(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[  38337703,    1023341]*)
(*NotebookOutlinePosition[  38439132,    1026422]*)
(*  CellTagsIndexPosition[  38424685,    1025987]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["5. Partial Differential Equations in Infinite Domains", "Title",
  CellTags->{"i:1", "c:1"}],

Cell["", "Text"],

Cell[TextData[{
  "In Chapters ",
  ButtonBox["3",
    ButtonData:>{"Chapter3.nb", None},
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["4",
    ButtonData:>{"Chapter4.nb", None},
    ButtonStyle->"Hyperlink"],
  ",  we found solutions to various partial differential equations in finite \
spatial domains. In order to determine the solution, it was necessary to \
specify boundary conditions. In this chapter, we explore solutions to PDEs in \
infinite spatial domains. One often encounters effectively infinite domains, \
where the boundaries are sufficiently far from the region of interest to have \
negligible influence on the local behavior of the solution."
}], "Text"],

Cell[TextData[{
  "\t Take, for example, a large object, inside which a localized temperature \
perturbation ",
  Cell[BoxData[
      FormBox[
        RowBox[{"T", "(", 
          RowBox[{
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[",",
              FontWeight->"Plain"], 
            StyleBox["t",
              FontWeight->"Plain"]}], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  " evolves, far from the edges of the object. (See Fig. ",
  ButtonBox["5.1",
    ButtonData:>"Fig. 5.1",
    ButtonStyle->"Hyperlink"],
  ".) This perturbation could be expanded as a sum of  eigenmodes for the \
system, but then boundary conditions would have to be specified, and this \
ought to be unnecessary. It should make no difference to the local evolution \
of the temperature whether the boundaries are insulated or are conducting, \
given that they are far from the perturbation. Also, if the boundary has some \
complicated shape, it could be difficult as a practical matter to determine \
the eigenmodes."
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000=P0001I2000`400?l00000o`00003oo`3ooooo
0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00
o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS
0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0oooo
o`3ooomS0?ooo`00o`3ooooo0?ooonD0oooo1@00001h0?ooo`00o`3ooooo0?ooonD0oooo2000001e
0?ooo`00o`3ooooo0?ooon@0oooo00<0P820000000000000200000000`10@400P8200820P01`0?oo
o`00o`3ooooo0?ooon@0oooo4000001^0?ooo`00o`3ooooo0?ooon@0oooo4P00001/0?ooo`00o`3o
oooo0?ooon@0oooo5P00001X0?ooo`00o`3ooooo0?ooon@0oooo6@00001U0?ooo`00o`3ooooo0?oo
on<0oooo00<0P8200000000000006@00001S0?ooo`00o`3ooooo0?ooon<0oooo00<0P82000000000
00006`0000000`10@400P8200?ooo`1N0?ooo`00o`3ooooo0?ooon<0oooo00<0P820000000000000
8000001L0?ooo`00o`3ooooo0?ooon<0oooo00<0P8200000000000008P00001J0?ooo`00l@3ooooo
00000?l000006P00001G0?ooo`00l@3ooooo00000?l000007000001E0?ooo`00k`3ooooo00000?l0
00007P0000000`20P800oooo0?ooo`1B0?ooo`00k`3oool3000000030410@020P800P8200?l0P820
k@20P80U000000<0P820E`3oool00>l0oooo0`0000000`20P800oooo0?ooo`3o0?ooond0oooo00<0
P8200000000000008000001L0?ooo`00k`3oool3000000030820P03oool0oooo0?l0ooook@3oool0
0`20P80000000000000N000005h0oooo003_0?ooo`<0000000<0P8200?ooo`3oool0o`3oooo]0?oo
o`030820P0000000000001/0000000<0P8200?ooo`3oool0GP3oool00>l0oooo0`0000000`20P800
oooo0?ooo`3o0?ooond0oooo00<0P8200000000000006@00001S0?ooo`00k`3oool3000000030820
P03oool0oooo0?l0ooook@3oool00`20P80000000000000F000006H0oooo003_0?ooo`<0000000<0
P8200?ooo`3oool0o`3oooo^0?oooa<000000`20P81X0?ooo`00k`3oool3000000030820P03oool0
oooo0?l0ooookP3ooolA000006d0oooo003_0?ooo`<0000000<0P8200?ooo`3oool0o`3oooo^0?oo
o`h00000L03oool00>l0oooo0`0000000`20P800oooo0?ooo`3o0?ooonl0oooo2`00001b0?ooo`00
k`3oool3000000030820P03oool0oooo0?l0ooook`3oool9000007@0oooo003_0?ooo`<0000000<0
P8200?ooo`3oool0o`3oooo_0?ooo`H00000M`3oool00>l0oooo0`0000000`20P800oooo0?ooo`3o
0?ooonl0oooo1020P81i0?ooo`00k`3oool3000000030820P03oool0oooo0?l0ooooo`3ooom]0?oo
o`00k`3oool3000000030820P03oool0oooo0?l0ooooo`3ooom]0?ooo`00k`3oool3000000030820
P03oool0oooo0?l0ooooo`3ooom]0?ooo`00k`3oool3000000030820P03oool0oooo0?l0ooooo`3o
oom]0?ooo`00k`3oool3000000030820P03oool0oooo0?l0ooooo`3ooom]0?ooo`00k`3oool30000
00030820P03oool0oooo0?l0ooooo`3ooom]0?ooo`00k`3oool3000000030820P03oool0oooo0?l0
ooooo`3ooom]0?ooo`00k`3oool3000000030820P03oool0oooo0?l0ooooo`3ooom]0?ooo`00k`3o
ool3000000030820P03oool0oooo0?l0ooooo03oool3000000P0oooo0`00001R0?ooo`00k`3oool3
000000030820P03oool0oooo0?l0oooon`3oool4000000030820P03oool0oooo00@0oooo1@00001Q
0?ooo`00k`3oool3000000030820P03oool0oooo0?l0oooon`3oool5000000H0oooo100000000`3o
ool0P8200?ooo`1O0?ooo`00k`3oool3000000030820P03oool0oooo0?l0ooooo03oool20820P080
oooo00<000000820P03oool00`3oool3000000030820P03oool0P8200600oooo003_0?ooo`<00000
00<0P8200?ooo`3oool0o`3ooooo0?ooo`80oooo00D000000?ooo`3oool0oooo0820P003000000<0
oooo00<000000?ooo`3oool0G@3oool00>l0oooo0`0000000`20P800oooo0?ooo`3o0?ooool0oooo
0`3oool010000000oooo0?ooo`20P803000006<0oooo003_0?ooo`<0000000<0P8200?ooo`3oool0
o`3ooooo0?ooo`<0oooo0P0000000`3oool0P82000000002000006<0oooo003_0?ooo`<0000000<0
P8200?ooo`3oool0o`3ooooo0?ooo`@0oooo00<000000?ooo`20P8000`00001S0?ooo`00k`3oool3
000000030820P03oool0oooo0?l0ooooo`3oool50?ooo`0400000020P8000000000006@0oooo003_
0?ooo`<0000000<0P8200?ooo`3oool0o`3ooooo0?ooo`D0oooo00@0P8200000000000000000I03o
ool00>l0oooo0`0000000`20P800oooo0?ooo`3o0?ooool0oooo1P3oool3000006@0oooo003_0?oo
o`<0000000<0P8200?ooo`3oool0o`3ooooo0?ooo`H0oooo0`00001T0?ooo`00k`3oool300000003
0820P03oool0oooo0?l0ooooo`3oool60?ooo`<00000I03oool00>l0oooo0`0000000`20P800oooo
0?ooo`3o0?ooool0oooo1@3oool4000006@0oooo003_0?ooo`<0000000<0P8200?ooo`3oool0o`3o
oooo0?ooo`D0oooo1@00001S0?ooo`00k`3oool3000000030820P03oool0oooo0?l0ooooo`3oool5
0?ooo`<0000000<0oooo0820P0000000HP3oool00>l0oooo0`0000000`20P800oooo0?ooo`3o0?oo
ool0oooo1@3oool300000080oooo0P000000103oool0000000000000001M0?ooo`00k`3oool30000
00030820P03oool0oooo0?l0ooooo`3oool40?ooo`<00000103oool5000005d0oooo003_0?ooo`<0
000000<0P8200?ooo`3oool0o`3ooooo0?ooo`040820P0000000oooo0?ooo`<000001@3oool40000
05d0oooo003_0?ooo`<0000000<0P8200?ooo`3oool0o`3ooooo0?ooo`80oooo100000000`20P800
oooo0?ooo`030?ooo`030820P0000000000005h0oooo003_0?ooo`<0000000<0P8200?ooo`3oool0
o`3ooooo0?ooofd0oooo003_0?ooo`<0000000<0P8200?ooo`3oool0o`3ooooo0?ooofd0oooo003_
0?ooo`<0000000<0P8200?ooo`3oool0o`3ooooo0?ooofd0oooo003_0?ooo`<0000000<0P8200?oo
o`3oool0o`3ooooo0?ooofd0oooo003_0?ooo`<0000000<0P8200?ooo`3oool0o`3ooooo0?ooofd0
oooo000E0?ooo`P000004P3oool;00000180oooo2P00000B0?ooo`X000003P3ooomD000001/0oooo
0`0000000`20P800oooo0?ooo`3o0?ooool0ooooK@3oool001D0oooo2000000B0?ooo`/000004P3o
ool:00000180oooo2P00000>0?oooe/00000503oool3000000030820P03oool0oooo0?l0ooooo`3o
oom]0?ooo`005@3oool800000180oooo2`00000B0?ooo`X000004P3oool:000000h0ooooG`000004
0820P0`0oooo0`0000000`20P800oooo0?ooo`3o0?ooool0ooooK@3oool00=<0oooo4`0000000`20
P800oooo0?ooo`060?ooo`<0000000<0P8200?ooo`3oool0o`3ooooo0?ooofd0oooo003J0?ooo`03
0820P0000000000000d000001@3oool3000000030820P03oool0oooo0?l0ooooo`3ooom]0?ooo`00
gP3oool?00000080oooo0`0000000`20P800oooo0?ooo`3o0?ooool0ooooK@3oool00>80oooo4000
00000`20P800oooo0?ooo`3o0?ooool0ooooK@3oool00>H0oooo3P00003o0?ooool0ooooKP3oool0
0>T0oooo0`20P8000`10@40000000000000900000080P820o`3ooooo0?ooofP0oooo003`0?ooo`d0
0000o`3ooooo0?ooofD0oooo003c0?ooo`/0000000<0P8200?ooo`3oool0o`3ooooo0?ooof40oooo
003g0?ooo`X00000o`3ooooo0?ooof40oooo003i0?ooo`X00000o`3ooooo0?oooel0oooo003k0?oo
o`X00000o`3ooooo0?oooed0oooo003_0?ooo`<0000000<0`<300?ooo`3oool02@3oool00`20P800
00000000000600000080P820o`3ooooo0?oooeT0oooo003_0?ooo`<0000000<0P8200?ooo`3oool0
3@3oool900000?l0ooooo`3ooomG0?ooo`00k`3oool3000000030820P03oool0oooo00h0oooo00<0
P8200000000000001`00003o0?ooool0ooooE@3oool00>l0oooo0`0000000`20P800oooo0?ooo`0A
0?ooo`T0000000<0P8200?ooo`3oool0o`3ooooo0?oooe00oooo003_0?ooo`<0000000<0P8200?oo
o`3oool04`3oool900000?l0ooooo`3ooomA0?ooo`00k`3oool3000000030820P03oool0oooo01D0
oooo2P00003o0?ooool0ooooCP3oool00>l0oooo0`0000000`20P800oooo0?ooo`0G0?ooo`<0P820
1P0000000`20P800oooo0?ooo`3o0?ooool0ooooBP3oool00>l0oooo0`0000000`20P800oooo0?oo
o`0K0?ooo`P00000o`3ooooo0?ooodX0oooo003_0?ooo`<0000000<0P8200?ooo`3oool07@3oool7
00000?l0ooooo`3ooom90?ooo`00k`3oool3000000030820P03oool0oooo01h0oooo2000003o0?oo
ool0ooooA`3oool00>l0oooo0`0000000`20P800oooo0?ooo`0P0?ooo`H0000000<0P8200?ooo`3o
ool0o`3ooooo0?oood@0oooo003_0?ooo`<0000000<0P8200?ooo`3oool08@3oool700000?l0oooo
o`3ooom50?ooo`00k`3oool3000000030820P03oool0oooo0280oooo0P20P806000000030820P03o
ool0oooo0?l0ooooo`3ooom00?ooo`00k`3oool3000000030820P03oool0oooo02D0oooo1`000000
0`20P800oooo0?ooo`3o0?ooool0oooo?P3oool00>l0oooo0`0000000`20P800oooo0?ooo`0V0?oo
o`030820P0000000000000D00000o`3ooooo0?ooocl0oooo003_0?ooo`<0000000<0P8200?ooo`3o
ool0:03oool700000?l0ooooo`3oooln0?ooo`00k`3oool3000000030820P03oool0oooo02T0oooo
2000003o0?ooool0oooo?03oool00>l0oooo0`0000000`20P800oooo0?ooo`0[0?ooo`L00000o`3o
oooo0?oooc/0oooo003_0?ooo`<0000000<0P8200?ooo`3oool0;03oool00`30`<00000000000004
000000030820P03oool0oooo0?l0ooooo`3ooolg0?ooo`00k`3oool3000000030820P03oool0oooo
02l0oooo1`00003o0?ooool0oooo=`3oool00>l0oooo0`0000000`20P800oooo0?ooo`0`0?ooo`L0
0000o`3ooooo0?ooocH0oooo003_0?ooo`<0000000<0P8200?ooo`3oool0<P3oool600000?l0oooo
o`3ooole0?ooo`00k`3oool3000000030820P03oool0oooo0380oooo00<0P8200000000000000`00
00000`20P800oooo0?ooo`3o0?ooool0oooo<P3oool00>l0oooo0`0000000`20P800oooo0?ooo`0d
0?ooo`H00000o`3ooooo0?oooc<0oooo003_0?ooo`<0000000<0P8200?ooo`3oool0=@3oool00`20
P800000000000003000000030820P03oool0oooo0?l0ooooo`3oool_0?ooo`00k`3oool300000003
0820P03oool0oooo03P0oooo1@00003o0?ooool0oooo<03oool00>l0oooo0`0000000`20P800oooo
0?ooo`0h0?ooo`030820P0000000000000<0000000<0P8200?ooo`3oool0o`3ooooo0?ooob`0oooo
003_0?ooo`<0000000<0P8200?ooo`3oool0>@3oool600000?l0ooooo`3oool^0?ooo`00k`3oool3
000000030820P03oool0oooo03/0oooo1@00003o0?ooool0oooo;@3oool00>l0oooo0`0000000`20
P800oooo0?ooo`0l0?ooo`D00000o`3ooooo0?ooob`0oooo003_0?ooo`<0000000<0P8200?ooo`3o
ool0?@3oool00`20P800@41000000003000000030820P03oool0oooo0?l0ooooo`3ooolW0?ooo`00
k`3oool3000000030820P03oool0oooo03l0oooo1@0000000`20P800oooo0?ooo`3o0?ooool0oooo
9P3oool00>l0oooo0`0000000`20P800oooo0?ooo`100?ooo`D00000o`3ooooo0?ooobP0oooo003_
0?ooo`<0000000<0P8200?ooo`3oool0@P3oool500000?l0ooooo`3ooolV0?ooo`00k`3oool30000
00030820P03oool0oooo04<0oooo1@00003o0?ooool0oooo9@3oool00>l0oooo0`0000000`20P800
oooo0?ooo`140?ooo`D00000o`3ooooo0?ooob@0oooo003_0?ooo`<0000000<0P8200?ooo`3oool0
A@3oool4000000030410@03oool0oooo0?l0ooooo`3ooolQ0?ooo`00k`3oool3000000030820P03o
ool0oooo04H0oooo1@00003o0?ooool0oooo8P3oool00>l0oooo0`0000000`20P800oooo0?ooo`17
0?ooo`D00000o`3ooooo0?ooob40oooo003_0?ooo`<0000000<0P8200?ooo`3oool0B03oool50000
0?l0ooooo`3ooolP0?ooo`00k`3oool3000000030820P03oool0oooo04T0oooo1@00003o0?ooool0
oooo7`3oool00>l0oooo0`0000000`20P800oooo0?ooo`190?ooo`030<30`0000000000000<00000
00<0`<300?ooo`3oool0o`3ooooo0?oooa/0oooo003_0?ooo`<0000000<0P8200?ooo`3oool0B`3o
ool500000?l0ooooo`3ooolM0?ooo`00k`3oool3000000030820P03oool0oooo04`0oooo1@00003o
0?ooool0oooo703oool00>l0oooo0`0000000`20P800oooo0?ooo`1=0?ooo`D00000o`3ooooo0?oo
oa/0oooo003_0?ooo`<0000000<0P8200?ooo`3oool0CP3oool500000?l0ooooo`3ooolJ0?ooo`00
k`3oool3000000030820P03oool0oooo04l0oooo00<0P8200000000000000P00003o0?ooool0oooo
6@3oool00>l0oooo0`0000000`20P800oooo0?ooo`1@0?ooo`030820P000000000000080000000<0
`<300?ooo`3oool0o`3ooooo0?oooaD0oooo003_0?ooo`<0000000<0P8200?ooo`3oool0DP3oool4
00000?l0ooooo`3ooolG0?ooo`00k`3oool3000000030820P03oool0oooo05<0oooo1000003o0?oo
ool0oooo5P3oool00>l0oooo0`0000000`20P800oooo0?ooo`1D0?ooo`@00000o`3ooooo0?oooaD0
oooo003_0?ooo`<0000000<0P8200?ooo`3oool0E@3oool400000?l0ooooo`3ooolD0?ooo`00k`3o
ool3000000030820P03oool0oooo05D0oooo00<0P8200000000000000P00003o0?ooool0oooo4`3o
ool00>l0oooo0`0000000`20P800oooo0?ooo`1F0?ooo`030820P000000000000080000000<0@410
0?ooo`3oool0o`3ooooo0?ooo`l0oooo003_0?ooo`<0000000<0P8200?ooo`3oool0E`3oool50000
0?l0ooooo`3ooolA0?ooo`00k`3oool3000000030820P03oool0oooo05P0oooo1@00003o0?ooool0
oooo403oool00>l0oooo0`0000000`20P800oooo0?ooo`1I0?ooo`D00000o`3ooooo0?ooo`l0oooo
003_0?ooo`<0000000<0P8200?ooo`3oool0F@3oool600000?l0ooooo`3oool>0?ooo`00k`3oool3
000000030820P03oool0oooo05X0oooo1P00003o0?ooool0oooo3@3oool00>l0oooo0`0000000`20
P800oooo0?ooo`1K0?ooo`030410@0000000000000<00000o`3ooooo0?ooo``0oooo003_0?ooo`<0
000000<0P8200?ooo`3oool0G03oool5000000030820P03oool0oooo0?l0ooooo`3oool90?ooo`00
k`3oool3000000030820P03oool0oooo05d0oooo1@00003o0?ooool0oooo2`3oool00>l0oooo0`00
00000`20P800oooo0?ooo`1M0?ooo`H00000o`3ooooo0?ooo`X0oooo003_0?ooo`<0000000<0P820
0?ooo`3oool0GP3oool600000?l0ooooo`3oool90?ooo`00k`3oool3000000030820P03oool0oooo
05l0oooo1P00003o0?ooool0oooo203oool00>l0oooo0`0000000`20P800oooo0?ooo`1P0?ooo`03
0820P000000000000080000000<0P8200?ooo`3oool0o`3ooooo0?ooo`D0oooo003_0?ooo`<00000
00<0P8200?ooo`3oool0H@3oool00`20P80000000000000300000?l0ooooo`3oool60?ooo`00k`3o
ool3000000030820P03oool0oooo0640oooo00<0P8200000000000000`0000000`20P800oooo0?oo
o`3o0?ooool0oooo0`3oool00>l0oooo0`0000000`20P800oooo0?ooo`1R0?ooo`H00000o`3ooooo
0?ooo`D0oooo003_0?ooo`<0000000<0P8200?ooo`3oool0H`3oool600000?l0ooooo`3oool40?oo
o`00k`3oool3000000030820P03oool0oooo06@0oooo1@00003o0?ooool0oooo103oool00>l0oooo
0`0000000`20P800oooo0?ooo`1U0?ooo`030820P000000000000080000000<0P8200?ooo`3oool0
o`3ooooo0?ooo`00k`3oool3000000030820P03oool0oooo06H0oooo1P00003o0?ooool0oooo0@3o
ool00>l0oooo0`0000000`20P800oooo0?ooo`1W0?ooo`D00000o`3ooooo0?ooo`40oooo003_0?oo
o`<0000000<0P8200?ooo`3oool0I`3oool00`20P80000000000000300000?l0ooooo`3oool00>l0
oooo0`0000000`20P800oooo0?ooo`1X0?ooo`D0000000<0P8200?ooo`3oool0o`3ooool0?ooo`00
k`3oool3000000030820P03oool0oooo06T0oooo1@00003o0?ooooh0oooo003_0?ooo`<0000000<0
P8200?ooo`3oool0J@3oool00`20P800000000000002000000030820P03oool0oooo0?l0oooon`3o
ool00>l0oooo0`0000000`20P800oooo0?ooo`1[0?ooo`D00000o`3ooool0?ooo`00k`3oool30000
00030820P03oool0oooo06`0oooo1000003o0?oooo`0oooo003_0?ooo`<0000000<0P8200?ooo`3o
ool0K03oool500000?l0oooon`3oool00>l0oooo0`0000000`20P800oooo0?ooo`1]0?ooo`D00000
o`3ooooj0?ooo`00k`3oool3000000030820P03oool0oooo06d0oooo00<0P8200000000000000`00
003o0?ooooT0oooo003_0?ooo`<0000000<0P8200?ooo`3oool0KP3oool00`20P800000000000002
000000030<30`03oool0oooo0?l0oooomP3oool00>l0oooo0`0000000`20P800oooo0?ooo`1_0?oo
o`D00000o`3ooooh0?ooo`00k`3oool3000000030820P03oool0oooo0700oooo1000003o0?ooooP0
oooo003_0?ooo`<0000000<0P8200?ooo`3oool0L@3oool400000?l0oooom`3oool00>l0oooo0`00
00000`20P800oooo0?ooo`1b0?ooo`@00000o`3oooof0?ooo`00k`3oool3000000030820P03oool0
oooo07<0oooo0`00003o0?ooooH0oooo003_0?ooo`<0000000<0P8200?ooo`3oool0L`3oool01@10
@4000000000000000000P8200?l0oooom03oool00>l0oooo0`0000000`20P800oooo0?ooo`1d0?oo
o`D00000o`3ooooc0?ooo`00k`3oool3000000030820P03oool0oooo07D0oooo1000003o0?oooo<0
oooo003_0?ooo`<0000000<0P8200?ooo`3oool0M@3oool4000000030820P03oool0oooo0?l0oooo
l03oool00>l0oooo0`0000000`20P800oooo0?ooo`1f0?ooo`@00000o`3oooob0?ooo`00k`3oool3
000000030820P03oool0oooo07L0oooo0`00003o0?oooo80oooo003_0?ooo`<0000000<0P8200?oo
o`3oool0N03oool3000000030820P03oool0oooo0?l0ooookP3oool00>l0oooo0`0000000`20P800
oooo0?ooo`1i0?ooo`<00000o`3oooo`0?ooo`00k`3oool3000000030820P03oool0oooo07T0oooo
00@0P8200000000000000000o`3oooo_0?ooo`00k`3oool3000000030820P03oool0oooo07T0oooo
00<0P8200000000000000P00003o0?ooonh0oooo003_0?ooo`<0000000<0P8200?ooo`3oool0NP3o
ool400000?l0ooookP3oool00>l0oooo0`0000000`20P800oooo0?ooo`1k0?ooo`@00000o`3oooo]
0?ooo`00k`3oool3000000030820P03oool0oooo07/0oooo00D0P82000000000000000000820P03o
0?ooon`0oooo003_0?ooo`<0000000<0P8200?ooo`3oool0O@3oool300000?l0ooook03oool00>l0
oooo0`0000000`20P800oooo0?ooo`1m0?ooo`@00000o`3ooola0?ooo`030820P0000000000004/0
00004P3oool;00000140oooo00<0P8200000000000002@00000B0?ooo`T000005`3oool00>l0oooo
0`0000000`20P800oooo0?ooo`1n0?ooo`<00000o`3oool]0?oooe8000004P3oool;00000140oooo
00<0P8200000000000002@00000B0?ooo`T000005`3oool00>l0oooo0`0000000`20P800oooo0?oo
o`1o0?ooo`<00000o`3ooolW0?oooeL000004P3oool;00000140oooo00<0P8200000000000002@00
000B0?ooo`T000005`3oool00>l0oooo0`0000000`20P800oooo0?ooo`1o0?ooo`@00000o`3ooolS
0?oooeX000004P3oool;00000140oooo00<0P8200000000000002@00000B0?ooo`T000005`3oool0
0>l0oooo0`0000000`20P800oooo0?ooo`1o0?ooo`050<30`0000000000000000020P800o`3ooolM
0?ooo`030<30`020P800P82000X000001@20P82i0?ooo`00k`3oool3000000030820P03oool0oooo
0800oooo100000000`20P800oooo0?ooo`3o0?oooaP0oooo2`0000320?ooo`00k`3oool300000003
0820P03oool0oooo0840oooo0`0000000`20P800oooo0?ooo`3o0?oooaH0oooo2P0000350?ooo`00
k`3oool3000000030820P03oool0oooo0880oooo0`00003o0?oooaH0oooo2`0000360?ooo`00k`3o
ool3000000030820P03oool0oooo0880oooo1000003o0?oooa<0oooo2P0000390?ooo`00k`3oool3
000000030820P03oool0oooo08<0oooo0`00003o0?oooa40oooo2P00003;0?ooo`00k`3oool30000
00030820P03oool0oooo08@0oooo0`0000000`20P800oooo0?ooo`3o0?ooo`X0oooo00<0P8200410
@00000001@0000030820P<d0oooo003_0?ooo`<0000000<0P8200?ooo`3oool0Q03oool01020P800
000000000000003o0?ooo`X0oooo2@00003A0?ooo`00k`3oool3000000030820P03oool0oooo08D0
oooo1000003o0?ooo`L0oooo2@00003C0?ooo`00k`3oool3000000030820P03oool0oooo08D0oooo
1@00003o0?ooo`D0oooo1`00003F0?ooo`00k`3oool3000000030820P03oool0oooo08H0oooo1000
003o0?ooo`<0oooo2000003G0?ooo`00k`3oool3000000030820P03oool0oooo08L0oooo0`000000
0`20P800oooo0?ooo`3m0?ooo`P00000f@3oool00>l0oooo0`0000000`20P800oooo0?ooo`270?oo
o`040820P0000000000000000?d0oooo00<0P8200000000000000`0000000`10@400oooo0?ooo`3J
0?ooo`00k`3oool3000000030820P03oool0oooo08T0oooo0`00003j0?ooo`L00000gP3oool00>l0
oooo0`0000000`20P800oooo0?ooo`290?ooo`@00000n03oool700000=l0oooo003_0?ooo`<00000
00<0P8200?ooo`3oool0RP3oool300000?H0oooo1`00003Q0?ooo`00k`3oool3000000030820P03o
ool0oooo08X0oooo00@0P8200000000000000000m03oool700000>80oooo003_0?ooo`<0000000<0
P8200?ooo`3oool0RP3oool01020P800000000000000003c0?ooo`L00000h`3oool00>l0oooo0`00
00000`20P800oooo0?ooo`2;0?ooo`@0000000<0P8200?ooo`3oool0k03oool00`20P80000000000
0004000000030820P03oool0oooo0><0oooo003_0?ooo`<0000000<0P8200?ooo`3oool0S03oool4
00000>`0oooo00<0P8200000000000001000003X0?ooo`00k`3oool3000000030820P03oool0oooo
08d0oooo0`0000000`20P800oooo0?ooo`3Y0?ooo`H0000000<0P8200?ooo`3oool0iP3oool00>l0
oooo0`0000000`20P800oooo0?ooo`2=0?ooo`@00000jP3oool600000>X0oooo003_0?ooo`<00000
00<0P8200?ooo`3oool0SP3oool300000>P0oooo1`00003[0?ooo`00k`3oool3000000030820P03o
ool0oooo08l0oooo0`00003V0?ooo`H00000k@3oool00>l0oooo0`0000000`20P800oooo0?ooo`2?
0?ooo`040820P0000000000000000><0oooo00<0P8200000000000000`0000000`10@400oooo0?oo
o`3/0?ooo`00k`3oool3000000030820P03oool0oooo0900oooo00@0P8200000000000000000h@3o
ool600000?00oooo003_0?ooo`<0000000<0P8200?ooo`3oool0T03oool00`20P800000000000002
00000=h0oooo1`00003a0?ooo`00k`3oool3000000030820P03oool0oooo0940oooo1000003M0?oo
o`L00000lP3oool00>l0oooo0`0000000`20P800oooo0?ooo`2B0?ooo`@00000f`3oool600000?@0
oooo003_0?ooo`<0000000<0P8200?ooo`3oool0TP3oool4000000030820P03oool0oooo0=L0oooo
1P0000000`20P800oooo0?ooo`3b0?ooo`00k`3oool3000000030820P03oool0oooo09<0oooo00@0
P820000000000000@410e`3oool00`20P80000000000000200000080P820mP3oool00>l0oooo0`00
00000`20P800oooo0?ooo`2D0?ooo`@00000e03oool600000?T0oooo003_0?ooo`<0000000<0P820
0?ooo`3oool0U@3oool300000=<0oooo1@0000000`20P800oooo0?ooo`3h0?ooo`00k`3oool30000
00030820P03oool0oooo09D0oooo1000003A0?ooo`030820P0000000000000<00000n`3oool00>l0
oooo0`0000000`20P800oooo0?ooo`2F0?ooo`@00000c`3oool600000?`0oooo003_0?ooo`<00000
00<0P8200?ooo`3oool0UP3oool00`20P80000000000000200000<d0oooo1P00003m0?ooo`00k`3o
ool3000000030820P03oool0oooo09H0oooo00<0`<300000000000000P0000000`20P800oooo0?oo
o`370?ooo`030<30`020P800000000<0000000<0P8200?ooo`3oool0o@3oool00>l0oooo0`000000
0`20P800oooo0?ooo`2H0?ooo`@0000000<0P8200?ooo`3oool0aP3oool5000000030820P03oool0
oooo0?h0oooo003_0?ooo`<0000000<0P8200?ooo`3oool0V03oool4000000030820P03oool0oooo
0<D0oooo1P00003o0?ooo`80oooo003_0?ooo`<0000000<0P8200?ooo`3oool0V@3oool400000<H0
oooo1@00003o0?ooo`@0oooo003_0?ooo`<0000000<0P8200?ooo`3oool0VP3oool400000<<0oooo
1P00003o0?ooo`D0oooo003_0?ooo`<0000000<0P8200?ooo`3oool0VP3oool400000<80oooo1P00
003o0?ooo`H0oooo003_0?ooo`<0000000<0P8200?ooo`3oool0V`3oool4000000030820P03oool0
oooo0;d0oooo00<0@4100000000000000P0000000`20P800`<300?ooo`3o0?ooo`D0oooo003_0?oo
o`<0000000<0P8200?ooo`3oool0W03oool400000;d0oooo1P00003o0?ooo`T0oooo003_0?ooo`<0
000000<0P8200?ooo`3oool0W03oool00`20P80000000000000200000;/0oooo1P00003o0?ooo`X0
oooo003_0?ooo`<0000000<0P8200?ooo`3oool0W03oool00`20P80000000000000300000;T0oooo
1P00003o0?ooo`/0oooo003_0?ooo`<0000000<0P8200?ooo`3oool0W@3oool500000;P0oooo1@00
00000`20P800oooo0?ooo`3o0?ooo`X0oooo003_0?ooo`<0000000<0P8200?ooo`3oool0WP3oool0
1@20P8000000000000000000@4100;D0oooo00<0P8200000000000000`0000000`20P800oooo0?oo
o`3o0?ooo`/0oooo003_0?ooo`<0000000<0P8200?ooo`3oool0W`3oool400000;@0oooo1P00003o
0?ooo`l0oooo003_0?ooo`<0000000<0P8200?ooo`3oool0X03oool400000;80oooo1@00003o0?oo
oa40oooo003_0?ooo`<0000000<0P8200?ooo`3oool0X@3oool400000;00oooo1@00003o0?oooa80
oooo003_0?ooo`<0000000<0P8200?ooo`3oool0XP3oool300000:l0oooo1@0000000`20P800oooo
0?ooo`3o0?oooa00oooo003_0?ooo`<0000000<0P8200?ooo`3oool0XP3oool400000:d0oooo00<0
P8200000000000000`00003o0?oooa<0oooo003_0?ooo`<0000000<0P8200?ooo`3oool0XP3oool0
0`30`<0000000000000200000:/0oooo00@0P82000000000000000000P20P83o0?oooa@0oooo003_
0?ooo`<0000000<0P8200?ooo`3oool0X`3oool500000:P0oooo1@00003o0?oooaL0oooo003_0?oo
o`<0000000<0P8200?ooo`3oool0Y03oool4000000030820P03oool0oooo0:@0oooo1@00003o0?oo
oaP0oooo003_0?ooo`<0000000<0P8200?ooo`3oool0Y@3oool3000000030820P03oool0oooo0:<0
oooo1@0000000`20P800oooo0?ooo`3o0?oooaH0oooo003_0?ooo`<0000000<0P8200?ooo`3oool0
Y@3oool400000:@0oooo00<0P8200000000000000`00003o0?oooaT0oooo003_0?ooo`<0000000<0
P8200?ooo`3oool0YP3oool400000:<0oooo1@00003o0?oooaX0oooo003_0?ooo`<0000000<0P820
0?ooo`3oool0Y`3oool01020P800000000000020P82P0?ooo`040820P0000000000000000080P820
o`3ooolK0?ooo`00k`3oool3000000030820P03oool0oooo0:P0oooo1000002N0?ooo`@00000o`3o
oolN0?ooo`00k`3oool3000000030820P03oool0oooo0:P0oooo00@0P8200000000000000000W03o
ool5000000030820P03oool0oooo0?l0oooo703oool00>l0oooo0`0000000`20P800oooo0?ooo`2Y
0?ooo`D00000V@3oool00`20P80000000000000300000?l0oooo7`3oool00>l0oooo0`0000000`20
P800oooo0?ooo`2Y0?ooo`D0000000<0P8200?ooo`3oool0UP3oool500000?l0oooo803oool00>l0
oooo0`0000000`20P800oooo0?ooo`2Z0?ooo`D00000U`3oool400000?l0oooo8P3oool00>l0oooo
0`0000000`20P800oooo0?ooo`2[0?ooo`050820P0000000000000000020P800T`3oool00`20P800
000000000002000000030820P03oool0oooo0?l0oooo8@3oool00>l0oooo0`0000000`20P800oooo
0?ooo`2]0?ooo`@00000T@3oool5000000030820P03oool0oooo0?l0oooo8P3oool00>l0oooo0`00
00000`20P800oooo0?ooo`2]0?ooo`D00000S`3oool00`20P80000000000000200000?l0oooo9P3o
ool00>l0oooo0`0000000`20P800oooo0?ooo`2^0?ooo`D00000S@3oool500000?l0oooo9`3oool0
0>l0oooo0`0000000`20P800oooo0?ooo`2^0?ooo`030820P0000000000000<00000R`3oool50000
0?l0oooo:03oool00>l0oooo0`0000000`20P800oooo0?ooo`2_0?ooo`D00000RP3oool500000?l0
oooo:@3oool00>l0oooo0`0000000`20P800oooo0?ooo`2`0?ooo`050820P0000000000000000010
@400QP3oool00`30`<00000000000003000000030<30`03oool0oooo0?l0oooo:03oool00>l0oooo
0`0000000`20P800oooo0?ooo`2a0?ooo`D00000Q@3oool500000?l0oooo;03oool00>l0oooo0`00
00000`20P800oooo0?ooo`2b0?ooo`D00000PP3oool500000?l0oooo;P3oool00>l0oooo0`000000
0`20P800oooo0?ooo`2c0?ooo`D00000P03oool500000?l0oooo;`3oool00>l0oooo0`0000000`20
P800oooo0?ooo`2d0?ooo`@00000O`3oool500000?l0oooo<03oool00>l0oooo0`0000000`20P800
oooo0?ooo`2d0?ooo`030820P0000000000000800000O03oool00`20P80000000000000300000?l0
oooo<@3oool00>l0oooo0`0000000`20P800oooo0?ooo`2e0?ooo`@0000000<0@4100?ooo`3oool0
M`3oool20820P0@0000000<0P8200?ooo`3oool0o`3oool`0?ooo`00k`3oool3000000030820P03o
ool0oooo0;H0oooo1@00001g0?ooo`D00000o`3ooole0?ooo`00k`3oool3000000030820P03oool0
oooo0;L0oooo1@00001e0?ooo`D00000o`3ooolf0?ooo`00k`3oool3000000030820P03oool0oooo
0;P0oooo1@00001b0?ooo`030820P0000000000000<00000o`3ooolg0?ooo`00k`3oool300000003
0820P03oool0oooo0;T0oooo1@00001a0?ooo`D00000o`3ooolh0?ooo`00k`3oool3000000030820
P03oool0oooo0;T0oooo00<0P8200000000000000`00001^0?ooo`H00000o`3oooli0?ooo`00k`3o
ool3000000030820P03oool0oooo0;X0oooo00<0P8200000000000000P0000000`10@400P8200?oo
o`1X0?ooo`030<30`020P800000000<0000000<0P8200?ooo`3oool0o`3oooli0?ooo`00k`3oool3
000000030820P03oool0oooo0;`0oooo1P00001X0?ooo`D00000o`3ooolm0?ooo`00k`3oool30000
00030820P03oool0oooo0;d0oooo1P00001U0?ooo`H00000o`3oooln0?ooo`00k`3oool300000003
0820P03oool0oooo0;l0oooo1@00001S0?ooo`D00000o`3ooom00?ooo`00k`3oool3000000030820
P03oool0oooo0;l0oooo00<0P8200000000000000`00001P0?ooo`H00000o`3ooom10?ooo`00k`3o
ool3000000030820P03oool0oooo0<00oooo1@0000000`20P800oooo0?ooo`1L0?ooo`H00000o`3o
oom20?ooo`00k`3oool3000000030820P03oool0oooo0<40oooo00<0P8200000000000000P000000
0`20P800oooo0?ooo`1H0?ooo`80P820100000020820P?l0oooo@`3oool00>l0oooo0`0000000`20
P800oooo0?ooo`330?ooo`D00000E`3oool800000?l0ooooA@3oool00>l0oooo0`0000000`20P800
oooo0?ooo`340?ooo`D00000E@3oool00`20P80000000000000400000?l0ooooA`3oool00>l0oooo
0`0000000`20P800oooo0?ooo`350?ooo`H00000DP3oool700000?l0ooooB03oool00>l0oooo0`00
00000`20P800oooo0?ooo`350?ooo`030820P0000000000000<0000000<0P8200?ooo`3oool0C@3o
ool700000?l0ooooBP3oool00>l0oooo0`0000000`20P800oooo0?ooo`370?ooo`H00000C@3oool7
00000?l0ooooB`3oool00>l0oooo0`0000000`20P800oooo0?ooo`380?ooo`030820P00000000000
00<0000000<0P8200?ooo`3oool0A03oool20820P0L0000000<0P8200?ooo`3oool0o`3ooom;0?oo
o`00k`3oool3000000030820P03oool0oooo0</0oooo1P0000000`20P800oooo0?ooo`0o0?ooo`T0
0000o`3ooom@0?ooo`00k`3oool3000000030820P03oool0oooo0</0oooo00<0P820000000000000
1@00000o0?ooo`P00000o`3ooomB0?ooo`00k`3oool3000000030820P03oool0oooo0<d0oooo2000
000j0?ooo`T0000000<0P8200?ooo`3oool0o`3ooomA0?ooo`00k`3oool3000000030820P03oool0
oooo0<l0oooo2000000f0?ooo`X00000o`3ooomE0?ooo`00k`3oool3000000030820P03oool0oooo
0=00oooo2000000d0?ooo`P00000o`3ooomH0?ooo`00k`3oool3000000030820P03oool0oooo0=40
oooo00<0`<300820P00000001P0000020820P2T0oooo0`20P809000000030820P030`<00oooo0?l0
ooooF03oool00>l0oooo0`0000000`20P800oooo0?ooo`3E0?ooo`T000008`3oool=00000?l0oooo
GP3oool00>l0oooo0`0000000`20P800oooo0?ooo`3G0?ooo`030820P0000000000000P00000703o
ool>000000030820P03oool0oooo0?l0ooooG@3oool00>l0oooo0`0000000`20P800oooo0?ooo`3I
0?oooa4000003P3ooolA00000?l0ooooH`3oool00>l0oooo0`0000000`20P800oooo0?ooo`3K0?oo
ob/00000o`3ooomV0?ooo`00k`3oool3000000030820P03oool0oooo0=d0oooo00<0P82000000000
00008P00003o0?ooofX0oooo003_0?ooo`<0000000<0P8200?ooo`3oool0h03oool30820P1`00000
o`3ooom]0?ooo`00k`3oool3000000030820P03oool0oooo0?l0ooooo`3ooom]0?ooo`00k`3oool3
000000030820P03oool0oooo0?l0ooooo`3ooom]0?ooo`00k`3oool3000000030820P03oool0oooo
0?l0ooooo`3ooom]0?ooo`00k`3oool3000000030820P03oool0oooo0?l0ooooo`3ooom]0?ooo`00
k`3oool3000000030820P03oool0oooo0?l0ooooo`3ooom]0?ooo`00k`3oool3000000030820P03o
ool0oooo0?l0ooooo`3ooom]0?ooo`00k`3oool3000000030820P03oool0oooo0?l0ooooo`3ooom]
0?ooo`00j03ooolA00000?l0ooooo`3ooomY0?ooo`00iP3ooolF00000?l0ooooo`3ooomV0?ooo`00
h`3ooolK000000030820P03oool0oooo0?l0ooooo`3ooomQ0?ooo`00h`3ooolK000000030820P03o
ool0oooo0?l0ooooo`3ooomQ0?ooo`00i03ooolJ000000030820P03oool0oooo0?l0ooooo`3ooomQ
0?ooo`00i03ooolJ00000?l0ooooo`3ooomT0?ooo`00i@3ooolI00000?l0ooooo`3ooomT0?ooo`00
i@3ooolI00000?l0ooooo`3ooomT0?ooo`00i@3ooolH00000?l0ooooo`3ooomU0?ooo`00iP3ooolG
00000?l0ooooo`3ooomU0?ooo`00iP3ooolF000001<0oooo3020P8000`30`<00oooo0?ooo`3o0?oo
ool0ooooA03oool00>H0oooo00<0P8200000000000004`00000E0?ooo`L00000o`3ooooo0?ooodX0
oooo003V0?ooo`030820P00000000000018000005`3oool500000?l0ooooo`3ooom;0?ooo`00iP3o
ool00`20P80000000000000B000001P0oooo1000003o0?ooool0ooooB`3oool00>L0oooo5000000H
0?ooo`@00000o`3ooooo0?oood/0oooo003W0?oooa<000006P3oool400000?l0ooooo`3ooom:0?oo
o`00i`3oool00`20P80000000000000@000001X0oooo1000003o0?ooool0ooooBP3oool00>P0oooo
4@00000K0?ooo`@00000o`3ooooo0?ooodX0oooo003X0?oooa400000703oool400000?l0ooooo`3o
oom90?ooo`00j@3oool@000001`0oooo1000003o0?ooool0ooooB@3oool00>T0oooo3`0000000`20
P800oooo0?ooo`0J0?ooo`@00000o`3ooooo0?ooodT0oooo003Y0?ooo`l0000000<0P8200?ooo`3o
ool06P3oool500000?l0ooooo`3ooom80?ooo`00jP3oool>000000030<30`03oool0oooo01X0oooo
00<0P8200000000000000P00003o0?ooool0ooooB03oool00>/0oooo3@00000M0?ooo`030820P000
0000000000800000o`3ooooo0?ooodP0oooo003[0?ooo``000007P3oool00`20P800000000000003
00000?l0ooooo`3ooom70?ooo`00j`3oool<000001l0oooo1@00003o0?ooool0ooooA`3oool00>`0
oooo2`00000O0?ooo`D00000o`3ooooo0?ooodL0oooo003/0?ooo`X00000803oool500000?l0oooo
o`3ooom70?ooo`00k03oool00`10@40000000000000700000240oooo100000000`20P800oooo0?oo
o`3o0?ooool0ooooA03oool00>`0oooo00<0P8200000000000001P00000R0?ooo`@0000000<0P820
0?ooo`3oool0o`3ooooo0?oood@0oooo003/0?ooo`030820P0000000000000H000008P3oool50000
0?l0ooooo`3ooom60?ooo`00k@3oool7000002@0oooo1000003o0?ooool0ooooAP3oool00>d0oooo
1`00000T0?ooo`@00000o`3ooooo0?ooodH0oooo003]0?ooo`L000006`3oool00`20P800oooo0?oo
o`060?ooo`@000002@3oool00`000000oooo0?ooo`3o0?ooool0oooo>P3oool00>h0oooo1@00000L
0?ooo`030410@020P800oooo00H0oooo00<0P8200000000000000P0000080?ooo`0300000020P800
oooo0?l0ooooo`3ooolj0?ooo`00kP3oool5000001`0oooo00<0P8200000003oool01`3oool40000
00P0oooo0P00003o0?ooool0oooo>`3oool00>l0oooo0`0000000`20P800oooo0?ooo`0J0?ooo`03
0820P0000000000000L0oooo100000070?ooo`<00000o`3ooooo0?oooc/0oooo003_0?ooo`<00000
00<0P8200?ooo`3oool06`3oool4000000H0oooo100000050?ooo`@0000000<0P8200?ooo`3oool0
o`3ooooo0?ooocP0oooo003_0?ooo`<0000000<0P8200?ooo`3oool06`3ooolG000000030820P03o
ool0oooo0?l0ooooo`3ooolh0?ooo`00l03oool200000?l0ooooo`3ooom`0?ooo`00l03oool00`00
0000P8200?ooo`3o0?ooool0ooooK`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0oooo
o`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?oo
ool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo
003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?oo
of<0oooo0000\
\>"], "Picture",
  Evaluatable->False,
  ImageSize->{288, 118.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Fig. 5.1 Localized temperature perturbation", "Caption",
  CellTags->"Fig. 5.1"],

Cell[TextData[{
  "\tIn Sec. ",
  ButtonBox["5.1",
    ButtonData:>"c:3",
    ButtonStyle->"Hyperlink"],
  " we will see that problems such as this can be solved using Fourier \
transforms, provided that the system in question is uniform in space and time \
over the region of interest (i.e., the system is without spatial or temporal \
variation in intrinsic parameters such as the wave speed or the thermal \
conductivity).  Recall that in Chapter ",
  ButtonBox["2",
    ButtonData:>{"Chapter2.nb", None},
    ButtonStyle->"Hyperlink"],
  " Fourier transforms were used to describe arbitrary functions defined on \
the entire real line. Thus, they are just what is needed to describe the \
evolution of solutions to PDEs in infinite domains. Furthermore, we will see \
that these Fourier transform solutions can be determined without imposing \
specific boundary conditions."
}], "Text"],

Cell[TextData[{
  "\tIn Sec. ",
  ButtonBox["5.2",
    ButtonData:>"c:19",
    ButtonStyle->"Hyperlink"],
  " (and Sec. ",
  ButtonBox["5.3",
    ButtonData:>"c:32",
    ButtonStyle->"Hyperlink"],
  " in the electronic version) we consider systems that are nonuniform but \
still effectively infinite, in the sense that perturbations are localized far \
from boundaries, so that boundary conditions need not be specified. Now \
parameters such as the sound speed or conductivity vary with position or time \
in the region of interest. We will discuss an analytic approximation \
technique for determining the local evolution of the solution, called WKB \
theory. "
}], "Text"],

Cell[CellGroupData[{

Cell["5.1 Fourier Transform Methods", "Subtitle",
  CellTags->"c:3"],

Cell["", "Text"],

Cell[CellGroupData[{

Cell["5.1.1 The Wave Equation in One Dimension", "Subsubtitle",
  CellTags->"c:4"],

Cell[CellGroupData[{

Cell["Traveling Waves", "Section",
  CellTags->{"i:2", "c:5"}],

Cell[TextData[{
  "\tWe first consider solutions to the wave equation in one dimension, on an \
infinite uniform string running from ",
  Cell[BoxData[
      \(TraditionalForm\`\(-\[Infinity]\) < x < \[Infinity]\)]],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\^2 y\/\[PartialD]t\^2 = \(c\^2\) \
\[PartialD]\^2 y\/\[PartialD]x\^2\)]],
  ","
}], "NumberedEquation",
  CellTags->"(5.1.1)"],

Cell["subject to the initial conditions", "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`y(x, 0) = \(y\_o\)(
        x), \[IndentingNewLine]\(\[PartialD]y\/\[PartialD]t\) \((x, 
          0)\) = \(\(\(v\_o\)(x)\)\(.\)\)\)]]], "NumberedEquation",
  CellTags->"(5.1.2)"],

Cell[TextData[{
  "This problem can be solved by applying the spatial Fourier transform \
operator ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          
          FormBox[\(F\&^ = \[Integral]\_\(-\[Infinity]\)\%\[Infinity]\
\[DifferentialD]x\),
            "TraditionalForm"], 
          FormBox[\(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ k\ x\)\),
            "TraditionalForm"], " "}], TraditionalForm]]],
  "to both sides of Eq. ",
  ButtonBox["(5.1.1)",
    ButtonData:>"(5.1.1)",
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text",
  CellTags->"i:5"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(F\&^\) \[PartialD]\^2 y\/\[PartialD]t\^2 = \
\(F\&^\) \(c\^2\) \[PartialD]\^2 y\/\[PartialD]x\^2\)]],
  "."
}], "NumberedEquation",
  CellTags->"(5.1.3)"],

Cell[TextData[{
  "On the ",
  "left-hand",
  " side, we can exchange ",
  Cell[BoxData[
      \(TraditionalForm\`F\&^\)]],
  " with ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\^2\(\(/\)\(\[PartialD]t\^2\)\)\)]],
  ", writing"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(F\&^\) \[PartialD]\^2 y\/\[PartialD]t\^2 = \(\(\
\[PartialD]\^2\/\[PartialD]t\^2\) \(F\&^\) 
            y = \(\[PartialD]\^2\/\[PartialD]t\^2\) y\&~\)\)]],
  ", "
}], "Text"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\(y\&~\)(k, t)\)]],
  " is the spatial Fourier transform of ",
  Cell[BoxData[
      \(TraditionalForm\`y(x, t)\)]],
  ", given by"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(\(y\&~\)(k, t)\), "=", 
          RowBox[{
            
            FormBox[\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\
\[DifferentialD]x\),
              "TraditionalForm"], 
            
            FormBox[\(\(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ k\ x\)\) \(y(
                  x, t)\)\),
              "TraditionalForm"]}]}], TraditionalForm]]],
  "."
}], "NumberedEquation",
  CellTags->"(5.1.4)"],

Cell[TextData[{
  "On the ",
  "right-hand",
  " side of Eq. ",
  ButtonBox["(5.1.3)",
    ButtonData:>"(5.1.3)",
    ButtonStyle->"Hyperlink"],
  ", we use Eq. ",
  ButtonBox["(2.3.18)",
    ButtonData:>{"Chapter2.nb", "(2.3.18)"},
    ButtonStyle->"Hyperlink"],
  " to write\n\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(F\&^\) \(c\^2\) \[PartialD]\^2 y\/\[PartialD]x\^2 \
= \(\(-c\^2\) \(k\^2\) F\&^\ y = \(-c\^2\) \(k\^2\) y\&~\)\)]],
  ". \n Thus, Eq. ",
  ButtonBox["(5.1.3)",
    ButtonData:>"(5.1.3)",
    ButtonStyle->"Hyperlink"],
  " becomes a second-order ODE in time,"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\[PartialD]\^2\/\[PartialD]t\^2\) \(\(y\&~\)(k, 
            t)\) = \(-c\^2\) \(k\^2\) \(\(y\&~\)(k, t)\)\)]],
  "."
}], "NumberedEquation",
  CellTags->"(5.1.5)"],

Cell[TextData[{
  "This ODE is merely the harmonic oscillator equation, with an oscillation \
frequency that depends on the wavenumber ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  " according to "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Omega](k) = c\ k\)]],
  "."
}], "NumberedEquation",
  CellTags->"(5.1.6)"],

Cell[TextData[{
  "Such a relation between frequency and wavenumber is called a ",
  StyleBox["dispersion relation",
    FontSlant->"Italic"],
  ". "
}], "Text",
  CellTags->"i:3"],

Cell[TextData[{
  "\tIt is convenient to write the general solution to Eq. ",
  ButtonBox["(5.1.5)",
    ButtonData:>"(5.1.5)",
    ButtonStyle->"Hyperlink"],
  " in exponential notation, "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(y\&~\)(k, 
          t) = \(C(
              k)\)\ \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \(\[Omega](k)\)\ t\
\) + \(\(D(k)\) \(\[ExponentialE]\^\(\[ImaginaryI]\ \(\[Omega](
                    k)\)\ t\)\)\(\ \)\)\)]],
  "."
}], "NumberedEquation",
  CellTags->"(5.1.7)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`C(k)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`D(k)\)]],
  " are the two undetermined coefficients that appear in this second-order \
ODE. These coefficients can take on different values for different ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  "'s and so are written as functions of ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  ". We can then transform the solution back to ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  "-space by applying an inverse Fourier transformation, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          
          FormBox[\(F\&^\^\(-1\) = \[Integral]\_\(-\[Infinity]\)\%\[Infinity]\
\[DifferentialD]k\/\(2  \[Pi]\)\),
            "TraditionalForm"], 
          FormBox[\(\[ExponentialE]\^\(\[ImaginaryI]\ k\ x\)\),
            "TraditionalForm"]}], TraditionalForm]]],
  ", to Eq. ",
  ButtonBox["(5.1.7)",
    ButtonData:>"(5.1.7)",
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(y(x, t)\), "=", 
          RowBox[{\(\(F\&^\^\(-1\)\) \(\(y\&~\)(k, t)\)\), "=", 
            RowBox[{
              
              FormBox[\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\
\[DifferentialD]k\/\(2  \[Pi]\)\),
                "TraditionalForm"], \(C(k)\), 
              FormBox[
                
                RowBox[{\(\[ExponentialE]\^\(\[ImaginaryI]\ \((k\ x - \(\
\[Omega](k)\) t)\)\)\), "+", 
                  RowBox[{
                    
                    FormBox[\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\
\[DifferentialD]k\/\(2  \[Pi]\)\),
                      "TraditionalForm"], \(D(k)\), 
                    
                    FormBox[\(\[ExponentialE]\^\(\[ImaginaryI]\ \((k\ x + \(\
\[Omega](k)\) t)\)\)\),
                      "TraditionalForm"]}]}],
                "TraditionalForm"]}]}]}], TraditionalForm]]],
  "."
}], "NumberedEquation",
  CellTags->"(5.1.8)"],

Cell[TextData[{
  "Equation ",
  ButtonBox["(5.1.8)",
    ButtonData:>"(5.1.8)",
    ButtonStyle->"Hyperlink"],
  " is the general solution to the wave equation on a one-dimensional \
infinite uniform string. It looks very similar to the eigenmode expansions \
encountered in Chapter ",
  ButtonBox["4",
    ButtonData:>{"Chapter4.nb", None},
    ButtonStyle->"Hyperlink"],
  ", except that now we integrate over a continuous spectrum of modes rather \
than summing over a countably infinite set. In fact, one can think of the \
functions  ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(\[ImaginaryI]\ k\ x\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ k\ x\)\)]],
  " in Eq. ",
  ButtonBox["(5.1.8)",
    ButtonData:>"(5.1.8)",
    ButtonStyle->"Hyperlink"],
  "  as eigenmodes of the operator ",
  Cell[BoxData[
      \(TraditionalForm\`\(c\^\(\(2\)\(\ \)\)\) \[PartialD]\^2\(\(/\)\(\
\[PartialD]x\^2\)\)\)]],
  ", in that this operator returns these functions unchanged except for a \
multiplicative constant (the eigenvalue, ",
  Cell[BoxData[
      \(TraditionalForm\`\(-c\^2\)\ k\^2\)]],
  "). However, unlike regular eigenvalue problems, there are no boundary \
conditions associated with these functions at ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[PlusMinus]\[Infinity]\)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tEquation ",
  ButtonBox["(5.1.8)",
    ButtonData:>"(5.1.8)",
    ButtonStyle->"Hyperlink"],
  " can be further simplified by substituting the dispersion relation, Eq. ",
  ButtonBox["(5.1.6)",
    ButtonData:>"(5.1.6)",
    ButtonStyle->"Hyperlink"],
  ": "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(y(x, t)\), "=", 
          RowBox[{
            
            FormBox[\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\
\[DifferentialD]k\/\(2  \[Pi]\)\),
              "TraditionalForm"], \(C(k)\), 
            FormBox[
              
              RowBox[{\(\[ExponentialE]\^\(\[ImaginaryI]\ \(k(\ 
                        x - c\ t)\)\)\), "+", 
                RowBox[{
                  
                  FormBox[\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\
\[DifferentialD]k\/\(2  \[Pi]\)\),
                    "TraditionalForm"], \(D(k)\), 
                  
                  FormBox[\(\[ExponentialE]\^\(\[ImaginaryI]\ \(k(
                            x + c\ t)\)\)\),
                    "TraditionalForm"]}]}],
              "TraditionalForm"]}]}], TraditionalForm]]],
  "."
}], "NumberedEquation",
  CellTags->"(5.1.9)"],

Cell[TextData[{
  "The functions ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(\[ImaginaryI]\ \(k(\ x + c\ \
t)\)\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(\[ImaginaryI]\ \(k(x - c\ \
t)\)\)\)]],
  " represent traveling",
  StyleBox[" waves,",
    FontSlant->"Italic"],
  " propagating to the right and left respectively. The real parts of these \
two functions are shown in Cells ",
  ButtonBox["5.1",
    ButtonData:>"Cell 5.1",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["5.2",
    ButtonData:>"Cell 5.2",
    ButtonStyle->"Hyperlink"],
  ", taking ",
  Cell[BoxData[
      \(TraditionalForm\`c = 1\)]],
  "  and ",
  Cell[BoxData[
      \(TraditionalForm\`k = 1\)]],
  ". (The plots in Cells ",
  ButtonBox["5.1",
    ButtonData:>"Cell 5.1",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["5.2",
    ButtonData:>"Cell 5.2",
    ButtonStyle->"Hyperlink"],
  " differ only when animated, so only the former plot is included in the \
printed version of the book.)"
}], "Text",
  CellTags->"i:7"],

Cell[CellGroupData[{

Cell[BoxData[{\(c = 1; \ k = 1;\), "\n", 
    RowBox[{
      RowBox[{
      Cell[""], \(Table[
          Plot[Re[\[ExponentialE]\^\(\[ImaginaryI]\ k \((x - \ c\ t)\)\)], \
{x, 0, 6\ Pi}, 
            PlotLabel \[Rule] \
\*"\"\<Re[\!\(\[ExponentialE]\^\(\[ImaginaryI]\\\ k \((x - \\\ c\\\ t)\)\)\)]\
\>\"", AxesLabel \[Rule] {"\<x\>", "\<\>"}], {t, 0, 1.8\ Pi,  .2\ Pi}]\)}], 
      ";"}]}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 5.1"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0505254 0.309017 0.294302 [
[.15012 .29652 -9 -9 ]
[.15012 .29652 9 0 ]
[.27644 .29652 -3 -9 ]
[.27644 .29652 3 0 ]
[.40275 .29652 -9 -9 ]
[.40275 .29652 9 0 ]
[.52906 .29652 -6 -9 ]
[.52906 .29652 6 0 ]
[.65538 .29652 -12 -9 ]
[.65538 .29652 12 0 ]
[.78169 .29652 -6 -9 ]
[.78169 .29652 6 0 ]
[.908 .29652 -12 -9 ]
[.908 .29652 12 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .01471 -12 -4.5 ]
[.01131 .01471 0 4.5 ]
[.01131 .16187 -24 -4.5 ]
[.01131 .16187 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[.5 .63053 -37.9062 0 ]
[.5 .63053 37.9062 12.625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15012 .30902 m
.15012 .31527 L
s
[(2.5)] .15012 .29652 0 1 Mshowa
.27644 .30902 m
.27644 .31527 L
s
[(5)] .27644 .29652 0 1 Mshowa
.40275 .30902 m
.40275 .31527 L
s
[(7.5)] .40275 .29652 0 1 Mshowa
.52906 .30902 m
.52906 .31527 L
s
[(10)] .52906 .29652 0 1 Mshowa
.65538 .30902 m
.65538 .31527 L
s
[(12.5)] .65538 .29652 0 1 Mshowa
.78169 .30902 m
.78169 .31527 L
s
[(15)] .78169 .29652 0 1 Mshowa
.908 .30902 m
.908 .31527 L
s
[(17.5)] .908 .29652 0 1 Mshowa
.125 Mabswid
.04907 .30902 m
.04907 .31277 L
s
.07433 .30902 m
.07433 .31277 L
s
.0996 .30902 m
.0996 .31277 L
s
.12486 .30902 m
.12486 .31277 L
s
.17539 .30902 m
.17539 .31277 L
s
.20065 .30902 m
.20065 .31277 L
s
.22591 .30902 m
.22591 .31277 L
s
.25117 .30902 m
.25117 .31277 L
s
.3017 .30902 m
.3017 .31277 L
s
.32696 .30902 m
.32696 .31277 L
s
.35222 .30902 m
.35222 .31277 L
s
.37749 .30902 m
.37749 .31277 L
s
.42801 .30902 m
.42801 .31277 L
s
.45328 .30902 m
.45328 .31277 L
s
.47854 .30902 m
.47854 .31277 L
s
.5038 .30902 m
.5038 .31277 L
s
.55433 .30902 m
.55433 .31277 L
s
.57959 .30902 m
.57959 .31277 L
s
.60485 .30902 m
.60485 .31277 L
s
.63011 .30902 m
.63011 .31277 L
s
.68064 .30902 m
.68064 .31277 L
s
.7059 .30902 m
.7059 .31277 L
s
.73116 .30902 m
.73116 .31277 L
s
.75643 .30902 m
.75643 .31277 L
s
.80695 .30902 m
.80695 .31277 L
s
.83222 .30902 m
.83222 .31277 L
s
.85748 .30902 m
.85748 .31277 L
s
.88274 .30902 m
.88274 .31277 L
s
.93327 .30902 m
.93327 .31277 L
s
.95853 .30902 m
.95853 .31277 L
s
.98379 .30902 m
.98379 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01471 m
.03006 .01471 L
s
[(-1)] .01131 .01471 1 0 Mshowa
.02381 .16187 m
.03006 .16187 L
s
[(-0.5)] .01131 .16187 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(0.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .13244 m
.02756 .13244 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -98.9062 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.625 moveto
(@) show
81.000 13.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\343) show
87.000 9.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344) show
93.000 9.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
97.188 9.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
( ) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
99.000 9.625 moveto
(H) show
103.188 9.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
107.375 9.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
113.375 9.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
119.375 9.625 moveto
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
123.562 9.625 moveto
(L) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
128.812 13.625 moveto
(D) show
134.812 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.02499 .60324 L
.02605 .60303 L
.02729 .60262 L
.02846 .60208 L
.03053 .60072 L
.03279 .59869 L
.03527 .59578 L
.0379 .59195 L
.04262 .58316 L
.05205 .55852 L
.06244 .52139 L
.0842 .41696 L
.10458 .30083 L
.12312 .19585 L
.14335 .09889 L
.15431 .05946 L
.15965 .04441 L
.16449 .0333 L
.16689 .02872 L
.16949 .02447 L
.17174 .02141 L
.17421 .01871 L
.17684 .01659 L
.17827 .01577 L
.17896 .01545 L
.17961 .01521 L
.18086 .01488 L
.18201 .01473 L
.18324 .01474 L
.18393 .01483 L
.18458 .01495 L
.18575 .01531 L
.18699 .01586 L
.18805 .01646 L
.18921 .01728 L
.1918 .01964 L
.1942 .02252 L
.19857 .02941 L
.20324 .03907 L
.21403 .07006 L
.22384 .10769 L
.26382 .3202 L
.28214 .42377 L
.29255 .47678 L
.30229 .52 L
.31268 .55744 L
.32217 .58253 L
.32466 .58755 L
.32737 .59225 L
Mistroke
.32996 .59598 L
.33231 .5987 L
.33505 .60109 L
.33655 .60204 L
.33724 .60238 L
.33797 .60269 L
.33928 .60309 L
.34049 .60328 L
.34179 .6033 L
.34252 .60323 L
.34321 .6031 L
.34448 .60273 L
.34512 .60247 L
.34582 .60213 L
.34823 .60053 L
.34959 .59934 L
.35105 .59782 L
.35369 .59447 L
.35886 .58566 L
.3636 .57504 L
.37265 .54835 L
.38217 .51204 L
.42033 .31079 L
.44162 .19025 L
.46094 .09835 L
.47061 .06313 L
.47569 .04812 L
.48107 .03513 L
.48578 .0263 L
.48827 .02261 L
.49095 .01943 L
.49221 .01821 L
.4934 .01722 L
.49457 .01641 L
.49565 .01581 L
.49667 .01535 L
.49775 .01501 L
.49884 .01479 L
.50004 .01472 L
.50125 .01481 L
.50238 .01504 L
.50362 .01547 L
.50432 .01579 L
.50495 .01613 L
.50761 .01804 L
.51012 .0206 L
.51455 .02684 L
.51936 .03607 L
.52463 .04899 L
.53021 .06576 L
Mistroke
.54021 .10311 L
.57807 .30146 L
.59912 .42118 L
.61837 .51433 L
.62789 .55017 L
.63291 .56573 L
.63827 .57951 L
.64341 .58989 L
.64807 .59679 L
.65032 .59925 L
.65151 .60031 L
.65276 .60126 L
.65385 .60195 L
.65505 .60254 L
.65615 .60293 L
.65717 .60318 L
.65843 .60331 L
.65907 .60331 L
.65977 .60326 L
.66101 .60302 L
.66218 .60263 L
.66285 .60234 L
.66355 .60198 L
.6648 .6012 L
.66763 .59877 L
.67008 .59592 L
.67236 .59267 L
.67753 .58317 L
.68651 .55994 L
.6961 .52644 L
.71746 .42592 L
.73761 .31183 L
.75594 .2072 L
.76636 .15284 L
.7761 .10794 L
.7865 .06828 L
.79599 .04089 L
.8012 .02983 L
.80614 .02207 L
.80885 .01898 L
.81135 .01686 L
.8128 .01597 L
.81411 .01536 L
.81483 .01511 L
.81562 .01491 L
.81636 .01479 L
.81704 .01473 L
.81831 .01476 L
.81951 .01496 L
.82059 .01528 L
Mistroke
.82176 .01578 L
.82303 .0165 L
.82438 .01747 L
.82681 .01974 L
.83114 .02544 L
.83591 .03413 L
.84106 .04623 L
.84659 .06229 L
.8566 .09868 L
.87772 .20038 L
.89781 .31475 L
.91783 .42788 L
.93599 .51498 L
.94601 .55234 L
.95544 .57886 L
.96063 .58948 L
.96541 .59664 L
.96791 .59937 L
.96934 .60062 L
.97065 .60155 L
.97203 .60232 L
.97274 .60263 L
.97352 .60291 L
.97423 .6031 L
.97489 .60322 L
.97619 .60332 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  FontSlant->"Italic",
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool001So
oooo1?l000000ol@413oooooooooo`02ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000?ooooo`Ko00001Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000
ooooooooool01?ooool3o`0002gooooo1Ol0001Nooooo`Go0000G_ooool5o`0004cooooo000Joooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo05[ooooo0_l00003ooooo`;o0000GOooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo04Wooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0;?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05Sooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0BOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0[ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo05Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`18ooooo`006?oo
ool00omEEEGoIVIVo`000006ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0E_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04Sooooo000Qooooo`03o`000?oooooo
oooo02Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Fooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo04Oooooo000Qooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`1Dooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0E?ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo04Kooooo000Qooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo04Ko
oooo000Qooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`1Cooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0D_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo04Gooooo000Qooooo`?o0000:?ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`1Booooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0A?ooool0027ooooo00?o0000
ooooooooool0:?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo057ooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool0A?ooool0027ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo057ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1@oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool0A?ooool0027ooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo053ooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool0@oooool0027ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo04oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1?ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool0@oooool0027ooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0@ooo
ool0027ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo04kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0@oooool0027ooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`1=ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0@oooool0027o
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04go
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool0@_ooool0027ooooo0ol0000Uooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04gooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`12ooooo`008Oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0C?ooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`12ooooo`008Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool0Boooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo04_ooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`12ooooo`008Oooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`11oooo
o`008Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool0B_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04Wooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`11ooooo`008Oooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo04Wooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`11ooooo`008Ooo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0BOoo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`11ooooo`008Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo04Sooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`10ooooo`008Oooool00ol0
003oooooooooo`0Sooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0B?ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`10ooooo`008Oooool3o`0002?ooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`18ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0Aoooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo043ooooo000Qooooo`03o`000?oooooooooo02?ooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo043ooooo
000Qooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`16ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0A_ooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo03oooooo000Qooooo`03o`000?oooooooooo02;ooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool0A_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo03oooooo000Qoooo
o`03o`000?oooooooooo02;ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`16oooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo03oooooo000Qooooo`03o`000?oooooooooo02;ooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool0A?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo03oooooo000Qooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`15ooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo03oooooo000Qooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0A?oo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo03kooooo000Qooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`14ooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo03kooooo000Qooooo`?o00008Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
04Cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool0?_ooool0027ooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`12ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0?_ooool0027ooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo04?ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool0?Oooool0027ooooo00?o0000ooooooooool08?ooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`12ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0?Oooool0027ooooo00?o0000
ooooooooool08?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo04;ooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool0?Oooool0027ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo04;ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`12oooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0?Oooool0027ooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo04;ooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool0?Oooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo047ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`10oooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool0??ooool000Oooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
03cooooo0005o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
043ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool0??ooool000Oooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo00?ooooo0ol0000Nooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool0@?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo043ooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`0looooo`001oooool01Ol0003ooooooooooooooooo0000
00cooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool0?oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo03cooooo0007oooo
o`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo03_ooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0n
ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo03_ooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo03kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0nooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool0>oooool0027ooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`0nooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0>oooool0027o
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool0>_ooool0027ooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool08Oooool00ol0003ooooo
ooooo`0looooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0>_ooool0027ooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03gooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo027ooooo00?o
0000ooooooooool0>_ooool0027ooooo0ol0000Looooo`03o`000?oooooooooo02;ooooo00?o0000
ooooooooool0??ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03cooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`0jooooo`008Oooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo03cooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0joooo
o`008Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02;ooooo00?o0000oooooooo
ool0??ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03cooooo00?o0000oooooooo
ool08_ooool00ol0003oooooooooo`0iooooo`008Oooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo02;ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Rooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0iooooo`008Ooo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`0iooooo`008Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo03[ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0iooooo`008Oooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0>_ooool00ol0
003oooooooooo`0Sooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool08oooool00ol0
003oooooooooo`0iooooo`008Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03[o
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0hooooo`008Oooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0>Oooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`0hooooo`008Oooool3o`0001_ooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`0iooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0>Oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo03Sooooo000Qooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0>?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo000Qoooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo03Sooooo000Qooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0>?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo000Qooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0hooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo03Oooooo000Qooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0=ooo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo03Oooooo000Qooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooo
oooo02Oooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo03Oooooo000Qooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`0fooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo03Oooooo000Qooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo03Oo
oooo000Qooooo`?o00006Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo03Kooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool0=oooool0027ooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0=_ooool0027ooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo03Gooooo00?o0000
ooooooooool0:?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool0=_ooool0027ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Xoooo
o`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0doooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0=_ooool0027ooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo03Cooooo00?o0000oooooooo
ool0:Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02Wooooo00?o0000oooooooo
ool0=_ooool0027ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo03Cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo02Wooooo00?o0000ooooooooool0=_ooool0027ooooo00?o0000ooooooooool06Ooo
ool6o`0000Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd05Oooool00ol0003ooooo
ooooo`02ooooo`05odA4A?l0003o0000oc8b<_oMgMd07?ooool00ol0003ok^k^ooooo`05ooooo`;o
8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01Kooooo1?l000002?l@413oooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^1oooool00ol0003oooooooooo`0:ooooo`Co000000?o410@ooooooooool0
1Ol00005ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00gooooo00?o0000oooooooo
ool00_ooool4o`000005oa0@4?oooooooooooooooom4A4@00_l000000olb<S;ogMgMooooo`0Aoooo
o`Co000000?o410@ooooooooool00_ooool00ol0003ok^k^ooooo`05ooooo`;o8B4Q1Oooool01Om4
A4Co0000o`000?lb<S;ogMgM02Cooooo000Qooooo`03o`000?oooooooooo01Sooooo00Oo0000oooo
oonHV9So8B4Qonk^k_ooooooA4A400Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo01Cooooo00?o
0000ooooooooool01Oooool00omgMgOo<S8booooo`0Kooooo`03oeEEEOnYZJWooooo00Gooooo0_lQ
8B46ooooo`04o`000?ooooooMgMgoc8b<QSooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`02ooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool02oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?oMgMgoc8b<_ooool04oooool00ol0
003oooooooooo`04ooooo`03o`000?nYZJWooooo00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo
02?ooooo000Qooooo`03o`000?oooooooooo01Sooooo00Ko0000ooooooooooooV9RHob4Q8Oo^k^hA
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0J
ooooo`03ojVYZOmEEEGooooo00gooooo00Co0000oooooooooooo00006?ooool00ol0003ooooooooo
o`02ooooo`05oa0@4?ooooooooooooooool@41001oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00?ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo00Cooooo00?o0000oeEEEOooool04?ooool00ol0003oooooooooo`0Rooooo`008Ooo
ool3o`0001Sooooo00Oo0000oooooooooooooooooiRHV?lQ8B7ok^k^00oooooo00?oMgMgoc8b<_oo
ool05Oooool00ol0003oooooooooo`04ooooo`03ogMgMolb<S;ooooo01cooooo00?o8B4Qoooooooo
ool03?ooool01?l0003oooooogMgMolb<S8Hooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`000008ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01?ooool0
0onHV9So8B4Qonk^kP0?ooooo`03ogMgMolb<S;ooooo00_ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo01?ooooo00?o0000ooooooooool01?ooool0
0ol0003o8B4Qooooo`0?ooooo`03ogMgMolb<S;ooooo02?ooooo000Qooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool00_ooool00omgMgOoIVIVooooo`0;ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`05_ooool02Ol0003ooooooooooooooooo0000ob4Q8Ol0003o<S8bolc<c00Mooooo`03
oeEEEOo<c<cooooo00_ooooo0ol000000olb<S;oc<c<ooooo`0Gooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool01Oooool00omgMgOoIVIVooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c00Dooooo`03o`000?oooooooooo00Cooooo00?o0000oeEEEOo<c<`03?ooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<02Cooooo000Qooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Sooooo00Go0000oooooooooooooooo
o`00000Qooooo`03ojVYZOmgMgOooooo00_ooooo0_l0000Kooooo`03o`000?oooooooooo00;ooooo
00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool01?ooool00ol0003oZJVYogMgM`0<ooooo`03o`000?oooooooooo02Kooooo000Qooooo`03o`00
0?oooooooooo01Sooooo00Oo0000ooooool0003o^[ZjoooooonHV9So410@00cooooo00?o0000oooo
ooooool06?ooool01Ol0003ooooooooooooooooo000001kooooo00Go410@oooooooooooooooooc8b
<P0<ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`05o`00
0?nj^[[ooooooiRHV?l@41003?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00;o
oooo00Go410@oooooooooooo0000oc8b<P0<ooooo`03o`000?oooooooooo02Kooooo000Qooooo`03
o`000?oooooooooo01Sooooo00Oo0000oooooonHV9So410@o`000?lQ8B7oc<c<00cooooo1?l0000G
ooooo`04o`000?ooooooooooooooo`Co00006oooool5o`0000cooooo1?l0000Gooooo`03oeEEEOmV
IVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo00Wooooo
00?oEEEEofIVI_l000001?ooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo1?l0000<ooooo`03
o`000?oooooooooo00Cooooo00?oEEEEofIVI_l000001Oooool4o`0001?ooooo00?oEEEEofIVI_l0
00001?ooool5o`0000cooooo1?l0000Uooooo`008Oooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo02cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0]ooooo`03o`00
0?oooooooooo033ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0dooooo`008Ooo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0<?oo
ool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0;Ooo
ool00ol0003oooooooooo`0dooooo`008Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo02gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooo
oooo033ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Zooooo`;o00000_ooool2
o`0000Cooooo000Qooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0;Oooool00ol0
003oooooooooo`0_ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0;oooool00ol0
003oooooooooo`0^ooooo`03o`000?oooooooooo02[ooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oM
gMd4ooooo`006_ooooooo`0003[o00003?ooool01?oMgMgo0000oa0@4?o<c<`5ooooo`008Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooo`000005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool0
1?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`04ooooo`;o00001oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00oo
oooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo0_l00006ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooool000001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Go0000
ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00oooooo00Co8B4QogMgMomgMgOo<S8b
1Oooool0027ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0_ooooo`03o`000?oo
oooooooo02kooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0^ooooo`03o`000?oo
oooooooo02oooooo00?o0000ooooooooool0:Oooool2o`0000;ooooo0_l00004ooooo`008Oooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0;_ooool0
0ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0;oooool0
0ol0003oooooooooo`0cooooo`008Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
02oooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo
02gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0cooooo`008Oooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0;Oooool00ol0003o
ooooooooo`0`ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0<Oooool00ol0003o
ooooooooo`0booooo`008Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo02cooooo
00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0booooo`008Oooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0;?ooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0<Oooool00ol0003ooooooooo
o`0booooo`008Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool0;?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo02cooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`0booooo`008Oooool3o`0001Gooooo00?o0000oooo
ooooool0<Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo03;ooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo03;ooooo000Qooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo03;ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0cooooo`03
o`000?oooooooooo037ooooo000Qooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
<_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0
:oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo037ooooo000Qooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo03?ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0cooooo`03o`000?oo
oooooooo037ooooo000Qooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0<oooool0
0ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`0cooooo`03o`000?oooooooooo037ooooo000Qooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
03Cooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo
037ooooo000Qooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0<oooool00ol0003o
ooooooooo`0Yooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0:_ooool00ol0003o
ooooooooo`0dooooo`03o`000?oooooooooo033ooooo000Qooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo03Cooooo
00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo033ooooo
000Qooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0=Oooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo033ooooo000Qooooo`?o00004oooool00ol0003oooooooooo`0e
ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0<?ooool0027ooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02Oooooo00?o0000oooo
ooooool0=_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo03Gooooo00?o0000oooo
ooooool0<?ooool0027ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0eooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Xooooo`03
o`000?oooooooooo03Kooooo00?o0000ooooooooool0;oooool0027ooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
=_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0
;oooool0027ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0fooooo`03o`000?oo
oooooooo02Oooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo03Oooooo00?o0000ooooooooool0;oooool0027ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0gooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0=oooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0;oooool0
027ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
03Oooooo00?o0000ooooooooool0;oooool0027ooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0gooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?ooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0;_ooool0027ooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo03Sooooo
00?o0000ooooooooool0;_ooool0027ooooo0ol0000Aooooo`03o`000?oooooooooo03Sooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool0>?ooool00ol0003oooooooooo`0^ooooo`008Oooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0i
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0^
ooooo`008Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo03Wooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool0>Oooool00ol0003oooooooooo`0^ooooo`008Oooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo03Wooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0jooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0]ooooo`00
8Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
>_ooool00ol0003oooooooooo`0]ooooo`008Oooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo03[ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0jooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0]ooooo`008Oooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool08_ooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`0]ooooo`008Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0]ooooo`008Oooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`0looooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0??ooool00ol0003o
ooooooooo`0/ooooo`008Oooool3o`0000oooooo00?o0000ooooooooool0??ooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool08_ooool00ol0003ooooo
ooooo`0looooo`03o`000?oooooooooo02cooooo000Qooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0??ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03cooooo00?o
0000ooooooooool08_ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo02cooooo000Q
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0l
ooooo`03o`000?oooooooooo02cooooo000Qooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0?Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03gooooo00?o0000oooo
ooooool08?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo02cooooo000Qooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Oooooo`03
o`000?oooooooooo03kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0mooooo`03
o`000?oooooooooo02cooooo000Qooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
?_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0
8?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo02_ooooo000Qooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo03kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0nooooo`03o`000?oo
oooooooo02_ooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00Go
A4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
?_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0
7oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo02_ooooo0007ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`0oooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0?oooool00ol0003ooooo
ooooo`0[ooooo`001oooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool0
0_ooool3o`0000kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo03oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0oooooo`03o`00
0?oooooooooo02_ooooo0007ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8b
ooooo`03ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0@?ooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`10ooooo`03o`000?oooooooooo02[ooooo0007ooooo`05o`000?ooooooooooooooool00000
3?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`10ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0@?ooool00ol0003o
ooooooooo`0Nooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0:_ooool000Oooooo
00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool0@Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo047ooooo00?o0000oooooooo
ool0:_ooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo047o
oooo00?o0000ooooooooool0:_ooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co
00001Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo04;ooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool0@Oooool00ol0003oooooooooo`0Zooooo`008Oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo04;ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`12ooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0Yooooo`008Ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0@ooo
ool00ol0003oooooooooo`0Yooooo`008Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo04;ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`13ooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Yooooo`008Oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`13ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0@oooool00ol0
003oooooooooo`0Yooooo`008Oooool3o`0000_ooooo00?o0000ooooooooool0A?ooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`13ooooo`03o`000?oooooooooo02Wooooo000Qooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04Cooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo02Wooooo
000Qooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0A?ooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`15ooooo`03o`000?oooooooooo02Sooooo000Qooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool0A?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04Gooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo02Sooooo000Qoooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo04Gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`15oooo
o`03o`000?oooooooooo02Sooooo000Qooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool0A_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04Gooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo02Sooooo000Qooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo04Kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`16ooooo`03o`00
0?oooooooooo02Sooooo000Qooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0A_oo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo02Oooooo000Qooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo04Oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`17ooooo`03o`000?oooooo
oooo02Oooooo000Qooooo`?o00002_ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
04Oooooo00?o0000ooooooooool09oooool0027ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`18ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0Aoooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool09oooool0027ooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04Sooooo
00?o0000ooooooooool09oooool0027ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`19ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0BOooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool09_ooool0027ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0BOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04Wooooo00?o0000
ooooooooool09_ooool0027ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1:oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo04Wooooo00?o0000ooooooooool09_ooool0027ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool0Boooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo04_ooooo00?o0000oooooooo
ool09Oooool0027ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1;ooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo04_ooooo00?o0000ooooooooool09Oooool0027ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0Booo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool09Ooo
ool0027ooooo0ol00007ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`1<ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0C?ooool0
0ol0003oooooooooo`0Uooooo`008Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
04gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0Tooooo`008Oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`1=ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0COooool00ol0003o
ooooooooo`0Tooooo`008Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04oooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool0COooool00ol0003oooooooooo`0Tooooo`008Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`1?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0Coooool00ol0003ooooooooo
o`0Sooooo`008Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04oooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool0Coooool00ol0003oooooooooo`0Sooooo`008Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo057ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1@oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0Soooo
o`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo057ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool0D?ooool00ol0003oooooooooo`0Rooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo057ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Aooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`0Rooooo`008Ooo
ool3o`0000Cooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo05;ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Aooooo`03o`000?oo
oooooooo02;ooooo000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Doooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`1Booooo`03o`000?oooooooooo027ooooo000Qooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
05?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo
027ooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0EOooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`1Cooooo`03o`000?oooooooooo027ooooo000Qooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0EOooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo05Gooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo023ooooo
000Qooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0E_ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`1Fooooo`03o`000?oooooooooo01oooooo000Qooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0Eoooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05Oooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo01oooooo000Hoooo
o`Co000000?o410@ooooooooool00_ooool01Ol0003ooooooooooooooooo000005_ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0FOooool00ol0003oooooooooo`0Nooooo`006_ooool00ol0003oooooooooo`04oooo
o`04o`000?ooooooooooo`0005gooooo00?o0000ooooooooool00_ooool2o`0005cooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo01gooooo000Joooo
o`03o`000?oooooooooo00Cooooo1?l0001Nooooo`Go0000G_ooool5o`0005kooooo0ol0000Loooo
o`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001Sooooo00?oEEEEofIVI_l000001_ooool00ol0
003oooooooooo`3oooooodGooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo002Looooo`;o0000?oooool2o`0008Wooooo
002Looooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0Qoooool008Wooooo0ol00002
ooooo`06oc8b<_l@413oooooooooooo^k^koEEEE0_l000000om4A4Co^[Zjooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00Kok^k^ofIVI_l0003o0000oc8b<_nj^[Xgooooo`03o`000?oooooooooo
08Oooooo002:ooooo`05o`000?ooooooooooolc<c?l@41000oooool01_mEEEGoMgMgooooooo^k^ko
MgMgoa0@40Cooooo00?o0000ooooooooool00_ooool2ogMgM`04oeEEEOn7QhOogMgModA4A3Oooooo
00?o0000ooooooooool0Qoooool008[ooooo00Go0000ooooooooooooEEEEohN7Q`03ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool00_ooool00onHV9Soooooo`00000jooooo`03o`00
0?oooooooooo08Oooooo002:ooooo`05o`000?oooooogMgMo`000?o^k^h00oooool6o`0000Cooooo
00?o0000ooooooooool00_ooool00onHV9Soooooo`000003o`0001;ooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo08Oooooo002:ooooo`?o000000?o
410@oiRHV?ooool00_ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<PCooooo00?o0000oooooooo
ool00_ooool00omgMgOoQhN7ofIVIP02okZj^P03oc8b<_oooooooooo00oooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo08Oooooo002:ooooo`05o`00
0?ooooooooooolc<c?l000000oooool01_o^k^koEEEEo`000?l0003oA4A4onk^kPCooooo00?o0000
ooooooooool00oooool01_mVIVKo0000o`000?m4A4Cok^k^ooooo`?o00001?ooool2o`000003oooo
ool0003o000000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooo`00000:ooooo`?o0000
1_ooool2o`0000Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`27ooooo`00R_oo
ool01Ol0003oooooooooooo<c<co000000gooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooo000000Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo08Oooooo0029ooooo`Co000000?o410@ojVYZOooool03?oo
ool2o`0000_ooooo00?o0000ooooooooool01?ooool2o`0000Gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`02ooooo`Co00000_ooool01?l0003oooooooooool00005ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool2o`0008Wooooo002Yooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooool000001?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooo000000[ooooo0ol00004ooooo`Co00001?ooool00ol0003oooooooooo`2=ooooo`00Z?ooool2
o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0S_ooool00:oooooo0_l00008ooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool0Soooool00:Wooooo00?o0000ooooooooool0_?ooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-2, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0505254 0.309017 0.294302 [
[.15012 .29652 -9 -9 ]
[.15012 .29652 9 0 ]
[.27644 .29652 -3 -9 ]
[.27644 .29652 3 0 ]
[.40275 .29652 -9 -9 ]
[.40275 .29652 9 0 ]
[.52906 .29652 -6 -9 ]
[.52906 .29652 6 0 ]
[.65538 .29652 -12 -9 ]
[.65538 .29652 12 0 ]
[.78169 .29652 -6 -9 ]
[.78169 .29652 6 0 ]
[.908 .29652 -12 -9 ]
[.908 .29652 12 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .01472 -12 -4.5 ]
[.01131 .01472 0 4.5 ]
[.01131 .16187 -24 -4.5 ]
[.01131 .16187 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[.5 .63053 -37.9062 0 ]
[.5 .63053 37.9062 12.625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15012 .30902 m
.15012 .31527 L
s
[(2.5)] .15012 .29652 0 1 Mshowa
.27644 .30902 m
.27644 .31527 L
s
[(5)] .27644 .29652 0 1 Mshowa
.40275 .30902 m
.40275 .31527 L
s
[(7.5)] .40275 .29652 0 1 Mshowa
.52906 .30902 m
.52906 .31527 L
s
[(10)] .52906 .29652 0 1 Mshowa
.65538 .30902 m
.65538 .31527 L
s
[(12.5)] .65538 .29652 0 1 Mshowa
.78169 .30902 m
.78169 .31527 L
s
[(15)] .78169 .29652 0 1 Mshowa
.908 .30902 m
.908 .31527 L
s
[(17.5)] .908 .29652 0 1 Mshowa
.125 Mabswid
.04907 .30902 m
.04907 .31277 L
s
.07433 .30902 m
.07433 .31277 L
s
.0996 .30902 m
.0996 .31277 L
s
.12486 .30902 m
.12486 .31277 L
s
.17539 .30902 m
.17539 .31277 L
s
.20065 .30902 m
.20065 .31277 L
s
.22591 .30902 m
.22591 .31277 L
s
.25117 .30902 m
.25117 .31277 L
s
.3017 .30902 m
.3017 .31277 L
s
.32696 .30902 m
.32696 .31277 L
s
.35222 .30902 m
.35222 .31277 L
s
.37749 .30902 m
.37749 .31277 L
s
.42801 .30902 m
.42801 .31277 L
s
.45328 .30902 m
.45328 .31277 L
s
.47854 .30902 m
.47854 .31277 L
s
.5038 .30902 m
.5038 .31277 L
s
.55433 .30902 m
.55433 .31277 L
s
.57959 .30902 m
.57959 .31277 L
s
.60485 .30902 m
.60485 .31277 L
s
.63011 .30902 m
.63011 .31277 L
s
.68064 .30902 m
.68064 .31277 L
s
.7059 .30902 m
.7059 .31277 L
s
.73116 .30902 m
.73116 .31277 L
s
.75643 .30902 m
.75643 .31277 L
s
.80695 .30902 m
.80695 .31277 L
s
.83222 .30902 m
.83222 .31277 L
s
.85748 .30902 m
.85748 .31277 L
s
.88274 .30902 m
.88274 .31277 L
s
.93327 .30902 m
.93327 .31277 L
s
.95853 .30902 m
.95853 .31277 L
s
.98379 .30902 m
.98379 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01472 m
.03006 .01472 L
s
[(-1)] .01131 .01472 1 0 Mshowa
.02381 .16187 m
.03006 .16187 L
s
[(-0.5)] .01131 .16187 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(0.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .13244 m
.02756 .13244 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -98.9062 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.625 moveto
(@) show
81.000 13.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\343) show
87.000 9.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344) show
93.000 9.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
97.188 9.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
( ) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
99.000 9.625 moveto
(H) show
103.188 9.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
107.375 9.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
113.375 9.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
119.375 9.625 moveto
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
123.562 9.625 moveto
(L) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
128.812 13.625 moveto
(D) show
134.812 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .54711 m
.02846 .56199 L
.03279 .57394 L
.03793 .5856 L
.04262 .59372 L
.04498 .59689 L
.04754 .59963 L
.04872 .60063 L
.04996 .60152 L
.05113 .60219 L
.0522 .60267 L
.05341 .60305 L
.05471 .60328 L
.05592 .60331 L
.05707 .60319 L
.05772 .60305 L
.05841 .60285 L
.05964 .60236 L
.06111 .60154 L
.06244 .60059 L
.06508 .5981 L
.06787 .59462 L
.07287 .58621 L
.07824 .57415 L
.08414 .55746 L
.10458 .47532 L
.145 .25067 L
.16364 .15059 L
.17347 .10563 L
.18391 .06631 L
.18916 .05037 L
.19495 .03601 L
.19748 .03085 L
.20021 .02606 L
.20277 .02233 L
.20515 .01951 L
.20759 .01729 L
.20889 .01639 L
.21027 .01565 L
.21096 .01535 L
.21172 .0151 L
.21243 .01491 L
.21309 .0148 L
.21433 .01472 L
.21565 .01482 L
.21679 .01508 L
.21802 .01552 L
.21917 .01609 L
.22023 .01675 L
.22282 .0189 L
Mistroke
.22527 .02165 L
.23032 .02941 L
.23489 .03884 L
.24512 .06784 L
.2546 .10353 L
.26352 .14372 L
.30212 .35813 L
.32171 .46417 L
.33208 .51188 L
.34318 .55347 L
.34868 .56984 L
.35389 .58248 L
.35856 .59136 L
.36098 .595 L
.36364 .59827 L
.36612 .60058 L
.36726 .60141 L
.36845 .60212 L
.36973 .6027 L
.37091 .60306 L
.37217 .60328 L
.37289 .60332 L
.37355 .6033 L
.37475 .60315 L
.37588 .60285 L
.37689 .60245 L
.37799 .6019 L
.38045 .60014 L
.38272 .59791 L
.38741 .59146 L
.39244 .58185 L
.40152 .55772 L
.41232 .51868 L
.42217 .47468 L
.46199 .25341 L
.48018 .15513 L
.49054 .10726 L
.50028 .06996 L
.50978 .04209 L
.51513 .03049 L
.51767 .02607 L
.52003 .02259 L
.52259 .01953 L
.52491 .0174 L
.52624 .01646 L
.5275 .01576 L
.52882 .01521 L
.52957 .01499 L
.53026 .01484 L
.53154 .01472 L
Mistroke
.53275 .01477 L
.53407 .01503 L
.53481 .01526 L
.53549 .01552 L
.53685 .01621 L
.53833 .01721 L
.54103 .01967 L
.54359 .02276 L
.54635 .02693 L
.55136 .03661 L
.56072 .06179 L
.57165 .10182 L
.5817 .1472 L
.62121 .36742 L
.64108 .47354 L
.64976 .51282 L
.6592 .5487 L
.66441 .56501 L
.66923 .57767 L
.67412 .58804 L
.67872 .59539 L
.68104 .59821 L
.68355 .60056 L
.6849 .60153 L
.68632 .60233 L
.68754 .60282 L
.68823 .60303 L
.68887 .60317 L
.68954 .60327 L
.69027 .60332 L
.69096 .60331 L
.6916 .60325 L
.6928 .60301 L
.69408 .60257 L
.69474 .60227 L
.69545 .6019 L
.69673 .60107 L
.69964 .59849 L
.70219 .59544 L
.7049 .5914 L
.70978 .5821 L
.71558 .56773 L
.72083 .55179 L
.74094 .46834 L
.78108 .24411 L
.79951 .14598 L
.80996 .09913 L
.8197 .06349 L
.82936 .03714 L
.83477 .02665 L
Mistroke
.83716 .02304 L
.83969 .01992 L
.84098 .01861 L
.84239 .01739 L
.84369 .01646 L
.84489 .01579 L
.84556 .01548 L
.84629 .01521 L
.84706 .01498 L
.8478 .01483 L
.84848 .01475 L
.84921 .01472 L
.85053 .01482 L
.85122 .01495 L
.85186 .01512 L
.85256 .01536 L
.85329 .01568 L
.85454 .01635 L
.8559 .01729 L
.85842 .0196 L
.86077 .0224 L
.86578 .0304 L
.87122 .04221 L
.88112 .07149 L
.89075 .10873 L
.89967 .14971 L
.93892 .3689 L
.97619 .54711 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  FontSlant->"Italic",
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool001So
oooo1?l000000ol@413oooooooooo`02ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000?ooooo`Ko00001Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000
ooooooooool01?ooool3o`0003Oooooo1Ol0001Nooooo`Go0000G_ooool5o`0004;ooooo000Joooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo05[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Joooo
o`;o00001?ooool00ol0003oooooooooo`0oooooo`006_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo03Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Iooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo03kooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
=?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
?_ooool001Sooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`0dooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo05Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0mooooo`008Oooool0
0ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0E_ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0mooooo`008Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
05Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0looooo`008Oooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0E?ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0looooo`008Oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0Doooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05?ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0kooooo`008Oooool3o`0003;ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0D_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03_ooooo000Q
ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1A
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo03[ooooo000Qooooo`03o`000?oooooooooo037ooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool0DOooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03[ooooo000Qooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1@ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo03[ooooo000Qooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
D?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03Wooooo000Qooooo`03o`000?oo
oooooooo033ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1>ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo03Wooooo000Qooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0C_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03Wooooo000Qooooo`03o`000?oooooooooo
02oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
03Sooooo000Qooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`1<ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0COooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo03Sooooo000Qooooo`?o0000;oooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`1<ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0>?ooool0027ooooo00?o
0000ooooooooool0;_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo04cooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool0>?ooool0027ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1<
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0=oooool0027ooooo00?o0000oooo
ooooool0;_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04[ooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool0=oooool0027ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo04[ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1:ooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool0=oooool0027ooooo00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
=oooool0027ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo04Wooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1:ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool0=_ooool0027ooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`19ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0=_ooool0
027ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
04Sooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool0=_ooool0027ooooo0ol0000/ooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04So
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0fooooo`008Oooool00ol0003ooooo
ooooo`0/ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0Aoooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`0eooooo`008Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool0Aoooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Oooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`0eooooo`008Oooool00ol0003oooooooooo`0/
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0e
ooooo`008Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool0AOooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04Kooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`0eooooo`008Oooool00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0dooooo`00
8Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
AOooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`0dooooo`008Oooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo04Cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0dooooo`008Oooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0A?ooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0dooooo`008Oooool3o`0002[ooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`13ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0A?ooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo03?ooooo000Qooooo`03o`000?oooooooooo02[o
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo03?o
oooo000Qooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`13ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0@oooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo03?ooooo000Qooooo`03o`000?oooooooooo02[ooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool0@_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo03?ooooo000Q
ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`12
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo03?ooooo000Qooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool0@Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo03;ooooo000Qooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`11ooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo03;ooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Go
oooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool0@Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo03;ooooo0007ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0@?ooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`0booooo`001Ol00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`10ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0?oooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo03;ooooo0007ooooo`05o`000?oooooooooooooo
ool000003oooool00omgMgOo<S8booooo`03ooooo`?o0000:?ooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo043ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0ooooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool0<Oooool000Oooooo00Go0000oooooooo
ooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0a
ooooo`001oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0?oooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`0aooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool0?_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03kooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`0aooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00cooooo1?l00005ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`0nooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0?_ooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo037ooooo000Qooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo
023ooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
033ooooo000Qooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`0mooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0?Oooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo033ooooo000Qooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo033ooooo
000Qooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool08?ooool00ol0003ooooooooo
o`0mooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0??ooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo033ooooo000Qooooo`?o00009oooool00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0l
ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0<?ooool0027ooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03cooooo00?o0000oooo
ooooool08_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool0<?ooool0027ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Rooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool0;oooool0027ooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0
;oooool0027ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Rooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0jooooo`03o`000?oo
oooooooo02?ooooo00?o0000ooooooooool0;oooool0027ooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0jooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0;oooool0
027ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
03[ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo
02?ooooo00?o0000ooooooooool0;oooool0027ooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0Tooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0iooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0;oooool0027ooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo03Wooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool0;_ooool0027ooooo0ol0000Uooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0^ooooo`008Oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0^
ooooo`008Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool0>?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0^ooooo`008Oooool00ol0003oooooooooo`0Tooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo03Sooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0^ooooo`00
8Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
=oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`0]ooooo`008Oooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0]ooooo`008Oooool0
0ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0=oooool0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool09oooool0
0ol0003oooooooooo`0]ooooo`008Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
03Kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0]ooooo`008Oooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0=Oooool00ol0003o
ooooooooo`0Xooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool09oooool00ol0003o
ooooooooo`0]ooooo`008Oooool3o`0002?ooooo00?o0000ooooooooool0:?ooool00ol0003ooooo
ooooo`0eooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0=_ooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo02gooooo000Qooooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool0:?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02Wooooo00?o
0000ooooooooool0=Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02cooooo000Q
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0e
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Y
ooooo`03o`000?oooooooooo02cooooo000Qooooo`03o`000?oooooooooo02?ooooo00?o0000oooo
ooooool0:?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool0=?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02cooooo000Qooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0dooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo02cooooo000Qooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0
:_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0
=?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02cooooo000Qooooo`03o`000?oo
oooooooo01[ooooo1Ol00003ooooo`04o`000?oooooo8B4Qob4Q8@Gooooo00GoA4A4o`000?l0003o
<S8bomgMg@0Jooooo`06odA4A?l0003o0000oc8b<_oMgMgo00006oooool00ol0003ok^k^ooooo`05
ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Kooooo00?o0000ooooooooool03Ooo
ool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hBooooo`03o`000?oooooo0000
00?o000000?o410@ooooooooool01Ol00005ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM01;ooooo1?l000001Ol@413o0000ooooooooooooA4A400;o000000?o<S8bomgMgOooool04Ooo
ool4o`000003oa0@4?oooooooooo00;ooooo00?o0000onk^k_ooool01Oooool00olQ8B7o0000oooo
o`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd09?ooool0027ooooo00?o0000ooooooooool06_oo
ool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00Co0000oooooolQ8B7o8B4Q2?ooool00omgMgOo
<S8booooo`0Looooo`03ogMgMolb<S;o000001_ooooo00?oEEEEojVYZOooool01Oooool2ob4Q8@So
oooo00?oMgMgoc8b<_ooool01Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Booooo`05o`000?ooooooooooooooool000001?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo01?ooooo00?o
0000ooooool000001_ooool00omgMgOo<S8booooo`0Cooooo`03o`000?oooooooooo00Cooooo00?o
EEEEojVYZOooool01Oooool2ob4Q8@03o`000?oooooooooo00Gooooo00?oMgMgoc8b<_ooool08ooo
ool0027ooooo00?o0000ooooooooool06oooool00onHV9So8B4Qonk^kP04ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool07?ooool2o`0001_ooooo00?oZJVYoeEEEOooool04?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@01;ooooo00Go0000ooooooooooooooooo`000005ooooo`03oiRH
V?lQ8B7ok^k^017ooooo00?o0000ooooooooool04_ooool00ol0003oooooo`000007ooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool01?ooool00onYZJWoEEEEooooo`07ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool08_ooool0027ooooo0ol0000Looooo`03oiRHV?lQ
8B7ok^k^00?ooooo00?o0000ooooooooool02Oooool00omgMgOo<S8booooo`0Looooo`03ogMgMolb
<S;o000001cooooo00?o8B4Qooooooooool03_ooool00omgMgOo<S8booooo`05ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000001;ooooo
00Go0000ooooooooooooooooo`000006ooooo`03oiRHV?lQ8B7ok^k^00oooooo00?oMgMgoc8b<_oo
ool04oooool00ol0003oooooo`000006ooooo`03ogMgMolb<S;ooooo01?ooooo00?o0000oooooooo
ool01Oooool00olQ8B7oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?oMgMgoc8b<_oo
ool08oooool0027ooooo00?o0000ooooooooool07Oooool01OmgMgOoIVIVoooooooooooo000000Wo
oooo00Go0000ob4Q8Ol0003o<S8bolc<c00Jooooo`07o`000?lQ8B7o0000oc8b<_o<c<coooooo`00
000Kooooo`03oeEEEOo<c<cooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c006ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000001;o
oooo00Go0000ooooooooooooooooo`000007ooooo`03ogMgMomVIVKooooo00_ooooo00Go0000ob4Q
8Ol0003o<S8bolc<c00Dooooo`03o`000?oooooo000000?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c00Dooooo`03o`000?oooooooooo00Gooooo00?oEEEEolc<c?ooool01_ooool00ol0003ooooooooo
o`02ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`09?ooool0027ooooo00?o0000ooooooooool07_oo
ool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Iooooo`03ojVYZOmgMgOooooo00_ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@400Booooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooool000000oooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo00Gooooo00?oZJVYogMgMoooool01_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo02Kooooo000Qooooo`03o`000?oooooooooo01[ooooo00Go0000okZj^_oo
ooooV9RHoa0@4002ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo01Kooooo00Go410@oooooooooooooooooc8b<P0<
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool01?l0003oooooooooool00004ooooo`05o`00
0?nj^[[ooooooiRHV?l@41003?ooool00ol0003oooooooooo`0Fooooo`;o00001?ooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooc8b<P08oooo
o`05o`000?ooooooooooooooool00000:?ooool0027ooooo00?o0000ooooooooool06_ooool01OnH
V9So410@o`000?lQ8B7oc<c<00;ooooo00?o0000ooooooooool01oooool4o`0001_ooooo1?l00002
ooooo`03o`000?oooooooooo01Kooooo1Ol0000<ooooo`Co00001_ooool00ol0003oooooooooo`0>
ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Cooooo`04o`000?mE
EEGoIVIVo`0000Cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00<ooooo`Co00004oooool01?mEEEGo
IVIVo`000?l00004ooooo`Co00004oooool00omEEEGoIVIVo`000004ooooo`Go00002?ooool01?l0
003oooooooooooooool4o`0002Gooooo000Qooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo02gooooo00?o0000oooo
ooooool0<?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02[ooooo000Qooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0`ooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0]ooooo`03
o`000?oooooooooo02[ooooo000Qooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
;_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo023ooooo0_l00002ooooo`;o0000
1?ooool0027ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0^ooooo`03o`000?oo
oooooooo02oooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0`ooooo`03o`000?oo
oooooooo02gooooo00?o0000ooooooooool08?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@Co
oooo000Joooooooo0000>_l0000<ooooo`04omgMgOl0003o410@olc<c0Gooooo000Qooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00007oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooo`000005oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo0_l00007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03oooool0
1?o^k^ko8B4Qoa0@4?o^k^h5ooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`;o00001oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00oooooo00Co8B4QogMgMomgMgOo<S8b1Oooool0027o
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02ko
oooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02oo
oooo00?o0000ooooooooool07oooool2o`0000;ooooo0_l00004ooooo`008Oooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0;Oooool00ol0003ooooo
ooooo`0`ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0;oooool00ol0003ooooo
ooooo`0Yooooo`008Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo033ooooo00?o
0000ooooooooool0;Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02gooooo00?o
0000ooooooooool0<?ooool00ol0003oooooooooo`0Yooooo`008Oooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0a
ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0X
ooooo`008Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo033ooooo00?o0000oooo
ooooool0;Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo02cooooo00?o0000oooo
ooooool0<Oooool00ol0003oooooooooo`0Xooooo`008Oooool00ol0003oooooooooo`0Oooooo`03
o`000?oooooooooo033ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0aooooo`03
o`000?oooooooooo02cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Xooooo`00
8Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0
;?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0
<Oooool00ol0003oooooooooo`0Xooooo`008Oooool3o`0001kooooo00?o0000ooooooooool0<_oo
ool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0;?oo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo02Sooooo000Qooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooo
oooo03?ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooo
oooo02Oooooo000Qooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0<_ooool00ol0
003oooooooooo`0[ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0:_ooool00ol0
003oooooooooo`0cooooo`03o`000?oooooooooo02Oooooo000Qooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo03?o
oooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02Oo
oooo000Qooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0<oooool00ol0003ooooo
ooooo`0Zooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0:_ooool00ol0003ooooo
ooooo`0cooooo`03o`000?oooooooooo02Oooooo000Qooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool0=?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03?ooooo00?o
0000ooooooooool0:_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02Oooooo000Q
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Y
ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0d
ooooo`03o`000?oooooooooo02Oooooo000Qooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool0=?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo03Gooooo00?o0000oooo
ooooool0:?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02Kooooo000Qooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo03Gooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0eooooo`03
o`000?oooooooooo02Kooooo000Qooooo`?o00007Oooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo02Wooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Xooooo`03o`00
0?oooooooooo03Gooooo00?o0000ooooooooool09_ooool0027ooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0=Ooo
ool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool09_oo
ool0027ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooo
oooo02Oooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo03Kooooo00?o0000ooooooooool09_ooool0027ooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`0fooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool09Oooool0027o
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo03Oo
oooo00?o0000ooooooooool09Oooool0027ooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0fooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0=oooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool09Oooool0027ooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool0=oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo03Oooooo00?o
0000ooooooooool09Oooool0027ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0g
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool09Oooool0027ooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0>?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Wooooo00?o0000oooo
ooooool09?ooool0027ooooo0ol0000Kooooo`03o`000?oooooooooo03Sooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool0>Oooool00ol0003oooooooooo`0Tooooo`008Oooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo03Sooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0iooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Tooooo`008Ooo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0>Ooo
ool00ol0003oooooooooo`0Tooooo`008Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo03Wooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Tooooo`008Oooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`0iooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`0Sooooo`008Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo03[o
oooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo02?o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Sooooo`008Oooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool08oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`0Sooooo`008Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo03[ooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02;ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`0Sooooo`008Oooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0R
ooooo`008Oooool3o`0001[ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Roooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0loooo
o`03o`000?oooooooooo02;ooooo000Qooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool0??ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo02;ooooo000Qooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo03gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0mooooo`03o`00
0?oooooooooo02;ooooo000Qooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0??oo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool08?oo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo02;ooooo000Qooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo03gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooo
oooo027ooooo000Qooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0?Oooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`0nooooo`03o`000?oooooooooo027ooooo000Qooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03go
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo027o
oooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0
003o<S8bomgMg@04ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0?_ooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`0oooooo`03o`000?oooooooooo027ooooo0007ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo03kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0ooooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0Qoooo
o`001oooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00_ooool3o`00
01Sooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
03oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo
023ooooo0007ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`03oooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo03oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`10oooo
o`03o`000?oooooooooo023ooooo0007ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0o
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool08?ooool000Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`0oooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0?oooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool08?ooool0
00Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool0@Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo04;ooooo00?o0000
ooooooooool07oooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`11ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0@_ooool0
0ol0003oooooooooo`0Oooooo`008Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
047ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0Oooooo`008Oooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`11ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0@oooool00ol0003o
ooooooooo`0Oooooo`008Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo047ooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Oooooo`008Oooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`13ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0A?ooool00ol0003ooooooooo
o`0Nooooo`008Oooool3o`0001Kooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`14
ooooo`03o`000?oooooooooo01kooooo000Qooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool0@oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04?ooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01kooooo000Qooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo04?ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`15ooooo`03
o`000?oooooooooo01kooooo000Qooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
AOooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01kooooo000Qooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo04Gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`16ooooo`03o`000?oo
oooooooo01gooooo000Qooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0AOooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`16ooooo`03o`000?oooooooooo01gooooo000Qooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
04Gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo
01gooooo000Qooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0Aoooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`17ooooo`03o`000?oooooooooo01gooooo000Qooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Kooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo01cooooo
000Qooooo`?o00005?ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool0Aoooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Sooooo00?o
0000ooooooooool07?ooool0027ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`18
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool07?ooool0027ooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool0B?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04Wooooo00?o0000oooo
ooooool07?ooool0027ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`19ooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo04Wooooo00?o0000ooooooooool07?ooool0027ooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
BOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0
6oooool0027ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1:ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo04_ooooo00?o0000ooooooooool06oooool0027ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`1;ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0Boooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool06oooool0
027ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
04_ooooo00?o0000ooooooooool06oooool0027ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`1<ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0Boooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool06oooool0027ooooo
0ol0000Aooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`1=ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0C?ooool00ol0003ooooo
ooooo`0Jooooo`008Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04cooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool0COooool00ol0003oooooooooo`0Jooooo`008Oooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1=
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0J_ooool0027ooooo0_l0000Aoooo
o`03o`000?oooooooooo04kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1>oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0J_ooool0027ooooo0_l0000Aooooo`03
o`000?oooooooooo04kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1?ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool0Joooool0027ooooo00?o0000ooooool00000
4?ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
Coooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo06_ooooo000Qooooo`03o`000?oo
oooo000000oooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo04oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1[ooooo`008Oooool0
0ol0003oooooo`00000?ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`1@ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0K?ooool0
027ooooo00Co0000oooooooooooo00003_ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo06cooooo000Qooooo`Co00003Oooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
06cooooo000Qooooo`04o`000?ooooooooooo`0000gooooo00?o0000ooooooooool0D_ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`1]ooooo`008Oooool01Ol0003ooooooooooooooooo000000cooooo00?o0000oooo
ooooool0Doooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05?ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`1]ooooo`008Oooool01Ol0003ooooooooooooooooo0000
00_ooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
05?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1]ooooo`008Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0E?ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`1]ooooo`008Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0EOooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo05Gooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`1^ooooo`008Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Eoooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`1_ooooo`006?ooool4o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`1Iooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0L?ooool0
01[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
05_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1aooooo`006_ooool00ol0003o
ooooooooo`04ooooo`?o00001Oooool5o`0005kooooo1Ol0001Nooooo`Ko0000Loooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00W?ooool2o`0003oooooo0_l00029ooooo`00W?ooool0
0ol0003oooooooooo`0oooooo`03o`000?oooooooooo08Oooooo0029ooooo`?o00000_ooool01_lb
<S;o410@ooooooooooook^k^oeEEE@;o000000?oA4A4okZj^_ooool00oooool00ol0003ooooooooo
o`02ooooo`06onk^k_mVIVKo0000o`000?lb<S;o^[Zj=oooool00ol0003oooooooooo`27ooooo`00
R_ooool01Ol0003oooooooooooo<c<co410@00?ooooo00KoEEEEogMgMoooooook^k^ogMgMol@4104
ooooo`03o`000?oooooooooo00;ooooo0_mgMgL01?mEEEGoQhN7omgMgOm4A4@gooooo`03o`000?oo
oooooooo08Oooooo002:ooooo`05o`000?oooooooooooeEEEOn7QhL00oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00;ooooo00?oV9RHooooool00000>_ooool00ol0003ooooooooo
o`27ooooo`00R_ooool01Ol0003oooooomgMgOl0003ok^k^00?ooooo1_l00004ooooo`03o`000?oo
oooooooo00;ooooo00?oV9RHooooool000000ol0000Booooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`27ooooo`00R_ooool3o`000003oa0@4?nHV9So
oooo00;ooooo00KoEEEEohN7Qoo^k^koooooohN7Qolb<S84ooooo`03o`000?oooooooooo00;ooooo
00?oMgMgohN7QomVIVH00_nj^[X00olb<S;oooooooooo`0?ooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`27ooooo`00R_ooool01Ol0003ooooooooo
ooo<c<co000000?ooooo00Kok^k^oeEEEOl0003o0000odA4A?o^k^h4ooooo`03o`000?oooooooooo
00?ooooo00KoIVIVo`000?l0003oA4A4onk^k_ooool3o`0000Cooooo0_l000000ooooooo0000o`00
0003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000002_ooool3o`0000Kooooo0_l0
0004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Qoooool008[ooooo00Go0000
ooooooooooooc<c<o`00000=ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooo`000004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`27ooooo`00ROooool4o`000003oa0@4?nYZJWooooo00cooooo0_l0000;
ooooo`03o`000?oooooooooo00Cooooo0_l00005ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool4o`0000;ooooo00Co0000oooooooooooo00001Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo0_l00029ooooo`00ZOooool00ol0003oooooooooo`04
ooooo`03o`000?oooooo000000Cooooo00?o0000ooooooooool00_ooool00ol0003oooooo`00000:
ooooo`?o00001?ooool4o`0000Cooooo00?o0000ooooooooool0SOooool00:Sooooo0_l00006oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo08kooooo002_ooooo`;o00002?ooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo08oooooo002Yooooo`03o`000?oooooooooo0;cooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-2, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0505254 0.309016 0.294303 [
[.15012 .29652 -9 -9 ]
[.15012 .29652 9 0 ]
[.27644 .29652 -3 -9 ]
[.27644 .29652 3 0 ]
[.40275 .29652 -9 -9 ]
[.40275 .29652 9 0 ]
[.52906 .29652 -6 -9 ]
[.52906 .29652 6 0 ]
[.65538 .29652 -12 -9 ]
[.65538 .29652 12 0 ]
[.78169 .29652 -6 -9 ]
[.78169 .29652 6 0 ]
[.908 .29652 -12 -9 ]
[.908 .29652 12 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .01471 -12 -4.5 ]
[.01131 .01471 0 4.5 ]
[.01131 .16186 -24 -4.5 ]
[.01131 .16186 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[.5 .63053 -37.9062 0 ]
[.5 .63053 37.9062 12.625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15012 .30902 m
.15012 .31527 L
s
[(2.5)] .15012 .29652 0 1 Mshowa
.27644 .30902 m
.27644 .31527 L
s
[(5)] .27644 .29652 0 1 Mshowa
.40275 .30902 m
.40275 .31527 L
s
[(7.5)] .40275 .29652 0 1 Mshowa
.52906 .30902 m
.52906 .31527 L
s
[(10)] .52906 .29652 0 1 Mshowa
.65538 .30902 m
.65538 .31527 L
s
[(12.5)] .65538 .29652 0 1 Mshowa
.78169 .30902 m
.78169 .31527 L
s
[(15)] .78169 .29652 0 1 Mshowa
.908 .30902 m
.908 .31527 L
s
[(17.5)] .908 .29652 0 1 Mshowa
.125 Mabswid
.04907 .30902 m
.04907 .31277 L
s
.07433 .30902 m
.07433 .31277 L
s
.0996 .30902 m
.0996 .31277 L
s
.12486 .30902 m
.12486 .31277 L
s
.17539 .30902 m
.17539 .31277 L
s
.20065 .30902 m
.20065 .31277 L
s
.22591 .30902 m
.22591 .31277 L
s
.25117 .30902 m
.25117 .31277 L
s
.3017 .30902 m
.3017 .31277 L
s
.32696 .30902 m
.32696 .31277 L
s
.35222 .30902 m
.35222 .31277 L
s
.37749 .30902 m
.37749 .31277 L
s
.42801 .30902 m
.42801 .31277 L
s
.45328 .30902 m
.45328 .31277 L
s
.47854 .30902 m
.47854 .31277 L
s
.5038 .30902 m
.5038 .31277 L
s
.55433 .30902 m
.55433 .31277 L
s
.57959 .30902 m
.57959 .31277 L
s
.60485 .30902 m
.60485 .31277 L
s
.63011 .30902 m
.63011 .31277 L
s
.68064 .30902 m
.68064 .31277 L
s
.7059 .30902 m
.7059 .31277 L
s
.73116 .30902 m
.73116 .31277 L
s
.75643 .30902 m
.75643 .31277 L
s
.80695 .30902 m
.80695 .31277 L
s
.83222 .30902 m
.83222 .31277 L
s
.85748 .30902 m
.85748 .31277 L
s
.88274 .30902 m
.88274 .31277 L
s
.93327 .30902 m
.93327 .31277 L
s
.95853 .30902 m
.95853 .31277 L
s
.98379 .30902 m
.98379 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01471 m
.03006 .01471 L
s
[(-1)] .01131 .01471 1 0 Mshowa
.02381 .16186 m
.03006 .16186 L
s
[(-0.5)] .01131 .16186 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(0.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04414 m
.02756 .04414 L
s
.02381 .07357 m
.02756 .07357 L
s
.02381 .103 m
.02756 .103 L
s
.02381 .13243 m
.02756 .13243 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -98.9062 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.625 moveto
(@) show
81.000 13.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\343) show
87.000 9.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344) show
93.000 9.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
97.188 9.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
( ) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
99.000 9.625 moveto
(H) show
103.188 9.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
107.375 9.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
113.375 9.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
119.375 9.625 moveto
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
123.562 9.625 moveto
(L) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
128.812 13.625 moveto
(D) show
134.812 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .39996 m
.04262 .49553 L
.0522 .5351 L
.06244 .56842 L
.0679 .58188 L
.07286 .59137 L
.07525 .59498 L
.07784 .59817 L
.08029 .60049 L
.08147 .60136 L
.08255 .60202 L
.08382 .60262 L
.08452 .60287 L
.08518 .60306 L
.08636 .60327 L
.08764 .60331 L
.08838 .60325 L
.08905 .60314 L
.08982 .60295 L
.09055 .60271 L
.09184 .60213 L
.09325 .60128 L
.09612 .59885 L
.09915 .59527 L
.10458 .58628 L
.10954 .57528 L
.11406 .56301 L
.12422 .5282 L
.14255 .44421 L
.1824 .21886 L
.20062 .12581 L
.21099 .08271 L
.21607 .06497 L
.22073 .05086 L
.22527 .03921 L
.23024 .02897 L
.23524 .0214 L
.23797 .01846 L
.2405 .01648 L
.24181 .01574 L
.24251 .01543 L
.24324 .01516 L
.24388 .01498 L
.24458 .01483 L
.24582 .01472 L
.24703 .01477 L
.24832 .01502 L
.24954 .01542 L
.25066 .01595 L
.25204 .01679 L
Mistroke
.25332 .01777 L
.25622 .02068 L
.25878 .02404 L
.26151 .02841 L
.26688 .03942 L
.27182 .05222 L
.28296 .08989 L
.30314 .18354 L
.34268 .40775 L
.36258 .50659 L
.37127 .541 L
.38071 .57059 L
.38593 .58311 L
.39075 .59208 L
.39536 .59824 L
.39769 .60044 L
.39892 .60135 L
.40025 .60215 L
.40158 .60273 L
.4023 .60297 L
.40297 .60313 L
.40417 .6033 L
.40546 .60329 L
.40618 .6032 L
.40697 .60304 L
.40771 .60282 L
.40839 .60256 L
.40969 .60192 L
.41106 .60104 L
.41355 .59888 L
.41588 .59622 L
.42118 .58791 L
.42618 .57727 L
.43162 .56272 L
.44151 .52885 L
.46006 .44396 L
.50081 .2136 L
.52104 .11264 L
.53095 .07368 L
.53529 .05938 L
.54004 .04584 L
.54431 .03566 L
.54888 .02694 L
.5514 .0231 L
.5537 .02023 L
.55601 .01794 L
.55819 .01633 L
.55932 .01572 L
.56056 .01521 L
.56186 .01487 L
Mistroke
.56307 .01472 L
.5642 .01474 L
.56524 .01489 L
.56644 .01521 L
.56758 .01567 L
.5688 .01634 L
.5701 .01723 L
.57245 .01932 L
.57524 .02263 L
.57776 .02637 L
.58264 .0356 L
.5878 .04811 L
.59702 .07718 L
.61785 .16922 L
.65584 .38381 L
.677 .4931 L
.68702 .53473 L
.69628 .56538 L
.70084 .57735 L
.70586 .58803 L
.71092 .59598 L
.71368 .59913 L
.71492 .60025 L
.71628 .60129 L
.7174 .60198 L
.7186 .60256 L
.71986 .603 L
.72104 .60324 L
.72221 .60332 L
.72332 .60325 L
.72431 .60307 L
.72539 .60274 L
.72658 .60223 L
.72788 .60148 L
.7305 .59937 L
.73294 .59673 L
.73521 .59365 L
.7402 .58489 L
.74563 .5723 L
.75552 .54171 L
.77406 .46156 L
.81477 .23307 L
.83362 .13467 L
.84353 .09182 L
.85398 .05568 L
.85932 .04129 L
.86517 .02896 L
.86774 .02472 L
.87049 .02101 L
.87308 .01828 L
Mistroke
.87544 .01646 L
.8767 .01576 L
.87739 .01545 L
.87803 .01521 L
.87917 .0149 L
.88042 .01473 L
.88111 .01472 L
.88178 .01475 L
.88302 .01496 L
.88371 .01515 L
.88436 .01538 L
.88582 .01608 L
.8871 .01689 L
.88831 .01783 L
.89057 .02003 L
.893 .02304 L
.89563 .02704 L
.90054 .03656 L
.90513 .04777 L
.91556 .08109 L
.93662 .17599 L
.97552 .39622 L
.97619 .39996 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  FontSlant->"Italic",
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool001So
oooo1?l000000ol@413oooooooooo`02ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000?ooooo`Ko00001Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000
ooooooooool01?ooool3o`00047ooooo1Ol0001Nooooo`Go0000G_ooool5o`0003Sooooo000Joooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`02oooo
o`;o0000G?ooool2o`0000Cooooo00?o0000ooooooooool0Foooool01?l0003oooooooooooooool2
o`0003Oooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0?oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1Iooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0=?ooool001[o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05So
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0cooooo`006?ooool00omEEEGoIVIV
o`000006ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`1Fooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Eoooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo03?ooooo000Qooooo`03o`000?oooooooooo03kooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool0E_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03;ooooo000Q
ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1D
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo03;ooooo000Qooooo`03o`000?oooooooooo03cooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool0E?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03;ooooo000Qooooo`03
o`000?oooooooooo03cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Cooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo037ooooo000Qooooo`?o0000??ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo05;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Booooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool0<Oooool0027ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0<?oo
ool0027ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo053ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool0<?ooool0027ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`1@ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0<?ooool0027o
oooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo053o
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool0;oooool0027ooooo00?o0000ooooooooool0>_ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`1?ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0;oooool0027ooooo00?o
0000ooooooooool0>Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04kooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0;oooool0027ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1>
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0;_ooool0027ooooo00?o0000oooo
ooooool0>Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04gooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool0;_ooool0027ooooo0ol0000iooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool0C?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04cooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0^ooooo`008Oooool00ol0003oooooooooo`0hooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo04cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0]ooooo`008Ooo
ool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0C?oo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0]ooooo`008Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo04_ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0]ooooo`008Oooool00ol0
003oooooooooo`0hooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0B_ooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`0]ooooo`008Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04Wo
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0/ooooo`008Oooool00ol0003ooooo
ooooo`0gooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0B_ooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`0/ooooo`008Oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0BOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04Wooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`0/ooooo`008Oooool00ol0003oooooooooo`0g
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0/
ooooo`008Oooool3o`0003Oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`18oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo02cooooo000Qooooo`03o`000?oooooooooo03Kooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0Aoooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02_ooooo000Qooooo`03o`00
0?oooooooooo03Kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`17ooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo02_ooooo000Qooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0A_oo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02_ooooo000Qooooo`03o`000?oooooo
oooo03Kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`16ooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo02_ooooo000Qooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`16ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0AOooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo02_ooooo000Qooooo`03o`000?oooooooooo03Go
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02[o
oooo000Qooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`14ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0A?ooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo02[ooooo000Qooooo`03o`000?oooooooooo03Gooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool0A?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02[ooooo000Q
ooooo`?o0000=Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04Cooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool0:_ooool0027ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo04Cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`13oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0:_ooool0027ooooo00?o0000oooooooo
ool0=?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo04;ooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool0:Oooool0027ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo04;ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`12ooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool0:Oooool0027ooooo00?o0000ooooooooool0=?oo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0:Ooo
ool0027ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo04;ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`11ooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool0:Oooool0027ooooo00?o0000ooooooooool0<oooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`11ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0:Oooool000Oo
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM00Cooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo043ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`10ooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool0:?ooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo03?ooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool0@?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Sooooo0005o`00
00;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0<oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo043ooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool0:?ooool000Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;o
oooo00?ooooo0ol0000cooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0@?ooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`0Xooooo`001oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000
ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0?_oo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Sooooo0007ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03;ooooo00?o
0000ooooooooool07oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool0?_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02Oooooo0007
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo03;ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0nooooo`03o`000?oo
oooooooo01oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo02Oooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o
0000ooooooooool0<_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03kooooo00?o
0000ooooooooool07oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool09oooool0027ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0m
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool09oooool0027ooooo00?o0000oooo
ooooool0<Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03cooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool09oooool0027ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo03cooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0looooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool09oooool0027ooooo00?o0000ooooooooool0
<Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
9_ooool0027ooooo0ol0000aooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0??oo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`0Vooooo`008Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooo
oooo02;ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Vooooo`008Oooool00ol0
003oooooooooo`0`ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0>_ooool00ol0
003oooooooooo`0Sooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool08_ooool00ol0
003oooooooooo`0Vooooo`008Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02?o
oooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03[o
oooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Vooooo`008Oooool00ol0003ooooo
ooooo`0`ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0>_ooool00ol0003ooooo
ooooo`0Sooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool08oooool00ol0003ooooo
ooooo`0Uooooo`008Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool0>_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03[ooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`0Uooooo`008Oooool00ol0003oooooooooo`0`
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0U
ooooo`008Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0>?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo03Wooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`0Uooooo`008Oooool00ol0003oooooooooo`0_ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo03Sooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Uooooo`00
8Oooool3o`0002oooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo02Cooooo000Qooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02Cooooo000Qooooo`03o`000?oooooo
oooo02oooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0gooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo02Cooooo000Qooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`0gooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo02Cooooo000Qooooo`03o`000?oooooooooo02ko
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Co
oooo000Qooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`0fooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0=_ooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo02Cooooo000Qooooo`03o`000?oooooooooo02kooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool0=_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02?ooooo000Q
ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0f
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo02?ooooo000Qooooo`03o`000?oooooooooo02gooooo00?o0000oooo
ooooool0:?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool0=Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02?ooooo000Qooooo`?o
0000;Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo03Cooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02Sooooo00?o0000oooooooo
ool08oooool0027ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo03Cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo02Sooooo00?o0000ooooooooool08oooool0027ooooo00?o0000ooooooooool0;Ooo
ool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool08_oo
ool0027ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooo
oooo03Cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooo
oooo02Wooooo00?o0000ooooooooool08_ooool0027ooooo00?o0000ooooooooool0;Oooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`0dooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool08_ooool0027o
oooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03?o
oooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02[o
oooo00?o0000ooooooooool08_ooool0027ooooo00?o0000ooooooooool06_ooool5o`0000Gooooo
0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd06_ooool01Om4A4Co0000o`000?lb<S;ogMgM
00_ooooo00?o0000ooooooooool03_ooool00ol0003ok^k^ooooo`05ooooo`;o8B4Q1Oooool01Om4
A4Co0000o`000?lb<S;ogMgM013ooooo00?o0000ooooooooool00oooool4o`000008oa0@4?oooooo
ooooonk^k_lb<S;o0000oc8b<_o^k^hDooooo`Co000000?o410@ooooooooool01Ol00005ooooo`;o
8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01;ooooo1?l000001Ol@413ooooooooooooooooo
A4A400;o000000Co<S8bomgMgOoooooo00004?ooool4o`000003oa0@4?oooooooooo00;ooooo00?o
0000onk^k_ooool01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bo`00000Tooooo`008Ooo
ool00ol0003oooooooooo`0Jooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q8@Kooooo
00Co0000oooooomgMgOo<S8b7Oooool00omgMgOo<S8booooo`0:ooooo`03o`000?oooooooooo00ko
oooo00?oEEEEojVYZOooool01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool03oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Foooo
o`03o`000?oooooooooo00;ooooo00GoV9RHo`000?o^k^koooooodA4A005ooooo`;o8B4Q2?ooool0
0omgMgOo<S8booooo`0Cooooo`03o`000?oooooooooo00Kooooo00CoMgMgoc8b<_oooooo00004_oo
ool00ol0003oooooooooo`04ooooo`03oeEEEOnYZJWooooo00Gooooo0_lQ8B48ooooo`03ogMgMolb
<S;o000002?ooooo000Qooooo`03o`000?oooooooooo01_ooooo00?oV9RHob4Q8Oo^k^h03_ooool0
1?l0003oooooooooool0000Nooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03_oo
ool00onYZJWoEEEEooooo`0@ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41005_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?lQ8B7ok^k^017ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooo000001;ooooo00?o0000ooooooooool01?ooool00onYZJWoEEEE
ooooo`0@ooooo`;o00008oooool0027ooooo0ol0000Looooo`03oiRHV?lQ8B7ok^k^00gooooo00Co
0000oooooomgMgOo<S8b7Oooool00omgMgOo<S8booooo`0:ooooo`03o`000?oooooooooo00oooooo
00?o8B4Qooooooooool03_ooool00omgMgOo<S8booooo`0?ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000001Kooooo00?o0000oooooooo
ool00oooool01?l0003oV9RHob4Q8Oo^k^h?ooooo`03ogMgMolb<S;ooooo01?ooooo00?o0000oooo
ooooool01_ooool01?mgMgOo<S8booooool0000Booooo`03o`000?oooooooooo00Gooooo00?o8B4Q
ooooooooool03_ooool00omgMgOo<S8bo`00000Sooooo`008Oooool00ol0003oooooooooo`0Moooo
o`03ogMgMomVIVKooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Jooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`02oooool00ol0003oooooooooo`0?ooooo`03oeEEEOo<c<cooooo00_ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c00@ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0_ooool01Ol0003ooooooooooooooooo000001Kooooo00?o0000ooooooooool00oooool01?l0003o
ooooogMgMomVIVH<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`05?ooool00ol0003oooooooooo`03
ooooo`07o`000?lQ8B7o0000oc8b<_o<c<coooooo`00000Booooo`03o`000?oooooooooo00Gooooo
00?oEEEEolc<c?ooool02oooool01_l0003o8B4Qo`000?lb<S;oc<c<o`0002?ooooo000Qooooo`03
o`000?oooooooooo01kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03oooool00onYZJWoMgMgooooo`0;ooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`05
oa0@4?ooooooooooooooool@41005_ooool00ol0003oooooooooo`03ooooo`04o`000?oooooooooo
o`0000cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`05ooooo`03ojVYZOmgMgOo
oooo00_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Qooooo`008Oooool00ol0
003oooooooooo`0Jooooo`05o`000?nj^[[ooooooiRHV?l@41003?ooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02oooool01Ol@413ooooooooooooo
oooo<S8b00cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Fooooo`03o`000?oooooooooo00;ooooo
00Go0000okZj^_l0003oV9RHoa0@400<ooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool00_ooool01Ol@413ooooooooooooooooo<S8b00cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Pooooo`008Oooool00ol0003oooooooooo`0Jooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`03?ooool4o`0001_ooooo1?l0000=ooooo`03o`000?oooooooooo00_ooooo1Ol0000<oooo
o`Co00004?ooool00ol0003oooooooooo`04ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Dooooo`03oeEEEOmVIVKo000000Cooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00<ooooo`Co00004oooool00omEEEGoIVIVo`000005ooooo`Co000000?oooooo`000?ooool04?oo
ool00omEEEGoIVIVo`000004ooooo`Go00003?ooool4o`0000;ooooo00?o0000ooooooooool08?oo
ool0027ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooo
oooo033ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooo
oooo02gooooo00?o0000ooooooooool08?ooool0027ooooo00?o0000ooooooooool0:oooool00ol0
003oooooooooo`0]ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0;Oooool00ol0
003oooooooooo`0`ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool08?ooool0027o
oooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo033o
oooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02go
oooo00?o0000ooooooooool05_ooool2o`0000;ooooo0_l00004ooooo`008Oooool00ol0003ooooo
ooooo`0Zooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0;oooool00ol0003ooooo
ooooo`0^ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`0Fooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1?ooool001[oooooool0000jo`0000co
oooo00CogMgMo`000?l@413oc<c<1Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000001Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`;o00001_ooool00ol0003oooooooooo`0?ooooo`04onk^k_lQ8B7o410@onk^kPGooooo000Q
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooo`000007ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000ooooooooool0
3oooool01?lQ8B7oMgMgogMgMolb<S85ooooo`008Oooool00ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo033ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0_ooooo`03o`00
0?oooooooooo02kooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Eooooo`;o0000
0_ooool2o`0000Cooooo000Qooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0<?oo
ool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0;_oo
ool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01oooooo000Qooooo`03o`000?oooooo
oooo02Wooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooo
oooo037ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooo
oooo01kooooo000Qooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`0/ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0;?ooool00ol0
003oooooooooo`0aooooo`03o`000?oooooooooo01kooooo000Qooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo037o
oooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo01ko
oooo000Qooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0<_ooool00ol0003ooooo
ooooo`0/ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0;?ooool00ol0003ooooo
ooooo`0aooooo`03o`000?oooooooooo01kooooo000Qooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool0<_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo037ooooo00?o
0000ooooooooool0;?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo01kooooo000Q
ooooo`?o0000:?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo02cooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo03;ooooo00?o0000
ooooooooool07Oooool0027ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0boooo
o`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Zoooo
o`03o`000?oooooooooo03?ooooo00?o0000ooooooooool07Oooool0027ooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02[ooooo00?o0000oooooooo
ool0<oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03?ooooo00?o0000oooooooo
ool07Oooool0027ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0cooooo`03o`00
0?oooooooooo02[ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Zooooo`03o`00
0?oooooooooo03?ooooo00?o0000ooooooooool07Oooool0027ooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0<ooo
ool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool07Ooo
ool0027ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0dooooo`03o`000?oooooo
oooo02[ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooo
oooo03?ooooo00?o0000ooooooooool07Oooool0027ooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`0dooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0<oooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool07?ooool0027o
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02So
oooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo03Go
oooo00?o0000ooooooooool07?ooool0027ooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`0eooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0=Oooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool07?ooool0027ooooo0ol0
000Vooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0=Oooool00ol0003ooooooooo
o`0Looooo`008Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo03Kooooo00?o0000
ooooooooool0:?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02Sooooo00?o0000
ooooooooool0=Oooool00ol0003oooooooooo`0Looooo`008Oooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0eoooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Koooo
o`008Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo03Kooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool0=oooool00ol0003oooooooooo`0Kooooo`008Oooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo03Oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0gooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Kooooo`008Ooo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0=ooo
ool00ol0003oooooooooo`0Kooooo`008Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo03Sooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Kooooo`008Oooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`0gooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0>?ooool00ol0
003oooooooooo`0Jooooo`008Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03So
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Jooooo`008Oooool3o`0002Gooooo
00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo03Sooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo01[ooooo
000Qooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>Oooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`0iooooo`03o`000?oooooooooo01[ooooo000Qooooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool0>_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo03Wooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`1Fooooo`008Oooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo03[ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0ioooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0E_ooool0027ooooo0_l0000Uooooo`03
o`000?oooooooooo03[ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0iooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool0E_ooool0027ooooo0_l0000Uooooo`03o`00
0?oooooooooo03[ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0jooooo`03o`00
0?oooooooooo02?ooooo00?o0000ooooooooool0E_ooool0027ooooo0_l0000Uooooo`03o`000?oo
oooooooo03[ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0jooooo`03o`000?oo
oooooooo02;ooooo00?o0000ooooooooool0Eoooool0027ooooo0_l0000Uooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo02;ooooo00?o0000ooooooooool0Eoooool0027ooooo0_l0000Tooooo`03o`000?oooooooooo
03cooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool0Eoooool0027ooooo0ol0000Sooooo`03o`000?oooooooooo03co
oooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02;o
oooo00?o0000ooooooooool0Eoooool0027ooooo00?o0000ooooool000008oooool00ol0003ooooo
ooooo`0looooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`0Rooooo`03o`000?oooooooooo05Oooooo000Qooooo`03o`000?oooooo000002?ooooo00?o
0000ooooooooool0??ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03cooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`1Gooooo`008Oooool00ol0003oooooo`00000S
ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0l
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0F?ooool0027ooooo00?o0000oooo
ool000008_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool0?Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo05Sooooo000Qooooo`04
o`000?ooooooooooo`00027ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0Poooo
o`03o`000?oooooooooo03gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1Hoooo
o`008Oooool01?l0003oooooooooool0000Qooooo`03o`000?oooooooooo03kooooo00?o0000oooo
ooooool08?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool0F?ooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4
A4Co0000o`000?lb<S;ogMgM00Cooooo00Co0000oooooooooooo00008Oooool00ol0003ooooooooo
o`0nooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0?Oooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo05Sooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool01?l0003oooooooooool0000Qooooo`03o`00
0?oooooooooo03oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0nooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool0F?ooool000Oooooo00Go410@oooooooooooooooo
oa0@400@ooooo`03o`000?oooooooooo00;ooooo1?l0000Qooooo`03o`000?oooooooooo03oooooo
00?o0000ooooooooool07_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool0FOooool000Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMg
Molb<S;ooooo00?ooooo00Go0000ooooooooooooooooo`00000Oooooo`03o`000?oooooooooo043o
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool0FOooool000Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`01?ooool01Ol0003ooooooooooooooooo000001oooooo00?o0000
ooooooooool0@?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo03oooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`1Iooooo`001oooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo000001oooooo00?o
0000ooooooooool0@?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo03oooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`1Iooooo`001oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00cooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo000001oooooo
00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo047ooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`1Iooooo`001oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00cooooo1?l00005ooooo`05o`000?ooooooooooooooool000007oooool00ol0003o
ooooooooo`11ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0@Oooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo05[ooooo000Qooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo05[ooooo
000Qooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`12ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0@Oooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo05[ooooo000Qooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool0@Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo05[ooooo000Qoooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`13oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo05_ooooo000Qooooo`?o00000_ooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo04?ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`13ooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool0Foooool0027ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
Foooool0027ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo04Cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`13ooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool0Foooool0027ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`14ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0G?ooool0
027ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
04Gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool0G?ooool0027ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`15ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0G?ooool0027ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Kooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool0G?ooool0027ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`16ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0G?ooool0027ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Kooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool0GOooool0027ooooo0ol00004ooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool0Aoooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Oooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`1Mooooo`008Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo04Oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1Mooooo`00
8Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
B?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`1Mooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo04Sooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Nooooo`008Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0BOooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`1Nooooo`008Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
04Wooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Nooooo`008Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0BOooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`1Nooooo`008Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0Boooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo04[ooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`1Oooooo`008Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0Boooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`1Oooooo`008Oooool3o`0000Oooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1;
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo05oooooo000Qooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool0C?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo05oooooo000Qooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1=ooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo063ooooo000Qooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
COooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo063ooooo000Qooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1>ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo063ooooo000Qooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`1?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0C_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo067ooooo000Qooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
067ooooo000Qooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`1@ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0Coooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo067ooooo000Qooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo06;ooooo
000Qooooo`?o00002_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo057ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool0H_ooool0027ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1C
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0H_ooool0027ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05?ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool0Hoooool0027ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo05Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Dooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool0Hoooool0027ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
I?ooool0027ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo05Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Fooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool0I?ooool0027ooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`1Gooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0IOooool0
01Sooooo1?l000000ol@413oooooooooo`02ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0FOooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06Kooooo000Jooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool03_ooool2o`0000Cooooo00?o0000oooooooo
ool0F_ooool2o`0000Cooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo06Oooooo000Jooooo`03o`000?oooooooooo00Cooooo0ol0000?ooooo`Go0000
Goooool4o`0005oooooo1?l0001Zooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001Sooooo
00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooodGooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002L
ooooo`;o0000?oooool2o`0008Wooooo002Looooo`03o`000?oooooooooo03oooooo00?o0000oooo
ooooool0Qoooool008Wooooo0ol00002ooooo`06oc8b<_l@413oooooooooooo^k^koEEEE0_l00000
0om4A4Co^[Zjooooo`03ooooo`03o`000?oooooooooo00;ooooo00Kok^k^ofIVI_l0003o0000oc8b
<_nj^[Xgooooo`03o`000?oooooooooo08Oooooo002:ooooo`05o`000?ooooooooooolc<c?l@4100
0oooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40Cooooo00?o0000ooooooooool00_ooool2ogMg
M`04oeEEEOn7QhOogMgModA4A3Oooooo00?o0000ooooooooool0Qoooool008[ooooo00Go0000oooo
ooooooooEEEEohN7Q`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool0
0onHV9Soooooo`00000jooooo`03o`000?oooooooooo08Oooooo002:ooooo`05o`000?oooooogMgM
o`000?o^k^h00oooool6o`0000Cooooo00?o0000ooooooooool00_ooool00onHV9Soooooo`000003
o`0001;ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo08Oooooo002:ooooo`?o000000?o410@oiRHV?ooool00_ooool01_mEEEGoQhN7onk^k_oooooo
QhN7oc8b<PCooooo00?o0000ooooooooool00_ooool00omgMgOoQhN7ofIVIP02okZj^P03oc8b<_oo
oooooooo00oooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo08Oooooo002:ooooo`05o`000?ooooooooooolc<c?l000000oooool01_o^k^koEEEEo`00
0?l0003oA4A4onk^kPCooooo00?o0000ooooooooool00oooool01_mVIVKo0000o`000?m4A4Cok^k^
ooooo`?o00001?ooool2o`000003ooooool0003o000000?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooo`00000:ooooo`?o00001_ooool2o`0000Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`27ooooo`00R_ooool01Ol0003oooooooooooo<c<co000000gooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo000000Cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo08Oooooo0029oooo
o`Co000000?o410@ojVYZOooool03?ooool2o`0000_ooooo00?o0000ooooooooool01?ooool2o`00
00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`Co00000_ooool01?l0
003oooooooooool00005ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool2
o`0008Wooooo002Yooooo`03o`000?oooooooooo00Cooooo00?o0000ooooool000001?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooo000000[ooooo0ol00004ooooo`Co00001?ooool00ol0
003oooooooooo`2=ooooo`00Z?ooool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0S_ooool00:oooooo
0_l00008ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0Soooool00:Wooooo00?o
0000ooooooooool0_?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-2, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0505254 0.309016 0.294305 [
[.15012 .29652 -9 -9 ]
[.15012 .29652 9 0 ]
[.27644 .29652 -3 -9 ]
[.27644 .29652 3 0 ]
[.40275 .29652 -9 -9 ]
[.40275 .29652 9 0 ]
[.52906 .29652 -6 -9 ]
[.52906 .29652 6 0 ]
[.65538 .29652 -12 -9 ]
[.65538 .29652 12 0 ]
[.78169 .29652 -6 -9 ]
[.78169 .29652 6 0 ]
[.908 .29652 -12 -9 ]
[.908 .29652 12 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .01471 -12 -4.5 ]
[.01131 .01471 0 4.5 ]
[.01131 .16186 -24 -4.5 ]
[.01131 .16186 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[.5 .63053 -37.9062 0 ]
[.5 .63053 37.9062 12.625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15012 .30902 m
.15012 .31527 L
s
[(2.5)] .15012 .29652 0 1 Mshowa
.27644 .30902 m
.27644 .31527 L
s
[(5)] .27644 .29652 0 1 Mshowa
.40275 .30902 m
.40275 .31527 L
s
[(7.5)] .40275 .29652 0 1 Mshowa
.52906 .30902 m
.52906 .31527 L
s
[(10)] .52906 .29652 0 1 Mshowa
.65538 .30902 m
.65538 .31527 L
s
[(12.5)] .65538 .29652 0 1 Mshowa
.78169 .30902 m
.78169 .31527 L
s
[(15)] .78169 .29652 0 1 Mshowa
.908 .30902 m
.908 .31527 L
s
[(17.5)] .908 .29652 0 1 Mshowa
.125 Mabswid
.04907 .30902 m
.04907 .31277 L
s
.07433 .30902 m
.07433 .31277 L
s
.0996 .30902 m
.0996 .31277 L
s
.12486 .30902 m
.12486 .31277 L
s
.17539 .30902 m
.17539 .31277 L
s
.20065 .30902 m
.20065 .31277 L
s
.22591 .30902 m
.22591 .31277 L
s
.25117 .30902 m
.25117 .31277 L
s
.3017 .30902 m
.3017 .31277 L
s
.32696 .30902 m
.32696 .31277 L
s
.35222 .30902 m
.35222 .31277 L
s
.37749 .30902 m
.37749 .31277 L
s
.42801 .30902 m
.42801 .31277 L
s
.45328 .30902 m
.45328 .31277 L
s
.47854 .30902 m
.47854 .31277 L
s
.5038 .30902 m
.5038 .31277 L
s
.55433 .30902 m
.55433 .31277 L
s
.57959 .30902 m
.57959 .31277 L
s
.60485 .30902 m
.60485 .31277 L
s
.63011 .30902 m
.63011 .31277 L
s
.68064 .30902 m
.68064 .31277 L
s
.7059 .30902 m
.7059 .31277 L
s
.73116 .30902 m
.73116 .31277 L
s
.75643 .30902 m
.75643 .31277 L
s
.80695 .30902 m
.80695 .31277 L
s
.83222 .30902 m
.83222 .31277 L
s
.85748 .30902 m
.85748 .31277 L
s
.88274 .30902 m
.88274 .31277 L
s
.93327 .30902 m
.93327 .31277 L
s
.95853 .30902 m
.95853 .31277 L
s
.98379 .30902 m
.98379 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01471 m
.03006 .01471 L
s
[(-1)] .01131 .01471 1 0 Mshowa
.02381 .16186 m
.03006 .16186 L
s
[(-0.5)] .01131 .16186 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(0.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04414 m
.02756 .04414 L
s
.02381 .07357 m
.02756 .07357 L
s
.02381 .103 m
.02756 .103 L
s
.02381 .13243 m
.02756 .13243 L
s
.02381 .19129 m
.02756 .19129 L
s
.02381 .22072 m
.02756 .22072 L
s
.02381 .25015 m
.02756 .25015 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -98.9062 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.625 moveto
(@) show
81.000 13.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\343) show
87.000 9.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344) show
93.000 9.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
97.188 9.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
( ) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
99.000 9.625 moveto
(H) show
103.188 9.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
107.375 9.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
113.375 9.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
119.375 9.625 moveto
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
123.562 9.625 moveto
(L) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
128.812 13.625 moveto
(D) show
134.812 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .21807 m
.04262 .3261 L
.06244 .43716 L
.08255 .52983 L
.08806 .54969 L
.09396 .56777 L
.09948 .58153 L
.10458 .59134 L
.10714 .59519 L
.10954 .59812 L
.11204 .6005 L
.11337 .60146 L
.1148 .60228 L
.11548 .60259 L
.11622 .60286 L
.11702 .60308 L
.11776 .60323 L
.11853 .60331 L
.11924 .60332 L
.11989 .60328 L
.12059 .60318 L
.12123 .60305 L
.12193 .60284 L
.12335 .60226 L
.12466 .60151 L
.12589 .60063 L
.1285 .59819 L
.13097 .59517 L
.13561 .58766 L
.1406 .57696 L
.14603 .56236 L
.15542 .53028 L
.1658 .48606 L
.18681 .37602 L
.20778 .25476 L
.22701 .15119 L
.24586 .07152 L
.25533 .04328 L
.2607 .03136 L
.2657 .02308 L
.26833 .01985 L
.27075 .01756 L
.27201 .01662 L
.27341 .01581 L
.27411 .01549 L
.27486 .0152 L
.27557 .01499 L
.27622 .01485 L
.27749 .01472 L
.27866 .01476 L
Mistroke
.27995 .01498 L
.28067 .01519 L
.28132 .01543 L
.28252 .016 L
.28381 .01681 L
.28616 .01875 L
.2884 .0212 L
.29087 .02453 L
.29584 .03332 L
.30474 .05564 L
.31497 .09093 L
.32429 .13086 L
.34522 .24021 L
.36596 .3601 L
.38512 .46376 L
.40374 .54357 L
.41314 .5724 L
.41849 .5848 L
.42108 .58971 L
.4235 .59362 L
.42597 .59694 L
.42821 .59936 L
.4307 .60138 L
.43207 .60219 L
.43336 .60275 L
.43462 .60311 L
.43525 .60323 L
.43595 .6033 L
.43718 .6033 L
.43833 .60313 L
.43903 .60295 L
.43969 .60274 L
.44093 .60219 L
.44227 .60141 L
.44372 .60033 L
.44594 .59821 L
.44838 .59523 L
.45334 .58715 L
.45793 .57727 L
.46224 .56598 L
.47205 .53344 L
.4824 .49006 L
.50089 .395 L
.53897 .17912 L
.55856 .08892 L
.5642 .06853 L
.56952 .05201 L
.57427 .03969 L
.5795 .02888 L
.58191 .02489 L
Mistroke
.58451 .02132 L
.58696 .01865 L
.5892 .01681 L
.59051 .016 L
.59173 .01542 L
.59242 .01517 L
.59306 .01498 L
.59379 .01483 L
.59448 .01474 L
.59573 .01472 L
.59688 .01487 L
.59815 .0152 L
.59879 .01544 L
.59949 .01575 L
.6019 .01726 L
.60409 .01922 L
.60663 .02216 L
.60903 .02561 L
.61329 .03331 L
.61793 .0439 L
.62734 .07215 L
.63772 .11276 L
.65873 .2181 L
.67972 .33879 L
.69896 .44545 L
.71782 .53115 L
.7273 .56327 L
.73263 .57747 L
.73767 .58813 L
.7426 .5959 L
.74538 .59908 L
.74671 .60029 L
.74795 .60124 L
.74908 .60194 L
.75011 .60246 L
.75126 .6029 L
.75249 .60319 L
.75367 .60332 L
.75495 .60327 L
.75617 .60304 L
.75729 .60269 L
.75861 .60208 L
.76004 .6012 L
.76262 .59902 L
.76513 .59616 L
.76744 .59292 L
.7727 .58332 L
.77825 .56999 L
.78776 .53992 L
.79794 .49873 L
Mistroke
.81629 .40642 L
.83615 .29259 L
.85772 .1724 L
.86779 .12349 L
.87848 .07968 L
.88759 .0503 L
.89278 .03729 L
.89764 .02768 L
.90004 .0239 L
.9026 .02057 L
.90407 .01899 L
.90541 .01777 L
.90676 .01674 L
.90801 .01597 L
.9092 .01542 L
.91045 .015 L
.91171 .01477 L
.91243 .01472 L
.91309 .01472 L
.9143 .01486 L
.9154 .01513 L
.91667 .01562 L
.91788 .01626 L
.92011 .01787 L
.92248 .02021 L
.92675 .02602 L
.93134 .03451 L
.9364 .0465 L
.94639 .07774 L
.95555 .11434 L
.97619 .21807 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  FontSlant->"Italic",
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool001So
oooo1?l000000ol@413oooooooooo`02ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000?ooooo`Ko00001Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000
ooooooooool01?ooool3o`0004_ooooo1Ol0001Nooooo`Go0000G_ooool5o`0002kooooo000Joooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo05_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Joooo
o`;o00000oooool2o`0002gooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0BOooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05Wooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0:oooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`19ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo05Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Zooooo`006?oo
ool00omEEEGoIVIVo`000006ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Eooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02[ooooo000Qooooo`03o`000?oooooo
oooo04Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Fooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo02Wooooo000Qooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`1Eooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0EOooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo02Sooooo000Qooooo`03o`000?oooooooooo04Oo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02So
oooo000Qooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`1Cooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0E?ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo02Sooooo000Qooooo`?o0000A_ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`1Booooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool09oooool0027ooooo00?o0000
ooooooooool0A_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo057ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool09oooool0027ooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo057ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1@oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool09oooool0027ooooo00?o0000oooooooo
ool0AOooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo053ooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool09_ooool0027ooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo04oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1?ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool09_ooool0027ooooo00?o0000ooooooooool0A?oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool09_oo
ool0027ooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo04kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool09Oooool0027ooooo00?o0000ooooooooool0A?ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`1=ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool09Oooool0027o
oooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04go
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool09Oooool0027ooooo0ol00013ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04cooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Tooooo`008Oooool00ol0003ooooooooo
o`13ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0Boooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0Tooooo`008Oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool0Boooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo04_ooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0Tooooo`008Oooool00ol0003oooooooooo`12oooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo04[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Toooo
o`008Oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool0BOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04[ooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0Sooooo`008Oooool00ol0003oooooooooo`12ooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo04Wooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Sooooo`008Ooo
ool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0BOoo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`0Sooooo`008Oooool00ol0003oooooooooo`11ooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo04Sooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Sooooo`008Oooool00ol0
003oooooooooo`11ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0Aoooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`0Rooooo`008Oooool3o`00047ooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`17ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0B?ooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo02;ooooo000Qooooo`03o`000?oooooooooo043ooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02;ooooo
000Qooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`17ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0A_ooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo02;ooooo000Qooooo`03o`000?oooooooooo043ooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool0A_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo027ooooo000Qoooo
o`03o`000?oooooooooo043ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`15oooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo027ooooo000Qooooo`03o`000?oooooooooo043ooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool0A_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo027ooooo000Qooooo`03o`00
0?oooooooooo03oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`15ooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo027ooooo000Qooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0A?oo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo023ooooo000Qooooo`03o`000?oooooo
oooo03oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`14ooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo023ooooo000Qooooo`?o0000?oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
04?ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool08?ooool0027ooooo00?o0000ooooooooool0?_ooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`13ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool08?ooool0027ooooo
00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04?ooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool08?ooool0027ooooo00?o0000ooooooooool0?_ooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`12ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07oooool0027ooooo00?o0000
ooooooooool0?_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo047ooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool07oooool0027ooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo047ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`12oooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07oooool0027ooooo00?o0000oooooooo
ool0?Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo047ooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool07oooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo047ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`10oooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool07_ooool000Oooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo
03gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
01kooooo0005o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
03oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool07_ooool000Oooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo00?ooooo0ol0000looooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool0?oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo043ooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`0Nooooo`001oooool01Ol0003ooooooooooooooooo0000
00cooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo03cooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool0?_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01kooooo0007oooo
o`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo03cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo01gooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0n
ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo01gooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Gooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo03gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool07Oooool0027ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`0nooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool07Oooool0027o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03go
oooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool07Oooool0027ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool08Oooool00ol0003ooooo
ooooo`0looooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool07?ooool0027ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03cooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo027ooooo00?o
0000ooooooooool07?ooool0027ooooo0ol0000kooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03cooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`0Looooo`008Oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Roooo
o`03o`000?oooooooooo03cooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Loooo
o`008Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo02;ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool08_ooool00ol0003oooooooooo`0Kooooo`008Oooool00ol0003oooooooooo`0jooooo`03o`00
0?oooooooooo02;ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Sooooo`03o`00
0?oooooooooo03[ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Kooooo`008Ooo
ool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0>_oo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`0Kooooo`008Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooo
oooo02?ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo
oooo03[ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Kooooo`008Oooool00ol0
003oooooooooo`0jooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0>Oooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool08oooool00ol0
003oooooooooo`0Kooooo`008Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Wo
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Jooooo`008Oooool00ol0003ooooo
ooooo`0iooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0>Oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0Jooooo`008Oooool3o`0003Wooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0hooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?ooool00ol0003ooooooooo
o`12ooooo`008Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0>?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo00?o0000
ooooooooool0@_ooool0027ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo03Oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0hoooo
o`03o`000?oooooooooo04;ooooo000Qooooo`;o0000>_ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo03Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo04;ooooo000Qooooo`;o0000>Oooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo03Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0fooooo`03o`00
0?oooooooooo04?ooooo000Qooooo`;o0000>Oooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0fooooo`03o`000?oo
oooooooo04?ooooo000Qooooo`;o0000>Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo03Kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0fooooo`03o`000?oooooo
oooo04?ooooo000Qooooo`;o0000>Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
03Kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo
04?ooooo000Qooooo`03o`000?oooooo000003Sooooo00?o0000ooooooooool09oooool00ol0003o
ooooooooo`0eooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0=_ooool00ol0003o
ooooooooo`13ooooo`008Oooool3o`0003Oooooo00?o0000ooooooooool0:?ooool00ol0003ooooo
ooooo`0eooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0=Oooool00ol0003ooooo
ooooo`13ooooo`008Oooool00ol0003oooooo`00000gooooo`03o`000?oooooooooo02Wooooo00?o
0000ooooooooool0=?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo03Cooooo00?o
0000ooooooooool0A?ooool0027ooooo00?o0000ooooool00000=oooool00ol0003oooooooooo`0Y
ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0d
ooooo`03o`000?oooooooooo04Cooooo000Qooooo`03o`000?oooooo000003Oooooo00?o0000oooo
ooooool0:Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool0=?ooool00ol0003oooooooooo`14ooooo`008Oooool00ol0003oooooo`00000gooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Zooooo`03
o`000?oooooooooo03Cooooo00?o0000ooooooooool0A?ooool0027ooooo00Co0000oooooooooooo
0000=_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo03?ooooo00?o0000oooooooo
ool0:_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo04Cooooo000Qooooo`04o`00
0?ooooooooooo`0001Wooooo1Ol00005ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM
00Kooooo00?o0000ooooooooool04Oooool01Om4A4Co0000o`000?lb<S;ogMgM01Cooooo00?o0000
ooooooooool01Oooool00ol0003ok^k^ooooo`05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb
<S;ogMgM01Kooooo1Ol00002ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h05?ooool4o`000003oa0@
4?oooooooooo00Go00001Oooool00ol0003o8B4Qooooo`04ooooo`05odA4A?l0003o0000oc8b<_oM
gMd04_ooool4o`000005oa0@4?oooooooooooooooom4A4@00_l000000olb<S;ogMgMooooo`0:oooo
o`03o`000?oooooooooo00Cooooo1?l000000ol@413oooooooooo`02ooooo`03o`000?o^k^kooooo
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd09?ooool0027ooooo00Co0000oooo
oooooooo00006Oooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo0_lQ8B48ooooo`03ogMgMolb
<S;ooooo00Gooooo00?o0000ooooooooool05?ooool00omgMgOo<S8booooo`0Dooooo`03o`000?oo
oooooooo00Cooooo00?oEEEEojVYZOooool01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool05ooo
ool00ol0003oooooo`000002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL05_ooool00ol0003ooooo
ooooo`02ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool00olQ8B7o0000ooooo`07ooooo`03
ogMgMolb<S;ooooo01?ooooo00?o0000ooooooooool01_ooool00omgMgOo<S8booooo`0:ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool00omEEEGoZJVYooooo`05ooooo`;o
8B4Q2?ooool00omgMgOo<S8booooo`0Sooooo`008Oooool01?l0003oooooooooool0000Jooooo`03
oiRHV?lQ8B7ok^k^017ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool01?ooool00onYZJWoEEEEooooo`0@ooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooool000000_ooool01Ol@413ooooooooooooooooo410@
01Kooooo00?o0000ooooooooool00oooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03ojVYZOmEEEGooooo
013ooooo00?o0000ooooooooool08_ooool0027ooooo1?l0000Kooooo`03oiRHV?lQ8B7ok^k^00oo
oooo00?oMgMgoc8b<_ooool01Oooool00ol0003oooooooooo`0Dooooo`03ogMgMolb<S;ooooo01Co
oooo00?o0000ooooooooool01Oooool00olQ8B7oooooooooo`0>ooooo`03ogMgMolb<S;ooooo01Oo
oooo00?o0000ooooool000000_ooool01Ol0003ooooooooooooooooo000001Kooooo00?o0000oooo
ooooool01?ooool00onHV9So8B4Qonk^kP06ooooo`03o`000?oooooooooo00Kooooo00?oMgMgoc8b
<_ooool04oooool00ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo00[ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`03ob4Q8Ooooooooooo00kooooo00?oMgMgoc8b
<_ooool08oooool0027ooooo00Co0000oooooooooooo00007?ooool00omgMgOoIVIVooooo`0;oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`01_ooool00ol0003oooooooooo`0Aooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`05Oooool00ol0003oooooooooo`05ooooo`03oeEEEOo<c<cooooo00_ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c00Hooooo`;o00000oooool01Ol0003ooooooooooooooooo000001Ko
oooo00?o0000ooooooooool01Oooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo00?o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c00Dooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q
8Ol0003o<S8bolc<c00;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0omEEEGoc<c<ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`09?ooool0027ooooo00Go0000
ooooooooooooooooo`00000Looooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01Ooo
ool00onYZJWoMgMgooooo`0;ooooo`03o`000?oooooooooo01[ooooo0_l00003ooooo`05oa0@4?oo
ooooooooooooool@41005_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo
00?oZJVYogMgMoooool02oooool00ol0003oooooooooo`0Vooooo`008Oooool01Ol0003ooooooooo
oooooooo000001Sooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00;o
oooo00Go410@oooooooooooooooooc8b<P0<ooooo`03o`000?oooooooooo01[ooooo0_l00003oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL05_ooool00ol0003oooooooooo`02ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo<S8b00cooooo00?o0000ooooooooool0
9_ooool0027ooooo00Go0000ooooooooooooooooo`00000Hooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`03?ooool4o`0000Kooooo00?o0000ooooooooool04_ooool4o`0001Oooooo00Co0000oooooooo
oooooooo1Ol0000<ooooo`Co00005oooool01?mEEEGoIVIVo`000?l00003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h05?ooool00omEEEGoIVIVo`000004ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
1oooool00ol0003oooooooooo`02ooooo`Co00004oooool00omEEEGoIVIVo`000005ooooo`Co0000
2oooool00ol0003oooooooooo`05ooooo`03oeEEEOmVIVKo000000Cooooo1Ol0000<ooooo`Co0000
9Oooool0027ooooo00Go0000ooooooooooooooooo`00000cooooo`03o`000?oooooooooo02gooooo
00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool0A_ooool0027ooooo00Go0000ooooooooooooooooo`00000cooooo`03o`00
0?oooooooooo02gooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0^ooooo`03o`00
0?oooooooooo033ooooo00?o0000ooooooooool0A_ooool0027ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0;ooo
ool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0??oo
ool2o`0000;ooooo0_l00004ooooo`008Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo02oooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0mooooo`06onk^k_lQ8B7o
QhN7okZj^_l0003ogMgM1?ooool001[oooooool0000jo`0000cooooo00CogMgMo`000?l@413oc<c<
1Oooool0027ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00007ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01?ooool2o`0000Oooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`;o00001oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03oooool01?o^k^ko
8B4Qoa0@4?o^k^h5ooooo`008Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
00Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`;o00001oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000001Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03
ooooo`;o00001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool03oooool01?lQ8B7oMgMgogMgMolb<S85ooooo`008Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0]
ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0m
ooooo`;o00000_ooool2o`0000Cooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0;Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02gooooo00?o0000oooo
ooooool0<?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo04Oooooo000Qooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0`ooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0]ooooo`03
o`000?oooooooooo04Sooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo04Sooooo000Qooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0`ooooo`03o`000?oo
oooooooo02gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0]ooooo`03o`000?oo
oooooooo04Sooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`0aooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0<_ooool0
0ol0003oooooooooo`0/ooooo`03o`000?oooooooooo04Sooooo000Qooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo
02_ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo
04Sooooo000Qooooo`?o00001?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo03;o
oooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo02co
oooo00?o0000ooooooooool0B?ooool0027ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0[ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0:oooool00ol0003ooooo
ooooo`0booooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0BOooool0027ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo03;ooooo00?o
0000ooooooooool0:oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo02_ooooo00?o
0000ooooooooool0BOooool0027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0[
ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0b
ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0BOooool0027ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03Cooooo00?o0000oooo
ooooool0:Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02[ooooo00?o0000oooo
ooooool0BOooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo03Cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0dooooo`03
o`000?oooooooooo02[ooooo00?o0000ooooooooool0BOooool0027ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0
BOooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Yooooo`03o`000?oo
oooooooo03Cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0dooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool0B_ooool0027ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0:Oooool0
0ol0003oooooooooo`0dooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0B_ooool0
027ooooo0ol00005ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0=Oooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0:?ooool00ol0
003oooooooooo`1:ooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02So
oooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`1:ooooo`008Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0=_ooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0:?ooool00ol0003ooooo
ooooo`1:ooooo`008Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool0=_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo03Kooooo00?o
0000ooooooooool0:?ooool00ol0003oooooooooo`1:ooooo`008Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1;
ooooo`008Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Oooooo00?o0000oooo
ooooool0=_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo03Kooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`1;ooooo`008Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo03Sooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1;ooooo`00
8Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
>?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`1;ooooo`008Oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo03Sooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1;ooooo`008Oooool3
o`0000Oooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo04_ooooo000Qooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0hooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo04cooooo000Qooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo04co
oooo000Qooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`0jooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0>_ooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo04cooooo000Qooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool0>_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo04cooooo000Q
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0j
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo04cooooo000Qooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo02?ooooo00?o0000oooo
ooooool0>_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo04gooooo000Qooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0jooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo04gooooo000Qooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo04gooooo000Qooooo`?o00002?oo
ool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`0looooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0COoo
ool0027ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo03cooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0looooo`03o`000?oooooo
oooo02;ooooo00?o0000ooooooooool0COooool0027ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0Qooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool08Oooool00ol0
003oooooooooo`0looooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0C_ooool0027o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03co
oooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool0C_ooool0027ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool08Oooool00ol0003ooooo
ooooo`0mooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0C_ooool0027ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03kooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool0C_ooool0027ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0n
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0C_ooool000Oooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03kooooo00?o
0000ooooooooool07oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool0Coooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?oo
ool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0?_oo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo04oooooo0007ooooo`05oa0@4?oooooo
ooooooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o00002_ooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`0oooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0Coooool000Oooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0Cooo
ool000Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
@?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`1?ooooo`001oooool01Ol@413ooooooooooooooooo410@00cooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo043ooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`1@ooooo`001oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo01gooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo043ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1@ooooo`001ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo053ooooo
000Qooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`11ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0@Oooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo053ooooo000Qooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool0@Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo053ooooo000Qoooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`12oooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo057ooooo000Qooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool0@oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo057ooooo000Qooooo`?o0000
3Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
DOooool0027ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo04?ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`13ooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool0DOooool0027ooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`13ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0DOooool0
027ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
04Cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool0D_ooool0027ooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`15ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0D_ooool0027ooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool0D_ooool0027ooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`15ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0D_ooool0027ooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Kooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool0Doooool0027ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo04Kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`17oooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0Doooool0027ooooo0ol0000?ooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo04Oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1Cooooo`00
8Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
B?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`1Cooooo`008Oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo04Sooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Dooooo`008Oooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0B?ooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`1Dooooo`008Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
04Wooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Dooooo`008Oooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0B_ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`1Dooooo`008Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04[ooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Dooooo`008Oooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0B_ooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`1Eooooo`008Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool0C?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo04_ooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`1Eooooo`008Oooool3o`00017ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool0C?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo05Gooooo000Qooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1<ooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo05Kooooo000Qooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
COooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05Kooooo000Qooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1=ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo05Kooooo000Qooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0C_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05Oooooo000Qooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
05Oooooo000Qooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`1?ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0D?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo05Oooooo000Qooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo05Sooooo
000Qooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`1Aooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0DOooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo05Sooooo000Qooooo`?o00005?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1B
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0F?ooool0027ooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05;ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool0FOooool0027ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo05?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Cooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool0FOooool0027ooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
F_ooool0027ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo05Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Eooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool0F_ooool0027ooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`1Eooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Foooool0
027ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
05Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0Foooool001Sooooo1?l000000ol@413oooooooooo`02ooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Iooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo05cooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
6?ooool2o`0000Cooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo05_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Mooooo`006_oo
ool00ol0003oooooooooo`04ooooo`?o00006Oooool5o`0005kooooo1Ol0001Nooooo`Go0000H?oo
ool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Joooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o
0000ooooooooool0oooooom5ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00W?ooool2o`0003oooooo0_l00029oooo
o`00W?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo08Oooooo0029ooooo`?o0000
0_ooool01_lb<S;o410@ooooooooooook^k^oeEEE@;o000000?oA4A4okZj^_ooool00oooool00ol0
003oooooooooo`02ooooo`06onk^k_mVIVKo0000o`000?lb<S;o^[Zj=oooool00ol0003ooooooooo
o`27ooooo`00R_ooool01Ol0003oooooooooooo<c<co410@00?ooooo00KoEEEEogMgMoooooook^k^
ogMgMol@4104ooooo`03o`000?oooooooooo00;ooooo0_mgMgL01?mEEEGoQhN7omgMgOm4A4@goooo
o`03o`000?oooooooooo08Oooooo002:ooooo`05o`000?oooooooooooeEEEOn7QhL00oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?oV9RHooooool00000>_ooool00ol0
003oooooooooo`27ooooo`00R_ooool01Ol0003oooooomgMgOl0003ok^k^00?ooooo1_l00004oooo
o`03o`000?oooooooooo00;ooooo00?oV9RHooooool000000ol0000Booooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`27ooooo`00R_ooool3o`000003
oa0@4?nHV9Sooooo00;ooooo00KoEEEEohN7Qoo^k^koooooohN7Qolb<S84ooooo`03o`000?oooooo
oooo00;ooooo00?oMgMgohN7QomVIVH00_nj^[X00olb<S;oooooooooo`0?ooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`27ooooo`00R_ooool01Ol0
003oooooooooooo<c<co000000?ooooo00Kok^k^oeEEEOl0003o0000odA4A?o^k^h4ooooo`03o`00
0?oooooooooo00?ooooo00KoIVIVo`000?l0003oA4A4onk^k_ooool3o`0000Cooooo0_l000000ooo
oooo0000o`000003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000002_ooool3o`00
00Kooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Qoooool008[o
oooo00Go0000ooooooooooooc<c<o`00000=ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`27ooooo`00ROooool4o`000003oa0@4?nYZJWooooo00co
oooo0_l0000;ooooo`03o`000?oooooooooo00Cooooo0_l00005ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool4o`0000;ooooo00Co0000oooooooooooo00001Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo0_l00029ooooo`00ZOooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooo000000Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooo`00000:ooooo`?o00001?ooool4o`0000Cooooo00?o0000ooooooooool0SOooool00:Sooooo
0_l00006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo08kooooo002_ooooo`;o00002?ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo08oooooo002Yooooo`03o`000?oooooooooo0;cooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-2, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0505254 0.309017 0.294302 [
[.15012 .29652 -9 -9 ]
[.15012 .29652 9 0 ]
[.27644 .29652 -3 -9 ]
[.27644 .29652 3 0 ]
[.40275 .29652 -9 -9 ]
[.40275 .29652 9 0 ]
[.52906 .29652 -6 -9 ]
[.52906 .29652 6 0 ]
[.65538 .29652 -12 -9 ]
[.65538 .29652 12 0 ]
[.78169 .29652 -6 -9 ]
[.78169 .29652 6 0 ]
[.908 .29652 -12 -9 ]
[.908 .29652 12 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .01471 -12 -4.5 ]
[.01131 .01471 0 4.5 ]
[.01131 .16187 -24 -4.5 ]
[.01131 .16187 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[.5 .63053 -37.9062 0 ]
[.5 .63053 37.9062 12.625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15012 .30902 m
.15012 .31527 L
s
[(2.5)] .15012 .29652 0 1 Mshowa
.27644 .30902 m
.27644 .31527 L
s
[(5)] .27644 .29652 0 1 Mshowa
.40275 .30902 m
.40275 .31527 L
s
[(7.5)] .40275 .29652 0 1 Mshowa
.52906 .30902 m
.52906 .31527 L
s
[(10)] .52906 .29652 0 1 Mshowa
.65538 .30902 m
.65538 .31527 L
s
[(12.5)] .65538 .29652 0 1 Mshowa
.78169 .30902 m
.78169 .31527 L
s
[(15)] .78169 .29652 0 1 Mshowa
.908 .30902 m
.908 .31527 L
s
[(17.5)] .908 .29652 0 1 Mshowa
.125 Mabswid
.04907 .30902 m
.04907 .31277 L
s
.07433 .30902 m
.07433 .31277 L
s
.0996 .30902 m
.0996 .31277 L
s
.12486 .30902 m
.12486 .31277 L
s
.17539 .30902 m
.17539 .31277 L
s
.20065 .30902 m
.20065 .31277 L
s
.22591 .30902 m
.22591 .31277 L
s
.25117 .30902 m
.25117 .31277 L
s
.3017 .30902 m
.3017 .31277 L
s
.32696 .30902 m
.32696 .31277 L
s
.35222 .30902 m
.35222 .31277 L
s
.37749 .30902 m
.37749 .31277 L
s
.42801 .30902 m
.42801 .31277 L
s
.45328 .30902 m
.45328 .31277 L
s
.47854 .30902 m
.47854 .31277 L
s
.5038 .30902 m
.5038 .31277 L
s
.55433 .30902 m
.55433 .31277 L
s
.57959 .30902 m
.57959 .31277 L
s
.60485 .30902 m
.60485 .31277 L
s
.63011 .30902 m
.63011 .31277 L
s
.68064 .30902 m
.68064 .31277 L
s
.7059 .30902 m
.7059 .31277 L
s
.73116 .30902 m
.73116 .31277 L
s
.75643 .30902 m
.75643 .31277 L
s
.80695 .30902 m
.80695 .31277 L
s
.83222 .30902 m
.83222 .31277 L
s
.85748 .30902 m
.85748 .31277 L
s
.88274 .30902 m
.88274 .31277 L
s
.93327 .30902 m
.93327 .31277 L
s
.95853 .30902 m
.95853 .31277 L
s
.98379 .30902 m
.98379 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01471 m
.03006 .01471 L
s
[(-1)] .01131 .01471 1 0 Mshowa
.02381 .16187 m
.03006 .16187 L
s
[(-0.5)] .01131 .16187 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(0.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .13244 m
.02756 .13244 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -98.9062 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.625 moveto
(@) show
81.000 13.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\343) show
87.000 9.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344) show
93.000 9.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
97.188 9.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
( ) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
99.000 9.625 moveto
(H) show
103.188 9.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
107.375 9.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
113.375 9.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
119.375 9.625 moveto
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
123.562 9.625 moveto
(L) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
128.812 13.625 moveto
(D) show
134.812 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .07092 m
.06244 .25696 L
.08255 .3733 L
.10458 .48856 L
.11448 .53052 L
.11992 .55007 L
.12507 .56598 L
.12986 .57841 L
.13506 .58916 L
.13735 .59297 L
.13979 .59636 L
.14187 .59875 L
.14415 .60078 L
.14546 .60168 L
.14667 .60234 L
.14783 .60281 L
.14907 .60315 L
.15028 .6033 L
.15142 .6033 L
.15245 .60316 L
.15356 .60288 L
.15479 .6024 L
.15613 .60168 L
.15753 .60071 L
.15884 .5996 L
.16133 .59695 L
.16369 .59379 L
.16831 .58582 L
.17252 .57653 L
.18199 .54899 L
.19164 .51227 L
.2019 .46519 L
.22032 .36598 L
.25807 .1546 L
.26749 .11081 L
.27741 .07217 L
.28261 .05549 L
.28829 .04031 L
.29346 .02946 L
.29827 .02198 L
.3009 .01899 L
.30332 .01693 L
.30459 .01612 L
.30598 .01544 L
.30668 .01518 L
.30743 .01497 L
.30814 .01482 L
.30879 .01475 L
.31006 .01473 L
.31123 .01488 L
Mistroke
.31252 .01523 L
.31324 .01551 L
.31389 .01581 L
.31509 .0165 L
.31638 .01742 L
.31873 .01958 L
.32098 .02224 L
.32344 .02581 L
.32841 .03505 L
.33732 .05813 L
.34755 .09419 L
.35686 .13472 L
.37779 .2449 L
.39853 .36483 L
.41769 .46784 L
.43631 .54644 L
.44571 .57451 L
.45106 .58644 L
.45366 .59112 L
.45607 .59481 L
.45854 .5979 L
.46078 .60011 L
.46198 .60105 L
.46327 .60189 L
.46398 .60227 L
.46464 .60257 L
.46593 .60301 L
.46717 .60325 L
.46833 .60332 L
.4696 .60321 L
.47032 .60307 L
.47097 .6029 L
.47228 .60239 L
.4737 .60161 L
.47505 .60066 L
.47629 .5996 L
.48056 .59464 L
.48299 .5909 L
.48527 .58679 L
.49481 .56359 L
.50463 .5303 L
.51497 .48624 L
.53347 .39038 L
.57154 .17482 L
.59113 .08576 L
.59677 .06579 L
.6021 .0497 L
.60684 .03779 L
.61207 .02744 L
.61449 .02367 L
Mistroke
.61708 .02035 L
.61953 .01791 L
.62178 .01628 L
.62308 .01559 L
.6243 .01513 L
.625 .01494 L
.62563 .01482 L
.62636 .01474 L
.62705 .01472 L
.6283 .01482 L
.62946 .01507 L
.63072 .01552 L
.63206 .0162 L
.63426 .01776 L
.63661 .02004 L
.64086 .02574 L
.6459 .03511 L
.6505 .04603 L
.66043 .07687 L
.6696 .11336 L
.69037 .21748 L
.71064 .33397 L
.72966 .44001 L
.74784 .52442 L
.75806 .56032 L
.76743 .58425 L
.77217 .59281 L
.77483 .59651 L
.77724 .59919 L
.77949 .60109 L
.78076 .60191 L
.78194 .6025 L
.78296 .60288 L
.78409 .60317 L
.78526 .60331 L
.78637 .60329 L
.78765 .6031 L
.78837 .60291 L
.78904 .60268 L
.79027 .60212 L
.79158 .60134 L
.79409 .59929 L
.79635 .59682 L
.80188 .58839 L
.80707 .57742 L
.81687 .54912 L
.8272 .50954 L
.84569 .41918 L
.88374 .20279 L
.89463 .14651 L
Mistroke
.90494 .10019 L
.91497 .06339 L
.91938 .0502 L
.92423 .03795 L
.9286 .02906 L
.9333 .02184 L
.9359 .01892 L
.93827 .01691 L
.93941 .01617 L
.94065 .01554 L
.94183 .01511 L
.94292 .01485 L
.9442 .01472 L
.94491 .01473 L
.94557 .01479 L
.94679 .01503 L
.94807 .01547 L
.94922 .01603 L
.9503 .01669 L
.95274 .01868 L
.95539 .02159 L
.9578 .02493 L
.96321 .03479 L
.96943 .04997 L
.97619 .07092 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  FontSlant->"Italic",
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool001So
oooo1?l000000ol@413oooooooooo`02ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000?ooooo`Ko00001Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000
ooooooooool01?ooool3o`0005Gooooo1Ol0001Nooooo`Co0000Goooool5o`0002Cooooo000Joooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo05_ooooo00?o0000ooooooooool00_ooool2o`0005cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Rooooo`006_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo05?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Iooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo027ooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
Doooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
8?ooool001Sooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`1Booooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo05Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Pooooo`008Oooool0
0ol0003oooooooooo`1Booooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0E_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0Oooooo`008Oooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
05Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Nooooo`008Oooool00ol0003o
ooooooooo`1Aooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Doooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0Nooooo`008Oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0Doooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05?ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Mooooo`008Oooool3o`00053ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0D_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01gooooo000Q
ooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1A
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo01gooooo000Qooooo`03o`000?oooooooooo04oooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool0DOooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01cooooo000Qooooo`03
o`000?oooooooooo04kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1@ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo01cooooo000Qooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
D?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01_ooooo000Qooooo`03o`000?oo
oooooooo04kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1?ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo01_ooooo000Qooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`1?ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0C_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01_ooooo000Qooooo`03o`000?oooooooooo
04gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
01[ooooo000Qooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`1=ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0C_ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo01[ooooo000Qooooo`?o0000COooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`1<ooooo`03o`000?oooooooooo02kooooo000Qooooo`03o`000?oooooooooo04gooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool0C?ooool00ol0003oooooooooo`0^ooooo`008Oooool2o`0004gooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool0C?ooool00ol0003oooooooooo`0^ooooo`008Oooool2o`0004gooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool0Boooool00ol0003oooooooooo`0_ooooo`008Oooool2o`0004gooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool0B_ooool00ol0003oooooooooo`0_ooooo`008Oooool2o`0004cooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
B_ooool00ol0003oooooooooo`0_ooooo`008Oooool2o`0004cooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0B_oo
ool00ol0003oooooooooo`0_ooooo`008Oooool00ol0003oooooo`00001;ooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo04Sooooo00?o0000ooooooooool0<?ooool0027ooooo00?o0000ooooool00000B_ooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`18ooooo`03o`000?oooooooooo033ooooo000Qooooo`?o0000B_ooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`18ooooo`03o`000?oooooooooo033ooooo000Qooooo`03o`000?oooooo000004[ooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0`ooooo`008Oooool00ol0003oooooo`00
0019ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0Aoooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0<Oooool0027ooooo00Co0000
oooooooooooo0000B?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Oooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo037ooooo000Q
ooooo`04o`000?ooooooooooo`0004Sooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`16ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0A_ooool00ol0003ooooooooo
o`0aooooo`008Oooool01?l0003oooooooooool00018ooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool0A_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Kooooo00?o
0000ooooooooool0<Oooool0027ooooo00Co0000oooooooooooo0000B?ooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`14ooooo`03o`000?oooooooooo03;ooooo000Qooooo`04o`000?ooooooooooo`0004Oooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool0A?ooool00ol0003oooooooooo`0booooo`008Oooool01Ol0003ooooooooooooo
oooo000004Kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`15ooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0booooo`008Oooool3
o`000003ooooool0003ooooo04Gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`14
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0c
ooooo`008Oooool01Ol0003ooooooooooooooooo000004Kooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`13ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0@oooool0
0ol0003oooooooooo`0cooooo`008Oooool01Ol0003ooooooooooooooooo000004Kooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool0@_ooool00ol0003oooooooooo`0cooooo`008Oooool01Ol0003ooooooooooooooooo
000004Kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`13ooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0cooooo`008Oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`12ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0@Oooool00ol0
003oooooooooo`0dooooo`008Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04;o
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0dooooo`008Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`11ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0@Oooool00ol0003ooooo
ooooo`0dooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4
A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04;o
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0dooooo`001oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool0@Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo043ooooo00?o0000oooooooo
ool0=?ooool000Go00000_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo047ooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool0?oooool00ol0003oooooooooo`0eooooo`001oooool01Ol0003ooooooooooooooooo000000oo
oooo00?oMgMgoc8b<_ooool00oooool3o`0000?ooooo00?o0000ooooooooool0@Oooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`0oooooo`03o`000?oooooooooo03Gooooo0007ooooo`05o`000?ooooooooooooooool0
00003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`10ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0?oooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0=Oooool000Oo
oooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool0?oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03kooooo00?o0000oooo
ooooool0=Oooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
03kooooo00?o0000ooooooooool0=Oooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<oooo
o`Co00001Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03oooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool0?Oooool00ol0003oooooooooo`0fooooo`008Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0mooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0fooooo`00
8Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0
8?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
??ooool00ol0003oooooooooo`0fooooo`008Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo03kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0mooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0fooooo`008Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`0looooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0??ooool0
0ol0003oooooooooo`0fooooo`008Oooool3o`0000Gooooo00?o0000ooooooooool0?Oooool00ol0
003oooooooooo`0Qooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool08_ooool00ol0
003oooooooooo`0looooo`03o`000?oooooooooo03Kooooo000Qooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo03Oo
oooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0?Oooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool08oooool00ol0003ooooo
ooooo`0jooooo`03o`000?oooooooooo03Oooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0??ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03Oooooo000Q
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0R
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0j
ooooo`03o`000?oooooooooo03Oooooo000Qooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03Wooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03Oooooo000Qooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo03Wooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0jooooo`03
o`000?oooooooooo03Oooooo000Qooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo03Sooooo000Qooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo03Wooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hooooo`03o`000?oo
oooooooo03Sooooo000Qooooo`?o00001oooool00ol0003oooooooooo`0iooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo03Sooooo00?o0000ooooooooool0>?ooool0027ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0iooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0>?ooool0027o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo03So
oooo00?o0000ooooooooool0>?ooool0027ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0iooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0=oooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0>Oooool0027ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0=oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo03Kooooo00?o
0000ooooooooool0>Oooool0027ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0g
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0>Oooool0027ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02Oooooo00?o0000oooo
ooooool0=_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo03Kooooo00?o0000oooo
ooooool0>Oooool0027ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo03Kooooo00?o0000ooooooooool0>Oooool0027ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
=Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0
>Oooool0027ooooo0ol00008ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0=?oo
ool00ol0003oooooooooo`0jooooo`008Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo03Gooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooo
oooo02Wooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0jooooo`008Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`0dooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0=?ooool00ol0
003oooooooooo`0jooooo`008Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03Go
oooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0jooooo`008Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0:Oooool00ol0003ooooo
ooooo`0dooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0=?ooool00ol0003ooooo
ooooo`0jooooo`008Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03Gooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02[ooooo00?o
0000ooooooooool0=?ooool00ol0003oooooooooo`0jooooo`008Oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00gooooo1Ol00005ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb
<S;ogMgM017ooooo00?o0000ooooooooool01_ooool01Om4A4Co0000o`000?lb<S;ogMgM01cooooo
00?o0000onk^k_l000001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Fooooo`Co
000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP;ooooo00?o0000ooooooooool03ooo
ool4o`000003oa0@4?oooooooooo00Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8b
o`00000Booooo`Co000000Go410@ooooooooooooooooodA4A002o`000003oc8b<_oMgMgooooo017o
oooo1?l000000ol@413oooooooooo`02ooooo`03o`000?o^k^kooooo00Gooooo0_lQ8B45ooooo`05
odA4A?l0003o0000oc8b<_oMgMd09?ooool0027ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0=ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool03oooool00ol0003oooooooooo`0:ooooo`03ogMgMolb<S;ooooo01_ooooo00?oEEEEojVY
ZOl000001Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool05oooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL00_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo00;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`;o8B4Q2?ooool00omgMgOo0000oooo
o`0Cooooo`03o`000?oooooooooo00Kooooo00?oMgMgoc8b<_ooool04oooool2o`0000Gooooo00?o
EEEEojVYZOooool01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool08oooool0027ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0>ooooo`03oiRHV?lQ8B7ok^k^017ooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01[ooooo00CoZJVY
oeEEEOoooooo00003oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00;ooooo00Go
410@oooooooooooooooooa0@4002ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
0oooool00onHV9So8B4Qonk^kP0Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Booooo`;o00001Oooool00onYZJWoEEEEooooo`0@ooooo`03o`00
0?oooooooooo02;ooooo000Qooooo`?o00002_ooool00ol0003oooooooooo`0?ooooo`03oiRHV?lQ
8B7ok^k^00oooooo00?oMgMgoc8b<_ooool03oooool00ol0003oooooooooo`0:ooooo`03ogMgMolb
<S;ooooo01cooooo00?o8B4Qooooool000003_ooool00omgMgOo<S8booooo`0Gooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool01?ooool00onHV9So8B4Qonk^kP0?ooooo`03ogMgMol0003ooooo01?ooooo
00?o0000ooooooooool01_ooool00omgMgOo<S8booooo`0Cooooo`;o00001_ooool00olQ8B7ooooo
ooooo`0>ooooo`03ogMgMolb<S;ooooo02?ooooo000Qooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool04?ooool00omgMgOoIVIVooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
4?ooool00ol0003oooooooooo`07ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`07Oooool00omEEEGo
c<c<o`00000;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06?ooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo00Gooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;o000001Cooooo00?o
0000ooooooooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Cooooo0_l00006ooooo`03oeEE
EOo<c<cooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Tooooo`008Oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07oooool00onYZJWoMgMg
o`00000;ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool00_ooool01ol@413ooooo
oooooooooooo410@ooooool000005?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00[ooooo00Go0000ooooooooooooooooo`00000Dooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`05ooooo`03ojVYZOmgMgOooooo00_ooooo00?o0000
ooooooooool09_ooool0027ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`05o`000?nj^[[ooooooiRHV?l@41003?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool07?ooool01_l@413ooooooooooooooooo<S8bo`0000_ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`02ooooo`07ogMgMonHV9SooooooiRHV?mg
MgOoooooo`00000Dooooo`03o`000?oooooooooo00;ooooo00Go0000okZj^_ooooooV9RHoa0@400<
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo<S8b00cooooo00?o0000ooooooooool09_ooool0027ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0<ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?ooool4o`00013ooooo00?o
0000ooooooooool02?ooool4o`0001_ooooo1_l0000;ooooo`Co00005oooool00omEEEGoIVIVo`00
0004ooooo`07onk^k_lb<S;o0000oc8b<_o^k^koooooo`00000Booooo`03oeEEEOmVIVKo000000Co
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c00<ooooo`Co000000?oooooo`000?ooool04?ooool00omE
EEGoIVIVo`000005ooooo`Co00004oooool00omEEEGoIVIVo`000004ooooo`Go00003?ooool4o`00
02Gooooo000Qooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0<Oooool00ol0003o
ooooooooo`0/ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0;Oooool00ol0003o
ooooooooo`0`ooooo`03o`000?oooooooooo03cooooo000Qooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo03cooooo
000Qooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0<?ooool00ol0003ooooooooo
o`0]ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0;Oooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo03;ooooo0_l00002ooooo`;o00001?ooool0027ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02gooooo00?o0000
ooooooooool0<?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02oooooo00?o0000
ooooooooool0<oooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@Cooooo000Joooooooo0000>_l0
000<ooooo`04omgMgOl0003o410@olc<c0Gooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01?ooool2o`0000Oooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`;o00001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Co
0000oooooooooooo00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool00oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0?ooooo`04onk^k_lQ8B7o410@onk^kPGooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01?ooool2o`0000Oooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`;o00001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0?ooooo`04ob4Q8OmgMgOoMgMgoc8b<PGooooo000Qooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02ko
oooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo03?o
oooo0_l00002ooooo`;o00001?ooool0027ooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0^ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`0_ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0?Oooool0027ooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo033ooooo00?o
0000ooooooooool0;_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02gooooo00?o
0000ooooooooool0?_ooool0027ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0]
ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0a
ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0?_ooool0027ooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo033ooooo00?o0000oooo
ooooool0;Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo02cooooo00?o0000oooo
ooooool0?_ooool0027ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0]ooooo`03
o`000?oooooooooo033ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0aooooo`03
o`000?oooooooooo02cooooo00?o0000ooooooooool0?_ooool0027ooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
;?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0
?_ooool0027ooooo0ol0000>ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0<Ooo
ool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0:ooo
ool00ol0003oooooooooo`0oooooo`008Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo02_ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooo
oooo037ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0oooooo`008Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0<_ooool00ol0
003oooooooooo`0[ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0:_ooool00ol0
003oooooooooo`0oooooo`008Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02_o
oooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo03?o
oooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0oooooo`008Oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0<_ooool00ol0003ooooo
ooooo`0[ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0:_ooool00ol0003ooooo
ooooo`0oooooo`008Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02[ooooo00?o
0000ooooooooool0<_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo03?ooooo00?o
0000ooooooooool0:_ooool00ol0003oooooooooo`0oooooo`008Oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Z
ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`10
ooooo`008Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool0=?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03Cooooo00?o0000oooo
ooooool0:?ooool00ol0003oooooooooo`10ooooo`008Oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo03Gooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`10ooooo`00
8Oooool3o`00013ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo02Wooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Xooooo`03o`00
0?oooooooooo043ooooo000Qooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0:?oo
ool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0=Ooo
ool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo043ooooo000Qooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooo
oooo02Wooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo043ooooo000Qooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`0fooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0=Oooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo047ooooo000Qooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo02So
oooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo047o
oooo000Qooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`0fooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0=oooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo047ooooo000Qooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool0=oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo047ooooo000Q
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0f
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo047ooooo000Qooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool0=oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo04;ooooo000Qooooo`?o
00004Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool0@_ooool0027ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo03Sooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0iooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool0@_ooool0027ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0@_oo
ool0027ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo
oooo03Sooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool0@_ooool0027ooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0Sooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`0iooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0@_ooool0027o
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03[o
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02?o
oooo00?o0000ooooooooool0@oooool0027ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Sooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool08oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0@oooool0027ooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03[ooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02;ooooo00?o
0000ooooooooool0@oooool0027ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0R
ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0@oooool0027ooooo0ol0000Coooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`13oooo
o`008Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool0??ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`14ooooo`008Oooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo03gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`14ooooo`008Ooo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0??oo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool08?oo
ool00ol0003oooooooooo`14ooooo`008Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo03gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`14ooooo`008Oooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0?Oooool00ol0
003oooooooooo`0Qooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`14ooooo`008Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03go
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`15ooooo`001oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0?_ooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`15ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo03kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0ooooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool0AOooool000Oooooo00Go410@oooooooo
oooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo0ol0000Eooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
03oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`15ooooo`001oooool01Ol0003o
oooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo03oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`15oooo
o`001oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c004
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`10
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo04Kooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`10ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0@?ooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04Kooooo0007ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool0@Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo04Kooooo0007oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`11ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0A_ooool0
027ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
047ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool0Aoooool0027ooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`11ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0Aoooool0027ooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo04;ooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool0Aoooool0027ooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`13ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0Aoooool0027ooooo0ol0000G
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`17
ooooo`008Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool0A?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04?ooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`18ooooo`008Oooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo04?ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`18ooooo`00
8Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
A?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`18ooooo`008Oooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo04Cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`18ooooo`008Oooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0AOooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`18ooooo`008Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
04Gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`19ooooo`008Oooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0A_ooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`19ooooo`008Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Kooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`19ooooo`008Oooool3o`0001Wooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool0A_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Wooooo000Q
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`17
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo04[ooooo000Qooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool0Aoooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04[ooooo000Qooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`18ooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo04[ooooo000Qooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
B?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04[ooooo000Qooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1:ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo04_ooooo000Qooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`1:ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0BOooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04_ooooo000Qooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
04_ooooo000Qooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`1:ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0Boooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo04_ooooo000Qooooo`?o00006oooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`1;ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0C?ooool0027ooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04cooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool0C?ooool0027ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1=
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0C?ooool0027ooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04kooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0COooool0027ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo04kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1>ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0COooool0027ooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
COooool0027ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo053ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1@ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool0C_ooool0027ooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`1Aooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0C_ooool0
027ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
053ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool0C_ooool0027ooooo0ol0000Nooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05?o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1?ooooo`008Oooool00ol0003ooooo
ooooo`0Nooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0D_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`1?ooooo`008Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool0Doooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo05Cooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`1?ooooo`008Oooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1@
ooooo`008Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool0EOooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05Kooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`1@ooooo`008Oooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo05Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Aooooo`00
8Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
F?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`1Aooooo`006?ooool4o`000003oa0@4?oooooooooo00;ooooo00?o
0000ooooooooool08_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05Wooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0D_ooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0R
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0F_ooool2o`0000Cooooo00?o0000
ooooooooool0Foooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05?ooooo000Joooo
o`03o`000?oooooooooo00Cooooo0ol0000Sooooo`Go0000G_ooool5o`0005kooooo1Ol0001Foooo
o`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001Sooooo00?oEEEEofIVI_l000001_ooool00ol0
003oooooooooo`3oooooodGooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo002Looooo`;o0000?oooool2o`0008Wooooo
002Looooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0Qoooool008Wooooo0ol00002
ooooo`06oc8b<_l@413oooooooooooo^k^koEEEE0_l000000om4A4Co^[Zjooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00Kok^k^ofIVI_l0003o0000oc8b<_nj^[Xgooooo`03o`000?oooooooooo
08Oooooo002:ooooo`05o`000?ooooooooooolc<c?l@41000oooool01_mEEEGoMgMgooooooo^k^ko
MgMgoa0@40Cooooo00?o0000ooooooooool00_ooool2ogMgM`04oeEEEOn7QhOogMgModA4A3Oooooo
00?o0000ooooooooool0Qoooool008[ooooo00Go0000ooooooooooooEEEEohN7Q`03ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool00_ooool00onHV9Soooooo`00000jooooo`03o`00
0?oooooooooo08Oooooo002:ooooo`05o`000?oooooogMgMo`000?o^k^h00oooool6o`0000Cooooo
00?o0000ooooooooool00_ooool00onHV9Soooooo`000003o`0001;ooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo08Oooooo002:ooooo`?o000000?o
410@oiRHV?ooool00_ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<PCooooo00?o0000oooooooo
ool00_ooool00omgMgOoQhN7ofIVIP02okZj^P03oc8b<_oooooooooo00oooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo08Oooooo002:ooooo`05o`00
0?ooooooooooolc<c?l000000oooool01_o^k^koEEEEo`000?l0003oA4A4onk^kPCooooo00?o0000
ooooooooool00oooool01_mVIVKo0000o`000?m4A4Cok^k^ooooo`?o00001?ooool2o`000003oooo
ool0003o000000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooo`00000:ooooo`?o0000
1_ooool2o`0000Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`27ooooo`00R_oo
ool01Ol0003oooooooooooo<c<co000000gooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooo000000Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo08Oooooo0029ooooo`Co000000?o410@ojVYZOooool03?oo
ool2o`0000_ooooo00?o0000ooooooooool01?ooool2o`0000Gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`02ooooo`Co00000_ooool01?l0003oooooooooool00005ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool2o`0008Wooooo002Yooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooool000001?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooo000000[ooooo0ol00004ooooo`Co00001?ooool00ol0003oooooooooo`2=ooooo`00Z?ooool2
o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0S_ooool00:oooooo0_l00008ooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool0Soooool00:Wooooo00?o0000ooooooooool0_?ooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-2, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0505254 0.309017 0.294302 [
[.15012 .29652 -9 -9 ]
[.15012 .29652 9 0 ]
[.27644 .29652 -3 -9 ]
[.27644 .29652 3 0 ]
[.40275 .29652 -9 -9 ]
[.40275 .29652 9 0 ]
[.52906 .29652 -6 -9 ]
[.52906 .29652 6 0 ]
[.65538 .29652 -12 -9 ]
[.65538 .29652 12 0 ]
[.78169 .29652 -6 -9 ]
[.78169 .29652 6 0 ]
[.908 .29652 -12 -9 ]
[.908 .29652 12 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .01472 -12 -4.5 ]
[.01131 .01472 0 4.5 ]
[.01131 .16187 -24 -4.5 ]
[.01131 .16187 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[.5 .63053 -37.9062 0 ]
[.5 .63053 37.9062 12.625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15012 .30902 m
.15012 .31527 L
s
[(2.5)] .15012 .29652 0 1 Mshowa
.27644 .30902 m
.27644 .31527 L
s
[(5)] .27644 .29652 0 1 Mshowa
.40275 .30902 m
.40275 .31527 L
s
[(7.5)] .40275 .29652 0 1 Mshowa
.52906 .30902 m
.52906 .31527 L
s
[(10)] .52906 .29652 0 1 Mshowa
.65538 .30902 m
.65538 .31527 L
s
[(12.5)] .65538 .29652 0 1 Mshowa
.78169 .30902 m
.78169 .31527 L
s
[(15)] .78169 .29652 0 1 Mshowa
.908 .30902 m
.908 .31527 L
s
[(17.5)] .908 .29652 0 1 Mshowa
.125 Mabswid
.04907 .30902 m
.04907 .31277 L
s
.07433 .30902 m
.07433 .31277 L
s
.0996 .30902 m
.0996 .31277 L
s
.12486 .30902 m
.12486 .31277 L
s
.17539 .30902 m
.17539 .31277 L
s
.20065 .30902 m
.20065 .31277 L
s
.22591 .30902 m
.22591 .31277 L
s
.25117 .30902 m
.25117 .31277 L
s
.3017 .30902 m
.3017 .31277 L
s
.32696 .30902 m
.32696 .31277 L
s
.35222 .30902 m
.35222 .31277 L
s
.37749 .30902 m
.37749 .31277 L
s
.42801 .30902 m
.42801 .31277 L
s
.45328 .30902 m
.45328 .31277 L
s
.47854 .30902 m
.47854 .31277 L
s
.5038 .30902 m
.5038 .31277 L
s
.55433 .30902 m
.55433 .31277 L
s
.57959 .30902 m
.57959 .31277 L
s
.60485 .30902 m
.60485 .31277 L
s
.63011 .30902 m
.63011 .31277 L
s
.68064 .30902 m
.68064 .31277 L
s
.7059 .30902 m
.7059 .31277 L
s
.73116 .30902 m
.73116 .31277 L
s
.75643 .30902 m
.75643 .31277 L
s
.80695 .30902 m
.80695 .31277 L
s
.83222 .30902 m
.83222 .31277 L
s
.85748 .30902 m
.85748 .31277 L
s
.88274 .30902 m
.88274 .31277 L
s
.93327 .30902 m
.93327 .31277 L
s
.95853 .30902 m
.95853 .31277 L
s
.98379 .30902 m
.98379 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01472 m
.03006 .01472 L
s
[(-1)] .01131 .01472 1 0 Mshowa
.02381 .16187 m
.03006 .16187 L
s
[(-0.5)] .01131 .16187 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(0.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .13244 m
.02756 .13244 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -98.9062 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.625 moveto
(@) show
81.000 13.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\343) show
87.000 9.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344) show
93.000 9.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
97.188 9.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
( ) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
99.000 9.625 moveto
(H) show
103.188 9.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
107.375 9.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
113.375 9.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
119.375 9.625 moveto
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
123.562 9.625 moveto
(L) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
128.812 13.625 moveto
(D) show
134.812 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.02499 .01479 L
.02605 .01501 L
.02729 .01541 L
.02846 .01596 L
.03053 .01732 L
.03279 .01935 L
.03527 .02225 L
.0379 .02608 L
.04262 .03487 L
.05205 .05951 L
.06244 .09665 L
.0842 .20107 L
.10458 .3172 L
.12312 .42219 L
.14335 .51915 L
.15431 .55857 L
.15965 .57362 L
.16449 .58473 L
.16689 .58932 L
.16949 .59356 L
.17174 .59662 L
.17421 .59933 L
.17684 .60145 L
.17827 .60227 L
.17896 .60258 L
.17961 .60282 L
.18086 .60316 L
.18201 .6033 L
.18324 .60329 L
.18393 .60321 L
.18458 .60308 L
.18575 .60272 L
.18699 .60218 L
.18805 .60157 L
.18921 .60076 L
.1918 .59839 L
.1942 .59551 L
.19857 .58863 L
.20324 .57896 L
.21403 .54797 L
.22384 .51034 L
.26382 .29784 L
.28214 .19427 L
.29255 .14125 L
.30229 .09804 L
.31268 .0606 L
.32217 .0355 L
.32466 .03048 L
.32737 .02578 L
Mistroke
.32996 .02205 L
.33231 .01933 L
.33505 .01694 L
.33655 .016 L
.33724 .01565 L
.33797 .01534 L
.33928 .01494 L
.34049 .01475 L
.34179 .01473 L
.34252 .01481 L
.34321 .01493 L
.34448 .01531 L
.34512 .01557 L
.34582 .01591 L
.34823 .0175 L
.34959 .01869 L
.35105 .02021 L
.35369 .02356 L
.35886 .03238 L
.3636 .043 L
.37265 .06969 L
.38217 .10599 L
.42033 .30725 L
.44162 .42778 L
.46094 .51968 L
.47061 .55491 L
.47569 .56991 L
.48107 .5829 L
.48578 .59173 L
.48827 .59542 L
.49095 .59861 L
.49221 .59983 L
.4934 .60082 L
.49457 .60162 L
.49565 .60223 L
.49667 .60268 L
.49775 .60303 L
.49884 .60324 L
.50004 .60332 L
.50125 .60323 L
.50238 .60299 L
.50362 .60256 L
.50432 .60225 L
.50495 .60191 L
.50761 .59999 L
.51012 .59744 L
.51455 .59119 L
.51936 .58197 L
.52463 .56904 L
.53021 .55227 L
Mistroke
.54021 .51493 L
.57807 .31658 L
.59912 .19685 L
.61837 .1037 L
.62789 .06787 L
.63291 .05231 L
.63827 .03852 L
.64341 .02814 L
.64807 .02124 L
.65032 .01878 L
.65151 .01772 L
.65276 .01677 L
.65385 .01609 L
.65505 .01549 L
.65615 .0151 L
.65717 .01486 L
.65843 .01472 L
.65907 .01472 L
.65977 .01478 L
.66101 .01502 L
.66218 .0154 L
.66285 .01569 L
.66355 .01605 L
.6648 .01684 L
.66763 .01927 L
.67008 .02211 L
.67236 .02536 L
.67753 .03486 L
.68651 .05809 L
.6961 .09159 L
.71746 .19211 L
.73761 .30621 L
.75594 .41084 L
.76636 .4652 L
.7761 .51009 L
.7865 .54976 L
.79599 .57714 L
.8012 .58821 L
.80614 .59596 L
.80885 .59905 L
.81135 .60117 L
.8128 .60207 L
.81411 .60267 L
.81483 .60292 L
.81562 .60312 L
.81636 .60325 L
.81704 .60331 L
.81831 .60328 L
.81951 .60308 L
.82059 .60276 L
Mistroke
.82176 .60226 L
.82303 .60153 L
.82438 .60056 L
.82681 .5983 L
.83114 .5926 L
.83591 .58391 L
.84106 .5718 L
.84659 .55574 L
.8566 .51935 L
.87772 .41766 L
.89781 .30329 L
.91783 .19016 L
.93599 .10306 L
.94601 .06569 L
.95544 .03918 L
.96063 .02856 L
.96541 .02139 L
.96791 .01866 L
.96934 .01741 L
.97065 .01648 L
.97203 .01571 L
.97274 .0154 L
.97352 .01513 L
.97423 .01494 L
.97489 .01481 L
.97619 .01472 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  FontSlant->"Italic",
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool001So
oooo1?l000000ol@413oooooooooo`02ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000?ooooo`Ko00001Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000
ooooooooool01?ooool4o`0005kooooo1Ol0001Nooooo`Go0000G_ooool3o`0001cooooo000Joooo
o`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo0000GOooool00ol0003oooooooooo`02
ooooo`;o0000G?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05_ooooo00?o0000
ooooooooool07Oooool001[ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo
000005_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Nooooo`006_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Eoooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1Hooooo`03o`000?oooooooooo01kooooo000Hooooo`03oeEEEOmVIVKo000000Ko
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05Oo
oooo00?o0000ooooooooool07oooool0027ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`1Eooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0E_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool07oooool0027ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool0EOooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo05Cooooo00?o
0000ooooooooool08?ooool0027ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1E
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool08Oooool0027ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool0Doooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05?ooooo00?o0000oooo
ooooool08Oooool0027ooooo0ol00004ooooo`03o`000?oooooooooo05?ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool0DOooool00ol0003oooooooooo`0Rooooo`008Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo05?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Aooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`0Rooooo`008Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0DOoo
ool00ol0003oooooooooo`0Rooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo057ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0Sooooo`008Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`1?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0Coooool00ol0
003oooooooooo`0Sooooo`008Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04oo
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0Sooooo`008Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`1?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0C_ooool00ol0003ooooo
ooooo`0Tooooo`008Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04kooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool0COooool00ol0003oooooooooo`0Tooooo`008Oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1=
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0T
ooooo`008Oooool3o`0000Oooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo04gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1=oooo
o`03o`000?oooooooooo02Cooooo000Qooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0C?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04cooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo02Gooooo000Qooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo04_ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1;ooooo`03o`00
0?oooooooooo02Gooooo000Qooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0Booo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo02Gooooo000Qooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo04[ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1:ooooo`03o`000?oooooo
oooo02Kooooo000Qooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0B_ooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`19ooooo`03o`000?oooooooooo02Kooooo000Qooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04Wo
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo02Ko
oooo000Qooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0B?ooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`19ooooo`03o`000?oooooooooo02Kooooo000Qooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool0B?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04Sooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo02Oooooo000Q
ooooo`?o00002Oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool0Aoooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Oooooo00?o0000
ooooooooool09oooool0027ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`17oooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo04Oooooo00?o0000ooooooooool09oooool0027ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool0Aoooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Oooooo00?o0000oooooooo
ool09oooool0027ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`16ooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo04Oooooo00?o0000ooooooooool09oooool0027ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0A_oo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0:?oo
ool0027ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`16ooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo04Gooooo00?o0000ooooooooool0:?ooool0027ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`14ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0AOooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0:?ooool0027o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04Go
oooo00?o0000ooooooooool0:?ooool0027ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`14ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0A?ooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0:?ooool0027ooooo0ol0
000;ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`14ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0@oooool00ol0003ooooooooo
o`0Yooooo`008Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo04Cooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool0@oooool00ol0003oooooooooo`0Yooooo`008Oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo04;ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`13oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Yoooo
o`008Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo04;ooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool0@oooool00ol0003oooooooooo`0Yooooo`008Oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo04;ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`12ooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0Yooooo`008Ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0@Ooo
ool00ol0003oooooooooo`0Zooooo`008Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo047ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0Zooooo`001oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0@Ooo
ool00ol0003oooooooooo`0Zooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`10ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0@Oooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0:_ooool000Go00000_ooool0
1Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`10ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0@?ooool00ol0003ooooooooo
o`0Zooooo`001oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00ooo
ool3o`0000gooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo043ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`10ooooo`03o`000?oo
oooooooo02[ooooo0007ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0oooooo`03o`00
0?oooooooooo01kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo03oooooo00?o0000ooooooooool0:oooool000Oooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0nooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0?oooool00ol0003ooooo
ooooo`0Nooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0:oooool000Oooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0
?oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0
:oooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`0nooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0?_ooool00ol0003ooooo
ooooo`0[ooooo`008Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03kooooo00?o
0000ooooooooool07oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool0?_ooool00ol0003oooooooooo`0[ooooo`008Oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0n
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0/
ooooo`008Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03gooooo00?o0000oooo
ooooool08?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool0?Oooool00ol0003oooooooooo`0/ooooo`008Oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo03cooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0mooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0/ooooo`00
8Oooool3o`0000oooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo03cooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0looooo`03o`00
0?oooooooooo02cooooo000Qooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0??oo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool08_oo
ool00ol0003oooooooooo`0looooo`03o`000?oooooooooo02cooooo000Qooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo03cooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0looooo`03o`000?oooooo
oooo02cooooo000Qooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`0Rooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool08_ooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo02gooooo000Qooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo02go
oooo000Qooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0>_ooool00ol0003ooooo
ooooo`0Sooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`0jooooo`03o`000?oooooooooo02gooooo000Qooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool0>_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03[ooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo02gooooo000Q
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0S
ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0j
ooooo`03o`000?oooooooooo02gooooo000Qooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool0>Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo03Wooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02kooooo000Qooooo`?o
00004Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool0>Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo03Wooooo00?o0000oooooooo
ool0;_ooool0027ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0hooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo03Sooooo00?o0000ooooooooool0;_ooool0027ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0;_oo
ool0027ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo03Sooooo00?o0000ooooooooool0;_ooool0027ooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0gooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0;oooool0027o
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo03Oo
oooo00?o0000ooooooooool0;oooool0027ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0fooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0=oooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0;oooool0027ooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool0=_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo03Kooooo00?o
0000ooooooooool0;oooool0027ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0e
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0;oooool0027ooooo0ol0000Coooo
o`03o`000?oooooooooo03Gooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0foooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0`oooo
o`008Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo03Gooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02Sooooo00?o0000oooooooo
ool0=Oooool00ol0003oooooooooo`0`ooooo`008Oooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo03Gooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0eooooo`03o`00
0?oooooooooo02Sooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0`ooooo`008Ooo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0=Ooo
ool00ol0003oooooooooo`0`ooooo`008Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo03?ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooo
oooo02[ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0`ooooo`008Oooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`0dooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0<oooool00ol0
003oooooooooo`0aooooo`008Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00?o
oooo1Ol00005ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01[ooooo0ol000000olb
<S;ogMgMooooo`0Kooooo`03o`000?o^k^kooooo00Gooooo0_lQ8B42ooooo`04o`000?oooooooooo
odA4A0;o000000?o<S8bomgMgOooool05Oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000
oc8b<_o^k^h<ooooo`03o`000?oooooooooo00Gooooo1?l000000ol@413oooooooooo`05o`0000Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd02?ooool00ol0003oooooooooo`07oooo
o`Co000000Go410@ooooooooooooooooodA4A002o`000003oc8b<_oMgMgooooo017ooooo1?l00000
0ol@413oooooooooo`02ooooo`05o`000?o^k^koooooooooool000000oooool2ob4Q8@Gooooo00Go
A4A4o`000?l0003o<S8bomgMg@0Tooooo`008Oooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo00?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`;o8B4Q2?ooool00omgMgOo<S8b
ooooo`0Iooooo`05o`000?ooooooooooogMgMolb<S807?ooool00omEEEGoZJVYooooo`05ooooo`;o
8B4Q0_ooool00ol0003oooooooooo`03ooooo`03ogMgMolb<S;ooooo01Oooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`02ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool01oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Kooooo00?oMgMg
oc8b<_ooool04oooool00ol0003oooooooooo`04ooooo`05oeEEEOnYZJWoooooooooool000000ooo
ool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool08oooool0027ooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`04ooooo`03oiRHV?lQ8B7ok^k^017ooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo01[ooooo00?oZJVYoeEEEOooool02Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@00_ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`03ooooo`03oiRHV?lQ8B7ok^k^017ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`04ooooo`05ojVYZOmEEEGoooooooooool000003_ooool00ol0003oooooooooo`0Rooooo`008Ooo
ool3o`0001Gooooo00?o0000ooooooooool01?ooool00onHV9So8B4Qonk^kP0?ooooo`03ogMgMolb
<S;ooooo01Sooooo00Ko0000ooooooooooooooooogMgMolb<S8Mooooo`03ob4Q8Ooooooooooo00So
oooo00?o0000ooooooooool00oooool00omgMgOo<S8booooo`0Gooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`00000;ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool01?ooool00onHV9So8B4Qonk^kP0?ooooo`03ogMgMolb<S;ooooo00Oooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo01?ooooo00?o0000oooo
ooooool01Oooool01?lQ8B7oooooooooool0000=ooooo`03ogMgMolb<S;ooooo02?ooooo000Qoooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01Oooool00omgMgOoIVIVooooo`0;oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`06Oooool2o`000004ob4Q8Ol0003o<S8bolc<c1gooooo00?o
EEEEolc<c?ooool02?ooool02?l0003oooooooooool0003o8B4Qo`000?lb<S;oc<c<6?ooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Gooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`03ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`05?ooool00ol0003oooooooooo`05ooooo`03oeEEEOo<c<co000000_ooooo
00Go0000ob4Q8Ol0003o<S8bolc<c00Tooooo`008Oooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Kooooo`;o0000
8Oooool00onYZJWoMgMgooooo`09ooooo`03o`000?oooooo000001cooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@00_ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`05ooooo`03ojVYZOmgMgOo000000_ooooo00?o0000ooooooooool09_ooool0027ooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`02ooooo`05o`000?nj^[[ooooooiRHV?l@
41003?ooool00ol0003oooooooooo`0Kooooo`;o00007_ooool01Ol@413ooooooooooooooooo<S8b
00[ooooo00?o0000ooooool000007?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00Go0000
okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool00_oo
ool01_l@413ooooooooooooooooo<S8bo`0000_ooooo00?o0000ooooooooool09_ooool0027ooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`02ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`03?ooool4o`0001Wooooo00?o0000ooooool000000ol0000Kooooo`Go00002_ooool00ol0003o
ooooo`000003o`0001Oooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00_ooooo00?o0000ooooooooool01_ooool00omEEEGoIVIVo`000004ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`03?ooool4o`0000[ooooo00?o0000ooooooooool01_ooool00omEEEGoIVIVo`000005
ooooo`Co00004oooool00omEEEGoIVIVo`000004ooooo`Ko00002oooool4o`0002Gooooo000Qoooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0]oooo
o`03o`000?oooooooooo033ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0aoooo
o`03o`000?oooooooooo03;ooooo000Qooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool0;oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo033ooooo00?o0000oooooooo
ool0;Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo03?ooooo000Qooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0^ooooo`03o`00
0?oooooooooo02oooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0_ooooo`03o`00
0?oooooooooo02Wooooo0_l00002ooooo`;o00001?ooool0027ooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0;ooo
ool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0:Ooo
ool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@Cooooo000Joooooooo0000>_l0000<ooooo`04omgM
gOl0003o410@olc<c0Gooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo0_l00007oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooo`000005oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo
000000;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool03oooool01?o^k^ko8B4Qoa0@4?o^k^h5ooooo`008Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooo`000005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool0
1?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`04ooooo`;o00001oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00oo
oooo00Co8B4QogMgMomgMgOo<S8b1Oooool0027ooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`0]ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0;_ooool00ol0003o
ooooooooo`0_ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0:_ooool2o`0000;o
oooo0_l00004ooooo`008Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02gooooo
00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0dooooo`008Oooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0<?ooool00ol0003ooooooooo
o`0]ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0;Oooool00ol0003ooooooooo
o`0dooooo`008Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02cooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo033ooooo00?o0000
ooooooooool0;Oooool00ol0003oooooooooo`0dooooo`008Oooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0/oooo
o`03o`000?oooooooooo037ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0doooo
o`008Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02_ooooo00?o0000oooooooo
ool0<Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo037ooooo00?o0000oooooooo
ool0;Oooool00ol0003oooooooooo`0dooooo`008Oooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo02_ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0[ooooo`03o`00
0?oooooooooo03;ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0eooooo`008Ooo
ool3o`0001Sooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0booooo`03o`000?oo
oooooooo02_ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo03Gooooo000Qooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0:oooool0
0ol0003oooooooooo`0booooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0<_ooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo03Gooooo000Qooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo
02[ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
03Gooooo000Qooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0:_ooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0<oooool00ol0003o
ooooooooo`0[ooooo`03o`000?oooooooooo03Gooooo000Qooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02[ooooo
00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03Gooooo
000Qooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo03Kooooo000Qooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool0:Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool0=?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo03Kooooo000Qoooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0eoooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Yoooo
o`03o`000?oooooooooo03Kooooo000Qooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02Sooooo00?o0000oooooooo
ool0=Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo03Kooooo000Qooooo`?o0000
6Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0
:?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0
=_ooool0027ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0fooooo`03o`000?oo
oooooooo02Oooooo00?o0000ooooooooool0=oooool0027ooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool09oooool0
0ol0003oooooooooo`0fooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0=oooool0
027ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
03Kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool0=oooool0027ooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool09oooool00ol0003o
ooooooooo`0fooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0=oooool0027ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo03Oooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool0=oooool0027ooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0hooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0=oooool0027ooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo03Sooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0>?ooool0027ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo03Sooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?ooool0027ooooo0ol0000Kooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo03Sooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hooooo`00
8Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
>Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0hooooo`008Oooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo03[ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0hooooo`008Oooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`0hooooo`008Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
03[ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0iooooo`008Oooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0>_ooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`0iooooo`008Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03[ooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`0iooooo`008Oooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool08oooool00ol0003ooooooooo
o`0iooooo`008Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02;ooooo00?o0000
ooooooooool0??ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03cooooo00?o0000
ooooooooool08_ooool00ol0003oooooooooo`0iooooo`008Oooool3o`0001cooooo00?o0000oooo
ooooool08_ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool0??ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03[ooooo000Qooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0looooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo03[ooooo000Qooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
8?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
??ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03[ooooo000Qooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0mooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo03[ooooo000Qooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`0nooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0?_ooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03[ooooo000Qooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
03_ooooo000Qooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`0nooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0?_ooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo03_ooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
03_ooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool00oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool0?oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03kooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`0kooooo`001oooool01Ol@413ooooooooooooooooo410@
013ooooo00?o0000ooooooooool00_ooool3o`0001kooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`10ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0?oooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo03cooooo0007ooooo`05o`000?oooooooooooooo
ool000003oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool0@?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo03cooooo0007ooooo`05
o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo043ooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool0??ooool000Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo043ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`10ooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool0??ooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`10
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0??ooool000Oooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo043ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0mooooo`008Oooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0@_ooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`0mooooo`008Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo04;o
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0mooooo`008Oooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0@_ooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`0mooooo`008Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool0@oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04;ooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`0mooooo`008Oooool3o`00027ooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool0@_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo03kooooo000Qoooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`14oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo03kooooo000Qooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool0A?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo03kooooo000Qooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`14ooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo03kooooo000Qooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0A?oo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo03oooooo000Qooooo`03o`000?oooooo
oooo02;ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`16ooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo03oooooo000Qooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`16ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0AOooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo03oooooo000Qooooo`03o`000?oooooooooo02;o
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo03oo
oooo000Qooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`16ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0A_ooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo03oooooo000Qooooo`?o00008oooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`16ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0@?ooool0027ooooo00?o0000
ooooooooool08oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04Sooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool0@?ooool0027ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo04Sooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`17oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0@?ooool0027ooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04Sooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0@?ooool0027ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo04Wooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`19ooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool0@Oooool0027ooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0@Ooo
ool0027ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo04[ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1:ooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool0@Oooool0027ooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`1;ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0@Oooool0027o
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo04_o
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool0@_ooool0027ooooo0ol0000Uooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo04_ooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`12ooooo`008Oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0C?ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`12ooooo`008Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool0COooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04gooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`12ooooo`008Oooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo04gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`13oooo
o`008Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0C_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04kooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`13ooooo`008Oooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo04oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`13ooooo`008Ooo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0D?oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`13ooooo`008Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo053ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`14ooooo`008Oooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0DOooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`14ooooo`008Oooool3o`0002Sooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`1Aooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0DOooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo04Cooooo000Qooooo`03o`000?oooooooooo02Sooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0D_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo04Cooooo
000Qooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`1Cooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0D_ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo04Gooooo000Qooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0E?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo04Kooooo000Qoooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Eoooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo04Kooooo000Qooooo`03o`000?oooooooooo02[ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0E_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04Oooooo000Qooooo`03o`00
0?oooooooooo02_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Gooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo04Sooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003ooooooooo
o`0/ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0F?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`18ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`1Jooooo`;o00000oooool2o`0005gooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`19ooooo`006_ooool00ol0003oooooooooo`04oooo
o`?o0000;Oooool5o`0005kooooo1Ol0001Nooooo`Go0000C?ooool001[ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3o
ooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool0oooooom5oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00W?ooool2o`0003oooooo0_l00029ooooo`00W?ooool00ol0003ooooooooo
o`0oooooo`03o`000?oooooooooo08Oooooo0029ooooo`?o00000_ooool01_lb<S;o410@oooooooo
ooook^k^oeEEE@;o000000?oA4A4okZj^_ooool00oooool00ol0003oooooooooo`02ooooo`06onk^
k_mVIVKo0000o`000?lb<S;o^[Zj=oooool00ol0003oooooooooo`27ooooo`00R_ooool01Ol0003o
ooooooooooo<c<co410@00?ooooo00KoEEEEogMgMoooooook^k^ogMgMol@4104ooooo`03o`000?oo
oooooooo00;ooooo0_mgMgL01?mEEEGoQhN7omgMgOm4A4@gooooo`03o`000?oooooooooo08Oooooo
002:ooooo`05o`000?oooooooooooeEEEOn7QhL00oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00;ooooo00?oV9RHooooool00000>_ooool00ol0003oooooooooo`27ooooo`00R_oo
ool01Ol0003oooooomgMgOl0003ok^k^00?ooooo1_l00004ooooo`03o`000?oooooooooo00;ooooo
00?oV9RHooooool000000ol0000Booooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`27ooooo`00R_ooool3o`000003oa0@4?nHV9Sooooo00;ooooo00Ko
EEEEohN7Qoo^k^koooooohN7Qolb<S84ooooo`03o`000?oooooooooo00;ooooo00?oMgMgohN7QomV
IVH00_nj^[X00olb<S;oooooooooo`0?ooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`27ooooo`00R_ooool01Ol0003oooooooooooo<c<co000000?o
oooo00Kok^k^oeEEEOl0003o0000odA4A?o^k^h4ooooo`03o`000?oooooooooo00?ooooo00KoIVIV
o`000?l0003oA4A4onk^k_ooool3o`0000Cooooo0_l000000ooooooo0000o`000003ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooool000002_ooool3o`0000Kooooo0_l00004ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0Qoooool008[ooooo00Go0000ooooooooooooc<c<
o`00000=ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
o`000004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`27ooooo`00ROooool4o`000003oa0@4?nYZJWooooo00cooooo0_l0000;ooooo`03o`000?oo
oooooooo00Cooooo0_l00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oo
ool4o`0000;ooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00;ooooo0_l00029ooooo`00ZOooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooo000000Cooooo00?o0000ooooooooool00_ooool00ol0003oooooo`00000:ooooo`?o00001?oo
ool4o`0000Cooooo00?o0000ooooooooool0SOooool00:Sooooo0_l00006ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo08kooooo002_ooooo`;o00002?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
08oooooo002Yooooo`03o`000?oooooooooo0;cooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-2, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0505254 0.309017 0.294302 [
[.15012 .29652 -9 -9 ]
[.15012 .29652 9 0 ]
[.27644 .29652 -3 -9 ]
[.27644 .29652 3 0 ]
[.40275 .29652 -9 -9 ]
[.40275 .29652 9 0 ]
[.52906 .29652 -6 -9 ]
[.52906 .29652 6 0 ]
[.65538 .29652 -12 -9 ]
[.65538 .29652 12 0 ]
[.78169 .29652 -6 -9 ]
[.78169 .29652 6 0 ]
[.908 .29652 -12 -9 ]
[.908 .29652 12 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .01471 -12 -4.5 ]
[.01131 .01471 0 4.5 ]
[.01131 .16187 -24 -4.5 ]
[.01131 .16187 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[.5 .63053 -37.9062 0 ]
[.5 .63053 37.9062 12.625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15012 .30902 m
.15012 .31527 L
s
[(2.5)] .15012 .29652 0 1 Mshowa
.27644 .30902 m
.27644 .31527 L
s
[(5)] .27644 .29652 0 1 Mshowa
.40275 .30902 m
.40275 .31527 L
s
[(7.5)] .40275 .29652 0 1 Mshowa
.52906 .30902 m
.52906 .31527 L
s
[(10)] .52906 .29652 0 1 Mshowa
.65538 .30902 m
.65538 .31527 L
s
[(12.5)] .65538 .29652 0 1 Mshowa
.78169 .30902 m
.78169 .31527 L
s
[(15)] .78169 .29652 0 1 Mshowa
.908 .30902 m
.908 .31527 L
s
[(17.5)] .908 .29652 0 1 Mshowa
.125 Mabswid
.04907 .30902 m
.04907 .31277 L
s
.07433 .30902 m
.07433 .31277 L
s
.0996 .30902 m
.0996 .31277 L
s
.12486 .30902 m
.12486 .31277 L
s
.17539 .30902 m
.17539 .31277 L
s
.20065 .30902 m
.20065 .31277 L
s
.22591 .30902 m
.22591 .31277 L
s
.25117 .30902 m
.25117 .31277 L
s
.3017 .30902 m
.3017 .31277 L
s
.32696 .30902 m
.32696 .31277 L
s
.35222 .30902 m
.35222 .31277 L
s
.37749 .30902 m
.37749 .31277 L
s
.42801 .30902 m
.42801 .31277 L
s
.45328 .30902 m
.45328 .31277 L
s
.47854 .30902 m
.47854 .31277 L
s
.5038 .30902 m
.5038 .31277 L
s
.55433 .30902 m
.55433 .31277 L
s
.57959 .30902 m
.57959 .31277 L
s
.60485 .30902 m
.60485 .31277 L
s
.63011 .30902 m
.63011 .31277 L
s
.68064 .30902 m
.68064 .31277 L
s
.7059 .30902 m
.7059 .31277 L
s
.73116 .30902 m
.73116 .31277 L
s
.75643 .30902 m
.75643 .31277 L
s
.80695 .30902 m
.80695 .31277 L
s
.83222 .30902 m
.83222 .31277 L
s
.85748 .30902 m
.85748 .31277 L
s
.88274 .30902 m
.88274 .31277 L
s
.93327 .30902 m
.93327 .31277 L
s
.95853 .30902 m
.95853 .31277 L
s
.98379 .30902 m
.98379 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01471 m
.03006 .01471 L
s
[(-1)] .01131 .01471 1 0 Mshowa
.02381 .16187 m
.03006 .16187 L
s
[(-0.5)] .01131 .16187 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(0.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04414 m
.02756 .04414 L
s
.02381 .07357 m
.02756 .07357 L
s
.02381 .103 m
.02756 .103 L
s
.02381 .13244 m
.02756 .13244 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -98.9062 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.625 moveto
(@) show
81.000 13.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\343) show
87.000 9.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344) show
93.000 9.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
97.188 9.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
( ) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
99.000 9.625 moveto
(H) show
103.188 9.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
107.375 9.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
113.375 9.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
119.375 9.625 moveto
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
123.562 9.625 moveto
(L) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
128.812 13.625 moveto
(D) show
134.812 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .07092 m
.02846 .05604 L
.03279 .0441 L
.03793 .03243 L
.04262 .02431 L
.04498 .02114 L
.04754 .01841 L
.04872 .01741 L
.04996 .01652 L
.05113 .01584 L
.0522 .01536 L
.05341 .01498 L
.05471 .01475 L
.05592 .01472 L
.05707 .01485 L
.05772 .01498 L
.05841 .01518 L
.05964 .01568 L
.06111 .01649 L
.06244 .01745 L
.06508 .01993 L
.06787 .02342 L
.07287 .03182 L
.07824 .04388 L
.08414 .06057 L
.10458 .14272 L
.145 .36736 L
.16364 .46744 L
.17347 .5124 L
.18391 .55172 L
.18916 .56766 L
.19495 .58202 L
.19748 .58719 L
.20021 .59197 L
.20277 .59571 L
.20515 .59852 L
.20759 .60074 L
.20889 .60164 L
.21027 .60239 L
.21096 .60268 L
.21172 .60294 L
.21243 .60312 L
.21309 .60324 L
.21433 .60332 L
.21565 .60321 L
.21679 .60296 L
.21802 .60252 L
.21917 .60194 L
.22023 .60128 L
.22282 .59913 L
Mistroke
.22527 .59639 L
.23032 .58863 L
.23489 .57919 L
.24512 .5502 L
.2546 .5145 L
.26352 .47431 L
.30212 .25991 L
.32171 .15386 L
.33208 .10616 L
.34318 .06456 L
.34868 .0482 L
.35389 .03556 L
.35856 .02668 L
.36098 .02303 L
.36364 .01977 L
.36612 .01745 L
.36726 .01662 L
.36845 .01591 L
.36973 .01534 L
.37091 .01497 L
.37217 .01476 L
.37289 .01472 L
.37355 .01473 L
.37475 .01489 L
.37588 .01519 L
.37689 .01558 L
.37799 .01614 L
.38045 .01789 L
.38272 .02012 L
.38741 .02657 L
.39244 .03619 L
.40152 .06031 L
.41232 .09935 L
.42217 .14335 L
.46199 .36462 L
.48018 .4629 L
.49054 .51077 L
.50028 .54808 L
.50978 .57595 L
.51513 .58754 L
.51767 .59197 L
.52003 .59545 L
.52259 .5985 L
.52491 .60063 L
.52624 .60157 L
.5275 .60228 L
.52882 .60283 L
.52957 .60305 L
.53026 .60319 L
.53154 .60332 L
Mistroke
.53275 .60326 L
.53407 .60301 L
.53481 .60278 L
.53549 .60251 L
.53685 .60182 L
.53833 .60082 L
.54103 .59836 L
.54359 .59527 L
.54635 .59111 L
.55136 .58142 L
.56072 .55624 L
.57165 .51621 L
.5817 .47083 L
.62121 .25061 L
.64108 .1445 L
.64976 .10521 L
.6592 .06933 L
.66441 .05303 L
.66923 .04036 L
.67412 .02999 L
.67872 .02264 L
.68104 .01983 L
.68355 .01748 L
.6849 .01651 L
.68632 .01571 L
.68754 .01521 L
.68823 .01501 L
.68887 .01486 L
.68954 .01476 L
.69027 .01472 L
.69096 .01473 L
.6916 .01479 L
.6928 .01503 L
.69408 .01546 L
.69474 .01576 L
.69545 .01614 L
.69673 .01696 L
.69964 .01954 L
.70219 .02259 L
.7049 .02663 L
.70978 .03594 L
.71558 .0503 L
.72083 .06625 L
.74094 .14969 L
.78108 .37392 L
.79951 .47205 L
.80996 .5189 L
.8197 .55454 L
.82936 .5809 L
.83477 .59138 L
Mistroke
.83716 .59499 L
.83969 .59812 L
.84098 .59942 L
.84239 .60065 L
.84369 .60157 L
.84489 .60224 L
.84556 .60255 L
.84629 .60283 L
.84706 .60305 L
.8478 .6032 L
.84848 .60329 L
.84921 .60332 L
.85053 .60322 L
.85122 .60309 L
.85186 .60291 L
.85256 .60267 L
.85329 .60236 L
.85454 .60168 L
.8559 .60074 L
.85842 .59844 L
.86077 .59564 L
.86578 .58763 L
.87122 .57583 L
.88112 .54655 L
.89075 .5093 L
.89967 .46833 L
.93892 .24913 L
.97619 .07092 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  FontSlant->"Italic",
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool001So
oooo1?l000000ol@413oooooooooo`02ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000?ooooo`Ko00001Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000
ooooooooool01?ooool3o`0000Gooooo1Ol0001Nooooo`Go0000G_ooool6o`0007?ooooo000Joooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo05_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Koooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0LOooool001[ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0FOooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05Wooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`1`ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Hooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo06oooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Kooo
ool0027ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo05Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Eooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0K_ooool0027ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`1Dooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0KOooool0027o
oooo00Go0000ooooooooooooooooo`00000;ooooo`03o`000?oooooooooo05Cooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool0KOooool0027ooooo00Go0000ooooooooooooooooo`00000<ooooo`03o`000?oooooooooo
05?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool0KOooool0027ooooo1?l0000=ooooo`03o`000?oooooooooo05;o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool0K?ooool0027ooooo00Co0000oooooooooooo00003Oooool00ol0003o
ooooooooo`1Booooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0DOooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo06cooooo000Qooooo`04o`000?ooooooooooo`0000ko
oooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo057o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1/ooooo`008Oooool00ol0003ooooo
o`00000?ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`1@ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0K?ooool0027ooooo00?o
0000ooooool000003oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool0Coooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo06_ooooo000Q
ooooo`03o`000?oooooo0000013ooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1[
ooooo`008Oooool2o`00017ooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo04kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1[oooo
o`008Oooool2o`00017ooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo04gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Zooooo`00
8Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
COooool00ol0003oooooooooo`0Jooooo`008Oooool3o`00017ooooo00?o0000ooooooooool0C?oo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo01[ooooo000Qooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo04cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1<ooooo`03o`000?oooooo
oooo01[ooooo000Qooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0C?ooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`1;ooooo`03o`000?oooooooooo01_ooooo000Qooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo04_o
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo01_o
oooo000Qooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0B_ooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`1;ooooo`03o`000?oooooooooo01_ooooo000Qooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool0B_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04Wooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo01_ooooo000Q
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1:
ooooo`03o`000?oooooooooo01_ooooo000Qooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool0BOooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04Sooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo01cooooo000Qooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo04Sooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`19ooooo`03
o`000?oooooooooo01cooooo000Qooooo`?o00004oooool00ol0003oooooooooo`18ooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo04Wooooo00?o0000ooooooooool07?ooool0027ooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0Aooo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool07?oo
ool0027ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`17ooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo04Sooooo00?o0000ooooooooool07?ooool0027ooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`17ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0A_ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool07Oooool0027o
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Oo
oooo00?o0000ooooooooool07Oooool0027ooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`15ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0AOooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool07Oooool0027ooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool0AOooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04Kooooo00?o
0000ooooooooool07Oooool0027ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`15
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool07_ooool0027ooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool0@oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04Gooooo00?o0000oooo
ooooool07_ooool0027ooooo0ol0000Fooooo`03o`000?oooooooooo04?ooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool0A?ooool00ol0003oooooooooo`0Nooooo`008Oooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo04?ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`13ooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0Nooooo`008Ooo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0A?oo
ool00ol0003oooooooooo`0Nooooo`008Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo047ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Oooooo`008Oooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`11ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0@oooool00ol0
003oooooooooo`0Oooooo`008Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo047o
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0Oooooo`008Oooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`11ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0@_ooool00ol0003ooooo
ooooo`0Oooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4
A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo043o
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0Oooooo`001oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool0?oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo047ooooo00?o0000oooooooo
ool08?ooool000Go00000_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo03oooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool0@Oooool00ol0003oooooooooo`0Pooooo`001oooool01Ol0003ooooooooooooooooo000000oo
oooo00?oMgMgoc8b<_ooool00oooool3o`0001Sooooo00?o0000ooooooooool0?oooool00ol0003o
ooooooooo`0Nooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`10ooooo`03o`000?oooooooooo023ooooo0007ooooo`05o`000?ooooooooooooooool0
00003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`0nooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0?oooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool08?ooool000Oo
oooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool0?oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo03oooooo00?o0000oooo
ooooool08Oooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
03oooooo00?o0000ooooooooool08Oooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<oooo
o`Co00001Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo03gooooo00?o0000oooo
ooooool08?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool0?oooool00ol0003oooooooooo`0Qooooo`008Oooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo03gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0mooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0Qooooo`00
8Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
?_ooool00ol0003oooooooooo`0Qooooo`008Oooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo03cooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0mooooo`03o`000?oo
oooooooo023ooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Rooooo`008Oooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool08Oooool0
0ol0003oooooooooo`0mooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0?Oooool0
0ol0003oooooooooo`0Rooooo`008Oooool3o`0001Wooooo00?o0000ooooooooool0??ooool00ol0
003oooooooooo`0Rooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool08Oooool00ol0
003oooooooooo`0mooooo`03o`000?oooooooooo02;ooooo000Qooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo02;o
oooo000Qooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`0Rooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool08_ooool00ol0003ooooo
ooooo`0looooo`03o`000?oooooooooo02;ooooo000Qooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool0>_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool08_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02?ooooo000Q
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0S
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo02?ooooo000Qooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool0>_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03[ooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02?ooooo000Qooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Tooooo`03
o`000?oooooooooo03Wooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo02?ooooo000Qooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
>Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02Cooooo000Qooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo03Wooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0iooooo`03o`000?oo
oooooooo02Cooooo000Qooooo`?o00006oooool00ol0003oooooooooo`0hooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo
oooo03Wooooo00?o0000ooooooooool09?ooool0027ooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`0hooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>Oooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool09?ooool0027o
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Wo
oooo00?o0000ooooooooool09?ooool0027ooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0gooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0=oooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool09Oooool0027ooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool0=oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo03Oooooo00?o
0000ooooooooool09Oooool0027ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0f
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool09Oooool0027ooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo02Oooooo00?o0000oooo
ooooool0=oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo03Oooooo00?o0000oooo
ooooool09Oooool0027ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0fooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo03Oooooo00?o0000ooooooooool09Oooool0027ooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
=_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0
9_ooool0027ooooo0ol0000Mooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0:?oo
ool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0=Ooo
ool00ol0003oooooooooo`0Vooooo`008Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo03Cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooo
oooo02Sooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Vooooo`008Oooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`0eooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0=Oooool00ol0
003oooooooooo`0Vooooo`008Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo03Co
oooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02So
oooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Vooooo`008Oooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0:Oooool00ol0003ooooo
ooooo`0dooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0=?ooool00ol0003ooooo
ooooo`0Wooooo`008Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo03Cooooo00?o
0000ooooooooool0:_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02[ooooo00?o
0000ooooooooool0<oooool00ol0003oooooooooo`0Wooooo`008Oooool00ol0003oooooooooo`0J
ooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Jooooo`05odA4A?l0
003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Dooooo`03o`000?o^k^kooooo00Gooooo
0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool00ol0003oooooooooo`0Aooooo`Co
000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kQCooooo1?l000000ol@413ooooooooo
o`05o`0000Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd04_ooool4o`000005oa0@
4?oooooooooooooooom4A4@00_l000000olb<S;ogMgMooooo`0Aooooo`Co000000?o410@oooooooo
ool00_ooool00ol0003ok^k^ooooo`05ooooo`;o8B4Q1?ooool01_l0003oA4A4o`000?l0003o<S8b
omgMgBCooooo000Qooooo`03o`000?oooooooooo01[ooooo00GoV9RHob4Q8Oo^k^koooooo`000005
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Looooo`03ogMgMolb<S;ooooo00?ooooo00?o0000
ooooooooool05Oooool00omEEEGoZJVYooooo`05ooooo`;o8B4Q2?ooool01OmgMgOo<S8boooooooo
oooo000001Gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01Kooooo
00?o0000ooooooooool00_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo0_lQ8B48ooooo`03
ogMgMolb<S;ooooo017ooooo00?o0000ooooool000002?ooool00omgMgOo<S8booooo`0Cooooo`03
o`000?oooooooooo00Cooooo00?oEEEEojVYZOooool01Oooool2ob4Q8@Cooooo00Ko0000oooooooo
ooooooooogMgMolb<S8Tooooo`008Oooool00ol0003oooooooooo`0Kooooo`04oiRHV?lQ8B7ok^k^
o`00013ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo01Gooooo00?oZJVYoeEEEOooool04?ooool01?l0003oooooooooool0000Eooooo`03o`000?oo
oooooooo00;ooooo00Go410@oooooooooooooooooa0@400Fooooo`03o`000?oooooooooo00?ooooo
00?oV9RHob4Q8Oo^k^h04Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo000000Wooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`04ooooo`03ojVYZOmEEEGooooo00_ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Rooooo`008Oooool3o`0001cooooo00?o
V9RHob4Q8Ol000003oooool00omgMgOo<S8booooo`0Looooo`03ogMgMolb<S;ooooo00?ooooo00?o
0000ooooooooool05_ooool00olQ8B7oooooooooo`0>ooooo`05ogMgMolb<S;oooooooooool00000
5Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000005_ooool00ol0003o
ooooooooo`04ooooo`03oiRHV?lQ8B7ok^k^00oooooo00?oMgMgoc8b<_ooool04Oooool00ol0003o
ooooo`000008ooooo`03ogMgMolb<S;ooooo01?ooooo00?o0000ooooooooool01Oooool00olQ8B7o
ooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00?oMgMgoc8b<_ooool08oooool0027ooooo
00?o0000ooooooooool07Oooool00omgMgOo0000ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`06_ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool05_ooool00omE
EEGoc<c<ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Eooooo`;o00001ooo
ool00omgMgOoIVIVooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`04oooool2o`0000Gooooo
00Go0000ob4Q8Ol0003o<S8bolc<c00Dooooo`03o`000?oooooooooo00Gooooo00?oEEEEolc<c?oo
ool02Oooool01ol0003oooooo`000?lQ8B7o0000oc8b<_o<c<`09?ooool0027ooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0Fooooo`03ojVYZOmgMgOooooo00_ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00;ooooo00Go410@oooo
oooooooooooooa0@400Eooooo`;o00002?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo01Gooooo0_l00005ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01Oooool0
0onYZJWoMgMgooooo`09ooooo`03o`000?oooooo000002Sooooo000Qooooo`03o`000?oooooooooo
01[ooooo00Ko0000okZj^_ooooooV9RHoa0@4?l0000;ooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Dooooo`05oa0@4?oooooooooooooooolb<S80
3?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01Gooooo0_l00004ooooo`05o`000?nj^[[ooooooiRH
V?l@41003?ooool00ol0003oooooooooo`0Eooooo`;o00001Oooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooc8b<P0:ooooo`03o`000?oooooo
000002Sooooo000Qooooo`03o`000?oooooooooo01[ooooo00KoV9RHoa0@4?l0003o8B4Qolc<c?l0
000;ooooo`Co00006oooool4o`0000Cooooo00?o0000ooooooooool05?ooool5o`0000cooooo1?l0
0004ooooo`03o`000?oooooooooo013ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^01Cooooo00?oEEEEo`000?l000001?ooool01OnHV9So410@o`000?lQ8B7oc<c<00co
oooo1?l0000Cooooo`03oeEEEOl0003o000000Gooooo1?l0000Cooooo`03oeEEEOmVIVKo000000Co
oooo1Ol0000:ooooo`03o`000?oooooo000000?o00009Oooool0027ooooo00?o0000ooooooooool0
7oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0
<Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
:?ooool0027ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0`ooooo`03o`000?oo
oooooooo02gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0]ooooo`03o`000?oo
oooooooo033ooooo00?o0000ooooooooool0:Oooool0027ooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0<?ooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool07oooool2
o`0000;ooooo0_l00004ooooo`008Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
033ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo
02kooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Oooooo`06onk^k_lQ8B7oQhN7
okZj^_l0003ogMgM1?ooool001[oooooool0000jo`0000cooooo00CogMgMo`000?l@413oc<c<1Ooo
ool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooo000000Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`05o`00
0?ooooooooooooooool000000oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01?ooool2o`0000Oooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0?ooooo`04onk^k_lQ8B7o410@onk^kPGooooo000Qooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooo`000005ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo0_l0
0007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03oooool01?lQ8B7oMgMgogMg
Molb<S85ooooo`008Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02kooooo00?o
0000ooooooooool0;oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo033ooooo00?o
0000ooooooooool0;Oooool00ol0003oooooooooo`0Pooooo`;o00000_ooool2o`0000Cooooo000Q
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0_
ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0]
ooooo`03o`000?oooooooooo02[ooooo000Qooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool0;Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02gooooo00?o0000oooo
ooooool0<?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02[ooooo000Qooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0aooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0]ooooo`03
o`000?oooooooooo02[ooooo000Qooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
;?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02[ooooo000Qooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo02gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo02_ooooo000Qooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0;?ooool0
0ol0003oooooooooo`0aooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0<_ooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo02_ooooo000Qooooo`?o00008Oooool00ol0
003oooooooooo`0/ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0:oooool00ol0
003oooooooooo`0booooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0:oooool0027o
oooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03?o
oooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo02_o
oooo00?o0000ooooooooool0:oooool0027ooooo00?o0000ooooooooool08_ooool00ol0003ooooo
ooooo`0Zooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0:oooool00ol0003ooooo
ooooo`0booooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0:oooool0027ooooo00?o
0000ooooooooool08_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03?ooooo00?o
0000ooooooooool0:oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo02_ooooo00?o
0000ooooooooool0:oooool0027ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Z
ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0c
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0;?ooool0027ooooo00?o0000oooo
ooooool08_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03?ooooo00?o0000oooo
ooooool0:_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool0;?ooool0027ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Zooooo`03
o`000?oooooooooo03Cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0dooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool0;?ooool0027ooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0
;?ooool0027ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo03Gooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0dooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool0;?ooool0027ooooo0ol0000Sooooo`03o`000?oooooo
oooo02Sooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooo
oooo03Gooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0/ooooo`008Oooool00ol0
003oooooooooo`0Sooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0=Oooool00ol0
003oooooooooo`0Xooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`0]ooooo`008Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02So
oooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0]ooooo`008Oooool00ol0003ooooo
ooooo`0Sooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0=oooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`0]ooooo`008Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool0=oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo03Kooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`0]ooooo`008Oooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0]
ooooo`008Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool0=oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo03Oooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0^ooooo`008Oooool00ol0003oooooooooo`0Tooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo03Sooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0^ooooo`00
8Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
>?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0^ooooo`008Oooool3o`0002Gooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02kooooo000Qooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo
oooo02kooooo000Qooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`0iooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>Oooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo02kooooo000Qooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02oo
oooo000Qooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`0jooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0>_ooool00ol0003ooooo
ooooo`0Sooooo`03o`000?oooooooooo02oooooo000Qooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool08_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool0>_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02oooooo000Q
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0R
ooooo`03o`000?oooooooooo02oooooo000Qooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool08_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02?ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo02oooooo000Qooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Rooooo`03
o`000?oooooooooo02oooooo000Qooooo`?o00009_ooool00ol0003oooooooooo`0Rooooo`03o`00
0?oooooooooo03cooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool0<?ooool0027ooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`0looooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0<?oo
ool0027ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo03gooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool0<?ooool0027ooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool08Oooool00ol0
003oooooooooo`0mooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0<?ooool0027o
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03go
oooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo023o
oooo00?o0000ooooooooool0<?ooool0027ooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool08?ooool00ol0003ooooo
ooooo`0mooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0<Oooool0027ooooo00?o
0000ooooooooool0:?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03kooooo00?o
0000ooooooooool07oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool0<Oooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Ooo
ool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0:?ooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`0oooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0<Oooool000Oooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`00
0?oooooooooo02Sooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0oooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo037ooooo0007ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooo
ooooo`02ooooo`?o0000:?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo03oooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool0<Oooool000Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMg
Molb<S;ooooo00?ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo043ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0oooooo`03o`00
0?oooooooooo01kooooo00?o0000ooooooooool0<Oooool000Oooooo00Go0000oooooooooooooooo
o`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0booooo`00
1oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0Yooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0@?ooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0booooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool0@Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo047ooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`0booooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00co
oooo1?l00005ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`11ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0@Oooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo03;ooooo000Qooooo`03o`000?oooooooooo02Wooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo03;ooooo
000Qooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`12ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0@Oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo03?ooooo000Qooooo`03o`000?oooooooooo02[ooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool0@oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo03?ooooo000Qoooo
o`03o`000?oooooooooo02[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`13oooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo03?ooooo000Qooooo`?o0000:_ooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo04?ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`13ooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool0<oooool0027ooooo00?o0000ooooooooool0
:_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
=?ooool0027ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo04Cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`14ooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool0=?ooool0027ooooo00?o0000ooooooooool0:oooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0=?ooool0
027ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
04Gooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool0=?ooool0027ooooo00?o0000ooooooooool0:oooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`16ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0=?ooool0027ooooo
00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04Kooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool0=Oooool0027ooooo00?o0000ooooooooool0;?ooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`16ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0=Oooool0027ooooo00?o0000
ooooooooool0;?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Oooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool0=Oooool0027ooooo0ol0000/ooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool0Aoooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Sooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`0eooooo`008Oooool00ol0003oooooooooo`0/ooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo04Sooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0fooooo`00
8Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
B?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0fooooo`008Oooool00ol0003oooooooooo`0]ooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo04Wooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0fooooo`008Oooool0
0ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0BOooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`0fooooo`008Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
04[ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0gooooo`008Oooool00ol0003o
ooooooooo`0^ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0B_ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0gooooo`008Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo04cooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0gooooo`008Oooool00ol0003ooooooooo
o`0^ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0B_ooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0gooooo`008Oooool3o`0002kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1<
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo03Sooooo000Qooooo`03o`000?oooooooooo02oooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool0C?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo03Sooooo000Qooooo`03
o`000?oooooooooo02oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1<ooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo03Sooooo000Qooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
C_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03Wooooo000Qooooo`03o`000?oo
oooooooo033ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1>ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo03Wooooo000Qooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Coooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03Wooooo000Qooooo`03o`000?oooooooooo
033ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
03[ooooo000Qooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`1@ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0D?ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo03[ooooo000Qooooo`03o`000?oooooooooo037ooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool0DOooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03[ooooo
000Qooooo`?o0000<_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05;ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0>oooool0027ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1B
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0>oooool0027ooooo00?o0000oooo
ooooool0<_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05?ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool0>oooool0027ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo05Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Dooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool0??ooool0027ooooo00?o0000ooooooooool0
=?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
?Oooool0027ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo05Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Fooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0?Oooool0027ooooo00?o0000ooooooooool0=?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`1Gooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0?_ooool0
01Sooooo1?l000000ol@413oooooooooo`02ooooo`03o`000?oooooooooo03Gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0F?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03kooooo000Jooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo05[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Jooooo`;o
00001?ooool00ol0003oooooooooo`0oooooo`006_ooool00ol0003oooooooooo`04ooooo`?o0000
=oooool5o`0005kooooo1Ol0001Nooooo`Go0000@_ooool001[ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGo
oooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool0oooooom5ooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00W?ooool2o`0003oooooo0_l00029ooooo`00W?ooool00ol0003oooooooooo`0ooooo
o`03o`000?oooooooooo08Oooooo0029ooooo`?o00000_ooool01_lb<S;o410@ooooooooooook^k^
oeEEE@;o000000?oA4A4okZj^_ooool00oooool00ol0003oooooooooo`02ooooo`06onk^k_mVIVKo
0000o`000?lb<S;o^[Zj=oooool00ol0003oooooooooo`27ooooo`00R_ooool01Ol0003ooooooooo
ooo<c<co410@00?ooooo00KoEEEEogMgMoooooook^k^ogMgMol@4104ooooo`03o`000?oooooooooo
00;ooooo0_mgMgL01?mEEEGoQhN7omgMgOm4A4@gooooo`03o`000?oooooooooo08Oooooo002:oooo
o`05o`000?oooooooooooeEEEOn7QhL00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00;ooooo00?oV9RHooooool00000>_ooool00ol0003oooooooooo`27ooooo`00R_ooool01Ol0
003oooooomgMgOl0003ok^k^00?ooooo1_l00004ooooo`03o`000?oooooooooo00;ooooo00?oV9RH
ooooool000000ol0000Booooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`27ooooo`00R_ooool3o`000003oa0@4?nHV9Sooooo00;ooooo00KoEEEEohN7
Qoo^k^koooooohN7Qolb<S84ooooo`03o`000?oooooooooo00;ooooo00?oMgMgohN7QomVIVH00_nj
^[X00olb<S;oooooooooo`0?ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`27ooooo`00R_ooool01Ol0003oooooooooooo<c<co000000?ooooo00Ko
k^k^oeEEEOl0003o0000odA4A?o^k^h4ooooo`03o`000?oooooooooo00?ooooo00KoIVIVo`000?l0
003oA4A4onk^k_ooool3o`0000Cooooo0_l000000ooooooo0000o`000003ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooool000002_ooool3o`0000Kooooo0_l00004ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0Qoooool008[ooooo00Go0000ooooooooooooc<c<o`00000=
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01?ooool00ol0003oooooo`000004
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`27
ooooo`00ROooool4o`000003oa0@4?nYZJWooooo00cooooo0_l0000;ooooo`03o`000?oooooooooo
00Cooooo0_l00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool4o`00
00;ooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00;ooooo0_l00029ooooo`00ZOooool00ol0003oooooooooo`04ooooo`03o`000?oooooo0000
00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooo`00000:ooooo`?o00001?ooool4o`00
00Cooooo00?o0000ooooooooool0SOooool00:Sooooo0_l00006ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo08ko
oooo002_ooooo`;o00002?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo08oooooo
002Yooooo`03o`000?oooooooooo0;cooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-2, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0505254 0.309018 0.294303 [
[.15012 .29652 -9 -9 ]
[.15012 .29652 9 0 ]
[.27644 .29652 -3 -9 ]
[.27644 .29652 3 0 ]
[.40275 .29652 -9 -9 ]
[.40275 .29652 9 0 ]
[.52906 .29652 -6 -9 ]
[.52906 .29652 6 0 ]
[.65538 .29652 -12 -9 ]
[.65538 .29652 12 0 ]
[.78169 .29652 -6 -9 ]
[.78169 .29652 6 0 ]
[.908 .29652 -12 -9 ]
[.908 .29652 12 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .01472 -12 -4.5 ]
[.01131 .01472 0 4.5 ]
[.01131 .16187 -24 -4.5 ]
[.01131 .16187 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[.5 .63053 -37.9062 0 ]
[.5 .63053 37.9062 12.625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15012 .30902 m
.15012 .31527 L
s
[(2.5)] .15012 .29652 0 1 Mshowa
.27644 .30902 m
.27644 .31527 L
s
[(5)] .27644 .29652 0 1 Mshowa
.40275 .30902 m
.40275 .31527 L
s
[(7.5)] .40275 .29652 0 1 Mshowa
.52906 .30902 m
.52906 .31527 L
s
[(10)] .52906 .29652 0 1 Mshowa
.65538 .30902 m
.65538 .31527 L
s
[(12.5)] .65538 .29652 0 1 Mshowa
.78169 .30902 m
.78169 .31527 L
s
[(15)] .78169 .29652 0 1 Mshowa
.908 .30902 m
.908 .31527 L
s
[(17.5)] .908 .29652 0 1 Mshowa
.125 Mabswid
.04907 .30902 m
.04907 .31277 L
s
.07433 .30902 m
.07433 .31277 L
s
.0996 .30902 m
.0996 .31277 L
s
.12486 .30902 m
.12486 .31277 L
s
.17539 .30902 m
.17539 .31277 L
s
.20065 .30902 m
.20065 .31277 L
s
.22591 .30902 m
.22591 .31277 L
s
.25117 .30902 m
.25117 .31277 L
s
.3017 .30902 m
.3017 .31277 L
s
.32696 .30902 m
.32696 .31277 L
s
.35222 .30902 m
.35222 .31277 L
s
.37749 .30902 m
.37749 .31277 L
s
.42801 .30902 m
.42801 .31277 L
s
.45328 .30902 m
.45328 .31277 L
s
.47854 .30902 m
.47854 .31277 L
s
.5038 .30902 m
.5038 .31277 L
s
.55433 .30902 m
.55433 .31277 L
s
.57959 .30902 m
.57959 .31277 L
s
.60485 .30902 m
.60485 .31277 L
s
.63011 .30902 m
.63011 .31277 L
s
.68064 .30902 m
.68064 .31277 L
s
.7059 .30902 m
.7059 .31277 L
s
.73116 .30902 m
.73116 .31277 L
s
.75643 .30902 m
.75643 .31277 L
s
.80695 .30902 m
.80695 .31277 L
s
.83222 .30902 m
.83222 .31277 L
s
.85748 .30902 m
.85748 .31277 L
s
.88274 .30902 m
.88274 .31277 L
s
.93327 .30902 m
.93327 .31277 L
s
.95853 .30902 m
.95853 .31277 L
s
.98379 .30902 m
.98379 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01472 m
.03006 .01472 L
s
[(-1)] .01131 .01472 1 0 Mshowa
.02381 .16187 m
.03006 .16187 L
s
[(-0.5)] .01131 .16187 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(0.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .13244 m
.02756 .13244 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -98.9062 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.625 moveto
(@) show
81.000 13.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\343) show
87.000 9.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344) show
93.000 9.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
97.188 9.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
( ) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
99.000 9.625 moveto
(H) show
103.188 9.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
107.375 9.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
113.375 9.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
119.375 9.625 moveto
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
123.562 9.625 moveto
(L) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
128.812 13.625 moveto
(D) show
134.812 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .21807 m
.04262 .1225 L
.0522 .08294 L
.06244 .04962 L
.0679 .03616 L
.07286 .02666 L
.07525 .02305 L
.07784 .01986 L
.08029 .01754 L
.08147 .01667 L
.08255 .01601 L
.08382 .01541 L
.08452 .01516 L
.08518 .01497 L
.08636 .01477 L
.08764 .01472 L
.08838 .01478 L
.08905 .01489 L
.08982 .01508 L
.09055 .01532 L
.09184 .0159 L
.09325 .01675 L
.09612 .01918 L
.09915 .02277 L
.10458 .03176 L
.10954 .04276 L
.11406 .05503 L
.12422 .08984 L
.14255 .17382 L
.1824 .39917 L
.20062 .49222 L
.21099 .53533 L
.21607 .55307 L
.22073 .56717 L
.22527 .57882 L
.23024 .58907 L
.23524 .59663 L
.23797 .59958 L
.2405 .60156 L
.24181 .6023 L
.24251 .6026 L
.24324 .60287 L
.24388 .60305 L
.24458 .6032 L
.24582 .60332 L
.24703 .60326 L
.24832 .60302 L
.24954 .60261 L
.25066 .60209 L
.25204 .60124 L
Mistroke
.25332 .60026 L
.25622 .59735 L
.25878 .594 L
.26151 .58962 L
.26688 .57861 L
.27182 .56581 L
.28296 .52815 L
.30314 .43449 L
.34268 .21028 L
.36258 .11144 L
.37127 .07704 L
.38071 .04745 L
.38593 .03493 L
.39075 .02596 L
.39536 .01979 L
.39769 .01759 L
.39892 .01668 L
.40025 .01589 L
.40158 .0153 L
.4023 .01506 L
.40297 .0149 L
.40417 .01474 L
.40546 .01474 L
.40618 .01483 L
.40697 .015 L
.40771 .01522 L
.40839 .01547 L
.40969 .01611 L
.41106 .017 L
.41355 .01916 L
.41588 .02181 L
.42118 .03012 L
.42618 .04076 L
.43162 .05532 L
.44151 .08919 L
.46006 .17407 L
.50081 .40443 L
.52104 .5054 L
.53095 .54435 L
.53529 .55865 L
.54004 .57219 L
.54431 .58237 L
.54888 .5911 L
.5514 .59494 L
.5537 .59781 L
.55601 .6001 L
.55819 .6017 L
.55932 .60232 L
.56056 .60282 L
.56186 .60317 L
Mistroke
.56307 .60331 L
.5642 .60329 L
.56524 .60314 L
.56644 .60282 L
.56758 .60236 L
.5688 .6017 L
.5701 .60081 L
.57245 .59871 L
.57524 .59541 L
.57776 .59166 L
.58264 .58243 L
.5878 .56992 L
.59702 .54086 L
.61785 .44882 L
.65584 .23423 L
.677 .12493 L
.68702 .08331 L
.69628 .05265 L
.70084 .04068 L
.70586 .03001 L
.71092 .02205 L
.71368 .01891 L
.71492 .01778 L
.71628 .01675 L
.7174 .01605 L
.7186 .01547 L
.71986 .01504 L
.72104 .0148 L
.72221 .01472 L
.72332 .01478 L
.72431 .01497 L
.72539 .01529 L
.72658 .01581 L
.72788 .01656 L
.7305 .01866 L
.73294 .02131 L
.73521 .02439 L
.7402 .03315 L
.74563 .04574 L
.75552 .07633 L
.77406 .15647 L
.81477 .38496 L
.83362 .48337 L
.84353 .52622 L
.85398 .56236 L
.85932 .57675 L
.86517 .58907 L
.86774 .59331 L
.87049 .59703 L
.87308 .59976 L
Mistroke
.87544 .60157 L
.8767 .60228 L
.87739 .60259 L
.87803 .60283 L
.87917 .60314 L
.88042 .6033 L
.88111 .60332 L
.88178 .60328 L
.88302 .60307 L
.88371 .60288 L
.88436 .60265 L
.88582 .60196 L
.8871 .60114 L
.88831 .60021 L
.89057 .59801 L
.893 .595 L
.89563 .59099 L
.90054 .58147 L
.90513 .57026 L
.91556 .53694 L
.93662 .44204 L
.97552 .22181 L
.97619 .21807 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  FontSlant->"Italic",
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool001So
oooo1?l000000ol@413oooooooooo`02ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000?ooooo`Ko00001Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000
ooooooooool01?ooool3o`0000oooooo1Ol0001Nooooo`Go0000Goooool4o`0006[ooooo000Joooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo05[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Koooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Ioooool001[ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0FOooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05Wooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`1Vooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Hooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo06Gooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0IOoo
ool0027ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo05Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Fooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0I?ooool0027ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`1Eooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0I?ooool0027o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05?o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool0Hoooool0027ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`1Cooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0Hoooool0027ooooo0ol0
000:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0D_ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`1Rooooo`008Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0DOooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo057ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`1Rooooo`008Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo053ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1Roooo
o`008Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool0Coooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo04oooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`1Qooooo`008Oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo04oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1Qooooo`008Ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Cooo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`1Qooooo`008Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo04gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Pooooo`008Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0COooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`1Pooooo`008Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04co
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Pooooo`008Oooool3o`0000Oooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool0Boooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo05oooooo
000Qooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`1;ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0Boooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo05oooooo000Qooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool0B_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo05oooooo000Qoooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1;oooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo05oooooo000Qooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool0BOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo05kooooo000Qooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`19ooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo05kooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0B?oo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo05kooooo000Qooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`18ooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo05kooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`18ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0Aoooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo05gooooo000Qooooo`?o00001Oooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`17ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0GOooool0027ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Oooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool0GOooool0027ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`16ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0GOooool0027ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Kooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool0G?ooool0027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo04Kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`15oooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0G?ooool0027ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04Gooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool0G?ooool0027ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo04Gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`14ooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool0G?ooool0027ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0G?oo
ool0027ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo04Cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`13ooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool0Foooool0027ooooo0ol00002ooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
04?ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1Kooooo`008Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0@oooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`1Kooooo`008Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04;ooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`1Kooooo`008Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0@_ooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`1Jooooo`008Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool0@_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo047ooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`1Jooooo`008Oooool01Ol0003ooooooooooooooooo
000001kooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo047ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1Jooooo`008Oooool01Ol0
003ooooooooooooooooo000001oooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1J
ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o
0000oc8b<_oMgMd01?ooool01Ol0003ooooooooooooooooo000001oooooo00?o0000ooooooooool0
@Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`1Iooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00Go0000ooooooooooooooooo`00000Oooooo`03
o`000?oooooooooo043ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo01kooooo00?o0000ooooooooool0FOooool000Go00000_ooool01Ol@413ooooo
oooooooooooo410@013ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
01oooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
03oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1Iooooo`001oooool01Ol0003o
oooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool4o`00023ooooo00?o0000oooo
ooooool0@?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo03oooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`1Iooooo`001oooool01Ol0003ooooooooooooooooo0000
00cooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`04o`000?ooooooooooo`00027ooooo00?o
0000ooooooooool0?oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo03oooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`1Iooooo`001oooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01_ooool01?l0003oooooooooool0000Qooooo`03o`00
0?oooooooooo03oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0nooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool0F?ooool000Oooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0<ooooo`03o`000?oooooooooo00Kooooo00Co0000oooooooooooo00008Oooool00ol0003o
ooooooooo`0nooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0?Oooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo05Sooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h03?ooool4o`0000Gooooo00Co0000oooooooooooo00008Oooool00ol0003oooooooooo`0noooo
o`03o`000?oooooooooo023ooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Poooo
o`03o`000?oooooooooo05Sooooo000Qooooo`03o`000?oooooo000002;ooooo00?o0000oooooooo
ool0?_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03gooooo00?o0000oooooooo
ool08?ooool00ol0003oooooooooo`1Hooooo`008Oooool00ol0003oooooo`00000Rooooo`03o`00
0?oooooooooo03kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0mooooo`03o`00
0?oooooooooo023ooooo00?o0000ooooooooool0F?ooool0027ooooo00?o0000ooooool000008ooo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0??oo
ool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo05Sooooo000Qooooo`03o`000?oooooo
000002?ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo03cooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`1Gooooo`008Oooool3o`00
02?ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`1Gooooo`008Oooool2o`0002Co
oooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`1Gooooo`008Oooool2o`0002Cooooo
00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03_ooooo
00?o0000ooooooooool08_ooool00ol0003oooooooooo`1Gooooo`008Oooool2o`0002Gooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool08_ooool00ol0003oooooooooo`1Gooooo`008Oooool2o`0002Gooooo00?o0000
ooooooooool0>_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo03[ooooo00?o0000
ooooooooool08_ooool00ol0003oooooooooo`1Gooooo`008Oooool2o`0002Gooooo00?o0000oooo
ooooool0>_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo03Wooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`1Fooooo`008Oooool00ol0003oooooooooo`0Tooooo`03
o`000?oooooooooo03[ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0iooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool0E_ooool0027ooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
>Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo05Kooooo000Qooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo03Wooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0iooooo`03o`000?oo
oooooooo01[ooooo000Qooooo`?o00009Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo
oooo03Wooooo00?o0000ooooooooool06_ooool0027ooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0hooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0>?ooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool06_ooool0027o
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo03So
oooo00?o0000ooooooooool06_ooool0027ooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0hooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0=oooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool06_ooool0027ooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool0=oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo03Oooooo00?o
0000ooooooooool06oooool0027ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0g
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool06oooool0027ooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool0=oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo03Oooooo00?o0000oooo
ooooool06oooool0027ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0fooooo`03
o`000?oooooooooo02Sooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo03Oooooo00?o0000ooooooooool06oooool0027ooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0
=Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0
6oooool0027ooooo0ol0000Vooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0:?oo
ool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0=Ooo
ool00ol0003oooooooooo`0Looooo`008Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo03Kooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooo
oooo02Sooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Looooo`008Oooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0:?ooool00ol0
003oooooooooo`0eooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0=Oooool00ol0
003oooooooooo`0Looooo`008Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo03Go
oooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02So
oooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Looooo`008Oooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0:_ooool00ol0003ooooo
ooooo`0cooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0=Oooool00ol0003ooooo
ooooo`0Looooo`008Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo03Cooooo00?o
0000ooooooooool0:_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02[ooooo00?o
0000ooooooooool0<oooool00ol0003oooooooooo`0Mooooo`008Oooool00ol0003oooooooooo`0J
ooooo`Go00001Oooool2ob4Q8@03ooooool0003ooooo00;ooooo00GoA4A4o`000?l0003o<S8bomgM
g@0Jooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool00ol0003oooooooooo`0:ooooo`03o`00
0?o^k^kooooo00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd03?ooool00ol0003o
ooooooooo`07ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kQCooooo1?l0
00000ol@413oooooooooo`06o`0000Cooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
4_ooool4o`000005oa0@4?oooooooooooooooom4A4@00_l000000olb<S;ogMgMooooo`0Aooooo`Co
000000?o410@ooooooooool00_ooool00ol0003ok^k^ooooo`05ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool07Oooool0027ooooo00?o0000oooooooo
ool06_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo0_lQ8B42ooooo`03o`000?oooooooooo
00?ooooo00?oMgMgoc8b<_ooool07?ooool00omgMgOo<S8booooo`0>ooooo`03o`000?oooooooooo
00[ooooo00?oEEEEojVYZOooool01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool02oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0F
ooooo`03o`000?oooooooooo00;ooooo00KoV9RHob4Q8Oo^k^koooooodA4A?l00004ooooo`;o8B4Q
2?ooool00omgMgOo<S8booooo`0Cooooo`03o`000?oooooooooo00Gooooo00?o0000ogMgMolb<S80
5?ooool00ol0003oooooooooo`04ooooo`03oeEEEOnYZJWooooo00Gooooo0_lQ8B48ooooo`03ogMg
Molb<S;ooooo00?ooooo00?o0000ooooooooool07Oooool0027ooooo00?o0000ooooooooool06ooo
ool00onHV9So8B4Qonk^kP0:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo00?oZJVYoeEEEOooool04?oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@01Kooooo00?o0000ooooooooool00oooool01OnHV9So8B4Q
onk^k_oooooo000000oooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooo000001Cooooo00?o0000ooooooooool01?ooool00onYZJWoEEEEooooo`0@ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool07Oooool0027ooooo0ol0000Looooo`03oiRH
V?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00omgMgOo<S8booooo`0Looooo`03ogMg
Molb<S;ooooo00gooooo00?o0000ooooooooool03?ooool00olQ8B7oooooooooo`0>ooooo`03ogMg
Molb<S;ooooo00_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000005_ooool00ol0003oooooooooo`04ooooo`04oiRHV?lQ8B7ok^k^o`00
00kooooo00?oMgMgoc8b<_ooool04oooool00ol0003oooooooooo`05ooooo`03o`000?mgMgOo<S8b
01Cooooo00?o0000ooooooooool01Oooool00olQ8B7oooooooooo`0>ooooo`03ogMgMolb<S;ooooo
00?ooooo00?o0000ooooooooool07Oooool0027ooooo00?o0000ooooooooool07Oooool00omgMgOo
IVIVooooo`08ooooo`08o`000?ooooooooooo`000?lQ8B7o0000oc8b<_o<c<`Jooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`03_ooool00ol0003oooooooooo`0<ooooo`03oeEEEOo<c<cooooo00_ooooo
00Go0000ob4Q8Ol0003o<S8bolc<c00=ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool00_ooool01Ol0003ooooooooooooooooo000001Kooooo00?o0000ooooooooool01Oooool00omg
MgOo0000ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`05?ooool00ol0003oooooooooo`03
ooooo`05o`000?lQ8B7o0000o`000?o<c<`05?ooool00ol0003oooooooooo`05ooooo`03oeEEEOo<
c<cooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo01gooooo
000Qooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool01oooool01?l0003ooooooooo
ool0000Nooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03?ooool00onYZJWoMgMg
ooooo`0;ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41005_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`03ooooo`04
o`000?ooooooooooo`0001Gooooo00?o0000ooooooooool01Oooool00onYZJWoMgMgooooo`0;oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool07_ooool0027ooooo00?o0000oooooooo
ool06_ooool01Ol0003o^[ZjoooooonHV9So410@00[ooooo00?o0000ooooool000007_ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo00Wooooo00Go410@oooooooooooooooooc8b<P0<
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL05_ooool00ol0003oooooooooo`02ooooo`05o`000?nj
^[[ooooooiRHV?l000003?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00?ooooo
00Co0000oooooooooooo00005Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooo
oolb<S803?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01kooooo000Qooooo`03
o`000?oooooooooo01[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00:ooooo`03o`000?oooooo0000
00?o00006oooool4o`0000oooooo00?o0000ooooooooool02Oooool5o`0000cooooo1?l0000>oooo
o`03o`000?oooooooooo00Kooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01Cooooo00?oEEEEofIVI_l000001?ooool01OnHV9So410@o`000?lQ8B7o000000cooooo1?l0
000Cooooo`03oeEEEOmVIVKo000000Gooooo1?l0000Cooooo`03oeEEEOmVIVKo000000Cooooo1Ol0
000<ooooo`Co00001?ooool00ol0003oooooooooo`0Nooooo`008Oooool00ol0003oooooooooo`0Y
ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0a
ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0N
ooooo`008Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo033ooooo00?o0000oooo
ooooool0;Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo02cooooo00?o0000oooo
ooooool0<Oooool00ol0003oooooooooo`0Nooooo`008Oooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo033ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0_ooooo`03
o`000?oooooooooo02kooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Eooooo`;o
00000_ooool2o`0000Cooooo000Qooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0
;_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01Gooooo00Kok^k^ob4Q8On7QhOo
^[Zjo`000?oMgMd4ooooo`006_ooooooo`0003[o00003?ooool01?oMgMgo0000oa0@4?o<c<`5oooo
o`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01Oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000001oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo0_l00006ooooo`03o`000?oooooo
oooo00oooooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool0027ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000001Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Go0000oooooooooooooooo
o`000003ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`;o00001_ooool00ol0003oooooooooo`0?ooooo`04ob4Q8OmgMgOoMgMgoc8b<PGo
oooo000Qooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`0_ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0;oooool00ol0003ooooo
ooooo`0^ooooo`03o`000?oooooooooo01Kooooo0_l00002ooooo`;o00001?ooool0027ooooo00?o
0000ooooooooool0:_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo033ooooo00?o
0000ooooooooool0;Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02gooooo00?o
0000ooooooooool08?ooool0027ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0]
ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0`
ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool08?ooool0027ooooo00?o0000oooo
ooooool0:oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo033ooooo00?o0000oooo
ooooool0;Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02gooooo00?o0000oooo
ooooool08?ooool0027ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0]ooooo`03
o`000?oooooooooo033ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0`ooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool08?ooool0027ooooo00?o0000ooooooooool0
:oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0
8Oooool0027ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo037ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo02cooooo00?o0000ooooooooool08Oooool0027ooooo0ol0000[ooooo`03o`000?oooooo
oooo02cooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooo
oooo03;ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Qooooo`008Oooool00ol0
003oooooooooo`0/ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0<_ooool00ol0
003oooooooooo`0[ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0:oooool00ol0
003oooooooooo`0Qooooo`008Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo02_o
oooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo03;o
oooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Qooooo`008Oooool00ol0003ooooo
ooooo`0/ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0<_ooool00ol0003ooooo
ooooo`0[ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0:oooool00ol0003ooooo
ooooo`0Qooooo`008Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo02_ooooo00?o
0000ooooooooool0<_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03?ooooo00?o
0000ooooooooool0:_ooool00ol0003oooooooooo`0Rooooo`008Oooool00ol0003oooooooooo`0/
ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Z
ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0R
ooooo`008Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool0=?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo03Cooooo00?o0000oooo
ooooool0:Oooool00ol0003oooooooooo`0Rooooo`008Oooool00ol0003oooooooooo`0]ooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo03Cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Rooooo`00
8Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0
=?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`0Rooooo`008Oooool3o`0002gooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0=?oo
ool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02?ooooo000Qooooo`03o`000?oooooo
oooo02gooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooo
oooo02Sooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo02?ooooo000Qooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0:?ooool00ol0
003oooooooooo`0eooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0=Oooool00ol0
003oooooooooo`0Xooooo`03o`000?oooooooooo02?ooooo000Qooooo`03o`000?oooooooooo02ko
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02?o
oooo000Qooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`0fooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0=_ooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo02?ooooo000Qooooo`03o`000?oooooooooo02kooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool0=_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Cooooo000Q
ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0f
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo02Cooooo000Qooooo`03o`000?oooooooooo02kooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool0=oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Cooooo000Qooooo`03
o`000?oooooooooo02oooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo02Cooooo000Qooooo`?o0000;oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo03Sooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool09?ooool0027ooooo00?o0000ooooooooool0;ooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool09?oo
ool0027ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo03Sooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool09Oooool0027ooooo00?o0000ooooooooool0;oooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`0iooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool09Oooool0027o
oooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03Wo
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool09Oooool0027ooooo00?o0000ooooooooool0<?ooool00ol0003ooooo
ooooo`0Sooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool08oooool00ol0003ooooo
ooooo`0jooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool09Oooool0027ooooo00?o
0000ooooooooool0<?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03[ooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool09Oooool0027ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0S
ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0j
ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool09_ooool0027ooooo00?o0000oooo
ooooool0<?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03[ooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo02;ooooo00?o0000oooo
ooooool09_ooool0027ooooo0ol0000aooooo`03o`000?oooooooooo02;ooooo00?o0000oooooooo
ool0>_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool08_ooool00ol0003oooooooooo`0Vooooo`008Oooool00ol0003oooooooooo`0aooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo03cooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Vooooo`008Ooo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0??oo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`0Vooooo`008Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo03cooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Wooooo`008Oooool00ol0
003oooooooooo`0aooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0??ooool00ol0
003oooooooooo`0Qooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`0Wooooo`008Oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo023o
oooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03go
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Wooooo`008Oooool00ol0003ooooo
ooooo`0booooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0?_ooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`0Wooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4
A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Wooooo`001oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000oooooooo
ool0<_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03kooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool0:?ooool000Oooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;o
oooo0ol0000booooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0?_ooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`0Xooooo`001oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_oo
ool00oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool0@?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo03oooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`0Xooooo`001oooool01Ol0003ooooooooooooooooo000000co
oooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo03?ooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool0@?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Sooooo0007ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
03?ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
02Sooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo03?ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`10oooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo02Wooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`00
00Gooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
047ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool0:Oooool0027ooooo00?o0000ooooooooool0=?ooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`11ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0:Oooool0027ooooo
00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo04;ooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool0:Oooool0027ooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`12ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0:Oooool0027ooooo00?o0000
ooooooooool0=?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04?ooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool0:_ooool0027ooooo0ol0000dooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool0A?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04?ooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0Zooooo`008Oooool00ol0003oooooooooo`0eooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo04?ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Zooooo`00
8Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
A?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`0Zooooo`008Oooool00ol0003oooooooooo`0eooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo04Gooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Zooooo`008Oooool0
0ol0003oooooooooo`0eooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0AOooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`0[ooooo`008Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
04Gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0[ooooo`008Oooool00ol0003o
ooooooooo`0fooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0A_ooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`0[ooooo`008Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Kooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`0[ooooo`008Oooool00ol0003ooooooooo
o`0fooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0Aoooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`0[ooooo`008Oooool3o`0003Oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`18
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo02cooooo000Qooooo`03o`000?oooooooooo03Oooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool0Aoooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02cooooo000Qooooo`03
o`000?oooooooooo03Oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`18ooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo02cooooo000Qooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
BOooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02cooooo000Qooooo`03o`000?oo
oooooooo03Oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1:ooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo02cooooo000Qooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`1:ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0B_ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02gooooo000Qooooo`03o`000?oooooooooo
03Sooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
02gooooo000Qooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`1;ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0Boooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo02gooooo000Qooooo`03o`000?oooooooooo03Sooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02gooooo
000Qooooo`?o0000>?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo04cooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool0;Oooool0027ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1=
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0;_ooool0027ooooo00?o0000oooo
ooooool0>Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04gooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool0;_ooool0027ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo04kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1>ooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool0;_ooool0027ooooo00?o0000ooooooooool0
>Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
;oooool0027ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo04kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1@ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool0;oooool0027ooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`1@ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0;oooool0
027ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
053ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool0<?ooool0027ooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`1Aooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0<?ooool0027ooooo
0ol0000kooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0D_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0`ooooo`008Oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0D_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05;ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0aooooo`008Oooool00ol0003oooooooooo`0l
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0a
ooooo`008Oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool0E?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo05Cooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0booooo`008Oooool00ol0003oooooooooo`0mooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo05Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0booooo`00
8Oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
E_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0cooooo`008Oooool00ol0003oooooooooo`0nooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo05Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0cooooo`006?ooool4
o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1I
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0=?ooool001[ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo00;ooooo0_l0001Loooo
o`;o00001?ooool00ol0003oooooooooo`1Kooooo`04o`000?ooooooooooooooo`;o0000=oooool0
01[ooooo00?o0000ooooooooool01?ooool3o`00047ooooo1Ol0001Nooooo`Go0000G_ooool5o`00
03Sooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`00
6_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006?ooool00omEEEGoIVIVo`000006oooo
o`03o`000?oooooooooo0?ooooooAOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool009cooooo0_l0000oooooo`;o0000
ROooool009cooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`27ooooo`00ROooool3
o`0000;ooooo00Ko<S8boa0@4?ooooooooooonk^k_mEEED2o`000003odA4A?nj^[[ooooo00?ooooo
00?o0000ooooooooool00_ooool01_o^k^koIVIVo`000?l0003o<S8bokZj^SOooooo00?o0000oooo
ooooool0Qoooool008[ooooo00Go0000ooooooooooooc<c<oa0@4003ooooo`06oeEEEOmgMgOooooo
onk^k_mgMgOo410@1?ooool00ol0003oooooooooo`02ooooo`;oMgMg00CoEEEEohN7QooMgMgoA4A4
=oooool00ol0003oooooooooo`27ooooo`00R_ooool01Ol0003ooooooooooomEEEGoQhN700?ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`03oiRHV?oooooo000003[ooooo
00?o0000ooooooooool0Qoooool008[ooooo00Go0000oooooooMgMgo0000onk^kP03ooooo`Ko0000
1?ooool00ol0003oooooooooo`02ooooo`03oiRHV?oooooo000000?o00004_ooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Qoooool008[ooooo0ol0
00000ol@413oV9RHooooo`02ooooo`06oeEEEOn7QhOok^k^oooooon7QhOo<S8b1?ooool00ol0003o
ooooooooo`02ooooo`03ogMgMon7QhOoIVIV00;o^[Zj00?o<S8booooooooool03oooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Qoooool008[ooooo
00Go0000ooooooooooooc<c<o`000003ooooo`06onk^k_mEEEGo0000o`000?m4A4Cok^k^1?ooool0
0ol0003oooooooooo`03ooooo`06ofIVI_l0003o0000odA4A?o^k^kooooo0ol00004ooooo`;o0000
00?oooooo`000?l000000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000[ooooo
0ol00006ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo08Oooooo
002:ooooo`05o`000?ooooooooooolc<c?l000003Oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooool000001?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0Qoooool008Wooooo1?l000000ol@413oZJVYoooo
o`0<ooooo`;o00002oooool00ol0003oooooooooo`04ooooo`;o00001Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo1?l00002ooooo`04o`000?ooooooooooo`0000Gooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`;o0000ROooool00:Wooooo00?o
0000ooooooooool01?ooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooool000002_ooool3o`0000Cooooo1?l00004ooooo`03o`000?oooooooooo08gooooo002X
ooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`2>ooooo`00[oooool2o`0000Sooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`2?ooooo`00ZOooool00ol0003oooooooooo`2looooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-2, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0505254 0.309018 0.294305 [
[.15012 .29652 -9 -9 ]
[.15012 .29652 9 0 ]
[.27644 .29652 -3 -9 ]
[.27644 .29652 3 0 ]
[.40275 .29652 -9 -9 ]
[.40275 .29652 9 0 ]
[.52906 .29652 -6 -9 ]
[.52906 .29652 6 0 ]
[.65538 .29652 -12 -9 ]
[.65538 .29652 12 0 ]
[.78169 .29652 -6 -9 ]
[.78169 .29652 6 0 ]
[.908 .29652 -12 -9 ]
[.908 .29652 12 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .01471 -12 -4.5 ]
[.01131 .01471 0 4.5 ]
[.01131 .16187 -24 -4.5 ]
[.01131 .16187 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[.5 .63053 -37.9062 0 ]
[.5 .63053 37.9062 12.625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15012 .30902 m
.15012 .31527 L
s
[(2.5)] .15012 .29652 0 1 Mshowa
.27644 .30902 m
.27644 .31527 L
s
[(5)] .27644 .29652 0 1 Mshowa
.40275 .30902 m
.40275 .31527 L
s
[(7.5)] .40275 .29652 0 1 Mshowa
.52906 .30902 m
.52906 .31527 L
s
[(10)] .52906 .29652 0 1 Mshowa
.65538 .30902 m
.65538 .31527 L
s
[(12.5)] .65538 .29652 0 1 Mshowa
.78169 .30902 m
.78169 .31527 L
s
[(15)] .78169 .29652 0 1 Mshowa
.908 .30902 m
.908 .31527 L
s
[(17.5)] .908 .29652 0 1 Mshowa
.125 Mabswid
.04907 .30902 m
.04907 .31277 L
s
.07433 .30902 m
.07433 .31277 L
s
.0996 .30902 m
.0996 .31277 L
s
.12486 .30902 m
.12486 .31277 L
s
.17539 .30902 m
.17539 .31277 L
s
.20065 .30902 m
.20065 .31277 L
s
.22591 .30902 m
.22591 .31277 L
s
.25117 .30902 m
.25117 .31277 L
s
.3017 .30902 m
.3017 .31277 L
s
.32696 .30902 m
.32696 .31277 L
s
.35222 .30902 m
.35222 .31277 L
s
.37749 .30902 m
.37749 .31277 L
s
.42801 .30902 m
.42801 .31277 L
s
.45328 .30902 m
.45328 .31277 L
s
.47854 .30902 m
.47854 .31277 L
s
.5038 .30902 m
.5038 .31277 L
s
.55433 .30902 m
.55433 .31277 L
s
.57959 .30902 m
.57959 .31277 L
s
.60485 .30902 m
.60485 .31277 L
s
.63011 .30902 m
.63011 .31277 L
s
.68064 .30902 m
.68064 .31277 L
s
.7059 .30902 m
.7059 .31277 L
s
.73116 .30902 m
.73116 .31277 L
s
.75643 .30902 m
.75643 .31277 L
s
.80695 .30902 m
.80695 .31277 L
s
.83222 .30902 m
.83222 .31277 L
s
.85748 .30902 m
.85748 .31277 L
s
.88274 .30902 m
.88274 .31277 L
s
.93327 .30902 m
.93327 .31277 L
s
.95853 .30902 m
.95853 .31277 L
s
.98379 .30902 m
.98379 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01471 m
.03006 .01471 L
s
[(-1)] .01131 .01471 1 0 Mshowa
.02381 .16187 m
.03006 .16187 L
s
[(-0.5)] .01131 .16187 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(0.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04414 m
.02756 .04414 L
s
.02381 .07357 m
.02756 .07357 L
s
.02381 .103 m
.02756 .103 L
s
.02381 .13243 m
.02756 .13243 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -98.9062 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.625 moveto
(@) show
81.000 13.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\343) show
87.000 9.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344) show
93.000 9.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
97.188 9.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
( ) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
99.000 9.625 moveto
(H) show
103.188 9.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
107.375 9.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
113.375 9.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
119.375 9.625 moveto
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
123.562 9.625 moveto
(L) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
128.812 13.625 moveto
(D) show
134.812 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .39996 m
.04262 .29193 L
.06244 .18087 L
.08255 .0882 L
.08806 .06834 L
.09396 .05026 L
.09948 .03651 L
.10458 .0267 L
.10714 .02285 L
.10954 .01991 L
.11204 .01754 L
.11337 .01657 L
.1148 .01575 L
.11548 .01545 L
.11622 .01518 L
.11702 .01495 L
.11776 .01481 L
.11853 .01473 L
.11924 .01472 L
.11989 .01475 L
.12059 .01485 L
.12123 .01499 L
.12193 .01519 L
.12335 .01578 L
.12466 .01653 L
.12589 .0174 L
.1285 .01984 L
.13097 .02287 L
.13561 .03038 L
.1406 .04108 L
.14603 .05568 L
.15542 .08775 L
.1658 .13197 L
.18681 .24201 L
.20778 .36327 L
.22701 .46684 L
.24586 .54651 L
.25533 .57476 L
.2607 .58668 L
.2657 .59495 L
.26833 .59819 L
.27075 .60048 L
.27201 .60141 L
.27341 .60222 L
.27411 .60255 L
.27486 .60283 L
.27557 .60304 L
.27622 .60318 L
.27749 .60332 L
.27866 .60328 L
Mistroke
.27995 .60305 L
.28067 .60284 L
.28132 .6026 L
.28252 .60203 L
.28381 .60123 L
.28616 .59929 L
.2884 .59684 L
.29087 .5935 L
.29584 .58471 L
.30474 .56239 L
.31497 .5271 L
.32429 .48717 L
.34522 .37783 L
.36596 .25794 L
.38512 .15427 L
.40374 .07447 L
.41314 .04564 L
.41849 .03324 L
.42108 .02832 L
.4235 .02441 L
.42597 .02109 L
.42821 .01867 L
.4307 .01666 L
.43207 .01585 L
.43336 .01529 L
.43462 .01492 L
.43525 .0148 L
.43595 .01473 L
.43718 .01474 L
.43833 .0149 L
.43903 .01508 L
.43969 .0153 L
.44093 .01584 L
.44227 .01662 L
.44372 .01771 L
.44594 .01982 L
.44838 .0228 L
.45334 .03089 L
.45793 .04076 L
.46224 .05206 L
.47205 .08459 L
.4824 .12798 L
.50089 .22304 L
.53897 .43892 L
.55856 .52911 L
.5642 .5495 L
.56952 .56603 L
.57427 .57835 L
.5795 .58916 L
.58191 .59315 L
Mistroke
.58451 .59671 L
.58696 .59938 L
.5892 .60123 L
.59051 .60204 L
.59173 .60261 L
.59242 .60287 L
.59306 .60305 L
.59379 .6032 L
.59448 .60329 L
.59573 .60331 L
.59688 .60317 L
.59815 .60283 L
.59879 .6026 L
.59949 .60228 L
.6019 .60077 L
.60409 .59881 L
.60663 .59588 L
.60903 .59243 L
.61329 .58473 L
.61793 .57413 L
.62734 .54589 L
.63772 .50527 L
.65873 .39994 L
.67972 .27925 L
.69896 .17259 L
.71782 .08688 L
.7273 .05477 L
.73263 .04057 L
.73767 .0299 L
.7426 .02213 L
.74538 .01895 L
.74671 .01774 L
.74795 .0168 L
.74908 .01609 L
.75011 .01557 L
.75126 .01514 L
.75249 .01484 L
.75367 .01472 L
.75495 .01477 L
.75617 .01499 L
.75729 .01535 L
.75861 .01595 L
.76004 .01683 L
.76262 .01902 L
.76513 .02187 L
.76744 .02512 L
.7727 .03471 L
.77825 .04804 L
.78776 .07811 L
.79794 .1193 L
Mistroke
.81629 .21161 L
.83615 .32544 L
.85772 .44563 L
.86779 .49455 L
.87848 .53835 L
.88759 .56774 L
.89278 .58075 L
.89764 .59035 L
.90004 .59414 L
.9026 .59746 L
.90407 .59904 L
.90541 .60026 L
.90676 .6013 L
.90801 .60206 L
.9092 .60262 L
.91045 .60303 L
.91171 .60327 L
.91243 .60332 L
.91309 .60331 L
.9143 .60318 L
.9154 .6029 L
.91667 .60241 L
.91788 .60178 L
.92011 .60016 L
.92248 .59782 L
.92675 .59202 L
.93134 .58353 L
.9364 .57153 L
.94639 .54029 L
.95555 .50369 L
.97619 .39996 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  FontSlant->"Italic",
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool001So
oooo1?l000000ol@413oooooooooo`02ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000?ooooo`Ko00001Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000
ooooooooool01?ooool3o`0001Wooooo1Ol0001Nooooo`Go0000G_ooool5o`00063ooooo000Joooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo05_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Koooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0GOooool001[ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0FOooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05Wooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`1Looooo`006_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Hooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo05_ooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Fooo
ool0027ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo05Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Eooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0F_ooool0027ooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`1Eooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0F_ooool0027o
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo05Co
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0F_ooool0027ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`1Cooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0FOooool0027ooooo0ol0
000Dooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0D_ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`1Iooooo`008Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool0DOooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo057ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`1Hooooo`008Oooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo057ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Hoooo
o`008Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool0Coooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo053ooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`1Gooooo`008Oooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo053ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1Gooooo`008Ooo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0C_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`1Gooooo`008Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo04kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Fooooo`008Oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0COooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`1Fooooo`008Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04go
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Fooooo`008Oooool3o`00017ooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo05Gooooo
000Qooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`1<ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0C?ooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo05Gooooo000Qooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool0Boooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo05Gooooo000Qoooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1:oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo05Gooooo000Qooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool0B_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo05Cooooo000Qooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1:ooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo05Cooooo000Qooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0BOoo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo05Cooooo000Qooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`18ooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo05Cooooo000Qooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`18ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0B?ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo05?ooooo000Qooooo`?o00003oooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`17ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0Doooool0027ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Oooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool0Doooool0027ooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`17ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0Doooool0027ooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Kooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool0Doooool0027ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo04Kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`15oooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0D_ooool0027ooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04Gooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool0D_ooool0027ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo04Gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`15ooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool0D_ooool0027ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0D_oo
ool0027ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo04?ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`13ooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool0DOooool0027ooooo0ol0000=ooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
04?ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1Aooooo`008Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0@oooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`1Aooooo`008Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo04?ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`1Aooooo`008Oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0@_ooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`1Aooooo`008Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool0@Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo047ooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`1@ooooo`008Oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo047ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1@oooo
o`008Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool0@?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo047ooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`1@ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo043ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1@oooo
o`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo
00?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
043ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool0D?ooool000Go00000_ooool01Ol@413ooooooooooooooooo410@
013ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
03oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1?ooooo`001oooool01Ol0003o
oooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool3o`0000[ooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool0?oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo04oooooo0007ooooo`05
o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03kooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool0Coooool000Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo03kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0nooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool0Coooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0n
ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0Coooool000Oooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo03kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1>ooooo`008Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0?_ooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`1>ooooo`008Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03go
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1>ooooo`008Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0??ooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool08Oooool00ol0003ooooo
ooooo`1>ooooo`008Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo027ooooo00?o
0000ooooooooool0??ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03cooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`1>ooooo`008Oooool3o`0000Sooooo00?o0000
ooooooooool08_ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool0??ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo04gooooo000Qoooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0loooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Roooo
o`03o`000?oooooooooo04gooooo000Qooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02;ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo04gooooo000Qooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0jooooo`03o`00
0?oooooooooo02?ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Sooooo`03o`00
0?oooooooooo04gooooo000Qooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0>_oo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo04gooooo000Qooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0jooooo`03o`000?oooooo
oooo02?ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo
oooo04cooooo000Qooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`0jooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0>_ooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo04cooooo000Qooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo02?o
oooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo04co
oooo000Qooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0hooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>Oooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo04cooooo000Qooooo`?o00001oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0hooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0C?ooool0027ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool0Boooool0027ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo03Sooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0Boooool0027ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo03Sooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool0Boooool0027ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo03Sooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool0Boooool0027ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0Booo
ool0027ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo03Kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0fooooo`03o`000?oooooo
oooo02Oooooo00?o0000ooooooooool0Boooool0027ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`0fooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0B_ooool0027o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo02So
oooo00?o0000ooooooooool0B_ooool0027ooooo0ol00005ooooo`03o`000?oooooooooo02Sooooo
00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo03Kooooo
00?o0000ooooooooool0:?ooool00ol0003oooooooooo`1:ooooo`008Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0=Oooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`1:ooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool0=?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo03Cooooo00?o0000
ooooooooool0:Oooool00ol0003oooooooooo`1:ooooo`008Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Yoooo
o`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1:oooo
o`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Wooooo00?o0000oooooooo
ool0=?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo03Cooooo00?o0000oooooooo
ool0:_ooool00ol0003oooooooooo`19ooooo`008Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo02[ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo03Cooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`19ooooo`008Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01?ooooo1Ol00005ooooo`;o8B4Q1Ooo
ool01om4A4Co0000o`000?lb<S;ogMgMooooool000006?ooool01Om4A4Co0000o`000?lb<S;ogMgM
01Wooooo00Go0000oooooooooooo0000onk^kP06ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb
<S;ogMgM01Gooooo1Ol000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^5?ooool4o`00
0003oa0@4?oooooooooo00Go00001Oooool2ob4Q8@?ooooo00?o0000oooooom4A4@00_l000000olb
<S;ogMgMooooo`0Aooooo`Co000000Go410@ooooooooooooooooodA4A002o`000003oc8b<_oMgMgo
oooo00Kooooo00?o0000ooooooooool02?ooool4o`000003oa0@4?oooooooooo00;ooooo00?o0000
onk^k_ooool01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Tooooo`008Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo01?ooooo00GoV9RHob4Q8Oo^k^koooooodA4
A005ooooo`;o8B4Q2?ooool01OmgMgOo<S8boooooooooooo000001[ooooo00?oMgMgoc8b<_ooool0
5oooool01_l0003oooooooooooooooooEEEEojVYZ@Kooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo
01Gooooo00?o0000ooooool000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg01Kooooo00?o0000
ooooooooool00_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo0_lQ8B42ooooo`03o`000?oo
oooooooo00?ooooo00?oMgMgoc8b<_ooool04oooool00ol0003oooooooooo`06ooooo`03ogMgMolb
<S;ooooo00Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`04ooooo`03oeEEEOnY
ZJWooooo00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo02?ooooo000Qooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool05?ooool00onHV9So8B4Qonk^kP0Aooooo`04o`000?oooooo
ooooo`0001_ooooo00?o0000ooooooooool05_ooool01_l0003oooooooooooooooooZJVYoeEEEA7o
oooo00?o0000ooooooooool05?ooool00ol0003oooooo`000004ooooo`05oa0@4?oooooooooooooo
ool@41005_ooool00ol0003oooooooooo`03ooooo`03oiRHV?lQ8B7ok^k^00[ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo00?oZJVYoeEE
EOooool04?ooool00ol0003oooooooooo`0Rooooo`008Oooool3o`0000Cooooo00?o0000oooooooo
ool05Oooool00onHV9So8B4Qonk^kP0?ooooo`05ogMgMolb<S;oooooooooool000006_ooool00omg
MgOo<S8booooo`0Gooooo`03o`000?oooooooooo00;ooooo00?o8B4Qooooooooool03_ooool00omg
MgOo<S8booooo`0Eooooo`03o`000?oooooo000000Cooooo00Go0000ooooooooooooooooo`00000F
ooooo`03o`000?oooooooooo00Cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03
ooooo`03ogMgMolb<S;ooooo01?ooooo00?o0000ooooooooool01_ooool00omgMgOo<S8booooo`06
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01Oooool00olQ8B7oooooooooo`0>
ooooo`03ogMgMolb<S;ooooo02?ooooo000Qooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool05_ooool00omgMgOoIVIVooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool0
0ol0003oooooooooo`0Eooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06?ooool00ol0003ooooooooo
o`02ooooo`03oeEEEOo<c<cooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Fooooo`03o`00
0?oooooo000000Cooooo00Go0000ooooooooooooooooo`00000Fooooo`03o`000?oooooooooo00Go
oooo00?oMgMgofIVI_ooool02?ooool02?l0003oooooooooool0003o8B4Qo`000?lb<S;oc<c<5?oo
ool00ol0003oooooooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`02?ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Gooooo00?oEEEEolc<c?ooool02oooool01Ol0003o8B4Q
o`000?lb<S;oc<c<02Cooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00;ooooo00?oZJVYogMgMoooool0
2oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo000000Cooooo00Go410@oooooooooooo
oooooa0@400Fooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool01?l0003o
ooooooooool0000Hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo00?oZJVYogMgMoooool02oooool00ol0
003oooooooooo`0Vooooo`008Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Co
oooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo410@00?ooooo00?o<S8boooo
ooooool02_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo000000Cooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0Fooooo`03o`000?oooooooooo00;ooooo00Go0000okZj^_ooooooV9RHoa0@
4009ooooo`04o`000?ooooooooooo`0001Sooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool01Ol@413ooooo
oooooooooooo<S8b00cooooo00?o0000ooooooooool09_ooool0027ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Dooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?ooool4o`0000Co
oooo00?o0000ooooooooool05?ooool4o`0001Sooooo00?o0000ooooooooool01Ol0000<ooooo`Co
00005oooool00omEEEGo0000o`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h05?ooool00omE
EEGoIVIVo`000004ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`02?ooool01?l0003ooooooooooooo
ool4o`0001?ooooo00?oEEEEofIVI_l000001Oooool4o`0000Wooooo00?o0000ooooooooool01ooo
ool00omEEEGoIVIVo`000004ooooo`Go00003?ooool4o`0002Gooooo000Qooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooo
oooo02gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooo
oooo04Sooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0;Oooool00ol0
003oooooooooo`0`ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0<?ooool00ol0
003oooooooooo`0]ooooo`03o`000?oooooooooo04Sooooo000Qooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02go
oooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo03go
oooo0_l00002ooooo`;o00001?ooool0027ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0_ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0;Oooool00ol0003ooooo
ooooo`0`ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0?Oooool01_o^k^ko8B4Q
ohN7Qonj^[[o0000omgMg@Cooooo000Joooooooo0000>_l0000<ooooo`04omgMgOl0003o410@olc<
c0Gooooo000Qooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooo`000007
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0?
ooooo`04onk^k_lQ8B7o410@onk^kPGooooo000Qooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo0_l0
0007ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool2o`0000Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool00000
0oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0_ooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0?ooooo`04ob4Q8OmgMgOoMgMgoc8b<PGooooo000Qooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0^ooooo`03o`00
0?oooooooooo02oooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0_ooooo`03o`00
0?oooooooooo03gooooo0_l00002ooooo`;o00001?ooool0027ooooo00Go0000oooooooooooooooo
o`00000booooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0;oooool00ol0003ooooo
ooooo`0^ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0A_ooool0027ooooo00Go
0000ooooooooooooooooo`00000cooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0
;oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
A_ooool0027ooooo00Go0000ooooooooooooooooo`00000cooooo`03o`000?oooooooooo02gooooo
00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool0A_ooool0027ooooo00Go0000ooooooooooooooooo`00000cooooo`03o`00
0?oooooooooo02gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0]ooooo`03o`00
0?oooooooooo033ooooo00?o0000ooooooooool0A_ooool0027ooooo00Go0000oooooooooooooooo
o`00000cooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0<Oooool00ol0003ooooo
ooooo`0/ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0A_ooool0027ooooo00Go
0000ooooooooooooooooo`00000cooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0
<Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
A_ooool0027ooooo1?l0000eooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0<Ooo
ool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0AOoo
ool0027ooooo00Co0000oooooooooooo0000=Oooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo03;ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0booooo`03o`000?oo
oooooooo04Gooooo000Qooooo`04o`000?ooooooooooo`0003Gooooo00?o0000ooooooooool0:ooo
ool00ol0003oooooooooo`0booooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0<_oo
ool00ol0003oooooooooo`15ooooo`008Oooool01?l0003oooooooooool0000eooooo`03o`000?oo
oooooooo02_ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo03;ooooo00?o0000ooooooooool0AOooool0027ooooo00Co0000oooooooooooo0000=Ooo
ool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0:_oo
ool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo04Gooooo000Qooooo`04o`000?oooooo
ooooo`0003Kooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0cooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`14ooooo`008Oooool0
0ol0003oooooo`00000gooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0<oooool0
0ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0A?ooool0
027ooooo00?o0000ooooool00000=oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
03Cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo
04Cooooo000Qooooo`03o`000?oooooo000003Oooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`0dooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0=?ooool00ol0003o
ooooooooo`14ooooo`008Oooool3o`0003Oooooo00?o0000ooooooooool0:Oooool00ol0003ooooo
ooooo`0dooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0=?ooool00ol0003ooooo
ooooo`14ooooo`008Oooool00ol0003oooooo`00000gooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool0=Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo03Kooooo00?o
0000ooooooooool0@oooool0027ooooo0_l0000iooooo`03o`000?oooooooooo02Oooooo00?o0000
ooooooooool0=Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo03Kooooo00?o0000
ooooooooool0@oooool0027ooooo0_l0000iooooo`03o`000?oooooooooo02Oooooo00?o0000oooo
ooooool0=_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo03Kooooo00?o0000oooo
ooooool0@oooool0027ooooo0_l0000iooooo`03o`000?oooooooooo02Oooooo00?o0000oooooooo
ool0=_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo03Kooooo00?o0000oooooooo
ool0@oooool0027ooooo0_l0000iooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
=_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0
@oooool0027ooooo0_l0000iooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0=ooo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0@_oo
ool0027ooooo0_l0000jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0=oooool0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0@_ooool0
027ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
03Oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo
04;ooooo000Qooooo`?o0000>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03So
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo04;o
oooo000Qooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0hooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo01[ooooo000Qooooo`03o`000?oooooooooo03Wooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0>?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01[ooooo000Q
ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0i
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo01[ooooo000Qooooo`03o`000?oooooooooo03[ooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool0>_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01_ooooo000Qooooo`03
o`000?oooooooooo03[ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0iooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo01_ooooo000Qooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0
>_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01_ooooo000Qooooo`03o`000?oo
oooooooo03[ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo02?ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo01_ooooo000Qooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool08_ooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0>oooool0
0ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01_ooooo000Qooooo`?o0000>oooool00ol0
003oooooooooo`0Qooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool08_ooool00ol0
003oooooooooo`0looooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool07?ooool0027o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool07?ooool0027ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool08Oooool00ol0003ooooo
ooooo`0looooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool07?ooool0027ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03gooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo027ooooo00?o
0000ooooooooool07?ooool0027ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0m
ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool07Oooool0027ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03gooooo00?o0000oooo
ooooool08?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool07Oooool0027ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Oooooo`03
o`000?oooooooooo03gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0nooooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool07Oooool000Oooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000oooo
ooooool0??ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03kooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool07Oooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omg
MgOo<S8booooo`03ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`0oooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0?_ooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo01gooooo0007ooooo`05oa0@4?oooooooooooooo
ool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000??ooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo03oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`10oooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool07_ooool000Oooooo00Go0000oooooooo
ooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0??ooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`10ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool07_ooool000Oo
oooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool0
0ol0003oooooooooo`0mooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0?oooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0Nooooo`001oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool0@?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo043ooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`0Nooooo`001oooool01OmgMgOoV9RHoooooonHV9So
MgMg00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo043ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Nooooo`001oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo03gooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool0@_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01oooooo000Qoooo
o`03o`000?oooooooooo03gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`11oooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo01oooooo000Qooooo`03o`000?oooooooooo03kooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool0@_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01oooooo000Qooooo`03o`00
0?oooooooooo03kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`12ooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo01oooooo000Qooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0@_oo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo023ooooo000Qooooo`?o0000?_ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`14ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool08?ooool0
027ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
04?ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool08?ooool0027ooooo00?o0000ooooooooool0?oooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`14ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool08?ooool0027ooooo
00?o0000ooooooooool0?oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool08?ooool0027ooooo00?o0000ooooooooool0?oooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`14ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool08Oooool0027ooooo00?o0000
ooooooooool0@?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Gooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool08Oooool0027ooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo04Gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`16oooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool08Oooool0027ooooo00?o0000oooooooo
ool0@?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Oooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool08Oooool0027ooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo04Oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`16ooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool08_ooool0027ooooo0ol00010ooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo04Oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Rooooo`008Oooool0
0ol0003oooooooooo`11ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0Aoooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`0Rooooo`008Oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
04Sooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Rooooo`008Oooool00ol0003o
ooooooooo`11ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0BOooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`0Sooooo`008Oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool0BOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04Wooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Sooooo`008Oooool00ol0003ooooooooo
o`12ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0BOooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`0Sooooo`008Oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool0BOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04[ooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`0Sooooo`008Oooool00ol0003oooooooooo`12oooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo04[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Toooo
o`008Oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool0Boooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo04_ooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`0Tooooo`008Oooool3o`0004?ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
C?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02Cooooo000Qooooo`03o`000?oo
oooooooo04?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1=ooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo02Gooooo000Qooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`1=ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0COooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02Gooooo000Qooooo`03o`000?oooooooooo
04Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
02Gooooo000Qooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`1>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0C_ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo02Kooooo000Qooooo`03o`000?oooooooooo04Cooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool0Coooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02Kooooo
000Qooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`1?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo02Kooooo000Qooooo`03o`000?oooooooooo04Gooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0D?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02Oooooo000Qoooo
o`03o`000?oooooooooo04Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Aoooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo02Oooooo000Qooooo`?o0000A_ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo057ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Booooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool09oooool0027ooooo00?o0000ooooooooool0
A_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
9oooool0027ooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo05?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Dooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool0:?ooool0027ooooo00?o0000ooooooooool0Aoooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`1Dooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0:?ooool0
027ooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
05Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0:?ooool0027ooooo00?o0000ooooooooool0Aoooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`1Fooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0:Oooool0027ooooo
00?o0000ooooooooool0B?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05Sooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0:_ooool001Sooooo1?l000000ol@413oooooooooo`02ooooo`03o`000?oo
oooooooo04Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Iooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo02[ooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0B_ooool2
o`0000?ooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo05[ooooo0_l00003ooooo`;o0000;Oooool001[ooooo00?o0000ooooooooool01?ooool3o`00
04_ooooo1Ol0001Nooooo`Go0000G_ooool5o`0002kooooo000Jooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5
ooooo`006?ooool00omEEEGoIVIVo`000006ooooo`03o`000?oooooooooo0?ooooooAOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool009cooooo0_l0000oooooo`;o0000ROooool009cooooo00?o0000ooooooooool0?ooo
ool00ol0003oooooooooo`27ooooo`00ROooool3o`0000;ooooo00Ko<S8boa0@4?ooooooooooonk^
k_mEEED2o`000003odA4A?nj^[[ooooo00?ooooo00?o0000ooooooooool00_ooool01_o^k^koIVIV
o`000?l0003o<S8bokZj^SOooooo00?o0000ooooooooool0Qoooool008[ooooo00Go0000oooooooo
ooooc<c<oa0@4003ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo410@1?ooool00ol0003ooooooooo
o`02ooooo`;oMgMg00CoEEEEohN7QooMgMgoA4A4=oooool00ol0003oooooooooo`27ooooo`00R_oo
ool01Ol0003ooooooooooomEEEGoQhN700?ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`02ooooo`03oiRHV?oooooo000003[ooooo00?o0000ooooooooool0Qoooool008[ooooo00Go
0000oooooooMgMgo0000onk^kP03ooooo`Ko00001?ooool00ol0003oooooooooo`02ooooo`03oiRH
V?oooooo000000?o00004_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0Qoooool008[ooooo0ol000000ol@413oV9RHooooo`02ooooo`06oeEEEOn7
QhOok^k^oooooon7QhOo<S8b1?ooool00ol0003oooooooooo`02ooooo`03ogMgMon7QhOoIVIV00;o
^[Zj00?o<S8booooooooool03oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0Qoooool008[ooooo00Go0000ooooooooooooc<c<o`000003ooooo`06
onk^k_mEEEGo0000o`000?m4A4Cok^k^1?ooool00ol0003oooooooooo`03ooooo`06ofIVI_l0003o
0000odA4A?o^k^kooooo0ol00004ooooo`;o000000?oooooo`000?l000000oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooo000000[ooooo0ol00006ooooo`;o00001?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo08Oooooo002:ooooo`05o`000?ooooooooooolc<c?l00000
3Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooool00000
1?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
Qoooool008Wooooo1?l000000ol@413oZJVYooooo`0<ooooo`;o00002oooool00ol0003ooooooooo
o`04ooooo`;o00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo1?l0
0002ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`;o0000ROooool00:Wooooo00?o0000ooooooooool01?ooool00ol0003oooooo`00
0004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000002_ooool3o`0000Cooooo1?l0
0004ooooo`03o`000?oooooooooo08gooooo002Xooooo`;o00001_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2>
ooooo`00[oooool2o`0000Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`2?oooo
o`00ZOooool00ol0003oooooooooo`2looooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-2, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0505254 0.309017 0.294302 [
[.15012 .29652 -9 -9 ]
[.15012 .29652 9 0 ]
[.27644 .29652 -3 -9 ]
[.27644 .29652 3 0 ]
[.40275 .29652 -9 -9 ]
[.40275 .29652 9 0 ]
[.52906 .29652 -6 -9 ]
[.52906 .29652 6 0 ]
[.65538 .29652 -12 -9 ]
[.65538 .29652 12 0 ]
[.78169 .29652 -6 -9 ]
[.78169 .29652 6 0 ]
[.908 .29652 -12 -9 ]
[.908 .29652 12 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .01471 -12 -4.5 ]
[.01131 .01471 0 4.5 ]
[.01131 .16187 -24 -4.5 ]
[.01131 .16187 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[.5 .63053 -37.9062 0 ]
[.5 .63053 37.9062 12.625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15012 .30902 m
.15012 .31527 L
s
[(2.5)] .15012 .29652 0 1 Mshowa
.27644 .30902 m
.27644 .31527 L
s
[(5)] .27644 .29652 0 1 Mshowa
.40275 .30902 m
.40275 .31527 L
s
[(7.5)] .40275 .29652 0 1 Mshowa
.52906 .30902 m
.52906 .31527 L
s
[(10)] .52906 .29652 0 1 Mshowa
.65538 .30902 m
.65538 .31527 L
s
[(12.5)] .65538 .29652 0 1 Mshowa
.78169 .30902 m
.78169 .31527 L
s
[(15)] .78169 .29652 0 1 Mshowa
.908 .30902 m
.908 .31527 L
s
[(17.5)] .908 .29652 0 1 Mshowa
.125 Mabswid
.04907 .30902 m
.04907 .31277 L
s
.07433 .30902 m
.07433 .31277 L
s
.0996 .30902 m
.0996 .31277 L
s
.12486 .30902 m
.12486 .31277 L
s
.17539 .30902 m
.17539 .31277 L
s
.20065 .30902 m
.20065 .31277 L
s
.22591 .30902 m
.22591 .31277 L
s
.25117 .30902 m
.25117 .31277 L
s
.3017 .30902 m
.3017 .31277 L
s
.32696 .30902 m
.32696 .31277 L
s
.35222 .30902 m
.35222 .31277 L
s
.37749 .30902 m
.37749 .31277 L
s
.42801 .30902 m
.42801 .31277 L
s
.45328 .30902 m
.45328 .31277 L
s
.47854 .30902 m
.47854 .31277 L
s
.5038 .30902 m
.5038 .31277 L
s
.55433 .30902 m
.55433 .31277 L
s
.57959 .30902 m
.57959 .31277 L
s
.60485 .30902 m
.60485 .31277 L
s
.63011 .30902 m
.63011 .31277 L
s
.68064 .30902 m
.68064 .31277 L
s
.7059 .30902 m
.7059 .31277 L
s
.73116 .30902 m
.73116 .31277 L
s
.75643 .30902 m
.75643 .31277 L
s
.80695 .30902 m
.80695 .31277 L
s
.83222 .30902 m
.83222 .31277 L
s
.85748 .30902 m
.85748 .31277 L
s
.88274 .30902 m
.88274 .31277 L
s
.93327 .30902 m
.93327 .31277 L
s
.95853 .30902 m
.95853 .31277 L
s
.98379 .30902 m
.98379 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01471 m
.03006 .01471 L
s
[(-1)] .01131 .01471 1 0 Mshowa
.02381 .16187 m
.03006 .16187 L
s
[(-0.5)] .01131 .16187 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(0.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04414 m
.02756 .04414 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .13244 m
.02756 .13244 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -98.9062 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.625 moveto
(@) show
81.000 13.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\343) show
87.000 9.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344) show
93.000 9.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
97.188 9.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
( ) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
99.000 9.625 moveto
(H) show
103.188 9.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
107.375 9.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
113.375 9.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
119.375 9.625 moveto
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
123.562 9.625 moveto
(L) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
128.812 13.625 moveto
(D) show
134.812 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .54711 m
.06244 .36107 L
.08255 .24474 L
.10458 .12948 L
.11448 .08752 L
.11992 .06797 L
.12507 .05205 L
.12986 .03962 L
.13506 .02887 L
.13735 .02506 L
.13979 .02167 L
.14187 .01929 L
.14415 .01725 L
.14546 .01635 L
.14667 .01569 L
.14783 .01522 L
.14907 .01489 L
.15028 .01473 L
.15142 .01474 L
.15245 .01487 L
.15356 .01516 L
.15479 .01563 L
.15613 .01635 L
.15753 .01732 L
.15884 .01843 L
.16133 .02109 L
.16369 .02424 L
.16831 .03222 L
.17252 .0415 L
.18199 .06904 L
.19164 .10576 L
.2019 .15284 L
.22032 .25205 L
.25807 .46344 L
.26749 .50722 L
.27741 .54586 L
.28261 .56254 L
.28829 .57772 L
.29346 .58857 L
.29827 .59605 L
.3009 .59904 L
.30332 .6011 L
.30459 .60191 L
.30598 .60259 L
.30668 .60285 L
.30743 .60307 L
.30814 .60321 L
.30879 .60329 L
.31006 .6033 L
.31123 .60315 L
Mistroke
.31252 .6028 L
.31324 .60252 L
.31389 .60222 L
.31509 .60154 L
.31638 .60061 L
.31873 .59845 L
.32098 .59579 L
.32344 .59222 L
.32841 .58299 L
.33732 .55991 L
.34755 .52384 L
.35686 .48332 L
.37779 .37314 L
.39853 .25321 L
.41769 .1502 L
.43631 .07159 L
.44571 .04353 L
.45106 .0316 L
.45366 .02691 L
.45607 .02323 L
.45854 .02014 L
.46078 .01793 L
.46198 .01698 L
.46327 .01614 L
.46398 .01577 L
.46464 .01547 L
.46593 .01503 L
.46717 .01478 L
.46833 .01472 L
.4696 .01482 L
.47032 .01496 L
.47097 .01514 L
.47228 .01565 L
.4737 .01642 L
.47505 .01737 L
.47629 .01843 L
.48056 .0234 L
.48299 .02714 L
.48527 .03124 L
.49481 .05444 L
.50463 .08774 L
.51497 .1318 L
.53347 .22765 L
.57154 .44322 L
.59113 .53227 L
.59677 .55224 L
.6021 .56833 L
.60684 .58025 L
.61207 .59059 L
.61449 .59436 L
Mistroke
.61708 .59769 L
.61953 .60013 L
.62178 .60176 L
.62308 .60244 L
.6243 .6029 L
.625 .60309 L
.62563 .60321 L
.62636 .6033 L
.62705 .60332 L
.6283 .60322 L
.62946 .60297 L
.63072 .60251 L
.63206 .60184 L
.63426 .60028 L
.63661 .59799 L
.64086 .5923 L
.6459 .58293 L
.6505 .572 L
.66043 .54117 L
.6696 .50468 L
.69037 .40055 L
.71064 .28407 L
.72966 .17802 L
.74784 .09361 L
.75806 .05771 L
.76743 .03378 L
.77217 .02522 L
.77483 .02152 L
.77724 .01884 L
.77949 .01694 L
.78076 .01613 L
.78194 .01554 L
.78296 .01515 L
.78409 .01487 L
.78526 .01473 L
.78637 .01474 L
.78765 .01493 L
.78837 .01512 L
.78904 .01535 L
.79027 .01591 L
.79158 .0167 L
.79409 .01875 L
.79635 .02121 L
.80188 .02964 L
.80707 .04062 L
.81687 .06892 L
.8272 .10849 L
.84569 .19885 L
.88374 .41525 L
.89463 .47152 L
Mistroke
.90494 .51785 L
.91497 .55465 L
.91938 .56784 L
.92423 .58009 L
.9286 .58897 L
.9333 .59619 L
.9359 .59912 L
.93827 .60112 L
.93941 .60186 L
.94065 .60249 L
.94183 .60293 L
.94292 .60319 L
.9442 .60332 L
.94491 .60331 L
.94557 .60325 L
.94679 .603 L
.94807 .60256 L
.94922 .602 L
.9503 .60135 L
.95274 .59936 L
.95539 .59645 L
.9578 .5931 L
.96321 .58324 L
.96943 .56806 L
.97619 .54711 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  FontSlant->"Italic",
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool001So
oooo1?l000000ol@413oooooooooo`02ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000?ooooo`Ko00001Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000
ooooooooool01?ooool3o`0002?ooooo1Ol0001Nooooo`Go0000G_ooool5o`0005Kooooo000Joooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo05[ooooo0_l00004ooooo`03o`000?oooooooooo05_ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1Cooooo`006_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Iooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo05;ooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
D_ooool001Sooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo05Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Aooooo`008Oooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0EOooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`1Aooooo`008Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
05Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1@ooooo`008Oooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0Doooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`1@ooooo`008Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0Doooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo05Cooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`1?ooooo`008Oooool3o`0001kooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0Doooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo04oooooo000Q
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1A
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo04kooooo000Qooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool0D_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo04kooooo000Qooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1@ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo04kooooo000Qooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
D?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo04gooooo000Qooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1>ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo04gooooo000Qooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0C_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04gooooo000Qooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
04cooooo000Qooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`1<ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0COooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo04cooooo000Qooooo`?o00006oooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`1<ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0C?ooool0027ooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04cooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool0C?ooool0027ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1;
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0Boooool0027ooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04[ooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool0Boooool0027ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo04[ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`19ooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool0Boooool0027ooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
Boooool0027ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo04Sooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`18ooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool0B_ooool0027ooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`17ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0B_ooool0
027ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
04Sooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool0B_ooool0027ooooo0ol0000Iooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Oo
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1:ooooo`008Oooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0A_ooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`19ooooo`008Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool0A_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Kooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`19ooooo`008Oooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`19
ooooo`008Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool0AOooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04Gooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`19ooooo`008Oooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo04Gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`18ooooo`00
8Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
A?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`18ooooo`008Oooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo04Cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`18ooooo`008Oooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0A?ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`18ooooo`008Oooool3o`0001Oooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`13ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0@oooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo04Sooooo000Qooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04Oo
oooo000Qooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`12ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0@_ooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo04Oooooo000Qooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool0@Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo04Oooooo000Q
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`12
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo04Oooooo000Qooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool0@Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo04Oooooo000Qooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`10ooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo04Kooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Go
oooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool0@Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo04Kooooo0007ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0@?ooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`16ooooo`001Ol00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`10ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0?oooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo04Kooooo0007ooooo`05o`000?oooooooooooooo
ool000003oooool00omgMgOo<S8booooo`03ooooo`?o00005Oooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo03oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0ooooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool0AOooool000Oooooo00Go0000oooooooo
ooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`15
ooooo`001oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0?_ooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`15ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool0?_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03gooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`15ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00cooooo1?l00005ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`0nooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0?Oooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo04Gooooo000Qooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo
027ooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
04Cooooo000Qooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`0looooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0?Oooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo04Cooooo000Qooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo04Cooooo
000Qooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool08Oooool00ol0003ooooooooo
o`0looooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0??ooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo04Cooooo000Qooooo`?o00004oooool00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0A?ooool0027ooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02;ooooo00?o0000oooo
ooooool0@oooool0027ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Rooooo`03
o`000?oooooooooo03[ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool0@oooool0027ooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0
@oooool0027ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo03[ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0jooooo`03o`000?oo
oooooooo02;ooooo00?o0000ooooooooool0@oooool0027ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`0iooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0@oooool0
027ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
03[ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool0@_ooool0027ooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0Tooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0iooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0@_ooool0027ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo03Sooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool0@_ooool0027ooooo0ol0000Aooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0>?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo03Sooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`12ooooo`008Oooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`12
ooooo`008Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0>?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo03Oooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`11ooooo`008Oooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo03Oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`11ooooo`00
8Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
=_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`11ooooo`008Oooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo02Oooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo03Oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`11ooooo`008Oooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0=_ooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`11ooooo`008Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo
03Gooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`11ooooo`008Oooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0=?ooool00ol0003o
ooooooooo`0Yooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0:?ooool00ol0003o
ooooooooo`10ooooo`008Oooool3o`00013ooooo00?o0000ooooooooool0:?ooool00ol0003ooooo
ooooo`0dooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0=Oooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooooooo043ooooo000Qooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool0:?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02Wooooo00?o
0000ooooooooool0=Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo043ooooo000Q
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0d
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo043ooooo000Qooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0:Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02[ooooo00?o0000oooo
ooooool0=?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo043ooooo000Qooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0dooooo`03
o`000?oooooooooo02[ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo043ooooo000Qooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
:_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0
<oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03oooooo000Qooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool02?ooool5o`0000Gooooo0_lQ8B45ooooo`05odA4A?l0
003o0000oc8b<_oMgMd03?ooool00ol0003oooooooooo`0;ooooo`05odA4A?l0003o0000oc8b<_oM
gMd07?ooool00ol0003ok^k^ooooo`03ooooo`04o`000?oooooo8B4Qob4Q8@Gooooo00GoA4A4o`00
0?l0003o<S8bomgMg@0Fooooo`Co000000Go410@ooooooooooook^k^oc8b<P02o`000003onk^k_oo
oooooooo01;ooooo1?l000000ol@413oooooooooo`05o`0000Gooooo0_lQ8B45ooooo`05odA4A?l0
003o0000oc8b<_oMgMd00oooool00ol0003oooooooooo`0<ooooo`Co000000Go410@oooooooooooo
ooooodA4A002o`000003oc8b<_oMgMgooooo013ooooo1Ol000000ol@413oooooooooo`02ooooo`03
o`000?o^k^kooooo00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd09?ooool0027o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`09ooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool02oooool00ol0003oooooooooo`0>oooo
o`03ogMgMolb<S;ooooo01_ooooo00?oEEEEojVYZOooool00oooool01?l0003oooooob4Q8OlQ8B48
ooooo`03ogMgMolb<S;ooooo01Oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHooooool0
003oMgMg01Kooooo00?o0000ooooooooool00_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo
0_lQ8B48ooooo`03ogMgMolb<S;ooooo00;ooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`06ooooo`03ogMgMolb<S;ooooo013ooooo00Co0000oooooooooooo00001_ooool00omEEEGo
ZJVYooooo`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Sooooo`008Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool06_ooool00onYZJWoEEEE
ooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooo`000?l@41005_ooool00ol0003oooooooooo`03ooooo`03
oiRHV?lQ8B7ok^k^017ooooo00Go0000ooooooooooooooooo`00000@ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool03oooool01?l0003oooooooooool00006ooooo`03ojVYZOmEEEGo
oooo013ooooo00?o0000ooooooooool08_ooool0027ooooo0ol0000>ooooo`03o`000?oooooooooo
00_ooooo00?oV9RHob4Q8Oo^k^h03oooool00omgMgOo<S8booooo`0;ooooo`03o`000?oooooooooo
00kooooo00?oMgMgoc8b<_ooool07?ooool00olQ8B7oooooooooo`02ooooo`03o`000?oooooooooo
00Wooooo00?oMgMgoc8b<_ooool05oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool000005_ooool00ol0003oooooooooo`04ooooo`03oiRHV?lQ8B7ok^k^00oooooo00GoMgMg
oc8b<_ooooooooooo`00000Aooooo`03o`000?oooooooooo00Kooooo00?oMgMgoc8b<_ooool04?oo
ool01?l0003oooooooooool00007ooooo`03ob4Q8Ooooooooooo00kooooo00?oMgMgoc8b<_ooool0
8oooool0027ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0<ooooo`03ogMgMomV
IVKooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00=ooooo`03o`000?oooooooooo00[ooooo
00Go0000ob4Q8Ol0003o<S8bolc<c00Mooooo`03oeEEEOo<c<cooooo00;ooooo00?o0000oooooooo
ool01_ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Sooooo00?o0000ooooooooool00_ooool01Ol0
003ooooooooooooooooo000001Kooooo00?o0000ooooooooool01Oooool00omgMgOoIVIVooooo`0;
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Booooo`03o`000?oooooo000000Oooooo
00?oEEEEolc<c?ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<02Cooooo000Qooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Oooooo`05ojVY
ZOmgMgOoooooooooool000002Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00;o
oooo00Go410@ooooooooooooooooo`00000Fooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo000000Oooooo00?oZJVYogMg
Moooool02oooool00ol0003oooooooooo`0Vooooo`008Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00[ooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Looooo`05oa0@4?oooooooooo
oooooolb<S800_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So000001Kooooo00?o0000ooooooooool00_oo
ool01Ol0003o^[ZjoooooonHV9So410@00cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
o`000004ooooo`05oa0@4?oooooooooooooooolb<S803?ooool00ol0003oooooooooo`0Vooooo`00
8Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c00<ooooo`Co00003_ooool00ol0003oooooooooo`0:ooooo`Co00006oooool5o`0000;o
oooo00?o0000ooooooooool01oooool4o`0001Oooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko
<S8bo`000?lb<S;o000001Cooooo00?oEEEEofIVI_l000001?ooool01OnHV9So410@o`000?lQ8B7o
c<c<00cooooo1?l00003ooooo`03o`000?oooooooooo00gooooo00?oEEEEofIVI_l000001Oooool4
o`0001?ooooo00?o0000ofIVI_l000001?ooool5o`0000cooooo1?l0000Uooooo`008Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0<?ooool00ol0
003oooooooooo`0]ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0;?ooool00ol0
003oooooooooo`0nooooo`008Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02go
oooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02oo
oooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0nooooo`008Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0;oooool00ol0003ooooo
ooooo`0^ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`0cooooo`;o00000_ooool2o`0000Cooooo000Qooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool0;oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02kooooo00?o
0000ooooooooool0;oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo03?ooooo00Ko
k^k^ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`006_ooooooo`0003[o00003?ooool01?oMgMgo0000
oa0@4?o<c<`5ooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo
0_l00007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool2o`0000Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Co
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooool000001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Go
oooo0_l00006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooo`000005ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03oooool01?o^k^ko
8B4Qoa0@4?o^k^h5ooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Co
oooo0_l00007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool2o`0000Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Gooooo0_l00006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooo`000005ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03oooool01?lQ
8B7oMgMgogMgMolb<S85ooooo`008Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
033ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo
02gooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0cooooo`;o00000_ooool2o`00
00Cooooo000Qooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0<?ooool00ol0003o
ooooooooo`0]ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0;Oooool00ol0003o
ooooooooo`0`ooooo`03o`000?oooooooooo03cooooo000Qooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo03cooooo
000Qooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0<Oooool00ol0003ooooooooo
o`0/ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0;Oooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo03cooooo000Qooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool0;Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo03cooooo000Qoooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0/oooo
o`03o`000?oooooooooo037ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0`oooo
o`03o`000?oooooooooo03cooooo000Qooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool0<_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo03;ooooo00?o0000oooooooo
ool0:oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo03_ooooo000Qooooo`?o0000
2_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0
<_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0
>oooool0027ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0cooooo`03o`000?oo
oooooooo02_ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo03;ooooo00?o0000ooooooooool0>oooool0027ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0cooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0<oooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0>oooool0
027ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo
02[ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
03;ooooo00?o0000ooooooooool0>oooool0027ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0dooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0<oooool00ol0003o
ooooooooo`0[ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0>oooool0027ooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02Wooooo
00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03Cooooo
00?o0000ooooooooool0>_ooool0027ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0>_ooool0027ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool0=?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo03Cooooo00?o0000
ooooooooool0>_ooool0027ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0eoooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Yoooo
o`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0>_ooool0027ooooo0ol00009ooooo`03
o`000?oooooooooo03Gooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0eooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0jooooo`00
8Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0
9oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0
=?ooool00ol0003oooooooooo`0jooooo`008Oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo03Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0eooooo`03o`000?oo
oooooooo02Sooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0iooooo`008Oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool09oooool0
0ol0003oooooooooo`0fooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0=_ooool0
0ol0003oooooooooo`0iooooo`008Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
03Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0iooooo`008Oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`0gooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0=_ooool00ol0003o
ooooooooo`0iooooo`008Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Wooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0iooooo`008Oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0gooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0=oooool00ol0003ooooooooo
o`0hooooo`008Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Wooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool0>?ooool00ol0003oooooooooo`0hooooo`008Oooool3o`0000Oooooo00?o0000oooo
ooooool0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo03Sooooo000Qooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Tooooo`03
o`000?oooooooooo03Wooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hooooo`03
o`000?oooooooooo03Sooooo000Qooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
>_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo03Sooooo000Qooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo03Wooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hooooo`03o`000?oo
oooooooo03Sooooo000Qooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0>oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`0jooooo`03o`000?oooooooooo03Oooooo000Qooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
03Wooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo
03Oooooo000Qooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`0jooooo`03o`000?oooooooooo03Oooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03_ooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03Oooooo
000Qooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0?Oooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool08oooool00ol0003ooooooooo
o`0jooooo`03o`000?oooooooooo03Oooooo000Qooooo`?o00001Oooool00ol0003oooooooooo`0m
ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0R
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0=oooool0027ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03cooooo00?o0000oooo
ooooool0=_ooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0mooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Rooooo`03
o`000?oooooooooo03cooooo00?o0000ooooooooool0=_ooool0027ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
?Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0
=_ooool0027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0nooooo`03o`000?oo
oooooooo023ooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo03cooooo00?o0000ooooooooool0=_ooool0027ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0oooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0?Oooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0=_ooool0
027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
03kooooo00?o0000ooooooooool0=Oooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0oooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0?_ooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0=Oooool0
00Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0n
ooooo`03o`000?oooooooooo03Gooooo0007ooooo`05oa0@4?ooooooooooooooool@41004?ooool0
0ol0003oooooooooo`02ooooo`?o00000oooool00ol0003oooooooooo`10ooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo03oooooo00?o0000ooooooooool0=Oooool000Oooooo00Go0000ooooooooooooooooo`00000?
ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`11
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0=Oooool000Oooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`0oooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0?oooool00ol0003ooooooooo
o`0eooooo`001oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0@?oo
ool00ol0003oooooooooo`0dooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04;ooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool0@?ooool00ol0003oooooooooo`0dooooo`001oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0@_oo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo03Cooooo000Qooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo047ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooo
oooo03Cooooo000Qooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0@oooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`11ooooo`03o`000?oooooooooo03Cooooo000Qooooo`05o`000?oooooooooooooo
ool00000A_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04?ooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo03?ooooo000Qooooo`05
o`000?ooooooooooooooool00000A_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
04?ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo
03?ooooo000Qooooo`?o000000?oooooo`000?ooool0AOooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo04?ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`13ooooo`03
o`000?oooooooooo03?ooooo000Qooooo`05o`000?ooooooooooooooool00000A_ooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`13ooooo`03o`000?oooooooooo03?ooooo000Qooooo`05o`000?ooooooooooooooool0
0000A_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04Gooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo03;ooooo000Qooooo`04o`00
0?ooooooooooo`0004Oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`15ooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0booooo`00
8Oooool01?l0003oooooooooool00018ooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool0AOooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04Cooooo00?o0000oooooooo
ool0<_ooool0027ooooo00Co0000oooooooooooo0000B?ooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`16ooooo`03
o`000?oooooooooo037ooooo000Qooooo`04o`000?ooooooooooo`0004Sooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool0A_ooool00ol0003oooooooooo`0aooooo`008Oooool01?l0003oooooooooool00018ooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0<Oooool0027ooooo00?o0000ooooool00000
B_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo037ooooo000Qooooo`?o0000B_oo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo033ooooo000Qooooo`03o`000?oooooo
000004[ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`18ooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0`ooooo`008Oooool00ol0
003oooooo`00001;ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0BOooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0<?ooool0027o
oooo00?o0000ooooool00000Boooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04Wo
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo033o
oooo000Qooooo`;o0000C?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04[ooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo02oooooo
000Qooooo`;o0000COooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04[ooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo02oooooo000Q
ooooo`;o0000COooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo04_ooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo02oooooo000Qoooo
o`;o0000COooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo04_ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo02kooooo000Qooooo`;o
0000C_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04_ooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo02kooooo000Qooooo`?o0000
COooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo02kooooo000Qooooo`03o`000?oo
oooooooo04gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1=ooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo01[ooooo000Qooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`1=ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0C_ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01[ooooo000Qooooo`03o`000?oooooooooo
04gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
01_ooooo000Qooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`1?ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0C_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo01_ooooo000Qooooo`03o`000?oooooooooo04kooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool0Coooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01_ooooo
000Qooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`1?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo01cooooo000Qooooo`03o`000?oooooooooo04kooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0D?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01cooooo000Qoooo
o`03o`000?oooooooooo04oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Aoooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo01cooooo000Qooooo`?o0000Coooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo057ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Booooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool07Oooool0027ooooo00?o0000ooooooooool0
D?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
7Oooool0027ooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo05?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Dooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool07Oooool0027ooooo00?o0000ooooooooool0DOooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`1Dooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool07_ooool0
027ooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
05Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool07_ooool0027ooooo00?o0000ooooooooool0D_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`1Fooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07oooool0027ooooo
00?o0000ooooooooool0D_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05Oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool08?ooool001Sooooo1?l000000ol@413oooooooooo`02ooooo`03o`000?oo
oooooooo05?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Iooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo027ooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0E?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool00_ooool2
o`0005cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Rooooo`006_ooool00ol0
003oooooooooo`04ooooo`?o0000EOooool5o`0005kooooo1?l0001Oooooo`Go00009?ooool001[o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooo
ooooool0oooooom5ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00W?ooool2o`0003oooooo0_l00029ooooo`00W?oo
ool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo08Oooooo0029ooooo`?o00000_ooool0
1_lb<S;o410@ooooooooooook^k^oeEEE@;o000000?oA4A4okZj^_ooool00oooool00ol0003ooooo
ooooo`02ooooo`06onk^k_mVIVKo0000o`000?lb<S;o^[Zj=oooool00ol0003oooooooooo`27oooo
o`00R_ooool01Ol0003oooooooooooo<c<co410@00?ooooo00KoEEEEogMgMoooooook^k^ogMgMol@
4104ooooo`03o`000?oooooooooo00;ooooo0_mgMgL01?mEEEGoQhN7omgMgOm4A4@gooooo`03o`00
0?oooooooooo08Oooooo002:ooooo`05o`000?oooooooooooeEEEOn7QhL00oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00;ooooo00?oV9RHooooool00000>_ooool00ol0003ooooo
ooooo`27ooooo`00R_ooool01Ol0003oooooomgMgOl0003ok^k^00?ooooo1_l00004ooooo`03o`00
0?oooooooooo00;ooooo00?oV9RHooooool000000ol0000Booooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`27ooooo`00R_ooool3o`000003oa0@4?nH
V9Sooooo00;ooooo00KoEEEEohN7Qoo^k^koooooohN7Qolb<S84ooooo`03o`000?oooooooooo00;o
oooo00?oMgMgohN7QomVIVH00_nj^[X00olb<S;oooooooooo`0?ooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`27ooooo`00R_ooool01Ol0003ooooo
ooooooo<c<co000000?ooooo00Kok^k^oeEEEOl0003o0000odA4A?o^k^h4ooooo`03o`000?oooooo
oooo00?ooooo00KoIVIVo`000?l0003oA4A4onk^k_ooool3o`0000Cooooo0_l000000ooooooo0000
o`000003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000002_ooool3o`0000Kooooo
0_l00004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Qoooool008[ooooo00Go
0000ooooooooooooc<c<o`00000=ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`27ooooo`00ROooool4o`000003oa0@4?nYZJWooooo00cooooo0_l0
000;ooooo`03o`000?oooooooooo00Cooooo0_l00005ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool4o`0000;ooooo00Co0000oooooooooooo00001Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00;ooooo0_l00029ooooo`00ZOooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooo000000Cooooo00?o0000ooooooooool00_ooool00ol0003oooooo`00
000:ooooo`?o00001?ooool4o`0000Cooooo00?o0000ooooooooool0SOooool00:Sooooo0_l00006
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo08kooooo002_ooooo`;o00002?ooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo08oooooo002Yooooo`03o`000?oooooooooo0;cooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-2, -1, 0, 0}}]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{\(c = 1; \ k = 1;\), "\n", 
    RowBox[{
      RowBox[{
      Cell[""], \(Table[
          Plot[Re[\[ExponentialE]\^\(\[ImaginaryI]\ k \((x + c\ t)\)\)], {x, 
              0, 6\ Pi}, 
            PlotLabel \[Rule] \
\*"\"\<Re[\!\(\[ExponentialE]\^\(\[ImaginaryI]\\\ k \((x + c\\\ \
t)\)\)\)]\>\"", AxesLabel \[Rule] {"\<x\>", "\<\>"}], {t, 0, 
            1.8\ Pi,  .2\ Pi}]\)}], ";"}]}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 5.2"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0505254 0.309017 0.294302 [
[.15012 .29652 -9 -9 ]
[.15012 .29652 9 0 ]
[.27644 .29652 -3 -9 ]
[.27644 .29652 3 0 ]
[.40275 .29652 -9 -9 ]
[.40275 .29652 9 0 ]
[.52906 .29652 -6 -9 ]
[.52906 .29652 6 0 ]
[.65538 .29652 -12 -9 ]
[.65538 .29652 12 0 ]
[.78169 .29652 -6 -9 ]
[.78169 .29652 6 0 ]
[.908 .29652 -12 -9 ]
[.908 .29652 12 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .01471 -12 -4.5 ]
[.01131 .01471 0 4.5 ]
[.01131 .16187 -24 -4.5 ]
[.01131 .16187 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[.5 .63053 -37 0 ]
[.5 .63053 37 12.625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15012 .30902 m
.15012 .31527 L
s
[(2.5)] .15012 .29652 0 1 Mshowa
.27644 .30902 m
.27644 .31527 L
s
[(5)] .27644 .29652 0 1 Mshowa
.40275 .30902 m
.40275 .31527 L
s
[(7.5)] .40275 .29652 0 1 Mshowa
.52906 .30902 m
.52906 .31527 L
s
[(10)] .52906 .29652 0 1 Mshowa
.65538 .30902 m
.65538 .31527 L
s
[(12.5)] .65538 .29652 0 1 Mshowa
.78169 .30902 m
.78169 .31527 L
s
[(15)] .78169 .29652 0 1 Mshowa
.908 .30902 m
.908 .31527 L
s
[(17.5)] .908 .29652 0 1 Mshowa
.125 Mabswid
.04907 .30902 m
.04907 .31277 L
s
.07433 .30902 m
.07433 .31277 L
s
.0996 .30902 m
.0996 .31277 L
s
.12486 .30902 m
.12486 .31277 L
s
.17539 .30902 m
.17539 .31277 L
s
.20065 .30902 m
.20065 .31277 L
s
.22591 .30902 m
.22591 .31277 L
s
.25117 .30902 m
.25117 .31277 L
s
.3017 .30902 m
.3017 .31277 L
s
.32696 .30902 m
.32696 .31277 L
s
.35222 .30902 m
.35222 .31277 L
s
.37749 .30902 m
.37749 .31277 L
s
.42801 .30902 m
.42801 .31277 L
s
.45328 .30902 m
.45328 .31277 L
s
.47854 .30902 m
.47854 .31277 L
s
.5038 .30902 m
.5038 .31277 L
s
.55433 .30902 m
.55433 .31277 L
s
.57959 .30902 m
.57959 .31277 L
s
.60485 .30902 m
.60485 .31277 L
s
.63011 .30902 m
.63011 .31277 L
s
.68064 .30902 m
.68064 .31277 L
s
.7059 .30902 m
.7059 .31277 L
s
.73116 .30902 m
.73116 .31277 L
s
.75643 .30902 m
.75643 .31277 L
s
.80695 .30902 m
.80695 .31277 L
s
.83222 .30902 m
.83222 .31277 L
s
.85748 .30902 m
.85748 .31277 L
s
.88274 .30902 m
.88274 .31277 L
s
.93327 .30902 m
.93327 .31277 L
s
.95853 .30902 m
.95853 .31277 L
s
.98379 .30902 m
.98379 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01471 m
.03006 .01471 L
s
[(-1)] .01131 .01471 1 0 Mshowa
.02381 .16187 m
.03006 .16187 L
s
[(-0.5)] .01131 .16187 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(0.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .13244 m
.02756 .13244 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -98 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.625 moveto
(@) show
81.000 13.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\343) show
87.000 9.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344) show
93.000 9.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
97.188 9.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
( ) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
99.000 9.625 moveto
(H) show
103.188 9.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
107.375 9.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
111.562 9.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
117.562 9.625 moveto
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
121.750 9.625 moveto
(L) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
127.000 13.625 moveto
(D) show
133.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.02499 .60324 L
.02605 .60303 L
.02729 .60262 L
.02846 .60208 L
.03053 .60072 L
.03279 .59869 L
.03527 .59578 L
.0379 .59195 L
.04262 .58316 L
.05205 .55852 L
.06244 .52139 L
.0842 .41696 L
.10458 .30083 L
.12312 .19585 L
.14335 .09889 L
.15431 .05946 L
.15965 .04441 L
.16449 .0333 L
.16689 .02872 L
.16949 .02447 L
.17174 .02141 L
.17421 .01871 L
.17684 .01659 L
.17827 .01577 L
.17896 .01545 L
.17961 .01521 L
.18086 .01488 L
.18201 .01473 L
.18324 .01474 L
.18393 .01483 L
.18458 .01495 L
.18575 .01531 L
.18699 .01586 L
.18805 .01646 L
.18921 .01728 L
.1918 .01964 L
.1942 .02252 L
.19857 .02941 L
.20324 .03907 L
.21403 .07006 L
.22384 .10769 L
.26382 .3202 L
.28214 .42377 L
.29255 .47678 L
.30229 .52 L
.31268 .55744 L
.32217 .58253 L
.32466 .58755 L
.32737 .59225 L
Mistroke
.32996 .59598 L
.33231 .5987 L
.33505 .60109 L
.33655 .60204 L
.33724 .60238 L
.33797 .60269 L
.33928 .60309 L
.34049 .60328 L
.34179 .6033 L
.34252 .60323 L
.34321 .6031 L
.34448 .60273 L
.34512 .60247 L
.34582 .60213 L
.34823 .60053 L
.34959 .59934 L
.35105 .59782 L
.35369 .59447 L
.35886 .58566 L
.3636 .57504 L
.37265 .54835 L
.38217 .51204 L
.42033 .31079 L
.44162 .19025 L
.46094 .09835 L
.47061 .06313 L
.47569 .04812 L
.48107 .03513 L
.48578 .0263 L
.48827 .02261 L
.49095 .01943 L
.49221 .01821 L
.4934 .01722 L
.49457 .01641 L
.49565 .01581 L
.49667 .01535 L
.49775 .01501 L
.49884 .01479 L
.50004 .01472 L
.50125 .01481 L
.50238 .01504 L
.50362 .01547 L
.50432 .01579 L
.50495 .01613 L
.50761 .01804 L
.51012 .0206 L
.51455 .02684 L
.51936 .03607 L
.52463 .04899 L
.53021 .06576 L
Mistroke
.54021 .10311 L
.57807 .30146 L
.59912 .42118 L
.61837 .51433 L
.62789 .55017 L
.63291 .56573 L
.63827 .57951 L
.64341 .58989 L
.64807 .59679 L
.65032 .59925 L
.65151 .60031 L
.65276 .60126 L
.65385 .60195 L
.65505 .60254 L
.65615 .60293 L
.65717 .60318 L
.65843 .60331 L
.65907 .60331 L
.65977 .60326 L
.66101 .60302 L
.66218 .60263 L
.66285 .60234 L
.66355 .60198 L
.6648 .6012 L
.66763 .59877 L
.67008 .59592 L
.67236 .59267 L
.67753 .58317 L
.68651 .55994 L
.6961 .52644 L
.71746 .42592 L
.73761 .31183 L
.75594 .2072 L
.76636 .15284 L
.7761 .10794 L
.7865 .06828 L
.79599 .04089 L
.8012 .02983 L
.80614 .02207 L
.80885 .01898 L
.81135 .01686 L
.8128 .01597 L
.81411 .01536 L
.81483 .01511 L
.81562 .01491 L
.81636 .01479 L
.81704 .01473 L
.81831 .01476 L
.81951 .01496 L
.82059 .01528 L
Mistroke
.82176 .01578 L
.82303 .0165 L
.82438 .01747 L
.82681 .01974 L
.83114 .02544 L
.83591 .03413 L
.84106 .04623 L
.84659 .06229 L
.8566 .09868 L
.87772 .20038 L
.89781 .31475 L
.91783 .42788 L
.93599 .51498 L
.94601 .55234 L
.95544 .57886 L
.96063 .58948 L
.96541 .59664 L
.96791 .59937 L
.96934 .60062 L
.97065 .60155 L
.97203 .60232 L
.97274 .60263 L
.97352 .60291 L
.97423 .6031 L
.97489 .60322 L
.97619 .60332 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool001So
oooo1?l000000ol@413oooooooooo`02ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000?ooooo`Ko00001Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000
ooooooooool01?ooool3o`0002gooooo1Ol0001Nooooo`Go0000G_ooool5o`0004cooooo000Joooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo05[ooooo0_l00003ooooo`;o0000GOooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo04Wooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0;?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05Sooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0BOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0[ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo05Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`18ooooo`006?oo
ool00omEEEGoIVIVo`000006ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0E_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04Sooooo000Qooooo`03o`000?oooooo
oooo02Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Fooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo04Oooooo000Qooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`1Dooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0E?ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo04Kooooo000Qooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo04Ko
oooo000Qooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`1Cooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0D_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo04Gooooo000Qooooo`?o0000:?ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`1Booooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0A?ooool0027ooooo00?o0000
ooooooooool0:?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo057ooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool0A?ooool0027ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo057ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1@oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool0A?ooool0027ooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo053ooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool0@oooool0027ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo04oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1?ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool0@oooool0027ooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0@ooo
ool0027ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo04kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0@oooool0027ooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`1=ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0@oooool0027o
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04go
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool0@_ooool0027ooooo0ol0000Uooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04gooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`12ooooo`008Oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0C?ooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`12ooooo`008Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool0Boooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo04_ooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`12ooooo`008Oooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`11oooo
o`008Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool0B_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04Wooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`11ooooo`008Oooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo04Wooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`11ooooo`008Ooo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0BOoo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`11ooooo`008Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo04Sooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`10ooooo`008Oooool00ol0
003oooooooooo`0Sooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0B?ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`10ooooo`008Oooool3o`0002?ooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`18ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0Aoooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo043ooooo000Qooooo`03o`000?oooooooooo02?ooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo043ooooo
000Qooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`16ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0A_ooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo03oooooo000Qooooo`03o`000?oooooooooo02;ooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool0A_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo03oooooo000Qoooo
o`03o`000?oooooooooo02;ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`16oooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo03oooooo000Qooooo`03o`000?oooooooooo02;ooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool0A?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo03oooooo000Qooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`15ooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo03oooooo000Qooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0A?oo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo03kooooo000Qooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`14ooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo03kooooo000Qooooo`?o00008Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
04Cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool0?_ooool0027ooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`12ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0?_ooool0027ooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo04?ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool0?Oooool0027ooooo00?o0000ooooooooool08?ooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`12ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0?Oooool0027ooooo00?o0000
ooooooooool08?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo04;ooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool0?Oooool0027ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo04;ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`12oooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0?Oooool0027ooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo04;ooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool0?Oooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo047ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`10oooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool0??ooool000Oooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
03cooooo0005o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
043ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool0??ooool000Oooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo00?ooooo0ol0000Nooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool0@?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo043ooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`0looooo`001oooool01Ol0003ooooooooooooooooo0000
00cooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool0?oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo03cooooo0007oooo
o`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo03_ooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0n
ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo03_ooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo03kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0nooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool0>oooool0027ooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`0nooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0>oooool0027o
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool0>_ooool0027ooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool08Oooool00ol0003ooooo
ooooo`0looooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0>_ooool0027ooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03gooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo027ooooo00?o
0000ooooooooool0>_ooool0027ooooo0ol0000Looooo`03o`000?oooooooooo02;ooooo00?o0000
ooooooooool0??ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03cooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`0jooooo`008Oooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo03cooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0joooo
o`008Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02;ooooo00?o0000oooooooo
ool0??ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03cooooo00?o0000oooooooo
ool08_ooool00ol0003oooooooooo`0iooooo`008Oooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo02;ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Rooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0iooooo`008Ooo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`0iooooo`008Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo03[ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0iooooo`008Oooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0>_ooool00ol0
003oooooooooo`0Sooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool08oooool00ol0
003oooooooooo`0iooooo`008Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03[o
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0hooooo`008Oooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0>Oooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`0hooooo`008Oooool3o`0001_ooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`0iooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0>Oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo03Sooooo000Qooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0>?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo000Qoooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo03Sooooo000Qooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0>?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo000Qooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0hooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo03Oooooo000Qooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0=ooo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo03Oooooo000Qooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooo
oooo02Oooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo03Oooooo000Qooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`0fooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo03Oooooo000Qooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo03Oo
oooo000Qooooo`?o00006Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo03Kooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool0=oooool0027ooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0=_ooool0027ooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo03Gooooo00?o0000
ooooooooool0:?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool0=_ooool0027ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Xoooo
o`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0doooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0=_ooool0027ooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo03Cooooo00?o0000oooooooo
ool0:Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02Wooooo00?o0000oooooooo
ool0=_ooool0027ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo03Cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo02Wooooo00?o0000ooooooooool0=_ooool0027ooooo00?o0000ooooooooool06Ooo
ool6o`0000Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd05Oooool00ol0003ooooo
ooooo`02ooooo`05odA4A?l0003o0000oc8b<_oMgMd07?ooool00ol0003ok^k^ooooo`05ooooo`;o
8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01Kooooo1?l000002?l@413oooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^1oooool00ol0003oooooooooo`0:ooooo`Co000000?o410@ooooooooool0
1Ol00005ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00gooooo00?o0000oooooooo
ool00_ooool4o`000005oa0@4?oooooooooooooooom4A4@00_l000000olb<S;ogMgMooooo`0Aoooo
o`Co000000?o410@ooooooooool00_ooool00ol0003ok^k^ooooo`05ooooo`;o8B4Q1Oooool01Om4
A4Co0000o`000?lb<S;ogMgM02Cooooo000Qooooo`03o`000?oooooooooo01Sooooo00Oo0000oooo
oonHV9So8B4Qonk^k_ooooooA4A400Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo01Cooooo00?o
0000ooooooooool01Oooool00omgMgOo<S8booooo`0Kooooo`03oeEEEOnYZJWooooo00Gooooo0_lQ
8B46ooooo`04o`000?ooooooMgMgoc8b<QSooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`02ooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool02oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?oMgMgoc8b<_ooool04oooool00ol0
003oooooooooo`04ooooo`03o`000?nYZJWooooo00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo
02?ooooo000Qooooo`03o`000?oooooooooo01Sooooo00Ko0000ooooooooooooV9RHob4Q8Oo^k^hA
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0J
ooooo`03ojVYZOmEEEGooooo00gooooo00Co0000oooooooooooo00006?ooool00ol0003ooooooooo
o`02ooooo`05oa0@4?ooooooooooooooool@41001oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00?ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo00Cooooo00?o0000oeEEEOooool04?ooool00ol0003oooooooooo`0Rooooo`008Ooo
ool3o`0001Sooooo00Oo0000oooooooooooooooooiRHV?lQ8B7ok^k^00oooooo00?oMgMgoc8b<_oo
ool05Oooool00ol0003oooooooooo`04ooooo`03ogMgMolb<S;ooooo01cooooo00?o8B4Qoooooooo
ool03?ooool01?l0003oooooogMgMolb<S8Hooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`000008ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01?ooool0
0onHV9So8B4Qonk^kP0?ooooo`03ogMgMolb<S;ooooo00_ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo01?ooooo00?o0000ooooooooool01?ooool0
0ol0003o8B4Qooooo`0?ooooo`03ogMgMolb<S;ooooo02?ooooo000Qooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool00_ooool00omgMgOoIVIVooooo`0;ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`05_ooool02Ol0003ooooooooooooooooo0000ob4Q8Ol0003o<S8bolc<c00Mooooo`03
oeEEEOo<c<cooooo00_ooooo0ol000000olb<S;oc<c<ooooo`0Gooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool01Oooool00omgMgOoIVIVooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`03?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c00Dooooo`03o`000?oooooooooo00Cooooo00?o0000oeEEEOo<c<`03?ooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<02Cooooo000Qooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Sooooo00Go0000oooooooooooooooo
o`00000Qooooo`03ojVYZOmgMgOooooo00_ooooo0_l0000Kooooo`03o`000?oooooooooo00;ooooo
00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool01?ooool00ol0003oZJVYogMgM`0<ooooo`03o`000?oooooooooo02Kooooo000Qooooo`03o`00
0?oooooooooo01Sooooo00Oo0000ooooool0003o^[ZjoooooonHV9So410@00cooooo00?o0000oooo
ooooool06?ooool01Ol0003ooooooooooooooooo000001kooooo00Go410@oooooooooooooooooc8b
<P0<ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`05o`00
0?nj^[[ooooooiRHV?l@41003?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00;o
oooo00Go410@oooooooooooo0000oc8b<P0<ooooo`03o`000?oooooooooo02Kooooo000Qooooo`03
o`000?oooooooooo01Sooooo00Oo0000oooooonHV9So410@o`000?lQ8B7oc<c<00cooooo1?l0000G
ooooo`04o`000?ooooooooooooooo`Co00006oooool5o`0000cooooo1?l0000Gooooo`03oeEEEOmV
IVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo00Wooooo
00?oEEEEofIVI_l000001?ooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo1?l0000<ooooo`03
o`000?oooooooooo00Cooooo00?oEEEEofIVI_l000001Oooool4o`0001?ooooo00?oEEEEofIVI_l0
00001?ooool5o`0000cooooo1?l0000Uooooo`008Oooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo02cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0]ooooo`03o`00
0?oooooooooo033ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0dooooo`008Ooo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0<?oo
ool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0;Ooo
ool00ol0003oooooooooo`0dooooo`008Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo02gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooo
oooo033ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Zooooo`;o00000_ooool2
o`0000Cooooo000Qooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0;Oooool00ol0
003oooooooooo`0_ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0;oooool00ol0
003oooooooooo`0^ooooo`03o`000?oooooooooo02[ooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oM
gMd4ooooo`006_ooooooo`0003[o00003?ooool01?oMgMgo0000oa0@4?o<c<`5ooooo`008Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooo`000005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool0
1?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`04ooooo`;o00001oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00oo
oooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo0_l00006ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooool000001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Go0000
ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00oooooo00Co8B4QogMgMomgMgOo<S8b
1Oooool0027ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0_ooooo`03o`000?oo
oooooooo02kooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0^ooooo`03o`000?oo
oooooooo02oooooo00?o0000ooooooooool0:Oooool2o`0000;ooooo0_l00004ooooo`008Oooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0;_ooool0
0ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0;oooool0
0ol0003oooooooooo`0cooooo`008Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
02oooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo
02gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0cooooo`008Oooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0;Oooool00ol0003o
ooooooooo`0`ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0<Oooool00ol0003o
ooooooooo`0booooo`008Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo02cooooo
00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0booooo`008Oooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0;?ooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0<Oooool00ol0003ooooooooo
o`0booooo`008Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool0;?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo02cooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`0booooo`008Oooool3o`0001Gooooo00?o0000oooo
ooooool0<Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo03;ooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo03;ooooo000Qooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo03;ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0cooooo`03
o`000?oooooooooo037ooooo000Qooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
<_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0
:oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo037ooooo000Qooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo03?ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0cooooo`03o`000?oo
oooooooo037ooooo000Qooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0<oooool0
0ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`0cooooo`03o`000?oooooooooo037ooooo000Qooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
03Cooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo
037ooooo000Qooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0<oooool00ol0003o
ooooooooo`0Yooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0:_ooool00ol0003o
ooooooooo`0dooooo`03o`000?oooooooooo033ooooo000Qooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo03Cooooo
00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo033ooooo
000Qooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0=Oooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo033ooooo000Qooooo`?o00004oooool00ol0003oooooooooo`0e
ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0<?ooool0027ooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02Oooooo00?o0000oooo
ooooool0=_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo03Gooooo00?o0000oooo
ooooool0<?ooool0027ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0eooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Xooooo`03
o`000?oooooooooo03Kooooo00?o0000ooooooooool0;oooool0027ooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
=_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0
;oooool0027ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0fooooo`03o`000?oo
oooooooo02Oooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo03Oooooo00?o0000ooooooooool0;oooool0027ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0gooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0=oooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0;oooool0
027ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
03Oooooo00?o0000ooooooooool0;oooool0027ooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0gooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?ooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0;_ooool0027ooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo03Sooooo
00?o0000ooooooooool0;_ooool0027ooooo0ol0000Aooooo`03o`000?oooooooooo03Sooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool0>?ooool00ol0003oooooooooo`0^ooooo`008Oooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0i
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0^
ooooo`008Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo03Wooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool0>Oooool00ol0003oooooooooo`0^ooooo`008Oooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo03Wooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0jooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0]ooooo`00
8Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
>_ooool00ol0003oooooooooo`0]ooooo`008Oooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo03[ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0jooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0]ooooo`008Oooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool08_ooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`0]ooooo`008Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0]ooooo`008Oooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`0looooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0??ooool00ol0003o
ooooooooo`0/ooooo`008Oooool3o`0000oooooo00?o0000ooooooooool0??ooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool08_ooool00ol0003ooooo
ooooo`0looooo`03o`000?oooooooooo02cooooo000Qooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0??ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03cooooo00?o
0000ooooooooool08_ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo02cooooo000Q
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0l
ooooo`03o`000?oooooooooo02cooooo000Qooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0?Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03gooooo00?o0000oooo
ooooool08?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo02cooooo000Qooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Oooooo`03
o`000?oooooooooo03kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0mooooo`03
o`000?oooooooooo02cooooo000Qooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
?_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0
8?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo02_ooooo000Qooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo03kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0nooooo`03o`000?oo
oooooooo02_ooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00Go
A4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
?_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0
7oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo02_ooooo0007ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`0oooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0?oooool00ol0003ooooo
ooooo`0[ooooo`001oooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool0
0_ooool3o`0000kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo03oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0oooooo`03o`00
0?oooooooooo02_ooooo0007ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8b
ooooo`03ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0@?ooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`10ooooo`03o`000?oooooooooo02[ooooo0007ooooo`05o`000?ooooooooooooooool00000
3?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`10ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0@?ooool00ol0003o
ooooooooo`0Nooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool0:_ooool000Oooooo
00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool0@Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo047ooooo00?o0000oooooooo
ool0:_ooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo047o
oooo00?o0000ooooooooool0:_ooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co
00001Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo04;ooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool0@Oooool00ol0003oooooooooo`0Zooooo`008Oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo04;ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`12ooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0Yooooo`008Ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0@ooo
ool00ol0003oooooooooo`0Yooooo`008Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo04;ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`13ooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Yooooo`008Oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`13ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0@oooool00ol0
003oooooooooo`0Yooooo`008Oooool3o`0000_ooooo00?o0000ooooooooool0A?ooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`13ooooo`03o`000?oooooooooo02Wooooo000Qooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04Cooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo02Wooooo
000Qooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0A?ooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`15ooooo`03o`000?oooooooooo02Sooooo000Qooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool0A?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04Gooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo02Sooooo000Qoooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo04Gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`15oooo
o`03o`000?oooooooooo02Sooooo000Qooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool0A_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04Gooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo02Sooooo000Qooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo04Kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`16ooooo`03o`00
0?oooooooooo02Sooooo000Qooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0A_oo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo02Oooooo000Qooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo04Oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`17ooooo`03o`000?oooooo
oooo02Oooooo000Qooooo`?o00002_ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
04Oooooo00?o0000ooooooooool09oooool0027ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`18ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0Aoooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool09oooool0027ooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04Sooooo
00?o0000ooooooooool09oooool0027ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`19ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0BOooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool09_ooool0027ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0BOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04Wooooo00?o0000
ooooooooool09_ooool0027ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1:oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo04Wooooo00?o0000ooooooooool09_ooool0027ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool0Boooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo04_ooooo00?o0000oooooooo
ool09Oooool0027ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1;ooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo04_ooooo00?o0000ooooooooool09Oooool0027ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0Booo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool09Ooo
ool0027ooooo0ol00007ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`1<ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0C?ooool0
0ol0003oooooooooo`0Uooooo`008Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
04gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0Tooooo`008Oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`1=ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0COooool00ol0003o
ooooooooo`0Tooooo`008Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04oooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool0COooool00ol0003oooooooooo`0Tooooo`008Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`1?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0Coooool00ol0003ooooooooo
o`0Sooooo`008Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04oooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool0Coooool00ol0003oooooooooo`0Sooooo`008Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo057ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1@oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0Soooo
o`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo057ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool0D?ooool00ol0003oooooooooo`0Rooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo057ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Aooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`0Rooooo`008Ooo
ool3o`0000Cooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo05;ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Aooooo`03o`000?oo
oooooooo02;ooooo000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Doooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`1Booooo`03o`000?oooooooooo027ooooo000Qooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
05?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo
027ooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0EOooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`1Cooooo`03o`000?oooooooooo027ooooo000Qooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0EOooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo05Gooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo023ooooo
000Qooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0E_ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`1Fooooo`03o`000?oooooooooo01oooooo000Qooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0Eoooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05Oooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo01oooooo000Hoooo
o`Co000000?o410@ooooooooool00_ooool01Ol0003ooooooooooooooooo000005_ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0FOooool00ol0003oooooooooo`0Nooooo`006_ooool00ol0003oooooooooo`04oooo
o`04o`000?ooooooooooo`0005gooooo00?o0000ooooooooool00_ooool2o`0005cooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo01gooooo000Joooo
o`03o`000?oooooooooo00Cooooo1?l0001Nooooo`Go0000G_ooool5o`0005kooooo0ol0000Loooo
o`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001Sooooo00?oEEEEofIVI_l000001_ooool00ol0
003oooooooooo`3oooooodGooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo002Mooooo`;o0000?Oooool2o`0008[ooooo
002Mooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0R?ooool008[ooooo0ol00002
ooooo`06oc8b<_l@413oooooooooooo^k^koEEEE0_l000000om4A4Co^[Zjooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00Kok^k^ofIVI_l0003o0000oc8b<_nj^[Xeooooo`03o`000?oooooooooo
08Sooooo002;ooooo`05o`000?ooooooooooolc<c?l@41000oooool01_mEEEGoMgMgooooooo^k^ko
MgMgoa0@40Cooooo00?o0000ooooooooool00_ooool2ogMgM`04oeEEEOn7QhOogMgModA4A3Gooooo
00?o0000ooooooooool0R?ooool008_ooooo00Go0000ooooooooooooEEEEohN7Q`03ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool00_ooool00onHV9Soooooo`00000hooooo`03o`00
0?oooooooooo08Sooooo002;ooooo`05o`000?oooooogMgMo`000?o^k^h00oooool6o`0000Cooooo
00?o0000ooooooooool00_ooool00onHV9Soooooo`000003o`0001;ooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo08Sooooo002;ooooo`?o000000?o
410@oiRHV?ooool00_ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<PCooooo00?o0000oooooooo
ool00_ooool00omgMgOoQhN7ofIVIP02okZj^P03oc8b<_oooooooooo00oooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo08Sooooo002;ooooo`05o`00
0?ooooooooooolc<c?l000000oooool01_o^k^koEEEEo`000?l0003oA4A4onk^kPCooooo00?o0000
ooooooooool00oooool01_mVIVKo0000o`000?m4A4Cok^k^ooooo`?o00001?ooool2o`000003oooo
ool0003o000000?ooooo00?o0000ooooooooool00oooool00ol0003oooooo`000003ooooo`04o`00
0?ooooooooooooooo`?o00001_ooool2o`0000Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`28ooooo`00Roooool01Ol0003oooooooooooo<c<co000000gooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo000000Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo08Sooooo002:ooooo`Co
000000?o410@ojVYZOooool03?ooool2o`0000_ooooo00?o0000ooooooooool01?ooool2o`0000Go
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06o`0000;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo0_l0002:ooooo`00
Z_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo000000Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooo`000003ooooo`04o`000?ooooooooooooooo`?o00001?ooool4o`0000Co
oooo00?o0000ooooooooool0S_ooool00:Wooooo0_l00006ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0Soooool00;3ooooo0_l00008ooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool0T?ooool00:[ooooo00?o0000ooooooooool0^oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-2, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0505254 0.309017 0.294302 [
[.15012 .29652 -9 -9 ]
[.15012 .29652 9 0 ]
[.27644 .29652 -3 -9 ]
[.27644 .29652 3 0 ]
[.40275 .29652 -9 -9 ]
[.40275 .29652 9 0 ]
[.52906 .29652 -6 -9 ]
[.52906 .29652 6 0 ]
[.65538 .29652 -12 -9 ]
[.65538 .29652 12 0 ]
[.78169 .29652 -6 -9 ]
[.78169 .29652 6 0 ]
[.908 .29652 -12 -9 ]
[.908 .29652 12 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .01471 -12 -4.5 ]
[.01131 .01471 0 4.5 ]
[.01131 .16187 -24 -4.5 ]
[.01131 .16187 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[.5 .63053 -37 0 ]
[.5 .63053 37 12.625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15012 .30902 m
.15012 .31527 L
s
[(2.5)] .15012 .29652 0 1 Mshowa
.27644 .30902 m
.27644 .31527 L
s
[(5)] .27644 .29652 0 1 Mshowa
.40275 .30902 m
.40275 .31527 L
s
[(7.5)] .40275 .29652 0 1 Mshowa
.52906 .30902 m
.52906 .31527 L
s
[(10)] .52906 .29652 0 1 Mshowa
.65538 .30902 m
.65538 .31527 L
s
[(12.5)] .65538 .29652 0 1 Mshowa
.78169 .30902 m
.78169 .31527 L
s
[(15)] .78169 .29652 0 1 Mshowa
.908 .30902 m
.908 .31527 L
s
[(17.5)] .908 .29652 0 1 Mshowa
.125 Mabswid
.04907 .30902 m
.04907 .31277 L
s
.07433 .30902 m
.07433 .31277 L
s
.0996 .30902 m
.0996 .31277 L
s
.12486 .30902 m
.12486 .31277 L
s
.17539 .30902 m
.17539 .31277 L
s
.20065 .30902 m
.20065 .31277 L
s
.22591 .30902 m
.22591 .31277 L
s
.25117 .30902 m
.25117 .31277 L
s
.3017 .30902 m
.3017 .31277 L
s
.32696 .30902 m
.32696 .31277 L
s
.35222 .30902 m
.35222 .31277 L
s
.37749 .30902 m
.37749 .31277 L
s
.42801 .30902 m
.42801 .31277 L
s
.45328 .30902 m
.45328 .31277 L
s
.47854 .30902 m
.47854 .31277 L
s
.5038 .30902 m
.5038 .31277 L
s
.55433 .30902 m
.55433 .31277 L
s
.57959 .30902 m
.57959 .31277 L
s
.60485 .30902 m
.60485 .31277 L
s
.63011 .30902 m
.63011 .31277 L
s
.68064 .30902 m
.68064 .31277 L
s
.7059 .30902 m
.7059 .31277 L
s
.73116 .30902 m
.73116 .31277 L
s
.75643 .30902 m
.75643 .31277 L
s
.80695 .30902 m
.80695 .31277 L
s
.83222 .30902 m
.83222 .31277 L
s
.85748 .30902 m
.85748 .31277 L
s
.88274 .30902 m
.88274 .31277 L
s
.93327 .30902 m
.93327 .31277 L
s
.95853 .30902 m
.95853 .31277 L
s
.98379 .30902 m
.98379 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01471 m
.03006 .01471 L
s
[(-1)] .01131 .01471 1 0 Mshowa
.02381 .16187 m
.03006 .16187 L
s
[(-0.5)] .01131 .16187 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(0.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04414 m
.02756 .04414 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .13244 m
.02756 .13244 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -98 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.625 moveto
(@) show
81.000 13.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\343) show
87.000 9.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344) show
93.000 9.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
97.188 9.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
( ) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
99.000 9.625 moveto
(H) show
103.188 9.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
107.375 9.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
111.562 9.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
117.562 9.625 moveto
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
121.750 9.625 moveto
(L) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
127.000 13.625 moveto
(D) show
133.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .54711 m
.06244 .36107 L
.08255 .24474 L
.10458 .12948 L
.11448 .08752 L
.11992 .06797 L
.12507 .05205 L
.12986 .03962 L
.13506 .02887 L
.13735 .02506 L
.13979 .02167 L
.14187 .01929 L
.14415 .01725 L
.14546 .01635 L
.14667 .01569 L
.14783 .01522 L
.14907 .01489 L
.15028 .01473 L
.15142 .01474 L
.15245 .01487 L
.15356 .01516 L
.15479 .01563 L
.15613 .01635 L
.15753 .01732 L
.15884 .01843 L
.16133 .02109 L
.16369 .02424 L
.16831 .03222 L
.17252 .0415 L
.18199 .06904 L
.19164 .10576 L
.2019 .15284 L
.22032 .25205 L
.25807 .46344 L
.26749 .50722 L
.27741 .54586 L
.28261 .56254 L
.28829 .57772 L
.29346 .58857 L
.29827 .59605 L
.3009 .59904 L
.30332 .6011 L
.30459 .60191 L
.30598 .60259 L
.30668 .60285 L
.30743 .60307 L
.30814 .60321 L
.30879 .60329 L
.31006 .6033 L
.31123 .60315 L
Mistroke
.31252 .6028 L
.31324 .60252 L
.31389 .60222 L
.31509 .60154 L
.31638 .60061 L
.31873 .59845 L
.32098 .59579 L
.32344 .59222 L
.32841 .58299 L
.33732 .55991 L
.34755 .52384 L
.35686 .48332 L
.37779 .37314 L
.39853 .25321 L
.41769 .1502 L
.43631 .07159 L
.44571 .04353 L
.45106 .0316 L
.45366 .02691 L
.45607 .02323 L
.45854 .02014 L
.46078 .01793 L
.46198 .01698 L
.46327 .01614 L
.46398 .01577 L
.46464 .01547 L
.46593 .01503 L
.46717 .01478 L
.46833 .01472 L
.4696 .01482 L
.47032 .01496 L
.47097 .01514 L
.47228 .01565 L
.4737 .01642 L
.47505 .01737 L
.47629 .01843 L
.48056 .0234 L
.48299 .02714 L
.48527 .03124 L
.49481 .05444 L
.50463 .08774 L
.51497 .1318 L
.53347 .22765 L
.57154 .44322 L
.59113 .53227 L
.59677 .55224 L
.6021 .56833 L
.60684 .58025 L
.61207 .59059 L
.61449 .59436 L
Mistroke
.61708 .59769 L
.61953 .60013 L
.62178 .60176 L
.62308 .60244 L
.6243 .6029 L
.625 .60309 L
.62563 .60321 L
.62636 .6033 L
.62705 .60332 L
.6283 .60322 L
.62946 .60297 L
.63072 .60251 L
.63206 .60184 L
.63426 .60028 L
.63661 .59799 L
.64086 .5923 L
.6459 .58293 L
.6505 .572 L
.66043 .54117 L
.6696 .50468 L
.69037 .40055 L
.71064 .28407 L
.72966 .17802 L
.74784 .09361 L
.75806 .05771 L
.76743 .03378 L
.77217 .02522 L
.77483 .02152 L
.77724 .01884 L
.77949 .01694 L
.78076 .01613 L
.78194 .01554 L
.78296 .01515 L
.78409 .01487 L
.78526 .01473 L
.78637 .01474 L
.78765 .01493 L
.78837 .01512 L
.78904 .01535 L
.79027 .01591 L
.79158 .0167 L
.79409 .01875 L
.79635 .02121 L
.80188 .02964 L
.80707 .04062 L
.81687 .06892 L
.8272 .10849 L
.84569 .19885 L
.88374 .41525 L
.89463 .47152 L
Mistroke
.90494 .51785 L
.91497 .55465 L
.91938 .56784 L
.92423 .58009 L
.9286 .58897 L
.9333 .59619 L
.9359 .59912 L
.93827 .60112 L
.93941 .60186 L
.94065 .60249 L
.94183 .60293 L
.94292 .60319 L
.9442 .60332 L
.94491 .60331 L
.94557 .60325 L
.94679 .603 L
.94807 .60256 L
.94922 .602 L
.9503 .60135 L
.95274 .59936 L
.95539 .59645 L
.9578 .5931 L
.96321 .58324 L
.96943 .56806 L
.97619 .54711 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool001So
oooo1?l000000ol@413oooooooooo`02ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000?ooooo`Ko00001Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000
ooooooooool01?ooool3o`0002?ooooo1Ol0001Nooooo`Go0000G_ooool5o`0005Kooooo000Joooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo05[ooooo0_l00004ooooo`03o`000?oooooooooo05_ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1Cooooo`006_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Iooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo05;ooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
D_ooool001Sooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo05Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Aooooo`008Oooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0EOooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`1Aooooo`008Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
05Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1@ooooo`008Oooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0Doooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`1@ooooo`008Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0Doooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo05Cooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`1?ooooo`008Oooool3o`0001kooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0Doooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo04oooooo000Q
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1A
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo04kooooo000Qooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool0D_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo04kooooo000Qooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1@ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo04kooooo000Qooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
D?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo04gooooo000Qooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1>ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo04gooooo000Qooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0C_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04gooooo000Qooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
04cooooo000Qooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`1<ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0COooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo04cooooo000Qooooo`?o00006oooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`1<ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0C?ooool0027ooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04cooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool0C?ooool0027ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1;
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0Boooool0027ooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04[ooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool0Boooool0027ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo04[ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`19ooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool0Boooool0027ooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
Boooool0027ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo04Sooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`18ooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool0B_ooool0027ooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`17ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0B_ooool0
027ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
04Sooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool0B_ooool0027ooooo0ol0000Iooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Oo
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1:ooooo`008Oooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0A_ooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`19ooooo`008Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool0A_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Kooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`19ooooo`008Oooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`19
ooooo`008Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool0AOooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04Gooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`19ooooo`008Oooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo04Gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`18ooooo`00
8Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
A?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`18ooooo`008Oooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo04Cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`18ooooo`008Oooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0A?ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`18ooooo`008Oooool3o`0001Oooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`13ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0@oooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo04Sooooo000Qooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04Oo
oooo000Qooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`12ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0@_ooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo04Oooooo000Qooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool0@Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo04Oooooo000Q
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`12
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo04Oooooo000Qooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool0@Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo04Oooooo000Qooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`10ooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo04Kooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Go
oooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool0@Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo04Kooooo0007ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0@?ooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`16ooooo`001Ol00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`10ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0?oooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo04Kooooo0007ooooo`05o`000?oooooooooooooo
ool000003oooool00omgMgOo<S8booooo`03ooooo`?o00005Oooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo03oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0ooooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool0AOooool000Oooooo00Go0000oooooooo
ooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`15
ooooo`001oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0?_ooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`15ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool0?_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03gooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`15ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00cooooo1?l00005ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`0nooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0?Oooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo04Gooooo000Qooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo
027ooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
04Cooooo000Qooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`0looooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0?Oooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo04Cooooo000Qooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo04Cooooo
000Qooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool08Oooool00ol0003ooooooooo
o`0looooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0??ooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo04Cooooo000Qooooo`?o00004oooool00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0A?ooool0027ooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03_ooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02;ooooo00?o0000oooo
ooooool0@oooool0027ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Rooooo`03
o`000?oooooooooo03[ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool0@oooool0027ooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0
@oooool0027ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo03[ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0jooooo`03o`000?oo
oooooooo02;ooooo00?o0000ooooooooool0@oooool0027ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`0iooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0@oooool0
027ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
03[ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool0@_ooool0027ooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0Tooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0iooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0@_ooool0027ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo03Sooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool0@_ooool0027ooooo0ol0000Aooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0>?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo03Sooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`12ooooo`008Oooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`12
ooooo`008Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0>?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo03Oooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`11ooooo`008Oooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo03Oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`11ooooo`00
8Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
=_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`11ooooo`008Oooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo02Oooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo03Oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`11ooooo`008Oooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0=_ooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`11ooooo`008Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo
03Gooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`11ooooo`008Oooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0=?ooool00ol0003o
ooooooooo`0Yooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0:?ooool00ol0003o
ooooooooo`10ooooo`008Oooool3o`00013ooooo00?o0000ooooooooool0:?ooool00ol0003ooooo
ooooo`0dooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0=Oooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooooooo043ooooo000Qooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool0:?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02Wooooo00?o
0000ooooooooool0=Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo043ooooo000Q
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0d
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo043ooooo000Qooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0:Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02[ooooo00?o0000oooo
ooooool0=?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo043ooooo000Qooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0dooooo`03
o`000?oooooooooo02[ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo043ooooo000Qooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
:_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0
<oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03oooooo000Qooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool02?ooool5o`0000Gooooo0_lQ8B45ooooo`05odA4A?l0
003o0000oc8b<_oMgMd03?ooool00ol0003oooooooooo`0;ooooo`05odA4A?l0003o0000oc8b<_oM
gMd07?ooool00ol0003ok^k^ooooo`03ooooo`04o`000?oooooo8B4Qob4Q8@Gooooo00GoA4A4o`00
0?l0003o<S8bomgMg@0Fooooo`Co000000Go410@ooooooooooook^k^oc8b<P02o`000003onk^k_oo
oooooooo01;ooooo1?l000000ol@413oooooooooo`05o`0000Gooooo0_lQ8B45ooooo`05odA4A?l0
003o0000oc8b<_oMgMd00oooool00ol0003oooooooooo`0<ooooo`Co000000Go410@oooooooooooo
ooooodA4A002o`000003oc8b<_oMgMgooooo013ooooo1Ol000000ol@413oooooooooo`02ooooo`03
o`000?o^k^kooooo00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd09?ooool0027o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`09ooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool02oooool00ol0003oooooooooo`0>oooo
o`03ogMgMolb<S;ooooo01_ooooo00?oEEEEojVYZOooool00oooool01?l0003oooooob4Q8OlQ8B48
ooooo`03ogMgMolb<S;ooooo01Oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHooooool0
003oMgMg01Kooooo00?o0000ooooooooool00_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo
0_lQ8B48ooooo`03ogMgMolb<S;ooooo00;ooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`06ooooo`03ogMgMolb<S;ooooo013ooooo00Co0000oooooooooooo00001_ooool00omEEEGo
ZJVYooooo`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Sooooo`008Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00[ooooo00?oV9RHob4Q8Oo^k^h04Oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool06_ooool00onYZJWoEEEE
ooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooo`000?l@41005_ooool00ol0003oooooooooo`03ooooo`03
oiRHV?lQ8B7ok^k^017ooooo00Go0000ooooooooooooooooo`00000@ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool03oooool01?l0003oooooooooool00006ooooo`03ojVYZOmEEEGo
oooo013ooooo00?o0000ooooooooool08_ooool0027ooooo0ol0000>ooooo`03o`000?oooooooooo
00_ooooo00?oV9RHob4Q8Oo^k^h03oooool00omgMgOo<S8booooo`0;ooooo`03o`000?oooooooooo
00kooooo00?oMgMgoc8b<_ooool07?ooool00olQ8B7oooooooooo`02ooooo`03o`000?oooooooooo
00Wooooo00?oMgMgoc8b<_ooool05oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool000005_ooool00ol0003oooooooooo`04ooooo`03oiRHV?lQ8B7ok^k^00oooooo00GoMgMg
oc8b<_ooooooooooo`00000Aooooo`03o`000?oooooooooo00Kooooo00?oMgMgoc8b<_ooool04?oo
ool01?l0003oooooooooool00007ooooo`03ob4Q8Ooooooooooo00kooooo00?oMgMgoc8b<_ooool0
8oooool0027ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0<ooooo`03ogMgMomV
IVKooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00=ooooo`03o`000?oooooooooo00[ooooo
00Go0000ob4Q8Ol0003o<S8bolc<c00Mooooo`03oeEEEOo<c<cooooo00;ooooo00?o0000oooooooo
ool01_ooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Sooooo00?o0000ooooooooool00_ooool01Ol0
003ooooooooooooooooo000001Kooooo00?o0000ooooooooool01Oooool00omgMgOoIVIVooooo`0;
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Booooo`03o`000?oooooo000000Oooooo
00?oEEEEolc<c?ooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<02Cooooo000Qooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Oooooo`05ojVY
ZOmgMgOoooooooooool000002Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00;o
oooo00Go410@ooooooooooooooooo`00000Fooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo000000Oooooo00?oZJVYogMg
Moooool02oooool00ol0003oooooooooo`0Vooooo`008Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00[ooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Looooo`05oa0@4?oooooooooo
oooooolb<S800_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So000001Kooooo00?o0000ooooooooool00_oo
ool01Ol0003o^[ZjoooooonHV9So410@00cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
o`000004ooooo`05oa0@4?oooooooooooooooolb<S803?ooool00ol0003oooooooooo`0Vooooo`00
8Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c00<ooooo`Co00003_ooool00ol0003oooooooooo`0:ooooo`Co00006oooool5o`0000;o
oooo00?o0000ooooooooool01oooool4o`0001Oooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko
<S8bo`000?lb<S;o000001Cooooo00?oEEEEofIVI_l000001?ooool01OnHV9So410@o`000?lQ8B7o
c<c<00cooooo1?l00003ooooo`03o`000?oooooooooo00gooooo00?oEEEEofIVI_l000001Oooool4
o`0001?ooooo00?o0000ofIVI_l000001?ooool5o`0000cooooo1?l0000Uooooo`008Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0<?ooool00ol0
003oooooooooo`0]ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0;?ooool00ol0
003oooooooooo`0nooooo`008Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02go
oooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02oo
oooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0nooooo`008Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0;oooool00ol0003ooooo
ooooo`0^ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`0cooooo`;o00000_ooool2o`0000Cooooo000Qooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool0;oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02kooooo00?o
0000ooooooooool0;oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo03?ooooo00Ko
k^k^ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`006_ooooooo`0003[o00003?ooool01?oMgMgo0000
oa0@4?o<c<`5ooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo
0_l00007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool2o`0000Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Co
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooool000001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Go
oooo0_l00006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooo`000005ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03oooool01?o^k^ko
8B4Qoa0@4?o^k^h5ooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Co
oooo0_l00007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool2o`0000Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Gooooo0_l00006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooo`000005ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03oooool01?lQ
8B7oMgMgogMgMolb<S85ooooo`008Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
033ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo
02gooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0cooooo`;o00000_ooool2o`00
00Cooooo000Qooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0<?ooool00ol0003o
ooooooooo`0]ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0;Oooool00ol0003o
ooooooooo`0`ooooo`03o`000?oooooooooo03cooooo000Qooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo03cooooo
000Qooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0<Oooool00ol0003ooooooooo
o`0/ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0;Oooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo03cooooo000Qooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool0;Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo03cooooo000Qoooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0/oooo
o`03o`000?oooooooooo037ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0`oooo
o`03o`000?oooooooooo03cooooo000Qooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool0<_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo03;ooooo00?o0000oooooooo
ool0:oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo03_ooooo000Qooooo`?o0000
2_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0
<_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0
>oooool0027ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0cooooo`03o`000?oo
oooooooo02_ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo03;ooooo00?o0000ooooooooool0>oooool0027ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0cooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0<oooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0>oooool0
027ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo
02[ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
03;ooooo00?o0000ooooooooool0>oooool0027ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0dooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0<oooool00ol0003o
ooooooooo`0[ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0>oooool0027ooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02Wooooo
00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03Cooooo
00?o0000ooooooooool0>_ooool0027ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0>_ooool0027ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool0=?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo03Cooooo00?o0000
ooooooooool0>_ooool0027ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0eoooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Yoooo
o`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0>_ooool0027ooooo0ol00009ooooo`03
o`000?oooooooooo03Gooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0eooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0jooooo`00
8Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0
9oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0
=?ooool00ol0003oooooooooo`0jooooo`008Oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo03Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0eooooo`03o`000?oo
oooooooo02Sooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0iooooo`008Oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool09oooool0
0ol0003oooooooooo`0fooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0=_ooool0
0ol0003oooooooooo`0iooooo`008Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
03Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0iooooo`008Oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`0gooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0=_ooool00ol0003o
ooooooooo`0iooooo`008Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Wooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0iooooo`008Oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0gooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0=oooool00ol0003ooooooooo
o`0hooooo`008Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Wooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool0>?ooool00ol0003oooooooooo`0hooooo`008Oooool3o`0000Oooooo00?o0000oooo
ooooool0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo03Sooooo000Qooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Tooooo`03
o`000?oooooooooo03Wooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hooooo`03
o`000?oooooooooo03Sooooo000Qooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
>_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo03Sooooo000Qooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo03Wooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hooooo`03o`000?oo
oooooooo03Sooooo000Qooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0>oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`0jooooo`03o`000?oooooooooo03Oooooo000Qooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
03Wooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo
03Oooooo000Qooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`0jooooo`03o`000?oooooooooo03Oooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03_ooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03Oooooo
000Qooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0?Oooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool08oooool00ol0003ooooooooo
o`0jooooo`03o`000?oooooooooo03Oooooo000Qooooo`?o00001Oooool00ol0003oooooooooo`0m
ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0R
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0=oooool0027ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03cooooo00?o0000oooo
ooooool0=_ooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0mooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Rooooo`03
o`000?oooooooooo03cooooo00?o0000ooooooooool0=_ooool0027ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
?Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0
=_ooool0027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0nooooo`03o`000?oo
oooooooo023ooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo03cooooo00?o0000ooooooooool0=_ooool0027ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0oooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0?Oooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0=_ooool0
027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
03kooooo00?o0000ooooooooool0=Oooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0oooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0?_ooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0=Oooool0
00Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0n
ooooo`03o`000?oooooooooo03Gooooo0007ooooo`05oa0@4?ooooooooooooooool@41004?ooool0
0ol0003oooooooooo`02ooooo`?o00000oooool00ol0003oooooooooo`10ooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo03oooooo00?o0000ooooooooool0=Oooool000Oooooo00Go0000ooooooooooooooooo`00000?
ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`11
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0=Oooool000Oooooo00Go0000oooo
ooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`0oooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0?oooool00ol0003ooooooooo
o`0eooooo`001oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0@?oo
ool00ol0003oooooooooo`0dooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04;ooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool0@?ooool00ol0003oooooooooo`0dooooo`001oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0@_oo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo03Cooooo000Qooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo047ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooo
oooo03Cooooo000Qooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0@oooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`11ooooo`03o`000?oooooooooo03Cooooo000Qooooo`05o`000?oooooooooooooo
ool00000A_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04?ooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo03?ooooo000Qooooo`05
o`000?ooooooooooooooool00000A_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
04?ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo
03?ooooo000Qooooo`?o000000?oooooo`000?ooool0AOooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo04?ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`13ooooo`03
o`000?oooooooooo03?ooooo000Qooooo`05o`000?ooooooooooooooool00000A_ooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`13ooooo`03o`000?oooooooooo03?ooooo000Qooooo`05o`000?ooooooooooooooool0
0000A_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04Gooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo03;ooooo000Qooooo`04o`00
0?ooooooooooo`0004Oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`15ooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0booooo`00
8Oooool01?l0003oooooooooool00018ooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool0AOooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04Cooooo00?o0000oooooooo
ool0<_ooool0027ooooo00Co0000oooooooooooo0000B?ooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`16ooooo`03
o`000?oooooooooo037ooooo000Qooooo`04o`000?ooooooooooo`0004Sooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool0A_ooool00ol0003oooooooooo`0aooooo`008Oooool01?l0003oooooooooool00018ooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool0<Oooool0027ooooo00?o0000ooooool00000
B_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo037ooooo000Qooooo`?o0000B_oo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo033ooooo000Qooooo`03o`000?oooooo
000004[ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`18ooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0`ooooo`008Oooool00ol0
003oooooo`00001;ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0BOooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0<?ooool0027o
oooo00?o0000ooooool00000Boooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04Wo
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo033o
oooo000Qooooo`;o0000C?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04[ooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo02oooooo
000Qooooo`;o0000COooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04[ooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo02oooooo000Q
ooooo`;o0000COooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo04_ooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo02oooooo000Qoooo
o`;o0000COooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo04_ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo02kooooo000Qooooo`;o
0000C_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04_ooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo02kooooo000Qooooo`?o0000
COooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo02kooooo000Qooooo`03o`000?oo
oooooooo04gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1=ooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo01[ooooo000Qooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`1=ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0C_ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01[ooooo000Qooooo`03o`000?oooooooooo
04gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
01_ooooo000Qooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`1?ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0C_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo01_ooooo000Qooooo`03o`000?oooooooooo04kooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool0Coooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01_ooooo
000Qooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`1?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo01cooooo000Qooooo`03o`000?oooooooooo04kooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0D?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01cooooo000Qoooo
o`03o`000?oooooooooo04oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Aoooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo01cooooo000Qooooo`?o0000Coooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo057ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Booooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool07Oooool0027ooooo00?o0000ooooooooool0
D?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
7Oooool0027ooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo05?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Dooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool07Oooool0027ooooo00?o0000ooooooooool0DOooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`1Dooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool07_ooool0
027ooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
05Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool07_ooool0027ooooo00?o0000ooooooooool0D_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`1Fooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07oooool0027ooooo
00?o0000ooooooooool0D_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05Oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool08?ooool001Sooooo1?l000000ol@413oooooooooo`02ooooo`03o`000?oo
oooooooo05?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Iooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo027ooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0E?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool00_ooool2
o`0005cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Rooooo`006_ooool00ol0
003oooooooooo`04ooooo`?o0000EOooool5o`0005kooooo1?l0001Oooooo`Go00009?ooool001[o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooo
ooooool0oooooom5ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00WOooool2o`0003gooooo0_l0002:ooooo`00WOoo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo08Sooooo002:ooooo`?o00000_ooool0
1_lb<S;o410@ooooooooooook^k^oeEEE@;o000000?oA4A4okZj^_ooool00oooool00ol0003ooooo
ooooo`02ooooo`06onk^k_mVIVKo0000o`000?lb<S;o^[Zj=Oooool00ol0003oooooooooo`28oooo
o`00Roooool01Ol0003oooooooooooo<c<co410@00?ooooo00KoEEEEogMgMoooooook^k^ogMgMol@
4104ooooo`03o`000?oooooooooo00;ooooo0_mgMgL01?mEEEGoQhN7omgMgOm4A4@eooooo`03o`00
0?oooooooooo08Sooooo002;ooooo`05o`000?oooooooooooeEEEOn7QhL00oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00;ooooo00?oV9RHooooool00000>?ooool00ol0003ooooo
ooooo`28ooooo`00Roooool01Ol0003oooooomgMgOl0003ok^k^00?ooooo1_l00004ooooo`03o`00
0?oooooooooo00;ooooo00?oV9RHooooool000000ol0000Booooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`28ooooo`00Roooool3o`000003oa0@4?nH
V9Sooooo00;ooooo00KoEEEEohN7Qoo^k^koooooohN7Qolb<S84ooooo`03o`000?oooooooooo00;o
oooo00?oMgMgohN7QomVIVH00_nj^[X00olb<S;oooooooooo`0?ooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`28ooooo`00Roooool01Ol0003ooooo
ooooooo<c<co000000?ooooo00Kok^k^oeEEEOl0003o0000odA4A?o^k^h4ooooo`03o`000?oooooo
oooo00?ooooo00KoIVIVo`000?l0003oA4A4onk^k_ooool3o`0000Cooooo0_l000000ooooooo0000
o`000003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000000oooool01?l0003ooooo
ooooooooool3o`0000Kooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0R?ooool008_ooooo00Go0000ooooooooooooc<c<o`00000=ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool01?ooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`28ooooo`00R_ooool4o`000003
oa0@4?nYZJWooooo00cooooo0_l0000;ooooo`03o`000?oooooooooo00Cooooo0_l00005ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01_l00002ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`;o0000R_ooool00:[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooool000000oooool01?l0003oooooooooooooool3o`0000Cooooo1?l00004ooooo`03
o`000?oooooooooo08kooooo002Yooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo08oooooo002`ooooo`;o00002?ooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo093ooooo002Zooooo`03o`000?oooooooooo0;_ooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-2, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0505254 0.309018 0.294305 [
[.15012 .29652 -9 -9 ]
[.15012 .29652 9 0 ]
[.27644 .29652 -3 -9 ]
[.27644 .29652 3 0 ]
[.40275 .29652 -9 -9 ]
[.40275 .29652 9 0 ]
[.52906 .29652 -6 -9 ]
[.52906 .29652 6 0 ]
[.65538 .29652 -12 -9 ]
[.65538 .29652 12 0 ]
[.78169 .29652 -6 -9 ]
[.78169 .29652 6 0 ]
[.908 .29652 -12 -9 ]
[.908 .29652 12 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .01471 -12 -4.5 ]
[.01131 .01471 0 4.5 ]
[.01131 .16187 -24 -4.5 ]
[.01131 .16187 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[.5 .63053 -37 0 ]
[.5 .63053 37 12.625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15012 .30902 m
.15012 .31527 L
s
[(2.5)] .15012 .29652 0 1 Mshowa
.27644 .30902 m
.27644 .31527 L
s
[(5)] .27644 .29652 0 1 Mshowa
.40275 .30902 m
.40275 .31527 L
s
[(7.5)] .40275 .29652 0 1 Mshowa
.52906 .30902 m
.52906 .31527 L
s
[(10)] .52906 .29652 0 1 Mshowa
.65538 .30902 m
.65538 .31527 L
s
[(12.5)] .65538 .29652 0 1 Mshowa
.78169 .30902 m
.78169 .31527 L
s
[(15)] .78169 .29652 0 1 Mshowa
.908 .30902 m
.908 .31527 L
s
[(17.5)] .908 .29652 0 1 Mshowa
.125 Mabswid
.04907 .30902 m
.04907 .31277 L
s
.07433 .30902 m
.07433 .31277 L
s
.0996 .30902 m
.0996 .31277 L
s
.12486 .30902 m
.12486 .31277 L
s
.17539 .30902 m
.17539 .31277 L
s
.20065 .30902 m
.20065 .31277 L
s
.22591 .30902 m
.22591 .31277 L
s
.25117 .30902 m
.25117 .31277 L
s
.3017 .30902 m
.3017 .31277 L
s
.32696 .30902 m
.32696 .31277 L
s
.35222 .30902 m
.35222 .31277 L
s
.37749 .30902 m
.37749 .31277 L
s
.42801 .30902 m
.42801 .31277 L
s
.45328 .30902 m
.45328 .31277 L
s
.47854 .30902 m
.47854 .31277 L
s
.5038 .30902 m
.5038 .31277 L
s
.55433 .30902 m
.55433 .31277 L
s
.57959 .30902 m
.57959 .31277 L
s
.60485 .30902 m
.60485 .31277 L
s
.63011 .30902 m
.63011 .31277 L
s
.68064 .30902 m
.68064 .31277 L
s
.7059 .30902 m
.7059 .31277 L
s
.73116 .30902 m
.73116 .31277 L
s
.75643 .30902 m
.75643 .31277 L
s
.80695 .30902 m
.80695 .31277 L
s
.83222 .30902 m
.83222 .31277 L
s
.85748 .30902 m
.85748 .31277 L
s
.88274 .30902 m
.88274 .31277 L
s
.93327 .30902 m
.93327 .31277 L
s
.95853 .30902 m
.95853 .31277 L
s
.98379 .30902 m
.98379 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01471 m
.03006 .01471 L
s
[(-1)] .01131 .01471 1 0 Mshowa
.02381 .16187 m
.03006 .16187 L
s
[(-0.5)] .01131 .16187 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(0.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04414 m
.02756 .04414 L
s
.02381 .07357 m
.02756 .07357 L
s
.02381 .103 m
.02756 .103 L
s
.02381 .13243 m
.02756 .13243 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -98 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.625 moveto
(@) show
81.000 13.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\343) show
87.000 9.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344) show
93.000 9.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
97.188 9.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
( ) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
99.000 9.625 moveto
(H) show
103.188 9.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
107.375 9.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
111.562 9.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
117.562 9.625 moveto
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
121.750 9.625 moveto
(L) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
127.000 13.625 moveto
(D) show
133.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .39996 m
.04262 .29193 L
.06244 .18087 L
.08255 .0882 L
.08806 .06834 L
.09396 .05026 L
.09948 .03651 L
.10458 .0267 L
.10714 .02285 L
.10954 .01991 L
.11204 .01754 L
.11337 .01657 L
.1148 .01575 L
.11548 .01545 L
.11622 .01518 L
.11702 .01495 L
.11776 .01481 L
.11853 .01473 L
.11924 .01472 L
.11989 .01475 L
.12059 .01485 L
.12123 .01499 L
.12193 .01519 L
.12335 .01578 L
.12466 .01653 L
.12589 .0174 L
.1285 .01984 L
.13097 .02287 L
.13561 .03038 L
.1406 .04108 L
.14603 .05568 L
.15542 .08775 L
.1658 .13197 L
.18681 .24201 L
.20778 .36327 L
.22701 .46684 L
.24586 .54651 L
.25533 .57476 L
.2607 .58668 L
.2657 .59495 L
.26833 .59819 L
.27075 .60048 L
.27201 .60141 L
.27341 .60222 L
.27411 .60255 L
.27486 .60283 L
.27557 .60304 L
.27622 .60318 L
.27749 .60332 L
.27866 .60328 L
Mistroke
.27995 .60305 L
.28067 .60284 L
.28132 .6026 L
.28252 .60203 L
.28381 .60123 L
.28616 .59929 L
.2884 .59684 L
.29087 .5935 L
.29584 .58471 L
.30474 .56239 L
.31497 .5271 L
.32429 .48717 L
.34522 .37783 L
.36596 .25794 L
.38512 .15427 L
.40374 .07447 L
.41314 .04564 L
.41849 .03324 L
.42108 .02832 L
.4235 .02441 L
.42597 .02109 L
.42821 .01867 L
.4307 .01666 L
.43207 .01585 L
.43336 .01529 L
.43462 .01492 L
.43525 .0148 L
.43595 .01473 L
.43718 .01474 L
.43833 .0149 L
.43903 .01508 L
.43969 .0153 L
.44093 .01584 L
.44227 .01662 L
.44372 .01771 L
.44594 .01982 L
.44838 .0228 L
.45334 .03089 L
.45793 .04076 L
.46224 .05206 L
.47205 .08459 L
.4824 .12798 L
.50089 .22304 L
.53897 .43892 L
.55856 .52911 L
.5642 .5495 L
.56952 .56603 L
.57427 .57835 L
.5795 .58916 L
.58191 .59315 L
Mistroke
.58451 .59671 L
.58696 .59938 L
.5892 .60123 L
.59051 .60204 L
.59173 .60261 L
.59242 .60287 L
.59306 .60305 L
.59379 .6032 L
.59448 .60329 L
.59573 .60331 L
.59688 .60317 L
.59815 .60283 L
.59879 .6026 L
.59949 .60228 L
.6019 .60077 L
.60409 .59881 L
.60663 .59588 L
.60903 .59243 L
.61329 .58473 L
.61793 .57413 L
.62734 .54589 L
.63772 .50527 L
.65873 .39994 L
.67972 .27925 L
.69896 .17259 L
.71782 .08688 L
.7273 .05477 L
.73263 .04057 L
.73767 .0299 L
.7426 .02213 L
.74538 .01895 L
.74671 .01774 L
.74795 .0168 L
.74908 .01609 L
.75011 .01557 L
.75126 .01514 L
.75249 .01484 L
.75367 .01472 L
.75495 .01477 L
.75617 .01499 L
.75729 .01535 L
.75861 .01595 L
.76004 .01683 L
.76262 .01902 L
.76513 .02187 L
.76744 .02512 L
.7727 .03471 L
.77825 .04804 L
.78776 .07811 L
.79794 .1193 L
Mistroke
.81629 .21161 L
.83615 .32544 L
.85772 .44563 L
.86779 .49455 L
.87848 .53835 L
.88759 .56774 L
.89278 .58075 L
.89764 .59035 L
.90004 .59414 L
.9026 .59746 L
.90407 .59904 L
.90541 .60026 L
.90676 .6013 L
.90801 .60206 L
.9092 .60262 L
.91045 .60303 L
.91171 .60327 L
.91243 .60332 L
.91309 .60331 L
.9143 .60318 L
.9154 .6029 L
.91667 .60241 L
.91788 .60178 L
.92011 .60016 L
.92248 .59782 L
.92675 .59202 L
.93134 .58353 L
.9364 .57153 L
.94639 .54029 L
.95555 .50369 L
.97619 .39996 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool001So
oooo1?l000000ol@413oooooooooo`02ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000?ooooo`Ko00001Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000
ooooooooool01?ooool3o`0001Wooooo1Ol0001Nooooo`Go0000G_ooool5o`00063ooooo000Joooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo05_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Koooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0GOooool001[ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0FOooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05Wooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`1Looooo`006_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Hooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo05_ooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Fooo
ool0027ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo05Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Eooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0F_ooool0027ooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`1Eooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0F_ooool0027o
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo05Co
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0F_ooool0027ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`1Cooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0FOooool0027ooooo0ol0
000Dooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0D_ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`1Iooooo`008Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool0DOooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo057ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`1Hooooo`008Oooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo057ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Hoooo
o`008Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool0Coooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo053ooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`1Gooooo`008Oooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo053ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1Gooooo`008Ooo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0C_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`1Gooooo`008Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo04kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Fooooo`008Oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0COooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`1Fooooo`008Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04go
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Fooooo`008Oooool3o`00017ooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo05Gooooo
000Qooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`1<ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0C?ooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo05Gooooo000Qooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool0Boooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo05Gooooo000Qoooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1:oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo05Gooooo000Qooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool0B_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo05Cooooo000Qooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1:ooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo05Cooooo000Qooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0BOoo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo05Cooooo000Qooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`18ooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo05Cooooo000Qooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`18ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0B?ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo05?ooooo000Qooooo`?o00003oooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`17ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0Doooool0027ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Oooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool0Doooool0027ooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`17ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0Doooool0027ooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Kooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool0Doooool0027ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo04Kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`15oooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0D_ooool0027ooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04Gooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool0D_ooool0027ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo04Gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`15ooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool0D_ooool0027ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0D_oo
ool0027ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo04?ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`13ooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool0DOooool0027ooooo0ol0000=ooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
04?ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1Aooooo`008Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0@oooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`1Aooooo`008Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo04?ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`1Aooooo`008Oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0@_ooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`1Aooooo`008Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool0@Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo047ooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`1@ooooo`008Oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo047ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1@oooo
o`008Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool0@?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo047ooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`1@ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo043ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1@oooo
o`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo
00?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
043ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool0D?ooool000Go00000_ooool01Ol@413ooooooooooooooooo410@
013ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
03oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1?ooooo`001oooool01Ol0003o
oooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool3o`0000[ooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool0?oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo04oooooo0007ooooo`05
o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03kooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool0Coooool000Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo03kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0nooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool0Coooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0n
ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0Coooool000Oooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo03kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1>ooooo`008Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0?_ooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`1>ooooo`008Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03go
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1>ooooo`008Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0??ooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool08Oooool00ol0003ooooo
ooooo`1>ooooo`008Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo027ooooo00?o
0000ooooooooool0??ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03cooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`1>ooooo`008Oooool3o`0000Sooooo00?o0000
ooooooooool08_ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool0??ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo04gooooo000Qoooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0loooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Roooo
o`03o`000?oooooooooo04gooooo000Qooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02;ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo04gooooo000Qooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0jooooo`03o`00
0?oooooooooo02?ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Sooooo`03o`00
0?oooooooooo04gooooo000Qooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0>_oo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo04gooooo000Qooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0jooooo`03o`000?oooooo
oooo02?ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo
oooo04cooooo000Qooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`0jooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0>_ooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo04cooooo000Qooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo02?o
oooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo04co
oooo000Qooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0hooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>Oooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo04cooooo000Qooooo`?o00001oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0hooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0C?ooool0027ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool0Boooool0027ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo03Sooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0Boooool0027ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo03Sooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool0Boooool0027ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo03Sooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool0Boooool0027ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0Booo
ool0027ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo03Kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0fooooo`03o`000?oooooo
oooo02Oooooo00?o0000ooooooooool0Boooool0027ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`0fooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0B_ooool0027o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo02So
oooo00?o0000ooooooooool0B_ooool0027ooooo0ol00005ooooo`03o`000?oooooooooo02Sooooo
00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo03Kooooo
00?o0000ooooooooool0:?ooool00ol0003oooooooooo`1:ooooo`008Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0=Oooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`1:ooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool0=?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo03Cooooo00?o0000
ooooooooool0:Oooool00ol0003oooooooooo`1:ooooo`008Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Yoooo
o`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1:oooo
o`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Wooooo00?o0000oooooooo
ool0=?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo03Cooooo00?o0000oooooooo
ool0:_ooool00ol0003oooooooooo`19ooooo`008Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo02[ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo03Cooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`19ooooo`008Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01?ooooo1Ol00005ooooo`;o8B4Q1Ooo
ool01om4A4Co0000o`000?lb<S;ogMgMooooool000006?ooool01Om4A4Co0000o`000?lb<S;ogMgM
01Wooooo00Go0000oooooooooooo0000onk^kP06ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb
<S;ogMgM01Gooooo1Ol000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^5?ooool4o`00
0003oa0@4?oooooooooo00Go00001Oooool2ob4Q8@?ooooo00?o0000oooooom4A4@00_l000000olb
<S;ogMgMooooo`0Aooooo`Co000000Go410@ooooooooooooooooodA4A002o`000003oc8b<_oMgMgo
oooo00Kooooo00?o0000ooooooooool02?ooool4o`000003oa0@4?oooooooooo00;ooooo00?o0000
onk^k_ooool01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Tooooo`008Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo01?ooooo00GoV9RHob4Q8Oo^k^koooooodA4
A005ooooo`;o8B4Q2?ooool01OmgMgOo<S8boooooooooooo000001[ooooo00?oMgMgoc8b<_ooool0
5oooool01_l0003oooooooooooooooooEEEEojVYZ@Kooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo
01Gooooo00?o0000ooooool000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg01Kooooo00?o0000
ooooooooool00_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo0_lQ8B42ooooo`03o`000?oo
oooooooo00?ooooo00?oMgMgoc8b<_ooool04oooool00ol0003oooooooooo`06ooooo`03ogMgMolb
<S;ooooo00Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`04ooooo`03oeEEEOnY
ZJWooooo00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo02?ooooo000Qooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool05?ooool00onHV9So8B4Qonk^kP0Aooooo`04o`000?oooooo
ooooo`0001_ooooo00?o0000ooooooooool05_ooool01_l0003oooooooooooooooooZJVYoeEEEA7o
oooo00?o0000ooooooooool05?ooool00ol0003oooooo`000004ooooo`05oa0@4?oooooooooooooo
ool@41005_ooool00ol0003oooooooooo`03ooooo`03oiRHV?lQ8B7ok^k^00[ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo00?oZJVYoeEE
EOooool04?ooool00ol0003oooooooooo`0Rooooo`008Oooool3o`0000Cooooo00?o0000oooooooo
ool05Oooool00onHV9So8B4Qonk^kP0?ooooo`05ogMgMolb<S;oooooooooool000006_ooool00omg
MgOo<S8booooo`0Gooooo`03o`000?oooooooooo00;ooooo00?o8B4Qooooooooool03_ooool00omg
MgOo<S8booooo`0Eooooo`03o`000?oooooo000000Cooooo00Go0000ooooooooooooooooo`00000F
ooooo`03o`000?oooooooooo00Cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03
ooooo`03ogMgMolb<S;ooooo01?ooooo00?o0000ooooooooool01_ooool00omgMgOo<S8booooo`06
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01Oooool00olQ8B7oooooooooo`0>
ooooo`03ogMgMolb<S;ooooo02?ooooo000Qooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool05_ooool00omgMgOoIVIVooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool0
0ol0003oooooooooo`0Eooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06?ooool00ol0003ooooooooo
o`02ooooo`03oeEEEOo<c<cooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Fooooo`03o`00
0?oooooo000000Cooooo00Go0000ooooooooooooooooo`00000Fooooo`03o`000?oooooooooo00Go
oooo00?oMgMgofIVI_ooool02?ooool02?l0003oooooooooool0003o8B4Qo`000?lb<S;oc<c<5?oo
ool00ol0003oooooooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`02?ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Gooooo00?oEEEEolc<c?ooool02oooool01Ol0003o8B4Q
o`000?lb<S;oc<c<02Cooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00;ooooo00?oZJVYogMgMoooool0
2oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo000000Cooooo00Go410@oooooooooooo
oooooa0@400Fooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool01?l0003o
ooooooooool0000Hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo00?oZJVYogMgMoooool02oooool00ol0
003oooooooooo`0Vooooo`008Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Co
oooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo410@00?ooooo00?o<S8boooo
ooooool02_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo000000Cooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0Fooooo`03o`000?oooooooooo00;ooooo00Go0000okZj^_ooooooV9RHoa0@
4009ooooo`04o`000?ooooooooooo`0001Sooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool01Ol@413ooooo
oooooooooooo<S8b00cooooo00?o0000ooooooooool09_ooool0027ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Dooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?ooool4o`0000Co
oooo00?o0000ooooooooool05?ooool4o`0001Sooooo00?o0000ooooooooool01Ol0000<ooooo`Co
00005oooool00omEEEGo0000o`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h05?ooool00omE
EEGoIVIVo`000004ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`02?ooool01?l0003ooooooooooooo
ool4o`0001?ooooo00?oEEEEofIVI_l000001Oooool4o`0000Wooooo00?o0000ooooooooool01ooo
ool00omEEEGoIVIVo`000004ooooo`Go00003?ooool4o`0002Gooooo000Qooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooo
oooo02gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooo
oooo04Sooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0;Oooool00ol0
003oooooooooo`0`ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0<?ooool00ol0
003oooooooooo`0]ooooo`03o`000?oooooooooo04Sooooo000Qooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02go
oooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo03go
oooo0_l00002ooooo`;o00001?ooool0027ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0_ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0;Oooool00ol0003ooooo
ooooo`0`ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0?Oooool01_o^k^ko8B4Q
ohN7Qonj^[[o0000omgMg@Cooooo000Joooooooo0000>_l0000<ooooo`04omgMgOl0003o410@olc<
c0Gooooo000Qooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo0_l00007ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooo`000007
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0?
ooooo`04onk^k_lQ8B7o410@onk^kPGooooo000Qooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo0_l0
0007ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool2o`0000Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool00000
0oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0_ooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0?ooooo`04ob4Q8OmgMgOoMgMgoc8b<PGooooo000Qooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0^ooooo`03o`00
0?oooooooooo02oooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0_ooooo`03o`00
0?oooooooooo03gooooo0_l00002ooooo`;o00001?ooool0027ooooo00Go0000oooooooooooooooo
o`00000booooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0;oooool00ol0003ooooo
ooooo`0^ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0A_ooool0027ooooo00Go
0000ooooooooooooooooo`00000cooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0
;oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
A_ooool0027ooooo00Go0000ooooooooooooooooo`00000cooooo`03o`000?oooooooooo02gooooo
00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool0A_ooool0027ooooo00Go0000ooooooooooooooooo`00000cooooo`03o`00
0?oooooooooo02gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0]ooooo`03o`00
0?oooooooooo033ooooo00?o0000ooooooooool0A_ooool0027ooooo00Go0000oooooooooooooooo
o`00000cooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0<Oooool00ol0003ooooo
ooooo`0/ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0A_ooool0027ooooo00Go
0000ooooooooooooooooo`00000cooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0
<Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
A_ooool0027ooooo1?l0000eooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0<Ooo
ool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0AOoo
ool0027ooooo00Co0000oooooooooooo0000=Oooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo03;ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0booooo`03o`000?oo
oooooooo04Gooooo000Qooooo`04o`000?ooooooooooo`0003Gooooo00?o0000ooooooooool0:ooo
ool00ol0003oooooooooo`0booooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0<_oo
ool00ol0003oooooooooo`15ooooo`008Oooool01?l0003oooooooooool0000eooooo`03o`000?oo
oooooooo02_ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo03;ooooo00?o0000ooooooooool0AOooool0027ooooo00Co0000oooooooooooo0000=Ooo
ool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0:_oo
ool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo04Gooooo000Qooooo`04o`000?oooooo
ooooo`0003Kooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0cooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`14ooooo`008Oooool0
0ol0003oooooo`00000gooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0<oooool0
0ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0A?ooool0
027ooooo00?o0000ooooool00000=oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
03Cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo
04Cooooo000Qooooo`03o`000?oooooo000003Oooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`0dooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0=?ooool00ol0003o
ooooooooo`14ooooo`008Oooool3o`0003Oooooo00?o0000ooooooooool0:Oooool00ol0003ooooo
ooooo`0dooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0=?ooool00ol0003ooooo
ooooo`14ooooo`008Oooool00ol0003oooooo`00000gooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool0=Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo03Kooooo00?o
0000ooooooooool0@oooool0027ooooo0_l0000iooooo`03o`000?oooooooooo02Oooooo00?o0000
ooooooooool0=Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo03Kooooo00?o0000
ooooooooool0@oooool0027ooooo0_l0000iooooo`03o`000?oooooooooo02Oooooo00?o0000oooo
ooooool0=_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo03Kooooo00?o0000oooo
ooooool0@oooool0027ooooo0_l0000iooooo`03o`000?oooooooooo02Oooooo00?o0000oooooooo
ool0=_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo03Kooooo00?o0000oooooooo
ool0@oooool0027ooooo0_l0000iooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
=_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0
@oooool0027ooooo0_l0000iooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0=ooo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0@_oo
ool0027ooooo0_l0000jooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0=oooool0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0@_ooool0
027ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
03Oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo
04;ooooo000Qooooo`?o0000>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03So
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo04;o
oooo000Qooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0hooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo01[ooooo000Qooooo`03o`000?oooooooooo03Wooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0>?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01[ooooo000Q
ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0i
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo01[ooooo000Qooooo`03o`000?oooooooooo03[ooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool0>_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01_ooooo000Qooooo`03
o`000?oooooooooo03[ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0iooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo01_ooooo000Qooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0
>_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01_ooooo000Qooooo`03o`000?oo
oooooooo03[ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo02?ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo01_ooooo000Qooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool08_ooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0>oooool0
0ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01_ooooo000Qooooo`?o0000>oooool00ol0
003oooooooooo`0Qooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool08_ooool00ol0
003oooooooooo`0looooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool07?ooool0027o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool07?ooool0027ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool08Oooool00ol0003ooooo
ooooo`0looooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool07?ooool0027ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03gooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo027ooooo00?o
0000ooooooooool07?ooool0027ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0m
ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool07Oooool0027ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03gooooo00?o0000oooo
ooooool08?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool07Oooool0027ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Oooooo`03
o`000?oooooooooo03gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0nooooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool07Oooool000Oooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000oooo
ooooool0??ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03kooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool07Oooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omg
MgOo<S8booooo`03ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`0oooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0?_ooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo01gooooo0007ooooo`05oa0@4?oooooooooooooo
ool@41004?ooool00ol0003oooooooooo`02ooooo`?o0000??ooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo03oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`10oooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool07_ooool000Oooooo00Go0000oooooooo
ooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool0??ooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`10ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool07_ooool000Oo
oooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool0
0ol0003oooooooooo`0mooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0?oooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0Nooooo`001oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool0@?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo043ooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`0Nooooo`001oooool01OmgMgOoV9RHoooooonHV9So
MgMg00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo043ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Nooooo`001oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo03gooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool0@_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01oooooo000Qoooo
o`03o`000?oooooooooo03gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`11oooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo01oooooo000Qooooo`03o`000?oooooooooo03kooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool0@_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01oooooo000Qooooo`03o`00
0?oooooooooo03kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`12ooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo01oooooo000Qooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0@_oo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo023ooooo000Qooooo`?o0000?_ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`14ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool08?ooool0
027ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
04?ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool08?ooool0027ooooo00?o0000ooooooooool0?oooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`14ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool08?ooool0027ooooo
00?o0000ooooooooool0?oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool08?ooool0027ooooo00?o0000ooooooooool0?oooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`14ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool08Oooool0027ooooo00?o0000
ooooooooool0@?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Gooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool08Oooool0027ooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo04Gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`16oooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool08Oooool0027ooooo00?o0000oooooooo
ool0@?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Oooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool08Oooool0027ooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo04Oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`16ooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool08_ooool0027ooooo0ol00010ooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo04Oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Rooooo`008Oooool0
0ol0003oooooooooo`11ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0Aoooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`0Rooooo`008Oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
04Sooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Rooooo`008Oooool00ol0003o
ooooooooo`11ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0BOooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`0Sooooo`008Oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool0BOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04Wooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Sooooo`008Oooool00ol0003ooooooooo
o`12ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0BOooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`0Sooooo`008Oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool0BOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04[ooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`0Sooooo`008Oooool00ol0003oooooooooo`12oooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo04[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Toooo
o`008Oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool0Boooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo04_ooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`0Tooooo`008Oooool3o`0004?ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
C?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02Cooooo000Qooooo`03o`000?oo
oooooooo04?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1=ooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo02Gooooo000Qooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`1=ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0COooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02Gooooo000Qooooo`03o`000?oooooooooo
04Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
02Gooooo000Qooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`1>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0C_ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo02Kooooo000Qooooo`03o`000?oooooooooo04Cooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool0Coooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02Kooooo
000Qooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`1?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo02Kooooo000Qooooo`03o`000?oooooooooo04Gooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0D?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02Oooooo000Qoooo
o`03o`000?oooooooooo04Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Aoooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo02Oooooo000Qooooo`?o0000A_ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo057ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Booooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool09oooool0027ooooo00?o0000ooooooooool0
A_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
9oooool0027ooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo05?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Dooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool0:?ooool0027ooooo00?o0000ooooooooool0Aoooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`1Dooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0:?ooool0
027ooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
05Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0:?ooool0027ooooo00?o0000ooooooooool0Aoooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`1Fooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0:Oooool0027ooooo
00?o0000ooooooooool0B?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05Sooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0:_ooool001Sooooo1?l000000ol@413oooooooooo`02ooooo`03o`000?oo
oooooooo04Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Iooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo02[ooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0B_ooool2
o`0000?ooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo05[ooooo0_l00003ooooo`;o0000;Oooool001[ooooo00?o0000ooooooooool01?ooool3o`00
04_ooooo1Ol0001Nooooo`Go0000G_ooool5o`0002kooooo000Jooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5
ooooo`006?ooool00omEEEGoIVIVo`000006ooooo`03o`000?oooooooooo0?ooooooAOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool009gooooo0_l0000mooooo`;o0000R_ooool009gooooo00?o0000ooooooooool0?Ooo
ool00ol0003oooooooooo`28ooooo`00R_ooool3o`0000;ooooo00Ko<S8boa0@4?ooooooooooonk^
k_mEEED2o`000003odA4A?nj^[[ooooo00?ooooo00?o0000ooooooooool00_ooool01_o^k^koIVIV
o`000?l0003o<S8bokZj^SGooooo00?o0000ooooooooool0R?ooool008_ooooo00Go0000oooooooo
ooooc<c<oa0@4003ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo410@1?ooool00ol0003ooooooooo
o`02ooooo`;oMgMg00CoEEEEohN7QooMgMgoA4A4=Oooool00ol0003oooooooooo`28ooooo`00Rooo
ool01Ol0003ooooooooooomEEEGoQhN700?ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`02ooooo`03oiRHV?oooooo000003Sooooo00?o0000ooooooooool0R?ooool008_ooooo00Go
0000oooooooMgMgo0000onk^kP03ooooo`Ko00001?ooool00ol0003oooooooooo`02ooooo`03oiRH
V?oooooo000000?o00004_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0R?ooool008_ooooo0ol000000ol@413oV9RHooooo`02ooooo`06oeEEEOn7
QhOok^k^oooooon7QhOo<S8b1?ooool00ol0003oooooooooo`02ooooo`03ogMgMon7QhOoIVIV00;o
^[Zj00?o<S8booooooooool03oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0R?ooool008_ooooo00Go0000ooooooooooooc<c<o`000003ooooo`06
onk^k_mEEEGo0000o`000?m4A4Cok^k^1?ooool00ol0003oooooooooo`03ooooo`06ofIVI_l0003o
0000odA4A?o^k^kooooo0ol00004ooooo`;o000000?oooooo`000?l000000oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooooooo0ol00006ooooo`;o
00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo08Sooooo002;ooooo`05o`00
0?ooooooooooolc<c?l000003Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooool000001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0R?ooool008[ooooo1?l000000ol@413oZJVYooooo`0<ooooo`;o
00002oooool00ol0003oooooooooo`04ooooo`;o00001Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Ko00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00_ooool2o`0008[ooooo002Zooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooool000001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000?ooooo
00Co0000oooooooooooooooo0ol00004ooooo`Co00001?ooool00ol0003oooooooooo`2>ooooo`00
ZOooool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2?ooooo`00/?oo
ool2o`0000Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`2@ooooo`00Z_ooool0
0ol0003oooooooooo`2kooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-2, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0505254 0.309018 0.294303 [
[.15012 .29652 -9 -9 ]
[.15012 .29652 9 0 ]
[.27644 .29652 -3 -9 ]
[.27644 .29652 3 0 ]
[.40275 .29652 -9 -9 ]
[.40275 .29652 9 0 ]
[.52906 .29652 -6 -9 ]
[.52906 .29652 6 0 ]
[.65538 .29652 -12 -9 ]
[.65538 .29652 12 0 ]
[.78169 .29652 -6 -9 ]
[.78169 .29652 6 0 ]
[.908 .29652 -12 -9 ]
[.908 .29652 12 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .01472 -12 -4.5 ]
[.01131 .01472 0 4.5 ]
[.01131 .16187 -24 -4.5 ]
[.01131 .16187 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[.5 .63053 -37 0 ]
[.5 .63053 37 12.625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15012 .30902 m
.15012 .31527 L
s
[(2.5)] .15012 .29652 0 1 Mshowa
.27644 .30902 m
.27644 .31527 L
s
[(5)] .27644 .29652 0 1 Mshowa
.40275 .30902 m
.40275 .31527 L
s
[(7.5)] .40275 .29652 0 1 Mshowa
.52906 .30902 m
.52906 .31527 L
s
[(10)] .52906 .29652 0 1 Mshowa
.65538 .30902 m
.65538 .31527 L
s
[(12.5)] .65538 .29652 0 1 Mshowa
.78169 .30902 m
.78169 .31527 L
s
[(15)] .78169 .29652 0 1 Mshowa
.908 .30902 m
.908 .31527 L
s
[(17.5)] .908 .29652 0 1 Mshowa
.125 Mabswid
.04907 .30902 m
.04907 .31277 L
s
.07433 .30902 m
.07433 .31277 L
s
.0996 .30902 m
.0996 .31277 L
s
.12486 .30902 m
.12486 .31277 L
s
.17539 .30902 m
.17539 .31277 L
s
.20065 .30902 m
.20065 .31277 L
s
.22591 .30902 m
.22591 .31277 L
s
.25117 .30902 m
.25117 .31277 L
s
.3017 .30902 m
.3017 .31277 L
s
.32696 .30902 m
.32696 .31277 L
s
.35222 .30902 m
.35222 .31277 L
s
.37749 .30902 m
.37749 .31277 L
s
.42801 .30902 m
.42801 .31277 L
s
.45328 .30902 m
.45328 .31277 L
s
.47854 .30902 m
.47854 .31277 L
s
.5038 .30902 m
.5038 .31277 L
s
.55433 .30902 m
.55433 .31277 L
s
.57959 .30902 m
.57959 .31277 L
s
.60485 .30902 m
.60485 .31277 L
s
.63011 .30902 m
.63011 .31277 L
s
.68064 .30902 m
.68064 .31277 L
s
.7059 .30902 m
.7059 .31277 L
s
.73116 .30902 m
.73116 .31277 L
s
.75643 .30902 m
.75643 .31277 L
s
.80695 .30902 m
.80695 .31277 L
s
.83222 .30902 m
.83222 .31277 L
s
.85748 .30902 m
.85748 .31277 L
s
.88274 .30902 m
.88274 .31277 L
s
.93327 .30902 m
.93327 .31277 L
s
.95853 .30902 m
.95853 .31277 L
s
.98379 .30902 m
.98379 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01472 m
.03006 .01472 L
s
[(-1)] .01131 .01472 1 0 Mshowa
.02381 .16187 m
.03006 .16187 L
s
[(-0.5)] .01131 .16187 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(0.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .13244 m
.02756 .13244 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -98 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.625 moveto
(@) show
81.000 13.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\343) show
87.000 9.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344) show
93.000 9.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
97.188 9.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
( ) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
99.000 9.625 moveto
(H) show
103.188 9.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
107.375 9.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
111.562 9.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
117.562 9.625 moveto
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
121.750 9.625 moveto
(L) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
127.000 13.625 moveto
(D) show
133.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .21807 m
.04262 .1225 L
.0522 .08294 L
.06244 .04962 L
.0679 .03616 L
.07286 .02666 L
.07525 .02305 L
.07784 .01986 L
.08029 .01754 L
.08147 .01667 L
.08255 .01601 L
.08382 .01541 L
.08452 .01516 L
.08518 .01497 L
.08636 .01477 L
.08764 .01472 L
.08838 .01478 L
.08905 .01489 L
.08982 .01508 L
.09055 .01532 L
.09184 .0159 L
.09325 .01675 L
.09612 .01918 L
.09915 .02277 L
.10458 .03176 L
.10954 .04276 L
.11406 .05503 L
.12422 .08984 L
.14255 .17382 L
.1824 .39917 L
.20062 .49222 L
.21099 .53533 L
.21607 .55307 L
.22073 .56717 L
.22527 .57882 L
.23024 .58907 L
.23524 .59663 L
.23797 .59958 L
.2405 .60156 L
.24181 .6023 L
.24251 .6026 L
.24324 .60287 L
.24388 .60305 L
.24458 .6032 L
.24582 .60332 L
.24703 .60326 L
.24832 .60302 L
.24954 .60261 L
.25066 .60209 L
.25204 .60124 L
Mistroke
.25332 .60026 L
.25622 .59735 L
.25878 .594 L
.26151 .58962 L
.26688 .57861 L
.27182 .56581 L
.28296 .52815 L
.30314 .43449 L
.34268 .21028 L
.36258 .11144 L
.37127 .07704 L
.38071 .04745 L
.38593 .03493 L
.39075 .02596 L
.39536 .01979 L
.39769 .01759 L
.39892 .01668 L
.40025 .01589 L
.40158 .0153 L
.4023 .01506 L
.40297 .0149 L
.40417 .01474 L
.40546 .01474 L
.40618 .01483 L
.40697 .015 L
.40771 .01522 L
.40839 .01547 L
.40969 .01611 L
.41106 .017 L
.41355 .01916 L
.41588 .02181 L
.42118 .03012 L
.42618 .04076 L
.43162 .05532 L
.44151 .08919 L
.46006 .17407 L
.50081 .40443 L
.52104 .5054 L
.53095 .54435 L
.53529 .55865 L
.54004 .57219 L
.54431 .58237 L
.54888 .5911 L
.5514 .59494 L
.5537 .59781 L
.55601 .6001 L
.55819 .6017 L
.55932 .60232 L
.56056 .60282 L
.56186 .60317 L
Mistroke
.56307 .60331 L
.5642 .60329 L
.56524 .60314 L
.56644 .60282 L
.56758 .60236 L
.5688 .6017 L
.5701 .60081 L
.57245 .59871 L
.57524 .59541 L
.57776 .59166 L
.58264 .58243 L
.5878 .56992 L
.59702 .54086 L
.61785 .44882 L
.65584 .23423 L
.677 .12493 L
.68702 .08331 L
.69628 .05265 L
.70084 .04068 L
.70586 .03001 L
.71092 .02205 L
.71368 .01891 L
.71492 .01778 L
.71628 .01675 L
.7174 .01605 L
.7186 .01547 L
.71986 .01504 L
.72104 .0148 L
.72221 .01472 L
.72332 .01478 L
.72431 .01497 L
.72539 .01529 L
.72658 .01581 L
.72788 .01656 L
.7305 .01866 L
.73294 .02131 L
.73521 .02439 L
.7402 .03315 L
.74563 .04574 L
.75552 .07633 L
.77406 .15647 L
.81477 .38496 L
.83362 .48337 L
.84353 .52622 L
.85398 .56236 L
.85932 .57675 L
.86517 .58907 L
.86774 .59331 L
.87049 .59703 L
.87308 .59976 L
Mistroke
.87544 .60157 L
.8767 .60228 L
.87739 .60259 L
.87803 .60283 L
.87917 .60314 L
.88042 .6033 L
.88111 .60332 L
.88178 .60328 L
.88302 .60307 L
.88371 .60288 L
.88436 .60265 L
.88582 .60196 L
.8871 .60114 L
.88831 .60021 L
.89057 .59801 L
.893 .595 L
.89563 .59099 L
.90054 .58147 L
.90513 .57026 L
.91556 .53694 L
.93662 .44204 L
.97552 .22181 L
.97619 .21807 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool001So
oooo1?l000000ol@413oooooooooo`02ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000?ooooo`Ko00001Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000
ooooooooool01?ooool3o`0000oooooo1Ol0001Nooooo`Go0000Goooool4o`0006[ooooo000Joooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo05[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Koooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Ioooool001[ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0FOooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05Wooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`1Vooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Hooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo06Gooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0IOoo
ool0027ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo05Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Fooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0I?ooool0027ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`1Eooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0I?ooool0027o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05?o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool0Hoooool0027ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`1Cooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0Hoooool0027ooooo0ol0
000:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0D_ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`1Rooooo`008Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0DOooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo057ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`1Rooooo`008Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo053ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1Roooo
o`008Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool0Coooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo04oooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`1Qooooo`008Oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo04oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1Qooooo`008Ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Cooo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`1Qooooo`008Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo04gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Pooooo`008Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0COooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`1Pooooo`008Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04co
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Pooooo`008Oooool3o`0000Oooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool0Boooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo05oooooo
000Qooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`1;ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0Boooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo05oooooo000Qooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool0B_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo05oooooo000Qoooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1;oooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo05oooooo000Qooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool0BOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo05kooooo000Qooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`19ooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo05kooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0B?oo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo05kooooo000Qooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`18ooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo05kooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`18ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0Aoooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo05gooooo000Qooooo`?o00001Oooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`17ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0GOooool0027ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Oooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool0GOooool0027ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`16ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0GOooool0027ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Kooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool0G?ooool0027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo04Kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`15oooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0G?ooool0027ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04Gooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool0G?ooool0027ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo04Gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`14ooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool0G?ooool0027ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0G?oo
ool0027ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo04Cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`13ooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool0Foooool0027ooooo0ol00002ooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
04?ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1Kooooo`008Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0@oooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`1Kooooo`008Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04;ooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`1Kooooo`008Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0@_ooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`1Jooooo`008Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool0@_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo047ooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`1Jooooo`008Oooool01Ol0003ooooooooooooooooo
000001kooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo047ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1Jooooo`008Oooool01Ol0
003ooooooooooooooooo000001oooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1J
ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o
0000oc8b<_oMgMd01?ooool01Ol0003ooooooooooooooooo000001oooooo00?o0000ooooooooool0
@Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`1Iooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00Go0000ooooooooooooooooo`00000Oooooo`03
o`000?oooooooooo043ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo01kooooo00?o0000ooooooooool0FOooool000Go00000_ooool01Ol@413ooooo
oooooooooooo410@013ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
01oooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
03oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1Iooooo`001oooool01Ol0003o
oooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool4o`00023ooooo00?o0000oooo
ooooool0@?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo03oooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`1Iooooo`001oooool01Ol0003ooooooooooooooooo0000
00cooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`04o`000?ooooooooooo`00027ooooo00?o
0000ooooooooool0?oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo03oooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`1Iooooo`001oooool01Ol@413ooooooooooooo
oooo410@00cooooo00?o0000ooooooooool01_ooool01?l0003oooooooooool0000Qooooo`03o`00
0?oooooooooo03oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0nooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool0F?ooool000Oooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0<ooooo`03o`000?oooooooooo00Kooooo00Co0000oooooooooooo00008Oooool00ol0003o
ooooooooo`0nooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0?Oooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo05Sooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h03?ooool4o`0000Gooooo00Co0000oooooooooooo00008Oooool00ol0003oooooooooo`0noooo
o`03o`000?oooooooooo023ooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Poooo
o`03o`000?oooooooooo05Sooooo000Qooooo`03o`000?oooooo000002;ooooo00?o0000oooooooo
ool0?_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03gooooo00?o0000oooooooo
ool08?ooool00ol0003oooooooooo`1Hooooo`008Oooool00ol0003oooooo`00000Rooooo`03o`00
0?oooooooooo03kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0mooooo`03o`00
0?oooooooooo023ooooo00?o0000ooooooooool0F?ooool0027ooooo00?o0000ooooool000008ooo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0??oo
ool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo05Sooooo000Qooooo`03o`000?oooooo
000002?ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo03cooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`1Gooooo`008Oooool3o`00
02?ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`1Gooooo`008Oooool2o`0002Co
oooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`1Gooooo`008Oooool2o`0002Cooooo
00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03_ooooo
00?o0000ooooooooool08_ooool00ol0003oooooooooo`1Gooooo`008Oooool2o`0002Gooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool08_ooool00ol0003oooooooooo`1Gooooo`008Oooool2o`0002Gooooo00?o0000
ooooooooool0>_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo03[ooooo00?o0000
ooooooooool08_ooool00ol0003oooooooooo`1Gooooo`008Oooool2o`0002Gooooo00?o0000oooo
ooooool0>_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo03Wooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`1Fooooo`008Oooool00ol0003oooooooooo`0Tooooo`03
o`000?oooooooooo03[ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0iooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool0E_ooool0027ooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
>Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo05Kooooo000Qooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo03Wooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0iooooo`03o`000?oo
oooooooo01[ooooo000Qooooo`?o00009Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo
oooo03Wooooo00?o0000ooooooooool06_ooool0027ooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0hooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0>?ooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool06_ooool0027o
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo03So
oooo00?o0000ooooooooool06_ooool0027ooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0hooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0=oooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool06_ooool0027ooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool0=oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo03Oooooo00?o
0000ooooooooool06oooool0027ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0g
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool06oooool0027ooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool0=oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo03Oooooo00?o0000oooo
ooooool06oooool0027ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0fooooo`03
o`000?oooooooooo02Sooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo03Oooooo00?o0000ooooooooool06oooool0027ooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0
=Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0
6oooool0027ooooo0ol0000Vooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0:?oo
ool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0=Ooo
ool00ol0003oooooooooo`0Looooo`008Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo03Kooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooo
oooo02Sooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Looooo`008Oooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0:?ooool00ol0
003oooooooooo`0eooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0=Oooool00ol0
003oooooooooo`0Looooo`008Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo03Go
oooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02So
oooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Looooo`008Oooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0:_ooool00ol0003ooooo
ooooo`0cooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0=Oooool00ol0003ooooo
ooooo`0Looooo`008Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo03Cooooo00?o
0000ooooooooool0:_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02[ooooo00?o
0000ooooooooool0<oooool00ol0003oooooooooo`0Mooooo`008Oooool00ol0003oooooooooo`0J
ooooo`Go00001Oooool2ob4Q8@03ooooool0003ooooo00;ooooo00GoA4A4o`000?l0003o<S8bomgM
g@0Jooooo`05odA4A?l0003o0000oc8b<_oMgMd03oooool00ol0003oooooooooo`0:ooooo`03o`00
0?o^k^kooooo00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd03?ooool00ol0003o
ooooooooo`07ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kQCooooo1?l0
00000ol@413oooooooooo`06o`0000Cooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
4_ooool4o`000005oa0@4?oooooooooooooooom4A4@00_l000000olb<S;ogMgMooooo`0Aooooo`Co
000000?o410@ooooooooool00_ooool00ol0003ok^k^ooooo`05ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool07Oooool0027ooooo00?o0000oooooooo
ool06_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo0_lQ8B42ooooo`03o`000?oooooooooo
00?ooooo00?oMgMgoc8b<_ooool07?ooool00omgMgOo<S8booooo`0>ooooo`03o`000?oooooooooo
00[ooooo00?oEEEEojVYZOooool01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool02oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0F
ooooo`03o`000?oooooooooo00;ooooo00KoV9RHob4Q8Oo^k^koooooodA4A?l00004ooooo`;o8B4Q
2?ooool00omgMgOo<S8booooo`0Cooooo`03o`000?oooooooooo00Gooooo00?o0000ogMgMolb<S80
5?ooool00ol0003oooooooooo`04ooooo`03oeEEEOnYZJWooooo00Gooooo0_lQ8B48ooooo`03ogMg
Molb<S;ooooo00?ooooo00?o0000ooooooooool07Oooool0027ooooo00?o0000ooooooooool06ooo
ool00onHV9So8B4Qonk^kP0:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo00?oZJVYoeEEEOooool04?oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@01Kooooo00?o0000ooooooooool00oooool01OnHV9So8B4Q
onk^k_oooooo000000oooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooo000001Cooooo00?o0000ooooooooool01?ooool00onYZJWoEEEEooooo`0@ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool07Oooool0027ooooo0ol0000Looooo`03oiRH
V?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool00omgMgOo<S8booooo`0Looooo`03ogMg
Molb<S;ooooo00gooooo00?o0000ooooooooool03?ooool00olQ8B7oooooooooo`0>ooooo`03ogMg
Molb<S;ooooo00_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000005_ooool00ol0003oooooooooo`04ooooo`04oiRHV?lQ8B7ok^k^o`00
00kooooo00?oMgMgoc8b<_ooool04oooool00ol0003oooooooooo`05ooooo`03o`000?mgMgOo<S8b
01Cooooo00?o0000ooooooooool01Oooool00olQ8B7oooooooooo`0>ooooo`03ogMgMolb<S;ooooo
00?ooooo00?o0000ooooooooool07Oooool0027ooooo00?o0000ooooooooool07Oooool00omgMgOo
IVIVooooo`08ooooo`08o`000?ooooooooooo`000?lQ8B7o0000oc8b<_o<c<`Jooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`03_ooool00ol0003oooooooooo`0<ooooo`03oeEEEOo<c<cooooo00_ooooo
00Go0000ob4Q8Ol0003o<S8bolc<c00=ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool00_ooool01Ol0003ooooooooooooooooo000001Kooooo00?o0000ooooooooool01Oooool00omg
MgOo0000ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`05?ooool00ol0003oooooooooo`03
ooooo`05o`000?lQ8B7o0000o`000?o<c<`05?ooool00ol0003oooooooooo`05ooooo`03oeEEEOo<
c<cooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo01gooooo
000Qooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool01oooool01?l0003ooooooooo
ool0000Nooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03?ooool00onYZJWoMgMg
ooooo`0;ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41005_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`03ooooo`04
o`000?ooooooooooo`0001Gooooo00?o0000ooooooooool01Oooool00onYZJWoMgMgooooo`0;oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool07_ooool0027ooooo00?o0000oooooooo
ool06_ooool01Ol0003o^[ZjoooooonHV9So410@00[ooooo00?o0000ooooool000007_ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo00Wooooo00Go410@oooooooooooooooooc8b<P0<
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL05_ooool00ol0003oooooooooo`02ooooo`05o`000?nj
^[[ooooooiRHV?l000003?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00?ooooo
00Co0000oooooooooooo00005Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooo
oolb<S803?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01kooooo000Qooooo`03
o`000?oooooooooo01[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00:ooooo`03o`000?oooooo0000
00?o00006oooool4o`0000oooooo00?o0000ooooooooool02Oooool5o`0000cooooo1?l0000>oooo
o`03o`000?oooooooooo00Kooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^01Cooooo00?oEEEEofIVI_l000001?ooool01OnHV9So410@o`000?lQ8B7o000000cooooo1?l0
000Cooooo`03oeEEEOmVIVKo000000Gooooo1?l0000Cooooo`03oeEEEOmVIVKo000000Cooooo1Ol0
000<ooooo`Co00001?ooool00ol0003oooooooooo`0Nooooo`008Oooool00ol0003oooooooooo`0Y
ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0a
ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0N
ooooo`008Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo033ooooo00?o0000oooo
ooooool0;Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo02cooooo00?o0000oooo
ooooool0<Oooool00ol0003oooooooooo`0Nooooo`008Oooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo033ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0_ooooo`03
o`000?oooooooooo02kooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Eooooo`;o
00000_ooool2o`0000Cooooo000Qooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0
;_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01Gooooo00Kok^k^ob4Q8On7QhOo
^[Zjo`000?oMgMd4ooooo`006_ooooooo`0003[o00003?ooool01?oMgMgo0000oa0@4?o<c<`5oooo
o`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01Oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000001oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo0_l00006ooooo`03o`000?oooooo
oooo00oooooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool0027ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000001Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Go0000oooooooooooooooo
o`000003ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`;o00001_ooool00ol0003oooooooooo`0?ooooo`04ob4Q8OmgMgOoMgMgoc8b<PGo
oooo000Qooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`0_ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0;oooool00ol0003ooooo
ooooo`0^ooooo`03o`000?oooooooooo01Kooooo0_l00002ooooo`;o00001?ooool0027ooooo00?o
0000ooooooooool0:_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo033ooooo00?o
0000ooooooooool0;Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02gooooo00?o
0000ooooooooool08?ooool0027ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0]
ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0`
ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool08?ooool0027ooooo00?o0000oooo
ooooool0:oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo033ooooo00?o0000oooo
ooooool0;Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02gooooo00?o0000oooo
ooooool08?ooool0027ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0]ooooo`03
o`000?oooooooooo033ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0`ooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool08?ooool0027ooooo00?o0000ooooooooool0
:oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0
8Oooool0027ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo037ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo02cooooo00?o0000ooooooooool08Oooool0027ooooo0ol0000[ooooo`03o`000?oooooo
oooo02cooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooo
oooo03;ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Qooooo`008Oooool00ol0
003oooooooooo`0/ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0<_ooool00ol0
003oooooooooo`0[ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0:oooool00ol0
003oooooooooo`0Qooooo`008Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo02_o
oooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo03;o
oooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Qooooo`008Oooool00ol0003ooooo
ooooo`0/ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0<_ooool00ol0003ooooo
ooooo`0[ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0:oooool00ol0003ooooo
ooooo`0Qooooo`008Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo02_ooooo00?o
0000ooooooooool0<_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03?ooooo00?o
0000ooooooooool0:_ooool00ol0003oooooooooo`0Rooooo`008Oooool00ol0003oooooooooo`0/
ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Z
ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0R
ooooo`008Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool0=?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo03Cooooo00?o0000oooo
ooooool0:Oooool00ol0003oooooooooo`0Rooooo`008Oooool00ol0003oooooooooo`0]ooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo03Cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Rooooo`00
8Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0
=?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`0Rooooo`008Oooool3o`0002gooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0=?oo
ool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02?ooooo000Qooooo`03o`000?oooooo
oooo02gooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooo
oooo02Sooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo02?ooooo000Qooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0:?ooool00ol0
003oooooooooo`0eooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0=Oooool00ol0
003oooooooooo`0Xooooo`03o`000?oooooooooo02?ooooo000Qooooo`03o`000?oooooooooo02ko
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02?o
oooo000Qooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`0fooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0=_ooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo02?ooooo000Qooooo`03o`000?oooooooooo02kooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool0=_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Cooooo000Q
ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0f
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo02Cooooo000Qooooo`03o`000?oooooooooo02kooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool0=oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Cooooo000Qooooo`03
o`000?oooooooooo02oooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo02Cooooo000Qooooo`?o0000;oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo03Sooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool09?ooool0027ooooo00?o0000ooooooooool0;ooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool09?oo
ool0027ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo03Sooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool09Oooool0027ooooo00?o0000ooooooooool0;oooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`0iooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool09Oooool0027o
oooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03Wo
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool09Oooool0027ooooo00?o0000ooooooooool0<?ooool00ol0003ooooo
ooooo`0Sooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool08oooool00ol0003ooooo
ooooo`0jooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool09Oooool0027ooooo00?o
0000ooooooooool0<?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03[ooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool09Oooool0027ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0S
ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0j
ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool09_ooool0027ooooo00?o0000oooo
ooooool0<?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03[ooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo02;ooooo00?o0000oooo
ooooool09_ooool0027ooooo0ol0000aooooo`03o`000?oooooooooo02;ooooo00?o0000oooooooo
ool0>_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool08_ooool00ol0003oooooooooo`0Vooooo`008Oooool00ol0003oooooooooo`0aooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo03cooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Vooooo`008Ooo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0??oo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`0Vooooo`008Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo03cooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Wooooo`008Oooool00ol0
003oooooooooo`0aooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0??ooool00ol0
003oooooooooo`0Qooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`0Wooooo`008Oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo023o
oooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03go
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Wooooo`008Oooool00ol0003ooooo
ooooo`0booooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0?_ooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`0Wooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4
A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Wooooo`001oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000oooooooo
ool0<_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03kooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool0:?ooool000Oooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;o
oooo0ol0000booooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0?_ooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`0Xooooo`001oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_oo
ool00oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool0@?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo03oooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`0Xooooo`001oooool01Ol0003ooooooooooooooooo000000co
oooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo03?ooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool0@?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Sooooo0007ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
03?ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
02Sooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo03?ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`10oooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo02Wooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`00
00Gooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
047ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool0:Oooool0027ooooo00?o0000ooooooooool0=?ooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`11ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0:Oooool0027ooooo
00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo04;ooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool0:Oooool0027ooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`12ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0:Oooool0027ooooo00?o0000
ooooooooool0=?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04?ooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool0:_ooool0027ooooo0ol0000dooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool0A?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04?ooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0Zooooo`008Oooool00ol0003oooooooooo`0eooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo04?ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Zooooo`00
8Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
A?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`0Zooooo`008Oooool00ol0003oooooooooo`0eooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo04Gooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Zooooo`008Oooool0
0ol0003oooooooooo`0eooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0AOooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`0[ooooo`008Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
04Gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0[ooooo`008Oooool00ol0003o
ooooooooo`0fooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0A_ooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`0[ooooo`008Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Kooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`0[ooooo`008Oooool00ol0003ooooooooo
o`0fooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0Aoooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`0[ooooo`008Oooool3o`0003Oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`18
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo02cooooo000Qooooo`03o`000?oooooooooo03Oooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool0Aoooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02cooooo000Qooooo`03
o`000?oooooooooo03Oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`18ooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo02cooooo000Qooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
BOooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02cooooo000Qooooo`03o`000?oo
oooooooo03Oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1:ooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo02cooooo000Qooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`1:ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0B_ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02gooooo000Qooooo`03o`000?oooooooooo
03Sooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
02gooooo000Qooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`1;ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0Boooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo02gooooo000Qooooo`03o`000?oooooooooo03Sooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02gooooo
000Qooooo`?o0000>?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo04cooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool0;Oooool0027ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1=
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0;_ooool0027ooooo00?o0000oooo
ooooool0>Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04gooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool0;_ooool0027ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo04kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1>ooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool0;_ooool0027ooooo00?o0000ooooooooool0
>Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
;oooool0027ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo04kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1@ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool0;oooool0027ooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`1@ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0;oooool0
027ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
053ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool0<?ooool0027ooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`1Aooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0<?ooool0027ooooo
0ol0000kooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0D_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0`ooooo`008Oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0D_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05;ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0aooooo`008Oooool00ol0003oooooooooo`0l
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0a
ooooo`008Oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool0E?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo05Cooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0booooo`008Oooool00ol0003oooooooooo`0mooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo05Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0booooo`00
8Oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
E_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0cooooo`008Oooool00ol0003oooooooooo`0nooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo05Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0cooooo`006?ooool4
o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1I
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0=?ooool001[ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo00;ooooo0_l0001Loooo
o`;o00001?ooool00ol0003oooooooooo`1Kooooo`04o`000?ooooooooooooooo`;o0000=oooool0
01[ooooo00?o0000ooooooooool01?ooool3o`00047ooooo1Ol0001Nooooo`Go0000G_ooool5o`00
03Sooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`00
6_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006?ooool00omEEEGoIVIVo`000006oooo
o`03o`000?oooooooooo0?ooooooAOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool009gooooo0_l0000mooooo`;o0000
R_ooool009gooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`28ooooo`00R_ooool3
o`0000;ooooo00Ko<S8boa0@4?ooooooooooonk^k_mEEED2o`000003odA4A?nj^[[ooooo00?ooooo
00?o0000ooooooooool00_ooool01_o^k^koIVIVo`000?l0003o<S8bokZj^SGooooo00?o0000oooo
ooooool0R?ooool008_ooooo00Go0000ooooooooooooc<c<oa0@4003ooooo`06oeEEEOmgMgOooooo
onk^k_mgMgOo410@1?ooool00ol0003oooooooooo`02ooooo`;oMgMg00CoEEEEohN7QooMgMgoA4A4
=Oooool00ol0003oooooooooo`28ooooo`00Roooool01Ol0003ooooooooooomEEEGoQhN700?ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`03oiRHV?oooooo000003Sooooo
00?o0000ooooooooool0R?ooool008_ooooo00Go0000oooooooMgMgo0000onk^kP03ooooo`Ko0000
1?ooool00ol0003oooooooooo`02ooooo`03oiRHV?oooooo000000?o00004_ooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0R?ooool008_ooooo0ol0
00000ol@413oV9RHooooo`02ooooo`06oeEEEOn7QhOok^k^oooooon7QhOo<S8b1?ooool00ol0003o
ooooooooo`02ooooo`03ogMgMon7QhOoIVIV00;o^[Zj00?o<S8booooooooool03oooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0R?ooool008_ooooo
00Go0000ooooooooooooc<c<o`000003ooooo`06onk^k_mEEEGo0000o`000?m4A4Cok^k^1?ooool0
0ol0003oooooooooo`03ooooo`06ofIVI_l0003o0000odA4A?o^k^kooooo0ol00004ooooo`;o0000
00?oooooo`000?l000000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000?ooooo
00Co0000oooooooooooooooo0ol00006ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo08Sooooo002;ooooo`05o`000?ooooooooooolc<c?l000003Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooool000001?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00002?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0R?ooool008[o
oooo1?l000000ol@413oZJVYooooo`0<ooooo`;o00002oooool00ol0003oooooooooo`04ooooo`;o
00001Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Ko00000_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool2o`0008[o
oooo002Zooooo`03o`000?oooooooooo00Cooooo00?o0000ooooool000001?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooooooo0ol00004ooooo`Co
00001?ooool00ol0003oooooooooo`2>ooooo`00ZOooool2o`0000Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`2?ooooo`00/?ooool2o`0000Sooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`2@ooooo`00Z_ooool00ol0003oooooooooo`2kooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-2, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0505254 0.309017 0.294302 [
[.15012 .29652 -9 -9 ]
[.15012 .29652 9 0 ]
[.27644 .29652 -3 -9 ]
[.27644 .29652 3 0 ]
[.40275 .29652 -9 -9 ]
[.40275 .29652 9 0 ]
[.52906 .29652 -6 -9 ]
[.52906 .29652 6 0 ]
[.65538 .29652 -12 -9 ]
[.65538 .29652 12 0 ]
[.78169 .29652 -6 -9 ]
[.78169 .29652 6 0 ]
[.908 .29652 -12 -9 ]
[.908 .29652 12 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .01471 -12 -4.5 ]
[.01131 .01471 0 4.5 ]
[.01131 .16187 -24 -4.5 ]
[.01131 .16187 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[.5 .63053 -37 0 ]
[.5 .63053 37 12.625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15012 .30902 m
.15012 .31527 L
s
[(2.5)] .15012 .29652 0 1 Mshowa
.27644 .30902 m
.27644 .31527 L
s
[(5)] .27644 .29652 0 1 Mshowa
.40275 .30902 m
.40275 .31527 L
s
[(7.5)] .40275 .29652 0 1 Mshowa
.52906 .30902 m
.52906 .31527 L
s
[(10)] .52906 .29652 0 1 Mshowa
.65538 .30902 m
.65538 .31527 L
s
[(12.5)] .65538 .29652 0 1 Mshowa
.78169 .30902 m
.78169 .31527 L
s
[(15)] .78169 .29652 0 1 Mshowa
.908 .30902 m
.908 .31527 L
s
[(17.5)] .908 .29652 0 1 Mshowa
.125 Mabswid
.04907 .30902 m
.04907 .31277 L
s
.07433 .30902 m
.07433 .31277 L
s
.0996 .30902 m
.0996 .31277 L
s
.12486 .30902 m
.12486 .31277 L
s
.17539 .30902 m
.17539 .31277 L
s
.20065 .30902 m
.20065 .31277 L
s
.22591 .30902 m
.22591 .31277 L
s
.25117 .30902 m
.25117 .31277 L
s
.3017 .30902 m
.3017 .31277 L
s
.32696 .30902 m
.32696 .31277 L
s
.35222 .30902 m
.35222 .31277 L
s
.37749 .30902 m
.37749 .31277 L
s
.42801 .30902 m
.42801 .31277 L
s
.45328 .30902 m
.45328 .31277 L
s
.47854 .30902 m
.47854 .31277 L
s
.5038 .30902 m
.5038 .31277 L
s
.55433 .30902 m
.55433 .31277 L
s
.57959 .30902 m
.57959 .31277 L
s
.60485 .30902 m
.60485 .31277 L
s
.63011 .30902 m
.63011 .31277 L
s
.68064 .30902 m
.68064 .31277 L
s
.7059 .30902 m
.7059 .31277 L
s
.73116 .30902 m
.73116 .31277 L
s
.75643 .30902 m
.75643 .31277 L
s
.80695 .30902 m
.80695 .31277 L
s
.83222 .30902 m
.83222 .31277 L
s
.85748 .30902 m
.85748 .31277 L
s
.88274 .30902 m
.88274 .31277 L
s
.93327 .30902 m
.93327 .31277 L
s
.95853 .30902 m
.95853 .31277 L
s
.98379 .30902 m
.98379 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01471 m
.03006 .01471 L
s
[(-1)] .01131 .01471 1 0 Mshowa
.02381 .16187 m
.03006 .16187 L
s
[(-0.5)] .01131 .16187 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(0.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04414 m
.02756 .04414 L
s
.02381 .07357 m
.02756 .07357 L
s
.02381 .103 m
.02756 .103 L
s
.02381 .13244 m
.02756 .13244 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -98 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.625 moveto
(@) show
81.000 13.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\343) show
87.000 9.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344) show
93.000 9.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
97.188 9.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
( ) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
99.000 9.625 moveto
(H) show
103.188 9.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
107.375 9.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
111.562 9.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
117.562 9.625 moveto
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
121.750 9.625 moveto
(L) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
127.000 13.625 moveto
(D) show
133.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .07092 m
.02846 .05604 L
.03279 .0441 L
.03793 .03243 L
.04262 .02431 L
.04498 .02114 L
.04754 .01841 L
.04872 .01741 L
.04996 .01652 L
.05113 .01584 L
.0522 .01536 L
.05341 .01498 L
.05471 .01475 L
.05592 .01472 L
.05707 .01485 L
.05772 .01498 L
.05841 .01518 L
.05964 .01568 L
.06111 .01649 L
.06244 .01745 L
.06508 .01993 L
.06787 .02342 L
.07287 .03182 L
.07824 .04388 L
.08414 .06057 L
.10458 .14272 L
.145 .36736 L
.16364 .46744 L
.17347 .5124 L
.18391 .55172 L
.18916 .56766 L
.19495 .58202 L
.19748 .58719 L
.20021 .59197 L
.20277 .59571 L
.20515 .59852 L
.20759 .60074 L
.20889 .60164 L
.21027 .60239 L
.21096 .60268 L
.21172 .60294 L
.21243 .60312 L
.21309 .60324 L
.21433 .60332 L
.21565 .60321 L
.21679 .60296 L
.21802 .60252 L
.21917 .60194 L
.22023 .60128 L
.22282 .59913 L
Mistroke
.22527 .59639 L
.23032 .58863 L
.23489 .57919 L
.24512 .5502 L
.2546 .5145 L
.26352 .47431 L
.30212 .25991 L
.32171 .15386 L
.33208 .10616 L
.34318 .06456 L
.34868 .0482 L
.35389 .03556 L
.35856 .02668 L
.36098 .02303 L
.36364 .01977 L
.36612 .01745 L
.36726 .01662 L
.36845 .01591 L
.36973 .01534 L
.37091 .01497 L
.37217 .01476 L
.37289 .01472 L
.37355 .01473 L
.37475 .01489 L
.37588 .01519 L
.37689 .01558 L
.37799 .01614 L
.38045 .01789 L
.38272 .02012 L
.38741 .02657 L
.39244 .03619 L
.40152 .06031 L
.41232 .09935 L
.42217 .14335 L
.46199 .36462 L
.48018 .4629 L
.49054 .51077 L
.50028 .54808 L
.50978 .57595 L
.51513 .58754 L
.51767 .59197 L
.52003 .59545 L
.52259 .5985 L
.52491 .60063 L
.52624 .60157 L
.5275 .60228 L
.52882 .60283 L
.52957 .60305 L
.53026 .60319 L
.53154 .60332 L
Mistroke
.53275 .60326 L
.53407 .60301 L
.53481 .60278 L
.53549 .60251 L
.53685 .60182 L
.53833 .60082 L
.54103 .59836 L
.54359 .59527 L
.54635 .59111 L
.55136 .58142 L
.56072 .55624 L
.57165 .51621 L
.5817 .47083 L
.62121 .25061 L
.64108 .1445 L
.64976 .10521 L
.6592 .06933 L
.66441 .05303 L
.66923 .04036 L
.67412 .02999 L
.67872 .02264 L
.68104 .01983 L
.68355 .01748 L
.6849 .01651 L
.68632 .01571 L
.68754 .01521 L
.68823 .01501 L
.68887 .01486 L
.68954 .01476 L
.69027 .01472 L
.69096 .01473 L
.6916 .01479 L
.6928 .01503 L
.69408 .01546 L
.69474 .01576 L
.69545 .01614 L
.69673 .01696 L
.69964 .01954 L
.70219 .02259 L
.7049 .02663 L
.70978 .03594 L
.71558 .0503 L
.72083 .06625 L
.74094 .14969 L
.78108 .37392 L
.79951 .47205 L
.80996 .5189 L
.8197 .55454 L
.82936 .5809 L
.83477 .59138 L
Mistroke
.83716 .59499 L
.83969 .59812 L
.84098 .59942 L
.84239 .60065 L
.84369 .60157 L
.84489 .60224 L
.84556 .60255 L
.84629 .60283 L
.84706 .60305 L
.8478 .6032 L
.84848 .60329 L
.84921 .60332 L
.85053 .60322 L
.85122 .60309 L
.85186 .60291 L
.85256 .60267 L
.85329 .60236 L
.85454 .60168 L
.8559 .60074 L
.85842 .59844 L
.86077 .59564 L
.86578 .58763 L
.87122 .57583 L
.88112 .54655 L
.89075 .5093 L
.89967 .46833 L
.93892 .24913 L
.97619 .07092 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool001So
oooo1?l000000ol@413oooooooooo`02ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000?ooooo`Ko00001Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000
ooooooooool01?ooool3o`0000Gooooo1Ol0001Nooooo`Go0000G_ooool6o`0007?ooooo000Joooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo05_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Koooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0LOooool001[ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0FOooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05Wooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`1`ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Hooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo06oooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Kooo
ool0027ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo05Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Eooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0K_ooool0027ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`1Dooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0KOooool0027o
oooo00Go0000ooooooooooooooooo`00000;ooooo`03o`000?oooooooooo05Cooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool0KOooool0027ooooo00Go0000ooooooooooooooooo`00000<ooooo`03o`000?oooooooooo
05?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool0KOooool0027ooooo1?l0000=ooooo`03o`000?oooooooooo05;o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool0K?ooool0027ooooo00Co0000oooooooooooo00003Oooool00ol0003o
ooooooooo`1Booooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0DOooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo06cooooo000Qooooo`04o`000?ooooooooooo`0000ko
oooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo057o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1/ooooo`008Oooool00ol0003ooooo
o`00000?ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`1@ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0K?ooool0027ooooo00?o
0000ooooool000003oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool0Coooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo06_ooooo000Q
ooooo`03o`000?oooooo0000013ooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1[
ooooo`008Oooool2o`00017ooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo04kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1[oooo
o`008Oooool2o`00017ooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo04gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Zooooo`00
8Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
COooool00ol0003oooooooooo`0Jooooo`008Oooool3o`00017ooooo00?o0000ooooooooool0C?oo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo01[ooooo000Qooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo04cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1<ooooo`03o`000?oooooo
oooo01[ooooo000Qooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0C?ooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`1;ooooo`03o`000?oooooooooo01_ooooo000Qooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo04_o
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo01_o
oooo000Qooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0B_ooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`1;ooooo`03o`000?oooooooooo01_ooooo000Qooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool0B_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04Wooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo01_ooooo000Q
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1:
ooooo`03o`000?oooooooooo01_ooooo000Qooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool0BOooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04Sooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo01cooooo000Qooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo04Sooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`19ooooo`03
o`000?oooooooooo01cooooo000Qooooo`?o00004oooool00ol0003oooooooooo`18ooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo04Wooooo00?o0000ooooooooool07?ooool0027ooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0Aooo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool07?oo
ool0027ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`17ooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo04Sooooo00?o0000ooooooooool07?ooool0027ooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`17ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0A_ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool07Oooool0027o
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Oo
oooo00?o0000ooooooooool07Oooool0027ooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`15ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0AOooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool07Oooool0027ooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool0AOooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04Kooooo00?o
0000ooooooooool07Oooool0027ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`15
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool07_ooool0027ooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool0@oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04Gooooo00?o0000oooo
ooooool07_ooool0027ooooo0ol0000Fooooo`03o`000?oooooooooo04?ooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool0A?ooool00ol0003oooooooooo`0Nooooo`008Oooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo04?ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`13ooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0Nooooo`008Ooo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0A?oo
ool00ol0003oooooooooo`0Nooooo`008Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo047ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Oooooo`008Oooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`11ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0@oooool00ol0
003oooooooooo`0Oooooo`008Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo047o
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0Oooooo`008Oooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`11ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0@_ooool00ol0003ooooo
ooooo`0Oooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4
A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo043o
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0Oooooo`001oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool0?oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo047ooooo00?o0000oooooooo
ool08?ooool000Go00000_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo03oooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool0@Oooool00ol0003oooooooooo`0Pooooo`001oooool01Ol0003ooooooooooooooooo000000oo
oooo00?oMgMgoc8b<_ooool00oooool3o`0001Sooooo00?o0000ooooooooool0?oooool00ol0003o
ooooooooo`0Nooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`10ooooo`03o`000?oooooooooo023ooooo0007ooooo`05o`000?ooooooooooooooool0
00003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`0nooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0?oooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool08?ooool000Oo
oooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool0?oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo03oooooo00?o0000oooo
ooooool08Oooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
03oooooo00?o0000ooooooooool08Oooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<oooo
o`Co00001Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo03gooooo00?o0000oooo
ooooool08?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool0?oooool00ol0003oooooooooo`0Qooooo`008Oooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo03gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0mooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0Qooooo`00
8Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
?_ooool00ol0003oooooooooo`0Qooooo`008Oooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo03cooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0mooooo`03o`000?oo
oooooooo023ooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Rooooo`008Oooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool08Oooool0
0ol0003oooooooooo`0mooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0?Oooool0
0ol0003oooooooooo`0Rooooo`008Oooool3o`0001Wooooo00?o0000ooooooooool0??ooool00ol0
003oooooooooo`0Rooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool08Oooool00ol0
003oooooooooo`0mooooo`03o`000?oooooooooo02;ooooo000Qooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo02;o
oooo000Qooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`0Rooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool08_ooool00ol0003ooooo
ooooo`0looooo`03o`000?oooooooooo02;ooooo000Qooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool0>_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool08_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02?ooooo000Q
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0S
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo02?ooooo000Qooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool0>_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03[ooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02?ooooo000Qooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Tooooo`03
o`000?oooooooooo03Wooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo02?ooooo000Qooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
>Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02Cooooo000Qooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo03Wooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0iooooo`03o`000?oo
oooooooo02Cooooo000Qooooo`?o00006oooool00ol0003oooooooooo`0hooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo
oooo03Wooooo00?o0000ooooooooool09?ooool0027ooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`0hooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>Oooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool09?ooool0027o
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Wo
oooo00?o0000ooooooooool09?ooool0027ooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0gooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0=oooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool09Oooool0027ooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool0=oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo03Oooooo00?o
0000ooooooooool09Oooool0027ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0f
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool09Oooool0027ooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo02Oooooo00?o0000oooo
ooooool0=oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo03Oooooo00?o0000oooo
ooooool09Oooool0027ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0fooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo03Oooooo00?o0000ooooooooool09Oooool0027ooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
=_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0
9_ooool0027ooooo0ol0000Mooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0:?oo
ool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0=Ooo
ool00ol0003oooooooooo`0Vooooo`008Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo03Cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooo
oooo02Sooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Vooooo`008Oooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`0eooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0=Oooool00ol0
003oooooooooo`0Vooooo`008Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo03Co
oooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02So
oooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Vooooo`008Oooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0:Oooool00ol0003ooooo
ooooo`0dooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0=?ooool00ol0003ooooo
ooooo`0Wooooo`008Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo03Cooooo00?o
0000ooooooooool0:_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02[ooooo00?o
0000ooooooooool0<oooool00ol0003oooooooooo`0Wooooo`008Oooool00ol0003oooooooooo`0J
ooooo`Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Jooooo`05odA4A?l0
003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Dooooo`03o`000?o^k^kooooo00Gooooo
0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd00_ooool00ol0003oooooooooo`0Aooooo`Co
000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kQCooooo1?l000000ol@413ooooooooo
o`05o`0000Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd04_ooool4o`000005oa0@
4?oooooooooooooooom4A4@00_l000000olb<S;ogMgMooooo`0Aooooo`Co000000?o410@oooooooo
ool00_ooool00ol0003ok^k^ooooo`05ooooo`;o8B4Q1?ooool01_l0003oA4A4o`000?l0003o<S8b
omgMgBCooooo000Qooooo`03o`000?oooooooooo01[ooooo00GoV9RHob4Q8Oo^k^koooooo`000005
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`0Looooo`03ogMgMolb<S;ooooo00?ooooo00?o0000
ooooooooool05Oooool00omEEEGoZJVYooooo`05ooooo`;o8B4Q2?ooool01OmgMgOo<S8boooooooo
oooo000001Gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01Kooooo
00?o0000ooooooooool00_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo0_lQ8B48ooooo`03
ogMgMolb<S;ooooo017ooooo00?o0000ooooool000002?ooool00omgMgOo<S8booooo`0Cooooo`03
o`000?oooooooooo00Cooooo00?oEEEEojVYZOooool01Oooool2ob4Q8@Cooooo00Ko0000oooooooo
ooooooooogMgMolb<S8Tooooo`008Oooool00ol0003oooooooooo`0Kooooo`04oiRHV?lQ8B7ok^k^
o`00013ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo01Gooooo00?oZJVYoeEEEOooool04?ooool01?l0003oooooooooool0000Eooooo`03o`000?oo
oooooooo00;ooooo00Go410@oooooooooooooooooa0@400Fooooo`03o`000?oooooooooo00?ooooo
00?oV9RHob4Q8Oo^k^h04Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo000000Wooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`04ooooo`03ojVYZOmEEEGooooo00_ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Rooooo`008Oooool3o`0001cooooo00?o
V9RHob4Q8Ol000003oooool00omgMgOo<S8booooo`0Looooo`03ogMgMolb<S;ooooo00?ooooo00?o
0000ooooooooool05_ooool00olQ8B7oooooooooo`0>ooooo`05ogMgMolb<S;oooooooooool00000
5Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000005_ooool00ol0003o
ooooooooo`04ooooo`03oiRHV?lQ8B7ok^k^00oooooo00?oMgMgoc8b<_ooool04Oooool00ol0003o
ooooo`000008ooooo`03ogMgMolb<S;ooooo01?ooooo00?o0000ooooooooool01Oooool00olQ8B7o
ooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00?oMgMgoc8b<_ooool08oooool0027ooooo
00?o0000ooooooooool07Oooool00omgMgOo0000ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<
c<`06_ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool05_ooool00omE
EEGoc<c<ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00_ooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Eooooo`;o00001ooo
ool00omgMgOoIVIVooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`04oooool2o`0000Gooooo
00Go0000ob4Q8Ol0003o<S8bolc<c00Dooooo`03o`000?oooooooooo00Gooooo00?oEEEEolc<c?oo
ool02Oooool01ol0003oooooo`000?lQ8B7o0000oc8b<_o<c<`09?ooool0027ooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0Fooooo`03ojVYZOmgMgOooooo00_ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00;ooooo00Go410@oooo
oooooooooooooa0@400Eooooo`;o00002?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo01Gooooo0_l00005ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01Oooool0
0onYZJWoMgMgooooo`09ooooo`03o`000?oooooo000002Sooooo000Qooooo`03o`000?oooooooooo
01[ooooo00Ko0000okZj^_ooooooV9RHoa0@4?l0000;ooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Dooooo`05oa0@4?oooooooooooooooolb<S80
3?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01Gooooo0_l00004ooooo`05o`000?nj^[[ooooooiRH
V?l@41003?ooool00ol0003oooooooooo`0Eooooo`;o00001Oooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooc8b<P0:ooooo`03o`000?oooooo
000002Sooooo000Qooooo`03o`000?oooooooooo01[ooooo00KoV9RHoa0@4?l0003o8B4Qolc<c?l0
000;ooooo`Co00006oooool4o`0000Cooooo00?o0000ooooooooool05?ooool5o`0000cooooo1?l0
0004ooooo`03o`000?oooooooooo013ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^01Cooooo00?oEEEEo`000?l000001?ooool01OnHV9So410@o`000?lQ8B7oc<c<00co
oooo1?l0000Cooooo`03oeEEEOl0003o000000Gooooo1?l0000Cooooo`03oeEEEOmVIVKo000000Co
oooo1Ol0000:ooooo`03o`000?oooooo000000?o00009Oooool0027ooooo00?o0000ooooooooool0
7oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0
<Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
:?ooool0027ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0`ooooo`03o`000?oo
oooooooo02gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0]ooooo`03o`000?oo
oooooooo033ooooo00?o0000ooooooooool0:Oooool0027ooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0<?ooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool07oooool2
o`0000;ooooo0_l00004ooooo`008Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
033ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo
02kooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Oooooo`06onk^k_lQ8B7oQhN7
okZj^_l0003ogMgM1?ooool001[oooooool0000jo`0000cooooo00CogMgMo`000?l@413oc<c<1Ooo
ool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooo000000Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`05o`00
0?ooooooooooooooool000000oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01?ooool2o`0000Oooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0?ooooo`04onk^k_lQ8B7o410@onk^kPGooooo000Qooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooo`000005ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000?ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo0_l0
0007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03oooool01?lQ8B7oMgMgogMg
Molb<S85ooooo`008Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02kooooo00?o
0000ooooooooool0;oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo033ooooo00?o
0000ooooooooool0;Oooool00ol0003oooooooooo`0Pooooo`;o00000_ooool2o`0000Cooooo000Q
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0_
ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0]
ooooo`03o`000?oooooooooo02[ooooo000Qooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool0;Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02gooooo00?o0000oooo
ooooool0<?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02[ooooo000Qooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0aooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0]ooooo`03
o`000?oooooooooo02[ooooo000Qooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
;?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02[ooooo000Qooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo02gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo02_ooooo000Qooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0;?ooool0
0ol0003oooooooooo`0aooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0<_ooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo02_ooooo000Qooooo`?o00008Oooool00ol0
003oooooooooo`0/ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0:oooool00ol0
003oooooooooo`0booooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0:oooool0027o
oooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03?o
oooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo02_o
oooo00?o0000ooooooooool0:oooool0027ooooo00?o0000ooooooooool08_ooool00ol0003ooooo
ooooo`0Zooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0:oooool00ol0003ooooo
ooooo`0booooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0:oooool0027ooooo00?o
0000ooooooooool08_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03?ooooo00?o
0000ooooooooool0:oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo02_ooooo00?o
0000ooooooooool0:oooool0027ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Z
ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0c
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0;?ooool0027ooooo00?o0000oooo
ooooool08_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03?ooooo00?o0000oooo
ooooool0:_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool0;?ooool0027ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Zooooo`03
o`000?oooooooooo03Cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0dooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool0;?ooool0027ooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0
;?ooool0027ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo03Gooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0dooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool0;?ooool0027ooooo0ol0000Sooooo`03o`000?oooooo
oooo02Sooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooo
oooo03Gooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0/ooooo`008Oooool00ol0
003oooooooooo`0Sooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0=Oooool00ol0
003oooooooooo`0Xooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`0]ooooo`008Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02So
oooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0]ooooo`008Oooool00ol0003ooooo
ooooo`0Sooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0=oooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`0]ooooo`008Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool0=oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo03Kooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`0]ooooo`008Oooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0]
ooooo`008Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool0=oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo03Oooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0^ooooo`008Oooool00ol0003oooooooooo`0Tooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo03Sooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0^ooooo`00
8Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
>?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0^ooooo`008Oooool3o`0002Gooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02kooooo000Qooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo
oooo02kooooo000Qooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`0iooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>Oooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo02kooooo000Qooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02oo
oooo000Qooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`0jooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0>_ooool00ol0003ooooo
ooooo`0Sooooo`03o`000?oooooooooo02oooooo000Qooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool08_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool0>_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02oooooo000Q
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0R
ooooo`03o`000?oooooooooo02oooooo000Qooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool08_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02?ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo02oooooo000Qooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Rooooo`03
o`000?oooooooooo02oooooo000Qooooo`?o00009_ooool00ol0003oooooooooo`0Rooooo`03o`00
0?oooooooooo03cooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool0<?ooool0027ooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`0looooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0<?oo
ool0027ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo03gooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool0<?ooool0027ooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool08Oooool00ol0
003oooooooooo`0mooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0<?ooool0027o
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03go
oooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo023o
oooo00?o0000ooooooooool0<?ooool0027ooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool08?ooool00ol0003ooooo
ooooo`0mooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0<Oooool0027ooooo00?o
0000ooooooooool0:?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03kooooo00?o
0000ooooooooool07oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool0<Oooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Ooo
ool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0:?ooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`0oooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0<Oooool000Oooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`00
0?oooooooooo02Sooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0oooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo037ooooo0007ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooo
ooooo`02ooooo`?o0000:?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo03oooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool0<Oooool000Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMg
Molb<S;ooooo00?ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo043ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0oooooo`03o`00
0?oooooooooo01kooooo00?o0000ooooooooool0<Oooool000Oooooo00Go0000oooooooooooooooo
o`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0booooo`00
1oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0Yooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0@?ooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0booooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool0@Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo047ooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`0booooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00co
oooo1?l00005ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`11ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0@Oooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo03;ooooo000Qooooo`03o`000?oooooooooo02Wooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo03;ooooo
000Qooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`12ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0@Oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo03?ooooo000Qooooo`03o`000?oooooooooo02[ooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool0@oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo03?ooooo000Qoooo
o`03o`000?oooooooooo02[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`13oooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo03?ooooo000Qooooo`?o0000:_ooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo04?ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`13ooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool0<oooool0027ooooo00?o0000ooooooooool0
:_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
=?ooool0027ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo04Cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`14ooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool0=?ooool0027ooooo00?o0000ooooooooool0:oooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0=?ooool0
027ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
04Gooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool0=?ooool0027ooooo00?o0000ooooooooool0:oooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`16ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0=?ooool0027ooooo
00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04Kooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool0=Oooool0027ooooo00?o0000ooooooooool0;?ooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`16ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0=Oooool0027ooooo00?o0000
ooooooooool0;?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Oooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool0=Oooool0027ooooo0ol0000/ooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool0Aoooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Sooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`0eooooo`008Oooool00ol0003oooooooooo`0/ooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo04Sooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0fooooo`00
8Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
B?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0fooooo`008Oooool00ol0003oooooooooo`0]ooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo04Wooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0fooooo`008Oooool0
0ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0BOooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`0fooooo`008Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
04[ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0gooooo`008Oooool00ol0003o
ooooooooo`0^ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0B_ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0gooooo`008Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo04cooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0gooooo`008Oooool00ol0003ooooooooo
o`0^ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0B_ooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0gooooo`008Oooool3o`0002kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1<
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo03Sooooo000Qooooo`03o`000?oooooooooo02oooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool0C?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo03Sooooo000Qooooo`03
o`000?oooooooooo02oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1<ooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo03Sooooo000Qooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
C_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03Wooooo000Qooooo`03o`000?oo
oooooooo033ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1>ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo03Wooooo000Qooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Coooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03Wooooo000Qooooo`03o`000?oooooooooo
033ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
03[ooooo000Qooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`1@ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0D?ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo03[ooooo000Qooooo`03o`000?oooooooooo037ooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool0DOooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03[ooooo
000Qooooo`?o0000<_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05;ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0>oooool0027ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1B
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0>oooool0027ooooo00?o0000oooo
ooooool0<_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05?ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool0>oooool0027ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo05Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Dooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool0??ooool0027ooooo00?o0000ooooooooool0
=?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
?Oooool0027ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo05Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Fooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0?Oooool0027ooooo00?o0000ooooooooool0=?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`1Gooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0?_ooool0
01Sooooo1?l000000ol@413oooooooooo`02ooooo`03o`000?oooooooooo03Gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0F?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03kooooo000Jooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo05[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Jooooo`;o
00001?ooool00ol0003oooooooooo`0oooooo`006_ooool00ol0003oooooooooo`04ooooo`?o0000
=oooool5o`0005kooooo1Ol0001Nooooo`Go0000@_ooool001[ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGo
oooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool0oooooom5ooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00WOooool2o`0003gooooo0_l0002:ooooo`00WOooool00ol0003oooooooooo`0moooo
o`03o`000?oooooooooo08Sooooo002:ooooo`?o00000_ooool01_lb<S;o410@ooooooooooook^k^
oeEEE@;o000000?oA4A4okZj^_ooool00oooool00ol0003oooooooooo`02ooooo`06onk^k_mVIVKo
0000o`000?lb<S;o^[Zj=Oooool00ol0003oooooooooo`28ooooo`00Roooool01Ol0003ooooooooo
ooo<c<co410@00?ooooo00KoEEEEogMgMoooooook^k^ogMgMol@4104ooooo`03o`000?oooooooooo
00;ooooo0_mgMgL01?mEEEGoQhN7omgMgOm4A4@eooooo`03o`000?oooooooooo08Sooooo002;oooo
o`05o`000?oooooooooooeEEEOn7QhL00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00;ooooo00?oV9RHooooool00000>?ooool00ol0003oooooooooo`28ooooo`00Roooool01Ol0
003oooooomgMgOl0003ok^k^00?ooooo1_l00004ooooo`03o`000?oooooooooo00;ooooo00?oV9RH
ooooool000000ol0000Booooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`28ooooo`00Roooool3o`000003oa0@4?nHV9Sooooo00;ooooo00KoEEEEohN7
Qoo^k^koooooohN7Qolb<S84ooooo`03o`000?oooooooooo00;ooooo00?oMgMgohN7QomVIVH00_nj
^[X00olb<S;oooooooooo`0?ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`28ooooo`00Roooool01Ol0003oooooooooooo<c<co000000?ooooo00Ko
k^k^oeEEEOl0003o0000odA4A?o^k^h4ooooo`03o`000?oooooooooo00?ooooo00KoIVIVo`000?l0
003oA4A4onk^k_ooool3o`0000Cooooo0_l000000ooooooo0000o`000003ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooool000000oooool01?l0003oooooooooooooool3o`0000Kooooo0_l0
0004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0R?ooool008_ooooo00Go0000
ooooooooooooc<c<o`00000=ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooo`000004ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`28ooooo`00R_ooool4o`000003oa0@4?nYZJWooooo00cooooo0_l0
000;ooooo`03o`000?oooooooooo00Cooooo0_l00005ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01_l00002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`02ooooo`;o0000R_ooool00:[ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooo`000004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000000oooool0
1?l0003oooooooooooooool3o`0000Cooooo1?l00004ooooo`03o`000?oooooooooo08kooooo002Y
ooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo08oooooo002`oooo
o`;o00002?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo093ooooo002Zooooo`03
o`000?oooooooooo0;_ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-2, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0505254 0.309017 0.294302 [
[.15012 .29652 -9 -9 ]
[.15012 .29652 9 0 ]
[.27644 .29652 -3 -9 ]
[.27644 .29652 3 0 ]
[.40275 .29652 -9 -9 ]
[.40275 .29652 9 0 ]
[.52906 .29652 -6 -9 ]
[.52906 .29652 6 0 ]
[.65538 .29652 -12 -9 ]
[.65538 .29652 12 0 ]
[.78169 .29652 -6 -9 ]
[.78169 .29652 6 0 ]
[.908 .29652 -12 -9 ]
[.908 .29652 12 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .01472 -12 -4.5 ]
[.01131 .01472 0 4.5 ]
[.01131 .16187 -24 -4.5 ]
[.01131 .16187 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[.5 .63053 -37 0 ]
[.5 .63053 37 12.625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15012 .30902 m
.15012 .31527 L
s
[(2.5)] .15012 .29652 0 1 Mshowa
.27644 .30902 m
.27644 .31527 L
s
[(5)] .27644 .29652 0 1 Mshowa
.40275 .30902 m
.40275 .31527 L
s
[(7.5)] .40275 .29652 0 1 Mshowa
.52906 .30902 m
.52906 .31527 L
s
[(10)] .52906 .29652 0 1 Mshowa
.65538 .30902 m
.65538 .31527 L
s
[(12.5)] .65538 .29652 0 1 Mshowa
.78169 .30902 m
.78169 .31527 L
s
[(15)] .78169 .29652 0 1 Mshowa
.908 .30902 m
.908 .31527 L
s
[(17.5)] .908 .29652 0 1 Mshowa
.125 Mabswid
.04907 .30902 m
.04907 .31277 L
s
.07433 .30902 m
.07433 .31277 L
s
.0996 .30902 m
.0996 .31277 L
s
.12486 .30902 m
.12486 .31277 L
s
.17539 .30902 m
.17539 .31277 L
s
.20065 .30902 m
.20065 .31277 L
s
.22591 .30902 m
.22591 .31277 L
s
.25117 .30902 m
.25117 .31277 L
s
.3017 .30902 m
.3017 .31277 L
s
.32696 .30902 m
.32696 .31277 L
s
.35222 .30902 m
.35222 .31277 L
s
.37749 .30902 m
.37749 .31277 L
s
.42801 .30902 m
.42801 .31277 L
s
.45328 .30902 m
.45328 .31277 L
s
.47854 .30902 m
.47854 .31277 L
s
.5038 .30902 m
.5038 .31277 L
s
.55433 .30902 m
.55433 .31277 L
s
.57959 .30902 m
.57959 .31277 L
s
.60485 .30902 m
.60485 .31277 L
s
.63011 .30902 m
.63011 .31277 L
s
.68064 .30902 m
.68064 .31277 L
s
.7059 .30902 m
.7059 .31277 L
s
.73116 .30902 m
.73116 .31277 L
s
.75643 .30902 m
.75643 .31277 L
s
.80695 .30902 m
.80695 .31277 L
s
.83222 .30902 m
.83222 .31277 L
s
.85748 .30902 m
.85748 .31277 L
s
.88274 .30902 m
.88274 .31277 L
s
.93327 .30902 m
.93327 .31277 L
s
.95853 .30902 m
.95853 .31277 L
s
.98379 .30902 m
.98379 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01472 m
.03006 .01472 L
s
[(-1)] .01131 .01472 1 0 Mshowa
.02381 .16187 m
.03006 .16187 L
s
[(-0.5)] .01131 .16187 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(0.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .13244 m
.02756 .13244 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -98 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.625 moveto
(@) show
81.000 13.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\343) show
87.000 9.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344) show
93.000 9.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
97.188 9.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
( ) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
99.000 9.625 moveto
(H) show
103.188 9.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
107.375 9.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
111.562 9.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
117.562 9.625 moveto
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
121.750 9.625 moveto
(L) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
127.000 13.625 moveto
(D) show
133.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .01472 m
.02499 .01479 L
.02605 .01501 L
.02729 .01541 L
.02846 .01596 L
.03053 .01732 L
.03279 .01935 L
.03527 .02225 L
.0379 .02608 L
.04262 .03487 L
.05205 .05951 L
.06244 .09665 L
.0842 .20107 L
.10458 .3172 L
.12312 .42219 L
.14335 .51915 L
.15431 .55857 L
.15965 .57362 L
.16449 .58473 L
.16689 .58932 L
.16949 .59356 L
.17174 .59662 L
.17421 .59933 L
.17684 .60145 L
.17827 .60227 L
.17896 .60258 L
.17961 .60282 L
.18086 .60316 L
.18201 .6033 L
.18324 .60329 L
.18393 .60321 L
.18458 .60308 L
.18575 .60272 L
.18699 .60218 L
.18805 .60157 L
.18921 .60076 L
.1918 .59839 L
.1942 .59551 L
.19857 .58863 L
.20324 .57896 L
.21403 .54797 L
.22384 .51034 L
.26382 .29784 L
.28214 .19427 L
.29255 .14125 L
.30229 .09804 L
.31268 .0606 L
.32217 .0355 L
.32466 .03048 L
.32737 .02578 L
Mistroke
.32996 .02205 L
.33231 .01933 L
.33505 .01694 L
.33655 .016 L
.33724 .01565 L
.33797 .01534 L
.33928 .01494 L
.34049 .01475 L
.34179 .01473 L
.34252 .01481 L
.34321 .01493 L
.34448 .01531 L
.34512 .01557 L
.34582 .01591 L
.34823 .0175 L
.34959 .01869 L
.35105 .02021 L
.35369 .02356 L
.35886 .03238 L
.3636 .043 L
.37265 .06969 L
.38217 .10599 L
.42033 .30725 L
.44162 .42778 L
.46094 .51968 L
.47061 .55491 L
.47569 .56991 L
.48107 .5829 L
.48578 .59173 L
.48827 .59542 L
.49095 .59861 L
.49221 .59983 L
.4934 .60082 L
.49457 .60162 L
.49565 .60223 L
.49667 .60268 L
.49775 .60303 L
.49884 .60324 L
.50004 .60332 L
.50125 .60323 L
.50238 .60299 L
.50362 .60256 L
.50432 .60225 L
.50495 .60191 L
.50761 .59999 L
.51012 .59744 L
.51455 .59119 L
.51936 .58197 L
.52463 .56904 L
.53021 .55227 L
Mistroke
.54021 .51493 L
.57807 .31658 L
.59912 .19685 L
.61837 .1037 L
.62789 .06787 L
.63291 .05231 L
.63827 .03852 L
.64341 .02814 L
.64807 .02124 L
.65032 .01878 L
.65151 .01772 L
.65276 .01677 L
.65385 .01609 L
.65505 .01549 L
.65615 .0151 L
.65717 .01486 L
.65843 .01472 L
.65907 .01472 L
.65977 .01478 L
.66101 .01502 L
.66218 .0154 L
.66285 .01569 L
.66355 .01605 L
.6648 .01684 L
.66763 .01927 L
.67008 .02211 L
.67236 .02536 L
.67753 .03486 L
.68651 .05809 L
.6961 .09159 L
.71746 .19211 L
.73761 .30621 L
.75594 .41084 L
.76636 .4652 L
.7761 .51009 L
.7865 .54976 L
.79599 .57714 L
.8012 .58821 L
.80614 .59596 L
.80885 .59905 L
.81135 .60117 L
.8128 .60207 L
.81411 .60267 L
.81483 .60292 L
.81562 .60312 L
.81636 .60325 L
.81704 .60331 L
.81831 .60328 L
.81951 .60308 L
.82059 .60276 L
Mistroke
.82176 .60226 L
.82303 .60153 L
.82438 .60056 L
.82681 .5983 L
.83114 .5926 L
.83591 .58391 L
.84106 .5718 L
.84659 .55574 L
.8566 .51935 L
.87772 .41766 L
.89781 .30329 L
.91783 .19016 L
.93599 .10306 L
.94601 .06569 L
.95544 .03918 L
.96063 .02856 L
.96541 .02139 L
.96791 .01866 L
.96934 .01741 L
.97065 .01648 L
.97203 .01571 L
.97274 .0154 L
.97352 .01513 L
.97423 .01494 L
.97489 .01481 L
.97619 .01472 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool001So
oooo1?l000000ol@413oooooooooo`02ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000?ooooo`Ko00001Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000
ooooooooool01?ooool4o`0005kooooo1Ol0001Nooooo`Go0000G_ooool3o`0001cooooo000Joooo
o`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo0000GOooool00ol0003oooooooooo`02
ooooo`;o0000G?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05_ooooo00?o0000
ooooooooool07Oooool001[ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo
000005_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`0Nooooo`006_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Eoooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1Hooooo`03o`000?oooooooooo01kooooo000Hooooo`03oeEEEOmVIVKo000000Ko
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05Oo
oooo00?o0000ooooooooool07oooool0027ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`1Eooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0E_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool07oooool0027ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool0EOooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo05Cooooo00?o
0000ooooooooool08?ooool0027ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1E
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool08Oooool0027ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool0Doooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05?ooooo00?o0000oooo
ooooool08Oooool0027ooooo0ol00004ooooo`03o`000?oooooooooo05?ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool0DOooool00ol0003oooooooooo`0Rooooo`008Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo05?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Aooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`0Rooooo`008Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0DOoo
ool00ol0003oooooooooo`0Rooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo057ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0Sooooo`008Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`1?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0Coooool00ol0
003oooooooooo`0Sooooo`008Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04oo
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0Sooooo`008Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`1?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0C_ooool00ol0003ooooo
ooooo`0Tooooo`008Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04kooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool0COooool00ol0003oooooooooo`0Tooooo`008Oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1=
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0T
ooooo`008Oooool3o`0000Oooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo04gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1=oooo
o`03o`000?oooooooooo02Cooooo000Qooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0C?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04cooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo02Gooooo000Qooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo04_ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1;ooooo`03o`00
0?oooooooooo02Gooooo000Qooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0Booo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo02Gooooo000Qooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo04[ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1:ooooo`03o`000?oooooo
oooo02Kooooo000Qooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0B_ooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`19ooooo`03o`000?oooooooooo02Kooooo000Qooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04Wo
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo02Ko
oooo000Qooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0B?ooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`19ooooo`03o`000?oooooooooo02Kooooo000Qooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool0B?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04Sooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo02Oooooo000Q
ooooo`?o00002Oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool0Aoooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Oooooo00?o0000
ooooooooool09oooool0027ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`17oooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo04Oooooo00?o0000ooooooooool09oooool0027ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool0Aoooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Oooooo00?o0000oooooooo
ool09oooool0027ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`16ooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo04Oooooo00?o0000ooooooooool09oooool0027ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0A_oo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0:?oo
ool0027ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`16ooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo04Gooooo00?o0000ooooooooool0:?ooool0027ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`14ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0AOooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0:?ooool0027o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04Go
oooo00?o0000ooooooooool0:?ooool0027ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`14ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0A?ooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0:?ooool0027ooooo0ol0
000;ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`14ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0@oooool00ol0003ooooooooo
o`0Yooooo`008Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo04Cooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool0@oooool00ol0003oooooooooo`0Yooooo`008Oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo04;ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`13oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Yoooo
o`008Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo04;ooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool0@oooool00ol0003oooooooooo`0Yooooo`008Oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo04;ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`12ooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0Yooooo`008Ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0@Ooo
ool00ol0003oooooooooo`0Zooooo`008Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo047ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0Zooooo`001oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0@Ooo
ool00ol0003oooooooooo`0Zooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`10ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0@Oooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0:_ooool000Go00000_ooool0
1Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`10ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0@?ooool00ol0003ooooooooo
o`0Zooooo`001oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00ooo
ool3o`0000gooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo043ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`10ooooo`03o`000?oo
oooooooo02[ooooo0007ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`00
0?lb<S;oc<c<00Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0oooooo`03o`00
0?oooooooooo01kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo03oooooo00?o0000ooooooooool0:oooool000Oooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0nooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0?oooool00ol0003ooooo
ooooo`0Nooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0:oooool000Oooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0
?oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0
:oooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`0nooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0?_ooool00ol0003ooooo
ooooo`0[ooooo`008Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03kooooo00?o
0000ooooooooool07oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool0?_ooool00ol0003oooooooooo`0[ooooo`008Oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0n
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0/
ooooo`008Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03gooooo00?o0000oooo
ooooool08?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool0?Oooool00ol0003oooooooooo`0/ooooo`008Oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo03cooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0mooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0/ooooo`00
8Oooool3o`0000oooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo03cooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0looooo`03o`00
0?oooooooooo02cooooo000Qooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0??oo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool08_oo
ool00ol0003oooooooooo`0looooo`03o`000?oooooooooo02cooooo000Qooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo03cooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0looooo`03o`000?oooooo
oooo02cooooo000Qooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`0Rooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool08_ooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo02gooooo000Qooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo02go
oooo000Qooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0>_ooool00ol0003ooooo
ooooo`0Sooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`0jooooo`03o`000?oooooooooo02gooooo000Qooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool0>_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03[ooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo02gooooo000Q
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0S
ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0j
ooooo`03o`000?oooooooooo02gooooo000Qooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool0>Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo03Wooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02kooooo000Qooooo`?o
00004Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool0>Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo03Wooooo00?o0000oooooooo
ool0;_ooool0027ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0hooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo03Sooooo00?o0000ooooooooool0;_ooool0027ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0;_oo
ool0027ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo03Sooooo00?o0000ooooooooool0;_ooool0027ooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0gooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0;oooool0027o
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo03Oo
oooo00?o0000ooooooooool0;oooool0027ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0fooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0=oooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0;oooool0027ooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool0=_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo03Kooooo00?o
0000ooooooooool0;oooool0027ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0e
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0;oooool0027ooooo0ol0000Coooo
o`03o`000?oooooooooo03Gooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0foooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0`oooo
o`008Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo03Gooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02Sooooo00?o0000oooooooo
ool0=Oooool00ol0003oooooooooo`0`ooooo`008Oooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo03Gooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0eooooo`03o`00
0?oooooooooo02Sooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0`ooooo`008Ooo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0=Ooo
ool00ol0003oooooooooo`0`ooooo`008Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo03?ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooo
oooo02[ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0`ooooo`008Oooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`0dooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0<oooool00ol0
003oooooooooo`0aooooo`008Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00?o
oooo1Ol00005ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01[ooooo0ol000000olb
<S;ogMgMooooo`0Kooooo`03o`000?o^k^kooooo00Gooooo0_lQ8B42ooooo`04o`000?oooooooooo
odA4A0;o000000?o<S8bomgMgOooool05Oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000
oc8b<_o^k^h<ooooo`03o`000?oooooooooo00Gooooo1?l000000ol@413oooooooooo`05o`0000Go
oooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd02?ooool00ol0003oooooooooo`07oooo
o`Co000000Go410@ooooooooooooooooodA4A002o`000003oc8b<_oMgMgooooo017ooooo1?l00000
0ol@413oooooooooo`02ooooo`05o`000?o^k^koooooooooool000000oooool2ob4Q8@Gooooo00Go
A4A4o`000?l0003o<S8bomgMg@0Tooooo`008Oooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo00?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`;o8B4Q2?ooool00omgMgOo<S8b
ooooo`0Iooooo`05o`000?ooooooooooogMgMolb<S807?ooool00omEEEGoZJVYooooo`05ooooo`;o
8B4Q0_ooool00ol0003oooooooooo`03ooooo`03ogMgMolb<S;ooooo01Oooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`02ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool01oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Kooooo00?oMgMg
oc8b<_ooool04oooool00ol0003oooooooooo`04ooooo`05oeEEEOnYZJWoooooooooool000000ooo
ool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool08oooool0027ooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`04ooooo`03oiRHV?lQ8B7ok^k^017ooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo01[ooooo00?oZJVYoeEEEOooool02Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@00_ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`03ooooo`03oiRHV?lQ8B7ok^k^017ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`04ooooo`05ojVYZOmEEEGoooooooooool000003_ooool00ol0003oooooooooo`0Rooooo`008Ooo
ool3o`0001Gooooo00?o0000ooooooooool01?ooool00onHV9So8B4Qonk^kP0?ooooo`03ogMgMolb
<S;ooooo01Sooooo00Ko0000ooooooooooooooooogMgMolb<S8Mooooo`03ob4Q8Ooooooooooo00So
oooo00?o0000ooooooooool00oooool00omgMgOo<S8booooo`0Gooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`00000;ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool01?ooool00onHV9So8B4Qonk^kP0?ooooo`03ogMgMolb<S;ooooo00Oooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo01?ooooo00?o0000oooo
ooooool01Oooool01?lQ8B7oooooooooool0000=ooooo`03ogMgMolb<S;ooooo02?ooooo000Qoooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01Oooool00omgMgOoIVIVooooo`0;oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`06Oooool2o`000004ob4Q8Ol0003o<S8bolc<c1gooooo00?o
EEEEolc<c?ooool02?ooool02?l0003oooooooooool0003o8B4Qo`000?lb<S;oc<c<6?ooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Gooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`03ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`05?ooool00ol0003oooooooooo`05ooooo`03oeEEEOo<c<co000000_ooooo
00Go0000ob4Q8Ol0003o<S8bolc<c00Tooooo`008Oooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Kooooo`;o0000
8Oooool00onYZJWoMgMgooooo`09ooooo`03o`000?oooooo000001cooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@00_ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`05ooooo`03ojVYZOmgMgOo000000_ooooo00?o0000ooooooooool09_ooool0027ooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`02ooooo`05o`000?nj^[[ooooooiRHV?l@
41003?ooool00ol0003oooooooooo`0Kooooo`;o00007_ooool01Ol@413ooooooooooooooooo<S8b
00[ooooo00?o0000ooooool000007?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00Go0000
okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool00_oo
ool01_l@413ooooooooooooooooo<S8bo`0000_ooooo00?o0000ooooooooool09_ooool0027ooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`02ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`03?ooool4o`0001Wooooo00?o0000ooooool000000ol0000Kooooo`Go00002_ooool00ol0003o
ooooo`000003o`0001Oooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00_ooooo00?o0000ooooooooool01_ooool00omEEEGoIVIVo`000004ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`03?ooool4o`0000[ooooo00?o0000ooooooooool01_ooool00omEEEGoIVIVo`000005
ooooo`Co00004oooool00omEEEGoIVIVo`000004ooooo`Ko00002oooool4o`0002Gooooo000Qoooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0]oooo
o`03o`000?oooooooooo033ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0aoooo
o`03o`000?oooooooooo03;ooooo000Qooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool0;oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo033ooooo00?o0000oooooooo
ool0;Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo03?ooooo000Qooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0^ooooo`03o`00
0?oooooooooo02oooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0_ooooo`03o`00
0?oooooooooo02Wooooo0_l00002ooooo`;o00001?ooool0027ooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0;ooo
ool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0:Ooo
ool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@Cooooo000Joooooooo0000>_l0000<ooooo`04omgM
gOl0003o410@olc<c0Gooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo0_l00007oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooo`000005oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo
000000;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool03oooool01?o^k^ko8B4Qoa0@4?o^k^h5ooooo`008Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooo`000005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool0
1?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`04ooooo`;o00001oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00oo
oooo00Co8B4QogMgMomgMgOo<S8b1Oooool0027ooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`0]ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0;_ooool00ol0003o
ooooooooo`0_ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0:_ooool2o`0000;o
oooo0_l00004ooooo`008Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02gooooo
00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0dooooo`008Oooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0<?ooool00ol0003ooooooooo
o`0]ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0;Oooool00ol0003ooooooooo
o`0dooooo`008Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02cooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo033ooooo00?o0000
ooooooooool0;Oooool00ol0003oooooooooo`0dooooo`008Oooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0/oooo
o`03o`000?oooooooooo037ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0doooo
o`008Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02_ooooo00?o0000oooooooo
ool0<Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo037ooooo00?o0000oooooooo
ool0;Oooool00ol0003oooooooooo`0dooooo`008Oooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo02_ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0[ooooo`03o`00
0?oooooooooo03;ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0eooooo`008Ooo
ool3o`0001Sooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0booooo`03o`000?oo
oooooooo02_ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo03Gooooo000Qooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0:oooool0
0ol0003oooooooooo`0booooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0<_ooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo03Gooooo000Qooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo
02[ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
03Gooooo000Qooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0:_ooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0<oooool00ol0003o
ooooooooo`0[ooooo`03o`000?oooooooooo03Gooooo000Qooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02[ooooo
00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03Gooooo
000Qooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo03Kooooo000Qooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool0:Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool0=?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo03Kooooo000Qoooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0eoooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Yoooo
o`03o`000?oooooooooo03Kooooo000Qooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02Sooooo00?o0000oooooooo
ool0=Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo03Kooooo000Qooooo`?o0000
6Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0
:?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0
=_ooool0027ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0fooooo`03o`000?oo
oooooooo02Oooooo00?o0000ooooooooool0=oooool0027ooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool09oooool0
0ol0003oooooooooo`0fooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0=oooool0
027ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
03Kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool0=oooool0027ooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool09oooool00ol0003o
ooooooooo`0fooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0=oooool0027ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo03Oooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool0=oooool0027ooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0hooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0=oooool0027ooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo03Sooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0>?ooool0027ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo03Sooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hoooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?ooool0027ooooo0ol0000Kooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo03Sooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hooooo`00
8Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
>Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0hooooo`008Oooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo03[ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0hooooo`008Oooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`0hooooo`008Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
03[ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0iooooo`008Oooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0>_ooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`0iooooo`008Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03[ooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`0iooooo`008Oooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool08oooool00ol0003ooooooooo
o`0iooooo`008Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02;ooooo00?o0000
ooooooooool0??ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03cooooo00?o0000
ooooooooool08_ooool00ol0003oooooooooo`0iooooo`008Oooool3o`0001cooooo00?o0000oooo
ooooool08_ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool0??ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03[ooooo000Qooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0looooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo03[ooooo000Qooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
8?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
??ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03[ooooo000Qooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0mooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo03[ooooo000Qooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`0nooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0?_ooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03[ooooo000Qooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
03_ooooo000Qooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`0nooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0?_ooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo03_ooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
03_ooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool00oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool0?oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03kooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`0kooooo`001oooool01Ol@413ooooooooooooooooo410@
013ooooo00?o0000ooooooooool00_ooool3o`0001kooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`10ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0?oooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo03cooooo0007ooooo`05o`000?oooooooooooooo
ool000003oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool0@?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo03cooooo0007ooooo`05
o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo043ooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool0??ooool000Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo043ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`10ooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool0??ooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`10
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0??ooool000Oooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo043ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0mooooo`008Oooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0@_ooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`0mooooo`008Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo04;o
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0mooooo`008Oooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0@_ooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`0mooooo`008Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool0@oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04;ooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`0mooooo`008Oooool3o`00027ooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool0@_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo03kooooo000Qoooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`14oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo03kooooo000Qooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool0A?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo03kooooo000Qooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`14ooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo03kooooo000Qooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0A?oo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo03oooooo000Qooooo`03o`000?oooooo
oooo02;ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`16ooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo03oooooo000Qooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`16ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0AOooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo03oooooo000Qooooo`03o`000?oooooooooo02;o
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo03oo
oooo000Qooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`16ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0A_ooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo03oooooo000Qooooo`?o00008oooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`16ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0@?ooool0027ooooo00?o0000
ooooooooool08oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04Sooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool0@?ooool0027ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo04Sooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`17oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0@?ooool0027ooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04Sooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0@?ooool0027ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo04Wooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`19ooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool0@Oooool0027ooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0@Ooo
ool0027ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo04[ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1:ooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool0@Oooool0027ooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`1;ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0@Oooool0027o
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo04_o
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool0@_ooool0027ooooo0ol0000Uooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo04_ooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`12ooooo`008Oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0C?ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`12ooooo`008Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool0COooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04gooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`12ooooo`008Oooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo04gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`13oooo
o`008Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0C_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04kooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`13ooooo`008Oooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo04oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`13ooooo`008Ooo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0D?oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`13ooooo`008Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo053ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`14ooooo`008Oooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0DOooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`14ooooo`008Oooool3o`0002Sooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`1Aooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0DOooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo04Cooooo000Qooooo`03o`000?oooooooooo02Sooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0D_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo04Cooooo
000Qooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`1Cooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0D_ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo04Gooooo000Qooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0E?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo04Kooooo000Qoooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Eoooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo04Kooooo000Qooooo`03o`000?oooooooooo02[ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0E_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04Oooooo000Qooooo`03o`00
0?oooooooooo02_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Gooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo04Sooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003ooooooooo
o`0/ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0F?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`18ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`1Jooooo`;o00000oooool2o`0005gooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`19ooooo`006_ooool00ol0003oooooooooo`04oooo
o`?o0000;Oooool5o`0005kooooo1Ol0001Nooooo`Go0000C?ooool001[ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3o
ooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool0oooooom5oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00WOooool2o`0003gooooo0_l0002:ooooo`00WOooool00ol0003ooooooooo
o`0mooooo`03o`000?oooooooooo08Sooooo002:ooooo`?o00000_ooool01_lb<S;o410@oooooooo
ooook^k^oeEEE@;o000000?oA4A4okZj^_ooool00oooool00ol0003oooooooooo`02ooooo`06onk^
k_mVIVKo0000o`000?lb<S;o^[Zj=Oooool00ol0003oooooooooo`28ooooo`00Roooool01Ol0003o
ooooooooooo<c<co410@00?ooooo00KoEEEEogMgMoooooook^k^ogMgMol@4104ooooo`03o`000?oo
oooooooo00;ooooo0_mgMgL01?mEEEGoQhN7omgMgOm4A4@eooooo`03o`000?oooooooooo08Sooooo
002;ooooo`05o`000?oooooooooooeEEEOn7QhL00oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00;ooooo00?oV9RHooooool00000>?ooool00ol0003oooooooooo`28ooooo`00Rooo
ool01Ol0003oooooomgMgOl0003ok^k^00?ooooo1_l00004ooooo`03o`000?oooooooooo00;ooooo
00?oV9RHooooool000000ol0000Booooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`28ooooo`00Roooool3o`000003oa0@4?nHV9Sooooo00;ooooo00Ko
EEEEohN7Qoo^k^koooooohN7Qolb<S84ooooo`03o`000?oooooooooo00;ooooo00?oMgMgohN7QomV
IVH00_nj^[X00olb<S;oooooooooo`0?ooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`28ooooo`00Roooool01Ol0003oooooooooooo<c<co000000?o
oooo00Kok^k^oeEEEOl0003o0000odA4A?o^k^h4ooooo`03o`000?oooooooooo00?ooooo00KoIVIV
o`000?l0003oA4A4onk^k_ooool3o`0000Cooooo0_l000000ooooooo0000o`000003ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooool000000oooool01?l0003oooooooooooooool3o`0000Ko
oooo0_l00004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0R?ooool008_ooooo
00Go0000ooooooooooooc<c<o`00000=ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`28ooooo`00R_ooool4o`000003oa0@4?nYZJWooooo00co
oooo0_l0000;ooooo`03o`000?oooooooooo00Cooooo0_l00005ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01_l00002ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`02ooooo`;o0000R_ooool00:[ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool00000
0oooool01?l0003oooooooooooooool3o`0000Cooooo1?l00004ooooo`03o`000?oooooooooo08ko
oooo002Yooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo08oooooo
002`ooooo`;o00002?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo093ooooo002Z
ooooo`03o`000?oooooooooo0;_ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-2, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0505254 0.309017 0.294302 [
[.15012 .29652 -9 -9 ]
[.15012 .29652 9 0 ]
[.27644 .29652 -3 -9 ]
[.27644 .29652 3 0 ]
[.40275 .29652 -9 -9 ]
[.40275 .29652 9 0 ]
[.52906 .29652 -6 -9 ]
[.52906 .29652 6 0 ]
[.65538 .29652 -12 -9 ]
[.65538 .29652 12 0 ]
[.78169 .29652 -6 -9 ]
[.78169 .29652 6 0 ]
[.908 .29652 -12 -9 ]
[.908 .29652 12 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .01471 -12 -4.5 ]
[.01131 .01471 0 4.5 ]
[.01131 .16187 -24 -4.5 ]
[.01131 .16187 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[.5 .63053 -37 0 ]
[.5 .63053 37 12.625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15012 .30902 m
.15012 .31527 L
s
[(2.5)] .15012 .29652 0 1 Mshowa
.27644 .30902 m
.27644 .31527 L
s
[(5)] .27644 .29652 0 1 Mshowa
.40275 .30902 m
.40275 .31527 L
s
[(7.5)] .40275 .29652 0 1 Mshowa
.52906 .30902 m
.52906 .31527 L
s
[(10)] .52906 .29652 0 1 Mshowa
.65538 .30902 m
.65538 .31527 L
s
[(12.5)] .65538 .29652 0 1 Mshowa
.78169 .30902 m
.78169 .31527 L
s
[(15)] .78169 .29652 0 1 Mshowa
.908 .30902 m
.908 .31527 L
s
[(17.5)] .908 .29652 0 1 Mshowa
.125 Mabswid
.04907 .30902 m
.04907 .31277 L
s
.07433 .30902 m
.07433 .31277 L
s
.0996 .30902 m
.0996 .31277 L
s
.12486 .30902 m
.12486 .31277 L
s
.17539 .30902 m
.17539 .31277 L
s
.20065 .30902 m
.20065 .31277 L
s
.22591 .30902 m
.22591 .31277 L
s
.25117 .30902 m
.25117 .31277 L
s
.3017 .30902 m
.3017 .31277 L
s
.32696 .30902 m
.32696 .31277 L
s
.35222 .30902 m
.35222 .31277 L
s
.37749 .30902 m
.37749 .31277 L
s
.42801 .30902 m
.42801 .31277 L
s
.45328 .30902 m
.45328 .31277 L
s
.47854 .30902 m
.47854 .31277 L
s
.5038 .30902 m
.5038 .31277 L
s
.55433 .30902 m
.55433 .31277 L
s
.57959 .30902 m
.57959 .31277 L
s
.60485 .30902 m
.60485 .31277 L
s
.63011 .30902 m
.63011 .31277 L
s
.68064 .30902 m
.68064 .31277 L
s
.7059 .30902 m
.7059 .31277 L
s
.73116 .30902 m
.73116 .31277 L
s
.75643 .30902 m
.75643 .31277 L
s
.80695 .30902 m
.80695 .31277 L
s
.83222 .30902 m
.83222 .31277 L
s
.85748 .30902 m
.85748 .31277 L
s
.88274 .30902 m
.88274 .31277 L
s
.93327 .30902 m
.93327 .31277 L
s
.95853 .30902 m
.95853 .31277 L
s
.98379 .30902 m
.98379 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01471 m
.03006 .01471 L
s
[(-1)] .01131 .01471 1 0 Mshowa
.02381 .16187 m
.03006 .16187 L
s
[(-0.5)] .01131 .16187 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(0.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .13244 m
.02756 .13244 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -98 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.625 moveto
(@) show
81.000 13.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\343) show
87.000 9.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344) show
93.000 9.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
97.188 9.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
( ) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
99.000 9.625 moveto
(H) show
103.188 9.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
107.375 9.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
111.562 9.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
117.562 9.625 moveto
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
121.750 9.625 moveto
(L) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
127.000 13.625 moveto
(D) show
133.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .07092 m
.06244 .25696 L
.08255 .3733 L
.10458 .48856 L
.11448 .53052 L
.11992 .55007 L
.12507 .56598 L
.12986 .57841 L
.13506 .58916 L
.13735 .59297 L
.13979 .59636 L
.14187 .59875 L
.14415 .60078 L
.14546 .60168 L
.14667 .60234 L
.14783 .60281 L
.14907 .60315 L
.15028 .6033 L
.15142 .6033 L
.15245 .60316 L
.15356 .60288 L
.15479 .6024 L
.15613 .60168 L
.15753 .60071 L
.15884 .5996 L
.16133 .59695 L
.16369 .59379 L
.16831 .58582 L
.17252 .57653 L
.18199 .54899 L
.19164 .51227 L
.2019 .46519 L
.22032 .36598 L
.25807 .1546 L
.26749 .11081 L
.27741 .07217 L
.28261 .05549 L
.28829 .04031 L
.29346 .02946 L
.29827 .02198 L
.3009 .01899 L
.30332 .01693 L
.30459 .01612 L
.30598 .01544 L
.30668 .01518 L
.30743 .01497 L
.30814 .01482 L
.30879 .01475 L
.31006 .01473 L
.31123 .01488 L
Mistroke
.31252 .01523 L
.31324 .01551 L
.31389 .01581 L
.31509 .0165 L
.31638 .01742 L
.31873 .01958 L
.32098 .02224 L
.32344 .02581 L
.32841 .03505 L
.33732 .05813 L
.34755 .09419 L
.35686 .13472 L
.37779 .2449 L
.39853 .36483 L
.41769 .46784 L
.43631 .54644 L
.44571 .57451 L
.45106 .58644 L
.45366 .59112 L
.45607 .59481 L
.45854 .5979 L
.46078 .60011 L
.46198 .60105 L
.46327 .60189 L
.46398 .60227 L
.46464 .60257 L
.46593 .60301 L
.46717 .60325 L
.46833 .60332 L
.4696 .60321 L
.47032 .60307 L
.47097 .6029 L
.47228 .60239 L
.4737 .60161 L
.47505 .60066 L
.47629 .5996 L
.48056 .59464 L
.48299 .5909 L
.48527 .58679 L
.49481 .56359 L
.50463 .5303 L
.51497 .48624 L
.53347 .39038 L
.57154 .17482 L
.59113 .08576 L
.59677 .06579 L
.6021 .0497 L
.60684 .03779 L
.61207 .02744 L
.61449 .02367 L
Mistroke
.61708 .02035 L
.61953 .01791 L
.62178 .01628 L
.62308 .01559 L
.6243 .01513 L
.625 .01494 L
.62563 .01482 L
.62636 .01474 L
.62705 .01472 L
.6283 .01482 L
.62946 .01507 L
.63072 .01552 L
.63206 .0162 L
.63426 .01776 L
.63661 .02004 L
.64086 .02574 L
.6459 .03511 L
.6505 .04603 L
.66043 .07687 L
.6696 .11336 L
.69037 .21748 L
.71064 .33397 L
.72966 .44001 L
.74784 .52442 L
.75806 .56032 L
.76743 .58425 L
.77217 .59281 L
.77483 .59651 L
.77724 .59919 L
.77949 .60109 L
.78076 .60191 L
.78194 .6025 L
.78296 .60288 L
.78409 .60317 L
.78526 .60331 L
.78637 .60329 L
.78765 .6031 L
.78837 .60291 L
.78904 .60268 L
.79027 .60212 L
.79158 .60134 L
.79409 .59929 L
.79635 .59682 L
.80188 .58839 L
.80707 .57742 L
.81687 .54912 L
.8272 .50954 L
.84569 .41918 L
.88374 .20279 L
.89463 .14651 L
Mistroke
.90494 .10019 L
.91497 .06339 L
.91938 .0502 L
.92423 .03795 L
.9286 .02906 L
.9333 .02184 L
.9359 .01892 L
.93827 .01691 L
.93941 .01617 L
.94065 .01554 L
.94183 .01511 L
.94292 .01485 L
.9442 .01472 L
.94491 .01473 L
.94557 .01479 L
.94679 .01503 L
.94807 .01547 L
.94922 .01603 L
.9503 .01669 L
.95274 .01868 L
.95539 .02159 L
.9578 .02493 L
.96321 .03479 L
.96943 .04997 L
.97619 .07092 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool001So
oooo1?l000000ol@413oooooooooo`02ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000?ooooo`Ko00001Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000
ooooooooool01?ooool3o`0005Gooooo1Ol0001Nooooo`Co0000Goooool5o`0002Cooooo000Joooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo05_ooooo00?o0000ooooooooool00_ooool2o`0005cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Rooooo`006_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo05?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Iooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo027ooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
Doooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
8?ooool001Sooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`1Booooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo05Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Pooooo`008Oooool0
0ol0003oooooooooo`1Booooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0E_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0Oooooo`008Oooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
05Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Nooooo`008Oooool00ol0003o
ooooooooo`1Aooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Doooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0Nooooo`008Oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0Doooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05?ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Mooooo`008Oooool3o`00053ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0D_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01gooooo000Q
ooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1A
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo01gooooo000Qooooo`03o`000?oooooooooo04oooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool0DOooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01cooooo000Qooooo`03
o`000?oooooooooo04kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1@ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo01cooooo000Qooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
D?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01_ooooo000Qooooo`03o`000?oo
oooooooo04kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1?ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo01_ooooo000Qooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`1?ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0C_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01_ooooo000Qooooo`03o`000?oooooooooo
04gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
01[ooooo000Qooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`1=ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0C_ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo01[ooooo000Qooooo`?o0000COooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`1<ooooo`03o`000?oooooooooo02kooooo000Qooooo`03o`000?oooooooooo04gooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool0C?ooool00ol0003oooooooooo`0^ooooo`008Oooool2o`0004gooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool0C?ooool00ol0003oooooooooo`0^ooooo`008Oooool2o`0004gooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool0Boooool00ol0003oooooooooo`0_ooooo`008Oooool2o`0004gooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool0B_ooool00ol0003oooooooooo`0_ooooo`008Oooool2o`0004cooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
B_ooool00ol0003oooooooooo`0_ooooo`008Oooool2o`0004cooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0B_oo
ool00ol0003oooooooooo`0_ooooo`008Oooool00ol0003oooooo`00001;ooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo04Sooooo00?o0000ooooooooool0<?ooool0027ooooo00?o0000ooooool00000B_ooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`18ooooo`03o`000?oooooooooo033ooooo000Qooooo`?o0000B_ooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`18ooooo`03o`000?oooooooooo033ooooo000Qooooo`03o`000?oooooo000004[ooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0`ooooo`008Oooool00ol0003oooooo`00
0019ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0Aoooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0<Oooool0027ooooo00Co0000
oooooooooooo0000B?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Oooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo037ooooo000Q
ooooo`04o`000?ooooooooooo`0004Sooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`16ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0A_ooool00ol0003ooooooooo
o`0aooooo`008Oooool01?l0003oooooooooool00018ooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool0A_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Kooooo00?o
0000ooooooooool0<Oooool0027ooooo00Co0000oooooooooooo0000B?ooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`14ooooo`03o`000?oooooooooo03;ooooo000Qooooo`04o`000?ooooooooooo`0004Oooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool0A?ooool00ol0003oooooooooo`0booooo`008Oooool01Ol0003ooooooooooooo
oooo000004Kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`15ooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0booooo`008Oooool3
o`000003ooooool0003ooooo04Gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`14
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0c
ooooo`008Oooool01Ol0003ooooooooooooooooo000004Kooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`13ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0@oooool0
0ol0003oooooooooo`0cooooo`008Oooool01Ol0003ooooooooooooooooo000004Kooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool0@_ooool00ol0003oooooooooo`0cooooo`008Oooool01Ol0003ooooooooooooooooo
000004Kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`13ooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0cooooo`008Oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`12ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0@Oooool00ol0
003oooooooooo`0dooooo`008Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04;o
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0dooooo`008Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`11ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0@Oooool00ol0003ooooo
ooooo`0dooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4
A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04;o
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0dooooo`001oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool0@Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo043ooooo00?o0000oooooooo
ool0=?ooool000Go00000_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo047ooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool0?oooool00ol0003oooooooooo`0eooooo`001oooool01Ol0003ooooooooooooooooo000000oo
oooo00?oMgMgoc8b<_ooool00oooool3o`0000?ooooo00?o0000ooooooooool0@Oooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`0oooooo`03o`000?oooooooooo03Gooooo0007ooooo`05o`000?ooooooooooooooool0
00003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`10ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0?oooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0=Oooool000Oo
oooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool0?oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03kooooo00?o0000oooo
ooooool0=Oooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
03kooooo00?o0000ooooooooool0=Oooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<oooo
o`Co00001Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03oooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool0?Oooool00ol0003oooooooooo`0fooooo`008Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo03oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0mooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0fooooo`00
8Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool0
8?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
??ooool00ol0003oooooooooo`0fooooo`008Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo03kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0mooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0fooooo`008Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`0looooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0??ooool0
0ol0003oooooooooo`0fooooo`008Oooool3o`0000Gooooo00?o0000ooooooooool0?Oooool00ol0
003oooooooooo`0Qooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool08_ooool00ol0
003oooooooooo`0looooo`03o`000?oooooooooo03Kooooo000Qooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo03Oo
oooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0?Oooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool08oooool00ol0003ooooo
ooooo`0jooooo`03o`000?oooooooooo03Oooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0??ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03Oooooo000Q
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0R
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0j
ooooo`03o`000?oooooooooo03Oooooo000Qooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03Wooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03Oooooo000Qooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo03Wooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0jooooo`03
o`000?oooooooooo03Oooooo000Qooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo03Sooooo000Qooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo03Wooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hooooo`03o`000?oo
oooooooo03Sooooo000Qooooo`?o00001oooool00ol0003oooooooooo`0iooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo03Sooooo00?o0000ooooooooool0>?ooool0027ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0iooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0>?ooool0027o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo03So
oooo00?o0000ooooooooool0>?ooool0027ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0iooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0=oooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0>Oooool0027ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0=oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo03Kooooo00?o
0000ooooooooool0>Oooool0027ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0g
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0>Oooool0027ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02Oooooo00?o0000oooo
ooooool0=_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo03Kooooo00?o0000oooo
ooooool0>Oooool0027ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo03Kooooo00?o0000ooooooooool0>Oooool0027ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
=Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0
>Oooool0027ooooo0ol00008ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0=?oo
ool00ol0003oooooooooo`0jooooo`008Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo03Gooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooo
oooo02Wooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0jooooo`008Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`0dooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0=?ooool00ol0
003oooooooooo`0jooooo`008Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03Go
oooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0jooooo`008Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0:Oooool00ol0003ooooo
ooooo`0dooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0=?ooool00ol0003ooooo
ooooo`0jooooo`008Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03Gooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02[ooooo00?o
0000ooooooooool0=?ooool00ol0003oooooooooo`0jooooo`008Oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00gooooo1Ol00005ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb
<S;ogMgM017ooooo00?o0000ooooooooool01_ooool01Om4A4Co0000o`000?lb<S;ogMgM01cooooo
00?o0000onk^k_l000001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0Fooooo`Co
000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP;ooooo00?o0000ooooooooool03ooo
ool4o`000003oa0@4?oooooooooo00Go00001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8b
o`00000Booooo`Co000000Go410@ooooooooooooooooodA4A002o`000003oc8b<_oMgMgooooo017o
oooo1?l000000ol@413oooooooooo`02ooooo`03o`000?o^k^kooooo00Gooooo0_lQ8B45ooooo`05
odA4A?l0003o0000oc8b<_oMgMd09?ooool0027ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0=ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool03oooool00ol0003oooooooooo`0:ooooo`03ogMgMolb<S;ooooo01_ooooo00?oEEEEojVY
ZOl000001Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool05oooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL00_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo00;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`;o8B4Q2?ooool00omgMgOo0000oooo
o`0Cooooo`03o`000?oooooooooo00Kooooo00?oMgMgoc8b<_ooool04oooool2o`0000Gooooo00?o
EEEEojVYZOooool01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool08oooool0027ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0>ooooo`03oiRHV?lQ8B7ok^k^017ooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01[ooooo00CoZJVY
oeEEEOoooooo00003oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00;ooooo00Go
410@oooooooooooooooooa0@4002ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
0oooool00onHV9So8B4Qonk^kP0Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Booooo`;o00001Oooool00onYZJWoEEEEooooo`0@ooooo`03o`00
0?oooooooooo02;ooooo000Qooooo`?o00002_ooool00ol0003oooooooooo`0?ooooo`03oiRHV?lQ
8B7ok^k^00oooooo00?oMgMgoc8b<_ooool03oooool00ol0003oooooooooo`0:ooooo`03ogMgMolb
<S;ooooo01cooooo00?o8B4Qooooool000003_ooool00omgMgOo<S8booooo`0Gooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool01?ooool00onHV9So8B4Qonk^kP0?ooooo`03ogMgMol0003ooooo01?ooooo
00?o0000ooooooooool01_ooool00omgMgOo<S8booooo`0Cooooo`;o00001_ooool00olQ8B7ooooo
ooooo`0>ooooo`03ogMgMolb<S;ooooo02?ooooo000Qooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool04?ooool00omgMgOoIVIVooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
4?ooool00ol0003oooooooooo`07ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`07Oooool00omEEEGo
c<c<o`00000;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06?ooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo00Gooooo00?oMgMgofIVI_ooool02oooool01Ol0003o8B4Qo`000?lb<S;o000001Cooooo00?o
0000ooooooooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01Cooooo0_l00006ooooo`03oeEE
EOo<c<cooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Tooooo`008Oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07oooool00onYZJWoMgMg
o`00000;ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool00_ooool01ol@413ooooo
oooooooooooo410@ooooool000005?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00[ooooo00Go0000ooooooooooooooooo`00000Dooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`05ooooo`03ojVYZOmgMgOooooo00_ooooo00?o0000
ooooooooool09_ooool0027ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`05o`000?nj^[[ooooooiRHV?l@41003?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool07?ooool01_l@413ooooooooooooooooo<S8bo`0000_ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`02ooooo`07ogMgMonHV9SooooooiRHV?mg
MgOoooooo`00000Dooooo`03o`000?oooooooooo00;ooooo00Go0000okZj^_ooooooV9RHoa0@400<
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo<S8b00cooooo00?o0000ooooooooool09_ooool0027ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0<ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?ooool4o`00013ooooo00?o
0000ooooooooool02?ooool4o`0001_ooooo1_l0000;ooooo`Co00005oooool00omEEEGoIVIVo`00
0004ooooo`07onk^k_lb<S;o0000oc8b<_o^k^koooooo`00000Booooo`03oeEEEOmVIVKo000000Co
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c00<ooooo`Co000000?oooooo`000?ooool04?ooool00omE
EEGoIVIVo`000005ooooo`Co00004oooool00omEEEGoIVIVo`000004ooooo`Go00003?ooool4o`00
02Gooooo000Qooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0<Oooool00ol0003o
ooooooooo`0/ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0;Oooool00ol0003o
ooooooooo`0`ooooo`03o`000?oooooooooo03cooooo000Qooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo03cooooo
000Qooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0<?ooool00ol0003ooooooooo
o`0]ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0;Oooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo03;ooooo0_l00002ooooo`;o00001?ooool0027ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02gooooo00?o0000
ooooooooool0<?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02oooooo00?o0000
ooooooooool0<oooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@Cooooo000Joooooooo0000>_l0
000<ooooo`04omgMgOl0003o410@olc<c0Gooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01?ooool2o`0000Oooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`;o00001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Co
0000oooooooooooo00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool00oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0?ooooo`04onk^k_lQ8B7o410@onk^kPGooooo000Qooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01?ooool2o`0000Oooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`;o00001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0?ooooo`04ob4Q8OmgMgOoMgMgoc8b<PGooooo000Qooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02ko
oooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo03?o
oooo0_l00002ooooo`;o00001?ooool0027ooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0^ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`0_ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0?Oooool0027ooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo033ooooo00?o
0000ooooooooool0;_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02gooooo00?o
0000ooooooooool0?_ooool0027ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0]
ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0a
ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0?_ooool0027ooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo033ooooo00?o0000oooo
ooooool0;Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo02cooooo00?o0000oooo
ooooool0?_ooool0027ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0]ooooo`03
o`000?oooooooooo033ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0aooooo`03
o`000?oooooooooo02cooooo00?o0000ooooooooool0?_ooool0027ooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
;?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0
?_ooool0027ooooo0ol0000>ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0<Ooo
ool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0:ooo
ool00ol0003oooooooooo`0oooooo`008Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo02_ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooo
oooo037ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0oooooo`008Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0<_ooool00ol0
003oooooooooo`0[ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0:_ooool00ol0
003oooooooooo`0oooooo`008Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02_o
oooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo03?o
oooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0oooooo`008Oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0<_ooool00ol0003ooooo
ooooo`0[ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0:_ooool00ol0003ooooo
ooooo`0oooooo`008Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02[ooooo00?o
0000ooooooooool0<_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo03?ooooo00?o
0000ooooooooool0:_ooool00ol0003oooooooooo`0oooooo`008Oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Z
ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`10
ooooo`008Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool0=?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03Cooooo00?o0000oooo
ooooool0:?ooool00ol0003oooooooooo`10ooooo`008Oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo03Gooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`10ooooo`00
8Oooool3o`00013ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo02Wooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Xooooo`03o`00
0?oooooooooo043ooooo000Qooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0:?oo
ool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0=Ooo
ool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo043ooooo000Qooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooo
oooo02Wooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo043ooooo000Qooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`0fooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0=Oooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo047ooooo000Qooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo02So
oooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo047o
oooo000Qooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`0fooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0=oooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo047ooooo000Qooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool0=oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo047ooooo000Q
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0f
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo047ooooo000Qooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool0=oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo04;ooooo000Qooooo`?o
00004Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool0@_ooool0027ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo03Sooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0iooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool0@_ooool0027ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0@_oo
ool0027ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo
oooo03Sooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool0@_ooool0027ooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0Sooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`0iooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0@_ooool0027o
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03[o
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02?o
oooo00?o0000ooooooooool0@oooool0027ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Sooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool08oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0@oooool0027ooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03[ooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02;ooooo00?o
0000ooooooooool0@oooool0027ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0R
ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0@oooool0027ooooo0ol0000Coooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`13oooo
o`008Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool0??ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`14ooooo`008Oooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo03gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`14ooooo`008Ooo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0??oo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool08?oo
ool00ol0003oooooooooo`14ooooo`008Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo03gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`14ooooo`008Oooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0?Oooool00ol0
003oooooooooo`0Qooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`14ooooo`008Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03go
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`15ooooo`001oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0?_ooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`15ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo03kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0ooooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool0AOooool000Oooooo00Go410@oooooooo
oooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo0ol0000Eooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
03oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`15ooooo`001oooool01Ol0003o
oooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo03oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`15oooo
o`001oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c004
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`10
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo04Kooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`10ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0@?ooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo04Kooooo0007ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool0@Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo04Kooooo0007oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`11ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0A_ooool0
027ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
047ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool0Aoooool0027ooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`11ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0Aoooool0027ooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo04;ooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool0Aoooool0027ooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`13ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0Aoooool0027ooooo0ol0000G
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`17
ooooo`008Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool0A?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04?ooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`18ooooo`008Oooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo04?ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`18ooooo`00
8Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
A?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`18ooooo`008Oooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo04Cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`18ooooo`008Oooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0AOooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`18ooooo`008Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
04Gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`19ooooo`008Oooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0A_ooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`19ooooo`008Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Kooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`19ooooo`008Oooool3o`0001Wooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool0A_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Wooooo000Q
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`17
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo04[ooooo000Qooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool0Aoooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04[ooooo000Qooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`18ooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo04[ooooo000Qooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
B?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04[ooooo000Qooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1:ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo04_ooooo000Qooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`1:ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0BOooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04_ooooo000Qooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
04_ooooo000Qooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`1:ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0Boooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo04_ooooo000Qooooo`?o00006oooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`1;ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0C?ooool0027ooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04cooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool0C?ooool0027ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1=
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0C?ooool0027ooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04kooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0COooool0027ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo04kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1>ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0COooool0027ooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
COooool0027ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo053ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1@ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool0C_ooool0027ooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`1Aooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0C_ooool0
027ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
053ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool0C_ooool0027ooooo0ol0000Nooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05?o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1?ooooo`008Oooool00ol0003ooooo
ooooo`0Nooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0D_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`1?ooooo`008Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool0Doooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo05Cooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`1?ooooo`008Oooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1@
ooooo`008Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool0EOooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05Kooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`1@ooooo`008Oooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo05Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Aooooo`00
8Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
F?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`1Aooooo`006?ooool4o`000003oa0@4?oooooooooo00;ooooo00?o
0000ooooooooool08_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05Wooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0D_ooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0R
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0F_ooool2o`0000Cooooo00?o0000
ooooooooool0Foooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05?ooooo000Joooo
o`03o`000?oooooooooo00Cooooo0ol0000Sooooo`Go0000G_ooool5o`0005kooooo1Ol0001Foooo
o`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001Sooooo00?oEEEEofIVI_l000001_ooool00ol0
003oooooooooo`3oooooodGooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo002Mooooo`;o0000?Oooool2o`0008[ooooo
002Mooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0R?ooool008[ooooo0ol00002
ooooo`06oc8b<_l@413oooooooooooo^k^koEEEE0_l000000om4A4Co^[Zjooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00Kok^k^ofIVI_l0003o0000oc8b<_nj^[Xeooooo`03o`000?oooooooooo
08Sooooo002;ooooo`05o`000?ooooooooooolc<c?l@41000oooool01_mEEEGoMgMgooooooo^k^ko
MgMgoa0@40Cooooo00?o0000ooooooooool00_ooool2ogMgM`04oeEEEOn7QhOogMgModA4A3Gooooo
00?o0000ooooooooool0R?ooool008_ooooo00Go0000ooooooooooooEEEEohN7Q`03ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool00_ooool00onHV9Soooooo`00000hooooo`03o`00
0?oooooooooo08Sooooo002;ooooo`05o`000?oooooogMgMo`000?o^k^h00oooool6o`0000Cooooo
00?o0000ooooooooool00_ooool00onHV9Soooooo`000003o`0001;ooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo08Sooooo002;ooooo`?o000000?o
410@oiRHV?ooool00_ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<PCooooo00?o0000oooooooo
ool00_ooool00omgMgOoQhN7ofIVIP02okZj^P03oc8b<_oooooooooo00oooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo08Sooooo002;ooooo`05o`00
0?ooooooooooolc<c?l000000oooool01_o^k^koEEEEo`000?l0003oA4A4onk^kPCooooo00?o0000
ooooooooool00oooool01_mVIVKo0000o`000?m4A4Cok^k^ooooo`?o00001?ooool2o`000003oooo
ool0003o000000?ooooo00?o0000ooooooooool00oooool00ol0003oooooo`000003ooooo`04o`00
0?ooooooooooooooo`?o00001_ooool2o`0000Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`28ooooo`00Roooool01Ol0003oooooooooooo<c<co000000gooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo000000Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo08Sooooo002:ooooo`Co
000000?o410@ojVYZOooool03?ooool2o`0000_ooooo00?o0000ooooooooool01?ooool2o`0000Go
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06o`0000;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo0_l0002:ooooo`00
Z_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo000000Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooo`000003ooooo`04o`000?ooooooooooooooo`?o00001?ooool4o`0000Co
oooo00?o0000ooooooooool0S_ooool00:Wooooo0_l00006ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0Soooool00;3ooooo0_l00008ooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool0T?ooool00:[ooooo00?o0000ooooooooool0^oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-2, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0505254 0.309016 0.294305 [
[.15012 .29652 -9 -9 ]
[.15012 .29652 9 0 ]
[.27644 .29652 -3 -9 ]
[.27644 .29652 3 0 ]
[.40275 .29652 -9 -9 ]
[.40275 .29652 9 0 ]
[.52906 .29652 -6 -9 ]
[.52906 .29652 6 0 ]
[.65538 .29652 -12 -9 ]
[.65538 .29652 12 0 ]
[.78169 .29652 -6 -9 ]
[.78169 .29652 6 0 ]
[.908 .29652 -12 -9 ]
[.908 .29652 12 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .01471 -12 -4.5 ]
[.01131 .01471 0 4.5 ]
[.01131 .16186 -24 -4.5 ]
[.01131 .16186 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[.5 .63053 -37 0 ]
[.5 .63053 37 12.625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15012 .30902 m
.15012 .31527 L
s
[(2.5)] .15012 .29652 0 1 Mshowa
.27644 .30902 m
.27644 .31527 L
s
[(5)] .27644 .29652 0 1 Mshowa
.40275 .30902 m
.40275 .31527 L
s
[(7.5)] .40275 .29652 0 1 Mshowa
.52906 .30902 m
.52906 .31527 L
s
[(10)] .52906 .29652 0 1 Mshowa
.65538 .30902 m
.65538 .31527 L
s
[(12.5)] .65538 .29652 0 1 Mshowa
.78169 .30902 m
.78169 .31527 L
s
[(15)] .78169 .29652 0 1 Mshowa
.908 .30902 m
.908 .31527 L
s
[(17.5)] .908 .29652 0 1 Mshowa
.125 Mabswid
.04907 .30902 m
.04907 .31277 L
s
.07433 .30902 m
.07433 .31277 L
s
.0996 .30902 m
.0996 .31277 L
s
.12486 .30902 m
.12486 .31277 L
s
.17539 .30902 m
.17539 .31277 L
s
.20065 .30902 m
.20065 .31277 L
s
.22591 .30902 m
.22591 .31277 L
s
.25117 .30902 m
.25117 .31277 L
s
.3017 .30902 m
.3017 .31277 L
s
.32696 .30902 m
.32696 .31277 L
s
.35222 .30902 m
.35222 .31277 L
s
.37749 .30902 m
.37749 .31277 L
s
.42801 .30902 m
.42801 .31277 L
s
.45328 .30902 m
.45328 .31277 L
s
.47854 .30902 m
.47854 .31277 L
s
.5038 .30902 m
.5038 .31277 L
s
.55433 .30902 m
.55433 .31277 L
s
.57959 .30902 m
.57959 .31277 L
s
.60485 .30902 m
.60485 .31277 L
s
.63011 .30902 m
.63011 .31277 L
s
.68064 .30902 m
.68064 .31277 L
s
.7059 .30902 m
.7059 .31277 L
s
.73116 .30902 m
.73116 .31277 L
s
.75643 .30902 m
.75643 .31277 L
s
.80695 .30902 m
.80695 .31277 L
s
.83222 .30902 m
.83222 .31277 L
s
.85748 .30902 m
.85748 .31277 L
s
.88274 .30902 m
.88274 .31277 L
s
.93327 .30902 m
.93327 .31277 L
s
.95853 .30902 m
.95853 .31277 L
s
.98379 .30902 m
.98379 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01471 m
.03006 .01471 L
s
[(-1)] .01131 .01471 1 0 Mshowa
.02381 .16186 m
.03006 .16186 L
s
[(-0.5)] .01131 .16186 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(0.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04414 m
.02756 .04414 L
s
.02381 .07357 m
.02756 .07357 L
s
.02381 .103 m
.02756 .103 L
s
.02381 .13243 m
.02756 .13243 L
s
.02381 .19129 m
.02756 .19129 L
s
.02381 .22072 m
.02756 .22072 L
s
.02381 .25015 m
.02756 .25015 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -98 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.625 moveto
(@) show
81.000 13.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\343) show
87.000 9.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344) show
93.000 9.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
97.188 9.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
( ) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
99.000 9.625 moveto
(H) show
103.188 9.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
107.375 9.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
111.562 9.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
117.562 9.625 moveto
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
121.750 9.625 moveto
(L) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
127.000 13.625 moveto
(D) show
133.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .21807 m
.04262 .3261 L
.06244 .43716 L
.08255 .52983 L
.08806 .54969 L
.09396 .56777 L
.09948 .58153 L
.10458 .59134 L
.10714 .59519 L
.10954 .59812 L
.11204 .6005 L
.11337 .60146 L
.1148 .60228 L
.11548 .60259 L
.11622 .60286 L
.11702 .60308 L
.11776 .60323 L
.11853 .60331 L
.11924 .60332 L
.11989 .60328 L
.12059 .60318 L
.12123 .60305 L
.12193 .60284 L
.12335 .60226 L
.12466 .60151 L
.12589 .60063 L
.1285 .59819 L
.13097 .59517 L
.13561 .58766 L
.1406 .57696 L
.14603 .56236 L
.15542 .53028 L
.1658 .48606 L
.18681 .37602 L
.20778 .25476 L
.22701 .15119 L
.24586 .07152 L
.25533 .04328 L
.2607 .03136 L
.2657 .02308 L
.26833 .01985 L
.27075 .01756 L
.27201 .01662 L
.27341 .01581 L
.27411 .01549 L
.27486 .0152 L
.27557 .01499 L
.27622 .01485 L
.27749 .01472 L
.27866 .01476 L
Mistroke
.27995 .01498 L
.28067 .01519 L
.28132 .01543 L
.28252 .016 L
.28381 .01681 L
.28616 .01875 L
.2884 .0212 L
.29087 .02453 L
.29584 .03332 L
.30474 .05564 L
.31497 .09093 L
.32429 .13086 L
.34522 .24021 L
.36596 .3601 L
.38512 .46376 L
.40374 .54357 L
.41314 .5724 L
.41849 .5848 L
.42108 .58971 L
.4235 .59362 L
.42597 .59694 L
.42821 .59936 L
.4307 .60138 L
.43207 .60219 L
.43336 .60275 L
.43462 .60311 L
.43525 .60323 L
.43595 .6033 L
.43718 .6033 L
.43833 .60313 L
.43903 .60295 L
.43969 .60274 L
.44093 .60219 L
.44227 .60141 L
.44372 .60033 L
.44594 .59821 L
.44838 .59523 L
.45334 .58715 L
.45793 .57727 L
.46224 .56598 L
.47205 .53344 L
.4824 .49006 L
.50089 .395 L
.53897 .17912 L
.55856 .08892 L
.5642 .06853 L
.56952 .05201 L
.57427 .03969 L
.5795 .02888 L
.58191 .02489 L
Mistroke
.58451 .02132 L
.58696 .01865 L
.5892 .01681 L
.59051 .016 L
.59173 .01542 L
.59242 .01517 L
.59306 .01498 L
.59379 .01483 L
.59448 .01474 L
.59573 .01472 L
.59688 .01487 L
.59815 .0152 L
.59879 .01544 L
.59949 .01575 L
.6019 .01726 L
.60409 .01922 L
.60663 .02216 L
.60903 .02561 L
.61329 .03331 L
.61793 .0439 L
.62734 .07215 L
.63772 .11276 L
.65873 .2181 L
.67972 .33879 L
.69896 .44545 L
.71782 .53115 L
.7273 .56327 L
.73263 .57747 L
.73767 .58813 L
.7426 .5959 L
.74538 .59908 L
.74671 .60029 L
.74795 .60124 L
.74908 .60194 L
.75011 .60246 L
.75126 .6029 L
.75249 .60319 L
.75367 .60332 L
.75495 .60327 L
.75617 .60304 L
.75729 .60269 L
.75861 .60208 L
.76004 .6012 L
.76262 .59902 L
.76513 .59616 L
.76744 .59292 L
.7727 .58332 L
.77825 .56999 L
.78776 .53992 L
.79794 .49873 L
Mistroke
.81629 .40642 L
.83615 .29259 L
.85772 .1724 L
.86779 .12349 L
.87848 .07968 L
.88759 .0503 L
.89278 .03729 L
.89764 .02768 L
.90004 .0239 L
.9026 .02057 L
.90407 .01899 L
.90541 .01777 L
.90676 .01674 L
.90801 .01597 L
.9092 .01542 L
.91045 .015 L
.91171 .01477 L
.91243 .01472 L
.91309 .01472 L
.9143 .01486 L
.9154 .01513 L
.91667 .01562 L
.91788 .01626 L
.92011 .01787 L
.92248 .02021 L
.92675 .02602 L
.93134 .03451 L
.9364 .0465 L
.94639 .07774 L
.95555 .11434 L
.97619 .21807 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool001So
oooo1?l000000ol@413oooooooooo`02ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000?ooooo`Ko00001Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000
ooooooooool01?ooool3o`0004_ooooo1Ol0001Nooooo`Go0000G_ooool5o`0002kooooo000Joooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo05_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Joooo
o`;o00000oooool2o`0002gooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0BOooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05Wooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0:oooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`19ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo05Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Zooooo`006?oo
ool00omEEEGoIVIVo`000006ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Eooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02[ooooo000Qooooo`03o`000?oooooo
oooo04Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Fooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo02Wooooo000Qooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`1Eooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0EOooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo02Sooooo000Qooooo`03o`000?oooooooooo04Oo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02So
oooo000Qooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`1Cooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0E?ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo02Sooooo000Qooooo`?o0000A_ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`1Booooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool09oooool0027ooooo00?o0000
ooooooooool0A_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo057ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool09oooool0027ooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo057ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1@oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool09oooool0027ooooo00?o0000oooooooo
ool0AOooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo053ooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool09_ooool0027ooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo04oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1?ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool09_ooool0027ooooo00?o0000ooooooooool0A?oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool09_oo
ool0027ooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo04kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool09Oooool0027ooooo00?o0000ooooooooool0A?ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`1=ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool09Oooool0027o
oooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04go
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool09Oooool0027ooooo0ol00013ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04cooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Tooooo`008Oooool00ol0003ooooooooo
o`13ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0Boooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0Tooooo`008Oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool0Boooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo04_ooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0Tooooo`008Oooool00ol0003oooooooooo`12oooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo04[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Toooo
o`008Oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool0BOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04[ooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0Sooooo`008Oooool00ol0003oooooooooo`12ooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo04Wooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Sooooo`008Ooo
ool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0BOoo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`0Sooooo`008Oooool00ol0003oooooooooo`11ooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo04Sooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Sooooo`008Oooool00ol0
003oooooooooo`11ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0Aoooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`0Rooooo`008Oooool3o`00047ooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`17ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0B?ooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo02;ooooo000Qooooo`03o`000?oooooooooo043ooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02;ooooo
000Qooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`17ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0A_ooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo02;ooooo000Qooooo`03o`000?oooooooooo043ooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool0A_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo027ooooo000Qoooo
o`03o`000?oooooooooo043ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`15oooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo027ooooo000Qooooo`03o`000?oooooooooo043ooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool0A_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo027ooooo000Qooooo`03o`00
0?oooooooooo03oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`15ooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo027ooooo000Qooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0A?oo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo023ooooo000Qooooo`03o`000?oooooo
oooo03oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`14ooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo023ooooo000Qooooo`?o0000?oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
04?ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool08?ooool0027ooooo00?o0000ooooooooool0?_ooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`13ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool08?ooool0027ooooo
00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04?ooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool08?ooool0027ooooo00?o0000ooooooooool0?_ooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`12ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07oooool0027ooooo00?o0000
ooooooooool0?_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo047ooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool07oooool0027ooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo047ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`12oooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07oooool0027ooooo00?o0000oooooooo
ool0?Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo047ooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool07oooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo047ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`10oooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool07_ooool000Oooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo
03gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
01kooooo0005o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
03oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool07_ooool000Oooooo00Go0000ooooooooooooooooo`00000?oooo
o`03ogMgMolb<S;ooooo00?ooooo0ol0000looooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool0?oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo043ooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`0Nooooo`001oooool01Ol0003ooooooooooooooooo0000
00cooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo03cooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool0?_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01kooooo0007oooo
o`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo03cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo01gooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0n
ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo01gooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0000Gooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo03gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool07Oooool0027ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`0nooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool07Oooool0027o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03go
oooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool07Oooool0027ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool08Oooool00ol0003ooooo
ooooo`0looooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool07?ooool0027ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03cooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo027ooooo00?o
0000ooooooooool07?ooool0027ooooo0ol0000kooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03cooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`0Looooo`008Oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Roooo
o`03o`000?oooooooooo03cooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Loooo
o`008Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo02;ooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool08_ooool00ol0003oooooooooo`0Kooooo`008Oooool00ol0003oooooooooo`0jooooo`03o`00
0?oooooooooo02;ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Sooooo`03o`00
0?oooooooooo03[ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Kooooo`008Ooo
ool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0>_oo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`0Kooooo`008Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooo
oooo02?ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo
oooo03[ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Kooooo`008Oooool00ol0
003oooooooooo`0jooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0>Oooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool08oooool00ol0
003oooooooooo`0Kooooo`008Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Wo
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Jooooo`008Oooool00ol0003ooooo
ooooo`0iooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0>Oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`0Jooooo`008Oooool3o`0003Wooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0hooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?ooool00ol0003ooooooooo
o`12ooooo`008Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0>?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo00?o0000
ooooooooool0@_ooool0027ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo03Oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0hoooo
o`03o`000?oooooooooo04;ooooo000Qooooo`;o0000>_ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo03Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo04;ooooo000Qooooo`;o0000>Oooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo03Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0fooooo`03o`00
0?oooooooooo04?ooooo000Qooooo`;o0000>Oooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0fooooo`03o`000?oo
oooooooo04?ooooo000Qooooo`;o0000>Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo03Kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0fooooo`03o`000?oooooo
oooo04?ooooo000Qooooo`;o0000>Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
03Kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo
04?ooooo000Qooooo`03o`000?oooooo000003Sooooo00?o0000ooooooooool09oooool00ol0003o
ooooooooo`0eooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0=_ooool00ol0003o
ooooooooo`13ooooo`008Oooool3o`0003Oooooo00?o0000ooooooooool0:?ooool00ol0003ooooo
ooooo`0eooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0=Oooool00ol0003ooooo
ooooo`13ooooo`008Oooool00ol0003oooooo`00000gooooo`03o`000?oooooooooo02Wooooo00?o
0000ooooooooool0=?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo03Cooooo00?o
0000ooooooooool0A?ooool0027ooooo00?o0000ooooool00000=oooool00ol0003oooooooooo`0Y
ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0d
ooooo`03o`000?oooooooooo04Cooooo000Qooooo`03o`000?oooooo000003Oooooo00?o0000oooo
ooooool0:Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool0=?ooool00ol0003oooooooooo`14ooooo`008Oooool00ol0003oooooo`00000gooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Zooooo`03
o`000?oooooooooo03Cooooo00?o0000ooooooooool0A?ooool0027ooooo00Co0000oooooooooooo
0000=_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo03?ooooo00?o0000oooooooo
ool0:_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo04Cooooo000Qooooo`04o`00
0?ooooooooooo`0001Wooooo1Ol00005ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM
00Kooooo00?o0000ooooooooool04Oooool01Om4A4Co0000o`000?lb<S;ogMgM01Cooooo00?o0000
ooooooooool01Oooool00ol0003ok^k^ooooo`05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb
<S;ogMgM01Kooooo1Ol00002ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h05?ooool4o`000003oa0@
4?oooooooooo00Go00001Oooool00ol0003o8B4Qooooo`04ooooo`05odA4A?l0003o0000oc8b<_oM
gMd04_ooool4o`000005oa0@4?oooooooooooooooom4A4@00_l000000olb<S;ogMgMooooo`0:oooo
o`03o`000?oooooooooo00Cooooo1?l000000ol@413oooooooooo`02ooooo`03o`000?o^k^kooooo
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd09?ooool0027ooooo00Co0000oooo
oooooooo00006Oooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo0_lQ8B48ooooo`03ogMgMolb
<S;ooooo00Gooooo00?o0000ooooooooool05?ooool00omgMgOo<S8booooo`0Dooooo`03o`000?oo
oooooooo00Cooooo00?oEEEEojVYZOooool01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool05ooo
ool00ol0003oooooo`000002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL05_ooool00ol0003ooooo
ooooo`02ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool00olQ8B7o0000ooooo`07ooooo`03
ogMgMolb<S;ooooo01?ooooo00?o0000ooooooooool01_ooool00omgMgOo<S8booooo`0:ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool00omEEEGoZJVYooooo`05ooooo`;o
8B4Q2?ooool00omgMgOo<S8booooo`0Sooooo`008Oooool01?l0003oooooooooool0000Jooooo`03
oiRHV?lQ8B7ok^k^017ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool01?ooool00onYZJWoEEEEooooo`0@ooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooool000000_ooool01Ol@413ooooooooooooooooo410@
01Kooooo00?o0000ooooooooool00oooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03ojVYZOmEEEGooooo
013ooooo00?o0000ooooooooool08_ooool0027ooooo1?l0000Kooooo`03oiRHV?lQ8B7ok^k^00oo
oooo00?oMgMgoc8b<_ooool01Oooool00ol0003oooooooooo`0Dooooo`03ogMgMolb<S;ooooo01Co
oooo00?o0000ooooooooool01Oooool00olQ8B7oooooooooo`0>ooooo`03ogMgMolb<S;ooooo01Oo
oooo00?o0000ooooool000000_ooool01Ol0003ooooooooooooooooo000001Kooooo00?o0000oooo
ooooool01?ooool00onHV9So8B4Qonk^kP06ooooo`03o`000?oooooooooo00Kooooo00?oMgMgoc8b
<_ooool04oooool00ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo00[ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`03ob4Q8Ooooooooooo00kooooo00?oMgMgoc8b
<_ooool08oooool0027ooooo00Co0000oooooooooooo00007?ooool00omgMgOoIVIVooooo`0;oooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`01_ooool00ol0003oooooooooo`0Aooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`05Oooool00ol0003oooooooooo`05ooooo`03oeEEEOo<c<cooooo00_ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c00Hooooo`;o00000oooool01Ol0003ooooooooooooooooo000001Ko
oooo00?o0000ooooooooool01Oooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo00?o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c00Dooooo`03o`000?oooooooooo00?ooooo00Go0000ob4Q
8Ol0003o<S8bolc<c00;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool0
0omEEEGoc<c<ooooo`0;ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`09?ooool0027ooooo00Go0000
ooooooooooooooooo`00000Looooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01Ooo
ool00onYZJWoMgMgooooo`0;ooooo`03o`000?oooooooooo01[ooooo0_l00003ooooo`05oa0@4?oo
ooooooooooooool@41005_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo
00?oZJVYogMgMoooool02oooool00ol0003oooooooooo`0Vooooo`008Oooool01Ol0003ooooooooo
oooooooo000001Sooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00;o
oooo00Go410@oooooooooooooooooc8b<P0<ooooo`03o`000?oooooooooo01[ooooo0_l00003oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL05_ooool00ol0003oooooooooo`02ooooo`05o`000?nj^[[o
oooooiRHV?l@41001_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo<S8b00cooooo00?o0000ooooooooool0
9_ooool0027ooooo00Go0000ooooooooooooooooo`00000Hooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`03?ooool4o`0000Kooooo00?o0000ooooooooool04_ooool4o`0001Oooooo00Co0000oooooooo
oooooooo1Ol0000<ooooo`Co00005oooool01?mEEEGoIVIVo`000?l00003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h05?ooool00omEEEGoIVIVo`000004ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
1oooool00ol0003oooooooooo`02ooooo`Co00004oooool00omEEEGoIVIVo`000005ooooo`Co0000
2oooool00ol0003oooooooooo`05ooooo`03oeEEEOmVIVKo000000Cooooo1Ol0000<ooooo`Co0000
9Oooool0027ooooo00Go0000ooooooooooooooooo`00000cooooo`03o`000?oooooooooo02gooooo
00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool0A_ooool0027ooooo00Go0000ooooooooooooooooo`00000cooooo`03o`00
0?oooooooooo02gooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0^ooooo`03o`00
0?oooooooooo033ooooo00?o0000ooooooooool0A_ooool0027ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0;ooo
ool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0??oo
ool2o`0000;ooooo0_l00004ooooo`008Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo02oooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0mooooo`06onk^k_lQ8B7o
QhN7okZj^_l0003ogMgM1?ooool001[oooooool0000jo`0000cooooo00CogMgMo`000?l@413oc<c<
1Oooool0027ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00007ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01?ooool2o`0000Oooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`;o00001oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03oooool01?o^k^ko
8B4Qoa0@4?o^k^h5ooooo`008Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
00Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`;o00001oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000001Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03
ooooo`;o00001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool03oooool01?lQ8B7oMgMgogMgMolb<S85ooooo`008Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0]
ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0m
ooooo`;o00000_ooool2o`0000Cooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0;Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02gooooo00?o0000oooo
ooooool0<?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo04Oooooo000Qooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0`ooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0]ooooo`03
o`000?oooooooooo04Sooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo04Sooooo000Qooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0`ooooo`03o`000?oo
oooooooo02gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0]ooooo`03o`000?oo
oooooooo04Sooooo000Qooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`0aooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0<_ooool0
0ol0003oooooooooo`0/ooooo`03o`000?oooooooooo04Sooooo000Qooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo
02_ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo
04Sooooo000Qooooo`?o00001?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo03;o
oooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo02co
oooo00?o0000ooooooooool0B?ooool0027ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0[ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0:oooool00ol0003ooooo
ooooo`0booooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0BOooool0027ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo03;ooooo00?o
0000ooooooooool0:oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo02_ooooo00?o
0000ooooooooool0BOooool0027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0[
ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0b
ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0BOooool0027ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03Cooooo00?o0000oooo
ooooool0:Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02[ooooo00?o0000oooo
ooooool0BOooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo03Cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0dooooo`03
o`000?oooooooooo02[ooooo00?o0000ooooooooool0BOooool0027ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0
BOooool0027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Yooooo`03o`000?oo
oooooooo03Cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0dooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool0B_ooool0027ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0:Oooool0
0ol0003oooooooooo`0dooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0B_ooool0
027ooooo0ol00005ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0=Oooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0:?ooool00ol0
003oooooooooo`1:ooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02So
oooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`1:ooooo`008Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0=_ooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0:?ooool00ol0003ooooo
ooooo`1:ooooo`008Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool0=_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo03Kooooo00?o
0000ooooooooool0:?ooool00ol0003oooooooooo`1:ooooo`008Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1;
ooooo`008Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Oooooo00?o0000oooo
ooooool0=_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo03Kooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`1;ooooo`008Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo03Sooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1;ooooo`00
8Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
>?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`1;ooooo`008Oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo03Sooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1;ooooo`008Oooool3
o`0000Oooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo04_ooooo000Qooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0hooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo04cooooo000Qooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo04co
oooo000Qooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`0jooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0>_ooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo04cooooo000Qooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool0>_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo04cooooo000Q
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0j
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo04cooooo000Qooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo02?ooooo00?o0000oooo
ooooool0>_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo04gooooo000Qooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0jooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo04gooooo000Qooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo04gooooo000Qooooo`?o00002?oo
ool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`0looooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0COoo
ool0027ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo03cooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0looooo`03o`000?oooooo
oooo02;ooooo00?o0000ooooooooool0COooool0027ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0Qooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool08Oooool00ol0
003oooooooooo`0looooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0C_ooool0027o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03co
oooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool0C_ooool0027ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool08Oooool00ol0003ooooo
ooooo`0mooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0C_ooool0027ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03kooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool0C_ooool0027ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0n
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0C_ooool000Oooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03kooooo00?o
0000ooooooooool07oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool0Coooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?oo
ool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0?_oo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo04oooooo0007ooooo`05oa0@4?oooooo
ooooooooool@41004?ooool00ol0003oooooooooo`02ooooo`?o00002_ooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`0oooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0Coooool000Oooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0Cooo
ool000Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
@?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`1?ooooo`001oooool01Ol@413ooooooooooooooooo410@00cooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo043ooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`1@ooooo`001oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo01gooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo043ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1@ooooo`001ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo053ooooo
000Qooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`11ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0@Oooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo053ooooo000Qooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool0@Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo053ooooo000Qoooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`12oooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo057ooooo000Qooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool0@oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo057ooooo000Qooooo`?o0000
3Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
DOooool0027ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo04?ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`13ooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool0DOooool0027ooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`13ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0DOooool0
027ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
04Cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool0D_ooool0027ooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`15ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0D_ooool0027ooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04Gooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool0D_ooool0027ooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`15ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0D_ooool0027ooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Kooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool0Doooool0027ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo04Kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`17oooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0Doooool0027ooooo0ol0000?ooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo04Oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1Cooooo`00
8Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
B?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`1Cooooo`008Oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo04Sooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Dooooo`008Oooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0B?ooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`1Dooooo`008Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
04Wooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Dooooo`008Oooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0B_ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`1Dooooo`008Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04[ooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Dooooo`008Oooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0B_ooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`1Eooooo`008Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool0C?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo04_ooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`1Eooooo`008Oooool3o`00017ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool0C?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo05Gooooo000Qooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1<ooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo05Kooooo000Qooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
COooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05Kooooo000Qooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1=ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo05Kooooo000Qooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0C_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo05Oooooo000Qooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
05Oooooo000Qooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`1?ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0D?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo05Oooooo000Qooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo05Sooooo
000Qooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`1Aooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0DOooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo05Sooooo000Qooooo`?o00005?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1B
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0F?ooool0027ooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05;ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool0FOooool0027ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo05?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Cooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool0FOooool0027ooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
F_ooool0027ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo05Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Eooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool0F_ooool0027ooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`1Eooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Foooool0
027ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
05Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0Foooool001Sooooo1?l000000ol@413oooooooooo`02ooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Iooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo05cooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
6?ooool2o`0000Cooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo05_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Mooooo`006_oo
ool00ol0003oooooooooo`04ooooo`?o00006Oooool5o`0005kooooo1Ol0001Nooooo`Go0000H?oo
ool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Joooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o
0000ooooooooool0oooooom5ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00WOooool2o`0003gooooo0_l0002:oooo
o`00WOooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo08Sooooo002:ooooo`?o0000
0_ooool01_lb<S;o410@ooooooooooook^k^oeEEE@;o000000?oA4A4okZj^_ooool00oooool00ol0
003oooooooooo`02ooooo`06onk^k_mVIVKo0000o`000?lb<S;o^[Zj=Oooool00ol0003ooooooooo
o`28ooooo`00Roooool01Ol0003oooooooooooo<c<co410@00?ooooo00KoEEEEogMgMoooooook^k^
ogMgMol@4104ooooo`03o`000?oooooooooo00;ooooo0_mgMgL01?mEEEGoQhN7omgMgOm4A4@eoooo
o`03o`000?oooooooooo08Sooooo002;ooooo`05o`000?oooooooooooeEEEOn7QhL00oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?oV9RHooooool00000>?ooool00ol0
003oooooooooo`28ooooo`00Roooool01Ol0003oooooomgMgOl0003ok^k^00?ooooo1_l00004oooo
o`03o`000?oooooooooo00;ooooo00?oV9RHooooool000000ol0000Booooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`28ooooo`00Roooool3o`000003
oa0@4?nHV9Sooooo00;ooooo00KoEEEEohN7Qoo^k^koooooohN7Qolb<S84ooooo`03o`000?oooooo
oooo00;ooooo00?oMgMgohN7QomVIVH00_nj^[X00olb<S;oooooooooo`0?ooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`28ooooo`00Roooool01Ol0
003oooooooooooo<c<co000000?ooooo00Kok^k^oeEEEOl0003o0000odA4A?o^k^h4ooooo`03o`00
0?oooooooooo00?ooooo00KoIVIVo`000?l0003oA4A4onk^k_ooool3o`0000Cooooo0_l000000ooo
oooo0000o`000003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000000oooool01?l0
003oooooooooooooool3o`0000Kooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0R?ooool008_ooooo00Go0000ooooooooooooc<c<o`00000=ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool01?ooool00ol0003oooooo`000004ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00008ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`28ooooo`00R_ooool4
o`000003oa0@4?nYZJWooooo00cooooo0_l0000;ooooo`03o`000?oooooooooo00Cooooo0_l00005
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_l00002ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`;o0000R_ooool0
0:[ooooo00?o0000ooooooooool01?ooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooool000000oooool01?l0003oooooooooooooool3o`0000Cooooo1?l00004
ooooo`03o`000?oooooooooo08kooooo002Yooooo`;o00001_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo08oooooo002`ooooo`;o00002?ooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo093ooooo002Zooooo`03o`000?oooooooooo0;_ooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-2, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0505254 0.309016 0.294303 [
[.15012 .29652 -9 -9 ]
[.15012 .29652 9 0 ]
[.27644 .29652 -3 -9 ]
[.27644 .29652 3 0 ]
[.40275 .29652 -9 -9 ]
[.40275 .29652 9 0 ]
[.52906 .29652 -6 -9 ]
[.52906 .29652 6 0 ]
[.65538 .29652 -12 -9 ]
[.65538 .29652 12 0 ]
[.78169 .29652 -6 -9 ]
[.78169 .29652 6 0 ]
[.908 .29652 -12 -9 ]
[.908 .29652 12 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .01471 -12 -4.5 ]
[.01131 .01471 0 4.5 ]
[.01131 .16186 -24 -4.5 ]
[.01131 .16186 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[.5 .63053 -37 0 ]
[.5 .63053 37 12.625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15012 .30902 m
.15012 .31527 L
s
[(2.5)] .15012 .29652 0 1 Mshowa
.27644 .30902 m
.27644 .31527 L
s
[(5)] .27644 .29652 0 1 Mshowa
.40275 .30902 m
.40275 .31527 L
s
[(7.5)] .40275 .29652 0 1 Mshowa
.52906 .30902 m
.52906 .31527 L
s
[(10)] .52906 .29652 0 1 Mshowa
.65538 .30902 m
.65538 .31527 L
s
[(12.5)] .65538 .29652 0 1 Mshowa
.78169 .30902 m
.78169 .31527 L
s
[(15)] .78169 .29652 0 1 Mshowa
.908 .30902 m
.908 .31527 L
s
[(17.5)] .908 .29652 0 1 Mshowa
.125 Mabswid
.04907 .30902 m
.04907 .31277 L
s
.07433 .30902 m
.07433 .31277 L
s
.0996 .30902 m
.0996 .31277 L
s
.12486 .30902 m
.12486 .31277 L
s
.17539 .30902 m
.17539 .31277 L
s
.20065 .30902 m
.20065 .31277 L
s
.22591 .30902 m
.22591 .31277 L
s
.25117 .30902 m
.25117 .31277 L
s
.3017 .30902 m
.3017 .31277 L
s
.32696 .30902 m
.32696 .31277 L
s
.35222 .30902 m
.35222 .31277 L
s
.37749 .30902 m
.37749 .31277 L
s
.42801 .30902 m
.42801 .31277 L
s
.45328 .30902 m
.45328 .31277 L
s
.47854 .30902 m
.47854 .31277 L
s
.5038 .30902 m
.5038 .31277 L
s
.55433 .30902 m
.55433 .31277 L
s
.57959 .30902 m
.57959 .31277 L
s
.60485 .30902 m
.60485 .31277 L
s
.63011 .30902 m
.63011 .31277 L
s
.68064 .30902 m
.68064 .31277 L
s
.7059 .30902 m
.7059 .31277 L
s
.73116 .30902 m
.73116 .31277 L
s
.75643 .30902 m
.75643 .31277 L
s
.80695 .30902 m
.80695 .31277 L
s
.83222 .30902 m
.83222 .31277 L
s
.85748 .30902 m
.85748 .31277 L
s
.88274 .30902 m
.88274 .31277 L
s
.93327 .30902 m
.93327 .31277 L
s
.95853 .30902 m
.95853 .31277 L
s
.98379 .30902 m
.98379 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01471 m
.03006 .01471 L
s
[(-1)] .01131 .01471 1 0 Mshowa
.02381 .16186 m
.03006 .16186 L
s
[(-0.5)] .01131 .16186 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(0.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04414 m
.02756 .04414 L
s
.02381 .07357 m
.02756 .07357 L
s
.02381 .103 m
.02756 .103 L
s
.02381 .13243 m
.02756 .13243 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -98 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.625 moveto
(@) show
81.000 13.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\343) show
87.000 9.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344) show
93.000 9.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
97.188 9.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
( ) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
99.000 9.625 moveto
(H) show
103.188 9.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
107.375 9.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
111.562 9.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
117.562 9.625 moveto
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
121.750 9.625 moveto
(L) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
127.000 13.625 moveto
(D) show
133.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .39996 m
.04262 .49553 L
.0522 .5351 L
.06244 .56842 L
.0679 .58188 L
.07286 .59137 L
.07525 .59498 L
.07784 .59817 L
.08029 .60049 L
.08147 .60136 L
.08255 .60202 L
.08382 .60262 L
.08452 .60287 L
.08518 .60306 L
.08636 .60327 L
.08764 .60331 L
.08838 .60325 L
.08905 .60314 L
.08982 .60295 L
.09055 .60271 L
.09184 .60213 L
.09325 .60128 L
.09612 .59885 L
.09915 .59527 L
.10458 .58628 L
.10954 .57528 L
.11406 .56301 L
.12422 .5282 L
.14255 .44421 L
.1824 .21886 L
.20062 .12581 L
.21099 .08271 L
.21607 .06497 L
.22073 .05086 L
.22527 .03921 L
.23024 .02897 L
.23524 .0214 L
.23797 .01846 L
.2405 .01648 L
.24181 .01574 L
.24251 .01543 L
.24324 .01516 L
.24388 .01498 L
.24458 .01483 L
.24582 .01472 L
.24703 .01477 L
.24832 .01502 L
.24954 .01542 L
.25066 .01595 L
.25204 .01679 L
Mistroke
.25332 .01777 L
.25622 .02068 L
.25878 .02404 L
.26151 .02841 L
.26688 .03942 L
.27182 .05222 L
.28296 .08989 L
.30314 .18354 L
.34268 .40775 L
.36258 .50659 L
.37127 .541 L
.38071 .57059 L
.38593 .58311 L
.39075 .59208 L
.39536 .59824 L
.39769 .60044 L
.39892 .60135 L
.40025 .60215 L
.40158 .60273 L
.4023 .60297 L
.40297 .60313 L
.40417 .6033 L
.40546 .60329 L
.40618 .6032 L
.40697 .60304 L
.40771 .60282 L
.40839 .60256 L
.40969 .60192 L
.41106 .60104 L
.41355 .59888 L
.41588 .59622 L
.42118 .58791 L
.42618 .57727 L
.43162 .56272 L
.44151 .52885 L
.46006 .44396 L
.50081 .2136 L
.52104 .11264 L
.53095 .07368 L
.53529 .05938 L
.54004 .04584 L
.54431 .03566 L
.54888 .02694 L
.5514 .0231 L
.5537 .02023 L
.55601 .01794 L
.55819 .01633 L
.55932 .01572 L
.56056 .01521 L
.56186 .01487 L
Mistroke
.56307 .01472 L
.5642 .01474 L
.56524 .01489 L
.56644 .01521 L
.56758 .01567 L
.5688 .01634 L
.5701 .01723 L
.57245 .01932 L
.57524 .02263 L
.57776 .02637 L
.58264 .0356 L
.5878 .04811 L
.59702 .07718 L
.61785 .16922 L
.65584 .38381 L
.677 .4931 L
.68702 .53473 L
.69628 .56538 L
.70084 .57735 L
.70586 .58803 L
.71092 .59598 L
.71368 .59913 L
.71492 .60025 L
.71628 .60129 L
.7174 .60198 L
.7186 .60256 L
.71986 .603 L
.72104 .60324 L
.72221 .60332 L
.72332 .60325 L
.72431 .60307 L
.72539 .60274 L
.72658 .60223 L
.72788 .60148 L
.7305 .59937 L
.73294 .59673 L
.73521 .59365 L
.7402 .58489 L
.74563 .5723 L
.75552 .54171 L
.77406 .46156 L
.81477 .23307 L
.83362 .13467 L
.84353 .09182 L
.85398 .05568 L
.85932 .04129 L
.86517 .02896 L
.86774 .02472 L
.87049 .02101 L
.87308 .01828 L
Mistroke
.87544 .01646 L
.8767 .01576 L
.87739 .01545 L
.87803 .01521 L
.87917 .0149 L
.88042 .01473 L
.88111 .01472 L
.88178 .01475 L
.88302 .01496 L
.88371 .01515 L
.88436 .01538 L
.88582 .01608 L
.8871 .01689 L
.88831 .01783 L
.89057 .02003 L
.893 .02304 L
.89563 .02704 L
.90054 .03656 L
.90513 .04777 L
.91556 .08109 L
.93662 .17599 L
.97552 .39622 L
.97619 .39996 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool001So
oooo1?l000000ol@413oooooooooo`02ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000?ooooo`Ko00001Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000
ooooooooool01?ooool3o`00047ooooo1Ol0001Nooooo`Go0000G_ooool5o`0003Sooooo000Joooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`02oooo
o`;o0000G?ooool2o`0000Cooooo00?o0000ooooooooool0Foooool01?l0003oooooooooooooool2
o`0003Oooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0?oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1Iooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0=?ooool001[o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05So
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0cooooo`006?ooool00omEEEGoIVIV
o`000006ooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`1Fooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Eoooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo03?ooooo000Qooooo`03o`000?oooooooooo03kooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool0E_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03;ooooo000Q
ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1D
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo03;ooooo000Qooooo`03o`000?oooooooooo03cooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool0E?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03;ooooo000Qooooo`03
o`000?oooooooooo03cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Cooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo037ooooo000Qooooo`?o0000??ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo05;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Booooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool0<Oooool0027ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0<?oo
ool0027ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo053ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool0<?ooool0027ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`1@ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0<?ooool0027o
oooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo053o
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool0;oooool0027ooooo00?o0000ooooooooool0>_ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`1?ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0;oooool0027ooooo00?o
0000ooooooooool0>Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04kooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0;oooool0027ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1>
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0;_ooool0027ooooo00?o0000oooo
ooooool0>Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo04gooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool0;_ooool0027ooooo0ol0000iooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool0C?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04cooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0^ooooo`008Oooool00ol0003oooooooooo`0hooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo04cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0]ooooo`008Ooo
ool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0C?oo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0]ooooo`008Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo04_ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0]ooooo`008Oooool00ol0
003oooooooooo`0hooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0B_ooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`0]ooooo`008Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04Wo
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0/ooooo`008Oooool00ol0003ooooo
ooooo`0gooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0B_ooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`0/ooooo`008Oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0BOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04Wooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`0/ooooo`008Oooool00ol0003oooooooooo`0g
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0/
ooooo`008Oooool3o`0003Oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`18oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo02cooooo000Qooooo`03o`000?oooooooooo03Kooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0Aoooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02_ooooo000Qooooo`03o`00
0?oooooooooo03Kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`17ooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo02_ooooo000Qooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0A_oo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02_ooooo000Qooooo`03o`000?oooooo
oooo03Kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`16ooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo02_ooooo000Qooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`16ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0AOooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo02_ooooo000Qooooo`03o`000?oooooooooo03Go
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02[o
oooo000Qooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`14ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0A?ooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo02[ooooo000Qooooo`03o`000?oooooooooo03Gooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool0A?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02[ooooo000Q
ooooo`?o0000=Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04Cooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool0:_ooool0027ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo04Cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`13oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0:_ooool0027ooooo00?o0000oooooooo
ool0=?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo04;ooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool0:Oooool0027ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo04;ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`12ooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool0:Oooool0027ooooo00?o0000ooooooooool0=?oo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0:Ooo
ool0027ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo04;ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`11ooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool0:Oooool0027ooooo00?o0000ooooooooool0<oooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`11ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0:Oooool000Oo
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM00Cooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo043ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`10ooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool0:?ooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo03?ooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool0@?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Sooooo0005o`00
00;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0<oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo043ooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool0:?ooool000Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;o
oooo00?ooooo0ol0000cooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0@?ooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`0Xooooo`001oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000
ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0?_oo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Sooooo0007ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03;ooooo00?o
0000ooooooooool07oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool0?_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02Oooooo0007
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo03;ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0nooooo`03o`000?oo
oooooooo01oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo02Oooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o
0000ooooooooool0<_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03kooooo00?o
0000ooooooooool07oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool09oooool0027ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0m
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool09oooool0027ooooo00?o0000oooo
ooooool0<Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03cooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool09oooool0027ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo03cooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0looooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool09oooool0027ooooo00?o0000ooooooooool0
<Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
9_ooool0027ooooo0ol0000aooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0??oo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`0Vooooo`008Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooo
oooo02;ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Vooooo`008Oooool00ol0
003oooooooooo`0`ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0>_ooool00ol0
003oooooooooo`0Sooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool08_ooool00ol0
003oooooooooo`0Vooooo`008Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02?o
oooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03[o
oooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Vooooo`008Oooool00ol0003ooooo
ooooo`0`ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0>_ooool00ol0003ooooo
ooooo`0Sooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool08oooool00ol0003ooooo
ooooo`0Uooooo`008Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool0>_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03[ooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`0Uooooo`008Oooool00ol0003oooooooooo`0`
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0U
ooooo`008Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0>?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo03Wooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`0Uooooo`008Oooool00ol0003oooooooooo`0_ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo03Sooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Uooooo`00
8Oooool3o`0002oooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0hooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo02Cooooo000Qooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>?oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02Cooooo000Qooooo`03o`000?oooooo
oooo02oooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0gooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo02Cooooo000Qooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`0gooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo02Cooooo000Qooooo`03o`000?oooooooooo02ko
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Co
oooo000Qooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`0fooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0=_ooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo02Cooooo000Qooooo`03o`000?oooooooooo02kooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool0=_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02?ooooo000Q
ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0f
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo02?ooooo000Qooooo`03o`000?oooooooooo02gooooo00?o0000oooo
ooooool0:?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool0=Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02?ooooo000Qooooo`?o
0000;Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo03Cooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02Sooooo00?o0000oooooooo
ool08oooool0027ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo03Cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo02Sooooo00?o0000ooooooooool08oooool0027ooooo00?o0000ooooooooool0;Ooo
ool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool08_oo
ool0027ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooo
oooo03Cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooo
oooo02Wooooo00?o0000ooooooooool08_ooool0027ooooo00?o0000ooooooooool0;Oooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`0dooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool08_ooool0027o
oooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03?o
oooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02[o
oooo00?o0000ooooooooool08_ooool0027ooooo00?o0000ooooooooool06_ooool5o`0000Gooooo
0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd06_ooool01Om4A4Co0000o`000?lb<S;ogMgM
00_ooooo00?o0000ooooooooool03_ooool00ol0003ok^k^ooooo`05ooooo`;o8B4Q1Oooool01Om4
A4Co0000o`000?lb<S;ogMgM013ooooo00?o0000ooooooooool00oooool4o`000008oa0@4?oooooo
ooooonk^k_lb<S;o0000oc8b<_o^k^hDooooo`Co000000?o410@ooooooooool01Ol00005ooooo`;o
8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01;ooooo1?l000001Ol@413ooooooooooooooooo
A4A400;o000000Co<S8bomgMgOoooooo00004?ooool4o`000003oa0@4?oooooooooo00;ooooo00?o
0000onk^k_ooool01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bo`00000Tooooo`008Ooo
ool00ol0003oooooooooo`0Jooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q8@Kooooo
00Co0000oooooomgMgOo<S8b7Oooool00omgMgOo<S8booooo`0:ooooo`03o`000?oooooooooo00ko
oooo00?oEEEEojVYZOooool01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool03oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Foooo
o`03o`000?oooooooooo00;ooooo00GoV9RHo`000?o^k^koooooodA4A005ooooo`;o8B4Q2?ooool0
0omgMgOo<S8booooo`0Cooooo`03o`000?oooooooooo00Kooooo00CoMgMgoc8b<_oooooo00004_oo
ool00ol0003oooooooooo`04ooooo`03oeEEEOnYZJWooooo00Gooooo0_lQ8B48ooooo`03ogMgMolb
<S;o000002?ooooo000Qooooo`03o`000?oooooooooo01_ooooo00?oV9RHob4Q8Oo^k^h03_ooool0
1?l0003oooooooooool0000Nooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03_oo
ool00onYZJWoEEEEooooo`0@ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41005_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?lQ8B7ok^k^017ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooo000001;ooooo00?o0000ooooooooool01?ooool00onYZJWoEEEE
ooooo`0@ooooo`;o00008oooool0027ooooo0ol0000Looooo`03oiRHV?lQ8B7ok^k^00gooooo00Co
0000oooooomgMgOo<S8b7Oooool00omgMgOo<S8booooo`0:ooooo`03o`000?oooooooooo00oooooo
00?o8B4Qooooooooool03_ooool00omgMgOo<S8booooo`0?ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000001Kooooo00?o0000oooooooo
ool00oooool01?l0003oV9RHob4Q8Oo^k^h?ooooo`03ogMgMolb<S;ooooo01?ooooo00?o0000oooo
ooooool01_ooool01?mgMgOo<S8booooool0000Booooo`03o`000?oooooooooo00Gooooo00?o8B4Q
ooooooooool03_ooool00omgMgOo<S8bo`00000Sooooo`008Oooool00ol0003oooooooooo`0Moooo
o`03ogMgMomVIVKooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Jooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`02oooool00ol0003oooooooooo`0?ooooo`03oeEEEOo<c<cooooo00_ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c00@ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0_ooool01Ol0003ooooooooooooooooo000001Kooooo00?o0000ooooooooool00oooool01?l0003o
ooooogMgMomVIVH<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`05?ooool00ol0003oooooooooo`03
ooooo`07o`000?lQ8B7o0000oc8b<_o<c<coooooo`00000Booooo`03o`000?oooooooooo00Gooooo
00?oEEEEolc<c?ooool02oooool01_l0003o8B4Qo`000?lb<S;oc<c<o`0002?ooooo000Qooooo`03
o`000?oooooooooo01kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03oooool00onYZJWoMgMgooooo`0;ooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`05
oa0@4?ooooooooooooooool@41005_ooool00ol0003oooooooooo`03ooooo`04o`000?oooooooooo
o`0000cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`05ooooo`03ojVYZOmgMgOo
oooo00_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Qooooo`008Oooool00ol0
003oooooooooo`0Jooooo`05o`000?nj^[[ooooooiRHV?l@41003?ooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02oooool01Ol@413ooooooooooooo
oooo<S8b00cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Fooooo`03o`000?oooooooooo00;ooooo
00Go0000okZj^_l0003oV9RHoa0@400<ooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool00_ooool01Ol@413ooooooooooooooooo<S8b00cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Pooooo`008Oooool00ol0003oooooooooo`0Jooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`03?ooool4o`0001_ooooo1?l0000=ooooo`03o`000?oooooooooo00_ooooo1Ol0000<oooo
o`Co00004?ooool00ol0003oooooooooo`04ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Dooooo`03oeEEEOmVIVKo000000Cooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00<ooooo`Co00004oooool00omEEEGoIVIVo`000005ooooo`Co000000?oooooo`000?ooool04?oo
ool00omEEEGoIVIVo`000004ooooo`Go00003?ooool4o`0000;ooooo00?o0000ooooooooool08?oo
ool0027ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooo
oooo033ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooo
oooo02gooooo00?o0000ooooooooool08?ooool0027ooooo00?o0000ooooooooool0:oooool00ol0
003oooooooooo`0]ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0;Oooool00ol0
003oooooooooo`0`ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool08?ooool0027o
oooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo033o
oooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02go
oooo00?o0000ooooooooool05_ooool2o`0000;ooooo0_l00004ooooo`008Oooool00ol0003ooooo
ooooo`0Zooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0;oooool00ol0003ooooo
ooooo`0^ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`0Fooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM1?ooool001[oooooool0000jo`0000co
oooo00CogMgMo`000?l@413oc<c<1Oooool0027ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000001Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`;o00001_ooool00ol0003oooooooooo`0?ooooo`04onk^k_lQ8B7o410@onk^kPGooooo000Q
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooo`000007ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool2o`0000Kooooo00?o0000ooooooooool0
3oooool01?lQ8B7oMgMgogMgMolb<S85ooooo`008Oooool00ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo033ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0_ooooo`03o`00
0?oooooooooo02kooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Eooooo`;o0000
0_ooool2o`0000Cooooo000Qooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0<?oo
ool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0;_oo
ool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01oooooo000Qooooo`03o`000?oooooo
oooo02Wooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooo
oooo037ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooo
oooo01kooooo000Qooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`0/ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0;?ooool00ol0
003oooooooooo`0aooooo`03o`000?oooooooooo01kooooo000Qooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo037o
oooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo01ko
oooo000Qooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0<_ooool00ol0003ooooo
ooooo`0/ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0;?ooool00ol0003ooooo
ooooo`0aooooo`03o`000?oooooooooo01kooooo000Qooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool0<_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo037ooooo00?o
0000ooooooooool0;?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo01kooooo000Q
ooooo`?o0000:?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo02cooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo03;ooooo00?o0000
ooooooooool07Oooool0027ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0boooo
o`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Zoooo
o`03o`000?oooooooooo03?ooooo00?o0000ooooooooool07Oooool0027ooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02[ooooo00?o0000oooooooo
ool0<oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03?ooooo00?o0000oooooooo
ool07Oooool0027ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0cooooo`03o`00
0?oooooooooo02[ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Zooooo`03o`00
0?oooooooooo03?ooooo00?o0000ooooooooool07Oooool0027ooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0<ooo
ool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool07Ooo
ool0027ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0dooooo`03o`000?oooooo
oooo02[ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooo
oooo03?ooooo00?o0000ooooooooool07Oooool0027ooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`0dooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0<oooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool07?ooool0027o
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02So
oooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo03Go
oooo00?o0000ooooooooool07?ooool0027ooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`0eooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0=Oooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool07?ooool0027ooooo0ol0
000Vooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0=Oooool00ol0003ooooooooo
o`0Looooo`008Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo03Kooooo00?o0000
ooooooooool0:?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02Sooooo00?o0000
ooooooooool0=Oooool00ol0003oooooooooo`0Looooo`008Oooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0eoooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Koooo
o`008Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo03Kooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool0=oooool00ol0003oooooooooo`0Kooooo`008Oooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo03Oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0gooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Kooooo`008Ooo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0=ooo
ool00ol0003oooooooooo`0Kooooo`008Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo03Sooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Kooooo`008Oooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`0gooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0>?ooool00ol0
003oooooooooo`0Jooooo`008Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03So
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Jooooo`008Oooool3o`0002Gooooo
00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo03Sooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo01[ooooo
000Qooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0>Oooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`0iooooo`03o`000?oooooooooo01[ooooo000Qooooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool0>_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo03Wooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`1Fooooo`008Oooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo03[ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0ioooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0E_ooool0027ooooo0_l0000Uooooo`03
o`000?oooooooooo03[ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0iooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool0E_ooool0027ooooo0_l0000Uooooo`03o`00
0?oooooooooo03[ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0jooooo`03o`00
0?oooooooooo02?ooooo00?o0000ooooooooool0E_ooool0027ooooo0_l0000Uooooo`03o`000?oo
oooooooo03[ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0jooooo`03o`000?oo
oooooooo02;ooooo00?o0000ooooooooool0Eoooool0027ooooo0_l0000Uooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo02;ooooo00?o0000ooooooooool0Eoooool0027ooooo0_l0000Tooooo`03o`000?oooooooooo
03cooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool0Eoooool0027ooooo0ol0000Sooooo`03o`000?oooooooooo03co
oooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02;o
oooo00?o0000ooooooooool0Eoooool0027ooooo00?o0000ooooool000008oooool00ol0003ooooo
ooooo`0looooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`0Rooooo`03o`000?oooooooooo05Oooooo000Qooooo`03o`000?oooooo000002?ooooo00?o
0000ooooooooool0??ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03cooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`1Gooooo`008Oooool00ol0003oooooo`00000S
ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0l
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0F?ooool0027ooooo00?o0000oooo
ool000008_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool0?Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo05Sooooo000Qooooo`04
o`000?ooooooooooo`00027ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0Poooo
o`03o`000?oooooooooo03gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1Hoooo
o`008Oooool01?l0003oooooooooool0000Qooooo`03o`000?oooooooooo03kooooo00?o0000oooo
ooooool08?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool0F?ooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4
A4Co0000o`000?lb<S;ogMgM00Cooooo00Co0000oooooooooooo00008Oooool00ol0003ooooooooo
o`0nooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0?Oooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo05Sooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool01?l0003oooooooooool0000Qooooo`03o`00
0?oooooooooo03oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0nooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool0F?ooool000Oooooo00Go410@oooooooooooooooo
oa0@400@ooooo`03o`000?oooooooooo00;ooooo1?l0000Qooooo`03o`000?oooooooooo03oooooo
00?o0000ooooooooool07_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool0FOooool000Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMg
Molb<S;ooooo00?ooooo00Go0000ooooooooooooooooo`00000Oooooo`03o`000?oooooooooo043o
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool0FOooool000Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`01?ooool01Ol0003ooooooooooooooooo000001oooooo00?o0000
ooooooooool0@?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo03oooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`1Iooooo`001oooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo000001oooooo00?o
0000ooooooooool0@?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo03oooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`1Iooooo`001oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00cooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo000001oooooo
00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo047ooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`1Iooooo`001oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00cooooo1?l00005ooooo`05o`000?ooooooooooooooool000007oooool00ol0003o
ooooooooo`11ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0@Oooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo05[ooooo000Qooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo05[ooooo
000Qooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`12ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0@Oooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo05[ooooo000Qooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool0@Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo05[ooooo000Qoooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`13oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo05_ooooo000Qooooo`?o00000_ooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo04?ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`13ooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool0Foooool0027ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
Foooool0027ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo04Cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`13ooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool0Foooool0027ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`14ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0G?ooool0
027ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
04Gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool0G?ooool0027ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`15ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0G?ooool0027ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Kooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool0G?ooool0027ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`16ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0G?ooool0027ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Kooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool0GOooool0027ooooo0ol00004ooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool0Aoooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Oooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`1Mooooo`008Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo04Oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1Mooooo`00
8Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
B?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`1Mooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo04Sooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Nooooo`008Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0BOooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`1Nooooo`008Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
04Wooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Nooooo`008Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0BOooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`1Nooooo`008Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0Boooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo04[ooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`1Oooooo`008Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0Boooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`1Oooooo`008Oooool3o`0000Oooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1;
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo05oooooo000Qooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool0C?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo05oooooo000Qooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1=ooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo063ooooo000Qooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
COooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo063ooooo000Qooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1>ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo063ooooo000Qooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`1?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0C_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo067ooooo000Qooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
067ooooo000Qooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`1@ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0Coooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo067ooooo000Qooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo06;ooooo
000Qooooo`?o00002_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo057ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool0H_ooool0027ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1C
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0H_ooool0027ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05?ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool0Hoooool0027ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo05Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Dooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool0Hoooool0027ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
I?ooool0027ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo05Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Fooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool0I?ooool0027ooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`1Gooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0IOooool0
01Sooooo1?l000000ol@413oooooooooo`02ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0FOooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06Kooooo000Jooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool03_ooool2o`0000Cooooo00?o0000oooooooo
ool0F_ooool2o`0000Cooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo06Oooooo000Jooooo`03o`000?oooooooooo00Cooooo0ol0000?ooooo`Go0000
Goooool4o`0005oooooo1?l0001Zooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001Sooooo
00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`3oooooodGooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002M
ooooo`;o0000?Oooool2o`0008[ooooo002Mooooo`03o`000?oooooooooo03gooooo00?o0000oooo
ooooool0R?ooool008[ooooo0ol00002ooooo`06oc8b<_l@413oooooooooooo^k^koEEEE0_l00000
0om4A4Co^[Zjooooo`03ooooo`03o`000?oooooooooo00;ooooo00Kok^k^ofIVI_l0003o0000oc8b
<_nj^[Xeooooo`03o`000?oooooooooo08Sooooo002;ooooo`05o`000?ooooooooooolc<c?l@4100
0oooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40Cooooo00?o0000ooooooooool00_ooool2ogMg
M`04oeEEEOn7QhOogMgModA4A3Gooooo00?o0000ooooooooool0R?ooool008_ooooo00Go0000oooo
ooooooooEEEEohN7Q`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool0
0onHV9Soooooo`00000hooooo`03o`000?oooooooooo08Sooooo002;ooooo`05o`000?oooooogMgM
o`000?o^k^h00oooool6o`0000Cooooo00?o0000ooooooooool00_ooool00onHV9Soooooo`000003
o`0001;ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo08Sooooo002;ooooo`?o000000?o410@oiRHV?ooool00_ooool01_mEEEGoQhN7onk^k_oooooo
QhN7oc8b<PCooooo00?o0000ooooooooool00_ooool00omgMgOoQhN7ofIVIP02okZj^P03oc8b<_oo
oooooooo00oooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo08Sooooo002;ooooo`05o`000?ooooooooooolc<c?l000000oooool01_o^k^koEEEEo`00
0?l0003oA4A4onk^kPCooooo00?o0000ooooooooool00oooool01_mVIVKo0000o`000?m4A4Cok^k^
ooooo`?o00001?ooool2o`000003ooooool0003o000000?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooo`000003ooooo`04o`000?ooooooooooooooo`?o00001_ooool2o`0000Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`28ooooo`00Roooool01Ol0003oooooooooooo<
c<co000000gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooo000000Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0000Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo08Sooooo002:ooooo`Co000000?o410@ojVYZOooool03?ooool2o`0000_ooooo00?o
0000ooooooooool01?ooool2o`0000Gooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`06o`0000;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00;ooooo0_l0002:ooooo`00Z_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
000000Cooooo00?o0000ooooooooool00oooool00ol0003oooooo`000003ooooo`04o`000?oooooo
ooooooooo`?o00001?ooool4o`0000Cooooo00?o0000ooooooooool0S_ooool00:Wooooo0_l00006
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Soooool00;3ooooo0_l00008oooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0T?ooool00:[ooooo00?o0000oooooooo
ool0^oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-2, -1, 0, 0}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0505254 0.309017 0.294302 [
[.15012 .29652 -9 -9 ]
[.15012 .29652 9 0 ]
[.27644 .29652 -3 -9 ]
[.27644 .29652 3 0 ]
[.40275 .29652 -9 -9 ]
[.40275 .29652 9 0 ]
[.52906 .29652 -6 -9 ]
[.52906 .29652 6 0 ]
[.65538 .29652 -12 -9 ]
[.65538 .29652 12 0 ]
[.78169 .29652 -6 -9 ]
[.78169 .29652 6 0 ]
[.908 .29652 -12 -9 ]
[.908 .29652 12 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.01131 .01472 -12 -4.5 ]
[.01131 .01472 0 4.5 ]
[.01131 .16187 -24 -4.5 ]
[.01131 .16187 0 4.5 ]
[.01131 .45617 -18 -4.5 ]
[.01131 .45617 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[.5 .63053 -37 0 ]
[.5 .63053 37 12.625 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15012 .30902 m
.15012 .31527 L
s
[(2.5)] .15012 .29652 0 1 Mshowa
.27644 .30902 m
.27644 .31527 L
s
[(5)] .27644 .29652 0 1 Mshowa
.40275 .30902 m
.40275 .31527 L
s
[(7.5)] .40275 .29652 0 1 Mshowa
.52906 .30902 m
.52906 .31527 L
s
[(10)] .52906 .29652 0 1 Mshowa
.65538 .30902 m
.65538 .31527 L
s
[(12.5)] .65538 .29652 0 1 Mshowa
.78169 .30902 m
.78169 .31527 L
s
[(15)] .78169 .29652 0 1 Mshowa
.908 .30902 m
.908 .31527 L
s
[(17.5)] .908 .29652 0 1 Mshowa
.125 Mabswid
.04907 .30902 m
.04907 .31277 L
s
.07433 .30902 m
.07433 .31277 L
s
.0996 .30902 m
.0996 .31277 L
s
.12486 .30902 m
.12486 .31277 L
s
.17539 .30902 m
.17539 .31277 L
s
.20065 .30902 m
.20065 .31277 L
s
.22591 .30902 m
.22591 .31277 L
s
.25117 .30902 m
.25117 .31277 L
s
.3017 .30902 m
.3017 .31277 L
s
.32696 .30902 m
.32696 .31277 L
s
.35222 .30902 m
.35222 .31277 L
s
.37749 .30902 m
.37749 .31277 L
s
.42801 .30902 m
.42801 .31277 L
s
.45328 .30902 m
.45328 .31277 L
s
.47854 .30902 m
.47854 .31277 L
s
.5038 .30902 m
.5038 .31277 L
s
.55433 .30902 m
.55433 .31277 L
s
.57959 .30902 m
.57959 .31277 L
s
.60485 .30902 m
.60485 .31277 L
s
.63011 .30902 m
.63011 .31277 L
s
.68064 .30902 m
.68064 .31277 L
s
.7059 .30902 m
.7059 .31277 L
s
.73116 .30902 m
.73116 .31277 L
s
.75643 .30902 m
.75643 .31277 L
s
.80695 .30902 m
.80695 .31277 L
s
.83222 .30902 m
.83222 .31277 L
s
.85748 .30902 m
.85748 .31277 L
s
.88274 .30902 m
.88274 .31277 L
s
.93327 .30902 m
.93327 .31277 L
s
.95853 .30902 m
.95853 .31277 L
s
.98379 .30902 m
.98379 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .01472 m
.03006 .01472 L
s
[(-1)] .01131 .01472 1 0 Mshowa
.02381 .16187 m
.03006 .16187 L
s
[(-0.5)] .01131 .16187 1 0 Mshowa
.02381 .45617 m
.03006 .45617 L
s
[(0.5)] .01131 .45617 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04415 m
.02756 .04415 L
s
.02381 .07358 m
.02756 .07358 L
s
.02381 .10301 m
.02756 .10301 L
s
.02381 .13244 m
.02756 .13244 L
s
.02381 .1913 m
.02756 .1913 L
s
.02381 .22073 m
.02756 .22073 L
s
.02381 .25016 m
.02756 .25016 L
s
.02381 .27959 m
.02756 .27959 L
s
.02381 .33845 m
.02756 .33845 L
s
.02381 .36788 m
.02756 .36788 L
s
.02381 .39731 m
.02756 .39731 L
s
.02381 .42674 m
.02756 .42674 L
s
.02381 .4856 m
.02756 .4856 L
s
.02381 .51503 m
.02756 .51503 L
s
.02381 .54446 m
.02756 .54446 L
s
.02381 .57389 m
.02756 .57389 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -98 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.625 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.625 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.625 moveto
(@) show
81.000 13.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\343) show
87.000 9.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\344) show
93.000 9.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(k) show
97.188 9.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
( ) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
99.000 9.625 moveto
(H) show
103.188 9.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
107.375 9.625 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
111.562 9.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(c) show
117.562 9.625 moveto
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
121.750 9.625 moveto
(L) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
127.000 13.625 moveto
(D) show
133.000 13.625 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .54711 m
.02846 .56199 L
.03279 .57394 L
.03793 .5856 L
.04262 .59372 L
.04498 .59689 L
.04754 .59963 L
.04872 .60063 L
.04996 .60152 L
.05113 .60219 L
.0522 .60267 L
.05341 .60305 L
.05471 .60328 L
.05592 .60331 L
.05707 .60319 L
.05772 .60305 L
.05841 .60285 L
.05964 .60236 L
.06111 .60154 L
.06244 .60059 L
.06508 .5981 L
.06787 .59462 L
.07287 .58621 L
.07824 .57415 L
.08414 .55746 L
.10458 .47532 L
.145 .25067 L
.16364 .15059 L
.17347 .10563 L
.18391 .06631 L
.18916 .05037 L
.19495 .03601 L
.19748 .03085 L
.20021 .02606 L
.20277 .02233 L
.20515 .01951 L
.20759 .01729 L
.20889 .01639 L
.21027 .01565 L
.21096 .01535 L
.21172 .0151 L
.21243 .01491 L
.21309 .0148 L
.21433 .01472 L
.21565 .01482 L
.21679 .01508 L
.21802 .01552 L
.21917 .01609 L
.22023 .01675 L
.22282 .0189 L
Mistroke
.22527 .02165 L
.23032 .02941 L
.23489 .03884 L
.24512 .06784 L
.2546 .10353 L
.26352 .14372 L
.30212 .35813 L
.32171 .46417 L
.33208 .51188 L
.34318 .55347 L
.34868 .56984 L
.35389 .58248 L
.35856 .59136 L
.36098 .595 L
.36364 .59827 L
.36612 .60058 L
.36726 .60141 L
.36845 .60212 L
.36973 .6027 L
.37091 .60306 L
.37217 .60328 L
.37289 .60332 L
.37355 .6033 L
.37475 .60315 L
.37588 .60285 L
.37689 .60245 L
.37799 .6019 L
.38045 .60014 L
.38272 .59791 L
.38741 .59146 L
.39244 .58185 L
.40152 .55772 L
.41232 .51868 L
.42217 .47468 L
.46199 .25341 L
.48018 .15513 L
.49054 .10726 L
.50028 .06996 L
.50978 .04209 L
.51513 .03049 L
.51767 .02607 L
.52003 .02259 L
.52259 .01953 L
.52491 .0174 L
.52624 .01646 L
.5275 .01576 L
.52882 .01521 L
.52957 .01499 L
.53026 .01484 L
.53154 .01472 L
Mistroke
.53275 .01477 L
.53407 .01503 L
.53481 .01526 L
.53549 .01552 L
.53685 .01621 L
.53833 .01721 L
.54103 .01967 L
.54359 .02276 L
.54635 .02693 L
.55136 .03661 L
.56072 .06179 L
.57165 .10182 L
.5817 .1472 L
.62121 .36742 L
.64108 .47354 L
.64976 .51282 L
.6592 .5487 L
.66441 .56501 L
.66923 .57767 L
.67412 .58804 L
.67872 .59539 L
.68104 .59821 L
.68355 .60056 L
.6849 .60153 L
.68632 .60233 L
.68754 .60282 L
.68823 .60303 L
.68887 .60317 L
.68954 .60327 L
.69027 .60332 L
.69096 .60331 L
.6916 .60325 L
.6928 .60301 L
.69408 .60257 L
.69474 .60227 L
.69545 .6019 L
.69673 .60107 L
.69964 .59849 L
.70219 .59544 L
.7049 .5914 L
.70978 .5821 L
.71558 .56773 L
.72083 .55179 L
.74094 .46834 L
.78108 .24411 L
.79951 .14598 L
.80996 .09913 L
.8197 .06349 L
.82936 .03714 L
.83477 .02665 L
Mistroke
.83716 .02304 L
.83969 .01992 L
.84098 .01861 L
.84239 .01739 L
.84369 .01646 L
.84489 .01579 L
.84556 .01548 L
.84629 .01521 L
.84706 .01498 L
.8478 .01483 L
.84848 .01475 L
.84921 .01472 L
.85053 .01482 L
.85122 .01495 L
.85186 .01512 L
.85256 .01536 L
.85329 .01568 L
.85454 .01635 L
.8559 .01729 L
.85842 .0196 L
.86077 .0224 L
.86578 .0304 L
.87122 .04221 L
.88112 .07149 L
.89075 .10873 L
.89967 .14971 L
.93892 .3689 L
.97619 .54711 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool001So
oooo1?l000000ol@413oooooooooo`02ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000?ooooo`Ko00001Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000
ooooooooool01?ooool3o`0003Oooooo1Ol0001Nooooo`Go0000G_ooool5o`0004;ooooo000Joooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo05[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Joooo
o`;o00001?ooool00ol0003oooooooooo`0oooooo`006_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo03Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Iooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo03kooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
=?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
?_ooool001Sooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`0dooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo05Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0mooooo`008Oooool0
0ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0E_ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0mooooo`008Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
05Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0looooo`008Oooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0E?ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0looooo`008Oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0Doooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05?ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0kooooo`008Oooool3o`0003;ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0D_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03_ooooo000Q
ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1A
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo03[ooooo000Qooooo`03o`000?oooooooooo037ooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool0DOooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03[ooooo000Qooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1@ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo03[ooooo000Qooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
D?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03Wooooo000Qooooo`03o`000?oo
oooooooo033ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1>ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo03Wooooo000Qooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0C_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03Wooooo000Qooooo`03o`000?oooooooooo
02oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
03Sooooo000Qooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`1<ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0COooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo03Sooooo000Qooooo`?o0000;oooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`1<ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0>?ooool0027ooooo00?o
0000ooooooooool0;_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo04cooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool0>?ooool0027ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1<
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0=oooool0027ooooo00?o0000oooo
ooooool0;_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo04[ooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool0=oooool0027ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo04[ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1:ooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool0=oooool0027ooooo00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
=oooool0027ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo04Wooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1:ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool0=_ooool0027ooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`19ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0=_ooool0
027ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
04Sooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool0=_ooool0027ooooo0ol0000/ooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04So
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0fooooo`008Oooool00ol0003ooooo
ooooo`0/ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0Aoooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`0eooooo`008Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool0Aoooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Oooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`0eooooo`008Oooool00ol0003oooooooooo`0/
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0e
ooooo`008Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool0AOooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04Kooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`0eooooo`008Oooool00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0dooooo`00
8Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
AOooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`0dooooo`008Oooool00ol0003oooooooooo`0[ooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo04Cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0dooooo`008Oooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0A?ooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0dooooo`008Oooool3o`0002[ooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`13ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0A?ooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo03?ooooo000Qooooo`03o`000?oooooooooo02[o
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo03?o
oooo000Qooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`13ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0@oooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo03?ooooo000Qooooo`03o`000?oooooooooo02[ooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool0@_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo03?ooooo000Q
ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`12
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo03?ooooo000Qooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool0@Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo03;ooooo000Qooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`11ooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo03;ooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Go
oooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool0@Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo03;ooooo0007ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0@?ooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`0booooo`001Ol00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`10ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0?oooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo03;ooooo0007ooooo`05o`000?oooooooooooooo
ool000003oooool00omgMgOo<S8booooo`03ooooo`?o0000:?ooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo043ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0ooooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool0<Oooool000Oooooo00Go0000oooooooo
ooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0a
ooooo`001oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0?oooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`0aooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool0?_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03kooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`0aooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00cooooo1?l00005ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`0nooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0?_ooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo037ooooo000Qooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo
023ooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
033ooooo000Qooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`0mooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0?Oooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo033ooooo000Qooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo033ooooo
000Qooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool08?ooool00ol0003ooooooooo
o`0mooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0??ooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo033ooooo000Qooooo`?o00009oooool00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0l
ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0<?ooool0027ooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03cooooo00?o0000oooo
ooooool08_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool0<?ooool0027ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Rooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool0;oooool0027ooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0
;oooool0027ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Rooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0jooooo`03o`000?oo
oooooooo02?ooooo00?o0000ooooooooool0;oooool0027ooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0jooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0;oooool0
027ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
03[ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo
02?ooooo00?o0000ooooooooool0;oooool0027ooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0Tooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0iooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0;oooool0027ooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo03Wooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool0;_ooool0027ooooo0ol0000Uooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool0>Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0^ooooo`008Oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0^
ooooo`008Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool0>?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Sooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0^ooooo`008Oooool00ol0003oooooooooo`0Tooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo03Sooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0^ooooo`00
8Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
=oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`0]ooooo`008Oooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0]ooooo`008Oooool0
0ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0=oooool0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool09oooool0
0ol0003oooooooooo`0]ooooo`008Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
03Kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0]ooooo`008Oooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0=Oooool00ol0003o
ooooooooo`0Xooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool09oooool00ol0003o
ooooooooo`0]ooooo`008Oooool3o`0002?ooooo00?o0000ooooooooool0:?ooool00ol0003ooooo
ooooo`0eooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0=_ooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo02gooooo000Qooooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool0:?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02Wooooo00?o
0000ooooooooool0=Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02cooooo000Q
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0e
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Y
ooooo`03o`000?oooooooooo02cooooo000Qooooo`03o`000?oooooooooo02?ooooo00?o0000oooo
ooooool0:?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool0=?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02cooooo000Qooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0dooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo02cooooo000Qooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0
:_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0
=?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02cooooo000Qooooo`03o`000?oo
oooooooo01[ooooo1Ol00003ooooo`04o`000?oooooo8B4Qob4Q8@Gooooo00GoA4A4o`000?l0003o
<S8bomgMg@0Jooooo`06odA4A?l0003o0000oc8b<_oMgMgo00006oooool00ol0003ok^k^ooooo`05
ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Kooooo00?o0000ooooooooool03Ooo
ool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hBooooo`03o`000?oooooo0000
00?o000000?o410@ooooooooool01Ol00005ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM01;ooooo1?l000001Ol@413o0000ooooooooooooA4A400;o000000?o<S8bomgMgOooool04Ooo
ool4o`000003oa0@4?oooooooooo00;ooooo00?o0000onk^k_ooool01Oooool00olQ8B7o0000oooo
o`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd09?ooool0027ooooo00?o0000ooooooooool06_oo
ool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00Co0000oooooolQ8B7o8B4Q2?ooool00omgMgOo
<S8booooo`0Looooo`03ogMgMolb<S;o000001_ooooo00?oEEEEojVYZOooool01Oooool2ob4Q8@So
oooo00?oMgMgoc8b<_ooool01Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Booooo`05o`000?ooooooooooooooool000001?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo01?ooooo00?o
0000ooooool000001_ooool00omgMgOo<S8booooo`0Cooooo`03o`000?oooooooooo00Cooooo00?o
EEEEojVYZOooool01Oooool2ob4Q8@03o`000?oooooooooo00Gooooo00?oMgMgoc8b<_ooool08ooo
ool0027ooooo00?o0000ooooooooool06oooool00onHV9So8B4Qonk^kP04ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool07?ooool2o`0001_ooooo00?oZJVYoeEEEOooool04?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@01;ooooo00Go0000ooooooooooooooooo`000005ooooo`03oiRH
V?lQ8B7ok^k^017ooooo00?o0000ooooooooool04_ooool00ol0003oooooo`000007ooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool01?ooool00onYZJWoEEEEooooo`07ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool08_ooool0027ooooo0ol0000Looooo`03oiRHV?lQ
8B7ok^k^00?ooooo00?o0000ooooooooool02Oooool00omgMgOo<S8booooo`0Looooo`03ogMgMolb
<S;o000001cooooo00?o8B4Qooooooooool03_ooool00omgMgOo<S8booooo`05ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000001;ooooo
00Go0000ooooooooooooooooo`000006ooooo`03oiRHV?lQ8B7ok^k^00oooooo00?oMgMgoc8b<_oo
ool04oooool00ol0003oooooo`000006ooooo`03ogMgMolb<S;ooooo01?ooooo00?o0000oooooooo
ool01Oooool00olQ8B7oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?oMgMgoc8b<_oo
ool08oooool0027ooooo00?o0000ooooooooool07Oooool01OmgMgOoIVIVoooooooooooo000000Wo
oooo00Go0000ob4Q8Ol0003o<S8bolc<c00Jooooo`07o`000?lQ8B7o0000oc8b<_o<c<coooooo`00
000Kooooo`03oeEEEOo<c<cooooo00_ooooo00Go0000ob4Q8Ol0003o<S8bolc<c006ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000001;o
oooo00Go0000ooooooooooooooooo`000007ooooo`03ogMgMomVIVKooooo00_ooooo00Go0000ob4Q
8Ol0003o<S8bolc<c00Dooooo`03o`000?oooooo000000?ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c00Dooooo`03o`000?oooooooooo00Gooooo00?oEEEEolc<c?ooool01_ooool00ol0003ooooooooo
o`02ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`09?ooool0027ooooo00?o0000ooooooooool07_oo
ool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Iooooo`03ojVYZOmgMgOooooo00_ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@400Booooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooool000000oooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo00Gooooo00?oZJVYogMgMoooool01_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo02Kooooo000Qooooo`03o`000?oooooooooo01[ooooo00Go0000okZj^_oo
ooooV9RHoa0@4002ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo01Kooooo00Go410@oooooooooooooooooc8b<P0<
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool01?l0003oooooooooool00004ooooo`05o`00
0?nj^[[ooooooiRHV?l@41003?ooool00ol0003oooooooooo`0Fooooo`;o00001?ooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooc8b<P08oooo
o`05o`000?ooooooooooooooool00000:?ooool0027ooooo00?o0000ooooooooool06_ooool01OnH
V9So410@o`000?lQ8B7oc<c<00;ooooo00?o0000ooooooooool01oooool4o`0001_ooooo1?l00002
ooooo`03o`000?oooooooooo01Kooooo1Ol0000<ooooo`Co00001_ooool00ol0003oooooooooo`0>
ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Cooooo`04o`000?mE
EEGoIVIVo`0000Cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00<ooooo`Co00004oooool01?mEEEGo
IVIVo`000?l00004ooooo`Co00004oooool00omEEEGoIVIVo`000004ooooo`Go00002?ooool01?l0
003oooooooooooooool4o`0002Gooooo000Qooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo02gooooo00?o0000oooo
ooooool0<?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02[ooooo000Qooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0`ooooo`03
o`000?oooooooooo02gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0]ooooo`03
o`000?oooooooooo02[ooooo000Qooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
;_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo023ooooo0_l00002ooooo`;o0000
1?ooool0027ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0^ooooo`03o`000?oo
oooooooo02oooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0`ooooo`03o`000?oo
oooooooo02gooooo00?o0000ooooooooool08?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@Co
oooo000Joooooooo0000>_l0000<ooooo`04omgMgOl0003o410@olc<c0Gooooo000Qooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00007oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooo`000005oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo0_l00007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03oooool0
1?o^k^ko8B4Qoa0@4?o^k^h5ooooo`008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`;o00001oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00oooooo00Co8B4QogMgMomgMgOo<S8b1Oooool0027o
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02ko
oooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02oo
oooo00?o0000ooooooooool07oooool2o`0000;ooooo0_l00004ooooo`008Oooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0;Oooool00ol0003ooooo
ooooo`0`ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0;oooool00ol0003ooooo
ooooo`0Yooooo`008Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo033ooooo00?o
0000ooooooooool0;Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02gooooo00?o
0000ooooooooool0<?ooool00ol0003oooooooooo`0Yooooo`008Oooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0a
ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0X
ooooo`008Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo033ooooo00?o0000oooo
ooooool0;Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo02cooooo00?o0000oooo
ooooool0<Oooool00ol0003oooooooooo`0Xooooo`008Oooool00ol0003oooooooooo`0Oooooo`03
o`000?oooooooooo033ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0aooooo`03
o`000?oooooooooo02cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Xooooo`00
8Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0
;?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0
<Oooool00ol0003oooooooooo`0Xooooo`008Oooool3o`0001kooooo00?o0000ooooooooool0<_oo
ool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0;?oo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo02Sooooo000Qooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooo
oooo03?ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooo
oooo02Oooooo000Qooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0<_ooool00ol0
003oooooooooo`0[ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0:_ooool00ol0
003oooooooooo`0cooooo`03o`000?oooooooooo02Oooooo000Qooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo03?o
oooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02Oo
oooo000Qooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0<oooool00ol0003ooooo
ooooo`0Zooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0:_ooool00ol0003ooooo
ooooo`0cooooo`03o`000?oooooooooo02Oooooo000Qooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool0=?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo03?ooooo00?o
0000ooooooooool0:_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02Oooooo000Q
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Y
ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0d
ooooo`03o`000?oooooooooo02Oooooo000Qooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool0=?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo03Gooooo00?o0000oooo
ooooool0:?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02Kooooo000Qooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo03Gooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0eooooo`03
o`000?oooooooooo02Kooooo000Qooooo`?o00007Oooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo02Wooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Xooooo`03o`00
0?oooooooooo03Gooooo00?o0000ooooooooool09_ooool0027ooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0=Ooo
ool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool09_oo
ool0027ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooo
oooo02Oooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo03Kooooo00?o0000ooooooooool09_ooool0027ooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`0fooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool09Oooool0027o
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo03Oo
oooo00?o0000ooooooooool09Oooool0027ooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0fooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0=oooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool09Oooool0027ooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool0=oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo03Oooooo00?o
0000ooooooooool09Oooool0027ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0g
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool09Oooool0027ooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool0>?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03Wooooo00?o0000oooo
ooooool09?ooool0027ooooo0ol0000Kooooo`03o`000?oooooooooo03Sooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool0>Oooool00ol0003oooooooooo`0Tooooo`008Oooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo03Sooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0iooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Tooooo`008Ooo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0>Ooo
ool00ol0003oooooooooo`0Tooooo`008Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo03Wooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Tooooo`008Oooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`0iooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`0Sooooo`008Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo03[o
oooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo02?o
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Sooooo`008Oooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool08oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`0Sooooo`008Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo03[ooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02;ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`0Sooooo`008Oooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0R
ooooo`008Oooool3o`0001[ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Roooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0loooo
o`03o`000?oooooooooo02;ooooo000Qooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool0??ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo02;ooooo000Qooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo03gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0mooooo`03o`00
0?oooooooooo02;ooooo000Qooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0??oo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool08?oo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo02;ooooo000Qooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo03gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooo
oooo027ooooo000Qooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0?Oooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`0nooooo`03o`000?oooooooooo027ooooo000Qooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo03go
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo027o
oooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0
003o<S8bomgMg@04ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0?_ooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`0oooooo`03o`000?oooooooooo027ooooo0007ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo03kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0ooooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0Qoooo
o`001oooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00_ooool3o`00
01Sooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
03oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo
023ooooo0007ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`03oooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo03oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`10oooo
o`03o`000?oooooooooo023ooooo0007ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0
003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0o
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool08?ooool000Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`0oooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0?oooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool08?ooool0
00Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool0@Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo04;ooooo00?o0000
ooooooooool07oooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`11ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0@_ooool0
0ol0003oooooooooo`0Oooooo`008Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
047ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0Oooooo`008Oooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`11ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0@oooool00ol0003o
ooooooooo`0Oooooo`008Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo047ooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Oooooo`008Oooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`13ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0A?ooool00ol0003ooooooooo
o`0Nooooo`008Oooool3o`0001Kooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`14
ooooo`03o`000?oooooooooo01kooooo000Qooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool0@oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04?ooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01kooooo000Qooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo04?ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`15ooooo`03
o`000?oooooooooo01kooooo000Qooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
AOooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01kooooo000Qooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo04Gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`16ooooo`03o`000?oo
oooooooo01gooooo000Qooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0AOooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`16ooooo`03o`000?oooooooooo01gooooo000Qooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
04Gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo
01gooooo000Qooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0Aoooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`17ooooo`03o`000?oooooooooo01gooooo000Qooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Kooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo01cooooo
000Qooooo`?o00005?ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool0Aoooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Sooooo00?o
0000ooooooooool07?ooool0027ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`18
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool07?ooool0027ooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool0B?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04Wooooo00?o0000oooo
ooooool07?ooool0027ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`19ooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo04Wooooo00?o0000ooooooooool07?ooool0027ooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
BOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0
6oooool0027ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1:ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo04_ooooo00?o0000ooooooooool06oooool0027ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`1;ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0Boooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool06oooool0
027ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
04_ooooo00?o0000ooooooooool06oooool0027ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`1<ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0Boooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool06oooool0027ooooo
0ol0000Aooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`1=ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0C?ooool00ol0003ooooo
ooooo`0Jooooo`008Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04cooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool0COooool00ol0003oooooooooo`0Jooooo`008Oooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1=
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0J_ooool0027ooooo0_l0000Aoooo
o`03o`000?oooooooooo04kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1>oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0J_ooool0027ooooo0_l0000Aooooo`03
o`000?oooooooooo04kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1?ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool0Joooool0027ooooo00?o0000ooooool00000
4?ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
Coooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo06_ooooo000Qooooo`03o`000?oo
oooo000000oooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo04oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1[ooooo`008Oooool0
0ol0003oooooo`00000?ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`1@ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0K?ooool0
027ooooo00Co0000oooooooooooo00003_ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo06cooooo000Qooooo`Co00003Oooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
06cooooo000Qooooo`04o`000?ooooooooooo`0000gooooo00?o0000ooooooooool0D_ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`1]ooooo`008Oooool01Ol0003ooooooooooooooooo000000cooooo00?o0000oooo
ooooool0Doooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05?ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`1]ooooo`008Oooool01Ol0003ooooooooooooooooo0000
00_ooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
05?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1]ooooo`008Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0E?ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`1]ooooo`008Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0EOooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo05Gooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`1^ooooo`008Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Eoooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`1_ooooo`006?ooool4o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo05Wooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`1Iooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0L?ooool0
01[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
05_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1aooooo`006_ooool00ol0003o
ooooooooo`04ooooo`?o00001Oooool5o`0005kooooo1Ol0001Nooooo`Ko0000Loooool001[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3oooooodGooooo000Hooooo`03oeEEEOmVIVKo000000Kooooo00?o0000oooooooo
ool0oooooom5ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00WOooool2o`0003gooooo0_l0002:ooooo`00WOooool0
0ol0003oooooooooo`0mooooo`03o`000?oooooooooo08Sooooo002:ooooo`?o00000_ooool01_lb
<S;o410@ooooooooooook^k^oeEEE@;o000000?oA4A4okZj^_ooool00oooool00ol0003ooooooooo
o`02ooooo`06onk^k_mVIVKo0000o`000?lb<S;o^[Zj=Oooool00ol0003oooooooooo`28ooooo`00
Roooool01Ol0003oooooooooooo<c<co410@00?ooooo00KoEEEEogMgMoooooook^k^ogMgMol@4104
ooooo`03o`000?oooooooooo00;ooooo0_mgMgL01?mEEEGoQhN7omgMgOm4A4@eooooo`03o`000?oo
oooooooo08Sooooo002;ooooo`05o`000?oooooooooooeEEEOn7QhL00oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00;ooooo00?oV9RHooooool00000>?ooool00ol0003ooooooooo
o`28ooooo`00Roooool01Ol0003oooooomgMgOl0003ok^k^00?ooooo1_l00004ooooo`03o`000?oo
oooooooo00;ooooo00?oV9RHooooool000000ol0000Booooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`28ooooo`00Roooool3o`000003oa0@4?nHV9So
oooo00;ooooo00KoEEEEohN7Qoo^k^koooooohN7Qolb<S84ooooo`03o`000?oooooooooo00;ooooo
00?oMgMgohN7QomVIVH00_nj^[X00olb<S;oooooooooo`0?ooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`28ooooo`00Roooool01Ol0003ooooooooo
ooo<c<co000000?ooooo00Kok^k^oeEEEOl0003o0000odA4A?o^k^h4ooooo`03o`000?oooooooooo
00?ooooo00KoIVIVo`000?l0003oA4A4onk^k_ooool3o`0000Cooooo0_l000000ooooooo0000o`00
0003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000000oooool01?l0003ooooooooo
ooooool3o`0000Kooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
R?ooool008_ooooo00Go0000ooooooooooooc<c<o`00000=ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`28ooooo`00R_ooool4o`000003oa0@
4?nYZJWooooo00cooooo0_l0000;ooooo`03o`000?oooooooooo00Cooooo0_l00005ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01_l00002ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`;o0000R_ooool00:[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooool000000oooool01?l0003oooooooooooooool3o`0000Cooooo1?l00004ooooo`03o`00
0?oooooooooo08kooooo002Yooooo`;o00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo08oooooo002`ooooo`;o00002?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo093ooooo002Zooooo`03o`000?oooooooooo0;_ooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-2, -1, 0, 0}}]
}, Closed]]
}, Open  ]],

Cell[TextData[{
  "These traveling waves extend over the whole real line, and are periodic in \
both time and space.  The spatial period of the waves is the wavelength \
\[Lambda], and is  related to the wavenumber ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  " by ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda] = 2\ \[Pi]/\ k\)]],
  ". The temporal period ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  " is related to the frequency ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega](k)\)]],
  " by ",
  Cell[BoxData[
      \(TraditionalForm\`T = \ 2\ \[Pi]/\(\[Omega](k)\)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tThe speed at which the waves propagate can be seen to equal ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  ", since the waves can be written as  ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(\[ImaginaryI]\ \(k(x \[PlusMinus] \
c\ t)\)\)\)]],
  ". For instance,  the motion of a wave maximum in the previous animations \
is determined by the condition that the argument of ",
  Cell[BoxData[
      \(TraditionalForm\`cos\ \(k(x \[PlusMinus] c\ t)\)\)]],
  " equals 0. Therefore, the location of the maximum satisfies ",
  Cell[BoxData[
      \(TraditionalForm\`x \[PlusMinus] c\ t = 0\)]],
  ",",
  " which implies that the maximum moves with velocity  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[MinusPlus]c\)\)]],
  "."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["General Solution", "Section",
  CellTags->"c:6"],

Cell[TextData[{
  "\tThe general solution to the wave equation ",
  ButtonBox["(5.1.9)",
    ButtonData:>"(5.1.9)",
    ButtonStyle->"Hyperlink"],
  " is a linear superposition of these traveling waves, propagating to the \
left and the right. This solution can also be written in another, \
illuminating form. If we define two functions ",
  Cell[BoxData[
      \(TraditionalForm\`f(x)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`g(x)\)]],
  " according to "
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{\(f(x)\), "=", 
        RowBox[{
          
          FormBox[\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\[DifferentialD]\
k\/\(2  \[Pi]\)\),
            "TraditionalForm"], \(C(k)\), 
          FormBox[
            RowBox[{\(\[ExponentialE]\^\(\[ImaginaryI]\ k\ x\)\), ",", " ", 
              RowBox[{\(g(x)\), "=", 
                RowBox[{
                  
                  FormBox[\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\
\[DifferentialD]k\/\(2  \[Pi]\)\),
                    "TraditionalForm"], \(D(k)\), 
                  
                  FormBox[\(\(\[ExponentialE]\^\(\[ImaginaryI]\ k\ x\)\)\(,\)\
\(\ \)\),
                    "TraditionalForm"]}]}]}],
            "TraditionalForm"]}]}], TraditionalForm]]]], "NumberedEquation",
  CellTags->"(5.1.10)"],

Cell[TextData[{
  "then Eq. ",
  ButtonBox["(5.1.9)",
    ButtonData:>"(5.1.9)",
    ButtonStyle->"Hyperlink"],
  " becomes"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`y(x, t) = f(x - c\ t)\  + \ g(x + c\ t)\)]],
  "."
}], "NumberedEquation",
  CellTags->{"i:6", "(5.1.11)"}],

Cell[TextData[{
  "Equation ",
  ButtonBox["(5.1.11)",
    ButtonData:>"(5.1.11)",
    ButtonStyle->"Hyperlink"],
  " is another way to represent the general solution to the wave equation in \
one dimension. It is called D'Alembert's solution. The functions ",
  Cell[BoxData[
      \(TraditionalForm\`f(x - c\ t)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`g(x + c\ t)\)]],
  " are arbitrary disturbances traveling to the right and left respectively \
with constant speed ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  ", and without changing their shape. We discussed this behavior previously; \
see Eq. ",
  ButtonBox["(3.1.26)",
    ButtonData:>{"Chapter3.nb", "(3.1.26)"},
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[TextData[{
  "\tIn order to determine the connection between these propagating \
disturbances and the initial conditions, we evaluate Eq. ",
  ButtonBox["(5.1.11)",
    ButtonData:>"(5.1.11)",
    ButtonStyle->"Hyperlink"],
  " and its time-derivative  at ",
  Cell[BoxData[
      \(TraditionalForm\`t = 0\)]],
  ", and use Eq. ",
  ButtonBox["(5.1.2)",
    ButtonData:>"(5.1.2)",
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(\(y(x, 
          0) = \(f(x) + g(x) = \(y\_o\)(x)\)\)\(,\)\)\)]],
  "\n\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(\[PartialD]y\/\[PartialD]t\) \((x, 
            0)\) = \(\(-c\)\ \(\[PartialD]f\/\[PartialD]x\) \((x)\) + 
            c\ \(\[PartialD]g\/\[PartialD]x\) \((x)\) = \(v\_o\)(x)\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "In the second line we have used the chain rule to write ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[PartialD]f\/\[PartialD]t\) \((x - 
              c\ t)\) = \(-c\) \(\[PartialD]f\/\[PartialD]x\) \((x - 
              c\ t)\)\)]],
  ", and similarly for the  time derivative of ",
  Cell[BoxData[
      \(TraditionalForm\`g\)]],
  ". These two equations are sufficient to determine ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`g\)]],
  " in terms of ",
  Cell[BoxData[
      \(TraditionalForm\`y\_o\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`v\_o\)]],
  ". To do so, operate on both equations with a Fourier transform. Then, \
using Eq. ",
  ButtonBox["(5.1.10)",
    ButtonData:>"(5.1.10)",
    ButtonStyle->"Hyperlink"],
  ", we obtain"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\(C(k)\  + \ D(k)\)\(\ \)\(=\)\(\(y\&~\_o\)(
          k)\)\(\ \)\)\)]],
  ",\n",
  Cell[BoxData[
      \(TraditionalForm\`\(-\[ImaginaryI]\)\ \(\[Omega](k)\)\ [
            C(k) - D(k)] = \ \(v\&~\_o\)(k)\)]],
  ","
}], "NumberedEquation",
  CellTags->"(5.1.12)"],

Cell[TextData[{
  "where we have also used Eq. ",
  ButtonBox["(2.3.18)",
    ButtonData:>{"Chapter2.nb", "(2.3.18)"},
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(5.1.6)",
    ButtonData:>{"Chapter5.nb", "(5.1.6)"},
    ButtonStyle->"Hyperlink"],
  ", and where ",
  Cell[BoxData[
      \(TraditionalForm\`y\&~\_o\)]],
  "and ",
  Cell[BoxData[
      \(TraditionalForm\`v\&~\_o\)]],
  "are the Fourier transforms of ",
  Cell[BoxData[
      \(TraditionalForm\`y\_o\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`v\_o\)]],
  " respectively. Solving these coupled equations for ",
  Cell[BoxData[
      \(TraditionalForm\`A(k)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`B(k)\)]],
  " yields"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`C(
        k)\  = \ \(1\/2\)[\(y\&~\_o\)(
            k) + \[ImaginaryI]\ \(\(v\&~\_o\)(k)\)/\(\[Omega](
                k)\)], \[IndentingNewLine]D(
        k)\  = \ \(\(\(1\/2\)[\(y\&~\_o\)(
              k) - \[ImaginaryI]\ \(\(v\&~\_o\)(k)\)/\(\[Omega](
                  k)\)]\)\(.\)\)\)]]], "NumberedEquation",
  CellTags->"(5.1.13)"],

Cell[TextData[{
  "The functions ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`g\)]],
  " then follow from Eq. ",
  ButtonBox["(5.1.10)",
    ButtonData:>"(5.1.10)",
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text"],

Cell[TextData[{
  "\tFor example, if the initial perturbation is stationary, so that ",
  Cell[BoxData[
      \(TraditionalForm\`\(v\_o\)(x) = 0\)]],
  ", but ",
  Cell[BoxData[
      \(TraditionalForm\`\(y\_o\)(x) \[NotEqual] \ 0\)]],
  ", then equations ",
  ButtonBox["(5.1.13)",
    ButtonData:>"(5.1.13)",
    ButtonStyle->"Hyperlink"],
  " imply that ",
  Cell[BoxData[
      \(TraditionalForm\`C(k) = \(D(k) = \(\(y\&~\_o\)(k)\)/2\)\)]],
  ". Equations ",
  ButtonBox["(5.1.10)",
    ButtonData:>"(5.1.10)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(5.1.11)",
    ButtonData:>"(5.1.11)",
    ButtonStyle->"Hyperlink"],
  " then yield"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`y(x, 
          t) = \([\(y\_o\)(x + c\ t) + \(y\_o\)(x\  - \ c\ t)]\)/2\)]],
  ".  "
}], "NumberedEquation",
  CellTags->"(5.1.14)"],

Cell[TextData[{
  "The initial perturbation breaks into two equal pulses, traveling in \
opposite directions. Recall that this was the behavior observed in Example 2 \
of Sec. ",
  ButtonBox["3.1.2",
    ButtonData:>{"Chapter3.nb", "c:10"},
    ButtonStyle->"Hyperlink"],
  ", up to the time where the pulses encountered the boundaries. "
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["5.1.2 Dispersion; Phase and Group Velocities", "Subsubtitle",
  CellTags->"c:7"],

Cell[CellGroupData[{

Cell["\<\
The Schr\[ODoubleDot]dinger Equation for a Free Particle Moving in \
One Dimension\
\>", "Section",
  CellTags->"c:8"],

Cell[TextData[{
  "\tLet's now apply the Fourier transform analysis to another wave equation: \
the ",
  "Schr\[ODoubleDot]dinger",
  " equation for the evolution of the wave function ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi](x, t)\)]],
  " of a free particle of mass ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(m\)\(\ \)\)\)]],
  "moving in one dimension, "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[ImaginaryI]\ \[HBar] \(\[PartialD]\/\[PartialD]t\) \
\(\[Psi](x, 
            t)\) = \(-\(\[HBar]\^2\/\(2\ m\)\)\) \
\(\[PartialD]\^2\/\[PartialD]x\^2\) \(\[Psi](x, t)\)\)]],
  "."
}], "NumberedEquation",
  CellTags->"(5.1.15)"],

Cell[TextData[{
  "This ODE is first-order in time, and so is supplemented by a single \
initial condition on the ",
  "wave function",
  " at ",
  Cell[BoxData[
      \(TraditionalForm\`t = 0\)]],
  ":"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{\(\[Psi](x, 0)\), "=", 
        RowBox[{\(\(\[Psi]\_o\)(x)\), Cell[""]}]}], 
      TraditionalForm]]]], "NumberedEquation",
  CellTags->"(5.1.16)"],

Cell[TextData[{
  "Application of the spatial Fourier transformation operator ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          FormBox[
            RowBox[{
              
              FormBox[\(F\&^ = \[Integral]\_\(-\[Infinity]\)\%\[Infinity]\
\[DifferentialD]x\),
                "TraditionalForm"], 
              FormBox[\(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ k\ x\)\),
                "TraditionalForm"], " "}],
            "TraditionalForm"]}], TraditionalForm]]],
  "to both sides of Eq. ",
  ButtonBox["(5.1.15)",
    ButtonData:>{"Chapter5.nb", "(5.1.15)"},
    ButtonStyle->"Hyperlink"],
  "  yields the following ODE:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[ImaginaryI]\ \[HBar] \(\[PartialD]\/\[PartialD]t\) \
\(\(\[Psi]\&~\)(k, 
            t)\) = \(\(\(\[HBar]\^2\) k\^2\)\/\(2\ m\)\) \(\(\[Psi]\&~\)(k, 
            t)\)\)]],
  ","
}], "NumberedEquation",
  CellTags->"(5.1.17)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\&~ = \(F\&^\) \[Psi]\)]],
  " is the spatial Fourier transform of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\)]],
  ". This first",
  "-order",
  " ODE has the general solution"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\&~\)(k, 
          t) = \(C(
            k)\)\ \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \(\[Omega](k)\)\ t\)\
\)]],
  ","
}], "NumberedEquation",
  CellTags->"(5.1.18)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`C(k)\)]],
  " is the undetermined constant, a function of the wavenumber ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega](k)\)]],
  " is given by"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[Omega](
        k) = \(\[HBar]\ k\^2\)\/\(2  m\)\)]]], "NumberedEquation",
  CellTags->{"i:8", "(5.1.19)"}],

Cell[TextData[{
  "An inverse transformation of Eq. ",
  ButtonBox["(5.1.18)",
    ButtonData:>"(5.1.18)",
    ButtonStyle->"Hyperlink"],
  " then yields the general solution for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi](x, t)\)]],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Psi](x, t)\), "=", 
          RowBox[{\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\), 
            RowBox[{\(\[DifferentialD]k\/\(2  \[Pi]\)\), 
              
              FormBox[\(\(C(
                    k)\)\ \[ExponentialE]\^\[ImaginaryI]\ [k\ x - \
\(\[Omega](k)\) t]\),
                "TraditionalForm"]}]}]}], TraditionalForm]]],
  "."
}], "NumberedEquation",
  CellTags->"(5.1.20)"],

Cell[TextData[{
  "\tEquation ",
  ButtonBox["(5.1.20)",
    ButtonData:>"(5.1.20)",
    ButtonStyle->"Hyperlink"],
  " implies that the ",
  "wave function",
  " for a free particle can be written as a superposition of traveling waves, \
each of the form ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\[ImaginaryI]\ [k\ x\  - \
\(\[Omega](k)\) t]\)]],
  ". These waves propagate with a velocity that depends on the wavenumber, \
termed the ",
  StyleBox["phase velocity",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\(v\_\[Phi]\)(k)\)]],
  ". The phase velocity refers to the velocity of a point of given phase ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " on the wave, where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] = k\ x\  - \ \(\[Omega](k)\)\ t\)]],
  ". For example, the real part of the wave has a maximum at ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] = 0\)]],
  ". The maximum moves according to the equation ",
  Cell[BoxData[
      \(TraditionalForm\`0 = k\ x\  - \ \(\[Omega](k)\)\ t\)]],
  ". Therefore, the speed at which this point moves is given by"
}], "Text",
  CellTags->"i:9"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(v\_\[Phi]\)(k)\  = \ \(\[Omega](k)\)/k\)]],
  "."
}], "NumberedEquation",
  CellTags->"(5.1.21)"],

Cell[TextData[{
  "For a string, with dispersion relation ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega](k) = c\ k\)]],
  ", Eq. ",
  ButtonBox["(5.1.21)",
    ButtonData:>"(5.1.21)",
    ButtonStyle->"Hyperlink"],
  " implies that ",
  Cell[BoxData[
      \(TraditionalForm\`\(v\_\[Phi]\)(k) = c\)]],
  ", so that waves of any wavenumber propagate at the same speed. Here \
however, Eqs. ",
  ButtonBox["(5.1.21)",
    ButtonData:>"(5.1.21)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(5.1.19)",
    ButtonData:>"(5.1.19)",
    ButtonStyle->"Hyperlink"],
  " imply that ",
  Cell[BoxData[
      \(TraditionalForm\`\(v\_\[Phi]\)(k) = \(\[HBar]\ k\)\/\(2  m\)\)]],
  ", so long waves propagate more slowly than short waves.  This variation of \
phase velocity with wavenumber is called ",
  StyleBox["dispersion",
    FontSlant->"Italic"],
  ". Dispersion has important consequences for the behavior of the \
free-particle wave function, as we will now see."
}], "Text",
  CellTags->"i:10"],

Cell["\<\
\tThe effects of dispersion are most easily addressed with an \
example. Consider the evolution of a wave function from the following initial \
condition:\
\>", "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\_o\)(x) = 
        A\ \[ExponentialE]\^\(\(-\ x\^2\)/2  a\^2 + \[ImaginaryI]\ k\_o\ \
x\)\)]],
  "."
}], "NumberedEquation",
  CellTags->"(5.1.22)"],

Cell[TextData[{
  "The functions ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(|\)\(\(\[Psi]\_o\)(x)\)\(|\)\)\)]],
  ",and ",
  Cell[BoxData[
      \(TraditionalForm\`Re[\(\[Psi]\_o\)(x)]\)]],
  " are displayed in Cell ",
  ButtonBox["5.3",
    ButtonData:>"Cell 5.3",
    ButtonStyle->"Hyperlink"],
  ". This  initial condition is a wave with wavenumber ",
  Cell[BoxData[
      \(TraditionalForm\`k\_o\)]],
  "and varying amplitude that vanishes as ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(|\)\(x\)\(|\)\) \[Rule] \ \[Infinity]\)]],
  ". This sort of wave function is often referred to as a ",
  StyleBox["wave packet",
    FontSlant->"Italic"],
  ".   According to the tenets of quantum theory, the probability of finding \
the particle in the range from ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`x + \[DifferentialD]x\)]],
  " is ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(|\)\(\[Psi](
          x)\)\( | \^2\)\(\[DifferentialD]x\)\)\)]],
  ", so Eq. ",
  ButtonBox["(5.1.22)",
    ButtonData:>"(5.1.22)",
    ButtonStyle->"Hyperlink"],
  " describes a particle localized to within a distance of roughly ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " from the origin.  The constant ",
  Cell[BoxData[
      \(TraditionalForm\`A\)]],
  " in Eq. ",
  ButtonBox["(5.1.22)",
    ButtonData:>"(5.1.22)",
    ButtonStyle->"Hyperlink"],
  " is determined by the condition that"
}], "Text",
  CellTags->"i:12"],

Cell[TextData[{
  "\t\t\t\t ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\(\(|\)\(\
\[Psi](x)\)\( | \^2\)\(\[DifferentialD]x\)\) = 1\)]],
  ";"
}], "Text"],

Cell[TextData[{
  "or in words, there is a unit probability of finding the particle somewhere \
on the real line. For ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\_o\)(x)\)]],
  " given by Eq. ",
  ButtonBox["(5.1.22)",
    ButtonData:>"(5.1.22)",
    ButtonStyle->"Hyperlink"],
  ", this implies that ",
  Cell[BoxData[
      \(TraditionalForm\`A = 1\/\@\(2  \[Pi]\ a\^2\)\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(A\  = \ 1/\@\(2  Pi\ a\^2\);\)\), "\n", 
    \(\[Psi]\_o[x_]\  = \ 
      A\ Exp[\(-x^2\)/\((2  a^2\ )\) + \ I\ \(k\_o\) x]; \ a = 1/Sqrt[2]; 
    k\_o = 12;\), "\n", 
    \(\(Plot[{Abs[\[Psi]\_o[x]], \ Re[\[Psi]\_o[x]]}, {x, \(-4\), 4}, 
        PlotRange \[Rule] All, 
        PlotLabel \[Rule] 
          TableForm[{{StyleForm[\*"\"\<|\!\(\[Psi]\_o\)(x)|\>\"", 
                  FontColor \[Rule] RGBColor[0, 0, 0]], "\<,\>", 
                StyleForm[\*"\"\<Re[\!\(\[Psi]\_o\)[x]]\>\"", 
                  FontColor \[Rule] RGBColor[1, 0, 1]]}}, 
            TableSpacing \[Rule] 0], 
        AxesLabel \[Rule] {\*"\"\<x/\!\(\@2\)a\>\"", "\<\>"}, 
        PlotStyle \[Rule] {RGBColor[0, 0, 0], 
            RGBColor[1, 0, 1]}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 5.3"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.119048 0.29898 0.539427 [
[.02381 .28648 -6 -9 ]
[.02381 .28648 6 0 ]
[.2619 .28648 -6 -9 ]
[.2619 .28648 6 0 ]
[.7381 .28648 -3 -9 ]
[.7381 .28648 3 0 ]
[.97619 .28648 -3 -9 ]
[.97619 .28648 3 0 ]
[1.025 .29898 0 -6.71875 ]
[1.025 .29898 38.5625 6.71875 ]
[.4875 .08321 -24 -4.5 ]
[.4875 .08321 0 4.5 ]
[.4875 .19109 -24 -4.5 ]
[.4875 .19109 0 4.5 ]
[.4875 .40687 -18 -4.5 ]
[.4875 .40687 0 4.5 ]
[.4875 .51475 -18 -4.5 ]
[.4875 .51475 0 4.5 ]
[.5 .63053 -53 0 ]
[.5 .63053 53 12.3125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .29898 m
.02381 .30523 L
s
[(-4)] .02381 .28648 0 1 Mshowa
.2619 .29898 m
.2619 .30523 L
s
[(-2)] .2619 .28648 0 1 Mshowa
.7381 .29898 m
.7381 .30523 L
s
[(2)] .7381 .28648 0 1 Mshowa
.97619 .29898 m
.97619 .30523 L
s
[(4)] .97619 .28648 0 1 Mshowa
.125 Mabswid
.08333 .29898 m
.08333 .30273 L
s
.14286 .29898 m
.14286 .30273 L
s
.20238 .29898 m
.20238 .30273 L
s
.32143 .29898 m
.32143 .30273 L
s
.38095 .29898 m
.38095 .30273 L
s
.44048 .29898 m
.44048 .30273 L
s
.55952 .29898 m
.55952 .30273 L
s
.61905 .29898 m
.61905 .30273 L
s
.67857 .29898 m
.67857 .30273 L
s
.79762 .29898 m
.79762 .30273 L
s
.85714 .29898 m
.85714 .30273 L
s
.91667 .29898 m
.91667 .30273 L
s
.25 Mabswid
0 .29898 m
1 .29898 L
s
gsave
1.025 .29898 -61 -10.7188 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.4375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 14.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 14.438 moveto
(\\220) show
0.000 0.000 0.000 setrgbcolor
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 9.062 moveto
(\\217) show
83.188 9.062 moveto
(!!) show
88.000 9.062 moveto
(!) show
83.562 14.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
91.562 14.438 moveto
(a) show
97.562 14.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .08321 m
.50625 .08321 L
s
[(-0.4)] .4875 .08321 1 0 Mshowa
.5 .19109 m
.50625 .19109 L
s
[(-0.2)] .4875 .19109 1 0 Mshowa
.5 .40687 m
.50625 .40687 L
s
[(0.2)] .4875 .40687 1 0 Mshowa
.5 .51475 m
.50625 .51475 L
s
[(0.4)] .4875 .51475 1 0 Mshowa
.125 Mabswid
.5 .11018 m
.50375 .11018 L
s
.5 .13715 m
.50375 .13715 L
s
.5 .16412 m
.50375 .16412 L
s
.5 .21807 m
.50375 .21807 L
s
.5 .24504 m
.50375 .24504 L
s
.5 .27201 m
.50375 .27201 L
s
.5 .32595 m
.50375 .32595 L
s
.5 .35292 m
.50375 .35292 L
s
.5 .37989 m
.50375 .37989 L
s
.5 .43384 m
.50375 .43384 L
s
.5 .46081 m
.50375 .46081 L
s
.5 .48778 m
.50375 .48778 L
s
.5 .54172 m
.50375 .54172 L
s
.5 .56869 m
.50375 .56869 L
s
.5 .59566 m
.50375 .59566 L
s
.5 .05624 m
.50375 .05624 L
s
.5 .02927 m
.50375 .02927 L
s
.5 .0023 m
.50375 .0023 L
s
.25 Mabswid
.5 0 m
.5 .61803 L
s
gsave
.5 .63053 -114 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.3125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 12.688 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 12.688 moveto
(\\310) show
69.000 12.688 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
75.000 14.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(o) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
80.250 12.688 moveto
(H) show
86.250 12.688 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
92.250 12.688 moveto
(L) show
98.250 12.688 moveto
(\\310) show
104.250 12.688 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
105.000 12.688 moveto
0.000 0.000 rmoveto
105.000 12.688 moveto
(,) show
111.000 12.688 moveto
0.000 0.000 rmoveto
111.000 12.688 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 1.000 setrgbcolor
0.000 0.000 rmoveto
111.000 12.688 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 1.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 1.000 setrgbcolor
123.000 12.688 moveto
(@) show
129.000 12.688 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 1.000 setrgbcolor
(y) show
135.000 14.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 1.000 setrgbcolor
(o) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 1.000 setrgbcolor
140.250 12.688 moveto
(@) show
146.250 12.688 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 1.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 1.000 setrgbcolor
152.250 12.688 moveto
(D) show
158.250 12.688 moveto
(D) show
164.250 12.688 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 1.000 setrgbcolor
0.000 0.000 rmoveto
0.000 0.000 0.000 setrgbcolor
1.000 setlinewidth
grestore
0 0 0 r
.5 Mabswid
.02381 .29898 m
.02846 .29898 L
.03279 .29898 L
.03754 .29898 L
.04262 .29898 L
.04795 .29898 L
.053 .29898 L
.05753 .29898 L
.06244 .29898 L
.06751 .29898 L
.07308 .29898 L
.0789 .29898 L
.08435 .29898 L
.08944 .29898 L
.0941 .29898 L
.09947 .29898 L
.10458 .29899 L
.10961 .29899 L
.11417 .29899 L
.11943 .29899 L
.12439 .29899 L
.13322 .299 L
.13819 .29901 L
.14277 .29902 L
.14747 .29903 L
.15251 .29904 L
.1616 .29907 L
.16715 .2991 L
.17241 .29914 L
.17709 .29917 L
.18226 .29923 L
.19191 .29936 L
.1972 .29945 L
.20217 .29956 L
.21103 .29982 L
.22059 .30021 L
.23016 .30077 L
.24063 .30162 L
.25156 .30289 L
.26173 .30452 L
.27225 .30681 L
.28219 .30968 L
.29111 .31298 L
.30077 .31748 L
.32065 .33043 L
.33067 .33923 L
.34169 .35091 L
.36114 .37705 L
.38203 .41298 L
.42331 .49995 L
Mistroke
.44394 .54279 L
.45398 .56108 L
.46307 .5754 L
.47198 .58691 L
.47666 .59184 L
.48159 .59613 L
.48412 .59795 L
.48689 .59965 L
.48944 .60093 L
.49176 .60186 L
.49415 .60258 L
.49546 .60288 L
.4967 .60309 L
.49785 .60322 L
.49891 .60329 L
.50008 .60332 L
.50132 .60328 L
.50246 .60319 L
.50371 .60302 L
.50501 .60278 L
.50622 .60249 L
.50839 .60181 L
.51071 .60087 L
.51601 .59786 L
.52083 .59415 L
.53024 .5843 L
.53912 .57217 L
.57764 .49789 L
.61861 .41177 L
.63901 .37683 L
.65806 .35119 L
.67637 .33288 L
.68663 .32504 L
.696 .31922 L
.70524 .31456 L
.71506 .31062 L
.72584 .30731 L
.73582 .305 L
.74517 .30336 L
.75526 .30205 L
.76479 .30114 L
.77353 .30053 L
.78332 .30004 L
.79243 .29971 L
.79767 .29957 L
.80243 .29946 L
.80763 .29936 L
.81313 .29928 L
.81787 .29922 L
.82309 .29917 L
Mistroke
.83229 .29911 L
.83746 .29908 L
.84302 .29906 L
.84789 .29904 L
.85308 .29903 L
.85832 .29902 L
.86319 .29901 L
.86898 .299 L
.87423 .299 L
.8792 .29899 L
.88458 .29899 L
.88965 .29899 L
.89432 .29899 L
.89902 .29898 L
.90407 .29898 L
.90882 .29898 L
.91316 .29898 L
.91825 .29898 L
.92378 .29898 L
.929 .29898 L
.93383 .29898 L
.93847 .29898 L
.94346 .29898 L
.94818 .29898 L
.95251 .29898 L
.9573 .29898 L
.96255 .29898 L
.96802 .29898 L
.97311 .29898 L
.97619 .29898 L
Mfstroke
1 0 1 r
.02381 .29898 m
.02846 .29898 L
.03279 .29898 L
.03406 .29898 L
.03527 .29898 L
.03636 .29898 L
.03754 .29898 L
.03882 .29898 L
.03947 .29898 L
.04018 .29898 L
.04144 .29898 L
.04262 .29898 L
.04384 .29898 L
.04517 .29898 L
.04761 .29898 L
.04997 .29898 L
.05217 .29898 L
.05711 .29898 L
.06244 .29898 L
.06384 .29898 L
.06531 .29898 L
.06657 .29898 L
.06729 .29898 L
.06795 .29898 L
.06926 .29898 L
.07046 .29898 L
.07112 .29898 L
.07183 .29898 L
.07314 .29898 L
.0743 .29898 L
.07558 .29898 L
.07692 .29898 L
.07818 .29898 L
.08042 .29898 L
.08284 .29898 L
.08836 .29898 L
.09138 .29898 L
.09418 .29898 L
.09542 .29898 L
.09658 .29898 L
.09723 .29898 L
.09793 .29898 L
.09915 .29898 L
.0998 .29898 L
.10052 .29898 L
.10127 .29898 L
.10197 .29898 L
.10323 .29898 L
.10394 .29898 L
.10458 .29898 L
Mistroke
.10587 .29898 L
.10709 .29898 L
.10936 .29898 L
.11181 .29898 L
.11445 .29898 L
.11882 .29899 L
.1236 .29899 L
.12492 .29899 L
.12632 .299 L
.12765 .299 L
.12886 .299 L
.12957 .299 L
.13023 .299 L
.13095 .299 L
.13171 .299 L
.133 .299 L
.13373 .299 L
.13441 .299 L
.13563 .29899 L
.13691 .29899 L
.13919 .29899 L
.14165 .29898 L
.14434 .29897 L
.1492 .29894 L
.15175 .29893 L
.15445 .29892 L
.15682 .29891 L
.15816 .2989 L
.15942 .2989 L
.16057 .2989 L
.16162 .2989 L
.16284 .2989 L
.16399 .2989 L
.16462 .2989 L
.16531 .2989 L
.16672 .29891 L
.16803 .29892 L
.16925 .29893 L
.17201 .29897 L
.17498 .29902 L
.18014 .29913 L
.18495 .29924 L
.18733 .29929 L
.1885 .2993 L
.18957 .29932 L
.19081 .29933 L
.19147 .29933 L
.19216 .29933 L
.19328 .29933 L
.19451 .29932 L
Mistroke
.19521 .29931 L
.19587 .2993 L
.19711 .29928 L
.19845 .29924 L
.19991 .29919 L
.20254 .29906 L
.20497 .29891 L
.21019 .2985 L
.21293 .29826 L
.21583 .29803 L
.21837 .29786 L
.21982 .29778 L
.22051 .29776 L
.22116 .29774 L
.2224 .29771 L
.22353 .29771 L
.22474 .29773 L
.22606 .29778 L
.22733 .29785 L
.22852 .29795 L
.22983 .29809 L
.23124 .29828 L
.2341 .29878 L
.23673 .29936 L
.24145 .30061 L
.24394 .3013 L
.2466 .30199 L
.24787 .30227 L
.24906 .30251 L
.25023 .30271 L
.2513 .30284 L
.25232 .30294 L
.2534 .30299 L
.25448 .30299 L
.25567 .30293 L
.25691 .30278 L
.25805 .30258 L
.25936 .30226 L
.2606 .30186 L
.26281 .30093 L
.26521 .29963 L
.2701 .29622 L
.27538 .29209 L
.2778 .2904 L
.27913 .2896 L
.28036 .28897 L
.2815 .2885 L
.28254 .28819 L
.2837 .28797 L
.28494 .2879 L
Mistroke
.28562 .28795 L
.28635 .28807 L
.28765 .28846 L
.28838 .28878 L
.28906 .28914 L
.2906 .29023 L
.29195 .29146 L
.29318 .29282 L
.29596 .29661 L
.30078 .30514 L
.30593 .31512 L
.30858 .31968 L
.30989 .32158 L
.31109 .32306 L
.31218 .32415 L
.31334 .325 L
.31449 .32552 L
.31577 .32566 L
.31696 .32535 L
.31805 .32469 L
.3193 .32344 L
.32049 .32179 L
.32261 .31771 L
.3249 .31166 L
.33475 .27317 L
.3373 .26279 L
.33998 .25339 L
.34139 .24941 L
.34213 .24764 L
.34293 .24603 L
.34366 .24481 L
.34432 .24394 L
.34562 .24296 L
.34693 .24297 L
.34814 .24392 L
.34877 .24478 L
.34946 .24603 L
.35087 .24953 L
.3521 .25366 L
.35342 .25919 L
.35582 .27188 L
.36082 .30732 L
.36539 .3446 L
.36789 .36392 L
.37054 .3816 L
.37207 .38976 L
.37346 .39556 L
.37413 .39775 L
.37485 .39965 L
.37616 .40176 L
Mistroke
.3774 .40208 L
.3781 .40152 L
.37876 .40049 L
.38008 .39692 L
.38082 .39404 L
.38149 .39087 L
.38401 .3745 L
.38639 .35287 L
.39607 .22851 L
.39862 .19572 L
.40137 .16585 L
.40263 .1548 L
.40396 .14541 L
.40509 .1394 L
.40633 .13513 L
.40749 .13343 L
.40853 .13386 L
.40974 .13675 L
.41088 .14186 L
.41193 .14865 L
.4129 .15664 L
.4151 .18052 L
.41734 .21247 L
.4198 .25481 L
.42476 .35347 L
.42727 .40352 L
.42999 .45302 L
.43256 .4912 L
.43379 .50553 L
.43495 .51632 L
.43598 .52358 L
.43709 .52876 L
.43832 .53116 L
.43945 .53016 L
.44056 .52613 L
.44178 .51826 L
.44306 .50623 L
.44424 .49164 L
.44696 .44681 L
.44953 .39211 L
.45434 .27014 L
.45948 .13968 L
.46241 .07935 L
.46381 .05633 L
.46514 .03874 L
.46631 .0271 L
.46758 .01863 L
.46874 .01493 L
.46982 .01499 L
.47109 .01948 L
Mistroke
.47225 .02766 L
.47289 .03386 L
.47359 .04187 L
.47484 .05972 L
.47745 .10926 L
.4802 .17685 L
.48512 .32031 L
.48937 .44347 L
.4917 .50197 L
.49392 .54721 L
.49517 .56747 L
.49583 .57644 L
.49653 .58462 L
.49776 .59551 L
.49891 .60145 L
.50005 .60332 L
.50112 .60135 L
.5023 .59508 L
.50357 .58362 L
.51307 .37439 L
.51829 .21888 L
.52085 .14943 L
.52322 .0951 L
.52455 .06977 L
.52602 .04703 L
.52749 .03 L
.5283 .02329 L
.52905 .01872 L
.52974 .01601 L
.53039 .01472 L
.53161 .01564 L
.53292 .02146 L
.53367 .0269 L
.53435 .03329 L
.53571 .04952 L
.53699 .06887 L
.53937 .11429 L
.54471 .2451 L
.54955 .37016 L
.55218 .42976 L
.55464 .47508 L
.55675 .50401 L
.55792 .51582 L
.559 .5237 L
.56017 .52913 L
.56145 .53121 L
.56265 .52957 L
.56377 .52503 L
.56495 .51718 L
.56622 .50543 L
Mistroke
.56852 .47642 L
.57375 .38348 L
.57924 .27292 L
.58192 .22458 L
.58434 .18778 L
.58555 .17262 L
.58686 .15883 L
.58809 .14847 L
.58923 .14129 L
.59043 .13617 L
.59112 .13443 L
.59176 .13355 L
.59305 .13394 L
.59378 .13541 L
.59444 .1375 L
.59512 .14038 L
.59584 .14423 L
.59715 .15306 L
.6001 .18087 L
.60546 .24939 L
.61005 .3116 L
.61246 .34064 L
.615 .36625 L
.61636 .37734 L
.61784 .38722 L
.61919 .39406 L
.62044 .39856 L
.62173 .4013 L
.62291 .40216 L
.62356 .40198 L
.62426 .40127 L
.62554 .39867 L
.62677 .3947 L
.6279 .3899 L
.63043 .3756 L
.635 .34146 L
.64039 .29787 L
.64302 .27916 L
.6454 .265 L
.6479 .25366 L
.64927 .24913 L
.65056 .24598 L
.65125 .24475 L
.65197 .24379 L
.65327 .2429 L
.65399 .24285 L
.65466 .24309 L
.6554 .24365 L
.65619 .24459 L
.65751 .24688 L
Mistroke
.65895 .25029 L
.66155 .25852 L
.66644 .27825 L
.67097 .29724 L
.67335 .30605 L
.67585 .31382 L
.67719 .31723 L
.67865 .3203 L
.67997 .32249 L
.68121 .32401 L
.68248 .32506 L
.68364 .32556 L
.68428 .32566 L
.68497 .32563 L
.68623 .32524 L
.68754 .32438 L
.68877 .32322 L
.69155 .31948 L
.69717 .30914 L
.7024 .29929 L
.70495 .29527 L
.70725 .29232 L
.70967 .29002 L
.71099 .28912 L
.71224 .2885 L
.7129 .28826 L
.7136 .28808 L
.71485 .28791 L
.71555 .28791 L
.7162 .28795 L
.71691 .28806 L
.71767 .28824 L
.71895 .28868 L
.72033 .28931 L
.72285 .29083 L
.72756 .29437 L
.73224 .29795 L
.7348 .29964 L
.7372 .30094 L
.73924 .3018 L
.74029 .30215 L
.74143 .30246 L
.74268 .30272 L
.74387 .30288 L
.74503 .30297 L
.7461 .303 L
.74739 .30296 L
.74803 .30291 L
.74874 .30284 L
.75 .30267 L
Mistroke
.75117 .30247 L
.75666 .30113 L
.76187 .29971 L
.76414 .29915 L
.76662 .29864 L
.76901 .29824 L
.77007 .2981 L
.77123 .29797 L
.77225 .29788 L
.77335 .29781 L
.77451 .29775 L
.7756 .29772 L
.77677 .29771 L
.77804 .29772 L
.77869 .29773 L
.77938 .29775 L
.78062 .2978 L
.78186 .29787 L
.78303 .29795 L
.78522 .29811 L
.79025 .29854 L
.79494 .2989 L
.7975 .29906 L
.79984 .29918 L
.80118 .29923 L
.80244 .29927 L
.80378 .2993 L
.80453 .29931 L
.80523 .29932 L
.8064 .29933 L
.80765 .29933 L
.80884 .29933 L
.80992 .29932 L
.81091 .29931 L
.81199 .2993 L
.81417 .29926 L
.82369 .29905 L
.82621 .299 L
.82894 .29896 L
.8302 .29894 L
.83153 .29893 L
.83268 .29892 L
.83392 .29891 L
.83511 .2989 L
.8362 .2989 L
.83725 .2989 L
.83835 .2989 L
.83956 .2989 L
.84068 .2989 L
.84191 .2989 L
Mistroke
.84323 .29891 L
.84853 .29893 L
.85413 .29896 L
.85643 .29897 L
.85891 .29898 L
.86033 .29899 L
.86162 .29899 L
.86294 .29899 L
.86416 .29899 L
.86538 .299 L
.86668 .299 L
.86799 .299 L
.86873 .299 L
.86943 .299 L
.87068 .299 L
.87183 .299 L
.87309 .299 L
.87442 .299 L
.88018 .29899 L
.88554 .29898 L
.88793 .29898 L
.89019 .29898 L
.89144 .29898 L
.8928 .29898 L
.89402 .29898 L
.89517 .29898 L
.89643 .29898 L
.8971 .29898 L
.89783 .29898 L
.89858 .29898 L
.8993 .29898 L
.89994 .29898 L
.90065 .29898 L
.90192 .29898 L
.90263 .29898 L
.90327 .29898 L
.9057 .29898 L
.91507 .29898 L
.91735 .29898 L
.91979 .29898 L
.92119 .29898 L
.92246 .29898 L
.92367 .29898 L
.92496 .29898 L
.92635 .29898 L
.92763 .29898 L
.92834 .29898 L
.92901 .29898 L
.92974 .29898 L
.93053 .29898 L
Mistroke
.93117 .29898 L
.93187 .29898 L
.93261 .29898 L
.93329 .29898 L
.93451 .29898 L
.93581 .29898 L
.941 .29898 L
.94579 .29898 L
.94943 .29898 L
.95127 .29898 L
.95329 .29898 L
.95532 .29898 L
.95646 .29898 L
.9575 .29898 L
.95846 .29898 L
.95951 .29898 L
.96051 .29898 L
.96143 .29898 L
.96236 .29898 L
.96336 .29898 L
.96431 .29898 L
.96518 .29898 L
.96684 .29898 L
.96858 .29898 L
.97619 .29898 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.812},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00Uoooool2o`000<oooooo002Gooooo`03o`000?oo
oooooooo0<kooooo002Gooooo`03o`000?oooooooooo0<kooooo002Gooooo`03o`000?oooooooooo
0<kooooo002>ooooo`03ool0oooooooooooo00Kooooo00?o0000ooooooooool01_ooool2ool0olKo
oooo002=ooooo`;oo`3o2?ooool00ol0003oooooooooo`06ooooo`;oo`3oa_ooool008gooooo0_oo
0?l8ooooo`03o`000?oooooooooo00Kooooo0_oo0?o6ooooo`00SOooool2ool0o`Sooooo00?o0000
ooooooooool01_ooool2ool0olKooooo002=ooooo`03ool0ooooooooo`3o00Oooooo00?o0000oooo
ooooool01_ooool2ool0olKooooo002=ooooo`03ool0ooooooooo`3o00Oooooo0_l00007ooooo`;o
o`3oa_ooool008gooooo00?oo`3ooooooooo0?l01oooool00ol0003oooooooooo`06ooooo`03ool0
ooooooooo`3o0<Gooooo002=ooooo`03ool0ooooooooo`3o00Oooooo00?o0000ooooooooool01_oo
ool00ooo0?ooooooool0o`35ooooo`00SOooool00ooo0?ooooooool0o`07ooooo`03o`000?oooooo
oooo00Gooooo00Coo`3oooooooooooooo`3oaOooool008gooooo00?oo`3ooooooooo0?l01oooool0
0ol0003oooooooooo`05ooooo`04ool0ooooooooooooool0olGooooo002=ooooo`03ool0oooooooo
o`3o00Oooooo00?o0000ooooooooool01Oooool01?oo0?oooooooooooooo0?o5ooooo`00S?ooool0
1?oo0?oooooooooooooo0?l7ooooo`03o`000?oooooooooo00Gooooo00Coo`3oooooooooooooo`3o
aOooool008cooooo00Goo`3oooooooooooooooooool0o`06ooooo`03o`000?oooooooooo00Gooooo
00Coo`3oooooooooooooo`3oaOooool008cooooo00Goo`3oooooooooooooooooool0o`06ooooo`;o
00001_ooool01?oo0?oooooooooooooo0?o5ooooo`00S?ooool01Ooo0?ooooooooooooooooooo`3o
00Kooooo00?o0000ooooooooool01Oooool01?oo0?oooooooooooooo0?o5ooooo`00S?ooool01Ooo
0?ooooooooooooooooooo`3o00Kooooo00?o0000ooooooooool01Oooool01?oo0?oooooooooooooo
0?o5ooooo`00S?ooool01Ooo0?ooooooooooooooooooo`3o00Kooooo00?o0000ooooooooool01Ooo
ool01?oo0?oooooooooooooo0?o5ooooo`00S?ooool01Ooo0?ooooooooooooooooooo`3o00Kooooo
00?o0000ooooooooool01Oooool01?oo0?oooooooooooooo0?o5ooooo`00O?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05ool0oooooooo0000o`000?oo0?l01_ooool00ol0
003oooooooooo`05ooooo`04ool0ooooooooooooool0olGooooo001looooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Goo`3ooooooooooooo0000ool0o`06ooooo`03o`000?oo
oooooooo00Gooooo00Coo`3oooooooooooooo`3oaOooool007Cooooo1_l00002ooooo`05oa0@4?oo
ooooooooooooool@41002oooool01Ooo0?oo0000o`000?l0003oo`3o00Kooooo00?o0000oooooooo
ool01Oooool01?oo0?oooooooooooooo0?o5ooooo`00O?ooool01Ol0003ooooooooooooooooo0000
00_ooooo00Goo`3oomgMgOoooooo0000ool0o`06ooooo`?o00001?ooool01Ooo0?oooooooooooooo
ooooo`3o0<Gooooo001looooo`05o`000?ooooooooooooooool000002oooool01Ooo0?ooEEEEoooo
ool0003oo`3o00Kooooo00?o0000ooooooooool01?ooool01Ooo0?ooooooooooooooooooo`3o0<Go
oooo001looooo`05oa0@4?ooooooooooooooool@41002oooool01Ooo0?ooMgMgolc<c?l0003oo`3o
00Kooooo00?o0000ooooooooool01?ooool01Ooo0?ooooooooooooooooooo`3o0<Gooooo001loooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ooo0?ook^k^odA4A?l0003oo`3o00Kooooo00?o
0000ooooooooool01?ooool00ooo0?ooooooooooo`02ooooo`03ool0oooooooooooo0<;ooooo001l
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01Ooo0?ooooooogMgMol0003oo`3o00Kooooo
00?o0000ooooooooool01?ooool00ooo0?ooooooooooo`02ooooo`03ool0oooooooooooo0<;ooooo
002<ooooo`05ool0oooooooooooooooooooo0?l01_ooool00ol0003oooooooooo`04ooooo`03ool0
oooooooooooo00;ooooo00?oo`3oooooooooool0`_ooool008cooooo00Goo`3ooooooooooooooooo
ool0o`06ooooo`03o`000?oooooooooo00Cooooo00?oo`3oooooooooool00_ooool00ooo0?oooooo
ooooo`32ooooo`00S?ooool01Ooo0?ooooooooooooooooooo`3o00Kooooo00?o0000ooooooooool0
1?ooool00ooo0?ooooooooooo`02ooooo`03ool0oooooooooooo0<;ooooo002<ooooo`05ool0oooo
oooooooooooooooo0?l01_ooool2o`0000Gooooo00?oo`3oooooooooool00_ooool00ooo0?oooooo
ooooo`32ooooo`00Roooool00ooo0?ooooooooooo`02ooooo`03ool0oooooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ooo0?ooooooooooo`02ooooo`03ool0oooooooooooo0<;ooooo002;
ooooo`03ool0oooooooooooo00;ooooo00?oo`3oooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03ool0oooooooooooo00;ooooo00?oo`3oooooooooool0`_ooool008_ooooo00?oo`3ooooo
ooooool00_ooool00ooo0?ooooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?oo`3ooooo
ooooool00_ooool00ooo0?ooooooooooo`32ooooo`00Roooool00ooo0?ooooooooooo`02ooooo`03
ool0oooooooooooo00Cooooo00?o0000ooooooooool01?ooool00ooo0?ooooooooooo`02ooooo`03
ool0oooooooooooo0<;ooooo002;ooooo`03ool0oooooooooooo00;ooooo00?oo`3oooooooooool0
1?ooool00ol0003oooooooooo`04ooooo`03ool0oooooooooooo00;ooooo00?oo`3oooooooooool0
`_ooool008_ooooo00?oo`3oooooooooool00_ooool00ooo0?ooooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?oo`3oooooooooool00_ooool00ooo0?ooooooooooo`32ooooo`00Noooool2
ool0o`kooooo00?oo`3oooooooooool00_ooool00ooo0?ooooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?oo`3oooooooooool00_ooool00ooo0?ooooooooooo`0=ooooo`03ool0oooooooo
oooo0;;ooooo001kooooo`;oo`3o3_ooool00ooo0?ooooooooooo`02ooooo`03ool0oooooooooooo
00Cooooo0_l00005ooooo`03ool0oooooooooooo00;ooooo00?oo`3oooooooooool03Oooool2ool0
ok?ooooo001kooooo`;oo`3o3_ooool00ooo0?ooooooooooo`02ooooo`03ool0oooooooooooo00Co
oooo00?o0000ooooooooool01?ooool00ooo0?ooooooooooo`02ooooo`03ool0oooooooooooo00co
oooo00?oo`3ooooooooo0?l0/oooool007_ooooo0_oo0?l>ooooo`03ool0oooooooooooo00;ooooo
00?oo`3oooooooooool01?ooool00ol0003oooooooooo`04ooooo`03ool0oooooooooooo00;ooooo
00?oo`3oooooooooool03?ooool00ooo0?ooooooool0o`2cooooo`00N_ooool00ooo0?ooooooool0
o`0>ooooo`03ool0oooooooooooo00?ooooo00?oo`3oooooooooool00oooool00ol0003ooooooooo
o`04ooooo`03ool0oooooooooooo00;ooooo00?oo`3oooooooooool03?ooool00ooo0?ooooooool0
o`2cooooo`00N_ooool01?oo0?oooooooooooooo0?l=ooooo`03ool0oooooooooooo00?ooooo00?o
o`3oooooooooool00oooool00ol0003oooooooooo`04ooooo`03ool0oooooooooooo00?ooooo00?o
o`3oooooooooool02oooool01?oo0?oooooooooooooo0?nbooooo`00N_ooool01?oo0?oooooooooo
oooo0?l=ooooo`03ool0oooooooooooo00?ooooo00?oo`3oooooooooool00oooool00ol0003ooooo
ooooo`04ooooo`03ool0oooooooooooo00?ooooo00?oo`3oooooooooool02oooool01?oo0?oooooo
oooooooo0?nbooooo`00N_ooool01?oo0?oooooooooooooo0?l=ooooo`03ool0oooooooooooo00?o
oooo00?oo`3oooooooooool00oooool00ol0003oooooooooo`04ooooo`03ool0oooooooooooo00?o
oooo00?oo`3oooooooooool02oooool01?oo0?oooooooooooooo0?nbooooo`00N_ooool01?oo0?oo
oooooooooooo0?l=ooooo`03ool0oooooooooooo00?ooooo00?oo`3oooooooooool00oooool00ol0
003oooooooooo`04ooooo`03ool0oooooooooooo00?ooooo00?oo`3oooooooooool02oooool01?oo
0?oooooooooooooo0?nbooooo`00NOooool01Ooo0?ooooooooooooooooooo`3o00gooooo00?oo`3o
ooooooooool00oooool00ooo0?ooooooooooo`03ooooo`;o00001Oooool00ooo0?ooooooooooo`03
ooooo`03ool0oooooooooooo00_ooooo00Coo`3oooooooooooooo`3o/_ooool007Wooooo00Goo`3o
ooooooooooooooooool0o`0=ooooo`03ool0oooooooooooo00?ooooo00?oo`3oooooooooool00ooo
ool00ol0003oooooooooo`04ooooo`03ool0oooooooooooo00?ooooo00?oo`3oooooooooool02ooo
ool01?oo0?oooooooooooooo0?nbooooo`00NOooool00ooo0?ooooooooooo`02ooooo`03ool0oooo
oooooooo00[ooooo00?oo`3oooooooooool00oooool00ooo0?ooooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00?oo`3oooooooooool00oooool00ooo0?ooooooooooo`0:ooooo`03ool0oooo
oooooooo00;ooooo00?oo`3oooooooooool0[oooool007Wooooo00?oo`3oooooooooool00_ooool0
0ooo0?ooooooooooo`0:ooooo`03ool0oooooooooooo00?ooooo00?oo`3oooooooooool00oooool0
0ol0003oooooooooo`04ooooo`03ool0oooooooooooo00?ooooo00?oo`3oooooooooool02_ooool0
0ooo0?ooooooooooo`02ooooo`03ool0oooooooooooo0:oooooo001iooooo`03ool0oooooooooooo
00;ooooo00?oo`3oooooooooool02Oooool00ooo0?ooooooooooo`04ooooo`03ool0oooooooooooo
00?ooooo00?o0000ooooooooool01?ooool00ooo0?ooooooooooo`03ooooo`03ool0oooooooooooo
00[ooooo00?oo`3oooooooooool00_ooool00ooo0?ooooooooooo`2_ooooo`00NOooool00ooo0?oo
ooooooooo`02ooooo`03ool0oooooooooooo00Wooooo00?oo`3oooooooooool01?ooool00ooo0?oo
ooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?oo`3oooooooooool00oooool00ooo0?oo
ooooooooo`0:ooooo`03ool0oooooooooooo00;ooooo00?oo`3oooooooooool0[oooool007Wooooo
00Soo`3oooooooooooook^k^oc8b<_oo0?oo<S8bonk^kPGooooo0_lQ8B42ooooo`03ool0oooooooo
000000Co000000?oo`3oooooooooool00oooool00ol0003oooooooooo`04ooooo`03ool0oooooooo
oooo00?ooooo00?oo`3oooooooooool02_ooool00ooo0?ooooooooooo`02ooooo`03ool0oooooooo
oooo0:oooooo001iooooo`08ool0ooooooooooooogMgMonHV9Soo`3ooiRHV?mgMgL5ooooo`;o8B4Q
0_ooool02?oo0?oooooooiRHV?lQ8B7ok^k^oooooom4A4Coo`3o1Oooool00ol0003oooooooooo`03
ooooo`03ool0oooooooooooo00Cooooo00?oo`3oooooooooool02_ooool00ooo0?ooooooooooo`02
ooooo`03ool0oooooooooooo0:oooooo001dooooo`Go000000Soo`3ooooooooooooo410@oooooooo
0?oooooooa0@40Wooooo00Soo`3oooooooooooooV9RHob4Q8Oo^k^koooooool0o`Gooooo00?o0000
ooooooooool00oooool00ooo0?ooooooooooo`04ooooo`03ool0oooooooooooo00[ooooo00?oo`3o
ooooooooool00_ooool00ooo0?ooooooooooo`2_ooooo`00NOooool02?oo0?ooooooooooool0003o
ooooool0oooooooo00002Oooool02?oo0?ooooooooooooooooooV9RHob4Q8Oo^k^koo`3o1Oooool3
o`0000?ooooo00?oo`3oooooooooool01?ooool00ooo0?ooooooooooo`0:ooooo`03ool0oooooooo
oooo00;ooooo00?oo`3oooooooooool0[oooool007Wooooo00Soo`3ooooooooooooo0000oooooooo
0?ooooooo`0000Wooooo00?oo`3oooooooooool00_ooool00omgMgOoIVIVool0o`05ooooo`03o`00
0?oooooooooo00?ooooo00?oo`3oooooooooool01?ooool00ooo0?ooooooooooo`0:ooooo`03ool0
oooooooooooo00;ooooo00?oo`3oooooooooool0[oooool007Wooooo00Soo`3ooooooooooooo410@
oooooooo0?oooooooa0@40Wooooo00?oo`3oooooooooool00oooool00ol0003oo`3oooooo`04oooo
o`03o`000?oooooooooo00?ooooo00?oo`3oooooooooool01?ooool00ooo0?ooooooooooo`0:oooo
o`03ool0oooooooooooo00;ooooo00?oo`3oooooooooool0[oooool007Wooooo00Soo`3ooooooooo
ooooMgMgoiRHV?oo0?ooV9RHogMgM`Wooooo00Soo`3oooooool0003o^[ZjoooooonHV9So410@ool0
o`Gooooo00?o0000ooooooooool00oooool00ooo0?ooooooooooo`04ooooo`03ool0oooooooooooo
00[ooooo00?oo`3oooooooooool00_ooool00ooo0?ooooooooooo`2_ooooo`00NOooool02?oo0?oo
ooooooooooo^k^ko<S8bool0oolb<S;ok^k^2Oooool02?oo0?oooooooiRHV?l@413o0000ob4Q8Oo<
c<coo`3o1Oooool00ol0003oooooooooo`03ooooo`03ool0oooooooooooo00Cooooo00?oo`3ooooo
ooooool02_ooool00ooo0?ooooooooooo`02ooooo`03ool0oooooooooooo0:oooooo001iooooo`03
ool0oooooooooooo00;ooooo00?oo`3oooooooooool02Oooool00ooo0?ooooooooooo`04ooooo`03
ool0oooooooooooo00?ooooo00?o0000ooooooooool00oooool00ooo0?ooooooooooo`04ooooo`03
ool0oooooooooooo00Wooooo00?oo`3oooooooooool00oooool00ooo0?ooooooooooo`2_ooooo`00
NOooool00ooo0?ooooooooooo`02ooooo`03ool0oooooooooooo00Wooooo00?oo`3oooooooooool0
1?ooool00ooo0?ooooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?oo`3oooooooooool0
1?ooool00ooo0?ooooooooooo`09ooooo`03ool0oooooooooooo00?ooooo00?oo`3oooooooooool0
[oooool007Sooooo00?oo`3oooooooooool00oooool00ooo0?ooooooooooo`09ooooo`03ool0oooo
oooooooo00Gooooo00?oo`3oooooooooool00_ooool00ol0003oooooooooo`03ooooo`03ool0oooo
oooooooo00Gooooo00?oo`3oooooooooool02?ooool00ooo0?ooooooooooo`04ooooo`03ool0oooo
oooooooo0:kooooo001hooooo`03ool0oooooooooooo00?ooooo00?oo`3oooooooooool02Oooool0
0ooo0?ooooooooooo`05ooooo`03ool0oooooooooooo00;ooooo0_l00004ooooo`03ool0oooooooo
oooo00Gooooo00?oo`3oooooooooool02?ooool00ooo0?ooooooooooo`04ooooo`03ool0oooooooo
oooo0:kooooo001hooooo`03ool0oooooooooooo00?ooooo00?oo`3oooooooooool02Oooool00ooo
0?ooooooooooo`05ooooo`03ool0oooooooooooo00;ooooo00?o0000ooooooooool00oooool00ooo
0?ooooooooooo`05ooooo`03ool0oooooooooooo00Sooooo00?oo`3oooooooooool01?ooool00ooo
0?ooooooooooo`2^ooooo`00N?ooool00ooo0?ooooooooooo`03ooooo`03ool0oooooooooooo00Wo
oooo00?oo`3oooooooooool01Oooool00ooo0?ooooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00?oo`3oooooooooool01Oooool00ooo0?ooooooooooo`08ooooo`03ool0oooooooooooo00Co
oooo00?oo`3oooooooooool0[_ooool007Sooooo00?oo`3oooooooooool00oooool00ooo0?oooooo
ooooo`09ooooo`03ool0oooooooooooo00Gooooo00?oo`3oooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`03ool0oooooooooooo00Gooooo00?oo`3oooooooooool02?ooool00ooo0?oooooo
ooooo`04ooooo`03ool0oooooooooooo0:kooooo001hooooo`03ool0oooooooooooo00?ooooo00?o
o`3oooooooooool02Oooool00ooo0?ooooooooooo`05ooooo`03ool0oooooooooooo00;ooooo00?o
0000ooooooooool00oooool00ooo0?ooooooooooo`05ooooo`03ool0oooooooooooo00Sooooo00?o
o`3oooooooooool01?ooool00ooo0?ooooooooooo`2^ooooo`00N?ooool00ooo0?ooooooooooo`04
ooooo`03ool0oooooooooooo00Sooooo00?oo`3oooooooooool01Oooool00ooo0?ooooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00?oo`3oooooooooool01Oooool00ooo0?ooooooooooo`08
ooooo`03ool0oooooooooooo00Cooooo00?oo`3oooooooooool0[_ooool007Sooooo00?oo`3ooooo
ooooool01?ooool00ooo0?ooooooooooo`08ooooo`03ool0oooooooooooo00Gooooo00?oo`3ooooo
ooooool00_ooool00ol0003oooooooooo`03ooooo`03ool0oooooooooooo00Gooooo00?oo`3ooooo
ooooool02?ooool00ooo0?ooooooooooo`04ooooo`03ool0oooooooooooo0:kooooo001Xooooo`;o
o`3o3_ooool00ooo0?ooooooooooo`04ooooo`03ool0oooooooooooo00Oooooo00?oo`3ooooooooo
ool01_ooool00ooo0?ooooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?oo`3ooooooooo
ool01Oooool00ooo0?ooooooooooo`08ooooo`03ool0oooooooooooo00Cooooo00?oo`3ooooooooo
ool03?ooool00ooo0?ooooooooooo`2Oooooo`00J?ooool3ool0o`gooooo00?oo`3oooooooooool0
1?ooool00ooo0?ooooooooooo`07ooooo`03ool0oooooooooooo00Kooooo00?oo`3oooooooooool0
0_ooool2o`0000Cooooo00?oo`3oooooooooool01Oooool00ooo0?ooooooooooo`08ooooo`03ool0
oooooooooooo00Cooooo00?oo`3oooooooooool02oooool00ooo0?ooooooool0o`2Pooooo`00Iooo
ool01?oo0?oooooooooooooo0?l=ooooo`03ool0oooooooooooo00Cooooo00?oo`3oooooooooool0
1oooool00ooo0?ooooooooooo`06ooooo`03ool0oooooooooooo00;ooooo00?o0000ooooooooool0
0oooool00ooo0?ooooooooooo`05ooooo`03ool0oooooooooooo00Sooooo00?oo`3oooooooooool0
1?ooool00ooo0?ooooooooooo`0:ooooo`04ool0ooooooooooooool0oj3ooooo001Wooooo`04ool0
ooooooooooooool0o`cooooo00?oo`3oooooooooool01Oooool00ooo0?ooooooooooo`07ooooo`03
ool0oooooooooooo00Kooooo00?oo`3oooooooooool00_ooool00ol0003oooooooooo`03ooooo`03
ool0oooooooooooo00Gooooo00?oo`3oooooooooool01oooool00ooo0?ooooooooooo`05ooooo`03
ool0oooooooooooo00[ooooo00Coo`3oooooooooooooo`3oX?ooool000[ooooo0_l000000ol@413o
ooooooooo`11ooooo`Go00004_ooool01?oo0?oooooooooooooo0?l<ooooo`03ool0oooooooooooo
00Gooooo00?oo`3oooooooooool01oooool00ooo0?ooooooooooo`06ooooo`03ool0oooooooooooo
00;ooooo00?o0000ooooooooool00oooool00ooo0?ooooooooooo`05ooooo`03ool0oooooooooooo
00Oooooo00?oo`3oooooooooool01Oooool00ooo0?ooooooooooo`0:ooooo`05ool0oooooooooooo
oooooooo0?l04oooool5o`0004Kooooo0_l000000ol@413oooooooooo`0looooo`002oooool00ol0
003oooooooooo`12ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@04Oooool00ooo0?ooooooooooo`02
ooooo`03ool0oooooooooooo00Wooooo00?oo`3oooooooooool01Oooool00ooo0?ooooooooooo`07
ooooo`03ool0oooooooooooo00Kooooo00?oo`3oooooooooool00_ooool00ol0003oooooooooo`03
ooooo`03ool0oooooooooooo00Gooooo00?oo`3oooooooooool01oooool00ooo0?ooooooooooo`05
ooooo`03ool0oooooooooooo00[ooooo00Goo`3oooooooooooooooooool0o`0Cooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@0Aoooool00ol0003oooooooooo`0mooooo`001_l00002ooooo`Go0000>ooo
ool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h04_ooool00ooo0?ooooooooooo`02ooooo`03ool0oooo
oooooooo00Wooooo00?oo`3oooooooooool01Oooool00ooo0?ooooooooooo`07ooooo`03ool0oooo
oooooooo00Kooooo00?oo`3oooooooooool00_ooool00ol0003oooooooooo`02ooooo`03ool0oooo
oooooooo00Kooooo00?oo`3oooooooooool01oooool00ooo0?ooooooooooo`05ooooo`03ool0oooo
oooooooo00Wooooo00?oo`3oooooooooool00_ooool00ooo0?ooooooooooo`0Booooo`03oiRHV?lQ
8B7ok^k^04Gooooo1Ol0000nooooo`002?ooool01?m4A4CogMgMooooool00016ooooo`03oiRHV?lQ
8B7ok^k^017ooooo00?oo`3oooooooooool00_ooool00ooo0?ooooooooooo`09ooooo`03ool0oooo
oooooooo00Gooooo00?oo`3oooooooooool01oooool00ooo0?ooooooooooo`06ooooo`03ool0oooo
oooooooo00;ooooo00?o0000ooooooooool00_ooool00ooo0?ooooooooooo`06ooooo`03ool0oooo
oooooooo00Oooooo00?oo`3oooooooooool01Oooool00ooo0?ooooooooooo`09ooooo`03ool0oooo
oooooooo00?ooooo00?oo`3oooooooooool04_ooool00onHV9So8B4Qonk^kP14ooooo`04odA4A?oM
gMgoooooo`0003oooooo0008ooooo`04omgMgOmEEEGoooooo`0004Oooooo00?oMgMgofIVI_ooool0
3oooool00ooo0?ooooooooooo`04ooooo`03ool0oooooooooooo00Sooooo00?oo`3oooooooooool0
1Oooool00ooo0?ooooooooooo`07ooooo`03ool0oooooooooooo00Kooooo00?oo`3oooooooooool0
0_ooool00ol0003oooooooooo`02ooooo`03ool0oooooooooooo00Kooooo00?oo`3oooooooooool0
1oooool00ooo0?ooooooooooo`06ooooo`03ool0oooooooooooo00Sooooo00?oo`3oooooooooool0
0oooool00ooo0?ooooooooooo`0Cooooo`03ogMgMomVIVKooooo04?ooooo00CogMgMoeEEEOoooooo
0000?oooool000Wooooo00?oMgMgolc<c?l00000B?ooool00ol0003oooooooooo`0>ooooo`03ool0
oooooooooooo00Cooooo00?oo`3oooooooooool02?ooool00ooo0?ooooooooooo`05ooooo`03ool0
oooooooooooo00Oooooo00?oo`3oooooooooool01_ooool00ooo0?ooooooooooo`02ooooo`;o0000
0oooool00ooo0?ooooooooooo`06ooooo`03ool0oooooooooooo00Oooooo00?oo`3oooooooooool0
1_ooool00ooo0?ooooooooooo`08ooooo`03ool0oooooooooooo00?ooooo00?oo`3oooooooooool0
5?ooool00ol0003oooooooooo`13ooooo`03ogMgMoo<c<co000003oooooo0009ooooo`03onk^k_m4
A4Co000004Cooooo00Go0000okZj^_ooooooV9RHoa0@400@ooooo`03ool0oooooooooooo00Cooooo
00?oo`3oooooooooool02?ooool00ooo0?ooooooooooo`05ooooo`03ool0oooooooooooo00Oooooo
00?oo`3oooooooooool01_ooool00ooo0?ooooooooooo`02ooooo`03o`000?oooooooooo00;ooooo
00?oo`3oooooooooool01_ooool00ooo0?ooooooooooo`07ooooo`03ool0oooooooooooo00Kooooo
00?oo`3oooooooooool02?ooool00ooo0?ooooooooooo`04ooooo`03ool0oooooooooooo00oooooo
00Go0000okZj^_ooooooV9RHoa0@4015ooooo`03onk^k_m4A4Co000003oooooo000:ooooo`03ogMg
Mol0003ooooo04?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00@ooooo`03ool0oooooooooooo00Co
oooo00?oo`3oooooooooool02?ooool00ooo0?ooooooooooo`05ooooo`03ool0oooooooooooo00Oo
oooo00?oo`3oooooooooool01_ooool00ooo0?ooooooooooo`02ooooo`03o`000?oooooooooo00;o
oooo00?oo`3oooooooooool01_ooool00ooo0?ooooooooooo`07ooooo`03ool0oooooooooooo00Ko
oooo00?oo`3oooooooooool02?ooool00ooo0?ooooooooooo`04ooooo`03ool0oooooooooooo00oo
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c016ooooo`03ogMgMol0003ooooo02?ooooo00?oV9RHoooo
ooooool06?ooool006Cooooo00?oo`3oooooooooool01Oooool00ooo0?ooooooooooo`08ooooo`03
ool0oooooooooooo00Gooooo00?oo`3oooooooooool01oooool00ooo0?ooooooooooo`06ooooo`03
ool0oooooooooooo00;ooooo00?o0000ooooooooool00_ooool00ooo0?ooooooooooo`06ooooo`03
ool0oooooooooooo00Oooooo00?oo`3oooooooooool01_ooool00ooo0?ooooooooooo`08ooooo`03
ool0oooooooooooo00Cooooo00?oo`3oooooooooool0Ooooool00oo^k^ko0000olc<c00Iooooo`00
I?ooool00ooo0?ooooooooooo`05ooooo`03ool0oooooooooooo00Sooooo00?oo`3oooooooooool0
1Oooool00ooo0?ooooooooooo`07ooooo`03ool0oooooooooooo00Kooooo00?oo`3oooooooooool0
0_ooool00ol0003oooooooooo`02ooooo`03ool0oooooooooooo00Kooooo00?oo`3oooooooooool0
1oooool00ooo0?ooooooooooo`06ooooo`03ool0oooooooooooo00Sooooo00?oo`3oooooooooool0
1?ooool00ooo0?ooooooooooo`1eooooo`03ob4Q8OoMgMgooooo00Oooooo00?oMgMgo`000?mVIVH0
6Oooool005Cooooo1?oo0?l<ooooo`03ool0oooooooooooo00Gooooo00?oo`3oooooooooool02?oo
ool00ooo0?ooooooooooo`05ooooo`03ool0oooooooooooo00Oooooo00?oo`3oooooooooool01ooo
ool01Ooo0?oooooooooooooooooo000000Cooooo00?oo`3oooooooooool01_ooool00ooo0?oooooo
ooooo`07ooooo`03ool0oooooooooooo00Kooooo00?oo`3oooooooooool02?ooool00ooo0?oooooo
ooooo`04ooooo`03ool0oooooooooooo00[ooooo1?oo0?mOooooo`;o00000_ooool2o`0000;ooooo
00?oV9RHoeEEEOooool01_ooool01?o^k^ko0000oiRHV?lQ8B44ooooo`Go00001Oooool01_nHV9So
0000o`000?mgMgOo410@o`0000Gooooo001Cooooo`;oo`3o0oooool2ool0o`[ooooo00?oo`3ooooo
ooooool01_ooool00ooo0?ooooooooooo`07ooooo`03ool0oooooooooooo00Gooooo00?oo`3ooooo
ooooool01oooool00ooo0?ooooooooooo`07ooooo`05ool0ooooooooooooooooool000001?ooool0
0ooo0?ooooooooooo`06ooooo`03ool0oooooooooooo00Oooooo00?oo`3oooooooooool01_ooool0
0ooo0?ooooooooooo`07ooooo`03ool0oooooooooooo00Kooooo00?oo`3oooooooooool02?ooool2
ool0o`?ooooo00?oo`3oooooooooool0G?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@?ooooo
00?o0000omgMgOooool01Oooool01OmgMgOoEEEEooooool0003ogMgM00?ooooo00GoV9RHob4Q8Oo^
k^koooooodA4A005ooooo`05o`000?o<c<cok^k^ohN7Qol000001_ooool0057ooooo0_oo0?l6oooo
o`03ool0oooooooooooo00Oooooo00?oo`3oooooooooool01oooool00ooo0?ooooooooooo`06oooo
o`03ool0oooooooooooo00Kooooo00?oo`3oooooooooool01oooool00ooo0?ooooooooooo`07oooo
o`05ool0ooooooooooooooooool000001?ooool00ooo0?ooooooooooo`06ooooo`03ool0oooooooo
oooo00Oooooo00?oo`3oooooooooool01_ooool00ooo0?ooooooooooo`07ooooo`03ool0oooooooo
oooo00Kooooo00?oo`3oooooooooool01oooool00ooo0?ooooooooooo`04ooooo`;oo`3oGOooool0
1?oMgMgo0000oa0@4?o<c<`4ooooo`;oMgMg1_ooool01Ol0003oc<c<oooooomEEEGoQhN700Cooooo
00?oV9RHob4Q8Oo^k^h01_ooool01Ol@413oQhN7ooooooo^k^ko000000Kooooo0007o`0004;oo`3o
1ol000000ooo0?oo0000o`000006o`000003ool0ool0003o000000Oo000000?oo`3oo`000?l00000
1ol000000ooo0?oo0000o`000006o`000003ool0ool0003o000000Ko000000?oo`3oo`000?l00000
1ol000000ooo0?oo0000o`000007o`000003ool0ool0003o000000Ko000000?oo`3oo`000?l00000
1_l000000ooo0?oo0000o`000007o`000003ool0ool0003o000000Oo000000?oo`3oo`000?l00000
1_l000000ooo0?oo0000o`000006o`000003ool0ool0003o000000Oo000000?oo`3oo`000?l00000
1_l000000ooo0?oo0000o`000005o`0004?oo`3o1ol0000;ooooo`04onk^k_lQ8B7o410@onk^kPCo
oooo00?ok^k^oa0@4?o^k^h00oooool00olb<S;oEEEEoc8b<P02ooooo`03ojVYZOlQ8B7ooooo00Co
oooo00?oV9RHob4Q8Oo^k^h01Oooool00onj^[[o410@o`000002o`0000Kooooo0007ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo00?ooooo1_l00007ool0o`[ooooo00?oo`3oooooooooool01?ooool00ol0003ooooo
ool0o`09ooooo`03ool0oooooooooooo00?ooooo00Co0000ooooooooooooo`3o2?ooool00ooo0?oo
ooooooooo`03ooooo`05o`000?oooooooooooooooooo0?l02Oooool01Ooo0?oooooooooooooooooo
000000Cooooo00?oo`3oooooooooool01_ooool01Ooo0?oooooooooooooooooo000000Gooooo00?o
o`3oooooooooool01oooool00ooo0?ooooooo`000006ooooo`03ool0oooooooooooo00Kooooo00?o
o`3oooooool000001oooool00ooo0?ooooooooooo`07ooooo`Ooo`3o2Ol00002ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo013ooooo00Co8B4QogMgMomgMgOo<S8b1Oooool00omEEEGoV9RHooooo`02ooooo`03okZj
^_lb<S;o^[Zj00?ooooo00?o0000omgMgOooool01?ooool00omgMgOoIVIVooooo`07ooooo`03olc<
c?l0003ooooo00Gooooo0007ooooo`03o`000?oooooooooo04Gooooo0ol00009ooooo`03ool0oooo
oooooooo00Gooooo00?oo`3oooooooooool01oooool00ooo0?ooooooooooo`06ooooo`03ool0oooo
oooooooo00Kooooo00?oo`3oooooooooool01oooool00ooo0?ooooooooooo`07ooooo`05ool0oooo
ooooooooooooool000001?ooool00ooo0?ooooooooooo`06ooooo`03ool0oooooooooooo00Oooooo
00?oo`3oooooooooool01oooool00ooo0?ooooooooooo`06ooooo`03ool0oooooooooooo00Oooooo
00?oo`3oooooooooool01Oooool00ooo0?ooooooooooo`07ooooo`Ko0000A?ooool00ol0003ooooo
ooooo`0?ooooo`;o00000_ooool2o`0000Cooooo00?ogMgMoa0@4?ooool02?ooool00omEEEGoQhN7
ooooo`05ooooo`03o`000?oooooooooo00Cooooo00Co<S8bo`000?l0003oV9RH1_ooool005;ooooo
1_l00003ooooo`03ool0oooooooooooo00Cooooo00?oo`3oooooooooool02?ooool00ooo0?oooooo
ooooo`06ooooo`03ool0oooooooooooo00Oooooo00?oo`3oooooooooool01_ooool00ooo0?oooooo
ooooo`07ooooo`05ool0ooooooooooooooooool000001?ooool00ooo0?ooooooooooo`06ooooo`03
ool0oooooooooooo00Oooooo00?oo`3oooooooooool01oooool00ooo0?ooooooooooo`06ooooo`03
ool0oooooooooooo00Oooooo00?oo`3oooooooooool01?ooool00ooo0?ooooooooooo`04ooooo`Co
0000Ioooool00omEEEGoV9RHooooo`07ooooo`09ojVYZOlb<S;oooooooooool0003o^[ZjoooooonH
V9So410@013ooooo001Hooooo`;o00000_ooool00ooo0?ooooooooooo`03ooooo`03ool0oooooooo
oooo00Sooooo00?oo`3oooooooooool01_ooool00ooo0?ooooooooooo`07ooooo`03ool0oooooooo
oooo00Kooooo00?oo`3oooooooooool01oooool01Ooo0?oooooooooooooooooo000000Cooooo00?o
o`3oooooooooool01oooool00ooo0?ooooooooooo`06ooooo`03ool0oooooooooooo00Oooooo00?o
o`3oooooooooool01Oooool00ooo0?ooooooooooo`09ooooo`03ool0oooooooooooo00?ooooo00Co
o`3ooooooooooooooooo0ol0001[ooooo`03okZj^_m4A4Cooooo00Oooooo00Wok^k^o`000?o^k^ko
oooooiRHV?l@413o0000ob4Q8Oo<c<`04?ooool005[ooooo00?o0000oooooooo0?l01Oooool00ooo
0?ooooooooooo`08ooooo`03ool0oooooooooooo00Kooooo00?oo`3oooooooooool01oooool00ooo
0?ooooooooooo`06ooooo`03ool0oooooooooooo00Oooooo00Goo`3oooooooooooooooooo`000004
ooooo`03ool0oooooooooooo00Oooooo00?oo`3oooooooooool01_ooool00ooo0?ooooooooooo`07
ooooo`03ool0oooooooooooo00Gooooo00?oo`3oooooooooool02Oooool00ooo0?ooooooooooo`02
ooooo`03ool0oooooooo000000;o0000NOooool00om4A4CoV9RHooooo`0Eooooo`00Foooool00ol0
003oo`3oooooo`04ooooo`03ool0oooooooooooo00Sooooo00?oo`3oooooooooool01_ooool00ooo
0?ooooooooooo`07ooooo`03ool0oooooooooooo00Kooooo00?oo`3oooooooooool01oooool01Ooo
0?oooooooooooooooooo000000Cooooo00?oo`3oooooooooool01oooool00ooo0?ooooooooooo`06
ooooo`03ool0oooooooooooo00Oooooo00?oo`3oooooooooool01Oooool00ooo0?ooooooooooo`09
ooooo`05ool0oooooooooooooooooooo0?l00_l0001looooo`03oiRHV?m4A4Cooooo01Gooooo001M
ooooo`;oo`3o0_ooool00ooo0?ooooooooooo`09ooooo`03ool0oooooooooooo00Kooooo00?oo`3o
ooooooooool01oooool00ooo0?ooooooooooo`06ooooo`03ool0oooooooooooo00Oooooo00Goo`3o
ooooooooooooooooo`000004ooooo`03ool0oooooooooooo00Oooooo00?oo`3oooooooooool01_oo
ool00ooo0?ooooooooooo`07ooooo`03ool0oooooooooooo00Gooooo00?oo`3oooooooooool02Ooo
ool2ool0o`;ooooo00?oo`3oooooooooool0O?ooool00oo^k^ko0000o`000009o`0000cooooo001N
ooooo`Coo`3o2oooool00ooo0?ooooooooooo`06ooooo`03ool0oooooooooooo00Oooooo00?oo`3o
ooooooooool01_ooool00ooo0?ooooooooooo`07ooooo`04ool0ooooooooooooooooo`;o00000ooo
ool00ooo0?ooooooooooo`07ooooo`03ool0oooooooooooo00Kooooo00?oo`3oooooooooool01ooo
ool00ooo0?ooooooooooo`05ooooo`03ool0oooooooooooo00[ooooo0ooo0?nGooooo`00H?ooool0
0ol0003oooooooooo`0;ooooo`03ool0oooooooooooo00Gooooo00?oo`3oooooooooool01oooool0
0ooo0?ooooooooooo`06ooooo`03ool0oooooooooooo00Oooooo00Goo`3oooooooooooooooooo`00
0004ooooo`03ool0oooooooooooo00Oooooo00?oo`3oooooooooool01_ooool00ooo0?oooooooooo
o`07ooooo`03ool0oooooooooooo00Gooooo00?oo`3oooooooooool02oooool00ol0003ooooooooo
o`2Fooooo`00HOooool2o`0000_ooooo00?oo`3oooooooooool01Oooool00ooo0?ooooooooooo`07
ooooo`03ool0oooooooooooo00Kooooo00?oo`3oooooooooool01oooool01Ooo0?oooooooooooooo
oooo000000Cooooo00?oo`3oooooooooool01oooool00ooo0?ooooooooooo`05ooooo`03ool0oooo
oooooooo00Sooooo00?oo`3oooooooooool01Oooool00ooo0?ooooooooooo`0:ooooo`03o`000?oo
oooooooo09Oooooo001Sooooo`03o`000?oooooooooo00Sooooo00?oo`3oooooooooool01Oooool0
0ooo0?ooooooooooo`07ooooo`03ool0oooooooooooo00Gooooo00?oo`3oooooooooool02?ooool0
1Ooo0?oooooooooooooooooo000000Cooooo00?oo`3oooooooooool01oooool00ooo0?oooooooooo
o`05ooooo`03ool0oooooooooooo00Sooooo00?oo`3oooooooooool01?ooool00ooo0?oooooooooo
o`09ooooo`;o0000V_ooool006Cooooo00?o0000ooooooooool01oooool00ooo0?ooooooooooo`04
ooooo`03ool0oooooooooooo00Sooooo00?oo`3oooooooooool01Oooool00ooo0?ooooooooooo`08
ooooo`05ool0ooooooooooooooooool000000oooool00ooo0?ooooooooooo`08ooooo`03ool0oooo
oooooooo00Gooooo00?oo`3oooooooooool02?ooool00ooo0?ooooooooooo`04ooooo`03ool0oooo
oooooooo00Sooooo00?o0000ooooooooool0V_ooool006Cooooo00?o0000ooooooooool01oooool0
0ooo0?ooooooooooo`04ooooo`03ool0oooooooooooo00Sooooo00?oo`3oooooooooool01Oooool0
0ooo0?ooooooooooo`08ooooo`05ool0ooooooooooooooooool000000oooool00ooo0?oooooooooo
o`08ooooo`03ool0oooooooooooo00Gooooo00?oo`3oooooooooool02?ooool00ooo0?oooooooooo
o`04ooooo`03ool0oooooooooooo00Oooooo00?o0000ooooooooool0Voooool006Gooooo00?o0000
ooooooooool01_ooool00ooo0?ooooooooooo`04ooooo`03ool0oooooooooooo00Sooooo00?oo`3o
ooooooooool01Oooool00ooo0?ooooooooooo`08ooooo`05ool0ooooooooooooooooool000000ooo
ool00ooo0?ooooooooooo`08ooooo`03ool0oooooooooooo00Gooooo00?oo`3oooooooooool02?oo
ool00ooo0?ooooooooooo`04ooooo`03ool0oooooooooooo00Kooooo00?o0000ooooooooool0W?oo
ool006Kooooo00?o0000ooooooooool01Oooool00ooo0?ooooooooooo`04ooooo`03ool0oooooooo
oooo00Sooooo00?oo`3oooooooooool01Oooool00ooo0?ooooooooooo`08ooooo`05ool0oooooooo
ooooooooool000000oooool00ooo0?ooooooooooo`08ooooo`03ool0oooooooooooo00Gooooo00?o
o`3oooooooooool02?ooool00ooo0?ooooooooooo`04ooooo`03ool0oooooooooooo00Gooooo00?o
0000ooooooooool0WOooool006Oooooo00?o0000ooooooooool01?ooool00ooo0?ooooooooooo`04
ooooo`03ool0oooooooooooo00Sooooo00?oo`3oooooooooool01Oooool00ooo0?ooooooooooo`08
ooooo`05ool0ooooooooooooooooool000000oooool00ooo0?ooooooooooo`08ooooo`03ool0oooo
oooooooo00Gooooo00?oo`3oooooooooool02?ooool00ooo0?ooooooooooo`04ooooo`03ool0oooo
oooooooo00Cooooo00?o0000ooooooooool0W_ooool006Oooooo00?o0000ooooooooool01?ooool0
0ooo0?ooooooooooo`04ooooo`03ool0oooooooooooo00Sooooo00?oo`3oooooooooool01Oooool0
0ooo0?ooooooooooo`08ooooo`04ool0ooooooooooooooooo`;o00000_ooool00ooo0?oooooooooo
o`08ooooo`03ool0oooooooooooo00Gooooo00?oo`3oooooooooool02?ooool00ooo0?oooooooooo
o`04ooooo`03ool0oooooooooooo00Cooooo00?o0000ooooooooool0W_ooool006Sooooo00?o0000
ooooooooool01?ooool00ooo0?ooooooooooo`03ooooo`03ool0oooooooooooo00Sooooo00?oo`3o
ooooooooool01Oooool00ooo0?ooooooooooo`08ooooo`05ool0ooooooooooooooooool000000ooo
ool00ooo0?ooooooooooo`08ooooo`03ool0oooooooooooo00Gooooo00?oo`3oooooooooool02Ooo
ool00ooo0?ooooooooooo`03ooooo`03ool0oooooooooooo00?ooooo00?o0000ooooooooool0Wooo
ool006Wooooo00?o0000ooooooooool00oooool00ooo0?ooooooooooo`03ooooo`03ool0oooooooo
oooo00Sooooo00?oo`3oooooooooool01Oooool00ooo0?ooooooooooo`08ooooo`05ool0oooooooo
ooooooooool000000oooool00ooo0?ooooooooooo`08ooooo`03ool0oooooooooooo00Gooooo00?o
o`3oooooooooool02Oooool00ooo0?ooooooooooo`02ooooo`03ool0oooooooooooo00?ooooo00?o
0000ooooooooool0X?ooool006[ooooo00?o0000ooooooooool00_ooool00ooo0?ooooooooooo`03
ooooo`03ool0oooooooooooo00Sooooo00?oo`3oooooooooool01Oooool00ooo0?ooooooooooo`08
ooooo`05ool0ooooooooooooooooool000000oooool00ooo0?ooooooooooo`08ooooo`03ool0oooo
oooooooo00Gooooo00?oo`3oooooooooool02Oooool00ooo0?ooooooooooo`02ooooo`03ool0oooo
oooooooo00;ooooo00?o0000ooooooooool0XOooool006[ooooo00?o0000ooooooooool00_ooool0
0ooo0?ooooooooooo`02ooooo`03ool0oooooooooooo00Wooooo00?oo`3oooooooooool01Oooool0
0ooo0?ooooooooooo`08ooooo`05ool0ooooooooooooooooool000000oooool00ooo0?oooooooooo
o`08ooooo`03ool0oooooooooooo00Gooooo00?oo`3oooooooooool02Oooool00ooo0?oooooooooo
o`02ooooo`03ool0oooooooooooo00;ooooo00?o0000ooooooooool0XOooool006_ooooo00Go0000
ooooooooooooooooool0o`04ooooo`03ool0oooooooooooo00Wooooo00?oo`3oooooooooool01Ooo
ool00ooo0?ooooooooooo`08ooooo`05ool0ooooooooooooooooool000000oooool00ooo0?oooooo
ooooo`08ooooo`03ool0oooooooooooo00Gooooo00?oo`3oooooooooool02Oooool00ooo0?oooooo
ooooo`02ooooo`05ool0ooooooooooooooooool00000Y?ooool006cooooo00Go0000oooooooooooo
ooooool0o`03ooooo`03ool0oooooooooooo00Wooooo00?oo`3oooooooooool01Oooool00ooo0?oo
ooooooooo`08ooooo`05ool0ooooooooooooooooool000000oooool00ooo0?ooooooooooo`08oooo
o`03ool0oooooooooooo00Gooooo00?oo`3oooooooooool02_ooool01Ooo0?oooooooooooooooooo
o`3o00;ooooo00?o0000ooooooooool0Xoooool006gooooo00Co0000ooooooooooooo`3o0oooool0
0ooo0?ooooooooooo`09ooooo`03ool0oooooooooooo00Gooooo00?oo`3oooooooooool02?ooool0
1Ooo0?oooooooooooooooooo000000?ooooo00?oo`3oooooooooool02?ooool00ooo0?oooooooooo
o`05ooooo`03ool0oooooooooooo00[ooooo00Ooo`3oooooooooooooooooool0oooooooo00000:Ko
oooo001]ooooo`04o`000?ooooooooooool0o`?ooooo00?oo`3oooooooooool02_ooool00ooo0?oo
ooooooooo`04ooooo`03ool0oooooooooooo00Sooooo00Coo`3ooooooooooooooooo0_l00002oooo
o`03ool0oooooooooooo00Sooooo00?oo`3oooooooooool01Oooool00ooo0?ooooooooooo`0:oooo
o`07ool0oooooooooooooooooooo0?ooooooo`00002Vooooo`00K_ooool00ol0003oooooool0o`02
ooooo`03ool0oooooooooooo00_ooooo00?oo`3oooooooooool01?ooool00ooo0?ooooooooooo`09
ooooo`04ool0ooooooooooooo`0000?ooooo00?oo`3oooooooooool02?ooool00ooo0?oooooooooo
o`05ooooo`03ool0oooooooooooo00[ooooo00Koo`3oooooooooooooo`3oooooool0002Wooooo`00
Koooool01Ol0003oooooool0ooooooooo`3o00gooooo00?oo`3oooooooooool01?ooool00ooo0?oo
ooooooooo`09ooooo`04ool0ooooooooooooo`0000?ooooo00?oo`3oooooooooool02?ooool00ooo
0?ooooooooooo`05ooooo`03ool0oooooooooooo00[ooooo00Goo`3oooooooooooooo`3oo`00002X
ooooo`00Koooool01Ol0003oooooool0ooooooooo`3o00gooooo00?oo`3oooooooooool01?ooool0
0ooo0?ooooooooooo`09ooooo`04ool0ooooooooooooo`0000?ooooo00?oo`3oooooooooool02?oo
ool00ooo0?ooooooooooo`05ooooo`03ool0oooooooooooo00[ooooo00Goo`3oooooooooooooo`3o
o`00002Xooooo`00L?ooool01?l0003oo`3ooooooooo0?l=ooooo`03ool0oooooooooooo00Cooooo
00?oo`3oooooooooool02Oooool01?oo0?ooooooooooool00003ooooo`03ool0oooooooooooo00So
oooo00?oo`3oooooooooool01Oooool00ooo0?ooooooooooo`0:ooooo`04ool0ooooooooooooool0
ojWooooo001aooooo`03ool0ooooooooo`3o00Sooooo00Kok^k^oc8b<_l0003o<S8bonk^k_oo0?l4
ooooo`;o8B4Q00Coo`3ooooooooooooooooo1Ol00003ooooo`04ool0ooooooooooooo`0000?ooooo
00?oo`3oooooooooool02?ooool00ooo0?ooooooooooo`05ooooo`03ool0oooooooooooo00_ooooo
0_oo0?l00ol0003oooooooooo`2Wooooo`00LOooool3ool0o`Sooooo00KoMgMgoiRHV?ooooooV9RH
ogMgMooo0?l4ooooo`;o8B4Q00Woo`3ooooooooooooooooooiRHV?lQ8B7ok^k^oooooom4A4@00ooo
ool01?oo0?ooooooooooool00003ooooo`03ool0oooooooooooo00Sooooo00?oo`3oooooooooool0
1Oooool00ooo0?ooooooooooo`0;ooooo`;oo`3oZ_ooool007;ooooo00?o0000ooooooooool01ooo
ool01_l@413ooooooooooooooooo410@ool0o`Kooooo00?oo`3oooooooooool00_ooool00onHV9So
8B4Qonk^kP04ooooo`04ool0ooooooooooooo`0000?ooooo00?oo`3oooooooooool02Oooool00ooo
0?ooooooooooo`04ooooo`03ool0oooooooooooo00_ooooo00?oo`3oooooooooool0ZOooool007;o
oooo00?o0000ooooooooool01oooool01_l0003ooooooooooooooooo0000ool0o`Kooooo00?oo`3o
ooooooooool00oooool00onHV9So8B4Qonk^kP03ooooo`03ool0oooooooooooo00?o000000?ooooo
ool0ooooool02_ooool00ooo0?ooooooooooo`04ooooo`03ool0oooooooooooo00_ooooo00?o0000
ooooooooool0ZOooool007?ooooo00?o0000ooooooooool01_ooool01_l0003ooooooooooooooooo
0000ool0o`Kooooo00?oo`3oooooooooool01?ooool00omgMgOoIVIVooooo`02ooooo`04ool0oooo
ooooooooo`0000;ooooo00?oo`3oooooooooool02_ooool00ooo0?ooooooooooo`03ooooo`03ool0
oooooooooooo00_ooooo00?o0000ooooooooool0Z_ooool007Cooooo00?o0000ooooooooool01Ooo
ool01_l@413ooooooooooooooooo410@ool0o`Kooooo00?oo`3oooooooooool01Oooool01Ol0003o
ooooooooooooooooo`3o00;ooooo00Co0000ooooooooooooo`3o3?ooool00ooo0?ooooooooooo`03
ooooo`03ool0oooooooooooo00_ooooo00?o0000ooooooooool0Z_ooool007Cooooo00?o0000oooo
ooooool01Oooool01_mgMgOoV9RHoooooonHV9SoMgMgool0o`Kooooo00Woo`3ooooooooooooooooo
o`000?nj^[[ooooooiRHV?l@41000oooool01?oo0?ooooooooooool00002ooooo`03ool0oooooooo
oooo00[ooooo00?oo`3oooooooooool00oooool00ooo0?ooooooooooo`0:ooooo`03o`000?oooooo
oooo0:_ooooo001eooooo`03o`000?oooooooooo00Cooooo00Kok^k^oc8b<_l0003o<S8bonk^k_oo
0?l5ooooo`03ool0oooooooooooo00;ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`04ool0
ooooooooooooo`0000;ooooo00?oo`3oooooooooool02_ooool00ooo0?ooooooooooo`03ooooo`03
ool0oooooooooooo00[ooooo00?o0000ooooooooool0Zoooool007Gooooo00?o0000ooooooooool0
2Oooool00ooo0?ooooooooooo`03ooooo`03ool0oooooooooooo00[ooooo00Coo`3ooooooooooooo
00000_ooool00ooo0?ooooooooooo`0:ooooo`03ool0oooooooooooo00?ooooo00?oo`3ooooooooo
ool02Oooool00ol0003oooooooooo`2/ooooo`00M_ooool00ol0003oooooooooo`08ooooo`03ool0
oooooooooooo00?ooooo00?oo`3oooooooooool02_ooool01?oo0?ooooooooooool00002ooooo`03
ool0oooooooooooo00[ooooo00?oo`3oooooooooool00oooool00ooo0?ooooooooooo`09ooooo`03
o`000?oooooooooo0:cooooo001fooooo`03o`000?oooooooooo00Wooooo00?oo`3oooooooooool0
0_ooool00ooo0?ooooooooooo`0:ooooo`04ool0ooooooooooooo`0000;ooooo00?oo`3ooooooooo
ool02_ooool00ooo0?ooooooooooo`03ooooo`03ool0oooooooooooo00Wooooo00?o0000oooooooo
ool0[?ooool007Oooooo00?o0000ooooooooool02?ooool00ooo0?ooooooooooo`02ooooo`03ool0
oooooooooooo00[ooooo00?oo`3oooooooooool00_l000000oooooooo`3oooooo`0;ooooo`03ool0
oooooooooooo00?ooooo00?oo`3oooooooooool02?ooool00ol0003oooooooooo`2]ooooo`00Mooo
ool00ol0003oooooooooo`08ooooo`03ool0oooooooooooo00;ooooo00?oo`3oooooooooool02_oo
ool01?oo0?ooooooooooool00002ooooo`03ool0oooooooooooo00[ooooo00?oo`3oooooooooool0
0oooool00ooo0?ooooooooooo`08ooooo`03o`000?oooooooooo0:gooooo001gooooo`03o`000?oo
oooooooo00Sooooo00?oo`3oooooooooool00_ooool00ooo0?ooooooooooo`0:ooooo`04ool0oooo
ooooooooo`0000;ooooo00?oo`3oooooooooool02_ooool00ooo0?ooooooooooo`03ooooo`03ool0
oooooooooooo00Oooooo00?o0000ooooooooool0[_ooool007Sooooo00?o0000ooooooooool01ooo
ool00ooo0?ooooooooooo`02ooooo`03ool0oooooooooooo00[ooooo00Coo`3ooooooooooooo0000
0_ooool00ooo0?ooooooooooo`0:ooooo`03ool0oooooooooooo00?ooooo00?oo`3oooooooooool0
1oooool00ol0003oooooooooo`2^ooooo`00N?ooool00ol0003oooooooooo`07ooooo`03ool0oooo
oooooooo00;ooooo00?oo`3oooooooooool02_ooool01?oo0?ooooooooooool00002ooooo`03ool0
oooooooooooo00[ooooo00?oo`3oooooooooool00oooool00ooo0?ooooooooooo`06ooooo`03o`00
0?oooooooooo0:oooooo001iooooo`03o`000?oooooooooo00Kooooo00?oo`3oooooooooool00_oo
ool00ooo0?ooooooooooo`0:ooooo`04ool0ooooooooooooo`0000;ooooo00?oo`3oooooooooool0
2_ooool00ooo0?ooooooooooo`03ooooo`03ool0oooooooooooo00Kooooo00?o0000ooooooooool0
[oooool007Wooooo00?o0000ooooooooool01_ooool00ooo0?ooooooooooo`02ooooo`03ool0oooo
oooooooo00[ooooo00Coo`3ooooooooooooo00000_ooool00ooo0?ooooooooooo`0:ooooo`03ool0
oooooooooooo00?ooooo00?oo`3oooooooooool01Oooool00ol0003oooooooooo`2`ooooo`00N_oo
ool00ol0003oooooooooo`05ooooo`03ool0oooooooooooo00;ooooo00?oo`3oooooooooool02_oo
ool01?oo0?ooooooooooool00002ooooo`03ool0oooooooooooo00_ooooo00Goo`3ooooooooooooo
ooooool0o`08ooooo`03o`000?oooooooooo0;3ooooo001jooooo`03o`000?oooooooooo00Gooooo
00?oo`3oooooooooool00_ooool00ooo0?ooooooooooo`0:ooooo`03ool0oooooooooooo00;o0000
00?oooooool0ooooool03?ooool01Ooo0?ooooooooooooooooooo`3o00Sooooo00?o0000oooooooo
ool0/?ooool007_ooooo00?o0000ooooooooool01?ooool00ooo0?ooooooooooo`02ooooo`03ool0
oooooooooooo00[ooooo00Coo`3ooooooooooooo00000_ooool00ooo0?ooooooooooo`0;ooooo`05
ool0oooooooooooooooooooo0?l01oooool00ol0003oooooooooo`2aooooo`00Noooool00ol0003o
ooooooooo`04ooooo`03ool0oooooooooooo00;ooooo00?oo`3oooooooooool02_ooool01?oo0?oo
ooooooooool00002ooooo`03ool0oooooooooooo00_ooooo00Goo`3oooooooooooooooooool0o`07
ooooo`03o`000?oooooooooo0;7ooooo001looooo`03o`000?oooooooooo00?ooooo00?oo`3ooooo
ooooool00_ooool00ooo0?ooooooooooo`0:ooooo`04ool0ooooooooooooo`0000;ooooo00?oo`3o
ooooooooool02oooool01Ooo0?ooooooooooooooooooo`3o00Kooooo00?o0000ooooooooool0/_oo
ool007cooooo00?o0000ooooooooool01?ooool01?oo0?oooooooooooooo0?l=ooooo`04ool0oooo
ooooooooo`0000;ooooo00?oo`3oooooooooool02oooool01Ooo0?ooooooooooooooooooo`3o00Ko
oooo00?o0000ooooooooool0/_ooool007gooooo00?o0000ooooooooool00oooool01?oo0?oooooo
oooooooo0?l>ooooo`03ool0oooooooo000000;ooooo00?oo`3oooooooooool02oooool01Ooo0?oo
ooooooooooooooooo`3o00Gooooo00?o0000ooooooooool0/oooool007gooooo00?o0000oooooooo
ool00oooool01?oo0?oooooooooooooo0?l>ooooo`05ool0oooooooo0000oooooooo0?l03_ooool0
1Ooo0?ooooooooooooooooooo`3o00Gooooo00?o0000ooooooooool0/oooool007gooooo00?o0000
ooooooooool00oooool01?oo0?oooooooooooooo0?l>ooooo`05ool0oooooooo0000oooooooo0?l0
3_ooool01Ooo0?ooooooooooooooooooo`3o00Cooooo00?o0000ooooooooool0]?ooool007kooooo
00?o0000ooooooooool00_ooool01?oo0?oooooooooooooo0?l>ooooo`05ool0oooooooo0000o`00
0?oo0?l03_ooool01Ooo0?ooooooooooooooooooo`3o00Cooooo00?o0000ooooooooool0]?ooool0
07kooooo00?o0000ooooooooool00_ooool01?oo0?oooooooooooooo0?l>ooooo`05ool0oooooooo
0000oooooooo0?l03_ooool01Ooo0?ooooooooooooooooooo`3o00Cooooo00?o0000ooooooooool0
]?ooool007oooooo00Go0000ooooooooooooooooool0o`02ooooo`03ool0oooooooooooo00cooooo
00Goo`3oooooool0003oooooool0o`0>ooooo`04ool0ooooooooooooool0o`Cooooo00?o0000oooo
ooooool0]Oooool007oooooo00Go0000ooooooooooooooooool0o`02ooooo`03ool0oooooooooooo
00cooooo00Goo`3oooooool0003oooooool0o`0>ooooo`04ool0ooooooooooooool0o`Cooooo00?o
0000ooooooooool0]Oooool0083ooooo00Co0000ooooooooooooo`3o0_ooool00ooo0?oooooooooo
o`0<ooooo`05ool0oooooooo0000oooooooo0?l03_ooool01?oo0?oooooooooooooo0?l3ooooo`03
o`000?oooooooooo0;Kooooo0020ooooo`04o`000?ooooooooooool0o`;ooooo00?oo`3ooooooooo
ool03?ooool01Ooo0?ooooooo`000?ooooooo`3o00kooooo00Coo`3oooooooooooooo`3o0oooool0
0ol0003oooooooooo`2fooooo`00O?ooool02?o^k^ko<S8bo`000?lb<S;ok^k^o`000?ooooooo`3o
0_ooool00ooo0?oo8B4Qooooo`05ooooo`;o000000?o410@ooooooooool00_ooool01Ooo0?oooooo
o`000?ooooooo`3o00kooooo00Coo`3oooooooooooooo`3o0_ooool00ol0003oooooooooo`2goooo
o`00O?ooool02?mgMgOoV9RHoooooonHV9SoMgMgo`000?ooooooo`3o0_ooool00ooo0?oo8B4Qoooo
o`06ooooo`03o`000?oooooooooo00?ooooo00Goo`3oooooool0003oooooool0o`0>ooooo`04ool0
ooooooooooooool0o`;ooooo00?o0000ooooooooool0]oooool007cooooo00_o410@oooooooooooo
oooooa0@4?oooooo0000oooooooo0?ooooooool0o`05ooooo`Go00001?ooool01Ooo0?ooooooo`00
0?ooooooo`3o00oooooo00Goo`3ooooooooo0?ooooooo`00002jooooo`00O?ooool02ol0003ooooo
oooooooooooo0000ooooool0003oooooool0ooooooooo`3o00Gooooo00CoA4A4omgMgOoooooo0000
1Oooool01Ooo0?ooooooo`000?l0003oo`3o00oooooo00Goo`3ooooooooo0?ooooooo`00002joooo
o`00O?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000ool0ooooooooo`3o1Oooool0
1?oMgMgoEEEEooooool00005ooooo`05ool0oooooooo0000oooooooo0?l03oooool01?oo0?oooooo
ool0ool0002kooooo`00O?ooool01Ol@413ooooooooooooooooo410@00;ooooo00Co0000ool0oooo
ooooo`3o1_ooool00omgMgOoc<c<o`000005ooooo`05ool0oooooooo0000oooooooo0?l03oooool0
0ooo0?ooooooool0o`2looooo`00O?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00;ooooo00?o0000
ool0oooo0?l01oooool00oo^k^koA4A4o`000005ooooo`05ool0oooooooo0000oooooooo0?l03ooo
ool00ooo0?ooooooool0o`2looooo`00O?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo0_oo
0?l8ooooo`03ogMgMol0003ooooo00Cooooo00Goo`3oooooool0003oooooool0o`0?ooooo`;oo`3o
_Oooool008Cooooo00?o0000ool0ooooool03_ooool01Ooo0?ooooooo`000?ooooooo`3o013ooooo
00?oo`3oooooooooool0^oooool008Gooooo00?o0000ooooooooool03Oooool01Ooo0?ooooooo`00
0?ooooooo`3o00oooooo00?o0000ooooooooool0_?ooool008Gooooo00?o0000ooooooooool03Ooo
ool01Ooo0?ooooooo`000?ooooooo`3o00oooooo00?o0000ooooooooool0_?ooool008Kooooo00?o
0000ooooooooool03?ooool01Ooo0?ooooooo`000?l0003oo`3o00kooooo00?o0000ooooooooool0
_Oooool008Kooooo00?o0000ooooooooool03?ooool01Ooo0?ooooooo`000?ooooooo`3o00kooooo
00?o0000ooooooooool0_Oooool008Oooooo00?o0000ooooooooool02oooool01?oo0?ooooooo`00
0?oo0?l>ooooo`03o`000?oooooooooo0;kooooo0027ooooo`03o`000?oooooooooo00_ooooo00Co
o`3oooooool0003oo`3o3_ooool00ol0003oooooooooo`2nooooo`00R?ooool00ol0003ooooooooo
o`0:ooooo`04ool0oooooooo0000ool0o`gooooo00?o0000ooooooooool0_oooool008Sooooo00?o
0000ooooooooool02oooool00ooo0?oo0000ool0o`0<ooooo`03o`000?oooooooooo0<3ooooo0029
ooooo`03o`000?oooooooooo00[ooooo00?oo`3oo`000?oo0?l03?ooool00ol0003oooooooooo`30
ooooo`00ROooool00ol0003oooooooooo`0:ooooo`03ool0ool0003oo`3o00_ooooo00?o0000oooo
ooooool0`Oooool008[ooooo00?o0000ooooooooool02Oooool00ooo0?oo0000ool0o`0;ooooo`03
o`000?oooooooooo0<7ooooo002;ooooo`03o`000?oooooooooo00Sooooo00?oo`3oo`000?oo0?l0
2_ooool00ol0003oooooooooo`32ooooo`00S?ooool00ol0003oooooooooo`07ooooo`03ool0ool0
003oo`3o00[ooooo00?o0000ooooooooool0`_ooool008gooooo00?o0000ooooooooool01_ooool0
0ooo0?oo0000ool0o`09ooooo`03o`000?oooooooooo0<?ooooo002>ooooo`03o`000?oooooooooo
00Gooooo00?oo`3oo`000?oo0?l02?ooool00ol0003oooooooooo`34ooooo`00Soooool00ol0003o
ooooooooo`04ooooo`03ool0ool0003oo`3o00Oooooo00?o0000ooooooooool0aOooool008oooooo
00?o0000ooooooooool01?ooool00ooo0?oo0000ool0o`07ooooo`03o`000?oooooooooo0<Gooooo
002@ooooo`;o00001Oooool2ool0o`Kooooo00?o0000ooooooooool0a_ooool009;ooooo00?o0000
ooooooooool00_ooool2ool0o`Cooooo0_l00039ooooo`00T_ooool2o`0000?ooooo0_oo0?l3oooo
o`03o`000?oooooooooo0<Wooooo002Dooooo`?o00000_oo0?l3o`000<cooooo002Gooooo`03o`00
0?oooooooooo0<kooooo002Gooooo`03o`000?oooooooooo0<kooooo002Gooooo`03o`000?oooooo
oooo0<kooooo002Gooooo`03o`000?oooooooooo0<kooooo002Gooooo`03o`000?oooooooooo0<ko
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo001Looooo`03o`000?oooooooooo00;ooooo00?o^[Zjoc8b<_ooool01?oo
ool2o`0000Sooooo00?oMgMgofIVI_ooool02?ooool00omVIVKoMgMgooooo`08ooooo`03o`000?oo
oooooooo00?ooooo00?o0000okZj^_ooool05_ooool2ool0o`?ooooo00?ook[ooolbooooool01?oo
ool2ool0o`Oooooo0_oo0?l;ooooo`;oo`3o1_ooool2ool0oiGooooo001Looooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00006ooooo`03omgMgOl@
413ok^k^00Wooooo00?ok^k^oa0@4?oMgMd02?ooool00ol0003oooooooooo`03ooooo`;o<S8b5ooo
ool00ooo0?ooooooooooo`03ooooo`03ool0oooooooooooo00;ooooo00Coo`3oooooooooooooo`3o
1_ooool00ooo0?ooooooooooo`0;ooooo`03ool0oooooooooooo00Gooooo00?oo`3oooooooooool0
Toooool005cooooo00Ko0000oooooooooooooooooiRHV?l@4102o`000004ojVYZOooooooooooo`00
00;ooooo00?o0000ooooooooool01?ooool00omEEEGoV9RHooooo`02ooooo`;o00000_ooool2o`00
00;ooooo00?oQhN7ofIVI_ooool01oooool00ol0003oooooooooo`03ooooo`03ohN7Qol0003o^[Zj
00?ooooo0ooo0?l2ooooo`06oolboooo4?ooooooooooooook_oooeGo0_oo0?l00oooA?oook[ooooo
o`03ooooo`06ool0ooooooooooooooooooooV?oooa3o0_oo0?l01?ooZOoooooooooooooo0?l2oooo
o`03ool0oooooooooooo00Cooooo00?oo`3oooooooooool00_ooool2ool0o`;ooooo0_oo0?l3oooo
o`03ool0oooooooooooo00Gooooo00?oo`3oooooooooool0Toooool005cooooo00[o0000oooooooo
ooooooooo`000?nYZJWoEEEEoiRHV?mEEEGo^[Zj0_ooool2o`0000Oooooo00?o0000ooooooooool0
0_ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@;ooooo00?ok^k^o`000?ooool01oooool00ol0
003oooooooooo`03ooooo`03olc<c?l0003o410@00Cooooo00Goo`3oooooooooooooolcoool@o`03
ooooo`06oomEooooMoooooooooo^ooooMooooa3o1?ooool02_oo0?ooooooooooooooooooo`3ooonY
ooooEOoooiSooomEoooo^_l2ooooo`;oo`3o1oooool00ooo0?ooooooooooo`02ooooo`06ooo^oooo
8OooohOooonjoooo0?ooomgo0oooool00ooo0?ooooooooooo`05ooooo`03ool0oooooooooooo09?o
oooo001Looooo`0:o`000?oooooooooooooooolb<S;ok^k^oiRHV?mEEEGogMgMoa0@40_ooooo00?o
<S8booooooooool00oooool01?oMgMgo0000oa0@4?o<c<`4ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool02_ooool01Ooo0?ooooooooooooooEOooohOo00?ooooo00?oo`3ooooooooo
ool01oooool02_oo0?oooooooooooooooooooc;oooo^ooooV?oooeGooooMoooo4?l;ooooo`03ool0
oooooooooooo00?ooooo00Coomgoool0oooo4?ooolco1?ooool00ooo0?ooooooooooo`05ooooo`03
ool0oooooooooooo09?ooooo001Looooo`0;o`000?oooooooooooooooonj^[[oA4A4olc<c?lQ8B7o
oooooa0@4?o<c<`02_ooool00olb<S;oooooooooo`03ooooo`04onk^k_lQ8B7o410@onk^kPCooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`05ool0ooooooooomgoool0oooo
k_l00oooool6ool0o`Cooooo00_oo`3ooooooooooooooooooonjooooA?ooolcooolQoooooooooa3o
ooo<o`0:ooooo`03ool0oooooooooooo00?ooooo00CoonkooolQoooo4?ooonko1?ooool00ooo0?oo
ooooooooo`05ooooo`03ool0oooooooooooo09?ooooo001Looooo`0;o`000?ooooooooooooooooo^
k^ko0000ooooool0003oooooofIVI_n7QhL02_ooool00ol0003ok^k^ooooo`03ooooo`04ob4Q8Omg
MgOoMgMgoc8b<P?ooooo00?ok^k^o`000?ooool01oooool00ol0003oooooooooo`0:ooooo`?oo`3o
00?ooa3ooonHooooool00_ooool01_ooEOooohOoooo^ooooooooohOooolbo`Cooooo00_oo`3ooooo
ooooooooooooooo^oooo0?ooooooool0ooooooooofKooon7o`0:ooooo`03ool0oooooooooooo00?o
oooo00Coob7ooomgooooMooooc;o1?ooool00ooo0?ooooooooooo`05ooooo`03ool0oooooooooooo
09?ooooo001Looooo`08o`000?oooooooooooooooomVIVKoV9RHoooooolb<S82okZj^P03o`000?oo
oooooooo00Sooooo00?oEEEEogMgMoooool00_ooool2o`0000;ooooo0_l00002ooooo`03ogMgMomE
EEGooooo00Oooooo00?o0000ooooooooool02_ooool01Ooo0?ooooooooooooooc?ooo`3o00?ooooo
00KoonkooomEoooo0?ooo`3ooom4ooook_l4ooooo`08ool0ooooooooooooooooooooI_oooiSooooo
oooo<_l2oonjo`03ool0oooooooooooo00Sooooo00?oo`3oooooooooool00_ooool2ool0o`;ooooo
0_oo0?l3ooooo`03ool0oooooooooooo00Gooooo00?oo`3oooooooooool0Toooool005cooooo00?o
0000ooooooooool01?ooool00omVIVKoQhN7ooooo`0;ooooo`03omgMgOl@413ok^k^00Wooooo00?o
k^k^oa0@4?oMgMd02?ooool00ol0003oooooooooo`0:ooooo`05ool0ooooooooooooooo<oooo0?l0
3Oooool00ooo0?ooooooooooo`04ooooo`03oomVooooQooooooo00_ooooo00?oo`3oooooooooool0
2oooool00ooo0?ooooooooooo`05ooooo`03ool0oooooooooooo09?ooooo001Looooo`03o`000?oo
oooooooo00Cooooo00?oZJVYodA4A?ooool03?ooool00omgMgOoIVIVooooo`08ooooo`03ofIVI_mg
MgOooooo00Sooooo00?o0000ooooooooool02Oooool4ool0o`03ool@ooooZOoooooo00cooooo0_oo
0?l5ooooo`03oonYooooA?oooooo00_ooooo0_oo0?l;ooooo`;oo`3o1_ooool2ool0oiGooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.25, 0}} -> {-4.20799, -0.599695, \
0.034661, 0.00764945}}]
}, Open  ]],

Cell[TextData[{
  "\t To find how this initial condition evolves, we can use Eq. ",
  ButtonBox["(5.1.20)",
    ButtonData:>"(5.1.20)",
    ButtonStyle->"Hyperlink"],
  ". But we need the function ",
  Cell[BoxData[
      \(TraditionalForm\`C(k)\)]],
  ". This function is determined using Eqs. ",
  ButtonBox["(5.1.20)",
    ButtonData:>"(5.1.20)",
    ButtonStyle->"Hyperlink"],
  ", and ",
  ButtonBox["(5.1.16)",
    ButtonData:>"(5.1.16)",
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(\(\[Psi]\_o\)(x)\), "=", 
          RowBox[{\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\), 
            RowBox[{\(\[DifferentialD]k\/\(2  \[Pi]\)\), 
              FormBox[\(\(C(k)\)\ \[ExponentialE]\^\(\[ImaginaryI]\ k\ x\)\),
                "TraditionalForm"]}]}]}], TraditionalForm]]],
  "."
}], "NumberedEquation",
  CellTags->"(5.1.23)"],

Cell[TextData[{
  " Thus, ",
  Cell[BoxData[
      \(TraditionalForm\`C(k)\)]],
  " can be recognized as the Fourier transform of the initial condition:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`C(
          k)\  = \ \
\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\[DifferentialD]x\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ k\ x\)\ 1\/\@\
\(2  \[Pi]\ a\^2\)\ \[ExponentialE]\^\(\(-\ x\^2\)/2  a\^2 + \ \[ImaginaryI]\ \
k\_o\ x\)\)]]
}], "NumberedEquation",
  CellTags->"(5.1.24)"],

Cell[TextData[{
  "This integral can be evaluated analytically:",
  Cell[BoxData[
      FormBox["", TraditionalForm]]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Clear["\<Global`*\>"];\)\), "\n", 
    \(Integrate[
      1\/\(\(\@\(2  \[Pi]\)\) a\)\ Exp[\(-I\)\ k\ x\  + \ I\ k0\ x\  - \ 
            x^2/\((2  a^2)\)], {x, \(-Infinity\), Infinity}, 
      Assumptions \[Rule] a > 0]\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 5.4"],

Cell[BoxData[
    \(\[ExponentialE]\^\(\(-\(1\/2\)\)\ a\^2\ \((k - k0)\)\^2\)\)], "Output"]
}, Open  ]],

Cell["Therefore, ", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\(C(
          k)\)\(\ \)\(=\)\(\[ExponentialE]\^\(-\(\(\(a\^2\)(k - \
k\_o)\)\^2\/\(\(2\)\(\ \)\)\)\)\)\(\ \ \)\)\)]],
  "."
}], "NumberedEquation",
  CellTags->"(5.1.25)"],

Cell[TextData[{
  "\tThe Fourier transform of the initial condition is another Gaussian, \
peaked around the central wavenumber of the packet, ",
  Cell[BoxData[
      \(TraditionalForm\`k\_o\)]],
  ".  The width in ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  " of this spectrum is of order ",
  Cell[BoxData[
      \(TraditionalForm\`1/a\)]],
  ". Thus, as the width ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " of the initial condition increases, the Fourier transform ",
  ButtonBox["(5.1.25)",
    ButtonData:>"(5.1.25)",
    ButtonStyle->"Hyperlink"],
  " of the packet decreases in width, becoming more sharply peaked around ",
  Cell[BoxData[
      \(TraditionalForm\`k\_o\)]],
  ".  This is expected from the uncertainty principle of Fourier analysis, \
discussed in Chapter ",
  ButtonBox["2",
    ButtonData:>{"Chapter2.nb", None},
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text"],

Cell[TextData[{
  "\tEquation ",
  ButtonBox["(5.1.20)",
    ButtonData:>"(5.1.20)",
    ButtonStyle->"Hyperlink"],
  " implies that the wave function evolves according to "
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Psi](x, t)\), "=", 
          RowBox[{\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\), 
            RowBox[{\(\[DifferentialD]k\/\(2  \[Pi]\)\), 
              
              FormBox[\(\(\ \)\(\[ExponentialE]\^\(\(-\(1\/2\)\)\ a\^2\ \((k \
- k\_o)\)\^2\)\ \[ExponentialE]\^\[ImaginaryI]\ [k\ x - \(\[HBar]\ \
k\^2\)\/\(2  m\)\ t]\)\),
                "TraditionalForm"]}]}]}], TraditionalForm]]],
  "."
}], "Text"],

Cell["\<\
This integral can also be evaluated analytically, although the \
precise form of the result is not of importance at this point: \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Psi][x_, t_]\  = \ 
      Integrate[\ \[ExponentialE]\^\(\(-\(1\/2\)\)\ a\^2\ \((k - k0)\)\^2\)\ \
Exp[I\ \((k\ x\  - \ \[HBar]\ \(k\^2\) t/\((2\ m)\))\)], {k, \(-Infinity\), 
            Infinity}]/\((2\ Pi)\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 5.5"],

Cell[BoxData[
    \(\[ExponentialE]\^\(-\(\(m\ x\^2 + \[ImaginaryI]\ a\^2\ k0\ \((\(-2\)\ m\
\ x + k0\ t\ \[HBar])\)\)\/\(2\ a\^2\ m + 2\ \[ImaginaryI]\ t\ \
\[HBar]\)\)\)\/\(\@\(2\ \[Pi]\)\ \@\(a\^2 + \(\[ImaginaryI]\ t\ \
\[HBar]\)\/m\)\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The probability density",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{"|", "\[Psi]", 
            FormBox[\( | \^2\),
              "TraditionalForm"]}]}], TraditionalForm]]],
  " is shown in Cell ",
  ButtonBox["5.6",
    ButtonData:>"Cell 5.6",
    ButtonStyle->"Hyperlink"],
  " for an electron  with",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{
            FormBox[\(k\_o\),
              "TraditionalForm"], "=", " ", 
            RowBox[{"100", " ", 
              FormBox[\(\[Angstrom]\^\(-1\)\),
                "TraditionalForm"]}]}]}], TraditionalForm]]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`a = \(\(700\)\(\ \)\(\[Angstrom]\)\(\ \)\)\)]],
  ", where 1 angstrom (\[Angstrom]) is ",
  Cell[BoxData[
      \(TraditionalForm\`\(10\^\(\(-10\)\(\ \)\)\) m\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(m = 9.11\ 10^\(-31\); \ \[HBar] = 1.05\ 10^\(-34\);\ \), "\n", 
    \(\[Angstrom] = 10^\(-10\); \ a = \ 700\ \[Angstrom]; \ 
    k0 = \ \ 10^\(-2\)\ \[Angstrom]\^\(-1\);\ \), "\n", 
    \(\(Table[
        Plot[Abs[\[Psi][x, t]]^2, {x, \(-2000\)\ \[Angstrom], 
            20000\ \[Angstrom]}, 
          AxesLabel \[Rule] {"\<x (meters)\>", "\< \>"}, 
          PlotLabel \[Rule] \*"\"\<(|\[Psi]|\!\(\()\^2\)\),\>\"" <> 
              ToString[
                t/10^\(-11\)] <> \*"\"\<\[Cross]\!\(10\^\(-11\)\)sec\>\"", 
          PlotRange \[Rule] {0, 1/\((2  Pi\ a\^2)\)}], {t, 0. , 
          15\ 10^\(-11\), 1. \ 10^\(-11\)}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 5.6"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0 1.90278e-14 [
[.32684 -0.0125 -16.5 -12.5 ]
[.32684 -0.0125 16.5 0 ]
[.54329 -0.0125 -16.5 -12.5 ]
[.54329 -0.0125 16.5 0 ]
[.75974 -0.0125 -22.5 -12.5 ]
[.75974 -0.0125 22.5 0 ]
[.97619 -0.0125 -16.5 -12.5 ]
[.97619 -0.0125 16.5 0 ]
[1.025 0 0 -6 ]
[1.025 0 64 6 ]
[.09789 .09514 -33 -6.25 ]
[.09789 .09514 0 6.25 ]
[.09789 .19028 -33 -6.25 ]
[.09789 .19028 0 6.25 ]
[.09789 .28542 -45 -6.25 ]
[.09789 .28542 0 6.25 ]
[.09789 .38056 -33 -6.25 ]
[.09789 .38056 0 6.25 ]
[.09789 .47569 -45 -6.25 ]
[.09789 .47569 0 6.25 ]
[.09789 .57083 -33 -6.25 ]
[.09789 .57083 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -53.4375 0 ]
[.5 .63053 53.4375 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 0 m
.32684 .00625 L
s
gsave
.32684 -0.0125 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 0 m
.54329 .00625 L
s
gsave
.54329 -0.0125 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 0 m
.75974 .00625 L
s
gsave
.75974 -0.0125 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 0 m
.15368 .00375 L
s
.19697 0 m
.19697 .00375 L
s
.24026 0 m
.24026 .00375 L
s
.28355 0 m
.28355 .00375 L
s
.37013 0 m
.37013 .00375 L
s
.41342 0 m
.41342 .00375 L
s
.45671 0 m
.45671 .00375 L
s
.5 0 m
.5 .00375 L
s
.58658 0 m
.58658 .00375 L
s
.62987 0 m
.62987 .00375 L
s
.67316 0 m
.67316 .00375 L
s
.71645 0 m
.71645 .00375 L
s
.80303 0 m
.80303 .00375 L
s
.84632 0 m
.84632 .00375 L
s
.88961 0 m
.88961 .00375 L
s
.9329 0 m
.9329 .00375 L
s
.0671 0 m
.0671 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09514 m
.11664 .09514 L
s
gsave
.09789 .09514 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(12) show
grestore
.11039 .19028 m
.11664 .19028 L
s
gsave
.09789 .19028 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.11039 .28542 m
.11664 .28542 L
s
gsave
.09789 .28542 -45 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.11039 .38056 m
.11664 .38056 L
s
gsave
.09789 .38056 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.11039 .47569 m
.11664 .47569 L
s
gsave
.09789 .47569 -45 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.11039 .57083 m
.11664 .57083 L
s
gsave
.09789 .57083 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(3) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.125 Mabswid
.11039 .01903 m
.11414 .01903 L
s
.11039 .03806 m
.11414 .03806 L
s
.11039 .05708 m
.11414 .05708 L
s
.11039 .07611 m
.11414 .07611 L
s
.11039 .11417 m
.11414 .11417 L
s
.11039 .13319 m
.11414 .13319 L
s
.11039 .15222 m
.11414 .15222 L
s
.11039 .17125 m
.11414 .17125 L
s
.11039 .20931 m
.11414 .20931 L
s
.11039 .22833 m
.11414 .22833 L
s
.11039 .24736 m
.11414 .24736 L
s
.11039 .26639 m
.11414 .26639 L
s
.11039 .30444 m
.11414 .30444 L
s
.11039 .32347 m
.11414 .32347 L
s
.11039 .3425 m
.11414 .3425 L
s
.11039 .36153 m
.11414 .36153 L
s
.11039 .39958 m
.11414 .39958 L
s
.11039 .41861 m
.11414 .41861 L
s
.11039 .43764 m
.11414 .43764 L
s
.11039 .45667 m
.11414 .45667 L
s
.11039 .49472 m
.11414 .49472 L
s
.11039 .51375 m
.11414 .51375 L
s
.11039 .53278 m
.11414 .53278 L
s
.11039 .55181 m
.11414 .55181 L
s
.11039 .58986 m
.11414 .58986 L
s
.11039 .60889 m
.11414 .60889 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -114.438 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.812 moveto
(H) show
69.000 13.812 moveto
(\\310) show
75.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.812 moveto
(\\310) show
87.000 13.812 moveto
(L) show
93.000 9.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
98.250 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
104.250 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.) show
116.250 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
122.250 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
134.250 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
138.438 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
147.875 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
165.875 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .00018 m
.02499 .00022 L
.02605 .00027 L
.02721 .00033 L
.02846 .00041 L
.03068 .00061 L
.03279 .00088 L
.03397 .00107 L
.03527 .00132 L
.03653 .00163 L
.0379 .00202 L
.04033 .00295 L
.04262 .00416 L
.04516 .006 L
.04793 .00882 L
.05054 .0125 L
.05297 .01705 L
.05538 .02289 L
.05756 .02957 L
.06244 .05056 L
.06508 .06611 L
.06787 .08631 L
.07287 .13339 L
.07824 .20055 L
.08414 .29185 L
.09483 .47483 L
.09729 .51265 L
.0999 .54818 L
.10231 .57564 L
.10458 .59573 L
.10568 .60327 L
.10686 .60971 L
.10817 .61474 L
.10938 .61735 L
.11059 .61801 L
.11128 .6175 L
.11192 .61646 L
.11322 .61268 L
.11394 .60961 L
.1146 .60623 L
.11694 .58981 L
.11948 .56484 L
.12409 .50379 L
.13405 .33595 L
.13933 .24825 L
.145 .16763 L
.15037 .1084 L
.15527 .06891 L
.15763 .05439 L
.1602 .04145 L
Mistroke
.16261 .03171 L
.16488 .02436 L
.16766 .01738 L
.17017 .01262 L
.17288 .0088 L
.1758 .00586 L
.17837 .00403 L
.17966 .00332 L
.18108 .00268 L
.18229 .00222 L
.18358 .00181 L
.18592 .00124 L
.18715 .00101 L
.1885 .00081 L
.18981 .00064 L
.19122 .0005 L
.19254 .0004 L
.19375 .00032 L
.19612 .00021 L
.19746 .00016 L
.1987 .00013 L
.20007 .0001 L
.20152 7e-05 L
.20306 5e-05 L
.2045 4e-05 L
.2058 3e-05 L
.2072 2e-05 L
.20846 2e-05 L
.20963 1e-05 L
.21092 1e-05 L
.2123 1e-05 L
.21374 1e-05 L
.21511 0 L
.21635 0 L
.21768 0 L
.21884 0 L
.22011 0 L
.22144 0 L
.2227 0 L
.22386 0 L
.22493 0 L
.2261 0 L
.22734 0 L
.22857 0 L
.2299 0 L
.23116 0 L
.23233 0 L
.23338 0 L
.23453 0 L
.23574 0 L
Mistroke
.23686 0 L
.23818 0 L
.23943 0 L
.24055 0 L
.24177 0 L
.24247 0 L
.2431 0 L
.24378 0 L
.24451 0 L
.24582 0 L
.24705 0 L
.2482 0 L
.24927 0 L
.25045 0 L
.25171 0 L
.25303 0 L
.25428 0 L
.2554 0 L
.25662 0 L
.25767 0 L
.25883 0 L
.26005 0 L
.26119 0 L
.26225 0 L
.26322 0 L
.26429 0 L
.26541 0 L
.26665 0 L
.26735 0 L
.26799 0 L
.26917 0 L
.27042 0 L
.27154 0 L
.27259 0 L
.27373 0 L
.27497 0 L
.27628 0 L
.27702 0 L
.2777 0 L
.27896 0 L
.27966 0 L
.2803 0 L
.28151 0 L
.28281 0 L
.28404 0 L
.28517 0 L
.28624 0 L
.28738 0 L
.28846 0 L
.28944 0 L
Mistroke
.29059 0 L
.29184 0 L
.29302 0 L
.29411 0 L
.29523 0 L
.29629 0 L
.29744 0 L
.29869 0 L
.29999 0 L
.30122 0 L
.30233 0 L
.30354 0 L
.30419 0 L
.30487 0 L
.30609 0 L
.30741 0 L
.30815 0 L
.30885 0 L
.31011 0 L
.31126 0 L
.3119 0 L
.31259 0 L
.31385 0 L
.31497 0 L
.31621 0 L
.3175 0 L
.31871 0 L
.31984 0 L
.32087 0 L
.32201 0 L
.3232 0 L
.32452 0 L
.32571 0 L
.32637 0 L
.32709 0 L
.32839 0 L
.32961 0 L
.3309 0 L
.332 0 L
.33322 0 L
.33395 0 L
.33464 0 L
.33595 0 L
.33667 0 L
.33735 0 L
.33809 0 L
.33888 0 L
.33957 0 L
.34031 0 L
.34101 0 L
Mistroke
.34166 0 L
.34288 0 L
.34417 0 L
.3454 0 L
.34609 0 L
.34673 0 L
.3479 0 L
.34914 0 L
.35025 0 L
.3513 0 L
.35244 0 L
.35367 0 L
.35491 0 L
.35561 0 L
.35626 0 L
.35757 0 L
.35831 0 L
.35898 0 L
.36018 0 L
.36148 0 L
.36271 0 L
.36384 0 L
.3649 0 L
.36604 0 L
.36711 0 L
.36809 0 L
.36924 0 L
.37048 0 L
.37166 0 L
.37276 0 L
.37388 0 L
.37493 0 L
.37608 0 L
.37733 0 L
.37856 0 L
.37986 0 L
.38097 0 L
.38219 0 L
.3835 0 L
.38471 0 L
.38535 0 L
.38604 0 L
.38677 0 L
.38746 0 L
.38871 0 L
.38986 0 L
.39049 0 L
.39118 0 L
.39244 0 L
.39367 0 L
Mistroke
.39478 0 L
.39606 0 L
.39727 0 L
.3984 0 L
.39943 0 L
.40056 0 L
.40176 0 L
.40307 0 L
.40426 0 L
.40491 0 L
.40563 0 L
.40693 0 L
.40814 0 L
.40943 0 L
.41053 0 L
.41175 0 L
.41244 0 L
.41317 0 L
.41447 0 L
.41519 0 L
.41587 0 L
.41661 0 L
.4174 0 L
.41808 0 L
.41883 0 L
.41953 0 L
.42018 0 L
.4214 0 L
.4227 0 L
.42391 0 L
.42523 0 L
.42648 0 L
.42764 0 L
.42878 0 L
.42982 0 L
.43102 0 L
.43214 0 L
.43338 0 L
.43468 0 L
.4358 0 L
.43702 0 L
.43833 0 L
.43907 0 L
.43974 0 L
.44105 0 L
.44228 0 L
.44334 0 L
.4445 0 L
.44571 0 L
.44685 0 L
Mistroke
.44791 0 L
.44888 0 L
.45 0 L
.45106 0 L
.4522 0 L
.45342 0 L
.45457 0 L
.45562 0 L
.45685 0 L
.45754 0 L
.45818 0 L
.45936 0 L
.4606 0 L
.46181 0 L
.4625 0 L
.46314 0 L
.46431 0 L
.46555 0 L
.46665 0 L
.46769 0 L
.46883 0 L
.47006 0 L
.47129 0 L
.47199 0 L
.47264 0 L
.47395 0 L
.47469 0 L
.47536 0 L
.47656 0 L
.47786 0 L
.47908 0 L
.48022 0 L
.48127 0 L
.4824 0 L
.48347 0 L
.48445 0 L
.4856 0 L
.48684 0 L
.48802 0 L
.48912 0 L
.49035 0 L
.49151 0 L
.49255 0 L
.49368 0 L
.49491 0 L
.49621 0 L
.49733 0 L
.49854 0 L
.49985 0 L
.50106 0 L
Mistroke
.50169 0 L
.50239 0 L
.50311 0 L
.50379 0 L
.50504 0 L
.50619 0 L
.50744 0 L
.50876 0 L
.50988 0 L
.51107 0 L
.51219 0 L
.51321 0 L
.51441 0 L
.51571 0 L
.51694 0 L
.51807 0 L
.51928 0 L
.52058 0 L
.5218 0 L
.52292 0 L
.52422 0 L
.52496 0 L
.52565 0 L
.5269 0 L
.52761 0 L
.52824 0 L
.52892 0 L
.52963 0 L
.53091 0 L
.53162 0 L
.53228 0 L
.53301 0 L
.53378 0 L
.53446 0 L
.53519 0 L
.53588 0 L
.53651 0 L
.53772 0 L
.539 0 L
.5402 0 L
.54151 0 L
.54276 0 L
.54391 0 L
.54505 0 L
.54608 0 L
.54728 0 L
.5484 0 L
.54964 0 L
.55094 0 L
.55205 0 L
Mistroke
.55327 0 L
.55458 0 L
.55532 0 L
.55599 0 L
.55729 0 L
.55853 0 L
.55958 0 L
.56073 0 L
.56194 0 L
.56308 0 L
.56414 0 L
.56511 0 L
.56617 0 L
.56729 0 L
.56843 0 L
.56965 0 L
.5708 0 L
.57184 0 L
.57307 0 L
.57377 0 L
.57441 0 L
.57558 0 L
.57683 0 L
.57804 0 L
.57935 0 L
.5806 0 L
.58176 0 L
.5829 0 L
.58394 0 L
.58513 0 L
.58626 0 L
.5875 0 L
.5888 0 L
.58991 0 L
.59113 0 L
.59245 0 L
.59319 0 L
.59386 0 L
.59516 0 L
.5964 0 L
.59745 0 L
.59861 0 L
.59982 0 L
.60096 0 L
.60202 0 L
.60299 0 L
.60405 0 L
.60517 0 L
.60632 0 L
.60754 0 L
Mistroke
.60869 0 L
.60973 0 L
.61096 0 L
.61165 0 L
.61229 0 L
.61347 0 L
.61471 0 L
.61592 0 L
.61661 0 L
.61725 0 L
.61841 0 L
.61965 0 L
.62076 0 L
.6218 0 L
.62294 0 L
.62417 0 L
.6254 0 L
.6261 0 L
.62675 0 L
.62806 0 L
.62879 0 L
.62946 0 L
.63066 0 L
.63196 0 L
.63319 0 L
.63432 0 L
.63537 0 L
.63651 0 L
.63757 0 L
.63855 0 L
.6397 0 L
.64094 0 L
.64212 0 L
.64322 0 L
.64445 0 L
.64561 0 L
.64665 0 L
.64778 0 L
.64901 0 L
.65031 0 L
.65142 0 L
.65264 0 L
.65395 0 L
.65516 0 L
.65579 0 L
.65648 0 L
.65721 0 L
.65789 0 L
.65914 0 L
.66028 0 L
Mistroke
.66154 0 L
.66286 0 L
.66397 0 L
.66516 0 L
.66628 0 L
.6673 0 L
.6685 0 L
.6698 0 L
.67103 0 L
.67216 0 L
.67337 0 L
.67467 0 L
.67589 0 L
.677 0 L
.67831 0 L
.67905 0 L
.67974 0 L
.68099 0 L
.68169 0 L
.68233 0 L
.683 0 L
.68372 0 L
.68499 0 L
.6857 0 L
.68637 0 L
.68709 0 L
.68787 0 L
.68854 0 L
.68927 0 L
.68996 0 L
.6906 0 L
.6918 0 L
.69308 0 L
.69429 0 L
.6956 0 L
.69684 0 L
.69799 0 L
.69913 0 L
.70017 0 L
.70136 0 L
.70249 0 L
.70372 0 L
.70502 0 L
.70613 0 L
.70735 0 L
.70866 0 L
.70939 0 L
.71006 0 L
.71137 0 L
.7126 0 L
Mistroke
.71365 0 L
.71481 0 L
.71602 0 L
.71715 0 L
.71821 0 L
.71918 0 L
.72025 0 L
.72137 0 L
.72251 0 L
.72372 0 L
.72487 0 L
.72592 0 L
.72715 0 L
.72784 0 L
.72848 0 L
.72966 0 L
.7309 0 L
.73211 0 L
.73343 0 L
.73467 0 L
.73583 0 L
.73697 0 L
.73801 0 L
.7392 0 L
.74033 0 L
.74156 0 L
.74287 0 L
.74398 0 L
.7452 0 L
.74651 0 L
.74725 0 L
.74792 0 L
.74923 0 L
.75046 0 L
.75151 0 L
.75267 0 L
.75389 0 L
.75502 0 L
.75608 0 L
.75705 0 L
.75812 0 L
.75924 0 L
.76038 0 L
.7616 0 L
.76275 0 L
.76379 0 L
.76502 0 L
.76572 0 L
.76635 0 L
.76753 0 L
Mistroke
.76877 0 L
.76999 0 L
.77131 0 L
.77256 0 L
.77371 0 L
.77475 0 L
.7759 0 L
.7771 0 L
.77822 0 L
.77946 0 L
.78077 0 L
.78188 0 L
.7831 0 L
.78442 0 L
.78516 0 L
.78583 0 L
.78714 0 L
.78837 0 L
.78943 0 L
.79059 0 L
.7918 0 L
.79294 0 L
.794 0 L
.79497 0 L
.79609 0 L
.79716 0 L
.7983 0 L
.79952 0 L
.80067 0 L
.80172 0 L
.80295 0 L
.80364 0 L
.80428 0 L
.80545 0 L
.80669 0 L
.80791 0 L
.8086 0 L
.80924 0 L
.81041 0 L
.81165 0 L
.81276 0 L
.8138 0 L
.81494 0 L
.81617 0 L
.81741 0 L
.81811 0 L
.81876 0 L
.82007 0 L
.82081 0 L
.82147 0 L
Mistroke
.82267 0 L
.82397 0 L
.8252 0 L
.82633 0 L
.82739 0 L
.82853 0 L
.8296 0 L
.83058 0 L
.83172 0 L
.83297 0 L
.83415 0 L
.83524 0 L
.83647 0 L
.83764 0 L
.83868 0 L
.83981 0 L
.84104 0 L
.84234 0 L
.84345 0 L
.84467 0 L
.84598 0 L
.84719 0 L
.84782 0 L
.84852 0 L
.84924 0 L
.84993 0 L
.85118 0 L
.85232 0 L
.85358 0 L
.8549 0 L
.85602 0 L
.85721 0 L
.85833 0 L
.85935 0 L
.86056 0 L
.86186 0 L
.86309 0 L
.86422 0 L
.86543 0 L
.86673 0 L
.86795 0 L
.86907 0 L
.87038 0 L
.87112 0 L
.8718 0 L
.87306 0 L
.87369 0 L
.87439 0 L
.87507 0 L
.87578 0 L
Mistroke
.87706 0 L
.87777 0 L
.87843 0 L
.87916 0 L
.87994 0 L
.88061 0 L
.88134 0 L
.88203 0 L
.88267 0 L
.88387 0 L
.88515 0 L
.88635 0 L
.88767 0 L
.88892 0 L
.89007 0 L
.89121 0 L
.89225 0 L
.89344 0 L
.89457 0 L
.8958 0 L
.89711 0 L
.89822 0 L
.89944 0 L
.90075 0 L
.90149 0 L
.90216 0 L
.90346 0 L
.9047 0 L
.90575 0 L
.90691 0 L
.90812 0 L
.90926 0 L
.91032 0 L
.91129 0 L
.91235 0 L
.91347 0 L
.91461 0 L
.91583 0 L
.91698 0 L
.91803 0 L
.91926 0 L
.91995 0 L
.92059 0 L
.92176 0 L
.92301 0 L
.92422 0 L
.92554 0 L
.92679 0 L
.92794 0 L
.92909 0 L
Mistroke
.93013 0 L
.93133 0 L
.93245 0 L
.93369 0 L
.935 0 L
.93611 0 L
.93733 0 L
.93865 0 L
.93939 0 L
.94006 0 L
.94136 0 L
.9426 0 L
.94365 0 L
.94481 0 L
.94603 0 L
.94716 0 L
.94822 0 L
.94919 0 L
.95031 0 L
.95138 0 L
.95252 0 L
.95374 0 L
.95489 0 L
.95594 0 L
.96092 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oo`3ooomY
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00HP3oool20>k^kP<0oooo0P3^
k^h]0?ooo`80k^k^0`3oool20>k^kSH0oooo0P3^k^h30?ooo`80k^k^903oool20>k^kP<0oooo0P3^
k^iS0?ooo`00G03oool03@14A4@000000000000c<c<0gMgM0?ooo`3^k^h0EEEE0>k^kP3oool0k^k^
05EEE@3^k^h00`3oool400000008014A4@3oool0oooo0>k^kP0c<c<0000003<c<`3^k^hH0?ooo`@0
000000T04A4A0?ooo`3^k^h0EEEE0>k^kP3oool0k^k^05EEE@3^k^h00`3oool400000008014A4@3o
ool0oooo0>k^kP0c<c<0000003<c<`3^k^hA0?ooo`@0000000<04A4A0?ooo`3oool00P3oool2028R
8PD0oooo00d0A4A4000000000000<c<c0=gMg@3oool0k^k^05EEE@3^k^h0oooo0>k^kP1EEED0k^k^
00<0oooo10000000200A4A40oooo0?ooo`3^k^h0<c<c0000000c<c<0k^k^3P3oool500000080oooo
00L0k^k^05EEE@3^k^h0oooo0>k^kP1EEED0k^k^00<0oooo10000000200A4A40oooo0?ooo`3^k^h0
<c<c0000000c<c<0k^k^E03oool005l0oooo00T0MgMg03<c<`3oool0oooo0>k^kP1EEED0gMgM05EE
E@3^k^h01P3oool00`000000oooo0?ooo`020?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL06P3oool0
0`000000oooo0?ooo`020?ooo`050>k^kP1EEED0gMgM05EEE@3^k^h01P3oool00`000000oooo0?oo
o`020?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL04`3oool00`000000oooo0?ooo`040?ooo`808R8R
203oool02@1gMgL0<c<c0?ooo`3oool0k^k^05EEE@3MgMd0EEEE0>k^kP060?ooo`030000003oool0
oooo0080oooo00D0MgMg09VIV@3oool0VIVI07MgM`0>0?ooo`0509VIV@0R8R80k^k^0?ooo`14A4@0
0`3oool01@3^k^h0EEEE0=gMg@1EEED0k^k^00H0oooo00<000000?ooo`3oool00P3oool01@1gMgL0
VIVI0?ooo`2IVIT0MgMg05@0oooo001P0?ooo`070000003oool0oooo0?ooo`3MgMd000000=gMg@07
0?ooo`030000003oool0oooo0080oooo00D04A4A0?ooo`3oool0oooo014A4@0J0?ooo`030000003o
ool0oooo00<0oooo00<0gMgM0000003MgMd01`3oool00`000000oooo0?ooo`020?ooo`05014A4@3o
ool0oooo0?ooo`0A4A404`3oool00`000000oooo0?ooo`0?0?ooo`070000003oool0oooo0?ooo`3M
gMd000000=gMg@070?ooo`030000003oool0oooo0080oooo00D04A4A0?ooo`3oool0oooo014A4@0?
0?ooo`0309VIV@0R8R80k^k^00D0oooo00<0gMgM0000003MgMd01`3oool00`000000oooo0?ooo`02
0?ooo`05014A4@3oool0oooo0?ooo`0A4A40E03oool005l0oooo00T0MgMg03<c<`3oool0oooo0>k^
kP1EEED0gMgM05EEE@3^k^h01P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?oo
o`0000006P3oool00`000000oooo0?ooo`020?ooo`050>k^kP1EEED0gMgM05EEE@3^k^h01P3oool0
0`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000004`3oool00`000000oooo0?oo
o`0>0?ooo`0907MgM`0c<c<0oooo0?ooo`3^k^h0EEEE0=gMg@1EEED0k^k^00H0oooo00<000000?oo
o`3oool00P3oool01@000000oooo0?ooo`3oool000000100oooo00<0VIVI028R8P3^k^h00`3oool0
1@3^k^h0EEEE0=gMg@1EEED0k^k^00H0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?oo
o`3oool0000005@0oooo001L0?ooo`0=0000000R8R80000003<c<`3<c<`0oooo0>k^kP1EEED0k^k^
0?ooo`3^k^h0EEEE0>k^kP050?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo
0000000J0?ooo`0;0000003oool0oooo0?ooo`3^k^h0EEEE0>k^kP3oool0k^k^05EEE@3^k^h01@3o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000004`3oool00`000000oooo
0?ooo`0;0?ooo`0=0000000R8R80000003<c<`3<c<`0oooo0>k^kP1EEED0k^k^0?ooo`3^k^h0EEEE
0>k^kP050?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000000A0?ooo`0;
07MgM`1VIVH0oooo0?ooo`3^k^h0EEEE0>k^kP3oool0k^k^05EEE@3^k^h01@3oool00`000000oooo
0?ooo`020?ooo`050000003oool0oooo0?ooo`000000E03oool005`0oooo00<000000?ooo`3oool0
0`3oool20>k^kP<0oooo0P3^k^h50?ooo`030000003oool0oooo0080oooo00D04A4A0?ooo`3oool0
oooo014A4@0J0?ooo`040000003oool0oooo0?ooo`80k^k^0`3oool20>k^kPD0oooo00<000000?oo
o`3oool00P3oool01@0A4A40oooo0?ooo`3oool04A4A01<0oooo00<000000?ooo`3oool02`3oool0
0`000000oooo0?ooo`030?ooo`80k^k^0`3oool20>k^kPD0oooo00<000000?ooo`3oool00P3oool0
1@0A4A40oooo0?ooo`3oool04A4A0180oooo00<000000?ooo`3oool00P3^k^h30?ooo`80k^k^1@3o
ool00`000000oooo0?ooo`020?ooo`05014A4@3oool0oooo0?ooo`0A4A40E03oool005`0oooo00<0
00000?ooo`3oool03`3oool00`000000oooo0?ooo`020?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL0
6P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo0080oooo00D0MgMg09VIV@3oool0
VIVI07MgM`0C0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool03`3oool00`000000
oooo0?ooo`020?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL03P3oool01@000000^k^k0?ooo`2IVIT0
4A4A00h0oooo00<000000?ooo`3oool00P3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg05@0oooo001L
0?ooo`@00000303oool205EEE@030000003oool0oooo0080oooo00D0k^k^03<c<`000000<c<c0>k^
kP080?ooo`030000003oool0oooo00d0oooo0P1EEED00`000000oooo0?ooo`0;0?ooo`80EEEE00<0
00000?ooo`3oool00P3oool01@3^k^h0<c<c0000000c<c<0k^k^00P0oooo0P0000070?ooo`80EEEE
00<000000?ooo`3oool02`3oool4000000`0oooo0P1EEED00`000000oooo0?ooo`020?ooo`050>k^
kP0c<c<0000003<c<`3^k^h0203oool2000000@0oooo00D0VIVI014A4@0000008R8R0<c<c00<0?oo
o`80EEEE00<000000?ooo`3oool00P3oool01@3^k^h0<c<c0000000c<c<0k^k^00P0oooo0P00001:
0?ooo`00P03oool00`000000oooo0?ooo`0`0?ooo`040000003oool0oooo000003T0oooo00@00000
0?ooo`3oool000009`3oool010000000oooo0?ooo`0000190?ooo`00NP3oool4000000<0oooo00<0
00000?ooo`3oool0:P3oool4000000050?ooo`000000oooo0?ooo`000000=03oool4000000050?oo
o`000000oooo0?ooo`0000008P3oool4000000050?ooo`000000oooo0?ooo`000000B@3oool00840
oooo00<000000?ooo`3oool0;`3oool3000003X0oooo0`00000X0?ooo`<00000BP3oool007l0oooo
00@000000?ooo`3oool00000<@3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo02P0
oooo00<000000?ooo`3oool03P3oool00`1gMgL0IVIV0?ooo`0^0?ooo`0306IVIP1gMgL0oooo00L0
oooo001o0?ooo`@00000<P3oool00`000000oooo0?ooo`0j0?ooo`030000003oool0oooo02P0oooo
00<000000?ooo`3oool0303oool00`3MgMd04A4A0>k^kP0_0?ooo`030>k^kP0A4A40gMgM00L0oooo
003o0?oooa/0oooo0P0000020?ooo`800000303oool0101EEED0VIVI0?ooo`3oool200000080oooo
00L000000?ooo`3oool00000014A4@3^k^h0EEEE0080000000<0A4A40;^k^`3oool00P3oool01@2I
VIT0000000000014A4@0^k^k0080oooo00P0k^k^05EEE@000000000004A4A02k^k/0oooo014A4@D0
00000`3oool0200A4A40<c<c0000000000004A4A0:ZZZP28R8P0IVIV1`3oool00?l0oooo6`3oool0
1P3^k^h08R8R08R8R03<c<`000000<c<c0`0oooo00<000000?ooo`3oool00P3oool010000000oooo
0?ooo`0000020?ooo`080000003oool0EEEE07MgM`3oool0k^k^07MgM`0A4A430?ooo`05014A4@2k
^k/0k^k^07MgM`0A4A400P3oool01P1EEED0MgMg0?ooo`3^k^h0MgMg014A4@<0oooo00<000000?oo
o`3oool0103oool020000000ZZZZ0?ooo`3oool0^k^k0000003^k^h000001`3oool00200ooool@00
000:0?ooo`040=gMg@00000000000<c<c0d0oooo00<0<c<c0?ooo`3oool00P3oool010000000oooo
0?ooo`0000020?ooo`030000003oool0000000P0oooo00<000000?ooo`3oool0103oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00L0^k^k08R8R01VIVH0IVIV014A4@3oool0
000000L0oooo000V0?ooo`D000001@3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
00L0oooo00<000000?ooo`3oool00`3oool4000000030?ooo`000000oooo00P0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool0203oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00P0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool01`3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00d0oooo00@0k^k^028R
8P000000k^k^3@3oool00`0c<c<0oooo0?ooo`020?ooo`040000003oool0oooo00000080oooo00<0
00000?ooo`0000001@0000030?ooo`030000003oool0oooo00@0oooo1P0000030?ooo`030000003o
ool0oooo00@0oooo00P0<c<c028R8P1gMgL0MgMg08R8R03^k^h0oooo000000L0oooo000[0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0R0?ooo`03
0000003oool0oooo0340oooo00<000000?ooo`3oool0<@3oool00`000000oooo0?ooo`0a0?ooo`03
0000003oool0oooo00`0oooo00D0k^k^028R8P1gMgL0MgMg03<c<`0=0?ooo`030000003^k^h0oooo
0080oooo00h000000<c<c03<c<`000000:ZZZP3MgMd08R8R0?ooo`1EEED0R8R80>k^kP3oool0R8R8
03<c<`<0oooo00<000000?ooo`3oool0103oool01P1EEED0R8R80>k^kP3oool0R8R803<c<`<0oooo
00<0000003<c<`3MgMd0103oool020000000^k^k0?ooo`3^k^h0MgMg0000003^k^h000001`3oool0
02`0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0;0?ooo`800000c`3oool20000
0080oooo0P00000<0?ooo`0?05EEE@1gMgL0oooo0?ooo`0A4A400000028R8P000000MgMg014A4@00
0000ZZZZ0?ooo`3^k^h0EEEE0080000000@0A4A40>k^kP3oool04A4A1@0000030?ooo`060>k^kP1E
EED0000000000014A4@0k^k^0P3oool2000000040:ZZZP0R8R800000028R8P80oooo00P0ZZZZ028R
8P000000000003<c<`0A4A40MgMg05EEE@L0oooo000/0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool02`3oool00`000000oooo0?ooo`3P0?ooo`030=gMg@0A4A40k^k^01<0oooo00<0
00000?ooo`3oool06@3oool00`3^k^h04A4A0=gMg@070?ooo`00;@3oool00`000000oooo0?ooo`0;
0?ooo`800000303oool00`000000oooo0?ooo`3Q0?ooo`0307MgM`1VIVH0oooo0180oooo00<00000
0?ooo`3oool06@3oool00`1VIVH0MgMg0?ooo`070?ooo`00;P3oool00`000000oooo0?ooo`0:0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool0o`3ooolN0?ooo`00;P3oool00`000000
oooo0?ooo`0:0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0o`3ooolN0?ooo`00
;P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<000000?ooo`3oool0
o`3ooolO0?ooo`00;P3oool00`000000oooo0?ooo`0:0?ooo`030000003oool0oooo00T0oooo00<0
00000?ooo`3oool0o`3ooolO0?ooo`00;P3oool00`000000oooo0?ooo`0:0?ooo`8000002P3oool0
0`000000oooo0?ooo`3o0?oooal0oooo000_0?ooo`030000003oool0oooo00T0oooo00<000000?oo
o`3oool02@3oool00`000000oooo0?ooo`3o0?oooal0oooo000_0?ooo`030000003oool0oooo00T0
oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3o0?ooob00oooo000_0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`3o0?ooob00oooo
000_0?ooo`030000003oool0oooo00T0oooo0P0000090?ooo`030000003oool0oooo0?l0oooo803o
ool00300oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?ooo`030000003oool0
oooo0?l0oooo803oool00300oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`080?oo
o`030000003oool0oooo0?l0oooo803oool00300oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo0?l0oooo803oool001L0oooo0P3^k^h30?ooo`80k^k^
4P3oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0
o`3ooolP0?ooo`004@3oool03@14A4@000000000000c<c<0gMgM0?ooo`3^k^h0EEEE0>k^kP3oool0
k^k^05EEE@3^k^h00`3oool400000008014A4@3oool0oooo0>k^kP0c<c<0000003<c<`3^k^h40?oo
o`030000003oool0oooo00L0oooo0P0000090?ooo`030000003oool0oooo0?l0oooo803oool001@0
oooo00T0MgMg03<c<`3oool0oooo0>k^kP1EEED0gMgM05EEE@3^k^h01P3oool00`000000oooo0?oo
o`020?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL0103oool00`000000oooo0?ooo`070?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0o`3ooolQ0?ooo`005@3oool01`000000oooo0?oo
o`3oool0gMgM0000003MgMd01`3oool00`000000oooo0?ooo`020?ooo`05014A4@3oool0oooo0?oo
o`0A4A40103oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo00L0oooo00<000000?oo
o`3oool0o`3ooolQ0?ooo`00503oool02@1gMgL0<c<c0?ooo`3oool0k^k^05EEE@3MgMd0EEEE0>k^
kP060?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`3o0?ooob40oooo
000A0?ooo`0=0000000R8R80000003<c<`3<c<`0oooo0>k^kP1EEED0k^k^0?ooo`3^k^h0EEEE0>k^
kP050?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000040?ooo`030000
003oool0oooo00L0oooo0P0000080?ooo`030000003oool0oooo0?l0oooo8@3oool00140oooo00<0
00000?ooo`3oool00`3oool20>k^kP<0oooo0P3^k^h50?ooo`030000003oool0oooo0080oooo00D0
4A4A0?ooo`3oool0oooo014A4@040?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`3o0?ooob40oooo000A0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool00P3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00@0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0?l0oooo8P3oool00140oooo1000
000<0?ooo`80EEEE00<000000?ooo`3oool00P3oool01@3^k^h0<c<c0000000c<c<0k^k^00<0oooo
0`0000000`3oool0000000000002000000<0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`3o0?ooob80oooo000a0?ooo`8000000P3oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo00H0oooo00<000000?ooo`3oool0o`3ooolR0?ooo`00<@3oool2000000<0oooo00<00000
0?ooo`3oool00P3oool2000000L0oooo00<000000?ooo`3oool0o`3ooolR0?ooo`00<@3oool20000
00@0oooo00D000000?ooo`3oool0oooo000000080?ooo`030000003oool0oooo0?l0oooo8P3oool0
0340oooo0P0000001@3oool000000?ooo`3oool0000000<0oooo00<000000?ooo`3oool01P3oool0
0`000000oooo0?ooo`3o0?ooob80oooo000`0?ooo`<000000P3oool2000000@0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`3o0?ooob80oooo000b0?ooo`030000003oool0oooo00H0
oooo0P0000070?ooo`030000003oool0oooo0?l0oooo8P3oool00380oooo00<000000?ooo`3oool0
1P3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo0?l0oooo8P3oool00380oooo00<0
00000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0oooo8`3o
ool00380oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?ooo`030000003oool0
oooo0?l0oooo8`3oool00380oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo0?l0oooo8`3oool00380oooo00<000000?ooo`3oool01P3oool2000000H0
oooo00<000000?ooo`3oool0o`3ooolS0?ooo`00<P3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00D0oooo00<000000?ooo`3oool0o`3ooolS0?ooo`00<P3oool00`000000oooo0?oo
o`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3ooolS0?ooo`00<P3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0o`3ooolS
0?ooo`005`3oool20>k^kP<0oooo0P3^k^hE0?ooo`030000003oool0oooo00D0oooo00<000000?oo
o`3oool01@3oool00`000000oooo0?ooo`3o0?ooob<0oooo000A0?ooo`@0000000T04A4A0?ooo`3^
k^h0EEEE0>k^kP3oool0k^k^05EEE@3^k^h00`3oool400000008014A4@3oool0oooo0>k^kP0c<c<0
000003<c<`3^k^h60?ooo`030000003oool0oooo00D0oooo0P0000060?ooo`030000003oool0oooo
0?l0oooo8`3oool001<0oooo00<000000?ooo`3oool00P3oool01@3^k^h0EEEE0=gMg@1EEED0k^k^
00H0oooo00<000000?ooo`3oool00P3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00H0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0oooo8`3oool0
01<0oooo00<000000?ooo`3oool00`3oool00`3MgMd000000=gMg@070?ooo`030000003oool0oooo
0080oooo00D04A4A0?ooo`3oool0oooo014A4@060?ooo`030000003oool0oooo00D0oooo00<00000
0?ooo`3oool01@3oool00`000000oooo0?ooo`3o0?ooob<0oooo000C0?ooo`030000003oool0oooo
0080oooo00D0k^k^05EEE@3MgMd0EEEE0>k^kP060?ooo`030000003oool0oooo0080oooo00D00000
0?ooo`3oool0oooo000000060?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`3o0?ooob<0oooo000C0?ooo`0;0000003oool0oooo0?ooo`3^k^h0EEEE
0>k^kP3oool0k^k^05EEE@3^k^h01@3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo
0?ooo`0000001P3oool00`000000oooo0?ooo`050?ooo`8000001P3oool00`000000oooo0?ooo`3o
0?ooob<0oooo000C0?ooo`040000003oool0oooo0?ooo`80k^k^0`3oool20>k^kPD0oooo00<00000
0?ooo`3oool00P3oool01@0A4A40oooo0?ooo`3oool04A4A00H0oooo00<000000?ooo`3oool01@3o
ool00`000000oooo0?ooo`050?ooo`030000003oool0oooo0?l0oooo8`3oool001<0oooo00<00000
0?ooo`3oool03@3oool00`000000oooo0?ooo`020?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL00`3o
ool4000000030?ooo`000000000000@0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`3o0?ooob<0oooo000A0?ooo`80EEEE00<000000?ooo`3oool02`3oool205EEE@030000003oool0
oooo0080oooo00D0k^k^03<c<`000000<c<c0>k^kP040?ooo`040000003oool0000000000080oooo
00D000000?ooo`3oool0oooo000000070?ooo`030000003oool0oooo0?l0oooo8`3oool00340oooo
00<000000?ooo`0000000`3oool01@000000oooo0?ooo`3oool0000000L0oooo00<000000?ooo`3o
ool0o`3ooolS0?ooo`00<@3oool00`000000oooo000000020?ooo`030000003oool0oooo0080oooo
0P0000050?ooo`030000003oool0oooo0?l0oooo903oool00340oooo00@000000?ooo`0000000000
0P3oool01@000000oooo0?ooo`3oool0000000H0oooo00<000000?ooo`3oool0o`3ooolT0?ooo`00
<03oool2000000030?ooo`000000oooo00800000103oool00`000000oooo0?ooo`040?ooo`030000
003oool0oooo0?l0oooo903oool003<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?oo
o`040?ooo`030000003oool0oooo0?l0oooo903oool003<0oooo00<000000?ooo`3oool01@3oool2
000000D0oooo00<000000?ooo`3oool0o`3ooolT0?ooo`00<`3oool00`000000oooo0?ooo`050?oo
o`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3ooolT0?ooo`00<`3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0o`3ooolT0?ooo`00
<`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
o`3ooolT0?ooo`00<`3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00@0oooo00<0
00000?ooo`3oool0o`3ooolT0?ooo`00<`3oool00`000000oooo0?ooo`050?ooo`8000001@3oool0
0`000000oooo0?ooo`3o0?ooob@0oooo000d0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`3o0?ooob@0oooo000d0?ooo`030000003oool0oooo00@0
oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?ooob@0oooo000d0?ooo`030000
003oool0oooo00@0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`3o0?ooob@0oooo
000H0?ooo`80k^k^0`3oool20>k^kQD0oooo00<000000?ooo`3oool0103oool2000000D0oooo00<0
00000?ooo`3oool0o`3ooolT0?ooo`000P3oool400000003014A4@3oool0oooo0080oooo0P0R8R85
0?ooo`0=04A4A0000000000003<c<`3MgMd0oooo0>k^kP1EEED0k^k^0?ooo`3^k^h0EEEE0>k^kP03
0?ooo`@0000000P04A4A0?ooo`3oool0k^k^03<c<`000000<c<c0>k^kPH0oooo00<000000?ooo`3o
ool0103oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0?l0oooo903oool000@0oooo
00<000000?ooo`3oool0103oool2028R8PP0oooo00T0MgMg03<c<`3oool0oooo0>k^kP1EEED0gMgM
05EEE@3^k^h01P3oool00`000000oooo0?ooo`020?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL01P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0o`3o
oolU0?ooo`00103oool00`000000oooo0?ooo`0?0?ooo`070000003oool0oooo0?ooo`3MgMd00000
0=gMg@070?ooo`030000003oool0oooo0080oooo00D04A4A0?ooo`3oool0oooo014A4@060?ooo`03
0000003oool0oooo00@0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?ooobD0
oooo00040?ooo`030000003oool0oooo00h0oooo00T0MgMg03<c<`3oool0oooo0>k^kP1EEED0gMgM
05EEE@3^k^h01P3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`0000001P3o
ool00`000000oooo0?ooo`040?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool0o`3o
oolU0?ooo`00103oool00`000000oooo0?ooo`0;0?ooo`0=0000000R8R80000003<c<`3<c<`0oooo
0>k^kP1EEED0k^k^0?ooo`3^k^h0EEEE0>k^kP050?ooo`030000003oool0oooo0080oooo00D00000
0?ooo`3oool0oooo000000060?ooo`030000003oool0oooo00@0oooo0P0000040?ooo`030000003o
ool0oooo0?l0oooo9@3oool000@0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`03
0?ooo`80k^k^0`3oool20>k^kPD0oooo00<000000?ooo`3oool00P3oool01@0A4A40oooo0?ooo`3o
ool04A4A00H0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`030?ooo`030000003o
ool0oooo0?l0oooo9@3oool000@0oooo00<000000?ooo`3oool02`3oool00`000000oooo0?ooo`0?
0?ooo`030000003oool0oooo0080oooo00D0MgMg09VIV@3oool0VIVI07MgM`030?ooo`@0000000<0
oooo0000000000000`3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0?l0oooo9@3o
ool00080oooo0P1EEED00`000000oooo0?ooo`0;0?ooo`@00000303oool205EEE@030000003oool0
oooo0080oooo00D0k^k^03<c<`000000<c<c0>k^kP040?ooo`040000003oool0000000000080oooo
00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`3o0?ooobD0oooo000b0?ooo`030000
003oool0000000<0oooo00@000000?ooo`3oool000001@3oool00`000000oooo0?ooo`3o0?ooobD0
oooo000b0?ooo`030000003oool000000080oooo00@000000?ooo`3oool0oooo0P0000040?ooo`03
0000003oool0oooo0?l0oooo9@3oool00380oooo00@000000?ooo`00000000000P3oool010000000
oooo0?ooo`0000050?ooo`030000003oool0oooo0?l0oooo9@3oool00340oooo0P0000000`3oool0
00000?ooo`02000000<0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`3o0?ooobD0
oooo000d0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool00P3oool00`000000oooo
0?ooo`3o0?ooobH0oooo000d0?ooo`030000003oool0oooo00@0oooo0P0000030?ooo`030000003o
ool0oooo0?l0oooo9P3oool003D0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0?l0oooo9P3oool003D0oooo00<000000?ooo`3oool00`3oool00`00
0000oooo0?ooo`020?ooo`030000003oool0oooo0?l0oooo9P3oool003D0oooo00<000000?ooo`3o
ool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0?l0oooo9P3oool003D0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0?l0oooo
9P3oool003D0oooo00<000000?ooo`3oool00`3oool2000000<0oooo00<000000?ooo`3oool0o`3o
oolV0?ooo`00=@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0080oooo00<00000
0?ooo`3oool0o`3ooolV0?ooo`00=@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0o`3ooolV0?ooo`00=@3oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0o`3ooolV0?ooo`005`3oool20>k^kP<0oooo
0P3^k^hG0?ooo`030000003oool0oooo00<0oooo0P0000030?ooo`030000003oool0oooo0?l0oooo
9P3oool00100oooo1@0000020?ooo`070>k^kP1EEED0k^k^0?ooo`3^k^h0EEEE0>k^kP030?ooo`@0
000000P04A4A0?ooo`3oool0k^k^03<c<`000000<c<c0>k^kPP0oooo00<000000?ooo`3oool00`3o
ool00`000000oooo0?ooo`020?ooo`030000003oool0oooo0?l0oooo9P3oool00100oooo00D0VIVI
028R8P3^k^h0oooo04A4A0030?ooo`050>k^kP1EEED0gMgM05EEE@3^k^h01P3oool00`000000oooo
0?ooo`020?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL0203oool00`000000oooo0?ooo`030?ooo`03
0000003oool0oooo0080oooo00<000000?ooo`3oool0o`3ooolV0?ooo`004@3oool00`2IVIT08R8R
0>k^kP050?ooo`030=gMg@000000gMgM00L0oooo00<000000?ooo`3oool00P3oool01@0A4A40oooo
0?ooo`3oool04A4A00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0?l0oooo9P3oool00180oooo00<0VIVI028R8P3^k^h00`3oool01@3^k^h0EEEE
0=gMg@1EEED0k^k^00H0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool00000
00P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo
0?l0oooo9P3oool001<0oooo00/0MgMg06IVIP3oool0oooo0>k^kP1EEED0k^k^0?ooo`3^k^h0EEEE
0>k^kP050?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo000000080?ooo`03
0000003oool0oooo00<0oooo0P0000020?ooo`030000003oool0oooo0?l0oooo9`3oool001@0oooo
00<000000?ooo`3oool00P3^k^h30?ooo`80k^k^1@3oool00`000000oooo0?ooo`020?ooo`05014A
4@3oool0oooo0?ooo`0A4A402@3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?oo
o`000000o`3ooolY0?ooo`00403oool01@000000^k^k0?ooo`2IVIT04A4A00h0oooo00<000000?oo
o`3oool00P3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00<0oooo0`0000020?ooo`800000103oool0
1@000000oooo0?ooo`3oool000000?l0oooo:@3oool00100oooo00D0VIVI014A4@0000008R8R0<c<
c00<0?ooo`80EEEE00<000000?ooo`3oool00P3oool01@3^k^h0<c<c0000000c<c<0k^k^00@0oooo
00D000000?ooo`3oool000000?ooo`02000000<0oooo00D000000?ooo`3oool0oooo0000003o0?oo
obT0oooo000a0?ooo`030000003oool0oooo0080oooo0P0000030?ooo`8000000P3oool00`000000
oooo0?ooo`3o0?ooobL0oooo000a0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3oool0
0P3oool01@000000oooo0?ooo`3oool000000?l0oooo:@3oool00340oooo00D000000?ooo`3oool0
00000?ooo`02000000<0oooo00D000000?ooo`3oool0oooo0000003o0?ooobT0oooo000`0?ooo`80
00000`3oool2000000@0oooo00D000000?ooo`3oool0oooo0000003o0?ooobT0oooo000f0?ooo`03
0000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000003o0?ooobT0oooo000f0?ooo`03
0000003oool0oooo0080oooo0P0000020?ooo`030000003oool0oooo0?l0oooo9`3oool003H0oooo
00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool000000?l0oooo:@3oool003H0oooo
00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool000000?l0oooo:@3oool003H0oooo
00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool000000?l0oooo:@3oool003H0oooo
00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool000000?l0oooo:@3oool003H0oooo
00<000000?ooo`3oool00P3oool200000080oooo00<000000?ooo`3oool0o`3ooolW0?ooo`00=P3o
ool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?ooo`000000o`3ooolY0?ooo`00=`3o
ool01@000000oooo0?ooo`3oool0000000<0oooo00<000000?ooo`3oool0o`3ooolW0?ooo`00603o
ool20>k^kP<0oooo0P3^k^hH0?ooo`050000003oool0oooo0?ooo`0000000`3oool00`000000oooo
0?ooo`3o0?ooobL0oooo00000`3oool0000000000003000000D0oooo0P0R8R850?ooo`0=04A4A000
0000000003<c<`3MgMd0oooo0>k^kP1EEED0k^k^0?ooo`3^k^h0EEEE0>k^kP030?ooo`@0000000P0
4A4A0?ooo`3oool0k^k^03<c<`000000<c<c0>k^kPT0oooo00@000000?ooo`3oool0oooo0P000002
0?ooo`030000003oool0oooo0?l0oooo9`3oool000060?ooo`2IVIT08R8R0>k^kP3oool0A4A41@3o
ool2028R8PP0oooo00T0MgMg03<c<`3oool0oooo0>k^kP1EEED0gMgM05EEE@3^k^h01P3oool00`00
0000oooo0?ooo`020?ooo`0507MgM`2IVIT0oooo09VIV@1gMgL02@3oool01@000000oooo0?ooo`3o
ool0000000<0oooo00<000000?ooo`3oool0o`3ooolW0?ooo`000P3oool00`2IVIT08R8R0>k^kP0A
0?ooo`070000003oool0oooo0?ooo`3MgMd000000=gMg@070?ooo`030000003oool0oooo0080oooo
00D04A4A0?ooo`3oool0oooo014A4@090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`3o0?ooobP0oooo00030?ooo`0309VIV@0R8R80k^k^00l0oooo00T0MgMg03<c<`3o
ool0oooo0>k^kP1EEED0gMgM05EEE@3^k^h01P3oool00`000000oooo0?ooo`020?ooo`050000003o
ool0oooo0?ooo`0000002@3oool01@000000oooo0?ooo`3oool000000080oooo00<000000?ooo`3o
ool0o`3ooolX0?ooo`00103oool00`1gMgL0IVIV0?ooo`0;0?ooo`0=0000000R8R80000003<c<`3<
c<`0oooo0>k^kP1EEED0k^k^0?ooo`3^k^h0EEEE0>k^kP050?ooo`030000003oool0oooo0080oooo
00D000000?ooo`3oool0oooo000000090?ooo`050000003oool0oooo0?ooo`0000000P3oool00`00
0000oooo0?ooo`3o0?ooobP0oooo00050?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3o
ool00`3oool20>k^kP<0oooo0P3^k^h50?ooo`030000003oool0oooo0080oooo00D04A4A0?ooo`3o
ool0oooo014A4@090?ooo`040000003oool0oooo0?ooo`80000000<0oooo0000003oool0o`3ooolY
0?ooo`0000H0oooo0000002k^k/0oooo09VIV@0A4A4<0?ooo`030000003oool0oooo00l0oooo00<0
00000?ooo`3oool00P3oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00T0oooo00D000000?ooo`3oool0
oooo000000020?ooo`030000003oool0oooo0?l0oooo:03oool000060?ooo`2IVIT04A4A0000000R
8R80c<c<303oool4000000`0oooo0P1EEED00`000000oooo0?ooo`020?ooo`050>k^kP0c<c<00000
03<c<`3^k^h00`3oool300000080oooo0P0000030?ooo`040000003oool0oooo00000?l0oooo:P3o
ool00380oooo00D000000?ooo`3oool000000?ooo`0200000080oooo00@000000?ooo`3oool00000
o`3ooolZ0?ooo`00<P3oool00`000000oooo0?ooo`020?ooo`8000000P3oool2000000030?ooo`00
0000oooo0?l0oooo:@3oool00380oooo00<000000?ooo`3oool00P3oool200000080oooo00@00000
0?ooo`3oool00000o`3ooolZ0?ooo`00<P3oool010000000oooo0?ooo`0000020?ooo`040000003o
ool0oooo00000080oooo00<000000?ooo`3oool0o`3ooolX0?ooo`00<@3oool2000000<0oooo0`00
00020?ooo`040000003oool0oooo00000?l0oooo:P3oool003P0oooo00@000000?ooo`3oool00000
0P3oool00`000000oooo0?ooo`3o0?ooobP0oooo000h0?ooo`030000003oool0oooo0080000000<0
oooo0000003oool0o`3ooolY0?ooo`00>03oool010000000oooo0?ooo`0000020?ooo`030000003o
ool0oooo0?l0oooo:03oool003P0oooo00@000000?ooo`3oool000000P3oool00`000000oooo0?oo
o`3o0?ooobP0oooo000h0?ooo`040000003oool0oooo00000080oooo00<000000?ooo`3oool0o`3o
oolX0?ooo`00>03oool00`000000oooo0?ooo`02000000030?ooo`000000oooo0?l0oooo:@3oool0
03P0oooo00H000000?ooo`3oool000000?ooo`00003o0?ooob/0oooo000h0?ooo`060000003oool0
oooo0000003oool00000o`3oool[0?ooo`00>03oool01P000000oooo0?ooo`000000oooo00000?l0
oooo:`3oool001L0oooo0P3^k^h30?ooo`80k^k^6P3oool01P000000oooo0?ooo`000000oooo0000
0?l0oooo:`3oool00100oooo00D0VIVI014A4@000000<c<c0<c<c0020?ooo`070>k^kP1EEED0k^k^
0?ooo`3^k^h0EEEE0>k^kP030?ooo`@0000000P04A4A0?ooo`3oool0k^k^03<c<`000000<c<c0>k^
kP/0oooo00<000000?ooo`3oool00`00003o0?ooob/0oooo000@0?ooo`05014A4@2k^k/0oooo07Mg
M`0c<c<00`3oool01@3^k^h0EEEE0=gMg@1EEED0k^k^00H0oooo00<000000?ooo`3oool00P3oool0
1@1gMgL0VIVI0?ooo`2IVIT0MgMg00/0oooo00H000000?ooo`3oool000000?ooo`00003o0?ooob/0
oooo000D0?ooo`030000003oool0oooo0080oooo00<0gMgM0000003MgMd01`3oool00`000000oooo
0?ooo`020?ooo`05014A4@3oool0oooo0?ooo`0A4A402`3oool01P000000oooo0?ooo`000000oooo
00000?l0oooo:`3oool001<0oooo00<0ZZZZ014A4@3oool00P3oool01@3^k^h0EEEE0=gMg@1EEED0
k^k^00H0oooo00<000000?ooo`3oool00P3oool01@000000oooo0?ooo`3oool0000000`0oooo00D0
00000?ooo`000000oooo0000003o0?ooob/0oooo000B0?ooo`03014A4@000000^k^k0080oooo00L0
k^k^05EEE@3^k^h0oooo0>k^kP1EEED0k^k^00D0oooo00<000000?ooo`3oool00P3oool01@000000
oooo0?ooo`3oool0000000`0oooo00D000000?ooo`000000oooo0000003o0?ooob/0oooo000C0?oo
o`040;^k^`0R8R80oooo0?ooo`80k^k^0`3oool20>k^kPD0oooo00<000000?ooo`3oool00P3oool0
1@0A4A40oooo0?ooo`3oool04A4A00`0oooo00<000000?ooo`0000000P00003o0?ooob/0oooo000@
0?ooo`05014A4@2IVIT0oooo0;^k^`0000003P3oool00`000000oooo0?ooo`020?ooo`0507MgM`2I
VIT0oooo09VIV@1gMgL0303oool01@000000oooo0000003oool000000?l0oooo:`3oool00100oooo
00D0ZZZZ014A4@0000004A4A0:ZZZP0<0?ooo`80EEEE00<000000?ooo`3oool00P3oool01@3^k^h0
<c<c0000000c<c<0k^k^00<0oooo0`0000020?ooo`8000000P3oool010000000oooo00000000003o
0?ooob`0oooo000a0?ooo`040000003oool0oooo00000080oooo00@000000?ooo`000000oooo0P00
003o0?ooob`0oooo000a0?ooo`030000003oool0oooo00<0oooo00@000000?ooo`000000oooo0P00
003o0?ooob`0oooo000a0?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool000000?oo
o`0200000?l0oooo;03oool00340oooo00@000000?ooo`3oool000000P3oool010000000oooo0000
003oool200000?l0oooo;03oool00300oooo0P0000030?ooo`8000000`3oool300000?l0oooo;03o
ool003X0oooo0`00003o0?ooob`0oooo000j0?ooo`<00000o`3oool/0?ooo`00>P3oool200000?l0
oooo;@3oool003/0oooo00<000000?ooo`3oool0o`3oool[0?ooo`00o`3ooomY0?ooo`00o`3ooomY
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00G@3oool00`1gMgL0IVIV0?oo
o`040?ooo`030000003oool0oooo0080oooo00<0^k^k03<c<`3oool01`3oool01P000000oooo0?oo
o`3oool0IVIV07MgM`d0oooo00<04A4A0;^k^`3oool0g`3oool005`0oooo00<0gMgM014A4@3^k^h0
1@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo00H0oooo00L000000?ooo`3oool0
oooo0>k^kP0A4A40gMgM00`0oooo0P0c<c?P0?ooo`00G03oool00`1EEED0VIVI0?ooo`050?ooo`06
0000003oool0oooo0?ooo`2IVIT04A4A0P0000000`2ZZZX0oooo0?ooo`040?ooo`030000003oool0
oooo0080oooo00<0R8R806IVIP3oool02`3oool00`28R8P000000:ZZZP040?ooo`050>k^kP0c<c<0
000003<c<`3^k^h01@3oool2028R8P<0oooo00D0c<c<0>k^kP3oool0k^k^0<c<c0030?ooo`@00000
00P04A4A0?ooo`3oool0k^k^03<c<`000000<c<c0>k^kQ<0oooo00H04A4A03<c<`0000000000014A
4@2ZZZX20?ooo`060>k^kP1EEED0000000000014A4@0^k^k0`3oool01@1VIVH0000000000014A4@0
c<c<08l0oooo001L0?ooo`030000003oool0oooo00D0oooo00X000000?ooo`3oool0oooo0000002Z
ZZX0EEEE08R8R01EEED0^k^k1@3oool00`000000oooo0?ooo`020?ooo`030>k^kP000000oooo00/0
oooo00<0c<c<0000000A4A40103oool01@1gMgL0VIVI0?ooo`2IVIT0MgMg00D0oooo0P0R8R830?oo
o`050>k^kP1EEED0gMgM05EEE@3^k^h01@3oool00`000000oooo0?ooo`020?ooo`0507MgM`2IVIT0
oooo09VIV@1gMgL04`3oool01P000000ZZZZ0?ooo`3oool0^k^k00000080oooo00H0EEEE07MgM`3o
ool0k^k^07MgM`0A4A420?ooo`0606IVIP1gMgL0oooo0?ooo`28R8P04A4AS`3oool005`0oooo00<0
<c<c0?ooo`3oool01@3oool02P000000oooo0?ooo`3oool0<c<c0>k^kP2IVIT0EEEE0=gMg@0A4A45
0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3oool04@3oool01@0A4A40oooo0?ooo`3o
ool04A4A00/0oooo00<0gMgM0000003MgMd01P3oool00`000000oooo0?ooo`020?ooo`05014A4@3o
ool0oooo0?ooo`0A4A40503oool01@2k^k/0R8R806IVIP1VIVH04A4A0080oooo00<000000?ooo`3o
ool01@3oool00`000000oooo0?ooo`2B0?ooo`00G03oool00`0c<c<0oooo0?ooo`050?ooo`0;0000
003oool0oooo0?ooo`2k^k/0A4A40<c<c00R8R80oooo014A4@3<c<`0103oool00`000000oooo0?oo
o`030?ooo`030000003oool0oooo0140oooo00D000000?ooo`3oool0oooo0000000:0?ooo`050>k^
kP1EEED0gMgM05EEE@3^k^h01@3oool00`000000oooo0?ooo`020?ooo`050000003oool0oooo0?oo
o`0000004`3oool01P0c<c<08R8R07MgM`1gMgL0R8R80>k^kP80oooo1P0000020?ooo`030000003o
ool0oooo0980oooo001L0?ooo`030000003^k^h0oooo00D0oooo00/000000?ooo`3oool0oooo0>k^
kP000000oooo0000003^k^h0IVIV08R8R0040?ooo`030000003oool0oooo0080oooo00<0k^k^0000
003oool04P3oool01@000000oooo0?ooo`3oool0000000X0oooo00D0c<c<0>k^kP3oool0k^k^0<c<
c0050?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000000C0?ooo`060000
002k^k/0oooo0>k^kP1gMgL000000P3oool01P1EEED0R8R80>k^kP3oool0R8R803<c<`80oooo00H0
IVIV07MgM`3oool0oooo08R8R000002?0?ooo`00G03oool00`1EEED0MgMg0?ooo`050?ooo`080000
003oool0oooo0?ooo`1VIVH0VIVI0?ooo`0c<c<20;^k^`030000003oool0oooo0080oooo00<00000
0?ooo`3oool00P3oool00`1gMgL0EEEE0?ooo`030?ooo`@000002`3oool01@0A4A40oooo0?ooo`3o
ool04A4A01@0oooo00<000000?ooo`3oool00P3oool01@0A4A40oooo0?ooo`3oool04A4A00L0oooo
0`0000020?ooo`<00000103oool01P2ZZZX08R8R000000000000<c<c014A4@80oooo00H0k^k^05EE
E@000000000004A4A03^k^h20?ooo`060>k^kP1VIVH0000000000014A4@00000S`3oool005`0oooo
00<0gMgM014A4@3^k^h01@3oool00`000000oooo0?ooo`040?ooo`0306IVIP1gMgL0oooo00D0oooo
00L000000?ooo`3oool0oooo0>k^kP0A4A40gMgM00D0oooo00<000000?ooo`3oool02`3oool01@1g
MgL0VIVI0?ooo`2IVIT0MgMg01@0oooo00<000000?ooo`3oool00P3oool01@1gMgL0VIVI0?ooo`2I
VIT0MgMg00P0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`2X0?ooo`00G@3oool0
0`1gMgL0IVIV0?ooo`040?ooo`030000003oool0oooo00@0oooo00<0ZZZZ04A4A03oool01@3oool0
1P000000oooo0?ooo`3oool0IVIV07MgM`L0oooo00<000000?ooo`3oool02P3oool01@3^k^h0<c<c
0000000c<c<0k^k^0180oooo0P1EEED00`000000oooo0?ooo`020?ooo`050>k^kP0c<c<0000003<c
<`3^k^h00P3oool400000080oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`2X0?oo
o`00P@3oool00`000000oooo0?ooo`0d0?ooo`030000003oool0oooo0080oooo00<000000?ooo`3o
ool0Z03oool007h0oooo00@000000?ooo`3oool00000=P3oool00`000000oooo0?ooo`020?ooo`03
0000003oool0oooo0:P0oooo001o0?ooo`800000=P3oool2000000<0oooo0P00002Z0?ooo`00o`3o
oomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3o
oomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3o
oomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3o
oomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.312, 0}} -> {-5.69706*^-7, -7.70471*^12, \
1.20182*^-8, 2.73426*^11}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0 1.90278e-14 [
[.32684 -0.0125 -16.5 -12.5 ]
[.32684 -0.0125 16.5 0 ]
[.54329 -0.0125 -16.5 -12.5 ]
[.54329 -0.0125 16.5 0 ]
[.75974 -0.0125 -22.5 -12.5 ]
[.75974 -0.0125 22.5 0 ]
[.97619 -0.0125 -16.5 -12.5 ]
[.97619 -0.0125 16.5 0 ]
[1.025 0 0 -6 ]
[1.025 0 64 6 ]
[.09789 .09514 -33 -6.25 ]
[.09789 .09514 0 6.25 ]
[.09789 .19028 -33 -6.25 ]
[.09789 .19028 0 6.25 ]
[.09789 .28542 -45 -6.25 ]
[.09789 .28542 0 6.25 ]
[.09789 .38056 -33 -6.25 ]
[.09789 .38056 0 6.25 ]
[.09789 .47569 -45 -6.25 ]
[.09789 .47569 0 6.25 ]
[.09789 .57083 -33 -6.25 ]
[.09789 .57083 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -53.4375 0 ]
[.5 .63053 53.4375 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 0 m
.32684 .00625 L
s
gsave
.32684 -0.0125 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 0 m
.54329 .00625 L
s
gsave
.54329 -0.0125 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 0 m
.75974 .00625 L
s
gsave
.75974 -0.0125 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 0 m
.15368 .00375 L
s
.19697 0 m
.19697 .00375 L
s
.24026 0 m
.24026 .00375 L
s
.28355 0 m
.28355 .00375 L
s
.37013 0 m
.37013 .00375 L
s
.41342 0 m
.41342 .00375 L
s
.45671 0 m
.45671 .00375 L
s
.5 0 m
.5 .00375 L
s
.58658 0 m
.58658 .00375 L
s
.62987 0 m
.62987 .00375 L
s
.67316 0 m
.67316 .00375 L
s
.71645 0 m
.71645 .00375 L
s
.80303 0 m
.80303 .00375 L
s
.84632 0 m
.84632 .00375 L
s
.88961 0 m
.88961 .00375 L
s
.9329 0 m
.9329 .00375 L
s
.0671 0 m
.0671 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09514 m
.11664 .09514 L
s
gsave
.09789 .09514 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(12) show
grestore
.11039 .19028 m
.11664 .19028 L
s
gsave
.09789 .19028 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.11039 .28542 m
.11664 .28542 L
s
gsave
.09789 .28542 -45 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.11039 .38056 m
.11664 .38056 L
s
gsave
.09789 .38056 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.11039 .47569 m
.11664 .47569 L
s
gsave
.09789 .47569 -45 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.11039 .57083 m
.11664 .57083 L
s
gsave
.09789 .57083 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(3) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.125 Mabswid
.11039 .01903 m
.11414 .01903 L
s
.11039 .03806 m
.11414 .03806 L
s
.11039 .05708 m
.11414 .05708 L
s
.11039 .07611 m
.11414 .07611 L
s
.11039 .11417 m
.11414 .11417 L
s
.11039 .13319 m
.11414 .13319 L
s
.11039 .15222 m
.11414 .15222 L
s
.11039 .17125 m
.11414 .17125 L
s
.11039 .20931 m
.11414 .20931 L
s
.11039 .22833 m
.11414 .22833 L
s
.11039 .24736 m
.11414 .24736 L
s
.11039 .26639 m
.11414 .26639 L
s
.11039 .30444 m
.11414 .30444 L
s
.11039 .32347 m
.11414 .32347 L
s
.11039 .3425 m
.11414 .3425 L
s
.11039 .36153 m
.11414 .36153 L
s
.11039 .39958 m
.11414 .39958 L
s
.11039 .41861 m
.11414 .41861 L
s
.11039 .43764 m
.11414 .43764 L
s
.11039 .45667 m
.11414 .45667 L
s
.11039 .49472 m
.11414 .49472 L
s
.11039 .51375 m
.11414 .51375 L
s
.11039 .53278 m
.11414 .53278 L
s
.11039 .55181 m
.11414 .55181 L
s
.11039 .58986 m
.11414 .58986 L
s
.11039 .60889 m
.11414 .60889 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -114.438 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.812 moveto
(H) show
69.000 13.812 moveto
(\\310) show
75.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.812 moveto
(\\310) show
87.000 13.812 moveto
(L) show
93.000 9.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
98.250 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
104.250 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
116.250 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
122.250 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
134.250 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
138.438 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
147.875 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
165.875 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.02499 0 L
.02605 0 L
.02729 0 L
.02846 0 L
.02954 0 L
.03053 0 L
.03163 0 L
.03279 0 L
.03395 0 L
.0352 0 L
.03638 0 L
.03746 0 L
.03873 0 L
.04011 0 L
.04141 0 L
.04262 0 L
.04386 0 L
.04521 0 L
.04648 0 L
.04765 0 L
.04871 0 L
.04987 0 L
.05108 0 L
.05221 0 L
.05354 0 L
.0548 1e-05 L
.05592 1e-05 L
.05715 1e-05 L
.05848 1e-05 L
.0599 2e-05 L
.06111 2e-05 L
.06244 3e-05 L
.06371 4e-05 L
.0651 5e-05 L
.06655 7e-05 L
.0679 9e-05 L
.07032 .00014 L
.07167 .00018 L
.0729 .00023 L
.07569 .00037 L
.07726 .00049 L
.0787 .00063 L
.08136 .00097 L
.0827 .00121 L
.08418 .00153 L
.08683 .0023 L
.08926 .0033 L
.09206 .00494 L
.09472 .00712 L
Mistroke
.09717 .00986 L
.09944 .01318 L
.10193 .01791 L
.10458 .02447 L
.10719 .03282 L
.10995 .04406 L
.11489 .07176 L
.11764 .09213 L
.12021 .11467 L
.12603 .17927 L
.13571 .32253 L
.14117 .4126 L
.14621 .49045 L
.1513 .55351 L
.15386 .57656 L
.15532 .58653 L
.15669 .59366 L
.15791 .59812 L
.15918 .60086 L
.16028 .60161 L
.16147 .60075 L
.16276 .59784 L
.16348 .59532 L
.16413 .5925 L
.16533 .58599 L
.16661 .57731 L
.169 .55631 L
.1712 .53207 L
.17616 .46379 L
.18517 .31745 L
.19464 .17802 L
.19994 .11869 L
.20479 .07793 L
.20929 .05046 L
.21184 .03875 L
.2142 .02998 L
.21852 .01818 L
.2207 .01391 L
.22311 .01024 L
.22546 .00751 L
.22802 .00529 L
.2307 .00361 L
.23319 .0025 L
.23553 .00175 L
.23766 .00125 L
.23884 .00103 L
.24012 .00084 L
.24244 .00057 L
.24373 .00046 L
.24494 .00037 L
Mistroke
.24638 .00029 L
.2477 .00023 L
.24899 .00018 L
.25039 .00014 L
.25187 .0001 L
.25328 8e-05 L
.25457 6e-05 L
.25579 5e-05 L
.2572 4e-05 L
.25847 3e-05 L
.2596 2e-05 L
.26078 2e-05 L
.26209 1e-05 L
.26329 1e-05 L
.26451 1e-05 L
.26583 1e-05 L
.26709 0 L
.26825 0 L
.26929 0 L
.27044 0 L
.27165 0 L
.27277 0 L
.27402 0 L
.27533 0 L
.27644 0 L
.27767 0 L
.27899 0 L
.2804 0 L
.28173 0 L
.28294 0 L
.28408 0 L
.2853 0 L
.28633 0 L
.28747 0 L
.28869 0 L
.29 0 L
.29124 0 L
.29237 0 L
.29351 0 L
.29456 0 L
.29571 0 L
.29694 0 L
.29811 0 L
.29922 0 L
.30021 0 L
.30128 0 L
.30253 0 L
.30366 0 L
.30497 0 L
.30622 0 L
Mistroke
.30736 0 L
.30842 0 L
.30958 0 L
.31082 0 L
.31205 0 L
.31275 0 L
.31338 0 L
.31462 0 L
.31579 0 L
.31645 0 L
.31715 0 L
.31841 0 L
.31918 0 L
.31991 0 L
.32061 0 L
.32127 0 L
.32249 0 L
.32314 0 L
.32383 0 L
.32456 0 L
.32525 0 L
.32654 0 L
.32775 0 L
.32887 0 L
.33009 0 L
.3314 0 L
.33269 0 L
.33341 0 L
.33408 0 L
.33531 0 L
.3366 0 L
.33729 0 L
.33802 0 L
.33872 0 L
.33935 0 L
.34009 0 L
.34089 0 L
.34165 0 L
.34235 0 L
.3436 0 L
.34479 0 L
.34586 0 L
.34702 0 L
.34828 0 L
.34899 0 L
.34963 0 L
.35087 0 L
.35204 0 L
.35314 0 L
.35431 0 L
Mistroke
.35531 0 L
.3564 0 L
.35757 0 L
.35883 0 L
.36002 0 L
.36111 0 L
.36239 0 L
.36303 0 L
.36375 0 L
.36501 0 L
.36619 0 L
.36686 0 L
.36758 0 L
.36885 0 L
.36956 0 L
.37021 0 L
.37094 0 L
.37171 0 L
.37301 0 L
.37374 0 L
.37442 0 L
.37566 0 L
.37697 0 L
.37814 0 L
.37924 0 L
.38045 0 L
.38174 0 L
.38296 0 L
.38365 0 L
.3843 0 L
.3856 0 L
.38634 0 L
.38701 0 L
.38815 0 L
.38939 0 L
.39069 0 L
.39189 0 L
.39258 0 L
.39333 0 L
.39404 0 L
.39469 0 L
.39593 0 L
.39724 0 L
.39791 0 L
.39864 0 L
.39995 0 L
.40076 0 L
.40152 0 L
.4022 0 L
.40295 0 L
Mistroke
.4036 0 L
.40431 0 L
.4056 0 L
.40685 0 L
.408 0 L
.40924 0 L
.40995 0 L
.41061 0 L
.41131 0 L
.41195 0 L
.41268 0 L
.41338 0 L
.41455 0 L
.41579 0 L
.41685 0 L
.41802 0 L
.41927 0 L
.41997 0 L
.42062 0 L
.42181 0 L
.42306 0 L
.42429 0 L
.42499 0 L
.42563 0 L
.42681 0 L
.42806 0 L
.42918 0 L
.43023 0 L
.43138 0 L
.43261 0 L
.43392 0 L
.43466 0 L
.43534 0 L
.4366 0 L
.4373 0 L
.43794 0 L
.43914 0 L
.44045 0 L
.44168 0 L
.44281 0 L
.44387 0 L
.44501 0 L
.44609 0 L
.44707 0 L
.44822 0 L
.44947 0 L
.45065 0 L
.45175 0 L
.45287 0 L
.45392 0 L
Mistroke
.45508 0 L
.45632 0 L
.45762 0 L
.45886 0 L
.45996 0 L
.46118 0 L
.46182 0 L
.4625 0 L
.46372 0 L
.46504 0 L
.46578 0 L
.46648 0 L
.46774 0 L
.46889 0 L
.46953 0 L
.47022 0 L
.47148 0 L
.4726 0 L
.47383 0 L
.47512 0 L
.47634 0 L
.47746 0 L
.4785 0 L
.47963 0 L
.48083 0 L
.48214 0 L
.48334 0 L
.484 0 L
.48471 0 L
.48601 0 L
.48723 0 L
.48852 0 L
.48963 0 L
.49084 0 L
.49157 0 L
.49226 0 L
.49357 0 L
.49429 0 L
.49497 0 L
.49571 0 L
.4965 0 L
.49719 0 L
.49793 0 L
.49863 0 L
.49928 0 L
.5005 0 L
.5018 0 L
.50302 0 L
.50371 0 L
.50435 0 L
Mistroke
.50552 0 L
.50676 0 L
.50787 0 L
.50891 0 L
.51006 0 L
.51129 0 L
.51252 0 L
.51322 0 L
.51387 0 L
.51519 0 L
.51593 0 L
.51659 0 L
.51779 0 L
.5191 0 L
.52032 0 L
.52146 0 L
.52251 0 L
.52365 0 L
.52472 0 L
.5257 0 L
.52685 0 L
.5281 0 L
.52927 0 L
.53037 0 L
.5316 0 L
.53277 0 L
.53381 0 L
.53494 0 L
.53617 0 L
.53747 0 L
.53858 0 L
.5398 0 L
.54111 0 L
.54232 0 L
.54295 0 L
.54365 0 L
.54438 0 L
.54506 0 L
.54631 0 L
.54746 0 L
.54809 0 L
.54878 0 L
.55004 0 L
.55127 0 L
.55238 0 L
.55367 0 L
.55488 0 L
.556 0 L
.55703 0 L
.55817 0 L
Mistroke
.55936 0 L
.56067 0 L
.56185 0 L
.56251 0 L
.56323 0 L
.56453 0 L
.56574 0 L
.56703 0 L
.56813 0 L
.56934 0 L
.57003 0 L
.57076 0 L
.57206 0 L
.57279 0 L
.57346 0 L
.5742 0 L
.57499 0 L
.57568 0 L
.57642 0 L
.57713 0 L
.57777 0 L
.579 0 L
.5803 0 L
.58151 0 L
.58283 0 L
.58407 0 L
.58523 0 L
.58637 0 L
.58741 0 L
.58861 0 L
.58973 0 L
.59097 0 L
.59227 0 L
.59339 0 L
.59461 0 L
.59592 0 L
.59666 0 L
.59733 0 L
.59864 0 L
.59987 0 L
.60092 0 L
.60208 0 L
.6033 0 L
.60443 0 L
.60549 0 L
.60646 0 L
.60753 0 L
.60865 0 L
.60979 0 L
.61101 0 L
Mistroke
.61216 0 L
.6132 0 L
.61443 0 L
.61513 0 L
.61577 0 L
.61694 0 L
.61818 0 L
.6194 0 L
.62008 0 L
.62072 0 L
.62189 0 L
.62313 0 L
.62423 0 L
.62527 0 L
.62641 0 L
.62764 0 L
.62887 0 L
.62957 0 L
.63022 0 L
.63153 0 L
.63227 0 L
.63293 0 L
.63413 0 L
.63543 0 L
.63666 0 L
.63779 0 L
.63885 0 L
.63998 0 L
.64105 0 L
.64203 0 L
.64317 0 L
.64442 0 L
.6456 0 L
.64669 0 L
.64792 0 L
.64908 0 L
.65013 0 L
.65125 0 L
.65249 0 L
.65379 0 L
.6549 0 L
.65612 0 L
.65742 0 L
.65863 0 L
.65926 0 L
.65996 0 L
.66068 0 L
.66136 0 L
.66261 0 L
.66375 0 L
Mistroke
.66501 0 L
.66633 0 L
.66744 0 L
.66863 0 L
.66976 0 L
.67078 0 L
.67198 0 L
.67328 0 L
.67451 0 L
.67564 0 L
.67684 0 L
.67814 0 L
.67936 0 L
.68048 0 L
.68179 0 L
.68252 0 L
.68321 0 L
.68446 0 L
.68517 0 L
.6858 0 L
.68648 0 L
.68719 0 L
.68847 0 L
.68918 0 L
.68984 0 L
.69057 0 L
.69134 0 L
.69202 0 L
.69275 0 L
.69344 0 L
.69407 0 L
.69528 0 L
.69656 0 L
.69776 0 L
.69907 0 L
.70031 0 L
.70147 0 L
.70261 0 L
.70364 0 L
.70483 0 L
.70596 0 L
.70719 0 L
.70849 0 L
.7096 0 L
.71082 0 L
.71213 0 L
.71287 0 L
.71354 0 L
.71484 0 L
.71608 0 L
Mistroke
.71713 0 L
.71828 0 L
.71949 0 L
.72063 0 L
.72169 0 L
.72265 0 L
.72372 0 L
.72484 0 L
.72598 0 L
.7272 0 L
.72835 0 L
.72939 0 L
.73062 0 L
.73132 0 L
.73195 0 L
.73313 0 L
.73437 0 L
.73558 0 L
.7369 0 L
.73815 0 L
.7393 0 L
.74044 0 L
.74148 0 L
.74268 0 L
.7438 0 L
.74504 0 L
.74634 0 L
.74745 0 L
.74867 0 L
.74999 0 L
.75072 0 L
.7514 0 L
.7527 0 L
.75394 0 L
.75499 0 L
.75615 0 L
.75736 0 L
.7585 0 L
.75955 0 L
.76052 0 L
.76159 0 L
.76271 0 L
.76385 0 L
.76507 0 L
.76622 0 L
.76727 0 L
.7685 0 L
.76919 0 L
.76983 0 L
.771 0 L
Mistroke
.77224 0 L
.77346 0 L
.77478 0 L
.77603 0 L
.77719 0 L
.77823 0 L
.77937 0 L
.78057 0 L
.7817 0 L
.78294 0 L
.78424 0 L
.78536 0 L
.78658 0 L
.7879 0 L
.78863 0 L
.78931 0 L
.79061 0 L
.79185 0 L
.7929 0 L
.79406 0 L
.79528 0 L
.79641 0 L
.79748 0 L
.79845 0 L
.79957 0 L
.80063 0 L
.80178 0 L
.803 0 L
.80415 0 L
.80519 0 L
.80642 0 L
.80712 0 L
.80775 0 L
.80893 0 L
.81017 0 L
.81139 0 L
.81208 0 L
.81271 0 L
.81388 0 L
.81513 0 L
.81623 0 L
.81727 0 L
.81842 0 L
.81965 0 L
.82088 0 L
.82158 0 L
.82223 0 L
.82354 0 L
.82428 0 L
.82495 0 L
Mistroke
.82615 0 L
.82745 0 L
.82868 0 L
.82981 0 L
.83086 0 L
.832 0 L
.83307 0 L
.83405 0 L
.83519 0 L
.83644 0 L
.83762 0 L
.83871 0 L
.83995 0 L
.84111 0 L
.84215 0 L
.84328 0 L
.84451 0 L
.84581 0 L
.84692 0 L
.84814 0 L
.84945 0 L
.85066 0 L
.85129 0 L
.85199 0 L
.85272 0 L
.8534 0 L
.85465 0 L
.8558 0 L
.85705 0 L
.85838 0 L
.85949 0 L
.86068 0 L
.86181 0 L
.86283 0 L
.86403 0 L
.86533 0 L
.86656 0 L
.86769 0 L
.8689 0 L
.8702 0 L
.87142 0 L
.87254 0 L
.87385 0 L
.87459 0 L
.87527 0 L
.87653 0 L
.87716 0 L
.87787 0 L
.87854 0 L
.87926 0 L
Mistroke
.88053 0 L
.88124 0 L
.88191 0 L
.88263 0 L
.88341 0 L
.88408 0 L
.88481 0 L
.8855 0 L
.88614 0 L
.88735 0 L
.88862 0 L
.88983 0 L
.89115 0 L
.89239 0 L
.89354 0 L
.89469 0 L
.89572 0 L
.89692 0 L
.89804 0 L
.89928 0 L
.90058 0 L
.90169 0 L
.90291 0 L
.90423 0 L
.90496 0 L
.90563 0 L
.90694 0 L
.90817 0 L
.90922 0 L
.91038 0 L
.91159 0 L
.91273 0 L
.91379 0 L
.91476 0 L
.91582 0 L
.91694 0 L
.91809 0 L
.9193 0 L
.92045 0 L
.9215 0 L
.92273 0 L
.92342 0 L
.92406 0 L
.92524 0 L
.92648 0 L
.92769 0 L
.92901 0 L
.93026 0 L
.93142 0 L
.93256 0 L
Mistroke
.9336 0 L
.9348 0 L
.93593 0 L
.93716 0 L
.93847 0 L
.93958 0 L
.9408 0 L
.94212 0 L
.94286 0 L
.94353 0 L
.94484 0 L
.94607 0 L
.94713 0 L
.94829 0 L
.9495 0 L
.95064 0 L
.9517 0 L
.95267 0 L
.95379 0 L
.95485 0 L
.956 0 L
.95722 0 L
.95837 0 L
.95941 0 L
.96064 0 L
.96134 0 L
.96197 0 L
.96315 0 L
.96439 0 L
.96518 0 L
.96593 0 L
.9666 0 L
.96733 0 L
.96813 0 L
.96897 0 L
.9697 0 L
.97049 0 L
.97123 0 L
.97191 0 L
.97265 0 L
.97343 0 L
.97475 0 L
.9755 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00H_ooool2onk^kP?ooooo0_o^
k^h]ooooo`;ok^k^0oooool2onk^kSKooooo0_o^k^h3ooooo`;ok^k^9?ooool2onk^kP?ooooo0_o^
k^iSooooo`00G?ooool03Om4A4Co0000o`000?lb<S;ogMgMooooooo^k^koEEEEonk^k_ooooook^k^
oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hHooooo`Co
000000Wo410@ooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?oo
ooooooooonk^k_lb<S;o0000oc8b<_o^k^hAooooo`Co000000?o410@ooooooooool00_ooool2ob4Q
8@Gooooo00goA4A4o`000?l0003o<S8bomgMgOooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^
00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^3_ooool5o`0000;ooooo
00Ook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413oooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^E?ooool005oooooo00WoMgMgoc8b<_ooooooooooonk^k_mEEEGogMgMoeEE
EOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool0
0ol0003oooooooooo`02ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool00ol0003oooooooooo`04ooooo`;o8B4Q
2?ooool02OmgMgOo<S8booooooooooook^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
0oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg05Cooooo001Pooooo`07o`000?oooooooooooooooooMgMgo0000omgMg@07
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Jooooo`03o`000?oo
oooooooo00?ooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?oo
ooooooooooooool@41004oooool00ol0003oooooooooo`0?ooooo`07o`000?oooooooooooooooooM
gMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400?
ooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@4100E?ooool005oooooo00WoMgMgoc8b<_ooooooooooonk^
k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000006_ooool00ol0003oooooooooo`02ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000004oooool00ol0003ooooooooo
o`0>ooooo`09ogMgMolb<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo0000013ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000005Cooooo001Looooo`0=o`000?lQ8B7o0000oc8b<_o<c<coooooonk^k_mEEEGok^k^
ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Jooooo`0;o`000?ooooooooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Ooo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000004oooool00ol0003ooooo
ooooo`0;ooooo`0=o`000?lQ8B7o0000oc8b<_o<c<coooooonk^k_mEEEGok^k^ooooooo^k^koEEEE
onk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Aooooo`0;
ogMgMomVIVKoooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool00000E?ooool005cooooo00?o0000ooooooooool0
0oooool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@400Jooooo`04o`000?ooooooooooooooo`;ok^k^0oooool2onk^kPGooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@01?ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`03ooooo`;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@01;ooooo00?o0000ooooooooool00_o^k^h3ooooo`;ok^k^1Ooo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100E?ooool005cooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
6_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Cooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool01Ol0003o^[ZjoooooonHV9So
410@00kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg05Cooooo001L
ooooo`Co00003?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?oo
ool00ol0003oooooooooo`0=ooooo`03oeEEEOmVIVKo000000gooooo00?oEEEEofIVI_l000001?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo0_l00007ooooo`03oeEEEOmVIVKo000000gooooo
1?l0000<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`;o
00001?ooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo00?oEEEEofIVI_l000001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Sooooo0_l0001:ooooo`00P?ooool00ol0003oooooooooo`0`oooo
o`04o`000?ooooooooooo`0003Wooooo00Co0000oooooooooooo00009oooool01?l0003ooooooooo
ool00019ooooo`00N_ooool4o`0000?ooooo00?o0000ooooooooool0:_ooool4o`000005ooooool0
003oooooooooool00000=?ooool4o`000005ooooool0003oooooooooool000008_ooool4o`000005
ooooool0003oooooooooool00000BOooool0087ooooo00?o0000ooooooooool0;oooool3o`0003[o
oooo0ol0000Xooooo`?o0000B_ooool007oooooo00Co0000oooooooooooo0000<Oooool00ol0003o
ooooooooo`0jooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool03_ooool00omgMgOo
IVIVooooo`0^ooooo`03ofIVI_mgMgOooooo00Oooooo001oooooo`Co0000<_ooool00ol0003ooooo
ooooo`0jooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool03?ooool00ooMgMgo410@
onk^kP0_ooooo`03onk^k_l@413ogMgM00Oooooo003ooooooa_ooooo0_l00002ooooo`;o00003?oo
ool01?mEEEGoV9RHooooooooool2o`0000;ooooo00Oo0000oooooooooooo0000oa0@4?o^k^koEEEE
00;o000000?oA4A4okZj^_ooool00_ooool01OnHV9So0000o`000?m4A4Co^[Zj00;ooooo00Sok^k^
oeEEEOl0003o0000odA4A?nj^[[ooooooa0@40Go00000oooool02?l@413o<S8bo`000?l0003o410@
ojVYZOn7QhOoIVIV1oooool00?oooooo6oooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@cooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`08o`000?ooooooEEEEogMg
Moooooook^k^ogMgMol@4103ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000_ooool01_mEEEGoMgMg
ooooooo^k^koMgMgoa0@40?ooooo00?o0000ooooooooool01?ooool02?l0003oZJVYoooooooooooo
^[Zjo`000?o^k^ko00001oooool0023ooooolOl0000:ooooo`04omgMgOl0003o410@olc<c0gooooo
00?o<S8booooooooool00_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo000000So
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Go
oooo00Oo^[ZjohN7QomVIVKoIVIVoa0@4?oooooo000000Oooooo000Vooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01?l00004ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`05ooooo`?o00002Oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00gooooo00Cok^k^ob4Q8Ol@413ok^k^3Oooool00olb<S;oooooooooo`02
ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooool000001Ol00003ooooo`03o`000?oo
oooooooo00Cooooo1_l00003ooooo`03o`000?oooooooooo00Cooooo00So<S8bob4Q8OmgMgOoMgMg
ohN7Qoo^k^koooooo`0000Oooooo000fooooo`;o00000oooool00ol0003oooooooooo`0Hooooo`;o
00005oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo037ooooo00?o0000oooooooo
ool0<Oooool00ol0003oooooooooo`0=ooooo`04ob4Q8OmgMgOoMgMgoc8b<Pgooooo00?o0000onk^
k_ooool00_ooool03_l0003oc<c<olc<c?l0003oZJVYomgMgOlQ8B7ooooooeEEEOn7QhOok^k^oooo
oon7QhOo<S8b0oooool00ol0003oooooooooo`04ooooo`06oeEEEOn7QhOok^k^oooooon7QhOo<S8b
0oooool00ol0003o<S8bomgMg@04ooooo`08o`000?nj^[[oooooonk^k_mgMgOo0000onk^k_l00007
ooooo`00>?ooool01?l0003oooooooooool0000Jooooo`03o`000?oooooooooo0<7ooooo0_l00002
ooooo`;o00003?ooool03omEEEGoMgMgoooooooooooo410@o`000?lQ8B7o0000ogMgMol@413o0000
ojVYZOooooook^k^oeEEE@02o`000004odA4A?o^k^kooooooa0@40Go00000oooool01_o^k^koEEEE
o`000?l0003oA4A4onk^kP;ooooo0_l000001?nYZJWo8B4Qo`000?lQ8B42ooooo`08ojVYZOlQ8B7o
0000o`000?lb<S;o0000ogMgMomEEED7ooooo`00>?ooool01?l0003oooooooooool0000Iooooo`03
o`000?oooooooooo0=Cooooo00?ogMgMoa0@4?o^k^h04oooool00ol0003oooooooooo`0Iooooo`03
onk^k_l@413ogMgM00Oooooo000iooooo`04o`000?oooooo0000o`0001Sooooo00?o0000oooooooo
ool0eOooool00omgMgOoIVIVooooo`0Booooo`03o`000?oooooooooo01Wooooo00?oIVIVogMgMooo
ool01oooool003Wooooo00?o0000ooooool000006Oooool00ol0003oooooooooo`3ooooooa7ooooo
000iooooo`03o`000?oooooo000001Sooooo00?o0000ooooooooool0oooooolBooooo`00>_ooool2
o`0001Sooooo00?o0000ooooooooool0oooooolBooooo`00>_ooool2o`0001Sooooo00?o0000oooo
ooooool0oooooolBooooo`00>oooool2o`0001Kooooo00?o0000ooooooooool0oooooolCooooo`00
>oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0?oooooo4oooool003_ooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`3ooooooa?ooooo000kooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool0oooooolCooooo`00>oooool2o`0001Kooooo00?o0000oooo
ooooool0oooooolCooooo`00>oooool2o`0001Gooooo00?o0000ooooooooool0oooooolDooooo`00
>oooool2o`0001Gooooo00?o0000ooooooooool0oooooolDooooo`00>oooool2o`0001Gooooo00?o
0000ooooooooool0oooooolDooooo`005oooool2onk^kP?ooooo0_o^k^hMooooo`;o00005?ooool0
0ol0003oooooooooo`3ooooooaGooooo000Aooooo`0=odA4A?l0003o0000oc8b<_oMgMgoooooonk^
k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0
003o<S8bonk^kPkooooo0_l0000Dooooo`03o`000?oooooooooo0?oooooo5Oooool001Cooooo00Wo
MgMgoc8b<_ooooooooooonk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool2o`0001Cooooo00?o0000ooooooooool0oooooolE
ooooo`005Oooool01ol0003ooooooooooooooooogMgMo`000?oMgMd01oooool00ol0003ooooooooo
o`02ooooo`05oa0@4?ooooooooooooooool@41003_ooool2o`0001Cooooo00?o0000ooooooooool0
oooooolEooooo`005?ooool02OmgMgOo<S8booooooooooook^k^oeEEEOoMgMgoEEEEonk^kP06oooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000>ooooo`;o00005?ooool0
0ol0003oooooooooo`3ooooooaGooooo000Aooooo`0=o`000?lQ8B7o0000oc8b<_o<c<coooooonk^
k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`00000>ooooo`;o00005?ooool00ol0003oooooooooo`3ooooooaGooooo000Aoooo
o`03o`000?oooooooooo00?ooooo0_o^k^h3ooooo`;ok^k^1Oooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@41003_ooool2o`0001Cooooo00?o0000ooooooooool0oooooolE
ooooo`004Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`03ooooo`?o000000?oooooo`000?l000000_l00003ooooo`;o00004oooool0
0ol0003oooooooooo`3ooooooaKooooo000Aooooo`Co00003?ooool00omEEEGoIVIVo`000004oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool01Ol0003ooooooooooooooooo000000Gooooo00?o
0000ooooool000004_ooool00ol0003oooooooooo`3ooooooaKooooo000aooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooo`00000Booooo`03o`000?oooooo
oooo0?oooooo5_ooool0037ooooo00?o0000ooooooooool00oooool01?l0003oooooooooooooool3
o`0001;ooooo00?o0000ooooooooool0oooooolFooooo`00<Oooool01?l0003oooooooooool00002
ooooo`07o`000?ooooooooooooooool0003oooooo`00000Booooo`03o`000?oooooooooo0?oooooo
5_ooool0033ooooo0_l00003ooooo`;o00001?ooool00ol0003oooooo`00000Booooo`03o`000?oo
oooooooo0?oooooo5_ooool003_ooooo00?o0000ooooool000004_ooool00ol0003oooooooooo`3o
oooooaKooooo000kooooo`?o00004_ooool00ol0003oooooooooo`3ooooooaKooooo000kooooo`04
o`000?ooooooooooo`00017ooooo00?o0000ooooooooool0oooooolFooooo`00>oooool01?l0003o
ooooooooool0000Aooooo`03o`000?oooooooooo0?oooooo5_ooool003_ooooo00Co0000oooooooo
oooo00004Oooool00ol0003oooooooooo`3ooooooaKooooo000kooooo`04o`000?ooooooooooo`00
017ooooo00?o0000ooooooooool0oooooolFooooo`00>oooool2o`000003ooooool0003ooooo00oo
oooo00?o0000ooooooooool0oooooolGooooo`00>oooool01?l0003oooooooooool0000@ooooo`03
o`000?oooooooooo0?oooooo5oooool003_ooooo00Co0000oooooooooooo00004?ooool00ol0003o
ooooooooo`3ooooooaOooooo000kooooo`05o`000?ooooooooooooooool000003oooool00ol0003o
ooooooooo`3ooooooaOooooo000Gooooo`;ok^k^0oooool2onk^kQgooooo00Go0000oooooooooooo
ooooo`00000?ooooo`03o`000?oooooooooo0?oooooo5oooool0017ooooo1?l000002Ol@413ooooo
onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co000000So410@ooooooooooook^k^oc8b
<_l0003o<S8bonk^kPkooooo0_l00002ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool0oooooolGooooo`004oooool00ol0003oooooooooo`02ooooo`05onk^k_mEEEGogMgMoeEEEOo^
k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool01Ol0
003ooooooooooooooooo000000oooooo00?o0000ooooooooool0oooooolGooooo`004oooool00ol0
003oooooooooo`03ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@
413ooooooooooooooooo410@00kooooo00Go0000ooooooooooooooooo`00000?ooooo`03o`000?oo
oooooooo0?oooooo5oooool001?ooooo00?o0000ooooooooool00_ooool01Oo^k^koEEEEomgMgOmE
EEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000kooooo
00Go0000ooooooooooooooooo`00000?ooooo`03o`000?oooooooooo0?oooooo5oooool001?ooooo
00_o0000ooooooooooooooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000>ooooo`;o00000_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo0?oooooo5oooool001?ooooo00Co0000oooooooooooooooo
0_o^k^h3ooooo`;ok^k^1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41003_ooool01Ol0003ooooooooooooooooo000000oooooo00?o0000ooooooooool0oooooolGoooo
o`004oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`?o00000_ooool2o`0000Cooooo00Go0000ooooooooooooooooo`00000?
ooooo`03o`000?oooooooooo0?oooooo5oooool0017ooooo00?oEEEEofIVI_l000003Oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool01?l0003oooooooooool0
0002ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo0?oooooo5oooool0037ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooo
oooooooo000000?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`3ooooooaOooooo
000aooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool2o`0000;ooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`3ooooooaOooooo000aooooo`04o`000?oooooo
ooooo`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool0oooooolHooooo`00<?ooool2o`0000?ooooo0_l00004ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`3ooooooaSooooo000k
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`3o
oooooaSooooo000kooooo`;o00000oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
0?oooooo6?ooool003_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo0?oooooo6?ooool003_ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo0?oooooo6?ooool003_ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0?oooooo6?ooool003_ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0?oooooo6?ooool0
03_ooooo0_l00003ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0oooooolHoooo
o`00>oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool0oooooolHooooo`00>oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0oooooolHooooo`00>oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool0oooooolHooooo`006?ooool2onk^kP?ooooo0_o^k^hL
ooooo`;o00000oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0?oooooo6?ooool0
00;ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool03Om4A4Co0000o`000?lb<S;o
gMgMooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^h=ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`3ooooooaSooooo0004ooooo`03o`000?oooooooooo00Cooooo0_lQ
8B48ooooo`09ogMgMolb<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000oooo
ooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00gooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0?oooooo6?ooool000Cooooo00?o0000oooo
ooooool03oooool01ol0003ooooooooooooooooogMgMo`000?oMgMd01oooool00ol0003ooooooooo
o`02ooooo`05oa0@4?ooooooooooooooool@41003Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool0oooooolHooooo`001?ooool00ol0003ooooooooo
o`0>ooooo`09ogMgMolb<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0?oooooo6?ooool000Cooooo00?o0000oooo
ooooool02oooool03Ol0003o8B4Qo`000?lb<S;oc<c<ooooooo^k^koEEEEonk^k_ooooook^k^oeEE
EOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000003Oooool2
o`0000?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`3ooooooaWooooo0004oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00oooool2onk^kP?ooooo0_o^k^h5oooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`3ooooooaWooooo0004oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL00oooool3o`0000;ooooo0_l00003ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`3ooooooaWooooo0002oooo
o`03oeEEEOmVIVKo000000gooooo1?l0000<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP04ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
1Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0?oooooo6Oooool003;ooooo00?o
0000ooooooooool00oooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool0oooooolIooooo`00<_ooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooooooo`;o00001?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0?oooooo
6Oooool003;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00005ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool0oooooolIooooo`00<Oooool2o`0000?ooooo
0_l00003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`3ooooooaWooooo000kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`3ooooooaWooooo000kooooo`;o00001?ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo0?oooooo6Oooool003_ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo0?oooooo6Oooool003_ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0?oooooo6Oooool003_ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0?oooooo
6Oooool003_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo0?oooooo6Oooool003_ooooo0_l00004ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0oooooolIooooo`00>oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0oooooolIooooo`00>oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool0oooooolIooooo`005oooool2onk^kP?ooooo
0_o^k^hMooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`3ooooooaWooooo000@ooooo`Go00000_ooool01oo^k^koEEEEonk^k_ooooook^k^oeEEEOo^
k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h>ooooo`;o00001?oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0?oooooo6_ooool0013ooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool0oooooolJooooo`004Oooool00onHV9So8B4Q
onk^kP05ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@413ooooo
oooooooooooo410@00kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo0?oooooo6_ooool001;ooooo00?oV9RHob4Q8Oo^k^h00oooool01Oo^k^koEEEE
omgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
00kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
0?oooooo6_ooool001?ooooo00_oMgMgofIVI_ooooooooooonk^k_mEEEGok^k^ooooooo^k^koEEEE
onk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000>ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3ooooooa[o
oooo000Dooooo`03o`000?oooooooooo00;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@00kooooo0_l00005ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0oooooolJooooo`004?ooool01Ol0003o^[ZjoooooonHV9So410@00ko
oooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo6_ooool0013o
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c00<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP03ooooo`?o00000_ooool2o`0000Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo6_ooool0037ooooo00Co0000oooo
oooooooo00000_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`3ooooooa[ooooo000aooooo`03o`000?oooooooooo00?ooooo00Co0000
oooooooooooooooo0_l00005ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooo
oolJooooo`00<Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo6_ooool0
037ooooo00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`3ooooooa[ooooo000`ooooo`;o00000oooool2
o`0000Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo0?oooooo6_ooool003_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo0?oooooo6_ooool003_ooooo0_l00005ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0oooooolJooooo`00>oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0oooooolJooooo`00>oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolJooooo`00>oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooolK
ooooo`00>oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0oooooolKooooo`00>oooool2o`0000Gooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`3ooooooa_ooooo000kooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`3ooooooa_ooooo000kooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`3ooooooa_ooooo000Hooooo`;ok^k^0oooool2
onk^kQcooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo0?oooooo6oooool00003ooooool0003o000000?o00001Oooool2ob4Q8@Gooooo00goA4A4o`00
0?l0003o<S8bomgMgOooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@
413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^3Oooool2o`0000Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`3ooooooa_ooooo00001_ooooooV9RHob4Q8Oo^k^koooooodA4A0Go
oooo0_lQ8B48ooooo`09ogMgMolb<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo6oooool000;ooooo00?o
V9RHob4Q8Oo^k^h04Oooool01ol0003ooooooooooooooooogMgMo`000?oMgMd01oooool00ol0003o
ooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41003Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooolKooooo`000oooool00onHV9So
8B4Qonk^kP0?ooooo`09ogMgMolb<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo6oooool000Cooooo00?o
MgMgofIVI_ooool02oooool03Ol0003o8B4Qo`000?lb<S;oc<c<ooooooo^k^koEEEEonk^k_oooooo
k^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
3Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
oooooolKooooo`001Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo0_o^
k^h3ooooo`;ok^k^1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100
3Oooool2o`0000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooooa_ooooo
00001_oooooo0000okZj^_ooooooV9RHoa0@40cooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooolKooooo`0000KooooooiRHV?l@
413o0000ob4Q8Oo<c<`<ooooo`Co00003?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00oooool3o`0000;ooooo0_l00003ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`3ooooooacooooo000booooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo0?oooooo7?ooool003;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02o`0000Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooooacooooo000b
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooolLooooo`00<_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`3ooooooacooooo000aooooo`;o00000oooool2o`0000?ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo7?ooool003_ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo7?ooool0
03_ooooo0_l00007ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0oooooolLoooo
o`00>oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0oooooolMooooo`00>oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0oooooolMooooo`00>oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0oooooolMooooo`00>oooool2o`0000Oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`3ooooooagooooo000kooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3ooooooagooooo000kooooo`03
o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`00003ooooooaoooooo000kooooo`03
o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`00003ooooooaoooooo000Gooooo`;o
k^k^0oooool2onk^kQgooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo0000
0?oooooo7oooool0013ooooo00GoV9RHoa0@4?l0003o<S8bolc<c002ooooo`07onk^k_mEEEGok^k^
ooooooo^k^koEEEEonk^kP03ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^
kPkooooo0_l00008ooooo`05o`000?ooooooooooooooool00000oooooolOooooo`004?ooool01Ol@
413o^[ZjoooooomgMgOo<S8b00?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oooooooooo00Oooooo
00Go0000ooooooooooooooooo`00003ooooooaoooooo000Dooooo`03o`000?oooooooooo00;ooooo
00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41003_ooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool00000oooooolOoooo
o`004oooool00onYZJWo410@ooooo`02ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003oooooooooo`07
ooooo`05o`000?ooooooooooooooool00000oooooolOooooo`004_ooool00ol@413o0000okZj^P02
ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo
00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooo
oooo0000oooooolPooooo`004oooool01?nj^[[o8B4Qooooooooool2onk^kP?ooooo0_o^k^h5oooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400>ooooo`;o00002?ooool0
1?l0003oooooooooool0003oooooob3ooooo000@ooooo`05oa0@4?nHV9SooooookZj^_l000003_oo
ool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool00ol0003ooooo
ooooo`07ooooo`04o`000?ooooooooooo`000?oooooo8?ooool0013ooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@0<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03oooo
o`?o00000_ooool2o`0000Cooooo00?o0000ooooooooool01oooool01?l0003oooooooooool0003o
ooooob3ooooo000aooooo`04o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`00
000:ooooo`03o`000?oooooo00000?oooooo8?ooool0037ooooo00?o0000ooooooooool00oooool0
1?l0003oooooooooooooool2o`0000Wooooo00?o0000ooooool00000oooooolPooooo`00<Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooo`00003oooooob3ooooo000aooooo`04o`000?ooooooooooo`0000;ooooo00Go0000
ooooooooooooooooo`00000:ooooo`;o0000oooooolQooooo`00<?ooool2o`0000?ooooo0_l00004
ooooo`03o`000?oooooooooo00Sooooo0_l0003oooooob7ooooo000kooooo`03o`000?oooooooooo
0?oooooo:oooool003_ooooo0_l0003oooooobcooooo000kooooo`03o`000?oooooooooo0?oooooo
:oooool003_ooooo00?o0000ooooooooool0ooooool[ooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00GOooool00omgMgOoIVIVooooo`04
ooooo`03o`000?oooooooooo00;ooooo00?o^[Zjoc8b<_ooool01oooool01_l0003ooooooooooooo
ooooIVIVogMgM`gooooo00?o0000okZj^_ooool0goooool005cooooo00?ogMgMoa0@4?o^k^h01Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00Oo0000oooooooooooooooo
onk^k_l@413ogMgM00cooooo0_lb<S;Pooooo`00G?ooool00omEEEGoV9RHooooo`05ooooo`06o`00
0?oooooooooooooooonHV9So410@0_l000000onYZJWoooooooooo`04ooooo`03o`000?oooooooooo
00;ooooo00?oQhN7ofIVI_ooool02oooool00on7QhOo0000okZj^P05ooooo`Co000000?o410@oooo
ooooool00_ooool2ob4Q8@?ooooo00Goc<c<onk^k_ooooook^k^olc<c003ooooo`Co000000So410@
ooooooooooook^k^oc8b<_l0003o<S8bonk^kQ?ooooo00Ko410@oc8b<_l0003o0000oa0@4?nYZJT2
ooooo`06onk^k_mEEEGo0000o`000?m4A4Co^[Zj0oooool01OmVIVKo0000o`000?m4A4Coc<c<08oo
oooo001Looooo`03o`000?oooooooooo00Gooooo00[o0000ooooooooooooooooo`000?nYZJWoEEEE
oiRHV?mEEEGo^[Zj1Oooool00ol0003oooooooooo`02ooooo`03onk^k_l0003ooooo00_ooooo00?o
c<c<o`000?l@41001oooool00ol0003oooooooooo`04ooooo`;o8B4Q0oooool01Oo^k^koEEEEomgM
gOmEEEGok^k^00Gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01?o
oooo00Ko0000ojVYZOoooooooooookZj^_l00002ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo410@
0_ooool01_mVIVKoMgMgooooooooooooQhN7oa0@48oooooo001Looooo`03oc8b<_oooooooooo00Go
oooo00[o0000oooooooooooooooooc8b<_o^k^koV9RHoeEEEOoMgMgo410@1Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool02_ooool00ooMgMgo0000
omgMg@06ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Dooooo`05
okZj^_n7QhOoIVIVofIVI_l@41000_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
09;ooooo001Looooo`03oc8b<_oooooooooo00Gooooo00_o0000oooooooooooooooookZj^_m4A4Co
c<c<ob4Q8Ooooooo410@olc<c004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`09ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01Oooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000004oooool01_lb<S;o8B4QogMgMomgMgOo
QhN7onk^kP;ooooo1_l00002ooooo`03o`000?oooooooooo09;ooooo001Looooo`03o`000?o^k^ko
oooo00Gooooo00_o0000ooooooooooooooooonk^k_l0003oooooo`000?ooooooIVIVohN7Q`04oooo
o`03o`000?oooooooooo00;ooooo00?ok^k^o`000?ooool05Oooool00ol0003oooooooooo`09oooo
o`05olc<c?o^k^koooooonk^k_o<c<`01Oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000004oooool01_l0003o^[Zjooooooo^k^koMgMgo`0000;ooooo00KoEEEEohN7Qoo^
k^koooooohN7Qolb<S82ooooo`06ofIVI_mgMgOooooooooooon7QhOo0000Soooool005cooooo00?o
EEEEogMgMoooool01Oooool02?l0003oooooooooooooooooIVIVoiRHV?oooooo<S8b0_nj^[X00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?oMgMgoeEEEOooool00oooool4o`00
00kooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@41001oooool3o`0000;ooooo0ol00004ooooo`06ojVYZOlQ8B7o0000o`000?lb<S;o0000
0_ooool01_o^k^koEEEEo`000?l0003oA4A4onk^kP;ooooo00Kok^k^ofIVI_l0003o0000odA4A?l0
002?ooooo`00G?ooool00ooMgMgo410@onk^kP05ooooo`03o`000?oooooooooo00Cooooo00?oIVIV
ohN7Qoooool01Oooool01ol0003oooooooooooooooook^k^oa0@4?oMgMd01Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2Xooooo`00
GOooool00omgMgOoIVIVooooo`04ooooo`03o`000?oooooooooo00Cooooo00?oZJVYodA4A?ooool0
1Oooool01_l0003oooooooooooooooooIVIVogMgM`Oooooo00?o0000ooooooooool02oooool00omE
EEGoIVIVo`00000Cooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02
ooooo`Co00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0:Sooooo0021oooo
o`03o`000?oooooooooo03Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2Xoooo
o`00O_ooool01?l0003oooooooooool0000fooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0Z?ooool007oooooo0_l0000fooooo`;o00000oooool2o`000:[ooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -2.14748*^9, 0, \
2.14748*^9}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0 1.90278e-14 [
[.32684 -0.0125 -16.5 -12.5 ]
[.32684 -0.0125 16.5 0 ]
[.54329 -0.0125 -16.5 -12.5 ]
[.54329 -0.0125 16.5 0 ]
[.75974 -0.0125 -22.5 -12.5 ]
[.75974 -0.0125 22.5 0 ]
[.97619 -0.0125 -16.5 -12.5 ]
[.97619 -0.0125 16.5 0 ]
[1.025 0 0 -6 ]
[1.025 0 64 6 ]
[.09789 .09514 -33 -6.25 ]
[.09789 .09514 0 6.25 ]
[.09789 .19028 -33 -6.25 ]
[.09789 .19028 0 6.25 ]
[.09789 .28542 -45 -6.25 ]
[.09789 .28542 0 6.25 ]
[.09789 .38056 -33 -6.25 ]
[.09789 .38056 0 6.25 ]
[.09789 .47569 -45 -6.25 ]
[.09789 .47569 0 6.25 ]
[.09789 .57083 -33 -6.25 ]
[.09789 .57083 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -53.4375 0 ]
[.5 .63053 53.4375 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 0 m
.32684 .00625 L
s
gsave
.32684 -0.0125 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 0 m
.54329 .00625 L
s
gsave
.54329 -0.0125 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 0 m
.75974 .00625 L
s
gsave
.75974 -0.0125 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 0 m
.15368 .00375 L
s
.19697 0 m
.19697 .00375 L
s
.24026 0 m
.24026 .00375 L
s
.28355 0 m
.28355 .00375 L
s
.37013 0 m
.37013 .00375 L
s
.41342 0 m
.41342 .00375 L
s
.45671 0 m
.45671 .00375 L
s
.5 0 m
.5 .00375 L
s
.58658 0 m
.58658 .00375 L
s
.62987 0 m
.62987 .00375 L
s
.67316 0 m
.67316 .00375 L
s
.71645 0 m
.71645 .00375 L
s
.80303 0 m
.80303 .00375 L
s
.84632 0 m
.84632 .00375 L
s
.88961 0 m
.88961 .00375 L
s
.9329 0 m
.9329 .00375 L
s
.0671 0 m
.0671 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09514 m
.11664 .09514 L
s
gsave
.09789 .09514 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(12) show
grestore
.11039 .19028 m
.11664 .19028 L
s
gsave
.09789 .19028 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.11039 .28542 m
.11664 .28542 L
s
gsave
.09789 .28542 -45 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.11039 .38056 m
.11664 .38056 L
s
gsave
.09789 .38056 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.11039 .47569 m
.11664 .47569 L
s
gsave
.09789 .47569 -45 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.11039 .57083 m
.11664 .57083 L
s
gsave
.09789 .57083 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(3) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.125 Mabswid
.11039 .01903 m
.11414 .01903 L
s
.11039 .03806 m
.11414 .03806 L
s
.11039 .05708 m
.11414 .05708 L
s
.11039 .07611 m
.11414 .07611 L
s
.11039 .11417 m
.11414 .11417 L
s
.11039 .13319 m
.11414 .13319 L
s
.11039 .15222 m
.11414 .15222 L
s
.11039 .17125 m
.11414 .17125 L
s
.11039 .20931 m
.11414 .20931 L
s
.11039 .22833 m
.11414 .22833 L
s
.11039 .24736 m
.11414 .24736 L
s
.11039 .26639 m
.11414 .26639 L
s
.11039 .30444 m
.11414 .30444 L
s
.11039 .32347 m
.11414 .32347 L
s
.11039 .3425 m
.11414 .3425 L
s
.11039 .36153 m
.11414 .36153 L
s
.11039 .39958 m
.11414 .39958 L
s
.11039 .41861 m
.11414 .41861 L
s
.11039 .43764 m
.11414 .43764 L
s
.11039 .45667 m
.11414 .45667 L
s
.11039 .49472 m
.11414 .49472 L
s
.11039 .51375 m
.11414 .51375 L
s
.11039 .53278 m
.11414 .53278 L
s
.11039 .55181 m
.11414 .55181 L
s
.11039 .58986 m
.11414 .58986 L
s
.11039 .60889 m
.11414 .60889 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -114.438 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.812 moveto
(H) show
69.000 13.812 moveto
(\\310) show
75.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.812 moveto
(\\310) show
87.000 13.812 moveto
(L) show
93.000 9.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
98.250 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
104.250 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.) show
116.250 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
122.250 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
134.250 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
138.438 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
147.875 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
165.875 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.02499 0 L
.02605 0 L
.02729 0 L
.02846 0 L
.02954 0 L
.03053 0 L
.03163 0 L
.03279 0 L
.03395 0 L
.0352 0 L
.03638 0 L
.03746 0 L
.03873 0 L
.03944 0 L
.04011 0 L
.04132 0 L
.04262 0 L
.04327 0 L
.04396 0 L
.04519 0 L
.04588 0 L
.04652 0 L
.04726 0 L
.04797 0 L
.04925 0 L
.05041 0 L
.05166 0 L
.05236 0 L
.05302 0 L
.05414 0 L
.05519 0 L
.05634 0 L
.05759 0 L
.05882 0 L
.06012 0 L
.06123 0 L
.06244 0 L
.06381 0 L
.06458 0 L
.06529 0 L
.06659 0 L
.06797 0 L
.06921 0 L
.07037 0 L
.07163 0 L
.073 0 L
.07444 0 L
.07526 0 L
.07602 0 L
Mistroke
.07741 0 L
.07889 0 L
.08034 0 L
.08171 0 L
.08294 0 L
.08427 0 L
.08554 0 L
.08673 0 L
.08803 0 L
.08942 0 L
.09088 0 L
.09227 0 L
.09351 0 L
.09486 0 L
.09602 1e-05 L
.09731 1e-05 L
.09865 1e-05 L
.09991 1e-05 L
.10216 2e-05 L
.10342 2e-05 L
.10458 3e-05 L
.10586 3e-05 L
.10707 4e-05 L
.10934 6e-05 L
.1106 8e-05 L
.11177 .0001 L
.11313 .00013 L
.11441 .00016 L
.11652 .00022 L
.11885 .00033 L
.12111 .00047 L
.12354 .00069 L
.12492 .00086 L
.1262 .00104 L
.12758 .00128 L
.1291 .00159 L
.13166 .00229 L
.13437 .00333 L
.13682 .00461 L
.13947 .00648 L
.14197 .00882 L
.14426 .01161 L
.14673 .01544 L
.14899 .01984 L
.15141 .02571 L
.15404 .03367 L
.15873 .05278 L
.16316 .07786 L
.16838 .11777 L
.17392 .17314 L
Mistroke
.18385 .30137 L
.19327 .43336 L
.19846 .4948 L
.20102 .51895 L
.2034 .53677 L
.20561 .54893 L
.20685 .55374 L
.20797 .55681 L
.20921 .55877 L
.2099 .5592 L
.21054 .55918 L
.21172 .55806 L
.21296 .5554 L
.214 .55201 L
.21512 .54722 L
.21713 .53567 L
.21952 .51737 L
.2217 .4968 L
.23175 .36936 L
.24242 .22142 L
.25152 .12183 L
.2567 .08117 L
.26157 .05309 L
.26626 .03386 L
.26862 .02661 L
.2712 .02022 L
.27341 .01582 L
.27577 .01206 L
.27799 .00927 L
.28003 .00722 L
.2826 .00521 L
.28539 .00361 L
.28785 .00258 L
.29045 .00179 L
.29278 .00127 L
.29496 .00092 L
.29735 .00064 L
.29869 .00052 L
.29992 .00043 L
.30121 .00035 L
.30243 .00028 L
.3047 .00019 L
.30598 .00016 L
.30715 .00013 L
.30852 .0001 L
.3098 8e-05 L
.31193 5e-05 L
.31305 4e-05 L
.31426 4e-05 L
.31552 3e-05 L
Mistroke
.31672 2e-05 L
.31896 1e-05 L
.32015 1e-05 L
.32146 1e-05 L
.32284 1e-05 L
.32413 1e-05 L
.3253 0 L
.32643 0 L
.32772 0 L
.3289 0 L
.3302 0 L
.33158 0 L
.33288 0 L
.33406 0 L
.33546 0 L
.33696 0 L
.33839 0 L
.3397 0 L
.34096 0 L
.34215 0 L
.34323 0 L
.34439 0 L
.34566 0 L
.34701 0 L
.34816 0 L
.34943 0 L
.3506 0 L
.35168 0 L
.35287 0 L
.35411 0 L
.3552 0 L
.35622 0 L
.35733 0 L
.35851 0 L
.3599 0 L
.36118 0 L
.36185 0 L
.36259 0 L
.36337 0 L
.36408 0 L
.36539 0 L
.36611 0 L
.3668 0 L
.36801 0 L
.36869 0 L
.36934 0 L
.37063 0 L
.37181 0 L
.37307 0 L
.37379 0 L
Mistroke
.37444 0 L
.37554 0 L
.37674 0 L
.378 0 L
.37917 0 L
.38044 0 L
.38108 0 L
.38178 0 L
.38303 0 L
.38419 0 L
.38486 0 L
.38556 0 L
.38682 0 L
.38752 0 L
.38817 0 L
.38888 0 L
.38965 0 L
.39094 0 L
.39216 0 L
.39335 0 L
.39444 0 L
.39562 0 L
.39693 0 L
.39758 0 L
.39829 0 L
.39956 0 L
.40079 0 L
.40194 0 L
.4032 0 L
.40384 0 L
.40454 0 L
.40571 0 L
.40697 0 L
.40817 0 L
.40926 0 L
.41033 0 L
.41132 0 L
.41241 0 L
.41358 0 L
.4148 0 L
.41596 0 L
.417 0 L
.41812 0 L
.41935 0 L
.42047 0 L
.42177 0 L
.423 0 L
.42413 0 L
.42518 0 L
.42634 0 L
Mistroke
.42757 0 L
.42827 0 L
.42892 0 L
.42962 0 L
.43037 0 L
.43164 0 L
.43235 0 L
.43302 0 L
.43427 0 L
.43541 0 L
.43672 0 L
.43796 0 L
.43917 0 L
.43986 0 L
.4405 0 L
.4418 0 L
.44253 0 L
.4432 0 L
.44432 0 L
.44556 0 L
.44684 0 L
.44804 0 L
.44872 0 L
.44947 0 L
.45017 0 L
.45082 0 L
.45204 0 L
.45334 0 L
.45401 0 L
.45473 0 L
.45603 0 L
.45683 0 L
.45758 0 L
.45826 0 L
.459 0 L
.45965 0 L
.46033 0 L
.46156 0 L
.46288 0 L
.46363 0 L
.46433 0 L
.4656 0 L
.46675 0 L
.46739 0 L
.46808 0 L
.46935 0 L
.47047 0 L
.47171 0 L
.473 0 L
.47421 0 L
Mistroke
.47535 0 L
.47638 0 L
.47758 0 L
.47871 0 L
.48003 0 L
.48123 0 L
.48189 0 L
.48261 0 L
.48391 0 L
.48514 0 L
.48643 0 L
.48753 0 L
.48875 0 L
.48948 0 L
.49017 0 L
.49148 0 L
.49221 0 L
.49288 0 L
.49362 0 L
.49441 0 L
.49571 0 L
.49692 0 L
.49762 0 L
.49826 0 L
.49896 0 L
.4997 0 L
.50093 0 L
.50163 0 L
.50227 0 L
.50345 0 L
.50469 0 L
.50581 0 L
.50686 0 L
.508 0 L
.50923 0 L
.51054 0 L
.51128 0 L
.51196 0 L
.51322 0 L
.51392 0 L
.51456 0 L
.51576 0 L
.51706 0 L
.51829 0 L
.51942 0 L
.52049 0 L
.52163 0 L
.5227 0 L
.52368 0 L
.52483 0 L
Mistroke
.52608 0 L
.52726 0 L
.52836 0 L
.52948 0 L
.53053 0 L
.53169 0 L
.53293 0 L
.53416 0 L
.53546 0 L
.53657 0 L
.53779 0 L
.53911 0 L
.54033 0 L
.54096 0 L
.54166 0 L
.5424 0 L
.54308 0 L
.54434 0 L
.54549 0 L
.54612 0 L
.54682 0 L
.54807 0 L
.54931 0 L
.55042 0 L
.55171 0 L
.55292 0 L
.55405 0 L
.55508 0 L
.55622 0 L
.55742 0 L
.55873 0 L
.55992 0 L
.56058 0 L
.56129 0 L
.56259 0 L
.56381 0 L
.5651 0 L
.5662 0 L
.56742 0 L
.56815 0 L
.56884 0 L
.57014 0 L
.57087 0 L
.57154 0 L
.57228 0 L
.57307 0 L
.57376 0 L
.57451 0 L
.57521 0 L
.57585 0 L
Mistroke
.57708 0 L
.57837 0 L
.57959 0 L
.58028 0 L
.58092 0 L
.58209 0 L
.58333 0 L
.58444 0 L
.58548 0 L
.58662 0 L
.58785 0 L
.58908 0 L
.58978 0 L
.59043 0 L
.59174 0 L
.59248 0 L
.59315 0 L
.59435 0 L
.59565 0 L
.59688 0 L
.59801 0 L
.59906 0 L
.6002 0 L
.60127 0 L
.60225 0 L
.60339 0 L
.60464 0 L
.60582 0 L
.60691 0 L
.60815 0 L
.60931 0 L
.61035 0 L
.61148 0 L
.61271 0 L
.61401 0 L
.61512 0 L
.61634 0 L
.61765 0 L
.61886 0 L
.61949 0 L
.62019 0 L
.62092 0 L
.6216 0 L
.62285 0 L
.62399 0 L
.62525 0 L
.62657 0 L
.62769 0 L
.62888 0 L
.63 0 L
Mistroke
.63102 0 L
.63222 0 L
.63353 0 L
.63475 0 L
.63589 0 L
.63709 0 L
.63839 0 L
.63962 0 L
.64073 0 L
.64204 0 L
.64278 0 L
.64347 0 L
.64472 0 L
.64536 0 L
.64606 0 L
.64673 0 L
.64745 0 L
.64872 0 L
.64944 0 L
.6501 0 L
.65082 0 L
.6516 0 L
.65228 0 L
.65301 0 L
.65369 0 L
.65433 0 L
.65554 0 L
.65681 0 L
.65802 0 L
.65934 0 L
.66058 0 L
.66173 0 L
.66287 0 L
.66391 0 L
.66511 0 L
.66623 0 L
.66746 0 L
.66877 0 L
.66988 0 L
.6711 0 L
.67241 0 L
.67315 0 L
.67382 0 L
.67512 0 L
.67636 0 L
.67741 0 L
.67857 0 L
.67978 0 L
.68091 0 L
.68197 0 L
Mistroke
.68294 0 L
.68401 0 L
.68513 0 L
.68627 0 L
.68749 0 L
.68864 0 L
.68968 0 L
.69091 0 L
.69161 0 L
.69225 0 L
.69342 0 L
.69466 0 L
.69588 0 L
.6972 0 L
.69844 0 L
.6996 0 L
.70075 0 L
.70178 0 L
.70298 0 L
.70411 0 L
.70534 0 L
.70665 0 L
.70776 0 L
.70898 0 L
.7103 0 L
.71104 0 L
.71171 0 L
.71301 0 L
.71425 0 L
.7153 0 L
.71646 0 L
.71768 0 L
.71881 0 L
.71987 0 L
.72084 0 L
.72196 0 L
.72303 0 L
.72417 0 L
.72539 0 L
.72654 0 L
.72759 0 L
.72882 0 L
.72951 0 L
.73015 0 L
.73132 0 L
.73257 0 L
.73378 0 L
.73447 0 L
.73511 0 L
.73628 0 L
Mistroke
.73752 0 L
.73862 0 L
.73966 0 L
.74081 0 L
.74204 0 L
.74327 0 L
.74397 0 L
.74461 0 L
.74593 0 L
.74666 0 L
.74733 0 L
.74853 0 L
.74983 0 L
.75106 0 L
.75219 0 L
.75325 0 L
.75438 0 L
.75545 0 L
.75643 0 L
.75757 0 L
.75882 0 L
.76 0 L
.76109 0 L
.76233 0 L
.76349 0 L
.76453 0 L
.76566 0 L
.76689 0 L
.76819 0 L
.7693 0 L
.77052 0 L
.77183 0 L
.77304 0 L
.77367 0 L
.77436 0 L
.77509 0 L
.77577 0 L
.77702 0 L
.77817 0 L
.77942 0 L
.78074 0 L
.78186 0 L
.78305 0 L
.78417 0 L
.78519 0 L
.78639 0 L
.7877 0 L
.78892 0 L
.79006 0 L
.79126 0 L
Mistroke
.79256 0 L
.79378 0 L
.7949 0 L
.79621 0 L
.79695 0 L
.79763 0 L
.79889 0 L
.79952 0 L
.80022 0 L
.8009 0 L
.80161 0 L
.80289 0 L
.8036 0 L
.80426 0 L
.80499 0 L
.80577 0 L
.80644 0 L
.80717 0 L
.80786 0 L
.8085 0 L
.8097 0 L
.81098 0 L
.81218 0 L
.8135 0 L
.81474 0 L
.8159 0 L
.81704 0 L
.81807 0 L
.81927 0 L
.82039 0 L
.82162 0 L
.82293 0 L
.82404 0 L
.82526 0 L
.82657 0 L
.82731 0 L
.82798 0 L
.82928 0 L
.83052 0 L
.83157 0 L
.83272 0 L
.83393 0 L
.83507 0 L
.83613 0 L
.8371 0 L
.83816 0 L
.83928 0 L
.84042 0 L
.84164 0 L
.84279 0 L
Mistroke
.84384 0 L
.84507 0 L
.84576 0 L
.8464 0 L
.84757 0 L
.84882 0 L
.85003 0 L
.85135 0 L
.85259 0 L
.85375 0 L
.8549 0 L
.85593 0 L
.85713 0 L
.85826 0 L
.85949 0 L
.8608 0 L
.86191 0 L
.86313 0 L
.86445 0 L
.86518 0 L
.86585 0 L
.86716 0 L
.86839 0 L
.86945 0 L
.87061 0 L
.87182 0 L
.87296 0 L
.87402 0 L
.87499 0 L
.87605 0 L
.87717 0 L
.87832 0 L
.87953 0 L
.88069 0 L
.88173 0 L
.88296 0 L
.88365 0 L
.88429 0 L
.88547 0 L
.88671 0 L
.88792 0 L
.88861 0 L
.88925 0 L
.89042 0 L
.89166 0 L
.89276 0 L
.8938 0 L
.89494 0 L
.89617 0 L
.8974 0 L
Mistroke
.8981 0 L
.89875 0 L
.90006 0 L
.9008 0 L
.90147 0 L
.90266 0 L
.90396 0 L
.90519 0 L
.90632 0 L
.90738 0 L
.90851 0 L
.90958 0 L
.91056 0 L
.9117 0 L
.91295 0 L
.91413 0 L
.91522 0 L
.91646 0 L
.91762 0 L
.91866 0 L
.91979 0 L
.92102 0 L
.92232 0 L
.92343 0 L
.92465 0 L
.92596 0 L
.92716 0 L
.9278 0 L
.92849 0 L
.92922 0 L
.9299 0 L
.93115 0 L
.93229 0 L
.93355 0 L
.93487 0 L
.93598 0 L
.93717 0 L
.93829 0 L
.93931 0 L
.94052 0 L
.94182 0 L
.94305 0 L
.94418 0 L
.94538 0 L
.94668 0 L
.9479 0 L
.94902 0 L
.95033 0 L
.95107 0 L
.95175 0 L
Mistroke
.95301 0 L
.95371 0 L
.95434 0 L
.95502 0 L
.95573 0 L
.95701 0 L
.95772 0 L
.95838 0 L
.95911 0 L
.95989 0 L
.96056 0 L
.96129 0 L
.96198 0 L
.96261 0 L
.96382 0 L
.9651 0 L
.96584 0 L
.96654 0 L
.96786 0 L
.96859 0 L
.96928 0 L
.97002 0 L
.97082 0 L
.97152 0 L
.97227 0 L
.97298 0 L
.97364 0 L
.97488 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00H_ooool2onk^kP?ooooo0_o^
k^h]ooooo`;ok^k^0oooool2onk^kSKooooo0_o^k^h3ooooo`;ok^k^9?ooool2onk^kP?ooooo0_o^
k^iSooooo`00G?ooool03Om4A4Co0000o`000?lb<S;ogMgMooooooo^k^koEEEEonk^k_ooooook^k^
oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hHooooo`Co
000000Wo410@ooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?oo
ooooooooonk^k_lb<S;o0000oc8b<_o^k^hAooooo`Co000000?o410@ooooooooool00_ooool2ob4Q
8@Gooooo00goA4A4o`000?l0003o<S8bomgMgOooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^
00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^3_ooool5o`0000;ooooo
00Ook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413oooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^E?ooool005oooooo00WoMgMgoc8b<_ooooooooooonk^k_mEEEGogMgMoeEE
EOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool0
0ol0003oooooooooo`02ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool00ol0003oooooooooo`04ooooo`;o8B4Q
2?ooool02OmgMgOo<S8booooooooooook^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
0oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg05Cooooo001Pooooo`07o`000?oooooooooooooooooMgMgo0000omgMg@07
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Jooooo`03o`000?oo
oooooooo00?ooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?oo
ooooooooooooool@41004oooool00ol0003oooooooooo`0?ooooo`07o`000?oooooooooooooooooM
gMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400?
ooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@4100E?ooool005oooooo00WoMgMgoc8b<_ooooooooooonk^
k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000006_ooool00ol0003oooooooooo`02ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000004oooool00ol0003ooooooooo
o`0>ooooo`09ogMgMolb<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo0000013ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000005Cooooo001Looooo`0=o`000?lQ8B7o0000oc8b<_o<c<coooooonk^k_mEEEGok^k^
ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Jooooo`0;o`000?ooooooooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Ooo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000004oooool00ol0003ooooo
ooooo`0;ooooo`0=o`000?lQ8B7o0000oc8b<_o<c<coooooonk^k_mEEEGok^k^ooooooo^k^koEEEE
onk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Aooooo`0;
ogMgMomVIVKoooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool00000E?ooool005cooooo00?o0000ooooooooool0
0oooool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@400Jooooo`04o`000?ooooooooooooooo`;ok^k^0oooool2onk^kPGooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@01?ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`03ooooo`;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@01;ooooo00?o0000ooooooooool00_o^k^h3ooooo`;ok^k^1Ooo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100E?ooool005cooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
6_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Cooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool01Ol0003o^[ZjoooooonHV9So
410@00kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg05Cooooo001L
ooooo`Co00003?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?oo
ool00ol0003oooooooooo`0=ooooo`03oeEEEOmVIVKo000000gooooo00?oEEEEofIVI_l000001?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo0_l00007ooooo`03oeEEEOmVIVKo000000gooooo
1?l0000<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`;o
00001?ooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo00?oEEEEofIVI_l000001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Sooooo0_l0001:ooooo`00P?ooool00ol0003oooooooooo`0`oooo
o`04o`000?ooooooooooo`0003Wooooo00Co0000oooooooooooo00009oooool01?l0003ooooooooo
ool00019ooooo`00N_ooool4o`0000?ooooo00?o0000ooooooooool0:_ooool4o`000005ooooool0
003oooooooooool00000=?ooool4o`000005ooooool0003oooooooooool000008_ooool4o`000005
ooooool0003oooooooooool00000BOooool0087ooooo00?o0000ooooooooool0;oooool3o`0003[o
oooo0ol0000Xooooo`?o0000B_ooool007oooooo00Co0000oooooooooooo0000<Oooool00ol0003o
ooooooooo`0jooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool03_ooool00omgMgOo
IVIVooooo`0^ooooo`03ofIVI_mgMgOooooo00Oooooo001oooooo`Co0000<_ooool00ol0003ooooo
ooooo`0jooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool03?ooool00ooMgMgo410@
onk^kP0_ooooo`03onk^k_l@413ogMgM00Oooooo003ooooooa_ooooo0_l00002ooooo`;o00003?oo
ool01?mEEEGoV9RHooooooooool2o`0000;ooooo00Oo0000oooooooooooo0000oa0@4?o^k^koEEEE
00;o000000?oA4A4okZj^_ooool00_ooool01OnHV9So0000o`000?m4A4Co^[Zj00;ooooo00Sok^k^
oeEEEOl0003o0000odA4A?nj^[[ooooooa0@40Go00000oooool02?l@413o<S8bo`000?l0003o410@
ojVYZOn7QhOoIVIV1oooool00?oooooo6oooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@cooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`08o`000?ooooooEEEEogMg
Moooooook^k^ogMgMol@4103ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000_ooool01_mEEEGoMgMg
ooooooo^k^koMgMgoa0@40?ooooo00?o0000ooooooooool01?ooool02?l0003oZJVYoooooooooooo
^[Zjo`000?o^k^ko00001oooool0023ooooolOl0000:ooooo`04omgMgOl0003o410@olc<c0gooooo
00?o<S8booooooooool00_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo000000So
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Go
oooo00Oo^[ZjohN7QomVIVKoIVIVoa0@4?oooooo000000Oooooo000Vooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`04o`0000?ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo1Ol00006oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00gooooo00Cok^k^ob4Q8Ol@413ok^k^3Oooool00olb<S;oooooooooo`02
ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooool000001Ol00003ooooo`03o`000?oo
oooooooo00Cooooo1_l00003ooooo`03o`000?oooooooooo00Cooooo00So<S8bob4Q8OmgMgOoMgMg
ohN7Qoo^k^koooooo`0000Oooooo000kooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo037ooooo00?o0000oooooooo
ool0<Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00gooooo00Co8B4QogMgMomg
MgOo<S8b3Oooool00ol0003ok^k^ooooo`02ooooo`0>o`000?o<c<coc<c<o`000?nYZJWogMgMob4Q
8OooooooEEEEohN7Qoo^k^koooooohN7Qolb<S83ooooo`03o`000?oooooooooo00Cooooo00KoEEEE
ohN7Qoo^k^koooooohN7Qolb<S83ooooo`03o`000?lb<S;ogMgM00Cooooo00So0000okZj^_oooooo
k^k^ogMgMol0003ok^k^o`0000Oooooo000kooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool07?ooool2o`000;Kooooo0_l00002ooooo`;o00003?ooool03omEEEGoMgMgoooooooooooo
410@o`000?lQ8B7o0000ogMgMol@413o0000ojVYZOooooook^k^oeEEE@02o`000004odA4A?o^k^ko
oooooa0@40Go00000oooool01_o^k^koEEEEo`000?l0003oA4A4onk^kP;ooooo0_l000001?nYZJWo
8B4Qo`000?lQ8B42ooooo`08ojVYZOlQ8B7o0000o`000?lb<S;o0000ogMgMomEEED7ooooo`00>ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0aooo
ool00ooMgMgo410@onk^kP0Cooooo`03o`000?oooooooooo01Wooooo00?ok^k^oa0@4?oMgMd01ooo
ool003_ooooo0_l00007ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0bOooool0
0omgMgOoIVIVooooo`0Booooo`03o`000?oooooooooo01Wooooo00?oIVIVogMgMoooool01oooool0
03_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
0?oooooo1Oooool003_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo0?oooooo1Oooool003_ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo0?oooooo1Oooool003_ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo0?oooooo1_ooool003_ooooo0_l00008
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0ooooool6ooooo`00>oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0ooooool6oooo
o`00>oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool0ooooool7ooooo`00>oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool0ooooool7ooooo`00>oooool2o`0000Wooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`3oooooo`Oooooo000kooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`3oooooo`Oooooo000kooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`3oooooo`Oooooo000kooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`3oooooo`So
oooo000Gooooo`;ok^k^0oooool2onk^kQgooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo0?oooooo2?ooool0017ooooo00goA4A4o`000?l0003o<S8b
omgMgOooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413ooooooooo
ooo^k^ko<S8bo`000?lb<S;ok^k^3_ooool2o`0000[ooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`3oooooo`Sooooo000Dooooo`09ogMgMolb<S;oooooooooooo^k^koEEEEomgMgOmE
EEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo0?oooooo
2?ooool001Gooooo00Oo0000ooooooooooooooooomgMgOl0003ogMgM00Oooooo00?o0000oooooooo
ool00_ooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo0?oooooo2?ooool001Cooooo00WoMgMgoc8b<_oo
ooooooooonk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000003_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool0ooooool8ooooo`004Oooool03Ol0003o8B4Qo`000?lb<S;oc<c<ooooooo^
k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000003_ooool2o`0000_ooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`3oooooo`Sooooo000Aooooo`03o`000?oooooooooo00?ooooo0_o^k^h3ooooo`;ok^k^1Ooo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0ooooool8ooooo`004Ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`?o000000?oooooo`000?l000000_l00003ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`3oooooo`Sooooo000Aooooo`Co00003?oo
ool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool01Ol0003ooooo
oooooooooooo000000Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo0?oooooo2Oooool0037ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`3oooooo`Wooooo000aooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooooooo
0_l0000<ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0ooooool9ooooo`00<Ooo
ool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool000003Oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo0?oooooo2Oooool0033ooooo0_l00003ooooo`;o0000
1?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
ooooool9ooooo`00>oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool0ooooool9ooooo`00>oooool2o`0000cooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`3oooooo`Wooooo000kooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`3oooooo`Wooooo000kooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`3oooooo`Wooooo000kooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`3oooooo`[ooooo
000kooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`3oooooo`[ooooo000kooooo`;o00003Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo0?oooooo2_ooool003_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo0?oooooo2_ooool003_ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo0?oooooo2_ooool003_ooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0?oooooo2_ooool001Oooooo0_o^
k^h3ooooo`;ok^k^7Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0ooooool:ooooo`004Oooool4o`000009oa0@4?ooooook^k^oeEEEOo^k^kooooo
onk^k_mEEEGok^k^00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^3_oo
ool2o`0000gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`3oooooo`[ooooo000C
ooooo`03o`000?oooooooooo00;ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`3oooooo`_ooooo000Cooooo`03o`000?oo
oooooooo00?ooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?oo
ooooooooooooool@41003_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool0ooooool;ooooo`004oooool00ol0003oooooooooo`02ooooo`05onk^k_mE
EEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
00003_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool0ooooool;ooooo`004oooool02ol0003oooooooooooooooook^k^oeEEEOo^k^koooooonk^k_mE
EEGok^k^00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000kooooo
0_l0000=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0ooooool;ooooo`004ooo
ool01?l0003oooooooooooooool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo
00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`3oooooo`_ooooo000Cooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo0ol00002ooooo`;o
00001?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool0ooooool;ooooo`004Oooool00omEEEGoIVIVo`00000=ooooo`03oeEEEOmVIVKo000000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0ooooool;
ooooo`00<Oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000003_ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo0?oooooo2oooool0037ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`02ooooo`;o00003_ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo0?oooooo3?ooool0037ooooo00Co0000oooooooooooo00000_ooool01Ol0
003ooooooooooooooooo000000oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`3o
ooooo`cooooo000`ooooo`;o00000oooool2o`0000Cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo0?oooooo3?ooool003_ooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo0?oooooo3?ooool003_ooooo
0_l0000>ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0ooooool<ooooo`00>ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0oooo
ool<ooooo`00>oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool0ooooool<ooooo`00>oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool0ooooool<ooooo`00>oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool0ooooool<ooooo`00>oooool2o`0000kooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`3oooooo`cooooo000kooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`3oooooo`cooooo000k
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`3o
ooooo`cooooo000kooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`3oooooo`cooooo000Hooooo`;ok^k^0oooool2onk^kQcooooo0_l0000>ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0ooooool=ooooo`000_ooool4o`000003oa0@
4?oooooooooo00;ooooo0_lQ8B45ooooo`0=odA4A?l0003o0000oc8b<_oMgMgoooooonk^k_mEEEGo
k^k^ooooooo^k^koEEEEonk^kP03ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8b
onk^kPgooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo0?oooooo3Oooool000Cooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00WoMgMgoc8b
<_ooooooooooonk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool0ooooool=ooooo`001?ooool00ol0003oooooooooo`0?ooooo`07o`00
0?oooooooooooooooooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooo
oooooooooooooa0@400=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`3oooooo`gooooo0004ooooo`03o`000?oooooooooo00kooooo00WoMgMgoc8b
<_ooooooooooonk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000003Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool0ooooool=ooooo`001?ooool00ol0003oooooooooo`0;ooooo`0=o`00
0?lQ8B7o0000oc8b<_o<c<coooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000=ooooo`;o00003oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo0?oooooo3Oooool000Cooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`03ooooo`;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@00gooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo0?oooooo3Oooool000Cooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`?o00000_ooool2o`0000?ooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo0?oooooo3Oooool000;ooooo00?oEEEEofIVI_l00000
3Oooool4o`0000cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Co
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000@ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool0ooooool=ooooo`00<_ooool00ol0003oooooooooo`03oooo
o`04o`000?ooooooooooo`00013ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`3o
ooooo`gooooo000booooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooooooo0_l0000?
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0ooooool=ooooo`00<_ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`00013ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`3oooooo`gooooo000aooooo`;o00000oooool2o`0000?ooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0?oooooo3Oooool0
03_ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
0?oooooo3Oooool003_ooooo0_l0000?ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool0ooooool=ooooo`00>oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool0ooooool=ooooo`00>oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool0ooooool=ooooo`00>oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0ooooool>ooooo`00>oooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0ooooool>oooo
o`00>oooool2o`00013ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`3oooooo`ko
oooo000kooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`3oooooo`kooooo000kooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`3oooooo`kooooo000Gooooo`;ok^k^0oooool2onk^kQgooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0?oooooo3_ooool0
013ooooo1Ol00002ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co000000So
410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPkooooo0_l0000@ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0ooooool>ooooo`004?ooool01OnHV9So8B4Qonk^k_ooooooA4A4
00?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`3oooooo`kooooo000Aooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?ogMgM
o`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41003_oo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooo
ool>ooooo`004_ooool00onHV9So8B4Qonk^kP03ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_oo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0ooooool>ooooo`004ooo
ool02omgMgOoIVIVooooooooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo3_ooool001Cooooo00?o0000
ooooooooool00_o^k^h3ooooo`;ok^k^1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooo
ooooooooool@41003_ooool2o`00017ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`3oooooo`kooooo000@ooooo`05o`000?nj^[[ooooooiRHV?l@41003_ooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0ooooool>ooooo`004?ooool01OnHV9So410@o`00
0?lQ8B7oc<c<00cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?o
oooo0ol00002ooooo`;o00001?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0ooooool>ooooo`00<Oooool01?l0003oooooooooool00002ooooo`05
o`000?ooooooooooooooool000004_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
0?oooooo3oooool0037ooooo00?o0000ooooooooool00oooool01?l0003oooooooooooooool2o`00
017ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooo`oooooo000aooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool?ooooo`00<Oooool01?l0003ooooo
ooooool00002ooooo`05o`000?ooooooooooooooool000004_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo0?oooooo3oooool0033ooooo0_l00003ooooo`;o00001?ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool?ooooo`00
>oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
ooooool?ooooo`00>oooool2o`0001;ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`3oooooo`oooooo000kooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`3oooooo`oooooo000kooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`3oooooo`oooooo000kooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooo`oooooo000kooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooooa3ooooo
000kooooo`;o00004_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo4?oo
ool003_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo0?oooooo4?ooool003_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo0?oooooo4?ooool001Sooooo0_o^k^h3ooooo`;ok^k^7?ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0ooooool@ooooo`00
00?oooooo`000?l000000ol00005ooooo`;o8B4Q1Oooool03Om4A4Co0000o`000?lb<S;ogMgMoooo
ooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb
<S;o0000oc8b<_o^k^h=ooooo`;o00004_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo0?oooooo4?ooool00006oooooonHV9So8B4Qonk^k_ooooooA4A41Oooool2ob4Q8@Sooooo00Wo
MgMgoc8b<_ooooooooooonk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0ooooool@ooooo`000_ooool00onHV9So8B4Qonk^kP0Aoooo
o`07o`000?oooooooooooooooooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go
410@oooooooooooooooooa0@400=ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`3ooooooa3ooooo0003ooooo`03oiRHV?lQ8B7ok^k^00oooooo00Wo
MgMgoc8b<_ooooooooooonk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000003Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0ooooool@ooooo`001?ooool00omgMgOoIVIVooooo`0;oooo
o`0=o`000?lQ8B7o0000oc8b<_o<c<coooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05oooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000=ooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3ooooooa3ooooo0005oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00oooool2onk^kP?ooooo0_o^k^h5oooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400=ooooo`;o00004oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo4?ooool00006ooooool0003o^[Zj
oooooonHV9So410@3?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0=ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`3ooooooa7ooooo00001_ooooooV9RHoa0@4?l0003o8B4Qolc<c0co
oooo1?l0000<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03oooo
o`?o00000_ooool2o`0000?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo0?oooooo4Oooool003;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool0000Dooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0oooooolA
ooooo`00<_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o00004oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo4Oooool003;ooooo00?o0000oooooooo
ool00_ooool01Ol0003ooooooooooooooooo000001Cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`3ooooooa7ooooo000booooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00005?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo4Oooool0
037ooooo0_l00003ooooo`;o00000oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0oooooolAooooo`00>oooool00ol0003oooooooooo`0Cooooo`05
o`000?ooooooooooooooool00000oooooolCooooo`00>oooool2o`0001Cooooo00Go0000oooooooo
ooooooooo`00003ooooooa?ooooo000kooooo`03o`000?oooooooooo01?ooooo00Go0000oooooooo
ooooooooo`00003ooooooa?ooooo000kooooo`03o`000?oooooooooo01?ooooo00Go0000oooooooo
ooooooooo`00003ooooooa?ooooo000kooooo`03o`000?oooooooooo01?ooooo00Go0000oooooooo
ooooooooo`00003ooooooa?ooooo000kooooo`;o00005?ooool01?l0003oooooooooool0003ooooo
oaCooooo000kooooo`03o`000?oooooooooo01?ooooo00Co0000oooooooooooo0000oooooolDoooo
o`00>oooool00ol0003oooooooooo`0Cooooo`04o`000?ooooooooooo`000?oooooo5?ooool003_o
oooo00?o0000ooooooooool05?ooool00ol0003oooooo`00003ooooooaCooooo000Gooooo`;ok^k^
0oooool2onk^kQgooooo00?o0000ooooooooool05?ooool00ol0003oooooo`00003ooooooaCooooo
000@ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00_ooool01oo^k^koEEEEonk^k_ooooook^k^oeEE
EOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h>ooooo`;o0000
5Oooool00ol0003oooooo`00003ooooooaCooooo000@ooooo`05oa0@4?nj^[[oooooogMgMolb<S80
0oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00kooooo00?o0000ooooooooool05?ooool2o`000?oooooo5Oooool001Co
oooo00?o0000ooooooooool00_ooool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;o
oooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo01Cooooo0_l0003ooooo
oaGooooo000Cooooo`03ojVYZOl@413ooooo00;ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06oooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooo
oooo0?oooooo:oooool001;ooooo00?o410@o`000?nj^[X00_ooool01oo^k^koEEEEonk^k_oooooo
k^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
3_ooool00ol0003oooooooooo`3oooooob_ooooo000Cooooo`04okZj^_lQ8B7oooooooooo`;ok^k^
0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00ko
oooo0_l0003oooooobcooooo000@ooooo`05oa0@4?nHV9SooooookZj^_l000003_ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`3ooooo
ob_ooooo000@ooooo`05ojVYZOl@413o0000oa0@4?nYZJT03?ooool00omEEEGoIVIVo`000004oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool3o`0000;ooooo0_l00004ooooo`03o`000?oooooo
oooo0?oooooo:oooool0037ooooo00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooo
oooo00000?oooooo;Oooool0037ooooo00?o0000ooooooooool00oooool01?l0003ooooooooooooo
ool2o`000?oooooo;?ooool0037ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo0?oooooo:oooool0037ooooo00Co0000oooooooooooo00000_ooool0
1Ol0003ooooooooooooooooo00000?oooooo;Oooool0033ooooo0_l00003ooooo`;o00001?ooool0
0ol0003oooooooooo`3oooooob_ooooo000kooooo`03o`000?oooooooooo0?oooooo:oooool003_o
oooo0_l0003oooooobcooooo000kooooo`03o`000?oooooooooo0?oooooo:oooool003_ooooo00?o
0000ooooooooool0ooooool[ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00GOooool00omgMgOoIVIVooooo`04ooooo`03o`000?oooooo
oooo00;ooooo00?o^[Zjoc8b<_ooool01oooool01_l0003oooooooooooooooooIVIVogMgM`gooooo
00?o0000okZj^_ooool0goooool005cooooo00?ogMgMoa0@4?o^k^h01Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Kooooo00Oo0000ooooooooooooooooonk^k_l@413ogMgM00co
oooo0_lb<S;Pooooo`00G?ooool00omEEEGoV9RHooooo`05ooooo`06o`000?oooooooooooooooonH
V9So410@0_l000000onYZJWoooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?oQhN7ofIV
I_ooool02oooool00on7QhOo0000okZj^P04ooooo`Go00001Oooool2ob4Q8@?ooooo00Goc<c<onk^
k_ooooook^k^olc<c003ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kQ?o
oooo00Ko410@oc8b<_l0003o0000oa0@4?nYZJT2ooooo`06onk^k_mEEEGo0000o`000?m4A4Co^[Zj
0oooool01OmVIVKo0000o`000?m4A4Coc<c<08oooooo001Looooo`03o`000?oooooooooo00Gooooo
00[o0000ooooooooooooooooo`000?nYZJWoEEEEoiRHV?mEEEGo^[Zj1Oooool00ol0003ooooooooo
o`02ooooo`03onk^k_l0003ooooo00_ooooo00?oc<c<o`000?l@41001?ooool01OnHV9So8B4Qonk^
k_ooooooA4A400Gooooo0_lQ8B43ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01Oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool01_l0003oZJVYoooooooooooo
^[Zjo`0000;ooooo00KoEEEEogMgMoooooook^k^ogMgMol@4102ooooo`06ofIVI_mgMgOooooooooo
oon7QhOo410@Soooool005cooooo00?o<S8booooooooool01Oooool02_l0003ooooooooooooooooo
<S8bonk^k_nHV9SoEEEEomgMgOl@4105ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool04_ooool00onHV9So8B4Qonk^kP0<ooooo`03omgMgOl0003ogMgM00Kooooo00?o0000oooooooo
ool00_ooool01Ol@413ooooooooooooooooo410@01Cooooo00Go^[ZjohN7QomVIVKoIVIVoa0@4002
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0T_ooool005cooooo00?o<S8boooo
ooooool01Oooool02ol0003ooooooooooooooooo^[ZjodA4A?o<c<co8B4Qooooool@413oc<c<00Co
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Cooooo`03oiRHV?lQ8B7ok^k^00[o
oooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`00000Cooooo`06oc8b<_lQ8B7oMgMgogMgMon7QhOok^k^0_ooool6o`0000;ooooo
00?o0000ooooooooool0T_ooool005cooooo00?o0000onk^k_ooool01Oooool02ol0003ooooooooo
ooooooook^k^o`000?oooooo0000oooooomVIVKoQhN700Cooooo00?o0000ooooooooool00_ooool0
0oo^k^ko0000ooooo`0Eooooo`03ogMgMomVIVKooooo00Wooooo00Goc<c<onk^k_ooooook^k^olc<
c005ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Cooooo`06o`00
0?nj^[[oooooonk^k_mgMgOo00000_ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<P;ooooo00Ko
IVIVogMgMoooooooooooohN7Qol0002?ooooo`00G?ooool00omEEEGoMgMgooooo`05ooooo`08o`00
0?oooooooooooooooomVIVKoV9RHoooooolb<S82okZj^P03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00_ooool00omgMgOoEEEEooooo`03ooooo`Co00003oooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4007ooooo`?o00000_oo
ool3o`0000Cooooo00KoZJVYob4Q8Ol0003o0000oc8b<_l00002ooooo`06onk^k_mEEEGo0000o`00
0?m4A4Cok^k^0_ooool01_o^k^koIVIVo`000?l0003oA4A4o`0008oooooo001Looooo`03omgMgOl@
413ok^k^00Gooooo00?o0000ooooooooool01?ooool00omVIVKoQhN7ooooo`05ooooo`07o`000?oo
ooooooooooooooo^k^ko410@omgMg@05ooooo`03o`000?oooooooooo00_ooooo00Go0000okZj^_oo
ooooV9RHoa0@400Dooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Z?ooool005gooooo00?oMgMgofIV
I_ooool01?ooool00ol0003oooooooooo`04ooooo`03ojVYZOm4A4Cooooo00Gooooo00Ko0000oooo
ooooooooooooofIVI_mgMgL7ooooo`03o`000?oooooooooo00[ooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c00Booooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`Co
00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0:Sooooo0021ooooo`03o`00
0?oooooooooo03Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2Xooooo`00O_oo
ool01?l0003oooooooooool0000fooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
Z?ooool007oooooo0_l0000fooooo`;o00000oooool2o`000:[ooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -2.14748*^9, 0, \
2.14748*^9}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0 1.90278e-14 [
[.32684 -0.0125 -16.5 -12.5 ]
[.32684 -0.0125 16.5 0 ]
[.54329 -0.0125 -16.5 -12.5 ]
[.54329 -0.0125 16.5 0 ]
[.75974 -0.0125 -22.5 -12.5 ]
[.75974 -0.0125 22.5 0 ]
[.97619 -0.0125 -16.5 -12.5 ]
[.97619 -0.0125 16.5 0 ]
[1.025 0 0 -6 ]
[1.025 0 64 6 ]
[.09789 .09514 -33 -6.25 ]
[.09789 .09514 0 6.25 ]
[.09789 .19028 -33 -6.25 ]
[.09789 .19028 0 6.25 ]
[.09789 .28542 -45 -6.25 ]
[.09789 .28542 0 6.25 ]
[.09789 .38056 -33 -6.25 ]
[.09789 .38056 0 6.25 ]
[.09789 .47569 -45 -6.25 ]
[.09789 .47569 0 6.25 ]
[.09789 .57083 -33 -6.25 ]
[.09789 .57083 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -53.4375 0 ]
[.5 .63053 53.4375 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 0 m
.32684 .00625 L
s
gsave
.32684 -0.0125 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 0 m
.54329 .00625 L
s
gsave
.54329 -0.0125 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 0 m
.75974 .00625 L
s
gsave
.75974 -0.0125 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 0 m
.15368 .00375 L
s
.19697 0 m
.19697 .00375 L
s
.24026 0 m
.24026 .00375 L
s
.28355 0 m
.28355 .00375 L
s
.37013 0 m
.37013 .00375 L
s
.41342 0 m
.41342 .00375 L
s
.45671 0 m
.45671 .00375 L
s
.5 0 m
.5 .00375 L
s
.58658 0 m
.58658 .00375 L
s
.62987 0 m
.62987 .00375 L
s
.67316 0 m
.67316 .00375 L
s
.71645 0 m
.71645 .00375 L
s
.80303 0 m
.80303 .00375 L
s
.84632 0 m
.84632 .00375 L
s
.88961 0 m
.88961 .00375 L
s
.9329 0 m
.9329 .00375 L
s
.0671 0 m
.0671 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09514 m
.11664 .09514 L
s
gsave
.09789 .09514 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(12) show
grestore
.11039 .19028 m
.11664 .19028 L
s
gsave
.09789 .19028 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.11039 .28542 m
.11664 .28542 L
s
gsave
.09789 .28542 -45 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.11039 .38056 m
.11664 .38056 L
s
gsave
.09789 .38056 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.11039 .47569 m
.11664 .47569 L
s
gsave
.09789 .47569 -45 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.11039 .57083 m
.11664 .57083 L
s
gsave
.09789 .57083 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(3) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.125 Mabswid
.11039 .01903 m
.11414 .01903 L
s
.11039 .03806 m
.11414 .03806 L
s
.11039 .05708 m
.11414 .05708 L
s
.11039 .07611 m
.11414 .07611 L
s
.11039 .11417 m
.11414 .11417 L
s
.11039 .13319 m
.11414 .13319 L
s
.11039 .15222 m
.11414 .15222 L
s
.11039 .17125 m
.11414 .17125 L
s
.11039 .20931 m
.11414 .20931 L
s
.11039 .22833 m
.11414 .22833 L
s
.11039 .24736 m
.11414 .24736 L
s
.11039 .26639 m
.11414 .26639 L
s
.11039 .30444 m
.11414 .30444 L
s
.11039 .32347 m
.11414 .32347 L
s
.11039 .3425 m
.11414 .3425 L
s
.11039 .36153 m
.11414 .36153 L
s
.11039 .39958 m
.11414 .39958 L
s
.11039 .41861 m
.11414 .41861 L
s
.11039 .43764 m
.11414 .43764 L
s
.11039 .45667 m
.11414 .45667 L
s
.11039 .49472 m
.11414 .49472 L
s
.11039 .51375 m
.11414 .51375 L
s
.11039 .53278 m
.11414 .53278 L
s
.11039 .55181 m
.11414 .55181 L
s
.11039 .58986 m
.11414 .58986 L
s
.11039 .60889 m
.11414 .60889 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -114.438 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.812 moveto
(H) show
69.000 13.812 moveto
(\\310) show
75.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.812 moveto
(\\310) show
87.000 13.812 moveto
(L) show
93.000 9.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
98.250 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
104.250 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.) show
116.250 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
122.250 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
134.250 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
138.438 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
147.875 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
165.875 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.02499 0 L
.02605 0 L
.02729 0 L
.02846 0 L
.02954 0 L
.03053 0 L
.03163 0 L
.03279 0 L
.03395 0 L
.0352 0 L
.03638 0 L
.03746 0 L
.03873 0 L
.03944 0 L
.04011 0 L
.04132 0 L
.04262 0 L
.04327 0 L
.04396 0 L
.04519 0 L
.04588 0 L
.04652 0 L
.04726 0 L
.04797 0 L
.04925 0 L
.05041 0 L
.05166 0 L
.05236 0 L
.05302 0 L
.05414 0 L
.05519 0 L
.05634 0 L
.05759 0 L
.05882 0 L
.06012 0 L
.06123 0 L
.06244 0 L
.06315 0 L
.06381 0 L
.06451 0 L
.06529 0 L
.06659 0 L
.06731 0 L
.06797 0 L
.06924 0 L
.0704 0 L
.07173 0 L
.073 0 L
.07435 0 L
Mistroke
.07511 0 L
.0758 0 L
.07713 0 L
.07839 0 L
.07911 0 L
.07987 0 L
.08122 0 L
.08197 0 L
.08268 0 L
.08351 0 L
.08427 0 L
.08554 0 L
.08691 0 L
.08812 0 L
.08941 0 L
.09055 0 L
.09163 0 L
.09281 0 L
.09408 0 L
.09536 0 L
.09675 0 L
.09821 0 L
.09956 0 L
.10083 0 L
.10199 0 L
.10332 0 L
.10458 0 L
.10574 0 L
.10698 0 L
.10815 0 L
.10922 0 L
.11048 0 L
.11184 0 L
.11313 0 L
.11433 0 L
.11555 0 L
.1167 0 L
.11796 0 L
.11932 0 L
.12067 0 L
.12209 0 L
.1233 0 L
.12463 0 L
.12588 0 L
.12705 0 L
.12925 0 L
.13049 0 L
.13162 0 L
.13295 0 L
.13419 1e-05 L
Mistroke
.13625 1e-05 L
.13734 1e-05 L
.13852 1e-05 L
.13974 1e-05 L
.14091 2e-05 L
.1431 2e-05 L
.14434 3e-05 L
.14569 4e-05 L
.14688 5e-05 L
.14813 6e-05 L
.15051 8e-05 L
.15269 .00012 L
.15522 .00017 L
.15757 .00024 L
.16015 .00036 L
.1616 .00044 L
.16292 .00053 L
.16527 .00073 L
.16745 .00099 L
.16983 .00136 L
.17237 .00188 L
.17456 .00248 L
.17662 .00319 L
.17888 .00418 L
.18131 .00555 L
.18371 .00728 L
.18628 .00963 L
.19089 .01556 L
.19372 .02056 L
.19638 .02645 L
.20137 .04121 L
.20664 .06334 L
.2115 .09082 L
.21683 .12965 L
.22247 .18063 L
.23264 .29213 L
.24228 .40117 L
.24648 .44147 L
.25094 .47526 L
.25351 .48941 L
.25473 .49457 L
.25584 .49842 L
.25696 .50143 L
.25818 .50365 L
.25925 .50472 L
.26038 .50493 L
.26159 .50412 L
.2627 .50244 L
.26398 .49941 L
.26519 .49547 L
Mistroke
.26733 .48599 L
.26967 .47231 L
.27496 .42989 L
.27984 .38012 L
.29063 .25617 L
.30074 .15178 L
.30536 .11372 L
.30975 .08396 L
.31482 .05716 L
.31945 .03891 L
.32193 .03129 L
.32457 .02456 L
.32931 .01548 L
.33222 .01148 L
.33496 .00857 L
.33742 .00653 L
.34008 .00481 L
.34245 .00364 L
.34499 .00267 L
.34739 .00198 L
.34958 .00149 L
.35214 .00106 L
.35493 .00073 L
.35757 .0005 L
.36001 .00036 L
.36251 .00025 L
.36486 .00017 L
.3662 .00014 L
.36744 .00012 L
.36888 9e-05 L
.37022 7e-05 L
.37274 5e-05 L
.37407 4e-05 L
.3755 3e-05 L
.377 2e-05 L
.37842 2e-05 L
.37969 2e-05 L
.38107 1e-05 L
.38232 1e-05 L
.38346 1e-05 L
.38569 1e-05 L
.38694 0 L
.3883 0 L
.38958 0 L
.39078 0 L
.39214 0 L
.39337 0 L
.39469 0 L
.39612 0 L
.39738 0 L
Mistroke
.3987 0 L
.39983 0 L
.40107 0 L
.40231 0 L
.40348 0 L
.40455 0 L
.40568 0 L
.40691 0 L
.40805 0 L
.40927 0 L
.41062 0 L
.41177 0 L
.41283 0 L
.41399 0 L
.41521 0 L
.41628 0 L
.41727 0 L
.41836 0 L
.41952 0 L
.42076 0 L
.42212 0 L
.42354 0 L
.42486 0 L
.4261 0 L
.42724 0 L
.42854 0 L
.42978 0 L
.43112 0 L
.43255 0 L
.43376 0 L
.4351 0 L
.43654 0 L
.43735 0 L
.43809 0 L
.43946 0 L
.44015 0 L
.4409 0 L
.44226 0 L
.44354 0 L
.44469 0 L
.44594 0 L
.4473 0 L
.44799 0 L
.44875 0 L
.44939 0 L
.45008 0 L
.45134 0 L
.45258 0 L
.45329 0 L
.45394 0 L
Mistroke
.45514 0 L
.45641 0 L
.45767 0 L
.45885 0 L
.45991 0 L
.46106 0 L
.4623 0 L
.46343 0 L
.46474 0 L
.46598 0 L
.46712 0 L
.46818 0 L
.46934 0 L
.47057 0 L
.4718 0 L
.47249 0 L
.47313 0 L
.4743 0 L
.47553 0 L
.47618 0 L
.47688 0 L
.47814 0 L
.47891 0 L
.47964 0 L
.48035 0 L
.481 0 L
.48222 0 L
.48287 0 L
.48356 0 L
.48428 0 L
.48497 0 L
.48626 0 L
.48747 0 L
.48858 0 L
.48981 0 L
.49111 0 L
.49186 0 L
.49254 0 L
.49329 0 L
.49408 0 L
.49472 0 L
.49541 0 L
.49616 0 L
.49686 0 L
.49753 0 L
.49826 0 L
.49891 0 L
.49959 0 L
.50088 0 L
.50207 0 L
Mistroke
.50327 0 L
.50458 0 L
.50582 0 L
.50698 0 L
.50812 0 L
.50915 0 L
.51034 0 L
.51147 0 L
.5127 0 L
.514 0 L
.51511 0 L
.51633 0 L
.51764 0 L
.51837 0 L
.51905 0 L
.52035 0 L
.52159 0 L
.52263 0 L
.52379 0 L
.525 0 L
.52613 0 L
.52719 0 L
.52816 0 L
.52922 0 L
.53035 0 L
.53148 0 L
.5327 0 L
.53385 0 L
.5349 0 L
.53613 0 L
.53682 0 L
.53746 0 L
.53864 0 L
.53988 0 L
.54109 0 L
.54241 0 L
.54365 0 L
.5448 0 L
.54595 0 L
.54698 0 L
.54818 0 L
.5493 0 L
.55054 0 L
.55184 0 L
.55295 0 L
.55417 0 L
.55549 0 L
.55622 0 L
.5569 0 L
.5582 0 L
Mistroke
.55944 0 L
.56049 0 L
.56165 0 L
.56286 0 L
.56399 0 L
.56505 0 L
.56602 0 L
.56709 0 L
.56821 0 L
.56935 0 L
.57057 0 L
.57172 0 L
.57276 0 L
.57399 0 L
.57469 0 L
.57533 0 L
.5765 0 L
.57774 0 L
.57896 0 L
.58028 0 L
.58153 0 L
.58268 0 L
.58383 0 L
.58487 0 L
.58607 0 L
.58719 0 L
.58843 0 L
.58974 0 L
.59085 0 L
.59207 0 L
.59339 0 L
.59413 0 L
.5948 0 L
.5961 0 L
.59734 0 L
.59839 0 L
.59955 0 L
.60077 0 L
.6019 0 L
.60297 0 L
.60394 0 L
.60506 0 L
.60612 0 L
.60727 0 L
.60849 0 L
.60964 0 L
.61068 0 L
.61191 0 L
.61261 0 L
.61324 0 L
Mistroke
.61442 0 L
.61566 0 L
.61688 0 L
.61757 0 L
.6182 0 L
.61937 0 L
.62061 0 L
.62172 0 L
.62276 0 L
.6239 0 L
.62513 0 L
.62637 0 L
.62706 0 L
.62771 0 L
.62903 0 L
.62976 0 L
.63043 0 L
.63163 0 L
.63293 0 L
.63416 0 L
.63529 0 L
.63635 0 L
.63748 0 L
.63855 0 L
.63953 0 L
.64068 0 L
.64192 0 L
.6431 0 L
.6442 0 L
.64543 0 L
.64659 0 L
.64764 0 L
.64876 0 L
.65 0 L
.6513 0 L
.65241 0 L
.65362 0 L
.65493 0 L
.65614 0 L
.65678 0 L
.65747 0 L
.6582 0 L
.65888 0 L
.66013 0 L
.66128 0 L
.66253 0 L
.66385 0 L
.66497 0 L
.66616 0 L
.66729 0 L
Mistroke
.66831 0 L
.66951 0 L
.67081 0 L
.67204 0 L
.67317 0 L
.67438 0 L
.67567 0 L
.6769 0 L
.67802 0 L
.67932 0 L
.68006 0 L
.68075 0 L
.68201 0 L
.68264 0 L
.68334 0 L
.68402 0 L
.68473 0 L
.68601 0 L
.68672 0 L
.68738 0 L
.68811 0 L
.68889 0 L
.68956 0 L
.69029 0 L
.69098 0 L
.69161 0 L
.69282 0 L
.6941 0 L
.6953 0 L
.69662 0 L
.69786 0 L
.69902 0 L
.70016 0 L
.70119 0 L
.70239 0 L
.70352 0 L
.70475 0 L
.70605 0 L
.70716 0 L
.70838 0 L
.70969 0 L
.71043 0 L
.7111 0 L
.71241 0 L
.71364 0 L
.71469 0 L
.71585 0 L
.71706 0 L
.7182 0 L
.71926 0 L
Mistroke
.72023 0 L
.72129 0 L
.72241 0 L
.72355 0 L
.72477 0 L
.72592 0 L
.72697 0 L
.7282 0 L
.72889 0 L
.72953 0 L
.7307 0 L
.73195 0 L
.73316 0 L
.73448 0 L
.73573 0 L
.73688 0 L
.73803 0 L
.73907 0 L
.74026 0 L
.74139 0 L
.74263 0 L
.74393 0 L
.74505 0 L
.74627 0 L
.74758 0 L
.74832 0 L
.74899 0 L
.7503 0 L
.75153 0 L
.75259 0 L
.75375 0 L
.75496 0 L
.7561 0 L
.75716 0 L
.75813 0 L
.75925 0 L
.76031 0 L
.76146 0 L
.76268 0 L
.76383 0 L
.76487 0 L
.7661 0 L
.7668 0 L
.76743 0 L
.76861 0 L
.76985 0 L
.77107 0 L
.77176 0 L
.77239 0 L
.77356 0 L
Mistroke
.7748 0 L
.77591 0 L
.77695 0 L
.77809 0 L
.77932 0 L
.78055 0 L
.78125 0 L
.7819 0 L
.78321 0 L
.78395 0 L
.78462 0 L
.78581 0 L
.78711 0 L
.78834 0 L
.78947 0 L
.79053 0 L
.79166 0 L
.79273 0 L
.79371 0 L
.79486 0 L
.7961 0 L
.79728 0 L
.79838 0 L
.79961 0 L
.80077 0 L
.80181 0 L
.80294 0 L
.80417 0 L
.80548 0 L
.80659 0 L
.8078 0 L
.80911 0 L
.81032 0 L
.81095 0 L
.81165 0 L
.81237 0 L
.81306 0 L
.81431 0 L
.81545 0 L
.81671 0 L
.81803 0 L
.81914 0 L
.82033 0 L
.82146 0 L
.82248 0 L
.82368 0 L
.82498 0 L
.82621 0 L
.82734 0 L
.82855 0 L
Mistroke
.82984 0 L
.83107 0 L
.83218 0 L
.83349 0 L
.83423 0 L
.83492 0 L
.83617 0 L
.83681 0 L
.83751 0 L
.83818 0 L
.8389 0 L
.84017 0 L
.84089 0 L
.84155 0 L
.84227 0 L
.84305 0 L
.84372 0 L
.84445 0 L
.84514 0 L
.84578 0 L
.84699 0 L
.84826 0 L
.84947 0 L
.85078 0 L
.85203 0 L
.85318 0 L
.85432 0 L
.85536 0 L
.85655 0 L
.85768 0 L
.85891 0 L
.86021 0 L
.86132 0 L
.86254 0 L
.86385 0 L
.86459 0 L
.86526 0 L
.86656 0 L
.8678 0 L
.86885 0 L
.87001 0 L
.87122 0 L
.87235 0 L
.87341 0 L
.87438 0 L
.87545 0 L
.87657 0 L
.87771 0 L
.87893 0 L
.88008 0 L
Mistroke
.88112 0 L
.88235 0 L
.88304 0 L
.88368 0 L
.88486 0 L
.8861 0 L
.88731 0 L
.88863 0 L
.88988 0 L
.89103 0 L
.89218 0 L
.89322 0 L
.89441 0 L
.89554 0 L
.89678 0 L
.89808 0 L
.89919 0 L
.90041 0 L
.90173 0 L
.90247 0 L
.90314 0 L
.90444 0 L
.90568 0 L
.90673 0 L
.90789 0 L
.9091 0 L
.91024 0 L
.9113 0 L
.91227 0 L
.91334 0 L
.91446 0 L
.9156 0 L
.91682 0 L
.91797 0 L
.91901 0 L
.92024 0 L
.92094 0 L
.92158 0 L
.92275 0 L
.92399 0 L
.92521 0 L
.9259 0 L
.92653 0 L
.9277 0 L
.92894 0 L
.93005 0 L
.93109 0 L
.93223 0 L
.93346 0 L
.93469 0 L
Mistroke
.93538 0 L
.93603 0 L
.93735 0 L
.93808 0 L
.93875 0 L
.93995 0 L
.94125 0 L
.94247 0 L
.94361 0 L
.94466 0 L
.9458 0 L
.94687 0 L
.94784 0 L
.94899 0 L
.95023 0 L
.95141 0 L
.95251 0 L
.95374 0 L
.9549 0 L
.95594 0 L
.95707 0 L
.9583 0 L
.9596 0 L
.96072 0 L
.96193 0 L
.96282 0 L
.96378 0 L
.96469 0 L
.96554 0 L
.96629 0 L
.96713 0 L
.968 0 L
.96882 0 L
.96972 0 L
.97067 0 L
.97148 0 L
.97237 0 L
.97332 0 L
.97435 0 L
.97531 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00H_ooool2onk^kP?ooooo0_o^
k^h]ooooo`;ok^k^0oooool2onk^kSKooooo0_o^k^h3ooooo`;ok^k^9?ooool2onk^kP?ooooo0_o^
k^iSooooo`00G?ooool03Om4A4Co0000o`000?lb<S;ogMgMooooooo^k^koEEEEonk^k_ooooook^k^
oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hHooooo`Co
000000Wo410@ooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?oo
ooooooooonk^k_lb<S;o0000oc8b<_o^k^hAooooo`Co000000?o410@ooooooooool00_ooool2ob4Q
8@Gooooo00goA4A4o`000?l0003o<S8bomgMgOooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^
00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^3_ooool5o`0000;ooooo
00Ook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413oooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^E?ooool005oooooo00WoMgMgoc8b<_ooooooooooonk^k_mEEEGogMgMoeEE
EOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool0
0ol0003oooooooooo`02ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool00ol0003oooooooooo`04ooooo`;o8B4Q
2?ooool02OmgMgOo<S8booooooooooook^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
0oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg05Cooooo001Pooooo`07o`000?oooooooooooooooooMgMgo0000omgMg@07
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Jooooo`03o`000?oo
oooooooo00?ooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?oo
ooooooooooooool@41004oooool00ol0003oooooooooo`0?ooooo`07o`000?oooooooooooooooooM
gMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400?
ooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@4100E?ooool005oooooo00WoMgMgoc8b<_ooooooooooonk^
k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000006_ooool00ol0003oooooooooo`02ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000004oooool00ol0003ooooooooo
o`0>ooooo`09ogMgMolb<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo0000013ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000005Cooooo001Looooo`0=o`000?lQ8B7o0000oc8b<_o<c<coooooonk^k_mEEEGok^k^
ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Jooooo`0;o`000?ooooooooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Ooo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000004oooool00ol0003ooooo
ooooo`0;ooooo`0=o`000?lQ8B7o0000oc8b<_o<c<coooooonk^k_mEEEGok^k^ooooooo^k^koEEEE
onk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Aooooo`0;
ogMgMomVIVKoooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool00000E?ooool005cooooo00?o0000ooooooooool0
0oooool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@400Jooooo`04o`000?ooooooooooooooo`;ok^k^0oooool2onk^kPGooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@01?ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`03ooooo`;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@01;ooooo00?o0000ooooooooool00_o^k^h3ooooo`;ok^k^1Ooo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100E?ooool005cooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
6_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Cooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool01Ol0003o^[ZjoooooonHV9So
410@00kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg05Cooooo001L
ooooo`Co00003?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?oo
ool00ol0003oooooooooo`0=ooooo`03oeEEEOmVIVKo000000gooooo00?oEEEEofIVI_l000001?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo0_l00007ooooo`03oeEEEOmVIVKo000000gooooo
1?l0000<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`;o
00001?ooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo00?oEEEEofIVI_l000001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Sooooo0_l0001:ooooo`00P?ooool00ol0003oooooooooo`0`oooo
o`04o`000?ooooooooooo`0003Wooooo00Co0000oooooooooooo00009oooool01?l0003ooooooooo
ool00019ooooo`00N_ooool4o`0000?ooooo00?o0000ooooooooool0:_ooool4o`000005ooooool0
003oooooooooool00000=?ooool4o`000005ooooool0003oooooooooool000008_ooool4o`000005
ooooool0003oooooooooool00000BOooool0087ooooo00?o0000ooooooooool0;oooool3o`0003[o
oooo0ol0000Xooooo`?o0000B_ooool007oooooo00Co0000oooooooooooo0000<Oooool00ol0003o
ooooooooo`0jooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool03_ooool00omgMgOo
IVIVooooo`0^ooooo`03ofIVI_mgMgOooooo00Oooooo001oooooo`Co0000<_ooool00ol0003ooooo
ooooo`0jooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool03?ooool00ooMgMgo410@
onk^kP0_ooooo`03onk^k_l@413ogMgM00Oooooo003ooooooa_ooooo0_l00002ooooo`;o00003?oo
ool01?mEEEGoV9RHooooooooool2o`0000;ooooo00Oo0000oooooooooooo0000oa0@4?o^k^koEEEE
00;o000000?oA4A4okZj^_ooool00_ooool01OnHV9So0000o`000?m4A4Co^[Zj00;ooooo00Sok^k^
oeEEEOl0003o0000odA4A?nj^[[ooooooa0@40Go00000oooool02?l@413o<S8bo`000?l0003o410@
ojVYZOn7QhOoIVIV1oooool00?oooooo6oooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@cooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`08o`000?ooooooEEEEogMg
Moooooook^k^ogMgMol@4103ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000_ooool01_mEEEGoMgMg
ooooooo^k^koMgMgoa0@40?ooooo00?o0000ooooooooool01?ooool02?l0003oZJVYoooooooooooo
^[Zjo`000?o^k^ko00001oooool0023ooooolOl0000:ooooo`04omgMgOl0003o410@olc<c0gooooo
00?o<S8booooooooool00_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo000000So
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Go
oooo00Oo^[ZjohN7QomVIVKoIVIVoa0@4?oooooo000000Oooooo000Vooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo0000
00Co00001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool02?ooool01?l0003oooooooooooooool4o`0000;ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00gooooo00Cok^k^ob4Q8Ol@413ok^k^3Ooo
ool00olb<S;oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooool00000
1Ol00003ooooo`03o`000?oooooooooo00Cooooo1_l00003ooooo`03o`000?oooooooooo00Cooooo
00So<S8bob4Q8OmgMgOoMgMgohN7Qoo^k^koooooo`0000Oooooo000kooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool08?ooool01?l0003oooooo`000?l0000`ooooo`03o`000?oooooo
oooo037ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0=ooooo`04ob4Q8OmgMgOo
MgMgoc8b<Pgooooo00?o0000onk^k_ooool00_ooool03_l0003oc<c<olc<c?l0003oZJVYomgMgOlQ
8B7ooooooeEEEOn7QhOok^k^oooooon7QhOo<S8b0oooool00ol0003oooooooooo`04ooooo`06oeEE
EOn7QhOok^k^oooooon7QhOo<S8b0oooool00ol0003o<S8bomgMg@04ooooo`08o`000?nj^[[ooooo
onk^k_mgMgOo0000onk^k_l00007ooooo`00>oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo023ooooo00?o0000ooooooooool0Yoooool2o`0000;ooooo0_l0000<ooooo`0?oeEEEOmg
MgOoooooooooool@413o0000ob4Q8Ol0003oMgMgoa0@4?l0003oZJVYooooooo^k^koEEEE00;o0000
00CoA4A4onk^k_oooooo410@1Ol00003ooooo`06onk^k_mEEEGo0000o`000?m4A4Cok^k^0_ooool2
o`000004ojVYZOlQ8B7o0000ob4Q8@;ooooo00SoZJVYob4Q8Ol0003o0000oc8b<_l0003oMgMgoeEE
E@Oooooo000kooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`2jooooo`03omgMgOl@413ok^k^01?ooooo00?o0000ooooooooool06Oooool00oo^k^ko
410@omgMg@07ooooo`00>oooool2o`0001;ooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`2kooooo`03ogMgMomVIVKooooo01;ooooo00?o0000ooooooooool06Oooool00omVIVKoMgMg
ooooo`07ooooo`00>oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool0moooool003_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo0?Oooooo000kooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`3gooooo`00>oooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool0moooool003_ooooo0_l0000Dooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool0n?ooool003_ooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo0?Sooooo000kooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`3hooooo`00>oooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0nOooool003_o
oooo0_l0000Eooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0nOooool003_ooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo0?Wooooo
000kooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`3iooooo`00>oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool0nOooool001Oooooo0_o^k^h3ooooo`;ok^k^7Oooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0n_ooool0017ooooo00goA4A4o`000?l0
003o<S8bomgMgOooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413o
ooooooooooo^k^ko<S8bo`000?lb<S;ok^k^3_ooool2o`0001Gooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`3jooooo`005?ooool02OmgMgOo<S8booooooooooook^k^oeEEEOoMgMgo
EEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`3joooo
o`005Oooool01ol0003ooooooooooooooooogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool0n_ooool001Cooooo00WoMgMgoc8b<_ooooooooooonk^
k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000003_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool0n_ooool0017ooooo00go0000ob4Q8Ol0003o<S8bolc<c?ooooook^k^oeEEEOo^k^kooooo
onk^k_mEEEGok^k^00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
00kooooo0_l0000Fooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0n_ooool0017o
oooo00?o0000ooooooooool00oooool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;o
oooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`3jooooo`004Oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`?o000000?oooooo`00
0?l000000_l00003ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`3kooooo`004Oooool4o`0000cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Cooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`3kooooo`00<Oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo0?_ooooo000aooooo`03o`000?oooooooooo00?o
oooo00Co0000oooooooooooooooo0_l0000Gooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool0noooool0037ooooo00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo
000001Sooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`3kooooo`00<?ooool2o`00
00?ooooo0_l00004ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`3kooooo`00>oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool0o?ooool003_ooooo0_l0000Gooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool0o?ooool003_ooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo0?cooooo000kooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`3looooo`00>oooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0o?ooool003_ooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo0?gooooo000kooooo`;o0000
6?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo0?gooooo000kooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`3mooooo`00>oooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0oOooool0
03_ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
0?gooooo000Gooooo`;ok^k^0oooool2onk^kQgooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo0?gooooo000Aooooo`Co000000Wo410@ooooooo^k^ko
EEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000
oc8b<_o^k^h>ooooo`;o00006Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0?go
oooo000Cooooo`03o`000?oooooooooo00;ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`3mooooo`004oooool00ol0003o
ooooooooo`03ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@413o
oooooooooooooooo410@00kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo0?kooooo000Cooooo`03o`000?oooooooooo00;ooooo00Gok^k^oeEEEOoM
gMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`3n
ooooo`004oooool02ol0003oooooooooooooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Go
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000kooooo0_l0000Ioooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool0o_ooool001?ooooo00Co0000oooooooo
oooooooo0_o^k^h3ooooo`;ok^k^1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@41003_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool0o_ooool001?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL00oooool3o`0000;ooooo0_l00004ooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`3nooooo`004Oooool00omE
EEGoIVIVo`00000=ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04
ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`00000Jooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool0o_ooool0037ooooo00?o0000ooooooooool00ooo
ool01Ol0003ooooooooooooooooo000001[ooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`3nooooo`00<Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo0_l0
000Iooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0o_ooool0037ooooo00Co0000
oooooooooooo00000_ooool01Ol0003ooooooooooooooooo000001_ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`3nooooo`00<?ooool2o`0000?ooooo0_l00004ooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`3nooooo`00>oooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0o_ooool0
03_ooooo0_l0000Jooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0o_ooool003_o
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo0?ko
oooo000kooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`3oooooo`00>oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool0ooooool003_ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo0?oooooo000kooooo`;o00006_ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo0?oooooo000kooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`3oooooo`00>oooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool0ooooool003_ooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo0?oooooo000Hooooo`;ok^k^0oooool2
onk^kQcooooo0_l0000Jooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0ooooool0
00;ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool03Om4A4Co0000o`000?lb<S;o
gMgMooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^h=ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`3oooooo`001?ooool00ol0003oooooooooo`04ooooo`;o8B4Q2?oo
ool02OmgMgOo<S8booooooooooook^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0=ooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`3oooooo`001?ooool00ol0003oooooooooo`0?oooo
o`07o`000?oooooooooooooooooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go
410@oooooooooooooooooa0@400=ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`3oooooo`001?ooool00ol0003oooooooooo`0>ooooo`09ogMgMolb
<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0
003ooooooooooooooooo000000gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo0?oooooo0Oooool000Cooooo00?o0000ooooooooool02oooool03Ol0
003o8B4Qo`000?lb<S;oc<c<ooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000003Oooool2o`0001_ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`3oooooo`7ooooo0004ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool00oooool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo
00;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`3oooooo`7ooooo0004ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00oooool3o`0000;ooooo0_l00003ooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`3oooooo`7ooooo0002ooooo`03oeEEEOmVIVKo0000
00gooooo1?l0000<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00007?ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo0?oooooo0Oooool003;ooooo00?o0000ooooooooool00ooo
ool01?l0003oooooooooool0000Looooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
ooooool1ooooo`00<_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooooooo`;o0000
6oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0?oooooo0Oooool003;ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool0000Looooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool0ooooool1ooooo`00<Oooool2o`0000?ooooo0_l00003ooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`3oooooo`7ooooo
000kooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`3oooooo`7ooooo000kooooo`;o00007?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo0?oooooo0_ooool003_ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo0?oooooo0_ooool003_ooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo0?oooooo0_ooool003_ooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0?oooooo0_ooool003_ooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0?oooooo0_oo
ool003_ooooo0_l0000Looooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0ooooool2
ooooo`00>oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool0ooooool2ooooo`00>oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool0ooooool2ooooo`005oooool2onk^kP?ooooo0_o^k^hMooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`3oooooo`;ooooo
000@ooooo`Go00000_ooool01oo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008
oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h>ooooo`;o00007?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo0?oooooo0_ooool0013ooooo00GoV9RHob4Q8Oo^k^koooooodA4
A003ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0ooooool3ooooo`004Oooool00onHV9So8B4Qonk^kP05ooooo`03omgM
gOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00ko
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oo
oooo0oooool001;ooooo00?oV9RHob4Q8Oo^k^h00oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Ko
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000kooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo0oooool001?o
oooo00_oMgMgofIVI_ooooooooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooo`?ooooo000Dooooo`03o`00
0?oooooooooo00;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@413ooooo
oooooooooooo410@00kooooo0_l0000Mooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0ooooool3ooooo`004?ooool01Ol0003o^[ZjoooooonHV9So410@00kooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo0oooool0013ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c00<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03
ooooo`?o00000_ooool2o`0000Cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo0?oooooo0oooool0037ooooo00Co0000oooooooooooo00000_ooool0
1Ol0003ooooooooooooooooo000001kooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`3oooooo`?ooooo000aooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooooooo0_l0
000Mooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooool3ooooo`00<Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo0oooool0037ooooo00Co0000oooo
oooooooo00000_ooool01Ol0003ooooooooooooooooo000001kooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`3oooooo`?ooooo000`ooooo`;o00000oooool2o`0000Cooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo1?ooool0
03_ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?oooooo1?ooool003_ooooo0_l0000Mooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0ooooool4ooooo`00>oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0ooooool4ooooo`00>oooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0ooooool4ooooo`00>oooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0ooooool4ooooo`00>oooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0ooooool4oooo
o`00>oooool2o`0001kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooo`Co
oooo000kooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`3oooooo`Cooooo000kooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`3oooooo`Cooooo000Hooooo`;ok^k^0oooool2onk^kQcooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo1?ooool0
0003ooooool0003o000000?o00001Oooool2ob4Q8@Gooooo00goA4A4o`000?l0003o<S8bomgMgOoo
ooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413oooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^3Oooool2o`0001oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`3oooooo`Gooooo00001_ooooooV9RHob4Q8Oo^k^koooooodA4A0Gooooo0_lQ8B48ooooo`09
ogMgMolb<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00gooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo0?oooooo1Oooool000;ooooo00?oV9RHob4Q8Oo^k^h04Ooo
ool01ol0003ooooooooooooooooogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05
oa0@4?ooooooooooooooool@41003Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0ooooool5ooooo`000oooool00onHV9So8B4Qonk^kP0?ooooo`09
ogMgMolb<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo0?oooooo1Oooool000Cooooo00?oMgMgofIVI_ooool02ooo
ool03Ol0003o8B4Qo`000?lb<S;oc<c<ooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Ooo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000003Oooool00ol0003ooooo
ooooo`0Oooooo`05o`000?ooooooooooooooool00000ooooool7ooooo`001Oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00?ooooo0_o^k^h3ooooo`;ok^k^1Oooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41003Oooool2o`00023ooooo00Go0000oooooooo
ooooooooo`00003oooooo`Oooooo00001_oooooo0000okZj^_ooooooV9RHoa0@40cooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03Ooo
ool00ol0003oooooooooo`0Oooooo`04o`000?ooooooooooo`000?oooooo2?ooool00006oooooonH
V9So410@o`000?lQ8B7oc<c<3?ooool4o`0000cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00?ooooo0ol00002ooooo`;o00000oooool00ol0003oooooooooo`0Ooooo
o`04o`000?ooooooooooo`000?oooooo2?ooool003;ooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool0000Qooooo`04o`000?ooooooooooo`000?oooooo2?ooool003;ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02o`00023ooooo00Co0000oooooooooooo0000
ooooool8ooooo`00<_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
8_ooool00ol0003oooooo`00003oooooo`Sooooo000booooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00008_ooool2o`000?oooooo2Oooool0037ooooo0_l00003ooooo`;o0000
0oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo0?oooooo1oooool003_ooooo00?o
0000ooooooooool0ooooool[ooooo`00>oooool2o`000?oooooo;?ooool003_ooooo00?o0000oooo
ooooool0ooooool[ooooo`00>oooool00ol0003oooooooooo`3oooooob_ooooo000kooooo`03o`00
0?oooooooooo0?oooooo:oooool003_ooooo0_l0003oooooobcooooo000kooooo`03o`000?oooooo
oooo0?oooooo:oooool003_ooooo00?o0000ooooooooool0ooooool[ooooo`00>oooool00ol0003o
ooooooooo`3oooooob_ooooo000Gooooo`;ok^k^0oooool2onk^kQgooooo00?o0000ooooooooool0
ooooool[ooooo`004?ooool01OnHV9So410@o`000?lb<S;oc<c<00;ooooo00Ook^k^oeEEEOo^k^ko
ooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^
3_ooool2o`000?oooooo;?ooool0013ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05onk^
k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL03_ooool00ol0003oooooooooo`3oooooob_ooooo000Dooooo`03o`000?oooooooooo00;o
oooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooo
ool@41003_ooool00ol0003oooooooooo`3oooooob_ooooo000Cooooo`03ojVYZOl@413ooooo00;o
oooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03o`000?oooooooooo0?oooooo:oooool001;ooooo00?o410@o`00
0?nj^[X00_ooool01oo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003oooooooooo`3oooooob_ooooo
000Cooooo`04okZj^_lQ8B7oooooooooo`;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@00kooooo0_l0003oooooobcooooo000@ooooo`05oa0@
4?nHV9SooooookZj^_l000003_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL03_ooool00ol0003oooooooooo`3oooooob_ooooo000@ooooo`05ojVYZOl@413o0000oa0@
4?nYZJT03?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool3
o`0000;ooooo0_l00004ooooo`03o`000?oooooooooo0?oooooo:oooool0037ooooo00Co0000oooo
oooooooo00000_ooool01Ol0003ooooooooooooooooo00000?oooooo;Oooool0037ooooo00?o0000
ooooooooool00oooool01?l0003oooooooooooooool2o`000?oooooo;?ooool0037ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo:oooool0
037ooooo00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo00000?oooooo;Ooo
ool0033ooooo0_l00003ooooo`;o00001?ooool00ol0003oooooooooo`3oooooob_ooooo000koooo
o`03o`000?oooooooooo0?oooooo:oooool003_ooooo0_l0003oooooobcooooo000kooooo`03o`00
0?oooooooooo0?oooooo:oooool003_ooooo00?o0000ooooooooool0ooooool[ooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00GOooool0
0omgMgOoIVIVooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o^[Zjoc8b<_ooool01oooool0
1_l0003oooooooooooooooooIVIVogMgM`gooooo00?o0000okZj^_ooool0goooool005cooooo00?o
gMgMoa0@4?o^k^h01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00Oo
0000ooooooooooooooooonk^k_l@413ogMgM00cooooo0_lb<S;Pooooo`00G?ooool00omEEEGoV9RH
ooooo`05ooooo`06o`000?oooooooooooooooonHV9So410@0_l000000onYZJWoooooooooo`04oooo
o`03o`000?oooooooooo00;ooooo00?oQhN7ofIVI_ooool02oooool00on7QhOo0000okZj^P04oooo
o`05oiRHV?l@413o0000oc8b<_o<c<`01Oooool2ob4Q8@?ooooo00Goc<c<onk^k_ooooook^k^olc<
c003ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kQ?ooooo00Ko410@oc8b
<_l0003o0000oa0@4?nYZJT2ooooo`06onk^k_mEEEGo0000o`000?m4A4Co^[Zj0oooool01OmVIVKo
0000o`000?m4A4Coc<c<08oooooo001Looooo`03o`000?oooooooooo00Gooooo00[o0000oooooooo
ooooooooo`000?nYZJWoEEEEoiRHV?mEEEGo^[Zj1Oooool00ol0003oooooooooo`02ooooo`03onk^
k_l0003ooooo00_ooooo00?oc<c<o`000?l@41001?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Go
oooo0_lQ8B43ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01Oooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL04oooool01_l0003oZJVYoooooooooooo^[Zjo`0000;ooooo
00KoEEEEogMgMoooooook^k^ogMgMol@4102ooooo`06ofIVI_mgMgOooooooooooon7QhOo410@Sooo
ool005cooooo00?o<S8booooooooool01Oooool02_l0003ooooooooooooooooo<S8bonk^k_nHV9So
EEEEomgMgOl@4105ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`09ooooo`03omgMgOl0003ogMgM00Kooooo00?o0000ooooooooool00_ooool01Ol@
413ooooooooooooooooo410@01Cooooo00Go^[ZjohN7QomVIVKoIVIVoa0@4002ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0T_ooool005cooooo00?o<S8booooooooool01Oooool0
2ol0003ooooooooooooooooo^[ZjodA4A?o<c<co8B4Qooooool@413oc<c<00Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Dooooo`03ojVYZOl@413ooooo00Wooooo00Gok^k^oeEE
EOoMgMgoEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
000Cooooo`06oc8b<_lQ8B7oMgMgogMgMon7QhOok^k^0_ooool6o`0000;ooooo00?o0000oooooooo
ool0T_ooool005cooooo00?o0000onk^k_ooool01Oooool02ol0003oooooooooooooooook^k^o`00
0?oooooo0000oooooomVIVKoQhN700Cooooo00?o0000ooooooooool00_ooool00oo^k^ko0000oooo
o`0Dooooo`03oa0@4?l0003o^[Zj00[ooooo00Goc<c<onk^k_ooooook^k^olc<c005ooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Cooooo`06o`000?nj^[[oooooonk^
k_mgMgOo00000_ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<P;ooooo00KoIVIVogMgMooooooo
ooooohN7Qol0002?ooooo`00G?ooool00omEEEGoMgMgooooo`05ooooo`08o`000?oooooooooooooo
oomVIVKoV9RHoooooolb<S82okZj^P03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_oo
ool00omgMgOoEEEEooooo`03ooooo`Co00003_ooool00onj^[[o8B4Qooooo`0Cooooo`03o`000?oo
oooooooo00;ooooo00Go410@oooooooooooooooooa0@4007ooooo`?o00000_ooool3o`0000Cooooo
00KoZJVYob4Q8Ol0003o0000oc8b<_l00002ooooo`06onk^k_mEEEGo0000o`000?m4A4Cok^k^0_oo
ool01_o^k^koIVIVo`000?l0003oA4A4o`0008oooooo001Looooo`03omgMgOl@413ok^k^00Gooooo
00?o0000ooooooooool01?ooool00omVIVKoQhN7ooooo`05ooooo`07o`000?ooooooooooooooooo^
k^ko410@omgMg@05ooooo`03o`000?oooooooooo00_ooooo00Go410@oiRHV?oooooo^[Zjo`00000D
ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0Z?ooool005gooooo00?oMgMgofIVI_ooool01?ooool0
0ol0003oooooooooo`04ooooo`03ojVYZOm4A4Cooooo00Gooooo00Ko0000ooooooooooooooooofIV
I_mgMgL7ooooo`03o`000?oooooooooo00[ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@0Booooo`03
oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`Co00000_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo0:Sooooo0021ooooo`03o`000?oooooooooo03Co
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2Xooooo`00O_ooool01?l0003ooooo
ooooool0000fooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Z?ooool007oooooo
0_l0000fooooo`;o00000oooool2o`000:[ooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -2.14748*^9, 0, \
2.14748*^9}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0 1.90278e-14 [
[.32684 -0.0125 -16.5 -12.5 ]
[.32684 -0.0125 16.5 0 ]
[.54329 -0.0125 -16.5 -12.5 ]
[.54329 -0.0125 16.5 0 ]
[.75974 -0.0125 -22.5 -12.5 ]
[.75974 -0.0125 22.5 0 ]
[.97619 -0.0125 -16.5 -12.5 ]
[.97619 -0.0125 16.5 0 ]
[1.025 0 0 -6 ]
[1.025 0 64 6 ]
[.09789 .09514 -33 -6.25 ]
[.09789 .09514 0 6.25 ]
[.09789 .19028 -33 -6.25 ]
[.09789 .19028 0 6.25 ]
[.09789 .28542 -45 -6.25 ]
[.09789 .28542 0 6.25 ]
[.09789 .38056 -33 -6.25 ]
[.09789 .38056 0 6.25 ]
[.09789 .47569 -45 -6.25 ]
[.09789 .47569 0 6.25 ]
[.09789 .57083 -33 -6.25 ]
[.09789 .57083 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -53.4375 0 ]
[.5 .63053 53.4375 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 0 m
.32684 .00625 L
s
gsave
.32684 -0.0125 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 0 m
.54329 .00625 L
s
gsave
.54329 -0.0125 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 0 m
.75974 .00625 L
s
gsave
.75974 -0.0125 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 0 m
.15368 .00375 L
s
.19697 0 m
.19697 .00375 L
s
.24026 0 m
.24026 .00375 L
s
.28355 0 m
.28355 .00375 L
s
.37013 0 m
.37013 .00375 L
s
.41342 0 m
.41342 .00375 L
s
.45671 0 m
.45671 .00375 L
s
.5 0 m
.5 .00375 L
s
.58658 0 m
.58658 .00375 L
s
.62987 0 m
.62987 .00375 L
s
.67316 0 m
.67316 .00375 L
s
.71645 0 m
.71645 .00375 L
s
.80303 0 m
.80303 .00375 L
s
.84632 0 m
.84632 .00375 L
s
.88961 0 m
.88961 .00375 L
s
.9329 0 m
.9329 .00375 L
s
.0671 0 m
.0671 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09514 m
.11664 .09514 L
s
gsave
.09789 .09514 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(12) show
grestore
.11039 .19028 m
.11664 .19028 L
s
gsave
.09789 .19028 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.11039 .28542 m
.11664 .28542 L
s
gsave
.09789 .28542 -45 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.11039 .38056 m
.11664 .38056 L
s
gsave
.09789 .38056 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.11039 .47569 m
.11664 .47569 L
s
gsave
.09789 .47569 -45 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.11039 .57083 m
.11664 .57083 L
s
gsave
.09789 .57083 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(3) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.125 Mabswid
.11039 .01903 m
.11414 .01903 L
s
.11039 .03806 m
.11414 .03806 L
s
.11039 .05708 m
.11414 .05708 L
s
.11039 .07611 m
.11414 .07611 L
s
.11039 .11417 m
.11414 .11417 L
s
.11039 .13319 m
.11414 .13319 L
s
.11039 .15222 m
.11414 .15222 L
s
.11039 .17125 m
.11414 .17125 L
s
.11039 .20931 m
.11414 .20931 L
s
.11039 .22833 m
.11414 .22833 L
s
.11039 .24736 m
.11414 .24736 L
s
.11039 .26639 m
.11414 .26639 L
s
.11039 .30444 m
.11414 .30444 L
s
.11039 .32347 m
.11414 .32347 L
s
.11039 .3425 m
.11414 .3425 L
s
.11039 .36153 m
.11414 .36153 L
s
.11039 .39958 m
.11414 .39958 L
s
.11039 .41861 m
.11414 .41861 L
s
.11039 .43764 m
.11414 .43764 L
s
.11039 .45667 m
.11414 .45667 L
s
.11039 .49472 m
.11414 .49472 L
s
.11039 .51375 m
.11414 .51375 L
s
.11039 .53278 m
.11414 .53278 L
s
.11039 .55181 m
.11414 .55181 L
s
.11039 .58986 m
.11414 .58986 L
s
.11039 .60889 m
.11414 .60889 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -114.438 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.812 moveto
(H) show
69.000 13.812 moveto
(\\310) show
75.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.812 moveto
(\\310) show
87.000 13.812 moveto
(L) show
93.000 9.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
98.250 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
104.250 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.) show
116.250 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
122.250 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
134.250 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
138.438 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
147.875 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
165.875 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.02499 0 L
.02605 0 L
.02729 0 L
.02846 0 L
.02954 0 L
.03053 0 L
.03163 0 L
.03279 0 L
.03395 0 L
.0352 0 L
.03638 0 L
.03746 0 L
.03873 0 L
.03944 0 L
.04011 0 L
.04132 0 L
.04262 0 L
.04327 0 L
.04396 0 L
.04519 0 L
.04588 0 L
.04652 0 L
.04726 0 L
.04797 0 L
.04925 0 L
.05041 0 L
.05166 0 L
.05236 0 L
.05302 0 L
.05414 0 L
.05519 0 L
.05634 0 L
.05759 0 L
.05882 0 L
.06012 0 L
.06123 0 L
.06244 0 L
.06315 0 L
.06381 0 L
.06451 0 L
.06529 0 L
.06659 0 L
.06731 0 L
.06797 0 L
.06924 0 L
.0704 0 L
.07103 0 L
.07173 0 L
.073 0 L
Mistroke
.07376 0 L
.07448 0 L
.07583 0 L
.07659 0 L
.07728 0 L
.07809 0 L
.07885 0 L
.08011 0 L
.08083 0 L
.08149 0 L
.08283 0 L
.08357 0 L
.08427 0 L
.08544 0 L
.08673 0 L
.08807 0 L
.08933 0 L
.09051 0 L
.09158 0 L
.09276 0 L
.09401 0 L
.09527 0 L
.09663 0 L
.0979 0 L
.09906 0 L
.10042 0 L
.1019 0 L
.1033 0 L
.10458 0 L
.10584 0 L
.10703 0 L
.1081 0 L
.10927 0 L
.11053 0 L
.11188 0 L
.11303 0 L
.1143 0 L
.11547 0 L
.11655 0 L
.11773 0 L
.11898 0 L
.12007 0 L
.12108 0 L
.12219 0 L
.12338 0 L
.12477 0 L
.12605 0 L
.12745 0 L
.12894 0 L
.13023 0 L
Mistroke
.13144 0 L
.13277 0 L
.1342 0 L
.13546 0 L
.13683 0 L
.13813 0 L
.13934 0 L
.14161 0 L
.14288 0 L
.14404 0 L
.14636 0 L
.14768 0 L
.14892 0 L
.1514 0 L
.1528 0 L
.15407 0 L
.15634 0 L
.15762 0 L
.15881 0 L
.16099 0 L
.16208 0 L
.1633 0 L
.16461 0 L
.16599 0 L
.16847 0 L
.16985 1e-05 L
.17113 1e-05 L
.17263 1e-05 L
.17404 1e-05 L
.17527 1e-05 L
.1766 2e-05 L
.17892 2e-05 L
.18023 3e-05 L
.18162 3e-05 L
.18412 5e-05 L
.18665 7e-05 L
.18906 .0001 L
.19122 .00013 L
.19357 .00018 L
.19612 .00025 L
.19883 .00036 L
.20139 .0005 L
.20371 .00066 L
.20608 .00088 L
.20825 .00114 L
.21064 .00151 L
.21315 .002 L
.21739 .00318 L
.21979 .0041 L
.22203 .00517 L
Mistroke
.22706 .00849 L
.2299 .01109 L
.23252 .01407 L
.23733 .02136 L
.24244 .0323 L
.247 .04555 L
.25127 .06152 L
.26101 .11271 L
.26597 .1471 L
.27138 .19045 L
.28125 .27948 L
.29078 .36389 L
.29546 .39859 L
.29977 .42386 L
.30218 .4346 L
.30472 .44301 L
.30604 .44612 L
.30728 .44823 L
.30798 .44909 L
.30863 .44965 L
.30937 .45003 L
.31008 .45012 L
.31121 .44972 L
.31241 .44858 L
.31343 .44702 L
.31456 .44468 L
.31577 .44146 L
.31707 .43719 L
.31943 .42743 L
.32476 .39669 L
.33037 .35394 L
.3404 .26364 L
.34994 .17887 L
.35518 .1382 L
.36013 .10521 L
.36475 .07953 L
.36975 .05711 L
.3743 .04122 L
.3785 .02987 L
.38317 .02038 L
.38574 .01633 L
.38819 .01314 L
.39045 .01068 L
.39292 .00845 L
.39725 .00552 L
.39997 .00418 L
.40244 .00322 L
.40528 .00237 L
.40796 .00176 L
.41045 .00132 L
Mistroke
.41273 .00101 L
.41524 .00075 L
.41789 .00054 L
.42044 .00039 L
.42286 .00029 L
.42503 .00021 L
.42739 .00016 L
.42995 .00011 L
.43267 8e-05 L
.435 5e-05 L
.43756 4e-05 L
.43994 3e-05 L
.44211 2e-05 L
.44451 1e-05 L
.44571 1e-05 L
.44702 1e-05 L
.44925 1e-05 L
.45049 1e-05 L
.45162 0 L
.45382 0 L
.4559 0 L
.45706 0 L
.4583 0 L
.46054 0 L
.46191 0 L
.46321 0 L
.46564 0 L
.46688 0 L
.4682 0 L
.47057 0 L
.47189 0 L
.47312 0 L
.47448 0 L
.47594 0 L
.47818 0 L
.47945 0 L
.48063 0 L
.48186 0 L
.48302 0 L
.48435 0 L
.48557 0 L
.48664 0 L
.48777 0 L
.48981 0 L
.49094 0 L
.492 0 L
.49326 0 L
.49441 0 L
.49565 0 L
.49698 0 L
Mistroke
.49821 0 L
.49937 0 L
.50073 0 L
.50198 0 L
.50334 0 L
.50479 0 L
.50597 0 L
.50722 0 L
.50841 0 L
.5095 0 L
.51077 0 L
.51215 0 L
.51345 0 L
.51466 0 L
.51572 0 L
.51686 0 L
.51794 0 L
.51893 0 L
.52003 0 L
.52123 0 L
.52248 0 L
.52364 0 L
.52489 0 L
.52606 0 L
.52712 0 L
.52826 0 L
.5295 0 L
.53082 0 L
.53195 0 L
.53319 0 L
.53448 0 L
.53568 0 L
.537 0 L
.53767 0 L
.5384 0 L
.53974 0 L
.541 0 L
.54223 0 L
.54335 0 L
.54447 0 L
.54551 0 L
.54665 0 L
.54787 0 L
.54915 0 L
.55037 0 L
.55146 0 L
.55264 0 L
.55393 0 L
.55515 0 L
.55584 0 L
Mistroke
.55648 0 L
.55722 0 L
.55791 0 L
.55928 0 L
.56 0 L
.56077 0 L
.56151 0 L
.5622 0 L
.5635 0 L
.56472 0 L
.56601 0 L
.56711 0 L
.56832 0 L
.56962 0 L
.57035 0 L
.57101 0 L
.57231 0 L
.57353 0 L
.57467 0 L
.5759 0 L
.57705 0 L
.57811 0 L
.57929 0 L
.58058 0 L
.58123 0 L
.58192 0 L
.58317 0 L
.58386 0 L
.5845 0 L
.58518 0 L
.58594 0 L
.5872 0 L
.58789 0 L
.58854 0 L
.58977 0 L
.5909 0 L
.59219 0 L
.59342 0 L
.59458 0 L
.59564 0 L
.59685 0 L
.59799 0 L
.59905 0 L
.60003 0 L
.6011 0 L
.60223 0 L
.60338 0 L
.6046 0 L
.60576 0 L
.60681 0 L
Mistroke
.60805 0 L
.60875 0 L
.60939 0 L
.61058 0 L
.61184 0 L
.61298 0 L
.61422 0 L
.61553 0 L
.61674 0 L
.61787 0 L
.61891 0 L
.6201 0 L
.62122 0 L
.62245 0 L
.62375 0 L
.62486 0 L
.62607 0 L
.62738 0 L
.62812 0 L
.62879 0 L
.63009 0 L
.63133 0 L
.63249 0 L
.63353 0 L
.63474 0 L
.63587 0 L
.63693 0 L
.6379 0 L
.63896 0 L
.64008 0 L
.64122 0 L
.64244 0 L
.64359 0 L
.64463 0 L
.64586 0 L
.64655 0 L
.64719 0 L
.64837 0 L
.64962 0 L
.65082 0 L
.65214 0 L
.65338 0 L
.65453 0 L
.65567 0 L
.65671 0 L
.6579 0 L
.65903 0 L
.66026 0 L
.66156 0 L
.66267 0 L
Mistroke
.66389 0 L
.6652 0 L
.66594 0 L
.66661 0 L
.66791 0 L
.66915 0 L
.6702 0 L
.67135 0 L
.67256 0 L
.6737 0 L
.67476 0 L
.67573 0 L
.67679 0 L
.67791 0 L
.67905 0 L
.68027 0 L
.68142 0 L
.68247 0 L
.68369 0 L
.68439 0 L
.68503 0 L
.6862 0 L
.68745 0 L
.68866 0 L
.68998 0 L
.69122 0 L
.69238 0 L
.69352 0 L
.69456 0 L
.69576 0 L
.69688 0 L
.69812 0 L
.69942 0 L
.70053 0 L
.70175 0 L
.70307 0 L
.70381 0 L
.70448 0 L
.70578 0 L
.70702 0 L
.70807 0 L
.70923 0 L
.71044 0 L
.71158 0 L
.71264 0 L
.71361 0 L
.71467 0 L
.71579 0 L
.71694 0 L
.71816 0 L
Mistroke
.71931 0 L
.72035 0 L
.72158 0 L
.72227 0 L
.72291 0 L
.72409 0 L
.72533 0 L
.72654 0 L
.72723 0 L
.72787 0 L
.72903 0 L
.73028 0 L
.73138 0 L
.73242 0 L
.73356 0 L
.73479 0 L
.73602 0 L
.73672 0 L
.73737 0 L
.73868 0 L
.73941 0 L
.74008 0 L
.74128 0 L
.74258 0 L
.74381 0 L
.74494 0 L
.74599 0 L
.74713 0 L
.7482 0 L
.74917 0 L
.75032 0 L
.75156 0 L
.75274 0 L
.75384 0 L
.75507 0 L
.75623 0 L
.75727 0 L
.7584 0 L
.75963 0 L
.76093 0 L
.76205 0 L
.76326 0 L
.76457 0 L
.76578 0 L
.76641 0 L
.7671 0 L
.76783 0 L
.76851 0 L
.76976 0 L
.7709 0 L
Mistroke
.77216 0 L
.77348 0 L
.77459 0 L
.77578 0 L
.7769 0 L
.77792 0 L
.77912 0 L
.78042 0 L
.78165 0 L
.78279 0 L
.78399 0 L
.78529 0 L
.78651 0 L
.78763 0 L
.78893 0 L
.78967 0 L
.79036 0 L
.79161 0 L
.79231 0 L
.79295 0 L
.79362 0 L
.79434 0 L
.79561 0 L
.79632 0 L
.79699 0 L
.79771 0 L
.79849 0 L
.79916 0 L
.79989 0 L
.80058 0 L
.80122 0 L
.80243 0 L
.8037 0 L
.80491 0 L
.80622 0 L
.80746 0 L
.80861 0 L
.80975 0 L
.81079 0 L
.81198 0 L
.81311 0 L
.81434 0 L
.81564 0 L
.81675 0 L
.81797 0 L
.81928 0 L
.82001 0 L
.82069 0 L
.82199 0 L
.82323 0 L
Mistroke
.82427 0 L
.82543 0 L
.82664 0 L
.82778 0 L
.82883 0 L
.8298 0 L
.83087 0 L
.83199 0 L
.83313 0 L
.83435 0 L
.83549 0 L
.83654 0 L
.83777 0 L
.83846 0 L
.8391 0 L
.84028 0 L
.84152 0 L
.84273 0 L
.84405 0 L
.84529 0 L
.84645 0 L
.84759 0 L
.84863 0 L
.84982 0 L
.85095 0 L
.85218 0 L
.85349 0 L
.8546 0 L
.85582 0 L
.85713 0 L
.85787 0 L
.85854 0 L
.85985 0 L
.86108 0 L
.86213 0 L
.86329 0 L
.86451 0 L
.86564 0 L
.8667 0 L
.86767 0 L
.86874 0 L
.86986 0 L
.871 0 L
.87222 0 L
.87337 0 L
.87441 0 L
.87564 0 L
.87634 0 L
.87698 0 L
.87815 0 L
Mistroke
.87939 0 L
.88061 0 L
.88193 0 L
.88318 0 L
.88433 0 L
.88537 0 L
.88652 0 L
.88772 0 L
.88885 0 L
.89008 0 L
.89139 0 L
.8925 0 L
.89373 0 L
.89504 0 L
.89578 0 L
.89645 0 L
.89776 0 L
.89899 0 L
.90005 0 L
.90121 0 L
.90242 0 L
.90356 0 L
.90462 0 L
.90559 0 L
.90671 0 L
.90778 0 L
.90892 0 L
.91014 0 L
.91129 0 L
.91234 0 L
.91357 0 L
.91426 0 L
.9149 0 L
.91607 0 L
.91731 0 L
.91853 0 L
.91922 0 L
.91986 0 L
.92103 0 L
.92227 0 L
.92338 0 L
.92442 0 L
.92556 0 L
.92679 0 L
.92803 0 L
.92873 0 L
.92938 0 L
.93069 0 L
.93143 0 L
.93209 0 L
Mistroke
.93329 0 L
.93459 0 L
.93582 0 L
.93695 0 L
.93801 0 L
.93915 0 L
.94022 0 L
.9412 0 L
.94234 0 L
.94359 0 L
.94477 0 L
.94586 0 L
.9471 0 L
.94826 0 L
.9493 0 L
.95043 0 L
.95166 0 L
.95296 0 L
.95407 0 L
.95529 0 L
.95659 0 L
.95733 0 L
.958 0 L
.95925 0 L
.96057 0 L
.96175 0 L
.96286 0 L
.96408 0 L
.96538 0 L
.9667 0 L
.96744 0 L
.96813 0 L
.96887 0 L
.96953 0 L
.9703 0 L
.97103 0 L
.97232 0 L
.97351 0 L
.97481 0 L
.97547 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00H_ooool2onk^kP?ooooo0_o^
k^h]ooooo`;ok^k^0oooool2onk^kSKooooo0_o^k^h3ooooo`;ok^k^9?ooool2onk^kP?ooooo0_o^
k^iSooooo`00G?ooool03Om4A4Co0000o`000?lb<S;ogMgMooooooo^k^koEEEEonk^k_ooooook^k^
oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hHooooo`Co
000000Wo410@ooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?oo
ooooooooonk^k_lb<S;o0000oc8b<_o^k^hAooooo`Co000000?o410@ooooooooool00_ooool2ob4Q
8@Gooooo00goA4A4o`000?l0003o<S8bomgMgOooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^
00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^3_ooool5o`0000;ooooo
00Ook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413oooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^E?ooool005oooooo00WoMgMgoc8b<_ooooooooooonk^k_mEEEGogMgMoeEE
EOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool0
0ol0003oooooooooo`02ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool00ol0003oooooooooo`04ooooo`;o8B4Q
2?ooool02OmgMgOo<S8booooooooooook^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
0oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg05Cooooo001Pooooo`07o`000?oooooooooooooooooMgMgo0000omgMg@07
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Jooooo`03o`000?oo
oooooooo00?ooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?oo
ooooooooooooool@41004oooool00ol0003oooooooooo`0?ooooo`07o`000?oooooooooooooooooM
gMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400?
ooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@4100E?ooool005oooooo00WoMgMgoc8b<_ooooooooooonk^
k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000006_ooool00ol0003oooooooooo`02ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000004oooool00ol0003ooooooooo
o`0>ooooo`09ogMgMolb<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo0000013ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000005Cooooo001Looooo`0=o`000?lQ8B7o0000oc8b<_o<c<coooooonk^k_mEEEGok^k^
ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Jooooo`0;o`000?ooooooooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Ooo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000004oooool00ol0003ooooo
ooooo`0;ooooo`0=o`000?lQ8B7o0000oc8b<_o<c<coooooonk^k_mEEEGok^k^ooooooo^k^koEEEE
onk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Aooooo`0;
ogMgMomVIVKoooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool00000E?ooool005cooooo00?o0000ooooooooool0
0oooool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@400Jooooo`04o`000?ooooooooooooooo`;ok^k^0oooool2onk^kPGooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@01?ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`03ooooo`;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@01;ooooo00?o0000ooooooooool00_o^k^h3ooooo`;ok^k^1Ooo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100E?ooool005cooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
6_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Cooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool01Ol0003o^[ZjoooooonHV9So
410@00kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg05Cooooo001L
ooooo`Co00003?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?oo
ool00ol0003oooooooooo`0=ooooo`03oeEEEOmVIVKo000000gooooo00?oEEEEofIVI_l000001?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo0_l00007ooooo`03oeEEEOmVIVKo000000gooooo
1?l0000<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`;o
00001?ooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo00?oEEEEofIVI_l000001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Sooooo0_l0001:ooooo`00P?ooool00ol0003oooooooooo`0`oooo
o`04o`000?ooooooooooo`0003Wooooo00Co0000oooooooooooo00009oooool01?l0003ooooooooo
ool00019ooooo`00N_ooool4o`0000?ooooo00?o0000ooooooooool0:_ooool4o`000005ooooool0
003oooooooooool00000=?ooool4o`000005ooooool0003oooooooooool000008_ooool4o`000005
ooooool0003oooooooooool00000BOooool0087ooooo00?o0000ooooooooool0;oooool3o`0003[o
oooo0ol0000Xooooo`?o0000B_ooool007oooooo00Co0000oooooooooooo0000<Oooool00ol0003o
ooooooooo`0jooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool03_ooool00omgMgOo
IVIVooooo`0^ooooo`03ofIVI_mgMgOooooo00Oooooo001oooooo`Co0000<_ooool00ol0003ooooo
ooooo`0jooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool03?ooool00ooMgMgo410@
onk^kP0_ooooo`03onk^k_l@413ogMgM00Oooooo003ooooooa_ooooo0_l00002ooooo`;o00003?oo
ool01?mEEEGoV9RHooooooooool2o`0000;ooooo00Oo0000oooooooooooo0000oa0@4?o^k^koEEEE
00;o000000?oA4A4okZj^_ooool00_ooool01OnHV9So0000o`000?m4A4Co^[Zj00;ooooo00Sok^k^
oeEEEOl0003o0000odA4A?nj^[[ooooooa0@40Go00000oooool02?l@413o<S8bo`000?l0003o410@
ojVYZOn7QhOoIVIV1oooool00?oooooo6oooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@cooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`08o`000?ooooooEEEEogMg
Moooooook^k^ogMgMol@4103ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000_ooool01_mEEEGoMgMg
ooooooo^k^koMgMgoa0@40?ooooo00?o0000ooooooooool01?ooool02?l0003oZJVYoooooooooooo
^[Zjo`000?o^k^ko00001oooool0023ooooolOl0000:ooooo`04omgMgOl0003o410@olc<c0gooooo
00?o<S8booooooooool00_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo000000So
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Go
oooo00Oo^[ZjohN7QomVIVKoIVIVoa0@4?oooooo000000Oooooo000Vooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Sooooo1_l00004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo1_l00008ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00gooooo00Cok^k^ob4Q8Ol@413ok^k^3Oooool00olb<S;oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000;ooooo00?o0000ooooool000001Ol00003ooooo`03o`000?oooooooooo00Cooooo1_l0
0003ooooo`03o`000?oooooooooo00Cooooo00So<S8bob4Q8OmgMgOoMgMgohN7Qoo^k^koooooo`00
00Oooooo000kooooo`03o`000?oooooooooo01Sooooo0_l0000Gooooo`03o`000?oooooooooo00go
oooo0_l0000Rooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0<Oooool00ol0003o
ooooooooo`0=ooooo`04ob4Q8OmgMgOoMgMgoc8b<Pgooooo00?o0000onk^k_ooool00_ooool03_l0
003oc<c<olc<c?l0003oZJVYomgMgOlQ8B7ooooooeEEEOn7QhOok^k^oooooon7QhOo<S8b0oooool0
0ol0003oooooooooo`04ooooo`06oeEEEOn7QhOok^k^oooooon7QhOo<S8b0oooool00ol0003o<S8b
omgMg@04ooooo`08o`000?nj^[[oooooonk^k_mgMgOo0000onk^k_l00007ooooo`00>oooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0VOooool2o`00
00;ooooo0_l0000<ooooo`0?oeEEEOmgMgOoooooooooool@413o0000ob4Q8Ol0003oMgMgoa0@4?l0
003oZJVYooooooo^k^koEEEE00;o000000CoA4A4onk^k_oooooo410@1Ol00003ooooo`06onk^k_mE
EEGo0000o`000?m4A4Cok^k^0_ooool2o`000004ojVYZOlQ8B7o0000ob4Q8@;ooooo00SoZJVYob4Q
8Ol0003o0000oc8b<_l0003oMgMgoeEEE@Oooooo000kooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool08_ooool2o`000:gooooo00?ogMgMoa0@4?o^k^h04oooool00ol0003ooooooooo
o`0Iooooo`03onk^k_l@413ogMgM00Oooooo000kooooo`;o00006oooool00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo0:kooooo00?oMgMgofIVI_ooool04_ooool00ol0003oooooooooo`0I
ooooo`03ofIVI_mgMgOooooo00Oooooo000kooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool08?ooool00ol0003oooooooooo`3Yooooo`00>oooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool0j_ooool003_ooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo0>[ooooo000kooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`3Zooooo`00>oooool2
o`0001kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`3[ooooo`00>oooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0joooool003_o
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo0>_o
oooo000kooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`3/ooooo`00>oooool2o`00023ooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`3/ooooo`00>oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool0k?ooool003_ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo0>cooooo000kooooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`3]ooooo`005oooool2onk^kP?ooooo0_o^k^hMooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`3]ooooo`004Ooo
ool03Om4A4Co0000o`000?lb<S;ogMgMooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00ooo
ool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h>ooooo`;o00008Oooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo0>gooooo000Dooooo`09ogMgMolb<S;ooooooooo
ooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo0>gooooo000Eooooo`07o`000?oooooooooooooooooMgMgo0000omgMg@07ooooo`03
o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo
023ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`3]ooooo`005?ooool02OmgMgOo
<S8booooooooooook^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`3]ooooo`004Oooool03Ol0003o8B4Qo`000?lb<S;oc<c<ooooooo^
k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000003_ooool2o`00027ooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`3^ooooo`004Oooool00ol0003oooooooooo`03ooooo`;ok^k^0oooool2onk^kPGooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool0
8?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo0>kooooo000Aooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo
0ol000000ooooooo0000o`000002o`0000?ooooo00?o0000ooooooooool08Oooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo0>kooooo000Aooooo`Co00003?ooool00omEEEGoIVIVo`00
0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool01Ol0003ooooooooooooooooo000000Go
oooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0>ko
oooo000aooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0k_ooool0037ooooo00?o
0000ooooooooool00oooool01?l0003oooooooooooooool2o`0002;ooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`3^ooooo`00<Oooool01?l0003oooooooooool00002ooooo`05o`00
0?ooooooooooooooool000008oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0>ko
oooo000`ooooo`;o00000oooool2o`0000Cooooo00?o0000ooooooooool08Oooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo0>kooooo000kooooo`03o`000?oooooooooo027ooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`3_ooooo`00>oooool2o`0002?ooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`3_ooooo`00>oooool00ol0003oooooooooo`0Roooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0koooool003_ooooo00?o0000oooooooo
ool08_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo0>oooooo000kooooo`03o`00
0?oooooooooo02;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`3_ooooo`00>ooo
ool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0kooo
ool003_ooooo0_l0000Sooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0l?ooool0
03_ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
0?3ooooo000kooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`3`ooooo`00>oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool0l?ooool001Oooooo0_o^k^h3ooooo`;ok^k^7Oooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0l?ooool0017ooooo1?l00000
2Ol@413oooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co000000So410@oooooooo
ooook^k^oc8b<_l0003o<S8bonk^kPkooooo0_l0000Tooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool0lOooool001?ooooo00?o0000ooooooooool00_ooool01Oo^k^koEEEEomgMgOmE
EEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo0?7ooooo
000Cooooo`03o`000?oooooooooo00?ooooo00?ogMgMo`000?oMgMd01oooool00ol0003ooooooooo
o`02ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`0Sooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool0lOooool001?ooooo00?o0000ooooooooool00_oo
ool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000kooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo0?7ooooo000Cooooo`0;o`000?ooooooooooooooooo^k^koEEEEonk^k_oooooo
k^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
3_ooool2o`0002Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`3aooooo`004ooo
ool01?l0003oooooooooooooool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo
00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo02?ooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`3aooooo`004oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`?o00000_ooool2o`0000Co
oooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo0?7o
oooo000Aooooo`03oeEEEOmVIVKo000000gooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Cooooo00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo
000002Gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`3booooo`00<Oooool00ol0
003oooooooooo`03ooooo`05o`000?ooooooooooooooool000009Oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo0?;ooooo000aooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00_ooool2o`0002Gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`3boooo
o`00<Oooool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool000009_ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo0?;ooooo000`ooooo`;o00000oooool2o`00
00Cooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
0?;ooooo000kooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`3booooo`00>oooool2o`0002Gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`3booooo`00>oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool0l_ooool003_ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo0?;ooooo000kooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`3booooo`00>oooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool0l_ooool003_ooooo0_l0000Vooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool0loooool003_ooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo0??ooooo000kooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`3cooooo`00>oooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0loooool001So
oooo0_o^k^h3ooooo`;ok^k^7?ooool2o`0002Kooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`3cooooo`000_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`0=odA4
A?l0003o0000oc8b<_oMgMgoooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co0000
00So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPgooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0??ooooo0004ooooo`03o`000?oooooooooo
00Cooooo0_lQ8B48ooooo`09ogMgMolb<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00gooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0??ooooo0004ooooo`03o`00
0?oooooooooo00oooooo00Oo0000ooooooooooooooooomgMgOl0003ogMgM00Oooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@00gooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0??ooooo0004ooooo`03o`000?oooooooooo
00kooooo00WoMgMgoc8b<_ooooooooooonk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000003Oooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0loooool000Cooooo00?o0000ooooooooool0
2oooool03Ol0003o8B4Qo`000?lb<S;oc<c<ooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h0
1Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000003Oooool2o`0002Oo
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`3cooooo`001?ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00?ooooo0_o^k^h3ooooo`;ok^k^1Oooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41003Oooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool0m?ooool000Cooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`?o00000_ooool2o`0000?ooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo0?Cooooo0002ooooo`03oeEEEOmVIVKo000000gooooo
1?l0000<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000:?ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo0?Cooooo000booooo`03o`000?oooooooooo00?ooooo00Co0000oooo
oooooooo0000:?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0?Cooooo000boooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooooooo0_l0000Xooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool0m?ooool003;ooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool0000Yooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0m?oo
ool0037ooooo0_l00003ooooo`;o00000oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool0m?ooool003_ooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo0?Cooooo000kooooo`;o0000:?ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo0?Cooooo000kooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`3dooooo`00>oooool00ol0003ooooooooo
o`0Wooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0m?ooool003_ooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0?Gooooo000koooo
o`03o`000?oooooooooo02Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`3eoooo
o`00>oooool2o`0002Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`3eooooo`00
>oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
mOooool003_ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo0?Gooooo000Gooooo`;ok^k^0oooool2onk^kQgooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?Gooooo000@ooooo`Go00000_ooool01oo^
k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o
0000oc8b<_o^k^h>ooooo`;o0000:Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
0?Gooooo000@ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01Oo^k^koEEEEomgMgOmEEEGo
k^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00?o
0000ooooooooool0:?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?Gooooo000A
ooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0m_ooool001;ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000kooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo0?Kooooo000Cooooo`0;ogMgMomVIVKoooooooooooo^k^koEEEEonk^k_ooooook^k^
oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000003_oo
ool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0m_oo
ool001Cooooo00?o0000ooooooooool00_o^k^h3ooooo`;ok^k^1Oooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@41003_ooool2o`0002Wooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`3fooooo`004?ooool01Ol0003o^[ZjoooooonHV9So410@00kooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?Kooooo000@ooooo`05oiRHV?l@
413o0000ob4Q8Oo<c<`03?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00oooool3o`0000;ooooo0_l00004ooooo`03o`000?oooooooooo02Wooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`3gooooo`00<Oooool01?l0003oooooooooool00002ooooo`05
o`000?ooooooooooooooool00000:oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
0?Oooooo000aooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooooooo0_l0000Zoooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0moooool0037ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Wooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`3gooooo`00<Oooool01?l0003oooooooooool00002ooooo`05
o`000?ooooooooooooooool00000:oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
0?Oooooo000`ooooo`;o00000oooool2o`0000Cooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo0?Oooooo000kooooo`03o`000?oooooooooo02[ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`3hooooo`00>oooool2o`0002_ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`3hooooo`00>oooool00ol0003oooooooooo`0Z
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0n?ooool003_ooooo00?o0000oooo
ooooool0:_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?Sooooo000kooooo`03
o`000?oooooooooo02_ooooo00Go0000ooooooooooooooooo`00003jooooo`00>oooool00ol0003o
ooooooooo`0[ooooo`04o`000?ooooooooooo`000?_ooooo000kooooo`;o0000;?ooool01?l0003o
ooooooooool0003kooooo`00>oooool00ol0003oooooooooo`0[ooooo`04o`000?ooooooooooo`00
0?_ooooo000kooooo`03o`000?oooooooooo02cooooo0ol0003kooooo`006?ooool2onk^kP?ooooo
0_o^k^hLooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0n_ooool00003ooooool0
003o000000?o00001Oooool2ob4Q8@Gooooo00goA4A4o`000?l0003o<S8bomgMgOooooook^k^oeEE
EOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb
<S;ok^k^3Oooool2o`000?oooooo;?ooool00006oooooonHV9So8B4Qonk^k_ooooooA4A41Oooool2
ob4Q8@Sooooo00WoMgMgoc8b<_ooooooooooonk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03Oooool00ol0003oooooooooo`3ooooo
ob_ooooo0002ooooo`03oiRHV?lQ8B7ok^k^017ooooo00Oo0000ooooooooooooooooomgMgOl0003o
gMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00gooooo00?o
0000ooooooooool0ooooool[ooooo`000oooool00onHV9So8B4Qonk^kP0?ooooo`09ogMgMolb<S;o
ooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000000gooooo00?o0000ooooooooool0ooooool[ooooo`001?ooool00omgMgOo
IVIVooooo`0;ooooo`0=o`000?lQ8B7o0000oc8b<_o<c<coooooonk^k_mEEEGok^k^ooooooo^k^ko
EEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000=oooo
o`03o`000?oooooooooo0?oooooo:oooool000Gooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`03ooooo`;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@413o
oooooooooooooooo410@00gooooo0_l0003oooooobcooooo00001_oooooo0000okZj^_ooooooV9RH
oa0@40cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03Oooool00ol0003oooooooooo`3oooooob_ooooo00001_ooooooV9RHoa0@4?l0
003o8B4Qolc<c0cooooo1?l0000<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP03ooooo`?o00000_ooool2o`0000?ooooo00?o0000ooooooooool0ooooool[ooooo`00
<_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`000?oooooo;Oooool003;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02o`000?oooooo;?ooool003;ooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo00000?oooooo;Oooool003;ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0003oooooobgooooo000aooooo`;o
00000oooool2o`0000?ooooo00?o0000ooooooooool0ooooool[ooooo`00>oooool00ol0003ooooo
ooooo`3oooooob_ooooo000kooooo`;o0000ooooool/ooooo`00>oooool00ol0003oooooooooo`3o
ooooob_ooooo000kooooo`03o`000?oooooooooo0?oooooo:oooool003_ooooo00?o0000oooooooo
ool0ooooool[ooooo`00>oooool2o`000?oooooo;?ooool003_ooooo00?o0000ooooooooool0oooo
ool[ooooo`00>oooool00ol0003oooooooooo`3oooooob_ooooo000kooooo`03o`000?oooooooooo
0?oooooo:oooool001Oooooo0_o^k^h3ooooo`;ok^k^7Oooool00ol0003oooooooooo`3oooooob_o
oooo000@ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00_ooool01oo^k^koEEEEonk^k_ooooook^k^
oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h>ooooo`;o
0000ooooool/ooooo`004?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00Gok^k^oeEEEOoM
gMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>
ooooo`03o`000?oooooooooo0?oooooo:oooool001Cooooo00?o0000ooooooooool00_ooool00ooM
gMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400>
ooooo`03o`000?oooooooooo0?oooooo:oooool001?ooooo00?oZJVYoa0@4?ooool00_ooool01Oo^
k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000000kooooo00?o0000ooooooooool0ooooool[ooooo`004_ooool00ol@413o0000okZj^P02
ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo
00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo0?oooooo:oooool001?ooooo
00Co^[Zjob4Q8Ooooooooooo0_o^k^h3ooooo`;ok^k^1Oooool00ol0003oooooooooo`02ooooo`05
oa0@4?ooooooooooooooool@41003_ooool2o`000?oooooo;?ooool0013ooooo00Go410@oiRHV?oo
oooo^[Zjo`00000>ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>
ooooo`03o`000?oooooooooo0?oooooo:oooool0013ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@0<
ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`?o00000_oo
ool2o`0000Cooooo00?o0000ooooooooool0ooooool[ooooo`00<Oooool01?l0003oooooooooool0
0002ooooo`05o`000?ooooooooooooooool00000ooooool]ooooo`00<Oooool00ol0003ooooooooo
o`03ooooo`04o`000?ooooooooooooooo`;o0000ooooool/ooooo`00<Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0ooooool[ooooo`00<Oooool0
1?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool00000ooooool]ooooo`00<?oo
ool2o`0000?ooooo0_l00004ooooo`03o`000?oooooooooo0?oooooo:oooool003_ooooo00?o0000
ooooooooool0ooooool[ooooo`00>oooool2o`000?oooooo;?ooool003_ooooo00?o0000oooooooo
ool0ooooool[ooooo`00>oooool00ol0003oooooooooo`3oooooob_ooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo001Mooooo`03ogMgMomV
IVKooooo00Cooooo00?o0000ooooooooool00_ooool00onj^[[o<S8booooo`07ooooo`06o`000?oo
oooooooooooooomVIVKoMgMg3Oooool00ol0003o^[Zjooooo`3Oooooo`00G?ooool00ooMgMgo410@
onk^kP05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01_ooool01ol0003ooooo
ooooooooooook^k^oa0@4?oMgMd03?ooool2oc8b<^3ooooo001Looooo`03oeEEEOnHV9Sooooo00Go
oooo00Ko0000oooooooooooooooooiRHV?l@4102o`000003ojVYZOoooooooooo00Cooooo00?o0000
ooooooooool00_ooool00on7QhOoIVIVooooo`0;ooooo`03ohN7Qol0003o^[Zj00Kooooo0_l00000
0ol@413oooooooooo`03ooooo`;o8B4Q0oooool01Oo<c<cok^k^ooooooo^k^koc<c<00?ooooo1?l0
00002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^4oooool01_l@413o<S8bo`000?l0003o
410@ojVYZ@;ooooo00Kok^k^oeEEEOl0003o0000odA4A?nj^[X3ooooo`05ofIVI_l0003o0000odA4
A?o<c<`0Soooool005cooooo00?o0000ooooooooool01Oooool02_l0003ooooooooooooooooo0000
ojVYZOmEEEGoV9RHoeEEEOnj^[X5ooooo`03o`000?oooooooooo00;ooooo00?ok^k^o`000?ooool0
2oooool00oo<c<co0000oa0@4007ooooo`03o`000?oooooooooo00Cooooo0_lQ8B43ooooo`05onk^
k_mEEEGogMgMoeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL04oooool01_l0003oZJVYoooooooooooo^[Zjo`0000;ooooo00KoEEEEogMgMoooooook^k^
ogMgMol@4102ooooo`06ofIVI_mgMgOooooooooooon7QhOo410@Soooool005cooooo00?o<S8boooo
ooooool01Oooool02_l0003ooooooooooooooooo<S8bonk^k_nHV9SoEEEEomgMgOl@4105ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool04Oooool5o`0000_ooooo00?ogMgMo`000?oM
gMd01_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41005?ooool01Onj
^[[oQhN7ofIVI_mVIVKo410@00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2B
ooooo`00G?ooool00olb<S;oooooooooo`05ooooo`0;o`000?oooooooooooooooonj^[[oA4A4olc<
c?lQ8B7ooooooa0@4?o<c<`01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo017o
oooo00CoA4A4omgMgOoooooo00002oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Gooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000001?ooooo00Ko<S8bob4Q8OmgMgOoMgMg
ohN7Qoo^k^h2ooooo`Ko00000_ooool00ol0003oooooooooo`2Booooo`00G?ooool00ol0003ok^k^
ooooo`05ooooo`0;o`000?ooooooooooooooooo^k^ko0000ooooool0003oooooofIVI_n7QhL01?oo
ool00ol0003oooooooooo`02ooooo`03onk^k_l0003ooooo01;ooooo00CogMgMoeEEEOoooooo0000
2oooool01Oo<c<cok^k^ooooooo^k^koc<c<00Gooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000001?ooooo00Ko0000okZj^_ooooook^k^ogMgMol00002ooooo`06oeEEEOn7
QhOok^k^oooooon7QhOo<S8b0_ooool01_mVIVKoMgMgooooooooooooQhN7o`0008oooooo001Loooo
o`03oeEEEOmgMgOooooo00Gooooo00So0000ooooooooooooooooofIVI_nHV9Sooooooc8b<P;o^[Zj
00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03ogMgMomEEEGooooo00?ooooo
1?l0000<ooooo`03ogMgMoo<c<co000001Gooooo00?o0000ooooooooool00_ooool01Ol@413ooooo
oooooooooooo410@00Oooooo0ol00002ooooo`?o00001?ooool01_nYZJWo8B4Qo`000?l0003o<S8b
o`0000;ooooo00Kok^k^oeEEEOl0003o0000odA4A?o^k^h2ooooo`06onk^k_mVIVKo0000o`000?m4
A4Co0000Soooool005cooooo00?ogMgMoa0@4?o^k^h01Oooool00ol0003oooooooooo`04ooooo`03
ofIVI_n7QhOooooo00Gooooo00Oo0000ooooooooooooooooonk^k_l@413ogMgM00Gooooo00?o0000
ooooooooool03?ooool00oo^k^koA4A4o`00000Eooooo`03o`000?oooooooooo00;ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Z?oo
ool005gooooo00?oMgMgofIVI_ooool01?ooool00ol0003oooooooooo`04ooooo`03ojVYZOm4A4Co
oooo00Gooooo00Ko0000ooooooooooooooooofIVI_mgMgL7ooooo`03o`000?oooooooooo00cooooo
00?oMgMgo`000?ooool04_ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00_ooool4o`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2Xooooo`00
POooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
Z?ooool007kooooo00Co0000oooooooooooo0000=_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo0:Sooooo001oooooo`;o0000=_ooool2o`0000?ooooo0_l0002Zooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -2.14748*^9, 0, \
2.14748*^9}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0 1.90278e-14 [
[.32684 -0.0125 -16.5 -12.5 ]
[.32684 -0.0125 16.5 0 ]
[.54329 -0.0125 -16.5 -12.5 ]
[.54329 -0.0125 16.5 0 ]
[.75974 -0.0125 -22.5 -12.5 ]
[.75974 -0.0125 22.5 0 ]
[.97619 -0.0125 -16.5 -12.5 ]
[.97619 -0.0125 16.5 0 ]
[1.025 0 0 -6 ]
[1.025 0 64 6 ]
[.09789 .09514 -33 -6.25 ]
[.09789 .09514 0 6.25 ]
[.09789 .19028 -33 -6.25 ]
[.09789 .19028 0 6.25 ]
[.09789 .28542 -45 -6.25 ]
[.09789 .28542 0 6.25 ]
[.09789 .38056 -33 -6.25 ]
[.09789 .38056 0 6.25 ]
[.09789 .47569 -45 -6.25 ]
[.09789 .47569 0 6.25 ]
[.09789 .57083 -33 -6.25 ]
[.09789 .57083 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -53.4375 0 ]
[.5 .63053 53.4375 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 0 m
.32684 .00625 L
s
gsave
.32684 -0.0125 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 0 m
.54329 .00625 L
s
gsave
.54329 -0.0125 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 0 m
.75974 .00625 L
s
gsave
.75974 -0.0125 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 0 m
.15368 .00375 L
s
.19697 0 m
.19697 .00375 L
s
.24026 0 m
.24026 .00375 L
s
.28355 0 m
.28355 .00375 L
s
.37013 0 m
.37013 .00375 L
s
.41342 0 m
.41342 .00375 L
s
.45671 0 m
.45671 .00375 L
s
.5 0 m
.5 .00375 L
s
.58658 0 m
.58658 .00375 L
s
.62987 0 m
.62987 .00375 L
s
.67316 0 m
.67316 .00375 L
s
.71645 0 m
.71645 .00375 L
s
.80303 0 m
.80303 .00375 L
s
.84632 0 m
.84632 .00375 L
s
.88961 0 m
.88961 .00375 L
s
.9329 0 m
.9329 .00375 L
s
.0671 0 m
.0671 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09514 m
.11664 .09514 L
s
gsave
.09789 .09514 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(12) show
grestore
.11039 .19028 m
.11664 .19028 L
s
gsave
.09789 .19028 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.11039 .28542 m
.11664 .28542 L
s
gsave
.09789 .28542 -45 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.11039 .38056 m
.11664 .38056 L
s
gsave
.09789 .38056 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.11039 .47569 m
.11664 .47569 L
s
gsave
.09789 .47569 -45 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.11039 .57083 m
.11664 .57083 L
s
gsave
.09789 .57083 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(3) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.125 Mabswid
.11039 .01903 m
.11414 .01903 L
s
.11039 .03806 m
.11414 .03806 L
s
.11039 .05708 m
.11414 .05708 L
s
.11039 .07611 m
.11414 .07611 L
s
.11039 .11417 m
.11414 .11417 L
s
.11039 .13319 m
.11414 .13319 L
s
.11039 .15222 m
.11414 .15222 L
s
.11039 .17125 m
.11414 .17125 L
s
.11039 .20931 m
.11414 .20931 L
s
.11039 .22833 m
.11414 .22833 L
s
.11039 .24736 m
.11414 .24736 L
s
.11039 .26639 m
.11414 .26639 L
s
.11039 .30444 m
.11414 .30444 L
s
.11039 .32347 m
.11414 .32347 L
s
.11039 .3425 m
.11414 .3425 L
s
.11039 .36153 m
.11414 .36153 L
s
.11039 .39958 m
.11414 .39958 L
s
.11039 .41861 m
.11414 .41861 L
s
.11039 .43764 m
.11414 .43764 L
s
.11039 .45667 m
.11414 .45667 L
s
.11039 .49472 m
.11414 .49472 L
s
.11039 .51375 m
.11414 .51375 L
s
.11039 .53278 m
.11414 .53278 L
s
.11039 .55181 m
.11414 .55181 L
s
.11039 .58986 m
.11414 .58986 L
s
.11039 .60889 m
.11414 .60889 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -114.438 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.812 moveto
(H) show
69.000 13.812 moveto
(\\310) show
75.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.812 moveto
(\\310) show
87.000 13.812 moveto
(L) show
93.000 9.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
98.250 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
104.250 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5.) show
116.250 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
122.250 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
134.250 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
138.438 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
147.875 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
165.875 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.02499 0 L
.02605 0 L
.02729 0 L
.02846 0 L
.02954 0 L
.03053 0 L
.03163 0 L
.03279 0 L
.03395 0 L
.0352 0 L
.03638 0 L
.03746 0 L
.03873 0 L
.03944 0 L
.04011 0 L
.04132 0 L
.04262 0 L
.04327 0 L
.04396 0 L
.04519 0 L
.04588 0 L
.04652 0 L
.04726 0 L
.04797 0 L
.04925 0 L
.05041 0 L
.05166 0 L
.05236 0 L
.05302 0 L
.05414 0 L
.05519 0 L
.05634 0 L
.05759 0 L
.05882 0 L
.06012 0 L
.06123 0 L
.06244 0 L
.06381 0 L
.06458 0 L
.06529 0 L
.06659 0 L
.06725 0 L
.06797 0 L
.06923 0 L
.07057 0 L
.07184 0 L
.073 0 L
.07369 0 L
.07443 0 L
Mistroke
.07577 0 L
.07658 0 L
.07735 0 L
.07805 0 L
.07878 0 L
.08016 0 L
.08142 0 L
.08278 0 L
.08355 0 L
.08427 0 L
.08554 0 L
.08691 0 L
.08821 0 L
.08941 0 L
.09048 0 L
.09167 0 L
.09292 0 L
.09408 0 L
.09537 0 L
.09672 0 L
.09787 0 L
.09914 0 L
.1005 0 L
.10196 0 L
.10333 0 L
.10458 0 L
.10578 0 L
.1069 0 L
.10813 0 L
.10944 0 L
.11082 0 L
.11213 0 L
.11331 0 L
.11459 0 L
.11569 0 L
.11691 0 L
.11818 0 L
.11937 0 L
.12048 0 L
.1215 0 L
.12262 0 L
.1238 0 L
.1251 0 L
.12629 0 L
.12766 0 L
.12895 0 L
.13014 0 L
.13124 0 L
.13246 0 L
.13374 0 L
Mistroke
.13503 0 L
.13641 0 L
.13772 0 L
.13891 0 L
.14031 0 L
.14184 0 L
.14328 0 L
.14461 0 L
.1459 0 L
.14726 0 L
.14842 0 L
.1497 0 L
.15107 0 L
.15254 0 L
.15393 0 L
.15519 0 L
.15764 0 L
.15903 0 L
.16031 0 L
.16266 0 L
.16384 0 L
.16515 0 L
.16633 0 L
.16756 0 L
.16977 0 L
.17101 0 L
.17215 0 L
.17349 0 L
.17475 0 L
.17585 0 L
.17704 0 L
.17911 0 L
.18029 0 L
.18153 0 L
.18376 0 L
.18498 0 L
.1863 0 L
.18746 0 L
.1887 0 L
.19104 0 L
.19321 0 L
.19453 0 L
.19595 0 L
.19721 0 L
.19853 0 L
.20105 0 L
.20335 1e-05 L
.20554 1e-05 L
.20788 1e-05 L
.21008 1e-05 L
Mistroke
.21209 2e-05 L
.21445 3e-05 L
.21702 4e-05 L
.21944 5e-05 L
.22167 6e-05 L
.2241 9e-05 L
.22632 .00012 L
.22889 .00016 L
.23133 .00021 L
.23358 .00027 L
.23566 .00035 L
.23795 .00045 L
.24039 .00059 L
.24306 .00079 L
.24595 .00107 L
.24869 .00141 L
.2512 .00182 L
.25597 .00289 L
.25837 .00362 L
.26101 .0046 L
.26352 .00576 L
.26625 .0073 L
.27121 .01103 L
.27604 .01614 L
.28051 .02253 L
.28533 .03161 L
.29065 .04484 L
.2962 .06283 L
.30142 .08406 L
.31125 .13594 L
.32159 .205 L
.33129 .27564 L
.3401 .33487 L
.34467 .36027 L
.34964 .38165 L
.35236 .39017 L
.35356 .39313 L
.35488 .39582 L
.35612 .39778 L
.35728 .39912 L
.35851 .40001 L
.35983 .40034 L
.36105 .40009 L
.36218 .39936 L
.36343 .39803 L
.36412 .39704 L
.36475 .396 L
.36716 .39073 L
.36942 .38398 L
.37364 .36711 L
Mistroke
.37819 .34338 L
.39777 .20765 L
.40813 .13806 L
.41384 .10577 L
.41924 .07997 L
.42436 .05982 L
.42994 .04246 L
.43501 .03034 L
.43969 .02178 L
.44409 .01566 L
.44894 .01066 L
.45138 .00872 L
.45401 .00698 L
.45876 .00459 L
.46117 .00368 L
.46373 .00289 L
.46835 .00185 L
.47118 .00139 L
.47385 .00106 L
.47624 .00082 L
.47883 .00062 L
.48138 .00047 L
.48417 .00034 L
.48709 .00025 L
.48982 .00018 L
.49237 .00013 L
.4947 .0001 L
.49739 7e-05 L
.49994 5e-05 L
.5023 4e-05 L
.50452 3e-05 L
.50695 2e-05 L
.50957 1e-05 L
.51217 1e-05 L
.51348 1e-05 L
.51492 1e-05 L
.51745 0 L
.51982 0 L
.52221 0 L
.52448 0 L
.52651 0 L
.52871 0 L
.53112 0 L
.53233 0 L
.53366 0 L
.5348 0 L
.53602 0 L
.53823 0 L
.53956 0 L
.54077 0 L
Mistroke
.54206 0 L
.54347 0 L
.54478 0 L
.54598 0 L
.54834 0 L
.54966 0 L
.55089 0 L
.55236 0 L
.5537 0 L
.55501 0 L
.55644 0 L
.55794 0 L
.55937 0 L
.56177 0 L
.56314 0 L
.56443 0 L
.56569 0 L
.56702 0 L
.56847 0 L
.56981 0 L
.57096 0 L
.57219 0 L
.57442 0 L
.57578 0 L
.57706 0 L
.57821 0 L
.57946 0 L
.58067 0 L
.58182 0 L
.58314 0 L
.58435 0 L
.58541 0 L
.58654 0 L
.58778 0 L
.58893 0 L
.59028 0 L
.59174 0 L
.59313 0 L
.59439 0 L
.59554 0 L
.5968 0 L
.59812 0 L
.59934 0 L
.60065 0 L
.60208 0 L
.60342 0 L
.60466 0 L
.60578 0 L
.60701 0 L
.6083 0 L
Mistroke
.60951 0 L
.61091 0 L
.61224 0 L
.61344 0 L
.61475 0 L
.61616 0 L
.61767 0 L
.61909 0 L
.62039 0 L
.62159 0 L
.62271 0 L
.62393 0 L
.62525 0 L
.62663 0 L
.62794 0 L
.62912 0 L
.6304 0 L
.6315 0 L
.63272 0 L
.63399 0 L
.63518 0 L
.6363 0 L
.63732 0 L
.63844 0 L
.63961 0 L
.64092 0 L
.6421 0 L
.64347 0 L
.64476 0 L
.64596 0 L
.64706 0 L
.64827 0 L
.64955 0 L
.65084 0 L
.65155 0 L
.65223 0 L
.65353 0 L
.65473 0 L
.65541 0 L
.65614 0 L
.65745 0 L
.65826 0 L
.65901 0 L
.65975 0 L
.66043 0 L
.66159 0 L
.66284 0 L
.664 0 L
.66509 0 L
.66636 0 L
Mistroke
.66754 0 L
.66883 0 L
.66949 0 L
.67021 0 L
.67086 0 L
.67154 0 L
.67277 0 L
.67409 0 L
.67484 0 L
.67553 0 L
.6768 0 L
.67795 0 L
.67858 0 L
.67927 0 L
.68053 0 L
.68168 0 L
.68275 0 L
.68393 0 L
.6852 0 L
.68584 0 L
.68653 0 L
.68778 0 L
.68901 0 L
.69014 0 L
.69131 0 L
.6924 0 L
.69338 0 L
.69444 0 L
.6956 0 L
.69682 0 L
.69786 0 L
.69901 0 L
.70032 0 L
.70153 0 L
.70216 0 L
.70286 0 L
.7036 0 L
.70427 0 L
.70551 0 L
.70619 0 L
.70684 0 L
.70799 0 L
.70925 0 L
.71048 0 L
.71159 0 L
.71288 0 L
.71409 0 L
.71521 0 L
.71624 0 L
.71738 0 L
Mistroke
.71857 0 L
.71988 0 L
.72107 0 L
.72172 0 L
.72244 0 L
.72374 0 L
.72495 0 L
.72624 0 L
.72734 0 L
.72855 0 L
.72925 0 L
.72997 0 L
.73127 0 L
.732 0 L
.73267 0 L
.73341 0 L
.73421 0 L
.73489 0 L
.73563 0 L
.73629 0 L
.73698 0 L
.7383 0 L
.73951 0 L
.74072 0 L
.74204 0 L
.74328 0 L
.74444 0 L
.74558 0 L
.74662 0 L
.74782 0 L
.74894 0 L
.75018 0 L
.75148 0 L
.7526 0 L
.75382 0 L
.75513 0 L
.75587 0 L
.75654 0 L
.75785 0 L
.75908 0 L
.76013 0 L
.76129 0 L
.76251 0 L
.76364 0 L
.7647 0 L
.76567 0 L
.76674 0 L
.76786 0 L
.769 0 L
.77022 0 L
Mistroke
.77137 0 L
.77241 0 L
.77364 0 L
.77434 0 L
.77498 0 L
.77615 0 L
.77739 0 L
.77861 0 L
.7793 0 L
.77993 0 L
.7811 0 L
.78234 0 L
.78344 0 L
.78448 0 L
.78562 0 L
.78685 0 L
.78808 0 L
.78878 0 L
.78943 0 L
.79074 0 L
.79148 0 L
.79215 0 L
.79334 0 L
.79464 0 L
.79587 0 L
.797 0 L
.79806 0 L
.79919 0 L
.80026 0 L
.80124 0 L
.80238 0 L
.80363 0 L
.80481 0 L
.8059 0 L
.80713 0 L
.80829 0 L
.80934 0 L
.81046 0 L
.8117 0 L
.813 0 L
.81411 0 L
.81533 0 L
.81663 0 L
.81784 0 L
.81847 0 L
.81917 0 L
.81989 0 L
.82057 0 L
.82182 0 L
.82296 0 L
Mistroke
.82422 0 L
.82554 0 L
.82665 0 L
.82784 0 L
.82897 0 L
.82999 0 L
.83119 0 L
.83249 0 L
.83372 0 L
.83485 0 L
.83605 0 L
.83735 0 L
.83857 0 L
.83969 0 L
.841 0 L
.84174 0 L
.84242 0 L
.84368 0 L
.84438 0 L
.84501 0 L
.84569 0 L
.8464 0 L
.84768 0 L
.84839 0 L
.84905 0 L
.84978 0 L
.85055 0 L
.85123 0 L
.85196 0 L
.85265 0 L
.85328 0 L
.85449 0 L
.85577 0 L
.85697 0 L
.85828 0 L
.85952 0 L
.86068 0 L
.86182 0 L
.86285 0 L
.86404 0 L
.86517 0 L
.8664 0 L
.8677 0 L
.86881 0 L
.87003 0 L
.87134 0 L
.87208 0 L
.87275 0 L
.87405 0 L
.87529 0 L
Mistroke
.87634 0 L
.87749 0 L
.8787 0 L
.87984 0 L
.8809 0 L
.88187 0 L
.88293 0 L
.88405 0 L
.88519 0 L
.88641 0 L
.88756 0 L
.8886 0 L
.88983 0 L
.89053 0 L
.89117 0 L
.89234 0 L
.89359 0 L
.89479 0 L
.89611 0 L
.89736 0 L
.89851 0 L
.89965 0 L
.90069 0 L
.90189 0 L
.90301 0 L
.90425 0 L
.90555 0 L
.90666 0 L
.90788 0 L
.9092 0 L
.90994 0 L
.91061 0 L
.91191 0 L
.91315 0 L
.9142 0 L
.91536 0 L
.91657 0 L
.91771 0 L
.91876 0 L
.91973 0 L
.9208 0 L
.92192 0 L
.92306 0 L
.92428 0 L
.92543 0 L
.92648 0 L
.92771 0 L
.9284 0 L
.92904 0 L
.93021 0 L
Mistroke
.93146 0 L
.93267 0 L
.93399 0 L
.93524 0 L
.9364 0 L
.93744 0 L
.93858 0 L
.93978 0 L
.94091 0 L
.94215 0 L
.94345 0 L
.94457 0 L
.94579 0 L
.94711 0 L
.94784 0 L
.94852 0 L
.94982 0 L
.95106 0 L
.95211 0 L
.95327 0 L
.95449 0 L
.95562 0 L
.95669 0 L
.95766 0 L
.95878 0 L
.95984 0 L
.96099 0 L
.96221 0 L
.96336 0 L
.9644 0 L
.96563 0 L
.96633 0 L
.96696 0 L
.96814 0 L
.96938 0 L
.97027 0 L
.97108 0 L
.97201 0 L
.9729 0 L
.97372 0 L
.97448 0 L
.97531 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00H_ooool2onk^kP?ooooo0_o^
k^h]ooooo`;ok^k^0oooool2onk^kSKooooo0_o^k^h3ooooo`;ok^k^9?ooool2onk^kP?ooooo0_o^
k^iSooooo`00G?ooool03Om4A4Co0000o`000?lb<S;ogMgMooooooo^k^koEEEEonk^k_ooooook^k^
oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hHooooo`Co
000000Wo410@ooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?oo
ooooooooonk^k_lb<S;o0000oc8b<_o^k^hAooooo`Co000000?o410@ooooooooool00_ooool2ob4Q
8@Gooooo00goA4A4o`000?l0003o<S8bomgMgOooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^
00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^3_ooool5o`0000;ooooo
00Ook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413oooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^E?ooool005oooooo00WoMgMgoc8b<_ooooooooooonk^k_mEEEGogMgMoeEE
EOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool0
0ol0003oooooooooo`02ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool00ol0003oooooooooo`04ooooo`;o8B4Q
2?ooool02OmgMgOo<S8booooooooooook^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
0oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg05Cooooo001Pooooo`07o`000?oooooooooooooooooMgMgo0000omgMg@07
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Jooooo`03o`000?oo
oooooooo00?ooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?oo
ooooooooooooool@41004oooool00ol0003oooooooooo`0?ooooo`07o`000?oooooooooooooooooM
gMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400?
ooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@4100E?ooool005oooooo00WoMgMgoc8b<_ooooooooooonk^
k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000006_ooool00ol0003oooooooooo`02ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000004oooool00ol0003ooooooooo
o`0>ooooo`09ogMgMolb<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo0000013ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000005Cooooo001Looooo`0=o`000?lQ8B7o0000oc8b<_o<c<coooooonk^k_mEEEGok^k^
ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Jooooo`0;o`000?ooooooooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Ooo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000004oooool00ol0003ooooo
ooooo`0;ooooo`0=o`000?lQ8B7o0000oc8b<_o<c<coooooonk^k_mEEEGok^k^ooooooo^k^koEEEE
onk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Aooooo`0;
ogMgMomVIVKoooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool00000E?ooool005cooooo00?o0000ooooooooool0
0oooool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@400Jooooo`04o`000?ooooooooooooooo`;ok^k^0oooool2onk^kPGooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@01?ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`03ooooo`;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@01;ooooo00?o0000ooooooooool00_o^k^h3ooooo`;ok^k^1Ooo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100E?ooool005cooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
6_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Cooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool01Ol0003o^[ZjoooooonHV9So
410@00kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg05Cooooo001L
ooooo`Co00003?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?oo
ool00ol0003oooooooooo`0=ooooo`03oeEEEOmVIVKo000000gooooo00?oEEEEofIVI_l000001?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo0_l00007ooooo`03oeEEEOmVIVKo000000gooooo
1?l0000<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`;o
00001?ooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo00?oEEEEofIVI_l000001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Sooooo0_l0001:ooooo`00P?ooool00ol0003oooooooooo`0`oooo
o`04o`000?ooooooooooo`0003Wooooo00Co0000oooooooooooo00009oooool01?l0003ooooooooo
ool00019ooooo`00N_ooool4o`0000?ooooo00?o0000ooooooooool0:_ooool4o`000005ooooool0
003oooooooooool00000=?ooool4o`000005ooooool0003oooooooooool000008_ooool4o`000005
ooooool0003oooooooooool00000BOooool0087ooooo00?o0000ooooooooool0;oooool3o`0003[o
oooo0ol0000Xooooo`?o0000B_ooool007oooooo00Co0000oooooooooooo0000<Oooool00ol0003o
ooooooooo`0jooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool03_ooool00omgMgOo
IVIVooooo`0^ooooo`03ofIVI_mgMgOooooo00Oooooo001oooooo`Co0000<_ooool00ol0003ooooo
ooooo`0jooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool03?ooool00ooMgMgo410@
onk^kP0_ooooo`03onk^k_l@413ogMgM00Oooooo003ooooooa_ooooo0_l00002ooooo`;o00003?oo
ool01?mEEEGoV9RHooooooooool2o`0000;ooooo00Oo0000oooooooooooo0000oa0@4?o^k^koEEEE
00;o000000?oA4A4okZj^_ooool00_ooool01OnHV9So0000o`000?m4A4Co^[Zj00;ooooo00Sok^k^
oeEEEOl0003o0000odA4A?nj^[[ooooooa0@40Go00000oooool02?l@413o<S8bo`000?l0003o410@
ojVYZOn7QhOoIVIV1oooool00?oooooo6oooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@cooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`08o`000?ooooooEEEEogMg
Moooooook^k^ogMgMol@4103ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000_ooool01_mEEEGoMgMg
ooooooo^k^koMgMgoa0@40?ooooo00?o0000ooooooooool01?ooool02?l0003oZJVYoooooooooooo
^[Zjo`000?o^k^ko00001oooool0023ooooolOl0000:ooooo`04omgMgOl0003o410@olc<c0gooooo
00?o<S8booooooooool00_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo000000So
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Go
oooo00Oo^[ZjohN7QomVIVKoIVIVoa0@4?oooooo000000Oooooo000Vooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool01oooool6o`0000Cooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool6o`00
00Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00gooooo00Cok^k^ob4Q8Ol@413ok^k^3Oooool00olb<S;oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000;ooooo00?o0000ooooool000001Ol00003ooooo`03o`000?oooooooooo00Cooooo1_l0
0003ooooo`03o`000?oooooooooo00Cooooo00So<S8bob4Q8OmgMgOoMgMgohN7Qoo^k^koooooo`00
00Oooooo000kooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0<Oooool00ol0003o
ooooooooo`0aooooo`03o`000?oooooooooo00gooooo00Co8B4QogMgMomgMgOo<S8b3Oooool00ol0
003ok^k^ooooo`02ooooo`0>o`000?o<c<coc<c<o`000?nYZJWogMgMob4Q8OooooooEEEEohN7Qoo^
k^koooooohN7Qolb<S83ooooo`03o`000?oooooooooo00Cooooo00KoEEEEohN7Qoo^k^koooooohN7
Qolb<S83ooooo`03o`000?lb<S;ogMgM00Cooooo00So0000okZj^_ooooook^k^ogMgMol0003ok^k^
o`0000Oooooo000kooooo`03o`000?oooooooooo02?ooooo0_l0000Yooooo`03o`000?oooooooooo
08_ooooo0_l00002ooooo`;o00003?ooool03omEEEGoMgMgoooooooooooo410@o`000?lQ8B7o0000
ogMgMol@413o0000ojVYZOooooook^k^oeEEE@02o`000004odA4A?o^k^kooooooa0@40Go00000ooo
ool01_o^k^koEEEEo`000?l0003oA4A4onk^kP;ooooo0_l000001?nYZJWo8B4Qo`000?lQ8B42oooo
o`08ojVYZOlQ8B7o0000o`000?lb<S;o0000ogMgMomEEED7ooooo`00>oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0W_ooool00ooMgMgo410@onk^
kP0Cooooo`03o`000?oooooooooo01Wooooo00?ok^k^oa0@4?oMgMd01oooool003_ooooo0_l0000V
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0Woooool00omgMgOoIVIVooooo`0B
ooooo`03o`000?oooooooooo01Wooooo00?oIVIVogMgMoooool01oooool003_ooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo0=_ooooo000kooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`3Kooooo`00
>oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
g?ooool003_ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo0=cooooo000kooooo`;o0000:Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo0=gooooo000kooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`3Mooooo`00>oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool0gOooool003_ooooo00?o0000ooooooooool0:?ooool00ol0003ooooo
ooooo`0Nooooo`03o`000?oooooooooo0=kooooo000kooooo`;o0000:_ooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo0=kooooo000kooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`3Oooooo`00>oooool00ol0003oooooooooo`0Yoooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool0goooool003_ooooo00?o0000oooooooo
ool0:_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo0=oooooo000Gooooo`;ok^k^
0oooool2onk^kQgooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo0>3ooooo000Aooooo`0=odA4A?l0003o0000oc8b<_oMgMgoooooonk^k_mEEEGok^k^
ooooooo^k^koEEEEonk^kP03ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^
kPkooooo0_l0000[ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0h?ooool001Co
oooo00WoMgMgoc8b<_ooooooooooonk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`0[ooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool0h?ooool001Gooooo00Oo0000oooooooooooooooo
omgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@
00kooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
0>3ooooo000Dooooo`09ogMgMolb<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool0
:oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo0>3ooooo000Aooooo`0=o`000?lQ
8B7o0000oc8b<_o<c<coooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000>ooooo`;o0000;?ooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo0>3ooooo000Aooooo`03o`000?oooooooooo00?ooooo0_o^
k^h3ooooo`;ok^k^1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100
3_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
hOooool0017ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL00oooool3o`000003ooooool0003o000000;o00000oooool00ol0003ooooo
ooooo`0/ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0hOooool0017ooooo1?l0
000<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`05o`00
0?ooooooooooooooool000001Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool0hOooool0037ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`3Qooooo`00<Oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooo`;o0000
;Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo0>7ooooo000aooooo`04o`000?oo
ooooooooo`0000;ooooo00Go0000ooooooooooooooooo`00000^ooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool0h_ooool0033ooooo0_l00003ooooo`;o00001?ooool00ol0003ooooo
ooooo`0/ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0h_ooool003_ooooo00?o
0000ooooooooool0;Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0>;ooooo000k
ooooo`;o0000;_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0>;ooooo000koooo
o`03o`000?oooooooooo02gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`3Soooo
o`00>oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool0hoooool003_ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo0>?ooooo000kooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`3Sooooo`00>oooool2o`0002kooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`3Sooooo`00>oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool0hoooool003_ooooo00?o0000ooooooooool0;_ooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo0>Cooooo000kooooo`03o`000?oooooooooo02kooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`3Tooooo`005oooool2onk^kP?ooooo0_o^
k^hMooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`3Tooooo`004Oooool4o`000009oa0@4?ooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?o
oooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^3_ooool2o`0002oooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`3Tooooo`004oooool00ol0003oooooooooo`02
ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool0i?ooool001?ooooo00?o0000ooooooooool00oooool00ooMgMgo0000omgM
g@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`00
0?oooooooooo02kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`3Tooooo`004ooo
ool00ol0003oooooooooo`02ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003oooooooooo`0^ooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool0i?ooool001?ooooo00_o0000oooooooooooo
ooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`00000>ooooo`;o0000;oooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo0>Cooooo000Cooooo`04o`000?ooooooooooooooo`;ok^k^0oooool2onk^kPGooooo
00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000oooooooo
ool0;oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo0>Gooooo000Cooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo0ol00002ooooo`;o00001?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool0iOooool0017ooooo00?oEEEEofIVI_l000003Oooool00omEEEGoIVIV
o`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool01?l0003oooooooooool00002oooo
o`05o`000?ooooooooooooooool00000<Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo0>Gooooo000aooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00000a
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0iOooool0037ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`02ooooo`;o0000<?ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo0>Gooooo000aooooo`04o`000?ooooooooooo`0000;ooooo00Go0000oooo
ooooooooooooo`00000aooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0iOooool0
033ooooo0_l00003ooooo`;o00001?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool0iOooool003_ooooo00?o0000ooooooooool0<?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo0>Kooooo000kooooo`;o0000<Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo0>Kooooo000kooooo`03o`000?oooooooooo033ooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`3Vooooo`00>oooool00ol0003oooooooooo`0`
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0i_ooool003_ooooo00?o0000oooo
ooooool0<?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo0>Kooooo000kooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`3Vooooo`00
>oooool2o`0003;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`3Vooooo`00>ooo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0iooo
ool003_ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo0>Oooooo000kooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`3Wooooo`006?ooool2onk^kP?ooooo0_o^k^hLooooo`;o0000<_ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo0>Oooooo0002ooooo`Co000000?o410@ooooooooool0
0_ooool2ob4Q8@Gooooo00goA4A4o`000?l0003o<S8bomgMgOooooook^k^oeEEEOo^k^koooooonk^
k_mEEEGok^k^00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^3Oooool0
0ol0003oooooooooo`0booooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0ioooool0
00Cooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00WoMgMgoc8b<_ooooooooooonk^k_mE
EEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03Oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool0ioooool000Cooooo00?o0000ooooooooool03oooool01ol0003ooooooooooooooooogMgMo`00
0?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41003Oooool0
0ol0003oooooooooo`0booooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0j?ooool0
00Cooooo00?o0000ooooooooool03_ooool02OmgMgOo<S8booooooooooook^k^oeEEEOoMgMgoEEEE
onk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000=ooooo`03
o`000?oooooooooo03;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`3Xooooo`00
1?ooool00ol0003oooooooooo`0;ooooo`0=o`000?lQ8B7o0000oc8b<_o<c<coooooonk^k_mEEEGo
k^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`00000=ooooo`;o0000<oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0>So
oooo0004ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00oooool2onk^kP?ooooo
0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03
o`000?oooooooooo03;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`3Xooooo`00
1?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo0ol00002ooooo`;o00000oooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0j?ooool000;ooooo
00?oEEEEofIVI_l000003Oooool4o`0000cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Cooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0000e
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0j?ooool003;ooooo00?o0000oooo
ooooool00oooool01?l0003oooooooooool0000eooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0j?ooool003;ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooooooool2
o`0003Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`3Yooooo`00<_ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0003Gooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`3Yooooo`00<Oooool2o`0000?ooooo0_l00003ooooo`03o`000?oooooo
oooo03?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`3Yooooo`00>oooool00ol0
003oooooooooo`0cooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0jOooool003_o
oooo0_l0000eooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0jOooool003_ooooo
00?o0000ooooooooool0=?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0>Wooooo
000kooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`3Yooooo`00>oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0j_ooool003_ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo0>[ooooo000kooooo`;o0000=Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo0>[ooooo000kooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`3Zooooo`00>oooool00ol0003oooooooooo`0eooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0j_ooool001Oooooo0_o^k^h3ooooo`;ok^k^7Oooool0
0ol0003oooooooooo`0eooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0j_ooool0
013ooooo1Ol00002ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co000000So
410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPkooooo0_l0000fooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0joooool0013ooooo00GoV9RHob4Q8Oo^k^koooooodA4A003oooo
o`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0joooool0017ooooo00?oV9RHob4Q8Oo^k^h01Oooool00ooMgMgo0000omgMg@07
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oo
oooooooo03Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3[ooooo`004_ooool0
0onHV9So8B4Qonk^kP03ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003oooooooooo`0fooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0joooool001?ooooo00_oMgMgofIVI_oooooooooo
onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`3[ooooo`005?ooool00ol0003oooooooooo`02onk^kP?ooooo0_o^k^h5
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400>ooooo`;o0000=ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0>cooooo000@ooooo`05o`000?nj^[[o
oooooiRHV?l@41003_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
k?ooool0013ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00<ooooo`03oeEEEOmVIVKo000000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`?o00000_ooool2o`0000Cooooo00?o0000oooooooo
ool0=oooool01?l0003oooooooooool0003_ooooo`00<Oooool01?l0003oooooooooool00002oooo
o`05o`000?ooooooooooooooool00000>Oooool01?l0003oooooooooool0003_ooooo`00<Oooool0
0ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooo`;o0000>Oooool3o`000>oooooo000a
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0i
ooooo`03o`000?oooooooooo0>kooooo000aooooo`04o`000?ooooooooooo`0000;ooooo00Go0000
ooooooooooooooooo`00003oooooobgooooo000`ooooo`;o00000oooool2o`0000Cooooo00?o0000
ooooooooool0ooooool[ooooo`00>oooool00ol0003oooooooooo`3oooooob_ooooo000kooooo`;o
0000ooooool/ooooo`00>oooool00ol0003oooooooooo`3oooooob_ooooo000kooooo`03o`000?oo
oooooooo0?oooooo:oooool003_ooooo00?o0000ooooooooool0ooooool[ooooo`00>oooool00ol0
003oooooooooo`3oooooob_ooooo000kooooo`;o0000ooooool/ooooo`00>oooool00ol0003ooooo
ooooo`3oooooob_ooooo000kooooo`03o`000?oooooooooo0?oooooo:oooool001Sooooo0_o^k^h3
ooooo`;ok^k^7?ooool00ol0003oooooooooo`3oooooob_ooooo00000ooooooo0000o`000003o`00
00Gooooo0_lQ8B45ooooo`0=odA4A?l0003o0000oc8b<_oMgMgoooooonk^k_mEEEGok^k^ooooooo^
k^koEEEEonk^kP03ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPgooooo
0_l0003oooooobcooooo00001_ooooooV9RHob4Q8Oo^k^koooooodA4A0Gooooo0_lQ8B48ooooo`09
ogMgMolb<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00gooooo00?o0000ooooooooool0ooooool[ooooo`000_oo
ool00onHV9So8B4Qonk^kP0Aooooo`07o`000?oooooooooooooooooMgMgo0000omgMg@07ooooo`03
o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03o`000?oooooooooo
0?oooooo:oooool000?ooooo00?oV9RHob4Q8Oo^k^h03oooool02OmgMgOo<S8booooooooooook^k^
oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000=ooooo`03o`000?oooooooooo0?oooooo:oooool000Cooooo00?oMgMgofIVI_ooool02ooo
ool03Ol0003o8B4Qo`000?lb<S;oc<c<ooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Ooo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000003Oooool00ol0003ooooo
ooooo`3oooooob_ooooo0005ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00ooo
ool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooo
oa0@400=ooooo`;o0000ooooool/ooooo`0000Koooooo`000?nj^[[ooooooiRHV?l@410<ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00gooooo00?o0000ooooooooool0ooooool[ooooo`0000KooooooiRHV?l@413o0000ob4Q8Oo<c<`<
ooooo`Co00003?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ooo
ool3o`0000;ooooo0_l00003ooooo`03o`000?oooooooooo0?oooooo:oooool003;ooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooool0003oooooobgooooo000booooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00_l0003oooooobcooooo000booooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`00003oooooobgooooo000booooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo0000ooooool]ooooo`00<Oooool2o`0000?ooooo0_l0
0003ooooo`03o`000?oooooooooo0?oooooo:oooool003_ooooo00?o0000ooooooooool0ooooool[
ooooo`00>oooool2o`000?oooooo;?ooool003_ooooo00?o0000ooooooooool0ooooool[ooooo`00
>oooool00ol0003oooooooooo`3oooooob_ooooo000kooooo`03o`000?oooooooooo0?oooooo:ooo
ool003_ooooo0_l0003oooooobcooooo000kooooo`03o`000?oooooooooo0?oooooo:oooool003_o
oooo00?o0000ooooooooool0ooooool[ooooo`00>oooool00ol0003oooooooooo`3oooooob_ooooo
000Gooooo`;ok^k^0oooool2onk^kQgooooo00?o0000ooooooooool0ooooool[ooooo`004?ooool0
1OnHV9So410@o`000?lb<S;oc<c<00;ooooo00Ook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?o
oooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^3_ooool2o`000?oooooo;?oo
ool0013ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h0
1_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool00ol0003o
ooooooooo`3oooooob_ooooo000Dooooo`03o`000?oooooooooo00;ooooo00?ogMgMo`000?oMgMd0
1oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003o
ooooooooo`3oooooob_ooooo000Cooooo`03ojVYZOl@413ooooo00;ooooo00Gok^k^oeEEEOoMgMgo
EEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000>oooo
o`03o`000?oooooooooo0?oooooo:oooool001;ooooo00?o410@o`000?nj^[X00_ooool01oo^k^ko
EEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000003_ooool00ol0003oooooooooo`3oooooob_ooooo000Cooooo`04okZj^_lQ8B7o
ooooooooo`;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@00kooooo0_l0003oooooobcooooo000@ooooo`05oa0@4?nHV9SooooookZj^_l00000
3_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool00ol0003o
ooooooooo`3oooooob_ooooo000@ooooo`05ojVYZOl@413o0000oa0@4?nYZJT03?ooool00omEEEGo
IVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool3o`0000;ooooo0_l00004oooo
o`03o`000?oooooooooo0?oooooo:oooool0037ooooo00Co0000oooooooooooo00000_ooool01Ol0
003ooooooooooooooooo00000?oooooo;Oooool0037ooooo00?o0000ooooooooool00oooool01?l0
003oooooooooooooool2o`000?oooooo;?ooool0037ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo:oooool0037ooooo00Co0000oooooooo
oooo00000_ooool01Ol0003ooooooooooooooooo00000?oooooo;Oooool0033ooooo0_l00003oooo
o`;o00001?ooool00ol0003oooooooooo`3oooooob_ooooo000kooooo`03o`000?oooooooooo0?oo
oooo:oooool003_ooooo0_l0003oooooobcooooo000kooooo`03o`000?oooooooooo0?oooooo:ooo
ool003_ooooo00?o0000ooooooooool0ooooool[ooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00GOooool00omgMgOoIVIVooooo`04oooo
o`03o`000?oooooooooo00;ooooo00?o^[Zjoc8b<_ooool01oooool01_l0003ooooooooooooooooo
IVIVogMgM`gooooo00?o0000okZj^_ooool0goooool005cooooo00?ogMgMoa0@4?o^k^h01Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00Oo0000ooooooooooooooooonk^
k_l@413ogMgM00cooooo0_lb<S;Pooooo`00G?ooool00omEEEGoV9RHooooo`05ooooo`06o`000?oo
oooooooooooooonHV9So410@0_l000000onYZJWoooooooooo`04ooooo`03o`000?oooooooooo00;o
oooo00?oQhN7ofIVI_ooool02oooool00on7QhOo0000okZj^P05ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01?ooool2ob4Q8@?ooooo00Goc<c<onk^k_ooooook^k^olc<c003ooooo`Co000000So410@
ooooooooooook^k^oc8b<_l0003o<S8bonk^kQ?ooooo00Ko410@oc8b<_l0003o0000oa0@4?nYZJT2
ooooo`06onk^k_mEEEGo0000o`000?m4A4Co^[Zj0oooool01OmVIVKo0000o`000?m4A4Coc<c<08oo
oooo001Looooo`03o`000?oooooooooo00Gooooo00[o0000ooooooooooooooooo`000?nYZJWoEEEE
oiRHV?mEEEGo^[Zj1Oooool00ol0003oooooooooo`02ooooo`03onk^k_l0003ooooo00_ooooo00?o
c<c<o`000?l@41002?ooool00omgMgOo<S8booooo`03ooooo`;o8B4Q0oooool01Oo^k^koEEEEomgM
gOmEEEGok^k^00Gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01?o
oooo00Ko0000ojVYZOoooooooooookZj^_l00002ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo410@
0_ooool01_mVIVKoMgMgooooooooooooQhN7oa0@48oooooo001Looooo`03oc8b<_oooooooooo00Go
oooo00[o0000oooooooooooooooooc8b<_o^k^koV9RHoeEEEOoMgMgo410@1Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02?ooool00ooMgMgo0000
omgMg@06ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Dooooo`05
okZj^_n7QhOoIVIVofIVI_l@41000_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
09;ooooo001Looooo`03oc8b<_oooooooooo00Gooooo00_o0000oooooooooooooooookZj^_m4A4Co
c<c<ob4Q8Ooooooo410@olc<c004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
5Oooool00omgMgOo<S8booooo`08ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01Oooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000004oooool01_lb<S;o8B4QogMgMomgMgOo
QhN7onk^kP;ooooo1_l00002ooooo`03o`000?oooooooooo09;ooooo001Looooo`03o`000?o^k^ko
oooo00Gooooo00_o0000ooooooooooooooooonk^k_l0003oooooo`000?ooooooIVIVohN7Q`04oooo
o`03o`000?oooooooooo00;ooooo00?ok^k^o`000?ooool04oooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00Wooooo00Goc<c<onk^k_ooooook^k^olc<c005ooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`00000Cooooo`06o`000?nj^[[oooooonk^k_mgMgOo00000_ooool01_mE
EEGoQhN7onk^k_ooooooQhN7oc8b<P;ooooo00KoIVIVogMgMoooooooooooohN7Qol0002?ooooo`00
G?ooool00omEEEGoMgMgooooo`05ooooo`08o`000?oooooooooooooooomVIVKoV9RHoooooolb<S82
okZj^P03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00omgMgOoEEEEooooo`03
ooooo`Co00003?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@4007ooooo`?o00000_ooool3o`0000Cooooo00KoZJVYob4Q8Ol0003o0000
oc8b<_l00002ooooo`06onk^k_mEEEGo0000o`000?m4A4Cok^k^0_ooool01_o^k^koIVIVo`000?l0
003oA4A4o`0008oooooo001Looooo`03omgMgOl@413ok^k^00Gooooo00?o0000ooooooooool01?oo
ool00omVIVKoQhN7ooooo`05ooooo`07o`000?ooooooooooooooooo^k^ko410@omgMg@05ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`02ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
0:Sooooo001Mooooo`03ogMgMomVIVKooooo00Cooooo00?o0000ooooooooool01?ooool00onYZJWo
A4A4ooooo`05ooooo`06o`000?oooooooooooooooomVIVKoMgMg1oooool00ol0003oooooooooo`0;
ooooo`Co00004_ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_oo
ool4o`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2Xooooo`00POooool0
0ol0003oooooooooo`0dooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Z?ooool0
07kooooo00Co0000oooooooooooo0000=_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo0:Sooooo001oooooo`;o0000=_ooool2o`0000?ooooo0_l0002Zooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -2.14748*^9, 0, \
2.14748*^9}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0 1.90278e-14 [
[.32684 -0.0125 -16.5 -12.5 ]
[.32684 -0.0125 16.5 0 ]
[.54329 -0.0125 -16.5 -12.5 ]
[.54329 -0.0125 16.5 0 ]
[.75974 -0.0125 -22.5 -12.5 ]
[.75974 -0.0125 22.5 0 ]
[.97619 -0.0125 -16.5 -12.5 ]
[.97619 -0.0125 16.5 0 ]
[1.025 0 0 -6 ]
[1.025 0 64 6 ]
[.09789 .09514 -33 -6.25 ]
[.09789 .09514 0 6.25 ]
[.09789 .19028 -33 -6.25 ]
[.09789 .19028 0 6.25 ]
[.09789 .28542 -45 -6.25 ]
[.09789 .28542 0 6.25 ]
[.09789 .38056 -33 -6.25 ]
[.09789 .38056 0 6.25 ]
[.09789 .47569 -45 -6.25 ]
[.09789 .47569 0 6.25 ]
[.09789 .57083 -33 -6.25 ]
[.09789 .57083 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -53.4375 0 ]
[.5 .63053 53.4375 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 0 m
.32684 .00625 L
s
gsave
.32684 -0.0125 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 0 m
.54329 .00625 L
s
gsave
.54329 -0.0125 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 0 m
.75974 .00625 L
s
gsave
.75974 -0.0125 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 0 m
.15368 .00375 L
s
.19697 0 m
.19697 .00375 L
s
.24026 0 m
.24026 .00375 L
s
.28355 0 m
.28355 .00375 L
s
.37013 0 m
.37013 .00375 L
s
.41342 0 m
.41342 .00375 L
s
.45671 0 m
.45671 .00375 L
s
.5 0 m
.5 .00375 L
s
.58658 0 m
.58658 .00375 L
s
.62987 0 m
.62987 .00375 L
s
.67316 0 m
.67316 .00375 L
s
.71645 0 m
.71645 .00375 L
s
.80303 0 m
.80303 .00375 L
s
.84632 0 m
.84632 .00375 L
s
.88961 0 m
.88961 .00375 L
s
.9329 0 m
.9329 .00375 L
s
.0671 0 m
.0671 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09514 m
.11664 .09514 L
s
gsave
.09789 .09514 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(12) show
grestore
.11039 .19028 m
.11664 .19028 L
s
gsave
.09789 .19028 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.11039 .28542 m
.11664 .28542 L
s
gsave
.09789 .28542 -45 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.11039 .38056 m
.11664 .38056 L
s
gsave
.09789 .38056 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.11039 .47569 m
.11664 .47569 L
s
gsave
.09789 .47569 -45 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.11039 .57083 m
.11664 .57083 L
s
gsave
.09789 .57083 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(3) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.125 Mabswid
.11039 .01903 m
.11414 .01903 L
s
.11039 .03806 m
.11414 .03806 L
s
.11039 .05708 m
.11414 .05708 L
s
.11039 .07611 m
.11414 .07611 L
s
.11039 .11417 m
.11414 .11417 L
s
.11039 .13319 m
.11414 .13319 L
s
.11039 .15222 m
.11414 .15222 L
s
.11039 .17125 m
.11414 .17125 L
s
.11039 .20931 m
.11414 .20931 L
s
.11039 .22833 m
.11414 .22833 L
s
.11039 .24736 m
.11414 .24736 L
s
.11039 .26639 m
.11414 .26639 L
s
.11039 .30444 m
.11414 .30444 L
s
.11039 .32347 m
.11414 .32347 L
s
.11039 .3425 m
.11414 .3425 L
s
.11039 .36153 m
.11414 .36153 L
s
.11039 .39958 m
.11414 .39958 L
s
.11039 .41861 m
.11414 .41861 L
s
.11039 .43764 m
.11414 .43764 L
s
.11039 .45667 m
.11414 .45667 L
s
.11039 .49472 m
.11414 .49472 L
s
.11039 .51375 m
.11414 .51375 L
s
.11039 .53278 m
.11414 .53278 L
s
.11039 .55181 m
.11414 .55181 L
s
.11039 .58986 m
.11414 .58986 L
s
.11039 .60889 m
.11414 .60889 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -114.438 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.812 moveto
(H) show
69.000 13.812 moveto
(\\310) show
75.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.812 moveto
(\\310) show
87.000 13.812 moveto
(L) show
93.000 9.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
98.250 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
104.250 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6.) show
116.250 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
122.250 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
134.250 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
138.438 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
147.875 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
165.875 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.02499 0 L
.02605 0 L
.02729 0 L
.02846 0 L
.02954 0 L
.03053 0 L
.03163 0 L
.03279 0 L
.03395 0 L
.0352 0 L
.03638 0 L
.03746 0 L
.03873 0 L
.03944 0 L
.04011 0 L
.04132 0 L
.04262 0 L
.04396 0 L
.04519 0 L
.04654 0 L
.04722 0 L
.04797 0 L
.04923 0 L
.05058 0 L
.05185 0 L
.05302 0 L
.05422 0 L
.05534 0 L
.05656 0 L
.05786 0 L
.05898 0 L
.06004 0 L
.0612 0 L
.06244 0 L
.06373 0 L
.06509 0 L
.06639 0 L
.06756 0 L
.06894 0 L
.06972 0 L
.07044 0 L
.07176 0 L
.07315 0 L
.07449 0 L
.07593 0 L
.07728 0 L
.07852 0 L
.07997 0 L
.08079 0 L
Mistroke
.08155 0 L
.08294 0 L
.08443 0 L
.08579 0 L
.08705 0 L
.08842 0 L
.08988 0 L
.09114 0 L
.09232 0 L
.09362 0 L
.095 0 L
.09624 0 L
.09758 0 L
.09884 0 L
.10002 0 L
.10107 0 L
.10223 0 L
.10344 0 L
.10458 0 L
.10576 0 L
.10702 0 L
.10821 0 L
.10929 0 L
.11056 0 L
.11194 0 L
.11324 0 L
.11444 0 L
.11568 0 L
.11684 0 L
.11811 0 L
.11948 0 L
.12091 0 L
.12226 0 L
.12348 0 L
.1248 0 L
.12594 0 L
.12702 0 L
.12819 0 L
.12946 0 L
.13072 0 L
.13205 0 L
.13318 0 L
.13442 0 L
.13664 0 L
.13789 0 L
.13903 0 L
.14009 0 L
.14123 0 L
.14332 0 L
.14455 0 L
Mistroke
.14567 0 L
.14688 0 L
.1482 0 L
.14941 0 L
.15054 0 L
.15277 0 L
.15413 0 L
.15541 0 L
.1578 0 L
.15915 0 L
.16038 0 L
.16174 0 L
.16317 0 L
.16568 0 L
.16708 0 L
.16836 0 L
.16955 0 L
.17085 0 L
.1732 0 L
.17452 0 L
.17597 0 L
.17749 0 L
.17892 0 L
.18146 0 L
.18289 0 L
.18421 0 L
.18549 0 L
.18669 0 L
.18895 0 L
.19022 0 L
.19138 0 L
.19275 0 L
.19402 0 L
.19613 0 L
.19845 0 L
.20071 0 L
.20314 0 L
.20452 0 L
.2058 0 L
.20732 0 L
.2087 0 L
.21125 0 L
.21265 0 L
.21397 0 L
.21644 0 L
.21872 0 L
.22122 0 L
.22385 0 L
.22641 0 L
.22883 0 L
Mistroke
.231 0 L
.23336 0 L
.23593 1e-05 L
.23866 1e-05 L
.24098 1e-05 L
.24354 2e-05 L
.24593 2e-05 L
.24811 3e-05 L
.25062 4e-05 L
.25302 5e-05 L
.25522 6e-05 L
.25726 8e-05 L
.2595 .0001 L
.26189 .00012 L
.2645 .00016 L
.26725 .00022 L
.26959 .00028 L
.27217 .00036 L
.27495 .00048 L
.27792 .00064 L
.28073 .00083 L
.2833 .00106 L
.28825 .00166 L
.29106 .00212 L
.29365 .00264 L
.29841 .00392 L
.30081 .00475 L
.30346 .00585 L
.30838 .00848 L
.31355 .0123 L
.31797 .01664 L
.3228 .02279 L
.32802 .0314 L
.3336 .04327 L
.34365 .07282 L
.35389 .11471 L
.36499 .17226 L
.37458 .22774 L
.38514 .28656 L
.39009 .31035 L
.3954 .33148 L
.39798 .3397 L
.40042 .34614 L
.40261 .35073 L
.40376 .35266 L
.40501 .35438 L
.40575 .35522 L
.40644 .35587 L
.40708 .35637 L
.40778 .3568 L
Mistroke
.409 .35723 L
.41029 .35727 L
.41103 .3571 L
.4117 .35682 L
.41247 .35635 L
.41321 .35577 L
.41451 .35439 L
.41592 .35241 L
.41847 .34757 L
.42118 .34074 L
.42605 .32443 L
.43544 .28108 L
.44555 .22418 L
.46384 .12325 L
.47343 .08171 L
.48391 .0483 L
.4892 .03593 L
.49485 .02562 L
.50018 .01823 L
.50502 .01314 L
.50988 .0093 L
.51502 .00633 L
.51941 .00449 L
.52423 .00303 L
.52694 .00241 L
.52942 .00195 L
.53208 .00154 L
.53499 .00119 L
.53766 .00093 L
.54015 .00073 L
.5427 .00057 L
.54504 .00046 L
.54966 .00029 L
.55209 .00022 L
.55464 .00017 L
.55895 .00011 L
.5614 8e-05 L
.56367 6e-05 L
.56635 5e-05 L
.56888 4e-05 L
.57115 3e-05 L
.57362 2e-05 L
.57631 1e-05 L
.57915 1e-05 L
.58158 1e-05 L
.58426 1e-05 L
.58675 0 L
.58946 0 L
.59202 0 L
.5944 0 L
Mistroke
.59675 0 L
.59889 0 L
.60135 0 L
.60368 0 L
.60622 0 L
.6075 0 L
.6089 0 L
.61139 0 L
.61371 0 L
.61511 0 L
.61645 0 L
.61894 0 L
.62034 0 L
.62163 0 L
.62306 0 L
.62456 0 L
.62571 0 L
.62697 0 L
.62919 0 L
.63044 0 L
.63178 0 L
.63419 0 L
.63536 0 L
.63662 0 L
.63774 0 L
.63892 0 L
.63999 0 L
.64116 0 L
.64323 0 L
.6446 0 L
.64591 0 L
.64836 0 L
.64973 0 L
.651 0 L
.65248 0 L
.65387 0 L
.65509 0 L
.6564 0 L
.6587 0 L
.66 0 L
.66137 0 L
.66383 0 L
.66506 0 L
.66639 0 L
.66756 0 L
.66881 0 L
.66993 0 L
.67116 0 L
.67334 0 L
.67466 0 L
Mistroke
.67587 0 L
.67726 0 L
.67859 0 L
.67973 0 L
.68094 0 L
.68227 0 L
.68351 0 L
.68467 0 L
.68589 0 L
.68723 0 L
.68846 0 L
.68954 0 L
.69069 0 L
.69195 0 L
.69313 0 L
.69426 0 L
.69548 0 L
.69655 0 L
.6977 0 L
.69872 0 L
.69986 0 L
.70186 0 L
.70307 0 L
.7042 0 L
.70544 0 L
.70677 0 L
.70816 0 L
.70948 0 L
.71066 0 L
.71194 0 L
.71305 0 L
.71428 0 L
.71556 0 L
.71675 0 L
.71787 0 L
.71889 0 L
.72007 0 L
.72119 0 L
.7225 0 L
.72369 0 L
.72507 0 L
.72636 0 L
.72756 0 L
.72867 0 L
.72988 0 L
.73116 0 L
.73246 0 L
.73385 0 L
.73516 0 L
.73635 0 L
Mistroke
.73775 0 L
.73849 0 L
.73927 0 L
.74071 0 L
.74204 0 L
.74318 0 L
.74443 0 L
.74573 0 L
.74694 0 L
.74807 0 L
.74911 0 L
.7503 0 L
.75142 0 L
.75265 0 L
.75395 0 L
.75506 0 L
.75628 0 L
.75759 0 L
.75899 0 L
.76032 0 L
.76153 0 L
.76266 0 L
.76386 0 L
.765 0 L
.76602 0 L
.76724 0 L
.76854 0 L
.76978 0 L
.77092 0 L
.77199 0 L
.77298 0 L
.77408 0 L
.77525 0 L
.77648 0 L
.77764 0 L
.77868 0 L
.77982 0 L
.78104 0 L
.78217 0 L
.78346 0 L
.78469 0 L
.78582 0 L
.78687 0 L
.78803 0 L
.78926 0 L
.78996 0 L
.7906 0 L
.7913 0 L
.79206 0 L
.79335 0 L
Mistroke
.79405 0 L
.79471 0 L
.79596 0 L
.79709 0 L
.79841 0 L
.79965 0 L
.80086 0 L
.80154 0 L
.80219 0 L
.80348 0 L
.80421 0 L
.80488 0 L
.80601 0 L
.80724 0 L
.80853 0 L
.80972 0 L
.81041 0 L
.81115 0 L
.8118 0 L
.8125 0 L
.81381 0 L
.81502 0 L
.81569 0 L
.81641 0 L
.81771 0 L
.81851 0 L
.81926 0 L
.82 0 L
.82068 0 L
.82193 0 L
.82259 0 L
.82328 0 L
.82444 0 L
.82572 0 L
.82686 0 L
.82809 0 L
.82924 0 L
.83029 0 L
.8316 0 L
.83281 0 L
.83344 0 L
.83414 0 L
.83487 0 L
.83555 0 L
.83678 0 L
.83743 0 L
.83811 0 L
.83926 0 L
.84052 0 L
.84177 0 L
Mistroke
.84294 0 L
.84399 0 L
.84514 0 L
.84638 0 L
.8477 0 L
.84882 0 L
.85006 0 L
.85121 0 L
.85227 0 L
.85349 0 L
.85464 0 L
.8557 0 L
.85669 0 L
.85777 0 L
.85892 0 L
.86005 0 L
.86129 0 L
.86259 0 L
.8638 0 L
.86493 0 L
.86596 0 L
.86715 0 L
.86827 0 L
.86949 0 L
.87079 0 L
.87189 0 L
.87311 0 L
.87442 0 L
.87515 0 L
.87582 0 L
.87713 0 L
.87836 0 L
.87951 0 L
.88056 0 L
.88176 0 L
.88289 0 L
.88395 0 L
.88492 0 L
.88598 0 L
.8871 0 L
.88824 0 L
.88945 0 L
.8906 0 L
.89165 0 L
.89287 0 L
.89357 0 L
.89421 0 L
.89538 0 L
.89663 0 L
.89777 0 L
Mistroke
.89902 0 L
.90032 0 L
.90153 0 L
.90266 0 L
.9037 0 L
.90489 0 L
.90601 0 L
.90724 0 L
.90853 0 L
.90964 0 L
.91086 0 L
.91217 0 L
.91291 0 L
.91358 0 L
.91488 0 L
.91612 0 L
.91727 0 L
.91832 0 L
.91952 0 L
.92066 0 L
.92171 0 L
.92268 0 L
.92374 0 L
.92487 0 L
.926 0 L
.92722 0 L
.92837 0 L
.92941 0 L
.93064 0 L
.93134 0 L
.93198 0 L
.93315 0 L
.9344 0 L
.9356 0 L
.93692 0 L
.93816 0 L
.93931 0 L
.94045 0 L
.94148 0 L
.94268 0 L
.9438 0 L
.94503 0 L
.94633 0 L
.94744 0 L
.94866 0 L
.94997 0 L
.95071 0 L
.95138 0 L
.95269 0 L
.95392 0 L
Mistroke
.95497 0 L
.95613 0 L
.95734 0 L
.95847 0 L
.95953 0 L
.9605 0 L
.96156 0 L
.96268 0 L
.96382 0 L
.96504 0 L
.96619 0 L
.96724 0 L
.96846 0 L
.96916 0 L
.9698 0 L
.97097 0 L
.97222 0 L
.97321 0 L
.97427 0 L
.97527 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00H_ooool2onk^kP?ooooo0_o^
k^h]ooooo`;ok^k^0oooool2onk^kSKooooo0_o^k^h3ooooo`;ok^k^9?ooool2onk^kP?ooooo0_o^
k^iSooooo`00G?ooool03Om4A4Co0000o`000?lb<S;ogMgMooooooo^k^koEEEEonk^k_ooooook^k^
oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hHooooo`Co
000000Wo410@ooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?oo
ooooooooonk^k_lb<S;o0000oc8b<_o^k^hAooooo`Co000000?o410@ooooooooool00_ooool2ob4Q
8@Gooooo00goA4A4o`000?l0003o<S8bomgMgOooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^
00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^3_ooool5o`0000;ooooo
00Ook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413oooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^E?ooool005oooooo00WoMgMgoc8b<_ooooooooooonk^k_mEEEGogMgMoeEE
EOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool0
0ol0003oooooooooo`02ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool00ol0003oooooooooo`04ooooo`;o8B4Q
2?ooool02OmgMgOo<S8booooooooooook^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
0oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg05Cooooo001Pooooo`07o`000?oooooooooooooooooMgMgo0000omgMg@07
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Jooooo`03o`000?oo
oooooooo00?ooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?oo
ooooooooooooool@41004oooool00ol0003oooooooooo`0?ooooo`07o`000?oooooooooooooooooM
gMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400?
ooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@4100E?ooool005oooooo00WoMgMgoc8b<_ooooooooooonk^
k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000006_ooool00ol0003oooooooooo`02ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000004oooool00ol0003ooooooooo
o`0>ooooo`09ogMgMolb<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo0000013ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000005Cooooo001Looooo`0=o`000?lQ8B7o0000oc8b<_o<c<coooooonk^k_mEEEGok^k^
ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Jooooo`0;o`000?ooooooooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Ooo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000004oooool00ol0003ooooo
ooooo`0;ooooo`0=o`000?lQ8B7o0000oc8b<_o<c<coooooonk^k_mEEEGok^k^ooooooo^k^koEEEE
onk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Aooooo`0;
ogMgMomVIVKoooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool00000E?ooool005cooooo00?o0000ooooooooool0
0oooool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@400Jooooo`04o`000?ooooooooooooooo`;ok^k^0oooool2onk^kPGooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@01?ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`03ooooo`;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@01;ooooo00?o0000ooooooooool00_o^k^h3ooooo`;ok^k^1Ooo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100E?ooool005cooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
6_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Cooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool01Ol0003o^[ZjoooooonHV9So
410@00kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg05Cooooo001L
ooooo`Co00003?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?oo
ool00ol0003oooooooooo`0=ooooo`03oeEEEOmVIVKo000000gooooo00?oEEEEofIVI_l000001?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo0_l00007ooooo`03oeEEEOmVIVKo000000gooooo
1?l0000<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`;o
00001?ooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo00?oEEEEofIVI_l000001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Sooooo0_l0001:ooooo`00P?ooool00ol0003oooooooooo`0`oooo
o`04o`000?ooooooooooo`0003Wooooo00Co0000oooooooooooo00009oooool01?l0003ooooooooo
ool00019ooooo`00N_ooool4o`0000?ooooo00?o0000ooooooooool0:_ooool4o`000005ooooool0
003oooooooooool00000=?ooool4o`000005ooooool0003oooooooooool000008_ooool4o`000005
ooooool0003oooooooooool00000BOooool0087ooooo00?o0000ooooooooool0;oooool3o`0003[o
oooo0ol0000Xooooo`?o0000B_ooool007oooooo00Co0000oooooooooooo0000<Oooool00ol0003o
ooooooooo`0jooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool03_ooool00omgMgOo
IVIVooooo`0^ooooo`03ofIVI_mgMgOooooo00Oooooo001oooooo`Co0000<_ooool00ol0003ooooo
ooooo`0jooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool03?ooool00ooMgMgo410@
onk^kP0_ooooo`03onk^k_l@413ogMgM00Oooooo003ooooooa_ooooo0_l00002ooooo`;o00003?oo
ool01?mEEEGoV9RHooooooooool2o`0000;ooooo00Oo0000oooooooooooo0000oa0@4?o^k^koEEEE
00;o000000?oA4A4okZj^_ooool00_ooool01OnHV9So0000o`000?m4A4Co^[Zj00;ooooo00Sok^k^
oeEEEOl0003o0000odA4A?nj^[[ooooooa0@40Go00000oooool02?l@413o<S8bo`000?l0003o410@
ojVYZOn7QhOoIVIV1oooool00?oooooo6oooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@cooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`08o`000?ooooooEEEEogMg
Moooooook^k^ogMgMol@4103ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000_ooool01_mEEEGoMgMg
ooooooo^k^koMgMgoa0@40?ooooo00?o0000ooooooooool01?ooool02?l0003oZJVYoooooooooooo
^[Zjo`000?o^k^ko00001oooool0023ooooolOl0000:ooooo`04omgMgOl0003o410@olc<c0gooooo
00?o<S8booooooooool00_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo000000So
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Go
oooo00Oo^[ZjohN7QomVIVKoIVIVoa0@4?oooooo000000Oooooo000Vooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`Ko00001_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo1ol00009ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00gooooo00Cok^k^ob4Q8Ol@413ok^k^3Oooool00olb<S;oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000;ooooo00?o0000ooooool000001Ol00003ooooo`03o`000?oooooooooo00Cooooo1_l0
0003ooooo`03o`000?oooooooooo00Cooooo00So<S8bob4Q8OmgMgOoMgMgohN7Qoo^k^koooooo`00
00Oooooo000kooooo`03o`000?oooooooooo02_ooooo0ol00003ooooo`03o`000?oooooooooo02[o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo037o
oooo00?o0000ooooooooool03Oooool01?lQ8B7oMgMgogMgMolb<S8=ooooo`03o`000?o^k^kooooo
00;ooooo00ko0000olc<c?o<c<co0000ojVYZOoMgMgo8B4QoooooomEEEGoQhN7onk^k_ooooooQhN7
oc8b<P?ooooo00?o0000ooooooooool01?ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<P?ooooo
00?o0000oc8b<_oMgMd01?ooool02?l0003o^[Zjooooooo^k^koMgMgo`000?o^k^ko00001oooool0
03_ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo
07cooooo0_l00002ooooo`;o00003?ooool03omEEEGoMgMgoooooooooooo410@o`000?lQ8B7o0000
ogMgMol@413o0000ojVYZOooooook^k^oeEEE@02o`000004odA4A?o^k^kooooooa0@40Go00000ooo
ool01_o^k^koEEEEo`000?l0003oA4A4onk^kP;ooooo0_l000001?nYZJWo8B4Qo`000?lQ8B42oooo
o`08ojVYZOlQ8B7o0000o`000?lb<S;o0000ogMgMomEEED7ooooo`00>oooool00ol0003ooooooooo
o`0_ooooo`03o`000?oooooooooo02Wooooo0_l0002Aooooo`03omgMgOl@413ok^k^01?ooooo00?o
0000ooooooooool06Oooool00oo^k^ko410@omgMg@07ooooo`00>oooool2o`00033ooooo00?o0000
ooooooooool0:?ooool00ol0003oooooooooo`2Booooo`03ogMgMomVIVKooooo01;ooooo00?o0000
ooooooooool06Oooool00omVIVKoMgMgooooo`07ooooo`00>oooool00ol0003oooooooooo`0`oooo
o`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0cOooool003_ooooo00?o0000oooooooo
ool0<?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo0<kooooo000kooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`3>ooooo`00>ooo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0cooo
ool003_ooooo0_l0000cooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0coooool0
03_ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
0=3ooooo000kooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`3Aooooo`00>oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo023ooooo
00?o0000ooooooooool0dOooool003_ooooo0_l0000dooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool0dOooool003_ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo0=;ooooo000kooooo`03o`000?oooooooooo03Cooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`3Booooo`00>oooool00ol0003oooooooooo`0dooooo`03
o`000?oooooooooo01kooooo00?o0000ooooooooool0d_ooool001Oooooo0_o^k^h3ooooo`;ok^k^
7Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
d_ooool0017ooooo00goA4A4o`000?l0003o<S8bomgMgOooooook^k^oeEEEOo^k^koooooonk^k_mE
EEGok^k^00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^3_ooool2o`00
03Kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`3Cooooo`005?ooool02OmgMgOo
<S8booooooooooook^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`3Cooooo`005Oooool01ol0003ooooooooooooooooogMgMo`000?oM
gMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0
003oooooooooo`0fooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0doooool001Co
oooo00WoMgMgoc8b<_ooooooooooonk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003oooooooooo`0fooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool0doooool0017ooooo00go0000ob4Q8Ol0003o<S8b
olc<c?ooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000000kooooo0_l0000gooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool0e?ooool0017ooooo00?o0000ooooooooool00oooool2onk^kP?ooooo0_o^
k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`00
0?oooooooooo03Kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`3Dooooo`004Ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`?o000000?oooooo`000?l000000_l00003ooooo`03o`000?oooooooooo03Kooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`3Dooooo`004Oooool4o`0000cooooo00?o
EEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo00Go0000oooooooooooo
ooooo`000005ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`3Dooooo`00<Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo0=Cooooo
000aooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooooooo0_l0000hooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool0eOooool0037ooooo00Co0000oooooooooooo0000
0_ooool01Ol0003ooooooooooooooooo000003Wooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`3Eooooo`00<?ooool2o`0000?ooooo0_l00004ooooo`03o`000?oooooooooo03Oooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`3Eooooo`00>oooool00ol0003ooooooooo
o`0hooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0eOooool003_ooooo0_l0000i
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0eOooool003_ooooo00?o0000oooo
ooooool0>?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo0=Kooooo000kooooo`03
o`000?oooooooooo03Sooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`3Fooooo`00
>oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
e_ooool003_ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo0=Kooooo000kooooo`;o0000>_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo0=Kooooo000kooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`3Gooooo`00>oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool0eoooool003_ooooo00?o0000ooooooooool0>Oooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo0=Oooooo000Gooooo`;ok^k^0oooool2onk^kQgooooo00?o
0000ooooooooool0>_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo0=Oooooo000A
ooooo`Co000000Wo410@ooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008
oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h>ooooo`;o0000>oooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo0=Oooooo000Cooooo`03o`000?oooooooooo00;ooooo00Gok^k^
oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0>ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`3Hooooo`004oooool00ol0003oooooooooo`03ooooo`03omgMgOl0003ogMgM00Oooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool0
>_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo0=Sooooo000Cooooo`03o`000?oo
oooooooo00;ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo
00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo03[ooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`3Hooooo`004oooool02ol0003oooooooooooooooook^k^oeEE
EOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000kooooo0_l0000looooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
f?ooool001?ooooo00Co0000oooooooooooooooo0_o^k^h3ooooo`;ok^k^1Oooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool0f?ooool001?ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool3o`0000;o
oooo0_l00004ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`3Iooooo`004Oooool00omEEEGoIVIVo`00000=ooooo`03oeEEEOmVIVKo000000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000oooo
ooooooooooooo`00000mooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0fOooool0
037ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000003gooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`3Iooooo`00<Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00;ooooo0_l0000looooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool0fOooool0037ooooo00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo
000003gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`3Iooooo`00<?ooool2o`00
00?ooooo0_l00004ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`3Jooooo`00>oooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool0f_ooool003_ooooo0_l0000mooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool0f_ooool003_ooooo00?o0000ooooooooool0??ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo0=[ooooo000kooooo`03o`000?oooooooooo03cooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`3Jooooo`00>oooool00ol0003oooooooooo`0moooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool0foooool003_ooooo00?o0000oooooooo
ool0?Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo0=_ooooo000kooooo`;o0000
?_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo0=_ooooo000kooooo`03o`000?oo
oooooooo03gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`3Kooooo`00>oooool0
0ol0003oooooooooo`0mooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0foooool0
03_ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
0=_ooooo000Hooooo`;ok^k^0oooool2onk^kQcooooo0_l0000oooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool0foooool000;ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q
1Oooool03Om4A4Co0000o`000?lb<S;ogMgMooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h0
0oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h=ooooo`03o`000?oooooo
oooo03kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`3Looooo`001?ooool00ol0
003oooooooooo`04ooooo`;o8B4Q2?ooool02OmgMgOo<S8booooooooooook^k^oeEEEOoMgMgoEEEE
onk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0=ooooo`03
o`000?oooooooooo03kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`3Looooo`00
1?ooool00ol0003oooooooooo`0?ooooo`07o`000?oooooooooooooooooMgMgo0000omgMg@07oooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03o`000?oooooo
oooo03kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`3Looooo`001?ooool00ol0
003oooooooooo`0>ooooo`09ogMgMolb<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000gooooo00?o0000oooooooo
ool0?oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0=cooooo0004ooooo`03o`00
0?oooooooooo00_ooooo00go0000ob4Q8Ol0003o<S8bolc<c?ooooook^k^oeEEEOo^k^koooooonk^
k_mEEEGok^k^00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000go
oooo0_l00010ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0g?ooool000Cooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`03ooooo`;ok^k^0oooool2onk^kPGooooo
00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00gooooo00?o0000oooooooo
ool0?oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0=cooooo0004ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL00oooool3o`0000;ooooo0_l00003ooooo`03o`000?oooooooooo03oo
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`3Mooooo`000_ooool00omEEEGoIVIV
o`00000=ooooo`Co00003?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01?ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00047ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`3Mooooo`00<_ooool00ol0003oooooooooo`03oooo
o`04o`000?ooooooooooo`0004;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3M
ooooo`00<_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooooooo`;o0000@Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0=gooooo000booooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo0000@_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo0=gooooo000aooooo`;o00000oooool2o`0000?ooooo00?o0000ooooooooool0@?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo0=kooooo000kooooo`03o`000?oooooooooo
043ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3Nooooo`00>oooool2o`0004;o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3Nooooo`00>oooool00ol0003ooooo
ooooo`11ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0g_ooool003_ooooo00?o
0000ooooooooool0@Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0=oooooo000k
ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3O
ooooo`00>oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0h?ooool003_ooooo0_l00013ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0h?ooool003_ooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo0>3ooooo000kooooo`03o`000?oooooooooo04?ooooo00Co0000oooooooooooo0000
hoooool001Oooooo0_o^k^h3ooooo`;ok^k^7Oooool00ol0003oooooooooo`14ooooo`?o0000hooo
ool0013ooooo1Ol00002ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co0000
00So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPkooooo0_l0003oooooobcooooo000@oooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00?o0000ooooooooool0
ooooool[ooooo`004Oooool00onHV9So8B4Qonk^kP05ooooo`03omgMgOl0003ogMgM00Oooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool0
ooooool[ooooo`004_ooool00onHV9So8B4Qonk^kP03ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h0
1_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003o
ooooooooo`3oooooob_ooooo000Cooooo`0;ogMgMomVIVKoooooooooooo^k^koEEEEonk^k_oooooo
k^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
3_ooool00ol0003oooooooooo`3oooooob_ooooo000Dooooo`03o`000?oooooooooo00;ok^k^0ooo
ool2onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00kooooo
0_l0003oooooobcooooo000@ooooo`05o`000?nj^[[ooooooiRHV?l@41003_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`3oooooob_o
oooo000@ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?ooool00omEEEGoIVIVo`000004ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h00oooool3o`0000;ooooo0_l00004ooooo`03o`000?oooooooooo
0?oooooo:oooool0037ooooo00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo
00000?oooooo;Oooool0037ooooo00?o0000ooooooooool00oooool01?l0003oooooooooooooool2
o`000?oooooo;?ooool0037ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo0?oooooo:oooool0037ooooo00Co0000oooooooooooo00000_ooool01Ol0
003ooooooooooooooooo00000?oooooo;Oooool0033ooooo0_l00003ooooo`;o00001?ooool00ol0
003oooooooooo`3oooooob_ooooo000kooooo`03o`000?oooooooooo0?oooooo:oooool003_ooooo
0_l0003oooooobcooooo000kooooo`03o`000?oooooooooo0?oooooo:oooool003_ooooo00?o0000
ooooooooool0ooooool[ooooo`00>oooool00ol0003oooooooooo`3oooooob_ooooo000kooooo`03
o`000?oooooooooo0?oooooo:oooool003_ooooo0_l0003oooooobcooooo000kooooo`03o`000?oo
oooooooo0?oooooo:oooool003_ooooo00?o0000ooooooooool0ooooool[ooooo`006?ooool2onk^
kP?ooooo0_o^k^hLooooo`03o`000?oooooooooo0?oooooo:oooool00003ooooool0003o000000?o
00001Oooool2ob4Q8@Gooooo00goA4A4o`000?l0003o<S8bomgMgOooooook^k^oeEEEOo^k^kooooo
onk^k_mEEEGok^k^00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^3Ooo
ool2o`000?oooooo;?ooool00006oooooonHV9So8B4Qonk^k_ooooooA4A41Oooool2ob4Q8@Sooooo
00WoMgMgoc8b<_ooooooooooonk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03Oooool00ol0003oooooooooo`3oooooob_ooooo0002
ooooo`03oiRHV?lQ8B7ok^k^017ooooo00Oo0000ooooooooooooooooomgMgOl0003ogMgM00Oooooo
00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00gooooo00?o0000oooooooo
ool0ooooool[ooooo`000oooool00onHV9So8B4Qonk^kP0?ooooo`09ogMgMolb<S;oooooooooooo^
k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000000gooooo00?o0000ooooooooool0ooooool[ooooo`001?ooool00omgMgOoIVIVooooo`0;
ooooo`0=o`000?lQ8B7o0000oc8b<_o<c<coooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000=ooooo`03o`000?oo
oooooooo0?oooooo:oooool000Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`03
ooooo`;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@00gooooo0_l0003oooooobcooooo00001_oooooo0000okZj^_ooooooV9RHoa0@40cooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03Oooool00ol0003oooooooooo`3oooooob_ooooo00001_ooooooV9RHoa0@4?l0003o8B4Qolc<
c0cooooo1?l0000<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03
ooooo`?o00000_ooool2o`0000?ooooo00?o0000ooooooooool0ooooool[ooooo`00<_ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`000?oooooo;Oooool003;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02o`000?oooooo;?ooool003;ooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo00000?oooooo;Oooool003;ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool0003oooooobgooooo000aooooo`;o00000oooool2
o`0000?ooooo00?o0000ooooooooool0ooooool[ooooo`00>oooool00ol0003oooooooooo`3ooooo
ob_ooooo000kooooo`;o0000ooooool/ooooo`00>oooool00ol0003oooooooooo`3oooooob_ooooo
000kooooo`03o`000?oooooooooo0?oooooo:oooool003_ooooo00?o0000ooooooooool0ooooool[
ooooo`00>oooool2o`000?oooooo;?ooool003_ooooo00?o0000ooooooooool0ooooool[ooooo`00
>oooool00ol0003oooooooooo`3oooooob_ooooo000kooooo`03o`000?oooooooooo0?oooooo:ooo
ool001Oooooo0_o^k^h3ooooo`;ok^k^7Oooool00ol0003oooooooooo`3oooooob_ooooo000@oooo
o`05oiRHV?l@413o0000oc8b<_o<c<`00_ooool01oo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h0
0oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h>ooooo`;o0000ooooool/
ooooo`004?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^
kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`00
0?oooooooooo0?oooooo:oooool001Cooooo00?o0000ooooooooool00_ooool00ooMgMgo0000omgM
g@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`00
0?oooooooooo0?oooooo:oooool001?ooooo00?oZJVYoa0@4?ooool00_ooool01Oo^k^koEEEEomgM
gOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?o0000ooooooooool0ooooool[ooooo`004_ooool00ol@413o0000okZj^P02ooooo`07onk^
k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03o`000?oooooooooo0?oooooo:oooool001?ooooo00Co^[Zjob4Q
8Ooooooooooo0_o^k^h3ooooo`;ok^k^1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooo
ooooooooool@41003_ooool2o`000?oooooo;?ooool0013ooooo00Go410@oiRHV?oooooo^[Zjo`00
000>ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`00
0?oooooooooo0?oooooo:oooool0013ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@0<ooooo`03oeEE
EOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`?o00000_ooool2o`0000Co
oooo00?o0000ooooooooool0ooooool[ooooo`00<Oooool01?l0003oooooooooool00002ooooo`05
o`000?ooooooooooooooool00000ooooool]ooooo`00<Oooool00ol0003oooooooooo`03ooooo`04
o`000?ooooooooooooooo`;o0000ooooool/ooooo`00<Oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0ooooool[ooooo`00<Oooool01?l0003ooooo
ooooool00002ooooo`05o`000?ooooooooooooooool00000ooooool]ooooo`00<?ooool2o`0000?o
oooo0_l00004ooooo`03o`000?oooooooooo0?oooooo:oooool003_ooooo00?o0000ooooooooool0
ooooool[ooooo`00>oooool2o`000?oooooo;?ooool003_ooooo00?o0000ooooooooool0ooooool[
ooooo`00>oooool00ol0003oooooooooo`3oooooob_ooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo001Mooooo`03ogMgMomVIVKooooo00Co
oooo00?o0000ooooooooool00_ooool00onj^[[o<S8booooo`07ooooo`06o`000?oooooooooooooo
oomVIVKoMgMg3Oooool00ol0003o^[Zjooooo`3Oooooo`00G?ooool00ooMgMgo410@onk^kP05oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01_ooool01ol0003ooooooooooooooooo
k^k^oa0@4?oMgMd03?ooool2oc8b<^3ooooo001Looooo`03oeEEEOnHV9Sooooo00Gooooo00Ko0000
oooooooooooooooooiRHV?l@4102o`000003ojVYZOoooooooooo00Cooooo00?o0000ooooooooool0
0_ooool00on7QhOoIVIVooooo`0;ooooo`03ohN7Qol0003o^[Zj00Cooooo00Gok^k^oc8b<_l0003o
410@olc<c005ooooo`;o8B4Q0oooool01Oo<c<cok^k^ooooooo^k^koc<c<00?ooooo1?l000002?l@
413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^4oooool01_l@413o<S8bo`000?l0003o410@ojVY
Z@;ooooo00Kok^k^oeEEEOl0003o0000odA4A?nj^[X3ooooo`05ofIVI_l0003o0000odA4A?o<c<`0
Soooool005cooooo00?o0000ooooooooool01Oooool02_l0003ooooooooooooooooo0000ojVYZOmE
EEGoV9RHoeEEEOnj^[X5ooooo`03o`000?oooooooooo00;ooooo00?ok^k^o`000?ooool02oooool0
0oo<c<co0000oa0@4004ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401Oooool2ob4Q8@?ooooo00Go
k^k^oeEEEOoMgMgoEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Cooooo`06o`000?nYZJWooooooooooonj^[[o00000_ooool01_mEEEGoMgMgooooooo^
k^koMgMgoa0@40;ooooo00KoIVIVogMgMoooooooooooohN7Qol@412?ooooo`00G?ooool00olb<S;o
ooooooooo`05ooooo`0:o`000?oooooooooooooooolb<S;ok^k^oiRHV?mEEEGogMgMoa0@40Gooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Aooooo`05o`000?ooooooooooooooool0
00002oooool00ooMgMgo0000omgMg@06ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooo
oooooooooa0@400Dooooo`05okZj^_n7QhOoIVIVofIVI_l@41000_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo09;ooooo001Looooo`03oc8b<_oooooooooo00Gooooo00_o0000oooo
oooooooooooookZj^_m4A4Coc<c<ob4Q8Ooooooo410@olc<c004ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool04Oooool01Ol0003oV9RHoooooonHV9So8B4Q00[ooooo00Gok^k^oeEE
EOoMgMgoEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
000Cooooo`06oc8b<_lQ8B7oMgMgogMgMon7QhOok^k^0_ooool6o`0000;ooooo00?o0000oooooooo
ool0T_ooool005cooooo00?o0000onk^k_ooool01Oooool02ol0003oooooooooooooooook^k^o`00
0?oooooo0000oooooomVIVKoQhN700Cooooo00?o0000ooooooooool00_ooool00oo^k^ko0000oooo
o`0Booooo`05o`000?mEEEGo0000oa0@4?o<c<`02_ooool01Oo<c<cok^k^ooooooo^k^koc<c<00Go
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000001?ooooo00Ko0000okZj
^_ooooook^k^ogMgMol00002ooooo`06oeEEEOn7QhOok^k^oooooon7QhOo<S8b0_ooool01_mVIVKo
MgMgooooooooooooQhN7o`0008oooooo001Looooo`03oeEEEOmgMgOooooo00Gooooo00So0000oooo
ooooooooooooofIVI_nHV9Sooooooc8b<P;o^[Zj00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`02ooooo`03ogMgMomEEEGooooo00?ooooo1?l0000;ooooo`03oeEEEOn7QhOooooo01Kooooo
00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Oooooo0ol00002ooooo`?o
00001?ooool01_nYZJWo8B4Qo`000?l0003o<S8bo`0000;ooooo00Kok^k^oeEEEOl0003o0000odA4
A?o^k^h2ooooo`06onk^k_mVIVKo0000o`000?m4A4Co0000Soooool005cooooo00?ogMgMoa0@4?o^
k^h01Oooool00ol0003oooooooooo`04ooooo`03ofIVI_n7QhOooooo00Gooooo00Oo0000oooooooo
ooooooooonk^k_l@413ogMgM00Gooooo00?o0000ooooooooool02oooool00ooMgMgo410@oiRHV00F
ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0Z?ooool005gooooo00?oMgMgofIVI_ooool01?ooool0
0ol0003oooooooooo`04ooooo`03ojVYZOm4A4Cooooo00Gooooo00Ko0000ooooooooooooooooofIV
I_mgMgL7ooooo`03o`000?oooooooooo00_ooooo00Coc<c<odA4A?l0003o410@4_ooool00omEEEGo
IVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_ooool4o`0000;ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`2Xooooo`00POooool00ol0003oooooooooo`0dooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0Z?ooool007kooooo00Co0000oooooooooooo
0000=_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0:Sooooo001oooooo`;o0000
=_ooool2o`0000?ooooo0_l0002Zooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -2.14748*^9, 0, \
2.14748*^9}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0 1.90278e-14 [
[.32684 -0.0125 -16.5 -12.5 ]
[.32684 -0.0125 16.5 0 ]
[.54329 -0.0125 -16.5 -12.5 ]
[.54329 -0.0125 16.5 0 ]
[.75974 -0.0125 -22.5 -12.5 ]
[.75974 -0.0125 22.5 0 ]
[.97619 -0.0125 -16.5 -12.5 ]
[.97619 -0.0125 16.5 0 ]
[1.025 0 0 -6 ]
[1.025 0 64 6 ]
[.09789 .09514 -33 -6.25 ]
[.09789 .09514 0 6.25 ]
[.09789 .19028 -33 -6.25 ]
[.09789 .19028 0 6.25 ]
[.09789 .28542 -45 -6.25 ]
[.09789 .28542 0 6.25 ]
[.09789 .38056 -33 -6.25 ]
[.09789 .38056 0 6.25 ]
[.09789 .47569 -45 -6.25 ]
[.09789 .47569 0 6.25 ]
[.09789 .57083 -33 -6.25 ]
[.09789 .57083 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -53.4375 0 ]
[.5 .63053 53.4375 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 0 m
.32684 .00625 L
s
gsave
.32684 -0.0125 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 0 m
.54329 .00625 L
s
gsave
.54329 -0.0125 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 0 m
.75974 .00625 L
s
gsave
.75974 -0.0125 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 0 m
.15368 .00375 L
s
.19697 0 m
.19697 .00375 L
s
.24026 0 m
.24026 .00375 L
s
.28355 0 m
.28355 .00375 L
s
.37013 0 m
.37013 .00375 L
s
.41342 0 m
.41342 .00375 L
s
.45671 0 m
.45671 .00375 L
s
.5 0 m
.5 .00375 L
s
.58658 0 m
.58658 .00375 L
s
.62987 0 m
.62987 .00375 L
s
.67316 0 m
.67316 .00375 L
s
.71645 0 m
.71645 .00375 L
s
.80303 0 m
.80303 .00375 L
s
.84632 0 m
.84632 .00375 L
s
.88961 0 m
.88961 .00375 L
s
.9329 0 m
.9329 .00375 L
s
.0671 0 m
.0671 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09514 m
.11664 .09514 L
s
gsave
.09789 .09514 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(12) show
grestore
.11039 .19028 m
.11664 .19028 L
s
gsave
.09789 .19028 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.11039 .28542 m
.11664 .28542 L
s
gsave
.09789 .28542 -45 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.11039 .38056 m
.11664 .38056 L
s
gsave
.09789 .38056 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.11039 .47569 m
.11664 .47569 L
s
gsave
.09789 .47569 -45 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.11039 .57083 m
.11664 .57083 L
s
gsave
.09789 .57083 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(3) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.125 Mabswid
.11039 .01903 m
.11414 .01903 L
s
.11039 .03806 m
.11414 .03806 L
s
.11039 .05708 m
.11414 .05708 L
s
.11039 .07611 m
.11414 .07611 L
s
.11039 .11417 m
.11414 .11417 L
s
.11039 .13319 m
.11414 .13319 L
s
.11039 .15222 m
.11414 .15222 L
s
.11039 .17125 m
.11414 .17125 L
s
.11039 .20931 m
.11414 .20931 L
s
.11039 .22833 m
.11414 .22833 L
s
.11039 .24736 m
.11414 .24736 L
s
.11039 .26639 m
.11414 .26639 L
s
.11039 .30444 m
.11414 .30444 L
s
.11039 .32347 m
.11414 .32347 L
s
.11039 .3425 m
.11414 .3425 L
s
.11039 .36153 m
.11414 .36153 L
s
.11039 .39958 m
.11414 .39958 L
s
.11039 .41861 m
.11414 .41861 L
s
.11039 .43764 m
.11414 .43764 L
s
.11039 .45667 m
.11414 .45667 L
s
.11039 .49472 m
.11414 .49472 L
s
.11039 .51375 m
.11414 .51375 L
s
.11039 .53278 m
.11414 .53278 L
s
.11039 .55181 m
.11414 .55181 L
s
.11039 .58986 m
.11414 .58986 L
s
.11039 .60889 m
.11414 .60889 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -114.438 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.812 moveto
(H) show
69.000 13.812 moveto
(\\310) show
75.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.812 moveto
(\\310) show
87.000 13.812 moveto
(L) show
93.000 9.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
98.250 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
104.250 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7.) show
116.250 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
122.250 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
134.250 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
138.438 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
147.875 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
165.875 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.02499 0 L
.02605 0 L
.02729 0 L
.02846 0 L
.02954 0 L
.03053 0 L
.03163 0 L
.03279 0 L
.03395 0 L
.0352 0 L
.03638 0 L
.03746 0 L
.03873 0 L
.04011 0 L
.04141 0 L
.04262 0 L
.04386 0 L
.04521 0 L
.04648 0 L
.04765 0 L
.04871 0 L
.04987 0 L
.05108 0 L
.05221 0 L
.05354 0 L
.0548 0 L
.05592 0 L
.05715 0 L
.05848 0 L
.0599 0 L
.06111 0 L
.06244 0 L
.06371 0 L
.0651 0 L
.06655 0 L
.0679 0 L
.06917 0 L
.07032 0 L
.07165 0 L
.0729 0 L
.07427 0 L
.07572 0 L
.07695 0 L
.07831 0 L
.07977 0 L
.08134 0 L
.08282 0 L
.08418 0 L
.08544 0 L
Mistroke
.08678 0 L
.08804 0 L
.08918 0 L
.09054 0 L
.092 0 L
.09338 0 L
.09464 0 L
.09584 0 L
.09695 0 L
.09817 0 L
.09948 0 L
.10085 0 L
.10215 0 L
.10331 0 L
.10458 0 L
.1058 0 L
.10692 0 L
.10815 0 L
.10944 0 L
.11057 0 L
.11162 0 L
.11278 0 L
.114 0 L
.11535 0 L
.11681 0 L
.11818 0 L
.11945 0 L
.1206 0 L
.12185 0 L
.12317 0 L
.12439 0 L
.1257 0 L
.12711 0 L
.12845 0 L
.1297 0 L
.13204 0 L
.13323 0 L
.13453 0 L
.13594 0 L
.13723 0 L
.13865 0 L
.14014 0 L
.14145 0 L
.14266 0 L
.14399 0 L
.14541 0 L
.14664 0 L
.148 0 L
.14941 0 L
.15073 0 L
Mistroke
.1531 0 L
.15443 0 L
.15564 0 L
.15696 0 L
.15836 0 L
.1599 0 L
.16133 0 L
.16279 0 L
.16417 0 L
.16539 0 L
.16673 0 L
.16919 0 L
.17053 0 L
.17178 0 L
.17402 0 L
.17527 0 L
.17641 0 L
.17899 0 L
.18044 0 L
.18179 0 L
.18426 0 L
.1855 0 L
.18688 0 L
.18923 0 L
.19056 0 L
.1918 0 L
.19431 0 L
.19571 0 L
.19698 0 L
.19927 0 L
.20056 0 L
.20175 0 L
.20393 0 L
.20624 0 L
.20872 0 L
.21011 0 L
.21138 0 L
.21384 0 L
.21618 0 L
.21749 0 L
.21889 0 L
.22141 0 L
.22295 0 L
.2244 0 L
.2271 0 L
.22952 0 L
.23178 0 L
.23425 0 L
.2369 0 L
.23968 0 L
Mistroke
.24231 0 L
.24467 0 L
.24724 0 L
.24946 0 L
.2519 0 L
.25445 0 L
.25685 0 L
.25908 0 L
.26112 0 L
.26348 0 L
.26573 1e-05 L
.26831 1e-05 L
.27075 1e-05 L
.27294 1e-05 L
.27531 1e-05 L
.27789 2e-05 L
.28063 3e-05 L
.28296 3e-05 L
.28552 4e-05 L
.29011 7e-05 L
.29268 9e-05 L
.29503 .00011 L
.29721 .00014 L
.29959 .00017 L
.30391 .00026 L
.30624 .00032 L
.30875 .0004 L
.3133 .0006 L
.31593 .00075 L
.31871 .00094 L
.32367 .00141 L
.32618 .00172 L
.32887 .00212 L
.3337 .00305 L
.33945 .00462 L
.34468 .00663 L
.34952 .00913 L
.35465 .01262 L
.35903 .01644 L
.36385 .0217 L
.36903 .02881 L
.37459 .03838 L
.38465 .06155 L
.39477 .09326 L
.40581 .13701 L
.42591 .22968 L
.43606 .27246 L
.44104 .28979 L
.44561 .30278 L
.44814 .30857 L
Mistroke
.4509 .31369 L
.45369 .31748 L
.45521 .31896 L
.45588 .31948 L
.45662 .31995 L
.45792 .32054 L
.45914 .32079 L
.46034 .32078 L
.46144 .32052 L
.46263 .31999 L
.46394 .3191 L
.46531 .31782 L
.4666 .31632 L
.46903 .31264 L
.4713 .3083 L
.47645 .29535 L
.48681 .25841 L
.50532 .17398 L
.52409 .09489 L
.53466 .06155 L
.54441 .03898 L
.54936 .03026 L
.5548 .02253 L
.56048 .01625 L
.56578 .01177 L
.57087 .00851 L
.57551 .00625 L
.58087 .0043 L
.58595 .00298 L
.59052 .00211 L
.59558 .00142 L
.59812 .00116 L
.60086 .00092 L
.60323 .00076 L
.60582 .00061 L
.61049 .0004 L
.61304 .00032 L
.61542 .00026 L
.61968 .00017 L
.62206 .00014 L
.62423 .00011 L
.62906 7e-05 L
.6315 6e-05 L
.63419 4e-05 L
.63648 3e-05 L
.63894 3e-05 L
.64124 2e-05 L
.64338 2e-05 L
.64604 1e-05 L
.64895 1e-05 L
Mistroke
.65151 1e-05 L
.65424 0 L
.65692 0 L
.65945 0 L
.66171 0 L
.66417 0 L
.66654 0 L
.66909 0 L
.67149 0 L
.67368 0 L
.67624 0 L
.67904 0 L
.68167 0 L
.68411 0 L
.68662 0 L
.68897 0 L
.69155 0 L
.693 0 L
.69433 0 L
.69685 0 L
.69828 0 L
.69961 0 L
.7023 0 L
.70381 0 L
.70518 0 L
.70749 0 L
.71003 0 L
.71131 0 L
.71268 0 L
.71387 0 L
.71516 0 L
.71644 0 L
.71763 0 L
.71997 0 L
.7221 0 L
.72437 0 L
.72578 0 L
.72707 0 L
.72847 0 L
.72999 0 L
.73257 0 L
.73397 0 L
.73529 0 L
.73657 0 L
.73778 0 L
.74006 0 L
.74133 0 L
.74251 0 L
.74387 0 L
.74517 0 L
Mistroke
.74633 0 L
.7476 0 L
.74982 0 L
.75107 0 L
.75241 0 L
.75482 0 L
.756 0 L
.75727 0 L
.75839 0 L
.75957 0 L
.76064 0 L
.76181 0 L
.76388 0 L
.76526 0 L
.76657 0 L
.76902 0 L
.77039 0 L
.77166 0 L
.77305 0 L
.77454 0 L
.77571 0 L
.77698 0 L
.77927 0 L
.7806 0 L
.78199 0 L
.78319 0 L
.78449 0 L
.78581 0 L
.78703 0 L
.78836 0 L
.78977 0 L
.791 0 L
.79214 0 L
.7934 0 L
.79476 0 L
.79595 0 L
.79726 0 L
.79849 0 L
.79963 0 L
.80179 0 L
.80299 0 L
.80409 0 L
.8054 0 L
.80679 0 L
.80797 0 L
.80927 0 L
.81067 0 L
.81217 0 L
.81359 0 L
.81487 0 L
Mistroke
.81617 0 L
.81737 0 L
.81869 0 L
.82009 0 L
.8213 0 L
.82244 0 L
.82369 0 L
.82503 0 L
.82629 0 L
.82743 0 L
.82875 0 L
.83 0 L
.83115 0 L
.83221 0 L
.83338 0 L
.83461 0 L
.83586 0 L
.83719 0 L
.83845 0 L
.83961 0 L
.84095 0 L
.84242 0 L
.84381 0 L
.84509 0 L
.84642 0 L
.84786 0 L
.84921 0 L
.85046 0 L
.85159 0 L
.85282 0 L
.85412 0 L
.85532 0 L
.85673 0 L
.85807 0 L
.85927 0 L
.86057 0 L
.86199 0 L
.8635 0 L
.86478 0 L
.8662 0 L
.86749 0 L
.86868 0 L
.86999 0 L
.87139 0 L
.87273 0 L
.87398 0 L
.87511 0 L
.87633 0 L
.87745 0 L
.87868 0 L
Mistroke
.87996 0 L
.88116 0 L
.88228 0 L
.8833 0 L
.88449 0 L
.8856 0 L
.8868 0 L
.88812 0 L
.8895 0 L
.8908 0 L
.892 0 L
.89311 0 L
.89432 0 L
.8956 0 L
.8969 0 L
.89829 0 L
.89961 0 L
.9008 0 L
.9022 0 L
.90299 0 L
.90372 0 L
.90506 0 L
.90574 0 L
.90648 0 L
.90777 0 L
.90897 0 L
.91029 0 L
.91103 0 L
.91169 0 L
.91292 0 L
.91424 0 L
.91549 0 L
.91664 0 L
.91776 0 L
.9188 0 L
.91994 0 L
.92116 0 L
.92244 0 L
.92365 0 L
.92474 0 L
.92592 0 L
.92722 0 L
.92843 0 L
.92976 0 L
.93051 0 L
.93119 0 L
.93249 0 L
.93323 0 L
.93392 0 L
.9353 0 L
Mistroke
.93608 0 L
.93678 0 L
.93807 0 L
.93926 0 L
.94057 0 L
.94122 0 L
.94195 0 L
.94316 0 L
.94446 0 L
.94569 0 L
.94682 0 L
.94768 0 L
.9485 0 L
.94939 0 L
.95035 0 L
.95131 0 L
.95232 0 L
.95318 0 L
.95412 0 L
.955 0 L
.95581 0 L
.95674 0 L
.95762 0 L
.95838 0 L
.95918 0 L
.96006 0 L
.96088 0 L
.96183 0 L
.96269 0 L
.96369 0 L
.96464 0 L
.96552 0 L
.96633 0 L
.96722 0 L
.96817 0 L
.96921 0 L
.97033 0 L
.9714 0 L
.97238 0 L
.97326 0 L
.97423 0 L
.97524 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00H_ooool2onk^kP?ooooo0_o^
k^h]ooooo`;ok^k^0oooool2onk^kSKooooo0_o^k^h3ooooo`;ok^k^9?ooool2onk^kP?ooooo0_o^
k^iSooooo`00G?ooool03Om4A4Co0000o`000?lb<S;ogMgMooooooo^k^koEEEEonk^k_ooooook^k^
oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hHooooo`Co
000000Wo410@ooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?oo
ooooooooonk^k_lb<S;o0000oc8b<_o^k^hAooooo`Co000000?o410@ooooooooool00_ooool2ob4Q
8@Gooooo00goA4A4o`000?l0003o<S8bomgMgOooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^
00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^3_ooool5o`0000;ooooo
00Ook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413oooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^E?ooool005oooooo00WoMgMgoc8b<_ooooooooooonk^k_mEEEGogMgMoeEE
EOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool0
0ol0003oooooooooo`02ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool00ol0003oooooooooo`04ooooo`;o8B4Q
2?ooool02OmgMgOo<S8booooooooooook^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
0oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg05Cooooo001Pooooo`07o`000?oooooooooooooooooMgMgo0000omgMg@07
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Jooooo`03o`000?oo
oooooooo00?ooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?oo
ooooooooooooool@41004oooool00ol0003oooooooooo`0?ooooo`07o`000?oooooooooooooooooM
gMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400?
ooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@4100E?ooool005oooooo00WoMgMgoc8b<_ooooooooooonk^
k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000006_ooool00ol0003oooooooooo`02ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000004oooool00ol0003ooooooooo
o`0>ooooo`09ogMgMolb<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo0000013ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000005Cooooo001Looooo`0=o`000?lQ8B7o0000oc8b<_o<c<coooooonk^k_mEEEGok^k^
ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Jooooo`0;o`000?ooooooooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Ooo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000004oooool00ol0003ooooo
ooooo`0;ooooo`0=o`000?lQ8B7o0000oc8b<_o<c<coooooonk^k_mEEEGok^k^ooooooo^k^koEEEE
onk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Aooooo`0;
ogMgMomVIVKoooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool00000E?ooool005cooooo00?o0000ooooooooool0
0oooool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@400Jooooo`04o`000?ooooooooooooooo`;ok^k^0oooool2onk^kPGooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@01?ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`03ooooo`;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@01;ooooo00?o0000ooooooooool00_o^k^h3ooooo`;ok^k^1Ooo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100E?ooool005cooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
6_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Cooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool01Ol0003o^[ZjoooooonHV9So
410@00kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg05Cooooo001L
ooooo`Co00003?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?oo
ool00ol0003oooooooooo`0=ooooo`03oeEEEOmVIVKo000000gooooo00?oEEEEofIVI_l000001?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo0_l00007ooooo`03oeEEEOmVIVKo000000gooooo
1?l0000<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`;o
00001?ooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo00?oEEEEofIVI_l000001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Sooooo0_l0001:ooooo`00P?ooool00ol0003oooooooooo`0`oooo
o`04o`000?ooooooooooo`0003Wooooo00Co0000oooooooooooo00009oooool01?l0003ooooooooo
ool00019ooooo`00N_ooool4o`0000?ooooo00?o0000ooooooooool0:_ooool4o`000005ooooool0
003oooooooooool00000=?ooool4o`000005ooooool0003oooooooooool000008_ooool4o`000005
ooooool0003oooooooooool00000BOooool0087ooooo00?o0000ooooooooool0;oooool3o`0003[o
oooo0ol0000Xooooo`?o0000B_ooool007oooooo00Co0000oooooooooooo0000<Oooool00ol0003o
ooooooooo`0jooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool03_ooool00omgMgOo
IVIVooooo`0^ooooo`03ofIVI_mgMgOooooo00Oooooo001oooooo`Co0000<_ooool00ol0003ooooo
ooooo`0jooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool03?ooool00ooMgMgo410@
onk^kP0_ooooo`03onk^k_l@413ogMgM00Oooooo003ooooooa_ooooo0_l00002ooooo`;o00003?oo
ool01?mEEEGoV9RHooooooooool2o`0000;ooooo00Oo0000oooooooooooo0000oa0@4?o^k^koEEEE
00;o000000?oA4A4okZj^_ooool00_ooool01OnHV9So0000o`000?m4A4Co^[Zj00;ooooo00Sok^k^
oeEEEOl0003o0000odA4A?nj^[[ooooooa0@40Go00000oooool02?l@413o<S8bo`000?l0003o410@
ojVYZOn7QhOoIVIV1oooool00?oooooo6oooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@cooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`08o`000?ooooooEEEEogMg
Moooooook^k^ogMgMol@4103ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000_ooool01_mEEEGoMgMg
ooooooo^k^koMgMgoa0@40?ooooo00?o0000ooooooooool01?ooool02?l0003oZJVYoooooooooooo
^[Zjo`000?o^k^ko00001oooool0023ooooolOl0000:ooooo`04omgMgOl0003o410@olc<c0gooooo
00?o<S8booooooooool00_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo000000So
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Go
oooo00Oo^[ZjohN7QomVIVKoIVIVoa0@4?oooooo000000Oooooo000Vooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Gooooo1ol00006ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool7o`00
00Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00gooooo00Cok^k^ob4Q8Ol@413ok^k^3Oooool00olb<S;oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000;ooooo00?o0000ooooool000001Ol00003ooooo`03o`000?oooooooooo00Cooooo1_l0
0003ooooo`03o`000?oooooooooo00Cooooo00So<S8bob4Q8OmgMgOoMgMgohN7Qoo^k^koooooo`00
00Oooooo000kooooo`03o`000?oooooooooo037ooooo00Go0000ooooooooooooooooo`00000_oooo
o`03o`000?oooooooooo00?ooooo0ol0000[ooooo`03o`000?oooooooooo037ooooo00?o0000oooo
ooooool03Oooool01?lQ8B7oMgMgogMgMolb<S8=ooooo`03o`000?o^k^kooooo00;ooooo00ko0000
olc<c?o<c<co0000ojVYZOoMgMgo8B4QoooooomEEEGoQhN7onk^k_ooooooQhN7oc8b<P?ooooo00?o
0000ooooooooool01?ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<P?ooooo00?o0000oc8b<_oM
gMd01?ooool02?l0003o^[Zjooooooo^k^koMgMgo`000?o^k^ko00001oooool003_ooooo00?o0000
ooooooooool0=_ooool2o`0003;ooooo00?o0000ooooooooool0Koooool2o`0000;ooooo0_l0000<
ooooo`0?oeEEEOmgMgOoooooooooool@413o0000ob4Q8Ol0003oMgMgoa0@4?l0003oZJVYooooooo^
k^koEEEE00;o000000CoA4A4onk^k_oooooo410@1Ol00003ooooo`06onk^k_mEEEGo0000o`000?m4
A4Cok^k^0_ooool2o`000004ojVYZOlQ8B7o0000ob4Q8@;ooooo00SoZJVYob4Q8Ol0003o0000oc8b
<_l0003oMgMgoeEEE@Oooooo000kooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0
;_ooool00ol0003oooooooooo`22ooooo`03omgMgOl@413ok^k^01?ooooo00?o0000ooooooooool0
6Oooool00oo^k^ko410@omgMg@07ooooo`00>oooool2o`0003[ooooo00?o0000ooooooooool0;Ooo
ool00ol0003oooooooooo`23ooooo`03ogMgMomVIVKooooo01;ooooo00?o0000ooooooooool06Ooo
ool00omVIVKoMgMgooooo`07ooooo`00>oooool00ol0003oooooooooo`0jooooo`03o`000?oooooo
oooo02_ooooo00?o0000ooooooooool0_oooool003_ooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo0<3ooooo000kooooo`03o`000?oooooooooo03_o
oooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`31ooooo`00>oooool00ol0003ooooo
ooooo`0looooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0`Oooool003_ooooo0_l0
000mooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0`_ooool003_ooooo00?o0000
ooooooooool0??ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo0<;ooooo000koooo
o`03o`000?oooooooooo03gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`33oooo
o`00>oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo02?ooooo00?o0000oooooooo
ool0`oooool003_ooooo0_l0000oooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0
`oooool003_ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo0<Cooooo000kooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool08Oooool0
0ol0003oooooooooo`34ooooo`00>oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo
023ooooo00?o0000ooooooooool0aOooool001Oooooo0_o^k^h3ooooo`;ok^k^7Oooool00ol0003o
ooooooooo`10ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0aOooool0017ooooo
00goA4A4o`000?l0003o<S8bomgMgOooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo
1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^3_ooool2o`00047ooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`35ooooo`005?ooool02OmgMgOo<S8boooooooooooo
k^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0>ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`36ooooo`005Oooool01ol0003ooooooooooooooooogMgMo`000?oMgMd01oooool00ol0
003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`10
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0a_ooool001Cooooo00WoMgMgoc8b
<_ooooooooooonk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000003_ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool0a_ooool0017ooooo00go0000ob4Q8Ol0003o<S8bolc<c?ooooook^k^
oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000kooooo0_l00012ooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool0aoooool0017ooooo00?o0000ooooooooool00oooool2onk^kP?ooooo0_o^k^h5ooooo`03o`00
0?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo047o
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`37ooooo`004Oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`?o
000000?oooooo`000?l000000_l00003ooooo`03o`000?oooooooooo047ooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`37ooooo`004Oooool4o`0000cooooo00?oEEEEofIVI_l00000
1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo00Go0000ooooooooooooooooo`000005oooo
o`03o`000?oooooooooo04;ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`38oooo
o`00<Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0@_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo0<Sooooo000aooooo`03o`00
0?oooooooooo00?ooooo00Co0000oooooooooooooooo0_l00013ooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool0b?ooool0037ooooo00Co0000oooooooooooo00000_ooool01Ol0003o
oooooooooooooooo000004Gooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`38oooo
o`00<?ooool2o`0000?ooooo0_l00004ooooo`03o`000?oooooooooo04?ooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`38ooooo`00>oooool00ol0003oooooooooo`13ooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool0bOooool003_ooooo0_l00015ooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool0bOooool003_ooooo00?o0000ooooooooool0A?ooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo0<Wooooo000kooooo`03o`000?oooooooooo
04Cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`39ooooo`00>oooool00ol0003o
ooooooooo`14ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0bOooool003_ooooo
00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0<[ooooo
000kooooo`;o0000A_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0<[ooooo000k
ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`3:
ooooo`00>oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool0b_ooool003_ooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo0<[ooooo000Gooooo`;ok^k^0oooool2onk^kQgooooo00?o0000ooooooooool0
A_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo0<_ooooo000Aooooo`Co000000Wo
410@ooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^h>ooooo`;o0000Aoooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo0<_ooooo000Cooooo`03o`000?oooooooooo00;ooooo00Gok^k^oeEEEOoMgMgoEEEE
onk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03
o`000?oooooooooo04Kooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`3;ooooo`00
4oooool00ol0003oooooooooo`03ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool0A_ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo0<_ooooo000Cooooo`03o`000?oooooooooo00;ooooo
00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`00000>ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`3<ooooo`004oooool02ol0003oooooooooooooooook^k^oeEEEOo^k^koooooonk^
k_mEEEGok^k^00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000ko
oooo0_l00018ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0c?ooool001?ooooo
00Co0000oooooooooooooooo0_o^k^h3ooooo`;ok^k^1Oooool00ol0003oooooooooo`02ooooo`05
oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool0c?ooool001?ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool3o`0000;ooooo0_l00004oooo
o`03o`000?oooooooooo04Oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`3<oooo
o`004Oooool00omEEEGoIVIVo`00000=ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP04ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`00
0019ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0cOooool0037ooooo00?o0000
ooooooooool00oooool01Ol0003ooooooooooooooooo000004[ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`3=ooooo`00<Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00;ooooo0_l00019ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0cOooool0
037ooooo00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo000004[ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`3=ooooo`00<?ooool2o`0000?ooooo0_l00004
ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`3>
ooooo`00>oooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool0c_ooool003_ooooo0_l0001:ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool0c_ooool003_ooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo0<kooooo000kooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`3?ooooo`00>oooool00ol0003oooooooooo`19ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool0coooool003_ooooo00?o0000ooooooooool0B_ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo0<oooooo000kooooo`;o0000Boooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo0<oooooo000kooooo`03o`000?oooooooooo04[ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`3@ooooo`00>oooool00ol0003ooooooooo
o`1:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0d?ooool003_ooooo00?o0000
ooooooooool0B_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0=3ooooo000Hoooo
o`;ok^k^0oooool2onk^kQcooooo0_l0001<ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool0d?ooool000;ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool03Om4A4Co
0000o`000?lb<S;ogMgMooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008
oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h=ooooo`03o`000?oooooooooo04_ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`3Aooooo`001?ooool00ol0003oooooooooo`04
ooooo`;o8B4Q2?ooool02OmgMgOo<S8booooooooooook^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0=ooooo`03o`000?oooooooooo
04_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`3Aooooo`001?ooool00ol0003o
ooooooooo`0?ooooo`07o`000?oooooooooooooooooMgMgo0000omgMg@07ooooo`03o`000?oooooo
oooo00;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03o`000?oooooooooo04_ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`3Aooooo`001?ooool00ol0003oooooooooo`0>
ooooo`09ogMgMolb<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000oooooooo
ool00_ooool01Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool0Boooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo0=7ooooo0004ooooo`03o`000?oooooooooo00_o
oooo00go0000ob4Q8Ol0003o<S8bolc<c?ooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Go
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000gooooo0_l0001=oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0dOooool000Cooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`03ooooo`;ok^k^0oooool2onk^kPGooooo00?o0000oooooooo
ool00_ooool01Ol@413ooooooooooooooooo410@00gooooo00?o0000ooooooooool0C?ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo0=;ooooo0004ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool3o`0000;ooooo0_l00003ooooo`03o`000?oooooooooo04cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`3Booooo`000_ooool00omEEEGoIVIVo`00000=ooooo`Co
00003?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0004oooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`3Booooo`00<_ooool00ol0003oooooooooo`03ooooo`04o`000?oooooo
ooooo`0004oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3Cooooo`00<_ooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooooooo`;o0000C_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo0=Cooooo000booooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo0000D?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0=Cooooo
000aooooo`;o00000oooool2o`0000?ooooo00?o0000ooooooooool0Coooool01?l0003ooooooooo
ool0003Gooooo`00>oooool00ol0003oooooooooo`1?ooooo`Co0000eoooool003_ooooo0_l0003o
ooooobcooooo000kooooo`03o`000?oooooooooo0?oooooo:oooool003_ooooo00?o0000oooooooo
ool0ooooool[ooooo`00>oooool00ol0003oooooooooo`3oooooob_ooooo000kooooo`03o`000?oo
oooooooo0?oooooo:oooool003_ooooo0_l0003oooooobcooooo000kooooo`03o`000?oooooooooo
0?oooooo:oooool003_ooooo00?o0000ooooooooool0ooooool[ooooo`005oooool2onk^kP?ooooo
0_o^k^hMooooo`03o`000?oooooooooo0?oooooo:oooool0013ooooo1Ol00002ooooo`07onk^k_mE
EEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o
<S8bonk^kPkooooo0_l0003oooooobcooooo000@ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00ooo
ool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00kooooo00?o0000ooooooooool0ooooool[ooooo`004Oooool00onHV9So8B4Q
onk^kP05ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@413ooooo
oooooooooooo410@00kooooo00?o0000ooooooooool0ooooool[ooooo`004_ooool00onHV9So8B4Q
onk^kP03ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000003_ooool00ol0003oooooooooo`3oooooob_ooooo000Cooooo`0;
ogMgMomVIVKoooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003oooooooooo`3oooooob_o
oooo000Dooooo`03o`000?oooooooooo00;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@00kooooo0_l0003oooooobcooooo000@ooooo`05o`00
0?nj^[[ooooooiRHV?l@41003_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL03_ooool00ol0003oooooooooo`3oooooob_ooooo000@ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`03?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool3
o`0000;ooooo0_l00004ooooo`03o`000?oooooooooo0?oooooo:oooool0037ooooo00Co0000oooo
oooooooo00000_ooool01Ol0003ooooooooooooooooo00000?oooooo;Oooool0037ooooo00?o0000
ooooooooool00oooool01?l0003oooooooooooooool2o`000?oooooo;?ooool0037ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo:oooool0
037ooooo00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo00000?oooooo;Ooo
ool0033ooooo0_l00003ooooo`;o00001?ooool00ol0003oooooooooo`3oooooob_ooooo000koooo
o`03o`000?oooooooooo0?oooooo:oooool003_ooooo0_l0003oooooobcooooo000kooooo`03o`00
0?oooooooooo0?oooooo:oooool003_ooooo00?o0000ooooooooool0ooooool[ooooo`00>oooool0
0ol0003oooooooooo`3oooooob_ooooo000kooooo`03o`000?oooooooooo0?oooooo:oooool003_o
oooo0_l0003oooooobcooooo000kooooo`03o`000?oooooooooo0?oooooo:oooool003_ooooo00?o
0000ooooooooool0ooooool[ooooo`006?ooool2onk^kP?ooooo0_o^k^hLooooo`03o`000?oooooo
oooo0?oooooo:oooool00003ooooool0003o000000?o00001Oooool2ob4Q8@Gooooo00goA4A4o`00
0?l0003o<S8bomgMgOooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@
413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^3Oooool2o`000?oooooo;?ooool00006oooooonH
V9So8B4Qonk^k_ooooooA4A41Oooool2ob4Q8@Sooooo00WoMgMgoc8b<_ooooooooooonk^k_mEEEGo
gMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3Oooool00ol0003oooooooooo`3oooooob_ooooo0002ooooo`03oiRHV?lQ8B7ok^k^017ooooo00Oo
0000ooooooooooooooooomgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@413o
oooooooooooooooo410@00gooooo00?o0000ooooooooool0ooooool[ooooo`000oooool00onHV9So
8B4Qonk^kP0?ooooo`09ogMgMolb<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool0
ooooool[ooooo`001?ooool00omgMgOoIVIVooooo`0;ooooo`0=o`000?lQ8B7o0000oc8b<_o<c<co
ooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`00000=ooooo`03o`000?oooooooooo0?oooooo:oooool000Gooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`03ooooo`;ok^k^0oooool2onk^kPGooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00gooooo0_l0003oooooobcooooo
00001_oooooo0000okZj^_ooooooV9RHoa0@40cooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03Oooool00ol0003oooooooooo`3ooooo
ob_ooooo00001_ooooooV9RHoa0@4?l0003o8B4Qolc<c0cooooo1?l0000<ooooo`03oeEEEOmVIVKo
000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`?o00000_ooool2o`0000?ooooo00?o
0000ooooooooool0ooooool[ooooo`00<_ooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`000?oooooo;Oooool003;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02o`000?oooooo;?ooool003;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo00000?oooooo;Oooool003;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool0003oooooobgooooo000aooooo`;o00000oooool2o`0000?ooooo00?o0000ooooooooool0oooo
ool[ooooo`00>oooool00ol0003oooooooooo`3oooooob_ooooo000kooooo`;o0000ooooool/oooo
o`00>oooool00ol0003oooooooooo`3oooooob_ooooo000kooooo`03o`000?oooooooooo0?oooooo
:oooool003_ooooo00?o0000ooooooooool0ooooool[ooooo`00>oooool2o`000?oooooo;?ooool0
03_ooooo00?o0000ooooooooool0ooooool[ooooo`00>oooool00ol0003oooooooooo`3oooooob_o
oooo000kooooo`03o`000?oooooooooo0?oooooo:oooool001Oooooo0_o^k^h3ooooo`;ok^k^7Ooo
ool00ol0003oooooooooo`3oooooob_ooooo000@ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00_oo
ool01oo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^
k_lb<S;o0000oc8b<_o^k^h>ooooo`;o0000ooooool/ooooo`004?ooool01Ol@413o^[Zjoooooomg
MgOo<S8b00?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oooooooooo0?oooooo:oooool001Cooooo
00?o0000ooooooooool00_ooool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo
00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo0?oooooo:oooool001?ooooo
00?oZJVYoa0@4?ooool00_ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000oooooooo
ool00_ooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool0ooooool[oooo
o`004_ooool00ol@413o0000okZj^P02ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oo
oooooooo0?oooooo:oooool001?ooooo00Co^[Zjob4Q8Ooooooooooo0_o^k^h3ooooo`;ok^k^1Ooo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41003_ooool2o`000?oooooo
;?ooool0013ooooo00Go410@oiRHV?oooooo^[Zjo`00000>ooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oooooooooo0?oooooo:oooool0013ooooo
00GoZJVYoa0@4?l0003o410@ojVYZ@0<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP03ooooo`?o00000_ooool2o`0000Cooooo00?o0000ooooooooool0ooooool[oooo
o`00<Oooool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool00000ooooool]
ooooo`00<Oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooo`;o0000ooooool/
ooooo`00<Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0ooooool[ooooo`00<Oooool01?l0003oooooooooool00002ooooo`05o`000?oooooooooo
ooooool00000ooooool]ooooo`00<?ooool2o`0000?ooooo0_l00004ooooo`03o`000?oooooooooo
0?oooooo:oooool003_ooooo00?o0000ooooooooool0ooooool[ooooo`00>oooool2o`000?oooooo
;?ooool003_ooooo00?o0000ooooooooool0ooooool[ooooo`00>oooool00ol0003oooooooooo`3o
ooooob_ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo001Mooooo`03ogMgMomVIVKooooo00Cooooo00?o0000ooooooooool00_ooool00onj
^[[o<S8booooo`07ooooo`06o`000?oooooooooooooooomVIVKoMgMg3Oooool00ol0003o^[Zjoooo
o`3Oooooo`00G?ooool00ooMgMgo410@onk^kP05ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01_ooool01ol0003oooooooooooooooook^k^oa0@4?oMgMd03?ooool2oc8b<^3ooooo
001Looooo`03oeEEEOnHV9Sooooo00Gooooo00Ko0000oooooooooooooooooiRHV?l@4102o`000003
ojVYZOoooooooooo00Cooooo00?o0000ooooooooool00_ooool00on7QhOoIVIVooooo`0;ooooo`03
ohN7Qol0003o^[Zj00Kooooo00?o0000onk^k_ooool01Oooool2ob4Q8@?ooooo00Goc<c<onk^k_oo
ooook^k^olc<c003ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kQ?ooooo
00Ko410@oc8b<_l0003o0000oa0@4?nYZJT2ooooo`06onk^k_mEEEGo0000o`000?m4A4Co^[Zj0ooo
ool01OmVIVKo0000o`000?m4A4Coc<c<08oooooo001Looooo`03o`000?oooooooooo00Gooooo00[o
0000ooooooooooooooooo`000?nYZJWoEEEEoiRHV?mEEEGo^[Zj1Oooool00ol0003oooooooooo`02
ooooo`03onk^k_l0003ooooo00_ooooo00?oc<c<o`000?l@41001_ooool00omEEEGoZJVYooooo`05
ooooo`;o8B4Q0oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Gooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01?ooooo00Ko0000ojVYZOoooooooooookZj^_l00002oooo
o`06oeEEEOmgMgOoooooonk^k_mgMgOo410@0_ooool01_mVIVKoMgMgooooooooooooQhN7oa0@48oo
oooo001Looooo`03oc8b<_oooooooooo00Gooooo00[o0000oooooooooooooooooc8b<_o^k^koV9RH
oeEEEOoMgMgo410@1Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01?ooooo00?o
ZJVYoeEEEOooool02oooool00ooMgMgo0000omgMg@06ooooo`03o`000?oooooooooo00;ooooo00Go
410@oooooooooooooooooa0@400Dooooo`05okZj^_n7QhOoIVIVofIVI_l@41000_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo09;ooooo001Looooo`03oc8b<_oooooooooo00Gooooo
00_o0000oooooooooooooooookZj^_m4A4Coc<c<ob4Q8Ooooooo410@olc<c004ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool05?ooool00olQ8B7oooooooooo`09ooooo`05onk^k_mE
EEGogMgMoeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
00004oooool01_lb<S;o8B4QogMgMomgMgOoQhN7onk^kP;ooooo1_l00002ooooo`03o`000?oooooo
oooo09;ooooo001Looooo`03o`000?o^k^kooooo00Gooooo00_o0000ooooooooooooooooonk^k_l0
003oooooo`000?ooooooIVIVohN7Q`04ooooo`03o`000?oooooooooo00;ooooo00?ok^k^o`000?oo
ool05Oooool00omEEEGoc<c<ooooo`09ooooo`05olc<c?o^k^koooooonk^k_o<c<`01Oooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000004oooool01_l0003o^[Zjooooooo^
k^koMgMgo`0000;ooooo00KoEEEEohN7Qoo^k^koooooohN7Qolb<S82ooooo`06ofIVI_mgMgOooooo
oooooon7QhOo0000Soooool005cooooo00?oEEEEogMgMoooool01Oooool02?l0003ooooooooooooo
ooooIVIVoiRHV?oooooo<S8b0_nj^[X00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o
oooo00?oMgMgoeEEEOooool00oooool4o`0000kooooo00?oZJVYogMgMoooool04oooool00ol0003o
ooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41001oooool3o`0000;ooooo0ol00004oooo
o`06ojVYZOlQ8B7o0000o`000?lb<S;o00000_ooool01_o^k^koEEEEo`000?l0003oA4A4onk^kP;o
oooo00Kok^k^ofIVI_l0003o0000odA4A?l0002?ooooo`00G?ooool00ooMgMgo410@onk^kP05oooo
o`03o`000?oooooooooo00Cooooo00?oIVIVohN7Qoooool01Oooool01ol0003ooooooooooooooooo
k^k^oa0@4?oMgMd01Oooool00ol0003oooooooooo`0;ooooo`05oa0@4?oooooooooooooooolb<S80
5?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo0:Sooooo001Mooooo`03ogMgMomVIVKooooo00Cooooo
00?o0000ooooooooool01?ooool00onYZJWoA4A4ooooo`05ooooo`06o`000?oooooooooooooooomV
IVKoMgMg1oooool00ol0003oooooooooo`0:ooooo`Go00004_ooool00omEEEGoIVIVo`000004oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h00_ooool4o`0000;ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`2Xooooo`00POooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0Z?ooool007kooooo00Co0000oooooooooooo0000=_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo0:Sooooo001oooooo`;o0000=_ooool2o`0000?o
oooo0_l0002Zooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -2.14748*^9, 0, \
2.14748*^9}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0 1.90278e-14 [
[.32684 -0.0125 -16.5 -12.5 ]
[.32684 -0.0125 16.5 0 ]
[.54329 -0.0125 -16.5 -12.5 ]
[.54329 -0.0125 16.5 0 ]
[.75974 -0.0125 -22.5 -12.5 ]
[.75974 -0.0125 22.5 0 ]
[.97619 -0.0125 -16.5 -12.5 ]
[.97619 -0.0125 16.5 0 ]
[1.025 0 0 -6 ]
[1.025 0 64 6 ]
[.09789 .09514 -33 -6.25 ]
[.09789 .09514 0 6.25 ]
[.09789 .19028 -33 -6.25 ]
[.09789 .19028 0 6.25 ]
[.09789 .28542 -45 -6.25 ]
[.09789 .28542 0 6.25 ]
[.09789 .38056 -33 -6.25 ]
[.09789 .38056 0 6.25 ]
[.09789 .47569 -45 -6.25 ]
[.09789 .47569 0 6.25 ]
[.09789 .57083 -33 -6.25 ]
[.09789 .57083 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -53.4375 0 ]
[.5 .63053 53.4375 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 0 m
.32684 .00625 L
s
gsave
.32684 -0.0125 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 0 m
.54329 .00625 L
s
gsave
.54329 -0.0125 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 0 m
.75974 .00625 L
s
gsave
.75974 -0.0125 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 0 m
.15368 .00375 L
s
.19697 0 m
.19697 .00375 L
s
.24026 0 m
.24026 .00375 L
s
.28355 0 m
.28355 .00375 L
s
.37013 0 m
.37013 .00375 L
s
.41342 0 m
.41342 .00375 L
s
.45671 0 m
.45671 .00375 L
s
.5 0 m
.5 .00375 L
s
.58658 0 m
.58658 .00375 L
s
.62987 0 m
.62987 .00375 L
s
.67316 0 m
.67316 .00375 L
s
.71645 0 m
.71645 .00375 L
s
.80303 0 m
.80303 .00375 L
s
.84632 0 m
.84632 .00375 L
s
.88961 0 m
.88961 .00375 L
s
.9329 0 m
.9329 .00375 L
s
.0671 0 m
.0671 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09514 m
.11664 .09514 L
s
gsave
.09789 .09514 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(12) show
grestore
.11039 .19028 m
.11664 .19028 L
s
gsave
.09789 .19028 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.11039 .28542 m
.11664 .28542 L
s
gsave
.09789 .28542 -45 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.11039 .38056 m
.11664 .38056 L
s
gsave
.09789 .38056 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.11039 .47569 m
.11664 .47569 L
s
gsave
.09789 .47569 -45 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.11039 .57083 m
.11664 .57083 L
s
gsave
.09789 .57083 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(3) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.125 Mabswid
.11039 .01903 m
.11414 .01903 L
s
.11039 .03806 m
.11414 .03806 L
s
.11039 .05708 m
.11414 .05708 L
s
.11039 .07611 m
.11414 .07611 L
s
.11039 .11417 m
.11414 .11417 L
s
.11039 .13319 m
.11414 .13319 L
s
.11039 .15222 m
.11414 .15222 L
s
.11039 .17125 m
.11414 .17125 L
s
.11039 .20931 m
.11414 .20931 L
s
.11039 .22833 m
.11414 .22833 L
s
.11039 .24736 m
.11414 .24736 L
s
.11039 .26639 m
.11414 .26639 L
s
.11039 .30444 m
.11414 .30444 L
s
.11039 .32347 m
.11414 .32347 L
s
.11039 .3425 m
.11414 .3425 L
s
.11039 .36153 m
.11414 .36153 L
s
.11039 .39958 m
.11414 .39958 L
s
.11039 .41861 m
.11414 .41861 L
s
.11039 .43764 m
.11414 .43764 L
s
.11039 .45667 m
.11414 .45667 L
s
.11039 .49472 m
.11414 .49472 L
s
.11039 .51375 m
.11414 .51375 L
s
.11039 .53278 m
.11414 .53278 L
s
.11039 .55181 m
.11414 .55181 L
s
.11039 .58986 m
.11414 .58986 L
s
.11039 .60889 m
.11414 .60889 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -114.438 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.812 moveto
(H) show
69.000 13.812 moveto
(\\310) show
75.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.812 moveto
(\\310) show
87.000 13.812 moveto
(L) show
93.000 9.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
98.250 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
104.250 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8.) show
116.250 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
122.250 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
134.250 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
138.438 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
147.875 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
165.875 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.02499 0 L
.02605 0 L
.02729 0 L
.02846 0 L
.02954 0 L
.03053 0 L
.03163 0 L
.03279 0 L
.03395 0 L
.0352 0 L
.03638 0 L
.03746 0 L
.03873 0 L
.04011 0 L
.04141 0 L
.04262 0 L
.04386 0 L
.04521 0 L
.04648 0 L
.04765 0 L
.04871 0 L
.04987 0 L
.05108 0 L
.05221 0 L
.05354 0 L
.0548 0 L
.05592 0 L
.05715 0 L
.05848 0 L
.0599 0 L
.06111 0 L
.06244 0 L
.06371 0 L
.0651 0 L
.06655 0 L
.0679 0 L
.06917 0 L
.07032 0 L
.07165 0 L
.0729 0 L
.07427 0 L
.07572 0 L
.07695 0 L
.07831 0 L
.07977 0 L
.08134 0 L
.08282 0 L
.08418 0 L
.08544 0 L
Mistroke
.08678 0 L
.08804 0 L
.08918 0 L
.09054 0 L
.092 0 L
.09338 0 L
.09464 0 L
.09584 0 L
.09695 0 L
.09817 0 L
.09948 0 L
.10085 0 L
.10215 0 L
.10331 0 L
.10458 0 L
.10692 0 L
.10824 0 L
.10944 0 L
.11167 0 L
.11278 0 L
.114 0 L
.11537 0 L
.11661 0 L
.11804 0 L
.11939 0 L
.12179 0 L
.12315 0 L
.12439 0 L
.12561 0 L
.12691 0 L
.12926 0 L
.1307 0 L
.13206 0 L
.13328 0 L
.13461 0 L
.1359 0 L
.13733 0 L
.13882 0 L
.14022 0 L
.14272 0 L
.14412 0 L
.14541 0 L
.14669 0 L
.14789 0 L
.15014 0 L
.15141 0 L
.15257 0 L
.15393 0 L
.1552 0 L
.15731 0 L
Mistroke
.15842 0 L
.15963 0 L
.16088 0 L
.16207 0 L
.16431 0 L
.16562 0 L
.1668 0 L
.16807 0 L
.16945 0 L
.17073 0 L
.1719 0 L
.17421 0 L
.17551 0 L
.17671 0 L
.17815 0 L
.17946 0 L
.18214 0 L
.18361 0 L
.18501 0 L
.18738 0 L
.1896 0 L
.19087 0 L
.19204 0 L
.1934 0 L
.19467 0 L
.19706 0 L
.19832 0 L
.19967 0 L
.20109 0 L
.20243 0 L
.20493 0 L
.20717 0 L
.20953 0 L
.21155 0 L
.21377 0 L
.21616 0 L
.21873 0 L
.22115 0 L
.22336 0 L
.22587 0 L
.22814 0 L
.23077 0 L
.23324 0 L
.23553 0 L
.23764 0 L
.23995 0 L
.24239 0 L
.24487 0 L
.24752 0 L
.25002 0 L
Mistroke
.25229 0 L
.25496 0 L
.25787 0 L
.26061 0 L
.26314 0 L
.26557 0 L
.26779 0 L
.27036 0 L
.2728 0 L
.27504 0 L
.27713 0 L
.27941 0 L
.28185 0 L
.28453 0 L
.28742 0 L
.29015 0 L
.29267 0 L
.29494 0 L
.29744 1e-05 L
.30004 1e-05 L
.30247 1e-05 L
.30507 1e-05 L
.30748 2e-05 L
.31012 2e-05 L
.31292 3e-05 L
.31762 4e-05 L
.3203 5e-05 L
.32282 7e-05 L
.32509 8e-05 L
.32747 .0001 L
.33174 .00015 L
.33413 .00018 L
.33634 .00022 L
.34137 .00033 L
.344 .00041 L
.34642 .00049 L
.34902 .0006 L
.35189 .00075 L
.35671 .00107 L
.36182 .00155 L
.36645 .00214 L
.37142 .00299 L
.37611 .00405 L
.3804 .00531 L
.38518 .0071 L
.39027 .00956 L
.39942 .01582 L
.40502 .02111 L
.4103 .02732 L
.42015 .04266 L
Mistroke
.42994 .06343 L
.44026 .09171 L
.45874 .15616 L
.47864 .23062 L
.48732 .25761 L
.4919 .26914 L
.49675 .27886 L
.49924 .28272 L
.50197 .28606 L
.50317 .28721 L
.50446 .28823 L
.50568 .28898 L
.50679 .2895 L
.50794 .28984 L
.50901 .29 L
.51018 .29 L
.51142 .28978 L
.51274 .28932 L
.51398 .28867 L
.51509 .2879 L
.51629 .28688 L
.51882 .28412 L
.52159 .28012 L
.52719 .26918 L
.53722 .24138 L
.55833 .16392 L
.5776 .09554 L
.58715 .06845 L
.59755 .04529 L
.60737 .02924 L
.61646 .01871 L
.62108 .01469 L
.62607 .01118 L
.63038 .00875 L
.63509 .00662 L
.64032 .0048 L
.64583 .00337 L
.65093 .0024 L
.65568 .00173 L
.66072 .00121 L
.66337 .001 L
.66618 .00081 L
.66864 .00067 L
.67134 .00054 L
.67611 .00037 L
.68073 .00026 L
.68333 .00021 L
.6857 .00017 L
.6879 .00014 L
.69031 .00011 L
Mistroke
.69468 8e-05 L
.69724 6e-05 L
.7 5e-05 L
.70243 4e-05 L
.70501 3e-05 L
.70733 2e-05 L
.70988 2e-05 L
.71436 1e-05 L
.7171 1e-05 L
.7196 1e-05 L
.72248 1e-05 L
.72521 0 L
.72773 0 L
.73006 0 L
.73262 0 L
.73534 0 L
.73772 0 L
.74023 0 L
.74237 0 L
.74471 0 L
.74724 0 L
.74995 0 L
.7525 0 L
.75481 0 L
.75716 0 L
.75933 0 L
.7617 0 L
.76422 0 L
.7664 0 L
.76845 0 L
.77069 0 L
.7731 0 L
.77564 0 L
.77836 0 L
.78091 0 L
.78323 0 L
.78597 0 L
.78751 0 L
.78892 0 L
.79153 0 L
.79284 0 L
.79428 0 L
.79691 0 L
.7993 0 L
.80063 0 L
.80207 0 L
.80468 0 L
.80713 0 L
.80972 0 L
.81194 0 L
Mistroke
.81438 0 L
.81567 0 L
.81686 0 L
.81828 0 L
.81957 0 L
.82196 0 L
.82327 0 L
.8245 0 L
.82682 0 L
.82895 0 L
.8313 0 L
.83248 0 L
.83377 0 L
.83517 0 L
.83649 0 L
.83898 0 L
.84037 0 L
.84165 0 L
.84315 0 L
.84456 0 L
.84688 0 L
.84812 0 L
.84945 0 L
.85077 0 L
.85216 0 L
.85464 0 L
.85587 0 L
.85721 0 L
.85839 0 L
.85964 0 L
.86076 0 L
.862 0 L
.86418 0 L
.8655 0 L
.86671 0 L
.86802 0 L
.86944 0 L
.87075 0 L
.87197 0 L
.87437 0 L
.87552 0 L
.87677 0 L
.87787 0 L
.87903 0 L
.88008 0 L
.88123 0 L
.88326 0 L
.88449 0 L
.88562 0 L
.88684 0 L
Mistroke
.88816 0 L
.88938 0 L
.8905 0 L
.89273 0 L
.89391 0 L
.89515 0 L
.89737 0 L
.89861 0 L
.89976 0 L
.9011 0 L
.90237 0 L
.90347 0 L
.90466 0 L
.90674 0 L
.90792 0 L
.90917 0 L
.91141 0 L
.91269 0 L
.91386 0 L
.91521 0 L
.91649 0 L
.91876 0 L
.92004 0 L
.92123 0 L
.92264 0 L
.92397 0 L
.92517 0 L
.92646 0 L
.92787 0 L
.92936 0 L
.93063 0 L
.93202 0 L
.93333 0 L
.93455 0 L
.93588 0 L
.93729 0 L
.93851 0 L
.93966 0 L
.94091 0 L
.94227 0 L
.94346 0 L
.94476 0 L
.94599 0 L
.94713 0 L
.94825 0 L
.94929 0 L
.9505 0 L
.95159 0 L
.9528 0 L
.95414 0 L
Mistroke
.95553 0 L
.95683 0 L
.95804 0 L
.95915 0 L
.96043 0 L
.96165 0 L
.96296 0 L
.96435 0 L
.96554 0 L
.96686 0 L
.96826 0 L
.96978 0 L
.97121 0 L
.97253 0 L
.97428 0 L
.97527 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00H_ooool2onk^kP?ooooo0_o^
k^h]ooooo`;ok^k^0oooool2onk^kSKooooo0_o^k^h3ooooo`;ok^k^9?ooool2onk^kP?ooooo0_o^
k^iSooooo`00G?ooool03Om4A4Co0000o`000?lb<S;ogMgMooooooo^k^koEEEEonk^k_ooooook^k^
oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hHooooo`Co
000000Wo410@ooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?oo
ooooooooonk^k_lb<S;o0000oc8b<_o^k^hAooooo`Co000000?o410@ooooooooool00_ooool2ob4Q
8@Gooooo00goA4A4o`000?l0003o<S8bomgMgOooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^
00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^3_ooool5o`0000;ooooo
00Ook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413oooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^E?ooool005oooooo00WoMgMgoc8b<_ooooooooooonk^k_mEEEGogMgMoeEE
EOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool0
0ol0003oooooooooo`02ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool00ol0003oooooooooo`04ooooo`;o8B4Q
2?ooool02OmgMgOo<S8booooooooooook^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
0oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg05Cooooo001Pooooo`07o`000?oooooooooooooooooMgMgo0000omgMg@07
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Jooooo`03o`000?oo
oooooooo00?ooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?oo
ooooooooooooool@41004oooool00ol0003oooooooooo`0?ooooo`07o`000?oooooooooooooooooM
gMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400?
ooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@4100E?ooool005oooooo00WoMgMgoc8b<_ooooooooooonk^
k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000006_ooool00ol0003oooooooooo`02ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000004oooool00ol0003ooooooooo
o`0>ooooo`09ogMgMolb<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo0000013ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000005Cooooo001Looooo`0=o`000?lQ8B7o0000oc8b<_o<c<coooooonk^k_mEEEGok^k^
ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Jooooo`0;o`000?ooooooooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Ooo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000004oooool00ol0003ooooo
ooooo`0;ooooo`0=o`000?lQ8B7o0000oc8b<_o<c<coooooonk^k_mEEEGok^k^ooooooo^k^koEEEE
onk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Aooooo`0;
ogMgMomVIVKoooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool00000E?ooool005cooooo00?o0000ooooooooool0
0oooool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@400Jooooo`04o`000?ooooooooooooooo`;ok^k^0oooool2onk^kPGooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@01?ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`03ooooo`;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@01;ooooo00?o0000ooooooooool00_o^k^h3ooooo`;ok^k^1Ooo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100E?ooool005cooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
6_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Cooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool01Ol0003o^[ZjoooooonHV9So
410@00kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg05Cooooo001L
ooooo`Co00003?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?oo
ool00ol0003oooooooooo`0=ooooo`03oeEEEOmVIVKo000000gooooo00?oEEEEofIVI_l000001?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo0_l00007ooooo`03oeEEEOmVIVKo000000gooooo
1?l0000<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`;o
00001?ooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo00?oEEEEofIVI_l000001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Sooooo0_l0001:ooooo`00P?ooool00ol0003oooooooooo`0`oooo
o`04o`000?ooooooooooo`0003Wooooo00Co0000oooooooooooo00009oooool01?l0003ooooooooo
ool00019ooooo`00N_ooool4o`0000?ooooo00?o0000ooooooooool0:_ooool4o`000005ooooool0
003oooooooooool00000=?ooool4o`000005ooooool0003oooooooooool000008_ooool4o`000005
ooooool0003oooooooooool00000BOooool0087ooooo00?o0000ooooooooool0;oooool3o`0003[o
oooo0ol0000Xooooo`?o0000B_ooool007oooooo00Co0000oooooooooooo0000<Oooool00ol0003o
ooooooooo`0jooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool03_ooool00omgMgOo
IVIVooooo`0^ooooo`03ofIVI_mgMgOooooo00Oooooo001oooooo`Co0000<_ooool00ol0003ooooo
ooooo`0jooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool03?ooool00ooMgMgo410@
onk^kP0_ooooo`03onk^k_l@413ogMgM00Oooooo003ooooooa_ooooo0_l00002ooooo`;o00003?oo
ool01?mEEEGoV9RHooooooooool2o`0000;ooooo00Oo0000oooooooooooo0000oa0@4?o^k^koEEEE
00;o000000?oA4A4okZj^_ooool00_ooool01OnHV9So0000o`000?m4A4Co^[Zj00;ooooo00Sok^k^
oeEEEOl0003o0000odA4A?nj^[[ooooooa0@40Go00000oooool02?l@413o<S8bo`000?l0003o410@
ojVYZOn7QhOoIVIV1oooool00?oooooo6oooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@cooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`08o`000?ooooooEEEEogMg
Moooooook^k^ogMgMol@4103ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000_ooool01_mEEEGoMgMg
ooooooo^k^koMgMgoa0@40?ooooo00?o0000ooooooooool01?ooool02?l0003oZJVYoooooooooooo
^[Zjo`000?o^k^ko00001oooool0023ooooolOl0000:ooooo`04omgMgOl0003o410@olc<c0gooooo
00?o<S8booooooooool00_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo000000So
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Go
oooo00Oo^[ZjohN7QomVIVKoIVIVoa0@4?oooooo000000Oooooo000Vooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool00_ooool8o`0000Sooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00So00002Oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0=oooo
o`04onk^k_lQ8B7o410@onk^kPgooooo00?o<S8booooooooool00_ooool01?l0003oooooooooool0
0002ooooo`03o`000?oooooo000000Go00000oooool00ol0003oooooooooo`04ooooo`Ko00000ooo
ool00ol0003oooooooooo`04ooooo`08oc8b<_lQ8B7oMgMgogMgMon7QhOok^k^ooooool00007oooo
o`00>oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00[ooooo0_l0000Uooooo`03
o`000?oooooooooo01;ooooo0ol0000Looooo`03o`000?oooooooooo037ooooo00?o0000oooooooo
ool03Oooool01?lQ8B7oMgMgogMgMolb<S8=ooooo`03o`000?o^k^kooooo00;ooooo00ko0000olc<
c?o<c<co0000ojVYZOoMgMgo8B4QoooooomEEEGoQhN7onk^k_ooooooQhN7oc8b<P?ooooo00?o0000
ooooooooool01?ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<P?ooooo00?o0000oc8b<_oMgMd0
1?ooool02?l0003o^[Zjooooooo^k^koMgMgo`000?o^k^ko00001oooool003_ooooo00?o0000oooo
ooooool0@?ooool2o`0003Kooooo0_l0001Rooooo`;o00000_ooool2o`0000cooooo00ooEEEEogMg
Mooooooooooooa0@4?l0003o8B4Qo`000?mgMgOo410@o`000?nYZJWoooooonk^k_mEEED00_l00000
1?m4A4Cok^k^ooooool@4105o`0000?ooooo00Kok^k^oeEEEOl0003o0000odA4A?o^k^h2ooooo`;o
000000CoZJVYob4Q8Ol0003o8B4Q0_ooool02?nYZJWo8B4Qo`000?l0003o<S8bo`000?mgMgOoEEEE
1oooool003_ooooo00?o0000ooooooooool0@_ooool2o`0003?ooooo00?o0000ooooooooool0M?oo
ool00ooMgMgo410@onk^kP0Cooooo`03o`000?oooooooooo01Wooooo00?ok^k^oa0@4?oMgMd01ooo
ool003_ooooo0_l00015ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0M_ooool0
0omgMgOoIVIVooooo`0Booooo`03o`000?oooooooooo01Wooooo00?oIVIVogMgMoooool01oooool0
03_ooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo
0;;ooooo000kooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0;?ooool00ol0003o
ooooooooo`2cooooo`00>oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo02cooooo
00?o0000ooooooooool0/oooool003_ooooo00?o0000ooooooooool0A_ooool00ol0003ooooooooo
o`0Zooooo`03o`000?oooooooooo0;Cooooo000kooooo`;o0000Aoooool00ol0003oooooooooo`0Z
ooooo`03o`000?oooooooooo0;Cooooo000kooooo`03o`000?oooooooooo04Oooooo00?o0000oooo
ooooool0:?ooool00ol0003oooooooooo`2eooooo`00>oooool00ol0003oooooooooo`17ooooo`03
o`000?oooooooooo02Sooooo00?o0000ooooooooool0]Oooool003_ooooo00?o0000ooooooooool0
B?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo0;Kooooo000kooooo`;o0000B_oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo0;Kooooo000kooooo`03o`000?oooooo
oooo04Wooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`2gooooo`00>oooool00ol0
003oooooooooo`1:ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0]oooool003_o
oooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo0;So
oooo000Gooooo`;ok^k^0oooool2onk^kQgooooo00?o0000ooooooooool0Boooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo0;Sooooo000Aooooo`0=odA4A?l0003o0000oc8b<_oMgMgo
ooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co000000So410@ooooooooooook^k^
oc8b<_l0003o<S8bonk^kPkooooo0_l0001<ooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool0^Oooool001Cooooo00WoMgMgoc8b<_ooooooooooonk^k_mEEEGogMgMoeEEEOo^k^h01_oo
ool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool00ol0003ooooo
ooooo`1;ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0^Oooool001Gooooo00Oo
0000ooooooooooooooooomgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@413o
oooooooooooooooo410@00kooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo0;Wooooo000Dooooo`09ogMgMolb<S;oooooooooooo^k^koEEEEomgMgOmE
EEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000kooooo
00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo0;[ooooo
000Aooooo`0=o`000?lQ8B7o0000oc8b<_o<c<coooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^
kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000>ooooo`;o0000
COooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo0;[ooooo000Aooooo`03o`000?oo
oooooooo00?ooooo0_o^k^h3ooooo`;ok^k^1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oo
ooooooooooooool@41003_ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool0^_ooool0017ooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool3o`000003ooooool0003o000000;o0000
0oooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
^_ooool0017ooooo1?l0000<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP04ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`1=ooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool0^oooool0037ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`2kooooo`00<Oooool00ol0003oooooooooo`03ooooo`04o`000?oo
ooooooooooooo`;o0000C_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo0;_ooooo
000aooooo`04o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`00001@ooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool0_?ooool0033ooooo0_l00003ooooo`;o0000
1?ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
_?ooool003_ooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo0;cooooo000kooooo`;o0000Coooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo0;gooooo000kooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`2mooooo`00>oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool0_Oooool003_ooooo00?o0000ooooooooool0Coooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo0;gooooo000kooooo`03o`000?oooooooooo04oooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`2nooooo`00>oooool2o`00057ooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`2nooooo`00>oooool00ol0003oooooooooo`1@oooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0__ooool003_ooooo00?o0000oooooooo
ool0D?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0;oooooo000kooooo`03o`00
0?oooooooooo053ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`2oooooo`005ooo
ool2onk^kP?ooooo0_o^k^hMooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`2oooooo`004Oooool4o`000009oa0@4?ooooook^k^oeEEEOo^k^kooooo
onk^k_mEEEGok^k^00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^3_oo
ool2o`0005;ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`2oooooo`004oooool0
0ol0003oooooooooo`02ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`1Aooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool0`?ooool001?ooooo00?o0000ooooooooool00ooo
ool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooo
oa0@400>ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`30ooooo`004oooool00ol0003oooooooooo`02ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h0
1_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003o
ooooooooo`1Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0`?ooool001?ooooo
00_o0000ooooooooooooooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000>ooooo`;o0000Doooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo0<7ooooo000Cooooo`04o`000?ooooooooooooooo`;ok^k^
0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00ko
oooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo0<7o
oooo000Cooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00?ooooo0ol00002ooooo`;o00001?ooool00ol0003oooooooooo`1Cooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool0`Oooool0017ooooo00?oEEEEofIVI_l00000
3Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool01?l0003o
ooooooooool00002ooooo`05o`000?ooooooooooooooool00000EOooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo0<7ooooo000aooooo`03o`000?oooooooooo00?ooooo00Go0000oooo
ooooooooooooo`00001Eooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0`_ooool0
037ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`;o0000E?ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo0<;ooooo000aooooo`04o`000?ooooooooooo`00
00;ooooo00Go0000ooooooooooooooooo`00001Fooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool0`_ooool0033ooooo0_l00003ooooo`;o00001?ooool00ol0003oooooooooo`1Doooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool0`_ooool003_ooooo00?o0000oooooooo
ool0E?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo0<?ooooo000kooooo`;o0000
E_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo0<?ooooo000kooooo`03o`000?oo
oooooooo05Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`33ooooo`00>oooool0
0ol0003oooooooooo`1Eooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0a?ooool0
03_ooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
0<Cooooo000kooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`34ooooo`00>oooool2o`0005Oooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`34ooooo`00>oooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool0aOooool003_ooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo0<Gooooo000kooooo`03o`000?oooooooooo05Oooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`35ooooo`006?ooool2onk^kP?ooooo0_o^k^hLooooo`;o
0000FOooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0<Kooooo0002ooooo`Co0000
00?o410@ooooooooool00_ooool2ob4Q8@Gooooo00goA4A4o`000?l0003o<S8bomgMgOooooook^k^
oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`00
0?lb<S;ok^k^3Oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0a_ooool000Cooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00WoMgMgoc8b
<_ooooooooooonk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL03Oooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0a_ooool000Cooooo00?o0000ooooooooool03oooool01ol0003ooooo
oooooooooooogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@41003Oooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0aoooool000Cooooo00?o0000ooooooooool03_ooool02OmgMgOo<S8boooooooooooo
k^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`37ooooo`001?ooool00ol0003oooooooooo`0;ooooo`0=o`000?lQ8B7o0000oc8b<_o<
c<coooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo
00Go0000ooooooooooooooooo`00000=ooooo`;o0000G?ooool00ol0003oooooooooo`02o`000<[o
oooo0004ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00oooool2onk^kP?ooooo
0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03
o`000?oooooooooo05_ooooo1?l0003;ooooo`001?ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo0ol00002ooooo`;o00000oooool00ol0003oooooooooo`3oooooob_ooooo0002ooooo`03oeEE
EOmVIVKo000000gooooo1?l0000<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP04ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000ooooool]
ooooo`00<_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`000?oooooo;Oooool0
03;ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooooooool2o`000?oooooo;?ooool0
03;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0003oooooobgooooo000a
ooooo`;o00000oooool2o`0000?ooooo00?o0000ooooooooool0ooooool[ooooo`00>oooool00ol0
003oooooooooo`3oooooob_ooooo000kooooo`;o0000ooooool/ooooo`00>oooool00ol0003ooooo
ooooo`3oooooob_ooooo000kooooo`03o`000?oooooooooo0?oooooo:oooool003_ooooo00?o0000
ooooooooool0ooooool[ooooo`00>oooool00ol0003oooooooooo`3oooooob_ooooo000kooooo`;o
0000ooooool/ooooo`00>oooool00ol0003oooooooooo`3oooooob_ooooo000kooooo`03o`000?oo
oooooooo0?oooooo:oooool001Oooooo0_o^k^h3ooooo`;ok^k^7Oooool00ol0003oooooooooo`3o
ooooob_ooooo000@ooooo`Go00000_ooool01oo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00ooo
ool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h>ooooo`;o0000ooooool/oooo
o`004?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06
ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oo
oooooooo0?oooooo:oooool0017ooooo00?oV9RHob4Q8Oo^k^h01Oooool00ooMgMgo0000omgMg@07
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oo
oooooooo0?oooooo:oooool001;ooooo00?oV9RHob4Q8Oo^k^h00oooool01Oo^k^koEEEEomgMgOmE
EEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000kooooo
00?o0000ooooooooool0ooooool[ooooo`004oooool02omgMgOoIVIVooooooooooook^k^oeEEEOo^
k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000000kooooo00?o0000ooooooooool0ooooool[ooooo`005?ooool00ol0003oooooooooo`02
onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
400>ooooo`;o0000ooooool/ooooo`004?ooool01Ol0003o^[ZjoooooonHV9So410@00kooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00?o0000ooooooooool0
ooooool[ooooo`004?ooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo00?oEEEEofIVI_l00000
1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo0ol00002ooooo`;o00001?ooool00ol0003o
ooooooooo`3oooooob_ooooo000aooooo`04o`000?ooooooooooo`0000;ooooo00Go0000oooooooo
ooooooooo`00003oooooobgooooo000aooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooo
oooooooo0_l0003oooooobcooooo000aooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`3oooooob_ooooo000aooooo`04o`000?ooooooooooo`0000;o
oooo00Go0000ooooooooooooooooo`00003oooooobgooooo000`ooooo`;o00000oooool2o`0000Co
oooo00?o0000ooooooooool0ooooool[ooooo`00>oooool00ol0003oooooooooo`3oooooob_ooooo
000kooooo`;o0000ooooool/ooooo`00>oooool00ol0003oooooooooo`3oooooob_ooooo000koooo
o`03o`000?oooooooooo0?oooooo:oooool003_ooooo00?o0000ooooooooool0ooooool[ooooo`00
>oooool00ol0003oooooooooo`3oooooob_ooooo000kooooo`;o0000ooooool/ooooo`00>oooool0
0ol0003oooooooooo`3oooooob_ooooo000kooooo`03o`000?oooooooooo0?oooooo:oooool001So
oooo0_o^k^h3ooooo`;ok^k^7?ooool00ol0003oooooooooo`3oooooob_ooooo00000ooooooo0000
o`000003o`0000Gooooo0_lQ8B45ooooo`0=odA4A?l0003o0000oc8b<_oMgMgoooooonk^k_mEEEGo
k^k^ooooooo^k^koEEEEonk^kP03ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8b
onk^kPgooooo0_l0003oooooobcooooo00001_ooooooV9RHob4Q8Oo^k^koooooodA4A0Gooooo0_lQ
8B48ooooo`09ogMgMolb<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000oooo
ooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00gooooo00?o0000ooooooooool0ooooool[
ooooo`000_ooool00onHV9So8B4Qonk^kP0Aooooo`07o`000?oooooooooooooooooMgMgo0000omgM
g@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03o`00
0?oooooooooo0?oooooo:oooool000?ooooo00?oV9RHob4Q8Oo^k^h03oooool02OmgMgOo<S8boooo
ooooooook^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`00000=ooooo`03o`000?oooooooooo0?oooooo:oooool000Cooooo00?oMgMgofIV
I_ooool02oooool03Ol0003o8B4Qo`000?lb<S;oc<c<ooooooo^k^koEEEEonk^k_ooooook^k^oeEE
EOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000003Oooool0
0ol0003oooooooooo`3oooooob_ooooo0005ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool00oooool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooo
oooooooooooooa0@400=ooooo`;o0000ooooool/ooooo`0000Koooooo`000?nj^[[ooooooiRHV?l@
410<ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00gooooo00?o0000ooooooooool0ooooool[ooooo`0000KooooooiRHV?l@413o0000
ob4Q8Oo<c<`<ooooo`Co00003?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool3o`0000;ooooo0_l00003ooooo`03o`000?oooooooooo0?oooooo:oooool003;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0003oooooobgooooo000boooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_l0003oooooobcooooo000booooo`03
o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00003oooooobgooooo000booooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000ooooool]ooooo`00<Oooool2o`00
00?ooooo0_l00003ooooo`03o`000?oooooooooo0?oooooo:oooool003_ooooo00?o0000oooooooo
ool0ooooool[ooooo`00>oooool2o`000?oooooo;?ooool003_ooooo00?o0000ooooooooool0oooo
ool[ooooo`00>oooool00ol0003oooooooooo`3oooooob_ooooo000kooooo`03o`000?oooooooooo
0?oooooo:oooool003_ooooo0_l0003oooooobcooooo000kooooo`03o`000?oooooooooo0?oooooo
:oooool003_ooooo00?o0000ooooooooool0ooooool[ooooo`00>oooool00ol0003oooooooooo`3o
ooooob_ooooo000Gooooo`;ok^k^0oooool2onk^kQgooooo00?o0000ooooooooool0ooooool[oooo
o`004?ooool01OnHV9So410@o`000?lb<S;oc<c<00;ooooo00Ook^k^oeEEEOo^k^koooooonk^k_mE
EEGok^k^00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^3_ooool2o`00
0?oooooo;?ooool0013ooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05onk^k_mEEEGogMgM
oeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_oo
ool00ol0003oooooooooo`3oooooob_ooooo000Dooooo`03o`000?oooooooooo00;ooooo00?ogMgM
o`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41003_oo
ool00ol0003oooooooooo`3oooooob_ooooo000Cooooo`03ojVYZOl@413ooooo00;ooooo00Gok^k^
oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03o`000?oooooooooo0?oooooo:oooool001;ooooo00?o410@o`000?nj^[X00_oo
ool01oo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000003_ooool00ol0003oooooooooo`3oooooob_ooooo000Cooooo`04
okZj^_lQ8B7oooooooooo`;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@
413ooooooooooooooooo410@00kooooo0_l0003oooooobcooooo000@ooooo`05oa0@4?nHV9Sooooo
okZj^_l000003_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_oo
ool00ol0003oooooooooo`3oooooob_ooooo000@ooooo`05ojVYZOl@413o0000oa0@4?nYZJT03?oo
ool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool3o`0000;ooooo
0_l00004ooooo`03o`000?oooooooooo0?oooooo:oooool0037ooooo00Co0000oooooooooooo0000
0_ooool01Ol0003ooooooooooooooooo00000?oooooo;Oooool0037ooooo00?o0000ooooooooool0
0oooool01?l0003oooooooooooooool2o`000?oooooo;?ooool0037ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo:oooool0037ooooo00Co
0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo00000?oooooo;Oooool0033ooooo
0_l00003ooooo`;o00001?ooool00ol0003oooooooooo`3oooooob_ooooo000kooooo`03o`000?oo
oooooooo0?oooooo:oooool003_ooooo0_l0003oooooobcooooo000kooooo`03o`000?oooooooooo
0?oooooo:oooool003_ooooo00?o0000ooooooooool0ooooool[ooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00GOooool00omgMgOoIVIV
ooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o^[Zjoc8b<_ooool01oooool01_l0003ooooo
ooooooooooooIVIVogMgM`gooooo00?o0000okZj^_ooool0goooool005cooooo00?ogMgMoa0@4?o^
k^h01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00Oo0000oooooooo
ooooooooonk^k_l@413ogMgM00cooooo0_lb<S;Pooooo`00G?ooool00omEEEGoV9RHooooo`05oooo
o`06o`000?oooooooooooooooonHV9So410@0_l000000onYZJWoooooooooo`04ooooo`03o`000?oo
oooooooo00;ooooo00?oQhN7ofIVI_ooool02oooool00on7QhOo0000okZj^P04ooooo`05olc<c?lQ
8B7o0000ob4Q8Oo<c<`01Oooool2ob4Q8@?ooooo00Goc<c<onk^k_ooooook^k^olc<c003ooooo`Co
000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kQ?ooooo00Ko410@oc8b<_l0003o0000
oa0@4?nYZJT2ooooo`06onk^k_mEEEGo0000o`000?m4A4Co^[Zj0oooool01OmVIVKo0000o`000?m4
A4Coc<c<08oooooo001Looooo`03o`000?oooooooooo00Gooooo00[o0000ooooooooooooooooo`00
0?nYZJWoEEEEoiRHV?mEEEGo^[Zj1Oooool00ol0003oooooooooo`02ooooo`03onk^k_l0003ooooo
00_ooooo00?oc<c<o`000?l@41001?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Gooooo0_lQ8B43
ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL04oooool01_l0003oZJVYoooooooooooo^[Zjo`0000;ooooo00KoEEEEogMg
Moooooook^k^ogMgMol@4102ooooo`06ofIVI_mgMgOooooooooooon7QhOo410@Soooool005cooooo
00?o<S8booooooooool01Oooool02_l0003ooooooooooooooooo<S8bonk^k_nHV9SoEEEEomgMgOl@
4105ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04Oooool01Ol0003ooooooooo
oooooooo000000_ooooo00?ogMgMo`000?oMgMd01_ooool00ol0003oooooooooo`02ooooo`05oa0@
4?ooooooooooooooool@41005?ooool01Onj^[[oQhN7ofIVI_mVIVKo410@00;ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`2Booooo`00G?ooool00olb<S;oooooooooo`05ooooo`0;
o`000?oooooooooooooooonj^[[oA4A4olc<c?lQ8B7ooooooa0@4?o<c<`01?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo017ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0:ooooo`05
onk^k_mEEEGogMgMoeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool000004oooool01_lb<S;o8B4QogMgMomgMgOoQhN7onk^kP;ooooo1_l00002ooooo`03o`00
0?oooooooooo09;ooooo001Looooo`03o`000?o^k^kooooo00Gooooo00_o0000oooooooooooooooo
onk^k_l0003oooooo`000?ooooooIVIVohN7Q`04ooooo`03o`000?oooooooooo00;ooooo00?ok^k^
o`000?ooool04_ooool01Oo<c<co0000o`000?l0003oc<c<00[ooooo00Goc<c<onk^k_ooooook^k^
olc<c005ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Cooooo`06
o`000?nj^[[oooooonk^k_mgMgOo00000_ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<P;ooooo
00KoIVIVogMgMoooooooooooohN7Qol0002?ooooo`00G?ooool00omEEEGoMgMgooooo`05ooooo`08
o`000?oooooooooooooooomVIVKoV9RHoooooolb<S82okZj^P03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00_ooool00omgMgOoEEEEooooo`03ooooo`Co00002oooool01Ol@413o^[Zjoooo
oonj^[[o410@01Cooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Oo
oooo0ol00002ooooo`?o00001?ooool01_nYZJWo8B4Qo`000?l0003o<S8bo`0000;ooooo00Kok^k^
oeEEEOl0003o0000odA4A?o^k^h2ooooo`06onk^k_mVIVKo0000o`000?m4A4Co0000Soooool005co
oooo00?ogMgMoa0@4?o^k^h01Oooool00ol0003oooooooooo`04ooooo`03ofIVI_n7QhOooooo00Go
oooo00Oo0000ooooooooooooooooonk^k_l@413ogMgM00Gooooo00?o0000ooooooooool02oooool0
1Ol0003o^[Zjoooooonj^[[o000001Cooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2Xooooo`00GOoo
ool00omgMgOoIVIVooooo`04ooooo`03o`000?oooooooooo00Cooooo00?oZJVYodA4A?ooool01Ooo
ool01_l0003oooooooooooooooooIVIVogMgM`Oooooo00?o0000ooooooooool02_ooool01OnYZJWo
410@o`000?l@413oZJVY01;ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00;ooooo1?l00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Z?ooool0
087ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
0:Sooooo001nooooo`04o`000?ooooooooooo`0003Kooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`2Xooooo`00Ooooool2o`0003Kooooo0_l00003ooooo`;o0000Z_ooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -2.14748*^9, 0, \
2.14748*^9}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0 1.90278e-14 [
[.32684 -0.0125 -16.5 -12.5 ]
[.32684 -0.0125 16.5 0 ]
[.54329 -0.0125 -16.5 -12.5 ]
[.54329 -0.0125 16.5 0 ]
[.75974 -0.0125 -22.5 -12.5 ]
[.75974 -0.0125 22.5 0 ]
[.97619 -0.0125 -16.5 -12.5 ]
[.97619 -0.0125 16.5 0 ]
[1.025 0 0 -6 ]
[1.025 0 64 6 ]
[.09789 .09514 -33 -6.25 ]
[.09789 .09514 0 6.25 ]
[.09789 .19028 -33 -6.25 ]
[.09789 .19028 0 6.25 ]
[.09789 .28542 -45 -6.25 ]
[.09789 .28542 0 6.25 ]
[.09789 .38056 -33 -6.25 ]
[.09789 .38056 0 6.25 ]
[.09789 .47569 -45 -6.25 ]
[.09789 .47569 0 6.25 ]
[.09789 .57083 -33 -6.25 ]
[.09789 .57083 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -53.4375 0 ]
[.5 .63053 53.4375 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 0 m
.32684 .00625 L
s
gsave
.32684 -0.0125 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 0 m
.54329 .00625 L
s
gsave
.54329 -0.0125 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 0 m
.75974 .00625 L
s
gsave
.75974 -0.0125 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 0 m
.15368 .00375 L
s
.19697 0 m
.19697 .00375 L
s
.24026 0 m
.24026 .00375 L
s
.28355 0 m
.28355 .00375 L
s
.37013 0 m
.37013 .00375 L
s
.41342 0 m
.41342 .00375 L
s
.45671 0 m
.45671 .00375 L
s
.5 0 m
.5 .00375 L
s
.58658 0 m
.58658 .00375 L
s
.62987 0 m
.62987 .00375 L
s
.67316 0 m
.67316 .00375 L
s
.71645 0 m
.71645 .00375 L
s
.80303 0 m
.80303 .00375 L
s
.84632 0 m
.84632 .00375 L
s
.88961 0 m
.88961 .00375 L
s
.9329 0 m
.9329 .00375 L
s
.0671 0 m
.0671 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09514 m
.11664 .09514 L
s
gsave
.09789 .09514 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(12) show
grestore
.11039 .19028 m
.11664 .19028 L
s
gsave
.09789 .19028 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.11039 .28542 m
.11664 .28542 L
s
gsave
.09789 .28542 -45 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.11039 .38056 m
.11664 .38056 L
s
gsave
.09789 .38056 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.11039 .47569 m
.11664 .47569 L
s
gsave
.09789 .47569 -45 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.11039 .57083 m
.11664 .57083 L
s
gsave
.09789 .57083 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(3) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.125 Mabswid
.11039 .01903 m
.11414 .01903 L
s
.11039 .03806 m
.11414 .03806 L
s
.11039 .05708 m
.11414 .05708 L
s
.11039 .07611 m
.11414 .07611 L
s
.11039 .11417 m
.11414 .11417 L
s
.11039 .13319 m
.11414 .13319 L
s
.11039 .15222 m
.11414 .15222 L
s
.11039 .17125 m
.11414 .17125 L
s
.11039 .20931 m
.11414 .20931 L
s
.11039 .22833 m
.11414 .22833 L
s
.11039 .24736 m
.11414 .24736 L
s
.11039 .26639 m
.11414 .26639 L
s
.11039 .30444 m
.11414 .30444 L
s
.11039 .32347 m
.11414 .32347 L
s
.11039 .3425 m
.11414 .3425 L
s
.11039 .36153 m
.11414 .36153 L
s
.11039 .39958 m
.11414 .39958 L
s
.11039 .41861 m
.11414 .41861 L
s
.11039 .43764 m
.11414 .43764 L
s
.11039 .45667 m
.11414 .45667 L
s
.11039 .49472 m
.11414 .49472 L
s
.11039 .51375 m
.11414 .51375 L
s
.11039 .53278 m
.11414 .53278 L
s
.11039 .55181 m
.11414 .55181 L
s
.11039 .58986 m
.11414 .58986 L
s
.11039 .60889 m
.11414 .60889 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -114.438 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.812 moveto
(H) show
69.000 13.812 moveto
(\\310) show
75.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.812 moveto
(\\310) show
87.000 13.812 moveto
(L) show
93.000 9.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
98.250 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
104.250 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(9.) show
116.250 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
122.250 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
134.250 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
138.438 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
147.875 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
165.875 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.02499 0 L
.02605 0 L
.02729 0 L
.02846 0 L
.03053 0 L
.0317 0 L
.03279 0 L
.03396 0 L
.03506 0 L
.03626 0 L
.03756 0 L
.03891 0 L
.0402 0 L
.04136 0 L
.04262 0 L
.04396 0 L
.04523 0 L
.04636 0 L
.04759 0 L
.04894 0 L
.05036 0 L
.05157 0 L
.0529 0 L
.05415 0 L
.05528 0 L
.05659 0 L
.05784 0 L
.06004 0 L
.06129 0 L
.06244 0 L
.0637 0 L
.06486 0 L
.06612 0 L
.06745 0 L
.0697 0 L
.07097 0 L
.07216 0 L
.07355 0 L
.07487 0 L
.07606 0 L
.07734 0 L
.07874 0 L
.08022 0 L
.08148 0 L
.08288 0 L
.08432 0 L
.0857 0 L
.08693 0 L
.08828 0 L
Mistroke
.08974 0 L
.09129 0 L
.09276 0 L
.09409 0 L
.09544 0 L
.09669 0 L
.09805 0 L
.09949 0 L
.10075 0 L
.10192 0 L
.10321 0 L
.10458 0 L
.10582 0 L
.10719 0 L
.1096 0 L
.11096 0 L
.11242 0 L
.1138 0 L
.11506 0 L
.11737 0 L
.11868 0 L
.11989 0 L
.12235 0 L
.12372 0 L
.12497 0 L
.12613 0 L
.12736 0 L
.12956 0 L
.13079 0 L
.13193 0 L
.13326 0 L
.13453 0 L
.13562 0 L
.1368 0 L
.13888 0 L
.14005 0 L
.1413 0 L
.14354 0 L
.14467 0 L
.14592 0 L
.14713 0 L
.14842 0 L
.14963 0 L
.15074 0 L
.15289 0 L
.15419 0 L
.15538 0 L
.15667 0 L
.15808 0 L
.16046 0 L
Mistroke
.16177 0 L
.16299 0 L
.16412 0 L
.16535 0 L
.16759 0 L
.16977 0 L
.17179 0 L
.1742 0 L
.17638 0 L
.17758 0 L
.17889 0 L
.18126 0 L
.18363 0 L
.18497 0 L
.18618 0 L
.18854 0 L
.19077 0 L
.19203 0 L
.19337 0 L
.19577 0 L
.19711 0 L
.19836 0 L
.19972 0 L
.20121 0 L
.20379 0 L
.2052 0 L
.2065 0 L
.20885 0 L
.21135 0 L
.21277 0 L
.2143 0 L
.21565 0 L
.21708 0 L
.21979 0 L
.22228 0 L
.22482 0 L
.22722 0 L
.22938 0 L
.23173 0 L
.23428 0 L
.23699 0 L
.23955 0 L
.24187 0 L
.24424 0 L
.24641 0 L
.2488 0 L
.25131 0 L
.2535 0 L
.25555 0 L
.25779 0 L
Mistroke
.26019 0 L
.26277 0 L
.2655 0 L
.26783 0 L
.2704 0 L
.27316 0 L
.27612 0 L
.27892 0 L
.28149 0 L
.28404 0 L
.28642 0 L
.28903 0 L
.29181 0 L
.29446 0 L
.29695 0 L
.2992 0 L
.30162 0 L
.30399 0 L
.30653 0 L
.31112 0 L
.31392 0 L
.31658 0 L
.31896 0 L
.32155 0 L
.32407 0 L
.32685 1e-05 L
.32976 1e-05 L
.33249 1e-05 L
.33736 1e-05 L
.3401 2e-05 L
.34261 2e-05 L
.34735 3e-05 L
.35 4e-05 L
.35241 5e-05 L
.3571 8e-05 L
.36153 .00011 L
.36404 .00013 L
.36669 .00016 L
.37146 .00024 L
.37658 .00034 L
.3795 .00042 L
.38223 .00051 L
.3872 .00073 L
.39263 .00105 L
.39775 .00146 L
.4025 .00198 L
.40721 .00264 L
.41148 .00341 L
.4164 .00453 L
.42104 .00587 L
Mistroke
.43082 .00987 L
.43575 .01263 L
.44115 .01637 L
.45071 .0252 L
.45963 .03647 L
.4701 .05405 L
.48001 .07536 L
.49858 .12644 L
.51682 .184 L
.52721 .21472 L
.53695 .23871 L
.54159 .24777 L
.54648 .2553 L
.54904 .25836 L
.55184 .26096 L
.55307 .26185 L
.55438 .26263 L
.55562 .26321 L
.55675 .26359 L
.55806 .26387 L
.55873 .26394 L
.55945 .26397 L
.56074 .26388 L
.56194 .26365 L
.56267 .26343 L
.56336 .26317 L
.56465 .26255 L
.56605 .2617 L
.56757 .26054 L
.57013 .25805 L
.57286 .2547 L
.57777 .24694 L
.58712 .22673 L
.5972 .19886 L
.61547 .14149 L
.63509 .0847 L
.64547 .06069 L
.65657 .04052 L
.6673 .02618 L
.67706 .01691 L
.68177 .01351 L
.68687 .01049 L
.69615 .00645 L
.70102 .00492 L
.70559 .00379 L
.7106 .00282 L
.71599 .00203 L
.72162 .00142 L
.72698 .001 L
.73178 .00072 L
Mistroke
.73702 .0005 L
.74234 .00034 L
.74734 .00024 L
.75184 .00017 L
.7567 .00012 L
.75923 .0001 L
.76201 8e-05 L
.76472 6e-05 L
.76763 5e-05 L
.77035 4e-05 L
.77282 3e-05 L
.77513 3e-05 L
.77768 2e-05 L
.78248 1e-05 L
.78512 1e-05 L
.78759 1e-05 L
.79201 1e-05 L
.79449 0 L
.79677 0 L
.7991 0 L
.8016 0 L
.80433 0 L
.80688 0 L
.80975 0 L
.81246 0 L
.81489 0 L
.81753 0 L
.81989 0 L
.82242 0 L
.82481 0 L
.827 0 L
.82955 0 L
.83234 0 L
.83497 0 L
.83741 0 L
.84017 0 L
.84276 0 L
.84509 0 L
.8476 0 L
.85036 0 L
.85326 0 L
.85574 0 L
.85845 0 L
.86098 0 L
.86372 0 L
.8663 0 L
.86869 0 L
.87084 0 L
.87321 0 L
.87569 0 L
Mistroke
.87801 0 L
.88071 0 L
.88327 0 L
.88557 0 L
.88809 0 L
.89081 0 L
.89233 0 L
.89371 0 L
.8964 0 L
.89894 0 L
.90134 0 L
.90359 0 L
.90605 0 L
.90869 0 L
.91002 0 L
.91146 0 L
.91273 0 L
.91408 0 L
.91663 0 L
.919 0 L
.92117 0 L
.92352 0 L
.92574 0 L
.92777 0 L
.93003 0 L
.93249 0 L
.93374 0 L
.93507 0 L
.93747 0 L
.93861 0 L
.93988 0 L
.94111 0 L
.94243 0 L
.9448 0 L
.94702 0 L
.94835 0 L
.94979 0 L
.95107 0 L
.95243 0 L
.95378 0 L
.955 0 L
.95738 0 L
.95856 0 L
.9598 0 L
.96204 0 L
.96328 0 L
.96444 0 L
.96579 0 L
.96707 0 L
.96817 0 L
Mistroke
.96937 0 L
.97147 0 L
.97266 0 L
.97392 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00H_ooool2onk^kP?ooooo0_o^
k^h]ooooo`;ok^k^0oooool2onk^kSKooooo0_o^k^h3ooooo`;ok^k^9?ooool2onk^kP?ooooo0_o^
k^iSooooo`00G?ooool03Om4A4Co0000o`000?lb<S;ogMgMooooooo^k^koEEEEonk^k_ooooook^k^
oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hHooooo`Co
000000Wo410@ooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?oo
ooooooooonk^k_lb<S;o0000oc8b<_o^k^hAooooo`Co000000?o410@ooooooooool00_ooool2ob4Q
8@Gooooo00goA4A4o`000?l0003o<S8bomgMgOooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^
00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^3_ooool5o`0000;ooooo
00Ook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413oooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^E?ooool005oooooo00WoMgMgoc8b<_ooooooooooonk^k_mEEEGogMgMoeEE
EOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool0
0ol0003oooooooooo`02ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool00ol0003oooooooooo`04ooooo`;o8B4Q
2?ooool02OmgMgOo<S8booooooooooook^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
0oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg05Cooooo001Pooooo`07o`000?oooooooooooooooooMgMgo0000omgMg@07
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Jooooo`03o`000?oo
oooooooo00?ooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?oo
ooooooooooooool@41004oooool00ol0003oooooooooo`0?ooooo`07o`000?oooooooooooooooooM
gMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400?
ooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@4100E?ooool005oooooo00WoMgMgoc8b<_ooooooooooonk^
k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000006_ooool00ol0003oooooooooo`02ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000004oooool00ol0003ooooooooo
o`0>ooooo`09ogMgMolb<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo0000013ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000005Cooooo001Looooo`0=o`000?lQ8B7o0000oc8b<_o<c<coooooonk^k_mEEEGok^k^
ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Jooooo`0;o`000?ooooooooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Ooo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000004oooool00ol0003ooooo
ooooo`0;ooooo`0=o`000?lQ8B7o0000oc8b<_o<c<coooooonk^k_mEEEGok^k^ooooooo^k^koEEEE
onk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Aooooo`0;
ogMgMomVIVKoooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool00000E?ooool005cooooo00?o0000ooooooooool0
0oooool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@400Jooooo`04o`000?ooooooooooooooo`;ok^k^0oooool2onk^kPGooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@01?ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`03ooooo`;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@01;ooooo00?o0000ooooooooool00_o^k^h3ooooo`;ok^k^1Ooo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100E?ooool005cooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
6_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Cooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool01Ol0003o^[ZjoooooonHV9So
410@00kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg05Cooooo001L
ooooo`Co00003?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?oo
ool00ol0003oooooooooo`0=ooooo`03oeEEEOmVIVKo000000gooooo00?oEEEEofIVI_l000001?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo0_l00007ooooo`03oeEEEOmVIVKo000000gooooo
1?l0000<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`;o
00001?ooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo00?oEEEEofIVI_l000001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Sooooo0_l0001:ooooo`00P?ooool00ol0003oooooooooo`0`oooo
o`04o`000?ooooooooooo`0003Wooooo00Co0000oooooooooooo00009oooool01?l0003ooooooooo
ool00019ooooo`00N_ooool4o`0000?ooooo00?o0000ooooooooool0:_ooool4o`000005ooooool0
003oooooooooool00000=?ooool4o`000005ooooool0003oooooooooool000008_ooool4o`000005
ooooool0003oooooooooool00000BOooool0087ooooo00?o0000ooooooooool0;oooool3o`0003[o
oooo0ol0000Xooooo`?o0000B_ooool007oooooo00Co0000oooooooooooo0000<Oooool00ol0003o
ooooooooo`0jooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool03_ooool00omgMgOo
IVIVooooo`0^ooooo`03ofIVI_mgMgOooooo00Oooooo001oooooo`Co0000<_ooool00ol0003ooooo
ooooo`0jooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool03?ooool00ooMgMgo410@
onk^kP0_ooooo`03onk^k_l@413ogMgM00Oooooo003ooooooa_ooooo0_l00002ooooo`;o00003?oo
ool01?mEEEGoV9RHooooooooool2o`0000;ooooo00Oo0000oooooooooooo0000oa0@4?o^k^koEEEE
00;o000000?oA4A4okZj^_ooool00_ooool01OnHV9So0000o`000?m4A4Co^[Zj00;ooooo00Sok^k^
oeEEEOl0003o0000odA4A?nj^[[ooooooa0@40Go00000oooool02?l@413o<S8bo`000?l0003o410@
ojVYZOn7QhOoIVIV1oooool00?oooooo6oooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@cooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`08o`000?ooooooEEEEogMg
Moooooook^k^ogMgMol@4103ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000_ooool01_mEEEGoMgMg
ooooooo^k^koMgMgoa0@40?ooooo00?o0000ooooooooool01?ooool02?l0003oZJVYoooooooooooo
^[Zjo`000?o^k^ko00001oooool0023ooooolOl0000:ooooo`04omgMgOl0003o410@olc<c0gooooo
00?o<S8booooooooool00_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo000000So
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Go
oooo00Oo^[ZjohN7QomVIVKoIVIVoa0@4?oooooo000000Oooooo000Vooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool01oooool01?l0003oooooooooooooool8o`0000Wooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo1ol00006
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0=
ooooo`04onk^k_lQ8B7o410@onk^kPgooooo00?o<S8booooooooool00_ooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooo000000Go00000oooool00ol0003oooooooooo`04ooooo`Ko0000
0oooool00ol0003oooooooooo`04ooooo`08oc8b<_lQ8B7oMgMgogMgMon7QhOok^k^ooooool00007
ooooo`00>oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo01?ooooo0ol0000Koooo
o`03o`000?oooooooooo023ooooo1?l0000=ooooo`03o`000?oooooooooo037ooooo00?o0000oooo
ooooool03Oooool01?lQ8B7oMgMgogMgMolb<S8=ooooo`03o`000?o^k^kooooo00;ooooo00ko0000
olc<c?o<c<co0000ojVYZOoMgMgo8B4QoooooomEEEGoQhN7onk^k_ooooooQhN7oc8b<P?ooooo00?o
0000ooooooooool01?ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<P?ooooo00?o0000oc8b<_oM
gMd01?ooool02?l0003o^[Zjooooooo^k^koMgMgo`000?o^k^ko00001oooool003_ooooo00?o0000
ooooooooool0B_ooool2o`0003_ooooo00?o0000ooooooooool0D_ooool2o`0000;ooooo0_l0000<
ooooo`0?oeEEEOmgMgOoooooooooool@413o0000ob4Q8Ol0003oMgMgoa0@4?l0003oZJVYooooooo^
k^koEEEE00;o000000CoA4A4onk^k_oooooo410@1Ol00003ooooo`06onk^k_mEEEGo0000o`000?m4
A4Cok^k^0_ooool2o`000004ojVYZOlQ8B7o0000ob4Q8@;ooooo00SoZJVYob4Q8Ol0003o0000oc8b
<_l0003oMgMgoeEEE@Oooooo000kooooo`03o`000?oooooooooo04cooooo0_l0000gooooo`;o0000
Ioooool00ooMgMgo410@onk^kP0Cooooo`03o`000?oooooooooo01Wooooo00?ok^k^oa0@4?oMgMd0
1oooool003_ooooo0_l0001?ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0Iooo
ool00omgMgOoIVIVooooo`0Booooo`03o`000?oooooooooo01Wooooo00?oIVIVogMgMoooool01ooo
ool003_ooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0booooo`03o`000?oooooo
oooo0:?ooooo000kooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`2Tooooo`00>oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo02oo
oooo00?o0000ooooooooool0YOooool003_ooooo00?o0000ooooooooool0DOooool00ol0003ooooo
ooooo`0]ooooo`03o`000?oooooooooo0:Kooooo000kooooo`;o0000D_ooool00ol0003ooooooooo
o`0/ooooo`03o`000?oooooooooo0:Oooooo000kooooo`03o`000?oooooooooo05;ooooo00?o0000
ooooooooool0:oooool00ol0003oooooooooo`2Wooooo`00>oooool00ol0003oooooooooo`1Boooo
o`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0Z?ooool003_ooooo00?o0000oooooooo
ool0Doooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo0:Wooooo000kooooo`;o0000
E?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo0:Wooooo000kooooo`03o`000?oo
oooooooo05Cooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`2Zooooo`00>oooool0
0ol0003oooooooooo`1Eooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0Z_ooool0
03_ooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
0:_ooooo000Gooooo`;ok^k^0oooool2onk^kQgooooo00?o0000ooooooooool0E_ooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo0:_ooooo000Aooooo`0=odA4A?l0003o0000oc8b<_oM
gMgoooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co000000So410@oooooooooooo
k^k^oc8b<_l0003o<S8bonk^kPkooooo0_l0001Gooooo`03o`000?oooooooooo02?ooooo00?o0000
ooooooooool0Zoooool001Cooooo00WoMgMgoc8b<_ooooooooooonk^k_mEEEGogMgMoeEEEOo^k^h0
1_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool00ol0003o
ooooooooo`1Fooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0[?ooool001Gooooo
00Oo0000ooooooooooooooooomgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@
413ooooooooooooooooo410@00kooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo0:cooooo000Dooooo`09ogMgMolb<S;oooooooooooo^k^koEEEEomgM
gOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo0:co
oooo000Aooooo`0=o`000?lQ8B7o0000oc8b<_o<c<coooooonk^k_mEEEGok^k^ooooooo^k^koEEEE
onk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000>ooooo`;o
0000F?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo0:gooooo000Aooooo`03o`00
0?oooooooooo00?ooooo0_o^k^h3ooooo`;ok^k^1Oooool00ol0003oooooooooo`02ooooo`05oa0@
4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool0[Oooool0017ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool3o`000003ooooool0003o000000;o
00000oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool0[Oooool0017ooooo1?l0000<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP04ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`1Hoooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool0[_ooool0037ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05Wooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`2^ooooo`00<Oooool00ol0003oooooooooo`03ooooo`04o`00
0?ooooooooooooooo`;o0000F_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo0:oo
oooo000aooooo`04o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`00001Koooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool0[oooool0033ooooo0_l00003ooooo`;o
00001?ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool0[oooool003_ooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo0;3ooooo000kooooo`;o0000Foooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo0;3ooooo000kooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`2`ooooo`00>oooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool0/Oooool003_ooooo00?o0000ooooooooool0Foooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo0;7ooooo000kooooo`03o`000?oooooooooo05_ooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`2aooooo`00>oooool2o`0005gooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`2booooo`00>oooool00ol0003oooooooooo`1L
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0/_ooool003_ooooo00?o0000oooo
ooooool0G?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo0;;ooooo000kooooo`03
o`000?oooooooooo05cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`2cooooo`00
5oooool2onk^kP?ooooo0_o^k^hMooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`2cooooo`004Oooool4o`000009oa0@4?ooooook^k^oeEEEOo^k^ko
ooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^
3_ooool2o`0005kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`2cooooo`004ooo
ool00ol0003oooooooooo`02ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`1Mooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool0/oooool001?ooooo00?o0000ooooooooool0
0oooool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@400>ooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`2dooooo`004oooool00ol0003oooooooooo`02ooooo`05onk^k_mEEEGogMgMoeEEEOo^
k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000003_ooool00ol0
003oooooooooo`1Nooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0]?ooool001?o
oooo00_o0000ooooooooooooooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000>ooooo`;o0000Goooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo0;Cooooo000Cooooo`04o`000?ooooooooooooooo`;o
k^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@
00kooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
0;Gooooo000Cooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00?ooooo0ol00002ooooo`;o00001?ooool00ol0003oooooooooo`1Ooooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0]Oooool0017ooooo00?oEEEEofIVI_l0
00003Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool01?l0
003oooooooooool00002ooooo`05o`000?ooooooooooooooool00000H_ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo0;Gooooo000aooooo`03o`000?oooooooooo00?ooooo00Go0000
ooooooooooooooooo`00001Rooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0]_oo
ool0037ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`;o0000HOooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo0;Kooooo000aooooo`04o`000?oooooooooo
o`0000;ooooo00Go0000ooooooooooooooooo`00001Sooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool0]oooool0033ooooo0_l00003ooooo`;o00001?ooool00ol0003oooooooooo`1Q
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0]oooool003_ooooo00?o0000oooo
ooooool0H_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0;Oooooo000kooooo`;o
0000Hoooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0;Sooooo000kooooo`03o`00
0?oooooooooo06;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`2hooooo`00>ooo
ool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0^Ooo
ool003_ooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo0;Wooooo000kooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`2iooooo`00>oooool2o`0006Gooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`2jooooo`00>oooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0^_ooool003_ooooo00?o0000ooooooooool0I_ooool00ol0003ooooooooo
o`02ooooo`;o0000_Oooool003_ooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`02
o`000;kooooo000Hooooo`;ok^k^0oooool2onk^kQcooooo0_l0001Yooooo`?o0000_oooool000;o
oooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool03Om4A4Co0000o`000?lb<S;ogMgM
ooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^
k_lb<S;o0000oc8b<_o^k^h=ooooo`03o`000?oooooooooo0?oooooo:oooool000Cooooo00?o0000
ooooooooool01?ooool2ob4Q8@Sooooo00WoMgMgoc8b<_ooooooooooonk^k_mEEEGogMgMoeEEEOo^
k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03Oooool00ol0
003oooooooooo`3oooooob_ooooo0004ooooo`03o`000?oooooooooo00oooooo00Oo0000oooooooo
ooooooooomgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@00gooooo00?o0000ooooooooool0ooooool[ooooo`001?ooool00ol0003oooooooooo`0>
ooooo`09ogMgMolb<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000oooooooo
ool00_ooool01Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool0ooooool[oooo
o`001?ooool00ol0003oooooooooo`0;ooooo`0=o`000?lQ8B7o0000oc8b<_o<c<coooooonk^k_mE
EEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`00000=ooooo`;o0000ooooool/ooooo`001?ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00?ooooo0_o^k^h3ooooo`;ok^k^1Oooool00ol0003oooooooooo`02ooooo`05
oa0@4?ooooooooooooooool@41003Oooool00ol0003oooooooooo`3oooooob_ooooo0004ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL00oooool3o`0000;ooooo0_l00003ooooo`03o`000?oooooooooo
0?oooooo:oooool000;ooooo00?oEEEEofIVI_l000003Oooool4o`0000cooooo00?oEEEEofIVI_l0
00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool0003oooooobgooooo000booooo`03o`000?oooooooooo00?ooooo00Co0000
oooooooooooo0000ooooool]ooooo`00<_ooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooooooo`;o0000ooooool/ooooo`00<_ooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`000?oooooo;Oooool0037ooooo0_l00003ooooo`;o00000oooool00ol0003ooooooooo
o`3oooooob_ooooo000kooooo`03o`000?oooooooooo0?oooooo:oooool003_ooooo0_l0003ooooo
obcooooo000kooooo`03o`000?oooooooooo0?oooooo:oooool003_ooooo00?o0000ooooooooool0
ooooool[ooooo`00>oooool00ol0003oooooooooo`3oooooob_ooooo000kooooo`03o`000?oooooo
oooo0?oooooo:oooool003_ooooo0_l0003oooooobcooooo000kooooo`03o`000?oooooooooo0?oo
oooo:oooool003_ooooo00?o0000ooooooooool0ooooool[ooooo`005oooool2onk^kP?ooooo0_o^
k^hMooooo`03o`000?oooooooooo0?oooooo:oooool0013ooooo1Ol00002ooooo`07onk^k_mEEEGo
k^k^ooooooo^k^koEEEEonk^kP03ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8b
onk^kPkooooo0_l0003oooooobcooooo000@ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool0
1Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00kooooo00?o0000ooooooooool0ooooool[ooooo`004Oooool00onHV9So8B4Qonk^
kP05ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@00kooooo00?o0000ooooooooool0ooooool[ooooo`004_ooool00onHV9So8B4Qonk^
kP03ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000003_ooool00ol0003oooooooooo`3oooooob_ooooo000Cooooo`0;ogMg
MomVIVKoooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003oooooooooo`3oooooob_ooooo
000Dooooo`03o`000?oooooooooo00;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@00kooooo0_l0003oooooobcooooo000@ooooo`05o`000?nj
^[[ooooooiRHV?l@41003_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03_ooool00ol0003oooooooooo`3oooooob_ooooo000@ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`03?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool3o`00
00;ooooo0_l00004ooooo`03o`000?oooooooooo0?oooooo:oooool0037ooooo00Co0000oooooooo
oooo00000_ooool01Ol0003ooooooooooooooooo00000?oooooo;Oooool0037ooooo00?o0000oooo
ooooool00oooool01?l0003oooooooooooooool2o`000?oooooo;?ooool0037ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo:oooool0037o
oooo00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo00000?oooooo;Oooool0
033ooooo0_l00003ooooo`;o00001?ooool00ol0003oooooooooo`3oooooob_ooooo000kooooo`03
o`000?oooooooooo0?oooooo:oooool003_ooooo0_l0003oooooobcooooo000kooooo`03o`000?oo
oooooooo0?oooooo:oooool003_ooooo00?o0000ooooooooool0ooooool[ooooo`00>oooool00ol0
003oooooooooo`3oooooob_ooooo000kooooo`03o`000?oooooooooo0?oooooo:oooool003_ooooo
0_l0003oooooobcooooo000kooooo`03o`000?oooooooooo0?oooooo:oooool003_ooooo00?o0000
ooooooooool0ooooool[ooooo`006?ooool2onk^kP?ooooo0_o^k^hLooooo`03o`000?oooooooooo
0?oooooo:oooool00003ooooool0003o000000?o00001Oooool2ob4Q8@Gooooo00goA4A4o`000?l0
003o<S8bomgMgOooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413o
ooooooooooo^k^ko<S8bo`000?lb<S;ok^k^3Oooool2o`000?oooooo;?ooool00006oooooonHV9So
8B4Qonk^k_ooooooA4A41Oooool2ob4Q8@Sooooo00WoMgMgoc8b<_ooooooooooonk^k_mEEEGogMgM
oeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03Ooo
ool00ol0003oooooooooo`3oooooob_ooooo0002ooooo`03oiRHV?lQ8B7ok^k^017ooooo00Oo0000
ooooooooooooooooomgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@413ooooo
oooooooooooo410@00gooooo00?o0000ooooooooool0ooooool[ooooo`000oooool00onHV9So8B4Q
onk^kP0?ooooo`09ogMgMolb<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool0oooo
ool[ooooo`001?ooool00omgMgOoIVIVooooo`0;ooooo`0=o`000?lQ8B7o0000oc8b<_o<c<cooooo
onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`00000=ooooo`03o`000?oooooooooo0?oooooo:oooool000Gooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`03ooooo`;ok^k^0oooool2onk^kPGooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00gooooo0_l0003oooooobcooooo0000
1_oooooo0000okZj^_ooooooV9RHoa0@40cooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03Oooool00ol0003oooooooooo`3oooooob_o
oooo00001_ooooooV9RHoa0@4?l0003o8B4Qolc<c0cooooo1?l0000<ooooo`03oeEEEOmVIVKo0000
00Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`?o00000_ooool2o`0000?ooooo00?o0000
ooooooooool0ooooool[ooooo`00<_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`000?oooooo;Oooool003;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
o`000?oooooo;?ooool003;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo
00000?oooooo;Oooool003;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
003oooooobgooooo000aooooo`;o00000oooool2o`0000?ooooo00?o0000ooooooooool0ooooool[
ooooo`00>oooool00ol0003oooooooooo`3oooooob_ooooo000kooooo`;o0000ooooool/ooooo`00
>oooool00ol0003oooooooooo`3oooooob_ooooo000kooooo`03o`000?oooooooooo0?oooooo:ooo
ool003_ooooo00?o0000ooooooooool0ooooool[ooooo`00>oooool2o`000?oooooo;?ooool003_o
oooo00?o0000ooooooooool0ooooool[ooooo`00>oooool00ol0003oooooooooo`3oooooob_ooooo
000kooooo`03o`000?oooooooooo0?oooooo:oooool001Oooooo0_o^k^h3ooooo`;ok^k^7Oooool0
0ol0003oooooooooo`3oooooob_ooooo000@ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00_ooool0
1oo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb
<S;o0000oc8b<_o^k^h>ooooo`;o0000ooooool/ooooo`004?ooool01Ol@413o^[ZjoooooomgMgOo
<S8b00?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oooooooooo0?oooooo:oooool001Cooooo00?o
0000ooooooooool00_ooool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go
410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo0?oooooo:oooool001?ooooo00?o
ZJVYoa0@4?ooool00_ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool0
0_ooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool0ooooool[ooooo`00
4_ooool00ol@413o0000okZj^P02ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05oooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooo
oooo0?oooooo:oooool001?ooooo00Co^[Zjob4Q8Ooooooooooo0_o^k^h3ooooo`;ok^k^1Oooool0
0ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41003_ooool2o`000?oooooo;?oo
ool0013ooooo00Go410@oiRHV?oooooo^[Zjo`00000>ooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oooooooooo0?oooooo:oooool0013ooooo00Go
ZJVYoa0@4?l0003o410@ojVYZ@0<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP03ooooo`?o00000_ooool2o`0000Cooooo00?o0000ooooooooool0ooooool[ooooo`00
<Oooool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool00000ooooool]oooo
o`00<Oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooo`;o0000ooooool/oooo
o`00<Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0ooooool[ooooo`00<Oooool01?l0003oooooooooool00002ooooo`05o`000?oooooooooooooo
ool00000ooooool]ooooo`00<?ooool2o`0000?ooooo0_l00004ooooo`03o`000?oooooooooo0?oo
oooo:oooool003_ooooo00?o0000ooooooooool0ooooool[ooooo`00>oooool2o`000?oooooo;?oo
ool003_ooooo00?o0000ooooooooool0ooooool[ooooo`00>oooool00ol0003oooooooooo`3ooooo
ob_ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo001Mooooo`03ogMgMomVIVKooooo00Cooooo00?o0000ooooooooool00_ooool00onj^[[o
<S8booooo`07ooooo`06o`000?oooooooooooooooomVIVKoMgMg3Oooool00ol0003o^[Zjooooo`3O
ooooo`00G?ooool00ooMgMgo410@onk^kP05ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01_ooool01ol0003oooooooooooooooook^k^oa0@4?oMgMd03?ooool2oc8b<^3ooooo001L
ooooo`03oeEEEOnHV9Sooooo00Gooooo00Ko0000oooooooooooooooooiRHV?l@4102o`000003ojVY
ZOoooooooooo00Cooooo00?o0000ooooooooool00_ooool00on7QhOoIVIVooooo`0;ooooo`03ohN7
Qol0003o^[Zj00Cooooo00Co410@o`000?m4A4Coc<c<1_ooool2ob4Q8@?ooooo00Goc<c<onk^k_oo
ooook^k^olc<c003ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kQ?ooooo
00Ko410@oc8b<_l0003o0000oa0@4?nYZJT2ooooo`06onk^k_mEEEGo0000o`000?m4A4Co^[Zj0ooo
ool01OmVIVKo0000o`000?m4A4Coc<c<08oooooo001Looooo`03o`000?oooooooooo00Gooooo00[o
0000ooooooooooooooooo`000?nYZJWoEEEEoiRHV?mEEEGo^[Zj1Oooool00ol0003oooooooooo`02
ooooo`03onk^k_l0003ooooo00_ooooo00?oc<c<o`000?l@41001_ooool00onHV9So410@omgMg@05
ooooo`;o8B4Q0oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Gooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01?ooooo00Ko0000ojVYZOoooooooooookZj^_l00002oooo
o`06oeEEEOmgMgOoooooonk^k_mgMgOo410@0_ooool01_mVIVKoMgMgooooooooooooQhN7oa0@48oo
oooo001Looooo`03oc8b<_oooooooooo00Gooooo00[o0000oooooooooooooooooc8b<_o^k^koV9RH
oeEEEOoMgMgo410@1Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Cooooo00?o
QhN7oeEEEOooool02_ooool00ooMgMgo0000omgMg@06ooooo`03o`000?oooooooooo00;ooooo00Go
410@oooooooooooooooooa0@400Dooooo`05okZj^_n7QhOoIVIVofIVI_l@41000_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo09;ooooo001Looooo`03oc8b<_oooooooooo00Gooooo
00_o0000oooooooooooooooookZj^_m4A4Coc<c<ob4Q8Ooooooo410@olc<c004ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool04Oooool01Oo<c<co8B4Qo`000?mEEEGo000000[ooooo
00Gok^k^oeEEEOoMgMgoEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`00000Cooooo`06oc8b<_lQ8B7oMgMgogMgMon7QhOok^k^0_ooool6o`0000;ooooo00?o
0000ooooooooool0T_ooool005cooooo00?o0000onk^k_ooool01Oooool02ol0003ooooooooooooo
ooook^k^o`000?oooooo0000oooooomVIVKoQhN700Cooooo00?o0000ooooooooool00_ooool00oo^
k^ko0000ooooo`0Booooo`05ob4Q8On7QhOooooooiRHV?l000002_ooool01Oo<c<cok^k^ooooooo^
k^koc<c<00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000001?ooooo
00Ko0000okZj^_ooooook^k^ogMgMol00002ooooo`06oeEEEOn7QhOok^k^oooooon7QhOo<S8b0_oo
ool01_mVIVKoMgMgooooooooooooQhN7o`0008oooooo001Looooo`03oeEEEOmgMgOooooo00Gooooo
00So0000ooooooooooooooooofIVI_nHV9Sooooooc8b<P;o^[Zj00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`02ooooo`03ogMgMomEEEGooooo00?ooooo1?l0000;ooooo`05o`000?oooooo
ooooooooool000005?ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100
1oooool3o`0000;ooooo0ol00004ooooo`06ojVYZOlQ8B7o0000o`000?lb<S;o00000_ooool01_o^
k^koEEEEo`000?l0003oA4A4onk^kP;ooooo00Kok^k^ofIVI_l0003o0000odA4A?l0002?ooooo`00
G?ooool00ooMgMgo410@onk^kP05ooooo`03o`000?oooooooooo00Cooooo00?oIVIVohN7Qoooool0
1Oooool01ol0003oooooooooooooooook^k^oa0@4?oMgMd01Oooool00ol0003oooooooooo`0;oooo
o`05ob4Q8OnHV9SoooooogMgMomEEED05?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0:Sooooo001M
ooooo`03ogMgMomVIVKooooo00Cooooo00?o0000ooooooooool01?ooool00onYZJWoA4A4ooooo`05
ooooo`06o`000?oooooooooooooooomVIVKoMgMg1oooool00ol0003oooooooooo`0:ooooo`05olc<
c?l@413o0000oc8b<_o^k^h04_ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00_ooool4o`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2Xoooo
o`00POooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0Z?ooool007kooooo00Co0000oooooooooooo0000=_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo0:Sooooo001oooooo`;o0000=_ooool2o`0000?ooooo0_l0002Zooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -2.14748*^9, 0, \
2.14748*^9}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0 1.90278e-14 [
[.32684 -0.0125 -16.5 -12.5 ]
[.32684 -0.0125 16.5 0 ]
[.54329 -0.0125 -16.5 -12.5 ]
[.54329 -0.0125 16.5 0 ]
[.75974 -0.0125 -22.5 -12.5 ]
[.75974 -0.0125 22.5 0 ]
[.97619 -0.0125 -16.5 -12.5 ]
[.97619 -0.0125 16.5 0 ]
[1.025 0 0 -6 ]
[1.025 0 64 6 ]
[.09789 .09514 -33 -6.25 ]
[.09789 .09514 0 6.25 ]
[.09789 .19028 -33 -6.25 ]
[.09789 .19028 0 6.25 ]
[.09789 .28542 -45 -6.25 ]
[.09789 .28542 0 6.25 ]
[.09789 .38056 -33 -6.25 ]
[.09789 .38056 0 6.25 ]
[.09789 .47569 -45 -6.25 ]
[.09789 .47569 0 6.25 ]
[.09789 .57083 -33 -6.25 ]
[.09789 .57083 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -56.4375 0 ]
[.5 .63053 56.4375 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 0 m
.32684 .00625 L
s
gsave
.32684 -0.0125 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 0 m
.54329 .00625 L
s
gsave
.54329 -0.0125 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 0 m
.75974 .00625 L
s
gsave
.75974 -0.0125 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 0 m
.15368 .00375 L
s
.19697 0 m
.19697 .00375 L
s
.24026 0 m
.24026 .00375 L
s
.28355 0 m
.28355 .00375 L
s
.37013 0 m
.37013 .00375 L
s
.41342 0 m
.41342 .00375 L
s
.45671 0 m
.45671 .00375 L
s
.5 0 m
.5 .00375 L
s
.58658 0 m
.58658 .00375 L
s
.62987 0 m
.62987 .00375 L
s
.67316 0 m
.67316 .00375 L
s
.71645 0 m
.71645 .00375 L
s
.80303 0 m
.80303 .00375 L
s
.84632 0 m
.84632 .00375 L
s
.88961 0 m
.88961 .00375 L
s
.9329 0 m
.9329 .00375 L
s
.0671 0 m
.0671 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09514 m
.11664 .09514 L
s
gsave
.09789 .09514 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(12) show
grestore
.11039 .19028 m
.11664 .19028 L
s
gsave
.09789 .19028 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.11039 .28542 m
.11664 .28542 L
s
gsave
.09789 .28542 -45 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.11039 .38056 m
.11664 .38056 L
s
gsave
.09789 .38056 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.11039 .47569 m
.11664 .47569 L
s
gsave
.09789 .47569 -45 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.11039 .57083 m
.11664 .57083 L
s
gsave
.09789 .57083 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(3) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.125 Mabswid
.11039 .01903 m
.11414 .01903 L
s
.11039 .03806 m
.11414 .03806 L
s
.11039 .05708 m
.11414 .05708 L
s
.11039 .07611 m
.11414 .07611 L
s
.11039 .11417 m
.11414 .11417 L
s
.11039 .13319 m
.11414 .13319 L
s
.11039 .15222 m
.11414 .15222 L
s
.11039 .17125 m
.11414 .17125 L
s
.11039 .20931 m
.11414 .20931 L
s
.11039 .22833 m
.11414 .22833 L
s
.11039 .24736 m
.11414 .24736 L
s
.11039 .26639 m
.11414 .26639 L
s
.11039 .30444 m
.11414 .30444 L
s
.11039 .32347 m
.11414 .32347 L
s
.11039 .3425 m
.11414 .3425 L
s
.11039 .36153 m
.11414 .36153 L
s
.11039 .39958 m
.11414 .39958 L
s
.11039 .41861 m
.11414 .41861 L
s
.11039 .43764 m
.11414 .43764 L
s
.11039 .45667 m
.11414 .45667 L
s
.11039 .49472 m
.11414 .49472 L
s
.11039 .51375 m
.11414 .51375 L
s
.11039 .53278 m
.11414 .53278 L
s
.11039 .55181 m
.11414 .55181 L
s
.11039 .58986 m
.11414 .58986 L
s
.11039 .60889 m
.11414 .60889 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -117.438 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.812 moveto
(H) show
69.000 13.812 moveto
(\\310) show
75.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.812 moveto
(\\310) show
87.000 13.812 moveto
(L) show
93.000 9.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
98.250 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
104.250 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10.) show
122.250 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
128.250 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
140.250 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
144.438 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
153.875 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
171.875 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.02499 0 L
.02605 0 L
.02721 0 L
.02846 0 L
.02961 0 L
.03068 0 L
.03279 0 L
.03396 0 L
.03506 0 L
.03636 0 L
.03756 0 L
.04 0 L
.04134 0 L
.04262 0 L
.045 0 L
.04633 0 L
.04753 0 L
.04866 0 L
.04988 0 L
.0521 0 L
.05335 0 L
.05472 0 L
.05615 0 L
.05749 0 L
.05988 0 L
.06122 0 L
.06244 0 L
.06369 0 L
.06505 0 L
.06649 0 L
.06783 0 L
.07022 0 L
.07157 0 L
.07281 0 L
.07408 0 L
.07543 0 L
.07692 0 L
.0783 0 L
.07986 0 L
.08133 0 L
.08265 0 L
.08408 0 L
.08655 0 L
.08795 0 L
.08926 0 L
.09191 0 L
.09339 0 L
.09475 0 L
.09716 0 L
Mistroke
.09853 0 L
.09979 0 L
.10211 0 L
.10341 0 L
.10458 0 L
.10691 0 L
.10824 0 L
.10947 0 L
.11196 0 L
.11336 0 L
.11463 0 L
.1169 0 L
.11819 0 L
.11938 0 L
.12155 0 L
.12265 0 L
.12386 0 L
.12518 0 L
.12657 0 L
.12904 0 L
.13042 0 L
.13171 0 L
.1332 0 L
.13462 0 L
.13585 0 L
.13717 0 L
.13949 0 L
.14081 0 L
.1422 0 L
.1447 0 L
.14591 0 L
.14724 0 L
.14841 0 L
.14965 0 L
.15199 0 L
.15416 0 L
.15536 0 L
.15665 0 L
.15898 0 L
.16034 0 L
.16176 0 L
.16431 0 L
.1665 0 L
.16884 0 L
.17105 0 L
.17306 0 L
.17542 0 L
.17676 0 L
.17799 0 L
.18024 0 L
Mistroke
.18264 0 L
.18516 0 L
.18756 0 L
.18971 0 L
.19206 0 L
.1946 0 L
.19602 0 L
.19731 0 L
.19982 0 L
.20219 0 L
.20442 0 L
.20677 0 L
.20878 0 L
.21098 0 L
.21336 0 L
.2159 0 L
.2183 0 L
.22049 0 L
.22278 0 L
.22531 0 L
.22794 0 L
.23042 0 L
.23272 0 L
.23483 0 L
.23715 0 L
.23959 0 L
.24208 0 L
.24473 0 L
.24724 0 L
.24951 0 L
.25219 0 L
.25509 0 L
.25783 0 L
.26036 0 L
.2628 0 L
.26504 0 L
.26762 0 L
.27006 0 L
.27232 0 L
.2744 0 L
.2767 0 L
.27914 0 L
.28182 0 L
.28472 0 L
.28746 0 L
.28997 0 L
.29225 0 L
.29475 0 L
.29735 0 L
.29978 0 L
Mistroke
.3024 0 L
.30481 0 L
.30746 0 L
.31027 0 L
.31271 0 L
.31499 0 L
.31749 0 L
.32019 0 L
.32257 0 L
.32516 0 L
.32745 0 L
.32989 0 L
.3323 0 L
.33449 0 L
.33876 0 L
.34108 0 L
.34363 0 L
.34612 0 L
.34878 0 L
.35127 0 L
.35355 0 L
.358 1e-05 L
.36066 1e-05 L
.36312 1e-05 L
.36577 1e-05 L
.36869 2e-05 L
.3736 2e-05 L
.37629 3e-05 L
.37882 3e-05 L
.38351 5e-05 L
.38864 7e-05 L
.39123 9e-05 L
.394 .00011 L
.39899 .00015 L
.40397 .00021 L
.40868 .00029 L
.41291 .00039 L
.41749 .00052 L
.42238 .00071 L
.42695 .00094 L
.43197 .00128 L
.43736 .00175 L
.443 .0024 L
.44835 .00321 L
.45316 .00414 L
.4584 .00542 L
.46372 .00705 L
.46874 .00896 L
.4781 .01369 L
.48818 .02093 L
Mistroke
.49908 .03187 L
.50861 .04455 L
.51905 .06213 L
.54013 .1088 L
.5613 .16458 L
.58059 .21068 L
.59018 .22745 L
.59281 .23103 L
.5956 .2343 L
.59801 .23668 L
.6006 .23874 L
.60178 .23951 L
.60303 .2402 L
.60418 .24073 L
.60525 .24113 L
.60626 .24142 L
.60733 .24164 L
.60852 .24178 L
.60961 .2418 L
.61088 .24171 L
.61206 .2415 L
.61335 .24115 L
.61472 .24064 L
.61701 .23944 L
.61954 .23765 L
.62476 .2324 L
.62972 .22563 L
.63902 .20879 L
.65992 .15786 L
.67811 .10994 L
.68847 .08516 L
.6982 .06483 L
.7085 .04696 L
.71794 .03385 L
.72804 .02309 L
.73331 .01866 L
.73894 .01471 L
.74406 .01174 L
.74872 .00949 L
.75783 .00613 L
.76293 .00474 L
.76847 .00355 L
.7737 .00268 L
.77852 .00205 L
.78318 .00157 L
.78819 .00117 L
.79292 .00088 L
.79725 .00067 L
.80231 .00049 L
.80783 .00034 L
Mistroke
.81304 .00024 L
.81788 .00017 L
.82296 .00012 L
.82563 .0001 L
.82845 8e-05 L
.83364 6e-05 L
.83841 4e-05 L
.843 3e-05 L
.84728 2e-05 L
.85198 1e-05 L
.85461 1e-05 L
.85702 1e-05 L
.86183 1e-05 L
.86425 0 L
.86693 0 L
.86921 0 L
.87167 0 L
.87611 0 L
.87863 0 L
.88138 0 L
.88426 0 L
.88694 0 L
.89174 0 L
.89443 0 L
.89687 0 L
.90172 0 L
.90417 0 L
.90685 0 L
.90915 0 L
.91161 0 L
.91392 0 L
.91606 0 L
.91873 0 L
.92164 0 L
.9242 0 L
.92693 0 L
.92961 0 L
.93214 0 L
.93441 0 L
.93686 0 L
.93914 0 L
.94158 0 L
.94389 0 L
.94599 0 L
.94846 0 L
.95113 0 L
.95366 0 L
.956 0 L
.95841 0 L
.96066 0 L
Mistroke
.96313 0 L
.9658 0 L
.96858 0 L
.97122 0 L
.9736 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00H_ooool2onk^kP?ooooo0_o^
k^h]ooooo`;ok^k^0oooool2onk^kSKooooo0_o^k^h3ooooo`;ok^k^9?ooool2onk^kP?ooooo0_o^
k^iSooooo`00G?ooool03Om4A4Co0000o`000?lb<S;ogMgMooooooo^k^koEEEEonk^k_ooooook^k^
oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hHooooo`Co
000000Wo410@ooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?oo
ooooooooonk^k_lb<S;o0000oc8b<_o^k^hAooooo`Co000000?o410@ooooooooool00_ooool2ob4Q
8@Gooooo00goA4A4o`000?l0003o<S8bomgMgOooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^
00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^3_ooool5o`0000;ooooo
00Ook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413oooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^E?ooool005oooooo00WoMgMgoc8b<_ooooooooooonk^k_mEEEGogMgMoeEE
EOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool0
0ol0003oooooooooo`02ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool00ol0003oooooooooo`04ooooo`;o8B4Q
2?ooool02OmgMgOo<S8booooooooooook^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
0oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg05Cooooo001Pooooo`07o`000?oooooooooooooooooMgMgo0000omgMg@07
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Jooooo`03o`000?oo
oooooooo00?ooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?oo
ooooooooooooool@41004oooool00ol0003oooooooooo`0?ooooo`07o`000?oooooooooooooooooM
gMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400?
ooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@4100E?ooool005oooooo00WoMgMgoc8b<_ooooooooooonk^
k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000006_ooool00ol0003oooooooooo`02ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000004oooool00ol0003ooooooooo
o`0>ooooo`09ogMgMolb<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo0000013ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000005Cooooo001Looooo`0=o`000?lQ8B7o0000oc8b<_o<c<coooooonk^k_mEEEGok^k^
ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Jooooo`0;o`000?ooooooooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Ooo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000004oooool00ol0003ooooo
ooooo`0;ooooo`0=o`000?lQ8B7o0000oc8b<_o<c<coooooonk^k_mEEEGok^k^ooooooo^k^koEEEE
onk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Aooooo`0;
ogMgMomVIVKoooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool00000E?ooool005cooooo00?o0000ooooooooool0
0oooool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@400Jooooo`04o`000?ooooooooooooooo`;ok^k^0oooool2onk^kPGooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@01?ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`03ooooo`;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@01;ooooo00?o0000ooooooooool00_o^k^h3ooooo`;ok^k^1Ooo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100E?ooool005cooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
6_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Cooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool01Ol0003o^[ZjoooooonHV9So
410@00kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg05Cooooo001L
ooooo`Co00003?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?oo
ool00ol0003oooooooooo`0=ooooo`03oeEEEOmVIVKo000000gooooo00?oEEEEofIVI_l000001?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo0_l00007ooooo`03oeEEEOmVIVKo000000gooooo
1?l0000<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`;o
00001?ooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo00?oEEEEofIVI_l000001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Sooooo0_l0001:ooooo`00P?ooool00ol0003oooooooooo`0`oooo
o`04o`000?ooooooooooo`0003Wooooo00Co0000oooooooooooo00009oooool01?l0003ooooooooo
ool00019ooooo`00N_ooool4o`0000?ooooo00?o0000ooooooooool0:_ooool4o`000005ooooool0
003oooooooooool00000=?ooool4o`000005ooooool0003oooooooooool000008_ooool4o`000005
ooooool0003oooooooooool00000BOooool0087ooooo00?o0000ooooooooool0;oooool3o`0003[o
oooo0ol0000Xooooo`?o0000B_ooool007oooooo00Co0000oooooooooooo0000<Oooool00ol0003o
ooooooooo`0jooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool03_ooool00omgMgOo
IVIVooooo`0^ooooo`03ofIVI_mgMgOooooo00Oooooo001oooooo`Co0000<_ooool00ol0003ooooo
ooooo`0jooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool03?ooool00ooMgMgo410@
onk^kP0_ooooo`03onk^k_l@413ogMgM00Oooooo003ooooooa_ooooo0_l00002ooooo`;o00003?oo
ool01?mEEEGoV9RHooooooooool2o`0000;ooooo00Oo0000oooooooooooo0000oa0@4?o^k^koEEEE
00;o000000?oA4A4okZj^_ooool00_ooool01OnHV9So0000o`000?m4A4Co^[Zj00;ooooo00Sok^k^
oeEEEOl0003o0000odA4A?nj^[[ooooooa0@40Go00000oooool02?l@413o<S8bo`000?l0003o410@
ojVYZOn7QhOoIVIV1oooool00?oooooo6oooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@cooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`08o`000?ooooooEEEEogMg
Moooooook^k^ogMgMol@4103ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000_ooool01_mEEEGoMgMg
ooooooo^k^koMgMgoa0@40?ooooo00?o0000ooooooooool01?ooool02?l0003oZJVYoooooooooooo
^[Zjo`000?o^k^ko00001oooool0023ooooolOl0000:ooooo`04omgMgOl0003o410@olc<c0gooooo
00?o<S8booooooooool00_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo000000So
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Go
oooo00Oo^[ZjohN7QomVIVKoIVIVoa0@4?oooooo000000Oooooo000Vooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`_o00002Oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0
003oooooo`000008o`0000[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03Oooool01?o^k^ko8B4Qoa0@4?o^k^h=
ooooo`03oc8b<_oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`00
0005o`0000?ooooo00?o0000ooooooooool01?ooool6o`0000?ooooo00?o0000ooooooooool01?oo
ool02?lb<S;o8B4QogMgMomgMgOoQhN7onk^k_oooooo00001oooool003_ooooo00?o0000oooooooo
ool0<Oooool00ol0003oooooooooo`0Looooo`?o00004_ooool00ol0003oooooooooo`0_ooooo`Co
0000<_ooool00ol0003oooooooooo`0=ooooo`04ob4Q8OmgMgOoMgMgoc8b<Pgooooo00?o0000onk^
k_ooool00_ooool03_l0003oc<c<olc<c?l0003oZJVYomgMgOlQ8B7ooooooeEEEOn7QhOok^k^oooo
oon7QhOo<S8b0oooool00ol0003oooooooooo`04ooooo`06oeEEEOn7QhOok^k^oooooon7QhOo<S8b
0oooool00ol0003o<S8bomgMg@04ooooo`08o`000?nj^[[oooooonk^k_mgMgOo0000onk^k_l00007
ooooo`00>oooool00ol0003oooooooooo`1Cooooo`;o0000@?ooool2o`0004Gooooo0_l00002oooo
o`;o00003?ooool03omEEEGoMgMgoooooooooooo410@o`000?lQ8B7o0000ogMgMol@413o0000ojVY
ZOooooook^k^oeEEE@02o`000004odA4A?o^k^kooooooa0@40Go00000oooool01_o^k^koEEEEo`00
0?l0003oA4A4onk^kP;ooooo0_l000001?nYZJWo8B4Qo`000?lQ8B42ooooo`08ojVYZOlQ8B7o0000
o`000?lb<S;o0000ogMgMomEEED7ooooo`00>oooool00ol0003oooooooooo`1Eooooo`?o0000>ooo
ool2o`0005Wooooo00?ogMgMoa0@4?o^k^h04oooool00ol0003oooooooooo`0Iooooo`03onk^k_l@
413ogMgM00Oooooo000kooooo`;o0000FOooool00ol0003oooooooooo`0gooooo`03o`000?oooooo
oooo05[ooooo00?oMgMgofIVI_ooool04_ooool00ol0003oooooooooo`0Iooooo`03ofIVI_mgMgOo
oooo00Oooooo000kooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`2Fooooo`00>oooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo03Go
oooo00?o0000ooooooooool0U_ooool003_ooooo00?o0000ooooooooool0F_ooool00ol0003ooooo
ooooo`0cooooo`03o`000?oooooooooo09Oooooo000kooooo`03o`000?oooooooooo05[ooooo00?o
0000ooooooooool0<_ooool00ol0003oooooooooo`2Hooooo`00>oooool2o`0005cooooo00?o0000
ooooooooool0<?ooool00ol0003oooooooooo`2Iooooo`00>oooool00ol0003oooooooooo`1Loooo
o`03o`000?oooooooooo02kooooo00?o0000ooooooooool0V_ooool003_ooooo00?o0000oooooooo
ool0G?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo09_ooooo000kooooo`03o`00
0?oooooooooo05gooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`2Kooooo`00>ooo
ool2o`0005oooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`2Looooo`00>oooool0
0ol0003oooooooooo`1Oooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0W?ooool0
03_ooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo
09gooooo000kooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool09oooool00ol0003o
ooooooooo`2Mooooo`005oooool2onk^kP?ooooo0_o^k^hMooooo`03o`000?oooooooooo063ooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`2Nooooo`004Oooool03Om4A4Co0000o`00
0?lb<S;ogMgMooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?oo
ooooooooonk^k_lb<S;o0000oc8b<_o^k^h>ooooo`;o0000HOooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo09kooooo000Dooooo`09ogMgMolb<S;oooooooooooo^k^koEEEEomgMgOmE
EEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo
00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo09kooooo
000Eooooo`07o`000?oooooooooooooooooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;o
oooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo067ooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`2Oooooo`005?ooool02OmgMgOo<S8booooooooooook^k^
oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool08oooool00ol0003ooooo
ooooo`2Oooooo`004Oooool03Ol0003o8B4Qo`000?lb<S;oc<c<ooooooo^k^koEEEEonk^k_oooooo
k^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
3_ooool2o`0006?ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`2Pooooo`004Ooo
ool00ol0003oooooooooo`03ooooo`;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool0Hoooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo0:3ooooo000Aooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo0ol000000ooooooo0000
o`000002o`0000?ooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0Pooooo`03o`00
0?oooooooooo0:7ooooo000Aooooo`Co00003?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01?ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000oooooooo
ool0Hoooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo0:7ooooo000aooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Tooooo`03o`00
0?oooooooooo01kooooo00?o0000ooooooooool0X_ooool0037ooooo00?o0000ooooooooool00ooo
ool01?l0003oooooooooooooool2o`0006Gooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`2Rooooo`00<Oooool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool0
0000Ioooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo0:?ooooo000`ooooo`;o0000
0oooool2o`0000Cooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo0:?ooooo000kooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`2Sooooo`00>oooool2o`0006Oooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`2Tooooo`00>oooool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool0Y?ooool003_ooooo00?o0000ooooooooool0Ioooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo0:Cooooo000kooooo`03o`000?oooooooooo06Oooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`2Uooooo`00>oooool00ol0003ooooooooo
o`1Wooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0YOooool003_ooooo0_l0001Y
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0YOooool003_ooooo00?o0000oooo
ooooool0J?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo0:Kooooo000kooooo`03
o`000?oooooooooo06Sooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`2Vooooo`00
>oooool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
Yoooool001Oooooo0_o^k^h3ooooo`;ok^k^7Oooool00ol0003oooooooooo`1Yooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool0Yoooool0017ooooo1?l000002Ol@413oooooonk^k_mE
EEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o
<S8bonk^kPkooooo0_l0001[ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0Yooo
ool001?ooooo00?o0000ooooooooool00_ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00?o0000ooooooooool0
J_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo0:Sooooo000Cooooo`03o`000?oo
oooooooo00?ooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?oo
ooooooooooooool@41003_ooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool0Z?ooool001?ooooo00?o0000ooooooooool00_ooool01Oo^k^koEEEEomgM
gOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo0:Wo
oooo000Cooooo`0;o`000?ooooooooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Ooo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000003_ooool2o`0006gooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`2Yooooo`004oooool01?l0003ooooooooo
ooooool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@400>ooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`2Yooooo`004oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`?o00000_ooool2o`0000Cooooo00?o0000oooooooo
ool0K?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo0:[ooooo000Aooooo`03oeEE
EOmVIVKo000000gooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Co
oooo00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo000006oooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`2Zooooo`00<Oooool00ol0003oooooooooo`03oooo
o`05o`000?ooooooooooooooool00000Koooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo0:[ooooo000aooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool2o`00
06oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`2[ooooo`00<Oooool01?l0003o
ooooooooool00002ooooo`05o`000?ooooooooooooooool00000L?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo0:_ooooo000`ooooo`;o00000oooool2o`0000Cooooo00?o0000oooo
ooooool0Koooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0:cooooo000kooooo`03
o`000?oooooooooo06oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2/ooooo`00
>oooool2o`00077ooooo00?o0000ooooooooool01_ooool2o`000:oooooo000kooooo`03o`000?oo
oooooooo077ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2_ooooo`00>oooool0
0ol0003oooooooooo`1aooooo`;o00001?ooool00ol0003oooooooooo`2`ooooo`00>oooool00ol0
003oooooooooo`1cooooo`Co0000/oooool003_ooooo00?o0000ooooooooool0ooooool[ooooo`00
>oooool2o`000?oooooo;?ooool003_ooooo00?o0000ooooooooool0ooooool[ooooo`00>oooool0
0ol0003oooooooooo`3oooooob_ooooo000kooooo`03o`000?oooooooooo0?oooooo:oooool001So
oooo0_o^k^h3ooooo`;ok^k^7?ooool2o`000?oooooo;?ooool000;ooooo1?l000000ol@413ooooo
ooooo`02ooooo`;o8B4Q1Oooool03Om4A4Co0000o`000?lb<S;ogMgMooooooo^k^koEEEEonk^k_oo
ooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h=
ooooo`03o`000?oooooooooo0?oooooo:oooool000Cooooo00?o0000ooooooooool01?ooool2ob4Q
8@Sooooo00WoMgMgoc8b<_ooooooooooonk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03Oooool00ol0003oooooooooo`3oooooob_o
oooo0004ooooo`03o`000?oooooooooo00oooooo00Oo0000ooooooooooooooooomgMgOl0003ogMgM
00Oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00gooooo00?o0000
ooooooooool0ooooool[ooooo`001?ooool00ol0003oooooooooo`0>ooooo`09ogMgMolb<S;ooooo
ooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000gooooo00?o0000ooooooooool0ooooool[ooooo`001?ooool00ol0003ooooo
ooooo`0;ooooo`0=o`000?lQ8B7o0000oc8b<_o<c<coooooonk^k_mEEEGok^k^ooooooo^k^koEEEE
onk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000=ooooo`;o
0000ooooool/ooooo`001?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo
0_o^k^h3ooooo`;ok^k^1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41003Oooool00ol0003oooooooooo`3oooooob_ooooo0004ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00oooool3o`0000;ooooo0_l00003ooooo`03o`000?oooooooooo0?oooooo:oooool000;ooooo
00?oEEEEofIVI_l000003Oooool4o`0000cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Cooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0003o
ooooobgooooo000booooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo0000ooooool]
ooooo`00<_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooooooo`;o0000ooooool/
ooooo`00<_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`000?oooooo;Ooo
ool0037ooooo0_l00003ooooo`;o00000oooool00ol0003oooooooooo`3oooooob_ooooo000koooo
o`03o`000?oooooooooo0?oooooo:oooool003_ooooo0_l0003oooooobcooooo000kooooo`03o`00
0?oooooooooo0?oooooo:oooool003_ooooo00?o0000ooooooooool0ooooool[ooooo`00>oooool0
0ol0003oooooooooo`3oooooob_ooooo000kooooo`03o`000?oooooooooo0?oooooo:oooool003_o
oooo0_l0003oooooobcooooo000kooooo`03o`000?oooooooooo0?oooooo:oooool003_ooooo00?o
0000ooooooooool0ooooool[ooooo`005oooool2onk^kP?ooooo0_o^k^hMooooo`03o`000?oooooo
oooo0?oooooo:oooool0013ooooo1Ol00002ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^
kP03ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPkooooo0_l0003ooooo
obcooooo000@ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01Oo^k^koEEEEomgMgOmEEEGo
k^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00?o
0000ooooooooool0ooooool[ooooo`004Oooool00onHV9So8B4Qonk^kP05ooooo`03omgMgOl0003o
gMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00kooooo00?o
0000ooooooooool0ooooool[ooooo`004_ooool00onHV9So8B4Qonk^kP03ooooo`05onk^k_mEEEGo
gMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
3_ooool00ol0003oooooooooo`3oooooob_ooooo000Cooooo`0;ogMgMomVIVKoooooooooooo^k^ko
EEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000003_ooool00ol0003oooooooooo`3oooooob_ooooo000Dooooo`03o`000?oooooo
oooo00;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@00kooooo0_l0003oooooobcooooo000@ooooo`05o`000?nj^[[ooooooiRHV?l@41003_oo
ool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool00ol0003ooooo
ooooo`3oooooob_ooooo000@ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?ooool00omEEEGoIVIV
o`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool3o`0000;ooooo0_l00004ooooo`03
o`000?oooooooooo0?oooooo:oooool0037ooooo00Co0000oooooooooooo00000_ooool01Ol0003o
oooooooooooooooo00000?oooooo;Oooool0037ooooo00?o0000ooooooooool00oooool01?l0003o
ooooooooooooool2o`000?oooooo;?ooool0037ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo0?oooooo:oooool0037ooooo00Co0000oooooooooooo
00000_ooool01Ol0003ooooooooooooooooo00000?oooooo;Oooool0033ooooo0_l00003ooooo`;o
00001?ooool00ol0003oooooooooo`3oooooob_ooooo000kooooo`03o`000?oooooooooo0?oooooo
:oooool003_ooooo0_l0003oooooobcooooo000kooooo`03o`000?oooooooooo0?oooooo:oooool0
03_ooooo00?o0000ooooooooool0ooooool[ooooo`00>oooool00ol0003oooooooooo`3oooooob_o
oooo000kooooo`03o`000?oooooooooo0?oooooo:oooool003_ooooo0_l0003oooooobcooooo000k
ooooo`03o`000?oooooooooo0?oooooo:oooool003_ooooo00?o0000ooooooooool0ooooool[oooo
o`006?ooool2onk^kP?ooooo0_o^k^hLooooo`03o`000?oooooooooo0?oooooo:oooool00003oooo
ool0003o000000?o00001Oooool2ob4Q8@Gooooo00goA4A4o`000?l0003o<S8bomgMgOooooook^k^
oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`00
0?lb<S;ok^k^3Oooool2o`000?oooooo;?ooool00006oooooonHV9So8B4Qonk^k_ooooooA4A41Ooo
ool2ob4Q8@Sooooo00WoMgMgoc8b<_ooooooooooonk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0
003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03Oooool00ol0003oooooooooo`3o
ooooob_ooooo0002ooooo`03oiRHV?lQ8B7ok^k^017ooooo00Oo0000ooooooooooooooooomgMgOl0
003ogMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00gooooo
00?o0000ooooooooool0ooooool[ooooo`000oooool00onHV9So8B4Qonk^kP0?ooooo`09ogMgMolb
<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0
003ooooooooooooooooo000000gooooo00?o0000ooooooooool0ooooool[ooooo`001?ooool00omg
MgOoIVIVooooo`0;ooooo`0=o`000?lQ8B7o0000oc8b<_o<c<coooooonk^k_mEEEGok^k^ooooooo^
k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000=
ooooo`03o`000?oooooooooo0?oooooo:oooool000Gooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`03ooooo`;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@
413ooooooooooooooooo410@00gooooo0_l0003oooooobcooooo00001_oooooo0000okZj^_oooooo
V9RHoa0@40cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03Oooool00ol0003oooooooooo`3oooooob_ooooo00001_ooooooV9RHoa0@
4?l0003o8B4Qolc<c0cooooo1?l0000<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP03ooooo`?o00000_ooool2o`0000?ooooo00?o0000ooooooooool0ooooool[oooo
o`00<_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`000?oooooo;Oooool0
03;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02o`000?oooooo;?ooool003;o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo00000?oooooo;Oooool003;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0003oooooobgooooo000aoooo
o`;o00000oooool2o`0000?ooooo00?o0000ooooooooool0ooooool[ooooo`00>oooool00ol0003o
ooooooooo`3oooooob_ooooo000kooooo`;o0000ooooool/ooooo`00>oooool00ol0003ooooooooo
o`3oooooob_ooooo000kooooo`03o`000?oooooooooo0?oooooo:oooool003_ooooo00?o0000oooo
ooooool0ooooool[ooooo`00>oooool2o`000?oooooo;?ooool003_ooooo00?o0000ooooooooool0
ooooool[ooooo`00>oooool00ol0003oooooooooo`3oooooob_ooooo000kooooo`03o`000?oooooo
oooo0?oooooo:oooool001Oooooo0_o^k^h3ooooo`;ok^k^7Oooool00ol0003oooooooooo`3ooooo
ob_ooooo000@ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00_ooool01oo^k^koEEEEonk^k_oooooo
k^k^oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h>oooo
o`;o0000ooooool/ooooo`004?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00Gok^k^oeEE
EOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0>ooooo`03o`000?oooooooooo0?oooooo:oooool001Cooooo00?o0000ooooooooool00_ooool0
0ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
400>ooooo`03o`000?oooooooooo0?oooooo:oooool001?ooooo00?oZJVYoa0@4?ooool00_ooool0
1Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000kooooo00?o0000ooooooooool0ooooool[ooooo`004_ooool00ol@413o0000okZj
^P02ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo0?oooooo:oooool001?o
oooo00Co^[Zjob4Q8Ooooooooooo0_o^k^h3ooooo`;ok^k^1Oooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@41003_ooool2o`000?oooooo;?ooool0013ooooo00Go410@oiRH
V?oooooo^[Zjo`00000>ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0>ooooo`03o`000?oooooooooo0?oooooo:oooool0013ooooo00GoZJVYoa0@4?l0003o410@ojVY
Z@0<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`?o0000
0_ooool2o`0000Cooooo00?o0000ooooooooool0ooooool[ooooo`00<Oooool01?l0003ooooooooo
ool00002ooooo`05o`000?ooooooooooooooool00000ooooool]ooooo`00<Oooool00ol0003ooooo
ooooo`03ooooo`04o`000?ooooooooooooooo`;o0000ooooool/ooooo`00<Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0ooooool[ooooo`00<Ooo
ool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool00000ooooool]ooooo`00
<?ooool2o`0000?ooooo0_l00004ooooo`03o`000?oooooooooo0?oooooo:oooool003_ooooo00?o
0000ooooooooool0ooooool[ooooo`00>oooool2o`000?oooooo;?ooool003_ooooo00?o0000oooo
ooooool0ooooool[ooooo`00>oooool00ol0003oooooooooo`3oooooob_ooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo001Iooooo`03ogMg
MomVIVKooooo00Cooooo00?o0000ooooooooool00_ooool00onj^[[o<S8booooo`07ooooo`06o`00
0?oooooooooooooooomVIVKoMgMg3Oooool00ol0003o^[Zjooooo`3Sooooo`00F?ooool00ooMgMgo
410@onk^kP05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01_ooool01ol0003o
ooooooooooooooook^k^oa0@4?oMgMd03?ooool2oc8b<^Cooooo001Hooooo`03oeEEEOnHV9Sooooo
00Gooooo00Ko0000oooooooooooooooooiRHV?l@4102o`000003ojVYZOoooooooooo00Cooooo00?o
0000ooooooooool00_ooool00on7QhOoIVIVooooo`0;ooooo`03ohN7Qol0003o^[Zj00Gooooo1?l0
00002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@;ooooo00Goc<c<onk^
k_ooooook^k^olc<c004ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kQ?o
oooo00Ko410@oc8b<_l0003o0000oa0@4?nYZJT2ooooo`06onk^k_mEEEGo0000o`000?m4A4Co^[Zj
0oooool01OmVIVKo0000o`000?m4A4Coc<c<08_ooooo001Hooooo`03o`000?oooooooooo00Gooooo
00[o0000ooooooooooooooooo`000?nYZJWoEEEEoiRHV?mEEEGo^[Zj1Oooool00ol0003ooooooooo
o`02ooooo`03onk^k_l0003ooooo00_ooooo00?oc<c<o`000?l@41001oooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@;ooooo00Gok^k^oeEEEOoMgMgo
EEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Coooo
o`06o`000?nYZJWooooooooooonj^[[o00000_ooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40;o
oooo00KoIVIVogMgMoooooooooooohN7Qol@412;ooooo`00F?ooool00olb<S;oooooooooo`05oooo
o`0:o`000?oooooooooooooooolb<S;ok^k^oiRHV?mEEEGogMgMoa0@40Gooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooo
oooooooooa0@400:ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@
413ooooooooooooooooo410@01Cooooo00Go^[ZjohN7QomVIVKoIVIVoa0@4002ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0S_ooool005Sooooo00?o<S8booooooooool01Oooool0
2ol0003ooooooooooooooooo^[ZjodA4A?o<c<co8B4Qooooool@413oc<c<00Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`000009ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000004oooool01_lb<S;o8B4QogMgMomgMgOoQhN7onk^
kP;ooooo1_l00002ooooo`03o`000?oooooooooo08kooooo001Hooooo`03o`000?o^k^kooooo00Go
oooo00_o0000ooooooooooooooooonk^k_l0003oooooo`000?ooooooIVIVohN7Q`04ooooo`03o`00
0?oooooooooo00;ooooo00?ok^k^o`000?ooool05Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000002Oooool01Oo<c<cok^k^ooooooo^k^koc<c<00Kooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000001?ooooo00Ko0000okZj^_ooooook^k^ogMg
Mol00002ooooo`06oeEEEOn7QhOok^k^oooooon7QhOo<S8b0_ooool01_mVIVKoMgMgoooooooooooo
QhN7o`0008_ooooo001Hooooo`03oeEEEOmgMgOooooo00Gooooo00So0000ooooooooooooooooofIV
I_nHV9Sooooooc8b<P;o^[Zj00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03
ogMgMomEEEGooooo00?ooooo1?l0000>ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooo
oooooooooa0@400Dooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4007
ooooo`?o00000_ooool3o`0000Cooooo00KoZJVYob4Q8Ol0003o0000oc8b<_l00002ooooo`06onk^
k_mEEEGo0000o`000?m4A4Cok^k^0_ooool01_o^k^koIVIVo`000?l0003oA4A4o`0008_ooooo001H
ooooo`03omgMgOl@413ok^k^00Gooooo00?o0000ooooooooool01?ooool00omVIVKoQhN7ooooo`05
ooooo`07o`000?ooooooooooooooooo^k^ko410@omgMg@05ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01Cooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`2Tooooo`00FOooool00omgMgOoIVIVooooo`04ooooo`03o`000?oooooooooo00Co
oooo00?oZJVYodA4A?ooool01Oooool01_l0003oooooooooooooooooIVIVogMgM`Oooooo00?o0000
ooooooooool02oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04_oo
ool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_ooool4o`0000;ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`2Tooooo`00OOooool00ol0003ooooooooo
o`0looooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Y?ooool007[ooooo00Co0000
oooooooooooo0000?_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0:Cooooo001k
ooooo`;o0000?_ooool2o`0000?ooooo0_l0002Vooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -2.14748*^9, 0, \
2.14748*^9}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0 1.90278e-14 [
[.32684 -0.0125 -16.5 -12.5 ]
[.32684 -0.0125 16.5 0 ]
[.54329 -0.0125 -16.5 -12.5 ]
[.54329 -0.0125 16.5 0 ]
[.75974 -0.0125 -22.5 -12.5 ]
[.75974 -0.0125 22.5 0 ]
[.97619 -0.0125 -16.5 -12.5 ]
[.97619 -0.0125 16.5 0 ]
[1.025 0 0 -6 ]
[1.025 0 64 6 ]
[.09789 .09514 -33 -6.25 ]
[.09789 .09514 0 6.25 ]
[.09789 .19028 -33 -6.25 ]
[.09789 .19028 0 6.25 ]
[.09789 .28542 -45 -6.25 ]
[.09789 .28542 0 6.25 ]
[.09789 .38056 -33 -6.25 ]
[.09789 .38056 0 6.25 ]
[.09789 .47569 -45 -6.25 ]
[.09789 .47569 0 6.25 ]
[.09789 .57083 -33 -6.25 ]
[.09789 .57083 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -56.4375 0 ]
[.5 .63053 56.4375 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 0 m
.32684 .00625 L
s
gsave
.32684 -0.0125 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 0 m
.54329 .00625 L
s
gsave
.54329 -0.0125 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 0 m
.75974 .00625 L
s
gsave
.75974 -0.0125 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 0 m
.15368 .00375 L
s
.19697 0 m
.19697 .00375 L
s
.24026 0 m
.24026 .00375 L
s
.28355 0 m
.28355 .00375 L
s
.37013 0 m
.37013 .00375 L
s
.41342 0 m
.41342 .00375 L
s
.45671 0 m
.45671 .00375 L
s
.5 0 m
.5 .00375 L
s
.58658 0 m
.58658 .00375 L
s
.62987 0 m
.62987 .00375 L
s
.67316 0 m
.67316 .00375 L
s
.71645 0 m
.71645 .00375 L
s
.80303 0 m
.80303 .00375 L
s
.84632 0 m
.84632 .00375 L
s
.88961 0 m
.88961 .00375 L
s
.9329 0 m
.9329 .00375 L
s
.0671 0 m
.0671 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09514 m
.11664 .09514 L
s
gsave
.09789 .09514 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(12) show
grestore
.11039 .19028 m
.11664 .19028 L
s
gsave
.09789 .19028 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.11039 .28542 m
.11664 .28542 L
s
gsave
.09789 .28542 -45 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.11039 .38056 m
.11664 .38056 L
s
gsave
.09789 .38056 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.11039 .47569 m
.11664 .47569 L
s
gsave
.09789 .47569 -45 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.11039 .57083 m
.11664 .57083 L
s
gsave
.09789 .57083 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(3) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.125 Mabswid
.11039 .01903 m
.11414 .01903 L
s
.11039 .03806 m
.11414 .03806 L
s
.11039 .05708 m
.11414 .05708 L
s
.11039 .07611 m
.11414 .07611 L
s
.11039 .11417 m
.11414 .11417 L
s
.11039 .13319 m
.11414 .13319 L
s
.11039 .15222 m
.11414 .15222 L
s
.11039 .17125 m
.11414 .17125 L
s
.11039 .20931 m
.11414 .20931 L
s
.11039 .22833 m
.11414 .22833 L
s
.11039 .24736 m
.11414 .24736 L
s
.11039 .26639 m
.11414 .26639 L
s
.11039 .30444 m
.11414 .30444 L
s
.11039 .32347 m
.11414 .32347 L
s
.11039 .3425 m
.11414 .3425 L
s
.11039 .36153 m
.11414 .36153 L
s
.11039 .39958 m
.11414 .39958 L
s
.11039 .41861 m
.11414 .41861 L
s
.11039 .43764 m
.11414 .43764 L
s
.11039 .45667 m
.11414 .45667 L
s
.11039 .49472 m
.11414 .49472 L
s
.11039 .51375 m
.11414 .51375 L
s
.11039 .53278 m
.11414 .53278 L
s
.11039 .55181 m
.11414 .55181 L
s
.11039 .58986 m
.11414 .58986 L
s
.11039 .60889 m
.11414 .60889 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -117.438 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.812 moveto
(H) show
69.000 13.812 moveto
(\\310) show
75.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.812 moveto
(\\310) show
87.000 13.812 moveto
(L) show
93.000 9.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
98.250 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
104.250 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11.) show
122.250 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
128.250 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
140.250 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
144.438 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
153.875 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
171.875 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.02499 0 L
.02605 0 L
.02721 0 L
.02846 0 L
.02961 0 L
.03068 0 L
.03279 0 L
.03396 0 L
.03506 0 L
.03636 0 L
.03756 0 L
.04 0 L
.04134 0 L
.04262 0 L
.045 0 L
.04633 0 L
.04753 0 L
.04866 0 L
.04988 0 L
.0521 0 L
.05335 0 L
.05472 0 L
.05615 0 L
.05749 0 L
.05988 0 L
.06122 0 L
.06244 0 L
.06505 0 L
.06637 0 L
.06783 0 L
.06906 0 L
.0704 0 L
.07281 0 L
.07418 0 L
.07567 0 L
.07724 0 L
.07869 0 L
.0813 0 L
.08276 0 L
.08408 0 L
.08536 0 L
.08671 0 L
.08914 0 L
.09049 0 L
.09175 0 L
.09323 0 L
.09463 0 L
.09583 0 L
.09713 0 L
Mistroke
.09942 0 L
.10072 0 L
.1021 0 L
.10458 0 L
.10583 0 L
.10719 0 L
.10853 0 L
.10995 0 L
.11129 0 L
.11251 0 L
.11489 0 L
.11632 0 L
.11764 0 L
.11905 0 L
.12062 0 L
.12324 0 L
.12468 0 L
.12603 0 L
.1285 0 L
.12975 0 L
.13111 0 L
.13351 0 L
.13575 0 L
.13712 0 L
.1384 0 L
.14081 0 L
.14216 0 L
.14341 0 L
.14485 0 L
.14621 0 L
.14867 0 L
.1509 0 L
.15331 0 L
.15467 0 L
.15593 0 L
.15803 0 L
.16034 0 L
.16275 0 L
.16502 0 L
.16754 0 L
.16881 0 L
.1702 0 L
.17266 0 L
.17495 0 L
.17766 0 L
.18013 0 L
.1815 0 L
.18298 0 L
.18567 0 L
.18802 0 L
Mistroke
.19055 0 L
.19294 0 L
.19512 0 L
.19767 0 L
.20045 0 L
.20308 0 L
.20552 0 L
.20827 0 L
.21086 0 L
.21319 0 L
.21571 0 L
.21845 0 L
.22136 0 L
.22384 0 L
.22656 0 L
.22907 0 L
.2318 0 L
.23438 0 L
.23677 0 L
.23892 0 L
.24129 0 L
.24376 0 L
.24608 0 L
.24864 0 L
.25133 0 L
.25364 0 L
.25615 0 L
.25887 0 L
.26177 0 L
.26451 0 L
.267 0 L
.26931 0 L
.27185 0 L
.27451 0 L
.27699 0 L
.27931 0 L
.28143 0 L
.28388 0 L
.2862 0 L
.2887 0 L
.29137 0 L
.29388 0 L
.29616 0 L
.29884 0 L
.30175 0 L
.30449 0 L
.307 0 L
.30947 0 L
.31172 0 L
.31432 0 L
Mistroke
.31677 0 L
.32114 0 L
.3236 0 L
.32588 0 L
.33065 0 L
.33337 0 L
.33592 0 L
.34104 0 L
.34393 0 L
.34656 0 L
.35132 0 L
.35399 0 L
.3564 0 L
.35866 0 L
.36111 0 L
.36554 0 L
.36804 0 L
.37078 0 L
.37346 0 L
.37633 0 L
.37901 0 L
.38146 0 L
.38626 1e-05 L
.38854 1e-05 L
.39106 1e-05 L
.39617 1e-05 L
.40089 2e-05 L
.40533 2e-05 L
.41054 4e-05 L
.41532 5e-05 L
.42057 7e-05 L
.42609 .0001 L
.43109 .00014 L
.43563 .00019 L
.44087 .00026 L
.44582 .00035 L
.45041 .00047 L
.45463 .0006 L
.45927 .00078 L
.46419 .00102 L
.46911 .00134 L
.47362 .0017 L
.47847 .00218 L
.48375 .00285 L
.48862 .00362 L
.49314 .00449 L
.50206 .00675 L
.50715 .00844 L
.51265 .01065 L
.52262 .01587 L
Mistroke
.53232 .02279 L
.54123 .03105 L
.56009 .05542 L
.58076 .09319 L
.60194 .13999 L
.62122 .18159 L
.63081 .19873 L
.63587 .20623 L
.64123 .21281 L
.64591 .21727 L
.64858 .21925 L
.65108 .22071 L
.65219 .22124 L
.65336 .22171 L
.65437 .22206 L
.65546 .22235 L
.65662 .22258 L
.65771 .22273 L
.659 .2228 L
.66017 .22277 L
.66137 .22266 L
.66249 .22247 L
.66372 .22217 L
.66503 .22174 L
.66772 .22054 L
.67017 .21906 L
.6749 .2152 L
.67939 .21036 L
.68935 .19597 L
.70019 .17572 L
.71955 .13316 L
.74093 .08664 L
.75066 .06827 L
.76115 .05123 L
.77099 .03805 L
.78015 .02814 L
.7897 .02003 L
.80016 .01341 L
.81035 .0088 L
.81606 .00686 L
.82125 .00543 L
.82608 .00433 L
.83121 .00339 L
.8404 .00214 L
.84551 .00164 L
.85029 .00127 L
.85554 .00095 L
.86119 .00069 L
.86643 .00051 L
.87129 .00038 L
Mistroke
.87663 .00028 L
.88233 .00019 L
.88775 .00014 L
.89286 .0001 L
.89745 7e-05 L
.90242 5e-05 L
.90734 4e-05 L
.91193 3e-05 L
.91696 2e-05 L
.91979 1e-05 L
.92236 1e-05 L
.92754 1e-05 L
.93047 1e-05 L
.93318 1e-05 L
.93815 0 L
.94066 0 L
.94343 0 L
.94744 0 L
.95165 0 L
.95526 0 L
.9592 0 L
.96345 0 L
.96584 0 L
.968 0 L
.97221 0 L
.97619 0 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00H_ooool2onk^kP?ooooo0_o^
k^h]ooooo`;ok^k^0oooool2onk^kSKooooo0_o^k^h3ooooo`;ok^k^9?ooool2onk^kP?ooooo0_o^
k^iSooooo`00G?ooool03Om4A4Co0000o`000?lb<S;ogMgMooooooo^k^koEEEEonk^k_ooooook^k^
oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hHooooo`Co
000000Wo410@ooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?oo
ooooooooonk^k_lb<S;o0000oc8b<_o^k^hAooooo`Co000000?o410@ooooooooool00_ooool2ob4Q
8@Gooooo00goA4A4o`000?l0003o<S8bomgMgOooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^
00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^3_ooool5o`0000;ooooo
00Ook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413oooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^E?ooool005oooooo00WoMgMgoc8b<_ooooooooooonk^k_mEEEGogMgMoeEE
EOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool0
0ol0003oooooooooo`02ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool00ol0003oooooooooo`04ooooo`;o8B4Q
2?ooool02OmgMgOo<S8booooooooooook^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
0oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg05Cooooo001Pooooo`07o`000?oooooooooooooooooMgMgo0000omgMg@07
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Jooooo`03o`000?oo
oooooooo00?ooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?oo
ooooooooooooool@41004oooool00ol0003oooooooooo`0?ooooo`07o`000?oooooooooooooooooM
gMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400?
ooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@4100E?ooool005oooooo00WoMgMgoc8b<_ooooooooooonk^
k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000006_ooool00ol0003oooooooooo`02ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000004oooool00ol0003ooooooooo
o`0>ooooo`09ogMgMolb<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo0000013ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000005Cooooo001Looooo`0=o`000?lQ8B7o0000oc8b<_o<c<coooooonk^k_mEEEGok^k^
ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Jooooo`0;o`000?ooooooooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Ooo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000004oooool00ol0003ooooo
ooooo`0;ooooo`0=o`000?lQ8B7o0000oc8b<_o<c<coooooonk^k_mEEEGok^k^ooooooo^k^koEEEE
onk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Aooooo`0;
ogMgMomVIVKoooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool00000E?ooool005cooooo00?o0000ooooooooool0
0oooool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@400Jooooo`04o`000?ooooooooooooooo`;ok^k^0oooool2onk^kPGooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@01?ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`03ooooo`;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@01;ooooo00?o0000ooooooooool00_o^k^h3ooooo`;ok^k^1Ooo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100E?ooool005cooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
6_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Cooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool01Ol0003o^[ZjoooooonHV9So
410@00kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg05Cooooo001L
ooooo`Co00003?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?oo
ool00ol0003oooooooooo`0=ooooo`03oeEEEOmVIVKo000000gooooo00?oEEEEofIVI_l000001?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo0_l00007ooooo`03oeEEEOmVIVKo000000gooooo
1?l0000<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`;o
00001?ooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo00?oEEEEofIVI_l000001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Sooooo0_l0001:ooooo`00P?ooool00ol0003oooooooooo`0`oooo
o`04o`000?ooooooooooo`0003Wooooo00Co0000oooooooooooo00009oooool01?l0003ooooooooo
ool00019ooooo`00N_ooool4o`0000?ooooo00?o0000ooooooooool0:_ooool4o`000005ooooool0
003oooooooooool00000=?ooool4o`000005ooooool0003oooooooooool000008_ooool4o`000005
ooooool0003oooooooooool00000BOooool0087ooooo00?o0000ooooooooool0;oooool3o`0003[o
oooo0ol0000Xooooo`?o0000B_ooool007oooooo00Co0000oooooooooooo0000<Oooool00ol0003o
ooooooooo`0jooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool03_ooool00omgMgOo
IVIVooooo`0^ooooo`03ofIVI_mgMgOooooo00Oooooo001oooooo`Co0000<_ooool00ol0003ooooo
ooooo`0jooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool03?ooool00ooMgMgo410@
onk^kP0_ooooo`03onk^k_l@413ogMgM00Oooooo003ooooooa_ooooo0_l00002ooooo`;o00003?oo
ool01?mEEEGoV9RHooooooooool2o`0000;ooooo00Oo0000oooooooooooo0000oa0@4?o^k^koEEEE
00;o000000?oA4A4okZj^_ooool00_ooool01OnHV9So0000o`000?m4A4Co^[Zj00;ooooo00Sok^k^
oeEEEOl0003o0000odA4A?nj^[[ooooooa0@40Go00000oooool02?l@413o<S8bo`000?l0003o410@
ojVYZOn7QhOoIVIV1oooool00?oooooo6oooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@cooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`08o`000?ooooooEEEEogMg
Moooooook^k^ogMgMol@4103ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000_ooool01_mEEEGoMgMg
ooooooo^k^koMgMgoa0@40?ooooo00?o0000ooooooooool01?ooool02?l0003oZJVYoooooooooooo
^[Zjo`000?o^k^ko00001oooool0023ooooolOl0000:ooooo`04omgMgOl0003o410@olc<c0gooooo
00?o<S8booooooooool00_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo000000So
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Go
oooo00Oo^[ZjohN7QomVIVKoIVIVoa0@4?oooooo000000Oooooo000Vooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Kooooo3?l0000:ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo2Ol00006ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0=ooooo`04onk^k_lQ8B7o410@
onk^kPgooooo00?o<S8booooooooool00_ooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooo000000Go00000oooool00ol0003oooooooooo`04ooooo`Ko00000oooool00ol0003ooooooooo
o`04ooooo`08oc8b<_lQ8B7oMgMgogMgMon7QhOok^k^ooooool00007ooooo`00>oooool00ol0003o
ooooooooo`0aooooo`03o`000?oooooooooo02Oooooo0_l00008ooooo`03o`000?oooooooooo037o
oooo00?o0000ooooooooool02?ooool5o`0002Cooooo00?o0000ooooooooool03Oooool01?lQ8B7o
MgMgogMgMolb<S8=ooooo`03o`000?o^k^kooooo00;ooooo00ko0000olc<c?o<c<co0000ojVYZOoM
gMgo8B4QoooooomEEEGoQhN7onk^k_ooooooQhN7oc8b<P?ooooo00?o0000ooooooooool01?ooool0
1_mEEEGoQhN7onk^k_ooooooQhN7oc8b<P?ooooo00?o0000oc8b<_oMgMd01?ooool02?l0003o^[Zj
ooooooo^k^koMgMgo`000?o^k^ko00001oooool003_ooooo00?o0000ooooooooool0GOooool3o`00
04?ooooo00?o0000ooooooooool0=_ooool2o`0000;ooooo0_l0000<ooooo`0?oeEEEOmgMgOooooo
ooooool@413o0000ob4Q8Ol0003oMgMgoa0@4?l0003oZJVYooooooo^k^koEEEE00;o000000CoA4A4
onk^k_oooooo410@1Ol00003ooooo`06onk^k_mEEEGo0000o`000?m4A4Cok^k^0_ooool2o`000004
ojVYZOlQ8B7o0000ob4Q8@;ooooo00SoZJVYob4Q8Ol0003o0000oc8b<_l0003oMgMgoeEEE@Oooooo
000kooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0?_ooool2o`0004_ooooo00?o
gMgMoa0@4?o^k^h04oooool00ol0003oooooooooo`0Iooooo`03onk^k_l@413ogMgM00Oooooo000k
ooooo`;o0000H_ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo04cooooo00?oMgMg
ofIVI_ooool04_ooool00ol0003oooooooooo`0Iooooo`03ofIVI_mgMgOooooo00Oooooo000koooo
o`03o`000?oooooooooo06;ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`28oooo
o`00>oooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo03Sooooo00?o0000oooooooo
ool0ROooool003_ooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`0fooooo`03o`00
0?oooooooooo08[ooooo000kooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0=Ooo
ool00ol0003oooooooooo`2;ooooo`00>oooool2o`0006Kooooo00?o0000ooooooooool0<oooool0
0ol0003oooooooooo`2<ooooo`00>oooool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo
03;ooooo00?o0000ooooooooool0S?ooool003_ooooo00?o0000ooooooooool0Ioooool00ol0003o
ooooooooo`0`ooooo`03o`000?oooooooooo08gooooo000kooooo`03o`000?oooooooooo06Sooooo
00?o0000ooooooooool0;_ooool00ol0003oooooooooo`2>ooooo`00>oooool2o`0006[ooooo00?o
0000ooooooooool0;Oooool00ol0003oooooooooo`2>ooooo`00>oooool00ol0003oooooooooo`1Y
ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0Soooool003_ooooo00?o0000oooo
ooooool0J_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo08oooooo000kooooo`03
o`000?oooooooooo06[ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`2@ooooo`00
5oooool2onk^kP?ooooo0_o^k^hMooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`2@ooooo`004Oooool03Om4A4Co0000o`000?lb<S;ogMgMooooooo^
k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o
0000oc8b<_o^k^h>ooooo`;o0000KOooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
097ooooo000Dooooo`09ogMgMolb<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00?o0000ooooooooool0
K?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo09;ooooo000Eooooo`07o`000?oo
oooooooooooooooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooo
oooooooooa0@400>ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`2Cooooo`005?ooool02OmgMgOo<S8booooooooooook^k^oeEEEOoMgMgoEEEEonk^
kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`00
0?oooooooooo06gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`2Cooooo`004Ooo
ool03Ol0003o8B4Qo`000?lb<S;oc<c<ooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Ooo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000003_ooool2o`0006oooooo
00?o0000ooooooooool08_ooool00ol0003oooooooooo`2Dooooo`004Oooool00ol0003ooooooooo
o`03ooooo`;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@00kooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`0Rooooo`03o`00
0?oooooooooo09Cooooo000Aooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo0ol000000ooooooo0000o`000002o`0000?ooooo
00?o0000ooooooooool0Koooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo09Gooooo
000Aooooo`Co00003?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1?ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0Koooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo09Gooooo000aooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool0U_ooool0037ooooo00?o0000ooooooooool00oooool01?l0003ooooooooo
ooooool2o`00077ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`2Fooooo`00<Ooo
ool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool00000Loooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo09Kooooo000`ooooo`;o00000oooool2o`0000Cooooo
00?o0000ooooooooool0LOooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo09Oooooo
000kooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`2Gooooo`00>oooool2o`0007?ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`2H
ooooo`00>oooool00ol0003oooooooooo`1booooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool0V?ooool003_ooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo09Wooooo000kooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`2Iooooo`00>oooool00ol0003oooooooooo`1dooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool0V_ooool003_ooooo0_l0001eooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool0V_ooool003_ooooo00?o0000ooooooooool0M?ooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo09_ooooo000kooooo`03o`000?oooooooooo07Go
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`2Kooooo`00>oooool00ol0003ooooo
ooooo`1eooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0Voooool001Oooooo0_o^
k^h3ooooo`;ok^k^7Oooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool0W?ooool0017ooooo1?l000002Ol@413oooooonk^k_mEEEGok^k^ooooooo^k^ko
EEEEonk^kP03ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPkooooo0_l0
001gooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0W?ooool001?ooooo00?o0000
ooooooooool00_ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00?o0000ooooooooool0M_ooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo09gooooo000Cooooo`03o`000?oooooooooo00?ooooo00?o
gMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100
3_ooool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
WOooool001?ooooo00?o0000ooooooooool00_ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000kooooo00?o0000oooooooo
ool0Moooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo09kooooo000Cooooo`0;o`00
0?ooooooooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000003_ooool2o`0007Wooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`2Nooooo`004oooool01?l0003oooooooooooooool2onk^kP?ooooo
0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400>ooooo`03
o`000?oooooooooo07Wooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`2Oooooo`00
4oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`?o00000_ooool2o`0000Cooooo00?o0000ooooooooool0N_ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo09oooooo000Aooooo`03oeEEEOmVIVKo000000gooooo
00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo00Co0000oooooooo
oooo00000_ooool01Ol0003ooooooooooooooooo000007cooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`2Pooooo`00<Oooool00ol0003oooooooooo`03ooooo`05o`000?oooooooooo
ooooool00000OOooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0:7ooooo000aoooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool2o`0007cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`2Rooooo`00<Oooool01?l0003oooooooooool00002oooo
o`05o`000?ooooooooooooooool00000O_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo0:?ooooo000`ooooo`;o00000oooool2o`0000Cooooo00?o0000ooooooooool0OOooool3o`00
00?ooooo00?o0000ooooooooool0Y?ooool003_ooooo00?o0000ooooooooool0Ooooool4o`000:Oo
oooo000kooooo`;o0000ooooool/ooooo`00>oooool00ol0003oooooooooo`3oooooob_ooooo000k
ooooo`03o`000?oooooooooo0?oooooo:oooool003_ooooo00?o0000ooooooooool0ooooool[oooo
o`00>oooool00ol0003oooooooooo`3oooooob_ooooo000kooooo`;o0000ooooool/ooooo`00>ooo
ool00ol0003oooooooooo`3oooooob_ooooo000kooooo`03o`000?oooooooooo0?oooooo:oooool0
03_ooooo00?o0000ooooooooool0ooooool[ooooo`006?ooool2onk^kP?ooooo0_o^k^hLooooo`;o
0000ooooool/ooooo`000_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`0=odA4
A?l0003o0000oc8b<_oMgMgoooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co0000
00So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPgooooo00?o0000ooooooooool0ooooool[
ooooo`001?ooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool02OmgMgOo<S8boooooooooooo
k^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0=ooooo`03o`000?oooooooooo0?oooooo:oooool000Cooooo00?o0000ooooooooool0
3oooool01ol0003ooooooooooooooooogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@41003Oooool00ol0003oooooooooo`3oooooob_ooooo0004oooo
o`03o`000?oooooooooo00kooooo00WoMgMgoc8b<_ooooooooooonk^k_mEEEGogMgMoeEEEOo^k^h0
1_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000003Oooool00ol0003o
ooooooooo`3oooooob_ooooo0004ooooo`03o`000?oooooooooo00_ooooo00go0000ob4Q8Ol0003o
<S8bolc<c?ooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000ooooooooool0
0_ooool01Ol0003ooooooooooooooooo000000gooooo0_l0003oooooobcooooo0004ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool00oooool2onk^kP?ooooo0_o^k^h5ooooo`03o`00
0?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03o`000?oooooooooo0?oo
oooo:oooool000Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`?o00000_ooool2o`0000?o
oooo00?o0000ooooooooool0ooooool[ooooo`000_ooool00omEEEGoIVIVo`00000=ooooo`Co0000
3?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`000?oooooo;Oooool003;ooooo00?o0000oooo
ooooool00oooool01?l0003oooooooooool0003oooooobgooooo000booooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooooooo0_l0003oooooobcooooo000booooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo0000ooooool]ooooo`00<Oooool2o`0000?ooooo0_l00003
ooooo`03o`000?oooooooooo0?oooooo:oooool003_ooooo00?o0000ooooooooool0ooooool[oooo
o`00>oooool2o`000?oooooo;?ooool003_ooooo00?o0000ooooooooool0ooooool[ooooo`00>ooo
ool00ol0003oooooooooo`3oooooob_ooooo000kooooo`03o`000?oooooooooo0?oooooo:oooool0
03_ooooo00?o0000ooooooooool0ooooool[ooooo`00>oooool2o`000?oooooo;?ooool003_ooooo
00?o0000ooooooooool0ooooool[ooooo`00>oooool00ol0003oooooooooo`3oooooob_ooooo000G
ooooo`;ok^k^0oooool2onk^kQgooooo00?o0000ooooooooool0ooooool[ooooo`004?ooool5o`00
00;ooooo00Ook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413ooooooooo
ooo^k^ko<S8bo`000?lb<S;ok^k^3_ooool2o`000?oooooo;?ooool0013ooooo00GoV9RHob4Q8Oo^
k^koooooodA4A003ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`3oooooob_ooooo000A
ooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`3oooooob_ooooo000B
ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo0?oooooo
:oooool001?ooooo00_oMgMgofIVI_ooooooooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oo
oooooooo0?oooooo:oooool001Cooooo00?o0000ooooooooool00_o^k^h3ooooo`;ok^k^1Oooool0
0ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41003_ooool2o`000?oooooo;?oo
ool0013ooooo00Go0000okZj^_ooooooV9RHoa0@400>ooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oooooooooo0?oooooo:oooool0013ooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c00<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP03ooooo`?o00000_ooool2o`0000Cooooo00?o0000ooooooooool0ooooool[ooooo`00
<Oooool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool00000ooooool]oooo
o`00<Oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooo`;o0000ooooool/oooo
o`00<Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0ooooool[ooooo`00<Oooool01?l0003oooooooooool00002ooooo`05o`000?oooooooooooooo
ool00000ooooool]ooooo`00<?ooool2o`0000?ooooo0_l00004ooooo`03o`000?oooooooooo0?oo
oooo:oooool003_ooooo00?o0000ooooooooool0ooooool[ooooo`00>oooool2o`000?oooooo;?oo
ool003_ooooo00?o0000ooooooooool0ooooool[ooooo`00>oooool00ol0003oooooooooo`3ooooo
ob_ooooo000kooooo`03o`000?oooooooooo0?oooooo:oooool003_ooooo00?o0000ooooooooool0
ooooool[ooooo`00>oooool2o`000?oooooo;?ooool003_ooooo00?o0000ooooooooool0ooooool[
ooooo`00>oooool00ol0003oooooooooo`3oooooob_ooooo000Hooooo`;ok^k^0oooool2onk^kQco
oooo00?o0000ooooooooool0ooooool[ooooo`0000?oooooo`000?l000000ol00005ooooo`;o8B4Q
1Oooool03Om4A4Co0000o`000?lb<S;ogMgMooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h0
0oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h=ooooo`;o0000ooooool/
ooooo`0000KooooooiRHV?lQ8B7ok^k^oooooom4A4@5ooooo`;o8B4Q2?ooool02OmgMgOo<S8boooo
ooooooook^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0=ooooo`03o`000?oooooooooo0?oooooo:oooool000;ooooo00?oV9RHob4Q
8Oo^k^h04Oooool01ol0003ooooooooooooooooogMgMo`000?oMgMd01oooool00ol0003ooooooooo
o`02ooooo`05oa0@4?ooooooooooooooool@41003Oooool00ol0003oooooooooo`3oooooob_ooooo
0003ooooo`03oiRHV?lQ8B7ok^k^00oooooo00WoMgMgoc8b<_ooooooooooonk^k_mEEEGogMgMoeEE
EOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000003Oooool0
0ol0003oooooooooo`3oooooob_ooooo0004ooooo`03ogMgMomVIVKooooo00_ooooo00go0000ob4Q
8Ol0003o<S8bolc<c?ooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool0ooooool[
ooooo`001Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo0_o^k^h3oooo
o`;ok^k^1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41003Oooool2
o`000?oooooo;?ooool00006ooooool0003o^[ZjoooooonHV9So410@3?ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0=ooooo`03o`00
0?oooooooooo0?oooooo:oooool00006oooooonHV9So410@o`000?lQ8B7oc<c<3?ooool4o`0000co
oooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo0ol00002oooo
o`;o00000oooool00ol0003oooooooooo`3oooooob_ooooo000booooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo0000ooooool]ooooo`00<_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;o0000ooooool/ooooo`00<_ooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool00000ooooool]ooooo`00<_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`000?oooooo;Oooool0037ooooo0_l00003ooooo`;o00000oooool00ol0
003oooooooooo`3oooooob_ooooo000kooooo`03o`000?oooooooooo0?oooooo:oooool003_ooooo
0_l0003oooooobcooooo000kooooo`03o`000?oooooooooo0?oooooo:oooool003_ooooo00?o0000
ooooooooool0ooooool[ooooo`00>oooool00ol0003oooooooooo`3oooooob_ooooo000kooooo`;o
0000ooooool/ooooo`00>oooool00ol0003oooooooooo`3oooooob_ooooo000kooooo`03o`000?oo
oooooooo0?oooooo:oooool003_ooooo00?o0000ooooooooool0ooooool[ooooo`005oooool2onk^
kP?ooooo0_o^k^hMooooo`03o`000?oooooooooo0?oooooo:oooool0013ooooo00GoV9RHoa0@4?l0
003o<S8bolc<c002ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co000000So
410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPkooooo0_l0003oooooobcooooo000@ooooo`05
oa0@4?nj^[[oooooogMgMolb<S800oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000
ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00?o0000ooooooooool0oooo
ool[ooooo`005?ooool00ol0003oooooooooo`02ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool0oooo
ool[ooooo`004oooool00onYZJWo410@ooooo`02ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_oo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003ooooo
ooooo`3oooooob_ooooo000Booooo`03oa0@4?l0003o^[Zj00;ooooo00Ook^k^oeEEEOo^k^kooooo
onk^k_mEEEGok^k^00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
00kooooo00?o0000ooooooooool0ooooool[ooooo`004oooool01?nj^[[o8B4Qooooooooool2onk^
kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400>
ooooo`;o0000ooooool/ooooo`004?ooool01Ol@413oV9RHoooooonj^[[o000000kooooo00?o0000
ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00?o0000ooooooooool0oooo
ool[ooooo`004?ooool01OnYZJWo410@o`000?l@413oZJVY00cooooo00?oEEEEofIVI_l000001?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo0ol00002ooooo`;o00001?ooool00ol0003ooooo
ooooo`3oooooob_ooooo000aooooo`04o`000?ooooooooooo`0000;ooooo00Go0000oooooooooooo
ooooo`00003oooooobgooooo000aooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo
oooo0_l0003oooooobcooooo000aooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`3oooooob_ooooo000aooooo`04o`000?ooooooooooo`0000;ooooo
00Go0000ooooooooooooooooo`00003oooooobgooooo000`ooooo`;o00000oooool2o`0000Cooooo
00?o0000ooooooooool0ooooool[ooooo`00>oooool00ol0003oooooooooo`3oooooob_ooooo000k
ooooo`;o0000ooooool/ooooo`00>oooool00ol0003oooooooooo`3oooooob_ooooo000kooooo`03
o`000?oooooooooo0?oooooo:oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool005Wooooo00?oMgMgofIVI_ooool01?ooool00ol0003ooooo
ooooo`02ooooo`03okZj^_lb<S;ooooo00Oooooo00Ko0000ooooooooooooooooofIVI_mgMgL=oooo
o`03o`000?nj^[[ooooo0>?ooooo001Hooooo`03omgMgOl@413ok^k^00Gooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`06ooooo`07o`000?ooooooooooooooooo^k^ko410@omgMg@0<
ooooo`;o<S8bi?ooool005Sooooo00?oEEEEoiRHV?ooool01Oooool01_l0003ooooooooooooooooo
V9RHoa0@40;o000000?oZJVYooooooooool01?ooool00ol0003oooooooooo`02ooooo`03ohN7QomV
IVKooooo00_ooooo00?oQhN7o`000?nj^[X01Oooool4o`000004oa0@4?ooooooooooooooo`Co0000
00?o410@ooooooooool00_ooool2ob4Q8@;ooooo00Goc<c<onk^k_ooooook^k^olc<c004ooooo`Co
000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kQ?ooooo00Ko410@oc8b<_l0003o0000
oa0@4?nYZJT2ooooo`06onk^k_mEEEGo0000o`000?m4A4Co^[Zj0oooool01OmVIVKo0000o`000?m4
A4Coc<c<08_ooooo001Hooooo`03o`000?oooooooooo00Gooooo00[o0000ooooooooooooooooo`00
0?nYZJWoEEEEoiRHV?mEEEGo^[Zj1Oooool00ol0003oooooooooo`02ooooo`03onk^k_l0003ooooo
00_ooooo00?oc<c<o`000?l@41001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Cooooo0_lQ8B42ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool01_l0003oZJVYoooooooooooo^[Zjo`0000;o
oooo00KoEEEEogMgMoooooook^k^ogMgMol@4102ooooo`06ofIVI_mgMgOooooooooooon7QhOo410@
Roooool005Sooooo00?o<S8booooooooool01Oooool02_l0003ooooooooooooooooo<S8bonk^k_nH
V9SoEEEEomgMgOl@4105ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo00?ogMgMo`000?oMgMd01oooool0
0ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41005?ooool01Onj^[[oQhN7ofIV
I_mVIVKo410@00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2>ooooo`00F?oo
ool00olb<S;oooooooooo`05ooooo`0;o`000?oooooooooooooooonj^[[oA4A4olc<c?lQ8B7ooooo
oa0@4?o<c<`01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`08ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_oo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000004oooool01_lb<S;o8B4Q
ogMgMomgMgOoQhN7onk^kP;ooooo1_l00002ooooo`03o`000?oooooooooo08kooooo001Hooooo`03
o`000?o^k^kooooo00Gooooo00_o0000ooooooooooooooooonk^k_l0003oooooo`000?ooooooIVIV
ohN7Q`04ooooo`03o`000?oooooooooo00;ooooo00?ok^k^o`000?ooool05Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Sooooo00Goc<c<onk^k_ooooook^k^olc<c006ooooo`03
o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Cooooo`06o`000?nj^[[ooooo
onk^k_mgMgOo00000_ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<P;ooooo00KoIVIVogMgMooo
ooooooooohN7Qol0002;ooooo`00F?ooool00omEEEGoMgMgooooo`05ooooo`08o`000?oooooooooo
oooooomVIVKoV9RHoooooolb<S82okZj^P03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0_ooool00omgMgOoEEEEooooo`03ooooo`Co00003_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Oo
oooo0ol00002ooooo`?o00001?ooool01_nYZJWo8B4Qo`000?l0003o<S8bo`0000;ooooo00Kok^k^
oeEEEOl0003o0000odA4A?o^k^h2ooooo`06onk^k_mVIVKo0000o`000?m4A4Co0000Roooool005So
oooo00?ogMgMoa0@4?o^k^h01Oooool00ol0003oooooooooo`04ooooo`03ofIVI_n7QhOooooo00Go
oooo00Oo0000ooooooooooooooooonk^k_l@413ogMgM00Gooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`2Tooooo`00FOooool00omgMgOoIVIVooooo`04ooooo`03o`000?oooooooooo00Cooooo00?oZJVY
odA4A?ooool01Oooool01_l0003oooooooooooooooooIVIVogMgM`Oooooo00?o0000ooooooooool0
2oooool00omEEEGoIVIVo`000005ooooo`03oeEEEOmVIVKo000001?ooooo00?oEEEEofIVI_l00000
1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo1?l00002ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0Y?ooool007gooooo00?o0000ooooooooool0??ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo0:Cooooo001jooooo`04o`000?ooooooooooo`0003kooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`2Tooooo`00Noooool2o`0003kooooo0_l0
0003ooooo`;o0000Y_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -2.14748*^9, 0, \
2.14748*^9}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0 1.90278e-14 [
[.32684 -0.0125 -16.5 -12.5 ]
[.32684 -0.0125 16.5 0 ]
[.54329 -0.0125 -16.5 -12.5 ]
[.54329 -0.0125 16.5 0 ]
[.75974 -0.0125 -22.5 -12.5 ]
[.75974 -0.0125 22.5 0 ]
[.97619 -0.0125 -16.5 -12.5 ]
[.97619 -0.0125 16.5 0 ]
[1.025 0 0 -6 ]
[1.025 0 64 6 ]
[.09789 .09514 -33 -6.25 ]
[.09789 .09514 0 6.25 ]
[.09789 .19028 -33 -6.25 ]
[.09789 .19028 0 6.25 ]
[.09789 .28542 -45 -6.25 ]
[.09789 .28542 0 6.25 ]
[.09789 .38056 -33 -6.25 ]
[.09789 .38056 0 6.25 ]
[.09789 .47569 -45 -6.25 ]
[.09789 .47569 0 6.25 ]
[.09789 .57083 -33 -6.25 ]
[.09789 .57083 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -56.4375 0 ]
[.5 .63053 56.4375 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 0 m
.32684 .00625 L
s
gsave
.32684 -0.0125 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 0 m
.54329 .00625 L
s
gsave
.54329 -0.0125 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 0 m
.75974 .00625 L
s
gsave
.75974 -0.0125 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 0 m
.15368 .00375 L
s
.19697 0 m
.19697 .00375 L
s
.24026 0 m
.24026 .00375 L
s
.28355 0 m
.28355 .00375 L
s
.37013 0 m
.37013 .00375 L
s
.41342 0 m
.41342 .00375 L
s
.45671 0 m
.45671 .00375 L
s
.5 0 m
.5 .00375 L
s
.58658 0 m
.58658 .00375 L
s
.62987 0 m
.62987 .00375 L
s
.67316 0 m
.67316 .00375 L
s
.71645 0 m
.71645 .00375 L
s
.80303 0 m
.80303 .00375 L
s
.84632 0 m
.84632 .00375 L
s
.88961 0 m
.88961 .00375 L
s
.9329 0 m
.9329 .00375 L
s
.0671 0 m
.0671 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09514 m
.11664 .09514 L
s
gsave
.09789 .09514 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(12) show
grestore
.11039 .19028 m
.11664 .19028 L
s
gsave
.09789 .19028 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.11039 .28542 m
.11664 .28542 L
s
gsave
.09789 .28542 -45 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.11039 .38056 m
.11664 .38056 L
s
gsave
.09789 .38056 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.11039 .47569 m
.11664 .47569 L
s
gsave
.09789 .47569 -45 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.11039 .57083 m
.11664 .57083 L
s
gsave
.09789 .57083 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(3) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.125 Mabswid
.11039 .01903 m
.11414 .01903 L
s
.11039 .03806 m
.11414 .03806 L
s
.11039 .05708 m
.11414 .05708 L
s
.11039 .07611 m
.11414 .07611 L
s
.11039 .11417 m
.11414 .11417 L
s
.11039 .13319 m
.11414 .13319 L
s
.11039 .15222 m
.11414 .15222 L
s
.11039 .17125 m
.11414 .17125 L
s
.11039 .20931 m
.11414 .20931 L
s
.11039 .22833 m
.11414 .22833 L
s
.11039 .24736 m
.11414 .24736 L
s
.11039 .26639 m
.11414 .26639 L
s
.11039 .30444 m
.11414 .30444 L
s
.11039 .32347 m
.11414 .32347 L
s
.11039 .3425 m
.11414 .3425 L
s
.11039 .36153 m
.11414 .36153 L
s
.11039 .39958 m
.11414 .39958 L
s
.11039 .41861 m
.11414 .41861 L
s
.11039 .43764 m
.11414 .43764 L
s
.11039 .45667 m
.11414 .45667 L
s
.11039 .49472 m
.11414 .49472 L
s
.11039 .51375 m
.11414 .51375 L
s
.11039 .53278 m
.11414 .53278 L
s
.11039 .55181 m
.11414 .55181 L
s
.11039 .58986 m
.11414 .58986 L
s
.11039 .60889 m
.11414 .60889 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -117.438 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.812 moveto
(H) show
69.000 13.812 moveto
(\\310) show
75.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.812 moveto
(\\310) show
87.000 13.812 moveto
(L) show
93.000 9.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
98.250 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
104.250 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12.) show
122.250 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
128.250 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
140.250 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
144.438 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
153.875 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
171.875 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.02499 0 L
.02605 0 L
.02721 0 L
.02846 0 L
.02961 0 L
.03068 0 L
.03279 0 L
.03396 0 L
.03506 0 L
.03636 0 L
.03756 0 L
.04 0 L
.04134 0 L
.04262 0 L
.045 0 L
.04633 0 L
.04753 0 L
.04866 0 L
.04988 0 L
.0521 0 L
.05335 0 L
.05472 0 L
.05605 0 L
.05749 0 L
.05883 0 L
.06005 0 L
.06244 0 L
.06369 0 L
.06505 0 L
.06639 0 L
.06783 0 L
.06917 0 L
.0704 0 L
.07281 0 L
.07417 0 L
.07543 0 L
.07693 0 L
.0783 0 L
.0811 0 L
.08263 0 L
.08408 0 L
.08657 0 L
.08782 0 L
.0892 0 L
.09164 0 L
.09392 0 L
.0953 0 L
.0966 0 L
.09906 0 L
Mistroke
.10043 0 L
.1017 0 L
.1031 0 L
.10458 0 L
.10585 0 L
.10723 0 L
.10967 0 L
.11105 0 L
.11252 0 L
.11517 0 L
.11646 0 L
.11786 0 L
.11909 0 L
.12039 0 L
.12286 0 L
.12514 0 L
.12734 0 L
.12971 0 L
.13195 0 L
.134 0 L
.13627 0 L
.13876 0 L
.14135 0 L
.14376 0 L
.1464 0 L
.14883 0 L
.15149 0 L
.15284 0 L
.15431 0 L
.15679 0 L
.15945 0 L
.16197 0 L
.16426 0 L
.16663 0 L
.16883 0 L
.17124 0 L
.17381 0 L
.17602 0 L
.17811 0 L
.18039 0 L
.18286 0 L
.18525 0 L
.18781 0 L
.19022 0 L
.19241 0 L
.19499 0 L
.19779 0 L
.20044 0 L
.20288 0 L
.20539 0 L
Mistroke
.20775 0 L
.21034 0 L
.21312 0 L
.21602 0 L
.21878 0 L
.22126 0 L
.22397 0 L
.22652 0 L
.22929 0 L
.2319 0 L
.23429 0 L
.23647 0 L
.23885 0 L
.24133 0 L
.24365 0 L
.24638 0 L
.24895 0 L
.25127 0 L
.25378 0 L
.25652 0 L
.25942 0 L
.2619 0 L
.26463 0 L
.26698 0 L
.26955 0 L
.27224 0 L
.27474 0 L
.27708 0 L
.27921 0 L
.28167 0 L
.28399 0 L
.28653 0 L
.2892 0 L
.29149 0 L
.29401 0 L
.29671 0 L
.29961 0 L
.30235 0 L
.30486 0 L
.30737 0 L
.30964 0 L
.31227 0 L
.31474 0 L
.31914 0 L
.32162 0 L
.32389 0 L
.32871 0 L
.33144 0 L
.33399 0 L
.33913 0 L
Mistroke
.34201 0 L
.34464 0 L
.34946 0 L
.3519 0 L
.35459 0 L
.35687 0 L
.35933 0 L
.36377 0 L
.36643 0 L
.36934 0 L
.37189 0 L
.37462 0 L
.37732 0 L
.37977 0 L
.38455 0 L
.38687 0 L
.38942 0 L
.39191 0 L
.39457 0 L
.39934 0 L
.40379 0 L
.40647 0 L
.40938 0 L
.41195 0 L
.41468 1e-05 L
.41983 1e-05 L
.42461 1e-05 L
.42949 2e-05 L
.43397 2e-05 L
.43889 3e-05 L
.44407 4e-05 L
.44859 5e-05 L
.4528 7e-05 L
.45741 9e-05 L
.46235 .00013 L
.46767 .00017 L
.47258 .00023 L
.47797 .00031 L
.48368 .00043 L
.48864 .00056 L
.49328 .00072 L
.49836 .00094 L
.50383 .00124 L
.50908 .0016 L
.51396 .00202 L
.51975 .00265 L
.525 .00336 L
.53473 .00513 L
.54007 .00642 L
.5451 .00786 L
Mistroke
.55488 .01147 L
.5652 .01668 L
.57402 .02248 L
.58369 .03053 L
.60323 .05286 L
.62415 .08586 L
.64399 .12328 L
.66555 .16387 L
.67561 .18005 L
.68111 .18762 L
.68628 .1937 L
.69103 .19834 L
.69539 .20171 L
.6977 .20314 L
.70023 .20441 L
.70277 .20537 L
.70415 .20577 L
.70544 .20604 L
.70672 .20624 L
.70736 .20631 L
.70807 .20636 L
.70933 .20639 L
.7105 .20634 L
.71121 .20628 L
.71188 .2062 L
.71314 .20598 L
.7145 .20567 L
.71598 .20521 L
.71848 .20421 L
.72114 .2028 L
.72592 .19944 L
.73048 .19528 L
.73476 .19057 L
.74452 .17727 L
.78316 .10608 L
.80278 .07115 L
.81316 .05546 L
.82426 .04127 L
.83499 .03015 L
.84475 .02211 L
.85456 .01582 L
.86384 .01128 L
.87354 .00775 L
.88382 .00507 L
.8926 .00346 L
.89759 .00276 L
.90226 .00223 L
.90723 .00176 L
.91264 .00135 L
.91742 .00106 L
Mistroke
.92251 .00082 L
.92755 .00063 L
.93212 .00049 L
.93646 .00039 L
.94104 .0003 L
.94523 .00024 L
.94984 .00018 L
.95407 .00014 L
.95793 .00011 L
.96249 8e-05 L
.96737 6e-05 L
.9719 5e-05 L
.97619 4e-05 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00H_ooool2onk^kP?ooooo0_o^
k^h]ooooo`;ok^k^0oooool2onk^kSKooooo0_o^k^h3ooooo`;ok^k^9?ooool2onk^kP?ooooo0_o^
k^iSooooo`00G?ooool03Om4A4Co0000o`000?lb<S;ogMgMooooooo^k^koEEEEonk^k_ooooook^k^
oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hHooooo`Co
000000Wo410@ooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?oo
ooooooooonk^k_lb<S;o0000oc8b<_o^k^hAooooo`Co000000?o410@ooooooooool00_ooool2ob4Q
8@Gooooo00goA4A4o`000?l0003o<S8bomgMgOooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^
00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^3_ooool5o`0000;ooooo
00Ook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413oooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^E?ooool005oooooo00WoMgMgoc8b<_ooooooooooonk^k_mEEEGogMgMoeEE
EOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool0
0ol0003oooooooooo`02ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool00ol0003oooooooooo`04ooooo`;o8B4Q
2?ooool02OmgMgOo<S8booooooooooook^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
0oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg05Cooooo001Pooooo`07o`000?oooooooooooooooooMgMgo0000omgMg@07
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Jooooo`03o`000?oo
oooooooo00?ooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?oo
ooooooooooooool@41004oooool00ol0003oooooooooo`0?ooooo`07o`000?oooooooooooooooooM
gMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400?
ooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@4100E?ooool005oooooo00WoMgMgoc8b<_ooooooooooonk^
k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000006_ooool00ol0003oooooooooo`02ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000004oooool00ol0003ooooooooo
o`0>ooooo`09ogMgMolb<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo0000013ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000005Cooooo001Looooo`0=o`000?lQ8B7o0000oc8b<_o<c<coooooonk^k_mEEEGok^k^
ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Jooooo`0;o`000?ooooooooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Ooo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000004oooool00ol0003ooooo
ooooo`0;ooooo`0=o`000?lQ8B7o0000oc8b<_o<c<coooooonk^k_mEEEGok^k^ooooooo^k^koEEEE
onk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Aooooo`0;
ogMgMomVIVKoooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool00000E?ooool005cooooo00?o0000ooooooooool0
0oooool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@400Jooooo`04o`000?ooooooooooooooo`;ok^k^0oooool2onk^kPGooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@01?ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`03ooooo`;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@01;ooooo00?o0000ooooooooool00_o^k^h3ooooo`;ok^k^1Ooo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100E?ooool005cooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
6_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Cooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool01Ol0003o^[ZjoooooonHV9So
410@00kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg05Cooooo001L
ooooo`Co00003?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?oo
ool00ol0003oooooooooo`0=ooooo`03oeEEEOmVIVKo000000gooooo00?oEEEEofIVI_l000001?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo0_l00007ooooo`03oeEEEOmVIVKo000000gooooo
1?l0000<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`;o
00001?ooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo00?oEEEEofIVI_l000001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Sooooo0_l0001:ooooo`00P?ooool00ol0003oooooooooo`0`oooo
o`04o`000?ooooooooooo`0003Wooooo00Co0000oooooooooooo00009oooool01?l0003ooooooooo
ool00019ooooo`00N_ooool4o`0000?ooooo00?o0000ooooooooool0:_ooool4o`000005ooooool0
003oooooooooool00000=?ooool4o`000005ooooool0003oooooooooool000008_ooool4o`000005
ooooool0003oooooooooool00000BOooool0087ooooo00?o0000ooooooooool0;oooool3o`0003[o
oooo0ol0000Xooooo`?o0000B_ooool007oooooo00Co0000oooooooooooo0000<Oooool00ol0003o
ooooooooo`0jooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool03_ooool00omgMgOo
IVIVooooo`0^ooooo`03ofIVI_mgMgOooooo00Oooooo001oooooo`Co0000<_ooool00ol0003ooooo
ooooo`0jooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool03?ooool00ooMgMgo410@
onk^kP0_ooooo`03onk^k_l@413ogMgM00Oooooo003ooooooa_ooooo0_l00002ooooo`;o00003?oo
ool01?mEEEGoV9RHooooooooool2o`0000;ooooo00Oo0000oooooooooooo0000oa0@4?o^k^koEEEE
00;o000000?oA4A4okZj^_ooool00_ooool01OnHV9So0000o`000?m4A4Co^[Zj00;ooooo00Sok^k^
oeEEEOl0003o0000odA4A?nj^[[ooooooa0@40Go00000oooool02?l@413o<S8bo`000?l0003o410@
ojVYZOn7QhOoIVIV1oooool00?oooooo6oooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@cooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`08o`000?ooooooEEEEogMg
Moooooook^k^ogMgMol@4103ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000_ooool01_mEEEGoMgMg
ooooooo^k^koMgMgoa0@40?ooooo00?o0000ooooooooool01?ooool02?l0003oZJVYoooooooooooo
^[Zjo`000?o^k^ko00001oooool0023ooooolOl0000:ooooo`04omgMgOl0003o410@olc<c0gooooo
00?o<S8booooooooool00_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo000000So
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Go
oooo00Oo^[ZjohN7QomVIVKoIVIVoa0@4?oooooo000000Oooooo000Vooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01Oooool;o`0000;ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`07ooooo`_o00002_ooool00ol0003oooooooooo`0=ooooo`04onk^k_lQ8B7o410@
onk^kPgooooo00?o<S8booooooooool00_ooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooo000000Go00000oooool00ol0003oooooooooo`04ooooo`Ko00000oooool00ol0003ooooooooo
o`04ooooo`08oc8b<_lQ8B7oMgMgogMgMon7QhOok^k^ooooool00007ooooo`00>oooool00ol0003o
ooooooooo`0aooooo`03o`000?oooooooooo02oooooo1Ol0000aooooo`03o`000?oooooooooo01Oo
oooo1Ol0000Eooooo`03o`000?oooooooooo00gooooo00Co8B4QogMgMomgMgOo<S8b3Oooool00ol0
003ok^k^ooooo`02ooooo`0>o`000?o<c<coc<c<o`000?nYZJWogMgMob4Q8OooooooEEEEohN7Qoo^
k^koooooohN7Qolb<S83ooooo`03o`000?oooooooooo00Cooooo00KoEEEEohN7Qoo^k^koooooohN7
Qolb<S83ooooo`03o`000?lb<S;ogMgM00Cooooo00So0000okZj^_ooooook^k^ogMgMol0003ok^k^
o`0000Oooooo000kooooo`03o`000?oooooooooo06Sooooo0_l00017ooooo`;o0000:Oooool2o`00
00;ooooo0_l0000<ooooo`0?oeEEEOmgMgOoooooooooool@413o0000ob4Q8Ol0003oMgMgoa0@4?l0
003oZJVYooooooo^k^koEEEE00;o000000CoA4A4onk^k_oooooo410@1Ol00003ooooo`06onk^k_mE
EEGo0000o`000?m4A4Cok^k^0_ooool2o`000004ojVYZOlQ8B7o0000ob4Q8@;ooooo00SoZJVYob4Q
8Ol0003o0000oc8b<_l0003oMgMgoeEEE@Oooooo000kooooo`03o`000?oooooooooo06[ooooo00?o
0000ooooooooool0@_ooool2o`0003gooooo00?ogMgMoa0@4?o^k^h04oooool00ol0003ooooooooo
o`0Iooooo`03onk^k_l@413ogMgM00Oooooo000kooooo`;o0000K?ooool00ol0003oooooooooo`10
ooooo`03o`000?oooooooooo03kooooo00?oMgMgofIVI_ooool04_ooool00ol0003oooooooooo`0I
ooooo`03ofIVI_mgMgOooooo00Oooooo000kooooo`03o`000?oooooooooo06cooooo00?o0000oooo
ooooool0?_ooool00ol0003oooooooooo`1jooooo`00>oooool00ol0003oooooooooo`1]ooooo`03
o`000?oooooooooo03cooooo00?o0000ooooooooool0Noooool003_ooooo00?o0000ooooooooool0
K_ooool00ol0003oooooooooo`0iooooo`;o0000O_ooool003_ooooo00?o0000ooooooooool0Kooo
ool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo07kooooo000kooooo`;o0000LOooool0
0ol0003oooooooooo`0eooooo`03o`000?oooooooooo07oooooo000kooooo`03o`000?oooooooooo
077ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`1oooooo`00>oooool00ol0003o
ooooooooo`1booooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0P?ooool003_ooooo
00?o0000ooooooooool0Loooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo083ooooo
000kooooo`;o0000M?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo087ooooo000k
ooooo`03o`000?oooooooooo07Cooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`22
ooooo`00>oooool00ol0003oooooooooo`1eooooo`03o`000?oooooooooo02cooooo00?o0000oooo
ooooool0Poooool003_ooooo00?o0000ooooooooool0MOooool00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo08Cooooo000Gooooo`;ok^k^0oooool2onk^kQgooooo00?o0000ooooooooool0
M_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo08Cooooo000Aooooo`0=odA4A?l0
003o0000oc8b<_oMgMgoooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co000000So
410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPkooooo0_l0001gooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool0QOooool001Cooooo00WoMgMgoc8b<_ooooooooooonk^k_mEEEGo
gMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3_ooool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0
QOooool001Gooooo00Oo0000ooooooooooooooooomgMgOl0003ogMgM00Oooooo00?o0000oooooooo
ool00_ooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool0N?ooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo08Kooooo000Dooooo`09ogMgMolb<S;ooooooooo
ooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000kooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo08Oooooo000Aooooo`0=o`000?lQ8B7o0000oc8b<_o<c<coooooonk^k_mEEEGok^k^
ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`;o0000N_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo08Oooooo
000Aooooo`03o`000?oooooooooo00?ooooo0_o^k^h3ooooo`;ok^k^1Oooool00ol0003ooooooooo
o`02ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`1iooooo`03o`00
0?oooooooooo02?ooooo00?o0000ooooooooool0R?ooool0017ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool3o`000003oooo
ool0003o000000;o00000oooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool0R?ooool0017ooooo1?l0000<ooooo`03oeEEEOmVIVKo000000Cooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP04ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003o
ooooooooo`1kooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0ROooool0037ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo07_ooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`29ooooo`00<Oooool00ol0003ooooooooo
o`03ooooo`04o`000?ooooooooooooooo`;o0000OOooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo08[ooooo000aooooo`04o`000?ooooooooooo`0000;ooooo00Go0000oooooooooooo
ooooo`00001nooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0R_ooool0033ooooo
0_l00003ooooo`;o00001?ooool00ol0003oooooooooo`1mooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool0Roooool003_ooooo00?o0000ooooooooool0OOooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo08_ooooo000kooooo`;o0000Ooooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo08cooooo000kooooo`03o`000?oooooooooo07kooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`2<ooooo`00>oooool00ol0003oooooooooo`1oooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool0SOooool003_ooooo00?o0000ooooooooool0
Ooooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo08kooooo000kooooo`03o`000?oo
oooooooo083ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`2>ooooo`00>oooool2
o`00087ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`2?ooooo`00>oooool00ol0
003oooooooooo`21ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0Soooool003_o
oooo00?o0000ooooooooool0POooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo093o
oooo000kooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`2@ooooo`005oooool2onk^kP?ooooo0_o^k^hMooooo`03o`000?oooooooooo08;ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`2Aooooo`004Oooool4o`000009oa0@4?oooooo
k^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8b
o`000?lb<S;ok^k^3_ooool2o`0008Cooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`2Aooooo`004oooool00ol0003oooooooooo`02ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_oo
ool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool00ol0003ooooo
ooooo`24ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0T_ooool001?ooooo00?o
0000ooooooooool00oooool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go
410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo08Gooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`2Booooo`004oooool00ol0003oooooooooo`02ooooo`05onk^k_mE
EEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
00003_ooool00ol0003oooooooooo`26ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool0Toooool001?ooooo00_o0000ooooooooooooooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^
kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000>ooooo`;o0000
Qoooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo09Cooooo000Cooooo`04o`000?oo
ooooooooooooo`;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@413ooooo
oooooooooooo410@00kooooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo09Gooooo000Cooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo0ol00002ooooo`;o00001?ooool00ol0003o
ooooooooo`28ooooo`03o`000?oooooooooo00Gooooo0_l0002Hooooo`004Oooool00omEEEGoIVIV
o`00000=ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`04
o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`00002;ooooo`;o00001?ooool0
0ol0003oooooooooo`2Hooooo`00<Oooool00ol0003oooooooooo`03ooooo`05o`000?oooooooooo
ooooool00000SOooool4o`0009_ooooo000aooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00_ooool2o`000?oooooo;?ooool0037ooooo00Co0000oooooooooooo00000_ooool01Ol0
003ooooooooooooooooo00000?oooooo;Oooool0033ooooo0_l00003ooooo`;o00001?ooool00ol0
003oooooooooo`3oooooob_ooooo000kooooo`03o`000?oooooooooo0?oooooo:oooool003_ooooo
0_l0003oooooobcooooo000kooooo`03o`000?oooooooooo0?oooooo:oooool003_ooooo00?o0000
ooooooooool0ooooool[ooooo`00>oooool00ol0003oooooooooo`3oooooob_ooooo000kooooo`03
o`000?oooooooooo0?oooooo:oooool003_ooooo0_l0003oooooobcooooo000kooooo`03o`000?oo
oooooooo0?oooooo:oooool003_ooooo00?o0000ooooooooool0ooooool[ooooo`00>oooool00ol0
003oooooooooo`3oooooob_ooooo000Hooooo`;ok^k^0oooool2onk^kQcooooo0_l0003oooooobco
oooo0002ooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo00goA4A4o`000?l0003o
<S8bomgMgOooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^3Oooool00ol0003oooooooooo`3oooooob_ooooo0004oooo
o`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`09ogMgMolb<S;oooooooooooo^k^koEEEEomgM
gOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00go
oooo00?o0000ooooooooool0ooooool[ooooo`001?ooool00ol0003oooooooooo`0?ooooo`07o`00
0?oooooooooooooooooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooo
oooooooooooooa0@400=ooooo`03o`000?oooooooooo0?oooooo:oooool000Cooooo00?o0000oooo
ooooool03_ooool02OmgMgOo<S8booooooooooook^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000=ooooo`03o`000?oooooooooo0?oo
oooo:oooool000Cooooo00?o0000ooooooooool02oooool03Ol0003o8B4Qo`000?lb<S;oc<c<oooo
ooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000003Oooool2o`000?oooooo;?ooool000Cooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`03ooooo`;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@00gooooo00?o0000ooooooooool0ooooool[ooooo`00
1?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo0ol00002ooooo`;o00000oooool00ol0003o
ooooooooo`3oooooob_ooooo0002ooooo`03oeEEEOmVIVKo000000gooooo1?l0000<ooooo`03oeEE
EOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo0000ooooool]ooooo`00<_ooool00ol0003oooooooooo`03oooo
o`04o`000?ooooooooooo`000?oooooo;Oooool003;ooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooooooool2o`000?oooooo;?ooool003;ooooo00Co0000oooooooooooo00000_ooool0
1?l0003oooooooooool0003oooooobgooooo000aooooo`;o00000oooool2o`0000?ooooo00?o0000
ooooooooool0ooooool[ooooo`00>oooool00ol0003oooooooooo`3oooooob_ooooo000kooooo`;o
0000ooooool/ooooo`00>oooool00ol0003oooooooooo`3oooooob_ooooo000kooooo`03o`000?oo
oooooooo0?oooooo:oooool003_ooooo00?o0000ooooooooool0ooooool[ooooo`00>oooool00ol0
003oooooooooo`3oooooob_ooooo000kooooo`;o0000ooooool/ooooo`00>oooool00ol0003ooooo
ooooo`3oooooob_ooooo000kooooo`03o`000?oooooooooo0?oooooo:oooool001Oooooo0_o^k^h3
ooooo`;ok^k^7Oooool00ol0003oooooooooo`3oooooob_ooooo000@ooooo`Go00000_ooool01oo^
k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o
0000oc8b<_o^k^h>ooooo`;o0000ooooool/ooooo`004?ooool01OnHV9So8B4Qonk^k_ooooooA4A4
00?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oooooooooo0?oooooo:oooool0017ooooo00?oV9RH
ob4Q8Oo^k^h01Oooool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo0?oooooo:oooool001;ooooo00?oV9RH
ob4Q8Oo^k^h00oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool0ooooool[ooooo`004ooo
ool02omgMgOoIVIVooooooooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool0oooo
ool[ooooo`005?ooool00ol0003oooooooooo`02onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooo
oooo00;ooooo00Go410@oooooooooooooooooa0@400>ooooo`;o0000ooooool/ooooo`004?ooool0
1Ol0003o^[ZjoooooonHV9So410@00kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00kooooo00?o0000ooooooooool0ooooool[ooooo`004?ooool01OnHV9So410@o`00
0?lQ8B7oc<c<00cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?o
oooo0ol00002ooooo`;o00001?ooool00ol0003oooooooooo`3oooooob_ooooo000aooooo`04o`00
0?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`00003oooooobgooooo000aooooo`03
o`000?oooooooooo00?ooooo00Co0000oooooooooooooooo0_l0003oooooobcooooo000aooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3oooooob_o
oooo000aooooo`04o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`00003ooooo
obgooooo000`ooooo`;o00000oooool2o`0000Cooooo00?o0000ooooooooool0ooooool[ooooo`00
>oooool00ol0003oooooooooo`3oooooob_ooooo000kooooo`;o0000ooooool/ooooo`00>oooool0
0ol0003oooooooooo`3oooooob_ooooo000kooooo`03o`000?oooooooooo0?oooooo:oooool003_o
oooo00?o0000ooooooooool0ooooool[ooooo`00>oooool00ol0003oooooooooo`3oooooob_ooooo
000kooooo`;o0000ooooool/ooooo`00>oooool00ol0003oooooooooo`3oooooob_ooooo000koooo
o`03o`000?oooooooooo0?oooooo:oooool001Sooooo0_o^k^h3ooooo`;ok^k^7?ooool00ol0003o
ooooooooo`3oooooob_ooooo00000ooooooo0000o`000003o`0000Gooooo0_lQ8B45ooooo`0=odA4
A?l0003o0000oc8b<_oMgMgoooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co0000
00So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPgooooo0_l0003oooooobcooooo00001_oo
ooooV9RHob4Q8Oo^k^koooooodA4A0Gooooo0_lQ8B48ooooo`09ogMgMolb<S;oooooooooooo^k^ko
EEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00gooooo00?o0000ooooooooool0ooooool[ooooo`000_ooool00onHV9So8B4Qonk^kP0Aoooo
o`07o`000?oooooooooooooooooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go
410@oooooooooooooooooa0@400=ooooo`03o`000?oooooooooo0?oooooo:oooool000?ooooo00?o
V9RHob4Q8Oo^k^h03oooool02OmgMgOo<S8booooooooooook^k^oeEEEOoMgMgoEEEEonk^kP06oooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000=ooooo`03o`000?oooooo
oooo0?oooooo:oooool000Cooooo00?oMgMgofIVI_ooool02oooool03Ol0003o8B4Qo`000?lb<S;o
c<c<ooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000003Oooool00ol0003oooooooooo`3oooooob_ooooo0005oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00oooool2onk^kP?ooooo0_o^k^h5oooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400=ooooo`;o0000ooooool/
ooooo`0000Koooooo`000?nj^[[ooooooiRHV?l@410<ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00gooooo00?o0000ooooooooool0
ooooool[ooooo`0000KooooooiRHV?l@413o0000ob4Q8Oo<c<`<ooooo`Co00003?ooool00omEEEGo
IVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool3o`0000;ooooo0_l00003oooo
o`03o`000?oooooooooo0?oooooo:oooool003;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool0003oooooobgooooo000booooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_l0003oooooobcooooo000booooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`00003oooooobgooooo000booooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo0000ooooool]ooooo`00<Oooool2o`0000?ooooo0_l00003ooooo`03o`000?oooooooooo
0?oooooo:oooool003_ooooo00?o0000ooooooooool0ooooool[ooooo`00>oooool2o`000?oooooo
;?ooool003_ooooo00?o0000ooooooooool0ooooool[ooooo`00>oooool00ol0003oooooooooo`3o
ooooob_ooooo000kooooo`03o`000?oooooooooo0?oooooo:oooool003_ooooo0_l0003oooooobco
oooo000kooooo`03o`000?oooooooooo0?oooooo:oooool003_ooooo00?o0000ooooooooool0oooo
ool[ooooo`00>oooool00ol0003oooooooooo`3oooooob_ooooo000Gooooo`;ok^k^0oooool2onk^
kQgooooo00?o0000ooooooooool0ooooool[ooooo`004?ooool01OnHV9So410@o`000?lb<S;oc<c<
00;ooooo00Ook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413ooooooooo
ooo^k^ko<S8bo`000?lb<S;ok^k^3_ooool2o`000?oooooo;?ooool0013ooooo00Go410@okZj^_oo
ooooMgMgoc8b<P03ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`3oooooob_ooooo000D
ooooo`03o`000?oooooooooo00;ooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`3oooooob_ooooo000C
ooooo`03ojVYZOl@413ooooo00;ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo0?oooooo
:oooool001;ooooo00?o410@o`000?nj^[X00_ooool01oo^k^koEEEEonk^k_ooooook^k^oeEEEOo^
k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000003_ooool00ol0
003oooooooooo`3oooooob_ooooo000Cooooo`04okZj^_lQ8B7oooooooooo`;ok^k^0oooool2onk^
kPGooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00kooooo0_l0003o
ooooobcooooo000@ooooo`05oa0@4?nHV9SooooookZj^_l000003_ooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`3oooooob_ooooo000@
ooooo`05ojVYZOl@413o0000oa0@4?nYZJT03?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00oooool3o`0000;ooooo0_l00004ooooo`03o`000?oooooooooo0?oooooo
:oooool0037ooooo00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo00000?oo
oooo;Oooool0037ooooo00?o0000ooooooooool00oooool01?l0003oooooooooooooool2o`000?oo
oooo;?ooool0037ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo0?oooooo:oooool0037ooooo00Co0000oooooooooooo00000_ooool01Ol0003ooooo
oooooooooooo00000?oooooo;Oooool0033ooooo0_l00003ooooo`;o00001?ooool00ol0003ooooo
ooooo`3oooooob_ooooo000kooooo`03o`000?oooooooooo0?oooooo:oooool003_ooooo0_l0003o
ooooobcooooo000kooooo`03o`000?oooooooooo0?oooooo:oooool003_ooooo00?o0000oooooooo
ool0ooooool[ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00FOooool00omgMgOoIVIVooooo`04ooooo`03o`000?oooooooooo00;ooooo
00?o^[Zjoc8b<_ooool01oooool01_l0003oooooooooooooooooIVIVogMgM`gooooo00?o0000okZj
^_ooool0hoooool005Sooooo00?ogMgMoa0@4?o^k^h01Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Kooooo00Oo0000ooooooooooooooooonk^k_l@413ogMgM00cooooo0_lb<S;T
ooooo`00F?ooool00omEEEGoV9RHooooo`05ooooo`06o`000?oooooooooooooooonHV9So410@0_l0
00000onYZJWoooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?oQhN7ofIVI_ooool02ooo
ool00on7QhOo0000okZj^P05ooooo`Co000000?o410@ooooooooool01Ol00005ooooo`;o8B4Q0_oo
ool01Oo<c<cok^k^ooooooo^k^koc<c<00Cooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`00
0?lb<S;ok^k^4oooool01_l@413o<S8bo`000?l0003o410@ojVYZ@;ooooo00Kok^k^oeEEEOl0003o
0000odA4A?nj^[X3ooooo`05ofIVI_l0003o0000odA4A?o<c<`0Roooool005Sooooo00?o0000oooo
ooooool01Oooool02_l0003ooooooooooooooooo0000ojVYZOmEEEGoV9RHoeEEEOnj^[X5ooooo`03
o`000?oooooooooo00;ooooo00?ok^k^o`000?ooool02oooool00oo<c<co0000oa0@4007ooooo`03
o`000?oooooooooo00;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`;o8B4Q0_ooool01Oo^
k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg01?ooooo00Ko0000ojVYZOoooooooooookZj^_l00002ooooo`06oeEEEOmgMgOoooooonk^
k_mgMgOo410@0_ooool01_mVIVKoMgMgooooooooooooQhN7oa0@48_ooooo001Hooooo`03oc8b<_oo
oooooooo00Gooooo00[o0000oooooooooooooooooc8b<_o^k^koV9RHoeEEEOoMgMgo410@1Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00oooool0
0onHV9So8B4Qonk^kP0;ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@01Cooooo00Go^[ZjohN7QomVIVKoIVIVoa0@4002ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0S_ooool005Sooooo00?o<S8booooooooool01Ooo
ool02ol0003ooooooooooooooooo^[ZjodA4A?o<c<co8B4Qooooool@413oc<c<00Cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Cooooo00?oV9RH
ob4Q8Oo^k^h02Oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000001?ooooo00Ko<S8bob4Q8OmgMgOoMgMgohN7Qoo^k^h2oooo
o`Ko00000_ooool00ol0003oooooooooo`2>ooooo`00F?ooool00ol0003ok^k^ooooo`05ooooo`0;
o`000?ooooooooooooooooo^k^ko0000ooooool0003oooooofIVI_n7QhL01?ooool00ol0003ooooo
ooooo`02ooooo`03onk^k_l0003ooooo01Gooooo00?o0000ooooooooool01Oooool00omgMgOoIVIV
ooooo`08ooooo`05olc<c?o^k^koooooonk^k_o<c<`01_ooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000004oooool01_l0003o^[Zjooooooo^k^koMgMgo`0000;ooooo00Ko
EEEEohN7Qoo^k^koooooohN7Qolb<S82ooooo`06ofIVI_mgMgOooooooooooon7QhOo0000Roooool0
05Sooooo00?oEEEEogMgMoooool01Oooool02?l0003oooooooooooooooooIVIVoiRHV?oooooo<S8b
0_nj^[X00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?oMgMgoeEEEOooool0
0oooool4o`0000kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4007ooooo`?o00000_ooool3o`0000Co
oooo00KoZJVYob4Q8Ol0003o0000oc8b<_l00002ooooo`06onk^k_mEEEGo0000o`000?m4A4Cok^k^
0_ooool01_o^k^koIVIVo`000?l0003oA4A4o`0008_ooooo001Hooooo`03omgMgOl@413ok^k^00Go
oooo00?o0000ooooooooool01?ooool00omVIVKoQhN7ooooo`05ooooo`07o`000?oooooooooooooo
ooo^k^ko410@omgMg@05ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool0
1Ol0003o^[ZjoooooonHV9So410@01Cooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2Tooooo`00FOoo
ool00omgMgOoIVIVooooo`04ooooo`03o`000?oooooooooo00Cooooo00?oZJVYodA4A?ooool01Ooo
ool01_l0003oooooooooooooooooIVIVogMgM`Oooooo00?o0000ooooooooool02oooool00omEEEGo
IVIVo`000004ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`04_ooool00omEEEGoIVIVo`000004oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h00_ooool4o`0000;ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`2Tooooo`00OOooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0Y?ooool007[ooooo00Co0000oooooooooooo0000?_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo0:Cooooo001kooooo`;o0000?_ooool2o`0000?o
oooo0_l0002Vooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -2.14748*^9, 0, \
2.14748*^9}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0 1.90278e-14 [
[.32684 -0.0125 -16.5 -12.5 ]
[.32684 -0.0125 16.5 0 ]
[.54329 -0.0125 -16.5 -12.5 ]
[.54329 -0.0125 16.5 0 ]
[.75974 -0.0125 -22.5 -12.5 ]
[.75974 -0.0125 22.5 0 ]
[.97619 -0.0125 -16.5 -12.5 ]
[.97619 -0.0125 16.5 0 ]
[1.025 0 0 -6 ]
[1.025 0 64 6 ]
[.09789 .09514 -33 -6.25 ]
[.09789 .09514 0 6.25 ]
[.09789 .19028 -33 -6.25 ]
[.09789 .19028 0 6.25 ]
[.09789 .28542 -45 -6.25 ]
[.09789 .28542 0 6.25 ]
[.09789 .38056 -33 -6.25 ]
[.09789 .38056 0 6.25 ]
[.09789 .47569 -45 -6.25 ]
[.09789 .47569 0 6.25 ]
[.09789 .57083 -33 -6.25 ]
[.09789 .57083 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -56.4375 0 ]
[.5 .63053 56.4375 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 0 m
.32684 .00625 L
s
gsave
.32684 -0.0125 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 0 m
.54329 .00625 L
s
gsave
.54329 -0.0125 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 0 m
.75974 .00625 L
s
gsave
.75974 -0.0125 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 0 m
.15368 .00375 L
s
.19697 0 m
.19697 .00375 L
s
.24026 0 m
.24026 .00375 L
s
.28355 0 m
.28355 .00375 L
s
.37013 0 m
.37013 .00375 L
s
.41342 0 m
.41342 .00375 L
s
.45671 0 m
.45671 .00375 L
s
.5 0 m
.5 .00375 L
s
.58658 0 m
.58658 .00375 L
s
.62987 0 m
.62987 .00375 L
s
.67316 0 m
.67316 .00375 L
s
.71645 0 m
.71645 .00375 L
s
.80303 0 m
.80303 .00375 L
s
.84632 0 m
.84632 .00375 L
s
.88961 0 m
.88961 .00375 L
s
.9329 0 m
.9329 .00375 L
s
.0671 0 m
.0671 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09514 m
.11664 .09514 L
s
gsave
.09789 .09514 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(12) show
grestore
.11039 .19028 m
.11664 .19028 L
s
gsave
.09789 .19028 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.11039 .28542 m
.11664 .28542 L
s
gsave
.09789 .28542 -45 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.11039 .38056 m
.11664 .38056 L
s
gsave
.09789 .38056 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.11039 .47569 m
.11664 .47569 L
s
gsave
.09789 .47569 -45 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.11039 .57083 m
.11664 .57083 L
s
gsave
.09789 .57083 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(3) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.125 Mabswid
.11039 .01903 m
.11414 .01903 L
s
.11039 .03806 m
.11414 .03806 L
s
.11039 .05708 m
.11414 .05708 L
s
.11039 .07611 m
.11414 .07611 L
s
.11039 .11417 m
.11414 .11417 L
s
.11039 .13319 m
.11414 .13319 L
s
.11039 .15222 m
.11414 .15222 L
s
.11039 .17125 m
.11414 .17125 L
s
.11039 .20931 m
.11414 .20931 L
s
.11039 .22833 m
.11414 .22833 L
s
.11039 .24736 m
.11414 .24736 L
s
.11039 .26639 m
.11414 .26639 L
s
.11039 .30444 m
.11414 .30444 L
s
.11039 .32347 m
.11414 .32347 L
s
.11039 .3425 m
.11414 .3425 L
s
.11039 .36153 m
.11414 .36153 L
s
.11039 .39958 m
.11414 .39958 L
s
.11039 .41861 m
.11414 .41861 L
s
.11039 .43764 m
.11414 .43764 L
s
.11039 .45667 m
.11414 .45667 L
s
.11039 .49472 m
.11414 .49472 L
s
.11039 .51375 m
.11414 .51375 L
s
.11039 .53278 m
.11414 .53278 L
s
.11039 .55181 m
.11414 .55181 L
s
.11039 .58986 m
.11414 .58986 L
s
.11039 .60889 m
.11414 .60889 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -117.438 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.812 moveto
(H) show
69.000 13.812 moveto
(\\310) show
75.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.812 moveto
(\\310) show
87.000 13.812 moveto
(L) show
93.000 9.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
98.250 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
104.250 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13.) show
122.250 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
128.250 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
140.250 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
144.438 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
153.875 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
171.875 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.02499 0 L
.02605 0 L
.02721 0 L
.02846 0 L
.03068 0 L
.03279 0 L
.03527 0 L
.03652 0 L
.0379 0 L
.03907 0 L
.04033 0 L
.04262 0 L
.04393 0 L
.04516 0 L
.04661 0 L
.04793 0 L
.05037 0 L
.05171 0 L
.05297 0 L
.05534 0 L
.05752 0 L
.05992 0 L
.06112 0 L
.06244 0 L
.0638 0 L
.06527 0 L
.06657 0 L
.06795 0 L
.06918 0 L
.07055 0 L
.07296 0 L
.07442 0 L
.07576 0 L
.0772 0 L
.07878 0 L
.08144 0 L
.08289 0 L
.08424 0 L
.08551 0 L
.08689 0 L
.08939 0 L
.09183 0 L
.09407 0 L
.0965 0 L
.09788 0 L
.09918 0 L
.10178 0 L
.10324 0 L
.10458 0 L
Mistroke
.10709 0 L
.10936 0 L
.11198 0 L
.11445 0 L
.11674 0 L
.11885 0 L
.12116 0 L
.1236 0 L
.12608 0 L
.12872 0 L
.13122 0 L
.1335 0 L
.13617 0 L
.13768 0 L
.13907 0 L
.14163 0 L
.14434 0 L
.14673 0 L
.14925 0 L
.15139 0 L
.15374 0 L
.15627 0 L
.15898 0 L
.16153 0 L
.16385 0 L
.1662 0 L
.16837 0 L
.17075 0 L
.17327 0 L
.17545 0 L
.1775 0 L
.17974 0 L
.18214 0 L
.1847 0 L
.18742 0 L
.18974 0 L
.1923 0 L
.19504 0 L
.198 0 L
.2008 0 L
.20336 0 L
.20578 0 L
.20803 0 L
.21051 0 L
.21315 0 L
.21593 0 L
.21856 0 L
.22091 0 L
.22347 0 L
.22582 0 L
Mistroke
.22835 0 L
.23074 0 L
.23292 0 L
.23547 0 L
.23826 0 L
.24088 0 L
.24332 0 L
.24608 0 L
.24867 0 L
.25099 0 L
.25351 0 L
.25626 0 L
.25916 0 L
.26164 0 L
.26436 0 L
.26687 0 L
.26961 0 L
.27219 0 L
.27457 0 L
.27909 0 L
.28137 0 L
.28388 0 L
.28659 0 L
.28908 0 L
.29181 0 L
.29468 0 L
.29718 0 L
.29951 0 L
.30207 0 L
.3048 0 L
.3074 0 L
.31014 0 L
.31248 0 L
.31506 0 L
.31782 0 L
.3208 0 L
.3236 0 L
.32616 0 L
.33111 0 L
.33391 0 L
.33651 0 L
.34126 0 L
.34392 0 L
.34632 0 L
.35122 0 L
.35368 0 L
.35638 0 L
.35869 0 L
.36116 0 L
.36562 0 L
Mistroke
.36831 0 L
.37123 0 L
.3738 0 L
.37653 0 L
.37899 0 L
.38169 0 L
.38646 0 L
.38894 0 L
.39165 0 L
.39404 0 L
.39659 0 L
.4014 0 L
.40586 0 L
.40857 0 L
.4115 0 L
.41408 0 L
.41681 0 L
.42198 0 L
.42673 0 L
.43169 0 L
.43621 0 L
.44142 0 L
.44636 1e-05 L
.45092 1e-05 L
.45514 1e-05 L
.45977 2e-05 L
.46469 2e-05 L
.46958 3e-05 L
.47406 4e-05 L
.47898 5e-05 L
.48416 7e-05 L
.48868 9e-05 L
.49288 .00011 L
.4975 .00014 L
.50243 .00019 L
.50776 .00025 L
.51267 .00032 L
.51806 .00043 L
.52377 .00057 L
.53336 .0009 L
.53881 .00117 L
.54392 .00148 L
.54889 .00184 L
.55432 .00234 L
.5642 .00354 L
.57381 .0052 L
.58273 .0073 L
.59332 .01069 L
.60328 .01497 L
.61223 .0199 L
Mistroke
.6219 .02657 L
.64187 .04532 L
.66294 .07272 L
.70095 .13472 L
.71183 .15197 L
.72213 .16646 L
.73215 .17805 L
.73656 .18216 L
.74142 .18594 L
.74609 .18875 L
.74823 .18976 L
.75047 .19063 L
.75163 .191 L
.75289 .19134 L
.75405 .1916 L
.7551 .19179 L
.75635 .19196 L
.75704 .19202 L
.75768 .19207 L
.75884 .1921 L
.76008 .19208 L
.76135 .19199 L
.76253 .19185 L
.76382 .19164 L
.76521 .19133 L
.76805 .19046 L
.77064 .18939 L
.77563 .18661 L
.78037 .18312 L
.79 .17366 L
.80024 .16066 L
.81865 .13216 L
.85636 .0709 L
.87567 .0459 L
.88562 .03558 L
.89652 .02629 L
.90618 .01968 L
.91652 .01413 L
.92744 .00972 L
.93761 .0067 L
.94712 .00464 L
.95213 .0038 L
.95745 .00305 L
.96208 .00251 L
.96719 .00201 L
.97619 .00134 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00H_ooool2onk^kP?ooooo0_o^
k^h]ooooo`;ok^k^0oooool2onk^kSKooooo0_o^k^h3ooooo`;ok^k^9?ooool2onk^kP?ooooo0_o^
k^iSooooo`00G?ooool03Om4A4Co0000o`000?lb<S;ogMgMooooooo^k^koEEEEonk^k_ooooook^k^
oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hHooooo`Co
000000Wo410@ooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?oo
ooooooooonk^k_lb<S;o0000oc8b<_o^k^hAooooo`Co000000?o410@ooooooooool00_ooool2ob4Q
8@Gooooo00goA4A4o`000?l0003o<S8bomgMgOooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^
00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^3_ooool5o`0000;ooooo
00Ook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413oooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^E?ooool005oooooo00WoMgMgoc8b<_ooooooooooonk^k_mEEEGogMgMoeEE
EOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool0
0ol0003oooooooooo`02ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool00ol0003oooooooooo`04ooooo`;o8B4Q
2?ooool02OmgMgOo<S8booooooooooook^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
0oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg05Cooooo001Pooooo`07o`000?oooooooooooooooooMgMgo0000omgMg@07
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Jooooo`03o`000?oo
oooooooo00?ooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?oo
ooooooooooooool@41004oooool00ol0003oooooooooo`0?ooooo`07o`000?oooooooooooooooooM
gMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400?
ooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@4100E?ooool005oooooo00WoMgMgoc8b<_ooooooooooonk^
k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000006_ooool00ol0003oooooooooo`02ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000004oooool00ol0003ooooooooo
o`0>ooooo`09ogMgMolb<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo0000013ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000005Cooooo001Looooo`0=o`000?lQ8B7o0000oc8b<_o<c<coooooonk^k_mEEEGok^k^
ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Jooooo`0;o`000?ooooooooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Ooo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000004oooool00ol0003ooooo
ooooo`0;ooooo`0=o`000?lQ8B7o0000oc8b<_o<c<coooooonk^k_mEEEGok^k^ooooooo^k^koEEEE
onk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Aooooo`0;
ogMgMomVIVKoooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool00000E?ooool005cooooo00?o0000ooooooooool0
0oooool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@400Jooooo`04o`000?ooooooooooooooo`;ok^k^0oooool2onk^kPGooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@01?ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`03ooooo`;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@01;ooooo00?o0000ooooooooool00_o^k^h3ooooo`;ok^k^1Ooo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100E?ooool005cooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
6_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Cooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool01Ol0003o^[ZjoooooonHV9So
410@00kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg05Cooooo001L
ooooo`Co00003?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?oo
ool00ol0003oooooooooo`0=ooooo`03oeEEEOmVIVKo000000gooooo00?oEEEEofIVI_l000001?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo0_l00007ooooo`03oeEEEOmVIVKo000000gooooo
1?l0000<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`;o
00001?ooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo00?oEEEEofIVI_l000001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Sooooo0_l0001:ooooo`00P?ooool00ol0003oooooooooo`0`oooo
o`04o`000?ooooooooooo`0003Wooooo00Co0000oooooooooooo00009oooool01?l0003ooooooooo
ool00019ooooo`00N_ooool4o`0000?ooooo00?o0000ooooooooool0:_ooool4o`000005ooooool0
003oooooooooool00000=?ooool4o`000005ooooool0003oooooooooool000008_ooool4o`000005
ooooool0003oooooooooool00000BOooool0087ooooo00?o0000ooooooooool0;oooool3o`0003[o
oooo0ol0000Xooooo`?o0000B_ooool007oooooo00Co0000oooooooooooo0000<Oooool00ol0003o
ooooooooo`0jooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool03_ooool00omgMgOo
IVIVooooo`0^ooooo`03ofIVI_mgMgOooooo00Oooooo001oooooo`Co0000<_ooool00ol0003ooooo
ooooo`0jooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool03?ooool00ooMgMgo410@
onk^kP0_ooooo`03onk^k_l@413ogMgM00Oooooo003ooooooa_ooooo0_l00002ooooo`;o00003?oo
ool01?mEEEGoV9RHooooooooool2o`0000;ooooo00Oo0000oooooooooooo0000oa0@4?o^k^koEEEE
00;o000000?oA4A4okZj^_ooool00_ooool01OnHV9So0000o`000?m4A4Co^[Zj00;ooooo00Sok^k^
oeEEEOl0003o0000odA4A?nj^[[ooooooa0@40Go00000oooool02?l@413o<S8bo`000?l0003o410@
ojVYZOn7QhOoIVIV1oooool00?oooooo6oooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@cooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`08o`000?ooooooEEEEogMg
Moooooook^k^ogMgMol@4103ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000_ooool01_mEEEGoMgMg
ooooooo^k^koMgMgoa0@40?ooooo00?o0000ooooooooool01?ooool02?l0003oZJVYoooooooooooo
^[Zjo`000?o^k^ko00001oooool0023ooooolOl0000:ooooo`04omgMgOl0003o410@olc<c0gooooo
00?o<S8booooooooool00_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo000000So
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Go
oooo00Oo^[ZjohN7QomVIVKoIVIVoa0@4?oooooo000000Oooooo000Vooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`co00000oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Ol0000?oooo
o`04onk^k_lQ8B7o410@onk^kPgooooo00?o<S8booooooooool00_ooool01?l0003oooooooooool0
0002ooooo`03o`000?oooooo000000Go00000oooool00ol0003oooooooooo`04ooooo`Ko00000ooo
ool00ol0003oooooooooo`04ooooo`08oc8b<_lQ8B7oMgMgogMgMon7QhOok^k^ooooool00007oooo
o`00>oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo037ooooo00?o0000oooooooo
ool01?ooool5o`0002Sooooo00?o0000ooooooooool09oooool2o`0000Sooooo00?o0000oooooooo
ool03Oooool01?lQ8B7oMgMgogMgMolb<S8=ooooo`03o`000?o^k^kooooo00;ooooo00ko0000olc<
c?o<c<co0000ojVYZOoMgMgo8B4QoooooomEEEGoQhN7onk^k_ooooooQhN7oc8b<P?ooooo00?o0000
ooooooooool01?ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<P?ooooo00?o0000oc8b<_oMgMd0
1?ooool02?l0003o^[Zjooooooo^k^koMgMgo`000?o^k^ko00001oooool003_ooooo00?o0000oooo
ooooool0LOooool2o`0004gooooo0ol0000Iooooo`;o00000_ooool2o`0000cooooo00ooEEEEogMg
Mooooooooooooa0@4?l0003o8B4Qo`000?mgMgOo410@o`000?nYZJWoooooonk^k_mEEED00_l00000
1?m4A4Cok^k^ooooool@4105o`0000?ooooo00Kok^k^oeEEEOl0003o0000odA4A?o^k^h2ooooo`;o
000000CoZJVYob4Q8Ol0003o8B4Q0_ooool02?nYZJWo8B4Qo`000?l0003o<S8bo`000?mgMgOoEEEE
1oooool003_ooooo00?o0000ooooooooool0Loooool2o`0004Sooooo0ol0000^ooooo`03omgMgOl@
413ok^k^01?ooooo00?o0000ooooooooool06Oooool00oo^k^ko410@omgMg@07ooooo`00>oooool2
o`0007Kooooo0_l00015ooooo`03o`000?oooooooooo033ooooo00?oMgMgofIVI_ooool04_ooool0
0ol0003oooooooooo`0Iooooo`03ofIVI_mgMgOooooo00Oooooo000kooooo`03o`000?oooooooooo
07Oooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`1/ooooo`00>oooool00ol0003o
ooooooooo`1hooooo`03o`000?oooooooooo03kooooo0_l0001_ooooo`00>oooool00ol0003ooooo
ooooo`1iooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0Koooool003_ooooo00?o
0000ooooooooool0N_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo073ooooo000k
ooooo`;o0000O?ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo077ooooo000koooo
o`03o`000?oooooooooo07cooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`1boooo
o`00>oooool00ol0003oooooooooo`1looooo`03o`000?oooooooooo03Kooooo00?o0000oooooooo
ool0L_ooool003_ooooo00?o0000ooooooooool0OOooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo07?ooooo000kooooo`;o0000Ooooool00ol0003oooooooooo`0booooo`03o`000?oo
oooooooo07Cooooo000kooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool0<?ooool0
0ol0003oooooooooo`1eooooo`00>oooool00ol0003oooooooooo`20ooooo`03o`000?oooooooooo
02kooooo00?o0000ooooooooool0M_ooool003_ooooo00?o0000ooooooooool0POooool00ol0003o
ooooooooo`0/ooooo`03o`000?oooooooooo07Oooooo000Gooooo`;ok^k^0oooool2onk^kQgooooo
00?o0000ooooooooool0P_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo07Oooooo
000Aooooo`0=odA4A?l0003o0000oc8b<_oMgMgoooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^
kP03ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPkooooo0_l00023oooo
o`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0N?ooool001Cooooo00WoMgMgoc8b<_oo
ooooooooonk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`23ooooo`03o`000?oooooooooo02Sooooo
00?o0000ooooooooool0NOooool001Gooooo00Oo0000ooooooooooooooooomgMgOl0003ogMgM00Oo
oooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000oooo
ooooool0Q?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo07Wooooo000Dooooo`09
ogMgMolb<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool0Q?ooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo07[ooooo000Aooooo`0=o`000?lQ8B7o0000oc8b<_o<c<co
ooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`00000>ooooo`;o0000Q_ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo07[ooooo000Aooooo`03o`000?oooooooooo00?ooooo0_o^k^h3ooooo`;ok^k^1Ooo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003ooooo
ooooo`25ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0Noooool0017ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
0oooool3o`000003ooooool0003o000000;o00000oooool00ol0003oooooooooo`26ooooo`03o`00
0?oooooooooo02;ooooo00?o0000ooooooooool0O?ooool0017ooooo1?l0000<ooooo`03oeEEEOmV
IVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`05o`000?ooooooooooooooool0
00001Oooool00ol0003oooooooooo`27ooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool0O?ooool0037ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo08Oooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1mooooo`00<Ooo
ool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooo`;o0000ROooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo07gooooo000aooooo`04o`000?ooooooooooo`0000;ooooo
00Go0000ooooooooooooooooo`00002:ooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool0O_ooool0033ooooo0_l00003ooooo`;o00001?ooool00ol0003oooooooooo`29ooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool0Ooooool003_ooooo00?o0000ooooooooool0R_oo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo07oooooo000kooooo`;o0000Roooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo083ooooo000kooooo`03o`000?oooooooooo
08_ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`20ooooo`00>oooool00ol0003o
ooooooooo`2;ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0POooool003_ooooo
00?o0000ooooooooool0S?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo08;ooooo
000kooooo`03o`000?oooooooooo08cooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`23ooooo`00>oooool2o`0008kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`23
ooooo`00>oooool00ol0003oooooooooo`2>ooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool0Q?ooool003_ooooo00?o0000ooooooooool0Soooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo08Gooooo000kooooo`03o`000?oooooooooo093ooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`25ooooo`005oooool2onk^kP?ooooo0_o^k^hMooooo`03o`000?oo
oooooooo093ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`26ooooo`004Oooool4
o`000009oa0@4?ooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413o
ooooooooooo^k^ko<S8bo`000?lb<S;ok^k^3_ooool2o`0009;ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`27ooooo`004oooool00ol0003oooooooooo`02ooooo`05onk^k_mEEEGo
gMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3_ooool00ol0003oooooooooo`2Booooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
R?ooool001?ooooo00?o0000ooooooooool00oooool00ooMgMgo0000omgMg@07ooooo`03o`000?oo
oooooooo00;ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo09?ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`29ooooo`004oooool00ol0003ooooooooo
o`02ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000003_ooool00ol0003oooooooooo`2Dooooo`03o`000?oooooooooo00Go
oooo0_l0002<ooooo`004oooool02ol0003oooooooooooooooook^k^oeEEEOo^k^koooooonk^k_mE
EEGok^k^00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000kooooo
0_l0002Fooooo`Oo0000S_ooool001?ooooo00Co0000oooooooooooooooo0_o^k^h3ooooo`;ok^k^
1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003o
ooooooooo`2Hooooo`;o0000T?ooool001?ooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool3o`0000;ooooo0_l00004ooooo`03
o`000?oooooooooo0?oooooo:oooool0017ooooo00?oEEEEofIVI_l000003Oooool00omEEEGoIVIV
o`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool01?l0003oooooooooool00002oooo
o`05o`000?ooooooooooooooool00000ooooool]ooooo`00<Oooool00ol0003oooooooooo`03oooo
o`05o`000?ooooooooooooooool00000ooooool]ooooo`00<Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00;ooooo0_l0003oooooobcooooo000aooooo`04o`000?ooooooooooo`00
00;ooooo00Go0000ooooooooooooooooo`00003oooooobgooooo000`ooooo`;o00000oooool2o`00
00Cooooo00?o0000ooooooooool0ooooool[ooooo`00>oooool00ol0003oooooooooo`3oooooob_o
oooo000kooooo`;o0000ooooool/ooooo`00>oooool00ol0003oooooooooo`3oooooob_ooooo000k
ooooo`03o`000?oooooooooo0?oooooo:oooool003_ooooo00?o0000ooooooooool0ooooool[oooo
o`00>oooool00ol0003oooooooooo`3oooooob_ooooo000kooooo`;o0000ooooool/ooooo`00>ooo
ool00ol0003oooooooooo`3oooooob_ooooo000kooooo`03o`000?oooooooooo0?oooooo:oooool0
03_ooooo00?o0000ooooooooool0ooooool[ooooo`006?ooool2onk^kP?ooooo0_o^k^hLooooo`;o
0000ooooool/ooooo`000_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`0=odA4
A?l0003o0000oc8b<_oMgMgoooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co0000
00So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPgooooo00?o0000ooooooooool0ooooool[
ooooo`001?ooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool02OmgMgOo<S8boooooooooooo
k^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0=ooooo`03o`000?oooooooooo0?oooooo:oooool000Cooooo00?o0000ooooooooool0
3oooool01ol0003ooooooooooooooooogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@41003Oooool00ol0003oooooooooo`3oooooob_ooooo0004oooo
o`03o`000?oooooooooo00kooooo00WoMgMgoc8b<_ooooooooooonk^k_mEEEGogMgMoeEEEOo^k^h0
1_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000003Oooool00ol0003o
ooooooooo`3oooooob_ooooo0004ooooo`03o`000?oooooooooo00_ooooo00go0000ob4Q8Ol0003o
<S8bolc<c?ooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000ooooooooool0
0_ooool01Ol0003ooooooooooooooooo000000gooooo0_l0003oooooobcooooo0004ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool00oooool2onk^kP?ooooo0_o^k^h5ooooo`03o`00
0?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03o`000?oooooooooo0?oo
oooo:oooool000Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`?o00000_ooool2o`0000?o
oooo00?o0000ooooooooool0ooooool[ooooo`000_ooool00omEEEGoIVIVo`00000=ooooo`Co0000
3?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`000?oooooo;Oooool003;ooooo00?o0000oooo
ooooool00oooool01?l0003oooooooooool0003oooooobgooooo000booooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooooooo0_l0003oooooobcooooo000booooo`04o`000?oooooooooo
o`0000;ooooo00Co0000oooooooooooo0000ooooool]ooooo`00<Oooool2o`0000?ooooo0_l00003
ooooo`03o`000?oooooooooo0?oooooo:oooool003_ooooo00?o0000ooooooooool0ooooool[oooo
o`00>oooool2o`000?oooooo;?ooool003_ooooo00?o0000ooooooooool0ooooool[ooooo`00>ooo
ool00ol0003oooooooooo`3oooooob_ooooo000kooooo`03o`000?oooooooooo0?oooooo:oooool0
03_ooooo00?o0000ooooooooool0ooooool[ooooo`00>oooool2o`000?oooooo;?ooool003_ooooo
00?o0000ooooooooool0ooooool[ooooo`00>oooool00ol0003oooooooooo`3oooooob_ooooo000G
ooooo`;ok^k^0oooool2onk^kQgooooo00?o0000ooooooooool0ooooool[ooooo`004?ooool5o`00
00;ooooo00Ook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413ooooooooo
ooo^k^ko<S8bo`000?lb<S;ok^k^3_ooool2o`000?oooooo;?ooool0013ooooo00GoV9RHob4Q8Oo^
k^koooooodA4A003ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`3oooooob_ooooo000A
ooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`3oooooob_ooooo000B
ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo0?oooooo
:oooool001?ooooo00_oMgMgofIVI_ooooooooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oo
oooooooo0?oooooo:oooool001Cooooo00?o0000ooooooooool00_o^k^h3ooooo`;ok^k^1Oooool0
0ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41003_ooool2o`000?oooooo;?oo
ool0013ooooo00Go0000okZj^_ooooooV9RHoa0@400>ooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oooooooooo0?oooooo:oooool0013ooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c00<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP03ooooo`?o00000_ooool2o`0000Cooooo00?o0000ooooooooool0ooooool[ooooo`00
<Oooool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool00000ooooool]oooo
o`00<Oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooo`;o0000ooooool/oooo
o`00<Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0ooooool[ooooo`00<Oooool01?l0003oooooooooool00002ooooo`05o`000?oooooooooooooo
ool00000ooooool]ooooo`00<?ooool2o`0000?ooooo0_l00004ooooo`03o`000?oooooooooo0?oo
oooo:oooool003_ooooo00?o0000ooooooooool0ooooool[ooooo`00>oooool2o`000?oooooo;?oo
ool003_ooooo00?o0000ooooooooool0ooooool[ooooo`00>oooool00ol0003oooooooooo`3ooooo
ob_ooooo000kooooo`03o`000?oooooooooo0?oooooo:oooool003_ooooo00?o0000ooooooooool0
ooooool[ooooo`00>oooool2o`000?oooooo;?ooool003_ooooo00?o0000ooooooooool0ooooool[
ooooo`00>oooool00ol0003oooooooooo`3oooooob_ooooo000Hooooo`;ok^k^0oooool2onk^kQco
oooo00?o0000ooooooooool0ooooool[ooooo`0000?oooooo`000?l000000ol00005ooooo`;o8B4Q
1Oooool03Om4A4Co0000o`000?lb<S;ogMgMooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h0
0oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h=ooooo`;o0000ooooool/
ooooo`0000KooooooiRHV?lQ8B7ok^k^oooooom4A4@5ooooo`;o8B4Q2?ooool02OmgMgOo<S8boooo
ooooooook^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0=ooooo`03o`000?oooooooooo0?oooooo:oooool000;ooooo00?oV9RHob4Q
8Oo^k^h04Oooool01ol0003ooooooooooooooooogMgMo`000?oMgMd01oooool00ol0003ooooooooo
o`02ooooo`05oa0@4?ooooooooooooooool@41003Oooool00ol0003oooooooooo`3oooooob_ooooo
0003ooooo`03oiRHV?lQ8B7ok^k^00oooooo00WoMgMgoc8b<_ooooooooooonk^k_mEEEGogMgMoeEE
EOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000003Oooool0
0ol0003oooooooooo`3oooooob_ooooo0004ooooo`03ogMgMomVIVKooooo00_ooooo00go0000ob4Q
8Ol0003o<S8bolc<c?ooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool0ooooool[
ooooo`001Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo0_o^k^h3oooo
o`;ok^k^1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41003Oooool2
o`000?oooooo;?ooool00006ooooool0003o^[ZjoooooonHV9So410@3?ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0=ooooo`03o`00
0?oooooooooo0?oooooo:oooool00006oooooonHV9So410@o`000?lQ8B7oc<c<3?ooool4o`0000co
oooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo0ol00002oooo
o`;o00000oooool00ol0003oooooooooo`3oooooob_ooooo000booooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo0000ooooool]ooooo`00<_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;o0000ooooool/ooooo`00<_ooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool00000ooooool]ooooo`00<_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`000?oooooo;Oooool0037ooooo0_l00003ooooo`;o00000oooool00ol0
003oooooooooo`3oooooob_ooooo000kooooo`03o`000?oooooooooo0?oooooo:oooool003_ooooo
0_l0003oooooobcooooo000kooooo`03o`000?oooooooooo0?oooooo:oooool003_ooooo00?o0000
ooooooooool0ooooool[ooooo`00>oooool00ol0003oooooooooo`3oooooob_ooooo000kooooo`;o
0000ooooool/ooooo`00>oooool00ol0003oooooooooo`3oooooob_ooooo000kooooo`03o`000?oo
oooooooo0?oooooo:oooool003_ooooo00?o0000ooooooooool0ooooool[ooooo`005oooool2onk^
kP?ooooo0_o^k^hMooooo`03o`000?oooooooooo0?oooooo:oooool0013ooooo00GoV9RHoa0@4?l0
003o<S8bolc<c002ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co000000So
410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPkooooo0_l0003oooooobcooooo000@ooooo`05
oa0@4?nj^[[oooooogMgMolb<S800oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000
ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00?o0000ooooooooool0oooo
ool[ooooo`005?ooool00ol0003oooooooooo`02ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool0oooo
ool[ooooo`004oooool00onYZJWo410@ooooo`02ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_oo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003ooooo
ooooo`3oooooob_ooooo000Booooo`03oa0@4?l0003o^[Zj00;ooooo00Ook^k^oeEEEOo^k^kooooo
onk^k_mEEEGok^k^00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
00kooooo00?o0000ooooooooool0ooooool[ooooo`004oooool01?nj^[[o8B4Qooooooooool2onk^
kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400>
ooooo`;o0000ooooool/ooooo`004?ooool01Ol@413oV9RHoooooonj^[[o000000kooooo00?o0000
ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00?o0000ooooooooool0oooo
ool[ooooo`004?ooool01OnYZJWo410@o`000?l@413oZJVY00cooooo00?oEEEEofIVI_l000001?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo0ol00002ooooo`;o00001?ooool00ol0003ooooo
ooooo`3oooooob_ooooo000aooooo`04o`000?ooooooooooo`0000;ooooo00Go0000oooooooooooo
ooooo`00003oooooobgooooo000aooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo
oooo0_l0003oooooobcooooo000aooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`3oooooob_ooooo000aooooo`04o`000?ooooooooooo`0000;ooooo
00Go0000ooooooooooooooooo`00003oooooobgooooo000`ooooo`;o00000oooool2o`0000Cooooo
00?o0000ooooooooool0ooooool[ooooo`00>oooool00ol0003oooooooooo`3oooooob_ooooo000k
ooooo`;o0000ooooool/ooooo`00>oooool00ol0003oooooooooo`3oooooob_ooooo000kooooo`03
o`000?oooooooooo0?oooooo:oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool005Wooooo00?oMgMgofIVI_ooool01?ooool00ol0003ooooo
ooooo`02ooooo`03okZj^_lb<S;ooooo00Oooooo00Ko0000ooooooooooooooooofIVI_mgMgL=oooo
o`03o`000?nj^[[ooooo0>?ooooo001Hooooo`03omgMgOl@413ok^k^00Gooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`06ooooo`07o`000?ooooooooooooooooo^k^ko410@omgMg@0<
ooooo`;o<S8bi?ooool005Sooooo00?oEEEEoiRHV?ooool01Oooool01_l0003ooooooooooooooooo
V9RHoa0@40;o000000?oZJVYooooooooool01?ooool00ol0003oooooooooo`02ooooo`03ohN7QomV
IVKooooo00_ooooo00?oQhN7o`000?nj^[X01Oooool4o`000008oa0@4?oooooooooooiRHV?l@413o
0000oc8b<_o<c<`5ooooo`;o8B4Q0_ooool01Oo<c<cok^k^ooooooo^k^koc<c<00Cooooo1?l00000
2?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^4oooool01_l@413o<S8bo`000?l0003o410@
ojVYZ@;ooooo00Kok^k^oeEEEOl0003o0000odA4A?nj^[X3ooooo`05ofIVI_l0003o0000odA4A?o<
c<`0Roooool005Sooooo00?o0000ooooooooool01Oooool02_l0003ooooooooooooooooo0000ojVY
ZOmEEEGoV9RHoeEEEOnj^[X5ooooo`03o`000?oooooooooo00;ooooo00?ok^k^o`000?ooool02ooo
ool00oo<c<co0000oa0@4007ooooo`03o`000?oooooooooo00;ooooo00Go410@okZj^_ooooooMgMg
oc8b<P05ooooo`;o8B4Q0_ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01?ooooo00Ko0000ojVYZOoooooooooookZj^_l0
0002ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo410@0_ooool01_mVIVKoMgMgooooooooooooQhN7
oa0@48_ooooo001Hooooo`03oc8b<_oooooooooo00Gooooo00[o0000oooooooooooooooooc8b<_o^
k^koV9RHoeEEEOoMgMgo410@1Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`03omgMgOl0003ogMgM00Oo
oooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01Cooooo00Go^[ZjohN7
QomVIVKoIVIVoa0@4002ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0S_ooool0
05Sooooo00?o<S8booooooooool01Oooool02ol0003ooooooooooooooooo^[ZjodA4A?o<c<co8B4Q
ooooool@413oc<c<00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo00Gooooo00?oZJVYoa0@4?ooool02?ooool01Oo^k^koEEEEomgMgOmEEEGok^k^
00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000001?ooooo00Ko<S8b
ob4Q8OmgMgOoMgMgohN7Qoo^k^h2ooooo`Ko00000_ooool00ol0003oooooooooo`2>ooooo`00F?oo
ool00ol0003ok^k^ooooo`05ooooo`0;o`000?ooooooooooooooooo^k^ko0000ooooool0003ooooo
ofIVI_n7QhL01?ooool00ol0003oooooooooo`02ooooo`03onk^k_l0003ooooo01Gooooo00?o0000
ooooooooool01?ooool00ol@413o0000okZj^P09ooooo`05olc<c?o^k^koooooonk^k_o<c<`01_oo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000004oooool01_l0003o^[Zj
ooooooo^k^koMgMgo`0000;ooooo00KoEEEEohN7Qoo^k^koooooohN7Qolb<S82ooooo`06ofIVI_mg
MgOooooooooooon7QhOo0000Roooool005Sooooo00?oEEEEogMgMoooool01Oooool02?l0003ooooo
ooooooooooooIVIVoiRHV?oooooo<S8b0_nj^[X00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00;ooooo00?oMgMgoeEEEOooool00oooool4o`0000kooooo00?o0000ooooooooool01Oooool0
0onj^[[o8B4Qooooo`0Cooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4007ooooo`?o00000_ooool3o`0000Cooooo00KoZJVYob4Q8Ol0003o0000oc8b<_l00002ooooo`06
onk^k_mEEEGo0000o`000?m4A4Cok^k^0_ooool01_o^k^koIVIVo`000?l0003oA4A4o`0008_ooooo
001Hooooo`03omgMgOl@413ok^k^00Gooooo00?o0000ooooooooool01?ooool00omVIVKoQhN7oooo
o`05ooooo`07o`000?ooooooooooooooooo^k^ko410@omgMg@05ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool00_ooool01Ol@413oV9RHoooooonj^[[o000001Cooooo00?o0000oooo
ooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`2Tooooo`00FOooool00omgMgOoIVIVooooo`04ooooo`03o`000?oooooooooo
00Cooooo00?oZJVYodA4A?ooool01Oooool01_l0003oooooooooooooooooIVIVogMgM`Oooooo00?o
0000ooooooooool02oooool00omEEEGoIVIVo`000004ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0
4_ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_ooool4o`0000;o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2Tooooo`00OOooool00ol0003ooooo
ooooo`0looooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Y?ooool007[ooooo00Co
0000oooooooooooo0000?_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0:Cooooo
001kooooo`;o0000?_ooool2o`0000?ooooo0_l0002Vooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -2.14748*^9, 0, \
2.14748*^9}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0 1.90278e-14 [
[.32684 -0.0125 -16.5 -12.5 ]
[.32684 -0.0125 16.5 0 ]
[.54329 -0.0125 -16.5 -12.5 ]
[.54329 -0.0125 16.5 0 ]
[.75974 -0.0125 -22.5 -12.5 ]
[.75974 -0.0125 22.5 0 ]
[.97619 -0.0125 -16.5 -12.5 ]
[.97619 -0.0125 16.5 0 ]
[1.025 0 0 -6 ]
[1.025 0 64 6 ]
[.09789 .09514 -33 -6.25 ]
[.09789 .09514 0 6.25 ]
[.09789 .19028 -33 -6.25 ]
[.09789 .19028 0 6.25 ]
[.09789 .28542 -45 -6.25 ]
[.09789 .28542 0 6.25 ]
[.09789 .38056 -33 -6.25 ]
[.09789 .38056 0 6.25 ]
[.09789 .47569 -45 -6.25 ]
[.09789 .47569 0 6.25 ]
[.09789 .57083 -33 -6.25 ]
[.09789 .57083 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -56.4375 0 ]
[.5 .63053 56.4375 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 0 m
.32684 .00625 L
s
gsave
.32684 -0.0125 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 0 m
.54329 .00625 L
s
gsave
.54329 -0.0125 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 0 m
.75974 .00625 L
s
gsave
.75974 -0.0125 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 0 m
.15368 .00375 L
s
.19697 0 m
.19697 .00375 L
s
.24026 0 m
.24026 .00375 L
s
.28355 0 m
.28355 .00375 L
s
.37013 0 m
.37013 .00375 L
s
.41342 0 m
.41342 .00375 L
s
.45671 0 m
.45671 .00375 L
s
.5 0 m
.5 .00375 L
s
.58658 0 m
.58658 .00375 L
s
.62987 0 m
.62987 .00375 L
s
.67316 0 m
.67316 .00375 L
s
.71645 0 m
.71645 .00375 L
s
.80303 0 m
.80303 .00375 L
s
.84632 0 m
.84632 .00375 L
s
.88961 0 m
.88961 .00375 L
s
.9329 0 m
.9329 .00375 L
s
.0671 0 m
.0671 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09514 m
.11664 .09514 L
s
gsave
.09789 .09514 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(12) show
grestore
.11039 .19028 m
.11664 .19028 L
s
gsave
.09789 .19028 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.11039 .28542 m
.11664 .28542 L
s
gsave
.09789 .28542 -45 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.11039 .38056 m
.11664 .38056 L
s
gsave
.09789 .38056 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.11039 .47569 m
.11664 .47569 L
s
gsave
.09789 .47569 -45 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.11039 .57083 m
.11664 .57083 L
s
gsave
.09789 .57083 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(3) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.125 Mabswid
.11039 .01903 m
.11414 .01903 L
s
.11039 .03806 m
.11414 .03806 L
s
.11039 .05708 m
.11414 .05708 L
s
.11039 .07611 m
.11414 .07611 L
s
.11039 .11417 m
.11414 .11417 L
s
.11039 .13319 m
.11414 .13319 L
s
.11039 .15222 m
.11414 .15222 L
s
.11039 .17125 m
.11414 .17125 L
s
.11039 .20931 m
.11414 .20931 L
s
.11039 .22833 m
.11414 .22833 L
s
.11039 .24736 m
.11414 .24736 L
s
.11039 .26639 m
.11414 .26639 L
s
.11039 .30444 m
.11414 .30444 L
s
.11039 .32347 m
.11414 .32347 L
s
.11039 .3425 m
.11414 .3425 L
s
.11039 .36153 m
.11414 .36153 L
s
.11039 .39958 m
.11414 .39958 L
s
.11039 .41861 m
.11414 .41861 L
s
.11039 .43764 m
.11414 .43764 L
s
.11039 .45667 m
.11414 .45667 L
s
.11039 .49472 m
.11414 .49472 L
s
.11039 .51375 m
.11414 .51375 L
s
.11039 .53278 m
.11414 .53278 L
s
.11039 .55181 m
.11414 .55181 L
s
.11039 .58986 m
.11414 .58986 L
s
.11039 .60889 m
.11414 .60889 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -117.438 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.812 moveto
(H) show
69.000 13.812 moveto
(\\310) show
75.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.812 moveto
(\\310) show
87.000 13.812 moveto
(L) show
93.000 9.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
98.250 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
104.250 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(14.) show
122.250 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
128.250 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
140.250 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
144.438 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
153.875 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
171.875 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.02605 0 L
.02846 0 L
.03072 0 L
.03279 0 L
.03521 0 L
.03658 0 L
.03784 0 L
.04016 0 L
.04262 0 L
.04496 0 L
.04749 0 L
.04987 0 L
.05205 0 L
.0546 0 L
.05604 0 L
.05738 0 L
.05983 0 L
.06244 0 L
.06383 0 L
.06529 0 L
.06791 0 L
.06937 0 L
.07073 0 L
.07232 0 L
.07382 0 L
.07653 0 L
.079 0 L
.08165 0 L
.08315 0 L
.08454 0 L
.08693 0 L
.08916 0 L
.09161 0 L
.09426 0 L
.09688 0 L
.09964 0 L
.102 0 L
.10458 0 L
.10712 0 L
.10986 0 L
.11246 0 L
.11485 0 L
.11701 0 L
.11939 0 L
.12187 0 L
.12419 0 L
.1269 0 L
.12947 0 L
.13178 0 L
Mistroke
.13429 0 L
.13702 0 L
.13992 0 L
.14266 0 L
.14514 0 L
.14747 0 L
.15003 0 L
.1527 0 L
.15519 0 L
.15753 0 L
.15965 0 L
.1621 0 L
.16443 0 L
.16694 0 L
.16962 0 L
.1719 0 L
.17441 0 L
.17711 0 L
.18001 0 L
.18275 0 L
.18526 0 L
.18775 0 L
.19001 0 L
.19263 0 L
.19509 0 L
.19737 0 L
.19947 0 L
.20178 0 L
.20422 0 L
.20668 0 L
.20932 0 L
.21182 0 L
.21409 0 L
.21676 0 L
.21966 0 L
.2224 0 L
.22494 0 L
.22735 0 L
.22956 0 L
.23199 0 L
.23455 0 L
.23678 0 L
.23886 0 L
.24114 0 L
.24358 0 L
.24624 0 L
.24912 0 L
.25185 0 L
.25436 0 L
.25663 0 L
Mistroke
.25912 0 L
.26173 0 L
.26417 0 L
.26675 0 L
.26914 0 L
.27176 0 L
.27456 0 L
.27723 0 L
.27974 0 L
.28202 0 L
.28443 0 L
.28664 0 L
.28907 0 L
.29334 0 L
.29574 0 L
.29832 0 L
.30296 0 L
.30553 0 L
.30825 0 L
.31315 0 L
.31586 0 L
.31841 0 L
.3212 0 L
.32422 0 L
.32666 0 L
.32933 0 L
.33212 0 L
.33472 0 L
.33937 0 L
.34198 0 L
.34434 0 L
.3492 0 L
.35164 0 L
.35433 0 L
.35663 0 L
.35909 0 L
.36354 0 L
.36621 0 L
.36912 0 L
.37169 0 L
.37441 0 L
.37712 0 L
.37957 0 L
.38434 0 L
.38668 0 L
.38924 0 L
.39174 0 L
.39441 0 L
.39919 0 L
.40364 0 L
Mistroke
.40633 0 L
.40925 0 L
.41183 0 L
.41455 0 L
.41972 0 L
.42448 0 L
.42939 0 L
.43389 0 L
.43908 0 L
.44401 0 L
.44854 0 L
.45276 0 L
.45738 0 L
.46231 0 L
.46766 0 L
.47259 1e-05 L
.47799 1e-05 L
.48371 1e-05 L
.48868 1e-05 L
.49332 2e-05 L
.49841 3e-05 L
.50388 3e-05 L
.50916 5e-05 L
.51404 6e-05 L
.51941 8e-05 L
.52511 .00011 L
.53004 .00014 L
.53467 .00018 L
.53975 .00023 L
.54522 .0003 L
.55479 .00047 L
.56021 .00061 L
.56526 .00076 L
.57545 .0012 L
.58116 .00152 L
.58635 .00189 L
.59633 .00282 L
.60553 .004 L
.61563 .00579 L
.62632 .00837 L
.63575 .0114 L
.64589 .01559 L
.6642 .02618 L
.67432 .03395 L
.68536 .04412 L
.70546 .06712 L
.74615 .125 L
.76497 .15036 L
.77487 .16142 L
.78532 .17061 L
Mistroke
.79065 .17415 L
.79347 .17568 L
.79649 .17704 L
.79927 .17805 L
.8018 .17874 L
.80302 .17901 L
.80435 .17923 L
.8056 .1794 L
.80676 .1795 L
.80792 .17956 L
.80916 .17958 L
.81034 .17955 L
.81141 .17948 L
.81261 .17935 L
.81392 .17917 L
.81528 .17891 L
.81655 .17862 L
.81918 .17785 L
.82157 .17696 L
.82694 .1743 L
.8318 .17114 L
.83694 .16708 L
.84615 .15809 L
.86696 .13175 L
.90489 .07701 L
.926 .05093 L
.94527 .03251 L
.96114 .02134 L
.97619 .01371 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00H_ooool2onk^kP?ooooo0_o^
k^h]ooooo`;ok^k^0oooool2onk^kSKooooo0_o^k^h3ooooo`;ok^k^9?ooool2onk^kP?ooooo0_o^
k^iSooooo`00G?ooool03Om4A4Co0000o`000?lb<S;ogMgMooooooo^k^koEEEEonk^k_ooooook^k^
oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hHooooo`Co
000000Wo410@ooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?oo
ooooooooonk^k_lb<S;o0000oc8b<_o^k^hAooooo`Co000000?o410@ooooooooool00_ooool2ob4Q
8@Gooooo00goA4A4o`000?l0003o<S8bomgMgOooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^
00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^3_ooool5o`0000;ooooo
00Ook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413oooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^E?ooool005oooooo00WoMgMgoc8b<_ooooooooooonk^k_mEEEGogMgMoeEE
EOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool0
0ol0003oooooooooo`02ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool00ol0003oooooooooo`04ooooo`;o8B4Q
2?ooool02OmgMgOo<S8booooooooooook^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
0oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg05Cooooo001Pooooo`07o`000?oooooooooooooooooMgMgo0000omgMg@07
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Jooooo`03o`000?oo
oooooooo00?ooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?oo
ooooooooooooool@41004oooool00ol0003oooooooooo`0?ooooo`07o`000?oooooooooooooooooM
gMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400?
ooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@4100E?ooool005oooooo00WoMgMgoc8b<_ooooooooooonk^
k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000006_ooool00ol0003oooooooooo`02ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000004oooool00ol0003ooooooooo
o`0>ooooo`09ogMgMolb<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo0000013ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000005Cooooo001Looooo`0=o`000?lQ8B7o0000oc8b<_o<c<coooooonk^k_mEEEGok^k^
ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Jooooo`0;o`000?ooooooooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Ooo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000004oooool00ol0003ooooo
ooooo`0;ooooo`0=o`000?lQ8B7o0000oc8b<_o<c<coooooonk^k_mEEEGok^k^ooooooo^k^koEEEE
onk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Aooooo`0;
ogMgMomVIVKoooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool00000E?ooool005cooooo00?o0000ooooooooool0
0oooool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@400Jooooo`04o`000?ooooooooooooooo`;ok^k^0oooool2onk^kPGooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@01?ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`03ooooo`;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@01;ooooo00?o0000ooooooooool00_o^k^h3ooooo`;ok^k^1Ooo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100E?ooool005cooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
6_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Cooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool01Ol0003o^[ZjoooooonHV9So
410@00kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg05Cooooo001L
ooooo`Co00003?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?oo
ool00ol0003oooooooooo`0=ooooo`03oeEEEOmVIVKo000000gooooo00?oEEEEofIVI_l000001?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo0_l00007ooooo`03oeEEEOmVIVKo000000gooooo
1?l0000<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`;o
00001?ooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo00?oEEEEofIVI_l000001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Sooooo0_l0001:ooooo`00P?ooool00ol0003oooooooooo`0`oooo
o`04o`000?ooooooooooo`0003Wooooo00Co0000oooooooooooo00009oooool01?l0003ooooooooo
ool00019ooooo`00N_ooool4o`0000?ooooo00?o0000ooooooooool0:_ooool4o`000005ooooool0
003oooooooooool00000=?ooool4o`000005ooooool0003oooooooooool000008_ooool4o`000005
ooooool0003oooooooooool00000BOooool0087ooooo00?o0000ooooooooool0;oooool3o`0003[o
oooo0ol0000Xooooo`?o0000B_ooool007oooooo00Co0000oooooooooooo0000<Oooool00ol0003o
ooooooooo`0jooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool03_ooool00omgMgOo
IVIVooooo`0^ooooo`03ofIVI_mgMgOooooo00Oooooo001oooooo`Co0000<_ooool00ol0003ooooo
ooooo`0jooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool03?ooool00ooMgMgo410@
onk^kP0_ooooo`03onk^k_l@413ogMgM00Oooooo003ooooooa_ooooo0_l00002ooooo`;o00003?oo
ool01?mEEEGoV9RHooooooooool2o`0000;ooooo00Oo0000oooooooooooo0000oa0@4?o^k^koEEEE
00;o000000?oA4A4okZj^_ooool00_ooool01OnHV9So0000o`000?m4A4Co^[Zj00;ooooo00Sok^k^
oeEEEOl0003o0000odA4A?nj^[[ooooooa0@40Go00000oooool02?l@413o<S8bo`000?l0003o410@
ojVYZOn7QhOoIVIV1oooool00?oooooo6oooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@cooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`08o`000?ooooooEEEEogMg
Moooooook^k^ogMgMol@4103ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000_ooool01_mEEEGoMgMg
ooooooo^k^koMgMgoa0@40?ooooo00?o0000ooooooooool01?ooool02?l0003oZJVYoooooooooooo
^[Zjo`000?o^k^ko00001oooool0023ooooolOl0000:ooooo`04omgMgOl0003o410@olc<c0gooooo
00?o<S8booooooooool00_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo000000So
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Go
oooo00Oo^[ZjohN7QomVIVKoIVIVoa0@4?oooooo000000Oooooo000Vooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`04o`000?oooooooooo
ooooo`go00001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool03Oooool01?o^k^ko8B4Qoa0@4?o^k^h=ooooo`03oc8b<_oooooooooo00;ooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooo`000005o`0000?ooooo00?o0000ooooooooool0
1?ooool6o`0000?ooooo00?o0000ooooooooool01?ooool02?lb<S;o8B4QogMgMomgMgOoQhN7onk^
k_oooooo00001oooool003_ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0aoooo
o`03o`000?oooooooooo00kooooo1Ol0000Nooooo`03o`000?oooooooooo037ooooo00?o0000oooo
ooooool03Oooool01?lQ8B7oMgMgogMgMolb<S8=ooooo`03o`000?o^k^kooooo00;ooooo00ko0000
olc<c?o<c<co0000ojVYZOoMgMgo8B4QoooooomEEEGoQhN7onk^k_ooooooQhN7oc8b<P?ooooo00?o
0000ooooooooool01?ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<P?ooooo00?o0000oc8b<_oM
gMd01?ooool02?l0003o^[Zjooooooo^k^koMgMgo`000?o^k^ko00001oooool003_ooooo00?o0000
ooooooooool0Noooool2o`0005oooooo0_l00002ooooo`;o00003?ooool03omEEEGoMgMgoooooooo
oooo410@o`000?lQ8B7o0000ogMgMol@413o0000ojVYZOooooook^k^oeEEE@02o`000004odA4A?o^
k^kooooooa0@40Go00000oooool01_o^k^koEEEEo`000?l0003oA4A4onk^kP;ooooo0_l000001?nY
ZJWo8B4Qo`000?lQ8B42ooooo`08ojVYZOlQ8B7o0000o`000?lb<S;o0000ogMgMomEEED7ooooo`00
>oooool00ol0003oooooooooo`1mooooo`;o0000COooool2o`00023ooooo00?ogMgMoa0@4?o^k^h0
4oooool00ol0003oooooooooo`0Iooooo`03onk^k_l@413ogMgM00Oooooo000kooooo`;o0000P?oo
ool2o`0004Wooooo0_l0000Sooooo`03ogMgMomVIVKooooo01;ooooo00?o0000ooooooooool06Ooo
ool00omVIVKoMgMgooooo`07ooooo`00>oooool00ol0003oooooooooo`21ooooo`03o`000?oooooo
oooo04Cooooo0_l0001Pooooo`00>oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo
047ooooo0_l0001Rooooo`00>oooool00ol0003oooooooooo`23ooooo`03o`000?oooooooooo03oo
oooo00?o0000ooooooooool0H_ooool003_ooooo00?o0000ooooooooool0Q?ooool2o`0003oooooo
00?o0000ooooooooool0H_ooool003_ooooo0_l00027ooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool0Hoooool003_ooooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`0i
ooooo`03o`000?oooooooooo06Cooooo000kooooo`03o`000?oooooooooo08Oooooo00?o0000oooo
ooooool0>?ooool00ol0003oooooooooo`1Uooooo`00>oooool00ol0003oooooooooo`28ooooo`03
o`000?oooooooooo03Kooooo00?o0000ooooooooool0I_ooool003_ooooo0_l0002:ooooo`03o`00
0?oooooooooo03Gooooo00?o0000ooooooooool0I_ooool003_ooooo00?o0000ooooooooool0R_oo
ool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo06Oooooo000kooooo`03o`000?oooooo
oooo08_ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`1Xooooo`00>oooool00ol0
003oooooooooo`2<ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0JOooool001Oo
oooo0_o^k^h3ooooo`;ok^k^7Oooool00ol0003oooooooooo`2<ooooo`03o`000?oooooooooo02ko
oooo00?o0000ooooooooool0J_ooool0017ooooo00goA4A4o`000?l0003o<S8bomgMgOooooook^k^
oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`00
0?lb<S;ok^k^3_ooool2o`0008kooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`1[
ooooo`005?ooool02OmgMgOo<S8booooooooooook^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`00
0?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oooooooooo08ko
oooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`1[ooooo`005Oooool01ol0003ooooo
oooooooooooogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@41003_ooool00ol0003oooooooooo`2?ooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool0K?ooool001Cooooo00WoMgMgoc8b<_ooooooooooonk^k_mEEEGogMgMoeEEEOo^k^h0
1_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003o
ooooooooo`2?ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0KOooool0017ooooo
00go0000ob4Q8Ol0003o<S8bolc<c?ooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000kooooo0_l0002Aooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool0KOooool0017ooooo00?o0000ooooooooool0
0oooool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@400>ooooo`03o`000?oooooooooo097ooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`1^ooooo`004Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`?o000000?oooooo`000?l000000_l00003ooooo`03
o`000?oooooooooo09;ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1_ooooo`00
4Oooool4o`0000cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Co
oooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo09?ooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`1`ooooo`00<Oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0Toooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo073ooooo000aooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo
oooo0_l0002Eooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0LOooool0037ooooo
00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo000009Oooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`1booooo`00<?ooool2o`0000?ooooo0_l00004ooooo`03
o`000?oooooooooo09Kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1booooo`00
>oooool00ol0003oooooooooo`2Fooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
Loooool003_ooooo0_l0002Hooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0M?oo
ool003_ooooo00?o0000ooooooooool0Uoooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo07Cooooo000kooooo`03o`000?oooooooooo09Sooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`1eooooo`00>oooool00ol0003oooooooooo`2Iooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool0M_ooool003_ooooo00?o0000ooooooooool0VOooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo07Oooooo000kooooo`;o0000Voooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo07Sooooo000kooooo`03o`000?oooooooooo09_ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`1iooooo`00>oooool00ol0003oooooooooo`2Loooo
o`;o00003oooool00ol0003oooooooooo`1jooooo`00>oooool00ol0003oooooooooo`2Nooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0Noooool001Oooooo0_o^k^h3ooooo`;ok^k^
7Oooool00ol0003oooooooooo`2Oooooo`03o`000?oooooooooo00Sooooo0_l0001nooooo`004Ooo
ool4o`000009oa0@4?ooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@
413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^3_ooool2o`000:7ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`1nooooo`004oooool00ol0003oooooooooo`02ooooo`05onk^k_mE
EEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03_ooool00ol0003oooooooooo`2Qooooo`So0000POooool001?ooooo00?o0000ooooooooool0
0oooool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@400>ooooo`03o`000?oooooooooo0:Cooooo0_l00024ooooo`004oooool00ol0003ooooo
ooooo`02ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000003_ooool00ol0003oooooooooo`3oooooob_ooooo000Cooooo`0;
o`000?ooooooooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000003_ooool2o`000?oooooo;?ooool001?ooooo
00Co0000oooooooooooooooo0_o^k^h3ooooo`;ok^k^1Oooool00ol0003oooooooooo`02ooooo`05
oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`3oooooob_ooooo000Cooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo0ol00002ooooo`;o00001?ooool00ol0003oooooooooo`3oooooob_ooooo000Aooooo`03
oeEEEOmVIVKo000000gooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Cooooo00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo00000?oooooo;Ooo
ool0037ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo00000?oooooo;Ooo
ool0037ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`;o0000ooooool/
ooooo`00<Oooool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool00000oooo
ool]ooooo`00<?ooool2o`0000?ooooo0_l00004ooooo`03o`000?oooooooooo0?oooooo:oooool0
03_ooooo00?o0000ooooooooool0ooooool[ooooo`00>oooool2o`000?oooooo;?ooool003_ooooo
00?o0000ooooooooool0ooooool[ooooo`00>oooool00ol0003oooooooooo`3oooooob_ooooo000k
ooooo`03o`000?oooooooooo0?oooooo:oooool003_ooooo00?o0000ooooooooool0ooooool[oooo
o`00>oooool2o`000?oooooo;?ooool003_ooooo00?o0000ooooooooool0ooooool[ooooo`00>ooo
ool00ol0003oooooooooo`3oooooob_ooooo000kooooo`03o`000?oooooooooo0?oooooo:oooool0
01Sooooo0_o^k^h3ooooo`;ok^k^7?ooool2o`000?oooooo;?ooool000;ooooo1?l000000ol@413o
ooooooooo`02ooooo`;o8B4Q1Oooool03Om4A4Co0000o`000?lb<S;ogMgMooooooo^k^koEEEEonk^
k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h=ooooo`03o`000?oooooooooo0?oooooo:oooool000Cooooo00?o0000ooooooooool01?ooool2
ob4Q8@Sooooo00WoMgMgoc8b<_ooooooooooonk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03Oooool00ol0003oooooooooo`3ooooo
ob_ooooo0004ooooo`03o`000?oooooooooo00oooooo00Oo0000ooooooooooooooooomgMgOl0003o
gMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00gooooo00?o
0000ooooooooool0ooooool[ooooo`001?ooool00ol0003oooooooooo`0>ooooo`09ogMgMolb<S;o
ooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000000gooooo00?o0000ooooooooool0ooooool[ooooo`001?ooool00ol0003o
ooooooooo`0;ooooo`0=o`000?lQ8B7o0000oc8b<_o<c<coooooonk^k_mEEEGok^k^ooooooo^k^ko
EEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000=oooo
o`;o0000ooooool/ooooo`001?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00?o
oooo0_o^k^h3ooooo`;ok^k^1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00ol0003oooooooooo`3oooooob_ooooo0004ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool3o`0000;ooooo0_l00003ooooo`03o`000?oooooooooo0?oooooo:oooool000;o
oooo00?oEEEEofIVI_l000003Oooool4o`0000cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Cooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
003oooooobgooooo000booooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo0000oooo
ool]ooooo`00<_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooooooo`;o0000oooo
ool/ooooo`00<_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`000?oooooo
;Oooool0037ooooo0_l00003ooooo`;o00000oooool00ol0003oooooooooo`3oooooob_ooooo000k
ooooo`03o`000?oooooooooo0?oooooo:oooool003_ooooo0_l0003oooooobcooooo000kooooo`03
o`000?oooooooooo0?oooooo:oooool003_ooooo00?o0000ooooooooool0ooooool[ooooo`00>ooo
ool00ol0003oooooooooo`3oooooob_ooooo000kooooo`03o`000?oooooooooo0?oooooo:oooool0
03_ooooo0_l0003oooooobcooooo000kooooo`03o`000?oooooooooo0?oooooo:oooool003_ooooo
00?o0000ooooooooool0ooooool[ooooo`005oooool2onk^kP?ooooo0_o^k^hMooooo`03o`000?oo
oooooooo0?oooooo:oooool0013ooooo1Ol00002ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEE
onk^kP03ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPkooooo0_l0003o
ooooobcooooo000@ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01Oo^k^koEEEEomgMgOmE
EEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo
00?o0000ooooooooool0ooooool[ooooo`004Oooool00onHV9So8B4Qonk^kP05ooooo`03omgMgOl0
003ogMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00kooooo
00?o0000ooooooooool0ooooool[ooooo`004_ooool00onHV9So8B4Qonk^kP03ooooo`05onk^k_mE
EEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
00003_ooool00ol0003oooooooooo`3oooooob_ooooo000Cooooo`0;ogMgMomVIVKoooooooooooo^
k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000003_ooool00ol0003oooooooooo`3oooooob_ooooo000Dooooo`03o`000?oo
oooooooo00;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@00kooooo0_l0003oooooobcooooo000@ooooo`05o`000?nj^[[ooooooiRHV?l@4100
3_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool00ol0003o
ooooooooo`3oooooob_ooooo000@ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?ooool00omEEEGo
IVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool3o`0000;ooooo0_l00004oooo
o`03o`000?oooooooooo0?oooooo:oooool0037ooooo00Co0000oooooooooooo00000_ooool01Ol0
003ooooooooooooooooo00000?oooooo;Oooool0037ooooo00?o0000ooooooooool00oooool01?l0
003oooooooooooooool2o`000?oooooo;?ooool0037ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo:oooool0037ooooo00Co0000oooooooo
oooo00000_ooool01Ol0003ooooooooooooooooo00000?oooooo;Oooool0033ooooo0_l00003oooo
o`;o00001?ooool00ol0003oooooooooo`3oooooob_ooooo000kooooo`03o`000?oooooooooo0?oo
oooo:oooool003_ooooo0_l0003oooooobcooooo000kooooo`03o`000?oooooooooo0?oooooo:ooo
ool003_ooooo00?o0000ooooooooool0ooooool[ooooo`00>oooool00ol0003oooooooooo`3ooooo
ob_ooooo000kooooo`03o`000?oooooooooo0?oooooo:oooool003_ooooo0_l0003oooooobcooooo
000kooooo`03o`000?oooooooooo0?oooooo:oooool003_ooooo00?o0000ooooooooool0ooooool[
ooooo`006?ooool2onk^kP?ooooo0_o^k^hLooooo`03o`000?oooooooooo0?oooooo:oooool00003
ooooool0003o000000?o00001Oooool2ob4Q8@Gooooo00goA4A4o`000?l0003o<S8bomgMgOoooooo
k^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8b
o`000?lb<S;ok^k^3Oooool2o`000?oooooo;?ooool00006oooooonHV9So8B4Qonk^k_ooooooA4A4
1Oooool2ob4Q8@Sooooo00WoMgMgoc8b<_ooooooooooonk^k_mEEEGogMgMoeEEEOo^k^h01_ooool0
0ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03Oooool00ol0003ooooooooo
o`3oooooob_ooooo0002ooooo`03oiRHV?lQ8B7ok^k^017ooooo00Oo0000ooooooooooooooooomgM
gOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00go
oooo00?o0000ooooooooool0ooooool[ooooo`000oooool00onHV9So8B4Qonk^kP0?ooooo`09ogMg
Molb<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool0ooooool[ooooo`001?ooool0
0omgMgOoIVIVooooo`0;ooooo`0=o`000?lQ8B7o0000oc8b<_o<c<coooooonk^k_mEEEGok^k^oooo
ooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
000=ooooo`03o`000?oooooooooo0?oooooo:oooool000Gooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`03ooooo`;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@00gooooo0_l0003oooooobcooooo00001_oooooo0000okZj^_oo
ooooV9RHoa0@40cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL03Oooool00ol0003oooooooooo`3oooooob_ooooo00001_ooooooV9RH
oa0@4?l0003o8B4Qolc<c0cooooo1?l0000<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP03ooooo`?o00000_ooool2o`0000?ooooo00?o0000ooooooooool0ooooool[
ooooo`00<_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`000?oooooo;Ooo
ool003;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02o`000?oooooo;?ooool0
03;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo00000?oooooo;Oooool0
03;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0003oooooobgooooo000a
ooooo`;o00000oooool2o`0000?ooooo00?o0000ooooooooool0ooooool[ooooo`00>oooool00ol0
003oooooooooo`3oooooob_ooooo000kooooo`;o0000ooooool/ooooo`00>oooool00ol0003ooooo
ooooo`3oooooob_ooooo000kooooo`03o`000?oooooooooo0?oooooo:oooool003_ooooo00?o0000
ooooooooool0ooooool[ooooo`00>oooool2o`000?oooooo;?ooool003_ooooo00?o0000oooooooo
ool0ooooool[ooooo`00>oooool00ol0003oooooooooo`3oooooob_ooooo000kooooo`03o`000?oo
oooooooo0?oooooo:oooool001Oooooo0_o^k^h3ooooo`;ok^k^7Oooool00ol0003oooooooooo`3o
ooooob_ooooo000@ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00_ooool01oo^k^koEEEEonk^k_oo
ooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h>
ooooo`;o0000ooooool/ooooo`004?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00Gok^k^
oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0>ooooo`03o`000?oooooooooo0?oooooo:oooool001Cooooo00?o0000ooooooooool00_oo
ool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooo
oa0@400>ooooo`03o`000?oooooooooo0?oooooo:oooool001?ooooo00?oZJVYoa0@4?ooool00_oo
ool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000kooooo00?o0000ooooooooool0ooooool[ooooo`004_ooool00ol@413o0000
okZj^P02ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo0?oooooo:oooool0
01?ooooo00Co^[Zjob4Q8Ooooooooooo0_o^k^h3ooooo`;ok^k^1Oooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@41003_ooool2o`000?oooooo;?ooool0013ooooo00Go410@
oiRHV?oooooo^[Zjo`00000>ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0>ooooo`03o`000?oooooooooo0?oooooo:oooool0013ooooo00GoZJVYoa0@4?l0003o410@
ojVYZ@0<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`?o
00000_ooool2o`0000Cooooo00?o0000ooooooooool0ooooool[ooooo`00<Oooool01?l0003ooooo
ooooool00002ooooo`05o`000?ooooooooooooooool00000ooooool]ooooo`00<Oooool00ol0003o
ooooooooo`03ooooo`04o`000?ooooooooooooooo`;o0000ooooool/ooooo`00<Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0ooooool[ooooo`00
<Oooool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool00000ooooool]oooo
o`00<?ooool2o`0000?ooooo0_l00004ooooo`03o`000?oooooooooo0?oooooo:oooool003_ooooo
00?o0000ooooooooool0ooooool[ooooo`00>oooool2o`000?oooooo;?ooool003_ooooo00?o0000
ooooooooool0ooooool[ooooo`00>oooool00ol0003oooooooooo`3oooooob_ooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo001Iooooo`03
ogMgMomVIVKooooo00Cooooo00?o0000ooooooooool00_ooool00onj^[[o<S8booooo`07ooooo`06
o`000?oooooooooooooooomVIVKoMgMg3Oooool00ol0003o^[Zjooooo`3Sooooo`00F?ooool00ooM
gMgo410@onk^kP05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01_ooool01ol0
003oooooooooooooooook^k^oa0@4?oMgMd03?ooool2oc8b<^Cooooo001Hooooo`03oeEEEOnHV9So
oooo00Gooooo00Ko0000oooooooooooooooooiRHV?l@4102o`000003ojVYZOoooooooooo00Cooooo
00?o0000ooooooooool00_ooool00on7QhOoIVIVooooo`0;ooooo`03ohN7Qol0003o^[Zj00Gooooo
1?l000000ol@413oooooooooo`02ooooo`;o000000?o410@ooooooooool00oooool2ob4Q8@;ooooo
00Goc<c<onk^k_ooooook^k^olc<c004ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o
<S8bonk^kQ?ooooo00Ko410@oc8b<_l0003o0000oa0@4?nYZJT2ooooo`06onk^k_mEEEGo0000o`00
0?m4A4Co^[Zj0oooool01OmVIVKo0000o`000?m4A4Coc<c<08_ooooo001Hooooo`03o`000?oooooo
oooo00Gooooo00[o0000ooooooooooooooooo`000?nYZJWoEEEEoiRHV?mEEEGo^[Zj1Oooool00ol0
003oooooooooo`02ooooo`03onk^k_l0003ooooo00_ooooo00?oc<c<o`000?l@41001oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo0_lQ8B42ooooo`05onk^k_mEEEGogMgM
oeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04ooo
ool01_l0003oZJVYoooooooooooo^[Zjo`0000;ooooo00KoEEEEogMgMoooooook^k^ogMgMol@4102
ooooo`06ofIVI_mgMgOooooooooooon7QhOo410@Roooool005Sooooo00?o<S8booooooooool01Ooo
ool02_l0003ooooooooooooooooo<S8bonk^k_nHV9SoEEEEomgMgOl@4105ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`02ooooo`Go00002_ooool0
0ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
400Dooooo`05okZj^_n7QhOoIVIVofIVI_l@41000_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo08kooooo001Hooooo`03oc8b<_oooooooooo00Gooooo00_o0000oooooooooooooooo
okZj^_m4A4Coc<c<ob4Q8Ooooooo410@olc<c004ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`02ooooo`04odA4A?oMgMgoooooo`0000[ooooo00Go
k^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`00000Cooooo`06oc8b<_lQ8B7oMgMgogMgMon7QhOok^k^0_ooool6o`0000;ooooo00?o0000
ooooooooool0S_ooool005Sooooo00?o0000onk^k_ooool01Oooool02ol0003ooooooooooooooooo
k^k^o`000?oooooo0000oooooomVIVKoQhN700Cooooo00?o0000ooooooooool00_ooool00oo^k^ko
0000ooooo`0Eooooo`03o`000?oooooooooo00;ooooo00CogMgMoeEEEOoooooo00002_ooool01Oo<
c<cok^k^ooooooo^k^koc<c<00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000001?ooooo00Ko0000okZj^_ooooook^k^ogMgMol00002ooooo`06oeEEEOn7QhOok^k^oooo
oon7QhOo<S8b0_ooool01_mVIVKoMgMgooooooooooooQhN7o`0008_ooooo001Hooooo`03oeEEEOmg
MgOooooo00Gooooo00So0000ooooooooooooooooofIVI_nHV9Sooooooc8b<P;o^[Zj00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`02ooooo`03ogMgMomEEEGooooo00?ooooo1?l0000>oooo
o`03o`000?oooooooooo00?ooooo00?oMgMgolc<c?l000005Oooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@41001oooool3o`0000;ooooo0ol00004ooooo`06ojVYZOlQ8B7o
0000o`000?lb<S;o00000_ooool01_o^k^koEEEEo`000?l0003oA4A4onk^kP;ooooo00Kok^k^ofIV
I_l0003o0000odA4A?l0002;ooooo`00F?ooool00ooMgMgo410@onk^kP05ooooo`03o`000?oooooo
oooo00Cooooo00?oIVIVohN7Qoooool01Oooool01ol0003oooooooooooooooook^k^oa0@4?oMgMd0
1Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00?ooooo00?ok^k^odA4A?l00000
5Oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo0:Cooooo001Iooooo`03ogMgMomVIVKooooo00Cooooo
00?o0000ooooooooool01?ooool00onYZJWoA4A4ooooo`05ooooo`06o`000?oooooooooooooooomV
IVKoMgMg1oooool00ol0003oooooooooo`0;ooooo`03oeEEEOmVIVKo000000Kooooo00?oMgMgo`00
0?ooool04_ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_ooool4
o`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2Tooooo`00OOooool00ol0
003oooooooooo`0looooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Y?ooool007[o
oooo00Co0000oooooooooooo0000?_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
0:Cooooo001kooooo`;o0000?_ooool2o`0000?ooooo0_l0002Vooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -2.14748*^9, 0, \
2.14748*^9}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0 1.90278e-14 [
[.32684 -0.0125 -16.5 -12.5 ]
[.32684 -0.0125 16.5 0 ]
[.54329 -0.0125 -16.5 -12.5 ]
[.54329 -0.0125 16.5 0 ]
[.75974 -0.0125 -22.5 -12.5 ]
[.75974 -0.0125 22.5 0 ]
[.97619 -0.0125 -16.5 -12.5 ]
[.97619 -0.0125 16.5 0 ]
[1.025 0 0 -6 ]
[1.025 0 64 6 ]
[.09789 .09514 -33 -6.25 ]
[.09789 .09514 0 6.25 ]
[.09789 .19028 -33 -6.25 ]
[.09789 .19028 0 6.25 ]
[.09789 .28542 -45 -6.25 ]
[.09789 .28542 0 6.25 ]
[.09789 .38056 -33 -6.25 ]
[.09789 .38056 0 6.25 ]
[.09789 .47569 -45 -6.25 ]
[.09789 .47569 0 6.25 ]
[.09789 .57083 -33 -6.25 ]
[.09789 .57083 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -56.4375 0 ]
[.5 .63053 56.4375 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 0 m
.32684 .00625 L
s
gsave
.32684 -0.0125 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 0 m
.54329 .00625 L
s
gsave
.54329 -0.0125 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 0 m
.75974 .00625 L
s
gsave
.75974 -0.0125 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 0 m
.97619 .00625 L
s
gsave
.97619 -0.0125 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 0 m
.15368 .00375 L
s
.19697 0 m
.19697 .00375 L
s
.24026 0 m
.24026 .00375 L
s
.28355 0 m
.28355 .00375 L
s
.37013 0 m
.37013 .00375 L
s
.41342 0 m
.41342 .00375 L
s
.45671 0 m
.45671 .00375 L
s
.5 0 m
.5 .00375 L
s
.58658 0 m
.58658 .00375 L
s
.62987 0 m
.62987 .00375 L
s
.67316 0 m
.67316 .00375 L
s
.71645 0 m
.71645 .00375 L
s
.80303 0 m
.80303 .00375 L
s
.84632 0 m
.84632 .00375 L
s
.88961 0 m
.88961 .00375 L
s
.9329 0 m
.9329 .00375 L
s
.0671 0 m
.0671 .00375 L
s
.02381 0 m
.02381 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09514 m
.11664 .09514 L
s
gsave
.09789 .09514 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(12) show
grestore
.11039 .19028 m
.11664 .19028 L
s
gsave
.09789 .19028 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.11039 .28542 m
.11664 .28542 L
s
gsave
.09789 .28542 -45 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.11039 .38056 m
.11664 .38056 L
s
gsave
.09789 .38056 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.11039 .47569 m
.11664 .47569 L
s
gsave
.09789 .47569 -45 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.11039 .57083 m
.11664 .57083 L
s
gsave
.09789 .57083 -33 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(3) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(13) show
grestore
.125 Mabswid
.11039 .01903 m
.11414 .01903 L
s
.11039 .03806 m
.11414 .03806 L
s
.11039 .05708 m
.11414 .05708 L
s
.11039 .07611 m
.11414 .07611 L
s
.11039 .11417 m
.11414 .11417 L
s
.11039 .13319 m
.11414 .13319 L
s
.11039 .15222 m
.11414 .15222 L
s
.11039 .17125 m
.11414 .17125 L
s
.11039 .20931 m
.11414 .20931 L
s
.11039 .22833 m
.11414 .22833 L
s
.11039 .24736 m
.11414 .24736 L
s
.11039 .26639 m
.11414 .26639 L
s
.11039 .30444 m
.11414 .30444 L
s
.11039 .32347 m
.11414 .32347 L
s
.11039 .3425 m
.11414 .3425 L
s
.11039 .36153 m
.11414 .36153 L
s
.11039 .39958 m
.11414 .39958 L
s
.11039 .41861 m
.11414 .41861 L
s
.11039 .43764 m
.11414 .43764 L
s
.11039 .45667 m
.11414 .45667 L
s
.11039 .49472 m
.11414 .49472 L
s
.11039 .51375 m
.11414 .51375 L
s
.11039 .53278 m
.11414 .53278 L
s
.11039 .55181 m
.11414 .55181 L
s
.11039 .58986 m
.11414 .58986 L
s
.11039 .60889 m
.11414 .60889 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -117.438 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.812 moveto
(H) show
69.000 13.812 moveto
(\\310) show
75.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
81.000 13.812 moveto
(\\310) show
87.000 13.812 moveto
(L) show
93.000 9.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
98.250 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
104.250 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15.) show
122.250 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
128.250 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
140.250 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
144.438 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
153.875 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
171.875 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 0 m
.02605 0 L
.02846 0 L
.03072 0 L
.03279 0 L
.03521 0 L
.03784 0 L
.04032 0 L
.04262 0 L
.04498 0 L
.0472 0 L
.04963 0 L
.05224 0 L
.05497 0 L
.05757 0 L
.0599 0 L
.06244 0 L
.06382 0 L
.0653 0 L
.06799 0 L
.07061 0 L
.07302 0 L
.07563 0 L
.0785 0 L
.07995 0 L
.0815 0 L
.08429 0 L
.0869 0 L
.08974 0 L
.09242 0 L
.09491 0 L
.09713 0 L
.0996 0 L
.10217 0 L
.10458 0 L
.10701 0 L
.10928 0 L
.11176 0 L
.11441 0 L
.1172 0 L
.11983 0 L
.1222 0 L
.12476 0 L
.12699 0 L
.12944 0 L
.132 0 L
.13439 0 L
.13663 0 L
.13867 0 L
.14103 0 L
Mistroke
.14327 0 L
.14587 0 L
.14831 0 L
.15051 0 L
.15288 0 L
.15547 0 L
.15821 0 L
.16055 0 L
.16311 0 L
.16552 0 L
.16771 0 L
.17024 0 L
.17263 0 L
.17485 0 L
.17689 0 L
.17913 0 L
.18151 0 L
.1839 0 L
.18642 0 L
.18856 0 L
.19091 0 L
.19344 0 L
.19615 0 L
.1987 0 L
.20102 0 L
.20338 0 L
.20554 0 L
.20792 0 L
.21044 0 L
.21262 0 L
.21467 0 L
.21692 0 L
.21932 0 L
.22191 0 L
.22431 0 L
.22689 0 L
.22975 0 L
.2322 0 L
.23485 0 L
.23735 0 L
.23964 0 L
.24395 0 L
.2464 0 L
.24867 0 L
.25327 0 L
.25585 0 L
.25819 0 L
.26303 0 L
.26547 0 L
.26816 0 L
Mistroke
.27045 0 L
.27291 0 L
.27735 0 L
.28002 0 L
.28292 0 L
.28566 0 L
.28821 0 L
.29302 0 L
.29571 0 L
.29814 0 L
.30302 0 L
.30548 0 L
.30818 0 L
.31048 0 L
.31295 0 L
.3174 0 L
.32008 0 L
.323 0 L
.32575 0 L
.3283 0 L
.33311 0 L
.33555 0 L
.33823 0 L
.34315 0 L
.34562 0 L
.34833 0 L
.35065 0 L
.35313 0 L
.35759 0 L
.36029 0 L
.36321 0 L
.36579 0 L
.36852 0 L
.37098 0 L
.37369 0 L
.37845 0 L
.38095 0 L
.38367 0 L
.38607 0 L
.38862 0 L
.39344 0 L
.39791 0 L
.40063 0 L
.40357 0 L
.40615 0 L
.40888 0 L
.41406 0 L
.41881 0 L
.42379 0 L
.42832 0 L
Mistroke
.43356 0 L
.4385 0 L
.44308 0 L
.4473 0 L
.45194 0 L
.45685 0 L
.46176 0 L
.46626 0 L
.47145 0 L
.47638 0 L
.48091 0 L
.48513 0 L
.48975 0 L
.49468 0 L
.50003 1e-05 L
.50496 1e-05 L
.51036 1e-05 L
.51608 1e-05 L
.52105 2e-05 L
.52569 2e-05 L
.53079 3e-05 L
.53625 4e-05 L
.54153 5e-05 L
.54641 6e-05 L
.55178 8e-05 L
.55748 .00011 L
.56704 .00017 L
.57248 .00022 L
.5776 .00028 L
.58742 .00043 L
.59236 .00054 L
.59777 .00068 L
.60735 .00101 L
.61627 .00144 L
.62679 .00215 L
.63672 .0031 L
.64563 .00425 L
.6553 .00589 L
.66476 .00799 L
.67517 .01098 L
.68604 .01503 L
.69621 .01981 L
.71649 .03268 L
.73502 .04872 L
.77477 .09512 L
.813 .14219 L
.82315 .15203 L
.83271 .15947 L
.838 .16271 L
.84372 .16544 L
Mistroke
.84624 .16638 L
.84891 .16719 L
.85119 .16773 L
.8524 .16797 L
.85369 .16817 L
.855 .16833 L
.85621 .16843 L
.85751 .1685 L
.85825 .16852 L
.85894 .16853 L
.86019 .1685 L
.86134 .16844 L
.86259 .16833 L
.86391 .16817 L
.86622 .16778 L
.86836 .16729 L
.87323 .16572 L
.87853 .1633 L
.88335 .16051 L
.89415 .15232 L
.91337 .13244 L
.93417 .10641 L
.97513 .05635 L
.97619 .05523 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00H_ooool2onk^kP?ooooo0_o^
k^h]ooooo`;ok^k^0oooool2onk^kSKooooo0_o^k^h3ooooo`;ok^k^9?ooool2onk^kP?ooooo0_o^
k^iSooooo`00G?ooool03Om4A4Co0000o`000?lb<S;ogMgMooooooo^k^koEEEEonk^k_ooooook^k^
oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hHooooo`Co
000000Wo410@ooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?oo
ooooooooonk^k_lb<S;o0000oc8b<_o^k^hAooooo`Co000000?o410@ooooooooool00_ooool2ob4Q
8@Gooooo00goA4A4o`000?l0003o<S8bomgMgOooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^
00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^3_ooool5o`0000;ooooo
00Ook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413oooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^E?ooool005oooooo00WoMgMgoc8b<_ooooooooooonk^k_mEEEGogMgMoeEE
EOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool0
0ol0003oooooooooo`02ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool00ol0003oooooooooo`04ooooo`;o8B4Q
2?ooool02OmgMgOo<S8booooooooooook^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
0oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg05Cooooo001Pooooo`07o`000?oooooooooooooooooMgMgo0000omgMg@07
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Jooooo`03o`000?oo
oooooooo00?ooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?oo
ooooooooooooool@41004oooool00ol0003oooooooooo`0?ooooo`07o`000?oooooooooooooooooM
gMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400?
ooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@4100E?ooool005oooooo00WoMgMgoc8b<_ooooooooooonk^
k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000006_ooool00ol0003oooooooooo`02ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000004oooool00ol0003ooooooooo
o`0>ooooo`09ogMgMolb<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo0000013ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000005Cooooo001Looooo`0=o`000?lQ8B7o0000oc8b<_o<c<coooooonk^k_mEEEGok^k^
ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Jooooo`0;o`000?ooooooooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Ooo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000004oooool00ol0003ooooo
ooooo`0;ooooo`0=o`000?lQ8B7o0000oc8b<_o<c<coooooonk^k_mEEEGok^k^ooooooo^k^koEEEE
onk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Aooooo`0;
ogMgMomVIVKoooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool00000E?ooool005cooooo00?o0000ooooooooool0
0oooool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@400Jooooo`04o`000?ooooooooooooooo`;ok^k^0oooool2onk^kPGooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@01?ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`03ooooo`;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@01;ooooo00?o0000ooooooooool00_o^k^h3ooooo`;ok^k^1Ooo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100E?ooool005cooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
6_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0Cooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool01Ol0003o^[ZjoooooonHV9So
410@00kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg05Cooooo001L
ooooo`Co00003?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?oo
ool00ol0003oooooooooo`0=ooooo`03oeEEEOmVIVKo000000gooooo00?oEEEEofIVI_l000001?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo0_l00007ooooo`03oeEEEOmVIVKo000000gooooo
1?l0000<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`;o
00001?ooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo00?oEEEEofIVI_l000001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Sooooo0_l0001:ooooo`00P?ooool00ol0003oooooooooo`0`oooo
o`04o`000?ooooooooooo`0003Wooooo00Co0000oooooooooooo00009oooool01?l0003ooooooooo
ool00019ooooo`00N_ooool4o`0000?ooooo00?o0000ooooooooool0:_ooool4o`000005ooooool0
003oooooooooool00000=?ooool4o`000005ooooool0003oooooooooool000008_ooool4o`000005
ooooool0003oooooooooool00000BOooool0087ooooo00?o0000ooooooooool0;oooool3o`0003[o
oooo0ol0000Xooooo`?o0000B_ooool007oooooo00Co0000oooooooooooo0000<Oooool00ol0003o
ooooooooo`0jooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool03_ooool00omgMgOo
IVIVooooo`0^ooooo`03ofIVI_mgMgOooooo00Oooooo001oooooo`Co0000<_ooool00ol0003ooooo
ooooo`0jooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool03?ooool00ooMgMgo410@
onk^kP0_ooooo`03onk^k_l@413ogMgM00Oooooo003ooooooa_ooooo0_l00002ooooo`;o00003?oo
ool01?mEEEGoV9RHooooooooool2o`0000;ooooo00Oo0000oooooooooooo0000oa0@4?o^k^koEEEE
00;o000000?oA4A4okZj^_ooool00_ooool01OnHV9So0000o`000?m4A4Co^[Zj00;ooooo00Sok^k^
oeEEEOl0003o0000odA4A?nj^[[ooooooa0@40Go00000oooool02?l@413o<S8bo`000?l0003o410@
ojVYZOn7QhOoIVIV1oooool00?oooooo6oooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@cooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`08o`000?ooooooEEEEogMg
Moooooook^k^ogMgMol@4103ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000_ooool01_mEEEGoMgMg
ooooooo^k^koMgMgoa0@40?ooooo00?o0000ooooooooool01?ooool02?l0003oZJVYoooooooooooo
^[Zjo`000?o^k^ko00001oooool0023ooooolOl0000:ooooo`04omgMgOl0003o410@olc<c0gooooo
00?o<S8booooooooool00_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo000000So
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Go
oooo00Oo^[ZjohN7QomVIVKoIVIVoa0@4?oooooo000000Oooooo000Vooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooool000003_l00004ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool03Oooool01?o^k^ko8B4Qoa0@4?o^k^h=ooooo`03oc8b<_oooooooooo00;ooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooo`000005o`0000?ooooo00?o0000ooooooooool01?oo
ool6o`0000?ooooo00?o0000ooooooooool01?ooool02?lb<S;o8B4QogMgMomgMgOoQhN7onk^k_oo
oooo00001oooool003_ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0aooooo`03
o`000?oooooooooo01Sooooo1?l0000Eooooo`03o`000?oooooooooo037ooooo00?o0000oooooooo
ool03Oooool01?lQ8B7oMgMgogMgMolb<S8=ooooo`03o`000?o^k^kooooo00;ooooo00ko0000olc<
c?o<c<co0000ojVYZOoMgMgo8B4QoooooomEEEGoQhN7onk^k_ooooooQhN7oc8b<P?ooooo00?o0000
ooooooooool01?ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<P?ooooo00?o0000oc8b<_oMgMd0
1?ooool02?l0003o^[Zjooooooo^k^koMgMgo`000?o^k^ko00001oooool003_ooooo00?o0000oooo
ooooool0Q?ooool3o`0005Gooooo0_l00002ooooo`;o00003?ooool03omEEEGoMgMgoooooooooooo
410@o`000?lQ8B7o0000ogMgMol@413o0000ojVYZOooooook^k^oeEEE@02o`000004odA4A?o^k^ko
oooooa0@40Go00000oooool01_o^k^koEEEEo`000?l0003oA4A4onk^kP;ooooo0_l000001?nYZJWo
8B4Qo`000?lQ8B42ooooo`08ojVYZOlQ8B7o0000o`000?lb<S;o0000ogMgMomEEED7ooooo`00>ooo
ool00ol0003oooooooooo`27ooooo`?o0000I?ooool00ooMgMgo410@onk^kP0Cooooo`03o`000?oo
oooooooo01Wooooo00?ok^k^oa0@4?oMgMd01oooool003_ooooo0_l0002;ooooo`;o0000Hoooool0
0omgMgOoIVIVooooo`0Booooo`03o`000?oooooooooo01Wooooo00?oIVIVogMgMoooool01oooool0
03_ooooo00?o0000ooooooooool0S?ooool00ol0003oooooooooo`2Kooooo`00>oooool00ol0003o
ooooooooo`2=ooooo`03o`000?oooooooooo09[ooooo000kooooo`03o`000?oooooooooo08kooooo
0_l0002Jooooo`00>oooool00ol0003oooooooooo`2@ooooo`03o`000?oooooooooo09Oooooo000k
ooooo`;o0000T_ooool00ol0003oooooooooo`2Fooooo`00>oooool00ol0003oooooooooo`2Boooo
o`03o`000?oooooooooo09Gooooo000kooooo`03o`000?oooooooooo09?ooooo00?o0000oooooooo
ool0U?ooool003_ooooo00?o0000ooooooooool0Toooool00ol0003oooooooooo`2Dooooo`00>ooo
ool2o`0009Gooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`1Jooooo`00>oooool0
0ol0003oooooooooo`2Eooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0F_ooool0
03_ooooo00?o0000ooooooooool0U_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo
05_ooooo000kooooo`03o`000?oooooooooo09Oooooo00?o0000ooooooooool0<Oooool00ol0003o
ooooooooo`1Looooo`005oooool2onk^kP?ooooo0_o^k^hMooooo`03o`000?oooooooooo09Sooooo
00?o0000ooooooooool0;oooool00ol0003oooooooooo`1Mooooo`004Oooool03Om4A4Co0000o`00
0?lb<S;ogMgMooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?oo
ooooooooonk^k_lb<S;o0000oc8b<_o^k^h>ooooo`;o0000VOooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooooooo05kooooo000Dooooo`09ogMgMolb<S;oooooooooooo^k^koEEEEomgMgOmE
EEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo
00?o0000ooooooooool0VOooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo05oooooo
000Eooooo`07o`000?oooooooooooooooooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;o
oooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo09[ooooo00?o0000oooo
ooooool0:oooool00ol0003oooooooooo`1Oooooo`005?ooool02OmgMgOo<S8booooooooooook^k^
oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000>ooooo`03o`000?oooooooooo09_ooooo00?o0000ooooooooool0:Oooool00ol0003ooooo
ooooo`1Pooooo`004Oooool03Ol0003o8B4Qo`000?lb<S;oc<c<ooooooo^k^koEEEEonk^k_oooooo
k^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
3_ooool2o`0009gooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1Qooooo`004Ooo
ool00ol0003oooooooooo`03ooooo`;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool0W?ooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo06;ooooo000Aooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo0ol000000ooooooo0000
o`000002o`0000?ooooo00?o0000ooooooooool0WOooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo06?ooooo000Aooooo`Co00003?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01?ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000oooooooo
ool0W_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo06Cooooo000aooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2Oooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool0I?ooool0037ooooo00?o0000ooooooooool00ooo
ool01?l0003oooooooooooooool2o`000:7ooooo00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`1Uooooo`00<Oooool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool0
0000Xoooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo06Kooooo000`ooooo`;o0000
0oooool2o`0000Cooooo00?o0000ooooooooool0XOooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo06Oooooo000kooooo`03o`000?oooooooooo0:;ooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`1Xooooo`00>oooool2o`000:Cooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`1Yooooo`00>oooool00ol0003oooooooooo`2Tooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool0J_ooool003_ooooo00?o0000ooooooooool0YOooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo06_ooooo000kooooo`03o`000?oooooooooo0:Kooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`1/ooooo`00>oooool00ol0003ooooooooo
o`2Wooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0KOooool003_ooooo0_l0002Y
ooooo`03o`000?oooooooooo00gooooo0_l0001`ooooo`00>oooool00ol0003oooooooooo`2Yoooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0L?ooool003_ooooo00?o0000oooooooo
ool0Z_ooool3o`0000Wooooo00?o0000ooooooooool0LOooool003_ooooo00?o0000ooooooooool0
[Oooool2o`0000Gooooo0_l0001dooooo`005oooool2onk^kP?ooooo0_o^k^hMooooo`03o`000?oo
oooooooo0:kooooo1_l0001fooooo`004Oooool4o`000009oa0@4?ooooook^k^oeEEEOo^k^kooooo
onk^k_mEEEGok^k^00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^3_oo
ool2o`000?oooooo;?ooool001?ooooo00?o0000ooooooooool00_ooool01Oo^k^koEEEEomgMgOmE
EEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo
00?o0000ooooooooool0ooooool[ooooo`004oooool00ol0003oooooooooo`03ooooo`03omgMgOl0
003ogMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00kooooo
00?o0000ooooooooool0ooooool[ooooo`004oooool00ol0003oooooooooo`02ooooo`05onk^k_mE
EEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
00003_ooool00ol0003oooooooooo`3oooooob_ooooo000Cooooo`0;o`000?ooooooooooooooooo^
k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000003_ooool2o`000?oooooo;?ooool001?ooooo00Co0000oooooooooooooooo
0_o^k^h3ooooo`;ok^k^1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41003_ooool00ol0003oooooooooo`3oooooob_ooooo000Cooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo0ol00002ooooo`;o
00001?ooool00ol0003oooooooooo`3oooooob_ooooo000Aooooo`03oeEEEOmVIVKo000000gooooo
00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo00Co0000oooooooo
oooo00000_ooool01Ol0003ooooooooooooooooo00000?oooooo;Oooool0037ooooo00?o0000oooo
ooooool00oooool01Ol0003ooooooooooooooooo00000?oooooo;Oooool0037ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`02ooooo`;o0000ooooool/ooooo`00<Oooool01?l0003o
ooooooooool00002ooooo`05o`000?ooooooooooooooool00000ooooool]ooooo`00<?ooool2o`00
00?ooooo0_l00004ooooo`03o`000?oooooooooo0?oooooo:oooool003_ooooo00?o0000oooooooo
ool0ooooool[ooooo`00>oooool2o`000?oooooo;?ooool003_ooooo00?o0000ooooooooool0oooo
ool[ooooo`00>oooool00ol0003oooooooooo`3oooooob_ooooo000kooooo`03o`000?oooooooooo
0?oooooo:oooool003_ooooo00?o0000ooooooooool0ooooool[ooooo`00>oooool2o`000?oooooo
;?ooool003_ooooo00?o0000ooooooooool0ooooool[ooooo`00>oooool00ol0003oooooooooo`3o
ooooob_ooooo000kooooo`03o`000?oooooooooo0?oooooo:oooool001Sooooo0_o^k^h3ooooo`;o
k^k^7?ooool2o`000?oooooo;?ooool000;ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q
1Oooool03Om4A4Co0000o`000?lb<S;ogMgMooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h0
0oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h=ooooo`03o`000?oooooo
oooo0?oooooo:oooool000Cooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00WoMgMgoc8b
<_ooooooooooonk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL03Oooool00ol0003oooooooooo`3oooooob_ooooo0004ooooo`03o`00
0?oooooooooo00oooooo00Oo0000ooooooooooooooooomgMgOl0003ogMgM00Oooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@00gooooo00?o0000ooooooooool0ooooool[
ooooo`001?ooool00ol0003oooooooooo`0>ooooo`09ogMgMolb<S;oooooooooooo^k^koEEEEomgM
gOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000go
oooo00?o0000ooooooooool0ooooool[ooooo`001?ooool00ol0003oooooooooo`0;ooooo`0=o`00
0?lQ8B7o0000oc8b<_o<c<coooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000=ooooo`;o0000ooooool/ooooo`00
1?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo0_o^k^h3ooooo`;ok^k^
1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41003Oooool00ol0003o
ooooooooo`3oooooob_ooooo0004ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool3o`0000;o
oooo0_l00003ooooo`03o`000?oooooooooo0?oooooo:oooool000;ooooo00?oEEEEofIVI_l00000
3Oooool4o`0000cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Co
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0003oooooobgooooo000boooo
o`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo0000ooooool]ooooo`00<_ooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooooooo`;o0000ooooool/ooooo`00<_ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`000?oooooo;Oooool0037ooooo0_l00003
ooooo`;o00000oooool00ol0003oooooooooo`3oooooob_ooooo000kooooo`03o`000?oooooooooo
0?oooooo:oooool003_ooooo0_l0003oooooobcooooo000kooooo`03o`000?oooooooooo0?oooooo
:oooool003_ooooo00?o0000ooooooooool0ooooool[ooooo`00>oooool00ol0003oooooooooo`3o
ooooob_ooooo000kooooo`03o`000?oooooooooo0?oooooo:oooool003_ooooo0_l0003oooooobco
oooo000kooooo`03o`000?oooooooooo0?oooooo:oooool003_ooooo00?o0000ooooooooool0oooo
ool[ooooo`005oooool2onk^kP?ooooo0_o^k^hMooooo`03o`000?oooooooooo0?oooooo:oooool0
013ooooo1Ol00002ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co000000So
410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPkooooo0_l0003oooooobcooooo000@ooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000
ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00?o0000ooooooooool0oooo
ool[ooooo`004Oooool00onHV9So8B4Qonk^kP05ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool0oooo
ool[ooooo`004_ooool00onHV9So8B4Qonk^kP03ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_oo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003ooooo
ooooo`3oooooob_ooooo000Cooooo`0;ogMgMomVIVKoooooooooooo^k^koEEEEonk^k_ooooook^k^
oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000003_oo
ool00ol0003oooooooooo`3oooooob_ooooo000Dooooo`03o`000?oooooooooo00;ok^k^0oooool2
onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00kooooo0_l0
003oooooobcooooo000@ooooo`05o`000?nj^[[ooooooiRHV?l@41003_ooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`3oooooob_ooooo
000@ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?ooool00omEEEGoIVIVo`000004ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h00oooool3o`0000;ooooo0_l00004ooooo`03o`000?oooooooooo0?oo
oooo:oooool0037ooooo00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo0000
0?oooooo;Oooool0037ooooo00?o0000ooooooooool00oooool01?l0003oooooooooooooool2o`00
0?oooooo;?ooool0037ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo0?oooooo:oooool0037ooooo00Co0000oooooooooooo00000_ooool01Ol0003o
oooooooooooooooo00000?oooooo;Oooool0033ooooo0_l00003ooooo`;o00001?ooool00ol0003o
ooooooooo`3oooooob_ooooo000kooooo`03o`000?oooooooooo0?oooooo:oooool003_ooooo0_l0
003oooooobcooooo000kooooo`03o`000?oooooooooo0?oooooo:oooool003_ooooo00?o0000oooo
ooooool0ooooool[ooooo`00>oooool00ol0003oooooooooo`3oooooob_ooooo000kooooo`03o`00
0?oooooooooo0?oooooo:oooool003_ooooo0_l0003oooooobcooooo000kooooo`03o`000?oooooo
oooo0?oooooo:oooool003_ooooo00?o0000ooooooooool0ooooool[ooooo`006?ooool2onk^kP?o
oooo0_o^k^hLooooo`03o`000?oooooooooo0?oooooo:oooool00003ooooool0003o000000?o0000
1Oooool2ob4Q8@Gooooo00goA4A4o`000?l0003o<S8bomgMgOooooook^k^oeEEEOo^k^koooooonk^
k_mEEEGok^k^00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^3Oooool2
o`000?oooooo;?ooool00006oooooonHV9So8B4Qonk^k_ooooooA4A41Oooool2ob4Q8@Sooooo00Wo
MgMgoc8b<_ooooooooooonk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03Oooool00ol0003oooooooooo`3oooooob_ooooo0002oooo
o`03oiRHV?lQ8B7ok^k^017ooooo00Oo0000ooooooooooooooooomgMgOl0003ogMgM00Oooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00gooooo00?o0000ooooooooool0
ooooool[ooooo`000oooool00onHV9So8B4Qonk^kP0?ooooo`09ogMgMolb<S;oooooooooooo^k^ko
EEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo
000000gooooo00?o0000ooooooooool0ooooool[ooooo`001?ooool00omgMgOoIVIVooooo`0;oooo
o`0=o`000?lQ8B7o0000oc8b<_o<c<coooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05oooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000=ooooo`03o`000?oooooo
oooo0?oooooo:oooool000Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`03oooo
o`;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@00gooooo0_l0003oooooobcooooo00001_oooooo0000okZj^_ooooooV9RHoa0@40cooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3Oooool00ol0003oooooooooo`3oooooob_ooooo00001_ooooooV9RHoa0@4?l0003o8B4Qolc<c0co
oooo1?l0000<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03oooo
o`?o00000_ooool2o`0000?ooooo00?o0000ooooooooool0ooooool[ooooo`00<_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`000?oooooo;Oooool003;ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02o`000?oooooo;?ooool003;ooooo00?o0000oooooooo
ool00_ooool01Ol0003ooooooooooooooooo00000?oooooo;Oooool003;ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool0003oooooobgooooo000aooooo`;o00000oooool2o`00
00?ooooo00?o0000ooooooooool0ooooool[ooooo`00>oooool00ol0003oooooooooo`3oooooob_o
oooo000kooooo`;o0000ooooool/ooooo`00>oooool00ol0003oooooooooo`3oooooob_ooooo000k
ooooo`03o`000?oooooooooo0?oooooo:oooool003_ooooo00?o0000ooooooooool0ooooool[oooo
o`00>oooool2o`000?oooooo;?ooool003_ooooo00?o0000ooooooooool0ooooool[ooooo`00>ooo
ool00ol0003oooooooooo`3oooooob_ooooo000kooooo`03o`000?oooooooooo0?oooooo:oooool0
01Oooooo0_o^k^h3ooooo`;ok^k^7Oooool00ol0003oooooooooo`3oooooob_ooooo000@ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`00_ooool01oo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00ooo
ool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h>ooooo`;o0000ooooool/oooo
o`004?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06
ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oo
oooooooo0?oooooo:oooool001Cooooo00?o0000ooooooooool00_ooool00ooMgMgo0000omgMg@07
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oo
oooooooo0?oooooo:oooool001?ooooo00?oZJVYoa0@4?ooool00_ooool01Oo^k^koEEEEomgMgOmE
EEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000kooooo
00?o0000ooooooooool0ooooool[ooooo`004_ooool00ol@413o0000okZj^P02ooooo`07onk^k_mE
EEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`00000>ooooo`03o`000?oooooooooo0?oooooo:oooool001?ooooo00Co^[Zjob4Q8Ooo
oooooooo0_o^k^h3ooooo`;ok^k^1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@41003_ooool2o`000?oooooo;?ooool0013ooooo00Go410@oiRHV?oooooo^[Zjo`00000>
ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oo
oooooooo0?oooooo:oooool0013ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@0<ooooo`03oeEEEOmV
IVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`?o00000_ooool2o`0000Cooooo
00?o0000ooooooooool0ooooool[ooooo`00<Oooool01?l0003oooooooooool00002ooooo`05o`00
0?ooooooooooooooool00000ooooool]ooooo`00<Oooool00ol0003oooooooooo`03ooooo`04o`00
0?ooooooooooooooo`;o0000ooooool/ooooo`00<Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0ooooool[ooooo`00<Oooool01?l0003ooooooooo
ool00002ooooo`05o`000?ooooooooooooooool00000ooooool]ooooo`00<?ooool2o`0000?ooooo
0_l00004ooooo`03o`000?oooooooooo0?oooooo:oooool003_ooooo00?o0000ooooooooool0oooo
ool[ooooo`00>oooool2o`000?oooooo;?ooool003_ooooo00?o0000ooooooooool0ooooool[oooo
o`00>oooool00ol0003oooooooooo`3oooooob_ooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo001Iooooo`03ogMgMomVIVKooooo00Cooooo
00?o0000ooooooooool00_ooool00onj^[[o<S8booooo`07ooooo`06o`000?oooooooooooooooomV
IVKoMgMg3Oooool00ol0003o^[Zjooooo`3Sooooo`00F?ooool00ooMgMgo410@onk^kP05ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool01_ooool01ol0003oooooooooooooooook^k^
oa0@4?oMgMd03?ooool2oc8b<^Cooooo001Hooooo`03oeEEEOnHV9Sooooo00Gooooo00Ko0000oooo
oooooooooooooiRHV?l@4102o`000003ojVYZOoooooooooo00Cooooo00?o0000ooooooooool00_oo
ool00on7QhOoIVIVooooo`0;ooooo`03ohN7Qol0003o^[Zj00Gooooo1?l000001Ol@413ooooooooo
ooooooooA4A400;o000000?o<S8bomgMgOooool00oooool2ob4Q8@;ooooo00Goc<c<onk^k_oooooo
k^k^olc<c004ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kQ?ooooo00Ko
410@oc8b<_l0003o0000oa0@4?nYZJT2ooooo`06onk^k_mEEEGo0000o`000?m4A4Co^[Zj0oooool0
1OmVIVKo0000o`000?m4A4Coc<c<08_ooooo001Hooooo`03o`000?oooooooooo00Gooooo00[o0000
ooooooooooooooooo`000?nYZJWoEEEEoiRHV?mEEEGo^[Zj1Oooool00ol0003oooooooooo`02oooo
o`03onk^k_l0003ooooo00_ooooo00?oc<c<o`000?l@41001oooool00ol0003oooooooooo`06oooo
o`03ogMgMolb<S;ooooo00?ooooo0_lQ8B42ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool0
0ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool01_l0003oZJVYoooo
oooooooo^[Zjo`0000;ooooo00KoEEEEogMgMoooooook^k^ogMgMol@4102ooooo`06ofIVI_mgMgOo
oooooooooon7QhOo410@Roooool005Sooooo00?o<S8booooooooool01Oooool02_l0003ooooooooo
oooooooo<S8bonk^k_nHV9SoEEEEomgMgOl@4105ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?ogMgM
o`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41005?oo
ool01Onj^[[oQhN7ofIVI_mVIVKo410@00;ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`2>ooooo`00F?ooool00olb<S;oooooooooo`05ooooo`0;o`000?oooooooooooooooonj^[[o
A4A4olc<c?lQ8B7ooooooa0@4?o<c<`01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool01_ooool00omgMgOo<S8booooo`07ooooo`05onk^k_mEEEGo
gMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
4oooool01_lb<S;o8B4QogMgMomgMgOoQhN7onk^kP;ooooo1_l00002ooooo`03o`000?oooooooooo
08kooooo001Hooooo`03o`000?o^k^kooooo00Gooooo00_o0000ooooooooooooooooonk^k_l0003o
ooooo`000?ooooooIVIVohN7Q`04ooooo`03o`000?oooooooooo00;ooooo00?ok^k^o`000?ooool0
5Oooool00ol0003oooooooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`02?ooool01Oo<c<co
k^k^ooooooo^k^koc<c<00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo
000001?ooooo00Ko0000okZj^_ooooook^k^ogMgMol00002ooooo`06oeEEEOn7QhOok^k^oooooon7
QhOo<S8b0_ooool01_mVIVKoMgMgooooooooooooQhN7o`0008_ooooo001Hooooo`03oeEEEOmgMgOo
oooo00Gooooo00So0000ooooooooooooooooofIVI_nHV9Sooooooc8b<P;o^[Zj00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`02ooooo`03ogMgMomEEEGooooo00?ooooo1?l0000>ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`02ooooo`05
oa0@4?ooooooooooooooool@41001oooool3o`0000;ooooo0ol00004ooooo`06ojVYZOlQ8B7o0000
o`000?lb<S;o00000_ooool01_o^k^koEEEEo`000?l0003oA4A4onk^kP;ooooo00Kok^k^ofIVI_l0
003o0000odA4A?l0002;ooooo`00F?ooool00ooMgMgo410@onk^kP05ooooo`03o`000?oooooooooo
00Cooooo00?oIVIVohN7Qoooool01Oooool01ol0003oooooooooooooooook^k^oa0@4?oMgMd01Ooo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo0:Cooooo001Iooooo`03ogMgMomVIVKooooo00Cooooo00?o
0000ooooooooool01?ooool00onYZJWoA4A4ooooo`05ooooo`06o`000?oooooooooooooooomVIVKo
MgMg1oooool00ol0003oooooooooo`0;ooooo`03oeEEEOmVIVKo000000Gooooo1?l0000Booooo`03
oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`Co00000_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo0:Cooooo001mooooo`03o`000?oooooooooo03co
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2Tooooo`00N_ooool01?l0003ooooo
ooooool0000nooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Y?ooool007_ooooo
0_l0000nooooo`;o00000oooool2o`000:Kooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {0, -2.14748*^9, 0, \
2.14748*^9}}]
}, Closed]]
}, Open  ]],

Cell[TextData[{
  "Our choice of initial condition leads to an electron that travels to the \
right with constant velocity. As the electron propagates, its probability \
density spreads: the electron becomes ",
  StyleBox["delocalized",
    FontSlant->"Italic"],
  ".  First, we will consider what sets the speed of the wave function as it \
moves to the right, then we will discuss the spreading of the wave function. \
"
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Group Velocity", "Section",
  CellTags->{"i:13", "c:9"}],

Cell[TextData[{
  "The previous calculation shows that the electron travelled roughly ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(10\^\(-6\)\), " ", 
          StyleBox["m",
            FontSlant->"Plain"]}], TraditionalForm]]],
  " in ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(10\^\(-10\)\), " ", 
          StyleBox["s",
            FontSlant->"Plain"]}], TraditionalForm]]],
  ", implying a speed of about ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(10\^4\), " ", 
          RowBox[{
            StyleBox["m",
              FontSlant->"Plain"], "/", 
            StyleBox["s",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  ". What sets this speed?  One might think that the speed is determined by \
the phase velocity ",
  Cell[BoxData[
      \(TraditionalForm\`v\_\[Phi]\)]],
  " of waves with the central wavenumber ",
  Cell[BoxData[
      \(TraditionalForm\`k\_o\)]],
  " of the ",
  "wave packet",
  ". Using Eq. ",
  ButtonBox["(5.1.19)",
    ButtonData:>"(5.1.19)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(5.1.21)",
    ButtonData:>"(5.1.21)",
    ButtonStyle->"Hyperlink"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(v\_\[Phi]\)(k\_o)\)]],
  "is evaluated as"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[HBar]\ k0/\((2\ m)\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 5.7"],

Cell[BoxData[
    \(5762.8979143798015`\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "This phase velocity, measured in meters per second, is less than the \
observed electron speed by roughly a factor of two. In fact, we will now show \
that the electron wave packet travels at the ",
  StyleBox["group velocity",
    FontSlant->"Italic"],
  ". "
}], "Text"],

Cell[TextData[{
  "\tIn this wave packet,  the spectrum of wavenumbers ",
  Cell[BoxData[
      \(TraditionalForm\`C(k)\)]],
  " is sharply peaked around ",
  Cell[BoxData[
      \(TraditionalForm\`k\_o\)]],
  ". We can then approximate the wavenumber integral in Eq. ",
  ButtonBox["(5.1.20)",
    ButtonData:>"(5.1.20)",
    ButtonStyle->"Hyperlink"],
  ", by Taylor-expanding ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega](k)\)]],
  " about ",
  Cell[BoxData[
      \(TraditionalForm\`k = k\_o\)]],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Psi](x, t)\), "=", 
          RowBox[{\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\), 
            RowBox[{\(\[DifferentialD]k\/\(2  \[Pi]\)\), 
              
              FormBox[\(\(C(
                    k)\)\ \[ExponentialE]\^\[ImaginaryI]\ [k\ x - \
\((\[Omega](k\_o) + \ \((k - k\_o)\) \[PartialD]\[Omega]\/\[PartialD]k\( | \_\
\(k = k\_o\)\)\(+ ... \))\)\ t]\),
                "TraditionalForm"]}]}]}], TraditionalForm]]],
  "."
}], "NumberedEquation",
  CellTags->"(5.1.26)"],

Cell["\<\
If we neglect  the higher-order terms in the Taylor expansion, and \
keep only those terms shown,  then we can write the wave packet as\
\>", \
"Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Psi](x, t)\), "=", 
          
          RowBox[{\(\[ExponentialE]\^\(\[ImaginaryI]\ [\(k\_\(\(o\)\(\ \)\)\) \
\[PartialD]\[Omega]\/\[PartialD]k\( | \_\(k = k\_o\)\)\(-\ \(\[Omega](
                          k\_o)\)\)\ ] t\)\), 
            RowBox[{\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\), 
              RowBox[{\(\[DifferentialD]k\/\(2  \[Pi]\)\), 
                
                FormBox[\(\(C(
                      k)\)\ \[ExponentialE]\^\(\[ImaginaryI]\ k[\ x - \ \
\[PartialD]\[Omega]\/\[PartialD]k\( | \_\(k = k\_o\)\)\ \ t]\)\),
                  "TraditionalForm"]}]}]}]}], TraditionalForm]]],
  "."
}], "NumberedEquation",
  CellTags->"(5.1.27)"],

Cell[TextData[{
  "The Fourier integral in Eq. ",
  ButtonBox["(5.1.27)",
    ButtonData:>"(5.1.27)",
    ButtonStyle->"Hyperlink"],
  " can now be evaluated using Eq. ",
  ButtonBox["(5.1.23)",
    ButtonData:>"(5.1.23)",
    ButtonStyle->"Hyperlink"],
  ":\n\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi](x, 
          t) = \(\[ExponentialE]\^\(\[ImaginaryI]\ [\(k\_\(\(o\)\(\ \)\)\) \
\[PartialD]\[Omega]\/\[PartialD]k\( | \_\(k = k\_o\)\)\(-\ \(\[Omega](
                        k\_o)\)\)\ ] t\)\) \(\(\[Psi]\_o\)(\ 
            x - \ \[PartialD]\[Omega]\/\[PartialD]k\( | \_\(k = 
                    k\_o\)\)\ \ t)\)\)]],
  "."
}], "Text",
  CellTags->"i:22"],

Cell[TextData[{
  "Thus, aside from a phase factor that is unimportant in determining ",
  Cell[BoxData[
      \(TraditionalForm\`\((\(|\)\(\[Psi]\)\(|\))\)\^2\)]],
  ", we see that the initial condition ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\_o\)(x)\)]],
  " simply moves with a velocity equal to ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[PartialD]\[Omega]\/\[PartialD]k\)\( | \_\(k = 
              k\_o\)\)\)\)]],
  ". This is the group velocity of the ",
  "wave packet",
  ":"
}], "Text",
  CellTags->"i:27"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(v\_g\)(k\_o)\)\(=\)\)\)]],
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[PartialD]\[Omega]\/\[PartialD]k\), 
          SubscriptBox[
            StyleBox["|",
              FontSize->14], \(k = k\_o\)]}], TraditionalForm]]],
  "."
}], "NumberedEquation",
  CellTags->{"i:14", "(5.1.28)"}],

Cell[TextData[{
  "Evaluating this derivative using the dispersion relation for a free \
particle, Eq. ",
  ButtonBox["(5.1.19)",
    ButtonData:>"(5.1.19)",
    ButtonStyle->"Hyperlink"],
  ", yields the following result for the group velocity:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(v\_g\)(k\_o) = \(\[HBar]\ k\_o/m = 
          2 \(\( v\_\[Phi]\)(k\_o)\)\)\)]],
  "."
}], "NumberedEquation",
  CellTags->"(5.1.29)"],

Cell[TextData[{
  "For the parameters of our example, ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(v\_g \[TildeEqual] 11\), ",", 
          RowBox[{"500", " ", 
            RowBox[{
              StyleBox["m",
                FontSlant->"Plain"], "/", 
              StyleBox["s",
                FontSlant->"Plain"]}]}]}], TraditionalForm]]],
  ", which is in rough agreement with the observed speed of the packet."
}], "Text"],

Cell[TextData[{
  "\tThe fact that the phase velocity of waves at ",
  Cell[BoxData[
      \(TraditionalForm\`k = k\_o\)]],
  " is unequal to the group velocity means that waves making up the packet \
move with respect to the packet itself. This cannot be seen when we plot ",
  Cell[BoxData[
      \(TraditionalForm\`\((\(|\)\(\[Psi]\)\(|\))\)\^2\)]],
  ", but is very clear if we instead plot Re \[Psi], as shown in Cell ",
  ButtonBox["5.8",
    ButtonData:>"Cell 5.8",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Table[
        Plot[Re[\[Psi][x, t]], {x, \(-2000\)\ \[Angstrom], 
            20000\ \[Angstrom]}, 
          PlotRange \[Rule] {\(-1\), 1}/Sqrt[2  Pi\ a^2], 
          AxesLabel \[Rule] {"\<x (meters)\>", "\< \>"}, 
          PlotLabel \[Rule] "\<Re[\[Psi]], t=\>" <> 
              ToString[
                t/10^\(-11\)] <> \*"\"\<\[Cross]\!\(10\^\(-11\)\)sec\>\"", 
          PlotPoints \[Rule] 300], {t, 0. , 
          1.5\ 10^\(-10\),  .2\ \ 10^\(-11\)}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 5.8"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0.309017 5.42214e-08 [
[.32684 .29652 -16.5 -12.5 ]
[.32684 .29652 16.5 0 ]
[.54329 .29652 -16.5 -12.5 ]
[.54329 .29652 16.5 0 ]
[.75974 .29652 -22.5 -12.5 ]
[.75974 .29652 22.5 0 ]
[.97619 .29652 -16.5 -12.5 ]
[.97619 .29652 16.5 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 64 6 ]
[.09789 .09213 -34.5 -6.25 ]
[.09789 .09213 0 6.25 ]
[.09789 .20057 -34.5 -6.25 ]
[.09789 .20057 0 6.25 ]
[.09789 .41746 -28.5 -6.25 ]
[.09789 .41746 0 6.25 ]
[.09789 .5259 -28.5 -6.25 ]
[.09789 .5259 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -59.8125 0 ]
[.5 .63053 59.8125 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 .30902 m
.32684 .31527 L
s
gsave
.32684 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 .30902 m
.54329 .31527 L
s
gsave
.54329 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 .30902 m
.75974 .31527 L
s
gsave
.75974 .29652 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 .30902 m
.15368 .31277 L
s
.19697 .30902 m
.19697 .31277 L
s
.24026 .30902 m
.24026 .31277 L
s
.28355 .30902 m
.28355 .31277 L
s
.37013 .30902 m
.37013 .31277 L
s
.41342 .30902 m
.41342 .31277 L
s
.45671 .30902 m
.45671 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.58658 .30902 m
.58658 .31277 L
s
.62987 .30902 m
.62987 .31277 L
s
.67316 .30902 m
.67316 .31277 L
s
.71645 .30902 m
.71645 .31277 L
s
.80303 .30902 m
.80303 .31277 L
s
.84632 .30902 m
.84632 .31277 L
s
.88961 .30902 m
.88961 .31277 L
s
.9329 .30902 m
.9329 .31277 L
s
.0671 .30902 m
.0671 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09213 m
.11664 .09213 L
s
gsave
.09789 .09213 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .20057 m
.11664 .20057 L
s
gsave
.09789 .20057 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .41746 m
.11664 .41746 L
s
gsave
.09789 .41746 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .5259 m
.11664 .5259 L
s
gsave
.09789 .5259 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.11039 .11924 m
.11414 .11924 L
s
.11039 .14635 m
.11414 .14635 L
s
.11039 .17346 m
.11414 .17346 L
s
.11039 .22768 m
.11414 .22768 L
s
.11039 .2548 m
.11414 .2548 L
s
.11039 .28191 m
.11414 .28191 L
s
.11039 .33613 m
.11414 .33613 L
s
.11039 .36324 m
.11414 .36324 L
s
.11039 .39035 m
.11414 .39035 L
s
.11039 .44457 m
.11414 .44457 L
s
.11039 .47168 m
.11414 .47168 L
s
.11039 .49879 m
.11414 .49879 L
s
.11039 .06502 m
.11414 .06502 L
s
.11039 .03791 m
.11414 .03791 L
s
.11039 .0108 m
.11414 .0108 L
s
.11039 .55301 m
.11414 .55301 L
s
.11039 .58012 m
.11414 .58012 L
s
.11039 .60723 m
.11414 .60723 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -120.812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.812 moveto
(@) show
81.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.812 moveto
(D) show
93.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.) show
129.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
135.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
147.000 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
151.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
160.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
178.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .31115 m
.02532 .31319 L
.02691 .31532 L
.02769 .31624 L
.02852 .31704 L
.029 .3174 L
.02944 .31764 L
.02965 .31772 L
.02976 .31776 L
.02988 .31779 L
.02998 .31782 L
.03004 .31783 L
.03009 .31783 L
.0302 .31785 L
.03029 .31785 L
.03035 .31785 L
.0304 .31785 L
.0305 .31785 L
.0306 .31783 L
.03066 .31783 L
.03071 .31782 L
.0309 .31777 L
.031 .31773 L
.0311 .31769 L
.03132 .31758 L
.03156 .31743 L
.03199 .31706 L
.03242 .31656 L
.03283 .31597 L
.0336 .31454 L
.03438 .31269 L
.0352 .3103 L
.03668 .30503 L
.03971 .29245 L
.04126 .28688 L
.04169 .28568 L
.04213 .28461 L
.04252 .28387 L
.04273 .28354 L
.04294 .28328 L
.04314 .28308 L
.04325 .28299 L
.04336 .28292 L
.04346 .28288 L
.04355 .28285 L
.04365 .28283 L
.04371 .28283 L
.04376 .28283 L
.04386 .28285 L
.04394 .28288 L
Mistroke
.04404 .28292 L
.04414 .28298 L
.04434 .28315 L
.04451 .28335 L
.04473 .28368 L
.04493 .28405 L
.04538 .28515 L
.04577 .28643 L
.04619 .2881 L
.04695 .29196 L
.04777 .29725 L
.04924 .30952 L
.05257 .34422 L
.05338 .35234 L
.05423 .36 L
.05503 .36581 L
.05541 .3681 L
.05577 .36982 L
.05611 .37113 L
.05629 .37165 L
.05648 .3721 L
.05657 .37228 L
.05667 .37243 L
.05672 .37249 L
.05677 .37255 L
.05687 .37264 L
.05696 .37268 L
.05706 .3727 L
.05714 .37269 L
.05724 .37264 L
.05729 .3726 L
.05734 .37255 L
.05745 .37242 L
.05755 .37225 L
.05764 .37206 L
.05785 .37152 L
.05807 .37074 L
.05844 .36901 L
.05885 .36645 L
.05966 .35937 L
.0604 .35056 L
.06208 .32326 L
.06525 .25411 L
.06685 .22018 L
.06755 .20762 L
.06831 .1963 L
.06873 .19127 L
.06912 .18751 L
.06949 .18477 L
.06968 .18373 L
Mistroke
.06988 .18284 L
.06999 .18248 L
.0701 .18222 L
.0702 .18205 L
.0703 .18194 L
.07036 .18192 L
.07041 .18191 L
.07047 .18193 L
.07053 .18198 L
.07064 .18212 L
.0707 .18223 L
.07075 .18236 L
.07094 .18298 L
.07105 .18344 L
.07115 .18395 L
.07136 .18533 L
.07156 .18691 L
.07196 .19101 L
.0724 .19687 L
.0732 .21118 L
.07392 .22813 L
.07469 .24986 L
.07772 .36125 L
.0794 .42651 L
.08014 .45212 L
.08095 .47649 L
.08173 .49552 L
.08211 .50271 L
.08246 .50825 L
.08266 .51075 L
.08287 .51301 L
.08304 .51453 L
.08323 .51582 L
.08334 .51636 L
.08344 .51675 L
.08355 .51704 L
.08361 .51715 L
.08366 .51721 L
.08376 .51723 L
.08386 .51714 L
.08396 .51693 L
.08405 .51663 L
.08416 .51618 L
.08427 .51556 L
.08446 .51411 L
.08467 .51204 L
.08491 .50917 L
.08532 .50244 L
.08571 .49436 L
.08643 .4747 L
Mistroke
.0872 .44749 L
.08891 .36832 L
.09053 .27816 L
.09199 .19425 L
.09361 .1123 L
.09438 .08097 L
.0952 .05463 L
.09566 .04381 L
.09607 .03642 L
.09627 .03376 L
.09638 .03258 L
.09649 .03152 L
.0966 .03067 L
.0967 .03005 L
.0968 .02958 L
.09689 .02927 L
.09698 .02909 L
.09708 .02905 L
.09718 .02914 L
.09726 .02935 L
.09736 .02974 L
.09742 .03003 L
.09747 .03034 L
.09767 .03191 L
.09786 .03398 L
.09807 .03691 L
.0985 .04492 L
.09887 .05403 L
.09926 .06606 L
.09998 .09338 L
.10159 .17698 L
.10328 .28775 L
.10634 .49083 L
.10715 .53419 L
.10791 .56802 L
.10834 .58331 L
.1088 .59691 L
.10921 .60644 L
.10941 .61004 L
.1096 .61275 L
.10979 .615 L
.10997 .61656 L
.11007 .61718 L
.11016 .6176 L
.11027 .6179 L
.11032 .618 L
.11037 .61803 L
.11047 .61798 L
.11055 .61781 L
.11065 .61747 L
Mistroke
.11075 .61695 L
.11084 .61636 L
.11092 .6157 L
.1111 .61378 L
.11132 .61084 L
.11152 .60736 L
.1119 .59903 L
.11231 .58752 L
.11276 .57214 L
.11435 .49604 L
.11603 .38911 L
.11907 .18434 L
.12062 .10104 L
.12105 .08302 L
.1215 .06666 L
.12192 .05389 L
.1223 .04453 L
.12249 .04068 L
.12269 .03712 L
.12287 .03456 L
.12307 .03231 L
.12327 .03056 L
.12339 .02989 L
.12349 .02943 L
.12359 .02917 L
.12368 .02905 L
.12379 .02908 L
.12388 .02926 L
.12397 .02952 L
.12406 .02995 L
.12416 .03053 L
.12425 .03121 L
.12441 .03272 L
.12459 .03481 L
.12499 .04122 L
.12536 .04909 L
.12615 .07184 L
.12688 .0996 L
.12854 .1806 L
.13167 .35765 L
.13326 .4347 L
.13416 .46867 L
.13459 .48193 L
.13499 .49251 L
.13538 .50095 L
.13574 .50715 L
.13613 .5123 L
.13634 .51436 L
.13645 .51518 L
.13655 .5158 L
Mistroke
.13665 .5163 L
.13675 .51672 L
.13681 .5169 L
.13686 .51703 L
.13696 .51719 L
.13705 .51724 L
.13714 .51718 L
.13725 .51701 L
.13734 .51675 L
.13745 .51631 L
.13756 .51576 L
.13776 .51441 L
.13797 .51247 L
.1382 .50981 L
.13859 .50411 L
.13896 .4974 L
.13979 .47768 L
.14147 .42289 L
.14458 .30181 L
.14616 .24785 L
.14699 .22474 L
.14788 .20521 L
.14833 .19762 L
.14875 .19182 L
.14912 .18775 L
.14932 .18608 L
.14953 .18456 L
.14973 .18345 L
.14992 .18269 L
.15002 .18238 L
.15012 .18217 L
.15017 .18208 L
.15023 .182 L
.15033 .18192 L
.15043 .18192 L
.15051 .18197 L
.15062 .1821 L
.15071 .18229 L
.1508 .18252 L
.15088 .18278 L
.15106 .18354 L
.15126 .1846 L
.15144 .18579 L
.15185 .18921 L
.15258 .19776 L
.15343 .21111 L
.15424 .22636 L
.15732 .29467 L
.15888 .32656 L
.15971 .34078 L
Mistroke
.1606 .35341 L
.16103 .35847 L
.16145 .36258 L
.16185 .3659 L
.16223 .36839 L
.16258 .37021 L
.16276 .37094 L
.16296 .37159 L
.16307 .3719 L
.16317 .37213 L
.16327 .37232 L
.16338 .37248 L
.16347 .37258 L
.16356 .37265 L
.16365 .37269 L
.16376 .3727 L
.16385 .37267 L
.16391 .37264 L
.16396 .3726 L
.16407 .37249 L
.16418 .37233 L
.16438 .37192 L
.16457 .37142 L
.165 .36985 L
.16546 .36758 L
.16623 .36249 L
.16707 .35544 L
.17033 .32158 L
.17183 .30683 L
.17346 .29419 L
.17435 .28919 L
.17474 .28745 L
.17517 .28587 L
.17558 .28469 L
.17596 .28385 L
.17617 .2835 L
.17636 .28324 L
.17646 .28313 L
.17658 .28303 L
.17669 .28295 L
.17679 .28289 L
.17689 .28286 L
.17694 .28284 L
.177 .28284 L
.1771 .28283 L
.1772 .28284 L
.17725 .28286 L
.17731 .28287 L
.17741 .28292 L
.17752 .28298 L
Mistroke
.17764 .28308 L
.17784 .28327 L
.17805 .28355 L
.17844 .28419 L
.17915 .28582 L
.17993 .28821 L
.18316 .30121 L
.18464 .30709 L
.18549 .31 L
.18627 .31233 L
.18711 .3144 L
.18788 .31585 L
.18827 .31644 L
.1887 .31696 L
.18893 .31719 L
.18915 .31737 L
.18937 .31753 L
.18957 .31764 L
.18976 .31773 L
.18995 .31779 L
.19005 .31781 L
.19014 .31783 L
.19024 .31784 L
.1903 .31785 L
.19035 .31785 L
.19045 .31785 L
.19053 .31785 L
.19063 .31784 L
.19073 .31783 L
.19081 .31781 L
.1909 .31779 L
.19108 .31774 L
.1913 .31766 L
.1915 .31756 L
.19188 .31732 L
.19274 .3166 L
.19434 .31472 L
.19582 .3127 L
.19745 .31053 L
.19898 .30883 L
.19973 .30816 L
.20044 .30763 L
.20126 .30715 L
.20201 .30685 L
.20242 .30673 L
.20278 .30666 L
.20299 .30663 L
.20309 .30661 L
.20321 .3066 L
.20331 .30659 L
Mistroke
.20341 .30658 L
.20351 .30658 L
.2036 .30657 L
.2037 .30657 L
.2038 .30657 L
.20389 .30657 L
.20398 .30657 L
.20406 .30658 L
.20414 .30658 L
.20432 .30659 L
.20451 .30661 L
.20471 .30663 L
.20508 .30669 L
.20585 .30686 L
.20669 .3071 L
.20838 .30769 L
.21009 .30832 L
.21164 .30882 L
.21241 .30902 L
.21325 .30921 L
.21404 .30935 L
.21477 .30945 L
.21515 .30948 L
.21555 .30952 L
.21593 .30954 L
.21628 .30956 L
.21649 .30956 L
.21668 .30957 L
.2168 .30957 L
.2169 .30957 L
.21695 .30957 L
.21702 .30957 L
.21707 .30957 L
.21713 .30957 L
.21722 .30957 L
.21731 .30957 L
.21741 .30957 L
.21752 .30957 L
.21763 .30957 L
.21774 .30957 L
.21793 .30956 L
.2183 .30955 L
.21871 .30953 L
.21953 .30949 L
.22101 .30938 L
.2227 .30924 L
.22424 .30912 L
.22576 .30903 L
.22652 .30899 L
.22735 .30896 L
Mistroke
.22778 .30895 L
.22818 .30894 L
.22855 .30893 L
.22893 .30892 L
.22913 .30892 L
.22935 .30892 L
.22955 .30892 L
.22974 .30892 L
.22996 .30891 L
.23008 .30891 L
.23019 .30891 L
.2303 .30891 L
.23039 .30891 L
.23044 .30891 L
.2305 .30891 L
.23056 .30891 L
.23061 .30891 L
.23071 .30891 L
.23081 .30891 L
.2309 .30891 L
.23099 .30891 L
.2312 .30891 L
.2314 .30892 L
.2318 .30892 L
.23223 .30892 L
.23372 .30894 L
.23528 .30896 L
.237 .30899 L
.23865 .30901 L
.23937 .30902 L
.24016 .30902 L
.24096 .30903 L
.24172 .30903 L
.24214 .30903 L
.24237 .30903 L
.24259 .30903 L
.24279 .30903 L
.24301 .30903 L
.24321 .30903 L
.24339 .30903 L
.24349 .30903 L
.24359 .30903 L
.24368 .30903 L
.24377 .30903 L
.24387 .30903 L
.24392 .30903 L
.24398 .30903 L
.24408 .30903 L
.24417 .30903 L
.24426 .30903 L
Mistroke
.24436 .30903 L
.24453 .30903 L
.24471 .30903 L
.2449 .30903 L
.24532 .30903 L
.24576 .30903 L
.24656 .30903 L
.24989 .30902 L
.25157 .30902 L
.2523 .30902 L
.25311 .30902 L
.25388 .30902 L
.25461 .30902 L
.255 .30902 L
.25537 .30902 L
.2558 .30902 L
.25619 .30902 L
.2564 .30902 L
.2566 .30902 L
.25678 .30902 L
.25687 .30902 L
.25697 .30902 L
.25707 .30902 L
.25712 .30902 L
.25717 .30902 L
.25723 .30902 L
.25729 .30902 L
.25739 .30902 L
.25749 .30902 L
.25758 .30902 L
.25768 .30902 L
.25779 .30902 L
.25796 .30902 L
.25815 .30902 L
.25849 .30902 L
.2589 .30902 L
.25927 .30902 L
.26245 .30902 L
.26406 .30902 L
.26552 .30902 L
.26633 .30902 L
.26709 .30902 L
.2679 .30902 L
.26836 .30902 L
.26878 .30902 L
.26915 .30902 L
.26936 .30902 L
.26956 .30902 L
.26974 .30902 L
.26994 .30902 L
Mistroke
.27012 .30902 L
.27029 .30902 L
.27038 .30902 L
.27048 .30902 L
.27058 .30902 L
.27067 .30902 L
.27077 .30902 L
.27082 .30902 L
.27087 .30902 L
.27098 .30902 L
.27104 .30902 L
.27109 .30902 L
.2712 .30902 L
.2713 .30902 L
.27153 .30902 L
.27194 .30902 L
.27232 .30902 L
.27272 .30902 L
.27345 .30902 L
.27511 .30902 L
.27669 .30902 L
.27753 .30902 L
.27842 .30902 L
.27929 .30902 L
.28007 .30902 L
.28086 .30902 L
.28161 .30902 L
.28198 .30902 L
.28239 .30902 L
.2826 .30902 L
.28282 .30902 L
.28301 .30902 L
.28322 .30902 L
.28343 .30902 L
.28362 .30902 L
.2838 .30902 L
.2839 .30902 L
.284 .30902 L
.28409 .30902 L
.28417 .30902 L
.28427 .30902 L
.28436 .30902 L
.28445 .30902 L
.28453 .30902 L
.28461 .30902 L
.28471 .30902 L
.28491 .30902 L
.28513 .30902 L
.28553 .30902 L
.28642 .30902 L
Mistroke
.28804 .30902 L
.28963 .30902 L
.29108 .30902 L
.29265 .30902 L
.29351 .30902 L
.29432 .30902 L
.2951 .30902 L
.29549 .30902 L
.29592 .30902 L
.29629 .30902 L
.29648 .30902 L
.29668 .30902 L
.29686 .30902 L
.29705 .30902 L
.29714 .30902 L
.29723 .30902 L
.29732 .30902 L
.2974 .30902 L
.2975 .30902 L
.29755 .30902 L
.2976 .30902 L
.29766 .30902 L
.29772 .30902 L
.29782 .30902 L
.29792 .30902 L
.29801 .30902 L
.29811 .30902 L
.29822 .30902 L
.29846 .30902 L
.29868 .30902 L
.29911 .30902 L
.30072 .30902 L
.30382 .30902 L
.30542 .30902 L
.30622 .30902 L
.30711 .30902 L
.30753 .30902 L
.30793 .30902 L
.30868 .30902 L
.30909 .30902 L
.30948 .30902 L
.3099 .30902 L
.31012 .30902 L
.31035 .30902 L
.31054 .30902 L
.31065 .30902 L
.31075 .30902 L
.31085 .30902 L
.31095 .30902 L
.311 .30902 L
Mistroke
.31106 .30902 L
.31116 .30902 L
.31125 .30902 L
.31135 .30902 L
.31146 .30902 L
.31155 .30902 L
.31172 .30902 L
.31191 .30902 L
.31236 .30902 L
.31278 .30902 L
.31358 .30902 L
.31665 .30902 L
.31823 .30902 L
.31912 .30902 L
.31992 .30902 L
.32073 .30902 L
.32147 .30902 L
.32186 .30902 L
.32228 .30902 L
.32273 .30902 L
.32294 .30902 L
.32314 .30902 L
.32333 .30902 L
.32354 .30902 L
.32376 .30902 L
.32387 .30902 L
.32398 .30902 L
.32408 .30902 L
.32418 .30902 L
.32428 .30902 L
.32434 .30902 L
.32439 .30902 L
.32449 .30902 L
.32458 .30902 L
.32468 .30902 L
.32478 .30902 L
.32486 .30902 L
.32496 .30902 L
.32515 .30902 L
.32533 .30902 L
.32549 .30902 L
.32627 .30902 L
.32939 .30902 L
.33098 .30902 L
.33187 .30902 L
.33271 .30902 L
.33344 .30902 L
.33425 .30902 L
.33466 .30902 L
.3351 .30902 L
Mistroke
.33552 .30902 L
.3359 .30902 L
.33627 .30902 L
.33667 .30902 L
.33689 .30902 L
.33711 .30902 L
.3373 .30902 L
.33741 .30902 L
.33751 .30902 L
.33761 .30902 L
.33771 .30902 L
.33776 .30902 L
.33782 .30902 L
.33788 .30902 L
.33794 .30902 L
.338 .30902 L
.33805 .30902 L
.33811 .30902 L
.33817 .30902 L
.33828 .30902 L
.33833 .30902 L
.33839 .30902 L
.33858 .30902 L
.33878 .30902 L
.3392 .30902 L
.34002 .30902 L
.34077 .30902 L
.34245 .30902 L
.34411 .30902 L
.34484 .30902 L
.34565 .30902 L
.34642 .30902 L
.34714 .30902 L
.3479 .30902 L
.34833 .30902 L
.34873 .30902 L
.34911 .30902 L
.34951 .30902 L
.3499 .30902 L
.35025 .30902 L
.35046 .30902 L
.35066 .30902 L
.35087 .30902 L
.35098 .30902 L
.3511 .30902 L
.35121 .30902 L
.3513 .30902 L
.35136 .30902 L
.35141 .30902 L
.35152 .30902 L
Mistroke
.35162 .30902 L
.35172 .30902 L
.35182 .30902 L
.35191 .30902 L
.3521 .30902 L
.3523 .30902 L
.35272 .30902 L
.35346 .30902 L
.35513 .30902 L
.35683 .30902 L
.35838 .30902 L
.35915 .30902 L
.35999 .30902 L
.36078 .30902 L
.36151 .30902 L
.36188 .30902 L
.36229 .30902 L
.36263 .30902 L
.36301 .30902 L
.36324 .30902 L
.36346 .30902 L
.36368 .30902 L
.36388 .30902 L
.36406 .30902 L
.36426 .30902 L
.36437 .30902 L
.36447 .30902 L
.36457 .30902 L
.36467 .30902 L
.36476 .30902 L
.36487 .30902 L
.36496 .30902 L
.36505 .30902 L
.36514 .30902 L
.36524 .30902 L
.36529 .30902 L
.36535 .30902 L
.36545 .30902 L
.36563 .30902 L
.36583 .30902 L
.36618 .30902 L
.36697 .30902 L
.36784 .30902 L
.36954 .30902 L
.37109 .30902 L
.37187 .30902 L
.3727 .30902 L
.3735 .30902 L
.37423 .30902 L
.3746 .30902 L
Mistroke
.375 .30902 L
.37573 .30902 L
.37617 .30902 L
.3766 .30902 L
.37697 .30902 L
.37719 .30902 L
.37739 .30902 L
.3776 .30902 L
.3778 .30902 L
.3779 .30902 L
.37801 .30902 L
.37813 .30902 L
.37818 .30902 L
.37824 .30902 L
.37834 .30902 L
.37844 .30902 L
.37854 .30902 L
.37862 .30902 L
.37872 .30902 L
.37882 .30902 L
.37893 .30902 L
.37904 .30902 L
.37941 .30902 L
.37976 .30902 L
.38053 .30902 L
.38218 .30902 L
.38372 .30902 L
.3852 .30902 L
.38603 .30902 L
.38678 .30902 L
.38758 .30902 L
.38832 .30902 L
.38871 .30902 L
.38913 .30902 L
.38958 .30902 L
.38999 .30902 L
.39039 .30902 L
.39062 .30902 L
.39083 .30902 L
.39103 .30902 L
.39121 .30902 L
.39141 .30902 L
.39151 .30902 L
.39162 .30902 L
.39172 .30902 L
.3918 .30902 L
.3919 .30902 L
.392 .30902 L
.39205 .30902 L
.39211 .30902 L
Mistroke
.39221 .30902 L
.39231 .30902 L
.3924 .30902 L
.39256 .30902 L
.39274 .30902 L
.39311 .30902 L
.39392 .30902 L
.39467 .30902 L
.39635 .30902 L
.39787 .30902 L
.39873 .30902 L
.39953 .30902 L
.40038 .30902 L
.40118 .30902 L
.4019 .30902 L
.4023 .30902 L
.40267 .30902 L
.40305 .30902 L
.40346 .30902 L
.40384 .30902 L
.40419 .30902 L
.4044 .30902 L
.40459 .30902 L
.40481 .30902 L
.40492 .30902 L
.40504 .30902 L
.40514 .30902 L
.40524 .30902 L
.40534 .30902 L
.4054 .30902 L
.40545 .30902 L
.40555 .30902 L
.40566 .30902 L
.40576 .30902 L
.40585 .30902 L
.40603 .30902 L
.40623 .30902 L
.40665 .30902 L
.40739 .30902 L
.40906 .30902 L
.40992 .30902 L
.41075 .30902 L
.41155 .30902 L
.41229 .30902 L
.41302 .30902 L
.41379 .30902 L
.41423 .30902 L
.41464 .30902 L
.41541 .30902 L
.41579 .30902 L
Mistroke
.4162 .30902 L
.41663 .30902 L
.41703 .30902 L
.4174 .30902 L
.41774 .30902 L
.41793 .30902 L
.41814 .30902 L
.41833 .30902 L
.41851 .30902 L
.41861 .30902 L
.41871 .30902 L
.41879 .30902 L
.41888 .30902 L
.41898 .30902 L
.41904 .30902 L
.41909 .30902 L
.41919 .30902 L
.41929 .30902 L
.41937 .30902 L
.41947 .30902 L
.41963 .30902 L
.42001 .30902 L
.4208 .30902 L
.42167 .30902 L
.42336 .30902 L
.42491 .30902 L
.42568 .30902 L
.42651 .30902 L
.4273 .30902 L
.42803 .30902 L
.4284 .30902 L
.4288 .30902 L
.42915 .30902 L
.42953 .30902 L
.42995 .30902 L
.43039 .30902 L
.43059 .30902 L
.4308 .30902 L
.43118 .30902 L
.43139 .30902 L
.43161 .30902 L
.4318 .30902 L
.4319 .30902 L
.432 .30902 L
.43212 .30902 L
.43223 .30902 L
.43228 .30902 L
.43234 .30902 L
.4324 .30902 L
.43246 .30902 L
Mistroke
.43252 .30902 L
.43258 .30902 L
.43264 .30902 L
.43269 .30902 L
.43279 .30902 L
.43289 .30902 L
.43309 .30902 L
.43329 .30902 L
.43367 .30902 L
.43451 .30902 L
.4361 .30902 L
.43694 .30902 L
.43783 .30902 L
.43862 .30902 L
.4395 .30902 L
.44029 .30902 L
.44103 .30902 L
.44141 .30902 L
.44182 .30902 L
.44223 .30902 L
.44266 .30902 L
.44306 .30902 L
.44343 .30902 L
.44379 .30902 L
.44414 .30902 L
.44451 .30902 L
.44473 .30902 L
.44492 .30902 L
.44513 .30902 L
.44532 .30902 L
.44543 .30902 L
.44554 .30902 L
.44565 .30902 L
.44575 .30902 L
.44584 .30902 L
.44594 .30902 L
.44604 .30902 L
.44613 .30902 L
.44621 .30902 L
.44629 .30902 L
.44638 .30902 L
.44647 .30902 L
.44666 .30902 L
.44684 .30902 L
.44723 .30902 L
.4489 .30902 L
.45044 .30902 L
.45193 .30902 L
.45269 .30902 L
.45352 .30902 L
Mistroke
.45394 .30902 L
.45433 .30902 L
.45508 .30902 L
.45549 .30902 L
.45588 .30902 L
.4563 .30902 L
.45675 .30902 L
.45718 .30902 L
.45758 .30902 L
.45779 .30902 L
.45801 .30902 L
.45825 .30902 L
.45847 .30902 L
.45868 .30902 L
.45888 .30902 L
.45898 .30902 L
.45908 .30902 L
.45919 .30902 L
.45925 .30902 L
.45931 .30902 L
.45941 .30902 L
.4595 .30902 L
.45961 .30902 L
.45966 .30902 L
.45971 .30902 L
.45981 .30902 L
.45991 .30902 L
.46009 .30902 L
.4603 .30902 L
.46052 .30902 L
.46091 .30902 L
.4618 .30902 L
.46342 .30902 L
.46418 .30902 L
.46499 .30902 L
.46576 .30902 L
.46646 .30902 L
.46726 .30902 L
.46799 .30902 L
.46841 .30902 L
.4688 .30902 L
.46921 .30902 L
.46965 .30902 L
.47004 .30902 L
.47046 .30902 L
.47084 .30902 L
.4712 .30902 L
.47142 .30902 L
.47163 .30902 L
.47181 .30902 L
Mistroke
.47201 .30902 L
.47223 .30902 L
.47242 .30902 L
.47254 .30902 L
.47264 .30902 L
.47275 .30902 L
.47282 .30902 L
.47287 .30902 L
.47298 .30902 L
.47307 .30902 L
.47316 .30902 L
.47326 .30902 L
.47336 .30902 L
.47347 .30902 L
.47366 .30902 L
.47401 .30902 L
.4744 .30902 L
.47606 .30902 L
.47693 .30902 L
.47775 .30902 L
.47856 .30902 L
.4793 .30902 L
.48003 .30902 L
.4808 .30902 L
.48157 .30902 L
.48201 .30902 L
.48242 .30902 L
.48283 .30902 L
.48321 .30902 L
.48361 .30902 L
.48404 .30902 L
.48442 .30902 L
.48476 .30902 L
.48495 .30902 L
.48515 .30902 L
.48535 .30902 L
.48552 .30902 L
.48571 .30902 L
.48581 .30902 L
.48592 .30902 L
.48601 .30902 L
.4861 .30902 L
.48619 .30902 L
.48628 .30902 L
.48634 .30902 L
.48639 .30902 L
.48649 .30902 L
.48659 .30902 L
.48669 .30902 L
.48674 .30902 L
Mistroke
.48679 .30902 L
.48689 .30902 L
.48701 .30902 L
.48712 .30902 L
.48753 .30902 L
.48798 .30902 L
.48881 .30902 L
.49036 .30902 L
.49119 .30902 L
.49208 .30902 L
.49293 .30902 L
.49371 .30902 L
.49445 .30902 L
.49483 .30902 L
.49523 .30902 L
.49566 .30902 L
.49606 .30902 L
.49642 .30902 L
.49681 .30902 L
.49723 .30902 L
.49762 .30902 L
.49803 .30902 L
.49827 .30902 L
.49849 .30902 L
.49869 .30902 L
.49889 .30902 L
.49912 .30902 L
.49933 .30902 L
.49943 .30902 L
.49954 .30902 L
.49964 .30902 L
.49974 .30902 L
.49984 .30902 L
.49994 .30902 L
.50003 .30902 L
.50012 .30902 L
.50021 .30902 L
.50031 .30902 L
.50041 .30902 L
.5005 .30902 L
.50066 .30902 L
.50084 .30902 L
.50121 .30902 L
.50161 .30902 L
.5033 .30902 L
.50484 .30902 L
.5056 .30902 L
.50644 .30902 L
.50722 .30902 L
.50795 .30902 L
Mistroke
.50836 .30902 L
.5088 .30902 L
.50919 .30902 L
.5096 .30902 L
.50997 .30902 L
.51038 .30902 L
.51075 .30902 L
.51109 .30902 L
.51149 .30902 L
.51172 .30902 L
.51193 .30902 L
.51232 .30902 L
.51251 .30902 L
.51273 .30902 L
.51292 .30902 L
.51309 .30902 L
.51319 .30902 L
.51329 .30902 L
.51339 .30902 L
.51349 .30902 L
.51359 .30902 L
.51368 .30902 L
.51376 .30902 L
.51384 .30902 L
.51394 .30902 L
.51404 .30902 L
.51421 .30902 L
.51442 .30902 L
.51461 .30902 L
.51497 .30902 L
.51578 .30902 L
.51725 .30902 L
.51803 .30902 L
.51885 .30902 L
.51962 .30902 L
.52032 .30902 L
.52072 .30902 L
.52113 .30902 L
.52187 .30902 L
.52228 .30902 L
.52267 .30902 L
.52309 .30902 L
.52354 .30902 L
.52397 .30902 L
.52436 .30902 L
.52479 .30902 L
.52501 .30902 L
.52525 .30902 L
.52565 .30902 L
.52588 .30902 L
Mistroke
.52608 .30902 L
.52627 .30902 L
.52646 .30902 L
.52656 .30902 L
.52667 .30902 L
.52677 .30902 L
.52687 .30902 L
.52696 .30902 L
.52702 .30902 L
.52707 .30902 L
.52713 .30902 L
.52719 .30902 L
.52729 .30902 L
.52739 .30902 L
.52748 .30902 L
.52758 .30902 L
.52769 .30902 L
.52791 .30902 L
.52811 .30902 L
.52858 .30902 L
.5302 .30902 L
.53099 .30902 L
.53182 .30902 L
.53253 .30902 L
.5333 .30902 L
.53372 .30902 L
.53412 .30902 L
.53487 .30902 L
.53529 .30902 L
.53568 .30902 L
.5361 .30902 L
.53655 .30902 L
.53696 .30902 L
.53733 .30902 L
.5377 .30902 L
.53806 .30902 L
.53847 .30902 L
.53885 .30902 L
.53907 .30902 L
.53927 .30902 L
.5395 .30902 L
.53971 .30902 L
.53991 .30902 L
.54009 .30902 L
.54019 .30902 L
.54028 .30902 L
.54039 .30902 L
.5405 .30902 L
.5406 .30902 L
.5407 .30902 L
Mistroke
.54079 .30902 L
.54089 .30902 L
.54095 .30902 L
.541 .30902 L
.54112 .30902 L
.54122 .30902 L
.54132 .30902 L
.54169 .30902 L
.54203 .30902 L
.54281 .30902 L
.54431 .30902 L
.54516 .30902 L
.54594 .30902 L
.54677 .30902 L
.54719 .30902 L
.54766 .30902 L
.54806 .30902 L
.54849 .30902 L
.54927 .30902 L
.54969 .30902 L
.55009 .30902 L
.55052 .30902 L
.55097 .30902 L
.55141 .30902 L
.55182 .30902 L
.55219 .30902 L
.55238 .30902 L
.55259 .30902 L
.55279 .30902 L
.55298 .30902 L
.55317 .30902 L
.55335 .30902 L
.55356 .30902 L
.55367 .30902 L
.55378 .30902 L
.55388 .30902 L
.55398 .30902 L
.55408 .30902 L
.55414 .30902 L
.55419 .30902 L
.55429 .30902 L
.55439 .30902 L
.55449 .30902 L
.55458 .30902 L
.55469 .30902 L
.55481 .30902 L
.55502 .30902 L
.55547 .30902 L
.55588 .30902 L
.55752 .30902 L
Mistroke
.55832 .30902 L
.55905 .30902 L
.5598 .30902 L
.56052 .30902 L
.56127 .30902 L
.5617 .30902 L
.5621 .30902 L
.56247 .30902 L
.56287 .30902 L
.56321 .30902 L
.56359 .30902 L
.56401 .30902 L
.56445 .30902 L
.56486 .30902 L
.56525 .30902 L
.56565 .30902 L
.56588 .30902 L
.56609 .30902 L
.56648 .30902 L
.56667 .30902 L
.56689 .30902 L
.56708 .30902 L
.56726 .30902 L
.56735 .30902 L
.56746 .30902 L
.56756 .30902 L
.56766 .30902 L
.56775 .30902 L
.56784 .30902 L
.56792 .30902 L
.56801 .30902 L
.5681 .30902 L
.5682 .30902 L
.56838 .30902 L
.56858 .30902 L
.56878 .30902 L
.56914 .30902 L
.56996 .30902 L
.57143 .30902 L
.5722 .30902 L
.57303 .30902 L
.57373 .30902 L
.57451 .30902 L
.5749 .30902 L
.57532 .30902 L
.57606 .30902 L
.57647 .30902 L
.57686 .30902 L
.57728 .30902 L
.57773 .30902 L
Mistroke
.57816 .30902 L
.57856 .30902 L
.57899 .30902 L
.57921 .30902 L
.57945 .30902 L
.57985 .30902 L
.58008 .30902 L
.58029 .30902 L
.58048 .30902 L
.58058 .30902 L
.58069 .30902 L
.58079 .30902 L
.58088 .30902 L
.58097 .30902 L
.58107 .30902 L
.58117 .30902 L
.58126 .30902 L
.58131 .30902 L
.58136 .30902 L
.58146 .30902 L
.58156 .30902 L
.58166 .30902 L
.58176 .30902 L
.58188 .30902 L
.58223 .30902 L
.58262 .30902 L
.58429 .30902 L
.58509 .30902 L
.58585 .30902 L
.58627 .30902 L
.58672 .30902 L
.58752 .30902 L
.58795 .30902 L
.58835 .30902 L
.5891 .30902 L
.58952 .30902 L
.58991 .30902 L
.59034 .30902 L
.59079 .30902 L
.59118 .30902 L
.59155 .30902 L
.59196 .30902 L
.59236 .30902 L
.59273 .30902 L
.59307 .30902 L
.59324 .30902 L
.59344 .30902 L
.59363 .30902 L
.59383 .30902 L
.59404 .30902 L
Mistroke
.59423 .30902 L
.59433 .30902 L
.59443 .30902 L
.59454 .30902 L
.59464 .30902 L
.59473 .30902 L
.59483 .30902 L
.59491 .30902 L
.595 .30902 L
.5951 .30902 L
.5952 .30902 L
.5953 .30902 L
.59539 .30902 L
.5956 .30902 L
.5958 .30902 L
.59624 .30902 L
.59706 .30902 L
.59791 .30902 L
.59871 .30902 L
.59943 .30902 L
.6002 .30902 L
.60097 .30902 L
.6014 .30902 L
.60181 .30902 L
.60223 .30902 L
.60262 .30902 L
.60308 .30902 L
.6035 .30902 L
.60387 .30902 L
.60428 .30902 L
.6047 .30902 L
.6051 .30902 L
.60547 .30902 L
.60581 .30902 L
.60619 .30902 L
.60637 .30902 L
.60658 .30902 L
.60678 .30902 L
.607 .30902 L
.60721 .30902 L
.60741 .30902 L
.60758 .30902 L
.60777 .30902 L
.60787 .30902 L
.60797 .30902 L
.60806 .30902 L
.60816 .30902 L
.60821 .30902 L
.60827 .30902 L
.60837 .30902 L
Mistroke
.60843 .30902 L
.60849 .30902 L
.60855 .30902 L
.60861 .30902 L
.60871 .30902 L
.60876 .30902 L
.60882 .30902 L
.60904 .30902 L
.60924 .30902 L
.60942 .30902 L
.60984 .30902 L
.61065 .30902 L
.61151 .30902 L
.6123 .30902 L
.61304 .30902 L
.61375 .30902 L
.61451 .30902 L
.61495 .30902 L
.61536 .30902 L
.61576 .30902 L
.61613 .30902 L
.6165 .30902 L
.6169 .30902 L
.61732 .30902 L
.61772 .30902 L
.61809 .30902 L
.61849 .30902 L
.61883 .30902 L
.6192 .30902 L
.6194 .30902 L
.61962 .30902 L
.61981 .30902 L
.62002 .30902 L
.6202 .30902 L
.6204 .30902 L
.62058 .30902 L
.62076 .30902 L
.62098 .30902 L
.62118 .30902 L
.62139 .30902 L
.62152 .30902 L
.62163 .30902 L
.62173 .30902 L
.62183 .30902 L
.62192 .30902 L
.62202 .30902 L
.62213 .30902 L
.62218 .30902 L
.62224 .30902 L
.62234 .30902 L
Mistroke
.62244 .30902 L
.62265 .30902 L
.62284 .30902 L
.62328 .30902 L
.62407 .30902 L
.62479 .30902 L
.62556 .30902 L
.62641 .30902 L
.6268 .30902 L
.62721 .30902 L
.62758 .30902 L
.62799 .30902 L
.62871 .30902 L
.62913 .30902 L
.62953 .30902 L
.62989 .30902 L
.63027 .30902 L
.63069 .30902 L
.63108 .30902 L
.6315 .30902 L
.63196 .30902 L
.63237 .30902 L
.63277 .30902 L
.63312 .30902 L
.63351 .30902 L
.63373 .30902 L
.63393 .30902 L
.63416 .30902 L
.63438 .30902 L
.63458 .30902 L
.63477 .30902 L
.63497 .30902 L
.63507 .30902 L
.63519 .30902 L
.63529 .30902 L
.63539 .30902 L
.63549 .30902 L
.63555 .30902 L
.63561 .30902 L
.63571 .30902 L
.63576 .30902 L
.63581 .30902 L
.63591 .30902 L
.63601 .30902 L
.63619 .30902 L
.63636 .30902 L
.63675 .30902 L
.63762 .30902 L
.63843 .30902 L
.63922 .30902 L
Mistroke
.64007 .30902 L
.64045 .30902 L
.64085 .30902 L
.64156 .30902 L
.64196 .30902 L
.64232 .30902 L
.64271 .30902 L
.64313 .30902 L
.64352 .30902 L
.64389 .30902 L
.64423 .30902 L
.6446 .30902 L
.64503 .30902 L
.64543 .30902 L
.64586 .30902 L
.64608 .30902 L
.64632 .30902 L
.64673 .30902 L
.64695 .30902 L
.64716 .30902 L
.64735 .30902 L
.64756 .30902 L
.64776 .30902 L
.64794 .30902 L
.64813 .30902 L
.64833 .30902 L
.64851 .30902 L
.6486 .30902 L
.6487 .30902 L
.64881 .30902 L
.64891 .30902 L
.64896 .30902 L
.64902 .30902 L
.64908 .30902 L
.64913 .30902 L
.64922 .30902 L
.64933 .30902 L
.64938 .30902 L
.64943 .30902 L
.64953 .30902 L
.64964 .30902 L
.64975 .30902 L
.64998 .30902 L
.65041 .30902 L
.65122 .30902 L
.65194 .30902 L
.65271 .30902 L
.65316 .30902 L
.65357 .30902 L
.65395 .30902 L
Mistroke
.65437 .30902 L
.65478 .30902 L
.65515 .30902 L
.65588 .30902 L
.65629 .30902 L
.65674 .30902 L
.65716 .30902 L
.65754 .30902 L
.65792 .30902 L
.65832 .30902 L
.6587 .30902 L
.65905 .30902 L
.65945 .30902 L
.65968 .30902 L
.6599 .30902 L
.66029 .30902 L
.6605 .30902 L
.6607 .30902 L
.66109 .30902 L
.66129 .30902 L
.66151 .30902 L
.66169 .30902 L
.66189 .30902 L
.66199 .30902 L
.66208 .30902 L
.66225 .30902 L
.66234 .30902 L
.66245 .30902 L
.6625 .30902 L
.66256 .30902 L
.66266 .30902 L
.66276 .30902 L
.66286 .30902 L
.66295 .30902 L
.66305 .30902 L
.66316 .30902 L
.66327 .30902 L
.6635 .30902 L
.66392 .30902 L
.66473 .30902 L
.66559 .30902 L
.66632 .30902 L
.66674 .30902 L
.66713 .30902 L
.6679 .30902 L
.66832 .30902 L
.66872 .30902 L
.66944 .30902 L
.66984 .30902 L
.67022 .30902 L
Mistroke
.67062 .30902 L
.67107 .30902 L
.67148 .30902 L
.67187 .30902 L
.67221 .30902 L
.67259 .30902 L
.67299 .30902 L
.67336 .30902 L
.67376 .30902 L
.67399 .30902 L
.6742 .30902 L
.67459 .30902 L
.67478 .30902 L
.675 .30902 L
.67519 .30902 L
.67537 .30902 L
.67556 .30902 L
.67566 .30902 L
.67577 .30902 L
.67586 .30902 L
.67595 .30902 L
.67605 .30902 L
.67614 .30902 L
.67623 .30902 L
.67631 .30902 L
.6764 .30902 L
.67649 .30902 L
.67659 .30902 L
.67664 .30902 L
.67669 .30902 L
.67688 .30902 L
.67725 .30902 L
.67806 .30902 L
.67877 .30902 L
.67953 .30902 L
.6803 .30902 L
.68103 .30902 L
.68145 .30902 L
.68189 .30902 L
.68231 .30902 L
.68268 .30902 L
.68305 .30902 L
.68345 .30902 L
.68387 .30902 L
.68427 .30902 L
.68464 .30902 L
.68503 .30902 L
.68537 .30902 L
.68574 .30902 L
.68616 .30902 L
Mistroke
.68655 .30902 L
.68691 .30902 L
.6873 .30902 L
.68752 .30902 L
.68772 .30902 L
.68793 .30902 L
.68817 .30902 L
.68838 .30902 L
.68858 .30902 L
.68877 .30902 L
.68897 .30902 L
.68907 .30902 L
.68918 .30902 L
.68927 .30902 L
.68937 .30902 L
.68946 .30902 L
.68956 .30902 L
.68965 .30902 L
.68974 .30902 L
.68984 .30902 L
.68994 .30902 L
.69003 .30902 L
.69013 .30902 L
.69023 .30902 L
.69035 .30902 L
.69055 .30902 L
.69202 .30902 L
.69285 .30902 L
.69328 .30902 L
.69374 .30902 L
.69414 .30902 L
.69458 .30902 L
.69536 .30902 L
.69578 .30902 L
.69617 .30902 L
.69653 .30902 L
.69692 .30902 L
.69734 .30902 L
.69772 .30902 L
.69818 .30902 L
.6986 .30902 L
.69899 .30902 L
.6994 .30902 L
.69976 .30902 L
.70015 .30902 L
.70036 .30902 L
.70056 .30902 L
.70078 .30902 L
.70101 .30902 L
.70123 .30902 L
Mistroke
.70143 .30902 L
.70163 .30902 L
.70182 .30902 L
.702 .30902 L
.70219 .30902 L
.7024 .30902 L
.70259 .30902 L
.70278 .30902 L
.70288 .30902 L
.70297 .30902 L
.70306 .30902 L
.70315 .30902 L
.70324 .30902 L
.70332 .30902 L
.70342 .30902 L
.70352 .30902 L
.70362 .30902 L
.7037 .30902 L
.70381 .30902 L
.70392 .30902 L
.70413 .30902 L
.70498 .30902 L
.70572 .30902 L
.70653 .30902 L
.70699 .30902 L
.70742 .30902 L
.70785 .30902 L
.70825 .30902 L
.70898 .30902 L
.70937 .30902 L
.70978 .30902 L
.71022 .30902 L
.71063 .30902 L
.711 .30902 L
.7114 .30902 L
.71179 .30902 L
.71216 .30902 L
.71256 .30902 L
.71299 .30902 L
.71321 .30902 L
.71345 .30902 L
.71365 .30902 L
.71388 .30902 L
.7141 .30902 L
.71429 .30902 L
.71468 .30902 L
.71487 .30902 L
.71508 .30902 L
.71528 .30902 L
.71549 .30902 L
Mistroke
.71569 .30902 L
.71587 .30902 L
.71606 .30902 L
.71623 .30902 L
.71633 .30902 L
.71643 .30902 L
.71654 .30902 L
.71665 .30902 L
.71674 .30902 L
.71683 .30902 L
.71693 .30902 L
.71703 .30902 L
.71714 .30902 L
.71719 .30902 L
.71725 .30902 L
.71735 .30902 L
.71745 .30902 L
.71767 .30902 L
.7179 .30902 L
.71947 .30902 L
.7199 .30902 L
.72036 .30902 L
.72119 .30902 L
.7216 .30902 L
.72204 .30902 L
.72243 .30902 L
.72285 .30902 L
.72322 .30902 L
.72363 .30902 L
.724 .30902 L
.72436 .30902 L
.72473 .30902 L
.72514 .30902 L
.72557 .30902 L
.72597 .30902 L
.72635 .30902 L
.72669 .30902 L
.72709 .30902 L
.72746 .30902 L
.72783 .30902 L
.72804 .30902 L
.72824 .30902 L
.72844 .30902 L
.72863 .30902 L
.72886 .30902 L
.72906 .30902 L
.72924 .30902 L
.72943 .30902 L
.72961 .30902 L
.72977 .30902 L
Mistroke
.72996 .30902 L
.73007 .30902 L
.73017 .30902 L
.73025 .30902 L
.73035 .30902 L
.73045 .30902 L
.73054 .30902 L
.73064 .30902 L
.73069 .30902 L
.73075 .30902 L
.73085 .30902 L
.73094 .30902 L
.73115 .30902 L
.73138 .30902 L
.73218 .30902 L
.73295 .30902 L
.73367 .30902 L
.73443 .30902 L
.73484 .30902 L
.73527 .30902 L
.73573 .30902 L
.73616 .30902 L
.73655 .30902 L
.73697 .30902 L
.73736 .30902 L
.73773 .30902 L
.73813 .30902 L
.73856 .30902 L
.73902 .30902 L
.73945 .30902 L
.73983 .30902 L
.74025 .30902 L
.74046 .30902 L
.74068 .30902 L
.74088 .30902 L
.74108 .30902 L
.74127 .30902 L
.74148 .30902 L
.74184 .30902 L
.74206 .30902 L
.74226 .30902 L
.74249 .30902 L
.74271 .30902 L
.74291 .30902 L
.7431 .30902 L
.7433 .30902 L
.74341 .30902 L
.74352 .30902 L
.74362 .30902 L
.74372 .30902 L
Mistroke
.74378 .30902 L
.74383 .30902 L
.74394 .30902 L
.74404 .30902 L
.74414 .30902 L
.74424 .30902 L
.74433 .30902 L
.74442 .30902 L
.74451 .30902 L
.7447 .30902 L
.74508 .30902 L
.74594 .30902 L
.74675 .30902 L
.74753 .30902 L
.74798 .30902 L
.74839 .30902 L
.74911 .30902 L
.74947 .30902 L
.74987 .30902 L
.75027 .30902 L
.75068 .30902 L
.75104 .30902 L
.75143 .30902 L
.75184 .30902 L
.75229 .30902 L
.75272 .30902 L
.7531 .30902 L
.75349 .30902 L
.7539 .30902 L
.75425 .30902 L
.75464 .30902 L
.75485 .30902 L
.75505 .30902 L
.75527 .30902 L
.7555 .30902 L
.75571 .30902 L
.75591 .30902 L
.7561 .30902 L
.75631 .30902 L
.75652 .30902 L
.75674 .30902 L
.75693 .30902 L
.75703 .30902 L
.75713 .30902 L
.75725 .30902 L
.75736 .30902 L
.75746 .30902 L
.75751 .30902 L
.75757 .30902 L
.75762 .30902 L
Mistroke
.75767 .30902 L
.75773 .30902 L
.75779 .30902 L
.75785 .30902 L
.75791 .30902 L
.75797 .30902 L
.75803 .30902 L
.75824 .30902 L
.75843 .30902 L
.75887 .30902 L
.75965 .30902 L
.7604 .30902 L
.76119 .30902 L
.7616 .30902 L
.76206 .30902 L
.76244 .30902 L
.76286 .30902 L
.76328 .30902 L
.76368 .30902 L
.76406 .30902 L
.76442 .30902 L
.76485 .30902 L
.76523 .30902 L
.76568 .30902 L
.7661 .30902 L
.76647 .30902 L
.76689 .30902 L
.76709 .30902 L
.76732 .30902 L
.76751 .30902 L
.76772 .30902 L
.76792 .30902 L
.76811 .30902 L
.76829 .30902 L
.76849 .30902 L
.76884 .30902 L
.76902 .30902 L
.7692 .30902 L
.76939 .30902 L
.7696 .30902 L
.76982 .30902 L
.77003 .30902 L
.77025 .30902 L
.77045 .30902 L
.77063 .30902 L
.77073 .30902 L
.77082 .30902 L
.77091 .30902 L
.771 .30902 L
.77109 .30902 L
Mistroke
.77117 .30902 L
.77126 .30902 L
.77136 .30902 L
.77146 .30902 L
.77155 .30902 L
.77164 .30902 L
.77172 .30902 L
.77192 .30902 L
.77231 .30902 L
.77379 .30902 L
.7742 .30902 L
.77463 .30902 L
.77542 .30902 L
.77585 .30902 L
.77626 .30902 L
.77663 .30902 L
.77702 .30902 L
.77745 .30902 L
.77791 .30902 L
.77829 .30902 L
.77872 .30902 L
.77914 .30902 L
.77953 .30902 L
.77989 .30902 L
.78028 .30902 L
.7807 .30902 L
.78094 .30902 L
.78115 .30902 L
.78135 .30902 L
.78156 .30902 L
.78196 .30902 L
.78215 .30902 L
.78235 .30902 L
.78272 .30902 L
.78295 .30902 L
.78316 .30902 L
.78335 .30902 L
.78356 .30902 L
.78376 .30902 L
.78399 .30902 L
.7841 .30902 L
.78422 .30902 L
.78433 .30902 L
.78444 .30902 L
.78454 .30902 L
.78463 .30902 L
.78473 .30902 L
.78478 .30902 L
.78483 .30902 L
.78494 .30902 L
Mistroke
.785 .30902 L
.78505 .30902 L
.78515 .30902 L
.78525 .30902 L
.78545 .30902 L
.78565 .30902 L
.78601 .30902 L
.78683 .30902 L
.78752 .30902 L
.7883 .30902 L
.78869 .30902 L
.78907 .30902 L
.7895 .30902 L
.78989 .30902 L
.79023 .30902 L
.7906 .30902 L
.79098 .30902 L
.79137 .30902 L
.79179 .30902 L
.79219 .30902 L
.79255 .30902 L
.79294 .30902 L
.79337 .30902 L
.79358 .30902 L
.79382 .30902 L
.79402 .30902 L
.79423 .30902 L
.79462 .30902 L
.79483 .30902 L
.79504 .30902 L
.79543 .30902 L
.79567 .30902 L
.7959 .30902 L
.7961 .30902 L
.79632 .30902 L
.79651 .30902 L
.79672 .30902 L
.79692 .30902 L
.7971 .30902 L
.79731 .30902 L
.7975 .30902 L
.79761 .30902 L
.79772 .30902 L
.79783 .30902 L
.79793 .30902 L
.79802 .30902 L
.79812 .30902 L
.79822 .30902 L
.79832 .30902 L
.79841 .30902 L
Mistroke
.79851 .30902 L
.7986 .30902 L
.79869 .30902 L
.79874 .30902 L
.7988 .30902 L
.79889 .30902 L
.79912 .30902 L
.79952 .30902 L
.80033 .30902 L
.80078 .30902 L
.80121 .30902 L
.8016 .30902 L
.80203 .30902 L
.80278 .30902 L
.80315 .30902 L
.80354 .30902 L
.80391 .30902 L
.80425 .30902 L
.80464 .30902 L
.80506 .30902 L
.80541 .30902 L
.8058 .30902 L
.80622 .30902 L
.80645 .30902 L
.80666 .30902 L
.80709 .30902 L
.80747 .30902 L
.80784 .30902 L
.80805 .30902 L
.80825 .30902 L
.80865 .30902 L
.80887 .30902 L
.80907 .30902 L
.80944 .30902 L
.80964 .30902 L
.80983 .30902 L
.81018 .30902 L
.81038 .30902 L
.81055 .30902 L
.81074 .30902 L
.81094 .30902 L
.81105 .30902 L
.81116 .30902 L
.81125 .30902 L
.81136 .30902 L
.81146 .30902 L
.81156 .30902 L
.81165 .30902 L
.81174 .30902 L
.81183 .30902 L
Mistroke
.81191 .30902 L
.812 .30902 L
.8121 .30902 L
.8122 .30902 L
.8123 .30902 L
.81241 .30902 L
.81252 .30902 L
.81297 .30902 L
.81377 .30902 L
.81459 .30902 L
.81502 .30902 L
.81548 .30902 L
.81588 .30902 L
.81632 .30902 L
.81672 .30902 L
.8171 .30902 L
.8175 .30902 L
.81793 .30902 L
.81834 .30902 L
.81873 .30902 L
.8191 .30902 L
.81945 .30902 L
.81984 .30902 L
.82021 .30902 L
.82059 .30902 L
.821 .30902 L
.82121 .30902 L
.82143 .30902 L
.82162 .30902 L
.82183 .30902 L
.82203 .30902 L
.82223 .30902 L
.82241 .30902 L
.8226 .30902 L
.82295 .30902 L
.82313 .30902 L
.82331 .30902 L
.82349 .30902 L
.82369 .30902 L
.8239 .30902 L
.8241 .30902 L
.82433 .30902 L
.82454 .30902 L
.82473 .30902 L
.82483 .30902 L
.82493 .30902 L
.82502 .30902 L
.82511 .30902 L
.8252 .30902 L
.82528 .30902 L
Mistroke
.82537 .30902 L
.82547 .30902 L
.82557 .30902 L
.82566 .30902 L
.82575 .30902 L
.82583 .30902 L
.82592 .30902 L
.82603 .30902 L
.82642 .30902 L
.82718 .30902 L
.82799 .30902 L
.82846 .30902 L
.82889 .30902 L
.82932 .30902 L
.82972 .30902 L
.8301 .30902 L
.8305 .30902 L
.8309 .30902 L
.83135 .30902 L
.83173 .30902 L
.83215 .30902 L
.83254 .30902 L
.83289 .30902 L
.83328 .30902 L
.83368 .30902 L
.83407 .30902 L
.83442 .30902 L
.83483 .30902 L
.83506 .30902 L
.83527 .30902 L
.83567 .30902 L
.83586 .30902 L
.83608 .30902 L
.83628 .30902 L
.8365 .30902 L
.8367 .30902 L
.8369 .30902 L
.83709 .30902 L
.83729 .30902 L
.83747 .30902 L
.83765 .30902 L
.83785 .30902 L
.83807 .30902 L
.83825 .30902 L
.83836 .30902 L
.83846 .30902 L
.83857 .30902 L
.83868 .30902 L
.83877 .30902 L
.83888 .30902 L
Mistroke
.83893 .30902 L
.83899 .30902 L
.83905 .30902 L
.83911 .30902 L
.83921 .30902 L
.83927 .30902 L
.83933 .30902 L
.83943 .30902 L
.83953 .30902 L
.83971 .30902 L
.84012 .30902 L
.84085 .30902 L
.84166 .30902 L
.84211 .30902 L
.84252 .30902 L
.84292 .30902 L
.84329 .30902 L
.8437 .30902 L
.84413 .30902 L
.8445 .30902 L
.8449 .30902 L
.84527 .30902 L
.84562 .30902 L
.84599 .30902 L
.84639 .30902 L
.84677 .30902 L
.84712 .30902 L
.8475 .30902 L
.84772 .30902 L
.84793 .30902 L
.84834 .30902 L
.84857 .30902 L
.84877 .30902 L
.84916 .30902 L
.84936 .30902 L
.84958 .30902 L
.84976 .30902 L
.84996 .30902 L
.85032 .30902 L
.85053 .30902 L
.85077 .30902 L
.85099 .30902 L
.85119 .30902 L
.85137 .30902 L
.85158 .30902 L
.85168 .30902 L
.85179 .30902 L
.85189 .30902 L
.85199 .30902 L
.85208 .30902 L
Mistroke
.85218 .30902 L
.85229 .30902 L
.85238 .30902 L
.85248 .30902 L
.85258 .30902 L
.85266 .30902 L
.85275 .30902 L
.85281 .30902 L
.85286 .30902 L
.85296 .30902 L
.85302 .30902 L
.85307 .30902 L
.85319 .30902 L
.85359 .30902 L
.85447 .30902 L
.85489 .30902 L
.85529 .30902 L
.85608 .30902 L
.8565 .30902 L
.85694 .30902 L
.8573 .30902 L
.85765 .30902 L
.85803 .30902 L
.85843 .30902 L
.85885 .30902 L
.85925 .30902 L
.85968 .30902 L
.8599 .30902 L
.86014 .30902 L
.86054 .30902 L
.86076 .30902 L
.86097 .30902 L
.86135 .30902 L
.86154 .30902 L
.86175 .30902 L
.86196 .30902 L
.86218 .30902 L
.86237 .30902 L
.86258 .30902 L
.86276 .30902 L
.86297 .30902 L
.86333 .30902 L
.86355 .30902 L
.86375 .30902 L
.86398 .30902 L
.8642 .30902 L
.8644 .30902 L
.86459 .30902 L
.86479 .30902 L
.86501 .30902 L
Mistroke
.86522 .30902 L
.86533 .30902 L
.86544 .30902 L
.86554 .30902 L
.86565 .30902 L
.86575 .30902 L
.86584 .30902 L
.86595 .30902 L
.86601 .30902 L
.86608 .30902 L
.86614 .30902 L
.86619 .30902 L
.86624 .30902 L
.86631 .30902 L
.86636 .30902 L
.86642 .30902 L
.86648 .30902 L
.86653 .30902 L
.86663 .30902 L
.86673 .30902 L
.86694 .30902 L
.86717 .30902 L
.86758 .30902 L
.86835 .30902 L
.86912 .30902 L
.86955 .30902 L
.86995 .30902 L
.87038 .30902 L
.87077 .30902 L
.87122 .30902 L
.87164 .30902 L
.87201 .30902 L
.87242 .30902 L
.87284 .30902 L
.87324 .30902 L
.87361 .30902 L
.87395 .30902 L
.87433 .30902 L
.87472 .30902 L
.87493 .30902 L
.87512 .30902 L
.87549 .30902 L
.87569 .30902 L
.87588 .30902 L
.8761 .30902 L
.8763 .30902 L
.87664 .30902 L
.87683 .30902 L
.87702 .30902 L
.87722 .30902 L
Mistroke
.87742 .30902 L
.87759 .30902 L
.87778 .30902 L
.87799 .30902 L
.87818 .30902 L
.87837 .30902 L
.87855 .30902 L
.87874 .30902 L
.87895 .30902 L
.87905 .30902 L
.87917 .30902 L
.87927 .30902 L
.87937 .30902 L
.87946 .30902 L
.87956 .30902 L
.87966 .30902 L
.87972 .30902 L
.87977 .30902 L
.87986 .30902 L
.87995 .30902 L
.88004 .30902 L
.88014 .30902 L
.88023 .30902 L
.88032 .30902 L
.88048 .30902 L
.88085 .30902 L
.88163 .30902 L
.88245 .30902 L
.88288 .30902 L
.88335 .30902 L
.88378 .30902 L
.88418 .30902 L
.8846 .30902 L
.88499 .30902 L
.88535 .30902 L
.88573 .30902 L
.88615 .30902 L
.88659 .30902 L
.88697 .30902 L
.88718 .30902 L
.88739 .30902 L
.88779 .30902 L
.888 .30902 L
.8882 .30902 L
.88856 .30902 L
.88876 .30902 L
.88895 .30902 L
.88936 .30902 L
.88959 .30902 L
.88981 .30902 L
Mistroke
.8902 .30902 L
.8904 .30902 L
.89062 .30902 L
.89082 .30902 L
.89104 .30902 L
.89124 .30902 L
.89143 .30902 L
.89162 .30902 L
.89179 .30902 L
.89199 .30902 L
.89218 .30902 L
.89238 .30902 L
.89248 .30902 L
.8926 .30902 L
.89269 .30902 L
.8928 .30902 L
.89289 .30902 L
.89298 .30902 L
.89309 .30902 L
.89315 .30902 L
.89322 .30902 L
.89332 .30902 L
.89338 .30902 L
.89344 .30902 L
.89354 .30902 L
.89364 .30902 L
.89374 .30902 L
.8938 .30902 L
.89385 .30902 L
.89473 .30902 L
.89556 .30902 L
.8963 .30902 L
.89672 .30902 L
.89711 .30902 L
.89748 .30902 L
.89784 .30902 L
.89822 .30902 L
.89863 .30902 L
.89907 .30902 L
.89948 .30902 L
.89984 .30902 L
.90024 .30902 L
.90045 .30902 L
.90067 .30902 L
.90087 .30902 L
.90108 .30902 L
.90147 .30902 L
.90183 .30902 L
.90203 .30902 L
.90224 .30902 L
Mistroke
.90263 .30902 L
.90287 .30902 L
.90309 .30902 L
.90331 .30902 L
.90351 .30902 L
.90388 .30902 L
.90408 .30902 L
.90429 .30902 L
.90451 .30902 L
.90472 .30902 L
.90491 .30902 L
.90511 .30902 L
.90531 .30902 L
.90549 .30902 L
.90569 .30902 L
.90588 .30902 L
.90606 .30902 L
.90622 .30902 L
.9064 .30902 L
.90649 .30902 L
.90659 .30902 L
.9067 .30902 L
.9068 .30902 L
.9069 .30902 L
.90696 .30902 L
.90701 .30902 L
.90711 .30902 L
.90717 .30902 L
.90722 .30902 L
.90731 .30902 L
.90741 .30902 L
.9076 .30902 L
.90777 .30902 L
.90816 .30902 L
.90902 .30902 L
.90945 .30902 L
.90984 .30902 L
.91021 .30902 L
.91062 .30902 L
.91104 .30902 L
.91148 .30902 L
.91185 .30902 L
.91225 .30902 L
.91263 .30902 L
.91297 .30902 L
.91335 .30902 L
.91376 .30902 L
.91415 .30902 L
.9145 .30902 L
.91491 .30902 L
Mistroke
.91514 .30902 L
.91535 .30902 L
.91575 .30902 L
.91594 .30902 L
.91616 .30902 L
.91636 .30902 L
.91658 .30902 L
.91677 .30902 L
.91698 .30902 L
.91716 .30902 L
.91737 .30902 L
.91773 .30902 L
.91795 .30902 L
.91814 .30902 L
.91836 .30902 L
.91859 .30902 L
.9188 .30902 L
.91898 .30902 L
.91919 .30902 L
.91941 .30902 L
.91962 .30902 L
.91972 .30902 L
.91984 .30902 L
.91993 .30902 L
.92004 .30902 L
.92014 .30902 L
.92023 .30902 L
.92029 .30902 L
.92034 .30902 L
.92045 .30902 L
.92051 .30902 L
.92057 .30902 L
.92063 .30902 L
.92069 .30902 L
.92074 .30902 L
.9208 .30902 L
.92086 .30902 L
.92091 .30902 L
.92101 .30902 L
.92112 .30902 L
.92274 .30902 L
.92314 .30902 L
.92356 .30902 L
.92402 .30902 L
.92445 .30902 L
.92485 .30902 L
.92522 .30902 L
.92563 .30902 L
.92607 .30902 L
.92649 .30902 L
Mistroke
.92688 .30902 L
.92731 .30902 L
.92755 .30902 L
.92776 .30902 L
.92816 .30902 L
.92839 .30902 L
.92859 .30902 L
.92897 .30902 L
.92917 .30902 L
.92938 .30902 L
.92958 .30902 L
.9298 .30902 L
.92999 .30902 L
.93019 .30902 L
.93038 .30902 L
.93058 .30902 L
.93094 .30902 L
.93116 .30902 L
.93136 .30902 L
.93158 .30902 L
.93181 .30902 L
.93201 .30902 L
.9322 .30902 L
.9324 .30902 L
.93262 .30902 L
.93283 .30902 L
.93305 .30902 L
.93324 .30902 L
.93334 .30902 L
.93344 .30902 L
.93356 .30902 L
.93367 .30902 L
.93377 .30902 L
.93387 .30902 L
.93393 .30902 L
.93399 .30902 L
.93405 .30902 L
.93411 .30902 L
.93417 .30902 L
.93422 .30902 L
.93427 .30902 L
.93433 .30902 L
.93443 .30902 L
.93453 .30902 L
.93463 .30902 L
.93473 .30902 L
.93511 .30902 L
.93595 .30902 L
.93673 .30902 L
.93712 .30902 L
Mistroke
.93755 .30902 L
.93792 .30902 L
.93832 .30902 L
.93869 .30902 L
.93903 .30902 L
.93941 .30902 L
.93982 .30902 L
.94021 .30902 L
.94055 .30902 L
.94097 .30902 L
.9412 .30902 L
.94141 .30902 L
.9418 .30902 L
.942 .30902 L
.94222 .30902 L
.94242 .30902 L
.94264 .30902 L
.94283 .30902 L
.94303 .30902 L
.94322 .30902 L
.94342 .30902 L
.94378 .30902 L
.944 .30902 L
.9442 .30902 L
.94442 .30902 L
.94465 .30902 L
.94485 .30902 L
.94503 .30902 L
.94524 .30902 L
.94546 .30902 L
.94567 .30902 L
.94589 .30902 L
.94607 .30902 L
.94628 .30902 L
.9465 .30902 L
.94663 .30902 L
.94674 .30902 L
.94685 .30902 L
.94696 .30902 L
.94706 .30902 L
.94717 .30902 L
.94728 .30902 L
.94738 .30902 L
.94748 .30902 L
.94758 .30902 L
.94768 .30902 L
.94773 .30902 L
.94779 .30902 L
.94784 .30902 L
.94789 .30902 L
Mistroke
.94795 .30902 L
.94801 .30902 L
.9481 .30902 L
.9482 .30902 L
.94838 .30902 L
.94879 .30902 L
.94954 .30902 L
.94994 .30902 L
.95035 .30902 L
.95072 .30902 L
.95112 .30902 L
.95148 .30902 L
.95182 .30902 L
.95222 .30902 L
.95266 .30902 L
.95308 .30902 L
.95346 .30902 L
.95381 .30902 L
.95419 .30902 L
.95438 .30902 L
.95458 .30902 L
.95495 .30902 L
.95516 .30902 L
.95538 .30902 L
.95577 .30902 L
.95601 .30902 L
.95623 .30902 L
.95644 .30902 L
.95666 .30902 L
.95685 .30902 L
.95706 .30902 L
.95743 .30902 L
.95764 .30902 L
.95787 .30902 L
.95808 .30902 L
.95827 .30902 L
.95847 .30902 L
.95866 .30902 L
.95885 .30902 L
.95907 .30902 L
.95925 .30902 L
.95942 .30902 L
.95962 .30902 L
.95981 .30902 L
.96001 .30902 L
.96012 .30902 L
.96022 .30902 L
.96032 .30902 L
.96042 .30902 L
.9606 .30902 L
Mistroke
.96071 .30902 L
.96082 .30902 L
.96094 .30902 L
.961 .30902 L
.96106 .30902 L
.96116 .30902 L
.96126 .30902 L
.96136 .30902 L
.96142 .30902 L
.96147 .30902 L
.96157 .30902 L
.96167 .30902 L
.96175 .30902 L
.96184 .30902 L
.96225 .30902 L
.96297 .30902 L
.96338 .30902 L
.96383 .30902 L
.96421 .30902 L
.96462 .30902 L
.96505 .30902 L
.96545 .30902 L
.96587 .30902 L
.96611 .30902 L
.96634 .30902 L
.96674 .30902 L
.96696 .30902 L
.96717 .30902 L
.96755 .30902 L
.96795 .30902 L
.96816 .30902 L
.96838 .30902 L
.96858 .30902 L
.96878 .30902 L
.96897 .30902 L
.96918 .30902 L
.96954 .30902 L
.96976 .30902 L
.96996 .30902 L
.97017 .30902 L
.97041 .30902 L
.97062 .30902 L
.97082 .30902 L
.97103 .30902 L
.97122 .30902 L
.97159 .30902 L
.97179 .30902 L
.97199 .30902 L
.97234 .30902 L
.97254 .30902 L
Mistroke
.97272 .30902 L
.97294 .30902 L
.97314 .30902 L
.97332 .30902 L
.97352 .30902 L
.97374 .30902 L
.97385 .30902 L
.97396 .30902 L
.97407 .30902 L
.97418 .30902 L
.97427 .30902 L
.97437 .30902 L
.97449 .30902 L
.97454 .30902 L
.97461 .30902 L
.97466 .30902 L
.97472 .30902 L
.97482 .30902 L
.97488 .30902 L
.97493 .30902 L
.97499 .30902 L
.97506 .30902 L
.97512 .30902 L
.97519 .30902 L
.97524 .30902 L
.97531 .30902 L
.97553 .30902 L
.97577 .30902 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{421.375, 260.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008>0001AB000`400?l00000o`00003ooooooooo
oooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo
003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooo
oooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool0
0?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooooooo
ool@ooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooo
ooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo0ol0003o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0
003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool002[ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo
e_ooool002[ooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0oooo
oooFooooo`00:_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool2o`000?oooooof?ooool0
02[ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo0_l0003oooooomSooooo000Zooooo`;o
00001?ooool3o`0000;ooooo0_l0003oooooomSooooo000Zooooo`;o00001?ooool00ol0003ooooo
ooooo`02ooooo`;o0000oooooooHooooo`00:_ooool2o`0000Cooooo00?o0000ooooooooool00_oo
ool2o`000?oooooof?ooool002[ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooool00000oooooooGooooo`00:_ooool2o`0000Cooooo00?o0000ooooooooool00_ooool00ol0
003oooooo`00003oooooomOooooo000Yooooo`03o`000?oooooo000000Cooooo00?o0000oooooooo
ool00_ooool00ol0003oooooo`00003oooooomOooooo000Yooooo`03o`000?oooooo000000Cooooo
00?o0000ooooooooool00_ooool00ol0003oooooo`00003oooooomOooooo000Yooooo`03o`000?oo
oooo000000Cooooo00?o0000ooooooooool00_ooool00ol0003oooooo`00003oooooomOooooo000Y
ooooo`03o`000?oooooo000000Cooooo00?o0000ooooooooool00_ooool00ol0003oooooo`00003o
ooooomOooooo000Yooooo`03o`000?oooooo000000Cooooo00?o0000ooooooooool00_ooool00ol0
003oooooo`00003oooooomOooooo000Yooooo`03o`000?oooooo000000Cooooo00?o0000oooooooo
ool00_ooool00ol0003oooooo`00003oooooomOooooo000Yooooo`03o`000?oooooo000000Cooooo
0ol00002ooooo`03o`000?oooooo00000?ooooooeoooool002Wooooo00?o0000ooooool000001?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooo00000?ooooooeoooool002Wooooo00?o0000
ooooool000001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo00000?ooooooeoooool0
02Wooooo00?o0000ooooool000001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo0000
0?ooooooeoooool002Wooooo00?o0000ooooool000001?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooo00000?ooooooeoooool002Wooooo00?o0000ooooool000001?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooo00000?ooooooeoooool002Wooooo00?o0000ooooool000001?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooo00000?ooooooeoooool0013ooooo0_o^k^h3
ooooo`;ok^k^4_ooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooool00000oooooooGooooo`002oooool2o`00000:oa0@4?ooooooooooonk^k_mEEEGok^k^oooo
ooo^k^koEEEEonk^kP?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0ooo
ool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool00000
oooooooGooooo`003?ooool00ol0003oooooooooo`02ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h0
1_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01?l0003o
ooooooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool00000oooooooGoooo
o`0000?oooooo`000?l000001?l00002ooooo`Go00001?ooool00ooMgMgo0000omgMg@07ooooo`03
o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`04o`000?oooooooooo
o`0000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooo`00003oooooomOooooo0009oooo
o`04odA4A?oMgMgoooooo`0000Cooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooo`00003oooooomOooooo0009ooooo`04omgM
gOmEEEGoooooo`0000?ooooo00Ook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo0000
0oooool4o`000004ooooool0003oooooo`000?ooooooeoooool000[ooooo00?oMgMgolc<c?l00000
0oooool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@4003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000002
ooooo`03o`000?oooooooooo0?ooooooeOooool000[ooooo00?ok^k^odA4A?l000003oooool00ol0
003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool2o`000003ooooool0003o
oooo00;ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo0?ooooooeOoo
ool000_ooooo00?oMgMgo`000?ooool03?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00_ooool2o`000003ooooool0003o000000?ooooo00Go0000oooooooooooooooo
o`000002ooooo`03o`000?oooooooooo0?ooooooeOooool002Sooooo0_l000000ooooooo0000o`00
0003ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`3oooooomGooooo
000Xooooo`?o000000?oooooo`000?ooool00_ooool01Ol0003ooooooooooooooooo000000;ooooo
00?o0000ooooooooool0oooooooEooooo`00:Oooool01?l0003oooooooooool00003ooooo`05o`00
0?ooooooooooooooool000000_ooool00ol0003oooooooooo`3oooooomGooooo000Yooooo`;o0000
00?oooooo`000?ooool00_ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000oooooooo
ool0oooooooEooooo`00:Oooool01?l0003oooooooooool00003ooooo`05o`000?oooooooooooooo
ool000000_ooool00ol0003oooooooooo`3oooooomGooooo000Yooooo`04o`000?ooooooooooo`00
00?ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo0?ooooooeOooool0
02Wooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000;ooooo00?o
0000ooooooooool0oooooooEooooo`00:Oooool01?l0003oooooooooool00003ooooo`05o`000?oo
ooooooooooooool000000_ooool00ol0003oooooooooo`3oooooomGooooo000Yooooo`04o`000?oo
ooooooooo`0000?ooooo0ol000001Ooooooo0000oooooooooooo00000?ooooooeoooool002Wooooo
00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000oooo
ooooool0oooooooEooooo`00:Oooool01?l0003oooooooooool00003ooooo`05o`000?oooooooooo
ooooool000000_ooool00ol0003oooooooooo`3oooooomGooooo000Yooooo`04o`000?oooooooooo
o`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo0?ooooooeOoo
ool002Wooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000;ooooo
00?o0000ooooooooool0oooooooEooooo`00:Oooool01?l0003oooooooooool00003ooooo`05o`00
0?ooooooooooooooool000000_ooool00ol0003oooooooooo`3oooooomGooooo000Yooooo`04o`00
0?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo
0?ooooooeOooool002Wooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo
000000;ooooo00?o0000ooooooooool0oooooooEooooo`00:Oooool01?l0003oooooooooool00003
ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`3oooooomGooooo000Y
ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`00
0?oooooooooo0?ooooooeOooool002Wooooo00Co0000oooooooooooo00000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooooooool0oooooooDooooo`00:Oooool01?l0003ooooo
ooooool00003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`3ooooo
omCooooo000Yooooo`04o`000?ooooooooooo`0000?ooooo0ol000000ooooooo0000ooooo`02oooo
o`03o`000?oooooooooo0?ooooooe?ooool002Wooooo00Co0000oooooooooooo00000oooool01Ol0
003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0oooooooDooooo`00:Oooool01?l0
003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`3oooooomCooooo000Xooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo000000?ooooo00?o0000ooooooooool0oooooooDooooo`00:?ooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo0?oo
ooooe?ooool002Sooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooooooo`3oooooomCooooo000Xooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0oooooooD
ooooo`00:?ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`03o`000?oooooooooo0?ooooooe?ooool002Sooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`3oooooomCooooo
000Xooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?o
oooo00?o0000ooooooooool0oooooooDooooo`00:?ooool01Ol0003ooooooooooooooooo000000?o
oooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo0?ooooooe?ooool002So
oooo00Go0000ooooooooooooooooo`000003ooooo`?o000000?oooooo`000?ooool00_ooool00ol0
003oooooooooo`3oooooomCooooo000Xooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0oooooooDooooo`00:?ooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oo
oooooooo0?ooooooe?ooool002Sooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`3oooooomCooooo000Oooooo`03o`000?oo
oooooooo00Kooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00000oooool00ol0003oooooooooo`06ooooo`;o0000ooooooo<ooooo`007_ooool2o`0000Sooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool00ol0
003oooooooooo`06ooooo`;o0000ooooooo<ooooo`007_ooool2o`0000Sooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`06
ooooo`;o0000ooooooo<ooooo`004?ooool2onk^kP?ooooo0_o^k^h7ooooo`;o00002?ooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oo
oooooooo00Kooooo0_l0003oooooolcooooo0009ooooo`Go00000_ooool01oo^k^koEEEEonk^k_oo
ooook^k^oeEEEOo^k^h00oooool6o`000006ooooooo^k^ko<S8bo`000?lb<S;ok^k^0_ooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oo
oooooooo00Kooooo0_l0003oooooolcooooo0009ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00ooo
ool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00[o0000ooooool0003o0000oooooomgMgOoV9RH
oooooonHV9SoMgMg0_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`03o`000?oooooooooo00Kooooo0_l0003oooooolcooooo00000ooooooo0000
o`000004o`0000?ooooo00?oV9RHob4Q8Oo^k^h01Oooool00ooMgMgo0000omgMg@07ooooo`06o`00
0?oooooo0000ooooool0003o410@0oooool01?l@413oooooooooool00003ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo0_l0003oooooolcooooo
000;ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`04o`00
0?oooooo0000ooooo`;o00000oooool01?l0003oooooooooool00003ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000Sooooo0_l0003oooooolcooooo000<
ooooo`0;ogMgMomVIVKoooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool01?l0
003oooooo`000?ooool2o`0000?ooooo00Co0000oooooooooooo00000oooool01?l0003ooooooooo
ooooool5o`0000?ooooo00?o0000ooooooooool01_ooool2o`000?ooooooc?ooool000gooooo00?o
0000ooooooooool00_o^k^h3ooooo`;ok^k^1Oooool2o`0000;ooooo00?o0000oa0@4?ooool00_oo
ool01?l@413oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000Oooooo00?o0000ooooool00000ooooooo<ooooo`002Oooool01Ol0003o
^[ZjoooooonHV9So410@00kooooo0_l00002ooooo`06o`000?mgMgOoV9RHoooooonHV9SoMgMg0_oo
ool3o`000003ooooool0003ooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooool00000ooooooo<ooooo`002Oooool01OnHV9So410@o`00
0?lQ8B7oc<c<00cooooo00CoEEEEofIVI_l0003o00000_ooool01_l0003ok^k^oc8b<_l0003o<S8b
onk^kP;ooooo00?o0000ooooooooool00_l00003ooooo`05o`000?ooooooooooooooool000000ooo
ool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`000?ooooooboooool001gooooo00Co
0000oooooooooooo00001oooool00ol0003oooooooooo`02o`0000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo0000ooooooo;oooo
o`007Oooool01?l0003oooooooooool00007ooooo`?o000000?oooooo`000?ooool00_ooool01Ol0
003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0
003ooooool_ooooo000Mooooo`04o`000?ooooooooooo`0000Oooooo0_l00002ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooo
oooo0000ooooooo;ooooo`007Oooool01?l0003oooooooooool00007ooooo`05o`000?oooooo0000
ooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01Ooo
ool01?l0003oooooooooool0003ooooool_ooooo000Mooooo`04o`000?ooooooooooo`0000Oooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool00ol0
003oooooooooo`05ooooo`04o`000?ooooooooooo`000?ooooooboooool001gooooo00Co0000oooo
oooooooo00001oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000003ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo0000ooooooo;ooooo`00
7Oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0
003ooooool_ooooo000Mooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`05ooooo`04
o`000?ooooooooooo`000?ooooooboooool001gooooo00Co0000oooooooooooo00001oooool01Ol0
003ooooooooooooooooo000000?ooooo0ol000000ooooooo0000ooooo`02ooooo`03o`000?oooooo
oooo00Gooooo00Co0000oooooooooooo0000ooooooo;ooooo`007Oooool01?l0003oooooooooool0
0007ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?o
oooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0003ooooool_ooooo000Mooooo`04
o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000000oooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`000?oooooo
boooool001gooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?oooooooooo
o`000?ooooooboooool001gooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`03
ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000007ooooo`04o`00
0?ooooooooooo`000?ooooooboooool001cooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo
000000Oooooo00Co0000oooooooooooo0000ooooooo;ooooo`007?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool0
0003ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool0003ooooool_o
oooo000Looooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000007oooo
o`04o`000?ooooooooooo`000?ooooooboooool001cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00000oooool0
1Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000ooooooo;ooooo`007?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000001oooool01?l0003o
ooooooooool0003ooooool_ooooo000Looooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooo
ooooooooooooo`000007ooooo`04o`000?ooooooooooo`000?ooooooboooool001cooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00Co0000
oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo
0000ooooooo;ooooo`007?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03o`000003ooooool0003ooooo00;ooooo
00?o0000ooooooooool01Oooool01?l0003oooooooooool0003ooooool_ooooo000Looooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`04o`00
0?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?oooooooooo
o`000?ooooooboooool001cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooo
oooo000000Oooooo00Co0000oooooooooooo0000ooooooo;ooooo`007?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool01?l0003ooooooooo
ool00003ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo0000
0?oooooob_ooool001cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo
000000Oooooo00Go0000ooooooooooooooooo`00003ooooool[ooooo000Looooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`04o`000?oooooo
ooooo`0000?ooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool0
0000??ooool2onk^kP?ooooo0_o^k^iGooooo`;ok^k^0oooool2onk^kV3ooooo0_o^k^h3ooooo`;o
k^k^C_ooool2onk^kP?ooooo0_o^k^i/ooooo`007?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00003ooooo`05
o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000003Kooooo00goA4A4
o`000?l0003o<S8bomgMgOooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l00000
2?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^@_ooool4o`000009oa0@4?ooooook^k^oeEE
EOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb
<S;ok^k^>oooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`0=odA4A?l0003o0000
oc8b<_oMgMgoooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co000000So410@oooo
ooooooook^k^oc8b<_l0003o<S8bonk^kSSooooo1Ol00002ooooo`07onk^k_mEEEGok^k^ooooooo^
k^koEEEEonk^kP03ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kUgooooo
000Looooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`04ooooo`05o`000?ooooooooooooooool00000>Oooool02OmgMgOo<S8booooooooooook^k^
oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`14ooooo`03o`000?oooooooooo00;ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0mooooo`03o`000?oooooooooo
00Cooooo0_lQ8B48ooooo`09ogMgMolb<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg03Sooooo00GoV9RHob4Q8Oo^
k^koooooodA4A003ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0GOooool001cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00000ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooooooo
o`00000jooooo`07o`000?oooooooooooooooooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo
00;ooooo00Go410@oooooooooooooooooa0@4014ooooo`03o`000?oooooooooo00?ooooo00?ogMgM
o`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100?Ooo
ool00ol0003oooooooooo`0?ooooo`07o`000?oooooooooooooooooMgMgo0000omgMg@07ooooo`03
o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400iooooo`03oiRHV?lQ8B7ok^k^
00Gooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@4100GOooool001cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0g
ooooo`09ogMgMolb<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000oooooooo
ool00_ooool01Ol0003ooooooooooooooooo000004Cooooo00?o0000ooooooooool00_ooool01Oo^
k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000003gooooo00?o0000ooooooooool03_ooool02OmgMgOo<S8booooooooooook^k^oeEEEOoM
gMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000j
ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00001Mooooo`007?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool01?l0003ooooooooo
ool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo03Cooooo00go0000ob4Q8Ol0003o<S8bolc<c?ooooook^k^
oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000004Cooooo00_o0000ooooooooooooooooonk^k_mEEEGok^k^ooooooo^k^koEEEE
onk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000mooooo`03
o`000?oooooooooo00_ooooo00go0000ob4Q8Ol0003o<S8bolc<c?ooooook^k^oeEEEOo^k^kooooo
onk^k_mEEEGok^k^00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
03_ooooo00_oMgMgofIVI_ooooooooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03
o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001Mooooo`007?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool01?l0003o
ooooooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool00oooool2onk^
kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4014
ooooo`04o`000?ooooooooooooooo`;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@03gooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`03ooooo`;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@413ooooo
oooooooooooo410@03cooooo00?o0000ooooooooool00_o^k^h3ooooo`;ok^k^1Oooool00ol0003o
ooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100GOooool001?ooooo0_l00007ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?o000000?oooooo`000?ooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Sooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`;o0000<oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Sooooo0_l0000^ooooo`05o`000?nj^[[ooooooiRHV?l@41003_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool2o`0005?ooooo000Booooo`03o`00
0?oooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooo000002cooooo1?l0000<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP08ooooo`03o`000?oooooooooo03Oooooo00?oEEEEofIVI_l000003Oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01oooool01?l0003oooooooooool0
000`ooooo`03oeEEEOmVIVKo000000gooooo1?l0000<ooooo`03oeEEEOmVIVKo000000Cooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP07ooooo`04o`000?ooooooooooo`0002gooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c00<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP07
ooooo`04o`000?ooooooooooo`0005;ooooo000Booooo`03o`000?oooooo000000Oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000004[ooooo1?l0
0003ooooo`03o`000?oooooooooo05Cooooo1?l000001Ooooooo0000oooooooooooo000005kooooo
1?l000001Ooooooo0000oooooooooooo000004cooooo1?l000001Ooooooo0000oooooooooooo0000
05;ooooo000Booooo`03o`000?oooooo000000Kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooo0000057ooooo00?o0000ooooooooool0FOooool3o`00
06Cooooo0ol0001Booooo`?o0000Doooool0017ooooo00Go0000ooooooooooooooooo`000005oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0
001>ooooo`04o`000?ooooooooooo`0005_ooooo00?o0000ooooooooool0I?ooool00ol0003ooooo
ooooo`1Booooo`03o`000?oooooooooo05;ooooo000Aooooo`05o`000?ooooooooooooooool00000
1Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooo
ooooooooo`00001>ooooo`Co0000G?ooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo
05;ooooo00?o0000ooooooooool0DOooool0017ooooo00Go0000ooooooooooooooooo`000005oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooo
oooo00000?oooooo_oooool0017ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`04o`000?oo
ooooooooo`0000;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo0?ooooooP_ooool00omgMgOoIVIVooooo`0]ooooo`03ofIVI_mgMgOooooo00Oooooo
000@ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`3ooooooh7ooooo00?ogMgMoa0@4?o^k^h0;_ooool00oo^k^ko410@omgMg@07ooooo`004?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo0000
0_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
oooooom_ooooo`;o00000_ooool2o`0000cooooo00?oEEEEoiRHV?ooool00_l00002ooooo`07o`00
0?ooooooooooo`000?l@413ok^k^oeEEE@02o`000003odA4A?nj^[[ooooo00;ooooo00GoV9RHo`00
0?l0003oA4A4okZj^P02ooooo`08onk^k_mEEEGo0000o`000?m4A4Co^[Zjooooool@4105o`0000?o
oooo00So410@oc8b<_l0003o0000oa0@4?nYZJWoQhN7ofIVIPOooooo000@ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00002ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`?o0000oooo
oomWooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM3?ooool01Ol0003ooooooooooooooooo0000
00;ooooo00_o0000oooooooooooo0000oooooomEEEGoMgMgooooooo^k^koMgMgoa0@4003ooooo`05
oa0@4?nj^[[ok^k^ogMgMol@41000_ooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40?ooooo00?o
0000ooooooooool01?ooool02?l0003oZJVYoooooooooooo^[Zjo`000?o^k^ko00001oooool00?oo
0000]?l0000?ooooo`04omgMgOl0003o410@olc<c0gooooo00Go<S8booooooooooooooooo`000002
ooooo`06o`000?ooooooooooo`000?oooooo00002?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool01onj^[[oQhN7ofIVI_mVIVKo410@oooo
ool000001oooool000[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooool000001?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00?ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00Co0000oooooooooooooooo0_l00006ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`?o00002?ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool05oooool0
1?o^k^ko8B4Qoa0@4?o^k^h=ooooo`05oc8b<_ooooooooooooooool000000_ooool01Ol0003ooooo
ooooool0003ooooo00Ko00000oooool00ol0003oooooooooo`04ooooo`Ko00000oooool00ol0003o
ooooooooo`04ooooo`08oc8b<_lQ8B7oMgMgogMgMon7QhOok^k^ooooool00007ooooo`002_ooool2
o`0000?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
000000Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`04o`000?oooooo
ooooo`0000;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`07o`000?oo
ooooooooooooool0003oooooo`000005ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooo
oooooooo0_l0000Aooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0Gooooo`04ob4Q8OmgMgOoMgMgoc8b<Pgooooo00Go0000onk^k_ooooooooooo`00
0002olc<c00;o`000?nYZJWogMgMob4Q8OooooooEEEEohN7Qoo^k^koooooohN7Qolb<S800oooool0
0ol0003oooooooooo`04ooooo`06oeEEEOn7QhOok^k^oooooon7QhOo<S8b0oooool00ol0003o<S8b
omgMg@04ooooo`08o`000?nj^[[oooooonk^k_mgMgOo0000onk^k_l00007ooooo`003?ooool01?l0
003oooooo`000?l00006ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00000_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo0_l00002ooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`1Kooooo`03o`000?oo
oooooooo05_ooooo00?o0000ooooooooool05_ooool2o`0000;ooooo0_l0000<ooooo`0>oeEEEOmg
MgOooooooa0@4?l0003o8B4Qo`000?mgMgOo410@o`000?nYZJWoooooonk^k_mEEED2o`000004odA4
A?o^k^kooooooa0@40Go00000oooool01_o^k^koEEEEo`000?l0003oA4A4onk^kP;ooooo0_l00000
1?nYZJWo8B4Qo`000?lQ8B42ooooo`08ojVYZOlQ8B7o0000o`000?lb<S;o0000ogMgMomEEED7oooo
o`003Oooool2o`0000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00002oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool3o`000?ooooooOoooool00ooM
gMgo410@onk^kP0Booooo`03o`000?oooooooooo01Wooooo00?ok^k^oa0@4?oMgMd01oooool001Ko
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0oooooon8ooooo`03ogMgMomVIVKooooo017ooooo00?o0000oooo
ooooool06Oooool00omVIVKoMgMgooooo`07ooooo`005_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`04
o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3ooooo
ol;ooooo000Fooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo`_ooool001Kooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0ooooooo2ooooo`005oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`3ooooool;ooooo000Gooooo`05o`000?oooooooooo
ooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo`_oo
ool001Oooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0ooooooo2ooooo`005oooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Co0000
1Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`3ooooool;ooooo000Gooooo`04o`000?ooooooooooo`0000Oooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3ooooool;ooooo000Gooooo`04o`00
0?ooooooooooo`0000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`04
o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00003oooooolGooooo000Goooo
o`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00003oooooolGooooo
000Gooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00003ooooo
olGooooo000Gooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00
003oooooolGooooo000Gooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo
0000ooooooo5ooooo`005oooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`04o`000?oooooooooo
o`000?ooooooaOooool001Oooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool01?l0003ooooooooo
ool0003oooooolGooooo000Hooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo
0000ooooooo5ooooo`006?ooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`00
0?ooooooaOooool001Sooooo00?o0000ooooool000001oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00?ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooo`00003ooooo
olKooooo000Hooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Co00001Oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooool00000ooooooo6ooooo`006?ooool00ol0003ooooo
o`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01?l0003ooooo
ooooool00002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooo00000?ooooooa_ooool001Sooooo0_l00008ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00002ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`;o
0000ooooooo6ooooo`006?ooool2o`0000Sooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Kooooo0_l0003oooooolKooooo000Iooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`04o`00
0?ooooooooooo`0000;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Kooooo0_l0003oooooolKooooo000Rooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3oooooolkooooo000Rooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00002ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3oooooolko
oooo000Rooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01?l0003ooooo
ooooool00002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`3oooooolkooooo000Rooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`3oooooolkooooo000Rooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3oooooolkooooo000Rooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00002ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3oooooolko
oooo000Rooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01?l0003ooooo
ooooool00002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`3oooooolkooooo000Rooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooo`000003o`0000Gooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`3oooooolkooooo000Rooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`3oooooolkooooo000Sooooo`05o`000?ooooooooooooooool000001_oo
ool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`3oooooolkooooo000Sooooo`05o`000?ooooooooooooooool000001_oo
ool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooooooo
o`00003oooooom3ooooo000Sooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooo
o`000002ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00003oooooom3o
oooo000Sooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooo`000002ooooo`03
o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00003oooooom3ooooo000?ooooo`;o
k^k^0oooool2onk^kPgooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo0000
00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo00000?ooooood?ooool0
00Sooooo1Ol00002ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co000000Go
410@ooooooooooook^k^oc8b<P02o`000004onk^k_ooooooooooo`0000Kooooo00?o0000ooooool0
00000_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000ooooooo@oooo
o`002?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06
ooooo`03o`000?oooooooooo00;ooooo00OoMgMgoiRHV?oooooo0000ogMgMooooooo000000Oooooo
00?o0000ooooool000000_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool0
0000ooooooo@ooooo`002Oooool00onHV9So8B4Qonk^kP05ooooo`03omgMgOl0003ogMgM00Oooooo
00?o0000ooooooooool00_ooool01ol@413oooooooooool0003o410@ooooool000001oooool00ol0
003oooooo`000002ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00003o
ooooom3ooooo000:ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_l000000ooooooo0000ooooo`06
ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooo
oooo00000?ooooood?ooool000_ooooo00_oMgMgofIVI_ooooooooooonk^k_mEEEGok^k^ooooooo^
k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_l000000ooo
oooo0000ooooo`06ooooo`03o`000?oooooo000000?o00001_ooool01Ol0003ooooooooooooooooo
00000?ooooood?ooool000cooooo00?o0000ooooooooool00_o^k^h3ooooo`;ok^k^1Oooool00ol0
003oooooooooo`02ooooo`07oa0@4?ooooooooooo`000?l@413oooooo`000007ooooo`03o`000?oo
oooo000000;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo00000?oooooo
d?ooool000Sooooo00Go0000okZj^_ooooooV9RHoa0@400>ooooo`03o`000?oooooooooo00;ooooo
00OoMgMgoiRHV?oooooo0000ogMgMooooooo000000Oooooo00?o0000ooooool000000_ooool00ol0
003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000ooooooo@ooooo`002?ooool01OnH
V9So410@o`000?lQ8B7oc<c<00cooooo00?oEEEEofIVI_l000001?ooool02?o^k^ko<S8bo`000?l0
003ok^k^ooooool0003ooooo0_l00004ooooo`03o`000?oooooo000000;ooooo00?o0000oooooooo
ool01?ooool01Ol0003ooooooooooooooooo00000?ooooood?ooool002?ooooo00?o0000oooooooo
ool00_l00002ooooo`07o`000?ooooooooooooooool0003oooooo`000002ooooo`03o`000?oooooo
oooo00Cooooo00Go0000ooooooooooooooooo`00003oooooom3ooooo000Sooooo`03o`000?oooooo
oooo00;o00000_ooool01ol0003ooooooooooooooooo0000ooooool000000_ooool00ol0003ooooo
ooooo`04ooooo`05o`000?ooooooooooooooool00000ooooooo@ooooo`008oooool00ol0003ooooo
ooooo`04o`0000Cooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`04ooooo`05o`00
0?ooooooooooooooool00000ooooooo@ooooo`008oooool01_l0003oooooooooool0003oooooo`00
00Gooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooo
ooooool00000ooooooo@ooooo`008oooool01?l0003oooooooooool00002ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooo
ooooooooool00000ooooooo@ooooo`008oooool01?l0003oooooooooool00007ooooo`03o`000?oo
oooo000000;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo00000?oooooo
d?ooool002?ooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`000002ooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00003oooooom3ooooo000Sooooo`04o`00
0?ooooooooooo`0000Oooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`04ooooo`05
o`000?ooooooooooooooool00000ooooooo@ooooo`008oooool01?l0003oooooooooool00007oooo
o`03o`000?oooooo000000;o00001oooool01Ol0003ooooooooooooooooo00000?ooooood?ooool0
02?ooooo00Co0000oooooooooooo00001oooool01Ol0003oooooo`000?oooooo000000Oooooo00Go
0000ooooooooooooooooo`00003oooooom3ooooo000Sooooo`04o`000?ooooooooooo`0000Oooooo
00Go0000ooooool0003oooooo`000007ooooo`05o`000?ooooooooooooooool00000ooooooo@oooo
o`008oooool01?l0003oooooooooool00007ooooo`05o`000?oooooo0000ooooool000001oooool0
1Ol0003ooooooooooooooooo00000?ooooood?ooool002?ooooo00Co0000oooooooooooo00001ooo
ool01Ol0003oooooo`000?oooooo000000Oooooo00Co0000oooooooooooo0000oooooooAooooo`00
8oooool01?l0003oooooooooool00007ooooo`05o`000?oooooo0000ooooool000001oooool01?l0
003oooooooooool0003oooooom7ooooo000Sooooo`04o`000?ooooooooooo`0000Oooooo00Go0000
ooooool0003oooooo`000007ooooo`04o`000?ooooooooooo`000?oooooodOooool002?ooooo00Co
0000oooooooooooo00001oooool01Ol0003oooooo`000?oooooo000000Oooooo00Co0000oooooooo
oooo0000oooooooAooooo`008oooool01?l0003oooooooooool00007ooooo`05o`000?oooooo0000
ooooool000001oooool01?l0003oooooooooool0003oooooom7ooooo000Sooooo`04o`000?oooooo
ooooo`0000Oooooo00Go0000ooooool0003oooooo`000007ooooo`04o`000?ooooooooooo`000?oo
oooodOooool002?ooooo00Co0000oooooooooooo00001oooool01Ol0003oooooo`000?oooooo0000
00Oooooo00Co0000oooooooooooo0000oooooooAooooo`008oooool01?l0003oooooooooool00007
ooooo`05o`000?oooooo0000ooooool000001oooool01?l0003oooooooooool0003oooooom7ooooo
000Sooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool000000_l00007ooooo`04o`00
0?ooooooooooo`000?oooooodOooool002?ooooo00Co0000oooooooooooo00001oooool01Ol0003o
ooooo`000?oooooo000000Oooooo00Co0000oooooooooooo0000oooooooAooooo`008oooool01?l0
003oooooooooool00007ooooo`05o`000?oooooo0000ooooool000002?ooool00ol0003oooooo`00
003oooooom7ooooo000Sooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooool0003ooooo
o`000008ooooo`03o`000?oooooo00000?oooooodOooool002?ooooo00Co0000oooooooooooo0000
1oooool01Ol0003oooooo`000?oooooo000000Sooooo00?o0000ooooool00000oooooooAooooo`00
8oooool01?l0003oooooooooool00007ooooo`05o`000?oooooo0000ooooool000002?ooool00ol0
003oooooo`00003oooooom7ooooo000Sooooo`03o`000?oooooo000000Sooooo00Go0000ooooool0
003oooooo`000008ooooo`03o`000?oooooo00000?oooooodOooool002Cooooo0_l00008ooooo`05
o`000?oooooo0000ooooool000002?ooool00ol0003oooooo`00003oooooom7ooooo000Tooooo`;o
00002?ooool01Ol0003oooooo`000?oooooo000000Sooooo0_l0003oooooom;ooooo000Tooooo`;o
00002?ooool01Ol0003oooooo`000?oooooo000000Sooooo0_l0003oooooom;ooooo000Tooooo`;o
00002?ooool01Ol0003oooooo`000?oooooo000000Sooooo0_l0003oooooom;ooooo000Tooooo`;o
00002?ooool01Ol0003oooooo`000?oooooo000000Sooooo0_l0003oooooom;ooooo000Tooooo`;o
00002?ooool00ol0003oooooo`000002o`0000Sooooo0_l0003oooooom;ooooo000Tooooo`;o0000
2?ooool01Ol0003oooooo`000?oooooo000000Sooooo0_l0003oooooom;ooooo000Tooooo`;o0000
2?ooool01Ol0003oooooo`000?oooooo000000Sooooo0_l0003oooooom;ooooo000Tooooo`;o0000
2?ooool01Ol0003oooooo`000?oooooo000000Sooooo0_l0003oooooom;ooooo000Tooooo`;o0000
2?ooool01Ol0003oooooo`000?oooooo000000Sooooo0_l0003oooooom;ooooo000Tooooo`;o0000
2?ooool01Ol0003oooooo`000?oooooo000000Sooooo0_l0003oooooom;ooooo000?ooooo`;ok^k^
0oooool2onk^kPkooooo0_l00009ooooo`;o000000?oooooo`000?ooool01oooool2o`000?oooooo
d_ooool000[ooooo0_l000002_l@413oooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h3
ooooo`Co000000Oo410@ooooooooooook^k^oc8b<_l0003o<S8b00;o00002Oooool2o`000003oooo
ool0003ooooo00Oooooo0_l0003oooooom;ooooo000;ooooo`03o`000?oooooooooo00;ooooo00Go
k^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00CoMgMgoiRHV?oooooo
V9RH0_l00009ooooo`;o000000?oooooo`000?ooool02?ooool00ol0003oooooooooo`3oooooom3o
oooo0008ooooo`Go00001?ooool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo
00Go410@oooooooooooooooooa0@400:ooooo`;o000000?oooooo`000?ooool0oooooooKooooo`00
2?ooool01?m4A4CogMgMooooool00004ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000002_ooool2o`000003ooooool0003o
oooo0?oooooofoooool000Sooooo00CogMgMoeEEEOoooooo00000oooool01oo^k^koEEEEonk^k_oo
ooook^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
00002_ooool5o`000?oooooofoooool000Wooooo00?oMgMgolc<c?l000000oooool2onk^kP?ooooo
0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400:ooooo`;o
000000?oooooo`000?ooool0oooooooKooooo`002Oooool00oo^k^koA4A4o`00000?ooooo`03o`00
0?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0:ooooo`;o000000?oooooo`000?oo
ool0oooooooKooooo`002_ooool00omgMgOo0000ooooo`0<ooooo`03oeEEEOmVIVKo000000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`;o00001Oooool2o`000003ooooool0003ooooo0?oo
oooofoooool002Oooooo00Co0000oooooooooooo00001?ooool2o`000003ooooool0003ooooo0?oo
oooofoooool002Oooooo00Co0000oooooooooooo00001?ooool3o`000?oooooogOooool002Oooooo
0ol00005ooooo`?o0000oooooooMooooo`00:?ooool00ol0003oooooooooo`04ooooo`?o0000oooo
oooMooooo`00:Oooool00ol0003oooooooooo`03ooooo`?o0000oooooooMooooo`00;oooool3o`00
0?oooooogOooool002oooooo0ol0003oooooomgooooo000_ooooo`?o0000oooooooMooooo`00;ooo
ool4o`000?oooooog?ooool002oooooo0ol0003oooooomgooooo000_ooooo`?o0000oooooooMoooo
o`00;oooool3o`000?oooooogOooool002oooooo0ol0003oooooomgooooo000_ooooo`?o0000oooo
oooMooooo`00;oooool3o`000?oooooogOooool002oooooo0ol0003oooooomgooooo000_ooooo`?o
0000oooooooMooooo`00;oooool3o`000?oooooogOooool002oooooo0ol0003oooooomgooooo000_
ooooo`?o0000oooooooMooooo`00;oooool4o`000?oooooog?ooool002oooooo0ol0003oooooomgo
oooo000_ooooo`?o0000oooooooMooooo`00;oooool3o`000?oooooogOooool002oooooo0ol0003o
ooooomgooooo000_ooooo`?o0000oooooooMooooo`00;oooool3o`000?oooooogOooool002oooooo
0ol0003oooooomgooooo000_ooooo`?o0000oooooooMooooo`00;oooool3o`000?oooooogOooool0
033ooooo0_l0003oooooomgooooo000`ooooo`;o0000oooooooMooooo`00<?ooool3o`000?oooooo
g?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@
ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooo
oooooooooa3ooooo003ooooooooooooo4?ooool00:Cooooo0_l00003ooooo`03okZj^_lb<S;ooooo
00Gooooo0_l00005ooooo`03o`000?nj^[[ooooo0?ooooooE?ooool00:Cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo0_lb<S;ooooooeGo
oooo002Aooooo`?o00000_ooool01_lb<S;o410@ooooooooooook^k^oeEEE@;o000000?oA4A4okZj
^_ooool00oooool01_l0003oooooooooooooooooV9RHoa0@40;o000000?oZJVYooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4
okZj^P09ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@?ooooo00Goc<c<onk^k_oo
ooook^k^olc<c004ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kQ?ooooo
00Ko410@oc8b<_l0003o0000oa0@4?nYZJT2ooooo`06onk^k_mEEEGo0000o`000?m4A4Co^[Zj0ooo
ool01OmVIVKo0000o`000?m4A4Coc<c<0>cooooo002Booooo`05o`000?ooooooooooolc<c?l@4100
0oooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40Cooooo00[o0000ooooooooooooooooo`000?nY
ZJWoEEEEoiRHV?mEEEGo^[Zj1?ooool00ol0003oooooooooo`03ooooo`03olc<c?l0003o410@00co
oooo00Go410@okZj^_o^k^koMgMgoa0@4002ooooo`Ko000000KoooooogMgMonHV9SooooooiRHV?mg
MgL5ooooo`;o8B4Q0oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01?ooooo00Ko0000ojVYZOoooooooooookZj^_l00002
ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo410@0_ooool01_mVIVKoMgMgooooooooooooQhN7oa0@
4>cooooo002Booooo`05o`000?oooooooooooeEEEOn7QhL00oooool00ol0003oooooooooo`07oooo
o`0:o`000?oooooooooooooooolb<S;ok^k^oiRHV?mEEEGogMgMoa0@40Cooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`0;ooooo`05oa0@4?ooooooooooooooool@41002oooool00ooM
gMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400D
ooooo`05okZj^_n7QhOoIVIVofIVI_l@41000_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0>oooooo002Booooo`05o`000?oooooogMgMo`000?o^k^h00oooool6o`0000Cooooo00_o
0000oooooooooooooooookZj^_m4A4Coc<c<ob4Q8Ooooooo410@olc<c003ooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool01?ooool6o`000003ooooool0003ooooo00;ooooo00?o0000
ooooooooool02?ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000001?ooooo00Ko<S8bob4Q8OmgMgOoMgMgohN7Qoo^k^h2oooo
o`Ko00000_ooool00ol0003oooooooooo`3_ooooo`00T_ooool3o`000003oa0@4?nHV9Sooooo00;o
oooo00KoEEEEohN7Qoo^k^koooooohN7Qolb<S84ooooo`0;o`000?ooooooooooooooooo^k^ko0000
ooooool0003oooooofIVI_n7QhL00oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
00_ooooo00Go0000ooooooooooooooooo`00000:ooooo`05olc<c?o^k^koooooonk^k_o<c<`01_oo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000004oooool01_l0003o^[Zj
ooooooo^k^koMgMgo`0000;ooooo00KoEEEEohN7Qoo^k^koooooohN7Qolb<S82ooooo`06ofIVI_mg
MgOooooooooooon7QhOo0000k?ooool009;ooooo00Go0000ooooooooooooc<c<o`000003ooooo`06
onk^k_mEEEGo0000o`000?m4A4Cok^k^1?ooool02?l0003oooooooooooooooooIVIVoiRHV?oooooo
<S8b0_nj^[X01Ol0003ooooooooooooooooo000001;ooooo00?o410@o`000?l000000ol0000:oooo
o`05oa0@4?ooooooooooooooool@41005Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooo
ooooooooool@41001oooool3o`0000;ooooo0ol00004ooooo`06ojVYZOlQ8B7o0000o`000?lb<S;o
00000_ooool01_o^k^koEEEEo`000?l0003oA4A4onk^kP;ooooo00Kok^k^ofIVI_l0003o0000odA4
A?l0003/ooooo`00T_ooool01Ol0003oooooooooooo<c<co000000gooooo00?o0000ooooooooool0
1?ooool00omVIVKoQhN7ooooo`04ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
2oooool01OmgMgOoV9RHoooooonHV9SoMgMg01Gooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3ooooo
o`Kooooo002Aooooo`Co000000?o410@ojVYZOooool03?ooool2o`0000Gooooo00?oZJVYodA4A?oo
ool00oooool2o`0001Cooooo00?o0000ooooooooool02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
01?ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo1?l00002
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0ooooool6ooooo`00ooooool2oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0ooooool6ooooo`00ooooool2ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0ooooool6ooooo`00ooooool1ooooo`;o0000
0oooool2o`000?oooooo2?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooo
oooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?oo
ool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooo
ooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@oooo
o`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooo
oooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo
0000\
\>"],
  ImageRangeCache->{{{0, 525.688}, {324.5, 0}} -> {0, -6.34248*^6, 0, 53093}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0.309017 5.42214e-08 [
[.32684 .29652 -16.5 -12.5 ]
[.32684 .29652 16.5 0 ]
[.54329 .29652 -16.5 -12.5 ]
[.54329 .29652 16.5 0 ]
[.75974 .29652 -22.5 -12.5 ]
[.75974 .29652 22.5 0 ]
[.97619 .29652 -16.5 -12.5 ]
[.97619 .29652 16.5 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 64 6 ]
[.09789 .09213 -34.5 -6.25 ]
[.09789 .09213 0 6.25 ]
[.09789 .20057 -34.5 -6.25 ]
[.09789 .20057 0 6.25 ]
[.09789 .41746 -28.5 -6.25 ]
[.09789 .41746 0 6.25 ]
[.09789 .5259 -28.5 -6.25 ]
[.09789 .5259 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -62.8125 0 ]
[.5 .63053 62.8125 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 .30902 m
.32684 .31527 L
s
gsave
.32684 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 .30902 m
.54329 .31527 L
s
gsave
.54329 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 .30902 m
.75974 .31527 L
s
gsave
.75974 .29652 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 .30902 m
.15368 .31277 L
s
.19697 .30902 m
.19697 .31277 L
s
.24026 .30902 m
.24026 .31277 L
s
.28355 .30902 m
.28355 .31277 L
s
.37013 .30902 m
.37013 .31277 L
s
.41342 .30902 m
.41342 .31277 L
s
.45671 .30902 m
.45671 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.58658 .30902 m
.58658 .31277 L
s
.62987 .30902 m
.62987 .31277 L
s
.67316 .30902 m
.67316 .31277 L
s
.71645 .30902 m
.71645 .31277 L
s
.80303 .30902 m
.80303 .31277 L
s
.84632 .30902 m
.84632 .31277 L
s
.88961 .30902 m
.88961 .31277 L
s
.9329 .30902 m
.9329 .31277 L
s
.0671 .30902 m
.0671 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09213 m
.11664 .09213 L
s
gsave
.09789 .09213 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .20057 m
.11664 .20057 L
s
gsave
.09789 .20057 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .41746 m
.11664 .41746 L
s
gsave
.09789 .41746 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .5259 m
.11664 .5259 L
s
gsave
.09789 .5259 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.11039 .11924 m
.11414 .11924 L
s
.11039 .14635 m
.11414 .14635 L
s
.11039 .17346 m
.11414 .17346 L
s
.11039 .22768 m
.11414 .22768 L
s
.11039 .2548 m
.11414 .2548 L
s
.11039 .28191 m
.11414 .28191 L
s
.11039 .33613 m
.11414 .33613 L
s
.11039 .36324 m
.11414 .36324 L
s
.11039 .39035 m
.11414 .39035 L
s
.11039 .44457 m
.11414 .44457 L
s
.11039 .47168 m
.11414 .47168 L
s
.11039 .49879 m
.11414 .49879 L
s
.11039 .06502 m
.11414 .06502 L
s
.11039 .03791 m
.11414 .03791 L
s
.11039 .0108 m
.11414 .0108 L
s
.11039 .55301 m
.11414 .55301 L
s
.11039 .58012 m
.11414 .58012 L
s
.11039 .60723 m
.11414 .60723 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -123.812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.812 moveto
(@) show
81.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.812 moveto
(D) show
93.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
135.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
141.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
153.000 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
157.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
166.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
184.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30805 m
.02453 .30829 L
.02532 .30862 L
.02691 .30951 L
.03029 .31207 L
.03117 .31275 L
.032 .31333 L
.0328 .3138 L
.03315 .31397 L
.03354 .31412 L
.03373 .31418 L
.03392 .31424 L
.03409 .31428 L
.03427 .31431 L
.03438 .31432 L
.03448 .31433 L
.03457 .31434 L
.03468 .31434 L
.03478 .31434 L
.03487 .31434 L
.03495 .31434 L
.03505 .31433 L
.03515 .31432 L
.03524 .31431 L
.03546 .31426 L
.03567 .3142 L
.03589 .31412 L
.0363 .31392 L
.03667 .31368 L
.03747 .31298 L
.03821 .31208 L
.03987 .30921 L
.04137 .30576 L
.04302 .30136 L
.04471 .29689 L
.04544 .29516 L
.04625 .29356 L
.04663 .29295 L
.04703 .2924 L
.04723 .29218 L
.04742 .292 L
.04758 .29187 L
.04776 .29175 L
.04786 .2917 L
.04796 .29166 L
.04806 .29162 L
.04816 .2916 L
.04826 .29159 L
.04835 .29158 L
.04844 .29159 L
Mistroke
.04853 .2916 L
.04858 .29162 L
.04864 .29163 L
.04874 .29167 L
.04884 .29172 L
.04896 .29179 L
.04917 .29195 L
.04936 .29214 L
.04974 .29264 L
.05014 .29338 L
.05087 .29521 L
.05174 .29826 L
.05253 .30185 L
.05407 .31079 L
.05573 .32267 L
.05729 .33446 L
.05812 .34038 L
.05901 .34608 L
.05986 .35053 L
.06023 .35208 L
.06064 .35347 L
.06083 .354 L
.06103 .35446 L
.0612 .3548 L
.06138 .35508 L
.06149 .3552 L
.0616 .35529 L
.06169 .35535 L
.06179 .35538 L
.06189 .35539 L
.06197 .35538 L
.06207 .35535 L
.06217 .35528 L
.06226 .3552 L
.06237 .35507 L
.06259 .35471 L
.06279 .35425 L
.06298 .35372 L
.06341 .35213 L
.06387 .3498 L
.06471 .34389 L
.06548 .3366 L
.067 .31757 L
.06866 .29123 L
.07037 .26174 L
.07191 .23682 L
.07269 .22639 L
.07309 .22166 L
.07353 .21734 L
.0739 .2142 L
Mistroke
.07432 .21149 L
.0745 .21056 L
.07469 .20975 L
.07488 .20916 L
.07496 .20897 L
.07505 .20879 L
.07515 .20863 L
.07525 .20854 L
.07534 .2085 L
.07543 .20851 L
.07552 .20857 L
.07563 .20869 L
.07568 .20878 L
.07574 .20888 L
.07584 .20913 L
.07603 .20977 L
.07622 .21059 L
.07657 .21269 L
.07699 .21613 L
.07737 .22023 L
.07824 .23278 L
.07901 .24766 L
.07973 .26451 L
.08139 .31139 L
.0845 .4113 L
.08611 .45434 L
.08691 .47028 L
.08737 .47715 L
.0876 .47985 L
.0878 .48197 L
.08799 .48363 L
.08821 .48507 L
.08831 .48562 L
.08842 .48609 L
.08848 .48631 L
.08854 .48647 L
.08859 .4866 L
.08865 .48671 L
.08875 .48682 L
.08884 .48684 L
.0889 .48681 L
.08895 .48675 L
.08905 .48656 L
.08915 .48628 L
.08924 .48594 L
.08944 .48488 L
.08962 .4836 L
.08979 .48211 L
.09017 .47767 L
.09054 .47194 L
Mistroke
.09094 .46428 L
.09175 .44357 L
.09264 .41415 L
.09426 .34552 L
.09754 .18122 L
.09833 .14529 L
.09917 .11136 L
.0999 .08719 L
.1007 .06736 L
.1009 .06351 L
.10112 .05998 L
.10131 .05742 L
.10151 .05518 L
.10162 .05421 L
.10172 .05345 L
.10181 .05287 L
.10192 .05237 L
.10201 .05204 L
.10209 .05185 L
.10219 .05175 L
.10228 .05178 L
.10238 .05194 L
.10247 .0522 L
.10257 .05262 L
.10267 .05322 L
.10285 .05457 L
.10304 .05657 L
.1034 .06164 L
.10373 .06804 L
.10452 .08918 L
.10535 .12019 L
.10684 .19475 L
.1099 .39041 L
.1116 .49447 L
.11241 .53562 L
.11315 .567 L
.11392 .59176 L
.11433 .60126 L
.11454 .60512 L
.11476 .6085 L
.11496 .6108 L
.11514 .61236 L
.11522 .61292 L
.11532 .6134 L
.1154 .61371 L
.11549 .61389 L
.11559 .61395 L
.11569 .61385 L
.11578 .61362 L
.11587 .61323 L
Mistroke
.11598 .61262 L
.11609 .61179 L
.11628 .6098 L
.11649 .60706 L
.11668 .60382 L
.11705 .59614 L
.11744 .58553 L
.11786 .57137 L
.11933 .50322 L
.12092 .40419 L
.12261 .28547 L
.12419 .17782 L
.12564 .09555 L
.1264 .06217 L
.1272 .03572 L
.12762 .02577 L
.128 .01895 L
.12822 .01611 L
.12842 .01422 L
.12854 .01346 L
.12859 .01314 L
.12866 .01286 L
.12871 .01267 L
.12877 .01252 L
.12888 .01239 L
.12898 .01243 L
.12908 .01263 L
.12918 .01303 L
.12924 .0133 L
.12929 .01365 L
.1295 .01529 L
.12969 .01745 L
.13005 .02301 L
.13044 .03122 L
.13086 .04278 L
.13131 .0577 L
.13212 .09074 L
.13517 .26581 L
.13687 .37143 L
.13842 .45419 L
.1392 .48722 L
.1396 .50195 L
.14003 .51537 L
.14041 .52518 L
.14082 .53386 L
.14101 .53694 L
.1412 .53977 L
.14139 .54198 L
.14155 .54358 L
.14165 .54434 L
Mistroke
.14176 .54502 L
.14187 .54557 L
.14198 .54594 L
.14207 .54616 L
.14218 .54624 L
.14227 .5462 L
.14237 .54603 L
.14243 .54587 L
.14248 .54568 L
.14259 .5452 L
.1427 .54453 L
.14282 .54361 L
.14305 .54147 L
.14325 .53895 L
.14362 .5331 L
.14403 .52479 L
.14486 .50252 L
.14642 .44505 L
.14809 .36938 L
.14967 .29635 L
.15139 .22666 L
.15219 .20092 L
.15304 .1791 L
.15346 .1708 L
.15385 .1644 L
.1542 .15984 L
.15458 .15618 L
.15476 .15486 L
.15487 .15427 L
.15497 .1538 L
.15506 .15345 L
.15516 .15315 L
.15525 .15296 L
.15534 .15285 L
.15539 .15281 L
.15544 .15279 L
.15555 .15284 L
.15565 .15298 L
.15574 .15319 L
.15584 .15349 L
.15595 .15392 L
.15617 .1551 L
.15639 .15668 L
.15659 .15847 L
.15705 .16361 L
.15786 .17652 L
.1594 .21102 L
.16106 .25738 L
.16262 .30199 L
.16434 .34511 L
Mistroke
.16513 .36104 L
.16597 .37488 L
.16638 .38025 L
.16677 .38454 L
.16714 .38791 L
.1675 .39038 L
.16769 .39146 L
.1679 .39239 L
.16809 .39304 L
.16827 .39347 L
.16837 .39364 L
.16846 .39376 L
.16856 .39384 L
.16861 .39386 L
.16867 .39387 L
.16877 .39384 L
.16883 .3938 L
.16888 .39375 L
.16898 .39363 L
.16909 .39344 L
.16926 .39301 L
.16945 .3924 L
.16979 .39089 L
.17019 .38846 L
.17056 .38567 L
.17208 .36959 L
.17374 .34646 L
.17544 .32129 L
.17699 .3007 L
.17777 .29206 L
.17861 .28423 L
.1794 .27847 L
.18013 .27461 L
.1805 .27317 L
.18071 .27254 L
.1809 .27203 L
.18109 .27165 L
.18128 .27134 L
.18137 .27123 L
.18146 .27113 L
.18155 .27106 L
.18163 .27101 L
.18174 .27096 L
.18179 .27095 L
.18184 .27095 L
.18195 .27095 L
.18204 .27098 L
.1821 .27101 L
.18215 .27104 L
.18226 .27112 L
Mistroke
.18236 .27123 L
.18248 .27138 L
.18269 .2717 L
.1829 .27213 L
.18329 .27313 L
.18404 .27581 L
.18485 .2796 L
.18632 .28809 L
.1879 .29812 L
.18962 .30835 L
.19042 .3124 L
.19127 .31606 L
.19207 .31882 L
.19281 .32076 L
.19321 .32156 L
.19363 .32223 L
.19405 .32271 L
.1943 .32291 L
.1944 .32297 L
.19452 .32303 L
.19463 .32308 L
.19473 .32311 L
.19483 .32313 L
.19493 .32315 L
.19503 .32315 L
.19513 .32314 L
.19521 .32313 L
.1953 .32312 L
.1954 .32309 L
.19551 .32304 L
.19574 .32293 L
.19595 .32279 L
.19614 .32263 L
.19698 .32164 L
.19778 .32034 L
.19927 .31728 L
.20235 .31046 L
.20394 .30768 L
.20475 .30661 L
.2052 .30611 L
.20563 .30571 L
.20602 .3054 L
.20645 .30513 L
.20683 .30494 L
.20719 .30481 L
.20741 .30476 L
.20752 .30473 L
.20762 .30471 L
.2077 .3047 L
.2078 .30469 L
Mistroke
.2079 .30468 L
.208 .30467 L
.20806 .30467 L
.20811 .30467 L
.20822 .30467 L
.20827 .30467 L
.20833 .30467 L
.20839 .30468 L
.20845 .30468 L
.20855 .30469 L
.20865 .3047 L
.20887 .30474 L
.20906 .30478 L
.20924 .30483 L
.20965 .30496 L
.21049 .30532 L
.21197 .3062 L
.2151 .30828 L
.21593 .30875 L
.21682 .30918 L
.21759 .3095 L
.21843 .30976 L
.21883 .30986 L
.21926 .30995 L
.21966 .31002 L
.22003 .31006 L
.22025 .31008 L
.22044 .3101 L
.22066 .31011 L
.22079 .31012 L
.2209 .31012 L
.221 .31012 L
.2211 .31013 L
.22115 .31013 L
.22121 .31013 L
.22127 .31013 L
.22132 .31013 L
.22142 .31013 L
.22151 .31012 L
.22162 .31012 L
.22172 .31012 L
.22191 .31011 L
.22209 .3101 L
.2225 .31007 L
.22289 .31004 L
.22332 .30999 L
.2248 .30978 L
.22638 .30951 L
.22811 .30923 L
.2289 .30912 L
Mistroke
.22976 .30902 L
.23055 .30894 L
.23129 .30888 L
.23211 .30883 L
.23255 .30881 L
.23277 .30881 L
.23301 .3088 L
.23321 .30879 L
.2334 .30879 L
.2336 .30879 L
.23378 .30878 L
.23388 .30878 L
.23399 .30878 L
.23409 .30878 L
.23415 .30878 L
.23421 .30878 L
.23432 .30878 L
.23441 .30878 L
.23451 .30878 L
.23457 .30878 L
.23462 .30878 L
.23473 .30878 L
.23483 .30878 L
.23505 .30879 L
.23524 .30879 L
.23545 .30879 L
.2362 .30881 L
.237 .30883 L
.23788 .30886 L
.23957 .30892 L
.24111 .30897 L
.24188 .30899 L
.24271 .30901 L
.24349 .30903 L
.24423 .30904 L
.24462 .30904 L
.24505 .30905 L
.24541 .30905 L
.24581 .30905 L
.24623 .30906 L
.24647 .30906 L
.24668 .30906 L
.24679 .30906 L
.24689 .30906 L
.24698 .30906 L
.24707 .30906 L
.24718 .30906 L
.24727 .30906 L
.24738 .30906 L
.24743 .30906 L
Mistroke
.24749 .30906 L
.24758 .30906 L
.24768 .30906 L
.24778 .30906 L
.24787 .30906 L
.24808 .30906 L
.24828 .30906 L
.24868 .30906 L
.24911 .30905 L
.2506 .30905 L
.25216 .30904 L
.25388 .30903 L
.25467 .30902 L
.25552 .30902 L
.25631 .30902 L
.25705 .30901 L
.25786 .30901 L
.25829 .30901 L
.25875 .30901 L
.25896 .30901 L
.25918 .30901 L
.25938 .30901 L
.25959 .30901 L
.25978 .30901 L
.25988 .30901 L
.25999 .30901 L
.26009 .30901 L
.26018 .30901 L
.26027 .30901 L
.26036 .30901 L
.26045 .30901 L
.26055 .30901 L
.26064 .30901 L
.26073 .30901 L
.26083 .30901 L
.26094 .30901 L
.26114 .30901 L
.26134 .30901 L
.26157 .30901 L
.26196 .30901 L
.26344 .30901 L
.26504 .30901 L
.26678 .30902 L
.26759 .30902 L
.26845 .30902 L
.26926 .30902 L
.26999 .30902 L
.27075 .30902 L
.27117 .30902 L
.27157 .30902 L
Mistroke
.27193 .30902 L
.27227 .30902 L
.27245 .30902 L
.27264 .30902 L
.27274 .30902 L
.27285 .30902 L
.27295 .30902 L
.27304 .30902 L
.27314 .30902 L
.27323 .30902 L
.27333 .30902 L
.27339 .30902 L
.27344 .30902 L
.27352 .30902 L
.27362 .30902 L
.27372 .30902 L
.27381 .30902 L
.27392 .30902 L
.27402 .30902 L
.27421 .30902 L
.27465 .30902 L
.27507 .30902 L
.27546 .30902 L
.27634 .30902 L
.27948 .30902 L
.28031 .30902 L
.2812 .30902 L
.28198 .30902 L
.28282 .30902 L
.28323 .30902 L
.28365 .30902 L
.28402 .30902 L
.28443 .30902 L
.28488 .30902 L
.28509 .30902 L
.28531 .30902 L
.28551 .30902 L
.28573 .30902 L
.28583 .30902 L
.28593 .30902 L
.28603 .30902 L
.28612 .30902 L
.28622 .30902 L
.28631 .30902 L
.28641 .30902 L
.28647 .30902 L
.28652 .30902 L
.2866 .30902 L
.2867 .30902 L
.2868 .30902 L
Mistroke
.28689 .30902 L
.2871 .30902 L
.28729 .30902 L
.28773 .30902 L
.2886 .30902 L
.28942 .30902 L
.2925 .30902 L
.29408 .30902 L
.29488 .30902 L
.29577 .30902 L
.29616 .30902 L
.29657 .30902 L
.29693 .30902 L
.29732 .30902 L
.29773 .30902 L
.29811 .30902 L
.29835 .30902 L
.29857 .30902 L
.29877 .30902 L
.29888 .30902 L
.29899 .30902 L
.29909 .30902 L
.29918 .30902 L
.29927 .30902 L
.29936 .30902 L
.29946 .30902 L
.29952 .30902 L
.29957 .30902 L
.29967 .30902 L
.29977 .30902 L
.29995 .30902 L
.30011 .30902 L
.30049 .30902 L
.30088 .30902 L
.3013 .30902 L
.30215 .30902 L
.30385 .30902 L
.30539 .30902 L
.30616 .30902 L
.307 .30902 L
.30778 .30902 L
.30852 .30902 L
.30927 .30902 L
.30967 .30902 L
.3101 .30902 L
.31053 .30902 L
.31077 .30902 L
.31098 .30902 L
.31119 .30902 L
.31137 .30902 L
Mistroke
.31157 .30902 L
.31168 .30902 L
.31179 .30902 L
.31189 .30902 L
.31198 .30902 L
.31207 .30902 L
.31218 .30902 L
.31228 .30902 L
.31234 .30902 L
.31239 .30902 L
.31249 .30902 L
.31259 .30902 L
.31269 .30902 L
.31279 .30902 L
.31298 .30902 L
.31333 .30902 L
.31375 .30902 L
.3142 .30902 L
.315 .30902 L
.31805 .30902 L
.31962 .30902 L
.3205 .30902 L
.3213 .30902 L
.32169 .30902 L
.3221 .30902 L
.32284 .30902 L
.32325 .30902 L
.32363 .30902 L
.32405 .30902 L
.32429 .30902 L
.3245 .30902 L
.32461 .30902 L
.3247 .30902 L
.32479 .30902 L
.32489 .30902 L
.32499 .30902 L
.32508 .30902 L
.32518 .30902 L
.32524 .30902 L
.32529 .30902 L
.32539 .30902 L
.32548 .30902 L
.32556 .30902 L
.32565 .30902 L
.32584 .30902 L
.32603 .30902 L
.32641 .30902 L
.32683 .30902 L
.32769 .30902 L
.32937 .30902 L
Mistroke
.33091 .30902 L
.33242 .30902 L
.33318 .30902 L
.33402 .30902 L
.33444 .30902 L
.33484 .30902 L
.33559 .30902 L
.33601 .30902 L
.33639 .30902 L
.33682 .30902 L
.33703 .30902 L
.33727 .30902 L
.33747 .30902 L
.33758 .30902 L
.33769 .30902 L
.33779 .30902 L
.33788 .30902 L
.33798 .30902 L
.33808 .30902 L
.33817 .30902 L
.33827 .30902 L
.33835 .30902 L
.33844 .30902 L
.33864 .30902 L
.33883 .30902 L
.33925 .30902 L
.33964 .30902 L
.34051 .30902 L
.34217 .30902 L
.34371 .30902 L
.3452 .30902 L
.34595 .30902 L
.34678 .30902 L
.34718 .30902 L
.34759 .30902 L
.34834 .30902 L
.34875 .30902 L
.34914 .30902 L
.34956 .30902 L
.3498 .30902 L
.35001 .30902 L
.3502 .30902 L
.3504 .30902 L
.35051 .30902 L
.35056 .30902 L
.35062 .30902 L
.35072 .30902 L
.35081 .30902 L
.3509 .30902 L
.351 .30902 L
Mistroke
.35109 .30902 L
.35117 .30902 L
.35126 .30902 L
.35137 .30902 L
.35155 .30902 L
.35176 .30902 L
.35198 .30902 L
.35242 .30902 L
.35322 .30902 L
.35493 .30902 L
.35647 .30902 L
.35725 .30902 L
.35808 .30902 L
.35887 .30902 L
.3596 .30902 L
.35998 .30902 L
.36038 .30902 L
.36111 .30902 L
.36155 .30902 L
.36197 .30902 L
.36235 .30902 L
.36256 .30902 L
.36276 .30902 L
.36297 .30902 L
.36317 .30902 L
.36327 .30902 L
.36338 .30902 L
.36344 .30902 L
.3635 .30902 L
.36356 .30902 L
.36361 .30902 L
.36371 .30902 L
.36381 .30902 L
.36391 .30902 L
.36396 .30902 L
.36402 .30902 L
.36412 .30902 L
.36422 .30902 L
.36441 .30902 L
.36479 .30902 L
.36519 .30902 L
.3659 .30902 L
.36896 .30902 L
.37053 .30902 L
.37141 .30902 L
.37221 .30902 L
.3726 .30902 L
.37302 .30902 L
.37375 .30902 L
.37416 .30902 L
Mistroke
.37455 .30902 L
.37497 .30902 L
.37521 .30902 L
.37542 .30902 L
.37562 .30902 L
.37581 .30902 L
.37591 .30902 L
.37602 .30902 L
.37611 .30902 L
.37622 .30902 L
.37631 .30902 L
.3764 .30902 L
.3765 .30902 L
.3766 .30902 L
.37669 .30902 L
.37678 .30902 L
.37686 .30902 L
.37695 .30902 L
.37715 .30902 L
.37737 .30902 L
.37781 .30902 L
.37861 .30902 L
.3803 .30902 L
.38184 .30902 L
.38336 .30902 L
.38412 .30902 L
.38495 .30902 L
.38538 .30902 L
.38578 .30902 L
.38653 .30902 L
.38695 .30902 L
.38734 .30902 L
.38776 .30902 L
.38798 .30902 L
.38821 .30902 L
.38841 .30902 L
.38852 .30902 L
.38863 .30902 L
.38873 .30902 L
.38884 .30902 L
.38894 .30902 L
.38903 .30902 L
.38912 .30902 L
.38922 .30902 L
.3893 .30902 L
.38939 .30902 L
.38949 .30902 L
.38959 .30902 L
.38969 .30902 L
.38978 .30902 L
Mistroke
.38999 .30902 L
.39019 .30902 L
.39064 .30902 L
.39145 .30902 L
.39309 .30902 L
.39461 .30902 L
.39536 .30902 L
.39608 .30902 L
.3969 .30902 L
.39765 .30902 L
.39842 .30902 L
.39885 .30902 L
.39924 .30902 L
.39961 .30902 L
.4 .30902 L
.40037 .30902 L
.40072 .30902 L
.40091 .30902 L
.40109 .30902 L
.4013 .30902 L
.4014 .30902 L
.4015 .30902 L
.40159 .30902 L
.40168 .30902 L
.40177 .30902 L
.40185 .30902 L
.40194 .30902 L
.40203 .30902 L
.40213 .30902 L
.40223 .30902 L
.40233 .30902 L
.40243 .30902 L
.40264 .30902 L
.40284 .30902 L
.40302 .30902 L
.40389 .30902 L
.40536 .30902 L
.40698 .30902 L
.40775 .30902 L
.40857 .30902 L
.40945 .30902 L
.40987 .30902 L
.41026 .30902 L
.41108 .30902 L
.4115 .30902 L
.41196 .30902 L
.4124 .30902 L
.41281 .30902 L
.41318 .30902 L
.41338 .30902 L
Mistroke
.41358 .30902 L
.41377 .30902 L
.41395 .30902 L
.41406 .30902 L
.41417 .30902 L
.41426 .30902 L
.41436 .30902 L
.41445 .30902 L
.41454 .30902 L
.41464 .30902 L
.41474 .30902 L
.41483 .30902 L
.41492 .30902 L
.415 .30902 L
.41509 .30902 L
.41531 .30902 L
.41551 .30902 L
.41595 .30902 L
.41675 .30902 L
.41842 .30902 L
.41916 .30902 L
.41996 .30902 L
.42069 .30902 L
.42147 .30902 L
.42229 .30902 L
.42306 .30902 L
.42348 .30902 L
.42387 .30902 L
.42429 .30902 L
.42476 .30902 L
.42516 .30902 L
.42554 .30902 L
.42594 .30902 L
.42617 .30902 L
.42638 .30902 L
.42657 .30902 L
.42676 .30902 L
.42686 .30902 L
.42696 .30902 L
.42707 .30902 L
.42716 .30902 L
.42725 .30902 L
.42733 .30902 L
.42742 .30902 L
.42752 .30902 L
.42762 .30902 L
.42771 .30902 L
.4278 .30902 L
.42789 .30902 L
.42811 .30902 L
Mistroke
.42831 .30902 L
.42875 .30902 L
.42955 .30902 L
.43123 .30902 L
.43197 .30902 L
.43277 .30902 L
.4335 .30902 L
.43428 .30902 L
.4351 .30902 L
.43587 .30902 L
.43629 .30902 L
.43669 .30902 L
.43712 .30902 L
.43758 .30902 L
.43797 .30902 L
.43834 .30902 L
.43875 .30902 L
.43898 .30902 L
.43919 .30902 L
.43929 .30902 L
.43939 .30902 L
.43957 .30902 L
.43967 .30902 L
.43977 .30902 L
.43987 .30902 L
.43992 .30902 L
.43998 .30902 L
.44008 .30902 L
.44016 .30902 L
.44026 .30902 L
.44036 .30902 L
.44045 .30902 L
.44053 .30902 L
.44071 .30902 L
.44114 .30902 L
.44152 .30902 L
.44237 .30902 L
.44405 .30902 L
.44479 .30902 L
.4456 .30902 L
.44638 .30902 L
.44711 .30902 L
.44788 .30902 L
.44831 .30902 L
.4487 .30902 L
.44909 .30902 L
.4495 .30902 L
.44985 .30902 L
.45024 .30902 L
.45064 .30902 L
Mistroke
.45103 .30902 L
.45126 .30902 L
.45149 .30902 L
.45169 .30902 L
.4519 .30902 L
.45211 .30902 L
.45222 .30902 L
.45233 .30902 L
.45242 .30902 L
.45253 .30902 L
.45258 .30902 L
.45263 .30902 L
.45273 .30902 L
.45283 .30902 L
.45293 .30902 L
.45303 .30902 L
.45312 .30902 L
.45348 .30902 L
.45387 .30902 L
.4543 .30902 L
.45517 .30902 L
.45685 .30902 L
.45759 .30902 L
.45839 .30902 L
.45918 .30902 L
.45991 .30902 L
.46068 .30902 L
.46111 .30902 L
.4615 .30902 L
.46189 .30902 L
.4623 .30902 L
.46265 .30902 L
.46304 .30902 L
.46345 .30902 L
.46369 .30902 L
.4639 .30902 L
.4641 .30902 L
.46431 .30902 L
.46452 .30902 L
.46471 .30902 L
.46481 .30902 L
.46492 .30902 L
.46501 .30902 L
.46512 .30902 L
.46517 .30902 L
.46523 .30902 L
.46529 .30902 L
.46534 .30902 L
.46545 .30902 L
.4655 .30902 L
Mistroke
.46556 .30902 L
.46574 .30902 L
.46595 .30902 L
.46636 .30902 L
.46785 .30902 L
.46867 .30902 L
.46954 .30902 L
.47034 .30902 L
.47108 .30902 L
.4718 .30902 L
.47257 .30902 L
.47301 .30902 L
.47342 .30902 L
.47419 .30902 L
.47456 .30902 L
.47497 .30902 L
.4754 .30902 L
.4758 .30902 L
.47618 .30902 L
.47652 .30902 L
.47671 .30902 L
.47691 .30902 L
.4771 .30902 L
.47728 .30902 L
.47738 .30902 L
.47748 .30902 L
.47756 .30902 L
.47765 .30902 L
.47776 .30902 L
.47781 .30902 L
.47786 .30902 L
.47796 .30902 L
.47806 .30902 L
.47814 .30902 L
.47824 .30902 L
.4784 .30902 L
.47878 .30902 L
.47957 .30902 L
.48043 .30902 L
.4813 .30902 L
.48212 .30902 L
.48292 .30902 L
.48367 .30902 L
.48439 .30902 L
.48516 .30902 L
.4856 .30902 L
.48601 .30902 L
.48678 .30902 L
.48716 .30902 L
.48757 .30902 L
Mistroke
.48799 .30902 L
.48839 .30902 L
.48859 .30902 L
.48877 .30902 L
.48911 .30902 L
.4893 .30902 L
.48948 .30902 L
.48967 .30902 L
.48977 .30902 L
.48988 .30902 L
.48998 .30902 L
.49007 .30902 L
.49017 .30902 L
.49022 .30902 L
.49027 .30902 L
.49038 .30902 L
.49043 .30902 L
.49049 .30902 L
.49058 .30902 L
.49069 .30902 L
.49087 .30902 L
.49104 .30902 L
.49143 .30902 L
.49311 .30902 L
.4946 .30902 L
.49544 .30902 L
.49622 .30902 L
.49705 .30902 L
.49751 .30902 L
.49792 .30902 L
.49832 .30902 L
.49876 .30902 L
.49916 .30902 L
.49954 .30902 L
.49991 .30902 L
.5003 .30902 L
.50053 .30902 L
.50074 .30902 L
.50114 .30902 L
.50135 .30902 L
.50156 .30902 L
.50175 .30902 L
.50195 .30902 L
.50217 .30902 L
.5023 .30902 L
.50241 .30902 L
.50251 .30902 L
.50257 .30902 L
.50263 .30902 L
.50273 .30902 L
Mistroke
.50278 .30902 L
.50284 .30902 L
.50293 .30902 L
.50302 .30902 L
.50312 .30902 L
.50323 .30902 L
.50344 .30902 L
.50364 .30902 L
.50438 .30902 L
.50605 .30902 L
.50679 .30902 L
.50758 .30902 L
.50845 .30902 L
.50925 .30902 L
.51 .30902 L
.51042 .30902 L
.51081 .30902 L
.51152 .30902 L
.51188 .30902 L
.51228 .30902 L
.5127 .30902 L
.5131 .30902 L
.51346 .30902 L
.51385 .30902 L
.51405 .30902 L
.51427 .30902 L
.51439 .30902 L
.51451 .30902 L
.51461 .30902 L
.51472 .30902 L
.51484 .30902 L
.51494 .30902 L
.51504 .30902 L
.51515 .30902 L
.51525 .30902 L
.51535 .30902 L
.51544 .30902 L
.51553 .30902 L
.51563 .30902 L
.51572 .30902 L
.51593 .30902 L
.5163 .30902 L
.51713 .30902 L
.51883 .30902 L
.51957 .30902 L
.52036 .30902 L
.52123 .30902 L
.52164 .30902 L
.52203 .30902 L
.52278 .30902 L
Mistroke
.52318 .30902 L
.52359 .30902 L
.52393 .30902 L
.52429 .30902 L
.52469 .30902 L
.52506 .30902 L
.52549 .30902 L
.52588 .30902 L
.52609 .30902 L
.52632 .30902 L
.52655 .30902 L
.52678 .30902 L
.52688 .30902 L
.52698 .30902 L
.52708 .30902 L
.52718 .30902 L
.52728 .30902 L
.52738 .30902 L
.52747 .30902 L
.52756 .30902 L
.52766 .30902 L
.52771 .30902 L
.52777 .30902 L
.52787 .30902 L
.52796 .30902 L
.52802 .30902 L
.52807 .30902 L
.52817 .30902 L
.52839 .30902 L
.52876 .30902 L
.52917 .30902 L
.53 .30902 L
.53148 .30902 L
.53229 .30902 L
.53304 .30902 L
.53345 .30902 L
.5339 .30902 L
.53471 .30902 L
.53514 .30902 L
.53554 .30902 L
.53591 .30902 L
.53629 .30902 L
.53671 .30902 L
.5371 .30902 L
.53752 .30902 L
.53774 .30902 L
.53797 .30902 L
.53819 .30902 L
.5384 .30902 L
.53859 .30902 L
Mistroke
.53879 .30902 L
.53897 .30902 L
.53916 .30902 L
.53935 .30902 L
.53954 .30902 L
.53965 .30902 L
.53974 .30902 L
.53985 .30902 L
.53991 .30902 L
.53997 .30902 L
.54003 .30902 L
.54008 .30902 L
.54014 .30902 L
.5402 .30902 L
.5403 .30902 L
.54036 .30902 L
.54042 .30902 L
.54052 .30902 L
.54062 .30902 L
.5408 .30902 L
.54122 .30902 L
.54283 .30902 L
.54429 .30902 L
.54511 .30902 L
.54587 .30902 L
.54668 .30902 L
.54714 .30902 L
.54756 .30902 L
.54794 .30902 L
.54834 .30902 L
.54869 .30902 L
.54907 .30902 L
.54952 .30902 L
.54994 .30902 L
.55035 .30902 L
.55055 .30902 L
.55073 .30902 L
.5511 .30902 L
.5513 .30902 L
.55151 .30902 L
.55169 .30902 L
.55185 .30902 L
.55204 .30902 L
.55214 .30902 L
.55223 .30902 L
.55234 .30902 L
.55239 .30902 L
.55245 .30902 L
.55255 .30902 L
.55264 .30902 L
Mistroke
.5527 .30902 L
.55275 .30902 L
.55286 .30902 L
.55297 .30902 L
.55309 .30902 L
.5535 .30902 L
.55389 .30902 L
.55551 .30902 L
.55631 .30902 L
.55704 .30902 L
.55775 .30902 L
.55849 .30902 L
.55924 .30902 L
.55967 .30902 L
.56007 .30902 L
.56047 .30902 L
.56091 .30902 L
.56132 .30902 L
.56171 .30902 L
.56205 .30902 L
.56243 .30902 L
.56283 .30902 L
.5632 .30902 L
.5634 .30902 L
.5636 .30902 L
.56381 .30902 L
.56392 .30902 L
.56403 .30902 L
.56414 .30902 L
.56425 .30902 L
.56434 .30902 L
.56445 .30902 L
.56454 .30902 L
.56463 .30902 L
.56472 .30902 L
.56482 .30902 L
.56492 .30902 L
.56502 .30902 L
.56512 .30902 L
.56517 .30902 L
.56522 .30902 L
.56542 .30902 L
.5656 .30902 L
.56631 .30902 L
.5678 .30902 L
.56864 .30902 L
.56942 .30902 L
.5702 .30902 L
.57103 .30902 L
.57149 .30902 L
Mistroke
.57192 .30902 L
.5723 .30902 L
.57272 .30902 L
.57313 .30902 L
.57351 .30902 L
.5739 .30902 L
.57433 .30902 L
.57473 .30902 L
.57511 .30902 L
.57544 .30902 L
.57564 .30902 L
.57581 .30902 L
.57601 .30902 L
.57622 .30902 L
.57633 .30902 L
.57645 .30902 L
.57656 .30902 L
.57666 .30902 L
.57676 .30902 L
.57687 .30902 L
.57692 .30902 L
.57698 .30902 L
.57708 .30902 L
.57717 .30902 L
.57727 .30902 L
.57737 .30902 L
.57747 .30902 L
.57756 .30902 L
.57766 .30902 L
.57784 .30902 L
.57819 .30902 L
.57896 .30902 L
.57984 .30902 L
.58067 .30902 L
.58142 .30902 L
.58222 .30902 L
.58302 .30902 L
.58342 .30902 L
.58386 .30902 L
.58423 .30902 L
.58464 .30902 L
.58499 .30902 L
.58536 .30902 L
.58579 .30902 L
.58618 .30902 L
.5866 .30902 L
.58684 .30902 L
.58707 .30902 L
.58747 .30902 L
.58768 .30902 L
Mistroke
.5879 .30902 L
.58808 .30902 L
.58827 .30902 L
.58849 .30902 L
.58868 .30902 L
.58889 .30902 L
.58899 .30902 L
.58911 .30902 L
.58921 .30902 L
.58931 .30902 L
.58941 .30902 L
.5895 .30902 L
.58956 .30902 L
.58962 .30902 L
.58972 .30902 L
.58979 .30902 L
.58985 .30902 L
.58996 .30902 L
.59017 .30902 L
.5904 .30902 L
.59201 .30902 L
.59284 .30902 L
.59362 .30902 L
.59442 .30902 L
.59485 .30902 L
.59531 .30902 L
.59613 .30902 L
.59659 .30902 L
.59702 .30902 L
.59739 .30902 L
.5978 .30902 L
.59823 .30902 L
.59863 .30902 L
.59901 .30902 L
.59942 .30902 L
.59963 .30902 L
.59985 .30902 L
.60025 .30902 L
.60045 .30902 L
.60065 .30902 L
.60085 .30902 L
.60103 .30902 L
.6012 .30902 L
.60129 .30902 L
.60138 .30902 L
.60147 .30902 L
.60155 .30902 L
.60165 .30902 L
.60174 .30902 L
.60183 .30902 L
Mistroke
.60193 .30902 L
.60202 .30902 L
.60211 .30902 L
.6022 .30902 L
.60231 .30902 L
.60251 .30902 L
.60334 .30902 L
.60481 .30902 L
.60564 .30902 L
.60639 .30902 L
.6068 .30902 L
.60725 .30902 L
.60767 .30902 L
.60807 .30902 L
.60882 .30902 L
.60923 .30902 L
.60966 .30902 L
.61011 .30902 L
.61054 .30902 L
.61093 .30902 L
.61135 .30902 L
.61155 .30902 L
.61177 .30902 L
.61197 .30902 L
.61218 .30902 L
.61236 .30902 L
.61257 .30902 L
.61275 .30902 L
.61293 .30902 L
.61315 .30902 L
.61335 .30902 L
.61346 .30902 L
.61356 .30902 L
.61368 .30902 L
.61374 .30902 L
.6138 .30902 L
.6139 .30902 L
.614 .30902 L
.61411 .30902 L
.61416 .30902 L
.61422 .30902 L
.61432 .30902 L
.61442 .30902 L
.61461 .30902 L
.61504 .30902 L
.61543 .30902 L
.61633 .30902 L
.61716 .30902 L
.61794 .30902 L
.61867 .30902 L
Mistroke
.61945 .30902 L
.61989 .30902 L
.62032 .30902 L
.62073 .30902 L
.62111 .30902 L
.62148 .30902 L
.62188 .30902 L
.6223 .30902 L
.6227 .30902 L
.62308 .30902 L
.62347 .30902 L
.62381 .30902 L
.62418 .30902 L
.62438 .30902 L
.6246 .30902 L
.62479 .30902 L
.625 .30902 L
.62518 .30902 L
.62539 .30902 L
.62548 .30902 L
.62557 .30902 L
.62566 .30902 L
.62575 .30902 L
.62586 .30902 L
.62596 .30902 L
.62603 .30902 L
.62609 .30902 L
.62614 .30902 L
.6262 .30902 L
.62625 .30902 L
.62631 .30902 L
.62636 .30902 L
.62642 .30902 L
.62652 .30902 L
.62663 .30902 L
.62684 .30902 L
.62705 .30902 L
.62743 .30902 L
.62889 .30902 L
.62972 .30902 L
.6305 .30902 L
.63127 .30902 L
.6317 .30902 L
.63209 .30902 L
.63251 .30902 L
.63291 .30902 L
.63332 .30902 L
.63378 .30902 L
.63418 .30902 L
.63462 .30902 L
Mistroke
.63503 .30902 L
.63542 .30902 L
.63576 .30902 L
.63614 .30902 L
.63633 .30902 L
.63654 .30902 L
.63691 .30902 L
.63711 .30902 L
.63733 .30902 L
.63753 .30902 L
.63772 .30902 L
.63783 .30902 L
.63794 .30902 L
.63805 .30902 L
.63811 .30902 L
.63818 .30902 L
.63823 .30902 L
.63828 .30902 L
.63834 .30902 L
.6384 .30902 L
.6385 .30902 L
.63855 .30902 L
.63861 .30902 L
.6387 .30902 L
.6388 .30902 L
.63898 .30902 L
.63939 .30902 L
.64022 .30902 L
.64098 .30902 L
.6418 .30902 L
.64227 .30902 L
.64269 .30902 L
.64313 .30902 L
.64352 .30902 L
.64431 .30902 L
.64472 .30902 L
.64516 .30902 L
.64554 .30902 L
.6459 .30902 L
.64629 .30902 L
.64671 .30902 L
.64713 .30902 L
.64752 .30902 L
.64795 .30902 L
.64817 .30902 L
.64841 .30902 L
.64881 .30902 L
.64903 .30902 L
.64924 .30902 L
.64942 .30902 L
Mistroke
.64962 .30902 L
.64972 .30902 L
.64983 .30902 L
.65002 .30902 L
.65012 .30902 L
.65023 .30902 L
.65028 .30902 L
.65034 .30902 L
.65045 .30902 L
.65056 .30902 L
.65066 .30902 L
.65075 .30902 L
.65084 .30902 L
.6509 .30902 L
.65096 .30902 L
.65107 .30902 L
.6513 .30902 L
.65173 .30902 L
.65252 .30902 L
.65335 .30902 L
.65412 .30902 L
.65453 .30902 L
.65496 .30902 L
.65536 .30902 L
.65573 .30902 L
.65644 .30902 L
.65683 .30902 L
.65724 .30902 L
.65759 .30902 L
.65798 .30902 L
.65839 .30902 L
.65884 .30902 L
.65926 .30902 L
.65964 .30902 L
.66002 .30902 L
.66023 .30902 L
.66043 .30902 L
.66061 .30902 L
.66081 .30902 L
.66116 .30902 L
.66136 .30902 L
.66158 .30902 L
.66169 .30902 L
.66181 .30902 L
.66191 .30902 L
.66203 .30902 L
.66214 .30902 L
.66224 .30902 L
.66234 .30902 L
.66244 .30902 L
Mistroke
.66255 .30902 L
.66264 .30902 L
.66273 .30902 L
.66282 .30902 L
.66292 .30902 L
.66301 .30902 L
.66312 .30902 L
.66322 .30902 L
.66359 .30902 L
.66443 .30902 L
.66525 .30902 L
.66612 .30902 L
.66688 .30902 L
.66731 .30902 L
.66772 .30902 L
.66843 .30902 L
.66883 .30902 L
.6692 .30902 L
.66958 .30902 L
.66999 .30902 L
.67037 .30902 L
.67072 .30902 L
.67113 .30902 L
.67135 .30902 L
.67158 .30902 L
.67178 .30902 L
.672 .30902 L
.67238 .30902 L
.67259 .30902 L
.6728 .30902 L
.673 .30902 L
.6732 .30902 L
.67339 .30902 L
.67359 .30902 L
.67378 .30902 L
.67395 .30902 L
.67415 .30902 L
.67426 .30902 L
.67437 .30902 L
.67447 .30902 L
.67457 .30902 L
.67467 .30902 L
.67476 .30902 L
.67481 .30902 L
.67487 .30902 L
.67497 .30902 L
.67503 .30902 L
.67508 .30902 L
.6752 .30902 L
.67541 .30902 L
Mistroke
.67563 .30902 L
.67721 .30902 L
.67805 .30902 L
.67851 .30902 L
.67894 .30902 L
.67935 .30902 L
.67981 .30902 L
.68059 .30902 L
.68098 .30902 L
.68139 .30902 L
.68174 .30902 L
.68213 .30902 L
.68255 .30902 L
.68295 .30902 L
.6833 .30902 L
.68369 .30902 L
.68412 .30902 L
.68433 .30902 L
.68457 .30902 L
.68477 .30902 L
.68498 .30902 L
.68519 .30902 L
.68537 .30902 L
.68557 .30902 L
.68577 .30902 L
.68596 .30902 L
.68614 .30902 L
.68624 .30902 L
.68635 .30902 L
.68644 .30902 L
.68655 .30902 L
.6866 .30902 L
.68665 .30902 L
.68671 .30902 L
.68677 .30902 L
.68687 .30902 L
.68693 .30902 L
.68698 .30902 L
.68704 .30902 L
.68709 .30902 L
.68721 .30902 L
.68731 .30902 L
.68741 .30902 L
.6878 .30902 L
.68868 .30902 L
.68944 .30902 L
.69026 .30902 L
.69103 .30902 L
.69173 .30902 L
.69212 .30902 L
Mistroke
.69253 .30902 L
.69288 .30902 L
.69327 .30902 L
.69368 .30902 L
.69406 .30902 L
.69452 .30902 L
.69494 .30902 L
.69532 .30902 L
.69572 .30902 L
.69611 .30902 L
.69646 .30902 L
.69667 .30902 L
.69687 .30902 L
.69708 .30902 L
.69731 .30902 L
.69752 .30902 L
.69771 .30902 L
.69791 .30902 L
.69801 .30902 L
.69812 .30902 L
.69833 .30902 L
.69844 .30902 L
.69855 .30902 L
.69864 .30902 L
.69873 .30902 L
.69883 .30902 L
.69894 .30902 L
.69899 .30902 L
.69904 .30902 L
.6991 .30902 L
.69916 .30902 L
.69926 .30902 L
.69936 .30902 L
.6996 .30902 L
.69983 .30902 L
.70066 .30902 L
.70144 .30902 L
.70223 .30902 L
.70295 .30902 L
.70336 .30902 L
.70374 .30902 L
.70419 .30902 L
.7046 .30902 L
.705 .30902 L
.70537 .30902 L
.70577 .30902 L
.70619 .30902 L
.70657 .30902 L
.70696 .30902 L
.7073 .30902 L
Mistroke
.70767 .30902 L
.70787 .30902 L
.70809 .30902 L
.70829 .30902 L
.70849 .30902 L
.70868 .30902 L
.70888 .30902 L
.70924 .30902 L
.70946 .30902 L
.70966 .30902 L
.70988 .30902 L
.70999 .30902 L
.71011 .30902 L
.71021 .30902 L
.71031 .30902 L
.71041 .30902 L
.71049 .30902 L
.7106 .30902 L
.71065 .30902 L
.71071 .30902 L
.71081 .30902 L
.71087 .30902 L
.71092 .30902 L
.71102 .30902 L
.71107 .30902 L
.71113 .30902 L
.71123 .30902 L
.71132 .30902 L
.71153 .30902 L
.71176 .30902 L
.71255 .30902 L
.71332 .30902 L
.71404 .30902 L
.71481 .30902 L
.71521 .30902 L
.71564 .30902 L
.7161 .30902 L
.71653 .30902 L
.71692 .30902 L
.71734 .30902 L
.71773 .30902 L
.7181 .30902 L
.7185 .30902 L
.71893 .30902 L
.71915 .30902 L
.71938 .30902 L
.71959 .30902 L
.71981 .30902 L
.72003 .30902 L
.72023 .30902 L
Mistroke
.72062 .30902 L
.72081 .30902 L
.72101 .30902 L
.72121 .30902 L
.72142 .30902 L
.72162 .30902 L
.72181 .30902 L
.72199 .30902 L
.72216 .30902 L
.72226 .30902 L
.72237 .30902 L
.72248 .30902 L
.72258 .30902 L
.72268 .30902 L
.72277 .30902 L
.72286 .30902 L
.72296 .30902 L
.72307 .30902 L
.72313 .30902 L
.72318 .30902 L
.72328 .30902 L
.72338 .30902 L
.72384 .30902 L
.72531 .30902 L
.72614 .30902 L
.72655 .30902 L
.72692 .30902 L
.72769 .30902 L
.72812 .30902 L
.72852 .30902 L
.72894 .30902 L
.72933 .30902 L
.72975 .30902 L
.73021 .30902 L
.73064 .30902 L
.73104 .30902 L
.73147 .30902 L
.73169 .30902 L
.73193 .30902 L
.73234 .30902 L
.73256 .30902 L
.73277 .30902 L
.73296 .30902 L
.73317 .30902 L
.73337 .30902 L
.73355 .30902 L
.73375 .30902 L
.73392 .30902 L
.73402 .30902 L
.73413 .30902 L
Mistroke
.73423 .30902 L
.73433 .30902 L
.73441 .30902 L
.73451 .30902 L
.73461 .30902 L
.7347 .30902 L
.73479 .30902 L
.73489 .30902 L
.73497 .30902 L
.73505 .30902 L
.73511 .30902 L
.73516 .30902 L
.73527 .30902 L
.73547 .30902 L
.73591 .30902 L
.73671 .30902 L
.73753 .30902 L
.73829 .30902 L
.73868 .30902 L
.73909 .30902 L
.73955 .30902 L
.73998 .30902 L
.74035 .30902 L
.74075 .30902 L
.74119 .30902 L
.74159 .30902 L
.742 .30902 L
.74246 .30902 L
.74289 .30902 L
.74328 .30902 L
.74365 .30902 L
.74386 .30902 L
.74406 .30902 L
.74424 .30902 L
.74443 .30902 L
.74478 .30902 L
.745 .30902 L
.7452 .30902 L
.74543 .30902 L
.74564 .30902 L
.74584 .30902 L
.74603 .30902 L
.74612 .30902 L
.74623 .30902 L
.74634 .30902 L
.74644 .30902 L
.74654 .30902 L
.74659 .30902 L
.74665 .30902 L
.74675 .30902 L
Mistroke
.74684 .30902 L
.7469 .30902 L
.74695 .30902 L
.74705 .30902 L
.74711 .30902 L
.74716 .30902 L
.74728 .30902 L
.74767 .30902 L
.74808 .30902 L
.74885 .30902 L
.74957 .30902 L
.75039 .30902 L
.75082 .30902 L
.75128 .30902 L
.75165 .30902 L
.75205 .30902 L
.75249 .30902 L
.7529 .30902 L
.75332 .30902 L
.75371 .30902 L
.75414 .30902 L
.75436 .30902 L
.7546 .30902 L
.75483 .30902 L
.75504 .30902 L
.75523 .30902 L
.75545 .30902 L
.75582 .30902 L
.75603 .30902 L
.75621 .30902 L
.75662 .30902 L
.75685 .30902 L
.75706 .30902 L
.75724 .30902 L
.75744 .30902 L
.75766 .30902 L
.75785 .30902 L
.75795 .30902 L
.75805 .30902 L
.75813 .30902 L
.75823 .30902 L
.75832 .30902 L
.75841 .30902 L
.75849 .30902 L
.75857 .30902 L
.75867 .30902 L
.75877 .30902 L
.75885 .30902 L
.75894 .30902 L
.75904 .30902 L
Mistroke
.75915 .30902 L
.75934 .30902 L
.76093 .30902 L
.76137 .30902 L
.76183 .30902 L
.76223 .30902 L
.76266 .30902 L
.76307 .30902 L
.76345 .30902 L
.76383 .30902 L
.76418 .30902 L
.76457 .30902 L
.765 .30902 L
.76542 .30902 L
.76586 .30902 L
.76629 .30902 L
.76668 .30902 L
.76689 .30902 L
.76712 .30902 L
.76736 .30902 L
.76758 .30902 L
.76798 .30902 L
.7682 .30902 L
.76841 .30902 L
.76879 .30902 L
.769 .30902 L
.76919 .30902 L
.76941 .30902 L
.7696 .30902 L
.76982 .30902 L
.76992 .30902 L
.77004 .30902 L
.77015 .30902 L
.77024 .30902 L
.7703 .30902 L
.77035 .30902 L
.77046 .30902 L
.77055 .30902 L
.77066 .30902 L
.77075 .30902 L
.77084 .30902 L
.77094 .30902 L
.77104 .30902 L
.77121 .30902 L
.77161 .30902 L
.77234 .30902 L
.77311 .30902 L
.77353 .30902 L
.77393 .30902 L
.7743 .30902 L
Mistroke
.7747 .30902 L
.7754 .30902 L
.77579 .30902 L
.77616 .30902 L
.77657 .30902 L
.777 .30902 L
.77745 .30902 L
.77788 .30902 L
.77827 .30902 L
.77847 .30902 L
.77869 .30902 L
.77908 .30902 L
.77944 .30902 L
.77965 .30902 L
.77988 .30902 L
.78027 .30902 L
.78048 .30902 L
.78069 .30902 L
.78089 .30902 L
.78108 .30902 L
.7813 .30902 L
.78141 .30902 L
.78153 .30902 L
.78164 .30902 L
.78175 .30902 L
.78186 .30902 L
.78196 .30902 L
.78206 .30902 L
.78216 .30902 L
.78222 .30902 L
.78227 .30902 L
.78238 .30902 L
.78248 .30902 L
.78257 .30902 L
.78267 .30902 L
.78277 .30902 L
.78286 .30902 L
.78296 .30902 L
.78313 .30902 L
.78352 .30902 L
.78439 .30902 L
.78519 .30902 L
.78601 .30902 L
.78644 .30902 L
.7869 .30902 L
.7873 .30902 L
.78767 .30902 L
.78808 .30902 L
.78852 .30902 L
.78891 .30902 L
Mistroke
.78928 .30902 L
.78969 .30902 L
.79013 .30902 L
.79034 .30902 L
.79058 .30902 L
.79079 .30902 L
.79101 .30902 L
.79121 .30902 L
.79143 .30902 L
.79182 .30902 L
.79202 .30902 L
.79224 .30902 L
.79244 .30902 L
.79264 .30902 L
.79283 .30902 L
.793 .30902 L
.79319 .30902 L
.79338 .30902 L
.79359 .30902 L
.79369 .30902 L
.7938 .30902 L
.7939 .30902 L
.794 .30902 L
.7941 .30902 L
.79419 .30902 L
.79424 .30902 L
.7943 .30902 L
.7944 .30902 L
.79446 .30902 L
.79451 .30902 L
.79457 .30902 L
.79464 .30902 L
.79486 .30902 L
.79506 .30902 L
.79586 .30902 L
.79671 .30902 L
.79712 .30902 L
.79751 .30902 L
.79824 .30902 L
.79862 .30902 L
.79901 .30902 L
.79935 .30902 L
.79972 .30902 L
.80011 .30902 L
.80054 .30902 L
.80094 .30902 L
.80131 .30902 L
.80169 .30902 L
.8021 .30902 L
.80245 .30902 L
Mistroke
.80284 .30902 L
.80306 .30902 L
.80325 .30902 L
.80347 .30902 L
.8037 .30902 L
.80389 .30902 L
.80409 .30902 L
.80431 .30902 L
.80451 .30902 L
.80471 .30902 L
.80493 .30902 L
.80512 .30902 L
.80533 .30902 L
.80544 .30902 L
.80555 .30902 L
.80567 .30902 L
.80573 .30902 L
.80579 .30902 L
.80584 .30902 L
.80589 .30902 L
.80599 .30902 L
.80605 .30902 L
.80611 .30902 L
.80617 .30902 L
.80622 .30902 L
.80631 .30902 L
.80641 .30902 L
.80651 .30902 L
.80659 .30902 L
.80701 .30902 L
.80784 .30902 L
.80858 .30902 L
.80937 .30902 L
.80978 .30902 L
.81024 .30902 L
.81065 .30902 L
.81104 .30902 L
.81141 .30902 L
.81183 .30902 L
.81226 .30902 L
.81266 .30902 L
.81304 .30902 L
.81338 .30902 L
.81377 .30902 L
.81415 .30902 L
.81452 .30902 L
.81473 .30902 L
.81493 .30902 L
.81533 .30902 L
.81555 .30902 L
Mistroke
.81575 .30902 L
.81593 .30902 L
.81612 .30902 L
.81632 .30902 L
.81651 .30902 L
.81669 .30902 L
.81686 .30902 L
.81704 .30902 L
.81714 .30902 L
.81724 .30902 L
.81734 .30902 L
.81743 .30902 L
.81752 .30902 L
.81761 .30902 L
.81772 .30902 L
.81777 .30902 L
.81783 .30902 L
.81793 .30902 L
.81802 .30902 L
.81811 .30902 L
.8182 .30902 L
.81837 .30902 L
.81875 .30902 L
.81956 .30902 L
.82041 .30902 L
.82084 .30902 L
.82125 .30902 L
.82164 .30902 L
.822 .30902 L
.82234 .30902 L
.82271 .30902 L
.82308 .30902 L
.82348 .30902 L
.8239 .30902 L
.8243 .30902 L
.82466 .30902 L
.82504 .30902 L
.82547 .30902 L
.82568 .30902 L
.82592 .30902 L
.82612 .30902 L
.82633 .30902 L
.82672 .30902 L
.82692 .30902 L
.82712 .30902 L
.8273 .30902 L
.82749 .30902 L
.82772 .30902 L
.82793 .30902 L
.82814 .30902 L
Mistroke
.82833 .30902 L
.82853 .30902 L
.82872 .30902 L
.82883 .30902 L
.82893 .30902 L
.82905 .30902 L
.82915 .30902 L
.82926 .30902 L
.82931 .30902 L
.82937 .30902 L
.82943 .30902 L
.82949 .30902 L
.82955 .30902 L
.8296 .30902 L
.8297 .30902 L
.82976 .30902 L
.82981 .30902 L
.82991 .30902 L
.83003 .30902 L
.83023 .30902 L
.83045 .30902 L
.83084 .30902 L
.83173 .30902 L
.8325 .30902 L
.83294 .30902 L
.83335 .30902 L
.83373 .30902 L
.83414 .30902 L
.83457 .30902 L
.83497 .30902 L
.83535 .30902 L
.83569 .30902 L
.83609 .30902 L
.83646 .30902 L
.83683 .30902 L
.83724 .30902 L
.83745 .30902 L
.83767 .30902 L
.83786 .30902 L
.83807 .30902 L
.83828 .30902 L
.83847 .30902 L
.83865 .30902 L
.83885 .30902 L
.83919 .30902 L
.83938 .30902 L
.83955 .30902 L
.83975 .30902 L
.83993 .30902 L
.84013 .30902 L
Mistroke
.84034 .30902 L
.84045 .30902 L
.84056 .30902 L
.84067 .30902 L
.84078 .30902 L
.84087 .30902 L
.84098 .30902 L
.84108 .30902 L
.84117 .30902 L
.84126 .30902 L
.84136 .30902 L
.84146 .30902 L
.84154 .30902 L
.84163 .30902 L
.84171 .30902 L
.84189 .30902 L
.84228 .30902 L
.84266 .30902 L
.84344 .30902 L
.84387 .30902 L
.84427 .30902 L
.84498 .30902 L
.84535 .30902 L
.84575 .30902 L
.84618 .30902 L
.84657 .30902 L
.847 .30902 L
.84746 .30902 L
.84785 .30902 L
.84823 .30902 L
.84863 .30902 L
.84886 .30902 L
.84907 .30902 L
.84945 .30902 L
.84967 .30902 L
.84986 .30902 L
.85004 .30902 L
.85024 .30902 L
.85059 .30902 L
.85079 .30902 L
.85101 .30902 L
.85124 .30902 L
.85146 .30902 L
.85166 .30902 L
.85184 .30902 L
.85194 .30902 L
.85205 .30902 L
.85226 .30902 L
.85236 .30902 L
.85246 .30902 L
Mistroke
.85257 .30902 L
.85268 .30902 L
.85278 .30902 L
.85288 .30902 L
.85298 .30902 L
.85304 .30902 L
.85309 .30902 L
.85318 .30902 L
.85327 .30902 L
.85337 .30902 L
.85347 .30902 L
.85384 .30902 L
.85465 .30902 L
.8551 .30902 L
.85552 .30902 L
.85592 .30902 L
.85634 .30902 L
.85674 .30902 L
.85709 .30902 L
.85746 .30902 L
.85785 .30902 L
.85822 .30902 L
.85856 .30902 L
.85893 .30902 L
.85934 .30902 L
.85955 .30902 L
.85977 .30902 L
.85996 .30902 L
.86017 .30902 L
.86038 .30902 L
.86057 .30902 L
.86095 .30902 L
.86129 .30902 L
.86146 .30902 L
.86165 .30902 L
.86205 .30902 L
.86225 .30902 L
.86246 .30902 L
.86265 .30902 L
.86285 .30902 L
.86304 .30902 L
.86321 .30902 L
.86342 .30902 L
.86362 .30902 L
.86384 .30902 L
.86395 .30902 L
.86407 .30902 L
.86417 .30902 L
.86427 .30902 L
.86432 .30902 L
Mistroke
.86438 .30902 L
.86449 .30902 L
.86459 .30902 L
.86469 .30902 L
.86479 .30902 L
.86488 .30902 L
.86498 .30902 L
.86507 .30902 L
.86527 .30902 L
.86569 .30902 L
.86643 .30902 L
.86724 .30902 L
.86769 .30902 L
.8681 .30902 L
.86849 .30902 L
.8689 .30902 L
.86925 .30902 L
.86963 .30902 L
.87005 .30902 L
.8705 .30902 L
.87092 .30902 L
.8713 .30902 L
.87168 .30902 L
.8719 .30902 L
.87209 .30902 L
.87227 .30902 L
.87247 .30902 L
.87282 .30902 L
.87302 .30902 L
.87324 .30902 L
.87346 .30902 L
.87369 .30902 L
.8739 .30902 L
.8741 .30902 L
.87428 .30902 L
.87449 .30902 L
.87468 .30902 L
.87487 .30902 L
.87507 .30902 L
.87528 .30902 L
.87547 .30902 L
.87556 .30902 L
.87566 .30902 L
.87575 .30902 L
.87585 .30902 L
.87593 .30902 L
.87602 .30902 L
.87607 .30902 L
.87613 .30902 L
.87623 .30902 L
Mistroke
.87629 .30902 L
.87635 .30902 L
.87641 .30902 L
.87646 .30902 L
.87657 .30902 L
.87663 .30902 L
.87668 .30902 L
.87689 .30902 L
.87727 .30902 L
.87768 .30902 L
.87851 .30902 L
.87894 .30902 L
.8794 .30902 L
.8798 .30902 L
.88024 .30902 L
.88065 .30902 L
.88102 .30902 L
.88142 .30902 L
.88186 .30902 L
.88227 .30902 L
.88265 .30902 L
.883 .30902 L
.88338 .30902 L
.88357 .30902 L
.88377 .30902 L
.88414 .30902 L
.88434 .30902 L
.88454 .30902 L
.88491 .30902 L
.88514 .30902 L
.88535 .30902 L
.88554 .30902 L
.88575 .30902 L
.88596 .30902 L
.88618 .30902 L
.88638 .30902 L
.88657 .30902 L
.88679 .30902 L
.88699 .30902 L
.8871 .30902 L
.88722 .30902 L
.88734 .30902 L
.88745 .30902 L
.88755 .30902 L
.88761 .30902 L
.88766 .30902 L
.88775 .30902 L
.88786 .30902 L
.88791 .30902 L
.88797 .30902 L
Mistroke
.88807 .30902 L
.88813 .30902 L
.88818 .30902 L
.88824 .30902 L
.8883 .30902 L
.88849 .30902 L
.88868 .30902 L
.8891 .30902 L
.88981 .30902 L
.89059 .30902 L
.89102 .30902 L
.89143 .30902 L
.89181 .30902 L
.89222 .30902 L
.89262 .30902 L
.893 .30902 L
.89334 .30902 L
.8937 .30902 L
.8941 .30902 L
.89447 .30902 L
.89487 .30902 L
.8951 .30902 L
.8953 .30902 L
.89572 .30902 L
.89595 .30902 L
.89617 .30902 L
.89657 .30902 L
.89677 .30902 L
.89699 .30902 L
.89718 .30902 L
.89739 .30902 L
.8976 .30902 L
.8978 .30902 L
.89799 .30902 L
.89816 .30902 L
.89836 .30902 L
.89854 .30902 L
.89875 .30902 L
.89885 .30902 L
.89896 .30902 L
.89906 .30902 L
.89916 .30902 L
.89926 .30902 L
.89935 .30902 L
.8994 .30902 L
.89946 .30902 L
.89956 .30902 L
.89962 .30902 L
.89968 .30902 L
.89974 .30902 L
Mistroke
.89979 .30902 L
.89985 .30902 L
.8999 .30902 L
.90002 .30902 L
.90022 .30902 L
.90109 .30902 L
.90152 .30902 L
.90192 .30902 L
.90266 .30902 L
.90305 .30902 L
.90347 .30902 L
.90383 .30902 L
.90423 .30902 L
.90461 .30902 L
.90495 .30902 L
.90533 .30902 L
.90575 .30902 L
.90596 .30902 L
.90619 .30902 L
.90659 .30902 L
.9068 .30902 L
.90702 .30902 L
.90741 .30902 L
.90763 .30902 L
.90784 .30902 L
.90806 .30902 L
.90831 .30902 L
.90851 .30902 L
.90874 .30902 L
.90895 .30902 L
.90915 .30902 L
.90935 .30902 L
.90953 .30902 L
.90973 .30902 L
.90992 .30902 L
.91012 .30902 L
.9103 .30902 L
.9104 .30902 L
.9105 .30902 L
.91061 .30902 L
.91071 .30902 L
.91081 .30902 L
.91086 .30902 L
.91092 .30902 L
.91102 .30902 L
.91111 .30902 L
.91117 .30902 L
.91122 .30902 L
.91132 .30902 L
.91137 .30902 L
Mistroke
.91142 .30902 L
.91154 .30902 L
.91174 .30902 L
.91192 .30902 L
.91226 .30902 L
.91303 .30902 L
.91381 .30902 L
.9142 .30902 L
.91464 .30902 L
.91501 .30902 L
.9154 .30902 L
.91578 .30902 L
.91612 .30902 L
.91651 .30902 L
.91692 .30902 L
.91727 .30902 L
.91765 .30902 L
.91787 .30902 L
.91807 .30902 L
.91828 .30902 L
.91851 .30902 L
.9189 .30902 L
.91912 .30902 L
.91932 .30902 L
.91952 .30902 L
.91972 .30902 L
.91995 .30902 L
.92016 .30902 L
.92035 .30902 L
.92054 .30902 L
.92076 .30902 L
.92096 .30902 L
.92115 .30902 L
.92136 .30902 L
.92156 .30902 L
.92174 .30902 L
.92183 .30902 L
.92192 .30902 L
.92209 .30902 L
.92218 .30902 L
.92226 .30902 L
.92235 .30902 L
.92245 .30902 L
.92255 .30902 L
.92261 .30902 L
.92266 .30902 L
.92275 .30902 L
.92285 .30902 L
.92294 .30902 L
.92302 .30902 L
Mistroke
.92322 .30902 L
.92361 .30902 L
.92403 .30902 L
.9248 .30902 L
.9255 .30902 L
.92588 .30902 L
.92627 .30902 L
.92672 .30902 L
.92712 .30902 L
.92754 .30902 L
.92776 .30902 L
.92799 .30902 L
.92819 .30902 L
.92842 .30902 L
.92881 .30902 L
.92901 .30902 L
.92923 .30902 L
.92942 .30902 L
.92963 .30902 L
.92981 .30902 L
.93002 .30902 L
.93037 .30902 L
.93059 .30902 L
.93079 .30902 L
.93101 .30902 L
.93124 .30902 L
.93145 .30902 L
.93164 .30902 L
.93184 .30902 L
.93205 .30902 L
.93226 .30902 L
.93248 .30902 L
.93267 .30902 L
.93287 .30902 L
.9331 .30902 L
.93322 .30902 L
.93333 .30902 L
.93344 .30902 L
.93355 .30902 L
.93366 .30902 L
.93376 .30902 L
.93387 .30902 L
.93392 .30902 L
.93398 .30902 L
.93407 .30902 L
.93417 .30902 L
.93427 .30902 L
.93435 .30902 L
.93445 .30902 L
.93455 .30902 L
Mistroke
.93465 .30902 L
.93477 .30902 L
.93498 .30902 L
.93538 .30902 L
.9362 .30902 L
.93697 .30902 L
.93736 .30902 L
.93777 .30902 L
.93823 .30902 L
.93866 .30902 L
.93904 .30902 L
.93944 .30902 L
.93983 .30902 L
.94018 .30902 L
.94059 .30902 L
.94082 .30902 L
.94103 .30902 L
.94142 .30902 L
.94162 .30902 L
.94184 .30902 L
.94204 .30902 L
.94226 .30902 L
.94245 .30902 L
.94265 .30902 L
.94286 .30902 L
.94304 .30902 L
.94322 .30902 L
.9434 .30902 L
.94362 .30902 L
.94382 .30902 L
.94403 .30902 L
.94426 .30902 L
.94447 .30902 L
.94458 .30902 L
.94469 .30902 L
.94478 .30902 L
.94489 .30902 L
.94508 .30902 L
.94518 .30902 L
.94527 .30902 L
.94537 .30902 L
.94547 .30902 L
.94556 .30902 L
.94564 .30902 L
.94574 .30902 L
.94584 .30902 L
.94589 .30902 L
.94594 .30902 L
.946 .30902 L
.94606 .30902 L
Mistroke
.94627 .30902 L
.94667 .30902 L
.94748 .30902 L
.94793 .30902 L
.94836 .30902 L
.94875 .30902 L
.94918 .30902 L
.94957 .30902 L
.94993 .30902 L
.95027 .30902 L
.95065 .30902 L
.95104 .30902 L
.9514 .30902 L
.95178 .30902 L
.95199 .30902 L
.95219 .30902 L
.95259 .30902 L
.95282 .30902 L
.95302 .30902 L
.95339 .30902 L
.9536 .30902 L
.95379 .30902 L
.95414 .30902 L
.95431 .30902 L
.95451 .30902 L
.95471 .30902 L
.95493 .30902 L
.95513 .30902 L
.95532 .30902 L
.95551 .30902 L
.95568 .30902 L
.95588 .30902 L
.95607 .30902 L
.95627 .30902 L
.95638 .30902 L
.95649 .30902 L
.95658 .30902 L
.95669 .30902 L
.95679 .30902 L
.95687 .30902 L
.95693 .30902 L
.95699 .30902 L
.95709 .30902 L
.95715 .30902 L
.9572 .30902 L
.95726 .30902 L
.95732 .30902 L
.95737 .30902 L
.95743 .30902 L
.95749 .30902 L
Mistroke
.95754 .30902 L
.95775 .30902 L
.95848 .30902 L
.95925 .30902 L
.95966 .30902 L
.9601 .30902 L
.9605 .30902 L
.96088 .30902 L
.96132 .30902 L
.96171 .30902 L
.96193 .30902 L
.96217 .30902 L
.96237 .30902 L
.9626 .30902 L
.96301 .30902 L
.96323 .30902 L
.96344 .30902 L
.96381 .30902 L
.96402 .30902 L
.96422 .30902 L
.9646 .30902 L
.96481 .30902 L
.965 .30902 L
.96518 .30902 L
.96538 .30902 L
.96573 .30902 L
.96593 .30902 L
.96615 .30902 L
.96638 .30902 L
.9666 .30902 L
.9668 .30902 L
.96698 .30902 L
.96719 .30902 L
.96739 .30902 L
.96749 .30902 L
.9676 .30902 L
.9677 .30902 L
.9678 .30902 L
.96789 .30902 L
.96799 .30902 L
.96808 .30902 L
.96816 .30902 L
.96827 .30902 L
.96837 .30902 L
.96847 .30902 L
.96853 .30902 L
.96859 .30902 L
.96868 .30902 L
.96878 .30902 L
.96888 .30902 L
Mistroke
.96898 .30902 L
.96916 .30902 L
.96935 .30902 L
.96969 .30902 L
.97046 .30902 L
.97123 .30902 L
.97165 .30902 L
.97204 .30902 L
.97241 .30902 L
.9728 .30902 L
.97318 .30902 L
.97352 .30902 L
.97384 .30902 L
.97418 .30902 L
.9745 .30902 L
.97479 .30902 L
.97513 .30902 L
.97533 .30902 L
.97551 .30902 L
.97584 .30902 L
.97602 .30902 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{421.375, 260.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008>0001AB000`400?l00000o`00003ooooooooo
oooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo
003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooo
oooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool0
0?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooooooo
ool@ooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooo
ooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo0ol0003o
ooooomcooooo000`ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooooDoooo
o`00<?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?ooooooe?ooool0033ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooomCooooo000`ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0oooooooDooooo`00<?ooool00ol0003oooooooooo`05
ooooo`;o0000oooooooEooooo`00<?ooool00ol0003oooooooooo`05ooooo`;o0000oooooooEoooo
o`00<?ooool00ol0003oooooooooo`05ooooo`;o0000oooooooEooooo`00<?ooool00ol0003ooooo
ooooo`05ooooo`;o0000oooooooEooooo`00<?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooo00000?ooooooeOooool0033ooooo00?o0000ooooooooool01?ooool00ol0003oooooo`00003o
ooooomGooooo000`ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooool00000oooooooEoooo
o`00<?ooool3o`0000Cooooo00?o0000ooooool00000oooooooEooooo`00<?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooo00000?ooooooeOooool0033ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooo`00003oooooomGooooo000`ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooool00000oooooooEooooo`00<?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo0000
0?ooooooeOooool0033ooooo00?o0000ooooooooool01?ooool00ol0003oooooo`00003oooooomGo
oooo000/ooooo`;o00000_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo00000?oooooo
eOooool002cooooo0_l00002ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooool00000oooo
oooEooooo`00;?ooool2o`0000;ooooo00?o0000ooooooooool01?ooool00ol0003oooooo`00003o
ooooomGooooo000/ooooo`;o00000_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo0000
0?ooooooeOooool002cooooo0_l00002ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooool0
0000oooooooEooooo`00;?ooool2o`0000;ooooo0ol00004ooooo`03o`000?oooooo00000?oooooo
eOooool002cooooo0_l00002ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooool00000oooo
oooEooooo`00;?ooool2o`0000;ooooo00?o0000ooooooooool01?ooool00ol0003oooooo`00003o
ooooomGooooo000/ooooo`;o00000_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo0000
0?ooooooeOooool002cooooo0_l00002ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooool0
0000oooooooEooooo`00;?ooool2o`0000;ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
o`00003oooooomGooooo000/ooooo`;o00000_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooo00000?ooooooeOooool0013ooooo0_o^k^h3ooooo`;ok^k^5Oooool01Ol0003oooooo`000?oo
oooo000000Kooooo00?o0000ooooool00000oooooooEooooo`002oooool2o`00000:oa0@4?oooooo
ooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP?ooooo1?l000002?l@413oooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^1_ooool01Ol0003oooooo`000?oooooo000000Kooooo00?o0000ooooool0
0000oooooooEooooo`003?ooool00ol0003oooooooooo`02ooooo`05onk^k_mEEEGogMgMoeEEEOo^
k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool01Ol0
003oooooo`000?oooooo000000Kooooo00?o0000ooooool00000oooooooEooooo`0000?oooooo`00
0?l000001?l00002ooooo`Go00001?ooool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo
00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`05o`000?oooooo0000ooooool000001_oo
ool00ol0003oooooo`00003oooooomGooooo0009ooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go
k^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`000006ooooo`05o`000?oooooo0000ooooool000001_ooool00ol0003oooooo`00003ooooo
omGooooo0009ooooo`04omgMgOmEEEGoooooo`0000?ooooo00Ook^k^oeEEEOo^k^koooooonk^k_mE
EEGok^k^00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo
00Co0000ooooool0003ooooo1?l00003ooooo`03o`000?oooooo00000?ooooooeOooool000[ooooo
00?oMgMgolc<c?l000000oooool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo
00Go410@oooooooooooooooooa0@4006ooooo`05o`000?oooooo0000ooooool000001_ooool00ol0
003oooooo`00003oooooomGooooo000:ooooo`03onk^k_m4A4Co000000oooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo0_l000001_oooooo0000ooooool0003o
ooooo`0000Kooooo00?o0000ooooool00000oooooooEooooo`002oooool00omgMgOo0000ooooo`0<
ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`03o`000?oo
oooooooo00;o000000Coooooo`000?oooooo00001_ooool00ol0003oooooo`00003oooooomGooooo
000Xooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooool000001_ooool00ol0003ooooo
o`00003oooooomGooooo000Xooooo`Co00000_ooool00ol0003oooooo`000006ooooo`03o`000?oo
oooo00000?ooooooeOooool002Wooooo00?o0000ooooool000000_ooool00ol0003oooooo`000006
ooooo`03o`000?oooooo00000?ooooooeOooool002[ooooo0_l00002ooooo`03o`000?oooooo0000
00Kooooo00?o0000ooooool00000oooooooEooooo`00:oooool01_l0003oooooooooool0003ooooo
o`0000Kooooo00?o0000ooooool00000oooooooEooooo`00:oooool01_l0003oooooooooool0003o
ooooo`0000Kooooo00?o0000ooooool00000oooooooEooooo`00:oooool01_l0003oooooooooool0
003oooooo`0000Kooooo00?o0000ooooool00000oooooooEooooo`00:oooool01_l0003ooooooooo
ool0003oooooo`0000Kooooo00?o0000ooooool00000oooooooEooooo`00:oooool01Ol0003ooooo
ooooool0003ooooo00?o00001?ooool00ol0003oooooo`00003oooooomGooooo000[ooooo`06o`00
0?ooooooooooo`000?oooooo00001_ooool00ol0003oooooo`00003oooooomGooooo000[ooooo`06
o`000?ooooooooooo`000?oooooo00001_ooool00ol0003oooooo`00003oooooomGooooo000[oooo
o`06o`000?ooooooooooo`000?oooooo00001_ooool00ol0003oooooo`00003oooooomGooooo000[
ooooo`06o`000?ooooooooooo`000?oooooo00001_ooool00ol0003oooooo`00003oooooomGooooo
000[ooooo`06o`000?ooooooooooo`000?oooooo00001_ooool00ol0003oooooo`00003oooooomGo
oooo000[ooooo`06o`000?ooooooooooo`000?oooooo00001_ooool00ol0003oooooo`00003ooooo
omGooooo000[ooooo`06o`000?ooooooooooo`000?oooooo00001_ooool00ol0003oooooo`00003o
ooooomGooooo000[ooooo`06o`000?ooooooooooo`000?oooooo00001Oooool01Ol0003ooooooooo
oooooooo00000?ooooooe?ooool002_ooooo00Ko0000oooooooooooo0000ooooool00005ooooo`05
o`000?ooooooooooooooool00000oooooooDooooo`00:oooool01_l0003oooooooooool0003ooooo
o`0000Gooooo00Go0000ooooooooooooooooo`00003oooooomCooooo000[ooooo`06o`000?oooooo
ooooo`000?oooooo00001Oooool01Ol0003ooooooooooooooooo00000?ooooooe?ooool002_ooooo
00Go0000oooooooooooo0000ooooo`03o`0000?ooooo00Go0000ooooooooooooooooo`00003ooooo
omCooooo000[ooooo`06o`000?ooooooooooo`000?oooooo00001Oooool01Ol0003ooooooooooooo
oooo00000?ooooooe?ooool002_ooooo00Ko0000oooooooooooo0000ooooool00005ooooo`05o`00
0?ooooooooooooooool000002Oooool00ol0003oooooooooo`3oooooolSooooo000[ooooo`06o`00
0?ooooooooooo`000?oooooo00001Oooool01Ol0003ooooooooooooooooo000000Sooooo0_l0003o
oooool[ooooo000[ooooo`06o`000?ooooooooooo`000?oooooo00001Oooool01Ol0003ooooooooo
oooooooo000000Sooooo0_l0003ooooool[ooooo000[ooooo`04o`000?ooooooooooooooo`;o0000
1Oooool01Ol0003ooooooooooooooooo000000Sooooo0_l0003ooooool[ooooo000[ooooo`04o`00
0?ooooooooooooooo`;o00001Oooool01Ol0003ooooooooooooooooo000000Sooooo0_l0003ooooo
ol[ooooo000[ooooo`04o`000?ooooooooooooooo`;o00001Oooool01Ol0003ooooooooooooooooo
000000Sooooo0_l0003ooooool[ooooo000Zooooo`03o`000?oooooooooo00;ooooo0_l00005oooo
o`05o`000?ooooooooooooooool000002?ooool2o`000?oooooob_ooool002[ooooo00?o0000oooo
ooooool00_ooool2o`0000Gooooo00Go0000ooooooooooooooooo`000008ooooo`;o0000ooooooo:
ooooo`00:_ooool00ol0003oooooooooo`02ooooo`;o00001Oooool01Ol0003ooooooooooooooooo
000000Sooooo0_l0003ooooool[ooooo000Zooooo`03o`000?oooooooooo00;ooooo1?l00003oooo
o`05o`000?ooooooooooooooool000002?ooool00ol0003oooooo`00003oooooolWooooo000Zoooo
o`03o`000?oooooooooo00;ooooo0_l00005ooooo`05o`000?ooooooooooooooool000002?ooool0
0ol0003oooooo`00003oooooolWooooo000Zooooo`03o`000?oooooooooo00;ooooo0_l00005oooo
o`05o`000?ooooooooooooooool000002?ooool00ol0003oooooo`00003oooooolWooooo000Zoooo
o`03o`000?oooooooooo00;ooooo0_l00005ooooo`05o`000?ooooooooooooooool000002?ooool0
0ol0003oooooo`00003oooooolWooooo000Zooooo`03o`000?oooooooooo00;ooooo0_l00005oooo
o`05o`000?ooooooooooooooool000002?ooool00ol0003oooooo`00003oooooolWooooo000Zoooo
o`03o`000?oooooooooo00;ooooo0_l00005ooooo`05o`000?ooooooooooooooool000002?ooool0
0ol0003oooooo`00003oooooolWooooo000Zooooo`03o`000?oooooooooo00;ooooo0_l00005oooo
o`05o`000?ooooooooooooooool000002?ooool00ol0003oooooo`00003oooooolWooooo000@oooo
o`;ok^k^0oooool2onk^kQ?ooooo00?o0000ooooooooool00_ooool2o`0000Gooooo00Go0000oooo
ooooooooooooo`000008ooooo`03o`000?oooooo00000?oooooobOooool000Wooooo1Ol00002oooo
o`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co000000So410@ooooooooooook^k^
oc8b<_l0003o<S8bonk^kPCooooo00?o0000ooooooooool00_ooool2o`0000Gooooo00Go0000oooo
ooooooooooooo`000007ooooo`04o`000?ooooooooooo`000?oooooobOooool000Wooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00ol0003oooooooooo`02ooooo`;o
00001Oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000ooooooo9
ooooo`0000?oooooo`000?l000001?l00003ooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?ogMgMo`00
0?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41001?ooool0
0ol0003oooooooooo`02ooooo`;o00001Oooool01Ol0003ooooooooooooooooo000000Oooooo00Co
0000oooooooooooo0000ooooooo9ooooo`002oooool00onHV9So8B4Qonk^kP03ooooo`05onk^k_mE
EEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
00001?ooool00ol0003oooooooooo`02ooooo`;o00001Oooool01Ol0003ooooooooooooooooo0000
00Oooooo00Co0000oooooooooooo0000ooooooo9ooooo`003?ooool02omgMgOoIVIVoooooooooooo
k^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000000Cooooo00?o0000ooooooooool00_ooool5o`0000;ooooo00Go0000oooo
ooooooooooooo`000007ooooo`04o`000?ooooooooooo`000?oooooobOooool000gooooo00?o0000
ooooooooool00_o^k^h3ooooo`;ok^k^1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooo
ooooooooool@41001?ooool00ol0003oooooooooo`02ooooo`;o00001Oooool01Ol0003ooooooooo
oooooooo000000Oooooo00Co0000oooooooooooo0000ooooooo9ooooo`002Oooool01Ol0003o^[Zj
oooooonHV9So410@00kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo0_l00004ooooo`;o00001Oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000
oooooooooooo0000ooooooo9ooooo`002Oooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo00?o
EEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo00Co0000ooooool0003o
00000oooool2o`0000Gooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?oooooooooo
o`000?oooooobOooool0027ooooo00?o0000ooooooooool01?ooool01?l0003oooooo`000?l00003
ooooo`;o00001Oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000
ooooooo9ooooo`008?ooool2o`0000Kooooo0ol00004ooooo`;o00001Oooool01Ol0003ooooooooo
oooooooo000000Oooooo00Co0000oooooooooooo0000ooooooo9ooooo`008?ooool2o`0000Oooooo
0_l00004ooooo`;o00001Oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooo
oooo0000ooooooo9ooooo`008?ooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00;o
oooo0_l00005ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool0003o
ooooolWooooo000Pooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool00_ooool2o`00
00Gooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`000?oooooobOoo
ool0023ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`02ooooo`;o00001Oooool0
1Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000ooooooo9ooooo`008?oo
ool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00;ooooo0_l00005ooooo`05o`000?oo
ooooooooooooool000001oooool01?l0003oooooooooool0003oooooolWooooo000Pooooo`03o`00
0?oooooo000000Oooooo00?o0000ooooooooool00_ooool2o`0000Gooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`000?oooooobOooool0023ooooo
00?o0000ooooool000001oooool00ol0003oooooooooo`02ooooo`Co00000oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo0000ooooooo9ooooo`00
8?ooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00;ooooo0_l00005ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0003oooooolWo
oooo000Oooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool00_ooool2o`0000Co
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`00
0?oooooobOooool001oooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`02oooo
o`;o00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00Co0000oooo
oooooooo0000ooooooo9ooooo`007oooool01?l0003oooooooooool00007ooooo`03o`000?oooooo
oooo00;ooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool0
1Ol0003ooooooooooooooooo00000?oooooob?ooool001oooooo00Co0000oooooooooooo00001ooo
ool00ol0003oooooooooo`02ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00Go0000ooooooooooooooooo`00003oooooolSooooo000Oooooo`04o`000?oo
ooooooooo`0000Oooooo00?o0000ooooooooool00_ooool2o`0000Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000ooooooo8ooooo`00
7oooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00;ooooo0_l00004ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000
0?oooooob?ooool001oooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`02oooo
o`;o00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00Go0000oooo
ooooooooooooo`00003oooooolSooooo000Oooooo`04o`000?ooooooooooo`0000Oooooo00?o0000
ooooooooool00_ooool2o`0000Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04
ooooo`05o`000?ooooooooooooooool00000ooooooo8ooooo`007oooool01?l0003oooooooooool0
0007ooooo`03o`000?oooooooooo00;ooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool01Ol0003ooooooooooooooooo00000?oooooob?ooool001oooooo00Co
0000oooooooooooo00001oooool00ol0003oooooooooo`02ooooo`;o00001?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00003oooooolSo
oooo000Oooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool00_ooool4o`0000;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooooooo
ool00000ooooooo8ooooo`007oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooo
ooooool00_ooool2o`0000Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04oooo
o`05o`000?ooooooooooooooool00000ooooooo8ooooo`007oooool01Ol0003ooooooooooooooooo
000000Kooooo00?o0000ooooooooool00_ooool2o`0000Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000ooooooo8ooooo`007oooool0
1Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool2o`0000Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000
ooooooo8ooooo`007oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0
0oooool2o`0000Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0ooooooo6ooooo`007oooool01Ol0003ooooooooo
oooooooo000000Gooooo00?o0000ooooooooool00oooool2o`0000Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
>?ooool2onk^kP?ooooo0_o^k^iGooooo`;ok^k^0oooool2onk^kV3ooooo0_o^k^h3ooooo`;ok^k^
C_ooool2onk^kP?ooooo0_o^k^i/ooooo`007oooool01Ol0003ooooooooooooooooo000000Gooooo
00?o0000ooooooooool00oooool2o`0000Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0<_ooool03Om4A4Co0000
o`000?lb<S;ogMgMooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@
4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^i2ooooo`Co000000Wo410@ooooooo^k^koEEEEonk^
k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^hkooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo00goA4A4o`000?l0003o<S8b
omgMgOooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413ooooooooo
ooo^k^ko<S8bo`000?lb<S;ok^k^>?ooool5o`0000;ooooo00Ook^k^oeEEEOo^k^koooooonk^k_mE
EEGok^k^00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^GOooool001oo
oooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00?ooooo0_l00004oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Kooooo0_l0000]ooooo`09ogMgMolb<S;oooooooooooo^k^koEEEEomgM
gOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg04Co
oooo00?o0000ooooooooool00_ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000oooo
ooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg03gooooo00?o0000ooooooooool01?ooool2
ob4Q8@Sooooo00WoMgMgoc8b<_ooooooooooonk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0>?ooool01OnHV9So8B4Qonk^k_oooooo
A4A400?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`1Mooooo`007oooool01Ol0003ooooooooooooooooo000000Gooooo
00?o0000ooooooooool00oooool2o`0000Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
o`00000^ooooo`07o`000?oooooooooooooooooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo
00;ooooo00Go410@oooooooooooooooooa0@4014ooooo`03o`000?oooooooooo00?ooooo00?ogMgM
o`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100?Ooo
ool00ol0003oooooooooo`0?ooooo`07o`000?oooooooooooooooooMgMgo0000omgMg@07ooooo`03
o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400iooooo`03oiRHV?lQ8B7ok^k^
00Gooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@4100GOooool001oooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooo
oooo00?ooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool00000;Oooool0
2OmgMgOo<S8booooooooooook^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`000014ooooo`03o`000?oooooooooo00;ooooo00Gok^k^oeEE
EOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
000mooooo`03o`000?oooooooooo00kooooo00WoMgMgoc8b<_ooooooooooonk^k_mEEEGogMgMoeEE
EOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000>_ooool0
0onHV9So8B4Qonk^kP03ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool00000GOooool001kooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooool00000:_ooool03Ol0003o8B4Qo`000?lb<S;oc<c<ooooooo^
k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool00000A?ooool02ol0003oooooooooooooooook^k^oeEEEOo^k^koooooonk^k_mE
EEGok^k^00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000003gooooo
00?o0000ooooooooool02oooool03Ol0003o8B4Qo`000?lb<S;oc<c<ooooooo^k^koEEEEonk^k_oo
ooook^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
0000>oooool02omgMgOoIVIVooooooooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000005gooooo000Nooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`;o0000
1?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo000002[ooooo00?o0000ooooooooool0
0oooool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@4014ooooo`04o`000?ooooooooooooooo`;ok^k^0oooool2onk^kPGooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@03gooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`03ooooo`;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@03cooooo00?o0000ooooooooool00_o^k^h3ooooo`;ok^k^1Ooo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100GOooool001kooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo1?l0
0002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooool00000:_ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`00
0?oooooooooo03Wooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02?ooool2o`0003?ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08oooo
o`;o0000;_ooool01Ol0003o^[ZjoooooonHV9So410@00kooooo00?o0000ooooooooool00_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo0_l0001Cooooo`007_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool2o`0000Cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01?ooool01?l0003oooooooooool0000Yooooo`Co00003?ooool00omEEEGoIVIVo`00
0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`0gooooo`03oeEE
EOmVIVKo000000gooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oo
oooo00Co0000oooooooooooo0000<?ooool00omEEEGoIVIVo`00000=ooooo`Co00003?ooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01oooool01?l0003oooooooooool0
000]ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?ooool00omEEEGoIVIVo`000004ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01oooool01?l0003oooooooooool0001Booooo`007_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool2o`0000Co
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00017ooooo`Co00000oooool00ol0
003oooooooooo`1Dooooo`Co000000Goooooo`000?ooooooooooo`00001Nooooo`Co000000Gooooo
o`000?ooooooooooo`00001<ooooo`Co000000Goooooo`000?ooooooooooo`00001Booooo`007_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool2o`0000Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000004kooooo
00?o0000ooooooooool0FOooool3o`0006Cooooo0ol0001Booooo`?o0000Doooool001Cooooo0ol0
0007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool00000
C?ooool01?l0003oooooooooool0001Kooooo`03o`000?oooooooooo06Cooooo00?o0000oooooooo
ool0D_ooool00ol0003oooooooooo`1Booooo`005?ooool00ol0003oooooo`000007ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo04Wooooo1?l0001Looooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0
D_ooool00ol0003oooooooooo`1Aooooo`005?ooool00ol0003oooooo`000007ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo0?oooooo^_ooool001Cooooo00Co0000oooooooooooo00001_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`3ooooooh3ooooo00?oMgMgofIVI_ooool0;Oooool00omVIVKoMgMgooooo`07ooooo`004oooool0
1Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0oooooomoooooo`03omgMgOl@
413ok^k^02kooooo00?ok^k^oa0@4?oMgMd01oooool001?ooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Gooooo0_l0003oooooofKooooo0_l00002ooooo`;o00003?oo
ool00omEEEGoV9RHooooo`02o`0000;ooooo00Oo0000oooooooooooo0000oa0@4?o^k^koEEEE00;o
000000?oA4A4okZj^_ooool00_ooool01OnHV9So0000o`000?m4A4Co^[Zj00;ooooo00Sok^k^oeEE
EOl0003o0000odA4A?nj^[[ooooooa0@40Go00000oooool02?l@413o<S8bo`000?l0003o410@ojVY
ZOn7QhOoIVIV1oooool001;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo1Ol0003oooooofCooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oM
gMd<ooooo`05o`000?ooooooooooooooool000000_ooool02ol0003oooooooooool0003ooooooeEE
EOmgMgOoooooonk^k_mgMgOo410@00?ooooo00Go410@okZj^_o^k^koMgMgoa0@4002ooooo`06oeEE
EOmgMgOoooooonk^k_mgMgOo410@0oooool00ol0003oooooooooo`04ooooo`08o`000?nYZJWooooo
oooooonj^[[o0000onk^k_l00007ooooo`00ool0002do`0000oooooo00CogMgMo`000?l@413oc<c<
3Oooool01Olb<S;ooooooooooooooooo000000;ooooo00Ko0000oooooooooooo0000ooooool00008
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05
ooooo`07okZj^_n7QhOoIVIVofIVI_l@413oooooo`000007ooooo`002_ooool00ol0003oooooo`00
0004ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooo`00
0003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01ol0003ooooooooo
oooooooo0000ooooool000001_ooool4o`0000Gooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo01Oooooo00Cok^k^ob4Q8Ol@413ok^k^3Oooool01Olb
<S;ooooooooooooooooo000000;ooooo00Go0000oooooooooooo0000ooooo`06o`0000?ooooo00?o
0000ooooooooool01?ooool6o`0000?ooooo00?o0000ooooooooool01?ooool02?lb<S;o8B4QogMg
MomgMgOoQhN7onk^k_oooooo00001oooool000[ooooo00?o0000ooooooooool01Ol00006ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooool000000oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Cooooo00Ko0000oooooooooooo0000ooooool0000?ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Gooooo`04ob4Q8OmgMgOo
MgMgoc8b<Pgooooo00Go0000onk^k_ooooooooooo`000002olc<c00;o`000?nYZJWogMgMob4Q8Ooo
ooooEEEEohN7Qoo^k^koooooohN7Qolb<S800oooool00ol0003oooooooooo`04ooooo`06oeEEEOn7
QhOok^k^oooooon7QhOo<S8b0oooool00ol0003o<S8bomgMg@04ooooo`08o`000?nj^[[oooooonk^
k_mgMgOo0000onk^k_l00007ooooo`003oooool2o`0000Oooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
1Ol0003ooooooooooooooooo000003Kooooo00?o0000ooooooooool0Foooool00ol0003ooooooooo
o`1Kooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool05_ooool2o`0000;ooooo0_l0
000<ooooo`0>oeEEEOmgMgOooooooa0@4?l0003o8B4Qo`000?mgMgOo410@o`000?nYZJWoooooonk^
k_mEEED2o`000004odA4A?o^k^kooooooa0@40Go00000oooool01_o^k^koEEEEo`000?l0003oA4A4
onk^kP;ooooo0_l000001?nYZJWo8B4Qo`000?lQ8B42ooooo`08ojVYZOlQ8B7o0000o`000?lb<S;o
0000ogMgMomEEED7ooooo`006?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooooooo
ool00000oooooomlooooo`03omgMgOl@413ok^k^01;ooooo00?o0000ooooooooool06Oooool00oo^
k^ko410@omgMg@07ooooo`006?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo00000?oo
ooooO_ooool00omgMgOoIVIVooooo`0Aooooo`03o`000?oooooooooo01Wooooo00?oIVIVogMgMooo
ool01oooool001Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01Oooool3o`000?oooooo^?ooool001Sooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0ooooooo0ooooo`006?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3ooooool3ooooo000Ioooo
o`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo0?oooooo`?ooool001Wooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0ooooooo0ooooo`006Oooool01Ol0003ooooooooooooooooo
000000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3ooooool3ooooo000Ioooo
o`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo0ol00002ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0ooooooo0ooooo`006Oooool0
1Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3ooooool3ooooo
000Iooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3ooooool3o
oooo000Iooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003o
oooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3ooooo
ol3ooooo000Jooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003o
oooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3ooooo
ol3ooooo000Jooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003o
oooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3ooooo
ol3ooooo000Jooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003o
oooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3ooooo
ol3ooooo000Jooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003o
oooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3ooooo
ol3ooooo000Jooooo`;o00002?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooooooo
ool000001oooool01Ol0003ooooooooooooooooo00000?oooooo`_ooool002Cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`00
003ooooool;ooooo000Tooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00
0007ooooo`05o`000?ooooooooooooooool00000ooooooo2ooooo`009?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`04ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool0003ooooool?o
oooo000Tooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool3o`0000;ooooo
00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooo
oooo0000ooooooo3ooooo`009?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooooooo
ool000001oooool01?l0003oooooooooool0003ooooool?ooooo000Tooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`000?oooooo`ooo
ool002Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Oooooo00Co
0000oooooooooooo0000ooooooo3ooooo`009?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oo
ooooooooooooool000001oooool01?l0003oooooooooool0003ooooool?ooooo000Tooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`00
0?oooooo`oooool002Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000
00Oooooo00Co0000oooooooooooo0000ooooooo3ooooo`009?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04oooo
o`05o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003oooooolCooooo000Toooo
o`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?ooooooa?oo
ool002Cooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Sooooo0_l0003oooooolCooooo
000Tooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000008ooooo`;o0000ooooooo4ooooo`00
9Oooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool01Ol0003ooooooooooooooooo000000Sooooo0_l0003oooooolCooooo000Uooooo`04
o`000?ooooooooooo`0000Oooooo0ol00002ooooo`03o`000?oooooooooo00Cooooo00Go0000oooo
ooooooooooooo`000008ooooo`;o0000ooooooo4ooooo`009Oooool01?l0003oooooooooool00007
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooo
oooo000000Sooooo0_l0003oooooolCooooo000Uooooo`04o`000?ooooooooooo`0000Oooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000
ooooooo>ooooo`009Oooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo00000?ooooooc_ooool002Gooooo
00Co0000oooooooooooo00001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00Go0000ooooooooooooooooo`00003oooooolkooooo000Uooooo`04o`000?ooooooooooo`00
00Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooo
ooooool00000ooooooo>ooooo`003oooool2onk^kP?ooooo0_o^k^h?ooooo`04o`000?oooooooooo
o`0000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooo
ooooooooool00000ooooooo>ooooo`002?ooool5o`0000;ooooo00Ook^k^oeEEEOo^k^koooooonk^
k_mEEEGok^k^00?ooooo1?l000002Ol@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^o`000002
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`05o`000?ooooooooooooooool00000ooooooo>ooooo`002?ooool01OnHV9So8B4Qonk^k_oo
ooooA4A400?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo
00KoMgMgoiRHV?ooooooV9RHogMgMol00002ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000ooooooo>
ooooo`002Oooool00onHV9So8B4Qonk^kP05ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000oooo
ooooool00_ooool01_l@413ooooooooooooooooo410@o`0000;ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooooooo
o`00003oooooolkooooo000:ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Gok^k^oeEEEOoMgMgoEEEE
onk^kP06ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooooooo0_l00002ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05
o`000?ooooooooooooooool00000ooooooo>ooooo`002oooool02omgMgOoIVIVooooooooooook^k^
oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooooooool2o`0000;ooooo00?o0000ooooooooool01Oooool4o`000003ooooool0003ooooo00Go
oooo00Go0000ooooooooooooooooo`00003oooooolkooooo000<ooooo`03o`000?oooooooooo00;o
k^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool01_l@413ooooooooooooooooo410@
o`0000;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00Go0000ooooooooooooooooo`00003oooooolkooooo0008ooooo`05o`000?nj^[[o
oooooiRHV?l@41003_ooool00ol0003oooooooooo`02ooooo`06ogMgMonHV9SooooooiRHV?mgMgOo
00000_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool01Ol0003ooooooooooooooooo00000?ooooooc_ooool000Sooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c00<ooooo`03oeEEEOmVIVKo000000Cooooo00Kok^k^oc8b<_l0003o<S8bonk^k_l0
0002ooooo`;o00001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go
0000ooooooooooooooooo`00003oooooolkooooo000Uooooo`06o`000?oooooo0000o`000?oooooo
00001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooo
ooooooooo`00003oooooolkooooo000Uooooo`06o`000?oooooo0000o`000?oooooo00001Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00
003oooooolkooooo000Uooooo`03o`000?oooooo000000;o00001_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00003oooooolkooooo000U
ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`04ooooo`05o`000?ooooooooooooooool00000ooooooo>ooooo`009_ooool01?l0003oooooo`00
0?l00006ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooo
oooooooooooo00000?ooooooc_ooool002Kooooo00?o0000ooooool000001oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00003oooooolko
oooo000Vooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`04ooooo`05o`000?ooooooooooooooool00000ooooooo>ooooo`009_ooool00ol0003ooooo
o`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooo
oooooooooooo00000?ooooooc_ooool002Kooooo00?o0000ooooool000001oooool3o`0000;ooooo
00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo00000?ooooooc_ooool002Kooooo
00?o0000ooooool000001oooool2o`0000?ooooo00?o0000ooooooooool01?ooool01Ol0003ooooo
oooooooooooo00000?ooooooc_ooool002Kooooo00?o0000ooooool000001oooool2o`0000?ooooo
00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo00000?ooooooc_ooool002Kooooo
00?o0000ooooool000001oooool2o`0000?ooooo00?o0000ooooooooool01?ooool01Ol0003ooooo
oooooooooooo00000?ooooooc_ooool002Kooooo00?o0000ooooool000001oooool2o`0000?ooooo
00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo00000?ooooooc_ooool002Kooooo
00?o0000ooooool000001oooool2o`0000;ooooo00?o0000ooooooooool01Oooool01Ol0003ooooo
oooooooooooo00000?ooooooc_ooool002Kooooo00?o0000ooooool000001oooool2o`0000;ooooo
00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo00000?ooooooc_ooool002Kooooo
00?o0000ooooool000001oooool2o`0000;ooooo00?o0000ooooooooool01Oooool01Ol0003ooooo
oooooooooooo00000?ooooooc_ooool002Kooooo00?o0000ooooool000001oooool2o`0000;ooooo
00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo00000?ooooooc_ooool002Kooooo
00?o0000ooooool000001oooool2o`0000;ooooo00?o0000ooooooooool01Oooool01Ol0003ooooo
oooooooooooo00000?ooooooc_ooool002Kooooo00?o0000ooooool000001oooool2o`0000;ooooo
00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo00000?ooooooc_ooool002Kooooo
0_l00008ooooo`;o00000_ooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool0
0000ooooooo>ooooo`009_ooool2o`0000Sooooo0ol000000ooooooo0000ooooo`07ooooo`04o`00
0?ooooooooooo`000?ooooooc_ooool002Kooooo0_l00008ooooo`;o00000_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooo00000?oooooocoooool002Kooooo0_l00008ooooo`;o00000_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooo00000?oooooocoooool002Kooooo0_l00008
ooooo`;o00000_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo00000?oooooocoooool0
02Kooooo0_l00008ooooo`;o00000_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo0000
0?oooooocoooool002Kooooo0_l00008ooooo`;o00000_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooo00000?oooooocoooool002Kooooo0_l00008ooooo`;o00000_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooo00000?oooooocoooool002Oooooo00?o0000ooooooooool01_oo
ool2o`0000;ooooo00?o0000ooooooooool01_ooool00ol0003oooooo`00003ooooooloooooo000`
ooooo`;o00000_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo00000?oooooocoooool0
033ooooo0_l00002ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooool00000ooooooo?oooo
o`00<?ooool2o`0000;ooooo00?o0000ooooooooool01_ooool00ol0003oooooo`00003ooooooloo
oooo000`ooooo`;o00000_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo00000?oooooo
coooool0033ooooo0ol000000ooooooo0000ooooo`07ooooo`03o`000?oooooo00000?oooooocooo
ool0033ooooo0_l00002ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooool00000ooooooo?
ooooo`00<?ooool2o`0000;ooooo00?o0000ooooooooool01_ooool00ol0003oooooo`00003ooooo
oloooooo000`ooooo`;o00000_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo00000?oo
oooocoooool0033ooooo0_l00002ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooool00000
ooooooo?ooooo`00<?ooool2o`0000;ooooo00?o0000ooooooooool01_ooool00ol0003oooooo`00
003ooooooloooooo000?ooooo`;ok^k^0oooool2onk^kQ[ooooo0_l00002ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooool00000ooooooo?ooooo`002_ooool2o`00000:oa0@4?oooooooooo
onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP?ooooo1?l000002?l@413oooooooooooo^k^ko<S8b
o`000?lb<S;ok^k^2oooool2o`0000;ooooo00?o0000ooooooooool01_ooool00ol0003oooooo`00
003ooooooloooooo000;ooooo`03o`000?oooooooooo00;ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^
kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`;o0000
0_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo00000?oooooocoooool000Sooooo1Ol0
0004ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@00_ooooo0_l00002ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooool00000
ooooooo?ooooo`002?ooool01?m4A4CogMgMooooool00004ooooo`05onk^k_mEEEGogMgMoeEEEOo^
k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000002oooool2o`00
00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooo`00003ooooooloooooo0008ooooo`04
omgMgOmEEEGoooooo`0000?ooooo00Ook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000_ooooo1Ol00008ooooo`03o`00
0?oooooo00000?oooooocoooool000Wooooo00?oMgMgolc<c?l000000oooool2onk^kP?ooooo0_o^
k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400;ooooo`;o0000
0_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo00000?oooooocoooool000Wooooo00?o
k^k^odA4A?l000003oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2oooool2o`0000;ooooo00?o0000ooooooooool01_ooool00ol0003oooooo`00003ooooooloooooo
000:ooooo`03ogMgMol0003ooooo00cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00?ooooo0_l00006ooooo`;o00000_ooool00ol0003oooooooooo`06ooooo`;o0000
ooooooo@ooooo`009oooool01?l0003oooooooooool00005ooooo`;o00000_ooool00ol0003ooooo
ooooo`06ooooo`;o0000ooooooo@ooooo`009oooool01?l0003oooooooooool00005ooooo`;o0000
0_ooool00ol0003oooooooooo`06ooooo`;o0000ooooooo@ooooo`009oooool3o`0000Kooooo0_l0
00000ooooooo0000ooooo`08ooooo`;o0000ooooooo@ooooo`00:?ooool00ol0003oooooooooo`05
ooooo`;o000000?oooooo`000?ooool02?ooool2o`000?ooooood?ooool002Wooooo00?o0000oooo
ooooool01?ooool2o`000003ooooool0003ooooo00Wooooo00?o0000ooooooooool0ooooooo>oooo
o`00<?ooool2o`000003ooooool0003ooooo00Wooooo00?o0000ooooooooool0ooooooo>ooooo`00
<?ooool2o`000003ooooool0003ooooo0?oooooof_ooool0033ooooo0_l000000ooooooo0000oooo
o`3oooooom[ooooo000`ooooo`Co0000oooooooKooooo`00<?ooool2o`000003ooooool0003ooooo
0?oooooof_ooool0033ooooo0_l000000ooooooo0000ooooo`3oooooom[ooooo000`ooooo`;o0000
00?oooooo`000?ooool0oooooooJooooo`00<?ooool2o`000003ooooool0003ooooo0?oooooof_oo
ool0033ooooo0_l000000ooooooo0000ooooo`3oooooom[ooooo000`ooooo`;o000000?oooooo`00
0?ooool0oooooooJooooo`00<?ooool2o`000003ooooool0003ooooo0?oooooof_ooool0033ooooo
0_l000000ooooooo0000ooooo`3oooooom[ooooo000`ooooo`;o000000?oooooo`000?ooool0oooo
oooJooooo`00<?ooool2o`000003ooooool0003ooooo0?oooooof_ooool0033ooooo0_l000000ooo
oooo0000ooooo`3oooooom[ooooo000`ooooo`Co0000oooooooKooooo`00<?ooool01?l0003ooooo
o`000?l0003oooooom_ooooo000`ooooo`04o`000?oooooo0000o`000?oooooofoooool0033ooooo
00Co0000ooooool0003o0000oooooooKooooo`00<?ooool01?l0003oooooo`000?l0003oooooom_o
oooo000`ooooo`04o`000?oooooo0000o`000?oooooofoooool0033ooooo00Co0000ooooool0003o
0000oooooooKooooo`00<?ooool01?l0003oooooo`000?l0003oooooom_ooooo000`ooooo`04o`00
0?oooooo0000o`000?oooooofoooool0033ooooo00Co0000ooooool0003o0000oooooooKooooo`00
<?ooool01?l0003oooooo`000?l0003oooooom_ooooo000`ooooo`04o`000?oooooo0000o`000?oo
oooofoooool0033ooooo1?l0003oooooom_ooooo000`ooooo`04o`000?oooooo0000o`000?oooooo
foooool0033ooooo00Co0000ooooool0003o0000oooooooKooooo`00<?ooool00ol0003oooooo`00
003oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool00?ooooooooooool@oooo
o`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooo
oooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo
002Pooooo`;o00001?ooool00onj^[[o<S8booooo`04ooooo`;o00001_ooool00ol0003o^[Zjoooo
o`3ooooooeOooooo002Pooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`;o<S8boooooomHooooo`00SOooool3o`0000;ooooo00Ko<S8boa0@
4?ooooooooooonk^k_mEEED2o`000003odA4A?nj^[[ooooo00?ooooo00?o0000ooooooooool00_oo
ool01OnHV9So410@o`000?l0003oZJVY00Cooooo00?o0000ooooooooool01?ooool00on7QhOo0000
okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X02Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`Go000000Koooooolc<c?o^k^koooooonk^k_o<c<`4ooooo`Co000000So
410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kQ?ooooo00Ko410@oc8b<_l0003o0000oa0@4?nY
ZJT2ooooo`06onk^k_mEEEGo0000o`000?m4A4Co^[Zj0oooool01OmVIVKo0000o`000?m4A4Coc<c<
0>Sooooo002>ooooo`05o`000?ooooooooooolc<c?l@41000oooool01_mEEEGoMgMgooooooo^k^ko
MgMgoa0@40Cooooo00?o0000ooooooooool00_ooool01_l0003oZJVYoeEEEOnHV9SoEEEEokZj^P?o
oooo00?o0000ooooooooool01?ooool00oo<c<co0000oa0@400<ooooo`06oa0@4?nj^[[ok^k^ogMg
Mol@413ooooo1_l00002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00_o
V9RHob4Q8Oo^k^koooooodA4A?ooooook^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Cooooo`06o`000?nYZJWooooooooooonj^[[o
00000_ooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40;ooooo00KoIVIVogMgMoooooooooooohN7
Qol@413Xooooo`00S_ooool01Ol0003ooooooooooomEEEGoQhN700?ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`02ooooo`06oc8b<_o^k^koV9RHoeEEEOoMgMgo410@0oooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo00_ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@41005?ooool01Onj^[[oQhN7ofIVI_mVIVKo410@00;ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3[ooooo`00S_ooool01Ol0003oooooomgM
gOl0003ok^k^00?ooooo1_l00004ooooo`03o`000?oooooooooo00;ooooo00Oo^[ZjodA4A?o<c<co
8B4Qooooool@413oc<c<00;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`03oooo
o`Ko00000_ooool01Ol0003ooooooooooooooooo000000gooooo00WoV9RHob4Q8Oo^k^koooooonk^
k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000004oooool01_lb<S;o8B4QogMgMomgMgOoQhN7onk^kP;ooooo1_l00002ooooo`03o`000?oo
oooooooo0>_ooooo002>ooooo`?o000000?o410@oiRHV?ooool00_ooool01_mEEEGoQhN7onk^k_oo
ooooQhN7oc8b<PCooooo00?o0000ooooooooool00_ooool01oo^k^ko0000ooooool0003oooooofIV
I_n7QhL00_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00_ooooo00Go0000oooo
ooooooooooooo`00000>ooooo`08ogMgMomVIVKoooooolc<c?o^k^koooooonk^k_o<c<`6ooooo`03
o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Cooooo`06o`000?nj^[[ooooo
onk^k_mgMgOo00000_ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<P;ooooo00KoIVIVogMgMooo
ooooooooohN7Qol0003Xooooo`00S_ooool01Ol0003oooooooooooo<c<co000000?ooooo00Kok^k^
oeEEEOl0003o0000odA4A?o^k^h4ooooo`03o`000?oooooooooo00;ooooo00CoIVIVoiRHV?oooooo
<S8b0_nj^[X01?l0003oooooooooool0000Cooooo`03oa0@4?l0003o000000?o00002_ooool01Ol@
413ooooooooooooooooo410@00oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@41001oooool3o`0000;ooooo0ol00004ooooo`06ojVYZOlQ
8B7o0000o`000?lb<S;o00000_ooool01_o^k^koEEEEo`000?l0003oA4A4onk^kP;ooooo00Kok^k^
ofIVI_l0003o0000odA4A?l0003Xooooo`00S_ooool01Ol0003oooooooooooo<c<co000000gooooo
00?o0000ooooooooool01Oooool00omVIVKoQhN7ooooo`03ooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool02oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oo
ooooV9RHoa0@400<ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0ooooool2ooooo`00SOooool4o`00
0003oa0@4?nYZJWooooo00cooooo0_l00006ooooo`03ojVYZOm4A4Cooooo00;ooooo0_l0000Eoooo
o`03o`000?oooooooooo00_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`02_ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
0_ooool4o`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3oooooo`;ooooo
003oooooo`Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3oooooo`;ooooo003o
ooooo`Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3oooooo`;ooooo003ooooo
o`Gooooo0_l00003ooooo`;o0000ooooool4ooooo`00oooooooooooooa3ooooo003ooooooooooooo
4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oo
ooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@
ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooo
oooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3o
oooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooo
oooooooo4?ooool00001\
\>"],
  ImageRangeCache->{{{0, 525.688}, {324.5, 0}} -> {0, -6.34248*^6, 0, 53093}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0.309017 5.42214e-08 [
[.32684 .29652 -16.5 -12.5 ]
[.32684 .29652 16.5 0 ]
[.54329 .29652 -16.5 -12.5 ]
[.54329 .29652 16.5 0 ]
[.75974 .29652 -22.5 -12.5 ]
[.75974 .29652 22.5 0 ]
[.97619 .29652 -16.5 -12.5 ]
[.97619 .29652 16.5 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 64 6 ]
[.09789 .09213 -34.5 -6.25 ]
[.09789 .09213 0 6.25 ]
[.09789 .20057 -34.5 -6.25 ]
[.09789 .20057 0 6.25 ]
[.09789 .41746 -28.5 -6.25 ]
[.09789 .41746 0 6.25 ]
[.09789 .5259 -28.5 -6.25 ]
[.09789 .5259 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -62.8125 0 ]
[.5 .63053 62.8125 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 .30902 m
.32684 .31527 L
s
gsave
.32684 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 .30902 m
.54329 .31527 L
s
gsave
.54329 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 .30902 m
.75974 .31527 L
s
gsave
.75974 .29652 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 .30902 m
.15368 .31277 L
s
.19697 .30902 m
.19697 .31277 L
s
.24026 .30902 m
.24026 .31277 L
s
.28355 .30902 m
.28355 .31277 L
s
.37013 .30902 m
.37013 .31277 L
s
.41342 .30902 m
.41342 .31277 L
s
.45671 .30902 m
.45671 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.58658 .30902 m
.58658 .31277 L
s
.62987 .30902 m
.62987 .31277 L
s
.67316 .30902 m
.67316 .31277 L
s
.71645 .30902 m
.71645 .31277 L
s
.80303 .30902 m
.80303 .31277 L
s
.84632 .30902 m
.84632 .31277 L
s
.88961 .30902 m
.88961 .31277 L
s
.9329 .30902 m
.9329 .31277 L
s
.0671 .30902 m
.0671 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09213 m
.11664 .09213 L
s
gsave
.09789 .09213 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .20057 m
.11664 .20057 L
s
gsave
.09789 .20057 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .41746 m
.11664 .41746 L
s
gsave
.09789 .41746 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .5259 m
.11664 .5259 L
s
gsave
.09789 .5259 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.11039 .11924 m
.11414 .11924 L
s
.11039 .14635 m
.11414 .14635 L
s
.11039 .17346 m
.11414 .17346 L
s
.11039 .22768 m
.11414 .22768 L
s
.11039 .2548 m
.11414 .2548 L
s
.11039 .28191 m
.11414 .28191 L
s
.11039 .33613 m
.11414 .33613 L
s
.11039 .36324 m
.11414 .36324 L
s
.11039 .39035 m
.11414 .39035 L
s
.11039 .44457 m
.11414 .44457 L
s
.11039 .47168 m
.11414 .47168 L
s
.11039 .49879 m
.11414 .49879 L
s
.11039 .06502 m
.11414 .06502 L
s
.11039 .03791 m
.11414 .03791 L
s
.11039 .0108 m
.11414 .0108 L
s
.11039 .55301 m
.11414 .55301 L
s
.11039 .58012 m
.11414 .58012 L
s
.11039 .60723 m
.11414 .60723 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -123.812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.812 moveto
(@) show
81.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.812 moveto
(D) show
93.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.4) show
135.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
141.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
153.000 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
157.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
166.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
184.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30836 m
.02399 .30835 L
.02418 .30834 L
.02435 .30834 L
.02453 .30834 L
.02464 .30833 L
.02474 .30833 L
.02484 .30833 L
.02494 .30833 L
.02504 .30833 L
.02512 .30833 L
.02522 .30833 L
.02532 .30833 L
.02542 .30834 L
.02552 .30834 L
.02575 .30834 L
.02594 .30835 L
.02615 .30836 L
.02655 .30839 L
.02691 .30842 L
.02775 .30852 L
.02822 .3086 L
.02865 .30869 L
.03029 .30912 L
.0318 .30966 L
.03346 .31038 L
.03516 .31113 L
.03671 .31172 L
.03748 .31194 L
.03769 .31198 L
.03791 .31203 L
.0381 .31206 L
.03831 .31208 L
.03841 .31209 L
.03851 .3121 L
.0386 .31211 L
.03868 .31211 L
.03876 .31212 L
.03885 .31212 L
.03895 .31212 L
.03903 .31212 L
.03914 .31212 L
.03923 .31211 L
.03933 .3121 L
.03944 .3121 L
.03963 .31207 L
.03983 .31204 L
.04003 .312 L
.04025 .31195 L
.04065 .31182 L
Mistroke
.04103 .31166 L
.04139 .31148 L
.0422 .31096 L
.04307 .31021 L
.04479 .30816 L
.04641 .30569 L
.04951 .30059 L
.05034 .29945 L
.05111 .29861 L
.0515 .29828 L
.05192 .29801 L
.05216 .2979 L
.05227 .29786 L
.05238 .29783 L
.05248 .2978 L
.05258 .29779 L
.05269 .29778 L
.05275 .29777 L
.0528 .29777 L
.0529 .29777 L
.053 .29778 L
.0531 .2978 L
.05318 .29782 L
.05328 .29785 L
.05339 .29789 L
.0536 .29798 L
.05381 .29812 L
.05403 .29829 L
.05443 .2987 L
.05479 .29918 L
.05514 .29974 L
.05591 .30135 L
.05675 .30364 L
.05755 .30633 L
.05903 .31257 L
.06211 .32808 L
.06366 .33525 L
.06455 .33845 L
.06495 .33962 L
.06538 .3406 L
.06576 .34124 L
.06597 .3415 L
.06607 .3416 L
.06617 .34168 L
.06626 .34174 L
.06635 .34178 L
.06644 .34181 L
.06652 .34182 L
.06661 .34182 L
.0667 .34181 L
Mistroke
.0668 .34177 L
.06689 .34172 L
.06699 .34165 L
.0671 .34155 L
.06731 .3413 L
.0675 .34098 L
.06768 .34062 L
.06809 .33954 L
.06853 .338 L
.06935 .33396 L
.07025 .32794 L
.07187 .31298 L
.07516 .27247 L
.0768 .25277 L
.0776 .24473 L
.07833 .23879 L
.07869 .23644 L
.07909 .23437 L
.07927 .23361 L
.07946 .23294 L
.07964 .23243 L
.0798 .23208 L
.07989 .23194 L
.07999 .23182 L
.08009 .23174 L
.08019 .23169 L
.08028 .23169 L
.08038 .23173 L
.08047 .23181 L
.08055 .23191 L
.08066 .23208 L
.08076 .23228 L
.08098 .23289 L
.08117 .23362 L
.08138 .23457 L
.08178 .23697 L
.08214 .2398 L
.08295 .24841 L
.08371 .25911 L
.08442 .27154 L
.0875 .34355 L
.08921 .38828 L
.09076 .42368 L
.09154 .43771 L
.09195 .44374 L
.09239 .44898 L
.09276 .45254 L
.09298 .45411 L
.09318 .45526 L
.09327 .4557 L
Mistroke
.09336 .45605 L
.09345 .45632 L
.09353 .45655 L
.09363 .45673 L
.09371 .45684 L
.09381 .45688 L
.09391 .45685 L
.09401 .45674 L
.09411 .45655 L
.09421 .45626 L
.09433 .45585 L
.09453 .45481 L
.09472 .45356 L
.09511 .45009 L
.09547 .44568 L
.09627 .43191 L
.09714 .41107 L
.09874 .35862 L
.10043 .28892 L
.10348 .15907 L
.10428 .13103 L
.10505 .10907 L
.10547 .09923 L
.10592 .09056 L
.10612 .08746 L
.10634 .08466 L
.10652 .08268 L
.10672 .08097 L
.10691 .07979 L
.10702 .07933 L
.10712 .07902 L
.10721 .07884 L
.10729 .07876 L
.10739 .07878 L
.10748 .0789 L
.10757 .07914 L
.10768 .07954 L
.10777 .07998 L
.10786 .08058 L
.10808 .08236 L
.10829 .08458 L
.10866 .08993 L
.10899 .09633 L
.10975 .11588 L
.11054 .14346 L
.11128 .175 L
.11294 .26319 L
.11609 .45232 L
.11691 .49664 L
.11781 .53785 L
Mistroke
.11865 .56858 L
.11906 .58009 L
.11943 .58856 L
.11981 .59517 L
.12001 .59788 L
.12011 .5989 L
.12021 .59983 L
.1203 .6005 L
.12039 .60111 L
.12048 .60153 L
.12056 .60182 L
.12066 .60203 L
.12074 .60209 L
.12084 .60202 L
.12094 .60179 L
.12105 .60138 L
.12114 .60086 L
.12125 .60008 L
.12135 .59917 L
.12154 .59713 L
.12173 .59433 L
.12219 .58566 L
.1226 .57491 L
.12338 .54788 L
.12411 .51517 L
.12577 .41914 L
.12889 .20339 L
.13047 .10647 L
.13137 .06308 L
.1318 .04608 L
.1322 .03251 L
.13259 .02187 L
.13294 .01415 L
.13313 .01086 L
.13333 .00792 L
.13353 .00566 L
.13365 .00472 L
.13375 .00403 L
.13385 .00353 L
.13391 .00333 L
.13397 .00319 L
.13406 .00306 L
.13417 .0031 L
.13426 .00329 L
.13435 .0036 L
.13444 .00408 L
.13455 .00477 L
.13477 .00692 L
.13499 .00976 L
.1354 .01712 L
Mistroke
.1358 .02701 L
.13617 .03811 L
.13699 .06984 L
.13846 .14696 L
.14168 .35778 L
.14316 .44752 L
.14399 .49027 L
.14478 .52303 L
.14555 .54764 L
.14598 .5578 L
.14638 .5647 L
.14659 .56751 L
.14679 .56949 L
.1469 .57029 L
.14701 .57099 L
.14707 .57126 L
.14713 .57151 L
.14719 .57169 L
.14725 .5718 L
.14734 .57191 L
.14744 .57188 L
.14754 .5717 L
.14759 .57154 L
.14765 .57135 L
.14775 .57085 L
.14786 .57013 L
.14807 .56836 L
.14826 .56621 L
.14846 .56334 L
.14883 .55675 L
.14926 .54664 L
.14966 .53536 L
.15135 .46947 L
.15454 .30373 L
.15616 .22523 L
.15762 .16971 L
.15801 .15811 L
.15843 .14735 L
.1588 .13957 L
.1592 .1327 L
.15963 .12732 L
.15986 .12523 L
.15997 .12443 L
.16008 .12381 L
.16017 .12334 L
.16028 .12295 L
.16038 .1227 L
.16047 .12255 L
.16056 .12249 L
.16067 .12254 L
Mistroke
.16072 .12261 L
.16078 .12272 L
.16088 .123 L
.16099 .12341 L
.16109 .12388 L
.1613 .12528 L
.1615 .127 L
.16169 .12897 L
.16212 .13464 L
.16258 .14257 L
.16342 .1614 L
.16419 .18289 L
.16736 .2916 L
.16895 .34388 L
.1704 .38192 L
.17121 .3976 L
.17197 .40852 L
.17238 .41283 L
.17277 .41574 L
.17297 .41686 L
.1732 .41778 L
.17331 .41811 L
.17337 .41826 L
.17343 .41838 L
.17348 .41847 L
.17354 .41855 L
.17365 .41863 L
.17375 .41863 L
.17385 .41858 L
.1739 .41852 L
.17396 .41844 L
.17407 .41823 L
.17417 .41797 L
.17428 .41762 L
.17447 .41683 L
.17486 .41454 L
.17522 .41171 L
.17608 .40226 L
.1769 .39036 L
.17997 .3325 L
.18168 .30065 L
.18323 .27758 L
.18401 .26889 L
.18442 .26517 L
.18485 .26191 L
.18523 .2596 L
.18543 .25859 L
.18565 .25767 L
.18584 .25697 L
.18602 .25645 L
Mistroke
.1862 .25604 L
.18638 .25576 L
.18647 .25565 L
.18657 .25556 L
.18666 .25551 L
.18674 .25549 L
.18684 .25549 L
.18694 .25553 L
.18699 .25556 L
.18705 .2556 L
.18715 .25571 L
.18726 .25585 L
.18737 .25604 L
.18758 .2565 L
.18797 .25768 L
.18835 .2592 L
.18874 .26118 L
.18945 .26559 L
.1925 .29173 L
.19419 .30677 L
.19574 .31813 L
.1965 .32253 L
.19734 .32627 L
.19772 .3276 L
.19813 .32876 L
.19851 .32961 L
.19886 .33017 L
.19904 .3304 L
.19925 .33059 L
.19935 .33067 L
.19946 .33073 L
.19957 .33077 L
.19966 .33079 L
.19976 .3308 L
.19985 .3308 L
.19994 .33079 L
.20005 .33076 L
.20013 .33072 L
.20022 .33068 L
.20041 .33055 L
.20062 .33035 L
.20083 .3301 L
.20121 .32952 L
.20208 .32765 L
.20367 .32282 L
.20514 .31752 L
.20665 .31218 L
.20828 .30728 L
.20918 .30519 L
.21 .30368 L
Mistroke
.21079 .30263 L
.21119 .30225 L
.21139 .30208 L
.21162 .30193 L
.21184 .30182 L
.21204 .30173 L
.21224 .30167 L
.21233 .30165 L
.21244 .30163 L
.21254 .30162 L
.21263 .30161 L
.21272 .30161 L
.21283 .30161 L
.21292 .30162 L
.213 .30162 L
.21309 .30164 L
.21319 .30166 L
.2134 .30171 L
.21364 .3018 L
.21407 .302 L
.21448 .30227 L
.21487 .30257 L
.21803 .30604 L
.21962 .30787 L
.22107 .30927 L
.22182 .30985 L
.22263 .31036 L
.22308 .31058 L
.22349 .31075 L
.22392 .31089 L
.22431 .31099 L
.2245 .31103 L
.22472 .31106 L
.22493 .31109 L
.22505 .3111 L
.22516 .31111 L
.22526 .31112 L
.22536 .31112 L
.22546 .31113 L
.22552 .31113 L
.22557 .31113 L
.22566 .31113 L
.22576 .31113 L
.22586 .31112 L
.22596 .31112 L
.22604 .31112 L
.22614 .31111 L
.22633 .31109 L
.22668 .31105 L
.22708 .31099 L
Mistroke
.22745 .31092 L
.2291 .31047 L
.23059 .30997 L
.23226 .30943 L
.2338 .30902 L
.23458 .30886 L
.2353 .30873 L
.23606 .30863 L
.23646 .3086 L
.23689 .30856 L
.2371 .30855 L
.23732 .30854 L
.23751 .30853 L
.23771 .30852 L
.23782 .30852 L
.23793 .30852 L
.23803 .30851 L
.23813 .30851 L
.23819 .30851 L
.23824 .30851 L
.2383 .30851 L
.23836 .30851 L
.23842 .30851 L
.23848 .30851 L
.23854 .30851 L
.2386 .30851 L
.23869 .30851 L
.23879 .30851 L
.23888 .30851 L
.23897 .30852 L
.23918 .30852 L
.23938 .30853 L
.23978 .30854 L
.24021 .30856 L
.24179 .30866 L
.24347 .30879 L
.24508 .30891 L
.24592 .30897 L
.24681 .30902 L
.24761 .30905 L
.24804 .30907 L
.24849 .30908 L
.24891 .30909 L
.24929 .3091 L
.24967 .30911 L
.25003 .30911 L
.25021 .30911 L
.2504 .30912 L
.25051 .30912 L
.25061 .30912 L
Mistroke
.25071 .30912 L
.25081 .30912 L
.2509 .30912 L
.251 .30912 L
.25105 .30912 L
.25111 .30912 L
.25121 .30912 L
.25131 .30912 L
.25141 .30912 L
.25146 .30912 L
.25152 .30912 L
.25163 .30912 L
.25182 .30912 L
.252 .30912 L
.25239 .30911 L
.25276 .30911 L
.25311 .30911 L
.25618 .30906 L
.25789 .30904 L
.25945 .30902 L
.26023 .30901 L
.26107 .30901 L
.26146 .309 L
.26186 .309 L
.26224 .309 L
.26259 .309 L
.26279 .309 L
.26299 .309 L
.26317 .309 L
.26336 .309 L
.26346 .309 L
.26356 .309 L
.26367 .309 L
.26373 .309 L
.26378 .309 L
.26388 .309 L
.26398 .309 L
.26408 .309 L
.26417 .309 L
.26427 .309 L
.26437 .309 L
.26455 .309 L
.26472 .309 L
.26489 .309 L
.26565 .309 L
.26643 .309 L
.26716 .309 L
.26882 .30901 L
.27031 .30901 L
.27194 .30902 L
Mistroke
.27282 .30902 L
.27364 .30902 L
.27442 .30902 L
.27482 .30902 L
.27503 .30902 L
.27526 .30902 L
.27565 .30902 L
.27586 .30902 L
.27597 .30902 L
.27606 .30902 L
.27616 .30902 L
.27625 .30902 L
.27634 .30902 L
.27642 .30902 L
.27651 .30902 L
.27661 .30902 L
.27671 .30902 L
.27681 .30902 L
.27691 .30902 L
.27702 .30902 L
.27723 .30902 L
.27743 .30902 L
.27761 .30902 L
.27848 .30902 L
.27933 .30902 L
.28013 .30902 L
.28162 .30902 L
.2831 .30902 L
.28394 .30902 L
.28472 .30902 L
.2855 .30902 L
.28632 .30902 L
.28678 .30902 L
.28721 .30902 L
.2876 .30902 L
.2878 .30902 L
.28802 .30902 L
.28822 .30902 L
.28841 .30902 L
.28858 .30902 L
.28877 .30902 L
.28887 .30902 L
.28893 .30902 L
.28898 .30902 L
.28908 .30902 L
.28917 .30902 L
.28922 .30902 L
.28928 .30902 L
.28938 .30902 L
.28943 .30902 L
Mistroke
.28949 .30902 L
.28961 .30902 L
.28971 .30902 L
.28982 .30902 L
.29003 .30902 L
.29042 .30902 L
.29129 .30902 L
.29456 .30902 L
.29618 .30902 L
.29698 .30902 L
.29771 .30902 L
.29842 .30902 L
.29917 .30902 L
.29955 .30902 L
.29991 .30902 L
.30031 .30902 L
.30053 .30902 L
.30074 .30902 L
.30092 .30902 L
.30112 .30902 L
.30123 .30902 L
.30134 .30902 L
.30144 .30902 L
.30154 .30902 L
.30163 .30902 L
.30172 .30902 L
.30181 .30902 L
.30191 .30902 L
.30201 .30902 L
.3021 .30902 L
.30227 .30902 L
.30248 .30902 L
.30269 .30902 L
.30307 .30902 L
.30394 .30902 L
.30699 .30902 L
.30856 .30902 L
.30943 .30902 L
.31023 .30902 L
.31103 .30902 L
.31177 .30902 L
.31215 .30902 L
.31257 .30902 L
.31279 .30902 L
.31302 .30902 L
.31322 .30902 L
.31343 .30902 L
.31354 .30902 L
.31364 .30902 L
.31374 .30902 L
Mistroke
.31383 .30902 L
.31392 .30902 L
.31401 .30902 L
.3141 .30902 L
.3142 .30902 L
.31426 .30902 L
.31431 .30902 L
.31441 .30902 L
.31447 .30902 L
.31452 .30902 L
.31464 .30902 L
.31483 .30902 L
.31504 .30902 L
.3155 .30902 L
.31593 .30902 L
.31674 .30902 L
.31983 .30902 L
.32144 .30902 L
.32224 .30902 L
.32313 .30902 L
.32355 .30902 L
.32395 .30902 L
.32431 .30902 L
.3247 .30902 L
.32512 .30902 L
.3255 .30902 L
.32572 .30902 L
.32592 .30902 L
.32603 .30902 L
.32614 .30902 L
.32627 .30902 L
.32632 .30902 L
.32638 .30902 L
.32648 .30902 L
.32653 .30902 L
.32659 .30902 L
.32668 .30902 L
.32678 .30902 L
.32687 .30902 L
.32697 .30902 L
.32706 .30902 L
.32715 .30902 L
.32735 .30902 L
.32757 .30902 L
.32797 .30902 L
.32873 .30902 L
.32944 .30902 L
.33107 .30902 L
.33259 .30902 L
.33405 .30902 L
Mistroke
.33487 .30902 L
.33562 .30902 L
.336 .30902 L
.33641 .30902 L
.33676 .30902 L
.33714 .30902 L
.33737 .30902 L
.33758 .30902 L
.33779 .30902 L
.33801 .30902 L
.3382 .30902 L
.33839 .30902 L
.33849 .30902 L
.33859 .30902 L
.3387 .30902 L
.3388 .30902 L
.3389 .30902 L
.33895 .30902 L
.33901 .30902 L
.3391 .30902 L
.3392 .30902 L
.33929 .30902 L
.33938 .30902 L
.33947 .30902 L
.33957 .30902 L
.33979 .30902 L
.34 .30902 L
.34039 .30902 L
.34187 .30902 L
.34333 .30902 L
.34494 .30902 L
.34571 .30902 L
.34653 .30902 L
.3474 .30902 L
.34783 .30902 L
.34822 .30902 L
.34899 .30902 L
.34939 .30902 L
.34983 .30902 L
.35005 .30902 L
.35029 .30902 L
.35051 .30902 L
.35072 .30902 L
.3509 .30902 L
.35101 .30902 L
.35111 .30902 L
.35121 .30902 L
.35131 .30902 L
.35136 .30902 L
.35142 .30902 L
Mistroke
.35152 .30902 L
.35158 .30902 L
.35163 .30902 L
.35173 .30902 L
.35184 .30902 L
.35195 .30902 L
.35235 .30902 L
.35274 .30902 L
.35311 .30902 L
.35479 .30902 L
.35629 .30902 L
.35792 .30902 L
.35881 .30902 L
.35963 .30902 L
.36041 .30902 L
.36081 .30902 L
.36125 .30902 L
.36166 .30902 L
.36206 .30902 L
.36242 .30902 L
.36262 .30902 L
.3628 .30902 L
.36291 .30902 L
.36302 .30902 L
.36312 .30902 L
.36323 .30902 L
.36332 .30902 L
.36343 .30902 L
.36353 .30902 L
.36361 .30902 L
.36367 .30902 L
.36373 .30902 L
.36378 .30902 L
.36383 .30902 L
.36393 .30902 L
.36403 .30902 L
.36424 .30902 L
.36448 .30902 L
.36487 .30902 L
.36529 .30902 L
.36603 .30902 L
.36771 .30902 L
.36931 .30902 L
.37001 .30902 L
.37076 .30902 L
.37157 .30902 L
.37234 .30902 L
.37276 .30902 L
.37321 .30902 L
.3736 .30902 L
Mistroke
.37402 .30902 L
.37422 .30902 L
.37444 .30902 L
.37463 .30902 L
.37483 .30902 L
.37504 .30902 L
.37522 .30902 L
.37531 .30902 L
.37541 .30902 L
.3755 .30902 L
.37558 .30902 L
.37568 .30902 L
.37578 .30902 L
.37588 .30902 L
.37597 .30902 L
.37607 .30902 L
.37613 .30902 L
.37619 .30902 L
.3764 .30902 L
.37659 .30902 L
.37681 .30902 L
.37726 .30902 L
.37894 .30902 L
.38049 .30902 L
.382 .30902 L
.38276 .30902 L
.3836 .30902 L
.38402 .30902 L
.38442 .30902 L
.38517 .30902 L
.38559 .30902 L
.38598 .30902 L
.3864 .30902 L
.38662 .30902 L
.38685 .30902 L
.38706 .30902 L
.38727 .30902 L
.38737 .30902 L
.38748 .30902 L
.38757 .30902 L
.38767 .30902 L
.38777 .30902 L
.38785 .30902 L
.38794 .30902 L
.38803 .30902 L
.38812 .30902 L
.38821 .30902 L
.38831 .30902 L
.38842 .30902 L
.38863 .30902 L
Mistroke
.38887 .30902 L
.3893 .30902 L
.3901 .30902 L
.39166 .30902 L
.39249 .30902 L
.39338 .30902 L
.39423 .30902 L
.39501 .30902 L
.39579 .30902 L
.39654 .30902 L
.39694 .30902 L
.39731 .30902 L
.3977 .30902 L
.39813 .30902 L
.39852 .30902 L
.3987 .30902 L
.39889 .30902 L
.39906 .30902 L
.39924 .30902 L
.39943 .30902 L
.3996 .30902 L
.3997 .30902 L
.39981 .30902 L
.39986 .30902 L
.39992 .30902 L
.40003 .30902 L
.40013 .30902 L
.40023 .30902 L
.40032 .30902 L
.40042 .30902 L
.40054 .30902 L
.40064 .30902 L
.40088 .30902 L
.40131 .30902 L
.40214 .30902 L
.40292 .30902 L
.40439 .30902 L
.40523 .30902 L
.40601 .30902 L
.40678 .30902 L
.40761 .30902 L
.40806 .30902 L
.40849 .30902 L
.40891 .30902 L
.4093 .30902 L
.40967 .30902 L
.41007 .30902 L
.41029 .30902 L
.41049 .30902 L
.4107 .30902 L
Mistroke
.41089 .30902 L
.41123 .30902 L
.41142 .30902 L
.41161 .30902 L
.41171 .30902 L
.41181 .30902 L
.41191 .30902 L
.41201 .30902 L
.41209 .30902 L
.41218 .30902 L
.41228 .30902 L
.41237 .30902 L
.41247 .30902 L
.41257 .30902 L
.41277 .30902 L
.41299 .30902 L
.4132 .30902 L
.41399 .30902 L
.41548 .30902 L
.41629 .30902 L
.41715 .30902 L
.41795 .30902 L
.41869 .30902 L
.4194 .30902 L
.42017 .30902 L
.4206 .30902 L
.42101 .30902 L
.42141 .30902 L
.42179 .30902 L
.42215 .30902 L
.42237 .30902 L
.42256 .30902 L
.42296 .30902 L
.42316 .30902 L
.42338 .30902 L
.42356 .30902 L
.42366 .30902 L
.42375 .30902 L
.42383 .30902 L
.42392 .30902 L
.42401 .30902 L
.42409 .30902 L
.42418 .30902 L
.42427 .30902 L
.42436 .30902 L
.42446 .30902 L
.42457 .30902 L
.42467 .30902 L
.42486 .30902 L
.42526 .30902 L
Mistroke
.42563 .30902 L
.42645 .30902 L
.42793 .30902 L
.42948 .30902 L
.43035 .30902 L
.43115 .30902 L
.43193 .30902 L
.43266 .30902 L
.43308 .30902 L
.43346 .30902 L
.4339 .30902 L
.43432 .30902 L
.43469 .30902 L
.4349 .30902 L
.4351 .30902 L
.4353 .30902 L
.43549 .30902 L
.43559 .30902 L
.4357 .30902 L
.43575 .30902 L
.43581 .30902 L
.43592 .30902 L
.43602 .30902 L
.43611 .30902 L
.43621 .30902 L
.43626 .30902 L
.43632 .30902 L
.43641 .30902 L
.43651 .30902 L
.43669 .30902 L
.43688 .30902 L
.43706 .30902 L
.4374 .30902 L
.44047 .30902 L
.44129 .30902 L
.44205 .30902 L
.44294 .30902 L
.44332 .30902 L
.44374 .30902 L
.44453 .30902 L
.44496 .30902 L
.44536 .30902 L
.44573 .30902 L
.44607 .30902 L
.44626 .30902 L
.44647 .30902 L
.44684 .30902 L
.44703 .30902 L
.44723 .30902 L
.44733 .30902 L
Mistroke
.44742 .30902 L
.44751 .30902 L
.4476 .30902 L
.4477 .30902 L
.44775 .30902 L
.44781 .30902 L
.4479 .30902 L
.448 .30902 L
.44805 .30902 L
.44811 .30902 L
.44817 .30902 L
.44822 .30902 L
.44832 .30902 L
.44843 .30902 L
.44865 .30902 L
.44889 .30902 L
.44932 .30902 L
.45012 .30902 L
.45168 .30902 L
.4525 .30902 L
.45339 .30902 L
.45424 .30902 L
.45502 .30902 L
.45576 .30902 L
.45614 .30902 L
.45655 .30902 L
.45697 .30902 L
.45737 .30902 L
.45773 .30902 L
.45812 .30902 L
.45832 .30902 L
.45854 .30902 L
.45878 .30902 L
.45899 .30902 L
.4591 .30902 L
.4592 .30902 L
.45938 .30902 L
.45949 .30902 L
.45958 .30902 L
.45969 .30902 L
.45975 .30902 L
.4598 .30902 L
.4599 .30902 L
.45999 .30902 L
.46009 .30902 L
.46019 .30902 L
.46031 .30902 L
.46041 .30902 L
.46061 .30902 L
.46096 .30902 L
Mistroke
.46135 .30902 L
.46302 .30902 L
.46461 .30902 L
.46541 .30902 L
.4663 .30902 L
.46669 .30902 L
.46711 .30902 L
.46785 .30902 L
.46827 .30902 L
.46866 .30902 L
.46908 .30902 L
.46953 .30902 L
.46974 .30902 L
.46996 .30902 L
.47035 .30902 L
.47057 .30902 L
.47078 .30902 L
.471 .30902 L
.47113 .30902 L
.47125 .30902 L
.47135 .30902 L
.4714 .30902 L
.47145 .30902 L
.47155 .30902 L
.47164 .30902 L
.4717 .30902 L
.47175 .30902 L
.47185 .30902 L
.47191 .30902 L
.47196 .30902 L
.47208 .30902 L
.47228 .30902 L
.47246 .30902 L
.47286 .30902 L
.47453 .30902 L
.47526 .30902 L
.47607 .30902 L
.47679 .30902 L
.47757 .30902 L
.47839 .30902 L
.47916 .30902 L
.47958 .30902 L
.47997 .30902 L
.4804 .30902 L
.48085 .30902 L
.48129 .30902 L
.4815 .30902 L
.4817 .30902 L
.48207 .30902 L
.48226 .30902 L
Mistroke
.48247 .30902 L
.48267 .30902 L
.48277 .30902 L
.48287 .30902 L
.48295 .30902 L
.48304 .30902 L
.48313 .30902 L
.48323 .30902 L
.48333 .30902 L
.48343 .30902 L
.48348 .30902 L
.48354 .30902 L
.4836 .30902 L
.48365 .30902 L
.48375 .30902 L
.48384 .30902 L
.48404 .30902 L
.48441 .30902 L
.4848 .30902 L
.48552 .30902 L
.48708 .30902 L
.48791 .30902 L
.4888 .30902 L
.48966 .30902 L
.49044 .30902 L
.49081 .30902 L
.49122 .30902 L
.49158 .30902 L
.49197 .30902 L
.49239 .30902 L
.4928 .30902 L
.49319 .30902 L
.49355 .30902 L
.49375 .30902 L
.49394 .30902 L
.49415 .30902 L
.49437 .30902 L
.49448 .30902 L
.4946 .30902 L
.49472 .30902 L
.49482 .30902 L
.49492 .30902 L
.49502 .30902 L
.49507 .30902 L
.49513 .30902 L
.49523 .30902 L
.49529 .30902 L
.49534 .30902 L
.49544 .30902 L
.49554 .30902 L
Mistroke
.49565 .30902 L
.49604 .30902 L
.49693 .30902 L
.49854 .30902 L
.49937 .30902 L
.50014 .30902 L
.50095 .30902 L
.50137 .30902 L
.50183 .30902 L
.50227 .30902 L
.50267 .30902 L
.50305 .30902 L
.50346 .30902 L
.50384 .30902 L
.50419 .30902 L
.50456 .30902 L
.50475 .30902 L
.50495 .30902 L
.50516 .30902 L
.50535 .30902 L
.50554 .30902 L
.50572 .30902 L
.50593 .30902 L
.50604 .30902 L
.50615 .30902 L
.50625 .30902 L
.50635 .30902 L
.50641 .30902 L
.50646 .30902 L
.50656 .30902 L
.50667 .30902 L
.50672 .30902 L
.50678 .30902 L
.50688 .30902 L
.50698 .30902 L
.50703 .30902 L
.50709 .30902 L
.5072 .30902 L
.50743 .30902 L
.50782 .30902 L
.50826 .30902 L
.50995 .30902 L
.51076 .30902 L
.5115 .30902 L
.51227 .30902 L
.51267 .30902 L
.51311 .30902 L
.51385 .30902 L
.51425 .30902 L
.51463 .30902 L
Mistroke
.51504 .30902 L
.51542 .30902 L
.51582 .30902 L
.51625 .30902 L
.51663 .30902 L
.51697 .30902 L
.51716 .30902 L
.51737 .30902 L
.51756 .30902 L
.51774 .30902 L
.51784 .30902 L
.51793 .30902 L
.51802 .30902 L
.51811 .30902 L
.51822 .30902 L
.51827 .30902 L
.51832 .30902 L
.51842 .30902 L
.51852 .30902 L
.51861 .30902 L
.5187 .30902 L
.51887 .30902 L
.51905 .30902 L
.51925 .30902 L
.5209 .30902 L
.52178 .30902 L
.52261 .30902 L
.52335 .30902 L
.52416 .30902 L
.52495 .30902 L
.52534 .30902 L
.52578 .30902 L
.52616 .30902 L
.52656 .30902 L
.52694 .30902 L
.52729 .30902 L
.52767 .30902 L
.52788 .30902 L
.52808 .30902 L
.52826 .30902 L
.52846 .30902 L
.52864 .30902 L
.52881 .30902 L
.52901 .30902 L
.52913 .30902 L
.52923 .30902 L
.52933 .30902 L
.52945 .30902 L
.52951 .30902 L
.52956 .30902 L
Mistroke
.52962 .30902 L
.52968 .30902 L
.52977 .30902 L
.52986 .30902 L
.52997 .30902 L
.53006 .30902 L
.53016 .30902 L
.53026 .30902 L
.53047 .30902 L
.53068 .30902 L
.5309 .30902 L
.5313 .30902 L
.53205 .30902 L
.53285 .30902 L
.53373 .30902 L
.53455 .30902 L
.53533 .30902 L
.53614 .30902 L
.5366 .30902 L
.53701 .30902 L
.5374 .30902 L
.53781 .30902 L
.53819 .30902 L
.53854 .30902 L
.53895 .30902 L
.53917 .30902 L
.5394 .30902 L
.5396 .30902 L
.53982 .30902 L
.54002 .30902 L
.54021 .30902 L
.54041 .30902 L
.54063 .30902 L
.54082 .30902 L
.54092 .30902 L
.54103 .30902 L
.54113 .30902 L
.54121 .30902 L
.54131 .30902 L
.54141 .30902 L
.5415 .30902 L
.54159 .30902 L
.54168 .30902 L
.54178 .30902 L
.54199 .30902 L
.54223 .30902 L
.54266 .30902 L
.54346 .30902 L
.54502 .30902 L
.54591 .30902 L
Mistroke
.54675 .30902 L
.54716 .30902 L
.54754 .30902 L
.54827 .30902 L
.54868 .30902 L
.54906 .30902 L
.54947 .30902 L
.54991 .30902 L
.5503 .30902 L
.55066 .30902 L
.55106 .30902 L
.55126 .30902 L
.55147 .30902 L
.55166 .30902 L
.55184 .30902 L
.55205 .30902 L
.55214 .30902 L
.55223 .30902 L
.55232 .30902 L
.55241 .30902 L
.55249 .30902 L
.55257 .30902 L
.55266 .30902 L
.55276 .30902 L
.55285 .30902 L
.55294 .30902 L
.55304 .30902 L
.5531 .30902 L
.55315 .30902 L
.55334 .30902 L
.55352 .30902 L
.55371 .30902 L
.55453 .30902 L
.55601 .30902 L
.55677 .30902 L
.55759 .30902 L
.55836 .30902 L
.55906 .30902 L
.55944 .30902 L
.55986 .30902 L
.56021 .30902 L
.56059 .30902 L
.561 .30902 L
.56138 .30902 L
.56161 .30902 L
.56184 .30902 L
.56206 .30902 L
.56226 .30902 L
.56245 .30902 L
.56266 .30902 L
Mistroke
.56303 .30902 L
.56323 .30902 L
.56345 .30902 L
.56364 .30902 L
.56375 .30902 L
.56384 .30902 L
.56394 .30902 L
.56404 .30902 L
.56413 .30902 L
.56422 .30902 L
.5643 .30902 L
.56438 .30902 L
.56447 .30902 L
.56456 .30902 L
.56465 .30902 L
.56475 .30902 L
.56492 .30902 L
.56532 .30902 L
.56692 .30902 L
.56762 .30902 L
.56837 .30902 L
.56918 .30902 L
.56994 .30902 L
.57037 .30902 L
.57082 .30902 L
.57124 .30902 L
.57162 .30902 L
.57199 .30902 L
.57238 .30902 L
.5728 .30902 L
.57319 .30902 L
.57356 .30902 L
.57376 .30902 L
.57395 .30902 L
.57413 .30902 L
.57432 .30902 L
.5745 .30902 L
.57466 .30902 L
.57485 .30902 L
.57495 .30902 L
.57506 .30902 L
.57515 .30902 L
.57524 .30902 L
.57533 .30902 L
.57542 .30902 L
.57552 .30902 L
.57558 .30902 L
.57563 .30902 L
.57572 .30902 L
.57582 .30902 L
Mistroke
.57587 .30902 L
.57593 .30902 L
.57603 .30902 L
.57626 .30902 L
.57672 .30902 L
.57715 .30902 L
.57795 .30902 L
.57873 .30902 L
.57956 .30902 L
.58026 .30902 L
.58104 .30902 L
.58146 .30902 L
.58185 .30902 L
.5826 .30902 L
.58302 .30902 L
.5834 .30902 L
.58383 .30902 L
.58428 .30902 L
.58449 .30902 L
.58471 .30902 L
.5851 .30902 L
.58532 .30902 L
.58553 .30902 L
.58576 .30902 L
.586 .30902 L
.58621 .30902 L
.58632 .30902 L
.58643 .30902 L
.58653 .30902 L
.58663 .30902 L
.58669 .30902 L
.58674 .30902 L
.58685 .30902 L
.58694 .30902 L
.58704 .30902 L
.58709 .30902 L
.58715 .30902 L
.58725 .30902 L
.58735 .30902 L
.58744 .30902 L
.58762 .30902 L
.5884 .30902 L
.58923 .30902 L
.59071 .30902 L
.59147 .30902 L
.59189 .30902 L
.59228 .30902 L
.59265 .30902 L
.59305 .30902 L
.59375 .30902 L
Mistroke
.59414 .30902 L
.59451 .30902 L
.59491 .30902 L
.59534 .30902 L
.59577 .30902 L
.59598 .30902 L
.59622 .30902 L
.59642 .30902 L
.59664 .30902 L
.59682 .30902 L
.59702 .30902 L
.59723 .30902 L
.59734 .30902 L
.59745 .30902 L
.59756 .30902 L
.59765 .30902 L
.59775 .30902 L
.59784 .30902 L
.5979 .30902 L
.59796 .30902 L
.59806 .30902 L
.59812 .30902 L
.59819 .30902 L
.59825 .30902 L
.5983 .30902 L
.5984 .30902 L
.59846 .30902 L
.59851 .30902 L
.59862 .30902 L
.59874 .30902 L
.59917 .30902 L
.59958 .30902 L
.60035 .30902 L
.60113 .30902 L
.60195 .30902 L
.60265 .30902 L
.60343 .30902 L
.60382 .30902 L
.60424 .30902 L
.60498 .30902 L
.6054 .30902 L
.60578 .30902 L
.60621 .30902 L
.60666 .30902 L
.60687 .30902 L
.60709 .30902 L
.60748 .30902 L
.6077 .30902 L
.60791 .30902 L
.60813 .30902 L
Mistroke
.60837 .30902 L
.60858 .30902 L
.6087 .30902 L
.60881 .30902 L
.60891 .30902 L
.60901 .30902 L
.60906 .30902 L
.60912 .30902 L
.60922 .30902 L
.60931 .30902 L
.60941 .30902 L
.60947 .30902 L
.60952 .30902 L
.60962 .30902 L
.60972 .30902 L
.60981 .30902 L
.60999 .30902 L
.61036 .30902 L
.61077 .30902 L
.61159 .30902 L
.61235 .30902 L
.61307 .30902 L
.61388 .30902 L
.61463 .30902 L
.61504 .30902 L
.61543 .30902 L
.61585 .30902 L
.6163 .30902 L
.61675 .30902 L
.61715 .30902 L
.61754 .30902 L
.61795 .30902 L
.61832 .30902 L
.61866 .30902 L
.61886 .30902 L
.61904 .30902 L
.61923 .30902 L
.61944 .30902 L
.61964 .30902 L
.61983 .30902 L
.62003 .30902 L
.62014 .30902 L
.62024 .30902 L
.62033 .30902 L
.62041 .30902 L
.6205 .30902 L
.6206 .30902 L
.6207 .30902 L
.62079 .30902 L
.62088 .30902 L
Mistroke
.62097 .30902 L
.62117 .30902 L
.62139 .30902 L
.62184 .30902 L
.62264 .30902 L
.62344 .30902 L
.6242 .30902 L
.62462 .30902 L
.62508 .30902 L
.62588 .30902 L
.6263 .30902 L
.62671 .30902 L
.62707 .30902 L
.62746 .30902 L
.62788 .30902 L
.62827 .30902 L
.62868 .30902 L
.6289 .30902 L
.62914 .30902 L
.62936 .30902 L
.62956 .30902 L
.62975 .30902 L
.62996 .30902 L
.63032 .30902 L
.63052 .30902 L
.63071 .30902 L
.63092 .30902 L
.63102 .30902 L
.63113 .30902 L
.63123 .30902 L
.63133 .30902 L
.63143 .30902 L
.63152 .30902 L
.63157 .30902 L
.63163 .30902 L
.63173 .30902 L
.63179 .30902 L
.63184 .30902 L
.6319 .30902 L
.63197 .30902 L
.63202 .30902 L
.63208 .30902 L
.63219 .30902 L
.63239 .30902 L
.63278 .30902 L
.63314 .30902 L
.63397 .30902 L
.63479 .30902 L
.63566 .30902 L
.63643 .30902 L
Mistroke
.63687 .30902 L
.63728 .30902 L
.63799 .30902 L
.63839 .30902 L
.63876 .30902 L
.63915 .30902 L
.63956 .30902 L
.63991 .30902 L
.6403 .30902 L
.64071 .30902 L
.64094 .30902 L
.64116 .30902 L
.64136 .30902 L
.64157 .30902 L
.64178 .30902 L
.64196 .30902 L
.64207 .30902 L
.64218 .30902 L
.64227 .30902 L
.64237 .30902 L
.64248 .30902 L
.64258 .30902 L
.64264 .30902 L
.6427 .30902 L
.64276 .30902 L
.64281 .30902 L
.64291 .30902 L
.64301 .30902 L
.64307 .30902 L
.64312 .30902 L
.64323 .30902 L
.64343 .30902 L
.64361 .30902 L
.64511 .30902 L
.64584 .30902 L
.64662 .30902 L
.64708 .30902 L
.64749 .30902 L
.64829 .30902 L
.64868 .30902 L
.64909 .30902 L
.64944 .30902 L
.64983 .30902 L
.65024 .30902 L
.65069 .30902 L
.65111 .30902 L
.6515 .30902 L
.65188 .30902 L
.65209 .30902 L
.65229 .30902 L
Mistroke
.65247 .30902 L
.65267 .30902 L
.65285 .30902 L
.65302 .30902 L
.65312 .30902 L
.65322 .30902 L
.65331 .30902 L
.65341 .30902 L
.65352 .30902 L
.65358 .30902 L
.65363 .30902 L
.65374 .30902 L
.65383 .30902 L
.65393 .30902 L
.65399 .30902 L
.65404 .30902 L
.65414 .30902 L
.65424 .30902 L
.65435 .30902 L
.65445 .30902 L
.65469 .30902 L
.65619 .30902 L
.65699 .30902 L
.65783 .30902 L
.65825 .30902 L
.65872 .30902 L
.65915 .30902 L
.65954 .30902 L
.65995 .30902 L
.66038 .30902 L
.66078 .30902 L
.66116 .30902 L
.66153 .30902 L
.66193 .30902 L
.66214 .30902 L
.66236 .30902 L
.66255 .30902 L
.66276 .30902 L
.66313 .30902 L
.66334 .30902 L
.66353 .30902 L
.6637 .30902 L
.66387 .30902 L
.66406 .30902 L
.66424 .30902 L
.66433 .30902 L
.66443 .30902 L
.66452 .30902 L
.66461 .30902 L
.66471 .30902 L
Mistroke
.66476 .30902 L
.66482 .30902 L
.66491 .30902 L
.66501 .30902 L
.66507 .30902 L
.66512 .30902 L
.66518 .30902 L
.66524 .30902 L
.66545 .30902 L
.66563 .30902 L
.66584 .30902 L
.66732 .30902 L
.66813 .30902 L
.66889 .30902 L
.66931 .30902 L
.66977 .30902 L
.67018 .30902 L
.67057 .30902 L
.67096 .30902 L
.67132 .30902 L
.67172 .30902 L
.67216 .30902 L
.67255 .30902 L
.67298 .30902 L
.67319 .30902 L
.67343 .30902 L
.67384 .30902 L
.67405 .30902 L
.67427 .30902 L
.67446 .30902 L
.67466 .30902 L
.67489 .30902 L
.67501 .30902 L
.67513 .30902 L
.67523 .30902 L
.67535 .30902 L
.67546 .30902 L
.67556 .30902 L
.67566 .30902 L
.67572 .30902 L
.67577 .30902 L
.67587 .30902 L
.67597 .30902 L
.67606 .30902 L
.67615 .30902 L
.67624 .30902 L
.67634 .30902 L
.67678 .30902 L
.67717 .30902 L
.67798 .30902 L
Mistroke
.67884 .30902 L
.67957 .30902 L
.67999 .30902 L
.68038 .30902 L
.68115 .30902 L
.68157 .30902 L
.68197 .30902 L
.68234 .30902 L
.68268 .30902 L
.68306 .30902 L
.68346 .30902 L
.68367 .30902 L
.68389 .30902 L
.68429 .30902 L
.68451 .30902 L
.68471 .30902 L
.68495 .30902 L
.68518 .30902 L
.68537 .30902 L
.68559 .30902 L
.68578 .30902 L
.68596 .30902 L
.68615 .30902 L
.68626 .30902 L
.68637 .30902 L
.68642 .30902 L
.68647 .30902 L
.68657 .30902 L
.68663 .30902 L
.68668 .30902 L
.68674 .30902 L
.6868 .30902 L
.6869 .30902 L
.68695 .30902 L
.68701 .30902 L
.68711 .30902 L
.68723 .30902 L
.68743 .30902 L
.68762 .30902 L
.68851 .30902 L
.68935 .30902 L
.69013 .30902 L
.69087 .30902 L
.69128 .30902 L
.69165 .30902 L
.69207 .30902 L
.69251 .30902 L
.69293 .30902 L
.69332 .30902 L
.6937 .30902 L
Mistroke
.6941 .30902 L
.69448 .30902 L
.69483 .30902 L
.69524 .30902 L
.69547 .30902 L
.69568 .30902 L
.69608 .30902 L
.69627 .30902 L
.69649 .30902 L
.69668 .30902 L
.69689 .30902 L
.69699 .30902 L
.6971 .30902 L
.69721 .30902 L
.6973 .30902 L
.6974 .30902 L
.69749 .30902 L
.69758 .30902 L
.69769 .30902 L
.69777 .30902 L
.69786 .30902 L
.69795 .30902 L
.69805 .30902 L
.69826 .30902 L
.6985 .30902 L
.69892 .30902 L
.69972 .30902 L
.70054 .30902 L
.70131 .30902 L
.70211 .30902 L
.70253 .30902 L
.70299 .30902 L
.70339 .30902 L
.70376 .30902 L
.70416 .30902 L
.7046 .30902 L
.70482 .30902 L
.70505 .30902 L
.70526 .30902 L
.70548 .30902 L
.70568 .30902 L
.7059 .30902 L
.70629 .30902 L
.70649 .30902 L
.70671 .30902 L
.7069 .30902 L
.7071 .30902 L
.70731 .30902 L
.70749 .30902 L
.70768 .30902 L
Mistroke
.70785 .30902 L
.70795 .30902 L
.70805 .30902 L
.70816 .30902 L
.70827 .30902 L
.70837 .30902 L
.70845 .30902 L
.70856 .30902 L
.70865 .30902 L
.70876 .30902 L
.70881 .30902 L
.70887 .30902 L
.70907 .30902 L
.70931 .30902 L
.70952 .30902 L
.71101 .30902 L
.71185 .30902 L
.71226 .30902 L
.71263 .30902 L
.71341 .30902 L
.71384 .30902 L
.71424 .30902 L
.71466 .30902 L
.71505 .30902 L
.71548 .30902 L
.71593 .30902 L
.71633 .30902 L
.71669 .30902 L
.71689 .30902 L
.71711 .30902 L
.71732 .30902 L
.71751 .30902 L
.71768 .30902 L
.71788 .30902 L
.71808 .30902 L
.71827 .30902 L
.71845 .30902 L
.71864 .30902 L
.7188 .30902 L
.71889 .30902 L
.71898 .30902 L
.71908 .30902 L
.71913 .30902 L
.71919 .30902 L
.71929 .30902 L
.71938 .30902 L
.71944 .30902 L
.71949 .30902 L
.71959 .30902 L
.71965 .30902 L
Mistroke
.7197 .30902 L
.71982 .30902 L
.7202 .30902 L
.72061 .30902 L
.7221 .30902 L
.72293 .30902 L
.72339 .30902 L
.72382 .30902 L
.72423 .30902 L
.72461 .30902 L
.725 .30902 L
.72544 .30902 L
.72584 .30902 L
.72628 .30902 L
.72669 .30902 L
.72707 .30902 L
.72741 .30902 L
.72779 .30902 L
.72798 .30902 L
.72819 .30902 L
.72856 .30902 L
.72875 .30902 L
.72896 .30902 L
.72915 .30902 L
.72933 .30902 L
.72944 .30902 L
.72954 .30902 L
.72964 .30902 L
.7297 .30902 L
.72976 .30902 L
.72986 .30902 L
.72995 .30902 L
.73001 .30902 L
.73007 .30902 L
.73017 .30902 L
.73022 .30902 L
.73027 .30902 L
.73037 .30902 L
.73048 .30902 L
.73059 .30902 L
.73098 .30902 L
.73186 .30902 L
.73269 .30902 L
.73346 .30902 L
.73385 .30902 L
.73427 .30902 L
.73473 .30902 L
.73515 .30902 L
.73554 .30902 L
.73595 .30902 L
Mistroke
.7363 .30902 L
.73669 .30902 L
.7371 .30902 L
.73732 .30902 L
.73755 .30902 L
.73775 .30902 L
.73797 .30902 L
.73836 .30902 L
.73856 .30902 L
.73878 .30902 L
.73897 .30902 L
.73918 .30902 L
.73937 .30902 L
.73957 .30902 L
.73976 .30902 L
.73993 .30902 L
.74004 .30902 L
.74015 .30902 L
.74025 .30902 L
.74035 .30902 L
.74046 .30902 L
.74056 .30902 L
.74065 .30902 L
.74074 .30902 L
.74079 .30902 L
.74085 .30902 L
.74091 .30902 L
.74096 .30902 L
.74106 .30902 L
.74116 .30902 L
.74128 .30902 L
.7414 .30902 L
.74161 .30902 L
.74308 .30902 L
.74391 .30902 L
.74432 .30902 L
.7447 .30902 L
.74506 .30902 L
.74546 .30902 L
.74589 .30902 L
.74629 .30902 L
.74671 .30902 L
.74716 .30902 L
.74759 .30902 L
.74798 .30902 L
.74837 .30902 L
.74856 .30902 L
.74878 .30902 L
.74897 .30902 L
.74916 .30902 L
Mistroke
.74952 .30902 L
.74974 .30902 L
.74997 .30902 L
.75019 .30902 L
.75039 .30902 L
.75058 .30902 L
.75078 .30902 L
.75088 .30902 L
.75099 .30902 L
.7511 .30902 L
.75119 .30902 L
.75129 .30902 L
.75139 .30902 L
.75148 .30902 L
.75157 .30902 L
.75168 .30902 L
.75173 .30902 L
.75178 .30902 L
.75188 .30902 L
.75198 .30902 L
.75233 .30902 L
.75271 .30902 L
.75357 .30902 L
.75437 .30902 L
.75519 .30902 L
.75561 .30902 L
.75607 .30902 L
.75651 .30902 L
.75692 .30902 L
.75729 .30902 L
.75769 .30902 L
.75808 .30902 L
.75845 .30902 L
.75885 .30902 L
.75908 .30902 L
.75929 .30902 L
.75971 .30902 L
.75994 .30902 L
.76016 .30902 L
.76036 .30902 L
.76056 .30902 L
.76076 .30902 L
.76098 .30902 L
.76118 .30902 L
.76136 .30902 L
.76146 .30902 L
.76156 .30902 L
.76167 .30902 L
.76177 .30902 L
.76187 .30902 L
Mistroke
.76192 .30902 L
.76198 .30902 L
.76208 .30902 L
.76217 .30902 L
.76223 .30902 L
.76228 .30902 L
.76238 .30902 L
.76244 .30902 L
.76249 .30902 L
.7626 .30902 L
.76295 .30902 L
.76332 .30902 L
.76409 .30902 L
.76484 .30902 L
.76564 .30902 L
.76606 .30902 L
.76651 .30902 L
.76693 .30902 L
.76731 .30902 L
.76772 .30902 L
.76816 .30902 L
.76857 .30902 L
.76895 .30902 L
.7693 .30902 L
.76968 .30902 L
.76987 .30902 L
.77007 .30902 L
.77044 .30902 L
.77065 .30902 L
.77087 .30902 L
.77105 .30902 L
.77126 .30902 L
.7715 .30902 L
.77161 .30902 L
.77172 .30902 L
.77183 .30902 L
.77194 .30902 L
.77214 .30902 L
.77225 .30902 L
.77235 .30902 L
.77244 .30902 L
.77254 .30902 L
.7726 .30902 L
.77265 .30902 L
.77271 .30902 L
.77277 .30902 L
.77287 .30902 L
.77293 .30902 L
.77298 .30902 L
.77307 .30902 L
Mistroke
.77316 .30902 L
.77336 .30902 L
.77376 .30902 L
.77526 .30902 L
.77567 .30902 L
.77611 .30902 L
.77689 .30902 L
.77731 .30902 L
.77771 .30902 L
.77814 .30902 L
.7786 .30902 L
.77904 .30902 L
.77945 .30902 L
.77982 .30902 L
.78022 .30902 L
.78043 .30902 L
.78065 .30902 L
.78085 .30902 L
.78105 .30902 L
.78124 .30902 L
.78145 .30902 L
.78163 .30902 L
.78181 .30902 L
.78203 .30902 L
.78223 .30902 L
.78244 .30902 L
.78257 .30902 L
.78268 .30902 L
.78277 .30902 L
.78287 .30902 L
.78297 .30902 L
.78307 .30902 L
.78313 .30902 L
.78318 .30902 L
.78324 .30902 L
.78329 .30902 L
.78339 .30902 L
.78349 .30902 L
.78359 .30902 L
.78365 .30902 L
.7837 .30902 L
.78392 .30902 L
.78432 .30902 L
.78521 .30902 L
.78598 .30902 L
.78642 .30902 L
.78683 .30902 L
.78723 .30902 L
.78767 .30902 L
.78804 .30902 L
Mistroke
.78846 .30902 L
.78883 .30902 L
.78923 .30902 L
.7896 .30902 L
.78995 .30902 L
.79033 .30902 L
.79054 .30902 L
.79074 .30902 L
.79092 .30902 L
.79112 .30902 L
.79147 .30902 L
.79167 .30902 L
.79189 .30902 L
.79212 .30902 L
.79233 .30902 L
.79253 .30902 L
.79272 .30902 L
.79282 .30902 L
.79293 .30902 L
.79313 .30902 L
.79324 .30902 L
.79333 .30902 L
.79344 .30902 L
.7935 .30902 L
.79356 .30902 L
.79365 .30902 L
.79375 .30902 L
.7938 .30902 L
.79386 .30902 L
.79396 .30902 L
.79405 .30902 L
.79415 .30902 L
.79423 .30902 L
.79432 .30902 L
.79471 .30902 L
.79559 .30902 L
.79639 .30902 L
.79715 .30902 L
.79753 .30902 L
.79795 .30902 L
.79837 .30902 L
.79882 .30902 L
.79924 .30902 L
.79962 .30902 L
.80001 .30902 L
.80043 .30902 L
.80078 .30902 L
.80117 .30902 L
.80138 .30902 L
.80158 .30902 L
Mistroke
.8018 .30902 L
.80203 .30902 L
.80224 .30902 L
.80244 .30902 L
.80265 .30902 L
.80284 .30902 L
.80302 .30902 L
.80321 .30902 L
.8034 .30902 L
.80351 .30902 L
.80361 .30902 L
.80379 .30902 L
.80389 .30902 L
.80398 .30902 L
.80407 .30902 L
.80415 .30902 L
.80424 .30902 L
.80433 .30902 L
.80443 .30902 L
.80453 .30902 L
.80458 .30902 L
.80463 .30902 L
.80474 .30902 L
.80493 .30902 L
.80512 .30902 L
.80598 .30902 L
.80683 .30902 L
.80725 .30902 L
.80763 .30902 L
.80835 .30902 L
.80873 .30902 L
.80912 .30902 L
.80952 .30902 L
.80989 .30902 L
.8103 .30902 L
.8107 .30902 L
.81107 .30902 L
.81141 .30902 L
.81178 .30902 L
.81197 .30902 L
.81217 .30902 L
.81257 .30902 L
.81277 .30902 L
.81298 .30902 L
.81317 .30902 L
.81337 .30902 L
.81356 .30902 L
.81373 .30902 L
.81383 .30902 L
.81394 .30902 L
Mistroke
.81414 .30902 L
.81425 .30902 L
.81435 .30902 L
.81447 .30902 L
.81453 .30902 L
.81459 .30902 L
.81469 .30902 L
.81479 .30902 L
.81489 .30902 L
.81495 .30902 L
.815 .30902 L
.8151 .30902 L
.81521 .30902 L
.8154 .30902 L
.81697 .30902 L
.8174 .30902 L
.81786 .30902 L
.8183 .30902 L
.8187 .30902 L
.81911 .30902 L
.81955 .30902 L
.81994 .30902 L
.82036 .30902 L
.82073 .30902 L
.82108 .30902 L
.82146 .30902 L
.82166 .30902 L
.82187 .30902 L
.82208 .30902 L
.82227 .30902 L
.82264 .30902 L
.82285 .30902 L
.82307 .30902 L
.82329 .30902 L
.82348 .30902 L
.82369 .30902 L
.82387 .30902 L
.82408 .30902 L
.82431 .30902 L
.82442 .30902 L
.82454 .30902 L
.82465 .30902 L
.82476 .30902 L
.82486 .30902 L
.82496 .30902 L
.82502 .30902 L
.82507 .30902 L
.82518 .30902 L
.82528 .30902 L
.82537 .30902 L
Mistroke
.82547 .30902 L
.82557 .30902 L
.82575 .30902 L
.82594 .30902 L
.82678 .30902 L
.82759 .30902 L
.82802 .30902 L
.82848 .30902 L
.82891 .30902 L
.8293 .30902 L
.8297 .30902 L
.83007 .30902 L
.83049 .30902 L
.83088 .30902 L
.8313 .30902 L
.83154 .30902 L
.83176 .30902 L
.83215 .30902 L
.83235 .30902 L
.83256 .30902 L
.83275 .30902 L
.83295 .30902 L
.83331 .30902 L
.83352 .30902 L
.83375 .30902 L
.83398 .30902 L
.83418 .30902 L
.83436 .30902 L
.83457 .30902 L
.83467 .30902 L
.83478 .30902 L
.83488 .30902 L
.83498 .30902 L
.83507 .30902 L
.83517 .30902 L
.83528 .30902 L
.83538 .30902 L
.83547 .30902 L
.83557 .30902 L
.83565 .30902 L
.83575 .30902 L
.8358 .30902 L
.83586 .30902 L
.83596 .30902 L
.83606 .30902 L
.83618 .30902 L
.83659 .30902 L
.83748 .30902 L
.83828 .30902 L
.83867 .30902 L
Mistroke
.8391 .30902 L
.83946 .30902 L
.83986 .30902 L
.84029 .30902 L
.84074 .30902 L
.84116 .30902 L
.84155 .30902 L
.84195 .30902 L
.84218 .30902 L
.84239 .30902 L
.84278 .30902 L
.84297 .30902 L
.84319 .30902 L
.84356 .30902 L
.84377 .30902 L
.84396 .30902 L
.84413 .30902 L
.84433 .30902 L
.84451 .30902 L
.84468 .30902 L
.84489 .30902 L
.84509 .30902 L
.84519 .30902 L
.8453 .30902 L
.84542 .30902 L
.84553 .30902 L
.84563 .30902 L
.84573 .30902 L
.84582 .30902 L
.84591 .30902 L
.84602 .30902 L
.84607 .30902 L
.84613 .30902 L
.84623 .30902 L
.84633 .30902 L
.84651 .30902 L
.8467 .30902 L
.84704 .30902 L
.84782 .30902 L
.84858 .30902 L
.84901 .30902 L
.8494 .30902 L
.84977 .30902 L
.85016 .30902 L
.85053 .30902 L
.85088 .30902 L
.85125 .30902 L
.85166 .30902 L
.85204 .30902 L
.85238 .30902 L
Mistroke
.85279 .30902 L
.85302 .30902 L
.85323 .30902 L
.85362 .30902 L
.85384 .30902 L
.85404 .30902 L
.85424 .30902 L
.85443 .30902 L
.85463 .30902 L
.85485 .30902 L
.85503 .30902 L
.8552 .30902 L
.8553 .30902 L
.8554 .30902 L
.85559 .30902 L
.85569 .30902 L
.85579 .30902 L
.85589 .30902 L
.85595 .30902 L
.85601 .30902 L
.85607 .30902 L
.85612 .30902 L
.85618 .30902 L
.85624 .30902 L
.8563 .30902 L
.85635 .30902 L
.85646 .30902 L
.85655 .30902 L
.85666 .30902 L
.85684 .30902 L
.85726 .30902 L
.85808 .30902 L
.85885 .30902 L
.85955 .30902 L
.85994 .30902 L
.8603 .30902 L
.86066 .30902 L
.86106 .30902 L
.86148 .30902 L
.86187 .30902 L
.86229 .30902 L
.86267 .30902 L
.86288 .30902 L
.8631 .30902 L
.86331 .30902 L
.86355 .30902 L
.86377 .30902 L
.86397 .30902 L
.86416 .30902 L
.86437 .30902 L
Mistroke
.86454 .30902 L
.86473 .30902 L
.86493 .30902 L
.86512 .30902 L
.86533 .30902 L
.86545 .30902 L
.86557 .30902 L
.86568 .30902 L
.86579 .30902 L
.8659 .30902 L
.86599 .30902 L
.86609 .30902 L
.86619 .30902 L
.8663 .30902 L
.86635 .30902 L
.86641 .30902 L
.86651 .30902 L
.8666 .30902 L
.8667 .30902 L
.8668 .30902 L
.86689 .30902 L
.86699 .30902 L
.86717 .30902 L
.86757 .30902 L
.8684 .30902 L
.86877 .30902 L
.86917 .30902 L
.86988 .30902 L
.87028 .30902 L
.87064 .30902 L
.87106 .30902 L
.87146 .30902 L
.87183 .30902 L
.87217 .30902 L
.87254 .30902 L
.87293 .30902 L
.87314 .30902 L
.87333 .30902 L
.87369 .30902 L
.8739 .30902 L
.87408 .30902 L
.8743 .30902 L
.87451 .30902 L
.87469 .30902 L
.87488 .30902 L
.87504 .30902 L
.87522 .30902 L
.87541 .30902 L
.87561 .30902 L
.8758 .30902 L
Mistroke
.87598 .30902 L
.87608 .30902 L
.87619 .30902 L
.87628 .30902 L
.87638 .30902 L
.87649 .30902 L
.87655 .30902 L
.87661 .30902 L
.87666 .30902 L
.87672 .30902 L
.87682 .30902 L
.87692 .30902 L
.87702 .30902 L
.87707 .30902 L
.87713 .30902 L
.87723 .30902 L
.87761 .30902 L
.87839 .30902 L
.87911 .30902 L
.87987 .30902 L
.88027 .30902 L
.8807 .30902 L
.88116 .30902 L
.88159 .30902 L
.88197 .30902 L
.88239 .30902 L
.88278 .30902 L
.88315 .30902 L
.88336 .30902 L
.88355 .30902 L
.88377 .30902 L
.88398 .30902 L
.88437 .30902 L
.88458 .30902 L
.8848 .30902 L
.88503 .30902 L
.88525 .30902 L
.88545 .30902 L
.88567 .30902 L
.88586 .30902 L
.88596 .30902 L
.88606 .30902 L
.88615 .30902 L
.88625 .30902 L
.88643 .30902 L
.88654 .30902 L
.88664 .30902 L
.88669 .30902 L
.88675 .30902 L
.88681 .30902 L
Mistroke
.88686 .30902 L
.88695 .30902 L
.88705 .30902 L
.88711 .30902 L
.88716 .30902 L
.88726 .30902 L
.88732 .30902 L
.88737 .30902 L
.88748 .30902 L
.88771 .30902 L
.88814 .30902 L
.88895 .30902 L
.8897 .30902 L
.89013 .30902 L
.89051 .30902 L
.89086 .30902 L
.89123 .30902 L
.89162 .30902 L
.89198 .30902 L
.89239 .30902 L
.89262 .30902 L
.89283 .30902 L
.89322 .30902 L
.89341 .30902 L
.89363 .30902 L
.894 .30902 L
.89421 .30902 L
.8944 .30902 L
.89457 .30902 L
.89477 .30902 L
.89512 .30902 L
.89532 .30902 L
.89555 .30902 L
.89576 .30902 L
.89595 .30902 L
.89613 .30902 L
.89632 .30902 L
.89641 .30902 L
.89652 .30902 L
.89661 .30902 L
.8967 .30902 L
.89676 .30902 L
.89682 .30902 L
.89692 .30902 L
.89698 .30902 L
.89704 .30902 L
.8971 .30902 L
.89716 .30902 L
.89726 .30902 L
.89732 .30902 L
Mistroke
.89738 .30902 L
.89748 .30902 L
.89759 .30902 L
.8978 .30902 L
.89801 .30902 L
.89839 .30902 L
.89917 .30902 L
.8996 .30902 L
.9 .30902 L
.90037 .30902 L
.90071 .30902 L
.90108 .30902 L
.90148 .30902 L
.90187 .30902 L
.90228 .30902 L
.90263 .30902 L
.90301 .30902 L
.90323 .30902 L
.90343 .30902 L
.90364 .30902 L
.90387 .30902 L
.90427 .30902 L
.90448 .30902 L
.90468 .30902 L
.90488 .30902 L
.90509 .30902 L
.90531 .30902 L
.90553 .30902 L
.90572 .30902 L
.9059 .30902 L
.90611 .30902 L
.90622 .30902 L
.90632 .30902 L
.90651 .30902 L
.90661 .30902 L
.90672 .30902 L
.90683 .30902 L
.90692 .30902 L
.90701 .30902 L
.9071 .30902 L
.90719 .30902 L
.90728 .30902 L
.90738 .30902 L
.90747 .30902 L
.90756 .30902 L
.90764 .30902 L
.90781 .30902 L
.90862 .30902 L
.90948 .30902 L
.91021 .30902 L
Mistroke
.91063 .30902 L
.91102 .30902 L
.91139 .30902 L
.91179 .30902 L
.91213 .30902 L
.9125 .30902 L
.9129 .30902 L
.91313 .30902 L
.91333 .30902 L
.91352 .30902 L
.91372 .30902 L
.9141 .30902 L
.91429 .30902 L
.91449 .30902 L
.91486 .30902 L
.91508 .30902 L
.9153 .30902 L
.91549 .30902 L
.9157 .30902 L
.9159 .30902 L
.91612 .30902 L
.91623 .30902 L
.91635 .30902 L
.91646 .30902 L
.91657 .30902 L
.91667 .30902 L
.91678 .30902 L
.91689 .30902 L
.917 .30902 L
.9171 .30902 L
.9172 .30902 L
.91729 .30902 L
.91739 .30902 L
.91748 .30902 L
.91758 .30902 L
.91768 .30902 L
.91778 .30902 L
.91795 .30902 L
.91814 .30902 L
.91898 .30902 L
.91944 .30902 L
.91987 .30902 L
.92028 .30902 L
.92067 .30902 L
.92104 .30902 L
.92143 .30902 L
.92182 .30902 L
.92225 .30902 L
.92267 .30902 L
.9229 .30902 L
Mistroke
.92312 .30902 L
.92332 .30902 L
.92354 .30902 L
.92373 .30902 L
.92393 .30902 L
.92414 .30902 L
.92432 .30902 L
.92469 .30902 L
.92488 .30902 L
.92509 .30902 L
.92531 .30902 L
.92552 .30902 L
.92574 .30902 L
.92595 .30902 L
.92613 .30902 L
.92634 .30902 L
.92656 .30902 L
.92667 .30902 L
.92679 .30902 L
.92689 .30902 L
.92701 .30902 L
.92711 .30902 L
.92721 .30902 L
.92731 .30902 L
.92741 .30902 L
.9275 .30902 L
.92759 .30902 L
.9277 .30902 L
.92775 .30902 L
.9278 .30902 L
.928 .30902 L
.92818 .30902 L
.92838 .30902 L
.92874 .30902 L
.9296 .30902 L
.92998 .30902 L
.9304 .30902 L
.9308 .30902 L
.93122 .30902 L
.93168 .30902 L
.93211 .30902 L
.93252 .30902 L
.93289 .30902 L
.93309 .30902 L
.93332 .30902 L
.93373 .30902 L
.93393 .30902 L
.93415 .30902 L
.93435 .30902 L
.93455 .30902 L
Mistroke
.93474 .30902 L
.93494 .30902 L
.93513 .30902 L
.9353 .30902 L
.93552 .30902 L
.93572 .30902 L
.93594 .30902 L
.93617 .30902 L
.93638 .30902 L
.93649 .30902 L
.9366 .30902 L
.93678 .30902 L
.93688 .30902 L
.93699 .30902 L
.93709 .30902 L
.93718 .30902 L
.93729 .30902 L
.93739 .30902 L
.93748 .30902 L
.93756 .30902 L
.93766 .30902 L
.93776 .30902 L
.93785 .30902 L
.93796 .30902 L
.93816 .30902 L
.9386 .30902 L
.93947 .30902 L
.93987 .30902 L
.94029 .30902 L
.94071 .30902 L
.9411 .30902 L
.94156 .30902 L
.94199 .30902 L
.94239 .30902 L
.94276 .30902 L
.94317 .30902 L
.94338 .30902 L
.9436 .30902 L
.9438 .30902 L
.94402 .30902 L
.94422 .30902 L
.94442 .30902 L
.94461 .30902 L
.94481 .30902 L
.94517 .30902 L
.94539 .30902 L
.94559 .30902 L
.94581 .30902 L
.94604 .30902 L
.94624 .30902 L
Mistroke
.94642 .30902 L
.94663 .30902 L
.94674 .30902 L
.94685 .30902 L
.94694 .30902 L
.94703 .30902 L
.94714 .30902 L
.94724 .30902 L
.94729 .30902 L
.94735 .30902 L
.94745 .30902 L
.94756 .30902 L
.94765 .30902 L
.94774 .30902 L
.94782 .30902 L
.94791 .30902 L
.94801 .30902 L
.94839 .30902 L
.94919 .30902 L
.94961 .30902 L
.95006 .30902 L
.9505 .30902 L
.95089 .30902 L
.95129 .30902 L
.95167 .30902 L
.95209 .30902 L
.95248 .30902 L
.95268 .30902 L
.95291 .30902 L
.95312 .30902 L
.95336 .30902 L
.95358 .30902 L
.95378 .30902 L
.95398 .30902 L
.95417 .30902 L
.95453 .30902 L
.95473 .30902 L
.95492 .30902 L
.95512 .30902 L
.95534 .30902 L
.95552 .30902 L
.95572 .30902 L
.95594 .30902 L
.95617 .30902 L
.95629 .30902 L
.95639 .30902 L
.95649 .30902 L
.95659 .30902 L
.95669 .30902 L
.95678 .30902 L
Mistroke
.95696 .30902 L
.95706 .30902 L
.95716 .30902 L
.95721 .30902 L
.95727 .30902 L
.95737 .30902 L
.95742 .30902 L
.95748 .30902 L
.95753 .30902 L
.95759 .30902 L
.95769 .30902 L
.95775 .30902 L
.9578 .30902 L
.9579 .30902 L
.95799 .30902 L
.95819 .30902 L
.95891 .30902 L
.95967 .30902 L
.96009 .30902 L
.96046 .30902 L
.96084 .30902 L
.9612 .30902 L
.96162 .30902 L
.962 .30902 L
.96242 .30902 L
.96263 .30902 L
.96286 .30902 L
.96307 .30902 L
.96329 .30902 L
.96348 .30902 L
.96368 .30902 L
.96387 .30902 L
.96407 .30902 L
.96443 .30902 L
.96465 .30902 L
.96485 .30902 L
.96508 .30902 L
.9653 .30902 L
.9655 .30902 L
.96569 .30902 L
.96589 .30902 L
.96611 .30902 L
.96632 .30902 L
.96643 .30902 L
.96654 .30902 L
.96664 .30902 L
.96675 .30902 L
.96685 .30902 L
.96694 .30902 L
.96705 .30902 L
Mistroke
.96711 .30902 L
.96718 .30902 L
.96723 .30902 L
.96729 .30902 L
.96735 .30902 L
.9674 .30902 L
.96746 .30902 L
.96751 .30902 L
.96757 .30902 L
.96763 .30902 L
.96772 .30902 L
.96783 .30902 L
.96794 .30902 L
.96804 .30902 L
.96827 .30902 L
.96868 .30902 L
.96945 .30902 L
.96982 .30902 L
.97023 .30902 L
.97061 .30902 L
.97095 .30902 L
.97136 .30902 L
.97157 .30902 L
.9718 .30902 L
.97202 .30902 L
.97222 .30902 L
.97261 .30902 L
.9728 .30902 L
.973 .30902 L
.9732 .30902 L
.97341 .30902 L
.97362 .30902 L
.9738 .30902 L
.97416 .30902 L
.97437 .30902 L
.97457 .30902 L
.97478 .30902 L
.97501 .30902 L
.97521 .30902 L
.9754 .30902 L
.97561 .30902 L
.97583 .30902 L
.976 .30902 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{421.375, 260.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008>0001AB000`400?l00000o`00003ooooooooo
oooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo
003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooo
oooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool0
0?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooooooo
ool@ooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0oooooooBooooo`00<?ooool00ol0003oooooooooo`07ooooo`;o
0000oooooooCooooo`00<?ooool00ol0003oooooooooo`07ooooo`;o0000oooooooCooooo`00<?oo
ool00ol0003oooooooooo`07ooooo`;o0000oooooooCooooo`00<?ooool3o`0000Oooooo0_l0003o
ooooom?ooooo000`ooooo`03o`000?oooooooooo00Oooooo0_l0003oooooom?ooooo000`ooooo`03
o`000?oooooooooo00Oooooo0_l0003oooooom?ooooo000`ooooo`03o`000?oooooooooo00Oooooo
0_l0003oooooom?ooooo000`ooooo`03o`000?oooooooooo00Oooooo0_l0003oooooom?ooooo000`
ooooo`03o`000?oooooooooo00Oooooo0_l0003oooooom?ooooo000`ooooo`03o`000?oooooooooo
00Oooooo0_l0003oooooom?ooooo000`ooooo`03o`000?oooooooooo00Oooooo0_l0003oooooom?o
oooo000`ooooo`03o`000?oooooooooo00Oooooo0_l0003oooooom?ooooo000`ooooo`03o`000?oo
oooooooo00Oooooo0_l0003oooooom?ooooo000`ooooo`03o`000?oooooooooo00Oooooo0_l0003o
ooooom?ooooo000`ooooo`03o`000?oooooooooo00Oooooo0_l0003oooooom?ooooo000`ooooo`?o
00001oooool2o`000?oooooodoooool0033ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
o`00003oooooom?ooooo000`ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooool00000oooo
oooCooooo`00<?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo00000?oooooodoooool0
033ooooo00?o0000ooooooooool01_ooool00ol0003oooooo`00003oooooom?ooooo000`ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooool00000oooooooCooooo`00<?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooo00000?oooooodoooool0033ooooo00?o0000ooooooooool01_oo
ool01?l0003oooooooooool0003oooooom;ooooo000`ooooo`03o`000?oooooooooo00Kooooo00Co
0000oooooooooooo0000oooooooBooooo`00<?ooool00ol0003oooooooooo`06ooooo`04o`000?oo
ooooooooo`000?ooooood_ooool0033ooooo00?o0000ooooooooool01_ooool01?l0003ooooooooo
ool0003oooooom;ooooo000`ooooo`?o00001_ooool01?l0003oooooooooool0003oooooom;ooooo
000`ooooo`03o`000?oooooooooo00Kooooo00Co0000oooooooooooo0000oooooooBooooo`00<?oo
ool00ol0003oooooooooo`06ooooo`04o`000?ooooooooooo`000?ooooood_ooool0033ooooo00?o
0000ooooooooool01_ooool01?l0003oooooooooool0003oooooom;ooooo000`ooooo`03o`000?oo
oooooooo00Kooooo00Co0000oooooooooooo0000oooooooBooooo`00<?ooool00ol0003ooooooooo
o`06ooooo`04o`000?ooooooooooo`000?ooooood_ooool002oooooo0_l00008ooooo`04o`000?oo
ooooooooo`000?ooooood_ooool0013ooooo0_o^k^h3ooooo`;ok^k^5oooool3o`0000Sooooo00Co
0000oooooooooooo0000oooooooBooooo`002oooool2o`00000:oa0@4?ooooooooooonk^k_mEEEGo
k^k^ooooooo^k^koEEEEonk^kP?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;o
k^k^2?ooool3o`0000Sooooo00Co0000oooooooooooo0000oooooooBooooo`003?ooool00ol0003o
ooooooooo`02ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool3o`0000Sooooo00Co0000oooooooooooo0000oooo
oooBooooo`0000?oooooo`000?l000001?l00002ooooo`Go00001?ooool00ooMgMgo0000omgMg@07
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4008ooooo`?o00002?oo
ool01?l0003oooooooooool0003oooooom;ooooo0009ooooo`04odA4A?oMgMgoooooo`0000Cooooo
00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`000008ooooo`?o00002?ooool01?l0003oooooooooool0003oooooom;ooooo0009oooo
o`04omgMgOmEEEGoooooo`0000?ooooo00Ook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Sooooo1_l00005ooooo`04
o`000?ooooooooooo`000?ooooood_ooool000[ooooo00?oMgMgolc<c?l000000oooool2onk^kP?o
oooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4008oooo
o`?o00002?ooool01?l0003oooooooooool0003oooooom;ooooo000:ooooo`03onk^k_m4A4Co0000
00oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo0_l00003
ooooo`?o00002?ooool01?l0003oooooooooool0003oooooom;ooooo000;ooooo`03ogMgMol0003o
oooo00cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo00Co
0000oooooooooooo00000_ooool3o`0000Sooooo00Co0000oooooooooooo0000oooooooBooooo`00
:?ooool01?l0003oooooooooool00002ooooo`?o00002?ooool01?l0003oooooooooool0003ooooo
om;ooooo000Xooooo`?o00000oooool3o`0000Sooooo00Co0000oooooooooooo0000oooooooBoooo
o`00:Oooool00ol0003oooooooooo`02ooooo`?o00002?ooool01?l0003oooooooooool0003ooooo
om;ooooo000Zooooo`07o`000?ooooooooooooooool0003oooooo`000008ooooo`04o`000?oooooo
ooooo`000?ooooood_ooool002kooooo00?o0000ooooool000002?ooool01?l0003oooooooooool0
003oooooom;ooooo000^ooooo`03o`000?oooooo000000Sooooo00Co0000oooooooooooo0000oooo
oooBooooo`00;_ooool00ol0003oooooo`000008ooooo`04o`000?ooooooooooo`000?ooooood_oo
ool002kooooo00?o0000ooooool000002?ooool01?l0003oooooooooool0003oooooom;ooooo000^
ooooo`03o`000?oooooo000000;o00001_ooool01?l0003oooooooooool0003oooooom;ooooo000]
ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002Oooool00ol0003ooooo
ooooo`3oooooolKooooo000]ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo
00002Oooool00ol0003oooooooooo`3oooooolKooooo000]ooooo`04o`000?ooooooooooo`0000So
oooo00Co0000oooooooooooo00002?ooool2o`000?oooooob?ooool002gooooo00Co0000oooooooo
oooo00002?ooool01?l0003oooooooooool00008ooooo`;o0000ooooooo8ooooo`00;Oooool01?l0
003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo0_l0003oooooolSooooo000]
ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002?ooool00ol0003ooooo
o`00003oooooolOooooo000]ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo
00002?ooool00ol0003oooooo`00003oooooolOooooo000]ooooo`04o`000?ooooooooooo`0000So
oooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003oooooolOooooo000]ooooo`04
o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003o
ooooolOooooo000]ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002?oo
ool00ol0003oooooo`00003oooooolOooooo000]ooooo`04o`000?ooooooooooo`0000Sooooo00Co
0000oooooooooooo00002?ooool00ol0003oooooo`00003oooooolOooooo000]ooooo`03o`000?oo
oooooooo00?o00001_ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?oooooo
aoooool002gooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00008ooooo`03
o`000?oooooo00000?ooooooaoooool002gooooo00Co0000oooooooooooo00002?ooool01?l0003o
ooooooooool00008ooooo`03o`000?oooooo00000?ooooooaoooool002gooooo00Co0000oooooooo
oooo00002?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?ooooooaoooool0
02gooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Sooooo00?o
0000ooooool00000ooooooo7ooooo`00;Oooool01?l0003oooooooooool00007ooooo`05o`000?oo
ooooooooooooool000002?ooool00ol0003oooooo`00003oooooolOooooo000]ooooo`04o`000?oo
ooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooo00000?oo
ooooaoooool002gooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000
00Sooooo00?o0000ooooool00000ooooooo7ooooo`00;Oooool01?l0003oooooooooool00007oooo
o`05o`000?ooooooooooooooool000002?ooool00ol0003oooooo`00003oooooolOooooo000]oooo
o`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oo
oooo00000?ooooooaoooool002gooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooo
oooooooo000000Sooooo00?o0000ooooool00000ooooooo7ooooo`00;Oooool00ol0003ooooooooo
o`03o`0000Gooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooo00000?oooooo
aoooool002gooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000So
oooo00?o0000ooooool00000ooooooo7ooooo`00;Oooool01?l0003oooooooooool00007ooooo`05
o`000?ooooooooooooooool000002?ooool00ol0003oooooo`00003oooooolOooooo000]ooooo`04
o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooo
00000?ooooooaoooool002gooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooo
oooo000000Sooooo00?o0000ooooool00000ooooooo7ooooo`00;Oooool01?l0003oooooooooool0
0007ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooo`00003oooooolOooooo
000]ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000008ooooo`03
o`000?oooooo00000?ooooooaoooool0013ooooo0_o^k^h3ooooo`;ok^k^5_ooool01?l0003ooooo
ooooool00007ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooo`00003ooooo
olOooooo0009ooooo`Go00000_ooool01oo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4
o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h7ooooo`04o`000?ooooooooooo`00
00Oooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooo00000?ooooooaoooool0
00Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_oo
ool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01oooool01?l0003ooooo
ooooool00007ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooo`00003ooooo
olOooooo00000ooooooo0000o`000004o`0000?ooooo00?oV9RHob4Q8Oo^k^h01Oooool00ooMgMgo
0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4007oooo
o`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oo
oooo00000?ooooooaoooool000_ooooo00?oV9RHob4Q8Oo^k^h00oooool01Oo^k^koEEEEomgMgOmE
EEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Oooooo
00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000oooo
ool00000ooooooo7ooooo`003?ooool02omgMgOoIVIVooooooooooook^k^oeEEEOo^k^koooooonk^
k_mEEEGok^k^00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Oo
oooo00?o0000ooooooooool01?l00004ooooo`05o`000?ooooooooooooooool000001oooool01?l0
003oooooooooool0003oooooolOooooo000=ooooo`03o`000?oooooooooo00;ok^k^0oooool2onk^
kPGooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Oooooo00Co0000
oooooooooooo00001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Co
0000oooooooooooo0000ooooooo7ooooo`002Oooool01Ol0003o^[ZjoooooonHV9So410@00kooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo0_l00002ooooo`04
o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04oooo
o`04o`000?ooooooooooo`000?ooooooaoooool000Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00<
ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`06o`000?oo
ooooooooo`000?oooooo00000_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0003oooooolOooooo000Xooooo`06
o`000?ooooooooooo`000?oooooo00000_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0003oooooolOooooo000X
ooooo`?o00000_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool01?l0003oooooooooool0003oooooolOooooo000Yooooo`05o`000?oo
ooooooooooooool000000_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo00000?ooooooa_ooool002[ooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo00000?ooooooa_ooool002go
oooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00Go0000ooooooooooooooooo`00003oooooolKooooo000]ooooo`03o`000?oooooooooo
00;o00001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooo
ooooooooooooo`00003oooooolKooooo000]ooooo`03o`000?oooooooooo00;o00001_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00003o
ooooolKooooo000/ooooo`04o`000?ooooooooooooooo`;o00001_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00003oooooolKooooo000/
ooooo`04o`000?ooooooooooooooo`?o00001Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00Go0000ooooooooooooooooo`00003oooooolKooooo000/ooooo`04o`000?oo
ooooooooooooo`;o00001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo
00Go0000ooooooooooooooooo`00003oooooolKooooo000Sooooo`03o`000?oooooooooo00Kooooo
00Co0000oooooooooooooooo0_l00006ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool01Ol0003ooooooooooooooooo00000?ooooooa_ooool002;ooooo0_l00008ooooo`04
o`000?ooooooooooooooo`;o00001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00Go0000ooooooooooooooooo`00003oooooolKooooo000Rooooo`03o`000?oooooo0000
00Oooooo00Co0000oooooooooooooooo0_l00006ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool01Ol0003ooooooooooooooooo00000?ooooooa_ooool002;ooooo00?o0000
ooooool000001oooool01?l0003oooooooooooooool2o`0000Kooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000ooooooo6ooooo`008_oo
ool00ol0003oooooo`000007ooooo`04o`000?ooooooooooooooo`;o00001_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00003oooooolKo
oooo000Rooooo`03o`000?oooooo000000Oooooo00Co0000oooooooooooooooo0_l00006ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000
0?ooooooa_ooool002;ooooo00?o0000ooooool000001oooool01?l0003oooooooooooooool2o`00
00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooo
ooooool00000ooooooo6ooooo`008_ooool00ol0003oooooo`000007ooooo`04o`000?oooooooooo
ooooo`;o00001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000
ooooooooooooooooo`00003oooooolKooooo000Qooooo`04o`000?ooooooooooo`0000Oooooo00Co
0000oooooooooooooooo0_l00006ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool01Ol0003ooooooooooooooooo00000?ooooooa_ooool0027ooooo00Co0000oooooooooooo
00001oooool01?l0003oooooooooooooool2o`0000Kooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000ooooooo6ooooo`008Oooool01?l0
003oooooooooool00007ooooo`04o`000?ooooooooooooooo`?o00001Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000008ooooo`03o`00
0?oooooooooo0?oooooo^oooool0027ooooo00Co0000oooooooooooo00001oooool01?l0003ooooo
ooooooooool2o`0000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05
o`000?ooooooooooooooool000002?ooool2o`000?oooooo_?ooool0027ooooo00Co0000oooooooo
oooo00001oooool01?l0003oooooooooooooool2o`0000Kooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000002?ooool2o`000?oooooo_?oo
ool0027ooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooooooool2o`0000Kooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool0
00001oooool00ol0003oooooo`00003ooooookcooooo000Qooooo`04o`000?ooooooooooo`0000Oo
oooo00Co0000oooooooooooooooo0_l00006ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01?ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooool00000oooooonl
ooooo`008Oooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooooooo0_l0
0006ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooool00000;_ooool2onk^kP?ooooo0_o^
k^iGooooo`;ok^k^0oooool2onk^kV3ooooo0_o^k^h3ooooo`;ok^k^C_ooool2onk^kP?ooooo0_o^
k^i/ooooo`008Oooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooooooo
0_l00006ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooool00000:?ooool03Om4A4Co0000
o`000?lb<S;ogMgMooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@
4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^i2ooooo`Co000000Wo410@ooooooo^k^koEEEEonk^
k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^hkooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo00goA4A4o`000?l0003o<S8b
omgMgOooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413ooooooooo
ooo^k^ko<S8bo`000?lb<S;ok^k^>?ooool5o`0000;ooooo00Ook^k^oeEEEOo^k^koooooonk^k_mE
EEGok^k^00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^GOooool0027o
oooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooooooo`;o00001_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooo000002_ooooo00WoMgMgoc8b<_ooooooooooonk^
k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL0A?ooool00ol0003oooooooooo`02ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool0
0ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?Oooool00ol0003ooooooooo
o`04ooooo`;o8B4Q2?ooool02OmgMgOo<S8booooooooooook^k^oeEEEOoMgMgoEEEEonk^kP06oooo
o`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0hooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@00oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg05gooooo000Qooooo`05o`000?ooooooooooooooool0
00001_ooool01?l0003oooooooooooooool2o`0000Kooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool01?l0
003oooooooooool0000[ooooo`07o`000?oooooooooooooooooMgMgo0000omgMg@07ooooo`03o`00
0?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4014ooooo`03o`000?oooooooooo00?o
oooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooo
ool@4100?Oooool00ol0003oooooooooo`0?ooooo`07o`000?oooooooooooooooooMgMgo0000omgM
g@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400iooooo`03oiRH
V?lQ8B7ok^k^00Gooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@
4?ooooooooooooooool@4100GOooool0027ooooo00Go0000ooooooooooooooooo`000006ooooo`04
o`000?ooooooooooooooo`;o00001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`04o`000?oooooooooo
o`0002[ooooo00WoMgMgoc8b<_ooooooooooonk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool00000A?ooool00ol0003oooooooooo`02oooo
o`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool00000?Oooool00ol0003oooooooooo`0>ooooo`09ogMgMolb<S;oooooooooooo^k^ko
EEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo
000003[ooooo00?oV9RHob4Q8Oo^k^h00oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000005gooooo000Qooooo`05o`000?oo
ooooooooooooool000001_ooool01?l0003oooooooooooooool2o`0000Kooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01?ooool01?l0003oooooooooool0000Wooooo`0=o`000?lQ8B7o0000oc8b<_o<c<coooooonk^
k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`000014ooooo`0;o`000?ooooooooooooooooo^k^koEEEEonk^k_ooooook^k^oeEE
EOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000?Oooool0
0ol0003oooooooooo`0;ooooo`0=o`000?lQ8B7o0000oc8b<_o<c<coooooonk^k_mEEEGok^k^oooo
ooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
000kooooo`0;ogMgMomVIVKoooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000GOooool0027ooooo00Go0000
ooooooooooooooooo`000006ooooo`04o`000?ooooooooooooooo`;o00001_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`04ooooo`04o`000?ooooooooooo`0002Oooooo00?o0000ooooooooool00oooool2onk^kP?o
oooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4014oooo
o`04o`000?ooooooooooooooo`;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@03gooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`03ooooo`;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@03cooooo00?o0000ooooooooool00_o^k^h3ooooo`;ok^k^1Oooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@4100GOooool0023ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooooooo`?o00001Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`04o`000?ooooooooooo`0002Oooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`0i
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Sooooo0_l0000cooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool2o`0002kooooo
00Go0000okZj^_ooooooV9RHoa0@400>ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`08ooooo`;o0000Doooool0023ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`04o`000?ooooooooooooooo`;o00001_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04oooo
o`04o`000?ooooooooooo`0002Oooooo1?l0000<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo03Oooooo00?oEEEEofIVI_l000003Ooo
ool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01oooool01?l0003ooooo
ooooool0000`ooooo`03oeEEEOmVIVKo000000gooooo1?l0000<ooooo`03oeEEEOmVIVKo000000Co
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP07ooooo`04o`000?ooooooooooo`0002gooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c00<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP07ooooo`04o`000?ooooooooooo`0005;ooooo000Pooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool01?l0003oooooooooooooool2o`0000Kooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01?ooool01Ol0003ooooooooooooooooo000004Cooooo1?l00003ooooo`03o`000?oooooooooo
05Cooooo1?l000001Ooooooo0000oooooooooooo000005kooooo1?l000001Ooooooo0000oooooooo
oooo000004cooooo1?l000001Ooooooo0000oooooooooooo000005;ooooo000Pooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooooooool2o`0000Kooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000004_ooooo00?o0000oooooooo
ool0FOooool3o`0006Cooooo0ol0001Booooo`?o0000Doooool0023ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooooooo`;o00001_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Aoooool01?l0003o
ooooooooool0001Kooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0D_ooool00ol0
003oooooooooo`1Booooo`008?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00Co0000oooooooooooooooo0_l00006ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`17ooooo`Co0000G?ooool00ol0003oooooooooo`1Toooo
o`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0DOooool001Oooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooo
oooooooo0_l00006ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`3ooooookSooooo000Fooooo`?o00001oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Cooooo00Co0000oooooooooooooooo0_l00006ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3oooooogkooooo00?oMgMgofIV
I_ooool0;Oooool00omVIVKoMgMgooooo`07ooooo`005_ooool00ol0003oooooo`000007ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooooooool2o`00
00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Gooooo0_l0003oooooogKooooo00?ogMgMoa0@4?o^k^h0;_ooool00oo^k^ko410@omgMg@07oooo
o`005Oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`04ooooo`04o`000?ooooooooooooooo`;o00001_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool4o`000?ooooooHoooool2
o`0000;ooooo0_l0000<ooooo`03oeEEEOnHV9Sooooo00;o00000_ooool01ol0003oooooooooool0
003o410@onk^k_mEEED00_l000000om4A4Co^[Zjooooo`02ooooo`05oiRHV?l0003o0000odA4A?nj
^[X00_ooool02?o^k^koEEEEo`000?l0003oA4A4okZj^_oooooo410@1Ol00003ooooo`08oa0@4?lb
<S;o0000o`000?l@413oZJVYohN7QomVIVH7ooooo`005?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`04
o`000?ooooooooooooooo`;o00001_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo00000?ooooooH_ooool0
1_o^k^ko8B4QohN7Qonj^[[o0000omgMg@cooooo00Go0000ooooooooooooooooo`000002ooooo`0;
o`000?ooooooooooo`000?ooooooEEEEogMgMoooooook^k^ogMgMol@41000oooool01Ol@413o^[Zj
onk^k_mgMgOo410@00;ooooo00KoEEEEogMgMoooooook^k^ogMgMol@4103ooooo`03o`000?oooooo
oooo00Cooooo00So0000ojVYZOoooooooooookZj^_l0003ok^k^o`0000Oooooo003oo`000;Co0000
3oooool01?oMgMgo0000oa0@4?o<c<`=ooooo`05oc8b<_ooooooooooooooool000000_ooool01_l0
003oooooooooool0003oooooo`0000Sooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Gooooo00Oo^[ZjohN7QomVIVKoIVIVoa0@4?oooooo000000Oo
oooo000:ooooo`04o`000?ooooooooooooooo`Ko00001_ooool01_l0003oooooooooool0003ooooo
o`0000Kooooo00?o0000ooooooooool00oooool01?l0003oooooooooooooool2o`0000Kooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000Cooooo00?o
0000ooooooooool00_ooool6o`0000;ooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo01Oooooo00Cok^k^ob4Q8Ol@413ok^k^3Oooool01Olb<S;ooooo
oooooooooooo000000;ooooo00Go0000oooooooooooo0000ooooo`06o`0000?ooooo00?o0000oooo
ooooool01?ooool6o`0000?ooooo00?o0000ooooooooool01?ooool02?lb<S;o8B4QogMgMomgMgOo
QhN7onk^k_oooooo00001oooool000[ooooo00?o0000ooooooooool00oooool3o`0000Oooooo00Ko
0000oooooooooooo0000ooooool00006ooooo`03o`000?oooooooooo00?ooooo00Oo0000oooooooo
ooooooooo`000?oooooo000000Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`;o00000oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0Gooooo`04ob4Q8OmgMgOoMgMgoc8b<Pgooooo00Go
0000onk^k_ooooooooooo`000002olc<c00;o`000?nYZJWogMgMob4Q8OooooooEEEEohN7Qoo^k^ko
ooooohN7Qolb<S800oooool00ol0003oooooooooo`04ooooo`06oeEEEOn7QhOok^k^oooooon7QhOo
<S8b0oooool00ol0003o<S8bomgMg@04ooooo`08o`000?nj^[[oooooonk^k_mgMgOo0000onk^k_l0
0007ooooo`006_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00oooool01ol0003ooooooooooooooooo0000ooooool000001?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0aooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool0Foooool00ol0003ooooo
ooooo`1Kooooo`03o`000?oooooooooo01Kooooo0_l00002ooooo`;o00003?ooool03_mEEEGoMgMg
ooooool@413o0000ob4Q8Ol0003oMgMgoa0@4?l0003oZJVYooooooo^k^koEEEE0_l000001?m4A4Co
k^k^ooooool@4105o`0000?ooooo00Kok^k^oeEEEOl0003o0000odA4A?o^k^h2ooooo`;o000000Co
ZJVYob4Q8Ol0003o8B4Q0_ooool02?nYZJWo8B4Qo`000?l0003o<S8bo`000?mgMgOoEEEE1oooool0
01[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo00Oo0000ooooooooooooooooo`000?oooooo000000Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool00000oooooomjooooo`03omgM
gOl@413ok^k^01;ooooo00?o0000ooooooooool06Oooool00oo^k^ko410@omgMg@07ooooo`006_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00ooo
ool01ol0003ooooooooooooooooo0000ooooool000001?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00003oooooog_ooooo00?oMgMgofIV
I_ooool04Oooool00ol0003oooooooooo`0Iooooo`03ofIVI_mgMgOooooo00Oooooo000Kooooo`05
o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`03ooooo`07o`000?oooooooooo
ooooool0003oooooo`000004ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool01Ol0003ooooooooooooooooo00000?oooooo]Oooool001_ooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo00?ooooo00Oo0000ooooooooooooooooo`000?oooooo0000
00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooo
ooooool00000ooooooneooooo`006oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo00000?oooooo]_ooool0
01_ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00_ooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01Oooool2o`000?oooooo]oooool001_ooooo00Go0000ooooooooooooooooo`000006
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooo`000004
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool2o`000?oooooo]oooool0
01cooooo00?o0000ooooool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooool000001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
0?oooooo__ooool001cooooo00?o0000ooooool000001oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00;ooooo0ol00004ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0oooooonnooooo`007?ooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00_ooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0oooooonnooooo`007?ooool3o`0000Oooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`3ooooookkooooo000Mooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`3ooooookkooooo000Vooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0oooooonnooooo`009_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooool000001?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo0?oooooo__ooool002Kooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooo000000Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`3ooooookkooooo000Vooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooo`000004ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0oooo
oonnooooo`009_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooool000001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo__ooool0
02Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo0000
00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3ooooookkooooo000Vooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooo`000004ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0oooooonnooooo`009_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000001?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo0?oooooo__ooool002Kooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`02ooooo`?o00001?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0003ooooool7ooooo
000Vooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooo`00
0004ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`04ooooo`04o`000?ooooooooooo`000?oooooo`Oooool002Oooooo00Go0000oooooooooooooooo
o`000004ooooo`03o`000?oooooo000000Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo0000ooooooo1ooooo`00
9oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooool000001?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01?l0003o
ooooooooool0003ooooool7ooooo000Wooooo`05o`000?ooooooooooooooool000001?ooool00ol0
003oooooo`000004ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`04ooooo`04o`000?ooooooooooo`000?oooooo`Oooool002Oooooo00Go0000oooo
ooooooooooooo`000004ooooo`03o`000?oooooo000000Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo0000oooo
ooo1ooooo`009oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooool000001?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool01?l0003oooooooooool0003ooooool7ooooo000Wooooo`05o`000?ooooooooooooooool00000
1?ooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`000?oooooo`Oooool002Oooooo
00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooo000000Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooo
oooo0000ooooooo1ooooo`009oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooo
ool000001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01?ooool01?l0003oooooooooool0003ooooool7ooooo000Wooooo`04o`000?oooooooooo
o`0000Gooooo00?o0000ooooool000001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0003ooooool7ooooo000W
ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooool000001?ooool00ol0003ooooooooo
o`04ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool0003ooooool7o
oooo000Wooooo`04o`000?ooooooooooo`0000Gooooo0ol00004ooooo`03o`000?oooooooooo00Co
oooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`000?oooooo`Oooool0
02Oooooo00Co0000oooooooooooo00001Oooool00ol0003oooooo`000004ooooo`03o`000?oooooo
oooo00Cooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`000?oooooo
`Oooool002Oooooo00Co0000oooooooooooo00001Oooool00ol0003oooooo`000004ooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`00
0?oooooo`Oooool002Oooooo00Co0000oooooooooooo00001Oooool00ol0003oooooo`000004oooo
o`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?oooooo
ooooo`000?oooooo`Oooool002Oooooo00Co0000oooooooooooo00001Oooool00ol0003oooooo`00
0004ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000007ooooo`04o`00
0?ooooooooooo`000?oooooo`Oooool002Oooooo00Co0000oooooooooooo00001Oooool00ol0003o
ooooo`000004ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000007oooo
o`04o`000?ooooooooooo`000?oooooo`Oooool000oooooo0_o^k^h3ooooo`;ok^k^4Oooool01?l0
003oooooooooool00005ooooo`03o`000?oooooo000000Cooooo00?o0000ooooooooool01?ooool0
1Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooool00000ooooooo1ooooo`002?ooool5
o`0000;ooooo00Ook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^0oooool00ol0003oooooo`000005ooooo`04o`000?oooooo
ooooo`0000?ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Sooooo
00?o0000ooooool00000ooooooo1ooooo`002?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo
00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`03o`000?oooooo000000Gooooo00Co0000oooooooooooo00000oooool0
0ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000002?ooool2o`000?oooooo`_oo
ool000Wooooo00?oV9RHob4Q8Oo^k^h01Oooool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooo
oooo00;ooooo00Go410@oooooooooooooooooa0@4003ooooo`03o`000?oooooo000000Gooooo00Co
0000oooooooooooo00000oooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool0
00002?ooool2o`000?oooooo`_ooool000[ooooo00?oV9RHob4Q8Oo^k^h00oooool01Oo^k^koEEEE
omgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooool000001Oooool01?l0003oooooooooool00003ooooo`03o`000?oooooo
oooo00Cooooo00Go0000ooooooooooooooooo`000008ooooo`;o0000ooooooo2ooooo`002oooool0
2omgMgOoIVIVooooooooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooool000001Oooool4
o`0000?ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Sooooo0_l0
003ooooool;ooooo000<ooooo`03o`000?oooooooooo00;ok^k^0oooool2onk^kPGooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo00?o0000ooooool000001Ooo
ool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooo
ooooo`000008ooooo`;o0000ooooooo2ooooo`002?ooool01Ol0003o^[ZjoooooonHV9So410@00ko
oooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00?o0000oooo
ool000001Oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Cooooo00Go0000
ooooooooooooooooo`00003oooooolcooooo0008ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?oo
ool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool3o`0000Gooooo
00Co0000oooooooooooo00000oooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooooooo
ool00000ooooooo<ooooo`009oooool2o`000003ooooool0003ooooo00Cooooo00Co0000oooooooo
oooo00000oooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000ooooooo<
ooooo`009oooool2o`000003ooooool0003ooooo00Cooooo00Co0000oooooooooooo00000oooool0
0ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000ooooooo<ooooo`009oooool4
o`0000Gooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`04ooooo`05o`000?oo
ooooooooooooool00000ooooooo<ooooo`00:?ooool00ol0003oooooo`000005ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo00000?oo
ooooc?ooool002Sooooo0ol00005ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooooooo
ool01?ooool01Ol0003ooooooooooooooooo00000?ooooooc?ooool002Sooooo00?o0000ooooool0
00001Oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Cooooo00Go0000oooo
ooooooooooooo`00003oooooolcooooo000Xooooo`03o`000?oooooo000000Gooooo00Co0000oooo
oooooooo00000oooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000oooo
ooo<ooooo`00:?ooool00ol0003oooooo`000005ooooo`04o`000?ooooooooooo`0000?ooooo00?o
0000ooooooooool01?ooool01Ol0003ooooooooooooooooo00000?ooooooc?ooool002Sooooo00?o
0000ooooool000001Oooool4o`0000?ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo00000?ooooooc?ooool002Sooooo00?o0000ooooool000001Oooool01?l0003ooooooooo
ool00003ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00003oooooolco
oooo000Xooooo`03o`000?oooooo000000Gooooo00Co0000oooooooooooo00000oooool00ol0003o
ooooooooo`04ooooo`05o`000?ooooooooooooooool00000ooooooo<ooooo`00:?ooool2o`0000Ko
oooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooo
ooooool00000ooooooo<ooooo`00:?ooool2o`0000Kooooo00Co0000oooooooooooo00000oooool0
0ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000ooooooo<ooooo`00:Oooool0
0ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01?oo
ool01Ol0003ooooooooooooooooo00000?ooooooc?ooool002Wooooo00?o0000ooooooooool01?oo
ool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooo
ooooo`00003oooooolcooooo000`ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooooooo
ool01?ooool01Ol0003ooooooooooooooooo00000?ooooooc?ooool0033ooooo00Co0000oooooooo
oooo00000oooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000ooooooo<
ooooo`00<?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Cooooo00Go0000
ooooooooooooooooo`00003oooooolcooooo000`ooooo`04o`000?ooooooooooo`0000?ooooo00?o
0000ooooooooool01?ooool01Ol0003ooooooooooooooooo00000?ooooooc?ooool0033ooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooooooo`06ooooo`04o`000?ooooooooooo`000?oo
ooooc?ooool0033ooooo1?l00002ooooo`03o`000?oooooooooo00Kooooo00Co0000oooooooooooo
0000ooooooo<ooooo`00<?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Ko
oooo00Co0000oooooooooooo0000ooooooo<ooooo`00<?ooool01?l0003oooooooooool00002oooo
o`03o`000?oooooooooo00Kooooo00Co0000oooooooooooo0000ooooooo<ooooo`00<?ooool01?l0
003oooooooooool00002ooooo`03o`000?oooooooooo00Kooooo00Co0000oooooooooooo0000oooo
ooo<ooooo`00<?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Kooooo00Co
0000oooooooooooo0000ooooooo<ooooo`00<?ooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo00Kooooo00Co0000oooooooooooo0000ooooooo<ooooo`00<?ooool01?l0003ooooo
ooooool00002ooooo`03o`000?oooooooooo00Kooooo00Co0000oooooooooooo0000ooooooo<oooo
o`00<?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Kooooo00Co0000oooo
oooooooo0000ooooooo<ooooo`00<?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo
oooo00Kooooo00Co0000oooooooooooo0000ooooooo<ooooo`00<?ooool01?l0003oooooooooool0
0002ooooo`03o`000?oooooooooo00Kooooo00Co0000oooooooooooo0000ooooooo<ooooo`00<?oo
ool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Kooooo00Co0000oooooooooooo
0000ooooooo<ooooo`00<?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Ko
oooo00Co0000oooooooooooo0000ooooooo<ooooo`00<?ooool4o`0000;ooooo00?o0000oooooooo
ool01_ooool01?l0003oooooooooool0003oooooolcooooo000`ooooo`04o`000?ooooooooooo`00
00;ooooo00?o0000ooooooooool01_ooool01?l0003oooooooooool0003oooooolcooooo000`oooo
o`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01_ooool00ol0003oooooo`00003o
ooooolgooooo000`ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooo`00003oooooolgooooo000`ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool01_ooool00ol0003oooooo`00003oooooolgooooo000`ooooo`04o`000?oooooooooo
o`0000;ooooo00?o0000ooooooooool01_ooool00ol0003oooooo`00003oooooolgooooo000?oooo
o`;ok^k^0oooool2onk^kQ[ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooo00000?oooooocOooool000[ooooo0_l000002_l@413oooooooooooo^k^ko
EEEEonk^k_ooooook^k^oeEEEOo^k^h3ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o
<S8bonk^kP_ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooo00000?oooooocOooool000_ooooo00?o0000ooooooooool00_ooool01Oo^k^koEEEEomgM
gOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo0000
0?oooooocOooool000Sooooo1Ol00004ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000oooooooo
ool00_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooo00000?oooooocOooool000Sooooo00CoA4A4omgM
gOoooooo00001?ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000000_ooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooo00000?oooooocOooool000Sooooo00CogMgMoeEEEOoooooo
00000oooool01oo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000002oooool4o`0000;ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooo`00003oooooolgooooo0009ooooo`03ogMgMoo<c<co000000?ooooo0_o^k^h3
ooooo`;ok^k^1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41002ooo
ool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooool00000
ooooooo=ooooo`002Oooool00oo^k^koA4A4o`00000?ooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooo`00003oooooolgooooo000:ooooo`03ogMgMol0003ooooo00cooooo
00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo0_l00006ooooo`04
o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01_ooool00ol0003oooooo`00003ooooo
olgooooo000Wooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooo00000?oooooocOooool002Oooooo00Co0000oooo
oooooooo00001Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooool00000ooooooo=ooooo`009oooool3o`0000Kooooo00Co0000oooooooooooo00000_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooo00000?oooooocOooool002Sooooo00?o0000
ooooooooool01Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooool00000ooooooo=ooooo`00:Oooool00ol0003oooooooooo`04ooooo`04o`000?oooooo
ooooo`0000;ooooo00?o0000ooooooooool01_ooool00ol0003oooooo`00003oooooolgooooo000`
ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01_ooool00ol0003oooooo`00
003oooooolgooooo000`ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooo`00003oooooolgooooo000`ooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooooooool01_ooool00ol0003oooooo`00003oooooolgooooo000`ooooo`Co00000_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooo00000?oooooocOooool0033ooooo00Oo0000oooo
ooooooooooooo`000?oooooo000000Wooooo0_l0003oooooolgooooo000`ooooo`07o`000?oooooo
ooooooooool0003oooooo`000009ooooo`;o0000ooooooo=ooooo`00<?ooool01ol0003ooooooooo
oooooooo0000ooooool000002Oooool2o`000?oooooocOooool0033ooooo00Oo0000oooooooooooo
ooooo`000?oooooo000000Wooooo0_l0003oooooolgooooo000`ooooo`04o`000?oooooooooooooo
o`;o00002_ooool2o`000?oooooocOooool0033ooooo00Co0000oooooooooooooooo0_l0000:oooo
o`;o0000ooooooo=ooooo`00<?ooool01?l0003oooooooooooooool2o`0000[ooooo00?o0000oooo
ooooool0ooooooo<ooooo`00<?ooool01?l0003oooooooooooooool2o`0000[ooooo00?o0000oooo
ooooool0ooooooo<ooooo`00<?ooool01?l0003oooooooooooooool2o`000?oooooofOooool0033o
oooo00Co0000oooooooooooooooo0_l0003oooooomWooooo000`ooooo`04o`000?oooooooooooooo
o`;o0000oooooooIooooo`00<?ooool3o`000003ooooool0003o00000?oooooofOooool0033ooooo
00Co0000oooooooooooooooo0_l0003oooooomWooooo000`ooooo`04o`000?ooooooooooooooo`;o
0000oooooooIooooo`00<?ooool01?l0003oooooooooooooool2o`000?oooooofOooool0033ooooo
00Co0000oooooooooooooooo0_l0003oooooomWooooo000`ooooo`04o`000?ooooooooooooooo`;o
0000oooooooIooooo`00<?ooool01?l0003oooooooooooooool2o`000?oooooofOooool0033ooooo
00Co0000oooooooooooooooo0_l0003oooooomWooooo000`ooooo`04o`000?ooooooooooooooo`;o
0000oooooooIooooo`00<?ooool01?l0003oooooooooooooool2o`000?oooooofOooool0033ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`3oooooomOooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0033ooooo0ol0003oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooo
ooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool00?ooooooooooool@
ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooo
oooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3o
oooo002Pooooo`;o00001?ooool00onj^[[o<S8booooo`04ooooo`;o00001_ooool00ol0003o^[Zj
ooooo`3ooooooeOooooo002Pooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`;o<S8boooooomHooooo`00SOooool3o`0000;ooooo00Ko<S8b
oa0@4?ooooooooooonk^k_mEEED2o`000003odA4A?nj^[[ooooo00?ooooo00?o0000ooooooooool0
0_ooool01OnHV9So410@o`000?l0003oZJVY00Cooooo00?o0000ooooooooool01?ooool00on7QhOo
0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X02Oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B46ooooo`;o000000Oo410@ooooooo<c<cok^k^ooooooo^k^koc<c<00Cooooo
1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^4oooool01_l@413o<S8bo`000?l0
003o410@ojVYZ@;ooooo00Kok^k^oeEEEOl0003o0000odA4A?nj^[X3ooooo`05ofIVI_l0003o0000
odA4A?o<c<`0j?ooool008kooooo00Go0000ooooooooooooc<c<oa0@4003ooooo`06oeEEEOmgMgOo
ooooonk^k_mgMgOo410@1?ooool00ol0003oooooooooo`02ooooo`06o`000?nYZJWoEEEEoiRHV?mE
EEGo^[Zj0oooool00ol0003oooooooooo`04ooooo`03olc<c?l0003o410@00cooooo00Ko410@okZj
^_o^k^koMgMgoa0@4?ooool6o`0000;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1oooool02?l0003oooooooooooo^k^koEEEEomgMgOmEEEGok^k^1_ooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool01_l0003oZJVYoooooooooooo^[Zjo`0000;o
oooo00KoEEEEogMgMoooooook^k^ogMgMol@4102ooooo`06ofIVI_mgMgOooooooooooon7QhOo410@
j?ooool008kooooo00Go0000ooooooooooooEEEEohN7Q`03ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool00_ooool01_lb<S;ok^k^oiRHV?mEEEGogMgMoa0@40?ooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0;ooooo`05oa0@4?ooooooooooooooool@41002oooool5
o`0000;ooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooo
ooooooooool@41005?ooool01Onj^[[oQhN7ofIVI_mVIVKo410@00;ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`3[ooooo`00S_ooool01Ol0003oooooomgMgOl0003ok^k^00?ooooo
1_l00004ooooo`03o`000?oooooooooo00;ooooo00Oo^[ZjodA4A?o<c<co8B4Qooooool@413oc<c<
00;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`03ooooo`Ko00000_ooool01Ol0
003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00000_ooool01Oo^k^koEEEEomgM
gOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000001?o
oooo00Ko<S8bob4Q8OmgMgOoMgMgohN7Qoo^k^h2ooooo`Ko00000_ooool00ol0003oooooooooo`3[
ooooo`00S_ooool3o`000003oa0@4?nHV9Sooooo00;ooooo00KoEEEEohN7Qoo^k^koooooohN7Qolb
<S84ooooo`03o`000?oooooooooo00;ooooo00Ook^k^o`000?oooooo0000oooooomVIVKoQhN700;o
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0;ooooo`05o`000?oooooooooooooo
ool000002oooool01?oMgMgoEEEEooooool00002ooooo`05olc<c?o^k^koooooonk^k_o<c<`01_oo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000004oooool01_l0003o^[Zj
ooooooo^k^koMgMgo`0000;ooooo00KoEEEEohN7Qoo^k^koooooohN7Qolb<S82ooooo`06ofIVI_mg
MgOooooooooooon7QhOo0000j?ooool008kooooo00Go0000ooooooooooooc<c<o`000003ooooo`06
onk^k_mEEEGo0000o`000?m4A4Cok^k^1?ooool00ol0003oooooooooo`02ooooo`04ofIVI_nHV9So
oooooc8b<P;o^[Zj00Co0000oooooooooooo00004oooool00ol@413o0000o`000003o`0000[ooooo
00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000gooooo00?o0000oooooooo
ool00_ooool01Ol@413ooooooooooooooooo410@00Oooooo0ol00002ooooo`?o00001?ooool01_nY
ZJWo8B4Qo`000?l0003o<S8bo`0000;ooooo00Kok^k^oeEEEOl0003o0000odA4A?o^k^h2ooooo`06
onk^k_mVIVKo0000o`000?m4A4Co0000j?ooool008kooooo00Go0000ooooooooooooc<c<o`00000=
ooooo`03o`000?oooooooooo00Gooooo00?oIVIVohN7Qoooool00oooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000000gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`3oooooo`;ooooo002=ooooo`Co000000?o
410@ojVYZOooool03?ooool2o`0000Kooooo00?oZJVYodA4A?ooool00_ooool2o`0001Gooooo00?o
0000ooooooooool02oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool0
2_ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_ooool4o`0000;o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3oooooo`;ooooo003oooooo`Kooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`3oooooo`;ooooo003oooooo`Kooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`3oooooo`;ooooo003oooooo`Gooooo0_l00003
ooooo`;o0000ooooool4ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooo
ooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@oooo
o`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooo
oooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo
003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooo
oooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool0
0001\
\>"],
  ImageRangeCache->{{{0, 525.688}, {324.5, 0}} -> {0, -6.34248*^6, 0, 53093}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0.309017 5.42214e-08 [
[.32684 .29652 -16.5 -12.5 ]
[.32684 .29652 16.5 0 ]
[.54329 .29652 -16.5 -12.5 ]
[.54329 .29652 16.5 0 ]
[.75974 .29652 -22.5 -12.5 ]
[.75974 .29652 22.5 0 ]
[.97619 .29652 -16.5 -12.5 ]
[.97619 .29652 16.5 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 64 6 ]
[.09789 .09213 -34.5 -6.25 ]
[.09789 .09213 0 6.25 ]
[.09789 .20057 -34.5 -6.25 ]
[.09789 .20057 0 6.25 ]
[.09789 .41746 -28.5 -6.25 ]
[.09789 .41746 0 6.25 ]
[.09789 .5259 -28.5 -6.25 ]
[.09789 .5259 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -62.8125 0 ]
[.5 .63053 62.8125 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 .30902 m
.32684 .31527 L
s
gsave
.32684 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 .30902 m
.54329 .31527 L
s
gsave
.54329 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 .30902 m
.75974 .31527 L
s
gsave
.75974 .29652 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 .30902 m
.15368 .31277 L
s
.19697 .30902 m
.19697 .31277 L
s
.24026 .30902 m
.24026 .31277 L
s
.28355 .30902 m
.28355 .31277 L
s
.37013 .30902 m
.37013 .31277 L
s
.41342 .30902 m
.41342 .31277 L
s
.45671 .30902 m
.45671 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.58658 .30902 m
.58658 .31277 L
s
.62987 .30902 m
.62987 .31277 L
s
.67316 .30902 m
.67316 .31277 L
s
.71645 .30902 m
.71645 .31277 L
s
.80303 .30902 m
.80303 .31277 L
s
.84632 .30902 m
.84632 .31277 L
s
.88961 .30902 m
.88961 .31277 L
s
.9329 .30902 m
.9329 .31277 L
s
.0671 .30902 m
.0671 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09213 m
.11664 .09213 L
s
gsave
.09789 .09213 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .20057 m
.11664 .20057 L
s
gsave
.09789 .20057 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .41746 m
.11664 .41746 L
s
gsave
.09789 .41746 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .5259 m
.11664 .5259 L
s
gsave
.09789 .5259 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.11039 .11924 m
.11414 .11924 L
s
.11039 .14635 m
.11414 .14635 L
s
.11039 .17346 m
.11414 .17346 L
s
.11039 .22768 m
.11414 .22768 L
s
.11039 .2548 m
.11414 .2548 L
s
.11039 .28191 m
.11414 .28191 L
s
.11039 .33613 m
.11414 .33613 L
s
.11039 .36324 m
.11414 .36324 L
s
.11039 .39035 m
.11414 .39035 L
s
.11039 .44457 m
.11414 .44457 L
s
.11039 .47168 m
.11414 .47168 L
s
.11039 .49879 m
.11414 .49879 L
s
.11039 .06502 m
.11414 .06502 L
s
.11039 .03791 m
.11414 .03791 L
s
.11039 .0108 m
.11414 .0108 L
s
.11039 .55301 m
.11414 .55301 L
s
.11039 .58012 m
.11414 .58012 L
s
.11039 .60723 m
.11414 .60723 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -123.812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.812 moveto
(@) show
81.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.812 moveto
(D) show
93.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.6) show
135.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
141.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
153.000 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
157.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
166.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
184.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30883 m
.02532 .30876 L
.02609 .30873 L
.02691 .3087 L
.02735 .30869 L
.02775 .30868 L
.02794 .30868 L
.02804 .30868 L
.02815 .30868 L
.02824 .30868 L
.02834 .30868 L
.02844 .30867 L
.02852 .30867 L
.02858 .30867 L
.02863 .30867 L
.02869 .30867 L
.02875 .30867 L
.02881 .30868 L
.02887 .30868 L
.02897 .30868 L
.02907 .30868 L
.02917 .30868 L
.02938 .30868 L
.02959 .30869 L
.02982 .30869 L
.03029 .30871 L
.03071 .30873 L
.03111 .30875 L
.03186 .30881 L
.03266 .3089 L
.03354 .30902 L
.03512 .3093 L
.03681 .30967 L
.03984 .31039 L
.0406 .31053 L
.04139 .31066 L
.04181 .31071 L
.04205 .31073 L
.04227 .31074 L
.04237 .31075 L
.04247 .31075 L
.04256 .31076 L
.04265 .31076 L
.04276 .31076 L
.04285 .31076 L
.04296 .31076 L
.04301 .31076 L
.04307 .31076 L
.04317 .31076 L
.04322 .31076 L
Mistroke
.04328 .31076 L
.04347 .31075 L
.04358 .31074 L
.04369 .31073 L
.0439 .31071 L
.04432 .31065 L
.0447 .31058 L
.04542 .31039 L
.04618 .3101 L
.04695 .30973 L
.04776 .30924 L
.04924 .30811 L
.05256 .30486 L
.05423 .3033 L
.05496 .30275 L
.05535 .30251 L
.05576 .30229 L
.05596 .30221 L
.05617 .30213 L
.05636 .30208 L
.05653 .30203 L
.0567 .302 L
.0568 .30199 L
.05688 .30198 L
.05697 .30198 L
.05707 .30198 L
.05717 .30198 L
.05726 .30198 L
.05735 .30199 L
.05745 .30201 L
.05754 .30202 L
.05763 .30204 L
.05783 .3021 L
.05803 .30217 L
.05842 .30237 L
.05884 .30266 L
.05923 .30301 L
.0596 .30341 L
.06043 .30458 L
.06124 .30608 L
.06211 .30806 L
.06541 .31823 L
.06706 .32379 L
.06786 .32626 L
.06859 .32822 L
.06935 .32986 L
.0697 .33046 L
.07007 .33096 L
.07026 .33117 L
.07046 .33134 L
Mistroke
.07055 .33141 L
.07065 .33147 L
.07074 .33151 L
.07083 .33154 L
.07093 .33157 L
.07099 .33158 L
.07105 .33159 L
.0711 .33159 L
.07116 .33159 L
.07126 .33157 L
.07135 .33155 L
.07144 .33151 L
.07154 .33146 L
.07165 .33139 L
.07185 .33122 L
.07205 .331 L
.07241 .33045 L
.0728 .32965 L
.07323 .32852 L
.07399 .3258 L
.0747 .3225 L
.0762 .31314 L
.07785 .29971 L
.07954 .28421 L
.08108 .2703 L
.08259 .25905 L
.08336 .25495 L
.08379 .25322 L
.08419 .25204 L
.0844 .25161 L
.08459 .25132 L
.08469 .25121 L
.08475 .25116 L
.08481 .25113 L
.08486 .2511 L
.08492 .25108 L
.08498 .25108 L
.08503 .25108 L
.08513 .25111 L
.08523 .25117 L
.08533 .25126 L
.08541 .25137 L
.08563 .25174 L
.08583 .25223 L
.0862 .25351 L
.08655 .25511 L
.08693 .25734 L
.08732 .26024 L
.08809 .26738 L
.0889 .27724 L
Mistroke
.09038 .3002 L
.0937 .36618 L
.09537 .39744 L
.0961 .40878 L
.09649 .41395 L
.09691 .41876 L
.09731 .4226 L
.09768 .42535 L
.09786 .42641 L
.09805 .42735 L
.09823 .42803 L
.09832 .42829 L
.0984 .42849 L
.0985 .42867 L
.09855 .42874 L
.09861 .4288 L
.0987 .42885 L
.0988 .42884 L
.0989 .42878 L
.09899 .42865 L
.09909 .42847 L
.09917 .42826 L
.09937 .42756 L
.09959 .42649 L
.0998 .42518 L
.09999 .42371 L
.10036 .42014 L
.10076 .41522 L
.10149 .40354 L
.10235 .38516 L
.10314 .36435 L
.10632 .25506 L
.10792 .19682 L
.10938 .15162 L
.11019 .13215 L
.11056 .12493 L
.11095 .11859 L
.11115 .11591 L
.11137 .1134 L
.11157 .11151 L
.11176 .11014 L
.11186 .10953 L
.11197 .10898 L
.11204 .10874 L
.11209 .10855 L
.11215 .10839 L
.11221 .10828 L
.11226 .1082 L
.11232 .10815 L
.11241 .10814 L
Mistroke
.11247 .10818 L
.11253 .10826 L
.11263 .10849 L
.11273 .10882 L
.11284 .1093 L
.11303 .11048 L
.11322 .11203 L
.11339 .11381 L
.11379 .11911 L
.11421 .12663 L
.11491 .14339 L
.11568 .16773 L
.11724 .23299 L
.11891 .32019 L
.12049 .40754 L
.12222 .4942 L
.12302 .52699 L
.12346 .5423 L
.12387 .55475 L
.12425 .56449 L
.12467 .57288 L
.12486 .57583 L
.12505 .57845 L
.12522 .58026 L
.1254 .58178 L
.12551 .58245 L
.12561 .58292 L
.1257 .58324 L
.1258 .58344 L
.12589 .58349 L
.12597 .58344 L
.12606 .58326 L
.12616 .58293 L
.12626 .58245 L
.12637 .58176 L
.12659 .57985 L
.12679 .57745 L
.12698 .57467 L
.12735 .56764 L
.12769 .55949 L
.12845 .53536 L
.12925 .50183 L
.12998 .46435 L
.13165 .36228 L
.13328 .25141 L
.13481 .15215 L
.13627 .07368 L
.1371 .04055 L
.13749 .02801 L
.13785 .01866 L
Mistroke
.13823 .01086 L
.13844 .00758 L
.13864 .00514 L
.13873 .00425 L
.13882 .00346 L
.1389 .00289 L
.13899 .00241 L
.13909 .00202 L
.13917 .0018 L
.13928 .0017 L
.13937 .00177 L
.13948 .00202 L
.13953 .00221 L
.13959 .00247 L
.13969 .00307 L
.13978 .00379 L
.14 .00596 L
.14023 .00915 L
.14065 .01721 L
.14104 .0271 L
.14182 .05417 L
.14256 .08703 L
.14422 .18333 L
.14735 .39809 L
.14895 .49327 L
.14985 .53531 L
.15028 .55164 L
.15068 .56456 L
.15107 .57479 L
.15143 .58213 L
.15162 .58524 L
.15182 .58799 L
.15193 .58922 L
.15204 .59019 L
.15214 .591 L
.15224 .59158 L
.15235 .59203 L
.1524 .5922 L
.15246 .59232 L
.15256 .59242 L
.15261 .59241 L
.15266 .59235 L
.15276 .59214 L
.15285 .59182 L
.15295 .5913 L
.15304 .59067 L
.15326 .58876 L
.15345 .58639 L
.15389 .5789 L
.15427 .5704 L
Mistroke
.15467 .5591 L
.1554 .53345 L
.15705 .45461 L
.16036 .26189 L
.16201 .17837 L
.16281 .14625 L
.16354 .12317 L
.16391 .11393 L
.16431 .10577 L
.16468 .09987 L
.16485 .09782 L
.16503 .096 L
.16521 .0945 L
.1653 .09398 L
.16539 .09351 L
.16545 .09328 L
.1655 .0931 L
.1656 .09285 L
.1657 .09273 L
.16579 .09272 L
.16589 .09283 L
.16599 .09306 L
.16609 .09341 L
.16618 .09383 L
.16639 .09516 L
.16661 .09712 L
.16701 .10213 L
.16737 .10821 L
.16819 .12677 L
.16895 .14927 L
.16966 .17433 L
.17275 .30215 L
.17431 .36274 L
.17514 .38977 L
.17603 .41353 L
.17647 .42296 L
.17688 .43046 L
.17729 .43639 L
.17766 .44064 L
.17802 .44356 L
.17822 .44473 L
.1784 .44551 L
.1785 .44584 L
.17859 .44606 L
.1787 .44622 L
.17875 .44627 L
.17881 .44629 L
.1789 .44628 L
.17901 .44618 L
.1791 .446 L
Mistroke
.17919 .44578 L
.17929 .44547 L
.17938 .44512 L
.17958 .4441 L
.17978 .44281 L
.17999 .4411 L
.18073 .43279 L
.18115 .42646 L
.1816 .41873 L
.18239 .40258 L
.18545 .32673 L
.18716 .28686 L
.18871 .25898 L
.18949 .24899 L
.18992 .24461 L
.19033 .2414 L
.19068 .23923 L
.19088 .23826 L
.19107 .23754 L
.19126 .23695 L
.19137 .23671 L
.19147 .23652 L
.19156 .2364 L
.19165 .23631 L
.19175 .23626 L
.19185 .23626 L
.19195 .23629 L
.19201 .23633 L
.19206 .23638 L
.19217 .23652 L
.19228 .23672 L
.19249 .23723 L
.19268 .23784 L
.19314 .23992 L
.19357 .24258 L
.19435 .24886 L
.19519 .25747 L
.19847 .29873 L
.2001 .31747 L
.2009 .32502 L
.20163 .33074 L
.20238 .33536 L
.20309 .33853 L
.20348 .33976 L
.20385 .34058 L
.20405 .34092 L
.20424 .34114 L
.20435 .34123 L
.2044 .34127 L
.20446 .3413 L
Mistroke
.20451 .34133 L
.20457 .34135 L
.20467 .34136 L
.20477 .34136 L
.20487 .34134 L
.20492 .34132 L
.20497 .34129 L
.20509 .34122 L
.20519 .34113 L
.20529 .34102 L
.20549 .34076 L
.20588 .34004 L
.20623 .33915 L
.20705 .3364 L
.20791 .33265 L
.21097 .31612 L
.21268 .30762 L
.21423 .30178 L
.215 .2997 L
.21541 .29884 L
.21584 .29811 L
.21621 .29762 L
.21641 .29741 L
.21663 .29723 L
.21683 .2971 L
.21701 .29701 L
.21709 .29697 L
.21719 .29695 L
.21728 .29693 L
.21736 .29691 L
.21746 .29691 L
.21751 .2969 L
.21757 .29691 L
.21767 .29692 L
.21777 .29693 L
.21782 .29695 L
.21788 .29696 L
.21798 .297 L
.21821 .2971 L
.21841 .29722 L
.21859 .29736 L
.21901 .29774 L
.21973 .29865 L
.2205 .29987 L
.22354 .30583 L
.22522 .30889 L
.22596 .30999 L
.22677 .31101 L
.22755 .31178 L
.22828 .3123 L
Mistroke
.22869 .31251 L
.22905 .31266 L
.22926 .31272 L
.22948 .31278 L
.22958 .3128 L
.22969 .31281 L
.22979 .31283 L
.22988 .31284 L
.22998 .31284 L
.23003 .31285 L
.23008 .31285 L
.23017 .31285 L
.23027 .31285 L
.23036 .31285 L
.23046 .31284 L
.23055 .31284 L
.23064 .31283 L
.23083 .3128 L
.23103 .31276 L
.23145 .31266 L
.23182 .31254 L
.23221 .31238 L
.23292 .31205 L
.23625 .31003 L
.23792 .30912 L
.23865 .3088 L
.23946 .3085 L
.24023 .30828 L
.24095 .30814 L
.24135 .30808 L
.24172 .30804 L
.24192 .30802 L
.24214 .30801 L
.24224 .308 L
.24235 .308 L
.24245 .30799 L
.24254 .30799 L
.24264 .30799 L
.24269 .30799 L
.24275 .30799 L
.24281 .30799 L
.24287 .30799 L
.24297 .30799 L
.24307 .30799 L
.24316 .30799 L
.24326 .30799 L
.24337 .308 L
.24359 .30801 L
.24379 .30802 L
.24426 .30806 L
Mistroke
.24504 .30814 L
.24588 .30826 L
.24746 .30851 L
.24918 .30879 L
.24998 .30891 L
.25083 .30901 L
.25163 .30909 L
.25237 .30915 L
.25319 .3092 L
.25362 .30922 L
.25384 .30923 L
.25408 .30924 L
.25429 .30924 L
.25448 .30925 L
.25467 .30925 L
.25485 .30925 L
.25495 .30925 L
.25501 .30925 L
.25506 .30925 L
.25516 .30925 L
.25526 .30925 L
.25531 .30925 L
.25537 .30925 L
.25547 .30925 L
.25552 .30925 L
.25558 .30925 L
.25564 .30925 L
.2557 .30925 L
.2559 .30925 L
.25601 .30925 L
.25612 .30925 L
.25652 .30924 L
.25698 .30923 L
.25741 .30922 L
.25902 .30917 L
.26213 .30905 L
.26294 .30903 L
.26383 .30901 L
.26466 .30899 L
.26544 .30898 L
.26585 .30898 L
.26629 .30898 L
.26649 .30897 L
.2667 .30897 L
.26689 .30897 L
.26709 .30897 L
.26719 .30897 L
.26728 .30897 L
.26737 .30897 L
.26746 .30897 L
Mistroke
.26754 .30897 L
.26762 .30897 L
.26771 .30897 L
.2678 .30897 L
.2679 .30897 L
.26799 .30897 L
.2681 .30897 L
.2682 .30897 L
.26838 .30897 L
.26858 .30897 L
.269 .30897 L
.2694 .30898 L
.27015 .30898 L
.27184 .30899 L
.2733 .309 L
.27492 .30901 L
.27569 .30902 L
.27652 .30902 L
.27697 .30902 L
.27739 .30902 L
.27778 .30902 L
.2782 .30902 L
.27862 .30902 L
.279 .30902 L
.27918 .30902 L
.27937 .30902 L
.27956 .30902 L
.27973 .30902 L
.27983 .30902 L
.27993 .30902 L
.28003 .30902 L
.28012 .30902 L
.28022 .30902 L
.28028 .30902 L
.28033 .30902 L
.28043 .30902 L
.28054 .30902 L
.28064 .30902 L
.28075 .30902 L
.28095 .30902 L
.28139 .30902 L
.28179 .30902 L
.28216 .30902 L
.28301 .30902 L
.2847 .30902 L
.28621 .30902 L
.28784 .30902 L
.28873 .30902 L
.28955 .30902 L
.29034 .30902 L
Mistroke
.29073 .30902 L
.29094 .30902 L
.29117 .30902 L
.29139 .30902 L
.29159 .30902 L
.29178 .30902 L
.29188 .30902 L
.29199 .30902 L
.29208 .30902 L
.29217 .30902 L
.29225 .30902 L
.29234 .30902 L
.29244 .30902 L
.29253 .30902 L
.29263 .30902 L
.29273 .30902 L
.29279 .30902 L
.29285 .30902 L
.29295 .30902 L
.29318 .30902 L
.29339 .30902 L
.29361 .30902 L
.29441 .30902 L
.29765 .30902 L
.29913 .30902 L
.29992 .30902 L
.30076 .30902 L
.30122 .30902 L
.30164 .30902 L
.30245 .30902 L
.30285 .30902 L
.30306 .30902 L
.30328 .30902 L
.30348 .30902 L
.30369 .30902 L
.30389 .30902 L
.30407 .30902 L
.30417 .30902 L
.30428 .30902 L
.30437 .30902 L
.30447 .30902 L
.30453 .30902 L
.30458 .30902 L
.30463 .30902 L
.30469 .30902 L
.3048 .30902 L
.30485 .30902 L
.30491 .30902 L
.30501 .30902 L
.30511 .30902 L
Mistroke
.30529 .30902 L
.30549 .30902 L
.3057 .30902 L
.30648 .30902 L
.30719 .30902 L
.30882 .30902 L
.31035 .30902 L
.31182 .30902 L
.31264 .30902 L
.31339 .30902 L
.31378 .30902 L
.31419 .30902 L
.31454 .30902 L
.31492 .30902 L
.31516 .30902 L
.31537 .30902 L
.31557 .30902 L
.3158 .30902 L
.31599 .30902 L
.31618 .30902 L
.31628 .30902 L
.31638 .30902 L
.31643 .30902 L
.31648 .30902 L
.31659 .30902 L
.31668 .30902 L
.31677 .30902 L
.31687 .30902 L
.31698 .30902 L
.31707 .30902 L
.31715 .30902 L
.31734 .30902 L
.31755 .30902 L
.31775 .30902 L
.31818 .30902 L
.31905 .30902 L
.31986 .30902 L
.32134 .30902 L
.32296 .30902 L
.32373 .30902 L
.32455 .30902 L
.32543 .30902 L
.32585 .30902 L
.32624 .30902 L
.32663 .30902 L
.32706 .30902 L
.32749 .30902 L
.32773 .30902 L
.32795 .30902 L
.32815 .30902 L
Mistroke
.32825 .30902 L
.32835 .30902 L
.32845 .30902 L
.32853 .30902 L
.32862 .30902 L
.32872 .30902 L
.32878 .30902 L
.32883 .30902 L
.32893 .30902 L
.32899 .30902 L
.32904 .30902 L
.32916 .30902 L
.32926 .30902 L
.32935 .30902 L
.32956 .30902 L
.32995 .30902 L
.33035 .30902 L
.33109 .30902 L
.33275 .30902 L
.33436 .30902 L
.3352 .30902 L
.33609 .30902 L
.33689 .30902 L
.33731 .30902 L
.33777 .30902 L
.33818 .30902 L
.33857 .30902 L
.33895 .30902 L
.33931 .30902 L
.33968 .30902 L
.33989 .30902 L
.34008 .30902 L
.34019 .30902 L
.34029 .30902 L
.34038 .30902 L
.34048 .30902 L
.34059 .30902 L
.34069 .30902 L
.34075 .30902 L
.3408 .30902 L
.34085 .30902 L
.34091 .30902 L
.341 .30902 L
.34109 .30902 L
.34118 .30902 L
.34128 .30902 L
.34149 .30902 L
.34168 .30902 L
.34239 .30902 L
.34392 .30902 L
Mistroke
.34558 .30902 L
.34716 .30902 L
.34805 .30902 L
.34885 .30902 L
.34924 .30902 L
.34966 .30902 L
.3504 .30902 L
.35081 .30902 L
.3512 .30902 L
.35142 .30902 L
.35162 .30902 L
.35185 .30902 L
.35196 .30902 L
.35207 .30902 L
.35217 .30902 L
.35226 .30902 L
.35235 .30902 L
.35244 .30902 L
.35254 .30902 L
.35264 .30902 L
.35274 .30902 L
.3528 .30902 L
.35285 .30902 L
.3529 .30902 L
.35296 .30902 L
.35305 .30902 L
.35316 .30902 L
.35327 .30902 L
.35367 .30902 L
.35404 .30902 L
.35444 .30902 L
.35515 .30902 L
.35674 .30902 L
.35758 .30902 L
.35847 .30902 L
.35926 .30902 L
.36013 .30902 L
.36093 .30902 L
.36167 .30902 L
.36205 .30902 L
.36246 .30902 L
.36289 .30902 L
.3631 .30902 L
.36329 .30902 L
.36347 .30902 L
.36367 .30902 L
.36384 .30902 L
.36401 .30902 L
.3641 .30902 L
.36419 .30902 L
Mistroke
.36428 .30902 L
.36438 .30902 L
.36449 .30902 L
.36459 .30902 L
.36468 .30902 L
.36478 .30902 L
.36488 .30902 L
.36498 .30902 L
.3652 .30902 L
.36561 .30902 L
.36636 .30902 L
.36804 .30902 L
.36968 .30902 L
.37048 .30902 L
.37121 .30902 L
.37192 .30902 L
.37269 .30902 L
.37311 .30902 L
.3735 .30902 L
.3739 .30902 L
.37427 .30902 L
.37464 .30902 L
.37483 .30902 L
.37504 .30902 L
.37521 .30902 L
.37539 .30902 L
.37559 .30902 L
.37577 .30902 L
.37588 .30902 L
.37598 .30902 L
.37603 .30902 L
.37609 .30902 L
.37616 .30902 L
.37621 .30902 L
.37632 .30902 L
.37642 .30902 L
.37647 .30902 L
.37653 .30902 L
.37663 .30902 L
.37683 .30902 L
.37704 .30902 L
.37742 .30902 L
.37817 .30902 L
.37898 .30902 L
.38045 .30902 L
.38205 .30902 L
.38286 .30902 L
.38375 .30902 L
.38417 .30902 L
.38457 .30902 L
Mistroke
.38532 .30902 L
.38574 .30902 L
.38612 .30902 L
.38655 .30902 L
.38676 .30902 L
.387 .30902 L
.3872 .30902 L
.38731 .30902 L
.38742 .30902 L
.38752 .30902 L
.38761 .30902 L
.38771 .30902 L
.38781 .30902 L
.3879 .30902 L
.388 .30902 L
.38808 .30902 L
.38817 .30902 L
.38827 .30902 L
.38837 .30902 L
.38856 .30902 L
.38877 .30902 L
.38901 .30902 L
.38943 .30902 L
.39023 .30902 L
.39179 .30902 L
.39262 .30902 L
.39351 .30902 L
.39436 .30902 L
.39513 .30902 L
.39588 .30902 L
.39629 .30902 L
.39666 .30902 L
.39703 .30902 L
.39743 .30902 L
.39785 .30902 L
.39804 .30902 L
.39825 .30902 L
.39843 .30902 L
.39862 .30902 L
.39882 .30902 L
.39891 .30902 L
.39901 .30902 L
.39911 .30902 L
.3992 .30902 L
.39929 .30902 L
.39938 .30902 L
.39947 .30902 L
.39956 .30902 L
.39964 .30902 L
.39972 .30902 L
Mistroke
.39982 .30902 L
.39991 .30902 L
.40012 .30902 L
.40031 .30902 L
.40049 .30902 L
.40132 .30902 L
.40302 .30902 L
.40448 .30902 L
.40532 .30902 L
.4061 .30902 L
.40686 .30902 L
.40769 .30902 L
.40814 .30902 L
.40857 .30902 L
.40896 .30902 L
.40938 .30902 L
.40958 .30902 L
.4098 .30902 L
.41 .30902 L
.4102 .30902 L
.41039 .30902 L
.4105 .30902 L
.41059 .30902 L
.41069 .30902 L
.41077 .30902 L
.41086 .30902 L
.41095 .30902 L
.41105 .30902 L
.41111 .30902 L
.41116 .30902 L
.41126 .30902 L
.41132 .30902 L
.41137 .30902 L
.41156 .30902 L
.41176 .30902 L
.41218 .30902 L
.41264 .30902 L
.41434 .30902 L
.41589 .30902 L
.41666 .30902 L
.4175 .30902 L
.41829 .30902 L
.41902 .30902 L
.4194 .30902 L
.4198 .30902 L
.42015 .30902 L
.42053 .30902 L
.42076 .30902 L
.42097 .30902 L
.42119 .30902 L
Mistroke
.42139 .30902 L
.42159 .30902 L
.42178 .30902 L
.42197 .30902 L
.42208 .30902 L
.42218 .30902 L
.42229 .30902 L
.42238 .30902 L
.42247 .30902 L
.42256 .30902 L
.42266 .30902 L
.42272 .30902 L
.42277 .30902 L
.42287 .30902 L
.42297 .30902 L
.42332 .30902 L
.4237 .30902 L
.42536 .30902 L
.42694 .30902 L
.42777 .30902 L
.42866 .30902 L
.42953 .30902 L
.43031 .30902 L
.43069 .30902 L
.4311 .30902 L
.43146 .30902 L
.43184 .30902 L
.43224 .30902 L
.43261 .30902 L
.43283 .30902 L
.43304 .30902 L
.43323 .30902 L
.43334 .30902 L
.43344 .30902 L
.43355 .30902 L
.43361 .30902 L
.43366 .30902 L
.43376 .30902 L
.43382 .30902 L
.43387 .30902 L
.43397 .30902 L
.43407 .30902 L
.43417 .30902 L
.43426 .30902 L
.43448 .30902 L
.43471 .30902 L
.43513 .30902 L
.43669 .30902 L
.43752 .30902 L
.43841 .30902 L
Mistroke
.43926 .30902 L
.44004 .30902 L
.44083 .30902 L
.44157 .30902 L
.44197 .30902 L
.44234 .30902 L
.44276 .30902 L
.44316 .30902 L
.44353 .30902 L
.44387 .30902 L
.44405 .30902 L
.44424 .30902 L
.44445 .30902 L
.44464 .30902 L
.44474 .30902 L
.44484 .30902 L
.44494 .30902 L
.44504 .30902 L
.44509 .30902 L
.44515 .30902 L
.4452 .30902 L
.44526 .30902 L
.44536 .30902 L
.44542 .30902 L
.44547 .30902 L
.44558 .30902 L
.44568 .30902 L
.44586 .30902 L
.44627 .30902 L
.44698 .30902 L
.44776 .30902 L
.44932 .30902 L
.45015 .30902 L
.45104 .30902 L
.4519 .30902 L
.45268 .30902 L
.45305 .30902 L
.45346 .30902 L
.45382 .30902 L
.45421 .30902 L
.45463 .30902 L
.45483 .30902 L
.45504 .30902 L
.45522 .30902 L
.45543 .30902 L
.45561 .30902 L
.45579 .30902 L
.45589 .30902 L
.45601 .30902 L
.45611 .30902 L
Mistroke
.45621 .30902 L
.4563 .30902 L
.4564 .30902 L
.4565 .30902 L
.4566 .30902 L
.45665 .30902 L
.45671 .30902 L
.45682 .30902 L
.45702 .30902 L
.45725 .30902 L
.45747 .30902 L
.46061 .30902 L
.46143 .30902 L
.46233 .30902 L
.46317 .30902 L
.46394 .30902 L
.46432 .30902 L
.46473 .30902 L
.46507 .30902 L
.46545 .30902 L
.46569 .30902 L
.4659 .30902 L
.4661 .30902 L
.46632 .30902 L
.46651 .30902 L
.4667 .30902 L
.46691 .30902 L
.46702 .30902 L
.46711 .30902 L
.4672 .30902 L
.4673 .30902 L
.46741 .30902 L
.46751 .30902 L
.4676 .30902 L
.4677 .30902 L
.46779 .30902 L
.46788 .30902 L
.46793 .30902 L
.46799 .30902 L
.46809 .30902 L
.46831 .30902 L
.46872 .30902 L
.46953 .30902 L
.47041 .30902 L
.47129 .30902 L
.47212 .30902 L
.47293 .30902 L
.47368 .30902 L
.47441 .30902 L
.47519 .30902 L
Mistroke
.47559 .30902 L
.47596 .30902 L
.47638 .30902 L
.47659 .30902 L
.47682 .30902 L
.47702 .30902 L
.47724 .30902 L
.47745 .30902 L
.47763 .30902 L
.47786 .30902 L
.47797 .30902 L
.47809 .30902 L
.47819 .30902 L
.4783 .30902 L
.47836 .30902 L
.47842 .30902 L
.47847 .30902 L
.47852 .30902 L
.47862 .30902 L
.47868 .30902 L
.47873 .30902 L
.47882 .30902 L
.47892 .30902 L
.47898 .30902 L
.47904 .30902 L
.47915 .30902 L
.47935 .30902 L
.47955 .30902 L
.47976 .30902 L
.48014 .30902 L
.48175 .30902 L
.48259 .30902 L
.48348 .30902 L
.48428 .30902 L
.48471 .30902 L
.48516 .30902 L
.48558 .30902 L
.48596 .30902 L
.4867 .30902 L
.48709 .30902 L
.4875 .30902 L
.48785 .30902 L
.48824 .30902 L
.48846 .30902 L
.48865 .30902 L
.48888 .30902 L
.48899 .30902 L
.4891 .30902 L
.48921 .30902 L
.4893 .30902 L
Mistroke
.4894 .30902 L
.48949 .30902 L
.48959 .30902 L
.48965 .30902 L
.4897 .30902 L
.4898 .30902 L
.48986 .30902 L
.48991 .30902 L
.49001 .30902 L
.49006 .30902 L
.49012 .30902 L
.49031 .30902 L
.49042 .30902 L
.49053 .30902 L
.49075 .30902 L
.49154 .30902 L
.49303 .30902 L
.49386 .30902 L
.49464 .30902 L
.49545 .30902 L
.49587 .30902 L
.49633 .30902 L
.49677 .30902 L
.49718 .30902 L
.49755 .30902 L
.49797 .30902 L
.49835 .30902 L
.4987 .30902 L
.49907 .30902 L
.49946 .30902 L
.49967 .30902 L
.49989 .30902 L
.50009 .30902 L
.50028 .30902 L
.50039 .30902 L
.5005 .30902 L
.50055 .30902 L
.50061 .30902 L
.50067 .30902 L
.50073 .30902 L
.50079 .30902 L
.50084 .30902 L
.50094 .30902 L
.501 .30902 L
.50105 .30902 L
.50116 .30902 L
.50126 .30902 L
.50135 .30902 L
.50153 .30902 L
.50195 .30902 L
Mistroke
.50278 .30902 L
.50436 .30902 L
.50519 .30902 L
.50608 .30902 L
.50653 .30902 L
.50695 .30902 L
.50735 .30902 L
.50773 .30902 L
.50847 .30902 L
.50885 .30902 L
.50926 .30902 L
.50966 .30902 L
.51002 .30902 L
.51022 .30902 L
.51044 .30902 L
.51063 .30902 L
.51084 .30902 L
.51103 .30902 L
.51121 .30902 L
.51131 .30902 L
.5114 .30902 L
.5115 .30902 L
.5116 .30902 L
.51169 .30902 L
.51178 .30902 L
.51186 .30902 L
.51194 .30902 L
.51203 .30902 L
.51213 .30902 L
.51231 .30902 L
.5125 .30902 L
.5127 .30902 L
.51307 .30902 L
.5139 .30902 L
.51559 .30902 L
.5164 .30902 L
.51729 .30902 L
.51769 .30902 L
.51812 .30902 L
.5189 .30902 L
.51933 .30902 L
.51972 .30902 L
.52016 .30902 L
.52038 .30902 L
.52062 .30902 L
.52083 .30902 L
.52102 .30902 L
.52139 .30902 L
.5216 .30902 L
.52171 .30902 L
Mistroke
.52183 .30902 L
.52193 .30902 L
.52204 .30902 L
.52214 .30902 L
.52224 .30902 L
.52233 .30902 L
.52243 .30902 L
.52248 .30902 L
.52253 .30902 L
.52263 .30902 L
.52274 .30902 L
.52283 .30902 L
.52294 .30902 L
.52305 .30902 L
.52323 .30902 L
.5234 .30902 L
.52379 .30902 L
.52546 .30902 L
.5263 .30902 L
.52709 .30902 L
.52781 .30902 L
.52858 .30902 L
.52901 .30902 L
.52941 .30902 L
.52978 .30902 L
.53016 .30902 L
.53059 .30902 L
.53097 .30902 L
.53139 .30902 L
.53163 .30902 L
.53185 .30902 L
.53204 .30902 L
.53225 .30902 L
.53248 .30902 L
.53269 .30902 L
.53278 .30902 L
.53289 .30902 L
.53297 .30902 L
.53307 .30902 L
.53317 .30902 L
.53323 .30902 L
.53329 .30902 L
.53338 .30902 L
.53349 .30902 L
.53359 .30902 L
.53368 .30902 L
.53378 .30902 L
.53389 .30902 L
.53407 .30902 L
.53427 .30902 L
Mistroke
.53498 .30902 L
.53667 .30902 L
.53748 .30902 L
.53822 .30902 L
.53899 .30902 L
.53938 .30902 L
.53982 .30902 L
.54056 .30902 L
.54096 .30902 L
.54134 .30902 L
.54172 .30902 L
.54213 .30902 L
.54234 .30902 L
.54256 .30902 L
.54275 .30902 L
.54296 .30902 L
.54317 .30902 L
.54336 .30902 L
.54354 .30902 L
.54363 .30902 L
.54374 .30902 L
.54383 .30902 L
.54391 .30902 L
.54401 .30902 L
.5441 .30902 L
.54419 .30902 L
.54426 .30902 L
.54435 .30902 L
.54444 .30902 L
.54454 .30902 L
.54465 .30902 L
.54487 .30902 L
.54527 .30902 L
.54616 .30902 L
.54701 .30902 L
.54778 .30902 L
.54853 .30902 L
.54935 .30902 L
.5498 .30902 L
.55021 .30902 L
.55061 .30902 L
.55103 .30902 L
.55143 .30902 L
.5518 .30902 L
.55216 .30902 L
.55253 .30902 L
.55294 .30902 L
.55332 .30902 L
.55354 .30902 L
.55374 .30902 L
Mistroke
.55397 .30902 L
.55407 .30902 L
.55418 .30902 L
.55428 .30902 L
.55438 .30902 L
.55447 .30902 L
.55456 .30902 L
.55466 .30902 L
.55471 .30902 L
.55477 .30902 L
.55487 .30902 L
.55497 .30902 L
.55502 .30902 L
.55507 .30902 L
.55517 .30902 L
.55528 .30902 L
.55539 .30902 L
.5556 .30902 L
.55579 .30902 L
.55727 .30902 L
.55877 .30902 L
.55962 .30902 L
.5604 .30902 L
.5608 .30902 L
.56123 .30902 L
.56169 .30902 L
.56211 .30902 L
.56252 .30902 L
.56289 .30902 L
.56332 .30902 L
.56353 .30902 L
.56373 .30902 L
.56392 .30902 L
.56413 .30902 L
.56431 .30902 L
.5645 .30902 L
.56471 .30902 L
.56481 .30902 L
.56493 .30902 L
.56503 .30902 L
.56513 .30902 L
.56523 .30902 L
.56532 .30902 L
.5654 .30902 L
.5655 .30902 L
.56559 .30902 L
.56569 .30902 L
.56577 .30902 L
.56585 .30902 L
.56593 .30902 L
Mistroke
.56603 .30902 L
.56639 .30902 L
.56679 .30902 L
.5685 .30902 L
.56931 .30902 L
.57005 .30902 L
.57082 .30902 L
.57123 .30902 L
.57166 .30902 L
.57239 .30902 L
.5728 .30902 L
.57318 .30902 L
.57358 .30902 L
.57379 .30902 L
.57402 .30902 L
.57423 .30902 L
.57443 .30902 L
.57463 .30902 L
.57481 .30902 L
.57499 .30902 L
.57518 .30902 L
.57537 .30902 L
.57548 .30902 L
.57558 .30902 L
.57566 .30902 L
.57576 .30902 L
.57586 .30902 L
.57595 .30902 L
.57604 .30902 L
.57613 .30902 L
.57621 .30902 L
.5763 .30902 L
.5764 .30902 L
.57649 .30902 L
.57669 .30902 L
.5769 .30902 L
.57711 .30902 L
.57785 .30902 L
.57953 .30902 L
.58035 .30902 L
.58079 .30902 L
.58125 .30902 L
.58165 .30902 L
.58209 .30902 L
.58246 .30902 L
.58286 .30902 L
.58328 .30902 L
.58368 .30902 L
.58407 .30902 L
.58443 .30902 L
Mistroke
.58481 .30902 L
.58503 .30902 L
.58524 .30902 L
.58546 .30902 L
.58566 .30902 L
.58588 .30902 L
.58599 .30902 L
.58611 .30902 L
.58621 .30902 L
.58631 .30902 L
.58642 .30902 L
.58647 .30902 L
.58653 .30902 L
.58663 .30902 L
.58668 .30902 L
.58674 .30902 L
.58683 .30902 L
.58693 .30902 L
.58702 .30902 L
.58711 .30902 L
.58729 .30902 L
.58768 .30902 L
.58936 .30902 L
.59018 .30902 L
.59108 .30902 L
.59149 .30902 L
.59192 .30902 L
.59233 .30902 L
.5927 .30902 L
.59306 .30902 L
.59346 .30902 L
.59388 .30902 L
.59427 .30902 L
.59464 .30902 L
.59504 .30902 L
.59537 .30902 L
.59575 .30902 L
.59593 .30902 L
.59614 .30902 L
.59636 .30902 L
.59646 .30902 L
.59656 .30902 L
.59665 .30902 L
.59674 .30902 L
.59683 .30902 L
.59692 .30902 L
.597 .30902 L
.5971 .30902 L
.5972 .30902 L
.5973 .30902 L
Mistroke
.5974 .30902 L
.59746 .30902 L
.59752 .30902 L
.59772 .30902 L
.59791 .30902 L
.59811 .30902 L
.59897 .30902 L
.60058 .30902 L
.60149 .30902 L
.60192 .30902 L
.60232 .30902 L
.60307 .30902 L
.60346 .30902 L
.60388 .30902 L
.60433 .30902 L
.60475 .30902 L
.60513 .30902 L
.60533 .30902 L
.60554 .30902 L
.60574 .30902 L
.60593 .30902 L
.6063 .30902 L
.6065 .30902 L
.60672 .30902 L
.60682 .30902 L
.60693 .30902 L
.60703 .30902 L
.60713 .30902 L
.60718 .30902 L
.60724 .30902 L
.60735 .30902 L
.60741 .30902 L
.60747 .30902 L
.60753 .30902 L
.60758 .30902 L
.60769 .30902 L
.60775 .30902 L
.60781 .30902 L
.60791 .30902 L
.60801 .30902 L
.60821 .30902 L
.6084 .30902 L
.60882 .30902 L
.6103 .30902 L
.61114 .30902 L
.61192 .30902 L
.6127 .30902 L
.61313 .30902 L
.61353 .30902 L
.61395 .30902 L
Mistroke
.6144 .30902 L
.61483 .30902 L
.61522 .30902 L
.6156 .30902 L
.6158 .30902 L
.616 .30902 L
.61618 .30902 L
.61638 .30902 L
.61656 .30902 L
.61673 .30902 L
.61694 .30902 L
.61714 .30902 L
.61736 .30902 L
.61748 .30902 L
.61759 .30902 L
.61768 .30902 L
.61777 .30902 L
.61787 .30902 L
.61797 .30902 L
.61803 .30902 L
.61808 .30902 L
.61819 .30902 L
.61829 .30902 L
.61838 .30902 L
.61858 .30902 L
.61876 .30902 L
.61916 .30902 L
.61988 .30902 L
.62074 .30902 L
.62154 .30902 L
.62227 .30902 L
.62306 .30902 L
.62351 .30902 L
.62393 .30902 L
.62431 .30902 L
.62472 .30902 L
.62511 .30902 L
.62548 .30902 L
.62588 .30902 L
.62611 .30902 L
.62632 .30902 L
.62652 .30902 L
.62673 .30902 L
.62697 .30902 L
.62719 .30902 L
.62739 .30902 L
.62758 .30902 L
.62768 .30902 L
.62778 .30902 L
.62789 .30902 L
Mistroke
.62795 .30902 L
.62801 .30902 L
.62811 .30902 L
.62816 .30902 L
.62821 .30902 L
.62831 .30902 L
.62841 .30902 L
.6285 .30902 L
.6286 .30902 L
.62877 .30902 L
.62899 .30902 L
.6292 .30902 L
.62959 .30902 L
.63106 .30902 L
.63183 .30902 L
.63225 .30902 L
.63265 .30902 L
.63302 .30902 L
.63343 .30902 L
.63413 .30902 L
.63452 .30902 L
.63489 .30902 L
.6353 .30902 L
.63573 .30902 L
.63595 .30902 L
.63618 .30902 L
.63639 .30902 L
.63661 .30902 L
.63681 .30902 L
.63703 .30902 L
.63723 .30902 L
.63742 .30902 L
.63761 .30902 L
.63772 .30902 L
.63781 .30902 L
.63791 .30902 L
.63802 .30902 L
.63813 .30902 L
.63823 .30902 L
.63832 .30902 L
.63842 .30902 L
.63852 .30902 L
.63862 .30902 L
.63871 .30902 L
.63879 .30902 L
.63888 .30902 L
.63897 .30902 L
.63917 .30902 L
.63939 .30902 L
.63977 .30902 L
Mistroke
.64065 .30902 L
.64147 .30902 L
.64237 .30902 L
.64278 .30902 L
.64321 .30902 L
.64362 .30902 L
.64399 .30902 L
.64435 .30902 L
.64475 .30902 L
.64517 .30902 L
.64557 .30902 L
.64594 .30902 L
.64633 .30902 L
.64667 .30902 L
.64704 .30902 L
.64723 .30902 L
.64744 .30902 L
.64765 .30902 L
.64785 .30902 L
.64804 .30902 L
.64821 .30902 L
.64831 .30902 L
.64841 .30902 L
.64851 .30902 L
.6486 .30902 L
.64869 .30902 L
.6488 .30902 L
.6489 .30902 L
.64898 .30902 L
.64909 .30902 L
.6492 .30902 L
.64941 .30902 L
.64986 .30902 L
.65027 .30902 L
.65105 .30902 L
.6519 .30902 L
.65269 .30902 L
.65307 .30902 L
.65342 .30902 L
.65413 .30902 L
.6545 .30902 L
.6549 .30902 L
.65531 .30902 L
.65571 .30902 L
.65606 .30902 L
.65645 .30902 L
.65664 .30902 L
.65684 .30902 L
.65721 .30902 L
.65743 .30902 L
Mistroke
.65764 .30902 L
.65783 .30902 L
.65804 .30902 L
.65816 .30902 L
.65826 .30902 L
.65836 .30902 L
.65847 .30902 L
.65852 .30902 L
.65858 .30902 L
.65868 .30902 L
.65874 .30902 L
.65881 .30902 L
.65886 .30902 L
.65892 .30902 L
.65902 .30902 L
.65912 .30902 L
.65922 .30902 L
.65934 .30902 L
.65952 .30902 L
.65973 .30902 L
.66142 .30902 L
.66215 .30902 L
.66254 .30902 L
.66296 .30902 L
.66337 .30902 L
.66374 .30902 L
.66447 .30902 L
.66487 .30902 L
.66529 .30902 L
.6657 .30902 L
.66607 .30902 L
.66644 .30902 L
.66665 .30902 L
.66685 .30902 L
.66703 .30902 L
.66723 .30902 L
.66757 .30902 L
.66779 .30902 L
.66799 .30902 L
.6681 .30902 L
.66822 .30902 L
.66832 .30902 L
.66843 .30902 L
.66853 .30902 L
.66864 .30902 L
.66869 .30902 L
.66875 .30902 L
.66885 .30902 L
.66894 .30902 L
.66905 .30902 L
Mistroke
.66914 .30902 L
.66923 .30902 L
.66933 .30902 L
.66943 .30902 L
.6696 .30902 L
.67001 .30902 L
.67073 .30902 L
.67153 .30902 L
.67239 .30902 L
.67282 .30902 L
.67322 .30902 L
.67362 .30902 L
.67398 .30902 L
.67469 .30902 L
.67506 .30902 L
.67545 .30902 L
.67585 .30902 L
.67621 .30902 L
.67641 .30902 L
.67663 .30902 L
.67682 .30902 L
.67703 .30902 L
.6774 .30902 L
.6776 .30902 L
.67779 .30902 L
.67796 .30902 L
.67813 .30902 L
.67833 .30902 L
.6785 .30902 L
.6786 .30902 L
.67871 .30902 L
.67881 .30902 L
.6789 .30902 L
.67899 .30902 L
.67908 .30902 L
.67918 .30902 L
.67927 .30902 L
.67937 .30902 L
.67947 .30902 L
.67966 .30902 L
.68008 .30902 L
.68156 .30902 L
.68233 .30902 L
.68275 .30902 L
.68315 .30902 L
.68352 .30902 L
.68393 .30902 L
.68463 .30902 L
.68502 .30902 L
.68539 .30902 L
Mistroke
.6858 .30902 L
.68623 .30902 L
.68645 .30902 L
.68669 .30902 L
.68689 .30902 L
.68712 .30902 L
.68731 .30902 L
.68753 .30902 L
.68774 .30902 L
.68792 .30902 L
.68811 .30902 L
.68822 .30902 L
.68832 .30902 L
.68852 .30902 L
.68863 .30902 L
.68873 .30902 L
.68882 .30902 L
.68892 .30902 L
.689 .30902 L
.68909 .30902 L
.68919 .30902 L
.68929 .30902 L
.68939 .30902 L
.68948 .30902 L
.68969 .30902 L
.68989 .30902 L
.69034 .30902 L
.69115 .30902 L
.69187 .30902 L
.69265 .30902 L
.69309 .30902 L
.6935 .30902 L
.69389 .30902 L
.6943 .30902 L
.69471 .30902 L
.69509 .30902 L
.69546 .30902 L
.69582 .30902 L
.69623 .30902 L
.69661 .30902 L
.69681 .30902 L
.69703 .30902 L
.69725 .30902 L
.69748 .30902 L
.69769 .30902 L
.6979 .30902 L
.69809 .30902 L
.69819 .30902 L
.69829 .30902 L
.6984 .30902 L
Mistroke
.69849 .30902 L
.69858 .30902 L
.69868 .30902 L
.69877 .30902 L
.69885 .30902 L
.69894 .30902 L
.69904 .30902 L
.69909 .30902 L
.69915 .30902 L
.69925 .30902 L
.69931 .30902 L
.69936 .30902 L
.69949 .30902 L
.69969 .30902 L
.69991 .30902 L
.70071 .30902 L
.70155 .30902 L
.70232 .30902 L
.70313 .30902 L
.70356 .30902 L
.70402 .30902 L
.70444 .30902 L
.70484 .30902 L
.70527 .30902 L
.70573 .30902 L
.70613 .30902 L
.7065 .30902 L
.70671 .30902 L
.70691 .30902 L
.70714 .30902 L
.70735 .30902 L
.70753 .30902 L
.70773 .30902 L
.70794 .30902 L
.70814 .30902 L
.70833 .30902 L
.70842 .30902 L
.70852 .30902 L
.70861 .30902 L
.7087 .30902 L
.70879 .30902 L
.70887 .30902 L
.70898 .30902 L
.70903 .30902 L
.70909 .30902 L
.70919 .30902 L
.70928 .30902 L
.70934 .30902 L
.7094 .30902 L
.7095 .30902 L
Mistroke
.70973 .30902 L
.71054 .30902 L
.71137 .30902 L
.71215 .30902 L
.71285 .30902 L
.71324 .30902 L
.7136 .30902 L
.714 .30902 L
.71437 .30902 L
.71476 .30902 L
.71518 .30902 L
.71561 .30902 L
.71599 .30902 L
.71621 .30902 L
.71644 .30902 L
.71664 .30902 L
.71686 .30902 L
.71707 .30902 L
.71725 .30902 L
.71744 .30902 L
.71762 .30902 L
.71781 .30902 L
.71792 .30902 L
.71802 .30902 L
.71823 .30902 L
.71834 .30902 L
.71845 .30902 L
.71855 .30902 L
.71865 .30902 L
.71871 .30902 L
.71877 .30902 L
.71887 .30902 L
.71897 .30902 L
.71907 .30902 L
.71916 .30902 L
.71926 .30902 L
.71948 .30902 L
.71971 .30902 L
.72013 .30902 L
.72092 .30902 L
.72174 .30902 L
.72217 .30902 L
.72264 .30902 L
.72308 .30902 L
.72347 .30902 L
.72386 .30902 L
.72428 .30902 L
.72472 .30902 L
.72514 .30902 L
.72553 .30902 L
Mistroke
.72595 .30902 L
.7263 .30902 L
.7265 .30902 L
.72669 .30902 L
.72707 .30902 L
.72728 .30902 L
.72748 .30902 L
.72769 .30902 L
.72789 .30902 L
.72799 .30902 L
.72811 .30902 L
.72822 .30902 L
.72832 .30902 L
.7284 .30902 L
.72849 .30902 L
.72858 .30902 L
.72866 .30902 L
.72875 .30902 L
.72885 .30902 L
.72895 .30902 L
.72904 .30902 L
.72914 .30902 L
.72923 .30902 L
.72941 .30902 L
.7298 .30902 L
.73128 .30902 L
.73169 .30902 L
.73212 .30902 L
.7329 .30902 L
.73333 .30902 L
.73374 .30902 L
.73411 .30902 L
.73451 .30902 L
.73493 .30902 L
.73539 .30902 L
.73577 .30902 L
.73599 .30902 L
.7362 .30902 L
.7366 .30902 L
.73682 .30902 L
.73703 .30902 L
.73723 .30902 L
.73742 .30902 L
.73763 .30902 L
.73772 .30902 L
.73782 .30902 L
.73801 .30902 L
.7381 .30902 L
.7382 .30902 L
.73828 .30902 L
Mistroke
.73836 .30902 L
.73845 .30902 L
.73854 .30902 L
.73863 .30902 L
.73873 .30902 L
.73882 .30902 L
.73891 .30902 L
.73912 .30902 L
.73931 .30902 L
.74079 .30902 L
.74163 .30902 L
.74204 .30902 L
.74242 .30902 L
.74279 .30902 L
.74319 .30902 L
.74362 .30902 L
.74402 .30902 L
.74445 .30902 L
.74491 .30902 L
.74529 .30902 L
.74551 .30902 L
.74572 .30902 L
.74612 .30902 L
.74634 .30902 L
.74655 .30902 L
.74675 .30902 L
.74694 .30902 L
.74715 .30902 L
.74735 .30902 L
.74753 .30902 L
.74762 .30902 L
.74772 .30902 L
.7478 .30902 L
.7479 .30902 L
.74798 .30902 L
.74806 .30902 L
.74816 .30902 L
.74825 .30902 L
.74835 .30902 L
.7484 .30902 L
.74846 .30902 L
.74855 .30902 L
.74865 .30902 L
.74883 .30902 L
.75041 .30902 L
.75125 .30902 L
.75172 .30902 L
.75214 .30902 L
.75255 .30902 L
.75299 .30902 L
Mistroke
.75341 .30902 L
.75379 .30902 L
.75415 .30902 L
.75454 .30902 L
.75494 .30902 L
.75532 .30902 L
.75553 .30902 L
.75573 .30902 L
.75593 .30902 L
.75616 .30902 L
.75635 .30902 L
.75655 .30902 L
.75676 .30902 L
.75696 .30902 L
.75714 .30902 L
.75733 .30902 L
.75743 .30902 L
.75754 .30902 L
.75764 .30902 L
.75773 .30902 L
.75782 .30902 L
.75791 .30902 L
.758 .30902 L
.7581 .30902 L
.75818 .30902 L
.75826 .30902 L
.75835 .30902 L
.75845 .30902 L
.76003 .30902 L
.76086 .30902 L
.76133 .30902 L
.76176 .30902 L
.76216 .30902 L
.76261 .30902 L
.76302 .30902 L
.76341 .30902 L
.76377 .30902 L
.76416 .30902 L
.76456 .30902 L
.76494 .30902 L
.76515 .30902 L
.76535 .30902 L
.76555 .30902 L
.76578 .30902 L
.76597 .30902 L
.76617 .30902 L
.76638 .30902 L
.76658 .30902 L
.76676 .30902 L
.76696 .30902 L
Mistroke
.76706 .30902 L
.76716 .30902 L
.76726 .30902 L
.76736 .30902 L
.76745 .30902 L
.76753 .30902 L
.76762 .30902 L
.76772 .30902 L
.76781 .30902 L
.76789 .30902 L
.76797 .30902 L
.76807 .30902 L
.76849 .30902 L
.76888 .30902 L
.76977 .30902 L
.77055 .30902 L
.77098 .30902 L
.77138 .30902 L
.77178 .30902 L
.77221 .30902 L
.77265 .30902 L
.77311 .30902 L
.77351 .30902 L
.77373 .30902 L
.77394 .30902 L
.77414 .30902 L
.77435 .30902 L
.77473 .30902 L
.77491 .30902 L
.77512 .30902 L
.77548 .30902 L
.77571 .30902 L
.77592 .30902 L
.77611 .30902 L
.77632 .30902 L
.77643 .30902 L
.77654 .30902 L
.77664 .30902 L
.77674 .30902 L
.77685 .30902 L
.77696 .30902 L
.77702 .30902 L
.77707 .30902 L
.77713 .30902 L
.77719 .30902 L
.7773 .30902 L
.77736 .30902 L
.77741 .30902 L
.77751 .30902 L
.77756 .30902 L
Mistroke
.77762 .30902 L
.77782 .30902 L
.77801 .30902 L
.77949 .30902 L
.77989 .30902 L
.78033 .30902 L
.78111 .30902 L
.78154 .30902 L
.78195 .30902 L
.78232 .30902 L
.78272 .30902 L
.78314 .30902 L
.78336 .30902 L
.7836 .30902 L
.7838 .30902 L
.78402 .30902 L
.78441 .30902 L
.78461 .30902 L
.78483 .30902 L
.78502 .30902 L
.78522 .30902 L
.78546 .30902 L
.78569 .30902 L
.78579 .30902 L
.78591 .30902 L
.78601 .30902 L
.78611 .30902 L
.7862 .30902 L
.7863 .30902 L
.78641 .30902 L
.78651 .30902 L
.7866 .30902 L
.7867 .30902 L
.78678 .30902 L
.78688 .30902 L
.78693 .30902 L
.78699 .30902 L
.78709 .30902 L
.78714 .30902 L
.7872 .30902 L
.78731 .30902 L
.78772 .30902 L
.78923 .30902 L
.78964 .30902 L
.79008 .30902 L
.79045 .30902 L
.79086 .30902 L
.79128 .30902 L
.79168 .30902 L
.79215 .30902 L
Mistroke
.79257 .30902 L
.79297 .30902 L
.7932 .30902 L
.79341 .30902 L
.79379 .30902 L
.79398 .30902 L
.79419 .30902 L
.79459 .30902 L
.79478 .30902 L
.795 .30902 L
.79519 .30902 L
.79539 .30902 L
.79557 .30902 L
.79574 .30902 L
.79585 .30902 L
.79596 .30902 L
.79605 .30902 L
.79616 .30902 L
.79621 .30902 L
.79627 .30902 L
.79633 .30902 L
.79639 .30902 L
.79649 .30902 L
.79655 .30902 L
.7966 .30902 L
.79671 .30902 L
.79681 .30902 L
.797 .30902 L
.79742 .30902 L
.79813 .30902 L
.79889 .30902 L
.79933 .30902 L
.79973 .30902 L
.80013 .30902 L
.80051 .30902 L
.8009 .30902 L
.80133 .30902 L
.80171 .30902 L
.80211 .30902 L
.80253 .30902 L
.80292 .30902 L
.80314 .30902 L
.80334 .30902 L
.80358 .30902 L
.8038 .30902 L
.80398 .30902 L
.80418 .30902 L
.80439 .30902 L
.80459 .30902 L
.80477 .30902 L
Mistroke
.80497 .30902 L
.80514 .30902 L
.80523 .30902 L
.80532 .30902 L
.80542 .30902 L
.80548 .30902 L
.80554 .30902 L
.80564 .30902 L
.80574 .30902 L
.80584 .30902 L
.80594 .30902 L
.80603 .30902 L
.80612 .30902 L
.80623 .30902 L
.80634 .30902 L
.80657 .30902 L
.80698 .30902 L
.80786 .30902 L
.80829 .30902 L
.80868 .30902 L
.80943 .30902 L
.80982 .30902 L
.81023 .30902 L
.8106 .30902 L
.811 .30902 L
.81138 .30902 L
.81172 .30902 L
.8121 .30902 L
.81232 .30902 L
.81252 .30902 L
.81293 .30902 L
.81315 .30902 L
.81336 .30902 L
.81356 .30902 L
.81375 .30902 L
.81395 .30902 L
.81416 .30902 L
.81435 .30902 L
.81452 .30902 L
.81461 .30902 L
.81472 .30902 L
.81481 .30902 L
.8149 .30902 L
.81501 .30902 L
.8151 .30902 L
.81516 .30902 L
.81522 .30902 L
.81532 .30902 L
.81538 .30902 L
.81543 .30902 L
Mistroke
.81554 .30902 L
.8156 .30902 L
.81566 .30902 L
.81577 .30902 L
.81616 .30902 L
.81657 .30902 L
.8174 .30902 L
.81817 .30902 L
.81855 .30902 L
.81897 .30902 L
.81943 .30902 L
.81986 .30902 L
.82024 .30902 L
.82065 .30902 L
.82103 .30902 L
.82138 .30902 L
.82179 .30902 L
.82202 .30902 L
.82224 .30902 L
.82263 .30902 L
.82283 .30902 L
.82305 .30902 L
.82325 .30902 L
.82347 .30902 L
.82367 .30902 L
.82387 .30902 L
.82404 .30902 L
.82414 .30902 L
.82423 .30902 L
.82432 .30902 L
.82441 .30902 L
.82451 .30902 L
.82461 .30902 L
.82472 .30902 L
.82481 .30902 L
.82487 .30902 L
.82492 .30902 L
.82503 .30902 L
.82513 .30902 L
.82523 .30902 L
.82541 .30902 L
.82629 .30902 L
.82705 .30902 L
.82747 .30902 L
.82786 .30902 L
.82823 .30902 L
.82863 .30902 L
.829 .30902 L
.82933 .30902 L
.82974 .30902 L
Mistroke
.82996 .30902 L
.83019 .30902 L
.8306 .30902 L
.83099 .30902 L
.83117 .30902 L
.83136 .30902 L
.8317 .30902 L
.83191 .30902 L
.83211 .30902 L
.8323 .30902 L
.83248 .30902 L
.83266 .30902 L
.83285 .30902 L
.83306 .30902 L
.83326 .30902 L
.83336 .30902 L
.83346 .30902 L
.83357 .30902 L
.83368 .30902 L
.83373 .30902 L
.83379 .30902 L
.83389 .30902 L
.83399 .30902 L
.83408 .30902 L
.83417 .30902 L
.83426 .30902 L
.83435 .30902 L
.83443 .30902 L
.83462 .30902 L
.8348 .30902 L
.83556 .30902 L
.83634 .30902 L
.83676 .30902 L
.83716 .30902 L
.83786 .30902 L
.83824 .30902 L
.83864 .30902 L
.83904 .30902 L
.83941 .30902 L
.83981 .30902 L
.84004 .30902 L
.84025 .30902 L
.84067 .30902 L
.8409 .30902 L
.84112 .30902 L
.84133 .30902 L
.84152 .30902 L
.84172 .30902 L
.84194 .30902 L
.84215 .30902 L
Mistroke
.84234 .30902 L
.84255 .30902 L
.84267 .30902 L
.84278 .30902 L
.84287 .30902 L
.84297 .30902 L
.84303 .30902 L
.84308 .30902 L
.84319 .30902 L
.84328 .30902 L
.84338 .30902 L
.84348 .30902 L
.84357 .30902 L
.84366 .30902 L
.84376 .30902 L
.84394 .30902 L
.84433 .30902 L
.84506 .30902 L
.84581 .30902 L
.84621 .30902 L
.84662 .30902 L
.84699 .30902 L
.84739 .30902 L
.84775 .30902 L
.84809 .30902 L
.8485 .30902 L
.84871 .30902 L
.84894 .30902 L
.84914 .30902 L
.84935 .30902 L
.84955 .30902 L
.84974 .30902 L
.85011 .30902 L
.85031 .30902 L
.85051 .30902 L
.85085 .30902 L
.85105 .30902 L
.85123 .30902 L
.85142 .30902 L
.8516 .30902 L
.85179 .30902 L
.85189 .30902 L
.852 .30902 L
.85209 .30902 L
.85218 .30902 L
.85228 .30902 L
.85238 .30902 L
.85246 .30902 L
.85254 .30902 L
.85263 .30902 L
Mistroke
.85272 .30902 L
.85283 .30902 L
.85292 .30902 L
.85297 .30902 L
.85303 .30902 L
.85313 .30902 L
.85351 .30902 L
.85438 .30902 L
.85519 .30902 L
.85596 .30902 L
.85638 .30902 L
.85684 .30902 L
.85726 .30902 L
.85764 .30902 L
.85802 .30902 L
.85842 .30902 L
.8588 .30902 L
.85915 .30902 L
.85936 .30902 L
.85956 .30902 L
.85977 .30902 L
.86 .30902 L
.86021 .30902 L
.8604 .30902 L
.8606 .30902 L
.86081 .30902 L
.861 .30902 L
.86111 .30902 L
.86121 .30902 L
.8613 .30902 L
.8614 .30902 L
.86149 .30902 L
.86158 .30902 L
.86168 .30902 L
.86173 .30902 L
.86179 .30902 L
.86185 .30902 L
.86191 .30902 L
.86196 .30902 L
.86202 .30902 L
.86212 .30902 L
.86218 .30902 L
.86223 .30902 L
.86233 .30902 L
.86242 .30902 L
.86285 .30902 L
.86324 .30902 L
.86411 .30902 L
.86449 .30902 L
.8649 .30902 L
Mistroke
.86525 .30902 L
.86563 .30902 L
.86608 .30902 L
.8665 .30902 L
.86691 .30902 L
.86729 .30902 L
.86766 .30902 L
.86787 .30902 L
.86806 .30902 L
.86825 .30902 L
.86844 .30902 L
.86879 .30902 L
.86901 .30902 L
.86921 .30902 L
.86943 .30902 L
.86965 .30902 L
.86985 .30902 L
.87003 .30902 L
.87023 .30902 L
.87033 .30902 L
.87045 .30902 L
.87054 .30902 L
.87065 .30902 L
.87076 .30902 L
.87087 .30902 L
.87096 .30902 L
.87106 .30902 L
.87116 .30902 L
.87121 .30902 L
.87126 .30902 L
.87135 .30902 L
.87144 .30902 L
.87153 .30902 L
.87163 .30902 L
.87201 .30902 L
.87288 .30902 L
.87369 .30902 L
.87409 .30902 L
.87451 .30902 L
.87493 .30902 L
.8754 .30902 L
.8758 .30902 L
.87603 .30902 L
.87624 .30902 L
.87665 .30902 L
.87702 .30902 L
.87723 .30902 L
.87742 .30902 L
.87779 .30902 L
.87799 .30902 L
Mistroke
.87818 .30902 L
.87839 .30902 L
.87861 .30902 L
.87879 .30902 L
.87897 .30902 L
.87915 .30902 L
.87931 .30902 L
.8795 .30902 L
.87961 .30902 L
.87971 .30902 L
.87981 .30902 L
.87989 .30902 L
.87999 .30902 L
.88009 .30902 L
.88018 .30902 L
.88028 .30902 L
.88038 .30902 L
.88046 .30902 L
.88057 .30902 L
.88062 .30902 L
.88068 .30902 L
.88088 .30902 L
.88128 .30902 L
.88171 .30902 L
.88249 .30902 L
.88319 .30902 L
.88358 .30902 L
.88395 .30902 L
.88434 .30902 L
.88477 .30902 L
.88514 .30902 L
.88553 .30902 L
.8859 .30902 L
.88624 .30902 L
.88663 .30902 L
.88683 .30902 L
.88705 .30902 L
.88723 .30902 L
.88743 .30902 L
.88762 .30902 L
.88779 .30902 L
.888 .30902 L
.88824 .30902 L
.88844 .30902 L
.88855 .30902 L
.88866 .30902 L
.88886 .30902 L
.88897 .30902 L
.88908 .30902 L
.88917 .30902 L
Mistroke
.88927 .30902 L
.88937 .30902 L
.88946 .30902 L
.88956 .30902 L
.88962 .30902 L
.88967 .30902 L
.88977 .30902 L
.88987 .30902 L
.89008 .30902 L
.89031 .30902 L
.89111 .30902 L
.89188 .30902 L
.8926 .30902 L
.893 .30902 L
.89342 .30902 L
.89384 .30902 L
.89408 .30902 L
.89431 .30902 L
.89471 .30902 L
.89492 .30902 L
.89514 .30902 L
.89551 .30902 L
.89572 .30902 L
.89592 .30902 L
.89612 .30902 L
.89633 .30902 L
.89656 .30902 L
.89677 .30902 L
.89696 .30902 L
.89715 .30902 L
.89735 .30902 L
.89756 .30902 L
.89776 .30902 L
.89786 .30902 L
.89796 .30902 L
.89806 .30902 L
.89815 .30902 L
.89825 .30902 L
.89834 .30902 L
.89843 .30902 L
.89852 .30902 L
.8986 .30902 L
.89869 .30902 L
.89878 .30902 L
.89888 .30902 L
.89897 .30902 L
.89906 .30902 L
.89986 .30902 L
.90072 .30902 L
.90145 .30902 L
Mistroke
.90187 .30902 L
.90226 .30902 L
.90264 .30902 L
.90303 .30902 L
.90337 .30902 L
.90374 .30902 L
.90414 .30902 L
.90437 .30902 L
.90457 .30902 L
.90476 .30902 L
.90497 .30902 L
.90534 .30902 L
.90553 .30902 L
.90573 .30902 L
.90592 .30902 L
.9061 .30902 L
.90631 .30902 L
.90641 .30902 L
.90653 .30902 L
.90663 .30902 L
.90674 .30902 L
.90694 .30902 L
.90704 .30902 L
.90716 .30902 L
.90725 .30902 L
.90736 .30902 L
.90742 .30902 L
.90747 .30902 L
.90753 .30902 L
.90759 .30902 L
.9077 .30902 L
.90775 .30902 L
.90781 .30902 L
.90791 .30902 L
.908 .30902 L
.9081 .30902 L
.90821 .30902 L
.90863 .30902 L
.90939 .30902 L
.91021 .30902 L
.91068 .30902 L
.91111 .30902 L
.91153 .30902 L
.91194 .30902 L
.91233 .30902 L
.91274 .30902 L
.91309 .30902 L
.91347 .30902 L
.91369 .30902 L
.91388 .30902 L
Mistroke
.9141 .30902 L
.91433 .30902 L
.91454 .30902 L
.91474 .30902 L
.91493 .30902 L
.91513 .30902 L
.91532 .30902 L
.91552 .30902 L
.91569 .30902 L
.91588 .30902 L
.91599 .30902 L
.91608 .30902 L
.91619 .30902 L
.9163 .30902 L
.9164 .30902 L
.91649 .30902 L
.91659 .30902 L
.91669 .30902 L
.91678 .30902 L
.91687 .30902 L
.91696 .30902 L
.91705 .30902 L
.91721 .30902 L
.91739 .30902 L
.91816 .30902 L
.91855 .30902 L
.91897 .30902 L
.91935 .30902 L
.91974 .30902 L
.9202 .30902 L
.92063 .30902 L
.92101 .30902 L
.92143 .30902 L
.92163 .30902 L
.92185 .30902 L
.92204 .30902 L
.92225 .30902 L
.92243 .30902 L
.92264 .30902 L
.923 .30902 L
.92322 .30902 L
.92341 .30902 L
.92365 .30902 L
.92386 .30902 L
.92407 .30902 L
.92425 .30902 L
.92446 .30902 L
.92456 .30902 L
.92468 .30902 L
.92489 .30902 L
Mistroke
.925 .30902 L
.92511 .30902 L
.92521 .30902 L
.9253 .30902 L
.9254 .30902 L
.9255 .30902 L
.92555 .30902 L
.92561 .30902 L
.92567 .30902 L
.92572 .30902 L
.92582 .30902 L
.92588 .30902 L
.92593 .30902 L
.92599 .30902 L
.92604 .30902 L
.92616 .30902 L
.9264 .30902 L
.92717 .30902 L
.92801 .30902 L
.92845 .30902 L
.92886 .30902 L
.92925 .30902 L
.92966 .30902 L
.93002 .30902 L
.93037 .30902 L
.93074 .30902 L
.93095 .30902 L
.93115 .30902 L
.93153 .30902 L
.93174 .30902 L
.93194 .30902 L
.93212 .30902 L
.93232 .30902 L
.93267 .30902 L
.93287 .30902 L
.9331 .30902 L
.93333 .30902 L
.93354 .30902 L
.93364 .30902 L
.93374 .30902 L
.93393 .30902 L
.93403 .30902 L
.93412 .30902 L
.93423 .30902 L
.93434 .30902 L
.93443 .30902 L
.93453 .30902 L
.93463 .30902 L
.93473 .30902 L
.93482 .30902 L
Mistroke
.93491 .30902 L
.935 .30902 L
.93509 .30902 L
.93548 .30902 L
.9359 .30902 L
.93666 .30902 L
.93737 .30902 L
.93774 .30902 L
.93813 .30902 L
.93857 .30902 L
.93897 .30902 L
.93938 .30902 L
.93962 .30902 L
.93984 .30902 L
.94023 .30902 L
.94044 .30902 L
.94066 .30902 L
.94105 .30902 L
.94125 .30902 L
.94147 .30902 L
.94165 .30902 L
.94185 .30902 L
.94204 .30902 L
.94221 .30902 L
.94242 .30902 L
.94262 .30902 L
.94272 .30902 L
.94284 .30902 L
.94296 .30902 L
.94307 .30902 L
.94317 .30902 L
.94327 .30902 L
.94336 .30902 L
.94346 .30902 L
.94357 .30902 L
.94363 .30902 L
.94368 .30902 L
.94378 .30902 L
.94388 .30902 L
.94397 .30902 L
.94407 .30902 L
.94426 .30902 L
.94467 .30902 L
.94549 .30902 L
.94589 .30902 L
.94627 .30902 L
.94663 .30902 L
.94698 .30902 L
.94735 .30902 L
.94775 .30902 L
Mistroke
.94815 .30902 L
.94837 .30902 L
.94858 .30902 L
.94892 .30902 L
.9493 .30902 L
.94949 .30902 L
.94969 .30902 L
.95005 .30902 L
.95026 .30902 L
.95048 .30902 L
.95067 .30902 L
.95088 .30902 L
.9511 .30902 L
.95122 .30902 L
.95134 .30902 L
.95144 .30902 L
.95156 .30902 L
.95177 .30902 L
.95188 .30902 L
.95198 .30902 L
.95207 .30902 L
.95217 .30902 L
.95223 .30902 L
.95228 .30902 L
.95234 .30902 L
.9524 .30902 L
.9525 .30902 L
.95256 .30902 L
.95261 .30902 L
.95271 .30902 L
.9528 .30902 L
.9529 .30902 L
.95301 .30902 L
.95339 .30902 L
.9542 .30902 L
.9546 .30902 L
.95497 .30902 L
.95533 .30902 L
.95566 .30902 L
.95603 .30902 L
.95642 .30902 L
.9568 .30902 L
.95701 .30902 L
.95722 .30902 L
.95741 .30902 L
.95761 .30902 L
.95798 .30902 L
.9582 .30902 L
.95839 .30902 L
.95861 .30902 L
Mistroke
.95884 .30902 L
.95906 .30902 L
.95926 .30902 L
.95945 .30902 L
.95965 .30902 L
.95984 .30902 L
.96004 .30902 L
.96022 .30902 L
.9604 .30902 L
.96051 .30902 L
.96061 .30902 L
.96071 .30902 L
.96082 .30902 L
.96093 .30902 L
.96102 .30902 L
.96112 .30902 L
.96121 .30902 L
.9613 .30902 L
.96139 .30902 L
.96148 .30902 L
.96157 .30902 L
.96166 .30902 L
.96174 .30902 L
.96191 .30902 L
.96268 .30902 L
.96309 .30902 L
.96353 .30902 L
.96392 .30902 L
.96433 .30902 L
.9647 .30902 L
.96511 .30902 L
.96548 .30902 L
.96582 .30902 L
.96623 .30902 L
.96645 .30902 L
.96666 .30902 L
.96705 .30902 L
.96724 .30902 L
.96746 .30902 L
.96783 .30902 L
.96804 .30902 L
.96823 .30902 L
.96841 .30902 L
.96858 .30902 L
.96876 .30902 L
.96895 .30902 L
.96905 .30902 L
.96916 .30902 L
.96935 .30902 L
.96946 .30902 L
Mistroke
.96956 .30902 L
.96967 .30902 L
.96979 .30902 L
.9699 .30902 L
.96995 .30902 L
.97001 .30902 L
.97011 .30902 L
.97021 .30902 L
.97031 .30902 L
.97041 .30902 L
.9705 .30902 L
.97059 .30902 L
.97077 .30902 L
.97097 .30902 L
.97137 .30902 L
.97208 .30902 L
.97251 .30902 L
.97291 .30902 L
.97327 .30902 L
.97366 .30902 L
.97408 .30902 L
.97429 .30902 L
.97453 .30902 L
.97473 .30902 L
.97495 .30902 L
.97534 .30902 L
.97555 .30902 L
.97577 .30902 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{421.375, 260.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008>0001AB000`400?l00000o`00003ooooooooo
oooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo
003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooo
oooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool0
0?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooooooo
ool@ooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
00Wooooo0_l0003oooooom7ooooo000`ooooo`03o`000?oooooooooo00Wooooo0_l0003oooooom7o
oooo000`ooooo`03o`000?oooooooooo00Wooooo0_l0003oooooom7ooooo000`ooooo`03o`000?oo
oooooooo00Wooooo0_l0003oooooom7ooooo000`ooooo`?o00002Oooool2o`000?oooooodOooool0
033ooooo00?o0000ooooooooool02Oooool2o`000?oooooodOooool0033ooooo00?o0000oooooooo
ool02Oooool2o`000?oooooodOooool0033ooooo00?o0000ooooooooool02Oooool2o`000?oooooo
dOooool0033ooooo00?o0000ooooooooool02Oooool2o`000?oooooodOooool0033ooooo00?o0000
ooooooooool02Oooool2o`000?oooooodOooool0033ooooo00?o0000ooooooooool02Oooool2o`00
0?oooooodOooool0033ooooo00?o0000ooooooooool02Oooool2o`000?oooooodOooool0033ooooo
00?o0000ooooooooool02Oooool2o`000?oooooodOooool0033ooooo00?o0000ooooooooool02Ooo
ool2o`000?oooooodOooool0033ooooo00?o0000ooooooooool02Oooool2o`000?oooooodOooool0
033ooooo00?o0000ooooooooool02Oooool2o`000?oooooodOooool0033ooooo0ol00009ooooo`;o
0000oooooooAooooo`00<?ooool00ol0003oooooooooo`09ooooo`;o0000oooooooAooooo`00<?oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooo00000?ooooood?ooool0033ooooo00?o0000
ooooooooool02Oooool00ol0003oooooo`00003oooooom3ooooo000`ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooool00000ooooooo@ooooo`00<?ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooo00000?ooooood?ooool0033ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
o`00003oooooom3ooooo000`ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooool00000oooo
ooo@ooooo`00<?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo00000?ooooood?ooool0
033ooooo00?o0000ooooooooool02?ooool01?l0003oooooooooool0003oooooom3ooooo000`oooo
o`03o`000?oooooooooo00Sooooo00Co0000oooooooooooo0000ooooooo@ooooo`00<?ooool3o`00
00Sooooo00Co0000oooooooooooo0000ooooooo@ooooo`00<?ooool00ol0003oooooooooo`08oooo
o`04o`000?ooooooooooo`000?ooooood?ooool0033ooooo00?o0000ooooooooool02?ooool01?l0
003oooooooooool0003oooooom3ooooo000`ooooo`03o`000?oooooooooo00Sooooo00Co0000oooo
oooooooo0000ooooooo@ooooo`00<?ooool00ol0003oooooooooo`08ooooo`04o`000?oooooooooo
o`000?ooooood?ooool0033ooooo00?o0000ooooooooool02?ooool01?l0003oooooooooool0003o
ooooom3ooooo000`ooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooo0000ooooooo@
ooooo`004?ooool2onk^kP?ooooo0_o^k^hIooooo`03o`000?oooooooooo00Sooooo00Co0000oooo
oooooooo0000ooooooo@ooooo`002oooool2o`00000:oa0@4?ooooooooooonk^k_mEEEGok^k^oooo
ooo^k^koEEEEonk^kP?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^2_oo
ool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`000?ooooood?ooool000cooooo00?o
0000ooooooooool00_ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00[ooooo00?o0000ooooooooool02?ooool01?l0003o
ooooooooool0003oooooom3ooooo00000ooooooo0000o`000004o`0000;ooooo1Ol00004ooooo`03
omgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@
00[ooooo00?o0000ooooooooool02?ooool01?l0003oooooooooool0003oooooom3ooooo0009oooo
o`04odA4A?oMgMgoooooo`0000Cooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000:ooooo`03o`000?oooooooooo00Sooooo
00Co0000oooooooooooo0000ooooooo@ooooo`002Oooool01?oMgMgoEEEEooooool00003ooooo`07
onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`00000:ooooo`Co00001oooool01?l0003oooooooooool00009ooooo`03o`00
0?oooooooooo0?ooooooa?ooool000[ooooo00?oMgMgolc<c?l000000oooool2onk^kP?ooooo0_o^
k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400:ooooo`03o`00
0?oooooooooo00Sooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`3oooooolCo
oooo000:ooooo`03onk^k_m4A4Co000000oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00?ooooo0_l00005ooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooo
oooo00002Oooool00ol0003oooooooooo`3oooooolCooooo000;ooooo`03ogMgMol0003ooooo00co
oooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo00Co0000oooo
oooooooo00001?ooool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`0000Wooooo00?o
0000ooooooooool0ooooooo4ooooo`00:?ooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo00Sooooo00Co0000oooooooooooo00002Oooool2o`000?ooooooaOooool002Sooooo0ol0
0005ooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooo00002Oooool2o`000?oooooo
aOooool002Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`04o`000?oo
ooooooooo`0000Sooooo00?o0000ooooool00000ooooooo5ooooo`00:_ooool00ol0003ooooooooo
o`03ooooo`;o00002Oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?oooooo
aOooool0033ooooo0_l00009ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000
ooooooo5ooooo`00<?ooool2o`0000Wooooo00Co0000oooooooooooo00002?ooool00ol0003ooooo
o`00003oooooolGooooo000`ooooo`;o00002Oooool01?l0003oooooooooool00008ooooo`03o`00
0?oooooo00000?ooooooaOooool0033ooooo0_l00009ooooo`04o`000?ooooooooooo`0000Sooooo
00?o0000ooooool00000ooooooo5ooooo`00<?ooool3o`0000Sooooo00Co0000oooooooooooo0000
2?ooool00ol0003oooooo`00003oooooolGooooo000`ooooo`03o`000?oooooo000000Sooooo00Co
0000oooooooooooo00002?ooool00ol0003oooooo`00003oooooolGooooo000`ooooo`03o`000?oo
oooo000000Sooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003oooooolGooooo
000`ooooo`03o`000?oooooo000000Sooooo00Co0000oooooooooooo00002?ooool00ol0003ooooo
o`00003oooooolGooooo000`ooooo`03o`000?oooooo000000Sooooo00Co0000oooooooooooo0000
2?ooool00ol0003oooooo`00003oooooolGooooo000`ooooo`03o`000?oooooo000000Sooooo00Co
0000oooooooooooo00002?ooool00ol0003oooooo`00003oooooolGooooo000`ooooo`03o`000?oo
oooo000000Sooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003oooooolGooooo
000`ooooo`03o`000?oooooo000000Sooooo00Co0000oooooooooooo00002?ooool00ol0003ooooo
o`00003oooooolGooooo000`ooooo`03o`000?oooooo000000Sooooo00Go0000oooooooooooooooo
o`000007ooooo`03o`000?oooooo00000?ooooooaOooool0033ooooo00?o0000ooooool000002?oo
ool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooool00000ooooooo5ooooo`00<?oo
ool00ol0003oooooo`000008ooooo`05o`000?ooooooooooooooool000001oooool00ol0003ooooo
o`00003oooooolGooooo000`ooooo`03o`000?oooooo000000Sooooo00Go0000oooooooooooooooo
o`000007ooooo`03o`000?oooooo00000?ooooooaOooool0033ooooo0ol00008ooooo`05o`000?oo
ooooooooooooool000001oooool00ol0003oooooo`00003oooooolGooooo000`ooooo`03o`000?oo
oooo000000Sooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?oooooo
aOooool0033ooooo00?o0000ooooool000002?ooool01Ol0003ooooooooooooooooo000000Oooooo
00?o0000ooooool00000ooooooo5ooooo`00<?ooool00ol0003oooooo`000008ooooo`05o`000?oo
ooooooooooooool000001oooool00ol0003oooooo`00003oooooolGooooo000`ooooo`03o`000?oo
oooo000000Sooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?oooooo
aOooool0033ooooo00?o0000ooooool000002?ooool01Ol0003ooooooooooooooooo000000Oooooo
00?o0000ooooool00000ooooooo5ooooo`00<?ooool00ol0003oooooo`000008ooooo`05o`000?oo
ooooooooooooool000001oooool00ol0003oooooo`00003oooooolGooooo000`ooooo`03o`000?oo
oooo000000Sooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`000?oo
ooooa?ooool0033ooooo00?o0000ooooool000002?ooool01Ol0003ooooooooooooooooo000000Ko
oooo00Go0000ooooooooooooooooo`00003oooooolCooooo000`ooooo`03o`000?oooooo000000So
oooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool00000ooooooo4
ooooo`00<?ooool00ol0003oooooo`000008ooooo`05o`000?ooooooooooooooool000001_ooool0
1Ol0003ooooooooooooooooo00000?ooooooa?ooool0033ooooo0ol00008ooooo`05o`000?oooooo
ooooooooool000001_ooool01Ol0003ooooooooooooooooo00000?ooooooa?ooool0033ooooo00?o
0000ooooool000002?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000oooooooooooo
ooooo`00003oooooolCooooo000_ooooo`;o000000?oooooo`000?ooool01oooool01Ol0003ooooo
oooooooooooo000000Kooooo00Go0000ooooooooooooooooo`00003oooooolCooooo000_ooooo`;o
000000?oooooo`000?ooool01oooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000oooo
ooooooooooooo`00003oooooolCooooo000_ooooo`;o000000?oooooo`000?ooool01oooool01Ol0
003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`00003oooooolCooooo000_
ooooo`;o000000?oooooo`000?ooool01oooool01Ol0003ooooooooooooooooo000000Kooooo00Go
0000ooooooooooooooooo`00003oooooolCooooo000_ooooo`;o000000?oooooo`000?ooool01ooo
ool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`00003oooooolCo
oooo000@ooooo`;ok^k^0oooool2onk^kQSooooo0_l000000ooooooo0000ooooo`07ooooo`05o`00
0?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo00000?ooooooa?ooool000Wo
oooo1Ol00002ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co000000So410@
ooooooooooook^k^oc8b<_l0003o<S8bonk^kPWooooo0_l000000ooooooo0000ooooo`07ooooo`05
o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo00000?ooooooa?ooool0
00Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_oo
ool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02Oooool2o`000003oooo
ool0003ooooo00Oooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?oooooooooooooo
ool00000ooooooo4ooooo`0000?oooooo`000?l000001?l00003ooooo`03oiRHV?lQ8B7ok^k^00Go
oooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooo
ool@41002Oooool2o`000003ooooool0003ooooo00Oooooo00Go0000ooooooooooooooooo`000006
ooooo`05o`000?ooooooooooooooool00000ooooooo4ooooo`002oooool00onHV9So8B4Qonk^kP03
ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000002Oooool2o`000003ooooool0003ooooo00Oooooo00Go0000oooooooooooo
ooooo`000006ooooo`05o`000?ooooooooooooooool00000ooooooo4ooooo`003?ooool02omgMgOo
IVIVooooooooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000ooooooooool0
0_ooool01Ol0003ooooooooooooooooo000000Wooooo1Ol00007ooooo`05o`000?oooooooooooooo
ool000001_ooool01Ol0003ooooooooooooooooo00000?ooooooa?ooool000gooooo00?o0000oooo
ooooool00_o^k^h3ooooo`;ok^k^1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@41002Oooool2o`0000;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00003oooooolCooooo0009
ooooo`05o`000?nj^[[ooooooiRHV?l@41003_ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL00oooool2o`0000Cooooo0_l00002ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool0
0000ooooooo4ooooo`002Oooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo00?oEEEEofIVI_l0
00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo00Co0000oooooooooooo00000oooool2
o`0000;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00Go0000ooooooooooooooooo`00003oooooolCooooo000Xooooo`04o`000?oooooo
ooooo`0000?ooooo0_l00002ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000ooooooo4ooooo`00:?oo
ool3o`0000Cooooo0_l00002ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000ooooooo4ooooo`00:Ooo
ool00ol0003oooooooooo`03ooooo`;o00000_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo00000?oooooo
a?ooool002[ooooo00?o0000ooooooooool00_ooool2o`0000;ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooooooo
o`00003oooooolCooooo000_ooooo`;o00000_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo00000?oooooo
a?ooool002oooooo0_l00002ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000ooooooo4ooooo`00;ooo
ool2o`0000;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00Go0000ooooooooooooooooo`00003oooooolCooooo000_ooooo`;o00000_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool01Ol0003ooooooooooooooooo00000?ooooooa?ooool002kooooo00?o0000ooooool000000ol0
0006ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo00000?ooooooa?ooool002kooooo00?o0000ooooool000000_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo00000?ooooooa?ooool002kooooo00?o0000ooooool000000_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo00000?ooooooa?ooool002kooooo00?o0000ooooool000000_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo00000?ooooooa?ooool002kooooo00?o0000ooooool000000_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000Sooooo0_l0003ooooook[ooooo000^ooooo`03o`000?oooooo000000;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`;o0000oooooonjooooo`00;_ooool0
0ol0003oooooo`000002ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool2
o`000?oooooo^_ooool002kooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Gooooo0_l0003ooooook[ooooo000^ooooo`03o`000?oooooo000000;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo00000?oo
oooo^Oooool002kooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00Co0000oooooooooooo0000ooooooniooooo`009Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`04ooooo`04o`000?ooooooooooo`000?oooooo^Oooool002Gooooo0_l00007ooooo`03o`00
0?oooooo000000;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`04o`00
0?ooooooooooo`000?oooooo^Oooool002Cooooo00?o0000ooooool000001oooool00ol0003ooooo
o`000003o`0000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0003ooooookWo
oooo000Tooooo`03o`000?oooooo000000Oooooo00?o0000ooooool000000_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo0000ooooooniooooo`00
9?ooool00ol0003oooooo`000007ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`000?oooooo^Oooool002Cooooo
00?o0000ooooool000001oooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool01?l0003oooooooooool0003ooooookWooooo000Tooooo`03o`00
0?oooooo000000Oooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00Co0000oooooooooooo0000ooooooniooooo`008oooool01?l0003ooooo
ooooool00007ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`04o`000?ooooooooooo`0002_ooooo0_o^k^h3ooooo`;ok^k^Eoooool2onk^
kP?ooooo0_o^k^iPooooo`;ok^k^0oooool2onk^kTkooooo0_o^k^h3ooooo`;ok^k^K?ooool002?o
oooo00Co0000oooooooooooo00001oooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0000Uooooo`0=odA4A?l0003o
0000oc8b<_oMgMgoooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co000000So410@
ooooooooooook^k^oc8b<_l0003o<S8bonk^kT;ooooo1?l000002Ol@413oooooonk^k_mEEEGok^k^
ooooooo^k^koEEEEonk^kP03ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^
kS_ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool03Om4A4Co0000o`000?lb<S;o
gMgMooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^hhooooo`Go00000_ooool01oo^k^koEEEEonk^k_ooooook^k^oeEE
EOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^iMooooo`008ooo
ool01?l0003oooooooooool00007ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0002Sooooo00WoMgMgoc8b<_oo
ooooooooonk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL0A?ooool00ol0003oooooooooo`02ooooo`05onk^k_mEEEGogMgMoeEEEOo^
k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?Oooool00ol0
003oooooooooo`04ooooo`;o8B4Q2?ooool02OmgMgOo<S8booooooooooook^k^oeEEEOoMgMgoEEEE
onk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0hooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000
ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg05gooooo000Sooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool01?l0003oooooooooool0000Yooooo`07o`000?oooooooooooooooooM
gMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4014
ooooo`03o`000?oooooooooo00?ooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@4100?Oooool00ol0003oooooooooo`0?ooooo`07o`000?oo
oooooooooooooooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooo
oooooooooa0@400iooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?ogMgMo`000?oMgMd01oooool00ol0
003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100GOooool002?ooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool00000:?ooool02OmgMgOo<S8boooo
ooooooook^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`000014ooooo`03o`000?oooooooooo00;ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^
kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000mooooo`03o`00
0?oooooooooo00kooooo00WoMgMgoc8b<_ooooooooooonk^k_mEEEGogMgMoeEEEOo^k^h01_ooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000>_ooool00onHV9So8B4Qonk^
kP03ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000GOooool002?ooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooo000000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05
o`000?ooooooooooooooool000009Oooool03Ol0003o8B4Qo`000?lb<S;oc<c<ooooooo^k^koEEEE
onk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool00000A?ooool02ol0003oooooooooooooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^
00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000003gooooo00?o0000
ooooooooool02oooool03Ol0003o8B4Qo`000?lb<S;oc<c<ooooooo^k^koEEEEonk^k_ooooook^k^
oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000>ooo
ool02omgMgOoIVIVooooooooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000005gooooo000Sooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02;ooooo00?o
0000ooooooooool00oooool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go
410@oooooooooooooooooa0@4014ooooo`04o`000?ooooooooooooooo`;ok^k^0oooool2onk^kPGo
oooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@03gooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`03ooooo`;ok^k^0oooool2onk^kPGooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@03cooooo00?o0000ooooooooool00_o^k^h3
ooooo`;ok^k^1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100GOoo
ool002?ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo000000;o000000?o
ooooo`000?ooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool08_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool2o`0003?o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`;o0000;_ooool01Ol0003o^[ZjoooooonHV9So
410@00kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo0_l0
001Cooooo`008oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooool000000ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0Rooooo`Co00003?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`0gooooo`03oeEEEOmVIVKo000000gooooo
00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oooooo00Co0000oooooooo
oooo0000<?ooool00omEEEGoIVIVo`00000=ooooo`Co00003?ooool00omEEEGoIVIVo`000004oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01oooool01?l0003oooooooooool0000]ooooo`05oiRHV?l@
413o0000ob4Q8Oo<c<`03?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01oooool01?l0003oooooooooool0001Booooo`008oooool01Ol0003ooooooooooooooooo0000
00Kooooo00?o0000ooooool000000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`10ooooo`Co00000oooool00ol0
003oooooooooo`1Dooooo`Co000000Goooooo`000?ooooooooooo`00001Nooooo`Co000000Gooooo
o`000?ooooooooooo`00001<ooooo`Co000000Goooooo`000?ooooooooooo`00001Booooo`008ooo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooool000000oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`17ooooo`03o`000?oooooooooo05Wooooo0ol0001Tooooo`?o0000D_ooool3o`0005?ooooo
000Sooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooo`000003ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo04Gooooo00Co0000oooooooooooo0000Foooool00ol0003oooooooooo`1Tooooo`03
o`000?oooooooooo05;ooooo00?o0000ooooooooool0D_ooool002;ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
AOooool4o`0005cooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`1Booooo`03o`00
0?oooooooooo057ooooo000Rooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo0_l0003oooooojoooooo000R
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooo`000003
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo0_l000000ooooooo0000ooooo`3oooooog?ooooo00?oMgMg
ofIVI_ooool0;Oooool00omVIVKoMgMgooooo`07ooooo`006?ooool2o`0000Sooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo000000?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01?ooool01?l0003oooooooooool0003oooooog?ooooo00?ogMgMoa0@4?o^k^h0;_ooool0
0oo^k^ko410@omgMg@07ooooo`006?ooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00Go0000ooooooooooooooooo`00003oooooof3ooooo0_l00002ooooo`;o00003?ooool0
0omEEEGoV9RHooooo`02o`0000;ooooo00Oo0000oooooooooooo0000oa0@4?o^k^koEEEE00;o0000
00?oA4A4okZj^_ooool00_ooool01OnHV9So0000o`000?m4A4Co^[Zj00;ooooo00Sok^k^oeEEEOl0
003o0000odA4A?nj^[[ooooooa0@40Go00000oooool02?l@413o<S8bo`000?l0003o410@ojVYZOn7
QhOoIVIV1oooool001Oooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3ooooooekooooo00Kok^k^ob4Q
8On7QhOo^[Zjo`000?oMgMd<ooooo`05o`000?ooooooooooooooool000000_ooool02ol0003ooooo
ooooool0003ooooooeEEEOmgMgOoooooonk^k_mgMgOo410@00?ooooo00Go410@okZj^_o^k^koMgMg
oa0@4002ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo410@0oooool00ol0003oooooooooo`04oooo
o`08o`000?nYZJWooooooooooonj^[[o0000onk^k_l00007ooooo`00ool0002do`0000oooooo00Co
gMgMo`000?l@413oc<c<3Oooool01Olb<S;ooooooooooooooooo000000;ooooo00Ko0000oooooooo
oooo0000ooooool00008ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`07okZj^_n7QhOoIVIVofIVI_l@413oooooo`000007ooooo`002_oo
ool00ol0003oooooooooo`03ooooo`Ko00001Oooool00ol0003oooooo`000003ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00003ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00002ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`;o
00001?ooool00ol0003oooooooooo`03ooooo`;o00000_ooool3o`0001;ooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0Gooooo`04onk^k_lQ8B7o410@onk^kPgooooo00Go<S8boooo
ooooooooooooo`000002ooooo`05o`000?ooooooooooo`000?ooool01_l00003ooooo`03o`000?oo
oooooooo00Cooooo1_l00003ooooo`03o`000?oooooooooo00Cooooo00So<S8bob4Q8OmgMgOoMgMg
ohN7Qoo^k^koooooo`0000Oooooo000:ooooo`03o`000?oooooooooo00oooooo0_l00003ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00003oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01_l0003oooooooooool0003o
ooooo`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`;o00001?oo
ool00ol0003oooooooooo`04ooooo`?o00000_ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool05oooool01?lQ8B7oMgMgogMgMolb<S8=ooooo`05o`00
0?o^k^koooooooooool000000_o<c<`02ol0003oZJVYomgMgOlQ8B7ooooooeEEEOn7QhOok^k^oooo
oon7QhOo<S8b00?ooooo00?o0000ooooooooool01?ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b
<P?ooooo00?o0000oc8b<_oMgMd01?ooool02?l0003o^[Zjooooooo^k^koMgMgo`000?o^k^ko0000
1oooool001cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo02oooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`1Kooooo`03o`00
0?oooooooooo05_ooooo00?o0000ooooooooool05_ooool2o`0000;ooooo0_l0000<ooooo`0>oeEE
EOmgMgOooooooa0@4?l0003o8B4Qo`000?mgMgOo410@o`000?nYZJWoooooonk^k_mEEED2o`000004
odA4A?o^k^kooooooa0@40Go00000oooool01_o^k^koEEEEo`000?l0003oA4A4onk^kP;ooooo0_l0
00001?nYZJWo8B4Qo`000?lQ8B42ooooo`08ojVYZOlQ8B7o0000o`000?lb<S;o0000ogMgMomEEED7
ooooo`007Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0oooo
oomeooooo`03omgMgOl@413ok^k^01;ooooo00?o0000ooooooooool06Oooool00oo^k^ko410@omgM
g@07ooooo`007Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
oooooomfooooo`03ogMgMomVIVKooooo017ooooo00?o0000ooooooooool06Oooool00omVIVKoMgMg
ooooo`07ooooo`007Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool00000ooooooncoooo
o`007Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool00000ooooooncooooo`007_ooool0
0ol0003oooooo`000007ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool01Ol0003ooooooooooooooooo00000?oooooo/oooool001kooooo00?o0000ooooool000001ooo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo
0000ooooooncooooo`007_ooool3o`0000Oooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooo00000?oooooo]?ooool002Sooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo00000?oooooo]?ooool002Sooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03o`000003ooooool0003ooooo00?ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo00000?oooooo
]?ooool002Sooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooo00000?oooooo]?ooool002Sooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`04ooooo`?o0000oooooondooooo`00:?ooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo0?oooooo^oooool002Sooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`3ooooook_ooooo000Xooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000oooooonnooooo`00
:?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool01Ol0003ooooooooooooooooo00000?oooooo__ooool002Wooooo00Go0000oooooooo
ooooooooo`000002ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooo
oooo00000?oooooo__ooool002Wooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oo
ooooooooooooool000001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo00000?oooooo__ooool002Wooooo
00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000001?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0
003ooooooooooooooooo00000?oooooo__ooool002Wooooo00Go0000ooooooooooooooooo`000002
ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo00000?oooooo
__ooool002Wooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool0
00001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool01Ol0003ooooooooooooooooo00000?oooooo__ooool002Wooooo00Go0000oooooooo
ooooooooo`000002ooooo`?o000000?oooooo`000?ooool00oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo
00000?oooooo__ooool002Wooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oooooo
ooooooooool000001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool01Ol0003ooooooooooooooooo00000?oooooo__ooool002Wooooo00Go
0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003o
oooooooooooooooo00000?oooooo__ooool002Wooooo00Go0000ooooooooooooooooo`000002oooo
o`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo00000?oooooo__oo
ool002Wooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool00000
1?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool01Ol0003ooooooooooooooooo00000?oooooo__ooool002Wooooo00Go0000oooooooooooo
ooooo`000002ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo
00000?oooooo__ooool002Wooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oooooo
ooooooooool000001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool01Ol0003ooooooooooooooooo00000?oooooo__ooool002Wooooo00Go
0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003o
oooooooooooooooo00000?oooooo__ooool002Wooooo00Go0000ooooooooooooooooo`000002oooo
o`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo00000?oooooo__oo
ool002[ooooo00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo000000Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo
00Go0000ooooooooooooooooo`00003ooooookkooooo000Zooooo`04o`000?ooooooooooo`0000;o
oooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`000?oooooo_oooool0
02[ooooo00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Co
0000oooooooooooo0000oooooonoooooo`00:_ooool01?l0003oooooooooool00002ooooo`?o0000
00?oooooo`000?ooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool01?l0003oooooooooool0003ooooookoooooo000Zooooo`04o`00
0?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`04o`000?oooooooooo
o`000?oooooo_oooool002[ooooo00?o0000ooooool000000oooool01Ol0003ooooooooooooooooo
000000Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00Co0000oooooooooooo0000oooooonoooooo`00:_ooool00ol0003oooooo`000003
ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0003ooooookoooooo
000Zooooo`03o`000?oooooo000000?ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`04o`00
0?ooooooooooo`000?oooooo_oooool002[ooooo00?o0000ooooool000000oooool01Ol0003ooooo
oooooooooooo000000Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooool00000oooooonoooooo`003oooool2onk^kP?ooooo
0_o^k^hDooooo`03o`000?oooooo000000?ooooo00Go0000ooooooooooooooooo`000004ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooo00000?oooooo_oooool000Sooooo1Ol00002ooooo`07onk^k_mEEEGok^k^ooooooo^
k^koEEEEonk^kP03ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPGooooo
00?o0000ooooool000000oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool0
0000oooooonoooooo`002?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00Gok^k^oeEEEOoM
gMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`03o`000?oooooo000000?ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oo
oooooooo00Cooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooo00000?oooooo
_oooool000Wooooo00?oV9RHob4Q8Oo^k^h01Oooool00ooMgMgo0000omgMg@07ooooo`03o`000?oo
oooooooo00;ooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooo000000?ooooo
00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooo
ooooooooo`000008ooooo`03o`000?oooooo00000?oooooo_oooool000[ooooo00?oV9RHob4Q8Oo^
k^h00oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0
003ooooooooooooooooo000000Gooooo00?o0000ooooool000000oooool01Ol0003ooooooooooooo
oooo000000Cooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Sooooo
00?o0000ooooool00000oooooonoooooo`002oooool02omgMgOoIVIVooooooooooook^k^oeEEEOo^
k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000000Gooooo00?o0000ooooool000000oooool5o`0000Cooooo00?o0000ooooooooool01?oo
ool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooool00000oooooonoooooo`003?oo
ool00ol0003oooooooooo`02onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go
410@oooooooooooooooooa0@4005ooooo`03o`000?oooooo000000?ooooo00Go0000oooooooooooo
ooooo`000004ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000008oooo
o`03o`000?oooooo00000?oooooo_oooool000Sooooo00Go0000okZj^_ooooooV9RHoa0@400>oooo
o`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooo
000000?ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00Cooooo00Go
0000ooooooooooooooooo`000008ooooo`03o`000?oooooo00000?oooooo_oooool000Sooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c00<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP03ooooo`?o000000?oooooo`000?ooool00_ooool01Ol0003ooooooooooooooooo0000
00Cooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000
ooooool00000oooooonoooooo`009oooool00ol0003oooooooooo`02o`0000Cooooo00Go0000oooo
ooooooooooooo`000004ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00
0008ooooo`03o`000?oooooo00000?oooooo_oooool002Oooooo00?o0000ooooooooool00_l00004
ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`04ooooo`05o`000?oo
ooooooooooooool000002?ooool00ol0003oooooo`00003ooooookoooooo000Wooooo`?o00001_oo
ool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool01?ooool01Ol0003ooooo
oooooooooooo000000Sooooo00?o0000ooooool00000oooooonoooooo`00:?ooool00ol0003ooooo
ooooo`05ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`04ooooo`05
o`000?ooooooooooooooool000002?ooool00ol0003oooooo`00003ooooookoooooo000Yooooo`03
o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo
00Cooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooo00000?oooooo_oooool0
033ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00Cooooo00Go0000
ooooooooooooooooo`000008ooooo`03o`000?oooooo00000?oooooo_oooool0033ooooo00Go0000
ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooooooo
o`000008ooooo`;o0000ooooooo0ooooo`00<?ooool01Ol0003ooooooooooooooooo000000Cooooo
00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Sooooo0_l0003ooooool3o
oooo000`ooooo`?o000000?oooooo`000?ooool00oooool00ol0003oooooooooo`04ooooo`05o`00
0?ooooooooooooooool000002?ooool2o`000?oooooo`?ooool0033ooooo00Go0000oooooooooooo
ooooo`000004ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00002Oooool00ol0
003oooooooooo`3ooooookkooooo000`ooooo`05o`000?ooooooooooooooool000001?ooool00ol0
003oooooooooo`05ooooo`04o`000?ooooooooooo`000?oooooob_ooool0033ooooo00Go0000oooo
ooooooooooooo`000004ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo0000oooo
ooo:ooooo`00<?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001ooo
ool01?l0003oooooooooool0003ooooool[ooooo000`ooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`000?oooooob_ooool0033ooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooo
oooo0000ooooooo:ooooo`00<?ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000001oooool01?l0003oooooooooool0003ooooool[ooooo000`ooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`000?oooooob_oo
ool0033ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Oooooo00Co
0000oooooooooooo0000ooooooo:ooooo`00<?ooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000001oooool01?l0003oooooooooool0003ooooool[ooooo000`ooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`00
0?oooooob_ooool0033ooooo0ol00002ooooo`05o`000?ooooooooooooooool000001oooool01?l0
003oooooooooool0003ooooool[ooooo000`ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`000007ooooo`04o`000?ooooooooooo`000?oooooob_ooool0033ooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000
ooooooo:ooooo`00<?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
1oooool01?l0003oooooooooool0003ooooool[ooooo000`ooooo`03o`000?oooooooooo00;ooooo
00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`000?oooooob_ooool0033o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooo
oooooooo0000ooooooo:ooooo`00<?ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000Sooooo00Co0000oooooooooooo0000ooooooo:ooooo`00<?ooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000ooooooo:ooooo`00<?oo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo
0000ooooooo:ooooo`00<?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000So
oooo00Co0000oooooooooooo0000ooooooo:ooooo`00<?ooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000ooooooo:ooooo`00<?ooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000oooo
ooo:ooooo`00<?ooool3o`0000;ooooo00Co0000oooooooooooo00002?ooool01?l0003ooooooooo
ool0003ooooool[ooooo000`ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool0003ooooool[ooooo000`ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0003ooooool[ooooo000`ooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0003o
oooool[ooooo000`ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00002?ooool0
1?l0003oooooooooool0003ooooool[ooooo000`ooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00002?ooool01?l0003oooooooooool0003ooooool[ooooo000?ooooo`;ok^k^0ooo
ool2onk^kQ[ooooo00?o0000ooooooooool00oooool00ol0003oooooo`000008ooooo`04o`000?oo
ooooooooo`000?oooooob_ooool000[ooooo0_l000002_l@413oooooooooooo^k^koEEEEonk^k_oo
ooook^k^oeEEEOo^k^h3ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP_o
oooo00?o0000ooooooooool00oooool00ol0003oooooo`000008ooooo`04o`000?ooooooooooo`00
0?oooooob_ooool000_ooooo00?o0000ooooooooool00_ooool01Oo^k^koEEEEomgMgOmEEEGok^k^
00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?o0000
ooooooooool00oooool00ol0003oooooo`000008ooooo`04o`000?ooooooooooo`000?oooooob_oo
ool000Sooooo1Ol00004ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@00_ooooo00?o0000ooooooooool00oooool00ol0003oooooo`00
0008ooooo`04o`000?ooooooooooo`000?oooooob_ooool000Sooooo00CoA4A4omgMgOoooooo0000
1?ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000000_ooooo00?o0000ooooooooool00oooool00ol0003oooooo`000008oooo
o`04o`000?ooooooooooo`000?oooooob_ooool000Sooooo00CogMgMoeEEEOoooooo00000oooool0
1oo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000002oooool4o`0000;ooooo00?o0000ooooool000002?ooool01?l0003o
ooooooooool0003ooooool[ooooo0009ooooo`03ogMgMoo<c<co000000?ooooo0_o^k^h3ooooo`;o
k^k^1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41002oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooo000000Sooooo00Co0000oooooooooooo0000ooooooo:
ooooo`002Oooool00oo^k^koA4A4o`00000?ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000002?ooool0
1?l0003oooooooooool0003ooooool[ooooo000:ooooo`03ogMgMol0003ooooo00cooooo00?oEEEE
ofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo0_l00006ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooool000002?ooool01?l0003oooooooooool0003ooooool[ooooo
000Wooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool00oooool00ol0003ooooo
o`000008ooooo`04o`000?ooooooooooo`000?oooooob_ooool002Oooooo00Co0000oooooooooooo
00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Sooooo00Co0000oooooooo
oooo0000ooooooo:ooooo`009oooool3o`0000Kooooo00?o0000ooooooooool00oooool00ol0003o
ooooo`000008ooooo`04o`000?ooooooooooo`000?oooooob_ooool002Sooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Sooooo00Co0000oooooooo
oooo0000ooooooo:ooooo`00:Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooool000002?ooool01?l0003oooooooooool0003ooooool[ooooo000`ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooool000002?ooool01?l0003oooooooooool0003ooooo
ol[ooooo000`ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000002?ooool00ol0003o
ooooo`00003ooooool_ooooo000`ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool00000
2?ooool00ol0003oooooo`00003ooooool_ooooo000`ooooo`?o00000oooool00ol0003oooooo`00
0008ooooo`03o`000?oooooo00000?ooooooboooool0033ooooo00?o0000ooooooooool00oooool0
0ol0003oooooo`000008ooooo`03o`000?oooooo00000?ooooooboooool0033ooooo00?o0000oooo
ooooool00oooool00ol0003oooooo`000008ooooo`03o`000?oooooo00000?ooooooboooool0033o
oooo00?o0000ooooooooool00oooool00ol0003oooooo`000009ooooo`;o0000ooooooo;ooooo`00
<?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Wooooo0_l0003ooooool_ooooo
000`ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000002Oooool2o`000?oooooobooo
ool0033ooooo00?o0000ooooooooool00oooool2o`0000[ooooo0_l0003ooooool_ooooo000`oooo
o`03o`000?oooooooooo00?ooooo0_l0000:ooooo`;o0000ooooooo;ooooo`00<?ooool00ol0003o
ooooooooo`03ooooo`;o00002_ooool2o`000?ooooooboooool0033ooooo00?o0000ooooooooool0
0oooool2o`0000[ooooo0_l0003ooooool_ooooo000`ooooo`03o`000?oooooooooo00?ooooo0_l0
000:ooooo`;o0000ooooooo;ooooo`00<?ooool00ol0003oooooooooo`03ooooo`;o00002_ooool2
o`000?ooooooboooool0033ooooo0ol00003ooooo`;o00002_ooool2o`000?ooooooboooool0033o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`;o0000ooooooo;ooooo`00
<?ooool00ol0003oooooooooo`0?ooooo`;o0000ooooooo;ooooo`00<?ooool00ol0003ooooooooo
o`0?ooooo`;o0000ooooooo;ooooo`00<?ooool00ol0003oooooooooo`0?ooooo`;o0000ooooooo;
ooooo`00<?ooool00ol0003oooooooooo`0?ooooo`;o0000ooooooo;ooooo`00<?ooool00ol0003o
ooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o
0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`oooo
o`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00
<?ooool3o`000?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool0
0ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033o
oooo00?o0000ooooooooool0oooooooLooooo`00oooooooooooooa3ooooo003ooooooooooooo4?oo
ool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooo
ooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00:3ooooo0_l00004oooo
o`03okZj^_lb<S;ooooo00Cooooo0_l00006ooooo`03o`000?nj^[[ooooo0?ooooooEoooool00:3o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Co
oooo0_lb<S;ooooooeSooooo002=ooooo`?o00000_ooool01_lb<S;o410@ooooooooooook^k^oeEE
E@;o000000?oA4A4okZj^_ooool00oooool00ol0003oooooooooo`02ooooo`05oiRHV?l@413o0000
o`000?nYZJT01?ooool00ol0003oooooooooo`04ooooo`03ohN7Qol0003o^[Zj00cooooo00GoV9RH
o`000?l0003oA4A4okZj^P09ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
00_ok^k^oc8b<_l0003o410@olc<c?ooooooc<c<onk^k_ooooook^k^olc<c004ooooo`Co000000So
410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kQ?ooooo00Ko410@oc8b<_l0003o0000oa0@4?nY
ZJT2ooooo`06onk^k_mEEEGo0000o`000?m4A4Co^[Zj0oooool01OmVIVKo0000o`000?m4A4Coc<c<
0>Sooooo002>ooooo`05o`000?ooooooooooolc<c?l@41000oooool01_mEEEGoMgMgooooooo^k^ko
MgMgoa0@40Cooooo00?o0000ooooooooool00_ooool01_l0003oZJVYoeEEEOnHV9SoEEEEokZj^P?o
oooo00?o0000ooooooooool01?ooool00oo<c<co0000oa0@400<ooooo`06oa0@4?nj^[[ok^k^ogMg
Mol@413ooooo1_l00002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00_o
EEEEogMgMoooooooV9RHob4Q8Oooooook^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Cooooo`06o`000?nYZJWooooooooooonj^[[o
00000_ooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40;ooooo00KoIVIVogMgMoooooooooooohN7
Qol@413Xooooo`00S_ooool01Ol0003ooooooooooomEEEGoQhN700?ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`02ooooo`06oc8b<_o^k^koV9RHoeEEEOoMgMgo410@0oooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo00_ooooo00Go410@oooooooooooooooooa0@400;
ooooo`05o`000?ooooooooooooooool000000_ooool00ooMgMgo0000omgMg@07ooooo`03o`000?oo
oooooooo00;ooooo00Go410@oooooooooooooooooa0@400Dooooo`05okZj^_n7QhOoIVIVofIVI_l@
41000_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0>_ooooo002>ooooo`05o`00
0?oooooogMgMo`000?o^k^h00oooool6o`0000Cooooo00?o0000ooooooooool00_ooool01onj^[[o
A4A4olc<c?lQ8B7ooooooa0@4?o<c<`00_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo00?ooooo1_l00002ooooo`05o`000?ooooooooooooooool000002oooool02ol0003oV9RHoooo
oonHV9So8B4Qooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000001?ooooo00Ko<S8bob4Q8OmgMgOoMgMgohN7Qoo^k^h2ooooo`Ko
00000_ooool00ol0003oooooooooo`3[ooooo`00S_ooool3o`000003oa0@4?nHV9Sooooo00;ooooo
00KoEEEEohN7Qoo^k^koooooohN7Qolb<S84ooooo`03o`000?oooooooooo00;ooooo00Ook^k^o`00
0?oooooo0000oooooomVIVKoQhN700;ooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0;ooooo`05o`000?ooooooooooooooool000002oooool02ol0003oEEEEo`000?l@413oc<c<oooo
ooo<c<cok^k^ooooooo^k^koc<c<00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000001?ooooo00Ko0000okZj^_ooooook^k^ogMgMol00002ooooo`06oeEEEOn7QhOok^k^
oooooon7QhOo<S8b0_ooool01_mVIVKoMgMgooooooooooooQhN7o`000>Sooooo002>ooooo`05o`00
0?ooooooooooolc<c?l000000oooool01_o^k^koEEEEo`000?l0003oA4A4onk^kPCooooo00?o0000
ooooooooool00_ooool01?mVIVKoV9RHoooooolb<S82okZj^P04o`000?ooooooooooo`0001?ooooo
00?o410@o`000?l000000ol0000:ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGo
QhN7ooooo`0>ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4007oooo
o`?o00000_ooool3o`0000Cooooo00KoZJVYob4Q8Ol0003o0000oc8b<_l00002ooooo`06onk^k_mE
EEGo0000o`000?m4A4Cok^k^0_ooool01_o^k^koIVIVo`000?l0003oA4A4o`000>Sooooo002>oooo
o`05o`000?ooooooooooolc<c?l000003Oooool00ol0003oooooooooo`05ooooo`03ofIVI_n7QhOo
oooo00?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0;ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV00>ooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
ooooool2ooooo`00SOooool4o`000003oa0@4?nYZJWooooo00cooooo0_l00006ooooo`03ojVYZOm4
A4Cooooo00;ooooo0_l0000Eooooo`03o`000?oooooooooo00_ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40[ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00;ooooo1?l00002ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0ooooool2ooooo`00ooooool6ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0ooooool2ooooo`00ooooool6ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
ooooool2ooooo`00ooooool5ooooo`;o00000oooool2o`000?oooooo1?ooool00?ooooooooooool@
ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooo
oooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3o
oooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooo
oooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?oo
ool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooo
ooooool@ooooo`00oooooooooooooa3ooooo0000\
\>"],
  ImageRangeCache->{{{0, 525.688}, {324.5, 0}} -> {0, -6.34248*^6, 0, 53093}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0.309017 5.42214e-08 [
[.32684 .29652 -16.5 -12.5 ]
[.32684 .29652 16.5 0 ]
[.54329 .29652 -16.5 -12.5 ]
[.54329 .29652 16.5 0 ]
[.75974 .29652 -22.5 -12.5 ]
[.75974 .29652 22.5 0 ]
[.97619 .29652 -16.5 -12.5 ]
[.97619 .29652 16.5 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 64 6 ]
[.09789 .09213 -34.5 -6.25 ]
[.09789 .09213 0 6.25 ]
[.09789 .20057 -34.5 -6.25 ]
[.09789 .20057 0 6.25 ]
[.09789 .41746 -28.5 -6.25 ]
[.09789 .41746 0 6.25 ]
[.09789 .5259 -28.5 -6.25 ]
[.09789 .5259 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -62.8125 0 ]
[.5 .63053 62.8125 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 .30902 m
.32684 .31527 L
s
gsave
.32684 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 .30902 m
.54329 .31527 L
s
gsave
.54329 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 .30902 m
.75974 .31527 L
s
gsave
.75974 .29652 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 .30902 m
.15368 .31277 L
s
.19697 .30902 m
.19697 .31277 L
s
.24026 .30902 m
.24026 .31277 L
s
.28355 .30902 m
.28355 .31277 L
s
.37013 .30902 m
.37013 .31277 L
s
.41342 .30902 m
.41342 .31277 L
s
.45671 .30902 m
.45671 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.58658 .30902 m
.58658 .31277 L
s
.62987 .30902 m
.62987 .31277 L
s
.67316 .30902 m
.67316 .31277 L
s
.71645 .30902 m
.71645 .31277 L
s
.80303 .30902 m
.80303 .31277 L
s
.84632 .30902 m
.84632 .31277 L
s
.88961 .30902 m
.88961 .31277 L
s
.9329 .30902 m
.9329 .31277 L
s
.0671 .30902 m
.0671 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09213 m
.11664 .09213 L
s
gsave
.09789 .09213 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .20057 m
.11664 .20057 L
s
gsave
.09789 .20057 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .41746 m
.11664 .41746 L
s
gsave
.09789 .41746 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .5259 m
.11664 .5259 L
s
gsave
.09789 .5259 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.11039 .11924 m
.11414 .11924 L
s
.11039 .14635 m
.11414 .14635 L
s
.11039 .17346 m
.11414 .17346 L
s
.11039 .22768 m
.11414 .22768 L
s
.11039 .2548 m
.11414 .2548 L
s
.11039 .28191 m
.11414 .28191 L
s
.11039 .33613 m
.11414 .33613 L
s
.11039 .36324 m
.11414 .36324 L
s
.11039 .39035 m
.11414 .39035 L
s
.11039 .44457 m
.11414 .44457 L
s
.11039 .47168 m
.11414 .47168 L
s
.11039 .49879 m
.11414 .49879 L
s
.11039 .06502 m
.11414 .06502 L
s
.11039 .03791 m
.11414 .03791 L
s
.11039 .0108 m
.11414 .0108 L
s
.11039 .55301 m
.11414 .55301 L
s
.11039 .58012 m
.11414 .58012 L
s
.11039 .60723 m
.11414 .60723 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -123.812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.812 moveto
(@) show
81.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.812 moveto
(D) show
93.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.8) show
135.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
141.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
153.000 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
157.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
166.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
184.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30899 m
.02691 .30893 L
.02852 .30889 L
.02938 .30888 L
.02985 .30887 L
.03029 .30886 L
.03071 .30886 L
.03092 .30886 L
.03115 .30885 L
.03135 .30885 L
.03146 .30885 L
.03156 .30885 L
.03166 .30885 L
.03174 .30885 L
.03184 .30885 L
.03194 .30885 L
.03203 .30885 L
.03212 .30885 L
.03222 .30885 L
.03232 .30885 L
.03249 .30885 L
.03267 .30886 L
.03287 .30886 L
.03309 .30886 L
.03347 .30887 L
.03387 .30887 L
.03423 .30888 L
.03505 .30891 L
.0358 .30895 L
.03652 .30899 L
.03812 .30912 L
.03959 .30928 L
.04275 .30968 L
.04352 .30977 L
.04433 .30985 L
.04502 .30991 L
.04541 .30993 L
.04578 .30995 L
.04598 .30996 L
.04608 .30996 L
.04617 .30996 L
.04625 .30997 L
.04634 .30997 L
.04643 .30997 L
.04653 .30997 L
.04663 .30997 L
.04673 .30997 L
.04678 .30997 L
.04684 .30997 L
.04694 .30997 L
Mistroke
.04704 .30996 L
.04714 .30996 L
.04733 .30996 L
.04755 .30994 L
.04778 .30993 L
.04821 .30989 L
.04862 .30984 L
.049 .30979 L
.04979 .30964 L
.05052 .30945 L
.05218 .30886 L
.05381 .30807 L
.0553 .30722 L
.05697 .30623 L
.0577 .30582 L
.05851 .30541 L
.05923 .30511 L
.0596 .30498 L
.06 .30487 L
.06021 .30483 L
.06043 .30479 L
.06053 .30477 L
.06063 .30476 L
.06073 .30475 L
.06082 .30474 L
.06092 .30474 L
.06097 .30474 L
.06103 .30473 L
.06112 .30473 L
.06122 .30473 L
.06131 .30474 L
.06141 .30474 L
.0615 .30475 L
.06159 .30476 L
.06177 .30478 L
.06197 .30482 L
.06218 .30487 L
.06238 .30493 L
.06274 .30506 L
.06312 .30525 L
.06399 .30584 L
.06478 .30661 L
.0663 .30862 L
.06796 .31161 L
.07121 .31864 L
.07272 .32155 L
.07356 .32283 L
.07397 .32331 L
.07435 .32367 L
.07455 .32383 L
Mistroke
.07474 .32394 L
.07495 .32404 L
.07507 .32408 L
.07512 .3241 L
.07518 .32411 L
.07528 .32413 L
.07534 .32414 L
.07539 .32415 L
.07549 .32415 L
.0756 .32414 L
.07565 .32413 L
.07571 .32412 L
.07578 .32411 L
.07584 .32409 L
.07594 .32405 L
.07606 .324 L
.07627 .32387 L
.07646 .32372 L
.07684 .32332 L
.07727 .3227 L
.07767 .32195 L
.07845 .32005 L
.07917 .31771 L
.08083 .31044 L
.08393 .29154 L
.08551 .28141 L
.08635 .27659 L
.08724 .27221 L
.08768 .27042 L
.0881 .26902 L
.08848 .26801 L
.08867 .26759 L
.08889 .26722 L
.08898 .26708 L
.08909 .26696 L
.08918 .26687 L
.08927 .26679 L
.08933 .26675 L
.08938 .26672 L
.08949 .26668 L
.08958 .26667 L
.08968 .26668 L
.08978 .26671 L
.08988 .26676 L
.08998 .26683 L
.09007 .26692 L
.09024 .26714 L
.09042 .26745 L
.09082 .26842 L
.09118 .26965 L
Mistroke
.0916 .2715 L
.092 .27367 L
.09271 .27854 L
.09347 .28528 L
.09507 .30365 L
.09675 .32804 L
.09979 .37434 L
.10059 .38456 L
.10135 .39267 L
.10176 .39632 L
.10222 .39955 L
.10242 .4007 L
.10264 .40174 L
.10282 .40246 L
.10302 .40309 L
.10313 .40334 L
.10323 .40353 L
.10329 .40361 L
.10334 .40367 L
.1034 .40373 L
.10345 .40376 L
.10355 .40379 L
.10364 .40378 L
.10374 .40371 L
.10385 .40358 L
.10395 .4034 L
.10407 .40314 L
.10427 .4025 L
.10452 .40144 L
.10474 .4002 L
.10512 .39749 L
.10553 .39364 L
.10636 .38309 L
.10718 .36902 L
.10793 .35333 L
.10961 .30985 L
.11282 .21366 L
.11429 .17557 L
.11513 .15865 L
.11553 .152 L
.11591 .14696 L
.1163 .1428 L
.11648 .1413 L
.11668 .14001 L
.11678 .13942 L
.11688 .13898 L
.11698 .13861 L
.11707 .13835 L
.11712 .13824 L
.11718 .13814 L
Mistroke
.11723 .13807 L
.11729 .13802 L
.11735 .13801 L
.1174 .13802 L
.1175 .13812 L
.11756 .13821 L
.11762 .13833 L
.11772 .13864 L
.11783 .13908 L
.11796 .1397 L
.11818 .14116 L
.11839 .14296 L
.11877 .14739 L
.11919 .15373 L
.11996 .16968 L
.1208 .1931 L
.1225 .25672 L
.12576 .41139 L
.12726 .47803 L
.12805 .50733 L
.12889 .53222 L
.12932 .54207 L
.12954 .54645 L
.12979 .5505 L
.13001 .55358 L
.13021 .55587 L
.13042 .55763 L
.13052 .5583 L
.13061 .55882 L
.1307 .55921 L
.1308 .55951 L
.1309 .55967 L
.13096 .55971 L
.13101 .5597 L
.1311 .55961 L
.13119 .5594 L
.13129 .55905 L
.13138 .5586 L
.13149 .55792 L
.1316 .55713 L
.13179 .55526 L
.132 .55267 L
.13223 .5492 L
.13262 .54159 L
.13298 .53262 L
.13382 .50584 L
.13463 .47185 L
.13551 .4278 L
.13882 .22298 L
.14047 .125 L
Mistroke
.14128 .08496 L
.14201 .05484 L
.14237 .04223 L
.14277 .0307 L
.14311 .02257 L
.14349 .01569 L
.1437 .01284 L
.14389 .0108 L
.144 .00992 L
.14409 .00929 L
.14415 .009 L
.14421 .00874 L
.14426 .00855 L
.14431 .00841 L
.1444 .00827 L
.14449 .00827 L
.14458 .00839 L
.14468 .00868 L
.14478 .00913 L
.14488 .00978 L
.14507 .01138 L
.14528 .0138 L
.14547 .01672 L
.14584 .02381 L
.14623 .03376 L
.14666 .04718 L
.14813 .11287 L
.14973 .21013 L
.15142 .32785 L
.15301 .43605 L
.15446 .51943 L
.15526 .55528 L
.15602 .5811 L
.15644 .59155 L
.15682 .5988 L
.15704 .60188 L
.15725 .60398 L
.15736 .60485 L
.15742 .60523 L
.15748 .60557 L
.15753 .60582 L
.15759 .60603 L
.1577 .60626 L
.1578 .60631 L
.1579 .6062 L
.15795 .60608 L
.15801 .6059 L
.15806 .60566 L
.15812 .60538 L
.15831 .60401 L
Mistroke
.15842 .60299 L
.15852 .60188 L
.1589 .59612 L
.15927 .58852 L
.16007 .56487 L
.16095 .52917 L
.16252 .44468 L
.16421 .33842 L
.16581 .23747 L
.16665 .18951 L
.16754 .1454 L
.16834 .11312 L
.16876 .09915 L
.16922 .08674 L
.16963 .07778 L
.17001 .07169 L
.1702 .06948 L
.17039 .06761 L
.17049 .06694 L
.17058 .06636 L
.17067 .06596 L
.17076 .06563 L
.17085 .06541 L
.17094 .06532 L
.17104 .06536 L
.1711 .06544 L
.17115 .06555 L
.17125 .06588 L
.17131 .06613 L
.17136 .0664 L
.17157 .06776 L
.17174 .06936 L
.17193 .07156 L
.17231 .0774 L
.17272 .08584 L
.17317 .09716 L
.17398 .12296 L
.17729 .27322 L
.17895 .35227 L
.17975 .38637 L
.18048 .41343 L
.1812 .43569 L
.18197 .45449 L
.18239 .46236 L
.18278 .46799 L
.18316 .47193 L
.18334 .47338 L
.18345 .47405 L
.18355 .47456 L
.18365 .47497 L
Mistroke
.18375 .4753 L
.18381 .47544 L
.18386 .47553 L
.18391 .47561 L
.18397 .47565 L
.18407 .47565 L
.18412 .47561 L
.18418 .47554 L
.18428 .47534 L
.18437 .47508 L
.18447 .4747 L
.18456 .47427 L
.18473 .47324 L
.18492 .47184 L
.18512 .46996 L
.18554 .46485 L
.18599 .45784 L
.1868 .44158 L
.18837 .39934 L
.18984 .353 L
.19133 .30599 L
.19296 .26178 L
.19384 .2429 L
.19466 .22937 L
.19506 .22419 L
.19544 .22025 L
.19565 .21846 L
.19588 .21683 L
.19609 .21562 L
.19627 .21475 L
.19647 .21409 L
.19657 .21382 L
.19667 .21363 L
.19676 .2135 L
.19685 .21343 L
.19694 .2134 L
.19704 .21343 L
.19714 .21351 L
.1972 .21358 L
.19725 .21366 L
.19735 .21386 L
.19744 .2141 L
.19765 .21482 L
.19788 .21586 L
.1983 .21852 L
.19876 .22231 L
.19957 .23132 L
.20129 .25713 L
.20291 .28543 L
.20438 .31034 L
Mistroke
.20522 .32286 L
.206 .333 L
.20684 .3419 L
.2076 .34808 L
.20802 .35067 L
.20842 .35258 L
.20862 .35336 L
.20884 .35404 L
.20895 .35433 L
.20907 .35461 L
.20919 .35482 L
.20929 .35499 L
.20939 .3551 L
.20948 .35519 L
.20954 .35523 L
.20959 .35526 L
.20969 .35529 L
.20979 .35529 L
.20989 .35526 L
.20999 .3552 L
.21005 .35516 L
.2101 .35511 L
.21029 .35487 L
.21049 .35451 L
.21085 .35359 L
.2113 .352 L
.21172 .35007 L
.21252 .34551 L
.21559 .32172 L
.2173 .3085 L
.21886 .29901 L
.21964 .29546 L
.22004 .29394 L
.22048 .29262 L
.22086 .29169 L
.22106 .29128 L
.22127 .29091 L
.22147 .29063 L
.22165 .29042 L
.22183 .29026 L
.222 .29014 L
.22209 .2901 L
.22219 .29006 L
.22229 .29004 L
.22237 .29003 L
.22247 .29003 L
.22257 .29004 L
.22262 .29005 L
.22268 .29007 L
.22278 .2901 L
Mistroke
.22288 .29016 L
.223 .29023 L
.22321 .2904 L
.2236 .29085 L
.22398 .29143 L
.22437 .29218 L
.22508 .29382 L
.22813 .30329 L
.22982 .30846 L
.23137 .31216 L
.23213 .31352 L
.23254 .3141 L
.23297 .31462 L
.23334 .31498 L
.23376 .31528 L
.23394 .31539 L
.23413 .31548 L
.23432 .31555 L
.23449 .3156 L
.23459 .31562 L
.23469 .31564 L
.23477 .31565 L
.23487 .31565 L
.23497 .31566 L
.23502 .31566 L
.23508 .31566 L
.23518 .31565 L
.23527 .31564 L
.23537 .31562 L
.23546 .31561 L
.23563 .31556 L
.23581 .31551 L
.23601 .31543 L
.23642 .31522 L
.23687 .31493 L
.23767 .31427 L
.241 .31067 L
.24268 .30903 L
.24342 .30844 L
.24422 .30791 L
.245 .30752 L
.24537 .30738 L
.24573 .30726 L
.24613 .30716 L
.2465 .3071 L
.2467 .30707 L
.24689 .30705 L
.24699 .30704 L
.2471 .30704 L
.24715 .30704 L
Mistroke
.24721 .30703 L
.24727 .30703 L
.24732 .30703 L
.24742 .30703 L
.24752 .30703 L
.2476 .30703 L
.2477 .30703 L
.2478 .30704 L
.24791 .30705 L
.24811 .30706 L
.24829 .30708 L
.24845 .3071 L
.24884 .30716 L
.24964 .30733 L
.2505 .30757 L
.25209 .30808 L
.25381 .30863 L
.25462 .30886 L
.25547 .30907 L
.25627 .30923 L
.25701 .30935 L
.2574 .3094 L
.25783 .30944 L
.25827 .30948 L
.25851 .30949 L
.25873 .30951 L
.25892 .30951 L
.25913 .30952 L
.25925 .30952 L
.25936 .30953 L
.25946 .30953 L
.25951 .30953 L
.25957 .30953 L
.25967 .30953 L
.25976 .30953 L
.25981 .30953 L
.25987 .30953 L
.25997 .30953 L
.26007 .30953 L
.26017 .30953 L
.26035 .30952 L
.26056 .30952 L
.26078 .30951 L
.26117 .30949 L
.26207 .30944 L
.26369 .30932 L
.26673 .30907 L
.26754 .30902 L
.2683 .30898 L
.26918 .30895 L
Mistroke
.26956 .30894 L
.26998 .30893 L
.27038 .30892 L
.27075 .30891 L
.27094 .30891 L
.27115 .30891 L
.27125 .30891 L
.27137 .30891 L
.27147 .3089 L
.27157 .3089 L
.27167 .3089 L
.27177 .3089 L
.27186 .3089 L
.27194 .3089 L
.27203 .3089 L
.27214 .3089 L
.27224 .3089 L
.27234 .3089 L
.27243 .3089 L
.27252 .3089 L
.27268 .30891 L
.27305 .30891 L
.27346 .30891 L
.27382 .30892 L
.27464 .30893 L
.27612 .30896 L
.2778 .30899 L
.27934 .30901 L
.28012 .30902 L
.28085 .30903 L
.2816 .30903 L
.28201 .30903 L
.28244 .30904 L
.28264 .30904 L
.28286 .30904 L
.28305 .30904 L
.28325 .30904 L
.28337 .30904 L
.28347 .30904 L
.28358 .30904 L
.28368 .30904 L
.28379 .30904 L
.28384 .30904 L
.2839 .30904 L
.28397 .30904 L
.28403 .30904 L
.28408 .30904 L
.28414 .30904 L
.28424 .30904 L
.28434 .30904 L
Mistroke
.28444 .30904 L
.28455 .30904 L
.28478 .30904 L
.28498 .30904 L
.28538 .30904 L
.28576 .30904 L
.28735 .30903 L
.28883 .30903 L
.29045 .30902 L
.29125 .30902 L
.29198 .30902 L
.29267 .30902 L
.29343 .30901 L
.2938 .30901 L
.2942 .30901 L
.29462 .30901 L
.29501 .30901 L
.29521 .30901 L
.29543 .30901 L
.29562 .30901 L
.29573 .30901 L
.29583 .30901 L
.29588 .30901 L
.29594 .30901 L
.296 .30901 L
.29605 .30901 L
.29615 .30901 L
.29625 .30901 L
.29631 .30901 L
.29638 .30901 L
.2965 .30901 L
.29661 .30901 L
.29672 .30901 L
.29709 .30901 L
.2975 .30901 L
.29833 .30901 L
.30158 .30902 L
.30307 .30902 L
.30392 .30902 L
.3047 .30902 L
.30553 .30902 L
.30594 .30902 L
.30641 .30902 L
.30681 .30902 L
.30703 .30902 L
.30724 .30902 L
.30742 .30902 L
.30752 .30902 L
.30762 .30902 L
.30772 .30902 L
Mistroke
.30777 .30902 L
.30783 .30902 L
.30793 .30902 L
.30802 .30902 L
.30812 .30902 L
.30821 .30902 L
.30831 .30902 L
.30841 .30902 L
.30859 .30902 L
.30878 .30902 L
.30921 .30902 L
.30962 .30902 L
.31131 .30902 L
.31282 .30902 L
.31445 .30902 L
.31535 .30902 L
.31617 .30902 L
.31696 .30902 L
.31736 .30902 L
.31779 .30902 L
.31821 .30902 L
.31842 .30902 L
.31861 .30902 L
.31897 .30902 L
.31916 .30902 L
.31927 .30902 L
.31936 .30902 L
.31946 .30902 L
.31956 .30902 L
.31966 .30902 L
.31972 .30902 L
.31977 .30902 L
.31987 .30902 L
.31996 .30902 L
.32006 .30902 L
.32016 .30902 L
.32027 .30902 L
.32038 .30902 L
.32058 .30902 L
.3208 .30902 L
.32104 .30902 L
.32186 .30902 L
.32261 .30902 L
.32428 .30902 L
.32594 .30902 L
.32667 .30902 L
.32748 .30902 L
.32825 .30902 L
.32897 .30902 L
.32937 .30902 L
Mistroke
.32973 .30902 L
.33013 .30902 L
.33035 .30902 L
.33055 .30902 L
.33075 .30902 L
.33096 .30902 L
.33105 .30902 L
.33114 .30902 L
.33124 .30902 L
.33132 .30902 L
.33142 .30902 L
.33152 .30902 L
.33162 .30902 L
.33171 .30902 L
.33176 .30902 L
.33182 .30902 L
.33191 .30902 L
.33203 .30902 L
.33214 .30902 L
.3325 .30902 L
.3329 .30902 L
.33361 .30902 L
.33518 .30902 L
.3369 .30902 L
.3377 .30902 L
.33854 .30902 L
.33934 .30902 L
.34008 .30902 L
.34089 .30902 L
.34132 .30902 L
.34154 .30902 L
.34178 .30902 L
.34199 .30902 L
.34218 .30902 L
.34237 .30902 L
.34255 .30902 L
.34275 .30902 L
.34285 .30902 L
.34296 .30902 L
.34302 .30902 L
.34308 .30902 L
.34314 .30902 L
.34319 .30902 L
.34329 .30902 L
.34334 .30902 L
.3434 .30902 L
.3435 .30902 L
.3436 .30902 L
.34382 .30902 L
.34401 .30902 L
Mistroke
.34421 .30902 L
.34496 .30902 L
.34664 .30902 L
.34824 .30902 L
.34909 .30902 L
.34998 .30902 L
.35078 .30902 L
.35121 .30902 L
.35166 .30902 L
.35208 .30902 L
.35246 .30902 L
.35281 .30902 L
.3532 .30902 L
.35359 .30902 L
.3538 .30902 L
.354 .30902 L
.3541 .30902 L
.35419 .30902 L
.35427 .30902 L
.35436 .30902 L
.35445 .30902 L
.35454 .30902 L
.35464 .30902 L
.35474 .30902 L
.35484 .30902 L
.3549 .30902 L
.35495 .30902 L
.35506 .30902 L
.35515 .30902 L
.35537 .30902 L
.3556 .30902 L
.35602 .30902 L
.35641 .30902 L
.35807 .30902 L
.3596 .30902 L
.3611 .30902 L
.36185 .30902 L
.36268 .30902 L
.36308 .30902 L
.36349 .30902 L
.36385 .30902 L
.36423 .30902 L
.36465 .30902 L
.36503 .30902 L
.36527 .30902 L
.36549 .30902 L
.36569 .30902 L
.3658 .30902 L
.36591 .30902 L
.36601 .30902 L
Mistroke
.3661 .30902 L
.36619 .30902 L
.36628 .30902 L
.36638 .30902 L
.36644 .30902 L
.36649 .30902 L
.36668 .30902 L
.36686 .30902 L
.36706 .30902 L
.36741 .30902 L
.36828 .30902 L
.36907 .30902 L
.37071 .30902 L
.37151 .30902 L
.37224 .30902 L
.37295 .30902 L
.37372 .30902 L
.37414 .30902 L
.37453 .30902 L
.37529 .30902 L
.37567 .30902 L
.37607 .30902 L
.37625 .30902 L
.37645 .30902 L
.37663 .30902 L
.37679 .30902 L
.37699 .30902 L
.3771 .30902 L
.3772 .30902 L
.3773 .30902 L
.37739 .30902 L
.37748 .30902 L
.37758 .30902 L
.37769 .30902 L
.37774 .30902 L
.3778 .30902 L
.3779 .30902 L
.378 .30902 L
.37821 .30902 L
.37845 .30902 L
.3792 .30902 L
.38003 .30902 L
.38172 .30902 L
.38327 .30902 L
.38414 .30902 L
.38494 .30902 L
.38532 .30902 L
.38573 .30902 L
.38608 .30902 L
.38646 .30902 L
Mistroke
.38691 .30902 L
.38711 .30902 L
.38733 .30902 L
.38752 .30902 L
.38774 .30902 L
.38794 .30902 L
.38812 .30902 L
.38822 .30902 L
.38833 .30902 L
.38843 .30902 L
.38852 .30902 L
.38857 .30902 L
.38863 .30902 L
.38868 .30902 L
.38874 .30902 L
.38884 .30902 L
.3889 .30902 L
.38895 .30902 L
.38906 .30902 L
.38915 .30902 L
.38934 .30902 L
.38953 .30902 L
.38975 .30902 L
.39052 .30902 L
.39123 .30902 L
.39286 .30902 L
.39366 .30902 L
.39439 .30902 L
.39508 .30902 L
.39584 .30902 L
.39661 .30902 L
.39703 .30902 L
.39742 .30902 L
.39782 .30902 L
.39826 .30902 L
.39846 .30902 L
.39868 .30902 L
.39886 .30902 L
.39906 .30902 L
.39925 .30902 L
.39943 .30902 L
.39951 .30902 L
.3996 .30902 L
.39969 .30902 L
.39977 .30902 L
.39987 .30902 L
.39997 .30902 L
.40005 .30902 L
.40015 .30902 L
.40025 .30902 L
Mistroke
.4003 .30902 L
.40036 .30902 L
.40055 .30902 L
.40075 .30902 L
.40097 .30902 L
.40137 .30902 L
.40212 .30902 L
.4038 .30902 L
.40539 .30902 L
.40619 .30902 L
.40708 .30902 L
.4075 .30902 L
.40789 .30902 L
.40864 .30902 L
.40905 .30902 L
.40944 .30902 L
.40986 .30902 L
.4101 .30902 L
.41031 .30902 L
.4105 .30902 L
.4106 .30902 L
.4107 .30902 L
.41081 .30902 L
.4109 .30902 L
.41095 .30902 L
.41101 .30902 L
.41112 .30902 L
.4112 .30902 L
.4113 .30902 L
.4114 .30902 L
.4115 .30902 L
.41167 .30902 L
.41185 .30902 L
.41228 .30902 L
.41273 .30902 L
.41353 .30902 L
.41513 .30902 L
.41658 .30902 L
.41739 .30902 L
.41816 .30902 L
.41896 .30902 L
.41942 .30902 L
.41984 .30902 L
.42021 .30902 L
.42042 .30902 L
.42061 .30902 L
.4208 .30902 L
.42099 .30902 L
.42117 .30902 L
.42134 .30902 L
Mistroke
.42145 .30902 L
.42156 .30902 L
.42165 .30902 L
.42176 .30902 L
.42182 .30902 L
.42187 .30902 L
.42193 .30902 L
.42199 .30902 L
.42205 .30902 L
.4221 .30902 L
.4222 .30902 L
.4223 .30902 L
.4224 .30902 L
.42249 .30902 L
.42258 .30902 L
.4228 .30902 L
.423 .30902 L
.42379 .30902 L
.42462 .30902 L
.42611 .30902 L
.42687 .30902 L
.42769 .30902 L
.42847 .30902 L
.42917 .30902 L
.42956 .30902 L
.42997 .30902 L
.43033 .30902 L
.43071 .30902 L
.43112 .30902 L
.4315 .30902 L
.43174 .30902 L
.43196 .30902 L
.43216 .30902 L
.43227 .30902 L
.43238 .30902 L
.43248 .30902 L
.43258 .30902 L
.43269 .30902 L
.43275 .30902 L
.43281 .30902 L
.43291 .30902 L
.433 .30902 L
.43305 .30902 L
.43311 .30902 L
.43321 .30902 L
.4333 .30902 L
.4334 .30902 L
.4336 .30902 L
.43379 .30902 L
.43396 .30902 L
Mistroke
.43477 .30902 L
.43565 .30902 L
.43723 .30902 L
.43807 .30902 L
.43896 .30902 L
.43982 .30902 L
.44061 .30902 L
.44099 .30902 L
.4414 .30902 L
.44179 .30902 L
.44214 .30902 L
.44252 .30902 L
.44273 .30902 L
.44293 .30902 L
.4431 .30902 L
.4432 .30902 L
.4433 .30902 L
.44339 .30902 L
.44348 .30902 L
.44357 .30902 L
.44365 .30902 L
.44375 .30902 L
.44386 .30902 L
.44391 .30902 L
.44397 .30902 L
.44407 .30902 L
.44417 .30902 L
.44427 .30902 L
.44445 .30902 L
.44467 .30902 L
.44487 .30902 L
.44531 .30902 L
.44695 .30902 L
.44848 .30902 L
.44923 .30902 L
.44994 .30902 L
.45034 .30902 L
.45076 .30902 L
.45152 .30902 L
.45194 .30902 L
.45235 .30902 L
.45271 .30902 L
.4531 .30902 L
.4533 .30902 L
.45353 .30902 L
.45376 .30902 L
.45387 .30902 L
.45398 .30902 L
.45407 .30902 L
.45418 .30902 L
Mistroke
.45428 .30902 L
.45437 .30902 L
.45446 .30902 L
.45457 .30902 L
.45462 .30902 L
.45468 .30902 L
.45478 .30902 L
.45488 .30902 L
.45498 .30902 L
.45508 .30902 L
.45518 .30902 L
.45555 .30902 L
.45596 .30902 L
.45639 .30902 L
.45809 .30902 L
.45969 .30902 L
.46049 .30902 L
.46095 .30902 L
.46138 .30902 L
.46177 .30902 L
.4622 .30902 L
.46255 .30902 L
.46294 .30902 L
.46336 .30902 L
.46358 .30902 L
.46381 .30902 L
.46403 .30902 L
.46423 .30902 L
.46442 .30902 L
.46462 .30902 L
.46472 .30902 L
.46483 .30902 L
.46492 .30902 L
.46502 .30902 L
.46511 .30902 L
.46521 .30902 L
.4653 .30902 L
.46538 .30902 L
.46549 .30902 L
.46559 .30902 L
.46568 .30902 L
.46578 .30902 L
.466 .30902 L
.4662 .30902 L
.46692 .30902 L
.46768 .30902 L
.46928 .30902 L
.47012 .30902 L
.47102 .30902 L
.47181 .30902 L
Mistroke
.47227 .30902 L
.47269 .30902 L
.47307 .30902 L
.47344 .30902 L
.47385 .30902 L
.47423 .30902 L
.4746 .30902 L
.47481 .30902 L
.47501 .30902 L
.47522 .30902 L
.4754 .30902 L
.4755 .30902 L
.47561 .30902 L
.47567 .30902 L
.47573 .30902 L
.47583 .30902 L
.47593 .30902 L
.47602 .30902 L
.47612 .30902 L
.47618 .30902 L
.47623 .30902 L
.47632 .30902 L
.47643 .30902 L
.47661 .30902 L
.47698 .30902 L
.47731 .30902 L
.47897 .30902 L
.47977 .30902 L
.4805 .30902 L
.48122 .30902 L
.48199 .30902 L
.48242 .30902 L
.48281 .30902 L
.48358 .30902 L
.48395 .30902 L
.48436 .30902 L
.48474 .30902 L
.48509 .30902 L
.4853 .30902 L
.4855 .30902 L
.48571 .30902 L
.48583 .30902 L
.48594 .30902 L
.48605 .30902 L
.48614 .30902 L
.48624 .30902 L
.48633 .30902 L
.48643 .30902 L
.48653 .30902 L
.48659 .30902 L
Mistroke
.48664 .30902 L
.4867 .30902 L
.48675 .30902 L
.48684 .30902 L
.48694 .30902 L
.48712 .30902 L
.48734 .30902 L
.48753 .30902 L
.48836 .30902 L
.48984 .30902 L
.49059 .30902 L
.49137 .30902 L
.49224 .30902 L
.49266 .30902 L
.49304 .30902 L
.49379 .30902 L
.49419 .30902 L
.4946 .30902 L
.49497 .30902 L
.4953 .30902 L
.49567 .30902 L
.49588 .30902 L
.49607 .30902 L
.49625 .30902 L
.49646 .30902 L
.49656 .30902 L
.49667 .30902 L
.49678 .30902 L
.49687 .30902 L
.49696 .30902 L
.49705 .30902 L
.49715 .30902 L
.49725 .30902 L
.49735 .30902 L
.49744 .30902 L
.49761 .30902 L
.49803 .30902 L
.49841 .30902 L
.49928 .30902 L
.50007 .30902 L
.50092 .30902 L
.50165 .30902 L
.50245 .30902 L
.50288 .30902 L
.50327 .30902 L
.50364 .30902 L
.50405 .30902 L
.50439 .30902 L
.50475 .30902 L
.50514 .30902 L
Mistroke
.5055 .30902 L
.50569 .30902 L
.5059 .30902 L
.50627 .30902 L
.5065 .30902 L
.50671 .30902 L
.5069 .30902 L
.50701 .30902 L
.50711 .30902 L
.50721 .30902 L
.50732 .30902 L
.50741 .30902 L
.5075 .30902 L
.50761 .30902 L
.50767 .30902 L
.50773 .30902 L
.50783 .30902 L
.50794 .30902 L
.50815 .30902 L
.50835 .30902 L
.50881 .30902 L
.51029 .30902 L
.51113 .30902 L
.51191 .30902 L
.51268 .30902 L
.51351 .30902 L
.51397 .30902 L
.5144 .30902 L
.51479 .30902 L
.51521 .30902 L
.5156 .30902 L
.51596 .30902 L
.51637 .30902 L
.51659 .30902 L
.5168 .30902 L
.51701 .30902 L
.51721 .30902 L
.51733 .30902 L
.51743 .30902 L
.51749 .30902 L
.51755 .30902 L
.51761 .30902 L
.51767 .30902 L
.51776 .30902 L
.51786 .30902 L
.51796 .30902 L
.51801 .30902 L
.51807 .30902 L
.51817 .30902 L
.51828 .30902 L
Mistroke
.51849 .30902 L
.51888 .30902 L
.51924 .30902 L
.52008 .30902 L
.5209 .30902 L
.52176 .30902 L
.52254 .30902 L
.52338 .30902 L
.52375 .30902 L
.52415 .30902 L
.52487 .30902 L
.5253 .30902 L
.52569 .30902 L
.52612 .30902 L
.52634 .30902 L
.52658 .30902 L
.52679 .30902 L
.52698 .30902 L
.52721 .30902 L
.52731 .30902 L
.52742 .30902 L
.52752 .30902 L
.52761 .30902 L
.5277 .30902 L
.52779 .30902 L
.52789 .30902 L
.52799 .30902 L
.52809 .30902 L
.52814 .30902 L
.5282 .30902 L
.5283 .30902 L
.5284 .30902 L
.52851 .30902 L
.52862 .30902 L
.52902 .30902 L
.52977 .30902 L
.53145 .30902 L
.5322 .30902 L
.53301 .30902 L
.53378 .30902 L
.53448 .30902 L
.53486 .30902 L
.53527 .30902 L
.53566 .30902 L
.53601 .30902 L
.53642 .30902 L
.53665 .30902 L
.53686 .30902 L
.53706 .30902 L
.53725 .30902 L
Mistroke
.53745 .30902 L
.53756 .30902 L
.53767 .30902 L
.53777 .30902 L
.53788 .30902 L
.53798 .30902 L
.53807 .30902 L
.53812 .30902 L
.53818 .30902 L
.53828 .30902 L
.53834 .30902 L
.53839 .30902 L
.53844 .30902 L
.53851 .30902 L
.53861 .30902 L
.53872 .30902 L
.53892 .30902 L
.5393 .30902 L
.54079 .30902 L
.54235 .30902 L
.54324 .30902 L
.54367 .30902 L
.54407 .30902 L
.54445 .30902 L
.54487 .30902 L
.54525 .30902 L
.54559 .30902 L
.54601 .30902 L
.54622 .30902 L
.54644 .30902 L
.54666 .30902 L
.54685 .30902 L
.54705 .30902 L
.54723 .30902 L
.54741 .30902 L
.54761 .30902 L
.54772 .30902 L
.54782 .30902 L
.54792 .30902 L
.54801 .30902 L
.5481 .30902 L
.54818 .30902 L
.54828 .30902 L
.54837 .30902 L
.54846 .30902 L
.54855 .30902 L
.54865 .30902 L
.54874 .30902 L
.54885 .30902 L
.54896 .30902 L
Mistroke
.54917 .30902 L
.54955 .30902 L
.5504 .30902 L
.55197 .30902 L
.55286 .30902 L
.55329 .30902 L
.55369 .30902 L
.55407 .30902 L
.55449 .30902 L
.55522 .30902 L
.55563 .30902 L
.55607 .30902 L
.55648 .30902 L
.55686 .30902 L
.55704 .30902 L
.55725 .30902 L
.55746 .30902 L
.55766 .30902 L
.55776 .30902 L
.55785 .30902 L
.55802 .30902 L
.55812 .30902 L
.55821 .30902 L
.5583 .30902 L
.5584 .30902 L
.55851 .30902 L
.5586 .30902 L
.55865 .30902 L
.55871 .30902 L
.55882 .30902 L
.55891 .30902 L
.55902 .30902 L
.5592 .30902 L
.55966 .30902 L
.56008 .30902 L
.56175 .30902 L
.56249 .30902 L
.56329 .30902 L
.56367 .30902 L
.56407 .30902 L
.5648 .30902 L
.56522 .30902 L
.56563 .30902 L
.56599 .30902 L
.56639 .30902 L
.56657 .30902 L
.56678 .30902 L
.56714 .30902 L
.56735 .30902 L
.56758 .30902 L
Mistroke
.56777 .30902 L
.56787 .30902 L
.56797 .30902 L
.56808 .30902 L
.56813 .30902 L
.56819 .30902 L
.56824 .30902 L
.5683 .30902 L
.5684 .30902 L
.5685 .30902 L
.5686 .30902 L
.5687 .30902 L
.56879 .30902 L
.5689 .30902 L
.569 .30902 L
.56924 .30902 L
.56966 .30902 L
.57117 .30902 L
.57197 .30902 L
.5728 .30902 L
.57323 .30902 L
.5737 .30902 L
.57453 .30902 L
.57493 .30902 L
.57536 .30902 L
.57577 .30902 L
.57615 .30902 L
.57653 .30902 L
.57673 .30902 L
.57694 .30902 L
.57713 .30902 L
.57732 .30902 L
.57751 .30902 L
.57768 .30902 L
.57778 .30902 L
.57788 .30902 L
.57797 .30902 L
.57807 .30902 L
.57813 .30902 L
.57818 .30902 L
.57823 .30902 L
.57829 .30902 L
.57839 .30902 L
.57849 .30902 L
.57855 .30902 L
.5786 .30902 L
.57871 .30902 L
.57876 .30902 L
.57882 .30902 L
.57893 .30902 L
Mistroke
.57913 .30902 L
.57935 .30902 L
.58093 .30902 L
.58237 .30902 L
.58313 .30902 L
.58393 .30902 L
.58434 .30902 L
.58472 .30902 L
.58515 .30902 L
.5856 .30902 L
.58603 .30902 L
.58642 .30902 L
.58662 .30902 L
.58685 .30902 L
.58709 .30902 L
.58731 .30902 L
.58752 .30902 L
.58762 .30902 L
.58772 .30902 L
.58789 .30902 L
.58799 .30902 L
.58809 .30902 L
.58815 .30902 L
.5882 .30902 L
.58825 .30902 L
.58831 .30902 L
.58842 .30902 L
.58847 .30902 L
.58853 .30902 L
.58863 .30902 L
.58872 .30902 L
.58893 .30902 L
.58931 .30902 L
.58972 .30902 L
.59046 .30902 L
.59126 .30902 L
.59213 .30902 L
.59294 .30902 L
.5933 .30902 L
.59369 .30902 L
.5944 .30902 L
.59479 .30902 L
.59516 .30902 L
.59556 .30902 L
.59578 .30902 L
.596 .30902 L
.5962 .30902 L
.59642 .30902 L
.59662 .30902 L
.5968 .30902 L
Mistroke
.59698 .30902 L
.59717 .30902 L
.59738 .30902 L
.59748 .30902 L
.59757 .30902 L
.59766 .30902 L
.59775 .30902 L
.59785 .30902 L
.59795 .30902 L
.59803 .30902 L
.59813 .30902 L
.59821 .30902 L
.59829 .30902 L
.5984 .30902 L
.59849 .30902 L
.5986 .30902 L
.59871 .30902 L
.59911 .30902 L
.59986 .30902 L
.60067 .30902 L
.60154 .30902 L
.60236 .30902 L
.60311 .30902 L
.60347 .30902 L
.60386 .30902 L
.60421 .30902 L
.60458 .30902 L
.605 .30902 L
.6054 .30902 L
.6058 .30902 L
.60616 .30902 L
.60636 .30902 L
.60655 .30902 L
.60675 .30902 L
.60697 .30902 L
.60708 .30902 L
.60721 .30902 L
.60731 .30902 L
.60743 .30902 L
.60753 .30902 L
.60758 .30902 L
.60764 .30902 L
.60774 .30902 L
.60784 .30902 L
.60794 .30902 L
.60803 .30902 L
.60814 .30902 L
.60824 .30902 L
.60833 .30902 L
.60841 .30902 L
Mistroke
.60861 .30902 L
.60901 .30902 L
.60945 .30902 L
.61026 .30902 L
.61114 .30902 L
.61196 .30902 L
.61271 .30902 L
.61307 .30902 L
.61346 .30902 L
.61381 .30902 L
.61418 .30902 L
.61461 .30902 L
.61501 .30902 L
.6154 .30902 L
.61576 .30902 L
.61596 .30902 L
.61615 .30902 L
.61637 .30902 L
.61658 .30902 L
.61679 .30902 L
.617 .30902 L
.61711 .30902 L
.61721 .30902 L
.61732 .30902 L
.61738 .30902 L
.61744 .30902 L
.61754 .30902 L
.61763 .30902 L
.61773 .30902 L
.61779 .30902 L
.61784 .30902 L
.61794 .30902 L
.618 .30902 L
.61805 .30902 L
.61826 .30902 L
.61862 .30902 L
.619 .30902 L
.61981 .30902 L
.62067 .30902 L
.6215 .30902 L
.62225 .30902 L
.62261 .30902 L
.623 .30902 L
.62372 .30902 L
.62411 .30902 L
.62447 .30902 L
.62487 .30902 L
.62508 .30902 L
.6253 .30902 L
.62573 .30902 L
Mistroke
.62596 .30902 L
.62618 .30902 L
.62638 .30902 L
.62657 .30902 L
.62667 .30902 L
.62678 .30902 L
.62689 .30902 L
.62699 .30902 L
.62709 .30902 L
.62718 .30902 L
.62727 .30902 L
.62736 .30902 L
.62746 .30902 L
.62752 .30902 L
.62757 .30902 L
.62767 .30902 L
.62776 .30902 L
.62811 .30902 L
.62849 .30902 L
.62928 .30902 L
.63015 .30902 L
.63092 .30902 L
.63175 .30902 L
.6322 .30902 L
.63262 .30902 L
.63302 .30902 L
.63344 .30902 L
.63382 .30902 L
.63423 .30902 L
.63461 .30902 L
.63497 .30902 L
.63517 .30902 L
.63539 .30902 L
.63557 .30902 L
.63577 .30902 L
.63598 .30902 L
.63618 .30902 L
.63631 .30902 L
.63642 .30902 L
.63652 .30902 L
.63658 .30902 L
.63664 .30902 L
.63673 .30902 L
.63682 .30902 L
.63692 .30902 L
.63703 .30902 L
.63712 .30902 L
.63722 .30902 L
.63731 .30902 L
.6374 .30902 L
Mistroke
.6376 .30902 L
.63783 .30902 L
.63823 .30902 L
.63904 .30902 L
.63992 .30902 L
.64075 .30902 L
.64152 .30902 L
.64195 .30902 L
.64234 .30902 L
.64279 .30902 L
.64322 .30902 L
.64358 .30902 L
.64399 .30902 L
.6442 .30902 L
.64442 .30902 L
.64461 .30902 L
.64482 .30902 L
.645 .30902 L
.64519 .30902 L
.6454 .30902 L
.64559 .30902 L
.64578 .30902 L
.64587 .30902 L
.64596 .30902 L
.64604 .30902 L
.64612 .30902 L
.64621 .30902 L
.6463 .30902 L
.6464 .30902 L
.6465 .30902 L
.6466 .30902 L
.64666 .30902 L
.64672 .30902 L
.64681 .30902 L
.64692 .30902 L
.64711 .30902 L
.6475 .30902 L
.64786 .30902 L
.64873 .30902 L
.64954 .30902 L
.65027 .30902 L
.65106 .30902 L
.6515 .30902 L
.65193 .30902 L
.6523 .30902 L
.65272 .30902 L
.65311 .30902 L
.65348 .30902 L
.65388 .30902 L
.6541 .30902 L
Mistroke
.65431 .30902 L
.65451 .30902 L
.65472 .30902 L
.65496 .30902 L
.65518 .30902 L
.65528 .30902 L
.6554 .30902 L
.65551 .30902 L
.65561 .30902 L
.6557 .30902 L
.6558 .30902 L
.6559 .30902 L
.656 .30902 L
.6561 .30902 L
.65615 .30902 L
.65621 .30902 L
.65631 .30902 L
.6564 .30902 L
.65661 .30902 L
.65684 .30902 L
.65763 .30902 L
.65912 .30902 L
.65989 .30902 L
.66033 .30902 L
.66073 .30902 L
.66115 .30902 L
.66155 .30902 L
.66201 .30902 L
.66243 .30902 L
.6628 .30902 L
.66321 .30902 L
.66341 .30902 L
.66364 .30902 L
.66383 .30902 L
.66403 .30902 L
.66424 .30902 L
.66443 .30902 L
.66461 .30902 L
.66471 .30902 L
.66481 .30902 L
.66491 .30902 L
.665 .30902 L
.66509 .30902 L
.66518 .30902 L
.66526 .30902 L
.66534 .30902 L
.66543 .30902 L
.66552 .30902 L
.66561 .30902 L
.66567 .30902 L
Mistroke
.66572 .30902 L
.66583 .30902 L
.66594 .30902 L
.66634 .30902 L
.66723 .30902 L
.66806 .30902 L
.66884 .30902 L
.66965 .30902 L
.67008 .30902 L
.67054 .30902 L
.67097 .30902 L
.67138 .30902 L
.67175 .30902 L
.67215 .30902 L
.67254 .30902 L
.67291 .30902 L
.67312 .30902 L
.67332 .30902 L
.67354 .30902 L
.67375 .30902 L
.67395 .30902 L
.67407 .30902 L
.67417 .30902 L
.67427 .30902 L
.67436 .30902 L
.67445 .30902 L
.67456 .30902 L
.67467 .30902 L
.67476 .30902 L
.67482 .30902 L
.67487 .30902 L
.67493 .30902 L
.67499 .30902 L
.67504 .30902 L
.6751 .30902 L
.67521 .30902 L
.67544 .30902 L
.67584 .30902 L
.6762 .30902 L
.67701 .30902 L
.67772 .30902 L
.67848 .30902 L
.6789 .30902 L
.67927 .30902 L
.68001 .30902 L
.68042 .30902 L
.68086 .30902 L
.68129 .30902 L
.68167 .30902 L
.68205 .30902 L
Mistroke
.68226 .30902 L
.68245 .30902 L
.68263 .30902 L
.68283 .30902 L
.68301 .30902 L
.68318 .30902 L
.68338 .30902 L
.68349 .30902 L
.6836 .30902 L
.68372 .30902 L
.68378 .30902 L
.68384 .30902 L
.68394 .30902 L
.68399 .30902 L
.68405 .30902 L
.68415 .30902 L
.68421 .30902 L
.68426 .30902 L
.68436 .30902 L
.68447 .30902 L
.68456 .30902 L
.68465 .30902 L
.68484 .30902 L
.68634 .30902 L
.68713 .30902 L
.68796 .30902 L
.68838 .30902 L
.68885 .30902 L
.68927 .30902 L
.68967 .30902 L
.69007 .30902 L
.69044 .30902 L
.69085 .30902 L
.69106 .30902 L
.69128 .30902 L
.69148 .30902 L
.6917 .30902 L
.6919 .30902 L
.6921 .30902 L
.69229 .30902 L
.69249 .30902 L
.69268 .30902 L
.69285 .30902 L
.69296 .30902 L
.69307 .30902 L
.69312 .30902 L
.69318 .30902 L
.69327 .30902 L
.69338 .30902 L
.69348 .30902 L
Mistroke
.69357 .30902 L
.69366 .30902 L
.69377 .30902 L
.69388 .30902 L
.69412 .30902 L
.69453 .30902 L
.6954 .30902 L
.69623 .30902 L
.69697 .30902 L
.69736 .30902 L
.69778 .30902 L
.69816 .30902 L
.69857 .30902 L
.699 .30902 L
.6994 .30902 L
.69978 .30902 L
.70018 .30902 L
.70053 .30902 L
.7009 .30902 L
.70111 .30902 L
.70133 .30902 L
.70153 .30902 L
.70173 .30902 L
.7019 .30902 L
.70209 .30902 L
.70219 .30902 L
.70229 .30902 L
.70239 .30902 L
.70248 .30902 L
.70258 .30902 L
.70264 .30902 L
.70269 .30902 L
.70279 .30902 L
.70289 .30902 L
.70294 .30902 L
.703 .30902 L
.70311 .30902 L
.70334 .30902 L
.70373 .30902 L
.70416 .30902 L
.70503 .30902 L
.70586 .30902 L
.7066 .30902 L
.70702 .30902 L
.70741 .30902 L
.70776 .30902 L
.70813 .30902 L
.70854 .30902 L
.70893 .30902 L
.70913 .30902 L
Mistroke
.70936 .30902 L
.70955 .30902 L
.70977 .30902 L
.70998 .30902 L
.71017 .30902 L
.71054 .30902 L
.71072 .30902 L
.71093 .30902 L
.71103 .30902 L
.71114 .30902 L
.71124 .30902 L
.71134 .30902 L
.71144 .30902 L
.71154 .30902 L
.71163 .30902 L
.71173 .30902 L
.71181 .30902 L
.71189 .30902 L
.71198 .30902 L
.71208 .30902 L
.71218 .30902 L
.71228 .30902 L
.7125 .30902 L
.71295 .30902 L
.71375 .30902 L
.71459 .30902 L
.71539 .30902 L
.71611 .30902 L
.71651 .30902 L
.71688 .30902 L
.71726 .30902 L
.71766 .30902 L
.71804 .30902 L
.71839 .30902 L
.71879 .30902 L
.71902 .30902 L
.71924 .30902 L
.71944 .30902 L
.71963 .30902 L
.71985 .30902 L
.72004 .30902 L
.72024 .30902 L
.72042 .30902 L
.72052 .30902 L
.72062 .30902 L
.72067 .30902 L
.72072 .30902 L
.72083 .30902 L
.72093 .30902 L
.72098 .30902 L
Mistroke
.72104 .30902 L
.72109 .30902 L
.72114 .30902 L
.7212 .30902 L
.72126 .30902 L
.72136 .30902 L
.72145 .30902 L
.72166 .30902 L
.72237 .30902 L
.72314 .30902 L
.72396 .30902 L
.7244 .30902 L
.72486 .30902 L
.72526 .30902 L
.7257 .30902 L
.7261 .30902 L
.72647 .30902 L
.72687 .30902 L
.72708 .30902 L
.72731 .30902 L
.72753 .30902 L
.72772 .30902 L
.72792 .30902 L
.7281 .30902 L
.72847 .30902 L
.72867 .30902 L
.72887 .30902 L
.72905 .30902 L
.72921 .30902 L
.7294 .30902 L
.7295 .30902 L
.72959 .30902 L
.72968 .30902 L
.72978 .30902 L
.72988 .30902 L
.72998 .30902 L
.73003 .30902 L
.73009 .30902 L
.73019 .30902 L
.7303 .30902 L
.73039 .30902 L
.73049 .30902 L
.73058 .30902 L
.73075 .30902 L
.73113 .30902 L
.73194 .30902 L
.7328 .30902 L
.73356 .30902 L
.734 .30902 L
.73441 .30902 L
Mistroke
.73478 .30902 L
.73512 .30902 L
.73552 .30902 L
.73589 .30902 L
.73626 .30902 L
.73667 .30902 L
.73687 .30902 L
.73709 .30902 L
.73728 .30902 L
.73749 .30902 L
.73767 .30902 L
.73786 .30902 L
.73807 .30902 L
.73826 .30902 L
.73835 .30902 L
.73845 .30902 L
.73854 .30902 L
.73863 .30902 L
.73871 .30902 L
.73881 .30902 L
.73889 .30902 L
.73897 .30902 L
.73907 .30902 L
.73912 .30902 L
.73917 .30902 L
.73927 .30902 L
.73937 .30902 L
.73942 .30902 L
.73948 .30902 L
.73958 .30902 L
.7398 .30902 L
.74018 .30902 L
.7406 .30902 L
.74136 .30902 L
.74208 .30902 L
.74248 .30902 L
.7429 .30902 L
.74326 .30902 L
.74365 .30902 L
.74408 .30902 L
.74452 .30902 L
.74494 .30902 L
.74533 .30902 L
.74571 .30902 L
.74592 .30902 L
.74612 .30902 L
.74633 .30902 L
.74653 .30902 L
.74675 .30902 L
.74695 .30902 L
Mistroke
.74714 .30902 L
.74733 .30902 L
.74749 .30902 L
.74767 .30902 L
.74777 .30902 L
.74786 .30902 L
.74797 .30902 L
.74807 .30902 L
.74816 .30902 L
.74825 .30902 L
.74834 .30902 L
.74844 .30902 L
.74853 .30902 L
.74863 .30902 L
.74883 .30902 L
.74919 .30902 L
.75 .30902 L
.75076 .30902 L
.75147 .30902 L
.75186 .30902 L
.75229 .30902 L
.75265 .30902 L
.75304 .30902 L
.75346 .30902 L
.75391 .30902 L
.75433 .30902 L
.75472 .30902 L
.75493 .30902 L
.75512 .30902 L
.75535 .30902 L
.75555 .30902 L
.75575 .30902 L
.75594 .30902 L
.75613 .30902 L
.75624 .30902 L
.75635 .30902 L
.75653 .30902 L
.75662 .30902 L
.75672 .30902 L
.75678 .30902 L
.75683 .30902 L
.75693 .30902 L
.75703 .30902 L
.75712 .30902 L
.75721 .30902 L
.75729 .30902 L
.75737 .30902 L
.75747 .30902 L
.75766 .30902 L
.75783 .30902 L
Mistroke
.75863 .30902 L
.75948 .30902 L
.76029 .30902 L
.76102 .30902 L
.76141 .30902 L
.76177 .30902 L
.76217 .30902 L
.76259 .30902 L
.76296 .30902 L
.7633 .30902 L
.76367 .30902 L
.76388 .30902 L
.76408 .30902 L
.76427 .30902 L
.76446 .30902 L
.76468 .30902 L
.76487 .30902 L
.76505 .30902 L
.76522 .30902 L
.76541 .30902 L
.7655 .30902 L
.7656 .30902 L
.76566 .30902 L
.76572 .30902 L
.76582 .30902 L
.76593 .30902 L
.76602 .30902 L
.76612 .30902 L
.76618 .30902 L
.76624 .30902 L
.76629 .30902 L
.76635 .30902 L
.76647 .30902 L
.76666 .30902 L
.76688 .30902 L
.76727 .30902 L
.76815 .30902 L
.76898 .30902 L
.76972 .30902 L
.77014 .30902 L
.77053 .30902 L
.77091 .30902 L
.77126 .30902 L
.77164 .30902 L
.77206 .30902 L
.77226 .30902 L
.77249 .30902 L
.77269 .30902 L
.7729 .30902 L
.77309 .30902 L
Mistroke
.7733 .30902 L
.77349 .30902 L
.77367 .30902 L
.77386 .30902 L
.77397 .30902 L
.77406 .30902 L
.77426 .30902 L
.77438 .30902 L
.77448 .30902 L
.77457 .30902 L
.77466 .30902 L
.77475 .30902 L
.77484 .30902 L
.77493 .30902 L
.77504 .30902 L
.77513 .30902 L
.77522 .30902 L
.77533 .30902 L
.77544 .30902 L
.77563 .30902 L
.77608 .30902 L
.7769 .30902 L
.77772 .30902 L
.77819 .30902 L
.77862 .30902 L
.77902 .30902 L
.7794 .30902 L
.7798 .30902 L
.78024 .30902 L
.78064 .30902 L
.78085 .30902 L
.78108 .30902 L
.78127 .30902 L
.78149 .30902 L
.78169 .30902 L
.78187 .30902 L
.78224 .30902 L
.78244 .30902 L
.78264 .30902 L
.78282 .30902 L
.78299 .30902 L
.78317 .30902 L
.78327 .30902 L
.78336 .30902 L
.78346 .30902 L
.78355 .30902 L
.78365 .30902 L
.78375 .30902 L
.78381 .30902 L
.78386 .30902 L
Mistroke
.78397 .30902 L
.78407 .30902 L
.78417 .30902 L
.78452 .30902 L
.7849 .30902 L
.78571 .30902 L
.78613 .30902 L
.78657 .30902 L
.78696 .30902 L
.78739 .30902 L
.78778 .30902 L
.78813 .30902 L
.7885 .30902 L
.78889 .30902 L
.78926 .30902 L
.7896 .30902 L
.78997 .30902 L
.79018 .30902 L
.79038 .30902 L
.79058 .30902 L
.79078 .30902 L
.791 .30902 L
.7912 .30902 L
.79138 .30902 L
.79157 .30902 L
.79175 .30902 L
.79191 .30902 L
.79201 .30902 L
.7921 .30902 L
.7922 .30902 L
.79225 .30902 L
.79231 .30902 L
.7924 .30902 L
.7925 .30902 L
.7926 .30902 L
.79268 .30902 L
.79278 .30902 L
.79287 .30902 L
.79307 .30902 L
.79348 .30902 L
.79422 .30902 L
.79503 .30902 L
.79547 .30902 L
.79588 .30902 L
.79629 .30902 L
.79666 .30902 L
.79707 .30902 L
.7975 .30902 L
.79787 .30902 L
.79827 .30902 L
Mistroke
.79864 .30902 L
.79899 .30902 L
.79918 .30902 L
.79936 .30902 L
.79956 .30902 L
.79977 .30902 L
.79996 .30902 L
.80014 .30902 L
.80031 .30902 L
.8005 .30902 L
.80061 .30902 L
.80071 .30902 L
.80082 .30902 L
.80088 .30902 L
.80094 .30902 L
.80105 .30902 L
.80114 .30902 L
.8012 .30902 L
.80126 .30902 L
.80136 .30902 L
.80146 .30902 L
.80156 .30902 L
.80165 .30902 L
.80174 .30902 L
.80215 .30902 L
.80297 .30902 L
.80384 .30902 L
.80458 .30902 L
.805 .30902 L
.80538 .30902 L
.80579 .30902 L
.80617 .30902 L
.80652 .30902 L
.80689 .30902 L
.80729 .30902 L
.8075 .30902 L
.80772 .30902 L
.80792 .30902 L
.80812 .30902 L
.8083 .30902 L
.80849 .30902 L
.8087 .30902 L
.80892 .30902 L
.80901 .30902 L
.80912 .30902 L
.80931 .30902 L
.80942 .30902 L
.80953 .30902 L
.80959 .30902 L
.80966 .30902 L
Mistroke
.80971 .30902 L
.80977 .30902 L
.80983 .30902 L
.80989 .30902 L
.80994 .30902 L
.80999 .30902 L
.81009 .30902 L
.8102 .30902 L
.81025 .30902 L
.8103 .30902 L
.81041 .30902 L
.8106 .30902 L
.81103 .30902 L
.81181 .30902 L
.81263 .30902 L
.81339 .30902 L
.81382 .30902 L
.81427 .30902 L
.81469 .30902 L
.81508 .30902 L
.81545 .30902 L
.81566 .30902 L
.81586 .30902 L
.81604 .30902 L
.81624 .30902 L
.81659 .30902 L
.81679 .30902 L
.81701 .30902 L
.81723 .30902 L
.81745 .30902 L
.81765 .30902 L
.81783 .30902 L
.81793 .30902 L
.81803 .30902 L
.81814 .30902 L
.81825 .30902 L
.81835 .30902 L
.8184 .30902 L
.81846 .30902 L
.81856 .30902 L
.81865 .30902 L
.81871 .30902 L
.81876 .30902 L
.81886 .30902 L
.81892 .30902 L
.81897 .30902 L
.81909 .30902 L
.81948 .30902 L
.81989 .30902 L
.82067 .30902 L
Mistroke
.82138 .30902 L
.82179 .30902 L
.82221 .30902 L
.82264 .30902 L
.82311 .30902 L
.82351 .30902 L
.82373 .30902 L
.82395 .30902 L
.82414 .30902 L
.82435 .30902 L
.82473 .30902 L
.82492 .30902 L
.82512 .30902 L
.82548 .30902 L
.82571 .30902 L
.82592 .30902 L
.82611 .30902 L
.82632 .30902 L
.82643 .30902 L
.82654 .30902 L
.82664 .30902 L
.82674 .30902 L
.82685 .30902 L
.82696 .30902 L
.82702 .30902 L
.82707 .30902 L
.82713 .30902 L
.82719 .30902 L
.8273 .30902 L
.82736 .30902 L
.82741 .30902 L
.82751 .30902 L
.82756 .30902 L
.82762 .30902 L
.82782 .30902 L
.82801 .30902 L
.82949 .30902 L
.8299 .30902 L
.83033 .30902 L
.8307 .30902 L
.83111 .30902 L
.83154 .30902 L
.83195 .30902 L
.83235 .30902 L
.83272 .30902 L
.83311 .30902 L
.83333 .30902 L
.83354 .30902 L
.83376 .30902 L
.83396 .30902 L
Mistroke
.8342 .30902 L
.83441 .30902 L
.83462 .30902 L
.83482 .30902 L
.83499 .30902 L
.83518 .30902 L
.83528 .30902 L
.83539 .30902 L
.83545 .30902 L
.83551 .30902 L
.83561 .30902 L
.83572 .30902 L
.83582 .30902 L
.83591 .30902 L
.836 .30902 L
.8361 .30902 L
.83618 .30902 L
.83638 .30902 L
.83677 .30902 L
.83748 .30902 L
.83827 .30902 L
.8387 .30902 L
.8391 .30902 L
.83948 .30902 L
.83981 .30902 L
.84019 .30902 L
.84059 .30902 L
.84098 .30902 L
.84139 .30902 L
.84175 .30902 L
.84195 .30902 L
.84213 .30902 L
.84235 .30902 L
.84255 .30902 L
.84274 .30902 L
.84294 .30902 L
.84315 .30902 L
.84335 .30902 L
.84357 .30902 L
.84369 .30902 L
.8438 .30902 L
.8439 .30902 L
.844 .30902 L
.84409 .30902 L
.84418 .30902 L
.84428 .30902 L
.84434 .30902 L
.84439 .30902 L
.84449 .30902 L
.84459 .30902 L
Mistroke
.84469 .30902 L
.84479 .30902 L
.84499 .30902 L
.84542 .30902 L
.84619 .30902 L
.84691 .30902 L
.84733 .30902 L
.84772 .30902 L
.84815 .30902 L
.8486 .30902 L
.849 .30902 L
.84921 .30902 L
.84943 .30902 L
.84963 .30902 L
.84984 .30902 L
.85022 .30902 L
.85042 .30902 L
.85064 .30902 L
.85083 .30902 L
.85103 .30902 L
.85122 .30902 L
.85142 .30902 L
.85161 .30902 L
.85178 .30902 L
.85199 .30902 L
.85209 .30902 L
.8522 .30902 L
.8523 .30902 L
.8524 .30902 L
.8525 .30902 L
.85259 .30902 L
.85264 .30902 L
.8527 .30902 L
.85281 .30902 L
.85286 .30902 L
.85292 .30902 L
.85297 .30902 L
.85304 .30902 L
.85309 .30902 L
.85315 .30902 L
.85326 .30902 L
.85346 .30902 L
.85434 .30902 L
.85518 .30902 L
.85592 .30902 L
.85634 .30902 L
.85673 .30902 L
.85711 .30902 L
.85746 .30902 L
.85785 .30902 L
Mistroke
.85826 .30902 L
.85847 .30902 L
.85869 .30902 L
.85889 .30902 L
.85911 .30902 L
.8593 .30902 L
.85951 .30902 L
.8597 .30902 L
.85987 .30902 L
.86007 .30902 L
.86029 .30902 L
.86048 .30902 L
.86059 .30902 L
.86069 .30902 L
.86078 .30902 L
.86087 .30902 L
.86097 .30902 L
.86107 .30902 L
.86116 .30902 L
.86124 .30902 L
.86133 .30902 L
.86143 .30902 L
.86149 .30902 L
.86154 .30902 L
.86165 .30902 L
.86176 .30902 L
.86188 .30902 L
.86231 .30902 L
.86311 .30902 L
.86386 .30902 L
.86424 .30902 L
.86466 .30902 L
.86511 .30902 L
.86553 .30902 L
.86592 .30902 L
.86633 .30902 L
.86654 .30902 L
.86676 .30902 L
.86715 .30902 L
.86737 .30902 L
.86758 .30902 L
.8678 .30902 L
.86804 .30902 L
.86825 .30902 L
.86848 .30902 L
.86869 .30902 L
.86879 .30902 L
.86889 .30902 L
.86898 .30902 L
.86909 .30902 L
Mistroke
.86917 .30902 L
.86926 .30902 L
.86936 .30902 L
.86942 .30902 L
.86947 .30902 L
.86957 .30902 L
.86966 .30902 L
.86976 .30902 L
.86982 .30902 L
.86987 .30902 L
.86997 .30902 L
.87003 .30902 L
.87009 .30902 L
.87028 .30902 L
.87048 .30902 L
.87137 .30902 L
.87215 .30902 L
.87259 .30902 L
.87298 .30902 L
.87338 .30902 L
.8738 .30902 L
.8742 .30902 L
.87457 .30902 L
.87491 .30902 L
.87529 .30902 L
.87548 .30902 L
.87568 .30902 L
.87605 .30902 L
.87625 .30902 L
.87647 .30902 L
.87667 .30902 L
.87686 .30902 L
.87708 .30902 L
.8772 .30902 L
.87732 .30902 L
.87743 .30902 L
.87753 .30902 L
.87763 .30902 L
.87775 .30902 L
.87785 .30902 L
.8779 .30902 L
.87796 .30902 L
.87805 .30902 L
.87816 .30902 L
.87825 .30902 L
.87833 .30902 L
.87843 .30902 L
.87853 .30902 L
.87875 .30902 L
.87896 .30902 L
Mistroke
.87936 .30902 L
.88013 .30902 L
.88055 .30902 L
.88095 .30902 L
.88132 .30902 L
.88172 .30902 L
.88209 .30902 L
.88243 .30902 L
.8828 .30902 L
.88301 .30902 L
.88321 .30902 L
.88359 .30902 L
.88394 .30902 L
.88414 .30902 L
.88435 .30902 L
.88453 .30902 L
.88473 .30902 L
.88494 .30902 L
.88514 .30902 L
.88526 .30902 L
.88538 .30902 L
.88548 .30902 L
.8856 .30902 L
.8857 .30902 L
.8858 .30902 L
.8859 .30902 L
.886 .30902 L
.88609 .30902 L
.88617 .30902 L
.88627 .30902 L
.88636 .30902 L
.88647 .30902 L
.88653 .30902 L
.88658 .30902 L
.88668 .30902 L
.88674 .30902 L
.88679 .30902 L
.88699 .30902 L
.88718 .30902 L
.88865 .30902 L
.88944 .30902 L
.88984 .30902 L
.89027 .30902 L
.89064 .30902 L
.89104 .30902 L
.89141 .30902 L
.89175 .30902 L
.89214 .30902 L
.89234 .30902 L
.89255 .30902 L
Mistroke
.89273 .30902 L
.89293 .30902 L
.89312 .30902 L
.89329 .30902 L
.89349 .30902 L
.89361 .30902 L
.89371 .30902 L
.89393 .30902 L
.89405 .30902 L
.89416 .30902 L
.89426 .30902 L
.89436 .30902 L
.89445 .30902 L
.89454 .30902 L
.89464 .30902 L
.8947 .30902 L
.89476 .30902 L
.89486 .30902 L
.89496 .30902 L
.89505 .30902 L
.89515 .30902 L
.89532 .30902 L
.89573 .30902 L
.89655 .30902 L
.89693 .30902 L
.89732 .30902 L
.89803 .30902 L
.89843 .30902 L
.89879 .30902 L
.89922 .30902 L
.89961 .30902 L
.89998 .30902 L
.90032 .30902 L
.9005 .30902 L
.90069 .30902 L
.90109 .30902 L
.90129 .30902 L
.9015 .30902 L
.90171 .30902 L
.9019 .30902 L
.90209 .30902 L
.90226 .30902 L
.90236 .30902 L
.90246 .30902 L
.90255 .30902 L
.90265 .30902 L
.90275 .30902 L
.90285 .30902 L
.90291 .30902 L
.90296 .30902 L
Mistroke
.90307 .30902 L
.90312 .30902 L
.90318 .30902 L
.90328 .30902 L
.90334 .30902 L
.9034 .30902 L
.90352 .30902 L
.9039 .30902 L
.90432 .30902 L
.90516 .30902 L
.90593 .30902 L
.90632 .30902 L
.90674 .30902 L
.9072 .30902 L
.90763 .30902 L
.90801 .30902 L
.90821 .30902 L
.90843 .30902 L
.90861 .30902 L
.90881 .30902 L
.90917 .30902 L
.90938 .30902 L
.90961 .30902 L
.90983 .30902 L
.91004 .30902 L
.91024 .30902 L
.91043 .30902 L
.91053 .30902 L
.91064 .30902 L
.91074 .30902 L
.91084 .30902 L
.91093 .30902 L
.91103 .30902 L
.91113 .30902 L
.91118 .30902 L
.91123 .30902 L
.91132 .30902 L
.91141 .30902 L
.91151 .30902 L
.9116 .30902 L
.91171 .30902 L
.91181 .30902 L
.91201 .30902 L
.91244 .30902 L
.91326 .30902 L
.91371 .30902 L
.91413 .30902 L
.91453 .30902 L
.91497 .30902 L
.91536 .30902 L
Mistroke
.91572 .30902 L
.91606 .30902 L
.91644 .30902 L
.91663 .30902 L
.91683 .30902 L
.9172 .30902 L
.9174 .30902 L
.91762 .30902 L
.91781 .30902 L
.91801 .30902 L
.91823 .30902 L
.91835 .30902 L
.91847 .30902 L
.91858 .30902 L
.9187 .30902 L
.91879 .30902 L
.9189 .30902 L
.91901 .30902 L
.91911 .30902 L
.91921 .30902 L
.91931 .30902 L
.91941 .30902 L
.91946 .30902 L
.91952 .30902 L
.91957 .30902 L
.91962 .30902 L
.91968 .30902 L
.91974 .30902 L
.91983 .30902 L
.91993 .30902 L
.92011 .30902 L
.92052 .30902 L
.92134 .30902 L
.92178 .30902 L
.92224 .30902 L
.92264 .30902 L
.92308 .30902 L
.92348 .30902 L
.92386 .30902 L
.92426 .30902 L
.92449 .30902 L
.9247 .30902 L
.92508 .30902 L
.92528 .30902 L
.92549 .30902 L
.92567 .30902 L
.92586 .30902 L
.92607 .30902 L
.92626 .30902 L
.92644 .30902 L
Mistroke
.92661 .30902 L
.92679 .30902 L
.92698 .30902 L
.92708 .30902 L
.92719 .30902 L
.92731 .30902 L
.92736 .30902 L
.92741 .30902 L
.92751 .30902 L
.9276 .30902 L
.9277 .30902 L
.92776 .30902 L
.92781 .30902 L
.92791 .30902 L
.92801 .30902 L
.92812 .30902 L
.92824 .30902 L
.9287 .30902 L
.92947 .30902 L
.92988 .30902 L
.93032 .30902 L
.93075 .30902 L
.93115 .30902 L
.93155 .30902 L
.93192 .30902 L
.93213 .30902 L
.93235 .30902 L
.93274 .30902 L
.93295 .30902 L
.93315 .30902 L
.93339 .30902 L
.93362 .30902 L
.93381 .30902 L
.93401 .30902 L
.93424 .30902 L
.93445 .30902 L
.93465 .30902 L
.93475 .30902 L
.93486 .30902 L
.93495 .30902 L
.93506 .30902 L
.93524 .30902 L
.93534 .30902 L
.93544 .30902 L
.93552 .30902 L
.93561 .30902 L
.93571 .30902 L
.93576 .30902 L
.93582 .30902 L
.93592 .30902 L
Mistroke
.93601 .30902 L
.9361 .30902 L
.93619 .30902 L
.93636 .30902 L
.93673 .30902 L
.93755 .30902 L
.93796 .30902 L
.93833 .30902 L
.93866 .30902 L
.93903 .30902 L
.9394 .30902 L
.93979 .30902 L
.94018 .30902 L
.9404 .30902 L
.9406 .30902 L
.94079 .30902 L
.94099 .30902 L
.94136 .30902 L
.94158 .30902 L
.94179 .30902 L
.94202 .30902 L
.94224 .30902 L
.94244 .30902 L
.94262 .30902 L
.94283 .30902 L
.94293 .30902 L
.94304 .30902 L
.94315 .30902 L
.94325 .30902 L
.94334 .30902 L
.94344 .30902 L
.94354 .30902 L
.94362 .30902 L
.94371 .30902 L
.94381 .30902 L
.94391 .30902 L
.94397 .30902 L
.94403 .30902 L
.94413 .30902 L
.94418 .30902 L
.94423 .30902 L
.94443 .30902 L
.94462 .30902 L
.94533 .30902 L
.9461 .30902 L
.9465 .30902 L
.94688 .30902 L
.94728 .30902 L
.94771 .30902 L
.94811 .30902 L
Mistroke
.94848 .30902 L
.94882 .30902 L
.94919 .30902 L
.94938 .30902 L
.94958 .30902 L
.94994 .30902 L
.95015 .30902 L
.95038 .30902 L
.95057 .30902 L
.95078 .30902 L
.95089 .30902 L
.951 .30902 L
.9512 .30902 L
.95131 .30902 L
.95141 .30902 L
.95153 .30902 L
.95159 .30902 L
.95165 .30902 L
.95174 .30902 L
.95185 .30902 L
.95194 .30902 L
.95204 .30902 L
.95214 .30902 L
.95224 .30902 L
.9523 .30902 L
.95235 .30902 L
.95246 .30902 L
.95328 .30902 L
.95372 .30902 L
.95414 .30902 L
.95452 .30902 L
.95487 .30902 L
.95526 .30902 L
.95568 .30902 L
.95608 .30902 L
.95644 .30902 L
.95684 .30902 L
.95705 .30902 L
.95727 .30902 L
.95764 .30902 L
.95785 .30902 L
.95805 .30902 L
.95823 .30902 L
.9584 .30902 L
.95858 .30902 L
.95878 .30902 L
.95899 .30902 L
.95918 .30902 L
.95928 .30902 L
.9594 .30902 L
Mistroke
.95951 .30902 L
.95962 .30902 L
.95972 .30902 L
.95982 .30902 L
.95991 .30902 L
.96001 .30902 L
.96011 .30902 L
.96017 .30902 L
.96022 .30902 L
.96032 .30902 L
.96042 .30902 L
.9606 .30902 L
.96079 .30902 L
.96114 .30902 L
.96191 .30902 L
.96268 .30902 L
.9631 .30902 L
.96349 .30902 L
.96386 .30902 L
.96425 .30902 L
.96462 .30902 L
.96497 .30902 L
.96516 .30902 L
.96534 .30902 L
.96553 .30902 L
.96574 .30902 L
.96594 .30902 L
.96611 .30902 L
.96628 .30902 L
.96647 .30902 L
.96669 .30902 L
.96689 .30902 L
.96709 .30902 L
.96727 .30902 L
.96737 .30902 L
.96747 .30902 L
.96757 .30902 L
.96769 .30902 L
.96774 .30902 L
.9678 .30902 L
.96786 .30902 L
.96791 .30902 L
.96802 .30902 L
.96807 .30902 L
.96812 .30902 L
.96822 .30902 L
.96831 .30902 L
.96841 .30902 L
.96852 .30902 L
.96893 .30902 L
Mistroke
.96968 .30902 L
.97013 .30902 L
.97055 .30902 L
.97094 .30902 L
.97135 .30902 L
.97174 .30902 L
.97211 .30902 L
.97251 .30902 L
.97274 .30902 L
.97295 .30902 L
.97315 .30902 L
.97336 .30902 L
.97359 .30902 L
.97381 .30902 L
.97403 .30902 L
.97424 .30902 L
.97443 .30902 L
.97463 .30902 L
.97482 .30902 L
.975 .30902 L
.97519 .30902 L
.97529 .30902 L
.97539 .30902 L
.97549 .30902 L
.97559 .30902 L
.97564 .30902 L
.9757 .30902 L
.9758 .30902 L
.9759 .30902 L
.976 .30902 L
.9761 .30902 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{421.375, 260.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008>0001AB000`400?l00000o`00003ooooooooo
oooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo
003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooo
oooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool0
0?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooooooo
ool@ooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooo
ooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0oooo
ooo=ooooo`00<?ooool3o`0000cooooo00?o0000ooooooooool0ooooooo=ooooo`00<?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo0?oooooocOooool0033ooooo00?o0000oooooooo
ool02oooool2o`000?oooooocoooool0033ooooo00?o0000ooooooooool02oooool2o`000?oooooo
coooool0033ooooo00?o0000ooooooooool02oooool2o`000?oooooocoooool0033ooooo00?o0000
ooooooooool02oooool2o`000?oooooocoooool0033ooooo00?o0000ooooooooool02oooool2o`00
0?oooooocoooool0033ooooo00?o0000ooooooooool02oooool2o`000?oooooocoooool0033ooooo
00?o0000ooooooooool02oooool00ol0003oooooo`00003oooooolkooooo000`ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooool00000ooooooo>ooooo`00<?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooo00000?ooooooc_ooool0033ooooo00?o0000ooooooooool02oooool00ol0
003oooooo`00003oooooolkooooo000`ooooo`?o00002oooool00ol0003oooooo`00003oooooolko
oooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooool00000ooooooo>ooooo`00<?oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooo00000?ooooooc_ooool0033ooooo00?o0000
ooooooooool02oooool00ol0003oooooo`00003oooooolkooooo000`ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooool00000ooooooo>ooooo`00<?ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooo00000?ooooooc_ooool0033ooooo00?o0000ooooooooool02oooool00ol0003ooooo
o`00003oooooolkooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooool00000oooo
ooo>ooooo`00<?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo00000?ooooooc_ooool0
033ooooo00?o0000ooooooooool02oooool00ol0003oooooo`00003oooooolkooooo000`ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooool00000ooooooo>ooooo`00<?ooool3o`0000_ooooo
00?o0000ooooool000002_ooool00ol0003oooooooooo`3ooooool7ooooo000`ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooool000002Oooool2o`000?oooooo`oooool0033ooooo00?o0000
ooooooooool02oooool00ol0003oooooo`000009ooooo`;o0000ooooooo3ooooo`00<?ooool00ol0
003oooooooooo`0:ooooo`04o`000?ooooooooooo`0000Wooooo0_l0003ooooool?ooooo000`oooo
o`03o`000?oooooooooo00[ooooo00Co0000oooooooooooo00002Oooool2o`000?oooooo`oooool0
033ooooo00?o0000ooooooooool02_ooool01?l0003oooooooooool00009ooooo`;o0000ooooooo3
ooooo`00<?ooool00ol0003oooooooooo`0:ooooo`04o`000?ooooooooooo`0000Wooooo0_l0003o
oooool?ooooo000@ooooo`;ok^k^0oooool2onk^kQWooooo00?o0000ooooooooool02_ooool01?l0
003oooooooooool00009ooooo`;o0000ooooooo3ooooo`002oooool2o`00000:oa0@4?oooooooooo
onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP?ooooo1?l000002?l@413oooooooooooo^k^ko<S8b
o`000?lb<S;ok^k^2_ooool00ol0003oooooooooo`0:ooooo`04o`000?ooooooooooo`0000Wooooo
0_l0003ooooool?ooooo000<ooooo`03o`000?oooooooooo00;ooooo00Gok^k^oeEEEOoMgMgoEEEE
onk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0:ooooo`03
o`000?oooooooooo00[ooooo00Co0000oooooooooooo00002Oooool2o`000?oooooo`oooool00003
ooooool0003o000000Co00000_ooool5o`0000Cooooo00?ogMgMo`000?oMgMd01oooool00ol0003o
ooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41002_ooool00ol0003oooooooooo`0:oooo
o`04o`000?ooooooooooo`0000Wooooo0_l0003ooooool?ooooo0009ooooo`04odA4A?oMgMgooooo
o`0000Cooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`00000:ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooo
00002Oooool2o`000?oooooo`oooool000Wooooo00CogMgMoeEEEOoooooo00000oooool01oo^k^ko
EEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000002_ooool4o`0000Wooooo00Co0000oooooooooooo00002Oooool2o`000?oooooo
`oooool000[ooooo00?oMgMgolc<c?l000000oooool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oo
oooooooo00;ooooo00Go410@oooooooooooooooooa0@400:ooooo`03o`000?oooooooooo00[ooooo
00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003ooooool?ooooo000:ooooo`03onk^
k_m4A4Co000000oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo0_l00005ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooo00002?ooool00ol0
003oooooo`00003ooooool?ooooo000;ooooo`03ogMgMol0003ooooo00cooooo00?oEEEEofIVI_l0
00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooooooo`0:ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooo
ooo3ooooo`00:?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00[ooooo00Co
0000oooooooooooo00002?ooool00ol0003oooooo`00003ooooool?ooooo000Xooooo`?o00001Ooo
ool00ol0003oooooooooo`0:ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000
ooooooo3ooooo`00:Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo00Co
0000oooooooooooo00002?ooool00ol0003oooooo`00003ooooool?ooooo000Zooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool02_ooool01?l0003oooooooooool00008ooooo`03o`00
0?oooooo00000?oooooo`oooool0033ooooo00?o0000ooooooooool02_ooool01?l0003ooooooooo
ool00008ooooo`03o`000?oooooo00000?oooooo`oooool0033ooooo00?o0000ooooooooool02_oo
ool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`000?oooooo`_ooool0033ooooo
00?o0000ooooooooool02_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00
0?oooooo`_ooool0033ooooo00?o0000ooooooooool02_ooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`000?oooooo`_ooool0033ooooo0ol0000:ooooo`04o`000?oooooooooo
o`0000Sooooo00Co0000oooooooooooo0000ooooooo2ooooo`00<?ooool00ol0003oooooooooo`0:
ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000ooooooo2ooooo`00<?oo
ool00ol0003oooooooooo`0:ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo
0000ooooooo2ooooo`00<?ooool00ol0003oooooooooo`0:ooooo`04o`000?ooooooooooo`0000So
oooo00Co0000oooooooooooo0000ooooooo2ooooo`00<?ooool00ol0003oooooooooo`0:ooooo`04
o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000ooooooo2ooooo`00<?ooool00ol0
003oooooooooo`0:ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000oooo
ooo2ooooo`00<?ooool00ol0003oooooooooo`0:ooooo`04o`000?ooooooooooo`0000Sooooo00Co
0000oooooooooooo0000ooooooo2ooooo`00<?ooool00ol0003oooooooooo`0:ooooo`04o`000?oo
ooooooooo`0000Sooooo00Co0000oooooooooooo0000ooooooo2ooooo`00<?ooool01?l0003ooooo
ooooool00009ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000ooooooo2
ooooo`00<?ooool01?l0003oooooooooool00009ooooo`04o`000?ooooooooooo`0000Sooooo00Co
0000oooooooooooo0000ooooooo2ooooo`00<?ooool00ol0003oooooooooo`02o`0000Sooooo00Co
0000oooooooooooo00002?ooool01?l0003oooooooooool0003ooooool;ooooo000`ooooo`03o`00
0?oooooooooo00;o00002?ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00
0?oooooo`_ooool0033ooooo0ol000000ooooooo0000ooooo`07ooooo`04o`000?ooooooooooo`00
00Sooooo00Co0000oooooooooooo0000ooooooo2ooooo`00<?ooool01Ol0003oooooo`000?oooooo
000000Sooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0003ooooool;ooooo
000`ooooo`05o`000?oooooo0000ooooool000002?ooool01?l0003oooooooooool00008ooooo`04
o`000?ooooooooooo`000?oooooo`_ooool0033ooooo00Go0000ooooool0003oooooo`000008oooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000ooooooo2ooooo`00<?ooool0
1Ol0003oooooo`000?oooooo000000Sooooo00Co0000oooooooooooo00002?ooool01?l0003ooooo
ooooool0003ooooool;ooooo000`ooooo`05o`000?oooooo0000ooooool000002?ooool01?l0003o
ooooooooool00008ooooo`04o`000?ooooooooooo`000?oooooo`_ooool0033ooooo00Go0000oooo
ool0003oooooo`000008ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000
ooooooo2ooooo`00<?ooool01Ol0003oooooo`000?oooooo000000Sooooo00Go0000oooooooooooo
ooooo`000007ooooo`04o`000?ooooooooooo`000?oooooo`_ooool0033ooooo00Go0000ooooool0
003oooooo`000008ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool0
003ooooool;ooooo000`ooooo`05o`000?oooooo0000ooooool000002?ooool01Ol0003ooooooooo
oooooooo000000Kooooo00Go0000ooooooooooooooooo`00003ooooool;ooooo000`ooooo`05o`00
0?oooooo0000ooooool000002?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000oooo
ooooooooooooo`00003ooooool;ooooo000`ooooo`?o000000?oooooo`000?ooool01oooool01Ol0
003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`00003ooooool;ooooo000`
ooooo`05o`000?oooooo0000ooooool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00Go0000ooooooooooooooooo`00003ooooool;ooooo000`ooooo`05o`000?oo
oooo0000ooooool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo
00Go0000ooooooooooooooooo`00003ooooool;ooooo000`ooooo`05o`000?oooooo0000ooooool0
00001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooo
ooooooooo`00003ooooool;ooooo000`ooooo`05o`000?oooooo0000ooooool000001oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00003o
oooool;ooooo000`ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00003o
oooool;ooooo000`ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00003o
oooool;ooooo000@ooooo`;ok^k^0oooool2onk^kQWooooo00?o0000ooooool000000_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0
003ooooooooooooooooo00000?oooooo`_ooool000Wooooo1Ol00002ooooo`07onk^k_mEEEGok^k^
ooooooo^k^koEEEEonk^kP03ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^
kP[ooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo00000?oooooo`_ooool0
00Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_oo
ool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02_ooool00ol0003ooooo
o`000002ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`04ooooo`05o`000?ooooooooooooooool00000ooooooo2ooooo`0000?oooooo`000?l00000
1?l00003ooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?ogMgMo`000?oMgMd01oooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41002_ooool2o`0000?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooo
ooooooooo`00003ooooool;ooooo000;ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Gok^k^oeEEEOoM
gMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000:
ooooo`;o00000oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool01Ol0003ooooooooooooooooo00000?oooooo`_ooool000cooooo00_oMgMg
ofIVI_ooooooooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`00000:ooooo`Co000000?oooooo`000?ooool01Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`3ooooookoooooo000=ooooo`03o`000?oooooooooo00;ok^k^0oooool2onk^
kPGooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00[ooooo0_l00003
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0oooooonoooooo`002Oooool01Ol0
003o^[ZjoooooonHV9So410@00kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00?ooooo0_l00005ooooo`;o00000oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo0?oooooo_oooool000Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00<ooooo`03oeEEEOmV
IVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`04o`000?ooooooooooo`0000Co
oooo0_l00003ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0oooooonoooooo`00
:?ooool01?l0003oooooooooool00004ooooo`;o00000oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo0?oooooo_oooool002Sooooo0ol00005ooooo`;o00000oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo0?oooooo_oooool002Wooooo00?o0000ooooooooool01?oo
ool2o`0000?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`;o0000oooo
oonhooooo`00:_ooool00ol0003oooooooooo`03ooooo`;o00000oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Gooooo0_l0003ooooookSooooo000`ooooo`;o00000oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo0_l0003ooooookSooooo000`ooooo`;o
00000oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo0_l0003ooooookSo
oooo000`ooooo`;o00000oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo
0_l0003ooooookSooooo000`ooooo`;o00000oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Gooooo0_l0003ooooookSooooo000`ooooo`?o00000_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Gooooo0_l0003ooooookSooooo000`ooooo`;o00000oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool00000oooooongoooo
o`00<?ooool2o`0000?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooo00000?oooooo]oooool0033ooooo0_l00003ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01Oooool00ol0003oooooo`00003ooooookOooooo000`ooooo`;o00000ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool00000oooo
oongooooo`00<?ooool2o`0000?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`04o`000?ooooooooooo`000?oooooo]oooool0033ooooo0_l00003ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0003ooooookOooooo000`
ooooo`;o00000oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Co0000
oooooooooooo0000oooooongooooo`00<?ooool2o`0000?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000oooooonfooooo`00<?ooool2
o`0000?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooo
ooooooooool00000oooooonfooooo`00<?ooool2o`0000?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000oooooonfooooo`00<?ooool2
o`0000?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooo
ooooooooool00000oooooonfooooo`00<?ooool3o`0000;ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000oooooonfooooo`00<?ooool2
o`0000?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooo
ooooooooool00000oooooonfooooo`00<?ooool2o`0000?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000oooooonfooooo`00<?ooool2
o`0000?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooo
ooooooooool00000oooooonfooooo`00<?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo00000?oooooo]_oo
ool002Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000002Sooooo0_o^
k^h3ooooo`;ok^k^Eoooool2onk^kP?ooooo0_o^k^iPooooo`;ok^k^0oooool2onk^kTkooooo0_o^
k^h3ooooo`;ok^k^K?ooool002Kooooo0ol00007ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000008_oo
ool03Om4A4Co0000o`000?lb<S;ogMgMooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00ooo
ool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^i2ooooo`Co000000Wo410@oooo
ooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb
<S;o0000oc8b<_o^k^hkooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo00goA4A4
o`000?l0003o<S8bomgMgOooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l00000
2?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^>?ooool5o`0000;ooooo00Ook^k^oeEEEOo^
k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;o
k^k^GOooool002Kooooo00?o0000ooooool000001oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000002Go
oooo00WoMgMgoc8b<_ooooooooooonk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0A?ooool00ol0003oooooooooo`02ooooo`05onk^
k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL0?Oooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool02OmgMgOo<S8boooooooooooo
k^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0hooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01Oo^k^koEEEEomgMgOmEEEGo
k^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg05gooooo000V
ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000Vooooo`07o`000?oo
oooooooooooooooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooo
oooooooooa0@4014ooooo`03o`000?oooooooooo00?ooooo00?ogMgMo`000?oMgMd01oooool00ol0
003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100?Oooool00ol0003oooooooooo`0?
ooooo`07o`000?oooooooooooooooooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo
00Go410@oooooooooooooooooa0@400iooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?ogMgMo`000?oM
gMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100GOooool002Ko
oooo00?o0000ooooool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000002Gooooo00WoMgMgoc8b
<_ooooooooooonk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000A?ooool00ol0003oooooooooo`02ooooo`05onk^k_mEEEGogMgMoeEE
EOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000?Oooool0
0ol0003oooooooooo`0>ooooo`09ogMgMolb<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Ko
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000003[ooooo00?oV9RHob4Q
8Oo^k^h00oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000005gooooo000Vooooo`03o`000?oooooo000000Oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000
ooooooooooooooooo`00000Rooooo`0=o`000?lQ8B7o0000oc8b<_o<c<coooooonk^k_mEEEGok^k^
ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`000014ooooo`0;o`000?ooooooooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Ooo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000?Oooool00ol0003ooooo
ooooo`0;ooooo`0=o`000?lQ8B7o0000oc8b<_o<c<coooooonk^k_mEEEGok^k^ooooooo^k^koEEEE
onk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000kooooo`0;
ogMgMomVIVKoooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool00000GOooool002Gooooo00Co0000oooooooooooo
00001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool01Ol0003ooooooooooooooooo000002;ooooo00?o0000ooooooooool00oooool2onk^
kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4014
ooooo`04o`000?ooooooooooooooo`;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@03gooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`03ooooo`;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@413ooooo
oooooooooooo410@03cooooo00?o0000ooooooooool00_o^k^h3ooooo`;ok^k^1Oooool00ol0003o
ooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100GOooool002Gooooo00Go0000oooooooo
ooooooooo`000006ooooo`?o00000_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00Go0000ooooooooooooooooo`00000Rooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0>Ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`08ooooo`;o0000<oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo0_l0000^ooooo`05
o`000?nj^[[ooooooiRHV?l@41003_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02?ooool2o`0005?ooooo000Uooooo`05o`000?ooooooooooooooool000001_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo023ooooo1?l0000<ooooo`03oeEEEOmVIVKo
000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo03Oooooo00?o
EEEEofIVI_l000003Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1oooool01?l0003oooooooooool0000`ooooo`03oeEEEOmVIVKo000000gooooo1?l0000<ooooo`03
oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP07ooooo`04o`000?oooooooooo
o`0002gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00<ooooo`03oeEEEOmVIVKo000000Cooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP07ooooo`04o`000?ooooooooooo`0005;ooooo000Uooooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03ko
oooo1?l00003ooooo`03o`000?oooooooooo05Cooooo1?l000001Ooooooo0000oooooooooooo0000
05kooooo1?l000001Ooooooo0000oooooooooooo000004cooooo1?l000001Ooooooo0000oooooooo
oooo000005;ooooo000Uooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Gooooo0_l0000nooooo`03o`000?oooooooooo05Wooooo0ol0
001Tooooo`?o0000D_ooool3o`0005?ooooo000Uooooo`05o`000?ooooooooooooooool000001_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo0ol0000kooooo`04o`000?oo
ooooooooo`0005_ooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`1Booooo`03o`00
0?oooooooooo05;ooooo000Uooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo0_l000000ooooooo0000ooooo`0jooooo`Co0000
G?ooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0
DOooool002Gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool01?l0003oooooooooool0003oooooojcooooo000Tooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00Co0000oooooooooooo0000oooooombooooo`03ogMgMomVIVKooooo02go
oooo00?oIVIVogMgMoooool01oooool002Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool01Ol0003ooooo
oooooooooooo00000?ooooooL?ooool00ooMgMgo410@onk^kP0^ooooo`03onk^k_l@413ogMgM00Oo
oooo000Jooooo`;o00002?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool0
0000oooooomNooooo`;o00000_ooool2o`0000cooooo00?oEEEEoiRHV?ooool00_l00002ooooo`07
o`000?ooooooooooo`000?l@413ok^k^oeEEE@02o`000003odA4A?nj^[[ooooo00;ooooo00GoV9RH
o`000?l0003oA4A4okZj^P02ooooo`08onk^k_mEEEGo0000o`000?m4A4Co^[Zjooooool@4105o`00
00?ooooo00So410@oc8b<_l0003o0000oa0@4?nYZJWoQhN7ofIVIPOooooo000Iooooo`Co00001ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Ooo
ool2o`000?ooooooEOooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@cooooo00Go0000oooooooo
ooooooooo`000002ooooo`0;o`000?ooooooooooo`000?ooooooEEEEogMgMoooooook^k^ogMgMol@
41000oooool01Ol@413o^[Zjonk^k_mgMgOo410@00;ooooo00KoEEEEogMgMoooooook^k^ogMgMol@
4103ooooo`03o`000?oooooooooo00Cooooo00So0000ojVYZOoooooooooookZj^_l0003ok^k^o`00
00Oooooo003oo`000;Co00003oooool01?oMgMgo0000oa0@4?o<c<`=ooooo`05oc8b<_oooooooooo
ooooool000000_ooool01_l0003oooooooooool0003oooooo`0000Sooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00Oo^[ZjohN7QomVIVKo
IVIVoa0@4?oooooo000000Oooooo000:ooooo`03o`000?oooooooooo00Kooooo1?l00006ooooo`;o
00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00002oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01?l0003oooooooooooooool2
o`0000Kooooo0ol00008ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool05oooool0
1?o^k^ko8B4Qoa0@4?o^k^h=ooooo`05oc8b<_ooooooooooooooool000000_ooool01Ol0003ooooo
ooooool0003ooooo00Ko00000oooool00ol0003oooooooooo`04ooooo`Ko00000oooool00ol0003o
ooooooooo`04ooooo`08oc8b<_lQ8B7oMgMgogMgMon7QhOok^k^ooooool00007ooooo`002_ooool0
0ol0003oooooooooo`0@ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo0_l00003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
1?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool01?l0003oooooooooool0000Booooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
5oooool01?lQ8B7oMgMgogMgMolb<S8=ooooo`05o`000?o^k^koooooooooool000000_o<c<`02ol0
003oZJVYomgMgOlQ8B7ooooooeEEEOn7QhOok^k^oooooon7QhOo<S8b00?ooooo00?o0000oooooooo
ool01?ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<P?ooooo00?o0000oc8b<_oMgMd01?ooool0
2?l0003o^[Zjooooooo^k^koMgMgo`000?o^k^ko00001oooool001oooooo00Go0000oooooooooooo
ooooo`000005ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Cooooo0ol0000Vooooo`03o`000?oooooooooo05_o
oooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo01Ko
oooo0_l00002ooooo`;o00003?ooool03_mEEEGoMgMgooooool@413o0000ob4Q8Ol0003oMgMgoa0@
4?l0003oZJVYooooooo^k^koEEEE0_l000001?m4A4Cok^k^ooooool@4105o`0000?ooooo00Kok^k^
oeEEEOl0003o0000odA4A?o^k^h2ooooo`;o000000CoZJVYob4Q8Ol0003o8B4Q0_ooool02?nYZJWo
8B4Qo`000?l0003o<S8bo`000?mgMgOoEEEE1oooool001oooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo0?ooooooLoooool00ooMgMgo410@onk^kP0Booooo`03o`000?oo
oooooooo01Wooooo00?ok^k^oa0@4?oMgMd01oooool001oooooo00Co0000oooooooooooo00001ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`3oooooogCooooo00?oMgMgofIVI_ooool04Oooool00ol0003ooooooooo
o`0Iooooo`03ofIVI_mgMgOooooo00Oooooo000Pooooo`03o`000?oooooo000000Oooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0oooooon^ooooo`008?ooool2o`0000Sooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0oooooon^oooo
o`00:_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`3oooooojkooooo000Zooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool01?l0003oooooooooool0003ooooook7ooooo000Zooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0003ooooook7o
oooo000Zooooo`03o`000?oooooooooo00;ooooo0_l00005ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`000?oo
oooo/Oooool002[ooooo00?o0000ooooooooool00_ooool4o`0000?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo
0000oooooonaooooo`00:_ooool00ol0003oooooooooo`02ooooo`;o00001Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01?l0003ooooo
ooooool0003ooooook7ooooo000Zooooo`03o`000?oooooooooo00;ooooo0_l00005ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooo00000?oooooo/_ooool002[ooooo00?o0000ooooooooool00_ooool2o`0000Gooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooool00000oooooonbooooo`00:_ooool00ol0003oooooooooo`02ooooo`;o00001Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooo`00003ooooook;ooooo000Zooooo`03o`000?oooooooooo00;ooooo0_l00005oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooo00000?oooooo/_ooool002[ooooo00?o0000ooooooooool00_ooool2o`0000Go
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooool00000oooooonbooooo`00:_ooool00ol0003oooooooooo`02ooooo`;o0000
1Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1Oooool2o`000?oooooo/_ooool002_ooooo00Co0000oooooooooooooooo0_l00005ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`;o0000
oooooonbooooo`00:oooool01?l0003oooooooooooooool2o`0000Gooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo^Oooool002_ooooo00Co
0000oooooooooooooooo0_l00005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`3ooooookWooooo000[ooooo`04o`000?ooooooooooooooo`;o0000
1Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
ooooooniooooo`00:oooool01?l0003oooooooooooooool4o`0000?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo^Oooool002_ooooo00Co
0000oooooooooooooooo0_l00005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`3ooooookWooooo000[ooooo`04o`000?ooooooooooooooo`;o0000
1Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
ooooooniooooo`00:oooool01?l0003oooooooooooooool2o`0000Gooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo^Oooool002_ooooo00Co
0000oooooooooooooooo0_l00005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`3ooooookWooooo000[ooooo`04o`000?ooooooooooooooo`;o0000
1_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0ooooooniooooo`00
:oooool01_l0003oooooooooool0003oooooo`0000Kooooo00Go0000ooooooooooooooooo`000006
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooo
oooo00000?oooooo_?ooool002_ooooo00Ko0000oooooooooooo0000ooooool00006ooooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00Go0000ooooooooooooooooo`00003ooooookcooooo000/ooooo`05o`000?oooooo0000oooo
ool000001_ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`00
0006ooooo`05o`000?ooooooooooooooool00000oooooonlooooo`00;?ooool01Ol0003oooooo`00
0?oooooo000000Kooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooooooooooo
ool000001_ooool01Ol0003ooooooooooooooooo00000?oooooo_?ooool002cooooo00Go0000oooo
ool0003oooooo`000006ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooo
oooooooo000000Kooooo00Go0000ooooooooooooooooo`00003ooooookcooooo000/ooooo`05o`00
0?oooooo0000ooooool000001_ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooo
ooooooooooooo`000006ooooo`05o`000?ooooooooooooooool00000oooooonlooooo`00;?ooool0
1?l0003oooooo`000?ooool3o`0000Cooooo00Go0000ooooooooooooooooo`000007ooooo`05o`00
0?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo00000?oooooo_?ooool002co
oooo00Go0000ooooool0003oooooo`000006ooooo`05o`000?ooooooooooooooool000001oooool0
1Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`00003ooooookcooooo
000/ooooo`05o`000?oooooo0000ooooool000001_ooool01Ol0003ooooooooooooooooo000000Oo
oooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool00000oooooonl
ooooo`00;?ooool01Ol0003oooooo`000?oooooo000000Kooooo00Go0000ooooooooooooooooo`00
0007ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo00000?oo
oooo_?ooool002gooooo0_l000000ooooooo0000ooooo`05ooooo`05o`000?ooooooooooooooool0
00001oooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`00003o
oooookcooooo000]ooooo`04o`000?ooooooooooo`0000Kooooo00Go0000ooooooooooooooooo`00
0007ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo00000?oo
oooo_?ooool000oooooo0_o^k^h3ooooo`;ok^k^6_ooool00ol0003oooooooooo`04ooooo`05o`00
0?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000oooo
ooooooooooooo`00003ooooookcooooo0008ooooo`Go00000_ooool01oo^k^koEEEEonk^k_oooooo
k^k^oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h;oooo
o`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooo
ooooooooool000001_ooool01Ol0003ooooooooooooooooo00000?oooooo_?ooool000Sooooo00Go
V9RHob4Q8Oo^k^koooooodA4A003ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ol0003oooooooooo`04oooo
o`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Kooooo00Go
0000ooooooooooooooooo`00003ooooookcooooo0009ooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?o
gMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100
2oooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003o
oooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`00003ooooookcooooo000:oooo
o`03oiRHV?lQ8B7ok^k^00?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`00000;ooooo`03o`000?oooooooooo00Cooooo00Go
0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003o
oooooooooooooooo00000?oooooo_?ooool000_ooooo00_oMgMgofIVI_ooooooooooonk^k_mEEEGo
k^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`00000;ooooo`Co00000oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooo
ooooooooooooo`000006ooooo`05o`000?ooooooooooooooool00000oooooonlooooo`003?ooool0
0ol0003oooooooooo`02onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@400;ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooooooo
o`000007ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo0000
0?oooooo_?ooool000Sooooo00Go0000okZj^_ooooooV9RHoa0@400>ooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03o`000?oooooooooo00Cooooo00Go0000
ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooo
oooooooooooo00000?oooooo_?ooool000Sooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00<ooooo`03
oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`;o00001_ooool00ol0
003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooo
oooo000000Kooooo00Co0000oooooooooooo0000oooooonmooooo`009oooool01?l0003ooooooooo
ool00005ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000007ooooo`05
o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003ooooookgooooo000Wooooo`04
o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo
000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?oooooo_Ooo
ool002Oooooo0ol00006ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00
0007ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003ooooookgooooo
000Xooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?oo
oooo_Oooool002Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`05o`00
0?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000oooo
ool00000oooooonmooooo`00<?ooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooooooo
ool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooool00000oooooonm
ooooo`00<?ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001oooool0
1Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooool00000oooooonmooooo`00<?ooool0
0ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooo
oooooooo000000Oooooo00?o0000ooooool00000oooooonmooooo`00<?ooool3o`0000Cooooo00Go
0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool00ol0003o
ooooo`00003ooooookgooooo000`ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooo
ooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003ooooo
okgooooo000`ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000007oooo
o`05o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003ooooookgooooo000`oooo
o`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooo
ooooooooool000001oooool00ol0003oooooo`00003ooooookgooooo000`ooooo`03o`000?oooooo
oooo00Cooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool00000
1oooool00ol0003oooooo`00003ooooookgooooo000`ooooo`03o`000?oooooooooo00Cooooo00Go
0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool00ol0003o
ooooo`00003ooooookgooooo000`ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooo
ooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003ooooo
okgooooo000`ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000007oooo
o`05o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003ooooookgooooo000`oooo
o`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooo
ooooooooool000001oooool00ol0003oooooo`00003ooooookgooooo000`ooooo`03o`000?oooooo
oooo00Cooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool00000
1oooool00ol0003oooooo`00003ooooookgooooo000`ooooo`03o`000?oooooooooo00Cooooo00Go
0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool00ol0003o
ooooo`00003ooooookgooooo000`ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooo
ooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003ooooo
okgooooo000`ooooo`?o00001?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooo
ooooooooooooo`000008ooooo`03o`000?oooooooooo0?oooooo_?ooool0033ooooo00?o0000oooo
ooooool01?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`00
0008ooooo`03o`000?oooooooooo0?oooooo_?ooool0033ooooo00?o0000ooooooooool01?ooool0
1Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000008ooooo`03o`00
0?oooooooooo0?oooooo_?ooool0033ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000Oooooo00Go0000ooooooooooooooooo`00003oooooolOooooo000`ooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooooooooooo
ool00000ooooooo7ooooo`00<?ooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooooooo
ool000001oooool01Ol0003ooooooooooooooooo00000?ooooooaoooool0033ooooo00?o0000oooo
ooooool01?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`00
003oooooolOooooo000`ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00
0007ooooo`04o`000?ooooooooooo`000?oooooob?ooool0033ooooo00?o0000ooooooooool01?oo
ool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`000?oooooob?ooool0033ooooo
00?o0000ooooooooool01?ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00
0?oooooob?ooool0033ooooo00?o0000ooooooooool01Oooool00ol0003oooooo`000008ooooo`04
o`000?ooooooooooo`000?oooooob?ooool0033ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooo`000008ooooo`04o`000?ooooooooooo`000?oooooob?ooool0033ooooo0ol00005ooooo`03
o`000?oooooo000000Sooooo00Co0000oooooooooooo0000ooooooo8ooooo`00<?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooo000000Sooooo00Co0000oooooooooooo0000ooooooo8oooo
o`00<?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Sooooo00Co0000oooooooo
oooo0000ooooooo8ooooo`00<?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000So
oooo00Co0000oooooooooooo0000ooooooo8ooooo`00<?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooo000000Sooooo00Co0000oooooooooooo0000ooooooo8ooooo`00<?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooo000000Sooooo00Co0000oooooooooooo0000ooooooo8oooo
o`003oooool2onk^kP?ooooo0_o^k^hJooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool0
00002?ooool01?l0003oooooooooool0003oooooolSooooo000:ooooo`;o000000[o410@oooooooo
ooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^0oooool4o`000008oa0@4?ooooooooooonk^k_lb
<S;o0000oc8b<_o^k^h;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000002?ooool0
1?l0003oooooooooool0003oooooolSooooo000;ooooo`03o`000?oooooooooo00;ooooo00Gok^k^
oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000002?ooool01?l0003ooooo
ooooool0003oooooolSooooo0008ooooo`Go00001?ooool00ooMgMgo0000omgMg@07ooooo`03o`00
0?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400;ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooool000002?ooool01?l0003oooooooooool0003oooooolSooooo0008ooooo`04
odA4A?oMgMgoooooo`0000Cooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`00000;ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooool000002?ooool01?l0003oooooooooool0003oooooolSooooo0008ooooo`04omgMgOmE
EEGoooooo`0000?ooooo00Ook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000000_ooooo1?l00004ooooo`03o`000?oooooo
000000Sooooo00Co0000oooooooooooo0000ooooooo8ooooo`002Oooool00omgMgOoc<c<o`000003
ooooo`;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooo`000008ooooo`04o`000?oo
ooooooooo`000?oooooob?ooool000Wooooo00?ok^k^odA4A?l000003oooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooo000000Sooooo00Co0000oooooooooooo0000ooooooo8ooooo`002_ooool00omgMgOo0000
ooooo`0<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`;o
00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Sooooo00Co0000oooooooo
oooo0000ooooooo8ooooo`009oooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooool000002?ooool01?l0003oooooooooool0003oooooolSooooo000Woooo
o`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool01Oooool00ol0003oooooo`000008
ooooo`04o`000?ooooooooooo`000?oooooob?ooool002Oooooo0ol00006ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooool000002Oooool00ol0003oooooo`00003oooooolSooooo000Xoooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooo`000009oooo
o`03o`000?oooooo00000?oooooob?ooool002Wooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooo000000Wooooo00?o0000ooooool00000ooooooo8ooooo`00
<?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Wooooo00?o0000ooooool00000
ooooooo8ooooo`00<?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Wooooo00?o
0000ooooool00000ooooooo8ooooo`00<?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
000000Wooooo00?o0000ooooool00000ooooooo8ooooo`00<?ooool3o`0000Gooooo0_l0000:oooo
o`03o`000?oooooo00000?oooooob?ooool0033ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooo00000?oooooob?ooool0033ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo00000?oooooob?ooool0033ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo00000?oooooob?oo
ool0033ooooo00?o0000ooooooooool04Oooool00ol0003oooooo`00003oooooolSooooo000`oooo
o`03o`000?oooooooooo017ooooo00?o0000ooooool00000ooooooo8ooooo`00<?ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooo00000?oooooob?ooool0033ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooo`00003oooooolSooooo000`ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooool00000ooooooo8ooooo`00<?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
00000?oooooob?ooool0033ooooo00?o0000ooooooooool04Oooool00ol0003oooooo`00003ooooo
olSooooo000`ooooo`03o`000?oooooooooo017ooooo0_l0003oooooolWooooo000`ooooo`?o0000
4Oooool2o`000?oooooobOooool0033ooooo00?o0000ooooooooool04Oooool2o`000?oooooobOoo
ool0033ooooo00?o0000ooooooooool04Oooool2o`000?oooooobOooool0033ooooo00?o0000oooo
ooooool04Oooool2o`000?oooooobOooool0033ooooo00?o0000ooooooooool04Oooool2o`000?oo
oooobOooool0033ooooo00?o0000ooooooooool04Oooool2o`000?oooooobOooool0033ooooo00?o
0000ooooooooool04Oooool2o`000?oooooobOooool0033ooooo00?o0000ooooooooool04Oooool2
o`000?oooooobOooool0033ooooo00?o0000ooooooooool04Oooool2o`000?oooooobOooool0033o
oooo00?o0000ooooooooool04Oooool2o`000?oooooobOooool0033ooooo00?o0000ooooooooool0
4Oooool2o`000?oooooobOooool0033ooooo00?o0000ooooooooool04Oooool2o`000?oooooobOoo
ool0033ooooo0ol0003oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033o
oooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo
000`ooooo`03o`000?oooooooooo0?oooooog?ooool00?ooooooooooool@ooooo`00oooooooooooo
oa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003o
oooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo002Pooooo`;o0000
1?ooool00onj^[[o<S8booooo`04ooooo`;o00001_ooool00ol0003o^[Zjooooo`3ooooooeOooooo
002Pooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`;o<S8boooooomHooooo`00SOooool3o`0000;ooooo00Ko<S8boa0@4?ooooooooooonk^
k_mEEED2o`000003odA4A?nj^[[ooooo00?ooooo00?o0000ooooooooool00_ooool01OnHV9So410@
o`000?l0003oZJVY00Cooooo00?o0000ooooooooool01?ooool00on7QhOo0000okZj^P0<ooooo`05
oiRHV?l0003o0000odA4A?nj^[X02Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`0;olc<c?lQ8B7o0000ob4Q8Oo<c<coooooolc<c?o^k^koooooonk^k_o<c<`01?ooool4o`00
0008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hCooooo`06oa0@4?lb<S;o0000o`000?l@
413oZJVY0_ooool01_o^k^koEEEEo`000?l0003oA4A4okZj^P?ooooo00GoIVIVo`000?l0003oA4A4
olc<c03Xooooo`00S_ooool01Ol0003oooooooooooo<c<co410@00?ooooo00KoEEEEogMgMooooooo
k^k^ogMgMol@4104ooooo`03o`000?oooooooooo00;ooooo00Ko0000ojVYZOmEEEGoV9RHoeEEEOnj
^[X3ooooo`03o`000?oooooooooo00Cooooo00?oc<c<o`000?l@41003?ooool01_l@413o^[Zjonk^
k_mgMgOo410@ooooo`Ko00000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44oooo
o`0;ob4Q8OnHV9SooooooiRHV?lQ8B7oooooonk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool01_l0003oZJVYoooooooooooo
^[Zjo`0000;ooooo00KoEEEEogMgMoooooook^k^ogMgMol@4102ooooo`06ofIVI_mgMgOooooooooo
oon7QhOo410@j?ooool008kooooo00Go0000ooooooooooooEEEEohN7Q`03ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool00_ooool01_lb<S;ok^k^oiRHV?mEEEGogMgMoa0@40?ooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0;ooooo`05oa0@4?ooooooooooooooool@
41002oooool01Ol0003ooooooooooooooooo000000;ooooo00?ogMgMo`000?oMgMd01oooool00ol0
003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41005?ooool01Onj^[[oQhN7ofIVI_mV
IVKo410@00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3[ooooo`00S_ooool0
1Ol0003oooooomgMgOl0003ok^k^00?ooooo1_l00004ooooo`03o`000?oooooooooo00;ooooo00Oo
^[ZjodA4A?o<c<co8B4Qooooool@413oc<c<00;ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`03ooooo`Ko00000_ooool01Ol0003ooooooooooooooooo000000_ooooo00_o<S8boiRH
V?ooooooV9RHoc8b<_ooooook^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`00000Cooooo`06oc8b<_lQ8B7oMgMgogMgMon7QhOok^k^0_oo
ool6o`0000;ooooo00?o0000ooooooooool0joooool008kooooo0ol000000ol@413oV9RHooooo`02
ooooo`06oeEEEOn7QhOok^k^oooooon7QhOo<S8b1?ooool00ol0003oooooooooo`02ooooo`07onk^
k_l0003oooooo`000?ooooooIVIVohN7Q`02ooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool02oooool01Ol0003ooooooooooooooooo000000_ooooo00_oc<c<o`000?l0003o0000olc<
c?ooooooc<c<onk^k_ooooook^k^olc<c006ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`00000Cooooo`06o`000?nj^[[oooooonk^k_mgMgOo00000_ooool01_mEEEGoQhN7
onk^k_ooooooQhN7oc8b<P;ooooo00KoIVIVogMgMoooooooooooohN7Qol0003Xooooo`00S_ooool0
1Ol0003oooooooooooo<c<co000000?ooooo00Kok^k^oeEEEOl0003o0000odA4A?o^k^h4ooooo`03
o`000?oooooooooo00;ooooo00CoIVIVoiRHV?oooooo<S8b0_nj^[X01?l0003oooooooooool0000C
ooooo`03oa0@4?l0003o000000?o00002_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go
410@okZj^_oooooo^[Zjoa0@400<ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@4007ooooo`?o00000_ooool3o`0000Cooooo00KoZJVYob4Q8Ol0003o0000oc8b<_l00002
ooooo`06onk^k_mEEEGo0000o`000?m4A4Cok^k^0_ooool01_o^k^koIVIVo`000?l0003oA4A4o`00
0>Sooooo002>ooooo`05o`000?ooooooooooolc<c?l000003Oooool00ol0003oooooooooo`05oooo
o`03ofIVI_n7QhOooooo00?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0;oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000cooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`3oooooo`;ooooo002=ooooo`Co000000?o410@ojVYZOooool03?oo
ool2o`0000Kooooo00?oZJVYodA4A?ooool00_ooool2o`0001Gooooo00?o0000ooooooooool02ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@0:ooooo`03
oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`Co00000_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo0_ooool00?oooooo1_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo0?oooooo0_ooool00?oooooo1_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo0?oooooo0_ooool00?oooooo1Oooool2o`0000?ooooo0_l0
003oooooo`Cooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3o
oooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooo
oooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?oo
ool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooo
ooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@oooo
o`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00\
\>"],
  ImageRangeCache->{{{0, 525.688}, {324.5, 0}} -> {0, -6.34248*^6, 0, 53093}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0.309017 5.42214e-08 [
[.32684 .29652 -16.5 -12.5 ]
[.32684 .29652 16.5 0 ]
[.54329 .29652 -16.5 -12.5 ]
[.54329 .29652 16.5 0 ]
[.75974 .29652 -22.5 -12.5 ]
[.75974 .29652 22.5 0 ]
[.97619 .29652 -16.5 -12.5 ]
[.97619 .29652 16.5 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 64 6 ]
[.09789 .09213 -34.5 -6.25 ]
[.09789 .09213 0 6.25 ]
[.09789 .20057 -34.5 -6.25 ]
[.09789 .20057 0 6.25 ]
[.09789 .41746 -28.5 -6.25 ]
[.09789 .41746 0 6.25 ]
[.09789 .5259 -28.5 -6.25 ]
[.09789 .5259 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -59.8125 0 ]
[.5 .63053 59.8125 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 .30902 m
.32684 .31527 L
s
gsave
.32684 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 .30902 m
.54329 .31527 L
s
gsave
.54329 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 .30902 m
.75974 .31527 L
s
gsave
.75974 .29652 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 .30902 m
.15368 .31277 L
s
.19697 .30902 m
.19697 .31277 L
s
.24026 .30902 m
.24026 .31277 L
s
.28355 .30902 m
.28355 .31277 L
s
.37013 .30902 m
.37013 .31277 L
s
.41342 .30902 m
.41342 .31277 L
s
.45671 .30902 m
.45671 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.58658 .30902 m
.58658 .31277 L
s
.62987 .30902 m
.62987 .31277 L
s
.67316 .30902 m
.67316 .31277 L
s
.71645 .30902 m
.71645 .31277 L
s
.80303 .30902 m
.80303 .31277 L
s
.84632 .30902 m
.84632 .31277 L
s
.88961 .30902 m
.88961 .31277 L
s
.9329 .30902 m
.9329 .31277 L
s
.0671 .30902 m
.0671 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09213 m
.11664 .09213 L
s
gsave
.09789 .09213 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .20057 m
.11664 .20057 L
s
gsave
.09789 .20057 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .41746 m
.11664 .41746 L
s
gsave
.09789 .41746 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .5259 m
.11664 .5259 L
s
gsave
.09789 .5259 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.11039 .11924 m
.11414 .11924 L
s
.11039 .14635 m
.11414 .14635 L
s
.11039 .17346 m
.11414 .17346 L
s
.11039 .22768 m
.11414 .22768 L
s
.11039 .2548 m
.11414 .2548 L
s
.11039 .28191 m
.11414 .28191 L
s
.11039 .33613 m
.11414 .33613 L
s
.11039 .36324 m
.11414 .36324 L
s
.11039 .39035 m
.11414 .39035 L
s
.11039 .44457 m
.11414 .44457 L
s
.11039 .47168 m
.11414 .47168 L
s
.11039 .49879 m
.11414 .49879 L
s
.11039 .06502 m
.11414 .06502 L
s
.11039 .03791 m
.11414 .03791 L
s
.11039 .0108 m
.11414 .0108 L
s
.11039 .55301 m
.11414 .55301 L
s
.11039 .58012 m
.11414 .58012 L
s
.11039 .60723 m
.11414 .60723 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -120.812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.812 moveto
(@) show
81.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.812 moveto
(D) show
93.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.) show
129.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
135.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
147.000 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
151.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
160.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
178.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02532 .30901 L
.02691 .309 L
.03029 .30897 L
.03189 .30896 L
.03259 .30895 L
.03335 .30894 L
.03377 .30894 L
.03395 .30894 L
.03416 .30894 L
.03435 .30894 L
.03444 .30894 L
.03453 .30894 L
.03462 .30894 L
.03471 .30894 L
.03481 .30894 L
.03487 .30894 L
.03492 .30894 L
.03502 .30894 L
.03508 .30894 L
.03514 .30894 L
.03524 .30894 L
.03535 .30894 L
.03553 .30894 L
.03573 .30894 L
.03595 .30894 L
.03618 .30894 L
.0366 .30895 L
.03702 .30895 L
.03742 .30896 L
.0383 .30897 L
.03909 .30899 L
.03992 .30902 L
.04148 .30909 L
.04295 .30917 L
.04605 .30936 L
.04763 .30945 L
.04806 .30947 L
.04853 .30949 L
.04896 .30951 L
.04915 .30951 L
.04936 .30951 L
.04956 .30952 L
.04966 .30952 L
.04977 .30952 L
.04986 .30952 L
.04995 .30952 L
.05005 .30952 L
.05014 .30952 L
.05024 .30952 L
Mistroke
.0503 .30952 L
.05035 .30952 L
.05045 .30952 L
.05055 .30952 L
.05076 .30951 L
.05099 .30951 L
.05138 .30949 L
.0518 .30947 L
.05215 .30945 L
.05254 .30942 L
.05336 .30933 L
.05411 .30923 L
.05579 .30889 L
.05732 .30848 L
.05899 .30795 L
.06055 .30742 L
.06138 .30715 L
.06227 .30689 L
.06312 .30668 L
.06349 .30661 L
.0639 .30655 L
.06408 .30653 L
.06428 .30651 L
.06447 .30649 L
.06455 .30649 L
.06464 .30648 L
.06474 .30648 L
.06483 .30648 L
.06493 .30648 L
.06499 .30648 L
.06504 .30648 L
.06514 .30648 L
.06523 .30648 L
.06533 .30649 L
.06542 .30649 L
.06561 .30651 L
.06579 .30652 L
.06599 .30655 L
.0662 .30659 L
.06662 .30668 L
.06702 .3068 L
.06774 .30708 L
.0685 .30749 L
.06926 .30802 L
.07008 .30872 L
.07155 .31028 L
.07488 .31474 L
.07655 .31689 L
.07728 .31767 L
.07767 .31802 L
Mistroke
.07809 .31834 L
.07849 .3186 L
.07886 .31877 L
.07904 .31883 L
.07913 .31885 L
.07923 .31888 L
.07933 .31889 L
.07942 .31891 L
.0795 .31891 L
.07959 .31892 L
.07968 .31892 L
.07978 .31891 L
.07988 .3189 L
.07998 .31889 L
.08007 .31887 L
.08016 .31885 L
.08035 .31878 L
.08055 .31869 L
.08077 .31857 L
.08117 .31826 L
.08156 .31787 L
.08193 .31741 L
.08276 .31602 L
.08357 .31422 L
.08445 .31179 L
.08775 .29887 L
.0894 .29145 L
.09093 .2852 L
.0917 .28265 L
.09241 .28074 L
.09281 .27993 L
.09302 .27959 L
.09324 .27928 L
.09343 .27908 L
.09353 .27899 L
.09363 .27891 L
.09373 .27886 L
.09382 .27882 L
.09391 .27879 L
.09399 .27877 L
.09409 .27877 L
.09415 .27878 L
.0942 .27879 L
.0943 .27881 L
.0944 .27886 L
.09449 .27891 L
.09457 .27898 L
.09477 .27917 L
.09497 .27944 L
.09516 .27976 L
Mistroke
.09559 .2807 L
.09595 .28177 L
.09635 .28321 L
.09707 .28657 L
.09782 .29116 L
.09866 .2974 L
.10034 .31337 L
.10358 .35032 L
.10506 .3658 L
.10585 .37246 L
.10669 .37792 L
.10693 .3791 L
.10715 .38006 L
.10737 .38083 L
.10757 .3814 L
.10776 .38182 L
.10785 .38198 L
.10796 .38211 L
.10807 .38221 L
.10813 .38225 L
.10818 .38227 L
.10828 .38228 L
.10838 .38225 L
.10848 .38219 L
.10858 .38208 L
.10869 .38193 L
.10879 .38175 L
.10896 .38132 L
.10916 .38071 L
.10959 .37876 L
.11 .37627 L
.11078 .36944 L
.11151 .36075 L
.11318 .3333 L
.11631 .26153 L
.11791 .22341 L
.11875 .20546 L
.11964 .18926 L
.12043 .17801 L
.12089 .1732 L
.1211 .17134 L
.12131 .16985 L
.12149 .16876 L
.1217 .16783 L
.12178 .16751 L
.12188 .16724 L
.12197 .16704 L
.12205 .1669 L
.12215 .1668 L
.12225 .16678 L
Mistroke
.12235 .16683 L
.1224 .16688 L
.12246 .16697 L
.12256 .16716 L
.12266 .16745 L
.12285 .16818 L
.12305 .16929 L
.12327 .17083 L
.12367 .17454 L
.12409 .17987 L
.12455 .18735 L
.12539 .20485 L
.12617 .22578 L
.12928 .3409 L
.13086 .40691 L
.13258 .47135 L
.13338 .49526 L
.13382 .50623 L
.13423 .515 L
.13462 .52169 L
.13482 .5246 L
.13504 .5272 L
.13522 .529 L
.13542 .53057 L
.13551 .53112 L
.1356 .53161 L
.13569 .53198 L
.13577 .53224 L
.13587 .53246 L
.13592 .53253 L
.13597 .53257 L
.13603 .53257 L
.13609 .53254 L
.13619 .53238 L
.13629 .53211 L
.13638 .53177 L
.13648 .53128 L
.13658 .53062 L
.13682 .52865 L
.13705 .52616 L
.13747 .51985 L
.13787 .51187 L
.13824 .50283 L
.13908 .47665 L
.14059 .41221 L
.14224 .32225 L
.14393 .2225 L
.14548 .1372 L
.14624 .10095 L
.14707 .06786 L
Mistroke
.14746 .05538 L
.14786 .0441 L
.14822 .03604 L
.14859 .02943 L
.1488 .02668 L
.1489 .02548 L
.14902 .02438 L
.14913 .02355 L
.14923 .02294 L
.14932 .02248 L
.14942 .02217 L
.14947 .02206 L
.14952 .02198 L
.14958 .02195 L
.14964 .02197 L
.14974 .02213 L
.14979 .02228 L
.14984 .02246 L
.14995 .02298 L
.15007 .02376 L
.15031 .02598 L
.15052 .02869 L
.15072 .03175 L
.15115 .04067 L
.15155 .05142 L
.15193 .06369 L
.15354 .13637 L
.15502 .22643 L
.15818 .4412 L
.159 .49035 L
.15977 .53112 L
.16052 .56395 L
.16122 .5874 L
.16158 .59667 L
.16197 .60427 L
.16219 .60755 L
.1624 .60991 L
.16258 .61142 L
.16269 .61202 L
.16278 .61241 L
.16288 .61266 L
.16299 .61274 L
.16308 .61265 L
.16317 .61243 L
.16328 .612 L
.16334 .61168 L
.16339 .61133 L
.1636 .60956 L
.1638 .60721 L
.16402 .60386 L
Mistroke
.16446 .59476 L
.16488 .58343 L
.16527 .57027 L
.16602 .53973 L
.16769 .44814 L
.17076 .24453 L
.17247 .1437 L
.17327 .10577 L
.17402 .07799 L
.17439 .06697 L
.17479 .05714 L
.1752 .04972 L
.17542 .04671 L
.17552 .04561 L
.17563 .04459 L
.17574 .04379 L
.17583 .04319 L
.17592 .04274 L
.17602 .0424 L
.1761 .04222 L
.17618 .04215 L
.17627 .04218 L
.17637 .04235 L
.17646 .04266 L
.17657 .04315 L
.17668 .04384 L
.17678 .04463 L
.17696 .04644 L
.17716 .04891 L
.17758 .05619 L
.17798 .06511 L
.17887 .09249 L
.18049 .16302 L
.18365 .33529 L
.18523 .41319 L
.18593 .44133 L
.18669 .46674 L
.1871 .47809 L
.18748 .4869 L
.18788 .49411 L
.18824 .49926 L
.18845 .50143 L
.18856 .50237 L
.18867 .50322 L
.18877 .50382 L
.18887 .50435 L
.18897 .50473 L
.18906 .50498 L
.18911 .50508 L
.18917 .50516 L
Mistroke
.18922 .5052 L
.18927 .5052 L
.18937 .50513 L
.18947 .50493 L
.18953 .50478 L
.18958 .50459 L
.18969 .50415 L
.18981 .50347 L
.18992 .5027 L
.1903 .49907 L
.19052 .49637 L
.19071 .49352 L
.19144 .47948 L
.1923 .4573 L
.1931 .43176 L
.19619 .31503 L
.19776 .26014 L
.19859 .23591 L
.19948 .21487 L
.19992 .2066 L
.20034 .20011 L
.20071 .19543 L
.20092 .19324 L
.20112 .19157 L
.2013 .19024 L
.2015 .1891 L
.20161 .18861 L
.20171 .18824 L
.20181 .18796 L
.20191 .18773 L
.202 .18761 L
.20209 .18753 L
.20218 .18753 L
.20226 .18757 L
.20236 .18768 L
.20246 .18787 L
.20256 .18813 L
.20265 .18842 L
.20284 .18926 L
.20302 .19025 L
.20342 .19327 L
.20379 .19697 L
.20415 .20126 L
.2058 .22934 L
.20887 .29804 L
.21058 .33295 L
.21139 .34633 L
.21213 .3564 L
.21291 .36441 L
.21332 .36755 L
Mistroke
.21352 .36887 L
.21375 .37007 L
.21394 .37094 L
.21412 .37159 L
.2143 .3721 L
.21447 .37245 L
.21457 .3726 L
.21467 .37271 L
.21476 .37277 L
.21486 .37281 L
.21496 .3728 L
.21502 .37278 L
.21507 .37274 L
.21517 .37265 L
.21527 .37252 L
.21537 .37235 L
.21548 .37212 L
.21567 .3716 L
.21604 .37025 L
.21646 .36811 L
.21686 .36562 L
.21833 .35279 L
.22149 .31689 L
.22308 .30065 L
.22378 .29479 L
.22453 .28948 L
.22495 .28708 L
.22533 .28518 L
.22573 .28358 L
.22609 .28238 L
.2263 .28185 L
.22652 .28136 L
.2267 .28104 L
.22691 .28077 L
.22702 .28065 L
.22713 .28057 L
.22724 .2805 L
.2273 .28048 L
.22736 .28046 L
.22746 .28045 L
.22752 .28045 L
.22757 .28045 L
.22767 .28048 L
.22777 .28053 L
.22786 .28058 L
.22796 .28066 L
.22816 .28088 L
.22835 .28114 L
.22852 .28143 L
.22892 .28228 L
Mistroke
.22934 .28342 L
.2308 .28904 L
.23414 .30553 L
.23495 .30919 L
.23581 .31259 L
.23661 .31522 L
.23735 .31716 L
.23806 .31853 L
.23846 .3191 L
.23883 .3195 L
.23903 .31967 L
.23922 .31979 L
.23943 .3199 L
.23954 .31993 L
.2396 .31995 L
.23966 .31996 L
.23976 .31998 L
.23985 .31999 L
.23995 .31999 L
.24001 .31999 L
.24006 .31999 L
.24016 .31997 L
.24025 .31996 L
.24035 .31993 L
.24044 .3199 L
.24064 .31981 L
.24081 .31971 L
.24122 .3194 L
.24162 .319 L
.24205 .31848 L
.24353 .31614 L
.24511 .31315 L
.24684 .30999 L
.24764 .30873 L
.24849 .30758 L
.24929 .30672 L
.25003 .30612 L
.25043 .30587 L
.25085 .30566 L
.25106 .30558 L
.25128 .30551 L
.25152 .30545 L
.25164 .30543 L
.25175 .30541 L
.25185 .3054 L
.25196 .30539 L
.25201 .30539 L
.25206 .30538 L
.25212 .30538 L
.25218 .30538 L
Mistroke
.25229 .30538 L
.25234 .30538 L
.2524 .30538 L
.2525 .30539 L
.25259 .3054 L
.25269 .30541 L
.25279 .30542 L
.25297 .30545 L
.25337 .30554 L
.25374 .30565 L
.25415 .30581 L
.25497 .3062 L
.25645 .30706 L
.25815 .30811 L
.25969 .30895 L
.26046 .30929 L
.26129 .30959 L
.26168 .3097 L
.26208 .30981 L
.26244 .30988 L
.26281 .30995 L
.26302 .30997 L
.26324 .31 L
.26345 .31002 L
.26364 .31004 L
.26386 .31005 L
.26399 .31005 L
.26404 .31006 L
.2641 .31006 L
.26415 .31006 L
.26421 .31006 L
.26431 .31006 L
.26437 .31006 L
.26443 .31006 L
.26448 .31006 L
.26453 .31006 L
.26463 .31006 L
.26469 .31006 L
.26474 .31006 L
.26493 .31005 L
.26504 .31005 L
.26515 .31004 L
.26536 .31003 L
.26578 .30999 L
.26615 .30995 L
.26766 .30974 L
.26932 .30945 L
.27102 .30916 L
.27257 .30896 L
.27333 .30888 L
Mistroke
.27374 .30885 L
.27417 .30882 L
.27454 .3088 L
.27496 .30878 L
.27514 .30878 L
.27533 .30877 L
.27552 .30877 L
.27569 .30876 L
.27588 .30876 L
.27599 .30876 L
.27609 .30876 L
.27618 .30876 L
.27626 .30876 L
.27636 .30876 L
.27646 .30876 L
.27656 .30876 L
.27661 .30876 L
.27666 .30876 L
.27676 .30876 L
.27686 .30876 L
.27707 .30876 L
.2773 .30876 L
.27772 .30877 L
.27817 .30878 L
.27899 .30881 L
.28233 .30895 L
.28315 .30898 L
.28401 .30901 L
.2848 .30903 L
.28555 .30905 L
.28626 .30906 L
.28666 .30907 L
.28703 .30907 L
.28742 .30907 L
.28765 .30907 L
.28776 .30907 L
.28786 .30907 L
.28795 .30907 L
.28804 .30907 L
.28814 .30907 L
.28824 .30907 L
.28833 .30907 L
.28844 .30907 L
.28849 .30907 L
.28855 .30907 L
.28865 .30907 L
.28874 .30907 L
.28885 .30907 L
.28907 .30907 L
.28928 .30907 L
Mistroke
.28947 .30907 L
.29036 .30907 L
.29114 .30906 L
.29198 .30905 L
.29357 .30904 L
.2953 .30902 L
.2961 .30902 L
.29695 .30901 L
.29768 .30901 L
.2981 .30901 L
.29849 .30901 L
.29887 .30901 L
.29908 .30901 L
.29928 .30901 L
.29948 .30901 L
.29959 .30901 L
.29971 .30901 L
.29981 .30901 L
.29991 .30901 L
.30001 .30901 L
.30011 .30901 L
.3002 .30901 L
.30028 .30901 L
.30038 .30901 L
.30047 .30901 L
.30056 .30901 L
.30063 .30901 L
.30081 .30901 L
.30101 .30901 L
.30119 .30901 L
.30159 .30901 L
.3024 .30901 L
.30314 .30901 L
.30481 .30901 L
.30645 .30902 L
.30725 .30902 L
.30798 .30902 L
.30873 .30902 L
.30945 .30902 L
.30984 .30902 L
.3102 .30902 L
.3106 .30902 L
.3108 .30902 L
.31103 .30902 L
.31121 .30902 L
.31142 .30902 L
.31152 .30902 L
.31158 .30902 L
.31164 .30902 L
.31174 .30902 L
Mistroke
.31184 .30902 L
.31193 .30902 L
.31202 .30902 L
.3121 .30902 L
.31219 .30902 L
.31229 .30902 L
.31239 .30902 L
.31258 .30902 L
.31279 .30902 L
.31303 .30902 L
.31345 .30902 L
.31425 .30902 L
.31597 .30902 L
.31752 .30902 L
.3183 .30902 L
.31914 .30902 L
.31993 .30902 L
.32066 .30902 L
.32143 .30902 L
.32183 .30902 L
.32227 .30902 L
.32249 .30902 L
.3226 .30902 L
.32272 .30902 L
.32283 .30902 L
.32295 .30902 L
.32305 .30902 L
.32315 .30902 L
.32325 .30902 L
.32336 .30902 L
.32345 .30902 L
.32354 .30902 L
.32365 .30902 L
.32371 .30902 L
.32376 .30902 L
.32396 .30902 L
.32415 .30902 L
.32435 .30902 L
.32476 .30902 L
.3255 .30902 L
.32717 .30902 L
.32887 .30902 L
.33042 .30902 L
.33118 .30902 L
.33159 .30902 L
.33202 .30902 L
.33239 .30902 L
.33281 .30902 L
.33318 .30902 L
.33354 .30902 L
Mistroke
.33391 .30902 L
.33413 .30902 L
.33433 .30902 L
.33443 .30902 L
.33454 .30902 L
.33463 .30902 L
.33473 .30902 L
.33478 .30902 L
.33483 .30902 L
.33489 .30902 L
.33495 .30902 L
.33505 .30902 L
.3351 .30902 L
.33516 .30902 L
.33525 .30902 L
.33534 .30902 L
.33552 .30902 L
.33573 .30902 L
.33592 .30902 L
.33664 .30902 L
.33819 .30902 L
.33986 .30902 L
.34146 .30902 L
.34227 .30902 L
.34272 .30902 L
.34315 .30902 L
.34354 .30902 L
.34397 .30902 L
.34433 .30902 L
.34472 .30902 L
.34514 .30902 L
.34537 .30902 L
.34548 .30902 L
.34559 .30902 L
.34569 .30902 L
.34579 .30902 L
.34589 .30902 L
.34598 .30902 L
.34609 .30902 L
.34618 .30902 L
.34623 .30902 L
.34629 .30902 L
.3464 .30902 L
.3465 .30902 L
.34659 .30902 L
.34669 .30902 L
.34679 .30902 L
.34716 .30902 L
.34756 .30902 L
.34799 .30902 L
Mistroke
.34968 .30902 L
.3514 .30902 L
.35295 .30902 L
.35373 .30902 L
.35414 .30902 L
.35457 .30902 L
.35495 .30902 L
.35537 .30902 L
.35575 .30902 L
.3561 .30902 L
.3563 .30902 L
.3565 .30902 L
.35673 .30902 L
.35683 .30902 L
.35694 .30902 L
.35704 .30902 L
.35714 .30902 L
.35723 .30902 L
.35732 .30902 L
.35742 .30902 L
.35752 .30902 L
.35763 .30902 L
.35768 .30902 L
.35774 .30902 L
.35783 .30902 L
.35793 .30902 L
.35811 .30902 L
.3583 .30902 L
.35851 .30902 L
.35923 .30902 L
.36093 .30902 L
.36247 .30902 L
.36324 .30902 L
.36408 .30902 L
.36486 .30902 L
.36559 .30902 L
.36597 .30902 L
.36637 .30902 L
.36671 .30902 L
.36709 .30902 L
.36751 .30902 L
.36774 .30902 L
.36785 .30902 L
.36795 .30902 L
.36805 .30902 L
.36816 .30902 L
.36825 .30902 L
.36834 .30902 L
.36843 .30902 L
.36854 .30902 L
Mistroke
.36859 .30902 L
.36864 .30902 L
.36875 .30902 L
.3688 .30902 L
.36885 .30902 L
.36895 .30902 L
.36905 .30902 L
.36917 .30902 L
.36956 .30902 L
.37002 .30902 L
.37044 .30902 L
.37206 .30902 L
.3737 .30902 L
.3745 .30902 L
.37523 .30902 L
.37599 .30902 L
.3767 .30902 L
.3771 .30902 L
.37746 .30902 L
.37786 .30902 L
.37807 .30902 L
.37828 .30902 L
.37847 .30902 L
.37868 .30902 L
.37886 .30902 L
.37904 .30902 L
.37914 .30902 L
.37924 .30902 L
.37933 .30902 L
.37943 .30902 L
.37953 .30902 L
.37959 .30902 L
.37965 .30902 L
.37975 .30902 L
.37985 .30902 L
.37994 .30902 L
.38004 .30902 L
.38022 .30902 L
.38039 .30902 L
.38056 .30902 L
.38132 .30902 L
.38294 .30902 L
.38446 .30902 L
.38592 .30902 L
.38674 .30902 L
.38749 .30902 L
.38787 .30902 L
.38828 .30902 L
.38863 .30902 L
.38901 .30902 L
Mistroke
.38924 .30902 L
.38945 .30902 L
.38966 .30902 L
.38988 .30902 L
.38997 .30902 L
.39007 .30902 L
.39016 .30902 L
.39025 .30902 L
.39031 .30902 L
.39037 .30902 L
.39047 .30902 L
.39057 .30902 L
.39067 .30902 L
.39077 .30902 L
.39082 .30902 L
.39088 .30902 L
.39098 .30902 L
.3911 .30902 L
.39131 .30902 L
.39149 .30902 L
.39239 .30902 L
.39401 .30902 L
.39567 .30902 L
.3964 .30902 L
.39721 .30902 L
.39798 .30902 L
.3987 .30902 L
.3991 .30902 L
.39946 .30902 L
.39986 .30902 L
.40008 .30902 L
.40028 .30902 L
.40048 .30902 L
.40069 .30902 L
.40078 .30902 L
.40088 .30902 L
.40097 .30902 L
.40105 .30902 L
.40115 .30902 L
.40125 .30902 L
.40135 .30902 L
.40144 .30902 L
.40149 .30902 L
.40155 .30902 L
.40165 .30902 L
.40171 .30902 L
.40176 .30902 L
.40187 .30902 L
.40205 .30902 L
.40224 .30902 L
Mistroke
.40258 .30902 L
.40334 .30902 L
.40494 .30902 L
.4064 .30902 L
.40715 .30902 L
.40797 .30902 L
.40841 .30902 L
.40883 .30902 L
.40922 .30902 L
.40965 .30902 L
.41005 .30902 L
.41042 .30902 L
.41079 .30902 L
.41115 .30902 L
.41135 .30902 L
.41146 .30902 L
.41156 .30902 L
.41165 .30902 L
.41176 .30902 L
.41185 .30902 L
.41194 .30902 L
.41204 .30902 L
.41214 .30902 L
.41225 .30902 L
.4123 .30902 L
.41236 .30902 L
.41242 .30902 L
.41247 .30902 L
.41259 .30902 L
.4128 .30902 L
.413 .30902 L
.41317 .30902 L
.41357 .30902 L
.4143 .30902 L
.41595 .30902 L
.41747 .30902 L
.41833 .30902 L
.41913 .30902 L
.41954 .30902 L
.41998 .30902 L
.42036 .30902 L
.42077 .30902 L
.42114 .30902 L
.42134 .30902 L
.42155 .30902 L
.42174 .30902 L
.42192 .30902 L
.4221 .30902 L
.42226 .30902 L
.42236 .30902 L
Mistroke
.42247 .30902 L
.42257 .30902 L
.42267 .30902 L
.42275 .30902 L
.42285 .30902 L
.42294 .30902 L
.42303 .30902 L
.42309 .30902 L
.42314 .30902 L
.42324 .30902 L
.42343 .30902 L
.42365 .30902 L
.42386 .30902 L
.42533 .30902 L
.42696 .30902 L
.42776 .30902 L
.42849 .30902 L
.4292 .30902 L
.42995 .30902 L
.4307 .30902 L
.43112 .30902 L
.43152 .30902 L
.43193 .30902 L
.43215 .30902 L
.43237 .30902 L
.43255 .30902 L
.43275 .30902 L
.43286 .30902 L
.43296 .30902 L
.43307 .30902 L
.43316 .30902 L
.43326 .30902 L
.43335 .30902 L
.43345 .30902 L
.43353 .30902 L
.43363 .30902 L
.43368 .30902 L
.43374 .30902 L
.43393 .30902 L
.4341 .30902 L
.43428 .30902 L
.43466 .30902 L
.43636 .30902 L
.43791 .30902 L
.43868 .30902 L
.43952 .30902 L
.44031 .30902 L
.44104 .30902 L
.44141 .30902 L
.44181 .30902 L
Mistroke
.44219 .30902 L
.44254 .30902 L
.44275 .30902 L
.44295 .30902 L
.44316 .30902 L
.44328 .30902 L
.44339 .30902 L
.44349 .30902 L
.44359 .30902 L
.44369 .30902 L
.44375 .30902 L
.4438 .30902 L
.4439 .30902 L
.44401 .30902 L
.44411 .30902 L
.4442 .30902 L
.44438 .30902 L
.44458 .30902 L
.44499 .30902 L
.44573 .30902 L
.44739 .30902 L
.44895 .30902 L
.44982 .30902 L
.45021 .30902 L
.45062 .30902 L
.45103 .30902 L
.45141 .30902 L
.45179 .30902 L
.45214 .30902 L
.45255 .30902 L
.45277 .30902 L
.45299 .30902 L
.45318 .30902 L
.45338 .30902 L
.45349 .30902 L
.4536 .30902 L
.4537 .30902 L
.4538 .30902 L
.4539 .30902 L
.454 .30902 L
.4541 .30902 L
.45418 .30902 L
.45428 .30902 L
.45438 .30902 L
.45444 .30902 L
.45449 .30902 L
.45459 .30902 L
.45479 .30902 L
.45498 .30902 L
.45533 .30902 L
Mistroke
.45613 .30902 L
.45699 .30902 L
.45855 .30902 L
.45944 .30902 L
.46027 .30902 L
.46066 .30902 L
.46106 .30902 L
.46179 .30902 L
.46219 .30902 L
.46257 .30902 L
.46298 .30902 L
.46322 .30902 L
.46343 .30902 L
.46361 .30902 L
.46382 .30902 L
.46392 .30902 L
.46403 .30902 L
.46413 .30902 L
.46423 .30902 L
.46432 .30902 L
.46441 .30902 L
.46451 .30902 L
.46461 .30902 L
.4647 .30902 L
.46478 .30902 L
.46487 .30902 L
.46497 .30902 L
.46517 .30902 L
.46539 .30902 L
.46584 .30902 L
.46664 .30902 L
.46834 .30902 L
.46915 .30902 L
.46989 .30902 L
.47066 .30902 L
.47106 .30902 L
.4715 .30902 L
.47186 .30902 L
.47224 .30902 L
.47264 .30902 L
.47302 .30902 L
.47323 .30902 L
.47344 .30902 L
.47363 .30902 L
.47383 .30902 L
.47396 .30902 L
.47407 .30902 L
.47418 .30902 L
.4743 .30902 L
.47441 .30902 L
Mistroke
.4745 .30902 L
.47461 .30902 L
.47467 .30902 L
.47472 .30902 L
.47482 .30902 L
.47487 .30902 L
.47493 .30902 L
.47503 .30902 L
.47512 .30902 L
.47533 .30902 L
.47555 .30902 L
.47596 .30902 L
.47633 .30902 L
.47798 .30902 L
.47879 .30902 L
.47952 .30902 L
.48023 .30902 L
.481 .30902 L
.48142 .30902 L
.48181 .30902 L
.48221 .30902 L
.48258 .30902 L
.48295 .30902 L
.48314 .30902 L
.48335 .30902 L
.48355 .30902 L
.48373 .30902 L
.4839 .30902 L
.48408 .30902 L
.4842 .30902 L
.4843 .30902 L
.4844 .30902 L
.4845 .30902 L
.4846 .30902 L
.48469 .30902 L
.48478 .30902 L
.48489 .30902 L
.48494 .30902 L
.485 .30902 L
.48505 .30902 L
.48512 .30902 L
.48522 .30902 L
.48533 .30902 L
.48554 .30902 L
.48574 .30902 L
.48657 .30902 L
.48736 .30902 L
.48885 .30902 L
.48962 .30902 L
.49044 .30902 L
Mistroke
.49121 .30902 L
.49192 .30902 L
.49231 .30902 L
.49272 .30902 L
.49307 .30902 L
.49346 .30902 L
.49368 .30902 L
.49388 .30902 L
.49411 .30902 L
.49421 .30902 L
.49432 .30902 L
.49442 .30902 L
.49452 .30902 L
.49462 .30902 L
.49471 .30902 L
.49482 .30902 L
.49491 .30902 L
.49496 .30902 L
.49502 .30902 L
.49508 .30902 L
.49513 .30902 L
.49523 .30902 L
.49528 .30902 L
.49534 .30902 L
.49554 .30902 L
.49576 .30902 L
.49597 .30902 L
.49677 .30902 L
.49826 .30902 L
.4991 .30902 L
.49989 .30902 L
.5006 .30902 L
.50138 .30902 L
.50181 .30902 L
.50221 .30902 L
.50257 .30902 L
.50296 .30902 L
.50339 .30902 L
.5036 .30902 L
.50384 .30902 L
.50404 .30902 L
.50415 .30902 L
.50425 .30902 L
.50435 .30902 L
.50446 .30902 L
.50455 .30902 L
.50464 .30902 L
.50474 .30902 L
.50484 .30902 L
.50492 .30902 L
Mistroke
.50502 .30902 L
.50512 .30902 L
.50517 .30902 L
.50522 .30902 L
.50532 .30902 L
.50542 .30902 L
.50577 .30902 L
.50614 .30902 L
.5078 .30902 L
.50937 .30902 L
.51025 .30902 L
.51068 .30902 L
.51109 .30902 L
.51147 .30902 L
.51188 .30902 L
.51223 .30902 L
.51261 .30902 L
.51303 .30902 L
.51325 .30902 L
.51346 .30902 L
.51365 .30902 L
.51384 .30902 L
.51406 .30902 L
.51425 .30902 L
.51435 .30902 L
.51446 .30902 L
.51456 .30902 L
.51465 .30902 L
.51474 .30902 L
.51483 .30902 L
.51493 .30902 L
.51502 .30902 L
.51512 .30902 L
.51522 .30902 L
.51541 .30902 L
.51561 .30902 L
.51583 .30902 L
.51731 .30902 L
.51819 .30902 L
.51902 .30902 L
.51976 .30902 L
.52015 .30902 L
.52057 .30902 L
.52137 .30902 L
.5218 .30902 L
.52221 .30902 L
.52259 .30902 L
.52293 .30902 L
.52312 .30902 L
.52333 .30902 L
Mistroke
.52353 .30902 L
.52371 .30902 L
.5239 .30902 L
.524 .30902 L
.5241 .30902 L
.52419 .30902 L
.52428 .30902 L
.52438 .30902 L
.52447 .30902 L
.52452 .30902 L
.52457 .30902 L
.52463 .30902 L
.52469 .30902 L
.52479 .30902 L
.52485 .30902 L
.5249 .30902 L
.525 .30902 L
.52509 .30902 L
.5253 .30902 L
.52551 .30902 L
.52571 .30902 L
.52616 .30902 L
.52699 .30902 L
.5285 .30902 L
.52935 .30902 L
.53013 .30902 L
.53053 .30902 L
.53097 .30902 L
.53143 .30902 L
.53185 .30902 L
.53226 .30902 L
.53264 .30902 L
.53284 .30902 L
.53307 .30902 L
.53326 .30902 L
.53347 .30902 L
.53368 .30902 L
.53377 .30902 L
.53386 .30902 L
.53395 .30902 L
.53404 .30902 L
.53414 .30902 L
.53423 .30902 L
.53429 .30902 L
.53434 .30902 L
.5344 .30902 L
.53446 .30902 L
.53456 .30902 L
.53461 .30902 L
.53467 .30902 L
Mistroke
.53477 .30902 L
.53486 .30902 L
.53506 .30902 L
.53528 .30902 L
.53548 .30902 L
.53593 .30902 L
.53675 .30902 L
.53753 .30902 L
.53838 .30902 L
.53917 .30902 L
.5399 .30902 L
.54061 .30902 L
.541 .30902 L
.54138 .30902 L
.54177 .30902 L
.54213 .30902 L
.54232 .30902 L
.54254 .30902 L
.54293 .30902 L
.54312 .30902 L
.54332 .30902 L
.54351 .30902 L
.54369 .30902 L
.54379 .30902 L
.54389 .30902 L
.54395 .30902 L
.544 .30902 L
.54406 .30902 L
.54412 .30902 L
.54422 .30902 L
.54431 .30902 L
.54441 .30902 L
.54447 .30902 L
.54452 .30902 L
.54474 .30902 L
.54494 .30902 L
.5454 .30902 L
.54621 .30902 L
.54702 .30902 L
.54787 .30902 L
.54867 .30902 L
.54941 .30902 L
.55012 .30902 L
.55051 .30902 L
.55088 .30902 L
.55125 .30902 L
.55166 .30902 L
.55187 .30902 L
.55209 .30902 L
.55249 .30902 L
Mistroke
.5527 .30902 L
.55292 .30902 L
.55311 .30902 L
.55321 .30902 L
.55331 .30902 L
.55343 .30902 L
.55349 .30902 L
.55354 .30902 L
.55364 .30902 L
.55369 .30902 L
.55374 .30902 L
.5538 .30902 L
.55387 .30902 L
.55393 .30902 L
.55399 .30902 L
.55404 .30902 L
.55409 .30902 L
.55421 .30902 L
.55442 .30902 L
.55461 .30902 L
.55504 .30902 L
.55582 .30902 L
.55663 .30902 L
.55749 .30902 L
.55822 .30902 L
.55864 .30902 L
.55903 .30902 L
.55979 .30902 L
.56022 .30902 L
.56062 .30902 L
.56099 .30902 L
.56133 .30902 L
.56171 .30902 L
.56192 .30902 L
.56211 .30902 L
.56231 .30902 L
.5625 .30902 L
.5627 .30902 L
.5628 .30902 L
.56292 .30902 L
.56301 .30902 L
.56311 .30902 L
.56321 .30902 L
.5633 .30902 L
.56338 .30902 L
.56347 .30902 L
.56357 .30902 L
.56366 .30902 L
.56375 .30902 L
.56386 .30902 L
Mistroke
.56408 .30902 L
.56446 .30902 L
.56533 .30902 L
.5662 .30902 L
.56703 .30902 L
.56778 .30902 L
.56816 .30902 L
.56858 .30902 L
.56937 .30902 L
.56981 .30902 L
.57021 .30902 L
.57059 .30902 L
.57094 .30902 L
.57113 .30902 L
.57134 .30902 L
.57153 .30902 L
.57172 .30902 L
.57192 .30902 L
.57203 .30902 L
.57214 .30902 L
.57234 .30902 L
.57245 .30902 L
.57255 .30902 L
.57264 .30902 L
.57274 .30902 L
.57282 .30902 L
.57291 .30902 L
.57301 .30902 L
.57311 .30902 L
.5732 .30902 L
.5733 .30902 L
.57352 .30902 L
.57372 .30902 L
.57417 .30902 L
.57498 .30902 L
.57578 .30902 L
.57663 .30902 L
.57744 .30902 L
.57817 .30902 L
.57856 .30902 L
.57892 .30902 L
.57932 .30902 L
.57974 .30902 L
.58011 .30902 L
.58045 .30902 L
.58083 .30902 L
.58104 .30902 L
.58123 .30902 L
.58141 .30902 L
.58161 .30902 L
Mistroke
.58171 .30902 L
.58182 .30902 L
.58193 .30902 L
.58202 .30902 L
.58211 .30902 L
.58219 .30902 L
.58228 .30902 L
.58238 .30902 L
.58248 .30902 L
.58258 .30902 L
.58266 .30902 L
.58276 .30902 L
.58296 .30902 L
.58318 .30902 L
.58362 .30902 L
.58442 .30902 L
.58529 .30902 L
.58611 .30902 L
.58685 .30902 L
.58727 .30902 L
.58766 .30902 L
.58803 .30902 L
.58844 .30902 L
.58887 .30902 L
.58927 .30902 L
.58965 .30902 L
.58986 .30902 L
.59005 .30902 L
.5904 .30902 L
.59058 .30902 L
.59077 .30902 L
.59098 .30902 L
.59108 .30902 L
.5912 .30902 L
.59129 .30902 L
.5914 .30902 L
.5915 .30902 L
.59159 .30902 L
.59164 .30902 L
.5917 .30902 L
.5918 .30902 L
.59186 .30902 L
.59191 .30902 L
.59202 .30902 L
.59214 .30902 L
.59224 .30902 L
.59248 .30902 L
.59409 .30902 L
.59482 .30902 L
.5956 .30902 L
Mistroke
.59605 .30902 L
.59646 .30902 L
.59684 .30902 L
.59726 .30902 L
.59767 .30902 L
.59805 .30902 L
.59843 .30902 L
.59878 .30902 L
.59899 .30902 L
.5992 .30902 L
.59958 .30902 L
.5998 .30902 L
.6 .30902 L
.60022 .30902 L
.60034 .30902 L
.60045 .30902 L
.60054 .30902 L
.60063 .30902 L
.60073 .30902 L
.60084 .30902 L
.60089 .30902 L
.60095 .30902 L
.60105 .30902 L
.60115 .30902 L
.60125 .30902 L
.60134 .30902 L
.60143 .30902 L
.6016 .30902 L
.60198 .30902 L
.60365 .30902 L
.60444 .30902 L
.60526 .30902 L
.60597 .30902 L
.60637 .30902 L
.60675 .30902 L
.60715 .30902 L
.60758 .30902 L
.608 .30902 L
.60838 .30902 L
.60872 .30902 L
.60892 .30902 L
.6091 .30902 L
.60929 .30902 L
.60947 .30902 L
.60966 .30902 L
.60976 .30902 L
.60981 .30902 L
.60987 .30902 L
.60997 .30902 L
.61007 .30902 L
Mistroke
.61018 .30902 L
.61023 .30902 L
.61029 .30902 L
.61039 .30902 L
.61048 .30902 L
.61059 .30902 L
.61069 .30902 L
.61105 .30902 L
.61144 .30902 L
.61312 .30902 L
.61394 .30902 L
.6147 .30902 L
.61513 .30902 L
.61559 .30902 L
.616 .30902 L
.61639 .30902 L
.61676 .30902 L
.61717 .30902 L
.61755 .30902 L
.6179 .30902 L
.61811 .30902 L
.61831 .30902 L
.61852 .30902 L
.61863 .30902 L
.61875 .30902 L
.61885 .30902 L
.61895 .30902 L
.61901 .30902 L
.61906 .30902 L
.61917 .30902 L
.61927 .30902 L
.61937 .30902 L
.61947 .30902 L
.61956 .30902 L
.61965 .30902 L
.61974 .30902 L
.61995 .30902 L
.62015 .30902 L
.62036 .30902 L
.6211 .30902 L
.62277 .30902 L
.62359 .30902 L
.62405 .30902 L
.62447 .30902 L
.62488 .30902 L
.62525 .30902 L
.62565 .30902 L
.62609 .30902 L
.62646 .30902 L
.62687 .30902 L
Mistroke
.62708 .30902 L
.6273 .30902 L
.62751 .30902 L
.6277 .30902 L
.6278 .30902 L
.62789 .30902 L
.62798 .30902 L
.62807 .30902 L
.62817 .30902 L
.62826 .30902 L
.62831 .30902 L
.62837 .30902 L
.62847 .30902 L
.62855 .30902 L
.62865 .30902 L
.62873 .30902 L
.62881 .30902 L
.6289 .30902 L
.62901 .30902 L
.62919 .30902 L
.63076 .30902 L
.63159 .30902 L
.63205 .30902 L
.63248 .30902 L
.63289 .30902 L
.63334 .30902 L
.63371 .30902 L
.63412 .30902 L
.6345 .30902 L
.63491 .30902 L
.63529 .30902 L
.63565 .30902 L
.63603 .30902 L
.63624 .30902 L
.63644 .30902 L
.63665 .30902 L
.63684 .30902 L
.63695 .30902 L
.63706 .30902 L
.63717 .30902 L
.63727 .30902 L
.63735 .30902 L
.63745 .30902 L
.63753 .30902 L
.63761 .30902 L
.63771 .30902 L
.63781 .30902 L
.6379 .30902 L
.63799 .30902 L
.63818 .30902 L
Mistroke
.63836 .30902 L
.63875 .30902 L
.63957 .30902 L
.64043 .30902 L
.64123 .30902 L
.64197 .30902 L
.64269 .30902 L
.64309 .30902 L
.64345 .30902 L
.64385 .30902 L
.64429 .30902 L
.64448 .30902 L
.64469 .30902 L
.64507 .30902 L
.64527 .30902 L
.64547 .30902 L
.64564 .30902 L
.64583 .30902 L
.64603 .30902 L
.64614 .30902 L
.64625 .30902 L
.64634 .30902 L
.64645 .30902 L
.64655 .30902 L
.64664 .30902 L
.64672 .30902 L
.64682 .30902 L
.6469 .30902 L
.64698 .30902 L
.64717 .30902 L
.64735 .30902 L
.64811 .30902 L
.64957 .30902 L
.6504 .30902 L
.65081 .30902 L
.65118 .30902 L
.65155 .30902 L
.65194 .30902 L
.65234 .30902 L
.65277 .30902 L
.65319 .30902 L
.65343 .30902 L
.65364 .30902 L
.65384 .30902 L
.65406 .30902 L
.65425 .30902 L
.65445 .30902 L
.65466 .30902 L
.65484 .30902 L
.65493 .30902 L
Mistroke
.65503 .30902 L
.65512 .30902 L
.65521 .30902 L
.65526 .30902 L
.65532 .30902 L
.65542 .30902 L
.65548 .30902 L
.65554 .30902 L
.65559 .30902 L
.65564 .30902 L
.65574 .30902 L
.6558 .30902 L
.65585 .30902 L
.65605 .30902 L
.65626 .30902 L
.65646 .30902 L
.65691 .30902 L
.65773 .30902 L
.65846 .30902 L
.65923 .30902 L
.65968 .30902 L
.66009 .30902 L
.66047 .30902 L
.66089 .30902 L
.6613 .30902 L
.66168 .30902 L
.66205 .30902 L
.66241 .30902 L
.66261 .30902 L
.66282 .30902 L
.66301 .30902 L
.66321 .30902 L
.66342 .30902 L
.66362 .30902 L
.66374 .30902 L
.66385 .30902 L
.66396 .30902 L
.66407 .30902 L
.66412 .30902 L
.66418 .30902 L
.66428 .30902 L
.66438 .30902 L
.66444 .30902 L
.6645 .30902 L
.6646 .30902 L
.66469 .30902 L
.66474 .30902 L
.6648 .30902 L
.6649 .30902 L
.66509 .30902 L
Mistroke
.66529 .30902 L
.66565 .30902 L
.66647 .30902 L
.66734 .30902 L
.66816 .30902 L
.66891 .30902 L
.66927 .30902 L
.66966 .30902 L
.67 .30902 L
.67037 .30902 L
.6708 .30902 L
.671 .30902 L
.6712 .30902 L
.67139 .30902 L
.67159 .30902 L
.67195 .30902 L
.67217 .30902 L
.67237 .30902 L
.67248 .30902 L
.6726 .30902 L
.67271 .30902 L
.67282 .30902 L
.67293 .30902 L
.67303 .30902 L
.67313 .30902 L
.67319 .30902 L
.67325 .30902 L
.67334 .30902 L
.67344 .30902 L
.67354 .30902 L
.67364 .30902 L
.67374 .30902 L
.67385 .30902 L
.67404 .30902 L
.67448 .30902 L
.67528 .30902 L
.67606 .30902 L
.67677 .30902 L
.67753 .30902 L
.67794 .30902 L
.67834 .30902 L
.67868 .30902 L
.67904 .30902 L
.67944 .30902 L
.67981 .30902 L
.68002 .30902 L
.68024 .30902 L
.68064 .30902 L
.68086 .30902 L
.68106 .30902 L
Mistroke
.68129 .30902 L
.68142 .30902 L
.68153 .30902 L
.68163 .30902 L
.68174 .30902 L
.68183 .30902 L
.68193 .30902 L
.68199 .30902 L
.68204 .30902 L
.68209 .30902 L
.68215 .30902 L
.68225 .30902 L
.68231 .30902 L
.68236 .30902 L
.68247 .30902 L
.68256 .30902 L
.68274 .30902 L
.68315 .30902 L
.68462 .30902 L
.68546 .30902 L
.68587 .30902 L
.68624 .30902 L
.68661 .30902 L
.68701 .30902 L
.68744 .30902 L
.68784 .30902 L
.68826 .30902 L
.68848 .30902 L
.68872 .30902 L
.68892 .30902 L
.68914 .30902 L
.68934 .30902 L
.68953 .30902 L
.68972 .30902 L
.68993 .30902 L
.69012 .30902 L
.6903 .30902 L
.6904 .30902 L
.69051 .30902 L
.6906 .30902 L
.6907 .30902 L
.69076 .30902 L
.69081 .30902 L
.69087 .30902 L
.69092 .30902 L
.69103 .30902 L
.69108 .30902 L
.69114 .30902 L
.69136 .30902 L
.69157 .30902 L
Mistroke
.69195 .30902 L
.69283 .30902 L
.69361 .30902 L
.69444 .30902 L
.69515 .30902 L
.69555 .30902 L
.69592 .30902 L
.69633 .30902 L
.69676 .30902 L
.69718 .30902 L
.69756 .30902 L
.6979 .30902 L
.6981 .30902 L
.69828 .30902 L
.69847 .30902 L
.69865 .30902 L
.69884 .30902 L
.69894 .30902 L
.69905 .30902 L
.69915 .30902 L
.69925 .30902 L
.6993 .30902 L
.69936 .30902 L
.69942 .30902 L
.69947 .30902 L
.69957 .30902 L
.69966 .30902 L
.69972 .30902 L
.69977 .30902 L
.69987 .30902 L
.70006 .30902 L
.70026 .30902 L
.70062 .30902 L
.7023 .30902 L
.70313 .30902 L
.7036 .30902 L
.70403 .30902 L
.7044 .30902 L
.70481 .30902 L
.70524 .30902 L
.70565 .30902 L
.70605 .30902 L
.70628 .30902 L
.70649 .30902 L
.70669 .30902 L
.70687 .30902 L
.70707 .30902 L
.70728 .30902 L
.70738 .30902 L
.70748 .30902 L
Mistroke
.70756 .30902 L
.70766 .30902 L
.70775 .30902 L
.70784 .30902 L
.70792 .30902 L
.708 .30902 L
.7081 .30902 L
.70819 .30902 L
.70828 .30902 L
.70837 .30902 L
.70847 .30902 L
.70858 .30902 L
.70877 .30902 L
.71036 .30902 L
.7112 .30902 L
.71166 .30902 L
.71209 .30902 L
.7125 .30902 L
.71288 .30902 L
.7133 .30902 L
.71375 .30902 L
.71411 .30902 L
.7145 .30902 L
.7147 .30902 L
.71491 .30902 L
.71529 .30902 L
.7155 .30902 L
.71572 .30902 L
.7159 .30902 L
.71611 .30902 L
.71623 .30902 L
.71633 .30902 L
.71639 .30902 L
.71645 .30902 L
.71651 .30902 L
.71657 .30902 L
.71663 .30902 L
.71668 .30902 L
.71673 .30902 L
.71679 .30902 L
.71685 .30902 L
.7169 .30902 L
.717 .30902 L
.7171 .30902 L
.71719 .30902 L
.7174 .30902 L
.71777 .30902 L
.71862 .30902 L
.71936 .30902 L
.72015 .30902 L
Mistroke
.72056 .30902 L
.72102 .30902 L
.72143 .30902 L
.72182 .30902 L
.7222 .30902 L
.72261 .30902 L
.72282 .30902 L
.72304 .30902 L
.72344 .30902 L
.72363 .30902 L
.72384 .30902 L
.72402 .30902 L
.72422 .30902 L
.72439 .30902 L
.72459 .30902 L
.72467 .30902 L
.72476 .30902 L
.72485 .30902 L
.72493 .30902 L
.72498 .30902 L
.72503 .30902 L
.72513 .30902 L
.72519 .30902 L
.72524 .30902 L
.72535 .30902 L
.72545 .30902 L
.72554 .30902 L
.72563 .30902 L
.72574 .30902 L
.72598 .30902 L
.7262 .30902 L
.72663 .30902 L
.72741 .30902 L
.72824 .30902 L
.729 .30902 L
.72944 .30902 L
.72984 .30902 L
.73021 .30902 L
.73056 .30902 L
.73096 .30902 L
.73132 .30902 L
.73153 .30902 L
.73173 .30902 L
.73209 .30902 L
.7323 .30902 L
.73249 .30902 L
.73269 .30902 L
.73291 .30902 L
.73309 .30902 L
.73319 .30902 L
Mistroke
.73328 .30902 L
.73336 .30902 L
.73346 .30902 L
.73354 .30902 L
.73362 .30902 L
.73371 .30902 L
.7338 .30902 L
.73389 .30902 L
.73399 .30902 L
.73409 .30902 L
.7342 .30902 L
.73439 .30902 L
.73599 .30902 L
.73669 .30902 L
.73745 .30902 L
.73787 .30902 L
.73826 .30902 L
.73863 .30902 L
.73902 .30902 L
.73944 .30902 L
.73982 .30902 L
.74004 .30902 L
.74025 .30902 L
.74049 .30902 L
.7407 .30902 L
.74089 .30902 L
.74109 .30902 L
.7413 .30902 L
.74139 .30902 L
.7415 .30902 L
.74168 .30902 L
.74178 .30902 L
.74188 .30902 L
.74197 .30902 L
.74205 .30902 L
.74214 .30902 L
.74223 .30902 L
.74233 .30902 L
.74243 .30902 L
.74248 .30902 L
.74254 .30902 L
.74264 .30902 L
.74284 .30902 L
.74303 .30902 L
.74389 .30902 L
.74463 .30902 L
.74542 .30902 L
.74587 .30902 L
.74628 .30902 L
.74666 .30902 L
Mistroke
.74708 .30902 L
.74747 .30902 L
.74788 .30902 L
.74826 .30902 L
.74862 .30902 L
.74884 .30902 L
.74904 .30902 L
.74923 .30902 L
.74943 .30902 L
.74964 .30902 L
.74984 .30902 L
.74995 .30902 L
.75006 .30902 L
.75017 .30902 L
.75029 .30902 L
.75039 .30902 L
.75048 .30902 L
.75059 .30902 L
.75069 .30902 L
.75078 .30902 L
.75087 .30902 L
.75096 .30902 L
.75106 .30902 L
.75127 .30902 L
.75146 .30902 L
.7519 .30902 L
.75277 .30902 L
.75359 .30902 L
.75437 .30902 L
.75481 .30902 L
.75522 .30902 L
.7556 .30902 L
.75594 .30902 L
.75633 .30902 L
.75671 .30902 L
.75708 .30902 L
.75729 .30902 L
.75749 .30902 L
.7577 .30902 L
.75789 .30902 L
.75811 .30902 L
.75821 .30902 L
.75832 .30902 L
.7585 .30902 L
.75859 .30902 L
.75869 .30902 L
.75877 .30902 L
.75885 .30902 L
.75894 .30902 L
.75903 .30902 L
Mistroke
.75912 .30902 L
.75922 .30902 L
.75931 .30902 L
.7594 .30902 L
.7596 .30902 L
.7598 .30902 L
.76127 .30902 L
.76168 .30902 L
.76211 .30902 L
.76289 .30902 L
.76332 .30902 L
.76372 .30902 L
.76409 .30902 L
.76449 .30902 L
.76491 .30902 L
.76515 .30902 L
.76536 .30902 L
.76556 .30902 L
.76578 .30902 L
.76599 .30902 L
.76618 .30902 L
.76637 .30902 L
.76655 .30902 L
.76665 .30902 L
.76676 .30902 L
.76687 .30902 L
.76696 .30902 L
.76705 .30902 L
.76713 .30902 L
.76722 .30902 L
.76731 .30902 L
.76742 .30902 L
.76751 .30902 L
.7676 .30902 L
.76769 .30902 L
.76791 .30902 L
.76811 .30902 L
.76855 .30902 L
.76935 .30902 L
.7701 .30902 L
.77089 .30902 L
.77131 .30902 L
.77176 .30902 L
.77218 .30902 L
.77257 .30902 L
.77297 .30902 L
.77319 .30902 L
.7734 .30902 L
.77379 .30902 L
.77398 .30902 L
Mistroke
.7742 .30902 L
.77439 .30902 L
.77457 .30902 L
.77476 .30902 L
.77486 .30902 L
.77497 .30902 L
.77506 .30902 L
.77514 .30902 L
.77523 .30902 L
.77531 .30902 L
.7754 .30902 L
.7755 .30902 L
.77559 .30902 L
.77569 .30902 L
.77578 .30902 L
.77589 .30902 L
.77599 .30902 L
.77608 .30902 L
.77644 .30902 L
.77726 .30902 L
.77796 .30902 L
.77873 .30902 L
.77917 .30902 L
.77958 .30902 L
.77997 .30902 L
.78038 .30902 L
.78075 .30902 L
.78109 .30902 L
.78147 .30902 L
.78168 .30902 L
.78187 .30902 L
.78226 .30902 L
.78245 .30902 L
.78267 .30902 L
.78285 .30902 L
.78305 .30902 L
.78314 .30902 L
.78323 .30902 L
.78332 .30902 L
.7834 .30902 L
.78351 .30902 L
.7836 .30902 L
.78371 .30902 L
.78376 .30902 L
.78382 .30902 L
.78391 .30902 L
.784 .30902 L
.78411 .30902 L
.7842 .30902 L
.78442 .30902 L
Mistroke
.78462 .30902 L
.78507 .30902 L
.78588 .30902 L
.78673 .30902 L
.78746 .30902 L
.78788 .30902 L
.78827 .30902 L
.78864 .30902 L
.78904 .30902 L
.78937 .30902 L
.78974 .30902 L
.78995 .30902 L
.79014 .30902 L
.79035 .30902 L
.79057 .30902 L
.79078 .30902 L
.79097 .30902 L
.79115 .30902 L
.79134 .30902 L
.79144 .30902 L
.79154 .30902 L
.79164 .30902 L
.79173 .30902 L
.79183 .30902 L
.79191 .30902 L
.792 .30902 L
.79209 .30902 L
.79219 .30902 L
.7923 .30902 L
.79239 .30902 L
.79249 .30902 L
.79291 .30902 L
.79438 .30902 L
.7948 .30902 L
.7952 .30902 L
.79556 .30902 L
.79594 .30902 L
.79636 .30902 L
.79675 .30902 L
.79716 .30902 L
.7974 .30902 L
.79762 .30902 L
.798 .30902 L
.79821 .30902 L
.79841 .30902 L
.79862 .30902 L
.79881 .30902 L
.79904 .30902 L
.79924 .30902 L
.79942 .30902 L
Mistroke
.79951 .30902 L
.79961 .30902 L
.7997 .30902 L
.79979 .30902 L
.79988 .30902 L
.79995 .30902 L
.80005 .30902 L
.80014 .30902 L
.80024 .30902 L
.8003 .30902 L
.80035 .30902 L
.80044 .30902 L
.80054 .30902 L
.80073 .30902 L
.8023 .30902 L
.80273 .30902 L
.80319 .30902 L
.80362 .30902 L
.80402 .30902 L
.80443 .30902 L
.80488 .30902 L
.80527 .30902 L
.80547 .30902 L
.80568 .30902 L
.80588 .30902 L
.80606 .30902 L
.8064 .30902 L
.80659 .30902 L
.80679 .30902 L
.807 .30902 L
.8072 .30902 L
.8073 .30902 L
.80741 .30902 L
.8076 .30902 L
.80771 .30902 L
.80781 .30902 L
.80792 .30902 L
.80799 .30902 L
.80804 .30902 L
.80815 .30902 L
.80824 .30902 L
.80834 .30902 L
.8084 .30902 L
.80845 .30902 L
.80855 .30902 L
.80865 .30902 L
.80884 .30902 L
.80922 .30902 L
.80962 .30902 L
.81034 .30902 L
Mistroke
.8111 .30902 L
.81153 .30902 L
.81192 .30902 L
.81228 .30902 L
.81268 .30902 L
.81305 .30902 L
.81339 .30902 L
.81377 .30902 L
.81398 .30902 L
.81417 .30902 L
.81435 .30902 L
.81454 .30902 L
.81472 .30902 L
.8149 .30902 L
.81511 .30902 L
.81531 .30902 L
.81553 .30902 L
.81565 .30902 L
.81576 .30902 L
.81584 .30902 L
.81594 .30902 L
.81605 .30902 L
.81614 .30902 L
.8162 .30902 L
.81625 .30902 L
.81636 .30902 L
.81646 .30902 L
.81655 .30902 L
.81665 .30902 L
.81675 .30902 L
.81693 .30902 L
.81733 .30902 L
.81805 .30902 L
.81885 .30902 L
.81929 .30902 L
.81971 .30902 L
.82011 .30902 L
.82054 .30902 L
.82093 .30902 L
.82129 .30902 L
.82163 .30902 L
.82201 .30902 L
.8222 .30902 L
.8224 .30902 L
.82277 .30902 L
.82297 .30902 L
.82319 .30902 L
.8234 .30902 L
.82358 .30902 L
.8237 .30902 L
Mistroke
.8238 .30902 L
.82392 .30902 L
.82398 .30902 L
.82404 .30902 L
.82409 .30902 L
.82414 .30902 L
.82424 .30902 L
.8243 .30902 L
.82436 .30902 L
.82442 .30902 L
.82447 .30902 L
.82456 .30902 L
.82466 .30902 L
.82475 .30902 L
.82484 .30902 L
.82525 .30902 L
.82608 .30902 L
.82682 .30902 L
.82761 .30902 L
.82806 .30902 L
.82847 .30902 L
.82888 .30902 L
.82927 .30902 L
.82964 .30902 L
.82985 .30902 L
.83005 .30902 L
.83045 .30902 L
.83068 .30902 L
.83088 .30902 L
.83107 .30902 L
.83124 .30902 L
.83144 .30902 L
.83154 .30902 L
.83164 .30902 L
.83173 .30902 L
.83182 .30902 L
.8319 .30902 L
.83198 .30902 L
.83207 .30902 L
.83217 .30902 L
.83226 .30902 L
.83236 .30902 L
.83246 .30902 L
.83252 .30902 L
.83257 .30902 L
.83268 .30902 L
.83279 .30902 L
.83318 .30902 L
.83408 .30902 L
.83491 .30902 L
Mistroke
.83569 .30902 L
.83609 .30902 L
.83651 .30902 L
.83675 .30902 L
.83697 .30902 L
.83718 .30902 L
.83739 .30902 L
.83758 .30902 L
.8378 .30902 L
.83817 .30902 L
.83838 .30902 L
.8386 .30902 L
.83881 .30902 L
.83901 .30902 L
.83919 .30902 L
.83939 .30902 L
.83949 .30902 L
.8396 .30902 L
.8397 .30902 L
.8398 .30902 L
.8399 .30902 L
.83999 .30902 L
.84009 .30902 L
.84019 .30902 L
.84028 .30902 L
.84037 .30902 L
.84045 .30902 L
.84054 .30902 L
.84064 .30902 L
.84074 .30902 L
.84096 .30902 L
.84141 .30902 L
.84221 .30902 L
.84261 .30902 L
.84304 .30902 L
.84343 .30902 L
.84384 .30902 L
.84421 .30902 L
.84461 .30902 L
.84498 .30902 L
.84533 .30902 L
.8457 .30902 L
.84592 .30902 L
.84611 .30902 L
.84632 .30902 L
.84652 .30902 L
.84674 .30902 L
.84694 .30902 L
.84712 .30902 L
.84731 .30902 L
Mistroke
.84748 .30902 L
.84766 .30902 L
.84776 .30902 L
.84785 .30902 L
.84795 .30902 L
.84806 .30902 L
.84815 .30902 L
.84823 .30902 L
.84833 .30902 L
.84843 .30902 L
.84853 .30902 L
.84864 .30902 L
.84886 .30902 L
.84926 .30902 L
.85015 .30902 L
.85055 .30902 L
.85099 .30902 L
.85137 .30902 L
.85177 .30902 L
.85219 .30902 L
.85258 .30902 L
.85301 .30902 L
.85325 .30902 L
.85347 .30902 L
.85367 .30902 L
.85388 .30902 L
.85425 .30902 L
.85446 .30902 L
.85465 .30902 L
.85486 .30902 L
.85497 .30902 L
.85509 .30902 L
.8553 .30902 L
.85541 .30902 L
.85552 .30902 L
.85562 .30902 L
.85571 .30902 L
.85581 .30902 L
.85591 .30902 L
.85597 .30902 L
.85602 .30902 L
.85608 .30902 L
.85613 .30902 L
.85623 .30902 L
.85629 .30902 L
.85634 .30902 L
.85645 .30902 L
.85656 .30902 L
.8568 .30902 L
.85765 .30902 L
Mistroke
.85842 .30902 L
.85881 .30902 L
.85923 .30902 L
.85962 .30902 L
.85999 .30902 L
.86038 .30902 L
.86081 .30902 L
.86102 .30902 L
.86125 .30902 L
.86167 .30902 L
.86187 .30902 L
.86209 .30902 L
.8623 .30902 L
.86248 .30902 L
.8627 .30902 L
.86281 .30902 L
.86294 .30902 L
.86304 .30902 L
.86316 .30902 L
.86326 .30902 L
.86337 .30902 L
.86347 .30902 L
.86358 .30902 L
.86368 .30902 L
.86377 .30902 L
.86387 .30902 L
.86392 .30902 L
.86398 .30902 L
.86403 .30902 L
.86408 .30902 L
.86414 .30902 L
.8642 .30902 L
.86439 .30902 L
.86457 .30902 L
.86498 .30902 L
.86571 .30902 L
.86648 .30902 L
.86688 .30902 L
.86733 .30902 L
.86773 .30902 L
.86811 .30902 L
.86854 .30902 L
.86894 .30902 L
.86915 .30902 L
.86939 .30902 L
.86962 .30902 L
.86982 .30902 L
.87003 .30902 L
.87023 .30902 L
.87044 .30902 L
Mistroke
.87066 .30902 L
.87086 .30902 L
.87096 .30902 L
.87107 .30902 L
.87116 .30902 L
.87126 .30902 L
.87135 .30902 L
.87144 .30902 L
.87153 .30902 L
.87162 .30902 L
.87172 .30902 L
.87183 .30902 L
.87193 .30902 L
.87198 .30902 L
.87204 .30902 L
.87224 .30902 L
.87297 .30902 L
.87385 .30902 L
.87464 .30902 L
.87503 .30902 L
.87545 .30902 L
.87585 .30902 L
.87622 .30902 L
.87661 .30902 L
.87683 .30902 L
.87703 .30902 L
.87725 .30902 L
.87745 .30902 L
.87768 .30902 L
.8779 .30902 L
.87811 .30902 L
.8783 .30902 L
.87848 .30902 L
.87867 .30902 L
.87877 .30902 L
.87888 .30902 L
.87899 .30902 L
.8791 .30902 L
.8792 .30902 L
.87929 .30902 L
.87939 .30902 L
.87949 .30902 L
.87958 .30902 L
.87967 .30902 L
.87977 .30902 L
.87986 .30902 L
.8802 .30902 L
.88097 .30902 L
.88137 .30902 L
.8818 .30902 L
Mistroke
.88219 .30902 L
.8826 .30902 L
.883 .30902 L
.88337 .30902 L
.88374 .30902 L
.88408 .30902 L
.88446 .30902 L
.88467 .30902 L
.88487 .30902 L
.88507 .30902 L
.88527 .30902 L
.88549 .30902 L
.88569 .30902 L
.88587 .30902 L
.88606 .30902 L
.88623 .30902 L
.8864 .30902 L
.8865 .30902 L
.8866 .30902 L
.8867 .30902 L
.8868 .30902 L
.8869 .30902 L
.88698 .30902 L
.88708 .30902 L
.88718 .30902 L
.88728 .30902 L
.88733 .30902 L
.88738 .30902 L
.88749 .30902 L
.8876 .30902 L
.888 .30902 L
.88889 .30902 L
.88932 .30902 L
.88974 .30902 L
.89014 .30902 L
.89051 .30902 L
.89091 .30902 L
.89128 .30902 L
.89167 .30902 L
.8919 .30902 L
.8921 .30902 L
.89244 .30902 L
.89264 .30902 L
.89282 .30902 L
.89301 .30902 L
.89319 .30902 L
.89339 .30902 L
.89358 .30902 L
.89377 .30902 L
.89395 .30902 L
Mistroke
.89414 .30902 L
.89425 .30902 L
.89435 .30902 L
.89445 .30902 L
.89455 .30902 L
.89465 .30902 L
.89471 .30902 L
.89476 .30902 L
.89486 .30902 L
.89492 .30902 L
.89497 .30902 L
.89507 .30902 L
.89518 .30902 L
.89535 .30902 L
.89554 .30902 L
.89588 .30902 L
.89666 .30902 L
.89747 .30902 L
.89793 .30902 L
.89836 .30902 L
.89873 .30902 L
.89914 .30902 L
.89935 .30902 L
.89957 .30902 L
.89977 .30902 L
.89998 .30902 L
.90018 .30902 L
.90037 .30902 L
.90074 .30902 L
.90095 .30902 L
.90117 .30902 L
.90139 .30902 L
.90158 .30902 L
.90168 .30902 L
.90178 .30902 L
.90188 .30902 L
.90197 .30902 L
.90209 .30902 L
.90214 .30902 L
.9022 .30902 L
.90225 .30902 L
.90231 .30902 L
.9024 .30902 L
.90246 .30902 L
.90252 .30902 L
.90262 .30902 L
.90268 .30902 L
.90273 .30902 L
.90285 .30902 L
.90306 .30902 L
Mistroke
.90328 .30902 L
.90405 .30902 L
.90487 .30902 L
.90529 .30902 L
.90577 .30902 L
.90619 .30902 L
.9066 .30902 L
.90699 .30902 L
.90719 .30902 L
.9074 .30902 L
.90759 .30902 L
.90778 .30902 L
.90814 .30902 L
.90835 .30902 L
.90858 .30902 L
.9088 .30902 L
.90901 .30902 L
.90919 .30902 L
.90939 .30902 L
.90949 .30902 L
.9096 .30902 L
.9097 .30902 L
.9098 .30902 L
.9099 .30902 L
.91 .30902 L
.91009 .30902 L
.91018 .30902 L
.91028 .30902 L
.91034 .30902 L
.91039 .30902 L
.91059 .30902 L
.91077 .30902 L
.91097 .30902 L
.91132 .30902 L
.91219 .30902 L
.91299 .30902 L
.91339 .30902 L
.91381 .30902 L
.91423 .30902 L
.91447 .30902 L
.9147 .30902 L
.91491 .30902 L
.91511 .30902 L
.91548 .30902 L
.91569 .30902 L
.91588 .30902 L
.91609 .30902 L
.91632 .30902 L
.91652 .30902 L
.91664 .30902 L
Mistroke
.91675 .30902 L
.91693 .30902 L
.91703 .30902 L
.91714 .30902 L
.91726 .30902 L
.91732 .30902 L
.91738 .30902 L
.91744 .30902 L
.9175 .30902 L
.91755 .30902 L
.91761 .30902 L
.91766 .30902 L
.91771 .30902 L
.91781 .30902 L
.91792 .30902 L
.91798 .30902 L
.91803 .30902 L
.91824 .30902 L
.91844 .30902 L
.91882 .30902 L
.91965 .30902 L
.92043 .30902 L
.92083 .30902 L
.92126 .30902 L
.92163 .30902 L
.92202 .30902 L
.9224 .30902 L
.92274 .30902 L
.92294 .30902 L
.92312 .30902 L
.92332 .30902 L
.92353 .30902 L
.92373 .30902 L
.92391 .30902 L
.92408 .30902 L
.92426 .30902 L
.92446 .30902 L
.92457 .30902 L
.92468 .30902 L
.92477 .30902 L
.92487 .30902 L
.92497 .30902 L
.92506 .30902 L
.92516 .30902 L
.92526 .30902 L
.92532 .30902 L
.92537 .30902 L
.92542 .30902 L
.92548 .30902 L
.92559 .30902 L
Mistroke
.9257 .30902 L
.92593 .30902 L
.92666 .30902 L
.92744 .30902 L
.92784 .30902 L
.92828 .30902 L
.92869 .30902 L
.92907 .30902 L
.92929 .30902 L
.9295 .30902 L
.92989 .30902 L
.93011 .30902 L
.93032 .30902 L
.93056 .30902 L
.93078 .30902 L
.93098 .30902 L
.93115 .30902 L
.93135 .30902 L
.93157 .30902 L
.93176 .30902 L
.93197 .30902 L
.93208 .30902 L
.93219 .30902 L
.9323 .30902 L
.9324 .30902 L
.9325 .30902 L
.93259 .30902 L
.93268 .30902 L
.93279 .30902 L
.93284 .30902 L
.9329 .30902 L
.933 .30902 L
.93311 .30902 L
.9332 .30902 L
.93356 .30902 L
.93394 .30902 L
.93481 .30902 L
.93519 .30902 L
.93561 .30902 L
.93601 .30902 L
.93643 .30902 L
.93665 .30902 L
.93689 .30902 L
.93733 .30902 L
.93753 .30902 L
.93776 .30902 L
.93796 .30902 L
.93817 .30902 L
.93836 .30902 L
.93857 .30902 L
Mistroke
.93876 .30902 L
.93894 .30902 L
.93914 .30902 L
.93932 .30902 L
.93952 .30902 L
.93963 .30902 L
.93973 .30902 L
.93984 .30902 L
.93994 .30902 L
.93999 .30902 L
.94005 .30902 L
.94011 .30902 L
.94016 .30902 L
.94026 .30902 L
.94036 .30902 L
.94041 .30902 L
.94046 .30902 L
.94056 .30902 L
.94067 .30902 L
.94076 .30902 L
.94094 .30902 L
.94134 .30902 L
.94205 .30902 L
.94284 .30902 L
.94323 .30902 L
.94367 .30902 L
.94404 .30902 L
.94443 .30902 L
.94481 .30902 L
.94515 .30902 L
.94533 .30902 L
.94554 .30902 L
.94573 .30902 L
.94595 .30902 L
.94615 .30902 L
.94633 .30902 L
.94651 .30902 L
.94668 .30902 L
.94688 .30902 L
.947 .30902 L
.9471 .30902 L
.94719 .30902 L
.9473 .30902 L
.94739 .30902 L
.94748 .30902 L
.94759 .30902 L
.94768 .30902 L
.94774 .30902 L
.94779 .30902 L
.94785 .30902 L
Mistroke
.94791 .30902 L
.94796 .30902 L
.94802 .30902 L
.94812 .30902 L
.94835 .30902 L
.94912 .30902 L
.94954 .30902 L
.94993 .30902 L
.95062 .30902 L
.95099 .30902 L
.95138 .30902 L
.95158 .30902 L
.9518 .30902 L
.95199 .30902 L
.95219 .30902 L
.95238 .30902 L
.95258 .30902 L
.95293 .30902 L
.95315 .30902 L
.95335 .30902 L
.95358 .30902 L
.9538 .30902 L
.954 .30902 L
.95418 .30902 L
.95439 .30902 L
.9545 .30902 L
.95461 .30902 L
.9547 .30902 L
.95479 .30902 L
.95489 .30902 L
.955 .30902 L
.95505 .30902 L
.95511 .30902 L
.95521 .30902 L
.95532 .30902 L
.95541 .30902 L
.9555 .30902 L
.95558 .30902 L
.95577 .30902 L
.95615 .30902 L
.95697 .30902 L
.95741 .30902 L
.95782 .30902 L
.9582 .30902 L
.9586 .30902 L
.95883 .30902 L
.95904 .30902 L
.95924 .30902 L
.95945 .30902 L
.95962 .30902 L
Mistroke
.95982 .30902 L
.96016 .30902 L
.96035 .30902 L
.96056 .30902 L
.96075 .30902 L
.96093 .30902 L
.96114 .30902 L
.96135 .30902 L
.96156 .30902 L
.96175 .30902 L
.96185 .30902 L
.96197 .30902 L
.96207 .30902 L
.96217 .30902 L
.96223 .30902 L
.96229 .30902 L
.96235 .30902 L
.96241 .30902 L
.96247 .30902 L
.96252 .30902 L
.96257 .30902 L
.96263 .30902 L
.96273 .30902 L
.96282 .30902 L
.96293 .30902 L
.96303 .30902 L
.9634 .30902 L
.96425 .30902 L
.96502 .30902 L
.96545 .30902 L
.96584 .30902 L
.9662 .30902 L
.9666 .30902 L
.96697 .30902 L
.96731 .30902 L
.96751 .30902 L
.96769 .30902 L
.96788 .30902 L
.96809 .30902 L
.96829 .30902 L
.96847 .30902 L
.96864 .30902 L
.96882 .30902 L
.96902 .30902 L
.96913 .30902 L
.96923 .30902 L
.96933 .30902 L
.96941 .30902 L
.96951 .30902 L
.96961 .30902 L
Mistroke
.96967 .30902 L
.96972 .30902 L
.96978 .30902 L
.96983 .30902 L
.96993 .30902 L
.97003 .30902 L
.97008 .30902 L
.97014 .30902 L
.97025 .30902 L
.97048 .30902 L
.97125 .30902 L
.97207 .30902 L
.97254 .30902 L
.97296 .30902 L
.97339 .30902 L
.97379 .30902 L
.97409 .30902 L
.97439 .30902 L
.97466 .30902 L
.97495 .30902 L
.97526 .30902 L
.97543 .30902 L
.97559 .30902 L
.97574 .30902 L
.9759 .30902 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{421.375, 260.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008>0001AB000`400?l00000o`00003ooooooooo
oooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo
003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooo
oooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool0
0?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooooooo
ool@ooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooo
ooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo0ol0003o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool0ooooooo;ooooo`00<?ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo0?ooooooboooool0033ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`3ooooool_ooooo000`ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool0ooooooo;ooooo`00<?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo0?oooooo
boooool0033ooooo00?o0000ooooooooool03_ooool2o`000?ooooooc?ooool0033ooooo00?o0000
ooooooooool03Oooool00ol0003oooooo`00003oooooolcooooo000`ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooool00000ooooooo<ooooo`00<?ooool3o`0000gooooo00?o0000ooooool0
0000ooooooo<ooooo`00<?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo000000[ooooo
00?o0000ooooooooool0oooooonoooooo`00<?ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooo000000Wooooo0_l0003ooooool7ooooo000`ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooool000002Oooool2o`000?oooooo`Oooool0033ooooo00?o0000ooooooooool03Oooool00ol0
003oooooo`000009ooooo`;o0000ooooooo1ooooo`00<?ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooo000000Wooooo0_l0003ooooool7ooooo000`ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooool000002Oooool2o`000?oooooo`Oooool0033ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooo`000009ooooo`;o0000ooooooo1ooooo`00<?ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooo000000Wooooo0_l0003ooooool7ooooo000`ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooool000002Oooool2o`000?oooooo`Oooool0033ooooo00?o0000oooooooo
ool03Oooool00ol0003oooooo`000009ooooo`;o0000ooooooo1ooooo`00<?ooool3o`0000gooooo
00?o0000ooooool000002Oooool2o`000?oooooo`Oooool0033ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooo`000009ooooo`;o0000ooooooo1ooooo`00<?ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooo000000Wooooo0_l0003ooooool7ooooo000`ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooool000002Oooool2o`000?oooooo`Oooool0033ooooo00?o0000oooooooo
ool03Oooool00ol0003oooooo`000009ooooo`;o0000ooooooo1ooooo`00<?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooo000000Wooooo0_l0003ooooool7ooooo000`ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooool000002Oooool2o`000?oooooo`Oooool0013ooooo0_o^k^h3
ooooo`;ok^k^6Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo000000Wooooo00?o0000
ooooool00000ooooooo0ooooo`002oooool2o`00000:oa0@4?ooooooooooonk^k_mEEEGok^k^oooo
ooo^k^koEEEEonk^kP?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^2_oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooo000000Wooooo00?o0000ooooool00000oooo
ooo0ooooo`003?ooool00ol0003oooooooooo`02ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_oo
ool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooo000000Wooooo00?o0000ooooool00000ooooooo0ooooo`0000?o
ooooo`000?l000001?l00002ooooo`Go00001?ooool00ooMgMgo0000omgMg@07ooooo`03o`000?oo
oooooooo00;ooooo00Go410@oooooooooooooooooa0@400:ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooool000002Oooool00ol0003oooooo`00003ooooool3ooooo0009ooooo`04odA4A?oM
gMgoooooo`0000Cooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`00000:ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ool000002Oooool00ol0003oooooo`00003ooooool3ooooo0009ooooo`04omgMgOmEEEGoooooo`00
00?ooooo00Ook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000000[ooooo1?l0000<ooooo`03o`000?oooooo000000Wooooo
00?o0000ooooool00000ooooooo0ooooo`002_ooool00omgMgOoc<c<o`000003ooooo`;ok^k^0ooo
ool2onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00[ooooo
00?o0000ooooooooool03Oooool00ol0003oooooo`000008ooooo`04o`000?ooooooooooo`000?oo
oooo`?ooool000[ooooo00?ok^k^odA4A?l000003oooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL00oooool2o`0000Gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooo`000008ooooo`04o`000?ooooooooooo`000?oooooo`?ooool000_ooooo00?oMgMgo`000?oo
ool03?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_ooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo00gooooo00?o0000ooooool000002?ooool0
1?l0003oooooooooool0003ooooool3ooooo000Xooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooooooool03Oooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`000?oo
oooo`?ooool002Sooooo0ol00005ooooo`03o`000?oooooooooo00gooooo00Co0000oooooooooooo
00001oooool01?l0003oooooooooool0003ooooool3ooooo000Yooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool03Oooool01?l0003oooooooooool00007ooooo`04o`000?oooooooooo
o`000?oooooo`?ooool002[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0=oooo
o`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo0000ooooooo0ooooo`00<?ooool0
0ol0003oooooooooo`0=ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo0000
ooooooo0ooooo`00<?ooool00ol0003oooooooooo`0=ooooo`04o`000?ooooooooooo`0000Oooooo
00Co0000oooooooooooo0000ooooooo0ooooo`00<?ooool00ol0003oooooooooo`0=ooooo`04o`00
0?ooooooooooo`0000Oooooo00Co0000oooooooooooo0000ooooooo0ooooo`00<?ooool00ol0003o
ooooooooo`0=ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo0000ooooooo0
ooooo`00<?ooool3o`0000gooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool0
003ooooool3ooooo000`ooooo`03o`000?oooooooooo00cooooo00Go0000ooooooooooooooooo`00
0007ooooo`04o`000?ooooooooooo`000?oooooo`?ooool0033ooooo00?o0000ooooooooool03?oo
ool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000ooooooo0ooooo`00
<?ooool00ol0003oooooooooo`0<ooooo`05o`000?ooooooooooooooool000001oooool01?l0003o
ooooooooool0003ooooool3ooooo000`ooooo`03o`000?oooooooooo00cooooo00Go0000oooooooo
ooooooooo`000007ooooo`04o`000?ooooooooooo`000?oooooo`?ooool0033ooooo00?o0000oooo
ooooool03?ooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000oooo
ooo0ooooo`00<?ooool00ol0003oooooooooo`0<ooooo`05o`000?ooooooooooooooool000001ooo
ool01?l0003oooooooooool0003ooooool3ooooo000`ooooo`03o`000?oooooooooo00cooooo00Go
0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`000?oooooo`?ooool0033ooooo
00?o0000ooooooooool03?ooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooo
oooo0000ooooooo0ooooo`00<?ooool00ol0003oooooooooo`0<ooooo`05o`000?oooooooooooooo
ool000001oooool01?l0003oooooooooool0003ooooool3ooooo000`ooooo`03o`000?oooooooooo
00cooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`000?oooooo`?oo
ool0033ooooo00?o0000ooooooooool03?ooool01Ol0003ooooooooooooooooo000000Oooooo00Co
0000oooooooooooo0000ooooooo0ooooo`00<?ooool3o`0000cooooo00Go0000oooooooooooooooo
o`000007ooooo`04o`000?ooooooooooo`000?oooooo`?ooool0033ooooo00?o0000ooooooooool0
3?ooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000ooooooo0oooo
o`00<?ooool00ol0003oooooooooo`0<ooooo`05o`000?ooooooooooooooool000001oooool01?l0
003oooooooooool0003ooooool3ooooo000`ooooo`03o`000?oooooooooo00cooooo00Go0000oooo
ooooooooooooo`000007ooooo`04o`000?ooooooooooo`000?oooooo`?ooool0033ooooo00?o0000
ooooooooool03?ooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000
ooooooo0ooooo`00<?ooool00ol0003oooooooooo`0<ooooo`05o`000?ooooooooooooooool00000
1oooool01?l0003oooooooooool0003ooooool3ooooo000`ooooo`03o`000?oooooooooo00cooooo
00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`000?oooooo`?ooool0033o
oooo00?o0000ooooooooool03?ooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooo
oooooooo0000ooooooo0ooooo`00<?ooool00ol0003oooooooooo`0<ooooo`05o`000?oooooooooo
ooooool000001oooool01?l0003oooooooooool0003ooooool3ooooo000`ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo000000Oooooo00Co
0000oooooooooooo0000ooooooo0ooooo`00<?ooool00ol0003oooooooooo`02ooooo`;o00002?oo
ool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000ooooooo0ooooo`00
<?ooool3o`0000;ooooo0_l00008ooooo`05o`000?ooooooooooooooool000001oooool01?l0003o
ooooooooool0003ooooool3ooooo000`ooooo`03o`000?oooooooooo00;ooooo0_l00008ooooo`05
o`000?ooooooooooooooool000001oooool01?l0003oooooooooool0003ooooool3ooooo000`oooo
o`07o`000?ooooooooooooooool0003oooooo`000008ooooo`05o`000?ooooooooooooooool00000
1oooool01?l0003oooooooooool0003ooooool3ooooo000`ooooo`07o`000?ooooooooooooooool0
003oooooo`000008ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool0
003ooooool3ooooo000`ooooo`07o`000?ooooooooooooooool0003oooooo`000008ooooo`05o`00
0?ooooooooooooooool000001oooool01?l0003oooooooooool0003ooooool3ooooo000`ooooo`07
o`000?ooooooooooooooool0003oooooo`000008ooooo`05o`000?ooooooooooooooool000001ooo
ool01?l0003oooooooooool0003ooooool3ooooo000`ooooo`07o`000?ooooooooooooooool0003o
ooooo`000008ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool00009
ooooo`03o`000?oooooooooo0?oooooo]?ooool0013ooooo0_o^k^h3ooooo`;ok^k^6Oooool01ol0
003ooooooooooooooooo0000ooooool000002?ooool01Ol0003ooooooooooooooooo000000Oooooo
00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`3ooooookCooooo0009ooooo`Go0000
0_ooool01oo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^h:ooooo`07o`000?ooooooooooooooool0003oooooo`000008oooo
o`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool00008ooooo`;o0000oooo
oonfooooo`002Oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00Gok^k^oeEEEOoMgMgoEEEE
onk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0:ooooo`07
o`000?ooooooooooooooool0003oooooo`000008ooooo`05o`000?ooooooooooooooool000001ooo
ool01?l0003oooooooooool00008ooooo`;o0000oooooonfooooo`0000?oooooo`000?l000001?l0
0003ooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?ogMgMo`000?oMgMd01oooool00ol0003ooooooooo
o`02ooooo`05oa0@4?ooooooooooooooool@41002_ooool01ol0003ooooooooooooooooo0000oooo
ool000002?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`00
0008ooooo`;o0000oooooonfooooo`002oooool00onHV9So8B4Qonk^kP03ooooo`05onk^k_mEEEGo
gMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
2_ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool01Oooool01Ol0003o
oooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooo
00000?oooooo]Oooool000cooooo00_oMgMgofIVI_ooooooooooonk^k_mEEEGok^k^ooooooo^k^ko
EEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000:oooo
o`Go00000_ooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000001_ooool0
1Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooool00000ooooooneooooo`003Oooool0
0ol0003oooooooooo`02onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@400:ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003ooooo
ooooo`05ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo0000
00Sooooo00?o0000ooooool00000ooooooneooooo`002Oooool01Ol0003o^[ZjoooooonHV9So410@
00kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo0_l00005
ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`05ooooo`05o`000?oo
ooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooool0
0000ooooooneooooo`002Oooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo00?oEEEEofIVI_l0
00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo00Co0000oooooooooooo00001?ooool0
1Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooo
oooooooo000000Kooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooo00000?oo
oooo]Oooool002Sooooo00Co0000oooooooooooo00001?ooool01Ol0003ooooooooooooooooo0000
00;ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo00000?oooooo]Oooool0
02Sooooo0ol00005ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`05
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooool00000ooooooneooooo`00:Oooool00ol0003oooooooooo`04
ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`05ooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooool00000ooooooneooooo`00:_ooool00ol0003oooooooooo`03ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo00000?oo
oooo]Oooool0033ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`05ooooo`05
o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooool00000ooooooneooooo`00<?ooool01?l0003oooooooooool00003oooo
o`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooo`00003ooooookGooooo000`oooo
o`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooo
oooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooo00000?oooooo]Oooool0033ooooo00Co0000oooooooooooo00000oooool00ol0003ooooooooo
o`05ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooool00000ooooooneooooo`00<?ooool4o`0000?ooooo00?o
0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`000?oooooo]Oooool0033ooooo
00Co0000oooooooooooo00000oooool00ol0003oooooooooo`05ooooo`05o`000?oooooooooooooo
ool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Co0000oooo
oooooooo0000ooooooneooooo`00<?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooo
oooo00Gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool01?l0003oooooooooool0003ooooookGooooo000`ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`00
0?oooooo]Oooool0033ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`05oooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00Co0000oooooooooooo0000ooooooneooooo`00<?ooool01?l0003oooooooooool0
0003ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0003ooooookGo
oooo000`ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01Oooool01Ol0003o
oooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04oooo
o`04o`000?ooooooooooo`000?oooooo]Oooool0033ooooo00Co0000oooooooooooo00000oooool0
0ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo0000ooooooneooooo`00<?oo
ool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Gooooo00Go0000oooooooooooo
ooooo`000006ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01?l0003o
ooooooooool0003ooooookGooooo000`ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooo
ooooool01Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000oooooondooooo`00<?ooool0
1?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Gooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooo
oooooooooooo00000?oooooo]?ooool0033ooooo00Co0000oooooooooooo00000oooool00ol0003o
ooooooooo`05ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00003ooooookCooooo000`oooo
o`Co00000oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000001_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00
003ooooookCooooo000`ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01Ooo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`04ooooo`05o`000?ooooooooooooooool00000oooooondooooo`00<?ooool01?l0003ooooo
ooooool00003ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000006oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo
00000?oooooo]?ooool0033ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`05
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00Go0000ooooooooooooooooo`00003ooooookCooooo000`ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooooooo
ool00000oooooondooooo`00<?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo
00Gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool01Ol0003ooooooooooooooooo000002Kooooo0_o^k^h3ooooo`;ok^k^Eooo
ool2onk^kP?ooooo0_o^k^iPooooo`;ok^k^0oooool2onk^kTkooooo0_o^k^h3ooooo`;ok^k^K?oo
ool0033ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`05ooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo
00Go0000ooooooooooooooooo`00000Pooooo`0=odA4A?l0003o0000oc8b<_oMgMgoooooonk^k_mE
EEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o
<S8bonk^kT;ooooo1?l000002Ol@413oooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kS_ooooo1?l000000ol@413ooooo
ooooo`02ooooo`;o8B4Q1Oooool03Om4A4Co0000o`000?lb<S;ogMgMooooooo^k^koEEEEonk^k_oo
ooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hh
ooooo`Go00000_ooool01oo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@
4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^iMooooo`00<?ooool01?l0003oooooooooool00003
ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000002?ooooo
00WoMgMgoc8b<_ooooooooooonk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0A?ooool00ol0003oooooooooo`02ooooo`05onk^k_mE
EEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL0?Oooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool02OmgMgOo<S8booooooooooook^k^
oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0hooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01Oo^k^koEEEEomgMgOmEEEGok^k^
00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg05gooooo000`oooo
o`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`05o`000?ooooooooooooooool000009?ooool01ol0003ooooooooooooooooogMgMo`000?oM
gMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100A?ooool00ol0
003oooooooooo`03ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@
413ooooooooooooooooo410@03gooooo00?o0000ooooooooool03oooool01ol0003ooooooooooooo
oooogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
4100>Oooool00onHV9So8B4Qonk^kP05ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000oooooooo
ool00_ooool01Ol@413ooooooooooooooooo410@05gooooo000`ooooo`04o`000?ooooooooooo`00
00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooo
ooooool000008oooool02OmgMgOo<S8booooooooooook^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03
o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000014ooooo`03o`000?oooooooooo
00;ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`00000mooooo`03o`000?oooooooooo00kooooo00WoMgMgoc8b<_oooooooooo
onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool00000>_ooool00onHV9So8B4Qonk^kP03ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_oo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000GOooool002Wooooo00?o
0000ooooooooool01?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000023ooooo00go0000ob4Q8Ol0
003o<S8bolc<c?ooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000oooooooo
ool00_ooool01Ol0003ooooooooooooooooo000004Cooooo00_o0000ooooooooooooooooonk^k_mE
EEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`00000mooooo`03o`000?oooooooooo00_ooooo00go0000ob4Q8Ol0003o<S8bolc<c?oo
ooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000ooooooooool00_ooool01Ol0
003ooooooooooooooooo000003_ooooo00_oMgMgofIVI_ooooooooooonk^k_mEEEGok^k^ooooooo^
k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001M
ooooo`00:?ooool3o`0000Gooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000007ooooo`;o00005ooo
ool00ol0003oooooooooo`03ooooo`;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@04Cooooo00Co0000oooooooooooooooo0_o^k^h3ooooo`;o
k^k^1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100?Oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo0_o^k^h3ooooo`;ok^k^1Oooool00ol0
003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100??ooool00ol0003oooooooooo`02
onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
401Mooooo`00:?ooool00ol0003oooooo`000005ooooo`?o00001?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooo000001Kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`0iooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo
0_l0000cooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool2o`0002kooooo00Go0000okZj^_oo
ooooV9RHoa0@400>ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08
ooooo`;o0000Doooool002Sooooo00?o0000ooooool000001Oooool00ol0003oooooo`000005oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooool000005_ooool4o`0000cooooo00?oEEEEofIV
I_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0=oooool0
0omEEEGoIVIVo`00000=ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP07ooooo`04o`000?ooooooooooo`00033ooooo00?oEEEEofIVI_l000003Oooool4o`0000cooooo
00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oooooo00Co0000oooooooo
oooo0000;Oooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo00?oEEEEofIVI_l000001?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Oooooo00Co0000oooooooooooo0000D_ooool002Sooooo00?o
0000ooooool000001Oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooool00000=?ooool4o`0000?ooooo00?o0000ooooooooool0E?ooool4o`000005ooooool0
003oooooooooool00000G_ooool4o`000005ooooool0003oooooooooool00000C?ooool4o`000005
ooooool0003oooooooooool00000D_ooool002Oooooo00Co0000oooooooooooo00001Oooool00ol0
003oooooo`000005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooool00000>oooool00ol0
003oooooooooo`1Iooooo`?o0000I?ooool3o`0005;ooooo0ol0001Cooooo`009oooool01Ol0003o
oooooooooooooooo000000Cooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooo000003Wooooo00Co0000oooooooooooo0000Foooool00ol0003oooooooooo`1T
ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0D_ooool002Oooooo00Go0000oooo
ooooooooooooo`000004ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
1?l0003oooooooooool0000iooooo`Co0000G?ooool00ol0003oooooooooo`1Tooooo`03o`000?oo
oooooooo05;ooooo00?o0000ooooooooool0DOooool002Kooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
1Ol0003ooooooooooooooooo00000?ooooooZOooool002Kooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
1Ol0003ooooooooooooooooo00000?ooooooKoooool00omgMgOoIVIVooooo`0]ooooo`03ofIVI_mg
MgOooooo00Oooooo000Vooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooo`000005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00
003oooooofkooooo00?ogMgMoa0@4?o^k^h0;_ooool00oo^k^ko410@omgMg@07ooooo`009_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000001Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0oooooomI
ooooo`;o00000_ooool2o`0000cooooo00?oEEEEoiRHV?ooool00_l00002ooooo`07o`000?oooooo
ooooo`000?l@413ok^k^oeEEE@02o`000003odA4A?nj^[[ooooo00;ooooo00GoV9RHo`000?l0003o
A4A4okZj^P02ooooo`08onk^k_mEEEGo0000o`000?m4A4Co^[Zjooooool@4105o`0000?ooooo00So
410@oc8b<_l0003o0000oa0@4?nYZJWoQhN7ofIVIPOooooo000Kooooo`Co00001oooool00ol0003o
ooooooooo`03ooooo`07o`000?ooooooooooooooool0003oooooo`000005ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`Co0000oooooomB
ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM3?ooool01Ol0003ooooooooooooooooo000000;o
oooo00_o0000oooooooooooo0000oooooomEEEGoMgMgooooooo^k^koMgMgoa0@4003ooooo`05oa0@
4?nj^[[ok^k^ogMgMol@41000_ooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40?ooooo00?o0000
ooooooooool01?ooool02?l0003oZJVYoooooooooooo^[Zjo`000?o^k^ko00001oooool00?oo0000
]?l0000?ooooo`04omgMgOl0003o410@olc<c0gooooo00Go<S8booooooooooooooooo`000002oooo
o`06o`000?ooooooooooo`000?oooooo00002?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01Oooool01onj^[[oQhN7ofIVI_mVIVKo410@ooooool0
00001oooool000[ooooo00?o0000ooooooooool02?ooool3o`0000Gooooo00?o0000ooooool00000
1Oooool00ol0003oooooooooo`04ooooo`07o`000?ooooooooooooooool0003oooooo`000005oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool2o`0000Gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`;o00001?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`04oooo
o`Co00001Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Oooooo00Cok^k^ob4Q
8Ol@413ok^k^3Oooool01Olb<S;ooooooooooooooooo000000;ooooo00Go0000oooooooooooo0000
ooooo`06o`0000?ooooo00?o0000ooooooooool01?ooool6o`0000?ooooo00?o0000ooooooooool0
1?ooool02?lb<S;o8B4QogMgMomgMgOoQhN7onk^k_oooooo00001oooool000[ooooo00?o0000oooo
ooooool04?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00Cooooo00Oo0000
ooooooooooooooooo`000?oooooo000000Gooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`;o00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
0_l00004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool2o`0000;ooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Oooooo
00Co8B4QogMgMomgMgOo<S8b3Oooool01Ol0003ok^k^oooooooooooo000000;oc<c<00_o0000ojVY
ZOoMgMgo8B4QoooooomEEEGoQhN7onk^k_ooooooQhN7oc8b<P03ooooo`03o`000?oooooooooo00Co
oooo00KoEEEEohN7Qoo^k^koooooohN7Qolb<S83ooooo`03o`000?lb<S;ogMgM00Cooooo00So0000
okZj^_ooooook^k^ogMgMol0003ok^k^o`0000Oooooo000Qooooo`04o`000?ooooooooooo`0000Oo
oooo00Oo0000ooooooooooooooooo`000?oooooo000000Gooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0002?ooooo00?o0000ooooooooool0Fooo
ool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool05_oo
ool2o`0000;ooooo0_l0000<ooooo`0>oeEEEOmgMgOooooooa0@4?l0003o8B4Qo`000?mgMgOo410@
o`000?nYZJWoooooonk^k_mEEED2o`000004odA4A?o^k^kooooooa0@40Go00000oooool01_o^k^ko
EEEEo`000?l0003oA4A4onk^kP;ooooo0_l000001?nYZJWo8B4Qo`000?lQ8B42ooooo`08ojVYZOlQ
8B7o0000o`000?lb<S;o0000ogMgMomEEED7ooooo`008Oooool4o`0000Oooooo00Co0000oooooooo
oooooooo0_l00006ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooo`00003o
ooooof[ooooo00?ogMgMoa0@4?o^k^h04_ooool00ol0003oooooooooo`0Iooooo`03onk^k_l@413o
gMgM00Oooooo000Rooooo`;o00002?ooool01?l0003oooooooooooooool2o`0000Kooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000
ooooooooooooooooo`000007ooooo`;o0000oooooom[ooooo`03ogMgMomVIVKooooo017ooooo00?o
0000ooooooooool06Oooool00omVIVKoMgMgooooo`07ooooo`00;?ooool01?l0003ooooooooooooo
ool2o`0000Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00Go0000ooooooooooooooooo`00003oooooojkooooo000/ooooo`04o`000?oo
ooooooooooooo`;o00001_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo00000?oooooo[_ooool002cooooo
00Co0000oooooooooooooooo0_l00006ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000oooooon^oooo
o`00;?ooool01?l0003oooooooooooooool2o`0000Kooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00003o
ooooojkooooo000/ooooo`04o`000?ooooooooooooooo`;o00001_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooo
oooo00000?oooooo[_ooool002gooooo00?o0000ooooooooool00_l00006ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooo
ooooooooool00000oooooon^ooooo`00;Oooool00ol0003oooooooooo`03o`0000Gooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Co0000
oooooooooooo0000oooooon_ooooo`00;Oooool00ol0003oooooooooo`02o`0000Kooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Co0000
oooooooooooo0000oooooon_ooooo`00;Oooool00ol0003oooooooooo`02o`0000Kooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Co0000
oooooooooooo0000oooooon_ooooo`00;Oooool00ol0003oooooooooo`02o`0000Kooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Co0000
oooooooooooo0000oooooon_ooooo`00;Oooool00ol0003oooooooooo`02o`0000Kooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Co0000
oooooooooooo0000oooooon_ooooo`00;Oooool00ol0003oooooooooo`02o`0000Kooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Co0000
oooooooooooo0000oooooon_ooooo`00;Oooool00ol0003oooooooooo`02o`0000Kooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Co0000
oooooooooooo0000oooooon_ooooo`00;Oooool00ol0003oooooooooo`02o`0000Kooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Co0000
oooooooooooo0000oooooon_ooooo`00;Oooool00ol0003oooooooooo`02o`0000Kooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Co0000
oooooooooooo0000oooooon_ooooo`00;Oooool00ol0003oooooooooo`02o`0000Kooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Co0000
oooooooooooo0000oooooon_ooooo`00;_ooool01?l0003oooooo`000?l00006ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`04o`000?oo
ooooooooo`000?oooooo[oooool002kooooo00Co0000ooooool0003o00001_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool2o`000?oooooo
/?ooool002kooooo00?o0000ooooool000000_l00005ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`;o0000oooooon`ooooo`00;_ooool0
1?l0003oooooo`000?l00006ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`05ooooo`;o0000oooooon`ooooo`00;_ooool00ol0003oooooo`000007
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05
ooooo`;o0000oooooon`ooooo`00;_ooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`;o0000oooooon`oooo
o`00;_ooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`05ooooo`;o0000oooooon`ooooo`00;_ooool00ol0003ooooo
o`000008ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00003ooooook[ooooo000^ooooo`03
o`000?oooooo000000Sooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0003ooooook[ooooo000_oooo
o`;o00002?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`000?oooooo^_ooool002oooooo0_l00008
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Gooooo00Co0000oooooooooooo0000oooooonjooooo`00<?ooool00ol0003ooooooooo
o`06ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Gooooo00Co0000oooooooooooo0000oooooonjooooo`00<?ooool00ol0003ooooo
ooooo`06ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Gooooo00Co0000oooooooooooo0000oooooonjooooo`00<?ooool00ol0003o
ooooooooo`06ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo
000000Oooooo00Co0000oooooooooooo0000oooooonjooooo`00<?ooool3o`0000Kooooo00Go0000
ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool01?l0003ooooo
ooooool0003ooooook[ooooo000`ooooo`03o`000?oooooooooo00Kooooo00Go0000oooooooooooo
ooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool0003o
oooook[ooooo000`ooooo`03o`000?oooooooooo00Kooooo00Go0000ooooooooooooooooo`000007
ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool0003ooooook[ooooo
000`ooooo`03o`000?oooooooooo00Kooooo00Go0000ooooooooooooooooo`000007ooooo`05o`00
0?ooooooooooooooool000001oooool01?l0003oooooooooool0003ooooook[ooooo000`ooooo`03
o`000?oooooooooo00Kooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooooooo
ooooool000001oooool01?l0003oooooooooool0003ooooook[ooooo000`ooooo`03o`000?oooooo
oooo00Kooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool00000
1oooool01?l0003oooooooooool0003ooooook[ooooo000?ooooo`;ok^k^0oooool2onk^kQ[ooooo
00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooooooo
ooooooooo`000007ooooo`04o`000?ooooooooooo`000?oooooo^_ooool000Sooooo1Ol00002oooo
o`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co000000So410@ooooooooooook^k^
oc8b<_l0003o<S8bonk^kP_ooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo
000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`000?oooooo
^_ooool000Sooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05onk^k_mEEEGogMgMoeEEEOo^
k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ol0
003oooooooooo`06ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooo
oooo000000Oooooo00Co0000oooooooooooo0000oooooonjooooo`002Oooool00onHV9So8B4Qonk^
kP05ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@00_ooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo000000Oo
oooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`000?oooooo^_ooool0
00[ooooo00?oV9RHob4Q8Oo^k^h00oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000000_ooooo00?o0000ooooooooool01_oo
ool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04
o`000?ooooooooooo`000?oooooo^_ooool000_ooooo00_oMgMgofIVI_ooooooooooonk^k_mEEEGo
k^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`00000;ooooo`Co00001Oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooo
ooooooooooooo`000007ooooo`04o`000?ooooooooooo`000?oooooo^_ooool000cooooo00?o0000
ooooooooool00_o^k^h3ooooo`;ok^k^1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooo
ooooooooool@41002oooool00ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool00000
1oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000oooooonjoooo
o`002?ooool01Ol0003o^[ZjoooooonHV9So410@00kooooo00?o0000ooooooooool00_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00_ooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooo
oooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`000?oo
oooo^_ooool000Sooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00<ooooo`03oeEEEOmVIVKo000000Co
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`;o00001_ooool00ol0003oooooooooo`06oooo
o`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co
0000oooooooooooo0000oooooonjooooo`009oooool01?l0003oooooooooool00005ooooo`03o`00
0?oooooooooo00Kooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooooooooooo
ool000001oooool01?l0003oooooooooool0003ooooook[ooooo000Wooooo`04o`000?oooooooooo
o`0000Gooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo000000Oooooo00Go
0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`000?oooooo^_ooool002Oooooo
0ol00006ooooo`03o`000?oooooooooo00Kooooo00Go0000ooooooooooooooooo`000007ooooo`05
o`000?ooooooooooooooool000001oooool01?l0003oooooooooool0003ooooook[ooooo000Xoooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo
000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`000?oooooo
^_ooool002Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`05o`000?oo
ooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooo
oooo0000oooooonjooooo`00<?ooool00ol0003oooooooooo`06ooooo`05o`000?oooooooooooooo
ool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000oooo
oonjooooo`00<?ooool00ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool000001ooo
ool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000oooooonjooooo`00
<?ooool00ol0003oooooooooo`07ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooo
ooooooooo`000007ooooo`04o`000?ooooooooooo`000?oooooo^_ooool0033ooooo0ol00007oooo
o`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?oo
ooooooooo`000?oooooo^_ooool0033ooooo00?o0000ooooooooool01oooool01?l0003ooooooooo
ool00007ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool0003ooooo
ok[ooooo000`ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo00001oooool01Ol0
003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000oooooonjooooo`00<?ooool0
0ol0003oooooooooo`07ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooooooooooo
o`000007ooooo`04o`000?ooooooooooo`000?oooooo^_ooool0033ooooo00?o0000ooooooooool0
1oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001oooool01?l0
003oooooooooool0003ooooook[ooooo000`ooooo`03o`000?oooooooooo00Oooooo00Co0000oooo
oooooooo00001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000
oooooonjooooo`00<?ooool00ol0003oooooooooo`07ooooo`04o`000?ooooooooooo`0000Oooooo
00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`000?oooooo^_ooool0033o
oooo00?o0000ooooooooool01oooool01?l0003oooooooooool00007ooooo`05o`000?oooooooooo
ooooool000001oooool01?l0003oooooooooool0003ooooook[ooooo000`ooooo`03o`000?oooooo
oooo00Oooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Oooooo
00Co0000oooooooooooo0000oooooonjooooo`00<?ooool00ol0003oooooooooo`07ooooo`04o`00
0?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?oooooooooo
o`000?oooooo^_ooool0033ooooo00?o0000ooooooooool01oooool01?l0003oooooooooool00007
ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool0003ooooook[ooooo
000`ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo00001oooool01Ol0003ooooo
oooooooooooo000000Oooooo00?o0000ooooool00000oooooonkooooo`00<?ooool3o`0000Oooooo
00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000oooo
ool00000oooooonkooooo`00<?ooool00ol0003oooooooooo`07ooooo`04o`000?ooooooooooo`00
00Oooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?oooooo^oooool0
033ooooo00?o0000ooooooooool01oooool01?l0003oooooooooool00007ooooo`05o`000?oooooo
ooooooooool000001oooool00ol0003oooooo`00003ooooook_ooooo000`ooooo`03o`000?oooooo
oooo00Oooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Oooooo
00?o0000ooooool00000oooooonkooooo`00<?ooool00ol0003oooooooooo`07ooooo`04o`000?oo
ooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?oo
oooo^oooool0033ooooo00?o0000ooooooooool01oooool01?l0003oooooooooool00007ooooo`05
o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003ooooook_ooooo000`ooooo`03
o`000?oooooooooo00Oooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo
000000Sooooo0_l0003ooooook_ooooo000`ooooo`03o`000?oooooooooo00Oooooo00Co0000oooo
oooooooo00001oooool01Ol0003ooooooooooooooooo000000Sooooo0_l0003ooooook_ooooo000`
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooool000002?ooool01Ol0003ooooooooooooo
oooo000000Sooooo0_l0003ooooook_ooooo000`ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooool000002?ooool01Ol0003ooooooooooooooooo000000Sooooo0_l0003ooooook_ooooo000`
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooool000002?ooool01?l0003oooooooooool0
0009ooooo`;o0000oooooonkooooo`00<?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
000000Sooooo00Co0000oooooooooooo00002Oooool2o`000?oooooo^oooool0033ooooo0ol00007
ooooo`03o`000?oooooo000000Sooooo00Co0000oooooooooooo00002Oooool2o`000?oooooo^ooo
ool0033ooooo00?o0000ooooooooool01oooool00ol0003oooooo`000008ooooo`04o`000?oooooo
ooooo`0000Wooooo0_l0003ooooook_ooooo000`ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooool000002?ooool01?l0003oooooooooool00009ooooo`;o0000oooooonkooooo`00<?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooo000000Sooooo00Co0000oooooooooooo00002Ooo
ool00ol0003oooooooooo`3ooooook[ooooo000`ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooool000002?ooool01?l0003oooooooooool0003oooooolKooooo000`ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooool000002?ooool01?l0003oooooooooool0003oooooolKooooo000?
ooooo`;ok^k^0oooool2onk^kQ[ooooo00?o0000ooooooooool01oooool00ol0003oooooo`000008
ooooo`04o`000?ooooooooooo`000?ooooooa_ooool000[ooooo0_l000002_l@413oooooooooooo^
k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h3ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0
003o<S8bonk^kP_ooooo00?o0000ooooooooool01oooool00ol0003oooooo`000008ooooo`04o`00
0?ooooooooooo`000?ooooooa_ooool000_ooooo00?o0000ooooooooool00_ooool01Oo^k^koEEEE
omgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00_ooooo00?o0000ooooooooool01oooool00ol0003oooooo`000008ooooo`04o`000?oooooooooo
o`000?ooooooa_ooool000Sooooo1Ol00004ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@00_ooooo00?o0000ooooooooool02?ooool2
o`0000Sooooo00Co0000oooooooooooo0000ooooooo6ooooo`002?ooool01?m4A4CogMgMooooool0
0004ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000002oooool00ol0003oooooooooo`08ooooo`;o00002?ooool01?l0003o
ooooooooool0003oooooolKooooo0008ooooo`04omgMgOmEEEGoooooo`0000?ooooo00Ook^k^oeEE
EOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000_ooooo1?l00007ooooo`;o00002?ooool01?l0003oooooooooool0003oooooolKo
oooo0009ooooo`03ogMgMoo<c<co000000?ooooo0_o^k^h3ooooo`;ok^k^1Oooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41002oooool00ol0003oooooooooo`08ooooo`;o
00002?ooool01?l0003oooooooooool0003oooooolKooooo0009ooooo`03onk^k_m4A4Co000000oo
oooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?o0000oooo
ooooool02?ooool2o`0000Sooooo00Co0000oooooooooooo0000ooooooo6ooooo`002_ooool00omg
MgOo0000ooooo`0<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03
ooooo`;o00001_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00Co0000
oooooooooooo0000ooooooo6ooooo`009oooool01?l0003oooooooooool00005ooooo`03o`000?oo
oooooooo01;ooooo00Co0000oooooooooooo0000ooooooo6ooooo`009oooool01?l0003ooooooooo
ool00005ooooo`03o`000?oooooooooo01;ooooo00Co0000oooooooooooo0000ooooooo6ooooo`00
9oooool3o`0000Kooooo00?o0000ooooooooool04_ooool01?l0003oooooooooool0003oooooolKo
oooo000Xooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04_ooool01?l0003ooooo
ooooool0003oooooolKooooo000Yooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
4_ooool01?l0003oooooooooool0003oooooolKooooo000`ooooo`03o`000?oooooooooo01;ooooo
00Co0000oooooooooooo0000ooooooo6ooooo`00<?ooool00ol0003oooooooooo`0Booooo`04o`00
0?ooooooooooo`000?ooooooa_ooool0033ooooo00?o0000ooooooooool04oooool00ol0003ooooo
o`00003oooooolKooooo000`ooooo`?o00004oooool00ol0003oooooo`00003oooooolKooooo000`
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooool00000ooooooo6ooooo`00<?ooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooo00000?ooooooa_ooool0033ooooo00?o0000oooooooo
ool04oooool00ol0003oooooo`00003oooooolKooooo000`ooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooool00000ooooooo6ooooo`00<?ooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooo00000?ooooooa_ooool0033ooooo00?o0000ooooooooool04oooool00ol0003oooooo`00003o
ooooolKooooo000`ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooool00000ooooooo6oooo
o`00<?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo00000?ooooooa_ooool0033ooooo
00?o0000ooooooooool04oooool00ol0003oooooo`00003oooooolKooooo000`ooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooool00000ooooooo6ooooo`00<?ooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooo00000?ooooooa_ooool0033ooooo0ol0000Cooooo`03o`000?oooooo0000
0?ooooooa_ooool0033ooooo00?o0000ooooooooool04oooool00ol0003oooooo`00003oooooolKo
oooo000`ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooool00000ooooooo6ooooo`00<?oo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooo00000?ooooooa_ooool0033ooooo00?o0000
ooooooooool04oooool00ol0003oooooo`00003oooooolKooooo000`ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooool00000ooooooo6ooooo`00<?ooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooo00000?ooooooa_ooool0033ooooo00?o0000ooooooooool04oooool00ol0003ooooo
o`00003oooooolKooooo000`ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooool00000oooo
ooo6ooooo`00<?ooool00ol0003oooooooooo`0Cooooo`;o0000ooooooo7ooooo`00<?ooool00ol0
003oooooooooo`0Cooooo`;o0000ooooooo7ooooo`00<?ooool00ol0003oooooooooo`0Cooooo`;o
0000ooooooo7ooooo`00<?ooool3o`0001Cooooo00?o0000ooooooooool0ooooooo5ooooo`00<?oo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo0?ooooooaOooool0033ooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`3oooooolGooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00oooooooooooooa3ooooo
003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooo
oooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool0
0:Cooooo0_l00003ooooo`03okZj^_lb<S;ooooo00Gooooo0_l00005ooooo`03o`000?nj^[[ooooo
0?ooooooE?ooool00:Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00?ooooo0_lb<S;ooooooeGooooo002Aooooo`?o00000_ooool01_lb<S;o410@
ooooooooooook^k^oeEEE@;o000000?oA4A4okZj^_ooool00oooool01_l0003ooooooooooooooooo
V9RHoa0@40;o000000?oZJVYooooooooool00oooool00ol0003oooooooooo`03ooooo`03ohN7Qol0
003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0:ooooo`Co000000?o410@ooooooooool0
0_ooool2ob4Q8@?ooooo00Goc<c<onk^k_ooooook^k^olc<c004ooooo`Co000000So410@oooooooo
ooook^k^oc8b<_l0003o<S8bonk^kQ?ooooo00Ko410@oc8b<_l0003o0000oa0@4?nYZJT2ooooo`06
onk^k_mEEEGo0000o`000?m4A4Co^[Zj0oooool01OmVIVKo0000o`000?m4A4Coc<c<0>cooooo002B
ooooo`05o`000?ooooooooooolc<c?l@41000oooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40Co
oooo00[o0000ooooooooooooooooo`000?nYZJWoEEEEoiRHV?mEEEGo^[Zj1?ooool00ol0003ooooo
ooooo`03ooooo`03olc<c?l0003o410@00cooooo00Go410@okZj^_o^k^koMgMgoa0@4002ooooo`Ko
00001?ooool00ol0003oooooooooo`04ooooo`;o8B4Q0oooool01Oo^k^koEEEEomgMgOmEEEGok^k^
00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01?ooooo00Ko0000
ojVYZOoooooooooookZj^_l00002ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo410@0_ooool01_mV
IVKoMgMgooooooooooooQhN7oa0@4>cooooo002Booooo`05o`000?oooooooooooeEEEOn7QhL00ooo
ool00ol0003oooooooooo`07ooooo`0:o`000?oooooooooooooooolb<S;ok^k^oiRHV?mEEEGogMgM
oa0@40Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00[ooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooo
ooooooooool@41005?ooool01Onj^[[oQhN7ofIVI_mVIVKo410@00;ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`3_ooooo`00T_ooool01Ol0003oooooomgMgOl0003ok^k^00?ooooo
1_l00004ooooo`0;o`000?oooooooooooooooonj^[[oA4A4olc<c?lQ8B7ooooooa0@4?o<c<`00ooo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Cooooo1_l00004ooooo`03o`000?oo
oooooooo00Wooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo
00Go0000ooooooooooooooooo`00000Cooooo`06oc8b<_lQ8B7oMgMgogMgMon7QhOok^k^0_ooool6
o`0000;ooooo00?o0000ooooooooool0koooool009;ooooo0ol000000ol@413oV9RHooooo`02oooo
o`06oeEEEOn7QhOok^k^oooooon7QhOo<S8b1?ooool02ol0003oooooooooooooooook^k^o`000?oo
oooo0000oooooomVIVKoQhN700?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00Wooooo00Goc<c<onk^k_ooooook^k^olc<c006ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000Cooooo`06o`000?nj^[[oooooonk^k_mg
MgOo00000_ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<P;ooooo00KoIVIVogMgMooooooooooo
ohN7Qol0003/ooooo`00T_ooool01Ol0003oooooooooooo<c<co000000?ooooo00Kok^k^oeEEEOl0
003o0000odA4A?o^k^h4ooooo`08o`000?oooooooooooooooomVIVKoV9RHoooooolb<S82okZj^P05
o`000?ooooooooooooooool000004_ooool00ol@413o0000o`000003o`0000gooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41001oooool3
o`0000;ooooo0ol00004ooooo`06ojVYZOlQ8B7o0000o`000?lb<S;o00000_ooool01_o^k^koEEEE
o`000?l0003oA4A4onk^kP;ooooo00Kok^k^ofIVI_l0003o0000odA4A?l0003/ooooo`00T_ooool0
1Ol0003oooooooooooo<c<co000000gooooo00?o0000ooooooooool01?ooool00omVIVKoQhN7oooo
o`04ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0ooooool6ooooo`00TOooool4o`000003oa0@4?nY
ZJWooooo00cooooo0_l00005ooooo`03ojVYZOm4A4Cooooo00?ooooo0_l0000Dooooo`03o`000?oo
oooooooo00cooooo00?oEEEEofIVI_l000005?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00_ooool4o`0000;ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`3oooooo`Kooooo003oooooo`;ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`3oooooo`Kooooo003oooooo`;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3o
ooooo`Kooooo003oooooo`7ooooo0_l00003ooooo`;o0000ooooool8ooooo`00oooooooooooooa3o
oooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooo
oooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?oo
ool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooo
ooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@oooo
o`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooo
oooooa3ooooo003ooooooooooooo4?ooool00001\
\>"],
  ImageRangeCache->{{{0, 525.688}, {324.5, 0}} -> {0, -6.34248*^6, 0, 53093}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0.309017 5.42214e-08 [
[.32684 .29652 -16.5 -12.5 ]
[.32684 .29652 16.5 0 ]
[.54329 .29652 -16.5 -12.5 ]
[.54329 .29652 16.5 0 ]
[.75974 .29652 -22.5 -12.5 ]
[.75974 .29652 22.5 0 ]
[.97619 .29652 -16.5 -12.5 ]
[.97619 .29652 16.5 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 64 6 ]
[.09789 .09213 -34.5 -6.25 ]
[.09789 .09213 0 6.25 ]
[.09789 .20057 -34.5 -6.25 ]
[.09789 .20057 0 6.25 ]
[.09789 .41746 -28.5 -6.25 ]
[.09789 .41746 0 6.25 ]
[.09789 .5259 -28.5 -6.25 ]
[.09789 .5259 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -62.8125 0 ]
[.5 .63053 62.8125 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 .30902 m
.32684 .31527 L
s
gsave
.32684 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 .30902 m
.54329 .31527 L
s
gsave
.54329 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 .30902 m
.75974 .31527 L
s
gsave
.75974 .29652 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 .30902 m
.15368 .31277 L
s
.19697 .30902 m
.19697 .31277 L
s
.24026 .30902 m
.24026 .31277 L
s
.28355 .30902 m
.28355 .31277 L
s
.37013 .30902 m
.37013 .31277 L
s
.41342 .30902 m
.41342 .31277 L
s
.45671 .30902 m
.45671 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.58658 .30902 m
.58658 .31277 L
s
.62987 .30902 m
.62987 .31277 L
s
.67316 .30902 m
.67316 .31277 L
s
.71645 .30902 m
.71645 .31277 L
s
.80303 .30902 m
.80303 .31277 L
s
.84632 .30902 m
.84632 .31277 L
s
.88961 .30902 m
.88961 .31277 L
s
.9329 .30902 m
.9329 .31277 L
s
.0671 .30902 m
.0671 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09213 m
.11664 .09213 L
s
gsave
.09789 .09213 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .20057 m
.11664 .20057 L
s
gsave
.09789 .20057 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .41746 m
.11664 .41746 L
s
gsave
.09789 .41746 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .5259 m
.11664 .5259 L
s
gsave
.09789 .5259 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.11039 .11924 m
.11414 .11924 L
s
.11039 .14635 m
.11414 .14635 L
s
.11039 .17346 m
.11414 .17346 L
s
.11039 .22768 m
.11414 .22768 L
s
.11039 .2548 m
.11414 .2548 L
s
.11039 .28191 m
.11414 .28191 L
s
.11039 .33613 m
.11414 .33613 L
s
.11039 .36324 m
.11414 .36324 L
s
.11039 .39035 m
.11414 .39035 L
s
.11039 .44457 m
.11414 .44457 L
s
.11039 .47168 m
.11414 .47168 L
s
.11039 .49879 m
.11414 .49879 L
s
.11039 .06502 m
.11414 .06502 L
s
.11039 .03791 m
.11414 .03791 L
s
.11039 .0108 m
.11414 .0108 L
s
.11039 .55301 m
.11414 .55301 L
s
.11039 .58012 m
.11414 .58012 L
s
.11039 .60723 m
.11414 .60723 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -123.812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.812 moveto
(@) show
81.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.812 moveto
(D) show
93.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.2) show
135.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
141.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
153.000 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
157.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
166.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
184.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02453 .30902 L
.02532 .30902 L
.02614 .30902 L
.02691 .30902 L
.02854 .30901 L
.03029 .30901 L
.03362 .30899 L
.03443 .30899 L
.03529 .30899 L
.03602 .30898 L
.03643 .30898 L
.03664 .30898 L
.03682 .30898 L
.03701 .30898 L
.03712 .30898 L
.03717 .30898 L
.03722 .30898 L
.03732 .30898 L
.03742 .30898 L
.03751 .30898 L
.0376 .30898 L
.03769 .30898 L
.03776 .30898 L
.03785 .30898 L
.03795 .30898 L
.03814 .30898 L
.03831 .30898 L
.03851 .30898 L
.0387 .30898 L
.03913 .30899 L
.03951 .30899 L
.03991 .30899 L
.04066 .309 L
.04147 .309 L
.04224 .30901 L
.04294 .30902 L
.04446 .30906 L
.04612 .3091 L
.04937 .3092 L
.05088 .30925 L
.05129 .30925 L
.05173 .30926 L
.0521 .30927 L
.05231 .30927 L
.05251 .30927 L
.05262 .30927 L
.05273 .30928 L
.05284 .30928 L
.05294 .30928 L
Mistroke
.05299 .30928 L
.05305 .30928 L
.05311 .30928 L
.05317 .30928 L
.05323 .30928 L
.05329 .30928 L
.05339 .30928 L
.05349 .30928 L
.0536 .30928 L
.0537 .30927 L
.05379 .30927 L
.05401 .30927 L
.05422 .30927 L
.05462 .30926 L
.055 .30925 L
.05541 .30924 L
.05584 .30922 L
.05659 .30918 L
.05741 .30911 L
.05887 .30896 L
.06049 .30874 L
.06218 .30844 L
.06524 .30788 L
.06605 .30775 L
.06682 .30765 L
.06724 .30761 L
.06747 .30759 L
.0677 .30757 L
.0679 .30756 L
.06801 .30756 L
.06812 .30755 L
.06822 .30755 L
.06832 .30755 L
.06841 .30755 L
.0685 .30755 L
.06859 .30755 L
.06869 .30755 L
.06879 .30755 L
.06887 .30755 L
.06897 .30755 L
.06907 .30756 L
.06928 .30757 L
.06948 .30758 L
.0697 .3076 L
.0701 .30764 L
.0705 .30771 L
.07087 .30778 L
.07158 .30796 L
.07236 .30822 L
.07318 .30858 L
Mistroke
.07466 .30941 L
.0777 .31177 L
.07939 .31321 L
.08094 .31437 L
.0817 .31482 L
.0821 .31501 L
.08253 .31517 L
.08275 .31524 L
.08295 .31528 L
.08313 .31532 L
.08323 .31533 L
.08332 .31534 L
.08341 .31535 L
.08349 .31535 L
.08358 .31536 L
.08367 .31536 L
.08378 .31535 L
.08387 .31535 L
.08396 .31534 L
.08405 .31533 L
.08424 .31529 L
.08444 .31525 L
.08463 .31518 L
.0848 .31512 L
.08521 .31492 L
.08564 .31463 L
.08644 .31389 L
.08732 .31275 L
.0889 .30987 L
.09058 .30572 L
.09391 .29582 L
.09473 .29354 L
.09559 .2914 L
.09638 .28977 L
.09677 .28913 L
.09713 .28865 L
.0973 .28845 L
.09749 .28826 L
.09767 .28812 L
.09784 .28802 L
.09793 .28797 L
.09803 .28793 L
.09813 .2879 L
.09823 .28788 L
.09832 .28787 L
.09842 .28787 L
.09851 .28787 L
.0986 .28789 L
.09865 .28791 L
.09871 .28793 L
Mistroke
.09881 .28797 L
.099 .28808 L
.09923 .28827 L
.09943 .2885 L
.09981 .28905 L
.10021 .28983 L
.10097 .29185 L
.10178 .29487 L
.10325 .30249 L
.10495 .31432 L
.10656 .32757 L
.10817 .34119 L
.10962 .35228 L
.11038 .35702 L
.1112 .36102 L
.11165 .36263 L
.11185 .36318 L
.11207 .36368 L
.11227 .36405 L
.11237 .36418 L
.11247 .36429 L
.11257 .36438 L
.11267 .36443 L
.11277 .36447 L
.11283 .36447 L
.11288 .36447 L
.11298 .36444 L
.11308 .36438 L
.11316 .36431 L
.11326 .36421 L
.11346 .3639 L
.11366 .36349 L
.11401 .36245 L
.11438 .36092 L
.11483 .35853 L
.11525 .35569 L
.11604 .34887 L
.11764 .32912 L
.11912 .30505 L
.12228 .24537 L
.12387 .2187 L
.12457 .20929 L
.12532 .20119 L
.12574 .19786 L
.12594 .19654 L
.12612 .19553 L
.1263 .19472 L
.12649 .19404 L
.1266 .19376 L
.12669 .19355 L
Mistroke
.12679 .19339 L
.12688 .19329 L
.12699 .19324 L
.12708 .19324 L
.12714 .19327 L
.12719 .19332 L
.1273 .19346 L
.1274 .19365 L
.1275 .19391 L
.12768 .19454 L
.1279 .19555 L
.1281 .19675 L
.12856 .20045 L
.12894 .20449 L
.12935 .20993 L
.13018 .22411 L
.13167 .25937 L
.13493 .36652 L
.13643 .4183 L
.13807 .46567 L
.1385 .47573 L
.13896 .48491 L
.13938 .49194 L
.13978 .49712 L
.14015 .5007 L
.14036 .50214 L
.14055 .50309 L
.14066 .50347 L
.14076 .50373 L
.14081 .50382 L
.14087 .50389 L
.14093 .50393 L
.14099 .50393 L
.14109 .50385 L
.14119 .50368 L
.14129 .5034 L
.1414 .50297 L
.14161 .50184 L
.1418 .50038 L
.14216 .49657 L
.14256 .49094 L
.14298 .48303 L
.14375 .4642 L
.14446 .44182 L
.14596 .3805 L
.14761 .29775 L
.1493 .20823 L
.15085 .13345 L
.15161 .10239 L
.15244 .07474 L
Mistroke
.15283 .06461 L
.15323 .05572 L
.15361 .04923 L
.15396 .045 L
.15415 .04341 L
.15425 .04271 L
.15435 .0422 L
.15446 .04181 L
.15455 .04159 L
.15461 .04152 L
.15466 .04149 L
.15477 .04155 L
.15486 .04172 L
.15495 .04204 L
.15506 .04252 L
.15515 .04311 L
.15532 .04448 L
.15551 .04642 L
.15593 .05273 L
.15638 .0621 L
.15718 .08564 L
.15794 .11585 L
.15876 .15545 L
.16024 .24159 L
.16184 .34662 L
.16357 .45769 L
.16438 .50353 L
.16524 .54505 L
.16597 .57347 L
.16636 .58549 L
.16678 .59609 L
.167 .60052 L
.1672 .60397 L
.16741 .60686 L
.1676 .60888 L
.16768 .60964 L
.16778 .61031 L
.16787 .61081 L
.16796 .61114 L
.16805 .61137 L
.16814 .61148 L
.16825 .61142 L
.16834 .61121 L
.16845 .61081 L
.1685 .61051 L
.16856 .61017 L
.16876 .60848 L
.16895 .60634 L
.16915 .60345 L
.16956 .59545 L
Mistroke
.17002 .58356 L
.17083 .55471 L
.17157 .52054 L
.17325 .42238 L
.17643 .20568 L
.17726 .15508 L
.17804 .11312 L
.1788 .079 L
.1795 .05438 L
.17987 .04425 L
.18026 .03579 L
.18044 .03254 L
.18065 .02967 L
.18076 .02831 L
.18087 .02726 L
.18097 .02645 L
.18108 .02573 L
.18118 .02522 L
.18124 .02501 L
.18129 .02486 L
.18139 .02471 L
.18149 .02471 L
.18154 .02478 L
.1816 .02491 L
.18167 .02511 L
.18172 .02535 L
.18183 .02591 L
.18194 .0267 L
.18216 .02883 L
.18237 .03154 L
.18276 .03837 L
.18313 .04694 L
.18354 .05862 L
.18436 .08883 L
.18584 .16115 L
.18908 .35428 L
.19057 .43389 L
.19136 .46841 L
.1922 .49781 L
.19266 .51042 L
.19308 .51951 L
.19328 .52308 L
.1935 .52633 L
.1937 .52881 L
.19389 .53063 L
.19409 .53197 L
.19419 .53248 L
.19425 .53271 L
.1943 .53287 L
.19436 .53301 L
Mistroke
.19442 .53311 L
.19447 .53316 L
.19453 .53317 L
.19463 .5331 L
.19468 .533 L
.19473 .53287 L
.19483 .53254 L
.19493 .53208 L
.19511 .53093 L
.1953 .52926 L
.19551 .52691 L
.19593 .52052 L
.19633 .51259 L
.19708 .49321 L
.19876 .43242 L
.20185 .29435 L
.20342 .2323 L
.20425 .20576 L
.20471 .19348 L
.20514 .1835 L
.20555 .17564 L
.206 .16884 L
.20619 .16644 L
.2064 .16428 L
.2066 .16263 L
.20678 .16144 L
.20698 .16047 L
.20708 .1601 L
.20713 .15996 L
.20719 .15983 L
.20729 .15968 L
.20738 .15962 L
.20743 .15962 L
.20748 .15964 L
.20758 .15975 L
.20767 .15992 L
.20776 .16018 L
.20793 .16083 L
.20811 .16181 L
.20831 .1632 L
.20872 .16717 L
.20912 .17221 L
.20986 .18468 L
.21154 .224 L
.2146 .31146 L
.21549 .33433 L
.21632 .35323 L
.21712 .36853 L
.21787 .37957 L
.21825 .38401 L
Mistroke
.2186 .3874 L
.21897 .39018 L
.21917 .39132 L
.21937 .39231 L
.21958 .39305 L
.2197 .39336 L
.21981 .39357 L
.21991 .39371 L
.22001 .39379 L
.22007 .39381 L
.22012 .39382 L
.22023 .39379 L
.22032 .3937 L
.22043 .39356 L
.22053 .39335 L
.22063 .39311 L
.22081 .39253 L
.22101 .39174 L
.22143 .38936 L
.22183 .38644 L
.22272 .37757 L
.22434 .35555 L
.22597 .32969 L
.2275 .30638 L
.22897 .28785 L
.22979 .27984 L
.23054 .27426 L
.23092 .27207 L
.23133 .27024 L
.23153 .26953 L
.23172 .26898 L
.23188 .26857 L
.23207 .26822 L
.23217 .26807 L
.23227 .26794 L
.23233 .26788 L
.23238 .26784 L
.23248 .26778 L
.23258 .26775 L
.23268 .26774 L
.23278 .26776 L
.23287 .2678 L
.23297 .26788 L
.23307 .26797 L
.23329 .26828 L
.2335 .2687 L
.23373 .26927 L
.23413 .27055 L
.2345 .27204 L
.23534 .27636 L
Mistroke
.23704 .28781 L
.24018 .3106 L
.241 .31546 L
.24189 .3198 L
.2423 .32143 L
.24273 .3229 L
.24314 .32404 L
.24351 .32488 L
.2437 .32523 L
.2439 .32556 L
.24408 .32579 L
.24427 .326 L
.24447 .32617 L
.24459 .32624 L
.24469 .32629 L
.24479 .32632 L
.24488 .32635 L
.24498 .32636 L
.24508 .32635 L
.24518 .32634 L
.24526 .32632 L
.24536 .32629 L
.24545 .32625 L
.24561 .32615 L
.24579 .32601 L
.24619 .32558 L
.24656 .32504 L
.24733 .32353 L
.24806 .32174 L
.24972 .31686 L
.2512 .31226 L
.25283 .30788 L
.25371 .30599 L
.25453 .30461 L
.25531 .30364 L
.25574 .30325 L
.25593 .30311 L
.25614 .30299 L
.25633 .30289 L
.25653 .30281 L
.25664 .30278 L
.25674 .30275 L
.25685 .30273 L
.25694 .30271 L
.25703 .3027 L
.25713 .3027 L
.25722 .30269 L
.25732 .3027 L
.25741 .3027 L
.25751 .30271 L
Mistroke
.2576 .30272 L
.25768 .30274 L
.25789 .30279 L
.25807 .30285 L
.2585 .30304 L
.25891 .30329 L
.25936 .30361 L
.26107 .30526 L
.26269 .30706 L
.26416 .30858 L
.265 .30932 L
.26578 .3099 L
.26655 .31036 L
.26694 .31054 L
.26737 .31071 L
.26783 .31085 L
.26803 .3109 L
.26826 .31094 L
.26848 .31098 L
.26867 .311 L
.26877 .31101 L
.26887 .31102 L
.26897 .31102 L
.26906 .31103 L
.26916 .31103 L
.26926 .31103 L
.26935 .31103 L
.26944 .31103 L
.26954 .31103 L
.2696 .31102 L
.26965 .31102 L
.26985 .31101 L
.27003 .31099 L
.27022 .31097 L
.27058 .31091 L
.27102 .31082 L
.27144 .31072 L
.27224 .31049 L
.2753 .30944 L
.27618 .30917 L
.27701 .30895 L
.27782 .30877 L
.27856 .30864 L
.2793 .30855 L
.27967 .30851 L
.28007 .30849 L
.28028 .30847 L
.28048 .30847 L
.28059 .30846 L
.2807 .30846 L
Mistroke
.28081 .30846 L
.28091 .30846 L
.28101 .30846 L
.2811 .30845 L
.28119 .30845 L
.2813 .30845 L
.2814 .30846 L
.28145 .30846 L
.28151 .30846 L
.2817 .30846 L
.28181 .30846 L
.28191 .30847 L
.28213 .30847 L
.28253 .30849 L
.28328 .30854 L
.28496 .30869 L
.28659 .30884 L
.28812 .30898 L
.28887 .30903 L
.28958 .30907 L
.29041 .30911 L
.29116 .30913 L
.29156 .30914 L
.29193 .30915 L
.29213 .30915 L
.29224 .30915 L
.29235 .30915 L
.29245 .30915 L
.29256 .30915 L
.29266 .30916 L
.29275 .30916 L
.29284 .30916 L
.29294 .30916 L
.29304 .30916 L
.29312 .30916 L
.2932 .30916 L
.29329 .30915 L
.29338 .30915 L
.29346 .30915 L
.29365 .30915 L
.29383 .30915 L
.29423 .30915 L
.29501 .30913 L
.29575 .30912 L
.29741 .30908 L
.29892 .30905 L
.30055 .30902 L
.30144 .309 L
.30183 .309 L
.30226 .309 L
Mistroke
.30264 .30899 L
.30305 .30899 L
.30327 .30899 L
.30348 .30899 L
.30367 .30899 L
.30388 .30899 L
.30398 .30899 L
.30408 .30899 L
.30417 .30899 L
.30427 .30899 L
.30437 .30899 L
.30443 .30899 L
.30448 .30899 L
.30457 .30899 L
.30467 .30899 L
.30477 .30899 L
.30487 .30899 L
.30497 .30899 L
.30506 .30899 L
.30523 .30899 L
.30541 .30899 L
.30582 .30899 L
.3062 .30899 L
.30707 .30899 L
.31019 .30901 L
.311 .30901 L
.31188 .30902 L
.31273 .30902 L
.3135 .30902 L
.31389 .30902 L
.31431 .30902 L
.31471 .30902 L
.31508 .30902 L
.31528 .30902 L
.31547 .30902 L
.31557 .30902 L
.31567 .30902 L
.31573 .30902 L
.31579 .30902 L
.31584 .30902 L
.31589 .30902 L
.316 .30902 L
.31605 .30902 L
.31611 .30902 L
.31617 .30902 L
.31623 .30902 L
.31629 .30902 L
.31634 .30902 L
.31645 .30902 L
.31656 .30902 L
Mistroke
.31676 .30902 L
.31697 .30902 L
.31719 .30902 L
.31758 .30902 L
.31847 .30902 L
.32009 .30902 L
.32168 .30902 L
.32313 .30902 L
.32393 .30902 L
.32469 .30902 L
.32508 .30902 L
.3255 .30902 L
.32595 .30902 L
.32637 .30902 L
.32658 .30902 L
.3268 .30902 L
.32699 .30902 L
.3271 .30902 L
.3272 .30902 L
.32725 .30902 L
.32731 .30902 L
.32737 .30902 L
.32742 .30902 L
.32752 .30902 L
.32763 .30902 L
.32768 .30902 L
.32774 .30902 L
.32785 .30902 L
.32798 .30902 L
.32809 .30902 L
.32847 .30902 L
.32888 .30902 L
.32971 .30902 L
.33142 .30902 L
.33297 .30902 L
.33375 .30902 L
.33459 .30902 L
.33538 .30902 L
.33611 .30902 L
.33649 .30902 L
.33689 .30902 L
.33727 .30902 L
.33762 .30902 L
.33783 .30902 L
.33803 .30902 L
.33813 .30902 L
.33824 .30902 L
.3383 .30902 L
.33836 .30902 L
.33842 .30902 L
Mistroke
.33847 .30902 L
.33857 .30902 L
.33862 .30902 L
.33868 .30902 L
.33873 .30902 L
.33879 .30902 L
.33889 .30902 L
.33899 .30902 L
.33908 .30902 L
.33928 .30902 L
.33947 .30902 L
.33965 .30902 L
.34005 .30902 L
.34078 .30902 L
.34244 .30902 L
.34409 .30902 L
.3449 .30902 L
.34563 .30902 L
.34634 .30902 L
.34711 .30902 L
.34754 .30902 L
.34793 .30902 L
.3483 .30902 L
.34869 .30902 L
.3489 .30902 L
.34909 .30902 L
.34927 .30902 L
.34937 .30902 L
.34946 .30902 L
.34955 .30902 L
.34964 .30902 L
.34974 .30902 L
.3498 .30902 L
.34985 .30902 L
.34995 .30902 L
.35001 .30902 L
.35006 .30902 L
.35016 .30902 L
.35027 .30902 L
.35046 .30902 L
.35067 .30902 L
.35104 .30902 L
.35174 .30902 L
.35331 .30902 L
.35503 .30902 L
.35582 .30902 L
.35667 .30902 L
.35747 .30902 L
.3582 .30902 L
.35858 .30902 L
Mistroke
.35899 .30902 L
.35937 .30902 L
.35972 .30902 L
.35994 .30902 L
.36014 .30902 L
.36024 .30902 L
.36035 .30902 L
.36041 .30902 L
.36047 .30902 L
.36053 .30902 L
.36058 .30902 L
.36069 .30902 L
.36074 .30902 L
.3608 .30902 L
.3609 .30902 L
.36095 .30902 L
.361 .30902 L
.3611 .30902 L
.36119 .30902 L
.36139 .30902 L
.36159 .30902 L
.36177 .30902 L
.36218 .30902 L
.36291 .30902 L
.36458 .30902 L
.36625 .30902 L
.36698 .30902 L
.36779 .30902 L
.36857 .30902 L
.36929 .30902 L
.3697 .30902 L
.37006 .30902 L
.37026 .30902 L
.37048 .30902 L
.37068 .30902 L
.37088 .30902 L
.37098 .30902 L
.37109 .30902 L
.37118 .30902 L
.37127 .30902 L
.37136 .30902 L
.37145 .30902 L
.37155 .30902 L
.37164 .30902 L
.37169 .30902 L
.37175 .30902 L
.37184 .30902 L
.37195 .30902 L
.37201 .30902 L
.37207 .30902 L
Mistroke
.37226 .30902 L
.37247 .30902 L
.37292 .30902 L
.37335 .30902 L
.37416 .30902 L
.37577 .30902 L
.37723 .30902 L
.37799 .30902 L
.37881 .30902 L
.37926 .30902 L
.37968 .30902 L
.38007 .30902 L
.38049 .30902 L
.3809 .30902 L
.38128 .30902 L
.38146 .30902 L
.38165 .30902 L
.38184 .30902 L
.38201 .30902 L
.3821 .30902 L
.3822 .30902 L
.3823 .30902 L
.38239 .30902 L
.38249 .30902 L
.38254 .30902 L
.38259 .30902 L
.3827 .30902 L
.38276 .30902 L
.38281 .30902 L
.38302 .30902 L
.38325 .30902 L
.38367 .30902 L
.38443 .30902 L
.38526 .30902 L
.38695 .30902 L
.38852 .30902 L
.38939 .30902 L
.38978 .30902 L
.39019 .30902 L
.39057 .30902 L
.39099 .30902 L
.39137 .30902 L
.39172 .30902 L
.39193 .30902 L
.39214 .30902 L
.39232 .30902 L
.39252 .30902 L
.39264 .30902 L
.39274 .30902 L
.3928 .30902 L
Mistroke
.39286 .30902 L
.39292 .30902 L
.39297 .30902 L
.39307 .30902 L
.39317 .30902 L
.39323 .30902 L
.39329 .30902 L
.39339 .30902 L
.3935 .30902 L
.39359 .30902 L
.39381 .30902 L
.3942 .30902 L
.39466 .30902 L
.39509 .30902 L
.3967 .30902 L
.39817 .30902 L
.39901 .30902 L
.39979 .30902 L
.40057 .30902 L
.401 .30902 L
.4014 .30902 L
.40181 .30902 L
.40203 .30902 L
.40226 .30902 L
.40247 .30902 L
.40269 .30902 L
.4029 .30902 L
.40309 .30902 L
.40318 .30902 L
.40328 .30902 L
.40338 .30902 L
.40346 .30902 L
.40357 .30902 L
.40362 .30902 L
.40368 .30902 L
.40377 .30902 L
.40388 .30902 L
.40397 .30902 L
.40408 .30902 L
.40427 .30902 L
.4045 .30902 L
.40471 .30902 L
.40547 .30902 L
.40619 .30902 L
.4078 .30902 L
.40926 .30902 L
.41008 .30902 L
.41085 .30902 L
.41124 .30902 L
.41166 .30902 L
Mistroke
.41211 .30902 L
.41253 .30902 L
.41274 .30902 L
.41293 .30902 L
.41311 .30902 L
.41329 .30902 L
.41339 .30902 L
.4135 .30902 L
.4136 .30902 L
.41369 .30902 L
.41379 .30902 L
.41385 .30902 L
.41391 .30902 L
.414 .30902 L
.41406 .30902 L
.41411 .30902 L
.4142 .30902 L
.4143 .30902 L
.4144 .30902 L
.41448 .30902 L
.41465 .30902 L
.41482 .30902 L
.41519 .30902 L
.41558 .30902 L
.41728 .30902 L
.41883 .30902 L
.41959 .30902 L
.42043 .30902 L
.42122 .30902 L
.42195 .30902 L
.42232 .30902 L
.42272 .30902 L
.4231 .30902 L
.42345 .30902 L
.42364 .30902 L
.42383 .30902 L
.42394 .30902 L
.42403 .30902 L
.42409 .30902 L
.42414 .30902 L
.42425 .30902 L
.42435 .30902 L
.42441 .30902 L
.42446 .30902 L
.42452 .30902 L
.42457 .30902 L
.42463 .30902 L
.42469 .30902 L
.42479 .30902 L
.42489 .30902 L
Mistroke
.4251 .30902 L
.42531 .30902 L
.42551 .30902 L
.42595 .30902 L
.42675 .30902 L
.42824 .30902 L
.42975 .30902 L
.43061 .30902 L
.43141 .30902 L
.43182 .30902 L
.43225 .30902 L
.43267 .30902 L
.43305 .30902 L
.43339 .30902 L
.43359 .30902 L
.43377 .30902 L
.43396 .30902 L
.43414 .30902 L
.43423 .30902 L
.43434 .30902 L
.43444 .30902 L
.43454 .30902 L
.43464 .30902 L
.43469 .30902 L
.43475 .30902 L
.43485 .30902 L
.43495 .30902 L
.435 .30902 L
.43506 .30902 L
.43516 .30902 L
.43538 .30902 L
.43558 .30902 L
.43577 .30902 L
.43618 .30902 L
.43768 .30902 L
.43919 .30902 L
.43998 .30902 L
.44082 .30902 L
.44125 .30902 L
.44172 .30902 L
.44215 .30902 L
.44255 .30902 L
.44295 .30902 L
.44316 .30902 L
.44339 .30902 L
.44359 .30902 L
.44379 .30902 L
.44399 .30902 L
.44417 .30902 L
.44426 .30902 L
Mistroke
.44436 .30902 L
.44445 .30902 L
.44454 .30902 L
.44464 .30902 L
.4447 .30902 L
.44475 .30902 L
.44484 .30902 L
.44494 .30902 L
.44503 .30902 L
.44513 .30902 L
.44523 .30902 L
.44532 .30902 L
.44549 .30902 L
.44567 .30902 L
.44611 .30902 L
.44654 .30902 L
.44733 .30902 L
.44879 .30902 L
.44962 .30902 L
.4504 .30902 L
.45117 .30902 L
.45199 .30902 L
.45242 .30902 L
.45287 .30902 L
.45325 .30902 L
.45368 .30902 L
.45388 .30902 L
.4541 .30902 L
.4542 .30902 L
.45431 .30902 L
.4544 .30902 L
.4545 .30902 L
.4546 .30902 L
.45468 .30902 L
.45477 .30902 L
.45486 .30902 L
.45495 .30902 L
.45504 .30902 L
.45514 .30902 L
.45525 .30902 L
.45536 .30902 L
.45547 .30902 L
.4557 .30902 L
.45613 .30902 L
.45693 .30902 L
.45857 .30902 L
.45938 .30902 L
.4601 .30902 L
.46086 .30902 L
.46158 .30902 L
Mistroke
.46234 .30902 L
.46276 .30902 L
.46316 .30902 L
.46353 .30902 L
.46374 .30902 L
.46393 .30902 L
.4641 .30902 L
.46429 .30902 L
.46438 .30902 L
.46448 .30902 L
.46457 .30902 L
.46466 .30902 L
.46476 .30902 L
.46481 .30902 L
.46487 .30902 L
.46497 .30902 L
.46507 .30902 L
.46512 .30902 L
.46518 .30902 L
.46528 .30902 L
.46539 .30902 L
.46551 .30902 L
.46593 .30902 L
.46631 .30902 L
.46794 .30902 L
.46873 .30902 L
.46946 .30902 L
.47016 .30902 L
.47092 .30902 L
.47168 .30902 L
.4721 .30902 L
.47249 .30902 L
.47289 .30902 L
.47311 .30902 L
.47333 .30902 L
.47353 .30902 L
.47375 .30902 L
.47394 .30902 L
.47413 .30902 L
.47422 .30902 L
.47432 .30902 L
.47441 .30902 L
.4745 .30902 L
.4746 .30902 L
.47468 .30902 L
.47477 .30902 L
.47485 .30902 L
.47494 .30902 L
.47504 .30902 L
.47513 .30902 L
Mistroke
.47522 .30902 L
.47543 .30902 L
.47562 .30902 L
.47602 .30902 L
.47646 .30902 L
.47726 .30902 L
.47875 .30902 L
.47956 .30902 L
.48033 .30902 L
.48114 .30902 L
.48156 .30902 L
.48202 .30902 L
.48242 .30902 L
.48279 .30902 L
.4832 .30902 L
.48342 .30902 L
.48363 .30902 L
.48385 .30902 L
.48405 .30902 L
.48415 .30902 L
.48427 .30902 L
.48433 .30902 L
.48439 .30902 L
.48445 .30902 L
.4845 .30902 L
.48461 .30902 L
.4847 .30902 L
.48476 .30902 L
.48481 .30902 L
.48487 .30902 L
.48492 .30902 L
.48512 .30902 L
.48522 .30902 L
.48532 .30902 L
.4857 .30902 L
.48611 .30902 L
.48684 .30902 L
.4885 .30902 L
.48932 .30902 L
.49021 .30902 L
.49062 .30902 L
.49105 .30902 L
.49145 .30902 L
.49182 .30902 L
.49221 .30902 L
.49258 .30902 L
.49297 .30902 L
.49319 .30902 L
.49339 .30902 L
.49358 .30902 L
Mistroke
.49376 .30902 L
.49393 .30902 L
.49402 .30902 L
.4941 .30902 L
.49419 .30902 L
.49428 .30902 L
.49437 .30902 L
.49447 .30902 L
.49458 .30902 L
.49467 .30902 L
.49476 .30902 L
.49486 .30902 L
.49525 .30902 L
.49561 .30902 L
.49645 .30902 L
.49813 .30902 L
.49892 .30902 L
.49975 .30902 L
.50046 .30902 L
.50086 .30902 L
.50124 .30902 L
.50164 .30902 L
.50208 .30902 L
.50228 .30902 L
.5025 .30902 L
.50268 .30902 L
.50288 .30902 L
.50307 .30902 L
.50324 .30902 L
.50342 .30902 L
.50359 .30902 L
.50368 .30902 L
.50378 .30902 L
.50388 .30902 L
.50396 .30902 L
.50406 .30902 L
.50412 .30902 L
.50417 .30902 L
.50427 .30902 L
.50437 .30902 L
.50457 .30902 L
.50477 .30902 L
.50513 .30902 L
.50595 .30902 L
.50742 .30902 L
.5082 .30902 L
.50902 .30902 L
.50972 .30902 L
.5105 .30902 L
.5109 .30902 L
Mistroke
.51131 .30902 L
.51167 .30902 L
.51206 .30902 L
.51228 .30902 L
.51248 .30902 L
.51271 .30902 L
.51281 .30902 L
.51292 .30902 L
.51302 .30902 L
.51313 .30902 L
.51322 .30902 L
.51331 .30902 L
.51342 .30902 L
.51351 .30902 L
.51357 .30902 L
.51362 .30902 L
.51373 .30902 L
.51383 .30902 L
.51392 .30902 L
.51412 .30902 L
.5143 .30902 L
.51448 .30902 L
.51531 .30902 L
.517 .30902 L
.51776 .30902 L
.51858 .30902 L
.51935 .30902 L
.52006 .30902 L
.52044 .30902 L
.52085 .30902 L
.52121 .30902 L
.52159 .30902 L
.52181 .30902 L
.52201 .30902 L
.52224 .30902 L
.52234 .30902 L
.52245 .30902 L
.52256 .30902 L
.52265 .30902 L
.52275 .30902 L
.52284 .30902 L
.52295 .30902 L
.52304 .30902 L
.52309 .30902 L
.52315 .30902 L
.52321 .30902 L
.52326 .30902 L
.52336 .30902 L
.52347 .30902 L
.52366 .30902 L
Mistroke
.52387 .30902 L
.5241 .30902 L
.52489 .30902 L
.52638 .30902 L
.52714 .30902 L
.52794 .30902 L
.52835 .30902 L
.52881 .30902 L
.5292 .30902 L
.52961 .30902 L
.53004 .30902 L
.53044 .30902 L
.53083 .30902 L
.53119 .30902 L
.53139 .30902 L
.53158 .30902 L
.53178 .30902 L
.5319 .30902 L
.532 .30902 L
.53211 .30902 L
.53222 .30902 L
.53227 .30902 L
.53233 .30902 L
.53239 .30902 L
.53245 .30902 L
.53255 .30902 L
.53265 .30902 L
.5327 .30902 L
.53276 .30902 L
.53287 .30902 L
.53307 .30902 L
.53329 .30902 L
.53369 .30902 L
.53444 .30902 L
.53524 .30902 L
.53612 .30902 L
.53688 .30902 L
.53771 .30902 L
.53816 .30902 L
.53858 .30902 L
.53897 .30902 L
.5394 .30902 L
.53981 .30902 L
.54018 .30902 L
.54037 .30902 L
.54056 .30902 L
.54075 .30902 L
.54092 .30902 L
.54112 .30902 L
.54122 .30902 L
Mistroke
.54134 .30902 L
.5414 .30902 L
.54146 .30902 L
.54151 .30902 L
.54157 .30902 L
.54162 .30902 L
.54168 .30902 L
.54178 .30902 L
.54189 .30902 L
.54198 .30902 L
.54209 .30902 L
.54214 .30902 L
.54219 .30902 L
.54239 .30902 L
.54258 .30902 L
.54342 .30902 L
.54422 .30902 L
.54571 .30902 L
.54649 .30902 L
.54692 .30902 L
.54732 .30902 L
.54802 .30902 L
.5484 .30902 L
.5488 .30902 L
.54922 .30902 L
.54961 .30902 L
.54984 .30902 L
.55004 .30902 L
.55015 .30902 L
.55027 .30902 L
.55039 .30902 L
.5505 .30902 L
.5506 .30902 L
.55069 .30902 L
.55079 .30902 L
.55085 .30902 L
.5509 .30902 L
.55096 .30902 L
.55101 .30902 L
.55111 .30902 L
.55117 .30902 L
.55122 .30902 L
.55128 .30902 L
.55134 .30902 L
.55143 .30902 L
.55153 .30902 L
.55174 .30902 L
.55211 .30902 L
.55382 .30902 L
.55462 .30902 L
Mistroke
.55537 .30902 L
.55614 .30902 L
.55655 .30902 L
.55698 .30902 L
.55733 .30902 L
.55771 .30902 L
.55812 .30902 L
.5585 .30902 L
.55871 .30902 L
.55893 .30902 L
.55911 .30902 L
.55932 .30902 L
.55944 .30902 L
.55956 .30902 L
.55967 .30902 L
.55978 .30902 L
.55989 .30902 L
.55999 .30902 L
.56009 .30902 L
.56015 .30902 L
.5602 .30902 L
.5603 .30902 L
.56036 .30902 L
.56041 .30902 L
.56051 .30902 L
.5606 .30902 L
.56071 .30902 L
.56081 .30902 L
.56103 .30902 L
.56182 .30902 L
.56347 .30902 L
.56428 .30902 L
.56501 .30902 L
.56537 .30902 L
.56577 .30902 L
.56649 .30902 L
.56689 .30902 L
.56731 .30902 L
.56767 .30902 L
.56807 .30902 L
.56827 .30902 L
.56849 .30902 L
.56859 .30902 L
.5687 .30902 L
.56879 .30902 L
.56889 .30902 L
.56898 .30902 L
.56907 .30902 L
.56916 .30902 L
.56924 .30902 L
Mistroke
.56934 .30902 L
.56943 .30902 L
.56953 .30902 L
.56964 .30902 L
.56969 .30902 L
.56975 .30902 L
.56985 .30902 L
.57009 .30902 L
.57052 .30902 L
.57131 .30902 L
.57213 .30902 L
.5729 .30902 L
.57366 .30902 L
.57436 .30902 L
.5751 .30902 L
.5755 .30902 L
.57592 .30902 L
.57637 .30902 L
.57659 .30902 L
.5768 .30902 L
.57718 .30902 L
.57738 .30902 L
.57759 .30902 L
.57769 .30902 L
.5778 .30902 L
.57789 .30902 L
.57799 .30902 L
.57808 .30902 L
.57818 .30902 L
.57827 .30902 L
.57836 .30902 L
.57846 .30902 L
.57856 .30902 L
.57865 .30902 L
.57875 .30902 L
.57885 .30902 L
.57897 .30902 L
.57917 .30902 L
.57957 .30902 L
.57994 .30902 L
.58064 .30902 L
.58212 .30902 L
.58295 .30902 L
.58336 .30902 L
.58374 .30902 L
.5841 .30902 L
.58451 .30902 L
.58493 .30902 L
.58533 .30902 L
.58576 .30902 L
Mistroke
.58597 .30902 L
.58621 .30902 L
.58641 .30902 L
.58663 .30902 L
.58673 .30902 L
.58684 .30902 L
.58693 .30902 L
.58702 .30902 L
.58712 .30902 L
.58717 .30902 L
.58723 .30902 L
.58732 .30902 L
.58742 .30902 L
.58751 .30902 L
.58761 .30902 L
.5877 .30902 L
.58779 .30902 L
.58799 .30902 L
.58821 .30902 L
.58861 .30902 L
.59008 .30902 L
.59089 .30902 L
.59166 .30902 L
.59208 .30902 L
.59254 .30902 L
.59296 .30902 L
.59334 .30902 L
.59371 .30902 L
.59411 .30902 L
.59433 .30902 L
.59454 .30902 L
.59494 .30902 L
.59515 .30902 L
.59537 .30902 L
.59555 .30902 L
.59575 .30902 L
.59587 .30902 L
.59597 .30902 L
.59609 .30902 L
.59615 .30902 L
.59621 .30902 L
.59626 .30902 L
.59632 .30902 L
.59637 .30902 L
.59643 .30902 L
.59653 .30902 L
.59658 .30902 L
.59664 .30902 L
.59674 .30902 L
.59683 .30902 L
Mistroke
.59701 .30902 L
.59741 .30902 L
.59814 .30902 L
.59894 .30902 L
.5998 .30902 L
.60064 .30902 L
.60139 .30902 L
.60176 .30902 L
.60215 .30902 L
.6025 .30902 L
.60287 .30902 L
.60327 .30902 L
.60364 .30902 L
.60386 .30902 L
.60407 .30902 L
.60427 .30902 L
.60447 .30902 L
.60468 .30902 L
.60479 .30902 L
.6049 .30902 L
.60496 .30902 L
.60502 .30902 L
.60512 .30902 L
.60518 .30902 L
.60523 .30902 L
.60529 .30902 L
.60535 .30902 L
.60546 .30902 L
.60552 .30902 L
.60557 .30902 L
.60578 .30902 L
.60597 .30902 L
.60617 .30902 L
.60776 .30902 L
.60846 .30902 L
.60921 .30902 L
.60963 .30902 L
.61002 .30902 L
.61078 .30902 L
.61116 .30902 L
.61159 .30902 L
.61181 .30902 L
.61204 .30902 L
.61224 .30902 L
.61246 .30902 L
.61266 .30902 L
.61285 .30902 L
.61305 .30902 L
.61322 .30902 L
.61343 .30902 L
Mistroke
.61354 .30902 L
.61366 .30902 L
.61376 .30902 L
.61385 .30902 L
.61395 .30902 L
.61401 .30902 L
.61406 .30902 L
.61417 .30902 L
.61423 .30902 L
.61428 .30902 L
.61438 .30902 L
.61448 .30902 L
.6147 .30902 L
.61493 .30902 L
.61576 .30902 L
.61733 .30902 L
.61776 .30902 L
.61822 .30902 L
.61905 .30902 L
.61946 .30902 L
.6199 .30902 L
.62032 .30902 L
.62071 .30902 L
.62106 .30902 L
.62144 .30902 L
.62164 .30902 L
.62185 .30902 L
.62204 .30902 L
.62222 .30902 L
.62233 .30902 L
.62242 .30902 L
.62251 .30902 L
.6226 .30902 L
.62271 .30902 L
.62276 .30902 L
.62282 .30902 L
.62292 .30902 L
.62301 .30902 L
.62311 .30902 L
.6232 .30902 L
.62336 .30902 L
.62374 .30902 L
.62541 .30902 L
.62618 .30902 L
.627 .30902 L
.6277 .30902 L
.6281 .30902 L
.62848 .30902 L
.62885 .30902 L
.62927 .30902 L
Mistroke
.62947 .30902 L
.6297 .30902 L
.62989 .30902 L
.6301 .30902 L
.6303 .30902 L
.6305 .30902 L
.63068 .30902 L
.63077 .30902 L
.63087 .30902 L
.63096 .30902 L
.63105 .30902 L
.63113 .30902 L
.63121 .30902 L
.6313 .30902 L
.6314 .30902 L
.63149 .30902 L
.63158 .30902 L
.63168 .30902 L
.63174 .30902 L
.63179 .30902 L
.63201 .30902 L
.6322 .30902 L
.63241 .30902 L
.6333 .30902 L
.63414 .30902 L
.63492 .30902 L
.63573 .30902 L
.63617 .30902 L
.63662 .30902 L
.63702 .30902 L
.63739 .30902 L
.6378 .30902 L
.63801 .30902 L
.63824 .30902 L
.63845 .30902 L
.63864 .30902 L
.63883 .30902 L
.63901 .30902 L
.63921 .30902 L
.63932 .30902 L
.63944 .30902 L
.63953 .30902 L
.63964 .30902 L
.63975 .30902 L
.63985 .30902 L
.6399 .30902 L
.63996 .30902 L
.64006 .30902 L
.64013 .30902 L
.64019 .30902 L
Mistroke
.64024 .30902 L
.6403 .30902 L
.64035 .30902 L
.64041 .30902 L
.64053 .30902 L
.64073 .30902 L
.64115 .30902 L
.64154 .30902 L
.64304 .30902 L
.64389 .30902 L
.64467 .30902 L
.64506 .30902 L
.6455 .30902 L
.64595 .30902 L
.64638 .30902 L
.64657 .30902 L
.64678 .30902 L
.64715 .30902 L
.64736 .30902 L
.64755 .30902 L
.64777 .30902 L
.64787 .30902 L
.64799 .30902 L
.64809 .30902 L
.6482 .30902 L
.64831 .30902 L
.64837 .30902 L
.64842 .30902 L
.64853 .30902 L
.64863 .30902 L
.64873 .30902 L
.64882 .30902 L
.64892 .30902 L
.64902 .30902 L
.64913 .30902 L
.64925 .30902 L
.64971 .30902 L
.65133 .30902 L
.65216 .30902 L
.65293 .30902 L
.65332 .30902 L
.65374 .30902 L
.65421 .30902 L
.65463 .30902 L
.65502 .30902 L
.65523 .30902 L
.65543 .30902 L
.65578 .30902 L
.65596 .30902 L
.65616 .30902 L
Mistroke
.65638 .30902 L
.6565 .30902 L
.65661 .30902 L
.65672 .30902 L
.65682 .30902 L
.65687 .30902 L
.65693 .30902 L
.65699 .30902 L
.65704 .30902 L
.65713 .30902 L
.65722 .30902 L
.65732 .30902 L
.65742 .30902 L
.65748 .30902 L
.65753 .30902 L
.65764 .30902 L
.65783 .30902 L
.65822 .30902 L
.65859 .30902 L
.65942 .30902 L
.66024 .30902 L
.66069 .30902 L
.66111 .30902 L
.66188 .30902 L
.66229 .30902 L
.66273 .30902 L
.66313 .30902 L
.66351 .30902 L
.66385 .30902 L
.66422 .30902 L
.66441 .30902 L
.66461 .30902 L
.6648 .30902 L
.66498 .30902 L
.66508 .30902 L
.66518 .30902 L
.66529 .30902 L
.66535 .30902 L
.66541 .30902 L
.66551 .30902 L
.66556 .30902 L
.66561 .30902 L
.66571 .30902 L
.66581 .30902 L
.66592 .30902 L
.66601 .30902 L
.66623 .30902 L
.66662 .30902 L
.6675 .30902 L
.66825 .30902 L
Mistroke
.66904 .30902 L
.66945 .30902 L
.66991 .30902 L
.67029 .30902 L
.67071 .30902 L
.67112 .30902 L
.67152 .30902 L
.6719 .30902 L
.67226 .30902 L
.67248 .30902 L
.67269 .30902 L
.67288 .30902 L
.67307 .30902 L
.67318 .30902 L
.67329 .30902 L
.67349 .30902 L
.6736 .30902 L
.67366 .30902 L
.67372 .30902 L
.67378 .30902 L
.67384 .30902 L
.67394 .30902 L
.67404 .30902 L
.67413 .30902 L
.67422 .30902 L
.67433 .30902 L
.67442 .30902 L
.6745 .30902 L
.67469 .30902 L
.6751 .30902 L
.67553 .30902 L
.6764 .30902 L
.67721 .30902 L
.67803 .30902 L
.67847 .30902 L
.67892 .30902 L
.67932 .30902 L
.67969 .30902 L
.6801 .30902 L
.68033 .30902 L
.68054 .30902 L
.68092 .30902 L
.68114 .30902 L
.68133 .30902 L
.68152 .30902 L
.68161 .30902 L
.68171 .30902 L
.6818 .30902 L
.6819 .30902 L
.68198 .30902 L
Mistroke
.68207 .30902 L
.68213 .30902 L
.68218 .30902 L
.68229 .30902 L
.68238 .30902 L
.68248 .30902 L
.68254 .30902 L
.68259 .30902 L
.6827 .30902 L
.68282 .30902 L
.68293 .30902 L
.68332 .30902 L
.68373 .30902 L
.68456 .30902 L
.68534 .30902 L
.68604 .30902 L
.68679 .30902 L
.68719 .30902 L
.68761 .30902 L
.68797 .30902 L
.68837 .30902 L
.68879 .30902 L
.68903 .30902 L
.68924 .30902 L
.68944 .30902 L
.68966 .30902 L
.68986 .30902 L
.69005 .30902 L
.69015 .30902 L
.69025 .30902 L
.69033 .30902 L
.69042 .30902 L
.69052 .30902 L
.69058 .30902 L
.69063 .30902 L
.69073 .30902 L
.69082 .30902 L
.69091 .30902 L
.691 .30902 L
.69117 .30902 L
.69135 .30902 L
.69155 .30902 L
.6932 .30902 L
.694 .30902 L
.69476 .30902 L
.69518 .30902 L
.69564 .30902 L
.69605 .30902 L
.69644 .30902 L
.69684 .30902 L
Mistroke
.69707 .30902 L
.69728 .30902 L
.69749 .30902 L
.69767 .30902 L
.69787 .30902 L
.69808 .30902 L
.69818 .30902 L
.69828 .30902 L
.69837 .30902 L
.69846 .30902 L
.69855 .30902 L
.69864 .30902 L
.69872 .30902 L
.6988 .30902 L
.6989 .30902 L
.699 .30902 L
.69908 .30902 L
.69918 .30902 L
.69928 .30902 L
.69938 .30902 L
.69958 .30902 L
.70118 .30902 L
.70202 .30902 L
.70248 .30902 L
.70291 .30902 L
.70332 .30902 L
.7037 .30902 L
.70413 .30902 L
.70458 .30902 L
.70496 .30902 L
.70516 .30902 L
.70537 .30902 L
.70557 .30902 L
.70576 .30902 L
.70595 .30902 L
.70612 .30902 L
.70631 .30902 L
.70641 .30902 L
.70651 .30902 L
.70661 .30902 L
.70671 .30902 L
.70677 .30902 L
.70682 .30902 L
.70693 .30902 L
.70701 .30902 L
.7071 .30902 L
.70719 .30902 L
.70729 .30902 L
.70739 .30902 L
.70749 .30902 L
Mistroke
.70767 .30902 L
.70787 .30902 L
.70808 .30902 L
.70847 .30902 L
.70934 .30902 L
.71016 .30902 L
.7106 .30902 L
.71106 .30902 L
.71146 .30902 L
.7119 .30902 L
.7123 .30902 L
.71268 .30902 L
.71308 .30902 L
.7133 .30902 L
.71351 .30902 L
.7139 .30902 L
.71409 .30902 L
.71431 .30902 L
.7145 .30902 L
.71468 .30902 L
.71477 .30902 L
.71487 .30902 L
.71498 .30902 L
.71508 .30902 L
.71517 .30902 L
.71526 .30902 L
.71534 .30902 L
.71542 .30902 L
.71552 .30902 L
.71562 .30902 L
.7158 .30902 L
.716 .30902 L
.71619 .30902 L
.71655 .30902 L
.71737 .30902 L
.71814 .30902 L
.71884 .30902 L
.71961 .30902 L
.72003 .30902 L
.72043 .30902 L
.7208 .30902 L
.72114 .30902 L
.72151 .30902 L
.7217 .30902 L
.7219 .30902 L
.72211 .30902 L
.72233 .30902 L
.72253 .30902 L
.72263 .30902 L
.72272 .30902 L
Mistroke
.7229 .30902 L
.72299 .30902 L
.72309 .30902 L
.72318 .30902 L
.72329 .30902 L
.72338 .30902 L
.72347 .30902 L
.72353 .30902 L
.72359 .30902 L
.72364 .30902 L
.72369 .30902 L
.72389 .30902 L
.72411 .30902 L
.72434 .30902 L
.72515 .30902 L
.72591 .30902 L
.72672 .30902 L
.72712 .30902 L
.72749 .30902 L
.72785 .30902 L
.72819 .30902 L
.7286 .30902 L
.72897 .30902 L
.72936 .30902 L
.72959 .30902 L
.72979 .30902 L
.73013 .30902 L
.73033 .30902 L
.73051 .30902 L
.7307 .30902 L
.73087 .30902 L
.73097 .30902 L
.73108 .30902 L
.73118 .30902 L
.73127 .30902 L
.73137 .30902 L
.73146 .30902 L
.73155 .30902 L
.73164 .30902 L
.73174 .30902 L
.73185 .30902 L
.73204 .30902 L
.73242 .30902 L
.73277 .30902 L
.73363 .30902 L
.73443 .30902 L
.73518 .30902 L
.73555 .30902 L
.73597 .30902 L
.73639 .30902 L
Mistroke
.73683 .30902 L
.73705 .30902 L
.73726 .30902 L
.73745 .30902 L
.73764 .30902 L
.73801 .30902 L
.7382 .30902 L
.73842 .30902 L
.73862 .30902 L
.73873 .30902 L
.73885 .30902 L
.73894 .30902 L
.73905 .30902 L
.73915 .30902 L
.73924 .30902 L
.73933 .30902 L
.73943 .30902 L
.73951 .30902 L
.7396 .30902 L
.7397 .30902 L
.73981 .30902 L
.74 .30902 L
.74037 .30902 L
.74072 .30902 L
.74152 .30902 L
.74237 .30902 L
.74279 .30902 L
.74318 .30902 L
.74353 .30902 L
.74391 .30902 L
.74428 .30902 L
.74468 .30902 L
.74504 .30902 L
.74538 .30902 L
.74559 .30902 L
.74579 .30902 L
.74596 .30902 L
.74615 .30902 L
.74636 .30902 L
.74655 .30902 L
.74675 .30902 L
.74687 .30902 L
.74698 .30902 L
.74707 .30902 L
.74717 .30902 L
.74727 .30902 L
.74736 .30902 L
.74746 .30902 L
.74752 .30902 L
.74757 .30902 L
Mistroke
.74767 .30902 L
.74777 .30902 L
.74797 .30902 L
.74817 .30902 L
.7486 .30902 L
.75009 .30902 L
.75049 .30902 L
.75092 .30902 L
.75131 .30902 L
.75172 .30902 L
.75209 .30902 L
.75249 .30902 L
.75286 .30902 L
.75321 .30902 L
.75358 .30902 L
.7538 .30902 L
.754 .30902 L
.75421 .30902 L
.7544 .30902 L
.7545 .30902 L
.75462 .30902 L
.75472 .30902 L
.75483 .30902 L
.75491 .30902 L
.755 .30902 L
.75511 .30902 L
.7552 .30902 L
.7553 .30902 L
.75535 .30902 L
.7554 .30902 L
.7555 .30902 L
.7556 .30902 L
.75569 .30902 L
.75579 .30902 L
.75597 .30902 L
.75631 .30902 L
.75788 .30902 L
.75831 .30902 L
.75877 .30902 L
.7592 .30902 L
.7596 .30902 L
.76001 .30902 L
.76045 .30902 L
.76085 .30902 L
.76104 .30902 L
.76126 .30902 L
.76164 .30902 L
.76185 .30902 L
.76204 .30902 L
.76221 .30902 L
Mistroke
.7624 .30902 L
.76249 .30902 L
.76259 .30902 L
.76269 .30902 L
.76277 .30902 L
.76287 .30902 L
.76292 .30902 L
.76298 .30902 L
.76304 .30902 L
.7631 .30902 L
.7632 .30902 L
.7633 .30902 L
.76339 .30902 L
.76349 .30902 L
.7636 .30902 L
.76384 .30902 L
.76406 .30902 L
.76449 .30902 L
.76528 .30902 L
.76611 .30902 L
.76688 .30902 L
.76731 .30902 L
.76772 .30902 L
.7681 .30902 L
.76844 .30902 L
.76863 .30902 L
.76883 .30902 L
.76921 .30902 L
.76939 .30902 L
.7696 .30902 L
.76977 .30902 L
.76996 .30902 L
.77008 .30902 L
.77019 .30902 L
.7703 .30902 L
.7704 .30902 L
.77049 .30902 L
.77059 .30902 L
.7707 .30902 L
.7708 .30902 L
.7709 .30902 L
.771 .30902 L
.77106 .30902 L
.77111 .30902 L
.77117 .30902 L
.77122 .30902 L
.77128 .30902 L
.77134 .30902 L
.77144 .30902 L
.77168 .30902 L
Mistroke
.77248 .30902 L
.77325 .30902 L
.77406 .30902 L
.77476 .30902 L
.77515 .30902 L
.77551 .30902 L
.77591 .30902 L
.77626 .30902 L
.77646 .30902 L
.77668 .30902 L
.77707 .30902 L
.77727 .30902 L
.77749 .30902 L
.77772 .30902 L
.77783 .30902 L
.77794 .30902 L
.77803 .30902 L
.77814 .30902 L
.77824 .30902 L
.77832 .30902 L
.77843 .30902 L
.77848 .30902 L
.77854 .30902 L
.77864 .30902 L
.77874 .30902 L
.77884 .30902 L
.77893 .30902 L
.77904 .30902 L
.77913 .30902 L
.77931 .30902 L
.7795 .30902 L
.78034 .30902 L
.78115 .30902 L
.78157 .30902 L
.78203 .30902 L
.78246 .30902 L
.78285 .30902 L
.78323 .30902 L
.78362 .30902 L
.78404 .30902 L
.78443 .30902 L
.78465 .30902 L
.78485 .30902 L
.78509 .30902 L
.78531 .30902 L
.7855 .30902 L
.78568 .30902 L
.78588 .30902 L
.78599 .30902 L
.78609 .30902 L
Mistroke
.7862 .30902 L
.78629 .30902 L
.78635 .30902 L
.7864 .30902 L
.78646 .30902 L
.78652 .30902 L
.78662 .30902 L
.78671 .30902 L
.78681 .30902 L
.78686 .30902 L
.78692 .30902 L
.78729 .30902 L
.78769 .30902 L
.7884 .30902 L
.78922 .30902 L
.78965 .30902 L
.79011 .30902 L
.79051 .30902 L
.79095 .30902 L
.79135 .30902 L
.79173 .30902 L
.79213 .30902 L
.79235 .30902 L
.79256 .30902 L
.79276 .30902 L
.79294 .30902 L
.79316 .30902 L
.79335 .30902 L
.79353 .30902 L
.79362 .30902 L
.79372 .30902 L
.79381 .30902 L
.7939 .30902 L
.79399 .30902 L
.79407 .30902 L
.79417 .30902 L
.79426 .30902 L
.79436 .30902 L
.79441 .30902 L
.79446 .30902 L
.79456 .30902 L
.79466 .30902 L
.79484 .30902 L
.79642 .30902 L
.79685 .30902 L
.79731 .30902 L
.79774 .30902 L
.79814 .30902 L
.79855 .30902 L
.799 .30902 L
Mistroke
.79939 .30902 L
.79959 .30902 L
.79981 .30902 L
.80019 .30902 L
.8004 .30902 L
.80059 .30902 L
.80077 .30902 L
.80097 .30902 L
.80115 .30902 L
.80132 .30902 L
.80143 .30902 L
.80154 .30902 L
.80163 .30902 L
.80173 .30902 L
.80179 .30902 L
.80184 .30902 L
.8019 .30902 L
.80196 .30902 L
.80206 .30902 L
.80212 .30902 L
.80217 .30902 L
.80236 .30902 L
.80256 .30902 L
.80297 .30902 L
.8037 .30902 L
.80447 .30902 L
.80486 .30902 L
.80528 .30902 L
.80567 .30902 L
.80602 .30902 L
.80644 .30902 L
.80666 .30902 L
.80689 .30902 L
.80711 .30902 L
.80731 .30902 L
.80751 .30902 L
.8077 .30902 L
.80788 .30902 L
.80808 .30902 L
.80828 .30902 L
.80848 .30902 L
.80866 .30902 L
.80876 .30902 L
.80886 .30902 L
.80903 .30902 L
.80911 .30902 L
.80921 .30902 L
.80931 .30902 L
.80941 .30902 L
.80947 .30902 L
Mistroke
.80952 .30902 L
.80957 .30902 L
.80963 .30902 L
.80968 .30902 L
.80974 .30902 L
.80984 .30902 L
.80995 .30902 L
.81007 .30902 L
.81087 .30902 L
.81173 .30902 L
.81216 .30902 L
.81256 .30902 L
.81295 .30902 L
.8133 .30902 L
.81369 .30902 L
.8141 .30902 L
.8145 .30902 L
.81487 .30902 L
.81507 .30902 L
.81528 .30902 L
.8155 .30902 L
.81571 .30902 L
.8159 .30902 L
.81608 .30902 L
.81628 .30902 L
.81639 .30902 L
.81649 .30902 L
.81657 .30902 L
.81666 .30902 L
.81675 .30902 L
.81684 .30902 L
.81694 .30902 L
.81704 .30902 L
.81712 .30902 L
.81722 .30902 L
.81732 .30902 L
.81742 .30902 L
.81753 .30902 L
.81764 .30902 L
.81804 .30902 L
.81879 .30902 L
.8196 .30902 L
.82005 .30902 L
.82047 .30902 L
.82087 .30902 L
.8213 .30902 L
.82169 .30902 L
.82205 .30902 L
.82242 .30902 L
.82276 .30902 L
Mistroke
.82295 .30902 L
.82315 .30902 L
.82334 .30902 L
.82352 .30902 L
.82372 .30902 L
.8239 .30902 L
.824 .30902 L
.8241 .30902 L
.82421 .30902 L
.8243 .30902 L
.82439 .30902 L
.82447 .30902 L
.82456 .30902 L
.82466 .30902 L
.82476 .30902 L
.82485 .30902 L
.82494 .30902 L
.82503 .30902 L
.82525 .30902 L
.82545 .30902 L
.82589 .30902 L
.82669 .30902 L
.82708 .30902 L
.8275 .30902 L
.82785 .30902 L
.82824 .30902 L
.82865 .30902 L
.82903 .30902 L
.82927 .30902 L
.82949 .30902 L
.82971 .30902 L
.82991 .30902 L
.83028 .30902 L
.83047 .30902 L
.83068 .30902 L
.83089 .30902 L
.83111 .30902 L
.8313 .30902 L
.83141 .30902 L
.83151 .30902 L
.8316 .30902 L
.8317 .30902 L
.83179 .30902 L
.83188 .30902 L
.83197 .30902 L
.83207 .30902 L
.83217 .30902 L
.83227 .30902 L
.83236 .30902 L
.83245 .30902 L
Mistroke
.83262 .30902 L
.83279 .30902 L
.83298 .30902 L
.83387 .30902 L
.8347 .30902 L
.83544 .30902 L
.83586 .30902 L
.83625 .30902 L
.83663 .30902 L
.83698 .30902 L
.83737 .30902 L
.83758 .30902 L
.83778 .30902 L
.83797 .30902 L
.83818 .30902 L
.8384 .30902 L
.83861 .30902 L
.8388 .30902 L
.83898 .30902 L
.83909 .30902 L
.83918 .30902 L
.83929 .30902 L
.83934 .30902 L
.83939 .30902 L
.83945 .30902 L
.8395 .30902 L
.8396 .30902 L
.8397 .30902 L
.83976 .30902 L
.83982 .30902 L
.83992 .30902 L
.84001 .30902 L
.84022 .30902 L
.84097 .30902 L
.84185 .30902 L
.84223 .30902 L
.84265 .30902 L
.84301 .30902 L
.8434 .30902 L
.8438 .30902 L
.84418 .30902 L
.84461 .30902 L
.84482 .30902 L
.84505 .30902 L
.84525 .30902 L
.84546 .30902 L
.84567 .30902 L
.84585 .30902 L
.84603 .30902 L
.84624 .30902 L
Mistroke
.84634 .30902 L
.84645 .30902 L
.84655 .30902 L
.84665 .30902 L
.84674 .30902 L
.84683 .30902 L
.84693 .30902 L
.84703 .30902 L
.84712 .30902 L
.84722 .30902 L
.8473 .30902 L
.84739 .30902 L
.84759 .30902 L
.84781 .30902 L
.84826 .30902 L
.84906 .30902 L
.84948 .30902 L
.84987 .30902 L
.85024 .30902 L
.85062 .30902 L
.85104 .30902 L
.85143 .30902 L
.85184 .30902 L
.85208 .30902 L
.8523 .30902 L
.85268 .30902 L
.85289 .30902 L
.85309 .30902 L
.8533 .30902 L
.85349 .30902 L
.8536 .30902 L
.85371 .30902 L
.85382 .30902 L
.85392 .30902 L
.85401 .30902 L
.8541 .30902 L
.8542 .30902 L
.8543 .30902 L
.85439 .30902 L
.85445 .30902 L
.8545 .30902 L
.85459 .30902 L
.85469 .30902 L
.85479 .30902 L
.85489 .30902 L
.85507 .30902 L
.85541 .30902 L
.85617 .30902 L
.85698 .30902 L
.85745 .30902 L
Mistroke
.85787 .30902 L
.8583 .30902 L
.8587 .30902 L
.85909 .30902 L
.8593 .30902 L
.85949 .30902 L
.85984 .30902 L
.86003 .30902 L
.86023 .30902 L
.86044 .30902 L
.86067 .30902 L
.86077 .30902 L
.86089 .30902 L
.86109 .30902 L
.86119 .30902 L
.8613 .30902 L
.86141 .30902 L
.8615 .30902 L
.86159 .30902 L
.86169 .30902 L
.86179 .30902 L
.86188 .30902 L
.86198 .30902 L
.86203 .30902 L
.86209 .30902 L
.86228 .30902 L
.8625 .30902 L
.86272 .30902 L
.86351 .30902 L
.86422 .30902 L
.8646 .30902 L
.865 .30902 L
.86541 .30902 L
.86579 .30902 L
.86622 .30902 L
.86643 .30902 L
.86662 .30902 L
.86698 .30902 L
.86718 .30902 L
.86738 .30902 L
.86755 .30902 L
.86773 .30902 L
.86792 .30902 L
.8681 .30902 L
.86831 .30902 L
.86842 .30902 L
.86852 .30902 L
.86862 .30902 L
.86873 .30902 L
.86882 .30902 L
Mistroke
.86892 .30902 L
.86897 .30902 L
.86902 .30902 L
.86912 .30902 L
.86918 .30902 L
.86924 .30902 L
.86929 .30902 L
.86935 .30902 L
.86946 .30902 L
.86958 .30902 L
.8698 .30902 L
.87058 .30902 L
.87141 .30902 L
.87181 .30902 L
.87223 .30902 L
.87259 .30902 L
.87298 .30902 L
.87335 .30902 L
.87374 .30902 L
.87411 .30902 L
.87445 .30902 L
.87463 .30902 L
.87484 .30902 L
.87505 .30902 L
.87525 .30902 L
.87544 .30902 L
.87561 .30902 L
.8757 .30902 L
.8758 .30902 L
.87589 .30902 L
.87599 .30902 L
.87605 .30902 L
.8761 .30902 L
.87615 .30902 L
.87621 .30902 L
.87631 .30902 L
.87641 .30902 L
.87647 .30902 L
.87652 .30902 L
.87658 .30902 L
.87664 .30902 L
.87674 .30902 L
.87686 .30902 L
.87727 .30902 L
.87766 .30902 L
.87838 .30902 L
.87916 .30902 L
.87961 .30902 L
.88002 .30902 L
.88043 .30902 L
Mistroke
.88082 .30902 L
.88103 .30902 L
.88122 .30902 L
.88159 .30902 L
.88179 .30902 L
.88198 .30902 L
.88219 .30902 L
.88241 .30902 L
.88258 .30902 L
.88277 .30902 L
.88286 .30902 L
.88295 .30902 L
.88311 .30902 L
.8832 .30902 L
.8833 .30902 L
.88339 .30902 L
.88348 .30902 L
.88358 .30902 L
.88364 .30902 L
.88369 .30902 L
.88378 .30902 L
.88388 .30902 L
.88398 .30902 L
.88409 .30902 L
.88428 .30902 L
.88465 .30902 L
.88547 .30902 L
.88584 .30902 L
.88624 .30902 L
.8866 .30902 L
.88694 .30902 L
.88734 .30902 L
.8877 .30902 L
.88809 .30902 L
.88831 .30902 L
.88851 .30902 L
.88871 .30902 L
.88889 .30902 L
.88923 .30902 L
.88942 .30902 L
.88959 .30902 L
.88978 .30902 L
.88998 .30902 L
.89008 .30902 L
.89019 .30902 L
.89028 .30902 L
.89038 .30902 L
.89047 .30902 L
.89057 .30902 L
.89066 .30902 L
Mistroke
.89075 .30902 L
.89085 .30902 L
.89095 .30902 L
.89104 .30902 L
.89114 .30902 L
.89125 .30902 L
.89136 .30902 L
.89156 .30902 L
.89304 .30902 L
.89344 .30902 L
.89386 .30902 L
.89432 .30902 L
.89475 .30902 L
.89515 .30902 L
.89552 .30902 L
.89574 .30902 L
.89593 .30902 L
.89614 .30902 L
.89637 .30902 L
.89657 .30902 L
.89676 .30902 L
.89695 .30902 L
.89705 .30902 L
.89716 .30902 L
.89735 .30902 L
.89745 .30902 L
.89755 .30902 L
.89764 .30902 L
.89772 .30902 L
.89781 .30902 L
.8979 .30902 L
.898 .30902 L
.8981 .30902 L
.89816 .30902 L
.89821 .30902 L
.89832 .30902 L
.89842 .30902 L
.89852 .30902 L
.8987 .30902 L
.89957 .30902 L
.90034 .30902 L
.90077 .30902 L
.90116 .30902 L
.90152 .30902 L
.90192 .30902 L
.90229 .30902 L
.90263 .30902 L
.90301 .30902 L
.90322 .30902 L
.90342 .30902 L
Mistroke
.9036 .30902 L
.90379 .30902 L
.90397 .30902 L
.90415 .30902 L
.90424 .30902 L
.90434 .30902 L
.90453 .30902 L
.90464 .30902 L
.90475 .30902 L
.90484 .30902 L
.90495 .30902 L
.90501 .30902 L
.90506 .30902 L
.90516 .30902 L
.90522 .30902 L
.90527 .30902 L
.90533 .30902 L
.90539 .30902 L
.90549 .30902 L
.90559 .30902 L
.9058 .30902 L
.9073 .30902 L
.90771 .30902 L
.90814 .30902 L
.90855 .30902 L
.90892 .30902 L
.90934 .30902 L
.90958 .30902 L
.9098 .30902 L
.9102 .30902 L
.9104 .30902 L
.91062 .30902 L
.91083 .30902 L
.91103 .30902 L
.91125 .30902 L
.91135 .30902 L
.91146 .30902 L
.91155 .30902 L
.91165 .30902 L
.91175 .30902 L
.91183 .30902 L
.91193 .30902 L
.91199 .30902 L
.91204 .30902 L
.91213 .30902 L
.91224 .30902 L
.91229 .30902 L
.91234 .30902 L
.91244 .30902 L
.91255 .30902 L
Mistroke
.91261 .30902 L
.91266 .30902 L
.91306 .30902 L
.91382 .30902 L
.91423 .30902 L
.91468 .30902 L
.91507 .30902 L
.9155 .30902 L
.91591 .30902 L
.91612 .30902 L
.91635 .30902 L
.91656 .30902 L
.91675 .30902 L
.91695 .30902 L
.91713 .30902 L
.91748 .30902 L
.91766 .30902 L
.91786 .30902 L
.91806 .30902 L
.91826 .30902 L
.91843 .30902 L
.91853 .30902 L
.91862 .30902 L
.91881 .30902 L
.91891 .30902 L
.91901 .30902 L
.9191 .30902 L
.91919 .30902 L
.91928 .30902 L
.91938 .30902 L
.91944 .30902 L
.91949 .30902 L
.91955 .30902 L
.91961 .30902 L
.91971 .30902 L
.91982 .30902 L
.92022 .30902 L
.9211 .30902 L
.9219 .30902 L
.92229 .30902 L
.92271 .30902 L
.92311 .30902 L
.92347 .30902 L
.92386 .30902 L
.92408 .30902 L
.92429 .30902 L
.92449 .30902 L
.9247 .30902 L
.92494 .30902 L
.92515 .30902 L
Mistroke
.92536 .30902 L
.92555 .30902 L
.92573 .30902 L
.92583 .30902 L
.92592 .30902 L
.92602 .30902 L
.92611 .30902 L
.92621 .30902 L
.92627 .30902 L
.92632 .30902 L
.92642 .30902 L
.92648 .30902 L
.92653 .30902 L
.92663 .30902 L
.92674 .30902 L
.92691 .30902 L
.9271 .30902 L
.92744 .30902 L
.92821 .30902 L
.92898 .30902 L
.92941 .30902 L
.92982 .30902 L
.93025 .30902 L
.93064 .30902 L
.93085 .30902 L
.93109 .30902 L
.93129 .30902 L
.93151 .30902 L
.93172 .30902 L
.9319 .30902 L
.93209 .30902 L
.93227 .30902 L
.93248 .30902 L
.93267 .30902 L
.93278 .30902 L
.93288 .30902 L
.933 .30902 L
.93305 .30902 L
.93311 .30902 L
.9332 .30902 L
.93325 .30902 L
.93331 .30902 L
.93337 .30902 L
.93342 .30902 L
.93353 .30902 L
.93362 .30902 L
.93371 .30902 L
.93381 .30902 L
.93392 .30902 L
.93433 .30902 L
Mistroke
.93479 .30902 L
.93555 .30902 L
.93596 .30902 L
.93635 .30902 L
.93676 .30902 L
.93722 .30902 L
.93761 .30902 L
.93782 .30902 L
.93802 .30902 L
.93841 .30902 L
.93861 .30902 L
.93882 .30902 L
.93901 .30902 L
.9392 .30902 L
.93939 .30902 L
.93956 .30902 L
.93966 .30902 L
.93977 .30902 L
.93987 .30902 L
.93997 .30902 L
.94003 .30902 L
.94009 .30902 L
.94015 .30902 L
.94021 .30902 L
.94031 .30902 L
.94037 .30902 L
.94042 .30902 L
.94052 .30902 L
.94062 .30902 L
.94071 .30902 L
.94081 .30902 L
.94103 .30902 L
.94123 .30902 L
.94202 .30902 L
.94245 .30902 L
.94286 .30902 L
.94324 .30902 L
.94366 .30902 L
.94404 .30902 L
.94439 .30902 L
.94458 .30902 L
.94478 .30902 L
.94497 .30902 L
.94516 .30902 L
.94533 .30902 L
.94552 .30902 L
.94569 .30902 L
.94586 .30902 L
.94606 .30902 L
.94625 .30902 L
Mistroke
.94645 .30902 L
.94656 .30902 L
.94667 .30902 L
.94684 .30902 L
.94694 .30902 L
.94703 .30902 L
.94713 .30902 L
.94722 .30902 L
.94732 .30902 L
.94742 .30902 L
.94752 .30902 L
.94758 .30902 L
.94763 .30902 L
.94772 .30902 L
.94782 .30902 L
.94819 .30902 L
.94901 .30902 L
.9494 .30902 L
.94978 .30902 L
.95014 .30902 L
.95048 .30902 L
.95084 .30902 L
.95124 .30902 L
.95163 .30902 L
.95185 .30902 L
.95205 .30902 L
.95241 .30902 L
.95262 .30902 L
.95281 .30902 L
.95297 .30902 L
.95315 .30902 L
.95334 .30902 L
.95352 .30902 L
.95362 .30902 L
.95373 .30902 L
.95382 .30902 L
.95392 .30902 L
.95403 .30902 L
.95409 .30902 L
.95415 .30902 L
.95425 .30902 L
.9543 .30902 L
.95436 .30902 L
.95446 .30902 L
.95456 .30902 L
.95461 .30902 L
.95467 .30902 L
.95477 .30902 L
.95515 .30902 L
.95592 .30902 L
Mistroke
.95664 .30902 L
.95701 .30902 L
.9574 .30902 L
.95784 .30902 L
.95824 .30902 L
.95846 .30902 L
.95866 .30902 L
.95889 .30902 L
.95911 .30902 L
.9593 .30902 L
.95951 .30902 L
.95972 .30902 L
.95993 .30902 L
.96012 .30902 L
.96023 .30902 L
.96033 .30902 L
.96042 .30902 L
.96052 .30902 L
.96061 .30902 L
.9607 .30902 L
.9608 .30902 L
.96085 .30902 L
.96091 .30902 L
.96096 .30902 L
.96102 .30902 L
.96108 .30902 L
.96113 .30902 L
.96123 .30902 L
.96129 .30902 L
.96134 .30902 L
.96144 .30902 L
.96154 .30902 L
.96174 .30902 L
.96196 .30902 L
.96235 .30902 L
.96323 .30902 L
.96362 .30902 L
.96399 .30902 L
.96441 .30902 L
.9648 .30902 L
.96517 .30902 L
.96551 .30902 L
.96588 .30902 L
.96607 .30902 L
.96627 .30902 L
.96646 .30902 L
.96667 .30902 L
.96688 .30902 L
.96708 .30902 L
.96727 .30902 L
Mistroke
.96744 .30902 L
.96754 .30902 L
.96764 .30902 L
.96774 .30902 L
.96783 .30902 L
.96792 .30902 L
.96803 .30902 L
.96813 .30902 L
.96821 .30902 L
.96832 .30902 L
.96838 .30902 L
.96843 .30902 L
.96864 .30902 L
.9695 .30902 L
.96991 .30902 L
.97035 .30902 L
.97074 .30902 L
.97115 .30902 L
.97152 .30902 L
.97193 .30902 L
.9723 .30902 L
.97265 .30902 L
.97286 .30902 L
.97305 .30902 L
.97326 .30902 L
.97349 .30902 L
.97368 .30902 L
.97387 .30902 L
.97407 .30902 L
.97418 .30902 L
.97428 .30902 L
.97437 .30902 L
.97446 .30902 L
.97455 .30902 L
.97463 .30902 L
.97472 .30902 L
.97482 .30902 L
.97492 .30902 L
.97501 .30902 L
.9751 .30902 L
.97519 .30902 L
.97528 .30902 L
.97538 .30902 L
.97577 .30902 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{421.375, 260.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008>0001AB000`400?l00000o`00003ooooooooo
oooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo
003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooo
oooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool0
0?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooooooo
ool@ooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooo
ooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo0ol0003o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo0?oooooo_Oooool0033ooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`3ooooookgooooo000`ooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool0oooooonmooooo`00<?ooool00ol0003oooooooooo`0Kooooo`;o0000oooo
oonoooooo`00<?ooool00ol0003oooooooooo`0Kooooo`;o0000oooooonoooooo`00<?ooool00ol0
003oooooooooo`0Kooooo`;o0000oooooonoooooo`00<?ooool3o`0001_ooooo0_l0003ooooookoo
oooo000`ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02?ooool2o`000?oooooo
_oooool0033ooooo00?o0000ooooooooool04?ooool2o`0000Wooooo0_l0003ooooookoooooo000`
ooooo`03o`000?oooooooooo013ooooo0_l00009ooooo`03o`000?oooooo00000?oooooo__ooool0
033ooooo00?o0000ooooooooool04?ooool2o`0000Wooooo00?o0000ooooool00000oooooonnoooo
o`00<?ooool00ol0003oooooooooo`0@ooooo`;o00002Oooool00ol0003oooooo`00003ooooookko
oooo000`ooooo`03o`000?oooooooooo013ooooo0_l00009ooooo`03o`000?oooooo00000?oooooo
__ooool0033ooooo00?o0000ooooooooool04?ooool2o`0000Wooooo00?o0000ooooool00000oooo
oonnooooo`00<?ooool00ol0003oooooooooo`0@ooooo`;o00002Oooool00ol0003oooooo`00003o
oooookkooooo000`ooooo`03o`000?oooooooooo013ooooo0_l00009ooooo`03o`000?oooooo0000
0?oooooo__ooool0033ooooo00?o0000ooooooooool03oooool00ol0003oooooo`000009ooooo`03
o`000?oooooo00000?oooooo__ooool0033ooooo0ol0000?ooooo`03o`000?oooooo000000Wooooo
00?o0000ooooool00000oooooonnooooo`00<?ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooo000000Wooooo00?o0000ooooool00000oooooonnooooo`00<?ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooo000000Wooooo00?o0000ooooool00000oooooonnooooo`00<?ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooo000000Wooooo00?o0000ooooool00000oooooonnoooo
o`00<?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo000000Wooooo00?o0000ooooool0
0000oooooonnooooo`00<?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo000000Wooooo
00?o0000ooooool00000oooooonnooooo`00<?ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooo000000Wooooo00?o0000ooooool00000oooooonnooooo`004?ooool2onk^kP?ooooo0_o^k^hI
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooool000002Oooool00ol0003oooooo`00003o
oooookkooooo000;ooooo`;o000000[o410@ooooooooooook^k^oeEEEOo^k^koooooonk^k_mEEEGo
k^k^0oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h:ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooool000002Oooool00ol0003oooooo`00003ooooookkooooo000<
ooooo`03o`000?oooooooooo00;ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0:ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooool000002Oooool00ol0003oooooo`00003ooooookkooooo00000ooooooo0000o`00
0004o`0000;ooooo1Ol00004ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@00[ooooo00?o0000ooooooooool03oooool00ol0003ooooo
o`000009ooooo`03o`000?oooooo00000?oooooo__ooool000Wooooo00CoA4A4omgMgOoooooo0000
1?ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000000[ooooo00?o0000ooooooooool03oooool00ol0003oooooo`000009oooo
o`03o`000?oooooo00000?oooooo__ooool000Wooooo00CogMgMoeEEEOoooooo00000oooool01oo^
k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000002_ooool4o`0000kooooo00?o0000ooooool000002Oooool00ol0003ooooo
o`00003ooooookkooooo000:ooooo`03ogMgMoo<c<co000000?ooooo0_o^k^h3ooooo`;ok^k^1Ooo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41002_ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooo000000Wooooo00?o0000ooooool00000oooooonnooooo`002_oo
ool00oo^k^koA4A4o`00000?ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`;o00001Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo000000Sooooo
00Co0000oooooooooooo0000oooooonnooooo`002oooool00omgMgOo0000ooooo`0<ooooo`03oeEE
EOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooooooool03oooool00ol0003oooooo`000008ooooo`04o`000?oooooooooo
o`000?oooooo__ooool002Sooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0?
ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo0000oooooonnooooo`00:?oo
ool3o`0000Gooooo00?o0000ooooooooool03oooool01?l0003oooooooooool00007ooooo`04o`00
0?ooooooooooo`000?oooooo__ooool002Wooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0?ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo0000oooooonnoooo
o`00:_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooo
oooo00001oooool01?l0003oooooooooool0003ooooookkooooo000`ooooo`03o`000?oooooooooo
00oooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool0003ooooookkooooo000`
ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooo00001oooool01?l0003ooooooooo
ool0003ooooookkooooo000`ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooo0000
1oooool01?l0003oooooooooool0003ooooookkooooo000`ooooo`03o`000?oooooooooo00oooooo
00Co0000oooooooooooo00001oooool01?l0003oooooooooool0003ooooookkooooo000`ooooo`?o
00003oooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`000?oooooo__ooool0
033ooooo00?o0000ooooooooool03oooool01?l0003oooooooooool00007ooooo`04o`000?oooooo
ooooo`000?oooooo__ooool0033ooooo00?o0000ooooooooool03oooool01?l0003oooooooooool0
0007ooooo`04o`000?ooooooooooo`000?oooooo__ooool0033ooooo00?o0000ooooooooool03ooo
ool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool00000oooooonmooooo`00
<?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooo
ooooooooo`00003ooooookgooooo000`ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooo
oooo00001oooool01Ol0003ooooooooooooooooo00000?oooooo_Oooool0033ooooo00?o0000oooo
ooooool03oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool00000oooo
oonmooooo`00<?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooo`0000Oooooo00Go
0000ooooooooooooooooo`00003ooooookgooooo000`ooooo`03o`000?oooooooooo00oooooo00Co
0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo00000?oooooo_Oooool0033ooooo
00?o0000ooooooooool03oooool01?l0003oooooooooool00007ooooo`05o`000?oooooooooooooo
ool00000oooooonmooooo`00<?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooo`00
00Oooooo00Go0000ooooooooooooooooo`00003ooooookgooooo000`ooooo`03o`000?oooooooooo
00oooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo00000?oooooo_Ooo
ool0033ooooo0ol0000?ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooooooooooo
o`00003ooooookgooooo000`ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooo0000
1oooool01Ol0003ooooooooooooooooo00000?oooooo_Oooool0033ooooo00?o0000ooooooooool0
3oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool00000oooooonmoooo
o`00<?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooo
ooooooooooooo`00003ooooookgooooo000`ooooo`03o`000?oooooooooo00oooooo00Co0000oooo
oooooooo00001oooool01Ol0003ooooooooooooooooo00000?oooooo_Oooool0033ooooo00?o0000
ooooooooool03oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool00000
2?ooool00ol0003oooooooooo`3ooooook;ooooo000`ooooo`03o`000?oooooooooo00oooooo00Co
0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000oooooooo
ool0oooooonbooooo`00<?ooool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooo`0000Oo
oooo00Go0000ooooooooooooooooo`000008ooooo`;o0000ooooooncooooo`00<?ooool00ol0003o
ooooooooo`0?ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000008
ooooo`;o0000ooooooncooooo`00<?ooool00ol0003oooooooooo`0?ooooo`04o`000?oooooooooo
o`0000Oooooo00Go0000ooooooooooooooooo`000008ooooo`;o0000ooooooncooooo`00<?ooool0
0ol0003oooooooooo`0?ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooooooooooo
o`000008ooooo`;o0000ooooooncooooo`00<?ooool3o`0000kooooo00Go0000oooooooooooooooo
o`000007ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003ooooook?o
oooo000`ooooo`03o`000?oooooooooo00kooooo00Go0000ooooooooooooooooo`000007ooooo`05
o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003ooooook?ooooo000`ooooo`03
o`000?oooooooooo00kooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooooooo
ooooool000001oooool00ol0003oooooo`00003ooooook?ooooo000`ooooo`03o`000?oooooooooo
00kooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001ooo
ool00ol0003oooooo`00003ooooook?ooooo000`ooooo`03o`000?oooooooooo00kooooo00Go0000
ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool00ol0003ooooo
o`00003ooooook?ooooo000`ooooo`03o`000?oooooooooo00kooooo00Go0000oooooooooooooooo
o`000007ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003ooooook?o
oooo000`ooooo`03o`000?oooooooooo00kooooo00Go0000ooooooooooooooooo`000007ooooo`05
o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003ooooook?ooooo000@ooooo`;o
k^k^0oooool2onk^kQWooooo00?o0000ooooooooool03_ooool01Ol0003ooooooooooooooooo0000
00Oooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?oooooo/oooool0
00Wooooo1Ol00002ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co000000So
410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP[ooooo00?o0000ooooooooool03_ooool01Ol0
003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oo
oooo00000?oooooo/oooool000Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05onk^k_mE
EEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02_ooool00ol0003oooooooooo`04ooooo`;o00002?ooool01Ol0003ooooooooooooooooo0000
00Oooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?oooooo/oooool0
0003ooooool0003o000000Co00000oooool00onHV9So8B4Qonk^kP05ooooo`03omgMgOl0003ogMgM
00Oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00[ooooo00?o0000
ooooooooool01?ooool2o`0000Sooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oo
ooooooooooooool000001oooool00ol0003oooooo`00003ooooook?ooooo000;ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo
00Go0000ooooooooooooooooo`00000:ooooo`03o`000?oooooooooo00Cooooo0_l00008ooooo`05
o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000
ooooool00000ooooooncooooo`003?ooool02omgMgOoIVIVooooooooooook^k^oeEEEOo^k^kooooo
onk^k_mEEEGok^k^00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
00[ooooo1?l00003ooooo`;o00002?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?oooooo/oooool0
00gooooo00?o0000ooooooooool00_o^k^h3ooooo`;ok^k^1Oooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@41002_ooool00ol0003oooooooooo`04ooooo`;o00002?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00
0007ooooo`03o`000?oooooo00000?oooooo/oooool000Wooooo00Go0000okZj^_ooooooV9RHoa0@
400>ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`;o0000
1Oooool00ol0003oooooooooo`04ooooo`;o00002?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`00
0?oooooo/_ooool000Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00<ooooo`03oeEEEOmVIVKo0000
00Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooooooool00oooool00ol0003oooooo`000008ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo
0000oooooonbooooo`00:?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooool000002?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`000?oooooo/_ooool0
02Sooooo0ol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000002?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000007
ooooo`04o`000?ooooooooooo`000?oooooo/_ooool002Wooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001oooool01?l0003ooooooooo
ool0003ooooook;ooooo000Zooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooo`000008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000oooooonbooooo`00
<?ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001oooool01?l0
003oooooooooool0003ooooook;ooooo000`ooooo`03o`000?oooooooooo00?ooooo00Co0000oooo
oooooooo00001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000
ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool00000oooooonbooooo`00<?oo
ool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003o
oooooooooooooooo00000?oooooo/_ooool0033ooooo00?o0000ooooooooool00oooool01?l0003o
ooooooooool00007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0
003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`00003ooooook;ooooo000`
ooooo`?o00000oooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000oooooooooooo
ooooo`00003ooooook;ooooo000`ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo
00001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooo
ooooooooo`000006ooooo`05o`000?ooooooooooooooool00000oooooonbooooo`00<?ooool00ol0
003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooo
oooooooo00000?oooooo/_ooool0033ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`00
0?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo00000?oooooo/_ooool0033o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool0
1Ol0003ooooooooooooooooo00000?oooooo/_ooool0033ooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`04ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo00000?oo
oooo/_ooool0033ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Oo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooooooo
ool000001_ooool01Ol0003ooooooooooooooooo00000?oooooo/_ooool0033ooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooo
oooooooo00000?oooooo/_ooool0033ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`00
0?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo00000?oooooo/_ooool0033o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool0
1Ol0003ooooooooooooooooo00000?oooooo/_ooool0033ooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`04ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo00000?oo
oooo/_ooool0033ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Oo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooooooo
ool000001_ooool01Ol0003ooooooooooooooooo00000?oooooo/_ooool0033ooooo0ol00002oooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool00000
oooooonbooooo`00<?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooo
ooooo`000006ooooo`05o`000?ooooooooooooooool00000oooooonbooooo`00<?ooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`05o`000?ooooooooooooooool00000oooooonbooooo`00<?ooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`05o`000?oooooo
ooooooooool00000oooooonbooooo`00<?ooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool00000
oooooonbooooo`00<?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003o
ooooooooo`0Iooooo`;ok^k^0oooool2onk^kUOooooo0_o^k^h3ooooo`;ok^k^H?ooool2onk^kP?o
oooo0_o^k^i>ooooo`;ok^k^0oooool2onk^kVcooooo000`ooooo`03o`000?oooooooooo00;ooooo
00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`05ooooo`;o00005?ooool03Om4A4Co0000o`000?lb<S;ogMgM
ooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^
k_lb<S;o0000oc8b<_o^k^i2ooooo`Co000000Wo410@ooooooo^k^koEEEEonk^k_ooooook^k^oeEE
EOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hkooooo`Co0000
00?o410@ooooooooool00_ooool2ob4Q8@Gooooo00goA4A4o`000?l0003o<S8bomgMgOooooook^k^
oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`00
0?lb<S;ok^k^>?ooool5o`0000;ooooo00Ook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo
1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^GOooool0033ooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooool000005oooool0
2OmgMgOo<S8booooooooooook^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`14ooooo`03o`000?oooooooooo00;ooooo00Gok^k^oeEE
EOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0mooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`09ogMgMolb<S;oooooooooooo^k^ko
EEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg03Sooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h0
1_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0GOooool0033ooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooool0
00006?ooool01ol0003ooooooooooooooooogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@4100A?ooool00ol0003oooooooooo`03ooooo`03omgMgOl0
003ogMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@03gooooo
00?o0000ooooooooool03oooool01ol0003ooooooooooooooooogMgMo`000?oMgMd01oooool00ol0
003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100>Oooool00onHV9So8B4Qonk^kP05
ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@05gooooo000`ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooo000001Oooooo00WoMgMgoc8b<_ooooooooooonk^k_mEEEGogMgMoeEE
EOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000A?ooool0
0ol0003oooooooooo`02ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool00000?Oooool00ol0003oooooooooo`0>ooooo`09ogMg
Molb<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000003[ooooo00?oV9RHob4Q8Oo^k^h00oooool01Oo^k^koEEEEomgM
gOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000005go
oooo000`ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooo000001Cooooo00go0000ob4Q8Ol0003o<S8bolc<c?ooooook^k^oeEEEOo^k^kooooo
onk^k_mEEEGok^k^00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
04Cooooo00_o0000ooooooooooooooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03
o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000mooooo`03o`000?oooooooooo
00_ooooo00go0000ob4Q8Ol0003o<S8bolc<c?ooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^
00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000003_ooooo00_oMgMg
ofIVI_ooooooooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`00001Mooooo`00<?ooool01Ol0003ooooooooooooooooo
000000Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooo`00000Dooooo`03o`000?oooooo
oooo00?ooooo0_o^k^h3ooooo`;ok^k^1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooo
ooooooooool@4100A?ooool01?l0003oooooooooooooool2onk^kP?ooooo0_o^k^h5ooooo`03o`00
0?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400mooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool00oooool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;o
oooo00Go410@oooooooooooooooooa0@400looooo`03o`000?oooooooooo00;ok^k^0oooool2onk^
kPGooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@05gooooo000`oooo
o`?o000000?oooooo`000?ooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`04o`000?oooooooooo
o`0001?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo0_l0000cooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02?ooool2o`0002kooooo00Go0000okZj^_ooooooV9RHoa0@400>oooo
o`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`;o0000Doooool0
033ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Co0000
oooooooooooo00004oooool4o`0000cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Sooooo00?o0000ooooooooool0=oooool00omEEEGoIVIVo`00000=ooooo`03oeEE
EOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP07ooooo`04o`000?ooooooooooo`00
033ooooo00?oEEEEofIVI_l000003Oooool4o`0000cooooo00?oEEEEofIVI_l000001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Oooooo00Co0000oooooooooooo0000;Oooool01OnHV9So410@o`00
0?lQ8B7oc<c<00cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oo
oooo00Co0000oooooooooooo0000D_ooool002[ooooo0_l00004ooooo`05o`000?oooooooooooooo
ool000001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`00037ooooo1?l00003
ooooo`03o`000?oooooooooo05Cooooo1?l000001Ooooooo0000oooooooooooo000005kooooo1?l0
00001Ooooooo0000oooooooooooo000004cooooo1?l000001Ooooooo0000oooooooooooo000005;o
oooo000Zooooo`?o00000oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool01?l0003oooooooooool0000hooooo`03o`000?oooooooooo05Wooooo0ol0001Toooo
o`?o0000D_ooool3o`0005?ooooo000Zooooo`03o`000?oooooo000000?ooooo00Go0000oooooooo
ooooooooo`000005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo0000=_ooool0
1?l0003oooooooooool0001Kooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0D_oo
ool00ol0003oooooooooo`1Booooo`00:Oooool01?l0003oooooooooool00003ooooo`05o`000?oo
ooooooooooooool000001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0003Ko
oooo1?l0001Looooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0D_ooool00ol0003o
ooooooooo`1Aooooo`00:Oooool01?l0003oooooooooool00003ooooo`05o`000?oooooooooooooo
ool000001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`000?ooooooYoooool0
02Wooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000001Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool00000oooooom]ooooo`03ogMg
MomVIVKooooo02gooooo00?oIVIVogMgMoooool01oooool002Sooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
oooooomQooooo`03omgMgOl@413ok^k^02kooooo00?ok^k^oa0@4?oMgMd01oooool002Sooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo
0ol0003ooooooe3ooooo0_l00002ooooo`;o00003?ooool00omEEEGoV9RHooooo`02o`0000;ooooo
00Oo0000oooooooooooo0000oa0@4?o^k^koEEEE00;o000000?oA4A4okZj^_ooool00_ooool01OnH
V9So0000o`000?m4A4Co^[Zj00;ooooo00Sok^k^oeEEEOl0003o0000odA4A?nj^[[ooooooa0@40Go
00000oooool02?l@413o<S8bo`000?l0003o410@ojVYZOn7QhOoIVIV1oooool001kooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02o`000?ooooooCoooool01_o^k^ko8B4QohN7
Qonj^[[o0000omgMg@cooooo00Go0000ooooooooooooooooo`000002ooooo`0;o`000?oooooooooo
o`000?ooooooEEEEogMgMoooooook^k^ogMgMol@41000oooool01Ol@413o^[Zjonk^k_mgMgOo410@
00;ooooo00KoEEEEogMgMoooooook^k^ogMgMol@4103ooooo`03o`000?oooooooooo00Cooooo00So
0000ojVYZOoooooooooookZj^_l0003ok^k^o`0000Oooooo003oo`000;Co00003oooool01?oMgMgo
0000oa0@4?o<c<`=ooooo`05oc8b<_ooooooooooooooool000000_ooool01_l0003oooooooooool0
003oooooo`0000Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Gooooo00Oo^[ZjohN7QomVIVKoIVIVoa0@4?oooooo000000Oooooo000:ooooo`03
o`000?oooooooooo013ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooool000000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00Oo0000ooooooooooooooooo`000?oooooo000000Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool5o`0000;ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Gooooo`04onk^
k_lQ8B7o410@onk^kPgooooo00Go<S8booooooooooooooooo`000002ooooo`05o`000?oooooooooo
o`000?ooool01_l00003ooooo`03o`000?oooooooooo00Cooooo1_l00003ooooo`03o`000?oooooo
oooo00Cooooo00So<S8bob4Q8OmgMgOoMgMgohN7Qoo^k^koooooo`0000Oooooo000:ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool00_ooool2o`0000;ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool01ol0003ooooooooooooooooo0000ooooool000001?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool05oooool01?lQ8B7oMgMgogMgMolb
<S8=ooooo`05o`000?o^k^koooooooooool000000_o<c<`02ol0003oZJVYomgMgOlQ8B7ooooooeEE
EOn7QhOok^k^oooooon7QhOo<S8b00?ooooo00?o0000ooooooooool01?ooool01_mEEEGoQhN7onk^
k_ooooooQhN7oc8b<P?ooooo00?o0000oc8b<_oMgMd01?ooool02?l0003o^[Zjooooooo^k^koMgMg
o`000?o^k^ko00001oooool002?ooooo0ol00008ooooo`03o`000?oooooo000000?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00Go0000
ooooooooooooooooo`00000Pooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool0Fooo
ool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo01Kooooo0_l00002ooooo`;o00003?oo
ool03_mEEEGoMgMgooooool@413o0000ob4Q8Ol0003oMgMgoa0@4?l0003oZJVYooooooo^k^koEEEE
0_l000001?m4A4Cok^k^ooooool@4105o`0000?ooooo00Kok^k^oeEEEOl0003o0000odA4A?o^k^h2
ooooo`;o000000CoZJVYob4Q8Ol0003o8B4Q0_ooool02?nYZJWo8B4Qo`000?l0003o<S8bo`000?mg
MgOoEEEE1oooool002kooooo00?o0000ooooool000000oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo0000
0?ooooooI_ooool00ooMgMgo410@onk^kP0Booooo`03o`000?oooooooooo01Wooooo00?ok^k^oa0@
4?oMgMd01oooool002kooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000
0?ooooooIoooool00omgMgOoIVIVooooo`0Aooooo`03o`000?oooooooooo01Wooooo00?oIVIVogMg
Moooool01oooool002kooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool2o`000003ooooool0003ooooo0?oo
ooooXOooool002kooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`05o`00
0?ooooooooooooooool000001oooool3o`000?ooooooX_ooool002kooooo00?o0000ooooool00000
0_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001oooool2o`000?oo
ooooXoooool002kooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`05o`00
0?ooooooooooooooool00000oooooon/ooooo`00;_ooool00ol0003oooooo`000002ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00003oooooojcooooo000^ooooo`03o`00
0?oooooo000000;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo00000?oo
oooo[?ooool002oooooo1Ol00006ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000oooooon/ooooo`00
;oooool2o`0000;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo00000?oo
oooo[?ooool002oooooo0_l00002ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooo
ooooo`00003oooooojcooooo000_ooooo`;o00000_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`00
0?ooooooooooooooool00000oooooon/ooooo`00;oooool2o`0000;ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool01Ol0003ooooooooooooooooo00000?oooooo[?ooool0033ooooo00Co0000oooooooooooo
00001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool01Ol0003ooooooooooooooooo00000?oooooo[?ooool0033ooooo00Co0000oooooooo
oooo00001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01?ooool01Ol0003ooooooooooooooooo00000?oooooo[?ooool0033ooooo00Co0000oooo
oooooooo00001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool01Ol0003ooooooooooooooooo00000?oooooo[?ooool0033ooooo00?o0000
ooooool000002?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool01Ol0003ooooooooooooooooo00000?oooooo[?ooool0033ooooo00?o0000
ooooool000002?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool01Ol0003ooooooooooooooooo00000?oooooo[?ooool0033ooooo00?o0000
ooooool000002?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool01Ol0003ooooooooooooooooo00000?oooooo[?ooool0033ooooo00?o0000
ooooool000002?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool01Ol0003ooooooooooooooooo00000?oooooo[?ooool0033ooooo0ol00008
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`05o`000?ooooooooooooooool00000oooooon/ooooo`00<?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`05o`000?ooooooooooooooool00000oooooon/ooooo`00<?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`04o`000?ooooooooooo`000?oooooo[Oooool0033ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
1?l0003oooooooooool0003oooooojgooooo000`ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Co0000
oooooooooooo0000oooooon]ooooo`00<?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
00000?oooooo[Oooool0033ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooo`00003ooooo
ojgooooo000`ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool00000oooooon]ooooo`00
<?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo00000?oooooo[Oooool0033ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01Oooool2o`000?oooooo[_ooool0033ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool2
o`000?oooooo[_ooool0033ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool2o`000?oooooo[_ooool0033o
oooo0ol00008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`05ooooo`;o0000oooooon^ooooo`00<?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`;o0000
oooooon^ooooo`00<?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00Go
0000ooooooooooooooooo`00003ooooookOooooo000`ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01Oooool01Ol0003ooooooooooooooooo00000?oooooo]oooool0033ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`000?oooooo
^?ooool0033ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`04o`000?oo
ooooooooo`000?oooooo^?ooool000oooooo0_o^k^h3ooooo`;ok^k^6_ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000Oooooo00Co0000oooooooooooo0000oooooonhooooo`002?ooool5o`0000;ooooo
00Ook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413oooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^2oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooo
oooo0000oooooonhooooo`002?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00Gok^k^oeEE
EOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`04ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool0003ooooookSo
oooo0009ooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?ogMgMo`000?oMgMd01oooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41002oooool00ol0003oooooooooo`08ooooo`05
o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000
oooooooooooo0000oooooonhooooo`002_ooool00onHV9So8B4Qonk^kP03ooooo`05onk^k_mEEEGo
gMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
2oooool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003o
oooooooooooooooo000000Oooooo00Co0000oooooooooooo0000oooooonhooooo`002oooool02omg
MgOoIVIVooooooooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000oooooooo
ool00_ooool01Ol0003ooooooooooooooooo000000_ooooo1?l00007ooooo`05o`000?oooooooooo
ooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000
oooooonhooooo`003?ooool00ol0003oooooooooo`02onk^kP?ooooo0_o^k^h5ooooo`03o`000?oo
oooooooo00;ooooo00Go410@oooooooooooooooooa0@400;ooooo`03o`000?oooooooooo00Sooooo
00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool01?l0
003oooooooooool0003ooooookSooooo0008ooooo`05o`000?nj^[[ooooooiRHV?l@41003_ooool0
0ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ol0003ooooooooo
o`08ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oo
oooo00Co0000oooooooooooo0000oooooonhooooo`002?ooool01OnHV9So410@o`000?lQ8B7oc<c<
00cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo0_l00006
ooooo`03o`000?oooooooooo00Sooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oo
ooooooooooooool000001oooool01?l0003oooooooooool0003ooooookSooooo000Wooooo`04o`00
0?ooooooooooo`0000Gooooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooooooo0000
00Oooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`000?oooooo^?oo
ool002Oooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`08ooooo`05o`000?oo
ooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooo
oooo0000oooooonhooooo`009oooool3o`0000Kooooo00?o0000ooooooooool02?ooool01Ol0003o
oooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?oooooo
ooooo`000?oooooo^?ooool002Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`08
ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo
00Co0000oooooooooooo0000oooooonhooooo`00:Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Sooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooooooooooo
ool000001oooool01?l0003oooooooooool0003ooooookSooooo000`ooooo`03o`000?oooooooooo
00Sooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001ooo
ool01?l0003oooooooooool0003ooooookSooooo000`ooooo`03o`000?oooooooooo00Sooooo00Go
0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool01?l0003o
ooooooooool0003ooooookSooooo000`ooooo`03o`000?oooooooooo00Sooooo00Go0000oooooooo
ooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool0
003ooooookSooooo000`ooooo`?o00002Oooool01?l0003oooooooooool00007ooooo`05o`000?oo
ooooooooooooool000001oooool01?l0003oooooooooool0003ooooookSooooo000`ooooo`03o`00
0?oooooooooo00Wooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000
00Oooooo00Co0000oooooooooooo0000oooooonhooooo`00<?ooool00ol0003oooooooooo`09oooo
o`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?oo
ooooooooo`000?oooooo^?ooool0033ooooo00?o0000ooooooooool02Oooool01?l0003ooooooooo
ool00007ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool0003ooooo
okSooooo000`ooooo`03o`000?oooooooooo00Wooooo00Co0000oooooooooooo00001oooool01Ol0
003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000oooooonhooooo`00<?ooool0
0ol0003oooooooooo`09ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooooooooooo
o`000007ooooo`04o`000?ooooooooooo`000?oooooo^?ooool0033ooooo00?o0000ooooooooool0
2Oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001oooool01?l0
003oooooooooool0003ooooookSooooo000`ooooo`03o`000?oooooooooo00Wooooo00Co0000oooo
oooooooo00001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000
oooooonhooooo`00<?ooool00ol0003oooooooooo`09ooooo`04o`000?ooooooooooo`0000Oooooo
00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`000?oooooo^?ooool0033o
oooo00?o0000ooooooooool02Oooool01?l0003oooooooooool00007ooooo`05o`000?oooooooooo
ooooool000001oooool01?l0003oooooooooool0003ooooookSooooo000`ooooo`03o`000?oooooo
oooo00Wooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Oooooo
00Co0000oooooooooooo0000oooooonhooooo`00<?ooool00ol0003oooooooooo`09ooooo`04o`00
0?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?oooooooooo
o`000?oooooo^?ooool0033ooooo0ol00009ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000
ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`000?oooooo^?ooool0033ooooo00?o
0000ooooooooool02Oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool0
00001oooool01?l0003oooooooooool0003ooooookSooooo000`ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooool000002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooo
oooooooo0000oooooonhooooo`00<?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo0000
00Sooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`000?oooooo^?oo
ool0033ooooo00?o0000ooooooooool02Oooool00ol0003oooooo`000008ooooo`05o`000?oooooo
ooooooooool000001oooool01?l0003oooooooooool0003ooooookSooooo000`ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooool000002?ooool01Ol0003ooooooooooooooooo000000Oooooo
00Co0000oooooooooooo0000oooooonhooooo`00<?ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooo000000Sooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooo00000?oo
oooo^?ooool0033ooooo00?o0000ooooooooool02Oooool00ol0003oooooo`000008ooooo`05o`00
0?ooooooooooooooool000002?ooool00ol0003oooooo`00003ooooookSooooo000`ooooo`03o`00
0?oooooooooo00[ooooo0_l00008ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003o
ooooo`00003ooooookSooooo000`ooooo`03o`000?oooooooooo00[ooooo0_l00008ooooo`05o`00
0?ooooooooooooooool000002?ooool00ol0003oooooo`00003ooooookSooooo000`ooooo`03o`00
0?oooooooooo00[ooooo0_l00008ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003o
ooooo`00003ooooookSooooo000`ooooo`03o`000?oooooooooo00[ooooo0_l00008ooooo`05o`00
0?ooooooooooooooool000002?ooool00ol0003oooooo`00003ooooookSooooo000`ooooo`?o0000
2_ooool2o`0000Sooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooo00000?oo
oooo^?ooool0033ooooo00?o0000ooooooooool02_ooool2o`0000Sooooo00Go0000oooooooooooo
ooooo`000008ooooo`03o`000?oooooo00000?oooooo^?ooool0033ooooo00?o0000ooooooooool0
2_ooool2o`0000Sooooo00Go0000ooooooooooooooooo`000008ooooo`;o0000ooooooniooooo`00
<?ooool00ol0003oooooooooo`0Dooooo`05o`000?ooooooooooooooool000002?ooool2o`000?oo
oooo^Oooool0033ooooo00?o0000ooooooooool05?ooool01Ol0003ooooooooooooooooo000000So
oooo0_l0003ooooookWooooo000`ooooo`03o`000?oooooooooo01Cooooo00Go0000oooooooooooo
ooooo`000008ooooo`;o0000ooooooniooooo`003oooool2onk^kP?ooooo0_o^k^hJooooo`03o`00
0?oooooooooo01Cooooo00Go0000ooooooooooooooooo`000008ooooo`;o0000ooooooniooooo`00
2_ooool2o`00000:oa0@4?ooooooooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP?ooooo1?l0
00002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool00ol0003oooooooooo`0Doooo
o`05o`000?ooooooooooooooool000002?ooool2o`000?oooooo^Oooool000_ooooo00?o0000oooo
ooooool00_ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?o0000ooooooooool05?ooool01Ol0003ooooooooo
oooooooo000000Sooooo0_l0003ooooookWooooo0008ooooo`Go00001?ooool00ooMgMgo0000omgM
g@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400;ooooo`03o`00
0?oooooooooo01Cooooo00Go0000ooooooooooooooooo`000008ooooo`;o0000ooooooniooooo`00
2?ooool01?m4A4CogMgMooooool00004ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`0D
ooooo`05o`000?ooooooooooooooool000002?ooool2o`000?oooooo^Oooool000Sooooo00CogMgM
oeEEEOoooooo00000oooool01oo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000002oooool4o`0001?ooooo00Go0000oooo
ooooooooooooo`000008ooooo`;o0000ooooooniooooo`002Oooool00omgMgOoc<c<o`000003oooo
o`;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@00_ooooo00?o0000ooooooooool05Oooool01?l0003oooooooooool00008ooooo`;o0000oooo
ooniooooo`002Oooool00oo^k^koA4A4o`00000?ooooo`03o`000?oooooooooo00;ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0;ooooo`03o`000?oooooooooo01Gooooo00Co0000oooooooooooo0000
2?ooool2o`000?oooooo^Oooool000[ooooo00?oMgMgo`000?ooool03?ooool00omEEEGoIVIVo`00
0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool2o`0000Kooooo00?o0000ooooooooool0
5Oooool01?l0003oooooooooool00008ooooo`;o0000ooooooniooooo`009oooool01?l0003ooooo
ooooool00005ooooo`03o`000?oooooooooo01Gooooo00Co0000oooooooooooo00002?ooool2o`00
0?oooooo^Oooool002Oooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`0Eoooo
o`04o`000?ooooooooooo`000?oooooo`oooool002Oooooo0ol00006ooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooool00000ooooooo4ooooo`00:?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooool00000ooooooo4ooooo`00:Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooool00000ooooooo4ooooo`00<?oo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooo00000?ooooooa?ooool0033ooooo00?o0000
ooooooooool05Oooool00ol0003oooooo`00003oooooolCooooo000`ooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooool00000ooooooo4ooooo`00<?ooool3o`0001Gooooo00?o0000ooooool0
0000ooooooo4ooooo`00<?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo00000?oooooo
a?ooool0033ooooo00?o0000ooooooooool05Oooool00ol0003oooooo`00003oooooolCooooo000`
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooool00000ooooooo4ooooo`00<?ooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooo00000?ooooooa?ooool0033ooooo00?o0000oooooooo
ool05Oooool00ol0003oooooo`00003oooooolCooooo000`ooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooool00000ooooooo4ooooo`00<?ooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooo00000?ooooooa?ooool0033ooooo00?o0000ooooooooool05Oooool00ol0003oooooo`00003o
ooooolCooooo000`ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooool00000ooooooo4oooo
o`00<?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo00000?ooooooa?ooool0033ooooo
00?o0000ooooooooool05Oooool00ol0003oooooo`00003oooooolCooooo000`ooooo`?o00005Ooo
ool00ol0003oooooo`00003oooooolCooooo000`ooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooool00000ooooooo4ooooo`00<?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo0000
0?ooooooa?ooool0033ooooo00?o0000ooooooooool05Oooool00ol0003oooooo`00003oooooolCo
oooo000`ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooool00000ooooooo4ooooo`00<?oo
ool00ol0003oooooooooo`0Fooooo`;o0000ooooooo4ooooo`00<?ooool00ol0003oooooooooo`0F
ooooo`;o0000ooooooo4ooooo`00<?ooool00ol0003oooooooooo`0Fooooo`;o0000ooooooo4oooo
o`00<?ooool00ol0003oooooooooo`0Fooooo`;o0000ooooooo4ooooo`00<?ooool00ol0003ooooo
ooooo`0Fooooo`;o0000ooooooo4ooooo`00<?ooool00ol0003oooooooooo`0Fooooo`;o0000oooo
ooo4ooooo`00<?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo0?oooooo`oooool0
033ooooo0ol0000Fooooo`03o`000?oooooooooo0?oooooo`oooool0033ooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`3ooooool?ooooo000`ooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool0ooooooo3ooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`
ooooo`03o`000?oooooooooo0?oooooog?ooool00?ooooooooooool@ooooo`00oooooooooooooa3o
oooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooo
oooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo002Pooooo`;o00001?oo
ool00onj^[[o<S8booooo`04ooooo`;o00001_ooool00ol0003o^[Zjooooo`3ooooooeOooooo002P
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`;o<S8boooooomHooooo`00SOooool3o`0000;ooooo00Ko<S8boa0@4?ooooooooooonk^k_mE
EED2o`000003odA4A?nj^[[ooooo00?ooooo00?o0000ooooooooool00_ooool01OnHV9So410@o`00
0?l0003oZJVY00Cooooo00?o0000ooooooooool01?ooool00on7QhOo0000okZj^P0<ooooo`05oiRH
V?l0003o0000odA4A?nj^[X02_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B44ooooo`Go
000000Koooooolc<c?o^k^koooooonk^k_o<c<`4ooooo`Co000000So410@ooooooooooook^k^oc8b
<_l0003o<S8bonk^kQ?ooooo00Ko410@oc8b<_l0003o0000oa0@4?nYZJT2ooooo`06onk^k_mEEEGo
0000o`000?m4A4Co^[Zj0oooool01OmVIVKo0000o`000?m4A4Coc<c<0>Sooooo002>ooooo`05o`00
0?ooooooooooolc<c?l@41000oooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40Cooooo00?o0000
ooooooooool00_ooool01_l0003oZJVYoeEEEOnHV9SoEEEEokZj^P?ooooo00?o0000ooooooooool0
1?ooool00oo<c<co0000oa0@400<ooooo`06oa0@4?nj^[[ok^k^ogMgMol@413ooooo1_l00005oooo
o`03o`000?oooooooooo00Cooooo0_lQ8B44ooooo`0;oiRHV?lQ8B7ok^k^oooooom4A4Coooooonk^
k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL04oooool01_l0003oZJVYoooooooooooo^[Zjo`0000;ooooo00KoEEEEogMgMoooooook^k^
ogMgMol@4102ooooo`06ofIVI_mgMgOooooooooooon7QhOo410@j?ooool008kooooo00Go0000oooo
ooooooooEEEEohN7Q`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool0
1_lb<S;ok^k^oiRHV?mEEEGogMgMoa0@40?ooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h00oooool00ooMgMgo0000
omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Dooooo`05
okZj^_n7QhOoIVIVofIVI_l@41000_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0>_ooooo002>ooooo`05o`000?oooooogMgMo`000?o^k^h00oooool6o`0000Cooooo00?o0000oooo
ooooool00_ooool01onj^[[oA4A4olc<c?lQ8B7ooooooa0@4?o<c<`00_ooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo00?ooooo1_l00005ooooo`03o`000?oooooooooo00cooooo00Wo
V9RHob4Q8Oo^k^koooooonk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000004oooool01_lb<S;o8B4QogMgMomgMgOoQhN7onk^kP;ooooo
1_l00002ooooo`03o`000?oooooooooo0>_ooooo002>ooooo`?o000000?o410@oiRHV?ooool00_oo
ool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<PCooooo00?o0000ooooooooool00_ooool01oo^k^ko
0000ooooool0003oooooofIVI_n7QhL00_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool03Oooool02?mgMgOoIVIVooooooo<c<cok^k^ooooooo^k^ko
c<c<1_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000004oooool01_l0
003o^[Zjooooooo^k^koMgMgo`0000;ooooo00KoEEEEohN7Qoo^k^koooooohN7Qolb<S82ooooo`06
ofIVI_mgMgOooooooooooon7QhOo0000j?ooool008kooooo00Go0000ooooooooooooc<c<o`000003
ooooo`06onk^k_mEEEGo0000o`000?m4A4Cok^k^1?ooool00ol0003oooooooooo`02ooooo`04ofIV
I_nHV9Sooooooc8b<P;o^[Zj00Co0000oooooooooooo00004oooool00ol@413o0000o`000003o`00
00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00;ooooo00Go410@oooooooooooooooooa0@4007ooooo`?o00000_ooool3o`0000Cooooo00KoZJVY
ob4Q8Ol0003o0000oc8b<_l00002ooooo`06onk^k_mEEEGo0000o`000?m4A4Cok^k^0_ooool01_o^
k^koIVIVo`000?l0003oA4A4o`000>Sooooo002>ooooo`05o`000?ooooooooooolc<c?l000003Ooo
ool00ol0003oooooooooo`05ooooo`03ofIVI_n7QhOooooo00?ooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00[ooooo00Go0000okZj^_ooooooV9RH
oa0@400<ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0ooooool2ooooo`00SOooool4o`000003oa0@
4?nYZJWooooo00cooooo0_l00006ooooo`03ojVYZOm4A4Cooooo00;ooooo0_l0000Eooooo`03o`00
0?oooooooooo00cooooo00?oEEEEofIVI_l000003?ooool01OnHV9So410@o`000?lQ8B7oc<c<00[o
oooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo1?l00002oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0ooooool2ooooo`00ooooool6ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0ooooool2ooooo`00ooooool6ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0ooooool2ooooo`00ooooool5ooooo`;o00000ooo
ool2o`000?oooooo1?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooo
oooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool0
0?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooooooo
ool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00
oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooo
oa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo0000
\
\>"],
  ImageRangeCache->{{{0, 525.688}, {324.5, 0}} -> {0, -6.34248*^6, 0, 53093}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0.309017 5.42214e-08 [
[.32684 .29652 -16.5 -12.5 ]
[.32684 .29652 16.5 0 ]
[.54329 .29652 -16.5 -12.5 ]
[.54329 .29652 16.5 0 ]
[.75974 .29652 -22.5 -12.5 ]
[.75974 .29652 22.5 0 ]
[.97619 .29652 -16.5 -12.5 ]
[.97619 .29652 16.5 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 64 6 ]
[.09789 .09213 -34.5 -6.25 ]
[.09789 .09213 0 6.25 ]
[.09789 .20057 -34.5 -6.25 ]
[.09789 .20057 0 6.25 ]
[.09789 .41746 -28.5 -6.25 ]
[.09789 .41746 0 6.25 ]
[.09789 .5259 -28.5 -6.25 ]
[.09789 .5259 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -62.8125 0 ]
[.5 .63053 62.8125 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 .30902 m
.32684 .31527 L
s
gsave
.32684 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 .30902 m
.54329 .31527 L
s
gsave
.54329 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 .30902 m
.75974 .31527 L
s
gsave
.75974 .29652 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 .30902 m
.15368 .31277 L
s
.19697 .30902 m
.19697 .31277 L
s
.24026 .30902 m
.24026 .31277 L
s
.28355 .30902 m
.28355 .31277 L
s
.37013 .30902 m
.37013 .31277 L
s
.41342 .30902 m
.41342 .31277 L
s
.45671 .30902 m
.45671 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.58658 .30902 m
.58658 .31277 L
s
.62987 .30902 m
.62987 .31277 L
s
.67316 .30902 m
.67316 .31277 L
s
.71645 .30902 m
.71645 .31277 L
s
.80303 .30902 m
.80303 .31277 L
s
.84632 .30902 m
.84632 .31277 L
s
.88961 .30902 m
.88961 .31277 L
s
.9329 .30902 m
.9329 .31277 L
s
.0671 .30902 m
.0671 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09213 m
.11664 .09213 L
s
gsave
.09789 .09213 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .20057 m
.11664 .20057 L
s
gsave
.09789 .20057 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .41746 m
.11664 .41746 L
s
gsave
.09789 .41746 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .5259 m
.11664 .5259 L
s
gsave
.09789 .5259 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.11039 .11924 m
.11414 .11924 L
s
.11039 .14635 m
.11414 .14635 L
s
.11039 .17346 m
.11414 .17346 L
s
.11039 .22768 m
.11414 .22768 L
s
.11039 .2548 m
.11414 .2548 L
s
.11039 .28191 m
.11414 .28191 L
s
.11039 .33613 m
.11414 .33613 L
s
.11039 .36324 m
.11414 .36324 L
s
.11039 .39035 m
.11414 .39035 L
s
.11039 .44457 m
.11414 .44457 L
s
.11039 .47168 m
.11414 .47168 L
s
.11039 .49879 m
.11414 .49879 L
s
.11039 .06502 m
.11414 .06502 L
s
.11039 .03791 m
.11414 .03791 L
s
.11039 .0108 m
.11414 .0108 L
s
.11039 .55301 m
.11414 .55301 L
s
.11039 .58012 m
.11414 .58012 L
s
.11039 .60723 m
.11414 .60723 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -123.812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.812 moveto
(@) show
81.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.812 moveto
(D) show
93.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.4) show
135.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
141.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
153.000 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
157.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
166.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
184.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02418 .30902 L
.02453 .30902 L
.02491 .30902 L
.02532 .30902 L
.02615 .30902 L
.02691 .30902 L
.02774 .30902 L
.02865 .30902 L
.03029 .30901 L
.03189 .30901 L
.03357 .30901 L
.03661 .30901 L
.03741 .309 L
.03817 .309 L
.03859 .309 L
.03881 .309 L
.03904 .309 L
.03916 .309 L
.03926 .309 L
.03936 .309 L
.03946 .309 L
.03955 .309 L
.03964 .309 L
.03974 .309 L
.03984 .309 L
.03995 .309 L
.04005 .309 L
.0401 .309 L
.04015 .309 L
.04026 .309 L
.04047 .309 L
.04066 .309 L
.04102 .309 L
.04141 .309 L
.04184 .309 L
.04229 .30901 L
.04309 .30901 L
.04385 .30901 L
.04467 .30902 L
.04615 .30903 L
.04786 .30905 L
.04948 .30907 L
.05257 .30912 L
.05339 .30913 L
.05416 .30914 L
.05458 .30914 L
.05497 .30914 L
.05517 .30914 L
.05539 .30915 L
Mistroke
.05551 .30915 L
.05563 .30915 L
.05574 .30915 L
.05579 .30915 L
.05585 .30915 L
.05595 .30915 L
.056 .30915 L
.05606 .30915 L
.05612 .30915 L
.05618 .30915 L
.05628 .30915 L
.05638 .30915 L
.05647 .30915 L
.05657 .30915 L
.05668 .30915 L
.0569 .30914 L
.0571 .30914 L
.05757 .30914 L
.05798 .30913 L
.05835 .30913 L
.05919 .30911 L
.05998 .30908 L
.06071 .30905 L
.06238 .30895 L
.06402 .30882 L
.06552 .30868 L
.06719 .3085 L
.06873 .30835 L
.06951 .30829 L
.07023 .30824 L
.07063 .30822 L
.07099 .3082 L
.07119 .3082 L
.07139 .30819 L
.07149 .30819 L
.0716 .30819 L
.07165 .30819 L
.07171 .30819 L
.07177 .30818 L
.07182 .30818 L
.07191 .30818 L
.07202 .30818 L
.07211 .30818 L
.0722 .30819 L
.0723 .30819 L
.07241 .30819 L
.07261 .30819 L
.07282 .3082 L
.07304 .30821 L
.07344 .30824 L
Mistroke
.0738 .30827 L
.07415 .3083 L
.07492 .30841 L
.07576 .30857 L
.07655 .30876 L
.07804 .30924 L
.0811 .31063 L
.08282 .31152 L
.08437 .31226 L
.08515 .31256 L
.08555 .31269 L
.08599 .31281 L
.08637 .31289 L
.08657 .31293 L
.08678 .31296 L
.08688 .31297 L
.08698 .31298 L
.08707 .31298 L
.08716 .31299 L
.08724 .31299 L
.08733 .313 L
.08741 .313 L
.08751 .313 L
.08761 .31299 L
.0877 .31299 L
.0878 .31298 L
.08791 .31297 L
.08812 .31294 L
.08832 .31291 L
.0887 .31282 L
.08906 .3127 L
.08948 .31252 L
.08987 .31232 L
.09074 .31171 L
.09152 .31098 L
.09225 .31015 L
.0939 .30774 L
.09702 .30182 L
.09861 .29873 L
.09945 .29728 L
.10034 .29599 L
.10078 .29547 L
.10121 .29507 L
.10158 .2948 L
.1018 .29468 L
.10189 .29464 L
.10199 .2946 L
.10209 .29457 L
.10218 .29454 L
.10227 .29452 L
Mistroke
.10235 .29451 L
.10245 .2945 L
.10254 .2945 L
.10264 .29451 L
.10274 .29452 L
.10283 .29454 L
.10293 .29457 L
.10312 .29464 L
.10333 .29475 L
.10353 .29489 L
.10391 .29525 L
.10432 .29577 L
.10505 .29707 L
.10592 .29925 L
.10672 .30182 L
.10826 .30838 L
.10993 .31739 L
.1115 .32685 L
.11322 .33705 L
.11401 .34121 L
.11486 .34501 L
.11527 .34654 L
.11566 .34778 L
.11604 .34875 L
.11639 .34945 L
.11657 .34972 L
.11676 .34994 L
.11686 .35003 L
.11697 .35011 L
.11706 .35015 L
.11716 .35018 L
.11722 .35019 L
.11727 .35019 L
.11737 .35018 L
.11748 .35015 L
.11754 .35012 L
.11759 .35009 L
.11768 .35001 L
.11778 .34992 L
.11799 .34965 L
.11818 .34932 L
.11836 .34894 L
.11875 .34783 L
.11912 .34648 L
.11947 .34491 L
.12024 .34041 L
.12106 .33408 L
.12253 .31898 L
.12588 .27273 L
.12755 .24874 L
Mistroke
.12829 .23939 L
.12909 .23052 L
.12947 .227 L
.12987 .22372 L
.13022 .22134 L
.1306 .21927 L
.13082 .21832 L
.13103 .21763 L
.13123 .21713 L
.13132 .21694 L
.13138 .21685 L
.13143 .21678 L
.13153 .21668 L
.13162 .21663 L
.13172 .21662 L
.13182 .21666 L
.13192 .21673 L
.13202 .21685 L
.13211 .21701 L
.13219 .21719 L
.13238 .2177 L
.13258 .21846 L
.13299 .22062 L
.13338 .22337 L
.13373 .22661 L
.13454 .23625 L
.1354 .25013 L
.13711 .28696 L
.13872 .33049 L
.14179 .41723 L
.14261 .43668 L
.14338 .45208 L
.14418 .46446 L
.1446 .46927 L
.14483 .47126 L
.14506 .47297 L
.14527 .4741 L
.14546 .47484 L
.14555 .47509 L
.14565 .47528 L
.14574 .47539 L
.14583 .47543 L
.14593 .47539 L
.14602 .47528 L
.14613 .47507 L
.14618 .47491 L
.14624 .47474 L
.14634 .47433 L
.14646 .47377 L
.14667 .47246 L
Mistroke
.14689 .47064 L
.14709 .46862 L
.14755 .46278 L
.14797 .45576 L
.14836 .44777 L
.14997 .40202 L
.15146 .34436 L
.15463 .19925 L
.15622 .13379 L
.15692 .1104 L
.15768 .08981 L
.15809 .0809 L
.15848 .07435 L
.15885 .0697 L
.15904 .06796 L
.15924 .06653 L
.15935 .066 L
.15941 .06577 L
.15946 .06559 L
.15956 .06536 L
.15966 .06524 L
.15972 .06524 L
.15977 .06527 L
.15988 .06544 L
.15993 .06559 L
.15999 .06577 L
.16011 .06631 L
.16021 .06687 L
.1603 .06751 L
.1605 .06937 L
.1607 .0717 L
.16092 .07478 L
.16134 .08252 L
.16173 .09169 L
.16262 .11932 L
.1634 .15097 L
.16424 .19119 L
.16758 .39044 L
.16926 .48709 L
.16999 .52307 L
.1708 .55604 L
.17118 .56877 L
.17158 .58032 L
.17193 .58848 L
.17231 .59534 L
.17253 .59837 L
.17263 .59947 L
.17273 .60051 L
.17283 .60127 L
.17293 .60194 L
Mistroke
.17299 .60224 L
.17304 .60247 L
.17314 .6028 L
.17324 .60297 L
.17333 .603 L
.17342 .60288 L
.17353 .6026 L
.17363 .60216 L
.17372 .60161 L
.1739 .6002 L
.17409 .59809 L
.17427 .59561 L
.17468 .58807 L
.17508 .57828 L
.17551 .56517 L
.17699 .50081 L
.17869 .39864 L
.18031 .28794 L
.18177 .18968 L
.1826 .13927 L
.18338 .09784 L
.18421 .06185 L
.18497 .0371 L
.18536 .02763 L
.18578 .02029 L
.186 .01758 L
.1862 .01573 L
.18631 .01497 L
.18642 .01446 L
.18648 .01426 L
.18654 .01411 L
.1866 .01402 L
.18665 .01399 L
.18675 .01406 L
.18685 .01429 L
.18694 .01461 L
.18703 .0151 L
.18713 .01579 L
.18724 .01671 L
.18743 .01883 L
.18781 .02476 L
.18816 .03208 L
.18901 .05768 L
.18981 .09071 L
.19291 .27178 L
.19448 .37262 L
.19531 .42169 L
.1962 .46811 L
.19706 .50501 L
.19785 .53073 L
Mistroke
.19822 .54018 L
.19863 .54821 L
.19882 .55108 L
.19902 .55358 L
.19919 .55526 L
.19938 .55662 L
.19947 .55714 L
.19957 .55749 L
.19967 .55773 L
.19972 .55781 L
.19977 .55784 L
.19987 .55779 L
.19993 .55769 L
.19999 .55756 L
.20008 .55721 L
.20019 .5567 L
.20037 .55542 L
.20054 .55381 L
.20093 .54864 L
.20135 .54078 L
.20174 .53164 L
.20261 .50484 L
.20413 .44064 L
.2058 .35647 L
.20752 .2691 L
.20907 .20181 L
.20985 .17519 L
.21026 .16352 L
.21069 .15308 L
.21107 .14554 L
.21149 .13907 L
.21167 .13683 L
.21186 .13484 L
.21203 .13347 L
.21222 .13232 L
.21232 .13182 L
.21242 .13147 L
.21253 .13121 L
.21259 .13112 L
.21264 .13107 L
.21274 .13106 L
.21284 .13117 L
.21294 .13138 L
.21304 .13166 L
.21315 .13215 L
.21326 .13273 L
.21347 .13416 L
.21369 .13617 L
.21393 .13888 L
.21434 .14477 L
Mistroke
.21477 .15261 L
.21554 .17038 L
.21859 .26947 L
.22029 .3281 L
.22183 .37273 L
.2226 .3899 L
.22301 .39739 L
.22344 .4041 L
.22381 .40888 L
.22423 .41297 L
.22441 .41436 L
.2246 .41561 L
.22479 .41652 L
.22496 .41715 L
.22506 .41744 L
.22516 .41764 L
.22524 .41776 L
.22534 .41783 L
.22544 .41784 L
.22549 .41782 L
.22555 .41777 L
.22565 .41764 L
.22574 .41745 L
.22584 .4172 L
.22593 .41691 L
.2261 .41623 L
.22628 .41529 L
.22648 .41403 L
.22689 .4106 L
.22734 .40589 L
.22814 .39495 L
.22986 .36354 L
.23148 .32964 L
.23296 .3002 L
.23379 .28565 L
.23458 .27409 L
.23535 .26486 L
.23575 .26105 L
.23618 .25764 L
.23642 .25611 L
.23663 .25489 L
.23684 .25393 L
.23707 .25307 L
.23727 .25248 L
.23746 .25208 L
.23756 .25191 L
.23766 .2518 L
.23776 .25172 L
.23781 .2517 L
.23787 .25168 L
Mistroke
.23792 .25168 L
.23798 .25169 L
.23808 .25173 L
.23818 .25182 L
.23824 .25188 L
.2383 .25196 L
.23849 .25231 L
.2387 .25283 L
.23909 .2542 L
.23945 .25589 L
.24031 .26145 L
.24113 .26832 L
.2442 .30037 L
.24576 .3154 L
.24658 .322 L
.24748 .32772 L
.24789 .32983 L
.24832 .33168 L
.24872 .33304 L
.2491 .33401 L
.24928 .33437 L
.24945 .33466 L
.24965 .33491 L
.24983 .33508 L
.24992 .33514 L
.25003 .33519 L
.25011 .33522 L
.25021 .33523 L
.25031 .33522 L
.25037 .33521 L
.25042 .33519 L
.25053 .33515 L
.25062 .33509 L
.25072 .33501 L
.25083 .3349 L
.25103 .33466 L
.25139 .33405 L
.25182 .33309 L
.25221 .33198 L
.25369 .32639 L
.25686 .31147 L
.25768 .30801 L
.25846 .30515 L
.25921 .30282 L
.25991 .30111 L
.26066 .29976 L
.26106 .29926 L
.26126 .29905 L
.26148 .29887 L
.26169 .29874 L
Mistroke
.26179 .29869 L
.26189 .29864 L
.26198 .29861 L
.26208 .29859 L
.26218 .29857 L
.26228 .29856 L
.26234 .29855 L
.26239 .29855 L
.26245 .29856 L
.26251 .29856 L
.26257 .29857 L
.26262 .29858 L
.26274 .29861 L
.26284 .29864 L
.26294 .29868 L
.26316 .29878 L
.26354 .29905 L
.26395 .29943 L
.26468 .30034 L
.26635 .30311 L
.26796 .30615 L
.26969 .30914 L
.27051 .31029 L
.27137 .31127 L
.27211 .3119 L
.27253 .31218 L
.27291 .31238 L
.27332 .31253 L
.27355 .31259 L
.27365 .31262 L
.27376 .31264 L
.27385 .31265 L
.27394 .31266 L
.27404 .31267 L
.27414 .31268 L
.27424 .31268 L
.2743 .31269 L
.27435 .31269 L
.27445 .31268 L
.27455 .31268 L
.27465 .31267 L
.27475 .31266 L
.27495 .31263 L
.27514 .3126 L
.27533 .31255 L
.27604 .31232 L
.2768 .31196 L
.27762 .3115 L
.27909 .31054 L
.28068 .30953 L
Mistroke
.28152 .30906 L
.28241 .30864 L
.2832 .30835 L
.28362 .30822 L
.28407 .3081 L
.28448 .30802 L
.28486 .30796 L
.28522 .30792 L
.28541 .30791 L
.2856 .30789 L
.28571 .30789 L
.28581 .30789 L
.28586 .30788 L
.28592 .30788 L
.28597 .30788 L
.28603 .30788 L
.28613 .30788 L
.28622 .30788 L
.28627 .30788 L
.28633 .30788 L
.28643 .30788 L
.28653 .30789 L
.28662 .30789 L
.28682 .3079 L
.287 .30791 L
.28718 .30793 L
.28799 .30802 L
.28886 .30816 L
.29043 .30846 L
.29215 .3088 L
.29295 .30894 L
.29379 .30907 L
.29459 .30917 L
.29533 .30924 L
.29572 .30926 L
.29614 .30929 L
.29657 .30931 L
.29681 .30932 L
.29703 .30932 L
.29723 .30933 L
.29733 .30933 L
.29744 .30933 L
.29753 .30933 L
.29763 .30933 L
.29773 .30933 L
.29781 .30933 L
.29786 .30933 L
.29792 .30933 L
.29802 .30933 L
.29807 .30933 L
Mistroke
.29812 .30933 L
.29824 .30933 L
.29844 .30932 L
.29865 .30932 L
.29907 .30931 L
.29946 .3093 L
.30035 .30926 L
.30196 .30917 L
.30359 .30908 L
.30438 .30905 L
.30511 .30902 L
.30581 .30899 L
.30657 .30897 L
.30733 .30896 L
.30775 .30895 L
.30814 .30895 L
.30835 .30894 L
.30854 .30894 L
.30876 .30894 L
.30886 .30894 L
.30892 .30894 L
.30898 .30894 L
.30908 .30894 L
.30918 .30894 L
.30928 .30894 L
.30934 .30894 L
.30939 .30894 L
.30949 .30894 L
.30958 .30894 L
.30968 .30894 L
.30978 .30894 L
.30996 .30894 L
.31015 .30894 L
.31049 .30894 L
.31127 .30895 L
.31285 .30897 L
.31432 .30899 L
.31581 .30901 L
.3166 .30902 L
.31744 .30902 L
.31786 .30903 L
.31833 .30903 L
.31875 .30903 L
.31915 .30903 L
.31955 .30903 L
.31976 .30903 L
.31986 .30903 L
.31998 .30903 L
.32008 .30903 L
.32017 .30903 L
Mistroke
.32027 .30903 L
.32035 .30903 L
.32045 .30903 L
.32051 .30903 L
.32056 .30903 L
.32066 .30903 L
.32076 .30903 L
.32086 .30903 L
.32096 .30903 L
.32107 .30903 L
.32118 .30903 L
.32139 .30903 L
.32158 .30903 L
.32232 .30903 L
.32319 .30903 L
.324 .30903 L
.32548 .30902 L
.3271 .30902 L
.32787 .30902 L
.3287 .30902 L
.32916 .30902 L
.32958 .30901 L
.32997 .30901 L
.33039 .30901 L
.33077 .30901 L
.33099 .30901 L
.33119 .30901 L
.33128 .30901 L
.33138 .30901 L
.33146 .30901 L
.33155 .30901 L
.33164 .30901 L
.33173 .30901 L
.33183 .30901 L
.33193 .30901 L
.33203 .30901 L
.33208 .30901 L
.33214 .30901 L
.33234 .30901 L
.33245 .30901 L
.33257 .30901 L
.33279 .30901 L
.33321 .30901 L
.3336 .30901 L
.33679 .30902 L
.33825 .30902 L
.33908 .30902 L
.33987 .30902 L
.34063 .30902 L
.34106 .30902 L
Mistroke
.34145 .30902 L
.34184 .30902 L
.34207 .30902 L
.34227 .30902 L
.34238 .30902 L
.34249 .30902 L
.34259 .30902 L
.34269 .30902 L
.34274 .30902 L
.3428 .30902 L
.34286 .30902 L
.34292 .30902 L
.34303 .30902 L
.34308 .30902 L
.34314 .30902 L
.34324 .30902 L
.34334 .30902 L
.34352 .30902 L
.34372 .30902 L
.34393 .30902 L
.34466 .30902 L
.34633 .30902 L
.3479 .30902 L
.34873 .30902 L
.34962 .30902 L
.35048 .30902 L
.35126 .30902 L
.35164 .30902 L
.35205 .30902 L
.35243 .30902 L
.35279 .30902 L
.35298 .30902 L
.35316 .30902 L
.35336 .30902 L
.35346 .30902 L
.35351 .30902 L
.35356 .30902 L
.35366 .30902 L
.35375 .30902 L
.35384 .30902 L
.35394 .30902 L
.35403 .30902 L
.35412 .30902 L
.3542 .30902 L
.35429 .30902 L
.35451 .30902 L
.3547 .30902 L
.35514 .30902 L
.35594 .30902 L
.3576 .30902 L
Mistroke
.35914 .30902 L
.36063 .30902 L
.36146 .30902 L
.36221 .30902 L
.3626 .30902 L
.36302 .30902 L
.36337 .30902 L
.36357 .30902 L
.36376 .30902 L
.36386 .30902 L
.36398 .30902 L
.36408 .30902 L
.36418 .30902 L
.36428 .30902 L
.36438 .30902 L
.36448 .30902 L
.36457 .30902 L
.36462 .30902 L
.36468 .30902 L
.36478 .30902 L
.36489 .30902 L
.36498 .30902 L
.3652 .30902 L
.36543 .30902 L
.36586 .30902 L
.36626 .30902 L
.36715 .30902 L
.36877 .30902 L
.37041 .30902 L
.37121 .30902 L
.37194 .30902 L
.3723 .30902 L
.37269 .30902 L
.37303 .30902 L
.37341 .30902 L
.3738 .30902 L
.37401 .30902 L
.37423 .30902 L
.37443 .30902 L
.37462 .30902 L
.3748 .30902 L
.37489 .30902 L
.37498 .30902 L
.37509 .30902 L
.37519 .30902 L
.37524 .30902 L
.37529 .30902 L
.37535 .30902 L
.37541 .30902 L
.37551 .30902 L
Mistroke
.3756 .30902 L
.37571 .30902 L
.37581 .30902 L
.37617 .30902 L
.37656 .30902 L
.37743 .30902 L
.37824 .30902 L
.37975 .30902 L
.38138 .30902 L
.38228 .30902 L
.38267 .30902 L
.3831 .30902 L
.38349 .30902 L
.38389 .30902 L
.38432 .30902 L
.38472 .30902 L
.38493 .30902 L
.38515 .30902 L
.38534 .30902 L
.38544 .30902 L
.38554 .30902 L
.38559 .30902 L
.38565 .30902 L
.38571 .30902 L
.38577 .30902 L
.38587 .30902 L
.38597 .30902 L
.38603 .30902 L
.3861 .30902 L
.38621 .30902 L
.38633 .30902 L
.38643 .30902 L
.38681 .30902 L
.38722 .30902 L
.38805 .30902 L
.38974 .30902 L
.39129 .30902 L
.39206 .30902 L
.39289 .30902 L
.39327 .30902 L
.39368 .30902 L
.39403 .30902 L
.39441 .30902 L
.3948 .30902 L
.39516 .30902 L
.39536 .30902 L
.39555 .30902 L
.39575 .30902 L
.39587 .30902 L
.39597 .30902 L
Mistroke
.39606 .30902 L
.39616 .30902 L
.39624 .30902 L
.39633 .30902 L
.39643 .30902 L
.39653 .30902 L
.39663 .30902 L
.39672 .30902 L
.3969 .30902 L
.39709 .30902 L
.39744 .30902 L
.39826 .30902 L
.39902 .30902 L
.4007 .30902 L
.40224 .30902 L
.40312 .30902 L
.4035 .30902 L
.40392 .30902 L
.40433 .30902 L
.4047 .30902 L
.40507 .30902 L
.40543 .30902 L
.40563 .30902 L
.40584 .30902 L
.40602 .30902 L
.40613 .30902 L
.40622 .30902 L
.40633 .30902 L
.40638 .30902 L
.40644 .30902 L
.40654 .30902 L
.40664 .30902 L
.4067 .30902 L
.40675 .30902 L
.40686 .30902 L
.40691 .30902 L
.40697 .30902 L
.40709 .30902 L
.40728 .30902 L
.40746 .30902 L
.40787 .30902 L
.40859 .30902 L
.41025 .30902 L
.41105 .30902 L
.41191 .30902 L
.41265 .30902 L
.41344 .30902 L
.41388 .30902 L
.41427 .30902 L
.41465 .30902 L
Mistroke
.41505 .30902 L
.41542 .30902 L
.41576 .30902 L
.41595 .30902 L
.41613 .30902 L
.41622 .30902 L
.41633 .30902 L
.41642 .30902 L
.41651 .30902 L
.41661 .30902 L
.4167 .30902 L
.4168 .30902 L
.4169 .30902 L
.417 .30902 L
.41709 .30902 L
.41719 .30902 L
.41727 .30902 L
.41748 .30902 L
.4177 .30902 L
.4181 .30902 L
.41979 .30902 L
.42136 .30902 L
.42219 .30902 L
.42308 .30902 L
.42352 .30902 L
.42394 .30902 L
.42434 .30902 L
.42472 .30902 L
.42507 .30902 L
.42545 .30902 L
.42583 .30902 L
.42605 .30902 L
.42625 .30902 L
.42634 .30902 L
.42644 .30902 L
.42653 .30902 L
.42663 .30902 L
.42668 .30902 L
.42674 .30902 L
.42684 .30902 L
.42694 .30902 L
.42704 .30902 L
.42714 .30902 L
.42724 .30902 L
.42734 .30902 L
.42743 .30902 L
.42766 .30902 L
.42787 .30902 L
.42858 .30902 L
.42935 .30902 L
Mistroke
.43107 .30902 L
.43262 .30902 L
.4334 .30902 L
.4338 .30902 L
.43424 .30902 L
.43462 .30902 L
.43503 .30902 L
.43541 .30902 L
.43576 .30902 L
.43597 .30902 L
.43616 .30902 L
.43638 .30902 L
.43648 .30902 L
.43654 .30902 L
.4366 .30902 L
.4367 .30902 L
.4368 .30902 L
.4369 .30902 L
.43696 .30902 L
.43701 .30902 L
.43711 .30902 L
.4372 .30902 L
.4373 .30902 L
.4374 .30902 L
.43758 .30902 L
.43777 .30902 L
.43811 .30902 L
.43889 .30902 L
.44048 .30902 L
.44193 .30902 L
.44273 .30902 L
.44349 .30902 L
.4443 .30902 L
.44475 .30902 L
.44517 .30902 L
.44558 .30902 L
.44581 .30902 L
.44602 .30902 L
.44621 .30902 L
.44631 .30902 L
.44641 .30902 L
.44652 .30902 L
.44661 .30902 L
.44666 .30902 L
.44672 .30902 L
.44682 .30902 L
.44692 .30902 L
.447 .30902 L
.4471 .30902 L
.4472 .30902 L
Mistroke
.44731 .30902 L
.44741 .30902 L
.4476 .30902 L
.44794 .30902 L
.44832 .30902 L
.45003 .30902 L
.45158 .30902 L
.45236 .30902 L
.4532 .30902 L
.45358 .30902 L
.45399 .30902 L
.45437 .30902 L
.45472 .30902 L
.45512 .30902 L
.45548 .30902 L
.45568 .30902 L
.45587 .30902 L
.45608 .30902 L
.45618 .30902 L
.4563 .30902 L
.45639 .30902 L
.45649 .30902 L
.45657 .30902 L
.45666 .30902 L
.45676 .30902 L
.45687 .30902 L
.45697 .30902 L
.45706 .30902 L
.45723 .30902 L
.45742 .30902 L
.45777 .30902 L
.45853 .30902 L
.45936 .30902 L
.46105 .30902 L
.46185 .30902 L
.46261 .30902 L
.46303 .30902 L
.46349 .30902 L
.46388 .30902 L
.46429 .30902 L
.46472 .30902 L
.46491 .30902 L
.46512 .30902 L
.46531 .30902 L
.46551 .30902 L
.4657 .30902 L
.46587 .30902 L
.46598 .30902 L
.46603 .30902 L
.46609 .30902 L
Mistroke
.46614 .30902 L
.4662 .30902 L
.4663 .30902 L
.4664 .30902 L
.4665 .30902 L
.4666 .30902 L
.46669 .30902 L
.46679 .30902 L
.46689 .30902 L
.46711 .30902 L
.46756 .30902 L
.4684 .30902 L
.4692 .30902 L
.4707 .30902 L
.47148 .30902 L
.47231 .30902 L
.47301 .30902 L
.47341 .30902 L
.47379 .30902 L
.47419 .30902 L
.4744 .30902 L
.47462 .30902 L
.47482 .30902 L
.47504 .30902 L
.47523 .30902 L
.47532 .30902 L
.47542 .30902 L
.47551 .30902 L
.4756 .30902 L
.4757 .30902 L
.47579 .30902 L
.47588 .30902 L
.47597 .30902 L
.47605 .30902 L
.47613 .30902 L
.47623 .30902 L
.47633 .30902 L
.47644 .30902 L
.47654 .30902 L
.47691 .30902 L
.47731 .30902 L
.47774 .30902 L
.47853 .30902 L
.48002 .30902 L
.48083 .30902 L
.4816 .30902 L
.48203 .30902 L
.48248 .30902 L
.4829 .30902 L
.48329 .30902 L
Mistroke
.48365 .30902 L
.48405 .30902 L
.48427 .30902 L
.48449 .30902 L
.48468 .30902 L
.48479 .30902 L
.48489 .30902 L
.48499 .30902 L
.48509 .30902 L
.4852 .30902 L
.48525 .30902 L
.48531 .30902 L
.48537 .30902 L
.48542 .30902 L
.48553 .30902 L
.48559 .30902 L
.48565 .30902 L
.48571 .30902 L
.48577 .30902 L
.48586 .30902 L
.48597 .30902 L
.48619 .30902 L
.48658 .30902 L
.48739 .30902 L
.48814 .30902 L
.48901 .30902 L
.48982 .30902 L
.49062 .30902 L
.49135 .30902 L
.49215 .30902 L
.49259 .30902 L
.49301 .30902 L
.49339 .30902 L
.4938 .30902 L
.494 .30902 L
.49423 .30902 L
.49433 .30902 L
.49444 .30902 L
.49453 .30902 L
.49463 .30902 L
.49472 .30902 L
.49481 .30902 L
.4949 .30902 L
.495 .30902 L
.49509 .30902 L
.49517 .30902 L
.49525 .30902 L
.49534 .30902 L
.49553 .30902 L
.49574 .30902 L
Mistroke
.49611 .30902 L
.49771 .30902 L
.49856 .30902 L
.49945 .30902 L
.50024 .30902 L
.50067 .30902 L
.50112 .30902 L
.50154 .30902 L
.50192 .30902 L
.5023 .30902 L
.50266 .30902 L
.50303 .30902 L
.50324 .30902 L
.50344 .30902 L
.50364 .30902 L
.50383 .30902 L
.50393 .30902 L
.50404 .30902 L
.50409 .30902 L
.50415 .30902 L
.50426 .30902 L
.50436 .30902 L
.50445 .30902 L
.50455 .30902 L
.5046 .30902 L
.50466 .30902 L
.50485 .30902 L
.50503 .30902 L
.50537 .30902 L
.50574 .30902 L
.50732 .30902 L
.50816 .30902 L
.50905 .30902 L
.5095 .30902 L
.50992 .30902 L
.51033 .30902 L
.5107 .30902 L
.51106 .30902 L
.51144 .30902 L
.51183 .30902 L
.51224 .30902 L
.51244 .30902 L
.51266 .30902 L
.51287 .30902 L
.51297 .30902 L
.51306 .30902 L
.51315 .30902 L
.51323 .30902 L
.51332 .30902 L
.51342 .30902 L
Mistroke
.51351 .30902 L
.51361 .30902 L
.51371 .30902 L
.51381 .30902 L
.51391 .30902 L
.51397 .30902 L
.51403 .30902 L
.51423 .30902 L
.51442 .30902 L
.51462 .30902 L
.51549 .30902 L
.51708 .30902 L
.51777 .30902 L
.51853 .30902 L
.51895 .30902 L
.51933 .30902 L
.52009 .30902 L
.52048 .30902 L
.52091 .30902 L
.52112 .30902 L
.52135 .30902 L
.52156 .30902 L
.52177 .30902 L
.52198 .30902 L
.52217 .30902 L
.52226 .30902 L
.52236 .30902 L
.52245 .30902 L
.52254 .30902 L
.52264 .30902 L
.52269 .30902 L
.52275 .30902 L
.52281 .30902 L
.52287 .30902 L
.52292 .30902 L
.52298 .30902 L
.52308 .30902 L
.52313 .30902 L
.52318 .30902 L
.52338 .30902 L
.5236 .30902 L
.5238 .30902 L
.52425 .30902 L
.52507 .30902 L
.52586 .30902 L
.52671 .30902 L
.52744 .30902 L
.52824 .30902 L
.52867 .30902 L
.52906 .30902 L
Mistroke
.52943 .30902 L
.52984 .30902 L
.5302 .30902 L
.53054 .30902 L
.5309 .30902 L
.5311 .30902 L
.53129 .30902 L
.53139 .30902 L
.53149 .30902 L
.53158 .30902 L
.53167 .30902 L
.53177 .30902 L
.53187 .30902 L
.53197 .30902 L
.53202 .30902 L
.53208 .30902 L
.53217 .30902 L
.53226 .30902 L
.53234 .30902 L
.53243 .30902 L
.53281 .30902 L
.53323 .30902 L
.53367 .30902 L
.53447 .30902 L
.53608 .30902 L
.53698 .30902 L
.53741 .30902 L
.53781 .30902 L
.5382 .30902 L
.53856 .30902 L
.53896 .30902 L
.53918 .30902 L
.53938 .30902 L
.53979 .30902 L
.54 .30902 L
.54023 .30902 L
.54032 .30902 L
.54043 .30902 L
.54052 .30902 L
.54061 .30902 L
.54072 .30902 L
.54078 .30902 L
.54083 .30902 L
.54093 .30902 L
.54103 .30902 L
.54113 .30902 L
.54119 .30902 L
.54124 .30902 L
.54135 .30902 L
.54146 .30902 L
Mistroke
.54167 .30902 L
.54186 .30902 L
.54275 .30902 L
.54437 .30902 L
.54511 .30902 L
.5459 .30902 L
.54631 .30902 L
.54676 .30902 L
.54715 .30902 L
.54757 .30902 L
.54796 .30902 L
.54816 .30902 L
.54837 .30902 L
.54858 .30902 L
.54876 .30902 L
.54893 .30902 L
.54912 .30902 L
.54922 .30902 L
.54933 .30902 L
.54943 .30902 L
.54953 .30902 L
.54964 .30902 L
.5497 .30902 L
.54976 .30902 L
.54986 .30902 L
.54992 .30902 L
.54998 .30902 L
.55003 .30902 L
.55008 .30902 L
.55018 .30902 L
.55028 .30902 L
.55037 .30902 L
.55057 .30902 L
.55079 .30902 L
.55155 .30902 L
.55237 .30902 L
.55384 .30902 L
.55466 .30902 L
.55509 .30902 L
.55555 .30902 L
.55595 .30902 L
.55639 .30902 L
.55679 .30902 L
.55716 .30902 L
.55754 .30902 L
.55775 .30902 L
.55795 .30902 L
.55816 .30902 L
.55835 .30902 L
.55846 .30902 L
Mistroke
.55852 .30902 L
.55858 .30902 L
.55863 .30902 L
.55868 .30902 L
.55878 .30902 L
.55888 .30902 L
.55898 .30902 L
.55906 .30902 L
.55915 .30902 L
.55925 .30902 L
.55936 .30902 L
.55955 .30902 L
.55993 .30902 L
.56027 .30902 L
.56195 .30902 L
.56269 .30902 L
.56349 .30902 L
.56387 .30902 L
.56427 .30902 L
.56462 .30902 L
.565 .30902 L
.56543 .30902 L
.56583 .30902 L
.56603 .30902 L
.56623 .30902 L
.56659 .30902 L
.56679 .30902 L
.56699 .30902 L
.56716 .30902 L
.56726 .30902 L
.56735 .30902 L
.56745 .30902 L
.56755 .30902 L
.56764 .30902 L
.56774 .30902 L
.56785 .30902 L
.5679 .30902 L
.56796 .30902 L
.56806 .30902 L
.56816 .30902 L
.56835 .30902 L
.56853 .30902 L
.56887 .30902 L
.56963 .30902 L
.57109 .30902 L
.57192 .30902 L
.57233 .30902 L
.5727 .30902 L
.57347 .30902 L
.57387 .30902 L
Mistroke
.57429 .30902 L
.57471 .30902 L
.5751 .30902 L
.57532 .30902 L
.57552 .30902 L
.57564 .30902 L
.57576 .30902 L
.57587 .30902 L
.57598 .30902 L
.57607 .30902 L
.57617 .30902 L
.57626 .30902 L
.57637 .30902 L
.57646 .30902 L
.57656 .30902 L
.57665 .30902 L
.57674 .30902 L
.57685 .30902 L
.57694 .30902 L
.57717 .30902 L
.57757 .30902 L
.57926 .30902 L
.57999 .30902 L
.58078 .30902 L
.58122 .30902 L
.58163 .30902 L
.58202 .30902 L
.58244 .30902 L
.58281 .30902 L
.58323 .30902 L
.58342 .30902 L
.58361 .30902 L
.58397 .30902 L
.58417 .30902 L
.58439 .30902 L
.58451 .30902 L
.58463 .30902 L
.58474 .30902 L
.58484 .30902 L
.58494 .30902 L
.58504 .30902 L
.58514 .30902 L
.58519 .30902 L
.58525 .30902 L
.58535 .30902 L
.58545 .30902 L
.58555 .30902 L
.58564 .30902 L
.58602 .30902 L
.58643 .30902 L
Mistroke
.58717 .30902 L
.58797 .30902 L
.58883 .30902 L
.58965 .30902 L
.59 .30902 L
.59039 .30902 L
.59111 .30902 L
.5915 .30902 L
.59186 .30902 L
.59226 .30902 L
.59249 .30902 L
.5927 .30902 L
.59289 .30902 L
.59309 .30902 L
.59319 .30902 L
.5933 .30902 L
.5934 .30902 L
.5935 .30902 L
.59359 .30902 L
.59369 .30902 L
.59378 .30902 L
.59386 .30902 L
.59396 .30902 L
.59402 .30902 L
.59407 .30902 L
.59426 .30902 L
.59443 .30902 L
.59462 .30902 L
.59499 .30902 L
.59669 .30902 L
.59749 .30902 L
.59824 .30902 L
.599 .30902 L
.59941 .30902 L
.59984 .30902 L
.60021 .30902 L
.60056 .30902 L
.60095 .30902 L
.60116 .30902 L
.60136 .30902 L
.60156 .30902 L
.60174 .30902 L
.60184 .30902 L
.60195 .30902 L
.60205 .30902 L
.60215 .30902 L
.60224 .30902 L
.60232 .30902 L
.60241 .30902 L
.6025 .30902 L
Mistroke
.6026 .30902 L
.6027 .30902 L
.60288 .30902 L
.60308 .30902 L
.60329 .30902 L
.60368 .30902 L
.60454 .30902 L
.60537 .30902 L
.60626 .30902 L
.60668 .30902 L
.60711 .30902 L
.60752 .30902 L
.60788 .30902 L
.60825 .30902 L
.60865 .30902 L
.60887 .30902 L
.60907 .30902 L
.60927 .30902 L
.60947 .30902 L
.60981 .30902 L
.60999 .30902 L
.61018 .30902 L
.61028 .30902 L
.61038 .30902 L
.61048 .30902 L
.61058 .30902 L
.61067 .30902 L
.61075 .30902 L
.61085 .30902 L
.61094 .30902 L
.61103 .30902 L
.61113 .30902 L
.61123 .30902 L
.61131 .30902 L
.61152 .30902 L
.61172 .30902 L
.61255 .30902 L
.61403 .30902 L
.6148 .30902 L
.61523 .30902 L
.61563 .30902 L
.61633 .30902 L
.6167 .30902 L
.61711 .30902 L
.6175 .30902 L
.61787 .30902 L
.61809 .30902 L
.61828 .30902 L
.61839 .30902 L
.6185 .30902 L
Mistroke
.61861 .30902 L
.61871 .30902 L
.61882 .30902 L
.61892 .30902 L
.61903 .30902 L
.61908 .30902 L
.61914 .30902 L
.6192 .30902 L
.61925 .30902 L
.61936 .30902 L
.61942 .30902 L
.61948 .30902 L
.61954 .30902 L
.61959 .30902 L
.6198 .30902 L
.62002 .30902 L
.62041 .30902 L
.622 .30902 L
.6227 .30902 L
.62346 .30902 L
.62388 .30902 L
.62426 .30902 L
.62466 .30902 L
.62503 .30902 L
.62541 .30902 L
.62564 .30902 L
.62584 .30902 L
.62626 .30902 L
.62647 .30902 L
.6267 .30902 L
.62691 .30902 L
.62701 .30902 L
.62711 .30902 L
.62719 .30902 L
.62728 .30902 L
.62737 .30902 L
.62747 .30902 L
.62753 .30902 L
.62758 .30902 L
.62768 .30902 L
.62778 .30902 L
.62784 .30902 L
.6279 .30902 L
.62799 .30902 L
.62809 .30902 L
.62829 .30902 L
.62866 .30902 L
.62905 .30902 L
.62977 .30902 L
.6306 .30902 L
Mistroke
.63137 .30902 L
.63218 .30902 L
.63261 .30902 L
.63306 .30902 L
.63349 .30902 L
.63388 .30902 L
.63432 .30902 L
.63453 .30902 L
.63477 .30902 L
.63498 .30902 L
.63518 .30902 L
.63528 .30902 L
.6354 .30902 L
.63551 .30902 L
.63561 .30902 L
.63571 .30902 L
.63581 .30902 L
.63589 .30902 L
.63599 .30902 L
.63609 .30902 L
.63614 .30902 L
.6362 .30902 L
.6363 .30902 L
.63639 .30902 L
.6366 .30902 L
.63679 .30902 L
.63723 .30902 L
.63802 .30902 L
.63874 .30902 L
.63951 .30902 L
.63992 .30902 L
.64029 .30902 L
.64101 .30902 L
.6414 .30902 L
.64182 .30902 L
.64203 .30902 L
.64226 .30902 L
.64267 .30902 L
.64287 .30902 L
.64309 .30902 L
.64328 .30902 L
.64349 .30902 L
.6436 .30902 L
.64371 .30902 L
.64383 .30902 L
.64389 .30902 L
.64395 .30902 L
.644 .30902 L
.64406 .30902 L
.64415 .30902 L
Mistroke
.64421 .30902 L
.64427 .30902 L
.64433 .30902 L
.64438 .30902 L
.64447 .30902 L
.64457 .30902 L
.64476 .30902 L
.64497 .30902 L
.64517 .30902 L
.646 .30902 L
.6468 .30902 L
.64766 .30902 L
.64839 .30902 L
.64881 .30902 L
.6492 .30902 L
.64958 .30902 L
.64997 .30902 L
.65031 .30902 L
.65068 .30902 L
.65089 .30902 L
.65108 .30902 L
.6513 .30902 L
.65151 .30902 L
.6517 .30902 L
.65188 .30902 L
.65197 .30902 L
.65208 .30902 L
.65213 .30902 L
.65218 .30902 L
.65228 .30902 L
.65238 .30902 L
.65243 .30902 L
.65249 .30902 L
.65259 .30902 L
.65265 .30902 L
.6527 .30902 L
.6528 .30902 L
.65289 .30902 L
.6531 .30902 L
.65356 .30902 L
.65398 .30902 L
.6556 .30902 L
.656 .30902 L
.65644 .30902 L
.65683 .30902 L
.65724 .30902 L
.65761 .30902 L
.65801 .30902 L
.65838 .30902 L
.65873 .30902 L
Mistroke
.65913 .30902 L
.65935 .30902 L
.65956 .30902 L
.65976 .30902 L
.65995 .30902 L
.66005 .30902 L
.66016 .30902 L
.66026 .30902 L
.66036 .30902 L
.66044 .30902 L
.66053 .30902 L
.66062 .30902 L
.6607 .30902 L
.66079 .30902 L
.6609 .30902 L
.66099 .30902 L
.66108 .30902 L
.66145 .30902 L
.66184 .30902 L
.66261 .30902 L
.66343 .30902 L
.66418 .30902 L
.66488 .30902 L
.66523 .30902 L
.66562 .30902 L
.66604 .30902 L
.66643 .30902 L
.66684 .30902 L
.66708 .30902 L
.66729 .30902 L
.6675 .30902 L
.66769 .30902 L
.66789 .30902 L
.66799 .30902 L
.6681 .30902 L
.66821 .30902 L
.66831 .30902 L
.66836 .30902 L
.66842 .30902 L
.66853 .30902 L
.66863 .30902 L
.66873 .30902 L
.66882 .30902 L
.66892 .30902 L
.66898 .30902 L
.66903 .30902 L
.66914 .30902 L
.66938 .30902 L
.6698 .30902 L
.67059 .30902 L
Mistroke
.67142 .30902 L
.67218 .30902 L
.67259 .30902 L
.67302 .30902 L
.67342 .30902 L
.67379 .30902 L
.67415 .30902 L
.6745 .30902 L
.67471 .30902 L
.6749 .30902 L
.67527 .30902 L
.67548 .30902 L
.67566 .30902 L
.67587 .30902 L
.67599 .30902 L
.67609 .30902 L
.67617 .30902 L
.67627 .30902 L
.67636 .30902 L
.67645 .30902 L
.67654 .30902 L
.67663 .30902 L
.67671 .30902 L
.67679 .30902 L
.67689 .30902 L
.67699 .30902 L
.67709 .30902 L
.67719 .30902 L
.67757 .30902 L
.67917 .30902 L
.67987 .30902 L
.68062 .30902 L
.68105 .30902 L
.68143 .30902 L
.6818 .30902 L
.6822 .30902 L
.68261 .30902 L
.683 .30902 L
.68322 .30902 L
.68342 .30902 L
.68366 .30902 L
.68376 .30902 L
.68388 .30902 L
.68399 .30902 L
.68409 .30902 L
.68418 .30902 L
.68428 .30902 L
.68438 .30902 L
.68446 .30902 L
.68455 .30902 L
Mistroke
.68465 .30902 L
.68476 .30902 L
.68482 .30902 L
.68487 .30902 L
.68497 .30902 L
.68508 .30902 L
.68527 .30902 L
.68547 .30902 L
.68695 .30902 L
.68771 .30902 L
.6885 .30902 L
.68892 .30902 L
.68938 .30902 L
.68979 .30902 L
.69018 .30902 L
.69058 .30902 L
.69081 .30902 L
.69102 .30902 L
.69123 .30902 L
.69141 .30902 L
.69161 .30902 L
.69182 .30902 L
.69192 .30902 L
.69202 .30902 L
.6921 .30902 L
.6922 .30902 L
.69228 .30902 L
.69238 .30902 L
.69246 .30902 L
.69254 .30902 L
.69264 .30902 L
.69274 .30902 L
.69282 .30902 L
.69291 .30902 L
.69301 .30902 L
.69312 .30902 L
.69332 .30902 L
.69491 .30902 L
.69575 .30902 L
.69621 .30902 L
.69664 .30902 L
.69706 .30902 L
.69744 .30902 L
.69786 .30902 L
.69831 .30902 L
.69869 .30902 L
.6989 .30902 L
.6991 .30902 L
.69929 .30902 L
.69946 .30902 L
Mistroke
.69966 .30902 L
.69985 .30902 L
.69994 .30902 L
.70004 .30902 L
.70014 .30902 L
.70022 .30902 L
.70032 .30902 L
.70038 .30902 L
.70043 .30902 L
.70053 .30902 L
.70063 .30902 L
.70073 .30902 L
.70084 .30902 L
.70094 .30902 L
.70103 .30902 L
.70146 .30902 L
.70294 .30902 L
.70368 .30902 L
.70446 .30902 L
.70491 .30902 L
.70532 .30902 L
.70574 .30902 L
.70613 .30902 L
.7065 .30902 L
.70671 .30902 L
.70691 .30902 L
.70711 .30902 L
.7073 .30902 L
.70741 .30902 L
.70753 .30902 L
.70763 .30902 L
.70773 .30902 L
.70783 .30902 L
.70793 .30902 L
.70802 .30902 L
.7081 .30902 L
.7082 .30902 L
.7083 .30902 L
.7084 .30902 L
.7085 .30902 L
.70859 .30902 L
.70868 .30902 L
.70884 .30902 L
.70921 .30902 L
.71068 .30902 L
.71151 .30902 L
.71192 .30902 L
.71229 .30902 L
.71266 .30902 L
.71306 .30902 L
Mistroke
.71348 .30902 L
.71389 .30902 L
.71431 .30902 L
.71455 .30902 L
.71476 .30902 L
.71496 .30902 L
.71518 .30902 L
.71528 .30902 L
.71538 .30902 L
.71557 .30902 L
.71567 .30902 L
.71578 .30902 L
.71588 .30902 L
.71597 .30902 L
.71605 .30902 L
.71615 .30902 L
.71624 .30902 L
.71633 .30902 L
.71643 .30902 L
.71654 .30902 L
.71673 .30902 L
.71715 .30902 L
.71862 .30902 L
.71938 .30902 L
.71981 .30902 L
.7202 .30902 L
.72057 .30902 L
.72097 .30902 L
.72134 .30902 L
.72168 .30902 L
.72205 .30902 L
.72226 .30902 L
.72245 .30902 L
.72263 .30902 L
.72283 .30902 L
.72301 .30902 L
.72318 .30902 L
.72329 .30902 L
.7234 .30902 L
.7235 .30902 L
.7236 .30902 L
.72369 .30902 L
.72379 .30902 L
.72389 .30902 L
.72398 .30902 L
.72404 .30902 L
.72409 .30902 L
.7242 .30902 L
.7244 .30902 L
.72462 .30902 L
Mistroke
.72484 .30902 L
.72562 .30902 L
.72646 .30902 L
.72726 .30902 L
.72764 .30902 L
.72799 .30902 L
.72836 .30902 L
.7287 .30902 L
.72907 .30902 L
.72947 .30902 L
.72985 .30902 L
.73007 .30902 L
.73027 .30902 L
.73044 .30902 L
.73064 .30902 L
.73073 .30902 L
.73084 .30902 L
.73102 .30902 L
.73113 .30902 L
.73123 .30902 L
.73128 .30902 L
.73134 .30902 L
.73145 .30902 L
.73155 .30902 L
.73165 .30902 L
.73174 .30902 L
.73184 .30902 L
.73195 .30902 L
.73206 .30902 L
.7323 .30902 L
.73273 .30902 L
.73356 .30902 L
.73434 .30902 L
.73508 .30902 L
.73546 .30902 L
.73588 .30902 L
.73629 .30902 L
.73674 .30902 L
.73695 .30902 L
.73716 .30902 L
.73754 .30902 L
.73775 .30902 L
.73795 .30902 L
.73812 .30902 L
.73831 .30902 L
.73852 .30902 L
.73863 .30902 L
.73874 .30902 L
.73884 .30902 L
.73894 .30902 L
Mistroke
.73904 .30902 L
.73913 .30902 L
.73922 .30902 L
.73932 .30902 L
.7394 .30902 L
.7395 .30902 L
.73959 .30902 L
.7397 .30902 L
.73989 .30902 L
.74061 .30902 L
.74137 .30902 L
.74219 .30902 L
.74265 .30902 L
.74308 .30902 L
.74351 .30902 L
.74391 .30902 L
.7443 .30902 L
.74471 .30902 L
.74505 .30902 L
.74525 .30902 L
.74544 .30902 L
.74565 .30902 L
.74585 .30902 L
.74604 .30902 L
.74614 .30902 L
.74623 .30902 L
.74635 .30902 L
.74645 .30902 L
.74651 .30902 L
.74656 .30902 L
.74662 .30902 L
.74668 .30902 L
.74678 .30902 L
.74688 .30902 L
.74698 .30902 L
.74704 .30902 L
.74709 .30902 L
.74728 .30902 L
.74748 .30902 L
.74789 .30902 L
.74863 .30902 L
.7495 .30902 L
.74988 .30902 L
.75029 .30902 L
.75066 .30902 L
.75105 .30902 L
.75147 .30902 L
.75185 .30902 L
.75207 .30902 L
.7523 .30902 L
Mistroke
.75251 .30902 L
.75273 .30902 L
.75293 .30902 L
.75314 .30902 L
.75334 .30902 L
.75352 .30902 L
.75363 .30902 L
.75373 .30902 L
.75383 .30902 L
.75393 .30902 L
.75398 .30902 L
.75403 .30902 L
.75413 .30902 L
.75419 .30902 L
.75424 .30902 L
.75431 .30902 L
.75436 .30902 L
.75447 .30902 L
.75456 .30902 L
.75465 .30902 L
.75475 .30902 L
.75496 .30902 L
.75516 .30902 L
.75664 .30902 L
.75737 .30902 L
.75815 .30902 L
.7586 .30902 L
.759 .30902 L
.75941 .30902 L
.7598 .30902 L
.76001 .30902 L
.76021 .30902 L
.76039 .30902 L
.76057 .30902 L
.76078 .30902 L
.76097 .30902 L
.76117 .30902 L
.76129 .30902 L
.7614 .30902 L
.76149 .30902 L
.76159 .30902 L
.76168 .30902 L
.76177 .30902 L
.76185 .30902 L
.76193 .30902 L
.76202 .30902 L
.76211 .30902 L
.7622 .30902 L
.7623 .30902 L
.76248 .30902 L
Mistroke
.76287 .30902 L
.7637 .30902 L
.76448 .30902 L
.76517 .30902 L
.76557 .30902 L
.76593 .30902 L
.7663 .30902 L
.7667 .30902 L
.7669 .30902 L
.76712 .30902 L
.76751 .30902 L
.76772 .30902 L
.76796 .30902 L
.76818 .30902 L
.76839 .30902 L
.76849 .30902 L
.76859 .30902 L
.76877 .30902 L
.76888 .30902 L
.76897 .30902 L
.76908 .30902 L
.76913 .30902 L
.76919 .30902 L
.76929 .30902 L
.76939 .30902 L
.76944 .30902 L
.7695 .30902 L
.76956 .30902 L
.76961 .30902 L
.7698 .30902 L
.77001 .30902 L
.77076 .30902 L
.77163 .30902 L
.77244 .30902 L
.77283 .30902 L
.77325 .30902 L
.77371 .30902 L
.77413 .30902 L
.77453 .30902 L
.77476 .30902 L
.77496 .30902 L
.77534 .30902 L
.77554 .30902 L
.77575 .30902 L
.77595 .30902 L
.77606 .30902 L
.77617 .30902 L
.77627 .30902 L
.77636 .30902 L
.77646 .30902 L
Mistroke
.77651 .30902 L
.77657 .30902 L
.77666 .30902 L
.77675 .30902 L
.77686 .30902 L
.77695 .30902 L
.77705 .30902 L
.77713 .30902 L
.77731 .30902 L
.77773 .30902 L
.77818 .30902 L
.77899 .30902 L
.77975 .30902 L
.78018 .30902 L
.78058 .30902 L
.78101 .30902 L
.7814 .30902 L
.78161 .30902 L
.78185 .30902 L
.78227 .30902 L
.78248 .30902 L
.7827 .30902 L
.78291 .30902 L
.7831 .30902 L
.78328 .30902 L
.78347 .30902 L
.78357 .30902 L
.78367 .30902 L
.78377 .30902 L
.78385 .30902 L
.78396 .30902 L
.78401 .30902 L
.78407 .30902 L
.78417 .30902 L
.78427 .30902 L
.78432 .30902 L
.78438 .30902 L
.78449 .30902 L
.78472 .30902 L
.78511 .30902 L
.78554 .30902 L
.78635 .30902 L
.78712 .30902 L
.78754 .30902 L
.788 .30902 L
.78841 .30902 L
.7888 .30902 L
.78917 .30902 L
.78938 .30902 L
.78958 .30902 L
Mistroke
.78976 .30902 L
.78996 .30902 L
.79014 .30902 L
.79031 .30902 L
.7905 .30902 L
.79062 .30902 L
.79072 .30902 L
.79082 .30902 L
.79094 .30902 L
.79105 .30902 L
.79111 .30902 L
.79117 .30902 L
.79127 .30902 L
.79137 .30902 L
.79147 .30902 L
.79153 .30902 L
.79158 .30902 L
.79167 .30902 L
.79177 .30902 L
.79187 .30902 L
.79196 .30902 L
.79345 .30902 L
.79424 .30902 L
.79467 .30902 L
.79508 .30902 L
.79554 .30902 L
.79596 .30902 L
.79635 .30902 L
.79655 .30902 L
.79677 .30902 L
.79697 .30902 L
.79718 .30902 L
.7974 .30902 L
.79761 .30902 L
.79782 .30902 L
.79792 .30902 L
.79802 .30902 L
.79819 .30902 L
.79829 .30902 L
.79838 .30902 L
.79848 .30902 L
.79858 .30902 L
.79868 .30902 L
.79878 .30902 L
.79887 .30902 L
.79895 .30902 L
.79905 .30902 L
.79914 .30902 L
.79934 .30902 L
.79953 .30902 L
Mistroke
.79995 .30902 L
.80066 .30902 L
.80142 .30902 L
.80182 .30902 L
.80219 .30902 L
.80257 .30902 L
.80292 .30902 L
.80333 .30902 L
.80356 .30902 L
.80377 .30902 L
.80416 .30902 L
.80438 .30902 L
.80458 .30902 L
.80477 .30902 L
.80495 .30902 L
.80515 .30902 L
.80536 .30902 L
.80547 .30902 L
.80559 .30902 L
.80564 .30902 L
.8057 .30902 L
.8058 .30902 L
.8059 .30902 L
.80599 .30902 L
.80609 .30902 L
.80614 .30902 L
.80619 .30902 L
.80628 .30902 L
.80637 .30902 L
.80654 .30902 L
.80692 .30902 L
.80768 .30902 L
.8085 .30902 L
.80894 .30902 L
.80939 .30902 L
.8098 .30902 L
.81024 .30902 L
.81064 .30902 L
.81101 .30902 L
.81122 .30902 L
.81141 .30902 L
.81162 .30902 L
.81185 .30902 L
.81205 .30902 L
.81224 .30902 L
.81243 .30902 L
.81254 .30902 L
.81264 .30902 L
.81273 .30902 L
.81282 .30902 L
Mistroke
.81291 .30902 L
.81299 .30902 L
.81308 .30902 L
.81319 .30902 L
.81328 .30902 L
.81337 .30902 L
.81346 .30902 L
.81355 .30902 L
.81374 .30902 L
.81393 .30902 L
.81413 .30902 L
.8149 .30902 L
.81572 .30902 L
.81619 .30902 L
.81661 .30902 L
.81704 .30902 L
.81744 .30902 L
.81783 .30902 L
.81805 .30902 L
.81824 .30902 L
.81859 .30902 L
.81878 .30902 L
.81898 .30902 L
.81919 .30902 L
.81942 .30902 L
.81953 .30902 L
.81964 .30902 L
.81974 .30902 L
.81984 .30902 L
.81995 .30902 L
.82004 .30902 L
.82013 .30902 L
.82022 .30902 L
.82032 .30902 L
.82042 .30902 L
.82052 .30902 L
.82058 .30902 L
.82063 .30902 L
.82073 .30902 L
.82082 .30902 L
.82102 .30902 L
.82144 .30902 L
.82218 .30902 L
.82303 .30902 L
.82345 .30902 L
.82384 .30902 L
.82422 .30902 L
.82463 .30902 L
.82485 .30902 L
.82507 .30902 L
Mistroke
.82527 .30902 L
.82547 .30902 L
.82565 .30902 L
.82585 .30902 L
.82619 .30902 L
.82638 .30902 L
.82659 .30902 L
.82679 .30902 L
.82696 .30902 L
.82706 .30902 L
.82715 .30902 L
.82725 .30902 L
.82735 .30902 L
.8274 .30902 L
.82746 .30902 L
.82757 .30902 L
.82767 .30902 L
.82776 .30902 L
.82786 .30902 L
.82795 .30902 L
.82812 .30902 L
.8285 .30902 L
.82931 .30902 L
.83017 .30902 L
.83094 .30902 L
.83137 .30902 L
.83178 .30902 L
.83215 .30902 L
.83249 .30902 L
.83268 .30902 L
.83289 .30902 L
.83326 .30902 L
.83345 .30902 L
.83365 .30902 L
.83384 .30902 L
.83402 .30902 L
.83412 .30902 L
.83421 .30902 L
.83431 .30902 L
.83437 .30902 L
.83442 .30902 L
.83453 .30902 L
.83459 .30902 L
.83464 .30902 L
.83474 .30902 L
.83479 .30902 L
.83485 .30902 L
.8349 .30902 L
.83496 .30902 L
.83507 .30902 L
Mistroke
.83527 .30902 L
.83572 .30902 L
.83653 .30902 L
.83693 .30902 L
.83735 .30902 L
.83772 .30902 L
.83812 .30902 L
.83858 .30902 L
.839 .30902 L
.83938 .30902 L
.8396 .30902 L
.8398 .30902 L
.84 .30902 L
.8402 .30902 L
.84043 .30902 L
.84064 .30902 L
.84084 .30902 L
.84102 .30902 L
.84112 .30902 L
.84122 .30902 L
.84133 .30902 L
.84138 .30902 L
.84144 .30902 L
.84153 .30902 L
.84162 .30902 L
.84171 .30902 L
.84181 .30902 L
.84189 .30902 L
.84198 .30902 L
.84206 .30902 L
.84215 .30902 L
.84255 .30902 L
.84293 .30902 L
.84365 .30902 L
.84442 .30902 L
.84482 .30902 L
.84526 .30902 L
.84567 .30902 L
.84605 .30902 L
.84625 .30902 L
.84647 .30902 L
.84687 .30902 L
.84708 .30902 L
.84729 .30902 L
.84751 .30902 L
.84775 .30902 L
.84796 .30902 L
.84808 .30902 L
.84818 .30902 L
.84828 .30902 L
Mistroke
.84838 .30902 L
.84844 .30902 L
.84849 .30902 L
.84859 .30902 L
.84869 .30902 L
.84875 .30902 L
.8488 .30902 L
.8489 .30902 L
.849 .30902 L
.8491 .30902 L
.84919 .30902 L
.84936 .30902 L
.85084 .30902 L
.85124 .30902 L
.85168 .30902 L
.85205 .30902 L
.85246 .30902 L
.85289 .30902 L
.85309 .30902 L
.8533 .30902 L
.85348 .30902 L
.85369 .30902 L
.85406 .30902 L
.85428 .30902 L
.85448 .30902 L
.8547 .30902 L
.85481 .30902 L
.85493 .30902 L
.85504 .30902 L
.85513 .30902 L
.85523 .30902 L
.85532 .30902 L
.85543 .30902 L
.85548 .30902 L
.85554 .30902 L
.85564 .30902 L
.8557 .30902 L
.85575 .30902 L
.85585 .30902 L
.85591 .30902 L
.85596 .30902 L
.85606 .30902 L
.85615 .30902 L
.85636 .30902 L
.85659 .30902 L
.85738 .30902 L
.85815 .30902 L
.85887 .30902 L
.85924 .30902 L
.85963 .30902 L
Mistroke
.86007 .30902 L
.86047 .30902 L
.86069 .30902 L
.86089 .30902 L
.8611 .30902 L
.86134 .30902 L
.86155 .30902 L
.86174 .30902 L
.86194 .30902 L
.86206 .30902 L
.86216 .30902 L
.86227 .30902 L
.86236 .30902 L
.86245 .30902 L
.86255 .30902 L
.86265 .30902 L
.8627 .30902 L
.86276 .30902 L
.86286 .30902 L
.86295 .30902 L
.86305 .30902 L
.86314 .30902 L
.86331 .30902 L
.86369 .30902 L
.86449 .30902 L
.86494 .30902 L
.86535 .30902 L
.86575 .30902 L
.86611 .30902 L
.86651 .30902 L
.86695 .30902 L
.86729 .30902 L
.86767 .30902 L
.86786 .30902 L
.86806 .30902 L
.86823 .30902 L
.86843 .30902 L
.86863 .30902 L
.86874 .30902 L
.86885 .30902 L
.86896 .30902 L
.86906 .30902 L
.86915 .30902 L
.86925 .30902 L
.86931 .30902 L
.86936 .30902 L
.86946 .30902 L
.86952 .30902 L
.86959 .30902 L
.86965 .30902 L
Mistroke
.8697 .30902 L
.8698 .30902 L
.86986 .30902 L
.86991 .30902 L
.87002 .30902 L
.87014 .30902 L
.87057 .30902 L
.87098 .30902 L
.87175 .30902 L
.87253 .30902 L
.87292 .30902 L
.87335 .30902 L
.87372 .30902 L
.87412 .30902 L
.8743 .30902 L
.87449 .30902 L
.87483 .30902 L
.87504 .30902 L
.87524 .30902 L
.87541 .30902 L
.8756 .30902 L
.87581 .30902 L
.87591 .30902 L
.87603 .30902 L
.87613 .30902 L
.87623 .30902 L
.87633 .30902 L
.87642 .30902 L
.87651 .30902 L
.87661 .30902 L
.8767 .30902 L
.87678 .30902 L
.87688 .30902 L
.87699 .30902 L
.87718 .30902 L
.87789 .30902 L
.87873 .30902 L
.8795 .30902 L
.87989 .30902 L
.88031 .30902 L
.88055 .30902 L
.88077 .30902 L
.88099 .30902 L
.88119 .30902 L
.88156 .30902 L
.88176 .30902 L
.88197 .30902 L
.88219 .30902 L
.8824 .30902 L
.88259 .30902 L
Mistroke
.8827 .30902 L
.8828 .30902 L
.88289 .30902 L
.88299 .30902 L
.88308 .30902 L
.88317 .30902 L
.88325 .30902 L
.88334 .30902 L
.88343 .30902 L
.88351 .30902 L
.88361 .30902 L
.88371 .30902 L
.88379 .30902 L
.88388 .30902 L
.88428 .30902 L
.88502 .30902 L
.88583 .30902 L
.88629 .30902 L
.88672 .30902 L
.88712 .30902 L
.88755 .30902 L
.88793 .30902 L
.88814 .30902 L
.88833 .30902 L
.88851 .30902 L
.8887 .30902 L
.88888 .30902 L
.88905 .30902 L
.88925 .30902 L
.88937 .30902 L
.88947 .30902 L
.88957 .30902 L
.88968 .30902 L
.8898 .30902 L
.88986 .30902 L
.88991 .30902 L
.89002 .30902 L
.89011 .30902 L
.89021 .30902 L
.89027 .30902 L
.89032 .30902 L
.89041 .30902 L
.89051 .30902 L
.89061 .30902 L
.8907 .30902 L
.8922 .30902 L
.89261 .30902 L
.89305 .30902 L
.89342 .30902 L
.89383 .30902 L
Mistroke
.89425 .30902 L
.89464 .30902 L
.89487 .30902 L
.89511 .30902 L
.89531 .30902 L
.89554 .30902 L
.89575 .30902 L
.89594 .30902 L
.89605 .30902 L
.89616 .30902 L
.89626 .30902 L
.89637 .30902 L
.89647 .30902 L
.89657 .30902 L
.89668 .30902 L
.89678 .30902 L
.89688 .30902 L
.89697 .30902 L
.89706 .30902 L
.89715 .30902 L
.89725 .30902 L
.89734 .30902 L
.89744 .30902 L
.89754 .30902 L
.89791 .30902 L
.89874 .30902 L
.89955 .30902 L
.90001 .30902 L
.90042 .30902 L
.90081 .30902 L
.90102 .30902 L
.90124 .30902 L
.90143 .30902 L
.90164 .30902 L
.90183 .30902 L
.90201 .30902 L
.90218 .30902 L
.90237 .30902 L
.90258 .30902 L
.90277 .30902 L
.90295 .30902 L
.90304 .30902 L
.90314 .30902 L
.90322 .30902 L
.90332 .30902 L
.9034 .30902 L
.90348 .30902 L
.90358 .30902 L
.90367 .30902 L
.90377 .30902 L
Mistroke
.90382 .30902 L
.90387 .30902 L
.90396 .30902 L
.90405 .30902 L
.90415 .30902 L
.90424 .30902 L
.90465 .30902 L
.90508 .30902 L
.90589 .30902 L
.90632 .30902 L
.90677 .30902 L
.90721 .30902 L
.90761 .30902 L
.90801 .30902 L
.90838 .30902 L
.90859 .30902 L
.90881 .30902 L
.90899 .30902 L
.9092 .30902 L
.90941 .30902 L
.90961 .30902 L
.90974 .30902 L
.90986 .30902 L
.90996 .30902 L
.91008 .30902 L
.91018 .30902 L
.91028 .30902 L
.91033 .30902 L
.91039 .30902 L
.91045 .30902 L
.9105 .30902 L
.91061 .30902 L
.9107 .30902 L
.91075 .30902 L
.91081 .30902 L
.91091 .30902 L
.9111 .30902 L
.9113 .30902 L
.91166 .30902 L
.91247 .30902 L
.91292 .30902 L
.91334 .30902 L
.91374 .30902 L
.91416 .30902 L
.91455 .30902 L
.91491 .30902 L
.9151 .30902 L
.91528 .30902 L
.91562 .30902 L
.91581 .30902 L
Mistroke
.91599 .30902 L
.91618 .30902 L
.91638 .30902 L
.91648 .30902 L
.91658 .30902 L
.91668 .30902 L
.91678 .30902 L
.91687 .30902 L
.91697 .30902 L
.91706 .30902 L
.91714 .30902 L
.91724 .30902 L
.91735 .30902 L
.91743 .30902 L
.91753 .30902 L
.91764 .30902 L
.91775 .30902 L
.91796 .30902 L
.91872 .30902 L
.91943 .30902 L
.91982 .30902 L
.92025 .30902 L
.92068 .30902 L
.92092 .30902 L
.92114 .30902 L
.92154 .30902 L
.92176 .30902 L
.92198 .30902 L
.92216 .30902 L
.92235 .30902 L
.92256 .30902 L
.92276 .30902 L
.92297 .30902 L
.92307 .30902 L
.92319 .30902 L
.92329 .30902 L
.92339 .30902 L
.92349 .30902 L
.92358 .30902 L
.92364 .30902 L
.9237 .30902 L
.9238 .30902 L
.92386 .30902 L
.92392 .30902 L
.92398 .30902 L
.92404 .30902 L
.9241 .30902 L
.92415 .30902 L
.92427 .30902 L
.92438 .30902 L
Mistroke
.92448 .30902 L
.92526 .30902 L
.9261 .30902 L
.92654 .30902 L
.92694 .30902 L
.92733 .30902 L
.92774 .30902 L
.92811 .30902 L
.92845 .30902 L
.92865 .30902 L
.92883 .30902 L
.92902 .30902 L
.92924 .30902 L
.92943 .30902 L
.92962 .30902 L
.92982 .30902 L
.92993 .30902 L
.93003 .30902 L
.93011 .30902 L
.9302 .30902 L
.9303 .30902 L
.93039 .30902 L
.93049 .30902 L
.93058 .30902 L
.93067 .30902 L
.93076 .30902 L
.93087 .30902 L
.93096 .30902 L
.93118 .30902 L
.93163 .30902 L
.93243 .30902 L
.93283 .30902 L
.93326 .30902 L
.93367 .30902 L
.93406 .30902 L
.93443 .30902 L
.93478 .30902 L
.93497 .30902 L
.93517 .30902 L
.93554 .30902 L
.93573 .30902 L
.93594 .30902 L
.93613 .30902 L
.93631 .30902 L
.93651 .30902 L
.93663 .30902 L
.93674 .30902 L
.93683 .30902 L
.93693 .30902 L
.93699 .30902 L
Mistroke
.93704 .30902 L
.93714 .30902 L
.93719 .30902 L
.93725 .30902 L
.93735 .30902 L
.93741 .30902 L
.93747 .30902 L
.93757 .30902 L
.93779 .30902 L
.93803 .30902 L
.93883 .30902 L
.93959 .30902 L
.94003 .30902 L
.94043 .30902 L
.94086 .30902 L
.94124 .30902 L
.94146 .30902 L
.94169 .30902 L
.94192 .30902 L
.94212 .30902 L
.94233 .30902 L
.94255 .30902 L
.94274 .30902 L
.94284 .30902 L
.94295 .30902 L
.94305 .30902 L
.94314 .30902 L
.94323 .30902 L
.94331 .30902 L
.94341 .30902 L
.94351 .30902 L
.9436 .30902 L
.9437 .30902 L
.94381 .30902 L
.9439 .30902 L
.94395 .30902 L
.94401 .30902 L
.94412 .30902 L
.94432 .30902 L
.9445 .30902 L
.94539 .30902 L
.94579 .30902 L
.94623 .30902 L
.94662 .30902 L
.94703 .30902 L
.9474 .30902 L
.9476 .30902 L
.94781 .30902 L
.948 .30902 L
.94818 .30902 L
Mistroke
.94853 .30902 L
.94871 .30902 L
.94891 .30902 L
.94912 .30902 L
.94932 .30902 L
.9495 .30902 L
.94967 .30902 L
.94976 .30902 L
.94986 .30902 L
.94996 .30902 L
.95006 .30902 L
.95016 .30902 L
.95022 .30902 L
.95027 .30902 L
.95037 .30902 L
.95048 .30902 L
.95057 .30902 L
.95066 .30902 L
.95086 .30902 L
.95128 .30902 L
.95172 .30902 L
.95253 .30902 L
.95299 .30902 L
.95342 .30902 L
.95383 .30902 L
.9542 .30902 L
.95441 .30902 L
.95463 .30902 L
.95482 .30902 L
.95503 .30902 L
.95524 .30902 L
.95543 .30902 L
.95562 .30902 L
.9558 .30902 L
.9559 .30902 L
.95601 .30902 L
.9562 .30902 L
.95631 .30902 L
.95641 .30902 L
.95652 .30902 L
.95658 .30902 L
.95663 .30902 L
.95673 .30902 L
.95684 .30902 L
.95694 .30902 L
.95703 .30902 L
.95708 .30902 L
.95713 .30902 L
.95725 .30902 L
.95746 .30902 L
Mistroke
.95833 .30902 L
.95905 .30902 L
.95946 .30902 L
.95983 .30902 L
.96027 .30902 L
.96049 .30902 L
.96069 .30902 L
.96107 .30902 L
.96128 .30902 L
.96149 .30902 L
.9617 .30902 L
.96192 .30902 L
.96211 .30902 L
.96232 .30902 L
.96244 .30902 L
.96254 .30902 L
.96266 .30902 L
.96278 .30902 L
.9629 .30902 L
.96295 .30902 L
.963 .30902 L
.96311 .30902 L
.96316 .30902 L
.96321 .30902 L
.96331 .30902 L
.96337 .30902 L
.96342 .30902 L
.96352 .30902 L
.96362 .30902 L
.96372 .30902 L
.96382 .30902 L
.964 .30902 L
.96484 .30902 L
.96562 .30902 L
.96601 .30902 L
.96645 .30902 L
.96682 .30902 L
.96702 .30902 L
.96721 .30902 L
.96739 .30902 L
.96759 .30902 L
.96793 .30902 L
.96812 .30902 L
.96832 .30902 L
.96851 .30902 L
.96868 .30902 L
.96888 .30902 L
.96899 .30902 L
.96909 .30902 L
.9692 .30902 L
Mistroke
.9693 .30902 L
.96941 .30902 L
.96952 .30902 L
.96961 .30902 L
.96967 .30902 L
.96972 .30902 L
.96982 .30902 L
.96988 .30902 L
.96994 .30902 L
.97003 .30902 L
.97014 .30902 L
.97032 .30902 L
.97078 .30902 L
.9712 .30902 L
.97161 .30902 L
.97205 .30902 L
.97244 .30902 L
.97285 .30902 L
.97322 .30902 L
.97342 .30902 L
.97363 .30902 L
.97382 .30902 L
.974 .30902 L
.97435 .30902 L
.97457 .30902 L
.97481 .30902 L
.97501 .30902 L
.97523 .30902 L
.97535 .30902 L
.97547 .30902 L
.97559 .30902 L
.97573 .30902 L
.97584 .30902 L
.97595 .30902 L
.97601 .30902 L
.97607 .30902 L
.97613 .30902 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{421.375, 260.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008>0001AB000`400?l00000o`00003ooooooooo
oooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo
003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooo
oooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool0
0?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooooooo
ool@ooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooo
ooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo0ol0003o
ooooomcooooo000`ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0oooooonkoooo
o`00<?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo0?oooooo^oooool0033ooooo
00?o0000ooooooooool07_ooool2o`000?oooooo_?ooool0033ooooo00?o0000ooooooooool07_oo
ool2o`000?oooooo_?ooool0033ooooo00?o0000ooooooooool07_ooool2o`000?oooooo_?ooool0
033ooooo00?o0000ooooooooool07_ooool2o`000?oooooo_?ooool0033ooooo00?o0000oooooooo
ool07_ooool2o`000?oooooo_?ooool0033ooooo00?o0000ooooooooool07_ooool2o`000?oooooo
_?ooool0033ooooo00?o0000ooooooooool07_ooool2o`000?oooooo_?ooool0033ooooo00?o0000
ooooooooool07Oooool00ol0003oooooo`00003ooooookcooooo000`ooooo`03o`000?oooooooooo
01gooooo00?o0000ooooool00000oooooonlooooo`00<?ooool3o`0001gooooo00?o0000ooooool0
0000oooooonlooooo`00<?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo00000?oooooo
_?ooool0033ooooo00?o0000ooooooooool07Oooool00ol0003oooooo`00003ooooookcooooo000`
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooool00000oooooonlooooo`00<?ooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooo00000?oooooo_?ooool0033ooooo00?o0000oooooooo
ool07Oooool00ol0003oooooo`00003ooooookcooooo000`ooooo`03o`000?oooooooooo01gooooo
00?o0000ooooool00000oooooonlooooo`00<?ooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooo00000?oooooo_?ooool0033ooooo00?o0000ooooooooool07Oooool00ol0003oooooo`00003o
oooookcooooo000`ooooo`03o`000?oooooooooo01gooooo00?o0000ooooool00000oooooonloooo
o`00<?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo00000?oooooo_?ooool0033ooooo
0ol0000Booooo`;o00002Oooool00ol0003oooooo`00003ooooookcooooo000`ooooo`03o`000?oo
oooooooo01;ooooo0_l00009ooooo`03o`000?oooooo00000?oooooo_?ooool0033ooooo00?o0000
ooooooooool04_ooool2o`0000Wooooo00?o0000ooooool00000oooooonlooooo`00<?ooool00ol0
003oooooooooo`0Booooo`;o00002Oooool00ol0003oooooo`00003ooooookcooooo000`ooooo`03
o`000?oooooooooo01;ooooo0_l00009ooooo`03o`000?oooooo00000?oooooo_?ooool0033ooooo
00?o0000ooooooooool04_ooool2o`0000Wooooo00Co0000oooooooooooo0000oooooonkooooo`00
<?ooool00ol0003oooooooooo`0Booooo`;o00002Oooool01?l0003oooooooooool0003ooooook_o
oooo000@ooooo`;ok^k^0oooool2onk^kQWooooo00?o0000ooooooooool04_ooool2o`0000Wooooo
00Co0000oooooooooooo0000oooooonkooooo`002oooool2o`00000:oa0@4?ooooooooooonk^k_mE
EEGok^k^ooooooo^k^koEEEEonk^kP?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb
<S;ok^k^2_ooool00ol0003oooooooooo`0Booooo`;o00002Oooool01?l0003oooooooooool0003o
oooook_ooooo000<ooooo`03o`000?oooooooooo00;ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06
ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0:ooooo`03o`000?oo
oooooooo01;ooooo0_l00009ooooo`04o`000?ooooooooooo`000?oooooo^oooool00003ooooool0
003o000000Co00000_ooool5o`0000Cooooo00?ogMgMo`000?oMgMd01oooool00ol0003ooooooooo
o`02ooooo`05oa0@4?ooooooooooooooool@41002_ooool00ol0003oooooooooo`0Booooo`;o0000
2Oooool01?l0003oooooooooool0003ooooook_ooooo0009ooooo`04odA4A?oMgMgoooooo`0000Co
oooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`00000:ooooo`03o`000?oooooooooo01;ooooo0_l00009ooooo`04o`000?oooooo
ooooo`000?oooooo^oooool000Wooooo00CogMgMoeEEEOoooooo00000oooool01oo^k^koEEEEonk^
k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000002_ooool4o`00017ooooo0_l00009ooooo`04o`000?ooooooooooo`000?oooooo^oooool0
00[ooooo00?oMgMgolc<c?l000000oooool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo
00;ooooo00Go410@oooooooooooooooooa0@400:ooooo`03o`000?oooooooooo01;ooooo0_l00009
ooooo`04o`000?ooooooooooo`000?oooooo^oooool000[ooooo00?ok^k^odA4A?l000003oooool0
0ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool2o`0000Gooooo00?o
0000ooooooooool04_ooool2o`0000Wooooo00Co0000oooooooooooo0000oooooonkooooo`002ooo
ool00omgMgOo0000ooooo`0<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP02ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool04_ooool2o`0000Wo
oooo00Co0000oooooooooooo0000oooooonkooooo`00:?ooool01?l0003oooooooooool00004oooo
o`03o`000?oooooooooo017ooooo00?o0000ooooool000002Oooool01?l0003oooooooooool0003o
oooook_ooooo000Xooooo`?o00001Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo0000
00Wooooo00Co0000oooooooooooo0000oooooonkooooo`00:Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo017ooooo00?o0000ooooool000002Oooool01?l0003oooooooooool0003o
oooook_ooooo000Zooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04Oooool01?l0
003oooooooooool00008ooooo`04o`000?ooooooooooo`000?oooooo^oooool0033ooooo00?o0000
ooooooooool04Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`000?oooooo
^oooool0033ooooo00?o0000ooooooooool04Oooool01?l0003oooooooooool00008ooooo`04o`00
0?ooooooooooo`000?oooooo^oooool0033ooooo00?o0000ooooooooool04Oooool01?l0003ooooo
ooooool00008ooooo`04o`000?ooooooooooo`000?oooooo^oooool0033ooooo00?o0000oooooooo
ool04Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`000?oooooo^oooool0
033ooooo0ol0000Aooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000oooo
oonkooooo`00<?ooool00ol0003oooooooooo`0Aooooo`04o`000?ooooooooooo`0000Oooooo00Go
0000ooooooooooooooooo`00003ooooook_ooooo000`ooooo`03o`000?oooooooooo017ooooo00Co
0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo00000?oooooo^oooool0033ooooo
00?o0000ooooooooool04Oooool01?l0003oooooooooool00007ooooo`05o`000?oooooooooooooo
ool00000oooooonkooooo`00<?ooool00ol0003oooooooooo`0Aooooo`04o`000?ooooooooooo`00
00Oooooo00Go0000ooooooooooooooooo`00003ooooook_ooooo000`ooooo`03o`000?oooooooooo
017ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Sooooo0_l0
003ooooook7ooooo000`ooooo`03o`000?oooooooooo017ooooo00Co0000oooooooooooo00001ooo
ool01Ol0003ooooooooooooooooo000000Sooooo0_l0003ooooook7ooooo000`ooooo`03o`000?oo
oooooooo017ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000So
oooo0_l0003ooooook7ooooo000`ooooo`03o`000?oooooooooo017ooooo00Co0000oooooooooooo
00001oooool01Ol0003ooooooooooooooooo000000Sooooo0_l0003ooooook7ooooo000`ooooo`03
o`000?oooooooooo017ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo
000000Sooooo0_l0003ooooook7ooooo000`ooooo`03o`000?oooooooooo017ooooo00Co0000oooo
oooooooo00001oooool01Ol0003ooooooooooooooooo000000Sooooo0_l0003ooooook7ooooo000`
ooooo`03o`000?oooooooooo017ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooo
oooooooo000000Sooooo0_l0003ooooook7ooooo000`ooooo`?o00004Oooool01?l0003ooooooooo
ool00007ooooo`05o`000?ooooooooooooooool000002?ooool2o`000?oooooo/Oooool0033ooooo
00?o0000ooooooooool04Oooool01?l0003oooooooooool00007ooooo`05o`000?oooooooooooooo
ool000002?ooool2o`000?oooooo/Oooool0033ooooo00?o0000ooooooooool04Oooool01?l0003o
ooooooooool00007ooooo`05o`000?ooooooooooooooool000002?ooool2o`000?oooooo/Oooool0
033ooooo00?o0000ooooooooool04Oooool01?l0003oooooooooool00007ooooo`05o`000?oooooo
ooooooooool000002?ooool2o`000?oooooo/Oooool0033ooooo00?o0000ooooooooool04Oooool0
1?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000002?ooool2o`000?oooooo
/Oooool0033ooooo00?o0000ooooooooool04Oooool01?l0003oooooooooool00007ooooo`05o`00
0?ooooooooooooooool000002?ooool2o`000?oooooo/Oooool0033ooooo00?o0000ooooooooool0
4Oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001oooool00ol0
003oooooo`00003ooooook7ooooo000`ooooo`03o`000?oooooooooo017ooooo00Co0000oooooooo
oooo00001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000oooo
oon`ooooo`00<?ooool00ol0003oooooooooo`0Aooooo`04o`000?ooooooooooo`0000Oooooo00Go
0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`000?oooooo/?ooool0033ooooo
00?o0000ooooooooool04?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooooooo
ooooooooo`000007ooooo`04o`000?ooooooooooo`000?oooooo/?ooool0033ooooo00?o0000oooo
ooooool04?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`00
0007ooooo`04o`000?ooooooooooo`000?oooooo/?ooool0033ooooo0ol0000@ooooo`05o`000?oo
ooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooo
oooo0000oooooon`ooooo`00<?ooool00ol0003oooooooooo`0@ooooo`05o`000?oooooooooooooo
ool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000oooo
oon`ooooo`00<?ooool00ol0003oooooooooo`0@ooooo`05o`000?ooooooooooooooool000001ooo
ool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000oooooon`ooooo`00
<?ooool00ol0003oooooooooo`0@ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003o
oooooooooooooooo000000Oooooo00Co0000oooooooooooo0000oooooon`ooooo`00<?ooool00ol0
003oooooooooo`0@ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooo
oooo000000Oooooo00Co0000oooooooooooo0000oooooon`ooooo`00<?ooool00ol0003ooooooooo
o`0@ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00Co0000oooooooooooo0000oooooon`ooooo`00<?ooool00ol0003ooooo
ooooo`0@ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Cooooo00Co0000oooooooooooo0000oooooon`ooooo`004?ooool2onk^kP?o
oooo0_o^k^hIooooo`03o`000?oooooooooo013ooooo00Go0000ooooooooooooooooo`000007oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0003o
oooook3ooooo0009ooooo`Go00000_ooool01oo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00ooo
ool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h:ooooo`03o`000?oooooooooo
013ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool01?l0003oooooooooool0003ooooook3ooooo0009ooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@00oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00[ooooo00?o0000ooooooooool04?ooool01Ol0003o
oooooooooooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04oooo
o`04o`000?ooooooooooo`000?oooooo/?ooool00003ooooool0003o000000Co00000oooool00onH
V9So8B4Qonk^kP05ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@
413ooooooooooooooooo410@00[ooooo00?o0000ooooooooool04?ooool01Ol0003ooooooooooooo
oooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`04o`000?oo
ooooooooo`000?oooooo/?ooool000_ooooo00?oV9RHob4Q8Oo^k^h00oooool01Oo^k^koEEEEomgM
gOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000[o
oooo00?o0000ooooooooool04?ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`000?oooooo/?ooool0
00cooooo00_oMgMgofIVI_ooooooooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03
o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000:ooooo`Co00003oooool01Ol0
003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`04o`000?ooooooooooo`000?oooooo/?ooool000gooooo00?o0000ooooooooool00_o^k^h3
ooooo`;ok^k^1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41002_oo
ool00ol0003oooooooooo`0@ooooo`05o`000?ooooooooooooooool000001oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo0000oooooon`ooooo`00
2Oooool01Ol0003o^[ZjoooooonHV9So410@00kooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00?ooooo0_l00005ooooo`03o`000?oooooooooo013ooooo00Go0000oooo
ooooooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
1?l0003oooooooooool0003ooooook3ooooo0009ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?oo
ool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_ooool01?l0003ooooo
ooooool00004ooooo`03o`000?oooooooooo013ooooo00Go0000ooooooooooooooooo`000007oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0003o
oooook3ooooo000Xooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool04?ooool0
1Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`04ooooo`04o`000?ooooooooooo`000?oooooo/?ooool002Sooooo0ol00005ooooo`03o`000?oo
oooooooo013ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool01?l0003oooooooooool0003ooooook3ooooo000Yooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool04?ooool01Ol0003ooooooooooooooooo000000Oo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`00
0?oooooo/?ooool002[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`;o
00002?ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`04ooooo`04o`000?ooooooooooo`000?oooooo/?ooool0033ooooo00?o0000oooo
ooooool01_ooool2o`0000Sooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0003ooooook3ooooo000`
ooooo`03o`000?oooooooooo00Kooooo0_l00008ooooo`05o`000?ooooooooooooooool000001ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooooooo
o`00003oooooojoooooo000`ooooo`03o`000?oooooooooo00Kooooo0_l00008ooooo`05o`000?oo
ooooooooooooool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo
00Go0000ooooooooooooooooo`00003oooooojoooooo000`ooooo`03o`000?oooooooooo00Kooooo
0_l00008ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00003oooooojoooooo000`ooooo`?o
00001Oooool00ol0003oooooo`000008ooooo`05o`000?ooooooooooooooool000001oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00003o
ooooojoooooo000`ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000002?ooool01Ol0
003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`05o`000?ooooooooooooooool00000oooooon_ooooo`00<?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooo000000Sooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo00000?oooooo
[oooool0033ooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00007ooooo`05o`00
0?ooooooooooooooool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00Go0000ooooooooooooooooo`00003oooooojoooooo000`ooooo`03o`000?oooooooooo00Go
oooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0oooooon]ooooo`00<?ooool00ol0003oooooooooo`05ooooo`04o`000?oooooooooo
o`0000Oooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo[Ooo
ool0033ooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00007ooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`3oooooojgooooo000`ooooo`03o`000?oo
oooooooo00Gooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0oooooon]ooooo`00<?ooool00ol0003ooooooooo
o`05ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo0?oooooo[Oooool0033ooooo00?o0000ooooooooool01Ooo
ool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`3oooooojgooooo000`ooooo`03o`000?oooooooooo00Gooooo00Co
0000oooooooooooo00001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01Oooool2o`000?ooooooY_ooool0033ooooo00?o0000ooooooooool01Ooo
ool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`05ooooo`;o0000oooooonVooooo`00<?ooool3o`0000Gooooo00Co
0000oooooooooooo00001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01Oooool2o`000?ooooooY_ooool0033ooooo00?o0000ooooooooool01Ooo
ool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`05ooooo`;o0000oooooonVooooo`00<?ooool00ol0003ooooooooo
o`05ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooool00000oooooonVooooo`00<?oo
ool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
o`00003oooooojKooooo000`ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooooooo
o`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooo00000?ooooooY_ooool0033ooooo00?o0000ooooooooool01?oo
ool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00005oooool2onk^kP?o
oooo0_o^k^iGooooo`;ok^k^0oooool2onk^kV3ooooo0_o^k^h3ooooo`;ok^k^C_ooool2onk^kP?o
oooo0_o^k^i/ooooo`00<?ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool0
00001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool01?l0003oooooooooool0000Aooooo`0=odA4A?l0003o0000oc8b<_oMgMgoooooonk^
k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0
003o<S8bonk^kT;ooooo1?l000002Ol@413oooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03
ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kS_ooooo1?l000000ol@413o
ooooooooo`02ooooo`;o8B4Q1Oooool03Om4A4Co0000o`000?lb<S;ogMgMooooooo^k^koEEEEonk^
k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^hhooooo`Go00000_ooool01oo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008
oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^iMooooo`00<?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0
000Dooooo`09ogMgMolb<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000oooo
ooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg04Cooooo00?o0000ooooooooool00_ooool0
1Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg03gooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00WoMgMgoc8b<_oooooo
ooooonk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL0>?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00Gok^k^oeEEEOoMgMgo
EEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Moooo
o`00<?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool01?l0003oooooooooool0000Eooooo`07o`000?oooooooooooooooooMgMgo0000omgM
g@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4014ooooo`03o`00
0?oooooooooo00?ooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@
4?ooooooooooooooool@4100?Oooool00ol0003oooooooooo`0?ooooo`07o`000?oooooooooooooo
oooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
400iooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?ogMgMo`000?oMgMd01oooool00ol0003ooooooooo
o`02ooooo`05oa0@4?ooooooooooooooool@4100GOooool0033ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo0000
5?ooool02OmgMgOo<S8booooooooooook^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000014ooooo`03o`000?oooooooooo00;ooooo00Go
k^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`00000mooooo`03o`000?oooooooooo00kooooo00WoMgMgoc8b<_ooooooooooonk^k_mEEEGo
gMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
>_ooool00onHV9So8B4Qonk^kP03ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool00000GOooool0033ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooo
oooo00004Oooool03Ol0003o8B4Qo`000?lb<S;oc<c<ooooooo^k^koEEEEonk^k_ooooook^k^oeEE
EOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000A?ooool0
2ol0003oooooooooooooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000003gooooo00?o0000ooooooooool02oooool0
3Ol0003o8B4Qo`000?lb<S;oc<c<ooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000>oooool02omgMgOoIVIVoooo
ooooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000005gooooo000`ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`00017ooooo00?o
0000ooooooooool00oooool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go
410@oooooooooooooooooa0@4014ooooo`04o`000?ooooooooooooooo`;ok^k^0oooool2onk^kPGo
oooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@03gooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`03ooooo`;ok^k^0oooool2onk^kPGooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@03cooooo00?o0000ooooooooool00_o^k^h3
ooooo`;ok^k^1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100GOoo
ool0033ooooo0ol00004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
1?l0003oooooooooool0000Aooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0>Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`;o
0000<oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo0_l0000^ooooo`05o`000?nj^[[ooooo
oiRHV?l@41003_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?oo
ool2o`0005?ooooo000`ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`00017ooooo1?l0000<ooooo`03oeEEEOmV
IVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo03Oooooo
00?oEEEEofIVI_l000003Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01oooool01?l0003oooooooooool0000`ooooo`03oeEEEOmVIVKo000000gooooo1?l0000<oooo
o`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP07ooooo`04o`000?oooooo
ooooo`0002gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00<ooooo`03oeEEEOmVIVKo000000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP07ooooo`04o`000?ooooooooooo`0005;ooooo000`ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05
o`000?ooooooooooooooool00000;_ooool4o`0000?ooooo00?o0000ooooooooool0E?ooool4o`00
0005ooooool0003oooooooooool00000G_ooool4o`000005ooooool0003oooooooooool00000C?oo
ool4o`000005ooooool0003oooooooooool00000D_ooool0033ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooooooo
o`00000eooooo`03o`000?oooooooooo05Wooooo0ol0001Tooooo`?o0000D_ooool3o`0005?ooooo
000`ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`04ooooo`05o`000?ooooooooooooooool00000<oooool01?l0003oooooooooool0001Kooooo`03
o`000?oooooooooo06Cooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`1Booooo`00
;?ooool2o`0000;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0aooooo`Co0000
G?ooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0
DOooool002_ooooo1?l000000ooooooo0000ooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?ooooooX_oo
ool002_ooooo00Ko0000oooooooooooo0000ooooool00005ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo
0ol0003oooooof7ooooo00?oMgMgofIVI_ooool0;Oooool00omVIVKoMgMgooooo`07ooooo`00:_oo
ool01ol0003ooooooooooooooooo0000ooooool000001Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooo00000?ooooooH?ooool00ooMgMgo410@onk^kP0^ooooo`03onk^k_l@413ogMgM00Oo
oooo000Zooooo`07o`000?ooooooooooooooool0003oooooo`000005ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00Co0000oooooooooooo0000oooooom=ooooo`;o00000_ooool2o`0000cooooo00?oEEEE
oiRHV?ooool00_l00002ooooo`07o`000?ooooooooooo`000?l@413ok^k^oeEEE@02o`000003odA4
A?nj^[[ooooo00;ooooo00GoV9RHo`000?l0003oA4A4okZj^P02ooooo`08onk^k_mEEEGo0000o`00
0?m4A4Co^[Zjooooool@4105o`0000?ooooo00So410@oc8b<_l0003o0000oa0@4?nYZJWoQhN7ofIV
IPOooooo000Yooooo`03o`000?oooooooooo00?ooooo0_l00005ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00Go0000ooooooooooooooooo`00003oooooodgooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oM
gMd<ooooo`05o`000?ooooooooooooooool000000_ooool02ol0003oooooooooool0003ooooooeEE
EOmgMgOoooooonk^k_mgMgOo410@00?ooooo00Go410@okZj^_o^k^koMgMgoa0@4002ooooo`06oeEE
EOmgMgOoooooonk^k_mgMgOo410@0oooool00ol0003oooooooooo`04ooooo`08o`000?nYZJWooooo
oooooonj^[[o0000onk^k_l00007ooooo`00ool0002do`0000oooooo00CogMgMo`000?l@413oc<c<
3Oooool01Olb<S;ooooooooooooooooo000000;ooooo00Ko0000oooooooooooo0000ooooool00008
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05
ooooo`07okZj^_n7QhOoIVIVofIVI_l@413oooooo`000007ooooo`002_ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`03o`000?oooooooooo00Cooooo0_l0
0004ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool2o`0000Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o0000
4_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0Gooooo`04onk^k_lQ8B7o410@onk^kPgooooo00Go<S8boooooooo
ooooooooo`000002ooooo`05o`000?ooooooooooo`000?ooool01_l00003ooooo`03o`000?oooooo
oooo00Cooooo1_l00003ooooo`03o`000?oooooooooo00Cooooo00So<S8bob4Q8OmgMgOoMgMgohN7
Qoo^k^koooooo`0000Oooooo000:ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
1Oooool3o`0000Oooooo0_l00004ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0oooool2o`0000Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooo000000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`?o
00000_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Oooooo00Co8B4QogMgMomg
MgOo<S8b3Oooool01Ol0003ok^k^oooooooooooo000000;oc<c<00_o0000ojVYZOoMgMgo8B4Qoooo
oomEEEGoQhN7onk^k_ooooooQhN7oc8b<P03ooooo`03o`000?oooooooooo00Cooooo00KoEEEEohN7
Qoo^k^koooooohN7Qolb<S83ooooo`03o`000?lb<S;ogMgM00Cooooo00So0000okZj^_ooooook^k^
ogMgMol0003ok^k^o`0000Oooooo000`ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo05_ooooo00?o0000oooooooo
ool0Foooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo01Kooooo0_l00002ooooo`;o
00003?ooool03_mEEEGoMgMgooooool@413o0000ob4Q8Ol0003oMgMgoa0@4?l0003oZJVYooooooo^
k^koEEEE0_l000001?m4A4Cok^k^ooooool@4105o`0000?ooooo00Kok^k^oeEEEOl0003o0000odA4
A?o^k^h2ooooo`;o000000CoZJVYob4Q8Ol0003o8B4Q0_ooool02?nYZJWo8B4Qo`000?l0003o<S8b
o`000?mgMgOoEEEE1oooool0033ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooo
oooo00000?ooooooI?ooool00ooMgMgo410@onk^kP0Booooo`03o`000?oooooooooo01Wooooo00?o
k^k^oa0@4?oMgMd01oooool0033ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooo
oooo00000?ooooooIOooool00omgMgOoIVIVooooo`0Aooooo`03o`000?oooooooooo01Wooooo00?o
IVIVogMgMoooool01oooool0033ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooo
oooo00000?ooooooWoooool0033ooooo0_l00003ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`000?ooooooX?ooool0033ooooo0_l0
0003ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooo00000?ooooooX?ooool0033ooooo0_l00003ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo00000?ooooooX?ooool0033ooooo0_l0
0003ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooo00000?ooooooX?ooool0033ooooo0_l00003ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`;o0000oooooonQooooo`00<?ooool3o`0000;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
oooooonOooooo`00<?ooool2o`0000;ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`04ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo0?ooooooYoooool0033ooooo00Go0000ooooool0003oooooo`000007ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0oooooonWooooo`00<?ooool01Ol0003oooooo`000?oooooo000000Oo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`3oooooojOooooo000`ooooo`05o`000?oooooo0000oooo
ool000001oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?ooooooYoooool0033ooooo00Go0000oooo
ool0003oooooo`000007ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00
0006ooooo`05o`000?ooooooooooooooool00000oooooonZooooo`00<?ooool00ol0003ooooooooo
o`02o`0000Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo
00Go0000ooooooooooooooooo`00003ooooooj[ooooo000`ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000oooooooo
ooooooooo`00003ooooooj[ooooo000`ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`00003o
oooooj[ooooo000`ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0
003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`00003ooooooj[ooooo000`
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooo
oooo000000Kooooo00Go0000ooooooooooooooooo`00003ooooooj[ooooo000`ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo
00Go0000ooooooooooooooooo`00003ooooooj[ooooo000`ooooo`?o00002_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo0000
0?ooooooZ_ooool0033ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05
o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo00000?ooooooZ_ooool0
033ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooo
ooooool000001_ooool01Ol0003ooooooooooooooooo00000?ooooooZ_ooool0033ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_oo
ool01Ol0003ooooooooooooooooo00000?ooooooZ_ooool0033ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooo
oooooooooooo00000?ooooooZ_ooool0033ooooo00?o0000ooooooooool02_ooool01Ol0003ooooo
oooooooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05
o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo00000?ooooooZ_ooool0
033ooooo00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_oo
ool01Ol0003ooooooooooooooooo00000?ooooooZ_ooool0033ooooo00?o0000ooooooooool02_oo
ool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo0000
0?ooooooZ_ooool0033ooooo00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo0000
00Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooo
ooooool000001oooool00ol0003oooooo`00003ooooooj_ooooo000`ooooo`03o`000?oooooooooo
00[ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooool00000oooo
oon[ooooo`00<?ooool00ol0003oooooooooo`0:ooooo`05o`000?ooooooooooooooool000001ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooooooo
o`000007ooooo`03o`000?oooooo00000?ooooooZoooool0033ooooo00?o0000ooooooooool02_oo
ool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`04ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003ooooooj_o
oooo000`ooooo`?o00002_ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001oooool00ol0
003oooooo`00003ooooooj_ooooo000`ooooo`03o`000?oooooooooo00[ooooo00Go0000oooooooo
ooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0
003ooooooooooooooooo000000Oooooo00?o0000ooooool00000oooooon[ooooo`00<?ooool00ol0
003oooooooooo`0:ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oo
oooo00000?ooooooZoooool0033ooooo00?o0000ooooooooool02oooool01?l0003oooooooooool0
0007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000Oooooo00?o0000ooooool00000oooooon[ooooo`00<?ooool00ol0003ooooooooo
o`0;ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`04ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003ooooooj_o
oooo000`ooooo`03o`000?oooooooooo00_ooooo00Co0000oooooooooooo00001oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000007oooo
o`03o`000?oooooo00000?ooooooZoooool000oooooo0_o^k^h3ooooo`;ok^k^6_ooool00ol0003o
ooooooooo`0;ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003o
oooooj_ooooo0008ooooo`Go00000_ooool01oo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00ooo
ool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`03o`000?oooooooooo
00_ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?ooooooZooo
ool000Sooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h0
1_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ol0003o
ooooooooo`0;ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003o
oooooj_ooooo0009ooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?ogMgMo`000?oMgMd01oooool00ol0
003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41002oooool00ol0003oooooooooo`0;
ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`04ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003ooooooj_ooooo
000:ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000;ooooo`03o`000?oooooooooo00_o
oooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?ooooooZ_ooool0
00_ooooo00_oMgMgofIVI_ooooooooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03
o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000;ooooo`Co00002_ooool01?l0
003oooooooooool00007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
1Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0oooooonZooooo`003?ooool0
0ol0003oooooooooo`02onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@400;ooooo`03o`000?oooooooooo00_ooooo00Co0000oooooooooooo0000
1oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooo
ooooo`000008ooooo`03o`000?oooooooooo0?ooooooZ_ooool000Sooooo00Go0000okZj^_oooooo
V9RHoa0@400>ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;oooo
o`03o`000?oooooooooo00_ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00003ooooookGooooo0008
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00oooool2o`0000Kooooo00?o0000ooooooooool02oooool01?l0003ooooo
ooooool00007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003o
oooooooooooooooo00000?oooooo]Oooool002Oooooo00Co0000oooooooooooo00001Oooool00ol0
003oooooooooo`0;ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000ooooooneooooo`009oooool0
1?l0003oooooooooool00005ooooo`03o`000?oooooooooo00_ooooo00Co0000oooooooooooo0000
1oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooo
ooooo`00003ooooookGooooo000Wooooo`?o00001_ooool00ol0003oooooooooo`0;ooooo`04o`00
0?ooooooooooo`0000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05
o`000?ooooooooooooooool00000ooooooneooooo`00:?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00_ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00003ooooookGooooo000Yoooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02oooool01?l0003oooooooooool00007
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooo
oooo00000?oooooo]Oooool0033ooooo00?o0000ooooooooool02oooool01?l0003oooooooooool0
0007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo00000?oooooo]Oooool0033ooooo00?o0000ooooooooool02oooool01?l0003ooooooooo
ool00007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooo
oooooooooooo00000?oooooo]Oooool0033ooooo00?o0000ooooooooool02oooool01?l0003ooooo
ooooool00008ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo
00000?oooooo]Oooool0033ooooo0ol0000;ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000
ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool00000ooooooneooooo`00<?oo
ool00ol0003oooooooooo`0;ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooooooo
ooooo`000006ooooo`05o`000?ooooooooooooooool00000ooooooneooooo`00<?ooool00ol0003o
ooooooooo`0;ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000006
ooooo`05o`000?ooooooooooooooool00000ooooooneooooo`00<?ooool00ol0003oooooooooo`0;
ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001oooool01Ol0003ooooo
oooooooooooo00000?oooooo]Oooool0033ooooo00?o0000ooooooooool02oooool00ol0003ooooo
o`000009ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00003ooooo
okGooooo000`ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooool000002Oooool01?l0003o
ooooooooool00007ooooo`05o`000?ooooooooooooooool00000ooooooneooooo`00<?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooo000000Wooooo00Co0000oooooooooooo00001oooool0
1Ol0003ooooooooooooooooo00000?oooooo]Oooool0033ooooo00?o0000ooooooooool03?ooool2
o`0000Wooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo00000?oooooo
]Oooool0033ooooo00?o0000ooooooooool03?ooool2o`0000Wooooo00Co0000oooooooooooo0000
1oooool01Ol0003ooooooooooooooooo00000?oooooo]Oooool0033ooooo00?o0000ooooooooool0
3?ooool2o`0000Wooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000
0?oooooo]Oooool0033ooooo00?o0000ooooooooool03?ooool2o`0000Wooooo00Co0000oooooooo
oooo00001oooool01Ol0003ooooooooooooooooo00000?oooooo]Oooool0033ooooo00?o0000oooo
ooooool03?ooool2o`0000Wooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooo
oooo00000?oooooo]Oooool0033ooooo0ol0000<ooooo`;o00002Oooool01?l0003oooooooooool0
0007ooooo`05o`000?ooooooooooooooool00000ooooooneooooo`00<?ooool00ol0003ooooooooo
o`0<ooooo`;o00002Oooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`000?oo
oooo]_ooool0033ooooo00?o0000ooooooooool03?ooool2o`0000Wooooo00Co0000oooooooooooo
00001oooool01?l0003oooooooooool0003ooooookKooooo000`ooooo`03o`000?oooooooooo01Oo
oooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool0003ooooookKooooo000`oooo
o`03o`000?oooooooooo01Oooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool0
003ooooookKooooo000`ooooo`03o`000?oooooooooo01Oooooo00Co0000oooooooooooo00001ooo
ool01?l0003oooooooooool0003ooooookKooooo000`ooooo`03o`000?oooooooooo01Oooooo00Co
0000oooooooooooo00001oooool01?l0003oooooooooool0003ooooookKooooo000`ooooo`03o`00
0?oooooooooo01Oooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003ooooookKo
oooo000`ooooo`03o`000?oooooooooo01Oooooo00Co0000oooooooooooo00002?ooool00ol0003o
ooooo`00003ooooookKooooo000`ooooo`03o`000?oooooooooo01Oooooo00Co0000oooooooooooo
00002?ooool00ol0003oooooo`00003ooooookKooooo000`ooooo`03o`000?oooooooooo01Oooooo
00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003ooooookKooooo000`ooooo`03o`00
0?oooooooooo01Oooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003ooooookKo
oooo000`ooooo`?o00005oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?oo
oooo]_ooool0033ooooo00?o0000ooooooooool05oooool01?l0003oooooooooool00008ooooo`03
o`000?oooooo00000?oooooo]_ooool0033ooooo00?o0000ooooooooool05oooool01?l0003ooooo
ooooool00008ooooo`03o`000?oooooo00000?oooooo]_ooool0033ooooo00?o0000ooooooooool0
5oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?oooooo]_ooool0033ooooo
00?o0000ooooooooool05oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?oo
oooo]_ooool0033ooooo00?o0000ooooooooool05oooool01?l0003oooooooooool00008ooooo`03
o`000?oooooo00000?oooooo]_ooool000oooooo0_o^k^h3ooooo`;ok^k^6_ooool00ol0003ooooo
ooooo`0Gooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooonfooooo`00
2_ooool2o`00000:oa0@4?ooooooooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP?ooooo1?l0
00002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool00ol0003oooooooooo`0Goooo
o`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooonfooooo`002oooool00ol0
003oooooooooo`02ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ol0003oooooooooo`0Gooooo`04o`000?oo
ooooooooo`0000Sooooo00?o0000ooooool00000oooooonfooooo`002?ooool5o`0000Cooooo00?o
gMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100
2oooool00ol0003oooooooooo`0Gooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool0
0000oooooonfooooo`002?ooool01?m4A4CogMgMooooool00004ooooo`05onk^k_mEEEGogMgMoeEE
EOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000002oooool0
0ol0003oooooooooo`0Gooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooo
oonfooooo`002?ooool01?oMgMgoEEEEooooool00003ooooo`07onk^k_mEEEGok^k^ooooooo^k^ko
EEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000;oooo
o`Co00005_ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?oooooo]_ooool0
00Wooooo00?oMgMgolc<c?l000000oooool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo
00;ooooo00Go410@oooooooooooooooooa0@400;ooooo`03o`000?oooooooooo01Oooooo00Co0000
oooooooooooo00002?ooool00ol0003oooooo`00003ooooookKooooo0009ooooo`03onk^k_m4A4Co
000000oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?o
0000ooooooooool05oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?oooooo
]_ooool000[ooooo00?oMgMgo`000?ooool03?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00oooool2o`0000Kooooo00?o0000ooooooooool05oooool01?l0003ooooo
ooooool00008ooooo`03o`000?oooooo00000?oooooo]_ooool002Oooooo00Co0000oooooooooooo
00001Oooool00ol0003oooooooooo`0Gooooo`04o`000?ooooooooooo`0000Sooooo00?o0000oooo
ool00000oooooonfooooo`009oooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooool000002Oooool00ol0003oooooo`00003ooooookKooooo000Wooooo`?o
00001_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo000000Wooooo00?o0000ooooool0
0000oooooonfooooo`00:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooool000002Oooool00ol0003oooooo`00003ooooookKooooo000Yooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool05oooool00ol0003oooooo`000009ooooo`03o`000?oo
oooo00000?oooooo]_ooool0033ooooo00?o0000ooooooooool05oooool00ol0003oooooo`000009
ooooo`;o0000oooooongooooo`00<?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo0000
00Wooooo0_l0003ooooookOooooo000`ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooool0
00002Oooool2o`000?oooooo]oooool0033ooooo0ol0000Gooooo`03o`000?oooooo000000Wooooo
0_l0003ooooookOooooo000`ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooool000002_oo
ool00ol0003oooooooooo`3ooooookGooooo000`ooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooool000002_ooool00ol0003oooooooooo`3ooooookGooooo000`ooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooool00000ooooooo2ooooo`00<?ooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooo00000?oooooo`_ooool0033ooooo00?o0000ooooooooool05oooool00ol0003ooooo
o`00003ooooool;ooooo000`ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooool00000oooo
ooo2ooooo`00<?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo00000?oooooo`_ooool0
033ooooo00?o0000ooooooooool05oooool00ol0003oooooo`00003ooooool;ooooo000`ooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooool00000ooooooo2ooooo`00<?ooool00ol0003ooooo
ooooo`0Hooooo`;o0000ooooooo2ooooo`00<?ooool00ol0003oooooooooo`0Hooooo`;o0000oooo
ooo2ooooo`00<?ooool3o`0001Sooooo0_l0003ooooool;ooooo000`ooooo`03o`000?oooooooooo
01Sooooo0_l0003ooooool;ooooo000`ooooo`03o`000?oooooooooo01Sooooo0_l0003ooooool;o
oooo000`ooooo`03o`000?oooooooooo01Sooooo0_l0003ooooool;ooooo000`ooooo`03o`000?oo
oooooooo01Sooooo0_l0003ooooool;ooooo000`ooooo`03o`000?oooooooooo01Sooooo0_l0003o
oooool;ooooo000`ooooo`03o`000?oooooooooo01Sooooo0_l0003ooooool;ooooo000`ooooo`03
o`000?oooooooooo01Sooooo0_l0003ooooool;ooooo000`ooooo`03o`000?oooooooooo01Sooooo
0_l0003ooooool;ooooo000`ooooo`03o`000?oooooooooo01Sooooo0_l0003ooooool;ooooo000`
ooooo`03o`000?oooooooooo01Sooooo0_l0003ooooool;ooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo0ol0003oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooo
g?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool00?ooooooooooool@ooooo`00
oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooo
oa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo002P
ooooo`;o00001?ooool00onj^[[o<S8booooo`04ooooo`;o00001_ooool00ol0003o^[Zjooooo`3o
oooooeOooooo002Pooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`04ooooo`;o<S8boooooomHooooo`00SOooool3o`0000;ooooo00Ko<S8boa0@4?oo
ooooooooonk^k_mEEED2o`000003odA4A?nj^[[ooooo00?ooooo00?o0000ooooooooool00_ooool0
1OnHV9So410@o`000?l0003oZJVY00Cooooo00?o0000ooooooooool01?ooool00on7QhOo0000okZj
^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X02_ooool4o`000003oa0@4?oooooooooo00;ooooo
0_lQ8B46ooooo`;o000000Oo410@ooooooo<c<cok^k^ooooooo^k^koc<c<00Cooooo1?l000002?l@
413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^4oooool01_l@413o<S8bo`000?l0003o410@ojVY
Z@;ooooo00Kok^k^oeEEEOl0003o0000odA4A?nj^[X3ooooo`05ofIVI_l0003o0000odA4A?o<c<`0
j?ooool008kooooo00Go0000ooooooooooooc<c<oa0@4003ooooo`06oeEEEOmgMgOoooooonk^k_mg
MgOo410@1?ooool00ol0003oooooooooo`02ooooo`06o`000?nYZJWoEEEEoiRHV?mEEEGo^[Zj0ooo
ool00ol0003oooooooooo`04ooooo`03olc<c?l0003o410@00cooooo00Ko410@okZj^_o^k^koMgMg
oa0@4?ooool6o`0000Gooooo00?o0000ooooooooool01?ooool2ob4Q8@Oooooo00So0000oooooooo
ooook^k^oeEEEOoMgMgoEEEEonk^kPKooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg01?ooooo00Ko0000ojVYZOoooooooooookZj^_l00002ooooo`06oeEEEOmgMgOooooo
onk^k_mgMgOo410@0_ooool01_mVIVKoMgMgooooooooooooQhN7oa0@4>Sooooo002>ooooo`05o`00
0?oooooooooooeEEEOn7QhL00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;o
oooo00Ko<S8bonk^k_nHV9SoEEEEomgMgOl@4103ooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0:ooooo`Go00000_ooool00ooMgMgo0000omgMg@07
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Dooooo`05okZj^_n7
QhOoIVIVofIVI_l@41000_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0>_ooooo
002>ooooo`05o`000?oooooogMgMo`000?o^k^h00oooool6o`0000Cooooo00?o0000ooooooooool0
0_ooool01onj^[[oA4A4olc<c?lQ8B7ooooooa0@4?o<c<`00_ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo00?ooooo1_l00005ooooo`03o`000?oooooooooo00[ooooo00CoA4A4omgM
gOoooooo00000_ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000001?ooooo00Ko<S8bob4Q8OmgMgOoMgMgohN7Qoo^k^h2oooo
o`Ko00000_ooool00ol0003oooooooooo`3[ooooo`00S_ooool3o`000003oa0@4?nHV9Sooooo00;o
oooo00KoEEEEohN7Qoo^k^koooooohN7Qolb<S84ooooo`03o`000?oooooooooo00;ooooo00Ook^k^
o`000?oooooo0000oooooomVIVKoQhN700;ooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00[ooooo00CogMgMoeEEEOoooooo00000_ooool01Oo<c<co
k^k^ooooooo^k^koc<c<00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo
000001?ooooo00Ko0000okZj^_ooooook^k^ogMgMol00002ooooo`06oeEEEOn7QhOok^k^oooooon7
QhOo<S8b0_ooool01_mVIVKoMgMgooooooooooooQhN7o`000>Sooooo002>ooooo`05o`000?oooooo
ooooolc<c?l000000oooool01_o^k^koEEEEo`000?l0003oA4A4onk^kPCooooo00?o0000oooooooo
ool00_ooool01?mVIVKoV9RHoooooolb<S82okZj^P04o`000?ooooooooooo`0001?ooooo00?o410@
o`000?l000000ol0000=ooooo`03o`000?oooooooooo00_ooooo00?oMgMgolc<c?l000003Oooool0
0ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41001oooool3o`0000;ooooo0ol0
0004ooooo`06ojVYZOlQ8B7o0000o`000?lb<S;o00000_ooool01_o^k^koEEEEo`000?l0003oA4A4
onk^kP;ooooo00Kok^k^ofIVI_l0003o0000odA4A?l0003Xooooo`00S_ooool01Ol0003ooooooooo
ooo<c<co000000gooooo00?o0000ooooooooool01Oooool00omVIVKoQhN7ooooo`03ooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0;ooooo`03onk^
k_m4A4Co000000gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00So
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3oooooo`;ooooo002=ooooo`Co0000
00?o410@ojVYZOooool03?ooool2o`0000Kooooo00?oZJVYodA4A?ooool00_ooool2o`0001Gooooo
00?o0000ooooooooool03?ooool00omEEEGoIVIVo`00000>ooooo`03ogMgMol0003ooooo00[ooooo
00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo1?l00002ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0ooooool2ooooo`00ooooool6ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0ooooool2ooooo`00ooooool6ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0ooooool2ooooo`00ooooool5ooooo`;o00000oooool2
o`000?oooooo1?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo
4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oo
ooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@
ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooo
oooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3o
oooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo0000\
\>"],
  ImageRangeCache->{{{0, 525.688}, {324.5, 0}} -> {0, -6.34248*^6, 0, 53093}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0.309017 5.42214e-08 [
[.32684 .29652 -16.5 -12.5 ]
[.32684 .29652 16.5 0 ]
[.54329 .29652 -16.5 -12.5 ]
[.54329 .29652 16.5 0 ]
[.75974 .29652 -22.5 -12.5 ]
[.75974 .29652 22.5 0 ]
[.97619 .29652 -16.5 -12.5 ]
[.97619 .29652 16.5 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 64 6 ]
[.09789 .09213 -34.5 -6.25 ]
[.09789 .09213 0 6.25 ]
[.09789 .20057 -34.5 -6.25 ]
[.09789 .20057 0 6.25 ]
[.09789 .41746 -28.5 -6.25 ]
[.09789 .41746 0 6.25 ]
[.09789 .5259 -28.5 -6.25 ]
[.09789 .5259 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -62.8125 0 ]
[.5 .63053 62.8125 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 .30902 m
.32684 .31527 L
s
gsave
.32684 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 .30902 m
.54329 .31527 L
s
gsave
.54329 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 .30902 m
.75974 .31527 L
s
gsave
.75974 .29652 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 .30902 m
.15368 .31277 L
s
.19697 .30902 m
.19697 .31277 L
s
.24026 .30902 m
.24026 .31277 L
s
.28355 .30902 m
.28355 .31277 L
s
.37013 .30902 m
.37013 .31277 L
s
.41342 .30902 m
.41342 .31277 L
s
.45671 .30902 m
.45671 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.58658 .30902 m
.58658 .31277 L
s
.62987 .30902 m
.62987 .31277 L
s
.67316 .30902 m
.67316 .31277 L
s
.71645 .30902 m
.71645 .31277 L
s
.80303 .30902 m
.80303 .31277 L
s
.84632 .30902 m
.84632 .31277 L
s
.88961 .30902 m
.88961 .31277 L
s
.9329 .30902 m
.9329 .31277 L
s
.0671 .30902 m
.0671 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09213 m
.11664 .09213 L
s
gsave
.09789 .09213 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .20057 m
.11664 .20057 L
s
gsave
.09789 .20057 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .41746 m
.11664 .41746 L
s
gsave
.09789 .41746 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .5259 m
.11664 .5259 L
s
gsave
.09789 .5259 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.11039 .11924 m
.11414 .11924 L
s
.11039 .14635 m
.11414 .14635 L
s
.11039 .17346 m
.11414 .17346 L
s
.11039 .22768 m
.11414 .22768 L
s
.11039 .2548 m
.11414 .2548 L
s
.11039 .28191 m
.11414 .28191 L
s
.11039 .33613 m
.11414 .33613 L
s
.11039 .36324 m
.11414 .36324 L
s
.11039 .39035 m
.11414 .39035 L
s
.11039 .44457 m
.11414 .44457 L
s
.11039 .47168 m
.11414 .47168 L
s
.11039 .49879 m
.11414 .49879 L
s
.11039 .06502 m
.11414 .06502 L
s
.11039 .03791 m
.11414 .03791 L
s
.11039 .0108 m
.11414 .0108 L
s
.11039 .55301 m
.11414 .55301 L
s
.11039 .58012 m
.11414 .58012 L
s
.11039 .60723 m
.11414 .60723 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -123.812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.812 moveto
(@) show
81.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.812 moveto
(D) show
93.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.6) show
135.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
141.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
153.000 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
157.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
166.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
184.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.0239 .30902 L
.02399 .30902 L
.02409 .30902 L
.02418 .30902 L
.02427 .30902 L
.02435 .30902 L
.02444 .30902 L
.02453 .30902 L
.02472 .30902 L
.02491 .30902 L
.0251 .30902 L
.02532 .30902 L
.02575 .30902 L
.02615 .30902 L
.02691 .30902 L
.02732 .30902 L
.02775 .30902 L
.02853 .30902 L
.02945 .30902 L
.03029 .30902 L
.03184 .30902 L
.03351 .30902 L
.0368 .30901 L
.03844 .30901 L
.03924 .30901 L
.03997 .30901 L
.04033 .30901 L
.04052 .30901 L
.04072 .30901 L
.0409 .30901 L
.0411 .30901 L
.04118 .30901 L
.04127 .30901 L
.04136 .30901 L
.04144 .30901 L
.04153 .30901 L
.04163 .30901 L
.04172 .30901 L
.04181 .30901 L
.04191 .30901 L
.04196 .30901 L
.04201 .30901 L
.04211 .30901 L
.04221 .30901 L
.0424 .30901 L
.0426 .30901 L
.0428 .30901 L
.04302 .30901 L
.04344 .30901 L
Mistroke
.04383 .30901 L
.04426 .30901 L
.04472 .30901 L
.04556 .30901 L
.04633 .30902 L
.04788 .30902 L
.04955 .30903 L
.05285 .30905 L
.05449 .30906 L
.05529 .30907 L
.05602 .30907 L
.05673 .30908 L
.0571 .30908 L
.05749 .30908 L
.05769 .30908 L
.05792 .30908 L
.05801 .30908 L
.05812 .30908 L
.05821 .30908 L
.0583 .30908 L
.0584 .30908 L
.0585 .30908 L
.0586 .30908 L
.05871 .30908 L
.0588 .30908 L
.0589 .30908 L
.05898 .30908 L
.05907 .30908 L
.05926 .30908 L
.05947 .30908 L
.05966 .30908 L
.05983 .30908 L
.06026 .30908 L
.06067 .30907 L
.06148 .30906 L
.06194 .30906 L
.06236 .30905 L
.06386 .30902 L
.06471 .30899 L
.06551 .30896 L
.06861 .30882 L
.07019 .30873 L
.07191 .30864 L
.07271 .30861 L
.07314 .30859 L
.07356 .30858 L
.07394 .30857 L
.07415 .30856 L
.07436 .30856 L
.07454 .30856 L
Mistroke
.07464 .30856 L
.07474 .30856 L
.07483 .30855 L
.07491 .30855 L
.075 .30855 L
.07509 .30855 L
.07519 .30855 L
.07525 .30855 L
.0753 .30856 L
.07539 .30856 L
.07549 .30856 L
.07567 .30856 L
.07586 .30856 L
.07607 .30857 L
.07629 .30857 L
.07668 .30859 L
.07708 .30861 L
.07745 .30863 L
.07816 .30869 L
.07893 .30877 L
.07976 .30889 L
.08124 .30916 L
.0828 .30953 L
.08427 .30995 L
.08737 .31088 L
.08821 .3111 L
.08898 .31127 L
.08941 .31134 L
.08979 .31139 L
.09 .31142 L
.09022 .31144 L
.09034 .31145 L
.09046 .31146 L
.09057 .31146 L
.09068 .31147 L
.09077 .31147 L
.09087 .31147 L
.09097 .31147 L
.09105 .31147 L
.09116 .31147 L
.09125 .31147 L
.0913 .31147 L
.09136 .31146 L
.09146 .31146 L
.09164 .31145 L
.09184 .31143 L
.09219 .31138 L
.09259 .3113 L
.09298 .31121 L
.09384 .31091 L
Mistroke
.09468 .3105 L
.09548 .30999 L
.09697 .30875 L
.10005 .30519 L
.10161 .30316 L
.10333 .30111 L
.10412 .30035 L
.10455 .29999 L
.10496 .29971 L
.10534 .2995 L
.10555 .29941 L
.10576 .29934 L
.10586 .29931 L
.10596 .29928 L
.10605 .29926 L
.10614 .29925 L
.10622 .29924 L
.10631 .29923 L
.1064 .29923 L
.10649 .29922 L
.1066 .29923 L
.10669 .29924 L
.10674 .29924 L
.1068 .29925 L
.10691 .29927 L
.10701 .29929 L
.10712 .29932 L
.10731 .2994 L
.1075 .29948 L
.1077 .2996 L
.10806 .29986 L
.10847 .30025 L
.10886 .30071 L
.10973 .30208 L
.11058 .30385 L
.11138 .30591 L
.11287 .31073 L
.11595 .32336 L
.11752 .32984 L
.11835 .3329 L
.11924 .33566 L
.11968 .33677 L
.12009 .33765 L
.12046 .33827 L
.12068 .33855 L
.12087 .33875 L
.12097 .33884 L
.12107 .33891 L
.12116 .33897 L
.12126 .33901 L
Mistroke
.12136 .33905 L
.12142 .33906 L
.12147 .33907 L
.12156 .33908 L
.12166 .33907 L
.12176 .33904 L
.12186 .33901 L
.12196 .33895 L
.12205 .33889 L
.12222 .33875 L
.1224 .33854 L
.12279 .33791 L
.12315 .33711 L
.12355 .33598 L
.12396 .33451 L
.12467 .33135 L
.12543 .32693 L
.12701 .31486 L
.12869 .29833 L
.13029 .28065 L
.13203 .26181 L
.13284 .25394 L
.1337 .24681 L
.13443 .242 L
.13485 .23987 L
.13524 .23834 L
.13545 .23771 L
.13564 .23725 L
.13575 .23704 L
.13585 .23688 L
.13596 .23675 L
.13601 .2367 L
.13608 .23666 L
.13617 .23661 L
.13628 .2366 L
.13633 .23661 L
.13639 .23663 L
.13649 .2367 L
.13659 .2368 L
.13669 .23693 L
.13687 .23728 L
.13705 .23774 L
.13724 .23836 L
.13758 .23982 L
.13795 .2419 L
.13836 .24481 L
.13917 .25258 L
.13992 .26191 L
.14159 .29003 L
.14478 .36108 L
Mistroke
.14639 .39732 L
.14785 .42464 L
.14866 .43609 L
.14903 .44021 L
.14943 .4437 L
.14963 .44513 L
.14985 .4464 L
.15005 .44729 L
.15014 .44761 L
.15023 .44789 L
.15029 .44803 L
.15035 .44814 L
.1504 .44822 L
.15046 .44829 L
.15055 .44836 L
.15066 .44837 L
.15072 .44834 L
.15077 .44829 L
.15083 .44821 L
.15089 .44811 L
.151 .44787 L
.15111 .44751 L
.15131 .44666 L
.15153 .44539 L
.15193 .44219 L
.15232 .43795 L
.15268 .43306 L
.1535 .41848 L
.15437 .39804 L
.15594 .34939 L
.15741 .29418 L
.16052 .17264 L
.16134 .14597 L
.16222 .12183 L
.16263 .11285 L
.16306 .10488 L
.16347 .09898 L
.16384 .09506 L
.16403 .0936 L
.16423 .09244 L
.16433 .09202 L
.16439 .09184 L
.16445 .0917 L
.16455 .09153 L
.16465 .09147 L
.16474 .09151 L
.16483 .09165 L
.16491 .09185 L
.165 .09215 L
.1651 .09258 L
Mistroke
.1652 .09315 L
.16539 .0945 L
.1656 .09652 L
.16583 .09932 L
.16626 .10601 L
.16667 .11448 L
.16706 .12403 L
.16871 .18188 L
.1702 .25386 L
.17341 .43334 L
.17489 .50583 L
.17572 .53898 L
.17613 .55248 L
.1765 .56307 L
.17687 .57184 L
.17728 .57934 L
.1775 .58251 L
.1777 .58485 L
.1779 .58653 L
.17799 .58717 L
.17805 .58745 L
.1781 .58771 L
.17815 .58791 L
.17821 .58808 L
.17827 .58821 L
.17832 .58828 L
.17843 .58831 L
.17852 .58819 L
.17858 .58805 L
.17863 .58788 L
.17876 .58734 L
.17886 .58669 L
.17898 .58581 L
.17918 .58378 L
.17936 .58134 L
.17979 .57384 L
.18019 .5645 L
.18063 .55176 L
.18142 .52211 L
.18291 .44699 L
.18617 .2344 L
.18768 .14039 L
.18848 .09818 L
.18932 .06125 L
.18974 .04593 L
.19021 .0321 L
.19064 .02239 L
.19104 .01588 L
.19125 .01345 L
.19135 .01252 L
Mistroke
.19145 .01181 L
.19153 .01129 L
.19162 .01088 L
.19172 .01061 L
.19182 .01046 L
.19187 .01045 L
.19193 .0105 L
.19203 .01069 L
.19208 .01088 L
.19213 .01109 L
.19225 .01173 L
.19235 .01248 L
.19245 .01331 L
.19266 .01568 L
.19284 .01837 L
.19305 .02196 L
.19346 .03119 L
.1942 .05408 L
.19506 .09026 L
.19587 .13197 L
.19899 .333 L
.20057 .43393 L
.20141 .47991 L
.2023 .52063 L
.20275 .53739 L
.20317 .55064 L
.20358 .56109 L
.20396 .56849 L
.20432 .57354 L
.2045 .57534 L
.2046 .57613 L
.2047 .57673 L
.2048 .57722 L
.2049 .57751 L
.205 .57768 L
.20506 .57771 L
.20511 .57768 L
.2052 .57755 L
.2053 .57726 L
.2054 .5768 L
.20549 .57623 L
.2057 .57453 L
.20589 .57238 L
.20633 .56552 L
.20671 .55726 L
.20712 .54627 L
.20861 .48958 L
.21033 .4005 L
.21194 .30759 L
.21342 .22785 L
Mistroke
.21426 .18863 L
.21504 .15767 L
.21581 .1334 L
.21624 .1228 L
.21664 .1151 L
.21705 .10908 L
.21729 .10663 L
.2174 .10571 L
.21751 .10498 L
.21761 .10442 L
.2177 .10402 L
.2178 .10369 L
.21785 .10357 L
.21791 .10348 L
.21801 .10341 L
.21811 .10347 L
.21816 .10355 L
.21821 .10366 L
.21827 .10383 L
.21833 .10403 L
.21842 .10444 L
.21852 .10499 L
.2187 .10629 L
.21891 .10832 L
.21911 .11064 L
.21953 .11712 L
.21994 .12503 L
.22064 .14276 L
.22142 .16688 L
.22468 .29807 L
.22619 .35725 L
.22699 .38391 L
.22783 .40742 L
.22826 .41734 L
.22872 .42648 L
.22916 .43322 L
.22955 .43795 L
.22974 .43979 L
.22995 .4414 L
.23007 .44212 L
.23018 .44269 L
.23028 .44316 L
.23039 .44351 L
.23047 .44373 L
.23057 .4439 L
.23067 .444 L
.23077 .44401 L
.23086 .44395 L
.23096 .4438 L
.23101 .44369 L
Mistroke
.23107 .44355 L
.23117 .44323 L
.23138 .4423 L
.2316 .44094 L
.23199 .43757 L
.23242 .43267 L
.23288 .42587 L
.2345 .39309 L
.23775 .30866 L
.23924 .27425 L
.24003 .25956 L
.24087 .24719 L
.24129 .24236 L
.24175 .23813 L
.24195 .23664 L
.24217 .23528 L
.24238 .23424 L
.24257 .23348 L
.24276 .2329 L
.24287 .23268 L
.24298 .2325 L
.24303 .23243 L
.24309 .23238 L
.24315 .23235 L
.2432 .23233 L
.2433 .23234 L
.24341 .2324 L
.2435 .2325 L
.2436 .23266 L
.24369 .23285 L
.24378 .23305 L
.24398 .23371 L
.24418 .23451 L
.24459 .2367 L
.24495 .23926 L
.24577 .24681 L
.24725 .26515 L
.24892 .28962 L
.25047 .31149 L
.25197 .32912 L
.25273 .33594 L
.25316 .33909 L
.25356 .34158 L
.25395 .34355 L
.25416 .34441 L
.25438 .34518 L
.25457 .34572 L
.25477 .34621 L
.25496 .34654 L
.25513 .34677 L
Mistroke
.25523 .34687 L
.25528 .34691 L
.25533 .34694 L
.25539 .34696 L
.25545 .34698 L
.25555 .34699 L
.25565 .34697 L
.25575 .34693 L
.25585 .34686 L
.25594 .34678 L
.25614 .34652 L
.25636 .34612 L
.25659 .34558 L
.25681 .34496 L
.25764 .34171 L
.25844 .33751 L
.25993 .32775 L
.263 .30666 L
.26381 .30216 L
.26458 .29864 L
.265 .29703 L
.26546 .29556 L
.26588 .29448 L
.26626 .2937 L
.26663 .29313 L
.26684 .2929 L
.26703 .29273 L
.26713 .29266 L
.26724 .29261 L
.26729 .29258 L
.26735 .29256 L
.26741 .29254 L
.26746 .29253 L
.26756 .29252 L
.26762 .29251 L
.26767 .29251 L
.26777 .29252 L
.26787 .29255 L
.26792 .29257 L
.26798 .29259 L
.26809 .29264 L
.26829 .29277 L
.26853 .29298 L
.26875 .29323 L
.26914 .29379 L
.26956 .29454 L
.27114 .2984 L
.27261 .30283 L
.2741 .3073 L
.27573 .31137 L
Mistroke
.27661 .31303 L
.277 .31362 L
.27743 .31418 L
.27781 .31457 L
.27822 .3149 L
.27844 .31505 L
.27864 .31515 L
.27884 .31523 L
.27894 .31527 L
.27905 .31529 L
.27916 .31532 L
.27925 .31533 L
.27935 .31534 L
.27945 .31535 L
.27954 .31535 L
.27962 .31535 L
.27971 .31534 L
.27981 .31533 L
.27992 .31532 L
.28003 .31529 L
.28024 .31523 L
.28044 .31516 L
.28063 .31508 L
.28135 .31464 L
.28211 .314 L
.28545 .31027 L
.28626 .3094 L
.28712 .3086 L
.28792 .30798 L
.28866 .30752 L
.28938 .3072 L
.28978 .30706 L
.29014 .30697 L
.29035 .30693 L
.29054 .3069 L
.29075 .30688 L
.29086 .30687 L
.29091 .30687 L
.29097 .30686 L
.29108 .30686 L
.29117 .30686 L
.29127 .30686 L
.29133 .30686 L
.29138 .30686 L
.29148 .30686 L
.29157 .30686 L
.29167 .30687 L
.29176 .30688 L
.29195 .3069 L
.29213 .30692 L
Mistroke
.29254 .30699 L
.29294 .30708 L
.29337 .30719 L
.29485 .3077 L
.29644 .30833 L
.29817 .30895 L
.29897 .30918 L
.29983 .30938 L
.30056 .30951 L
.30097 .30957 L
.30136 .30961 L
.30174 .30964 L
.30195 .30965 L
.30215 .30966 L
.30226 .30967 L
.30236 .30967 L
.30245 .30967 L
.30255 .30967 L
.3026 .30967 L
.30266 .30967 L
.30272 .30968 L
.30277 .30968 L
.30287 .30968 L
.30293 .30968 L
.30298 .30967 L
.30307 .30967 L
.30317 .30967 L
.30334 .30967 L
.30355 .30966 L
.30374 .30965 L
.30411 .30963 L
.30446 .30961 L
.30608 .30945 L
.30756 .30927 L
.3092 .30909 L
.31 .30901 L
.31073 .30895 L
.31148 .30891 L
.3122 .30887 L
.31259 .30886 L
.31296 .30885 L
.31316 .30885 L
.31335 .30884 L
.31355 .30884 L
.31366 .30884 L
.31378 .30884 L
.31388 .30884 L
.31397 .30884 L
.31407 .30884 L
.31417 .30884 L
Mistroke
.31427 .30884 L
.31435 .30884 L
.31445 .30884 L
.31455 .30884 L
.31464 .30884 L
.31475 .30884 L
.31495 .30884 L
.31539 .30885 L
.31584 .30886 L
.31627 .30887 L
.31708 .30889 L
.32015 .30899 L
.32173 .30903 L
.32262 .30904 L
.32342 .30905 L
.32381 .30906 L
.32402 .30906 L
.32422 .30906 L
.32458 .30906 L
.32476 .30906 L
.32486 .30906 L
.32496 .30906 L
.32508 .30906 L
.32518 .30906 L
.32524 .30906 L
.32529 .30906 L
.32535 .30906 L
.32541 .30906 L
.32547 .30906 L
.32552 .30906 L
.32558 .30906 L
.32564 .30906 L
.32573 .30906 L
.32584 .30906 L
.32605 .30906 L
.32626 .30906 L
.32664 .30906 L
.32742 .30905 L
.32825 .30905 L
.32973 .30904 L
.33132 .30902 L
.33277 .30902 L
.33358 .30901 L
.33434 .30901 L
.33476 .30901 L
.33514 .30901 L
.33536 .30901 L
.33557 .30901 L
.33578 .30901 L
.33589 .30901 L
Mistroke
.33602 .30901 L
.33612 .30901 L
.33621 .30901 L
.33631 .30901 L
.33641 .30901 L
.33651 .30901 L
.33659 .30901 L
.33668 .30901 L
.33678 .30901 L
.33688 .30901 L
.33699 .30901 L
.33718 .30901 L
.33741 .30901 L
.33762 .30901 L
.33849 .30901 L
.33932 .30901 L
.34238 .30902 L
.3432 .30902 L
.34396 .30902 L
.34439 .30902 L
.34485 .30902 L
.34526 .30902 L
.34565 .30902 L
.34602 .30902 L
.34641 .30902 L
.34664 .30902 L
.34675 .30902 L
.34685 .30902 L
.34694 .30902 L
.34704 .30902 L
.34714 .30902 L
.3472 .30902 L
.34725 .30902 L
.34735 .30902 L
.3474 .30902 L
.34746 .30902 L
.34756 .30902 L
.34762 .30902 L
.34767 .30902 L
.34777 .30902 L
.34788 .30902 L
.34806 .30902 L
.34829 .30902 L
.34852 .30902 L
.34894 .30902 L
.35051 .30902 L
.35198 .30902 L
.35348 .30902 L
.35426 .30902 L
.3551 .30902 L
Mistroke
.35557 .30902 L
.35599 .30902 L
.35641 .30902 L
.3568 .30902 L
.357 .30902 L
.35721 .30902 L
.35739 .30902 L
.35758 .30902 L
.35769 .30902 L
.35779 .30902 L
.35789 .30902 L
.35798 .30902 L
.35803 .30902 L
.35809 .30902 L
.35819 .30902 L
.35825 .30902 L
.3583 .30902 L
.35836 .30902 L
.35842 .30902 L
.35852 .30902 L
.35862 .30902 L
.35884 .30902 L
.35904 .30902 L
.35923 .30902 L
.36011 .30902 L
.36173 .30902 L
.3632 .30902 L
.36404 .30902 L
.36482 .30902 L
.36559 .30902 L
.36642 .30902 L
.36687 .30902 L
.3673 .30902 L
.36769 .30902 L
.36791 .30902 L
.36811 .30902 L
.3682 .30902 L
.3683 .30902 L
.36839 .30902 L
.36848 .30902 L
.36858 .30902 L
.36867 .30902 L
.36873 .30902 L
.36878 .30902 L
.36888 .30902 L
.36897 .30902 L
.36906 .30902 L
.36914 .30902 L
.36923 .30902 L
.36942 .30902 L
Mistroke
.36961 .30902 L
.37002 .30902 L
.3704 .30902 L
.37126 .30902 L
.37292 .30902 L
.37445 .30902 L
.37522 .30902 L
.37594 .30902 L
.37634 .30902 L
.37677 .30902 L
.37713 .30902 L
.37752 .30902 L
.37792 .30902 L
.37829 .30902 L
.37851 .30902 L
.37862 .30902 L
.37872 .30902 L
.37882 .30902 L
.37892 .30902 L
.37902 .30902 L
.37907 .30902 L
.37912 .30902 L
.37918 .30902 L
.37923 .30902 L
.37928 .30902 L
.37934 .30902 L
.37945 .30902 L
.37954 .30902 L
.3796 .30902 L
.37966 .30902 L
.37978 .30902 L
.38 .30902 L
.38019 .30902 L
.38039 .30902 L
.38082 .30902 L
.38238 .30902 L
.38406 .30902 L
.38487 .30902 L
.38576 .30902 L
.3866 .30902 L
.38697 .30902 L
.38737 .30902 L
.38778 .30902 L
.38814 .30902 L
.3885 .30902 L
.38867 .30902 L
.38887 .30902 L
.38898 .30902 L
.38909 .30902 L
.38918 .30902 L
Mistroke
.38928 .30902 L
.38939 .30902 L
.38949 .30902 L
.38955 .30902 L
.3896 .30902 L
.38966 .30902 L
.38972 .30902 L
.38983 .30902 L
.38988 .30902 L
.38994 .30902 L
.39004 .30902 L
.39014 .30902 L
.39034 .30902 L
.39052 .30902 L
.39091 .30902 L
.39133 .30902 L
.39207 .30902 L
.39374 .30902 L
.39533 .30902 L
.39603 .30902 L
.39679 .30902 L
.39721 .30902 L
.39759 .30902 L
.39799 .30902 L
.39835 .30902 L
.39874 .30902 L
.39895 .30902 L
.39917 .30902 L
.39939 .30902 L
.3995 .30902 L
.39962 .30902 L
.39972 .30902 L
.39978 .30902 L
.39983 .30902 L
.39994 .30902 L
.40003 .30902 L
.40013 .30902 L
.40023 .30902 L
.40032 .30902 L
.4004 .30902 L
.40061 .30902 L
.40081 .30902 L
.40121 .30902 L
.40164 .30902 L
.40312 .30902 L
.40484 .30902 L
.40565 .30902 L
.40639 .30902 L
.40717 .30902 L
.40758 .30902 L
Mistroke
.40801 .30902 L
.40839 .30902 L
.40874 .30902 L
.40912 .30902 L
.40934 .30902 L
.40944 .30902 L
.40953 .30902 L
.40963 .30902 L
.40972 .30902 L
.40982 .30902 L
.40992 .30902 L
.41002 .30902 L
.41008 .30902 L
.41013 .30902 L
.41023 .30902 L
.41033 .30902 L
.41043 .30902 L
.41053 .30902 L
.41072 .30902 L
.4109 .30902 L
.41107 .30902 L
.41188 .30902 L
.41274 .30902 L
.41433 .30902 L
.41578 .30902 L
.41659 .30902 L
.41735 .30902 L
.41777 .30902 L
.41815 .30902 L
.41858 .30902 L
.4188 .30902 L
.41903 .30902 L
.41921 .30902 L
.41942 .30902 L
.41951 .30902 L
.41961 .30902 L
.4197 .30902 L
.41978 .30902 L
.41988 .30902 L
.41994 .30902 L
.42 .30902 L
.42009 .30902 L
.42015 .30902 L
.4202 .30902 L
.4203 .30902 L
.42039 .30902 L
.42049 .30902 L
.42059 .30902 L
.42077 .30902 L
.42095 .30902 L
Mistroke
.42129 .30902 L
.42206 .30902 L
.42366 .30902 L
.4245 .30902 L
.4254 .30902 L
.4262 .30902 L
.42662 .30902 L
.42707 .30902 L
.42749 .30902 L
.42787 .30902 L
.42822 .30902 L
.42861 .30902 L
.429 .30902 L
.42921 .30902 L
.42941 .30902 L
.4295 .30902 L
.4296 .30902 L
.42968 .30902 L
.42977 .30902 L
.42986 .30902 L
.42995 .30902 L
.43005 .30902 L
.43015 .30902 L
.43025 .30902 L
.4303 .30902 L
.43036 .30902 L
.43046 .30902 L
.43056 .30902 L
.43077 .30902 L
.43101 .30902 L
.43182 .30902 L
.4334 .30902 L
.43424 .30902 L
.43513 .30902 L
.436 .30902 L
.43679 .30902 L
.43717 .30902 L
.43758 .30902 L
.43794 .30902 L
.43832 .30902 L
.43853 .30902 L
.43872 .30902 L
.43891 .30902 L
.43909 .30902 L
.4393 .30902 L
.43941 .30902 L
.43952 .30902 L
.43962 .30902 L
.43972 .30902 L
.43982 .30902 L
Mistroke
.43988 .30902 L
.43993 .30902 L
.44003 .30902 L
.44009 .30902 L
.44015 .30902 L
.44025 .30902 L
.44034 .30902 L
.44056 .30902 L
.4408 .30902 L
.44123 .30902 L
.44162 .30902 L
.44326 .30902 L
.44406 .30902 L
.44479 .30902 L
.4455 .30902 L
.44626 .30902 L
.44668 .30902 L
.44707 .30902 L
.44747 .30902 L
.44784 .30902 L
.44821 .30902 L
.44841 .30902 L
.44861 .30902 L
.44879 .30902 L
.44896 .30902 L
.44914 .30902 L
.44924 .30902 L
.44934 .30902 L
.44944 .30902 L
.44949 .30902 L
.44955 .30902 L
.44965 .30902 L
.44975 .30902 L
.4498 .30902 L
.44986 .30902 L
.44996 .30902 L
.45007 .30902 L
.45019 .30902 L
.45061 .30902 L
.45099 .30902 L
.4525 .30902 L
.45414 .30902 L
.45503 .30902 L
.45586 .30902 L
.45665 .30902 L
.45704 .30902 L
.45748 .30902 L
.45768 .30902 L
.4579 .30902 L
.45809 .30902 L
Mistroke
.4583 .30902 L
.45848 .30902 L
.45858 .30902 L
.45869 .30902 L
.45878 .30902 L
.45887 .30902 L
.45896 .30902 L
.45905 .30902 L
.45915 .30902 L
.45925 .30902 L
.4593 .30902 L
.45936 .30902 L
.45946 .30902 L
.45956 .30902 L
.45966 .30902 L
.45985 .30902 L
.46027 .30902 L
.46073 .30902 L
.46242 .30902 L
.46397 .30902 L
.46474 .30902 L
.46514 .30902 L
.46557 .30902 L
.46595 .30902 L
.46636 .30902 L
.46674 .30902 L
.46709 .30902 L
.46747 .30902 L
.46768 .30902 L
.46788 .30902 L
.46799 .30902 L
.46809 .30902 L
.46818 .30902 L
.46828 .30902 L
.46833 .30902 L
.46839 .30902 L
.46848 .30902 L
.46854 .30902 L
.4686 .30902 L
.46866 .30902 L
.46871 .30902 L
.4688 .30902 L
.4689 .30902 L
.46899 .30902 L
.46907 .30902 L
.46928 .30902 L
.46947 .30902 L
.46982 .30902 L
.47019 .30902 L
.47176 .30902 L
Mistroke
.47259 .30902 L
.47348 .30902 L
.47434 .30902 L
.47512 .30902 L
.4755 .30902 L
.47591 .30902 L
.4763 .30902 L
.47666 .30902 L
.47703 .30902 L
.47724 .30902 L
.47743 .30902 L
.4776 .30902 L
.47769 .30902 L
.47778 .30902 L
.47788 .30902 L
.47796 .30902 L
.47806 .30902 L
.47815 .30902 L
.47825 .30902 L
.47836 .30902 L
.47841 .30902 L
.47847 .30902 L
.47857 .30902 L
.47877 .30902 L
.47895 .30902 L
.47981 .30902 L
.48147 .30902 L
.48227 .30902 L
.483 .30902 L
.48377 .30902 L
.48449 .30902 L
.48489 .30902 L
.48525 .30902 L
.48565 .30902 L
.48587 .30902 L
.48607 .30902 L
.48626 .30902 L
.48647 .30902 L
.48666 .30902 L
.48684 .30902 L
.48693 .30902 L
.48703 .30902 L
.48713 .30902 L
.48718 .30902 L
.48723 .30902 L
.48734 .30902 L
.48739 .30902 L
.48745 .30902 L
.48755 .30902 L
.48765 .30902 L
Mistroke
.48775 .30902 L
.48784 .30902 L
.48805 .30902 L
.48843 .30902 L
.48913 .30902 L
.49076 .30902 L
.49157 .30902 L
.4923 .30902 L
.49305 .30902 L
.49377 .30902 L
.49416 .30902 L
.49452 .30902 L
.49492 .30902 L
.49512 .30902 L
.49534 .30902 L
.49553 .30902 L
.49573 .30902 L
.49592 .30902 L
.49609 .30902 L
.4962 .30902 L
.4963 .30902 L
.49639 .30902 L
.49649 .30902 L
.49659 .30902 L
.49664 .30902 L
.4967 .30902 L
.49681 .30902 L
.4969 .30902 L
.49699 .30902 L
.49709 .30902 L
.49727 .30902 L
.49761 .30902 L
.49837 .30902 L
.50008 .30902 L
.50089 .30902 L
.50164 .30902 L
.50241 .30902 L
.50282 .30902 L
.50326 .30902 L
.50361 .30902 L
.50398 .30902 L
.5042 .30902 L
.5044 .30902 L
.50478 .30902 L
.50496 .30902 L
.50517 .30902 L
.50527 .30902 L
.50538 .30902 L
.50548 .30902 L
.50558 .30902 L
Mistroke
.50567 .30902 L
.50575 .30902 L
.50584 .30902 L
.50594 .30902 L
.50604 .30902 L
.50613 .30902 L
.50631 .30902 L
.50652 .30902 L
.50673 .30902 L
.50711 .30902 L
.50798 .30902 L
.50957 .30902 L
.51027 .30902 L
.51103 .30902 L
.51144 .30902 L
.51183 .30902 L
.51222 .30902 L
.51259 .30902 L
.51298 .30902 L
.5132 .30902 L
.5134 .30902 L
.5136 .30902 L
.51382 .30902 L
.51404 .30902 L
.51416 .30902 L
.51427 .30902 L
.51436 .30902 L
.51447 .30902 L
.51458 .30902 L
.51464 .30902 L
.51469 .30902 L
.51479 .30902 L
.51488 .30902 L
.51493 .30902 L
.51499 .30902 L
.51509 .30902 L
.51519 .30902 L
.51528 .30902 L
.51548 .30902 L
.51584 .30902 L
.5167 .30902 L
.51752 .30902 L
.51899 .30902 L
.51983 .30902 L
.52024 .30902 L
.52061 .30902 L
.52098 .30902 L
.52139 .30902 L
.52181 .30902 L
.52221 .30902 L
Mistroke
.52242 .30902 L
.52264 .30902 L
.52287 .30902 L
.52298 .30902 L
.52309 .30902 L
.52319 .30902 L
.5233 .30902 L
.52339 .30902 L
.52348 .30902 L
.52359 .30902 L
.52365 .30902 L
.5237 .30902 L
.5238 .30902 L
.52391 .30902 L
.524 .30902 L
.52409 .30902 L
.5242 .30902 L
.5243 .30902 L
.52467 .30902 L
.52507 .30902 L
.5255 .30902 L
.52719 .30902 L
.52801 .30902 L
.52877 .30902 L
.5292 .30902 L
.52966 .30902 L
.53007 .30902 L
.53046 .30902 L
.53083 .30902 L
.53122 .30902 L
.53145 .30902 L
.53166 .30902 L
.53185 .30902 L
.53196 .30902 L
.53206 .30902 L
.53217 .30902 L
.53226 .30902 L
.53237 .30902 L
.53243 .30902 L
.53249 .30902 L
.53254 .30902 L
.5326 .30902 L
.5327 .30902 L
.53277 .30902 L
.53283 .30902 L
.53288 .30902 L
.53294 .30902 L
.53304 .30902 L
.53315 .30902 L
.53336 .30902 L
Mistroke
.53375 .30902 L
.53545 .30902 L
.537 .30902 L
.53776 .30902 L
.53817 .30902 L
.5386 .30902 L
.53897 .30902 L
.53939 .30902 L
.53976 .30902 L
.54012 .30902 L
.54031 .30902 L
.54049 .30902 L
.54069 .30902 L
.54091 .30902 L
.54101 .30902 L
.54113 .30902 L
.54118 .30902 L
.54124 .30902 L
.54134 .30902 L
.54144 .30902 L
.54153 .30902 L
.54163 .30902 L
.54168 .30902 L
.54174 .30902 L
.54183 .30902 L
.54192 .30902 L
.5421 .30902 L
.54231 .30902 L
.5425 .30902 L
.54322 .30902 L
.5449 .30902 L
.54563 .30902 L
.54644 .30902 L
.54681 .30902 L
.54722 .30902 L
.54757 .30902 L
.54794 .30902 L
.54837 .30902 L
.54857 .30902 L
.54878 .30902 L
.54896 .30902 L
.54917 .30902 L
.54936 .30902 L
.54953 .30902 L
.54963 .30902 L
.54973 .30902 L
.54982 .30902 L
.54991 .30902 L
.54997 .30902 L
.55002 .30902 L
Mistroke
.55013 .30902 L
.55022 .30902 L
.55032 .30902 L
.55042 .30902 L
.55053 .30902 L
.55063 .30902 L
.55072 .30902 L
.55094 .30902 L
.55116 .30902 L
.55187 .30902 L
.55264 .30902 L
.55353 .30902 L
.55436 .30902 L
.5551 .30902 L
.55549 .30902 L
.55591 .30902 L
.5563 .30902 L
.55671 .30902 L
.55715 .30902 L
.55734 .30902 L
.55755 .30902 L
.55776 .30902 L
.55796 .30902 L
.55814 .30902 L
.55824 .30902 L
.55834 .30902 L
.55843 .30902 L
.55852 .30902 L
.5586 .30902 L
.55868 .30902 L
.55878 .30902 L
.55886 .30902 L
.55896 .30902 L
.55906 .30902 L
.55916 .30902 L
.55921 .30902 L
.55927 .30902 L
.55949 .30902 L
.55968 .30902 L
.55988 .30902 L
.56078 .30902 L
.5624 .30902 L
.56321 .30902 L
.56364 .30902 L
.5641 .30902 L
.5645 .30902 L
.56494 .30902 L
.56534 .30902 L
.56571 .30902 L
.56609 .30902 L
Mistroke
.5663 .30902 L
.5665 .30902 L
.56671 .30902 L
.56691 .30902 L
.56701 .30902 L
.56713 .30902 L
.56718 .30902 L
.56723 .30902 L
.56733 .30902 L
.56743 .30902 L
.56751 .30902 L
.56761 .30902 L
.5677 .30902 L
.56778 .30902 L
.56786 .30902 L
.56804 .30902 L
.56824 .30902 L
.56842 .30902 L
.56882 .30902 L
.5705 .30902 L
.57123 .30902 L
.57204 .30902 L
.57242 .30902 L
.57282 .30902 L
.57317 .30902 L
.57355 .30902 L
.57397 .30902 L
.57417 .30902 L
.57438 .30902 L
.57457 .30902 L
.57477 .30902 L
.57496 .30902 L
.57514 .30902 L
.57533 .30902 L
.57543 .30902 L
.57553 .30902 L
.57564 .30902 L
.57573 .30902 L
.57584 .30902 L
.5759 .30902 L
.57595 .30902 L
.57604 .30902 L
.57612 .30902 L
.57621 .30902 L
.57631 .30902 L
.57641 .30902 L
.57651 .30902 L
.57669 .30902 L
.57711 .30902 L
.57749 .30902 L
Mistroke
.57837 .30902 L
.57915 .30902 L
.57999 .30902 L
.58079 .30902 L
.58116 .30902 L
.58152 .30902 L
.58188 .30902 L
.58222 .30902 L
.58259 .30902 L
.5828 .30902 L
.58299 .30902 L
.58337 .30902 L
.58358 .30902 L
.58368 .30902 L
.58379 .30902 L
.58389 .30902 L
.58397 .30902 L
.58406 .30902 L
.58415 .30902 L
.58425 .30902 L
.58435 .30902 L
.58444 .30902 L
.58454 .30902 L
.58464 .30902 L
.5847 .30902 L
.58475 .30902 L
.58486 .30902 L
.58497 .30902 L
.58537 .30902 L
.58584 .30902 L
.58626 .30902 L
.5871 .30902 L
.58788 .30902 L
.58861 .30902 L
.58942 .30902 L
.58983 .30902 L
.59022 .30902 L
.59064 .30902 L
.59085 .30902 L
.59108 .30902 L
.59129 .30902 L
.59148 .30902 L
.59167 .30902 L
.59185 .30902 L
.59206 .30902 L
.59217 .30902 L
.59228 .30902 L
.59238 .30902 L
.59248 .30902 L
.59254 .30902 L
Mistroke
.59259 .30902 L
.59269 .30902 L
.5928 .30902 L
.59285 .30902 L
.59291 .30902 L
.59301 .30902 L
.59311 .30902 L
.59316 .30902 L
.59322 .30902 L
.59332 .30902 L
.59356 .30902 L
.59395 .30902 L
.59438 .30902 L
.59526 .30902 L
.59609 .30902 L
.59689 .30902 L
.59764 .30902 L
.59836 .30902 L
.59873 .30902 L
.59913 .30902 L
.59954 .30902 L
.59977 .30902 L
.59998 .30902 L
.60017 .30902 L
.60038 .30902 L
.60048 .30902 L
.60058 .30902 L
.60067 .30902 L
.60076 .30902 L
.60086 .30902 L
.60092 .30902 L
.60097 .30902 L
.60103 .30902 L
.60109 .30902 L
.60119 .30902 L
.60129 .30902 L
.60138 .30902 L
.60148 .30902 L
.60159 .30902 L
.60181 .30902 L
.60201 .30902 L
.60248 .30902 L
.6041 .30902 L
.60489 .30902 L
.60572 .30902 L
.60643 .30902 L
.60683 .30902 L
.6072 .30902 L
.60761 .30902 L
.60784 .30902 L
Mistroke
.60805 .30902 L
.60825 .30902 L
.60843 .30902 L
.60863 .30902 L
.60873 .30902 L
.60884 .30902 L
.60894 .30902 L
.60904 .30902 L
.60913 .30902 L
.60922 .30902 L
.60931 .30902 L
.6094 .30902 L
.60948 .30902 L
.60956 .30902 L
.60966 .30902 L
.60976 .30902 L
.60987 .30902 L
.60997 .30902 L
.61034 .30902 L
.61183 .30902 L
.61262 .30902 L
.61346 .30902 L
.61388 .30902 L
.61435 .30902 L
.61478 .30902 L
.61517 .30902 L
.61557 .30902 L
.61578 .30902 L
.616 .30902 L
.61638 .30902 L
.61659 .30902 L
.61678 .30902 L
.61689 .30902 L
.617 .30902 L
.61709 .30902 L
.61719 .30902 L
.61725 .30902 L
.6173 .30902 L
.6174 .30902 L
.61746 .30902 L
.61752 .30902 L
.61758 .30902 L
.61763 .30902 L
.61773 .30902 L
.61781 .30902 L
.61791 .30902 L
.61802 .30902 L
.61823 .30902 L
.61843 .30902 L
.61992 .30902 L
Mistroke
.62072 .30902 L
.62157 .30902 L
.62198 .30902 L
.62237 .30902 L
.6231 .30902 L
.62347 .30902 L
.62386 .30902 L
.62419 .30902 L
.62456 .30902 L
.62477 .30902 L
.62496 .30902 L
.62506 .30902 L
.62518 .30902 L
.62528 .30902 L
.62538 .30902 L
.62548 .30902 L
.62558 .30902 L
.62566 .30902 L
.62576 .30902 L
.62586 .30902 L
.62596 .30902 L
.62605 .30902 L
.62615 .30902 L
.62635 .30902 L
.62657 .30902 L
.62697 .30902 L
.62772 .30902 L
.62852 .30902 L
.6294 .30902 L
.62979 .30902 L
.63022 .30902 L
.63058 .30902 L
.63098 .30902 L
.63141 .30902 L
.63163 .30902 L
.63186 .30902 L
.63208 .30902 L
.63228 .30902 L
.63267 .30902 L
.63286 .30902 L
.63306 .30902 L
.63316 .30902 L
.63327 .30902 L
.63338 .30902 L
.63347 .30902 L
.63357 .30902 L
.63365 .30902 L
.63375 .30902 L
.63385 .30902 L
.63395 .30902 L
Mistroke
.63404 .30902 L
.63412 .30902 L
.63421 .30902 L
.63441 .30902 L
.63463 .30902 L
.63508 .30902 L
.63588 .30902 L
.63669 .30902 L
.63745 .30902 L
.63787 .30902 L
.63833 .30902 L
.63874 .30902 L
.63913 .30902 L
.63949 .30902 L
.63989 .30902 L
.6401 .30902 L
.64032 .30902 L
.64053 .30902 L
.64072 .30902 L
.64092 .30902 L
.64103 .30902 L
.64114 .30902 L
.64124 .30902 L
.64134 .30902 L
.64143 .30902 L
.64153 .30902 L
.64163 .30902 L
.64169 .30902 L
.64174 .30902 L
.64185 .30902 L
.64195 .30902 L
.642 .30902 L
.64206 .30902 L
.64217 .30902 L
.64228 .30902 L
.64241 .30902 L
.6428 .30902 L
.64322 .30902 L
.64396 .30902 L
.64477 .30902 L
.64563 .30902 L
.64606 .30902 L
.64646 .30902 L
.64685 .30902 L
.64721 .30902 L
.64756 .30902 L
.64792 .30902 L
.64829 .30902 L
.64849 .30902 L
.64869 .30902 L
Mistroke
.64889 .30902 L
.64909 .30902 L
.6492 .30902 L
.6493 .30902 L
.64935 .30902 L
.64941 .30902 L
.64947 .30902 L
.64952 .30902 L
.64962 .30902 L
.64972 .30902 L
.64982 .30902 L
.64988 .30902 L
.64993 .30902 L
.65003 .30902 L
.65013 .30902 L
.65031 .30902 L
.65069 .30902 L
.65109 .30902 L
.6518 .30902 L
.65255 .30902 L
.65337 .30902 L
.65374 .30902 L
.65413 .30902 L
.65483 .30902 L
.65524 .30902 L
.6556 .30902 L
.6558 .30902 L
.65602 .30902 L
.65621 .30902 L
.65642 .30902 L
.6566 .30902 L
.65679 .30902 L
.6569 .30902 L
.657 .30902 L
.6571 .30902 L
.65719 .30902 L
.65728 .30902 L
.65736 .30902 L
.65745 .30902 L
.65755 .30902 L
.65763 .30902 L
.65773 .30902 L
.65781 .30902 L
.65789 .30902 L
.658 .30902 L
.65809 .30902 L
.65827 .30902 L
.65868 .30902 L
.65941 .30902 L
.66021 .30902 L
Mistroke
.66107 .30902 L
.66183 .30902 L
.66227 .30902 L
.66267 .30902 L
.66304 .30902 L
.66338 .30902 L
.66357 .30902 L
.66378 .30902 L
.66415 .30902 L
.66436 .30902 L
.66458 .30902 L
.66468 .30902 L
.66479 .30902 L
.66488 .30902 L
.66498 .30902 L
.66508 .30902 L
.66516 .30902 L
.66525 .30902 L
.66534 .30902 L
.66544 .30902 L
.66553 .30902 L
.66562 .30902 L
.66573 .30902 L
.66583 .30902 L
.66593 .30902 L
.66614 .30902 L
.66653 .30902 L
.66741 .30902 L
.66821 .30902 L
.66906 .30902 L
.66947 .30902 L
.66986 .30902 L
.67021 .30902 L
.67059 .30902 L
.67096 .30902 L
.67136 .30902 L
.67153 .30902 L
.67172 .30902 L
.67206 .30902 L
.67226 .30902 L
.67237 .30902 L
.67249 .30902 L
.6726 .30902 L
.6727 .30902 L
.6728 .30902 L
.67289 .30902 L
.67298 .30902 L
.67308 .30902 L
.67318 .30902 L
.67323 .30902 L
Mistroke
.67328 .30902 L
.67338 .30902 L
.67346 .30902 L
.67356 .30902 L
.67365 .30902 L
.67384 .30902 L
.67402 .30902 L
.67443 .30902 L
.67525 .30902 L
.67596 .30902 L
.67673 .30902 L
.67752 .30902 L
.67795 .30902 L
.67835 .30902 L
.67873 .30902 L
.67907 .30902 L
.67926 .30902 L
.67947 .30902 L
.67984 .30902 L
.68003 .30902 L
.68023 .30902 L
.68033 .30902 L
.68043 .30902 L
.68051 .30902 L
.6806 .30902 L
.6807 .30902 L
.68076 .30902 L
.68081 .30902 L
.6809 .30902 L
.681 .30902 L
.68105 .30902 L
.68111 .30902 L
.68117 .30902 L
.68123 .30902 L
.68133 .30902 L
.68144 .30902 L
.68166 .30902 L
.68189 .30902 L
.68232 .30902 L
.68313 .30902 L
.68395 .30902 L
.68472 .30902 L
.68552 .30902 L
.68595 .30902 L
.68641 .30902 L
.68661 .30902 L
.68683 .30902 L
.68722 .30902 L
.68746 .30902 L
.68768 .30902 L
Mistroke
.68789 .30902 L
.688 .30902 L
.68811 .30902 L
.6882 .30902 L
.6883 .30902 L
.68839 .30902 L
.68848 .30902 L
.68858 .30902 L
.68864 .30902 L
.68869 .30902 L
.68879 .30902 L
.68889 .30902 L
.68899 .30902 L
.68909 .30902 L
.68928 .30902 L
.68972 .30902 L
.6913 .30902 L
.69173 .30902 L
.69219 .30902 L
.69302 .30902 L
.69343 .30902 L
.69388 .30902 L
.6943 .30902 L
.6945 .30902 L
.69469 .30902 L
.69504 .30902 L
.69522 .30902 L
.69542 .30902 L
.69552 .30902 L
.69563 .30902 L
.69573 .30902 L
.69583 .30902 L
.69593 .30902 L
.69602 .30902 L
.69612 .30902 L
.6962 .30902 L
.6963 .30902 L
.6964 .30902 L
.69649 .30902 L
.69658 .30902 L
.69668 .30902 L
.69679 .30902 L
.69699 .30902 L
.69782 .30902 L
.6993 .30902 L
.70006 .30902 L
.70049 .30902 L
.70089 .30902 L
.70132 .30902 L
.70171 .30902 L
Mistroke
.70192 .30902 L
.70215 .30902 L
.70236 .30902 L
.70258 .30902 L
.7028 .30902 L
.70301 .30902 L
.7032 .30902 L
.7033 .30902 L
.70341 .30902 L
.7035 .30902 L
.70359 .30902 L
.7037 .30902 L
.7038 .30902 L
.70389 .30902 L
.70397 .30902 L
.70406 .30902 L
.70416 .30902 L
.70426 .30902 L
.70436 .30902 L
.70457 .30902 L
.70496 .30902 L
.70584 .30902 L
.70657 .30902 L
.70736 .30902 L
.70781 .30902 L
.70822 .30902 L
.70863 .30902 L
.70902 .30902 L
.70939 .30902 L
.7098 .30902 L
.71 .30902 L
.71022 .30902 L
.71043 .30902 L
.71062 .30902 L
.71072 .30902 L
.71081 .30902 L
.7109 .30902 L
.71099 .30902 L
.71104 .30902 L
.71109 .30902 L
.7112 .30902 L
.71129 .30902 L
.71138 .30902 L
.71147 .30902 L
.71156 .30902 L
.71165 .30902 L
.71173 .30902 L
.71192 .30902 L
.7121 .30902 L
.71357 .30902 L
Mistroke
.7144 .30902 L
.71481 .30902 L
.71518 .30902 L
.71555 .30902 L
.71595 .30902 L
.71635 .30902 L
.71677 .30902 L
.71699 .30902 L
.7172 .30902 L
.71741 .30902 L
.71765 .30902 L
.71786 .30902 L
.71806 .30902 L
.71826 .30902 L
.71835 .30902 L
.71846 .30902 L
.71856 .30902 L
.71866 .30902 L
.71877 .30902 L
.71883 .30902 L
.71888 .30902 L
.71898 .30902 L
.71903 .30902 L
.71908 .30902 L
.71918 .30902 L
.71928 .30902 L
.71946 .30902 L
.71963 .30902 L
.72002 .30902 L
.72088 .30902 L
.7217 .30902 L
.72249 .30902 L
.72293 .30902 L
.72334 .30902 L
.72368 .30902 L
.72406 .30902 L
.72425 .30902 L
.72446 .30902 L
.72483 .30902 L
.72503 .30902 L
.72525 .30902 L
.72545 .30902 L
.72564 .30902 L
.72575 .30902 L
.72586 .30902 L
.72597 .30902 L
.72603 .30902 L
.7261 .30902 L
.72615 .30902 L
.7262 .30902 L
Mistroke
.72626 .30902 L
.72632 .30902 L
.72642 .30902 L
.72647 .30902 L
.72653 .30902 L
.72662 .30902 L
.72672 .30902 L
.7269 .30902 L
.72731 .30902 L
.72814 .30902 L
.72897 .30902 L
.72975 .30902 L
.73014 .30902 L
.73056 .30902 L
.73102 .30902 L
.73144 .30902 L
.73183 .30902 L
.73203 .30902 L
.73224 .30902 L
.73242 .30902 L
.73262 .30902 L
.73281 .30902 L
.73298 .30902 L
.73308 .30902 L
.73319 .30902 L
.7333 .30902 L
.73339 .30902 L
.73345 .30902 L
.7335 .30902 L
.73356 .30902 L
.73362 .30902 L
.73372 .30902 L
.73378 .30902 L
.73384 .30902 L
.73394 .30902 L
.73404 .30902 L
.73423 .30902 L
.73443 .30902 L
.73465 .30902 L
.73621 .30902 L
.73663 .30902 L
.73709 .30902 L
.73749 .30902 L
.73793 .30902 L
.73834 .30902 L
.73873 .30902 L
.73914 .30902 L
.73937 .30902 L
.73957 .30902 L
.73975 .30902 L
Mistroke
.73995 .30902 L
.74016 .30902 L
.74035 .30902 L
.74044 .30902 L
.74053 .30902 L
.74061 .30902 L
.7407 .30902 L
.7408 .30902 L
.7409 .30902 L
.74099 .30902 L
.74108 .30902 L
.74118 .30902 L
.74128 .30902 L
.74136 .30902 L
.74145 .30902 L
.74166 .30902 L
.74185 .30902 L
.74258 .30902 L
.74343 .30902 L
.74423 .30902 L
.74502 .30902 L
.74546 .30902 L
.74587 .30902 L
.74622 .30902 L
.74659 .30902 L
.74679 .30902 L
.74699 .30902 L
.74719 .30902 L
.74736 .30902 L
.74757 .30902 L
.74768 .30902 L
.74778 .30902 L
.74787 .30902 L
.74797 .30902 L
.74808 .30902 L
.74817 .30902 L
.74828 .30902 L
.74834 .30902 L
.74839 .30902 L
.7485 .30902 L
.7486 .30902 L
.74865 .30902 L
.74871 .30902 L
.74882 .30902 L
.74906 .30902 L
.75067 .30902 L
.75143 .30902 L
.75182 .30902 L
.75224 .30902 L
.7526 .30902 L
Mistroke
.753 .30902 L
.75337 .30902 L
.7537 .30902 L
.75411 .30902 L
.75434 .30902 L
.75455 .30902 L
.75473 .30902 L
.75494 .30902 L
.75504 .30902 L
.75515 .30902 L
.75525 .30902 L
.75535 .30902 L
.75544 .30902 L
.75554 .30902 L
.75563 .30902 L
.75571 .30902 L
.75581 .30902 L
.75587 .30902 L
.75592 .30902 L
.75611 .30902 L
.75628 .30902 L
.75647 .30902 L
.75684 .30902 L
.75771 .30902 L
.75854 .30902 L
.75928 .30902 L
.7597 .30902 L
.76009 .30902 L
.76046 .30902 L
.76081 .30902 L
.7612 .30902 L
.76141 .30902 L
.76161 .30902 L
.76181 .30902 L
.762 .30902 L
.76221 .30902 L
.76233 .30902 L
.76243 .30902 L
.76253 .30902 L
.76263 .30902 L
.76273 .30902 L
.76278 .30902 L
.76284 .30902 L
.76293 .30902 L
.76303 .30902 L
.76313 .30902 L
.76322 .30902 L
.7634 .30902 L
.7636 .30902 L
.76401 .30902 L
Mistroke
.76475 .30902 L
.76562 .30902 L
.766 .30902 L
.76642 .30902 L
.76678 .30902 L
.76717 .30902 L
.76758 .30902 L
.76797 .30902 L
.76818 .30902 L
.76842 .30902 L
.76864 .30902 L
.76884 .30902 L
.76903 .30902 L
.76923 .30902 L
.76933 .30902 L
.76944 .30902 L
.76955 .30902 L
.76964 .30902 L
.76974 .30902 L
.76984 .30902 L
.76993 .30902 L
.77002 .30902 L
.77013 .30902 L
.77018 .30902 L
.77024 .30902 L
.77034 .30902 L
.77043 .30902 L
.77079 .30902 L
.77117 .30902 L
.77203 .30902 L
.77283 .30902 L
.77365 .30902 L
.77408 .30902 L
.77454 .30902 L
.77493 .30902 L
.77531 .30902 L
.77552 .30902 L
.77571 .30902 L
.77593 .30902 L
.77615 .30902 L
.77625 .30902 L
.77636 .30902 L
.77646 .30902 L
.77656 .30902 L
.77665 .30902 L
.77675 .30902 L
.77684 .30902 L
.77692 .30902 L
.77703 .30902 L
.77713 .30902 L
Mistroke
.77722 .30902 L
.77732 .30902 L
.77737 .30902 L
.77742 .30902 L
.77754 .30902 L
.77774 .30902 L
.7785 .30902 L
.77922 .30902 L
.78 .30902 L
.78043 .30902 L
.78083 .30902 L
.7812 .30902 L
.78154 .30902 L
.78192 .30902 L
.78211 .30902 L
.78232 .30902 L
.78271 .30902 L
.78292 .30902 L
.78312 .30902 L
.7833 .30902 L
.78347 .30902 L
.78357 .30902 L
.78367 .30902 L
.78376 .30902 L
.78385 .30902 L
.78396 .30902 L
.78402 .30902 L
.78407 .30902 L
.78417 .30902 L
.78428 .30902 L
.78437 .30902 L
.78446 .30902 L
.78456 .30902 L
.78466 .30902 L
.78511 .30902 L
.78552 .30902 L
.78633 .30902 L
.78718 .30902 L
.78791 .30902 L
.78833 .30902 L
.78872 .30902 L
.7891 .30902 L
.7893 .30902 L
.78949 .30902 L
.78983 .30902 L
.79001 .30902 L
.7902 .30902 L
.79041 .30902 L
.79052 .30902 L
.79063 .30902 L
Mistroke
.79073 .30902 L
.79083 .30902 L
.79093 .30902 L
.79098 .30902 L
.79104 .30902 L
.79114 .30902 L
.79119 .30902 L
.79124 .30902 L
.79134 .30902 L
.79144 .30902 L
.79153 .30902 L
.79163 .30902 L
.7918 .30902 L
.79328 .30902 L
.79412 .30902 L
.79452 .30902 L
.7949 .30902 L
.7953 .30902 L
.79567 .30902 L
.79607 .30902 L
.79629 .30902 L
.7965 .30902 L
.79669 .30902 L
.79689 .30902 L
.79711 .30902 L
.79732 .30902 L
.79754 .30902 L
.79765 .30902 L
.79778 .30902 L
.79788 .30902 L
.79794 .30902 L
.79799 .30902 L
.7981 .30902 L
.79819 .30902 L
.79829 .30902 L
.79839 .30902 L
.79848 .30902 L
.79857 .30902 L
.79878 .30902 L
.79898 .30902 L
.7998 .30902 L
.80051 .30902 L
.80091 .30902 L
.80128 .30902 L
.80169 .30902 L
.80206 .30902 L
.80245 .30902 L
.80288 .30902 L
.80322 .30902 L
.8036 .30902 L
Mistroke
.80379 .30902 L
.80399 .30902 L
.80419 .30902 L
.80436 .30902 L
.80454 .30902 L
.80465 .30902 L
.80475 .30902 L
.80485 .30902 L
.80495 .30902 L
.805 .30902 L
.80506 .30902 L
.80516 .30902 L
.80526 .30902 L
.80534 .30902 L
.80545 .30902 L
.80554 .30902 L
.80571 .30902 L
.8059 .30902 L
.80669 .30902 L
.80757 .30902 L
.80797 .30902 L
.80839 .30902 L
.80877 .30902 L
.80917 .30902 L
.80962 .30902 L
.80983 .30902 L
.81005 .30902 L
.81025 .30902 L
.81047 .30902 L
.81067 .30902 L
.81086 .30902 L
.81105 .30902 L
.81125 .30902 L
.81146 .30902 L
.81157 .30902 L
.81167 .30902 L
.81177 .30902 L
.81185 .30902 L
.81195 .30902 L
.81205 .30902 L
.81214 .30902 L
.81222 .30902 L
.81232 .30902 L
.81241 .30902 L
.81253 .30902 L
.81263 .30902 L
.81286 .30902 L
.81329 .30902 L
.81409 .30902 L
.8145 .30902 L
Mistroke
.81494 .30902 L
.81533 .30902 L
.81574 .30902 L
.81611 .30902 L
.81652 .30902 L
.81689 .30902 L
.81724 .30902 L
.81745 .30902 L
.81764 .30902 L
.81785 .30902 L
.81808 .30902 L
.81827 .30902 L
.81846 .30902 L
.81856 .30902 L
.81866 .30902 L
.81871 .30902 L
.81877 .30902 L
.81887 .30902 L
.81897 .30902 L
.81907 .30902 L
.81916 .30902 L
.81925 .30902 L
.81935 .30902 L
.81946 .30902 L
.81965 .30902 L
.82036 .30902 L
.82118 .30902 L
.82159 .30902 L
.82196 .30902 L
.82265 .30902 L
.82302 .30902 L
.82341 .30902 L
.8238 .30902 L
.82416 .30902 L
.82436 .30902 L
.82455 .30902 L
.82476 .30902 L
.82498 .30902 L
.82518 .30902 L
.82529 .30902 L
.82539 .30902 L
.82549 .30902 L
.82559 .30902 L
.82569 .30902 L
.82578 .30902 L
.82588 .30902 L
.82598 .30902 L
.82604 .30902 L
.82609 .30902 L
.8262 .30902 L
Mistroke
.82632 .30902 L
.82644 .30902 L
.82666 .30902 L
.82754 .30902 L
.82837 .30902 L
.82912 .30902 L
.82954 .30902 L
.82992 .30902 L
.8303 .30902 L
.83065 .30902 L
.83104 .30902 L
.83125 .30902 L
.83145 .30902 L
.83166 .30902 L
.83185 .30902 L
.83206 .30902 L
.83216 .30902 L
.83228 .30902 L
.83238 .30902 L
.83248 .30902 L
.83258 .30902 L
.83263 .30902 L
.83269 .30902 L
.83278 .30902 L
.83288 .30902 L
.83298 .30902 L
.83307 .30902 L
.83325 .30902 L
.83346 .30902 L
.83387 .30902 L
.83461 .30902 L
.83506 .30902 L
.83548 .30902 L
.8359 .30902 L
.83628 .30902 L
.83664 .30902 L
.83703 .30902 L
.83741 .30902 L
.83764 .30902 L
.83784 .30902 L
.83805 .30902 L
.83826 .30902 L
.83845 .30902 L
.83865 .30902 L
.83876 .30902 L
.83887 .30902 L
.83899 .30902 L
.8391 .30902 L
.83921 .30902 L
.8393 .30902 L
Mistroke
.83941 .30902 L
.83946 .30902 L
.83952 .30902 L
.83962 .30902 L
.83972 .30902 L
.83983 .30902 L
.83994 .30902 L
.84033 .30902 L
.84108 .30902 L
.84195 .30902 L
.84276 .30902 L
.84316 .30902 L
.84358 .30902 L
.84401 .30902 L
.84425 .30902 L
.84447 .30902 L
.84468 .30902 L
.84488 .30902 L
.84506 .30902 L
.84526 .30902 L
.84547 .30902 L
.84557 .30902 L
.84569 .30902 L
.84579 .30902 L
.84584 .30902 L
.8459 .30902 L
.846 .30902 L
.84609 .30902 L
.84619 .30902 L
.84625 .30902 L
.8463 .30902 L
.8464 .30902 L
.8465 .30902 L
.84659 .30902 L
.84667 .30902 L
.84686 .30902 L
.84768 .30902 L
.84838 .30902 L
.84915 .30902 L
.84959 .30902 L
.84999 .30902 L
.85037 .30902 L
.85057 .30902 L
.85078 .30902 L
.85099 .30902 L
.85119 .30902 L
.85137 .30902 L
.85156 .30902 L
.85173 .30902 L
.85191 .30902 L
Mistroke
.8521 .30902 L
.85227 .30902 L
.85237 .30902 L
.85248 .30902 L
.85253 .30902 L
.85259 .30902 L
.8527 .30902 L
.8528 .30902 L
.8529 .30902 L
.85299 .30902 L
.85309 .30902 L
.85315 .30902 L
.85321 .30902 L
.85331 .30902 L
.85355 .30902 L
.85398 .30902 L
.85477 .30902 L
.85519 .30902 L
.8556 .30902 L
.856 .30902 L
.85636 .30902 L
.85677 .30902 L
.85721 .30902 L
.85757 .30902 L
.85778 .30902 L
.85797 .30902 L
.85832 .30902 L
.85849 .30902 L
.85869 .30902 L
.85888 .30902 L
.85898 .30902 L
.85908 .30902 L
.85919 .30902 L
.85928 .30902 L
.85934 .30902 L
.85939 .30902 L
.8595 .30902 L
.85959 .30902 L
.85969 .30902 L
.85979 .30902 L
.85988 .30902 L
.85997 .30902 L
.86006 .30902 L
.86024 .30902 L
.86111 .30902 L
.86191 .30902 L
.86265 .30902 L
.86307 .30902 L
.86344 .30902 L
.86385 .30902 L
Mistroke
.86408 .30902 L
.8643 .30902 L
.86469 .30902 L
.86489 .30902 L
.8651 .30902 L
.86531 .30902 L
.86541 .30902 L
.86553 .30902 L
.86562 .30902 L
.86573 .30902 L
.86583 .30902 L
.86592 .30902 L
.86602 .30902 L
.86611 .30902 L
.86619 .30902 L
.86628 .30902 L
.86638 .30902 L
.86649 .30902 L
.86658 .30902 L
.86667 .30902 L
.86689 .30902 L
.86709 .30902 L
.86754 .30902 L
.86835 .30902 L
.86873 .30902 L
.86913 .30902 L
.86948 .30902 L
.86986 .30902 L
.87009 .30902 L
.8703 .30902 L
.87053 .30902 L
.87073 .30902 L
.87111 .30902 L
.87132 .30902 L
.87152 .30902 L
.87171 .30902 L
.87189 .30902 L
.87209 .30902 L
.8722 .30902 L
.8723 .30902 L
.87241 .30902 L
.87251 .30902 L
.87262 .30902 L
.87267 .30902 L
.87273 .30902 L
.87283 .30902 L
.87289 .30902 L
.87294 .30902 L
.87304 .30902 L
.87313 .30902 L
Mistroke
.87323 .30902 L
.87331 .30902 L
.8735 .30902 L
.87384 .30902 L
.87462 .30902 L
.87537 .30902 L
.87578 .30902 L
.87616 .30902 L
.87658 .30902 L
.87682 .30902 L
.87703 .30902 L
.87742 .30902 L
.87763 .30902 L
.87783 .30902 L
.87801 .30902 L
.8782 .30902 L
.87841 .30902 L
.87861 .30902 L
.87871 .30902 L
.87882 .30902 L
.87893 .30902 L
.87904 .30902 L
.87914 .30902 L
.87923 .30902 L
.87933 .30902 L
.87943 .30902 L
.87952 .30902 L
.87961 .30902 L
.87971 .30902 L
.8798 .30902 L
.87996 .30902 L
.88014 .30902 L
.88091 .30902 L
.88172 .30902 L
.88215 .30902 L
.88261 .30902 L
.88305 .30902 L
.88345 .30902 L
.88364 .30902 L
.88385 .30902 L
.88422 .30902 L
.88441 .30902 L
.88462 .30902 L
.88481 .30902 L
.88499 .30902 L
.88519 .30902 L
.88531 .30902 L
.88542 .30902 L
.88551 .30902 L
.88562 .30902 L
Mistroke
.88567 .30902 L
.88573 .30902 L
.88583 .30902 L
.88588 .30902 L
.88593 .30902 L
.88603 .30902 L
.88609 .30902 L
.88615 .30902 L
.8862 .30902 L
.88626 .30902 L
.88637 .30902 L
.88649 .30902 L
.88671 .30902 L
.88752 .30902 L
.88828 .30902 L
.8887 .30902 L
.88909 .30902 L
.88946 .30902 L
.88986 .30902 L
.89023 .30902 L
.89056 .30902 L
.89076 .30902 L
.89093 .30902 L
.89113 .30902 L
.89134 .30902 L
.89152 .30902 L
.89169 .30902 L
.89187 .30902 L
.89197 .30902 L
.89206 .30902 L
.89216 .30902 L
.89221 .30902 L
.89227 .30902 L
.89237 .30902 L
.89247 .30902 L
.89252 .30902 L
.89258 .30902 L
.89268 .30902 L
.89274 .30902 L
.89279 .30902 L
.89291 .30902 L
.89311 .30902 L
.8933 .30902 L
.89371 .30902 L
.89447 .30902 L
.89526 .30902 L
.89567 .30902 L
.89613 .30902 L
.89654 .30902 L
.89693 .30902 L
Mistroke
.89714 .30902 L
.89733 .30902 L
.89755 .30902 L
.89777 .30902 L
.89797 .30902 L
.89815 .30902 L
.89835 .30902 L
.89846 .30902 L
.89857 .30902 L
.89865 .30902 L
.89875 .30902 L
.89883 .30902 L
.89891 .30902 L
.89901 .30902 L
.89911 .30902 L
.8992 .30902 L
.89929 .30902 L
.89947 .30902 L
.89966 .30902 L
.90006 .30902 L
.90086 .30902 L
.90162 .30902 L
.90204 .30902 L
.90249 .30902 L
.90291 .30902 L
.90329 .30902 L
.90351 .30902 L
.9037 .30902 L
.90392 .30902 L
.90415 .30902 L
.90434 .30902 L
.90453 .30902 L
.90473 .30902 L
.90484 .30902 L
.90495 .30902 L
.90504 .30902 L
.90514 .30902 L
.90522 .30902 L
.90531 .30902 L
.90541 .30902 L
.90547 .30902 L
.90552 .30902 L
.90562 .30902 L
.90571 .30902 L
.9058 .30902 L
.90589 .30902 L
.90606 .30902 L
.90644 .30902 L
.90722 .30902 L
.90804 .30902 L
Mistroke
.90847 .30902 L
.90895 .30902 L
.90915 .30902 L
.90938 .30902 L
.90978 .30902 L
.90999 .30902 L
.91019 .30902 L
.91041 .30902 L
.91064 .30902 L
.91084 .30902 L
.91103 .30902 L
.91114 .30902 L
.91124 .30902 L
.91135 .30902 L
.91146 .30902 L
.91156 .30902 L
.91164 .30902 L
.91174 .30902 L
.91184 .30902 L
.91193 .30902 L
.91201 .30902 L
.9121 .30902 L
.91219 .30902 L
.91239 .30902 L
.91257 .30902 L
.91299 .30902 L
.91383 .30902 L
.91424 .30902 L
.91462 .30902 L
.91499 .30902 L
.91533 .30902 L
.91571 .30902 L
.9159 .30902 L
.91611 .30902 L
.9165 .30902 L
.91671 .30902 L
.91691 .30902 L
.9171 .30902 L
.91727 .30902 L
.91737 .30902 L
.91747 .30902 L
.91766 .30902 L
.91776 .30902 L
.91786 .30902 L
.91796 .30902 L
.91802 .30902 L
.91808 .30902 L
.91818 .30902 L
.91824 .30902 L
.9183 .30902 L
Mistroke
.91835 .30902 L
.91841 .30902 L
.91847 .30902 L
.91852 .30902 L
.91862 .30902 L
.91873 .30902 L
.91891 .30902 L
.91933 .30902 L
.92014 .30902 L
.92055 .30902 L
.92092 .30902 L
.92125 .30902 L
.92161 .30902 L
.92198 .30902 L
.92218 .30902 L
.92237 .30902 L
.92276 .30902 L
.92296 .30902 L
.92318 .30902 L
.92336 .30902 L
.92354 .30902 L
.92373 .30902 L
.92394 .30902 L
.92405 .30902 L
.92415 .30902 L
.92427 .30902 L
.92432 .30902 L
.92439 .30902 L
.92444 .30902 L
.92449 .30902 L
.92455 .30902 L
.92461 .30902 L
.92471 .30902 L
.92476 .30902 L
.92481 .30902 L
.92492 .30902 L
.92502 .30902 L
.9252 .30902 L
.92561 .30902 L
.92633 .30902 L
.92709 .30902 L
.92753 .30902 L
.92793 .30902 L
.92833 .30902 L
.92871 .30902 L
.9289 .30902 L
.92911 .30902 L
.92928 .30902 L
.92947 .30902 L
.92968 .30902 L
Mistroke
.92987 .30902 L
.92998 .30902 L
.9301 .30902 L
.93021 .30902 L
.93031 .30902 L
.93041 .30902 L
.93051 .30902 L
.93057 .30902 L
.93062 .30902 L
.93073 .30902 L
.93082 .30902 L
.93092 .30902 L
.93102 .30902 L
.93112 .30902 L
.93117 .30902 L
.93123 .30902 L
.93134 .30902 L
.93154 .30902 L
.932 .30902 L
.93282 .30902 L
.93358 .30902 L
.93401 .30902 L
.93447 .30902 L
.93467 .30902 L
.93488 .30902 L
.93527 .30902 L
.93547 .30902 L
.93567 .30902 L
.93584 .30902 L
.93603 .30902 L
.93623 .30902 L
.93642 .30902 L
.93653 .30902 L
.93662 .30902 L
.93673 .30902 L
.93685 .30902 L
.93694 .30902 L
.93704 .30902 L
.93713 .30902 L
.93719 .30902 L
.93724 .30902 L
.93733 .30902 L
.93743 .30902 L
.93753 .30902 L
.93762 .30902 L
.93778 .30902 L
.93796 .30902 L
.93832 .30902 L
.93912 .30902 L
.93988 .30902 L
Mistroke
.9403 .30902 L
.94076 .30902 L
.94096 .30902 L
.94118 .30902 L
.94156 .30902 L
.94175 .30902 L
.94195 .30902 L
.94213 .30902 L
.94231 .30902 L
.94251 .30902 L
.9427 .30902 L
.94281 .30902 L
.94292 .30902 L
.94302 .30902 L
.94312 .30902 L
.94321 .30902 L
.9433 .30902 L
.94339 .30902 L
.94349 .30902 L
.9436 .30902 L
.9437 .30902 L
.94379 .30902 L
.94389 .30902 L
.94406 .30902 L
.94425 .30902 L
.94459 .30902 L
.94542 .30902 L
.94585 .30902 L
.94631 .30902 L
.94671 .30902 L
.94693 .30902 L
.94715 .30902 L
.94736 .30902 L
.94756 .30902 L
.94793 .30902 L
.94811 .30902 L
.94832 .30902 L
.94853 .30902 L
.94873 .30902 L
.94891 .30902 L
.94908 .30902 L
.94917 .30902 L
.94927 .30902 L
.94937 .30902 L
.94946 .30902 L
.94957 .30902 L
.94963 .30902 L
.94968 .30902 L
.94978 .30902 L
.94989 .30902 L
Mistroke
.94998 .30902 L
.95007 .30902 L
.95017 .30902 L
.95027 .30902 L
.95113 .30902 L
.95194 .30902 L
.95241 .30902 L
.95283 .30902 L
.95324 .30902 L
.95361 .30902 L
.95382 .30902 L
.95404 .30902 L
.95424 .30902 L
.95445 .30902 L
.95465 .30902 L
.95484 .30902 L
.95503 .30902 L
.95521 .30902 L
.95531 .30902 L
.95542 .30902 L
.95551 .30902 L
.95561 .30902 L
.95572 .30902 L
.95578 .30902 L
.95584 .30902 L
.95589 .30902 L
.95595 .30902 L
.95605 .30902 L
.95611 .30902 L
.95617 .30902 L
.95622 .30902 L
.95627 .30902 L
.95648 .30902 L
.9567 .30902 L
.95693 .30902 L
.95774 .30902 L
.9585 .30902 L
.95893 .30902 L
.95932 .30902 L
.95968 .30902 L
.95987 .30902 L
.96008 .30902 L
.96025 .30902 L
.96045 .30902 L
.96079 .30902 L
.96098 .30902 L
.96119 .30902 L
.96129 .30902 L
.9614 .30902 L
.9615 .30902 L
Mistroke
.9616 .30902 L
.96171 .30902 L
.9618 .30902 L
.96189 .30902 L
.96199 .30902 L
.96208 .30902 L
.96216 .30902 L
.96225 .30902 L
.96234 .30902 L
.9624 .30902 L
.96245 .30902 L
.96256 .30902 L
.96279 .30902 L
.96322 .30902 L
.96402 .30902 L
.96442 .30902 L
.96485 .30902 L
.96531 .30902 L
.96552 .30902 L
.96574 .30902 L
.96595 .30902 L
.96614 .30902 L
.96651 .30902 L
.96672 .30902 L
.96695 .30902 L
.96716 .30902 L
.96736 .30902 L
.96745 .30902 L
.96755 .30902 L
.96773 .30902 L
.96783 .30902 L
.96792 .30902 L
.96803 .30902 L
.96808 .30902 L
.96813 .30902 L
.96823 .30902 L
.96831 .30902 L
.96841 .30902 L
.96851 .30902 L
.96859 .30902 L
.96868 .30902 L
.96886 .30902 L
.96928 .30902 L
.96966 .30902 L
.97007 .30902 L
.97051 .30902 L
.97089 .30902 L
.97131 .30902 L
.97169 .30902 L
.97204 .30902 L
Mistroke
.97225 .30902 L
.97246 .30902 L
.97265 .30902 L
.97285 .30902 L
.97306 .30902 L
.97326 .30902 L
.97338 .30902 L
.97349 .30902 L
.9736 .30902 L
.97371 .30902 L
.97386 .30902 L
.97401 .30902 L
.9741 .30902 L
.97418 .30902 L
.97425 .30902 L
.97434 .30902 L
.97442 .30902 L
.9745 .30902 L
.97459 .30902 L
.97468 .30902 L
.97476 .30902 L
.97483 .30902 L
.975 .30902 L
.97558 .30902 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{421.375, 260.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008>0001AB000`400?l00000o`00003ooooooooo
oooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo
003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooo
oooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool0
0?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooooooo
ool@ooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooo
ooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0oooo
oonhooooo`00<?ooool3o`00023ooooo0_l0003ooooook[ooooo000`ooooo`03o`000?oooooooooo
023ooooo0_l0003ooooook[ooooo000`ooooo`03o`000?oooooooooo023ooooo0_l0003ooooook[o
oooo000`ooooo`03o`000?oooooooooo023ooooo0_l0003ooooook[ooooo000`ooooo`03o`000?oo
oooooooo023ooooo0_l0003ooooook[ooooo000`ooooo`03o`000?oooooooooo023ooooo0_l0003o
oooook[ooooo000`ooooo`03o`000?oooooooooo023ooooo0_l0003ooooook[ooooo000`ooooo`03
o`000?oooooooooo023ooooo0_l0003ooooook[ooooo000`ooooo`03o`000?oooooooooo023ooooo
0_l0003ooooook[ooooo000`ooooo`03o`000?oooooooooo023ooooo0_l0003ooooook[ooooo000`
ooooo`03o`000?oooooooooo023ooooo0_l0003ooooook[ooooo000`ooooo`03o`000?oooooooooo
023ooooo0_l0003ooooook[ooooo000`ooooo`?o00008?ooool2o`000?oooooo^_ooool0033ooooo
00?o0000ooooooooool08?ooool2o`000?oooooo^_ooool0033ooooo00?o0000ooooooooool08?oo
ool2o`000?oooooo^_ooool0033ooooo00?o0000ooooooooool08?ooool2o`000?oooooo^_ooool0
033ooooo00?o0000ooooooooool08?ooool2o`000?oooooo^_ooool0033ooooo00?o0000oooooooo
ool08?ooool2o`000?oooooo^_ooool0033ooooo00?o0000ooooooooool08?ooool2o`000?oooooo
^_ooool0033ooooo00?o0000ooooooooool07oooool00ol0003oooooo`00003ooooook[ooooo000`
ooooo`03o`000?oooooooooo01oooooo00?o0000ooooool00000oooooonjooooo`00<?ooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooo00000?oooooo^_ooool0033ooooo00?o0000oooooooo
ool07oooool00ol0003oooooo`00003ooooook[ooooo000`ooooo`?o00007oooool00ol0003ooooo
o`00003ooooook[ooooo000`ooooo`03o`000?oooooooooo01oooooo00?o0000ooooool00000oooo
oonjooooo`00<?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo00000?oooooo^_ooool0
033ooooo00?o0000ooooooooool07oooool00ol0003oooooo`00003ooooook[ooooo000`ooooo`03
o`000?oooooooooo01oooooo00Co0000oooooooooooo0000ooooooniooooo`00<?ooool00ol0003o
ooooooooo`0Oooooo`04o`000?ooooooooooo`000?oooooo^Oooool0033ooooo00?o0000oooooooo
ool07oooool01?l0003oooooooooool0003ooooookWooooo000@ooooo`;ok^k^0oooool2onk^kQWo
oooo00?o0000ooooooooool07oooool01?l0003oooooooooool0003ooooookWooooo000;ooooo`;o
000000[o410@ooooooooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^0oooool4o`000008oa0@
4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h:ooooo`03o`000?oooooooooo01oooooo00Co0000
oooooooooooo0000ooooooniooooo`003?ooool00ol0003oooooooooo`02ooooo`05onk^k_mEEEGo
gMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2_ooool00ol0003oooooooooo`0Oooooo`04o`000?ooooooooooo`000?oooooo^Oooool00003oooo
ool0003o000000Co00000_ooool5o`0000Cooooo00?ogMgMo`000?oMgMd01oooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41002_ooool00ol0003oooooooooo`0Oooooo`04
o`000?ooooooooooo`000?oooooo^Oooool000Wooooo00CoA4A4omgMgOoooooo00001?ooool01Oo^
k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000000[ooooo00?o0000ooooooooool07oooool01?l0003oooooooooool0003ooooookWooooo
0009ooooo`04omgMgOmEEEGoooooo`0000?ooooo00Ook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^
00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000[ooooo1?l0000C
ooooo`;o00002Oooool01?l0003oooooooooool0003ooooookWooooo000:ooooo`03ogMgMoo<c<co
000000?ooooo0_o^k^h3ooooo`;ok^k^1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooo
ooooooooool@41002_ooool00ol0003oooooooooo`0Dooooo`;o00002Oooool01?l0003ooooooooo
ool0003ooooookWooooo000:ooooo`03onk^k_m4A4Co000000oooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo0_l00005ooooo`03o`000?oooooooooo01Cooooo
0_l00009ooooo`04o`000?ooooooooooo`000?oooooo^Oooool000_ooooo00?oMgMgo`000?ooool0
3?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_ooool01?l0003o
ooooooooool00004ooooo`03o`000?oooooooooo01Cooooo0_l00009ooooo`04o`000?oooooooooo
o`000?oooooo^Oooool002Sooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0D
ooooo`;o00002Oooool01?l0003oooooooooool0003ooooookWooooo000Xooooo`?o00001Oooool0
0ol0003oooooooooo`0Dooooo`;o00002Oooool01?l0003oooooooooool00009ooooo`03o`000?oo
oooooooo0?oooooo[Oooool002Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0D
ooooo`;o00002Oooool01?l0003oooooooooool00008ooooo`;o0000oooooon_ooooo`00:_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Cooooo0_l00009ooooo`04o`000?oooooo
ooooo`0000Sooooo0_l0003oooooojoooooo000`ooooo`03o`000?oooooooooo01Cooooo0_l00009
ooooo`04o`000?ooooooooooo`0000Sooooo0_l0003oooooojoooooo000`ooooo`03o`000?oooooo
oooo01Cooooo0_l00009ooooo`04o`000?ooooooooooo`0000Sooooo0_l0003oooooojoooooo000`
ooooo`03o`000?oooooooooo01Cooooo0_l00009ooooo`04o`000?ooooooooooo`0000Sooooo0_l0
003oooooojoooooo000`ooooo`03o`000?oooooooooo01Cooooo0_l00009ooooo`04o`000?oooooo
ooooo`0000Sooooo0_l0003oooooojoooooo000`ooooo`?o00005?ooool2o`0000Wooooo00Co0000
oooooooooooo00002?ooool2o`000?oooooo[oooool0033ooooo00?o0000ooooooooool05?ooool0
0ol0003oooooo`000008ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooo
oon^ooooo`00<?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo000000Sooooo00Co0000
oooooooooooo00002?ooool00ol0003oooooo`00003oooooojkooooo000`ooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooool000002?ooool01?l0003oooooooooool00008ooooo`03o`000?oo
oooo00000?oooooo[_ooool0033ooooo00?o0000ooooooooool05?ooool00ol0003oooooo`000008
ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooon^ooooo`00<?ooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooo000000Sooooo00Co0000oooooooooooo00002?oo
ool00ol0003oooooo`00003oooooojkooooo000`ooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooool000002?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?oooooo[_oo
ool0033ooooo00?o0000ooooooooool04oooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000Sooooo00?o0000ooooool00000oooooon^ooooo`00<?ooool00ol0003ooooooooo
o`0Cooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002?ooool00ol0003o
ooooo`00003oooooojkooooo000`ooooo`03o`000?oooooooooo01?ooooo00Co0000oooooooooooo
00002?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?oooooo[_ooool0033o
oooo00?o0000ooooooooool04oooool01?l0003oooooooooool00008ooooo`04o`000?oooooooooo
o`0000Sooooo00?o0000ooooool00000oooooon^ooooo`00<?ooool00ol0003oooooooooo`0Coooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00
003oooooojkooooo000`ooooo`?o00004oooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000Oooooo00Co0000oooooooooooo0000oooooon^ooooo`00<?ooool00ol0003ooooo
ooooo`0Cooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001oooool01?l0
003oooooooooool0003oooooojkooooo000`ooooo`03o`000?oooooooooo01?ooooo00Co0000oooo
oooooooo00002?ooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`000?oooooo
[_ooool0033ooooo00?o0000ooooooooool04oooool01?l0003oooooooooool00008ooooo`04o`00
0?ooooooooooo`0000Oooooo00Co0000oooooooooooo0000oooooon^ooooo`00<?ooool00ol0003o
ooooooooo`0Cooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001oooool0
1?l0003oooooooooool0003oooooojkooooo000`ooooo`03o`000?oooooooooo01?ooooo00Co0000
oooooooooooo00002?ooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`000?oo
oooo[_ooool0033ooooo00?o0000ooooooooool04oooool01?l0003oooooooooool00008ooooo`04
o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo0000oooooon^ooooo`00<?ooool00ol0
003oooooooooo`0Cooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001ooo
ool01?l0003oooooooooool0003oooooojkooooo000`ooooo`03o`000?oooooooooo01?ooooo00Co
0000oooooooooooo00002?ooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`00
0?oooooo[_ooool0033ooooo00?o0000ooooooooool04oooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo0000oooooon^ooooo`00<?ooool0
0ol0003oooooooooo`0Cooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000
1oooool01?l0003oooooooooool0003oooooojkooooo000`ooooo`?o00004oooool01?l0003ooooo
ooooool00008ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo0000oooooon^
ooooo`00<?ooool00ol0003oooooooooo`0Cooooo`04o`000?ooooooooooo`0000Sooooo00Co0000
oooooooooooo00001oooool01?l0003oooooooooool0003oooooojkooooo000`ooooo`03o`000?oo
oooooooo01?ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00007ooooo`04
o`000?ooooooooooo`000?oooooo[_ooool0033ooooo00?o0000ooooooooool04oooool01?l0003o
ooooooooool00008ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo0000oooo
oon^ooooo`00<?ooool00ol0003oooooooooo`0Cooooo`04o`000?ooooooooooo`0000Sooooo00Co
0000oooooooooooo00001oooool01?l0003oooooooooool0003oooooojkooooo000`ooooo`03o`00
0?oooooooooo01?ooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo0000
00Kooooo00Co0000oooooooooooo0000oooooon^ooooo`00<?ooool00ol0003oooooooooo`0Coooo
o`04o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?oo
ooooooooo`000?oooooo[_ooool0013ooooo0_o^k^h3ooooo`;ok^k^6Oooool00ol0003ooooooooo
o`0Cooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`04ooooo`04o`000?ooooooooooo`000?oooooo[_ooool000Wooooo1Ol00002ooooo`07onk^
k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0
003o<S8bonk^kP[ooooo00?o0000ooooooooool04oooool01?l0003oooooooooool00007ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0003ooooo
ojkooooo0009ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01Oo^k^koEEEEomgMgOmEEEGo
k^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00[ooooo00?o
0000ooooooooool04oooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool01?l0003oooooooooool0003oooooojkooooo00000ooooooo0000
o`000004o`0000?ooooo00?oV9RHob4Q8Oo^k^h01Oooool00ooMgMgo0000omgMg@07ooooo`03o`00
0?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400:ooooo`03o`000?oooooooooo01?o
oooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00Co0000oooooooooooo0000oooooon^ooooo`002oooool00onHV9So8B4Qonk^kP03oooo
o`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000002_ooool00ol0003oooooooooo`0Cooooo`04o`000?ooooooooooo`0000Oooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`000?oo
oooo[_ooool000cooooo00_oMgMgofIVI_ooooooooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^
kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000:ooooo`Co0000
4_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool01?l0003oooooooooool0003oooooojkooooo000=ooooo`03o`000?oooooooooo00;o
k^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@
00[ooooo00?o0000ooooooooool04oooool01?l0003oooooooooool00007ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo00000?oooooo[Ooo
ool000Wooooo00Go0000okZj^_ooooooV9RHoa0@400>ooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`03ooooo`;o00001Oooool00ol0003oooooooooo`0Booooo`05o`00
0?ooooooooooooooool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00Go0000ooooooooooooooooo`00003oooooojgooooo0009ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`03?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_ooool0
1?l0003oooooooooool00004ooooo`03o`000?oooooooooo01;ooooo00Go0000oooooooooooooooo
o`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooo
oooooooooooo00000?oooooo[Oooool002Sooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`0Booooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00003oooooojgooooo000Xoooo
o`?o00001Oooool00ol0003oooooooooo`0Booooo`05o`000?ooooooooooooooool000001oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00
003oooooojgooooo000Yooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04_ooool0
1Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`04ooooo`05o`000?ooooooooooooooool00000oooooon]ooooo`00:_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo01;ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo00000?oo
oooo[Oooool0033ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`00
0?ooooooooooooooool00000oooooon]ooooo`00<?ooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00003oooooojgooooo000`ooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo00000?oo
oooo[Oooool0033ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`00
0?ooooooooooooooool00000oooooon]ooooo`00<?ooool3o`0001;ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool01Ol0003ooooooooooooooooo00000?oooooo[Oooool0033ooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000oooooon]ooooo`00
<?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooo
ooooo`000008ooooo`03o`000?oooooooooo0?ooooooX_ooool0033ooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001oooool2o`000?oo
ooooY?ooool0033ooooo00?o0000ooooooooool02?ooool2o`0000Sooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool01Ol0003ooooooooooooooooo000000Oooooo0_l0003oooooojCooooo000`ooooo`03o`00
0?oooooooooo00Sooooo0_l00008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooo
ooooo`000007ooooo`;o0000oooooonTooooo`00<?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooo000000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Oo
oooo0_l0003oooooojCooooo000`ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooool00000
2?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001oooool00ol0003o
ooooo`00003ooooooj?ooooo000`ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooool00000
2?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001oooool00ol0003o
ooooo`00003ooooooj?ooooo000`ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooool00000
2?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001oooool00ol0003o
ooooo`00003ooooooj?ooooo000`ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo
00001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001oooool00ol0
003oooooo`00003ooooooj?ooooo000`ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooo
oooo00001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001oooool0
0ol0003oooooo`00003ooooooj?ooooo000`ooooo`?o00001oooool01?l0003oooooooooool00007
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?oo
ooooooooo`000?ooooooXoooool0033ooooo00?o0000ooooooooool01oooool01?l0003ooooooooo
ool00007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`04
o`000?ooooooooooo`000?ooooooXoooool0033ooooo00?o0000ooooooooool01_ooool01Ol0003o
oooooooooooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo
000000Kooooo00Co0000oooooooooooo0000oooooonSooooo`00<?ooool00ol0003oooooooooo`06
ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oo
ooooooooooooool000001_ooool01?l0003oooooooooool0003ooooooj?ooooo000`ooooo`03o`00
0?oooooooooo00Kooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`000?ooooooXoooool0
033ooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo0000
5Oooool2onk^kP?ooooo0_o^k^iGooooo`;ok^k^0oooool2onk^kV3ooooo0_o^k^h3ooooo`;ok^k^
C_ooool2onk^kP?ooooo0_o^k^i/ooooo`00<?ooool00ol0003oooooooooo`06ooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool01?l0003oooooooooool0000?ooooo`0=odA4A?l0003o0000oc8b
<_oMgMgoooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co000000So410@oooooooo
ooook^k^oc8b<_l0003o<S8bonk^kT;ooooo1?l000002Ol@413oooooonk^k_mEEEGok^k^ooooooo^
k^koEEEEonk^kP03ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kS_ooooo
1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool03Om4A4Co0000o`000?lb<S;ogMgMoooo
ooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb
<S;o0000oc8b<_o^k^hhooooo`Go00000_ooool01oo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h0
0oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^iMooooo`00<?ooool00ol0
003oooooooooo`06ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool0
000Booooo`09ogMgMolb<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000oooo
ooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg04Cooooo00?o0000ooooooooool00_ooool0
1Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg03gooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00WoMgMgoc8b<_oooooo
ooooonk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL0>?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00Gok^k^oeEEEOoMgMgo
EEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Moooo
o`00<?ooool00ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool000001_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool01?l0
003oooooooooool0000Cooooo`07o`000?oooooooooooooooooMgMgo0000omgMg@07ooooo`03o`00
0?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4014ooooo`03o`000?oooooooooo00?o
oooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooo
ool@4100?Oooool00ol0003oooooooooo`0?ooooo`07o`000?oooooooooooooooooMgMgo0000omgM
g@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400iooooo`03oiRH
V?lQ8B7ok^k^00Gooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@
4?ooooooooooooooool@4100GOooool0033ooooo00?o0000ooooooooool01_ooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00Co0000oooooooooooo00004_ooool02OmgMgOo<S8boooooooooooo
k^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`000014ooooo`03o`000?oooooooooo00;ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06oooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000mooooo`03o`000?oooooo
oooo00kooooo00WoMgMgoc8b<_ooooooooooonk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool00000>_ooool00onHV9So8B4Qonk^kP03oooo
o`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool00000GOooool0033ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00000>ooooo`0=o`000?lQ
8B7o0000oc8b<_o<c<coooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`000014ooooo`0;o`000?ooooooooooooooooo^
k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool00000?Oooool00ol0003oooooooooo`0;ooooo`0=o`000?lQ8B7o0000oc8b<_o<
c<coooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo
00Go0000ooooooooooooooooo`00000kooooo`0;ogMgMomVIVKoooooooooooo^k^koEEEEonk^k_oo
ooook^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
0000GOooool0033ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo00?o
oooo0_o^k^h3ooooo`;ok^k^1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooo
ool@4100A?ooool01?l0003oooooooooooooool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooo
oooo00;ooooo00Go410@oooooooooooooooooa0@400mooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool00oooool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go
410@oooooooooooooooooa0@400looooo`03o`000?oooooooooo00;ok^k^0oooool2onk^kPGooooo
00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@05gooooo000`ooooo`?o0000
1_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`;o0000<oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo0_l0000^ooooo`05o`000?nj^[[ooooooiRHV?l@4100
3_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool2o`0005?o
oooo000`ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`05o`000?ooooooooooooooool000003_ooool4o`0000cooooo00?oEEEEofIVI_l0
00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0=oooool00omE
EEGoIVIVo`00000=ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP07
ooooo`04o`000?ooooooooooo`00033ooooo00?oEEEEofIVI_l000003Oooool4o`0000cooooo00?o
EEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oooooo00Co0000oooooooooooo
0000;Oooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo00?oEEEEofIVI_l000001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Oooooo00Co0000oooooooooooo0000D_ooool0033ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00Go0000
ooooooooooooooooo`00000/ooooo`Co00000oooool00ol0003oooooooooo`1Dooooo`Co000000Go
ooooo`000?ooooooooooo`00001Nooooo`Co000000Goooooo`000?ooooooooooo`00001<ooooo`Co
000000Goooooo`000?ooooooooooo`00001Booooo`00<?ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo0000
03?ooooo00?o0000ooooooooool0FOooool3o`0006Cooooo0ol0001Booooo`?o0000Doooool0033o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`;o0000:?ooool01?l0003o
ooooooooool0001Kooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0D_ooool00ol0
003oooooooooo`1Booooo`00<?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo0ol0000Xooooo`Co0000G?ooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo05;o
oooo00?o0000ooooooooool0DOooool0033ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooo00000?ooooooVOooool002kooooo0ol00007ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00Co0000oooooooooooo0000oooooomNooooo`03ogMgMomVIVKooooo02gooooo
00?oIVIVogMgMoooool01oooool002gooooo00Co0000ooooool0003o00001oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`04o`000?ooooooooooo`000?ooooooGOooool00ooMgMgo410@onk^kP0^ooooo`03
onk^k_l@413ogMgM00Oooooo000/ooooo`05o`000?ooooooooooooooool000001oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`04o`000?ooooooooooo`000?ooooooBoooool2o`0000;ooooo0_l0000<oooo
o`03oeEEEOnHV9Sooooo00;o00000_ooool01ol0003oooooooooool0003o410@onk^k_mEEED00_l0
00000om4A4Co^[Zjooooo`02ooooo`05oiRHV?l0003o0000odA4A?nj^[X00_ooool02?o^k^koEEEE
o`000?l0003oA4A4okZj^_oooooo410@1Ol00003ooooo`08oa0@4?lb<S;o0000o`000?l@413oZJVY
ohN7QomVIVH7ooooo`00:oooool2o`0000?ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000001oooool2o`000?oooooo@_ooool01_o^k^ko
8B4QohN7Qonj^[[o0000omgMg@cooooo00Go0000ooooooooooooooooo`000002ooooo`0;o`000?oo
ooooooooo`000?ooooooEEEEogMgMoooooook^k^ogMgMol@41000oooool01Ol@413o^[Zjonk^k_mg
MgOo410@00;ooooo00KoEEEEogMgMoooooook^k^ogMgMol@4103ooooo`03o`000?oooooooooo00Co
oooo00So0000ojVYZOoooooooooookZj^_l0003ok^k^o`0000Oooooo003oo`000;Co00003oooool0
1?oMgMgo0000oa0@4?o<c<`=ooooo`05oc8b<_ooooooooooooooool000000_ooool01_l0003ooooo
ooooool0003oooooo`0000Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Gooooo00Oo^[ZjohN7QomVIVKoIVIVoa0@4?oooooo000000Oooooo000:
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01?ooool7o`0000Gooooo0_l00005
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool2o`0000Gooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`02ooooo`;o00001?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02o`0000Kooooo0ol00008ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo01Oooooo00Cok^k^ob4Q8Ol@413ok^k^3Oooool01Olb<S;ooooooooooooooooo000000;ooooo
00Go0000oooooooooooo0000ooooo`06o`0000?ooooo00?o0000ooooooooool01?ooool6o`0000?o
oooo00?o0000ooooooooool01?ooool02?lb<S;o8B4QogMgMomgMgOoQhN7onk^k_oooooo00001ooo
ool000[ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`;o00001Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo0_l00005ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00_ooool2o`0000Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00Co0000oooooooooooo00004_ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Gooooo`04ob4Q8Omg
MgOoMgMgoc8b<Pgooooo00Go0000onk^k_ooooooooooo`000002olc<c00;o`000?nYZJWogMgMob4Q
8OooooooEEEEohN7Qoo^k^koooooohN7Qolb<S800oooool00ol0003oooooooooo`04ooooo`06oeEE
EOn7QhOok^k^oooooon7QhOo<S8b0oooool00ol0003o<S8bomgMg@04ooooo`08o`000?nj^[[ooooo
onk^k_mgMgOo0000onk^k_l00007ooooo`00<?ooool2o`0000Gooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`;o00004oooool00ol0003oooooooooo`1Kooooo`03o`000?oo
oooooooo05_ooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`0Fooooo`;o00000_oo
ool2o`0000cooooo00koEEEEogMgMooooooo410@o`000?lQ8B7o0000ogMgMol@413o0000ojVYZOoo
ooook^k^oeEEE@;o000000CoA4A4onk^k_oooooo410@1Ol00003ooooo`06onk^k_mEEEGo0000o`00
0?m4A4Cok^k^0_ooool2o`000004ojVYZOlQ8B7o0000ob4Q8@;ooooo00SoZJVYob4Q8Ol0003o0000
oc8b<_l0003oMgMgoeEEE@Oooooo000`ooooo`;o00001Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo0000
0?ooooooH_ooool00ooMgMgo410@onk^kP0Booooo`03o`000?oooooooooo01Wooooo00?ok^k^oa0@
4?oMgMd01oooool0033ooooo00?o0000ooooool000001?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo0000
0?ooooooHoooool00omgMgOoIVIVooooo`0Aooooo`03o`000?oooooooooo01Wooooo00?oIVIVogMg
Moooool01oooool0033ooooo00?o0000ooooool000001?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0003ooooo
oigooooo000`ooooo`03o`000?oooooo000000Cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo0000oooooonMoooo
o`00<?ooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`000?ooooooWOooool0033o
oooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0003ooooooigooooo000`oooo
o`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo0000oooooonMooooo`00<?ooool0
1ol0003ooooooooooooooooo0000ooooool000002?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooool00000oooooonNooooo`00<?ooool3o`000004ooooool0
003oooooo`0000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooo00000?ooooooW_ooool0033ooooo00Co0000oooooooooooooooo0ol00008ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooo`00003ooooooikooooo
000`ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooo00000?ooooooW_ooool0033ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooool00000oooooonN
ooooo`00<?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01?ooool3o`000?ooooooW_ooool0033ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooonMooooo`00
<?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
oooooonUooooo`00<?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool00000
oooooonXooooo`00<?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool00000
oooooonXooooo`00<?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go
0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool00000oooooonXooooo`00
<?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooo
ooooo`000006ooooo`05o`000?ooooooooooooooool00000oooooonXooooo`00<?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006oooo
o`05o`000?ooooooooooooooool00000oooooonXooooo`00<?ooool3o`0000cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`00
003oooooojSooooo000`ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
1Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`00003oooooojSooooo
000`ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000Kooooo00Go0000ooooooooooooooooo`00003oooooojSooooo000`ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Ko
oooo00Go0000ooooooooooooooooo`00003oooooojSooooo000`ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooo
oooooooo0000oooooonXooooo`00<?ooool00ol0003oooooooooo`0<ooooo`05o`000?oooooooooo
ooooool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000
ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`000?ooooooZ?ooool0033ooooo00?o
0000ooooooooool03?ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001oooool01?l0003o
ooooooooool0003oooooojSooooo000`ooooo`03o`000?oooooooooo00cooooo00Go0000oooooooo
ooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0
003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000oooooonXooooo`00<?ooool0
0ol0003oooooooooo`0=ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001oooool01?l0003ooooo
ooooool0003oooooojSooooo000`ooooo`03o`000?oooooooooo00gooooo00Co0000oooooooooooo
00001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooo
ooooooooo`000007ooooo`04o`000?ooooooooooo`000?ooooooZ?ooool0033ooooo00?o0000oooo
ooooool03Oooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000
oooooonXooooo`00<?ooool00ol0003oooooooooo`0=ooooo`04o`000?ooooooooooo`0000Oooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool0
00001oooool01?l0003oooooooooool0003oooooojSooooo000`ooooo`?o00003Oooool01?l0003o
ooooooooool00007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0
003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000oooooonXooooo`00<?ooool0
0ol0003oooooooooo`0=ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001oooool01?l0003ooooo
ooooool0003oooooojSooooo000`ooooo`03o`000?oooooooooo00gooooo00Co0000oooooooooooo
00001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooo
ooooooooo`000007ooooo`04o`000?ooooooooooo`000?ooooooZ?ooool0033ooooo00?o0000oooo
ooooool03Oooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000
oooooonXooooo`00<?ooool00ol0003oooooooooo`0=ooooo`04o`000?ooooooooooo`0000Oooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool0
00001oooool01?l0003oooooooooool0003oooooojSooooo000`ooooo`03o`000?oooooooooo00go
oooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`000?ooooooZ?oo
ool000oooooo0_o^k^h3ooooo`;ok^k^6_ooool00ol0003oooooooooo`0=ooooo`04o`000?oooooo
ooooo`0000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oo
ooooooooooooool000001oooool01?l0003oooooooooool0003oooooojSooooo0008ooooo`Go0000
0_ooool01oo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^h;ooooo`03o`000?oooooooooo00gooooo00Co0000oooooooooooo
00001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooo
ooooooooo`000007ooooo`04o`000?ooooooooooo`000?ooooooZ?ooool000Sooooo00GoV9RHob4Q
8Oo^k^koooooodA4A003ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ol0003oooooooooo`0=ooooo`04o`00
0?ooooooooooo`0000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05
o`000?ooooooooooooooool000001oooool01?l0003oooooooooool0003oooooojSooooo0009oooo
o`03oiRHV?lQ8B7ok^k^00Gooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@41002oooool00ol0003oooooooooo`0=ooooo`04o`000?oooooo
ooooo`0000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oo
ooooooooooooool000001oooool00ol0003oooooo`00003oooooojWooooo000:ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo
00Go0000ooooooooooooooooo`00000;ooooo`03o`000?oooooooooo00gooooo00Co0000oooooooo
oooo00001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooo
ooooooooooooo`000007ooooo`03o`000?oooooo00000?ooooooZOooool000_ooooo00_oMgMgofIV
I_ooooooooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`00000;ooooo`Co00003?ooool01?l0003oooooooooool00007
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooo
oooo000000Oooooo00?o0000ooooool00000oooooonYooooo`003?ooool00ol0003oooooooooo`02
onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03o`000?oooooooooo00gooooo00Co0000oooooooooooo00001oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000007ooooo`03
o`000?oooooo00000?ooooooZOooool000Sooooo00Go0000okZj^_ooooooV9RHoa0@400>ooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03o`000?oooooooooo
00gooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?ooooooZOoo
ool000Sooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00<ooooo`03oeEEEOmVIVKo000000Cooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP03ooooo`;o00001_ooool00ol0003oooooooooo`0=ooooo`04o`00
0?ooooooooooo`0000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05
o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003oooooojWooooo000Wooooo`04
o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool03Oooool01?l0003oooooooooool00007
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooo
oooo000000Oooooo00?o0000ooooool00000oooooonYooooo`009oooool01?l0003oooooooooool0
0005ooooo`03o`000?oooooooooo00gooooo00?o0000ooooool000002?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000007ooooo`03o`00
0?oooooo00000?ooooooZOooool002Oooooo0ol00006ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooool000002?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go
0000ooooooooooooooooo`000008ooooo`;o0000oooooonYooooo`00:?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00kooooo0_l00008ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Sooooo0_l0003oooooojWooooo
000Yooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03_ooool2o`0000Sooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000
2?ooool2o`000?ooooooZOooool0033ooooo00?o0000ooooooooool03_ooool2o`0000Sooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000
2?ooool2o`000?ooooooZOooool0033ooooo00?o0000ooooooooool03_ooool2o`0000Sooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000
2?ooool2o`000?ooooooZOooool0033ooooo00?o0000ooooooooool03_ooool2o`0000Sooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000
2?ooool2o`000?ooooooZOooool0033ooooo0ol0000>ooooo`;o00002?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000008ooooo`;o0000
oooooonYooooo`00<?ooool00ol0003oooooooooo`0>ooooo`;o00002?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00003ooooook?ooooo
000`ooooo`03o`000?oooooooooo00kooooo0_l00008ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool01Ol0003ooooooooooooooooo00000?oooooo/oooool0033ooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go
0000ooooooooooooooooo`00003ooooook?ooooo000`ooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000
ooooooncooooo`00<?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool01Ol0003ooooooooooooooooo00000?oooooo/oooool0033ooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go
0000ooooooooooooooooo`00003ooooook?ooooo000`ooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`000?oooooo
/oooool0033ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Gooooo00Co0000oooooooooooo0000ooooooncooooo`00<?ooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool01?l0003ooooooooo
ool0003ooooook?ooooo000`ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`000?oooooo/oooool0033ooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00Co
0000oooooooooooo0000ooooooncooooo`00<?ooool3o`0001Wooooo00Go0000oooooooooooooooo
o`000007ooooo`04o`000?ooooooooooo`000?oooooo/oooool0033ooooo00?o0000ooooooooool0
6Oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000ooooooncoooo
o`00<?ooool00ol0003oooooooooo`0Iooooo`05o`000?ooooooooooooooool000001oooool01?l0
003oooooooooool0003ooooook?ooooo000`ooooo`03o`000?oooooooooo01Wooooo00Go0000oooo
ooooooooooooo`000007ooooo`04o`000?ooooooooooo`000?oooooo/oooool0033ooooo00?o0000
ooooooooool06Oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000
ooooooncooooo`00<?ooool00ol0003oooooooooo`0Iooooo`05o`000?ooooooooooooooool00000
1oooool01?l0003oooooooooool0003ooooook?ooooo000`ooooo`03o`000?oooooooooo01Wooooo
00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0003ooooook?ooooo000`ooooo`03
o`000?oooooooooo01Wooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0003o
oooook?ooooo000`ooooo`03o`000?oooooooooo01Wooooo00Co0000oooooooooooo00002?ooool0
1?l0003oooooooooool0003ooooook?ooooo000`ooooo`03o`000?oooooooooo01Wooooo00Co0000
oooooooooooo00002?ooool01?l0003oooooooooool0003ooooook?ooooo000`ooooo`03o`000?oo
oooooooo01Wooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0003ooooook?o
oooo000`ooooo`03o`000?oooooooooo01Wooooo00Co0000oooooooooooo00002?ooool01?l0003o
ooooooooool0003ooooook?ooooo000`ooooo`?o00006Oooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`000?oooooo/oooool0033ooooo00?o0000ooooooooool06Oooool01?l0
003oooooooooool00008ooooo`04o`000?ooooooooooo`000?oooooo/oooool0033ooooo00?o0000
ooooooooool06Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`000?oooooo
/oooool0033ooooo00?o0000ooooooooool06Oooool01?l0003oooooooooool00008ooooo`04o`00
0?ooooooooooo`000?oooooo/oooool0033ooooo00?o0000ooooooooool06Oooool01?l0003ooooo
ooooool00008ooooo`04o`000?ooooooooooo`000?oooooo/oooool0033ooooo00?o0000oooooooo
ool06Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`000?oooooo/oooool0
00oooooo0_o^k^h3ooooo`;ok^k^6_ooool00ol0003oooooooooo`0Iooooo`04o`000?oooooooooo
o`0000Sooooo00Co0000oooooooooooo0000ooooooncooooo`002_ooool2o`00000:oa0@4?oooooo
ooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP?ooooo1?l000002?l@413oooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^2oooool00ol0003oooooooooo`0Iooooo`04o`000?ooooooooooo`0000So
oooo00Co0000oooooooooooo0000ooooooncooooo`002oooool00ol0003oooooooooo`02ooooo`05
onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool00ol0003oooooooooo`0Iooooo`04o`000?ooooooooooo`0000Sooooo00Co
0000oooooooooooo0000ooooooncooooo`002?ooool5o`0000Cooooo00?ogMgMo`000?oMgMd01ooo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41002oooool00ol0003ooooo
ooooo`0Iooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooondooooo`00
2?ooool01?m4A4CogMgMooooool00004ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`0I
ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooondooooo`002?ooool0
1?oMgMgoEEEEooooool00003ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03
o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000;ooooo`Co00006?ooool01?l0
003oooooooooool00008ooooo`03o`000?oooooo00000?oooooo]?ooool000Wooooo00?oMgMgolc<
c?l000000oooool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooo
oooooooooooooa0@400;ooooo`03o`000?oooooooooo01Wooooo00Co0000oooooooooooo00002?oo
ool00ol0003oooooo`00003ooooookCooooo0009ooooo`03onk^k_m4A4Co000000oooooo00?o0000
ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?o0000ooooooooool06Ooo
ool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?oooooo]?ooool000[ooooo00?o
MgMgo`000?ooool03?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
0oooool2o`0000Kooooo00?o0000ooooooooool06Oooool01?l0003oooooooooool00008ooooo`03
o`000?oooooo00000?oooooo]?ooool002Oooooo00Co0000oooooooooooo00001Oooool00ol0003o
ooooooooo`0Iooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooondoooo
o`009oooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo01Wooooo00Co0000oooo
oooooooo00002?ooool00ol0003oooooo`00003ooooookCooooo000Wooooo`?o00001_ooool00ol0
003oooooooooo`0Iooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooond
ooooo`00:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Wooooo00Co0000oooo
oooooooo00002?ooool00ol0003oooooo`00003ooooookCooooo000Yooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool06Oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo
00000?oooooo]?ooool0033ooooo00?o0000ooooooooool06Oooool01?l0003oooooooooool00008
ooooo`03o`000?oooooo00000?oooooo]?ooool0033ooooo00?o0000ooooooooool06_ooool00ol0
003oooooo`000008ooooo`03o`000?oooooo00000?oooooo]?ooool0033ooooo00?o0000oooooooo
ool06_ooool00ol0003oooooo`000008ooooo`03o`000?oooooo00000?oooooo]?ooool0033ooooo
0ol0000Jooooo`03o`000?oooooo000000Sooooo00?o0000ooooool00000oooooondooooo`00<?oo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooo000000Sooooo00?o0000ooooool00000oooo
oondooooo`00<?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo000000Wooooo0_l0003o
oooookCooooo000`ooooo`03o`000?oooooooooo01[ooooo0_l0000:ooooo`;o0000oooooondoooo
o`00<?ooool00ol0003oooooooooo`0Jooooo`;o00002_ooool2o`000?oooooo]?ooool0033ooooo
00?o0000ooooooooool06_ooool2o`0000[ooooo0_l0003ooooookCooooo000`ooooo`03o`000?oo
oooooooo01[ooooo0_l0000:ooooo`;o0000oooooondooooo`00<?ooool00ol0003oooooooooo`0J
ooooo`;o00002_ooool2o`000?oooooo]?ooool0033ooooo00?o0000ooooooooool06_ooool2o`00
00[ooooo0_l0003ooooookCooooo000`ooooo`03o`000?oooooooooo01[ooooo0_l0000:ooooo`;o
0000oooooondooooo`00<?ooool00ol0003oooooooooo`0Jooooo`;o00002_ooool00ol0003ooooo
ooooo`3ooooook?ooooo000`ooooo`03o`000?oooooooooo01[ooooo0_l0000:ooooo`03o`000?oo
oooooooo0?oooooo/oooool0033ooooo0ol0000Jooooo`;o0000ooooooo0ooooo`00<?ooool00ol0
003oooooooooo`0Jooooo`;o0000ooooooo0ooooo`00<?ooool00ol0003oooooooooo`0Jooooo`;o
0000ooooooo0ooooo`00<?ooool00ol0003oooooooooo`0Jooooo`;o0000ooooooo0ooooo`00<?oo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo0?oooooo__ooool0033ooooo00?o0000
ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03
o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?oo
ool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0
033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool3o`000?oooooog?ooool0033ooooo
00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`
ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLoooo
o`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooo
oooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo
003ooooooooooooo4?ooool00:3ooooo0_l00004ooooo`03okZj^_lb<S;ooooo00Cooooo0_l00006
ooooo`03o`000?nj^[[ooooo0?ooooooEoooool00:3ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo0_lb<S;ooooooeSooooo002=ooooo`?o
00000_ooool01_lb<S;o410@ooooooooooook^k^oeEEE@;o000000?oA4A4okZj^_ooool00oooool0
0ol0003oooooooooo`02ooooo`05oiRHV?l@413o0000o`000?nYZJT01?ooool00ol0003ooooooooo
o`04ooooo`03ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0:ooooo`Co0000
00?o410@ooooooooool00_ooool2ob4Q8@Cooooo00_ok^k^oc8b<_l0003o410@olc<c?ooooooc<c<
onk^k_ooooook^k^olc<c004ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^
kQ?ooooo00Ko410@oc8b<_l0003o0000oa0@4?nYZJT2ooooo`06onk^k_mEEEGo0000o`000?m4A4Co
^[Zj0oooool01OmVIVKo0000o`000?m4A4Coc<c<0>Sooooo002>ooooo`05o`000?ooooooooooolc<
c?l@41000oooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40Cooooo00?o0000ooooooooool00_oo
ool01_l0003oZJVYoeEEEOnHV9SoEEEEokZj^P?ooooo00?o0000ooooooooool01?ooool00oo<c<co
0000oa0@400<ooooo`06oa0@4?nj^[[ok^k^ogMgMol@413ooooo1_l00005ooooo`03o`000?oooooo
oooo00Cooooo0_lQ8B44ooooo`0;oeEEEOmgMgOooooooiRHV?lQ8B7oooooonk^k_mEEEGogMgMoeEE
EOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool0
1_l0003oZJVYoooooooooooo^[Zjo`0000;ooooo00KoEEEEogMgMoooooook^k^ogMgMol@4102oooo
o`06ofIVI_mgMgOooooooooooon7QhOo410@j?ooool008kooooo00Go0000ooooooooooooEEEEohN7
Q`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool01_lb<S;ok^k^oiRH
V?mEEEGogMgMoa0@40?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00[ooooo00Go0000ooooooooooooooooo`000002ooooo`03omgMgOl0003ogMgM
00Oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01Cooooo00Go^[Zj
ohN7QomVIVKoIVIVoa0@4002ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0jooo
ool008kooooo00Go0000oooooooMgMgo0000onk^kP03ooooo`Ko00001?ooool00ol0003ooooooooo
o`02ooooo`07okZj^_m4A4Coc<c<ob4Q8Ooooooo410@olc<c002ooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool00oooool6o`0000Gooooo00?o0000ooooooooool02_ooool02ol0003o
V9RHoooooonHV9So8B4Qooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool0
0_ooool01Ol0003ooooooooooooooooo000001?ooooo00Ko<S8bob4Q8OmgMgOoMgMgohN7Qoo^k^h2
ooooo`Ko00000_ooool00ol0003oooooooooo`3[ooooo`00S_ooool3o`000003oa0@4?nHV9Sooooo
00;ooooo00KoEEEEohN7Qoo^k^koooooohN7Qolb<S84ooooo`03o`000?oooooooooo00;ooooo00Oo
k^k^o`000?oooooo0000oooooomVIVKoQhN700;ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00[ooooo00_o0000oeEEEOl0003o410@olc<c?oooooo
c<c<onk^k_ooooook^k^olc<c006ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`00000Cooooo`06o`000?nj^[[oooooonk^k_mgMgOo00000_ooool01_mEEEGoQhN7onk^k_oo
ooooQhN7oc8b<P;ooooo00KoIVIVogMgMoooooooooooohN7Qol0003Xooooo`00S_ooool01Ol0003o
ooooooooooo<c<co000000?ooooo00Kok^k^oeEEEOl0003o0000odA4A?o^k^h4ooooo`03o`000?oo
oooooooo00;ooooo00CoIVIVoiRHV?oooooo<S8b0_nj^[X01?l0003oooooooooool0000Cooooo`03
oa0@4?l0003o000000?o00003Oooool00ol0003oooooooooo`0:ooooo`03oeEEEOn7QhOooooo00ko
oooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Oooooo0ol00002oooo
o`?o00001?ooool01_nYZJWo8B4Qo`000?l0003o<S8bo`0000;ooooo00Kok^k^oeEEEOl0003o0000
odA4A?o^k^h2ooooo`06onk^k_mVIVKo0000o`000?m4A4Co0000j?ooool008kooooo00Go0000oooo
ooooooooc<c<o`00000=ooooo`03o`000?oooooooooo00Gooooo00?oIVIVohN7Qoooool00oooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02_ooool0
0ooMgMgo410@oiRHV00>ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`08ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0ooooool2ooooo`00SOooool4
o`000003oa0@4?nYZJWooooo00cooooo0_l00006ooooo`03ojVYZOm4A4Cooooo00;ooooo0_l0000E
ooooo`03o`000?oooooooooo00cooooo00?oEEEEofIVI_l000003Oooool01?o<c<coA4A4o`000?l@
410:ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`Co0000
0_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo0_ooool00?oooooo1_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo0_ooool00?oooooo1_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo0_ooool00?oooooo1Oooool2o`00
00?ooooo0_l0003oooooo`Cooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooo
oooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3o
oooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooo
oooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?oo
ool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooo
ooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@oooo
o`00\
\>"],
  ImageRangeCache->{{{0, 525.688}, {324.5, 0}} -> {0, -6.34248*^6, 0, 53093}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0.309017 5.42214e-08 [
[.32684 .29652 -16.5 -12.5 ]
[.32684 .29652 16.5 0 ]
[.54329 .29652 -16.5 -12.5 ]
[.54329 .29652 16.5 0 ]
[.75974 .29652 -22.5 -12.5 ]
[.75974 .29652 22.5 0 ]
[.97619 .29652 -16.5 -12.5 ]
[.97619 .29652 16.5 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 64 6 ]
[.09789 .09213 -34.5 -6.25 ]
[.09789 .09213 0 6.25 ]
[.09789 .20057 -34.5 -6.25 ]
[.09789 .20057 0 6.25 ]
[.09789 .41746 -28.5 -6.25 ]
[.09789 .41746 0 6.25 ]
[.09789 .5259 -28.5 -6.25 ]
[.09789 .5259 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -62.8125 0 ]
[.5 .63053 62.8125 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 .30902 m
.32684 .31527 L
s
gsave
.32684 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 .30902 m
.54329 .31527 L
s
gsave
.54329 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 .30902 m
.75974 .31527 L
s
gsave
.75974 .29652 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 .30902 m
.15368 .31277 L
s
.19697 .30902 m
.19697 .31277 L
s
.24026 .30902 m
.24026 .31277 L
s
.28355 .30902 m
.28355 .31277 L
s
.37013 .30902 m
.37013 .31277 L
s
.41342 .30902 m
.41342 .31277 L
s
.45671 .30902 m
.45671 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.58658 .30902 m
.58658 .31277 L
s
.62987 .30902 m
.62987 .31277 L
s
.67316 .30902 m
.67316 .31277 L
s
.71645 .30902 m
.71645 .31277 L
s
.80303 .30902 m
.80303 .31277 L
s
.84632 .30902 m
.84632 .31277 L
s
.88961 .30902 m
.88961 .31277 L
s
.9329 .30902 m
.9329 .31277 L
s
.0671 .30902 m
.0671 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09213 m
.11664 .09213 L
s
gsave
.09789 .09213 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .20057 m
.11664 .20057 L
s
gsave
.09789 .20057 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .41746 m
.11664 .41746 L
s
gsave
.09789 .41746 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .5259 m
.11664 .5259 L
s
gsave
.09789 .5259 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.11039 .11924 m
.11414 .11924 L
s
.11039 .14635 m
.11414 .14635 L
s
.11039 .17346 m
.11414 .17346 L
s
.11039 .22768 m
.11414 .22768 L
s
.11039 .2548 m
.11414 .2548 L
s
.11039 .28191 m
.11414 .28191 L
s
.11039 .33613 m
.11414 .33613 L
s
.11039 .36324 m
.11414 .36324 L
s
.11039 .39035 m
.11414 .39035 L
s
.11039 .44457 m
.11414 .44457 L
s
.11039 .47168 m
.11414 .47168 L
s
.11039 .49879 m
.11414 .49879 L
s
.11039 .06502 m
.11414 .06502 L
s
.11039 .03791 m
.11414 .03791 L
s
.11039 .0108 m
.11414 .0108 L
s
.11039 .55301 m
.11414 .55301 L
s
.11039 .58012 m
.11414 .58012 L
s
.11039 .60723 m
.11414 .60723 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -123.812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.812 moveto
(@) show
81.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.812 moveto
(D) show
93.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1.8) show
135.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
141.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
153.000 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
157.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
166.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
184.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02399 .30902 L
.02418 .30902 L
.02428 .30902 L
.02436 .30902 L
.02444 .30902 L
.02453 .30902 L
.02462 .30902 L
.02473 .30902 L
.02478 .30902 L
.02484 .30902 L
.02494 .30902 L
.02504 .30902 L
.02514 .30902 L
.02532 .30902 L
.02551 .30902 L
.02571 .30902 L
.02608 .30902 L
.02652 .30902 L
.02691 .30902 L
.02735 .30902 L
.02775 .30902 L
.02865 .30902 L
.02945 .30902 L
.03029 .30902 L
.03187 .30902 L
.03334 .30902 L
.03497 .30902 L
.03646 .30902 L
.03813 .30902 L
.03966 .30901 L
.04115 .30901 L
.04152 .30901 L
.04191 .30901 L
.04213 .30901 L
.04234 .30901 L
.04253 .30901 L
.04263 .30901 L
.04274 .30901 L
.04285 .30901 L
.04295 .30901 L
.04304 .30901 L
.04314 .30901 L
.04323 .30901 L
.04331 .30901 L
.04341 .30901 L
.0435 .30901 L
.04361 .30901 L
.04372 .30901 L
.04393 .30901 L
Mistroke
.04414 .30901 L
.04432 .30901 L
.0447 .30901 L
.04504 .30901 L
.0458 .30902 L
.04619 .30902 L
.0466 .30902 L
.04735 .30902 L
.04814 .30902 L
.04902 .30902 L
.05059 .30902 L
.05227 .30902 L
.05559 .30904 L
.05726 .30904 L
.05799 .30904 L
.05879 .30904 L
.05916 .30905 L
.05956 .30905 L
.05994 .30905 L
.06011 .30905 L
.06029 .30905 L
.06039 .30905 L
.06048 .30905 L
.06057 .30905 L
.06066 .30905 L
.06076 .30905 L
.06085 .30905 L
.06095 .30905 L
.061 .30905 L
.06106 .30905 L
.06117 .30905 L
.06126 .30905 L
.06138 .30905 L
.06148 .30905 L
.06167 .30905 L
.06187 .30905 L
.06226 .30905 L
.06263 .30904 L
.06303 .30904 L
.06346 .30904 L
.06434 .30904 L
.06515 .30903 L
.06666 .30901 L
.06752 .309 L
.06832 .30898 L
.07145 .3089 L
.07305 .30886 L
.07478 .30881 L
.07559 .30879 L
.07604 .30878 L
Mistroke
.07645 .30878 L
.0768 .30877 L
.07699 .30877 L
.07718 .30877 L
.0773 .30877 L
.0774 .30877 L
.07751 .30877 L
.0776 .30876 L
.0777 .30876 L
.07779 .30876 L
.07789 .30876 L
.07799 .30876 L
.07809 .30876 L
.07818 .30876 L
.07829 .30877 L
.07838 .30877 L
.07856 .30877 L
.07875 .30877 L
.07896 .30877 L
.07919 .30878 L
.07959 .30878 L
.08001 .3088 L
.0804 .30881 L
.08128 .30885 L
.08207 .3089 L
.0829 .30897 L
.08439 .30913 L
.08598 .30934 L
.08745 .30959 L
.09059 .31014 L
.09141 .31027 L
.0923 .31038 L
.09271 .31043 L
.09314 .31046 L
.09351 .31049 L
.09372 .3105 L
.09392 .3105 L
.09402 .31051 L
.09407 .31051 L
.09413 .31051 L
.09423 .31051 L
.09432 .31051 L
.09437 .31051 L
.09443 .31051 L
.09453 .31051 L
.09458 .31051 L
.09464 .31051 L
.09475 .3105 L
.09486 .3105 L
.09495 .31049 L
Mistroke
.09514 .31049 L
.09533 .31047 L
.09555 .31045 L
.09592 .31041 L
.09632 .31035 L
.09704 .31021 L
.09779 .31001 L
.0986 .30972 L
.10007 .30902 L
.10177 .30794 L
.10338 .3067 L
.10644 .30419 L
.10726 .30362 L
.10802 .30316 L
.10845 .30294 L
.10891 .30276 L
.10911 .30269 L
.10932 .30263 L
.10951 .30259 L
.10971 .30255 L
.10981 .30253 L
.10991 .30252 L
.11 .30251 L
.1101 .30251 L
.11019 .30251 L
.11028 .3025 L
.11037 .30251 L
.11047 .30251 L
.11057 .30252 L
.11067 .30253 L
.11079 .30255 L
.11089 .30257 L
.11108 .30261 L
.11128 .30267 L
.11168 .30284 L
.11205 .30304 L
.11275 .30357 L
.11353 .30438 L
.11436 .30552 L
.11584 .30825 L
.11888 .31615 L
.12057 .32117 L
.12212 .32545 L
.12288 .32726 L
.12371 .32888 L
.1241 .32946 L
.1245 .32997 L
.1247 .33017 L
.12488 .33032 L
.12505 .33044 L
Mistroke
.12523 .33053 L
.12533 .33057 L
.12543 .3306 L
.12552 .33062 L
.12561 .33063 L
.12571 .33063 L
.1258 .33063 L
.12591 .33061 L
.12596 .33059 L
.12602 .33058 L
.12612 .33053 L
.12622 .33048 L
.12644 .33033 L
.12664 .33015 L
.12685 .32992 L
.12721 .32938 L
.12755 .32874 L
.12833 .32676 L
.12918 .32375 L
.12997 .3201 L
.13147 .31131 L
.13456 .28734 L
.13612 .27451 L
.13695 .26828 L
.13785 .26242 L
.1387 .2579 L
.13911 .25622 L
.13948 .25497 L
.13986 .25403 L
.14006 .25367 L
.14016 .25352 L
.14027 .25339 L
.14036 .2533 L
.14045 .25323 L
.14053 .25319 L
.14062 .25317 L
.14072 .25316 L
.14081 .25318 L
.14091 .25323 L
.14101 .2533 L
.14111 .2534 L
.14122 .25354 L
.14144 .25393 L
.14164 .25441 L
.14183 .25496 L
.14226 .2566 L
.14272 .25897 L
.14357 .26497 L
.14434 .2723 L
.14586 .29164 L
Mistroke
.14753 .31874 L
.15079 .37839 L
.1523 .40184 L
.15315 .41203 L
.15355 .41589 L
.15393 .41885 L
.15433 .42125 L
.15454 .4222 L
.15477 .42297 L
.15488 .42325 L
.15494 .42337 L
.155 .42348 L
.15506 .42356 L
.15512 .42362 L
.15518 .42367 L
.15523 .42369 L
.15533 .42369 L
.15543 .42364 L
.15548 .42359 L
.15554 .42352 L
.15565 .42333 L
.15576 .42307 L
.15586 .42276 L
.15606 .42203 L
.15626 .42099 L
.15649 .41957 L
.15689 .41627 L
.15727 .41236 L
.15805 .40156 L
.15878 .38829 L
.16043 .34783 L
.16355 .24716 L
.16514 .19539 L
.16597 .17121 L
.16686 .14936 L
.16731 .14026 L
.16773 .13301 L
.16814 .12727 L
.16832 .12519 L
.16852 .12323 L
.16869 .12177 L
.16888 .12051 L
.16898 .11995 L
.16908 .11952 L
.16916 .11919 L
.16926 .11891 L
.16936 .11871 L
.16945 .1186 L
.16956 .11859 L
.16961 .11862 L
Mistroke
.16967 .11868 L
.16977 .11886 L
.16985 .11911 L
.16996 .11948 L
.17006 .11994 L
.17026 .12121 L
.17046 .12279 L
.17082 .12676 L
.17122 .13249 L
.17164 .14039 L
.17241 .15898 L
.17312 .18078 L
.17463 .2403 L
.17629 .31999 L
.17798 .40628 L
.17953 .47831 L
.1803 .50848 L
.18113 .5354 L
.18151 .54534 L
.18192 .5541 L
.18227 .56003 L
.18265 .56485 L
.18284 .56653 L
.18295 .56728 L
.18304 .56784 L
.18315 .56829 L
.18321 .56848 L
.18326 .56861 L
.18336 .56876 L
.18346 .56878 L
.18355 .56868 L
.18365 .56845 L
.18375 .56807 L
.18385 .56758 L
.18402 .5664 L
.1842 .56469 L
.18442 .56212 L
.18465 .55861 L
.18508 .55034 L
.18588 .52843 L
.18671 .49742 L
.18746 .46282 L
.18914 .36801 L
.19082 .26126 L
.19236 .16594 L
.19386 .08781 L
.19462 .05743 L
.19505 .04354 L
.19546 .03271 L
.19585 .02446 L
Mistroke
.19606 .02105 L
.19628 .01814 L
.19646 .01628 L
.19657 .01545 L
.19666 .01484 L
.19675 .01441 L
.19684 .01413 L
.19693 .01395 L
.19702 .0139 L
.19713 .01401 L
.19722 .01426 L
.19728 .01447 L
.19733 .01474 L
.19744 .01536 L
.19764 .01705 L
.19783 .01917 L
.19825 .02609 L
.1987 .03645 L
.19946 .0606 L
.20028 .09516 L
.20175 .17609 L
.20506 .397 L
.20672 .49439 L
.20753 .53193 L
.20825 .55872 L
.20862 .5694 L
.20902 .57866 L
.2092 .5821 L
.2094 .58516 L
.20958 .5875 L
.20974 .58918 L
.20983 .58992 L
.20993 .59058 L
.21004 .59111 L
.21013 .59145 L
.21023 .59163 L
.21032 .59168 L
.21041 .5916 L
.2105 .59138 L
.21055 .59118 L
.21061 .59096 L
.2107 .59041 L
.21081 .58965 L
.21093 .58862 L
.21113 .58625 L
.21133 .58345 L
.21173 .5757 L
.21217 .56459 L
.21297 .5377 L
.21447 .46782 L
Mistroke
.21776 .27014 L
.2194 .17996 L
.2202 .14403 L
.22093 .11739 L
.22129 .10659 L
.22168 .09675 L
.22205 .08935 L
.2224 .08416 L
.22259 .08202 L
.22276 .08045 L
.22286 .07978 L
.22295 .07921 L
.22301 .07896 L
.22306 .07874 L
.22316 .07845 L
.22322 .07835 L
.22327 .07829 L
.22337 .07828 L
.22347 .07841 L
.22353 .07855 L
.22358 .07872 L
.22367 .07909 L
.22377 .07962 L
.22397 .08111 L
.22417 .08311 L
.22439 .08588 L
.22479 .09244 L
.22554 .10979 L
.22641 .13742 L
.22721 .16884 L
.23036 .31642 L
.23196 .38635 L
.23281 .41656 L
.2337 .44189 L
.23409 .45055 L
.2345 .45818 L
.23474 .46178 L
.23495 .46454 L
.23517 .46686 L
.23538 .46856 L
.23556 .46972 L
.23565 .47018 L
.23576 .47058 L
.23586 .47088 L
.23592 .47099 L
.23597 .47107 L
.23607 .47114 L
.23617 .47112 L
.23626 .471 L
.23635 .4708 L
Mistroke
.23644 .47052 L
.23653 .4702 L
.23673 .46913 L
.23692 .46777 L
.23729 .46412 L
.2377 .4587 L
.23853 .4436 L
.24001 .4054 L
.24325 .30151 L
.24475 .25954 L
.24553 .24173 L
.24637 .22688 L
.24679 .22116 L
.24726 .21621 L
.24746 .21451 L
.24768 .21298 L
.24788 .21184 L
.24807 .21105 L
.24817 .21074 L
.24827 .21048 L
.24836 .2103 L
.24845 .21018 L
.24855 .21011 L
.24861 .2101 L
.24866 .21011 L
.24876 .21017 L
.24886 .2103 L
.24896 .21048 L
.24906 .21075 L
.24925 .2114 L
.24948 .21247 L
.24969 .21371 L
.25007 .21663 L
.25048 .22059 L
.25121 .22969 L
.25288 .25734 L
.25448 .28842 L
.25622 .32038 L
.25703 .33317 L
.25789 .34441 L
.25863 .35191 L
.25901 .35502 L
.25943 .35774 L
.25965 .35888 L
.25985 .35977 L
.26004 .36046 L
.26025 .36105 L
.26034 .36126 L
.26044 .36144 L
.26052 .36158 L
Mistroke
.26062 .36169 L
.26071 .36178 L
.26082 .36183 L
.26091 .36184 L
.261 .36183 L
.26111 .36177 L
.26116 .36172 L
.26122 .36167 L
.26132 .36154 L
.26143 .36136 L
.26161 .36097 L
.26181 .3604 L
.26226 .3587 L
.26268 .35656 L
.26352 .35097 L
.26431 .34434 L
.2658 .32981 L
.26741 .31352 L
.26887 .30059 L
.26963 .2951 L
.27045 .29035 L
.2709 .2883 L
.27132 .28678 L
.27172 .28565 L
.27193 .28518 L
.27214 .28481 L
.27233 .28454 L
.27243 .28442 L
.27254 .28432 L
.27263 .28426 L
.27272 .2842 L
.27281 .28417 L
.2729 .28415 L
.273 .28414 L
.2731 .28415 L
.27319 .28418 L
.27329 .28423 L
.2734 .2843 L
.27351 .28439 L
.27372 .28461 L
.27391 .28488 L
.27411 .28524 L
.27449 .28604 L
.27519 .28804 L
.27679 .29438 L
.27848 .30233 L
.28007 .30941 L
.28153 .31455 L
.28233 .31665 L
.28309 .31809 L
Mistroke
.28351 .31865 L
.28389 .31903 L
.2841 .31918 L
.28432 .3193 L
.28443 .31934 L
.28449 .31936 L
.28455 .31938 L
.28461 .31939 L
.28466 .3194 L
.28477 .31941 L
.28487 .31941 L
.28497 .31941 L
.28502 .3194 L
.28508 .31939 L
.28519 .31937 L
.28529 .31934 L
.2854 .3193 L
.28559 .3192 L
.28598 .31893 L
.28634 .3186 L
.2872 .31752 L
.28802 .31619 L
.29109 .31034 L
.29197 .30882 L
.29281 .30759 L
.29361 .30663 L
.29397 .30628 L
.29436 .30595 L
.29471 .3057 L
.29509 .30548 L
.2953 .30539 L
.29549 .30531 L
.29568 .30525 L
.29587 .30521 L
.29597 .30519 L
.29608 .30517 L
.29618 .30516 L
.29627 .30515 L
.29632 .30514 L
.29638 .30514 L
.29648 .30514 L
.29654 .30514 L
.29659 .30514 L
.29665 .30514 L
.29671 .30514 L
.29681 .30515 L
.29687 .30515 L
.29692 .30516 L
.29712 .30519 L
.29731 .30523 L
Mistroke
.2975 .30528 L
.2979 .30541 L
.29826 .30556 L
.29907 .30598 L
.30054 .30697 L
.3022 .30816 L
.30374 .30914 L
.30451 .30953 L
.30523 .30983 L
.30598 .31006 L
.30638 .31016 L
.30659 .3102 L
.30681 .31023 L
.30702 .31026 L
.30721 .31028 L
.3074 .3103 L
.30758 .31031 L
.30768 .31031 L
.30774 .31031 L
.30779 .31032 L
.30788 .31032 L
.30798 .31032 L
.30804 .31032 L
.30809 .31032 L
.30819 .31032 L
.30825 .31031 L
.3083 .31031 L
.30842 .31031 L
.30852 .3103 L
.30864 .3103 L
.30885 .31028 L
.30924 .31024 L
.30969 .31018 L
.31011 .31011 L
.31328 .30939 L
.31487 .30904 L
.31557 .30892 L
.31633 .30881 L
.31675 .30876 L
.31713 .30872 L
.31753 .30869 L
.31789 .30866 L
.31828 .30864 L
.31849 .30864 L
.31859 .30863 L
.31871 .30863 L
.31881 .30863 L
.31893 .30863 L
.31899 .30863 L
.31905 .30862 L
Mistroke
.31911 .30862 L
.31916 .30862 L
.31926 .30862 L
.31932 .30862 L
.31937 .30862 L
.31947 .30862 L
.31957 .30862 L
.31968 .30863 L
.31977 .30863 L
.31999 .30863 L
.32018 .30864 L
.32039 .30864 L
.32113 .30867 L
.32201 .30872 L
.32281 .30878 L
.32449 .3089 L
.32603 .309 L
.32681 .30904 L
.32754 .30907 L
.3283 .3091 L
.3287 .30911 L
.32891 .30911 L
.32913 .30912 L
.32933 .30912 L
.32956 .30912 L
.32976 .30912 L
.32995 .30912 L
.33006 .30912 L
.33012 .30912 L
.33017 .30912 L
.33027 .30912 L
.33032 .30912 L
.33038 .30912 L
.33044 .30913 L
.3305 .30913 L
.33056 .30912 L
.33062 .30912 L
.33067 .30912 L
.33073 .30912 L
.33084 .30912 L
.33095 .30912 L
.33105 .30912 L
.33124 .30912 L
.33167 .30912 L
.33205 .30911 L
.33245 .30911 L
.33573 .30905 L
.33651 .30903 L
.33735 .30902 L
.33808 .30901 L
Mistroke
.33888 .309 L
.33925 .309 L
.33964 .30899 L
.34006 .30899 L
.34025 .30899 L
.34045 .30899 L
.34066 .30899 L
.34084 .30899 L
.34102 .30899 L
.34111 .30899 L
.34121 .30899 L
.3413 .30899 L
.34138 .30899 L
.34148 .30899 L
.34157 .30899 L
.34165 .30899 L
.34173 .30899 L
.34181 .30899 L
.3419 .30899 L
.34211 .30899 L
.34233 .30899 L
.34273 .30899 L
.34362 .309 L
.34524 .309 L
.34684 .30901 L
.34829 .30902 L
.3491 .30902 L
.34986 .30902 L
.35028 .30902 L
.35066 .30902 L
.35109 .30902 L
.3513 .30902 L
.35154 .30902 L
.35173 .30902 L
.35183 .30902 L
.35193 .30902 L
.35204 .30902 L
.35214 .30902 L
.35219 .30902 L
.35225 .30902 L
.35235 .30902 L
.35244 .30902 L
.35254 .30902 L
.35264 .30902 L
.35274 .30902 L
.35291 .30902 L
.35309 .30902 L
.35354 .30902 L
.35397 .30902 L
.35477 .30902 L
Mistroke
.35784 .30902 L
.35866 .30902 L
.35942 .30902 L
.35985 .30902 L
.36031 .30902 L
.36072 .30902 L
.36111 .30902 L
.36148 .30902 L
.36187 .30902 L
.3621 .30902 L
.36221 .30902 L
.36231 .30902 L
.3624 .30902 L
.3625 .30902 L
.36261 .30902 L
.36266 .30902 L
.36271 .30902 L
.36282 .30902 L
.36288 .30902 L
.36293 .30902 L
.36303 .30902 L
.36309 .30902 L
.36314 .30902 L
.36323 .30902 L
.36334 .30902 L
.36353 .30902 L
.36375 .30902 L
.36398 .30902 L
.36441 .30902 L
.36517 .30902 L
.36598 .30902 L
.36745 .30902 L
.36904 .30902 L
.36994 .30902 L
.37077 .30902 L
.37151 .30902 L
.37193 .30902 L
.37232 .30902 L
.37252 .30902 L
.37274 .30902 L
.37292 .30902 L
.37302 .30902 L
.37311 .30902 L
.37317 .30902 L
.37323 .30902 L
.37333 .30902 L
.37343 .30902 L
.37353 .30902 L
.37363 .30902 L
.37369 .30902 L
Mistroke
.37374 .30902 L
.37385 .30902 L
.37397 .30902 L
.37417 .30902 L
.37439 .30902 L
.37478 .30902 L
.37567 .30902 L
.37728 .30902 L
.37889 .30902 L
.37973 .30902 L
.38062 .30902 L
.38142 .30902 L
.38188 .30902 L
.3823 .30902 L
.3825 .30902 L
.38269 .30902 L
.38286 .30902 L
.38304 .30902 L
.38314 .30902 L
.38324 .30902 L
.38334 .30902 L
.38343 .30902 L
.38353 .30902 L
.38358 .30902 L
.38364 .30902 L
.38374 .30902 L
.38384 .30902 L
.38389 .30902 L
.38395 .30902 L
.38405 .30902 L
.38415 .30902 L
.38427 .30902 L
.38447 .30902 L
.38467 .30902 L
.38503 .30902 L
.38542 .30902 L
.3871 .30902 L
.38869 .30902 L
.38953 .30902 L
.39042 .30902 L
.39121 .30902 L
.39165 .30902 L
.39208 .30902 L
.39246 .30902 L
.39282 .30902 L
.39302 .30902 L
.3932 .30902 L
.3934 .30902 L
.3935 .30902 L
.39361 .30902 L
Mistroke
.39371 .30902 L
.39377 .30902 L
.39382 .30902 L
.39392 .30902 L
.39402 .30902 L
.39407 .30902 L
.39413 .30902 L
.39419 .30902 L
.39425 .30902 L
.39435 .30902 L
.3944 .30902 L
.39446 .30902 L
.39465 .30902 L
.39487 .30902 L
.39525 .30902 L
.39603 .30902 L
.39674 .30902 L
.39838 .30902 L
.39918 .30902 L
.39991 .30902 L
.40062 .30902 L
.40139 .30902 L
.40181 .30902 L
.4022 .30902 L
.40257 .30902 L
.40276 .30902 L
.40296 .30902 L
.40315 .30902 L
.40336 .30902 L
.40354 .30902 L
.40372 .30902 L
.40382 .30902 L
.40392 .30902 L
.40401 .30902 L
.40411 .30902 L
.40421 .30902 L
.40427 .30902 L
.40433 .30902 L
.40443 .30902 L
.40453 .30902 L
.40462 .30902 L
.40472 .30902 L
.4049 .30902 L
.40523 .30902 L
.40563 .30902 L
.40599 .30902 L
.40914 .30902 L
.40997 .30902 L
.41086 .30902 L
.41127 .30902 L
Mistroke
.41171 .30902 L
.41211 .30902 L
.41248 .30902 L
.41287 .30902 L
.41325 .30902 L
.41345 .30902 L
.41364 .30902 L
.41374 .30902 L
.41384 .30902 L
.4139 .30902 L
.41396 .30902 L
.41406 .30902 L
.41416 .30902 L
.41425 .30902 L
.41435 .30902 L
.41441 .30902 L
.41446 .30902 L
.41455 .30902 L
.41465 .30902 L
.41483 .30902 L
.4152 .30902 L
.41554 .30902 L
.41705 .30902 L
.4187 .30902 L
.41951 .30902 L
.42027 .30902 L
.42069 .30902 L
.42115 .30902 L
.42156 .30902 L
.42195 .30902 L
.42231 .30902 L
.4227 .30902 L
.42291 .30902 L
.42313 .30902 L
.42332 .30902 L
.42353 .30902 L
.42365 .30902 L
.4237 .30902 L
.42375 .30902 L
.42385 .30902 L
.42395 .30902 L
.42406 .30902 L
.42412 .30902 L
.42417 .30902 L
.42423 .30902 L
.42428 .30902 L
.42441 .30902 L
.42451 .30902 L
.4246 .30902 L
.42482 .30902 L
Mistroke
.42522 .30902 L
.42607 .30902 L
.42687 .30902 L
.42836 .30902 L
.42915 .30902 L
.42997 .30902 L
.43068 .30902 L
.43146 .30902 L
.43188 .30902 L
.43228 .30902 L
.43264 .30902 L
.43284 .30902 L
.43303 .30902 L
.43312 .30902 L
.43323 .30902 L
.43332 .30902 L
.43341 .30902 L
.43352 .30902 L
.43358 .30902 L
.43364 .30902 L
.43373 .30902 L
.43384 .30902 L
.4339 .30902 L
.43395 .30902 L
.43401 .30902 L
.43407 .30902 L
.43418 .30902 L
.43429 .30902 L
.43451 .30902 L
.43471 .30902 L
.43511 .30902 L
.43554 .30902 L
.43634 .30902 L
.43782 .30902 L
.43941 .30902 L
.44029 .30902 L
.44109 .30902 L
.44149 .30902 L
.4419 .30902 L
.44226 .30902 L
.44246 .30902 L
.44264 .30902 L
.44275 .30902 L
.44286 .30902 L
.44296 .30902 L
.44307 .30902 L
.44316 .30902 L
.44327 .30902 L
.44336 .30902 L
.44345 .30902 L
Mistroke
.4435 .30902 L
.44356 .30902 L
.44367 .30902 L
.44377 .30902 L
.44387 .30902 L
.44408 .30902 L
.44432 .30902 L
.44475 .30902 L
.44514 .30902 L
.44603 .30902 L
.44765 .30902 L
.44838 .30902 L
.44916 .30902 L
.44961 .30902 L
.45002 .30902 L
.45041 .30902 L
.45082 .30902 L
.4512 .30902 L
.4514 .30902 L
.45162 .30902 L
.45182 .30902 L
.452 .30902 L
.45217 .30902 L
.45235 .30902 L
.45246 .30902 L
.45256 .30902 L
.45265 .30902 L
.45274 .30902 L
.45285 .30902 L
.45295 .30902 L
.453 .30902 L
.45305 .30902 L
.45311 .30902 L
.45317 .30902 L
.45322 .30902 L
.45328 .30902 L
.45338 .30902 L
.45358 .30902 L
.45381 .30902 L
.45402 .30902 L
.45487 .30902 L
.45567 .30902 L
.45717 .30902 L
.45795 .30902 L
.45878 .30902 L
.45949 .30902 L
.45986 .30902 L
.46026 .30902 L
.46069 .30902 L
.46088 .30902 L
Mistroke
.46109 .30902 L
.46127 .30902 L
.46147 .30902 L
.46166 .30902 L
.46183 .30902 L
.46193 .30902 L
.46204 .30902 L
.46209 .30902 L
.46215 .30902 L
.46226 .30902 L
.46236 .30902 L
.46246 .30902 L
.46255 .30902 L
.46264 .30902 L
.46275 .30902 L
.46286 .30902 L
.4631 .30902 L
.46331 .30902 L
.46351 .30902 L
.46435 .30902 L
.46514 .30902 L
.46663 .30902 L
.46741 .30902 L
.46823 .30902 L
.46893 .30902 L
.46933 .30902 L
.46971 .30902 L
.47008 .30902 L
.4705 .30902 L
.4707 .30902 L
.47092 .30902 L
.47103 .30902 L
.47113 .30902 L
.47123 .30902 L
.47133 .30902 L
.47142 .30902 L
.4715 .30902 L
.4716 .30902 L
.4717 .30902 L
.47179 .30902 L
.47187 .30902 L
.47195 .30902 L
.47204 .30902 L
.47214 .30902 L
.47223 .30902 L
.47244 .30902 L
.47281 .30902 L
.47362 .30902 L
.47436 .30902 L
.47603 .30902 L
Mistroke
.47676 .30902 L
.47754 .30902 L
.47799 .30902 L
.4784 .30902 L
.47879 .30902 L
.4792 .30902 L
.47958 .30902 L
.47979 .30902 L
.47999 .30902 L
.48017 .30902 L
.48035 .30902 L
.48044 .30902 L
.48055 .30902 L
.48064 .30902 L
.48073 .30902 L
.48084 .30902 L
.48089 .30902 L
.48095 .30902 L
.48105 .30902 L
.48115 .30902 L
.48125 .30902 L
.48134 .30902 L
.48143 .30902 L
.48154 .30902 L
.48177 .30902 L
.48199 .30902 L
.4824 .30902 L
.48401 .30902 L
.48547 .30902 L
.48629 .30902 L
.48705 .30902 L
.48747 .30902 L
.48786 .30902 L
.48829 .30902 L
.48852 .30902 L
.48874 .30902 L
.48893 .30902 L
.48914 .30902 L
.48933 .30902 L
.4895 .30902 L
.48969 .30902 L
.4898 .30902 L
.4899 .30902 L
.49 .30902 L
.4901 .30902 L
.49015 .30902 L
.49021 .30902 L
.49027 .30902 L
.49032 .30902 L
.49041 .30902 L
Mistroke
.49051 .30902 L
.49069 .30902 L
.49087 .30902 L
.49103 .30902 L
.49179 .30902 L
.49343 .30902 L
.49423 .30902 L
.49496 .30902 L
.49571 .30902 L
.49643 .30902 L
.49682 .30902 L
.49718 .30902 L
.49758 .30902 L
.49779 .30902 L
.49801 .30902 L
.49819 .30902 L
.4984 .30902 L
.49858 .30902 L
.49876 .30902 L
.49886 .30902 L
.49896 .30902 L
.49905 .30902 L
.49915 .30902 L
.49926 .30902 L
.49931 .30902 L
.49937 .30902 L
.49947 .30902 L
.49957 .30902 L
.49976 .30902 L
.49994 .30902 L
.50028 .30902 L
.50104 .30902 L
.50265 .30902 L
.5041 .30902 L
.50492 .30902 L
.50569 .30902 L
.50611 .30902 L
.50649 .30902 L
.50692 .30902 L
.50713 .30902 L
.50737 .30902 L
.50757 .30902 L
.50769 .30902 L
.50779 .30902 L
.50788 .30902 L
.50798 .30902 L
.50809 .30902 L
.50819 .30902 L
.50828 .30902 L
.50838 .30902 L
Mistroke
.50846 .30902 L
.50855 .30902 L
.50875 .30902 L
.50894 .30902 L
.50936 .30902 L
.50975 .30902 L
.51062 .30902 L
.51143 .30902 L
.51229 .30902 L
.51309 .30902 L
.51383 .30902 L
.51454 .30902 L
.51494 .30902 L
.5153 .30902 L
.5157 .30902 L
.51592 .30902 L
.51613 .30902 L
.51631 .30902 L
.51651 .30902 L
.51662 .30902 L
.51667 .30902 L
.51672 .30902 L
.51683 .30902 L
.51692 .30902 L
.51702 .30902 L
.51707 .30902 L
.51713 .30902 L
.51722 .30902 L
.51732 .30902 L
.51741 .30902 L
.51749 .30902 L
.51768 .30902 L
.51808 .30902 L
.5185 .30902 L
.51998 .30902 L
.52079 .30902 L
.52167 .30902 L
.52208 .30902 L
.52251 .30902 L
.52328 .30902 L
.52372 .30902 L
.52411 .30902 L
.52455 .30902 L
.52476 .30902 L
.525 .30902 L
.52511 .30902 L
.52522 .30902 L
.52531 .30902 L
.52541 .30902 L
.52546 .30902 L
Mistroke
.52552 .30902 L
.52562 .30902 L
.52567 .30902 L
.52573 .30902 L
.52579 .30902 L
.52584 .30902 L
.52594 .30902 L
.52602 .30902 L
.52612 .30902 L
.52622 .30902 L
.52643 .30902 L
.52662 .30902 L
.52742 .30902 L
.52816 .30902 L
.52903 .30902 L
.52983 .30902 L
.53062 .30902 L
.53134 .30902 L
.53175 .30902 L
.53214 .30902 L
.53255 .30902 L
.53276 .30902 L
.533 .30902 L
.53322 .30902 L
.53342 .30902 L
.53362 .30902 L
.53383 .30902 L
.53392 .30902 L
.53401 .30902 L
.5341 .30902 L
.53419 .30902 L
.53429 .30902 L
.53439 .30902 L
.53449 .30902 L
.53458 .30902 L
.53468 .30902 L
.53478 .30902 L
.53488 .30902 L
.53497 .30902 L
.53518 .30902 L
.5354 .30902 L
.53626 .30902 L
.53787 .30902 L
.53857 .30902 L
.53933 .30902 L
.53975 .30902 L
.54014 .30902 L
.54053 .30902 L
.5409 .30902 L
.54129 .30902 L
Mistroke
.54152 .30902 L
.54172 .30902 L
.54192 .30902 L
.54214 .30902 L
.54226 .30902 L
.54237 .30902 L
.54248 .30902 L
.54259 .30902 L
.54268 .30902 L
.54278 .30902 L
.54287 .30902 L
.54296 .30902 L
.54306 .30902 L
.54315 .30902 L
.5432 .30902 L
.54326 .30902 L
.54336 .30902 L
.54345 .30902 L
.54354 .30902 L
.54374 .30902 L
.54408 .30902 L
.54494 .30902 L
.54574 .30902 L
.54723 .30902 L
.54807 .30902 L
.54885 .30902 L
.54928 .30902 L
.54967 .30902 L
.54989 .30902 L
.55012 .30902 L
.55033 .30902 L
.55055 .30902 L
.55076 .30902 L
.55096 .30902 L
.55106 .30902 L
.55117 .30902 L
.55128 .30902 L
.55133 .30902 L
.55139 .30902 L
.55148 .30902 L
.55158 .30902 L
.55167 .30902 L
.55176 .30902 L
.55186 .30902 L
.55195 .30902 L
.55206 .30902 L
.55216 .30902 L
.55237 .30902 L
.55256 .30902 L
.55293 .30902 L
Mistroke
.55375 .30902 L
.55522 .30902 L
.556 .30902 L
.55683 .30902 L
.55754 .30902 L
.55794 .30902 L
.55831 .30902 L
.55871 .30902 L
.55894 .30902 L
.55915 .30902 L
.55935 .30902 L
.55953 .30902 L
.55964 .30902 L
.55974 .30902 L
.55985 .30902 L
.55994 .30902 L
.56003 .30902 L
.56012 .30902 L
.56021 .30902 L
.56029 .30902 L
.56038 .30902 L
.56048 .30902 L
.56058 .30902 L
.56067 .30902 L
.56104 .30902 L
.56143 .30902 L
.56302 .30902 L
.56371 .30902 L
.56447 .30902 L
.56488 .30902 L
.56527 .30902 L
.56603 .30902 L
.56645 .30902 L
.56684 .30902 L
.56705 .30902 L
.56728 .30902 L
.5675 .30902 L
.5677 .30902 L
.5679 .30902 L
.56808 .30902 L
.56818 .30902 L
.56823 .30902 L
.56829 .30902 L
.56839 .30902 L
.56848 .30902 L
.56857 .30902 L
.56866 .30902 L
.56875 .30902 L
.56883 .30902 L
.56892 .30902 L
Mistroke
.56902 .30902 L
.56921 .30902 L
.56963 .30902 L
.57007 .30902 L
.57087 .30902 L
.57247 .30902 L
.57291 .30902 L
.57337 .30902 L
.57377 .30902 L
.5742 .30902 L
.57461 .30902 L
.57499 .30902 L
.57537 .30902 L
.57573 .30902 L
.57593 .30902 L
.57604 .30902 L
.57615 .30902 L
.57624 .30902 L
.57635 .30902 L
.57644 .30902 L
.57653 .30902 L
.57664 .30902 L
.57669 .30902 L
.57675 .30902 L
.57682 .30902 L
.57688 .30902 L
.57693 .30902 L
.57699 .30902 L
.57709 .30902 L
.57715 .30902 L
.57721 .30902 L
.57741 .30902 L
.5776 .30902 L
.5778 .30902 L
.57822 .30902 L
.57896 .30902 L
.57984 .30902 L
.58064 .30902 L
.58145 .30902 L
.58222 .30902 L
.58264 .30902 L
.58302 .30902 L
.58345 .30902 L
.58366 .30902 L
.5839 .30902 L
.5841 .30902 L
.58432 .30902 L
.58442 .30902 L
.58453 .30902 L
.58462 .30902 L
Mistroke
.58472 .30902 L
.58481 .30902 L
.5849 .30902 L
.58498 .30902 L
.58507 .30902 L
.58517 .30902 L
.58526 .30902 L
.58536 .30902 L
.58546 .30902 L
.58558 .30902 L
.58568 .30902 L
.58591 .30902 L
.58634 .30902 L
.58714 .30902 L
.58793 .30902 L
.58877 .30902 L
.58957 .30902 L
.5903 .30902 L
.59069 .30902 L
.59105 .30902 L
.59144 .30902 L
.59164 .30902 L
.59186 .30902 L
.59207 .30902 L
.59226 .30902 L
.59244 .30902 L
.59263 .30902 L
.59272 .30902 L
.59281 .30902 L
.59289 .30902 L
.59297 .30902 L
.59307 .30902 L
.59316 .30902 L
.59325 .30902 L
.59334 .30902 L
.59343 .30902 L
.59353 .30902 L
.59362 .30902 L
.59371 .30902 L
.59392 .30902 L
.59411 .30902 L
.59484 .30902 L
.59649 .30902 L
.59734 .30902 L
.59775 .30902 L
.59813 .30902 L
.59885 .30902 L
.59923 .30902 L
.59963 .30902 L
.59983 .30902 L
Mistroke
.60002 .30902 L
.6002 .30902 L
.60038 .30902 L
.60059 .30902 L
.60077 .30902 L
.60089 .30902 L
.601 .30902 L
.60109 .30902 L
.6012 .30902 L
.60129 .30902 L
.60138 .30902 L
.60147 .30902 L
.60157 .30902 L
.60168 .30902 L
.60178 .30902 L
.60196 .30902 L
.60214 .30902 L
.6023 .30902 L
.60267 .30902 L
.6043 .30902 L
.6051 .30902 L
.60583 .30902 L
.60618 .30902 L
.60658 .30902 L
.60695 .30902 L
.60729 .30902 L
.60768 .30902 L
.60788 .30902 L
.6081 .30902 L
.60831 .30902 L
.60849 .30902 L
.60867 .30902 L
.60886 .30902 L
.60896 .30902 L
.60907 .30902 L
.60917 .30902 L
.60926 .30902 L
.60934 .30902 L
.60943 .30902 L
.60953 .30902 L
.60962 .30902 L
.60972 .30902 L
.60983 .30902 L
.61001 .30902 L
.61022 .30902 L
.61044 .30902 L
.61191 .30902 L
.61272 .30902 L
.61348 .30902 L
.6139 .30902 L
Mistroke
.61436 .30902 L
.61477 .30902 L
.61516 .30902 L
.61553 .30902 L
.61592 .30902 L
.61614 .30902 L
.61636 .30902 L
.61655 .30902 L
.61676 .30902 L
.61687 .30902 L
.61698 .30902 L
.61708 .30902 L
.61718 .30902 L
.61723 .30902 L
.61729 .30902 L
.61736 .30902 L
.61742 .30902 L
.61752 .30902 L
.61758 .30902 L
.61763 .30902 L
.61774 .30902 L
.61783 .30902 L
.61805 .30902 L
.61824 .30902 L
.61844 .30902 L
.62003 .30902 L
.62072 .30902 L
.62148 .30902 L
.62224 .30902 L
.62265 .30902 L
.62303 .30902 L
.62346 .30902 L
.62384 .30902 L
.62406 .30902 L
.62429 .30902 L
.62451 .30902 L
.62461 .30902 L
.62471 .30902 L
.6248 .30902 L
.6249 .30902 L
.625 .30902 L
.62508 .30902 L
.62518 .30902 L
.62528 .30902 L
.62533 .30902 L
.62539 .30902 L
.62549 .30902 L
.62557 .30902 L
.62567 .30902 L
.62577 .30902 L
Mistroke
.62587 .30902 L
.62622 .30902 L
.62663 .30902 L
.62702 .30902 L
.62787 .30902 L
.62862 .30902 L
.62941 .30902 L
.62982 .30902 L
.63028 .30902 L
.63069 .30902 L
.63108 .30902 L
.63148 .30902 L
.6317 .30902 L
.63191 .30902 L
.63211 .30902 L
.63229 .30902 L
.63251 .30902 L
.6326 .30902 L
.6327 .30902 L
.63279 .30902 L
.63288 .30902 L
.63298 .30902 L
.63308 .30902 L
.63317 .30902 L
.63325 .30902 L
.63333 .30902 L
.63342 .30902 L
.63351 .30902 L
.63361 .30902 L
.63382 .30902 L
.63401 .30902 L
.63419 .30902 L
.63567 .30902 L
.63651 .30902 L
.6373 .30902 L
.63807 .30902 L
.63851 .30902 L
.6389 .30902 L
.63932 .30902 L
.63956 .30902 L
.63978 .30902 L
.63998 .30902 L
.64017 .30902 L
.64038 .30902 L
.64048 .30902 L
.6406 .30902 L
.6407 .30902 L
.6408 .30902 L
.64086 .30902 L
.64091 .30902 L
Mistroke
.64102 .30902 L
.64112 .30902 L
.64122 .30902 L
.64131 .30902 L
.64141 .30902 L
.64153 .30902 L
.64163 .30902 L
.64187 .30902 L
.6423 .30902 L
.64391 .30902 L
.64466 .30902 L
.64545 .30902 L
.64586 .30902 L
.64631 .30902 L
.64673 .30902 L
.64711 .30902 L
.64749 .30902 L
.64771 .30902 L
.6479 .30902 L
.64801 .30902 L
.64812 .30902 L
.64831 .30902 L
.64841 .30902 L
.64851 .30902 L
.64857 .30902 L
.64862 .30902 L
.64868 .30902 L
.64874 .30902 L
.64883 .30902 L
.64893 .30902 L
.64902 .30902 L
.64911 .30902 L
.64928 .30902 L
.64945 .30902 L
.64982 .30902 L
.65022 .30902 L
.65104 .30902 L
.6519 .30902 L
.65264 .30902 L
.65306 .30902 L
.65345 .30902 L
.65382 .30902 L
.65422 .30902 L
.65445 .30902 L
.65465 .30902 L
.65486 .30902 L
.65505 .30902 L
.6554 .30902 L
.65558 .30902 L
.65578 .30902 L
Mistroke
.65588 .30902 L
.65599 .30902 L
.65609 .30902 L
.65618 .30902 L
.65628 .30902 L
.65636 .30902 L
.65646 .30902 L
.65655 .30902 L
.65664 .30902 L
.65674 .30902 L
.65684 .30902 L
.65692 .30902 L
.65714 .30902 L
.65734 .30902 L
.65816 .30902 L
.65965 .30902 L
.66042 .30902 L
.66081 .30902 L
.66125 .30902 L
.66161 .30902 L
.66201 .30902 L
.66238 .30902 L
.66272 .30902 L
.66292 .30902 L
.66311 .30902 L
.66332 .30902 L
.66341 .30902 L
.66351 .30902 L
.6636 .30902 L
.6637 .30902 L
.66378 .30902 L
.66386 .30902 L
.66396 .30902 L
.66405 .30902 L
.66415 .30902 L
.66425 .30902 L
.66435 .30902 L
.66445 .30902 L
.66455 .30902 L
.66466 .30902 L
.66504 .30902 L
.66591 .30902 L
.66739 .30902 L
.66779 .30902 L
.66823 .30902 L
.6686 .30902 L
.66901 .30902 L
.66944 .30902 L
.66985 .30902 L
.67004 .30902 L
Mistroke
.67025 .30902 L
.67044 .30902 L
.67061 .30902 L
.67081 .30902 L
.67092 .30902 L
.67103 .30902 L
.67113 .30902 L
.67123 .30902 L
.67132 .30902 L
.67142 .30902 L
.67148 .30902 L
.67153 .30902 L
.67159 .30902 L
.67166 .30902 L
.67171 .30902 L
.67176 .30902 L
.67182 .30902 L
.67188 .30902 L
.67194 .30902 L
.672 .30902 L
.6721 .30902 L
.6723 .30902 L
.67269 .30902 L
.67306 .30902 L
.67389 .30902 L
.67471 .30902 L
.67516 .30902 L
.67558 .30902 L
.67635 .30902 L
.67676 .30902 L
.6772 .30902 L
.67739 .30902 L
.6776 .30902 L
.67778 .30902 L
.67797 .30902 L
.67815 .30902 L
.67834 .30902 L
.67852 .30902 L
.67868 .30902 L
.67878 .30902 L
.67889 .30902 L
.67899 .30902 L
.67908 .30902 L
.67914 .30902 L
.67919 .30902 L
.67925 .30902 L
.67931 .30902 L
.67941 .30902 L
.67946 .30902 L
.67952 .30902 L
Mistroke
.67972 .30902 L
.6799 .30902 L
.68031 .30902 L
.6818 .30902 L
.68254 .30902 L
.68333 .30902 L
.68374 .30902 L
.6842 .30902 L
.68461 .30902 L
.68481 .30902 L
.685 .30902 L
.68538 .30902 L
.68558 .30902 L
.68579 .30902 L
.6859 .30902 L
.68601 .30902 L
.68612 .30902 L
.68623 .30902 L
.68632 .30902 L
.68638 .30902 L
.68643 .30902 L
.68653 .30902 L
.68662 .30902 L
.68672 .30902 L
.68681 .30902 L
.68691 .30902 L
.68696 .30902 L
.68702 .30902 L
.68721 .30902 L
.6874 .30902 L
.68811 .30902 L
.68959 .30902 L
.68999 .30902 L
.69043 .30902 L
.6908 .30902 L
.69121 .30902 L
.69164 .30902 L
.69205 .30902 L
.69224 .30902 L
.69245 .30902 L
.69281 .30902 L
.69302 .30902 L
.69323 .30902 L
.69334 .30902 L
.69343 .30902 L
.69362 .30902 L
.69373 .30902 L
.69379 .30902 L
.69384 .30902 L
.69389 .30902 L
Mistroke
.69395 .30902 L
.69404 .30902 L
.6941 .30902 L
.69416 .30902 L
.69423 .30902 L
.69429 .30902 L
.69434 .30902 L
.69439 .30902 L
.69451 .30902 L
.69469 .30902 L
.69489 .30902 L
.6953 .30902 L
.69604 .30902 L
.69691 .30902 L
.69771 .30902 L
.69846 .30902 L
.69884 .30902 L
.69926 .30902 L
.69968 .30902 L
.69991 .30902 L
.70013 .30902 L
.70033 .30902 L
.70054 .30902 L
.70075 .30902 L
.70093 .30902 L
.70104 .30902 L
.70113 .30902 L
.70122 .30902 L
.70131 .30902 L
.70141 .30902 L
.70147 .30902 L
.70152 .30902 L
.70162 .30902 L
.70171 .30902 L
.7018 .30902 L
.7019 .30902 L
.70206 .30902 L
.70244 .30902 L
.7041 .30902 L
.70486 .30902 L
.70528 .30902 L
.70568 .30902 L
.70605 .30902 L
.70645 .30902 L
.70681 .30902 L
.70715 .30902 L
.70752 .30902 L
.70773 .30902 L
.70793 .30902 L
.7081 .30902 L
Mistroke
.7082 .30902 L
.7083 .30902 L
.70839 .30902 L
.70848 .30902 L
.70857 .30902 L
.70865 .30902 L
.70875 .30902 L
.70885 .30902 L
.70891 .30902 L
.70896 .30902 L
.70907 .30902 L
.70917 .30902 L
.70927 .30902 L
.70945 .30902 L
.70986 .30902 L
.71031 .30902 L
.71106 .30902 L
.71186 .30902 L
.71232 .30902 L
.71275 .30902 L
.71318 .30902 L
.71358 .30902 L
.71393 .30902 L
.71431 .30902 L
.71453 .30902 L
.71473 .30902 L
.71491 .30902 L
.71511 .30902 L
.71531 .30902 L
.71541 .30902 L
.71552 .30902 L
.71562 .30902 L
.71571 .30902 L
.7158 .30902 L
.71589 .30902 L
.71599 .30902 L
.71605 .30902 L
.7161 .30902 L
.7162 .30902 L
.71629 .30902 L
.71634 .30902 L
.7164 .30902 L
.7165 .30902 L
.71673 .30902 L
.71713 .30902 L
.71749 .30902 L
.71831 .30902 L
.71902 .30902 L
.71978 .30902 L
.72016 .30902 L
Mistroke
.72058 .30902 L
.72096 .30902 L
.72131 .30902 L
.72152 .30902 L
.72173 .30902 L
.72192 .30902 L
.72212 .30902 L
.72233 .30902 L
.72253 .30902 L
.72265 .30902 L
.72276 .30902 L
.72287 .30902 L
.72298 .30902 L
.72308 .30902 L
.72317 .30902 L
.72327 .30902 L
.72337 .30902 L
.72346 .30902 L
.72355 .30902 L
.72364 .30902 L
.72374 .30902 L
.72397 .30902 L
.72418 .30902 L
.72458 .30902 L
.7254 .30902 L
.72627 .30902 L
.72704 .30902 L
.72748 .30902 L
.72788 .30902 L
.72826 .30902 L
.7286 .30902 L
.72879 .30902 L
.72899 .30902 L
.72919 .30902 L
.72937 .30902 L
.72956 .30902 L
.72976 .30902 L
.72985 .30902 L
.72995 .30902 L
.73004 .30902 L
.73012 .30902 L
.73018 .30902 L
.73023 .30902 L
.73033 .30902 L
.73039 .30902 L
.73045 .30902 L
.7305 .30902 L
.73056 .30902 L
.73066 .30902 L
.73071 .30902 L
Mistroke
.73077 .30902 L
.73086 .30902 L
.73096 .30902 L
.73116 .30902 L
.73138 .30902 L
.73177 .30902 L
.73265 .30902 L
.7334 .30902 L
.73379 .30902 L
.73421 .30902 L
.73458 .30902 L
.73498 .30902 L
.73534 .30902 L
.73568 .30902 L
.73608 .30902 L
.73631 .30902 L
.73652 .30902 L
.73671 .30902 L
.73691 .30902 L
.73701 .30902 L
.73712 .30902 L
.73722 .30902 L
.73732 .30902 L
.73741 .30902 L
.73751 .30902 L
.7376 .30902 L
.73769 .30902 L
.73778 .30902 L
.73784 .30902 L
.73789 .30902 L
.73798 .30902 L
.73808 .30902 L
.73843 .30902 L
.73881 .30902 L
.73968 .30902 L
.74051 .30902 L
.74125 .30902 L
.74167 .30902 L
.74206 .30902 L
.74243 .30902 L
.74278 .30902 L
.74316 .30902 L
.74338 .30902 L
.74358 .30902 L
.74377 .30902 L
.74395 .30902 L
.74415 .30902 L
.74426 .30902 L
.74436 .30902 L
.74447 .30902 L
Mistroke
.74457 .30902 L
.74462 .30902 L
.74467 .30902 L
.74473 .30902 L
.74479 .30902 L
.74489 .30902 L
.74498 .30902 L
.74503 .30902 L
.74509 .30902 L
.74519 .30902 L
.74557 .30902 L
.74594 .30902 L
.74677 .30902 L
.74759 .30902 L
.74804 .30902 L
.74846 .30902 L
.74886 .30902 L
.74923 .30902 L
.74964 .30902 L
.74987 .30902 L
.75007 .30902 L
.75044 .30902 L
.75063 .30902 L
.75084 .30902 L
.75102 .30902 L
.75118 .30902 L
.75128 .30902 L
.75136 .30902 L
.75146 .30902 L
.75156 .30902 L
.75166 .30902 L
.75172 .30902 L
.75177 .30902 L
.75186 .30902 L
.75196 .30902 L
.75205 .30902 L
.75214 .30902 L
.75233 .30902 L
.75273 .30902 L
.75315 .30902 L
.75392 .30902 L
.75463 .30902 L
.75544 .30902 L
.75587 .30902 L
.75633 .30902 L
.75673 .30902 L
.7571 .30902 L
.75731 .30902 L
.75751 .30902 L
.75772 .30902 L
Mistroke
.75783 .30902 L
.75795 .30902 L
.75806 .30902 L
.75815 .30902 L
.75825 .30902 L
.75835 .30902 L
.75844 .30902 L
.75853 .30902 L
.75862 .30902 L
.75871 .30902 L
.75882 .30902 L
.75888 .30902 L
.75893 .30902 L
.75904 .30902 L
.75909 .30902 L
.75914 .30902 L
.75934 .30902 L
.75953 .30902 L
.76101 .30902 L
.76179 .30902 L
.76222 .30902 L
.76262 .30902 L
.76299 .30902 L
.76333 .30902 L
.76371 .30902 L
.7639 .30902 L
.76411 .30902 L
.76429 .30902 L
.7645 .30902 L
.76471 .30902 L
.76491 .30902 L
.765 .30902 L
.7651 .30902 L
.76519 .30902 L
.76529 .30902 L
.76539 .30902 L
.76547 .30902 L
.76556 .30902 L
.76564 .30902 L
.76574 .30902 L
.76585 .30902 L
.7659 .30902 L
.76596 .30902 L
.76606 .30902 L
.76616 .30902 L
.76626 .30902 L
.76644 .30902 L
.76731 .30902 L
.76801 .30902 L
.76877 .30902 L
Mistroke
.76921 .30902 L
.76961 .30902 L
.76999 .30902 L
.77039 .30902 L
.77078 .30902 L
.77114 .30902 L
.77135 .30902 L
.77155 .30902 L
.77177 .30902 L
.77186 .30902 L
.77197 .30902 L
.77207 .30902 L
.77218 .30902 L
.77229 .30902 L
.77239 .30902 L
.7725 .30902 L
.7726 .30902 L
.77269 .30902 L
.77278 .30902 L
.77284 .30902 L
.7729 .30902 L
.773 .30902 L
.77312 .30902 L
.77324 .30902 L
.77366 .30902 L
.77523 .30902 L
.77566 .30902 L
.77612 .30902 L
.77655 .30902 L
.77695 .30902 L
.77736 .30902 L
.77757 .30902 L
.77781 .30902 L
.7782 .30902 L
.77841 .30902 L
.77861 .30902 L
.7788 .30902 L
.7789 .30902 L
.77899 .30902 L
.77908 .30902 L
.77916 .30902 L
.77925 .30902 L
.77934 .30902 L
.77944 .30902 L
.77954 .30902 L
.77964 .30902 L
.77969 .30902 L
.77975 .30902 L
.77984 .30902 L
.77994 .30902 L
Mistroke
.78013 .30902 L
.78171 .30902 L
.78255 .30902 L
.78297 .30902 L
.78344 .30902 L
.78385 .30902 L
.78407 .30902 L
.7843 .30902 L
.7845 .30902 L
.78472 .30902 L
.78492 .30902 L
.7851 .30902 L
.78528 .30902 L
.78548 .30902 L
.78559 .30902 L
.7857 .30902 L
.7858 .30902 L
.7859 .30902 L
.78598 .30902 L
.78607 .30902 L
.78616 .30902 L
.78626 .30902 L
.78635 .30902 L
.78645 .30902 L
.78655 .30902 L
.78664 .30902 L
.78674 .30902 L
.78685 .30902 L
.78704 .30902 L
.78748 .30902 L
.78828 .30902 L
.78907 .30902 L
.78978 .30902 L
.79017 .30902 L
.79054 .30902 L
.79093 .30902 L
.79113 .30902 L
.79135 .30902 L
.79172 .30902 L
.79193 .30902 L
.79212 .30902 L
.7923 .30902 L
.79246 .30902 L
.79264 .30902 L
.79273 .30902 L
.79283 .30902 L
.79293 .30902 L
.79303 .30902 L
.79308 .30902 L
.79314 .30902 L
Mistroke
.7932 .30902 L
.79325 .30902 L
.79335 .30902 L
.79344 .30902 L
.79349 .30902 L
.79355 .30902 L
.79365 .30902 L
.79404 .30902 L
.7944 .30902 L
.79527 .30902 L
.79608 .30902 L
.79647 .30902 L
.79688 .30902 L
.79732 .30902 L
.79773 .30902 L
.7981 .30902 L
.79845 .30902 L
.79864 .30902 L
.79882 .30902 L
.79903 .30902 L
.79913 .30902 L
.79923 .30902 L
.79933 .30902 L
.79942 .30902 L
.79951 .30902 L
.7996 .30902 L
.79969 .30902 L
.7998 .30902 L
.7999 .30902 L
.79995 .30902 L
.8 .30902 L
.80011 .30902 L
.80021 .30902 L
.80026 .30902 L
.80032 .30902 L
.80043 .30902 L
.80083 .30902 L
.80231 .30902 L
.80273 .30902 L
.80313 .30902 L
.80349 .30902 L
.80387 .30902 L
.80429 .30902 L
.80468 .30902 L
.80489 .30902 L
.80509 .30902 L
.80531 .30902 L
.80555 .30902 L
.80574 .30902 L
.80585 .30902 L
Mistroke
.80595 .30902 L
.80604 .30902 L
.80614 .30902 L
.80623 .30902 L
.80632 .30902 L
.80642 .30902 L
.80647 .30902 L
.80653 .30902 L
.80659 .30902 L
.80665 .30902 L
.8067 .30902 L
.80675 .30902 L
.80686 .30902 L
.80691 .30902 L
.80696 .30902 L
.80716 .30902 L
.80738 .30902 L
.80758 .30902 L
.80803 .30902 L
.80885 .30902 L
.80963 .30902 L
.81001 .30902 L
.81036 .30902 L
.81078 .30902 L
.81116 .30902 L
.81158 .30902 L
.81181 .30902 L
.81202 .30902 L
.81222 .30902 L
.81239 .30902 L
.81259 .30902 L
.81269 .30902 L
.8128 .30902 L
.81289 .30902 L
.81298 .30902 L
.81308 .30902 L
.81317 .30902 L
.81326 .30902 L
.81334 .30902 L
.81343 .30902 L
.81352 .30902 L
.81362 .30902 L
.81372 .30902 L
.81393 .30902 L
.81431 .30902 L
.81518 .30902 L
.81592 .30902 L
.8167 .30902 L
.81716 .30902 L
.81757 .30902 L
Mistroke
.81777 .30902 L
.81798 .30902 L
.81837 .30902 L
.81856 .30902 L
.81877 .30902 L
.81896 .30902 L
.81914 .30902 L
.81934 .30902 L
.81946 .30902 L
.81957 .30902 L
.81966 .30902 L
.81976 .30902 L
.81982 .30902 L
.81987 .30902 L
.81997 .30902 L
.82003 .30902 L
.82009 .30902 L
.82019 .30902 L
.82025 .30902 L
.82031 .30902 L
.82043 .30902 L
.82063 .30902 L
.82086 .30902 L
.82167 .30902 L
.82249 .30902 L
.82327 .30902 L
.82366 .30902 L
.82407 .30902 L
.82431 .30902 L
.82454 .30902 L
.82475 .30902 L
.82496 .30902 L
.82533 .30902 L
.82552 .30902 L
.82573 .30902 L
.82594 .30902 L
.82605 .30902 L
.82616 .30902 L
.82626 .30902 L
.82637 .30902 L
.82646 .30902 L
.82655 .30902 L
.82665 .30902 L
.82674 .30902 L
.82683 .30902 L
.82692 .30902 L
.82702 .30902 L
.82712 .30902 L
.82732 .30902 L
.82803 .30902 L
Mistroke
.82885 .30902 L
.82928 .30902 L
.82973 .30902 L
.83017 .30902 L
.83057 .30902 L
.83097 .30902 L
.83116 .30902 L
.83135 .30902 L
.83172 .30902 L
.83192 .30902 L
.83213 .30902 L
.83224 .30902 L
.83235 .30902 L
.83246 .30902 L
.83256 .30902 L
.83266 .30902 L
.83277 .30902 L
.83287 .30902 L
.83296 .30902 L
.83305 .30902 L
.83314 .30902 L
.83324 .30902 L
.83333 .30902 L
.83342 .30902 L
.8335 .30902 L
.83367 .30902 L
.83386 .30902 L
.83407 .30902 L
.83444 .30902 L
.83527 .30902 L
.83604 .30902 L
.83643 .30902 L
.83685 .30902 L
.83731 .30902 L
.83751 .30902 L
.83773 .30902 L
.83812 .30902 L
.83833 .30902 L
.83853 .30902 L
.83871 .30902 L
.83888 .30902 L
.83907 .30902 L
.83916 .30902 L
.83926 .30902 L
.83937 .30902 L
.83948 .30902 L
.83957 .30902 L
.83968 .30902 L
.83973 .30902 L
.83979 .30902 L
Mistroke
.83985 .30902 L
.83991 .30902 L
.84001 .30902 L
.84007 .30902 L
.84012 .30902 L
.84032 .30902 L
.84054 .30902 L
.84093 .30902 L
.84181 .30902 L
.84224 .30902 L
.84264 .30902 L
.84299 .30902 L
.84338 .30902 L
.84378 .30902 L
.84399 .30902 L
.84419 .30902 L
.84439 .30902 L
.8446 .30902 L
.84478 .30902 L
.84497 .30902 L
.84519 .30902 L
.84529 .30902 L
.84541 .30902 L
.84552 .30902 L
.84562 .30902 L
.84571 .30902 L
.84582 .30902 L
.84591 .30902 L
.846 .30902 L
.84609 .30902 L
.84617 .30902 L
.84626 .30902 L
.84635 .30902 L
.84645 .30902 L
.84655 .30902 L
.84665 .30902 L
.84675 .30902 L
.84692 .30902 L
.84733 .30902 L
.8481 .30902 L
.84892 .30902 L
.84939 .30902 L
.84981 .30902 L
.85024 .30902 L
.85044 .30902 L
.85065 .30902 L
.85104 .30902 L
.85125 .30902 L
.85145 .30902 L
.85163 .30902 L
Mistroke
.8518 .30902 L
.85189 .30902 L
.852 .30902 L
.85218 .30902 L
.85228 .30902 L
.85238 .30902 L
.85249 .30902 L
.85254 .30902 L
.8526 .30902 L
.85266 .30902 L
.85271 .30902 L
.85277 .30902 L
.85283 .30902 L
.85288 .30902 L
.85294 .30902 L
.85304 .30902 L
.85314 .30902 L
.85324 .30902 L
.85342 .30902 L
.85384 .30902 L
.85466 .30902 L
.85543 .30902 L
.85613 .30902 L
.85652 .30902 L
.85688 .30902 L
.85725 .30902 L
.85745 .30902 L
.85764 .30902 L
.85783 .30902 L
.85803 .30902 L
.85825 .30902 L
.85845 .30902 L
.85855 .30902 L
.85865 .30902 L
.85876 .30902 L
.85886 .30902 L
.85896 .30902 L
.85905 .30902 L
.85915 .30902 L
.85925 .30902 L
.85935 .30902 L
.85941 .30902 L
.85947 .30902 L
.85967 .30902 L
.8599 .30902 L
.86013 .30902 L
.86096 .30902 L
.86174 .30902 L
.86244 .30902 L
.86283 .30902 L
Mistroke
.8632 .30902 L
.86356 .30902 L
.86377 .30902 L
.86397 .30902 L
.86417 .30902 L
.86436 .30902 L
.86458 .30902 L
.86478 .30902 L
.86487 .30902 L
.86498 .30902 L
.86509 .30902 L
.8652 .30902 L
.86529 .30902 L
.86538 .30902 L
.86548 .30902 L
.86558 .30902 L
.86569 .30902 L
.86575 .30902 L
.8658 .30902 L
.8659 .30902 L
.866 .30902 L
.86622 .30902 L
.86646 .30902 L
.86722 .30902 L
.86803 .30902 L
.86849 .30902 L
.86892 .30902 L
.86934 .30902 L
.86975 .30902 L
.87013 .30902 L
.87034 .30902 L
.87053 .30902 L
.87072 .30902 L
.87091 .30902 L
.87109 .30902 L
.87126 .30902 L
.87136 .30902 L
.87146 .30902 L
.87156 .30902 L
.87165 .30902 L
.87175 .30902 L
.87181 .30902 L
.87186 .30902 L
.87196 .30902 L
.87207 .30902 L
.87217 .30902 L
.87222 .30902 L
.87227 .30902 L
.87247 .30902 L
.8727 .30902 L
Mistroke
.87291 .30902 L
.87374 .30902 L
.87452 .30902 L
.87522 .30902 L
.87562 .30902 L
.87598 .30902 L
.87634 .30902 L
.87655 .30902 L
.87675 .30902 L
.87695 .30902 L
.87714 .30902 L
.87736 .30902 L
.87756 .30902 L
.87765 .30902 L
.87776 .30902 L
.87787 .30902 L
.87798 .30902 L
.87807 .30902 L
.87816 .30902 L
.87826 .30902 L
.87836 .30902 L
.87847 .30902 L
.87853 .30902 L
.87858 .30902 L
.87878 .30902 L
.87902 .30902 L
.87924 .30902 L
.87995 .30902 L
.88071 .30902 L
.88115 .30902 L
.88155 .30902 L
.88195 .30902 L
.88233 .30902 L
.88252 .30902 L
.88272 .30902 L
.88309 .30902 L
.88332 .30902 L
.88353 .30902 L
.88372 .30902 L
.88383 .30902 L
.88392 .30902 L
.88403 .30902 L
.88413 .30902 L
.88424 .30902 L
.8843 .30902 L
.88435 .30902 L
.88441 .30902 L
.88447 .30902 L
.88457 .30902 L
.88463 .30902 L
Mistroke
.88468 .30902 L
.88474 .30902 L
.8848 .30902 L
.8849 .30902 L
.88501 .30902 L
.88523 .30902 L
.88561 .30902 L
.88649 .30902 L
.88692 .30902 L
.88732 .30902 L
.88768 .30902 L
.88807 .30902 L
.88846 .30902 L
.88867 .30902 L
.88887 .30902 L
.88907 .30902 L
.88928 .30902 L
.88946 .30902 L
.88966 .30902 L
.88987 .30902 L
.88998 .30902 L
.89009 .30902 L
.8902 .30902 L
.8903 .30902 L
.89039 .30902 L
.8905 .30902 L
.89059 .30902 L
.89068 .30902 L
.89077 .30902 L
.89085 .30902 L
.89094 .30902 L
.89103 .30902 L
.89113 .30902 L
.89123 .30902 L
.89142 .30902 L
.8916 .30902 L
.89201 .30902 L
.89273 .30902 L
.8935 .30902 L
.89394 .30902 L
.89434 .30902 L
.89475 .30902 L
.89512 .30902 L
.89533 .30902 L
.89555 .30902 L
.89574 .30902 L
.89594 .30902 L
.89616 .30902 L
.89636 .30902 L
.89649 .30902 L
Mistroke
.8966 .30902 L
.89671 .30902 L
.89676 .30902 L
.89682 .30902 L
.89692 .30902 L
.89702 .30902 L
.89707 .30902 L
.89713 .30902 L
.89723 .30902 L
.89728 .30902 L
.89734 .30902 L
.89744 .30902 L
.89755 .30902 L
.89766 .30902 L
.89844 .30902 L
.89918 .30902 L
.89998 .30902 L
.90039 .30902 L
.90085 .30902 L
.90105 .30902 L
.90126 .30902 L
.90165 .30902 L
.90185 .30902 L
.90207 .30902 L
.90227 .30902 L
.90246 .30902 L
.90268 .30902 L
.9028 .30902 L
.90292 .30902 L
.90302 .30902 L
.90307 .30902 L
.90313 .30902 L
.90318 .30902 L
.90323 .30902 L
.90329 .30902 L
.90335 .30902 L
.90344 .30902 L
.90354 .30902 L
.90359 .30902 L
.90365 .30902 L
.90375 .30902 L
.90394 .30902 L
.90412 .30902 L
.90496 .30902 L
.9057 .30902 L
.9061 .30902 L
.90648 .30902 L
.90694 .30902 L
.90715 .30902 L
.90735 .30902 L
Mistroke
.90773 .30902 L
.90793 .30902 L
.90815 .30902 L
.90835 .30902 L
.90854 .30902 L
.90872 .30902 L
.90891 .30902 L
.90901 .30902 L
.90911 .30902 L
.90917 .30902 L
.90923 .30902 L
.90933 .30902 L
.90943 .30902 L
.90954 .30902 L
.90962 .30902 L
.90972 .30902 L
.90982 .30902 L
.90992 .30902 L
.91009 .30902 L
.91048 .30902 L
.91119 .30902 L
.91197 .30902 L
.91237 .30902 L
.9128 .30902 L
.91317 .30902 L
.91337 .30902 L
.91356 .30902 L
.91374 .30902 L
.91394 .30902 L
.91428 .30902 L
.91449 .30902 L
.91471 .30902 L
.91481 .30902 L
.91492 .30902 L
.91501 .30902 L
.91511 .30902 L
.91521 .30902 L
.9153 .30902 L
.91538 .30902 L
.91547 .30902 L
.91557 .30902 L
.91566 .30902 L
.91576 .30902 L
.91586 .30902 L
.91597 .30902 L
.91606 .30902 L
.91628 .30902 L
.91666 .30902 L
.91755 .30902 L
.91793 .30902 L
Mistroke
.91833 .30902 L
.91869 .30902 L
.91907 .30902 L
.9193 .30902 L
.91952 .30902 L
.91972 .30902 L
.91994 .30902 L
.92032 .30902 L
.92053 .30902 L
.92073 .30902 L
.92094 .30902 L
.92113 .30902 L
.92123 .30902 L
.92134 .30902 L
.9214 .30902 L
.92146 .30902 L
.92151 .30902 L
.92157 .30902 L
.92166 .30902 L
.92177 .30902 L
.92187 .30902 L
.92193 .30902 L
.92198 .30902 L
.92207 .30902 L
.92218 .30902 L
.92236 .30902 L
.92274 .30902 L
.92313 .30902 L
.92385 .30902 L
.92461 .30902 L
.92503 .30902 L
.92542 .30902 L
.92578 .30902 L
.92597 .30902 L
.92617 .30902 L
.92637 .30902 L
.92654 .30902 L
.92672 .30902 L
.92689 .30902 L
.92707 .30902 L
.92718 .30902 L
.92728 .30902 L
.92737 .30902 L
.92748 .30902 L
.92754 .30902 L
.92759 .30902 L
.92769 .30902 L
.92778 .30902 L
.92786 .30902 L
.92795 .30902 L
Mistroke
.92805 .30902 L
.92815 .30902 L
.92825 .30902 L
.92834 .30902 L
.92843 .30902 L
.92885 .30902 L
.9293 .30902 L
.9301 .30902 L
.9305 .30902 L
.93093 .30902 L
.93139 .30902 L
.9316 .30902 L
.93182 .30902 L
.93203 .30902 L
.93222 .30902 L
.93241 .30902 L
.93259 .30902 L
.9328 .30902 L
.93302 .30902 L
.93322 .30902 L
.93333 .30902 L
.93344 .30902 L
.93353 .30902 L
.93362 .30902 L
.93368 .30902 L
.93373 .30902 L
.93383 .30902 L
.93393 .30902 L
.93399 .30902 L
.93404 .30902 L
.93414 .30902 L
.93424 .30902 L
.93433 .30902 L
.93442 .30902 L
.93459 .30902 L
.93498 .30902 L
.93585 .30902 L
.93666 .30902 L
.93705 .30902 L
.93747 .30902 L
.9377 .30902 L
.93793 .30902 L
.93813 .30902 L
.93835 .30902 L
.93854 .30902 L
.93875 .30902 L
.93895 .30902 L
.93912 .30902 L
.93923 .30902 L
.93934 .30902 L
Mistroke
.93943 .30902 L
.93953 .30902 L
.93964 .30902 L
.93974 .30902 L
.93979 .30902 L
.93984 .30902 L
.9399 .30902 L
.93996 .30902 L
.94006 .30902 L
.94015 .30902 L
.94026 .30902 L
.94036 .30902 L
.94045 .30902 L
.94054 .30902 L
.94073 .30902 L
.94157 .30902 L
.94199 .30902 L
.94244 .30902 L
.94286 .30902 L
.94326 .30902 L
.94364 .30902 L
.94384 .30902 L
.94405 .30902 L
.94424 .30902 L
.94442 .30902 L
.94459 .30902 L
.94477 .30902 L
.94498 .30902 L
.94518 .30902 L
.94539 .30902 L
.94551 .30902 L
.94562 .30902 L
.94572 .30902 L
.94582 .30902 L
.94591 .30902 L
.94601 .30902 L
.94611 .30902 L
.94617 .30902 L
.94622 .30902 L
.94633 .30902 L
.94642 .30902 L
.94662 .30902 L
.9468 .30902 L
.94721 .30902 L
.94805 .30902 L
.94876 .30902 L
.94917 .30902 L
.94953 .30902 L
.94992 .30902 L
.95012 .30902 L
Mistroke
.95033 .30902 L
.95052 .30902 L
.95072 .30902 L
.9509 .30902 L
.95107 .30902 L
.95118 .30902 L
.95129 .30902 L
.95138 .30902 L
.95148 .30902 L
.9516 .30902 L
.95166 .30902 L
.95172 .30902 L
.95177 .30902 L
.95183 .30902 L
.95193 .30902 L
.95198 .30902 L
.95204 .30902 L
.95213 .30902 L
.95224 .30902 L
.9523 .30902 L
.95235 .30902 L
.95254 .30902 L
.95274 .30902 L
.95356 .30902 L
.95433 .30902 L
.95466 .30902 L
.95502 .30902 L
.95541 .30902 L
.95578 .30902 L
.95598 .30902 L
.9562 .30902 L
.95639 .30902 L
.9566 .30902 L
.95678 .30902 L
.95698 .30902 L
.95717 .30902 L
.95734 .30902 L
.95744 .30902 L
.95755 .30902 L
.95766 .30902 L
.95776 .30902 L
.95785 .30902 L
.95795 .30902 L
.95805 .30902 L
.95815 .30902 L
.95825 .30902 L
.9583 .30902 L
.95836 .30902 L
.95856 .30902 L
.95901 .30902 L
Mistroke
.95989 .30902 L
.96032 .30902 L
.96072 .30902 L
.96108 .30902 L
.96146 .30902 L
.96185 .30902 L
.96206 .30902 L
.96227 .30902 L
.96246 .30902 L
.96267 .30902 L
.96287 .30902 L
.96306 .30902 L
.96324 .30902 L
.96341 .30902 L
.9635 .30902 L
.9636 .30902 L
.96369 .30902 L
.96378 .30902 L
.96387 .30902 L
.96397 .30902 L
.96407 .30902 L
.96416 .30902 L
.96426 .30902 L
.96431 .30902 L
.96437 .30902 L
.96457 .30902 L
.9654 .30902 L
.96612 .30902 L
.9665 .30902 L
.9669 .30902 L
.96735 .30902 L
.96756 .30902 L
.96776 .30902 L
.96814 .30902 L
.96834 .30902 L
.96856 .30902 L
.96877 .30902 L
.96899 .30902 L
.96917 .30902 L
.96928 .30902 L
.96938 .30902 L
.9695 .30902 L
.96955 .30902 L
.96961 .30902 L
.9697 .30902 L
.96976 .30902 L
.96981 .30902 L
.96987 .30902 L
.96992 .30902 L
.96998 .30902 L
Mistroke
.97003 .30902 L
.97009 .30902 L
.97015 .30902 L
.97027 .30902 L
.97049 .30902 L
.97068 .30902 L
.97111 .30902 L
.97189 .30902 L
.97228 .30902 L
.97269 .30902 L
.97304 .30902 L
.97343 .30902 L
.97384 .30902 L
.97408 .30902 L
.97429 .30902 L
.97449 .30902 L
.9747 .30902 L
.97491 .30902 L
.9751 .30902 L
.97524 .30902 L
.97532 .30902 L
.97539 .30902 L
.97546 .30902 L
.97553 .30902 L
.9756 .30902 L
.97567 .30902 L
.97574 .30902 L
.9758 .30902 L
.97586 .30902 L
.97592 .30902 L
.97599 .30902 L
.97606 .30902 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{421.375, 260.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008>0001AB000`400?l00000o`00003ooooooooo
oooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo
003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooo
oooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool0
0?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooooooo
ool@ooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooo
ooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo0ol0003o
ooooomcooooo000`ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0oooooonfoooo
o`00<?ooool00ol0003oooooooooo`0Rooooo`;o0000oooooonhooooo`00<?ooool00ol0003ooooo
ooooo`0Rooooo`;o0000oooooonhooooo`00<?ooool00ol0003oooooooooo`0Rooooo`;o0000oooo
oonhooooo`00<?ooool00ol0003oooooooooo`0Rooooo`;o0000oooooonhooooo`00<?ooool00ol0
003oooooooooo`0Rooooo`;o0000oooooonhooooo`00<?ooool00ol0003oooooooooo`0Rooooo`;o
0000oooooonhooooo`00<?ooool00ol0003oooooooooo`0Rooooo`;o0000oooooonhooooo`00<?oo
ool00ol0003oooooooooo`0Rooooo`;o0000oooooonhooooo`00<?ooool00ol0003oooooooooo`0R
ooooo`;o0000oooooonhooooo`00<?ooool00ol0003oooooooooo`0Rooooo`;o0000oooooonhoooo
o`00<?ooool3o`0002;ooooo0_l0003ooooookSooooo000`ooooo`03o`000?oooooooooo02;ooooo
0_l0003ooooookSooooo000`ooooo`03o`000?oooooooooo02;ooooo0_l0003ooooookSooooo000`
ooooo`03o`000?oooooooooo02;ooooo0_l0003ooooookSooooo000`ooooo`03o`000?oooooooooo
02;ooooo0_l0003ooooookSooooo000`ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooool0
0000oooooongooooo`00<?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo00000?oooooo
]oooool0033ooooo00?o0000ooooooooool08_ooool00ol0003oooooo`00003ooooookOooooo000`
ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooool00000oooooongooooo`00<?ooool00ol0
003oooooooooo`0Rooooo`03o`000?oooooo00000?oooooo]oooool0033ooooo00?o0000oooooooo
ool08_ooool00ol0003oooooo`00003ooooookOooooo000`ooooo`?o00008_ooool00ol0003ooooo
o`00003ooooookOooooo000`ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooool00000oooo
oongooooo`00<?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo00000?oooooo]oooool0
033ooooo00?o0000ooooooooool08_ooool00ol0003oooooo`00003ooooookOooooo000`ooooo`03
o`000?oooooooooo027ooooo00Co0000oooooooooooo0000oooooongooooo`00<?ooool00ol0003o
ooooooooo`0Qooooo`04o`000?ooooooooooo`000?oooooo]oooool0033ooooo00?o0000oooooooo
ool08Oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo0?ooooooZoooool0013o
oooo0_o^k^h3ooooo`;ok^k^6Oooool00ol0003oooooooooo`0Qooooo`04o`000?ooooooooooo`00
00Wooooo00?o0000ooooooooool0oooooon[ooooo`002oooool2o`00000:oa0@4?ooooooooooonk^
k_mEEEGok^k^ooooooo^k^koEEEEonk^kP?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`00
0?lb<S;ok^k^2_ooool00ol0003oooooooooo`0Qooooo`04o`000?ooooooooooo`0000Wooooo00?o
0000ooooooooool0oooooon[ooooo`003?ooool00ol0003oooooooooo`02ooooo`05onk^k_mEEEGo
gMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2_ooool00ol0003oooooooooo`0Qooooo`04o`000?ooooooooooo`0000Wooooo0_l0003oooooojco
oooo00000ooooooo0000o`000004o`0000;ooooo1Ol00004ooooo`03omgMgOl0003ogMgM00Oooooo
00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00[ooooo00?o0000oooooooo
ool08Oooool01?l0003oooooooooool00009ooooo`;o0000oooooon/ooooo`002Oooool01?m4A4Co
gMgMooooool00004ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000002_ooool00ol0003oooooooooo`0Qooooo`04o`000?oo
ooooooooo`0000Wooooo0_l0003oooooojcooooo0009ooooo`04omgMgOmEEEGoooooo`0000?ooooo
00Ook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000ooooooooool00_ooool01Ol0
003ooooooooooooooooo000000[ooooo1?l0000Pooooo`04o`000?ooooooooooo`0000Wooooo0_l0
003oooooojcooooo000:ooooo`03ogMgMoo<c<co000000?ooooo0_o^k^h3ooooo`;ok^k^1Oooool0
0ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41002_ooool00ol0003ooooooooo
o`0Qooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooon/ooooo`002_oo
ool00oo^k^koA4A4o`00000?ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`;o00001Oooool00ol0003oooooooooo`0Qooooo`04o`000?ooooooooooo`0000So
oooo00?o0000ooooool00000oooooon/ooooo`002oooool00omgMgOo0000ooooo`0<ooooo`03oeEE
EOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooooooool08Oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo
00000?oooooo[?ooool002Sooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0Q
ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooon/ooooo`00:?ooool3
o`0000Gooooo00?o0000ooooooooool08Oooool01?l0003oooooooooool00008ooooo`03o`000?oo
oooo00000?oooooo[?ooool002Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Q
ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooon/ooooo`00:_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo027ooooo00Co0000oooooooooooo00002?oo
ool00ol0003oooooo`00003oooooojcooooo000`ooooo`03o`000?oooooooooo027ooooo00Co0000
oooooooooooo00002?ooool00ol0003oooooo`00003oooooojcooooo000`ooooo`03o`000?oooooo
oooo027ooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003oooooojcooooo000`
ooooo`03o`000?oooooooooo027ooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00
003oooooojcooooo000`ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01oooool0
1?l0003oooooooooool00008ooooo`03o`000?oooooo00000?oooooo[?ooool0033ooooo0ol0000F
ooooo`;o00002Oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?oooooo[?oo
ool0033ooooo00?o0000ooooooooool05_ooool2o`0000Wooooo00Co0000oooooooooooo00002?oo
ool00ol0003oooooo`00003oooooojcooooo000`ooooo`03o`000?oooooooooo01Kooooo0_l00009
ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooon/ooooo`00<?ooool0
0ol0003oooooooooo`0Fooooo`;o00002Oooool01?l0003oooooooooool00008ooooo`03o`000?oo
oooo00000?oooooo[?ooool0033ooooo00?o0000ooooooooool05_ooool2o`0000Wooooo00Co0000
oooooooooooo00002?ooool00ol0003oooooo`00003oooooojcooooo000`ooooo`03o`000?oooooo
oooo01Kooooo0_l00009ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooo
oon/ooooo`00<?ooool00ol0003oooooooooo`0Fooooo`;o00002Oooool01?l0003oooooooooool0
0008ooooo`03o`000?oooooo00000?oooooo[?ooool0033ooooo00?o0000ooooooooool05_ooool2
o`0000Wooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003oooooojcooooo000`
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooool000002?ooool01Ol0003ooooooooooooo
oooo000000Oooooo00?o0000ooooool00000oooooon/ooooo`00<?ooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooo000000Sooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oo
oooo00000?oooooo[?ooool0033ooooo00?o0000ooooooooool05_ooool00ol0003oooooo`000008
ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003oooooojcooooo000`
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooool000002?ooool01Ol0003ooooooooooooo
oooo000000Oooooo00?o0000ooooool00000oooooon/ooooo`00<?ooool3o`0001Kooooo00?o0000
ooooool000002?ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooool00000oooo
oon/ooooo`00<?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo000000Sooooo00Go0000
ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?oooooo[?ooool0033ooooo00?o0000
ooooooooool05_ooool00ol0003oooooo`000008ooooo`05o`000?ooooooooooooooool000001ooo
ool00ol0003oooooo`00003oooooojcooooo000`ooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooool000002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000
oooooon[ooooo`00<?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo000000Sooooo00Go
0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`000?ooooooZoooool0033ooooo
00?o0000ooooooooool05_ooool00ol0003oooooo`000008ooooo`05o`000?ooooooooooooooool0
00001oooool01?l0003oooooooooool0003ooooooj_ooooo000`ooooo`03o`000?oooooooooo01Go
oooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000
oooooooooooo0000oooooon[ooooo`00<?ooool00ol0003oooooooooo`0Eooooo`04o`000?oooooo
ooooo`0000Sooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool0
0000oooooon[ooooo`00<?ooool00ol0003oooooooooo`0Eooooo`04o`000?ooooooooooo`0000So
oooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool00000oooooon[
ooooo`00<?ooool00ol0003oooooooooo`0Eooooo`04o`000?ooooooooooo`0000Sooooo00Go0000
ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool00000oooooon[ooooo`00<?oo
ool00ol0003oooooooooo`0Eooooo`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooooooo
ooooo`000006ooooo`05o`000?ooooooooooooooool00000oooooon[ooooo`00<?ooool3o`0001Go
oooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000
ooooooooooooooooo`00003ooooooj_ooooo000`ooooo`03o`000?oooooooooo01Gooooo00Co0000
oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000oooooooooooo
ooooo`00003ooooooj_ooooo000`ooooo`03o`000?oooooooooo01Gooooo00Co0000oooooooooooo
00002?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`00003o
oooooj_ooooo000`ooooo`03o`000?oooooooooo01Gooooo00Co0000oooooooooooo00002?ooool0
1Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`00003ooooooj_ooooo
000`ooooo`03o`000?oooooooooo01Gooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooo
oooooooooooo000000Kooooo00Go0000ooooooooooooooooo`00003ooooooj_ooooo000`ooooo`03
o`000?oooooooooo01Gooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo
000000Kooooo00Go0000ooooooooooooooooo`00003ooooooj_ooooo000`ooooo`03o`000?oooooo
oooo01Gooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Kooooo
00Go0000ooooooooooooooooo`00003ooooooj_ooooo000@ooooo`;ok^k^0oooool2onk^kQWooooo
00?o0000ooooooooool05Oooool01?l0003oooooooooool00008ooooo`05o`000?oooooooooooooo
ool000001_ooool01Ol0003ooooooooooooooooo00000?ooooooZoooool000Wooooo1Ol00002oooo
o`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co000000So410@ooooooooooook^k^
oc8b<_l0003o<S8bonk^kP[ooooo00?o0000ooooooooool05Oooool01?l0003oooooooooool00008
ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo00000?oooooo
Zoooool000Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05onk^k_mEEEGogMgMoeEEEOo^
k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02_ooool00ol0
003oooooooooo`0Eooooo`04o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`00
0006ooooo`05o`000?ooooooooooooooool00000oooooon[ooooo`0000?oooooo`000?l000001?l0
0003ooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?ogMgMo`000?oMgMd01oooool00ol0003ooooooooo
o`02ooooo`05oa0@4?ooooooooooooooool@41002_ooool00ol0003oooooooooo`0Eooooo`04o`00
0?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?oooooooooo
ooooool00000oooooon[ooooo`002oooool00onHV9So8B4Qonk^kP03ooooo`05onk^k_mEEEGogMgM
oeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000002_oo
ool00ol0003oooooooooo`0Eooooo`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooooooo
ooooo`000006ooooo`05o`000?ooooooooooooooool00000oooooon[ooooo`003?ooool02omgMgOo
IVIVooooooooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000ooooooooool0
0_ooool01Ol0003ooooooooooooooooo000000[ooooo1?l0000Dooooo`04o`000?ooooooooooo`00
00Sooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool00000oooo
oon[ooooo`003Oooool00ol0003oooooooooo`02onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooo
oooo00;ooooo00Go410@oooooooooooooooooa0@400:ooooo`03o`000?oooooooooo01Gooooo00Co
0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000oooooooo
ooooooooo`00003ooooooj_ooooo0009ooooo`05o`000?nj^[[ooooooiRHV?l@41003_ooool00ol0
003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool2o`0000Gooooo00?o0000
ooooooooool05Oooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool00000
1_ooool01Ol0003ooooooooooooooooo00000?ooooooZoooool000Wooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c00<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02oooo
o`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool05Oooool01?l0003oooooooooool0
0008ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo00000?oo
ooooZoooool002Sooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0Eooooo`04
o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?oooooo
ooooooooool000002?ooool00ol0003oooooooooo`3ooooooj3ooooo000Xooooo`?o00001Oooool0
0ol0003oooooooooo`0Eooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooo
oooooooo000000Kooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oo
ooooX?ooool002Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Eooooo`05o`00
0?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000oooo
ooooooooooooo`000008ooooo`;o0000oooooonQooooo`00:_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo01Gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Oooooo00?o
0000ooooool00000oooooonQooooo`00<?ooool00ol0003oooooooooo`0Eooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go
0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?ooooooXOooool0033ooooo00?o
0000ooooooooool05Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001oooool00ol0003o
ooooo`00003ooooooj7ooooo000`ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooool00000oooooonQooooo`00
<?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooo
ooooo`000007ooooo`03o`000?oooooo00000?ooooooXOooool0033ooooo0ol0000Dooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?oo
ooooXOooool0033ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`00
0?ooooooooooooooool000001oooool00ol0003oooooo`00003ooooooj7ooooo000`ooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Oo
oooo00?o0000ooooool00000oooooonQooooo`00<?ooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?oo
ooooXOooool0033ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`00
0?ooooooooooooooool000001oooool00ol0003oooooo`00003ooooooj7ooooo000`ooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Oo
oooo00?o0000ooooool00000oooooonQooooo`00<?ooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?oo
ooooXOooool0033ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooo`00003ooooooj7ooooo
000`ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo0000oooooonPooooo`00<?oo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`000?ooooooX?ooool0033ooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool01?l0003oooooooooool0003ooooooj3ooooo000`ooooo`03o`000?oo
oooooooo00[ooooo0_l00008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool00000oooooonPooooo`00<?oo
ool3o`0000[ooooo0_l00008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool00000oooooonPooooo`00<?oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooooooo
o`00003ooooooj3ooooo000`ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooool000002?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooo
ool01Ol0003ooooooooooooooooo00000?ooooooX?ooool0033ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooo`000008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool00000oooooonPooooo`00<?oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooooooo
o`00003ooooooj3ooooo000`ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooool000002?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooo
ool01Ol0003ooooooooooooooooo000001;ooooo0_o^k^h3ooooo`;ok^k^Eoooool2onk^kP?ooooo
0_o^k^iPooooo`;ok^k^0oooool2onk^kTkooooo0_o^k^h3ooooo`;ok^k^K?ooool0033ooooo00?o
0000ooooooooool02Oooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool0
00003?ooool03Om4A4Co0000o`000?lb<S;ogMgMooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^
k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^i2ooooo`Co000000Wo
410@ooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^hkooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo
00goA4A4o`000?l0003o<S8bomgMgOooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo
1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^>?ooool5o`0000;ooooo00Ook^k^
oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`00
0?lb<S;ok^k^GOooool0033ooooo00?o0000ooooooooool02Oooool01?l0003oooooooooool00007
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`05o`000?ooooooooooooooool000003oooool02OmgMgOo<S8booooooooooook^k^oeEEEOoM
gMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`14
ooooo`03o`000?oooooooooo00;ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0mooooo`03o`000?oooooooooo00Cooooo
0_lQ8B48ooooo`09ogMgMolb<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000
ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg03Sooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A003ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL0GOooool0033ooooo00?o0000ooooooooool02?ooool01Ol0003o
oooooooooooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0=oooo
o`07o`000?oooooooooooooooooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go
410@oooooooooooooooooa0@4014ooooo`03o`000?oooooooooo00?ooooo00?ogMgMo`000?oMgMd0
1oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100?Oooool00ol0003o
ooooooooo`0?ooooo`07o`000?oooooooooooooooooMgMgo0000omgMg@07ooooo`03o`000?oooooo
oooo00;ooooo00Go410@oooooooooooooooooa0@400iooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?o
gMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100
GOooool0033ooooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooooooo000000Oooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`09ogMgMolb<S;oooooooooooo^
k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000004Cooooo00?o0000ooooooooool00_ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000003gooooo00?o0000oooooooo
ool03_ooool02OmgMgOo<S8booooooooooook^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000jooooo`03oiRHV?lQ8B7ok^k^00?ooooo
00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`00001Mooooo`00<?ooool00ol0003oooooooooo`08ooooo`05o`000?oooooooooooooo
ool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo00go0000ob4Q
8Ol0003o<S8bolc<c?ooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000004Cooooo00_o0000ooooooooooooooooonk^
k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`00000mooooo`03o`000?oooooooooo00_ooooo00go0000ob4Q8Ol0003o<S8bolc<
c?ooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000003_ooooo00_oMgMgofIVI_ooooooooooonk^k_mEEEGok^k^oooo
ooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
001Mooooo`00<?ooool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool000001ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00ooo
ool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooo
oa0@4014ooooo`04o`000?ooooooooooooooo`;ok^k^0oooool2onk^kPGooooo00?o0000oooooooo
ool00_ooool01Ol@413ooooooooooooooooo410@03gooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`03ooooo`;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@
413ooooooooooooooooo410@03cooooo00?o0000ooooooooool00_o^k^h3ooooo`;ok^k^1Oooool0
0ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100GOooool0033ooooo0ol00008
ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Gooooo00Go0000ooooooooooooooooo`00000Aooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo03Wooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool2o`00
03?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`;o0000;_ooool01Ol0003o^[ZjoooooonH
V9So410@00kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo
0_l0001Cooooo`00<?ooool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool00000
1oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo0_l00003ooooo`Co0000
3?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003o
ooooooooo`0gooooo`03oeEEEOmVIVKo000000gooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Oooooo00Co0000oooooooooooo0000<?ooool00omEEEGoIVIVo`00000=
ooooo`Co00003?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01ooo
ool01?l0003oooooooooool0000]ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?ooool00omEEEGo
IVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01oooool01?l0003oooooooooool0001B
ooooo`00<?ooool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool000001oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooool000008?ooool4
o`0000?ooooo00?o0000ooooooooool0E?ooool4o`000005ooooool0003oooooooooool00000G_oo
ool4o`000005ooooool0003oooooooooool00000C?ooool4o`000005ooooool0003oooooooooool0
0000D_ooool0033ooooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooooooo000000Oo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo000002Oo
oooo00?o0000ooooooooool0FOooool3o`0006Cooooo0ol0001Booooo`?o0000Doooool0033ooooo
00?o0000ooooooooool02?ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo000002Gooooo00Co0000oooooooo
oooo0000Foooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo05;ooooo00?o0000oooo
ooooool0D_ooool0033ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`04
o`000?ooooooooooo`0002Gooooo1?l0001Looooo`03o`000?oooooooooo06Cooooo00?o0000oooo
ooooool0D_ooool00ol0003oooooooooo`1Aooooo`00<?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00?ooooo00Co0000oooooooooooo0000oooooonFooooo`00<?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00003ooooo
oe_ooooo00?oMgMgofIVI_ooool0;Oooool00omVIVKoMgMgooooo`07ooooo`00<?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00003ooooo
oe[ooooo00?ogMgMoa0@4?o^k^h0;_ooool00oo^k^ko410@omgMg@07ooooo`00;_ooool4o`0000So
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000oooo
ooooool0oooooolnooooo`;o00000_ooool2o`0000cooooo00?oEEEEoiRHV?ooool00_l00002oooo
o`07o`000?ooooooooooo`000?l@413ok^k^oeEEE@02o`000003odA4A?nj^[[ooooo00;ooooo00Go
V9RHo`000?l0003oA4A4okZj^P02ooooo`08onk^k_mEEEGo0000o`000?m4A4Co^[Zjooooool@4105
o`0000?ooooo00So410@oc8b<_l0003o0000oa0@4?nYZJWoQhN7ofIVIPOooooo000]ooooo`06o`00
0?ooooooooooo`000?oooooo00001_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00oooool4o`000?oooooo?_ooool01_o^k^ko8B4QohN7Qonj^[[o
0000omgMg@cooooo00Go0000ooooooooooooooooo`000002ooooo`0;o`000?ooooooooooo`000?oo
ooooEEEEogMgMoooooook^k^ogMgMol@41000oooool01Ol@413o^[Zjonk^k_mgMgOo410@00;ooooo
00KoEEEEogMgMoooooook^k^ogMgMol@4103ooooo`03o`000?oooooooooo00Cooooo00So0000ojVY
ZOoooooooooookZj^_l0003ok^k^o`0000Oooooo003oo`000;Co00003oooool01?oMgMgo0000oa0@
4?o<c<`=ooooo`05oc8b<_ooooooooooooooool000000_ooool01_l0003oooooooooool0003ooooo
o`0000Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Gooooo00Oo^[ZjohN7QomVIVKoIVIVoa0@4?oooooo000000Oooooo000:ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool01_ooool6o`0000Cooooo00?o0000ooooool000001_oo
ool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`07o`000?ooooooooooooooool0003oooooo`000004
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool2o`0000?ooooo00?o0000
ooooooooool00_ooool4o`0000Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool05oooool01?o^k^ko8B4Qoa0@4?o^
k^h=ooooo`05oc8b<_ooooooooooooooool000000_ooool01Ol0003oooooooooool0003ooooo00Ko
00000oooool00ol0003oooooooooo`04ooooo`Ko00000oooool00ol0003oooooooooo`04ooooo`08
oc8b<_lQ8B7oMgMgogMgMon7QhOok^k^ooooool00007ooooo`002_ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo013ooooo00Co0000oooooooooooo00001Oooool00ol0003ooooooooo
o`04ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`03ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`07o`000?ooooooooooooooool0003oooooo`000004ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool2o`0000;ooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0Gooooo`04ob4Q8OmgMgOoMgMgoc8b<Pgooooo00Go0000onk^k_oooooooooo
o`000002olc<c00;o`000?nYZJWogMgMob4Q8OooooooEEEEohN7Qoo^k^koooooohN7Qolb<S800ooo
ool00ol0003oooooooooo`04ooooo`06oeEEEOn7QhOok^k^oooooon7QhOo<S8b0oooool00ol0003o
<S8bomgMg@04ooooo`08o`000?nj^[[oooooonk^k_mgMgOo0000onk^k_l00007ooooo`00<?ooool0
1Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`04o`000?ooooooooooo`00013ooooo00?o0000ooooooooool0Foooool00ol0003ooooo
ooooo`1Kooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool05_ooool2o`0000;ooooo
0_l0000<ooooo`0>oeEEEOmgMgOooooooa0@4?l0003o8B4Qo`000?mgMgOo410@o`000?nYZJWooooo
onk^k_mEEED2o`000004odA4A?o^k^kooooooa0@40Go00000oooool01_o^k^koEEEEo`000?l0003o
A4A4onk^kP;ooooo0_l000001?nYZJWo8B4Qo`000?lQ8B42ooooo`08ojVYZOlQ8B7o0000o`000?lb
<S;o0000ogMgMomEEED7ooooo`00<?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`04ooooo`?o0000oooooomFooooo`03omgMgOl@413o
k^k^01;ooooo00?o0000ooooooooool06Oooool00oo^k^ko410@omgMg@07ooooo`00<?ooool01Ol0
003ooooooooooooooooo000000Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`;o0000oooooomHooooo`03ogMgMomVIVKooooo017ooooo00?o0000ooooooooool06Oooool0
0omVIVKoMgMgooooo`07ooooo`00<?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`3ooooooiSooooo000`ooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3ooooooiSooooo000`oooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3o
oooooiSooooo000`ooooo`03o`000?oooooooooo00?ooooo0ol00007ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo00000?ooooooV_ooool0
033ooooo00?o0000ooooooooool00oooool2o`0000Sooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000oooooonJooooo`00<?ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0
003ooooooooooooooooo00000?ooooooV_ooool0033ooooo0ol0000>ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo00000?ooooooV_ooool0
033ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00Co0000oooooooooooo0000oooooonKooooo`00<?ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0003o
oooooi_ooooo000`ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`04ooooo`04o`000?ooooooooooo`000?ooooooVoooool0033ooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Co0000oooo
oooooooo0000oooooonKooooo`00<?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0003ooooooi_ooooo000`oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04oooo
o`04o`000?ooooooooooo`000?ooooooVoooool0033ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo0000oooooonK
ooooo`00<?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001oooool0
0ol0003oooooo`00003ooooooi_ooooo000`ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooo
ooooooooooooo`000007ooooo`;o0000oooooonLooooo`00<?ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04oooo
o`05o`000?ooooooooooooooool000001oooool2o`000?ooooooW?ooool0033ooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01?ooool01Ol0003ooooooooooooooooo000000Oooooo0_l0003ooooooicooooo000`oooo
o`?o00003_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01?ooool01Ol0003ooooooooooooooooo00000?ooooooYOooool0033ooooo00?o0000oooo
ooooool03oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
1Ol0003ooooooooooooooooo00000?ooooooYOooool0033ooooo00?o0000ooooooooool03oooool0
1Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo00000?ooooooYOooool0033ooooo00?o0000ooooooooool03oooool01?l0003ooooooooo
ool00007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00003oooooojGo
oooo000`ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooo00001oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`05o`000?ooooooooooooooool00000oooooonUooooo`00<?ooool00ol0003o
ooooooooo`0?ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0
003ooooooooooooooooo00000?ooooooYOooool0033ooooo00?o0000ooooooooool03oooool01?l0
003oooooooooool00007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00
003oooooojGooooo000`ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooo00001ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000oooooonUooooo`00<?oo
ool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool01?l0003oooooooooool0003oooooojKooooo000`ooooo`03o`000?oooooooooo00oooooo
00Co0000oooooooooooo00001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`00
0?ooooooY_ooool0033ooooo00?o0000ooooooooool03oooool01?l0003oooooooooool00007oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo0000oooooonVooooo`00<?ooool00ol0
003oooooooooo`0?ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
1?l0003oooooooooool0003oooooojKooooo000`ooooo`?o00003oooool01?l0003oooooooooool0
0007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo0000oooooonVooooo`00<?oo
ool00ol0003oooooooooo`0?ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool01?l0003oooooooooool0003oooooojKooooo000`ooooo`03o`000?oooooooooo00oooooo
00Co0000oooooooooooo00001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`00
0?ooooooY_ooool0033ooooo00?o0000ooooooooool03oooool01?l0003oooooooooool00007oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo0000oooooonVooooo`00<?ooool00ol0
003oooooooooo`0?ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
1?l0003oooooooooool0003oooooojKooooo000`ooooo`03o`000?oooooooooo00oooooo00Co0000
oooooooooooo00001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`000?oooooo
Y_ooool000oooooo0_o^k^h3ooooo`;ok^k^6_ooool00ol0003oooooooooo`0?ooooo`04o`000?oo
ooooooooo`0000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0003oooooojKo
oooo0008ooooo`Go00000_ooool01oo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`00
0008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`03o`000?oooooooooo00oooooo
00Co0000oooooooooooo00001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`00
0?ooooooY_ooool000Sooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05onk^k_mEEEGogMgM
oeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool00ol0003oooooooooo`0@ooooo`;o00002?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`04o`000?oo
ooooooooo`000?ooooooY_ooool000Wooooo00?oV9RHob4Q8Oo^k^h01Oooool00ooMgMgo0000omgM
g@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400;ooooo`03o`00
0?oooooooooo013ooooo0_l00008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo
0000oooooonVooooo`002_ooool00onHV9So8B4Qonk^kP03ooooo`05onk^k_mEEEGogMgMoeEEEOo^
k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000002oooool00ol0
003oooooooooo`0@ooooo`;o00002?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`04o`000?oooooooooo
o`000?ooooooY_ooool000_ooooo00_oMgMgofIVI_ooooooooooonk^k_mEEEGok^k^ooooooo^k^ko
EEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000;oooo
o`Co00003oooool2o`0000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0003o
ooooojKooooo000<ooooo`03o`000?oooooooooo00;ok^k^0oooool2onk^kPGooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@00_ooooo00?o0000ooooooooool04?ooool2
o`0000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooo
ooooooooool000001oooool01?l0003oooooooooool0003oooooojKooooo0008ooooo`05o`000?nj
^[[ooooooiRHV?l@41003_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool00ol0003oooooooooo`0@ooooo`;o00002?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?oooooooooo
o`000?ooooooY_ooool000Sooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00<ooooo`03oeEEEOmVIVKo
000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`;o00001_ooool00ol0003ooooooooo
o`0@ooooo`;o00002?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go
0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`000?ooooooY_ooool002Oooooo
00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooo
oooooooo0000oooooonVooooo`009oooool01?l0003oooooooooool00005ooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooo
ooooooooool000001oooool01?l0003oooooooooool0003oooooojKooooo000Wooooo`?o00001_oo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooool00000oooooonVooooo`00:?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003ooooo
o`00003oooooojKooooo000Yooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooooooo
o`000008ooooo`03o`000?oooooo00000?ooooooY_ooool0033ooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooooooo
o`000008ooooo`03o`000?oooooo00000?ooooooY_ooool0033ooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooooooo
o`000008ooooo`03o`000?oooooo00000?ooooooY_ooool0033ooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooooooo
o`000008ooooo`03o`000?oooooo00000?ooooooY_ooool0033ooooo0ol0000Kooooo`05o`000?oo
ooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooool0
0000oooooonVooooo`00<?ooool00ol0003oooooooooo`0Kooooo`05o`000?ooooooooooooooool0
00001_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooool00000oooooonVoooo
o`00<?ooool00ol0003oooooooooo`0Kooooo`05o`000?ooooooooooooooool000001oooool01?l0
003oooooooooool00008ooooo`03o`000?oooooo00000?ooooooY_ooool0033ooooo00?o0000oooo
ooooool06oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo00002?oo
ool00ol0003oooooo`00003oooooojKooooo000`ooooo`03o`000?oooooooooo01_ooooo00Go0000
ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Sooooo0_l0003oooooojOooooo
000`ooooo`03o`000?oooooooooo01_ooooo00Go0000ooooooooooooooooo`000007ooooo`04o`00
0?ooooooooooo`0000Sooooo0_l0003oooooojOooooo000`ooooo`03o`000?oooooooooo01_ooooo
00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Sooooo0_l0003ooooo
ojOooooo000`ooooo`03o`000?oooooooooo01_ooooo00Go0000ooooooooooooooooo`000007oooo
o`04o`000?ooooooooooo`0000Sooooo0_l0003oooooojOooooo000`ooooo`03o`000?oooooooooo
01_ooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Sooooo0_l0
003oooooojOooooo000`ooooo`03o`000?oooooooooo01_ooooo00Go0000ooooooooooooooooo`00
0007ooooo`04o`000?ooooooooooo`0000Sooooo0_l0003oooooojOooooo000`ooooo`03o`000?oo
oooooooo01_ooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000So
oooo0_l0003oooooojOooooo000`ooooo`03o`000?oooooooooo01_ooooo00Go0000oooooooooooo
ooooo`000007ooooo`04o`000?ooooooooooo`0000Sooooo0_l0003oooooojOooooo000`ooooo`?o
00006oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo00002Oooool0
0ol0003oooooooooo`3oooooojGooooo000`ooooo`03o`000?oooooooooo01_ooooo00Go0000oooo
ooooooooooooo`000007ooooo`04o`000?ooooooooooo`000?oooooo/Oooool0033ooooo00?o0000
ooooooooool06oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000
oooooonaooooo`00<?ooool00ol0003oooooooooo`0Kooooo`05o`000?ooooooooooooooool00000
1oooool01?l0003oooooooooool0003ooooook7ooooo000`ooooo`03o`000?oooooooooo01_ooooo
00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0003ooooook7ooooo000`ooooo`03
o`000?oooooooooo01_ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0003o
oooook7ooooo000`ooooo`03o`000?oooooooooo01_ooooo00Co0000oooooooooooo00002?ooool0
1?l0003oooooooooool0003ooooook7ooooo000`ooooo`03o`000?oooooooooo01_ooooo00Co0000
oooooooooooo00002?ooool01?l0003oooooooooool0003ooooook7ooooo000`ooooo`03o`000?oo
oooooooo01_ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0003ooooook7o
oooo000`ooooo`03o`000?oooooooooo01_ooooo00Co0000oooooooooooo00002?ooool01?l0003o
ooooooooool0003ooooook7ooooo000`ooooo`03o`000?oooooooooo01_ooooo00Co0000oooooooo
oooo00002?ooool01?l0003oooooooooool0003ooooook7ooooo000`ooooo`03o`000?oooooooooo
01_ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0003ooooook7ooooo000`
ooooo`?o00006oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`000?oooooo
/Oooool0033ooooo00?o0000ooooooooool06oooool01?l0003oooooooooool00008ooooo`04o`00
0?ooooooooooo`000?oooooo/Oooool0033ooooo00?o0000ooooooooool06oooool01?l0003ooooo
ooooool00008ooooo`04o`000?ooooooooooo`000?oooooo/Oooool0033ooooo00?o0000oooooooo
ool06oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`000?oooooo/Oooool0
033ooooo00?o0000ooooooooool06oooool01?l0003oooooooooool00008ooooo`04o`000?oooooo
ooooo`000?oooooo/Oooool0033ooooo00?o0000ooooooooool06oooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`000?oooooo/Oooool000oooooo0_o^k^h3ooooo`;ok^k^6_oo
ool00ol0003oooooooooo`0Kooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo
0000oooooonaooooo`002_ooool2o`00000:oa0@4?ooooooooooonk^k_mEEEGok^k^ooooooo^k^ko
EEEEonk^kP?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool00ol0
003oooooooooo`0Kooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000oooo
oonaooooo`002oooool00ol0003oooooooooo`02ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_oo
ool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ol0003ooooo
ooooo`0Kooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000oooooonaoooo
o`002?ooool5o`0000Cooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05
oa0@4?ooooooooooooooool@41002oooool00ol0003oooooooooo`0Kooooo`04o`000?oooooooooo
o`0000Sooooo00Co0000oooooooooooo0000oooooonaooooo`002?ooool01?m4A4CogMgMooooool0
0004ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000002oooool00ol0003oooooooooo`0Kooooo`04o`000?ooooooooooo`00
00Sooooo00Co0000oooooooooooo0000oooooonaooooo`002?ooool01?oMgMgoEEEEooooool00003
ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo
00Go0000ooooooooooooooooo`00000;ooooo`Co00006oooool00ol0003oooooo`000008ooooo`04
o`000?ooooooooooo`000?oooooo/Oooool000Wooooo00?oMgMgolc<c?l000000oooool2onk^kP?o
oooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400;oooo
o`03o`000?oooooooooo01cooooo00?o0000ooooool000002?ooool01?l0003oooooooooool0003o
oooook7ooooo0009ooooo`03onk^k_m4A4Co000000oooooo00?o0000ooooooooool00_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00_ooooo00?o0000ooooooooool07?ooool00ol0003oooooo`000008
ooooo`04o`000?ooooooooooo`000?oooooo/Oooool000[ooooo00?oMgMgo`000?ooool03?ooool0
0omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool2o`0000Kooooo00?o
0000ooooooooool07?ooool00ol0003oooooo`000008ooooo`04o`000?ooooooooooo`000?oooooo
/Oooool002Oooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooo000000Sooooo00Co0000oooooooooooo0000oooooonaooooo`009oooool01?l0003ooooo
ooooool00005ooooo`03o`000?oooooooooo01cooooo00?o0000ooooool000002?ooool01?l0003o
ooooooooool0003ooooook7ooooo000Wooooo`?o00001_ooool00ol0003oooooooooo`0Looooo`03
o`000?oooooo000000Sooooo00Co0000oooooooooooo0000oooooonaooooo`00:?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo01cooooo0_l00009ooooo`04o`000?ooooooooooo`00
0?oooooo/Oooool002Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Looooo`;o
00002Oooool01?l0003oooooooooool0003ooooook7ooooo000`ooooo`03o`000?oooooooooo01co
oooo0_l00009ooooo`04o`000?ooooooooooo`000?oooooo/Oooool0033ooooo00?o0000oooooooo
ool07?ooool2o`0000[ooooo00?o0000ooooool00000oooooonaooooo`00<?ooool00ol0003ooooo
ooooo`0Looooo`;o00002_ooool00ol0003oooooo`00003ooooook7ooooo000`ooooo`?o00007?oo
ool2o`0000[ooooo0_l0003ooooook;ooooo000`ooooo`03o`000?oooooooooo01cooooo0_l0000:
ooooo`;o0000oooooonbooooo`00<?ooool00ol0003oooooooooo`0Looooo`;o00002_ooool2o`00
0?oooooo/_ooool0033ooooo00?o0000ooooooooool07?ooool2o`0000[ooooo0_l0003ooooook;o
oooo000`ooooo`03o`000?oooooooooo01cooooo0_l0000:ooooo`;o0000oooooonbooooo`00<?oo
ool00ol0003oooooooooo`0Looooo`;o00002_ooool2o`000?oooooo/_ooool0033ooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`08ooooo`;o0000oooooonbooooo`00<?ooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo00Sooooo0_l0003ooooook;ooooo000`ooooo`03
o`000?oooooooooo02Sooooo0_l0003ooooook;ooooo000`ooooo`03o`000?oooooooooo02Sooooo
0_l0003ooooook;ooooo000`ooooo`03o`000?oooooooooo02Sooooo0_l0003ooooook;ooooo000`
ooooo`03o`000?oooooooooo02Sooooo0_l0003ooooook;ooooo000`ooooo`?o0000:?ooool2o`00
0?oooooo/_ooool0033ooooo00?o0000ooooooooool0:?ooool2o`000?oooooo/_ooool0033ooooo
00?o0000ooooooooool0:?ooool2o`000?oooooo/_ooool0033ooooo00?o0000ooooooooool0:?oo
ool2o`000?oooooo/_ooool0033ooooo00?o0000ooooooooool0:?ooool2o`000?oooooo/_ooool0
033ooooo00?o0000ooooooooool0:?ooool2o`000?oooooo/_ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0
003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo
0ol0003oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000
ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03
o`000?oooooooooo0?oooooog?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003o
oooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo
4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo002Pooooo`;o00001?ooool00onj
^[[o<S8booooo`04ooooo`;o00001_ooool00ol0003o^[Zjooooo`3ooooooeOooooo002Pooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`;o
<S8boooooomHooooo`00SOooool3o`0000;ooooo00Ko<S8boa0@4?ooooooooooonk^k_mEEED2o`00
0003odA4A?nj^[[ooooo00?ooooo00?o0000ooooooooool00_ooool01OnHV9So410@o`000?l0003o
ZJVY00Cooooo00?o0000ooooooooool01?ooool00on7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o
0000odA4A?nj^[X02_ooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B44ooooo`0;olc<c?lQ
8B7o0000ob4Q8Oo<c<coooooolc<c?o^k^koooooonk^k_o<c<`01?ooool4o`000008oa0@4?oooooo
ooooonk^k_lb<S;o0000oc8b<_o^k^hCooooo`06oa0@4?lb<S;o0000o`000?l@413oZJVY0_ooool0
1_o^k^koEEEEo`000?l0003oA4A4okZj^P?ooooo00GoIVIVo`000?l0003oA4A4olc<c03Xooooo`00
S_ooool01Ol0003oooooooooooo<c<co410@00?ooooo00KoEEEEogMgMoooooook^k^ogMgMol@4104
ooooo`03o`000?oooooooooo00;ooooo00Ko0000ojVYZOmEEEGoV9RHoeEEEOnj^[X3ooooo`03o`00
0?oooooooooo00Cooooo00?oc<c<o`000?l@41003?ooool01_l@413o^[Zjonk^k_mgMgOo410@oooo
o`Ko00001Oooool00ol0003oooooooooo`04ooooo`;o8B4Q1?ooool02olQ8B7oV9RHoooooonHV9So
8B4Qooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg01?ooooo00Ko0000ojVYZOoooooooooookZj^_l00002ooooo`06oeEEEOmg
MgOoooooonk^k_mgMgOo410@0_ooool01_mVIVKoMgMgooooooooooooQhN7oa0@4>Sooooo002>oooo
o`05o`000?oooooooooooeEEEOn7QhL00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00;ooooo00Ko<S8bonk^k_nHV9SoEEEEomgMgOl@4103ooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0:ooooo`05o`000?ooooooooooooooool0
00000_ooool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooo
oooooooooa0@400Dooooo`05okZj^_n7QhOoIVIVofIVI_l@41000_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0>_ooooo002>ooooo`05o`000?oooooogMgMo`000?o^k^h00oooool6
o`0000Cooooo00?o0000ooooooooool00_ooool01onj^[[oA4A4olc<c?lQ8B7ooooooa0@4?o<c<`0
0_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00?ooooo1_l00005ooooo`03o`00
0?oooooooooo00[ooooo00_o<S8boiRHV?ooooooV9RHoc8b<_ooooook^k^oeEEEOoMgMgoEEEEonk^
kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Cooooo`06oc8b
<_lQ8B7oMgMgogMgMon7QhOok^k^0_ooool6o`0000;ooooo00?o0000ooooooooool0joooool008ko
oooo0ol000000ol@413oV9RHooooo`02ooooo`06oeEEEOn7QhOok^k^oooooon7QhOo<S8b1?ooool0
0ol0003oooooooooo`02ooooo`07onk^k_l0003oooooo`000?ooooooIVIVohN7Q`02ooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0:ooooo`0;olc<
c?l0003o0000o`000?o<c<coooooolc<c?o^k^koooooonk^k_o<c<`01_ooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000004oooool01_l0003o^[Zjooooooo^k^koMgMgo`00
00;ooooo00KoEEEEohN7Qoo^k^koooooohN7Qolb<S82ooooo`06ofIVI_mgMgOooooooooooon7QhOo
0000j?ooool008kooooo00Go0000ooooooooooooc<c<o`000003ooooo`06onk^k_mEEEGo0000o`00
0?m4A4Cok^k^1?ooool00ol0003oooooooooo`02ooooo`04ofIVI_nHV9Sooooooc8b<P;o^[Zj00Co
0000oooooooooooo00004oooool00ol@413o0000o`000003o`0000gooooo00?o0000ooooooooool0
2_ooool01Ol@413o^[Zjoooooonj^[[o410@00cooooo00?o0000ooooooooool00_ooool01Ol@413o
oooooooooooooooo410@00Oooooo0ol00002ooooo`?o00001?ooool01_nYZJWo8B4Qo`000?l0003o
<S8bo`0000;ooooo00Kok^k^oeEEEOl0003o0000odA4A?o^k^h2ooooo`06onk^k_mVIVKo0000o`00
0?m4A4Co0000j?ooool008kooooo00Go0000ooooooooooooc<c<o`00000=ooooo`03o`000?oooooo
oooo00Gooooo00?oIVIVohN7Qoooool00oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool02_ooool01Ol0003o^[Zjoooooonj^[[o000000cooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`3oooooo`;ooooo002=ooooo`Co000000?o410@ojVYZOooool03?oo
ool2o`0000Kooooo00?oZJVYodA4A?ooool00_ooool2o`0001Gooooo00?o0000ooooooooool03?oo
ool00omEEEGoIVIVo`00000<ooooo`05ojVYZOl@413o0000oa0@4?nYZJT02_ooool00omEEEGoIVIV
o`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_ooool4o`0000;ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`3oooooo`;ooooo003oooooo`Kooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`3oooooo`;ooooo003oooooo`Kooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`3oooooo`;ooooo003oooooo`Gooooo0_l00003ooooo`;o0000ooooool4
ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooo
oooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3o
oooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooo
oooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?oo
ool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooo
ooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00001\
\>"],
  ImageRangeCache->{{{0, 525.688}, {324.5, 0}} -> {0, -6.34248*^6, 0, 53093}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0.309017 5.42214e-08 [
[.32684 .29652 -16.5 -12.5 ]
[.32684 .29652 16.5 0 ]
[.54329 .29652 -16.5 -12.5 ]
[.54329 .29652 16.5 0 ]
[.75974 .29652 -22.5 -12.5 ]
[.75974 .29652 22.5 0 ]
[.97619 .29652 -16.5 -12.5 ]
[.97619 .29652 16.5 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 64 6 ]
[.09789 .09213 -34.5 -6.25 ]
[.09789 .09213 0 6.25 ]
[.09789 .20057 -34.5 -6.25 ]
[.09789 .20057 0 6.25 ]
[.09789 .41746 -28.5 -6.25 ]
[.09789 .41746 0 6.25 ]
[.09789 .5259 -28.5 -6.25 ]
[.09789 .5259 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -59.8125 0 ]
[.5 .63053 59.8125 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 .30902 m
.32684 .31527 L
s
gsave
.32684 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 .30902 m
.54329 .31527 L
s
gsave
.54329 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 .30902 m
.75974 .31527 L
s
gsave
.75974 .29652 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 .30902 m
.15368 .31277 L
s
.19697 .30902 m
.19697 .31277 L
s
.24026 .30902 m
.24026 .31277 L
s
.28355 .30902 m
.28355 .31277 L
s
.37013 .30902 m
.37013 .31277 L
s
.41342 .30902 m
.41342 .31277 L
s
.45671 .30902 m
.45671 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.58658 .30902 m
.58658 .31277 L
s
.62987 .30902 m
.62987 .31277 L
s
.67316 .30902 m
.67316 .31277 L
s
.71645 .30902 m
.71645 .31277 L
s
.80303 .30902 m
.80303 .31277 L
s
.84632 .30902 m
.84632 .31277 L
s
.88961 .30902 m
.88961 .31277 L
s
.9329 .30902 m
.9329 .31277 L
s
.0671 .30902 m
.0671 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09213 m
.11664 .09213 L
s
gsave
.09789 .09213 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .20057 m
.11664 .20057 L
s
gsave
.09789 .20057 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .41746 m
.11664 .41746 L
s
gsave
.09789 .41746 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .5259 m
.11664 .5259 L
s
gsave
.09789 .5259 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.11039 .11924 m
.11414 .11924 L
s
.11039 .14635 m
.11414 .14635 L
s
.11039 .17346 m
.11414 .17346 L
s
.11039 .22768 m
.11414 .22768 L
s
.11039 .2548 m
.11414 .2548 L
s
.11039 .28191 m
.11414 .28191 L
s
.11039 .33613 m
.11414 .33613 L
s
.11039 .36324 m
.11414 .36324 L
s
.11039 .39035 m
.11414 .39035 L
s
.11039 .44457 m
.11414 .44457 L
s
.11039 .47168 m
.11414 .47168 L
s
.11039 .49879 m
.11414 .49879 L
s
.11039 .06502 m
.11414 .06502 L
s
.11039 .03791 m
.11414 .03791 L
s
.11039 .0108 m
.11414 .0108 L
s
.11039 .55301 m
.11414 .55301 L
s
.11039 .58012 m
.11414 .58012 L
s
.11039 .60723 m
.11414 .60723 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -120.812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.812 moveto
(@) show
81.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.812 moveto
(D) show
93.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.) show
129.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
135.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
147.000 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
151.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
160.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
178.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02399 .30902 L
.02418 .30902 L
.02428 .30902 L
.02436 .30902 L
.02444 .30902 L
.02453 .30902 L
.02463 .30902 L
.02473 .30902 L
.02482 .30902 L
.02491 .30902 L
.02501 .30902 L
.02511 .30902 L
.02522 .30902 L
.02532 .30902 L
.02551 .30902 L
.02571 .30902 L
.02608 .30902 L
.0263 .30902 L
.02652 .30902 L
.02691 .30902 L
.02732 .30902 L
.02776 .30902 L
.02854 .30902 L
.02937 .30902 L
.03029 .30902 L
.03111 .30902 L
.03186 .30902 L
.03354 .30902 L
.03507 .30902 L
.03674 .30902 L
.04001 .30902 L
.04163 .30902 L
.04243 .30902 L
.04278 .30902 L
.04316 .30902 L
.04334 .30902 L
.04353 .30902 L
.04371 .30902 L
.04387 .30902 L
.04397 .30902 L
.04406 .30902 L
.04415 .30902 L
.04426 .30902 L
.04435 .30902 L
.04443 .30902 L
.04452 .30902 L
.04462 .30902 L
.04472 .30902 L
.04482 .30902 L
Mistroke
.04504 .30902 L
.04523 .30902 L
.04544 .30902 L
.04583 .30902 L
.04619 .30902 L
.04658 .30902 L
.047 .30902 L
.04774 .30902 L
.04854 .30902 L
.04941 .30902 L
.05098 .30902 L
.05186 .30902 L
.05266 .30902 L
.05586 .30902 L
.05894 .30903 L
.06053 .30903 L
.06134 .30903 L
.06156 .30903 L
.06179 .30903 L
.062 .30903 L
.06211 .30903 L
.06222 .30903 L
.06232 .30903 L
.06243 .30903 L
.06253 .30903 L
.06262 .30903 L
.06271 .30903 L
.0628 .30903 L
.0629 .30903 L
.06299 .30903 L
.06304 .30903 L
.0631 .30903 L
.0632 .30903 L
.0634 .30903 L
.06351 .30903 L
.06362 .30903 L
.06383 .30903 L
.06425 .30903 L
.06464 .30903 L
.06507 .30903 L
.06553 .30903 L
.06629 .30903 L
.06713 .30902 L
.06801 .30902 L
.06883 .30901 L
.07047 .309 L
.07196 .30898 L
.07517 .30894 L
.07663 .30891 L
.07747 .3089 L
Mistroke
.07825 .30889 L
.07902 .30889 L
.07924 .30889 L
.07945 .30888 L
.07966 .30888 L
.07984 .30888 L
.08005 .30888 L
.08016 .30888 L
.08026 .30888 L
.08036 .30888 L
.08045 .30888 L
.08055 .30888 L
.08065 .30888 L
.08076 .30888 L
.08082 .30888 L
.08087 .30888 L
.08107 .30888 L
.08118 .30888 L
.08131 .30888 L
.08153 .30888 L
.08192 .30889 L
.08229 .30889 L
.08269 .3089 L
.08312 .30891 L
.084 .30893 L
.08481 .30896 L
.08633 .30903 L
.08799 .30915 L
.09125 .30945 L
.09275 .3096 L
.09438 .30976 L
.09527 .30983 L
.09567 .30985 L
.0961 .30988 L
.09629 .30989 L
.0965 .30989 L
.09669 .3099 L
.09688 .30991 L
.097 .30991 L
.09711 .30991 L
.09721 .30991 L
.09727 .30991 L
.09732 .30991 L
.09742 .30991 L
.09747 .30991 L
.09752 .30991 L
.09762 .30991 L
.09772 .30991 L
.09781 .30991 L
.09792 .30991 L
Mistroke
.09811 .3099 L
.0983 .3099 L
.09848 .30989 L
.09888 .30987 L
.0993 .30984 L
.1 .30976 L
.10077 .30965 L
.10158 .30949 L
.10233 .3093 L
.104 .30875 L
.10719 .30728 L
.11025 .3057 L
.11107 .30535 L
.11183 .30508 L
.11225 .30496 L
.11271 .30485 L
.11292 .30482 L
.11313 .30479 L
.11331 .30477 L
.11342 .30476 L
.11351 .30475 L
.11362 .30474 L
.11367 .30474 L
.11372 .30474 L
.11382 .30474 L
.11392 .30474 L
.11397 .30474 L
.11403 .30474 L
.11413 .30475 L
.11418 .30475 L
.11423 .30475 L
.11435 .30477 L
.11455 .30479 L
.11474 .30482 L
.11515 .30491 L
.11551 .30503 L
.11591 .3052 L
.11664 .3056 L
.1174 .30616 L
.11823 .30697 L
.11992 .30916 L
.12316 .31506 L
.12627 .32112 L
.12708 .32238 L
.12751 .32295 L
.12797 .32346 L
.12841 .32385 L
.12881 .32412 L
.129 .32422 L
.1291 .32426 L
Mistroke
.12921 .32429 L
.1293 .32432 L
.1294 .32434 L
.1295 .32435 L
.12958 .32436 L
.12969 .32436 L
.12974 .32436 L
.12979 .32436 L
.12989 .32434 L
.12999 .32432 L
.1301 .32429 L
.1302 .32426 L
.13042 .32415 L
.13061 .32404 L
.13081 .32388 L
.13122 .32346 L
.13159 .32296 L
.13199 .3223 L
.13271 .32075 L
.13353 .31843 L
.13443 .31524 L
.13604 .30786 L
.13933 .28869 L
.14097 .27915 L
.14177 .27506 L
.1425 .27185 L
.14286 .2705 L
.14325 .26922 L
.14359 .2683 L
.14397 .2675 L
.14417 .26715 L
.14436 .2669 L
.14446 .26679 L
.14457 .2667 L
.14462 .26666 L
.14468 .26662 L
.14478 .26657 L
.14488 .26655 L
.14497 .26654 L
.14508 .26655 L
.14518 .26657 L
.14527 .26662 L
.14535 .26667 L
.14544 .26675 L
.14554 .26685 L
.14574 .26712 L
.14594 .26746 L
.1463 .26831 L
.14669 .26954 L
.14711 .27127 L
Mistroke
.14787 .27539 L
.14858 .28039 L
.15023 .29619 L
.15172 .31475 L
.15494 .36074 L
.15641 .37981 L
.15725 .38869 L
.15766 .39234 L
.15803 .39521 L
.1584 .3976 L
.15881 .39964 L
.15903 .40049 L
.15923 .40111 L
.15943 .40155 L
.15953 .4017 L
.15958 .40177 L
.15963 .40183 L
.15969 .40187 L
.15974 .4019 L
.1598 .40192 L
.15985 .40193 L
.15996 .4019 L
.16005 .40184 L
.16011 .40178 L
.16017 .40171 L
.16029 .4015 L
.16039 .40127 L
.16051 .40096 L
.16071 .40028 L
.1609 .39946 L
.16133 .39698 L
.16172 .39388 L
.16216 .38964 L
.16295 .3796 L
.16444 .35316 L
.16602 .3159 L
.16771 .26981 L
.16932 .22499 L
.17016 .20313 L
.17105 .18263 L
.17185 .16727 L
.17228 .16057 L
.17273 .15462 L
.17315 .15036 L
.17353 .14755 L
.17371 .14658 L
.17381 .14617 L
.17391 .14581 L
.174 .14556 L
.1741 .14537 L
Mistroke
.17419 .14525 L
.17427 .1452 L
.17437 .14522 L
.17443 .14526 L
.17448 .14532 L
.17458 .1455 L
.17467 .14574 L
.17478 .1461 L
.17488 .14653 L
.1751 .14779 L
.17529 .14912 L
.17549 .15091 L
.1759 .15555 L
.17627 .16097 L
.17666 .16805 L
.17738 .18405 L
.17909 .23703 L
.1807 .30225 L
.18378 .43771 L
.18536 .4957 L
.18616 .51797 L
.18659 .52752 L
.18705 .53555 L
.18743 .54064 L
.18765 .54279 L
.18776 .54363 L
.18786 .5443 L
.18795 .54481 L
.18804 .54526 L
.18813 .54558 L
.18821 .54578 L
.1883 .54591 L
.1884 .54595 L
.1885 .54587 L
.1886 .54567 L
.1887 .54534 L
.18881 .54483 L
.18892 .54421 L
.18902 .54351 L
.1894 .53964 L
.18963 .53662 L
.18982 .53337 L
.19027 .52436 L
.19108 .50222 L
.19182 .47558 L
.19349 .39682 L
.19666 .21165 L
.19826 .12549 L
.19895 .0939 L
.19971 .06525 L
Mistroke
.20013 .05233 L
.20052 .04239 L
.20089 .03478 L
.20128 .02881 L
.20148 .02664 L
.20158 .02573 L
.20169 .02495 L
.20179 .02441 L
.20189 .02398 L
.20199 .02373 L
.20208 .02362 L
.20213 .02361 L
.20219 .02366 L
.20225 .02375 L
.2023 .02388 L
.2024 .02423 L
.2025 .02476 L
.20262 .02551 L
.20272 .02639 L
.20296 .029 L
.20317 .03197 L
.20336 .0353 L
.2038 .04485 L
.20459 .06915 L
.20531 .09843 L
.20608 .13624 L
.20942 .34865 L
.2111 .45589 L
.21184 .49677 L
.21264 .53512 L
.21343 .56457 L
.2138 .57567 L
.21415 .58427 L
.21435 .58816 L
.21456 .59173 L
.21473 .59417 L
.21492 .59631 L
.21502 .59719 L
.21513 .59796 L
.21519 .5983 L
.21524 .59857 L
.2153 .59879 L
.21535 .59895 L
.21545 .59915 L
.21555 .59918 L
.21565 .59907 L
.21574 .59879 L
.21584 .59836 L
.21595 .5977 L
.21607 .59681 L
Mistroke
.21617 .59579 L
.21657 .59044 L
.2168 .5863 L
.217 .58186 L
.21746 .56959 L
.21829 .54003 L
.21908 .50413 L
.22216 .31843 L
.22371 .22032 L
.22454 .17363 L
.22543 .13021 L
.22628 .09722 L
.22665 .08567 L
.22706 .07519 L
.22744 .06742 L
.2278 .06211 L
.228 .05998 L
.22818 .05855 L
.22828 .05796 L
.22833 .05771 L
.22839 .05748 L
.22849 .0572 L
.22858 .05707 L
.22868 .05707 L
.22879 .05723 L
.22889 .05753 L
.22898 .05794 L
.22907 .05847 L
.22915 .05905 L
.22934 .06072 L
.22954 .06307 L
.22976 .06624 L
.23015 .07363 L
.23092 .09368 L
.23162 .11808 L
.2348 .27345 L
.23639 .35767 L
.23785 .42339 L
.2386 .45055 L
.23942 .47355 L
.23987 .48305 L
.24028 .48976 L
.24049 .49234 L
.24068 .4943 L
.24088 .49589 L
.24098 .49654 L
.2411 .4971 L
.2412 .49746 L
.24129 .49769 L
.2414 .49782 L
Mistroke
.2415 .49783 L
.24159 .49774 L
.24167 .49757 L
.24177 .49728 L
.24187 .49687 L
.24207 .49566 L
.24227 .49409 L
.24248 .49191 L
.24271 .48903 L
.24316 .48171 L
.24359 .47294 L
.2444 .45219 L
.24748 .34152 L
.24903 .28266 L
.24986 .25483 L
.25075 .22911 L
.25159 .20973 L
.25196 .20296 L
.25237 .1968 L
.25276 .19222 L
.25311 .18905 L
.25331 .18775 L
.25349 .18685 L
.25359 .18647 L
.2537 .18614 L
.2538 .18592 L
.2539 .18579 L
.254 .18574 L
.25409 .18576 L
.25418 .18583 L
.25427 .18599 L
.25437 .18623 L
.25448 .18657 L
.25467 .18741 L
.25487 .18855 L
.25505 .18988 L
.2554 .19301 L
.2562 .20318 L
.25706 .21818 L
.26035 .29574 L
.26199 .33312 L
.26279 .34833 L
.26352 .35985 L
.26388 .36464 L
.26428 .36912 L
.26462 .37237 L
.26499 .37526 L
.26539 .37753 L
.26561 .37844 L
.26571 .37877 L
Mistroke
.26581 .37907 L
.2659 .37928 L
.266 .37947 L
.26609 .37959 L
.26618 .37967 L
.26628 .37973 L
.26637 .37973 L
.26647 .37969 L
.26657 .3796 L
.26666 .37948 L
.26676 .3793 L
.26694 .37886 L
.26715 .37816 L
.26735 .37734 L
.26777 .37501 L
.26818 .37216 L
.26888 .36577 L
.26966 .35719 L
.27293 .31296 L
.27444 .2947 L
.27523 .28699 L
.27607 .2806 L
.2765 .27808 L
.27697 .27591 L
.27718 .27516 L
.2774 .27448 L
.2776 .27398 L
.27779 .27361 L
.27789 .27346 L
.278 .27333 L
.27811 .27322 L
.27817 .27318 L
.27823 .27315 L
.27833 .27311 L
.27843 .27311 L
.27848 .27311 L
.27854 .27313 L
.27864 .27317 L
.27874 .27325 L
.27884 .27333 L
.27904 .27361 L
.27923 .27395 L
.27941 .27435 L
.27979 .2754 L
.2802 .27688 L
.28103 .28077 L
.28251 .2899 L
.2842 .3017 L
.28575 .31167 L
.28652 .31584 L
Mistroke
.28735 .31959 L
.28774 .321 L
.28814 .32228 L
.2885 .32321 L
.28887 .324 L
.28906 .32433 L
.28926 .32462 L
.28945 .32485 L
.28962 .32501 L
.28983 .32515 L
.28994 .3252 L
.29004 .32524 L
.29014 .32526 L
.29023 .32527 L
.29033 .32527 L
.29043 .32526 L
.29053 .32523 L
.29061 .3252 L
.2907 .32516 L
.2908 .32511 L
.29113 .32483 L
.29132 .32463 L
.2915 .3244 L
.2919 .32377 L
.29275 .32201 L
.29355 .31991 L
.29505 .31538 L
.29652 .31083 L
.29736 .3085 L
.29814 .3066 L
.29898 .30493 L
.29974 .30377 L
.30016 .30329 L
.30056 .30293 L
.30077 .30279 L
.30098 .30266 L
.30122 .30255 L
.30132 .30251 L
.30144 .30248 L
.30153 .30246 L
.30163 .30244 L
.30173 .30243 L
.30183 .30242 L
.30193 .30242 L
.30202 .30242 L
.3021 .30242 L
.30219 .30244 L
.30229 .30245 L
.3024 .30247 L
.30261 .30254 L
Mistroke
.30281 .30262 L
.303 .30271 L
.30371 .30317 L
.30447 .30386 L
.30779 .30787 L
.30859 .30879 L
.30944 .30965 L
.31024 .31031 L
.31098 .31079 L
.31168 .31112 L
.31208 .31125 L
.31244 .31134 L
.31263 .31138 L
.31281 .3114 L
.31292 .31141 L
.31301 .31142 L
.31306 .31143 L
.31312 .31143 L
.31322 .31143 L
.31332 .31144 L
.31338 .31144 L
.31343 .31143 L
.31349 .31143 L
.31354 .31143 L
.3136 .31143 L
.31366 .31143 L
.31375 .31142 L
.31385 .31141 L
.31405 .31139 L
.31426 .31136 L
.31446 .31132 L
.3149 .31122 L
.3157 .31097 L
.31719 .31035 L
.31883 .30959 L
.32036 .30897 L
.32112 .30872 L
.32183 .30853 L
.32223 .30844 L
.32266 .30837 L
.32302 .30831 L
.32341 .30827 L
.32361 .30825 L
.3238 .30824 L
.32398 .30823 L
.32417 .30822 L
.32427 .30822 L
.32432 .30822 L
.32437 .30822 L
.32447 .30821 L
Mistroke
.32456 .30821 L
.32462 .30821 L
.32467 .30821 L
.32477 .30821 L
.32483 .30821 L
.32488 .30822 L
.325 .30822 L
.3251 .30822 L
.32522 .30823 L
.32542 .30824 L
.32581 .30826 L
.32627 .3083 L
.32669 .30834 L
.32983 .30879 L
.33144 .30901 L
.33234 .30911 L
.33317 .30918 L
.33392 .30922 L
.33434 .30924 L
.33474 .30925 L
.33495 .30925 L
.33506 .30926 L
.33516 .30926 L
.33524 .30926 L
.33534 .30926 L
.33544 .30926 L
.33554 .30926 L
.33559 .30926 L
.33565 .30926 L
.33575 .30926 L
.33581 .30926 L
.33586 .30926 L
.33592 .30926 L
.33598 .30926 L
.33609 .30926 L
.3362 .30926 L
.33639 .30926 L
.33659 .30925 L
.33677 .30925 L
.33718 .30924 L
.338 .30921 L
.33949 .30915 L
.34098 .30908 L
.34261 .30901 L
.34349 .30899 L
.34388 .30898 L
.34431 .30897 L
.34469 .30896 L
.34509 .30896 L
.34532 .30896 L
Mistroke
.34552 .30895 L
.34573 .30895 L
.34592 .30895 L
.34602 .30895 L
.34612 .30895 L
.34621 .30895 L
.3463 .30895 L
.34641 .30895 L
.34646 .30895 L
.34651 .30895 L
.34661 .30895 L
.34671 .30895 L
.3468 .30895 L
.34691 .30895 L
.347 .30895 L
.34709 .30895 L
.34726 .30895 L
.34744 .30895 L
.34789 .30895 L
.34831 .30896 L
.3491 .30897 L
.3522 .309 L
.3538 .30902 L
.35461 .30903 L
.35506 .30903 L
.35549 .30903 L
.35588 .30903 L
.35609 .30903 L
.35631 .30903 L
.3565 .30903 L
.3567 .30903 L
.35679 .30903 L
.35688 .30903 L
.35697 .30903 L
.35706 .30903 L
.35716 .30903 L
.35726 .30903 L
.35732 .30903 L
.35738 .30903 L
.35749 .30903 L
.35754 .30903 L
.3576 .30903 L
.3577 .30903 L
.35781 .30903 L
.35793 .30903 L
.35813 .30903 L
.35835 .30903 L
.35874 .30903 L
.35955 .30903 L
.36044 .30903 L
Mistroke
.36205 .30902 L
.36294 .30902 L
.36377 .30902 L
.36458 .30902 L
.36532 .30901 L
.36606 .30901 L
.36643 .30901 L
.36683 .30901 L
.36705 .30901 L
.36724 .30901 L
.36735 .30901 L
.36747 .30901 L
.36758 .30901 L
.36768 .30901 L
.36777 .30901 L
.36786 .30901 L
.36796 .30901 L
.36806 .30901 L
.36811 .30901 L
.36817 .30901 L
.36827 .30901 L
.36837 .30901 L
.36847 .30901 L
.36868 .30901 L
.36888 .30901 L
.36932 .30901 L
.37011 .30901 L
.37161 .30901 L
.37325 .30902 L
.37405 .30902 L
.37478 .30902 L
.37553 .30902 L
.37625 .30902 L
.37664 .30902 L
.377 .30902 L
.3774 .30902 L
.3776 .30902 L
.37772 .30902 L
.37782 .30902 L
.37792 .30902 L
.37801 .30902 L
.37811 .30902 L
.37817 .30902 L
.37822 .30902 L
.37832 .30902 L
.37842 .30902 L
.37852 .30902 L
.37858 .30902 L
.37863 .30902 L
.37873 .30902 L
Mistroke
.37882 .30902 L
.37902 .30902 L
.3792 .30902 L
.37938 .30902 L
.38018 .30902 L
.38105 .30902 L
.38276 .30902 L
.38432 .30902 L
.38509 .30902 L
.3855 .30902 L
.38594 .30902 L
.38631 .30902 L
.38673 .30902 L
.38711 .30902 L
.38746 .30902 L
.38767 .30902 L
.38786 .30902 L
.38808 .30902 L
.38818 .30902 L
.3883 .30902 L
.3884 .30902 L
.3885 .30902 L
.3886 .30902 L
.38865 .30902 L
.38871 .30902 L
.38881 .30902 L
.38891 .30902 L
.38901 .30902 L
.3891 .30902 L
.38929 .30902 L
.38946 .30902 L
.38986 .30902 L
.39059 .30902 L
.39222 .30902 L
.39375 .30902 L
.39522 .30902 L
.39605 .30902 L
.3968 .30902 L
.39718 .30902 L
.39739 .30902 L
.39759 .30902 L
.39794 .30902 L
.39813 .30902 L
.39833 .30902 L
.39843 .30902 L
.39853 .30902 L
.39858 .30902 L
.39864 .30902 L
.39869 .30902 L
.39875 .30902 L
Mistroke
.3988 .30902 L
.39886 .30902 L
.39896 .30902 L
.39902 .30902 L
.39907 .30902 L
.3992 .30902 L
.3994 .30902 L
.39958 .30902 L
.39999 .30902 L
.40078 .30902 L
.40152 .30902 L
.40318 .30902 L
.40469 .30902 L
.40554 .30902 L
.40632 .30902 L
.40672 .30902 L
.40716 .30902 L
.40738 .30902 L
.40762 .30902 L
.40784 .30902 L
.40804 .30902 L
.40825 .30902 L
.40836 .30902 L
.40842 .30902 L
.40848 .30902 L
.40858 .30902 L
.40867 .30902 L
.40873 .30902 L
.40879 .30902 L
.40889 .30902 L
.40898 .30902 L
.40908 .30902 L
.40917 .30902 L
.40926 .30902 L
.40947 .30902 L
.40966 .30902 L
.41003 .30902 L
.41044 .30902 L
.41127 .30902 L
.41275 .30902 L
.41362 .30902 L
.41444 .30902 L
.41524 .30902 L
.41599 .30902 L
.41671 .30902 L
.41711 .30902 L
.41748 .30902 L
.41769 .30902 L
.41788 .30902 L
.41809 .30902 L
Mistroke
.4182 .30902 L
.41832 .30902 L
.41842 .30902 L
.41851 .30902 L
.41857 .30902 L
.41862 .30902 L
.41873 .30902 L
.41882 .30902 L
.41892 .30902 L
.41901 .30902 L
.41911 .30902 L
.4193 .30902 L
.41952 .30902 L
.41992 .30902 L
.42066 .30902 L
.42234 .30902 L
.42322 .30902 L
.42405 .30902 L
.42485 .30902 L
.4256 .30902 L
.42633 .30902 L
.4267 .30902 L
.42711 .30902 L
.42732 .30902 L
.42751 .30902 L
.42774 .30902 L
.42784 .30902 L
.42795 .30902 L
.42804 .30902 L
.42815 .30902 L
.42824 .30902 L
.42833 .30902 L
.42843 .30902 L
.42852 .30902 L
.42863 .30902 L
.42868 .30902 L
.42874 .30902 L
.42884 .30902 L
.42894 .30902 L
.42916 .30902 L
.42956 .30902 L
.43031 .30902 L
.43199 .30902 L
.43278 .30902 L
.43362 .30902 L
.43435 .30902 L
.43515 .30902 L
.43557 .30902 L
.43597 .30902 L
.43634 .30902 L
Mistroke
.43653 .30902 L
.43674 .30902 L
.43694 .30902 L
.43713 .30902 L
.43731 .30902 L
.4375 .30902 L
.43758 .30902 L
.43767 .30902 L
.43775 .30902 L
.43783 .30902 L
.43793 .30902 L
.43802 .30902 L
.43811 .30902 L
.43819 .30902 L
.43829 .30902 L
.43839 .30902 L
.43847 .30902 L
.43856 .30902 L
.43877 .30902 L
.43897 .30902 L
.43969 .30902 L
.44135 .30902 L
.44285 .30902 L
.44364 .30902 L
.44448 .30902 L
.44491 .30902 L
.44538 .30902 L
.4458 .30902 L
.4462 .30902 L
.44641 .30902 L
.44661 .30902 L
.44678 .30902 L
.44698 .30902 L
.44709 .30902 L
.44719 .30902 L
.44724 .30902 L
.4473 .30902 L
.44736 .30902 L
.44741 .30902 L
.44752 .30902 L
.44757 .30902 L
.44762 .30902 L
.44772 .30902 L
.44782 .30902 L
.44791 .30902 L
.44802 .30902 L
.44824 .30902 L
.44845 .30902 L
.44864 .30902 L
.44953 .30902 L
Mistroke
.45114 .30902 L
.45263 .30902 L
.45347 .30902 L
.45425 .30902 L
.45468 .30902 L
.45508 .30902 L
.45529 .30902 L
.45553 .30902 L
.45573 .30902 L
.45595 .30902 L
.45616 .30902 L
.45636 .30902 L
.45647 .30902 L
.45657 .30902 L
.45662 .30902 L
.45668 .30902 L
.45674 .30902 L
.45679 .30902 L
.45688 .30902 L
.45699 .30902 L
.45708 .30902 L
.45714 .30902 L
.45719 .30902 L
.45728 .30902 L
.45737 .30902 L
.45756 .30902 L
.45777 .30902 L
.45799 .30902 L
.45839 .30902 L
.45914 .30902 L
.46082 .30902 L
.46241 .30902 L
.46322 .30902 L
.46368 .30902 L
.4641 .30902 L
.4645 .30902 L
.46471 .30902 L
.46494 .30902 L
.46515 .30902 L
.46535 .30902 L
.46555 .30902 L
.46563 .30902 L
.46573 .30902 L
.46582 .30902 L
.46591 .30902 L
.46601 .30902 L
.4661 .30902 L
.4662 .30902 L
.46628 .30902 L
.46636 .30902 L
Mistroke
.46645 .30902 L
.46654 .30902 L
.46664 .30902 L
.46675 .30902 L
.46685 .30902 L
.46722 .30902 L
.4676 .30902 L
.46801 .30902 L
.46884 .30902 L
.47033 .30902 L
.47114 .30902 L
.47191 .30902 L
.47233 .30902 L
.47279 .30902 L
.4732 .30902 L
.47359 .30902 L
.47396 .30902 L
.47435 .30902 L
.47457 .30902 L
.47479 .30902 L
.47498 .30902 L
.47509 .30902 L
.47519 .30902 L
.47528 .30902 L
.47539 .30902 L
.47549 .30902 L
.47558 .30902 L
.47568 .30902 L
.47573 .30902 L
.47579 .30902 L
.47589 .30902 L
.47601 .30902 L
.47624 .30902 L
.47646 .30902 L
.47688 .30902 L
.47996 .30902 L
.48078 .30902 L
.48156 .30902 L
.48197 .30902 L
.48236 .30902 L
.48279 .30902 L
.48303 .30902 L
.48324 .30902 L
.48343 .30902 L
.48363 .30902 L
.48384 .30902 L
.48393 .30902 L
.48403 .30902 L
.48412 .30902 L
.48422 .30902 L
Mistroke
.48432 .30902 L
.48442 .30902 L
.48451 .30902 L
.4846 .30902 L
.48468 .30902 L
.48477 .30902 L
.48487 .30902 L
.48497 .30902 L
.48507 .30902 L
.48519 .30902 L
.48563 .30902 L
.48605 .30902 L
.48643 .30902 L
.48808 .30902 L
.48888 .30902 L
.48961 .30902 L
.49038 .30902 L
.49109 .30902 L
.49149 .30902 L
.49185 .30902 L
.49225 .30902 L
.49245 .30902 L
.49267 .30902 L
.49288 .30902 L
.49298 .30902 L
.49309 .30902 L
.4932 .30902 L
.4933 .30902 L
.4934 .30902 L
.49349 .30902 L
.49358 .30902 L
.49368 .30902 L
.49376 .30902 L
.49385 .30902 L
.49395 .30902 L
.49405 .30902 L
.49424 .30902 L
.49445 .30902 L
.49469 .30902 L
.49511 .30902 L
.49591 .30902 L
.49747 .30902 L
.4983 .30902 L
.49919 .30902 L
.49963 .30902 L
.50004 .30902 L
.50045 .30902 L
.50082 .30902 L
.50118 .30902 L
.50137 .30902 L
Mistroke
.50155 .30902 L
.50175 .30902 L
.50185 .30902 L
.50196 .30902 L
.50206 .30902 L
.50217 .30902 L
.50226 .30902 L
.50235 .30902 L
.50245 .30902 L
.5025 .30902 L
.50256 .30902 L
.50266 .30902 L
.50275 .30902 L
.50281 .30902 L
.50286 .30902 L
.50296 .30902 L
.50319 .30902 L
.50357 .30902 L
.50398 .30902 L
.50547 .30902 L
.50635 .30902 L
.50718 .30902 L
.50792 .30902 L
.5083 .30902 L
.50873 .30902 L
.50911 .30902 L
.50952 .30902 L
.50974 .30902 L
.50995 .30902 L
.51016 .30902 L
.51036 .30902 L
.51054 .30902 L
.51073 .30902 L
.51083 .30902 L
.51094 .30902 L
.51103 .30902 L
.51113 .30902 L
.51122 .30902 L
.51131 .30902 L
.51141 .30902 L
.51151 .30902 L
.5116 .30902 L
.51168 .30902 L
.51186 .30902 L
.51204 .30902 L
.51225 .30902 L
.51266 .30902 L
.51339 .30902 L
.51506 .30902 L
.51582 .30902 L
Mistroke
.51662 .30902 L
.51703 .30902 L
.51749 .30902 L
.51791 .30902 L
.51829 .30902 L
.5187 .30902 L
.51893 .30902 L
.51914 .30902 L
.51932 .30902 L
.51953 .30902 L
.51963 .30902 L
.51968 .30902 L
.51974 .30902 L
.51984 .30902 L
.51994 .30902 L
.52002 .30902 L
.52012 .30902 L
.52021 .30902 L
.52031 .30902 L
.52039 .30902 L
.52047 .30902 L
.52065 .30902 L
.52103 .30902 L
.52143 .30902 L
.52303 .30902 L
.52448 .30902 L
.52529 .30902 L
.52606 .30902 L
.52647 .30902 L
.52686 .30902 L
.52729 .30902 L
.5275 .30902 L
.52774 .30902 L
.52794 .30902 L
.52804 .30902 L
.52815 .30902 L
.52826 .30902 L
.52836 .30902 L
.52846 .30902 L
.52855 .30902 L
.52864 .30902 L
.52874 .30902 L
.52882 .30902 L
.52891 .30902 L
.529 .30902 L
.52911 .30902 L
.52929 .30902 L
.52951 .30902 L
.52974 .30902 L
.53017 .30902 L
Mistroke
.53097 .30902 L
.53253 .30902 L
.53341 .30902 L
.53382 .30902 L
.53424 .30902 L
.53462 .30902 L
.53504 .30902 L
.53541 .30902 L
.53576 .30902 L
.53597 .30902 L
.53618 .30902 L
.53636 .30902 L
.53655 .30902 L
.53665 .30902 L
.53677 .30902 L
.53682 .30902 L
.53688 .30902 L
.53693 .30902 L
.53699 .30902 L
.53705 .30902 L
.5371 .30902 L
.5372 .30902 L
.5373 .30902 L
.5374 .30902 L
.5375 .30902 L
.53755 .30902 L
.53761 .30902 L
.53783 .30902 L
.53802 .30902 L
.53822 .30902 L
.53912 .30902 L
.54074 .30902 L
.54156 .30902 L
.54199 .30902 L
.54245 .30902 L
.54285 .30902 L
.54329 .30902 L
.54369 .30902 L
.54406 .30902 L
.54444 .30902 L
.54466 .30902 L
.54485 .30902 L
.54496 .30902 L
.54507 .30902 L
.54516 .30902 L
.54526 .30902 L
.54536 .30902 L
.54546 .30902 L
.54552 .30902 L
.54557 .30902 L
Mistroke
.54563 .30902 L
.54569 .30902 L
.54579 .30902 L
.54588 .30902 L
.54598 .30902 L
.54609 .30902 L
.54627 .30902 L
.54646 .30902 L
.54717 .30902 L
.54886 .30902 L
.54959 .30902 L
.5504 .30902 L
.55078 .30902 L
.55118 .30902 L
.55153 .30902 L
.55191 .30902 L
.55234 .30902 L
.55253 .30902 L
.55274 .30902 L
.55293 .30902 L
.55314 .30902 L
.55333 .30902 L
.5535 .30902 L
.5536 .30902 L
.55371 .30902 L
.55381 .30902 L
.5539 .30902 L
.55396 .30902 L
.55401 .30902 L
.55406 .30902 L
.55412 .30902 L
.55423 .30902 L
.55428 .30902 L
.55434 .30902 L
.55444 .30902 L
.55454 .30902 L
.55472 .30902 L
.55513 .30902 L
.55584 .30902 L
.55662 .30902 L
.55817 .30902 L
.5586 .30902 L
.55906 .30902 L
.55946 .30902 L
.55989 .30902 L
.56031 .30902 L
.56069 .30902 L
.5611 .30902 L
.56133 .30902 L
.56154 .30902 L
Mistroke
.56173 .30902 L
.56191 .30902 L
.562 .30902 L
.56211 .30902 L
.56216 .30902 L
.56221 .30902 L
.56231 .30902 L
.56241 .30902 L
.56251 .30902 L
.56261 .30902 L
.5627 .30902 L
.56278 .30902 L
.56286 .30902 L
.56304 .30902 L
.56344 .30902 L
.56385 .30902 L
.56459 .30902 L
.5654 .30902 L
.56627 .30902 L
.5671 .30902 L
.56785 .30902 L
.56821 .30902 L
.56861 .30902 L
.56898 .30902 L
.56932 .30902 L
.56952 .30902 L
.5697 .30902 L
.5699 .30902 L
.57 .30902 L
.5701 .30902 L
.57019 .30902 L
.57028 .30902 L
.57036 .30902 L
.57044 .30902 L
.57054 .30902 L
.57063 .30902 L
.57072 .30902 L
.57082 .30902 L
.57093 .30902 L
.57102 .30902 L
.57123 .30902 L
.57143 .30902 L
.57161 .30902 L
.57248 .30902 L
.57394 .30902 L
.57477 .30902 L
.57556 .30902 L
.57632 .30902 L
.57675 .30902 L
.57714 .30902 L
Mistroke
.57753 .30902 L
.57776 .30902 L
.57796 .30902 L
.57808 .30902 L
.57818 .30902 L
.57828 .30902 L
.57838 .30902 L
.57843 .30902 L
.57849 .30902 L
.5786 .30902 L
.57865 .30902 L
.57872 .30902 L
.57877 .30902 L
.57883 .30902 L
.57893 .30902 L
.57903 .30902 L
.57912 .30902 L
.57921 .30902 L
.57943 .30902 L
.57962 .30902 L
.58036 .30902 L
.58202 .30902 L
.58275 .30902 L
.58353 .30902 L
.58398 .30902 L
.58439 .30902 L
.5848 .30902 L
.58519 .30902 L
.58556 .30902 L
.58577 .30902 L
.58597 .30902 L
.58618 .30902 L
.58637 .30902 L
.58647 .30902 L
.58657 .30902 L
.58663 .30902 L
.58669 .30902 L
.58679 .30902 L
.58689 .30902 L
.58699 .30902 L
.58709 .30902 L
.58714 .30902 L
.58719 .30902 L
.58739 .30902 L
.58757 .30902 L
.58791 .30902 L
.58827 .30902 L
.58986 .30902 L
.5907 .30902 L
.59116 .30902 L
Mistroke
.59159 .30902 L
.59238 .30902 L
.5928 .30902 L
.59301 .30902 L
.59325 .30902 L
.59364 .30902 L
.59385 .30902 L
.59405 .30902 L
.59424 .30902 L
.59441 .30902 L
.5945 .30902 L
.5946 .30902 L
.5947 .30902 L
.59479 .30902 L
.59489 .30902 L
.59498 .30902 L
.59507 .30902 L
.59516 .30902 L
.59526 .30902 L
.59537 .30902 L
.59556 .30902 L
.59594 .30902 L
.59629 .30902 L
.59794 .30902 L
.5987 .30902 L
.59949 .30902 L
.59991 .30902 L
.60036 .30902 L
.60078 .30902 L
.60116 .30902 L
.60156 .30902 L
.60179 .30902 L
.602 .30902 L
.60218 .30902 L
.60239 .30902 L
.60249 .30902 L
.60254 .30902 L
.6026 .30902 L
.6027 .30902 L
.6028 .30902 L
.60289 .30902 L
.60297 .30902 L
.60307 .30902 L
.60316 .30902 L
.60325 .30902 L
.60333 .30902 L
.60351 .30902 L
.60389 .30902 L
.60429 .30902 L
.60588 .30902 L
Mistroke
.60657 .30902 L
.60733 .30902 L
.60774 .30902 L
.60813 .30902 L
.60852 .30902 L
.60889 .30902 L
.6091 .30902 L
.60932 .30902 L
.6095 .30902 L
.6097 .30902 L
.60992 .30902 L
.61003 .30902 L
.61015 .30902 L
.61027 .30902 L
.61037 .30902 L
.61047 .30902 L
.61057 .30902 L
.61066 .30902 L
.61076 .30902 L
.61085 .30902 L
.61094 .30902 L
.61104 .30902 L
.61109 .30902 L
.61115 .30902 L
.61134 .30902 L
.61155 .30902 L
.61174 .30902 L
.61217 .30902 L
.61365 .30902 L
.6144 .30902 L
.61519 .30902 L
.61561 .30902 L
.61606 .30902 L
.61648 .30902 L
.61686 .30902 L
.61727 .30902 L
.61749 .30902 L
.6177 .30902 L
.61788 .30902 L
.61809 .30902 L
.61819 .30902 L
.61824 .30902 L
.6183 .30902 L
.6184 .30902 L
.6185 .30902 L
.61859 .30902 L
.61867 .30902 L
.61877 .30902 L
.61886 .30902 L
.61895 .30902 L
Mistroke
.61903 .30902 L
.61921 .30902 L
.61959 .30902 L
.61999 .30902 L
.62157 .30902 L
.62227 .30902 L
.62302 .30902 L
.62344 .30902 L
.62382 .30902 L
.62419 .30902 L
.62458 .30902 L
.6248 .30902 L
.62504 .30902 L
.62526 .30902 L
.62546 .30902 L
.62565 .30902 L
.62585 .30902 L
.62595 .30902 L
.62601 .30902 L
.62606 .30902 L
.62617 .30902 L
.62626 .30902 L
.62635 .30902 L
.62645 .30902 L
.62655 .30902 L
.62663 .30902 L
.62673 .30902 L
.62683 .30902 L
.62704 .30902 L
.62746 .30902 L
.62786 .30902 L
.62934 .30902 L
.63019 .30902 L
.6306 .30902 L
.63098 .30902 L
.6317 .30902 L
.63208 .30902 L
.63228 .30902 L
.63248 .30902 L
.63267 .30902 L
.63287 .30902 L
.63305 .30902 L
.63324 .30902 L
.63344 .30902 L
.63355 .30902 L
.63366 .30902 L
.63376 .30902 L
.63385 .30902 L
.63395 .30902 L
.63405 .30902 L
Mistroke
.63414 .30902 L
.63423 .30902 L
.63432 .30902 L
.63441 .30902 L
.63458 .30902 L
.63475 .30902 L
.63515 .30902 L
.63552 .30902 L
.63631 .30902 L
.63715 .30902 L
.63788 .30902 L
.63868 .30902 L
.6391 .30902 L
.63949 .30902 L
.63987 .30902 L
.64006 .30902 L
.64027 .30902 L
.64047 .30902 L
.64066 .30902 L
.64084 .30902 L
.64103 .30902 L
.64111 .30902 L
.6412 .30902 L
.64127 .30902 L
.64136 .30902 L
.64145 .30902 L
.64154 .30902 L
.64163 .30902 L
.64172 .30902 L
.64181 .30902 L
.64191 .30902 L
.642 .30902 L
.64209 .30902 L
.6423 .30902 L
.64249 .30902 L
.64322 .30902 L
.64407 .30902 L
.64487 .30902 L
.64566 .30902 L
.64607 .30902 L
.64651 .30902 L
.64688 .30902 L
.64729 .30902 L
.64766 .30902 L
.648 .30902 L
.64821 .30902 L
.6484 .30902 L
.64861 .30902 L
.64873 .30902 L
.64884 .30902 L
Mistroke
.64894 .30902 L
.64903 .30902 L
.64914 .30902 L
.64919 .30902 L
.64925 .30902 L
.64934 .30902 L
.64945 .30902 L
.64954 .30902 L
.64963 .30902 L
.64982 .30902 L
.65 .30902 L
.6504 .30902 L
.65112 .30902 L
.6519 .30902 L
.65275 .30902 L
.65314 .30902 L
.65355 .30902 L
.65428 .30902 L
.65464 .30902 L
.65503 .30902 L
.65522 .30902 L
.65539 .30902 L
.65573 .30902 L
.65592 .30902 L
.65612 .30902 L
.6563 .30902 L
.65639 .30902 L
.65649 .30902 L
.65654 .30902 L
.65659 .30902 L
.65669 .30902 L
.65679 .30902 L
.65688 .30902 L
.65698 .30902 L
.65704 .30902 L
.65709 .30902 L
.6572 .30902 L
.65731 .30902 L
.65771 .30902 L
.65808 .30902 L
.65892 .30902 L
.65979 .30902 L
.66061 .30902 L
.6614 .30902 L
.66184 .30902 L
.66225 .30902 L
.66259 .30902 L
.66297 .30902 L
.66316 .30902 L
.66337 .30902 L
Mistroke
.66356 .30902 L
.66374 .30902 L
.66384 .30902 L
.66394 .30902 L
.66403 .30902 L
.66412 .30902 L
.66423 .30902 L
.66428 .30902 L
.66434 .30902 L
.66444 .30902 L
.66453 .30902 L
.66463 .30902 L
.66472 .30902 L
.66489 .30902 L
.66527 .30902 L
.66693 .30902 L
.66771 .30902 L
.66813 .30902 L
.66853 .30902 L
.66923 .30902 L
.66961 .30902 L
.6698 .30902 L
.67001 .30902 L
.67022 .30902 L
.67041 .30902 L
.6706 .30902 L
.67078 .30902 L
.67099 .30902 L
.67109 .30902 L
.67121 .30902 L
.67131 .30902 L
.6714 .30902 L
.67151 .30902 L
.67157 .30902 L
.67162 .30902 L
.67172 .30902 L
.67178 .30902 L
.67183 .30902 L
.67194 .30902 L
.67203 .30902 L
.67215 .30902 L
.67225 .30902 L
.67249 .30902 L
.67331 .30902 L
.67411 .30902 L
.67496 .30902 L
.67537 .30902 L
.67576 .30902 L
.67649 .30902 L
.67686 .30902 L
Mistroke
.67725 .30902 L
.67758 .30902 L
.67777 .30902 L
.67795 .30902 L
.67816 .30902 L
.67835 .30902 L
.67853 .30902 L
.67863 .30902 L
.67872 .30902 L
.67877 .30902 L
.67883 .30902 L
.67893 .30902 L
.67903 .30902 L
.67912 .30902 L
.67921 .30902 L
.67927 .30902 L
.67932 .30902 L
.67943 .30902 L
.67954 .30902 L
.67975 .30902 L
.67997 .30902 L
.68036 .30902 L
.68125 .30902 L
.68202 .30902 L
.68243 .30902 L
.68286 .30902 L
.68325 .30902 L
.68368 .30902 L
.68406 .30902 L
.68442 .30902 L
.68479 .30902 L
.68513 .30902 L
.68532 .30902 L
.68552 .30902 L
.68571 .30902 L
.68589 .30902 L
.68599 .30902 L
.68609 .30902 L
.68617 .30902 L
.68626 .30902 L
.68637 .30902 L
.68642 .30902 L
.68647 .30902 L
.68657 .30902 L
.68667 .30902 L
.68676 .30902 L
.68685 .30902 L
.68702 .30902 L
.6874 .30902 L
.68905 .30902 L
Mistroke
.68981 .30902 L
.69023 .30902 L
.69063 .30902 L
.691 .30902 L
.6914 .30902 L
.69177 .30902 L
.6921 .30902 L
.69248 .30902 L
.69269 .30902 L
.69288 .30902 L
.69305 .30902 L
.69314 .30902 L
.69323 .30902 L
.69333 .30902 L
.69341 .30902 L
.69351 .30902 L
.6936 .30902 L
.6937 .30902 L
.6938 .30902 L
.69386 .30902 L
.69391 .30902 L
.69402 .30902 L
.69422 .30902 L
.6944 .30902 L
.69526 .30902 L
.69606 .30902 L
.69692 .30902 L
.69765 .30902 L
.69806 .30902 L
.69845 .30902 L
.69883 .30902 L
.69922 .30902 L
.69956 .30902 L
.69975 .30902 L
.69993 .30902 L
.70003 .30902 L
.70014 .30902 L
.70023 .30902 L
.70033 .30902 L
.70043 .30902 L
.70053 .30902 L
.70062 .30902 L
.7007 .30902 L
.70075 .30902 L
.70081 .30902 L
.70091 .30902 L
.70101 .30902 L
.7011 .30902 L
.70121 .30902 L
.70131 .30902 L
Mistroke
.70153 .30902 L
.7032 .30902 L
.70394 .30902 L
.70433 .30902 L
.70474 .30902 L
.70515 .30902 L
.70552 .30902 L
.70589 .30902 L
.70625 .30902 L
.70644 .30902 L
.70664 .30902 L
.70682 .30902 L
.70701 .30902 L
.70721 .30902 L
.7074 .30902 L
.70751 .30902 L
.70763 .30902 L
.70773 .30902 L
.70779 .30902 L
.70784 .30902 L
.70794 .30902 L
.70799 .30902 L
.70805 .30902 L
.70815 .30902 L
.70824 .30902 L
.7083 .30902 L
.70835 .30902 L
.70846 .30902 L
.70868 .30902 L
.70906 .30902 L
.70948 .30902 L
.71097 .30902 L
.7114 .30902 L
.7118 .30902 L
.71217 .30902 L
.71256 .30902 L
.71298 .30902 L
.71337 .30902 L
.71358 .30902 L
.71378 .30902 L
.714 .30902 L
.71424 .30902 L
.71445 .30902 L
.71455 .30902 L
.71467 .30902 L
.71476 .30902 L
.71487 .30902 L
.71497 .30902 L
.71506 .30902 L
.71511 .30902 L
Mistroke
.71517 .30902 L
.71528 .30902 L
.71534 .30902 L
.7154 .30902 L
.71551 .30902 L
.71572 .30902 L
.71595 .30902 L
.71756 .30902 L
.71839 .30902 L
.71916 .30902 L
.71955 .30902 L
.71997 .30902 L
.72021 .30902 L
.72043 .30902 L
.72065 .30902 L
.72085 .30902 L
.72105 .30902 L
.72122 .30902 L
.72142 .30902 L
.72152 .30902 L
.72163 .30902 L
.72173 .30902 L
.72183 .30902 L
.72193 .30902 L
.72202 .30902 L
.72213 .30902 L
.72219 .30902 L
.72224 .30902 L
.72234 .30902 L
.72239 .30902 L
.72245 .30902 L
.72264 .30902 L
.72282 .30902 L
.72321 .30902 L
.72393 .30902 L
.72467 .30902 L
.72545 .30902 L
.72591 .30902 L
.72632 .30902 L
.72673 .30902 L
.72712 .30902 L
.72749 .30902 L
.72771 .30902 L
.7279 .30902 L
.72811 .30902 L
.7283 .30902 L
.72841 .30902 L
.72853 .30902 L
.72863 .30902 L
.72873 .30902 L
Mistroke
.72882 .30902 L
.72891 .30902 L
.72901 .30902 L
.72911 .30902 L
.7292 .30902 L
.7293 .30902 L
.7294 .30902 L
.7295 .30902 L
.7296 .30902 L
.72968 .30902 L
.72985 .30902 L
.73022 .30902 L
.73169 .30902 L
.73252 .30902 L
.73293 .30902 L
.73331 .30902 L
.73367 .30902 L
.73408 .30902 L
.7343 .30902 L
.7345 .30902 L
.73469 .30902 L
.7349 .30902 L
.73512 .30902 L
.73533 .30902 L
.73543 .30902 L
.73553 .30902 L
.73563 .30902 L
.73572 .30902 L
.73582 .30902 L
.73588 .30902 L
.73594 .30902 L
.73603 .30902 L
.73614 .30902 L
.73619 .30902 L
.73625 .30902 L
.73631 .30902 L
.73637 .30902 L
.73648 .30902 L
.73659 .30902 L
.7368 .30902 L
.73701 .30902 L
.7374 .30902 L
.73829 .30902 L
.73913 .30902 L
.7399 .30902 L
.7403 .30902 L
.74073 .30902 L
.74115 .30902 L
.74139 .30902 L
.74162 .30902 L
Mistroke
.74183 .30902 L
.74203 .30902 L
.74221 .30902 L
.7424 .30902 L
.7425 .30902 L
.74261 .30902 L
.74267 .30902 L
.74273 .30902 L
.74278 .30902 L
.74284 .30902 L
.74294 .30902 L
.74299 .30902 L
.74305 .30902 L
.74314 .30902 L
.74324 .30902 L
.74334 .30902 L
.74339 .30902 L
.74345 .30902 L
.74367 .30902 L
.74406 .30902 L
.74495 .30902 L
.74572 .30902 L
.74616 .30902 L
.74657 .30902 L
.74697 .30902 L
.7474 .30902 L
.74782 .30902 L
.7482 .30902 L
.74857 .30902 L
.74877 .30902 L
.74896 .30902 L
.74913 .30902 L
.74931 .30902 L
.74941 .30902 L
.74951 .30902 L
.7496 .30902 L
.74968 .30902 L
.74978 .30902 L
.74987 .30902 L
.74997 .30902 L
.75007 .30902 L
.75018 .30902 L
.75023 .30902 L
.75029 .30902 L
.75048 .30902 L
.75067 .30902 L
.75086 .30902 L
.75122 .30902 L
.75209 .30902 L
.75289 .30902 L
Mistroke
.75371 .30902 L
.75414 .30902 L
.7546 .30902 L
.755 .30902 L
.75537 .30902 L
.75559 .30902 L
.75578 .30902 L
.75589 .30902 L
.75601 .30902 L
.75612 .30902 L
.75622 .30902 L
.75631 .30902 L
.75641 .30902 L
.75651 .30902 L
.75661 .30902 L
.7567 .30902 L
.7568 .30902 L
.75689 .30902 L
.75697 .30902 L
.75703 .30902 L
.75708 .30902 L
.75718 .30902 L
.7574 .30902 L
.75781 .30902 L
.75862 .30902 L
.75949 .30902 L
.75991 .30902 L
.76031 .30902 L
.7607 .30902 L
.76106 .30902 L
.7614 .30902 L
.76176 .30902 L
.76197 .30902 L
.76217 .30902 L
.76234 .30902 L
.76253 .30902 L
.76272 .30902 L
.7629 .30902 L
.76301 .30902 L
.76312 .30902 L
.76321 .30902 L
.76331 .30902 L
.76341 .30902 L
.76347 .30902 L
.76352 .30902 L
.76358 .30902 L
.76363 .30902 L
.76369 .30902 L
.76375 .30902 L
.76384 .30902 L
Mistroke
.76394 .30902 L
.76414 .30902 L
.76434 .30902 L
.76452 .30902 L
.76486 .30902 L
.76563 .30902 L
.76641 .30902 L
.76683 .30902 L
.76723 .30902 L
.7676 .30902 L
.76794 .30902 L
.76831 .30902 L
.76852 .30902 L
.76872 .30902 L
.7691 .30902 L
.76931 .30902 L
.76951 .30902 L
.76969 .30902 L
.76986 .30902 L
.76995 .30902 L
.77005 .30902 L
.77015 .30902 L
.77024 .30902 L
.77035 .30902 L
.77041 .30902 L
.77046 .30902 L
.77056 .30902 L
.77066 .30902 L
.77076 .30902 L
.77085 .30902 L
.77105 .30902 L
.77191 .30902 L
.77263 .30902 L
.77339 .30902 L
.77384 .30902 L
.77424 .30902 L
.77464 .30902 L
.77502 .30902 L
.77522 .30902 L
.77544 .30902 L
.77563 .30902 L
.77583 .30902 L
.77605 .30902 L
.77625 .30902 L
.77638 .30902 L
.77649 .30902 L
.7766 .30902 L
.77671 .30902 L
.77681 .30902 L
.77691 .30902 L
Mistroke
.77701 .30902 L
.77707 .30902 L
.77712 .30902 L
.77722 .30902 L
.77728 .30902 L
.77733 .30902 L
.77744 .30902 L
.77755 .30902 L
.77796 .30902 L
.77833 .30902 L
.77914 .30902 L
.78 .30902 L
.78073 .30902 L
.78114 .30902 L
.78153 .30902 L
.78173 .30902 L
.78193 .30902 L
.78212 .30902 L
.78231 .30902 L
.7825 .30902 L
.78268 .30902 L
.78286 .30902 L
.78302 .30902 L
.78322 .30902 L
.78331 .30902 L
.78342 .30902 L
.78351 .30902 L
.78361 .30902 L
.78371 .30902 L
.78379 .30902 L
.78384 .30902 L
.7839 .30902 L
.78399 .30902 L
.7841 .30902 L
.78422 .30902 L
.78462 .30902 L
.78544 .30902 L
.78631 .30902 L
.78704 .30902 L
.78746 .30902 L
.78785 .30902 L
.78826 .30902 L
.78864 .30902 L
.78898 .30902 L
.78918 .30902 L
.78935 .30902 L
.78955 .30902 L
.78973 .30902 L
.78983 .30902 L
.78992 .30902 L
Mistroke
.79003 .30902 L
.79013 .30902 L
.79023 .30902 L
.79034 .30902 L
.79043 .30902 L
.79053 .30902 L
.79058 .30902 L
.79064 .30902 L
.79075 .30902 L
.79096 .30902 L
.79134 .30902 L
.79174 .30902 L
.79248 .30902 L
.79289 .30902 L
.79334 .30902 L
.79375 .30902 L
.79414 .30902 L
.79453 .30902 L
.79475 .30902 L
.79496 .30902 L
.79538 .30902 L
.79562 .30902 L
.79585 .30902 L
.79604 .30902 L
.79615 .30902 L
.79625 .30902 L
.79634 .30902 L
.79644 .30902 L
.79653 .30902 L
.79662 .30902 L
.79672 .30902 L
.79677 .30902 L
.79683 .30902 L
.79689 .30902 L
.79695 .30902 L
.797 .30902 L
.79706 .30902 L
.79716 .30902 L
.79721 .30902 L
.79727 .30902 L
.79746 .30902 L
.79765 .30902 L
.79786 .30902 L
.79827 .30902 L
.79902 .30902 L
.79947 .30902 L
.79989 .30902 L
.80031 .30902 L
.80069 .30902 L
.80106 .30902 L
Mistroke
.80145 .30902 L
.80184 .30902 L
.80206 .30902 L
.80226 .30902 L
.80248 .30902 L
.80269 .30902 L
.80287 .30902 L
.80298 .30902 L
.80308 .30902 L
.80313 .30902 L
.80319 .30902 L
.80324 .30902 L
.8033 .30902 L
.8034 .30902 L
.8035 .30902 L
.80355 .30902 L
.80361 .30902 L
.80371 .30902 L
.80377 .30902 L
.80383 .30902 L
.80395 .30902 L
.80414 .30902 L
.80432 .30902 L
.80472 .30902 L
.80555 .30902 L
.80625 .30902 L
.80703 .30902 L
.80744 .30902 L
.80782 .30902 L
.80822 .30902 L
.80845 .30902 L
.80865 .30902 L
.80883 .30902 L
.80902 .30902 L
.80923 .30902 L
.80932 .30902 L
.80942 .30902 L
.80951 .30902 L
.80959 .30902 L
.80968 .30902 L
.80976 .30902 L
.80985 .30902 L
.80995 .30902 L
.81004 .30902 L
.81014 .30902 L
.81023 .30902 L
.81033 .30902 L
.81043 .30902 L
.81053 .30902 L
.81089 .30902 L
Mistroke
.8117 .30902 L
.8124 .30902 L
.81316 .30902 L
.8136 .30902 L
.81401 .30902 L
.8144 .30902 L
.81459 .30902 L
.81481 .30902 L
.815 .30902 L
.81517 .30902 L
.81535 .30902 L
.81552 .30902 L
.81571 .30902 L
.81582 .30902 L
.81592 .30902 L
.816 .30902 L
.8161 .30902 L
.8162 .30902 L
.8163 .30902 L
.8164 .30902 L
.81649 .30902 L
.81659 .30902 L
.81669 .30902 L
.81678 .30902 L
.81687 .30902 L
.81706 .30902 L
.81725 .30902 L
.81747 .30902 L
.8179 .30902 L
.81878 .30902 L
.81917 .30902 L
.81959 .30902 L
.81996 .30902 L
.82035 .30902 L
.82076 .30902 L
.82114 .30902 L
.82136 .30902 L
.8216 .30902 L
.82182 .30902 L
.82202 .30902 L
.82221 .30902 L
.82241 .30902 L
.82251 .30902 L
.82262 .30902 L
.82272 .30902 L
.82282 .30902 L
.82292 .30902 L
.82302 .30902 L
.82311 .30902 L
.8232 .30902 L
Mistroke
.82331 .30902 L
.82342 .30902 L
.82361 .30902 L
.82435 .30902 L
.82515 .30902 L
.82559 .30902 L
.82601 .30902 L
.82641 .30902 L
.82684 .30902 L
.82723 .30902 L
.82759 .30902 L
.82793 .30902 L
.82813 .30902 L
.82831 .30902 L
.8285 .30902 L
.82867 .30902 L
.82877 .30902 L
.82887 .30902 L
.82897 .30902 L
.82907 .30902 L
.82917 .30902 L
.82922 .30902 L
.82928 .30902 L
.82938 .30902 L
.82947 .30902 L
.82953 .30902 L
.82958 .30902 L
.82969 .30902 L
.8298 .30902 L
.82991 .30902 L
.83033 .30902 L
.83071 .30902 L
.83143 .30902 L
.83221 .30902 L
.83261 .30902 L
.83298 .30902 L
.83333 .30902 L
.8337 .30902 L
.8339 .30902 L
.83411 .30902 L
.8343 .30902 L
.83449 .30902 L
.83473 .30902 L
.83483 .30902 L
.83495 .30902 L
.83505 .30902 L
.83516 .30902 L
.83526 .30902 L
.83536 .30902 L
.83546 .30902 L
Mistroke
.83556 .30902 L
.83562 .30902 L
.83567 .30902 L
.83578 .30902 L
.83588 .30902 L
.83597 .30902 L
.83607 .30902 L
.83617 .30902 L
.83636 .30902 L
.83653 .30902 L
.83692 .30902 L
.83778 .30902 L
.8382 .30902 L
.83859 .30902 L
.83897 .30902 L
.83938 .30902 L
.83979 .30902 L
.84002 .30902 L
.84023 .30902 L
.8406 .30902 L
.8408 .30902 L
.841 .30902 L
.84118 .30902 L
.84134 .30902 L
.84153 .30902 L
.84163 .30902 L
.84172 .30902 L
.84182 .30902 L
.84191 .30902 L
.84201 .30902 L
.84211 .30902 L
.84216 .30902 L
.84222 .30902 L
.84233 .30902 L
.84243 .30902 L
.84252 .30902 L
.84269 .30902 L
.84288 .30902 L
.84326 .30902 L
.84413 .30902 L
.84452 .30902 L
.84493 .30902 L
.8453 .30902 L
.84569 .30902 L
.8461 .30902 L
.84648 .30902 L
.8467 .30902 L
.84694 .30902 L
.84716 .30902 L
.84736 .30902 L
Mistroke
.84755 .30902 L
.84775 .30902 L
.84785 .30902 L
.84796 .30902 L
.84806 .30902 L
.84816 .30902 L
.84826 .30902 L
.84836 .30902 L
.84845 .30902 L
.84854 .30902 L
.84864 .30902 L
.8487 .30902 L
.84875 .30902 L
.84895 .30902 L
.84913 .30902 L
.84933 .30902 L
.84968 .30902 L
.85055 .30902 L
.85135 .30902 L
.85174 .30902 L
.85216 .30902 L
.85259 .30902 L
.85283 .30902 L
.85305 .30902 L
.85325 .30902 L
.85346 .30902 L
.85364 .30902 L
.85383 .30902 L
.85404 .30902 L
.85416 .30902 L
.85426 .30902 L
.85436 .30902 L
.85442 .30902 L
.85447 .30902 L
.85457 .30902 L
.85467 .30902 L
.85476 .30902 L
.85487 .30902 L
.85497 .30902 L
.85506 .30902 L
.85524 .30902 L
.85542 .30902 L
.85624 .30902 L
.85701 .30902 L
.85771 .30902 L
.85811 .30902 L
.85854 .30902 L
.85896 .30902 L
.85921 .30902 L
.85943 .30902 L
Mistroke
.85964 .30902 L
.85984 .30902 L
.86002 .30902 L
.86021 .30902 L
.86031 .30902 L
.86043 .30902 L
.86054 .30902 L
.8606 .30902 L
.86065 .30902 L
.86075 .30902 L
.86084 .30902 L
.86094 .30902 L
.861 .30902 L
.86105 .30902 L
.86115 .30902 L
.86121 .30902 L
.86126 .30902 L
.86146 .30902 L
.86169 .30902 L
.8619 .30902 L
.8627 .30902 L
.86341 .30902 L
.86379 .30902 L
.86419 .30902 L
.86463 .30902 L
.86503 .30902 L
.86541 .30902 L
.86562 .30902 L
.86582 .30902 L
.86601 .30902 L
.8662 .30902 L
.86636 .30902 L
.86654 .30902 L
.86664 .30902 L
.86673 .30902 L
.86678 .30902 L
.86684 .30902 L
.86694 .30902 L
.86703 .30902 L
.86713 .30902 L
.86722 .30902 L
.86731 .30902 L
.86742 .30902 L
.86751 .30902 L
.86762 .30902 L
.86773 .30902 L
.86813 .30902 L
.86887 .30902 L
.8693 .30902 L
.86975 .30902 L
Mistroke
.87016 .30902 L
.87055 .30902 L
.87094 .30902 L
.87117 .30902 L
.87138 .30902 L
.87158 .30902 L
.87181 .30902 L
.87204 .30902 L
.87227 .30902 L
.87246 .30902 L
.87268 .30902 L
.87279 .30902 L
.8729 .30902 L
.87301 .30902 L
.87311 .30902 L
.8732 .30902 L
.87329 .30902 L
.87339 .30902 L
.87349 .30902 L
.87354 .30902 L
.8736 .30902 L
.8737 .30902 L
.87389 .30902 L
.87546 .30902 L
.87588 .30902 L
.87634 .30902 L
.87678 .30902 L
.87718 .30902 L
.87737 .30902 L
.87758 .30902 L
.87795 .30902 L
.87818 .30902 L
.8784 .30902 L
.87859 .30902 L
.8787 .30902 L
.8788 .30902 L
.87899 .30902 L
.87909 .30902 L
.87919 .30902 L
.87924 .30902 L
.8793 .30902 L
.87941 .30902 L
.87951 .30902 L
.8796 .30902 L
.87969 .30902 L
.87977 .30902 L
.87986 .30902 L
.87996 .30902 L
.88034 .30902 L
.88111 .30902 L
Mistroke
.88192 .30902 L
.88239 .30902 L
.88282 .30902 L
.88325 .30902 L
.88344 .30902 L
.88365 .30902 L
.88404 .30902 L
.88425 .30902 L
.88445 .30902 L
.88463 .30902 L
.8848 .30902 L
.8849 .30902 L
.885 .30902 L
.88509 .30902 L
.88518 .30902 L
.88528 .30902 L
.88538 .30902 L
.88544 .30902 L
.88549 .30902 L
.8856 .30902 L
.88565 .30902 L
.88571 .30902 L
.88581 .30902 L
.88587 .30902 L
.88593 .30902 L
.88604 .30902 L
.88624 .30902 L
.88642 .30902 L
.88684 .30902 L
.88756 .30902 L
.88834 .30902 L
.88879 .30902 L
.8892 .30902 L
.88961 .30902 L
.89 .30902 L
.89021 .30902 L
.89041 .30902 L
.89058 .30902 L
.89077 .30902 L
.89098 .30902 L
.89108 .30902 L
.8912 .30902 L
.8913 .30902 L
.8914 .30902 L
.8915 .30902 L
.89159 .30902 L
.89168 .30902 L
.89178 .30902 L
.89187 .30902 L
.89196 .30902 L
Mistroke
.89206 .30902 L
.89216 .30902 L
.89235 .30902 L
.89307 .30902 L
.89391 .30902 L
.89468 .30902 L
.89507 .30902 L
.89549 .30902 L
.89573 .30902 L
.89596 .30902 L
.89617 .30902 L
.89638 .30902 L
.89657 .30902 L
.89675 .30902 L
.89695 .30902 L
.89706 .30902 L
.89716 .30902 L
.89726 .30902 L
.89736 .30902 L
.89745 .30902 L
.89755 .30902 L
.89761 .30902 L
.89766 .30902 L
.89772 .30902 L
.89778 .30902 L
.89788 .30902 L
.89793 .30902 L
.89799 .30902 L
.89808 .30902 L
.89818 .30902 L
.89836 .30902 L
.8987 .30902 L
.89947 .30902 L
.89986 .30902 L
.90029 .30902 L
.90069 .30902 L
.90106 .30902 L
.90148 .30902 L
.90187 .30902 L
.90208 .30902 L
.90229 .30902 L
.90251 .30902 L
.90275 .30902 L
.90296 .30902 L
.90306 .30902 L
.90318 .30902 L
.90328 .30902 L
.90339 .30902 L
.90349 .30902 L
.90358 .30902 L
Mistroke
.90363 .30902 L
.90369 .30902 L
.9038 .30902 L
.90385 .30902 L
.90391 .30902 L
.90397 .30902 L
.90404 .30902 L
.90415 .30902 L
.90426 .30902 L
.90447 .30902 L
.90525 .30902 L
.90609 .30902 L
.90652 .30902 L
.90692 .30902 L
.90728 .30902 L
.90768 .30902 L
.90805 .30902 L
.90824 .30902 L
.90844 .30902 L
.90862 .30902 L
.90881 .30902 L
.90899 .30902 L
.90915 .30902 L
.90925 .30902 L
.90935 .30902 L
.90944 .30902 L
.90953 .30902 L
.90964 .30902 L
.90969 .30902 L
.90975 .30902 L
.90985 .30902 L
.90994 .30902 L
.91004 .30902 L
.91013 .30902 L
.9103 .30902 L
.91068 .30902 L
.91149 .30902 L
.91193 .30902 L
.91234 .30902 L
.91274 .30902 L
.91311 .30902 L
.91351 .30902 L
.91374 .30902 L
.91395 .30902 L
.91431 .30902 L
.9145 .30902 L
.9147 .30902 L
.9149 .30902 L
.91508 .30902 L
.91525 .30902 L
Mistroke
.91534 .30902 L
.91543 .30902 L
.91553 .30902 L
.91562 .30902 L
.91571 .30902 L
.9158 .30902 L
.9159 .30902 L
.91596 .30902 L
.91601 .30902 L
.91611 .30902 L
.91621 .30902 L
.91656 .30902 L
.91694 .30902 L
.91773 .30902 L
.91815 .30902 L
.91859 .30902 L
.91903 .30902 L
.91943 .30902 L
.91962 .30902 L
.91983 .30902 L
.9202 .30902 L
.92041 .30902 L
.92063 .30902 L
.92074 .30902 L
.92086 .30902 L
.92097 .30902 L
.92108 .30902 L
.9212 .30902 L
.9213 .30902 L
.9214 .30902 L
.92146 .30902 L
.92151 .30902 L
.9216 .30902 L
.92171 .30902 L
.9218 .30902 L
.92189 .30902 L
.922 .30902 L
.92209 .30902 L
.92227 .30902 L
.92268 .30902 L
.92341 .30902 L
.92421 .30902 L
.92462 .30902 L
.92507 .30902 L
.92547 .30902 L
.92569 .30902 L
.92589 .30902 L
.92627 .30902 L
.92646 .30902 L
.92667 .30902 L
Mistroke
.92686 .30902 L
.92704 .30902 L
.92714 .30902 L
.92724 .30902 L
.92734 .30902 L
.92743 .30902 L
.92752 .30902 L
.9276 .30902 L
.92769 .30902 L
.92778 .30902 L
.92788 .30902 L
.92797 .30902 L
.92815 .30902 L
.92961 .30902 L
.93001 .30902 L
.93044 .30902 L
.93085 .30902 L
.93122 .30902 L
.93159 .30902 L
.9318 .30902 L
.93199 .30902 L
.93219 .30902 L
.93238 .30902 L
.9326 .30902 L
.9328 .30902 L
.9329 .30902 L
.93301 .30902 L
.93312 .30902 L
.93323 .30902 L
.93332 .30902 L
.93341 .30902 L
.93352 .30902 L
.93361 .30902 L
.93372 .30902 L
.93378 .30902 L
.93383 .30902 L
.93403 .30902 L
.93427 .30902 L
.93449 .30902 L
.9352 .30902 L
.93597 .30902 L
.9364 .30902 L
.9368 .30902 L
.9372 .30902 L
.93759 .30902 L
.93778 .30902 L
.93798 .30902 L
.93816 .30902 L
.93835 .30902 L
.93856 .30902 L
Mistroke
.93875 .30902 L
.93886 .30902 L
.93898 .30902 L
.93908 .30902 L
.93913 .30902 L
.93919 .30902 L
.93929 .30902 L
.93935 .30902 L
.93941 .30902 L
.93951 .30902 L
.93956 .30902 L
.93961 .30902 L
.93971 .30902 L
.93982 .30902 L
.94 .30902 L
.94088 .30902 L
.94169 .30902 L
.94215 .30902 L
.94258 .30902 L
.94299 .30902 L
.94336 .30902 L
.94356 .30902 L
.94379 .30902 L
.944 .30902 L
.94419 .30902 L
.94439 .30902 L
.94457 .30902 L
.94467 .30902 L
.94478 .30902 L
.94488 .30902 L
.94497 .30902 L
.94506 .30902 L
.94514 .30902 L
.94523 .30902 L
.94533 .30902 L
.94543 .30902 L
.94553 .30902 L
.94561 .30902 L
.9457 .30902 L
.94612 .30902 L
.94657 .30902 L
.94736 .30902 L
.94777 .30902 L
.94819 .30902 L
.94841 .30902 L
.94865 .30902 L
.94888 .30902 L
.94908 .30902 L
.94928 .30902 L
.94949 .30902 L
Mistroke
.94971 .30902 L
.94992 .30902 L
.95012 .30902 L
.95022 .30902 L
.95032 .30902 L
.9505 .30902 L
.9506 .30902 L
.9507 .30902 L
.9508 .30902 L
.95089 .30902 L
.951 .30902 L
.9511 .30902 L
.95119 .30902 L
.95128 .30902 L
.95137 .30902 L
.95147 .30902 L
.95187 .30902 L
.95231 .30902 L
.95319 .30902 L
.95358 .30902 L
.954 .30902 L
.95442 .30902 L
.95462 .30902 L
.9548 .30902 L
.95517 .30902 L
.95537 .30902 L
.95556 .30902 L
.95576 .30902 L
.95598 .30902 L
.95616 .30902 L
.95627 .30902 L
.95637 .30902 L
.95642 .30902 L
.95648 .30902 L
.95653 .30902 L
.95659 .30902 L
.95669 .30902 L
.95679 .30902 L
.95684 .30902 L
.9569 .30902 L
.957 .30902 L
.95706 .30902 L
.95712 .30902 L
.95724 .30902 L
.95806 .30902 L
.95884 .30902 L
.95954 .30902 L
.95993 .30902 L
.9603 .30902 L
.96066 .30902 L
Mistroke
.96087 .30902 L
.96106 .30902 L
.96126 .30902 L
.96145 .30902 L
.96167 .30902 L
.96187 .30902 L
.96198 .30902 L
.96208 .30902 L
.96219 .30902 L
.96229 .30902 L
.96239 .30902 L
.96248 .30902 L
.96258 .30902 L
.96268 .30902 L
.96278 .30902 L
.96284 .30902 L
.9629 .30902 L
.9631 .30902 L
.96356 .30902 L
.96436 .30902 L
.96481 .30902 L
.96522 .30902 L
.96557 .30902 L
.96595 .30902 L
.96617 .30902 L
.96637 .30902 L
.96658 .30902 L
.96676 .30902 L
.96694 .30902 L
.96713 .30902 L
.96733 .30902 L
.96752 .30902 L
.9677 .30902 L
.96779 .30902 L
.96789 .30902 L
.96798 .30902 L
.96807 .30902 L
.96816 .30902 L
.96823 .30902 L
.96833 .30902 L
.96844 .30902 L
.96853 .30902 L
.96863 .30902 L
.96874 .30902 L
.96885 .30902 L
.96906 .30902 L
.96984 .30902 L
.97025 .30902 L
.97068 .30902 L
.97107 .30902 L
Mistroke
.97145 .30902 L
.97165 .30902 L
.97188 .30902 L
.97226 .30902 L
.97248 .30902 L
.97272 .30902 L
.97292 .30902 L
.97304 .30902 L
.97314 .30902 L
.97333 .30902 L
.97343 .30902 L
.97354 .30902 L
.97364 .30902 L
.97373 .30902 L
.97382 .30902 L
.97391 .30902 L
.974 .30902 L
.97409 .30902 L
.97419 .30902 L
.97428 .30902 L
.97436 .30902 L
.97444 .30902 L
.97461 .30902 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{421.375, 260.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008>0001AB000`400?l00000o`00003ooooooooo
oooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo
003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooo
oooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool0
0?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooooooo
ool@ooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooo
ooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo0ol0003o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`3o
oooookCooooo000`ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0oooooondoooo
o`00<?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo0?oooooo]?ooool0033ooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`3ooooookCooooo000`ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0oooooondooooo`00<?ooool00ol0003oooooooooo`0T
ooooo`;o0000oooooonfooooo`00<?ooool00ol0003oooooooooo`0Tooooo`;o0000oooooonfoooo
o`00<?ooool3o`0002Cooooo0_l0003ooooookKooooo000`ooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooool00000ooooooneooooo`00<?ooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooo00000?oooooo]Oooool0033ooooo00?o0000ooooooooool09?ooool00ol0003oooooo`00003o
oooookGooooo000`ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooool00000ooooooneoooo
o`00<?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo00000?oooooo]Oooool0033ooooo
00?o0000ooooooooool09?ooool00ol0003oooooo`00003ooooookGooooo000`ooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooool00000ooooooneooooo`00<?ooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooo000000Wooooo0_l0003ooooooj[ooooo000`ooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooool000002Oooool2o`000?ooooooZ_ooool0033ooooo00?o0000oooooooo
ool09?ooool00ol0003oooooo`000009ooooo`;o0000oooooonZooooo`00<?ooool3o`0002Cooooo
00?o0000ooooool000002Oooool2o`000?ooooooZ_ooool0033ooooo00?o0000ooooooooool09?oo
ool00ol0003oooooo`000009ooooo`;o0000oooooonZooooo`00<?ooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooo000000Wooooo0_l0003ooooooj[ooooo000`ooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooool000002Oooool2o`000?ooooooZ_ooool0033ooooo00?o0000oooooooo
ool09?ooool00ol0003oooooo`000009ooooo`;o0000oooooonZooooo`00<?ooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooo000000Wooooo0_l0003ooooooj[ooooo000`ooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooool000002Oooool2o`000?ooooooZ_ooool0013ooooo0_o^k^h3
ooooo`;ok^k^6Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo000000Wooooo0_l0003o
oooooj[ooooo000;ooooo`;o000000[o410@ooooooooooook^k^oeEEEOo^k^koooooonk^k_mEEEGo
k^k^0oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h:ooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooool000002Oooool2o`000?ooooooZ_ooool000cooooo00?o0000
ooooooooool00_ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00[ooooo00?o0000ooooooooool09?ooool00ol0003ooooo
o`000009ooooo`;o0000oooooonZooooo`0000?oooooo`000?l000001?l00002ooooo`Go00001?oo
ool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooo
oa0@400:ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooool000002Oooool2o`000?oooooo
Z_ooool000Wooooo00CoA4A4omgMgOoooooo00001?ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Ko
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000[ooooo00?o0000oooo
ooooool09?ooool00ol0003oooooo`000009ooooo`;o0000oooooonZooooo`002Oooool01?oMgMgo
EEEEooooool00003ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000:ooooo`Co00008oooool00ol0003ooooo
o`000008ooooo`03o`000?oooooo00000?ooooooZ_ooool000[ooooo00?oMgMgolc<c?l000000ooo
ool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooo
oa0@400:ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooool000002?ooool00ol0003ooooo
o`00003ooooooj[ooooo000:ooooo`03onk^k_m4A4Co000000oooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo0_l00005ooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooool000002?ooool00ol0003oooooo`00003ooooooj[ooooo000;ooooo`03ogMgMol0
003ooooo00cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo000000So
oooo00?o0000ooooool00000oooooonZooooo`00:?ooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooool000002?ooool00ol0003oooooo`00003ooooooj[o
oooo000Xooooo`?o00001Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo000000Sooooo
00?o0000ooooool00000oooooonZooooo`00:Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooool000002?ooool00ol0003oooooo`00003ooooooj[ooooo000Z
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09?ooool00ol0003oooooo`000008
ooooo`04o`000?ooooooooooo`000?ooooooZOooool0033ooooo00?o0000ooooooooool09?ooool0
0ol0003oooooo`000008ooooo`04o`000?ooooooooooo`000?ooooooZOooool0033ooooo00?o0000
ooooooooool08oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`000?oooooo
ZOooool0033ooooo00?o0000ooooooooool08oooool01?l0003oooooooooool00008ooooo`04o`00
0?ooooooooooo`000?ooooooZOooool0033ooooo00?o0000ooooooooool08oooool01?l0003ooooo
ooooool00008ooooo`04o`000?ooooooooooo`000?ooooooZOooool0033ooooo0ol0000Sooooo`05
o`000?ooooooooooooooool000001oooool01?l0003oooooooooool0003oooooojWooooo000`oooo
o`03o`000?oooooooooo02?ooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?oooooo
ooooo`000?ooooooZOooool0033ooooo00?o0000ooooooooool08oooool01Ol0003ooooooooooooo
oooo000000Oooooo00Co0000oooooooooooo0000oooooonYooooo`00<?ooool00ol0003ooooooooo
o`0Sooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool0003oooooojWo
oooo000`ooooo`03o`000?oooooooooo02?ooooo00Go0000ooooooooooooooooo`000007ooooo`04
o`000?ooooooooooo`000?ooooooZOooool0033ooooo00?o0000ooooooooool08oooool01Ol0003o
oooooooooooooooo000000Oooooo00Co0000oooooooooooo0000oooooonYooooo`00<?ooool00ol0
003oooooooooo`0Sooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool0
003oooooojWooooo000`ooooo`03o`000?oooooooooo02?ooooo00Go0000ooooooooooooooooo`00
0007ooooo`04o`000?ooooooooooo`000?ooooooZOooool0033ooooo00?o0000ooooooooool08ooo
ool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000oooooonYooooo`00
<?ooool00ol0003oooooooooo`0Sooooo`05o`000?ooooooooooooooool000001oooool01?l0003o
ooooooooool0003oooooojWooooo000`ooooo`03o`000?oooooooooo02?ooooo00Go0000oooooooo
ooooooooo`000007ooooo`04o`000?ooooooooooo`000?ooooooZOooool0033ooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool000001oooool0
1?l0003oooooooooool0003oooooojWooooo000`ooooo`?o00006?ooool2o`0000Wooooo00Go0000
ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`000?ooooooZOooool0033ooooo00?o
0000ooooooooool06?ooool2o`0000Wooooo00Go0000ooooooooooooooooo`000007ooooo`04o`00
0?ooooooooooo`000?ooooooZOooool0033ooooo00?o0000ooooooooool06?ooool2o`0000Wooooo
00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`000?ooooooZOooool0033o
oooo00?o0000ooooooooool06?ooool2o`0000Wooooo00Go0000ooooooooooooooooo`000007oooo
o`04o`000?ooooooooooo`000?ooooooZOooool0033ooooo00?o0000ooooooooool06?ooool00ol0
003oooooo`000008ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool0
003oooooojWooooo000`ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooool000002?ooool0
1Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000oooooonYooooo`00<?oo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooo000000Sooooo00Go0000oooooooooooooooo
o`000007ooooo`04o`000?ooooooooooo`000?ooooooZOooool0033ooooo00?o0000ooooooooool0
6?ooool00ol0003oooooo`000008ooooo`05o`000?ooooooooooooooool000001oooool01?l0003o
ooooooooool0003oooooojWooooo000`ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooool0
00002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000oooooonY
ooooo`00<?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo000000Sooooo00Go0000oooo
ooooooooooooo`000007ooooo`04o`000?ooooooooooo`000?ooooooZOooool0033ooooo00?o0000
ooooooooool06?ooool00ol0003oooooo`000008ooooo`05o`000?ooooooooooooooool000001ooo
ool01?l0003oooooooooool0003oooooojWooooo000`ooooo`?o00006?ooool00ol0003oooooo`00
0008ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool0003oooooojWo
oooo000`ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooool000002?ooool01Ol0003ooooo
oooooooooooo000000Oooooo00Co0000oooooooooooo0000oooooonYooooo`00<?ooool00ol0003o
ooooooooo`0Gooooo`04o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000007
ooooo`04o`000?ooooooooooo`000?ooooooZOooool0033ooooo00?o0000ooooooooool05oooool0
1?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool000001oooool01?l0003ooooo
ooooool0003oooooojWooooo000`ooooo`03o`000?oooooooooo01Oooooo00Co0000oooooooooooo
00002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000oooooonY
ooooo`00<?ooool00ol0003oooooooooo`0Gooooo`04o`000?ooooooooooo`0000Sooooo00Go0000
ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`000?ooooooZOooool0033ooooo00?o
0000ooooooooool05oooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool0
00001oooool01?l0003oooooooooool00008ooooo`;o0000oooooonOooooo`004?ooool2onk^kP?o
oooo0_o^k^hIooooo`03o`000?oooooooooo01Oooooo00Co0000oooooooooooo00002?ooool01Ol0
003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo00002?ooool2o`000?ooooooWooo
ool000Wooooo1Ol00002ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co0000
00So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP[ooooo00?o0000ooooooooool05oooool0
1?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool000001oooool01?l0003ooooo
ooooool00008ooooo`;o0000oooooonOooooo`002Oooool01OnHV9So8B4Qonk^k_ooooooA4A400?o
oooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0:ooooo`03o`000?oooooooooo01Oooooo00Co0000oooooooooooo00002?oo
ool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo00002?ooool2o`000?oo
ooooWoooool00003ooooool0003o000000Co00000oooool00onHV9So8B4Qonk^kP05ooooo`03omgM
gOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00[o
oooo00?o0000ooooooooool05oooool01?l0003oooooooooool00008ooooo`05o`000?oooooooooo
ooooool000001oooool01?l0003oooooooooool00008ooooo`;o0000oooooonOooooo`002oooool0
0onHV9So8B4Qonk^kP03ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000002_ooool00ol0003oooooooooo`0Gooooo`04o`00
0?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooooooo
ooooool000001oooool2o`000?ooooooWoooool000cooooo00_oMgMgofIVI_ooooooooooonk^k_mE
EEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`00000:ooooo`Co00005_ooool01?l0003oooooooooool00008ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo0_l0
003ooooooioooooo000=ooooo`03o`000?oooooooooo00;ok^k^0oooool2onk^kPGooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00[ooooo00?o0000ooooooooool05ooo
ool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Gooooo0_l0003ooooooioooooo0009ooooo`05o`00
0?nj^[[ooooooiRHV?l@41003_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL00oooool2o`0000Gooooo00?o0000ooooooooool05oooool01?l0003oooooooooool00008
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Gooooo0_l0003ooooooioooooo0009ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?oo
ool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_ooool01?l0003ooooo
ooooool00004ooooo`03o`000?oooooooooo01Oooooo00Co0000oooooooooooo00002?ooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooo00000?ooooooWoooool002Sooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooooooo`0Gooooo`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
o`00003ooooooioooooo000Xooooo`?o00001Oooool00ol0003oooooooooo`0Gooooo`05o`000?oo
ooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`000?ooooooW_ooool002Wo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Gooooo`05o`000?oooooooooooooo
ool000001oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`000?ooooooW_ooool002[ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0Gooooo`05o`000?ooooooooooooooool000001ooo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`04ooooo`04o`000?ooooooooooo`000?ooooooW_ooool0033ooooo00?o0000ooooooooool0
5oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000006oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0003o
oooooikooooo000`ooooo`03o`000?oooooooooo01Oooooo00Go0000ooooooooooooooooo`000007
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00Co0000oooooooooooo0000oooooonNooooo`00<?ooool00ol0003ooooooooo
o`0Gooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`00
0?ooooooW_ooool0033ooooo00?o0000ooooooooool05oooool01Ol0003ooooooooooooooooo0000
00Oooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool01?l0003oooooooooool0003ooooooikooooo000`ooooo`?o00005oooool0
1Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0003ooooooiko
oooo000`ooooo`03o`000?oooooooooo01Oooooo00Go0000ooooooooooooooooo`000007ooooo`05
o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00Co0000oooooooooooo0000oooooonNooooo`00<?ooool00ol0003oooooooooo`0Goooo
o`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Kooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`000?oooooo
W_ooool0033ooooo00?o0000ooooooooool05oooool01Ol0003ooooooooooooooooo000000Oooooo
00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool01?l0003oooooooooool0003ooooooikooooo000`ooooo`03o`000?oooooooooo01Oo
oooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo0000oooo
oonNooooo`00<?ooool00ol0003oooooooooo`0Gooooo`05o`000?ooooooooooooooool000001ooo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`04ooooo`04o`000?ooooooooooo`000?ooooooW_ooool0033ooooo00?o0000ooooooooool0
5oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000006oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0003o
oooooikooooo000`ooooo`03o`000?oooooooooo01Oooooo00Go0000ooooooooooooooooo`000007
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo0000oooooonNooooo`00<?ooool0
0ol0003oooooooooo`0Gooooo`05o`000?ooooooooooooooool000001oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`04ooooo`04o`000?ooooooooooo`000?ooooooW_ooool0033ooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool01?l0003oooooooooool0003ooooooikooooo000`ooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Co
0000oooooooooooo0000oooooonNooooo`00<?ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`04o`000?oo
ooooooooo`000?ooooooW_ooool0033ooooo0ol0000Fooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`000?oooooo
W_ooool0033ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0003ooooooikooooo
000`ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00003ooooooigooooo
000`ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00003ooooooigooooo
000`ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00003ooooooigooooo
000`ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000oooooo0_o^k^h3ooooo`;ok^k^Eoooool2onk^kP?ooooo0_o^k^iPooooo`;ok^k^
0oooool2onk^kTkooooo0_o^k^h3ooooo`;ok^k^K?ooool0033ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooo`000008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000002Oooool03Om4A4Co0000
o`000?lb<S;ogMgMooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@
4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^i2ooooo`Co000000Wo410@ooooooo^k^koEEEEonk^
k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^hkooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo00goA4A4o`000?l0003o<S8b
omgMgOooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413ooooooooo
ooo^k^ko<S8bo`000?lb<S;ok^k^>?ooool5o`0000;ooooo00Ook^k^oeEEEOo^k^koooooonk^k_mE
EEGok^k^00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^GOooool0033o
oooo00?o0000ooooooooool02oooool00ol0003oooooo`000008ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool02_ooool02OmgMgOo<S8booooooooooook^k^oeEEEOoMgMgoEEEEonk^
kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`14ooooo`03o`00
0?oooooooooo00;ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0mooooo`03o`000?oooooooooo00Cooooo0_lQ8B48oooo
o`09ogMgMolb<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg03Sooooo00GoV9RHob4Q8Oo^k^koooooodA4A003oooo
o`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL0GOooool0033ooooo00?o0000ooooooooool02oooool00ol0003oooooo`000008
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03
ooooo`07o`000?oooooooooooooooooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo
00Go410@oooooooooooooooooa0@4014ooooo`03o`000?oooooooooo00?ooooo00?ogMgMo`000?oM
gMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100?Oooool00ol0
003oooooooooo`0?ooooo`07o`000?oooooooooooooooooMgMgo0000omgMg@07ooooo`03o`000?oo
oooooooo00;ooooo00Go410@oooooooooooooooooa0@400iooooo`03oiRHV?lQ8B7ok^k^00Gooooo
00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
4100GOooool0033ooooo00?o0000ooooooooool02oooool00ol0003oooooo`000008ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooo`000003ooooo`09ogMg
Molb<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000004Cooooo00?o0000ooooooooool00_ooool01Oo^k^koEEEEomgM
gOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000003go
oooo00?o0000ooooooooool03_ooool02OmgMgOo<S8booooooooooook^k^oeEEEOoMgMgoEEEEonk^
kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000jooooo`03oiRH
V?lQ8B7ok^k^00?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`00001Mooooo`00<?ooool00ol0003oooooooooo`0:ooooo`04
o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04oooo
o`0@o`000?oooooo0000o`000?lQ8B7o0000oc8b<_o<c<coooooonk^k_mEEEGok^k^ooooooo^k^ko
EEEEonk^kPGooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000004Cooooo
00_o0000ooooooooooooooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000mooooo`03o`000?oooooooooo00_ooooo
00go0000ob4Q8Ol0003o<S8bolc<c?ooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000003_ooooo00_oMgMgofIVI_oo
ooooooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo
00Go0000ooooooooooooooooo`00001Mooooo`00<?ooool00ol0003oooooooooo`0:ooooo`05o`00
0?ooooooooooooooool000001oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00Co0000ooooool0003o00001Oooool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo
00;ooooo00Go410@oooooooooooooooooa0@4014ooooo`04o`000?ooooooooooooooo`;ok^k^0ooo
ool2onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@03gooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`03ooooo`;ok^k^0oooool2onk^kPGooooo
00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@03cooooo00?o0000oooooooo
ool00_o^k^h3ooooo`;ok^k^1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooo
ool@4100GOooool0033ooooo0ol0000:ooooo`05o`000?ooooooooooooooool000001oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Co0000ooooool0003o00004Oooool0
0ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003ooooooooo
o`0iooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Sooooo0_l0000cooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool2o`0002ko
oooo00Go0000okZj^_ooooooV9RHoa0@400>ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`08ooooo`;o0000Doooool0033ooooo00?o0000ooooooooool02_ooool01Ol0
003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooo000000Co00003?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`0gooooo`03oeEEEOmVIVKo000000gooooo00?o
EEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oooooo00Co0000oooooooooooo
0000<?ooool00omEEEGoIVIVo`00000=ooooo`Co00003?ooool00omEEEGoIVIVo`000004ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01oooool01?l0003oooooooooool0000]ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`03?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1oooool01?l0003oooooooooool0001Booooo`00<?ooool00ol0003oooooooooo`0:ooooo`05o`00
0?ooooooooooooooool000001oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00Co0000oooooooooooo00007Oooool4o`0000?ooooo00?o0000ooooooooool0E?ooool4o`00
0005ooooool0003oooooooooool00000G_ooool4o`000005ooooool0003oooooooooool00000C?oo
ool4o`000005ooooool0003oooooooooool00000D_ooool0033ooooo00?o0000ooooooooool02_oo
ool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`04ooooo`04o`000?ooooooooooo`0002Cooooo00?o0000ooooooooool0FOooool3o`0006Co
oooo0ol0001Booooo`?o0000Doooool0033ooooo00?o0000ooooooooool02_ooool01Ol0003ooooo
oooooooooooo000000Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05
o`000?ooooooooooooooool000008_ooool01?l0003oooooooooool0001Kooooo`03o`000?oooooo
oooo06Cooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`1Booooo`00<?ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00000R
ooooo`Co0000G?ooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo05;ooooo00?o0000
ooooooooool0DOooool0033ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0oooooon@ooooo`00<?ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`3ooooooeKooooo00?oMgMgofIVI_ooool0;Oooool00omVIVKoMgMgooooo`07ooooo`00
<?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`;o0000oooooom?ooooo`03omgMgOl@413ok^k^02kooooo
00?ok^k^oa0@4?oMgMd01oooool0033ooooo0ol00009ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`?o0000oooooolmooooo`;o00000_oo
ool2o`0000cooooo00?oEEEEoiRHV?ooool00_l00002ooooo`07o`000?ooooooooooo`000?l@413o
k^k^oeEEE@02o`000003odA4A?nj^[[ooooo00;ooooo00GoV9RHo`000?l0003oA4A4okZj^P02oooo
o`08onk^k_mEEEGo0000o`000?m4A4Co^[Zjooooool@4105o`0000?ooooo00So410@oc8b<_l0003o
0000oa0@4?nYZJWoQhN7ofIVIPOooooo000`ooooo`Co00001oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool0003o
oooooccooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd<ooooo`05o`000?ooooooooooooooool0
00000_ooool02ol0003oooooooooool0003ooooooeEEEOmgMgOoooooonk^k_mgMgOo410@00?ooooo
00Go410@okZj^_o^k^koMgMgoa0@4002ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo410@0oooool0
0ol0003oooooooooo`04ooooo`08o`000?nYZJWooooooooooonj^[[o0000onk^k_l00007ooooo`00
ool0002do`0000oooooo00CogMgMo`000?l@413oc<c<3Oooool01Olb<S;ooooooooooooooooo0000
00;ooooo00Ko0000oooooooooooo0000ooooool00008ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`07okZj^_n7QhOoIVIVofIVI_l@413o
ooooo`000007ooooo`002_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Sooooo
1Ol00003ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`04ooooo`;o
00001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooo`000003ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01?l0003oooooooooooooool2o`00
00Cooooo00?o0000ooooooooool00_ooool6o`0000;ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool05oooool01?o^
k^ko8B4Qoa0@4?o^k^h=ooooo`05oc8b<_ooooooooooooooool000000_ooool01Ol0003ooooooooo
ool0003ooooo00Ko00000oooool00ol0003oooooooooo`04ooooo`Ko00000oooool00ol0003ooooo
ooooo`04ooooo`08oc8b<_lQ8B7oMgMgogMgMon7QhOok^k^ooooool00007ooooo`002_ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo0_l00004ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00oooool2o`0000Cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`04o`000?ooooooooooooooo`;o00001?ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo01Oooooo00Co8B4QogMgMomgMgOo<S8b3Oooool01Ol0003ok^k^oooo
oooooooo000000;oc<c<00_o0000ojVYZOoMgMgo8B4QoooooomEEEGoQhN7onk^k_ooooooQhN7oc8b
<P03ooooo`03o`000?oooooooooo00Cooooo00KoEEEEohN7Qoo^k^koooooohN7Qolb<S83ooooo`03
o`000?lb<S;ogMgM00Cooooo00So0000okZj^_ooooook^k^ogMgMol0003ok^k^o`0000Oooooo000`
ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00Co0000oooooooooooo00003Oooool00ol0003oooooooooo`1Kooooo`03o`00
0?oooooooooo05_ooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`0Fooooo`;o0000
0_ooool2o`0000cooooo00koEEEEogMgMooooooo410@o`000?lQ8B7o0000ogMgMol@413o0000ojVY
ZOooooook^k^oeEEE@;o000000CoA4A4onk^k_oooooo410@1Ol00003ooooo`06onk^k_mEEEGo0000
o`000?m4A4Cok^k^0_ooool2o`000004ojVYZOlQ8B7o0000ob4Q8@;ooooo00SoZJVYob4Q8Ol0003o
0000oc8b<_l0003oMgMgoeEEE@Oooooo000`ooooo`03o`000?oooooooooo00?ooooo00Go0000oooo
ooooooooooooo`000007ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo0000oooo
oomCooooo`03omgMgOl@413ok^k^01;ooooo00?o0000ooooooooool06Oooool00oo^k^ko410@omgM
g@07ooooo`00<?ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000Oooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool01?l0003oooooooooool0003ooooooeCooooo00?oMgMgofIVI_ooool0
4Oooool00ol0003oooooooooo`0Iooooo`03ofIVI_mgMgOooooo00Oooooo000`ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooo00000?ooooooSoooool0033ooooo00?o0000ooooooooool01Oooool2o`0000Sooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool2o`000?ooooooSoooool0033ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00003o
oooooiSooooo000`ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`05o`000?ooooooooooooooool00000oooooonHooooo`00<?ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0
003ooooooooooooooooo00000?ooooooV?ooool0033ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00003o
oooooiSooooo000`ooooo`?o00003oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00?ooooo00Go0000ooooooooooooooooo`00003ooooooiSooooo000`ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooooooo
ooooool00000oooooonHooooo`00<?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo00000?ooooooV?ooool0
033ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00?ooooo00Go0000ooooooooooooooooo`00003ooooooiSooooo000`ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooooooo
ooooool00000oooooonHooooo`00<?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool0003ooooooiWooooo000`oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`04o`000?ooooooooooo`000?ooooooVOooool0033ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo0000oooooonI
ooooo`00<?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooo`00003ooooooiWooooo000`ooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo00000?oo
ooooVOooool0033ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooool00000oooooonIooooo`00<?ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooo`00
003ooooooiWooooo000`ooooo`?o00004?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooool00000oooooonIooooo`00<?ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooo`00003ooooo
oiWooooo000`ooooo`03o`000?oooooooooo013ooooo00Go0000ooooooooooooooooo`000007oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooo00000?ooooooVOooool0033ooooo00?o0000ooooooooool04?ooool01Ol0003o
oooooooooooooooo000000Sooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Oooooo00?o
0000ooooool00000oooooonIooooo`00<?ooool00ol0003oooooooooo`0Aooooo`04o`000?oooooo
ooooo`0000Sooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooool0
0000oooooonIooooo`00<?ooool00ol0003oooooooooo`0Aooooo`04o`000?ooooooooooo`0000So
oooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01?ooool01Ol0003ooooooooooooooooo000000Oooooo0_l0003ooooooi[ooooo000`oooo
o`03o`000?oooooooooo017ooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooo
oooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oo
ooooooooooooool000001oooool2o`000?ooooooV_ooool0033ooooo00?o0000ooooooooool04Ooo
ool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000007oooo
o`;o0000oooooonJooooo`00<?ooool00ol0003oooooooooo`0Aooooo`04o`000?ooooooooooo`00
00Sooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool01Ol0003ooooooooooooooooo00000?ooooooXoooool0033ooooo00?o0000
ooooooooool04Oooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooo
ooooo`00003ooooooj?ooooo000`ooooo`03o`000?oooooooooo017ooooo00Co0000oooooooooooo
00002?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000oooooonSooooo`00<?ooool00ol0
003oooooooooo`0Aooooo`04o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo00000?ooooooXoooool0033ooooo0ol0000Aooooo`04o`000?ooooooooooo`0000Sooooo
00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool01Ol0003ooooooooooooooooo00000?ooooooXoooool0033ooooo00?o0000oooooooo
ool04_ooool2o`0000Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo00000?ooooooXoooool0
033ooooo00?o0000ooooooooool04_ooool2o`0000Wooooo00Go0000ooooooooooooooooo`000006
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooo
oooo00000?ooooooXoooool0033ooooo00?o0000ooooooooool04_ooool2o`0000Wooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool01Ol0003ooooooooooooooooo00000?ooooooXoooool0033ooooo00?o0000ooooooooool04_oo
ool2o`0000Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo00000?ooooooXoooool0033ooooo
00?o0000ooooooooool04_ooool2o`0000Wooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000
0?ooooooXoooool000oooooo0_o^k^h3ooooo`;ok^k^6_ooool00ol0003oooooooooo`0Mooooo`05
o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000
ooooooooooooooooo`00003ooooooj?ooooo0008ooooo`Go00000_ooool01oo^k^koEEEEonk^k_oo
ooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h;
ooooo`03o`000?oooooooooo01gooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oo
ooooooooooooool000001_ooool01Ol0003ooooooooooooooooo00000?ooooooXoooool000Sooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0
003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ol0003oooooooooo`0M
ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Kooooo
00Go0000ooooooooooooooooo`00003ooooooj?ooooo0009ooooo`03oiRHV?lQ8B7ok^k^00Gooooo
00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41002oooool00ol0003oooooooooo`0Mooooo`05o`000?ooooooooooooooool000001oooool01Ol0
003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`00003ooooooj?ooooo000:
ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000;ooooo`03o`000?oooooooooo01gooooo
00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0
003ooooooooooooooooo00000?ooooooXoooool000_ooooo00_oMgMgofIVI_ooooooooooonk^k_mE
EEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`00000;ooooo`Co00007?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000
ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool00000oooooonSooooo`003?oo
ool00ol0003oooooooooo`02onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go
410@oooooooooooooooooa0@400;ooooo`03o`000?oooooooooo01gooooo00Go0000oooooooooooo
ooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo
00000?ooooooXoooool000Sooooo00Go0000okZj^_ooooooV9RHoa0@400>ooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03o`000?oooooooooo01gooooo00Go
0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003o
oooooooooooooooo00000?ooooooXoooool000Sooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00<oooo
o`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`;o00001_ooool0
0ol0003oooooooooo`0Mooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooo
oooooooo000000Kooooo00Go0000ooooooooooooooooo`00003ooooooj?ooooo000Wooooo`04o`00
0?ooooooooooo`0000Gooooo00?o0000ooooooooool07Oooool01Ol0003ooooooooooooooooo0000
00Oooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`000?ooooooY?oo
ool002Oooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`0Mooooo`05o`000?oo
ooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooo
oooo0000oooooonTooooo`009oooool3o`0000Kooooo00?o0000ooooooooool07Oooool01Ol0003o
oooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?oooooo
ooooo`000?ooooooY?ooool002Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0M
ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Kooooo
00Co0000oooooooooooo0000oooooonTooooo`00:Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo01gooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooooooooooo
ool000001_ooool01?l0003oooooooooool0003oooooojCooooo000`ooooo`03o`000?oooooooooo
01gooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Kooooo00Co
0000oooooooooooo0000oooooonTooooo`00<?ooool00ol0003oooooooooo`0Mooooo`04o`000?oo
ooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?oo
ooooY?ooool0033ooooo00?o0000ooooooooool07Oooool01?l0003oooooooooool00008ooooo`05
o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003oooooojCooooo000`ooooo`?o
00007Oooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool000001oooool0
0ol0003oooooo`00003oooooojCooooo000`ooooo`03o`000?oooooooooo01gooooo00Co0000oooo
oooooooo00002?ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooool00000oooo
oonTooooo`00<?ooool00ol0003oooooooooo`0Mooooo`04o`000?ooooooooooo`0000Sooooo00Go
0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?ooooooY?ooool0033ooooo00?o
0000ooooooooool07Oooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool0
00001oooool00ol0003oooooo`00003oooooojCooooo000`ooooo`03o`000?oooooooooo01gooooo
00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000oooo
ool00000oooooonTooooo`00<?ooool00ol0003oooooooooo`0Mooooo`04o`000?ooooooooooo`00
00Sooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?ooooooY?ooool0
033ooooo00?o0000ooooooooool07Oooool01?l0003oooooooooool00008ooooo`05o`000?oooooo
ooooooooool000001oooool00ol0003oooooo`00003oooooojCooooo000`ooooo`03o`000?oooooo
oooo01gooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00008ooooo`03o`00
0?oooooo00000?ooooooY?ooool0033ooooo00?o0000ooooooooool07Oooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooonTooooo`00
<?ooool00ol0003oooooooooo`0Mooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooo
oooo00002?ooool00ol0003oooooo`00003oooooojCooooo000`ooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooool000002?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo0000
0?ooooooY?ooool0033ooooo00?o0000ooooooooool07_ooool00ol0003oooooo`000008ooooo`04
o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooonTooooo`00<?ooool3o`0001ko
oooo00?o0000ooooool000002?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo0000
0?ooooooY?ooool0033ooooo00?o0000ooooooooool07_ooool00ol0003oooooo`000008ooooo`04
o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooonTooooo`00<?ooool00ol0003o
ooooooooo`0Nooooo`03o`000?oooooo000000Sooooo00Co0000oooooooooooo00002?ooool00ol0
003oooooo`00003oooooojCooooo000`ooooo`03o`000?oooooooooo01kooooo00?o0000ooooool0
00002?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?ooooooY?ooool0033o
oooo00?o0000ooooooooool07_ooool00ol0003oooooo`000008ooooo`04o`000?ooooooooooo`00
00Sooooo00?o0000ooooool00000oooooonTooooo`00<?ooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooo000000Sooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003ooooo
ojCooooo000`ooooo`03o`000?oooooooooo01kooooo00?o0000ooooool000002?ooool01?l0003o
ooooooooool00008ooooo`03o`000?oooooo00000?ooooooY?ooool0033ooooo00?o0000oooooooo
ool07_ooool00ol0003oooooo`000008ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000oooo
ool00000oooooonTooooo`00<?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo000000So
oooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003oooooojCooooo000`ooooo`03
o`000?oooooooooo01kooooo00?o0000ooooool000002?ooool01?l0003oooooooooool00009oooo
o`03o`000?oooooooooo0?ooooooXoooool0033ooooo00?o0000ooooooooool07_ooool00ol0003o
ooooo`000008ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oooooonSoooo
o`00<?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo000000Sooooo00Co0000oooooooo
oooo00002Oooool00ol0003oooooooooo`3ooooooj?ooooo000`ooooo`?o00007_ooool00ol0003o
ooooo`000008ooooo`04o`000?ooooooooooo`000?oooooo[oooool0033ooooo00?o0000oooooooo
ool07_ooool00ol0003oooooo`000008ooooo`04o`000?ooooooooooo`000?oooooo[oooool0033o
oooo00?o0000ooooooooool07_ooool00ol0003oooooo`000008ooooo`04o`000?ooooooooooo`00
0?oooooo[oooool0033ooooo00?o0000ooooooooool07_ooool00ol0003oooooo`000008ooooo`04
o`000?ooooooooooo`000?oooooo[oooool0033ooooo00?o0000ooooooooool07_ooool00ol0003o
ooooo`000008ooooo`04o`000?ooooooooooo`000?oooooo[oooool0033ooooo00?o0000oooooooo
ool07_ooool00ol0003oooooo`000008ooooo`04o`000?ooooooooooo`000?oooooo[oooool000oo
oooo0_o^k^h3ooooo`;ok^k^6_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo000000So
oooo00Co0000oooooooooooo0000oooooon_ooooo`002_ooool2o`00000:oa0@4?ooooooooooonk^
k_mEEEGok^k^ooooooo^k^koEEEEonk^kP?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`00
0?lb<S;ok^k^2oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo000000Sooooo00Co0000
oooooooooooo0000oooooon_ooooo`002oooool00ol0003oooooooooo`02ooooo`05onk^k_mEEEGo
gMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo000000Sooooo00Co0000oooooooooooo
0000oooooon_ooooo`002?ooool5o`0000Cooooo00?ogMgMo`000?oMgMd01oooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41002oooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooo000000Sooooo00Co0000oooooooooooo0000oooooon_ooooo`002?ooool01?m4A4Co
gMgMooooool00004ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooo000000Sooooo00Co0000oooooooooooo0000oooooon_ooooo`002?ooool01?oMgMgoEEEEoooo
ool00003ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`00000;ooooo`Co00007Oooool00ol0003oooooo`000008
ooooo`04o`000?ooooooooooo`000?oooooo[oooool000Wooooo00?oMgMgolc<c?l000000oooool2
onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03o`000?oooooooooo01kooooo00?o0000ooooool000002?ooool01?l0003ooooooooo
ool0003oooooojoooooo0009ooooo`03onk^k_m4A4Co000000oooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?o0000ooooooooool07_ooool00ol0003ooooo
o`000008ooooo`04o`000?ooooooooooo`000?oooooo[oooool000[ooooo00?oMgMgo`000?ooool0
3?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool2o`0000Ko
oooo00?o0000ooooooooool07_ooool00ol0003oooooo`000008ooooo`04o`000?ooooooooooo`00
0?oooooo[oooool002Oooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooo000000Sooooo00Co0000oooooooooooo0000oooooon_ooooo`009oooool01?l0
003oooooooooool00005ooooo`03o`000?oooooooooo01kooooo0_l00009ooooo`04o`000?oooooo
ooooo`000?oooooo[oooool002Oooooo0ol00006ooooo`03o`000?oooooooooo01kooooo0_l00009
ooooo`04o`000?ooooooooooo`000?oooooo[oooool002Sooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo0000oooo
oon_ooooo`00:Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool01oooool01?l0003oooooooooool0003oooooojoooooo000`ooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool01oooool01?l0003oooooooooool0003oooooojoooooo000`
ooooo`03o`000?oooooooooo02Wooooo00Co0000oooooooooooo0000oooooon_ooooo`00<?ooool0
0ol0003oooooooooo`0Zooooo`03o`000?oooooo00000?oooooo[oooool0033ooooo0ol0000Zoooo
o`03o`000?oooooo00000?oooooo[oooool0033ooooo00?o0000ooooooooool0:_ooool00ol0003o
ooooo`00003oooooojoooooo000`ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooool00000
oooooon_ooooo`00<?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooo00000?oooooo[ooo
ool0033ooooo00?o0000ooooooooool0:_ooool00ol0003oooooo`00003oooooojoooooo000`oooo
o`03o`000?oooooooooo02[ooooo00?o0000ooooool00000oooooon_ooooo`00<?ooool00ol0003o
ooooooooo`0Zooooo`03o`000?oooooo00000?oooooo[oooool0033ooooo00?o0000ooooooooool0
:_ooool00ol0003oooooo`00003oooooojoooooo000`ooooo`03o`000?oooooooooo02[ooooo00?o
0000ooooool00000oooooon_ooooo`00<?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooo
00000?oooooo[oooool0033ooooo00?o0000ooooooooool0:_ooool00ol0003oooooo`00003ooooo
ojoooooo000`ooooo`03o`000?oooooooooo02[ooooo0_l0003ooooook3ooooo000`ooooo`?o0000
:_ooool2o`000?oooooo/?ooool0033ooooo00?o0000ooooooooool0:_ooool2o`000?oooooo/?oo
ool0033ooooo00?o0000ooooooooool0:_ooool2o`000?oooooo/?ooool0033ooooo00?o0000oooo
ooooool0:_ooool2o`000?oooooo/?ooool0033ooooo00?o0000ooooooooool0:_ooool2o`000?oo
oooo/?ooool0033ooooo00?o0000ooooooooool0:_ooool2o`000?oooooo/?ooool0033ooooo00?o
0000ooooooooool0:_ooool2o`000?oooooo/?ooool0033ooooo00?o0000ooooooooool0:_ooool2
o`000?oooooo/?ooool0033ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`3ooooo
ojkooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0
oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`?o0000oooooooL
ooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oo
oooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooooooo
o`3oooooomcooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3o
oooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooo
oooooooo4?ooool00?ooooooooooool@ooooo`00Y?ooool2o`0000?ooooo00?o^[Zjoc8b<_ooool0
1Oooool2o`0000Gooooo00?o0000okZj^_ooool0oooooomDooooo`00Y?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool2oc8b<_ooooooEOoo
ool0097ooooo0ol00002ooooo`06oc8b<_l@413oooooooooooo^k^koEEEE0_l000000om4A4Co^[Zj
ooooo`03ooooo`06o`000?oooooooooooooooonHV9So410@0_l000000onYZJWoooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co
^[Zj00Wooooo1Ol00005ooooo`;o8B4Q0oooool01Oo<c<cok^k^ooooooo^k^koc<c<00Cooooo1?l0
00002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^4oooool01_l@413o<S8bo`000?l0003o
410@ojVYZ@;ooooo00Kok^k^oeEEEOl0003o0000odA4A?nj^[X3ooooo`05ofIVI_l0003o0000odA4
A?o<c<`0k?ooool009;ooooo00Go0000ooooooooooooc<c<oa0@4003ooooo`06oeEEEOmgMgOooooo
onk^k_mgMgOo410@1?ooool02_l0003ooooooooooooooooo0000ojVYZOmEEEGoV9RHoeEEEOnj^[X4
ooooo`03o`000?oooooooooo00?ooooo00?oc<c<o`000?l@41003?ooool01Ol@413o^[Zjonk^k_mg
MgOo410@00;ooooo1_l000001_ooooooV9RHob4Q8Oo^k^koooooodA4A0Gooooo0_lQ8B43ooooo`05
onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL04oooool01_l0003oZJVYoooooooooooo^[Zjo`0000;ooooo00KoEEEEogMgMooooooo
k^k^ogMgMol@4102ooooo`06ofIVI_mgMgOooooooooooon7QhOo410@k?ooool009;ooooo00Go0000
ooooooooooooEEEEohN7Q`03ooooo`03o`000?oooooooooo00Oooooo00[o0000oooooooooooooooo
oc8b<_o^k^koV9RHoeEEEOoMgMgo410@1?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo00cooooo00?oV9RHob4Q8Oo^k^h03?ooool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooo
oooo00;ooooo00Go410@oooooooooooooooooa0@400Dooooo`05okZj^_n7QhOoIVIVofIVI_l@4100
0_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0>oooooo002Booooo`05o`000?oo
oooogMgMo`000?o^k^h00oooool6o`0000Cooooo00_o0000oooooooooooooooookZj^_m4A4Coc<c<
ob4Q8Ooooooo410@olc<c003ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01?oo
ool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h02_ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000001?ooooo00Ko<S8bob4Q8Omg
MgOoMgMgohN7Qoo^k^h2ooooo`Ko00000_ooool00ol0003oooooooooo`3_ooooo`00T_ooool3o`00
0003oa0@4?nHV9Sooooo00;ooooo00KoEEEEohN7Qoo^k^koooooohN7Qolb<S84ooooo`0;o`000?oo
ooooooooooooooo^k^ko0000ooooool0003oooooofIVI_n7QhL00oooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo00kooooo00?oMgMgofIVI_ooool02Oooool01Oo<c<cok^k^ooooooo^
k^koc<c<00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000001?ooooo
00Ko0000okZj^_ooooook^k^ogMgMol00002ooooo`06oeEEEOn7QhOok^k^oooooon7QhOo<S8b0_oo
ool01_mVIVKoMgMgooooooooooooQhN7o`000>cooooo002Booooo`05o`000?ooooooooooolc<c?l0
00000oooool01_o^k^koEEEEo`000?l0003oA4A4onk^kPCooooo00So0000ooooooooooooooooofIV
I_nHV9Sooooooc8b<P;o^[Zj00Go0000ooooooooooooooooo`00000Booooo`03oa0@4?l0003o0000
00?o00003_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00;ooooo00Go410@oooo
oooooooooooooa0@4007ooooo`?o00000_ooool3o`0000Cooooo00KoZJVYob4Q8Ol0003o0000oc8b
<_l00002ooooo`06onk^k_mEEEGo0000o`000?m4A4Cok^k^0_ooool01_o^k^koIVIVo`000?l0003o
A4A4o`000>cooooo002Booooo`05o`000?ooooooooooolc<c?l000003Oooool00ol0003ooooooooo
o`04ooooo`03ofIVI_n7QhOooooo00Cooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41005Oooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oo
oooo1_ooool0097ooooo1?l000000ol@413oZJVYooooo`0<ooooo`;o00001Oooool00onYZJWoA4A4
ooooo`03ooooo`;o00005?ooool00ol0003oooooooooo`0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`04oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_ooool4o`00
00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3oooooo`Kooooo003oooooo`;o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3oooooo`Kooooo003oooooo`;ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`3oooooo`Kooooo003oooooo`7ooooo0_l0
0003ooooo`;o0000ooooool8ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oo
ooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@
ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooo
oooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3o
oooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooo
oooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?oo
ool00001\
\>"],
  ImageRangeCache->{{{0, 525.688}, {324.5, 0}} -> {0, -6.34248*^6, 0, 53093}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0.309017 5.42214e-08 [
[.32684 .29652 -16.5 -12.5 ]
[.32684 .29652 16.5 0 ]
[.54329 .29652 -16.5 -12.5 ]
[.54329 .29652 16.5 0 ]
[.75974 .29652 -22.5 -12.5 ]
[.75974 .29652 22.5 0 ]
[.97619 .29652 -16.5 -12.5 ]
[.97619 .29652 16.5 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 64 6 ]
[.09789 .09213 -34.5 -6.25 ]
[.09789 .09213 0 6.25 ]
[.09789 .20057 -34.5 -6.25 ]
[.09789 .20057 0 6.25 ]
[.09789 .41746 -28.5 -6.25 ]
[.09789 .41746 0 6.25 ]
[.09789 .5259 -28.5 -6.25 ]
[.09789 .5259 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -62.8125 0 ]
[.5 .63053 62.8125 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 .30902 m
.32684 .31527 L
s
gsave
.32684 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 .30902 m
.54329 .31527 L
s
gsave
.54329 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 .30902 m
.75974 .31527 L
s
gsave
.75974 .29652 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 .30902 m
.15368 .31277 L
s
.19697 .30902 m
.19697 .31277 L
s
.24026 .30902 m
.24026 .31277 L
s
.28355 .30902 m
.28355 .31277 L
s
.37013 .30902 m
.37013 .31277 L
s
.41342 .30902 m
.41342 .31277 L
s
.45671 .30902 m
.45671 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.58658 .30902 m
.58658 .31277 L
s
.62987 .30902 m
.62987 .31277 L
s
.67316 .30902 m
.67316 .31277 L
s
.71645 .30902 m
.71645 .31277 L
s
.80303 .30902 m
.80303 .31277 L
s
.84632 .30902 m
.84632 .31277 L
s
.88961 .30902 m
.88961 .31277 L
s
.9329 .30902 m
.9329 .31277 L
s
.0671 .30902 m
.0671 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09213 m
.11664 .09213 L
s
gsave
.09789 .09213 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .20057 m
.11664 .20057 L
s
gsave
.09789 .20057 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .41746 m
.11664 .41746 L
s
gsave
.09789 .41746 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .5259 m
.11664 .5259 L
s
gsave
.09789 .5259 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.11039 .11924 m
.11414 .11924 L
s
.11039 .14635 m
.11414 .14635 L
s
.11039 .17346 m
.11414 .17346 L
s
.11039 .22768 m
.11414 .22768 L
s
.11039 .2548 m
.11414 .2548 L
s
.11039 .28191 m
.11414 .28191 L
s
.11039 .33613 m
.11414 .33613 L
s
.11039 .36324 m
.11414 .36324 L
s
.11039 .39035 m
.11414 .39035 L
s
.11039 .44457 m
.11414 .44457 L
s
.11039 .47168 m
.11414 .47168 L
s
.11039 .49879 m
.11414 .49879 L
s
.11039 .06502 m
.11414 .06502 L
s
.11039 .03791 m
.11414 .03791 L
s
.11039 .0108 m
.11414 .0108 L
s
.11039 .55301 m
.11414 .55301 L
s
.11039 .58012 m
.11414 .58012 L
s
.11039 .60723 m
.11414 .60723 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -123.812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.812 moveto
(@) show
81.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.812 moveto
(D) show
93.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.2) show
135.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
141.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
153.000 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
157.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
166.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
184.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.0239 .30902 L
.02399 .30902 L
.02409 .30902 L
.02418 .30902 L
.02427 .30902 L
.02435 .30902 L
.02444 .30902 L
.02453 .30902 L
.02462 .30902 L
.02472 .30902 L
.02482 .30902 L
.02491 .30902 L
.02512 .30902 L
.02532 .30902 L
.02571 .30902 L
.02608 .30902 L
.02648 .30902 L
.02691 .30902 L
.02735 .30902 L
.02782 .30902 L
.02868 .30902 L
.02952 .30902 L
.03029 .30902 L
.0318 .30902 L
.03266 .30902 L
.03346 .30902 L
.03659 .30902 L
.03991 .30902 L
.04157 .30902 L
.0423 .30902 L
.0431 .30902 L
.04347 .30902 L
.04387 .30902 L
.04406 .30902 L
.04425 .30902 L
.04441 .30902 L
.0445 .30902 L
.0446 .30902 L
.04465 .30902 L
.0447 .30902 L
.0448 .30902 L
.0449 .30902 L
.04499 .30902 L
.0451 .30902 L
.04519 .30902 L
.04525 .30902 L
.0453 .30902 L
.04542 .30902 L
.0456 .30902 L
Mistroke
.04581 .30902 L
.046 .30902 L
.04618 .30902 L
.04659 .30902 L
.04703 .30902 L
.04745 .30902 L
.04783 .30902 L
.04856 .30902 L
.04933 .30902 L
.05009 .30902 L
.0509 .30902 L
.05238 .30902 L
.05409 .30902 L
.0557 .30902 L
.05878 .30902 L
.06034 .30902 L
.06117 .30902 L
.06206 .30902 L
.06247 .30902 L
.06291 .30902 L
.06328 .30902 L
.0635 .30902 L
.06369 .30902 L
.06378 .30902 L
.06389 .30902 L
.06397 .30902 L
.06407 .30902 L
.06418 .30902 L
.06423 .30902 L
.06428 .30902 L
.06438 .30902 L
.06448 .30902 L
.06458 .30902 L
.06468 .30902 L
.06478 .30902 L
.06487 .30902 L
.06504 .30902 L
.06522 .30902 L
.06561 .30902 L
.06597 .30902 L
.06636 .30902 L
.06678 .30902 L
.06748 .30902 L
.06824 .30902 L
.06907 .30902 L
.06982 .30902 L
.0715 .30901 L
.07303 .309 L
.0747 .30899 L
.07799 .30897 L
Mistroke
.07962 .30896 L
.08042 .30895 L
.08115 .30895 L
.0815 .30895 L
.08169 .30895 L
.0819 .30895 L
.08209 .30895 L
.08227 .30895 L
.08235 .30895 L
.08244 .30895 L
.08253 .30894 L
.08261 .30894 L
.0827 .30894 L
.0828 .30894 L
.08289 .30894 L
.08297 .30894 L
.08307 .30894 L
.08313 .30895 L
.08318 .30895 L
.08338 .30895 L
.08356 .30895 L
.08377 .30895 L
.08418 .30895 L
.08458 .30895 L
.08499 .30895 L
.08574 .30896 L
.08654 .30897 L
.08741 .30899 L
.08899 .30904 L
.09067 .3091 L
.094 .30928 L
.09567 .30937 L
.09721 .30946 L
.09799 .30949 L
.09871 .30952 L
.09908 .30953 L
.09947 .30954 L
.09969 .30954 L
.0998 .30954 L
.09991 .30955 L
.10001 .30955 L
.1001 .30955 L
.1002 .30955 L
.10025 .30955 L
.1003 .30955 L
.1004 .30955 L
.1005 .30955 L
.10059 .30955 L
.10068 .30955 L
.10078 .30955 L
Mistroke
.10089 .30954 L
.10109 .30954 L
.1013 .30954 L
.10152 .30953 L
.10192 .30952 L
.10228 .3095 L
.10262 .30948 L
.1034 .30942 L
.10424 .30933 L
.10503 .30923 L
.10651 .30896 L
.1081 .30857 L
.10958 .30814 L
.11272 .30712 L
.11432 .30666 L
.11522 .30645 L
.11565 .30637 L
.11606 .30632 L
.11641 .30628 L
.11662 .30626 L
.1168 .30625 L
.1169 .30624 L
.117 .30624 L
.11711 .30624 L
.11716 .30624 L
.11722 .30624 L
.11732 .30624 L
.11737 .30624 L
.11743 .30624 L
.11752 .30624 L
.11762 .30624 L
.11772 .30625 L
.11782 .30626 L
.11803 .30627 L
.11822 .3063 L
.11841 .30632 L
.11882 .3064 L
.11927 .30651 L
.12003 .30677 L
.12086 .30717 L
.12174 .30772 L
.12255 .30836 L
.12567 .31176 L
.12898 .31624 L
.12978 .31724 L
.13064 .31819 L
.13137 .31887 L
.13176 .31916 L
.13217 .31942 L
.13238 .31952 L
Mistroke
.1326 .31962 L
.13281 .31969 L
.133 .31974 L
.1331 .31976 L
.1332 .31977 L
.13328 .31978 L
.13338 .31979 L
.13348 .31979 L
.13353 .31979 L
.13359 .31979 L
.13369 .31978 L
.13378 .31977 L
.13387 .31976 L
.13396 .31974 L
.13415 .31968 L
.13432 .31962 L
.13448 .31954 L
.13485 .31932 L
.13524 .319 L
.13567 .31855 L
.13606 .31804 L
.13696 .31654 L
.13774 .31481 L
.13857 .31258 L
.14162 .30138 L
.14331 .29394 L
.14486 .28731 L
.14563 .28435 L
.14646 .28154 L
.14725 .27942 L
.14763 .27861 L
.14798 .27801 L
.14835 .27753 L
.14855 .27734 L
.14864 .27727 L
.14875 .27721 L
.14884 .27716 L
.14893 .27713 L
.14902 .27711 L
.1491 .2771 L
.14919 .2771 L
.14928 .27711 L
.14937 .27714 L
.14948 .27718 L
.14958 .27724 L
.14967 .2773 L
.14988 .2775 L
.15008 .27774 L
.15026 .27803 L
.15068 .27887 L
Mistroke
.15113 .2801 L
.15196 .28325 L
.15271 .28711 L
.15439 .29907 L
.15594 .31355 L
.15761 .33166 L
.15918 .34921 L
.1609 .36651 L
.16169 .37296 L
.16213 .37596 L
.16254 .37838 L
.16292 .38023 L
.16312 .38104 L
.16334 .38176 L
.16352 .38227 L
.16372 .38271 L
.16381 .38286 L
.1639 .383 L
.16399 .3831 L
.16407 .38318 L
.16417 .38324 L
.16426 .38326 L
.16436 .38325 L
.16442 .38324 L
.16447 .38321 L
.16455 .38315 L
.16465 .38305 L
.16475 .38291 L
.16484 .38275 L
.16505 .38227 L
.16524 .38169 L
.16568 .37988 L
.16609 .3775 L
.16655 .37415 L
.16737 .36609 L
.1682 .35544 L
.16896 .34375 L
.17064 .31157 L
.17386 .2388 L
.17534 .20821 L
.17618 .19377 L
.17696 .18297 L
.17736 .17861 L
.17773 .17528 L
.17794 .17379 L
.17817 .17246 L
.17837 .17152 L
.17856 .17088 L
.17866 .17064 L
.17877 .17045 L
Mistroke
.17886 .17034 L
.17895 .17029 L
.17906 .1703 L
.17912 .17034 L
.17917 .1704 L
.17928 .17056 L
.17933 .17068 L
.17938 .1708 L
.1796 .17153 L
.17972 .17207 L
.17983 .17267 L
.18026 .17569 L
.18063 .17943 L
.18104 .18453 L
.18177 .19659 L
.18263 .21551 L
.18342 .23677 L
.18662 .3499 L
.18808 .40619 L
.18969 .46167 L
.19046 .48315 L
.19128 .50163 L
.19173 .50941 L
.19215 .51491 L
.19236 .51703 L
.19255 .51863 L
.19275 .5199 L
.19285 .52041 L
.19297 .52083 L
.19306 .52109 L
.19312 .52119 L
.19317 .52126 L
.19328 .52131 L
.19334 .52128 L
.19339 .52122 L
.19349 .52105 L
.19359 .52074 L
.19369 .52034 L
.19379 .51988 L
.19401 .51835 L
.19422 .5165 L
.19468 .5107 L
.19508 .50381 L
.19551 .49447 L
.19629 .47267 L
.1979 .41073 L
.19959 .32654 L
.20264 .16352 L
.20421 .0956 L
.20466 .08012 L
Mistroke
.20508 .0675 L
.20547 .05803 L
.20589 .04967 L
.20608 .04658 L
.20629 .0438 L
.20647 .04186 L
.20666 .04025 L
.20677 .03958 L
.20687 .0391 L
.20693 .0389 L
.20698 .03875 L
.20704 .03862 L
.20709 .03855 L
.20719 .03852 L
.20728 .03862 L
.20738 .03886 L
.20748 .03926 L
.20758 .03974 L
.20766 .04028 L
.20785 .04186 L
.20802 .04376 L
.20819 .04597 L
.20856 .05229 L
.20896 .06133 L
.2098 .08675 L
.21055 .11708 L
.21223 .20573 L
.21546 .41128 L
.21694 .49615 L
.21777 .53557 L
.21856 .5648 L
.21895 .57655 L
.21933 .58558 L
.21954 .58966 L
.21977 .59336 L
.21997 .59601 L
.22016 .59792 L
.22026 .59867 L
.22036 .59932 L
.22042 .5996 L
.22048 .59983 L
.22053 .59998 L
.22059 .6001 L
.22065 .60018 L
.2207 .6002 L
.22076 .60017 L
.22082 .60008 L
.22093 .59978 L
.22099 .59954 L
.22104 .59927 L
Mistroke
.22123 .59797 L
.22134 .59699 L
.22144 .5959 L
.22165 .59302 L
.22185 .5897 L
.22226 .58121 L
.22269 .56926 L
.22349 .54072 L
.22498 .46693 L
.22813 .26461 L
.22971 .16779 L
.23116 .0977 L
.23191 .07116 L
.23229 .0608 L
.23271 .05189 L
.23293 .04829 L
.23313 .04553 L
.23324 .04428 L
.23336 .04314 L
.23347 .04237 L
.23358 .0417 L
.23368 .04124 L
.23378 .04097 L
.23389 .04085 L
.23394 .04086 L
.234 .0409 L
.23409 .0411 L
.2342 .04147 L
.23429 .04197 L
.23438 .04256 L
.2346 .04444 L
.23479 .04677 L
.23523 .05407 L
.23562 .06281 L
.23603 .07425 L
.23753 .13284 L
.24058 .30194 L
.24228 .39651 L
.24383 .4656 L
.2446 .49089 L
.24501 .50139 L
.24544 .51029 L
.24581 .51612 L
.24603 .51862 L
.24623 .52042 L
.24632 .52106 L
.24641 .52161 L
.24649 .522 L
.24658 .52232 L
.24667 .52255 L
Mistroke
.24676 .52267 L
.24686 .52267 L
.24696 .52256 L
.24705 .52233 L
.24714 .52201 L
.24724 .52154 L
.24735 .5209 L
.24756 .51915 L
.24776 .51706 L
.24814 .51172 L
.2485 .50512 L
.2493 .48551 L
.25017 .45739 L
.25344 .31747 L
.25506 .24938 L
.25586 .22109 L
.25659 .19926 L
.2573 .18239 L
.25766 .17556 L
.25804 .16964 L
.25825 .16709 L
.25843 .16513 L
.25862 .16347 L
.25879 .16225 L
.259 .1612 L
.2591 .1608 L
.25916 .16064 L
.25922 .1605 L
.25931 .16034 L
.25941 .16027 L
.25946 .16027 L
.25952 .16029 L
.25962 .16041 L
.25972 .16063 L
.25977 .16079 L
.25982 .16096 L
.26002 .16184 L
.2602 .16294 L
.26039 .16441 L
.26078 .16844 L
.26121 .17429 L
.26197 .18809 L
.26268 .2043 L
.26581 .29541 L
.2674 .34051 L
.26824 .36051 L
.26913 .37777 L
.26992 .38916 L
.27037 .39389 L
.27057 .39562 L
Mistroke
.27079 .39714 L
.27097 .3982 L
.27118 .39911 L
.27127 .39943 L
.27136 .39972 L
.27145 .39993 L
.27153 .40009 L
.27163 .40022 L
.27169 .40027 L
.27175 .40029 L
.27184 .40029 L
.2719 .40027 L
.27195 .40023 L
.27204 .40011 L
.27213 .39996 L
.27223 .39972 L
.27233 .39944 L
.27254 .39865 L
.27273 .39768 L
.2731 .3953 L
.27349 .39196 L
.27392 .38753 L
.2754 .36672 L
.2787 .30771 L
.27949 .29477 L
.28034 .28269 L
.28107 .27407 L
.28187 .26685 L
.2823 .26396 L
.28269 .2619 L
.28307 .26049 L
.28326 .25998 L
.28337 .25975 L
.28347 .25958 L
.28356 .25945 L
.28366 .25935 L
.28375 .25929 L
.28383 .25926 L
.28393 .25925 L
.28402 .25927 L
.28412 .25934 L
.28422 .25943 L
.28431 .25954 L
.2844 .25968 L
.28456 .26 L
.28473 .26044 L
.28492 .26103 L
.28534 .26272 L
.28574 .26478 L
.28649 .26968 L
Mistroke
.28817 .28428 L
.29124 .31358 L
.29206 .31994 L
.29283 .3249 L
.29363 .32889 L
.29406 .33049 L
.29428 .33118 L
.29451 .33181 L
.29472 .33227 L
.29491 .33261 L
.2951 .33289 L
.29528 .33308 L
.29538 .33316 L
.29544 .3332 L
.29549 .33323 L
.29558 .33327 L
.29569 .33329 L
.29574 .3333 L
.2958 .3333 L
.2959 .33328 L
.29595 .33327 L
.296 .33325 L
.29612 .33318 L
.29623 .33311 L
.29634 .333 L
.29655 .33276 L
.29694 .33211 L
.2974 .33107 L
.29782 .32987 L
.29933 .32405 L
.30099 .31625 L
.30269 .30854 L
.30424 .30299 L
.305 .30099 L
.30541 .30016 L
.30584 .29945 L
.30622 .29898 L
.30643 .29877 L
.30663 .29861 L
.30681 .2985 L
.30698 .29843 L
.30707 .2984 L
.30717 .29837 L
.30727 .29836 L
.30736 .29835 L
.30746 .29835 L
.30752 .29835 L
.30757 .29836 L
.30767 .29838 L
.30777 .2984 L
Mistroke
.30788 .29844 L
.30798 .29848 L
.30821 .29861 L
.3084 .29874 L
.30862 .29892 L
.30901 .29933 L
.30978 .30039 L
.3105 .30162 L
.31365 .30799 L
.31441 .30939 L
.31522 .31068 L
.31597 .31165 L
.31667 .31235 L
.31703 .31263 L
.31741 .31288 L
.31763 .31299 L
.31784 .31308 L
.31802 .31314 L
.31822 .31319 L
.31832 .31321 L
.31842 .31323 L
.31848 .31324 L
.31854 .31325 L
.31864 .31326 L
.31873 .31326 L
.31884 .31326 L
.31893 .31326 L
.31902 .31326 L
.31908 .31325 L
.31914 .31325 L
.31925 .31324 L
.31945 .3132 L
.31968 .31315 L
.3199 .31308 L
.32027 .31293 L
.32068 .31274 L
.32141 .31229 L
.32306 .31102 L
.32466 .30972 L
.32549 .3091 L
.32639 .30853 L
.32717 .30812 L
.32759 .30794 L
.32805 .30778 L
.32846 .30767 L
.32884 .30759 L
.3292 .30753 L
.32938 .30751 L
.32958 .30749 L
.32969 .30749 L
Mistroke
.32979 .30748 L
.32984 .30748 L
.32989 .30748 L
.32995 .30748 L
.33001 .30748 L
.33011 .30748 L
.3302 .30748 L
.33025 .30748 L
.33031 .30748 L
.33041 .30749 L
.33051 .30749 L
.3306 .3075 L
.3308 .30751 L
.33116 .30755 L
.33157 .30761 L
.33202 .3077 L
.33284 .30789 L
.33441 .30835 L
.33614 .30884 L
.33693 .30904 L
.33778 .30922 L
.33858 .30936 L
.33931 .30944 L
.3397 .30948 L
.33991 .30949 L
.34011 .3095 L
.34029 .30951 L
.34046 .30952 L
.34064 .30952 L
.34074 .30952 L
.34084 .30953 L
.34095 .30953 L
.34104 .30953 L
.3411 .30953 L
.34115 .30953 L
.34126 .30953 L
.34135 .30953 L
.34146 .30952 L
.34155 .30952 L
.34164 .30952 L
.34186 .30952 L
.34209 .30951 L
.34251 .30949 L
.34333 .30943 L
.34422 .30935 L
.34583 .3092 L
.34738 .30905 L
.34821 .30899 L
.3491 .30893 L
.34951 .30891 L
Mistroke
.34995 .3089 L
.35035 .30888 L
.35072 .30887 L
.35108 .30887 L
.35127 .30887 L
.35145 .30886 L
.35156 .30886 L
.35165 .30886 L
.35175 .30886 L
.35181 .30886 L
.35186 .30886 L
.35196 .30886 L
.35206 .30886 L
.35216 .30886 L
.35225 .30886 L
.35235 .30886 L
.35245 .30886 L
.35263 .30886 L
.35283 .30887 L
.35304 .30887 L
.35378 .30888 L
.35464 .3089 L
.35544 .30893 L
.35708 .30898 L
.35861 .30902 L
.35937 .30903 L
.36008 .30904 L
.36048 .30905 L
.36091 .30905 L
.3613 .30906 L
.36166 .30906 L
.36185 .30906 L
.36203 .30906 L
.36223 .30906 L
.36233 .30906 L
.36238 .30906 L
.36243 .30906 L
.36253 .30906 L
.36262 .30906 L
.36271 .30906 L
.36281 .30906 L
.3629 .30906 L
.36299 .30906 L
.36307 .30906 L
.36316 .30906 L
.36338 .30906 L
.36357 .30906 L
.36401 .30906 L
.36481 .30905 L
.36647 .30904 L
Mistroke
.36801 .30903 L
.3695 .30902 L
.37033 .30901 L
.37108 .30901 L
.37147 .30901 L
.37189 .30901 L
.37224 .30901 L
.37244 .30901 L
.37263 .30901 L
.37273 .30901 L
.37285 .30901 L
.3729 .30901 L
.37295 .30901 L
.37305 .30901 L
.37315 .30901 L
.37323 .30901 L
.37333 .30901 L
.37344 .30901 L
.37349 .30901 L
.37355 .30901 L
.37367 .30901 L
.37389 .30901 L
.37409 .30901 L
.3743 .30901 L
.37513 .30901 L
.37602 .30901 L
.37764 .30901 L
.37921 .30902 L
.3801 .30902 L
.38052 .30902 L
.38093 .30902 L
.38131 .30902 L
.38173 .30902 L
.38211 .30902 L
.38246 .30902 L
.38265 .30902 L
.38284 .30902 L
.38304 .30902 L
.38315 .30902 L
.38325 .30902 L
.38335 .30902 L
.38345 .30902 L
.38355 .30902 L
.38361 .30902 L
.38366 .30902 L
.38372 .30902 L
.38377 .30902 L
.38389 .30902 L
.38399 .30902 L
.3841 .30902 L
Mistroke
.3843 .30902 L
.38449 .30902 L
.38485 .30902 L
.38567 .30902 L
.38714 .30902 L
.38875 .30902 L
.39021 .30902 L
.39102 .30902 L
.39179 .30902 L
.39221 .30902 L
.3926 .30902 L
.3928 .30902 L
.39302 .30902 L
.39314 .30902 L
.39326 .30902 L
.39337 .30902 L
.39347 .30902 L
.39357 .30902 L
.39366 .30902 L
.39375 .30902 L
.39386 .30902 L
.39396 .30902 L
.39402 .30902 L
.39407 .30902 L
.39427 .30902 L
.39446 .30902 L
.39465 .30902 L
.39501 .30902 L
.39588 .30902 L
.39667 .30902 L
.39835 .30902 L
.39908 .30902 L
.39989 .30902 L
.40061 .30902 L
.40139 .30902 L
.40182 .30902 L
.40221 .30902 L
.4024 .30902 L
.4026 .30902 L
.40298 .30902 L
.40316 .30902 L
.40326 .30902 L
.40337 .30902 L
.40346 .30902 L
.40356 .30902 L
.40365 .30902 L
.40373 .30902 L
.40378 .30902 L
.40384 .30902 L
.40394 .30902 L
Mistroke
.40404 .30902 L
.40413 .30902 L
.40423 .30902 L
.40434 .30902 L
.40456 .30902 L
.40478 .30902 L
.40498 .30902 L
.40543 .30902 L
.40625 .30902 L
.4079 .30902 L
.40944 .30902 L
.4102 .30902 L
.41092 .30902 L
.41132 .30902 L
.41175 .30902 L
.41214 .30902 L
.4125 .30902 L
.4127 .30902 L
.41288 .30902 L
.41309 .30902 L
.41319 .30902 L
.41328 .30902 L
.41337 .30902 L
.41347 .30902 L
.41355 .30902 L
.41363 .30902 L
.41373 .30902 L
.41382 .30902 L
.41391 .30902 L
.41401 .30902 L
.41412 .30902 L
.41421 .30902 L
.41443 .30902 L
.41462 .30902 L
.41481 .30902 L
.41567 .30902 L
.41876 .30902 L
.41959 .30902 L
.42036 .30902 L
.42116 .30902 L
.42159 .30902 L
.42205 .30902 L
.42225 .30902 L
.42247 .30902 L
.42266 .30902 L
.42286 .30902 L
.42299 .30902 L
.4231 .30902 L
.42321 .30902 L
.42327 .30902 L
Mistroke
.42333 .30902 L
.42343 .30902 L
.42349 .30902 L
.42354 .30902 L
.42365 .30902 L
.42375 .30902 L
.42384 .30902 L
.42394 .30902 L
.42415 .30902 L
.42434 .30902 L
.42452 .30902 L
.42536 .30902 L
.42847 .30902 L
.42928 .30902 L
.43017 .30902 L
.43057 .30902 L
.431 .30902 L
.43138 .30902 L
.43178 .30902 L
.43198 .30902 L
.43221 .30902 L
.43241 .30902 L
.4326 .30902 L
.43272 .30902 L
.43283 .30902 L
.43293 .30902 L
.43298 .30902 L
.43303 .30902 L
.43309 .30902 L
.43314 .30902 L
.4332 .30902 L
.43326 .30902 L
.43332 .30902 L
.43338 .30902 L
.43344 .30902 L
.4335 .30902 L
.43361 .30902 L
.43371 .30902 L
.4339 .30902 L
.43411 .30902 L
.43433 .30902 L
.43511 .30902 L
.43668 .30902 L
.43751 .30902 L
.4384 .30902 L
.43925 .30902 L
.44003 .30902 L
.44041 .30902 L
.44081 .30902 L
.4412 .30902 L
Mistroke
.44156 .30902 L
.44177 .30902 L
.44197 .30902 L
.44218 .30902 L
.44229 .30902 L
.44241 .30902 L
.44251 .30902 L
.44261 .30902 L
.44266 .30902 L
.44272 .30902 L
.44282 .30902 L
.44292 .30902 L
.44302 .30902 L
.44311 .30902 L
.44321 .30902 L
.4434 .30902 L
.44358 .30902 L
.44398 .30902 L
.4447 .30902 L
.44635 .30902 L
.44716 .30902 L
.44788 .30902 L
.4486 .30902 L
.44937 .30902 L
.44979 .30902 L
.45018 .30902 L
.45055 .30902 L
.45095 .30902 L
.45115 .30902 L
.45134 .30902 L
.45152 .30902 L
.4517 .30902 L
.45181 .30902 L
.45191 .30902 L
.45196 .30902 L
.45202 .30902 L
.45213 .30902 L
.45223 .30902 L
.45233 .30902 L
.45242 .30902 L
.45252 .30902 L
.45262 .30902 L
.45271 .30902 L
.45289 .30902 L
.45328 .30902 L
.45399 .30902 L
.45546 .30902 L
.45629 .30902 L
.45707 .30902 L
.4579 .30902 L
Mistroke
.45867 .30902 L
.45905 .30902 L
.45948 .30902 L
.45993 .30902 L
.46035 .30902 L
.46056 .30902 L
.46078 .30902 L
.46088 .30902 L
.46099 .30902 L
.46108 .30902 L
.46118 .30902 L
.46128 .30902 L
.46137 .30902 L
.46146 .30902 L
.46154 .30902 L
.46164 .30902 L
.46173 .30902 L
.46183 .30902 L
.46193 .30902 L
.46213 .30902 L
.46234 .30902 L
.46273 .30902 L
.46362 .30902 L
.46519 .30902 L
.46603 .30902 L
.46692 .30902 L
.46736 .30902 L
.46778 .30902 L
.46819 .30902 L
.46856 .30902 L
.46892 .30902 L
.4693 .30902 L
.46969 .30902 L
.4699 .30902 L
.4701 .30902 L
.4702 .30902 L
.47031 .30902 L
.47041 .30902 L
.4705 .30902 L
.47055 .30902 L
.47061 .30902 L
.47066 .30902 L
.47072 .30902 L
.47082 .30902 L
.47088 .30902 L
.47093 .30902 L
.47104 .30902 L
.47113 .30902 L
.47132 .30902 L
.47151 .30902 L
Mistroke
.47173 .30902 L
.4725 .30902 L
.47321 .30902 L
.47484 .30902 L
.47564 .30902 L
.47637 .30902 L
.47708 .30902 L
.47744 .30902 L
.47783 .30902 L
.47822 .30902 L
.47858 .30902 L
.4788 .30902 L
.47901 .30902 L
.4792 .30902 L
.47931 .30902 L
.4794 .30902 L
.47951 .30902 L
.4796 .30902 L
.47969 .30902 L
.47978 .30902 L
.47988 .30902 L
.47993 .30902 L
.47999 .30902 L
.48009 .30902 L
.48018 .30902 L
.48037 .30902 L
.48053 .30902 L
.48091 .30902 L
.48172 .30902 L
.48257 .30902 L
.48417 .30902 L
.48487 .30902 L
.48563 .30902 L
.48605 .30902 L
.48644 .30902 L
.48683 .30902 L
.4872 .30902 L
.48759 .30902 L
.48779 .30902 L
.48802 .30902 L
.48813 .30902 L
.48825 .30902 L
.48836 .30902 L
.48847 .30902 L
.48857 .30902 L
.48867 .30902 L
.48872 .30902 L
.48878 .30902 L
.48888 .30902 L
.48898 .30902 L
Mistroke
.48907 .30902 L
.48918 .30902 L
.48928 .30902 L
.48964 .30902 L
.49005 .30902 L
.49048 .30902 L
.49217 .30902 L
.49373 .30902 L
.49416 .30902 L
.49462 .30902 L
.49501 .30902 L
.49545 .30902 L
.49586 .30902 L
.49625 .30902 L
.49646 .30902 L
.49666 .30902 L
.49688 .30902 L
.49698 .30902 L
.49709 .30902 L
.49718 .30902 L
.49728 .30902 L
.49738 .30902 L
.49747 .30902 L
.49756 .30902 L
.49765 .30902 L
.49773 .30902 L
.49782 .30902 L
.49792 .30902 L
.49801 .30902 L
.49812 .30902 L
.49822 .30902 L
.4986 .30902 L
.49898 .30902 L
.49939 .30902 L
.50022 .30902 L
.5017 .30902 L
.50251 .30902 L
.50327 .30902 L
.50369 .30902 L
.50415 .30902 L
.50457 .30902 L
.50495 .30902 L
.50532 .30902 L
.50553 .30902 L
.50573 .30902 L
.5059 .30902 L
.50601 .30902 L
.5061 .30902 L
.50619 .30902 L
.50627 .30902 L
Mistroke
.50636 .30902 L
.50645 .30902 L
.50655 .30902 L
.50665 .30902 L
.50671 .30902 L
.50676 .30902 L
.50687 .30902 L
.50707 .30902 L
.50725 .30902 L
.50769 .30902 L
.50811 .30902 L
.50957 .30902 L
.5104 .30902 L
.51118 .30902 L
.51195 .30902 L
.51277 .30902 L
.5132 .30902 L
.51343 .30902 L
.51365 .30902 L
.51404 .30902 L
.51424 .30902 L
.51434 .30902 L
.51446 .30902 L
.51456 .30902 L
.51466 .30902 L
.51478 .30902 L
.51483 .30902 L
.51488 .30902 L
.51499 .30902 L
.51509 .30902 L
.51519 .30902 L
.51528 .30902 L
.51533 .30902 L
.51539 .30902 L
.5155 .30902 L
.51561 .30902 L
.51571 .30902 L
.51617 .30902 L
.51654 .30902 L
.51696 .30902 L
.51779 .30902 L
.51866 .30902 L
.51949 .30902 L
.52029 .30902 L
.52064 .30902 L
.52103 .30902 L
.52138 .30902 L
.52176 .30902 L
.52216 .30902 L
.52253 .30902 L
Mistroke
.52273 .30902 L
.52295 .30902 L
.52306 .30902 L
.52317 .30902 L
.52328 .30902 L
.52338 .30902 L
.52348 .30902 L
.52354 .30902 L
.52359 .30902 L
.52369 .30902 L
.52379 .30902 L
.52388 .30902 L
.52398 .30902 L
.52407 .30902 L
.52416 .30902 L
.52434 .30902 L
.52455 .30902 L
.52495 .30902 L
.52569 .30902 L
.52735 .30902 L
.52811 .30902 L
.52891 .30902 L
.52932 .30902 L
.52978 .30902 L
.53019 .30902 L
.53058 .30902 L
.53098 .30902 L
.53121 .30902 L
.53142 .30902 L
.5316 .30902 L
.53171 .30902 L
.53181 .30902 L
.53191 .30902 L
.53196 .30902 L
.53202 .30902 L
.53212 .30902 L
.53222 .30902 L
.53232 .30902 L
.53241 .30902 L
.5325 .30902 L
.53259 .30902 L
.53269 .30902 L
.5328 .30902 L
.53299 .30902 L
.53333 .30902 L
.53371 .30902 L
.53541 .30902 L
.53695 .30902 L
.53772 .30902 L
.53816 .30902 L
Mistroke
.53856 .30902 L
.53891 .30902 L
.53929 .30902 L
.53949 .30902 L
.5397 .30902 L
.5399 .30902 L
.54008 .30902 L
.54018 .30902 L
.54028 .30902 L
.54036 .30902 L
.54046 .30902 L
.54056 .30902 L
.54061 .30902 L
.54067 .30902 L
.54077 .30902 L
.54086 .30902 L
.54096 .30902 L
.54105 .30902 L
.54122 .30902 L
.5414 .30902 L
.5416 .30902 L
.54246 .30902 L
.54326 .30902 L
.54477 .30902 L
.54562 .30902 L
.5464 .30902 L
.5468 .30902 L
.54724 .30902 L
.54746 .30902 L
.5477 .30902 L
.54792 .30902 L
.54813 .30902 L
.54834 .30902 L
.54845 .30902 L
.54856 .30902 L
.54866 .30902 L
.54876 .30902 L
.54886 .30902 L
.54892 .30902 L
.54897 .30902 L
.54907 .30902 L
.54915 .30902 L
.54925 .30902 L
.54935 .30902 L
.54946 .30902 L
.54956 .30902 L
.54975 .30902 L
.55012 .30902 L
.55053 .30902 L
.55136 .30902 L
Mistroke
.55284 .30902 L
.55364 .30902 L
.5544 .30902 L
.55482 .30902 L
.55528 .30902 L
.5557 .30902 L
.5559 .30902 L
.55608 .30902 L
.55626 .30902 L
.55645 .30902 L
.55665 .30902 L
.55675 .30902 L
.55685 .30902 L
.55695 .30902 L
.55704 .30902 L
.55712 .30902 L
.5572 .30902 L
.5573 .30902 L
.5574 .30902 L
.55748 .30902 L
.55758 .30902 L
.55763 .30902 L
.55769 .30902 L
.55779 .30902 L
.55799 .30902 L
.55843 .30902 L
.55923 .30902 L
.56094 .30902 L
.56175 .30902 L
.5625 .30902 L
.56287 .30902 L
.56327 .30902 L
.56368 .30902 L
.56391 .30902 L
.56411 .30902 L
.5643 .30902 L
.56449 .30902 L
.5647 .30902 L
.5648 .30902 L
.5649 .30902 L
.56499 .30902 L
.56509 .30902 L
.56519 .30902 L
.56528 .30902 L
.56537 .30902 L
.56547 .30902 L
.56555 .30902 L
.56564 .30902 L
.56574 .30902 L
.56584 .30902 L
Mistroke
.56595 .30902 L
.56606 .30902 L
.56646 .30902 L
.56682 .30902 L
.56721 .30902 L
.5689 .30902 L
.5697 .30902 L
.57046 .30902 L
.57088 .30902 L
.57134 .30902 L
.57175 .30902 L
.57214 .30902 L
.57235 .30902 L
.57255 .30902 L
.57276 .30902 L
.57287 .30902 L
.57299 .30902 L
.57309 .30902 L
.57319 .30902 L
.57328 .30902 L
.57337 .30902 L
.57347 .30902 L
.57357 .30902 L
.57368 .30902 L
.57373 .30902 L
.57379 .30902 L
.57389 .30902 L
.57398 .30902 L
.57416 .30902 L
.57435 .30902 L
.57456 .30902 L
.57528 .30902 L
.57699 .30902 L
.5778 .30902 L
.57855 .30902 L
.57932 .30902 L
.57973 .30902 L
.57994 .30902 L
.58016 .30902 L
.58036 .30902 L
.58054 .30902 L
.58072 .30902 L
.58089 .30902 L
.58108 .30902 L
.58119 .30902 L
.5813 .30902 L
.58139 .30902 L
.58148 .30902 L
.58158 .30902 L
.58169 .30902 L
Mistroke
.58179 .30902 L
.58188 .30902 L
.58198 .30902 L
.58208 .30902 L
.58226 .30902 L
.58245 .30902 L
.58289 .30902 L
.58329 .30902 L
.58499 .30902 L
.58571 .30902 L
.58649 .30902 L
.58694 .30902 L
.58735 .30902 L
.58776 .30902 L
.58815 .30902 L
.58836 .30902 L
.58855 .30902 L
.58873 .30902 L
.58892 .30902 L
.58902 .30902 L
.58913 .30902 L
.58923 .30902 L
.58932 .30902 L
.58937 .30902 L
.58942 .30902 L
.58948 .30902 L
.58954 .30902 L
.58959 .30902 L
.58964 .30902 L
.58974 .30902 L
.58983 .30902 L
.58992 .30902 L
.59001 .30902 L
.5901 .30902 L
.59044 .30902 L
.59081 .30902 L
.59122 .30902 L
.59293 .30902 L
.59373 .30902 L
.59448 .30902 L
.59486 .30902 L
.59525 .30902 L
.59565 .30902 L
.59588 .30902 L
.59609 .30902 L
.59647 .30902 L
.59668 .30902 L
.59688 .30902 L
.59697 .30902 L
.59706 .30902 L
Mistroke
.59714 .30902 L
.59723 .30902 L
.59733 .30902 L
.59741 .30902 L
.59752 .30902 L
.59762 .30902 L
.59772 .30902 L
.59781 .30902 L
.5979 .30902 L
.598 .30902 L
.59821 .30902 L
.5984 .30902 L
.59913 .30902 L
.60079 .30902 L
.60152 .30902 L
.6023 .30902 L
.60274 .30902 L
.60315 .30902 L
.60356 .30902 L
.60395 .30902 L
.60416 .30902 L
.60436 .30902 L
.60453 .30902 L
.60472 .30902 L
.60482 .30902 L
.60493 .30902 L
.60499 .30902 L
.60504 .30902 L
.60515 .30902 L
.60526 .30902 L
.60536 .30902 L
.60545 .30902 L
.60554 .30902 L
.60563 .30902 L
.60572 .30902 L
.60592 .30902 L
.60611 .30902 L
.60631 .30902 L
.60702 .30902 L
.6086 .30902 L
.60943 .30902 L
.60989 .30902 L
.61032 .30902 L
.61074 .30902 L
.61119 .30902 L
.61139 .30902 L
.6116 .30902 L
.61197 .30902 L
.61215 .30902 L
.61235 .30902 L
Mistroke
.61253 .30902 L
.61261 .30902 L
.6127 .30902 L
.6128 .30902 L
.6129 .30902 L
.61296 .30902 L
.61301 .30902 L
.61311 .30902 L
.61321 .30902 L
.6133 .30902 L
.6134 .30902 L
.6135 .30902 L
.61371 .30902 L
.6139 .30902 L
.61427 .30902 L
.61508 .30902 L
.61656 .30902 L
.61734 .30902 L
.61776 .30902 L
.61816 .30902 L
.61853 .30902 L
.61886 .30902 L
.61924 .30902 L
.61945 .30902 L
.61964 .30902 L
.61982 .30902 L
.62002 .30902 L
.62013 .30902 L
.62023 .30902 L
.62033 .30902 L
.62043 .30902 L
.62051 .30902 L
.6206 .30902 L
.6207 .30902 L
.62079 .30902 L
.62088 .30902 L
.62098 .30902 L
.62107 .30902 L
.62116 .30902 L
.62136 .30902 L
.62155 .30902 L
.62197 .30902 L
.62283 .30902 L
.62431 .30902 L
.62515 .30902 L
.62556 .30902 L
.62593 .30902 L
.6263 .30902 L
.62671 .30902 L
.62693 .30902 L
Mistroke
.62713 .30902 L
.62734 .30902 L
.62754 .30902 L
.62773 .30902 L
.62793 .30902 L
.62804 .30902 L
.6281 .30902 L
.62815 .30902 L
.62825 .30902 L
.6283 .30902 L
.62836 .30902 L
.62842 .30902 L
.62847 .30902 L
.62853 .30902 L
.62859 .30902 L
.6287 .30902 L
.62876 .30902 L
.62882 .30902 L
.62902 .30902 L
.62923 .30902 L
.63005 .30902 L
.63094 .30902 L
.63171 .30902 L
.63255 .30902 L
.63295 .30902 L
.63337 .30902 L
.63374 .30902 L
.63414 .30902 L
.63457 .30902 L
.6348 .30902 L
.63502 .30902 L
.63523 .30902 L
.63541 .30902 L
.63552 .30902 L
.63563 .30902 L
.63573 .30902 L
.63583 .30902 L
.63593 .30902 L
.63603 .30902 L
.63611 .30902 L
.6362 .30902 L
.63631 .30902 L
.63641 .30902 L
.63661 .30902 L
.63695 .30902 L
.63734 .30902 L
.63899 .30902 L
.63975 .30902 L
.64054 .30902 L
.64096 .30902 L
Mistroke
.64142 .30902 L
.64183 .30902 L
.64222 .30902 L
.64243 .30902 L
.64262 .30902 L
.64283 .30902 L
.64294 .30902 L
.64306 .30902 L
.64316 .30902 L
.64326 .30902 L
.64331 .30902 L
.64337 .30902 L
.64347 .30902 L
.64357 .30902 L
.64367 .30902 L
.64377 .30902 L
.64386 .30902 L
.64395 .30902 L
.64405 .30902 L
.64422 .30902 L
.64462 .30902 L
.64535 .30902 L
.64617 .30902 L
.64694 .30902 L
.64764 .30902 L
.6484 .30902 L
.64879 .30902 L
.64921 .30902 L
.64957 .30902 L
.64977 .30902 L
.64996 .30902 L
.65017 .30902 L
.65028 .30902 L
.65038 .30902 L
.65048 .30902 L
.65057 .30902 L
.65066 .30902 L
.65077 .30902 L
.65082 .30902 L
.65088 .30902 L
.65098 .30902 L
.65104 .30902 L
.6511 .30902 L
.65115 .30902 L
.65122 .30902 L
.65127 .30902 L
.65133 .30902 L
.65144 .30902 L
.65164 .30902 L
.65207 .30902 L
Mistroke
.65247 .30902 L
.65322 .30902 L
.65404 .30902 L
.65491 .30902 L
.65568 .30902 L
.65611 .30902 L
.65652 .30902 L
.6569 .30902 L
.65724 .30902 L
.65743 .30902 L
.65763 .30902 L
.65773 .30902 L
.65783 .30902 L
.65792 .30902 L
.65801 .30902 L
.6581 .30902 L
.6582 .30902 L
.65829 .30902 L
.6584 .30902 L
.6585 .30902 L
.65859 .30902 L
.65867 .30902 L
.65876 .30902 L
.65897 .30902 L
.65918 .30902 L
.65957 .30902 L
.66104 .30902 L
.6618 .30902 L
.66222 .30902 L
.66261 .30902 L
.66298 .30902 L
.66338 .30902 L
.66375 .30902 L
.66409 .30902 L
.66446 .30902 L
.66467 .30902 L
.66486 .30902 L
.66503 .30902 L
.66521 .30902 L
.6653 .30902 L
.6654 .30902 L
.6655 .30902 L
.66558 .30902 L
.66568 .30902 L
.66574 .30902 L
.66579 .30902 L
.66589 .30902 L
.66599 .30902 L
.66605 .30902 L
.6661 .30902 L
Mistroke
.6662 .30902 L
.66643 .30902 L
.66682 .30902 L
.66723 .30902 L
.66812 .30902 L
.66895 .30902 L
.66969 .30902 L
.67008 .30902 L
.6705 .30902 L
.67091 .30902 L
.6713 .30902 L
.6717 .30902 L
.67193 .30902 L
.67214 .30902 L
.67233 .30902 L
.67251 .30902 L
.6726 .30902 L
.6727 .30902 L
.67275 .30902 L
.67281 .30902 L
.67291 .30902 L
.673 .30902 L
.6731 .30902 L
.6732 .30902 L
.67329 .30902 L
.67338 .30902 L
.67346 .30902 L
.67364 .30902 L
.67403 .30902 L
.67444 .30902 L
.67518 .30902 L
.67599 .30902 L
.67643 .30902 L
.67685 .30902 L
.67725 .30902 L
.67767 .30902 L
.67806 .30902 L
.67842 .30902 L
.6788 .30902 L
.67914 .30902 L
.67932 .30902 L
.67953 .30902 L
.67962 .30902 L
.67972 .30902 L
.67981 .30902 L
.6799 .30902 L
.67999 .30902 L
.68005 .30902 L
.6801 .30902 L
.68019 .30902 L
Mistroke
.68029 .30902 L
.68039 .30902 L
.68048 .30902 L
.68057 .30902 L
.68066 .30902 L
.68086 .30902 L
.68108 .30902 L
.68148 .30902 L
.68295 .30902 L
.68376 .30902 L
.68453 .30902 L
.68495 .30902 L
.68541 .30902 L
.68561 .30902 L
.68583 .30902 L
.68621 .30902 L
.68641 .30902 L
.68661 .30902 L
.68678 .30902 L
.68688 .30902 L
.68697 .30902 L
.68707 .30902 L
.68712 .30902 L
.68718 .30902 L
.68728 .30902 L
.68734 .30902 L
.68739 .30902 L
.68749 .30902 L
.68758 .30902 L
.68768 .30902 L
.68779 .30902 L
.68798 .30902 L
.68818 .30902 L
.68856 .30902 L
.68926 .30902 L
.69001 .30902 L
.69082 .30902 L
.69129 .30902 L
.69171 .30902 L
.69214 .30902 L
.69254 .30902 L
.69292 .30902 L
.69313 .30902 L
.69333 .30902 L
.69351 .30902 L
.6937 .30902 L
.69388 .30902 L
.69405 .30902 L
.69415 .30902 L
.69425 .30902 L
Mistroke
.69435 .30902 L
.69444 .30902 L
.69454 .30902 L
.6946 .30902 L
.69465 .30902 L
.69475 .30902 L
.69486 .30902 L
.69496 .30902 L
.69506 .30902 L
.69526 .30902 L
.6957 .30902 L
.69728 .30902 L
.69772 .30902 L
.69818 .30902 L
.69861 .30902 L
.69901 .30902 L
.69942 .30902 L
.69963 .30902 L
.69987 .30902 L
.70026 .30902 L
.70048 .30902 L
.70068 .30902 L
.70087 .30902 L
.70097 .30902 L
.70106 .30902 L
.70114 .30902 L
.70123 .30902 L
.70131 .30902 L
.70141 .30902 L
.70151 .30902 L
.7016 .30902 L
.7017 .30902 L
.70176 .30902 L
.70181 .30902 L
.70191 .30902 L
.70201 .30902 L
.70219 .30902 L
.7024 .30902 L
.70262 .30902 L
.70301 .30902 L
.7039 .30902 L
.70468 .30902 L
.70511 .30902 L
.70552 .30902 L
.70591 .30902 L
.70634 .30902 L
.70673 .30902 L
.70709 .30902 L
.70728 .30902 L
.70746 .30902 L
Mistroke
.70763 .30902 L
.7078 .30902 L
.70799 .30902 L
.70816 .30902 L
.70826 .30902 L
.70835 .30902 L
.70845 .30902 L
.70851 .30902 L
.70856 .30902 L
.70865 .30902 L
.70874 .30902 L
.70884 .30902 L
.70894 .30902 L
.70905 .30902 L
.70916 .30902 L
.70935 .30902 L
.71009 .30902 L
.7109 .30902 L
.71176 .30902 L
.71218 .30902 L
.71259 .30902 L
.71298 .30902 L
.71334 .30902 L
.71369 .30902 L
.71405 .30902 L
.71441 .30902 L
.71462 .30902 L
.71482 .30902 L
.71492 .30902 L
.71502 .30902 L
.71512 .30902 L
.71522 .30902 L
.71528 .30902 L
.71533 .30902 L
.71539 .30902 L
.71544 .30902 L
.71555 .30902 L
.7156 .30902 L
.71565 .30902 L
.71575 .30902 L
.71585 .30902 L
.71594 .30902 L
.71603 .30902 L
.71625 .30902 L
.71644 .30902 L
.71793 .30902 L
.71866 .30902 L
.71943 .30902 L
.71988 .30902 L
.72029 .30902 L
Mistroke
.7207 .30902 L
.72109 .30902 L
.7213 .30902 L
.72149 .30902 L
.72167 .30902 L
.72186 .30902 L
.72196 .30902 L
.72207 .30902 L
.72218 .30902 L
.72228 .30902 L
.72238 .30902 L
.72247 .30902 L
.72258 .30902 L
.72268 .30902 L
.72276 .30902 L
.72286 .30902 L
.72295 .30902 L
.72304 .30902 L
.72338 .30902 L
.72415 .30902 L
.72563 .30902 L
.72604 .30902 L
.72647 .30902 L
.72685 .30902 L
.72726 .30902 L
.72748 .30902 L
.72769 .30902 L
.72788 .30902 L
.7281 .30902 L
.72828 .30902 L
.72847 .30902 L
.72867 .30902 L
.72886 .30902 L
.72898 .30902 L
.72908 .30902 L
.72914 .30902 L
.7292 .30902 L
.72926 .30902 L
.72932 .30902 L
.72937 .30902 L
.72943 .30902 L
.72952 .30902 L
.72958 .30902 L
.72963 .30902 L
.72969 .30902 L
.72975 .30902 L
.72997 .30902 L
.73017 .30902 L
.73056 .30902 L
.73202 .30902 L
Mistroke
.73285 .30902 L
.73326 .30902 L
.73364 .30902 L
.73401 .30902 L
.7344 .30902 L
.73479 .30902 L
.73502 .30902 L
.73522 .30902 L
.73544 .30902 L
.73555 .30902 L
.73565 .30902 L
.73574 .30902 L
.73584 .30902 L
.73594 .30902 L
.73604 .30902 L
.7361 .30902 L
.73615 .30902 L
.73626 .30902 L
.73632 .30902 L
.73637 .30902 L
.73643 .30902 L
.73649 .30902 L
.73655 .30902 L
.7366 .30902 L
.73671 .30902 L
.73691 .30902 L
.73731 .30902 L
.73768 .30902 L
.73852 .30902 L
.73939 .30902 L
.73981 .30902 L
.74021 .30902 L
.74058 .30902 L
.741 .30902 L
.74141 .30902 L
.74164 .30902 L
.74185 .30902 L
.74204 .30902 L
.74222 .30902 L
.74239 .30902 L
.74257 .30902 L
.74267 .30902 L
.74276 .30902 L
.74281 .30902 L
.74287 .30902 L
.74297 .30902 L
.74306 .30902 L
.74316 .30902 L
.74325 .30902 L
.74334 .30902 L
Mistroke
.74344 .30902 L
.74354 .30902 L
.74376 .30902 L
.74416 .30902 L
.7449 .30902 L
.74577 .30902 L
.74619 .30902 L
.74658 .30902 L
.7473 .30902 L
.74768 .30902 L
.74808 .30902 L
.74828 .30902 L
.74849 .30902 L
.74867 .30902 L
.74887 .30902 L
.74899 .30902 L
.7491 .30902 L
.74921 .30902 L
.74932 .30902 L
.74943 .30902 L
.74952 .30902 L
.74963 .30902 L
.74968 .30902 L
.74974 .30902 L
.74984 .30902 L
.74994 .30902 L
.75002 .30902 L
.75012 .30902 L
.75022 .30902 L
.75033 .30902 L
.75053 .30902 L
.75126 .30902 L
.75207 .30902 L
.75293 .30902 L
.75335 .30902 L
.75375 .30902 L
.75414 .30902 L
.75451 .30902 L
.75485 .30902 L
.75521 .30902 L
.7554 .30902 L
.75558 .30902 L
.75577 .30902 L
.75588 .30902 L
.75598 .30902 L
.75607 .30902 L
.75617 .30902 L
.75628 .30902 L
.75638 .30902 L
.75647 .30902 L
Mistroke
.75657 .30902 L
.75666 .30902 L
.75675 .30902 L
.7568 .30902 L
.75686 .30902 L
.75696 .30902 L
.75718 .30902 L
.75759 .30902 L
.75841 .30902 L
.75928 .30902 L
.76004 .30902 L
.76047 .30902 L
.76088 .30902 L
.76125 .30902 L
.76159 .30902 L
.76196 .30902 L
.76215 .30902 L
.76236 .30902 L
.76256 .30902 L
.76268 .30902 L
.76278 .30902 L
.76287 .30902 L
.76298 .30902 L
.76303 .30902 L
.76308 .30902 L
.76318 .30902 L
.76328 .30902 L
.76338 .30902 L
.76348 .30902 L
.76357 .30902 L
.76375 .30902 L
.76393 .30902 L
.76561 .30902 L
.76644 .30902 L
.7669 .30902 L
.76733 .30902 L
.76771 .30902 L
.76812 .30902 L
.76833 .30902 L
.76855 .30902 L
.76876 .30902 L
.76895 .30902 L
.76913 .30902 L
.76924 .30902 L
.76934 .30902 L
.76944 .30902 L
.76953 .30902 L
.76964 .30902 L
.76969 .30902 L
.76975 .30902 L
Mistroke
.76984 .30902 L
.76993 .30902 L
.77003 .30902 L
.77013 .30902 L
.77022 .30902 L
.7703 .30902 L
.77048 .30902 L
.77129 .30902 L
.77215 .30902 L
.77291 .30902 L
.77333 .30902 L
.77372 .30902 L
.77409 .30902 L
.77449 .30902 L
.77485 .30902 L
.77519 .30902 L
.77541 .30902 L
.7756 .30902 L
.77582 .30902 L
.77592 .30902 L
.77599 .30902 L
.77604 .30902 L
.77615 .30902 L
.77624 .30902 L
.77635 .30902 L
.7764 .30902 L
.77646 .30902 L
.77655 .30902 L
.77664 .30902 L
.77675 .30902 L
.77684 .30902 L
.77722 .30902 L
.77756 .30902 L
.77834 .30902 L
.77908 .30902 L
.77986 .30902 L
.78031 .30902 L
.78072 .30902 L
.78092 .30902 L
.78114 .30902 L
.78152 .30902 L
.78171 .30902 L
.78192 .30902 L
.78211 .30902 L
.78229 .30902 L
.78239 .30902 L
.78249 .30902 L
.7826 .30902 L
.78266 .30902 L
.78272 .30902 L
Mistroke
.78282 .30902 L
.78287 .30902 L
.78293 .30902 L
.78302 .30902 L
.78312 .30902 L
.78323 .30902 L
.78333 .30902 L
.78354 .30902 L
.78393 .30902 L
.78481 .30902 L
.78556 .30902 L
.78635 .30902 L
.78677 .30902 L
.78722 .30902 L
.78742 .30902 L
.78763 .30902 L
.78802 .30902 L
.78823 .30902 L
.78844 .30902 L
.78865 .30902 L
.78883 .30902 L
.78895 .30902 L
.78905 .30902 L
.78917 .30902 L
.78923 .30902 L
.78929 .30902 L
.78935 .30902 L
.7894 .30902 L
.78946 .30902 L
.78951 .30902 L
.78961 .30902 L
.78967 .30902 L
.78972 .30902 L
.78991 .30902 L
.79009 .30902 L
.7905 .30902 L
.79133 .30902 L
.79212 .30902 L
.79256 .30902 L
.79296 .30902 L
.79333 .30902 L
.79367 .30902 L
.79404 .30902 L
.79423 .30902 L
.79444 .30902 L
.79463 .30902 L
.79483 .30902 L
.79505 .30902 L
.79514 .30902 L
.79524 .30902 L
Mistroke
.79535 .30902 L
.79544 .30902 L
.79553 .30902 L
.79563 .30902 L
.79572 .30902 L
.7958 .30902 L
.79589 .30902 L
.79598 .30902 L
.79609 .30902 L
.79619 .30902 L
.79629 .30902 L
.79641 .30902 L
.79686 .30902 L
.79765 .30902 L
.79847 .30902 L
.79891 .30902 L
.79936 .30902 L
.79976 .30902 L
.80021 .30902 L
.8004 .30902 L
.80061 .30902 L
.80098 .30902 L
.80119 .30902 L
.8014 .30902 L
.80161 .30902 L
.80179 .30902 L
.80191 .30902 L
.80201 .30902 L
.80207 .30902 L
.80213 .30902 L
.80219 .30902 L
.80225 .30902 L
.8023 .30902 L
.80236 .30902 L
.80246 .30902 L
.80251 .30902 L
.80256 .30902 L
.80268 .30902 L
.80277 .30902 L
.80287 .30902 L
.80305 .30902 L
.80346 .30902 L
.80429 .30902 L
.80512 .30902 L
.8059 .30902 L
.80629 .30902 L
.80671 .30902 L
.80695 .30902 L
.80717 .30902 L
.80739 .30902 L
Mistroke
.80759 .30902 L
.80777 .30902 L
.80797 .30902 L
.80807 .30902 L
.80818 .30902 L
.80828 .30902 L
.80837 .30902 L
.80847 .30902 L
.80858 .30902 L
.80868 .30902 L
.80877 .30902 L
.80882 .30902 L
.80888 .30902 L
.80898 .30902 L
.80903 .30902 L
.80908 .30902 L
.8092 .30902 L
.80957 .30902 L
.80992 .30902 L
.81068 .30902 L
.81143 .30902 L
.81222 .30902 L
.81263 .30902 L
.81285 .30902 L
.81308 .30902 L
.8133 .30902 L
.8135 .30902 L
.8137 .30902 L
.81388 .30902 L
.81408 .30902 L
.81427 .30902 L
.81446 .30902 L
.81457 .30902 L
.81467 .30902 L
.81476 .30902 L
.81484 .30902 L
.81493 .30902 L
.81503 .30902 L
.81513 .30902 L
.81523 .30902 L
.81531 .30902 L
.81541 .30902 L
.81551 .30902 L
.81561 .30902 L
.81582 .30902 L
.81627 .30902 L
.81707 .30902 L
.81786 .30902 L
.81829 .30902 L
.81869 .30902 L
Mistroke
.81903 .30902 L
.8194 .30902 L
.81961 .30902 L
.8198 .30902 L
.82017 .30902 L
.82036 .30902 L
.82054 .30902 L
.82074 .30902 L
.82085 .30902 L
.82095 .30902 L
.82106 .30902 L
.82115 .30902 L
.82121 .30902 L
.82126 .30902 L
.82132 .30902 L
.82137 .30902 L
.82148 .30902 L
.82157 .30902 L
.82167 .30902 L
.82172 .30902 L
.82178 .30902 L
.82197 .30902 L
.82215 .30902 L
.82254 .30902 L
.82326 .30902 L
.824 .30902 L
.82479 .30902 L
.8252 .30902 L
.82542 .30902 L
.82566 .30902 L
.82587 .30902 L
.82607 .30902 L
.82627 .30902 L
.82646 .30902 L
.82665 .30902 L
.82684 .30902 L
.82703 .30902 L
.82714 .30902 L
.82725 .30902 L
.82733 .30902 L
.82742 .30902 L
.8275 .30902 L
.8276 .30902 L
.8277 .30902 L
.8278 .30902 L
.82788 .30902 L
.82798 .30902 L
.82809 .30902 L
.8282 .30902 L
.8284 .30902 L
Mistroke
.82884 .30902 L
.82964 .30902 L
.83043 .30902 L
.83086 .30902 L
.83126 .30902 L
.8316 .30902 L
.83196 .30902 L
.83217 .30902 L
.83237 .30902 L
.83274 .30902 L
.83293 .30902 L
.83311 .30902 L
.83331 .30902 L
.83342 .30902 L
.83352 .30902 L
.83362 .30902 L
.83372 .30902 L
.83378 .30902 L
.83383 .30902 L
.83389 .30902 L
.83394 .30902 L
.83404 .30902 L
.83413 .30902 L
.83424 .30902 L
.83434 .30902 L
.83452 .30902 L
.83471 .30902 L
.83505 .30902 L
.83582 .30902 L
.83664 .30902 L
.8371 .30902 L
.83753 .30902 L
.8379 .30902 L
.83831 .30902 L
.83852 .30902 L
.83874 .30902 L
.83895 .30902 L
.83914 .30902 L
.83934 .30902 L
.83952 .30902 L
.83962 .30902 L
.83973 .30902 L
.83983 .30902 L
.83993 .30902 L
.84002 .30902 L
.8401 .30902 L
.84019 .30902 L
.84028 .30902 L
.84039 .30902 L
.84048 .30902 L
Mistroke
.84066 .30902 L
.84086 .30902 L
.84107 .30902 L
.84146 .30902 L
.84232 .30902 L
.84315 .30902 L
.84362 .30902 L
.84404 .30902 L
.84442 .30902 L
.84483 .30902 L
.84504 .30902 L
.84526 .30902 L
.84547 .30902 L
.84557 .30902 L
.84566 .30902 L
.84585 .30902 L
.84595 .30902 L
.84605 .30902 L
.84616 .30902 L
.84621 .30902 L
.84626 .30902 L
.84637 .30902 L
.84646 .30902 L
.84656 .30902 L
.84665 .30902 L
.84682 .30902 L
.847 .30902 L
.8472 .30902 L
.84799 .30902 L
.84887 .30902 L
.84926 .30902 L
.84969 .30902 L
.8501 .30902 L
.85046 .30902 L
.85088 .30902 L
.85111 .30902 L
.85133 .30902 L
.85152 .30902 L
.85173 .30902 L
.85183 .30902 L
.85195 .30902 L
.85206 .30902 L
.85215 .30902 L
.85226 .30902 L
.85235 .30902 L
.85244 .30902 L
.85253 .30902 L
.85264 .30902 L
.85269 .30902 L
.85274 .30902 L
Mistroke
.85284 .30902 L
.85294 .30902 L
.85329 .30902 L
.85367 .30902 L
.85453 .30902 L
.85533 .30902 L
.85572 .30902 L
.85614 .30902 L
.85638 .30902 L
.85661 .30902 L
.85681 .30902 L
.85703 .30902 L
.85722 .30902 L
.85743 .30902 L
.85762 .30902 L
.8578 .30902 L
.85791 .30902 L
.85801 .30902 L
.85811 .30902 L
.85821 .30902 L
.85826 .30902 L
.85832 .30902 L
.85841 .30902 L
.85847 .30902 L
.85853 .30902 L
.85859 .30902 L
.85864 .30902 L
.85874 .30902 L
.85884 .30902 L
.85893 .30902 L
.85902 .30902 L
.85943 .30902 L
.86016 .30902 L
.86095 .30902 L
.86137 .30902 L
.86182 .30902 L
.86225 .30902 L
.86265 .30902 L
.86284 .30902 L
.86304 .30902 L
.86324 .30902 L
.86342 .30902 L
.86364 .30902 L
.86384 .30902 L
.86396 .30902 L
.86406 .30902 L
.86417 .30902 L
.86429 .30902 L
.86439 .30902 L
.8645 .30902 L
Mistroke
.86459 .30902 L
.86468 .30902 L
.86479 .30902 L
.86485 .30902 L
.8649 .30902 L
.865 .30902 L
.86511 .30902 L
.86531 .30902 L
.8655 .30902 L
.86586 .30902 L
.86667 .30902 L
.86744 .30902 L
.86778 .30902 L
.86814 .30902 L
.86854 .30902 L
.86891 .30902 L
.86912 .30902 L
.86934 .30902 L
.86953 .30902 L
.86973 .30902 L
.86992 .30902 L
.8701 .30902 L
.8702 .30902 L
.8703 .30902 L
.8704 .30902 L
.87049 .30902 L
.87058 .30902 L
.87066 .30902 L
.87075 .30902 L
.87084 .30902 L
.87093 .30902 L
.87103 .30902 L
.87112 .30902 L
.87121 .30902 L
.87208 .30902 L
.87291 .30902 L
.87365 .30902 L
.87407 .30902 L
.87446 .30902 L
.87483 .30902 L
.87519 .30902 L
.87539 .30902 L
.87557 .30902 L
.87578 .30902 L
.87589 .30902 L
.87598 .30902 L
.87618 .30902 L
.87628 .30902 L
.87638 .30902 L
.87647 .30902 L
Mistroke
.87656 .30902 L
.87665 .30902 L
.87675 .30902 L
.87685 .30902 L
.87691 .30902 L
.87696 .30902 L
.87706 .30902 L
.87715 .30902 L
.87736 .30902 L
.87759 .30902 L
.87834 .30902 L
.87915 .30902 L
.87961 .30902 L
.88004 .30902 L
.88044 .30902 L
.88067 .30902 L
.88087 .30902 L
.88125 .30902 L
.88145 .30902 L
.88165 .30902 L
.88183 .30902 L
.882 .30902 L
.88218 .30902 L
.88227 .30902 L
.88238 .30902 L
.88243 .30902 L
.88249 .30902 L
.88259 .30902 L
.88269 .30902 L
.88279 .30902 L
.88284 .30902 L
.8829 .30902 L
.883 .30902 L
.88311 .30902 L
.88323 .30902 L
.88364 .30902 L
.88402 .30902 L
.88476 .30902 L
.88554 .30902 L
.88599 .30902 L
.8864 .30902 L
.8866 .30902 L
.88681 .30902 L
.8872 .30902 L
.88739 .30902 L
.88759 .30902 L
.88778 .30902 L
.88796 .30902 L
.88806 .30902 L
.88816 .30902 L
Mistroke
.88827 .30902 L
.88833 .30902 L
.88839 .30902 L
.88844 .30902 L
.8885 .30902 L
.8886 .30902 L
.88869 .30902 L
.88879 .30902 L
.8889 .30902 L
.88899 .30902 L
.8891 .30902 L
.88921 .30902 L
.8896 .30902 L
.89048 .30902 L
.89126 .30902 L
.89165 .30902 L
.89208 .30902 L
.89245 .30902 L
.89264 .30902 L
.89284 .30902 L
.89302 .30902 L
.89321 .30902 L
.89339 .30902 L
.89356 .30902 L
.89376 .30902 L
.89387 .30902 L
.89398 .30902 L
.89407 .30902 L
.89418 .30902 L
.89423 .30902 L
.89428 .30902 L
.89438 .30902 L
.89448 .30902 L
.89457 .30902 L
.89466 .30902 L
.89477 .30902 L
.89486 .30902 L
.89496 .30902 L
.89513 .30902 L
.89555 .30902 L
.89594 .30902 L
.89681 .30902 L
.89719 .30902 L
.8976 .30902 L
.89795 .30902 L
.89833 .30902 L
.89856 .30902 L
.89877 .30902 L
.89897 .30902 L
.8992 .30902 L
Mistroke
.89939 .30902 L
.89958 .30902 L
.89978 .30902 L
.89989 .30902 L
.89999 .30902 L
.90009 .30902 L
.90019 .30902 L
.90027 .30902 L
.90037 .30902 L
.90047 .30902 L
.90052 .30902 L
.90058 .30902 L
.90068 .30902 L
.90078 .30902 L
.90087 .30902 L
.90096 .30902 L
.90113 .30902 L
.90151 .30902 L
.90231 .30902 L
.90276 .30902 L
.90317 .30902 L
.90357 .30902 L
.90393 .30902 L
.90433 .30902 L
.90454 .30902 L
.90477 .30902 L
.90494 .30902 L
.90513 .30902 L
.9053 .30902 L
.90547 .30902 L
.90558 .30902 L
.90568 .30902 L
.90577 .30902 L
.90588 .30902 L
.90597 .30902 L
.90606 .30902 L
.90615 .30902 L
.90624 .30902 L
.9063 .30902 L
.90635 .30902 L
.90645 .30902 L
.90655 .30902 L
.90661 .30902 L
.90667 .30902 L
.90686 .30902 L
.90706 .30902 L
.90794 .30902 L
.90872 .30902 L
.90915 .30902 L
.90956 .30902 L
Mistroke
.90995 .30902 L
.91016 .30902 L
.91038 .30902 L
.91057 .30902 L
.91077 .30902 L
.91095 .30902 L
.91113 .30902 L
.91132 .30902 L
.9115 .30902 L
.91169 .30902 L
.91179 .30902 L
.91189 .30902 L
.91199 .30902 L
.91207 .30902 L
.91215 .30902 L
.91224 .30902 L
.91233 .30902 L
.91243 .30902 L
.91251 .30902 L
.9126 .30902 L
.91281 .30902 L
.91302 .30902 L
.91342 .30902 L
.91417 .30902 L
.91459 .30902 L
.91504 .30902 L
.91546 .30902 L
.91584 .30902 L
.91624 .30902 L
.91644 .30902 L
.91665 .30902 L
.91684 .30902 L
.91704 .30902 L
.91722 .30902 L
.91739 .30902 L
.9175 .30902 L
.91761 .30902 L
.9177 .30902 L
.91781 .30902 L
.91786 .30902 L
.91792 .30902 L
.91798 .30902 L
.91804 .30902 L
.91814 .30902 L
.9182 .30902 L
.91825 .30902 L
.91836 .30902 L
.91846 .30902 L
.91865 .30902 L
.91907 .30902 L
Mistroke
.91978 .30902 L
.92054 .30902 L
.92098 .30902 L
.92138 .30902 L
.92178 .30902 L
.92216 .30902 L
.92235 .30902 L
.92256 .30902 L
.92273 .30902 L
.92293 .30902 L
.92313 .30902 L
.92325 .30902 L
.92336 .30902 L
.92345 .30902 L
.92355 .30902 L
.9236 .30902 L
.92366 .30902 L
.92376 .30902 L
.92381 .30902 L
.92387 .30902 L
.92398 .30902 L
.92404 .30902 L
.92409 .30902 L
.92421 .30902 L
.92442 .30902 L
.92464 .30902 L
.92545 .30902 L
.92626 .30902 L
.92672 .30902 L
.92715 .30902 L
.92756 .30902 L
.92793 .30902 L
.92814 .30902 L
.92836 .30902 L
.92857 .30902 L
.92876 .30902 L
.92886 .30902 L
.92896 .30902 L
.92905 .30902 L
.92914 .30902 L
.92924 .30902 L
.92933 .30902 L
.92943 .30902 L
.92949 .30902 L
.92954 .30902 L
.92963 .30902 L
.92973 .30902 L
.92981 .30902 L
.9299 .30902 L
.92999 .30902 L
Mistroke
.93009 .30902 L
.93027 .30902 L
.93114 .30902 L
.93193 .30902 L
.93233 .30902 L
.93276 .30902 L
.93319 .30902 L
.93343 .30902 L
.93365 .30902 L
.93386 .30902 L
.93406 .30902 L
.93424 .30902 L
.93443 .30902 L
.93464 .30902 L
.93475 .30902 L
.93487 .30902 L
.93497 .30902 L
.93502 .30902 L
.93507 .30902 L
.93518 .30902 L
.93527 .30902 L
.93537 .30902 L
.93542 .30902 L
.93547 .30902 L
.93557 .30902 L
.93567 .30902 L
.93584 .30902 L
.93603 .30902 L
.93685 .30902 L
.93761 .30902 L
.93832 .30902 L
.93871 .30902 L
.93892 .30902 L
.93914 .30902 L
.93934 .30902 L
.93952 .30902 L
.9397 .30902 L
.93988 .30902 L
.9401 .30902 L
.9403 .30902 L
.94041 .30902 L
.94051 .30902 L
.94062 .30902 L
.94069 .30902 L
.94075 .30902 L
.94085 .30902 L
.9409 .30902 L
.94096 .30902 L
.94106 .30902 L
.94112 .30902 L
Mistroke
.94117 .30902 L
.94127 .30902 L
.94136 .30902 L
.94156 .30902 L
.94235 .30902 L
.94321 .30902 L
.94362 .30902 L
.94401 .30902 L
.94436 .30902 L
.94474 .30902 L
.94511 .30902 L
.94532 .30902 L
.94551 .30902 L
.94572 .30902 L
.94591 .30902 L
.94601 .30902 L
.94612 .30902 L
.94623 .30902 L
.94633 .30902 L
.94642 .30902 L
.94652 .30902 L
.94662 .30902 L
.9467 .30902 L
.94678 .30902 L
.94687 .30902 L
.94696 .30902 L
.94704 .30902 L
.94723 .30902 L
.94741 .30902 L
.9478 .30902 L
.94854 .30902 L
.94933 .30902 L
.94975 .30902 L
.94997 .30902 L
.9502 .30902 L
.95042 .30902 L
.95061 .30902 L
.95082 .30902 L
.951 .30902 L
.95118 .30902 L
.95138 .30902 L
.95149 .30902 L
.95159 .30902 L
.9517 .30902 L
.95179 .30902 L
.95188 .30902 L
.95196 .30902 L
.95205 .30902 L
.95215 .30902 L
.95224 .30902 L
Mistroke
.95234 .30902 L
.95244 .30902 L
.95252 .30902 L
.95262 .30902 L
.95272 .30902 L
.95291 .30902 L
.95333 .30902 L
.95419 .30902 L
.95495 .30902 L
.95539 .30902 L
.95579 .30902 L
.95601 .30902 L
.95622 .30902 L
.95641 .30902 L
.95661 .30902 L
.95683 .30902 L
.95703 .30902 L
.95725 .30902 L
.95737 .30902 L
.95749 .30902 L
.95759 .30902 L
.95764 .30902 L
.95769 .30902 L
.95779 .30902 L
.95789 .30902 L
.95794 .30902 L
.958 .30902 L
.9581 .30902 L
.95815 .30902 L
.9582 .30902 L
.95826 .30902 L
.95832 .30902 L
.95853 .30902 L
.95874 .30902 L
.95911 .30902 L
.95982 .30902 L
.96022 .30902 L
.9606 .30902 L
.96101 .30902 L
.96138 .30902 L
.96177 .30902 L
.96198 .30902 L
.9622 .30902 L
.96238 .30902 L
.96257 .30902 L
.96275 .30902 L
.96291 .30902 L
.963 .30902 L
.9631 .30902 L
.96321 .30902 L
Mistroke
.96331 .30902 L
.9634 .30902 L
.96348 .30902 L
.96358 .30902 L
.96368 .30902 L
.96374 .30902 L
.96379 .30902 L
.96388 .30902 L
.96399 .30902 L
.9641 .30902 L
.96449 .30902 L
.96538 .30902 L
.96579 .30902 L
.96622 .30902 L
.96659 .30902 L
.967 .30902 L
.9672 .30902 L
.96742 .30902 L
.96761 .30902 L
.96782 .30902 L
.968 .30902 L
.96821 .30902 L
.96839 .30902 L
.96857 .30902 L
.96867 .30902 L
.96878 .30902 L
.96883 .30902 L
.96889 .30902 L
.96899 .30902 L
.96909 .30902 L
.96919 .30902 L
.96928 .30902 L
.96938 .30902 L
.96948 .30902 L
.9696 .30902 L
.96983 .30902 L
.97025 .30902 L
.97105 .30902 L
.97181 .30902 L
.97223 .30902 L
.97245 .30902 L
.97269 .30902 L
.97289 .30902 L
.97311 .30902 L
.97329 .30902 L
.97349 .30902 L
.97365 .30902 L
.97382 .30902 L
.974 .30902 L
.97408 .30902 L
Mistroke
.97417 .30902 L
.97426 .30902 L
.97434 .30902 L
.97441 .30902 L
.97449 .30902 L
.97457 .30902 L
.97463 .30902 L
.97471 .30902 L
.97479 .30902 L
.97488 .30902 L
.97497 .30902 L
.97506 .30902 L
.97517 .30902 L
.97552 .30902 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{421.375, 260.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008>0001AB000`400?l00000o`00003ooooooooo
oooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo
003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooo
oooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool0
0?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooooooo
ool@ooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooo
ooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo0ol0003o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0
003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo
00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`
ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLoooo
o`00<?ooool3o`0002Oooooo00?o0000ooooooooool0oooooonbooooo`00<?ooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0oooooonVooooo`00<?oo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Sooooo0_l0003oooooojSooooo000`
ooooo`03o`000?oooooooooo02Oooooo0_l00009ooooo`;o0000oooooonXooooo`00<?ooool00ol0
003oooooooooo`0Wooooo`;o00002Oooool2o`000?ooooooZ?ooool0033ooooo00?o0000oooooooo
ool09oooool2o`0000Wooooo0_l0003oooooojSooooo000`ooooo`03o`000?oooooooooo02Oooooo
0_l00009ooooo`;o0000oooooonXooooo`00<?ooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooo000000Wooooo0_l0003oooooojSooooo000`ooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooool000002Oooool2o`000?ooooooZ?ooool0033ooooo00?o0000ooooooooool09_ooool00ol0
003oooooo`000009ooooo`;o0000oooooonXooooo`00<?ooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooo000000Wooooo0_l0003oooooojSooooo000`ooooo`?o00009_ooool00ol0003ooooo
o`000009ooooo`;o0000oooooonXooooo`00<?ooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooo000000Wooooo0_l0003oooooojSooooo000`ooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooool000002Oooool00ol0003oooooo`00003oooooojOooooo000`ooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooool000002Oooool00ol0003oooooo`00003oooooojOooooo000`ooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooool000002Oooool00ol0003oooooo`00003oooooojOo
oooo000`ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooool000002Oooool00ol0003ooooo
o`00003oooooojOooooo000`ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooool000002Ooo
ool00ol0003oooooo`00003oooooojOooooo000@ooooo`;ok^k^0oooool2onk^kQWooooo00?o0000
ooooooooool09_ooool00ol0003oooooo`000009ooooo`03o`000?oooooo00000?ooooooYoooool0
00_ooooo0_l000002_l@413oooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h3ooooo`Co
000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP[ooooo00?o0000ooooooooool09_oo
ool00ol0003oooooo`000009ooooo`03o`000?oooooo00000?ooooooYoooool000cooooo00?o0000
ooooooooool00_ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00[ooooo00?o0000ooooooooool09_ooool00ol0003ooooo
o`000009ooooo`03o`000?oooooo00000?ooooooYoooool00003ooooool0003o000000Co00000_oo
ool5o`0000Cooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?oo
ooooooooooooool@41002_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo000000Sooooo
00Co0000oooooooooooo0000oooooonWooooo`002Oooool01?m4A4CogMgMooooool00004ooooo`05
onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool000002_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo000000Sooooo00Co0000
oooooooooooo0000oooooonWooooo`002Oooool01?oMgMgoEEEEooooool00003ooooo`07onk^k_mE
EEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`00000:ooooo`Co00009Oooool00ol0003oooooo`000008ooooo`04o`000?oooooooooo
o`000?ooooooYoooool000[ooooo00?oMgMgolc<c?l000000oooool2onk^kP?ooooo0_o^k^h5oooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400:ooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooool000002?ooool01?l0003oooooooooool0003oooooojOooooo000:
ooooo`03onk^k_m4A4Co000000oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00?ooooo0_l00005ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooool000002?oo
ool01?l0003oooooooooool0003oooooojOooooo000;ooooo`03ogMgMol0003ooooo00cooooo00?o
EEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo000000Sooooo00Co0000oooooooo
oooo0000oooooonWooooo`00:?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooool000002?ooool01?l0003oooooooooool0003oooooojOooooo000Xoooo
o`?o00001Oooool00ol0003oooooooooo`0Vooooo`04o`000?ooooooooooo`0000Oooooo00Co0000
oooooooooooo0000oooooonWooooo`00:Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo02Kooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool0003oooooojOooooo
000Zooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09_ooool01?l0003ooooooooo
ool00007ooooo`04o`000?ooooooooooo`000?ooooooYoooool0033ooooo00?o0000ooooooooool0
9_ooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`000?ooooooYoooool0033o
oooo00?o0000ooooooooool09_ooool01?l0003oooooooooool00007ooooo`04o`000?oooooooooo
o`000?ooooooYoooool0033ooooo00?o0000ooooooooool09_ooool01?l0003oooooooooool00007
ooooo`04o`000?ooooooooooo`000?ooooooYoooool0033ooooo00?o0000ooooooooool09_ooool0
1?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`000?ooooooYoooool0033ooooo0ol0
000Vooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo0000oooooonWooooo`00
<?ooool00ol0003oooooooooo`0Vooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooo
oooo0000oooooonWooooo`00<?ooool00ol0003oooooooooo`0Vooooo`04o`000?ooooooooooo`00
00Oooooo00Co0000oooooooooooo0000oooooonWooooo`00<?ooool00ol0003oooooooooo`0Voooo
o`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo0000oooooonWooooo`00<?ooool0
0ol0003oooooooooo`0Vooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo0000
oooooonWooooo`00<?ooool00ol0003oooooooooo`0Uooooo`05o`000?ooooooooooooooool00000
1oooool01?l0003oooooooooool0003oooooojOooooo000`ooooo`03o`000?oooooooooo02Gooooo
00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`000?ooooooYoooool0033o
oooo00?o0000ooooooooool09Oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooo
oooooooo0000oooooonWooooo`00<?ooool00ol0003oooooooooo`0Uooooo`05o`000?oooooooooo
ooooool000001oooool01?l0003oooooooooool0003oooooojOooooo000`ooooo`03o`000?oooooo
oooo02Gooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`000?oooooo
Yoooool0033ooooo00?o0000ooooooooool09Oooool01Ol0003ooooooooooooooooo000000Oooooo
00Co0000oooooooooooo0000oooooonWooooo`00<?ooool00ol0003oooooooooo`0Uooooo`05o`00
0?ooooooooooooooool000001oooool01?l0003oooooooooool0003oooooojOooooo000`ooooo`?o
00009Oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000oooooonW
ooooo`00<?ooool00ol0003oooooooooo`0Uooooo`05o`000?ooooooooooooooool000001oooool0
1?l0003oooooooooool0003oooooojOooooo000`ooooo`03o`000?oooooooooo02Gooooo00Go0000
ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`000?ooooooYoooool0033ooooo00?o
0000ooooooooool09Oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo
0000oooooonWooooo`00<?ooool00ol0003oooooooooo`0Uooooo`05o`000?ooooooooooooooool0
00001oooool01?l0003oooooooooool0003oooooojOooooo000`ooooo`03o`000?oooooooooo02Go
oooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`000?ooooooYoooool0
033ooooo00?o0000ooooooooool09Oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000
oooooooooooo00002Oooool00ol0003oooooooooo`3ooooooi_ooooo000`ooooo`03o`000?oooooo
oooo02Gooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Sooooo
0_l0003ooooooigooooo000`ooooo`03o`000?oooooooooo02Gooooo00Go0000oooooooooooooooo
o`000007ooooo`04o`000?ooooooooooo`0000Sooooo0_l0003ooooooigooooo000`ooooo`03o`00
0?oooooooooo02Gooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`00
00Sooooo0_l0003ooooooigooooo000`ooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool01oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo00002?ooool2
o`000?ooooooWOooool0033ooooo0ol0000Jooooo`;o00002Oooool01Ol0003ooooooooooooooooo
000000Oooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003ooooooicooooo000`
ooooo`03o`000?oooooooooo01[ooooo0_l00009ooooo`05o`000?ooooooooooooooool000001ooo
ool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?ooooooW?ooool0033ooooo00?o
0000ooooooooool06_ooool2o`0000Wooooo00Go0000ooooooooooooooooo`000007ooooo`05o`00
0?ooooooooooooooool000001oooool00ol0003oooooo`00003ooooooicooooo000`ooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooool000002?ooool01Ol0003ooooooooooooooooo000000Oo
oooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?ooooooW?ooool0033o
oooo00?o0000ooooooooool06_ooool00ol0003oooooo`000008ooooo`05o`000?oooooooooooooo
ool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooool00000oooooonL
ooooo`00<?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo000000Sooooo00Go0000oooo
ooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooo`00
003ooooooicooooo000`ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooool000002?ooool0
1Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`03o`00
0?oooooo00000?ooooooW?ooool0013ooooo0_o^k^h3ooooo`;ok^k^6Oooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooo000000Sooooo00Go0000ooooooooooooooooo`000007ooooo`05o`00
0?ooooooooooooooool000001oooool00ol0003oooooo`00003ooooooicooooo0009ooooo`Go0000
0_ooool01oo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^h:ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooool00000
2?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007oooo
o`03o`000?oooooo00000?ooooooW?ooool000Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A003oooo
o`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo000000Sooooo00Go
0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool00ol0003o
ooooo`00003ooooooicooooo00000ooooooo0000o`000004o`0000?ooooo00?oV9RHob4Q8Oo^k^h0
1Oooool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@400:ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooool000002?ooool01Ol0003o
oooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo
00000?ooooooW?ooool000_ooooo00?oV9RHob4Q8Oo^k^h00oooool01Oo^k^koEEEEomgMgOmEEEGo
k^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000[ooooo00?o
0000ooooooooool06_ooool00ol0003oooooo`000008ooooo`05o`000?ooooooooooooooool00000
1oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooool00000oooooonLooooo`00
3?ooool02omgMgOoIVIVooooooooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000[ooooo1?l0000Iooooo`03o`00
0?oooooo000000Sooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooooooooooo
ool000001oooool00ol0003oooooo`00003ooooooicooooo000=ooooo`03o`000?oooooooooo00;o
k^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@
00[ooooo00?o0000ooooooooool06Oooool01?l0003oooooooooool00008ooooo`05o`000?oooooo
ooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooool00000
oooooonLooooo`002Oooool01Ol0003o^[ZjoooooonHV9So410@00kooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo0_l00005ooooo`03o`000?oooooooooo01Wo
oooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000
ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?ooooooW?ooool000Wooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c00<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP02ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool06Oooool01?l0003o
ooooooooool00008ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooo
oooo000000Oooooo00?o0000ooooool00000oooooonLooooo`00:?ooool01?l0003oooooooooool0
0004ooooo`03o`000?oooooooooo01Wooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooo
oooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo0000
0?ooooooW?ooool002Sooooo0ol00005ooooo`03o`000?oooooooooo01Wooooo00Co0000oooooooo
oooo00002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`00
0006ooooo`04o`000?ooooooooooo`000?ooooooW?ooool002Wooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0Iooooo`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooooooo
ooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool0003o
oooooicooooo000Zooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool06Oooool01?l0
003oooooooooool00008ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooo
oooooooo000000Kooooo00Co0000oooooooooooo0000oooooonLooooo`00<?ooool00ol0003ooooo
ooooo`0Iooooo`04o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000006oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0003o
oooooicooooo000`ooooo`03o`000?oooooooooo01Wooooo00Co0000oooooooooooo00002?ooool0
1Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`04ooooo`04o`000?ooooooooooo`000?ooooooW?ooool0033ooooo00?o0000ooooooooool06Ooo
ool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo0000oooooonLoooo
o`00<?ooool00ol0003oooooooooo`0Iooooo`04o`000?ooooooooooo`0000Sooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
1?l0003oooooooooool0003ooooooicooooo000`ooooo`?o00006Oooool01Ol0003ooooooooooooo
oooo000000Oooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool01?l0003oooooooooool0003ooooooicooooo000`ooooo`03o`00
0?oooooooooo01Wooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooooooooooo
ool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooo
ooooooooooooo`00003ooooooi_ooooo000`ooooo`03o`000?oooooooooo01Wooooo00Go0000oooo
ooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00003ooooooi_ooooo
000`ooooo`03o`000?oooooooooo01Wooooo00Go0000ooooooooooooooooo`000007ooooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00Go0000ooooooooooooooooo`00003ooooooi_ooooo000`ooooo`03o`000?oooooooooo01Wo
oooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00
003ooooooi_ooooo000`ooooo`03o`000?oooooooooo01Wooooo00Go0000ooooooooooooooooo`00
0007ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00003ooooooi_ooooo000`ooooo`03o`00
0?oooooooooo01Wooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooooooooooo
ool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooo
ooooooooooooo`00003ooooooi_ooooo000`ooooo`03o`000?oooooooooo01Wooooo00Go0000oooo
ooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00003ooooooi_ooooo
000`ooooo`03o`000?oooooooooo01Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00003ooooooi_ooooo000`ooooo`03o`00
0?oooooooooo01Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00Go0000ooooooooooooooooo`00003ooooooi_ooooo000`ooooo`03o`000?oooooooooo01Wo
oooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooo
ooooooooooooo`00003ooooooi_ooooo000`ooooo`03o`000?oooooooooo01Wooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00
003ooooooi_ooooo000`ooooo`?o00006Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool01Ol0003ooooooooooooooooo00000?ooooooVoooool0033ooooo00?o
0000ooooooooool06Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool01Ol0003ooooooooooooooooo00000?ooooooVoooool0033ooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool01Ol0003ooooooooooooooooo000000Oooooo0_l0003ooooooi;ooooo000`ooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000007ooooo`;o0000oooooonBooooo`00
<?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001oooool2o`000?oo
ooooT_ooool0033ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Oo
oooo0_l00004ooooo`;ok^k^0oooool2onk^kUOooooo0_o^k^h3ooooo`;ok^k^H?ooool2onk^kP?o
oooo0_o^k^i>ooooo`;ok^k^0oooool2onk^kVcooooo000`ooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00Go0000ooooooooooooooooo`000007ooooo`?o000000[o<S8bomgMgOooooook^k^oeEEEOo^k^ko
ooooonk^k_mEEEGok^k^0oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^i2
ooooo`Co000000Wo410@ooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008
oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hkooooo`Co000000?o410@ooooooooool00_oo
ool2ob4Q8@Gooooo00goA4A4o`000?l0003o<S8bomgMgOooooook^k^oeEEEOo^k^koooooonk^k_mE
EEGok^k^00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^>?ooool5o`00
00;ooooo00Ook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413ooooooooo
ooo^k^ko<S8bo`000?lb<S;ok^k^GOooool0033ooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool01Ol0003o
oooooooooooooooo000000Kooooo00Ko0000oooooooooooo0000ogMgMolb<S82ooooo`05onk^k_mE
EEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL0A?ooool00ol0003oooooooooo`02ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0
003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?Oooool00ol0003oooooooooo`04
ooooo`;o8B4Q2?ooool02OmgMgOo<S8booooooooooook^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0hooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg05gooooo000`ooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`06o`000?ooooooooooo`000?oooooo
00000oooool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooo
oooooooooa0@4014ooooo`03o`000?oooooooooo00?ooooo00?ogMgMo`000?oMgMd01oooool00ol0
003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100?Oooool00ol0003oooooooooo`0?
ooooo`07o`000?oooooooooooooooooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo
00Go410@oooooooooooooooooa0@400iooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?ogMgMo`000?oM
gMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100GOooool0033o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool01_l0003oooooooooool0003oMgMgoc8b<P;ooooo00Gok^k^
oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`000014ooooo`03o`000?oooooooooo00;ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03
o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000mooooo`03o`000?oooooooooo
00kooooo00WoMgMgoc8b<_ooooooooooonk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool00000>_ooool00onHV9So8B4Qonk^kP03ooooo`05
onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool00000GOooool0033ooooo00?o0000ooooooooool03Oooool3o`0000Sooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`03ooooo`;o000000co8B4Qo`000?lb<S;oc<c<ooooooo^
k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`000014ooooo`0;o`000?ooooooooooooooooo^k^koEEEEonk^k_ooooook^k^oeEE
EOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000?Oooool0
0ol0003oooooooooo`0;ooooo`0=o`000?lQ8B7o0000oc8b<_o<c<coooooonk^k_mEEEGok^k^oooo
ooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
000kooooo`0;ogMgMomVIVKoooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000GOooool0033ooooo00?o0000
ooooooooool03Oooool00ol0003oooooo`000008ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool2o`000003ooooool0003ooooo00;ooooo0_o^k^h3ooooo`;ok^k^1Oooool0
0ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100A?ooool01?l0003ooooooooo
ooooool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@400mooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00oooool2onk^kP?o
oooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400loooo
o`03o`000?oooooooooo00;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@
413ooooooooooooooooo410@05gooooo000`ooooo`?o00003Oooool00ol0003oooooo`000008oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool2o`000003ooooool0003ooooo
00kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000
ooooooooool0>Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`08ooooo`;o0000<oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo
0_l0000^ooooo`05o`000?nj^[[ooooooiRHV?l@41003_ooool00ol0003oooooooooo`02ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02?ooool2o`0005?ooooo000`ooooo`03o`000?oooooooooo00co
oooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo1Ol0000<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08
ooooo`03o`000?oooooooooo03Oooooo00?oEEEEofIVI_l000003Oooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01oooool01?l0003oooooooooool0000`ooooo`03oeEE
EOmVIVKo000000gooooo1?l0000<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP07ooooo`04o`000?ooooooooooo`0002gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00<
ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP07ooooo`04o`000?oo
ooooooooo`0005;ooooo000`ooooo`03o`000?oooooooooo00cooooo00Co0000oooooooooooo0000
2?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo
00006oooool4o`0000?ooooo00?o0000ooooooooool0E?ooool4o`000005ooooool0003ooooooooo
ool00000G_ooool4o`000005ooooool0003oooooooooool00000C?ooool4o`000005ooooool0003o
ooooooooool00000D_ooool0033ooooo00?o0000ooooooooool03?ooool01?l0003oooooooooool0
0008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000002;ooooo00?o0000ooooooooool0FOooool3o`0006Cooooo0ol0001Booooo`?o0000
Doooool0033ooooo00?o0000ooooooooool02oooool01Ol0003ooooooooooooooooo000000Sooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
00008?ooool01?l0003oooooooooool0001Kooooo`03o`000?oooooooooo06Cooooo00?o0000oooo
ooooool0D_ooool00ol0003oooooooooo`1Booooo`00<?ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Mooooo`Co
0000G?ooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo05;ooooo00?o0000oooooooo
ool0DOooool0033ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0oooooon>ooooo`00<?ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`04ooooo`;o0000oooooom>ooooo`03ogMgMomVIVKooooo02gooooo00?oIVIVogMgMoooool01ooo
ool0033ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooo`00003oooooodcooooo00?ogMgM
oa0@4?o^k^h0;_ooool00oo^k^ko410@omgMg@07ooooo`00<?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`04o`000?ooooooooooo`000?oooooo>_ooool2o`0000;ooooo0_l0000<ooooo`03oeEEEOnHV9So
oooo00;o00000_ooool01ol0003oooooooooool0003o410@onk^k_mEEED00_l000000om4A4Co^[Zj
ooooo`02ooooo`05oiRHV?l0003o0000odA4A?nj^[X00_ooool02?o^k^koEEEEo`000?l0003oA4A4
okZj^_oooooo410@1Ol00003ooooo`08oa0@4?lb<S;o0000o`000?l@413oZJVYohN7QomVIVH7oooo
o`00<?ooool5o`0000Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo
0?oooooo;oooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@cooooo00Go0000oooooooooooooooo
o`000002ooooo`0;o`000?ooooooooooo`000?ooooooEEEEogMgMoooooook^k^ogMgMol@41000ooo
ool01Ol@413o^[Zjonk^k_mgMgOo410@00;ooooo00KoEEEEogMgMoooooook^k^ogMgMol@4103oooo
o`03o`000?oooooooooo00Cooooo00So0000ojVYZOoooooooooookZj^_l0003ok^k^o`0000Oooooo
003oo`000;Co00003oooool01?oMgMgo0000oa0@4?o<c<`=ooooo`05oc8b<_ooooooooooooooool0
00000_ooool01_l0003oooooooooool0003oooooo`0000Sooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00Oo^[ZjohN7QomVIVKoIVIVoa0@
4?oooooo000000Oooooo000:ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02_oo
ool4o`0000;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00?ooooo0_l00005ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_oo
ool2o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`;o00001?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000000ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ol0
0004ooooo`?o00002oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool05oooool01?o^k^ko8B4Qoa0@4?o^k^h=ooooo`05oc8b<_ooooooooooooooool0
00000_ooool01Ol0003oooooooooool0003ooooo00Ko00000oooool00ol0003oooooooooo`04oooo
o`Ko00000oooool00ol0003oooooooooo`04ooooo`08oc8b<_lQ8B7oMgMgogMgMon7QhOok^k^oooo
ool00007ooooo`002_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo0_l0
0005ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool2o`0000Gooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`;o00001?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000000oooool01Ol0003ooooooooo
oooooooo000000Kooooo0ol000000ooooooo0000ooooo`0Aooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Gooooo`04ob4Q8OmgMgOoMgMgoc8b<Pgo
oooo00Go0000onk^k_ooooooooooo`000002olc<c00;o`000?nYZJWogMgMob4Q8OooooooEEEEohN7
Qoo^k^koooooohN7Qolb<S800oooool00ol0003oooooooooo`04ooooo`06oeEEEOn7QhOok^k^oooo
oon7QhOo<S8b0oooool00ol0003o<S8bomgMg@04ooooo`08o`000?nj^[[oooooonk^k_mgMgOo0000
onk^k_l00007ooooo`00<?ooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool0
00001oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000002_ooool00ol0
003oooooooooo`1Kooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool0Foooool00ol0
003oooooooooo`0Fooooo`;o00000_ooool2o`0000cooooo00koEEEEogMgMooooooo410@o`000?lQ
8B7o0000ogMgMol@413o0000ojVYZOooooook^k^oeEEE@;o000000CoA4A4onk^k_oooooo410@1Ol0
0003ooooo`06onk^k_mEEEGo0000o`000?m4A4Cok^k^0_ooool2o`000004ojVYZOlQ8B7o0000ob4Q
8@;ooooo00SoZJVYob4Q8Ol0003o0000oc8b<_l0003oMgMgoeEEE@Oooooo000`ooooo`03o`000?oo
oooooooo00Gooooo0_l000000ooooooo0000o`000007ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go
0000ooooooooooooooooo`00003ooooooe3ooooo00?ogMgMoa0@4?o^k^h04_ooool00ol0003ooooo
ooooo`0Iooooo`03onk^k_l@413ogMgM00Oooooo000`ooooo`03o`000?oooooooooo00Kooooo0ol0
0008ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00003ooooooe7ooooo
00?oMgMgofIVI_ooool04Oooool00ol0003oooooooooo`0Iooooo`03ofIVI_mgMgOooooo00Oooooo
000`ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01?l0003ooooooooo
ool0003oooooohcooooo000`ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooo
ool01?l0003oooooooooool0003oooooohcooooo000`ooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool01?l0003oooooooooool0003oooooohcooooo000`ooooo`03o`000?oo
oooooooo01;ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool2o`000?ooooooSOooool0033ooooo00?o0000ooooooooool04_oo
ool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`04ooooo`;o0000oooooon=ooooo`00<?ooool00ol0003oooooooooo`0Booooo`05o`000?oo
ooooooooooooool000001oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo
0_l0003oooooohgooooo000`ooooo`?o00004_ooool01Ol0003ooooooooooooooooo000000Oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`3ooooooi?ooooo000`ooooo`03o`000?oo
oooooooo01;ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool0
0000oooooonFooooo`00<?ooool00ol0003oooooooooo`0Booooo`05o`000?ooooooooooooooool0
00001oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool01Ol0003ooooooooooooooooo00000?ooooooU_ooool0033ooooo00?o0000oooooooo
ool04_ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00003o
oooooiKooooo000`ooooo`03o`000?oooooooooo01;ooooo00Go0000ooooooooooooooooo`000007
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`05o`000?ooooooooooooooool00000oooooonFooooo`00<?ooool00ol0003oooooooooo`0B
ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo00000?oooooo
U_ooool0033ooooo00?o0000ooooooooool04_ooool01Ol0003ooooooooooooooooo000000Oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
00Go0000ooooooooooooooooo`00003ooooooiKooooo000`ooooo`03o`000?oooooooooo01;ooooo
00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`000?ooooooU_ooool0033o
oooo00?o0000ooooooooool04_ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Co0000oooo
oooooooo0000oooooonFooooo`00<?ooool00ol0003oooooooooo`0Booooo`05o`000?oooooooooo
ooooool000001oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool01?l0003oooooooooool0003ooooooiKooooo000`ooooo`03o`000?oooooo
oooo01?ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0003ooooooiKooooo
000`ooooo`03o`000?oooooooooo01?ooooo00Co0000oooooooooooo00001oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01?l0003ooooo
ooooool0003ooooooiKooooo000`ooooo`?o00004oooool01?l0003oooooooooool00007ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`04
o`000?ooooooooooo`000?ooooooU_ooool0033ooooo00?o0000ooooooooool04oooool01?l0003o
ooooooooool00007ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`04ooooo`04o`000?ooooooooooo`000?ooooooU_ooool0033ooooo00?o0000oooo
ooooool04oooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`000?ooooooU_ooool0033ooooo00?o
0000ooooooooool04oooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`000?ooooooU_ooool0033o
oooo00?o0000ooooooooool04oooool00ol0003oooooo`000008ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`000?ooooooU_ooool0
033ooooo00?o0000ooooooooool05?ooool2o`0000Sooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`05ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo0000oooooonFooooo`00<?ooool0
0ol0003oooooooooo`0Dooooo`;o00002?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooo`00003ooooooiOooooo000`ooooo`03o`000?oooooo
oooo01Cooooo0_l00009ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooo00000?ooooooUoooool0033ooooo00?o0000ooooooooool05?ooool2o`0000Wooooo00Go
0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooool00000oooooonGooooo`00
<?ooool00ol0003oooooooooo`0Dooooo`;o00002Oooool01Ol0003ooooooooooooooooo000000Oo
oooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooo`00003ooooooiOooooo000`ooooo`03o`000?oooooooooo01oo
oooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooool00000oooooonG
ooooo`00<?ooool00ol0003oooooooooo`0Oooooo`05o`000?ooooooooooooooool000001oooool0
1Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000007ooooo`03o`00
0?oooooo00000?ooooooUoooool0033ooooo0ol0000Oooooo`05o`000?ooooooooooooooool00000
1oooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000007oooo
o`03o`000?oooooo00000?ooooooUoooool0033ooooo00?o0000ooooooooool07oooool01Ol0003o
oooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?oooooo
ooooooooool000002?ooool2o`000?ooooooUoooool0033ooooo00?o0000ooooooooool07oooool0
1Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000006ooooo`05o`00
0?ooooooooooooooool000002?ooool2o`000?ooooooUoooool0033ooooo00?o0000ooooooooool0
7oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000006oooo
o`05o`000?ooooooooooooooool000002?ooool2o`000?ooooooUoooool0033ooooo00?o0000oooo
ooooool07oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`00
0006ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooiKooooo
000`ooooo`03o`000?oooooooooo01oooooo00Go0000ooooooooooooooooo`000007ooooo`05o`00
0?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo00000?ooooooXOooool000oo
oooo0_o^k^h3ooooo`;ok^k^6_ooool00ol0003oooooooooo`0Oooooo`05o`000?oooooooooooooo
ool000001oooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`00
003ooooooj7ooooo0008ooooo`Go00000_ooool01oo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h0
0oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`03o`000?oooooo
oooo01oooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool00000
1_ooool01Ol0003ooooooooooooooooo00000?ooooooXOooool000Sooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A003ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ol0003oooooooooo`0Oooooo`05o`000?oooooo
ooooooooool000001oooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000oooooooooooo
ooooo`00003ooooooj7ooooo0009ooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?ogMgMo`000?oMgMd0
1oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41002oooool00ol0003o
ooooooooo`0Oooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo
000000Kooooo00Go0000ooooooooooooooooo`00003ooooooj7ooooo000:ooooo`03oiRHV?lQ8B7o
k^k^00?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`00000;ooooo`03o`000?oooooooooo01oooooo00Go0000oooooooooooo
ooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo
00000?ooooooXOooool000_ooooo00_oMgMgofIVI_ooooooooooonk^k_mEEEGok^k^ooooooo^k^ko
EEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000;oooo
o`Co00007_ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`00
0006ooooo`05o`000?ooooooooooooooool00000oooooonQooooo`003?ooool00ol0003ooooooooo
o`02onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooo
oa0@400;ooooo`03o`000?oooooooooo01oooooo00Go0000ooooooooooooooooo`000007ooooo`05
o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo00000?ooooooXOooool0
00Sooooo00Go0000okZj^_ooooooV9RHoa0@400>ooooo`03o`000?oooooooooo00;ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0;ooooo`03o`000?oooooooooo01oooooo00Go0000oooooooooooooooo
o`000007ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo0000
0?ooooooXOooool000Sooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00<ooooo`03oeEEEOmVIVKo0000
00Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`;o00001_ooool00ol0003oooooooooo`0O
ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Kooooo
00Go0000ooooooooooooooooo`00003ooooooj7ooooo000Wooooo`04o`000?ooooooooooo`0000Go
oooo00?o0000ooooooooool07oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooo
ooooooooooooo`000006ooooo`05o`000?ooooooooooooooool00000oooooonQooooo`009oooool0
1?l0003oooooooooool00005ooooo`03o`000?oooooooooo01oooooo00Go0000oooooooooooooooo
o`000007ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo0000
0?ooooooXOooool002Oooooo0ol00006ooooo`03o`000?oooooooooo01oooooo00Go0000oooooooo
ooooooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooo
oooo00000?ooooooXOooool002Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0O
ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo
00Co0000oooooooooooo0000oooooonQooooo`00:Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo01oooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooooooooooo
ool000001oooool01?l0003oooooooooool0003ooooooj7ooooo000`ooooo`03o`000?oooooooooo
01oooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001ooo
ool01?l0003oooooooooool0003ooooooj7ooooo000`ooooo`03o`000?oooooooooo01oooooo00Go
0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool01?l0003o
ooooooooool0003ooooooj7ooooo000`ooooo`03o`000?oooooooooo01oooooo00Co0000oooooooo
oooo00002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000oooo
oonQooooo`00<?ooool3o`0001oooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooo
oooooooo000000Oooooo00Co0000oooooooooooo0000oooooonQooooo`00<?ooool00ol0003ooooo
ooooo`0Oooooo`04o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000007oooo
o`04o`000?ooooooooooo`000?ooooooXOooool0033ooooo00?o0000ooooooooool07oooool01?l0
003oooooooooool00008ooooo`05o`000?ooooooooooooooool000001oooool01?l0003ooooooooo
ool0003ooooooj7ooooo000`ooooo`03o`000?oooooooooo01oooooo00Co0000oooooooooooo0000
2?ooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000oooooonQoooo
o`00<?ooool00ol0003oooooooooo`0Oooooo`04o`000?ooooooooooo`0000Sooooo00Go0000oooo
ooooooooooooo`000007ooooo`04o`000?ooooooooooo`000?ooooooXOooool0033ooooo00?o0000
ooooooooool07oooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool00000
1oooool01?l0003oooooooooool0003ooooooj7ooooo000`ooooo`03o`000?oooooooooo01oooooo
00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooo
oooooooo0000oooooonQooooo`00<?ooool00ol0003oooooooooo`0Oooooo`04o`000?oooooooooo
o`0000Sooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`000?oooooo
XOooool0033ooooo00?o0000ooooooooool07oooool01?l0003oooooooooool00008ooooo`05o`00
0?ooooooooooooooool000001oooool01?l0003oooooooooool0003ooooooj7ooooo000`ooooo`03
o`000?oooooooooo01oooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo
000000Oooooo00Co0000oooooooooooo0000oooooonQooooo`00<?ooool00ol0003oooooooooo`0O
ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000007ooooo`04o`00
0?ooooooooooo`000?ooooooXOooool0033ooooo00?o0000ooooooooool07oooool01?l0003ooooo
ooooool00008ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool0003o
oooooj7ooooo000`ooooo`?o00007oooool01?l0003oooooooooool00008ooooo`05o`000?oooooo
ooooooooool000001oooool01?l0003oooooooooool0003ooooooj7ooooo000`ooooo`03o`000?oo
oooooooo023ooooo00?o0000ooooool000002?ooool01Ol0003ooooooooooooooooo000000Oooooo
00?o0000ooooool00000oooooonRooooo`00<?ooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooo000000Sooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?oooooo
X_ooool0033ooooo00?o0000ooooooooool08?ooool00ol0003oooooo`000008ooooo`05o`000?oo
ooooooooooooool000001oooool00ol0003oooooo`00003ooooooj;ooooo000`ooooo`03o`000?oo
oooooooo023ooooo00?o0000ooooool000002?ooool01Ol0003ooooooooooooooooo000000Oooooo
00?o0000ooooool00000oooooonRooooo`00<?ooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooo000000Sooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?oooooo
X_ooool0033ooooo00?o0000ooooooooool08?ooool00ol0003oooooo`000008ooooo`05o`000?oo
ooooooooooooool000001oooool00ol0003oooooo`00003ooooooj;ooooo000`ooooo`03o`000?oo
oooooooo023ooooo00?o0000ooooool000002?ooool01Ol0003ooooooooooooooooo000000Oooooo
00?o0000ooooool00000oooooonRooooo`00<?ooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooo000000Sooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?oooooo
X_ooool0033ooooo00?o0000ooooooooool08?ooool00ol0003oooooo`000008ooooo`05o`000?oo
ooooooooooooool000001oooool00ol0003oooooo`00003ooooooj;ooooo000`ooooo`03o`000?oo
oooooooo023ooooo00?o0000ooooool000002?ooool01Ol0003ooooooooooooooooo000000Oooooo
00?o0000ooooool00000oooooonRooooo`00<?ooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooo000000Sooooo00Go0000ooooooooooooooooo`000008ooooo`;o0000oooooonRooooo`00<?oo
ool3o`00023ooooo00?o0000ooooool000002?ooool01Ol0003ooooooooooooooooo000000Sooooo
0_l0003ooooooj;ooooo000`ooooo`03o`000?oooooooooo023ooooo00?o0000ooooool000002?oo
ool01Ol0003ooooooooooooooooo000000Sooooo0_l0003ooooooj;ooooo000`ooooo`03o`000?oo
oooooooo023ooooo00?o0000ooooool000002?ooool01Ol0003ooooooooooooooooo000000Sooooo
0_l0003ooooooj;ooooo000`ooooo`03o`000?oooooooooo023ooooo00?o0000ooooool000002?oo
ool01?l0003oooooooooool00009ooooo`;o0000oooooonRooooo`00<?ooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooo000000Sooooo00Co0000oooooooooooo00002Oooool2o`000?oooooo
X_ooool0033ooooo00?o0000ooooooooool08?ooool00ol0003oooooo`000008ooooo`04o`000?oo
ooooooooo`0000Wooooo0_l0003ooooooj;ooooo000?ooooo`;ok^k^0oooool2onk^kQ[ooooo00?o
0000ooooooooool08Oooool2o`0000Sooooo00Co0000oooooooooooo00002Oooool2o`000?oooooo
X_ooool000[ooooo0_l000002_l@413oooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h3
ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`07ooooo`04o`000?ooooooooooo`0000Wooooo0_l0003ooooo
oj;ooooo000;ooooo`03o`000?oooooooooo00;ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06oooo
o`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool02?ooool00ol0003oooooo`000009ooooo`;o0000oooooonR
ooooo`002?ooool5o`0000Cooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@41002oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooool000002Oooool2o`000?ooooooX_ooool000Sooooo00CoA4A4omgM
gOoooooo00001?ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000000_ooooo00?o0000ooooooooool08Oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooo000000Wooooo00?o0000ooooooooool0oooooonQooooo`002?oo
ool01?oMgMgoEEEEooooool00003ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05oooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000;ooooo`Co0000:oooool0
0ol0003oooooo`00003oooooojgooooo0009ooooo`03ogMgMoo<c<co000000?ooooo0_o^k^h3oooo
o`;ok^k^1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41002oooool0
0ol0003oooooooooo`0/ooooo`03o`000?oooooo00000?oooooo[Oooool000Wooooo00?ok^k^odA4
A?l000003oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
0ol0003oooooooooo`0/ooooo`03o`000?oooooo00000?oooooo[Oooool000[ooooo00?oMgMgo`00
0?ooool03?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool2
o`0000Kooooo00?o0000ooooooooool0;?ooool00ol0003oooooo`00003oooooojgooooo000Woooo
o`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0;?ooool00ol0003oooooo`00003o
ooooojgooooo000Wooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0;?ooool0
0ol0003oooooo`00003oooooojgooooo000Wooooo`?o00001_ooool00ol0003oooooooooo`0/oooo
o`03o`000?oooooo00000?oooooo[Oooool002Sooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0/ooooo`03o`000?oooooo00000?oooooo[Oooool002Wooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooo00000?oooooo[Oooool0033ooooo00?o
0000ooooooooool0;?ooool00ol0003oooooo`00003oooooojgooooo000`ooooo`03o`000?oooooo
oooo02cooooo00?o0000ooooool00000oooooon]ooooo`00<?ooool00ol0003oooooooooo`0/oooo
o`03o`000?oooooo00000?oooooo[Oooool0033ooooo0ol0000/ooooo`03o`000?oooooo00000?oo
oooo[Oooool0033ooooo00?o0000ooooooooool0;?ooool00ol0003oooooo`00003oooooojgooooo
000`ooooo`03o`000?oooooooooo02cooooo00?o0000ooooool00000oooooon]ooooo`00<?ooool0
0ol0003oooooooooo`0/ooooo`03o`000?oooooo00000?oooooo[Oooool0033ooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooo`00003oooooojgooooo000`ooooo`03o`000?oooooooooo02co
oooo00?o0000ooooool00000oooooon]ooooo`00<?ooool00ol0003oooooooooo`0/ooooo`03o`00
0?oooooo00000?oooooo[Oooool0033ooooo00?o0000ooooooooool0;?ooool00ol0003oooooo`00
003oooooojgooooo000`ooooo`03o`000?oooooooooo02cooooo00?o0000ooooool00000oooooon]
ooooo`00<?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooo00000?oooooo[Oooool0033o
oooo00?o0000ooooooooool0;?ooool00ol0003oooooo`00003oooooojgooooo000`ooooo`03o`00
0?oooooooooo02cooooo00?o0000ooooool00000oooooon]ooooo`00<?ooool3o`0002cooooo00?o
0000ooooool00000oooooon]ooooo`00<?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooo
00000?oooooo[Oooool0033ooooo00?o0000ooooooooool0;?ooool00ol0003oooooo`00003ooooo
ojgooooo000`ooooo`03o`000?oooooooooo02cooooo0_l0003oooooojkooooo000`ooooo`03o`00
0?oooooooooo02cooooo0_l0003oooooojkooooo000`ooooo`03o`000?oooooooooo02cooooo0_l0
003oooooojkooooo000`ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0oooooon/
ooooo`00<?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo0?oooooo[?ooool0033o
oooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`3oooooojcooooo000`ooooo`03o`00
0?oooooooooo02gooooo00?o0000ooooooooool0oooooon/ooooo`00<?ooool00ol0003ooooooooo
o`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo0ol0003ooooo
omcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0
oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooo
oooo0?oooooog?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo
4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oo
ooooooooool@ooooo`00oooooooooooooa3ooooo002Pooooo`;o00001?ooool00onj^[[o<S8boooo
o`04ooooo`;o00001_ooool00ol0003o^[Zjooooo`3ooooooeOooooo002Pooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`;o<S8boooooomH
ooooo`00SOooool3o`0000;ooooo00Ko<S8boa0@4?ooooooooooonk^k_mEEED2o`000003odA4A?nj
^[[ooooo00?ooooo00?o0000ooooooooool00_ooool01OnHV9So410@o`000?l0003oZJVY00Cooooo
00?o0000ooooooooool01?ooool00on7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj
^[X02Oooool5o`0000Gooooo0_lQ8B44ooooo`Go000000Koooooolc<c?o^k^koooooonk^k_o<c<`4
ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kQ?ooooo00Ko410@oc8b<_l0
003o0000oa0@4?nYZJT2ooooo`06onk^k_mEEEGo0000o`000?m4A4Co^[Zj0oooool01OmVIVKo0000
o`000?m4A4Coc<c<0>Sooooo002>ooooo`05o`000?ooooooooooolc<c?l@41000oooool01_mEEEGo
MgMgooooooo^k^koMgMgoa0@40Cooooo00?o0000ooooooooool00_ooool01_l0003oZJVYoeEEEOnH
V9SoEEEEokZj^P?ooooo00?o0000ooooooooool01?ooool00oo<c<co0000oa0@400<ooooo`06oa0@
4?nj^[[ok^k^ogMgMol@413ooooo1_l00002ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2
ob4Q8@Cooooo00_oV9RHob4Q8Oo^k^koooooodA4A?ooooook^k^oeEEEOoMgMgoEEEEonk^kP06oooo
o`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Cooooo`06o`000?nYZJWo
oooooooooonj^[[o00000_ooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40;ooooo00KoIVIVogMg
MoooooooooooohN7Qol@413Xooooo`00S_ooool01Ol0003ooooooooooomEEEGoQhN700?ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`06oc8b<_o^k^koV9RHoeEEEOoMgMgo
410@0oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00cooooo00?oV9RHob4Q8Oo^
k^h03Oooool00onHV9So8B4Qonk^kP03ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000oooooooo
ool00_ooool01Ol@413ooooooooooooooooo410@01Cooooo00Go^[ZjohN7QomVIVKoIVIVoa0@4002
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0joooool008kooooo00Go0000oooo
oooMgMgo0000onk^kP03ooooo`Ko00001?ooool00ol0003oooooooooo`02ooooo`07okZj^_m4A4Co
c<c<ob4Q8Ooooooo410@olc<c002ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
0oooool6o`0000Cooooo00?oV9RHob4Q8Oo^k^h03Oooool02OnHV9So8B4Qonk^k_ooooook^k^oeEE
EOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
000Cooooo`06oc8b<_lQ8B7oMgMgogMgMon7QhOok^k^0_ooool6o`0000;ooooo00?o0000oooooooo
ool0joooool008kooooo0ol000000ol@413oV9RHooooo`02ooooo`06oeEEEOn7QhOok^k^oooooon7
QhOo<S8b1?ooool00ol0003oooooooooo`02ooooo`07onk^k_l0003oooooo`000?ooooooIVIVohN7
Q`02ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool03_ooool00omgMgOoIVIVoooo
o`0=ooooo`08ogMgMomVIVKoooooolc<c?o^k^koooooonk^k_o<c<`6ooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`00000Cooooo`06o`000?nj^[[oooooonk^k_mgMgOo0000
0_ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<P;ooooo00KoIVIVogMgMoooooooooooohN7Qol0
003Xooooo`00S_ooool01Ol0003oooooooooooo<c<co000000?ooooo00Kok^k^oeEEEOl0003o0000
odA4A?o^k^h4ooooo`03o`000?oooooooooo00;ooooo00CoIVIVoiRHV?oooooo<S8b0_nj^[X01?l0
003oooooooooool0000Cooooo`03oa0@4?l0003o000000?o00003_ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@00Oooooo0ol00002ooooo`?o00001?ooool01_nYZJWo8B4Qo`000?l0003o<S8bo`0000;o
oooo00Kok^k^oeEEEOl0003o0000odA4A?o^k^h2ooooo`06onk^k_mVIVKo0000o`000?m4A4Co0000
j?ooool008kooooo00Go0000ooooooooooooc<c<o`00000=ooooo`03o`000?oooooooooo00Gooooo
00?oIVIVohN7Qoooool00oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00_ooooo
00Go0000okZj^_ooooooV9RHoa0@400;ooooo`05o`000?nj^[[ooooooiRHV?l@41003?ooool00ol0
003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo0?oooooo0_ooool008gooooo1?l000000ol@413oZJVYooooo`0<oooo
o`;o00001_ooool00onYZJWoA4A4ooooo`02ooooo`;o00005Oooool00ol0003oooooooooo`0;oooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`02oooool01OnHV9So410@o`000?lQ8B7oc<c<00[ooooo00?o
EEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo1?l00002ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0ooooool2ooooo`00ooooool6ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0ooooool2ooooo`00ooooool6ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0ooooool2ooooo`00ooooool5ooooo`;o00000oooool2o`00
0?oooooo1?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?oo
ool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooo
ooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@oooo
o`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooo
oooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo
003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo0000\
\>"],
  ImageRangeCache->{{{0, 525.688}, {324.5, 0}} -> {0, -6.34248*^6, 0, 53093}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0.309017 5.42214e-08 [
[.32684 .29652 -16.5 -12.5 ]
[.32684 .29652 16.5 0 ]
[.54329 .29652 -16.5 -12.5 ]
[.54329 .29652 16.5 0 ]
[.75974 .29652 -22.5 -12.5 ]
[.75974 .29652 22.5 0 ]
[.97619 .29652 -16.5 -12.5 ]
[.97619 .29652 16.5 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 64 6 ]
[.09789 .09213 -34.5 -6.25 ]
[.09789 .09213 0 6.25 ]
[.09789 .20057 -34.5 -6.25 ]
[.09789 .20057 0 6.25 ]
[.09789 .41746 -28.5 -6.25 ]
[.09789 .41746 0 6.25 ]
[.09789 .5259 -28.5 -6.25 ]
[.09789 .5259 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -62.8125 0 ]
[.5 .63053 62.8125 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 .30902 m
.32684 .31527 L
s
gsave
.32684 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 .30902 m
.54329 .31527 L
s
gsave
.54329 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 .30902 m
.75974 .31527 L
s
gsave
.75974 .29652 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 .30902 m
.15368 .31277 L
s
.19697 .30902 m
.19697 .31277 L
s
.24026 .30902 m
.24026 .31277 L
s
.28355 .30902 m
.28355 .31277 L
s
.37013 .30902 m
.37013 .31277 L
s
.41342 .30902 m
.41342 .31277 L
s
.45671 .30902 m
.45671 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.58658 .30902 m
.58658 .31277 L
s
.62987 .30902 m
.62987 .31277 L
s
.67316 .30902 m
.67316 .31277 L
s
.71645 .30902 m
.71645 .31277 L
s
.80303 .30902 m
.80303 .31277 L
s
.84632 .30902 m
.84632 .31277 L
s
.88961 .30902 m
.88961 .31277 L
s
.9329 .30902 m
.9329 .31277 L
s
.0671 .30902 m
.0671 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09213 m
.11664 .09213 L
s
gsave
.09789 .09213 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .20057 m
.11664 .20057 L
s
gsave
.09789 .20057 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .41746 m
.11664 .41746 L
s
gsave
.09789 .41746 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .5259 m
.11664 .5259 L
s
gsave
.09789 .5259 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.11039 .11924 m
.11414 .11924 L
s
.11039 .14635 m
.11414 .14635 L
s
.11039 .17346 m
.11414 .17346 L
s
.11039 .22768 m
.11414 .22768 L
s
.11039 .2548 m
.11414 .2548 L
s
.11039 .28191 m
.11414 .28191 L
s
.11039 .33613 m
.11414 .33613 L
s
.11039 .36324 m
.11414 .36324 L
s
.11039 .39035 m
.11414 .39035 L
s
.11039 .44457 m
.11414 .44457 L
s
.11039 .47168 m
.11414 .47168 L
s
.11039 .49879 m
.11414 .49879 L
s
.11039 .06502 m
.11414 .06502 L
s
.11039 .03791 m
.11414 .03791 L
s
.11039 .0108 m
.11414 .0108 L
s
.11039 .55301 m
.11414 .55301 L
s
.11039 .58012 m
.11414 .58012 L
s
.11039 .60723 m
.11414 .60723 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -123.812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.812 moveto
(@) show
81.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.812 moveto
(D) show
93.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.4) show
135.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
141.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
153.000 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
157.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
166.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
184.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02399 .30902 L
.02418 .30902 L
.02453 .30902 L
.02474 .30902 L
.02494 .30902 L
.02532 .30902 L
.02572 .30902 L
.02608 .30902 L
.02691 .30902 L
.02769 .30902 L
.02855 .30902 L
.02945 .30902 L
.03029 .30902 L
.03192 .30902 L
.0334 .30902 L
.03493 .30902 L
.03659 .30902 L
.03985 .30902 L
.04136 .30902 L
.043 .30902 L
.04343 .30902 L
.04389 .30902 L
.04428 .30902 L
.04451 .30902 L
.04471 .30902 L
.04481 .30902 L
.04487 .30902 L
.04492 .30902 L
.04503 .30902 L
.04512 .30902 L
.04521 .30902 L
.0453 .30902 L
.04539 .30902 L
.0455 .30902 L
.0456 .30902 L
.04571 .30902 L
.04593 .30902 L
.04614 .30902 L
.04633 .30902 L
.04674 .30902 L
.04718 .30902 L
.04759 .30902 L
.04798 .30902 L
.0487 .30902 L
.04947 .30902 L
.05022 .30902 L
.05104 .30902 L
.05251 .30902 L
.05421 .30902 L
Mistroke
.05582 .30902 L
.05889 .30902 L
.06061 .30902 L
.06216 .30902 L
.06294 .30902 L
.06378 .30902 L
.06417 .30902 L
.06457 .30902 L
.06474 .30902 L
.06492 .30902 L
.06502 .30902 L
.06512 .30902 L
.06521 .30902 L
.0653 .30902 L
.06539 .30902 L
.06549 .30902 L
.06559 .30902 L
.06569 .30902 L
.06579 .30902 L
.06589 .30902 L
.06594 .30902 L
.066 .30902 L
.0661 .30902 L
.0663 .30902 L
.06649 .30902 L
.06684 .30902 L
.06725 .30902 L
.06764 .30902 L
.06806 .30902 L
.06851 .30902 L
.06927 .30902 L
.07008 .30902 L
.07155 .30902 L
.07237 .30901 L
.07325 .30901 L
.07487 .30901 L
.07814 .309 L
.07976 .30899 L
.08129 .30899 L
.082 .30898 L
.08274 .30898 L
.08314 .30898 L
.08356 .30898 L
.08375 .30898 L
.08395 .30898 L
.08413 .30898 L
.08432 .30898 L
.08442 .30898 L
.08452 .30898 L
.08463 .30898 L
Mistroke
.08469 .30898 L
.08474 .30898 L
.08484 .30898 L
.08494 .30898 L
.08504 .30898 L
.08514 .30898 L
.08525 .30898 L
.08536 .30898 L
.08557 .30898 L
.08579 .30898 L
.08603 .30898 L
.08644 .30898 L
.08687 .30898 L
.08764 .30899 L
.08841 .30899 L
.08922 .309 L
.09069 .30902 L
.09151 .30903 L
.0924 .30905 L
.09402 .30909 L
.09729 .3092 L
.09892 .30925 L
.09971 .30927 L
.10044 .30929 L
.10114 .30931 L
.10151 .30932 L
.1019 .30932 L
.10211 .30932 L
.1023 .30933 L
.10249 .30933 L
.10267 .30933 L
.10277 .30933 L
.10287 .30933 L
.10296 .30933 L
.10306 .30933 L
.10316 .30933 L
.10322 .30933 L
.10327 .30933 L
.10338 .30933 L
.10348 .30933 L
.10358 .30933 L
.10368 .30933 L
.10388 .30932 L
.10407 .30932 L
.10425 .30932 L
.10465 .30931 L
.10507 .3093 L
.10577 .30927 L
.10655 .30923 L
.10737 .30917 L
Mistroke
.10812 .30911 L
.1098 .30891 L
.11133 .30867 L
.113 .30837 L
.11456 .30805 L
.11628 .3077 L
.11707 .30756 L
.11791 .30743 L
.11832 .30737 L
.11871 .30733 L
.11908 .30729 L
.11944 .30726 L
.11963 .30725 L
.11984 .30724 L
.11993 .30723 L
.12003 .30723 L
.12012 .30723 L
.12021 .30723 L
.12031 .30722 L
.12041 .30722 L
.12051 .30722 L
.1206 .30722 L
.12065 .30723 L
.12071 .30723 L
.1208 .30723 L
.12091 .30723 L
.12103 .30724 L
.12122 .30725 L
.12139 .30726 L
.12179 .3073 L
.12214 .30734 L
.1225 .3074 L
.12327 .30757 L
.12409 .30781 L
.12486 .30812 L
.12556 .30845 L
.1271 .30938 L
.12877 .31066 L
.13205 .31362 L
.13369 .31501 L
.13448 .31557 L
.13521 .316 L
.13557 .31617 L
.13597 .31632 L
.13615 .31637 L
.13634 .31642 L
.13652 .31646 L
.13668 .31649 L
.13678 .3165 L
.13688 .31651 L
Mistroke
.13699 .31651 L
.13705 .31652 L
.13711 .31652 L
.13721 .31652 L
.1373 .31651 L
.13735 .31651 L
.13741 .3165 L
.13751 .31649 L
.1376 .31648 L
.1377 .31646 L
.1379 .31642 L
.13808 .31637 L
.13825 .3163 L
.13863 .31613 L
.13905 .31588 L
.13988 .31517 L
.14065 .31426 L
.14136 .31318 L
.14301 .30991 L
.1445 .30606 L
.14771 .29615 L
.14919 .29173 L
.15002 .28953 L
.1508 .28779 L
.15157 .28647 L
.15201 .28592 L
.1522 .28573 L
.1524 .28556 L
.1525 .28549 L
.15262 .28543 L
.15272 .28538 L
.15282 .28534 L
.15293 .28531 L
.15299 .28529 L
.15305 .28529 L
.15315 .28528 L
.15321 .28528 L
.15327 .28529 L
.15332 .28529 L
.15338 .2853 L
.15348 .28533 L
.15358 .28537 L
.15367 .28541 L
.15387 .28555 L
.15409 .28574 L
.15449 .28623 L
.15485 .28683 L
.15526 .28772 L
.15566 .28877 L
.15636 .2911 L
Mistroke
.15713 .29434 L
.15871 .30322 L
.16039 .31546 L
.16373 .34354 L
.16541 .35605 L
.16614 .36045 L
.16653 .36243 L
.16695 .36423 L
.16735 .36565 L
.16773 .36663 L
.1679 .36699 L
.168 .36715 L
.1681 .36729 L
.16819 .3674 L
.16828 .36749 L
.16837 .36756 L
.16845 .3676 L
.16855 .36763 L
.16865 .36764 L
.16875 .36762 L
.16885 .36757 L
.16894 .36751 L
.16903 .36742 L
.16922 .36717 L
.16942 .36679 L
.16964 .36624 L
.17004 .3649 L
.17043 .36313 L
.1708 .36107 L
.17164 .35491 L
.17245 .34695 L
.17333 .33637 L
.17664 .28183 L
.1783 .25115 L
.17983 .2252 L
.1806 .21426 L
.18132 .2057 L
.18172 .20179 L
.18215 .19833 L
.18254 .19591 L
.18273 .19502 L
.1829 .19434 L
.183 .19403 L
.1831 .19375 L
.18319 .19355 L
.18328 .19338 L
.18338 .19325 L
.18344 .1932 L
.18349 .19317 L
.18359 .19316 L
Mistroke
.18369 .19319 L
.18378 .19327 L
.18388 .19341 L
.18398 .1936 L
.18407 .19382 L
.18424 .19435 L
.18442 .1951 L
.18463 .19623 L
.18487 .19774 L
.18529 .20129 L
.18608 .21066 L
.18684 .22302 L
.18768 .24016 L
.18937 .2846 L
.19261 .38924 L
.1941 .43469 L
.19489 .45518 L
.19573 .47319 L
.19615 .48048 L
.19662 .48703 L
.19682 .48938 L
.19704 .49153 L
.19724 .49319 L
.19743 .49442 L
.19763 .49534 L
.19773 .4957 L
.19779 .49586 L
.19784 .49597 L
.1979 .49607 L
.19796 .49614 L
.19801 .49618 L
.19807 .49619 L
.19817 .49615 L
.19822 .49608 L
.19828 .49599 L
.19838 .49576 L
.19847 .49545 L
.19865 .49465 L
.19884 .49346 L
.19905 .49177 L
.19948 .48705 L
.19988 .48105 L
.20063 .46586 L
.20144 .44396 L
.20231 .41436 L
.20561 .26574 L
.20725 .18672 L
.20878 .12305 L
.20954 .09793 L
.21025 .07915 L
Mistroke
.21065 .0711 L
.21086 .06757 L
.21108 .06437 L
.21126 .06213 L
.21147 .06015 L
.21156 .05945 L
.21165 .0588 L
.21174 .0583 L
.21183 .05793 L
.21193 .05759 L
.21202 .05741 L
.21212 .05732 L
.21218 .05733 L
.21223 .05737 L
.21231 .05752 L
.21241 .05779 L
.21251 .05819 L
.2126 .05868 L
.21281 .06022 L
.213 .06213 L
.21344 .0682 L
.21386 .07625 L
.21431 .08748 L
.21513 .11419 L
.21672 .18544 L
.2184 .2817 L
.22001 .38083 L
.22175 .47995 L
.22256 .51914 L
.22343 .55291 L
.22416 .5745 L
.22458 .58348 L
.22497 .5896 L
.22518 .59198 L
.22537 .59359 L
.22547 .59421 L
.22559 .59471 L
.22564 .59489 L
.2257 .59503 L
.22576 .59511 L
.22581 .59514 L
.22591 .59508 L
.22601 .59489 L
.22611 .59452 L
.22617 .59425 L
.22622 .59395 L
.22642 .59245 L
.22661 .59047 L
.22698 .58498 L
.22732 .57809 L
Mistroke
.2281 .55631 L
.22888 .52619 L
.22961 .49151 L
.23127 .39473 L
.23439 .19145 L
.23521 .14471 L
.23609 .10103 L
.23693 .06833 L
.23731 .0568 L
.23771 .04661 L
.23791 .04251 L
.23811 .03883 L
.2383 .036 L
.23848 .03388 L
.23865 .03233 L
.23874 .0317 L
.23883 .03116 L
.23893 .03071 L
.23903 .03045 L
.23912 .03032 L
.23921 .03033 L
.2393 .03048 L
.23941 .0308 L
.2395 .03124 L
.23959 .03178 L
.23981 .0336 L
.24001 .03599 L
.24042 .04262 L
.24086 .05262 L
.24169 .07867 L
.24244 .10967 L
.24413 .19872 L
.24581 .30162 L
.24735 .39402 L
.24885 .46986 L
.24961 .49945 L
.25004 .51307 L
.25045 .5238 L
.25084 .53213 L
.25105 .53567 L
.25127 .53877 L
.25145 .54085 L
.25155 .54176 L
.25166 .54259 L
.25175 .54321 L
.25184 .54366 L
.25193 .54399 L
.25201 .54423 L
.25212 .54437 L
.25222 .54436 L
Mistroke
.25227 .5443 L
.25233 .54419 L
.25243 .54388 L
.25253 .54344 L
.25263 .54284 L
.25282 .5414 L
.25303 .53914 L
.25324 .53646 L
.25369 .52841 L
.2541 .51926 L
.25453 .50717 L
.25533 .48008 L
.25681 .4155 L
.25837 .33786 L
.26008 .25391 L
.26087 .22027 L
.26171 .18907 L
.2625 .16549 L
.26323 .14952 L
.26361 .14348 L
.26382 .14084 L
.26402 .13879 L
.2642 .13727 L
.2643 .13662 L
.2644 .13604 L
.26449 .13565 L
.26458 .13531 L
.26467 .13509 L
.26475 .13496 L
.26485 .13489 L
.26491 .13491 L
.26496 .13495 L
.26506 .13512 L
.26517 .13541 L
.26527 .13581 L
.26537 .1363 L
.26555 .13747 L
.26577 .13929 L
.26596 .14139 L
.26641 .14753 L
.26719 .16264 L
.26792 .18112 L
.26958 .23447 L
.27271 .34511 L
.27352 .36939 L
.27441 .39134 L
.27482 .39962 L
.27525 .40709 L
.27566 .4128 L
.27603 .41692 L
Mistroke
.27639 .41994 L
.27658 .42105 L
.27678 .42197 L
.27689 .42233 L
.27698 .42258 L
.27704 .42269 L
.2771 .42278 L
.2772 .42288 L
.2773 .4229 L
.2774 .42284 L
.27749 .42272 L
.27759 .42252 L
.27769 .42225 L
.27778 .42193 L
.27796 .42117 L
.27814 .4201 L
.27835 .41867 L
.27872 .41538 L
.27906 .41157 L
.27991 .3992 L
.28071 .38445 L
.28221 .35167 L
.2853 .28293 L
.28614 .26862 L
.28691 .25786 L
.28772 .24961 L
.28814 .24652 L
.28838 .24519 L
.2886 .24422 L
.28879 .24358 L
.28899 .24306 L
.28909 .24288 L
.28915 .2428 L
.2892 .24274 L
.28931 .24266 L
.2894 .24263 L
.28949 .24264 L
.28958 .24269 L
.28967 .24277 L
.28975 .24288 L
.28985 .24305 L
.28995 .24327 L
.29014 .2438 L
.29034 .24453 L
.29056 .24552 L
.29101 .24812 L
.29181 .25453 L
.29337 .27202 L
.29505 .29431 L
.29664 .31463 L
Mistroke
.29748 .32384 L
.29837 .33196 L
.29916 .33746 L
.29961 .33983 L
.30003 .34155 L
.30022 .34216 L
.30041 .34269 L
.30058 .34306 L
.30077 .34337 L
.30087 .34351 L
.30096 .34361 L
.30106 .34368 L
.30115 .34373 L
.30125 .34376 L
.30135 .34377 L
.30145 .34374 L
.30151 .34372 L
.30156 .34369 L
.30167 .34361 L
.30176 .34351 L
.30198 .34321 L
.30217 .34285 L
.30238 .34238 L
.30277 .34122 L
.30312 .33991 L
.30399 .3358 L
.3048 .33101 L
.3079 .30998 L
.3095 .30092 L
.31031 .29748 L
.31076 .29594 L
.31119 .29474 L
.31159 .29388 L
.31179 .29352 L
.31201 .2932 L
.3122 .29298 L
.3124 .2928 L
.31249 .29273 L
.31259 .29268 L
.31268 .29264 L
.31276 .29261 L
.31286 .29259 L
.31296 .29258 L
.31306 .29258 L
.31315 .2926 L
.31326 .29263 L
.31332 .29265 L
.31337 .29268 L
.31358 .29281 L
.31378 .29298 L
Mistroke
.314 .29321 L
.31444 .29385 L
.31526 .29551 L
.316 .29745 L
.31768 .3027 L
.31934 .308 L
.32007 .31009 L
.32087 .31209 L
.32159 .31356 L
.32236 .31477 L
.32279 .31527 L
.32318 .31562 L
.32355 .31586 L
.32374 .31595 L
.32385 .31599 L
.32395 .31602 L
.32405 .31605 L
.32415 .31607 L
.32426 .31608 L
.32431 .31608 L
.32437 .31609 L
.32447 .31609 L
.32456 .31608 L
.32461 .31608 L
.32467 .31607 L
.32477 .31605 L
.32487 .31603 L
.32496 .316 L
.32516 .31593 L
.32552 .31575 L
.32593 .31547 L
.32638 .31509 L
.3272 .31421 L
.33049 .30977 L
.33128 .30879 L
.33213 .3079 L
.33286 .30727 L
.33366 .30675 L
.33409 .30655 L
.33427 .30648 L
.33448 .30641 L
.33466 .30636 L
.33486 .30631 L
.33496 .30629 L
.33506 .30628 L
.33516 .30627 L
.33525 .30626 L
.33535 .30625 L
.33543 .30624 L
.33551 .30624 L
Mistroke
.33559 .30624 L
.33569 .30624 L
.33577 .30624 L
.33586 .30624 L
.33596 .30625 L
.33605 .30626 L
.33615 .30627 L
.33632 .30629 L
.33652 .30633 L
.33671 .30637 L
.3375 .30661 L
.33824 .30691 L
.3399 .30777 L
.34141 .30859 L
.34305 .30934 L
.34394 .30964 L
.34434 .30974 L
.34477 .30984 L
.34518 .30991 L
.34556 .30996 L
.34577 .30998 L
.34596 .31 L
.34606 .31 L
.34618 .31001 L
.34629 .31001 L
.34639 .31002 L
.34648 .31002 L
.34658 .31002 L
.34667 .31002 L
.34676 .31002 L
.34686 .31002 L
.34692 .31002 L
.34697 .31002 L
.34707 .31001 L
.34716 .31001 L
.34734 .31 L
.34754 .30999 L
.34789 .30996 L
.34827 .30992 L
.34869 .30986 L
.34954 .30972 L
.35124 .30939 L
.35279 .3091 L
.35355 .30897 L
.35439 .30886 L
.35518 .30878 L
.35556 .30875 L
.35591 .30873 L
.35628 .30871 L
.35647 .3087 L
Mistroke
.35668 .30869 L
.35686 .30869 L
.35703 .30869 L
.35713 .30868 L
.35721 .30868 L
.35731 .30868 L
.3574 .30868 L
.3575 .30868 L
.3576 .30868 L
.35766 .30868 L
.35771 .30868 L
.35782 .30868 L
.35792 .30869 L
.35801 .30869 L
.3582 .30869 L
.35841 .30869 L
.35861 .3087 L
.35906 .30872 L
.35991 .30876 L
.36071 .30881 L
.3622 .3089 L
.36368 .309 L
.36451 .30904 L
.3653 .30907 L
.36607 .30909 L
.3665 .3091 L
.3669 .30911 L
.36711 .30911 L
.36731 .30912 L
.36753 .30912 L
.36764 .30912 L
.36777 .30912 L
.36782 .30912 L
.36787 .30912 L
.36797 .30912 L
.36808 .30912 L
.36813 .30912 L
.36819 .30912 L
.36829 .30912 L
.36838 .30912 L
.36849 .30912 L
.36859 .30912 L
.36878 .30912 L
.36896 .30912 L
.36937 .30911 L
.36977 .30911 L
.3702 .3091 L
.37168 .30907 L
.37326 .30904 L
.3741 .30903 L
Mistroke
.37499 .30901 L
.37586 .309 L
.37665 .30899 L
.37703 .30899 L
.37723 .30899 L
.37744 .30899 L
.37763 .30899 L
.37783 .30899 L
.37801 .30899 L
.37819 .30899 L
.37829 .30899 L
.37834 .30899 L
.3784 .30899 L
.37849 .30899 L
.37859 .30899 L
.37865 .30899 L
.3787 .30899 L
.3788 .30899 L
.37886 .30899 L
.37891 .30899 L
.37903 .30899 L
.37913 .30899 L
.37923 .30899 L
.37941 .30899 L
.37982 .30899 L
.3802 .30899 L
.38054 .30899 L
.38132 .309 L
.38295 .30901 L
.38448 .30901 L
.38524 .30902 L
.38595 .30902 L
.38635 .30902 L
.38678 .30902 L
.38714 .30902 L
.38753 .30902 L
.38773 .30902 L
.38792 .30902 L
.38811 .30902 L
.38829 .30902 L
.38848 .30902 L
.38858 .30902 L
.38869 .30902 L
.38875 .30902 L
.38881 .30902 L
.38886 .30902 L
.38891 .30902 L
.38901 .30902 L
.38912 .30902 L
.38922 .30902 L
Mistroke
.38932 .30902 L
.38943 .30902 L
.38953 .30902 L
.38992 .30902 L
.39014 .30902 L
.39034 .30902 L
.3908 .30902 L
.39395 .30902 L
.39478 .30902 L
.39567 .30902 L
.39651 .30902 L
.39729 .30902 L
.39767 .30902 L
.39788 .30902 L
.39807 .30902 L
.39826 .30902 L
.39845 .30902 L
.39854 .30902 L
.39864 .30902 L
.39872 .30902 L
.3988 .30902 L
.39891 .30902 L
.399 .30902 L
.3991 .30902 L
.39916 .30902 L
.39921 .30902 L
.39931 .30902 L
.3994 .30902 L
.3995 .30902 L
.39959 .30902 L
.39981 .30902 L
.40001 .30902 L
.40046 .30902 L
.40124 .30902 L
.40197 .30902 L
.40363 .30902 L
.40512 .30902 L
.40597 .30902 L
.40675 .30902 L
.40714 .30902 L
.40757 .30902 L
.40779 .30902 L
.40803 .30902 L
.40823 .30902 L
.40845 .30902 L
.40855 .30902 L
.40866 .30902 L
.40877 .30902 L
.40886 .30902 L
.40892 .30902 L
Mistroke
.40897 .30902 L
.40902 .30902 L
.40908 .30902 L
.40918 .30902 L
.40924 .30902 L
.40929 .30902 L
.40939 .30902 L
.40949 .30902 L
.40957 .30902 L
.40966 .30902 L
.40987 .30902 L
.41007 .30902 L
.41047 .30902 L
.41091 .30902 L
.41171 .30902 L
.41321 .30902 L
.41478 .30902 L
.41567 .30902 L
.41609 .30902 L
.4165 .30902 L
.41688 .30902 L
.4173 .30902 L
.41768 .30902 L
.41803 .30902 L
.41822 .30902 L
.41841 .30902 L
.41851 .30902 L
.41861 .30902 L
.41866 .30902 L
.41872 .30902 L
.41882 .30902 L
.41888 .30902 L
.41894 .30902 L
.41904 .30902 L
.41909 .30902 L
.41914 .30902 L
.4192 .30902 L
.41926 .30902 L
.41936 .30902 L
.41946 .30902 L
.41967 .30902 L
.41988 .30902 L
.42007 .30902 L
.42051 .30902 L
.4213 .30902 L
.42279 .30902 L
.4243 .30902 L
.42509 .30902 L
.42593 .30902 L
.42636 .30902 L
Mistroke
.42683 .30902 L
.42726 .30902 L
.42765 .30902 L
.42787 .30902 L
.42806 .30902 L
.42824 .30902 L
.42834 .30902 L
.42844 .30902 L
.42854 .30902 L
.42863 .30902 L
.42873 .30902 L
.42879 .30902 L
.42884 .30902 L
.42895 .30902 L
.42901 .30902 L
.42906 .30902 L
.42928 .30902 L
.42938 .30902 L
.42949 .30902 L
.42968 .30902 L
.43012 .30902 L
.43092 .30902 L
.43241 .30902 L
.43401 .30902 L
.4347 .30902 L
.43546 .30902 L
.43588 .30902 L
.43626 .30902 L
.43666 .30902 L
.43703 .30902 L
.43741 .30902 L
.43762 .30902 L
.43772 .30902 L
.43784 .30902 L
.43795 .30902 L
.43806 .30902 L
.43812 .30902 L
.43817 .30902 L
.43823 .30902 L
.43829 .30902 L
.43839 .30902 L
.43849 .30902 L
.43859 .30902 L
.43865 .30902 L
.4387 .30902 L
.4389 .30902 L
.43912 .30902 L
.43952 .30902 L
.44026 .30902 L
.44194 .30902 L
Mistroke
.44282 .30902 L
.44365 .30902 L
.44446 .30902 L
.4452 .30902 L
.44594 .30902 L
.44631 .30902 L
.44672 .30902 L
.44693 .30902 L
.44712 .30902 L
.44723 .30902 L
.44735 .30902 L
.44746 .30902 L
.44756 .30902 L
.44765 .30902 L
.44774 .30902 L
.44784 .30902 L
.44794 .30902 L
.44805 .30902 L
.4481 .30902 L
.44815 .30902 L
.44835 .30902 L
.44855 .30902 L
.44877 .30902 L
.44917 .30902 L
.44992 .30902 L
.45161 .30902 L
.45317 .30902 L
.45406 .30902 L
.45449 .30902 L
.45489 .30902 L
.45527 .30902 L
.45569 .30902 L
.45587 .30902 L
.45607 .30902 L
.45625 .30902 L
.45642 .30902 L
.45663 .30902 L
.45674 .30902 L
.4568 .30902 L
.45686 .30902 L
.45697 .30902 L
.45706 .30902 L
.45712 .30902 L
.45718 .30902 L
.45728 .30902 L
.45737 .30902 L
.45747 .30902 L
.45756 .30902 L
.45765 .30902 L
.45786 .30902 L
Mistroke
.45806 .30902 L
.45846 .30902 L
.45889 .30902 L
.45968 .30902 L
.46117 .30902 L
.46275 .30902 L
.4632 .30902 L
.46363 .30902 L
.46401 .30902 L
.46443 .30902 L
.46484 .30902 L
.46522 .30902 L
.46543 .30902 L
.46562 .30902 L
.46572 .30902 L
.46584 .30902 L
.46594 .30902 L
.46604 .30902 L
.46613 .30902 L
.46622 .30902 L
.46632 .30902 L
.46642 .30902 L
.46651 .30902 L
.46661 .30902 L
.46672 .30902 L
.46681 .30902 L
.46699 .30902 L
.46716 .30902 L
.46753 .30902 L
.46833 .30902 L
.46907 .30902 L
.47074 .30902 L
.47146 .30902 L
.47224 .30902 L
.47269 .30902 L
.4731 .30902 L
.47349 .30902 L
.4739 .30902 L
.47411 .30902 L
.47431 .30902 L
.47451 .30902 L
.47469 .30902 L
.47486 .30902 L
.47504 .30902 L
.47514 .30902 L
.47523 .30902 L
.47532 .30902 L
.47543 .30902 L
.47548 .30902 L
.47554 .30902 L
Mistroke
.47564 .30902 L
.4757 .30902 L
.47575 .30902 L
.47587 .30902 L
.47598 .30902 L
.47608 .30902 L
.4763 .30902 L
.47668 .30902 L
.47709 .30902 L
.48015 .30902 L
.48096 .30902 L
.48173 .30902 L
.48215 .30902 L
.48261 .30902 L
.48303 .30902 L
.48323 .30902 L
.48341 .30902 L
.48359 .30902 L
.48379 .30902 L
.4839 .30902 L
.484 .30902 L
.4841 .30902 L
.48419 .30902 L
.48427 .30902 L
.48436 .30902 L
.48446 .30902 L
.48455 .30902 L
.48463 .30902 L
.48473 .30902 L
.48483 .30902 L
.48492 .30902 L
.48514 .30902 L
.48534 .30902 L
.48572 .30902 L
.48658 .30902 L
.48805 .30902 L
.48888 .30902 L
.48966 .30902 L
.49043 .30902 L
.49083 .30902 L
.49126 .30902 L
.49171 .30902 L
.49192 .30902 L
.49214 .30902 L
.49236 .30902 L
.49256 .30902 L
.49276 .30902 L
.49295 .30902 L
.49304 .30902 L
.49314 .30902 L
Mistroke
.49323 .30902 L
.49332 .30902 L
.49342 .30902 L
.49348 .30902 L
.49353 .30902 L
.49363 .30902 L
.49373 .30902 L
.49383 .30902 L
.49393 .30902 L
.49412 .30902 L
.49456 .30902 L
.49533 .30902 L
.49604 .30902 L
.49769 .30902 L
.49849 .30902 L
.49922 .30902 L
.49959 .30902 L
.49999 .30902 L
.50033 .30902 L
.5007 .30902 L
.5011 .30902 L
.50132 .30902 L
.50153 .30902 L
.50162 .30902 L
.50172 .30902 L
.5018 .30902 L
.50189 .30902 L
.50199 .30902 L
.50208 .30902 L
.50213 .30902 L
.50219 .30902 L
.50228 .30902 L
.50238 .30902 L
.50248 .30902 L
.50257 .30902 L
.50266 .30902 L
.50287 .30902 L
.50307 .30902 L
.50347 .30902 L
.5039 .30902 L
.50538 .30902 L
.50694 .30902 L
.50783 .30902 L
.50826 .30902 L
.50866 .30902 L
.50904 .30902 L
.50946 .30902 L
.50964 .30902 L
.50983 .30902 L
.51002 .30902 L
Mistroke
.51018 .30902 L
.5104 .30902 L
.51051 .30902 L
.51056 .30902 L
.51063 .30902 L
.51073 .30902 L
.51082 .30902 L
.51088 .30902 L
.51094 .30902 L
.51104 .30902 L
.51114 .30902 L
.51124 .30902 L
.51132 .30902 L
.51141 .30902 L
.51162 .30902 L
.51182 .30902 L
.51261 .30902 L
.51344 .30902 L
.51492 .30902 L
.51569 .30902 L
.51651 .30902 L
.51691 .30902 L
.51728 .30902 L
.51764 .30902 L
.51798 .30902 L
.51835 .30902 L
.51855 .30902 L
.51876 .30902 L
.51887 .30902 L
.51898 .30902 L
.51909 .30902 L
.51919 .30902 L
.51925 .30902 L
.5193 .30902 L
.5194 .30902 L
.51949 .30902 L
.51959 .30902 L
.51968 .30902 L
.51977 .30902 L
.51986 .30902 L
.51996 .30902 L
.52017 .30902 L
.52036 .30902 L
.52107 .30902 L
.52273 .30902 L
.52346 .30902 L
.52427 .30902 L
.52504 .30902 L
.52576 .30902 L
.52616 .30902 L
Mistroke
.52653 .30902 L
.52693 .30902 L
.52713 .30902 L
.52735 .30902 L
.52755 .30902 L
.52767 .30902 L
.52778 .30902 L
.52787 .30902 L
.52797 .30902 L
.52802 .30902 L
.52808 .30902 L
.52818 .30902 L
.52827 .30902 L
.52838 .30902 L
.52848 .30902 L
.52857 .30902 L
.52893 .30902 L
.52931 .30902 L
.52974 .30902 L
.53061 .30902 L
.53143 .30902 L
.53229 .30902 L
.53309 .30902 L
.53348 .30902 L
.53383 .30902 L
.53418 .30902 L
.53455 .30902 L
.53494 .30902 L
.53531 .30902 L
.53551 .30902 L
.53572 .30902 L
.53583 .30902 L
.53595 .30902 L
.53605 .30902 L
.53616 .30902 L
.53621 .30902 L
.53626 .30902 L
.53636 .30902 L
.53647 .30902 L
.53656 .30902 L
.53665 .30902 L
.53675 .30902 L
.53685 .30902 L
.53693 .30902 L
.53713 .30902 L
.53731 .30902 L
.53772 .30902 L
.53845 .30902 L
.5401 .30902 L
.54085 .30902 L
Mistroke
.54164 .30902 L
.54205 .30902 L
.5425 .30902 L
.54291 .30902 L
.5433 .30902 L
.54368 .30902 L
.54389 .30902 L
.54409 .30902 L
.5442 .30902 L
.5443 .30902 L
.5444 .30902 L
.54449 .30902 L
.54454 .30902 L
.5446 .30902 L
.5447 .30902 L
.54476 .30902 L
.54481 .30902 L
.54487 .30902 L
.54492 .30902 L
.54501 .30902 L
.54511 .30902 L
.5452 .30902 L
.54529 .30902 L
.54549 .30902 L
.54568 .30902 L
.54641 .30902 L
.54789 .30902 L
.54873 .30902 L
.54951 .30902 L
.55028 .30902 L
.55072 .30902 L
.55111 .30902 L
.55153 .30902 L
.55176 .30902 L
.55198 .30902 L
.55217 .30902 L
.55238 .30902 L
.55249 .30902 L
.5526 .30902 L
.55271 .30902 L
.5528 .30902 L
.55291 .30902 L
.553 .30902 L
.55309 .30902 L
.55319 .30902 L
.55329 .30902 L
.55334 .30902 L
.5534 .30902 L
.55359 .30902 L
.55378 .30902 L
Mistroke
.55397 .30902 L
.55433 .30902 L
.55599 .30902 L
.55676 .30902 L
.55758 .30902 L
.558 .30902 L
.55847 .30902 L
.55891 .30902 L
.55931 .30902 L
.55969 .30902 L
.5601 .30902 L
.56031 .30902 L
.56051 .30902 L
.56072 .30902 L
.56084 .30902 L
.5609 .30902 L
.56095 .30902 L
.56105 .30902 L
.56115 .30902 L
.56125 .30902 L
.56134 .30902 L
.56144 .30902 L
.56154 .30902 L
.56165 .30902 L
.56175 .30902 L
.56194 .30902 L
.56211 .30902 L
.5625 .30902 L
.56401 .30902 L
.56481 .30902 L
.56565 .30902 L
.56607 .30902 L
.56654 .30902 L
.56697 .30902 L
.56737 .30902 L
.56777 .30902 L
.56798 .30902 L
.5682 .30902 L
.56841 .30902 L
.5686 .30902 L
.56879 .30902 L
.56888 .30902 L
.56899 .30902 L
.56908 .30902 L
.56917 .30902 L
.56927 .30902 L
.56933 .30902 L
.56938 .30902 L
.56948 .30902 L
.56954 .30902 L
Mistroke
.56959 .30902 L
.56969 .30902 L
.5698 .30902 L
.56998 .30902 L
.57015 .30902 L
.57054 .30902 L
.57221 .30902 L
.57371 .30902 L
.57412 .30902 L
.57455 .30902 L
.57493 .30902 L
.57533 .30902 L
.57557 .30902 L
.57579 .30902 L
.576 .30902 L
.57623 .30902 L
.57642 .30902 L
.57662 .30902 L
.57673 .30902 L
.57683 .30902 L
.57693 .30902 L
.57703 .30902 L
.57713 .30902 L
.57719 .30902 L
.57724 .30902 L
.57733 .30902 L
.57743 .30902 L
.57749 .30902 L
.57755 .30902 L
.5776 .30902 L
.57766 .30902 L
.57776 .30902 L
.57786 .30902 L
.57808 .30902 L
.57827 .30902 L
.57865 .30902 L
.58012 .30902 L
.58096 .30902 L
.58174 .30902 L
.58251 .30902 L
.58295 .30902 L
.58334 .30902 L
.58376 .30902 L
.58399 .30902 L
.58421 .30902 L
.5844 .30902 L
.58461 .30902 L
.58471 .30902 L
.58483 .30902 L
.58493 .30902 L
Mistroke
.58503 .30902 L
.58513 .30902 L
.58523 .30902 L
.58532 .30902 L
.58541 .30902 L
.58552 .30902 L
.58557 .30902 L
.58562 .30902 L
.58582 .30902 L
.586 .30902 L
.5862 .30902 L
.58655 .30902 L
.58821 .30902 L
.58903 .30902 L
.58991 .30902 L
.59032 .30902 L
.59075 .30902 L
.59116 .30902 L
.59153 .30902 L
.59192 .30902 L
.59211 .30902 L
.59233 .30902 L
.59252 .30902 L
.59262 .30902 L
.59271 .30902 L
.5928 .30902 L
.5929 .30902 L
.59299 .30902 L
.59307 .30902 L
.59317 .30902 L
.59327 .30902 L
.59337 .30902 L
.59346 .30902 L
.59356 .30902 L
.59367 .30902 L
.59388 .30902 L
.59433 .30902 L
.59474 .30902 L
.59625 .30902 L
.59704 .30902 L
.59788 .30902 L
.59831 .30902 L
.59878 .30902 L
.5992 .30902 L
.5996 .30902 L
.59981 .30902 L
.60001 .30902 L
.60019 .30902 L
.60038 .30902 L
.60048 .30902 L
Mistroke
.60059 .30902 L
.60065 .30902 L
.60071 .30902 L
.60076 .30902 L
.60081 .30902 L
.60092 .30902 L
.60097 .30902 L
.60102 .30902 L
.60112 .30902 L
.60122 .30902 L
.60132 .30902 L
.60142 .30902 L
.60164 .30902 L
.60204 .30902 L
.60293 .30902 L
.60377 .30902 L
.60454 .30902 L
.60529 .30902 L
.6061 .30902 L
.60655 .30902 L
.60696 .30902 L
.60736 .30902 L
.60758 .30902 L
.60778 .30902 L
.60797 .30902 L
.60817 .30902 L
.60827 .30902 L
.60833 .30902 L
.60839 .30902 L
.60849 .30902 L
.60858 .30902 L
.60867 .30902 L
.60877 .30902 L
.60885 .30902 L
.60894 .30902 L
.60904 .30902 L
.60914 .30902 L
.60933 .30902 L
.60953 .30902 L
.60975 .30902 L
.6102 .30902 L
.611 .30902 L
.61187 .30902 L
.6127 .30902 L
.61345 .30902 L
.61387 .30902 L
.61425 .30902 L
.61463 .30902 L
.61498 .30902 L
.61518 .30902 L
Mistroke
.61536 .30902 L
.61558 .30902 L
.61568 .30902 L
.61578 .30902 L
.61587 .30902 L
.61597 .30902 L
.61603 .30902 L
.61608 .30902 L
.61618 .30902 L
.61626 .30902 L
.61636 .30902 L
.61646 .30902 L
.61655 .30902 L
.6166 .30902 L
.61666 .30902 L
.61676 .30902 L
.61695 .30902 L
.61718 .30902 L
.61739 .30902 L
.61902 .30902 L
.61982 .30902 L
.62055 .30902 L
.6209 .30902 L
.6213 .30902 L
.62167 .30902 L
.62201 .30902 L
.6224 .30902 L
.62262 .30902 L
.62282 .30902 L
.623 .30902 L
.62319 .30902 L
.62329 .30902 L
.62339 .30902 L
.62348 .30902 L
.62358 .30902 L
.62369 .30902 L
.62378 .30902 L
.62389 .30902 L
.62395 .30902 L
.624 .30902 L
.6241 .30902 L
.62419 .30902 L
.62429 .30902 L
.6244 .30902 L
.62458 .30902 L
.62476 .30902 L
.62515 .30902 L
.62682 .30902 L
.62767 .30902 L
.62847 .30902 L
Mistroke
.62918 .30902 L
.62958 .30902 L
.62996 .30902 L
.63033 .30902 L
.63054 .30902 L
.63073 .30902 L
.63091 .30902 L
.63101 .30902 L
.63111 .30902 L
.6312 .30902 L
.63128 .30902 L
.63137 .30902 L
.63146 .30902 L
.63156 .30902 L
.63166 .30902 L
.63172 .30902 L
.63177 .30902 L
.63188 .30902 L
.63208 .30902 L
.63226 .30902 L
.6327 .30902 L
.63312 .30902 L
.63458 .30902 L
.63542 .30902 L
.63582 .30902 L
.6362 .30902 L
.63656 .30902 L
.63696 .30902 L
.63736 .30902 L
.63758 .30902 L
.63779 .30902 L
.63801 .30902 L
.63821 .30902 L
.6384 .30902 L
.63851 .30902 L
.6386 .30902 L
.63871 .30902 L
.6388 .30902 L
.63886 .30902 L
.63891 .30902 L
.63897 .30902 L
.63903 .30902 L
.63908 .30902 L
.63914 .30902 L
.63924 .30902 L
.6393 .30902 L
.63935 .30902 L
.63947 .30902 L
.63967 .30902 L
.63985 .30902 L
Mistroke
.64026 .30902 L
.64109 .30902 L
.64258 .30902 L
.64298 .30902 L
.64342 .30902 L
.6438 .30902 L
.64421 .30902 L
.64458 .30902 L
.64478 .30902 L
.64499 .30902 L
.64518 .30902 L
.64536 .30902 L
.64554 .30902 L
.64571 .30902 L
.6458 .30902 L
.64591 .30902 L
.646 .30902 L
.64609 .30902 L
.64618 .30902 L
.64629 .30902 L
.64634 .30902 L
.64639 .30902 L
.6465 .30902 L
.64659 .30902 L
.64669 .30902 L
.64679 .30902 L
.64688 .30902 L
.64723 .30902 L
.64761 .30902 L
.64804 .30902 L
.64889 .30902 L
.64965 .30902 L
.65045 .30902 L
.65086 .30902 L
.65132 .30902 L
.65173 .30902 L
.65212 .30902 L
.65252 .30902 L
.65275 .30902 L
.65296 .30902 L
.65315 .30902 L
.65325 .30902 L
.65335 .30902 L
.65345 .30902 L
.65355 .30902 L
.6536 .30902 L
.65366 .30902 L
.65376 .30902 L
.65386 .30902 L
.65396 .30902 L
Mistroke
.65404 .30902 L
.65414 .30902 L
.65434 .30902 L
.65454 .30902 L
.65525 .30902 L
.65605 .30902 L
.6569 .30902 L
.65763 .30902 L
.65843 .30902 L
.65885 .30902 L
.65925 .30902 L
.65963 .30902 L
.65982 .30902 L
.66003 .30902 L
.66021 .30902 L
.66039 .30902 L
.66058 .30902 L
.66067 .30902 L
.66078 .30902 L
.66087 .30902 L
.66095 .30902 L
.66105 .30902 L
.66114 .30902 L
.66123 .30902 L
.6613 .30902 L
.66139 .30902 L
.66148 .30902 L
.66168 .30902 L
.66188 .30902 L
.66224 .30902 L
.66305 .30902 L
.66453 .30902 L
.6653 .30902 L
.66569 .30902 L
.66612 .30902 L
.66649 .30902 L
.66668 .30902 L
.66688 .30902 L
.66706 .30902 L
.66726 .30902 L
.66743 .30902 L
.6676 .30902 L
.6677 .30902 L
.66781 .30902 L
.6679 .30902 L
.668 .30902 L
.66806 .30902 L
.66811 .30902 L
.66817 .30902 L
.66823 .30902 L
Mistroke
.66833 .30902 L
.66839 .30902 L
.66844 .30902 L
.66855 .30902 L
.66864 .30902 L
.66883 .30902 L
.66903 .30902 L
.66924 .30902 L
.67073 .30902 L
.67156 .30902 L
.67233 .30902 L
.67272 .30902 L
.67314 .30902 L
.6736 .30902 L
.6738 .30902 L
.67402 .30902 L
.67421 .30902 L
.67441 .30902 L
.67462 .30902 L
.67472 .30902 L
.67482 .30902 L
.67491 .30902 L
.67501 .30902 L
.67511 .30902 L
.6752 .30902 L
.6753 .30902 L
.67539 .30902 L
.67547 .30902 L
.67556 .30902 L
.67566 .30902 L
.67576 .30902 L
.67586 .30902 L
.67598 .30902 L
.67642 .30902 L
.67722 .30902 L
.67881 .30902 L
.67924 .30902 L
.67971 .30902 L
.68014 .30902 L
.68054 .30902 L
.68095 .30902 L
.68117 .30902 L
.6814 .30902 L
.6816 .30902 L
.68179 .30902 L
.682 .30902 L
.68211 .30902 L
.68221 .30902 L
.68231 .30902 L
.68241 .30902 L
Mistroke
.68249 .30902 L
.68259 .30902 L
.68269 .30902 L
.68275 .30902 L
.6828 .30902 L
.6829 .30902 L
.68299 .30902 L
.68318 .30902 L
.68335 .30902 L
.68373 .30902 L
.68524 .30902 L
.68603 .30902 L
.68687 .30902 L
.6873 .30902 L
.68777 .30902 L
.68797 .30902 L
.68819 .30902 L
.6884 .30902 L
.68859 .30902 L
.6888 .30902 L
.68891 .30902 L
.68902 .30902 L
.68912 .30902 L
.68922 .30902 L
.68928 .30902 L
.68933 .30902 L
.68944 .30902 L
.68953 .30902 L
.68962 .30902 L
.68971 .30902 L
.68981 .30902 L
.68986 .30902 L
.68992 .30902 L
.69002 .30902 L
.69021 .30902 L
.6904 .30902 L
.6906 .30902 L
.69097 .30902 L
.6918 .30902 L
.69268 .30902 L
.69349 .30902 L
.69389 .30902 L
.6943 .30902 L
.69477 .30902 L
.69499 .30902 L
.69519 .30902 L
.69538 .30902 L
.69559 .30902 L
.6958 .30902 L
.69592 .30902 L
Mistroke
.69602 .30902 L
.69612 .30902 L
.69622 .30902 L
.69633 .30902 L
.69643 .30902 L
.69652 .30902 L
.69662 .30902 L
.69671 .30902 L
.6968 .30902 L
.6969 .30902 L
.69699 .30902 L
.69709 .30902 L
.6972 .30902 L
.69762 .30902 L
.69836 .30902 L
.69923 .30902 L
.70003 .30902 L
.70086 .30902 L
.70129 .30902 L
.70175 .30902 L
.70194 .30902 L
.70215 .30902 L
.70233 .30902 L
.70252 .30902 L
.70275 .30902 L
.70285 .30902 L
.70296 .30902 L
.70306 .30902 L
.70317 .30902 L
.70327 .30902 L
.70337 .30902 L
.70346 .30902 L
.70356 .30902 L
.70366 .30902 L
.70374 .30902 L
.70385 .30902 L
.7039 .30902 L
.70396 .30902 L
.70416 .30902 L
.70435 .30902 L
.70456 .30902 L
.70499 .30902 L
.70647 .30902 L
.70728 .30902 L
.70803 .30902 L
.70844 .30902 L
.70866 .30902 L
.70889 .30902 L
.70911 .30902 L
.70931 .30902 L
Mistroke
.7095 .30902 L
.70971 .30902 L
.7098 .30902 L
.70991 .30902 L
.71 .30902 L
.7101 .30902 L
.71021 .30902 L
.71031 .30902 L
.71042 .30902 L
.71051 .30902 L
.7106 .30902 L
.71068 .30902 L
.71077 .30902 L
.71087 .30902 L
.71097 .30902 L
.71107 .30902 L
.71125 .30902 L
.71166 .30902 L
.71205 .30902 L
.71292 .30902 L
.71377 .30902 L
.71418 .30902 L
.71456 .30902 L
.71491 .30902 L
.71528 .30902 L
.71566 .30902 L
.71606 .30902 L
.71626 .30902 L
.71648 .30902 L
.71668 .30902 L
.71678 .30902 L
.71687 .30902 L
.71696 .30902 L
.71706 .30902 L
.71715 .30902 L
.71723 .30902 L
.71732 .30902 L
.71742 .30902 L
.71752 .30902 L
.71762 .30902 L
.71772 .30902 L
.71784 .30902 L
.71804 .30902 L
.71843 .30902 L
.7193 .30902 L
.72005 .30902 L
.72085 .30902 L
.72132 .30902 L
.72174 .30902 L
.72217 .30902 L
Mistroke
.72257 .30902 L
.72295 .30902 L
.72316 .30902 L
.72336 .30902 L
.72354 .30902 L
.72363 .30902 L
.72373 .30902 L
.72382 .30902 L
.72391 .30902 L
.724 .30902 L
.72408 .30902 L
.72418 .30902 L
.72424 .30902 L
.7243 .30902 L
.72439 .30902 L
.7245 .30902 L
.72459 .30902 L
.72468 .30902 L
.72488 .30902 L
.72529 .30902 L
.72573 .30902 L
.72731 .30902 L
.72774 .30902 L
.7282 .30902 L
.72863 .30902 L
.72903 .30902 L
.72923 .30902 L
.72944 .30902 L
.72981 .30902 L
.73002 .30902 L
.73022 .30902 L
.73043 .30902 L
.73056 .30902 L
.73067 .30902 L
.73076 .30902 L
.73086 .30902 L
.73096 .30902 L
.73104 .30902 L
.73115 .30902 L
.7312 .30902 L
.73126 .30902 L
.73135 .30902 L
.73146 .30902 L
.73164 .30902 L
.73182 .30902 L
.73221 .30902 L
.73371 .30902 L
.73412 .30902 L
.73455 .30902 L
.73493 .30902 L
Mistroke
.73533 .30902 L
.73575 .30902 L
.73615 .30902 L
.73637 .30902 L
.73661 .30902 L
.73682 .30902 L
.73693 .30902 L
.73704 .30902 L
.73714 .30902 L
.73725 .30902 L
.73735 .30902 L
.73745 .30902 L
.73755 .30902 L
.7376 .30902 L
.73766 .30902 L
.73771 .30902 L
.73776 .30902 L
.73782 .30902 L
.73788 .30902 L
.73797 .30902 L
.73807 .30902 L
.73817 .30902 L
.73825 .30902 L
.73866 .30902 L
.74034 .30902 L
.74107 .30902 L
.74146 .30902 L
.74188 .30902 L
.74229 .30902 L
.74266 .30902 L
.74284 .30902 L
.74304 .30902 L
.74339 .30902 L
.74358 .30902 L
.74379 .30902 L
.7439 .30902 L
.74401 .30902 L
.74412 .30902 L
.74422 .30902 L
.74431 .30902 L
.7444 .30902 L
.7445 .30902 L
.74461 .30902 L
.74471 .30902 L
.7448 .30902 L
.74498 .30902 L
.74517 .30902 L
.74535 .30902 L
.74576 .30902 L
.74659 .30902 L
Mistroke
.7473 .30902 L
.74807 .30902 L
.74851 .30902 L
.74891 .30902 L
.7493 .30902 L
.7495 .30902 L
.74971 .30902 L
.7499 .30902 L
.75007 .30902 L
.75025 .30902 L
.75042 .30902 L
.7506 .30902 L
.75069 .30902 L
.7508 .30902 L
.75085 .30902 L
.7509 .30902 L
.75101 .30902 L
.75111 .30902 L
.7512 .30902 L
.7513 .30902 L
.75139 .30902 L
.75148 .30902 L
.75157 .30902 L
.75198 .30902 L
.7527 .30902 L
.75357 .30902 L
.75436 .30902 L
.75475 .30902 L
.75517 .30902 L
.75557 .30902 L
.75594 .30902 L
.75633 .30902 L
.75655 .30902 L
.75676 .30902 L
.75687 .30902 L
.75698 .30902 L
.75718 .30902 L
.75729 .30902 L
.75739 .30902 L
.75745 .30902 L
.75751 .30902 L
.75757 .30902 L
.75763 .30902 L
.75772 .30902 L
.75782 .30902 L
.75792 .30902 L
.758 .30902 L
.75811 .30902 L
.75822 .30902 L
.75842 .30902 L
Mistroke
.75925 .30902 L
.76074 .30902 L
.7615 .30902 L
.76193 .30902 L
.76233 .30902 L
.76255 .30902 L
.76276 .30902 L
.76295 .30902 L
.76315 .30902 L
.76337 .30902 L
.76357 .30902 L
.76368 .30902 L
.76378 .30902 L
.7639 .30902 L
.76396 .30902 L
.76402 .30902 L
.76413 .30902 L
.76422 .30902 L
.76431 .30902 L
.7644 .30902 L
.76451 .30902 L
.76456 .30902 L
.76461 .30902 L
.76481 .30902 L
.76499 .30902 L
.76519 .30902 L
.76554 .30902 L
.7672 .30902 L
.76801 .30902 L
.76847 .30902 L
.7689 .30902 L
.76911 .30902 L
.76931 .30902 L
.76949 .30902 L
.76968 .30902 L
.76989 .30902 L
.77008 .30902 L
.77019 .30902 L
.77029 .30902 L
.77039 .30902 L
.77046 .30902 L
.77051 .30902 L
.77061 .30902 L
.77066 .30902 L
.77072 .30902 L
.77077 .30902 L
.77083 .30902 L
.77094 .30902 L
.77103 .30902 L
.77112 .30902 L
Mistroke
.77133 .30902 L
.77155 .30902 L
.77176 .30902 L
.77222 .30902 L
.77306 .30902 L
.77383 .30902 L
.77458 .30902 L
.77496 .30902 L
.77537 .30902 L
.77579 .30902 L
.77602 .30902 L
.77624 .30902 L
.77643 .30902 L
.77654 .30902 L
.77665 .30902 L
.77676 .30902 L
.77685 .30902 L
.77695 .30902 L
.77704 .30902 L
.77714 .30902 L
.77724 .30902 L
.77733 .30902 L
.77742 .30902 L
.77752 .30902 L
.77758 .30902 L
.77763 .30902 L
.77783 .30902 L
.77823 .30902 L
.77866 .30902 L
.78014 .30902 L
.7809 .30902 L
.78132 .30902 L
.78171 .30902 L
.78207 .30902 L
.78227 .30902 L
.78246 .30902 L
.78264 .30902 L
.78281 .30902 L
.783 .30902 L
.78318 .30902 L
.78327 .30902 L
.78337 .30902 L
.78347 .30902 L
.78355 .30902 L
.78365 .30902 L
.78371 .30902 L
.78376 .30902 L
.78386 .30902 L
.78396 .30902 L
.78406 .30902 L
Mistroke
.78416 .30902 L
.78436 .30902 L
.78479 .30902 L
.78627 .30902 L
.78704 .30902 L
.78747 .30902 L
.78788 .30902 L
.7881 .30902 L
.78831 .30902 L
.7887 .30902 L
.78892 .30902 L
.78912 .30902 L
.78934 .30902 L
.78945 .30902 L
.78957 .30902 L
.78968 .30902 L
.78977 .30902 L
.78988 .30902 L
.78994 .30902 L
.78999 .30902 L
.79009 .30902 L
.79014 .30902 L
.7902 .30902 L
.79029 .30902 L
.79039 .30902 L
.79048 .30902 L
.79057 .30902 L
.79074 .30902 L
.79113 .30902 L
.79281 .30902 L
.79363 .30902 L
.79409 .30902 L
.79452 .30902 L
.79489 .30902 L
.7951 .30902 L
.7953 .30902 L
.79551 .30902 L
.7957 .30902 L
.79591 .30902 L
.79602 .30902 L
.79607 .30902 L
.79613 .30902 L
.79618 .30902 L
.79624 .30902 L
.79634 .30902 L
.79639 .30902 L
.79645 .30902 L
.79651 .30902 L
.79656 .30902 L
.79666 .30902 L
Mistroke
.79671 .30902 L
.79676 .30902 L
.79696 .30902 L
.79713 .30902 L
.79732 .30902 L
.79771 .30902 L
.79859 .30902 L
.79939 .30902 L
.80015 .30902 L
.80053 .30902 L
.80094 .30902 L
.80116 .30902 L
.80136 .30902 L
.80157 .30902 L
.80181 .30902 L
.80191 .30902 L
.80202 .30902 L
.80213 .30902 L
.80222 .30902 L
.80232 .30902 L
.80241 .30902 L
.80251 .30902 L
.80256 .30902 L
.80261 .30902 L
.80271 .30902 L
.80277 .30902 L
.80282 .30902 L
.80292 .30902 L
.80302 .30902 L
.80311 .30902 L
.80319 .30902 L
.80338 .30902 L
.80378 .30902 L
.8042 .30902 L
.80497 .30902 L
.80568 .30902 L
.80607 .30902 L
.8065 .30902 L
.80693 .30902 L
.80717 .30902 L
.80739 .30902 L
.80779 .30902 L
.808 .30902 L
.80822 .30902 L
.80831 .30902 L
.80841 .30902 L
.8085 .30902 L
.80859 .30902 L
.8087 .30902 L
.80881 .30902 L
Mistroke
.80891 .30902 L
.809 .30902 L
.8091 .30902 L
.8092 .30902 L
.80928 .30902 L
.80938 .30902 L
.80948 .30902 L
.80959 .30902 L
.80978 .30902 L
.81051 .30902 L
.81137 .30902 L
.81216 .30902 L
.81257 .30902 L
.81299 .30902 L
.81342 .30902 L
.81366 .30902 L
.81389 .30902 L
.8141 .30902 L
.8143 .30902 L
.81447 .30902 L
.81467 .30902 L
.81477 .30902 L
.81488 .30902 L
.81494 .30902 L
.815 .30902 L
.81505 .30902 L
.8151 .30902 L
.81521 .30902 L
.81526 .30902 L
.81531 .30902 L
.81541 .30902 L
.81551 .30902 L
.81561 .30902 L
.81571 .30902 L
.81594 .30902 L
.81633 .30902 L
.81722 .30902 L
.81807 .30902 L
.81884 .30902 L
.81923 .30902 L
.81964 .30902 L
.81984 .30902 L
.82004 .30902 L
.82023 .30902 L
.82041 .30902 L
.8206 .30902 L
.82071 .30902 L
.82082 .30902 L
.82101 .30902 L
.82111 .30902 L
Mistroke
.8212 .30902 L
.82126 .30902 L
.82132 .30902 L
.82137 .30902 L
.82143 .30902 L
.82152 .30902 L
.82163 .30902 L
.82168 .30902 L
.82174 .30902 L
.82185 .30902 L
.82197 .30902 L
.82208 .30902 L
.82374 .30902 L
.82454 .30902 L
.82527 .30902 L
.82564 .30902 L
.82583 .30902 L
.82604 .30902 L
.82622 .30902 L
.82641 .30902 L
.82659 .30902 L
.82676 .30902 L
.82697 .30902 L
.82715 .30902 L
.82726 .30902 L
.82736 .30902 L
.82741 .30902 L
.82746 .30902 L
.82752 .30902 L
.82758 .30902 L
.82767 .30902 L
.82777 .30902 L
.82785 .30902 L
.82794 .30902 L
.82804 .30902 L
.82815 .30902 L
.82834 .30902 L
.82994 .30902 L
.83038 .30902 L
.83084 .30902 L
.83124 .30902 L
.83167 .30902 L
.83189 .30902 L
.83209 .30902 L
.83228 .30902 L
.83246 .30902 L
.83265 .30902 L
.83282 .30902 L
.833 .30902 L
.8332 .30902 L
Mistroke
.83331 .30902 L
.83342 .30902 L
.83352 .30902 L
.83362 .30902 L
.83368 .30902 L
.83373 .30902 L
.83379 .30902 L
.83385 .30902 L
.83396 .30902 L
.83402 .30902 L
.83407 .30902 L
.83417 .30902 L
.83426 .30902 L
.83447 .30902 L
.83488 .30902 L
.83637 .30902 L
.83678 .30902 L
.83721 .30902 L
.83762 .30902 L
.838 .30902 L
.83842 .30902 L
.83865 .30902 L
.83887 .30902 L
.83906 .30902 L
.83927 .30902 L
.83937 .30902 L
.83949 .30902 L
.83959 .30902 L
.83969 .30902 L
.83979 .30902 L
.8399 .30902 L
.83999 .30902 L
.84009 .30902 L
.84014 .30902 L
.8402 .30902 L
.84031 .30902 L
.84041 .30902 L
.84052 .30902 L
.8413 .30902 L
.84213 .30902 L
.84291 .30902 L
.84325 .30902 L
.84361 .30902 L
.844 .30902 L
.84436 .30902 L
.84455 .30902 L
.84475 .30902 L
.84492 .30902 L
.84511 .30902 L
.84523 .30902 L
Mistroke
.84533 .30902 L
.84544 .30902 L
.84554 .30902 L
.84564 .30902 L
.84573 .30902 L
.84583 .30902 L
.84594 .30902 L
.84604 .30902 L
.84614 .30902 L
.8462 .30902 L
.84625 .30902 L
.84636 .30902 L
.84647 .30902 L
.84659 .30902 L
.84681 .30902 L
.84762 .30902 L
.84844 .30902 L
.84921 .30902 L
.84959 .30902 L
.85001 .30902 L
.85024 .30902 L
.85047 .30902 L
.85069 .30902 L
.85089 .30902 L
.85109 .30902 L
.8513 .30902 L
.85139 .30902 L
.85149 .30902 L
.85158 .30902 L
.85166 .30902 L
.85176 .30902 L
.85186 .30902 L
.85196 .30902 L
.85205 .30902 L
.8521 .30902 L
.85216 .30902 L
.85226 .30902 L
.85231 .30902 L
.85236 .30902 L
.85248 .30902 L
.85266 .30902 L
.85285 .30902 L
.85319 .30902 L
.85396 .30902 L
.85472 .30902 L
.85514 .30902 L
.85554 .30902 L
.85591 .30902 L
.85631 .30902 L
.85649 .30902 L
Mistroke
.85668 .30902 L
.85684 .30902 L
.85701 .30902 L
.85722 .30902 L
.85731 .30902 L
.85741 .30902 L
.85751 .30902 L
.85759 .30902 L
.85768 .30902 L
.85777 .30902 L
.85787 .30902 L
.85797 .30902 L
.85807 .30902 L
.85813 .30902 L
.85819 .30902 L
.85829 .30902 L
.85838 .30902 L
.85848 .30902 L
.85858 .30902 L
.85895 .30902 L
.85929 .30902 L
.86005 .30902 L
.86077 .30902 L
.86115 .30902 L
.86155 .30902 L
.86199 .30902 L
.86221 .30902 L
.8624 .30902 L
.86279 .30902 L
.86299 .30902 L
.8632 .30902 L
.86341 .30902 L
.86352 .30902 L
.86363 .30902 L
.86373 .30902 L
.86384 .30902 L
.86394 .30902 L
.86403 .30902 L
.86408 .30902 L
.86414 .30902 L
.86424 .30902 L
.86431 .30902 L
.86437 .30902 L
.86448 .30902 L
.86469 .30902 L
.86492 .30902 L
.86569 .30902 L
.86654 .30902 L
.86694 .30902 L
.86737 .30902 L
Mistroke
.86777 .30902 L
.86814 .30902 L
.86856 .30902 L
.86879 .30902 L
.86901 .30902 L
.8692 .30902 L
.86941 .30902 L
.86951 .30902 L
.86963 .30902 L
.86968 .30902 L
.86973 .30902 L
.86983 .30902 L
.86993 .30902 L
.86999 .30902 L
.87004 .30902 L
.87013 .30902 L
.87023 .30902 L
.87032 .30902 L
.87041 .30902 L
.8706 .30902 L
.871 .30902 L
.87142 .30902 L
.87219 .30902 L
.8729 .30902 L
.87329 .30902 L
.87371 .30902 L
.87413 .30902 L
.87437 .30902 L
.8746 .30902 L
.8748 .30902 L
.875 .30902 L
.87518 .30902 L
.87538 .30902 L
.87549 .30902 L
.87559 .30902 L
.87564 .30902 L
.8757 .30902 L
.87576 .30902 L
.87581 .30902 L
.8759 .30902 L
.87601 .30902 L
.87606 .30902 L
.87611 .30902 L
.87621 .30902 L
.87632 .30902 L
.87642 .30902 L
.87664 .30902 L
.87703 .30902 L
.87791 .30902 L
.87832 .30902 L
Mistroke
.87875 .30902 L
.87915 .30902 L
.87953 .30902 L
.87988 .30902 L
.88026 .30902 L
.88048 .30902 L
.88069 .30902 L
.88087 .30902 L
.88098 .30902 L
.88107 .30902 L
.88127 .30902 L
.88138 .30902 L
.88143 .30902 L
.88149 .30902 L
.88155 .30902 L
.88161 .30902 L
.88167 .30902 L
.88173 .30902 L
.88178 .30902 L
.88184 .30902 L
.88194 .30902 L
.88204 .30902 L
.88214 .30902 L
.88233 .30902 L
.88253 .30902 L
.88274 .30902 L
.88361 .30902 L
.88444 .30902 L
.8848 .30902 L
.88518 .30902 L
.8856 .30902 L
.88598 .30902 L
.8862 .30902 L
.88639 .30902 L
.8866 .30902 L
.88683 .30902 L
.88692 .30902 L
.88702 .30902 L
.88711 .30902 L
.88721 .30902 L
.88727 .30902 L
.88732 .30902 L
.88742 .30902 L
.88752 .30902 L
.88762 .30902 L
.88771 .30902 L
.8878 .30902 L
.88789 .30902 L
.88799 .30902 L
.88815 .30902 L
Mistroke
.88833 .30902 L
.8891 .30902 L
.88992 .30902 L
.89068 .30902 L
.89111 .30902 L
.89133 .30902 L
.89157 .30902 L
.89176 .30902 L
.89198 .30902 L
.89218 .30902 L
.89237 .30902 L
.89257 .30902 L
.89267 .30902 L
.89279 .30902 L
.89288 .30902 L
.89298 .30902 L
.89309 .30902 L
.89318 .30902 L
.89328 .30902 L
.89337 .30902 L
.89348 .30902 L
.89357 .30902 L
.89367 .30902 L
.89375 .30902 L
.89384 .30902 L
.89393 .30902 L
.89435 .30902 L
.89474 .30902 L
.89561 .30902 L
.89599 .30902 L
.89639 .30902 L
.89674 .30902 L
.89712 .30902 L
.89735 .30902 L
.89756 .30902 L
.89778 .30902 L
.89798 .30902 L
.89817 .30902 L
.89837 .30902 L
.89847 .30902 L
.89858 .30902 L
.89867 .30902 L
.89877 .30902 L
.89888 .30902 L
.89897 .30902 L
.89907 .30902 L
.89915 .30902 L
.89925 .30902 L
.89935 .30902 L
.8994 .30902 L
Mistroke
.89946 .30902 L
.89956 .30902 L
.89965 .30902 L
.89974 .30902 L
.89994 .30902 L
.90029 .30902 L
.90116 .30902 L
.90195 .30902 L
.90234 .30902 L
.90276 .30902 L
.90316 .30902 L
.90352 .30902 L
.90373 .30902 L
.90391 .30902 L
.90412 .30902 L
.90434 .30902 L
.90445 .30902 L
.90457 .30902 L
.90469 .30902 L
.90479 .30902 L
.90489 .30902 L
.90499 .30902 L
.90505 .30902 L
.9051 .30902 L
.90521 .30902 L
.90531 .30902 L
.9054 .30902 L
.9056 .30902 L
.90597 .30902 L
.90681 .30902 L
.90724 .30902 L
.90769 .30902 L
.90811 .30902 L
.90851 .30902 L
.90886 .30902 L
.90924 .30902 L
.90945 .30902 L
.90966 .30902 L
.90984 .30902 L
.91004 .30902 L
.91016 .30902 L
.91026 .30902 L
.91036 .30902 L
.91046 .30902 L
.91052 .30902 L
.91058 .30902 L
.91064 .30902 L
.9107 .30902 L
.9108 .30902 L
.91086 .30902 L
Mistroke
.91091 .30902 L
.91101 .30902 L
.91111 .30902 L
.91121 .30902 L
.91132 .30902 L
.91171 .30902 L
.91248 .30902 L
.91329 .30902 L
.91399 .30902 L
.91438 .30902 L
.91474 .30902 L
.91495 .30902 L
.91514 .30902 L
.91531 .30902 L
.9155 .30902 L
.9157 .30902 L
.91588 .30902 L
.91598 .30902 L
.91608 .30902 L
.91619 .30902 L
.91624 .30902 L
.9163 .30902 L
.9164 .30902 L
.91646 .30902 L
.91651 .30902 L
.91661 .30902 L
.91671 .30902 L
.91676 .30902 L
.91682 .30902 L
.91693 .30902 L
.91716 .30902 L
.91797 .30902 L
.91874 .30902 L
.91916 .30902 L
.91955 .30902 L
.91992 .30902 L
.92033 .30902 L
.9205 .30902 L
.92069 .30902 L
.92103 .30902 L
.92123 .30902 L
.92142 .30902 L
.92159 .30902 L
.92169 .30902 L
.92178 .30902 L
.92189 .30902 L
.92199 .30902 L
.92208 .30902 L
.92217 .30902 L
.92228 .30902 L
Mistroke
.92233 .30902 L
.92239 .30902 L
.9225 .30902 L
.92259 .30902 L
.92278 .30902 L
.92296 .30902 L
.9233 .30902 L
.92406 .30902 L
.92484 .30902 L
.92523 .30902 L
.92566 .30902 L
.92603 .30902 L
.92622 .30902 L
.92642 .30902 L
.9266 .30902 L
.9268 .30902 L
.92697 .30902 L
.92714 .30902 L
.92724 .30902 L
.92735 .30902 L
.92744 .30902 L
.92754 .30902 L
.9276 .30902 L
.92765 .30902 L
.92771 .30902 L
.92777 .30902 L
.92787 .30902 L
.92793 .30902 L
.92798 .30902 L
.92809 .30902 L
.92819 .30902 L
.92837 .30902 L
.92878 .30902 L
.92949 .30902 L
.93027 .30902 L
.93065 .30902 L
.93106 .30902 L
.93149 .30902 L
.93168 .30902 L
.93189 .30902 L
.93209 .30902 L
.93228 .30902 L
.93247 .30902 L
.93266 .30902 L
.93284 .30902 L
.933 .30902 L
.93309 .30902 L
.93318 .30902 L
.93327 .30902 L
.93337 .30902 L
Mistroke
.93347 .30902 L
.93352 .30902 L
.93358 .30902 L
.93367 .30902 L
.93377 .30902 L
.93386 .30902 L
.93395 .30902 L
.93414 .30902 L
.93496 .30902 L
.93566 .30902 L
.93603 .30902 L
.93643 .30902 L
.93687 .30902 L
.93707 .30902 L
.93727 .30902 L
.93765 .30902 L
.93785 .30902 L
.93806 .30902 L
.93824 .30902 L
.93844 .30902 L
.93854 .30902 L
.93865 .30902 L
.93875 .30902 L
.93884 .30902 L
.93893 .30902 L
.93901 .30902 L
.93911 .30902 L
.9392 .30902 L
.93929 .30902 L
.93937 .30902 L
.93946 .30902 L
.93955 .30902 L
.94113 .30902 L
.94157 .30902 L
.94203 .30902 L
.94246 .30902 L
.94286 .30902 L
.94306 .30902 L
.94327 .30902 L
.94345 .30902 L
.94365 .30902 L
.94386 .30902 L
.94406 .30902 L
.94418 .30902 L
.94429 .30902 L
.94439 .30902 L
.94445 .30902 L
.9445 .30902 L
.94459 .30902 L
.94469 .30902 L
Mistroke
.94478 .30902 L
.94486 .30902 L
.94495 .30902 L
.94505 .30902 L
.94525 .30902 L
.94566 .30902 L
.94605 .30902 L
.94689 .30902 L
.94731 .30902 L
.94769 .30902 L
.94804 .30902 L
.94841 .30902 L
.94878 .30902 L
.94899 .30902 L
.94918 .30902 L
.94939 .30902 L
.94958 .30902 L
.94969 .30902 L
.94979 .30902 L
.94985 .30902 L
.94991 .30902 L
.94997 .30902 L
.95002 .30902 L
.95011 .30902 L
.95022 .30902 L
.95032 .30902 L
.95038 .30902 L
.95043 .30902 L
.95053 .30902 L
.95063 .30902 L
.95081 .30902 L
.9523 .30902 L
.95306 .30902 L
.95349 .30902 L
.95389 .30902 L
.95411 .30902 L
.95431 .30902 L
.9545 .30902 L
.9547 .30902 L
.95482 .30902 L
.95492 .30902 L
.95512 .30902 L
.95523 .30902 L
.95529 .30902 L
.95536 .30902 L
.95541 .30902 L
.95547 .30902 L
.95553 .30902 L
.95558 .30902 L
.95568 .30902 L
Mistroke
.95573 .30902 L
.95579 .30902 L
.95589 .30902 L
.95598 .30902 L
.95603 .30902 L
.95609 .30902 L
.95619 .30902 L
.95642 .30902 L
.95721 .30902 L
.95799 .30902 L
.9587 .30902 L
.95909 .30902 L
.95946 .30902 L
.95967 .30902 L
.95986 .30902 L
.96006 .30902 L
.96028 .30902 L
.96046 .30902 L
.96055 .30902 L
.96064 .30902 L
.96073 .30902 L
.96082 .30902 L
.96091 .30902 L
.96098 .30902 L
.96108 .30902 L
.96118 .30902 L
.96126 .30902 L
.96136 .30902 L
.96146 .30902 L
.96151 .30902 L
.96156 .30902 L
.96176 .30902 L
.96263 .30902 L
.96345 .30902 L
.96381 .30902 L
.9642 .30902 L
.96461 .30902 L
.96482 .30902 L
.965 .30902 L
.96537 .30902 L
.96557 .30902 L
.96577 .30902 L
.96595 .30902 L
.96611 .30902 L
.96621 .30902 L
.96629 .30902 L
.96639 .30902 L
.96649 .30902 L
.96658 .30902 L
.96669 .30902 L
Mistroke
.96674 .30902 L
.9668 .30902 L
.9669 .30902 L
.967 .30902 L
.9671 .30902 L
.96728 .30902 L
.96768 .30902 L
.96813 .30902 L
.96894 .30902 L
.96934 .30902 L
.96971 .30902 L
.97014 .30902 L
.97036 .30902 L
.9706 .30902 L
.97078 .30902 L
.97098 .30902 L
.97119 .30902 L
.9714 .30902 L
.97149 .30902 L
.9716 .30902 L
.97172 .30902 L
.97182 .30902 L
.97192 .30902 L
.97201 .30902 L
.97212 .30902 L
.97222 .30902 L
.97227 .30902 L
.97232 .30902 L
.97238 .30902 L
.97244 .30902 L
.97254 .30902 L
.97264 .30902 L
.97311 .30902 L
.97389 .30902 L
.97432 .30902 L
.97472 .30902 L
.97509 .30902 L
.97542 .30902 L
.97579 .30902 L
.976 .30902 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{421.375, 260.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008>0001AB000`400?l00000o`00003ooooooooo
oooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo
003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooo
oooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool0
0?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooooooo
ool@ooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooo
ooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo0ol0003o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0
003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo
00?o0000ooooooooool0=Oooool00ol0003oooooooooo`3oooooojCooooo000`ooooo`03o`000?oo
oooooooo03Gooooo00?o0000ooooooooool0oooooonTooooo`00<?ooool00ol0003oooooooooo`0e
ooooo`03o`000?oooooooooo0?ooooooY?ooool0033ooooo00?o0000ooooooooool0=Oooool00ol0
003oooooooooo`3oooooojCooooo000`ooooo`?o0000=Oooool00ol0003oooooooooo`3oooooojCo
oooo000`ooooo`03o`000?oooooooooo03Gooooo0_l0003oooooojGooooo000`ooooo`03o`000?oo
oooooooo03Cooooo00?o0000ooooool00000oooooonUooooo`00<?ooool00ol0003oooooooooo`0d
ooooo`03o`000?oooooo00000?ooooooYOooool0033ooooo00?o0000ooooooooool0=?ooool00ol0
003oooooo`00003oooooojGooooo000`ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooool0
0000oooooonUooooo`00<?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooo00000?oooooo
YOooool0033ooooo00?o0000ooooooooool0=?ooool00ol0003oooooo`00003oooooojGooooo000`
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool02?ooool00ol0003oooooo`00003o
ooooojGooooo000`ooooo`03o`000?oooooooooo02Wooooo0_l00009ooooo`03o`000?oooooo0000
0?ooooooYOooool0033ooooo00?o0000ooooooooool0:Oooool2o`0000Wooooo00?o0000ooooool0
0000oooooonUooooo`00<?ooool3o`0002Wooooo0_l00009ooooo`03o`000?oooooo00000?oooooo
YOooool0033ooooo00?o0000ooooooooool0:Oooool2o`0000Wooooo00?o0000ooooool00000oooo
oonUooooo`00<?ooool00ol0003oooooooooo`0Yooooo`;o00002Oooool00ol0003oooooo`00003o
ooooojGooooo000`ooooo`03o`000?oooooooooo02Wooooo0_l00009ooooo`03o`000?oooooo0000
0?ooooooYOooool0033ooooo00?o0000ooooooooool0:Oooool2o`0000Wooooo00?o0000ooooool0
0000oooooonUooooo`00<?ooool00ol0003oooooooooo`0Yooooo`;o00002Oooool00ol0003ooooo
o`00003oooooojGooooo000`ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooool000002Ooo
ool00ol0003oooooo`00003oooooojGooooo000@ooooo`;ok^k^0oooool2onk^kQWooooo00?o0000
ooooooooool0:?ooool00ol0003oooooo`000009ooooo`03o`000?oooooo00000?ooooooYOooool0
00_ooooo0_l000002_l@413oooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h3ooooo`Co
000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP[ooooo00?o0000ooooooooool0:?oo
ool00ol0003oooooo`000009ooooo`03o`000?oooooo00000?ooooooYOooool000cooooo00?o0000
ooooooooool00_ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00[ooooo00?o0000ooooooooool0:?ooool00ol0003ooooo
o`000009ooooo`03o`000?oooooo00000?ooooooYOooool00003ooooool0003o000000Co00000_oo
ool5o`0000Cooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?oo
ooooooooooooool@41002_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo000000Wooooo
00?o0000ooooool00000oooooonUooooo`002Oooool01?m4A4CogMgMooooool00004ooooo`05onk^
k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000002_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo000000Wooooo00?o0000oooo
ool00000oooooonUooooo`002Oooool01?oMgMgoEEEEooooool00003ooooo`07onk^k_mEEEGok^k^
ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000:ooooo`Co00009oooool00ol0003oooooo`000009ooooo`03o`000?oooooo00000?oooooo
YOooool000[ooooo00?oMgMgolc<c?l000000oooool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oo
oooooooo00;ooooo00Go410@oooooooooooooooooa0@400:ooooo`03o`000?oooooooooo02Sooooo
00?o0000ooooool000002Oooool00ol0003oooooo`00003oooooojGooooo000:ooooo`03onk^k_m4
A4Co000000oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo
0_l00005ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooool000002Oooool00ol0003ooooo
o`00003oooooojGooooo000;ooooo`03ogMgMol0003ooooo00cooooo00?oEEEEofIVI_l000001?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`0Xooooo`03o`000?oooooo000000Wooooo00?o0000ooooool00000oooooonUooooo`00
:?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooool0
00002Oooool00ol0003oooooo`00003oooooojGooooo000Xooooo`?o00001Oooool00ol0003ooooo
ooooo`0Xooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooonUooooo`00
:Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Sooooo00Co0000oooooooooooo
00002?ooool00ol0003oooooo`00003oooooojGooooo000Zooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0:?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?oo
ooooYOooool0033ooooo00?o0000ooooooooool0:?ooool01?l0003oooooooooool00008ooooo`03
o`000?oooooo00000?ooooooYOooool0033ooooo00?o0000ooooooooool0:?ooool01?l0003ooooo
ooooool00008ooooo`03o`000?oooooo00000?ooooooYOooool0033ooooo00?o0000ooooooooool0
:?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?ooooooYOooool0033ooooo
00?o0000ooooooooool0:?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?oo
ooooYOooool0033ooooo0ol0000Xooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool0
0000oooooonUooooo`00<?ooool00ol0003oooooooooo`0Xooooo`04o`000?ooooooooooo`0000So
oooo00?o0000ooooool00000oooooonUooooo`00<?ooool00ol0003oooooooooo`0Xooooo`04o`00
0?ooooooooooo`0000Oooooo00Co0000oooooooooooo0000oooooonUooooo`00<?ooool00ol0003o
ooooooooo`0Xooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo0000oooooonU
ooooo`00<?ooool00ol0003oooooooooo`0Xooooo`04o`000?ooooooooooo`0000Oooooo00Co0000
oooooooooooo0000oooooonUooooo`00<?ooool00ol0003oooooooooo`0Xooooo`04o`000?oooooo
ooooo`0000Oooooo00Co0000oooooooooooo0000oooooonUooooo`00<?ooool00ol0003ooooooooo
o`0Xooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo0000oooooonUooooo`00
<?ooool00ol0003oooooooooo`0Xooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooo
oooo00002Oooool00ol0003oooooooooo`3ooooooiWooooo000`ooooo`03o`000?oooooooooo02So
oooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool00009ooooo`03o`000?oooooo
oooo0?ooooooVOooool0033ooooo00?o0000ooooooooool0:?ooool01?l0003oooooooooool00007
ooooo`04o`000?ooooooooooo`0000Wooooo0_l0003ooooooi[ooooo000`ooooo`03o`000?oooooo
oooo02Sooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool00009ooooo`;o0000
oooooonJooooo`00<?ooool00ol0003oooooooooo`0Xooooo`04o`000?ooooooooooo`0000Oooooo
00Co0000oooooooooooo00002Oooool2o`000?ooooooV_ooool0033ooooo0ol0000Xooooo`04o`00
0?ooooooooooo`0000Oooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003ooooo
oi[ooooo000`ooooo`03o`000?oooooooooo02Sooooo00Co0000oooooooooooo00001oooool01?l0
003oooooooooool00008ooooo`03o`000?oooooo00000?ooooooV_ooool0033ooooo00?o0000oooo
ooooool0:?ooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Sooooo00?o
0000ooooool00000oooooonJooooo`00<?ooool00ol0003oooooooooo`0Xooooo`04o`000?oooooo
ooooo`0000Oooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003ooooooi[ooooo
000`ooooo`03o`000?oooooooooo02Oooooo00Go0000ooooooooooooooooo`000007ooooo`05o`00
0?ooooooooooooooool000001oooool00ol0003oooooo`00003ooooooi[ooooo000`ooooo`03o`00
0?oooooooooo02Oooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooooooooooo
ool000001oooool00ol0003oooooo`00003ooooooi[ooooo000`ooooo`03o`000?oooooooooo02Oo
oooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool0
0ol0003oooooo`00003ooooooi[ooooo000`ooooo`03o`000?oooooooooo02Oooooo00Go0000oooo
ooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooo`00
003ooooooi[ooooo000`ooooo`03o`000?oooooooooo02Oooooo00Go0000ooooooooooooooooo`00
0007ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003ooooooi[ooooo
000`ooooo`03o`000?oooooooooo02Oooooo00Go0000ooooooooooooooooo`000007ooooo`05o`00
0?ooooooooooooooool000001oooool00ol0003oooooo`00003ooooooi[ooooo000`ooooo`03o`00
0?oooooooooo02Oooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooooooooooo
ool000001oooool00ol0003oooooo`00003ooooooi[ooooo000`ooooo`?o00009oooool01Ol0003o
oooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo
00000?ooooooV_ooool0033ooooo00?o0000ooooooooool09oooool01Ol0003ooooooooooooooooo
000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?ooooooV_oo
ool0033ooooo00?o0000ooooooooool09oooool01Ol0003ooooooooooooooooo000000Oooooo00Go
0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?ooooooV_ooool0033ooooo00?o
0000ooooooooool09oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooooooooooo
ooooo`000007ooooo`03o`000?oooooo00000?ooooooV_ooool0033ooooo00?o0000ooooooooool0
9oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007oooo
o`03o`000?oooooo00000?ooooooV_ooool0033ooooo00?o0000ooooooooool09oooool01Ol0003o
oooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo
00000?ooooooV_ooool0033ooooo00?o0000ooooooooool09oooool01Ol0003ooooooooooooooooo
000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?ooooooV_oo
ool0013ooooo0_o^k^h3ooooo`;ok^k^6Oooool00ol0003oooooooooo`0Wooooo`05o`000?oooooo
ooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooool00000
oooooonJooooo`002Oooool5o`0000;ooooo00Ook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?o
oooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^2_ooool00ol0003ooooooooo
o`0Wooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oo
oooo00?o0000ooooool00000oooooonJooooo`002Oooool01OnHV9So8B4Qonk^k_ooooooA4A400?o
oooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0:ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool01oooool0
1Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`03o`00
0?oooooo00000?ooooooV_ooool00003ooooool0003o000000Co00000oooool00onHV9So8B4Qonk^
kP05ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@00[ooooo00?o0000ooooooooool07?ooool2o`0000Wooooo00Go0000oooooooooooo
ooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003ooooo
oi[ooooo000;ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06oooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000:ooooo`03o`000?oooooo
oooo01cooooo0_l00009ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooo
oooooooo000000Oooooo00?o0000ooooool00000oooooonJooooo`003?ooool02omgMgOoIVIVoooo
ooooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000000[ooooo1?l0000Kooooo`;o00002Oooool01Ol0003ooooooooo
oooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?oo
ooooV_ooool000gooooo00?o0000ooooooooool00_o^k^h3ooooo`;ok^k^1Oooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41002_ooool00ol0003oooooooooo`0Looooo`03
o`000?oooooo000000Sooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooooooo
ooooool000001oooool00ol0003oooooo`00003ooooooi[ooooo0009ooooo`05o`000?nj^[[ooooo
oiRHV?l@41003_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00ooo
ool2o`0000Gooooo00?o0000ooooooooool07?ooool00ol0003oooooo`000008ooooo`05o`000?oo
ooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooool0
0000oooooonJooooo`002Oooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo00?oEEEEofIVI_l0
00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooo000000Sooooo00Go0000ooooooooooooooooo`00
0007ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool0003ooooooi[o
oooo000Xooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool07?ooool00ol0003o
ooooo`000008ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo
000000Kooooo00Go0000ooooooooooooooooo`00003ooooooiWooooo000Xooooo`?o00001Oooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooo000000Sooooo00Go0000ooooooooooooooooo`00
0007ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo00000?oo
ooooVOooool002Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooo000000Sooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooooooooooo
ool000001_ooool01Ol0003ooooooooooooooooo00000?ooooooVOooool002[ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Looooo`03o`000?oooooo000000Sooooo00Go0000oooo
ooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooo
oooooooo00000?ooooooVOooool0033ooooo00?o0000ooooooooool07?ooool00ol0003oooooo`00
0008ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Ko
oooo00Go0000ooooooooooooooooo`00003ooooooiWooooo000`ooooo`03o`000?oooooooooo01_o
oooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000
ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool00000oooooonIooooo`00<?oo
ool00ol0003oooooooooo`0Kooooo`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooooooo
ooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo
00000?ooooooVOooool0033ooooo00?o0000ooooooooool06oooool01?l0003oooooooooool00008
ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Kooooo
00Go0000ooooooooooooooooo`00003ooooooiWooooo000`ooooo`?o00006oooool01?l0003ooooo
ooooool00007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool01Ol0003o
oooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`00003ooooooiWooooo000`oooo
o`03o`000?oooooooooo01_ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?oo
ooooooooooooool00000oooooonIooooo`00<?ooool00ol0003oooooooooo`0Kooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo
00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool00000oooooonIoooo
o`00<?ooool00ol0003oooooooooo`0Kooooo`05o`000?ooooooooooooooool000001_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006
ooooo`05o`000?ooooooooooooooool00000oooooonIooooo`00<?ooool00ol0003oooooooooo`0K
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool0
0000oooooonIooooo`00<?ooool00ol0003oooooooooo`0Kooooo`05o`000?ooooooooooooooool0
00001_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooo
ooooooooo`000006ooooo`05o`000?ooooooooooooooool00000oooooonIooooo`00<?ooool00ol0
003oooooooooo`0Kooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?oo
ooooooooooooool000002?ooool00ol0003oooooooooo`3oooooohkooooo000`ooooo`03o`000?oo
oooooooo01_ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000oooooooo
ooooooooo`000007ooooo`;o0000oooooon@ooooo`00<?ooool00ol0003oooooooooo`0Kooooo`05
o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Cooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001ooo
ool2o`000?ooooooT?ooool0033ooooo00?o0000ooooooooool06oooool01Ol0003ooooooooooooo
oooo000000Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05o`000?oo
ooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Oooooo0_l0003ooooooi3o
oooo000`ooooo`03o`000?oooooooooo01_ooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000007ooooo`;o0000oooooon@oooo
o`00<?ooool00ol0003oooooooooo`0Kooooo`05o`000?ooooooooooooooool000001_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003o
ooooohoooooo000`ooooo`?o00006oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooool00000oooo
oon?ooooo`00<?ooool00ol0003oooooooooo`0Kooooo`05o`000?ooooooooooooooool000001_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001oooool00ol0003ooooo
o`00003oooooohoooooo000`ooooo`03o`000?oooooooooo01_ooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000007ooooo`03
o`000?oooooo00000?ooooooSoooool0033ooooo00?o0000ooooooooool06oooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo0000
00Oooooo00?o0000ooooool00000oooooon?ooooo`00<?ooool00ol0003oooooooooo`0Kooooo`05
o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo00000?ooooooS_ooool0
033ooooo00?o0000ooooooooool06oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000
ooooooooooooooooo`000002onk^kP?ooooo0_o^k^iGooooo`;ok^k^0oooool2onk^kV3ooooo0_o^
k^h3ooooo`;ok^k^C_ooool2onk^kP?ooooo0_o^k^i/ooooo`00<?ooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool03Om4A4Co0000o`000?lb
<S;ogMgMo`000?o^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?oooooo
ooooonk^k_lb<S;o0000oc8b<_o^k^i2ooooo`Co000000Wo410@ooooooo^k^koEEEEonk^k_oooooo
k^k^oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hkoooo
o`Co000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo00goA4A4o`000?l0003o<S8bomgMgOoo
ooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413oooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^>?ooool5o`0000;ooooo00Ook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^
00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^GOooool0033ooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00_o
0000oooooomgMgOo<S8bo`000?ooooook^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`14ooooo`03o`000?oooooooooo00;ooooo00Go
k^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0mooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`09ogMgMolb<S;ooooooooo
ooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg03Sooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05onk^k_mEEEGogMgMoeEE
EOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0GOooool0
033ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_l00002ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@04Cooooo00?o0000ooooooooool00oooool0
0ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
400mooooo`03o`000?oooooooooo00oooooo00Oo0000ooooooooooooooooomgMgOl0003ogMgM00Oo
oooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@03Wooooo00?oV9RHob4Q
8Oo^k^h01Oooool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooo
oooooooooooooa0@401Mooooo`00<?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00oooool02ol0003oooooogMgMolb<S;o0000ooooooo^k^koEEEE
omgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
04Cooooo00?o0000ooooooooool00_ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000003gooooo00?o0000ooooooooool03_oo
ool02OmgMgOo<S8booooooooooook^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`00000jooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Gok^k^
oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00001Mooooo`00<?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00_ooool3o`00000:oc8b<_o<c<co0000onk^k_mEEEGok^k^ooooooo^k^koEEEE
onk^kPGooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000004Cooooo00_o
0000ooooooooooooooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`00000mooooo`03o`000?oooooooooo00_ooooo00go
0000ob4Q8Ol0003o<S8bolc<c?ooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000003_ooooo00_oMgMgofIVI_oooooo
ooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`00001Mooooo`00<?ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00_ooool2o`0000?ooooo00?o0000onk^k_o^k^h00ooo
ool2onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@04Cooooo
00Co0000oooooooooooooooo0_o^k^h3ooooo`;ok^k^1Oooool00ol0003oooooooooo`02ooooo`05
oa0@4?ooooooooooooooool@4100?Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00?ooooo0_o^k^h3ooooo`;ok^k^1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@4100??ooool00ol0003oooooooooo`02onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooo
oooo00;ooooo00Go410@oooooooooooooooooa0@401Mooooo`00<?ooool3o`0001[ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`02ooooo`;o00000oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oo
oooooooo03Wooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02?ooool2o`0003?ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`;o
0000;_ooool01Ol0003o^[ZjoooooonHV9So410@00kooooo00?o0000ooooooooool00_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Sooooo0_l0001Cooooo`00<?ooool00ol0003oooooooooo`0?oooo
o`;o00002Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo1?l000000ooo
oooo0000ooooo`09ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08
ooooo`03o`000?oooooooooo03Oooooo00?oEEEEofIVI_l000003Oooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01oooool01?l0003oooooooooool0000`ooooo`03oeEE
EOmVIVKo000000gooooo1?l0000<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP07ooooo`04o`000?ooooooooooo`0002gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00<
ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP07ooooo`04o`000?oo
ooooooooo`0005;ooooo000`ooooo`03o`000?oooooooooo00oooooo0ol00008ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000001Sooooo
1?l00003ooooo`03o`000?oooooooooo05Cooooo1?l000001Ooooooo0000oooooooooooo000005ko
oooo1?l000001Ooooooo0000oooooooooooo000004cooooo1?l000001Ooooooo0000oooooooooooo
000005;ooooo000`ooooo`03o`000?oooooooooo00kooooo00Co0000oooooooooooo00002?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00
000Oooooo`03o`000?oooooooooo05Wooooo0ol0001Tooooo`?o0000D_ooool3o`0005?ooooo000`
ooooo`03o`000?oooooooooo00kooooo00Co0000oooooooooooo00002?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`00
0?oooooooooo01?ooooo00Co0000oooooooooooo0000Foooool00ol0003oooooooooo`1Tooooo`03
o`000?oooooooooo05;ooooo00?o0000ooooooooool0D_ooool0033ooooo00?o0000ooooooooool0
3_ooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0000Dooooo`Co0000G?ooool00ol0
003oooooooooo`1Tooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0DOooool0033o
oooo00?o0000ooooooooool03Oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001_ooool0
0ol0003oooooo`00003oooooohGooooo000`ooooo`03o`000?oooooooooo00gooooo00Go0000oooo
ooooooooooooo`000007ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
1Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooool00000oooooom;ooooo`03ogMgMomV
IVKooooo02gooooo00?oIVIVogMgMoooool01oooool0033ooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003ooooooooo
ool0003oooooodWooooo00?ogMgMoa0@4?o^k^h0;_ooool00oo^k^ko410@omgMg@07ooooo`00<?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooooooo
o`000006ooooo`04o`000?ooooooooooo`000?oooooo=oooool2o`0000;ooooo0_l0000<ooooo`03
oeEEEOnHV9Sooooo00;o00000_ooool01ol0003oooooooooool0003o410@onk^k_mEEED00_l00000
0om4A4Co^[Zjooooo`02ooooo`05oiRHV?l0003o0000odA4A?nj^[X00_ooool02?o^k^koEEEEo`00
0?l0003oA4A4okZj^_oooooo410@1Ol00003ooooo`08oa0@4?lb<S;o0000o`000?l@413oZJVYohN7
QomVIVH7ooooo`00<?ooool01?l0003oooooooooooooool2o`0000Wooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo
00001_ooool3o`000?oooooo;_ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@cooooo00Go0000
ooooooooooooooooo`000002ooooo`0;o`000?ooooooooooo`000?ooooooEEEEogMgMoooooook^k^
ogMgMol@41000oooool01Ol@413o^[Zjonk^k_mgMgOo410@00;ooooo00KoEEEEogMgMoooooook^k^
ogMgMol@4103ooooo`03o`000?oooooooooo00Cooooo00So0000ojVYZOoooooooooookZj^_l0003o
k^k^o`0000Oooooo003oo`000;Co00003oooool01?oMgMgo0000oa0@4?o<c<`=ooooo`05oc8b<_oo
ooooooooooooool000000_ooool01_l0003oooooooooool0003oooooo`0000Sooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00Oo^[ZjohN7
QomVIVKoIVIVoa0@4?oooooo000000Oooooo000:ooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo00?ooooo00Go
0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00;ooooo00Ko0000oooooooooooo0000ooooool00004ooooo`Co00002?ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool05oooool0
1?o^k^ko8B4Qoa0@4?o^k^h=ooooo`05oc8b<_ooooooooooooooool000000_ooool01Ol0003ooooo
ooooool0003ooooo00Ko00000oooool00ol0003oooooooooo`04ooooo`Ko00000oooool00ol0003o
ooooooooo`04ooooo`08oc8b<_lQ8B7oMgMgogMgMon7QhOok^k^ooooool00007ooooo`002_ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001Ooo
ool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo0_l00004ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool2o`000003ooooool0003o0000017o
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Oo
oooo00Co8B4QogMgMomgMgOo<S8b3Oooool01Ol0003ok^k^oooooooooooo000000;oc<c<00_o0000
ojVYZOoMgMgo8B4QoooooomEEEGoQhN7onk^k_ooooooQhN7oc8b<P03ooooo`03o`000?oooooooooo
00Cooooo00KoEEEEohN7Qoo^k^koooooohN7Qolb<S83ooooo`03o`000?lb<S;ogMgM00Cooooo00So
0000okZj^_ooooook^k^ogMgMol0003ok^k^o`0000Oooooo000`ooooo`03o`000?oooooooooo00Oo
oooo1?l00008ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`?o0000GOooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo05_o
oooo00?o0000ooooooooool05_ooool2o`0000;ooooo0_l0000<ooooo`0>oeEEEOmgMgOooooooa0@
4?l0003o8B4Qo`000?mgMgOo410@o`000?nYZJWoooooonk^k_mEEED2o`000004odA4A?o^k^kooooo
oa0@40Go00000oooool01_o^k^koEEEEo`000?l0003oA4A4onk^kP;ooooo0_l000001?nYZJWo8B4Q
o`000?lQ8B42ooooo`08ojVYZOlQ8B7o0000o`000?lb<S;o0000ogMgMomEEED7ooooo`00<?ooool0
0ol0003oooooooooo`08ooooo`;o00002Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool00000oooooom>ooooo`03omgMgOl@413ok^k^01;ooooo00?o0000ooooooooool06Ooo
ool00oo^k^ko410@omgMg@07ooooo`00<?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Gooooo00Go
0000ooooooooooooooooo`00003oooooodoooooo00?oMgMgofIVI_ooool04Oooool00ol0003ooooo
ooooo`0Iooooo`03ofIVI_mgMgOooooo00Oooooo000`ooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000
1Oooool01Ol0003ooooooooooooooooo00000?ooooooROooool0033ooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooo
ooooo`000005ooooo`05o`000?ooooooooooooooool00000oooooon9ooooo`00<?ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003o
oooooooooooooooo000000Gooooo00Go0000ooooooooooooooooo`00003oooooohWooooo000`oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04oooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooo`00003ooooooh[ooooo000`oooo
o`03o`000?oooooooooo01Cooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooo`00003ooooooh[ooooo000`ooooo`03o`000?oooooo
oooo01Cooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooo`00003ooooooh[ooooo000`ooooo`?o00005?ooool01Ol0003ooooooooo
oooooooo000000Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo00000?oo
ooooR_ooool0033ooooo00?o0000ooooooooool05?ooool01Ol0003ooooooooooooooooo000000Oo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo00000?ooooooR_ooool0033o
oooo00?o0000ooooooooool05?ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooo00000?ooooooR_ooool0033ooooo00?o0000oooo
ooooool05?ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00
0006ooooo`;o0000oooooon;ooooo`00<?ooool00ol0003oooooooooo`0Dooooo`05o`000?oooooo
ooooooooool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool01Ol0003ooooooooooooooooo00000?ooooooToooool0033ooooo00?o
0000ooooooooool05?ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooo
ooooo`00003ooooooi?ooooo000`ooooo`03o`000?oooooooooo01Cooooo00Go0000oooooooooooo
ooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006oooo
o`05o`000?ooooooooooooooool00000oooooonCooooo`00<?ooool00ol0003oooooooooo`0Eoooo
o`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooo
oooo000000Kooooo00Go0000ooooooooooooooooo`00003ooooooi?ooooo000`ooooo`03o`000?oo
oooooooo01Gooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`00
0?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo00000?ooooooToooool0033o
oooo00?o0000ooooooooool05Oooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool00000oooo
oonCooooo`00<?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo000000Sooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000oooooooooooooooo
o`00003ooooooi?ooooo000`ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooool000002?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooo
oooooooooooo00000?ooooooToooool0033ooooo0ol0000Eooooo`?o00002?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo0000
0?ooooooToooool0033ooooo00?o0000ooooooooool05_ooool2o`0000Wooooo00Go0000oooooooo
ooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0
003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`00003ooooooi?ooooo000`
ooooo`03o`000?oooooooooo01Kooooo0_l00009ooooo`05o`000?ooooooooooooooool000001ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooooooo
o`000006ooooo`05o`000?ooooooooooooooool00000oooooonCooooo`00<?ooool00ol0003ooooo
ooooo`0Qooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?oooooooooo
o`000?ooooooU?ooool0033ooooo00?o0000ooooooooool08Oooool01Ol0003ooooooooooooooooo
000000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooo
ooooooooool000001_ooool01?l0003oooooooooool0003ooooooiCooooo000`ooooo`03o`000?oo
oooooooo027ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooo
oooo0000oooooonDooooo`00<?ooool00ol0003oooooooooo`0Qooooo`05o`000?oooooooooooooo
ool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooo
ooooooooooooo`000006ooooo`04o`000?ooooooooooo`000?ooooooU?ooool0033ooooo00?o0000
ooooooooool08Oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003ooooo
ooooool0003ooooooiCooooo000`ooooo`03o`000?oooooooooo027ooooo00Go0000oooooooooooo
ooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003o
oooooooooooooooo000000Kooooo00Co0000oooooooooooo0000oooooonDooooo`00<?ooool00ol0
003oooooooooo`0Qooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?oo
ooooooooo`000?ooooooU?ooool0033ooooo00?o0000ooooooooool08Oooool01Ol0003ooooooooo
oooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`00
0?ooooooooooooooool000001_ooool01?l0003oooooooooool0003ooooooiCooooo000`ooooo`03
o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000
oooooooooooo0000oooooonDooooo`00<?ooool3o`00027ooooo00Go0000ooooooooooooooooo`00
0007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000Kooooo00Co0000oooooooooooo0000oooooonDooooo`00<?ooool00ol0003ooooo
ooooo`0Qooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?oooooooooo
o`000?ooooooU?ooool0033ooooo00?o0000ooooooooool08Oooool01Ol0003ooooooooooooooooo
000000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooo
ooooooooool000001_ooool01?l0003oooooooooool0003ooooooiCooooo000`ooooo`03o`000?oo
oooooooo027ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooo
oooo0000oooooonDooooo`00<?ooool00ol0003oooooooooo`0Qooooo`05o`000?oooooooooooooo
ool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooo
ooooooooooooo`000006ooooo`04o`000?ooooooooooo`000?ooooooU?ooool0033ooooo00?o0000
ooooooooool08Oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003ooooo
ooooool0003ooooooiCooooo000?ooooo`;ok^k^0oooool2onk^kQ[ooooo00?o0000ooooooooool0
8Oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003ooooo
oiCooooo0008ooooo`Go00000_ooool01oo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4
o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`03o`000?oooooooooo027o
oooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01?ooool01Ol0003ooooooooooooooooo000000Oooooo0_l0003ooooooiGooooo0008oooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?o0000ooooooooool0
8Oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`05o`000?ooooooooooooooool000001oooool2o`000?ooooooUOooool000Wo
oooo00?oV9RHob4Q8Oo^k^h01Oooool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;o
oooo00Go410@oooooooooooooooooa0@400;ooooo`03o`000?oooooooooo027ooooo00Go0000oooo
ooooooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
1Ol0003ooooooooooooooooo000000Oooooo0_l0003ooooooiGooooo000:ooooo`03oiRHV?lQ8B7o
k^k^00?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`00000;ooooo`03o`000?oooooooooo027ooooo00Go0000oooooooooooo
ooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003o
oooooooooooooooo000000Oooooo0_l0003ooooooiGooooo000;ooooo`0;ogMgMomVIVKooooooooo
ooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000002oooool4o`00023ooooo00Go0000ooooooooooooooooo`000007oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo
000000Oooooo0_l0003ooooooiGooooo000<ooooo`03o`000?oooooooooo00;ok^k^0oooool2onk^
kPGooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00_ooooo00?o0000
ooooooooool08Oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001oooool2o`000?oooooo
UOooool000Sooooo00Go0000okZj^_ooooooV9RHoa0@400>ooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03o`000?oooooooooo027ooooo00Go0000oooooooo
ooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0
003ooooooooooooooooo000000Oooooo0_l0003ooooooiGooooo0008ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`03?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ooo
ool2o`0000Kooooo00?o0000ooooooooool08Oooool01Ol0003ooooooooooooooooo000000Oooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool0
00001oooool2o`000?ooooooUOooool002Oooooo00Co0000oooooooooooo00001Oooool00ol0003o
ooooooooo`0Qooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00003ooooooikooooo000Woooo
o`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool08Oooool01Ol0003ooooooooooooo
oooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oo
ooooooooooooool00000oooooonNooooo`009oooool3o`0000Kooooo00?o0000ooooooooool08Ooo
ool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`04ooooo`05o`000?ooooooooooooooool00000oooooonNooooo`00:?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`000007ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000
0?ooooooW_ooool002Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Qooooo`05
o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00Go0000ooooooooooooooooo`00003ooooooikooooo000`ooooo`03o`000?oooooooooo
027ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool01Ol0003ooooooooooooooooo00000?ooooooW_ooool0033ooooo00?o0000
ooooooooool08Oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000oooooonNooooo`00<?oo
ool00ol0003oooooooooo`0Qooooo`05o`000?ooooooooooooooool000001oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00003ooooooiko
oooo000`ooooo`?o00008Oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000oooooonNoooo
o`00<?ooool00ol0003oooooooooo`0Rooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooo
ooooooooooooo`000007ooooo`05o`000?ooooooooooooooool00000oooooonNooooo`00<?ooool0
0ol0003oooooooooo`0Rooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooooooooooo
o`000007ooooo`05o`000?ooooooooooooooool00000oooooonNooooo`00<?ooool00ol0003ooooo
ooooo`0Rooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000007oooo
o`04o`000?ooooooooooo`000?ooooooWoooool0033ooooo00?o0000ooooooooool08_ooool01?l0
003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001oooool01?l0003ooooooooo
ool0003ooooooioooooo000`ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooool000002?oo
ool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000oooooonOooooo`00
<?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo000000Sooooo00Go0000oooooooooooo
ooooo`000007ooooo`04o`000?ooooooooooo`000?ooooooWoooool0033ooooo00?o0000oooooooo
ool08_ooool00ol0003oooooo`000008ooooo`05o`000?ooooooooooooooool000001oooool01?l0
003oooooooooool0003ooooooioooooo000`ooooo`03o`000?oooooooooo02;ooooo00?o0000oooo
ool000002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000oooo
oonOooooo`00<?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo000000Sooooo00Go0000
ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`000?ooooooWoooool0033ooooo00?o
0000ooooooooool08_ooool00ol0003oooooo`000008ooooo`05o`000?ooooooooooooooool00000
1oooool01?l0003oooooooooool0003ooooooioooooo000`ooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooool000002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooo
oooo0000oooooonOooooo`00<?ooool3o`0002;ooooo00?o0000ooooool000002?ooool01Ol0003o
oooooooooooooooo000000Oooooo00Co0000oooooooooooo0000oooooonOooooo`00<?ooool00ol0
003oooooooooo`0Rooooo`03o`000?oooooo000000Sooooo00Go0000ooooooooooooooooo`000007
ooooo`04o`000?ooooooooooo`000?ooooooWoooool0033ooooo00?o0000ooooooooool08_ooool0
0ol0003oooooo`000008ooooo`05o`000?ooooooooooooooool000001oooool01?l0003ooooooooo
ool0003ooooooioooooo000`ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooool000002?oo
ool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000oooooonOooooo`00
<?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo000000Sooooo00Go0000oooooooooooo
ooooo`000007ooooo`04o`000?ooooooooooo`000?ooooooWoooool0033ooooo00?o0000oooooooo
ool08_ooool00ol0003oooooo`000008ooooo`05o`000?ooooooooooooooool000001oooool01?l0
003oooooooooool0003ooooooioooooo000`ooooo`03o`000?oooooooooo02;ooooo00?o0000oooo
ool000002?ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooool00000oooooonO
ooooo`00<?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo000000Sooooo00Go0000oooo
ooooooooooooo`000008ooooo`03o`000?oooooo00000?ooooooWoooool0033ooooo00?o0000oooo
ooooool08oooool2o`0000Sooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooo
00000?ooooooWoooool0033ooooo00?o0000ooooooooool08oooool2o`0000Sooooo00Go0000oooo
ooooooooooooo`000008ooooo`03o`000?oooooo00000?ooooooWoooool0033ooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool000002?ooool0
0ol0003oooooo`00003ooooooioooooo000`ooooo`03o`000?oooooooooo02?ooooo00?o0000oooo
ooooool01oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooool00000oooooonO
ooooo`00<?ooool3o`0002gooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooo
00000?ooooooWoooool0033ooooo00?o0000ooooooooool0;_ooool01?l0003oooooooooool00008
ooooo`03o`000?oooooo00000?ooooooWoooool0033ooooo00?o0000ooooooooool0;_ooool01?l0
003oooooooooool00008ooooo`03o`000?oooooo00000?ooooooWoooool0033ooooo00?o0000oooo
ooooool0;_ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?ooooooWoooool0
033ooooo00?o0000ooooooooool0;_ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo
00000?ooooooWoooool0033ooooo00?o0000ooooooooool0;_ooool01?l0003oooooooooool00008
ooooo`03o`000?oooooo00000?ooooooWoooool000oooooo0_o^k^h3ooooo`;ok^k^6_ooool00ol0
003oooooooooo`0^ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooonO
ooooo`002_ooool2o`00000:oa0@4?ooooooooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP?o
oooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool00ol0003ooooooooo
o`0^ooooo`04o`000?ooooooooooo`0000Sooooo0_l0003ooooooj3ooooo000;ooooo`03o`000?oo
oooooooo00;ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03o`000?oooooooooo02kooooo00Co0000oooooooo
oooo00002?ooool2o`000?ooooooX?ooool000Sooooo1Ol00004ooooo`03omgMgOl0003ogMgM00Oo
oooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00_ooooo00?o0000oooo
ooooool0;_ooool01?l0003oooooooooool00008ooooo`;o0000oooooonPooooo`002?ooool01?m4
A4CogMgMooooool00004ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`0^ooooo`04o`00
0?ooooooooooo`0000Sooooo0_l0003ooooooj3ooooo0008ooooo`04omgMgOmEEEGoooooo`0000?o
oooo00Ook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000000_ooooo1?l0000]ooooo`04o`000?ooooooooooo`0000Sooooo
0_l0003ooooooj3ooooo0009ooooo`03ogMgMoo<c<co000000?ooooo0_o^k^h3ooooo`;ok^k^1Ooo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41002oooool00ol0003ooooo
ooooo`0^ooooo`04o`000?ooooooooooo`0000Sooooo0_l0003ooooooj3ooooo0009ooooo`03onk^
k_m4A4Co000000oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00?o0000ooooooooool0;_ooool01?l0003oooooooooool00008ooooo`;o0000oooooonPoooo
o`002_ooool00omgMgOo0000ooooo`0<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP03ooooo`;o00001_ooool00ol0003oooooooooo`0^ooooo`04o`000?oooooooooo
o`0000Sooooo0_l0003ooooooj3ooooo000Wooooo`04o`000?ooooooooooo`0000Gooooo00?o0000
ooooooooool0;_ooool01?l0003oooooooooool00008ooooo`;o0000oooooonPooooo`009oooool0
1?l0003oooooooooool00005ooooo`03o`000?oooooooooo02kooooo00Co0000oooooooooooo0000
2?ooool2o`000?ooooooX?ooool002Oooooo0ol00006ooooo`03o`000?oooooooooo02kooooo00Co
0000oooooooooooo00002?ooool2o`000?ooooooX?ooool002Sooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0^ooooo`04o`000?ooooooooooo`0000Sooooo0_l0003ooooooj3ooooo
000Yooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0;_ooool00ol0003oooooo`00
0009ooooo`;o0000oooooonPooooo`00<?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooo
000000[ooooo00?o0000ooooooooool0oooooonNooooo`00<?ooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooo00000?ooooooZoooool0033ooooo00?o0000ooooooooool0;_ooool00ol0003o
ooooo`00003ooooooj_ooooo000`ooooo`?o0000;_ooool00ol0003oooooo`00003ooooooj_ooooo
000`ooooo`03o`000?oooooooooo02kooooo00?o0000ooooool00000oooooon[ooooo`00<?ooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooo00000?ooooooZoooool0033ooooo00?o0000oooo
ooooool0;_ooool00ol0003oooooo`00003ooooooj_ooooo000`ooooo`03o`000?oooooooooo02ko
oooo00?o0000ooooool00000oooooon[ooooo`00<?ooool00ol0003oooooooooo`0^ooooo`03o`00
0?oooooo00000?ooooooZoooool0033ooooo00?o0000ooooooooool0;_ooool00ol0003oooooo`00
003ooooooj_ooooo000`ooooo`03o`000?oooooooooo02kooooo00?o0000ooooool00000oooooon[
ooooo`00<?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooo00000?ooooooZoooool0033o
oooo00?o0000ooooooooool0;_ooool00ol0003oooooo`00003ooooooj_ooooo000`ooooo`03o`00
0?oooooooooo02kooooo00?o0000ooooool00000oooooon[ooooo`00<?ooool00ol0003ooooooooo
o`0^ooooo`03o`000?oooooo00000?ooooooZoooool0033ooooo0ol0000_ooooo`;o0000oooooon[
ooooo`00<?ooool00ol0003oooooooooo`0_ooooo`;o0000oooooon[ooooo`00<?ooool00ol0003o
ooooooooo`0_ooooo`;o0000oooooon[ooooo`00<?ooool00ol0003oooooooooo`0_ooooo`;o0000
oooooon[ooooo`00<?ooool00ol0003oooooooooo`0_ooooo`;o0000oooooon[ooooo`00<?ooool0
0ol0003oooooooooo`0_ooooo`;o0000oooooon[ooooo`00<?ooool00ol0003oooooooooo`0_oooo
o`03o`000?oooooooooo0?ooooooZ_ooool0033ooooo00?o0000ooooooooool0;oooool00ol0003o
ooooooooo`3ooooooj[ooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o
0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`oooo
o`03o`000?oooooooooo0?oooooog?ooool0033ooooo0ol0003oooooomcooooo000`ooooo`03o`00
0?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool0
0ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool00?oo
ooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@
ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooo
oooooooooa3ooooo002Pooooo`;o00001?ooool00onj^[[o<S8booooo`04ooooo`;o00001_ooool0
0ol0003o^[Zjooooo`3ooooooeOooooo002Pooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`;o<S8boooooomHooooo`00SOooool3o`0000;o
oooo00Ko<S8boa0@4?ooooooooooonk^k_mEEED2o`000003odA4A?nj^[[ooooo00?ooooo00?o0000
ooooooooool00_ooool01OnHV9So410@o`000?l0003oZJVY00Cooooo00?o0000ooooooooool01?oo
ool00on7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X02Oooool5o`0000Gooooo
0_lQ8B46ooooo`;o000000Oo410@ooooooo<c<cok^k^ooooooo^k^koc<c<00Cooooo1?l000002?l@
413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^4oooool01_l@413o<S8bo`000?l0003o410@ojVY
Z@;ooooo00Kok^k^oeEEEOl0003o0000odA4A?nj^[X3ooooo`05ofIVI_l0003o0000odA4A?o<c<`0
j?ooool008kooooo00Go0000ooooooooooooc<c<oa0@4003ooooo`06oeEEEOmgMgOoooooonk^k_mg
MgOo410@1?ooool00ol0003oooooooooo`02ooooo`06o`000?nYZJWoEEEEoiRHV?mEEEGo^[Zj0ooo
ool00ol0003oooooooooo`04ooooo`03olc<c?l0003o410@00cooooo00Ko410@okZj^_o^k^koMgMg
oa0@4?ooool6o`0000;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`;o8B4Q1oooool02?l0
003oooooooooooo^k^koEEEEomgMgOmEEEGok^k^1_ooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL04oooool01_l0003oZJVYoooooooooooo^[Zjo`0000;ooooo00KoEEEE
ogMgMoooooook^k^ogMgMol@4102ooooo`06ofIVI_mgMgOooooooooooon7QhOo410@j?ooool008ko
oooo00Go0000ooooooooooooEEEEohN7Q`03ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool00_ooool01_lb<S;ok^k^oiRHV?mEEEGogMgMoa0@40?ooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0<ooooo`03oiRHV?lQ8B7ok^k^00cooooo1Ol00002ooooo`03omgMgOl0
003ogMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01Cooooo
00Go^[ZjohN7QomVIVKoIVIVoa0@4002ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0joooool008kooooo00Go0000oooooooMgMgo0000onk^kP03ooooo`Ko00001?ooool00ol0003o
ooooooooo`02ooooo`07okZj^_m4A4Coc<c<ob4Q8Ooooooo410@olc<c002ooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool00oooool6o`0000Cooooo00?oV9RHob4Q8Oo^k^h02oooool0
1?m4A4CogMgMooooool00002ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000004oooool01_lb<S;o8B4QogMgMomgMgOoQhN7
onk^kP;ooooo1_l00002ooooo`03o`000?oooooooooo0>_ooooo002>ooooo`?o000000?o410@oiRH
V?ooool00_ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<PCooooo00?o0000ooooooooool00_oo
ool01oo^k^ko0000ooooool0003oooooofIVI_n7QhL00_ooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo00kooooo00?oMgMgofIVI_ooool02_ooool01?oMgMgoEEEEooooool00002oooo
o`05olc<c?o^k^koooooonk^k_o<c<`01_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000004oooool01_l0003o^[Zjooooooo^k^koMgMgo`0000;ooooo00KoEEEEohN7Qoo^
k^koooooohN7Qolb<S82ooooo`06ofIVI_mgMgOooooooooooon7QhOo0000j?ooool008kooooo00Go
0000ooooooooooooc<c<o`000003ooooo`06onk^k_mEEEGo0000o`000?m4A4Cok^k^1?ooool00ol0
003oooooooooo`02ooooo`04ofIVI_nHV9Sooooooc8b<P;o^[Zj00Co0000oooooooooooo00004ooo
ool00ol@413o0000o`000003o`0000kooooo00?o0000ooooooooool02_ooool00omgMgOoc<c<o`00
000=ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4007ooooo`?o0000
0_ooool3o`0000Cooooo00KoZJVYob4Q8Ol0003o0000oc8b<_l00002ooooo`06onk^k_mEEEGo0000
o`000?m4A4Cok^k^0_ooool01_o^k^koIVIVo`000?l0003oA4A4o`000>Sooooo002>ooooo`05o`00
0?ooooooooooolc<c?l000003Oooool00ol0003oooooooooo`05ooooo`03ofIVI_n7QhOooooo00?o
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0;ooooo`05o`000?nj^[[ooooooiRH
V?l@41003?ooool00oo^k^koA4A4o`00000=ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0ooooool2
ooooo`00SOooool4o`000003oa0@4?nYZJWooooo00cooooo0_l00006ooooo`03ojVYZOm4A4Cooooo
00;ooooo0_l0000Eooooo`03o`000?oooooooooo00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00=
ooooo`03ogMgMol0003ooooo00[ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00;ooooo1?l00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0oooo
ool2ooooo`00ooooool6ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0ooooool2
ooooo`00ooooool6ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0ooooool2oooo
o`00ooooool5ooooo`;o00000oooool2o`000?oooooo1?ooool00?ooooooooooool@ooooo`00oooo
oooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3o
oooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooo
oooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?oo
ool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooo
ooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@oooo
o`00oooooooooooooa3ooooo0000\
\>"],
  ImageRangeCache->{{{0, 525.688}, {324.5, 0}} -> {0, -6.34248*^6, 0, 53093}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0.309017 5.42214e-08 [
[.32684 .29652 -16.5 -12.5 ]
[.32684 .29652 16.5 0 ]
[.54329 .29652 -16.5 -12.5 ]
[.54329 .29652 16.5 0 ]
[.75974 .29652 -22.5 -12.5 ]
[.75974 .29652 22.5 0 ]
[.97619 .29652 -16.5 -12.5 ]
[.97619 .29652 16.5 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 64 6 ]
[.09789 .09213 -34.5 -6.25 ]
[.09789 .09213 0 6.25 ]
[.09789 .20057 -34.5 -6.25 ]
[.09789 .20057 0 6.25 ]
[.09789 .41746 -28.5 -6.25 ]
[.09789 .41746 0 6.25 ]
[.09789 .5259 -28.5 -6.25 ]
[.09789 .5259 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -62.8125 0 ]
[.5 .63053 62.8125 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 .30902 m
.32684 .31527 L
s
gsave
.32684 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 .30902 m
.54329 .31527 L
s
gsave
.54329 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 .30902 m
.75974 .31527 L
s
gsave
.75974 .29652 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 .30902 m
.15368 .31277 L
s
.19697 .30902 m
.19697 .31277 L
s
.24026 .30902 m
.24026 .31277 L
s
.28355 .30902 m
.28355 .31277 L
s
.37013 .30902 m
.37013 .31277 L
s
.41342 .30902 m
.41342 .31277 L
s
.45671 .30902 m
.45671 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.58658 .30902 m
.58658 .31277 L
s
.62987 .30902 m
.62987 .31277 L
s
.67316 .30902 m
.67316 .31277 L
s
.71645 .30902 m
.71645 .31277 L
s
.80303 .30902 m
.80303 .31277 L
s
.84632 .30902 m
.84632 .31277 L
s
.88961 .30902 m
.88961 .31277 L
s
.9329 .30902 m
.9329 .31277 L
s
.0671 .30902 m
.0671 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09213 m
.11664 .09213 L
s
gsave
.09789 .09213 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .20057 m
.11664 .20057 L
s
gsave
.09789 .20057 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .41746 m
.11664 .41746 L
s
gsave
.09789 .41746 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .5259 m
.11664 .5259 L
s
gsave
.09789 .5259 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.11039 .11924 m
.11414 .11924 L
s
.11039 .14635 m
.11414 .14635 L
s
.11039 .17346 m
.11414 .17346 L
s
.11039 .22768 m
.11414 .22768 L
s
.11039 .2548 m
.11414 .2548 L
s
.11039 .28191 m
.11414 .28191 L
s
.11039 .33613 m
.11414 .33613 L
s
.11039 .36324 m
.11414 .36324 L
s
.11039 .39035 m
.11414 .39035 L
s
.11039 .44457 m
.11414 .44457 L
s
.11039 .47168 m
.11414 .47168 L
s
.11039 .49879 m
.11414 .49879 L
s
.11039 .06502 m
.11414 .06502 L
s
.11039 .03791 m
.11414 .03791 L
s
.11039 .0108 m
.11414 .0108 L
s
.11039 .55301 m
.11414 .55301 L
s
.11039 .58012 m
.11414 .58012 L
s
.11039 .60723 m
.11414 .60723 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -123.812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.812 moveto
(@) show
81.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.812 moveto
(D) show
93.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.6) show
135.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
141.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
153.000 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
157.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
166.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
184.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02418 .30902 L
.02453 .30902 L
.02532 .30902 L
.02609 .30902 L
.02691 .30902 L
.02782 .30902 L
.02868 .30902 L
.02946 .30902 L
.03029 .30902 L
.0319 .30902 L
.03338 .30902 L
.03494 .30902 L
.03641 .30902 L
.03953 .30902 L
.04111 .30902 L
.04194 .30902 L
.04283 .30902 L
.04328 .30902 L
.0437 .30902 L
.04408 .30902 L
.04429 .30902 L
.04439 .30902 L
.04449 .30902 L
.04458 .30902 L
.04467 .30902 L
.04476 .30902 L
.04484 .30902 L
.04494 .30902 L
.04503 .30902 L
.04513 .30902 L
.04523 .30902 L
.04533 .30902 L
.04543 .30902 L
.04561 .30902 L
.04582 .30902 L
.04602 .30902 L
.0464 .30902 L
.04681 .30902 L
.04719 .30902 L
.04754 .30902 L
.0484 .30902 L
.0492 .30902 L
.04998 .30902 L
.05081 .30902 L
.05229 .30902 L
.05305 .30902 L
.05386 .30902 L
.05533 .30902 L
.05864 .30902 L
Mistroke
.06184 .30902 L
.06345 .30902 L
.06415 .30902 L
.06491 .30902 L
.06533 .30902 L
.06552 .30902 L
.06572 .30902 L
.06591 .30902 L
.06609 .30902 L
.06619 .30902 L
.06628 .30902 L
.06639 .30902 L
.06649 .30902 L
.06658 .30902 L
.06664 .30902 L
.06669 .30902 L
.0668 .30902 L
.06691 .30902 L
.06701 .30902 L
.06711 .30902 L
.06729 .30902 L
.06751 .30902 L
.06771 .30902 L
.06817 .30902 L
.06858 .30902 L
.06902 .30902 L
.06982 .30902 L
.07059 .30902 L
.07131 .30902 L
.07282 .30902 L
.07368 .30902 L
.07448 .30902 L
.0776 .30901 L
.08092 .309 L
.08257 .309 L
.0833 .309 L
.08411 .309 L
.08488 .309 L
.08523 .309 L
.0856 .309 L
.08579 .309 L
.086 .309 L
.08609 .309 L
.08619 .309 L
.08628 .309 L
.08636 .309 L
.08647 .309 L
.08657 .309 L
.08662 .309 L
.08667 .309 L
Mistroke
.08673 .309 L
.08679 .309 L
.08689 .309 L
.08698 .309 L
.08708 .309 L
.08718 .309 L
.08739 .309 L
.08759 .309 L
.08796 .309 L
.08835 .309 L
.08878 .309 L
.08954 .309 L
.09025 .309 L
.09103 .30901 L
.09176 .30901 L
.09342 .30903 L
.09506 .30905 L
.09655 .30907 L
.09975 .30912 L
.10121 .30915 L
.10204 .30917 L
.10283 .30918 L
.10365 .30919 L
.10402 .30919 L
.10441 .3092 L
.10461 .3092 L
.10481 .3092 L
.10492 .3092 L
.10503 .3092 L
.10512 .3092 L
.10523 .3092 L
.10528 .3092 L
.10534 .3092 L
.10544 .3092 L
.1055 .3092 L
.10556 .3092 L
.10562 .3092 L
.10568 .3092 L
.10578 .3092 L
.10584 .3092 L
.10589 .3092 L
.1061 .3092 L
.1062 .3092 L
.10631 .3092 L
.10651 .3092 L
.10695 .30919 L
.10733 .30919 L
.10775 .30918 L
.10853 .30916 L
.10925 .30914 L
Mistroke
.11009 .3091 L
.11089 .30906 L
.11238 .30895 L
.11398 .3088 L
.11546 .30864 L
.11862 .30825 L
.1202 .30806 L
.1209 .308 L
.12165 .30794 L
.12207 .30791 L
.12245 .30789 L
.12264 .30788 L
.12282 .30788 L
.12292 .30787 L
.12302 .30787 L
.12311 .30787 L
.12321 .30787 L
.12331 .30787 L
.12341 .30787 L
.12347 .30787 L
.12353 .30787 L
.12363 .30787 L
.12369 .30787 L
.12375 .30787 L
.12385 .30787 L
.12396 .30787 L
.12408 .30788 L
.12428 .30788 L
.1245 .30789 L
.12489 .30792 L
.12528 .30795 L
.12565 .30799 L
.12649 .30811 L
.12731 .30828 L
.12819 .30851 L
.1299 .30913 L
.13152 .30989 L
.1346 .3117 L
.13617 .31265 L
.137 .3131 L
.13789 .31354 L
.13832 .31372 L
.13874 .31387 L
.13914 .31399 L
.13952 .31408 L
.13987 .31414 L
.14007 .31417 L
.14016 .31418 L
.14025 .31419 L
.14035 .31419 L
Mistroke
.14045 .3142 L
.14055 .3142 L
.14061 .3142 L
.14066 .3142 L
.14076 .3142 L
.14085 .31419 L
.14095 .31419 L
.14105 .31418 L
.14124 .31416 L
.14142 .31413 L
.14161 .31409 L
.14182 .31404 L
.14225 .31389 L
.14265 .31372 L
.14337 .3133 L
.14413 .31269 L
.1449 .31191 L
.14572 .31088 L
.14719 .30857 L
.15052 .30164 L
.1522 .2979 L
.15374 .29482 L
.15451 .29355 L
.15524 .29259 L
.1556 .29221 L
.156 .29189 L
.15622 .29175 L
.15643 .29164 L
.15662 .29157 L
.15673 .29155 L
.15683 .29153 L
.15692 .29152 L
.15702 .29151 L
.15711 .29151 L
.1572 .29152 L
.1573 .29154 L
.15735 .29155 L
.15741 .29156 L
.1576 .29163 L
.15778 .29172 L
.15797 .29184 L
.15832 .29214 L
.15874 .29264 L
.15918 .29333 L
.15998 .295 L
.16073 .29713 L
.16154 .29998 L
.16301 .30658 L
.16632 .32635 L
.16798 .33691 L
Mistroke
.16951 .34559 L
.17028 .34911 L
.171 .35178 L
.17139 .35293 L
.1716 .35343 L
.17182 .35389 L
.17201 .3542 L
.17222 .35448 L
.17231 .35458 L
.1724 .35466 L
.17249 .35473 L
.17258 .35478 L
.17268 .35482 L
.17273 .35483 L
.17278 .35484 L
.17284 .35484 L
.1729 .35483 L
.173 .35481 L
.1731 .35477 L
.17319 .35471 L
.17329 .35463 L
.17339 .35452 L
.17363 .35418 L
.17386 .35375 L
.17428 .35265 L
.17469 .35123 L
.17506 .3496 L
.1759 .34475 L
.17668 .33885 L
.1774 .33214 L
.17906 .31307 L
.18218 .26842 L
.18376 .24599 L
.1846 .23557 L
.18549 .22619 L
.18594 .2223 L
.18636 .21922 L
.18677 .21681 L
.18695 .21594 L
.18715 .21513 L
.18732 .21455 L
.18751 .21405 L
.18761 .21384 L
.1877 .21368 L
.1878 .21356 L
.18789 .21348 L
.18798 .21343 L
.18809 .21342 L
.18817 .21345 L
.18827 .21352 L
Mistroke
.18837 .21364 L
.18848 .21382 L
.18859 .21404 L
.18868 .21429 L
.18907 .21568 L
.18928 .21674 L
.18947 .21789 L
.19021 .22383 L
.19062 .22825 L
.19106 .23391 L
.19187 .24642 L
.19347 .279 L
.19516 .32195 L
.1982 .40502 L
.19977 .44042 L
.20065 .45542 L
.20103 .46066 L
.20145 .46518 L
.20182 .46832 L
.20204 .46967 L
.20214 .47017 L
.20224 .47063 L
.20233 .47095 L
.20243 .47124 L
.20251 .47144 L
.2026 .47158 L
.20269 .47168 L
.20278 .47171 L
.20288 .47166 L
.20298 .47155 L
.20307 .47137 L
.20318 .47108 L
.20329 .47069 L
.20339 .47023 L
.20358 .46921 L
.20378 .46781 L
.20423 .46344 L
.20464 .45801 L
.20543 .44388 L
.20617 .42652 L
.20783 .37376 L
.21098 .24308 L
.21258 .17645 L
.21343 .14565 L
.21432 .11815 L
.21512 .09894 L
.21557 .09068 L
.21579 .08745 L
.21599 .08484 L
.21618 .08286 L
Mistroke
.21638 .08114 L
.21647 .08053 L
.21657 .07997 L
.21666 .07953 L
.21674 .07922 L
.21683 .07894 L
.21693 .07876 L
.21702 .07869 L
.21712 .07872 L
.21722 .07887 L
.21732 .07912 L
.21742 .07951 L
.21753 .08008 L
.21774 .08151 L
.21796 .08357 L
.21836 .08866 L
.21878 .09615 L
.21925 .10673 L
.22009 .13159 L
.22087 .16118 L
.22399 .32196 L
.22557 .41244 L
.2273 .49953 L
.2281 .53191 L
.22855 .54681 L
.22896 .55876 L
.22935 .56802 L
.22977 .57582 L
.22995 .57852 L
.23015 .58085 L
.23031 .58243 L
.2305 .5837 L
.2306 .58422 L
.2307 .58456 L
.23075 .58468 L
.2308 .58477 L
.23086 .58482 L
.23092 .58482 L
.23102 .58471 L
.23111 .58448 L
.23116 .5843 L
.23122 .58407 L
.23132 .58352 L
.23151 .58211 L
.23171 .58005 L
.23207 .57489 L
.23252 .56578 L
.23295 .55459 L
.23375 .52726 L
.23536 .45007 L
Mistroke
.23684 .36058 L
.23848 .254 L
.24001 .16055 L
.24148 .08789 L
.2419 .07143 L
.2423 .05797 L
.24269 .04707 L
.24306 .03881 L
.24343 .03245 L
.24362 .02991 L
.24372 .02883 L
.24383 .02783 L
.24393 .02708 L
.24404 .02645 L
.2441 .02618 L
.24415 .02598 L
.24426 .02573 L
.24436 .02566 L
.24446 .02574 L
.24456 .02598 L
.24465 .02633 L
.24474 .02678 L
.24483 .02739 L
.245 .02881 L
.24519 .03106 L
.24537 .03363 L
.24576 .04087 L
.24613 .04983 L
.2469 .07462 L
.24773 .10929 L
.2492 .18864 L
.25254 .39814 L
.25336 .44409 L
.25422 .48625 L
.25502 .51802 L
.25541 .53063 L
.25576 .54034 L
.25611 .54805 L
.25648 .55453 L
.25668 .55723 L
.25687 .55918 L
.25705 .56055 L
.25714 .56106 L
.25724 .56149 L
.25734 .56176 L
.2574 .56184 L
.25745 .56189 L
.25755 .56185 L
.25764 .56168 L
.2577 .56152 L
Mistroke
.25775 .56132 L
.25785 .56084 L
.25796 .56017 L
.25808 .55924 L
.25828 .55722 L
.25849 .55447 L
.25886 .54802 L
.25926 .53914 L
.25962 .52928 L
.26044 .50146 L
.26191 .43517 L
.2651 .2622 L
.26656 .1928 L
.26739 .16104 L
.2678 .14805 L
.26818 .13773 L
.26854 .12924 L
.26894 .12175 L
.26934 .11618 L
.26956 .11397 L
.26976 .11245 L
.26987 .11186 L
.26992 .1116 L
.26998 .11138 L
.27003 .11121 L
.27009 .11107 L
.27019 .11091 L
.27028 .11087 L
.27039 .11096 L
.27049 .11116 L
.27058 .11145 L
.27069 .11193 L
.27079 .11252 L
.27102 .1143 L
.27123 .1164 L
.27145 .11916 L
.27188 .12613 L
.27227 .13425 L
.27317 .15801 L
.27479 .21588 L
.27643 .28438 L
.27796 .3467 L
.27943 .3967 L
.28025 .4181 L
.28101 .43264 L
.28139 .43815 L
.2816 .44059 L
.2818 .4425 L
.28198 .44394 L
.28215 .44499 L
Mistroke
.28234 .44586 L
.28244 .44618 L
.28254 .44643 L
.28264 .44659 L
.28274 .44664 L
.28279 .44664 L
.28285 .44661 L
.28295 .44648 L
.28305 .44627 L
.28315 .44595 L
.28333 .44516 L
.28355 .44388 L
.28375 .44233 L
.2842 .4376 L
.28461 .43215 L
.28504 .42492 L
.28583 .40875 L
.28732 .3707 L
.28904 .32157 L
.29059 .28005 L
.29137 .26234 L
.29221 .2465 L
.2926 .24053 L
.29301 .23517 L
.29338 .23113 L
.29374 .2281 L
.29393 .22678 L
.29414 .22561 L
.29433 .22478 L
.2945 .2242 L
.2946 .22396 L
.29469 .22379 L
.29479 .22365 L
.29485 .22361 L
.2949 .22358 L
.295 .22357 L
.29506 .22359 L
.29511 .22363 L
.29521 .22375 L
.29532 .22393 L
.29542 .22417 L
.29551 .22443 L
.29571 .2252 L
.2959 .22607 L
.29609 .22717 L
.29679 .23276 L
.29755 .24128 L
.29837 .25271 L
.29984 .27716 L
.30143 .30498 L
Mistroke
.30226 .31861 L
.30316 .33142 L
.30394 .34087 L
.30436 .34506 L
.30482 .34888 L
.30523 .35173 L
.30561 .35378 L
.30597 .35524 L
.30615 .3558 L
.30635 .35626 L
.30646 .35645 L
.30656 .35658 L
.30666 .3567 L
.30672 .35674 L
.30678 .35677 L
.30688 .3568 L
.30693 .3568 L
.30698 .35679 L
.30708 .35674 L
.30718 .35667 L
.30727 .35657 L
.30736 .35644 L
.30753 .35612 L
.30774 .35562 L
.30793 .35505 L
.30834 .35341 L
.30879 .35109 L
.30961 .34566 L
.3129 .31531 L
.31454 .30094 L
.31534 .29526 L
.31607 .29108 L
.31644 .28939 L
.31683 .28785 L
.31717 .28677 L
.31755 .28586 L
.31775 .28548 L
.31794 .2852 L
.31815 .28499 L
.31826 .2849 L
.31837 .28484 L
.31846 .28481 L
.31854 .2848 L
.31864 .2848 L
.31874 .28481 L
.31884 .28485 L
.31894 .2849 L
.31903 .28497 L
.31912 .28505 L
.31931 .28526 L
Mistroke
.31952 .28555 L
.31988 .28625 L
.32032 .28734 L
.32072 .28856 L
.32241 .29547 L
.32407 .30355 L
.32561 .31059 L
.32709 .31592 L
.32785 .31784 L
.32827 .31869 L
.32868 .31931 L
.32905 .31974 L
.32927 .31993 L
.32947 .32005 L
.32957 .32011 L
.32967 .32015 L
.32977 .32018 L
.32987 .3202 L
.32992 .32021 L
.32997 .32021 L
.33003 .32022 L
.33009 .32022 L
.33019 .32021 L
.33024 .3202 L
.33029 .32019 L
.33039 .32017 L
.33048 .32014 L
.33066 .32006 L
.33087 .31993 L
.33106 .31978 L
.33143 .31942 L
.33178 .31899 L
.33256 .31777 L
.33339 .31617 L
.33487 .31289 L
.33647 .3094 L
.33792 .3068 L
.33873 .30573 L
.33949 .30498 L
.33991 .30468 L
.34029 .30448 L
.34049 .3044 L
.34072 .30434 L
.34083 .30431 L
.34095 .30429 L
.341 .30429 L
.34106 .30428 L
.34117 .30427 L
.34127 .30427 L
.34132 .30427 L
Mistroke
.34137 .30427 L
.34147 .30427 L
.34157 .30428 L
.34166 .30429 L
.34174 .30431 L
.34193 .30435 L
.34214 .30441 L
.34233 .30447 L
.34275 .30466 L
.34351 .30513 L
.34423 .30569 L
.3473 .30854 L
.34888 .30976 L
.34976 .31027 L
.35056 .31059 L
.35096 .31071 L
.35117 .31076 L
.35137 .31079 L
.35155 .31082 L
.35172 .31084 L
.35191 .31086 L
.35201 .31086 L
.35211 .31087 L
.35221 .31087 L
.35231 .31087 L
.35237 .31087 L
.35242 .31087 L
.35253 .31087 L
.35263 .31087 L
.35273 .31086 L
.35291 .31084 L
.35313 .31082 L
.35333 .31079 L
.35378 .31071 L
.35463 .3105 L
.35543 .31024 L
.35692 .30969 L
.3584 .30916 L
.35923 .3089 L
.36001 .3087 L
.36079 .30854 L
.36122 .30848 L
.36161 .30843 L
.36203 .30839 L
.36226 .30837 L
.36248 .30836 L
.36267 .30835 L
.36278 .30835 L
.36288 .30835 L
.36293 .30835 L
Mistroke
.36299 .30835 L
.36308 .30835 L
.36319 .30835 L
.36325 .30835 L
.3633 .30835 L
.36341 .30835 L
.36346 .30835 L
.36351 .30835 L
.36371 .30836 L
.36382 .30836 L
.36393 .30836 L
.36415 .30837 L
.36456 .3084 L
.36494 .30843 L
.36643 .3086 L
.36809 .30883 L
.36962 .30902 L
.37039 .30909 L
.37111 .30915 L
.37151 .30918 L
.37194 .3092 L
.37233 .30922 L
.37269 .30923 L
.37289 .30923 L
.37307 .30924 L
.37317 .30924 L
.37328 .30924 L
.37337 .30924 L
.37347 .30924 L
.37357 .30924 L
.37366 .30924 L
.37375 .30924 L
.37385 .30924 L
.37394 .30924 L
.37404 .30924 L
.37412 .30924 L
.3742 .30924 L
.37442 .30924 L
.37462 .30924 L
.37506 .30923 L
.37547 .30922 L
.37586 .3092 L
.37895 .30907 L
.38052 .30901 L
.38141 .30898 L
.38183 .30897 L
.38224 .30896 L
.38262 .30896 L
.38304 .30895 L
.38322 .30895 L
Mistroke
.38341 .30895 L
.3836 .30895 L
.38376 .30895 L
.38387 .30895 L
.38392 .30895 L
.38398 .30895 L
.38407 .30895 L
.38417 .30895 L
.38423 .30895 L
.38428 .30895 L
.38438 .30895 L
.38444 .30895 L
.38449 .30895 L
.38461 .30895 L
.3847 .30895 L
.38479 .30895 L
.38499 .30895 L
.38519 .30895 L
.3854 .30895 L
.38621 .30896 L
.3871 .30897 L
.38871 .30899 L
.39042 .30901 L
.39123 .30902 L
.39197 .30903 L
.39275 .30903 L
.39316 .30904 L
.39337 .30904 L
.39359 .30904 L
.39379 .30904 L
.39397 .30904 L
.39405 .30904 L
.39415 .30904 L
.39423 .30904 L
.39432 .30904 L
.39441 .30904 L
.39452 .30904 L
.39462 .30904 L
.39468 .30904 L
.39473 .30904 L
.39482 .30904 L
.39492 .30904 L
.39502 .30904 L
.39511 .30904 L
.39532 .30904 L
.39552 .30904 L
.39596 .30904 L
.39675 .30903 L
.39825 .30903 L
.39988 .30902 L
Mistroke
.40068 .30902 L
.40141 .30902 L
.40216 .30901 L
.40287 .30901 L
.40326 .30901 L
.40363 .30901 L
.40384 .30901 L
.40403 .30901 L
.40413 .30901 L
.40424 .30901 L
.40435 .30901 L
.40445 .30901 L
.40455 .30901 L
.40465 .30901 L
.40473 .30901 L
.40483 .30901 L
.40493 .30901 L
.40498 .30901 L
.40504 .30901 L
.40523 .30901 L
.40541 .30901 L
.40561 .30901 L
.40596 .30901 L
.40683 .30901 L
.40762 .30901 L
.40927 .30902 L
.41008 .30902 L
.41081 .30902 L
.41152 .30902 L
.41229 .30902 L
.41271 .30902 L
.4131 .30902 L
.41347 .30902 L
.41366 .30902 L
.41387 .30902 L
.41407 .30902 L
.41418 .30902 L
.41429 .30902 L
.41438 .30902 L
.41448 .30902 L
.41459 .30902 L
.41469 .30902 L
.41478 .30902 L
.41487 .30902 L
.41495 .30902 L
.41504 .30902 L
.41514 .30902 L
.41524 .30902 L
.41543 .30902 L
.41588 .30902 L
Mistroke
.41631 .30902 L
.41711 .30902 L
.42019 .30902 L
.42102 .30902 L
.42179 .30902 L
.42259 .30902 L
.42302 .30902 L
.42324 .30902 L
.42347 .30902 L
.4237 .30902 L
.4239 .30902 L
.42399 .30902 L
.4241 .30902 L
.4242 .30902 L
.42429 .30902 L
.42434 .30902 L
.42439 .30902 L
.42449 .30902 L
.42455 .30902 L
.42461 .30902 L
.42466 .30902 L
.42472 .30902 L
.42477 .30902 L
.42483 .30902 L
.42495 .30902 L
.42517 .30902 L
.42538 .30902 L
.42557 .30902 L
.426 .30902 L
.42678 .30902 L
.42843 .30902 L
.42997 .30902 L
.43073 .30902 L
.43145 .30902 L
.43184 .30902 L
.43227 .30902 L
.43266 .30902 L
.43303 .30902 L
.43322 .30902 L
.4334 .30902 L
.4335 .30902 L
.43361 .30902 L
.43371 .30902 L
.4338 .30902 L
.4339 .30902 L
.43399 .30902 L
.43408 .30902 L
.43418 .30902 L
.43427 .30902 L
.43436 .30902 L
Mistroke
.43444 .30902 L
.43453 .30902 L
.43464 .30902 L
.43475 .30902 L
.43495 .30902 L
.43539 .30902 L
.43577 .30902 L
.43619 .30902 L
.43775 .30902 L
.43947 .30902 L
.44025 .30902 L
.44069 .30902 L
.4411 .30902 L
.44148 .30902 L
.44189 .30902 L
.44227 .30902 L
.44262 .30902 L
.44284 .30902 L
.44303 .30902 L
.44325 .30902 L
.44335 .30902 L
.44341 .30902 L
.44347 .30902 L
.44358 .30902 L
.44367 .30902 L
.44377 .30902 L
.44383 .30902 L
.44388 .30902 L
.44397 .30902 L
.44407 .30902 L
.44417 .30902 L
.44427 .30902 L
.44445 .30902 L
.44465 .30902 L
.44499 .30902 L
.44576 .30902 L
.44882 .30902 L
.44963 .30902 L
.45039 .30902 L
.45082 .30902 L
.45127 .30902 L
.45169 .30902 L
.45189 .30902 L
.45207 .30902 L
.45225 .30902 L
.45245 .30902 L
.45256 .30902 L
.45266 .30902 L
.45276 .30902 L
.45285 .30902 L
Mistroke
.45294 .30902 L
.45304 .30902 L
.45312 .30902 L
.4532 .30902 L
.45329 .30902 L
.45339 .30902 L
.45349 .30902 L
.45358 .30902 L
.45379 .30902 L
.454 .30902 L
.45438 .30902 L
.45524 .30902 L
.4567 .30902 L
.45753 .30902 L
.45832 .30902 L
.45914 .30902 L
.4599 .30902 L
.4603 .30902 L
.46072 .30902 L
.46113 .30902 L
.46137 .30902 L
.46159 .30902 L
.4618 .30902 L
.462 .30902 L
.4621 .30902 L
.46221 .30902 L
.46227 .30902 L
.46233 .30902 L
.46238 .30902 L
.46244 .30902 L
.46254 .30902 L
.46263 .30902 L
.46274 .30902 L
.46279 .30902 L
.46285 .30902 L
.46305 .30902 L
.46323 .30902 L
.46361 .30902 L
.46395 .30902 L
.46473 .30902 L
.46637 .30902 L
.46717 .30902 L
.4679 .30902 L
.46861 .30902 L
.46938 .30902 L
.4698 .30902 L
.47019 .30902 L
.47056 .30902 L
.47075 .30902 L
.47096 .30902 L
Mistroke
.47116 .30902 L
.47127 .30902 L
.47138 .30902 L
.47148 .30902 L
.47157 .30902 L
.47167 .30902 L
.47177 .30902 L
.47186 .30902 L
.47196 .30902 L
.47204 .30902 L
.47213 .30902 L
.47233 .30902 L
.47252 .30902 L
.47294 .30902 L
.47332 .30902 L
.47419 .30902 L
.47585 .30902 L
.47658 .30902 L
.47739 .30902 L
.47816 .30902 L
.47851 .30902 L
.47888 .30902 L
.47928 .30902 L
.47964 .30902 L
.47985 .30902 L
.48004 .30902 L
.48024 .30902 L
.48036 .30902 L
.48047 .30902 L
.48056 .30902 L
.48065 .30902 L
.48075 .30902 L
.48086 .30902 L
.48091 .30902 L
.48097 .30902 L
.48107 .30902 L
.48117 .30902 L
.48127 .30902 L
.48163 .30902 L
.48201 .30902 L
.48288 .30902 L
.48368 .30902 L
.48535 .30902 L
.48609 .30902 L
.4869 .30902 L
.48727 .30902 L
.48768 .30902 L
.48806 .30902 L
.4884 .30902 L
.48859 .30902 L
Mistroke
.4888 .30902 L
.4889 .30902 L
.48902 .30902 L
.48912 .30902 L
.48922 .30902 L
.48931 .30902 L
.48941 .30902 L
.48951 .30902 L
.48957 .30902 L
.48962 .30902 L
.48971 .30902 L
.4898 .30902 L
.4899 .30902 L
.48999 .30902 L
.49009 .30902 L
.49019 .30902 L
.49037 .30902 L
.49078 .30902 L
.49121 .30902 L
.4916 .30902 L
.49309 .30902 L
.49389 .30902 L
.49474 .30902 L
.49547 .30902 L
.4959 .30902 L
.49628 .30902 L
.49665 .30902 L
.49704 .30902 L
.49744 .30902 L
.49766 .30902 L
.49787 .30902 L
.49796 .30902 L
.49806 .30902 L
.49815 .30902 L
.49824 .30902 L
.49833 .30902 L
.49842 .30902 L
.49851 .30902 L
.49859 .30902 L
.49868 .30902 L
.49878 .30902 L
.49886 .30902 L
.49896 .30902 L
.49916 .30902 L
.49936 .30902 L
.49976 .30902 L
.5002 .30902 L
.501 .30902 L
.5025 .30902 L
.50333 .30902 L
Mistroke
.5041 .30902 L
.50491 .30902 L
.50533 .30902 L
.50555 .30902 L
.50579 .30902 L
.50599 .30902 L
.50621 .30902 L
.50642 .30902 L
.50661 .30902 L
.50672 .30902 L
.50683 .30902 L
.50693 .30902 L
.50698 .30902 L
.50704 .30902 L
.5071 .30902 L
.50715 .30902 L
.50721 .30902 L
.50727 .30902 L
.50733 .30902 L
.50739 .30902 L
.50744 .30902 L
.5075 .30902 L
.5076 .30902 L
.50771 .30902 L
.5079 .30902 L
.50811 .30902 L
.50833 .30902 L
.50911 .30902 L
.51083 .30902 L
.51238 .30902 L
.51316 .30902 L
.5136 .30902 L
.514 .30902 L
.51436 .30902 L
.51474 .30902 L
.51494 .30902 L
.51515 .30902 L
.51525 .30902 L
.51535 .30902 L
.51544 .30902 L
.51553 .30902 L
.51562 .30902 L
.51572 .30902 L
.51581 .30902 L
.5159 .30902 L
.516 .30902 L
.51609 .30902 L
.51619 .30902 L
.5163 .30902 L
.51641 .30902 L
Mistroke
.51653 .30902 L
.51674 .30902 L
.51713 .30902 L
.5179 .30902 L
.51861 .30902 L
.52025 .30902 L
.52105 .30902 L
.52178 .30902 L
.52214 .30902 L
.52253 .30902 L
.5229 .30902 L
.52325 .30902 L
.52343 .30902 L
.52361 .30902 L
.5238 .30902 L
.52391 .30902 L
.52401 .30902 L
.52411 .30902 L
.5242 .30902 L
.5243 .30902 L
.52436 .30902 L
.52441 .30902 L
.52451 .30902 L
.52457 .30902 L
.52462 .30902 L
.52472 .30902 L
.52482 .30902 L
.52503 .30902 L
.52522 .30902 L
.52558 .30902 L
.52639 .30902 L
.52786 .30902 L
.52863 .30902 L
.52946 .30902 L
.53023 .30902 L
.53093 .30902 L
.53132 .30902 L
.53154 .30902 L
.53174 .30902 L
.53192 .30902 L
.53209 .30902 L
.53228 .30902 L
.53238 .30902 L
.53248 .30902 L
.53258 .30902 L
.53268 .30902 L
.53273 .30902 L
.53279 .30902 L
.5329 .30902 L
.53299 .30902 L
Mistroke
.5331 .30902 L
.53318 .30902 L
.53328 .30902 L
.5335 .30902 L
.53373 .30902 L
.53415 .30902 L
.53575 .30902 L
.53659 .30902 L
.53749 .30902 L
.53828 .30902 L
.5387 .30902 L
.53916 .30902 L
.53957 .30902 L
.53995 .30902 L
.54014 .30902 L
.54034 .30902 L
.54052 .30902 L
.5407 .30902 L
.54079 .30902 L
.54089 .30902 L
.54098 .30902 L
.54107 .30902 L
.54117 .30902 L
.54122 .30902 L
.54128 .30902 L
.54137 .30902 L
.54147 .30902 L
.54156 .30902 L
.54165 .30902 L
.54182 .30902 L
.542 .30902 L
.54219 .30902 L
.54305 .30902 L
.54385 .30902 L
.54533 .30902 L
.54618 .30902 L
.54696 .30902 L
.54739 .30902 L
.54778 .30902 L
.548 .30902 L
.54823 .30902 L
.54843 .30902 L
.54866 .30902 L
.54876 .30902 L
.54887 .30902 L
.54896 .30902 L
.54906 .30902 L
.54912 .30902 L
.54918 .30902 L
.54923 .30902 L
Mistroke
.54929 .30902 L
.54939 .30902 L
.5495 .30902 L
.5496 .30902 L
.54969 .30902 L
.54979 .30902 L
.54989 .30902 L
.55007 .30902 L
.55027 .30902 L
.55069 .30902 L
.55109 .30902 L
.55184 .30902 L
.55266 .30902 L
.55352 .30902 L
.55429 .30902 L
.55469 .30902 L
.55513 .30902 L
.55553 .30902 L
.5559 .30902 L
.55626 .30902 L
.55661 .30902 L
.55682 .30902 L
.55702 .30902 L
.55719 .30902 L
.55729 .30902 L
.55738 .30902 L
.55748 .30902 L
.55757 .30902 L
.55768 .30902 L
.55773 .30902 L
.55778 .30902 L
.55789 .30902 L
.55795 .30902 L
.558 .30902 L
.5581 .30902 L
.55821 .30902 L
.55838 .30902 L
.55857 .30902 L
.55891 .30902 L
.55968 .30902 L
.56126 .30902 L
.5621 .30902 L
.56256 .30902 L
.56299 .30902 L
.5634 .30902 L
.56385 .30902 L
.56426 .30902 L
.56446 .30902 L
.56464 .30902 L
.56483 .30902 L
Mistroke
.565 .30902 L
.56518 .30902 L
.56529 .30902 L
.56539 .30902 L
.56548 .30902 L
.56558 .30902 L
.56567 .30902 L
.56576 .30902 L
.56587 .30902 L
.56592 .30902 L
.56598 .30902 L
.56607 .30902 L
.56617 .30902 L
.56627 .30902 L
.56638 .30902 L
.56658 .30902 L
.56694 .30902 L
.56776 .30902 L
.56923 .30902 L
.57005 .30902 L
.57083 .30902 L
.57124 .30902 L
.57163 .30902 L
.57206 .30902 L
.5723 .30902 L
.57251 .30902 L
.5727 .30902 L
.5729 .30902 L
.57311 .30902 L
.5732 .30902 L
.5733 .30902 L
.57339 .30902 L
.57349 .30902 L
.57359 .30902 L
.57369 .30902 L
.57378 .30902 L
.57387 .30902 L
.57395 .30902 L
.57404 .30902 L
.57414 .30902 L
.57424 .30902 L
.57446 .30902 L
.57467 .30902 L
.5749 .30902 L
.5757 .30902 L
.57728 .30902 L
.57812 .30902 L
.57857 .30902 L
.57901 .30902 L
.57942 .30902 L
Mistroke
.57987 .30902 L
.58028 .30902 L
.58047 .30902 L
.58066 .30902 L
.58084 .30902 L
.58101 .30902 L
.5812 .30902 L
.5813 .30902 L
.5814 .30902 L
.5815 .30902 L
.5816 .30902 L
.58169 .30902 L
.58178 .30902 L
.58188 .30902 L
.58194 .30902 L
.58199 .30902 L
.58209 .30902 L
.58219 .30902 L
.5824 .30902 L
.58259 .30902 L
.58295 .30902 L
.58377 .30902 L
.58524 .30902 L
.58602 .30902 L
.58645 .30902 L
.58685 .30902 L
.58755 .30902 L
.58792 .30902 L
.58833 .30902 L
.58853 .30902 L
.58875 .30902 L
.58895 .30902 L
.58914 .30902 L
.58925 .30902 L
.58936 .30902 L
.58941 .30902 L
.58947 .30902 L
.58953 .30902 L
.58959 .30902 L
.58965 .30902 L
.5897 .30902 L
.5898 .30902 L
.58986 .30902 L
.58991 .30902 L
.59002 .30902 L
.59021 .30902 L
.59039 .30902 L
.5908 .30902 L
.59164 .30902 L
.59312 .30902 L
Mistroke
.59396 .30902 L
.59437 .30902 L
.59474 .30902 L
.59511 .30902 L
.59552 .30902 L
.59574 .30902 L
.59594 .30902 L
.59615 .30902 L
.59635 .30902 L
.59655 .30902 L
.59674 .30902 L
.59684 .30902 L
.59695 .30902 L
.59706 .30902 L
.59717 .30902 L
.59723 .30902 L
.59729 .30902 L
.59739 .30902 L
.59745 .30902 L
.5975 .30902 L
.59756 .30902 L
.59762 .30902 L
.59773 .30902 L
.59782 .30902 L
.59804 .30902 L
.59825 .30902 L
.59844 .30902 L
.59888 .30902 L
.59968 .30902 L
.60117 .30902 L
.60194 .30902 L
.60267 .30902 L
.60309 .30902 L
.60347 .30902 L
.60388 .30902 L
.60409 .30902 L
.60432 .30902 L
.60453 .30902 L
.60464 .30902 L
.60475 .30902 L
.60484 .30902 L
.60494 .30902 L
.605 .30902 L
.60505 .30902 L
.60515 .30902 L
.60525 .30902 L
.60535 .30902 L
.60545 .30902 L
.60554 .30902 L
.60572 .30902 L
Mistroke
.6059 .30902 L
.60631 .30902 L
.6067 .30902 L
.60758 .30902 L
.60906 .30902 L
.60947 .30902 L
.6099 .30902 L
.61028 .30902 L
.61069 .30902 L
.61112 .30902 L
.61132 .30902 L
.61153 .30902 L
.61172 .30902 L
.61192 .30902 L
.61211 .30902 L
.61229 .30902 L
.6124 .30902 L
.61245 .30902 L
.61251 .30902 L
.61257 .30902 L
.61262 .30902 L
.61272 .30902 L
.61281 .30902 L
.61292 .30902 L
.61302 .30902 L
.61311 .30902 L
.61321 .30902 L
.61331 .30902 L
.61353 .30902 L
.61398 .30902 L
.61548 .30902 L
.61627 .30902 L
.61711 .30902 L
.61753 .30902 L
.618 .30902 L
.61842 .30902 L
.61881 .30902 L
.61901 .30902 L
.61922 .30902 L
.6194 .30902 L
.61959 .30902 L
.6197 .30902 L
.6198 .30902 L
.6199 .30902 L
.61999 .30902 L
.6201 .30902 L
.62016 .30902 L
.62022 .30902 L
.62032 .30902 L
.62038 .30902 L
Mistroke
.62043 .30902 L
.62053 .30902 L
.62059 .30902 L
.62064 .30902 L
.62074 .30902 L
.62083 .30902 L
.62104 .30902 L
.62127 .30902 L
.62206 .30902 L
.62355 .30902 L
.62438 .30902 L
.62515 .30902 L
.62554 .30902 L
.62596 .30902 L
.6262 .30902 L
.62642 .30902 L
.62664 .30902 L
.62684 .30902 L
.62704 .30902 L
.62721 .30902 L
.62741 .30902 L
.62752 .30902 L
.62762 .30902 L
.62772 .30902 L
.62783 .30902 L
.62793 .30902 L
.62802 .30902 L
.62807 .30902 L
.62812 .30902 L
.62818 .30902 L
.62824 .30902 L
.62845 .30902 L
.62862 .30902 L
.62881 .30902 L
.62915 .30902 L
.62993 .30902 L
.63151 .30902 L
.63195 .30902 L
.63241 .30902 L
.63281 .30902 L
.63324 .30902 L
.63365 .30902 L
.63383 .30902 L
.63403 .30902 L
.63439 .30902 L
.63458 .30902 L
.63476 .30902 L
.63487 .30902 L
.63498 .30902 L
.63503 .30902 L
Mistroke
.63509 .30902 L
.63519 .30902 L
.63528 .30902 L
.63537 .30902 L
.63547 .30902 L
.63557 .30902 L
.63563 .30902 L
.63569 .30902 L
.63581 .30902 L
.63603 .30902 L
.63644 .30902 L
.63795 .30902 L
.63875 .30902 L
.63958 .30902 L
.64001 .30902 L
.64048 .30902 L
.64091 .30902 L
.64131 .30902 L
.64152 .30902 L
.64171 .30902 L
.64189 .30902 L
.64209 .30902 L
.64219 .30902 L
.6423 .30902 L
.64235 .30902 L
.64241 .30902 L
.64247 .30902 L
.64252 .30902 L
.64262 .30902 L
.64268 .30902 L
.64273 .30902 L
.64283 .30902 L
.64292 .30902 L
.64302 .30902 L
.64308 .30902 L
.64313 .30902 L
.64335 .30902 L
.64354 .30902 L
.64375 .30902 L
.64464 .30902 L
.64626 .30902 L
.64707 .30902 L
.64753 .30902 L
.64796 .30902 L
.64833 .30902 L
.64874 .30902 L
.64895 .30902 L
.64917 .30902 L
.64938 .30902 L
.64957 .30902 L
Mistroke
.64968 .30902 L
.64977 .30902 L
.64986 .30902 L
.64995 .30902 L
.65006 .30902 L
.65011 .30902 L
.65016 .30902 L
.65026 .30902 L
.65036 .30902 L
.65045 .30902 L
.65054 .30902 L
.65071 .30902 L
.65109 .30902 L
.65188 .30902 L
.65275 .30902 L
.65356 .30902 L
.65433 .30902 L
.65475 .30902 L
.65521 .30902 L
.65563 .30902 L
.65583 .30902 L
.65601 .30902 L
.65619 .30902 L
.65639 .30902 L
.6566 .30902 L
.65669 .30902 L
.65679 .30902 L
.65688 .30902 L
.65698 .30902 L
.65708 .30902 L
.65717 .30902 L
.65726 .30902 L
.65736 .30902 L
.65744 .30902 L
.65752 .30902 L
.65758 .30902 L
.65764 .30902 L
.65774 .30902 L
.65794 .30902 L
.65817 .30902 L
.65838 .30902 L
.65918 .30902 L
.65997 .30902 L
.66082 .30902 L
.66162 .30902 L
.66235 .30902 L
.66273 .30902 L
.66309 .30902 L
.6633 .30902 L
.66349 .30902 L
Mistroke
.66371 .30902 L
.66391 .30902 L
.66409 .30902 L
.66418 .30902 L
.66428 .30902 L
.66436 .30902 L
.66445 .30902 L
.66454 .30902 L
.66462 .30902 L
.66472 .30902 L
.66481 .30902 L
.66491 .30902 L
.66501 .30902 L
.66519 .30902 L
.66539 .30902 L
.6662 .30902 L
.66694 .30902 L
.66781 .30902 L
.66862 .30902 L
.66935 .30902 L
.66977 .30902 L
.67014 .30902 L
.67055 .30902 L
.67078 .30902 L
.671 .30902 L
.67118 .30902 L
.67129 .30902 L
.67139 .30902 L
.67149 .30902 L
.67159 .30902 L
.67164 .30902 L
.6717 .30902 L
.6718 .30902 L
.6719 .30902 L
.67199 .30902 L
.67209 .30902 L
.67219 .30902 L
.67237 .30902 L
.67256 .30902 L
.67339 .30902 L
.67427 .30902 L
.67507 .30902 L
.67546 .30902 L
.67588 .30902 L
.67625 .30902 L
.67665 .30902 L
.67707 .30902 L
.67729 .30902 L
.67752 .30902 L
.67774 .30902 L
Mistroke
.67794 .30902 L
.67814 .30902 L
.67833 .30902 L
.67843 .30902 L
.67848 .30902 L
.67854 .30902 L
.67864 .30902 L
.67873 .30902 L
.67882 .30902 L
.67891 .30902 L
.679 .30902 L
.6791 .30902 L
.6792 .30902 L
.67932 .30902 L
.67953 .30902 L
.67992 .30902 L
.68139 .30902 L
.68221 .30902 L
.68298 .30902 L
.68337 .30902 L
.68379 .30902 L
.68401 .30902 L
.68425 .30902 L
.68446 .30902 L
.68467 .30902 L
.68486 .30902 L
.68507 .30902 L
.68516 .30902 L
.68526 .30902 L
.68544 .30902 L
.68553 .30902 L
.68564 .30902 L
.68574 .30902 L
.68583 .30902 L
.68593 .30902 L
.68599 .30902 L
.68605 .30902 L
.68615 .30902 L
.68626 .30902 L
.68645 .30902 L
.68665 .30902 L
.68703 .30902 L
.68773 .30902 L
.68849 .30902 L
.6893 .30902 L
.68977 .30902 L
.6902 .30902 L
.69063 .30902 L
.69103 .30902 L
.69141 .30902 L
Mistroke
.6916 .30902 L
.69181 .30902 L
.69202 .30902 L
.69214 .30902 L
.69225 .30902 L
.69235 .30902 L
.69246 .30902 L
.69257 .30902 L
.69266 .30902 L
.69276 .30902 L
.69286 .30902 L
.69296 .30902 L
.69305 .30902 L
.69313 .30902 L
.69322 .30902 L
.69341 .30902 L
.69361 .30902 L
.69382 .30902 L
.6942 .30902 L
.69579 .30902 L
.69623 .30902 L
.69669 .30902 L
.69709 .30902 L
.69752 .30902 L
.69793 .30902 L
.69831 .30902 L
.69866 .30902 L
.69884 .30902 L
.69904 .30902 L
.69915 .30902 L
.69926 .30902 L
.69936 .30902 L
.69946 .30902 L
.69952 .30902 L
.69957 .30902 L
.69968 .30902 L
.69974 .30902 L
.6998 .30902 L
.69986 .30902 L
.69991 .30902 L
.70001 .30902 L
.70011 .30902 L
.70021 .30902 L
.70033 .30902 L
.70072 .30902 L
.70233 .30902 L
.70317 .30902 L
.70363 .30902 L
.70406 .30902 L
.70448 .30902 L
Mistroke
.70486 .30902 L
.70528 .30902 L
.70552 .30902 L
.70574 .30902 L
.70592 .30902 L
.70603 .30902 L
.70612 .30902 L
.70629 .30902 L
.70638 .30902 L
.70648 .30902 L
.70657 .30902 L
.70663 .30902 L
.70668 .30902 L
.70679 .30902 L
.70684 .30902 L
.7069 .30902 L
.70699 .30902 L
.70709 .30902 L
.70728 .30902 L
.70767 .30902 L
.70804 .30902 L
.70888 .30902 L
.70974 .30902 L
.71017 .30902 L
.71057 .30902 L
.71094 .30902 L
.71135 .30902 L
.71176 .30902 L
.71199 .30902 L
.7122 .30902 L
.71237 .30902 L
.71257 .30902 L
.71276 .30902 L
.71287 .30902 L
.71297 .30902 L
.71305 .30902 L
.71315 .30902 L
.71325 .30902 L
.71334 .30902 L
.71343 .30902 L
.71352 .30902 L
.7136 .30902 L
.71369 .30902 L
.71379 .30902 L
.71389 .30902 L
.71399 .30902 L
.7141 .30902 L
.7145 .30902 L
.71525 .30902 L
.71612 .30902 L
Mistroke
.71692 .30902 L
.71775 .30902 L
.71818 .30902 L
.7184 .30902 L
.71864 .30902 L
.71885 .30902 L
.71904 .30902 L
.71923 .30902 L
.71941 .30902 L
.71962 .30902 L
.71973 .30902 L
.71985 .30902 L
.71995 .30902 L
.72004 .30902 L
.72015 .30902 L
.72021 .30902 L
.72026 .30902 L
.72036 .30902 L
.72046 .30902 L
.72055 .30902 L
.72064 .30902 L
.72074 .30902 L
.72085 .30902 L
.72105 .30902 L
.72178 .30902 L
.72258 .30902 L
.72344 .30902 L
.72386 .30902 L
.72426 .30902 L
.72465 .30902 L
.72501 .30902 L
.72535 .30902 L
.72572 .30902 L
.72592 .30902 L
.72612 .30902 L
.72629 .30902 L
.72648 .30902 L
.72658 .30902 L
.72667 .30902 L
.72678 .30902 L
.72688 .30902 L
.72697 .30902 L
.72706 .30902 L
.72715 .30902 L
.72725 .30902 L
.72735 .30902 L
.72745 .30902 L
.72765 .30902 L
.72788 .30902 L
.72809 .30902 L
Mistroke
.72978 .30902 L
.73052 .30902 L
.73092 .30902 L
.7313 .30902 L
.73175 .30902 L
.73197 .30902 L
.73216 .30902 L
.73255 .30902 L
.73275 .30902 L
.73296 .30902 L
.73306 .30902 L
.73317 .30902 L
.73326 .30902 L
.73336 .30902 L
.73345 .30902 L
.73355 .30902 L
.73364 .30902 L
.73372 .30902 L
.73382 .30902 L
.73393 .30902 L
.73402 .30902 L
.73412 .30902 L
.73422 .30902 L
.73434 .30902 L
.73454 .30902 L
.73531 .30902 L
.73601 .30902 L
.73676 .30902 L
.73755 .30902 L
.73796 .30902 L
.73842 .30902 L
.73862 .30902 L
.73883 .30902 L
.73922 .30902 L
.73942 .30902 L
.73964 .30902 L
.73974 .30902 L
.73984 .30902 L
.73993 .30902 L
.74003 .30902 L
.74014 .30902 L
.7402 .30902 L
.74025 .30902 L
.74035 .30902 L
.74046 .30902 L
.74052 .30902 L
.74058 .30902 L
.74064 .30902 L
.7407 .30902 L
.7408 .30902 L
Mistroke
.74092 .30902 L
.74131 .30902 L
.74168 .30902 L
.74253 .30902 L
.74332 .30902 L
.74375 .30902 L
.74415 .30902 L
.74452 .30902 L
.74486 .30902 L
.74524 .30902 L
.74543 .30902 L
.74564 .30902 L
.74582 .30902 L
.74603 .30902 L
.74624 .30902 L
.74634 .30902 L
.74644 .30902 L
.74654 .30902 L
.74664 .30902 L
.74673 .30902 L
.74683 .30902 L
.74692 .30902 L
.74701 .30902 L
.74709 .30902 L
.74718 .30902 L
.74728 .30902 L
.74738 .30902 L
.7476 .30902 L
.74782 .30902 L
.74805 .30902 L
.74885 .30902 L
.74967 .30902 L
.7501 .30902 L
.75056 .30902 L
.75096 .30902 L
.7514 .30902 L
.7518 .30902 L
.75217 .30902 L
.75238 .30902 L
.75257 .30902 L
.75278 .30902 L
.75289 .30902 L
.75301 .30902 L
.75312 .30902 L
.75322 .30902 L
.75332 .30902 L
.75342 .30902 L
.75352 .30902 L
.7536 .30902 L
.7537 .30902 L
Mistroke
.7538 .30902 L
.7539 .30902 L
.75399 .30902 L
.7542 .30902 L
.75458 .30902 L
.75529 .30902 L
.75607 .30902 L
.75691 .30902 L
.7573 .30902 L
.75771 .30902 L
.75806 .30902 L
.75844 .30902 L
.75864 .30902 L
.75884 .30902 L
.75901 .30902 L
.7592 .30902 L
.7594 .30902 L
.75959 .30902 L
.75969 .30902 L
.75979 .30902 L
.75984 .30902 L
.75989 .30902 L
.75995 .30902 L
.76001 .30902 L
.7601 .30902 L
.76018 .30902 L
.76028 .30902 L
.76037 .30902 L
.76045 .30902 L
.76053 .30902 L
.76071 .30902 L
.76108 .30902 L
.76147 .30902 L
.76229 .30902 L
.76307 .30902 L
.76376 .30902 L
.76416 .30902 L
.76452 .30902 L
.76488 .30902 L
.76528 .30902 L
.76548 .30902 L
.7657 .30902 L
.7658 .30902 L
.7659 .30902 L
.76609 .30902 L
.76619 .30902 L
.76629 .30902 L
.76634 .30902 L
.7664 .30902 L
.7665 .30902 L
Mistroke
.7666 .30902 L
.76671 .30902 L
.76679 .30902 L
.76689 .30902 L
.76701 .30902 L
.76711 .30902 L
.76734 .30902 L
.76777 .30902 L
.76857 .30902 L
.76943 .30902 L
.77016 .30902 L
.77057 .30902 L
.77096 .30902 L
.77134 .30902 L
.77154 .30902 L
.77173 .30902 L
.77191 .30902 L
.77207 .30902 L
.77225 .30902 L
.77244 .30902 L
.77254 .30902 L
.77265 .30902 L
.77274 .30902 L
.77284 .30902 L
.77289 .30902 L
.77294 .30902 L
.773 .30902 L
.77306 .30902 L
.77315 .30902 L
.77321 .30902 L
.77326 .30902 L
.77336 .30902 L
.77346 .30902 L
.77364 .30902 L
.77404 .30902 L
.77551 .30902 L
.77592 .30902 L
.77635 .30902 L
.77673 .30902 L
.77713 .30902 L
.77756 .30902 L
.77776 .30902 L
.77797 .30902 L
.77816 .30902 L
.77837 .30902 L
.77856 .30902 L
.77873 .30902 L
.77883 .30902 L
.77894 .30902 L
.77905 .30902 L
Mistroke
.77916 .30902 L
.77926 .30902 L
.77935 .30902 L
.77945 .30902 L
.77955 .30902 L
.7796 .30902 L
.77966 .30902 L
.77977 .30902 L
.77997 .30902 L
.78021 .30902 L
.78043 .30902 L
.78192 .30902 L
.78233 .30902 L
.78276 .30902 L
.78314 .30902 L
.78354 .30902 L
.78378 .30902 L
.784 .30902 L
.78421 .30902 L
.78444 .30902 L
.78463 .30902 L
.78483 .30902 L
.78494 .30902 L
.78504 .30902 L
.78524 .30902 L
.78534 .30902 L
.7854 .30902 L
.78545 .30902 L
.78554 .30902 L
.78564 .30902 L
.7857 .30902 L
.78575 .30902 L
.78585 .30902 L
.78591 .30902 L
.78596 .30902 L
.78601 .30902 L
.78607 .30902 L
.78629 .30902 L
.78648 .30902 L
.78686 .30902 L
.78833 .30902 L
.78874 .30902 L
.78917 .30902 L
.78954 .30902 L
.78995 .30902 L
.79017 .30902 L
.79038 .30902 L
.79057 .30902 L
.79079 .30902 L
.79097 .30902 L
Mistroke
.79116 .30902 L
.79136 .30902 L
.79155 .30902 L
.79166 .30902 L
.79176 .30902 L
.79181 .30902 L
.79186 .30902 L
.79192 .30902 L
.79198 .30902 L
.79203 .30902 L
.79209 .30902 L
.7922 .30902 L
.79225 .30902 L
.79231 .30902 L
.79243 .30902 L
.79254 .30902 L
.79264 .30902 L
.79282 .30902 L
.79324 .30902 L
.79407 .30902 L
.79485 .30902 L
.79555 .30902 L
.79595 .30902 L
.79631 .30902 L
.79668 .30902 L
.79708 .30902 L
.79728 .30902 L
.7975 .30902 L
.7976 .30902 L
.7977 .30902 L
.79789 .30902 L
.79799 .30902 L
.79809 .30902 L
.79815 .30902 L
.79821 .30902 L
.79831 .30902 L
.79841 .30902 L
.79851 .30902 L
.7986 .30902 L
.7987 .30902 L
.79881 .30902 L
.79892 .30902 L
.79915 .30902 L
.79958 .30902 L
.80039 .30902 L
.80125 .30902 L
.80198 .30902 L
.8024 .30902 L
.80279 .30902 L
.80298 .30902 L
Mistroke
.80319 .30902 L
.80337 .30902 L
.80357 .30902 L
.80374 .30902 L
.80384 .30902 L
.80394 .30902 L
.80403 .30902 L
.80411 .30902 L
.8042 .30902 L
.80428 .30902 L
.80437 .30902 L
.80447 .30902 L
.80456 .30902 L
.80465 .30902 L
.80475 .30902 L
.80484 .30902 L
.80495 .30902 L
.80506 .30902 L
.80545 .30902 L
.80588 .30902 L
.80674 .30902 L
.80757 .30902 L
.80831 .30902 L
.80872 .30902 L
.80911 .30902 L
.80931 .30902 L
.80952 .30902 L
.80971 .30902 L
.8099 .30902 L
.81008 .30902 L
.81017 .30902 L
.81028 .30902 L
.81037 .30902 L
.81045 .30902 L
.81054 .30902 L
.81062 .30902 L
.81071 .30902 L
.81081 .30902 L
.81092 .30902 L
.81102 .30902 L
.81111 .30902 L
.8112 .30902 L
.81139 .30902 L
.8118 .30902 L
.81222 .30902 L
.81305 .30902 L
.81383 .30902 L
.81453 .30902 L
.81492 .30902 L
.81528 .30902 L
Mistroke
.81565 .30902 L
.81585 .30902 L
.81605 .30902 L
.81625 .30902 L
.81644 .30902 L
.81654 .30902 L
.8166 .30902 L
.81665 .30902 L
.81676 .30902 L
.81686 .30902 L
.81691 .30902 L
.81697 .30902 L
.81708 .30902 L
.81713 .30902 L
.81719 .30902 L
.81731 .30902 L
.81742 .30902 L
.81752 .30902 L
.81774 .30902 L
.81854 .30902 L
.81935 .30902 L
.81979 .30902 L
.8202 .30902 L
.82059 .30902 L
.82094 .30902 L
.82132 .30902 L
.82153 .30902 L
.82174 .30902 L
.82194 .30902 L
.82211 .30902 L
.82229 .30902 L
.82246 .30902 L
.82256 .30902 L
.82266 .30902 L
.82274 .30902 L
.82284 .30902 L
.82294 .30902 L
.823 .30902 L
.82305 .30902 L
.82315 .30902 L
.82324 .30902 L
.82333 .30902 L
.82343 .30902 L
.82364 .30902 L
.824 .30902 L
.82482 .30902 L
.82558 .30902 L
.82637 .30902 L
.82679 .30902 L
.82725 .30902 L
Mistroke
.82745 .30902 L
.82766 .30902 L
.82785 .30902 L
.82805 .30902 L
.82826 .30902 L
.82836 .30902 L
.82848 .30902 L
.82858 .30902 L
.82868 .30902 L
.82878 .30902 L
.82887 .30902 L
.82893 .30902 L
.82898 .30902 L
.82903 .30902 L
.82909 .30902 L
.82919 .30902 L
.82924 .30902 L
.8293 .30902 L
.82935 .30902 L
.8294 .30902 L
.82952 .30902 L
.82964 .30902 L
.82976 .30902 L
.83019 .30902 L
.83061 .30902 L
.83138 .30902 L
.83215 .30902 L
.83254 .30902 L
.83298 .30902 L
.83334 .30902 L
.83354 .30902 L
.83374 .30902 L
.83392 .30902 L
.83411 .30902 L
.83429 .30902 L
.83446 .30902 L
.83466 .30902 L
.83477 .30902 L
.83488 .30902 L
.83498 .30902 L
.83507 .30902 L
.83517 .30902 L
.83523 .30902 L
.83528 .30902 L
.83538 .30902 L
.83547 .30902 L
.83556 .30902 L
.83567 .30902 L
.83586 .30902 L
.83603 .30902 L
Mistroke
.83691 .30902 L
.83771 .30902 L
.83847 .30902 L
.83885 .30902 L
.83926 .30902 L
.83968 .30902 L
.83992 .30902 L
.84013 .30902 L
.84033 .30902 L
.84043 .30902 L
.84054 .30902 L
.84064 .30902 L
.84075 .30902 L
.84084 .30902 L
.84094 .30902 L
.84104 .30902 L
.84109 .30902 L
.84114 .30902 L
.84124 .30902 L
.84133 .30902 L
.84139 .30902 L
.84144 .30902 L
.84154 .30902 L
.84165 .30902 L
.84177 .30902 L
.84218 .30902 L
.84256 .30902 L
.84327 .30902 L
.84405 .30902 L
.84448 .30902 L
.84489 .30902 L
.84527 .30902 L
.84547 .30902 L
.84568 .30902 L
.84587 .30902 L
.84604 .30902 L
.84622 .30902 L
.84639 .30902 L
.84657 .30902 L
.84667 .30902 L
.84677 .30902 L
.84688 .30902 L
.84698 .30902 L
.84707 .30902 L
.84717 .30902 L
.84727 .30902 L
.84736 .30902 L
.84746 .30902 L
.84756 .30902 L
.84765 .30902 L
Mistroke
.84774 .30902 L
.84793 .30902 L
.84876 .30902 L
.84963 .30902 L
.85006 .30902 L
.85045 .30902 L
.85083 .30902 L
.85125 .30902 L
.85166 .30902 L
.85189 .30902 L
.8521 .30902 L
.8523 .30902 L
.85248 .30902 L
.85265 .30902 L
.85274 .30902 L
.85282 .30902 L
.85292 .30902 L
.853 .30902 L
.8531 .30902 L
.8532 .30902 L
.8533 .30902 L
.85335 .30902 L
.85341 .30902 L
.85351 .30902 L
.8536 .30902 L
.85381 .30902 L
.854 .30902 L
.85444 .30902 L
.85524 .30902 L
.85596 .30902 L
.85636 .30902 L
.85673 .30902 L
.85714 .30902 L
.85751 .30902 L
.85786 .30902 L
.85806 .30902 L
.85824 .30902 L
.85844 .30902 L
.85863 .30902 L
.85873 .30902 L
.85883 .30902 L
.85888 .30902 L
.85893 .30902 L
.85899 .30902 L
.85905 .30902 L
.8591 .30902 L
.85916 .30902 L
.85926 .30902 L
.85937 .30902 L
.85946 .30902 L
Mistroke
.85956 .30902 L
.85967 .30902 L
.8599 .30902 L
.86077 .30902 L
.86159 .30902 L
.86233 .30902 L
.86275 .30902 L
.86314 .30902 L
.86333 .30902 L
.86354 .30902 L
.86373 .30902 L
.86393 .30902 L
.8641 .30902 L
.8643 .30902 L
.86439 .30902 L
.86448 .30902 L
.86456 .30902 L
.86464 .30902 L
.86469 .30902 L
.86475 .30902 L
.86485 .30902 L
.86491 .30902 L
.86497 .30902 L
.86502 .30902 L
.86507 .30902 L
.86517 .30902 L
.86527 .30902 L
.86533 .30902 L
.86538 .30902 L
.86548 .30902 L
.86569 .30902 L
.86588 .30902 L
.86625 .30902 L
.86696 .30902 L
.86772 .30902 L
.86816 .30902 L
.86856 .30902 L
.86896 .30902 L
.86934 .30902 L
.86953 .30902 L
.86973 .30902 L
.86993 .30902 L
.8701 .30902 L
.87031 .30902 L
.87042 .30902 L
.87053 .30902 L
.87062 .30902 L
.87073 .30902 L
.87078 .30902 L
.87083 .30902 L
Mistroke
.87093 .30902 L
.87099 .30902 L
.87105 .30902 L
.87115 .30902 L
.87121 .30902 L
.87126 .30902 L
.87139 .30902 L
.8716 .30902 L
.87182 .30902 L
.87262 .30902 L
.87343 .30902 L
.87386 .30902 L
.87432 .30902 L
.87476 .30902 L
.87515 .30902 L
.87535 .30902 L
.87555 .30902 L
.87575 .30902 L
.87593 .30902 L
.87603 .30902 L
.87613 .30902 L
.87621 .30902 L
.87631 .30902 L
.87641 .30902 L
.8765 .30902 L
.8766 .30902 L
.87666 .30902 L
.87671 .30902 L
.8768 .30902 L
.87689 .30902 L
.87697 .30902 L
.87706 .30902 L
.87726 .30902 L
.87744 .30902 L
.87829 .30902 L
.8791 .30902 L
.87989 .30902 L
.88033 .30902 L
.88074 .30902 L
.88108 .30902 L
.88128 .30902 L
.88146 .30902 L
.88166 .30902 L
.88183 .30902 L
.88193 .30902 L
.88204 .30902 L
.88214 .30902 L
.88223 .30902 L
.88233 .30902 L
.88239 .30902 L
Mistroke
.88244 .30902 L
.88254 .30902 L
.88264 .30902 L
.8827 .30902 L
.88275 .30902 L
.88285 .30902 L
.88296 .30902 L
.88308 .30902 L
.8835 .30902 L
.88388 .30902 L
.8846 .30902 L
.885 .30902 L
.88537 .30902 L
.88575 .30902 L
.88615 .30902 L
.88649 .30902 L
.88687 .30902 L
.88709 .30902 L
.88729 .30902 L
.8874 .30902 L
.88752 .30902 L
.88762 .30902 L
.88773 .30902 L
.88783 .30902 L
.88793 .30902 L
.88799 .30902 L
.88804 .30902 L
.88815 .30902 L
.88824 .30902 L
.88834 .30902 L
.88844 .30902 L
.88853 .30902 L
.88863 .30902 L
.88874 .30902 L
.88894 .30902 L
.88938 .30902 L
.89018 .30902 L
.89096 .30902 L
.89168 .30902 L
.89207 .30902 L
.89244 .30902 L
.89264 .30902 L
.89283 .30902 L
.89304 .30902 L
.89326 .30902 L
.89343 .30902 L
.89353 .30902 L
.89362 .30902 L
.8937 .30902 L
.89379 .30902 L
Mistroke
.89388 .30902 L
.89396 .30902 L
.89406 .30902 L
.89415 .30902 L
.89424 .30902 L
.89433 .30902 L
.89443 .30902 L
.89454 .30902 L
.89473 .30902 L
.89555 .30902 L
.89632 .30902 L
.89702 .30902 L
.89741 .30902 L
.89778 .30902 L
.89814 .30902 L
.89834 .30902 L
.89854 .30902 L
.89874 .30902 L
.89893 .30902 L
.89913 .30902 L
.89923 .30902 L
.89934 .30902 L
.8994 .30902 L
.89946 .30902 L
.89951 .30902 L
.89956 .30902 L
.89967 .30902 L
.89976 .30902 L
.89982 .30902 L
.89988 .30902 L
.89998 .30902 L
.90004 .30902 L
.9001 .30902 L
.90021 .30902 L
.90041 .30902 L
.9006 .30902 L
.90102 .30902 L
.90176 .30902 L
.90253 .30902 L
.90294 .30902 L
.90339 .30902 L
.90358 .30902 L
.90379 .30902 L
.90417 .30902 L
.90439 .30902 L
.90451 .30902 L
.90463 .30902 L
.90474 .30902 L
.90486 .30902 L
.90497 .30902 L
Mistroke
.90507 .30902 L
.90517 .30902 L
.90528 .30902 L
.90537 .30902 L
.90546 .30902 L
.90552 .30902 L
.90557 .30902 L
.90563 .30902 L
.90568 .30902 L
.90578 .30902 L
.90589 .30902 L
.90609 .30902 L
.9063 .30902 L
.90673 .30902 L
.90751 .30902 L
.90793 .30902 L
.90833 .30902 L
.90869 .30902 L
.90907 .30902 L
.90927 .30902 L
.90949 .30902 L
.90969 .30902 L
.90988 .30902 L
.91009 .30902 L
.91021 .30902 L
.91033 .30902 L
.91053 .30902 L
.91065 .30902 L
.91075 .30902 L
.91085 .30902 L
.91091 .30902 L
.91096 .30902 L
.91106 .30902 L
.91116 .30902 L
.91121 .30902 L
.91127 .30902 L
.91137 .30902 L
.91142 .30902 L
.91148 .30902 L
.9116 .30902 L
.91198 .30902 L
.91239 .30902 L
.91317 .30902 L
.91388 .30902 L
.91429 .30902 L
.91471 .30902 L
.91514 .30902 L
.91538 .30902 L
.9156 .30902 L
.91581 .30902 L
Mistroke
.91601 .30902 L
.91619 .30902 L
.91629 .30902 L
.91638 .30902 L
.91648 .30902 L
.91658 .30902 L
.91668 .30902 L
.91674 .30902 L
.91679 .30902 L
.91689 .30902 L
.91695 .30902 L
.917 .30902 L
.91711 .30902 L
.91722 .30902 L
.91882 .30902 L
.91926 .30902 L
.91972 .30902 L
.92012 .30902 L
.92034 .30902 L
.92056 .30902 L
.92076 .30902 L
.92097 .30902 L
.92117 .30902 L
.92136 .30902 L
.92157 .30902 L
.92169 .30902 L
.9218 .30902 L
.9219 .30902 L
.922 .30902 L
.9221 .30902 L
.92216 .30902 L
.92221 .30902 L
.92232 .30902 L
.92242 .30902 L
.92251 .30902 L
.9226 .30902 L
.92271 .30902 L
.92282 .30902 L
.92302 .30902 L
.92377 .30902 L
.92452 .30902 L
.92494 .30902 L
.92533 .30902 L
.9257 .30902 L
.9261 .30902 L
.92628 .30902 L
.92646 .30902 L
.9268 .30902 L
.92701 .30902 L
.92712 .30902 L
Mistroke
.92723 .30902 L
.92742 .30902 L
.92752 .30902 L
.92763 .30902 L
.92769 .30902 L
.92774 .30902 L
.9278 .30902 L
.92787 .30902 L
.92792 .30902 L
.92797 .30902 L
.92803 .30902 L
.92809 .30902 L
.92815 .30902 L
.9282 .30902 L
.92832 .30902 L
.92852 .30902 L
.92892 .30902 L
.92936 .30902 L
.93014 .30902 L
.93054 .30902 L
.93096 .30902 L
.93142 .30902 L
.93163 .30902 L
.93185 .30902 L
.93206 .30902 L
.93225 .30902 L
.93244 .30902 L
.93262 .30902 L
.93283 .30902 L
.93294 .30902 L
.93306 .30902 L
.93311 .30902 L
.93317 .30902 L
.93327 .30902 L
.93337 .30902 L
.93347 .30902 L
.93357 .30902 L
.93367 .30902 L
.93375 .30902 L
.93385 .30902 L
.93406 .30902 L
.93425 .30902 L
.93498 .30902 L
.93584 .30902 L
.93626 .30902 L
.93664 .30902 L
.93699 .30902 L
.93736 .30902 L
.93756 .30902 L
.93774 .30902 L
Mistroke
.93793 .30902 L
.93814 .30902 L
.93836 .30902 L
.93848 .30902 L
.93859 .30902 L
.93869 .30902 L
.93874 .30902 L
.93879 .30902 L
.9389 .30902 L
.93896 .30902 L
.93901 .30902 L
.93911 .30902 L
.9392 .30902 L
.9393 .30902 L
.93941 .30902 L
.93959 .30902 L
.9398 .30902 L
.94061 .30902 L
.94148 .30902 L
.94183 .30902 L
.94221 .30902 L
.94263 .30902 L
.94302 .30902 L
.94323 .30902 L
.94342 .30902 L
.94363 .30902 L
.94374 .30902 L
.94385 .30902 L
.94396 .30902 L
.94405 .30902 L
.94414 .30902 L
.94423 .30902 L
.94433 .30902 L
.94443 .30902 L
.94453 .30902 L
.94459 .30902 L
.94464 .30902 L
.94474 .30902 L
.94483 .30902 L
.94501 .30902 L
.9452 .30902 L
.9454 .30902 L
.94612 .30902 L
.94693 .30902 L
.94732 .30902 L
.94769 .30902 L
.94811 .30902 L
.94833 .30902 L
.94857 .30902 L
.94875 .30902 L
Mistroke
.94895 .30902 L
.94906 .30902 L
.94916 .30902 L
.94927 .30902 L
.94937 .30902 L
.94946 .30902 L
.94957 .30902 L
.94966 .30902 L
.94975 .30902 L
.94984 .30902 L
.94994 .30902 L
.95 .30902 L
.95005 .30902 L
.95015 .30902 L
.95025 .30902 L
.95035 .30902 L
.95054 .30902 L
.95089 .30902 L
.95176 .30902 L
.95255 .30902 L
.95294 .30902 L
.95336 .30902 L
.95356 .30902 L
.95376 .30902 L
.95413 .30902 L
.95433 .30902 L
.95455 .30902 L
.95465 .30902 L
.95475 .30902 L
.95484 .30902 L
.95493 .30902 L
.95504 .30902 L
.95509 .30902 L
.95515 .30902 L
.95526 .30902 L
.95536 .30902 L
.95541 .30902 L
.95548 .30902 L
.95554 .30902 L
.9556 .30902 L
.9557 .30902 L
.95576 .30902 L
.95581 .30902 L
.95621 .30902 L
.95662 .30902 L
.95736 .30902 L
.95815 .30902 L
.95861 .30902 L
.95883 .30902 L
.95903 .30902 L
Mistroke
.95943 .30902 L
.95964 .30902 L
.95987 .30902 L
.96006 .30902 L
.96024 .30902 L
.96035 .30902 L
.96044 .30902 L
.96055 .30902 L
.9606 .30902 L
.96066 .30902 L
.96076 .30902 L
.96086 .30902 L
.96094 .30902 L
.96103 .30902 L
.96113 .30902 L
.96124 .30902 L
.96143 .30902 L
.96177 .30902 L
.96215 .30902 L
.96295 .30902 L
.96371 .30902 L
.96413 .30902 L
.96435 .30902 L
.96458 .30902 L
.9648 .30902 L
.965 .30902 L
.9652 .30902 L
.96539 .30902 L
.96548 .30902 L
.96558 .30902 L
.96567 .30902 L
.96576 .30902 L
.96587 .30902 L
.96597 .30902 L
.96608 .30902 L
.96617 .30902 L
.96627 .30902 L
.96636 .30902 L
.96646 .30902 L
.96652 .30902 L
.96657 .30902 L
.96678 .30902 L
.967 .30902 L
.96848 .30902 L
.96888 .30902 L
.96925 .30902 L
.96968 .30902 L
.96987 .30902 L
.97007 .30902 L
.97024 .30902 L
Mistroke
.97044 .30902 L
.97061 .30902 L
.97078 .30902 L
.97097 .30902 L
.97107 .30902 L
.97117 .30902 L
.97126 .30902 L
.97135 .30902 L
.97144 .30902 L
.97154 .30902 L
.97164 .30902 L
.9717 .30902 L
.97175 .30902 L
.97181 .30902 L
.97186 .30902 L
.97198 .30902 L
.97218 .30902 L
.97237 .30902 L
.97327 .30902 L
.97368 .30902 L
.97411 .30902 L
.97451 .30902 L
.97489 .30902 L
.97519 .30902 L
.97551 .30902 L
.97569 .30902 L
.97586 .30902 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{421.375, 260.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008>0001AB000`400?l00000o`00003ooooooooo
oooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo
003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooo
oooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool0
0?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooooooo
ool@ooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooo
ooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo0ol0003o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0
003oooooooooo`0gooooo`03o`000?oooooooooo0?ooooooX_ooool0033ooooo00?o0000oooooooo
ool0=oooool00ol0003oooooooooo`3ooooooj;ooooo000`ooooo`03o`000?oooooooooo03Oooooo
0_l0003ooooooj?ooooo000`ooooo`03o`000?oooooooooo03Oooooo0_l0003ooooooj?ooooo000`
ooooo`03o`000?oooooooooo03Oooooo0_l0003ooooooj?ooooo000`ooooo`03o`000?oooooooooo
03Oooooo0_l0003ooooooj?ooooo000`ooooo`?o0000=oooool2o`000?ooooooXoooool0033ooooo
00?o0000ooooooooool0=oooool2o`000?ooooooXoooool0033ooooo00?o0000ooooooooool0=ooo
ool2o`000?ooooooXoooool0033ooooo00?o0000ooooooooool0=oooool2o`000?ooooooXoooool0
033ooooo00?o0000ooooooooool0=oooool2o`000?ooooooXoooool0033ooooo00?o0000oooooooo
ool0=oooool2o`000?ooooooXoooool0033ooooo00?o0000ooooooooool0=oooool2o`000?oooooo
Xoooool0033ooooo00?o0000ooooooooool0=_ooool00ol0003oooooo`00003ooooooj?ooooo000`
ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooool00000oooooonSooooo`00<?ooool00ol0
003oooooooooo`0fooooo`03o`000?oooooo00000?ooooooXoooool0033ooooo00?o0000oooooooo
ool0=_ooool00ol0003oooooo`00003ooooooj?ooooo000`ooooo`?o0000=_ooool00ol0003ooooo
o`00003ooooooj?ooooo000`ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooool00000oooo
oonSooooo`00<?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooo00000?ooooooXoooool0
033ooooo00?o0000ooooooooool0=_ooool00ol0003oooooo`00003ooooooj?ooooo000`ooooo`03
o`000?oooooooooo03Kooooo00?o0000ooooool00000oooooonSooooo`00<?ooool00ol0003ooooo
ooooo`0fooooo`03o`000?oooooo00000?ooooooXoooool0033ooooo00?o0000ooooooooool0:ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooo00000?ooooooXoooool0013ooooo0_o^k^h3
ooooo`;ok^k^6Oooool00ol0003oooooooooo`0[ooooo`;o00002Oooool00ol0003oooooo`00003o
oooooj?ooooo000;ooooo`;o000000[o410@ooooooooooook^k^oeEEEOo^k^koooooonk^k_mEEEGo
k^k^0oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h:ooooo`03o`000?oo
oooooooo02_ooooo0_l00009ooooo`03o`000?oooooo00000?ooooooXoooool000cooooo00?o0000
ooooooooool00_ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00[ooooo00?o0000ooooooooool0:oooool2o`0000Wooooo
00?o0000ooooool00000oooooonSooooo`0000?oooooo`000?l000001?l00002ooooo`Go00001?oo
ool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooo
oa0@400:ooooo`03o`000?oooooooooo02_ooooo0_l00009ooooo`03o`000?oooooo00000?oooooo
Xoooool000Wooooo00CoA4A4omgMgOoooooo00001?ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Ko
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000[ooooo00?o0000oooo
ooooool0:oooool2o`0000Wooooo00?o0000ooooool00000oooooonSooooo`002Oooool01?oMgMgo
EEEEooooool00003ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000:ooooo`Co0000:_ooool2o`0000Wooooo
00?o0000ooooool00000oooooonSooooo`002_ooool00omgMgOoc<c<o`000003ooooo`;ok^k^0ooo
ool2onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00[ooooo
00?o0000ooooooooool0:oooool2o`0000Wooooo00Co0000oooooooooooo0000oooooonRooooo`00
2_ooool00oo^k^koA4A4o`00000?ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`03ooooo`;o00001Oooool00ol0003oooooooooo`0[ooooo`;o00002Oooool01?l0003o
ooooooooool0003ooooooj;ooooo000;ooooo`03ogMgMol0003ooooo00cooooo00?oEEEEofIVI_l0
00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooooooo`0[ooooo`;o00002Oooool01?l0003oooooooooool0003ooooooj;ooooo000X
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0:oooool2o`0000Wooooo00Co
0000oooooooooooo0000oooooonRooooo`00:?ooool3o`0000Gooooo00?o0000ooooooooool0:ooo
ool2o`0000Wooooo00Co0000oooooooooooo0000oooooonRooooo`00:Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo02_ooooo0_l00009ooooo`04o`000?ooooooooooo`000?oooooo
X_ooool002[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0[ooooo`;o00002Ooo
ool01?l0003oooooooooool0003ooooooj;ooooo000`ooooo`03o`000?oooooooooo02[ooooo00?o
0000ooooool000002Oooool01?l0003oooooooooool00008ooooo`;o0000oooooonHooooo`00<?oo
ool00ol0003oooooooooo`0Zooooo`03o`000?oooooo000000Wooooo00Co0000oooooooooooo0000
2?ooool2o`000?ooooooV?ooool0033ooooo00?o0000ooooooooool0:_ooool00ol0003oooooo`00
0009ooooo`04o`000?ooooooooooo`0000Sooooo0_l0003ooooooiSooooo000`ooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooool000002Oooool01?l0003oooooooooool00008ooooo`;o0000
oooooonHooooo`00<?ooool3o`0002[ooooo00Co0000oooooooooooo00002?ooool01?l0003ooooo
ooooool00008ooooo`;o0000oooooonHooooo`00<?ooool00ol0003oooooooooo`0Zooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002?ooool2o`000?ooooooV?ooool0033o
oooo00?o0000ooooooooool0:_ooool01?l0003oooooooooool00008ooooo`04o`000?oooooooooo
o`0000Sooooo0_l0003ooooooiSooooo000`ooooo`03o`000?oooooooooo02[ooooo00Co0000oooo
oooooooo00001oooool01Ol0003ooooooooooooooooo000000Sooooo0_l0003ooooooiSooooo000`
ooooo`03o`000?oooooooooo02[ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooo
oooooooo000000Sooooo0_l0003ooooooiSooooo000`ooooo`03o`000?oooooooooo02[ooooo00Co
0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Sooooo0_l0003ooooooiSo
oooo000`ooooo`03o`000?oooooooooo02[ooooo00Co0000oooooooooooo00001oooool01Ol0003o
oooooooooooooooo000000Sooooo0_l0003ooooooiSooooo000`ooooo`03o`000?oooooooooo02[o
oooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Sooooo0_l0003o
oooooiSooooo000`ooooo`03o`000?oooooooooo02[ooooo00Co0000oooooooooooo00001oooool0
1Ol0003ooooooooooooooooo000000Sooooo0_l0003ooooooiSooooo000`ooooo`03o`000?oooooo
oooo02[ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Sooooo
0_l0003ooooooiSooooo000`ooooo`03o`000?oooooooooo02[ooooo00Co0000oooooooooooo0000
1oooool01Ol0003ooooooooooooooooo000000Sooooo0_l0003ooooooiSooooo000`ooooo`03o`00
0?oooooooooo02[ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000
00Oooooo00?o0000ooooool00000oooooonHooooo`00<?ooool3o`0002[ooooo00Co0000oooooooo
oooo00001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000oooo
oonGooooo`00<?ooool00ol0003oooooooooo`0Zooooo`04o`000?ooooooooooo`0000Oooooo00Go
0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`000?ooooooUoooool0033ooooo
00?o0000ooooooooool0:_ooool01?l0003oooooooooool00007ooooo`05o`000?oooooooooooooo
ool000001oooool01?l0003oooooooooool0003ooooooiOooooo000`ooooo`03o`000?oooooooooo
02[ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co
0000oooooooooooo0000oooooonGooooo`00<?ooool00ol0003oooooooooo`0Zooooo`04o`000?oo
ooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`00
0?ooooooUoooool0033ooooo00?o0000ooooooooool0:_ooool01?l0003oooooooooool00007oooo
o`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool0003ooooooiOooooo000`
ooooo`03o`000?oooooooooo02[ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooo
oooooooo000000Oooooo00Co0000oooooooooooo0000oooooonGooooo`00<?ooool00ol0003ooooo
ooooo`0Yooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo0000
00Oooooo00Co0000oooooooooooo0000oooooonGooooo`00<?ooool00ol0003oooooooooo`0Yoooo
o`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co
0000oooooooooooo0000oooooonGooooo`00<?ooool00ol0003oooooooooo`0Yooooo`05o`000?oo
ooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooo
oooo0000oooooonGooooo`00<?ooool00ol0003oooooooooo`0Yooooo`05o`000?oooooooooooooo
ool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000oooo
oonGooooo`00<?ooool3o`0002Wooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oo
ooooooooooooool000001oooool01?l0003oooooooooool0003ooooooiOooooo000`ooooo`03o`00
0?oooooooooo02Wooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooooooooooo
ool000001oooool01?l0003oooooooooool0003ooooooiOooooo000`ooooo`03o`000?oooooooooo
02Wooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001ooo
ool01?l0003oooooooooool0003ooooooiOooooo000`ooooo`03o`000?oooooooooo02Wooooo00Go
0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool01?l0003o
ooooooooool0003ooooooiOooooo000`ooooo`03o`000?oooooooooo02Wooooo00Go0000oooooooo
ooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool0
003ooooooiOooooo000`ooooo`03o`000?oooooooooo02Wooooo00Go0000ooooooooooooooooo`00
0007ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool0003ooooooiOo
oooo000`ooooo`03o`000?oooooooooo02Wooooo00Go0000ooooooooooooooooo`000007ooooo`05
o`000?ooooooooooooooool000001oooool01?l0003oooooooooool0003ooooooiOooooo000@oooo
o`;ok^k^0oooool2onk^kQWooooo00?o0000ooooooooool0:Oooool01Ol0003ooooooooooooooooo
000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`000?oooooo
Uoooool000Wooooo1Ol00002ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co
000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP[ooooo00?o0000ooooooooool0:Ooo
ool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04
o`000?ooooooooooo`000?ooooooUoooool000Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A003oooo
o`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02_ooool00ol0003oooooooooo`0Yooooo`05o`000?ooooooooooooooool00000
1oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000oooooonGoooo
o`0000?oooooo`000?l000001?l00003ooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?ogMgMo`000?oM
gMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41002_ooool00ol0
003oooooooooo`0Yooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooo
oooo000000Oooooo00Co0000oooooooooooo0000oooooonGooooo`002oooool00onHV9So8B4Qonk^
kP03ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000002_ooool00ol0003oooooooooo`0Yooooo`05o`000?oooooooooooooo
ool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000oooo
oonGooooo`003?ooool02omgMgOoIVIVooooooooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^
00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000[ooooo1?l0000X
ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo
00Co0000oooooooooooo0000oooooonGooooo`003Oooool00ol0003oooooooooo`02onk^kP?ooooo
0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400:ooooo`03
o`000?oooooooooo02Wooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooooooo
ooooool000001oooool01?l0003oooooooooool0003ooooooiOooooo0009ooooo`05o`000?nj^[[o
oooooiRHV?l@41003_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
0oooool2o`0000Gooooo00?o0000ooooooooool0:Oooool01Ol0003ooooooooooooooooo000000Oo
oooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`000?ooooooUoooool0
00Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP02ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0
:Oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007oooo
o`04o`000?ooooooooooo`000?ooooooUoooool002Sooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooooooo`0Yooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooo
oooooooo000000Oooooo00Co0000oooooooooooo0000oooooonGooooo`00:?ooool3o`0000Gooooo
00?o0000ooooooooool0:Oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooooooo
ooooooooo`000007ooooo`04o`000?ooooooooooo`000?ooooooUoooool002Wooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Nooooo`;o00002Oooool01Ol0003ooooooooooooooooo
000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`000?oooooo
Uoooool002[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Nooooo`;o00002Ooo
ool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04
o`000?ooooooooooo`000?ooooooUoooool0033ooooo00?o0000ooooooooool07_ooool2o`0000Wo
oooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool0
1?l0003oooooooooool0003ooooooiOooooo000`ooooo`03o`000?oooooooooo01kooooo0_l00009
ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo
00Co0000oooooooooooo0000oooooonGooooo`00<?ooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooo000000Sooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooooooooooo
ool000001oooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo0?ooooooS?ooool0
033ooooo00?o0000ooooooooool07_ooool00ol0003oooooo`000008ooooo`05o`000?oooooooooo
ooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000
2?ooool2o`000?ooooooSOooool0033ooooo0ol0000Nooooo`03o`000?oooooo000000Sooooo00Go
0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool01?l0003o
ooooooooool00008ooooo`;o0000oooooon=ooooo`00<?ooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooo000000Sooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooooooo
ooooool000001_ooool01Ol0003ooooooooooooooooo000000Sooooo0_l0003oooooohgooooo000`
ooooo`03o`000?oooooooooo01gooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooo
oooooooo000000Oooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?oooooooooooooo
ool000002?ooool2o`000?ooooooSOooool0033ooooo00?o0000ooooooooool07Oooool01?l0003o
ooooooooool00008ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooo
oooo000000Kooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?oooooo
SOooool0033ooooo00?o0000ooooooooool07Oooool01?l0003oooooooooool00008ooooo`05o`00
0?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000oooo
ooooooooooooo`000007ooooo`03o`000?oooooo00000?ooooooSOooool0033ooooo00?o0000oooo
ooooool07Oooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool000001ooo
ool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000007ooooo`03
o`000?oooooo00000?ooooooSOooool0033ooooo00?o0000ooooooooool07Oooool01?l0003ooooo
ooooool00008ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo
000000Kooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?ooooooSOoo
ool0033ooooo00?o0000ooooooooool07Oooool01?l0003oooooooooool00008ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?oooooo
SOooool0033ooooo00?o0000ooooooooool07Oooool01?l0003oooooooooool00008ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?oo
ooooSOooool0033ooooo00?o0000ooooooooool07Oooool01?l0003oooooooooool00008ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?oooooooooo
o`000?ooooooS?ooool0033ooooo00?o0000ooooooooool07Oooool01?l0003oooooooooool00008
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?oo
ooooooooo`000?ooooooS?ooool0033ooooo00?o0000ooooooooool07Oooool01?l0003ooooooooo
ool00008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`04ooooo`04o`000?ooooooooooo`000?ooooooS?ooool0033ooooo0ol0000Mooooo`04o`00
0?ooooooooooo`0000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Cooooo00Co0000oooooooooooo0000oooooon<ooooo`00<?ooool00ol0003o
ooooooooo`0Mooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo0000oooooon<
ooooo`00<?ooool00ol0003oooooooooo`0Looooo`05o`000?ooooooooooooooool000002?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
1?l0003oooooooooool0003oooooohcooooo000`ooooo`03o`000?oooooooooo01cooooo00Go0000
ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`000?ooooooS?ooool0033ooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Co
0000oooooooooooo0000oooooon<ooooo`00<?ooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool01?l0003oooooonk^k_l00003ooooo`;ok^k^
Eoooool2onk^kP?ooooo0_o^k^iPooooo`;ok^k^0oooool2onk^kTkooooo0_o^k^h3ooooo`;ok^k^
K?ooool0033ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`04o`000?oo
ooooooooodA4A0;o000000[o<S8bo`000?ooooook^k^o`000?o^k^koooooonk^k_mEEEGok^k^0ooo
ool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^i2ooooo`Co000000Wo410@oooo
ooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb
<S;o0000oc8b<_o^k^hkooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo00goA4A4
o`000?l0003o<S8bomgMgOooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l00000
2?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^>?ooool5o`0000;ooooo00Ook^k^oeEEEOo^
k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;o
k^k^GOooool0033ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00WoMgMgo`000?ooooooooooo`000?mEEEGogMgMoeEEEOo^k^h01_ooool0
0ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0A?ooool00ol0003ooooooooo
o`02ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL0?Oooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool02OmgMgOo
<S8booooooooooook^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0hooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01Oo^k^ko
EEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg05gooooo000`ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`;o00000_ooool01?l0003ogMgMo`000?oMgMd7ooooo`03o`000?oooooo
oooo00;ooooo00Go410@oooooooooooooooooa0@4014ooooo`03o`000?oooooooooo00?ooooo00?o
gMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100
?Oooool00ol0003oooooooooo`0?ooooo`07o`000?oooooooooooooooooMgMgo0000omgMg@07oooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400iooooo`03oiRHV?lQ8B7o
k^k^00Gooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooo
ooooooooool@4100GOooool0033ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00Wo0000oc8b<_ooooooooooo`000?mEEEGogMgMoeEEEOo^
k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000A?ooool00ol0
003oooooooooo`02ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool00000?Oooool00ol0003oooooooooo`0>ooooo`09ogMgMolb
<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0
003ooooooooooooooooo000003[ooooo00?oV9RHob4Q8Oo^k^h00oooool01Oo^k^koEEEEomgMgOmE
EEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000005gooooo
000`ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
ool0003o8B4Q00;o000000Woc<c<ooooooo^k^ko0000onk^k_ooooook^k^oeEEEOo^k^h01Oooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000A?ooool02ol0003ooooooooo
ooooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000003gooooo00?o0000ooooooooool02oooool03Ol0003o8B4Qo`00
0?lb<S;oc<c<ooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool00000>oooool02omgMgOoIVIVooooooooooook^k^oeEE
EOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000005gooooo000`ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooonk^k_l000000oooool2onk^kPGo
oooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@04Cooooo00Co0000oooo
oooooooooooo0_o^k^h3ooooo`;ok^k^1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooo
ooooooooool@4100?Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo0_o^
k^h3ooooo`;ok^k^1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100
??ooool00ol0003oooooooooo`02onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo
00Go410@oooooooooooooooooa0@401Mooooo`00<?ooool3o`0001cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool000002_ooool00ol0
003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`0i
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Sooooo0_l0000cooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool2o`0002kooooo
00Go0000okZj^_ooooooV9RHoa0@400>ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`08ooooo`;o0000Doooool0033ooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Co00000oooool00ol0003oooooooooo`05ooooo`;o
000000?oIVIVo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000oooo
ooooool0=oooool00omEEEGoIVIVo`00000=ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP07ooooo`04o`000?ooooooooooo`00033ooooo00?oEEEEofIVI_l000003Ooo
ool4o`0000cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oooooo
00Co0000oooooooooooo0000;Oooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo00?oEEEEofIV
I_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oooooo00Co0000oooooooooooo0000D_oo
ool0033ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00Go0000ooooooooooooooooo`000007ooooo`;o00003Oooool4o`0000?ooooo00?o
0000ooooooooool0E?ooool4o`000005ooooool0003oooooooooool00000G_ooool4o`000005oooo
ool0003oooooooooool00000C?ooool4o`000005ooooool0003oooooooooool00000D_ooool0033o
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00Go0000ooooooooooooooooo`000007ooooo`;o00005?ooool00ol0003oooooooooo`1Ioooo
o`?o0000I?ooool3o`0005;ooooo0ol0001Cooooo`00<?ooool00ol0003oooooooooo`0Aooooo`;o
00002?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`00017ooooo00Co0000oooo
oooooooo0000Foooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo05;ooooo00?o0000
ooooooooool0D_ooool0033ooooo00?o0000ooooooooool04?ooool01?l0003oooooo`000?l00007
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00004Oooool4o`0005cooooo00?o
0000ooooooooool0I?ooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo057ooooo000`
ooooo`03o`000?oooooooooo00oooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00Co0000oooooooooooo0000oooooon2ooooo`00<?ooool00ol0003ooooooooo
o`0?ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`04o`00
0?ooooooooooo`000?ooooooB?ooool00omgMgOoIVIVooooo`0]ooooo`03ofIVI_mgMgOooooo00Oo
oooo000`ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00003oooooodKo
oooo00?ogMgMoa0@4?o^k^h0;_ooool00oo^k^ko410@omgMg@07ooooo`00<?ooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`05o`000?ooooooooooooooool000001_ooool2o`000?oooooo;?ooool2o`0000;o
oooo0_l0000<ooooo`03oeEEEOnHV9Sooooo00;o00000_ooool01ol0003oooooooooool0003o410@
onk^k_mEEED00_l000000om4A4Co^[Zjooooo`02ooooo`05oiRHV?l0003o0000odA4A?nj^[X00_oo
ool02?o^k^koEEEEo`000?l0003oA4A4okZj^_oooooo410@1Ol00003ooooo`08oa0@4?lb<S;o0000
o`000?l@413oZJVYohN7QomVIVH7ooooo`00<?ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oo
ooooooooooooool000001Oooool4o`000?oooooo:oooool01_o^k^ko8B4QohN7Qonj^[[o0000omgM
g@cooooo00Go0000ooooooooooooooooo`000002ooooo`0;o`000?ooooooooooo`000?ooooooEEEE
ogMgMoooooook^k^ogMgMol@41000oooool01Ol@413o^[Zjonk^k_mgMgOo410@00;ooooo00KoEEEE
ogMgMoooooook^k^ogMgMol@4103ooooo`03o`000?oooooooooo00Cooooo00So0000ojVYZOoooooo
oooookZj^_l0003ok^k^o`0000Oooooo003oo`000;Co00003oooool01?oMgMgo0000oa0@4?o<c<`=
ooooo`05oc8b<_ooooooooooooooool000000_ooool01_l0003oooooooooool0003oooooo`0000So
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Go
oooo00Oo^[ZjohN7QomVIVKoIVIVoa0@4?oooooo000000Oooooo000:ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`06ooooo`?o00000oooool01Ol0
003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo0_l00004
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`05o`000?ooooooooooooooool000001Oooool4o`0000Gooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Oooooo00Cok^k^ob4Q8Ol@413o
k^k^3Oooool01Olb<S;ooooooooooooooooo000000;ooooo00Go0000oooooooooooo0000ooooo`06
o`0000?ooooo00?o0000ooooooooool01?ooool6o`0000?ooooo00?o0000ooooooooool01?ooool0
2?lb<S;o8B4QogMgMomgMgOoQhN7onk^k_oooooo00001oooool000[ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Sooooo1Ol00003ooooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooooooo`04ooooo`;o00001?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooooooo
ooooool000003_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool05oooool01?lQ8B7oMgMgogMgMolb<S8=ooooo`05o`000?o^k^koooooooooool00000
0_o<c<`02ol0003oZJVYomgMgOlQ8B7ooooooeEEEOn7QhOok^k^oooooon7QhOo<S8b00?ooooo00?o
0000ooooooooool01?ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<P?ooooo00?o0000oc8b<_oM
gMd01?ooool02?l0003o^[Zjooooooo^k^koMgMgo`000?o^k^ko00001oooool0033ooooo00?o0000
ooooooooool02_ooool2o`0000Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo0000F_ooool00ol0003ooooooooo
o`1Kooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool05_ooool2o`0000;ooooo0_l0
000<ooooo`0>oeEEEOmgMgOooooooa0@4?l0003o8B4Qo`000?mgMgOo410@o`000?nYZJWoooooonk^
k_mEEED2o`000004odA4A?o^k^kooooooa0@40Go00000oooool01_o^k^koEEEEo`000?l0003oA4A4
onk^kP;ooooo0_l000001?nYZJWo8B4Qo`000?lQ8B42ooooo`08ojVYZOlQ8B7o0000o`000?lb<S;o
0000ogMgMomEEED7ooooo`00<?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`00
0?oooooo@_ooool00ooMgMgo410@onk^kP0Booooo`03o`000?oooooooooo01Wooooo00?ok^k^oa0@
4?oMgMd01oooool0033ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool2o`000?ooooooA?ooool00omgMgOo
IVIVooooo`0Aooooo`03o`000?oooooooooo01Wooooo00?oIVIVogMgMoooool01oooool0033ooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0oooooon4ooooo`00<?ooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3oooooohCooooo000`
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooo
oooo00000?ooooooQ_ooool0033ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`05o`000?ooooooooooooooool00000oooooon6ooooo`00<?ooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo0000oooooon7ooooo`00<?ooool0
0ol0003oooooooooo`0Fooooo`05o`000?ooooooooooooooool000001oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo0000oooooon7ooooo`00<?oo
ool3o`0001Kooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool01?l0003oooooooooool0003oooooohOooooo000`ooooo`03o`00
0?oooooooooo01Kooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool01?l0003oooooooooool0003oooooohOooooo000`ooooo`03
o`000?oooooooooo01Kooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool0003oooooohOooooo000`oooo
o`03o`000?oooooooooo01Oooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo0000oooooon7ooooo`00<?ooool0
0ol0003oooooooooo`0Gooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`000?ooooooQoooool0033ooooo00?o
0000ooooooooool05oooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool0
00001_ooool01?l0003oooooooooool0003oooooohOooooo000`ooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooool000002?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooooooo
ool000001_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooool00000oooooon8
ooooo`00<?ooool00ol0003oooooooooo`0Gooooo`?o00002?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04oooo
o`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Oooooo0_l0
003oooooohSooooo000`ooooo`03o`000?oooooooooo01Sooooo0_l00008ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool00000
1oooool2o`000?ooooooR?ooool0033ooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`04ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Oo
oooo0_l0003oooooohSooooo000`ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`00003ooooo
oi7ooooo000`ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool01Ol0003o
oooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`00003ooooooi7ooooo000`oooo
o`?o00008_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool0
1Ol0003ooooooooooooooooo00000?ooooooTOooool0033ooooo00?o0000ooooooooool08oooool0
1Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`04ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo00000?oo
ooooTOooool0033ooooo00?o0000ooooooooool08oooool01Ol0003ooooooooooooooooo000000Oo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooooooo
ool000001_ooool01Ol0003ooooooooooooooooo00000?ooooooTOooool0033ooooo00?o0000oooo
ooooool08oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooo
oooooooo00000?ooooooTOooool0033ooooo00?o0000ooooooooool08oooool01Ol0003ooooooooo
oooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`00
0?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo00000?ooooooTOooool0033o
oooo00?o0000ooooooooool08oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool0
1Ol0003ooooooooooooooooo00000?ooooooTOooool0033ooooo00?o0000ooooooooool08oooool0
1Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`04ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo00000?oo
ooooTOooool0033ooooo00?o0000ooooooooool08oooool01Ol0003ooooooooooooooooo000000Oo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooooooo
ool000001_ooool01Ol0003ooooooooooooooooo00000?ooooooTOooool0033ooooo00?o0000oooo
ooooool08oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooo
oooooooo00000?ooooooTOooool0033ooooo00?o0000ooooooooool08oooool01Ol0003ooooooooo
oooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`00
0?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo00000?ooooooTOooool0033o
oooo00?o0000ooooooooool08oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool0
1Ol0003ooooooooooooooooo00000?ooooooTOooool0033ooooo00?o0000ooooooooool08oooool0
1Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`04ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo00000?oo
ooooTOooool0033ooooo0ol0000Sooooo`05o`000?ooooooooooooooool000001oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006oooo
o`04o`000?ooooooooooo`000?ooooooT_ooool0033ooooo00?o0000ooooooooool08oooool01Ol0
003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool0003ooooooi;ooooo
000`ooooo`03o`000?oooooooooo02?ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Ko
oooo00Co0000oooooooooooo0000oooooonBooooo`00<?ooool00ol0003oooooooooo`0Sooooo`05
o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`000?ooooooT_oo
ool0033ooooo00?o0000ooooooooool08oooool01Ol0003ooooooooooooooooo000000Oooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000
1_ooool01?l0003oooooooooool0003ooooooi;ooooo000`ooooo`03o`000?oooooooooo02?ooooo
00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo0000oooooonB
ooooo`003oooool2onk^kP?ooooo0_o^k^hJooooo`03o`000?oooooooooo02?ooooo00Go0000oooo
ooooooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
1Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo0000oooooonBooooo`002?oo
ool5o`0000;ooooo00Ook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413o
ooooooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool00ol0003oooooooooo`0Sooooo`05o`000?oo
ooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooooooo
ooooooooo`000006ooooo`04o`000?ooooooooooo`000?ooooooT_ooool000Sooooo00GoV9RHob4Q
8Oo^k^koooooodA4A003ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ol0003oooooooooo`0Sooooo`05o`00
0?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooo
ooooooooooooo`000007ooooo`03o`000?oooooo00000?ooooooT_ooool000Wooooo00?oV9RHob4Q
8Oo^k^h01Oooool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooo
oooooooooooooa0@400;ooooo`03o`000?oooooooooo02?ooooo00Go0000ooooooooooooooooo`00
0007ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oo
oooo00?o0000ooooool00000oooooonBooooo`002_ooool00onHV9So8B4Qonk^kP03ooooo`05onk^
k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000002oooool00ol0003oooooooooo`0Sooooo`05o`000?ooooooooooooooool000001oooool0
1Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`03o`00
0?oooooo00000?ooooooT_ooool000_ooooo00_oMgMgofIVI_ooooooooooonk^k_mEEEGok^k^oooo
ooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
000;ooooo`Co00008_ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooooooooooo
ooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003ooooo
oi;ooooo000<ooooo`03o`000?oooooooooo00;ok^k^0oooool2onk^kPGooooo00?o0000oooooooo
ool00_ooool01Ol@413ooooooooooooooooo410@00_ooooo00?o0000ooooooooool08oooool01Ol0
003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oo
ooooooooooooool000001oooool00ol0003oooooo`00003ooooooi;ooooo0008ooooo`05o`000?nj
^[[ooooooiRHV?l@41003_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool00ol0003oooooooooo`0Sooooo`05o`000?ooooooooooooooool000001oooool01Ol0
003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oo
oooo00000?ooooooT_ooool000Sooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00<ooooo`03oeEEEOmV
IVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`;o00001_ooool00ol0003ooooo
ooooo`0Tooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000007oooo
o`05o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003ooooooi;ooooo000Woooo
o`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool09?ooool01?l0003oooooooooool0
0007ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oo
oooo00?o0000ooooool00000oooooonBooooo`009oooool01?l0003oooooooooool00005ooooo`03
o`000?oooooooooo02Cooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo
000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?ooooooT_oo
ool002Oooooo0ol00006ooooo`03o`000?oooooooooo02Cooooo00Co0000oooooooooooo00001ooo
ool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`03
o`000?oooooo00000?ooooooT_ooool002Sooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Tooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000007oooo
o`05o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003ooooooi;ooooo000Yoooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool09?ooool01?l0003oooooooooool00007
ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo
00?o0000ooooool00000oooooonBooooo`00<?ooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooo000000Sooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool0
00001oooool00ol0003oooooo`00003ooooooi;ooooo000`ooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooool000002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooooooo
ooooooooo`000007ooooo`03o`000?oooooo00000?ooooooT_ooool0033ooooo00?o0000oooooooo
ool09?ooool00ol0003oooooo`000008ooooo`05o`000?ooooooooooooooool000001oooool01Ol0
003ooooooooooooooooo000000Oooooo0_l0003ooooooi?ooooo000`ooooo`?o00009?ooool00ol0
003oooooo`000008ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooo
oooo000000Sooooo00?o0000ooooooooool0oooooonAooooo`00<?ooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooo000000Sooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oo
ooooooooooooool000002?ooool00ol0003oooooooooo`3ooooooi7ooooo000`ooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooool000002?ooool01Ol0003ooooooooooooooooo000000Oooooo
00Go0000ooooooooooooooooo`00003ooooooicooooo000`ooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooool000002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooooooo
ooooooooo`00003ooooooicooooo000`ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooool0
00002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`00003o
oooooicooooo000`ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooool000002?ooool01Ol0
003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`00003ooooooicooooo000`
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooool000002Oooool01?l0003oooooooooool0
0007ooooo`05o`000?ooooooooooooooool00000oooooonLooooo`00<?ooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooo000000Wooooo00Co0000oooooooooooo00001oooool01Ol0003ooooo
oooooooooooo00000?ooooooW?ooool0033ooooo00?o0000ooooooooool09?ooool00ol0003ooooo
o`000009ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00003ooooo
oicooooo000`ooooo`03o`000?oooooooooo02Gooooo0_l00009ooooo`04o`000?ooooooooooo`00
00Oooooo00Go0000ooooooooooooooooo`00003ooooooicooooo000`ooooo`03o`000?oooooooooo
02Gooooo0_l00009ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000oooo
oonLooooo`00<?ooool00ol0003oooooooooo`0Uooooo`;o00002Oooool01?l0003oooooooooool0
0008ooooo`03o`000?oooooo00000?ooooooWOooool0033ooooo0ol0000Uooooo`03o`000?oooooo
oooo00Sooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003ooooooigooooo000`
ooooo`03o`000?oooooooooo033ooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00
003ooooooigooooo000`ooooo`03o`000?oooooooooo033ooooo00Co0000oooooooooooo00002?oo
ool00ol0003oooooo`00003ooooooigooooo000`ooooo`03o`000?oooooooooo033ooooo00Co0000
oooooooooooo00002?ooool00ol0003oooooo`00003ooooooigooooo000`ooooo`03o`000?oooooo
oooo033ooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003ooooooigooooo000`
ooooo`03o`000?oooooooooo033ooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00
003ooooooigooooo000`ooooo`03o`000?oooooooooo033ooooo00Co0000oooooooooooo00002?oo
ool00ol0003oooooo`00003ooooooigooooo000`ooooo`03o`000?oooooooooo033ooooo00Co0000
oooooooooooo00002?ooool00ol0003oooooo`00003ooooooigooooo000`ooooo`03o`000?oooooo
oooo033ooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003ooooooigooooo000`
ooooo`03o`000?oooooooooo033ooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00
003ooooooigooooo000`ooooo`03o`000?oooooooooo033ooooo00Co0000oooooooooooo00002?oo
ool00ol0003oooooo`00003ooooooigooooo000`ooooo`03o`000?oooooooooo033ooooo00Co0000
oooooooooooo00002?ooool00ol0003oooooo`00003ooooooigooooo000`ooooo`?o0000<?ooool0
1?l0003oooooooooool00008ooooo`03o`000?oooooo00000?ooooooWOooool0033ooooo00?o0000
ooooooooool0<?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?ooooooWOoo
ool0033ooooo00?o0000ooooooooool0<?ooool01?l0003oooooooooool00008ooooo`03o`000?oo
oooo00000?ooooooWOooool0033ooooo00?o0000ooooooooool0<?ooool01?l0003oooooooooool0
0008ooooo`03o`000?oooooo00000?ooooooWOooool0033ooooo00?o0000ooooooooool0<?ooool0
1?l0003oooooooooool00008ooooo`03o`000?oooooo00000?ooooooWOooool0033ooooo00?o0000
ooooooooool0<?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?ooooooWOoo
ool000oooooo0_o^k^h3ooooo`;ok^k^6_ooool00ol0003oooooooooo`0`ooooo`04o`000?oooooo
ooooo`0000Sooooo00?o0000ooooool00000oooooonMooooo`002_ooool2o`00000:oa0@4?oooooo
ooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP?ooooo1?l000002?l@413oooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^2oooool00ol0003oooooooooo`0`ooooo`04o`000?ooooooooooo`0000So
oooo00?o0000ooooool00000oooooonMooooo`002oooool00ol0003oooooooooo`02ooooo`05onk^
k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool00ol0003oooooooooo`0`ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000
ooooool00000oooooonMooooo`002?ooool5o`0000Cooooo00?ogMgMo`000?oMgMd01oooool00ol0
003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41002oooool00ol0003oooooooooo`0`
ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooonMooooo`002?ooool0
1?m4A4CogMgMooooool00004ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`0`ooooo`04
o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooonMooooo`002?ooool01?oMgMgo
EEEEooooool00003ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000;ooooo`Co0000;oooool01?l0003ooooo
ooooool00008ooooo`03o`000?oooooo00000?ooooooWOooool000Wooooo00?oMgMgolc<c?l00000
0oooool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@400;ooooo`03o`000?oooooooooo033ooooo00Co0000oooooooooooo00002?ooool00ol0
003oooooo`00003ooooooigooooo0009ooooo`03onk^k_m4A4Co000000oooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?o0000ooooooooool0<?ooool01?l0
003oooooooooool00008ooooo`03o`000?oooooo00000?ooooooWOooool000[ooooo00?oMgMgo`00
0?ooool03?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool2
o`0000Kooooo00?o0000ooooooooool0<?ooool01?l0003oooooooooool00008ooooo`03o`000?oo
oooo00000?ooooooWOooool002Oooooo00Co0000oooooooooooo00001Oooool00ol0003ooooooooo
o`0`ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooonMooooo`009ooo
ool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo033ooooo00Co0000oooooooooooo
00002?ooool00ol0003oooooo`00003ooooooigooooo000Wooooo`?o00001_ooool00ol0003ooooo
ooooo`0`ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooonMooooo`00
:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo033ooooo00Co0000oooooooooooo
00002?ooool00ol0003oooooo`00003ooooooigooooo000Yooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0<?ooool00ol0003oooooo`000009ooooo`03o`000?oooooo00000?oooooo
WOooool0033ooooo00?o0000ooooooooool0<?ooool00ol0003oooooo`000009ooooo`03o`000?oo
oooo00000?ooooooWOooool0033ooooo00?o0000ooooooooool0<?ooool00ol0003oooooo`000009
ooooo`03o`000?oooooo00000?ooooooWOooool0033ooooo00?o0000ooooooooool0<?ooool00ol0
003oooooo`000009ooooo`03o`000?oooooo00000?ooooooWOooool0033ooooo0ol0000`ooooo`03
o`000?oooooo000000Wooooo0_l0003ooooooikooooo000`ooooo`03o`000?oooooooooo037ooooo
0_l00009ooooo`;o0000oooooonNooooo`00<?ooool00ol0003oooooooooo`0aooooo`;o00002_oo
ool00ol0003oooooooooo`3ooooooicooooo000`ooooo`03o`000?oooooooooo037ooooo0_l0000:
ooooo`03o`000?oooooooooo0?ooooooW?ooool0033ooooo00?o0000ooooooooool0<Oooool2o`00
00[ooooo00?o0000ooooooooool0oooooonLooooo`00<?ooool00ol0003oooooooooo`0aooooo`;o
0000oooooonYooooo`00<?ooool00ol0003oooooooooo`0aooooo`;o0000oooooonYooooo`00<?oo
ool00ol0003oooooooooo`0aooooo`;o0000oooooonYooooo`00<?ooool00ol0003oooooooooo`0a
ooooo`;o0000oooooonYooooo`00<?ooool00ol0003oooooooooo`0aooooo`;o0000oooooonYoooo
o`00<?ooool00ol0003oooooooooo`0aooooo`;o0000oooooonYooooo`00<?ooool00ol0003ooooo
ooooo`0aooooo`;o0000oooooonYooooo`00<?ooool3o`00037ooooo0_l0003oooooojWooooo000`
ooooo`03o`000?oooooooooo037ooooo0_l0003oooooojWooooo000`ooooo`03o`000?oooooooooo
037ooooo0_l0003oooooojWooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo
00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`
ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLoooo
o`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooo
g?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3o
ooooomcooooo000`ooooo`?o0000oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomco
oooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooo
oooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo003ooooooooooooo4?ooool00?oo
ooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@
ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00X?oo
ool2o`0000Cooooo00?o^[Zjoc8b<_ooool01?ooool2o`0000Kooooo00?o0000okZj^_ooool0oooo
oomGooooo`00X?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01?ooool2oc8b<_ooooooF?ooool008gooooo0ol00002ooooo`06oc8b<_l@413ooooo
ooooooo^k^koEEEE0_l000000om4A4Co^[Zjooooo`03ooooo`03o`000?oooooooooo00;ooooo00Go
V9RHoa0@4?l0003o0000ojVYZ@04ooooo`03o`000?oooooooooo00Cooooo00?oQhN7o`000?nj^[X0
3?ooool01OnHV9So0000o`000?m4A4Co^[Zj00Wooooo1Ol00005ooooo`;o8B4Q1?ooool02oo^k^ko
<S8bo`000?l@413oc<c<ooooooo<c<cok^k^ooooooo^k^koc<c<00Cooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^4oooool01_l@413o<S8bo`000?l0003o410@ojVYZ@;ooooo
00Kok^k^oeEEEOl0003o0000odA4A?nj^[X3ooooo`05ofIVI_l0003o0000odA4A?o<c<`0j?ooool0
08kooooo00Go0000ooooooooooooc<c<oa0@4003ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo410@
1?ooool00ol0003oooooooooo`02ooooo`06o`000?nYZJWoEEEEoiRHV?mEEEGo^[Zj0oooool00ol0
003oooooooooo`04ooooo`03olc<c?l0003o410@00cooooo00Ko410@okZj^_o^k^koMgMgoa0@4?oo
ool6o`0000;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`;o8B4Q1?ooool02omEEEGoMgMg
oooooonHV9So8B4Qooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg01?ooooo00Ko0000ojVYZOoooooooooookZj^_l00002oooo
o`06oeEEEOmgMgOoooooonk^k_mgMgOo410@0_ooool01_mVIVKoMgMgooooooooooooQhN7oa0@4>So
oooo002>ooooo`05o`000?oooooooooooeEEEOn7QhL00oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00;ooooo00Ko<S8bonk^k_nHV9SoEEEEomgMgOl@4103ooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool03?ooool00onHV9So8B4Qonk^kP0<ooooo`05o`000?oooooo
ooooooooool000000_ooool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go
410@oooooooooooooooooa0@400Dooooo`05okZj^_n7QhOoIVIVofIVI_l@41000_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo0>_ooooo002>ooooo`05o`000?oooooogMgMo`000?o^
k^h00oooool6o`0000Cooooo00?o0000ooooooooool00_ooool01onj^[[oA4A4olc<c?lQ8B7ooooo
oa0@4?o<c<`00_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00?ooooo1_l00004
ooooo`03oiRHV?lQ8B7ok^k^00_ooooo00_o0000oiRHV?ooooooV9RHob4Q8Oooooook^k^oeEEEOoM
gMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000C
ooooo`06oc8b<_lQ8B7oMgMgogMgMon7QhOok^k^0_ooool6o`0000;ooooo00?o0000ooooooooool0
joooool008kooooo0ol000000ol@413oV9RHooooo`02ooooo`06oeEEEOn7QhOok^k^oooooon7QhOo
<S8b1?ooool00ol0003oooooooooo`02ooooo`07onk^k_l0003oooooo`000?ooooooIVIVohN7Q`02
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool03_ooool00omgMgOoIVIVooooo`0:
ooooo`0;o`000?mEEEGo0000oa0@4?o<c<coooooolc<c?o^k^koooooonk^k_o<c<`01_ooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000004oooool01_l0003o^[Zjooooooo^
k^koMgMgo`0000;ooooo00KoEEEEohN7Qoo^k^koooooohN7Qolb<S82ooooo`06ofIVI_mgMgOooooo
oooooon7QhOo0000j?ooool008kooooo00Go0000ooooooooooooc<c<o`000003ooooo`06onk^k_mE
EEGo0000o`000?m4A4Cok^k^1?ooool00ol0003oooooooooo`02ooooo`04ofIVI_nHV9Sooooooc8b
<P;o^[Zj00Co0000oooooooooooo00004oooool00ol@413o0000o`000003o`0000kooooo00?o0000
ooooooooool02Oooool00omEEEGoQhN7ooooo`0>ooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@4007ooooo`?o00000_ooool3o`0000Cooooo00KoZJVYob4Q8Ol0003o0000
oc8b<_l00002ooooo`06onk^k_mEEEGo0000o`000?m4A4Cok^k^0_ooool01_o^k^koIVIVo`000?l0
003oA4A4o`000>Sooooo002>ooooo`05o`000?ooooooooooolc<c?l000003Oooool00ol0003ooooo
ooooo`05ooooo`03ofIVI_n7QhOooooo00?ooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41002oooool00ooMgMgo410@oiRHV00>ooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0ooooool2ooooo`00SOooool4o`000003oa0@4?nYZJWooooo00co
oooo0_l00006ooooo`03ojVYZOm4A4Cooooo00;ooooo0_l0000Eooooo`03o`000?oooooooooo00_o
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c00<ooooo`04olc<c?m4A4Co0000oa0@40[ooooo00?oEEEE
ofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo1?l00002ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0ooooool2ooooo`00ooooool6ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0ooooool2ooooo`00ooooool6ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0ooooool2ooooo`00ooooool5ooooo`;o00000oooool2o`000?oo
oooo1?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool0
0?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooooooo
ool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00
oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooo
oa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003o
oooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo0000\
\>"],
  ImageRangeCache->{{{0, 525.688}, {324.5, 0}} -> {0, -6.34248*^6, 0, 53093}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0.309017 5.42214e-08 [
[.32684 .29652 -16.5 -12.5 ]
[.32684 .29652 16.5 0 ]
[.54329 .29652 -16.5 -12.5 ]
[.54329 .29652 16.5 0 ]
[.75974 .29652 -22.5 -12.5 ]
[.75974 .29652 22.5 0 ]
[.97619 .29652 -16.5 -12.5 ]
[.97619 .29652 16.5 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 64 6 ]
[.09789 .09213 -34.5 -6.25 ]
[.09789 .09213 0 6.25 ]
[.09789 .20057 -34.5 -6.25 ]
[.09789 .20057 0 6.25 ]
[.09789 .41746 -28.5 -6.25 ]
[.09789 .41746 0 6.25 ]
[.09789 .5259 -28.5 -6.25 ]
[.09789 .5259 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -62.8125 0 ]
[.5 .63053 62.8125 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 .30902 m
.32684 .31527 L
s
gsave
.32684 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 .30902 m
.54329 .31527 L
s
gsave
.54329 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 .30902 m
.75974 .31527 L
s
gsave
.75974 .29652 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 .30902 m
.15368 .31277 L
s
.19697 .30902 m
.19697 .31277 L
s
.24026 .30902 m
.24026 .31277 L
s
.28355 .30902 m
.28355 .31277 L
s
.37013 .30902 m
.37013 .31277 L
s
.41342 .30902 m
.41342 .31277 L
s
.45671 .30902 m
.45671 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.58658 .30902 m
.58658 .31277 L
s
.62987 .30902 m
.62987 .31277 L
s
.67316 .30902 m
.67316 .31277 L
s
.71645 .30902 m
.71645 .31277 L
s
.80303 .30902 m
.80303 .31277 L
s
.84632 .30902 m
.84632 .31277 L
s
.88961 .30902 m
.88961 .31277 L
s
.9329 .30902 m
.9329 .31277 L
s
.0671 .30902 m
.0671 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09213 m
.11664 .09213 L
s
gsave
.09789 .09213 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .20057 m
.11664 .20057 L
s
gsave
.09789 .20057 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .41746 m
.11664 .41746 L
s
gsave
.09789 .41746 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .5259 m
.11664 .5259 L
s
gsave
.09789 .5259 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.11039 .11924 m
.11414 .11924 L
s
.11039 .14635 m
.11414 .14635 L
s
.11039 .17346 m
.11414 .17346 L
s
.11039 .22768 m
.11414 .22768 L
s
.11039 .2548 m
.11414 .2548 L
s
.11039 .28191 m
.11414 .28191 L
s
.11039 .33613 m
.11414 .33613 L
s
.11039 .36324 m
.11414 .36324 L
s
.11039 .39035 m
.11414 .39035 L
s
.11039 .44457 m
.11414 .44457 L
s
.11039 .47168 m
.11414 .47168 L
s
.11039 .49879 m
.11414 .49879 L
s
.11039 .06502 m
.11414 .06502 L
s
.11039 .03791 m
.11414 .03791 L
s
.11039 .0108 m
.11414 .0108 L
s
.11039 .55301 m
.11414 .55301 L
s
.11039 .58012 m
.11414 .58012 L
s
.11039 .60723 m
.11414 .60723 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -123.812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.812 moveto
(@) show
81.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.812 moveto
(D) show
93.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2.8) show
135.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
141.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
153.000 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
157.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
166.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
184.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02453 .30902 L
.02532 .30902 L
.02614 .30902 L
.02691 .30902 L
.02854 .30902 L
.02946 .30902 L
.03029 .30902 L
.03183 .30902 L
.0335 .30902 L
.03678 .30902 L
.03994 .30902 L
.04152 .30902 L
.04222 .30902 L
.04297 .30902 L
.04317 .30902 L
.04339 .30902 L
.04357 .30902 L
.04377 .30902 L
.04388 .30902 L
.04398 .30902 L
.04407 .30902 L
.04417 .30902 L
.04426 .30902 L
.04434 .30902 L
.04443 .30902 L
.04453 .30902 L
.04459 .30902 L
.04464 .30902 L
.04475 .30902 L
.04486 .30902 L
.04498 .30902 L
.0452 .30902 L
.04541 .30902 L
.04579 .30902 L
.04621 .30902 L
.04661 .30902 L
.04698 .30902 L
.04782 .30902 L
.04863 .30902 L
.04951 .30902 L
.05033 .30902 L
.05122 .30902 L
.05284 .30902 L
.05444 .30902 L
.05612 .30902 L
.05917 .30902 L
.0624 .30902 L
.0639 .30902 L
.06468 .30902 L
Mistroke
.06552 .30902 L
.06576 .30902 L
.06598 .30902 L
.0662 .30902 L
.0664 .30902 L
.06659 .30902 L
.06669 .30902 L
.0668 .30902 L
.0669 .30902 L
.06696 .30902 L
.06702 .30902 L
.06712 .30902 L
.06722 .30902 L
.06731 .30902 L
.06742 .30902 L
.06752 .30902 L
.06762 .30902 L
.0678 .30902 L
.06799 .30902 L
.06843 .30902 L
.06883 .30902 L
.06922 .30902 L
.06962 .30902 L
.07036 .30902 L
.07123 .30902 L
.07202 .30902 L
.07356 .30902 L
.07443 .30902 L
.07523 .30902 L
.0784 .30901 L
.08144 .30901 L
.08314 .30901 L
.08469 .30901 L
.08545 .30901 L
.08586 .30901 L
.08629 .30901 L
.08666 .30901 L
.08686 .30901 L
.08708 .30901 L
.08727 .30901 L
.08745 .30901 L
.08763 .30901 L
.08771 .30901 L
.08781 .30901 L
.08791 .30901 L
.08801 .30901 L
.08806 .30901 L
.08812 .30901 L
.08818 .30901 L
.08823 .30901 L
Mistroke
.08833 .30901 L
.08842 .30901 L
.08853 .30901 L
.08863 .30901 L
.08882 .30901 L
.08899 .30901 L
.08938 .30901 L
.0896 .30901 L
.08981 .30901 L
.09019 .30901 L
.09061 .30901 L
.09106 .30901 L
.09184 .30901 L
.09267 .30901 L
.09416 .30902 L
.09572 .30903 L
.0974 .30904 L
.10072 .30907 L
.10239 .30909 L
.10392 .3091 L
.10542 .30911 L
.10617 .30912 L
.1066 .30912 L
.10681 .30912 L
.107 .30912 L
.10718 .30912 L
.10728 .30912 L
.10738 .30912 L
.10744 .30912 L
.10749 .30912 L
.1076 .30912 L
.10769 .30912 L
.10779 .30912 L
.10789 .30912 L
.108 .30912 L
.1081 .30912 L
.10819 .30912 L
.10841 .30912 L
.10862 .30912 L
.10899 .30912 L
.10933 .30912 L
.10971 .30911 L
.11011 .30911 L
.11094 .3091 L
.11183 .30908 L
.11268 .30906 L
.11345 .30903 L
.11497 .30896 L
.11663 .30887 L
.11988 .30864 L
Mistroke
.12301 .30841 L
.12383 .30836 L
.12426 .30834 L
.12472 .30832 L
.12512 .3083 L
.12533 .3083 L
.12556 .30829 L
.12577 .30829 L
.12587 .30829 L
.12596 .30829 L
.12605 .30828 L
.12615 .30828 L
.12624 .30828 L
.12633 .30828 L
.12643 .30828 L
.12649 .30828 L
.12654 .30828 L
.12665 .30829 L
.12676 .30829 L
.12687 .30829 L
.12697 .30829 L
.12716 .30829 L
.12738 .3083 L
.12759 .30831 L
.12805 .30833 L
.12842 .30836 L
.12884 .30839 L
.12967 .30848 L
.13048 .30859 L
.13122 .30872 L
.1329 .30911 L
.13441 .30957 L
.13608 .31018 L
.13933 .31149 L
.14083 .31203 L
.14162 .31225 L
.14246 .31244 L
.14289 .31251 L
.14313 .31254 L
.14335 .31256 L
.14346 .31256 L
.14356 .31257 L
.14365 .31257 L
.14375 .31258 L
.14381 .31258 L
.14386 .31258 L
.14392 .31258 L
.14397 .31258 L
.14407 .31258 L
.14412 .31258 L
Mistroke
.14418 .31258 L
.14427 .31257 L
.14437 .31257 L
.14455 .31255 L
.14477 .31253 L
.14496 .3125 L
.14539 .31242 L
.14579 .31232 L
.14657 .31204 L
.14739 .31161 L
.1481 .31114 L
.14887 .31051 L
.15043 .3089 L
.1521 .30668 L
.15541 .30152 L
.15706 .29907 L
.15786 .29806 L
.15859 .29729 L
.15896 .29697 L
.15935 .29668 L
.15973 .29646 L
.16007 .29632 L
.16026 .29626 L
.16035 .29624 L
.16044 .29622 L
.16054 .29621 L
.16063 .2962 L
.16073 .29619 L
.16079 .29619 L
.16084 .29619 L
.16094 .2962 L
.16103 .29621 L
.16113 .29623 L
.16124 .29625 L
.16145 .29631 L
.16165 .2964 L
.16203 .29662 L
.16244 .29696 L
.16282 .29737 L
.16317 .29782 L
.16402 .29926 L
.16483 .30106 L
.16643 .30587 L
.16792 .31164 L
.17107 .32647 L
.17266 .33382 L
.17411 .33945 L
.17491 .34182 L
.17528 .34269 L
.17567 .34345 L
Mistroke
.17589 .34379 L
.17609 .34404 L
.17628 .34425 L
.17647 .34439 L
.17658 .34445 L
.17664 .34447 L
.17669 .34449 L
.17679 .34452 L
.17689 .34453 L
.17695 .34453 L
.17701 .34452 L
.17711 .3445 L
.17717 .34448 L
.17722 .34446 L
.17735 .34439 L
.17744 .34432 L
.17754 .34423 L
.17772 .34403 L
.17812 .3434 L
.17847 .34264 L
.17884 .34157 L
.1797 .33826 L
.1805 .33403 L
.18214 .32199 L
.18363 .30764 L
.18684 .27096 L
.18831 .25484 L
.18915 .24686 L
.18993 .24056 L
.1907 .23572 L
.19113 .23369 L
.19153 .2323 L
.19174 .23175 L
.19194 .23136 L
.19206 .2312 L
.19216 .23109 L
.19222 .23104 L
.19228 .231 L
.19234 .23098 L
.19239 .23097 L
.19249 .23098 L
.19258 .23101 L
.19269 .23108 L
.19274 .23114 L
.19279 .2312 L
.1929 .23135 L
.19301 .23156 L
.19322 .23206 L
.1934 .23264 L
.19361 .23342 L
Mistroke
.19397 .23521 L
.19441 .23798 L
.19481 .24115 L
.19567 .25004 L
.19649 .26101 L
.19808 .28835 L
.19956 .3194 L
.2027 .39061 L
.20352 .40733 L
.20441 .42307 L
.20526 .435 L
.20566 .43955 L
.20603 .44295 L
.20641 .44563 L
.20662 .44675 L
.20681 .44758 L
.2069 .44788 L
.20699 .44814 L
.20708 .44832 L
.20716 .44847 L
.20726 .44858 L
.20734 .44864 L
.20745 .44864 L
.20754 .44857 L
.20764 .44845 L
.20774 .44825 L
.20784 .448 L
.20793 .44772 L
.20814 .44681 L
.20835 .44566 L
.20876 .44254 L
.2092 .43788 L
.20996 .42685 L
.21079 .41038 L
.21248 .36465 L
.21572 .24798 L
.21721 .19355 L
.21883 .14365 L
.21971 .12339 L
.22014 .11569 L
.22053 .11006 L
.22072 .10776 L
.22093 .10566 L
.22111 .10417 L
.22131 .1029 L
.22142 .10236 L
.22152 .10196 L
.22163 .10165 L
.22169 .10153 L
.22175 .10145 L
Mistroke
.22184 .10138 L
.2219 .10138 L
.22195 .10141 L
.22204 .10153 L
.22214 .10176 L
.22224 .10206 L
.22234 .10248 L
.22254 .10365 L
.22272 .1051 L
.2229 .10676 L
.22329 .11168 L
.22371 .11865 L
.22448 .13603 L
.22518 .15668 L
.22672 .21666 L
.22839 .29785 L
.22995 .38008 L
.23168 .46491 L
.23246 .49821 L
.23331 .52815 L
.23372 .5401 L
.23411 .54973 L
.23449 .55737 L
.23484 .563 L
.23504 .56543 L
.23525 .56751 L
.23534 .56825 L
.23544 .5689 L
.23553 .5694 L
.23561 .56976 L
.23571 .57006 L
.23582 .57025 L
.23591 .57028 L
.236 .5702 L
.23606 .57011 L
.23611 .56997 L
.23621 .56961 L
.23632 .56908 L
.23643 .56833 L
.23663 .56669 L
.2368 .56476 L
.2372 .5589 L
.23756 .55163 L
.23791 .54311 L
.23868 .51896 L
.2395 .48573 L
.24098 .40998 L
.24431 .20545 L
.24599 .11504 L
.24672 .08335 L
Mistroke
.24711 .06907 L
.24753 .05588 L
.24794 .04525 L
.24831 .03758 L
.24849 .03459 L
.24868 .03188 L
.24886 .02984 L
.24903 .02838 L
.24913 .02778 L
.24923 .02728 L
.24928 .02707 L
.24933 .02689 L
.24944 .0267 L
.24954 .02666 L
.24964 .02678 L
.24969 .02691 L
.24975 .02707 L
.24986 .02758 L
.24996 .02818 L
.25005 .02886 L
.25025 .03085 L
.25043 .03313 L
.25062 .03607 L
.25102 .04388 L
.25138 .05299 L
.2522 .08004 L
.25367 .14888 L
.25686 .34751 L
.25847 .44501 L
.25993 .51548 L
.26032 .53032 L
.26074 .54411 L
.26111 .55405 L
.26151 .56276 L
.26171 .56631 L
.26193 .56942 L
.26206 .57083 L
.26217 .57191 L
.26228 .57282 L
.26239 .57349 L
.26248 .57396 L
.26258 .5743 L
.26269 .57449 L
.26275 .57452 L
.2628 .57451 L
.2629 .57437 L
.26299 .57411 L
.26309 .57368 L
.26319 .57308 L
.2634 .57139 L
Mistroke
.26359 .56921 L
.26396 .56364 L
.26435 .5555 L
.26478 .54431 L
.26555 .51829 L
.26625 .48843 L
.26942 .31342 L
.27101 .22346 L
.27247 .15553 L
.27327 .12695 L
.27403 .1069 L
.27445 .09905 L
.27483 .09383 L
.27503 .09189 L
.27515 .09102 L
.27526 .09039 L
.27537 .08988 L
.27543 .08968 L
.27549 .08952 L
.27559 .08937 L
.27565 .08935 L
.27571 .08937 L
.27581 .08951 L
.27586 .08964 L
.27592 .08982 L
.27602 .09023 L
.27611 .09075 L
.27632 .09232 L
.27655 .09464 L
.27697 .10058 L
.27735 .10783 L
.27811 .12731 L
.27884 .15119 L
.28191 .28678 L
.28362 .36481 L
.28517 .42204 L
.28595 .44327 L
.28636 .45211 L
.28679 .45961 L
.28717 .46458 L
.28738 .46674 L
.28758 .46831 L
.28768 .46891 L
.28777 .46938 L
.28785 .46974 L
.28793 .47005 L
.28803 .47029 L
.28812 .47043 L
.28821 .4705 L
.28831 .47047 L
Mistroke
.28841 .47034 L
.2885 .47013 L
.2886 .4698 L
.28871 .46934 L
.28892 .46804 L
.28912 .46646 L
.2895 .46234 L
.28987 .45723 L
.29067 .44192 L
.29154 .42006 L
.29483 .31241 L
.29646 .26165 L
.29726 .24126 L
.29799 .22603 L
.29835 .21984 L
.29874 .21415 L
.29912 .20977 L
.29946 .2067 L
.29966 .20526 L
.29985 .2042 L
.30006 .20338 L
.30017 .20305 L
.30027 .20283 L
.30037 .2027 L
.30045 .20264 L
.30054 .20263 L
.30064 .20269 L
.30075 .20283 L
.30085 .20303 L
.30094 .20328 L
.30103 .2036 L
.30122 .20442 L
.30142 .20556 L
.30179 .20831 L
.30222 .21265 L
.30262 .21758 L
.30431 .24655 L
.3075 .31575 L
.30832 .33193 L
.3091 .34519 L
.30986 .35583 L
.31056 .36339 L
.31093 .36646 L
.31132 .369 L
.31151 .36998 L
.31171 .37083 L
.31183 .37123 L
.31193 .37154 L
.31203 .37178 L
.31214 .372 L
Mistroke
.31224 .37215 L
.3123 .37221 L
.31235 .37226 L
.31245 .3723 L
.31255 .37231 L
.31261 .37229 L
.31267 .37226 L
.31273 .37221 L
.31279 .37214 L
.31289 .37199 L
.313 .37177 L
.31322 .37119 L
.31343 .37045 L
.31382 .3686 L
.31419 .3663 L
.3146 .36323 L
.31543 .35547 L
.31691 .33793 L
.3186 .31583 L
.32015 .29747 L
.32091 .28996 L
.32174 .28335 L
.32212 .28093 L
.32253 .27879 L
.32291 .27719 L
.32326 .27609 L
.32345 .27564 L
.32365 .27525 L
.32376 .2751 L
.32387 .27497 L
.32397 .27488 L
.32407 .27482 L
.32416 .27479 L
.32425 .27478 L
.32434 .27479 L
.32445 .27483 L
.32454 .27488 L
.32462 .27495 L
.32481 .27517 L
.32501 .2755 L
.32523 .27596 L
.32561 .27704 L
.32603 .27853 L
.32648 .28054 L
.32806 .28977 L
.32974 .30152 L
.33134 .3121 L
.33218 .31678 L
.33307 .32079 L
.33387 .32343 L
Mistroke
.33432 .32451 L
.33454 .32492 L
.33474 .32525 L
.33493 .32549 L
.33513 .32569 L
.33522 .32576 L
.33532 .32583 L
.3354 .32588 L
.33549 .32591 L
.33558 .32594 L
.33568 .32595 L
.33577 .32596 L
.33586 .32595 L
.33597 .32593 L
.33606 .32589 L
.33617 .32584 L
.33628 .32577 L
.33649 .3256 L
.33671 .32536 L
.3371 .3248 L
.33753 .32401 L
.33799 .32295 L
.33961 .31813 L
.3413 .31229 L
.34284 .30739 L
.34361 .30539 L
.34444 .30363 L
.34482 .30299 L
.34523 .30241 L
.34558 .30201 L
.34596 .30169 L
.34616 .30155 L
.34627 .30149 L
.34639 .30144 L
.34649 .3014 L
.34659 .30137 L
.34669 .30134 L
.34678 .30133 L
.34683 .30132 L
.34689 .30131 L
.34695 .30131 L
.347 .30131 L
.3471 .30131 L
.34716 .30131 L
.34721 .30132 L
.34727 .30133 L
.34732 .30134 L
.34744 .30136 L
.34755 .3014 L
.34768 .30144 L
Mistroke
.34788 .30154 L
.34811 .30167 L
.34852 .30198 L
.34929 .30277 L
.35089 .30499 L
.35258 .30764 L
.35417 .30986 L
.35486 .31064 L
.35562 .31132 L
.35604 .31162 L
.35642 .31184 L
.35679 .31201 L
.35718 .31214 L
.3574 .31219 L
.35752 .31222 L
.35764 .31223 L
.35773 .31224 L
.35779 .31225 L
.35784 .31225 L
.3579 .31226 L
.35796 .31226 L
.35806 .31226 L
.35816 .31226 L
.35826 .31225 L
.35836 .31225 L
.35841 .31224 L
.35847 .31224 L
.35867 .31221 L
.35886 .31217 L
.35924 .31208 L
.35965 .31193 L
.36048 .31155 L
.36197 .31065 L
.36368 .30953 L
.36523 .30865 L
.366 .30831 L
.36641 .30816 L
.36684 .30803 L
.36722 .30793 L
.36764 .30785 L
.36782 .30783 L
.36801 .3078 L
.36818 .30778 L
.36837 .30777 L
.36847 .30776 L
.36857 .30776 L
.36868 .30775 L
.36874 .30775 L
.36879 .30775 L
.36888 .30775 L
Mistroke
.36898 .30775 L
.36909 .30775 L
.36918 .30776 L
.36924 .30776 L
.3693 .30776 L
.36941 .30776 L
.36961 .30778 L
.36985 .3078 L
.37007 .30782 L
.37085 .30794 L
.37168 .30812 L
.37472 .30888 L
.37628 .3092 L
.37673 .30927 L
.37716 .30933 L
.37758 .30938 L
.37796 .30941 L
.37836 .30944 L
.37854 .30945 L
.37873 .30946 L
.37894 .30947 L
.37912 .30947 L
.37923 .30948 L
.37933 .30948 L
.37938 .30948 L
.37943 .30948 L
.37949 .30948 L
.37955 .30948 L
.37964 .30948 L
.37973 .30948 L
.37983 .30948 L
.37992 .30948 L
.38008 .30947 L
.38026 .30947 L
.38045 .30946 L
.38066 .30945 L
.38103 .30943 L
.38179 .30938 L
.38261 .30932 L
.38409 .30918 L
.38569 .30904 L
.38653 .30897 L
.38742 .30892 L
.3878 .3089 L
.38822 .30889 L
.38867 .30888 L
.38887 .30887 L
.38909 .30887 L
.38931 .30886 L
.38941 .30886 L
Mistroke
.3895 .30886 L
.3896 .30886 L
.38969 .30886 L
.3898 .30886 L
.3899 .30886 L
.38999 .30886 L
.39008 .30886 L
.39018 .30886 L
.39028 .30886 L
.39037 .30886 L
.39045 .30886 L
.39063 .30886 L
.39082 .30886 L
.39102 .30887 L
.39143 .30887 L
.39217 .30889 L
.39384 .30894 L
.39552 .30899 L
.39707 .30903 L
.39783 .30905 L
.39823 .30905 L
.39866 .30906 L
.39908 .30906 L
.39945 .30906 L
.39963 .30907 L
.39973 .30907 L
.39983 .30907 L
.39991 .30907 L
.40001 .30907 L
.4001 .30907 L
.40018 .30907 L
.40028 .30907 L
.40033 .30907 L
.40039 .30907 L
.40049 .30907 L
.40058 .30907 L
.40063 .30907 L
.40069 .30907 L
.40079 .30907 L
.40102 .30907 L
.40121 .30907 L
.4014 .30906 L
.40181 .30906 L
.40253 .30906 L
.4033 .30905 L
.4049 .30903 L
.40574 .30902 L
.40663 .30902 L
.40743 .30901 L
.40785 .30901 L
Mistroke
.4083 .30901 L
.40872 .309 L
.4091 .309 L
.40928 .309 L
.40948 .309 L
.40967 .309 L
.40984 .309 L
.40994 .309 L
.41005 .309 L
.41015 .309 L
.41021 .309 L
.41027 .309 L
.41037 .309 L
.41046 .309 L
.41051 .309 L
.41057 .309 L
.41067 .309 L
.41076 .309 L
.41086 .309 L
.41106 .309 L
.41125 .309 L
.41142 .309 L
.41185 .309 L
.41223 .309 L
.41311 .30901 L
.41476 .30901 L
.41629 .30902 L
.41705 .30902 L
.41777 .30902 L
.41817 .30902 L
.4186 .30902 L
.41899 .30902 L
.41935 .30902 L
.41955 .30902 L
.41973 .30902 L
.41983 .30902 L
.41994 .30902 L
.42004 .30902 L
.42013 .30902 L
.42022 .30902 L
.4203 .30902 L
.42039 .30902 L
.42049 .30902 L
.42058 .30902 L
.42068 .30902 L
.42077 .30902 L
.42086 .30902 L
.42108 .30902 L
.42128 .30902 L
.42172 .30902 L
Mistroke
.42252 .30902 L
.42419 .30902 L
.42573 .30902 L
.4265 .30902 L
.42722 .30902 L
.42798 .30902 L
.42838 .30902 L
.42881 .30902 L
.42901 .30902 L
.42923 .30902 L
.42942 .30902 L
.42962 .30902 L
.42975 .30902 L
.42986 .30902 L
.42997 .30902 L
.43002 .30902 L
.43009 .30902 L
.43019 .30902 L
.43025 .30902 L
.4303 .30902 L
.43041 .30902 L
.43051 .30902 L
.4306 .30902 L
.4307 .30902 L
.43091 .30902 L
.4311 .30902 L
.43128 .30902 L
.43212 .30902 L
.43374 .30902 L
.43523 .30902 L
.43596 .30902 L
.43675 .30902 L
.4372 .30902 L
.43761 .30902 L
.43799 .30902 L
.43841 .30902 L
.4388 .30902 L
.43901 .30902 L
.43921 .30902 L
.4393 .30902 L
.43939 .30902 L
.43948 .30902 L
.43956 .30902 L
.43966 .30902 L
.43975 .30902 L
.43985 .30902 L
.43995 .30902 L
.44005 .30902 L
.44011 .30902 L
.44016 .30902 L
Mistroke
.44027 .30902 L
.44036 .30902 L
.44058 .30902 L
.44081 .30902 L
.44123 .30902 L
.44162 .30902 L
.44328 .30902 L
.44482 .30902 L
.44559 .30902 L
.44632 .30902 L
.44707 .30902 L
.44747 .30902 L
.4479 .30902 L
.44811 .30902 L
.44832 .30902 L
.44851 .30902 L
.44871 .30902 L
.44884 .30902 L
.44895 .30902 L
.44906 .30902 L
.44912 .30902 L
.44918 .30902 L
.44928 .30902 L
.44938 .30902 L
.44944 .30902 L
.44949 .30902 L
.4496 .30902 L
.44969 .30902 L
.44979 .30902 L
.4499 .30902 L
.45 .30902 L
.45037 .30902 L
.45077 .30902 L
.45121 .30902 L
.45279 .30902 L
.45451 .30902 L
.45531 .30902 L
.45616 .30902 L
.45657 .30902 L
.45696 .30902 L
.45731 .30902 L
.45769 .30902 L
.45788 .30902 L
.45808 .30902 L
.45818 .30902 L
.45827 .30902 L
.45836 .30902 L
.45845 .30902 L
.45855 .30902 L
.4586 .30902 L
Mistroke
.45865 .30902 L
.45875 .30902 L
.45885 .30902 L
.4589 .30902 L
.45896 .30902 L
.45902 .30902 L
.45907 .30902 L
.45917 .30902 L
.45928 .30902 L
.4595 .30902 L
.45974 .30902 L
.46017 .30902 L
.46097 .30902 L
.46253 .30902 L
.46336 .30902 L
.46425 .30902 L
.4651 .30902 L
.46547 .30902 L
.46587 .30902 L
.46623 .30902 L
.46662 .30902 L
.46683 .30902 L
.46702 .30902 L
.46722 .30902 L
.4674 .30902 L
.46759 .30902 L
.46769 .30902 L
.46779 .30902 L
.46784 .30902 L
.4679 .30902 L
.46801 .30902 L
.46811 .30902 L
.4682 .30902 L
.4683 .30902 L
.46839 .30902 L
.46847 .30902 L
.46856 .30902 L
.46876 .30902 L
.46894 .30902 L
.46933 .30902 L
.46976 .30902 L
.47061 .30902 L
.47232 .30902 L
.47386 .30902 L
.47464 .30902 L
.47507 .30902 L
.47547 .30902 L
.47582 .30902 L
.47621 .30902 L
.47641 .30902 L
Mistroke
.47651 .30902 L
.47662 .30902 L
.47671 .30902 L
.47681 .30902 L
.47691 .30902 L
.47699 .30902 L
.4771 .30902 L
.47715 .30902 L
.47721 .30902 L
.47731 .30902 L
.4774 .30902 L
.47746 .30902 L
.47751 .30902 L
.47761 .30902 L
.47772 .30902 L
.47784 .30902 L
.47826 .30902 L
.47864 .30902 L
.48013 .30902 L
.48176 .30902 L
.48256 .30902 L
.48329 .30902 L
.484 .30902 L
.48435 .30902 L
.48474 .30902 L
.48514 .30902 L
.48536 .30902 L
.48556 .30902 L
.48575 .30902 L
.48585 .30902 L
.48595 .30902 L
.48603 .30902 L
.48613 .30902 L
.48623 .30902 L
.48632 .30902 L
.48642 .30902 L
.48647 .30902 L
.48652 .30902 L
.48662 .30902 L
.48672 .30902 L
.48693 .30902 L
.48715 .30902 L
.48757 .30902 L
.48794 .30902 L
.48943 .30902 L
.49108 .30902 L
.49188 .30902 L
.49261 .30902 L
.49297 .30902 L
.49336 .30902 L
Mistroke
.49374 .30902 L
.49408 .30902 L
.49427 .30902 L
.49444 .30902 L
.49464 .30902 L
.49475 .30902 L
.49485 .30902 L
.49494 .30902 L
.49504 .30902 L
.49514 .30902 L
.49519 .30902 L
.49524 .30902 L
.49534 .30902 L
.4954 .30902 L
.49546 .30902 L
.49555 .30902 L
.49566 .30902 L
.49586 .30902 L
.49606 .30902 L
.49642 .30902 L
.49723 .30902 L
.4987 .30902 L
.50016 .30902 L
.501 .30902 L
.5014 .30902 L
.50178 .30902 L
.50214 .30902 L
.50254 .30902 L
.50294 .30902 L
.50316 .30902 L
.50336 .30902 L
.50347 .30902 L
.50358 .30902 L
.50363 .30902 L
.50369 .30902 L
.50379 .30902 L
.50388 .30902 L
.50397 .30902 L
.50407 .30902 L
.50418 .30902 L
.50424 .30902 L
.50429 .30902 L
.50441 .30902 L
.50463 .30902 L
.50483 .30902 L
.50505 .30902 L
.50587 .30902 L
.50677 .30902 L
.50839 .30902 L
.50922 .30902 L
Mistroke
.50999 .30902 L
.51041 .30902 L
.5108 .30902 L
.51122 .30902 L
.51146 .30902 L
.51168 .30902 L
.51187 .30902 L
.51205 .30902 L
.51214 .30902 L
.51224 .30902 L
.5123 .30902 L
.51235 .30902 L
.51246 .30902 L
.51251 .30902 L
.51256 .30902 L
.51266 .30902 L
.51277 .30902 L
.51283 .30902 L
.51288 .30902 L
.51297 .30902 L
.51308 .30902 L
.51328 .30902 L
.51347 .30902 L
.51365 .30902 L
.51404 .30902 L
.51476 .30902 L
.51642 .30902 L
.51722 .30902 L
.51795 .30902 L
.51872 .30902 L
.51907 .30902 L
.51944 .30902 L
.51984 .30902 L
.5202 .30902 L
.5204 .30902 L
.52059 .30902 L
.5207 .30902 L
.5208 .30902 L
.52092 .30902 L
.52102 .30902 L
.52111 .30902 L
.52121 .30902 L
.52131 .30902 L
.52139 .30902 L
.52149 .30902 L
.52155 .30902 L
.5216 .30902 L
.5218 .30902 L
.52201 .30902 L
.5222 .30902 L
Mistroke
.52262 .30902 L
.5241 .30902 L
.52492 .30902 L
.52578 .30902 L
.52658 .30902 L
.52696 .30902 L
.52732 .30902 L
.52766 .30902 L
.52803 .30902 L
.52842 .30902 L
.52879 .30902 L
.52899 .30902 L
.5292 .30902 L
.52931 .30902 L
.52937 .30902 L
.52942 .30902 L
.52948 .30902 L
.52953 .30902 L
.52963 .30902 L
.52974 .30902 L
.52983 .30902 L
.52988 .30902 L
.52994 .30902 L
.53004 .30902 L
.53013 .30902 L
.53023 .30902 L
.53041 .30902 L
.53081 .30902 L
.53117 .30902 L
.53198 .30902 L
.53345 .30902 L
.53419 .30902 L
.53498 .30902 L
.53543 .30902 L
.53584 .30902 L
.53622 .30902 L
.53664 .30902 L
.53704 .30902 L
.53725 .30902 L
.53745 .30902 L
.53755 .30902 L
.53764 .30902 L
.53772 .30902 L
.53781 .30902 L
.5379 .30902 L
.53799 .30902 L
.53809 .30902 L
.53819 .30902 L
.5383 .30902 L
.53835 .30902 L
Mistroke
.53841 .30902 L
.53851 .30902 L
.53861 .30902 L
.53882 .30902 L
.53905 .30902 L
.53948 .30902 L
.53986 .30902 L
.54153 .30902 L
.54227 .30902 L
.54307 .30902 L
.54385 .30902 L
.54422 .30902 L
.54458 .30902 L
.54498 .30902 L
.54534 .30902 L
.54555 .30902 L
.54574 .30902 L
.54594 .30902 L
.54605 .30902 L
.54611 .30902 L
.54617 .30902 L
.54626 .30902 L
.54635 .30902 L
.54641 .30902 L
.54646 .30902 L
.54656 .30902 L
.54666 .30902 L
.54676 .30902 L
.54686 .30902 L
.54697 .30902 L
.54716 .30902 L
.54733 .30902 L
.54772 .30902 L
.54939 .30902 L
.55088 .30902 L
.55172 .30902 L
.5525 .30902 L
.55293 .30902 L
.55332 .30902 L
.55354 .30902 L
.55377 .30902 L
.55399 .30902 L
.55409 .30902 L
.5542 .30902 L
.5543 .30902 L
.55439 .30902 L
.55448 .30902 L
.55457 .30902 L
.55467 .30902 L
.55477 .30902 L
Mistroke
.55487 .30902 L
.55492 .30902 L
.55498 .30902 L
.55509 .30902 L
.55519 .30902 L
.55541 .30902 L
.55581 .30902 L
.5566 .30902 L
.55733 .30902 L
.55818 .30902 L
.55899 .30902 L
.55978 .30902 L
.56019 .30902 L
.56063 .30902 L
.561 .30902 L
.56141 .30902 L
.56159 .30902 L
.56178 .30902 L
.56196 .30902 L
.56213 .30902 L
.56233 .30902 L
.56244 .30902 L
.56255 .30902 L
.56265 .30902 L
.56274 .30902 L
.56284 .30902 L
.56294 .30902 L
.56305 .30902 L
.5631 .30902 L
.56316 .30902 L
.56336 .30902 L
.56348 .30902 L
.5636 .30902 L
.56383 .30902 L
.56466 .30902 L
.56544 .30902 L
.56622 .30902 L
.56707 .30902 L
.56787 .30902 L
.56824 .30902 L
.5686 .30902 L
.56897 .30902 L
.5693 .30902 L
.56968 .30902 L
.56988 .30902 L
.57008 .30902 L
.57026 .30902 L
.57036 .30902 L
.57046 .30902 L
.57055 .30902 L
Mistroke
.57065 .30902 L
.57074 .30902 L
.57082 .30902 L
.57093 .30902 L
.57102 .30902 L
.57113 .30902 L
.57118 .30902 L
.57124 .30902 L
.57144 .30902 L
.57163 .30902 L
.57201 .30902 L
.57242 .30902 L
.57325 .30902 L
.57473 .30902 L
.57554 .30902 L
.57631 .30902 L
.57673 .30902 L
.57719 .30902 L
.57739 .30902 L
.5776 .30902 L
.57779 .30902 L
.57799 .30902 L
.57819 .30902 L
.57828 .30902 L
.57838 .30902 L
.57848 .30902 L
.57857 .30902 L
.57866 .30902 L
.57874 .30902 L
.57884 .30902 L
.57895 .30902 L
.57904 .30902 L
.57913 .30902 L
.57924 .30902 L
.57935 .30902 L
.57956 .30902 L
.57995 .30902 L
.58033 .30902 L
.58103 .30902 L
.58249 .30902 L
.58332 .30902 L
.58373 .30902 L
.58411 .30902 L
.58447 .30902 L
.58487 .30902 L
.58527 .30902 L
.58549 .30902 L
.58569 .30902 L
.58591 .30902 L
.58602 .30902 L
Mistroke
.58612 .30902 L
.58621 .30902 L
.58631 .30902 L
.58641 .30902 L
.58651 .30902 L
.58657 .30902 L
.58662 .30902 L
.58673 .30902 L
.58678 .30902 L
.58684 .30902 L
.5869 .30902 L
.58696 .30902 L
.58707 .30902 L
.58718 .30902 L
.58738 .30902 L
.58776 .30902 L
.58817 .30902 L
.589 .30902 L
.59048 .30902 L
.59129 .30902 L
.59205 .30902 L
.59247 .30902 L
.59293 .30902 L
.59313 .30902 L
.59335 .30902 L
.59353 .30902 L
.59373 .30902 L
.59384 .30902 L
.59393 .30902 L
.59404 .30902 L
.59413 .30902 L
.59422 .30902 L
.5943 .30902 L
.59439 .30902 L
.59449 .30902 L
.59459 .30902 L
.59464 .30902 L
.59469 .30902 L
.5948 .30902 L
.59486 .30902 L
.59491 .30902 L
.59511 .30902 L
.5953 .30902 L
.59567 .30902 L
.596 .30902 L
.59677 .30902 L
.59755 .30902 L
.59839 .30902 L
.59912 .30902 L
.59954 .30902 L
Mistroke
.59992 .30902 L
.60032 .30902 L
.60069 .30902 L
.60108 .30902 L
.6013 .30902 L
.6015 .30902 L
.60168 .30902 L
.60177 .30902 L
.60186 .30902 L
.60195 .30902 L
.60202 .30902 L
.60211 .30902 L
.6022 .30902 L
.60229 .30902 L
.60238 .30902 L
.60248 .30902 L
.60258 .30902 L
.60268 .30902 L
.60278 .30902 L
.60295 .30902 L
.60332 .30902 L
.60374 .30902 L
.60456 .30902 L
.60605 .30902 L
.60687 .30902 L
.60762 .30902 L
.60803 .30902 L
.60825 .30902 L
.60848 .30902 L
.60868 .30902 L
.6089 .30902 L
.60911 .30902 L
.6093 .30902 L
.60939 .30902 L
.60949 .30902 L
.60959 .30902 L
.60967 .30902 L
.60978 .30902 L
.60983 .30902 L
.60989 .30902 L
.60998 .30902 L
.61009 .30902 L
.61019 .30902 L
.61029 .30902 L
.61039 .30902 L
.61048 .30902 L
.61092 .30902 L
.61128 .30902 L
.61168 .30902 L
.61241 .30902 L
Mistroke
.61396 .30902 L
.61438 .30902 L
.61484 .30902 L
.61524 .30902 L
.61568 .30902 L
.61609 .30902 L
.61648 .30902 L
.61669 .30902 L
.61688 .30902 L
.61699 .30902 L
.61711 .30902 L
.61722 .30902 L
.61732 .30902 L
.6174 .30902 L
.6175 .30902 L
.61759 .30902 L
.61767 .30902 L
.61776 .30902 L
.61786 .30902 L
.61796 .30902 L
.61805 .30902 L
.61842 .30902 L
.61882 .30902 L
.62043 .30902 L
.62127 .30902 L
.62173 .30902 L
.62216 .30902 L
.62258 .30902 L
.62296 .30902 L
.62339 .30902 L
.62362 .30902 L
.62384 .30902 L
.62402 .30902 L
.62422 .30902 L
.62442 .30902 L
.62453 .30902 L
.62463 .30902 L
.62472 .30902 L
.62482 .30902 L
.6249 .30902 L
.62499 .30902 L
.62509 .30902 L
.62519 .30902 L
.62529 .30902 L
.62538 .30902 L
.62548 .30902 L
.62557 .30902 L
.62577 .30902 L
.62618 .30902 L
.62692 .30902 L
Mistroke
.62778 .30902 L
.62859 .30902 L
.62937 .30902 L
.62978 .30902 L
.63022 .30902 L
.63063 .30902 L
.63099 .30902 L
.63117 .30902 L
.63136 .30902 L
.63154 .30902 L
.63171 .30902 L
.6319 .30902 L
.632 .30902 L
.6321 .30902 L
.6322 .30902 L
.63228 .30902 L
.63237 .30902 L
.63247 .30902 L
.63257 .30902 L
.63263 .30902 L
.63268 .30902 L
.63278 .30902 L
.63287 .30902 L
.63298 .30902 L
.63308 .30902 L
.63331 .30902 L
.63374 .30902 L
.63413 .30902 L
.635 .30902 L
.63582 .30902 L
.63668 .30902 L
.63741 .30902 L
.63783 .30902 L
.63822 .30902 L
.63841 .30902 L
.63862 .30902 L
.6388 .30902 L
.639 .30902 L
.63918 .30902 L
.63927 .30902 L
.63937 .30902 L
.63946 .30902 L
.63955 .30902 L
.63963 .30902 L
.63971 .30902 L
.63981 .30902 L
.6399 .30902 L
.64001 .30902 L
.64011 .30902 L
.6402 .30902 L
Mistroke
.64028 .30902 L
.64048 .30902 L
.64067 .30902 L
.64088 .30902 L
.64131 .30902 L
.643 .30902 L
.6438 .30902 L
.64455 .30902 L
.64492 .30902 L
.64531 .30902 L
.64554 .30902 L
.64575 .30902 L
.64594 .30902 L
.64615 .30902 L
.64633 .30902 L
.64653 .30902 L
.64661 .30902 L
.64671 .30902 L
.64679 .30902 L
.64688 .30902 L
.64698 .30902 L
.64703 .30902 L
.64709 .30902 L
.64718 .30902 L
.64729 .30902 L
.64738 .30902 L
.64748 .30902 L
.64758 .30902 L
.64766 .30902 L
.64786 .30902 L
.64804 .30902 L
.64845 .30902 L
.64918 .30902 L
.65005 .30902 L
.65085 .30902 L
.6516 .30902 L
.65198 .30902 L
.65239 .30902 L
.6528 .30902 L
.65318 .30902 L
.65342 .30902 L
.65364 .30902 L
.65384 .30902 L
.65395 .30902 L
.65406 .30902 L
.65415 .30902 L
.65425 .30902 L
.65434 .30902 L
.65443 .30902 L
.65453 .30902 L
Mistroke
.65459 .30902 L
.65464 .30902 L
.65474 .30902 L
.65483 .30902 L
.65492 .30902 L
.65501 .30902 L
.65518 .30902 L
.65555 .30902 L
.65634 .30902 L
.65721 .30902 L
.658 .30902 L
.65876 .30902 L
.65918 .30902 L
.65964 .30902 L
.66005 .30902 L
.66044 .30902 L
.66065 .30902 L
.66085 .30902 L
.66106 .30902 L
.66117 .30902 L
.66129 .30902 L
.66139 .30902 L
.66149 .30902 L
.66154 .30902 L
.6616 .30902 L
.6617 .30902 L
.6618 .30902 L
.6619 .30902 L
.66199 .30902 L
.66209 .30902 L
.66228 .30902 L
.66246 .30902 L
.66286 .30902 L
.66358 .30902 L
.66438 .30902 L
.66523 .30902 L
.66603 .30902 L
.66676 .30902 L
.66715 .30902 L
.66752 .30902 L
.66771 .30902 L
.66791 .30902 L
.66813 .30902 L
.66823 .30902 L
.66834 .30902 L
.66843 .30902 L
.66853 .30902 L
.66862 .30902 L
.66871 .30902 L
.6688 .30902 L
Mistroke
.66889 .30902 L
.66897 .30902 L
.66905 .30902 L
.66914 .30902 L
.66925 .30902 L
.66935 .30902 L
.66945 .30902 L
.66982 .30902 L
.67066 .30902 L
.67146 .30902 L
.67217 .30902 L
.67295 .30902 L
.67372 .30902 L
.67415 .30902 L
.67434 .30902 L
.67455 .30902 L
.67473 .30902 L
.67492 .30902 L
.6751 .30902 L
.67526 .30902 L
.67545 .30902 L
.67556 .30902 L
.67566 .30902 L
.67575 .30902 L
.67584 .30902 L
.67593 .30902 L
.67603 .30902 L
.67613 .30902 L
.67618 .30902 L
.67623 .30902 L
.67633 .30902 L
.67643 .30902 L
.6766 .30902 L
.67679 .30902 L
.6776 .30902 L
.67907 .30902 L
.67983 .30902 L
.68063 .30902 L
.68104 .30902 L
.68126 .30902 L
.6815 .30902 L
.68172 .30902 L
.68191 .30902 L
.68211 .30902 L
.6823 .30902 L
.68248 .30902 L
.68258 .30902 L
.68269 .30902 L
.68274 .30902 L
.6828 .30902 L
Mistroke
.6829 .30902 L
.683 .30902 L
.6831 .30902 L
.6832 .30902 L
.68329 .30902 L
.68337 .30902 L
.68346 .30902 L
.68365 .30902 L
.68384 .30902 L
.68465 .30902 L
.68551 .30902 L
.68627 .30902 L
.68708 .30902 L
.68748 .30902 L
.68785 .30902 L
.68819 .30902 L
.68856 .30902 L
.68874 .30902 L
.68894 .30902 L
.68914 .30902 L
.68931 .30902 L
.6895 .30902 L
.68961 .30902 L
.68972 .30902 L
.68977 .30902 L
.68982 .30902 L
.68992 .30902 L
.69003 .30902 L
.69009 .30902 L
.69014 .30902 L
.69024 .30902 L
.69035 .30902 L
.69044 .30902 L
.69053 .30902 L
.69096 .30902 L
.69141 .30902 L
.69183 .30902 L
.69266 .30902 L
.69344 .30902 L
.69414 .30902 L
.69451 .30902 L
.6949 .30902 L
.6953 .30902 L
.69551 .30902 L
.69573 .30902 L
.69593 .30902 L
.69612 .30902 L
.69631 .30902 L
.69649 .30902 L
.69658 .30902 L
Mistroke
.69669 .30902 L
.69674 .30902 L
.6968 .30902 L
.69691 .30902 L
.69701 .30902 L
.69711 .30902 L
.6972 .30902 L
.69729 .30902 L
.69741 .30902 L
.69751 .30902 L
.69775 .30902 L
.69817 .30902 L
.69984 .30902 L
.70058 .30902 L
.70097 .30902 L
.70139 .30902 L
.70179 .30902 L
.70216 .30902 L
.70234 .30902 L
.70254 .30902 L
.70272 .30902 L
.70289 .30902 L
.70308 .30902 L
.70319 .30902 L
.70329 .30902 L
.70339 .30902 L
.70349 .30902 L
.7036 .30902 L
.70366 .30902 L
.70371 .30902 L
.70381 .30902 L
.70391 .30902 L
.70399 .30902 L
.70408 .30902 L
.70418 .30902 L
.70429 .30902 L
.70448 .30902 L
.70487 .30902 L
.70524 .30902 L
.70605 .30902 L
.70676 .30902 L
.70752 .30902 L
.70793 .30902 L
.70831 .30902 L
.70869 .30902 L
.70905 .30902 L
.70946 .30902 L
.70967 .30902 L
.70978 .30902 L
.7099 .30902 L
Mistroke
.71001 .30902 L
.7101 .30902 L
.7102 .30902 L
.71029 .30902 L
.71039 .30902 L
.71045 .30902 L
.7105 .30902 L
.7106 .30902 L
.71066 .30902 L
.71071 .30902 L
.7108 .30902 L
.71091 .30902 L
.711 .30902 L
.71109 .30902 L
.7113 .30902 L
.7115 .30902 L
.71233 .30902 L
.71382 .30902 L
.7146 .30902 L
.71499 .30902 L
.71543 .30902 L
.7158 .30902 L
.716 .30902 L
.71619 .30902 L
.71637 .30902 L
.71657 .30902 L
.71674 .30902 L
.71691 .30902 L
.717 .30902 L
.7171 .30902 L
.71719 .30902 L
.71728 .30902 L
.71738 .30902 L
.71744 .30902 L
.71749 .30902 L
.71759 .30902 L
.71768 .30902 L
.71777 .30902 L
.71786 .30902 L
.71803 .30902 L
.7184 .30902 L
.72006 .30902 L
.72081 .30902 L
.72123 .30902 L
.72163 .30902 L
.72199 .30902 L
.72239 .30902 L
.72276 .30902 L
.7231 .30902 L
.72331 .30902 L
Mistroke
.7235 .30902 L
.7236 .30902 L
.72372 .30902 L
.72377 .30902 L
.72383 .30902 L
.72389 .30902 L
.72394 .30902 L
.72405 .30902 L
.7241 .30902 L
.72416 .30902 L
.72426 .30902 L
.72431 .30902 L
.72436 .30902 L
.72446 .30902 L
.72455 .30902 L
.72474 .30902 L
.72509 .30902 L
.72547 .30902 L
.72624 .30902 L
.72705 .30902 L
.72781 .30902 L
.72823 .30902 L
.72869 .30902 L
.72911 .30902 L
.72931 .30902 L
.72949 .30902 L
.72967 .30902 L
.72987 .30902 L
.73008 .30902 L
.73018 .30902 L
.73027 .30902 L
.73036 .30902 L
.73045 .30902 L
.73055 .30902 L
.73065 .30902 L
.73074 .30902 L
.73083 .30902 L
.73091 .30902 L
.731 .30902 L
.73105 .30902 L
.73111 .30902 L
.73122 .30902 L
.73141 .30902 L
.73164 .30902 L
.73186 .30902 L
.73266 .30902 L
.73344 .30902 L
.73429 .30902 L
.73469 .30902 L
.73508 .30902 L
Mistroke
.73547 .30902 L
.73581 .30902 L
.73618 .30902 L
.73638 .30902 L
.73657 .30902 L
.73674 .30902 L
.7369 .30902 L
.73698 .30902 L
.73708 .30902 L
.73717 .30902 L
.73726 .30902 L
.73736 .30902 L
.73742 .30902 L
.73747 .30902 L
.73756 .30902 L
.73766 .30902 L
.73775 .30902 L
.73784 .30902 L
.73803 .30902 L
.73823 .30902 L
.73842 .30902 L
.73885 .30902 L
.73964 .30902 L
.74049 .30902 L
.74091 .30902 L
.7413 .30902 L
.74164 .30902 L
.74203 .30902 L
.7424 .30902 L
.74259 .30902 L
.74279 .30902 L
.74298 .30902 L
.74315 .30902 L
.74333 .30902 L
.74349 .30902 L
.74359 .30902 L
.74368 .30902 L
.74379 .30902 L
.74389 .30902 L
.74398 .30902 L
.74406 .30902 L
.74416 .30902 L
.74425 .30902 L
.74435 .30902 L
.74446 .30902 L
.74465 .30902 L
.74508 .30902 L
.74668 .30902 L
.74752 .30902 L
.74794 .30902 L
Mistroke
.74841 .30902 L
.74882 .30902 L
.74904 .30902 L
.74926 .30902 L
.74946 .30902 L
.74968 .30902 L
.74988 .30902 L
.75007 .30902 L
.75017 .30902 L
.75027 .30902 L
.75037 .30902 L
.75046 .30902 L
.75054 .30902 L
.75063 .30902 L
.75072 .30902 L
.75081 .30902 L
.75092 .30902 L
.75101 .30902 L
.7512 .30902 L
.75161 .30902 L
.75322 .30902 L
.75392 .30902 L
.75468 .30902 L
.7551 .30902 L
.7555 .30902 L
.75587 .30902 L
.75606 .30902 L
.75626 .30902 L
.75638 .30902 L
.75648 .30902 L
.75658 .30902 L
.75668 .30902 L
.75674 .30902 L
.7568 .30902 L
.7569 .30902 L
.75696 .30902 L
.75702 .30902 L
.75708 .30902 L
.75714 .30902 L
.75724 .30902 L
.75733 .30902 L
.75744 .30902 L
.75755 .30902 L
.75776 .30902 L
.75795 .30902 L
.75962 .30902 L
.76036 .30902 L
.76075 .30902 L
.76116 .30902 L
.76157 .30902 L
Mistroke
.76194 .30902 L
.76212 .30902 L
.76231 .30902 L
.7625 .30902 L
.76267 .30902 L
.76286 .30902 L
.76296 .30902 L
.76307 .30902 L
.76318 .30902 L
.76324 .30902 L
.76329 .30902 L
.76339 .30902 L
.76344 .30902 L
.76349 .30902 L
.76359 .30902 L
.76365 .30902 L
.7637 .30902 L
.76379 .30902 L
.76389 .30902 L
.76407 .30902 L
.76426 .30902 L
.76595 .30902 L
.76675 .30902 L
.7675 .30902 L
.76787 .30902 L
.76826 .30902 L
.76849 .30902 L
.7687 .30902 L
.76889 .30902 L
.76909 .30902 L
.76928 .30902 L
.76937 .30902 L
.76947 .30902 L
.76957 .30902 L
.76965 .30902 L
.76974 .30902 L
.76982 .30902 L
.76992 .30902 L
.77002 .30902 L
.77011 .30902 L
.7702 .30902 L
.7703 .30902 L
.77041 .30902 L
.77061 .30902 L
.77101 .30902 L
.77138 .30902 L
.77222 .30902 L
.7731 .30902 L
.77352 .30902 L
.77392 .30902 L
Mistroke
.7743 .30902 L
.77471 .30902 L
.77492 .30902 L
.77511 .30902 L
.77533 .30902 L
.77556 .30902 L
.77575 .30902 L
.77586 .30902 L
.77596 .30902 L
.77605 .30902 L
.77615 .30902 L
.77625 .30902 L
.77634 .30902 L
.77643 .30902 L
.77652 .30902 L
.7766 .30902 L
.77669 .30902 L
.77688 .30902 L
.77706 .30902 L
.77856 .30902 L
.77935 .30902 L
.78019 .30902 L
.78061 .30902 L
.78083 .30902 L
.78108 .30902 L
.7813 .30902 L
.7815 .30902 L
.7817 .30902 L
.7819 .30902 L
.78209 .30902 L
.7822 .30902 L
.7823 .30902 L
.78239 .30902 L
.78249 .30902 L
.78258 .30902 L
.78267 .30902 L
.78277 .30902 L
.78287 .30902 L
.78297 .30902 L
.78308 .30902 L
.78331 .30902 L
.78351 .30902 L
.78518 .30902 L
.78591 .30902 L
.7863 .30902 L
.78671 .30902 L
.78712 .30902 L
.78748 .30902 L
.78784 .30902 L
.78801 .30902 L
Mistroke
.78821 .30902 L
.78831 .30902 L
.78842 .30902 L
.78851 .30902 L
.7886 .30902 L
.78871 .30902 L
.78881 .30902 L
.78891 .30902 L
.78897 .30902 L
.78903 .30902 L
.78913 .30902 L
.78922 .30902 L
.78931 .30902 L
.7894 .30902 L
.78979 .30902 L
.79151 .30902 L
.7919 .30902 L
.79232 .30902 L
.7927 .30902 L
.79306 .30902 L
.79343 .30902 L
.79365 .30902 L
.79384 .30902 L
.79403 .30902 L
.79425 .30902 L
.79436 .30902 L
.79447 .30902 L
.79457 .30902 L
.79468 .30902 L
.79478 .30902 L
.79486 .30902 L
.79495 .30902 L
.79503 .30902 L
.79513 .30902 L
.79522 .30902 L
.79532 .30902 L
.79542 .30902 L
.79552 .30902 L
.79563 .30902 L
.79583 .30902 L
.79621 .30902 L
.79777 .30902 L
.7982 .30902 L
.79866 .30902 L
.7991 .30902 L
.7995 .30902 L
.7999 .30902 L
.80012 .30902 L
.80035 .30902 L
.80054 .30902 L
Mistroke
.80073 .30902 L
.80084 .30902 L
.80093 .30902 L
.80104 .30902 L
.8011 .30902 L
.80115 .30902 L
.80125 .30902 L
.80133 .30902 L
.80143 .30902 L
.80153 .30902 L
.80162 .30902 L
.80171 .30902 L
.80179 .30902 L
.80188 .30902 L
.80228 .30902 L
.80266 .30902 L
.80415 .30902 L
.80456 .30902 L
.805 .30902 L
.80537 .30902 L
.80578 .30902 L
.80602 .30902 L
.80624 .30902 L
.80645 .30902 L
.80667 .30902 L
.80687 .30902 L
.80706 .30902 L
.80717 .30902 L
.80726 .30902 L
.80732 .30902 L
.80737 .30902 L
.80748 .30902 L
.80758 .30902 L
.80767 .30902 L
.80777 .30902 L
.80783 .30902 L
.80789 .30902 L
.8081 .30902 L
.80832 .30902 L
.80909 .30902 L
.80992 .30902 L
.8107 .30902 L
.8114 .30902 L
.81179 .30902 L
.81215 .30902 L
.81252 .30902 L
.81273 .30902 L
.81292 .30902 L
.81302 .30902 L
.81312 .30902 L
Mistroke
.81321 .30902 L
.81331 .30902 L
.81341 .30902 L
.81351 .30902 L
.81361 .30902 L
.81367 .30902 L
.81373 .30902 L
.81383 .30902 L
.81388 .30902 L
.81394 .30902 L
.81404 .30902 L
.81415 .30902 L
.81435 .30902 L
.81454 .30902 L
.81541 .30902 L
.81616 .30902 L
.81695 .30902 L
.81736 .30902 L
.81782 .30902 L
.81802 .30902 L
.81823 .30902 L
.81862 .30902 L
.81882 .30902 L
.81904 .30902 L
.81914 .30902 L
.81924 .30902 L
.81933 .30902 L
.81943 .30902 L
.81954 .30902 L
.8196 .30902 L
.81965 .30902 L
.81975 .30902 L
.81985 .30902 L
.81991 .30902 L
.81998 .30902 L
.82004 .30902 L
.82009 .30902 L
.8202 .30902 L
.82031 .30902 L
.82071 .30902 L
.82108 .30902 L
.82193 .30902 L
.82272 .30902 L
.82315 .30902 L
.82355 .30902 L
.82389 .30902 L
.82426 .30902 L
.82447 .30902 L
.82466 .30902 L
.82484 .30902 L
Mistroke
.82503 .30902 L
.82522 .30902 L
.8254 .30902 L
.82551 .30902 L
.82562 .30902 L
.82571 .30902 L
.82581 .30902 L
.82587 .30902 L
.82592 .30902 L
.82602 .30902 L
.82608 .30902 L
.82613 .30902 L
.82624 .30902 L
.82644 .30902 L
.82664 .30902 L
.82812 .30902 L
.82888 .30902 L
.8293 .30902 L
.8297 .30902 L
.83007 .30902 L
.83026 .30902 L
.83047 .30902 L
.83064 .30902 L
.83084 .30902 L
.83101 .30902 L
.83117 .30902 L
.83136 .30902 L
.83146 .30902 L
.83157 .30902 L
.83162 .30902 L
.83168 .30902 L
.83179 .30902 L
.83189 .30902 L
.83199 .30902 L
.83207 .30902 L
.83216 .30902 L
.83225 .30902 L
.83235 .30902 L
.83255 .30902 L
.83273 .30902 L
.8336 .30902 L
.8344 .30902 L
.83515 .30902 L
.83552 .30902 L
.83593 .30902 L
.83635 .30902 L
.83658 .30902 L
.83679 .30902 L
.83698 .30902 L
.83719 .30902 L
Mistroke
.83729 .30902 L
.8374 .30902 L
.83751 .30902 L
.8376 .30902 L
.8377 .30902 L
.83779 .30902 L
.83788 .30902 L
.83799 .30902 L
.83804 .30902 L
.8381 .30902 L
.8382 .30902 L
.83831 .30902 L
.8384 .30902 L
.83876 .30902 L
.83914 .30902 L
.84001 .30902 L
.84081 .30902 L
.8412 .30902 L
.84163 .30902 L
.84207 .30902 L
.84231 .30902 L
.84253 .30902 L
.84274 .30902 L
.84294 .30902 L
.84312 .30902 L
.84331 .30902 L
.84341 .30902 L
.84352 .30902 L
.84358 .30902 L
.84364 .30902 L
.84369 .30902 L
.84374 .30902 L
.84384 .30902 L
.84394 .30902 L
.84399 .30902 L
.84405 .30902 L
.84415 .30902 L
.84425 .30902 L
.84436 .30902 L
.84458 .30902 L
.84497 .30902 L
.84586 .30902 L
.84671 .30902 L
.84748 .30902 L
.84786 .30902 L
.84807 .30902 L
.84828 .30902 L
.84849 .30902 L
.84868 .30902 L
.84885 .30902 L
Mistroke
.84904 .30902 L
.84915 .30902 L
.84926 .30902 L
.84936 .30902 L
.84946 .30902 L
.84952 .30902 L
.84957 .30902 L
.84967 .30902 L
.84973 .30902 L
.84979 .30902 L
.84984 .30902 L
.84991 .30902 L
.85 .30902 L
.85011 .30902 L
.8502 .30902 L
.85029 .30902 L
.85072 .30902 L
.85152 .30902 L
.85237 .30902 L
.85279 .30902 L
.85318 .30902 L
.85352 .30902 L
.85391 .30902 L
.85428 .30902 L
.85448 .30902 L
.85467 .30902 L
.85485 .30902 L
.85501 .30902 L
.8551 .30902 L
.8552 .30902 L
.85529 .30902 L
.85538 .30902 L
.85548 .30902 L
.85557 .30902 L
.85562 .30902 L
.85568 .30902 L
.85578 .30902 L
.85589 .30902 L
.85598 .30902 L
.85609 .30902 L
.85621 .30902 L
.85661 .30902 L
.85697 .30902 L
.85778 .30902 L
.85823 .30902 L
.85864 .30902 L
.85902 .30902 L
.85937 .30902 L
.85976 .30902 L
.85996 .30902 L
Mistroke
.86018 .30902 L
.86039 .30902 L
.86057 .30902 L
.86076 .30902 L
.86094 .30902 L
.86104 .30902 L
.86114 .30902 L
.86124 .30902 L
.86133 .30902 L
.86139 .30902 L
.86144 .30902 L
.8615 .30902 L
.86156 .30902 L
.86166 .30902 L
.86171 .30902 L
.86176 .30902 L
.86185 .30902 L
.86194 .30902 L
.86211 .30902 L
.86249 .30902 L
.86327 .30902 L
.8641 .30902 L
.86488 .30902 L
.86527 .30902 L
.86569 .30902 L
.86593 .30902 L
.86615 .30902 L
.86635 .30902 L
.86657 .30902 L
.86676 .30902 L
.86687 .30902 L
.86697 .30902 L
.86706 .30902 L
.86715 .30902 L
.86725 .30902 L
.86733 .30902 L
.86743 .30902 L
.86753 .30902 L
.86763 .30902 L
.86769 .30902 L
.86774 .30902 L
.86795 .30902 L
.86817 .30902 L
.86899 .30902 L
.86986 .30902 L
.87029 .30902 L
.87069 .30902 L
.87108 .30902 L
.87144 .30902 L
.87179 .30902 L
Mistroke
.87196 .30902 L
.87215 .30902 L
.87234 .30902 L
.87245 .30902 L
.87255 .30902 L
.87264 .30902 L
.87274 .30902 L
.87283 .30902 L
.87292 .30902 L
.87302 .30902 L
.87307 .30902 L
.87313 .30902 L
.87323 .30902 L
.87332 .30902 L
.87338 .30902 L
.87344 .30902 L
.87354 .30902 L
.87365 .30902 L
.87376 .30902 L
.87418 .30902 L
.87456 .30902 L
.87528 .30902 L
.87569 .30902 L
.87606 .30902 L
.87643 .30902 L
.87683 .30902 L
.87718 .30902 L
.87756 .30902 L
.87777 .30902 L
.87797 .30902 L
.87808 .30902 L
.8782 .30902 L
.8783 .30902 L
.87841 .30902 L
.87852 .30902 L
.87862 .30902 L
.87872 .30902 L
.87878 .30902 L
.87883 .30902 L
.87892 .30902 L
.87902 .30902 L
.87912 .30902 L
.87921 .30902 L
.87931 .30902 L
.87942 .30902 L
.87962 .30902 L
.88006 .30902 L
.88086 .30902 L
.88164 .30902 L
.88236 .30902 L
Mistroke
.88275 .30902 L
.88312 .30902 L
.88332 .30902 L
.88351 .30902 L
.88372 .30902 L
.88394 .30902 L
.88411 .30902 L
.88421 .30902 L
.8843 .30902 L
.88438 .30902 L
.88447 .30902 L
.88456 .30902 L
.88464 .30902 L
.88474 .30902 L
.88483 .30902 L
.88492 .30902 L
.88501 .30902 L
.88511 .30902 L
.88522 .30902 L
.88541 .30902 L
.88623 .30902 L
.887 .30902 L
.8877 .30902 L
.88809 .30902 L
.88846 .30902 L
.88882 .30902 L
.88902 .30902 L
.88921 .30902 L
.88942 .30902 L
.8896 .30902 L
.88981 .30902 L
.88991 .30902 L
.89002 .30902 L
.89008 .30902 L
.89013 .30902 L
.89019 .30902 L
.89024 .30902 L
.89034 .30902 L
.89044 .30902 L
.89049 .30902 L
.89055 .30902 L
.89065 .30902 L
.89072 .30902 L
.89078 .30902 L
.89089 .30902 L
.89128 .30902 L
.8917 .30902 L
.89258 .30902 L
.89301 .30902 L
.89341 .30902 L
Mistroke
.89377 .30902 L
.89416 .30902 L
.89455 .30902 L
.89476 .30902 L
.89496 .30902 L
.89516 .30902 L
.89526 .30902 L
.89537 .30902 L
.89547 .30902 L
.89557 .30902 L
.89567 .30902 L
.89576 .30902 L
.89585 .30902 L
.89594 .30902 L
.89603 .30902 L
.89613 .30902 L
.89622 .30902 L
.89631 .30902 L
.8964 .30902 L
.89648 .30902 L
.89669 .30902 L
.89688 .30902 L
.89732 .30902 L
.89811 .30902 L
.89883 .30902 L
.89924 .30902 L
.89962 .30902 L
.89983 .30902 L
.90006 .30902 L
.90047 .30902 L
.90067 .30902 L
.90089 .30902 L
.90099 .30902 L
.90109 .30902 L
.90127 .30902 L
.90137 .30902 L
.90147 .30902 L
.90156 .30902 L
.90165 .30902 L
.90175 .30902 L
.90181 .30902 L
.90186 .30902 L
.90196 .30902 L
.90206 .30902 L
.90216 .30902 L
.90226 .30902 L
.90245 .30902 L
.90289 .30902 L
.90366 .30902 L
.90437 .30902 L
Mistroke
.9048 .30902 L
.90518 .30902 L
.90561 .30902 L
.90585 .30902 L
.90607 .30902 L
.90627 .30902 L
.90647 .30902 L
.90665 .30902 L
.90684 .30902 L
.90695 .30902 L
.90705 .30902 L
.90711 .30902 L
.90717 .30902 L
.90723 .30902 L
.90728 .30902 L
.90737 .30902 L
.90747 .30902 L
.90753 .30902 L
.90758 .30902 L
.90768 .30902 L
.90778 .30902 L
.90788 .30902 L
.90808 .30902 L
.90845 .30902 L
.90929 .30902 L
.90972 .30902 L
.91017 .30902 L
.91059 .30902 L
.91098 .30902 L
.91134 .30902 L
.91172 .30902 L
.91193 .30902 L
.91214 .30902 L
.91232 .30902 L
.91243 .30902 L
.91252 .30902 L
.91263 .30902 L
.91269 .30902 L
.91274 .30902 L
.91284 .30902 L
.91295 .30902 L
.91304 .30902 L
.91313 .30902 L
.91323 .30902 L
.91333 .30902 L
.91356 .30902 L
.91378 .30902 L
.91419 .30902 L
.9149 .30902 L
.91566 .30902 L
Mistroke
.91609 .30902 L
.91649 .30902 L
.91687 .30902 L
.91707 .30902 L
.91727 .30902 L
.91748 .30902 L
.91767 .30902 L
.91778 .30902 L
.91789 .30902 L
.91799 .30902 L
.9181 .30902 L
.9182 .30902 L
.91829 .30902 L
.91839 .30902 L
.9185 .30902 L
.9186 .30902 L
.91869 .30902 L
.91877 .30902 L
.91887 .30902 L
.91907 .30902 L
.91929 .30902 L
.91974 .30902 L
.92055 .30902 L
.92095 .30902 L
.92136 .30902 L
.92172 .30902 L
.9221 .30902 L
.92232 .30902 L
.92252 .30902 L
.92272 .30902 L
.9229 .30902 L
.92312 .30902 L
.92323 .30902 L
.92335 .30902 L
.92345 .30902 L
.92356 .30902 L
.92367 .30902 L
.92378 .30902 L
.92383 .30902 L
.92388 .30902 L
.92398 .30902 L
.92409 .30902 L
.92414 .30902 L
.9242 .30902 L
.92429 .30902 L
.92439 .30902 L
.92449 .30902 L
.92459 .30902 L
.92502 .30902 L
.92547 .30902 L
Mistroke
.92631 .30902 L
.92709 .30902 L
.92748 .30902 L
.9279 .30902 L
.92812 .30902 L
.92833 .30902 L
.92855 .30902 L
.92868 .30902 L
.92879 .30902 L
.92899 .30902 L
.92909 .30902 L
.9292 .30902 L
.92926 .30902 L
.92932 .30902 L
.92938 .30902 L
.92943 .30902 L
.92953 .30902 L
.92964 .30902 L
.92973 .30902 L
.92983 .30902 L
.92992 .30902 L
.93 .30902 L
.93021 .30902 L
.93041 .30902 L
.93124 .30902 L
.93202 .30902 L
.93272 .30902 L
.93312 .30902 L
.93348 .30902 L
.93385 .30902 L
.93406 .30902 L
.93425 .30902 L
.93436 .30902 L
.93446 .30902 L
.93455 .30902 L
.93464 .30902 L
.93475 .30902 L
.93484 .30902 L
.93495 .30902 L
.93501 .30902 L
.93506 .30902 L
.93517 .30902 L
.93523 .30902 L
.93528 .30902 L
.93538 .30902 L
.93549 .30902 L
.93569 .30902 L
.93588 .30902 L
.93675 .30902 L
.9375 .30902 L
Mistroke
.93791 .30902 L
.93829 .30902 L
.93871 .30902 L
.93893 .30902 L
.93916 .30902 L
.93938 .30902 L
.93958 .30902 L
.93976 .30902 L
.93987 .30902 L
.93996 .30902 L
.94005 .30902 L
.94015 .30902 L
.94025 .30902 L
.94035 .30902 L
.94044 .30902 L
.94054 .30902 L
.94063 .30902 L
.94072 .30902 L
.94077 .30902 L
.94082 .30902 L
.94092 .30902 L
.94115 .30902 L
.94155 .30902 L
.94236 .30902 L
.94281 .30902 L
.94324 .30902 L
.94363 .30902 L
.94406 .30902 L
.94424 .30902 L
.94445 .30902 L
.94481 .30902 L
.945 .30902 L
.9452 .30902 L
.9453 .30902 L
.9454 .30902 L
.94548 .30902 L
.94558 .30902 L
.94567 .30902 L
.94575 .30902 L
.94583 .30902 L
.94591 .30902 L
.946 .30902 L
.94609 .30902 L
.94618 .30902 L
.94628 .30902 L
.94637 .30902 L
.94647 .30902 L
.94667 .30902 L
.94703 .30902 L
.94784 .30902 L
Mistroke
.9482 .30902 L
.9486 .30902 L
.94894 .30902 L
.94931 .30902 L
.94951 .30902 L
.94974 .30902 L
.94993 .30902 L
.95014 .30902 L
.95034 .30902 L
.95052 .30902 L
.95061 .30902 L
.95071 .30902 L
.95089 .30902 L
.95099 .30902 L
.95109 .30902 L
.95114 .30902 L
.95119 .30902 L
.95125 .30902 L
.95131 .30902 L
.95136 .30902 L
.95142 .30902 L
.95152 .30902 L
.95159 .30902 L
.95165 .30902 L
.95176 .30902 L
.95196 .30902 L
.95215 .30902 L
.95257 .30902 L
.95329 .30902 L
.95407 .30902 L
.95452 .30902 L
.95493 .30902 L
.95512 .30902 L
.95534 .30902 L
.95554 .30902 L
.95573 .30902 L
.95593 .30902 L
.95604 .30902 L
.95615 .30902 L
.95625 .30902 L
.95635 .30902 L
.9564 .30902 L
.95645 .30902 L
.95656 .30902 L
.95665 .30902 L
.95674 .30902 L
.95684 .30902 L
.95694 .30902 L
.95703 .30902 L
.95712 .30902 L
Mistroke
.95731 .30902 L
.95773 .30902 L
.95812 .30902 L
.95899 .30902 L
.95937 .30902 L
.95978 .30902 L
.96016 .30902 L
.96051 .30902 L
.96072 .30902 L
.96092 .30902 L
.96114 .30902 L
.96125 .30902 L
.96136 .30902 L
.96147 .30902 L
.96156 .30902 L
.96166 .30902 L
.96175 .30902 L
.96185 .30902 L
.96191 .30902 L
.96197 .30902 L
.96202 .30902 L
.96207 .30902 L
.96217 .30902 L
.96227 .30902 L
.96237 .30902 L
.96246 .30902 L
.96255 .30902 L
.96296 .30902 L
.96379 .30902 L
.96451 .30902 L
.9649 .30902 L
.96527 .30902 L
.96565 .30902 L
.96587 .30902 L
.96607 .30902 L
.96624 .30902 L
.96642 .30902 L
.96662 .30902 L
.96681 .30902 L
.96692 .30902 L
.96703 .30902 L
.96712 .30902 L
.96722 .30902 L
.96728 .30902 L
.96734 .30902 L
.9674 .30902 L
.96746 .30902 L
.96756 .30902 L
.96762 .30902 L
.96767 .30902 L
Mistroke
.96777 .30902 L
.96787 .30902 L
.96808 .30902 L
.96847 .30902 L
.96926 .30902 L
.96967 .30902 L
.9701 .30902 L
.97048 .30902 L
.97089 .30902 L
.97108 .30902 L
.97127 .30902 L
.97162 .30902 L
.97183 .30902 L
.97201 .30902 L
.97211 .30902 L
.97222 .30902 L
.97233 .30902 L
.97244 .30902 L
.97254 .30902 L
.97263 .30902 L
.97272 .30902 L
.97281 .30902 L
.97291 .30902 L
.97297 .30902 L
.97302 .30902 L
.97312 .30902 L
.97321 .30902 L
.97357 .30902 L
.9739 .30902 L
.97465 .30902 L
.97539 .30902 L
.9758 .30902 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{421.375, 260.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008>0001AB000`400?l00000o`00003ooooooooo
oooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo
003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooo
oooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool0
0?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooooooo
ool@ooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooo
ooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo0ol0003o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0
003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo03Wooooo0_l0003ooooooj7o
oooo000`ooooo`03o`000?oooooooooo03Wooooo0_l0003ooooooj7ooooo000`ooooo`03o`000?oo
oooooooo03Wooooo0_l0003ooooooj7ooooo000`ooooo`03o`000?oooooooooo03Wooooo0_l0003o
oooooj7ooooo000`ooooo`03o`000?oooooooooo03Wooooo0_l0003ooooooj7ooooo000`ooooo`?o
0000>Oooool2o`000?ooooooXOooool0033ooooo00?o0000ooooooooool0>Oooool2o`000?oooooo
XOooool0033ooooo00?o0000ooooooooool0>Oooool2o`000?ooooooXOooool0033ooooo00?o0000
ooooooooool0>Oooool2o`000?ooooooXOooool0033ooooo00?o0000ooooooooool0>Oooool2o`00
0?ooooooXOooool0033ooooo00?o0000ooooooooool0>Oooool2o`000?ooooooXOooool0033ooooo
00?o0000ooooooooool0>Oooool2o`000?ooooooXOooool0033ooooo00?o0000ooooooooool0>Ooo
ool2o`000?ooooooXOooool0033ooooo00?o0000ooooooooool0>Oooool2o`000?ooooooXOooool0
033ooooo00?o0000ooooooooool0>Oooool2o`000?ooooooXOooool0033ooooo00?o0000oooooooo
ool0>Oooool2o`000?ooooooXOooool0033ooooo0ol0000hooooo`03o`000?oooooo00000?oooooo
XOooool0033ooooo00?o0000ooooooooool0>?ooool00ol0003oooooo`00003ooooooj7ooooo000`
ooooo`03o`000?oooooooooo03Sooooo00Co0000oooooooooooo0000oooooonPooooo`00<?ooool0
0ol0003oooooooooo`0hooooo`04o`000?ooooooooooo`000?ooooooX?ooool0033ooooo00?o0000
ooooooooool0>?ooool01?l0003oooooooooool0003ooooooj3ooooo000`ooooo`03o`000?oooooo
oooo03Sooooo00Co0000oooooooooooo0000oooooonPooooo`00<?ooool00ol0003oooooooooo`0h
ooooo`04o`000?ooooooooooo`000?ooooooX?ooool0013ooooo0_o^k^h3ooooo`;ok^k^6Oooool0
0ol0003oooooooooo`0hooooo`04o`000?ooooooooooo`000?ooooooX?ooool000_ooooo0_l00000
2_l@413oooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h3ooooo`Co000000So410@oooo
ooooooook^k^oc8b<_l0003o<S8bonk^kP[ooooo00?o0000ooooooooool0>?ooool01?l0003ooooo
ooooool0003ooooooj3ooooo000<ooooo`03o`000?oooooooooo00;ooooo00Gok^k^oeEEEOoMgMgo
EEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0:oooo
o`03o`000?oooooooooo03Sooooo00Co0000oooooooooooo0000oooooonPooooo`0000?oooooo`00
0?l000001?l00002ooooo`Go00001?ooool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo
00;ooooo00Go410@oooooooooooooooooa0@400:ooooo`03o`000?oooooooooo03Sooooo00Co0000
oooooooooooo0000oooooonPooooo`002Oooool01?m4A4CogMgMooooool00004ooooo`05onk^k_mE
EEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
00002_ooool00ol0003oooooooooo`0hooooo`04o`000?ooooooooooo`0000Wooooo00?o0000oooo
ooooool0oooooonDooooo`002Oooool01?oMgMgoEEEEooooool00003ooooo`07onk^k_mEEEGok^k^
ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000:ooooo`Co0000=oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo0?oo
ooooU?ooool000[ooooo00?oMgMgolc<c?l000000oooool2onk^kP?ooooo0_o^k^h5ooooo`03o`00
0?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400:ooooo`03o`000?oooooooooo03So
oooo00Co0000oooooooooooo00002?ooool2o`000?ooooooU_ooool000[ooooo00?ok^k^odA4A?l0
00003oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool2o`00
00Gooooo00?o0000ooooooooool0>?ooool01?l0003oooooooooool00008ooooo`;o0000oooooonF
ooooo`002oooool00omgMgOo0000ooooo`0<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP02ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0>?oo
ool01?l0003oooooooooool00008ooooo`;o0000oooooonFooooo`00:?ooool01?l0003ooooooooo
ool00004ooooo`03o`000?oooooooooo02gooooo0_l00009ooooo`04o`000?ooooooooooo`0000So
oooo0_l0003ooooooiKooooo000Xooooo`?o00001Oooool00ol0003oooooooooo`0]ooooo`;o0000
2Oooool01?l0003oooooooooool00008ooooo`;o0000oooooonFooooo`00:Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo02gooooo0_l00009ooooo`04o`000?ooooooooooo`0000So
oooo00?o0000ooooool00000oooooonEooooo`00:_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo02gooooo0_l00009ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool0
0000oooooonEooooo`00<?ooool00ol0003oooooooooo`0]ooooo`;o00002Oooool01?l0003ooooo
ooooool00008ooooo`03o`000?oooooo00000?ooooooUOooool0033ooooo00?o0000ooooooooool0
;Oooool2o`0000Wooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003ooooooiGo
oooo000`ooooo`03o`000?oooooooooo02gooooo0_l00009ooooo`04o`000?ooooooooooo`0000So
oooo00?o0000ooooool00000oooooonEooooo`00<?ooool00ol0003oooooooooo`0]ooooo`;o0000
2Oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?ooooooUOooool0033ooooo
0ol0000]ooooo`;o00002Oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?oo
ooooUOooool0033ooooo00?o0000ooooooooool0;Oooool2o`0000Wooooo00Co0000oooooooooooo
00002?ooool00ol0003oooooo`00003ooooooiGooooo000`ooooo`03o`000?oooooooooo02gooooo
0_l00009ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooonEooooo`00
<?ooool00ol0003oooooooooo`0]ooooo`;o00002Oooool01?l0003oooooooooool00008ooooo`03
o`000?oooooo00000?ooooooUOooool0033ooooo00?o0000ooooooooool0;Oooool00ol0003ooooo
o`000008ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooonEooooo`00
<?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooo000000Sooooo00Co0000oooooooooooo
00002?ooool00ol0003oooooo`00003ooooooiGooooo000`ooooo`03o`000?oooooooooo02gooooo
00?o0000ooooool000002?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?oo
ooooUOooool0033ooooo00?o0000ooooooooool0;?ooool01?l0003oooooooooool00008ooooo`04
o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooonEooooo`00<?ooool00ol0003o
ooooooooo`0/ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002?ooool0
0ol0003oooooo`00003ooooooiGooooo000`ooooo`03o`000?oooooooooo02cooooo00Co0000oooo
oooooooo00002?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?ooooooUOoo
ool0033ooooo00?o0000ooooooooool0;?ooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000Oooooo00Co0000oooooooooooo0000oooooonEooooo`00<?ooool00ol0003ooooo
ooooo`0/ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001oooool01?l0
003oooooooooool0003ooooooiGooooo000`ooooo`?o0000;?ooool01?l0003oooooooooool00008
ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo0000oooooonEooooo`00<?oo
ool00ol0003oooooooooo`0/ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo
00001oooool01?l0003oooooooooool0003ooooooiGooooo000`ooooo`03o`000?oooooooooo02co
oooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00007ooooo`04o`000?oooooo
ooooo`000?ooooooUOooool0033ooooo00?o0000ooooooooool0;?ooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo0000oooooonEooooo`00
<?ooool00ol0003oooooooooo`0/ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooo
oooo00001oooool01?l0003oooooooooool0003ooooooiGooooo000`ooooo`03o`000?oooooooooo
02cooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00007ooooo`04o`000?oo
ooooooooo`000?ooooooUOooool0033ooooo00?o0000ooooooooool0;?ooool01?l0003ooooooooo
ool00007ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool0003ooooo
oiGooooo000`ooooo`03o`000?oooooooooo02cooooo00Co0000oooooooooooo00001oooool01Ol0
003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000oooooonEooooo`00<?ooool0
0ol0003oooooooooo`0/ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooooooooooo
o`000007ooooo`04o`000?ooooooooooo`000?ooooooUOooool0033ooooo00?o0000ooooooooool0
;?ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001oooool01?l0
003oooooooooool0003ooooooiGooooo000`ooooo`03o`000?oooooooooo02_ooooo00Go0000oooo
ooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool01?l0003ooooooooo
ool0003ooooooiGooooo000`ooooo`?o0000:oooool01Ol0003ooooooooooooooooo000000Oooooo
00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`000?ooooooUOooool0033o
oooo00?o0000ooooooooool0:oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooo
ooooooooooooo`000007ooooo`04o`000?ooooooooooo`000?ooooooUOooool0033ooooo00?o0000
ooooooooool0:oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooooooooooooooo
o`000007ooooo`04o`000?ooooooooooo`000?ooooooUOooool0033ooooo00?o0000ooooooooool0
:oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007oooo
o`04o`000?ooooooooooo`000?ooooooUOooool0033ooooo00?o0000ooooooooool0:oooool01Ol0
003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?oo
ooooooooo`000?ooooooUOooool0033ooooo00?o0000ooooooooool0:oooool01Ol0003ooooooooo
oooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`00
0?ooooooUOooool0033ooooo00?o0000ooooooooool0:oooool01Ol0003ooooooooooooooooo0000
00Oooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`000?ooooooUOoo
ool0013ooooo0_o^k^h3ooooo`;ok^k^6Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go
0000ooooooooooooooooo`00003ooooooiCooooo0009ooooo`Go00000_ooool01oo^k^koEEEEonk^
k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h:ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`04ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo00000?oo
ooooU?ooool000Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05onk^k_mEEEGogMgMoeEE
EOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02_ooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
1Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`00003ooooooiCooooo
00000ooooooo0000o`000004o`0000?ooooo00?oV9RHob4Q8Oo^k^h01Oooool00ooMgMgo0000omgM
g@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400:ooooo`03o`00
0?oooooooooo02_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`00
0?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo00000?ooooooU?ooool000_o
oooo00?oV9RHob4Q8Oo^k^h00oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000000[ooooo00?o0000ooooooooool0:oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00
0007ooooo`05o`000?ooooooooooooooool00000oooooonDooooo`003?ooool02omgMgOoIVIVoooo
ooooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000000[ooooo1?l0000Zooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go
0000ooooooooooooooooo`00003ooooooiCooooo000=ooooo`03o`000?oooooooooo00;ok^k^0ooo
ool2onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00[ooooo
00?o0000ooooooooool0:oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool0
00001oooool2o`000?ooooooRoooool000Wooooo00Go0000okZj^_ooooooV9RHoa0@400>ooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`;o00001Oooool00ol0
003oooooooooo`0[ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000007
ooooo`;o0000oooooon;ooooo`002Oooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo00?oEEEE
ofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooo
ooooo`000007ooooo`;o0000oooooon;ooooo`00:?ooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo02_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000
00Oooooo0_l0003ooooooh_ooooo000Xooooo`?o00001Oooool00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000007ooooo`;o0000oooooon;oooo
o`00:Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02_ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool01Ol0003ooooooooooooooooo000000Oooooo0_l0003ooooooh_ooooo000Zooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05
o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003ooooooh[ooooo000`ooooo`03
o`000?oooooooooo02_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000
00Oooooo00?o0000ooooool00000oooooon:ooooo`00<?ooool00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo0000
0?ooooooR_ooool0033ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05
o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003ooooooh[ooooo000`ooooo`03
o`000?oooooooooo02_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000
00Oooooo00?o0000ooooool00000oooooon:ooooo`00<?ooool3o`0002_ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooool00000oooooon:oooo
o`00<?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooool00000oooooon:oooo
o`00<?ooool00ol0003oooooooooo`0Pooooo`;o00002Oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05
o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003ooooooh[ooooo000`ooooo`03
o`000?oooooooooo023ooooo0_l00009ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooo
ooooooooo`000006ooooo`04o`000?ooooooooooo`000?ooooooR_ooool0033ooooo00?o0000oooo
ooooool08?ooool00ol0003oooooo`000008ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooo
ooooooooooooo`000006ooooo`04o`000?ooooooooooo`000?ooooooR_ooool0033ooooo00?o0000
ooooooooool08?ooool00ol0003oooooo`000008ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000
ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`000?ooooooR_ooool0033ooooo00?o
0000ooooooooool08?ooool00ol0003oooooo`000008ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go
0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`000?ooooooR_ooool0033ooooo
00?o0000ooooooooool08?ooool00ol0003oooooo`000008ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo
00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`000?ooooooR_ooool0033o
oooo00?o0000ooooooooool07oooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`000?ooooooR_oo
ool0033ooooo00?o0000ooooooooool07oooool01?l0003oooooooooool00008ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`000?oo
ooooR_ooool0033ooooo00?o0000ooooooooool07oooool01?l0003oooooooooool00008ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?oooooooooo
o`000?ooooooR_ooool0033ooooo00?o0000ooooooooool07oooool01?l0003oooooooooool00008
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?oo
ooooooooo`000?ooooooR_ooool0033ooooo0ol0000Oooooo`04o`000?ooooooooooo`0000Sooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
00Co0000oooooooooooo0000oooooon:ooooo`00<?ooool00ol0003oooooooooo`0Oooooo`04o`00
0?ooooooooooo`0000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00?ooooo00Co0000oooooooooooo0000oooooon:ooooo`00<?ooool00ol0003o
ooooooooo`0Oooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo0000oooooon:
ooooo`00<?ooool00ol0003oooooooooo`0Oooooo`04o`000?ooooooooooo`0000Sooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Co0000
oooooooooooo0000oooooon:ooooo`00<?ooool00ol0003oooooooooo`0Nooooo`05o`000?oooooo
ooooooooool000002?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool01Ol0003ooooooooooooooooo00000?ooooooROooool0033ooooo00?o
0000ooooooooool07_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000onk^k_oooooo
ooooo`000002onk^kUOooooo0_o^k^h3ooooo`;ok^k^H?ooool2onk^kP?ooooo0_o^k^i>ooooo`;o
k^k^0oooool2onk^kVcooooo000`ooooo`03o`000?oooooooooo01kooooo00Go0000oooooooooooo
ooooo`000008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool3o`00000:
oc8b<_oMgMgoooooo`000?mEEEGok^k^ooooool0003oEEEEonk^kP?ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^@_ooool4o`000009oa0@4?ooooook^k^oeEEEOo^k^kooooo
onk^k_mEEEGok^k^00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^>ooo
ool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`0=odA4A?l0003o0000oc8b<_oMgMgo
ooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co000000So410@ooooooooooook^k^
oc8b<_l0003o<S8bonk^kSSooooo1Ol00002ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^
kP03ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kUgooooo000`ooooo`03
o`000?oooooooooo01kooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool03?l0003ooooooooooomgMgOo<S8booooool0003ok^k^
oeEEEOoMgMgo0000onk^kPKooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg04Cooooo00?o0000ooooooooool00_ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg03gooooo00?o0000ooooooooool0
1?ooool2ob4Q8@Sooooo00WoMgMgoc8b<_ooooooooooonk^k_mEEEGogMgMoeEEEOo^k^h01_ooool0
0ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0>?ooool01OnHV9So8B4Qonk^
k_ooooooA4A400?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Mooooo`00<?ooool00ol0003oooooooooo`0Nooooo`05
o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00Wo0000ooooooooooooooooo`000?oooooo0000oooooooMgMd00_l00007ooooo`03o`00
0?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4014ooooo`03o`000?oooooooooo00?o
oooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooo
ool@4100?Oooool00ol0003oooooooooo`0?ooooo`07o`000?oooooooooooooooooMgMgo0000omgM
g@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400iooooo`03oiRH
V?lQ8B7ok^k^00Gooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@
4?ooooooooooooooool@4100GOooool0033ooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`0<o`000?ooooooooooogMgMolb<S;oooooo`000?o^k^koEEEEomgMgOl0003ok^k^
1Oooool3o`0000?ooooo00Go0000ooooooooooooooooo`000014ooooo`03o`000?oooooooooo00;o
oooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`00000mooooo`03o`000?oooooooooo00kooooo00WoMgMgoc8b<_ooooooooooonk^
k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000>_ooool00onHV9So8B4Qonk^kP03ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000GOooool0033ooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`0=o`000?lQ8B7o0000oc8b<_o<c<cooooo
o`000?mEEEGok^k^ooooool0003oEEEEonk^kP04ooooo`?o00000oooool01Ol0003ooooooooooooo
oooo000004Cooooo00_o0000ooooooooooooooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000mooooo`03o`000?oo
oooooooo00_ooooo00go0000ob4Q8Ol0003o<S8bolc<c?ooooook^k^oeEEEOo^k^koooooonk^k_mE
EEGok^k^00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000003_ooooo
00_oMgMgofIVI_ooooooooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00001Mooooo`00<?ooool00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool01Ol0003ok^k^oooo
oooooooo000000;ok^k^1?ooool3o`0000?ooooo00Go410@oooooooooooooooooa0@4014ooooo`04
o`000?ooooooooooooooo`;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@
413ooooooooooooooooo410@03gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`03
ooooo`;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@03cooooo00?o0000ooooooooool00_o^k^h3ooooo`;ok^k^1Oooool00ol0003ooooooooo
o`02ooooo`05oa0@4?ooooooooooooooool@4100GOooool0033ooooo0ol0000Nooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Kooooo
0ol00003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`0iooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Sooooo0_l0000cooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool2o`0002kooooo00Go0000
okZj^_ooooooV9RHoa0@400>ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`08ooooo`;o0000Doooool0033ooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`Co00000_ooool01Ol0003ooooooooooooooooo000000Gooooo00CoEEEEo`000?l0003o
00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0=oooool00omE
EEGoIVIVo`00000=ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP07
ooooo`04o`000?ooooooooooo`00033ooooo00?oEEEEofIVI_l000003Oooool4o`0000cooooo00?o
EEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oooooo00Co0000oooooooooooo
0000;Oooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo00?oEEEEofIVI_l000001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Oooooo00Co0000oooooooooooo0000D_ooool0033ooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00Go0000
ooooooooooooooooo`000005ooooo`05o`000?ooooooooooooooool000002Oooool4o`0000?ooooo
00?o0000ooooooooool0E?ooool4o`000005ooooool0003oooooooooool00000G_ooool4o`000005
ooooool0003oooooooooool00000C?ooool4o`000005ooooool0003oooooooooool00000D_ooool0
033ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooooooo
ooooool000004?ooool00ol0003oooooooooo`1Iooooo`?o0000I?ooool3o`0005;ooooo0ol0001C
ooooo`00<?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000oooo
ooooooooooooo`00000>ooooo`04o`000?ooooooooooo`0005_ooooo00?o0000ooooooooool0I?oo
ool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo05;ooooo000`ooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000kooooo1?l0
001Looooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0D_ooool00ol0003ooooooooo
o`1Aooooo`00<?ooool00ol0003oooooooooo`0Booooo`?o00002?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`05o`000?ooooooooooooooool00000oooooomoooooo`00<?ooool00ol0003oooooooooo`0A
ooooo`;o000000?oooooo`000?ooool01oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool00000oooooom5ooooo`03ogMgMomVIVKooooo02gooooo00?oIVIVogMgMoooool01ooo
ool0033ooooo00?o0000ooooooooool04Oooool01Ol0003ooooooooooooooooo000000Oooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo0_l0003ooooooccooooo
00?ogMgMoa0@4?o^k^h0;_ooool00oo^k^ko410@omgMg@07ooooo`00<?ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooo`00003oooooobWooooo
0_l00002ooooo`;o00003?ooool00omEEEGoV9RHooooo`02o`0000;ooooo00Oo0000oooooooooooo
0000oa0@4?o^k^koEEEE00;o000000?oA4A4okZj^_ooool00_ooool01OnHV9So0000o`000?m4A4Co
^[Zj00;ooooo00Sok^k^oeEEEOl0003o0000odA4A?nj^[[ooooooa0@40Go00000oooool02?l@413o
<S8bo`000?l0003o410@ojVYZOn7QhOoIVIV1oooool0033ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000000Gooooo00Co0000oooooooooooo0000oooooolYooooo`06onk^
k_lQ8B7oQhN7okZj^_l0003ogMgM3?ooool01Ol0003ooooooooooooooooo000000;ooooo00_o0000
oooooooooooo0000oooooomEEEGoMgMgooooooo^k^koMgMgoa0@4003ooooo`05oa0@4?nj^[[ok^k^
ogMgMol@41000_ooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40?ooooo00?o0000ooooooooool0
1?ooool02?l0003oZJVYoooooooooooo^[Zjo`000?o^k^ko00001oooool00?oo0000]?l0000?oooo
o`04omgMgOl0003o410@olc<c0gooooo00Go<S8booooooooooooooooo`000002ooooo`06o`000?oo
ooooooooo`000?oooooo00002?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01Oooool01onj^[[oQhN7ofIVI_mVIVKo410@ooooool000001oooool0
00[ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
00Oooooo1?l00002ooooo`;o000000?oooooo`000?ooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00?ooooo0_l00005ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_ooool2o`0000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooool000001?ooool00ol0003oooooooooo`02ooooo`;o000000?ooooo
o`000?l000000_ooool00ol0003oooooooooo`03o`0000gooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0Gooooo`04onk^k_lQ8B7o410@onk^kPgooooo00Go<S8boooooooooooooooo
o`000002ooooo`05o`000?ooooooooooo`000?ooool01_l00003ooooo`03o`000?oooooooooo00Co
oooo1_l00003ooooo`03o`000?oooooooooo00Cooooo00So<S8bob4Q8OmgMgOoMgMgohN7Qoo^k^ko
ooooo`0000Oooooo000:ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0:ooooo`Co00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool2o`0000Gooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`;o00001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooo
ooooooooool000000oooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00Cooooo0_l0
0004ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0Gooooo`04ob4Q8OmgMgOoMgMgoc8b<Pgooooo00Go0000onk^k_ooooooooooo`000002olc<c00;
o`000?nYZJWogMgMob4Q8OooooooEEEEohN7Qoo^k^koooooohN7Qolb<S800oooool00ol0003ooooo
ooooo`04ooooo`06oeEEEOn7QhOok^k^oooooon7QhOo<S8b0oooool00ol0003o<S8bomgMg@04oooo
o`08o`000?nj^[[oooooonk^k_mgMgOo0000onk^k_l00007ooooo`00<?ooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`00
0?oooooo000000?ooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`1Kooooo`03o`00
0?oooooooooo05_ooooo00?o0000ooooooooool05_ooool2o`0000;ooooo0_l0000<ooooo`0>oeEE
EOmgMgOooooooa0@4?l0003o8B4Qo`000?mgMgOo410@o`000?nYZJWoooooonk^k_mEEED2o`000004
odA4A?o^k^kooooooa0@40Go00000oooool01_o^k^koEEEEo`000?l0003oA4A4onk^kP;ooooo0_l0
00001?nYZJWo8B4Qo`000?lQ8B42ooooo`08ojVYZOlQ8B7o0000o`000?lb<S;o0000ogMgMomEEED7
ooooo`00<?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000oooo
ooooooooooooo`000005ooooo`05o`000?ooooooooooooooool00000ooooooloooooo`03omgMgOl@
413ok^k^01;ooooo00?o0000ooooooooool06Oooool00oo^k^ko410@omgMg@07ooooo`00<?ooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00
0006ooooo`04o`000?ooooooooooo`000?oooooo@?ooool00omgMgOoIVIVooooo`0Aooooo`03o`00
0?oooooooooo01Wooooo00?oIVIVogMgMoooool01oooool0033ooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooo
o`00003oooooog_ooooo000`ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooo
ool01Ol0003ooooooooooooooooo000000Kooooo0ol0003oooooog_ooooo000`ooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Oooooo
00?o0000ooooooooool0oooooomjooooo`00<?ooool00ol0003oooooooooo`0Gooooo`05o`000?oo
ooooooooooooool000002?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
00Go0000ooooooooooooooooo`00003oooooohCooooo000`ooooo`03o`000?oooooooooo01Sooooo
00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00Go0000ooooooooooooooooo`00003oooooohCooooo000`ooooo`03o`000?oooooooooo01So
oooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00?ooooo00Go0000ooooooooooooooooo`00003oooooohCooooo000`ooooo`?o00006?ooool01?l0
003oooooooooool00008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool0
1Ol0003ooooooooooooooooo00000?ooooooQ?ooool0033ooooo00?o0000ooooooooool06Oooool0
0ol0003oooooo`000008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool0
1Ol0003ooooooooooooooooo00000?ooooooQ?ooool0033ooooo00?o0000ooooooooool06Oooool0
0ol0003oooooo`000008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool0
1Ol0003ooooooooooooooooo00000?ooooooQ?ooool0033ooooo00?o0000ooooooooool06Oooool3
o`0000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooo
ooooooooool00000oooooon4ooooo`00<?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooo
ooooooooool00000oooooon4ooooo`00<?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool0003oooooohGooooo000`
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`04o`000?ooooooooooo`000?ooooooQOooool0033ooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooool00000oooooon5
ooooo`00<?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooo`00003oooooohGooooo000`ooooo`03o`000?oooooooooo02Go
oooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo00000?ooooooQOooool0033o
oooo00?o0000ooooooooool09Oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ool00000oooooon5ooooo`00<?ooool00ol0003oooooooooo`0Uooooo`05o`000?oooooooooooooo
ool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooo`00003oooooohGooooo000`ooooo`?o00009Oooool01Ol0003o
oooooooooooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooool00000oooooon5ooooo`00<?ooool00ol0003o
ooooooooo`0Uooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooo`00003ooooo
ohGooooo000`ooooo`03o`000?oooooooooo02Gooooo00Go0000ooooooooooooooooo`000007oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000007ooooo`;o0000oooooon6
ooooo`00<?ooool00ol0003oooooooooo`0Uooooo`05o`000?ooooooooooooooool000001oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001oooool2o`000?ooooooQ_oo
ool0033ooooo00?o0000ooooooooool09Oooool01Ol0003ooooooooooooooooo000000Oooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0
oooooon4ooooo`00<?ooool00ol0003oooooooooo`0Uooooo`05o`000?ooooooooooooooool00000
1oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool00000oooooon?ooooo`00
<?ooool00ol0003oooooooooo`0Uooooo`05o`000?ooooooooooooooool000001oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`05o`000?ooooooooooooooool00000oooooon?ooooo`00<?ooool00ol0003o
ooooooooo`0Uooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`05o`000?ooooooooooooooool00000oooooon?ooooo`00<?ooool00ol0003oooooooooo`0Uoooo
o`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooo
ooooooooool00000oooooon?ooooo`00<?ooool00ol0003oooooooooo`0Uooooo`05o`000?oooooo
ooooooooool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool00000
oooooon?ooooo`00<?ooool00ol0003oooooooooo`0Uooooo`05o`000?ooooooooooooooool00000
1oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool00000oooooon?ooooo`00
<?ooool00ol0003oooooooooo`0Uooooo`05o`000?ooooooooooooooool000001oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`05o`000?ooooooooooooooool00000oooooon?ooooo`00<?ooool3o`0002Go
oooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000oooo
ooooooooooooo`00003oooooohoooooo000`ooooo`03o`000?oooooooooo02Gooooo00Go0000oooo
ooooooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00
003oooooohoooooo000`ooooo`03o`000?oooooooooo02Gooooo00Go0000ooooooooooooooooo`00
0007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo0000oooooon?ooooo`00<?oo
ool00ol0003oooooooooo`0Uooooo`05o`000?ooooooooooooooool000001oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`04ooooo`04o`000?ooooooooooo`000?ooooooSoooool0033ooooo00?o0000ooooooooool0
9Oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01?l0003o
ooooooooool0003oooooohoooooo000`ooooo`03o`000?oooooooooo02Gooooo00Go0000oooooooo
ooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0
003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000oooooon?ooooo`003oooool2
onk^kP?ooooo0_o^k^hJooooo`03o`000?oooooooooo02Gooooo00Go0000ooooooooooooooooo`00
0007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000Oooooo00Co0000oooooooooooo0000oooooon?ooooo`002?ooool5o`0000;ooooo
00Ook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413oooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^2oooool00ol0003oooooooooo`0Uooooo`05o`000?ooooooooooooooool0
00001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooo
ooooooooo`000007ooooo`04o`000?ooooooooooo`000?ooooooSoooool000Sooooo00GoV9RHob4Q
8Oo^k^koooooodA4A003ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ol0003oooooooooo`0Uooooo`05o`00
0?ooooooooooooooool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`000?ooooooSoooool0
00Wooooo00?oV9RHob4Q8Oo^k^h01Oooool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo
00;ooooo00Go410@oooooooooooooooooa0@400;ooooo`03o`000?oooooooooo02Gooooo00Go0000
ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000oooooon?ooooo`00
2_ooool00onHV9So8B4Qonk^kP03ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`0Uoooo
o`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`000?oooooo
Soooool000_ooooo00_oMgMgofIVI_ooooooooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000;ooooo`Co00009Ooo
ool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000oooooon?oooo
o`003?ooool00ol0003oooooooooo`02onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;o
oooo00Go410@oooooooooooooooooa0@400;ooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ool000002?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooo
ooooooooooooo`000007ooooo`04o`000?ooooooooooo`000?ooooooSoooool000Sooooo00Go0000
okZj^_ooooooV9RHoa0@400>ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooool000002?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000007ooooo`04
o`000?ooooooooooo`000?ooooooSoooool000Sooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00<oooo
o`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`;o00001_ooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooo000000Wooooo00Go0000ooooooooooooooooo`00
0006ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool0003oooooohoo
oooo000Wooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool09_ooool00ol0003o
ooooo`000009ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo
000000Oooooo00Co0000oooooooooooo0000oooooon?ooooo`009oooool01?l0003oooooooooool0
0005ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooool000002Oooool01Ol0003ooooooooo
oooooooo000000Kooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`00
0?ooooooSoooool002Oooooo0ol00006ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooool0
00002Oooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000007
ooooo`04o`000?ooooooooooo`000?ooooooSoooool002Sooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooo000000Wooooo00Go0000ooooooooooooooooo`00
0006ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003ooooooi3ooooo
000Yooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool09_ooool00ol0003oooooo`00
0009ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Oo
oooo00?o0000ooooool00000oooooon@ooooo`00<?ooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooo000000Wooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?oooooooooooooo
ool000001oooool00ol0003oooooo`00003ooooooi3ooooo000`ooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooool000002Oooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000oooo
ooooooooooooo`000007ooooo`03o`000?oooooo00000?ooooooT?ooool0033ooooo00?o0000oooo
ooooool09oooool2o`0000Wooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?oooooo
ooooooooool000001oooool00ol0003oooooo`00003ooooooi3ooooo000`ooooo`?o00009oooool2
o`0000Wooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool00000
1oooool00ol0003oooooo`00003ooooooi3ooooo000`ooooo`03o`000?oooooooooo02Oooooo0_l0
0009ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Oo
oooo00?o0000ooooool00000oooooon@ooooo`00<?ooool00ol0003oooooooooo`0Wooooo`03o`00
0?oooooooooo00Sooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000
00Oooooo00?o0000ooooool00000oooooon@ooooo`00<?ooool00ol0003oooooooooo`0booooo`04
o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo
00000?ooooooT?ooool0033ooooo00?o0000ooooooooool0<_ooool01?l0003oooooooooool00007
ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003ooooooi3ooooo000`
ooooo`03o`000?oooooooooo03;ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooo
oooooooo000000Oooooo00?o0000ooooool00000oooooon@ooooo`00<?ooool00ol0003ooooooooo
o`0booooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000008ooooo`;o
0000oooooon@ooooo`00<?ooool00ol0003oooooooooo`0booooo`04o`000?ooooooooooo`0000Oo
oooo00Go0000ooooooooooooooooo`000008ooooo`;o0000oooooon@ooooo`00<?ooool00ol0003o
ooooooooo`0booooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000008
ooooo`;o0000oooooon@ooooo`00<?ooool00ol0003oooooooooo`0booooo`04o`000?oooooooooo
o`0000Oooooo00Go0000ooooooooooooooooo`000008ooooo`;o0000oooooon@ooooo`00<?ooool0
0ol0003oooooooooo`0booooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooooooooooo
o`000008ooooo`;o0000oooooon@ooooo`00<?ooool00ol0003oooooooooo`0booooo`04o`000?oo
ooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?oo
ooooSoooool0033ooooo0ol0000booooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooo
ooooooooo`00003ooooooi[ooooo000`ooooo`03o`000?oooooooooo03;ooooo00Co0000oooooooo
oooo00001oooool01Ol0003ooooooooooooooooo00000?ooooooV_ooool0033ooooo00?o0000oooo
ooooool0<_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool00000oooo
oonJooooo`00<?ooool00ol0003oooooooooo`0booooo`04o`000?ooooooooooo`0000Oooooo00Go
0000ooooooooooooooooo`00003ooooooi[ooooo000`ooooo`03o`000?oooooooooo03;ooooo00Co
0000oooooooooooo00002?ooool01?l0003oooooooooool0003ooooooi[ooooo000`ooooo`03o`00
0?oooooooooo03;ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0003ooooo
oi[ooooo000`ooooo`03o`000?oooooooooo03;ooooo00Co0000oooooooooooo00002?ooool01?l0
003oooooooooool0003ooooooi[ooooo000`ooooo`03o`000?oooooooooo03;ooooo00Co0000oooo
oooooooo00002?ooool01?l0003oooooooooool0003ooooooi[ooooo000`ooooo`03o`000?oooooo
oooo03;ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0003ooooooi[ooooo
000`ooooo`03o`000?oooooooooo03;ooooo00Co0000oooooooooooo00002?ooool01?l0003ooooo
ooooool0003ooooooi[ooooo000`ooooo`03o`000?oooooooooo03;ooooo00Co0000oooooooooooo
00002?ooool01?l0003oooooooooool0003ooooooi[ooooo000`ooooo`03o`000?oooooooooo03;o
oooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0003ooooooi[ooooo000`oooo
o`?o0000<_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`000?ooooooV_oo
ool0033ooooo00?o0000ooooooooool0<_ooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`000?ooooooV_ooool0033ooooo00?o0000ooooooooool0<_ooool01?l0003ooooooooo
ool00008ooooo`03o`000?oooooo00000?ooooooVoooool0033ooooo00?o0000ooooooooool0<_oo
ool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?ooooooVoooool0033ooooo00?o
0000ooooooooool0<_ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?oooooo
Voooool0033ooooo00?o0000ooooooooool0<_ooool01?l0003oooooooooool00008ooooo`03o`00
0?oooooo00000?ooooooVoooool000oooooo0_o^k^h3ooooo`;ok^k^6_ooool00ol0003ooooooooo
o`0booooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooonKooooo`002_oo
ool2o`00000:oa0@4?ooooooooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP?ooooo1?l00000
2?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool00ol0003oooooooooo`0booooo`04
o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooonKooooo`002oooool00ol0003o
ooooooooo`02ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ol0003oooooooooo`0booooo`04o`000?oooooo
ooooo`0000Sooooo00?o0000ooooool00000oooooonKooooo`002?ooool5o`0000Cooooo00?ogMgM
o`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41002ooo
ool00ol0003oooooooooo`0booooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000
oooooonKooooo`002?ooool01?m4A4CogMgMooooool00004ooooo`05onk^k_mEEEGogMgMoeEEEOo^
k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000002oooool00ol0
003oooooooooo`0booooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooonK
ooooo`002?ooool01?oMgMgoEEEEooooool00003ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEE
onk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000;ooooo`Co
0000<Oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?ooooooVoooool000Wo
oooo00?oMgMgolc<c?l000000oooool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;o
oooo00Go410@oooooooooooooooooa0@400;ooooo`03o`000?oooooooooo03;ooooo00Co0000oooo
oooooooo00002?ooool00ol0003oooooo`00003ooooooi_ooooo0009ooooo`03onk^k_m4A4Co0000
00oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?o0000
ooooooooool0<_ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?ooooooVooo
ool000[ooooo00?oMgMgo`000?ooool03?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00oooool2o`0000Kooooo00?o0000ooooooooool0<_ooool00ol0003oooooo`00
0009ooooo`03o`000?oooooo00000?ooooooVoooool002Oooooo00Co0000oooooooooooo00001Ooo
ool00ol0003oooooooooo`0booooo`03o`000?oooooo000000Wooooo00?o0000ooooool00000oooo
oonKooooo`009oooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo03?ooooo0_l0
0009ooooo`03o`000?oooooo00000?ooooooVoooool002Oooooo0ol00006ooooo`03o`000?oooooo
oooo03?ooooo0_l00009ooooo`03o`000?oooooo00000?ooooooVoooool002Sooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0cooooo`;o00002Oooool00ol0003oooooo`00003ooooo
oi_ooooo000Yooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0<oooool2o`0000Wo
oooo00?o0000ooooool00000oooooonKooooo`00<?ooool00ol0003oooooooooo`0cooooo`;o0000
2Oooool00ol0003oooooo`00003ooooooi_ooooo000`ooooo`03o`000?oooooooooo03?ooooo0_l0
0009ooooo`03o`000?oooooo00000?ooooooVoooool0033ooooo00?o0000ooooooooool0<oooool2
o`0000[ooooo0_l0003ooooooi_ooooo000`ooooo`?o0000<oooool2o`0000[ooooo0_l0003ooooo
oi_ooooo000`ooooo`03o`000?oooooooooo03?ooooo0_l0000:ooooo`;o0000oooooonKooooo`00
<?ooool00ol0003oooooooooo`0cooooo`;o00002_ooool2o`000?ooooooVoooool0033ooooo00?o
0000ooooooooool0<oooool2o`0000[ooooo0_l0003ooooooi_ooooo000`ooooo`03o`000?oooooo
oooo03?ooooo0_l0000:ooooo`;o0000oooooonKooooo`00<?ooool00ol0003oooooooooo`0coooo
o`;o00002_ooool2o`000?ooooooVoooool0033ooooo00?o0000ooooooooool0<oooool2o`0000[o
oooo0_l0003ooooooi_ooooo000`ooooo`03o`000?oooooooooo03?ooooo0_l0000:ooooo`;o0000
oooooonKooooo`00<?ooool00ol0003oooooooooo`0cooooo`;o00002_ooool00ol0003ooooooooo
o`3ooooooi[ooooo000`ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0oooooonJ
ooooo`00<?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo0?ooooooV_ooool0033o
oooo00?o0000ooooooooool0oooooooLooooo`00<?ooool3o`000?oooooog?ooool0033ooooo00?o
0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`oooo
o`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00
<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?oo
ool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3ooooo
omcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0
oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`?o0000oooooooL
ooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oo
oooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooooooo
o`3oooooomcooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3o
oooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooo
oooooooo4?ooool00?ooooooooooool@ooooo`00X?ooool2o`0000Cooooo00?o^[Zjoc8b<_ooool0
1?ooool2o`0000Kooooo00?o0000okZj^_ooool0oooooomGooooo`00X?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool2oc8b<_ooooooF?oo
ool008gooooo0ol00002ooooo`06oc8b<_l@413oooooooooooo^k^koEEEE0_l000000om4A4Co^[Zj
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00GoV9RHoa0@4?l0003o0000ojVYZ@04ooooo`03
o`000?oooooooooo00Cooooo00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj
00Wooooo1Ol00005ooooo`;o8B4Q1?ooool02oo<c<co8B4Qo`000?lQ8B7oc<c<ooooooo<c<cok^k^
ooooooo^k^koc<c<00Cooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^4ooo
ool01_l@413o<S8bo`000?l0003o410@ojVYZ@;ooooo00Kok^k^oeEEEOl0003o0000odA4A?nj^[X3
ooooo`05ofIVI_l0003o0000odA4A?o<c<`0j?ooool008kooooo00Go0000ooooooooooooc<c<oa0@
4003ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo410@1?ooool00ol0003oooooooooo`02ooooo`06
o`000?nYZJWoEEEEoiRHV?mEEEGo^[Zj0oooool00ol0003oooooooooo`04ooooo`03olc<c?l0003o
410@00cooooo00Ko410@okZj^_o^k^koMgMgoa0@4?ooool6o`0000;ooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A005ooooo`;o8B4Q1?ooool02olQ8B7oV9RHoooooonHV9So8B4Qooooooo^k^koEEEEomgM
gOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01?o
oooo00Ko0000ojVYZOoooooooooookZj^_l00002ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo410@
0_ooool01_mVIVKoMgMgooooooooooooQhN7oa0@4>Sooooo002>ooooo`05o`000?oooooooooooeEE
EOn7QhL00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00Ko<S8bonk^
k_nHV9SoEEEEomgMgOl@4103ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool03?oo
ool00onHV9So8B4Qonk^kP0<ooooo`05o`000?ooooooooooooooool000000_ooool00ooMgMgo0000
omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Dooooo`05
okZj^_n7QhOoIVIVofIVI_l@41000_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0>_ooooo002>ooooo`05o`000?oooooogMgMo`000?o^k^h00oooool6o`0000Cooooo00?o0000oooo
ooooool00_ooool01onj^[[oA4A4olc<c?lQ8B7ooooooa0@4?o<c<`00_ooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo00?ooooo1_l00004ooooo`03oiRHV?lQ8B7ok^k^00_ooooo00_o
<S8boiRHV?ooooooV9RHoc8b<_ooooook^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`00000Cooooo`06oc8b<_lQ8B7oMgMgogMgMon7QhOo
k^k^0_ooool6o`0000;ooooo00?o0000ooooooooool0joooool008kooooo0ol000000ol@413oV9RH
ooooo`02ooooo`06oeEEEOn7QhOok^k^oooooon7QhOo<S8b1?ooool00ol0003oooooooooo`02oooo
o`07onk^k_l0003oooooo`000?ooooooIVIVohN7Q`02ooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool03_ooool00omgMgOoIVIVooooo`0:ooooo`0;olc<c?l0003o0000o`000?o<c<co
ooooolc<c?o^k^koooooonk^k_o<c<`01_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000004oooool01_l0003o^[Zjooooooo^k^koMgMgo`0000;ooooo00KoEEEEohN7Qoo^
k^koooooohN7Qolb<S82ooooo`06ofIVI_mgMgOooooooooooon7QhOo0000j?ooool008kooooo00Go
0000ooooooooooooc<c<o`000003ooooo`06onk^k_mEEEGo0000o`000?m4A4Cok^k^1?ooool00ol0
003oooooooooo`02ooooo`04ofIVI_nHV9Sooooooc8b<P;o^[Zj00Co0000oooooooooooo00004ooo
ool00ol@413o0000o`000003o`0000kooooo00?o0000ooooooooool02Oooool01Ol@413o^[Zjoooo
oonj^[[o410@00cooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Oo
oooo0ol00002ooooo`?o00001?ooool01_nYZJWo8B4Qo`000?l0003o<S8bo`0000;ooooo00Kok^k^
oeEEEOl0003o0000odA4A?o^k^h2ooooo`06onk^k_mVIVKo0000o`000?m4A4Co0000j?ooool008ko
oooo00Go0000ooooooooooooc<c<o`00000=ooooo`03o`000?oooooooooo00Gooooo00?oIVIVohN7
Qoooool00oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00_ooooo00Go0000okZj
^_ooooooV9RHoa0@400;ooooo`05o`000?nj^[[ooooookZj^_l000003?ooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo0?oooooo0_ooool008gooooo1?l000000ol@413oZJVYooooo`0<ooooo`;o00001_oo
ool00onYZJWoA4A4ooooo`02ooooo`;o00005Oooool00ol0003oooooooooo`0;ooooo`05oiRHV?l@
413o0000ob4Q8Oo<c<`02oooool01OnYZJWo410@o`000?l@413oZJVY00[ooooo00?oEEEEofIVI_l0
00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo1?l00002ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0ooooool2ooooo`00ooooool6ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0ooooool2ooooo`00ooooool6ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0ooooool2ooooo`00ooooool5ooooo`;o00000oooool2o`000?oooooo1?oo
ool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooo
ooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@oooo
o`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooo
oooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo
003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooo
oooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo0000\
\>"],
  ImageRangeCache->{{{0, 525.688}, {324.5, 0}} -> {0, -6.34248*^6, 0, 53093}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0.309017 5.42214e-08 [
[.32684 .29652 -16.5 -12.5 ]
[.32684 .29652 16.5 0 ]
[.54329 .29652 -16.5 -12.5 ]
[.54329 .29652 16.5 0 ]
[.75974 .29652 -22.5 -12.5 ]
[.75974 .29652 22.5 0 ]
[.97619 .29652 -16.5 -12.5 ]
[.97619 .29652 16.5 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 64 6 ]
[.09789 .09213 -34.5 -6.25 ]
[.09789 .09213 0 6.25 ]
[.09789 .20057 -34.5 -6.25 ]
[.09789 .20057 0 6.25 ]
[.09789 .41746 -28.5 -6.25 ]
[.09789 .41746 0 6.25 ]
[.09789 .5259 -28.5 -6.25 ]
[.09789 .5259 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -59.8125 0 ]
[.5 .63053 59.8125 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 .30902 m
.32684 .31527 L
s
gsave
.32684 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 .30902 m
.54329 .31527 L
s
gsave
.54329 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 .30902 m
.75974 .31527 L
s
gsave
.75974 .29652 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 .30902 m
.15368 .31277 L
s
.19697 .30902 m
.19697 .31277 L
s
.24026 .30902 m
.24026 .31277 L
s
.28355 .30902 m
.28355 .31277 L
s
.37013 .30902 m
.37013 .31277 L
s
.41342 .30902 m
.41342 .31277 L
s
.45671 .30902 m
.45671 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.58658 .30902 m
.58658 .31277 L
s
.62987 .30902 m
.62987 .31277 L
s
.67316 .30902 m
.67316 .31277 L
s
.71645 .30902 m
.71645 .31277 L
s
.80303 .30902 m
.80303 .31277 L
s
.84632 .30902 m
.84632 .31277 L
s
.88961 .30902 m
.88961 .31277 L
s
.9329 .30902 m
.9329 .31277 L
s
.0671 .30902 m
.0671 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09213 m
.11664 .09213 L
s
gsave
.09789 .09213 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .20057 m
.11664 .20057 L
s
gsave
.09789 .20057 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .41746 m
.11664 .41746 L
s
gsave
.09789 .41746 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .5259 m
.11664 .5259 L
s
gsave
.09789 .5259 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.11039 .11924 m
.11414 .11924 L
s
.11039 .14635 m
.11414 .14635 L
s
.11039 .17346 m
.11414 .17346 L
s
.11039 .22768 m
.11414 .22768 L
s
.11039 .2548 m
.11414 .2548 L
s
.11039 .28191 m
.11414 .28191 L
s
.11039 .33613 m
.11414 .33613 L
s
.11039 .36324 m
.11414 .36324 L
s
.11039 .39035 m
.11414 .39035 L
s
.11039 .44457 m
.11414 .44457 L
s
.11039 .47168 m
.11414 .47168 L
s
.11039 .49879 m
.11414 .49879 L
s
.11039 .06502 m
.11414 .06502 L
s
.11039 .03791 m
.11414 .03791 L
s
.11039 .0108 m
.11414 .0108 L
s
.11039 .55301 m
.11414 .55301 L
s
.11039 .58012 m
.11414 .58012 L
s
.11039 .60723 m
.11414 .60723 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -120.812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.812 moveto
(@) show
81.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.812 moveto
(D) show
93.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.) show
129.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
135.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
147.000 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
151.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
160.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
178.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02453 .30902 L
.02532 .30902 L
.02691 .30902 L
.02776 .30902 L
.02866 .30902 L
.03029 .30902 L
.032 .30902 L
.03362 .30902 L
.0367 .30902 L
.03826 .30902 L
.03998 .30902 L
.04077 .30902 L
.0412 .30902 L
.04161 .30902 L
.042 .30902 L
.0422 .30902 L
.04241 .30902 L
.04251 .30902 L
.04261 .30902 L
.0427 .30902 L
.04279 .30902 L
.04287 .30902 L
.04296 .30902 L
.04305 .30902 L
.04314 .30902 L
.04325 .30902 L
.04334 .30902 L
.04339 .30902 L
.04345 .30902 L
.04356 .30902 L
.04377 .30902 L
.04396 .30902 L
.04432 .30902 L
.04452 .30902 L
.04471 .30902 L
.0451 .30902 L
.04553 .30902 L
.04597 .30902 L
.04639 .30902 L
.04721 .30902 L
.04796 .30902 L
.04877 .30902 L
.04964 .30902 L
.05124 .30902 L
.05204 .30902 L
.05293 .30902 L
.05449 .30902 L
.05616 .30902 L
.05948 .30902 L
Mistroke
.06267 .30902 L
.06428 .30902 L
.06498 .30902 L
.06574 .30902 L
.06616 .30902 L
.06635 .30902 L
.06655 .30902 L
.06665 .30902 L
.06675 .30902 L
.06683 .30902 L
.06693 .30902 L
.06703 .30902 L
.06713 .30902 L
.06723 .30902 L
.06732 .30902 L
.06742 .30902 L
.06752 .30902 L
.06762 .30902 L
.06771 .30902 L
.06792 .30902 L
.06814 .30902 L
.06835 .30902 L
.06855 .30902 L
.06901 .30902 L
.06941 .30902 L
.06985 .30902 L
.07065 .30902 L
.07143 .30902 L
.07214 .30902 L
.07365 .30902 L
.07451 .30902 L
.07531 .30902 L
.07694 .30902 L
.07843 .30902 L
.08163 .30901 L
.0847 .30901 L
.08626 .30901 L
.08708 .30901 L
.08752 .30901 L
.08797 .30901 L
.08838 .30901 L
.08861 .30901 L
.08872 .30901 L
.08882 .30901 L
.08891 .30901 L
.08902 .30901 L
.08911 .30901 L
.08919 .30901 L
.08929 .30901 L
.08939 .30901 L
Mistroke
.08944 .30901 L
.0895 .30901 L
.0896 .30901 L
.0897 .30901 L
.08979 .30901 L
.09 .30901 L
.09019 .30901 L
.09039 .30901 L
.09078 .30901 L
.09112 .30901 L
.09151 .30901 L
.09193 .30901 L
.09267 .30901 L
.09346 .30901 L
.09434 .30902 L
.09591 .30902 L
.09759 .30902 L
.09929 .30903 L
.10091 .30904 L
.10399 .30906 L
.10554 .30906 L
.10637 .30907 L
.10726 .30907 L
.10767 .30907 L
.10811 .30908 L
.10851 .30908 L
.10871 .30908 L
.10889 .30908 L
.10906 .30908 L
.10924 .30908 L
.10934 .30908 L
.10943 .30908 L
.10952 .30908 L
.10962 .30908 L
.10971 .30908 L
.10981 .30908 L
.10991 .30908 L
.11 .30908 L
.1101 .30908 L
.11021 .30908 L
.11041 .30908 L
.11062 .30908 L
.11084 .30908 L
.11124 .30908 L
.11164 .30907 L
.112 .30907 L
.11282 .30907 L
.11368 .30906 L
.11445 .30904 L
.11526 .30903 L
Mistroke
.11674 .309 L
.11845 .30894 L
.12006 .30888 L
.12314 .30874 L
.1247 .30866 L
.12553 .30863 L
.12642 .3086 L
.12686 .30858 L
.12727 .30857 L
.12768 .30856 L
.12787 .30856 L
.12805 .30856 L
.12822 .30856 L
.12841 .30855 L
.12851 .30855 L
.1286 .30855 L
.12869 .30855 L
.12878 .30855 L
.12888 .30855 L
.12898 .30855 L
.12908 .30855 L
.12916 .30855 L
.12927 .30855 L
.12932 .30855 L
.12938 .30855 L
.12958 .30855 L
.12977 .30856 L
.12995 .30856 L
.13035 .30857 L
.13071 .30858 L
.13108 .30859 L
.13187 .30864 L
.13273 .3087 L
.13356 .30878 L
.1343 .30888 L
.13599 .30914 L
.13919 .30986 L
.14228 .31069 L
.14384 .31106 L
.14467 .31122 L
.14513 .3113 L
.14556 .31136 L
.14597 .3114 L
.14619 .31142 L
.14642 .31144 L
.14653 .31144 L
.14663 .31145 L
.14673 .31145 L
.14682 .31145 L
.14691 .31146 L
Mistroke
.147 .31146 L
.1471 .31146 L
.1472 .31146 L
.1473 .31146 L
.1474 .31145 L
.14748 .31145 L
.14758 .31145 L
.14779 .31144 L
.14799 .31142 L
.14835 .31138 L
.14873 .31133 L
.14912 .31125 L
.14948 .31117 L
.15029 .31092 L
.15101 .31062 L
.15176 .31024 L
.15335 .30919 L
.15482 .30792 L
.15796 .30458 L
.15956 .3028 L
.1604 .30194 L
.16129 .30112 L
.16209 .30051 L
.16251 .30024 L
.16297 .30001 L
.16318 .29991 L
.16338 .29984 L
.16358 .29978 L
.16376 .29974 L
.16393 .29971 L
.16402 .29969 L
.16412 .29968 L
.16421 .29968 L
.16432 .29967 L
.16442 .29967 L
.16451 .29967 L
.16461 .29968 L
.1647 .29969 L
.16479 .2997 L
.16489 .29972 L
.1651 .29977 L
.16529 .29983 L
.16565 .29998 L
.16602 .3002 L
.16643 .30051 L
.16681 .30086 L
.16768 .30192 L
.16852 .30328 L
.16931 .30486 L
.1708 .3086 L
Mistroke
.17386 .31871 L
.17557 .32486 L
.17712 .32997 L
.1779 .33215 L
.17874 .33409 L
.17913 .33481 L
.17954 .33543 L
.17988 .33584 L
.18008 .33602 L
.18027 .33615 L
.18037 .33621 L
.18048 .33627 L
.18057 .3363 L
.18067 .33633 L
.18072 .33634 L
.18078 .33635 L
.18083 .33635 L
.18089 .33635 L
.18099 .33634 L
.18105 .33633 L
.18111 .33632 L
.18121 .33628 L
.18131 .33624 L
.18149 .33613 L
.18169 .33597 L
.1819 .33574 L
.18228 .3352 L
.18268 .33443 L
.18339 .33254 L
.18415 .32981 L
.18496 .32603 L
.18643 .31712 L
.18975 .2896 L
.1914 .27448 L
.19294 .26173 L
.1937 .25634 L
.19442 .25211 L
.19482 .25018 L
.19526 .24846 L
.19565 .24725 L
.19583 .24681 L
.19601 .24646 L
.1961 .24631 L
.19621 .24616 L
.19629 .24607 L
.19639 .24598 L
.19649 .24591 L
.19654 .24589 L
.1966 .24587 L
.19669 .24586 L
Mistroke
.19679 .24587 L
.19689 .24591 L
.19699 .24598 L
.19708 .24607 L
.19717 .24618 L
.19734 .24644 L
.19752 .24681 L
.19774 .24738 L
.19797 .24814 L
.19839 .24992 L
.1988 .25217 L
.19918 .25468 L
.20069 .2689 L
.20155 .27979 L
.20235 .29161 L
.20547 .34757 L
.20706 .37707 L
.2079 .39127 L
.20879 .40454 L
.20958 .41421 L
.21 .4184 L
.21045 .42211 L
.21065 .42347 L
.21086 .4247 L
.21106 .42564 L
.21124 .42636 L
.21141 .42688 L
.21151 .42711 L
.2116 .42727 L
.21169 .42741 L
.2118 .4275 L
.21189 .42753 L
.21199 .42752 L
.21209 .42746 L
.21218 .42735 L
.21227 .42721 L
.21236 .42701 L
.21257 .42639 L
.21276 .4256 L
.21311 .42363 L
.21349 .42078 L
.21394 .41633 L
.21436 .41112 L
.21515 .39878 L
.21676 .36365 L
.21824 .32186 L
.22141 .22008 L
.22301 .17436 L
.22371 .15788 L
.22446 .14318 L
Mistroke
.22488 .13671 L
.22527 .13186 L
.22564 .1283 L
.22583 .12692 L
.22603 .12573 L
.22614 .12525 L
.22625 .12486 L
.22635 .1246 L
.22645 .12441 L
.22651 .12434 L
.22656 .12431 L
.22662 .1243 L
.22668 .12432 L
.22679 .12443 L
.22684 .12454 L
.2269 .12466 L
.227 .12495 L
.22709 .1253 L
.22729 .12636 L
.2275 .12776 L
.22771 .12967 L
.22813 .1346 L
.22853 .1406 L
.22941 .15913 L
.23019 .18089 L
.23103 .20906 L
.23437 .35646 L
.23605 .43394 L
.23679 .46458 L
.23759 .49426 L
.23832 .51671 L
.2391 .53523 L
.23953 .54276 L
.23993 .54782 L
.24012 .54963 L
.24022 .55042 L
.24032 .55112 L
.24041 .55163 L
.24052 .55207 L
.24061 .55237 L
.24069 .55255 L
.24079 .55264 L
.24085 .55265 L
.2409 .55261 L
.241 .55246 L
.24109 .55221 L
.24115 .55202 L
.2412 .55179 L
.2413 .55126 L
.24153 .54963 L
Mistroke
.24172 .54772 L
.2419 .54551 L
.24232 .53898 L
.24269 .53129 L
.24304 .52282 L
.24381 .49895 L
.24534 .43376 L
.247 .3434 L
.24856 .2514 L
.25028 .15548 L
.25106 .11783 L
.2519 .0836 L
.25229 .07046 L
.2527 .05859 L
.25307 .04954 L
.25343 .04273 L
.25362 .03975 L
.25383 .03711 L
.25402 .03524 L
.25419 .03398 L
.25429 .03347 L
.25438 .03311 L
.25448 .03286 L
.25454 .03279 L
.25459 .03276 L
.2547 .03282 L
.25475 .03292 L
.25481 .03306 L
.25491 .03343 L
.25501 .03397 L
.2552 .03539 L
.25541 .03751 L
.25579 .04294 L
.25615 .05015 L
.25649 .05842 L
.25727 .08356 L
.258 .11379 L
.25966 .20202 L
.26279 .39956 L
.26438 .48815 L
.26528 .5277 L
.26571 .54316 L
.26611 .55546 L
.2665 .56515 L
.26685 .57214 L
.26704 .5751 L
.26724 .57774 L
.26745 .57976 L
.26756 .58058 L
.26766 .58118 L
Mistroke
.26777 .58161 L
.26783 .58178 L
.26788 .58189 L
.26798 .58197 L
.26808 .58191 L
.26818 .5817 L
.26826 .58139 L
.26836 .58092 L
.26846 .58025 L
.26869 .57821 L
.26891 .57554 L
.26931 .56868 L
.26968 .56042 L
.27009 .54912 L
.27091 .51971 L
.27239 .44856 L
.27561 .25525 L
.27709 .17416 L
.27793 .13627 L
.27871 .10797 L
.27911 .09643 L
.27949 .08746 L
.2797 .08333 L
.27992 .07952 L
.28013 .0767 L
.28032 .07459 L
.28052 .07291 L
.28063 .07226 L
.28075 .07174 L
.28081 .07156 L
.28087 .07141 L
.28093 .07132 L
.28098 .07128 L
.28109 .07133 L
.28115 .07142 L
.2812 .07155 L
.2813 .07191 L
.2814 .07238 L
.28151 .07305 L
.28162 .07392 L
.28181 .07578 L
.28201 .07836 L
.28243 .08539 L
.28283 .09413 L
.28358 .11559 L
.28526 .18367 L
.28834 .34079 L
.28989 .41218 L
.29072 .44279 L
.29115 .45627 L
Mistroke
.29161 .46835 L
.29202 .47715 L
.29246 .48463 L
.29265 .4872 L
.29286 .48946 L
.29306 .49112 L
.29324 .49224 L
.29333 .49268 L
.29343 .49303 L
.29352 .49324 L
.29361 .49337 L
.29372 .49339 L
.29377 .49335 L
.29383 .49328 L
.29393 .49305 L
.29402 .49273 L
.29411 .49234 L
.29421 .49182 L
.29438 .49063 L
.29458 .48881 L
.29476 .48677 L
.29516 .48121 L
.29557 .47365 L
.29631 .45618 L
.29799 .40204 L
.30104 .28321 L
.30191 .25261 L
.30274 .22759 L
.30355 .20779 L
.3039 .20069 L
.30429 .19407 L
.30464 .18923 L
.30502 .1852 L
.30522 .18352 L
.30542 .18231 L
.30551 .18184 L
.30561 .18142 L
.30569 .18112 L
.30579 .18086 L
.30585 .18075 L
.3059 .18067 L
.306 .18058 L
.3061 .18058 L
.3062 .18066 L
.30625 .18074 L
.3063 .18085 L
.30641 .18111 L
.30652 .18152 L
.30663 .182 L
.30683 .1831 L
Mistroke
.30704 .18462 L
.30742 .18827 L
.30781 .19308 L
.30817 .19855 L
.309 .21404 L
.31069 .25483 L
.31379 .33657 L
.31463 .35449 L
.3154 .36828 L
.31621 .37925 L
.31664 .38354 L
.31686 .38534 L
.31709 .38693 L
.3173 .38803 L
.31741 .38852 L
.31752 .38897 L
.31763 .38931 L
.31773 .38956 L
.31782 .38976 L
.31792 .3899 L
.31797 .38995 L
.31802 .38999 L
.31808 .39002 L
.31814 .39002 L
.31824 .38999 L
.31829 .38995 L
.31834 .38989 L
.31845 .38973 L
.31857 .38947 L
.31869 .38912 L
.31881 .38873 L
.31922 .38675 L
.31959 .38423 L
.32042 .37626 L
.32122 .36618 L
.32196 .35522 L
.32363 .32738 L
.32525 .30067 L
.32605 .28926 L
.32678 .2803 L
.32748 .2733 L
.32824 .26758 L
.32864 .26544 L
.32901 .26396 L
.32921 .26336 L
.3294 .26295 L
.3295 .26278 L
.32961 .26263 L
.32972 .26253 L
.32981 .26248 L
Mistroke
.32991 .26245 L
.33001 .26246 L
.3301 .2625 L
.33019 .26257 L
.33029 .26267 L
.3304 .26283 L
.33059 .26319 L
.33077 .26364 L
.33094 .26415 L
.33132 .26562 L
.33212 .26997 L
.33298 .27627 L
.33628 .30716 L
.33707 .31417 L
.33792 .32075 L
.33866 .32546 L
.33945 .32941 L
.33988 .33099 L
.34028 .33212 L
.34065 .33289 L
.34084 .33317 L
.34095 .33329 L
.34105 .33339 L
.34114 .33346 L
.34124 .33351 L
.34133 .33354 L
.34141 .33356 L
.34151 .33356 L
.3416 .33355 L
.34171 .33352 L
.3418 .33346 L
.34189 .33341 L
.34198 .33333 L
.34214 .33315 L
.34232 .33291 L
.34251 .33259 L
.34293 .33167 L
.34333 .33056 L
.34407 .32792 L
.34575 .32018 L
.34722 .31272 L
.34883 .30531 L
.34959 .30247 L
.35042 .30004 L
.35087 .29901 L
.35129 .29825 L
.35168 .29771 L
.35188 .2975 L
.3521 .29732 L
.35231 .2972 L
Mistroke
.35242 .29715 L
.35253 .29712 L
.35262 .2971 L
.35272 .29709 L
.35277 .29708 L
.35283 .29708 L
.35293 .29709 L
.35302 .29711 L
.35313 .29714 L
.35323 .29718 L
.35332 .29722 L
.35349 .29732 L
.35368 .29746 L
.35413 .29791 L
.35456 .29849 L
.35536 .29988 L
.35846 .3072 L
.36003 .31065 L
.36092 .31218 L
.36135 .31278 L
.36175 .31326 L
.36214 .31364 L
.36256 .31396 L
.36274 .31408 L
.36294 .31418 L
.36312 .31425 L
.36329 .31431 L
.36338 .31433 L
.36348 .31436 L
.36358 .31437 L
.36364 .31438 L
.36369 .31438 L
.36379 .31439 L
.36387 .31439 L
.36397 .31439 L
.36407 .31438 L
.36417 .31437 L
.36422 .31436 L
.36428 .31435 L
.36448 .31431 L
.36471 .31424 L
.36493 .31415 L
.36533 .31394 L
.36577 .31365 L
.36656 .31298 L
.36805 .31142 L
.3696 .3097 L
.37043 .30887 L
.37132 .3081 L
.37217 .30751 L
Mistroke
.37254 .30731 L
.37294 .30712 L
.37333 .30698 L
.37369 .30688 L
.37388 .30684 L
.37406 .30681 L
.37416 .3068 L
.37427 .30679 L
.37438 .30678 L
.37447 .30677 L
.37457 .30677 L
.37466 .30676 L
.37476 .30676 L
.37486 .30676 L
.37495 .30677 L
.37505 .30677 L
.37514 .30678 L
.37523 .30679 L
.37543 .30681 L
.37566 .30684 L
.37606 .30693 L
.37649 .30704 L
.37694 .30719 L
.37775 .30751 L
.3808 .3089 L
.38161 .30921 L
.38237 .30946 L
.38279 .30958 L
.38325 .30968 L
.38366 .30976 L
.38405 .30981 L
.38441 .30985 L
.38462 .30987 L
.3848 .30988 L
.3849 .30989 L
.385 .30989 L
.38511 .3099 L
.38521 .3099 L
.38526 .3099 L
.38532 .3099 L
.38538 .3099 L
.38543 .3099 L
.38553 .3099 L
.38564 .3099 L
.38574 .3099 L
.38584 .30989 L
.38605 .30988 L
.38625 .30987 L
.38644 .30986 L
.38686 .30982 L
Mistroke
.38732 .30977 L
.38891 .30951 L
.39059 .30921 L
.3922 .30895 L
.3931 .30884 L
.39353 .30879 L
.39394 .30876 L
.39433 .30874 L
.39468 .30872 L
.39487 .30871 L
.39508 .3087 L
.39519 .3087 L
.3953 .3087 L
.3954 .3087 L
.3955 .30869 L
.39561 .30869 L
.3957 .30869 L
.3958 .30869 L
.39589 .30869 L
.39599 .30869 L
.39609 .30869 L
.39614 .30869 L
.39619 .30869 L
.39631 .30869 L
.39642 .3087 L
.39652 .3087 L
.39674 .3087 L
.39716 .30872 L
.39753 .30873 L
.39794 .30875 L
.39867 .30879 L
.40033 .3089 L
.40192 .309 L
.40275 .30905 L
.40365 .30909 L
.40403 .3091 L
.40443 .30911 L
.40467 .30911 L
.40488 .30912 L
.4051 .30912 L
.40531 .30912 L
.40549 .30913 L
.40566 .30913 L
.40576 .30913 L
.40585 .30913 L
.40595 .30913 L
.40605 .30913 L
.40615 .30913 L
.40625 .30913 L
.40631 .30913 L
Mistroke
.40636 .30913 L
.40646 .30913 L
.40657 .30913 L
.40666 .30913 L
.40684 .30913 L
.40705 .30913 L
.40725 .30912 L
.40761 .30912 L
.40844 .3091 L
.40991 .30907 L
.41139 .30904 L
.41223 .30902 L
.41301 .30901 L
.41378 .309 L
.41418 .30899 L
.41461 .30899 L
.41485 .30899 L
.41507 .30898 L
.41527 .30898 L
.4155 .30898 L
.4157 .30898 L
.41589 .30898 L
.41599 .30898 L
.41609 .30898 L
.41619 .30898 L
.41625 .30898 L
.4163 .30898 L
.41636 .30898 L
.41641 .30898 L
.41651 .30898 L
.41661 .30898 L
.41667 .30898 L
.41673 .30898 L
.41692 .30898 L
.41713 .30898 L
.41752 .30898 L
.41788 .30898 L
.41874 .30899 L
.41956 .309 L
.42102 .30901 L
.42186 .30901 L
.42264 .30902 L
.42346 .30902 L
.42422 .30903 L
.42462 .30903 L
.42503 .30903 L
.42525 .30903 L
.42545 .30903 L
.42567 .30903 L
.42579 .30903 L
Mistroke
.42591 .30903 L
.426 .30903 L
.42609 .30903 L
.42619 .30903 L
.4263 .30903 L
.42635 .30903 L
.42641 .30903 L
.42651 .30903 L
.42661 .30903 L
.42671 .30903 L
.42689 .30903 L
.42706 .30903 L
.42744 .30903 L
.42786 .30903 L
.4283 .30903 L
.42911 .30902 L
.43068 .30902 L
.43151 .30902 L
.4324 .30902 L
.43326 .30902 L
.43404 .30901 L
.43442 .30901 L
.43483 .30901 L
.43502 .30901 L
.43522 .30901 L
.43539 .30901 L
.43558 .30901 L
.43567 .30901 L
.43576 .30901 L
.43586 .30901 L
.43592 .30901 L
.43597 .30901 L
.43607 .30901 L
.43613 .30901 L
.43618 .30901 L
.43628 .30901 L
.43639 .30901 L
.43647 .30901 L
.43657 .30901 L
.43674 .30901 L
.43694 .30901 L
.43713 .30901 L
.43799 .30901 L
.4388 .30901 L
.44041 .30902 L
.44187 .30902 L
.44269 .30902 L
.44346 .30902 L
.44388 .30902 L
.44427 .30902 L
Mistroke
.44469 .30902 L
.44491 .30902 L
.44503 .30902 L
.44514 .30902 L
.44524 .30902 L
.44534 .30902 L
.44545 .30902 L
.44551 .30902 L
.44556 .30902 L
.44566 .30902 L
.44576 .30902 L
.44586 .30902 L
.44596 .30902 L
.44605 .30902 L
.44615 .30902 L
.44632 .30902 L
.44653 .30902 L
.44671 .30902 L
.44713 .30902 L
.44758 .30902 L
.44839 .30902 L
.44996 .30902 L
.45079 .30902 L
.45168 .30902 L
.45254 .30902 L
.45332 .30902 L
.45369 .30902 L
.45389 .30902 L
.4541 .30902 L
.45429 .30902 L
.45449 .30902 L
.45468 .30902 L
.45485 .30902 L
.45494 .30902 L
.45504 .30902 L
.45514 .30902 L
.45522 .30902 L
.45533 .30902 L
.45538 .30902 L
.45544 .30902 L
.45553 .30902 L
.45564 .30902 L
.45574 .30902 L
.45584 .30902 L
.45603 .30902 L
.45647 .30902 L
.45687 .30902 L
.45724 .30902 L
.45795 .30902 L
.45956 .30902 L
Mistroke
.46102 .30902 L
.46183 .30902 L
.4626 .30902 L
.46302 .30902 L
.46341 .30902 L
.46361 .30902 L
.46384 .30902 L
.46395 .30902 L
.46407 .30902 L
.46417 .30902 L
.46429 .30902 L
.46434 .30902 L
.46439 .30902 L
.46449 .30902 L
.46455 .30902 L
.46461 .30902 L
.46471 .30902 L
.46481 .30902 L
.4649 .30902 L
.465 .30902 L
.4651 .30902 L
.46534 .30902 L
.46557 .30902 L
.46599 .30902 L
.46677 .30902 L
.46761 .30902 L
.46917 .30902 L
.47 .30902 L
.47089 .30902 L
.47133 .30902 L
.47175 .30902 L
.47215 .30902 L
.47253 .30902 L
.47289 .30902 L
.47308 .30902 L
.47326 .30902 L
.47346 .30902 L
.47357 .30902 L
.47367 .30902 L
.47376 .30902 L
.47386 .30902 L
.47396 .30902 L
.47406 .30902 L
.47416 .30902 L
.47421 .30902 L
.47427 .30902 L
.47446 .30902 L
.47457 .30902 L
.47469 .30902 L
.4749 .30902 L
Mistroke
.4757 .30902 L
.47719 .30902 L
.47877 .30902 L
.47961 .30902 L
.48007 .30902 L
.4805 .30902 L
.48091 .30902 L
.48137 .30902 L
.48177 .30902 L
.48197 .30902 L
.48215 .30902 L
.48234 .30902 L
.48251 .30902 L
.4826 .30902 L
.4827 .30902 L
.48279 .30902 L
.4829 .30902 L
.48299 .30902 L
.4831 .30902 L
.48315 .30902 L
.4832 .30902 L
.48331 .30902 L
.4834 .30902 L
.4835 .30902 L
.48369 .30902 L
.48389 .30902 L
.48409 .30902 L
.48445 .30902 L
.48527 .30902 L
.48674 .30902 L
.48821 .30902 L
.48905 .30902 L
.48946 .30902 L
.48983 .30902 L
.4902 .30902 L
.4906 .30902 L
.49082 .30902 L
.49102 .30902 L
.49122 .30902 L
.49143 .30902 L
.49154 .30902 L
.49165 .30902 L
.49175 .30902 L
.4918 .30902 L
.49186 .30902 L
.49195 .30902 L
.49206 .30902 L
.49216 .30902 L
.49224 .30902 L
.4923 .30902 L
Mistroke
.49236 .30902 L
.49246 .30902 L
.49257 .30902 L
.49269 .30902 L
.49312 .30902 L
.49351 .30902 L
.49393 .30902 L
.49467 .30902 L
.49635 .30902 L
.49712 .30902 L
.49793 .30902 L
.49833 .30902 L
.49871 .30902 L
.49907 .30902 L
.49941 .30902 L
.49978 .30902 L
.49998 .30902 L
.50019 .30902 L
.5003 .30902 L
.50041 .30902 L
.50052 .30902 L
.50062 .30902 L
.50072 .30902 L
.50078 .30902 L
.50083 .30902 L
.50092 .30902 L
.50102 .30902 L
.50111 .30902 L
.5012 .30902 L
.50129 .30902 L
.5014 .30902 L
.5016 .30902 L
.50179 .30902 L
.50216 .30902 L
.5025 .30902 L
.50559 .30902 L
.50641 .30902 L
.50718 .30902 L
.50757 .30902 L
.50798 .30902 L
.50822 .30902 L
.50845 .30902 L
.50866 .30902 L
.50887 .30902 L
.50906 .30902 L
.50916 .30902 L
.50927 .30902 L
.50936 .30902 L
.50946 .30902 L
.50955 .30902 L
Mistroke
.50964 .30902 L
.50969 .30902 L
.50974 .30902 L
.50985 .30902 L
.50994 .30902 L
.51003 .30902 L
.51013 .30902 L
.51024 .30902 L
.51046 .30902 L
.51083 .30902 L
.51122 .30902 L
.51194 .30902 L
.51351 .30902 L
.51435 .30902 L
.51524 .30902 L
.51568 .30902 L
.5161 .30902 L
.51651 .30902 L
.51689 .30902 L
.51725 .30902 L
.51743 .30902 L
.51762 .30902 L
.51782 .30902 L
.51793 .30902 L
.51804 .30902 L
.51813 .30902 L
.51823 .30902 L
.51833 .30902 L
.51842 .30902 L
.51852 .30902 L
.51858 .30902 L
.51863 .30902 L
.51874 .30902 L
.51883 .30902 L
.51904 .30902 L
.51927 .30902 L
.51969 .30902 L
.52007 .30902 L
.52157 .30902 L
.52238 .30902 L
.52323 .30902 L
.52403 .30902 L
.52442 .30902 L
.52477 .30902 L
.52511 .30902 L
.52548 .30902 L
.52568 .30902 L
.52587 .30902 L
.52605 .30902 L
.52624 .30902 L
Mistroke
.52635 .30902 L
.52645 .30902 L
.52654 .30902 L
.52665 .30902 L
.52674 .30902 L
.52683 .30902 L
.52692 .30902 L
.52702 .30902 L
.52708 .30902 L
.52713 .30902 L
.52718 .30902 L
.52724 .30902 L
.52734 .30902 L
.52746 .30902 L
.52766 .30902 L
.52785 .30902 L
.52823 .30902 L
.52864 .30902 L
.52947 .30902 L
.53096 .30902 L
.53177 .30902 L
.53253 .30902 L
.53295 .30902 L
.53341 .30902 L
.53383 .30902 L
.53403 .30902 L
.53421 .30902 L
.53439 .30902 L
.53459 .30902 L
.53479 .30902 L
.5349 .30902 L
.53499 .30902 L
.53508 .30902 L
.53517 .30902 L
.53527 .30902 L
.53537 .30902 L
.53546 .30902 L
.53555 .30902 L
.53563 .30902 L
.53572 .30902 L
.53583 .30902 L
.53593 .30902 L
.53613 .30902 L
.53657 .30902 L
.53696 .30902 L
.53737 .30902 L
.53893 .30902 L
.53976 .30902 L
.54065 .30902 L
.54106 .30902 L
Mistroke
.5415 .30902 L
.5419 .30902 L
.54228 .30902 L
.54263 .30902 L
.54283 .30902 L
.54301 .30902 L
.54321 .30902 L
.54332 .30902 L
.54342 .30902 L
.54351 .30902 L
.54361 .30902 L
.54371 .30902 L
.54381 .30902 L
.54391 .30902 L
.54396 .30902 L
.54401 .30902 L
.54411 .30902 L
.54421 .30902 L
.54442 .30902 L
.54464 .30902 L
.54506 .30902 L
.54544 .30902 L
.54692 .30902 L
.54772 .30902 L
.54857 .30902 L
.54937 .30902 L
.5501 .30902 L
.55049 .30902 L
.55085 .30902 L
.55104 .30902 L
.55125 .30902 L
.55136 .30902 L
.55147 .30902 L
.55157 .30902 L
.55167 .30902 L
.55176 .30902 L
.55186 .30902 L
.55192 .30902 L
.55197 .30902 L
.55207 .30902 L
.55216 .30902 L
.55225 .30902 L
.55235 .30902 L
.55245 .30902 L
.55262 .30902 L
.55279 .30902 L
.55316 .30902 L
.554 .30902 L
.55479 .30902 L
.55628 .30902 L
Mistroke
.55706 .30902 L
.55748 .30902 L
.55788 .30902 L
.55825 .30902 L
.55858 .30902 L
.55896 .30902 L
.55915 .30902 L
.55936 .30902 L
.55956 .30902 L
.55967 .30902 L
.55976 .30902 L
.55984 .30902 L
.55993 .30902 L
.56003 .30902 L
.56012 .30902 L
.56018 .30902 L
.56023 .30902 L
.56033 .30902 L
.56043 .30902 L
.56049 .30902 L
.56055 .30902 L
.56065 .30902 L
.56074 .30902 L
.56094 .30902 L
.56131 .30902 L
.5617 .30902 L
.56242 .30902 L
.56399 .30902 L
.56482 .30902 L
.56528 .30902 L
.56571 .30902 L
.56612 .30902 L
.56657 .30902 L
.56698 .30902 L
.56717 .30902 L
.56736 .30902 L
.56754 .30902 L
.56771 .30902 L
.5679 .30902 L
.568 .30902 L
.5681 .30902 L
.56819 .30902 L
.56829 .30902 L
.56839 .30902 L
.56848 .30902 L
.56858 .30902 L
.56863 .30902 L
.56869 .30902 L
.56889 .30902 L
.56908 .30902 L
Mistroke
.56926 .30902 L
.56967 .30902 L
.5704 .30902 L
.57205 .30902 L
.5728 .30902 L
.57358 .30902 L
.574 .30902 L
.57445 .30902 L
.57486 .30902 L
.57506 .30902 L
.57525 .30902 L
.57545 .30902 L
.57563 .30902 L
.57583 .30902 L
.57594 .30902 L
.57604 .30902 L
.57614 .30902 L
.57619 .30902 L
.57625 .30902 L
.57634 .30902 L
.57644 .30902 L
.57649 .30902 L
.57655 .30902 L
.57665 .30902 L
.5767 .30902 L
.57675 .30902 L
.57687 .30902 L
.57706 .30902 L
.57725 .30902 L
.57759 .30902 L
.57835 .30902 L
.57983 .30902 L
.58067 .30902 L
.58145 .30902 L
.58222 .30902 L
.58266 .30902 L
.58305 .30902 L
.58327 .30902 L
.58347 .30902 L
.58369 .30902 L
.5838 .30902 L
.58392 .30902 L
.58397 .30902 L
.58403 .30902 L
.58413 .30902 L
.58423 .30902 L
.58429 .30902 L
.58435 .30902 L
.58445 .30902 L
.58454 .30902 L
Mistroke
.58464 .30902 L
.58474 .30902 L
.58494 .30902 L
.58512 .30902 L
.58552 .30902 L
.58635 .30902 L
.58783 .30902 L
.58867 .30902 L
.58946 .30902 L
.59018 .30902 L
.59058 .30902 L
.59095 .30902 L
.59116 .30902 L
.59136 .30902 L
.59158 .30902 L
.59168 .30902 L
.5918 .30902 L
.59191 .30902 L
.592 .30902 L
.59206 .30902 L
.59211 .30902 L
.59222 .30902 L
.59231 .30902 L
.59242 .30902 L
.59251 .30902 L
.5926 .30902 L
.5928 .30902 L
.59298 .30902 L
.59338 .30902 L
.5941 .30902 L
.59575 .30902 L
.59656 .30902 L
.59729 .30902 L
.59765 .30902 L
.59805 .30902 L
.59842 .30902 L
.59877 .30902 L
.59896 .30902 L
.59914 .30902 L
.59933 .30902 L
.59944 .30902 L
.59954 .30902 L
.59964 .30902 L
.59974 .30902 L
.59984 .30902 L
.5999 .30902 L
.59996 .30902 L
.60005 .30902 L
.60016 .30902 L
.60026 .30902 L
Mistroke
.60035 .30902 L
.60055 .30902 L
.60073 .30902 L
.60114 .30902 L
.60187 .30902 L
.60353 .30902 L
.60428 .30902 L
.60507 .30902 L
.60548 .30902 L
.60594 .30902 L
.60614 .30902 L
.60635 .30902 L
.60656 .30902 L
.60674 .30902 L
.60694 .30902 L
.60706 .30902 L
.60716 .30902 L
.60726 .30902 L
.60735 .30902 L
.60745 .30902 L
.60755 .30902 L
.60766 .30902 L
.60772 .30902 L
.60777 .30902 L
.60788 .30902 L
.60797 .30902 L
.60809 .30902 L
.6082 .30902 L
.60844 .30902 L
.60881 .30902 L
.60922 .30902 L
.61005 .30902 L
.61087 .30902 L
.61174 .30902 L
.61248 .30902 L
.6129 .30902 L
.61328 .30902 L
.61368 .30902 L
.61406 .30902 L
.61427 .30902 L
.61446 .30902 L
.61467 .30902 L
.61478 .30902 L
.61489 .30902 L
.61499 .30902 L
.61509 .30902 L
.61517 .30902 L
.61527 .30902 L
.61537 .30902 L
.61542 .30902 L
Mistroke
.61548 .30902 L
.61557 .30902 L
.61567 .30902 L
.61585 .30902 L
.61602 .30902 L
.61639 .30902 L
.61804 .30902 L
.61884 .30902 L
.61957 .30902 L
.61993 .30902 L
.62033 .30902 L
.62067 .30902 L
.62105 .30902 L
.62144 .30902 L
.62166 .30902 L
.62187 .30902 L
.62206 .30902 L
.62223 .30902 L
.62233 .30902 L
.62243 .30902 L
.62253 .30902 L
.62262 .30902 L
.62273 .30902 L
.62278 .30902 L
.62284 .30902 L
.62294 .30902 L
.62303 .30902 L
.62309 .30902 L
.62314 .30902 L
.62325 .30902 L
.62347 .30902 L
.62386 .30902 L
.62427 .30902 L
.62577 .30902 L
.62659 .30902 L
.62735 .30902 L
.62777 .30902 L
.62816 .30902 L
.62858 .30902 L
.62882 .30902 L
.62904 .30902 L
.62922 .30902 L
.62942 .30902 L
.62953 .30902 L
.62963 .30902 L
.62973 .30902 L
.62983 .30902 L
.62992 .30902 L
.63 .30902 L
.63009 .30902 L
Mistroke
.63018 .30902 L
.63028 .30902 L
.63038 .30902 L
.63047 .30902 L
.63056 .30902 L
.63067 .30902 L
.63078 .30902 L
.63098 .30902 L
.63137 .30902 L
.63222 .30902 L
.6338 .30902 L
.63469 .30902 L
.63512 .30902 L
.63552 .30902 L
.6359 .30902 L
.63611 .30902 L
.63632 .30902 L
.6365 .30902 L
.6367 .30902 L
.63688 .30902 L
.63705 .30902 L
.63715 .30902 L
.63727 .30902 L
.63737 .30902 L
.63746 .30902 L
.63752 .30902 L
.63757 .30902 L
.63767 .30902 L
.63773 .30902 L
.63778 .30902 L
.63784 .30902 L
.6379 .30902 L
.63799 .30902 L
.6381 .30902 L
.63828 .30902 L
.6385 .30902 L
.63869 .30902 L
.64035 .30902 L
.64108 .30902 L
.64189 .30902 L
.64226 .30902 L
.64266 .30902 L
.643 .30902 L
.64338 .30902 L
.64378 .30902 L
.644 .30902 L
.64421 .30902 L
.6444 .30902 L
.64457 .30902 L
.64467 .30902 L
Mistroke
.64478 .30902 L
.64487 .30902 L
.64497 .30902 L
.64507 .30902 L
.64516 .30902 L
.64525 .30902 L
.64534 .30902 L
.64544 .30902 L
.64555 .30902 L
.64574 .30902 L
.64613 .30902 L
.64647 .30902 L
.64813 .30902 L
.64888 .30902 L
.64967 .30902 L
.65009 .30902 L
.65055 .30902 L
.65075 .30902 L
.65096 .30902 L
.65135 .30902 L
.65155 .30902 L
.65167 .30902 L
.65177 .30902 L
.65187 .30902 L
.65196 .30902 L
.65206 .30902 L
.65211 .30902 L
.65216 .30902 L
.65222 .30902 L
.65227 .30902 L
.65233 .30902 L
.65238 .30902 L
.65248 .30902 L
.65254 .30902 L
.65259 .30902 L
.6527 .30902 L
.65281 .30902 L
.65305 .30902 L
.65346 .30902 L
.65389 .30902 L
.65467 .30902 L
.65544 .30902 L
.65626 .30902 L
.65668 .30902 L
.65715 .30902 L
.65758 .30902 L
.65798 .30902 L
.65837 .30902 L
.65857 .30902 L
.65879 .30902 L
Mistroke
.65897 .30902 L
.65907 .30902 L
.65917 .30902 L
.65925 .30902 L
.65935 .30902 L
.65944 .30902 L
.65952 .30902 L
.65962 .30902 L
.65972 .30902 L
.65982 .30902 L
.6599 .30902 L
.66001 .30902 L
.66012 .30902 L
.66033 .30902 L
.66077 .30902 L
.66118 .30902 L
.66269 .30902 L
.66348 .30902 L
.66432 .30902 L
.66475 .30902 L
.66497 .30902 L
.66521 .30902 L
.66544 .30902 L
.66564 .30902 L
.66583 .30902 L
.66604 .30902 L
.66614 .30902 L
.66625 .30902 L
.66635 .30902 L
.66644 .30902 L
.66649 .30902 L
.66654 .30902 L
.6666 .30902 L
.66666 .30902 L
.66671 .30902 L
.66677 .30902 L
.66687 .30902 L
.66697 .30902 L
.66703 .30902 L
.66708 .30902 L
.66728 .30902 L
.66746 .30902 L
.66766 .30902 L
.66925 .30902 L
.66994 .30902 L
.6707 .30902 L
.67111 .30902 L
.6715 .30902 L
.67189 .30902 L
.67226 .30902 L
Mistroke
.67246 .30902 L
.67269 .30902 L
.67287 .30902 L
.67307 .30902 L
.67329 .30902 L
.67341 .30902 L
.67347 .30902 L
.67352 .30902 L
.67363 .30902 L
.67372 .30902 L
.67383 .30902 L
.67388 .30902 L
.67394 .30902 L
.67403 .30902 L
.67413 .30902 L
.67422 .30902 L
.67431 .30902 L
.67452 .30902 L
.67471 .30902 L
.67544 .30902 L
.67629 .30902 L
.67709 .30902 L
.67788 .30902 L
.6783 .30902 L
.67874 .30902 L
.67911 .30902 L
.6793 .30902 L
.67952 .30902 L
.67971 .30902 L
.67989 .30902 L
.68006 .30902 L
.68023 .30902 L
.68041 .30902 L
.68051 .30902 L
.68062 .30902 L
.68072 .30902 L
.68077 .30902 L
.68083 .30902 L
.68093 .30902 L
.68103 .30902 L
.68112 .30902 L
.68121 .30902 L
.68129 .30902 L
.68138 .30902 L
.68176 .30902 L
.68218 .30902 L
.68263 .30902 L
.68343 .30902 L
.68418 .30902 L
.685 .30902 L
Mistroke
.68539 .30902 L
.68576 .30902 L
.68613 .30902 L
.68647 .30902 L
.68666 .30902 L
.68687 .30902 L
.68706 .30902 L
.68724 .30902 L
.68743 .30902 L
.68753 .30902 L
.68764 .30902 L
.68769 .30902 L
.68774 .30902 L
.68784 .30902 L
.68794 .30902 L
.688 .30902 L
.68806 .30902 L
.68814 .30902 L
.68823 .30902 L
.6884 .30902 L
.68859 .30902 L
.68877 .30902 L
.68953 .30902 L
.69033 .30902 L
.69118 .30902 L
.69199 .30902 L
.69272 .30902 L
.69311 .30902 L
.69347 .30902 L
.69366 .30902 L
.69387 .30902 L
.69409 .30902 L
.69418 .30902 L
.69429 .30902 L
.69439 .30902 L
.69448 .30902 L
.69457 .30902 L
.69466 .30902 L
.69476 .30902 L
.69484 .30902 L
.69492 .30902 L
.69501 .30902 L
.6951 .30902 L
.6952 .30902 L
.69541 .30902 L
.6956 .30902 L
.69578 .30902 L
.69728 .30902 L
.69807 .30902 L
.6989 .30902 L
Mistroke
.69933 .30902 L
.69979 .30902 L
.7 .30902 L
.70022 .30902 L
.70061 .30902 L
.70082 .30902 L
.70093 .30902 L
.70105 .30902 L
.70116 .30902 L
.70126 .30902 L
.70136 .30902 L
.70146 .30902 L
.70155 .30902 L
.70165 .30902 L
.70174 .30902 L
.70183 .30902 L
.70193 .30902 L
.70199 .30902 L
.70204 .30902 L
.70223 .30902 L
.70241 .30902 L
.70262 .30902 L
.70303 .30902 L
.70376 .30902 L
.70463 .30902 L
.70543 .30902 L
.70618 .30902 L
.70656 .30902 L
.70698 .30902 L
.7072 .30902 L
.7074 .30902 L
.70763 .30902 L
.70774 .30902 L
.70785 .30902 L
.70794 .30902 L
.70805 .30902 L
.70815 .30902 L
.70823 .30902 L
.70834 .30902 L
.7084 .30902 L
.70845 .30902 L
.70855 .30902 L
.70865 .30902 L
.70871 .30902 L
.70876 .30902 L
.70886 .30902 L
.70897 .30902 L
.70908 .30902 L
.70948 .30902 L
.71024 .30902 L
Mistroke
.71112 .30902 L
.71192 .30902 L
.71231 .30902 L
.71273 .30902 L
.71309 .30902 L
.71349 .30902 L
.71391 .30902 L
.71414 .30902 L
.71436 .30902 L
.71456 .30902 L
.71475 .30902 L
.71485 .30902 L
.71495 .30902 L
.71501 .30902 L
.71506 .30902 L
.71517 .30902 L
.71527 .30902 L
.71532 .30902 L
.71538 .30902 L
.71543 .30902 L
.71548 .30902 L
.71554 .30902 L
.7156 .30902 L
.71569 .30902 L
.71579 .30902 L
.71599 .30902 L
.71642 .30902 L
.71688 .30902 L
.71766 .30902 L
.7185 .30902 L
.7189 .30902 L
.71932 .30902 L
.7197 .30902 L
.72006 .30902 L
.7204 .30902 L
.72076 .30902 L
.72097 .30902 L
.72116 .30902 L
.72134 .30902 L
.72144 .30902 L
.72153 .30902 L
.72162 .30902 L
.72172 .30902 L
.72182 .30902 L
.72192 .30902 L
.72201 .30902 L
.72211 .30902 L
.7222 .30902 L
.72229 .30902 L
.72234 .30902 L
Mistroke
.72239 .30902 L
.72249 .30902 L
.72272 .30902 L
.72312 .30902 L
.72481 .30902 L
.72557 .30902 L
.72599 .30902 L
.72639 .30902 L
.72676 .30902 L
.72716 .30902 L
.72733 .30902 L
.72752 .30902 L
.72768 .30902 L
.72786 .30902 L
.72805 .30902 L
.72815 .30902 L
.72825 .30902 L
.72835 .30902 L
.72844 .30902 L
.72853 .30902 L
.72861 .30902 L
.72871 .30902 L
.72881 .30902 L
.7289 .30902 L
.729 .30902 L
.7291 .30902 L
.72922 .30902 L
.72942 .30902 L
.72982 .30902 L
.73019 .30902 L
.73089 .30902 L
.73166 .30902 L
.73248 .30902 L
.73288 .30902 L
.73326 .30902 L
.7336 .30902 L
.73396 .30902 L
.73415 .30902 L
.73436 .30902 L
.73455 .30902 L
.73472 .30902 L
.73483 .30902 L
.73493 .30902 L
.73504 .30902 L
.7351 .30902 L
.73516 .30902 L
.73526 .30902 L
.73531 .30902 L
.73537 .30902 L
.73547 .30902 L
Mistroke
.73556 .30902 L
.73562 .30902 L
.73567 .30902 L
.73577 .30902 L
.73598 .30902 L
.73617 .30902 L
.73637 .30902 L
.73726 .30902 L
.73801 .30902 L
.73882 .30902 L
.73929 .30902 L
.73971 .30902 L
.74014 .30902 L
.74033 .30902 L
.74055 .30902 L
.74073 .30902 L
.74093 .30902 L
.74114 .30902 L
.74123 .30902 L
.74133 .30902 L
.74142 .30902 L
.74152 .30902 L
.74162 .30902 L
.74171 .30902 L
.74181 .30902 L
.7419 .30902 L
.74198 .30902 L
.74206 .30902 L
.74216 .30902 L
.74226 .30902 L
.74237 .30902 L
.74248 .30902 L
.74271 .30902 L
.74292 .30902 L
.74371 .30902 L
.74451 .30902 L
.74537 .30902 L
.74578 .30902 L
.74617 .30902 L
.74652 .30902 L
.7469 .30902 L
.74728 .30902 L
.74748 .30902 L
.74767 .30902 L
.74785 .30902 L
.74801 .30902 L
.7481 .30902 L
.7482 .30902 L
.74829 .30902 L
.74838 .30902 L
Mistroke
.74847 .30902 L
.74857 .30902 L
.74866 .30902 L
.74874 .30902 L
.74884 .30902 L
.74894 .30902 L
.74915 .30902 L
.74958 .30902 L
.74997 .30902 L
.75148 .30902 L
.75189 .30902 L
.75232 .30902 L
.7527 .30902 L
.75311 .30902 L
.75333 .30902 L
.75353 .30902 L
.75373 .30902 L
.75392 .30902 L
.75414 .30902 L
.75427 .30902 L
.75438 .30902 L
.75449 .30902 L
.7546 .30902 L
.75466 .30902 L
.75471 .30902 L
.75477 .30902 L
.75482 .30902 L
.75492 .30902 L
.75502 .30902 L
.75511 .30902 L
.7552 .30902 L
.7553 .30902 L
.7554 .30902 L
.75561 .30902 L
.75601 .30902 L
.75644 .30902 L
.75725 .30902 L
.75803 .30902 L
.75872 .30902 L
.75912 .30902 L
.75948 .30902 L
.75987 .30902 L
.76007 .30902 L
.76028 .30902 L
.76049 .30902 L
.76067 .30902 L
.76085 .30902 L
.76094 .30902 L
.76103 .30902 L
.76109 .30902 L
Mistroke
.76115 .30902 L
.7612 .30902 L
.76125 .30902 L
.76136 .30902 L
.76145 .30902 L
.76151 .30902 L
.76156 .30902 L
.76167 .30902 L
.76173 .30902 L
.76179 .30902 L
.7619 .30902 L
.7621 .30902 L
.76229 .30902 L
.76271 .30902 L
.76421 .30902 L
.76463 .30902 L
.76506 .30902 L
.76544 .30902 L
.76584 .30902 L
.76627 .30902 L
.76666 .30902 L
.7669 .30902 L
.76702 .30902 L
.76713 .30902 L
.76733 .30902 L
.76744 .30902 L
.7675 .30902 L
.76756 .30902 L
.76761 .30902 L
.76767 .30902 L
.76777 .30902 L
.76782 .30902 L
.76788 .30902 L
.76794 .30902 L
.76799 .30902 L
.7681 .30902 L
.76815 .30902 L
.76821 .30902 L
.76841 .30902 L
.76858 .30902 L
.76878 .30902 L
.76917 .30902 L
.77 .30902 L
.77086 .30902 L
.7716 .30902 L
.77202 .30902 L
.77241 .30902 L
.7726 .30902 L
.77281 .30902 L
.773 .30902 L
Mistroke
.77319 .30902 L
.77337 .30902 L
.77357 .30902 L
.77365 .30902 L
.77374 .30902 L
.77382 .30902 L
.77391 .30902 L
.77396 .30902 L
.77402 .30902 L
.77412 .30902 L
.77417 .30902 L
.77423 .30902 L
.77429 .30902 L
.77434 .30902 L
.77444 .30902 L
.77454 .30902 L
.77465 .30902 L
.77475 .30902 L
.77512 .30902 L
.77551 .30902 L
.77711 .30902 L
.77755 .30902 L
.77801 .30902 L
.77841 .30902 L
.77884 .30902 L
.77906 .30902 L
.77926 .30902 L
.77944 .30902 L
.77964 .30902 L
.77975 .30902 L
.77985 .30902 L
.77996 .30902 L
.78005 .30902 L
.78016 .30902 L
.78022 .30902 L
.78028 .30902 L
.78039 .30902 L
.78044 .30902 L
.7805 .30902 L
.78059 .30902 L
.7807 .30902 L
.7808 .30902 L
.78089 .30902 L
.78106 .30902 L
.78125 .30902 L
.78163 .30902 L
.78205 .30902 L
.78287 .30902 L
.78373 .30902 L
.78447 .30902 L
Mistroke
.78489 .30902 L
.78528 .30902 L
.78547 .30902 L
.78568 .30902 L
.78588 .30902 L
.78606 .30902 L
.78623 .30902 L
.78633 .30902 L
.78641 .30902 L
.7865 .30902 L
.7866 .30902 L
.78669 .30902 L
.78678 .30902 L
.78688 .30902 L
.78697 .30902 L
.78708 .30902 L
.78718 .30902 L
.78736 .30902 L
.78755 .30902 L
.78838 .30902 L
.78914 .30902 L
.78996 .30902 L
.79042 .30902 L
.79085 .30902 L
.79128 .30902 L
.79147 .30902 L
.79168 .30902 L
.79187 .30902 L
.79206 .30902 L
.79228 .30902 L
.79237 .30902 L
.79247 .30902 L
.79257 .30902 L
.79267 .30902 L
.79276 .30902 L
.79285 .30902 L
.79295 .30902 L
.79304 .30902 L
.79312 .30902 L
.7932 .30902 L
.79331 .30902 L
.7934 .30902 L
.79351 .30902 L
.79362 .30902 L
.79406 .30902 L
.79486 .30902 L
.79567 .30902 L
.7961 .30902 L
.79656 .30902 L
.79696 .30902 L
Mistroke
.7974 .30902 L
.79759 .30902 L
.7978 .30902 L
.79817 .30902 L
.79837 .30902 L
.79857 .30902 L
.79867 .30902 L
.79877 .30902 L
.79885 .30902 L
.79894 .30902 L
.79904 .30902 L
.7991 .30902 L
.79915 .30902 L
.79924 .30902 L
.79935 .30902 L
.7994 .30902 L
.79946 .30902 L
.79952 .30902 L
.79957 .30902 L
.79978 .30902 L
.8 .30902 L
.80021 .30902 L
.8006 .30902 L
.80148 .30902 L
.80226 .30902 L
.80269 .30902 L
.80309 .30902 L
.80346 .30902 L
.8038 .30902 L
.80417 .30902 L
.80438 .30902 L
.80457 .30902 L
.80476 .30902 L
.80494 .30902 L
.80504 .30902 L
.80514 .30902 L
.80524 .30902 L
.80529 .30902 L
.80535 .30902 L
.8054 .30902 L
.80546 .30902 L
.80556 .30902 L
.80566 .30902 L
.80572 .30902 L
.80578 .30902 L
.80597 .30902 L
.80617 .30902 L
.80688 .30902 L
.80765 .30902 L
.80845 .30902 L
Mistroke
.80922 .30902 L
.80964 .30902 L
.80986 .30902 L
.81009 .30902 L
.81029 .30902 L
.81051 .30902 L
.81071 .30902 L
.81089 .30902 L
.81099 .30902 L
.81109 .30902 L
.81118 .30902 L
.81127 .30902 L
.81137 .30902 L
.81143 .30902 L
.81148 .30902 L
.81158 .30902 L
.81168 .30902 L
.81178 .30902 L
.81188 .30902 L
.81198 .30902 L
.81208 .30902 L
.81251 .30902 L
.81399 .30902 L
.81473 .30902 L
.81514 .30902 L
.81552 .30902 L
.81574 .30902 L
.81597 .30902 L
.81638 .30902 L
.81658 .30902 L
.8168 .30902 L
.81698 .30902 L
.81709 .30902 L
.81718 .30902 L
.81728 .30902 L
.81734 .30902 L
.81739 .30902 L
.81748 .30902 L
.81758 .30902 L
.81764 .30902 L
.81769 .30902 L
.81779 .30902 L
.81785 .30902 L
.8179 .30902 L
.81802 .30902 L
.81822 .30902 L
.81841 .30902 L
.81882 .30902 L
.82031 .30902 L
.82069 .30902 L
Mistroke
.82111 .30902 L
.82146 .30902 L
.82185 .30902 L
.82206 .30902 L
.82226 .30902 L
.82246 .30902 L
.82264 .30902 L
.82286 .30902 L
.82298 .30902 L
.82309 .30902 L
.82319 .30902 L
.8233 .30902 L
.82335 .30902 L
.82341 .30902 L
.82346 .30902 L
.82352 .30902 L
.82362 .30902 L
.82371 .30902 L
.82381 .30902 L
.82389 .30902 L
.82399 .30902 L
.82409 .30902 L
.8243 .30902 L
.82468 .30902 L
.82503 .30902 L
.82584 .30902 L
.82669 .30902 L
.82706 .30902 L
.82747 .30902 L
.8279 .30902 L
.8281 .30902 L
.82831 .30902 L
.82852 .30902 L
.82871 .30902 L
.8289 .30902 L
.82899 .30902 L
.82909 .30902 L
.82918 .30902 L
.82927 .30902 L
.82935 .30902 L
.82943 .30902 L
.82952 .30902 L
.82962 .30902 L
.82971 .30902 L
.8298 .30902 L
.82989 .30902 L
.82999 .30902 L
.83009 .30902 L
.83019 .30902 L
.83055 .30902 L
Mistroke
.83136 .30902 L
.83206 .30902 L
.83283 .30902 L
.83327 .30902 L
.83367 .30902 L
.83406 .30902 L
.83426 .30902 L
.83447 .30902 L
.83466 .30902 L
.83483 .30902 L
.83501 .30902 L
.83518 .30902 L
.83527 .30902 L
.83537 .30902 L
.83547 .30902 L
.83555 .30902 L
.83565 .30902 L
.83571 .30902 L
.83576 .30902 L
.83586 .30902 L
.83596 .30902 L
.83606 .30902 L
.83616 .30902 L
.83636 .30902 L
.83672 .30902 L
.83754 .30902 L
.8383 .30902 L
.83901 .30902 L
.83937 .30902 L
.83976 .30902 L
.83998 .30902 L
.8402 .30902 L
.84041 .30902 L
.8406 .30902 L
.8408 .30902 L
.8409 .30902 L
.84101 .30902 L
.84112 .30902 L
.84121 .30902 L
.84131 .30902 L
.8414 .30902 L
.84151 .30902 L
.84157 .30902 L
.84162 .30902 L
.84172 .30902 L
.84182 .30902 L
.84188 .30902 L
.84194 .30902 L
.84204 .30902 L
.84228 .30902 L
Mistroke
.84272 .30902 L
.84311 .30902 L
.84401 .30902 L
.8448 .30902 L
.84519 .30902 L
.84563 .30902 L
.84583 .30902 L
.84605 .30902 L
.84624 .30902 L
.84645 .30902 L
.84664 .30902 L
.84684 .30902 L
.84693 .30902 L
.84702 .30902 L
.84711 .30902 L
.8472 .30902 L
.84726 .30902 L
.84731 .30902 L
.84741 .30902 L
.84747 .30902 L
.84753 .30902 L
.84759 .30902 L
.84765 .30902 L
.84775 .30902 L
.8478 .30902 L
.84786 .30902 L
.84796 .30902 L
.84808 .30902 L
.8485 .30902 L
.84888 .30902 L
.84968 .30902 L
.85054 .30902 L
.85089 .30902 L
.85127 .30902 L
.85169 .30902 L
.85189 .30902 L
.85208 .30902 L
.85227 .30902 L
.85245 .30902 L
.85265 .30902 L
.85276 .30902 L
.85286 .30902 L
.85295 .30902 L
.85306 .30902 L
.85317 .30902 L
.85323 .30902 L
.85328 .30902 L
.85338 .30902 L
.85347 .30902 L
.85352 .30902 L
Mistroke
.85358 .30902 L
.85368 .30902 L
.85378 .30902 L
.85387 .30902 L
.85405 .30902 L
.85444 .30902 L
.85515 .30902 L
.85594 .30902 L
.85637 .30902 L
.85677 .30902 L
.85714 .30902 L
.85747 .30902 L
.85785 .30902 L
.85806 .30902 L
.85825 .30902 L
.85844 .30902 L
.85862 .30902 L
.85872 .30902 L
.85882 .30902 L
.85893 .30902 L
.85903 .30902 L
.85913 .30902 L
.85923 .30902 L
.85933 .30902 L
.85942 .30902 L
.85948 .30902 L
.85953 .30902 L
.85964 .30902 L
.85974 .30902 L
.85985 .30902 L
.86022 .30902 L
.86056 .30902 L
.86133 .30902 L
.86217 .30902 L
.86258 .30902 L
.86296 .30902 L
.86331 .30902 L
.86367 .30902 L
.86386 .30902 L
.86404 .30902 L
.86424 .30902 L
.86435 .30902 L
.86445 .30902 L
.86454 .30902 L
.86464 .30902 L
.86475 .30902 L
.86485 .30902 L
.86494 .30902 L
.86504 .30902 L
.86512 .30902 L
Mistroke
.86522 .30902 L
.86527 .30902 L
.86533 .30902 L
.86543 .30902 L
.86553 .30902 L
.86565 .30902 L
.86606 .30902 L
.86694 .30902 L
.86775 .30902 L
.86814 .30902 L
.86856 .30902 L
.86896 .30902 L
.86933 .30902 L
.86972 .30902 L
.86994 .30902 L
.87015 .30902 L
.87026 .30902 L
.87037 .30902 L
.87046 .30902 L
.87057 .30902 L
.87062 .30902 L
.87068 .30902 L
.87074 .30902 L
.8708 .30902 L
.8709 .30902 L
.87096 .30902 L
.87101 .30902 L
.87112 .30902 L
.87121 .30902 L
.8713 .30902 L
.87139 .30902 L
.8718 .30902 L
.87253 .30902 L
.87332 .30902 L
.87374 .30902 L
.87419 .30902 L
.87463 .30902 L
.87502 .30902 L
.87521 .30902 L
.87541 .30902 L
.87561 .30902 L
.87579 .30902 L
.8759 .30902 L
.87601 .30902 L
.87611 .30902 L
.87621 .30902 L
.87633 .30902 L
.87639 .30902 L
.87645 .30902 L
.87656 .30902 L
Mistroke
.87661 .30902 L
.87667 .30902 L
.87677 .30902 L
.87687 .30902 L
.87697 .30902 L
.87708 .30902 L
.87727 .30902 L
.87748 .30902 L
.87834 .30902 L
.87917 .30902 L
.87991 .30902 L
.88032 .30902 L
.88071 .30902 L
.88091 .30902 L
.88112 .30902 L
.8813 .30902 L
.8815 .30902 L
.88168 .30902 L
.88177 .30902 L
.88187 .30902 L
.88197 .30902 L
.88205 .30902 L
.88214 .30902 L
.88222 .30902 L
.88231 .30902 L
.88241 .30902 L
.88252 .30902 L
.88262 .30902 L
.88271 .30902 L
.88279 .30902 L
.88299 .30902 L
.88339 .30902 L
.88382 .30902 L
.88459 .30902 L
.88501 .30902 L
.88541 .30902 L
.88578 .30902 L
.88618 .30902 L
.88654 .30902 L
.88688 .30902 L
.88708 .30902 L
.88725 .30902 L
.88735 .30902 L
.88746 .30902 L
.88756 .30902 L
.88766 .30902 L
.88775 .30902 L
.88784 .30902 L
.88793 .30902 L
.88803 .30902 L
Mistroke
.88812 .30902 L
.88822 .30902 L
.8883 .30902 L
.88838 .30902 L
.8885 .30902 L
.8886 .30902 L
.8888 .30902 L
.88924 .30902 L
.89004 .30902 L
.89082 .30902 L
.89124 .30902 L
.89164 .30902 L
.89198 .30902 L
.89234 .30902 L
.89254 .30902 L
.89275 .30902 L
.89293 .30902 L
.89312 .30902 L
.89323 .30902 L
.89332 .30902 L
.89343 .30902 L
.89349 .30902 L
.89354 .30902 L
.89364 .30902 L
.8937 .30902 L
.89375 .30902 L
.89385 .30902 L
.89395 .30902 L
.89404 .30902 L
.89413 .30902 L
.8943 .30902 L
.8947 .30902 L
.89557 .30902 L
.89638 .30902 L
.89677 .30902 L
.89721 .30902 L
.89764 .30902 L
.89788 .30902 L
.8981 .30902 L
.89831 .30902 L
.89851 .30902 L
.89869 .30902 L
.89879 .30902 L
.89888 .30902 L
.89898 .30902 L
.89908 .30902 L
.89918 .30902 L
.89924 .30902 L
.89929 .30902 L
.8994 .30902 L
Mistroke
.89946 .30902 L
.89951 .30902 L
.89961 .30902 L
.89967 .30902 L
.89972 .30902 L
.89991 .30902 L
.90011 .30902 L
.90053 .30902 L
.90127 .30902 L
.90172 .30902 L
.90214 .30902 L
.90256 .30902 L
.90294 .30902 L
.9033 .30902 L
.90369 .30902 L
.90389 .30902 L
.90408 .30902 L
.90428 .30902 L
.9044 .30902 L
.9045 .30902 L
.9046 .30902 L
.90471 .30902 L
.90481 .30902 L
.90489 .30902 L
.905 .30902 L
.90506 .30902 L
.90511 .30902 L
.90522 .30902 L
.90527 .30902 L
.90532 .30902 L
.90554 .30902 L
.90577 .30902 L
.90618 .30902 L
.90695 .30902 L
.90777 .30902 L
.90824 .30902 L
.90866 .30902 L
.90887 .30902 L
.90909 .30902 L
.9093 .30902 L
.9095 .30902 L
.90968 .30902 L
.90988 .30902 L
.91 .30902 L
.9101 .30902 L
.9102 .30902 L
.91031 .30902 L
.91041 .30902 L
.91047 .30902 L
.91052 .30902 L
Mistroke
.91058 .30902 L
.91063 .30902 L
.91069 .30902 L
.91075 .30902 L
.91085 .30902 L
.91095 .30902 L
.91116 .30902 L
.91155 .30902 L
.9119 .30902 L
.91269 .30902 L
.91308 .30902 L
.91349 .30902 L
.91385 .30902 L
.91423 .30902 L
.91445 .30902 L
.91464 .30902 L
.91484 .30902 L
.91503 .30902 L
.91524 .30902 L
.91535 .30902 L
.91548 .30902 L
.91557 .30902 L
.91568 .30902 L
.91574 .30902 L
.91579 .30902 L
.91584 .30902 L
.9159 .30902 L
.916 .30902 L
.9161 .30902 L
.91619 .30902 L
.91628 .30902 L
.91637 .30902 L
.91648 .30902 L
.91669 .30902 L
.91706 .30902 L
.91742 .30902 L
.91827 .30902 L
.91869 .30902 L
.91908 .30902 L
.91949 .30902 L
.91986 .30902 L
.92027 .30902 L
.92049 .30902 L
.92071 .30902 L
.92089 .30902 L
.92099 .30902 L
.92108 .30902 L
.92116 .30902 L
.92124 .30902 L
.92133 .30902 L
Mistroke
.92142 .30902 L
.92152 .30902 L
.92161 .30902 L
.92171 .30902 L
.92176 .30902 L
.92182 .30902 L
.92191 .30902 L
.92201 .30902 L
.92219 .30902 L
.92377 .30902 L
.9242 .30902 L
.92466 .30902 L
.9251 .30902 L
.9255 .30902 L
.92569 .30902 L
.92591 .30902 L
.92608 .30902 L
.92628 .30902 L
.92649 .30902 L
.92661 .30902 L
.92672 .30902 L
.92682 .30902 L
.92688 .30902 L
.92693 .30902 L
.92703 .30902 L
.92713 .30902 L
.92724 .30902 L
.92733 .30902 L
.92744 .30902 L
.92755 .30902 L
.92794 .30902 L
.92868 .30902 L
.92944 .30902 L
.92986 .30902 L
.93026 .30902 L
.93063 .30902 L
.93082 .30902 L
.93103 .30902 L
.9312 .30902 L
.93139 .30902 L
.93157 .30902 L
.93173 .30902 L
.93193 .30902 L
.93204 .30902 L
.93215 .30902 L
.9322 .30902 L
.93226 .30902 L
.93236 .30902 L
.93245 .30902 L
.93254 .30902 L
Mistroke
.93263 .30902 L
.93272 .30902 L
.93281 .30902 L
.93291 .30902 L
.93311 .30902 L
.93329 .30902 L
.93416 .30902 L
.93496 .30902 L
.93571 .30902 L
.93608 .30902 L
.9363 .30902 L
.9365 .30902 L
.93669 .30902 L
.93691 .30902 L
.93713 .30902 L
.93725 .30902 L
.93736 .30902 L
.93745 .30902 L
.93756 .30902 L
.93761 .30902 L
.93767 .30902 L
.93777 .30902 L
.93786 .30902 L
.93796 .30902 L
.93807 .30902 L
.93816 .30902 L
.93826 .30902 L
.93837 .30902 L
.93856 .30902 L
.939 .30902 L
.93979 .30902 L
.94056 .30902 L
.9409 .30902 L
.94128 .30902 L
.94168 .30902 L
.9419 .30902 L
.9421 .30902 L
.94233 .30902 L
.94254 .30902 L
.94265 .30902 L
.94277 .30902 L
.94289 .30902 L
.943 .30902 L
.94309 .30902 L
.94319 .30902 L
.94329 .30902 L
.94337 .30902 L
.94347 .30902 L
.94357 .30902 L
.94363 .30902 L
Mistroke
.94368 .30902 L
.94378 .30902 L
.94401 .30902 L
.94422 .30902 L
.94462 .30902 L
.94533 .30902 L
.94609 .30902 L
.94653 .30902 L
.94693 .30902 L
.94712 .30902 L
.94733 .30902 L
.94752 .30902 L
.94771 .30902 L
.9479 .30902 L
.94801 .30902 L
.94811 .30902 L
.94821 .30902 L
.94832 .30902 L
.94842 .30902 L
.94848 .30902 L
.94854 .30902 L
.94864 .30902 L
.94873 .30902 L
.94882 .30902 L
.94891 .30902 L
.94901 .30902 L
.94906 .30902 L
.94912 .30902 L
.94931 .30902 L
.94953 .30902 L
.94973 .30902 L
.95018 .30902 L
.951 .30902 L
.95138 .30902 L
.95179 .30902 L
.95217 .30902 L
.95252 .30902 L
.95272 .30902 L
.95293 .30902 L
.95316 .30902 L
.95338 .30902 L
.95347 .30902 L
.95358 .30902 L
.95367 .30902 L
.95376 .30902 L
.95382 .30902 L
.95388 .30902 L
.95393 .30902 L
.95398 .30902 L
.95408 .30902 L
Mistroke
.95418 .30902 L
.95428 .30902 L
.95437 .30902 L
.95447 .30902 L
.95458 .30902 L
.9548 .30902 L
.95499 .30902 L
.95574 .30902 L
.95661 .30902 L
.95699 .30902 L
.95741 .30902 L
.9578 .30902 L
.95816 .30902 L
.95836 .30902 L
.95854 .30902 L
.95864 .30902 L
.95875 .30902 L
.95885 .30902 L
.95895 .30902 L
.95907 .30902 L
.95912 .30902 L
.95917 .30902 L
.95928 .30902 L
.95937 .30902 L
.95943 .30902 L
.95948 .30902 L
.95958 .30902 L
.95965 .30902 L
.95971 .30902 L
.95982 .30902 L
.95992 .30902 L
.96002 .30902 L
.9602 .30902 L
.96062 .30902 L
.96143 .30902 L
.96183 .30902 L
.96221 .30902 L
.96257 .30902 L
.9629 .30902 L
.96327 .30902 L
.96347 .30902 L
.96366 .30902 L
.96385 .30902 L
.96405 .30902 L
.96422 .30902 L
.96431 .30902 L
.9644 .30902 L
.96451 .30902 L
.96461 .30902 L
.9647 .30902 L
Mistroke
.96479 .30902 L
.9649 .30902 L
.96495 .30902 L
.96501 .30902 L
.96512 .30902 L
.96521 .30902 L
.96542 .30902 L
.96563 .30902 L
.96602 .30902 L
.96689 .30902 L
.96765 .30902 L
.96808 .30902 L
.96847 .30902 L
.96883 .30902 L
.96904 .30902 L
.96923 .30902 L
.96939 .30902 L
.96958 .30902 L
.96967 .30902 L
.96977 .30902 L
.96986 .30902 L
.96995 .30902 L
.97005 .30902 L
.97015 .30902 L
.97023 .30902 L
.97033 .30902 L
.97043 .30902 L
.97054 .30902 L
.97074 .30902 L
.97147 .30902 L
.97227 .30902 L
.97272 .30902 L
.97313 .30902 L
.97353 .30902 L
.97374 .30902 L
.97396 .30902 L
.97415 .30902 L
.97435 .30902 L
.97454 .30902 L
.97471 .30902 L
.9748 .30902 L
.97489 .30902 L
.97499 .30902 L
.97508 .30902 L
.97517 .30902 L
.97525 .30902 L
.97534 .30902 L
.97542 .30902 L
.97551 .30902 L
.97561 .30902 L
Mistroke
.9757 .30902 L
.97579 .30902 L
.97618 .30902 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{421.375, 260.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008>0001AB000`400?l00000o`00003ooooooooo
oooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo
003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooo
oooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool0
0?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooooooo
ool@ooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooo
ooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo0ol0003o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0
003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo
00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`0looooo`03o`000?oo
oooooooo0?ooooooWOooool0033ooooo00?o0000ooooooooool0>oooool2o`000?ooooooWoooool0
033ooooo00?o0000ooooooooool0>oooool2o`000?ooooooWoooool0033ooooo0ol0000kooooo`;o
0000oooooonOooooo`00<?ooool00ol0003oooooooooo`0kooooo`;o0000oooooonOooooo`00<?oo
ool00ol0003oooooooooo`0kooooo`;o0000oooooonOooooo`00<?ooool00ol0003oooooooooo`0k
ooooo`;o0000oooooonOooooo`00<?ooool00ol0003oooooooooo`0kooooo`;o0000oooooonOoooo
o`00<?ooool00ol0003oooooooooo`0kooooo`;o0000oooooonOooooo`00<?ooool00ol0003ooooo
ooooo`0kooooo`;o0000oooooonOooooo`00<?ooool00ol0003oooooooooo`0kooooo`;o0000oooo
oonOooooo`00<?ooool00ol0003oooooooooo`0kooooo`;o0000oooooonOooooo`00<?ooool00ol0
003oooooooooo`0kooooo`;o0000oooooonOooooo`00<?ooool00ol0003oooooooooo`0kooooo`;o
0000oooooonOooooo`00<?ooool3o`0003_ooooo0_l0003ooooooioooooo000`ooooo`03o`000?oo
oooooooo03_ooooo0_l0003ooooooioooooo000`ooooo`03o`000?oooooooooo03_ooooo0_l0003o
oooooioooooo000`ooooo`03o`000?oooooooooo03_ooooo0_l0000:ooooo`03o`000?oooooooooo
0?ooooooT_ooool0033ooooo00?o0000ooooooooool0>oooool00ol0003oooooo`000009ooooo`03
o`000?oooooooooo0?ooooooT_ooool0033ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
o`000009ooooo`03o`000?oooooooooo0?ooooooT_ooool0033ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooo`000009ooooo`;o0000oooooonCooooo`004?ooool2onk^kP?ooooo0_o^k^hI
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooool000002Oooool2o`000?ooooooToooool0
00_ooooo0_l000002_l@413oooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h3ooooo`Co
000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP[ooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooo`000009ooooo`;o0000oooooonCooooo`003?ooool00ol0003oooooooooo`02
ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooo000000Wooooo
0_l0003ooooooi?ooooo00000ooooooo0000o`000004o`0000;ooooo1Ol00004ooooo`03omgMgOl0
003ogMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00[ooooo
00?o0000ooooooooool0>oooool00ol0003oooooo`000008ooooo`03o`000?oooooo00000?oooooo
Toooool000Wooooo00CoA4A4omgMgOoooooo00001?ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Ko
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000[ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooo`000008ooooo`03o`000?oooooo00000?ooooooToooool000Wo
oooo00CogMgMoeEEEOoooooo00000oooool01oo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Ooo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000002_ooool4o`0003[ooooo
00?o0000ooooool000002?ooool00ol0003oooooo`00003ooooooi?ooooo000:ooooo`03ogMgMoo<
c<co000000?ooooo0_o^k^h3ooooo`;ok^k^1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oo
ooooooooooooool@41002_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooo000000Sooooo
00?o0000ooooool00000oooooonCooooo`002_ooool00oo^k^koA4A4o`00000?ooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`;o00001Oooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooo000000Sooooo00?o0000ooooool00000oooooonCooooo`002ooo
ool00omgMgOo0000ooooo`0<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP02ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0>oooool00ol0003o
ooooo`000008ooooo`03o`000?oooooo00000?ooooooToooool002Sooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`0jooooo`04o`000?ooooooooooo`0000Sooooo00?o0000oooo
ool00000oooooonCooooo`00:?ooool3o`0000Gooooo00?o0000ooooooooool0>_ooool01?l0003o
ooooooooool00008ooooo`03o`000?oooooo00000?ooooooToooool002Wooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0jooooo`04o`000?ooooooooooo`0000Sooooo00?o0000oooo
ool00000oooooonCooooo`00:_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03[o
oooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003ooooooi?ooooo000`ooooo`03
o`000?oooooooooo03[ooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003ooooo
oi?ooooo000`ooooo`03o`000?oooooooooo03[ooooo00Co0000oooooooooooo00002?ooool00ol0
003oooooo`00003ooooooi?ooooo000`ooooo`03o`000?oooooooooo03[ooooo00Co0000oooooooo
oooo00002?ooool00ol0003oooooo`00003ooooooi?ooooo000`ooooo`03o`000?oooooooooo03[o
oooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003ooooooi?ooooo000`ooooo`?o
0000>_ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?ooooooToooool0033o
oooo00?o0000ooooooooool0>_ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo0000
0?ooooooToooool0033ooooo00?o0000ooooooooool0;oooool2o`0000Wooooo00Co0000oooooooo
oooo00002?ooool00ol0003oooooo`00003ooooooi?ooooo000`ooooo`03o`000?oooooooooo02oo
oooo0_l00009ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooonCoooo
o`00<?ooool00ol0003oooooooooo`0_ooooo`;o00002Oooool01?l0003oooooooooool00008oooo
o`03o`000?oooooo00000?ooooooToooool0033ooooo00?o0000ooooooooool0;oooool2o`0000Wo
oooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003ooooooi?ooooo000`ooooo`03
o`000?oooooooooo02oooooo0_l00009ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000oooo
ool00000oooooonCooooo`00<?ooool00ol0003oooooooooo`0_ooooo`;o00002Oooool01?l0003o
ooooooooool00008ooooo`03o`000?oooooo00000?ooooooToooool0033ooooo00?o0000oooooooo
ool0;oooool2o`0000Wooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003ooooo
oi?ooooo000`ooooo`03o`000?oooooooooo02oooooo0_l00009ooooo`04o`000?ooooooooooo`00
00Sooooo00?o0000ooooool00000oooooonCooooo`00<?ooool00ol0003oooooooooo`0_ooooo`;o
00002Oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?ooooooToooool0033o
oooo00?o0000ooooooooool0;oooool2o`0000Wooooo00Co0000oooooooooooo00002?ooool00ol0
003oooooo`00003ooooooi?ooooo000`ooooo`?o0000;oooool2o`0000Wooooo00Co0000oooooooo
oooo00002?ooool00ol0003oooooo`00003ooooooi?ooooo000`ooooo`03o`000?oooooooooo02oo
oooo0_l00009ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooonCoooo
o`00<?ooool00ol0003oooooooooo`0^ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooo
oooooooo00002?ooool01?l0003oooooooooool0003ooooooi;ooooo000`ooooo`03o`000?oooooo
oooo02kooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00008ooooo`04o`00
0?ooooooooooo`000?ooooooT_ooool0033ooooo00?o0000ooooooooool0;_ooool01?l0003ooooo
ooooool00008ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00003o
oooooi;ooooo000`ooooo`03o`000?oooooooooo02kooooo00Co0000oooooooooooo00002?ooool0
1?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool00000oooooonBooooo`00<?oo
ool00ol0003oooooooooo`0^ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooooooo
ooooo`000006ooooo`05o`000?ooooooooooooooool00000oooooonBooooo`00<?ooool00ol0003o
ooooooooo`0^ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000006
ooooo`05o`000?ooooooooooooooool00000oooooonBooooo`00<?ooool00ol0003oooooooooo`0^
ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000006ooooo`05o`00
0?ooooooooooooooool00000oooooonBooooo`00<?ooool00ol0003oooooooooo`0^ooooo`04o`00
0?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?oooooooooo
ooooool00000oooooonBooooo`00<?ooool00ol0003oooooooooo`0^ooooo`04o`000?oooooooooo
o`0000Sooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool00000
oooooonBooooo`00<?ooool3o`0002kooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooo
oooooooooooo000000Kooooo00Go0000ooooooooooooooooo`00003ooooooi;ooooo000`ooooo`03
o`000?oooooooooo02kooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo
000000Kooooo00Go0000ooooooooooooooooo`00003ooooooi;ooooo000`ooooo`03o`000?oooooo
oooo02kooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Kooooo
00Go0000ooooooooooooooooo`00003ooooooi;ooooo000`ooooo`03o`000?oooooooooo02kooooo
00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000oooo
ooooooooooooo`000008ooooo`03o`000?oooooooooo0?ooooooQoooool0033ooooo00?o0000oooo
ooooool0;_ooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool000001_oo
ool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0oooooon7ooooo`00<?oo
ool00ol0003oooooooooo`0^ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooooooo
ooooo`000006ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`3ooooo
ohOooooo000`ooooo`03o`000?oooooooooo02kooooo00Co0000oooooooooooo00002?ooool01Ol0
003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oo
oooooooo0?ooooooQoooool0013ooooo0_o^k^h3ooooo`;ok^k^6Oooool00ol0003oooooooooo`0^
ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000006ooooo`05o`00
0?ooooooooooooooool000001oooool00ol0003oooooo`00003oooooohSooooo0009ooooo`Go0000
0_ooool01oo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^h:ooooo`03o`000?oooooooooo02kooooo00Co0000oooooooooooo
00002?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000007
ooooo`03o`000?oooooo00000?ooooooR?ooool000Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A003
ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02_ooool00ol0003oooooooooo`0^ooooo`04o`000?ooooooooooo`0000So
oooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001oooool0
0ol0003oooooo`00003oooooohSooooo00000ooooooo0000o`000004o`0000?ooooo00?oV9RHob4Q
8Oo^k^h01Oooool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooo
oooooooooooooa0@400:ooooo`03o`000?oooooooooo02kooooo00Co0000oooooooooooo00002?oo
ool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000007ooooo`03
o`000?oooooo00000?ooooooR?ooool000_ooooo00?oV9RHob4Q8Oo^k^h00oooool01Oo^k^koEEEE
omgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
00[ooooo00?o0000ooooooooool0;_ooool01?l0003oooooooooool00008ooooo`05o`000?oooooo
ooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooool00000
oooooon8ooooo`003?ooool02omgMgOoIVIVooooooooooook^k^oeEEEOo^k^koooooonk^k_mEEEGo
k^k^00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000[ooooo1?l0
000/ooooo`05o`000?ooooooooooooooool000002?ooool01Ol0003ooooooooooooooooo000000Ko
oooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?ooooooR?ooool000go
oooo00?o0000ooooooooool00_o^k^h3ooooo`;ok^k^1Oooool00ol0003oooooooooo`02ooooo`05
oa0@4?ooooooooooooooool@41002_ooool00ol0003oooooooooo`0]ooooo`05o`000?oooooooooo
ooooool000002?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000oooooooooooooooo
o`000007ooooo`03o`000?oooooo00000?ooooooR?ooool000Wooooo00Go0000okZj^_ooooooV9RH
oa0@400>ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`;o
00001Oooool00ol0003oooooooooo`0]ooooo`05o`000?ooooooooooooooool000001oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000007
ooooo`03o`000?oooooo00000?ooooooR?ooool000Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00<
ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool0;Oooool01Ol0003ooooooooooooooooo000000Oo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooooooo
ool000001oooool00ol0003oooooo`00003oooooohSooooo000Xooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooooooool0;Oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001ooo
ool00ol0003oooooo`00003oooooohSooooo000Xooooo`?o00001Oooool00ol0003oooooooooo`0]
ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?oooooo
R?ooool002Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0]ooooo`05o`000?oo
ooooooooooooool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo
00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?ooooooR?ooool002[ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0]ooooo`05o`000?ooooooooooooooool0
00001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooo
ooooooooo`000007ooooo`03o`000?oooooo00000?ooooooR?ooool0033ooooo00?o0000oooooooo
ool0;Oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003o
ooooohSooooo000`ooooo`03o`000?oooooooooo02gooooo00Go0000ooooooooooooooooo`000007
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooo
oooo000000Oooooo00?o0000ooooool00000oooooon8ooooo`00<?ooool00ol0003oooooooooo`0]
ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?oooooo
R?ooool0033ooooo00?o0000ooooooooool0;Oooool01Ol0003ooooooooooooooooo000000Oooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool0
00001oooool00ol0003oooooo`00003oooooohSooooo000`ooooo`?o0000;Oooool01Ol0003ooooo
oooooooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05
o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003oooooohSooooo000`ooooo`03
o`000?oooooooooo02gooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000
ooooool00000oooooon8ooooo`00<?ooool00ol0003oooooooooo`0]ooooo`05o`000?oooooooooo
ooooool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000
ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?ooooooR?ooool0033ooooo00?o0000
ooooooooool0;Oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001oooool00ol0003ooooo
o`00003oooooohSooooo000`ooooo`03o`000?oooooooooo02gooooo00Go0000oooooooooooooooo
o`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooo
oooooooooooo000000Oooooo00Co0000oooooooooooo0000oooooon7ooooo`00<?ooool00ol0003o
ooooooooo`0]ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?oooooo
ooooo`000?ooooooQoooool0033ooooo00?o0000ooooooooool0;Oooool01Ol0003ooooooooooooo
oooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oo
ooooooooooooool000001_ooool01Ol0003ooooooooooooooooo00000?ooooooQoooool0033ooooo
00?o0000ooooooooool0;Oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0
003ooooooooooooooooo00000?ooooooQoooool0033ooooo00?o0000ooooooooool08_ooool2o`00
00Wooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000oooooooooooooooo
o`00003oooooohOooooo000`ooooo`03o`000?oooooooooo02;ooooo0_l00009ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool0
0000oooooon7ooooo`00<?ooool00ol0003oooooooooo`0Rooooo`;o00002Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo0000
0?ooooooQoooool0033ooooo00?o0000ooooooooool08_ooool2o`0000Wooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`00003o
ooooohOooooo000`ooooo`?o00008Oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool00000
oooooon7ooooo`00<?ooool00ol0003oooooooooo`0Qooooo`04o`000?ooooooooooo`0000Sooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000oooooooo
ooooooooo`00003oooooohOooooo000`ooooo`03o`000?oooooooooo027ooooo00Co0000oooooooo
oooo00002?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool0
1Ol0003ooooooooooooooooo00000?ooooooQoooool0033ooooo00?o0000ooooooooool08Oooool0
1?l0003oooooooooool00008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooooooo
o`000006ooooo`05o`000?ooooooooooooooool000001oooool2o`000?ooooooO_ooool0033ooooo
00?o0000ooooooooool08Oooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooooooooooo
ool000001oooool2o`000?ooooooO_ooool0033ooooo00?o0000ooooooooool08Oooool01?l0003o
ooooooooool00008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooooooool2onk^kP05o`000?ooooooooooonk^k_l000001oooool2o`0004kooooo0_o^
k^h3ooooo`;ok^k^H?ooool2onk^kP?ooooo0_o^k^i>ooooo`;ok^k^0oooool2onk^kVcooooo000`
ooooo`03o`000?oooooooooo023ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00Co0000ooooooooooooA4A40_l000002_lb<S;ogMgMooooooo^k^koEEEEo`00
0?ooooook^k^oeEEEOl00003ooooo`Ko000000Koooooonk^k_lb<S;o0000oc8b<_o^k^i2ooooo`Co
000000Wo410@ooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?oo
ooooooooonk^k_lb<S;o0000oc8b<_o^k^hkooooo`Co000000?o410@ooooooooool00_ooool2ob4Q
8@Gooooo00goA4A4o`000?l0003o<S8bomgMgOooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^
00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^>?ooool5o`0000;ooooo
00Ook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413oooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^GOooool0033ooooo00?o0000ooooooooool08?ooool01Ol0003ooooooooo
oooooooo000000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`00
0?mgMgOo<S8b00;ooooo00Kok^k^o`000?oMgMgoEEEEonk^k_l00005ooooo`;o000000Soooooo`00
0?ooooooMgMgoiRHV?ooooooV9RHogMgMdCooooo00?o0000ooooooooool00_ooool01Oo^k^koEEEE
omgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
03gooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00WoMgMgoc8b<_ooooooooooonk^k_mE
EEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL0>?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06
ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Mooooo`00<?ooool0
0ol0003oooooooooo`0Pooooo`05o`000?ooooooooooooooool000001oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000000oooool2o`000003omgMgOoo
oooo000000Gooooo0_l00002ooooo`03o`000?l@413ooooo00;ooooo00?o410@ooooooooool0@_oo
ool00ol0003oooooooooo`03ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@03gooooo00?o0000ooooooooool03oooool01ol0003ooooo
oooooooooooogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@4100>Oooool00onHV9So8B4Qonk^kP05ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@05gooooo000`ooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oMgMgoc8b<P02ooooo`06onk^k_l0003o
gMgMoeEEEOo^k^ko00001Oooool2o`0000;ooooo0_l00003ooooo`03o`000?oooooooooo04;ooooo
00?o0000ooooooooool00_ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000oooooooo
ool00_ooool01Ol0003ooooooooooooooooo000003gooooo00?o0000ooooooooool03_ooool02Omg
MgOo<S8booooooooooook^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo
00Go0000ooooooooooooooooo`00000jooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Gok^k^oeEEEOoM
gMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001M
ooooo`00<?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`04ooooo`0@o`000?ooooooooooo`000?lQ8B7o0000oc8b
<_o<c<coooooonk^k_mEEEGo0000ooooooo^k^koEEEEo`0000Gooooo0_l00002ooooo`;o00000ooo
ool00ol0003oooooooooo`12ooooo`0;o`000?ooooooooooooooooo^k^koEEEEonk^k_ooooook^k^
oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000?Ooo
ool00ol0003oooooooooo`0;ooooo`0=o`000?lQ8B7o0000oc8b<_o<c<coooooonk^k_mEEEGok^k^
ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000kooooo`0;ogMgMomVIVKoooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Ooo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000GOooool0033ooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool01_l0003oooooooooool0003oooooo`0000?ooooo0_o^k^h01Ol0003o
ooooooooooo^k^ko000000Gooooo0_l00002ooooo`03o`000?l@413ooooo00;ooooo00?o410@oooo
ooooool0@_ooool01?l0003oooooooooooooool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooo
oooo00;ooooo00Go410@oooooooooooooooooa0@400mooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool00oooool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go
410@oooooooooooooooooa0@400looooo`03o`000?oooooooooo00;ok^k^0oooool2onk^kPGooooo
00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@05gooooo000`ooooo`?o0000
8?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool01_l0003oooooooooool0003oooooo`0000Gooooo00Go0000ooooooooooooooooo`000005
ooooo`;o00000_ooool01_l0003oMgMgoiRHV?ooooooV9RHogMgM`Sooooo00?o0000ooooooooool0
>Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`08ooooo`;o0000<oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo0_l0000^oooo
o`05o`000?nj^[[ooooooiRHV?l@41003_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02?ooool2o`0005?ooooo000`ooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01?l00004ooooo`05o`000?ooooooooooooooool000000oooool01?mEEEGoIVIVo`00
0?l00002ooooo`06o`000?o^k^ko<S8bo`000?lb<S;ok^k^2?ooool00ol0003oooooooooo`0goooo
o`03oeEEEOmVIVKo000000gooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Oooooo00Co0000oooooooooooo0000<?ooool00omEEEGoIVIVo`00000=ooooo`Co00003?oo
ool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01oooool01?l0003ooooo
ooooool0000]ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?ooool00omEEEGoIVIVo`000004oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01oooool01?l0003oooooooooool0001Booooo`00<?ooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool0
1Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo00001oooool4o`0000?ooooo
00?o0000ooooooooool0E?ooool4o`000005ooooool0003oooooooooool00000G_ooool4o`000005
ooooool0003oooooooooool00000C?ooool4o`000005ooooool0003oooooooooool00000D_ooool0
033ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00?ooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000kooooo00?o
0000ooooooooool0FOooool3o`0006Cooooo0ol0001Booooo`?o0000Doooool0033ooooo00?o0000
ooooooooool08?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000
ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000cooooo00Co0000oooooooooooo
0000Foooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo05;ooooo00?o0000oooooooo
ool0D_ooool0033ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?oooooooooooooo
ool000002oooool4o`0005cooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`1Boooo
o`03o`000?oooooooooo057ooooo000`ooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo0_l0003oooooogCo
oooo000`ooooo`03o`000?oooooooooo01Cooooo0_l00009ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`?o0000ooooooljooooo`03ogMg
MomVIVKooooo02gooooo00?oIVIVogMgMoooool01oooool0033ooooo00?o0000ooooooooool04ooo
ool4o`0000Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooool00000ooooooliooooo`03omgMgOl@413ok^k^02kooooo00?o
k^k^oa0@4?oMgMd01oooool0033ooooo00?o0000ooooooooool04_ooool01Ol0003ooooooooooooo
oooo000000Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00Co0000oooooooooooo0000oooooolVooooo`;o00000_ooool2o`0000cooooo
00?oEEEEoiRHV?ooool00_l00002ooooo`07o`000?ooooooooooo`000?l@413ok^k^oeEEE@02o`00
0003odA4A?nj^[[ooooo00;ooooo00GoV9RHo`000?l0003oA4A4okZj^P02ooooo`08onk^k_mEEEGo
0000o`000?m4A4Co^[Zjooooool@4105o`0000?ooooo00So410@oc8b<_l0003o0000oa0@4?nYZJWo
QhN7ofIVIPOooooo000`ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Kooooo0ol0003ooooooagooooo00Ko
k^k^ob4Q8On7QhOo^[Zjo`000?oMgMd<ooooo`05o`000?ooooooooooooooool000000_ooool02ol0
003oooooooooool0003ooooooeEEEOmgMgOoooooonk^k_mgMgOo410@00?ooooo00Go410@okZj^_o^
k^koMgMgoa0@4002ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo410@0oooool00ol0003ooooooooo
o`04ooooo`08o`000?nYZJWooooooooooonj^[[o0000onk^k_l00007ooooo`00ool0002do`0000oo
oooo00CogMgMo`000?l@413oc<c<3Oooool01Olb<S;ooooooooooooooooo000000;ooooo00Ko0000
oooooooooooo0000ooooool00008ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`05ooooo`07okZj^_n7QhOoIVIVofIVI_l@413oooooo`000007oooo
o`002_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool02_ooool7o`0000Kooooo00?o0000ooooooooool01Oooool01ol0003ooooooooooooooooo0000
ooooool000001_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`07o`000?ooooooooooooooool0003o
ooooo`000005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool2o`0000?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooooooo
o`;o00001?ooool4o`0000[ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Goooo
o`04onk^k_lQ8B7o410@onk^kPgooooo00Go<S8booooooooooooooooo`000002ooooo`05o`000?oo
ooooooooo`000?ooool01_l00003ooooo`03o`000?oooooooooo00Cooooo1_l00003ooooo`03o`00
0?oooooooooo00Cooooo00So<S8bob4Q8OmgMgOoMgMgohN7Qoo^k^koooooo`0000Oooooo000:oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooo000000Kooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00002
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool01ol0003ooooooooooooo
oooo0000ooooool000001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo
0_l00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool3o`000003oooo
ool0003ooooo017ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Gooooo`04ob4Q
8OmgMgOoMgMgoc8b<Pgooooo00Go0000onk^k_ooooooooooo`000002olc<c00;o`000?nYZJWogMgM
ob4Q8OooooooEEEEohN7Qoo^k^koooooohN7Qolb<S800oooool00ol0003oooooooooo`04ooooo`06
oeEEEOn7QhOok^k^oooooon7QhOo<S8b0oooool00ol0003o<S8bomgMg@04ooooo`08o`000?nj^[[o
ooooonk^k_mgMgOo0000onk^k_l00007ooooo`00<?ooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool2o`0000?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`;o0000C?ooool00ol0003oooooooooo`1Kooooo`03o`00
0?oooooooooo05_ooooo00?o0000ooooooooool05_ooool2o`0000;ooooo0_l0000<ooooo`0>oeEE
EOmgMgOooooooa0@4?l0003o8B4Qo`000?mgMgOo410@o`000?nYZJWoooooonk^k_mEEED2o`000004
odA4A?o^k^kooooooa0@40Go00000oooool01_o^k^koEEEEo`000?l0003oA4A4onk^kP;ooooo0_l0
00001?nYZJWo8B4Qo`000?lQ8B42ooooo`08ojVYZOlQ8B7o0000o`000?lb<S;o0000ogMgMomEEED7
ooooo`00<?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000oooooolm
ooooo`03omgMgOl@413ok^k^01;ooooo00?o0000ooooooooool06Oooool00oo^k^ko410@omgMg@07
ooooo`00<?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`000?oooooo?_ooool0
0omgMgOoIVIVooooo`0Aooooo`03o`000?oooooooooo01Wooooo00?oIVIVogMgMoooool01oooool0
033ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool0003oooooogSooooo000`oooo
o`03o`000?oooooooooo01Wooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00Co0000oooooooooooo0000oooooomhooooo`00<?ooool00ol0003oooooooooo`0I
ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`04o`000?oo
ooooooooo`000?ooooooN?ooool0033ooooo00?o0000ooooooooool06_ooool01?l0003ooooooooo
ool00008ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooool00000oooooomhooooo`00<?oo
ool00ol0003oooooooooo`0Jooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool2o`000?ooooooNOooool0033ooooo00?o0000ooooooooool06oooool3o`0000Sooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool2o`000?ooooooNOooool0033ooooo0ol0000Kooooo`;o00002Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`3oooooogoooooo000`ooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0oooooomoooooo`00<?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oo
ooooOoooool0033ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00003ooooooh;ooooo000`ooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`00
0?ooooooooooooooool00000oooooon2ooooo`00<?ooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0003ooooooh;o
oooo000`ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`04ooooo`04o`000?ooooooooooo`000?ooooooP_ooool0033ooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo
0000oooooon2ooooo`00<?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool01?l0003oooooooooool0003ooooooh;ooooo000`ooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`04o`00
0?ooooooooooo`000?ooooooP_ooool0033ooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo0000oooooon2ooooo`00
<?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool01?l0003oooooooooool0003ooooooh;ooooo000`ooooo`?o00009oooool01Ol0003ooooo
oooooooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Cooooo00Co0000oooooooooooo0000oooooon2ooooo`00<?ooool00ol0003o
ooooooooo`0Wooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0003o
oooooh;ooooo000`ooooo`03o`000?oooooooooo02Oooooo00Go0000ooooooooooooooooo`000007
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`04o`000?ooooooooooo`000?ooooooP_ooool0033ooooo00?o0000ooooooooool09oooool0
1Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo0000oooooon2ooooo`00<?oo
ool00ol0003oooooooooo`0Wooooo`05o`000?ooooooooooooooool000001oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
o`00003ooooooh?ooooo000`ooooo`03o`000?oooooooooo02Oooooo00Go0000oooooooooooooooo
o`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooo00000?ooooooPoooool0033ooooo00?o0000ooooooooool09ooo
ool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooool00000oooooon3ooooo`00<?ooool00ol0003ooooo
ooooo`0Wooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05
o`000?ooooooooooooooool000001_ooool00ol0003oooooo`00003ooooooh?ooooo000`ooooo`03
o`000?oooooooooo02Oooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo00000?ooooooPoooool0
033ooooo00?o0000ooooooooool09oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Oooooo0_l0003ooooooh?ooooo000`
ooooo`03o`000?oooooooooo02Oooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00Go0000ooooooooooooooooo`000007ooooo`;o0000oooooon3ooooo`00<?oo
ool00ol0003oooooooooo`0Wooooo`05o`000?ooooooooooooooool000001oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`04ooooo`05o`000?ooooooooooooooool000001oooool2o`000?ooooooPoooool0033ooooo
0ol0000Wooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05
o`000?ooooooooooooooool00000oooooon<ooooo`00<?ooool00ol0003oooooooooo`0Wooooo`05
o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooo
ooooool00000oooooon<ooooo`00<?ooool00ol0003oooooooooo`0Wooooo`05o`000?oooooooooo
ooooool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000oooo
oon<ooooo`00<?ooool00ol0003oooooooooo`0Wooooo`05o`000?ooooooooooooooool000002?oo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`04ooooo`05o`000?ooooooooooooooool00000oooooon<ooooo`00<?ooool00ol0003ooooo
ooooo`0Xooooo`04o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000006oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo
00000?ooooooS?ooool0033ooooo00?o0000ooooooooool0:?ooool01?l0003oooooooooool00008
ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Oooooo
00Go0000ooooooooooooooooo`00003oooooohcooooo000?ooooo`;ok^k^0oooool2onk^kQ[ooooo
00?o0000ooooooooool0:?ooool01?l0003oooooooooool00008ooooo`05o`000?oooooooooooooo
ool000001_ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`00
003oooooohcooooo0008ooooo`Go00000_ooool01oo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h0
0oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`03o`000?oooooo
oooo02Sooooo00?o0000ooooool000002Oooool01Ol0003ooooooooooooooooo000000Kooooo00Go
0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool00000oooooon<ooooo`00
2?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06oooo
o`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03o`000?oooooo
oooo02Sooooo00?o0000ooooool000002Oooool01Ol0003ooooooooooooooooo000000Kooooo00Go
0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool00000oooooon<ooooo`00
2Oooool00onHV9So8B4Qonk^kP05ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@00_ooooo00?o0000ooooooooool0:?ooool00ol0003o
ooooo`000009ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo
000000Oooooo00Go0000ooooooooooooooooo`00003oooooohcooooo000:ooooo`03oiRHV?lQ8B7o
k^k^00?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`00000;ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooool00000
2Oooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000007oooo
o`05o`000?ooooooooooooooool00000oooooon<ooooo`002oooool02omgMgOoIVIVoooooooooooo
k^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000000_ooooo1?l0000Wooooo`03o`000?oooooo000000Wooooo00Go0000oooo
ooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooo
oooooooo00000?ooooooS?ooool000cooooo00?o0000ooooooooool00_o^k^h3ooooo`;ok^k^1Ooo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41002oooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooo000000Wooooo00Go0000ooooooooooooooooo`000006ooooo`05
o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo00000?ooooooS?ooool0
00Sooooo00Go0000okZj^_ooooooV9RHoa0@400>ooooo`03o`000?oooooooooo00;ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0;ooooo`03o`000?oooooooooo02Wooooo0_l00009ooooo`05o`000?oo
ooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooooooo
ooooooooo`00003oooooohcooooo0008ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?ooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool2o`0000Kooooo00?o0000
ooooooooool0:Oooool2o`0000Wooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?oo
ooooooooooooool000001oooool01Ol0003ooooooooooooooooo00000?ooooooS?ooool002Oooooo
00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`0Yooooo`;o00002Oooool01Ol0003o
oooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooo
ooooooooool00000oooooon<ooooo`009oooool01?l0003oooooooooool00005ooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooooooo000000Kooooo
00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool00000oooooon<oooo
o`009oooool3o`0000Kooooo00?o0000ooooooooool0=?ooool01Ol0003ooooooooooooooooo0000
00Kooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`000?ooooooSOoo
ool002Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0dooooo`05o`000?oooooo
ooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo
0000oooooon=ooooo`00:Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03Cooooo
00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001oooool01?l0
003oooooooooool0003oooooohgooooo000`ooooo`03o`000?oooooooooo03Cooooo00Go0000oooo
ooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001oooool01?l0003ooooooooo
ool0003oooooohgooooo000`ooooo`03o`000?oooooooooo03Cooooo00Go0000oooooooooooooooo
o`000006ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool0003ooooo
ohgooooo000`ooooo`03o`000?oooooooooo03Cooooo00Go0000ooooooooooooooooo`000006oooo
o`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool0003oooooohgooooo000`
ooooo`?o0000=?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000oooooooooooooooo
o`000007ooooo`04o`000?ooooooooooo`000?ooooooSOooool0033ooooo00?o0000ooooooooool0
=?ooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo00001oooool01?l0
003oooooooooool0003oooooohgooooo000`ooooo`03o`000?oooooooooo03Cooooo00Go0000oooo
ooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo0000
oooooon=ooooo`00<?ooool00ol0003oooooooooo`0dooooo`05o`000?ooooooooooooooool00000
1oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?ooooooSOooool0033ooooo
00?o0000ooooooooool0=?ooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooo
oooo00002?ooool00ol0003oooooo`00003oooooohgooooo000`ooooo`03o`000?oooooooooo03Co
oooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000
ooooool00000oooooon=ooooo`00<?ooool00ol0003oooooooooo`0dooooo`05o`000?oooooooooo
ooooool000001oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?ooooooSOoo
ool0033ooooo00?o0000ooooooooool0=?ooool01Ol0003ooooooooooooooooo000000Oooooo00Co
0000oooooooooooo00002?ooool00ol0003oooooo`00003oooooohgooooo000`ooooo`03o`000?oo
oooooooo03Cooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000So
oooo00?o0000ooooool00000oooooon=ooooo`00<?ooool00ol0003oooooooooo`0dooooo`05o`00
0?ooooooooooooooool000001oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo0000
0?ooooooSOooool0033ooooo00?o0000ooooooooool0=?ooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000Sooooo0_l0003oooooohkooooo000`ooooo`03o`000?oooooooooo
03Cooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00008ooooo`;o0000oooo
oon>ooooo`00<?ooool3o`0003Cooooo00Co0000oooooooooooo00002?ooool01?l0003ooooooooo
ool00008ooooo`;o0000oooooon>ooooo`00<?ooool00ol0003oooooooooo`0dooooo`04o`000?oo
ooooooooo`0000Sooooo00Co0000oooooooooooo00002?ooool2o`000?ooooooS_ooool0033ooooo
00?o0000ooooooooool0=?ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00
00Sooooo0_l0003oooooohkooooo000`ooooo`03o`000?oooooooooo03Cooooo00Co0000oooooooo
oooo00002?ooool01?l0003oooooooooool00008ooooo`;o0000oooooon>ooooo`00<?ooool00ol0
003oooooooooo`0dooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002?oo
ool2o`000?ooooooS_ooool0033ooooo00?o0000ooooooooool0=?ooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0000Sooooo0_l0003oooooohkooooo000`ooooo`03o`000?oo
oooooooo03Cooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00008ooooo`;o
0000oooooon>ooooo`00<?ooool00ol0003oooooooooo`0dooooo`04o`000?ooooooooooo`0000So
oooo00Co0000oooooooooooo00002?ooool2o`000?ooooooS_ooool0033ooooo00?o0000oooooooo
ool0=?ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo0_l0003o
ooooohkooooo000`ooooo`03o`000?oooooooooo03Cooooo00Co0000oooooooooooo00002?ooool0
1?l0003oooooooooool00008ooooo`;o0000oooooon>ooooo`00<?ooool00ol0003oooooooooo`0d
ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000oooooonHooooo`00<?oo
ool00ol0003oooooooooo`0dooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo
0000oooooonHooooo`00<?ooool3o`0003Cooooo00Co0000oooooooooooo00002?ooool01?l0003o
ooooooooool0003ooooooiSooooo000`ooooo`03o`000?oooooooooo03Cooooo00Co0000oooooooo
oooo00002?ooool01?l0003oooooooooool0003ooooooiSooooo000`ooooo`03o`000?oooooooooo
03Cooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0003ooooooiSooooo000`
ooooo`03o`000?oooooooooo03Cooooo00Co0000oooooooooooo00002?ooool01?l0003ooooooooo
ool0003ooooooiSooooo000`ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooool000002?oo
ool01?l0003oooooooooool0003ooooooiSooooo000`ooooo`03o`000?oooooooooo03Gooooo00?o
0000ooooool000002?ooool01?l0003oooooooooool0003ooooooiSooooo000?ooooo`;ok^k^0ooo
ool2onk^kQ[ooooo00?o0000ooooooooool0=Oooool00ol0003oooooo`000008ooooo`04o`000?oo
ooooooooo`000?ooooooV?ooool000[ooooo0_l000002_l@413oooooooooooo^k^koEEEEonk^k_oo
ooook^k^oeEEEOo^k^h3ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP_o
oooo00?o0000ooooooooool0=Oooool00ol0003oooooo`000008ooooo`04o`000?ooooooooooo`00
0?ooooooV?ooool000_ooooo00?o0000ooooooooool00_ooool01Oo^k^koEEEEomgMgOmEEEGok^k^
00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?o0000
ooooooooool0=Oooool00ol0003oooooo`000008ooooo`04o`000?ooooooooooo`000?ooooooV?oo
ool000Sooooo1Ol00004ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@00_ooooo00?o0000ooooooooool0=Oooool00ol0003oooooo`00
0008ooooo`04o`000?ooooooooooo`000?ooooooV?ooool000Sooooo00CoA4A4omgMgOoooooo0000
1?ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000000_ooooo00?o0000ooooooooool0=Oooool00ol0003oooooo`000008oooo
o`04o`000?ooooooooooo`000?ooooooV?ooool000Sooooo00CogMgMoeEEEOoooooo00000oooool0
1oo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000002oooool4o`0003Cooooo00?o0000ooooool000002?ooool01?l0003o
ooooooooool0003ooooooiSooooo0009ooooo`03ogMgMoo<c<co000000?ooooo0_o^k^h3ooooo`;o
k^k^1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41002oooool00ol0
003oooooooooo`0eooooo`03o`000?oooooo000000Sooooo00Co0000oooooooooooo0000oooooonH
ooooo`002Oooool00oo^k^koA4A4o`00000?ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0;ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooool000002?ooool0
1?l0003oooooooooool0003ooooooiSooooo000:ooooo`03ogMgMol0003ooooo00cooooo00?oEEEE
ofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo0_l00006ooooo`03o`000?oo
oooooooo03Gooooo00?o0000ooooool000002?ooool01?l0003oooooooooool0003ooooooiSooooo
000Wooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0=Oooool00ol0003ooooo
o`000008ooooo`04o`000?ooooooooooo`000?ooooooV?ooool002Oooooo00Co0000oooooooooooo
00001Oooool00ol0003oooooooooo`0eooooo`;o00002Oooool00ol0003oooooo`00003ooooooiWo
oooo000Wooooo`?o00001_ooool00ol0003oooooooooo`0eooooo`;o00002Oooool00ol0003ooooo
o`00003ooooooiWooooo000Xooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0=Ooo
ool2o`0000Wooooo00?o0000ooooool00000oooooonIooooo`00:Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo03Gooooo0_l00009ooooo`03o`000?oooooo00000?ooooooVOooool0
033ooooo00?o0000ooooooooool0=Oooool2o`0000Wooooo00?o0000ooooool00000oooooonIoooo
o`00<?ooool00ol0003oooooooooo`0eooooo`;o00002Oooool00ol0003oooooo`00003ooooooiWo
oooo000`ooooo`03o`000?oooooooooo03Gooooo0_l0000:ooooo`;o0000oooooonIooooo`00<?oo
ool3o`0003Kooooo00?o0000ooooooooool02?ooool2o`000?ooooooVOooool0033ooooo00?o0000
ooooooooool0@Oooool2o`000?ooooooVOooool0033ooooo00?o0000ooooooooool0@Oooool2o`00
0?ooooooVOooool0033ooooo00?o0000ooooooooool0@Oooool2o`000?ooooooVOooool0033ooooo
00?o0000ooooooooool0@Oooool2o`000?ooooooVOooool0033ooooo00?o0000ooooooooool0@Ooo
ool2o`000?ooooooVOooool0033ooooo00?o0000ooooooooool0@Oooool2o`000?ooooooVOooool0
033ooooo00?o0000ooooooooool0@Oooool2o`000?ooooooVOooool0033ooooo00?o0000oooooooo
ool0@Oooool2o`000?ooooooVOooool0033ooooo00?o0000ooooooooool0@Oooool2o`000?oooooo
VOooool0033ooooo00?o0000ooooooooool0@Oooool2o`000?ooooooVOooool0033ooooo00?o0000
ooooooooool0@Oooool2o`000?ooooooVOooool0033ooooo0ol00011ooooo`;o0000oooooonIoooo
o`00<?ooool00ol0003oooooooooo`11ooooo`;o0000oooooonIooooo`00<?ooool00ol0003ooooo
ooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000
ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03
o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?oo
ool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0
033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomco
oooo000`ooooo`?o0000oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`
ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLoooo
o`00<?ooool00ol0003oooooooooo`3oooooomcooooo003ooooooooooooo4?ooool00?oooooooooo
ool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00
oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00Y?ooool2o`00
00?ooooo00?o^[Zjoc8b<_ooool01Oooool2o`0000Gooooo00?o0000okZj^_ooool0oooooomDoooo
o`00Y?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00oooool2oc8b<_ooooooEOooool0097ooooo0ol00002ooooo`06oc8b<_l@413oooooooooooo^
k^koEEEE0_l000000om4A4Co^[Zjooooo`03ooooo`06o`000?oooooooooooooooonHV9So410@0_l0
00000onYZJWoooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?oQhN7o`000?nj^[X03?oo
ool01OnHV9So0000o`000?m4A4Co^[Zj00Wooooo00GoV9RHoa0@4?l0003o<S8bolc<c005ooooo`;o
8B4Q0oooool01Oo<c<cok^k^ooooooo^k^koc<c<00Cooooo1?l000002?l@413oooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^4oooool01_l@413o<S8bo`000?l0003o410@ojVYZ@;ooooo00Kok^k^oeEE
EOl0003o0000odA4A?nj^[X3ooooo`05ofIVI_l0003o0000odA4A?o<c<`0k?ooool009;ooooo00Go
0000ooooooooooooc<c<oa0@4003ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo410@1?ooool02_l0
003ooooooooooooooooo0000ojVYZOmEEEGoV9RHoeEEEOnj^[X4ooooo`03o`000?oooooooooo00?o
oooo00?oc<c<o`000?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00;ooooo1_l000001_oo
oooo410@okZj^_ooooooMgMgoc8b<PGooooo0_lQ8B43ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h0
1_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool01_l0003o
ZJVYoooooooooooo^[Zjo`0000;ooooo00KoEEEEogMgMoooooook^k^ogMgMol@4102ooooo`06ofIV
I_mgMgOooooooooooon7QhOo410@k?ooool009;ooooo00Go0000ooooooooooooEEEEohN7Q`03oooo
o`03o`000?oooooooooo00Oooooo00[o0000oooooooooooooooooc8b<_o^k^koV9RHoeEEEOoMgMgo
410@1?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool02Oooool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooo
oooooooooa0@400Dooooo`05okZj^_n7QhOoIVIVofIVI_l@41000_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0>oooooo002Booooo`05o`000?oooooogMgMo`000?o^k^h00oooool6
o`0000Cooooo00_o0000oooooooooooooooookZj^_m4A4Coc<c<ob4Q8Ooooooo410@olc<c003oooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01?ooool6o`0000Cooooo00?oZJVYoa0@
4?ooool02Oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000001?ooooo00Ko<S8bob4Q8OmgMgOoMgMgohN7Qoo^k^h2ooooo`Ko
00000_ooool00ol0003oooooooooo`3_ooooo`00T_ooool3o`000003oa0@4?nHV9Sooooo00;ooooo
00KoEEEEohN7Qoo^k^koooooohN7Qolb<S84ooooo`0;o`000?ooooooooooooooooo^k^ko0000oooo
ool0003oooooofIVI_n7QhL00oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00go
oooo00?o410@o`000?nj^[X02_ooool01Oo<c<cok^k^ooooooo^k^koc<c<00Kooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000001?ooooo00Ko0000okZj^_ooooook^k^ogMg
Mol00002ooooo`06oeEEEOn7QhOok^k^oooooon7QhOo<S8b0_ooool01_mVIVKoMgMgoooooooooooo
QhN7o`000>cooooo002Booooo`05o`000?ooooooooooolc<c?l000000oooool01_o^k^koEEEEo`00
0?l0003oA4A4onk^kPCooooo00So0000ooooooooooooooooofIVI_nHV9Sooooooc8b<P;o^[Zj00Go
0000ooooooooooooooooo`00000Booooo`03oa0@4?l0003o000000?o00003Oooool00onj^[[o8B4Q
ooooo`0Dooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4007ooooo`?o
00000_ooool3o`0000Cooooo00KoZJVYob4Q8Ol0003o0000oc8b<_l00002ooooo`06onk^k_mEEEGo
0000o`000?m4A4Cok^k^0_ooool01_o^k^koIVIVo`000?l0003oA4A4o`000>cooooo002Booooo`05
o`000?ooooooooooolc<c?l000003Oooool00ol0003oooooooooo`04ooooo`03ofIVI_n7QhOooooo
00Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0;ooooo`05oa0@4?nHV9Sooooo
okZj^_l000005Oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo1_ooool0097ooooo1?l00000
0ol@413oZJVYooooo`0<ooooo`;o00001Oooool00onYZJWoA4A4ooooo`03ooooo`;o00005?ooool0
0ol0003oooooooooo`0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT04oooool00omEEEGoIVIVo`00
0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_ooool4o`0000;ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`3oooooo`Kooooo003oooooo`;ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`3oooooo`Kooooo003oooooo`;ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`3oooooo`Kooooo003oooooo`7ooooo0_l00003ooooo`;o0000ooooool8oooo
o`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooo
oooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo
003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooo
oooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool0
0?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooooooo
ool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00001\
\>"],
  ImageRangeCache->{{{0, 525.688}, {324.5, 0}} -> {0, -6.34248*^6, 0, 53093}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0.309017 5.42214e-08 [
[.32684 .29652 -16.5 -12.5 ]
[.32684 .29652 16.5 0 ]
[.54329 .29652 -16.5 -12.5 ]
[.54329 .29652 16.5 0 ]
[.75974 .29652 -22.5 -12.5 ]
[.75974 .29652 22.5 0 ]
[.97619 .29652 -16.5 -12.5 ]
[.97619 .29652 16.5 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 64 6 ]
[.09789 .09213 -34.5 -6.25 ]
[.09789 .09213 0 6.25 ]
[.09789 .20057 -34.5 -6.25 ]
[.09789 .20057 0 6.25 ]
[.09789 .41746 -28.5 -6.25 ]
[.09789 .41746 0 6.25 ]
[.09789 .5259 -28.5 -6.25 ]
[.09789 .5259 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -62.8125 0 ]
[.5 .63053 62.8125 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 .30902 m
.32684 .31527 L
s
gsave
.32684 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 .30902 m
.54329 .31527 L
s
gsave
.54329 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 .30902 m
.75974 .31527 L
s
gsave
.75974 .29652 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 .30902 m
.15368 .31277 L
s
.19697 .30902 m
.19697 .31277 L
s
.24026 .30902 m
.24026 .31277 L
s
.28355 .30902 m
.28355 .31277 L
s
.37013 .30902 m
.37013 .31277 L
s
.41342 .30902 m
.41342 .31277 L
s
.45671 .30902 m
.45671 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.58658 .30902 m
.58658 .31277 L
s
.62987 .30902 m
.62987 .31277 L
s
.67316 .30902 m
.67316 .31277 L
s
.71645 .30902 m
.71645 .31277 L
s
.80303 .30902 m
.80303 .31277 L
s
.84632 .30902 m
.84632 .31277 L
s
.88961 .30902 m
.88961 .31277 L
s
.9329 .30902 m
.9329 .31277 L
s
.0671 .30902 m
.0671 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09213 m
.11664 .09213 L
s
gsave
.09789 .09213 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .20057 m
.11664 .20057 L
s
gsave
.09789 .20057 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .41746 m
.11664 .41746 L
s
gsave
.09789 .41746 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .5259 m
.11664 .5259 L
s
gsave
.09789 .5259 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.11039 .11924 m
.11414 .11924 L
s
.11039 .14635 m
.11414 .14635 L
s
.11039 .17346 m
.11414 .17346 L
s
.11039 .22768 m
.11414 .22768 L
s
.11039 .2548 m
.11414 .2548 L
s
.11039 .28191 m
.11414 .28191 L
s
.11039 .33613 m
.11414 .33613 L
s
.11039 .36324 m
.11414 .36324 L
s
.11039 .39035 m
.11414 .39035 L
s
.11039 .44457 m
.11414 .44457 L
s
.11039 .47168 m
.11414 .47168 L
s
.11039 .49879 m
.11414 .49879 L
s
.11039 .06502 m
.11414 .06502 L
s
.11039 .03791 m
.11414 .03791 L
s
.11039 .0108 m
.11414 .0108 L
s
.11039 .55301 m
.11414 .55301 L
s
.11039 .58012 m
.11414 .58012 L
s
.11039 .60723 m
.11414 .60723 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -123.812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.812 moveto
(@) show
81.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.812 moveto
(D) show
93.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.2) show
135.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
141.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
153.000 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
157.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
166.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
184.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02532 .30902 L
.02691 .30902 L
.02852 .30902 L
.03029 .30902 L
.03354 .30902 L
.03667 .30902 L
.03827 .30902 L
.03911 .30902 L
.03957 .30902 L
.04 .30902 L
.04038 .30902 L
.0406 .30902 L
.04079 .30902 L
.0409 .30902 L
.04101 .30902 L
.04107 .30902 L
.04112 .30902 L
.04118 .30902 L
.04124 .30902 L
.04129 .30902 L
.04135 .30902 L
.04145 .30902 L
.04155 .30902 L
.04161 .30902 L
.04167 .30902 L
.04176 .30902 L
.04187 .30902 L
.04206 .30902 L
.04224 .30902 L
.04241 .30902 L
.0428 .30902 L
.04321 .30902 L
.0436 .30902 L
.04396 .30902 L
.04477 .30902 L
.04548 .30902 L
.04624 .30902 L
.047 .30902 L
.04782 .30902 L
.04929 .30902 L
.05012 .30902 L
.05101 .30902 L
.05263 .30902 L
.05422 .30902 L
.05591 .30902 L
.05895 .30902 L
.06219 .30902 L
.06368 .30902 L
.06447 .30902 L
Mistroke
.06531 .30902 L
.06577 .30902 L
.06619 .30902 L
.06639 .30902 L
.0665 .30902 L
.06661 .30902 L
.06671 .30902 L
.06676 .30902 L
.06682 .30902 L
.06691 .30902 L
.06701 .30902 L
.06706 .30902 L
.06711 .30902 L
.06721 .30902 L
.06727 .30902 L
.06732 .30902 L
.06744 .30902 L
.06754 .30902 L
.06764 .30902 L
.06785 .30902 L
.06803 .30902 L
.06822 .30902 L
.06862 .30902 L
.06904 .30902 L
.06945 .30902 L
.0702 .30902 L
.071 .30902 L
.07188 .30902 L
.07264 .30902 L
.07348 .30902 L
.07517 .30902 L
.07673 .30902 L
.07841 .30902 L
.08173 .30902 L
.08492 .30902 L
.08638 .30901 L
.08722 .30901 L
.088 .30901 L
.08876 .30901 L
.08897 .30901 L
.08919 .30901 L
.08939 .30901 L
.08958 .30901 L
.08968 .30901 L
.08978 .30901 L
.08984 .30901 L
.08989 .30901 L
.09 .30901 L
.09009 .30901 L
.09019 .30901 L
Mistroke
.09029 .30901 L
.09039 .30901 L
.09044 .30901 L
.0905 .30901 L
.09061 .30901 L
.09071 .30901 L
.09081 .30901 L
.09103 .30901 L
.09127 .30901 L
.0917 .30901 L
.09209 .30901 L
.09253 .30901 L
.09299 .30901 L
.09376 .30902 L
.09461 .30902 L
.09543 .30902 L
.09617 .30902 L
.09785 .30902 L
.09939 .30902 L
.10105 .30903 L
.10433 .30904 L
.10596 .30904 L
.10748 .30905 L
.10896 .30905 L
.1097 .30905 L
.11013 .30905 L
.11051 .30905 L
.11072 .30905 L
.11092 .30905 L
.11102 .30905 L
.11113 .30905 L
.11118 .30905 L
.11125 .30905 L
.1113 .30905 L
.11135 .30905 L
.11146 .30905 L
.11155 .30905 L
.11165 .30905 L
.1117 .30905 L
.11176 .30905 L
.11185 .30905 L
.11194 .30905 L
.11213 .30905 L
.11233 .30905 L
.1125 .30905 L
.1129 .30905 L
.11325 .30905 L
.11362 .30905 L
.11438 .30905 L
.1152 .30904 L
Mistroke
.11597 .30904 L
.11667 .30903 L
.11821 .30901 L
.11988 .30898 L
.12316 .3089 L
.12632 .30881 L
.1279 .30877 L
.12859 .30875 L
.12935 .30874 L
.12976 .30873 L
.13015 .30873 L
.13052 .30872 L
.13072 .30872 L
.13091 .30872 L
.13101 .30872 L
.13112 .30872 L
.13122 .30872 L
.13132 .30872 L
.13138 .30872 L
.13143 .30872 L
.1315 .30872 L
.13155 .30872 L
.13166 .30872 L
.13172 .30872 L
.13177 .30872 L
.13196 .30872 L
.13206 .30872 L
.13216 .30872 L
.13238 .30873 L
.13258 .30873 L
.13296 .30873 L
.13337 .30874 L
.13377 .30875 L
.1342 .30877 L
.13498 .3088 L
.13569 .30884 L
.13723 .30896 L
.1389 .30914 L
.14218 .30963 L
.14534 .31019 L
.14693 .31044 L
.14762 .31052 L
.14838 .3106 L
.1488 .31064 L
.149 .31065 L
.14918 .31066 L
.14936 .31067 L
.14955 .31068 L
.14966 .31068 L
.14975 .31068 L
Mistroke
.14984 .31068 L
.14994 .31068 L
.15005 .31068 L
.15014 .31069 L
.15019 .31068 L
.15025 .31068 L
.15036 .31068 L
.15045 .31068 L
.15056 .31068 L
.15074 .31067 L
.15096 .31066 L
.15116 .31065 L
.15162 .31061 L
.152 .31057 L
.15241 .31051 L
.15324 .31034 L
.15401 .31014 L
.15473 .3099 L
.15637 .30917 L
.15786 .3083 L
.16108 .30594 L
.16417 .30361 L
.16499 .3031 L
.16577 .30272 L
.16619 .30255 L
.16657 .30242 L
.167 .30232 L
.16711 .30229 L
.16723 .30227 L
.16735 .30226 L
.16746 .30225 L
.16755 .30224 L
.16764 .30224 L
.16774 .30223 L
.16784 .30223 L
.16793 .30223 L
.16803 .30224 L
.16812 .30224 L
.16821 .30225 L
.16831 .30226 L
.16841 .30227 L
.16864 .30232 L
.16883 .30236 L
.16904 .30243 L
.16945 .30259 L
.16984 .30279 L
.17073 .30343 L
.17156 .30427 L
.17235 .30528 L
.17384 .30775 L
Mistroke
.1769 .31481 L
.18017 .32338 L
.18168 .32672 L
.18253 .3282 L
.18293 .32876 L
.18331 .32919 L
.18371 .32955 L
.18392 .3297 L
.18414 .32982 L
.18426 .32986 L
.18432 .32988 L
.18438 .3299 L
.18444 .32991 L
.1845 .32992 L
.18455 .32993 L
.18461 .32994 L
.18471 .32994 L
.18481 .32993 L
.18486 .32993 L
.18492 .32992 L
.18497 .32991 L
.18503 .3299 L
.18513 .32986 L
.18524 .32982 L
.18544 .32971 L
.18563 .32957 L
.18581 .32941 L
.18622 .32895 L
.18665 .32828 L
.18741 .32667 L
.18822 .32432 L
.18969 .31841 L
.19139 .30917 L
.193 .29858 L
.19607 .27699 L
.19696 .2714 L
.19779 .26678 L
.1986 .26307 L
.19895 .26173 L
.19934 .2605 L
.19972 .25954 L
.20008 .25888 L
.20027 .25862 L
.20045 .25844 L
.20055 .25837 L
.20061 .25834 L
.20066 .25832 L
.20075 .25829 L
.20085 .25829 L
.20095 .2583 L
Mistroke
.20105 .25833 L
.2011 .25836 L
.20115 .25839 L
.20125 .25847 L
.20145 .25868 L
.20163 .25895 L
.20185 .25937 L
.20204 .25985 L
.20249 .26124 L
.20288 .26285 L
.20329 .26494 L
.20403 .26968 L
.20483 .2762 L
.2057 .28497 L
.20894 .32889 L
.21206 .37573 L
.21288 .38612 L
.21377 .39566 L
.21417 .39928 L
.21461 .40254 L
.21501 .40501 L
.21519 .40591 L
.21538 .40674 L
.21556 .40738 L
.21575 .40792 L
.21585 .40816 L
.21595 .40834 L
.21604 .40848 L
.21613 .40857 L
.21623 .40864 L
.21634 .40866 L
.21642 .40865 L
.21652 .40859 L
.21663 .40848 L
.21669 .4084 L
.21674 .40831 L
.21694 .40786 L
.21713 .40728 L
.2173 .40661 L
.2177 .40456 L
.21804 .40217 L
.21841 .39902 L
.21924 .38965 L
.22013 .37609 L
.22175 .34331 L
.22504 .25617 L
.22668 .21233 L
.22749 .19327 L
.22822 .17804 L
.22892 .16573 L
Mistroke
.22969 .15551 L
.23011 .15145 L
.23029 .15005 L
.2305 .14876 L
.23069 .14783 L
.23087 .14719 L
.23097 .14693 L
.23106 .14677 L
.23116 .14665 L
.23127 .14661 L
.23136 .14665 L
.23142 .1467 L
.23147 .14677 L
.23157 .14695 L
.23167 .14722 L
.23184 .14786 L
.23203 .14883 L
.23224 .15018 L
.23246 .15199 L
.23285 .15619 L
.23325 .1616 L
.23362 .16784 L
.23433 .18236 L
.23592 .22774 L
.2374 .28215 L
.24055 .41297 L
.24215 .47168 L
.24306 .4979 L
.24349 .50812 L
.24389 .51619 L
.24428 .52265 L
.24464 .52721 L
.24484 .52925 L
.24503 .53077 L
.24524 .53196 L
.24535 .53244 L
.24546 .53276 L
.24555 .53294 L
.24566 .53302 L
.24575 .533 L
.24584 .53289 L
.24594 .53265 L
.246 .53246 L
.24606 .53226 L
.24626 .53118 L
.24637 .5304 L
.24648 .52954 L
.24667 .52761 L
.24711 .52174 L
.24749 .51509 L
Mistroke
.2479 .50606 L
.24872 .48252 L
.25021 .42456 L
.25345 .25469 L
.25495 .17538 L
.25657 .1035 L
.25746 .07449 L
.25785 .06448 L
.25828 .05557 L
.25847 .05231 L
.25868 .04933 L
.25886 .04722 L
.25906 .04541 L
.25917 .04464 L
.25927 .04407 L
.25938 .04361 L
.25944 .04343 L
.2595 .0433 L
.25959 .04318 L
.25965 .04317 L
.2597 .0432 L
.25979 .04334 L
.25989 .04363 L
.25999 .04404 L
.2601 .04464 L
.26029 .04612 L
.26048 .04805 L
.26065 .05027 L
.26104 .05683 L
.26146 .06609 L
.26224 .08902 L
.26293 .11592 L
.26448 .19281 L
.26615 .29332 L
.26773 .39138 L
.26945 .48696 L
.27024 .52247 L
.27068 .53901 L
.27109 .55249 L
.27147 .56301 L
.27189 .57214 L
.27208 .57537 L
.27227 .57827 L
.27244 .5803 L
.27262 .58205 L
.27271 .58275 L
.27281 .58335 L
.27292 .58382 L
.27302 .58412 L
.27311 .58427 L
Mistroke
.2732 .58428 L
.27329 .58418 L
.27338 .58396 L
.27347 .58358 L
.27358 .583 L
.27369 .5822 L
.2738 .58129 L
.274 .57909 L
.27419 .57646 L
.27456 .56981 L
.2749 .56203 L
.27566 .53884 L
.27643 .50784 L
.27725 .46785 L
.27873 .38286 L
.28176 .19745 L
.28331 .12156 L
.28373 .10517 L
.28418 .09029 L
.2846 .07874 L
.28498 .07033 L
.28517 .06693 L
.28537 .06381 L
.28555 .06161 L
.28575 .05971 L
.28585 .0589 L
.28595 .0583 L
.28606 .05782 L
.28612 .05762 L
.28617 .05749 L
.28627 .05735 L
.28637 .05736 L
.28647 .05752 L
.28656 .05779 L
.28666 .05819 L
.28676 .05876 L
.28694 .06016 L
.28711 .06198 L
.28728 .06404 L
.28765 .07011 L
.28804 .07852 L
.2888 .10051 L
.28961 .13141 L
.29109 .20191 L
.29268 .28973 L
.29441 .38342 L
.29521 .42185 L
.29607 .45675 L
.2968 .48068 L
.29719 .49087 L
Mistroke
.29761 .49997 L
.298 .50651 L
.29822 .50925 L
.29842 .51127 L
.29851 .51207 L
.29861 .5127 L
.29869 .51319 L
.29878 .51361 L
.29887 .51396 L
.29896 .51417 L
.29906 .51429 L
.29916 .51429 L
.29921 .51424 L
.29927 .51414 L
.29938 .51385 L
.29948 .51343 L
.29958 .51292 L
.29979 .51135 L
.30003 .50905 L
.30045 .50318 L
.30083 .49608 L
.30164 .47612 L
.30238 .45247 L
.30406 .38571 L
.3057 .31228 L
.30723 .2481 L
.30871 .19887 L
.30913 .1879 L
.30953 .17903 L
.30992 .17191 L
.31028 .16657 L
.31065 .16249 L
.31085 .16088 L
.31106 .15958 L
.31117 .1591 L
.31122 .15889 L
.31128 .1587 L
.31134 .15855 L
.31139 .15845 L
.31149 .15831 L
.31159 .15828 L
.3117 .15835 L
.3118 .15852 L
.31189 .15876 L
.31197 .15906 L
.31206 .15945 L
.31223 .16037 L
.31243 .1618 L
.31261 .16341 L
.313 .16791 L
Mistroke
.31337 .17337 L
.31414 .18823 L
.31496 .20839 L
.31644 .25239 L
.31947 .34705 L
.32023 .36642 L
.32102 .38342 L
.32144 .39075 L
.3219 .39742 L
.32231 .40224 L
.3227 .40562 L
.32291 .40701 L
.3231 .40802 L
.32321 .40847 L
.32331 .40881 L
.32342 .40909 L
.32348 .4092 L
.32354 .4093 L
.32364 .4094 L
.3237 .40943 L
.32375 .40943 L
.32385 .40939 L
.32396 .40926 L
.32406 .40907 L
.32416 .40882 L
.32434 .40819 L
.32452 .40735 L
.32471 .40622 L
.32505 .40363 L
.32542 .40006 L
.32583 .39529 L
.3274 .3698 L
.32908 .3351 L
.33067 .3017 L
.33151 .28593 L
.3324 .27159 L
.33319 .26144 L
.33361 .25715 L
.33406 .25343 L
.33426 .25208 L
.33448 .25086 L
.33467 .24992 L
.33486 .24921 L
.33503 .24868 L
.33521 .24827 L
.33532 .2481 L
.33542 .24799 L
.3355 .24793 L
.3356 .2479 L
.3357 .24792 L
Mistroke
.33579 .24797 L
.33589 .24808 L
.33599 .24822 L
.33617 .24858 L
.33636 .24912 L
.33657 .24989 L
.3368 .25089 L
.3372 .25318 L
.338 .25939 L
.33889 .26836 L
.34211 .30873 L
.34359 .32513 L
.34443 .33243 L
.34484 .33535 L
.34521 .33762 L
.34558 .33951 L
.34599 .34111 L
.34621 .3418 L
.34641 .34231 L
.34661 .34269 L
.34672 .34286 L
.34682 .34298 L
.34692 .34308 L
.34702 .34315 L
.34712 .34319 L
.34718 .3432 L
.34723 .34321 L
.34733 .34319 L
.34742 .34316 L
.34753 .34309 L
.34762 .343 L
.34773 .34288 L
.34785 .34272 L
.34805 .34234 L
.34827 .34184 L
.34851 .34115 L
.34933 .33793 L
.35008 .33397 L
.35176 .32278 L
.35342 .3109 L
.35495 .30136 L
.35572 .2976 L
.35645 .29483 L
.35684 .29366 L
.3572 .29279 L
.3576 .29207 L
.35781 .29179 L
.35792 .29168 L
.35803 .29157 L
.35814 .29149 L
Mistroke
.35824 .29143 L
.35833 .29139 L
.35843 .29136 L
.35852 .29134 L
.35861 .29134 L
.3587 .29135 L
.3588 .29137 L
.3589 .29141 L
.35902 .29146 L
.35912 .29154 L
.35922 .29162 L
.35962 .29205 L
.35999 .29265 L
.36033 .29332 L
.36109 .29524 L
.36431 .30657 L
.36579 .31151 L
.36663 .31377 L
.36741 .31543 L
.36781 .31609 L
.36818 .3166 L
.36839 .31683 L
.36862 .31704 L
.36882 .3172 L
.36901 .31732 L
.36922 .31741 L
.36932 .31745 L
.36938 .31746 L
.36944 .31748 L
.3695 .31749 L
.36955 .3175 L
.36962 .3175 L
.36968 .31751 L
.36973 .31751 L
.36979 .31751 L
.36989 .3175 L
.36999 .31748 L
.3701 .31746 L
.37018 .31743 L
.37028 .3174 L
.3705 .3173 L
.3707 .31718 L
.37111 .31687 L
.37154 .31643 L
.37234 .3154 L
.37383 .31296 L
.37538 .31019 L
.37621 .30883 L
.3771 .30754 L
.37794 .30656 L
Mistroke
.37831 .30621 L
.37872 .30589 L
.37908 .30565 L
.37946 .30546 L
.37968 .30538 L
.37987 .30532 L
.38006 .30527 L
.38025 .30524 L
.38034 .30523 L
.38044 .30522 L
.38053 .30521 L
.38062 .30521 L
.38072 .30521 L
.38077 .30522 L
.38083 .30522 L
.38092 .30523 L
.38103 .30524 L
.38113 .30525 L
.38125 .30527 L
.38146 .30532 L
.38185 .30545 L
.38223 .3056 L
.38262 .3058 L
.38333 .30624 L
.38638 .30861 L
.38795 .30966 L
.38883 .31009 L
.38922 .31024 L
.38963 .31037 L
.39001 .31047 L
.39021 .31051 L
.39042 .31055 L
.39062 .31057 L
.3908 .31059 L
.39098 .3106 L
.39107 .31061 L
.39116 .31061 L
.39122 .31061 L
.39127 .31061 L
.39133 .31061 L
.39138 .31061 L
.39148 .31061 L
.39158 .31061 L
.39163 .31061 L
.39169 .31061 L
.39179 .3106 L
.39202 .31058 L
.39224 .31056 L
.39244 .31053 L
.39283 .31046 L
Mistroke
.3936 .31029 L
.39442 .31005 L
.3959 .30956 L
.39751 .30904 L
.39835 .30881 L
.39924 .30862 L
.40004 .3085 L
.4005 .30845 L
.40072 .30843 L
.40092 .30842 L
.40111 .3084 L
.40121 .3084 L
.40131 .3084 L
.4014 .30839 L
.4015 .30839 L
.40159 .30839 L
.40167 .30839 L
.40177 .30839 L
.40187 .30839 L
.40196 .30839 L
.40205 .30839 L
.40216 .30839 L
.40221 .30839 L
.40227 .30839 L
.40247 .3084 L
.40265 .30841 L
.40286 .30842 L
.40327 .30844 L
.40401 .30851 L
.40568 .30871 L
.40738 .30894 L
.40892 .30911 L
.40969 .30917 L
.4101 .30919 L
.41053 .30922 L
.4109 .30923 L
.4111 .30924 L
.41132 .30924 L
.41151 .30925 L
.4116 .30925 L
.41169 .30925 L
.41178 .30925 L
.41187 .30925 L
.41196 .30925 L
.41205 .30925 L
.41215 .30925 L
.4122 .30925 L
.41225 .30925 L
.41236 .30925 L
.41242 .30925 L
Mistroke
.41247 .30925 L
.41257 .30925 L
.41268 .30925 L
.41287 .30925 L
.41309 .30924 L
.41333 .30924 L
.41376 .30922 L
.41461 .30919 L
.41538 .30916 L
.41705 .30907 L
.41779 .30904 L
.4186 .30901 L
.41932 .30898 L
.4201 .30896 L
.42053 .30895 L
.42093 .30894 L
.42112 .30894 L
.42132 .30894 L
.42152 .30894 L
.42169 .30894 L
.42188 .30894 L
.42198 .30893 L
.42208 .30893 L
.42218 .30893 L
.42226 .30893 L
.42235 .30893 L
.42245 .30893 L
.42251 .30893 L
.42256 .30893 L
.42268 .30893 L
.42278 .30894 L
.42289 .30894 L
.42308 .30894 L
.42328 .30894 L
.4237 .30894 L
.42416 .30895 L
.42497 .30896 L
.42656 .30899 L
.42829 .30902 L
.42909 .30903 L
.42953 .30903 L
.42995 .30903 L
.43033 .30904 L
.43068 .30904 L
.43106 .30904 L
.43127 .30904 L
.43148 .30904 L
.43169 .30904 L
.43179 .30904 L
.43188 .30904 L
Mistroke
.43197 .30904 L
.43206 .30904 L
.43215 .30904 L
.43225 .30904 L
.4323 .30904 L
.43235 .30904 L
.43245 .30904 L
.43256 .30904 L
.43261 .30904 L
.43267 .30904 L
.43286 .30904 L
.43306 .30904 L
.43346 .30904 L
.43384 .30904 L
.43454 .30904 L
.43763 .30902 L
.43846 .30902 L
.43923 .30901 L
.44004 .30901 L
.44047 .30901 L
.44069 .30901 L
.44093 .30901 L
.44113 .30901 L
.44135 .30901 L
.44145 .30901 L
.44155 .30901 L
.44165 .30901 L
.44174 .30901 L
.44185 .30901 L
.44191 .30901 L
.44197 .30901 L
.44203 .30901 L
.44209 .30901 L
.44215 .30901 L
.44221 .30901 L
.44226 .30901 L
.44231 .30901 L
.44237 .30901 L
.44243 .30901 L
.44253 .30901 L
.44263 .30901 L
.44284 .30901 L
.44306 .30901 L
.44348 .30901 L
.44425 .30901 L
.44596 .30901 L
.44751 .30902 L
.44829 .30902 L
.44914 .30902 L
.44952 .30902 L
Mistroke
.44993 .30902 L
.45031 .30902 L
.45066 .30902 L
.45085 .30902 L
.45106 .30902 L
.45125 .30902 L
.45133 .30902 L
.45142 .30902 L
.45152 .30902 L
.45161 .30902 L
.45167 .30902 L
.45172 .30902 L
.45182 .30902 L
.45192 .30902 L
.45202 .30902 L
.45208 .30902 L
.45213 .30902 L
.45224 .30902 L
.45243 .30902 L
.4526 .30902 L
.453 .30902 L
.45371 .30902 L
.45535 .30902 L
.45688 .30902 L
.45764 .30902 L
.45835 .30902 L
.45875 .30902 L
.45917 .30902 L
.45954 .30902 L
.45993 .30902 L
.46013 .30902 L
.46032 .30902 L
.4605 .30902 L
.46068 .30902 L
.46087 .30902 L
.46098 .30902 L
.46109 .30902 L
.46114 .30902 L
.4612 .30902 L
.46126 .30902 L
.46131 .30902 L
.46141 .30902 L
.46151 .30902 L
.46162 .30902 L
.46171 .30902 L
.46182 .30902 L
.46193 .30902 L
.46232 .30902 L
.46274 .30902 L
.4632 .30902 L
Mistroke
.46491 .30902 L
.46646 .30902 L
.46724 .30902 L
.46808 .30902 L
.46847 .30902 L
.46888 .30902 L
.46922 .30902 L
.46961 .30902 L
.46981 .30902 L
.47003 .30902 L
.47013 .30902 L
.47024 .30902 L
.47033 .30902 L
.47043 .30902 L
.47052 .30902 L
.47061 .30902 L
.47069 .30902 L
.47078 .30902 L
.47088 .30902 L
.47097 .30902 L
.47107 .30902 L
.47117 .30902 L
.47139 .30902 L
.47163 .30902 L
.47205 .30902 L
.47285 .30902 L
.47442 .30902 L
.47525 .30902 L
.47614 .30902 L
.477 .30902 L
.47778 .30902 L
.47815 .30902 L
.47856 .30902 L
.47875 .30902 L
.47895 .30902 L
.47912 .30902 L
.47931 .30902 L
.47941 .30902 L
.47952 .30902 L
.47963 .30902 L
.47968 .30902 L
.47974 .30902 L
.47979 .30902 L
.47985 .30902 L
.47995 .30902 L
.48004 .30902 L
.48014 .30902 L
.48024 .30902 L
.4803 .30902 L
.48035 .30902 L
Mistroke
.48056 .30902 L
.4808 .30902 L
.48103 .30902 L
.4818 .30902 L
.48265 .30902 L
.48436 .30902 L
.48591 .30902 L
.48669 .30902 L
.48713 .30902 L
.48753 .30902 L
.48788 .30902 L
.48809 .30902 L
.48827 .30902 L
.48847 .30902 L
.48857 .30902 L
.48868 .30902 L
.48877 .30902 L
.48886 .30902 L
.48895 .30902 L
.48905 .30902 L
.48914 .30902 L
.48924 .30902 L
.48935 .30902 L
.48945 .30902 L
.48962 .30902 L
.48981 .30902 L
.49023 .30902 L
.49062 .30902 L
.49208 .30902 L
.49375 .30902 L
.49449 .30902 L
.49529 .30902 L
.49567 .30902 L
.49607 .30902 L
.49641 .30902 L
.49679 .30902 L
.49701 .30902 L
.49722 .30902 L
.49741 .30902 L
.49751 .30902 L
.49762 .30902 L
.49773 .30902 L
.49783 .30902 L
.49792 .30902 L
.49802 .30902 L
.49811 .30902 L
.49819 .30902 L
.49828 .30902 L
.49838 .30902 L
.49848 .30902 L
Mistroke
.49859 .30902 L
.49881 .30902 L
.4992 .30902 L
.49966 .30902 L
.50009 .30902 L
.5017 .30902 L
.50319 .30902 L
.50403 .30902 L
.50444 .30902 L
.50481 .30902 L
.50519 .30902 L
.50559 .30902 L
.50582 .30902 L
.50602 .30902 L
.50622 .30902 L
.50633 .30902 L
.50643 .30902 L
.50652 .30902 L
.50663 .30902 L
.50668 .30902 L
.50674 .30902 L
.50684 .30902 L
.50693 .30902 L
.50703 .30902 L
.50714 .30902 L
.50723 .30902 L
.50728 .30902 L
.50734 .30902 L
.50746 .30902 L
.50766 .30902 L
.5079 .30902 L
.50812 .30902 L
.50896 .30902 L
.50976 .30902 L
.51125 .30902 L
.51203 .30902 L
.51286 .30902 L
.51356 .30902 L
.51396 .30902 L
.51434 .30902 L
.51473 .30902 L
.51496 .30902 L
.51507 .30902 L
.51517 .30902 L
.51527 .30902 L
.51537 .30902 L
.51547 .30902 L
.51555 .30902 L
.51565 .30902 L
.51575 .30902 L
Mistroke
.5158 .30902 L
.51586 .30902 L
.51596 .30902 L
.51606 .30902 L
.51615 .30902 L
.51636 .30902 L
.51655 .30902 L
.51674 .30902 L
.51745 .30902 L
.52048 .30902 L
.52124 .30902 L
.52204 .30902 L
.52245 .30902 L
.52291 .30902 L
.52311 .30902 L
.52332 .30902 L
.52351 .30902 L
.52371 .30902 L
.52392 .30902 L
.52403 .30902 L
.52409 .30902 L
.52414 .30902 L
.52424 .30902 L
.52433 .30902 L
.52443 .30902 L
.52448 .30902 L
.52453 .30902 L
.52459 .30902 L
.52465 .30902 L
.52476 .30902 L
.52487 .30902 L
.52496 .30902 L
.52519 .30902 L
.52542 .30902 L
.5262 .30902 L
.52704 .30902 L
.52874 .30902 L
.52955 .30902 L
.53029 .30902 L
.53106 .30902 L
.53147 .30902 L
.53168 .30902 L
.5319 .30902 L
.5321 .30902 L
.53227 .30902 L
.53236 .30902 L
.53245 .30902 L
.53254 .30902 L
.53262 .30902 L
.53273 .30902 L
Mistroke
.53282 .30902 L
.53293 .30902 L
.53298 .30902 L
.53304 .30902 L
.53313 .30902 L
.53322 .30902 L
.53333 .30902 L
.53342 .30902 L
.53363 .30902 L
.53382 .30902 L
.53426 .30902 L
.53505 .30902 L
.53654 .30902 L
.53804 .30902 L
.53845 .30902 L
.53889 .30902 L
.53931 .30902 L
.53969 .30902 L
.54006 .30902 L
.54026 .30902 L
.54046 .30902 L
.54069 .30902 L
.54079 .30902 L
.5409 .30902 L
.541 .30902 L
.54105 .30902 L
.54111 .30902 L
.54121 .30902 L
.5413 .30902 L
.54136 .30902 L
.54141 .30902 L
.54152 .30902 L
.54158 .30902 L
.54164 .30902 L
.54176 .30902 L
.54186 .30902 L
.54196 .30902 L
.54219 .30902 L
.54258 .30902 L
.54299 .30902 L
.54459 .30902 L
.54605 .30902 L
.54685 .30902 L
.54761 .30902 L
.54803 .30902 L
.54842 .30902 L
.54862 .30902 L
.54884 .30902 L
.54896 .30902 L
.54908 .30902 L
Mistroke
.54919 .30902 L
.54929 .30902 L
.54939 .30902 L
.54949 .30902 L
.54959 .30902 L
.54964 .30902 L
.54969 .30902 L
.54978 .30902 L
.54987 .30902 L
.54997 .30902 L
.55006 .30902 L
.55017 .30902 L
.55028 .30902 L
.55047 .30902 L
.5509 .30902 L
.55172 .30902 L
.5526 .30902 L
.55415 .30902 L
.55504 .30902 L
.55544 .30902 L
.55587 .30902 L
.55625 .30902 L
.55666 .30902 L
.55684 .30902 L
.55703 .30902 L
.55721 .30902 L
.55738 .30902 L
.55748 .30902 L
.55759 .30902 L
.5577 .30902 L
.55777 .30902 L
.55782 .30902 L
.55793 .30902 L
.55802 .30902 L
.55808 .30902 L
.55813 .30902 L
.55824 .30902 L
.55834 .30902 L
.55843 .30902 L
.55864 .30902 L
.55883 .30902 L
.55902 .30902 L
.5598 .30902 L
.56063 .30902 L
.56211 .30902 L
.56287 .30902 L
.56329 .30902 L
.56369 .30902 L
.56406 .30902 L
.56446 .30902 L
Mistroke
.56482 .30902 L
.56516 .30902 L
.56535 .30902 L
.56553 .30902 L
.56573 .30902 L
.56583 .30902 L
.56588 .30902 L
.56593 .30902 L
.56603 .30902 L
.56611 .30902 L
.56621 .30902 L
.56631 .30902 L
.5664 .30902 L
.56649 .30902 L
.56657 .30902 L
.56666 .30902 L
.56687 .30902 L
.56707 .30902 L
.56751 .30902 L
.56831 .30902 L
.56997 .30902 L
.57077 .30902 L
.5715 .30902 L
.57187 .30902 L
.57227 .30902 L
.57265 .30902 L
.57299 .30902 L
.57317 .30902 L
.57336 .30902 L
.57357 .30902 L
.57376 .30902 L
.57387 .30902 L
.57392 .30902 L
.57398 .30902 L
.57403 .30902 L
.57409 .30902 L
.57419 .30902 L
.57428 .30902 L
.57439 .30902 L
.57448 .30902 L
.57457 .30902 L
.57468 .30902 L
.57477 .30902 L
.57496 .30902 L
.57536 .30902 L
.5761 .30902 L
.57776 .30902 L
.57854 .30902 L
.57937 .30902 L
.58008 .30902 L
Mistroke
.58048 .30902 L
.58085 .30902 L
.58105 .30902 L
.58125 .30902 L
.58148 .30902 L
.58158 .30902 L
.58169 .30902 L
.58179 .30902 L
.58188 .30902 L
.58197 .30902 L
.58207 .30902 L
.58217 .30902 L
.58227 .30902 L
.58237 .30902 L
.58243 .30902 L
.58248 .30902 L
.58258 .30902 L
.58267 .30902 L
.58285 .30902 L
.58304 .30902 L
.58325 .30902 L
.58397 .30902 L
.58566 .30902 L
.58646 .30902 L
.58721 .30902 L
.58797 .30902 L
.58838 .30902 L
.58858 .30902 L
.58881 .30902 L
.58902 .30902 L
.58922 .30902 L
.5894 .30902 L
.5895 .30902 L
.5896 .30902 L
.58969 .30902 L
.58978 .30902 L
.58986 .30902 L
.58995 .30902 L
.59004 .30902 L
.59013 .30902 L
.59022 .30902 L
.59032 .30902 L
.59041 .30902 L
.59051 .30902 L
.59062 .30902 L
.59072 .30902 L
.59108 .30902 L
.59147 .30902 L
.59189 .30902 L
.59336 .30902 L
Mistroke
.59418 .30902 L
.59507 .30902 L
.59548 .30902 L
.59591 .30902 L
.59628 .30902 L
.59669 .30902 L
.59689 .30902 L
.59711 .30902 L
.59731 .30902 L
.59741 .30902 L
.5975 .30902 L
.5976 .30902 L
.59769 .30902 L
.59778 .30902 L
.59787 .30902 L
.59796 .30902 L
.59805 .30902 L
.59816 .30902 L
.59825 .30902 L
.59836 .30902 L
.59847 .30902 L
.59867 .30902 L
.59906 .30902 L
.59993 .30902 L
.60149 .30902 L
.60232 .30902 L
.60277 .30902 L
.60321 .30902 L
.60361 .30902 L
.60406 .30902 L
.60425 .30902 L
.60446 .30902 L
.60466 .30902 L
.60484 .30902 L
.60504 .30902 L
.60514 .30902 L
.60525 .30902 L
.60535 .30902 L
.60544 .30902 L
.60554 .30902 L
.60564 .30902 L
.60573 .30902 L
.60583 .30902 L
.60593 .30902 L
.60602 .30902 L
.6061 .30902 L
.60619 .30902 L
.60637 .30902 L
.60676 .30902 L
.60718 .30902 L
Mistroke
.60792 .30902 L
.60873 .30902 L
.60959 .30902 L
.61042 .30902 L
.61118 .30902 L
.61154 .30902 L
.61193 .30902 L
.61212 .30902 L
.61231 .30902 L
.61247 .30902 L
.61265 .30902 L
.61276 .30902 L
.61285 .30902 L
.61295 .30902 L
.61305 .30902 L
.61314 .30902 L
.61322 .30902 L
.61331 .30902 L
.61341 .30902 L
.61351 .30902 L
.61356 .30902 L
.61361 .30902 L
.61372 .30902 L
.61383 .30902 L
.61404 .30902 L
.61422 .30902 L
.61458 .30902 L
.61498 .30902 L
.61569 .30902 L
.61725 .30902 L
.61814 .30902 L
.61854 .30902 L
.61897 .30902 L
.61935 .30902 L
.61955 .30902 L
.61976 .30902 L
.61996 .30902 L
.62014 .30902 L
.62032 .30902 L
.62049 .30902 L
.62058 .30902 L
.62069 .30902 L
.62074 .30902 L
.6208 .30902 L
.6209 .30902 L
.621 .30902 L
.62109 .30902 L
.62118 .30902 L
.62127 .30902 L
.62138 .30902 L
Mistroke
.62149 .30902 L
.62172 .30902 L
.62212 .30902 L
.62293 .30902 L
.62367 .30902 L
.62454 .30902 L
.62535 .30902 L
.62608 .30902 L
.62649 .30902 L
.62686 .30902 L
.62727 .30902 L
.62751 .30902 L
.62772 .30902 L
.6279 .30902 L
.62801 .30902 L
.62811 .30902 L
.62821 .30902 L
.62831 .30902 L
.62836 .30902 L
.62842 .30902 L
.62853 .30902 L
.62858 .30902 L
.62863 .30902 L
.62873 .30902 L
.62884 .30902 L
.62895 .30902 L
.62916 .30902 L
.62935 .30902 L
.62972 .30902 L
.63011 .30902 L
.63179 .30902 L
.63261 .30902 L
.63304 .30902 L
.63349 .30902 L
.63389 .30902 L
.63433 .30902 L
.63453 .30902 L
.63473 .30902 L
.63493 .30902 L
.63511 .30902 L
.6353 .30902 L
.6354 .30902 L
.63551 .30902 L
.63561 .30902 L
.6357 .30902 L
.63579 .30902 L
.63588 .30902 L
.63598 .30902 L
.63603 .30902 L
.63609 .30902 L
Mistroke
.63618 .30902 L
.63628 .30902 L
.63639 .30902 L
.63649 .30902 L
.63672 .30902 L
.63715 .30902 L
.63754 .30902 L
.63841 .30902 L
.63923 .30902 L
.64009 .30902 L
.64083 .30902 L
.64125 .30902 L
.64163 .30902 L
.64183 .30902 L
.64204 .30902 L
.64222 .30902 L
.64242 .30902 L
.64259 .30902 L
.64279 .30902 L
.64287 .30902 L
.64297 .30902 L
.64305 .30902 L
.64313 .30902 L
.64319 .30902 L
.64324 .30902 L
.64334 .30902 L
.64339 .30902 L
.64345 .30902 L
.64351 .30902 L
.64356 .30902 L
.64366 .30902 L
.64376 .30902 L
.64387 .30902 L
.64397 .30902 L
.64434 .30902 L
.64473 .30902 L
.64632 .30902 L
.64716 .30902 L
.64762 .30902 L
.64805 .30902 L
.64846 .30902 L
.64884 .30902 L
.64926 .30902 L
.64948 .30902 L
.64971 .30902 L
.6499 .30902 L
.65009 .30902 L
.65019 .30902 L
.65028 .30902 L
.65036 .30902 L
Mistroke
.65045 .30902 L
.65054 .30902 L
.65065 .30902 L
.65074 .30902 L
.65083 .30902 L
.65094 .30902 L
.65103 .30902 L
.65114 .30902 L
.65125 .30902 L
.65165 .30902 L
.65202 .30902 L
.65284 .30902 L
.65432 .30902 L
.65512 .30902 L
.65586 .30902 L
.65625 .30902 L
.65668 .30902 L
.65689 .30902 L
.65712 .30902 L
.65723 .30902 L
.65734 .30902 L
.65743 .30902 L
.65754 .30902 L
.65764 .30902 L
.65773 .30902 L
.65781 .30902 L
.65791 .30902 L
.65801 .30902 L
.6581 .30902 L
.6582 .30902 L
.65826 .30902 L
.65831 .30902 L
.65852 .30902 L
.65874 .30902 L
.65914 .30902 L
.66062 .30902 L
.66144 .30902 L
.66221 .30902 L
.66302 .30902 L
.66344 .30902 L
.66367 .30902 L
.6639 .30902 L
.6641 .30902 L
.66433 .30902 L
.66453 .30902 L
.66472 .30902 L
.66483 .30902 L
.66488 .30902 L
.66494 .30902 L
.66504 .30902 L
Mistroke
.66509 .30902 L
.66514 .30902 L
.6652 .30902 L
.66527 .30902 L
.66533 .30902 L
.66539 .30902 L
.66549 .30902 L
.6656 .30902 L
.6658 .30902 L
.666 .30902 L
.66637 .30902 L
.66722 .30902 L
.6688 .30902 L
.66923 .30902 L
.6697 .30902 L
.67013 .30902 L
.67053 .30902 L
.67094 .30902 L
.67116 .30902 L
.67139 .30902 L
.67159 .30902 L
.67178 .30902 L
.67188 .30902 L
.67198 .30902 L
.67203 .30902 L
.67209 .30902 L
.67215 .30902 L
.6722 .30902 L
.67229 .30902 L
.67238 .30902 L
.67247 .30902 L
.67255 .30902 L
.67264 .30902 L
.67274 .30902 L
.67293 .30902 L
.67313 .30902 L
.67334 .30902 L
.67372 .30902 L
.67531 .30902 L
.67616 .30902 L
.67662 .30902 L
.67705 .30902 L
.67746 .30902 L
.67784 .30902 L
.67826 .30902 L
.6785 .30902 L
.67872 .30902 L
.6789 .30902 L
.679 .30902 L
.6791 .30902 L
Mistroke
.67919 .30902 L
.67928 .30902 L
.67937 .30902 L
.67945 .30902 L
.67955 .30902 L
.67964 .30902 L
.67974 .30902 L
.67984 .30902 L
.68006 .30902 L
.68026 .30902 L
.68105 .30902 L
.68179 .30902 L
.68265 .30902 L
.68346 .30902 L
.68418 .30902 L
.68459 .30902 L
.68496 .30902 L
.68534 .30902 L
.68556 .30902 L
.68577 .30902 L
.68588 .30902 L
.68598 .30902 L
.68607 .30902 L
.68618 .30902 L
.68623 .30902 L
.68629 .30902 L
.68635 .30902 L
.6864 .30902 L
.68651 .30902 L
.68656 .30902 L
.68661 .30902 L
.68671 .30902 L
.6868 .30902 L
.687 .30902 L
.6872 .30902 L
.68741 .30902 L
.68814 .30902 L
.68894 .30902 L
.68981 .30902 L
.69021 .30902 L
.69064 .30902 L
.69101 .30902 L
.69142 .30902 L
.69165 .30902 L
.69187 .30902 L
.69208 .30902 L
.6923 .30902 L
.69251 .30902 L
.69269 .30902 L
.6928 .30902 L
Mistroke
.69289 .30902 L
.69301 .30902 L
.69311 .30902 L
.69321 .30902 L
.69327 .30902 L
.69332 .30902 L
.69341 .30902 L
.69351 .30902 L
.6936 .30902 L
.69369 .30902 L
.69378 .30902 L
.69388 .30902 L
.6941 .30902 L
.69431 .30902 L
.6947 .30902 L
.69618 .30902 L
.69695 .30902 L
.69738 .30902 L
.69778 .30902 L
.69814 .30902 L
.69848 .30902 L
.69885 .30902 L
.69906 .30902 L
.69926 .30902 L
.69945 .30902 L
.69964 .30902 L
.69973 .30902 L
.69983 .30902 L
.69994 .30902 L
.70004 .30902 L
.70013 .30902 L
.70022 .30902 L
.70031 .30902 L
.70039 .30902 L
.70049 .30902 L
.70059 .30902 L
.70069 .30902 L
.70078 .30902 L
.70099 .30902 L
.7012 .30902 L
.70158 .30902 L
.70244 .30902 L
.70392 .30902 L
.70432 .30902 L
.70476 .30902 L
.70513 .30902 L
.70554 .30902 L
.70576 .30902 L
.70597 .30902 L
.70616 .30902 L
Mistroke
.70638 .30902 L
.70647 .30902 L
.70657 .30902 L
.70666 .30902 L
.70675 .30902 L
.70685 .30902 L
.70695 .30902 L
.70705 .30902 L
.70714 .30902 L
.7072 .30902 L
.70725 .30902 L
.7073 .30902 L
.70736 .30902 L
.70746 .30902 L
.70757 .30902 L
.70777 .30902 L
.70796 .30902 L
.70883 .30902 L
.71033 .30902 L
.71074 .30902 L
.71118 .30902 L
.71155 .30902 L
.71196 .30902 L
.71237 .30902 L
.71277 .30902 L
.71299 .30902 L
.71312 .30902 L
.71323 .30902 L
.71344 .30902 L
.71355 .30902 L
.7136 .30902 L
.71366 .30902 L
.71371 .30902 L
.71377 .30902 L
.71387 .30902 L
.71393 .30902 L
.71399 .30902 L
.71404 .30902 L
.7141 .30902 L
.7142 .30902 L
.71425 .30902 L
.71431 .30902 L
.71451 .30902 L
.7147 .30902 L
.71488 .30902 L
.71528 .30902 L
.71695 .30902 L
.71769 .30902 L
.71808 .30902 L
.7185 .30902 L
Mistroke
.7189 .30902 L
.71928 .30902 L
.71945 .30902 L
.71965 .30902 L
.71983 .30902 L
.72 .30902 L
.72019 .30902 L
.72029 .30902 L
.72035 .30902 L
.7204 .30902 L
.72046 .30902 L
.72051 .30902 L
.72057 .30902 L
.72063 .30902 L
.72068 .30902 L
.72073 .30902 L
.72083 .30902 L
.72092 .30902 L
.72102 .30902 L
.7212 .30902 L
.72139 .30902 L
.72159 .30902 L
.72329 .30902 L
.72409 .30902 L
.72483 .30902 L
.72521 .30902 L
.7256 .30902 L
.726 .30902 L
.72622 .30902 L
.72644 .30902 L
.72662 .30902 L
.72672 .30902 L
.72682 .30902 L
.72698 .30902 L
.72707 .30902 L
.72717 .30902 L
.72727 .30902 L
.72733 .30902 L
.72738 .30902 L
.72748 .30902 L
.72758 .30902 L
.72767 .30902 L
.72776 .30902 L
.72795 .30902 L
.72816 .30902 L
.72835 .30902 L
.72879 .30902 L
.72958 .30902 L
.73029 .30902 L
.73107 .30902 L
Mistroke
.73151 .30902 L
.73192 .30902 L
.7323 .30902 L
.7325 .30902 L
.73271 .30902 L
.73291 .30902 L
.73308 .30902 L
.73326 .30902 L
.73343 .30902 L
.73352 .30902 L
.73362 .30902 L
.73371 .30902 L
.7338 .30902 L
.7339 .30902 L
.73396 .30902 L
.73401 .30902 L
.73411 .30902 L
.73421 .30902 L
.73431 .30902 L
.73441 .30902 L
.73461 .30902 L
.73497 .30902 L
.73579 .30902 L
.73727 .30902 L
.73803 .30902 L
.73846 .30902 L
.73886 .30902 L
.73908 .30902 L
.73929 .30902 L
.73948 .30902 L
.73968 .30902 L
.7399 .30902 L
.7401 .30902 L
.74022 .30902 L
.74028 .30902 L
.74034 .30902 L
.74044 .30902 L
.7405 .30902 L
.74055 .30902 L
.74065 .30902 L
.74071 .30902 L
.74076 .30902 L
.74085 .30902 L
.74095 .30902 L
.74113 .30902 L
.74132 .30902 L
.74174 .30902 L
.74213 .30902 L
.74361 .30902 L
.744 .30902 L
Mistroke
.74444 .30902 L
.74482 .30902 L
.74523 .30902 L
.74563 .30902 L
.746 .30902 L
.74618 .30902 L
.74637 .30902 L
.74655 .30902 L
.74672 .30902 L
.74682 .30902 L
.74691 .30902 L
.747 .30902 L
.74709 .30902 L
.74719 .30902 L
.74725 .30902 L
.7473 .30902 L
.7474 .30902 L
.7475 .30902 L
.74759 .30902 L
.74768 .30902 L
.74785 .30902 L
.74823 .30902 L
.74988 .30902 L
.75065 .30902 L
.75107 .30902 L
.75147 .30902 L
.75184 .30902 L
.75224 .30902 L
.75242 .30902 L
.7526 .30902 L
.75277 .30902 L
.75294 .30902 L
.75305 .30902 L
.75314 .30902 L
.75324 .30902 L
.75334 .30902 L
.75343 .30902 L
.75351 .30902 L
.7536 .30902 L
.7537 .30902 L
.7538 .30902 L
.75385 .30902 L
.7539 .30902 L
.75401 .30902 L
.75412 .30902 L
.75432 .30902 L
.75451 .30902 L
.75527 .30902 L
.75598 .30902 L
.75676 .30902 L
Mistroke
.75718 .30902 L
.75758 .30902 L
.75795 .30902 L
.75828 .30902 L
.75866 .30902 L
.75887 .30902 L
.75906 .30902 L
.75924 .30902 L
.75944 .30902 L
.75955 .30902 L
.75965 .30902 L
.75975 .30902 L
.75985 .30902 L
.75993 .30902 L
.76003 .30902 L
.76012 .30902 L
.7602 .30902 L
.76029 .30902 L
.76039 .30902 L
.76049 .30902 L
.76058 .30902 L
.7608 .30902 L
.761 .30902 L
.76138 .30902 L
.76224 .30902 L
.76303 .30902 L
.76386 .30902 L
.7642 .30902 L
.76457 .30902 L
.76497 .30902 L
.76534 .30902 L
.76555 .30902 L
.76577 .30902 L
.76596 .30902 L
.76606 .30902 L
.76616 .30902 L
.76622 .30902 L
.76628 .30902 L
.76633 .30902 L
.76639 .30902 L
.76644 .30902 L
.76649 .30902 L
.76659 .30902 L
.76665 .30902 L
.76671 .30902 L
.76677 .30902 L
.76683 .30902 L
.76694 .30902 L
.76705 .30902 L
.76726 .30902 L
Mistroke
.76746 .30902 L
.76789 .30902 L
.76867 .30902 L
.76941 .30902 L
.7702 .30902 L
.77061 .30902 L
.77107 .30902 L
.77127 .30902 L
.77148 .30902 L
.77187 .30902 L
.77206 .30902 L
.77217 .30902 L
.77226 .30902 L
.77236 .30902 L
.77246 .30902 L
.77255 .30902 L
.77264 .30902 L
.77274 .30902 L
.77279 .30902 L
.77285 .30902 L
.77291 .30902 L
.77297 .30902 L
.77302 .30902 L
.77307 .30902 L
.77317 .30902 L
.77323 .30902 L
.77328 .30902 L
.77348 .30902 L
.77369 .30902 L
.77389 .30902 L
.77435 .30902 L
.77517 .30902 L
.7759 .30902 L
.77668 .30902 L
.77713 .30902 L
.77754 .30902 L
.77774 .30902 L
.77795 .30902 L
.77816 .30902 L
.77834 .30902 L
.77853 .30902 L
.77863 .30902 L
.77873 .30902 L
.77882 .30902 L
.77891 .30902 L
.77901 .30902 L
.7791 .30902 L
.77916 .30902 L
.77921 .30902 L
.77926 .30902 L
Mistroke
.77932 .30902 L
.77942 .30902 L
.77948 .30902 L
.77954 .30902 L
.77964 .30902 L
.77973 .30902 L
.77993 .30902 L
.78035 .30902 L
.7808 .30902 L
.78162 .30902 L
.78244 .30902 L
.7832 .30902 L
.78359 .30902 L
.78401 .30902 L
.78423 .30902 L
.78447 .30902 L
.78467 .30902 L
.78478 .30902 L
.78489 .30902 L
.78499 .30902 L
.78509 .30902 L
.7852 .30902 L
.78526 .30902 L
.78531 .30902 L
.78541 .30902 L
.78547 .30902 L
.78552 .30902 L
.78561 .30902 L
.78571 .30902 L
.78581 .30902 L
.7859 .30902 L
.7861 .30902 L
.78629 .30902 L
.78646 .30902 L
.78814 .30902 L
.78893 .30902 L
.78936 .30902 L
.78976 .30902 L
.7901 .30902 L
.79046 .30902 L
.79067 .30902 L
.79087 .30902 L
.79105 .30902 L
.79115 .30902 L
.79124 .30902 L
.79133 .30902 L
.79143 .30902 L
.79152 .30902 L
.79163 .30902 L
.79172 .30902 L
Mistroke
.79182 .30902 L
.79191 .30902 L
.79199 .30902 L
.79205 .30902 L
.7921 .30902 L
.7922 .30902 L
.79242 .30902 L
.79283 .30902 L
.79364 .30902 L
.79451 .30902 L
.79494 .30902 L
.79534 .30902 L
.79572 .30902 L
.79609 .30902 L
.79643 .30902 L
.79679 .30902 L
.797 .30902 L
.79719 .30902 L
.79737 .30902 L
.79746 .30902 L
.79756 .30902 L
.79766 .30902 L
.79775 .30902 L
.79785 .30902 L
.7979 .30902 L
.79795 .30902 L
.79804 .30902 L
.79813 .30902 L
.79823 .30902 L
.79832 .30902 L
.79843 .30902 L
.79853 .30902 L
.79873 .30902 L
.79916 .30902 L
.79998 .30902 L
.80085 .30902 L
.80128 .30902 L
.80169 .30902 L
.80208 .30902 L
.80244 .30902 L
.80279 .30902 L
.80315 .30902 L
.80334 .30902 L
.80352 .30902 L
.80362 .30902 L
.80371 .30902 L
.80382 .30902 L
.80392 .30902 L
.80401 .30902 L
.80411 .30902 L
Mistroke
.8042 .30902 L
.80429 .30902 L
.80438 .30902 L
.80448 .30902 L
.80459 .30902 L
.80469 .30902 L
.80509 .30902 L
.80551 .30902 L
.80699 .30902 L
.80781 .30902 L
.80828 .30902 L
.80871 .30902 L
.80908 .30902 L
.80929 .30902 L
.80949 .30902 L
.8096 .30902 L
.8097 .30902 L
.80979 .30902 L
.80989 .30902 L
.80995 .30902 L
.81 .30902 L
.8101 .30902 L
.81015 .30902 L
.81021 .30902 L
.81027 .30902 L
.81032 .30902 L
.81042 .30902 L
.81052 .30902 L
.81061 .30902 L
.8107 .30902 L
.81091 .30902 L
.81111 .30902 L
.81184 .30902 L
.81269 .30902 L
.81349 .30902 L
.81422 .30902 L
.81462 .30902 L
.815 .30902 L
.81519 .30902 L
.81538 .30902 L
.81558 .30902 L
.8158 .30902 L
.81591 .30902 L
.81603 .30902 L
.81608 .30902 L
.81614 .30902 L
.81625 .30902 L
.81635 .30902 L
.81644 .30902 L
.81654 .30902 L
Mistroke
.8166 .30902 L
.81665 .30902 L
.81674 .30902 L
.81683 .30902 L
.81703 .30902 L
.81744 .30902 L
.81818 .30902 L
.81899 .30902 L
.81943 .30902 L
.81984 .30902 L
.82025 .30902 L
.82062 .30902 L
.82102 .30902 L
.82125 .30902 L
.82146 .30902 L
.82164 .30902 L
.82183 .30902 L
.82199 .30902 L
.82209 .30902 L
.82217 .30902 L
.82227 .30902 L
.82237 .30902 L
.82245 .30902 L
.82255 .30902 L
.82265 .30902 L
.8227 .30902 L
.82275 .30902 L
.82295 .30902 L
.82313 .30902 L
.82334 .30902 L
.82375 .30902 L
.82449 .30902 L
.82536 .30902 L
.82616 .30902 L
.82655 .30902 L
.82675 .30902 L
.82697 .30902 L
.82715 .30902 L
.82736 .30902 L
.82754 .30902 L
.82773 .30902 L
.82783 .30902 L
.82795 .30902 L
.82805 .30902 L
.82814 .30902 L
.8282 .30902 L
.82826 .30902 L
.82836 .30902 L
.82842 .30902 L
.82847 .30902 L
Mistroke
.82853 .30902 L
.82859 .30902 L
.82869 .30902 L
.82879 .30902 L
.82889 .30902 L
.82898 .30902 L
.82941 .30902 L
.83021 .30902 L
.83106 .30902 L
.83148 .30902 L
.83187 .30902 L
.83222 .30902 L
.8326 .30902 L
.83297 .30902 L
.83318 .30902 L
.83337 .30902 L
.83354 .30902 L
.83371 .30902 L
.8338 .30902 L
.8339 .30902 L
.83398 .30902 L
.83407 .30902 L
.83417 .30902 L
.83427 .30902 L
.83432 .30902 L
.83438 .30902 L
.83448 .30902 L
.83458 .30902 L
.83468 .30902 L
.83474 .30902 L
.83479 .30902 L
.8349 .30902 L
.83509 .30902 L
.8353 .30902 L
.83567 .30902 L
.83724 .30902 L
.83767 .30902 L
.83813 .30902 L
.83856 .30902 L
.83896 .30902 L
.83915 .30902 L
.83936 .30902 L
.83954 .30902 L
.83974 .30902 L
.83985 .30902 L
.83995 .30902 L
.84006 .30902 L
.84011 .30902 L
.84017 .30902 L
.84028 .30902 L
Mistroke
.84033 .30902 L
.84039 .30902 L
.84049 .30902 L
.84058 .30902 L
.84067 .30902 L
.84077 .30902 L
.84097 .30902 L
.84132 .30902 L
.84213 .30902 L
.84292 .30902 L
.84368 .30902 L
.8441 .30902 L
.84456 .30902 L
.84476 .30902 L
.84498 .30902 L
.84516 .30902 L
.84536 .30902 L
.84557 .30902 L
.84568 .30902 L
.84579 .30902 L
.84589 .30902 L
.84598 .30902 L
.84603 .30902 L
.84609 .30902 L
.84619 .30902 L
.84624 .30902 L
.84629 .30902 L
.84635 .30902 L
.84641 .30902 L
.84647 .30902 L
.84654 .30902 L
.84659 .30902 L
.84665 .30902 L
.84687 .30902 L
.84708 .30902 L
.8487 .30902 L
.84911 .30902 L
.84955 .30902 L
.84993 .30902 L
.85034 .30902 L
.85071 .30902 L
.85092 .30902 L
.85112 .30902 L
.8513 .30902 L
.85147 .30902 L
.85156 .30902 L
.85166 .30902 L
.85175 .30902 L
.85184 .30902 L
.85189 .30902 L
Mistroke
.85194 .30902 L
.85204 .30902 L
.8521 .30902 L
.85216 .30902 L
.85221 .30902 L
.85226 .30902 L
.85236 .30902 L
.85242 .30902 L
.85247 .30902 L
.85267 .30902 L
.85284 .30902 L
.85303 .30902 L
.85342 .30902 L
.8543 .30902 L
.85511 .30902 L
.85549 .30902 L
.8559 .30902 L
.8563 .30902 L
.85666 .30902 L
.85688 .30902 L
.85709 .30902 L
.85727 .30902 L
.85747 .30902 L
.85758 .30902 L
.85769 .30902 L
.85775 .30902 L
.85781 .30902 L
.85787 .30902 L
.85792 .30902 L
.85803 .30902 L
.85808 .30902 L
.85814 .30902 L
.85823 .30902 L
.85834 .30902 L
.85843 .30902 L
.85853 .30902 L
.85873 .30902 L
.85909 .30902 L
.8599 .30902 L
.86066 .30902 L
.86137 .30902 L
.86176 .30902 L
.86219 .30902 L
.86238 .30902 L
.86258 .30902 L
.86277 .30902 L
.86294 .30902 L
.86314 .30902 L
.86325 .30902 L
.86335 .30902 L
Mistroke
.86345 .30902 L
.86354 .30902 L
.86364 .30902 L
.86374 .30902 L
.8638 .30902 L
.86386 .30902 L
.86392 .30902 L
.86398 .30902 L
.86404 .30902 L
.86409 .30902 L
.8642 .30902 L
.86431 .30902 L
.86441 .30902 L
.86462 .30902 L
.86629 .30902 L
.86702 .30902 L
.86743 .30902 L
.86782 .30902 L
.8682 .30902 L
.86854 .30902 L
.86872 .30902 L
.86892 .30902 L
.86902 .30902 L
.86913 .30902 L
.86923 .30902 L
.86932 .30902 L
.86942 .30902 L
.86952 .30902 L
.86961 .30902 L
.86971 .30902 L
.86982 .30902 L
.86988 .30902 L
.86993 .30902 L
.87014 .30902 L
.87032 .30902 L
.87053 .30902 L
.8709 .30902 L
.87165 .30902 L
.87246 .30902 L
.87292 .30902 L
.87334 .30902 L
.87375 .30902 L
.87395 .30902 L
.87417 .30902 L
.87439 .30902 L
.87459 .30902 L
.87477 .30902 L
.87487 .30902 L
.87496 .30902 L
.87506 .30902 L
Mistroke
.87516 .30902 L
.87526 .30902 L
.87532 .30902 L
.87537 .30902 L
.87543 .30902 L
.87548 .30902 L
.87553 .30902 L
.87559 .30902 L
.8757 .30902 L
.87581 .30902 L
.876 .30902 L
.87618 .30902 L
.87659 .30902 L
.87732 .30902 L
.87805 .30902 L
.87845 .30902 L
.87884 .30902 L
.87928 .30902 L
.8795 .30902 L
.87969 .30902 L
.87988 .30902 L
.88008 .30902 L
.88028 .30902 L
.88039 .30902 L
.88049 .30902 L
.88059 .30902 L
.88068 .30902 L
.88078 .30902 L
.88084 .30902 L
.88089 .30902 L
.88099 .30902 L
.88109 .30902 L
.88119 .30902 L
.88125 .30902 L
.8813 .30902 L
.8814 .30902 L
.88149 .30902 L
.88169 .30902 L
.88205 .30902 L
.88292 .30902 L
.88372 .30902 L
.88446 .30902 L
.88488 .30902 L
.88525 .30902 L
.88546 .30902 L
.88566 .30902 L
.88588 .30902 L
.88599 .30902 L
.88611 .30902 L
.88621 .30902 L
Mistroke
.88631 .30902 L
.8864 .30902 L
.88649 .30902 L
.8866 .30902 L
.88669 .30902 L
.88675 .30902 L
.8868 .30902 L
.88686 .30902 L
.88691 .30902 L
.88701 .30902 L
.88707 .30902 L
.88712 .30902 L
.88731 .30902 L
.88754 .30902 L
.88775 .30902 L
.88854 .30902 L
.88925 .30902 L
.89002 .30902 L
.89043 .30902 L
.89081 .30902 L
.89121 .30902 L
.89143 .30902 L
.89164 .30902 L
.89173 .30902 L
.89182 .30902 L
.892 .30902 L
.8921 .30902 L
.89219 .30902 L
.89229 .30902 L
.89234 .30902 L
.8924 .30902 L
.89248 .30902 L
.89256 .30902 L
.89265 .30902 L
.89275 .30902 L
.89285 .30902 L
.89294 .30902 L
.89312 .30902 L
.89459 .30902 L
.89499 .30902 L
.89542 .30902 L
.8958 .30902 L
.8962 .30902 L
.89643 .30902 L
.89663 .30902 L
.89684 .30902 L
.89704 .30902 L
.89723 .30902 L
.8974 .30902 L
.8975 .30902 L
Mistroke
.89759 .30902 L
.8977 .30902 L
.8978 .30902 L
.8979 .30902 L
.898 .30902 L
.89805 .30902 L
.89811 .30902 L
.89821 .30902 L
.89831 .30902 L
.89842 .30902 L
.8986 .30902 L
.89882 .30902 L
.89902 .30902 L
.89949 .30902 L
.9002 .30902 L
.90097 .30902 L
.90141 .30902 L
.90181 .30902 L
.90201 .30902 L
.90221 .30902 L
.90259 .30902 L
.90279 .30902 L
.903 .30902 L
.90311 .30902 L
.90322 .30902 L
.90328 .30902 L
.90333 .30902 L
.90343 .30902 L
.90353 .30902 L
.90362 .30902 L
.90372 .30902 L
.9038 .30902 L
.9039 .30902 L
.90396 .30902 L
.90401 .30902 L
.9042 .30902 L
.90441 .30902 L
.9046 .30902 L
.90503 .30902 L
.9059 .30902 L
.9063 .30902 L
.90674 .30902 L
.90713 .30902 L
.90754 .30902 L
.90791 .30902 L
.90812 .30902 L
.90831 .30902 L
.90849 .30902 L
.90866 .30902 L
.90875 .30902 L
Mistroke
.90885 .30902 L
.90894 .30902 L
.90903 .30902 L
.90913 .30902 L
.90918 .30902 L
.90924 .30902 L
.90934 .30902 L
.90944 .30902 L
.90949 .30902 L
.90955 .30902 L
.90965 .30902 L
.90988 .30902 L
.91026 .30902 L
.91068 .30902 L
.91145 .30902 L
.91217 .30902 L
.91253 .30902 L
.91292 .30902 L
.91314 .30902 L
.91336 .30902 L
.91357 .30902 L
.91376 .30902 L
.91396 .30902 L
.91406 .30902 L
.91417 .30902 L
.91428 .30902 L
.91437 .30902 L
.91447 .30902 L
.91456 .30902 L
.91467 .30902 L
.91473 .30902 L
.91478 .30902 L
.91488 .30902 L
.91498 .30902 L
.91504 .30902 L
.9151 .30902 L
.9152 .30902 L
.91544 .30902 L
.91705 .30902 L
.91749 .30902 L
.91795 .30902 L
.91835 .30902 L
.91857 .30902 L
.91878 .30902 L
.91899 .30902 L
.91921 .30902 L
.91941 .30902 L
.91959 .30902 L
.91969 .30902 L
.91979 .30902 L
Mistroke
.91989 .30902 L
.91995 .30902 L
.92001 .30902 L
.92007 .30902 L
.92012 .30902 L
.92018 .30902 L
.92024 .30902 L
.9203 .30902 L
.92035 .30902 L
.92045 .30902 L
.92054 .30902 L
.92064 .30902 L
.92084 .30902 L
.9212 .30902 L
.922 .30902 L
.92281 .30902 L
.9232 .30902 L
.92357 .30902 L
.92399 .30902 L
.92421 .30902 L
.92445 .30902 L
.92463 .30902 L
.92483 .30902 L
.92494 .30902 L
.92504 .30902 L
.92515 .30902 L
.92525 .30902 L
.92534 .30902 L
.92545 .30902 L
.92554 .30902 L
.92563 .30902 L
.92572 .30902 L
.92582 .30902 L
.92588 .30902 L
.92593 .30902 L
.92603 .30902 L
.92613 .30902 L
.92623 .30902 L
.92641 .30902 L
.92676 .30902 L
.92764 .30902 L
.92842 .30902 L
.92882 .30902 L
.92924 .30902 L
.92964 .30902 L
.93001 .30902 L
.93021 .30902 L
.9304 .30902 L
.9306 .30902 L
.93072 .30902 L
Mistroke
.93082 .30902 L
.93088 .30902 L
.93093 .30902 L
.93104 .30902 L
.93109 .30902 L
.93115 .30902 L
.93121 .30902 L
.93127 .30902 L
.93132 .30902 L
.93138 .30902 L
.93143 .30902 L
.93149 .30902 L
.93159 .30902 L
.93169 .30902 L
.93212 .30902 L
.93251 .30902 L
.9334 .30902 L
.93419 .30902 L
.93459 .30902 L
.93479 .30902 L
.93502 .30902 L
.93524 .30902 L
.93544 .30902 L
.93563 .30902 L
.93584 .30902 L
.93593 .30902 L
.93604 .30902 L
.93613 .30902 L
.93623 .30902 L
.93632 .30902 L
.93641 .30902 L
.9365 .30902 L
.93658 .30902 L
.93669 .30902 L
.93675 .30902 L
.9368 .30902 L
.9369 .30902 L
.93701 .30902 L
.93719 .30902 L
.93739 .30902 L
.93826 .30902 L
.93906 .30902 L
.93982 .30902 L
.94024 .30902 L
.94046 .30902 L
.94069 .30902 L
.94091 .30902 L
.94111 .30902 L
.94131 .30902 L
.94149 .30902 L
Mistroke
.94159 .30902 L
.94169 .30902 L
.94178 .30902 L
.94187 .30902 L
.94197 .30902 L
.94202 .30902 L
.94208 .30902 L
.94217 .30902 L
.94228 .30902 L
.94237 .30902 L
.94248 .30902 L
.94267 .30902 L
.9431 .30902 L
.94459 .30902 L
.94496 .30902 L
.94535 .30902 L
.94558 .30902 L
.94579 .30902 L
.94619 .30902 L
.94641 .30902 L
.94661 .30902 L
.94683 .30902 L
.94694 .30902 L
.94701 .30902 L
.94707 .30902 L
.94712 .30902 L
.94717 .30902 L
.94727 .30902 L
.94733 .30902 L
.94738 .30902 L
.94749 .30902 L
.94754 .30902 L
.9476 .30902 L
.9477 .30902 L
.9478 .30902 L
.94789 .30902 L
.94827 .30902 L
.94867 .30902 L
.9494 .30902 L
.94985 .30902 L
.95027 .30902 L
.95065 .30902 L
.95106 .30902 L
.95125 .30902 L
.95146 .30902 L
.95164 .30902 L
.95184 .30902 L
.95205 .30902 L
.95216 .30902 L
.95227 .30902 L
Mistroke
.95237 .30902 L
.95246 .30902 L
.95256 .30902 L
.95266 .30902 L
.95275 .30902 L
.95284 .30902 L
.95294 .30902 L
.95303 .30902 L
.95312 .30902 L
.9532 .30902 L
.95337 .30902 L
.95377 .30902 L
.95414 .30902 L
.95491 .30902 L
.95534 .30902 L
.95574 .30902 L
.9561 .30902 L
.95644 .30902 L
.95681 .30902 L
.95701 .30902 L
.95721 .30902 L
.95731 .30902 L
.95742 .30902 L
.95751 .30902 L
.95761 .30902 L
.9577 .30902 L
.9578 .30902 L
.95789 .30902 L
.95798 .30902 L
.95808 .30902 L
.95818 .30902 L
.95827 .30902 L
.95837 .30902 L
.95848 .30902 L
.95859 .30902 L
.9588 .30902 L
.96027 .30902 L
.96067 .30902 L
.96109 .30902 L
.96156 .30902 L
.96177 .30902 L
.96199 .30902 L
.9622 .30902 L
.96239 .30902 L
.96258 .30902 L
.96276 .30902 L
.96286 .30902 L
.96297 .30902 L
.96306 .30902 L
.96317 .30902 L
Mistroke
.96322 .30902 L
.96328 .30902 L
.96333 .30902 L
.96339 .30902 L
.9635 .30902 L
.96355 .30902 L
.96361 .30902 L
.96371 .30902 L
.96382 .30902 L
.96401 .30902 L
.96445 .30902 L
.96525 .30902 L
.96603 .30902 L
.96637 .30902 L
.96674 .30902 L
.96694 .30902 L
.96713 .30902 L
.9675 .30902 L
.96771 .30902 L
.96789 .30902 L
.968 .30902 L
.96811 .30902 L
.96822 .30902 L
.96831 .30902 L
.9684 .30902 L
.96849 .30902 L
.96858 .30902 L
.96865 .30902 L
.96875 .30902 L
.96885 .30902 L
.96894 .30902 L
.96903 .30902 L
.9692 .30902 L
.96939 .30902 L
.96978 .30902 L
.97065 .30902 L
.97107 .30902 L
.97147 .30902 L
.97186 .30902 L
.97221 .30902 L
.9726 .30902 L
.97281 .30902 L
.97302 .30902 L
.9732 .30902 L
.97339 .30902 L
.97349 .30902 L
.97355 .30902 L
.9736 .30902 L
.9737 .30902 L
.97379 .30902 L
Mistroke
.97388 .30902 L
.97397 .30902 L
.97405 .30902 L
.97414 .30902 L
.97423 .30902 L
.97433 .30902 L
.97451 .30902 L
.97492 .30902 L
.97535 .30902 L
.97613 .30902 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{421.375, 260.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008>0001AB000`400?l00000o`00003ooooooooo
oooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo
003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooo
oooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool0
0?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooooooo
ool@ooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooo
ooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo0ol0003o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0
003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo
00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`
ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLoooo
o`00<?ooool3o`000?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?oo
ool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo0?ooooooVoooool0033ooooo00?o0000
ooooooooool0?_ooool00ol0003oooooooooo`3ooooooi_ooooo000`ooooo`03o`000?oooooooooo
03kooooo00?o0000ooooooooool0oooooonKooooo`00<?ooool00ol0003oooooooooo`0mooooo`;o
0000oooooonMooooo`00<?ooool00ol0003oooooooooo`0mooooo`;o0000oooooonMooooo`00<?oo
ool00ol0003oooooooooo`0mooooo`;o0000oooooonMooooo`00<?ooool00ol0003oooooooooo`0m
ooooo`;o00002_ooool2o`000?ooooooTOooool0033ooooo00?o0000ooooooooool0?Oooool2o`00
00[ooooo0_l0003ooooooi7ooooo000`ooooo`03o`000?oooooooooo03gooooo0_l0000:ooooo`;o
0000oooooonAooooo`00<?ooool3o`0003gooooo00?o0000ooooool000002Oooool2o`000?oooooo
TOooool0033ooooo00?o0000ooooooooool0?Oooool00ol0003oooooo`000009ooooo`;o0000oooo
oonAooooo`00<?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooo000000Wooooo0_l0003o
oooooi7ooooo000`ooooo`03o`000?oooooooooo03gooooo00?o0000ooooool000002Oooool2o`00
0?ooooooTOooool0033ooooo00?o0000ooooooooool0?Oooool00ol0003oooooo`000009ooooo`;o
0000oooooonAooooo`00<?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooo000000Wooooo
0_l0003ooooooi7ooooo000`ooooo`03o`000?oooooooooo03gooooo00?o0000ooooool000002Ooo
ool2o`000?ooooooTOooool0013ooooo0_o^k^h3ooooo`;ok^k^6Oooool00ol0003oooooooooo`0m
ooooo`03o`000?oooooo000000Wooooo0_l0003ooooooi7ooooo000;ooooo`;o000000[o410@oooo
ooooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^0oooool4o`000008oa0@4?ooooooooooonk^
k_lb<S;o0000oc8b<_o^k^h:ooooo`03o`000?oooooooooo03gooooo00?o0000ooooool000002Ooo
ool2o`000?ooooooTOooool000cooooo00?o0000ooooooooool00_ooool01Oo^k^koEEEEomgMgOmE
EEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00[ooooo
00?o0000ooooooooool0?Oooool00ol0003oooooo`000009ooooo`;o0000oooooonAooooo`0000?o
ooooo`000?l000001?l00002ooooo`Go00001?ooool00ooMgMgo0000omgMg@07ooooo`03o`000?oo
oooooooo00;ooooo00Go410@oooooooooooooooooa0@400:ooooo`03o`000?oooooooooo03gooooo
00?o0000ooooool000002Oooool2o`000?ooooooTOooool000Wooooo00CoA4A4omgMgOoooooo0000
1?ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000000[ooooo00?o0000ooooooooool0?Oooool00ol0003oooooo`000009oooo
o`;o0000oooooonAooooo`002Oooool01?oMgMgoEEEEooooool00003ooooo`07onk^k_mEEEGok^k^
ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000:ooooo`Co0000??ooool00ol0003oooooo`000009ooooo`03o`000?oooooo00000?oooooo
T?ooool000[ooooo00?oMgMgolc<c?l000000oooool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oo
oooooooo00;ooooo00Go410@oooooooooooooooooa0@400:ooooo`03o`000?oooooooooo03gooooo
00?o0000ooooool000002Oooool00ol0003oooooo`00003ooooooi3ooooo000:ooooo`03onk^k_m4
A4Co000000oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo
0_l00005ooooo`03o`000?oooooooooo03gooooo00?o0000ooooool000002Oooool00ol0003ooooo
o`00003ooooooi3ooooo000;ooooo`03ogMgMol0003ooooo00cooooo00?oEEEEofIVI_l000001?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`0mooooo`03o`000?oooooo000000Sooooo00Co0000oooooooooooo0000oooooon@oooo
o`00:?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo03gooooo00?o0000oooo
ool000002?ooool01?l0003oooooooooool0003ooooooi3ooooo000Xooooo`?o00001Oooool00ol0
003oooooooooo`0mooooo`03o`000?oooooo000000Sooooo00Co0000oooooooooooo0000oooooon@
ooooo`00:Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03gooooo00?o0000oooo
ool000002?ooool01?l0003oooooooooool0003ooooooi3ooooo000Zooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0?Oooool00ol0003oooooo`000008ooooo`04o`000?oooooooooo
o`000?ooooooT?ooool0033ooooo00?o0000ooooooooool0?Oooool00ol0003oooooo`000008oooo
o`04o`000?ooooooooooo`000?ooooooT?ooool0033ooooo00?o0000ooooooooool0?Oooool00ol0
003oooooo`000008ooooo`04o`000?ooooooooooo`000?ooooooT?ooool0033ooooo00?o0000oooo
ooooool0?Oooool00ol0003oooooo`000008ooooo`04o`000?ooooooooooo`000?ooooooT?ooool0
033ooooo00?o0000ooooooooool0?Oooool00ol0003oooooo`000008ooooo`04o`000?oooooooooo
o`000?ooooooT?ooool0033ooooo0ol0000mooooo`03o`000?oooooo000000Sooooo00Co0000oooo
oooooooo0000oooooon@ooooo`00<?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooo0000
00Sooooo00Co0000oooooooooooo0000oooooon@ooooo`00<?ooool00ol0003oooooooooo`0moooo
o`03o`000?oooooo000000Sooooo00Co0000oooooooooooo0000oooooon@ooooo`00<?ooool00ol0
003oooooooooo`0mooooo`03o`000?oooooo000000Sooooo00Co0000oooooooooooo0000oooooon@
ooooo`00<?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooo000000Sooooo00Co0000oooo
oooooooo0000oooooon@ooooo`00<?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooo0000
00Sooooo00Co0000oooooooooooo0000oooooon@ooooo`00<?ooool00ol0003oooooooooo`0moooo
o`03o`000?oooooo000000Sooooo00Co0000oooooooooooo0000oooooon@ooooo`00<?ooool00ol0
003oooooooooo`0mooooo`03o`000?oooooo000000Sooooo00Co0000oooooooooooo0000oooooon@
ooooo`00<?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooo000000Sooooo00Co0000oooo
oooooooo0000oooooon@ooooo`00<?ooool00ol0003oooooooooo`0looooo`04o`000?oooooooooo
o`0000Sooooo00Co0000oooooooooooo0000oooooon@ooooo`00<?ooool00ol0003oooooooooo`0l
ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000oooooon@ooooo`00<?oo
ool00ol0003oooooooooo`0looooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo
0000oooooon@ooooo`00<?ooool3o`00037ooooo0_l00009ooooo`04o`000?ooooooooooo`0000So
oooo00Co0000oooooooooooo0000oooooon@ooooo`00<?ooool00ol0003oooooooooo`0aooooo`;o
00002Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`000?ooooooT?ooool0
033ooooo00?o0000ooooooooool0<Oooool2o`0000Wooooo00Co0000oooooooooooo00002?ooool0
1?l0003oooooooooool0003ooooooi3ooooo000`ooooo`03o`000?oooooooooo037ooooo0_l00009
ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000oooooon@ooooo`00<?oo
ool00ol0003oooooooooo`0aooooo`;o00002Oooool01Ol0003ooooooooooooooooo000000Oooooo
00Co0000oooooooooooo0000oooooon@ooooo`00<?ooool00ol0003oooooooooo`0aooooo`;o0000
2Oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo00002?ooool2o`00
0?ooooooQ_ooool0033ooooo00?o0000ooooooooool0<Oooool2o`0000Wooooo00Go0000oooooooo
ooooooooo`000006ooooo`05o`000?ooooooooooooooool000002?ooool2o`000?ooooooQ_ooool0
033ooooo00?o0000ooooooooool0<Oooool2o`0000Wooooo00Go0000ooooooooooooooooo`000006
ooooo`05o`000?ooooooooooooooool000002?ooool2o`000?ooooooQ_ooool0033ooooo00?o0000
ooooooooool0<Oooool00ol0003oooooo`000008ooooo`05o`000?ooooooooooooooool000001_oo
ool01Ol0003ooooooooooooooooo000000Sooooo0_l0003oooooohKooooo000`ooooo`03o`000?oo
oooooooo037ooooo00?o0000ooooool000002?ooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`;o0000oooooon6ooooo`00<?oo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooo000000Sooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool2o`000?oooooo
Q_ooool0033ooooo0ol0000`ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooooooo
ooooo`000006ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool2o`000?oo
ooooQ_ooool0033ooooo00?o0000ooooooooool0<?ooool01?l0003oooooooooool00008ooooo`05
o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Gooooo0_l0003oooooohKooooo000`ooooo`03o`000?oooooooooo033ooooo00Co0000oooooooo
oooo00002?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`05ooooo`;o0000oooooon6ooooo`00<?ooool00ol0003oooooooooo`0`oooo
o`04o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01Oooool2o`000?ooooooQ_ooool0033ooooo00?o0000
ooooooooool0<?ooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool00000
oooooon5ooooo`00<?ooool00ol0003oooooooooo`0`ooooo`04o`000?ooooooooooo`0000Sooooo
00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooo`00003oooooohGooooo000`ooooo`03o`000?oooooooooo033ooooo
00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`000?ooooooQOooool0
013ooooo0_o^k^h3ooooo`;ok^k^6Oooool00ol0003oooooooooo`0`ooooo`04o`000?oooooooooo
o`0000Sooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool01?l0003oooooooooool0003oooooohGooooo0009ooooo`Go00000_oo
ool01oo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^
k_lb<S;o0000oc8b<_o^k^h:ooooo`03o`000?oooooooooo033ooooo00Co0000oooooooooooo0000
2?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`04o`000?ooooooooooo`000?ooooooQOooool000Wooooo00GoV9RHob4Q8Oo^
k^koooooodA4A003ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02_ooool00ol0003oooooooooo`0`ooooo`04o`000?oo
ooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0003oooooohGooooo00000ooooooo
0000o`000004o`0000?ooooo00?oV9RHob4Q8Oo^k^h01Oooool00ooMgMgo0000omgMg@07ooooo`03
o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400:ooooo`03o`000?oooooooooo
033ooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`000?oooooo
QOooool000_ooooo00?oV9RHob4Q8Oo^k^h00oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000[ooooo00?o0000oooooooo
ool0<?ooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool000001_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo0000oooo
oon5ooooo`003?ooool02omgMgOoIVIVooooooooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^
00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000[ooooo1?l0000_
ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0003oooooohGo
oooo000=ooooo`03o`000?oooooooooo00;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@00[ooooo00?o0000ooooooooool0<?ooool01?l0003o
ooooooooool00008ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo0000oooooon5ooooo`002Oooool0
1Ol0003o^[ZjoooooonHV9So410@00kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00?ooooo0_l00005ooooo`03o`000?oooooooooo033ooooo00Co0000oooooooooooo
00002?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`04ooooo`04o`000?ooooooooooo`000?ooooooQOooool000Wooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP02ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0<?ooool01Ol0003ooooo
oooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0003oooooohGooooo000Xoooo
o`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0<?ooool01Ol0003ooooooooooooo
oooo000000Oooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool01?l0003oooooooooool0003oooooohGooooo000Xooooo`?o0000
1Oooool00ol0003oooooooooo`0`ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003o
oooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04oooo
o`04o`000?ooooooooooo`000?ooooooQOooool002Wooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0`ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooo
oooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`04o`000?oo
ooooooooo`000?ooooooQOooool002[ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0`ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`04o`00
0?ooooooooooo`000?ooooooQOooool0033ooooo00?o0000ooooooooool0<?ooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0003ooooo
ohGooooo000`ooooo`03o`000?oooooooooo033ooooo00Go0000ooooooooooooooooo`000006oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo0000oooooon5ooooo`00<?ooool00ol0
003oooooooooo`0`ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`04o`000?ooooooooooo`000?ooooooQOooool0033ooooo00?o0000ooooooooool0<?ooool0
1Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01?l0003ooooooooo
ool0003oooooohGooooo000`ooooo`?o0000<?ooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool01?l0003oooooooooool0003oooooohGooooo000`ooooo`03o`00
0?oooooooooo033ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00Co0000oooooooooooo0000oooooon5ooooo`00<?ooool00ol0003oooooooooo`0`ooooo`05
o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooo
ooooool00000oooooon4ooooo`00<?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooo
ooooool00000oooooon4ooooo`00<?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooo
ooooool00000oooooon4ooooo`00<?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooo
ooooool00000oooooon4ooooo`00<?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooo
ooooool00000oooooon4ooooo`00<?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooo
ooooool00000oooooon4ooooo`00<?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooo
ooooool00000oooooon4ooooo`00<?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooo
ooooool000001oooool00ol0003oooooooooo`3oooooog[ooooo000`ooooo`03o`000?oooooooooo
02oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00Go0000ooooooooooooooooo`000006ooooo`;o0000oooooomlooooo`00<?ooool00ol0
003oooooooooo`0_ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooo`00003o
ooooog_ooooo000`ooooo`?o0000;oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000
ooooool00000oooooomkooooo`00<?ooool00ol0003oooooooooo`0Tooooo`;o00002Oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooool00000oooooomkooooo`00<?ooool00ol0
003oooooooooo`0Tooooo`;o00002Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000
ooooool00000oooooomkooooo`00<?ooool00ol0003oooooooooo`0Sooooo`?o00002Oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooool00000oooooomkooooo`00<?ooool00ol0
003oooooooooo`0Sooooo`03o`000?oooooo000000Wooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006
ooooo`03o`000?oooooo00000?ooooooNoooool0033ooooo00?o0000ooooooooool08oooool00ol0
003oooooo`000009ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01?l0
003oooooonk^k_o^k^h3ooooo`05o`000?o^k^koooooooooool000001_ooool00ol0003oooooo`00
001;ooooo`;ok^k^0oooool2onk^kV3ooooo0_o^k^h3ooooo`;ok^k^C_ooool2onk^kP?ooooo0_o^
k^i/ooooo`00<?ooool00ol0003oooooooooo`0Sooooo`04o`000?ooooooooooo`0000Sooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool03_l0003oA4A4o`000?l0003o<S8bo`000?ooooook^k^oeEEEOo^k^ko
ooooonk^k_l0003ok^k^0_ooool5o`000004oa0@4?l0003oooooonk^kP;o000000?o<S8bonk^k_oo
ool0@Oooool4o`000009oa0@4?ooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l0
00002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^>oooool4o`000003oa0@4?oooooooooo
00;ooooo0_lQ8B45ooooo`0=odA4A?l0003o0000oc8b<_oMgMgoooooonk^k_mEEEGok^k^ooooooo^
k^koEEEEonk^kP03ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kSSooooo
1Ol00002ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co000000So410@oooo
ooooooook^k^oc8b<_l0003o<S8bonk^kUgooooo000`ooooo`03o`000?oooooooooo02?ooooo00Co
0000oooooooooooo00002?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`06o`000?oooooooooooooooomg
MgOo00000_ooool01Oo^k^koEEEEomgMgOmEEEGo000000?ooooo00Co0000oooooooooooo00000_oo
ool01ol0003oooooogMgMol0003ooooooiRHV?mgMgL0A?ooool00ol0003oooooooooo`02ooooo`05
onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL0?Oooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool02OmgMgOo<S8boooooooo
ooook^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0hooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01Oo^k^koEEEEomgMgOmE
EEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg05gooooo
000`ooooo`03o`000?oooooooooo02?ooooo00Co0000oooooooooooo00002?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00So0000ooooooooooooooooomgMgOl0003ogMgM
o`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooa0@4?l00002ooooo`03oa0@
4?oooooooooo04;ooooo00?o0000ooooooooool00oooool00ooMgMgo0000omgMg@07ooooo`03o`00
0?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400mooooo`03o`000?oooooooooo00oo
oooo00Oo0000ooooooooooooooooomgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@03Wooooo00?oV9RHob4Q8Oo^k^h01Oooool00ooMgMgo0000omgM
g@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@401Mooooo`00<?oo
ool00ol0003oooooooooo`0Rooooo`05o`000?ooooooooooooooool000002?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`06o`000?oooooooooooooooomgMgOo00000_ooool01Oo^k^koEEEEomgMgOmEEEGo
000000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooo`000?l00002ooooo`03o`00
0?oooooooooo04;ooooo00?o0000ooooooooool00_ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Ko
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000003gooooo00?o0000oooo
ooooool03_ooool02OmgMgOo<S8booooooooooook^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000jooooo`03oiRHV?lQ8B7ok^k^00?o
oooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`00001Mooooo`00<?ooool00ol0003oooooooooo`0Rooooo`05o`000?oooooooooo
ooooool000001oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`;o000000co8B4Qo`000?lb<S;o0000oooo
ooo^k^koEEEEonk^k_ooooook^k^o`000?o^k^h2ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000ooooool0003o00000_ooool00ol0003oooooooooo`12ooooo`0;o`000?ooooooooooooooooo^
k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool00000?Oooool00ol0003oooooooooo`0;ooooo`0=o`000?lQ8B7o0000oc8b<_o<
c<coooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo
00Go0000ooooooooooooooooo`00000kooooo`0;ogMgMomVIVKoooooooooooo^k^koEEEEonk^k_oo
ooook^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
0000GOooool0033ooooo00?o0000ooooooooool08_ooool01Ol0003ooooooooooooooooo000000Oo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool2o`0000?ooooo00Co0000ooooooo^k^kok^k^0oooool01Ol0
003ok^k^oooooooooooo000000;ooooo00[o0000oooooooooooo0000ooooool@413oooooo`000?oo
oooo410@A?ooool01?l0003oooooooooooooool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooo
oooo00;ooooo00Go410@oooooooooooooooooa0@400mooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool00oooool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go
410@oooooooooooooooooa0@400looooo`03o`000?oooooooooo00;ok^k^0oooool2onk^kPGooooo
00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@05gooooo000`ooooo`?o0000
8_ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool2o`0000?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
00;ooooo00Oo0000oooooomgMgOoV9RHo`000?nHV9SoMgMg00Sooooo00?o0000ooooooooool0>Ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`08ooooo`;o0000<oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo0_l0000^ooooo`05
o`000?nj^[[ooooooiRHV?l@41003_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02?ooool2o`0005?ooooo000`ooooo`03o`000?oooooooooo02;ooooo00Go0000oooo
ooooooooooooo`000007ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo1_l00005ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oeEEEOmVIVKo00000_ooool01ol0003oooooonk^k_lb<S;o0000oc8b<_o^
k^h02?ooool00ol0003oooooooooo`0gooooo`03oeEEEOmVIVKo000000gooooo00?oEEEEofIVI_l0
00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oooooo00Co0000oooooooooooo0000<?ooool0
0omEEEGoIVIVo`00000=ooooo`Co00003?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01oooool01?l0003oooooooooool0000]ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`03?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01oooool01?l0
003oooooooooool0001Booooo`00<?ooool00ol0003oooooooooo`0Rooooo`05o`000?oooooooooo
ooooool000001oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000
ooooooooooooooooo`000004ooooo`Co00000oooool00ol0003oooooooooo`1Dooooo`Co000000Go
ooooo`000?ooooooooooo`00001Nooooo`Co000000Goooooo`000?ooooooooooo`00001<ooooo`Co
000000Goooooo`000?ooooooooooo`00001Booooo`00<?ooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooooooo
ooooool00000Foooool3o`0006Cooooo0ol0001Booooo`?o0000Doooool0033ooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001_ooool2
o`000005ooooool0003oooooooooool00000Foooool00ol0003oooooooooo`1Tooooo`03o`000?oo
oooooooo05;ooooo00?o0000ooooooooool0D_ooool0033ooooo00?o0000ooooooooool08Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooo`00
0004o`0005cooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`1Booooo`03o`000?oo
oooooooo057ooooo000`ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool0
1Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooool00000oooooomaooooo`00<?ooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooo00000?oooooo=oooool00omgMgOoIVIVooooo`0]ooooo`03ofIVI_mg
MgOooooo00Oooooo000`ooooo`03o`000?oooooooooo01Gooooo0ol00009ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool00000ooooooleooooo`03omgMgOl@413ok^k^02kooooo00?ok^k^oa0@4?oMgMd01ooo
ool0033ooooo00?o0000ooooooooool05?ooool2o`000003ooooool0003o000000Sooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000007ooooo`03o`000?oooooooooo0?oooooo6Oooool2o`0000;ooooo0_l0
000<ooooo`03oeEEEOnHV9Sooooo00;o00000_ooool01ol0003oooooooooool0003o410@onk^k_mE
EED00_l000000om4A4Co^[Zjooooo`02ooooo`05oiRHV?l0003o0000odA4A?nj^[X00_ooool02?o^
k^koEEEEo`000?l0003oA4A4okZj^_oooooo410@1Ol00003ooooo`08oa0@4?lb<S;o0000o`000?l@
413oZJVYohN7QomVIVH7ooooo`00<?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Gooooo1?l0003o
oooooa[ooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd<ooooo`05o`000?ooooooooooooooool0
00000_ooool02ol0003oooooooooool0003ooooooeEEEOmgMgOoooooonk^k_mgMgOo410@00?ooooo
00Go410@okZj^_o^k^koMgMgoa0@4002ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo410@0oooool0
0ol0003oooooooooo`04ooooo`08o`000?nYZJWooooooooooonj^[[o0000onk^k_l00007ooooo`00
ool0002do`0000oooooo00CogMgMo`000?l@413oc<c<3Oooool01Olb<S;ooooooooooooooooo0000
00;ooooo00Ko0000oooooooooooo0000ooooool00008ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`07okZj^_n7QhOoIVIVofIVI_l@413o
ooooo`000007ooooo`002_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool02oooool6o`0000Sooooo00?o0000ooooooooool01?ooool01?l0003ooooo
ooooool00003ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool2o`0000Go
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`06o`000?ooooooooooo`00
0?oooooo00001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooool0003oooooo`000005ooooo`Co00001oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo01Oooooo00Cok^k^ob4Q8Ol@413ok^k^3Oooool01Olb<S;ooooooooooooooooo000000;o
oooo00Go0000oooooooooooo0000ooooo`06o`0000?ooooo00?o0000ooooooooool01?ooool6o`00
00?ooooo00?o0000ooooooooool01?ooool02?lb<S;o8B4QogMgMomgMgOoQhN7onk^k_oooooo0000
1oooool000[ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`04o`000?oo
ooooooooo`0000?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`;o0000
1Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool00000
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00Ko0000oooooooooooo
0000ooooool00004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01?l0
003oooooo`000?l0000Aooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool05oooool0
1?lQ8B7oMgMgogMgMolb<S8=ooooo`05o`000?o^k^koooooooooool000000_o<c<`02ol0003oZJVY
omgMgOlQ8B7ooooooeEEEOn7QhOok^k^oooooon7QhOo<S8b00?ooooo00?o0000ooooooooool01?oo
ool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<P?ooooo00?o0000oc8b<_oMgMd01?ooool02?l0003o
^[Zjooooooo^k^koMgMgo`000?o^k^ko00001oooool0033ooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`06o`000?ooooooooooo`000?oooooo00001?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool00000BOooool00ol0003ooooo
ooooo`1Kooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool05_ooool2o`0000;ooooo
0_l0000<ooooo`0>oeEEEOmgMgOooooooa0@4?l0003o8B4Qo`000?mgMgOo410@o`000?nYZJWooooo
onk^k_mEEED2o`000004odA4A?o^k^kooooooa0@40Go00000oooool01_o^k^koEEEEo`000?l0003o
A4A4onk^kP;ooooo0_l000001?nYZJWo8B4Qo`000?lQ8B42ooooo`08ojVYZOlQ8B7o0000o`000?lb
<S;o0000ogMgMomEEED7ooooo`00<?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool000001_ooool2o`000?oooooo<_ooool00ooMgMgo410@onk^kP0Booooo`03o`000?oooooo
oooo01Wooooo00?ok^k^oa0@4?oMgMd01oooool0033ooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0003ooooooooooooo
oooo00000?oooooo>oooool00omgMgOoIVIVooooo`0Aooooo`03o`000?oooooooooo01Wooooo00?o
IVIVogMgMoooool01oooool0033ooooo00?o0000ooooooooool06oooool01Ol0003ooooooooooooo
oooo000000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`05o`000?oo
ooooooooooooool000001Oooool01Ol0003ooooooooooooooooo00000?ooooooMOooool0033ooooo
00?o0000ooooooooool06oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0
003ooooooooooooooooo00000?ooooooMOooool0033ooooo00?o0000ooooooooool07?ooool00ol0
003oooooo`000009ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool01Ol0
003ooooooooooooooooo000000Gooooo00Go0000ooooooooooooooooo`00003oooooogGooooo000`
ooooo`03o`000?oooooooooo01cooooo0ol00009ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooool00000oooo
oomfooooo`00<?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooool00000oooo
oomfooooo`00<?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooool00000oooo
oomfooooo`00<?ooool3o`0002Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooo`00003oooooogKooooo000`
ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooo`00003oooooogKooooo000`
ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`05o`000?ooooooooooooooool000001_ooool2o`000?ooooooMoooool0033ooooo00?o0000
ooooooooool0:?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000
ooooooooooooooooo`000006ooooo`;o0000oooooomgooooo`00<?ooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooo
oooo00000?ooooooOoooool0033ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00003oooooogoooooo000`
ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`05o`000?ooooooooooooooool00000oooooomoooooo`00<?ooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo00000?oooooo
Ooooool0033ooooo00?o0000ooooooooool0:Oooool01Ol0003ooooooooooooooooo000000Oooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooo
oooo0000oooooon0ooooo`00<?ooool00ol0003oooooooooo`0Yooooo`05o`000?oooooooooooooo
ool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool0
1?l0003oooooooooool0003ooooooh3ooooo000`ooooo`03o`000?oooooooooo02Wooooo00Go0000
ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooooooo
o`000006ooooo`04o`000?ooooooooooo`000?ooooooP?ooool0033ooooo00?o0000ooooooooool0
:Oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003o
oooooooooooooooo000000Kooooo00Co0000oooooooooooo0000oooooon0ooooo`00<?ooool3o`00
02Wooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000
ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`000?ooooooP?ooool0033ooooo00?o
0000ooooooooool0:Oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo0000oooooon0oooo
o`00<?ooool00ol0003oooooooooo`0Yooooo`05o`000?ooooooooooooooool000001oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool0
003ooooooh3ooooo000`ooooo`03o`000?oooooooooo02Wooooo00Go0000ooooooooooooooooo`00
0007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`04o`00
0?ooooooooooo`000?ooooooP?ooool0033ooooo00?o0000ooooooooool0:Oooool01Ol0003ooooo
oooooooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000
00Kooooo00Co0000oooooooooooo0000oooooon0ooooo`00<?ooool00ol0003oooooooooo`0Yoooo
o`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooo
ooooooooool000001_ooool01?l0003oooooooooool0003ooooooh3ooooo000`ooooo`03o`000?oo
oooooooo02Wooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo
00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?ooooooP?ooool0033ooooo
00?o0000ooooooooool0:Oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooool00000oooooon0oooo
o`00<?ooool00ol0003oooooooooo`0Zooooo`04o`000?ooooooooooo`0000Sooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
1Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooool00000oooooon0ooooo`00<?ooool0
0ol0003oooooooooo`0Zooooo`03o`000?oooooo000000Wooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000Oooooo00?o0000ooooool00000oooooon0ooooo`00<?ooool00ol0003ooooooooo
o`0Zooooo`03o`000?oooooo000000Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Oo
oooo00?o0000ooooool00000oooooon0ooooo`00<?ooool00ol0003oooooooooo`0Zooooo`03o`00
0?oooooo000000Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000oooo
ool00000oooooon0ooooo`00<?ooool3o`0002[ooooo00?o0000ooooool000002Oooool01Ol0003o
oooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04oooo
o`05o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003ooooooh3ooooo000`oooo
o`03o`000?oooooooooo02[ooooo00?o0000ooooool000002Oooool01Ol0003ooooooooooooooooo
000000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooo
ooooooooool000001oooool00ol0003oooooo`00003ooooooh3ooooo000`ooooo`03o`000?oooooo
oooo02[ooooo00?o0000ooooool000002Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000
1oooool00ol0003oooooo`00003ooooooh3ooooo000`ooooo`03o`000?oooooooooo02[ooooo00?o
0000ooooool000002Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001oooool00ol0003o
ooooo`00003ooooooh3ooooo000`ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooool00000
2Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`05o`000?ooooooooooooooool000001oooool2o`000?ooooooPOooool0033o
oooo00?o0000ooooooooool0:_ooool00ol0003oooooo`000009ooooo`05o`000?oooooooooooooo
ool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooo
ooooooooooooo`000007ooooo`;o0000oooooon1ooooo`003oooool2onk^kP?ooooo0_o^k^hJoooo
o`03o`000?oooooooooo02[ooooo0ol00009ooooo`05o`000?ooooooooooooooool000001_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00
0007ooooo`;o0000oooooon1ooooo`002?ooool5o`0000;ooooo00Ook^k^oeEEEOo^k^koooooonk^
k_mEEEGok^k^00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00Sooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000Oooooo0_l0003ooooooh7ooooo0008ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
0oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`08oooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00Go0000ooooooooooooooooo`000007ooooo`;o0000oooooon1ooooo`002Oooool0
0onHV9So8B4Qonk^kP05ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@00_ooooo00?o0000ooooooooool0=_ooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`00
0?ooooooooooooooool00000oooooon:ooooo`002_ooool00onHV9So8B4Qonk^kP03ooooo`05onk^
k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000002oooool00ol0003oooooooooo`0fooooo`05o`000?ooooooooooooooool000001_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00
003ooooooh[ooooo000;ooooo`0;ogMgMomVIVKoooooooooooo^k^koEEEEonk^k_ooooook^k^oeEE
EOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000002oooool4
o`0003Gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool01Ol0003ooooooooooooooooo00000?ooooooR_ooool000cooooo00?o
0000ooooooooool00_o^k^h3ooooo`;ok^k^1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oo
ooooooooooooool@41002oooool00ol0003oooooooooo`0fooooo`05o`000?ooooooooooooooool0
00001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooo
ooooooooo`00003ooooooh[ooooo0008ooooo`05o`000?nj^[[ooooooiRHV?l@41003_ooool00ol0
003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ol0003oooooooooo`0f
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00Co0000oooooooooooo0000oooooon;ooooo`002?ooool01OnHV9So410@o`00
0?lQ8B7oc<c<00cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?o
oooo0_l00006ooooo`03o`000?oooooooooo03Kooooo00Go0000ooooooooooooooooo`000006oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0003o
oooooh_ooooo000Wooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0=_ooool0
1Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`04ooooo`04o`000?ooooooooooo`000?ooooooRoooool002Oooooo00Co0000oooooooooooo0000
1Oooool00ol0003oooooooooo`0fooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo0000oooooon;oooo
o`009oooool3o`0000Kooooo00?o0000ooooooooool0=_ooool01Ol0003ooooooooooooooooo0000
00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`04o`000?oooooooooo
o`000?ooooooRoooool002Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0foooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00Co0000oooooooooooo0000oooooon;ooooo`00:Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo03Kooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0003ooooooh_ooooo
000`ooooo`03o`000?oooooooooo03Kooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0003ooooooh_o
oooo000`ooooo`03o`000?oooooooooo03Kooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooo`00003ooooooh_o
oooo000`ooooo`03o`000?oooooooooo03Kooooo00Go0000ooooooooooooooooo`000007ooooo`05
o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003ooooooh_ooooo000`ooooo`?o
0000=_ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007
ooooo`03o`000?oooooo00000?ooooooRoooool0033ooooo00?o0000ooooooooool0=_ooool01Ol0
003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oo
oooo00000?ooooooRoooool0033ooooo00?o0000ooooooooool0=_ooool01Ol0003ooooooooooooo
oooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?oooooo
Roooool0033ooooo00?o0000ooooooooool0=_ooool01Ol0003ooooooooooooooooo000000Oooooo
00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?ooooooRoooool0033ooooo
00?o0000ooooooooool0=_ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooooooo
ooooooooo`000007ooooo`03o`000?oooooo00000?ooooooRoooool0033ooooo00?o0000oooooooo
ool0=_ooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool000001oooool0
0ol0003oooooo`00003ooooooh_ooooo000`ooooo`03o`000?oooooooooo03Kooooo00Co0000oooo
oooooooo00002?ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooool00000oooo
oon;ooooo`00<?ooool00ol0003oooooooooo`0fooooo`04o`000?ooooooooooo`0000Sooooo00Go
0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?ooooooRoooool0033ooooo00?o
0000ooooooooool0=_ooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool0
00001oooool00ol0003oooooo`00003ooooooh_ooooo000`ooooo`03o`000?oooooooooo03Kooooo
00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000oooo
ool00000oooooon;ooooo`00<?ooool00ol0003oooooooooo`0fooooo`04o`000?ooooooooooo`00
00Sooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?ooooooRoooool0
033ooooo00?o0000ooooooooool0=_ooool01?l0003oooooooooool00008ooooo`05o`000?oooooo
ooooooooool000001oooool00ol0003oooooo`00003ooooooh_ooooo000`ooooo`?o0000=_ooool0
1?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool000001oooool00ol0003ooooo
o`00003ooooooh_ooooo000`ooooo`03o`000?oooooooooo03Kooooo00Co0000oooooooooooo0000
2?ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooool00000oooooon;ooooo`00
<?ooool00ol0003oooooooooo`0fooooo`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooo
ooooooooo`000007ooooo`03o`000?oooooo00000?ooooooRoooool0033ooooo00?o0000oooooooo
ool0=_ooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool000001oooool0
0ol0003oooooo`00003ooooooh_ooooo000`ooooo`03o`000?oooooooooo03Kooooo00Co0000oooo
oooooooo00002?ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooool00000oooo
oon;ooooo`00<?ooool00ol0003oooooooooo`0fooooo`04o`000?ooooooooooo`0000Sooooo00Go
0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?ooooooRoooool0033ooooo00?o
0000ooooooooool0=oooool00ol0003oooooo`000008ooooo`05o`000?ooooooooooooooool00000
1oooool00ol0003oooooo`00003ooooooh_ooooo000`ooooo`03o`000?oooooooooo03Oooooo00?o
0000ooooool000002?ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooool00000
oooooon;ooooo`00<?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooo000000Sooooo00Co
0000oooooooooooo00002?ooool00ol0003oooooo`00003ooooooh_ooooo000`ooooo`03o`000?oo
oooooooo03Oooooo00?o0000ooooool000002?ooool01?l0003oooooooooool00008ooooo`03o`00
0?oooooo00000?ooooooRoooool0033ooooo00?o0000ooooooooool0=oooool00ol0003oooooo`00
0008ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooon;ooooo`00<?oo
ool00ol0003oooooooooo`0gooooo`03o`000?oooooo000000Sooooo00Co0000oooooooooooo0000
2?ooool00ol0003oooooo`00003ooooooh_ooooo000`ooooo`?o0000=oooool00ol0003oooooo`00
0008ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooon;ooooo`00<?oo
ool00ol0003oooooooooo`0gooooo`03o`000?oooooo000000Sooooo00Co0000oooooooooooo0000
2?ooool00ol0003oooooo`00003ooooooh_ooooo000`ooooo`03o`000?oooooooooo03Oooooo00?o
0000ooooool000002?ooool01?l0003oooooooooool00009ooooo`;o0000oooooon;ooooo`00<?oo
ool00ol0003oooooooooo`0gooooo`03o`000?oooooo000000Sooooo00Co0000oooooooooooo0000
2Oooool2o`000?ooooooRoooool0033ooooo00?o0000ooooooooool0=oooool00ol0003oooooo`00
0008ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oooooon:ooooo`00<?oo
ool00ol0003oooooooooo`0gooooo`03o`000?oooooo000000Sooooo00Co0000oooooooooooo0000
2Oooool00ol0003oooooooooo`3ooooooh[ooooo000?ooooo`;ok^k^0oooool2onk^kQ[ooooo00?o
0000ooooooooool0=oooool00ol0003oooooo`000008ooooo`04o`000?ooooooooooo`0000Wooooo
00?o0000ooooooooool0oooooon:ooooo`002_ooool2o`00000:oa0@4?ooooooooooonk^k_mEEEGo
k^k^ooooooo^k^koEEEEonk^kP?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;o
k^k^2oooool00ol0003oooooooooo`0gooooo`03o`000?oooooo000000Sooooo00Co0000oooooooo
oooo0000oooooonFooooo`002oooool00ol0003oooooooooo`02ooooo`05onk^k_mEEEGogMgMoeEE
EOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
0ol0003oooooooooo`0gooooo`03o`000?oooooo000000Sooooo00Co0000oooooooooooo0000oooo
oonFooooo`002?ooool5o`0000Cooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@41002oooool00ol0003oooooooooo`0gooooo`;o00002Ooo
ool01?l0003oooooooooool0003ooooooiKooooo0008ooooo`04odA4A?oMgMgoooooo`0000Cooooo
00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`00000;ooooo`03o`000?oooooooooo03Oooooo0_l00009ooooo`04o`000?oooooooooo
o`000?ooooooU_ooool000Sooooo00CogMgMoeEEEOoooooo00000oooool01oo^k^koEEEEonk^k_oo
ooook^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
00002oooool4o`0003Kooooo0_l00009ooooo`04o`000?ooooooooooo`000?ooooooU_ooool000Wo
oooo00?oMgMgolc<c?l000000oooool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;o
oooo00Go410@oooooooooooooooooa0@400;ooooo`03o`000?oooooooooo03Oooooo0_l00009oooo
o`04o`000?ooooooooooo`000?ooooooU_ooool000Wooooo00?ok^k^odA4A?l000003oooool00ol0
003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ol0003oooooooooo`0g
ooooo`;o00002Oooool01?l0003oooooooooool0003ooooooiKooooo000:ooooo`03ogMgMol0003o
oooo00cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo0_l0
0006ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool02?ooool00ol0003oooooo`00
003ooooooiKooooo000Wooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0>?oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooo00000?ooooooU_ooool002Oooooo00Co0000
oooooooooooo00001Oooool00ol0003oooooooooo`13ooooo`03o`000?oooooo00000?ooooooU_oo
ool002Oooooo0ol00006ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooool00000oooooonF
ooooo`00:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04?ooooo00?o0000oooo
ool00000oooooonFooooo`00:Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04?o
oooo00?o0000ooooool00000oooooonFooooo`00<?ooool00ol0003oooooooooo`13ooooo`03o`00
0?oooooo00000?ooooooU_ooool0033ooooo00?o0000ooooooooool0@oooool00ol0003oooooo`00
003ooooooiKooooo000`ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooool00000oooooonF
ooooo`00<?ooool3o`0004?ooooo0_l0003ooooooiOooooo000`ooooo`03o`000?oooooooooo04?o
oooo0_l0003ooooooiOooooo000`ooooo`03o`000?oooooooooo04?ooooo0_l0003ooooooiOooooo
000`ooooo`03o`000?oooooooooo04?ooooo0_l0003ooooooiOooooo000`ooooo`03o`000?oooooo
oooo04?ooooo0_l0003ooooooiOooooo000`ooooo`03o`000?oooooooooo04?ooooo0_l0003ooooo
oiOooooo000`ooooo`03o`000?oooooooooo04?ooooo0_l0003ooooooiOooooo000`ooooo`03o`00
0?oooooooooo04?ooooo0_l0003ooooooiOooooo000`ooooo`03o`000?oooooooooo04?ooooo0_l0
003ooooooiOooooo000`ooooo`03o`000?oooooooooo04?ooooo0_l0003ooooooiOooooo000`oooo
o`03o`000?oooooooooo04?ooooo0_l0003ooooooiOooooo000`ooooo`03o`000?oooooooooo04?o
oooo0_l0003ooooooiOooooo000`ooooo`?o0000@oooool2o`000?ooooooUoooool0033ooooo00?o
0000ooooooooool0@oooool2o`000?ooooooUoooool0033ooooo00?o0000ooooooooool0A?ooool0
0ol0003oooooooooo`3ooooooiGooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033o
oooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo
000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooL
ooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oo
oooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooooooo
o`3oooooomcooooo000`ooooo`?o0000oooooooLooooo`00<?ooool00ol0003oooooooooo`3ooooo
omcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0
oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo003ooooooooooooo4?ooool0
0?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooooooo
ool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00
X?ooool2o`0000Cooooo00?o^[Zjoc8b<_ooool01?ooool2o`0000Kooooo00?o0000okZj^_ooool0
oooooomGooooo`00X?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool2oc8b<_ooooooF?ooool008gooooo0ol00002ooooo`06oc8b<_l@413o
ooooooooooo^k^koEEEE0_l000000om4A4Co^[Zjooooo`03ooooo`03o`000?oooooooooo00;ooooo
00GoV9RHoa0@4?l0003o0000ojVYZ@04ooooo`03o`000?oooooooooo00Cooooo00?oQhN7o`000?nj
^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj00Wooooo00GoV9RHoa0@4?l0003o<S8bolc<c005
ooooo`;o8B4Q1?ooool5o`000006ooooooo<c<cok^k^ooooooo^k^koc<c<1?ooool4o`000008oa0@
4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hCooooo`06oa0@4?lb<S;o0000o`000?l@413oZJVY
0_ooool01_o^k^koEEEEo`000?l0003oA4A4okZj^P?ooooo00GoIVIVo`000?l0003oA4A4olc<c03X
ooooo`00S_ooool01Ol0003oooooooooooo<c<co410@00?ooooo00KoEEEEogMgMoooooook^k^ogMg
Mol@4104ooooo`03o`000?oooooooooo00;ooooo00Ko0000ojVYZOmEEEGoV9RHoeEEEOnj^[X3oooo
o`03o`000?oooooooooo00Cooooo00?oc<c<o`000?l@41003?ooool01_l@413o^[Zjonk^k_mgMgOo
410@ooooo`Ko00000_ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Gooooo0_lQ8B44ooooo`0;oiRH
V?lQ8B7ok^k^oooooom4A4Coooooonk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool01_l0003oZJVYoooooooooooo^[Zjo`00
00;ooooo00KoEEEEogMgMoooooook^k^ogMgMol@4102ooooo`06ofIVI_mgMgOooooooooooon7QhOo
410@j?ooool008kooooo00Go0000ooooooooooooEEEEohN7Q`03ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool00_ooool01_lb<S;ok^k^oiRHV?mEEEGogMgMoa0@40?ooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00[ooooo00?oV9RH
ob4Q8Oo^k^h00oooool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@400Dooooo`05okZj^_n7QhOoIVIVofIVI_l@41000_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo0>_ooooo002>ooooo`05o`000?oooooogMgMo`000?o^k^h0
0oooool6o`0000Cooooo00?o0000ooooooooool00_ooool01onj^[[oA4A4olc<c?lQ8B7ooooooa0@
4?o<c<`00_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00?ooooo1_l00005oooo
o`03ojVYZOl@413ooooo00cooooo00WoV9RHob4Q8Oo^k^koooooonk^k_mEEEGogMgMoeEEEOo^k^h0
1_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000004oooool01_lb<S;o
8B4QogMgMomgMgOoQhN7onk^kP;ooooo1_l00002ooooo`03o`000?oooooooooo0>_ooooo002>oooo
o`?o000000?o410@oiRHV?ooool00_ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<PCooooo00?o
0000ooooooooool00_ooool01oo^k^ko0000ooooool0003oooooofIVI_n7QhL00_ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo00gooooo00?o410@o`000?nj^[X03_ooool02?mgMgOo
IVIVooooooo<c<cok^k^ooooooo^k^koc<c<1_ooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000004oooool01_l0003o^[Zjooooooo^k^koMgMgo`0000;ooooo00KoEEEEohN7
Qoo^k^koooooohN7Qolb<S82ooooo`06ofIVI_mgMgOooooooooooon7QhOo0000j?ooool008kooooo
00Go0000ooooooooooooc<c<o`000003ooooo`06onk^k_mEEEGo0000o`000?m4A4Cok^k^1?ooool0
0ol0003oooooooooo`02ooooo`04ofIVI_nHV9Sooooooc8b<P;o^[Zj00Co0000oooooooooooo0000
4oooool00ol@413o0000o`000003o`0000gooooo00?o^[Zjob4Q8Oooool03_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4007ooooo`?o
00000_ooool3o`0000Cooooo00KoZJVYob4Q8Ol0003o0000oc8b<_l00002ooooo`06onk^k_mEEEGo
0000o`000?m4A4Cok^k^0_ooool01_o^k^koIVIVo`000?l0003oA4A4o`000>Sooooo002>ooooo`05
o`000?ooooooooooolc<c?l000003Oooool00ol0003oooooooooo`05ooooo`03ofIVI_n7QhOooooo
00?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0;ooooo`05oa0@4?nHV9Sooooo
okZj^_l000002oooool01Ol0003o^[ZjoooooonHV9So410@00cooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`3oooooo`;ooooo002=ooooo`Co000000?o410@ojVYZOooool03?ooool2o`0000Kooooo00?o
ZJVYodA4A?ooool00_ooool2o`0001Gooooo00?o0000ooooooooool02oooool01OnYZJWo410@o`00
0?l@413oZJVY00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00:ooooo`03oeEEEOmVIVKo000000Co
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`Co00000_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo0?oooooo0_ooool00?oooooo1_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo0?oooooo0_ooool00?oooooo1_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo0?oooooo0_ooool00?oooooo1Oooool2o`0000?ooooo0_l0003oooooo`Cooooo003o
oooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo
4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oo
ooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@
ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooo
oooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3o
oooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00\
\>"],
  ImageRangeCache->{{{0, 525.688}, {324.5, 0}} -> {0, -6.34248*^6, 0, 53093}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0.309017 5.42214e-08 [
[.32684 .29652 -16.5 -12.5 ]
[.32684 .29652 16.5 0 ]
[.54329 .29652 -16.5 -12.5 ]
[.54329 .29652 16.5 0 ]
[.75974 .29652 -22.5 -12.5 ]
[.75974 .29652 22.5 0 ]
[.97619 .29652 -16.5 -12.5 ]
[.97619 .29652 16.5 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 64 6 ]
[.09789 .09213 -34.5 -6.25 ]
[.09789 .09213 0 6.25 ]
[.09789 .20057 -34.5 -6.25 ]
[.09789 .20057 0 6.25 ]
[.09789 .41746 -28.5 -6.25 ]
[.09789 .41746 0 6.25 ]
[.09789 .5259 -28.5 -6.25 ]
[.09789 .5259 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -62.8125 0 ]
[.5 .63053 62.8125 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 .30902 m
.32684 .31527 L
s
gsave
.32684 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 .30902 m
.54329 .31527 L
s
gsave
.54329 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 .30902 m
.75974 .31527 L
s
gsave
.75974 .29652 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 .30902 m
.15368 .31277 L
s
.19697 .30902 m
.19697 .31277 L
s
.24026 .30902 m
.24026 .31277 L
s
.28355 .30902 m
.28355 .31277 L
s
.37013 .30902 m
.37013 .31277 L
s
.41342 .30902 m
.41342 .31277 L
s
.45671 .30902 m
.45671 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.58658 .30902 m
.58658 .31277 L
s
.62987 .30902 m
.62987 .31277 L
s
.67316 .30902 m
.67316 .31277 L
s
.71645 .30902 m
.71645 .31277 L
s
.80303 .30902 m
.80303 .31277 L
s
.84632 .30902 m
.84632 .31277 L
s
.88961 .30902 m
.88961 .31277 L
s
.9329 .30902 m
.9329 .31277 L
s
.0671 .30902 m
.0671 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09213 m
.11664 .09213 L
s
gsave
.09789 .09213 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .20057 m
.11664 .20057 L
s
gsave
.09789 .20057 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .41746 m
.11664 .41746 L
s
gsave
.09789 .41746 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .5259 m
.11664 .5259 L
s
gsave
.09789 .5259 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.11039 .11924 m
.11414 .11924 L
s
.11039 .14635 m
.11414 .14635 L
s
.11039 .17346 m
.11414 .17346 L
s
.11039 .22768 m
.11414 .22768 L
s
.11039 .2548 m
.11414 .2548 L
s
.11039 .28191 m
.11414 .28191 L
s
.11039 .33613 m
.11414 .33613 L
s
.11039 .36324 m
.11414 .36324 L
s
.11039 .39035 m
.11414 .39035 L
s
.11039 .44457 m
.11414 .44457 L
s
.11039 .47168 m
.11414 .47168 L
s
.11039 .49879 m
.11414 .49879 L
s
.11039 .06502 m
.11414 .06502 L
s
.11039 .03791 m
.11414 .03791 L
s
.11039 .0108 m
.11414 .0108 L
s
.11039 .55301 m
.11414 .55301 L
s
.11039 .58012 m
.11414 .58012 L
s
.11039 .60723 m
.11414 .60723 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -123.812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.812 moveto
(@) show
81.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.812 moveto
(D) show
93.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.4) show
135.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
141.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
153.000 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
157.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
166.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
184.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02532 .30902 L
.02691 .30902 L
.03029 .30902 L
.03335 .30902 L
.03505 .30902 L
.0366 .30902 L
.03737 .30902 L
.03781 .30902 L
.03801 .30902 L
.03821 .30902 L
.03839 .30902 L
.03856 .30902 L
.03865 .30902 L
.03875 .30902 L
.03884 .30902 L
.03895 .30902 L
.03905 .30902 L
.03914 .30902 L
.03919 .30902 L
.03925 .30902 L
.03935 .30902 L
.03945 .30902 L
.03955 .30902 L
.03973 .30902 L
.03993 .30902 L
.04013 .30902 L
.04049 .30902 L
.04088 .30902 L
.04131 .30902 L
.04207 .30902 L
.04278 .30902 L
.04355 .30902 L
.04427 .30902 L
.04507 .30902 L
.04593 .30902 L
.04754 .30902 L
.04835 .30902 L
.04923 .30902 L
.0508 .30902 L
.05249 .30902 L
.0542 .30902 L
.05582 .30902 L
.05891 .30902 L
.06219 .30902 L
.06298 .30902 L
.06382 .30902 L
.06455 .30902 L
.06494 .30902 L
.06535 .30902 L
Mistroke
.06557 .30902 L
.06578 .30902 L
.06587 .30902 L
.06598 .30902 L
.06608 .30902 L
.06617 .30902 L
.06626 .30902 L
.06636 .30902 L
.06646 .30902 L
.06652 .30902 L
.06657 .30902 L
.06666 .30902 L
.06676 .30902 L
.06685 .30902 L
.06694 .30902 L
.06711 .30902 L
.06728 .30902 L
.06765 .30902 L
.06801 .30902 L
.06839 .30902 L
.06879 .30902 L
.06916 .30902 L
.07001 .30902 L
.07082 .30902 L
.0717 .30902 L
.07252 .30902 L
.07342 .30902 L
.07503 .30902 L
.07663 .30902 L
.07832 .30902 L
.08137 .30902 L
.08461 .30902 L
.0861 .30902 L
.08773 .30902 L
.08862 .30902 L
.089 .30902 L
.08943 .30902 L
.08984 .30902 L
.09002 .30902 L
.09022 .30902 L
.09032 .30902 L
.09043 .30902 L
.09052 .30902 L
.09062 .30902 L
.09067 .30902 L
.09073 .30902 L
.09083 .30902 L
.09088 .30902 L
.09093 .30902 L
.09099 .30902 L
Mistroke
.09105 .30902 L
.09115 .30902 L
.09125 .30902 L
.09135 .30902 L
.09144 .30902 L
.09162 .30902 L
.09181 .30902 L
.09223 .30902 L
.09262 .30902 L
.09298 .30902 L
.09337 .30902 L
.09409 .30902 L
.09485 .30902 L
.09569 .30902 L
.09656 .30902 L
.09738 .30902 L
.09902 .30902 L
.1005 .30902 L
.1037 .30902 L
.10678 .30903 L
.10834 .30903 L
.11006 .30904 L
.11084 .30904 L
.11125 .30904 L
.11168 .30904 L
.11207 .30904 L
.11227 .30904 L
.11248 .30904 L
.11258 .30904 L
.11268 .30904 L
.11277 .30904 L
.11286 .30904 L
.11294 .30904 L
.11303 .30904 L
.11312 .30904 L
.11321 .30904 L
.11332 .30904 L
.11341 .30904 L
.11352 .30904 L
.11363 .30904 L
.11384 .30904 L
.11403 .30904 L
.11441 .30904 L
.11477 .30904 L
.11519 .30904 L
.11558 .30904 L
.11645 .30903 L
.11724 .30903 L
.11797 .30903 L
.11963 .30902 L
Mistroke
.12126 .309 L
.12276 .30898 L
.12596 .30893 L
.12904 .30888 L
.1306 .30885 L
.13143 .30884 L
.13189 .30884 L
.13232 .30883 L
.13273 .30883 L
.13296 .30883 L
.13307 .30883 L
.13317 .30883 L
.13327 .30883 L
.13337 .30883 L
.13346 .30883 L
.13355 .30883 L
.13364 .30883 L
.13374 .30883 L
.1338 .30883 L
.13385 .30883 L
.13395 .30883 L
.13405 .30883 L
.13415 .30883 L
.13436 .30883 L
.13455 .30883 L
.13475 .30883 L
.1351 .30884 L
.13548 .30884 L
.13587 .30885 L
.13629 .30885 L
.13703 .30887 L
.13783 .3089 L
.1387 .30893 L
.14028 .30902 L
.14196 .30915 L
.14529 .30949 L
.1485 .30986 L
.14997 .31001 L
.1508 .31007 L
.15121 .3101 L
.15158 .31012 L
.15177 .31013 L
.15198 .31014 L
.15217 .31014 L
.15235 .31015 L
.15245 .31015 L
.15256 .31015 L
.15262 .31015 L
.15267 .31015 L
.15273 .31015 L
Mistroke
.15278 .31016 L
.15287 .31016 L
.15297 .31016 L
.15307 .31016 L
.15318 .31016 L
.15323 .31015 L
.15329 .31015 L
.1534 .31015 L
.15351 .31015 L
.15363 .31015 L
.15385 .31014 L
.15406 .31013 L
.15445 .31011 L
.15487 .31008 L
.15564 .30999 L
.15648 .30987 L
.15736 .30969 L
.15817 .30948 L
.15982 .30893 L
.16131 .3083 L
.16452 .30662 L
.16761 .305 L
.16844 .30466 L
.16921 .3044 L
.16963 .30429 L
.17002 .30421 L
.17022 .30417 L
.17044 .30414 L
.17057 .30413 L
.17068 .30412 L
.17079 .30411 L
.17085 .30411 L
.1709 .30411 L
.17099 .3041 L
.17109 .3041 L
.17119 .3041 L
.17129 .3041 L
.17139 .30411 L
.17148 .30411 L
.17156 .30412 L
.17165 .30412 L
.17186 .30415 L
.17207 .30418 L
.17246 .30426 L
.17282 .30437 L
.17316 .30449 L
.17393 .30487 L
.17476 .30543 L
.17555 .30613 L
.17704 .30784 L
Mistroke
.18011 .31284 L
.18337 .3192 L
.18488 .32184 L
.18567 .32299 L
.18651 .32397 L
.18694 .32435 L
.18716 .32452 L
.18741 .32467 L
.18763 .32479 L
.18783 .32487 L
.18793 .3249 L
.18804 .32492 L
.18814 .32494 L
.18823 .32496 L
.18832 .32496 L
.18842 .32497 L
.18852 .32496 L
.1886 .32496 L
.1887 .32494 L
.1888 .32492 L
.18891 .32489 L
.18902 .32486 L
.18923 .32476 L
.18942 .32465 L
.18985 .32431 L
.19024 .32389 L
.19065 .32333 L
.19139 .32202 L
.19219 .32015 L
.19306 .31756 L
.19462 .3116 L
.1963 .3036 L
.19961 .28558 L
.20127 .27742 L
.20207 .27414 L
.2028 .27171 L
.20317 .27072 L
.20357 .26984 L
.20375 .2695 L
.20395 .2692 L
.20413 .26897 L
.20429 .26879 L
.20448 .26865 L
.20458 .26859 L
.20468 .26855 L
.20477 .26853 L
.20486 .26852 L
.20495 .26852 L
.20505 .26854 L
.20514 .26857 L
Mistroke
.20525 .26862 L
.20535 .26869 L
.20544 .26877 L
.20566 .26902 L
.20587 .26933 L
.20628 .27015 L
.20664 .27114 L
.20746 .27426 L
.20822 .27825 L
.20894 .28297 L
.21055 .29678 L
.21203 .31276 L
.2152 .35172 L
.21679 .3698 L
.21824 .38275 L
.21863 .38538 L
.21905 .38779 L
.21944 .38961 L
.21981 .39087 L
.22001 .39138 L
.2202 .39174 L
.2203 .39189 L
.2204 .392 L
.22045 .39204 L
.22051 .39208 L
.22057 .3921 L
.22062 .39212 L
.22068 .39212 L
.22073 .39211 L
.22079 .39209 L
.22084 .39206 L
.22094 .39199 L
.22104 .39187 L
.22115 .3917 L
.22125 .3915 L
.22149 .39091 L
.22169 .39022 L
.22189 .38943 L
.22232 .38713 L
.2227 .38451 L
.22311 .3811 L
.2246 .36347 L
.22543 .35032 L
.22632 .33378 L
.22794 .29905 L
.22951 .26238 L
.23123 .22348 L
.23203 .20756 L
.23288 .19274 L
.23367 .18152 L
Mistroke
.23441 .17387 L
.2348 .17095 L
.235 .16982 L
.23512 .16927 L
.23522 .16884 L
.23533 .16848 L
.23544 .16816 L
.23556 .16792 L
.23562 .16783 L
.23568 .16776 L
.23574 .16772 L
.23579 .16769 L
.23589 .1677 L
.23595 .16773 L
.236 .16777 L
.23605 .16784 L
.23611 .16793 L
.23621 .16815 L
.2363 .16839 L
.23651 .16915 L
.2367 .1701 L
.23688 .17122 L
.23729 .17452 L
.23773 .17933 L
.23856 .19187 L
.23931 .20697 L
.241 .25232 L
.24422 .3666 L
.2457 .41971 L
.24654 .4468 L
.24732 .46889 L
.24816 .48833 L
.24893 .50144 L
.24913 .50409 L
.24935 .50657 L
.24954 .50837 L
.24974 .50998 L
.24996 .51125 L
.25009 .51175 L
.25014 .51194 L
.2502 .51209 L
.2503 .5123 L
.2504 .5124 L
.2505 .51241 L
.25056 .51237 L
.25062 .5123 L
.25072 .51209 L
.25077 .51194 L
.25083 .51175 L
.25103 .51086 L
Mistroke
.25114 .5102 L
.25125 .50935 L
.25147 .50748 L
.25188 .5025 L
.25227 .49647 L
.25303 .48011 L
.25376 .45966 L
.25536 .39982 L
.25683 .33102 L
.25846 .24895 L
.25999 .17502 L
.26144 .11573 L
.26226 .09002 L
.26302 .07245 L
.2634 .06597 L
.26361 .06314 L
.2638 .06094 L
.26399 .05932 L
.26408 .05864 L
.26419 .05804 L
.26427 .05764 L
.26437 .05731 L
.26445 .05711 L
.26453 .057 L
.26464 .05699 L
.2647 .05704 L
.26475 .05713 L
.26485 .05738 L
.26495 .05779 L
.26506 .05833 L
.26515 .05896 L
.26534 .06046 L
.26555 .0628 L
.26575 .06546 L
.2662 .07329 L
.26657 .08186 L
.26698 .09294 L
.26771 .11767 L
.26937 .19338 L
.27269 .38742 L
.27436 .47791 L
.27509 .51112 L
.2759 .54132 L
.27627 .55266 L
.27667 .5629 L
.27701 .57003 L
.27739 .57594 L
.2776 .57835 L
.27779 .58003 L
.2779 .58072 L
Mistroke
.278 .58121 L
.27805 .58141 L
.27811 .58159 L
.27817 .58171 L
.27822 .58179 L
.27831 .58182 L
.27839 .58174 L
.27849 .58154 L
.27859 .58118 L
.27869 .58065 L
.27879 .57999 L
.27898 .57838 L
.27917 .57622 L
.27934 .57372 L
.27975 .56633 L
.28015 .55692 L
.28057 .54441 L
.28205 .48407 L
.28366 .39544 L
.28535 .28966 L
.28695 .19296 L
.2884 .11975 L
.28921 .08861 L
.28998 .0668 L
.2904 .05825 L
.29078 .05259 L
.29099 .05051 L
.2911 .04959 L
.29121 .04891 L
.29127 .04862 L
.29132 .04839 L
.29142 .04807 L
.29148 .04796 L
.29154 .04791 L
.29159 .04789 L
.29166 .04794 L
.29176 .04813 L
.29181 .04831 L
.29187 .04851 L
.29197 .04905 L
.29209 .04982 L
.2923 .05169 L
.29248 .05395 L
.29294 .06155 L
.29338 .07145 L
.29415 .09522 L
.295 .12903 L
.29827 .30801 L
.2999 .39967 L
.30069 .43902 L
Mistroke
.30142 .47019 L
.30212 .49469 L
.30288 .51485 L
.30328 .5224 L
.30365 .52754 L
.30385 .5296 L
.30404 .53098 L
.30414 .53155 L
.3042 .53178 L
.30425 .53199 L
.30436 .53226 L
.30446 .53238 L
.30455 .53237 L
.30466 .53221 L
.30476 .53192 L
.30485 .53154 L
.30494 .53104 L
.30503 .5305 L
.30521 .52894 L
.30542 .52675 L
.30563 .5238 L
.30603 .51695 L
.30679 .49838 L
.3075 .47584 L
.31067 .33293 L
.31227 .25632 L
.31373 .19752 L
.31453 .17223 L
.3153 .1542 L
.31571 .14692 L
.3161 .14191 L
.3163 .13995 L
.31653 .13833 L
.31664 .13772 L
.3167 .13744 L
.31676 .13722 L
.31681 .13705 L
.31687 .1369 L
.31698 .13673 L
.31703 .13669 L
.31708 .13668 L
.31718 .13675 L
.31729 .13694 L
.31735 .1371 L
.3174 .13729 L
.3176 .13819 L
.3177 .13888 L
.3178 .13961 L
.31819 .14343 L
.31855 .14844 L
Mistroke
.31936 .1639 L
.32024 .18677 L
.32351 .30267 L
.32513 .35927 L
.32593 .38258 L
.32666 .40037 L
.32737 .4139 L
.32773 .41919 L
.32812 .42378 L
.32832 .42565 L
.32851 .42711 L
.32862 .42778 L
.32873 .42841 L
.32883 .42884 L
.32893 .42924 L
.32903 .42952 L
.32912 .42971 L
.32922 .42984 L
.32933 .42989 L
.32942 .42985 L
.32952 .42975 L
.3296 .42959 L
.32969 .42936 L
.3298 .42901 L
.32989 .4286 L
.33012 .4274 L
.33031 .42603 L
.33052 .42427 L
.33127 .41534 L
.33207 .40188 L
.33295 .38337 L
.3362 .30111 L
.3377 .26771 L
.33855 .25288 L
.33933 .24243 L
.33972 .23845 L
.34016 .23508 L
.34037 .2338 L
.34061 .23272 L
.34072 .23234 L
.34083 .232 L
.34093 .23178 L
.34103 .23159 L
.34109 .23152 L
.34114 .23147 L
.34125 .23141 L
.34135 .23141 L
.34144 .23146 L
.34154 .23157 L
.3416 .23166 L
Mistroke
.34165 .23175 L
.34176 .23201 L
.34187 .23232 L
.34207 .23304 L
.34225 .23386 L
.34265 .2363 L
.34302 .23919 L
.34342 .24305 L
.34425 .25279 L
.34572 .27489 L
.3474 .30275 L
.34895 .32614 L
.34973 .33595 L
.35046 .34343 L
.35122 .34931 L
.35162 .35159 L
.35183 .35254 L
.35205 .35337 L
.35225 .35397 L
.35236 .35423 L
.35247 .35447 L
.35258 .35464 L
.35268 .35476 L
.35277 .35485 L
.35287 .3549 L
.35292 .35492 L
.35297 .35492 L
.35303 .35492 L
.35309 .3549 L
.35319 .35485 L
.35324 .35481 L
.35329 .35476 L
.3534 .35462 L
.35352 .35443 L
.35376 .35391 L
.35397 .35329 L
.35416 .35262 L
.35459 .3507 L
.35537 .346 L
.35691 .33333 L
.35857 .31712 L
.36013 .30281 L
.36096 .29639 L
.36185 .29081 L
.36226 .28875 L
.3627 .28696 L
.36307 .28576 L
.36328 .28521 L
.36347 .28479 L
.36366 .28446 L
Mistroke
.36385 .28419 L
.36396 .28407 L
.36406 .28399 L
.36416 .28393 L
.36426 .28389 L
.36435 .28387 L
.36444 .28387 L
.36453 .28388 L
.36461 .28391 L
.36471 .28395 L
.36481 .28402 L
.365 .2842 L
.3652 .28447 L
.36543 .28485 L
.36583 .28575 L
.36658 .28809 L
.36746 .29173 L
.36827 .29567 L
.36991 .30442 L
.37144 .31205 L
.3722 .31521 L
.37291 .3177 L
.37331 .31883 L
.37374 .31986 L
.3741 .32056 L
.37449 .32115 L
.3747 .32138 L
.37488 .32155 L
.37506 .32168 L
.37516 .32173 L
.37525 .32177 L
.37535 .32181 L
.3754 .32182 L
.37546 .32183 L
.37555 .32184 L
.37565 .32184 L
.3757 .32184 L
.37576 .32183 L
.37582 .32182 L
.37587 .32181 L
.37597 .32177 L
.37608 .32172 L
.3763 .32159 L
.37654 .3214 L
.37696 .32092 L
.37738 .3203 L
.37777 .31961 L
.38092 .31166 L
.3825 .30767 L
.38319 .30622 L
Mistroke
.38395 .3049 L
.3847 .30391 L
.38511 .30351 L
.3855 .30323 L
.38572 .30311 L
.38592 .30302 L
.38611 .30296 L
.38621 .30294 L
.38631 .30292 L
.38641 .30291 L
.38651 .3029 L
.38661 .3029 L
.38667 .3029 L
.38673 .30291 L
.38678 .30291 L
.38684 .30292 L
.38696 .30294 L
.38706 .30296 L
.38717 .303 L
.38738 .30307 L
.3876 .30317 L
.388 .30341 L
.38889 .30416 L
.39051 .30605 L
.39211 .30813 L
.39356 .3098 L
.39431 .3105 L
.39513 .31109 L
.39558 .31134 L
.39599 .31151 L
.39639 .31164 L
.39659 .31168 L
.3967 .3117 L
.39681 .31172 L
.39691 .31173 L
.397 .31174 L
.3971 .31175 L
.39715 .31175 L
.3972 .31175 L
.39731 .31175 L
.3974 .31175 L
.39751 .31175 L
.39756 .31175 L
.39762 .31174 L
.39772 .31173 L
.3978 .31173 L
.398 .3117 L
.39819 .31166 L
.39836 .31163 L
.39878 .31151 L
Mistroke
.39916 .31137 L
.40004 .31098 L
.40318 .3092 L
.40401 .30878 L
.40491 .30841 L
.40532 .30827 L
.40575 .30814 L
.40616 .30804 L
.40653 .30797 L
.40672 .30794 L
.40692 .30792 L
.4071 .3079 L
.40729 .30788 L
.4074 .30788 L
.4075 .30787 L
.4076 .30787 L
.40766 .30787 L
.40772 .30786 L
.40781 .30786 L
.40792 .30786 L
.40802 .30786 L
.40811 .30787 L
.4082 .30787 L
.4083 .30787 L
.40848 .30788 L
.40866 .3079 L
.40882 .30791 L
.40919 .30795 L
.40958 .30801 L
.41116 .30833 L
.41263 .30869 L
.41412 .30904 L
.41491 .30919 L
.41575 .30932 L
.41617 .30937 L
.41664 .30941 L
.41684 .30943 L
.41706 .30944 L
.41726 .30945 L
.41745 .30946 L
.41765 .30947 L
.41775 .30947 L
.41787 .30947 L
.41792 .30947 L
.41798 .30948 L
.41804 .30948 L
.41809 .30948 L
.41819 .30948 L
.4183 .30948 L
.41839 .30948 L
Mistroke
.41849 .30948 L
.41858 .30947 L
.41867 .30947 L
.41887 .30947 L
.41907 .30946 L
.41947 .30944 L
.41984 .30942 L
.42066 .30936 L
.42214 .30923 L
.42382 .30906 L
.42455 .309 L
.42536 .30894 L
.42614 .3089 L
.42651 .30888 L
.42687 .30887 L
.42706 .30886 L
.42727 .30886 L
.42744 .30885 L
.42763 .30885 L
.42784 .30885 L
.42795 .30885 L
.42806 .30884 L
.42816 .30884 L
.42825 .30884 L
.42835 .30884 L
.42846 .30884 L
.42856 .30884 L
.42861 .30884 L
.42866 .30884 L
.42876 .30884 L
.42886 .30885 L
.42903 .30885 L
.42922 .30885 L
.42965 .30886 L
.43004 .30886 L
.43152 .30891 L
.43301 .30897 L
.43464 .30902 L
.43552 .30905 L
.43591 .30905 L
.43634 .30906 L
.43672 .30907 L
.43712 .30907 L
.43735 .30908 L
.43755 .30908 L
.43775 .30908 L
.43785 .30908 L
.43795 .30908 L
.43806 .30908 L
.43816 .30908 L
Mistroke
.43826 .30908 L
.43836 .30908 L
.43844 .30908 L
.43853 .30908 L
.43862 .30908 L
.43872 .30908 L
.43882 .30908 L
.43894 .30908 L
.43915 .30908 L
.43935 .30908 L
.43954 .30908 L
.44025 .30907 L
.44101 .30906 L
.44261 .30904 L
.44346 .30903 L
.44435 .30902 L
.44515 .30901 L
.44557 .30901 L
.44602 .309 L
.44644 .309 L
.44682 .309 L
.447 .309 L
.4472 .309 L
.44739 .309 L
.44757 .309 L
.44775 .309 L
.44785 .309 L
.44796 .309 L
.44805 .309 L
.44813 .309 L
.44822 .309 L
.44832 .309 L
.44838 .309 L
.44843 .309 L
.44849 .309 L
.44855 .309 L
.44865 .309 L
.44876 .309 L
.44896 .309 L
.44915 .309 L
.44958 .309 L
.44997 .309 L
.45084 .309 L
.4525 .30901 L
.45403 .30902 L
.4548 .30902 L
.45552 .30902 L
.45592 .30902 L
.45635 .30902 L
.45674 .30902 L
Mistroke
.4571 .30902 L
.4573 .30902 L
.45748 .30902 L
.45758 .30902 L
.45763 .30902 L
.45769 .30902 L
.45779 .30902 L
.45789 .30902 L
.45797 .30902 L
.45807 .30902 L
.45815 .30902 L
.45823 .30902 L
.45833 .30902 L
.45843 .30902 L
.45862 .30902 L
.45884 .30902 L
.45903 .30902 L
.45948 .30902 L
.46028 .30902 L
.46195 .30902 L
.46349 .30902 L
.46427 .30902 L
.465 .30902 L
.46575 .30902 L
.46615 .30902 L
.46636 .30902 L
.46658 .30901 L
.46679 .30901 L
.46689 .30901 L
.46701 .30901 L
.46711 .30901 L
.46721 .30901 L
.4673 .30901 L
.4674 .30901 L
.46751 .30901 L
.46757 .30901 L
.46762 .30901 L
.46773 .30901 L
.46782 .30901 L
.46794 .30901 L
.46805 .30901 L
.46829 .30901 L
.46866 .30901 L
.46907 .30902 L
.4699 .30902 L
.47159 .30902 L
.47314 .30902 L
.4739 .30902 L
.47431 .30902 L
.47474 .30902 L
Mistroke
.47515 .30902 L
.47552 .30902 L
.4757 .30902 L
.4759 .30902 L
.47608 .30902 L
.47625 .30902 L
.47644 .30902 L
.47655 .30902 L
.47665 .30902 L
.47674 .30902 L
.47683 .30902 L
.47692 .30902 L
.47702 .30902 L
.47712 .30902 L
.47717 .30902 L
.47722 .30902 L
.47742 .30902 L
.47752 .30902 L
.47763 .30902 L
.47786 .30902 L
.47828 .30902 L
.47873 .30902 L
.47955 .30902 L
.48115 .30902 L
.48199 .30902 L
.48288 .30902 L
.48368 .30902 L
.48413 .30902 L
.48455 .30902 L
.48494 .30902 L
.4853 .30902 L
.48549 .30902 L
.48559 .30902 L
.4857 .30902 L
.48581 .30902 L
.48591 .30902 L
.486 .30902 L
.48609 .30902 L
.48619 .30902 L
.48629 .30902 L
.48638 .30902 L
.48647 .30902 L
.48657 .30902 L
.48668 .30902 L
.48688 .30902 L
.48709 .30902 L
.48731 .30902 L
.48771 .30902 L
.48919 .30902 L
.49078 .30902 L
Mistroke
.49223 .30902 L
.49261 .30902 L
.49303 .30902 L
.49343 .30902 L
.49379 .30902 L
.49421 .30902 L
.49444 .30902 L
.49455 .30902 L
.49466 .30902 L
.49475 .30902 L
.49486 .30902 L
.49495 .30902 L
.49504 .30902 L
.49515 .30902 L
.49525 .30902 L
.4953 .30902 L
.49536 .30902 L
.49546 .30902 L
.49556 .30902 L
.49565 .30902 L
.49575 .30902 L
.49585 .30902 L
.49622 .30902 L
.49662 .30902 L
.49705 .30902 L
.49874 .30902 L
.50044 .30902 L
.50125 .30902 L
.50199 .30902 L
.50237 .30902 L
.50277 .30902 L
.50317 .30902 L
.50339 .30902 L
.5036 .30902 L
.5037 .30902 L
.5038 .30902 L
.50389 .30902 L
.50399 .30902 L
.50408 .30902 L
.50417 .30902 L
.50426 .30902 L
.50434 .30902 L
.50443 .30902 L
.50454 .30902 L
.50462 .30902 L
.50472 .30902 L
.50493 .30902 L
.50513 .30902 L
.50553 .30902 L
.50597 .30902 L
Mistroke
.50676 .30902 L
.50825 .30902 L
.50984 .30902 L
.51065 .30902 L
.5111 .30902 L
.51153 .30902 L
.51191 .30902 L
.51212 .30902 L
.51232 .30902 L
.51253 .30902 L
.51273 .30902 L
.51283 .30902 L
.51289 .30902 L
.51295 .30902 L
.513 .30902 L
.51305 .30902 L
.51315 .30902 L
.51325 .30902 L
.51335 .30902 L
.51343 .30902 L
.51353 .30902 L
.51363 .30902 L
.51373 .30902 L
.51392 .30902 L
.51426 .30902 L
.51464 .30902 L
.51619 .30902 L
.51787 .30902 L
.5187 .30902 L
.51947 .30902 L
.51986 .30902 L
.52028 .30902 L
.52052 .30902 L
.52074 .30902 L
.52096 .30902 L
.52116 .30902 L
.52134 .30902 L
.52144 .30902 L
.52154 .30902 L
.52159 .30902 L
.52164 .30902 L
.52175 .30902 L
.52184 .30902 L
.52194 .30902 L
.522 .30902 L
.52205 .30902 L
.52211 .30902 L
.52217 .30902 L
.52227 .30902 L
.52238 .30902 L
Mistroke
.52258 .30902 L
.52277 .30902 L
.52314 .30902 L
.52348 .30902 L
.52425 .30902 L
.52591 .30902 L
.52664 .30902 L
.52745 .30902 L
.52822 .30902 L
.52857 .30902 L
.52894 .30902 L
.52934 .30902 L
.5297 .30902 L
.52991 .30902 L
.5301 .30902 L
.53021 .30902 L
.53031 .30902 L
.53036 .30902 L
.53042 .30902 L
.53048 .30902 L
.53053 .30902 L
.53063 .30902 L
.53072 .30902 L
.53081 .30902 L
.5309 .30902 L
.531 .30902 L
.53111 .30902 L
.53131 .30902 L
.53169 .30902 L
.53203 .30902 L
.53369 .30902 L
.53451 .30902 L
.53537 .30902 L
.53617 .30902 L
.53656 .30902 L
.53691 .30902 L
.53726 .30902 L
.53763 .30902 L
.53783 .30902 L
.53802 .30902 L
.5382 .30902 L
.53839 .30902 L
.53859 .30902 L
.53867 .30902 L
.53877 .30902 L
.53882 .30902 L
.53888 .30902 L
.53898 .30902 L
.53908 .30902 L
.53918 .30902 L
Mistroke
.53924 .30902 L
.53929 .30902 L
.53934 .30902 L
.5394 .30902 L
.53951 .30902 L
.53962 .30902 L
.53982 .30902 L
.54001 .30902 L
.54041 .30902 L
.54085 .30902 L
.54165 .30902 L
.54314 .30902 L
.54395 .30902 L
.54472 .30902 L
.54552 .30902 L
.54595 .30902 L
.54617 .30902 L
.54641 .30902 L
.54662 .30902 L
.54681 .30902 L
.547 .30902 L
.54718 .30902 L
.54728 .30902 L
.54733 .30902 L
.54738 .30902 L
.54748 .30902 L
.54758 .30902 L
.54763 .30902 L
.54769 .30902 L
.54779 .30902 L
.54784 .30902 L
.5479 .30902 L
.54802 .30902 L
.54812 .30902 L
.54824 .30902 L
.54845 .30902 L
.54884 .30902 L
.54971 .30902 L
.55128 .30902 L
.55211 .30902 L
.553 .30902 L
.55344 .30902 L
.55386 .30902 L
.55427 .30902 L
.55464 .30902 L
.555 .30902 L
.55518 .30902 L
.55528 .30902 L
.55538 .30902 L
.55547 .30902 L
Mistroke
.55558 .30902 L
.55568 .30902 L
.55574 .30902 L
.55579 .30902 L
.55589 .30902 L
.55598 .30902 L
.55608 .30902 L
.55618 .30902 L
.55627 .30902 L
.55637 .30902 L
.55655 .30902 L
.55676 .30902 L
.55696 .30902 L
.55778 .30902 L
.55927 .30902 L
.56007 .30902 L
.56092 .30902 L
.56165 .30902 L
.56207 .30902 L
.56246 .30902 L
.56283 .30902 L
.56322 .30902 L
.56343 .30902 L
.56361 .30902 L
.56372 .30902 L
.56382 .30902 L
.56388 .30902 L
.56394 .30902 L
.56399 .30902 L
.56404 .30902 L
.56414 .30902 L
.56422 .30902 L
.56433 .30902 L
.56442 .30902 L
.56452 .30902 L
.56462 .30902 L
.56482 .30902 L
.565 .30902 L
.56519 .30902 L
.56553 .30902 L
.56714 .30902 L
.56798 .30902 L
.56887 .30902 L
.56967 .30902 L
.57009 .30902 L
.57055 .30902 L
.57096 .30902 L
.57134 .30902 L
.57153 .30902 L
.57173 .30902 L
Mistroke
.57182 .30902 L
.57191 .30902 L
.572 .30902 L
.57209 .30902 L
.57218 .30902 L
.57228 .30902 L
.57238 .30902 L
.57248 .30902 L
.57258 .30902 L
.57267 .30902 L
.57275 .30902 L
.57284 .30902 L
.57305 .30902 L
.57326 .30902 L
.57365 .30902 L
.57512 .30902 L
.57671 .30902 L
.5774 .30902 L
.57816 .30902 L
.57858 .30902 L
.57896 .30902 L
.57933 .30902 L
.57954 .30902 L
.57972 .30902 L
.57983 .30902 L
.57994 .30902 L
.58003 .30902 L
.58014 .30902 L
.5802 .30902 L
.58025 .30902 L
.58035 .30902 L
.58041 .30902 L
.58047 .30902 L
.58053 .30902 L
.58059 .30902 L
.58068 .30902 L
.58077 .30902 L
.58087 .30902 L
.58098 .30902 L
.5812 .30902 L
.5814 .30902 L
.58219 .30902 L
.58292 .30902 L
.58378 .30902 L
.58458 .30902 L
.58537 .30902 L
.58579 .30902 L
.58623 .30902 L
.5866 .30902 L
.58701 .30902 L
Mistroke
.58719 .30902 L
.58738 .30902 L
.58754 .30902 L
.58772 .30902 L
.58793 .30902 L
.58804 .30902 L
.58815 .30902 L
.58824 .30902 L
.58833 .30902 L
.58843 .30902 L
.58854 .30902 L
.58864 .30902 L
.5887 .30902 L
.58876 .30902 L
.58896 .30902 L
.58908 .30902 L
.5892 .30902 L
.58943 .30902 L
.59027 .30902 L
.59104 .30902 L
.59183 .30902 L
.59267 .30902 L
.5934 .30902 L
.5942 .30902 L
.59462 .30902 L
.59502 .30902 L
.59539 .30902 L
.5956 .30902 L
.59569 .30902 L
.59579 .30902 L
.59588 .30902 L
.59598 .30902 L
.59606 .30902 L
.59615 .30902 L
.59625 .30902 L
.59634 .30902 L
.59644 .30902 L
.59654 .30902 L
.59662 .30902 L
.59671 .30902 L
.59687 .30902 L
.59705 .30902 L
.59724 .30902 L
.59805 .30902 L
.59879 .30902 L
.59966 .30902 L
.60047 .30902 L
.60127 .30902 L
.60199 .30902 L
.6024 .30902 L
Mistroke
.60279 .30902 L
.60301 .30902 L
.60321 .30902 L
.60342 .30902 L
.60353 .30902 L
.60365 .30902 L
.60376 .30902 L
.60386 .30902 L
.60395 .30902 L
.60405 .30902 L
.60415 .30902 L
.60424 .30902 L
.60432 .30902 L
.60441 .30902 L
.60451 .30902 L
.60462 .30902 L
.60483 .30902 L
.60522 .30902 L
.60599 .30902 L
.6067 .30902 L
.6082 .30902 L
.60904 .30902 L
.60982 .30902 L
.61022 .30902 L
.61065 .30902 L
.61087 .30902 L
.61111 .30902 L
.61122 .30902 L
.61133 .30902 L
.61144 .30902 L
.61153 .30902 L
.61163 .30902 L
.61173 .30902 L
.61183 .30902 L
.61188 .30902 L
.61193 .30902 L
.61202 .30902 L
.61212 .30902 L
.61221 .30902 L
.61231 .30902 L
.61252 .30902 L
.61271 .30902 L
.61315 .30902 L
.61481 .30902 L
.61554 .30902 L
.61635 .30902 L
.61672 .30902 L
.61712 .30902 L
.61746 .30902 L
.61784 .30902 L
Mistroke
.61824 .30902 L
.61846 .30902 L
.61867 .30902 L
.61886 .30902 L
.61903 .30902 L
.61913 .30902 L
.61923 .30902 L
.61933 .30902 L
.61942 .30902 L
.61953 .30902 L
.61962 .30902 L
.61971 .30902 L
.6198 .30902 L
.6199 .30902 L
.62001 .30902 L
.6202 .30902 L
.62058 .30902 L
.62093 .30902 L
.62259 .30902 L
.62334 .30902 L
.62413 .30902 L
.62455 .30902 L
.62501 .30902 L
.62542 .30902 L
.62581 .30902 L
.62602 .30902 L
.62621 .30902 L
.62642 .30902 L
.62653 .30902 L
.62665 .30902 L
.62675 .30902 L
.62684 .30902 L
.62693 .30902 L
.62703 .30902 L
.62713 .30902 L
.62723 .30902 L
.62733 .30902 L
.62739 .30902 L
.62744 .30902 L
.62763 .30902 L
.62781 .30902 L
.62821 .30902 L
.62893 .30902 L
.63057 .30902 L
.63137 .30902 L
.6321 .30902 L
.63246 .30902 L
.63285 .30902 L
.63322 .30902 L
.63357 .30902 L
Mistroke
.63376 .30902 L
.63393 .30902 L
.63412 .30902 L
.63423 .30902 L
.63433 .30902 L
.63443 .30902 L
.63452 .30902 L
.63462 .30902 L
.63468 .30902 L
.63473 .30902 L
.63483 .30902 L
.63489 .30902 L
.63494 .30902 L
.63504 .30902 L
.63514 .30902 L
.63535 .30902 L
.63554 .30902 L
.6359 .30902 L
.63671 .30902 L
.63818 .30902 L
.63895 .30902 L
.63938 .30902 L
.63977 .30902 L
.64015 .30902 L
.64055 .30902 L
.64073 .30902 L
.64091 .30902 L
.64107 .30902 L
.64125 .30902 L
.64145 .30902 L
.64155 .30902 L
.64165 .30902 L
.64174 .30902 L
.64184 .30902 L
.64193 .30902 L
.64201 .30902 L
.64211 .30902 L
.64222 .30902 L
.64231 .30902 L
.6424 .30902 L
.64251 .30902 L
.64262 .30902 L
.64283 .30902 L
.64322 .30902 L
.6436 .30902 L
.6443 .30902 L
.64577 .30902 L
.64661 .30902 L
.64701 .30902 L
.64739 .30902 L
Mistroke
.64776 .30902 L
.64816 .30902 L
.64838 .30902 L
.64858 .30902 L
.64878 .30902 L
.64898 .30902 L
.6491 .30902 L
.6492 .30902 L
.64926 .30902 L
.64932 .30902 L
.64938 .30902 L
.64944 .30902 L
.6495 .30902 L
.64955 .30902 L
.64965 .30902 L
.6497 .30902 L
.64975 .30902 L
.64987 .30902 L
.65006 .30902 L
.65026 .30902 L
.65067 .30902 L
.65236 .30902 L
.65316 .30902 L
.6539 .30902 L
.65467 .30902 L
.65507 .30902 L
.65528 .30902 L
.6555 .30902 L
.65571 .30902 L
.65591 .30902 L
.6561 .30902 L
.65619 .30902 L
.65629 .30902 L
.65639 .30902 L
.65647 .30902 L
.65656 .30902 L
.65664 .30902 L
.65673 .30902 L
.65682 .30902 L
.65691 .30902 L
.65702 .30902 L
.65711 .30902 L
.65721 .30902 L
.65741 .30902 L
.65777 .30902 L
.65819 .30902 L
.65858 .30902 L
.66004 .30902 L
.66089 .30902 L
.6613 .30902 L
Mistroke
.66168 .30902 L
.66203 .30902 L
.6624 .30902 L
.66278 .30902 L
.66298 .30902 L
.66318 .30902 L
.66338 .30902 L
.66348 .30902 L
.66358 .30902 L
.66369 .30902 L
.66379 .30902 L
.66384 .30902 L
.66389 .30902 L
.66395 .30902 L
.66401 .30902 L
.66411 .30902 L
.66421 .30902 L
.6643 .30902 L
.66439 .30902 L
.6646 .30902 L
.6648 .30902 L
.66517 .30902 L
.66552 .30902 L
.66629 .30902 L
.66707 .30902 L
.66792 .30902 L
.66831 .30902 L
.66872 .30902 L
.6691 .30902 L
.66945 .30902 L
.66981 .30902 L
.67 .30902 L
.6702 .30902 L
.67038 .30902 L
.67056 .30902 L
.67072 .30902 L
.6708 .30902 L
.67089 .30902 L
.671 .30902 L
.6711 .30902 L
.67119 .30902 L
.67129 .30902 L
.67134 .30902 L
.6714 .30902 L
.67145 .30902 L
.67151 .30902 L
.67161 .30902 L
.67171 .30902 L
.67191 .30902 L
.67211 .30902 L
Mistroke
.67248 .30902 L
.67408 .30902 L
.67478 .30902 L
.67553 .30902 L
.67595 .30902 L
.67634 .30902 L
.67671 .30902 L
.6771 .30902 L
.6773 .30902 L
.67752 .30902 L
.67762 .30902 L
.67772 .30902 L
.67782 .30902 L
.6779 .30902 L
.67801 .30902 L
.67807 .30902 L
.67812 .30902 L
.67822 .30902 L
.67833 .30902 L
.67838 .30902 L
.67844 .30902 L
.67851 .30902 L
.67856 .30902 L
.67867 .30902 L
.67879 .30902 L
.67899 .30902 L
.67921 .30902 L
.6796 .30902 L
.68049 .30902 L
.68127 .30902 L
.68211 .30902 L
.6825 .30902 L
.68292 .30902 L
.68331 .30902 L
.68367 .30902 L
.68401 .30902 L
.68437 .30902 L
.68458 .30902 L
.68477 .30902 L
.68495 .30902 L
.68504 .30902 L
.68514 .30902 L
.68524 .30902 L
.68533 .30902 L
.68542 .30902 L
.68551 .30902 L
.68561 .30902 L
.68567 .30902 L
.68572 .30902 L
.68591 .30902 L
Mistroke
.68609 .30902 L
.68629 .30902 L
.68664 .30902 L
.6883 .30902 L
.68913 .30902 L
.6899 .30902 L
.69029 .30902 L
.69071 .30902 L
.69095 .30902 L
.69117 .30902 L
.69139 .30902 L
.69159 .30902 L
.69177 .30902 L
.69186 .30902 L
.69196 .30902 L
.69207 .30902 L
.69212 .30902 L
.69218 .30902 L
.69227 .30902 L
.69237 .30902 L
.69243 .30902 L
.69248 .30902 L
.69253 .30902 L
.69259 .30902 L
.69269 .30902 L
.6928 .30902 L
.69301 .30902 L
.6932 .30902 L
.69391 .30902 L
.69467 .30902 L
.69544 .30902 L
.69626 .30902 L
.69669 .30902 L
.69716 .30902 L
.69759 .30902 L
.69778 .30902 L
.69799 .30902 L
.69818 .30902 L
.69838 .30902 L
.6986 .30902 L
.69869 .30902 L
.69879 .30902 L
.6989 .30902 L
.69899 .30902 L
.69908 .30902 L
.69918 .30902 L
.69927 .30902 L
.69935 .30902 L
.69943 .30902 L
.69953 .30902 L
Mistroke
.69958 .30902 L
.69964 .30902 L
.69974 .30902 L
.69997 .30902 L
.70019 .30902 L
.7004 .30902 L
.70119 .30902 L
.702 .30902 L
.70286 .30902 L
.7036 .30902 L
.70402 .30902 L
.70441 .30902 L
.70481 .30902 L
.705 .30902 L
.70519 .30902 L
.70535 .30902 L
.70553 .30902 L
.70571 .30902 L
.70581 .30902 L
.7059 .30902 L
.70599 .30902 L
.7061 .30902 L
.70615 .30902 L
.7062 .30902 L
.7063 .30902 L
.7064 .30902 L
.7065 .30902 L
.70658 .30902 L
.70667 .30902 L
.70688 .30902 L
.7071 .30902 L
.7075 .30902 L
.70909 .30902 L
.70979 .30902 L
.71054 .30902 L
.71096 .30902 L
.71135 .30902 L
.71171 .30902 L
.71192 .30902 L
.71211 .30902 L
.71232 .30902 L
.71252 .30902 L
.71263 .30902 L
.71274 .30902 L
.7128 .30902 L
.71286 .30902 L
.71292 .30902 L
.71297 .30902 L
.71308 .30902 L
.71317 .30902 L
Mistroke
.71328 .30902 L
.71333 .30902 L
.71339 .30902 L
.71359 .30902 L
.71378 .30902 L
.71418 .30902 L
.71462 .30902 L
.71541 .30902 L
.71617 .30902 L
.7169 .30902 L
.71729 .30902 L
.71772 .30902 L
.71811 .30902 L
.71847 .30902 L
.71866 .30902 L
.71886 .30902 L
.71909 .30902 L
.71929 .30902 L
.7194 .30902 L
.71946 .30902 L
.71952 .30902 L
.71958 .30902 L
.71964 .30902 L
.71974 .30902 L
.71985 .30902 L
.7199 .30902 L
.71996 .30902 L
.72005 .30902 L
.72016 .30902 L
.72026 .30902 L
.72036 .30902 L
.72056 .30902 L
.72092 .30902 L
.72174 .30902 L
.72321 .30902 L
.72397 .30902 L
.72441 .30902 L
.72481 .30902 L
.72503 .30902 L
.72523 .30902 L
.72542 .30902 L
.72562 .30902 L
.72584 .30902 L
.72604 .30902 L
.72617 .30902 L
.72623 .30902 L
.72628 .30902 L
.72639 .30902 L
.72644 .30902 L
.7265 .30902 L
Mistroke
.7266 .30902 L
.72665 .30902 L
.7267 .30902 L
.7268 .30902 L
.7269 .30902 L
.72699 .30902 L
.72707 .30902 L
.72726 .30902 L
.72765 .30902 L
.72808 .30902 L
.72955 .30902 L
.73038 .30902 L
.73116 .30902 L
.73155 .30902 L
.73197 .30902 L
.73221 .30902 L
.73243 .30902 L
.73264 .30902 L
.73275 .30902 L
.73286 .30902 L
.73296 .30902 L
.73305 .30902 L
.73314 .30902 L
.73323 .30902 L
.73333 .30902 L
.73338 .30902 L
.73344 .30902 L
.73354 .30902 L
.73363 .30902 L
.73382 .30902 L
.73399 .30902 L
.73436 .30902 L
.73602 .30902 L
.73675 .30902 L
.73754 .30902 L
.73799 .30902 L
.7384 .30902 L
.73859 .30902 L
.73881 .30902 L
.73901 .30902 L
.7392 .30902 L
.7393 .30902 L
.73939 .30902 L
.73948 .30902 L
.73957 .30902 L
.73967 .30902 L
.73976 .30902 L
.73982 .30902 L
.73987 .30902 L
.73997 .30902 L
Mistroke
.74006 .30902 L
.74016 .30902 L
.74024 .30902 L
.74032 .30902 L
.74052 .30902 L
.7407 .30902 L
.7415 .30902 L
.74236 .30902 L
.74317 .30902 L
.74361 .30902 L
.74406 .30902 L
.74446 .30902 L
.7449 .30902 L
.74509 .30902 L
.7453 .30902 L
.7455 .30902 L
.74568 .30902 L
.74587 .30902 L
.74598 .30902 L
.74608 .30902 L
.74617 .30902 L
.74625 .30902 L
.74635 .30902 L
.74645 .30902 L
.74655 .30902 L
.7466 .30902 L
.74665 .30902 L
.74675 .30902 L
.74685 .30902 L
.74706 .30902 L
.74729 .30902 L
.74817 .30902 L
.74898 .30902 L
.74983 .30902 L
.75025 .30902 L
.75063 .30902 L
.75097 .30902 L
.75135 .30902 L
.75173 .30902 L
.75193 .30902 L
.75213 .30902 L
.75223 .30902 L
.75234 .30902 L
.75243 .30902 L
.75253 .30902 L
.75264 .30902 L
.75274 .30902 L
.7528 .30902 L
.75286 .30902 L
.75291 .30902 L
Mistroke
.75297 .30902 L
.75307 .30902 L
.75317 .30902 L
.75322 .30902 L
.75328 .30902 L
.75338 .30902 L
.75358 .30902 L
.75376 .30902 L
.75449 .30902 L
.75525 .30902 L
.75601 .30902 L
.75643 .30902 L
.75683 .30902 L
.7572 .30902 L
.7576 .30902 L
.75796 .30902 L
.7583 .30902 L
.75849 .30902 L
.75867 .30902 L
.75887 .30902 L
.75897 .30902 L
.75907 .30902 L
.75917 .30902 L
.75925 .30902 L
.75935 .30902 L
.75945 .30902 L
.75954 .30902 L
.75962 .30902 L
.7597 .30902 L
.7598 .30902 L
.7599 .30902 L
.75999 .30902 L
.7602 .30902 L
.76058 .30902 L
.76145 .30902 L
.76225 .30902 L
.76311 .30902 L
.76352 .30902 L
.76391 .30902 L
.76426 .30902 L
.76446 .30902 L
.76464 .30902 L
.76483 .30902 L
.76501 .30902 L
.76521 .30902 L
.76532 .30902 L
.76542 .30902 L
.76552 .30902 L
.76562 .30902 L
.76572 .30902 L
Mistroke
.76578 .30902 L
.76584 .30902 L
.76594 .30902 L
.76603 .30902 L
.76613 .30902 L
.76624 .30902 L
.76633 .30902 L
.76641 .30902 L
.7666 .30902 L
.76694 .30902 L
.76771 .30902 L
.76852 .30902 L
.76938 .30902 L
.77011 .30902 L
.77053 .30902 L
.77092 .30902 L
.77111 .30902 L
.77132 .30902 L
.77152 .30902 L
.7717 .30902 L
.77179 .30902 L
.77188 .30902 L
.77196 .30902 L
.77204 .30902 L
.77214 .30902 L
.77222 .30902 L
.77231 .30902 L
.77241 .30902 L
.77246 .30902 L
.77252 .30902 L
.77262 .30902 L
.77272 .30902 L
.77281 .30902 L
.77324 .30902 L
.77361 .30902 L
.77401 .30902 L
.77482 .30902 L
.7756 .30902 L
.77629 .30902 L
.77668 .30902 L
.77705 .30902 L
.77725 .30902 L
.77744 .30902 L
.77762 .30902 L
.7778 .30902 L
.778 .30902 L
.77819 .30902 L
.77829 .30902 L
.77839 .30902 L
.77849 .30902 L
Mistroke
.77855 .30902 L
.7786 .30902 L
.77871 .30902 L
.77876 .30902 L
.77882 .30902 L
.77892 .30902 L
.77902 .30902 L
.77923 .30902 L
.77946 .30902 L
.78028 .30902 L
.78186 .30902 L
.78229 .30902 L
.78275 .30902 L
.78319 .30902 L
.78358 .30902 L
.78378 .30902 L
.78399 .30902 L
.78417 .30902 L
.78437 .30902 L
.78448 .30902 L
.78458 .30902 L
.78463 .30902 L
.7847 .30902 L
.78475 .30902 L
.78481 .30902 L
.78491 .30902 L
.78501 .30902 L
.78506 .30902 L
.78511 .30902 L
.78522 .30902 L
.78531 .30902 L
.7854 .30902 L
.78561 .30902 L
.78602 .30902 L
.78676 .30902 L
.78749 .30902 L
.78826 .30902 L
.78866 .30902 L
.78911 .30902 L
.78951 .30902 L
.78989 .30902 L
.7901 .30902 L
.79032 .30902 L
.79051 .30902 L
.79071 .30902 L
.79083 .30902 L
.79093 .30902 L
.79099 .30902 L
.79106 .30902 L
.79112 .30902 L
Mistroke
.79117 .30902 L
.79127 .30902 L
.79133 .30902 L
.79138 .30902 L
.79148 .30902 L
.79154 .30902 L
.7916 .30902 L
.7918 .30902 L
.79199 .30902 L
.79243 .30902 L
.79321 .30902 L
.79393 .30902 L
.79471 .30902 L
.79515 .30902 L
.79556 .30902 L
.79595 .30902 L
.79616 .30902 L
.79636 .30902 L
.79655 .30902 L
.79676 .30902 L
.79685 .30902 L
.79695 .30902 L
.79704 .30902 L
.79713 .30902 L
.79722 .30902 L
.79733 .30902 L
.79742 .30902 L
.79752 .30902 L
.79757 .30902 L
.79762 .30902 L
.79772 .30902 L
.79778 .30902 L
.79784 .30902 L
.79794 .30902 L
.79831 .30902 L
.79865 .30902 L
.79942 .30902 L
.80015 .30902 L
.80093 .30902 L
.80138 .30902 L
.80179 .30902 L
.80198 .30902 L
.8022 .30902 L
.80259 .30902 L
.80278 .30902 L
.80298 .30902 L
.80307 .30902 L
.80317 .30902 L
.80326 .30902 L
.80334 .30902 L
Mistroke
.80344 .30902 L
.8035 .30902 L
.80355 .30902 L
.80364 .30902 L
.80374 .30902 L
.80379 .30902 L
.80385 .30902 L
.80391 .30902 L
.80397 .30902 L
.80418 .30902 L
.8044 .30902 L
.8046 .30902 L
.80499 .30902 L
.80586 .30902 L
.80664 .30902 L
.80706 .30902 L
.80746 .30902 L
.80783 .30902 L
.80823 .30902 L
.80841 .30902 L
.8086 .30902 L
.80876 .30902 L
.80893 .30902 L
.80904 .30902 L
.80914 .30902 L
.80923 .30902 L
.80933 .30902 L
.80943 .30902 L
.80951 .30902 L
.8096 .30902 L
.8097 .30902 L
.8098 .30902 L
.80986 .30902 L
.80992 .30902 L
.81002 .30902 L
.81007 .30902 L
.81012 .30902 L
.81033 .30902 L
.81052 .30902 L
.81122 .30902 L
.81199 .30902 L
.81282 .30902 L
.81359 .30902 L
.81398 .30902 L
.81439 .30902 L
.81463 .30902 L
.81486 .30902 L
.81506 .30902 L
.81517 .30902 L
.81528 .30902 L
Mistroke
.81537 .30902 L
.81547 .30902 L
.81556 .30902 L
.81567 .30902 L
.81576 .30902 L
.81586 .30902 L
.81595 .30902 L
.81603 .30902 L
.81608 .30902 L
.81614 .30902 L
.81624 .30902 L
.81634 .30902 L
.81646 .30902 L
.81686 .30902 L
.81855 .30902 L
.81893 .30902 L
.81935 .30902 L
.81972 .30902 L
.82011 .30902 L
.82035 .30902 L
.82056 .30902 L
.82077 .30902 L
.82099 .30902 L
.8212 .30902 L
.8213 .30902 L
.8214 .30902 L
.82149 .30902 L
.82159 .30902 L
.82169 .30902 L
.82179 .30902 L
.82188 .30902 L
.82194 .30902 L
.82199 .30902 L
.8221 .30902 L
.82216 .30902 L
.82221 .30902 L
.8223 .30902 L
.8224 .30902 L
.8226 .30902 L
.82307 .30902 L
.82349 .30902 L
.82427 .30902 L
.82511 .30902 L
.82555 .30902 L
.82596 .30902 L
.82634 .30902 L
.82654 .30902 L
.82675 .30902 L
.82695 .30902 L
.82712 .30902 L
Mistroke
.8273 .30902 L
.82747 .30902 L
.82756 .30902 L
.82766 .30902 L
.82774 .30902 L
.82784 .30902 L
.82794 .30902 L
.828 .30902 L
.82805 .30902 L
.82815 .30902 L
.82825 .30902 L
.82835 .30902 L
.82845 .30902 L
.82865 .30902 L
.82901 .30902 L
.82983 .30902 L
.83059 .30902 L
.8313 .30902 L
.8317 .30902 L
.83206 .30902 L
.83246 .30902 L
.83268 .30902 L
.83289 .30902 L
.8331 .30902 L
.83321 .30902 L
.83331 .30902 L
.83341 .30902 L
.83352 .30902 L
.83361 .30902 L
.8337 .30902 L
.83381 .30902 L
.83391 .30902 L
.83396 .30902 L
.83401 .30902 L
.83407 .30902 L
.83413 .30902 L
.83418 .30902 L
.83424 .30902 L
.83435 .30902 L
.83446 .30902 L
.83458 .30902 L
.83498 .30902 L
.83539 .30902 L
.83614 .30902 L
.83694 .30902 L
.83739 .30902 L
.83781 .30902 L
.83821 .30902 L
.83842 .30902 L
.83864 .30902 L
Mistroke
.83883 .30902 L
.83903 .30902 L
.83922 .30902 L
.83939 .30902 L
.83949 .30902 L
.83959 .30902 L
.83968 .30902 L
.83977 .30902 L
.83985 .30902 L
.83993 .30902 L
.84002 .30902 L
.84011 .30902 L
.8402 .30902 L
.8403 .30902 L
.84047 .30902 L
.84066 .30902 L
.84087 .30902 L
.84174 .30902 L
.84257 .30902 L
.84331 .30902 L
.84373 .30902 L
.84412 .30902 L
.84449 .30902 L
.84484 .30902 L
.84504 .30902 L
.84522 .30902 L
.84532 .30902 L
.84542 .30902 L
.84553 .30902 L
.84564 .30902 L
.84574 .30902 L
.84579 .30902 L
.84585 .30902 L
.84594 .30902 L
.84604 .30902 L
.84614 .30902 L
.84622 .30902 L
.84641 .30902 L
.84662 .30902 L
.84682 .30902 L
.84725 .30902 L
.84805 .30902 L
.84891 .30902 L
.84964 .30902 L
.85005 .30902 L
.85024 .30902 L
.85044 .30902 L
.85062 .30902 L
.85082 .30902 L
.85102 .30902 L
Mistroke
.85111 .30902 L
.85121 .30902 L
.85131 .30902 L
.8514 .30902 L
.85149 .30902 L
.85158 .30902 L
.85167 .30902 L
.85174 .30902 L
.85183 .30902 L
.85192 .30902 L
.85203 .30902 L
.85213 .30902 L
.85235 .30902 L
.85254 .30902 L
.85275 .30902 L
.85352 .30902 L
.85434 .30902 L
.85478 .30902 L
.85524 .30902 L
.85564 .30902 L
.85585 .30902 L
.85608 .30902 L
.85629 .30902 L
.85648 .30902 L
.85667 .30902 L
.85686 .30902 L
.85704 .30902 L
.85714 .30902 L
.85724 .30902 L
.85735 .30902 L
.8574 .30902 L
.85746 .30902 L
.85756 .30902 L
.85765 .30902 L
.85775 .30902 L
.85784 .30902 L
.85792 .30902 L
.85801 .30902 L
.85821 .30902 L
.85839 .30902 L
.86006 .30902 L
.86078 .30902 L
.86118 .30902 L
.86156 .30902 L
.86178 .30902 L
.86201 .30902 L
.86223 .30902 L
.86242 .30902 L
.86262 .30902 L
.86272 .30902 L
Mistroke
.86284 .30902 L
.86294 .30902 L
.86303 .30902 L
.86312 .30902 L
.86322 .30902 L
.86332 .30902 L
.86337 .30902 L
.86343 .30902 L
.86352 .30902 L
.86362 .30902 L
.86371 .30902 L
.86379 .30902 L
.86398 .30902 L
.86419 .30902 L
.86438 .30902 L
.8648 .30902 L
.86627 .30902 L
.86666 .30902 L
.86706 .30902 L
.86745 .30902 L
.8678 .30902 L
.86801 .30902 L
.86821 .30902 L
.86843 .30902 L
.86854 .30902 L
.86865 .30902 L
.86876 .30902 L
.86885 .30902 L
.86895 .30902 L
.86904 .30902 L
.86914 .30902 L
.86924 .30902 L
.86929 .30902 L
.86935 .30902 L
.86941 .30902 L
.86946 .30902 L
.86956 .30902 L
.86966 .30902 L
.86984 .30902 L
.87025 .30902 L
.87108 .30902 L
.87185 .30902 L
.87257 .30902 L
.87297 .30902 L
.87339 .30902 L
.87361 .30902 L
.87381 .30902 L
.87404 .30902 L
.87416 .30902 L
.87428 .30902 L
Mistroke
.87439 .30902 L
.87449 .30902 L
.8746 .30902 L
.87466 .30902 L
.87471 .30902 L
.87481 .30902 L
.87487 .30902 L
.87492 .30902 L
.87502 .30902 L
.87512 .30902 L
.87522 .30902 L
.87532 .30902 L
.87542 .30902 L
.87552 .30902 L
.8759 .30902 L
.87736 .30902 L
.87776 .30902 L
.87819 .30902 L
.87857 .30902 L
.87898 .30902 L
.87938 .30902 L
.8796 .30902 L
.87981 .30902 L
.88 .30902 L
.88017 .30902 L
.88027 .30902 L
.88038 .30902 L
.88047 .30902 L
.88057 .30902 L
.88066 .30902 L
.88077 .30902 L
.88087 .30902 L
.88096 .30902 L
.88106 .30902 L
.88118 .30902 L
.88139 .30902 L
.88184 .30902 L
.88225 .30902 L
.88297 .30902 L
.88375 .30902 L
.88419 .30902 L
.8846 .30902 L
.88499 .30902 L
.88519 .30902 L
.8854 .30902 L
.8856 .30902 L
.88571 .30902 L
.88583 .30902 L
.88592 .30902 L
.88603 .30902 L
Mistroke
.88613 .30902 L
.88623 .30902 L
.88632 .30902 L
.88641 .30902 L
.8865 .30902 L
.88659 .30902 L
.88668 .30902 L
.88679 .30902 L
.88697 .30902 L
.88719 .30902 L
.88743 .30902 L
.88786 .30902 L
.88865 .30902 L
.88905 .30902 L
.88948 .30902 L
.88988 .30902 L
.89026 .30902 L
.89046 .30902 L
.89068 .30902 L
.89086 .30902 L
.89106 .30902 L
.89128 .30902 L
.89141 .30902 L
.89152 .30902 L
.89163 .30902 L
.89173 .30902 L
.89178 .30902 L
.89183 .30902 L
.89189 .30902 L
.89195 .30902 L
.89205 .30902 L
.8921 .30902 L
.89216 .30902 L
.89226 .30902 L
.89235 .30902 L
.89246 .30902 L
.89256 .30902 L
.89279 .30902 L
.89359 .30902 L
.89431 .30902 L
.89508 .30902 L
.8955 .30902 L
.89587 .30902 L
.89625 .30902 L
.89661 .30902 L
.89681 .30902 L
.89692 .30902 L
.89703 .30902 L
.89721 .30902 L
.89731 .30902 L
Mistroke
.89741 .30902 L
.89747 .30902 L
.89752 .30902 L
.89758 .30902 L
.89764 .30902 L
.89775 .30902 L
.89781 .30902 L
.89786 .30902 L
.89797 .30902 L
.89806 .30902 L
.89827 .30902 L
.89866 .30902 L
.89906 .30902 L
.8998 .30902 L
.90022 .30902 L
.90066 .30902 L
.90107 .30902 L
.90146 .30902 L
.90185 .30902 L
.90206 .30902 L
.90228 .30902 L
.9024 .30902 L
.90252 .30902 L
.90263 .30902 L
.90275 .30902 L
.90286 .30902 L
.90291 .30902 L
.90297 .30902 L
.90308 .30902 L
.90318 .30902 L
.90328 .30902 L
.90337 .30902 L
.90348 .30902 L
.90354 .30902 L
.90359 .30902 L
.90381 .30902 L
.90402 .30902 L
.9048 .30902 L
.9055 .30902 L
.90626 .30902 L
.9067 .30902 L
.9071 .30902 L
.90729 .30902 L
.9075 .30902 L
.9077 .30902 L
.90788 .30902 L
.90809 .30902 L
.90828 .30902 L
.90839 .30902 L
.90849 .30902 L
Mistroke
.90859 .30902 L
.90865 .30902 L
.90871 .30902 L
.90881 .30902 L
.9089 .30902 L
.90901 .30902 L
.90911 .30902 L
.9092 .30902 L
.90928 .30902 L
.90948 .30902 L
.90987 .30902 L
.91029 .30902 L
.91116 .30902 L
.91156 .30902 L
.91198 .30902 L
.91234 .30902 L
.91272 .30902 L
.91294 .30902 L
.91313 .30902 L
.91333 .30902 L
.91352 .30902 L
.91374 .30902 L
.91385 .30902 L
.91397 .30902 L
.91407 .30902 L
.91417 .30902 L
.91423 .30902 L
.91428 .30902 L
.91434 .30902 L
.91439 .30902 L
.91449 .30902 L
.91455 .30902 L
.9146 .30902 L
.9147 .30902 L
.9148 .30902 L
.91497 .30902 L
.91517 .30902 L
.91599 .30902 L
.91675 .30902 L
.91747 .30902 L
.91786 .30902 L
.91829 .30902 L
.91848 .30902 L
.91868 .30902 L
.91887 .30902 L
.91904 .30902 L
.91924 .30902 L
.91935 .30902 L
.91945 .30902 L
.91955 .30902 L
Mistroke
.91964 .30902 L
.91973 .30902 L
.91984 .30902 L
.9199 .30902 L
.91995 .30902 L
.92001 .30902 L
.92007 .30902 L
.92013 .30902 L
.92018 .30902 L
.9203 .30902 L
.9205 .30902 L
.92072 .30902 L
.92231 .30902 L
.92274 .30902 L
.92321 .30902 L
.9236 .30902 L
.92381 .30902 L
.92404 .30902 L
.92424 .30902 L
.92445 .30902 L
.92465 .30902 L
.92483 .30902 L
.92494 .30902 L
.92505 .30902 L
.92514 .30902 L
.92525 .30902 L
.9253 .30902 L
.92536 .30902 L
.92542 .30902 L
.92548 .30902 L
.92558 .30902 L
.92563 .30902 L
.92569 .30902 L
.92588 .30902 L
.92607 .30902 L
.92648 .30902 L
.92724 .30902 L
.92809 .30902 L
.9285 .30902 L
.92889 .30902 L
.92924 .30902 L
.9296 .30902 L
.9298 .30902 L
.92998 .30902 L
.93017 .30902 L
.93028 .30902 L
.93038 .30902 L
.93048 .30902 L
.93057 .30902 L
.93066 .30902 L
Mistroke
.93077 .30902 L
.93087 .30902 L
.93093 .30902 L
.93098 .30902 L
.93108 .30902 L
.93118 .30902 L
.93127 .30902 L
.93137 .30902 L
.93154 .30902 L
.93192 .30902 L
.93273 .30902 L
.93358 .30902 L
.93395 .30902 L
.93435 .30902 L
.93458 .30902 L
.93479 .30902 L
.935 .30902 L
.93519 .30902 L
.93537 .30902 L
.93556 .30902 L
.93575 .30902 L
.93585 .30902 L
.93595 .30902 L
.93604 .30902 L
.93613 .30902 L
.93621 .30902 L
.9363 .30902 L
.93639 .30902 L
.93649 .30902 L
.93659 .30902 L
.93668 .30902 L
.93686 .30902 L
.93706 .30902 L
.93747 .30902 L
.93821 .30902 L
.93866 .30902 L
.93908 .30902 L
.9395 .30902 L
.93988 .30902 L
.94024 .30902 L
.94044 .30902 L
.94063 .30902 L
.94083 .30902 L
.94093 .30902 L
.94105 .30902 L
.94114 .30902 L
.94125 .30902 L
.94135 .30902 L
.94144 .30902 L
.94154 .30902 L
Mistroke
.9416 .30902 L
.94166 .30902 L
.94176 .30902 L
.94186 .30902 L
.94196 .30902 L
.94205 .30902 L
.94225 .30902 L
.94247 .30902 L
.94267 .30902 L
.94312 .30902 L
.94385 .30902 L
.94464 .30902 L
.94509 .30902 L
.9455 .30902 L
.9457 .30902 L
.94591 .30902 L
.94611 .30902 L
.9463 .30902 L
.9464 .30902 L
.9465 .30902 L
.94658 .30902 L
.94667 .30902 L
.94677 .30902 L
.94687 .30902 L
.94692 .30902 L
.94698 .30902 L
.94708 .30902 L
.94717 .30902 L
.94726 .30902 L
.94734 .30902 L
.94743 .30902 L
.94762 .30902 L
.94781 .30902 L
.94866 .30902 L
.94946 .30902 L
.94984 .30902 L
.95025 .30902 L
.95069 .30902 L
.95089 .30902 L
.9511 .30902 L
.95129 .30902 L
.95147 .30902 L
.95164 .30902 L
.95181 .30902 L
.9519 .30902 L
.952 .30902 L
.9521 .30902 L
.95218 .30902 L
.95229 .30902 L
.95234 .30902 L
Mistroke
.95239 .30902 L
.95249 .30902 L
.95259 .30902 L
.95269 .30902 L
.9528 .30902 L
.95299 .30902 L
.95335 .30902 L
.95417 .30902 L
.95493 .30902 L
.95564 .30902 L
.956 .30902 L
.95639 .30902 L
.9566 .30902 L
.95683 .30902 L
.95702 .30902 L
.95712 .30902 L
.95723 .30902 L
.95734 .30902 L
.95739 .30902 L
.95745 .30902 L
.95755 .30902 L
.95765 .30902 L
.9577 .30902 L
.95776 .30902 L
.95786 .30902 L
.95793 .30902 L
.95799 .30902 L
.9581 .30902 L
.9582 .30902 L
.9583 .30902 L
.95849 .30902 L
.95891 .30902 L
.95969 .30902 L
.96052 .30902 L
.96095 .30902 L
.96118 .30902 L
.96142 .30902 L
.96165 .30902 L
.96185 .30902 L
.96206 .30902 L
.96225 .30902 L
.96244 .30902 L
.96254 .30902 L
.96264 .30902 L
.96275 .30902 L
.96284 .30902 L
.96294 .30902 L
.963 .30902 L
.96305 .30902 L
.96315 .30902 L
Mistroke
.96324 .30902 L
.96334 .30902 L
.96344 .30902 L
.96361 .30902 L
.9638 .30902 L
.96459 .30902 L
.96547 .30902 L
.96587 .30902 L
.9663 .30902 L
.9667 .30902 L
.96707 .30902 L
.96728 .30902 L
.96748 .30902 L
.9677 .30902 L
.96781 .30902 L
.96794 .30902 L
.96799 .30902 L
.96804 .30902 L
.96814 .30902 L
.96825 .30902 L
.96831 .30902 L
.96836 .30902 L
.96846 .30902 L
.96855 .30902 L
.96866 .30902 L
.96876 .30902 L
.96895 .30902 L
.96913 .30902 L
.96954 .30902 L
.97036 .30902 L
.97107 .30902 L
.97147 .30902 L
.97184 .30902 L
.97225 .30902 L
.97247 .30902 L
.97268 .30902 L
.97287 .30902 L
.97298 .30902 L
.97308 .30902 L
.97317 .30902 L
.97327 .30902 L
.97337 .30902 L
.97347 .30902 L
.97356 .30902 L
.97366 .30902 L
.97376 .30902 L
.97384 .30902 L
.97392 .30902 L
.97401 .30902 L
.97419 .30902 L
Mistroke
.97458 .30902 L
.97496 .30902 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{421.375, 260.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008>0001AB000`400?l00000o`00003ooooooooo
oooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo
003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooo
oooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool0
0?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooooooo
ool@ooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooo
ooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo0ol0003o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0
003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo
00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`
ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLoooo
o`00<?ooool3o`000?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?oo
ool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0
033ooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`3oooooohgooooo000`ooooo`03
o`000?oooooooooo04_ooooo0_l0003oooooohoooooo000`ooooo`03o`000?oooooooooo04_ooooo
0_l0003oooooohoooooo000`ooooo`03o`000?oooooooooo04_ooooo0_l0003oooooohoooooo000`
ooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool02?ooool2o`000?ooooooSoooool0
033ooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`08ooooo`;o0000oooooon?oooo
o`00<?ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo00Sooooo0_l0003oooooohoo
oooo000`ooooo`?o0000@?ooool00ol0003oooooooooo`08ooooo`;o0000oooooon?ooooo`00<?oo
ool00ol0003oooooooooo`0oooooo`03o`000?oooooo000000Wooooo0_l0003oooooohoooooo000`
ooooo`03o`000?oooooooooo03oooooo00?o0000ooooool000002Oooool00ol0003oooooo`00003o
ooooohkooooo000`ooooo`03o`000?oooooooooo03oooooo00?o0000ooooool000002Oooool00ol0
003oooooo`00003oooooohkooooo000`ooooo`03o`000?oooooooooo03oooooo00?o0000ooooool0
00002Oooool00ol0003oooooo`00003oooooohkooooo000`ooooo`03o`000?oooooooooo03oooooo
00?o0000ooooool000002Oooool00ol0003oooooo`00003oooooohkooooo000`ooooo`03o`000?oo
oooooooo03oooooo00?o0000ooooool000002Oooool00ol0003oooooo`00003oooooohkooooo000@
ooooo`;ok^k^0oooool2onk^kQWooooo00?o0000ooooooooool0?oooool00ol0003oooooo`000009
ooooo`03o`000?oooooo00000?ooooooS_ooool000_ooooo0_l000002_l@413oooooooooooo^k^ko
EEEEonk^k_ooooook^k^oeEEEOo^k^h3ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o
<S8bonk^kP[ooooo00?o0000ooooooooool0?oooool00ol0003oooooo`000009ooooo`03o`000?oo
oooo00000?ooooooS_ooool000cooooo00?o0000ooooooooool00_ooool01Oo^k^koEEEEomgMgOmE
EEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00[ooooo
00?o0000ooooooooool0?oooool00ol0003oooooo`000009ooooo`03o`000?oooooo00000?oooooo
S_ooool00003ooooool0003o000000Co00000_ooool5o`0000Cooooo00?ogMgMo`000?oMgMd01ooo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41002_ooool00ol0003ooooo
ooooo`0oooooo`03o`000?oooooo000000Wooooo00?o0000ooooool00000oooooon>ooooo`002Ooo
ool01?m4A4CogMgMooooool00004ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000002_ooool00ol0003oooooooooo`0ooooo
o`03o`000?oooooo000000Wooooo00?o0000ooooool00000oooooon>ooooo`002Oooool01?oMgMgo
EEEEooooool00003ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000:ooooo`Co0000?_ooool00ol0003ooooo
o`000009ooooo`03o`000?oooooo00000?ooooooS_ooool000[ooooo00?oMgMgolc<c?l000000ooo
ool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooo
oa0@400:ooooo`03o`000?oooooooooo03oooooo00?o0000ooooool000002Oooool00ol0003ooooo
o`00003oooooohkooooo000:ooooo`03onk^k_m4A4Co000000oooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo0_l00005ooooo`03o`000?oooooooooo03oooooo
00?o0000ooooool000002Oooool00ol0003oooooo`00003oooooohkooooo000;ooooo`03ogMgMol0
003ooooo00cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooo000000Wo
oooo00?o0000ooooool00000oooooon>ooooo`00:?ooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo03oooooo00?o0000ooooool000002Oooool00ol0003oooooo`00003oooooohko
oooo000Xooooo`?o00001Oooool00ol0003oooooooooo`0oooooo`03o`000?oooooo000000Wooooo
00?o0000ooooool00000oooooon>ooooo`00:Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo03oooooo00?o0000ooooool000002?ooool01?l0003oooooooooool0003oooooohkooooo
000Zooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0?oooool00ol0003oooooo`00
0008ooooo`04o`000?ooooooooooo`000?ooooooS_ooool0033ooooo00?o0000ooooooooool0?ooo
ool00ol0003oooooo`000008ooooo`04o`000?ooooooooooo`000?ooooooS_ooool0033ooooo00?o
0000ooooooooool0?oooool00ol0003oooooo`000008ooooo`04o`000?ooooooooooo`000?oooooo
S_ooool0033ooooo00?o0000ooooooooool0?oooool00ol0003oooooo`000008ooooo`04o`000?oo
ooooooooo`000?ooooooS_ooool0033ooooo00?o0000ooooooooool0?oooool00ol0003oooooo`00
0008ooooo`04o`000?ooooooooooo`000?ooooooS_ooool0033ooooo0ol0000oooooo`03o`000?oo
oooo000000Sooooo00Co0000oooooooooooo0000oooooon>ooooo`00<?ooool00ol0003ooooooooo
o`0oooooo`03o`000?oooooo000000Sooooo00Co0000oooooooooooo0000oooooon>ooooo`00<?oo
ool00ol0003oooooooooo`0oooooo`03o`000?oooooo000000Sooooo00Co0000oooooooooooo0000
oooooon>ooooo`00<?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooo000000Sooooo00Co
0000oooooooooooo0000oooooon>ooooo`00<?ooool00ol0003oooooooooo`0oooooo`03o`000?oo
oooo000000Sooooo00Co0000oooooooooooo0000oooooon>ooooo`00<?ooool00ol0003ooooooooo
o`0oooooo`03o`000?oooooo000000Sooooo00Co0000oooooooooooo0000oooooon>ooooo`00<?oo
ool00ol0003oooooooooo`0oooooo`03o`000?oooooo000000Sooooo00Co0000oooooooooooo0000
oooooon>ooooo`00<?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooo000000Sooooo00Co
0000oooooooooooo00002Oooool00ol0003oooooooooo`3ooooooh;ooooo000`ooooo`03o`000?oo
oooooooo03oooooo00?o0000ooooool000002?ooool01?l0003oooooooooool00009ooooo`03o`00
0?oooooooooo0?ooooooP_ooool0033ooooo00?o0000ooooooooool0?oooool00ol0003oooooo`00
0008ooooo`04o`000?ooooooooooo`0000Sooooo0_l0003oooooohCooooo000`ooooo`03o`000?oo
oooooooo03oooooo00?o0000ooooool000002?ooool01?l0003oooooooooool00008ooooo`;o0000
oooooon4ooooo`00<?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooo000000Sooooo00Co
0000oooooooooooo00002?ooool2o`000?ooooooQ?ooool0033ooooo0ol0000nooooo`04o`000?oo
ooooooooo`0000Sooooo00Co0000oooooooooooo00002?ooool2o`000?ooooooQ?ooool0033ooooo
00?o0000ooooooooool0?_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00
00Sooooo0_l0003oooooohCooooo000`ooooo`03o`000?oooooooooo03kooooo00Co0000oooooooo
oooo00002?ooool01?l0003oooooooooool00008ooooo`;o0000oooooon4ooooo`00<?ooool00ol0
003oooooooooo`0nooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002?oo
ool2o`000?ooooooQ?ooool0033ooooo00?o0000ooooooooool0?_ooool01Ol0003ooooooooooooo
oooo000000Oooooo00Co0000oooooooooooo00002?ooool2o`000?ooooooQ?ooool0033ooooo00?o
0000ooooooooool0?_ooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo
00002?ooool00ol0003oooooo`00003ooooooh?ooooo000`ooooo`03o`000?oooooooooo03kooooo
00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000oooo
ool00000oooooon3ooooo`00<?ooool00ol0003oooooooooo`0nooooo`05o`000?oooooooooooooo
ool000001oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?ooooooPoooool0
033ooooo00?o0000ooooooooool0?_ooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000
oooooooooooo00002?ooool00ol0003oooooo`00003ooooooh?ooooo000`ooooo`03o`000?oooooo
oooo03?ooooo0_l00009ooooo`05o`000?ooooooooooooooool000001oooool01?l0003ooooooooo
ool00008ooooo`03o`000?oooooo00000?ooooooPoooool0033ooooo00?o0000ooooooooool0<ooo
ool2o`0000Wooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000So
oooo00?o0000ooooool00000oooooon3ooooo`00<?ooool3o`0003?ooooo0_l00009ooooo`05o`00
0?ooooooooooooooool000001oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo0000
0?ooooooPoooool0033ooooo00?o0000ooooooooool0<oooool2o`0000Wooooo00Go0000oooooooo
ooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003o
oooooh?ooooo000`ooooo`03o`000?oooooooooo03?ooooo0_l00009ooooo`05o`000?oooooooooo
ooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooool00000oooo
oon3ooooo`00<?ooool00ol0003oooooooooo`0cooooo`;o00002Oooool01Ol0003ooooooooooooo
oooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?oooooo
Poooool0033ooooo00?o0000ooooooooool0<oooool2o`0000Wooooo00Go0000oooooooooooooooo
o`000007ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003ooooooh?o
oooo000`ooooo`03o`000?oooooooooo03?ooooo0_l00009ooooo`05o`000?ooooooooooooooool0
00001oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooool00000oooooon3oooo
o`00<?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooo000000Sooooo00Go0000oooooooo
ooooooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool0
003ooooooh?ooooo000@ooooo`;ok^k^0oooool2onk^kQWooooo00?o0000ooooooooool0<_ooool0
1?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooo
oooooooooooo000000Kooooo00Co0000oooooooooooo0000oooooon3ooooo`002Oooool5o`0000;o
oooo00Ook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413oooooooooooo^
k^ko<S8bo`000?lb<S;ok^k^2_ooool00ol0003oooooooooo`0booooo`04o`000?ooooooooooo`00
00Sooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001_oo
ool01?l0003oooooooooool0003ooooooh?ooooo0009ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
0oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00[ooooo00?o0000ooooooooool0<_ooool01?l0003oooooooooool00008
ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Kooooo
00Co0000oooooooooooo0000oooooon3ooooo`0000?oooooo`000?l000001?l00003ooooo`03oiRH
V?lQ8B7ok^k^00Gooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@
4?ooooooooooooooool@41002_ooool00ol0003oooooooooo`0booooo`04o`000?ooooooooooo`00
00Sooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001_oo
ool01?l0003oooooooooool0003ooooooh?ooooo000;ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go
k^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`00000:ooooo`03o`000?oooooooooo03;ooooo00Co0000oooooooooooo00002?ooool01Ol0
003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?oo
ooooooooo`000?ooooooPoooool000cooooo00_oMgMgofIVI_ooooooooooonk^k_mEEEGok^k^oooo
ooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
000:ooooo`Co0000<Oooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool0
00001oooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo0000oooooon3
ooooo`003Oooool00ol0003oooooooooo`02onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo
00;ooooo00Go410@oooooooooooooooooa0@400:ooooo`03o`000?oooooooooo03;ooooo00Co0000
oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooooooooooo
ooooo`000006ooooo`04o`000?ooooooooooo`000?ooooooPoooool000Wooooo00Go0000okZj^_oo
ooooV9RHoa0@400>ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03
ooooo`;o00001Oooool00ol0003oooooooooo`0booooo`04o`000?ooooooooooo`0000Sooooo00Go
0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003o
ooooooooool0003ooooooh?ooooo0009ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?ooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_ooool01?l0003oooooooooool0
0004ooooo`03o`000?oooooooooo03;ooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooo
oooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?oooooooooo
o`000?ooooooPoooool002Sooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0b
ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000007ooooo`05o`00
0?ooooooooooooooool000001_ooool01?l0003oooooooooool0003ooooooh?ooooo000Xooooo`?o
00001Oooool00ol0003oooooooooo`0booooo`04o`000?ooooooooooo`0000Sooooo00Go0000oooo
ooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003ooooooooo
ool0003ooooooh?ooooo000Yooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0<_oo
ool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1Oooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo0000oooooon3oooo
o`00:_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03;ooooo00Co0000oooooooo
oooo00001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00Go0000oooo
ooooooooooooo`000006ooooo`04o`000?ooooooooooo`000?ooooooPoooool0033ooooo00?o0000
ooooooooool0<_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000oooooooooooo
ooooo`00003ooooooh;ooooo000`ooooo`03o`000?oooooooooo03;ooooo00Co0000oooooooooooo
00001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00Go0000oooooooo
ooooooooo`000006ooooo`05o`000?ooooooooooooooool00000oooooon2ooooo`00<?ooool00ol0
003oooooooooo`0booooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooo
oooooooo00000?ooooooP_ooool0033ooooo00?o0000ooooooooool0<_ooool01?l0003ooooooooo
ool00007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool01Ol0003ooooo
oooooooooooo000000Kooooo00Go0000ooooooooooooooooo`00003ooooooh;ooooo000`ooooo`?o
0000<_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01Oooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`00
003ooooooh;ooooo000`ooooo`03o`000?oooooooooo03;ooooo00Co0000oooooooooooo00001ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00Go0000oooooooooooooooo
o`000006ooooo`05o`000?ooooooooooooooool00000oooooon2ooooo`00<?ooool00ol0003ooooo
ooooo`0booooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?oooooooooo
ooooool000001oooool2o`000?ooooooNOooool0033ooooo00?o0000ooooooooool0<_ooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05
ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Oooooo
0_l0003oooooogWooooo000`ooooo`03o`000?oooooooooo03;ooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool01Ol0003ooooo
oooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000007ooooo`;o0000oooooomioooo
o`00<?ooool00ol0003oooooooooo`0booooo`05o`000?ooooooooooooooool000001_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000006
ooooo`05o`000?ooooooooooooooool000001oooool2o`000?ooooooNOooool0033ooooo00?o0000
ooooooooool0<_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooool00000oooooomiooooo`00<?ooool00ol0003ooooo
ooooo`0aooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooo`00003oooooogWo
oooo000`ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooo00000?ooooooNOooool0033ooooo00?o0000ooooooooool0<Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooool00000oooooomiooooo`00<?ooool00ol0003ooooo
ooooo`0aooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool0003ooooo
ogSooooo000`ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006oooo
o`04o`000?ooooooooooo`000?ooooooN?ooool0033ooooo0ol0000aooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooo
ooooool000001_ooool01?l0003oooooooooool0003oooooogSooooo000`ooooo`03o`000?oooooo
oooo037ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`000?oooooo
N?ooool0033ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo
00Co0000oooooooooooo0000oooooomhooooo`00<?ooool00ol0003oooooooooo`0aooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`00
0?ooooooooooooooool000001_ooool01?l0003oooooooooool0003oooooogSooooo000`ooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?oooooooooo
o`000?ooooooN?ooool0033ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00?ok^k^o`000?ooool00_ooool2onk^kP05o`000?oooooooooo
ooooool000001_ooool01?l0003oooooooooool00018ooooo`;ok^k^0oooool2onk^kV3ooooo0_o^
k^h3ooooo`;ok^k^C_ooool2onk^kP?ooooo0_o^k^i/ooooo`00<?ooool00ol0003oooooooooo`0V
ooooo`;o00002Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`0>odA4A?l0003o0000oc8b<_oMgMgooooo
onk^k_l0003ok^k^ooooooo^k^koEEEEonk^k_l00002ooooo`Co000000Co410@ooooooooooook^k^
0_l000000olb<S;o0000ooooo`11ooooo`Co000000Wo410@ooooooo^k^koEEEEonk^k_ooooook^k^
oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hkooooo`Co
000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo00goA4A4o`000?l0003o<S8bomgMgOoooooo
k^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8b
o`000?lb<S;ok^k^>?ooool5o`0000;ooooo00Ook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?o
oooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^GOooool0033ooooo00?o0000
ooooooooool09Oooool00ol0003oooooo`000009ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00Co0000
oooooomgMgOo<S8b0_ooool01ol0003oEEEEomgMgOmEEEGok^k^ooooool000000oooool2o`0000Co
oooo00GoMgMgo`000?ooooooV9RHo`000014ooooo`03o`000?oooooooooo00;ooooo00Gok^k^oeEE
EOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0mooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`09ogMgMolb<S;oooooooooooo^k^ko
EEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg03Sooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h0
1_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0GOooool0033ooooo
00?o0000ooooooooool09Oooool00ol0003oooooo`000009ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00Co0000oooooooooooo00000_ooool01?l0003ogMgMo`000?oMgMd2ooooo`04o`000?oooooooooo
ooooo`;o00001?ooool01Ol@413o0000oooooooooooo000004Cooooo00?o0000ooooooooool00ooo
ool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooo
oa0@400mooooo`03o`000?oooooooooo00oooooo00Oo0000ooooooooooooooooomgMgOl0003ogMgM
00Oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@03Wooooo00?oV9RH
ob4Q8Oo^k^h01Oooool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@401Mooooo`00<?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
000000Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool01?l0003oooooogMgMolb<S82ooooo`07o`000?mE
EEGogMgMoeEEEOo^k^koooooo`000004ooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`03
o`000?oooooooooo04;ooooo00?o0000ooooooooool00_ooool01Oo^k^koEEEEomgMgOmEEEGok^k^
00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000003gooooo00?o0000
ooooooooool03_ooool02OmgMgOo<S8booooooooooook^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03
o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000jooooo`03oiRHV?lQ8B7ok^k^
00?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`00001Mooooo`00<?ooool00ol0003oooooooooo`0Uooooo`04o`000?oooooo
ooooo`0000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00_ooool3o`00000;oc8b<_o<c<coooooonk^k_l0003o
k^k^ooooooo^k^koEEEEonk^k_l000001?ooool00ol0003oooooooooo`02ooooo`;o00000_ooool0
0ol0003oooooooooo`12ooooo`0;o`000?ooooooooooooooooo^k^koEEEEonk^k_ooooook^k^oeEE
EOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000?Oooool0
0ol0003oooooooooo`0;ooooo`0=o`000?lQ8B7o0000oc8b<_o<c<coooooonk^k_mEEEGok^k^oooo
ooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
000kooooo`0;ogMgMomVIVKoooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000GOooool0033ooooo00?o0000
ooooooooool09Oooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo0_l0
0004ooooo`03onk^k_l0003ooooo00;ooooo0_o^k^h00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00;ooooo00Go410@o`000?ooooooooooo`000014ooooo`04o`000?ooooooooooooooo`;o
k^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@
03gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`03ooooo`;ok^k^0oooool2onk^
kPGooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@03cooooo00?o0000
ooooooooool00_o^k^h3ooooo`;ok^k^1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooo
ooooooooool@4100GOooool0033ooooo0ol0000Tooooo`05o`000?ooooooooooooooool000001ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`02ooooo`;o00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00_ooool01OmgMgOo0000oooooonHV9So000000Oooooo
0_l0000kooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Sooooo0_l0000cooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool2o`00
02kooooo00Go0000okZj^_ooooooV9RHoa0@400>ooooo`03o`000?oooooooooo00;ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`08ooooo`;o0000Doooool0033ooooo00?o0000ooooooooool09?ooool0
1Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool4o`0000?ooooo00?o
0000ooooooooool00oooool01_l0003ooooooooooomEEEGoIVIVo`0000Cooooo00Go0000oc8b<_l0
003o<S8bo`000007ooooo`;o0000>Oooool00omEEEGoIVIVo`00000=ooooo`03oeEEEOmVIVKo0000
00Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP07ooooo`04o`000?ooooooooooo`00033ooooo00?o
EEEEofIVI_l000003Oooool4o`0000cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Oooooo00Co0000oooooooooooo0000;Oooool01OnHV9So410@o`000?lQ8B7oc<c<
00cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oooooo00Co0000
oooooooooooo0000D_ooool0033ooooo00?o0000ooooooooool09?ooool01Ol0003ooooooooooooo
oooo000000Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000_ooool4o`000004ooooool0003o0000o`0005Kooooo1?l000001Ooooooo
0000oooooooooooo000005kooooo1?l000001Ooooooo0000oooooooooooo000004cooooo1?l00000
1Ooooooo0000oooooooooooo000005;ooooo000`ooooo`03o`000?oooooooooo02Cooooo00Go0000
ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000000Kooooo00Co0000ooooool0003o0000Foooool3o`0006Co
oooo0ol0001Booooo`?o0000Doooool0033ooooo00?o0000ooooooooool08oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool2o`000003oooo
ool0003o000005_ooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`1Booooo`03o`00
0?oooooooooo05;ooooo000`ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo1Ol0001Looooo`03o`000?oo
oooooooo06Cooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`1Aooooo`00<?ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`000?ooooooK_ooool0033ooooo00?o0000
ooooooooool08oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool01?l0003oooooooooool0003oooooocCooooo00?oMgMgofIVI_ooool0;Ooo
ool00omVIVKoMgMgooooo`07ooooo`00<?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooobWooooo00?ogMgM
oa0@4?o^k^h0;_ooool00oo^k^ko410@omgMg@07ooooo`00<?ooool00ol0003oooooooooo`0Foooo
o`?o00002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo0ol0003ooooo
oaSooooo0_l00002ooooo`;o00003?ooool00omEEEGoV9RHooooo`02o`0000;ooooo00Oo0000oooo
oooooooo0000oa0@4?o^k^koEEEE00;o000000?oA4A4okZj^_ooool00_ooool01OnHV9So0000o`00
0?m4A4Co^[Zj00;ooooo00Sok^k^oeEEEOl0003o0000odA4A?nj^[[ooooooa0@40Go00000oooool0
2?l@413o<S8bo`000?l0003o410@ojVYZOn7QhOoIVIV1oooool0033ooooo00?o0000ooooooooool0
5?ooool3o`0000;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00Co0000oooooooooooo0000oooooolGooooo`06onk^k_lQ8B7oQhN7okZj
^_l0003ogMgM3?ooool01Ol0003ooooooooooooooooo000000;ooooo00_o0000oooooooooooo0000
oooooomEEEGoMgMgooooooo^k^koMgMgoa0@4003ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000_oo
ool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40?ooooo00?o0000ooooooooool01?ooool02?l0003o
ZJVYoooooooooooo^[Zjo`000?o^k^ko00001oooool00?oo0000]?l0000?ooooo`04omgMgOl0003o
410@olc<c0gooooo00Go<S8booooooooooooooooo`000002ooooo`06o`000?ooooooooooo`000?oo
oooo00002?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01Oooool01onj^[[oQhN7ofIVI_mVIVKo410@ooooool000001oooool000[ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00cooooo1ol00007
ooooo`03o`000?oooooooooo00Gooooo0_l00005ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00_ooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool2o`0000Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`;o00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo1?l00005
ooooo`?o00003oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0Gooooo`04onk^k_lQ8B7o410@onk^kPgooooo00Go
<S8booooooooooooooooo`000002ooooo`05o`000?ooooooooooo`000?ooool01_l00003ooooo`03
o`000?oooooooooo00Cooooo1_l00003ooooo`03o`000?oooooooooo00Cooooo00So<S8bob4Q8Omg
MgOoMgMgohN7Qoo^k^koooooo`0000Oooooo000:ooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool01?ooool2o`0000Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`;o00001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo0_l00003
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool05oooool01?lQ8B7oMgMgogMgMolb
<S8=ooooo`05o`000?o^k^koooooooooool000000_o<c<`02ol0003oZJVYomgMgOlQ8B7ooooooeEE
EOn7QhOok^k^oooooon7QhOo<S8b00?ooooo00?o0000ooooooooool01?ooool01_mEEEGoQhN7onk^
k_ooooooQhN7oc8b<P?ooooo00?o0000oc8b<_oMgMd01?ooool02?l0003o^[Zjooooooo^k^koMgMg
o`000?o^k^ko00001oooool0033ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`;o00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool01?l0003oooooooooool00016ooooo`03o`000?oooooooooo05_ooooo00?o
0000ooooooooool0Foooool00ol0003oooooooooo`0Fooooo`;o00000_ooool2o`0000cooooo00ko
EEEEogMgMooooooo410@o`000?lQ8B7o0000ogMgMol@413o0000ojVYZOooooook^k^oeEEE@;o0000
00CoA4A4onk^k_oooooo410@1Ol00003ooooo`06onk^k_mEEEGo0000o`000?m4A4Cok^k^0_ooool2
o`000004ojVYZOlQ8B7o0000ob4Q8@;ooooo00SoZJVYob4Q8Ol0003o0000oc8b<_l0003oMgMgoeEE
E@Oooooo000`ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000005oooo
o`04o`000?ooooooooooo`000?oooooo;_ooool00ooMgMgo410@onk^kP0Booooo`03o`000?oooooo
oooo01Wooooo00?ok^k^oa0@4?oMgMd01oooool0033ooooo00?o0000ooooooooool07Oooool01Ol0
003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooo
oooo000000Gooooo0ol0003ooooooc3ooooo00?oMgMgofIVI_ooool04Oooool00ol0003ooooooooo
o`0Iooooo`03ofIVI_mgMgOooooo00Oooooo000`ooooo`03o`000?oooooooooo01gooooo0_l00000
0ooooooo0000ooooo`07ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00
0006ooooo`;o0000oooooomZooooo`00<?ooool00ol0003oooooooooo`0Nooooo`?o00002Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool00000oooooombooooo`00<?ooool0
0ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo0000oooo
oomcooooo`00<?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Co0000
oooooooooooo0000oooooomcooooo`00<?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00Co0000oooooooooooo0000oooooomcooooo`00<?ooool00ol0003oooooooooo`0Z
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo0000oooooomcooooo`00<?ooool3
o`0002[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool0003oooooog?ooooo000`
ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool0
003oooooog?ooooo000`ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool0
0ol0003oooooo`00003oooooogCooooo000`ooooo`03o`000?oooooooooo02[ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool00ol0003oooooo`00003oooooogCooooo000`ooooo`03o`000?oooooooooo02_o
oooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooo`00
003oooooogCooooo000`ooooo`03o`000?oooooooooo02_ooooo00Go0000ooooooooooooooooo`00
0007ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`00
0?ooooooooooooooool000001oooool2o`000?ooooooM?ooool0033ooooo00?o0000ooooooooool0
:oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000007ooooo`;o0000oooooomd
ooooo`00<?ooool00ol0003oooooooooo`0[ooooo`05o`000?ooooooooooooooool000001oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooo
oooooooo000000Oooooo0_l0003oooooogCooooo000`ooooo`03o`000?oooooooooo02_ooooo00Go
0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`05o`000?ooooooooooooooool000001oooool2o`000?ooooooM?ooool0033o
oooo00?o0000ooooooooool0:oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00
003ooooooggooooo000`ooooo`03o`000?oooooooooo02_ooooo00Go0000ooooooooooooooooo`00
0007ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`00
0?ooooooooooooooool00000oooooommooooo`00<?ooool00ol0003oooooooooo`0[ooooo`05o`00
0?ooooooooooooooool000001oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Co
oooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool01Ol0003ooooooooooooooooo00000?ooooooOOooool0033ooooo0ol0000[oooo
o`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool01Ol0003ooooooooooooooooo00000?ooooooOOooool0033ooooo00?o
0000ooooooooool0:oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00003ooooo
oggooooo000`ooooo`03o`000?oooooooooo02_ooooo00Go0000ooooooooooooooooo`000007oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo
000000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooo
ooooooooool00000oooooommooooo`00<?ooool00ol0003oooooooooo`0[ooooo`05o`000?oooooo
ooooooooool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool01Ol0003ooooooooooooooooo00000?ooooooOOooool0033ooooo00?o0000ooooooooool0
:oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`05ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo0000oooooommooooo`00<?ooool00ol0
003oooooooooo`0[ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo0000oooooommooooo`00<?oo
ool00ol0003oooooooooo`0/ooooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo0000oooooommooooo`00
<?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo0000oooooommoooo
o`00<?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooo000000Sooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000001_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo0000oooooomm
ooooo`00<?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooo000000Sooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000001_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo0000oooo
oommooooo`00<?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooo000000Sooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000001_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo0000
oooooommooooo`00<?ooool00ol0003oooooooooo`0/ooooo`;o00002Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0003ooooooggo
oooo000`ooooo`?o0000;Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`000?ooooooOOooool0033o
oooo00?o0000ooooooooool0>?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
1?l0003oooooooooool0003ooooooggooooo000`ooooo`03o`000?oooooooooo03Sooooo00Go0000
ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooool00000oooooomnooooo`00<?oo
ool00ol0003oooooooooo`0hooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooo00000?ooooooO_ooool0033ooooo00?o0000ooooooooool0>?ooool01Ol0003ooooo
oooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooo`00003oooooogkooooo000`ooooo`03
o`000?oooooooooo03Sooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooooooo
ooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooool00000oooooomnooooo`003oooool2onk^kP?ooooo0_o^k^hJooooo`03o`000?oooooooooo
03Sooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooool00000oooo
oomnooooo`002?ooool5o`0000;ooooo00Ook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo
1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool00ol0003oooooooooo`0h
ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Kooooo
00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?ooooooO_ooool000Sooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0
003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ol0003oooooooooo`0h
ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Kooooo
00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?ooooooO_ooool000Wooooo
00?oV9RHob4Q8Oo^k^h01Oooool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo
00Go410@oooooooooooooooooa0@400;ooooo`03o`000?oooooooooo03Sooooo00Go0000oooooooo
ooooooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooo
oooo000000Oooooo00?o0000ooooool00000oooooomnooooo`002_ooool00onHV9So8B4Qonk^kP03
ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000002oooool00ol0003oooooooooo`0hooooo`05o`000?ooooooooooooooool0
00001oooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000007
ooooo`03o`000?oooooo00000?ooooooO_ooool000_ooooo00_oMgMgofIVI_ooooooooooonk^k_mE
EEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`00000;ooooo`Co0000=oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000
ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001oooool00ol0003ooooo
o`00003oooooogkooooo000<ooooo`03o`000?oooooooooo00;ok^k^0oooool2onk^kPGooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00_ooooo00?o0000ooooooooool0
>?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000006oooo
o`05o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003oooooogkooooo0008oooo
o`05o`000?nj^[[ooooooiRHV?l@41003_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool00ol0003oooooooooo`0hooooo`05o`000?ooooooooooooooool00000
1oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo00001oooool00ol0
003oooooo`00003oooooogkooooo0008ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?ooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool2o`0000Kooooo00?o0000
ooooooooool0>?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooooooooooooooo
o`000007ooooo`04o`000?ooooooooooo`0000Sooooo0_l0003oooooogkooooo000Wooooo`04o`00
0?ooooooooooo`0000Gooooo00?o0000ooooooooool0>?ooool01Ol0003ooooooooooooooooo0000
00Oooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Sooooo0_l0
003oooooogkooooo000Wooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0>?oo
ool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04
o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool0oooooommooooo`009oooool3o`0000Ko
oooo00?o0000ooooooooool0>?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooo
ooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool0oooo
oommooooo`00:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Sooooo00Co0000
oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo
0000oooooon8ooooo`00:Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03Sooooo
00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooo
oooooooo0000oooooon8ooooo`00<?ooool00ol0003oooooooooo`0hooooo`04o`000?oooooooooo
o`0000Sooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`000?oooooo
R?ooool0033ooooo00?o0000ooooooooool0>?ooool01?l0003oooooooooool00008ooooo`05o`00
0?ooooooooooooooool000001oooool01?l0003oooooooooool0003oooooohSooooo000`ooooo`03
o`000?oooooooooo03Sooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo
000000Oooooo00Co0000oooooooooooo0000oooooon8ooooo`00<?ooool3o`0003Sooooo00Co0000
oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo
0000oooooon8ooooo`00<?ooool00ol0003oooooooooo`0hooooo`04o`000?ooooooooooo`0000So
oooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`000?ooooooR?ooool0
033ooooo00?o0000ooooooooool0>?ooool01?l0003oooooooooool00008ooooo`05o`000?oooooo
ooooooooool000001oooool01?l0003oooooooooool0003oooooohSooooo000`ooooo`03o`000?oo
oooooooo03Sooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Oo
oooo00Co0000oooooooooooo0000oooooon8ooooo`00<?ooool00ol0003oooooooooo`0hooooo`04
o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?oooooo
ooooo`000?ooooooR?ooool0033ooooo00?o0000ooooooooool0>?ooool01?l0003oooooooooool0
0008ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool0003oooooohSo
oooo000`ooooo`03o`000?oooooooooo03Sooooo00Co0000oooooooooooo00002?ooool01Ol0003o
oooooooooooooooo000000Oooooo00Co0000oooooooooooo0000oooooon8ooooo`00<?ooool00ol0
003oooooooooo`0iooooo`03o`000?oooooo000000Sooooo00Go0000ooooooooooooooooo`000007
ooooo`04o`000?ooooooooooo`000?ooooooR?ooool0033ooooo00?o0000ooooooooool0>Oooool0
0ol0003oooooo`000008ooooo`05o`000?ooooooooooooooool000001oooool01?l0003ooooooooo
ool0003oooooohSooooo000`ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooool000002?oo
ool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000oooooon8ooooo`00
<?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooo000000Sooooo00Go0000oooooooooooo
ooooo`000007ooooo`04o`000?ooooooooooo`000?ooooooR?ooool0033ooooo00?o0000oooooooo
ool0>Oooool00ol0003oooooo`000008ooooo`05o`000?ooooooooooooooool000001oooool01?l0
003oooooooooool0003oooooohSooooo000`ooooo`?o0000>Oooool00ol0003oooooo`000008oooo
o`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool0003oooooohSooooo000`
ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooool000002?ooool01Ol0003ooooooooooooo
oooo000000Oooooo00Co0000oooooooooooo0000oooooon8ooooo`00<?ooool00ol0003ooooooooo
o`0iooooo`03o`000?oooooo000000Sooooo00Go0000ooooooooooooooooo`000007ooooo`04o`00
0?ooooooooooo`000?ooooooR?ooool0033ooooo00?o0000ooooooooool0>Oooool00ol0003ooooo
o`000008ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool0003ooooo
ohSooooo000`ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooool000002?ooool01Ol0003o
oooooooooooooooo000000Oooooo00Co0000oooooooooooo0000oooooon8ooooo`00<?ooool00ol0
003oooooooooo`0iooooo`03o`000?oooooo000000Sooooo00Go0000ooooooooooooooooo`000007
ooooo`04o`000?ooooooooooo`000?ooooooR?ooool0033ooooo00?o0000ooooooooool0>Oooool0
0ol0003oooooo`000008ooooo`05o`000?ooooooooooooooool000001oooool01?l0003ooooooooo
ool0003oooooohSooooo000`ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooool000002?oo
ool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000oooooon8ooooo`00
<?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooo000000Sooooo00Go0000oooooooooooo
ooooo`000007ooooo`03o`000?oooooo00000?ooooooROooool0033ooooo00?o0000ooooooooool0
>Oooool00ol0003oooooo`000008ooooo`05o`000?ooooooooooooooool000001oooool00ol0003o
ooooo`00003oooooohWooooo000`ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooool00000
2?ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooool00000oooooon9ooooo`00
<?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooo000000Wooooo00Co0000oooooooooooo
00001oooool00ol0003oooooo`00003oooooohWooooo000`ooooo`?o0000>Oooool00ol0003ooooo
o`000009ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool00000oooooon9ooooo`00
<?ooool00ol0003oooooooooo`0iooooo`;o00002_ooool01?l0003oooooooooool00007ooooo`03
o`000?oooooo00000?ooooooROooool0033ooooo00?o0000ooooooooool0>Oooool2o`0000[ooooo
00Co0000oooooooooooo00001oooool00ol0003oooooo`00003oooooohWooooo000`ooooo`03o`00
0?oooooooooo03Wooooo0_l0000:ooooo`04o`000?ooooooooooo`0000Sooooo0_l0003oooooohWo
oooo000`ooooo`03o`000?oooooooooo03Wooooo0_l0000:ooooo`04o`000?ooooooooooo`0000So
oooo0_l0003oooooohWooooo000`ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0
2?ooool01?l0003oooooooooool00008ooooo`;o0000oooooon9ooooo`003oooool2onk^kP?ooooo
0_o^k^hJooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool02?ooool01?l0003ooooo
ooooool00008ooooo`;o0000oooooon9ooooo`002_ooool2o`00000:oa0@4?ooooooooooonk^k_mE
EEGok^k^ooooooo^k^koEEEEonk^kP?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb
<S;ok^k^2oooool00ol0003oooooooooo`15ooooo`03o`000?oooooo000000Wooooo0_l0003ooooo
ohWooooo000;ooooo`03o`000?oooooooooo00;ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06oooo
o`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03o`000?oooooo
oooo04Gooooo00?o0000ooooool000002Oooool2o`000?ooooooROooool000Sooooo1Ol00004oooo
o`03omgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@00_ooooo00?o0000ooooooooool0AOooool00ol0003oooooo`000009ooooo`;o0000oooooon9
ooooo`002?ooool01?m4A4CogMgMooooool00004ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_oo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000002oooool00ol0003ooooo
ooooo`15ooooo`03o`000?oooooo000000Wooooo0_l0003oooooohWooooo0008ooooo`04omgMgOmE
EEGoooooo`0000?ooooo00Ook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000000_ooooo1?l00014ooooo`03o`000?oooooo
000000Wooooo0_l0003oooooohWooooo0009ooooo`03ogMgMoo<c<co000000?ooooo0_o^k^h3oooo
o`;ok^k^1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41002oooool0
0ol0003oooooooooo`15ooooo`03o`000?oooooo000000Wooooo0_l0003oooooohWooooo0009oooo
o`03onk^k_m4A4Co000000oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00?o0000ooooooooool0AOooool00ol0003oooooo`000009ooooo`;o0000oooooon9
ooooo`002_ooool00omgMgOo0000ooooo`0<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP03ooooo`;o00001_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooo
000000Wooooo0_l0003oooooohWooooo000Wooooo`04o`000?ooooooooooo`0000Gooooo00?o0000
ooooooooool0AOooool00ol0003oooooo`00003ooooooiCooooo000Wooooo`04o`000?oooooooooo
o`0000Gooooo00?o0000ooooooooool0AOooool00ol0003oooooo`00003ooooooiCooooo000Woooo
o`?o00001_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooo00000?ooooooU?ooool002So
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`15ooooo`03o`000?oooooo00000?oo
ooooU?ooool002Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`15ooooo`03o`00
0?oooooo00000?ooooooU?ooool0033ooooo00?o0000ooooooooool0AOooool00ol0003oooooo`00
003ooooooiCooooo000`ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooool00000oooooonD
ooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooo00000?ooooooU?ooool0033o
oooo0ol00015ooooo`03o`000?oooooo00000?ooooooU?ooool0033ooooo00?o0000ooooooooool0
AOooool00ol0003oooooo`00003ooooooiCooooo000`ooooo`03o`000?oooooooooo04Gooooo00?o
0000ooooool00000oooooonDooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooo
00000?ooooooU?ooool0033ooooo00?o0000ooooooooool0AOooool00ol0003oooooo`00003ooooo
oiCooooo000`ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooool00000oooooonDooooo`00
<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooo00000?ooooooU?ooool0033ooooo00?o
0000ooooooooool0AOooool00ol0003oooooo`00003ooooooiCooooo000`ooooo`03o`000?oooooo
oooo04Gooooo0_l0003ooooooiGooooo000`ooooo`03o`000?oooooooooo04Gooooo0_l0003ooooo
oiGooooo000`ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0oooooonCooooo`00
<?ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo0?ooooooToooool0033ooooo0ol0
0016ooooo`03o`000?oooooooooo0?ooooooToooool0033ooooo00?o0000ooooooooool0A_ooool0
0ol0003oooooooooo`3ooooooi?ooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033o
oooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo
000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooL
ooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oo
oooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooooooo
o`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo0ol0003ooooo
omcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0
oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooo
oooo0?oooooog?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo
4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oo
ooooooooool@ooooo`00oooooooooooooa3ooooo002Pooooo`;o00001?ooool00onj^[[o<S8boooo
o`04ooooo`;o00001_ooool00ol0003o^[Zjooooo`3ooooooeOooooo002Pooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`;o<S8boooooomH
ooooo`00SOooool3o`0000;ooooo00Ko<S8boa0@4?ooooooooooonk^k_mEEED2o`000003odA4A?nj
^[[ooooo00?ooooo00?o0000ooooooooool00_ooool01OnHV9So410@o`000?l0003oZJVY00Cooooo
00?o0000ooooooooool01?ooool00on7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj
^[X02Oooool01OnHV9So410@o`000?lb<S;oc<c<00Gooooo0_lQ8B46ooooo`;o000000Oo410@oooo
ooo<c<cok^k^ooooooo^k^koc<c<00Cooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb
<S;ok^k^4oooool01_l@413o<S8bo`000?l0003o410@ojVYZ@;ooooo00Kok^k^oeEEEOl0003o0000
odA4A?nj^[X3ooooo`05ofIVI_l0003o0000odA4A?o<c<`0j?ooool008kooooo00Go0000oooooooo
ooooc<c<oa0@4003ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo410@1?ooool00ol0003ooooooooo
o`02ooooo`06o`000?nYZJWoEEEEoiRHV?mEEEGo^[Zj0oooool00ol0003oooooooooo`04ooooo`03
olc<c?l0003o410@00cooooo00Ko410@okZj^_o^k^koMgMgoa0@4?ooool6o`0000;ooooo00Go410@
okZj^_ooooooMgMgoc8b<P05ooooo`;o8B4Q1oooool02?l0003oooooooooooo^k^koEEEEomgMgOmE
EEGok^k^1_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool0
1_l0003oZJVYoooooooooooo^[Zjo`0000;ooooo00KoEEEEogMgMoooooook^k^ogMgMol@4102oooo
o`06ofIVI_mgMgOooooooooooon7QhOo410@j?ooool008kooooo00Go0000ooooooooooooEEEEohN7
Q`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool01_lb<S;ok^k^oiRH
V?mEEEGogMgMoa0@40?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo00Wooooo1Ol00002ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000oooooooo
ool00_ooool01Ol@413ooooooooooooooooo410@01Cooooo00Go^[ZjohN7QomVIVKoIVIVoa0@4002
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0joooool008kooooo00Go0000oooo
oooMgMgo0000onk^kP03ooooo`Ko00001?ooool00ol0003oooooooooo`02ooooo`07okZj^_m4A4Co
c<c<ob4Q8Ooooooo410@olc<c002ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
0oooool6o`0000Gooooo00?oZJVYoa0@4?ooool02_ooool01?m4A4CogMgMooooool00002ooooo`05
onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool000004oooool01_lb<S;o8B4QogMgMomgMgOoQhN7onk^kP;ooooo1_l00002ooooo`03o`00
0?oooooooooo0>_ooooo002>ooooo`?o000000?o410@oiRHV?ooool00_ooool01_mEEEGoQhN7onk^
k_ooooooQhN7oc8b<PCooooo00?o0000ooooooooool00_ooool01oo^k^ko0000ooooool0003ooooo
ofIVI_n7QhL00_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00gooooo00?o410@
o`000?nj^[X02oooool01?oMgMgoEEEEooooool00002ooooo`05olc<c?o^k^koooooonk^k_o<c<`0
1_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000004oooool01_l0003o
^[Zjooooooo^k^koMgMgo`0000;ooooo00KoEEEEohN7Qoo^k^koooooohN7Qolb<S82ooooo`06ofIV
I_mgMgOooooooooooon7QhOo0000j?ooool008kooooo00Go0000ooooooooooooc<c<o`000003oooo
o`06onk^k_mEEEGo0000o`000?m4A4Cok^k^1?ooool00ol0003oooooooooo`02ooooo`04ofIVI_nH
V9Sooooooc8b<P;o^[Zj00Co0000oooooooooooo00004oooool00ol@413o0000o`000003o`0000go
oooo00?o^[Zjob4Q8Oooool02oooool00omgMgOoc<c<o`00000=ooooo`03o`000?oooooooooo00;o
oooo00Go410@oooooooooooooooooa0@4007ooooo`?o00000_ooool3o`0000Cooooo00KoZJVYob4Q
8Ol0003o0000oc8b<_l00002ooooo`06onk^k_mEEEGo0000o`000?m4A4Cok^k^0_ooool01_o^k^ko
IVIVo`000?l0003oA4A4o`000>Sooooo002>ooooo`05o`000?ooooooooooolc<c?l000003Oooool0
0ol0003oooooooooo`05ooooo`03ofIVI_n7QhOooooo00?ooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`0;ooooo`05oa0@4?nHV9SooooookZj^_l000003?ooool00oo^k^koA4A4o`00
000=ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0ooooool2ooooo`00SOooool4o`000003oa0@4?nY
ZJWooooo00cooooo0_l00006ooooo`03ojVYZOm4A4Cooooo00;ooooo0_l0000Eooooo`03o`000?oo
oooooooo00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@0=ooooo`03ogMgMol0003ooooo00[ooooo
00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo1?l00002ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0ooooool2ooooo`00ooooool6ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0ooooool2ooooo`00ooooool6ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0ooooool2ooooo`00ooooool5ooooo`;o00000oooool2
o`000?oooooo1?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo
4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oo
ooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@
ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooo
oooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3o
oooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo0000\
\>"],
  ImageRangeCache->{{{0, 525.688}, {324.5, 0}} -> {0, -6.34248*^6, 0, 53093}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0.309017 5.42214e-08 [
[.32684 .29652 -16.5 -12.5 ]
[.32684 .29652 16.5 0 ]
[.54329 .29652 -16.5 -12.5 ]
[.54329 .29652 16.5 0 ]
[.75974 .29652 -22.5 -12.5 ]
[.75974 .29652 22.5 0 ]
[.97619 .29652 -16.5 -12.5 ]
[.97619 .29652 16.5 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 64 6 ]
[.09789 .09213 -34.5 -6.25 ]
[.09789 .09213 0 6.25 ]
[.09789 .20057 -34.5 -6.25 ]
[.09789 .20057 0 6.25 ]
[.09789 .41746 -28.5 -6.25 ]
[.09789 .41746 0 6.25 ]
[.09789 .5259 -28.5 -6.25 ]
[.09789 .5259 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -62.8125 0 ]
[.5 .63053 62.8125 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 .30902 m
.32684 .31527 L
s
gsave
.32684 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 .30902 m
.54329 .31527 L
s
gsave
.54329 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 .30902 m
.75974 .31527 L
s
gsave
.75974 .29652 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 .30902 m
.15368 .31277 L
s
.19697 .30902 m
.19697 .31277 L
s
.24026 .30902 m
.24026 .31277 L
s
.28355 .30902 m
.28355 .31277 L
s
.37013 .30902 m
.37013 .31277 L
s
.41342 .30902 m
.41342 .31277 L
s
.45671 .30902 m
.45671 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.58658 .30902 m
.58658 .31277 L
s
.62987 .30902 m
.62987 .31277 L
s
.67316 .30902 m
.67316 .31277 L
s
.71645 .30902 m
.71645 .31277 L
s
.80303 .30902 m
.80303 .31277 L
s
.84632 .30902 m
.84632 .31277 L
s
.88961 .30902 m
.88961 .31277 L
s
.9329 .30902 m
.9329 .31277 L
s
.0671 .30902 m
.0671 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09213 m
.11664 .09213 L
s
gsave
.09789 .09213 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .20057 m
.11664 .20057 L
s
gsave
.09789 .20057 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .41746 m
.11664 .41746 L
s
gsave
.09789 .41746 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .5259 m
.11664 .5259 L
s
gsave
.09789 .5259 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.11039 .11924 m
.11414 .11924 L
s
.11039 .14635 m
.11414 .14635 L
s
.11039 .17346 m
.11414 .17346 L
s
.11039 .22768 m
.11414 .22768 L
s
.11039 .2548 m
.11414 .2548 L
s
.11039 .28191 m
.11414 .28191 L
s
.11039 .33613 m
.11414 .33613 L
s
.11039 .36324 m
.11414 .36324 L
s
.11039 .39035 m
.11414 .39035 L
s
.11039 .44457 m
.11414 .44457 L
s
.11039 .47168 m
.11414 .47168 L
s
.11039 .49879 m
.11414 .49879 L
s
.11039 .06502 m
.11414 .06502 L
s
.11039 .03791 m
.11414 .03791 L
s
.11039 .0108 m
.11414 .0108 L
s
.11039 .55301 m
.11414 .55301 L
s
.11039 .58012 m
.11414 .58012 L
s
.11039 .60723 m
.11414 .60723 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -123.812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.812 moveto
(@) show
81.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.812 moveto
(D) show
93.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.6) show
135.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
141.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
153.000 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
157.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
166.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
184.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02691 .30902 L
.03029 .30902 L
.03194 .30902 L
.03347 .30902 L
.03423 .30902 L
.0346 .30902 L
.03494 .30902 L
.03513 .30902 L
.03534 .30902 L
.03555 .30902 L
.03566 .30902 L
.03572 .30902 L
.03577 .30902 L
.03587 .30902 L
.03596 .30902 L
.03605 .30902 L
.03613 .30902 L
.03623 .30902 L
.03632 .30902 L
.03643 .30902 L
.03652 .30902 L
.03672 .30902 L
.0369 .30902 L
.0371 .30902 L
.03731 .30902 L
.03774 .30902 L
.03814 .30902 L
.0385 .30902 L
.0389 .30902 L
.03962 .30902 L
.04037 .30902 L
.04121 .30902 L
.04208 .30902 L
.04289 .30902 L
.04368 .30902 L
.04451 .30902 L
.046 .30902 L
.04758 .30902 L
.04906 .30902 L
.0507 .30902 L
.05219 .30902 L
.0554 .30902 L
.05849 .30902 L
.06005 .30902 L
.06177 .30902 L
.06256 .30902 L
.06341 .30902 L
.06382 .30902 L
.0642 .30902 L
Mistroke
.06455 .30902 L
.06475 .30902 L
.06493 .30902 L
.06504 .30902 L
.06515 .30902 L
.06524 .30902 L
.06534 .30902 L
.0654 .30902 L
.06545 .30902 L
.06551 .30902 L
.06557 .30902 L
.06567 .30902 L
.06573 .30902 L
.06578 .30902 L
.06597 .30902 L
.06607 .30902 L
.06617 .30902 L
.06637 .30902 L
.06658 .30902 L
.06696 .30902 L
.06736 .30902 L
.06771 .30902 L
.06808 .30902 L
.06891 .30902 L
.06966 .30902 L
.07052 .30902 L
.07134 .30902 L
.07212 .30902 L
.07295 .30902 L
.07443 .30902 L
.07601 .30902 L
.07748 .30902 L
.0806 .30902 L
.08391 .30902 L
.08711 .30902 L
.08857 .30902 L
.0894 .30902 L
.08981 .30902 L
.09018 .30902 L
.09038 .30902 L
.09055 .30902 L
.09074 .30902 L
.09084 .30902 L
.09095 .30902 L
.091 .30902 L
.09105 .30902 L
.09111 .30902 L
.09117 .30902 L
.09127 .30902 L
.09132 .30902 L
Mistroke
.09138 .30902 L
.09148 .30902 L
.09157 .30902 L
.09167 .30902 L
.09177 .30902 L
.09197 .30902 L
.09219 .30902 L
.09258 .30902 L
.09281 .30902 L
.09304 .30902 L
.09345 .30902 L
.09424 .30902 L
.09463 .30902 L
.09507 .30902 L
.09655 .30902 L
.09737 .30902 L
.09812 .30902 L
.0998 .30902 L
.10133 .30902 L
.103 .30902 L
.10627 .30902 L
.10943 .30903 L
.11101 .30903 L
.1117 .30903 L
.11246 .30903 L
.11282 .30903 L
.11321 .30903 L
.11343 .30903 L
.11363 .30903 L
.11381 .30903 L
.11401 .30903 L
.11411 .30903 L
.11417 .30903 L
.11423 .30903 L
.11433 .30903 L
.11442 .30903 L
.11448 .30903 L
.11454 .30903 L
.1146 .30903 L
.11466 .30903 L
.11476 .30903 L
.11482 .30903 L
.11487 .30903 L
.11507 .30903 L
.11519 .30903 L
.11529 .30903 L
.1155 .30903 L
.11569 .30903 L
.11606 .30903 L
.11647 .30903 L
Mistroke
.1172 .30903 L
.11761 .30903 L
.11805 .30903 L
.11886 .30902 L
.11962 .30902 L
.12045 .30902 L
.12214 .30901 L
.1237 .309 L
.12537 .30899 L
.12868 .30895 L
.13033 .30894 L
.13187 .30892 L
.13335 .30891 L
.13378 .3089 L
.13418 .3089 L
.13457 .3089 L
.13493 .3089 L
.13511 .3089 L
.13531 .3089 L
.13542 .3089 L
.13552 .3089 L
.13561 .3089 L
.13572 .3089 L
.13581 .3089 L
.13587 .3089 L
.13592 .3089 L
.13598 .3089 L
.13603 .3089 L
.13609 .3089 L
.13615 .3089 L
.13633 .3089 L
.13644 .3089 L
.13654 .3089 L
.13674 .3089 L
.13692 .3089 L
.13726 .3089 L
.13763 .3089 L
.13803 .30891 L
.13878 .30892 L
.13962 .30893 L
.14049 .30895 L
.14131 .30898 L
.14294 .30904 L
.14442 .30912 L
.14761 .30933 L
.15068 .30956 L
.1524 .30968 L
.15321 .30973 L
.15395 .30976 L
.15433 .30977 L
Mistroke
.15473 .30978 L
.15494 .30979 L
.15513 .30979 L
.15524 .30979 L
.15534 .30979 L
.1554 .30979 L
.15546 .30979 L
.15552 .30979 L
.15557 .30979 L
.15566 .3098 L
.15575 .30979 L
.15584 .30979 L
.15592 .30979 L
.15601 .30979 L
.15611 .30979 L
.15631 .30979 L
.15651 .30979 L
.15672 .30978 L
.15709 .30977 L
.15752 .30975 L
.15792 .30972 L
.15881 .30964 L
.1596 .30955 L
.16043 .30943 L
.162 .30911 L
.16347 .30872 L
.16659 .30765 L
.16818 .30703 L
.16991 .30639 L
.17071 .30612 L
.17157 .30587 L
.17237 .30568 L
.17272 .30561 L
.1731 .30555 L
.17347 .3055 L
.17367 .30549 L
.17385 .30547 L
.17396 .30547 L
.17406 .30546 L
.17415 .30546 L
.17424 .30546 L
.17435 .30546 L
.1744 .30546 L
.17446 .30546 L
.17457 .30546 L
.17466 .30547 L
.17475 .30547 L
.17485 .30548 L
.17503 .30549 L
.17521 .30551 L
Mistroke
.17537 .30553 L
.17574 .30559 L
.17613 .30567 L
.17656 .3058 L
.17695 .30593 L
.17785 .30634 L
.17864 .30681 L
.17947 .30742 L
.18104 .30891 L
.18252 .31064 L
.18564 .31502 L
.18723 .31728 L
.18807 .31837 L
.18896 .31938 L
.18975 .32013 L
.19017 .32046 L
.19062 .32074 L
.19082 .32085 L
.19104 .32094 L
.19123 .32101 L
.19141 .32106 L
.19159 .3211 L
.19168 .32112 L
.19177 .32113 L
.19187 .32114 L
.19197 .32114 L
.19207 .32114 L
.19216 .32114 L
.19226 .32113 L
.19236 .32111 L
.19244 .3211 L
.19253 .32108 L
.19274 .32102 L
.19294 .32094 L
.19329 .32076 L
.19367 .32049 L
.19411 .32008 L
.19454 .31959 L
.19532 .31842 L
.19611 .31691 L
.19694 .31495 L
.19842 .31054 L
.20147 .2987 L
.20318 .29147 L
.20472 .28536 L
.20549 .28271 L
.20633 .28028 L
.20671 .27935 L
.20712 .2785 L
.2075 .27787 L
Mistroke
.20785 .2774 L
.20804 .2772 L
.20825 .27704 L
.20834 .27698 L
.20843 .27693 L
.20852 .27689 L
.20861 .27686 L
.20871 .27684 L
.20881 .27684 L
.20891 .27684 L
.20897 .27685 L
.20902 .27686 L
.20912 .27689 L
.20923 .27694 L
.20933 .277 L
.20942 .27706 L
.20961 .27723 L
.20978 .27743 L
.21017 .27802 L
.21052 .27872 L
.21089 .27966 L
.21164 .28216 L
.21245 .28577 L
.21391 .29463 L
.21552 .30741 L
.21721 .32338 L
.22027 .35347 L
.22184 .36629 L
.22273 .37176 L
.22311 .37368 L
.22353 .37535 L
.22391 .37653 L
.22412 .37704 L
.22433 .37741 L
.22442 .37755 L
.22451 .37765 L
.22459 .37773 L
.22468 .37779 L
.22478 .37783 L
.22488 .37785 L
.22498 .37784 L
.22506 .37781 L
.22517 .37774 L
.22522 .3777 L
.22528 .37764 L
.22548 .37736 L
.22559 .37715 L
.22571 .37689 L
.22592 .37631 L
.22635 .37476 L
Mistroke
.22673 .37287 L
.22753 .36751 L
.22827 .36083 L
.22993 .33992 L
.23309 .28403 L
.23612 .22675 L
.23767 .20402 L
.2381 .19922 L
.23855 .19494 L
.23897 .19173 L
.23935 .18952 L
.23954 .18867 L
.23974 .18796 L
.23984 .18771 L
.23994 .18749 L
.24002 .18734 L
.24012 .18722 L
.24017 .18717 L
.24022 .18714 L
.24032 .18712 L
.24043 .18715 L
.24048 .18719 L
.24054 .18725 L
.24064 .1874 L
.24073 .18758 L
.24094 .18815 L
.24113 .18889 L
.2413 .18975 L
.2417 .1923 L
.24204 .19528 L
.24241 .19914 L
.24317 .20957 L
.24399 .22418 L
.24546 .25858 L
.24879 .36059 L
.25046 .41267 L
.25119 .43322 L
.252 .45318 L
.25272 .46807 L
.25349 .4804 L
.25392 .48537 L
.25431 .48869 L
.2545 .48986 L
.2546 .49037 L
.2547 .49081 L
.25481 .49116 L
.2549 .49139 L
.25499 .49156 L
.25508 .49165 L
.25517 .49168 L
Mistroke
.25527 .49162 L
.25537 .4915 L
.25545 .49131 L
.25555 .49102 L
.25566 .4906 L
.25586 .48957 L
.25607 .48812 L
.25629 .48618 L
.25669 .48161 L
.25739 .47019 L
.25817 .45277 L
.25973 .40437 L
.2614 .3364 L
.26298 .26464 L
.2647 .18772 L
.26556 .15363 L
.26637 .12564 L
.26715 .10332 L
.26788 .08779 L
.26825 .08198 L
.26864 .07739 L
.26884 .07567 L
.26903 .07447 L
.26913 .07396 L
.26923 .07361 L
.26929 .07347 L
.26935 .07335 L
.2694 .07328 L
.26945 .07324 L
.26956 .07327 L
.26962 .07334 L
.26968 .07344 L
.26978 .07372 L
.26983 .0739 L
.26988 .07414 L
.27008 .0753 L
.27027 .0768 L
.27049 .07908 L
.27069 .08165 L
.27114 .08911 L
.27152 .09738 L
.27193 .10799 L
.27267 .13149 L
.27434 .20303 L
.27737 .36987 L
.27906 .45966 L
.2798 .49354 L
.2806 .52503 L
.28098 .53753 L
.28139 .54906 L
Mistroke
.28174 .55742 L
.28212 .56471 L
.28234 .56814 L
.28255 .5707 L
.28275 .57261 L
.28285 .57339 L
.28295 .57406 L
.28305 .57453 L
.28314 .57484 L
.28323 .57505 L
.28332 .57514 L
.28341 .57512 L
.28351 .57498 L
.28361 .5747 L
.28366 .5745 L
.28371 .57424 L
.2839 .57304 L
.28401 .57214 L
.28411 .57116 L
.28452 .5656 L
.28488 .5589 L
.28526 .54983 L
.28614 .52209 L
.28694 .48915 L
.29014 .3077 L
.29161 .21787 L
.29323 .13156 L
.294 .09878 L
.29482 .07121 L
.29528 .0598 L
.29569 .05187 L
.29589 .04894 L
.29611 .04641 L
.29621 .04548 L
.29632 .04466 L
.29642 .04404 L
.29651 .04359 L
.29661 .04325 L
.29666 .04313 L
.29672 .04305 L
.29678 .04301 L
.29683 .04303 L
.29694 .04318 L
.29704 .04347 L
.29713 .04387 L
.29723 .04444 L
.29734 .04522 L
.29755 .04734 L
.29776 .04996 L
.29823 .0582 L
Mistroke
.29864 .06782 L
.29901 .07858 L
.29985 .10911 L
.30137 .18271 L
.30303 .27982 L
.30474 .38171 L
.30629 .4619 L
.30706 .49387 L
.30747 .50799 L
.3079 .52071 L
.30828 .52987 L
.30869 .53773 L
.30887 .54043 L
.30907 .54282 L
.30925 .54458 L
.30942 .54578 L
.30953 .54631 L
.30962 .54668 L
.30971 .54689 L
.30981 .547 L
.30991 .54697 L
.30996 .5469 L
.31002 .54678 L
.31012 .54645 L
.31021 .54602 L
.31031 .54545 L
.3104 .5448 L
.31057 .54328 L
.31095 .53845 L
.31136 .53098 L
.31175 .52214 L
.31261 .49578 L
.31412 .43288 L
.31577 .34814 L
.31746 .2597 L
.319 .18981 L
.31977 .16242 L
.32017 .15029 L
.3206 .13929 L
.32101 .13071 L
.32138 .12466 L
.32157 .12234 L
.32176 .12027 L
.32195 .11875 L
.32211 .11771 L
.32222 .11726 L
.32231 .11694 L
.3224 .11676 L
.32249 .11666 L
.32259 .11667 L
Mistroke
.32264 .11672 L
.3227 .11682 L
.3228 .11708 L
.3229 .11743 L
.32298 .11787 L
.32308 .11843 L
.32325 .11968 L
.32362 .1237 L
.32403 .12986 L
.32442 .13719 L
.32528 .15909 L
.32692 .21629 L
.32842 .27828 L
.33008 .34724 L
.33082 .37438 L
.33162 .4005 L
.33235 .41981 L
.33312 .43562 L
.33355 .44199 L
.33394 .44629 L
.33413 .44784 L
.33423 .44852 L
.33434 .44914 L
.33444 .44963 L
.33453 .45 L
.33462 .45028 L
.33471 .45047 L
.3348 .4506 L
.3349 .45064 L
.335 .45059 L
.33508 .45048 L
.33519 .45025 L
.33524 .45008 L
.3353 .4499 L
.3355 .44898 L
.33569 .44777 L
.3359 .44605 L
.33632 .44141 L
.33669 .43621 L
.33709 .42945 L
.33781 .41448 L
.34111 .31919 L
.34276 .27169 L
.34357 .25225 L
.3443 .23759 L
.34466 .23145 L
.34506 .22577 L
.3454 .22171 L
.34578 .21816 L
.34597 .21673 L
Mistroke
.34618 .21547 L
.34629 .2149 L
.34639 .21446 L
.3465 .2141 L
.3466 .21382 L
.34669 .21363 L
.34679 .21349 L
.34688 .21341 L
.34694 .21339 L
.34699 .21339 L
.34708 .21344 L
.34717 .21353 L
.34726 .21369 L
.34736 .21392 L
.34746 .21421 L
.34756 .2146 L
.34776 .21549 L
.34812 .21779 L
.34855 .22146 L
.34894 .22573 L
.35041 .24805 L
.35357 .31154 L
.35516 .33989 L
.35585 .34977 L
.35661 .35833 L
.35702 .36196 L
.35741 .36462 L
.35777 .36654 L
.35798 .36734 L
.35817 .36789 L
.35827 .36814 L
.35838 .36834 L
.35848 .36847 L
.35858 .36856 L
.35864 .36859 L
.35869 .36861 L
.35875 .36861 L
.35881 .3686 L
.35892 .36854 L
.35897 .36849 L
.35903 .36842 L
.35913 .36828 L
.35922 .3681 L
.35942 .36758 L
.35962 .36691 L
.35984 .36599 L
.36024 .36386 L
.36061 .36136 L
.36145 .3541 L
.36314 .33469 L
Mistroke
.36465 .31536 L
.36628 .29621 L
.36717 .28775 L
.36799 .28165 L
.3684 .27931 L
.36878 .27754 L
.36917 .27613 L
.36938 .27557 L
.36961 .2751 L
.36972 .27493 L
.36981 .2748 L
.36993 .27468 L
.37003 .27461 L
.37013 .27457 L
.37022 .27455 L
.37032 .27456 L
.37042 .27459 L
.37053 .27466 L
.37059 .27471 L
.37064 .27476 L
.37085 .27503 L
.37096 .27522 L
.37108 .27547 L
.37131 .27602 L
.37172 .2773 L
.37215 .27905 L
.37292 .28304 L
.37596 .30439 L
.37764 .31575 L
.37838 .31978 L
.37919 .3233 L
.37957 .3246 L
.37998 .32574 L
.38036 .32656 L
.38071 .3271 L
.38091 .32733 L
.3811 .32748 L
.3812 .32753 L
.38125 .32756 L
.38131 .32758 L
.38136 .32759 L
.38142 .3276 L
.38153 .32761 L
.38162 .3276 L
.38172 .32757 L
.38182 .32753 L
.38192 .32748 L
.3821 .32734 L
.3823 .32714 L
.38269 .32658 L
Mistroke
.38311 .32579 L
.38385 .32388 L
.38552 .31801 L
.38858 .30631 L
.38939 .30389 L
.39015 .30207 L
.39058 .30127 L
.39103 .30059 L
.39124 .30034 L
.39145 .30012 L
.39163 .29997 L
.39183 .29983 L
.39194 .29977 L
.39204 .29973 L
.39214 .29969 L
.39223 .29966 L
.39232 .29964 L
.3924 .29963 L
.39249 .29963 L
.39259 .29963 L
.39269 .29963 L
.39274 .29964 L
.3928 .29965 L
.3929 .29968 L
.39301 .29972 L
.39322 .29981 L
.3934 .29992 L
.39376 .3002 L
.39416 .30061 L
.39487 .30157 L
.39646 .30442 L
.39815 .30783 L
.39973 .31064 L
.40042 .31162 L
.40118 .31247 L
.40157 .3128 L
.40194 .31306 L
.40232 .31326 L
.40254 .31334 L
.40273 .3134 L
.40284 .31343 L
.40295 .31345 L
.40304 .31346 L
.40315 .31347 L
.40321 .31348 L
.40326 .31348 L
.40332 .31348 L
.40338 .31348 L
.40348 .31348 L
.40354 .31347 L
Mistroke
.4036 .31347 L
.4037 .31345 L
.4038 .31344 L
.40399 .3134 L
.40419 .31334 L
.40441 .31326 L
.40481 .31308 L
.40517 .31287 L
.40601 .31226 L
.40771 .31072 L
.40921 .30929 L
.41084 .30802 L
.41127 .30776 L
.41172 .30752 L
.41215 .30735 L
.41254 .30721 L
.41292 .30712 L
.41312 .30708 L
.41331 .30706 L
.41341 .30704 L
.41352 .30703 L
.41358 .30703 L
.41364 .30703 L
.4137 .30702 L
.41375 .30702 L
.41385 .30702 L
.4139 .30702 L
.41396 .30702 L
.41406 .30702 L
.41416 .30702 L
.41427 .30703 L
.41436 .30703 L
.41458 .30705 L
.41477 .30708 L
.41498 .30711 L
.41533 .30718 L
.41573 .30729 L
.4174 .30789 L
.41909 .30862 L
.42063 .30922 L
.42141 .30947 L
.42214 .30964 L
.42254 .30972 L
.4229 .30977 L
.42331 .30982 L
.42353 .30984 L
.42374 .30985 L
.42383 .30985 L
.42393 .30986 L
.42402 .30986 L
Mistroke
.42411 .30986 L
.42421 .30987 L
.42426 .30987 L
.42432 .30987 L
.42441 .30987 L
.42452 .30987 L
.42457 .30986 L
.42462 .30986 L
.42474 .30986 L
.42484 .30986 L
.42495 .30985 L
.42514 .30984 L
.42534 .30983 L
.42571 .3098 L
.42611 .30975 L
.42682 .30965 L
.42842 .30937 L
.43015 .30906 L
.43095 .30893 L
.43181 .30883 L
.43254 .30876 L
.43296 .30872 L
.43335 .3087 L
.43353 .3087 L
.43373 .30869 L
.43394 .30868 L
.43414 .30868 L
.43425 .30868 L
.43431 .30868 L
.43436 .30868 L
.43447 .30867 L
.43452 .30867 L
.43457 .30867 L
.43467 .30867 L
.43478 .30868 L
.43488 .30868 L
.43497 .30868 L
.43516 .30868 L
.43534 .30868 L
.43573 .3087 L
.43608 .30871 L
.43646 .30873 L
.43948 .30894 L
.4403 .309 L
.44116 .30905 L
.44196 .30909 L
.44235 .30911 L
.44271 .30912 L
.44305 .30913 L
.44342 .30914 L
Mistroke
.44363 .30914 L
.44382 .30914 L
.444 .30915 L
.44419 .30915 L
.44429 .30915 L
.44438 .30915 L
.44449 .30915 L
.44459 .30915 L
.44468 .30915 L
.44476 .30915 L
.44486 .30915 L
.44496 .30915 L
.44507 .30915 L
.44519 .30915 L
.4454 .30914 L
.44581 .30914 L
.4462 .30913 L
.44657 .30913 L
.44741 .3091 L
.4491 .30906 L
.4506 .30902 L
.45139 .309 L
.45223 .30898 L
.45265 .30898 L
.45311 .30897 L
.45331 .30897 L
.45353 .30897 L
.45374 .30897 L
.45393 .30897 L
.45402 .30897 L
.45413 .30897 L
.45422 .30897 L
.45431 .30897 L
.45441 .30897 L
.45447 .30897 L
.45452 .30897 L
.45461 .30897 L
.45472 .30897 L
.45482 .30897 L
.45492 .30897 L
.45511 .30897 L
.45534 .30897 L
.45555 .30897 L
.45634 .30898 L
.45707 .30898 L
.45874 .309 L
.46025 .30902 L
.46105 .30902 L
.46188 .30903 L
.46231 .30903 L
Mistroke
.46278 .30903 L
.46299 .30903 L
.46321 .30903 L
.46342 .30903 L
.46361 .30903 L
.46371 .30903 L
.46382 .30903 L
.46393 .30903 L
.46399 .30903 L
.46404 .30903 L
.46415 .30903 L
.46424 .30903 L
.46429 .30903 L
.46435 .30903 L
.46445 .30903 L
.46456 .30903 L
.46465 .30903 L
.46485 .30903 L
.46505 .30903 L
.46523 .30903 L
.46601 .30903 L
.46684 .30903 L
.46832 .30902 L
.46991 .30902 L
.47061 .30902 L
.47137 .30901 L
.47178 .30901 L
.47217 .30901 L
.47254 .30901 L
.47274 .30901 L
.47293 .30901 L
.47313 .30901 L
.47323 .30901 L
.47334 .30901 L
.47344 .30901 L
.47353 .30901 L
.47363 .30901 L
.47373 .30901 L
.47379 .30901 L
.47384 .30901 L
.4739 .30901 L
.47397 .30901 L
.47402 .30901 L
.47407 .30901 L
.47419 .30901 L
.47429 .30901 L
.47439 .30901 L
.47461 .30901 L
.47499 .30901 L
.4754 .30901 L
Mistroke
.47613 .30901 L
.4778 .30901 L
.4794 .30902 L
.48031 .30902 L
.48074 .30902 L
.48114 .30902 L
.48153 .30902 L
.48189 .30902 L
.48228 .30902 L
.4825 .30902 L
.4826 .30902 L
.4827 .30902 L
.4828 .30902 L
.4829 .30902 L
.48296 .30902 L
.48301 .30902 L
.48312 .30902 L
.4832 .30902 L
.4833 .30902 L
.4834 .30902 L
.4835 .30902 L
.48361 .30902 L
.48371 .30902 L
.48391 .30902 L
.48413 .30902 L
.48436 .30902 L
.48512 .30902 L
.48595 .30902 L
.48764 .30902 L
.48921 .30902 L
.48966 .30902 L
.49008 .30902 L
.4905 .30902 L
.49088 .30902 L
.49128 .30902 L
.49146 .30902 L
.49166 .30902 L
.49186 .30902 L
.49205 .30902 L
.49216 .30902 L
.49226 .30902 L
.49231 .30902 L
.49236 .30902 L
.49242 .30902 L
.49248 .30902 L
.49256 .30902 L
.49266 .30902 L
.49276 .30902 L
.49285 .30902 L
.49301 .30902 L
Mistroke
.49319 .30902 L
.49359 .30902 L
.49396 .30902 L
.49548 .30902 L
.49714 .30902 L
.49796 .30902 L
.49872 .30902 L
.49915 .30902 L
.49961 .30902 L
.50002 .30902 L
.50041 .30902 L
.5006 .30902 L
.50078 .30902 L
.50099 .30902 L
.50109 .30902 L
.50119 .30902 L
.50127 .30902 L
.50137 .30902 L
.50146 .30902 L
.50154 .30902 L
.50163 .30902 L
.50172 .30902 L
.50182 .30902 L
.50192 .30902 L
.50202 .30902 L
.50212 .30902 L
.50233 .30902 L
.50252 .30902 L
.50271 .30902 L
.50358 .30902 L
.50666 .30902 L
.50749 .30902 L
.50826 .30902 L
.50865 .30902 L
.50906 .30902 L
.5093 .30902 L
.50952 .30902 L
.50974 .30902 L
.50995 .30902 L
.51014 .30902 L
.51025 .30902 L
.51035 .30902 L
.51044 .30902 L
.51053 .30902 L
.51063 .30902 L
.51072 .30902 L
.51077 .30902 L
.51083 .30902 L
.51093 .30902 L
.51102 .30902 L
Mistroke
.51112 .30902 L
.51132 .30902 L
.51154 .30902 L
.5119 .30902 L
.51224 .30902 L
.51302 .30902 L
.5145 .30902 L
.51534 .30902 L
.51613 .30902 L
.51691 .30902 L
.51731 .30902 L
.51774 .30902 L
.51798 .30902 L
.5182 .30902 L
.5184 .30902 L
.51863 .30902 L
.51883 .30902 L
.51902 .30902 L
.51912 .30902 L
.51922 .30902 L
.51927 .30902 L
.51933 .30902 L
.51943 .30902 L
.51953 .30902 L
.51962 .30902 L
.51972 .30902 L
.51982 .30902 L
.51991 .30902 L
.52 .30902 L
.52019 .30902 L
.5204 .30902 L
.52059 .30902 L
.52102 .30902 L
.52188 .30902 L
.5227 .30902 L
.52417 .30902 L
.52501 .30902 L
.52579 .30902 L
.52618 .30902 L
.52656 .30902 L
.52699 .30902 L
.52738 .30902 L
.52758 .30902 L
.5277 .30902 L
.5278 .30902 L
.5279 .30902 L
.528 .30902 L
.5281 .30902 L
.52819 .30902 L
.52829 .30902 L
Mistroke
.52839 .30902 L
.52845 .30902 L
.5285 .30902 L
.52856 .30902 L
.52862 .30902 L
.52873 .30902 L
.52883 .30902 L
.52907 .30902 L
.52926 .30902 L
.52944 .30902 L
.52984 .30902 L
.53057 .30902 L
.53222 .30902 L
.53302 .30902 L
.53387 .30902 L
.53429 .30902 L
.53468 .30902 L
.53502 .30902 L
.53541 .30902 L
.53578 .30902 L
.53597 .30902 L
.53617 .30902 L
.53636 .30902 L
.53653 .30902 L
.53662 .30902 L
.53671 .30902 L
.53679 .30902 L
.53687 .30902 L
.53697 .30902 L
.53703 .30902 L
.53708 .30902 L
.53718 .30902 L
.53728 .30902 L
.53737 .30902 L
.53745 .30902 L
.53765 .30902 L
.53785 .30902 L
.53804 .30902 L
.53847 .30902 L
.54 .30902 L
.54167 .30902 L
.54249 .30902 L
.54326 .30902 L
.54365 .30902 L
.54406 .30902 L
.5443 .30902 L
.54453 .30902 L
.54473 .30902 L
.54484 .30902 L
.54495 .30902 L
Mistroke
.54505 .30902 L
.54515 .30902 L
.54526 .30902 L
.54532 .30902 L
.54537 .30902 L
.54548 .30902 L
.54557 .30902 L
.54562 .30902 L
.54568 .30902 L
.54578 .30902 L
.54587 .30902 L
.54597 .30902 L
.54607 .30902 L
.54617 .30902 L
.54653 .30902 L
.54695 .30902 L
.54734 .30902 L
.54821 .30902 L
.54986 .30902 L
.55066 .30902 L
.55139 .30902 L
.55175 .30902 L
.55215 .30902 L
.55249 .30902 L
.55287 .30902 L
.55307 .30902 L
.55327 .30902 L
.55347 .30902 L
.55358 .30902 L
.55369 .30902 L
.55379 .30902 L
.55388 .30902 L
.55397 .30902 L
.55408 .30902 L
.55418 .30902 L
.55427 .30902 L
.55436 .30902 L
.55445 .30902 L
.55464 .30902 L
.55484 .30902 L
.55521 .30902 L
.55605 .30902 L
.55774 .30902 L
.55856 .30902 L
.55945 .30902 L
.55986 .30902 L
.56029 .30902 L
.56069 .30902 L
.56106 .30902 L
.56143 .30902 L
Mistroke
.56162 .30902 L
.56182 .30902 L
.56192 .30902 L
.56202 .30902 L
.56208 .30902 L
.56213 .30902 L
.56224 .30902 L
.56234 .30902 L
.56244 .30902 L
.56253 .30902 L
.56263 .30902 L
.56273 .30902 L
.56282 .30902 L
.563 .30902 L
.56318 .30902 L
.56339 .30902 L
.5641 .30902 L
.56565 .30902 L
.56648 .30902 L
.56737 .30902 L
.56778 .30902 L
.56821 .30902 L
.56862 .30902 L
.56899 .30902 L
.56934 .30902 L
.56972 .30902 L
.56993 .30902 L
.57004 .30902 L
.57014 .30902 L
.57022 .30902 L
.57032 .30902 L
.57041 .30902 L
.57052 .30902 L
.57062 .30902 L
.57071 .30902 L
.57082 .30902 L
.57088 .30902 L
.57093 .30902 L
.57103 .30902 L
.57114 .30902 L
.57133 .30902 L
.57172 .30902 L
.57207 .30902 L
.57375 .30902 L
.57454 .30902 L
.57539 .30902 L
.57619 .30902 L
.57692 .30902 L
.57731 .30902 L
.57767 .30902 L
Mistroke
.57786 .30902 L
.57807 .30902 L
.57817 .30902 L
.57828 .30902 L
.57839 .30902 L
.57849 .30902 L
.57857 .30902 L
.57867 .30902 L
.57877 .30902 L
.57886 .30902 L
.57896 .30902 L
.57907 .30902 L
.57917 .30902 L
.57926 .30902 L
.57942 .30902 L
.5796 .30902 L
.57997 .30902 L
.58078 .30902 L
.58153 .30902 L
.5824 .30902 L
.58321 .30902 L
.58401 .30902 L
.58473 .30902 L
.58515 .30902 L
.58554 .30902 L
.58574 .30902 L
.58595 .30902 L
.58619 .30902 L
.58629 .30902 L
.5864 .30902 L
.58651 .30902 L
.5866 .30902 L
.5867 .30902 L
.5868 .30902 L
.58689 .30902 L
.58697 .30902 L
.58706 .30902 L
.58716 .30902 L
.58726 .30902 L
.58737 .30902 L
.58759 .30902 L
.58779 .30902 L
.58798 .30902 L
.58869 .30902 L
.58945 .30902 L
.59105 .30902 L
.59196 .30902 L
.59239 .30902 L
.59279 .30902 L
.59318 .30902 L
Mistroke
.59353 .30902 L
.59393 .30902 L
.59414 .30902 L
.59424 .30902 L
.59435 .30902 L
.59444 .30902 L
.59455 .30902 L
.5946 .30902 L
.59466 .30902 L
.59476 .30902 L
.59485 .30902 L
.59494 .30902 L
.59505 .30902 L
.59514 .30902 L
.59519 .30902 L
.59525 .30902 L
.59536 .30902 L
.59556 .30902 L
.59579 .30902 L
.596 .30902 L
.59678 .30902 L
.59751 .30902 L
.59835 .30902 L
.59916 .30902 L
.59994 .30902 L
.60035 .30902 L
.60079 .30902 L
.60119 .30902 L
.60156 .30902 L
.60174 .30902 L
.60193 .30902 L
.60211 .30902 L
.60228 .30902 L
.60238 .30902 L
.60247 .30902 L
.60256 .30902 L
.60265 .30902 L
.60276 .30902 L
.60281 .30902 L
.60286 .30902 L
.60296 .30902 L
.60306 .30902 L
.60315 .30902 L
.60324 .30902 L
.60341 .30902 L
.60379 .30902 L
.6042 .30902 L
.60458 .30902 L
.60545 .30902 L
.60695 .30902 L
Mistroke
.6078 .30902 L
.60858 .30902 L
.60898 .30902 L
.60942 .30902 L
.60964 .30902 L
.60987 .30902 L
.60999 .30902 L
.61009 .30902 L
.6102 .30902 L
.6103 .30902 L
.6104 .30902 L
.61049 .30902 L
.61059 .30902 L
.61065 .30902 L
.6107 .30902 L
.61079 .30902 L
.61088 .30902 L
.61098 .30902 L
.61107 .30902 L
.61129 .30902 L
.61148 .30902 L
.61192 .30902 L
.61358 .30902 L
.61431 .30902 L
.61512 .30902 L
.61589 .30902 L
.61626 .30902 L
.61662 .30902 L
.61702 .30902 L
.61738 .30902 L
.61759 .30902 L
.61777 .30902 L
.61788 .30902 L
.61798 .30902 L
.61804 .30902 L
.6181 .30902 L
.61815 .30902 L
.6182 .30902 L
.6183 .30902 L
.6184 .30902 L
.61849 .30902 L
.61858 .30902 L
.61868 .30902 L
.61879 .30902 L
.61898 .30902 L
.61933 .30902 L
.61971 .30902 L
.62137 .30902 L
.62219 .30902 L
.62306 .30902 L
Mistroke
.62379 .30902 L
.62421 .30902 L
.6246 .30902 L
.62479 .30902 L
.625 .30902 L
.6252 .30902 L
.62539 .30902 L
.62555 .30902 L
.62564 .30902 L
.62573 .30902 L
.62583 .30902 L
.62591 .30902 L
.62601 .30902 L
.6261 .30902 L
.6262 .30902 L
.62629 .30902 L
.6264 .30902 L
.6265 .30902 L
.62668 .30902 L
.62687 .30902 L
.6273 .30902 L
.6277 .30902 L
.62935 .30902 L
.63015 .30902 L
.63088 .30902 L
.63124 .30902 L
.63163 .30902 L
.63201 .30902 L
.63235 .30902 L
.63253 .30902 L
.63271 .30902 L
.63292 .30902 L
.63312 .30902 L
.63322 .30902 L
.63332 .30902 L
.63338 .30902 L
.63344 .30902 L
.63354 .30902 L
.63365 .30902 L
.63374 .30902 L
.63383 .30902 L
.63393 .30902 L
.63403 .30902 L
.63412 .30902 L
.63432 .30902 L
.63469 .30902 L
.63553 .30902 L
.63722 .30902 L
.63796 .30902 L
.63875 .30902 L
Mistroke
.63916 .30902 L
.63961 .30902 L
.63981 .30902 L
.64002 .30902 L
.64023 .30902 L
.64041 .30902 L
.6406 .30902 L
.64071 .30902 L
.64081 .30902 L
.6409 .30902 L
.64099 .30902 L
.64108 .30902 L
.64118 .30902 L
.64128 .30902 L
.64133 .30902 L
.64139 .30902 L
.64148 .30902 L
.64158 .30902 L
.64179 .30902 L
.64202 .30902 L
.64244 .30902 L
.6429 .30902 L
.64371 .30902 L
.64532 .30902 L
.64575 .30902 L
.64622 .30902 L
.64662 .30902 L
.64705 .30902 L
.64726 .30902 L
.64747 .30902 L
.64766 .30902 L
.64784 .30902 L
.64802 .30902 L
.6481 .30902 L
.6482 .30902 L
.64829 .30902 L
.6484 .30902 L
.64849 .30902 L
.64858 .30902 L
.64868 .30902 L
.64879 .30902 L
.64889 .30902 L
.64898 .30902 L
.6492 .30902 L
.6494 .30902 L
.64982 .30902 L
.65027 .30902 L
.65183 .30902 L
.65266 .30902 L
.65312 .30902 L
Mistroke
.65355 .30902 L
.65396 .30902 L
.65441 .30902 L
.6546 .30902 L
.65481 .30902 L
.65501 .30902 L
.65519 .30902 L
.65539 .30902 L
.65549 .30902 L
.6556 .30902 L
.6557 .30902 L
.65579 .30902 L
.65588 .30902 L
.65599 .30902 L
.65608 .30902 L
.65619 .30902 L
.65628 .30902 L
.65637 .30902 L
.65654 .30902 L
.65672 .30902 L
.65711 .30902 L
.65747 .30902 L
.65828 .30902 L
.65975 .30902 L
.66054 .30902 L
.66127 .30902 L
.6617 .30902 L
.66208 .30902 L
.66229 .30902 L
.6624 .30902 L
.66252 .30902 L
.66262 .30902 L
.66274 .30902 L
.66284 .30902 L
.66294 .30902 L
.66304 .30902 L
.66309 .30902 L
.66315 .30902 L
.66325 .30902 L
.66334 .30902 L
.66339 .30902 L
.66345 .30902 L
.66355 .30902 L
.66366 .30902 L
.66378 .30902 L
.66397 .30902 L
.66419 .30902 L
.66457 .30902 L
.66606 .30902 L
.66688 .30902 L
Mistroke
.66731 .30902 L
.66777 .30902 L
.66817 .30902 L
.66861 .30902 L
.66901 .30902 L
.66939 .30902 L
.6696 .30902 L
.66979 .30902 L
.6699 .30902 L
.67 .30902 L
.67012 .30902 L
.67017 .30902 L
.67022 .30902 L
.67032 .30902 L
.67042 .30902 L
.67052 .30902 L
.6706 .30902 L
.67071 .30902 L
.6708 .30902 L
.67091 .30902 L
.67102 .30902 L
.67139 .30902 L
.67173 .30902 L
.6725 .30902 L
.67329 .30902 L
.67413 .30902 L
.67486 .30902 L
.67527 .30902 L
.67566 .30902 L
.67603 .30902 L
.67643 .30902 L
.67665 .30902 L
.67685 .30902 L
.67704 .30902 L
.67714 .30902 L
.67724 .30902 L
.67732 .30902 L
.67741 .30902 L
.6775 .30902 L
.67758 .30902 L
.67767 .30902 L
.67777 .30902 L
.67786 .30902 L
.67795 .30902 L
.67803 .30902 L
.67812 .30902 L
.67831 .30902 L
.67869 .30902 L
.67948 .30902 L
.68031 .30902 L
Mistroke
.68108 .30902 L
.68179 .30902 L
.68256 .30902 L
.68298 .30902 L
.68337 .30902 L
.68355 .30902 L
.68374 .30902 L
.6839 .30902 L
.68408 .30902 L
.68418 .30902 L
.68427 .30902 L
.68436 .30902 L
.68444 .30902 L
.68454 .30902 L
.6846 .30902 L
.68465 .30902 L
.68475 .30902 L
.68485 .30902 L
.68494 .30902 L
.68503 .30902 L
.68513 .30902 L
.68524 .30902 L
.68545 .30902 L
.68565 .30902 L
.68639 .30902 L
.68806 .30902 L
.68881 .30902 L
.68959 .30902 L
.69001 .30902 L
.69022 .30902 L
.69046 .30902 L
.69068 .30902 L
.69087 .30902 L
.69106 .30902 L
.69126 .30902 L
.69136 .30902 L
.69147 .30902 L
.69157 .30902 L
.69166 .30902 L
.69175 .30902 L
.69184 .30902 L
.69194 .30902 L
.69203 .30902 L
.69213 .30902 L
.69223 .30902 L
.69242 .30902 L
.69262 .30902 L
.69285 .30902 L
.69432 .30902 L
.6952 .30902 L
Mistroke
.69603 .30902 L
.69678 .30902 L
.6972 .30902 L
.69739 .30902 L
.69759 .30902 L
.69778 .30902 L
.69796 .30902 L
.69815 .30902 L
.69832 .30902 L
.69841 .30902 L
.69852 .30902 L
.6986 .30902 L
.6987 .30902 L
.6988 .30902 L
.69886 .30902 L
.69892 .30902 L
.69901 .30902 L
.69912 .30902 L
.69922 .30902 L
.69931 .30902 L
.69952 .30902 L
.69989 .30902 L
.70073 .30902 L
.70155 .30902 L
.70241 .30902 L
.70314 .30902 L
.70356 .30902 L
.70395 .30902 L
.70434 .30902 L
.70472 .30902 L
.70492 .30902 L
.70511 .30902 L
.70521 .30902 L
.70532 .30902 L
.70538 .30902 L
.70544 .30902 L
.70549 .30902 L
.70554 .30902 L
.70564 .30902 L
.70573 .30902 L
.70583 .30902 L
.70592 .30902 L
.70602 .30902 L
.70613 .30902 L
.70632 .30902 L
.7065 .30902 L
.70669 .30902 L
.70704 .30902 L
.70862 .30902 L
.70932 .30902 L
Mistroke
.71008 .30902 L
.71049 .30902 L
.71088 .30902 L
.71124 .30902 L
.71145 .30902 L
.71164 .30902 L
.71185 .30902 L
.71197 .30902 L
.71209 .30902 L
.7122 .30902 L
.7123 .30902 L
.7124 .30902 L
.71246 .30902 L
.71251 .30902 L
.71262 .30902 L
.71271 .30902 L
.71281 .30902 L
.71287 .30902 L
.71292 .30902 L
.71312 .30902 L
.71331 .30902 L
.71369 .30902 L
.7141 .30902 L
.71493 .30902 L
.71642 .30902 L
.71684 .30902 L
.71724 .30902 L
.71761 .30902 L
.71799 .30902 L
.71819 .30902 L
.71841 .30902 L
.71861 .30902 L
.7188 .30902 L
.71891 .30902 L
.71902 .30902 L
.71912 .30902 L
.71922 .30902 L
.71928 .30902 L
.71934 .30902 L
.7194 .30902 L
.71946 .30902 L
.71956 .30902 L
.71962 .30902 L
.71968 .30902 L
.71978 .30902 L
.71987 .30902 L
.72006 .30902 L
.72046 .30902 L
.72119 .30902 L
.722 .30902 L
Mistroke
.72285 .30902 L
.72361 .30902 L
.72405 .30902 L
.72445 .30902 L
.72483 .30902 L
.72517 .30902 L
.72535 .30902 L
.72545 .30902 L
.72556 .30902 L
.72566 .30902 L
.72575 .30902 L
.72584 .30902 L
.72593 .30902 L
.72603 .30902 L
.72612 .30902 L
.72618 .30902 L
.72623 .30902 L
.72633 .30902 L
.72643 .30902 L
.72652 .30902 L
.72663 .30902 L
.72674 .30902 L
.72709 .30902 L
.72748 .30902 L
.72915 .30902 L
.72991 .30902 L
.7307 .30902 L
.73112 .30902 L
.73134 .30902 L
.73157 .30902 L
.73179 .30902 L
.73199 .30902 L
.73219 .30902 L
.73238 .30902 L
.73247 .30902 L
.73257 .30902 L
.73266 .30902 L
.73275 .30902 L
.73285 .30902 L
.7329 .30902 L
.73296 .30902 L
.73305 .30902 L
.73316 .30902 L
.73321 .30902 L
.73326 .30902 L
.73338 .30902 L
.73359 .30902 L
.73398 .30902 L
.7347 .30902 L
.73546 .30902 L
Mistroke
.73622 .30902 L
.73664 .30902 L
.73704 .30902 L
.73741 .30902 L
.73781 .30902 L
.73818 .30902 L
.73851 .30902 L
.73871 .30902 L
.73889 .30902 L
.73908 .30902 L
.73918 .30902 L
.73929 .30902 L
.73938 .30902 L
.73947 .30902 L
.73957 .30902 L
.73966 .30902 L
.73975 .30902 L
.73983 .30902 L
.73992 .30902 L
.74001 .30902 L
.74021 .30902 L
.74042 .30902 L
.7408 .30902 L
.74167 .30902 L
.74244 .30902 L
.74326 .30902 L
.74368 .30902 L
.74415 .30902 L
.74458 .30902 L
.74477 .30902 L
.74498 .30902 L
.74517 .30902 L
.74537 .30902 L
.74549 .30902 L
.74559 .30902 L
.74569 .30902 L
.74579 .30902 L
.74587 .30902 L
.74597 .30902 L
.74606 .30902 L
.74616 .30902 L
.74625 .30902 L
.74635 .30902 L
.74644 .30902 L
.74652 .30902 L
.74662 .30902 L
.74673 .30902 L
.74693 .30902 L
.74737 .30902 L
.74818 .30902 L
Mistroke
.74896 .30902 L
.74978 .30902 L
.75021 .30902 L
.75069 .30902 L
.75112 .30902 L
.75152 .30902 L
.75172 .30902 L
.75194 .30902 L
.75203 .30902 L
.75214 .30902 L
.75223 .30902 L
.75233 .30902 L
.75242 .30902 L
.75251 .30902 L
.75259 .30902 L
.75268 .30902 L
.75278 .30902 L
.75287 .30902 L
.75297 .30902 L
.75307 .30902 L
.75312 .30902 L
.75318 .30902 L
.75329 .30902 L
.75352 .30902 L
.75394 .30902 L
.75473 .30902 L
.75555 .30902 L
.75632 .30902 L
.75702 .30902 L
.75741 .30902 L
.75778 .30902 L
.75798 .30902 L
.75817 .30902 L
.75835 .30902 L
.75853 .30902 L
.75863 .30902 L
.75873 .30902 L
.75883 .30902 L
.75892 .30902 L
.75902 .30902 L
.75908 .30902 L
.75914 .30902 L
.75923 .30902 L
.75934 .30902 L
.75944 .30902 L
.75954 .30902 L
.7596 .30902 L
.75965 .30902 L
.75976 .30902 L
.75999 .30902 L
Mistroke
.76021 .30902 L
.76102 .30902 L
.76184 .30902 L
.76262 .30902 L
.76332 .30902 L
.76372 .30902 L
.76408 .30902 L
.76444 .30902 L
.76465 .30902 L
.76485 .30902 L
.76505 .30902 L
.76524 .30902 L
.76534 .30902 L
.76539 .30902 L
.76545 .30902 L
.76556 .30902 L
.76566 .30902 L
.76576 .30902 L
.76586 .30902 L
.76596 .30902 L
.76601 .30902 L
.76607 .30902 L
.76617 .30902 L
.76627 .30902 L
.76646 .30902 L
.76692 .30902 L
.76734 .30902 L
.76815 .30902 L
.76901 .30902 L
.76974 .30902 L
.77016 .30902 L
.77055 .30902 L
.77074 .30902 L
.77095 .30902 L
.77113 .30902 L
.77132 .30902 L
.77152 .30902 L
.77169 .30902 L
.77178 .30902 L
.77187 .30902 L
.77195 .30902 L
.77203 .30902 L
.77213 .30902 L
.77223 .30902 L
.77232 .30902 L
.7724 .30902 L
.77251 .30902 L
.77261 .30902 L
.77281 .30902 L
.77302 .30902 L
Mistroke
.77324 .30902 L
.77363 .30902 L
.77522 .30902 L
.77591 .30902 L
.77627 .30902 L
.77667 .30902 L
.77706 .30902 L
.77742 .30902 L
.77764 .30902 L
.77784 .30902 L
.77802 .30902 L
.77813 .30902 L
.77822 .30902 L
.77832 .30902 L
.77842 .30902 L
.77852 .30902 L
.77861 .30902 L
.77871 .30902 L
.77877 .30902 L
.77883 .30902 L
.77893 .30902 L
.77903 .30902 L
.77927 .30902 L
.77949 .30902 L
.77989 .30902 L
.78137 .30902 L
.78221 .30902 L
.78262 .30902 L
.783 .30902 L
.78339 .30902 L
.78377 .30902 L
.78398 .30902 L
.78417 .30902 L
.78438 .30902 L
.78448 .30902 L
.78454 .30902 L
.7846 .30902 L
.78466 .30902 L
.78471 .30902 L
.78477 .30902 L
.78482 .30902 L
.78493 .30902 L
.78502 .30902 L
.78508 .30902 L
.78513 .30902 L
.78519 .30902 L
.78525 .30902 L
.78547 .30902 L
.78568 .30902 L
.78586 .30902 L
Mistroke
.78629 .30902 L
.78779 .30902 L
.7882 .30902 L
.78863 .30902 L
.78901 .30902 L
.78942 .30902 L
.78963 .30902 L
.78983 .30902 L
.79004 .30902 L
.79023 .30902 L
.79043 .30902 L
.79055 .30902 L
.79066 .30902 L
.79077 .30902 L
.79088 .30902 L
.79095 .30902 L
.79101 .30902 L
.79106 .30902 L
.79112 .30902 L
.79122 .30902 L
.79131 .30902 L
.79142 .30902 L
.79152 .30902 L
.79161 .30902 L
.7917 .30902 L
.79189 .30902 L
.7923 .30902 L
.79274 .30902 L
.79434 .30902 L
.79478 .30902 L
.79525 .30902 L
.79564 .30902 L
.79587 .30902 L
.79608 .30902 L
.79628 .30902 L
.7965 .30902 L
.7967 .30902 L
.79688 .30902 L
.79698 .30902 L
.79708 .30902 L
.79719 .30902 L
.79725 .30902 L
.7973 .30902 L
.7974 .30902 L
.79746 .30902 L
.79752 .30902 L
.79757 .30902 L
.79763 .30902 L
.79769 .30902 L
.79774 .30902 L
Mistroke
.79783 .30902 L
.79793 .30902 L
.79813 .30902 L
.79849 .30902 L
.7993 .30902 L
.80017 .30902 L
.80099 .30902 L
.80135 .30902 L
.80173 .30902 L
.80215 .30902 L
.80235 .30902 L
.80254 .30902 L
.80271 .30902 L
.80291 .30902 L
.8031 .30902 L
.8032 .30902 L
.8033 .30902 L
.8034 .30902 L
.80348 .30902 L
.80356 .30902 L
.80365 .30902 L
.80374 .30902 L
.80384 .30902 L
.80393 .30902 L
.80402 .30902 L
.80413 .30902 L
.80423 .30902 L
.80443 .30902 L
.80487 .30902 L
.80566 .30902 L
.80649 .30902 L
.80727 .30902 L
.80761 .30902 L
.80797 .30902 L
.80836 .30902 L
.80873 .30902 L
.80891 .30902 L
.80912 .30902 L
.80921 .30902 L
.80931 .30902 L
.80939 .30902 L
.80948 .30902 L
.80958 .30902 L
.80969 .30902 L
.80978 .30902 L
.80988 .30902 L
.80993 .30902 L
.80998 .30902 L
.81008 .30902 L
.81014 .30902 L
Mistroke
.81019 .30902 L
.81031 .30902 L
.81053 .30902 L
.81073 .30902 L
.81112 .30902 L
.81199 .30902 L
.81277 .30902 L
.8132 .30902 L
.8136 .30902 L
.81397 .30902 L
.8143 .30902 L
.81468 .30902 L
.81488 .30902 L
.81508 .30902 L
.81529 .30902 L
.81539 .30902 L
.81548 .30902 L
.81557 .30902 L
.81566 .30902 L
.81575 .30902 L
.81585 .30902 L
.81591 .30902 L
.81596 .30902 L
.81606 .30902 L
.81616 .30902 L
.81622 .30902 L
.81628 .30902 L
.81637 .30902 L
.81647 .30902 L
.81667 .30902 L
.81704 .30902 L
.81744 .30902 L
.81815 .30902 L
.81896 .30902 L
.81939 .30902 L
.81985 .30902 L
.82028 .30902 L
.82068 .30902 L
.82087 .30902 L
.82108 .30902 L
.82128 .30902 L
.82146 .30902 L
.82156 .30902 L
.82165 .30902 L
.82174 .30902 L
.82183 .30902 L
.82194 .30902 L
.82199 .30902 L
.82204 .30902 L
.82214 .30902 L
Mistroke
.82224 .30902 L
.82233 .30902 L
.82242 .30902 L
.82259 .30902 L
.82277 .30902 L
.82297 .30902 L
.82463 .30902 L
.82543 .30902 L
.82583 .30902 L
.8262 .30902 L
.82662 .30902 L
.82684 .30902 L
.82708 .30902 L
.82728 .30902 L
.82746 .30902 L
.82756 .30902 L
.82766 .30902 L
.82778 .30902 L
.82788 .30902 L
.82798 .30902 L
.82804 .30902 L
.82809 .30902 L
.82818 .30902 L
.82828 .30902 L
.82838 .30902 L
.82846 .30902 L
.82855 .30902 L
.82865 .30902 L
.82887 .30902 L
.82908 .30902 L
.82947 .30902 L
.83095 .30902 L
.83173 .30902 L
.83212 .30902 L
.83255 .30902 L
.83292 .30902 L
.83312 .30902 L
.83331 .30902 L
.83348 .30902 L
.83366 .30902 L
.83375 .30902 L
.83385 .30902 L
.83394 .30902 L
.83403 .30902 L
.83412 .30902 L
.83421 .30902 L
.83431 .30902 L
.83442 .30902 L
.83447 .30902 L
.83453 .30902 L
Mistroke
.83463 .30902 L
.83483 .30902 L
.83521 .30902 L
.83557 .30902 L
.83643 .30902 L
.83724 .30902 L
.83796 .30902 L
.83836 .30902 L
.83874 .30902 L
.83892 .30902 L
.83912 .30902 L
.83934 .30902 L
.83954 .30902 L
.83965 .30902 L
.83977 .30902 L
.83982 .30902 L
.83988 .30902 L
.83998 .30902 L
.84008 .30902 L
.84018 .30902 L
.84028 .30902 L
.84034 .30902 L
.84039 .30902 L
.84049 .30902 L
.84059 .30902 L
.84077 .30902 L
.84118 .30902 L
.84191 .30902 L
.84272 .30902 L
.84316 .30902 L
.84358 .30902 L
.84398 .30902 L
.84434 .30902 L
.84475 .30902 L
.84498 .30902 L
.84519 .30902 L
.84537 .30902 L
.84546 .30902 L
.84556 .30902 L
.84572 .30902 L
.84581 .30902 L
.8459 .30902 L
.84599 .30902 L
.84609 .30902 L
.84615 .30902 L
.8462 .30902 L
.8463 .30902 L
.8464 .30902 L
.84649 .30902 L
.84667 .30902 L
Mistroke
.84704 .30902 L
.84745 .30902 L
.84828 .30902 L
.84904 .30902 L
.84976 .30902 L
.85015 .30902 L
.85036 .30902 L
.85057 .30902 L
.85078 .30902 L
.85096 .30902 L
.85114 .30902 L
.85132 .30902 L
.85142 .30902 L
.85154 .30902 L
.85164 .30902 L
.85174 .30902 L
.85179 .30902 L
.85185 .30902 L
.85195 .30902 L
.85201 .30902 L
.85206 .30902 L
.85212 .30902 L
.85218 .30902 L
.85228 .30902 L
.85238 .30902 L
.85257 .30902 L
.85279 .30902 L
.853 .30902 L
.8538 .30902 L
.85465 .30902 L
.85506 .30902 L
.85545 .30902 L
.8558 .30902 L
.85618 .30902 L
.85655 .30902 L
.85676 .30902 L
.85695 .30902 L
.85713 .30902 L
.85729 .30902 L
.85738 .30902 L
.85748 .30902 L
.85757 .30902 L
.85765 .30902 L
.85774 .30902 L
.85784 .30902 L
.85793 .30902 L
.85802 .30902 L
.85811 .30902 L
.85822 .30902 L
.85832 .30902 L
Mistroke
.85842 .30902 L
.85882 .30902 L
.85925 .30902 L
.86002 .30902 L
.86084 .30902 L
.86127 .30902 L
.86174 .30902 L
.86217 .30902 L
.86257 .30902 L
.86277 .30902 L
.86299 .30902 L
.86309 .30902 L
.86319 .30902 L
.86329 .30902 L
.86338 .30902 L
.86348 .30902 L
.86358 .30902 L
.86367 .30902 L
.86377 .30902 L
.86386 .30902 L
.86394 .30902 L
.86402 .30902 L
.86412 .30902 L
.86433 .30902 L
.86457 .30902 L
.86499 .30902 L
.86578 .30902 L
.8666 .30902 L
.86737 .30902 L
.86776 .30902 L
.86817 .30902 L
.8684 .30902 L
.86863 .30902 L
.86884 .30902 L
.86895 .30902 L
.86906 .30902 L
.86916 .30902 L
.86922 .30902 L
.86927 .30902 L
.86936 .30902 L
.86946 .30902 L
.86952 .30902 L
.86957 .30902 L
.86967 .30902 L
.86973 .30902 L
.86978 .30902 L
.8699 .30902 L
.87001 .30902 L
.87011 .30902 L
.87029 .30902 L
Mistroke
.8707 .30902 L
.87219 .30902 L
.87298 .30902 L
.87338 .30902 L
.8736 .30902 L
.87381 .30902 L
.87418 .30902 L
.87438 .30902 L
.87458 .30902 L
.87466 .30902 L
.87476 .30902 L
.87484 .30902 L
.87492 .30902 L
.87501 .30902 L
.8751 .30902 L
.8752 .30902 L
.87529 .30902 L
.8754 .30902 L
.87549 .30902 L
.87558 .30902 L
.87568 .30902 L
.87589 .30902 L
.87608 .30902 L
.87682 .30902 L
.87768 .30902 L
.87848 .30902 L
.87885 .30902 L
.87921 .30902 L
.8794 .30902 L
.87962 .30902 L
.87999 .30902 L
.88019 .30902 L
.88041 .30902 L
.88052 .30902 L
.88064 .30902 L
.88069 .30902 L
.88075 .30902 L
.88085 .30902 L
.88095 .30902 L
.88105 .30902 L
.88114 .30902 L
.88123 .30902 L
.88133 .30902 L
.88145 .30902 L
.88165 .30902 L
.88204 .30902 L
.88241 .30902 L
.88324 .30902 L
.88366 .30902 L
.88411 .30902 L
Mistroke
.88454 .30902 L
.88493 .30902 L
.88534 .30902 L
.88557 .30902 L
.88578 .30902 L
.88597 .30902 L
.88615 .30902 L
.88625 .30902 L
.88635 .30902 L
.8864 .30902 L
.88646 .30902 L
.88656 .30902 L
.88666 .30902 L
.88675 .30902 L
.88685 .30902 L
.8869 .30902 L
.88696 .30902 L
.88705 .30902 L
.88716 .30902 L
.88734 .30902 L
.88771 .30902 L
.88805 .30902 L
.88885 .30902 L
.8897 .30902 L
.89011 .30902 L
.8905 .30902 L
.89085 .30902 L
.89105 .30902 L
.89123 .30902 L
.89143 .30902 L
.8916 .30902 L
.8918 .30902 L
.8919 .30902 L
.89201 .30902 L
.89211 .30902 L
.89221 .30902 L
.8923 .30902 L
.8924 .30902 L
.89251 .30902 L
.89256 .30902 L
.89262 .30902 L
.89272 .30902 L
.89283 .30902 L
.893 .30902 L
.89319 .30902 L
.89353 .30902 L
.89429 .30902 L
.89511 .30902 L
.89555 .30902 L
.89601 .30902 L
Mistroke
.89641 .30902 L
.89662 .30902 L
.89685 .30902 L
.89706 .30902 L
.89725 .30902 L
.89734 .30902 L
.89744 .30902 L
.89753 .30902 L
.89762 .30902 L
.89773 .30902 L
.89783 .30902 L
.89793 .30902 L
.89799 .30902 L
.89805 .30902 L
.89815 .30902 L
.89824 .30902 L
.89829 .30902 L
.89835 .30902 L
.89845 .30902 L
.89864 .30902 L
.89884 .30902 L
.8992 .30902 L
.90001 .30902 L
.90089 .30902 L
.90128 .30902 L
.9017 .30902 L
.90206 .30902 L
.90226 .30902 L
.90245 .30902 L
.90263 .30902 L
.90282 .30902 L
.90292 .30902 L
.90302 .30902 L
.90312 .30902 L
.90321 .30902 L
.9033 .30902 L
.90337 .30902 L
.90346 .30902 L
.90355 .30902 L
.90364 .30902 L
.90374 .30902 L
.90383 .30902 L
.90392 .30902 L
.90402 .30902 L
.90413 .30902 L
.90433 .30902 L
.90477 .30902 L
.90557 .30902 L
.90635 .30902 L
.90706 .30902 L
Mistroke
.90745 .30902 L
.90783 .30902 L
.90802 .30902 L
.90822 .30902 L
.90844 .30902 L
.90855 .30902 L
.90864 .30902 L
.90882 .30902 L
.90891 .30902 L
.909 .30902 L
.90909 .30902 L
.90917 .30902 L
.90925 .30902 L
.90934 .30902 L
.90944 .30902 L
.9095 .30902 L
.90955 .30902 L
.90965 .30902 L
.90975 .30902 L
.91012 .30902 L
.91171 .30902 L
.9124 .30902 L
.9128 .30902 L
.91316 .30902 L
.91355 .30902 L
.91375 .30902 L
.91397 .30902 L
.91415 .30902 L
.91426 .30902 L
.91436 .30902 L
.91445 .30902 L
.91454 .30902 L
.91463 .30902 L
.91473 .30902 L
.91483 .30902 L
.91489 .30902 L
.91495 .30902 L
.91505 .30902 L
.91515 .30902 L
.91525 .30902 L
.91534 .30902 L
.91554 .30902 L
.91596 .30902 L
.91641 .30902 L
.91722 .30902 L
.91765 .30902 L
.9181 .30902 L
.91854 .30902 L
.91894 .30902 L
.91913 .30902 L
Mistroke
.91934 .30902 L
.91954 .30902 L
.91972 .30902 L
.91982 .30902 L
.91991 .30902 L
.92 .30902 L
.92009 .30902 L
.9202 .30902 L
.92025 .30902 L
.9203 .30902 L
.92041 .30902 L
.9205 .30902 L
.92059 .30902 L
.92068 .30902 L
.92085 .30902 L
.92103 .30902 L
.92123 .30902 L
.9221 .30902 L
.92289 .30902 L
.92328 .30902 L
.9237 .30902 L
.9241 .30902 L
.92446 .30902 L
.92467 .30902 L
.92485 .30902 L
.92506 .30902 L
.92528 .30902 L
.92539 .30902 L
.92545 .30902 L
.92551 .30902 L
.92557 .30902 L
.92563 .30902 L
.92573 .30902 L
.92584 .30902 L
.92589 .30902 L
.92595 .30902 L
.92604 .30902 L
.92615 .30902 L
.92625 .30902 L
.92635 .30902 L
.92655 .30902 L
.92691 .30902 L
.92773 .30902 L
.92849 .30902 L
.9292 .30902 L
.92957 .30902 L
.92996 .30902 L
.93018 .30902 L
.9304 .30902 L
.93059 .30902 L
Mistroke
.93079 .30902 L
.93091 .30902 L
.93096 .30902 L
.93102 .30902 L
.93111 .30902 L
.93122 .30902 L
.93132 .30902 L
.93138 .30902 L
.93144 .30902 L
.9315 .30902 L
.93155 .30902 L
.93167 .30902 L
.93177 .30902 L
.93187 .30902 L
.93209 .30902 L
.93248 .30902 L
.93326 .30902 L
.93411 .30902 L
.9345 .30902 L
.9349 .30902 L
.93525 .30902 L
.93563 .30902 L
.93584 .30902 L
.93603 .30902 L
.9362 .30902 L
.9363 .30902 L
.93639 .30902 L
.93649 .30902 L
.93658 .30902 L
.93668 .30902 L
.93674 .30902 L
.93679 .30902 L
.93689 .30902 L
.93695 .30902 L
.937 .30902 L
.9371 .30902 L
.9372 .30902 L
.93739 .30902 L
.9376 .30902 L
.93797 .30902 L
.93866 .30902 L
.93949 .30902 L
.9399 .30902 L
.94027 .30902 L
.94066 .30902 L
.94087 .30902 L
.94107 .30902 L
.94129 .30902 L
.9415 .30902 L
.9416 .30902 L
Mistroke
.94172 .30902 L
.94178 .30902 L
.94184 .30902 L
.9419 .30902 L
.94196 .30902 L
.94206 .30902 L
.94215 .30902 L
.94225 .30902 L
.94231 .30902 L
.94236 .30902 L
.94244 .30902 L
.94254 .30902 L
.94273 .30902 L
.94294 .30902 L
.94316 .30902 L
.94357 .30902 L
.94445 .30902 L
.94527 .30902 L
.94566 .30902 L
.94608 .30902 L
.9463 .30902 L
.9465 .30902 L
.94673 .30902 L
.94685 .30902 L
.94697 .30902 L
.94707 .30902 L
.94716 .30902 L
.94727 .30902 L
.94732 .30902 L
.94738 .30902 L
.94743 .30902 L
.94749 .30902 L
.94759 .30902 L
.94764 .30902 L
.94769 .30902 L
.94775 .30902 L
.94781 .30902 L
.94791 .30902 L
.94802 .30902 L
.94821 .30902 L
.94858 .30902 L
.94946 .30902 L
.95029 .30902 L
.95066 .30902 L
.95104 .30902 L
.95124 .30902 L
.95146 .30902 L
.95185 .30902 L
.95206 .30902 L
.95226 .30902 L
Mistroke
.95244 .30902 L
.95254 .30902 L
.95263 .30902 L
.95273 .30902 L
.95283 .30902 L
.95293 .30902 L
.95299 .30902 L
.95304 .30902 L
.95314 .30902 L
.9532 .30902 L
.95325 .30902 L
.95347 .30902 L
.95367 .30902 L
.95386 .30902 L
.95421 .30902 L
.95499 .30902 L
.95577 .30902 L
.95616 .30902 L
.9566 .30902 L
.95697 .30902 L
.95717 .30902 L
.95736 .30902 L
.95754 .30902 L
.95763 .30902 L
.95773 .30902 L
.95782 .30902 L
.95791 .30902 L
.958 .30902 L
.95808 .30902 L
.95817 .30902 L
.95827 .30902 L
.95837 .30902 L
.95845 .30902 L
.95855 .30902 L
.95866 .30902 L
.95886 .30902 L
.9593 .30902 L
.95969 .30902 L
.96041 .30902 L
.96118 .30902 L
.96158 .30902 L
.96195 .30902 L
.96213 .30902 L
.96233 .30902 L
.96251 .30902 L
.96268 .30902 L
.96279 .30902 L
.9629 .30902 L
.96299 .30902 L
.9631 .30902 L
Mistroke
.96321 .30902 L
.96327 .30902 L
.96333 .30902 L
.96338 .30902 L
.96344 .30902 L
.96354 .30902 L
.96364 .30902 L
.96373 .30902 L
.96384 .30902 L
.96389 .30902 L
.96395 .30902 L
.96415 .30902 L
.96434 .30902 L
.96582 .30902 L
.96622 .30902 L
.96666 .30902 L
.96707 .30902 L
.96744 .30902 L
.96765 .30902 L
.96784 .30902 L
.96805 .30902 L
.96815 .30902 L
.96827 .30902 L
.96837 .30902 L
.96846 .30902 L
.96855 .30902 L
.96864 .30902 L
.96874 .30902 L
.96883 .30902 L
.96894 .30902 L
.969 .30902 L
.96905 .30902 L
.9691 .30902 L
.96915 .30902 L
.96927 .30902 L
.96947 .30902 L
.96992 .30902 L
.97074 .30902 L
.97155 .30902 L
.97194 .30902 L
.97231 .30902 L
.97273 .30902 L
.97295 .30902 L
.97319 .30902 L
.97339 .30902 L
.97357 .30902 L
.97367 .30902 L
.97377 .30902 L
.97388 .30902 L
.97393 .30902 L
Mistroke
.97399 .30902 L
.97406 .30902 L
.97413 .30902 L
.9742 .30902 L
.97428 .30902 L
.97434 .30902 L
.97441 .30902 L
.97455 .30902 L
.97468 .30902 L
.97479 .30902 L
.97505 .30902 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{421.375, 260.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008>0001AB000`400?l00000o`00003ooooooooo
oooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo
003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooo
oooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool0
0?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooooooo
ool@ooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooo
ooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo0ol0003o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0
003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo
00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`
ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLoooo
o`00<?ooool3o`000?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?oo
ool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo0?ooooooRoooool0033ooooo00?o0000
ooooooooool0C_ooool00ol0003oooooooooo`3ooooooh_ooooo000`ooooo`03o`000?oooooooooo
04kooooo00?o0000ooooooooool0oooooon;ooooo`00<?ooool00ol0003oooooooooo`1>ooooo`03
o`000?oooooooooo0?ooooooRoooool0033ooooo00?o0000ooooooooool0C_ooool00ol0003ooooo
ooooo`3ooooooh_ooooo000`ooooo`03o`000?oooooooooo04kooooo0_l0003oooooohcooooo000`
ooooo`03o`000?oooooooooo04gooooo00?o0000ooooool00000oooooon<ooooo`00<?ooool00ol0
003oooooooooo`1=ooooo`03o`000?oooooo00000?ooooooS?ooool0033ooooo00?o0000oooooooo
ool0COooool00ol0003oooooo`00003oooooohcooooo000`ooooo`?o0000COooool00ol0003ooooo
o`00003oooooohcooooo000`ooooo`03o`000?oooooooooo04gooooo00?o0000ooooool00000oooo
oon<ooooo`00<?ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooo00000?ooooooS?ooool0
033ooooo00?o0000ooooooooool0COooool00ol0003oooooo`00003oooooohcooooo000`ooooo`03
o`000?oooooooooo04;ooooo00?o0000ooooooooool02?ooool00ol0003oooooo`00003oooooohco
oooo000`ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
o`00003oooooohcooooo000`ooooo`03o`000?oooooooooo04;ooooo0_l00009ooooo`03o`000?oo
oooo00000?ooooooS?ooool0013ooooo0_o^k^h3ooooo`;ok^k^6Oooool00ol0003oooooooooo`12
ooooo`;o00002Oooool00ol0003oooooo`00003oooooohcooooo000;ooooo`;o000000[o410@oooo
ooooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^0oooool4o`000008oa0@4?ooooooooooonk^
k_lb<S;o0000oc8b<_o^k^h:ooooo`03o`000?oooooooooo04;ooooo0_l00009ooooo`03o`000?oo
oooo00000?ooooooS?ooool000cooooo00?o0000ooooooooool00_ooool01Oo^k^koEEEEomgMgOmE
EEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00[ooooo
00?o0000ooooooooool0@_ooool2o`0000Wooooo00?o0000ooooool00000oooooon<ooooo`0000?o
ooooo`000?l000001?l00002ooooo`Go00001?ooool00ooMgMgo0000omgMg@07ooooo`03o`000?oo
oooooooo00;ooooo00Go410@oooooooooooooooooa0@400:ooooo`03o`000?oooooooooo047ooooo
00?o0000ooooool000002Oooool00ol0003oooooo`00003oooooohcooooo0009ooooo`04odA4A?oM
gMgoooooo`0000Cooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`00000:ooooo`03o`000?oooooooooo047ooooo00?o0000oooo
ool000002Oooool00ol0003oooooo`00003oooooohcooooo0009ooooo`04omgMgOmEEEGoooooo`00
00?ooooo00Ook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000000[ooooo1?l00010ooooo`03o`000?oooooo000000Wooooo
00?o0000ooooool00000oooooon<ooooo`002_ooool00omgMgOoc<c<o`000003ooooo`;ok^k^0ooo
ool2onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00[ooooo
00?o0000ooooooooool0@Oooool00ol0003oooooo`000009ooooo`03o`000?oooooo00000?oooooo
S?ooool000[ooooo00?ok^k^odA4A?l000003oooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL00oooool2o`0000Gooooo00?o0000ooooooooool0@Oooool00ol0003ooooo
o`000009ooooo`03o`000?oooooo00000?ooooooS?ooool000_ooooo00?oMgMgo`000?ooool03?oo
ool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_ooool01?l0003ooooo
ooooool00004ooooo`03o`000?oooooooooo047ooooo00?o0000ooooool000002Oooool00ol0003o
ooooo`00003oooooohcooooo000Xooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool0@Oooool00ol0003oooooo`000009ooooo`03o`000?oooooo00000?ooooooS?ooool002Sooooo
0ol00005ooooo`03o`000?oooooooooo047ooooo00?o0000ooooool000002Oooool00ol0003ooooo
o`00003oooooohcooooo000Yooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0@Ooo
ool00ol0003oooooo`000009ooooo`03o`000?oooooo00000?ooooooS?ooool002[ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`11ooooo`03o`000?oooooo000000Wooooo00?o0000
ooooool00000oooooon<ooooo`00<?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooo0000
00Wooooo00?o0000ooooool00000oooooon<ooooo`00<?ooool00ol0003oooooooooo`11ooooo`03
o`000?oooooo000000Wooooo00?o0000ooooool00000oooooon<ooooo`00<?ooool00ol0003ooooo
ooooo`11ooooo`03o`000?oooooo000000Wooooo00?o0000ooooool00000oooooon<ooooo`00<?oo
ool00ol0003oooooooooo`11ooooo`03o`000?oooooo000000Sooooo00Co0000oooooooooooo0000
2Oooool00ol0003oooooooooo`3ooooooh3ooooo000`ooooo`?o0000@Oooool00ol0003oooooo`00
0008ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0oooooon0ooooo`00<?oo
ool00ol0003oooooooooo`11ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo
00002Oooool00ol0003oooooooooo`3ooooooh3ooooo000`ooooo`03o`000?oooooooooo047ooooo
00Co0000oooooooooooo00001oooool01?l0003oooooooooool00009ooooo`;o0000oooooon1oooo
o`00<?ooool00ol0003oooooooooo`11ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooo
oooooooo00002Oooool2o`000?ooooooPOooool0033ooooo00?o0000ooooooooool0@Oooool01?l0
003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Wooooo0_l0003ooooooh7ooooo000`
ooooo`03o`000?oooooooooo047ooooo00Co0000oooooooooooo00001oooool01?l0003ooooooooo
ool00009ooooo`;o0000oooooon1ooooo`00<?ooool00ol0003oooooooooo`11ooooo`04o`000?oo
ooooooooo`0000Oooooo00Co0000oooooooooooo00002Oooool2o`000?ooooooPOooool0033ooooo
00?o0000ooooooooool0@Oooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`00
00Wooooo0_l0003ooooooh7ooooo000`ooooo`03o`000?oooooooooo047ooooo00Co0000oooooooo
oooo00001oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?ooooooPOooool0
033ooooo00?o0000ooooooooool0@Oooool01?l0003oooooooooool00007ooooo`04o`000?oooooo
ooooo`0000Sooooo00?o0000ooooool00000oooooon1ooooo`00<?ooool00ol0003oooooooooo`10
ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool00008ooooo`03o`00
0?oooooo00000?ooooooPOooool0033ooooo00?o0000ooooooooool0@?ooool01Ol0003ooooooooo
oooooooo000000Oooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003ooooooh7o
oooo000`ooooo`?o0000@?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooooooo
ooooooooo`000007ooooo`03o`000?oooooo00000?ooooooPOooool0033ooooo00?o0000oooooooo
ool0@?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007
ooooo`03o`000?oooooo00000?ooooooPOooool0033ooooo00?o0000ooooooooool0@?ooool01Ol0
003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oo
oooo00000?ooooooPOooool0033ooooo00?o0000ooooooooool0@?ooool01Ol0003ooooooooooooo
oooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?oooooo
POooool0033ooooo00?o0000ooooooooool0@?ooool01Ol0003ooooooooooooooooo000000Oooooo
00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?ooooooPOooool0033ooooo
00?o0000ooooooooool0@?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooooooo
ooooooooo`000007ooooo`03o`000?oooooo00000?ooooooPOooool0033ooooo00?o0000oooooooo
ool0@?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007
ooooo`03o`000?oooooo00000?ooooooPOooool0033ooooo00?o0000ooooooooool0@?ooool01Ol0
003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oo
oooo00000?ooooooPOooool0033ooooo00?o0000ooooooooool0@?ooool01Ol0003ooooooooooooo
oooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?oooooo
POooool0033ooooo00?o0000ooooooooool0@?ooool01Ol0003ooooooooooooooooo000000Oooooo
00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?ooooooPOooool0033ooooo
00?o0000ooooooooool0@?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooooooo
ooooooooo`000007ooooo`03o`000?oooooo00000?ooooooPOooool0033ooooo0ol00010ooooo`05
o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000
ooooool00000oooooon1ooooo`00<?ooool00ol0003oooooooooo`10ooooo`05o`000?oooooooooo
ooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooool00000oooo
oon1ooooo`00<?ooool00ol0003oooooooooo`10ooooo`05o`000?ooooooooooooooool000001ooo
ool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooool00000oooooon1ooooo`00<?oo
ool00ol0003oooooooooo`10ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooo
oooooooooooo000000Oooooo00?o0000ooooool00000oooooon1ooooo`00<?ooool00ol0003ooooo
ooooo`10ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo0000
00Oooooo00?o0000ooooool00000oooooon1ooooo`00<?ooool00ol0003oooooooooo`10ooooo`05
o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000
ooooool00000oooooon1ooooo`00<?ooool00ol0003oooooooooo`0eooooo`;o00002Oooool01Ol0
003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oo
oooo00000?ooooooPOooool0013ooooo0_o^k^h3ooooo`;ok^k^6Oooool00ol0003oooooooooo`0e
ooooo`;o00002Oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooooooooooooooo
o`000007ooooo`04o`000?ooooooooooo`000?ooooooP?ooool000Wooooo1Ol00002ooooo`07onk^
k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0
003o<S8bonk^kP[ooooo00?o0000ooooooooool0=Oooool2o`0000Wooooo00Go0000oooooooooooo
ooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool0003o
oooooh3ooooo0009ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01Oo^k^koEEEEomgMgOmE
EEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00[ooooo
00?o0000ooooooooool0=Oooool2o`0000Wooooo00Go0000ooooooooooooooooo`000007ooooo`05
o`000?ooooooooooooooool000001oooool01?l0003oooooooooool0003ooooooh3ooooo00000ooo
oooo0000o`000004o`0000?ooooo00?oV9RHob4Q8Oo^k^h01Oooool00ooMgMgo0000omgMg@07oooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400:ooooo`03o`000?oooooo
oooo03Gooooo0_l00009ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooo
oooooooo000000Oooooo00Co0000oooooooooooo0000oooooon0ooooo`002oooool00onHV9So8B4Q
onk^kP03ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000002_ooool00ol0003oooooooooo`0eooooo`;o00002Oooool01Ol0
003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?oo
ooooooooo`000?ooooooP?ooool000cooooo00_oMgMgofIVI_ooooooooooonk^k_mEEEGok^k^oooo
ooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
000:ooooo`Co0000=?ooool2o`0000Wooooo00Go0000ooooooooooooooooo`000007ooooo`05o`00
0?ooooooooooooooool000001oooool01?l0003oooooooooool0003ooooooh3ooooo000=ooooo`03
o`000?oooooooooo00;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@413o
oooooooooooooooo410@00[ooooo00?o0000ooooooooool0=Oooool2o`0000Wooooo00Go0000oooo
ooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool01?l0003ooooooooo
ool0003ooooooh3ooooo0009ooooo`05o`000?nj^[[ooooooiRHV?l@41003_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool2o`0000Gooooo00?o0000oooooooo
ool0=?ooool00ol0003oooooo`000009ooooo`05o`000?ooooooooooooooool000001oooool01Ol0
003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000oooooon0ooooo`002Oooool0
1OnHV9So410@o`000?lQ8B7oc<c<00cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`0dooooo`04
o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooo
ooooooooool000001oooool01?l0003oooooooooool0003ooooooh3ooooo000Xooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool0=?ooool01?l0003oooooooooool00008ooooo`05
o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000
oooooooooooo0000oooooon0ooooo`00:?ooool3o`0000Gooooo00?o0000ooooooooool0=?ooool0
1?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooo
oooooooooooo000000Oooooo00Co0000oooooooooooo0000oooooon0ooooo`00:Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo03Cooooo00Co0000oooooooooooo00002?ooool01Ol0
003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?oo
ooooooooo`0000Oooooo0_l0003oooooogOooooo000Zooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0=?ooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool0
00001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo00001oooool2
o`000?ooooooMoooool0033ooooo00?o0000ooooooooool0=?ooool01?l0003oooooooooool00008
ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo
00Co0000oooooooooooo00001oooool2o`000?ooooooMoooool0033ooooo00?o0000ooooooooool0
=?ooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool000001oooool01Ol0
003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo00001oooool2o`000?ooooooMooo
ool0033ooooo00?o0000ooooooooool0=?ooool01?l0003oooooooooool00008ooooo`05o`000?oo
ooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooo
oooo00001oooool2o`000?ooooooMoooool0033ooooo00?o0000ooooooooool0=?ooool01?l0003o
ooooooooool00008ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooo
oooo000000Oooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00003oooooogKooooo
000`ooooo`?o0000=?ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000oooooooo
ooooooooo`000007ooooo`03o`000?oooooo00000?ooooooM_ooool0033ooooo00?o0000oooooooo
ool0=?ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01Oooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`00
0007ooooo`03o`000?oooooo00000?ooooooM_ooool0033ooooo00?o0000ooooooooool0=?ooool0
1?l0003oooooooooool00007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooooooo
o`000007ooooo`03o`000?oooooo00000?ooooooM_ooool0033ooooo00?o0000ooooooooool0=?oo
ool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooo
ooooo`000007ooooo`03o`000?oooooo00000?ooooooM_ooool0033ooooo00?o0000ooooooooool0
=?ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooo
ooooooooo`000007ooooo`03o`000?oooooo00000?ooooooM_ooool0033ooooo00?o0000oooooooo
ool0=?ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000oooo
ooooooooooooo`000007ooooo`03o`000?oooooo00000?ooooooM_ooool0033ooooo00?o0000oooo
ooooool0=?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool0
1Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooool00000oooooomfooooo`00<?ooool0
0ol0003oooooooooo`0cooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooo`00
003oooooogKooooo000`ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00
0006ooooo`04o`000?ooooooooooo`000?ooooooM_ooool0033ooooo00?o0000ooooooooool0<ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo0000
oooooomfooooo`00<?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool01?l0003oooooooooool0003oooooogKooooo000`ooooo`03o`000?oo
oooooooo03?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`04o`000?oo
ooooooooo`000?ooooooM_ooool0033ooooo0ol0000cooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool01?l0003oooooooooool0003oooooogKooooo000`ooooo`03o`000?oo
oooooooo03?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`04o`000?oo
ooooooooo`000?ooooooM_ooool0033ooooo00?o0000ooooooooool0<oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo0000oooooomfooooo`00<?oo
ool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooo
ool01?l0003oooooooooool0003oooooogKooooo000`ooooo`03o`000?oooooooooo03?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`000?oooooo
M_ooool0033ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ok^k^00?oooooo`000?ooool00_o^k^h2ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool01Ol0003ooooooooooooooooo000004Gooooo0_o^k^h3ooooo`;ok^k^
H?ooool2onk^kP?ooooo0_o^k^i>ooooo`;ok^k^0oooool2onk^kVcooooo000`ooooo`03o`000?oo
oooooooo03?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00?ooooo00Co0000ooooooooooooA4A40ol000002OoMgMgoooooonk^k_mEEEGok^k^o`00
0?o^k^koEEEEonk^kP02ooooo`Ko00000_ooool01Oo^k^ko<S8bo`000?l0003ok^k^00;ooooo00?o
0000ooooooooool0?Oooool4o`000009oa0@4?ooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^
00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^>oooool4o`000003oa0@
4?oooooooooo00;ooooo0_lQ8B45ooooo`0=odA4A?l0003o0000oc8b<_oMgMgoooooonk^k_mEEEGo
k^k^ooooooo^k^koEEEEonk^kP03ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8b
onk^kSSooooo1Ol00002ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co0000
00So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kUgooooo000`ooooo`03o`000?oooooooooo
03;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool02Ol0003o<S8booooooooooook^k^oeEEEOl0003oEEEE
onk^kP03ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool01OmgMgOoV9RHooooool0003o
MgMg00;ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`02ooooo`05onk^k_mEEEGo
gMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
?Oooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool02OmgMgOo<S8booooooooooook^k^oeEE
EOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0hooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Ko
oooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg05gooooo000`ooooo`03
o`000?oooooooooo03;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool2o`0000?ooooo00?ogMgMo`000?oM
gMd01?ooool01_l0003oooooooooool0003oooooo`0000;ooooo00Go410@oooooooooooo0000oa0@
4002ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0=oooool00ol0003ooooooooo
o`03ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@03gooooo00?o0000ooooooooool03oooool01ol0003ooooooooooooooooogMgMo`00
0?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100>Oooool0
0onHV9So8B4Qonk^kP05ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@05gooooo000`ooooo`03o`000?oooooooooo02Sooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`09o`000?lb<S;oooooooooooo^k^koEEEE
o`000?mEEEGok^k^00?ooooo00Ko0000oooooooooooo0000ooooool00002ooooo`03o`000?oooooo
oooo00;o00000_ooool00ol0003oooooooooo`04ooooo`;o0000>Oooool00ol0003oooooooooo`02
ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool00000?Oooool00ol0003oooooooooo`0>ooooo`09ogMgMolb<S;oooooooooooo^
k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000003[ooooo00?oV9RHob4Q8Oo^k^h00oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000005gooooo000`ooooo`03o`00
0?oooooooooo02Oooooo0ol00008ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooo`000?lQ8B400_l000002Oo<c<co
ooooonk^k_mEEEGok^k^o`000?o^k^koEEEEonk^kP02ooooo`06o`000?ooooooooooo`000?oooooo
00000_ooool00ol0003oooooooooo`02o`0000;ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooo`00000hooooo`0;o`000?ooooooooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h0
1Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000?Oooool00ol0003o
ooooooooo`0;ooooo`0=o`000?lQ8B7o0000oc8b<_o<c<coooooonk^k_mEEEGok^k^ooooooo^k^ko
EEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000koooo
o`0;ogMgMomVIVKoooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool00000GOooool0033ooooo00?o0000oooooooo
ool09oooool00ol0003oooooo`000008ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooo
ooooool00_o^k^h00ooooooo0000ooooo`02onk^kP;ooooo00Ko0000oooooooooooo0000ooooool0
0002ooooo`05oa0@4?ooooooooooo`000?l@41000_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooo000003Sooooo00Co0000oooooooooooooooo0_o^k^h3ooooo`;ok^k^1Oooool00ol0003o
ooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100?Oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00?ooooo0_o^k^h3ooooo`;ok^k^1Oooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@4100??ooool00ol0003oooooooooo`02onk^kP?ooooo0_o^k^h5
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@401Mooooo`00<?ooool3
o`0002Kooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool01_l0003oooooooooool0003oooooo`00
00;ooooo00GoMgMgoiRHV?oooooo0000ogMgM`02ooooo`03o`000?oooooooooo00?ooooo0_l00000
0ooooooo0000ooooo`0gooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo0_l0000cooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2?ooool2o`0002kooooo00Go0000okZj^_ooooooV9RHoa0@400>ooooo`03o`000?oooooooooo00;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`;o0000Doooool0033ooooo00?o0000oooooooo
ool09_ooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Co00001Oooool00ol0
003oooooooooo`03ooooo`06o`000?mEEEGoIVIVo`000?oooooo00000_ooool01Oo^k^ko<S8bo`00
0?l0003ok^k^00;ooooo00?o0000ooooooooool00oooool2o`000003ooooool0003ooooo03Gooooo
00?oEEEEofIVI_l000003Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01oooool01?l0003oooooooooool0000`ooooo`03oeEEEOmVIVKo000000gooooo1?l0000<oooo
o`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP07ooooo`04o`000?oooooo
ooooo`0002gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00<ooooo`03oeEEEOmVIVKo000000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP07ooooo`04o`000?ooooooooooo`0005;ooooo000`ooooo`03
o`000?oooooooooo02Kooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00Co0000oooooooooooooooo1?l00003ooooo`03o`000?oooooo
000005Cooooo1?l000001Ooooooo0000oooooooooooo000005kooooo1?l000001Ooooooo0000oooo
oooooooo000004cooooo1?l000001Ooooooo0000oooooooooooo000005;ooooo000`ooooo`03o`00
0?oooooooooo02Gooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooo
ool00000FOooool3o`0006Cooooo0ol0001Booooo`?o0000Doooool0033ooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001?ooool00ol0
003oooooo`000002o`0005[ooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`1Boooo
o`03o`000?oooooooooo05;ooooo000`ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool01Ol0003ooooooooooooooooo000000Cooooo1?l000000ooooooo0000ooooo`1Ioooo
o`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`1Aoooo
o`00<?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000oooooom[oooo
o`00<?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool2o`00
0?oooooo:Oooool00omgMgOoIVIVooooo`0]ooooo`03ofIVI_mgMgOooooo00Oooooo000`ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`?o0000oooooolWoooo
o`03omgMgOl@413ok^k^02kooooo00?ok^k^oa0@4?oMgMd01oooool0033ooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_ooool01Ol0003ooooooooooooooooo000000Gooooo00Co0000oooooooooooo0000oooooolE
ooooo`;o00000_ooool2o`0000cooooo00?oEEEEoiRHV?ooool00_l00002ooooo`07o`000?oooooo
ooooo`000?l@413ok^k^oeEEE@02o`000003odA4A?nj^[[ooooo00;ooooo00GoV9RHo`000?l0003o
A4A4okZj^P02ooooo`08onk^k_mEEEGo0000o`000?m4A4Co^[Zjooooool@4105o`0000?ooooo00So
410@oc8b<_l0003o0000oa0@4?nYZJWoQhN7ofIVIPOooooo000`ooooo`03o`000?oooooooooo01Ko
oooo1_l00008ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000001Oooool01?l0003oooooooooool00006
ooooo`;o0000ooooool=ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM3?ooool01Ol0003ooooo
oooooooooooo000000;ooooo00_o0000oooooooooooo0000oooooomEEEGoMgMgooooooo^k^koMgMg
oa0@4003ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000_ooool01_mEEEGoMgMgooooooo^k^koMgMg
oa0@40?ooooo00?o0000ooooooooool01?ooool02?l0003oZJVYoooooooooooo^[Zjo`000?o^k^ko
00001oooool00?oo0000]?l0000?ooooo`04omgMgOl0003o410@olc<c0gooooo00Go<S8boooooooo
ooooooooo`000002ooooo`06o`000?ooooooooooo`000?oooooo00002?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool01onj^[[oQhN7ofIV
I_mVIVKo410@ooooool000001oooool000[ooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo00oooooo1Ol00008ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`00
00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00;ooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000002
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooooooo00?o00003?ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Gooooo`04onk^
k_lQ8B7o410@onk^kPgooooo00Go<S8booooooooooooooooo`000002ooooo`05o`000?oooooooooo
o`000?ooool01_l00003ooooo`03o`000?oooooooooo00Cooooo1_l00003ooooo`03o`000?oooooo
oooo00Cooooo00So<S8bob4Q8OmgMgOoMgMgohN7Qoo^k^koooooo`0000Oooooo000:ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`;o00001?ooool00ol0
003oooooooooo`03ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0
0003ooooo`03o`000?oooooooooo00?ooooo0ol00003ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool05oooool01?lQ8B7oMgMgogMgMolb<S8=ooooo`05o`000?o^k^koooooooooool0
00000_o<c<`02ol0003oZJVYomgMgOlQ8B7ooooooeEEEOn7QhOok^k^oooooon7QhOo<S8b00?ooooo
00?o0000ooooooooool01?ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<P?ooooo00?o0000oc8b
<_oMgMd01?ooool02?l0003o^[Zjooooooo^k^koMgMgo`000?o^k^ko00001oooool0033ooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`;o00001?ooool00ol0003ooooooooo
o`03ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0003ooooooooooooooooo000004?o
oooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo01Ko
oooo0_l00002ooooo`;o00003?ooool03_mEEEGoMgMgooooool@413o0000ob4Q8Ol0003oMgMgoa0@
4?l0003oZJVYooooooo^k^koEEEE0_l000001?m4A4Cok^k^ooooool@4105o`0000?ooooo00Kok^k^
oeEEEOl0003o0000odA4A?o^k^h2ooooo`;o000000CoZJVYob4Q8Ol0003o8B4Q0_ooool02?nYZJWo
8B4Qo`000?l0003o<S8bo`000?mgMgOoEEEE1oooool0033ooooo00?o0000ooooooooool07_ooool2
o`0000;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooo
ooooooooool000001Oooool01Ol0003ooooooooooooooooo00000?oooooo:oooool00ooMgMgo410@
onk^kP0Booooo`03o`000?oooooooooo01Wooooo00?ok^k^oa0@4?oMgMd01oooool0033ooooo00?o
0000ooooooooool07oooool4o`0000Sooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooo
oooooooo000000Gooooo00Go0000ooooooooooooooooo`00003oooooobcooooo00?oMgMgofIVI_oo
ool04Oooool00ol0003oooooooooo`0Iooooo`03ofIVI_mgMgOooooo00Oooooo000`ooooo`03o`00
0?oooooooooo023ooooo0_l00009ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooo
ooooo`000005ooooo`04o`000?ooooooooooo`000?ooooooIoooool0033ooooo00?o0000oooooooo
ool0:oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001_ooool00ol0
003oooooo`00003oooooofOooooo000`ooooo`03o`000?oooooooooo02_ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool01Ol0003ooooooooooooooooo000000Kooooo0_l0003oooooofSooooo000`ooooo`03
o`000?oooooooooo02_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo0000
0?ooooooL?ooool0033ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05
o`000?ooooooooooooooool00000oooooom`ooooo`00<?ooool00ol0003oooooooooo`0/ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00003oooooog3ooooo000`ooooo`?o
0000;?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool00000oooooom`oooo
o`00<?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooo
ooooooooo`00003oooooog3ooooo000`ooooo`03o`000?oooooooooo02cooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool01Ol0003ooooooooooooooooo00000?ooooooL?ooool0033ooooo00?o0000oooooooo
ool0;?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool00000oooooom`oooo
o`00<?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooo
oooo0000oooooomaooooo`00<?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooool00000oooooomaooooo`00<?ooool00ol0003oooooooooo`0]ooooo`05o`00
0?ooooooooooooooool000001oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooool00000oooooomaooooo`00<?ooool00ol0003oooooooooo`0]ooooo`04o`00
0?ooooooooooo`0000Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooo00000?ooooooLOooool0033ooooo00?o0000ooooooooool0;Oooool01?l0003ooooo
ooooool00008ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooo`00003oooooog7ooooo000`ooooo`03o`000?oooooooooo02gooooo00Co0000oooooooooooo
00002?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooool0
0000oooooomaooooo`00<?ooool00ol0003oooooooooo`0]ooooo`04o`000?ooooooooooo`0000So
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo00000?oo
ooooLOooool0033ooooo00?o0000ooooooooool0;Oooool01?l0003oooooooooool00008ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooo`00003oooooog7o
oooo000`ooooo`?o0000;Oooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooooooo
ool000001_ooool00ol0003oooooo`00003oooooog7ooooo000`ooooo`03o`000?oooooooooo02go
oooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo0_l0003o
ooooog;ooooo000`ooooo`03o`000?oooooooooo02gooooo00Co0000oooooooooooo00002?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
1?l0003oooooooooool00008ooooo`03o`000?oooooooooo0?ooooooL?ooool0033ooooo00?o0000
ooooooooool0;_ooool00ol0003oooooo`000008ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`000?ooooooNooo
ool0033ooooo00?o0000ooooooooool0;_ooool00ol0003oooooo`000008ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`04o`000?oooooo
ooooo`000?ooooooNoooool0033ooooo00?o0000ooooooooool0;_ooool2o`0000Wooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Co0000
oooooooooooo0000oooooomkooooo`00<?ooool00ol0003oooooooooo`0^ooooo`;o00002Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
1?l0003oooooooooool0003oooooog_ooooo000`ooooo`03o`000?oooooooooo03Wooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Co0000
oooooooooooo0000oooooomkooooo`00<?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`04o`000?oooooo
ooooo`000?ooooooNoooool0033ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0
003oooooog_ooooo000`ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo0000oooo
oomkooooo`00<?ooool00ol0003oooooooooo`0jooooo`05o`000?ooooooooooooooool000001ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`000?ooooooNoooool0033ooooo0ol0
000jooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`04o`00
0?ooooooooooo`000?ooooooNoooool0033ooooo00?o0000ooooooooool0>_ooool01Ol0003ooooo
oooooooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0003ooooo
og_ooooo000`ooooo`03o`000?oooooooooo03[ooooo00Go0000ooooooooooooooooo`000007oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo0000oooooomkooooo`00<?ooool00ol0
003oooooooooo`0jooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`04o`000?ooooooooooo`000?ooooooNoooool0033ooooo00?o0000ooooooooool0>_ooool0
1Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0003oooooog_o
oooo000`ooooo`03o`000?oooooooooo03[ooooo00Go0000ooooooooooooooooo`000007ooooo`05
o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00Co0000oooooooooooo0000oooooomkooooo`003oooool2onk^kP?ooooo0_o^k^hJoooo
o`03o`000?oooooooooo03[ooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Co
0000oooooooooooo0000oooooomkooooo`002?ooool5o`0000;ooooo00Ook^k^oeEEEOo^k^kooooo
onk^k_mEEEGok^k^00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^2ooo
ool00ol0003oooooooooo`0jooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`04
o`000?ooooooooooo`000?ooooooNoooool000Sooooo00GoV9RHob4Q8Oo^k^koooooodA4A003oooo
o`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool00ol0003oooooooooo`0jooooo`05o`000?ooooooooooooooool00000
1oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`04o`000?ooooooooooo`000?ooooooNoooool000Wooooo00?oV9RHob4Q8Oo^
k^h01Oooool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooo
oooooooooa0@400;ooooo`03o`000?oooooooooo03[ooooo00Go0000ooooooooooooooooo`000007
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00Co0000oooooooooooo0000oooooomkooooo`002_ooool00onHV9So8B4Qonk^
kP03ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000002oooool00ol0003oooooooooo`0jooooo`05o`000?oooooooooooooo
ool000001oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`000?ooooooNoooool000_ooooo00_oMgMg
ofIVI_ooooooooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`00000;ooooo`Co0000>Oooool01Ol0003ooooooooooooo
oooo000000Oooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool01?l0003oooooooooool0003oooooog_ooooo000<ooooo`03o`00
0?oooooooooo00;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@413ooooo
oooooooooooo410@00_ooooo00?o0000ooooooooool0>_ooool01Ol0003ooooooooooooooooo0000
00Oooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool01?l0003oooooooooool0003oooooog_ooooo0008ooooo`05o`000?nj^[[o
oooooiRHV?l@41003_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2oooool00ol0003oooooooooo`0jooooo`05o`000?ooooooooooooooool000001oooool01Ol0003o
oooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04oooo
o`04o`000?ooooooooooo`000?ooooooNoooool000Sooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00<
ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`;o00001_oo
ool00ol0003oooooooooo`0jooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooo
oooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo0000
0?ooooooO?ooool002Oooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`0joooo
o`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooo00000?ooooooO?ooool002Oooooo00Co
0000oooooooooooo00001Oooool00ol0003oooooooooo`0jooooo`05o`000?ooooooooooooooool0
00001oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007
ooooo`;o0000oooooomlooooo`009oooool3o`0000Kooooo00?o0000ooooooooool0>_ooool01?l0
003oooooooooool00008ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooo
oooooooo000000Oooooo0_l0003oooooogcooooo000Xooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0>_ooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool0
00001oooool01Ol0003ooooooooooooooooo000000Oooooo0_l0003oooooogcooooo000Yooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0>_ooool01?l0003oooooooooool00008oooo
o`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo0_l0
003oooooogcooooo000`ooooo`03o`000?oooooooooo03[ooooo00Co0000oooooooooooo00002?oo
ool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`;o
0000oooooomlooooo`00<?ooool00ol0003oooooooooo`0jooooo`04o`000?ooooooooooo`0000So
oooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool2
o`000?ooooooO?ooool0033ooooo00?o0000ooooooooool0>_ooool01?l0003oooooooooool00008
ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo
0_l0003oooooogcooooo000`ooooo`?o0000>oooool00ol0003oooooo`000008ooooo`05o`000?oo
ooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo0_l0003oooooogco
oooo000`ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooool000002?ooool01Ol0003ooooo
oooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`;o0000oooooomloooo
o`00<?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooo000000Sooooo00Go0000oooooooo
ooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool2o`000?ooooooO?ooool0
033ooooo00?o0000ooooooooool0>oooool00ol0003oooooo`000008ooooo`05o`000?oooooooooo
ooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo0_l0003oooooogcooooo000`
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooool000002?ooool01Ol0003ooooooooooooo
oooo000000Oooooo00Go0000ooooooooooooooooo`00003oooooohGooooo000`ooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooool000002?ooool01Ol0003ooooooooooooooooo000000Oooooo
00Go0000ooooooooooooooooo`00003oooooohGooooo000`ooooo`03o`000?oooooooooo03_ooooo
00?o0000ooooool000002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooooooo
ooooooooo`00003oooooohGooooo000`ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooool0
00002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`00003o
ooooohGooooo000`ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooool000002?ooool01Ol0
003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`00003oooooohGooooo000`
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooool000002?ooool01Ol0003ooooooooooooo
oooo000000Oooooo00Co0000oooooooooooo0000oooooon6ooooo`00<?ooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooo000000Sooooo00Go0000ooooooooooooooooo`000007ooooo`04o`00
0?ooooooooooo`000?ooooooQ_ooool0033ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
o`000008ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool0003ooooo
ohKooooo000`ooooo`?o0000>oooool00ol0003oooooo`000008ooooo`05o`000?oooooooooooooo
ool000001oooool01?l0003oooooooooool0003oooooohKooooo000`ooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooool000002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000
oooooooooooo0000oooooon6ooooo`00<?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
000000Sooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`000?oooooo
Q_ooool0033ooooo00?o0000ooooooooool0>oooool00ol0003oooooo`000009ooooo`04o`000?oo
ooooooooo`0000Oooooo00Co0000oooooooooooo0000oooooon6ooooo`00<?ooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooo000000Wooooo00Co0000oooooooooooo00001oooool01?l0003o
ooooooooool0003oooooohKooooo000`ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooool0
00002Oooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`000?ooooooQ_ooool0
033ooooo00?o0000ooooooooool0>oooool2o`0000[ooooo00Co0000oooooooooooo00001oooool0
1?l0003oooooooooool0003oooooohKooooo000`ooooo`03o`000?oooooooooo03cooooo00?o0000
ooooooooool02?ooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`000?oooooo
Q_ooool0033ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`08ooooo`04o`000?oo
ooooooooo`0000Oooooo00Co0000oooooooooooo0000oooooon6ooooo`00<?ooool00ol0003ooooo
ooooo`0looooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooo00001oooool01?l0003o
ooooooooool0003oooooohKooooo000`ooooo`03o`000?oooooooooo04Oooooo00Co0000oooooooo
oooo00001oooool01?l0003oooooooooool0003oooooohKooooo000`ooooo`03o`000?oooooooooo
04Oooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool0003oooooohKooooo000`
ooooo`?o0000Aoooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`000?oooooo
Q_ooool0033ooooo00?o0000ooooooooool0Aoooool01?l0003oooooooooool00007ooooo`04o`00
0?ooooooooooo`000?ooooooQ_ooool0033ooooo00?o0000ooooooooool0Aoooool01?l0003ooooo
ooooool00008ooooo`03o`000?oooooo00000?ooooooQ_ooool0033ooooo00?o0000ooooooooool0
Aoooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?ooooooQ_ooool0033ooooo
00?o0000ooooooooool0Aoooool00ol0003oooooo`000009ooooo`03o`000?oooooo00000?oooooo
Q_ooool0033ooooo00?o0000ooooooooool0Aoooool00ol0003oooooo`000009ooooo`;o0000oooo
oon7ooooo`003oooool2onk^kP?ooooo0_o^k^hJooooo`03o`000?oooooooooo04Oooooo00?o0000
ooooool000002Oooool2o`000?ooooooQoooool000[ooooo0_l000002_l@413oooooooooooo^k^ko
EEEEonk^k_ooooook^k^oeEEEOo^k^h3ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o
<S8bonk^kP_ooooo00?o0000ooooooooool0Aoooool00ol0003oooooo`000009ooooo`;o0000oooo
oon7ooooo`002oooool00ol0003oooooooooo`02ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_oo
ool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ol0003ooooo
ooooo`17ooooo`03o`000?oooooo000000Wooooo0_l0003oooooohOooooo0008ooooo`Go00001?oo
ool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooo
oa0@400;ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooool000002Oooool2o`000?oooooo
Qoooool000Sooooo00CoA4A4omgMgOoooooo00001?ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Ko
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000_ooooo00?o0000oooo
ooooool0Aoooool00ol0003oooooo`000009ooooo`;o0000oooooon7ooooo`002?ooool01?oMgMgo
EEEEooooool00003ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000;ooooo`Co0000A_ooool00ol0003ooooo
o`000009ooooo`;o0000oooooon7ooooo`002Oooool00omgMgOoc<c<o`000003ooooo`;ok^k^0ooo
ool2onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00_ooooo
00?o0000ooooooooool0Aoooool00ol0003oooooo`000009ooooo`;o0000oooooon7ooooo`002Ooo
ool00oo^k^koA4A4o`00000?ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooool000002Oooool2o`000?oooooo
Qoooool000[ooooo00?oMgMgo`000?ooool03?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00oooool2o`0000Kooooo00?o0000ooooooooool0Aoooool00ol0003ooooo
o`000009ooooo`;o0000oooooon7ooooo`009oooool01?l0003oooooooooool00005ooooo`03o`00
0?oooooooooo04Oooooo00?o0000ooooool000002Oooool2o`000?ooooooQoooool002Oooooo00Co
0000oooooooooooo00001Oooool00ol0003oooooooooo`17ooooo`03o`000?oooooo000000Wooooo
0_l0003oooooohOooooo000Wooooo`?o00001_ooool00ol0003oooooooooo`17ooooo`03o`000?oo
oooo000000Wooooo0_l0003oooooohOooooo000Xooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0Aoooool00ol0003oooooo`000009ooooo`;o0000oooooon7ooooo`00:Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooool000002Oooool2o`00
0?ooooooQoooool0033ooooo00?o0000ooooooooool0Aoooool00ol0003oooooo`000009ooooo`;o
0000oooooon7ooooo`00<?ooool00ol0003oooooooooo`17ooooo`03o`000?oooooo000000[ooooo
00?o0000ooooooooool0oooooon5ooooo`00<?ooool00ol0003oooooooooo`17ooooo`03o`000?oo
oooo00000?ooooooT_ooool0033ooooo0ol00017ooooo`03o`000?oooooo00000?ooooooT_ooool0
033ooooo00?o0000ooooooooool0Aoooool00ol0003oooooo`00003ooooooi;ooooo000`ooooo`03
o`000?oooooooooo04Oooooo00?o0000ooooool00000oooooonBooooo`00<?ooool00ol0003ooooo
ooooo`17ooooo`03o`000?oooooo00000?ooooooT_ooool0033ooooo00?o0000ooooooooool0B?oo
ool2o`000?ooooooT_ooool0033ooooo00?o0000ooooooooool0B?ooool2o`000?ooooooT_ooool0
033ooooo00?o0000ooooooooool0B?ooool2o`000?ooooooT_ooool0033ooooo00?o0000oooooooo
ool0B?ooool2o`000?ooooooT_ooool0033ooooo00?o0000ooooooooool0B?ooool00ol0003ooooo
ooooo`3ooooooi7ooooo000`ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0oooo
oonAooooo`00<?ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo0?ooooooTOooool0
033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool3o`000?oooooog?ooool0033ooooo
00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`
ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLoooo
o`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooo
g?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`?o0000oooo
oooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooo
ooooo`3oooooomcooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooo
oa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003o
oooooooooooo4?ooool00?ooooooooooool@ooooo`00X?ooool2o`0000Cooooo00?o^[Zjoc8b<_oo
ool01?ooool2o`0000Kooooo00?o0000okZj^_ooool0oooooomGooooo`00X?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool2oc8b<_oooooo
F?ooool008gooooo0ol00002ooooo`06oc8b<_l@413oooooooooooo^k^koEEEE0_l000000om4A4Co
^[Zjooooo`03ooooo`03o`000?oooooooooo00;ooooo00GoV9RHoa0@4?l0003o0000ojVYZ@04oooo
o`03o`000?oooooooooo00Cooooo00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co
^[Zj00Wooooo00GoV9RHoa0@4?l0003o<S8bolc<c005ooooo`;o8B4Q1?ooool02oo^k^ko<S8bo`00
0?l@413oc<c<ooooooo<c<cok^k^ooooooo^k^koc<c<00Cooooo1?l000002?l@413oooooooooooo^
k^ko<S8bo`000?lb<S;ok^k^4oooool01_l@413o<S8bo`000?l0003o410@ojVYZ@;ooooo00Kok^k^
oeEEEOl0003o0000odA4A?nj^[X3ooooo`05ofIVI_l0003o0000odA4A?o<c<`0j?ooool008kooooo
00Go0000ooooooooooooc<c<oa0@4003ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo410@1?ooool0
0ol0003oooooooooo`02ooooo`06o`000?nYZJWoEEEEoiRHV?mEEEGo^[Zj0oooool00ol0003ooooo
ooooo`04ooooo`03olc<c?l0003o410@00cooooo00Ko410@okZj^_o^k^koMgMgoa0@4?ooool6o`00
00;ooooo00Go410@okZj^_ooooooMgMgoc8b<P05ooooo`;o8B4Q1?ooool02omEEEGoMgMgoooooonH
V9So8B4Qooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg01?ooooo00Ko0000ojVYZOoooooooooookZj^_l00002ooooo`06oeEE
EOmgMgOoooooonk^k_mgMgOo410@0_ooool01_mVIVKoMgMgooooooooooooQhN7oa0@4>Sooooo002>
ooooo`05o`000?oooooooooooeEEEOn7QhL00oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00;ooooo00Ko<S8bonk^k_nHV9SoEEEEomgMgOl@4103ooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`09ooooo`05o`000?oooooooooooooo
ool000000_ooool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooo
oooooooooooooa0@400Dooooo`05okZj^_n7QhOoIVIVofIVI_l@41000_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo0>_ooooo002>ooooo`05o`000?oooooogMgMo`000?o^k^h00ooo
ool6o`0000Cooooo00?o0000ooooooooool00_ooool01onj^[[oA4A4olc<c?lQ8B7ooooooa0@4?o<
c<`00_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00?ooooo1_l00005ooooo`03
ojVYZOl@413ooooo00[ooooo00_o0000oiRHV?ooooooV9RHob4Q8Oooooook^k^oeEEEOoMgMgoEEEE
onk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Cooooo`06
oc8b<_lQ8B7oMgMgogMgMon7QhOok^k^0_ooool6o`0000;ooooo00?o0000ooooooooool0joooool0
08kooooo0ol000000ol@413oV9RHooooo`02ooooo`06oeEEEOn7QhOok^k^oooooon7QhOo<S8b1?oo
ool00ol0003oooooooooo`02ooooo`07onk^k_l0003oooooo`000?ooooooIVIVohN7Q`02ooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool03Oooool00ol@413o0000okZj^P0;ooooo`0;
o`000?mEEEGo0000oa0@4?o<c<coooooolc<c?o^k^koooooonk^k_o<c<`01_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000004oooool01_l0003o^[Zjooooooo^k^koMgMg
o`0000;ooooo00KoEEEEohN7Qoo^k^koooooohN7Qolb<S82ooooo`06ofIVI_mgMgOooooooooooon7
QhOo0000j?ooool008kooooo00Go0000ooooooooooooc<c<o`000003ooooo`06onk^k_mEEEGo0000
o`000?m4A4Cok^k^1?ooool00ol0003oooooooooo`02ooooo`04ofIVI_nHV9Sooooooc8b<P;o^[Zj
00Co0000oooooooooooo00004oooool00ol@413o0000o`000003o`0000gooooo00?o^[Zjob4Q8Ooo
ool02_ooool00omEEEGoQhN7ooooo`0>ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooo
oooooooooa0@4007ooooo`?o00000_ooool3o`0000Cooooo00KoZJVYob4Q8Ol0003o0000oc8b<_l0
0002ooooo`06onk^k_mEEEGo0000o`000?m4A4Cok^k^0_ooool01_o^k^koIVIVo`000?l0003oA4A4
o`000>Sooooo002>ooooo`05o`000?ooooooooooolc<c?l000003Oooool00ol0003oooooooooo`05
ooooo`03ofIVI_n7QhOooooo00?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0;
ooooo`05oa0@4?nHV9SooooookZj^_l000002oooool00ooMgMgo410@oiRHV00>ooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0ooooool2ooooo`00SOooool4o`000003oa0@4?nYZJWooooo00cooooo0_l0
0006ooooo`03ojVYZOm4A4Cooooo00;ooooo0_l0000Eooooo`03o`000?oooooooooo00_ooooo00Go
ZJVYoa0@4?l0003o410@ojVYZ@0<ooooo`04olc<c?m4A4Co0000oa0@40[ooooo00?oEEEEofIVI_l0
00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo1?l00002ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0ooooool2ooooo`00ooooool6ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0ooooool2ooooo`00ooooool6ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0ooooool2ooooo`00ooooool5ooooo`;o00000oooool2o`000?oooooo1?oo
ool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooo
ooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@oooo
o`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooo
oooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo
003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooo
oooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo0000\
\>"],
  ImageRangeCache->{{{0, 525.688}, {324.5, 0}} -> {0, -6.34248*^6, 0, 53093}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0.309017 5.42214e-08 [
[.32684 .29652 -16.5 -12.5 ]
[.32684 .29652 16.5 0 ]
[.54329 .29652 -16.5 -12.5 ]
[.54329 .29652 16.5 0 ]
[.75974 .29652 -22.5 -12.5 ]
[.75974 .29652 22.5 0 ]
[.97619 .29652 -16.5 -12.5 ]
[.97619 .29652 16.5 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 64 6 ]
[.09789 .09213 -34.5 -6.25 ]
[.09789 .09213 0 6.25 ]
[.09789 .20057 -34.5 -6.25 ]
[.09789 .20057 0 6.25 ]
[.09789 .41746 -28.5 -6.25 ]
[.09789 .41746 0 6.25 ]
[.09789 .5259 -28.5 -6.25 ]
[.09789 .5259 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -62.8125 0 ]
[.5 .63053 62.8125 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 .30902 m
.32684 .31527 L
s
gsave
.32684 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 .30902 m
.54329 .31527 L
s
gsave
.54329 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 .30902 m
.75974 .31527 L
s
gsave
.75974 .29652 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 .30902 m
.15368 .31277 L
s
.19697 .30902 m
.19697 .31277 L
s
.24026 .30902 m
.24026 .31277 L
s
.28355 .30902 m
.28355 .31277 L
s
.37013 .30902 m
.37013 .31277 L
s
.41342 .30902 m
.41342 .31277 L
s
.45671 .30902 m
.45671 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.58658 .30902 m
.58658 .31277 L
s
.62987 .30902 m
.62987 .31277 L
s
.67316 .30902 m
.67316 .31277 L
s
.71645 .30902 m
.71645 .31277 L
s
.80303 .30902 m
.80303 .31277 L
s
.84632 .30902 m
.84632 .31277 L
s
.88961 .30902 m
.88961 .31277 L
s
.9329 .30902 m
.9329 .31277 L
s
.0671 .30902 m
.0671 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09213 m
.11664 .09213 L
s
gsave
.09789 .09213 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .20057 m
.11664 .20057 L
s
gsave
.09789 .20057 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .41746 m
.11664 .41746 L
s
gsave
.09789 .41746 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .5259 m
.11664 .5259 L
s
gsave
.09789 .5259 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.11039 .11924 m
.11414 .11924 L
s
.11039 .14635 m
.11414 .14635 L
s
.11039 .17346 m
.11414 .17346 L
s
.11039 .22768 m
.11414 .22768 L
s
.11039 .2548 m
.11414 .2548 L
s
.11039 .28191 m
.11414 .28191 L
s
.11039 .33613 m
.11414 .33613 L
s
.11039 .36324 m
.11414 .36324 L
s
.11039 .39035 m
.11414 .39035 L
s
.11039 .44457 m
.11414 .44457 L
s
.11039 .47168 m
.11414 .47168 L
s
.11039 .49879 m
.11414 .49879 L
s
.11039 .06502 m
.11414 .06502 L
s
.11039 .03791 m
.11414 .03791 L
s
.11039 .0108 m
.11414 .0108 L
s
.11039 .55301 m
.11414 .55301 L
s
.11039 .58012 m
.11414 .58012 L
s
.11039 .60723 m
.11414 .60723 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -123.812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.812 moveto
(@) show
81.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.812 moveto
(D) show
93.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3.8) show
135.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
141.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
153.000 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
157.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
166.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
184.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02691 .30902 L
.02852 .30902 L
.02938 .30902 L
.03029 .30902 L
.03074 .30902 L
.03115 .30902 L
.03153 .30902 L
.03174 .30902 L
.03184 .30902 L
.03194 .30902 L
.03203 .30902 L
.03212 .30902 L
.03221 .30902 L
.03229 .30902 L
.03239 .30902 L
.03248 .30902 L
.03258 .30902 L
.03268 .30902 L
.03278 .30902 L
.03289 .30902 L
.03309 .30902 L
.03329 .30902 L
.03347 .30902 L
.03385 .30902 L
.03425 .30902 L
.03463 .30902 L
.03498 .30902 L
.03539 .30902 L
.03583 .30902 L
.03664 .30902 L
.03739 .30902 L
.03823 .30902 L
.0391 .30902 L
.03991 .30902 L
.0407 .30902 L
.04153 .30902 L
.04302 .30902 L
.0446 .30902 L
.04608 .30902 L
.04772 .30902 L
.04921 .30902 L
.05242 .30902 L
.05551 .30902 L
.05879 .30902 L
.06043 .30902 L
.06122 .30902 L
.06195 .30902 L
.06231 .30902 L
.06271 .30902 L
Mistroke
.06308 .30902 L
.06324 .30902 L
.06342 .30902 L
.06353 .30902 L
.06363 .30902 L
.06372 .30902 L
.06382 .30902 L
.06391 .30902 L
.064 .30902 L
.06409 .30902 L
.06418 .30902 L
.06429 .30902 L
.06435 .30902 L
.0644 .30902 L
.0645 .30902 L
.06461 .30902 L
.06479 .30902 L
.065 .30902 L
.06518 .30902 L
.06539 .30902 L
.06581 .30902 L
.06619 .30902 L
.06655 .30902 L
.06736 .30902 L
.06782 .30902 L
.06823 .30902 L
.06898 .30902 L
.06977 .30902 L
.07064 .30902 L
.07144 .30902 L
.07301 .30902 L
.07449 .30902 L
.07612 .30902 L
.07761 .30902 L
.0808 .30902 L
.08388 .30902 L
.08715 .30902 L
.08793 .30902 L
.08877 .30902 L
.08957 .30902 L
.08994 .30902 L
.0903 .30902 L
.09064 .30902 L
.09083 .30902 L
.09091 .30902 L
.091 .30902 L
.0911 .30902 L
.09119 .30902 L
.09129 .30902 L
.09134 .30902 L
Mistroke
.0914 .30902 L
.09149 .30902 L
.09158 .30902 L
.09168 .30902 L
.09177 .30902 L
.09196 .30902 L
.09216 .30902 L
.09234 .30902 L
.09251 .30902 L
.09293 .30902 L
.09332 .30902 L
.09411 .30902 L
.0945 .30902 L
.09494 .30902 L
.0957 .30902 L
.09642 .30902 L
.09726 .30902 L
.09805 .30902 L
.09954 .30902 L
.10114 .30902 L
.10262 .30902 L
.10578 .30902 L
.10881 .30902 L
.11049 .30902 L
.11204 .30902 L
.11282 .30902 L
.11355 .30902 L
.11395 .30902 L
.11431 .30902 L
.11471 .30902 L
.11493 .30902 L
.11504 .30902 L
.11514 .30902 L
.11524 .30902 L
.11534 .30902 L
.11543 .30902 L
.11552 .30902 L
.11562 .30902 L
.11571 .30902 L
.11581 .30902 L
.11587 .30902 L
.11592 .30902 L
.11603 .30902 L
.11613 .30902 L
.11635 .30902 L
.11655 .30902 L
.11675 .30902 L
.11712 .30902 L
.11746 .30902 L
.11823 .30902 L
Mistroke
.11864 .30902 L
.11907 .30902 L
.11987 .30902 L
.12065 .30902 L
.12136 .30902 L
.12286 .30901 L
.12452 .30901 L
.12608 .309 L
.12775 .30899 L
.13106 .30897 L
.13271 .30896 L
.13425 .30895 L
.13501 .30895 L
.13573 .30894 L
.13613 .30894 L
.13656 .30894 L
.13675 .30894 L
.13695 .30894 L
.13712 .30894 L
.13731 .30894 L
.13742 .30894 L
.13751 .30894 L
.13761 .30894 L
.13771 .30894 L
.1378 .30894 L
.13788 .30894 L
.13797 .30894 L
.13807 .30894 L
.13817 .30894 L
.13828 .30894 L
.1385 .30894 L
.1387 .30894 L
.13889 .30894 L
.13926 .30894 L
.1396 .30895 L
.14036 .30895 L
.14075 .30895 L
.14116 .30896 L
.1419 .30897 L
.14269 .30898 L
.14357 .309 L
.14513 .30904 L
.1468 .30909 L
.15011 .30924 L
.15331 .3094 L
.15492 .30947 L
.15562 .3095 L
.15637 .30952 L
.1568 .30953 L
.15719 .30954 L
Mistroke
.15738 .30954 L
.15756 .30955 L
.15775 .30955 L
.15785 .30955 L
.15796 .30955 L
.15801 .30955 L
.15807 .30955 L
.15817 .30955 L
.15823 .30955 L
.15828 .30955 L
.15834 .30955 L
.15841 .30955 L
.15846 .30955 L
.15852 .30955 L
.15863 .30955 L
.15874 .30955 L
.15884 .30955 L
.15904 .30954 L
.15923 .30954 L
.15964 .30953 L
.16003 .30952 L
.16044 .3095 L
.16118 .30946 L
.16198 .3094 L
.16285 .30932 L
.16442 .30912 L
.16609 .30882 L
.16941 .30804 L
.1726 .30718 L
.17406 .30684 L
.1749 .30668 L
.1753 .30661 L
.17568 .30656 L
.17604 .30652 L
.17644 .30648 L
.17665 .30647 L
.17684 .30646 L
.17695 .30645 L
.17704 .30645 L
.1771 .30645 L
.17716 .30645 L
.17726 .30644 L
.17737 .30644 L
.17746 .30644 L
.17752 .30644 L
.17757 .30644 L
.17763 .30645 L
.17769 .30645 L
.1778 .30645 L
.1779 .30645 L
Mistroke
.17814 .30647 L
.17834 .30648 L
.17853 .3065 L
.17895 .30655 L
.17934 .30662 L
.17975 .30671 L
.18049 .30691 L
.18129 .30721 L
.18216 .30762 L
.18373 .3086 L
.18541 .30996 L
.18873 .31332 L
.19039 .31507 L
.19193 .31652 L
.1927 .31713 L
.19342 .31759 L
.19381 .3178 L
.19417 .31795 L
.19458 .31809 L
.19479 .31814 L
.19489 .31816 L
.19501 .31818 L
.19511 .31819 L
.19521 .3182 L
.19531 .31821 L
.19541 .31821 L
.1955 .31822 L
.19558 .31821 L
.19567 .31821 L
.19577 .3182 L
.19588 .31819 L
.19599 .31817 L
.1962 .31813 L
.1964 .31807 L
.19659 .31801 L
.19697 .31784 L
.19731 .31764 L
.19807 .31703 L
.19887 .31612 L
.19961 .31505 L
.20129 .31181 L
.2028 .30798 L
.20446 .303 L
.20771 .29252 L
.20921 .28831 L
.21 .2865 L
.21084 .28498 L
.21126 .2844 L
.21149 .28415 L
.21173 .28393 L
Mistroke
.21195 .28377 L
.21215 .28366 L
.21225 .28362 L
.21235 .28358 L
.21245 .28356 L
.21255 .28355 L
.21265 .28354 L
.21271 .28354 L
.21276 .28355 L
.21285 .28356 L
.21296 .28359 L
.21305 .28362 L
.21313 .28366 L
.21333 .28377 L
.21354 .28393 L
.21373 .28412 L
.21416 .28469 L
.21455 .28537 L
.21496 .28626 L
.21569 .28835 L
.21649 .29126 L
.21736 .29528 L
.22058 .31629 L
.22369 .34093 L
.22526 .35221 L
.2261 .35718 L
.22656 .35951 L
.22699 .36141 L
.2274 .36294 L
.22785 .36424 L
.22805 .36469 L
.22826 .36508 L
.22844 .36534 L
.22853 .36545 L
.22863 .36555 L
.22874 .36563 L
.22883 .36568 L
.22893 .36571 L
.22902 .36572 L
.22912 .3657 L
.22921 .36567 L
.22927 .36565 L
.22932 .36561 L
.22943 .36553 L
.22961 .36531 L
.22981 .365 L
.23017 .36419 L
.23057 .36292 L
.23093 .36142 L
.23174 .35686 L
Mistroke
.2325 .35116 L
.23322 .34449 L
.2363 .304 L
.23957 .25135 L
.2412 .22846 L
.242 .2194 L
.24273 .21277 L
.24309 .21011 L
.24344 .20808 L
.24379 .20645 L
.24398 .20579 L
.24419 .20525 L
.24429 .20504 L
.24439 .20489 L
.24444 .20482 L
.2445 .20477 L
.24455 .20472 L
.24461 .20469 L
.24471 .20467 L
.2448 .20469 L
.24485 .20472 L
.24491 .20476 L
.24501 .20488 L
.24511 .20504 L
.2452 .20522 L
.2454 .20575 L
.24558 .20641 L
.24576 .20718 L
.24613 .20931 L
.24654 .2124 L
.24737 .22103 L
.24814 .23184 L
.24886 .24421 L
.25199 .31875 L
.25358 .36329 L
.25531 .40931 L
.25612 .4281 L
.25698 .44511 L
.25771 .45671 L
.2581 .46159 L
.25852 .46585 L
.25874 .46759 L
.25894 .46893 L
.25913 .46995 L
.25923 .47037 L
.25933 .47075 L
.25944 .47105 L
.25953 .47125 L
.25963 .47138 L
.25972 .47146 L
Mistroke
.25981 .47146 L
.25989 .47142 L
.25998 .47131 L
.26008 .47114 L
.26019 .47084 L
.26029 .47049 L
.26053 .46938 L
.26073 .46807 L
.26095 .46632 L
.26133 .46243 L
.26175 .45688 L
.26256 .44247 L
.26331 .42519 L
.26498 .37371 L
.26816 .24762 L
.26976 .18475 L
.27122 .13719 L
.27203 .11689 L
.27279 .10271 L
.273 .09983 L
.27321 .0972 L
.2734 .0953 L
.2736 .09364 L
.27371 .09289 L
.27381 .09231 L
.27392 .09183 L
.27401 .09149 L
.27407 .09134 L
.27413 .09122 L
.27419 .09112 L
.27425 .09107 L
.27431 .09105 L
.27436 .09107 L
.27442 .09112 L
.27447 .0912 L
.27457 .09143 L
.27467 .09175 L
.27476 .09212 L
.27485 .09261 L
.27506 .09406 L
.27526 .09582 L
.27561 .10004 L
.27599 .10598 L
.27678 .12316 L
.27765 .14915 L
.2792 .21146 L
.28088 .29446 L
.28246 .37814 L
.28418 .46293 L
.28498 .49615 L
Mistroke
.28583 .5255 L
.28625 .53713 L
.28664 .54635 L
.28702 .55359 L
.28737 .55879 L
.28755 .56085 L
.28774 .5626 L
.28785 .56338 L
.28795 .56399 L
.28805 .56441 L
.28815 .56473 L
.28825 .56492 L
.28831 .56498 L
.28836 .56499 L
.28841 .56496 L
.28846 .56489 L
.28852 .56479 L
.28858 .56463 L
.28868 .56426 L
.28877 .56381 L
.28898 .56237 L
.28917 .56053 L
.28935 .55834 L
.28969 .55309 L
.29006 .54576 L
.29046 .5359 L
.29122 .51192 L
.29205 .47825 L
.29374 .39182 L
.29698 .20058 L
.29846 .12497 L
.29931 .09108 L
.30009 .06696 L
.30052 .05702 L
.30091 .05018 L
.30113 .0473 L
.30124 .04606 L
.30136 .04495 L
.30147 .04414 L
.30158 .04344 L
.30169 .04297 L
.30179 .04268 L
.30189 .04252 L
.30194 .0425 L
.302 .04252 L
.30209 .04266 L
.30219 .04296 L
.30228 .04335 L
.30237 .04383 L
.30256 .04531 L
Mistroke
.30277 .04751 L
.30297 .05008 L
.3034 .05778 L
.30378 .06667 L
.30419 .0783 L
.30492 .1044 L
.30658 .18422 L
.30991 .3833 L
.31158 .47141 L
.31232 .50226 L
.31271 .51616 L
.31312 .52901 L
.31353 .53933 L
.3139 .54681 L
.31408 .54973 L
.31427 .5524 L
.31445 .55442 L
.31462 .55589 L
.31472 .55656 L
.31483 .55712 L
.31493 .55747 L
.31502 .55768 L
.31512 .55777 L
.31518 .55775 L
.31523 .5577 L
.31534 .55748 L
.31539 .55728 L
.31545 .55706 L
.31564 .55596 L
.31574 .55512 L
.31584 .5542 L
.31621 .54949 L
.31659 .54285 L
.31699 .53364 L
.31771 .51189 L
.31937 .44178 L
.32268 .26133 L
.32433 .1807 L
.32513 .14948 L
.32586 .12707 L
.32623 .11815 L
.32663 .11036 L
.32681 .10745 L
.327 .10483 L
.32718 .10281 L
.32735 .10134 L
.32753 .10008 L
.32764 .09958 L
.32774 .09924 L
.32783 .09903 L
Mistroke
.32791 .09894 L
.328 .09894 L
.3281 .09906 L
.3282 .0993 L
.3283 .0997 L
.3284 .1002 L
.32849 .10078 L
.3287 .10251 L
.32893 .10493 L
.32933 .11081 L
.32969 .11779 L
.33051 .1387 L
.33198 .19159 L
.33519 .33749 L
.33666 .39787 L
.3375 .42572 L
.33828 .44628 L
.33867 .45441 L
.33905 .46065 L
.33925 .46347 L
.33948 .46603 L
.33968 .46788 L
.33987 .46922 L
.33998 .4698 L
.3401 .47028 L
.3402 .4706 L
.3403 .47079 L
.3404 .47089 L
.34046 .47089 L
.34052 .47086 L
.34058 .47079 L
.34063 .4707 L
.34069 .47055 L
.34075 .47038 L
.34085 .47 L
.34095 .4695 L
.34114 .46832 L
.34134 .46666 L
.34156 .46436 L
.34196 .4591 L
.34237 .45203 L
.34312 .43583 L
.34479 .38628 L
.34785 .27945 L
.34943 .23409 L
.35031 .21533 L
.35069 .20897 L
.35111 .20328 L
.3515 .19923 L
.35172 .19754 L
Mistroke
.35191 .19628 L
.35201 .1958 L
.3521 .1954 L
.35218 .1951 L
.35227 .19484 L
.35237 .19463 L
.35245 .1945 L
.35255 .19443 L
.35265 .19443 L
.35276 .19452 L
.35281 .1946 L
.35287 .19471 L
.35297 .19496 L
.35307 .19528 L
.35328 .19624 L
.35352 .19766 L
.35394 .20125 L
.35432 .20559 L
.35512 .21752 L
.35586 .23153 L
.35753 .27024 L
.35916 .31098 L
.36069 .34499 L
.36144 .35858 L
.36215 .36905 L
.36254 .37369 L
.36297 .37779 L
.36336 .38063 L
.36354 .38163 L
.36373 .3825 L
.36383 .38289 L
.36394 .38325 L
.36404 .38352 L
.36413 .38372 L
.36419 .38381 L
.36424 .38389 L
.3643 .38395 L
.36436 .38399 L
.36441 .38402 L
.36447 .38403 L
.36457 .384 L
.36467 .38392 L
.36477 .38378 L
.36487 .3836 L
.36495 .38339 L
.36516 .38275 L
.36537 .38185 L
.36574 .37977 L
.36609 .37727 L
.36687 .36972 L
Mistroke
.36851 .34739 L
.37 .32325 L
.37167 .29714 L
.3724 .28725 L
.37321 .27806 L
.37358 .27449 L
.37399 .27119 L
.37433 .26879 L
.37471 .26668 L
.37493 .26568 L
.37514 .26492 L
.37533 .26433 L
.37543 .26409 L
.37554 .26386 L
.37565 .26369 L
.37575 .26356 L
.37584 .26347 L
.37594 .2634 L
.37603 .26338 L
.37611 .26338 L
.3762 .26341 L
.3763 .26347 L
.3764 .26357 L
.3765 .26371 L
.37672 .26412 L
.37693 .26464 L
.37712 .26524 L
.37755 .267 L
.37801 .26947 L
.37885 .27532 L
.37962 .28186 L
.38127 .29788 L
.38281 .31265 L
.38429 .3244 L
.38512 .32925 L
.38548 .33091 L
.38587 .33241 L
.38626 .33355 L
.38647 .33403 L
.38667 .33439 L
.38686 .33465 L
.38703 .33481 L
.38713 .33488 L
.38723 .33493 L
.38732 .33496 L
.38741 .33496 L
.38751 .33495 L
.38761 .33492 L
.38771 .33487 L
.3878 .3348 L
Mistroke
.38801 .33459 L
.38822 .33428 L
.38863 .33346 L
.38908 .33222 L
.38991 .32917 L
.39066 .32569 L
.39234 .3165 L
.39401 .30737 L
.39474 .30387 L
.39554 .30059 L
.39632 .29813 L
.39669 .29721 L
.39704 .29649 L
.39723 .29617 L
.39744 .29587 L
.39763 .29564 L
.39781 .29547 L
.39801 .29532 L
.39813 .29526 L
.39818 .29524 L
.39823 .29522 L
.39833 .2952 L
.39842 .29518 L
.39852 .29518 L
.39858 .29518 L
.39863 .29519 L
.39873 .29521 L
.39878 .29522 L
.39884 .29524 L
.39903 .29534 L
.39914 .29541 L
.39926 .2955 L
.39947 .2957 L
.39988 .29622 L
.40027 .29684 L
.40175 .30028 L
.4034 .30514 L
.40494 .3096 L
.40642 .31308 L
.40684 .31385 L
.40725 .31447 L
.40763 .31497 L
.408 .31535 L
.40837 .31564 L
.40857 .31576 L
.40878 .31586 L
.40889 .31589 L
.409 .31592 L
.40905 .31594 L
.40911 .31595 L
Mistroke
.40921 .31596 L
.40926 .31597 L
.40932 .31597 L
.40942 .31597 L
.40952 .31597 L
.40961 .31596 L
.40969 .31594 L
.40978 .31592 L
.40995 .31587 L
.41015 .3158 L
.41033 .31571 L
.41072 .31546 L
.41109 .31515 L
.41187 .31432 L
.41269 .31324 L
.41417 .31102 L
.41576 .30872 L
.41721 .30705 L
.41759 .30671 L
.418 .3064 L
.4184 .30615 L
.41876 .30598 L
.41897 .3059 L
.41918 .30583 L
.4193 .3058 L
.41941 .30578 L
.41953 .30576 L
.41963 .30574 L
.41972 .30573 L
.41982 .30572 L
.41987 .30572 L
.41993 .30572 L
.42002 .30571 L
.42013 .30572 L
.42022 .30572 L
.42033 .30573 L
.42038 .30573 L
.42044 .30574 L
.42063 .30576 L
.42083 .30581 L
.42125 .30592 L
.42163 .30607 L
.42199 .30623 L
.42367 .30727 L
.42517 .30836 L
.4268 .30942 L
.42769 .30988 L
.42808 .31004 L
.42851 .31019 L
.42889 .3103 L
Mistroke
.4293 .31039 L
.42952 .31043 L
.42973 .31046 L
.42983 .31047 L
.42993 .31048 L
.43003 .31049 L
.43013 .31049 L
.43018 .3105 L
.43024 .3105 L
.43033 .3105 L
.43039 .3105 L
.43045 .3105 L
.43051 .3105 L
.43056 .3105 L
.43066 .3105 L
.43071 .3105 L
.43076 .3105 L
.43086 .3105 L
.43096 .31049 L
.43114 .31048 L
.43132 .31046 L
.43171 .31041 L
.43213 .31033 L
.43252 .31025 L
.43339 .31001 L
.43505 .30948 L
.43658 .309 L
.43734 .3088 L
.43806 .30864 L
.43846 .30857 L
.43889 .30851 L
.43925 .30846 L
.43964 .30842 L
.43985 .30841 L
.44003 .3084 L
.44022 .30839 L
.44031 .30839 L
.4404 .30838 L
.4405 .30838 L
.44056 .30838 L
.44061 .30838 L
.4407 .30838 L
.4408 .30838 L
.44086 .30838 L
.44091 .30838 L
.44097 .30838 L
.44103 .30838 L
.44113 .30838 L
.44124 .30839 L
.44146 .30839 L
Mistroke
.44169 .30841 L
.44212 .30843 L
.44254 .30847 L
.44293 .30851 L
.44609 .30893 L
.4469 .30904 L
.44768 .30912 L
.44837 .30918 L
.44913 .30923 L
.44952 .30925 L
.44973 .30926 L
.44993 .30926 L
.45012 .30927 L
.45022 .30927 L
.45033 .30927 L
.45042 .30927 L
.45051 .30928 L
.4506 .30928 L
.45068 .30928 L
.45079 .30928 L
.45085 .30928 L
.4509 .30928 L
.451 .30928 L
.45111 .30928 L
.4512 .30928 L
.45129 .30928 L
.45149 .30927 L
.45171 .30927 L
.45191 .30926 L
.45236 .30925 L
.45315 .30922 L
.45388 .30918 L
.45554 .30908 L
.45705 .309 L
.4579 .30897 L
.45868 .30894 L
.45907 .30893 L
.45951 .30893 L
.45973 .30892 L
.45997 .30892 L
.46008 .30892 L
.46019 .30892 L
.46029 .30892 L
.46039 .30892 L
.46049 .30892 L
.46059 .30892 L
.46069 .30892 L
.46074 .30892 L
.46079 .30892 L
.46088 .30892 L
Mistroke
.46097 .30892 L
.46107 .30892 L
.46117 .30892 L
.46128 .30892 L
.46138 .30892 L
.46157 .30892 L
.46201 .30892 L
.46238 .30893 L
.46279 .30893 L
.46361 .30895 L
.46509 .30898 L
.46678 .30902 L
.46758 .30903 L
.46832 .30904 L
.46869 .30905 L
.46908 .30905 L
.46931 .30905 L
.46952 .30905 L
.46971 .30905 L
.46992 .30905 L
.4701 .30905 L
.4702 .30905 L
.4703 .30905 L
.47038 .30906 L
.47046 .30906 L
.47056 .30906 L
.47065 .30906 L
.47074 .30906 L
.47084 .30905 L
.47093 .30905 L
.47102 .30905 L
.47123 .30905 L
.47143 .30905 L
.47181 .30905 L
.47222 .30905 L
.47305 .30904 L
.47454 .30903 L
.47624 .30902 L
.47705 .30901 L
.47779 .30901 L
.47816 .30901 L
.47856 .30901 L
.47897 .309 L
.47919 .309 L
.4794 .309 L
.4795 .309 L
.4796 .309 L
.47969 .309 L
.47978 .309 L
.47988 .309 L
Mistroke
.47997 .309 L
.48005 .309 L
.48013 .309 L
.48023 .309 L
.48033 .309 L
.48042 .309 L
.48051 .309 L
.48062 .309 L
.48073 .309 L
.48092 .309 L
.48135 .309 L
.48174 .30901 L
.48263 .30901 L
.48425 .30901 L
.48587 .30902 L
.48667 .30902 L
.4874 .30902 L
.48777 .30902 L
.48811 .30902 L
.48847 .30902 L
.48866 .30902 L
.48886 .30902 L
.48906 .30902 L
.48918 .30902 L
.48928 .30902 L
.48938 .30902 L
.48948 .30902 L
.48953 .30902 L
.48958 .30902 L
.48968 .30902 L
.48978 .30902 L
.48988 .30902 L
.48998 .30902 L
.49008 .30902 L
.49025 .30902 L
.49043 .30902 L
.49086 .30902 L
.49126 .30902 L
.49216 .30902 L
.49378 .30902 L
.49457 .30902 L
.49542 .30902 L
.49616 .30902 L
.49695 .30902 L
.49738 .30902 L
.49757 .30902 L
.49777 .30902 L
.49796 .30902 L
.49815 .30902 L
.49826 .30902 L
Mistroke
.49836 .30902 L
.49845 .30902 L
.49855 .30902 L
.49865 .30902 L
.49874 .30902 L
.49883 .30902 L
.49891 .30902 L
.49901 .30902 L
.4991 .30902 L
.49919 .30902 L
.4993 .30902 L
.49938 .30902 L
.49947 .30902 L
.49964 .30902 L
.50001 .30902 L
.50043 .30902 L
.50082 .30902 L
.50171 .30902 L
.50333 .30902 L
.50411 .30902 L
.50495 .30902 L
.50575 .30902 L
.50613 .30902 L
.50648 .30902 L
.50682 .30902 L
.50718 .30902 L
.50739 .30902 L
.50749 .30902 L
.50759 .30902 L
.50767 .30902 L
.50776 .30902 L
.50786 .30902 L
.50795 .30902 L
.50806 .30902 L
.50816 .30902 L
.50825 .30902 L
.50834 .30902 L
.50845 .30902 L
.50856 .30902 L
.50876 .30902 L
.50896 .30902 L
.50915 .30902 L
.50951 .30902 L
.51029 .30902 L
.51112 .30902 L
.51261 .30902 L
.51337 .30902 L
.51419 .30902 L
.51458 .30902 L
.51496 .30902 L
Mistroke
.51532 .30902 L
.51566 .30902 L
.51603 .30902 L
.51622 .30902 L
.51644 .30902 L
.51665 .30902 L
.51675 .30902 L
.51681 .30902 L
.51687 .30902 L
.51697 .30902 L
.51707 .30902 L
.51717 .30902 L
.51726 .30902 L
.51735 .30902 L
.51744 .30902 L
.51754 .30902 L
.51763 .30902 L
.51779 .30902 L
.51797 .30902 L
.51837 .30902 L
.51874 .30902 L
.5204 .30902 L
.52194 .30902 L
.5227 .30902 L
.52343 .30902 L
.52418 .30902 L
.52458 .30902 L
.52479 .30902 L
.52501 .30902 L
.52522 .30902 L
.52541 .30902 L
.5255 .30902 L
.5256 .30902 L
.52569 .30902 L
.52578 .30902 L
.52588 .30902 L
.52593 .30902 L
.52599 .30902 L
.52605 .30902 L
.52611 .30902 L
.52616 .30902 L
.52621 .30902 L
.52631 .30902 L
.52637 .30902 L
.52642 .30902 L
.52662 .30902 L
.52672 .30902 L
.52683 .30902 L
.52703 .30902 L
.52749 .30902 L
Mistroke
.52831 .30902 L
.5299 .30902 L
.53136 .30902 L
.53216 .30902 L
.53293 .30902 L
.53334 .30902 L
.53373 .30902 L
.53393 .30902 L
.53415 .30902 L
.53427 .30902 L
.53439 .30902 L
.5345 .30902 L
.5346 .30902 L
.53471 .30902 L
.5348 .30902 L
.53489 .30902 L
.53499 .30902 L
.53509 .30902 L
.53514 .30902 L
.5352 .30902 L
.5353 .30902 L
.53539 .30902 L
.53558 .30902 L
.53575 .30902 L
.53612 .30902 L
.53698 .30902 L
.53779 .30902 L
.5394 .30902 L
.5401 .30902 L
.54086 .30902 L
.54128 .30902 L
.54167 .30902 L
.54205 .30902 L
.54244 .30902 L
.54264 .30902 L
.54286 .30902 L
.54296 .30902 L
.54306 .30902 L
.54315 .30902 L
.54324 .30902 L
.54335 .30902 L
.54341 .30902 L
.54346 .30902 L
.54356 .30902 L
.54367 .30902 L
.54373 .30902 L
.54379 .30902 L
.54385 .30902 L
.54391 .30902 L
.54401 .30902 L
Mistroke
.54413 .30902 L
.54433 .30902 L
.54456 .30902 L
.54495 .30902 L
.54584 .30902 L
.54746 .30902 L
.54828 .30902 L
.54906 .30902 L
.54975 .30902 L
.55011 .30902 L
.55051 .30902 L
.5509 .30902 L
.55112 .30902 L
.55132 .30902 L
.55151 .30902 L
.55168 .30902 L
.55177 .30902 L
.55187 .30902 L
.55198 .30902 L
.55207 .30902 L
.55218 .30902 L
.55224 .30902 L
.55229 .30902 L
.55239 .30902 L
.55244 .30902 L
.5525 .30902 L
.5527 .30902 L
.55289 .30902 L
.5533 .30902 L
.55375 .30902 L
.55534 .30902 L
.55617 .30902 L
.55706 .30902 L
.55793 .30902 L
.55872 .30902 L
.5591 .30902 L
.5593 .30902 L
.55951 .30902 L
.5597 .30902 L
.5599 .30902 L
.56008 .30902 L
.56026 .30902 L
.56036 .30902 L
.56041 .30902 L
.56046 .30902 L
.56056 .30902 L
.56066 .30902 L
.56071 .30902 L
.56077 .30902 L
.56087 .30902 L
Mistroke
.56092 .30902 L
.56098 .30902 L
.5611 .30902 L
.5613 .30902 L
.56148 .30902 L
.56189 .30902 L
.56266 .30902 L
.56338 .30902 L
.56485 .30902 L
.56569 .30902 L
.56647 .30902 L
.56687 .30902 L
.56724 .30902 L
.56767 .30902 L
.56807 .30902 L
.56827 .30902 L
.56838 .30902 L
.56849 .30902 L
.56859 .30902 L
.56867 .30902 L
.56877 .30902 L
.56888 .30902 L
.56898 .30902 L
.56908 .30902 L
.56914 .30902 L
.56919 .30902 L
.56925 .30902 L
.56931 .30902 L
.56942 .30902 L
.56952 .30902 L
.56976 .30902 L
.57013 .30902 L
.57054 .30902 L
.57126 .30902 L
.57292 .30902 L
.57373 .30902 L
.57462 .30902 L
.57502 .30902 L
.57545 .30902 L
.57586 .30902 L
.57623 .30902 L
.57641 .30902 L
.57662 .30902 L
.57672 .30902 L
.57683 .30902 L
.57694 .30902 L
.57703 .30902 L
.57713 .30902 L
.57721 .30902 L
.57731 .30902 L
Mistroke
.57741 .30902 L
.5775 .30902 L
.57758 .30902 L
.57768 .30902 L
.57777 .30902 L
.57798 .30902 L
.5782 .30902 L
.57865 .30902 L
.57944 .30902 L
.58115 .30902 L
.58196 .30902 L
.5827 .30902 L
.58347 .30902 L
.58388 .30902 L
.58409 .30902 L
.58431 .30902 L
.58451 .30902 L
.58469 .30902 L
.58487 .30902 L
.58504 .30902 L
.58513 .30902 L
.58524 .30902 L
.58533 .30902 L
.58542 .30902 L
.58552 .30902 L
.58558 .30902 L
.58563 .30902 L
.58573 .30902 L
.58584 .30902 L
.58593 .30902 L
.58604 .30902 L
.58623 .30902 L
.5866 .30902 L
.58742 .30902 L
.58889 .30902 L
.59045 .30902 L
.59087 .30902 L
.59133 .30902 L
.59173 .30902 L
.59217 .30902 L
.59237 .30902 L
.59258 .30902 L
.59279 .30902 L
.59297 .30902 L
.59308 .30902 L
.59318 .30902 L
.59329 .30902 L
.59334 .30902 L
.5934 .30902 L
.59351 .30902 L
Mistroke
.59356 .30902 L
.59362 .30902 L
.59372 .30902 L
.59381 .30902 L
.5939 .30902 L
.594 .30902 L
.59419 .30902 L
.59437 .30902 L
.59454 .30902 L
.59532 .30902 L
.5968 .30902 L
.59764 .30902 L
.59843 .30902 L
.5992 .30902 L
.59964 .30902 L
.60003 .30902 L
.60045 .30902 L
.60069 .30902 L
.6009 .30902 L
.60109 .30902 L
.6012 .30902 L
.6013 .30902 L
.60136 .30902 L
.60141 .30902 L
.60151 .30902 L
.60161 .30902 L
.60167 .30902 L
.60173 .30902 L
.60183 .30902 L
.60188 .30902 L
.60194 .30902 L
.60213 .30902 L
.60236 .30902 L
.60257 .30902 L
.60337 .30902 L
.60487 .30902 L
.60637 .30902 L
.60678 .30902 L
.60721 .30902 L
.60759 .30902 L
.60799 .30902 L
.60821 .30902 L
.60841 .30902 L
.60862 .30902 L
.60881 .30902 L
.60901 .30902 L
.60912 .30902 L
.60918 .30902 L
.60924 .30902 L
.6093 .30902 L
Mistroke
.60937 .30902 L
.60942 .30902 L
.60948 .30902 L
.60959 .30902 L
.60964 .30902 L
.6097 .30902 L
.6098 .30902 L
.60991 .30902 L
.61011 .30902 L
.6103 .30902 L
.61048 .30902 L
.61132 .30902 L
.61283 .30902 L
.61362 .30902 L
.61446 .30902 L
.61489 .30902 L
.61536 .30902 L
.61579 .30902 L
.61619 .30902 L
.6164 .30902 L
.6166 .30902 L
.61678 .30902 L
.61688 .30902 L
.61697 .30902 L
.61707 .30902 L
.61716 .30902 L
.61727 .30902 L
.61732 .30902 L
.61738 .30902 L
.61748 .30902 L
.61754 .30902 L
.6176 .30902 L
.6177 .30902 L
.61781 .30902 L
.61802 .30902 L
.61824 .30902 L
.61863 .30902 L
.61953 .30902 L
.62114 .30902 L
.6219 .30902 L
.62232 .30902 L
.62272 .30902 L
.62309 .30902 L
.62349 .30902 L
.62385 .30902 L
.62419 .30902 L
.62439 .30902 L
.62456 .30902 L
.62466 .30902 L
.62476 .30902 L
Mistroke
.62481 .30902 L
.62486 .30902 L
.62496 .30902 L
.62506 .30902 L
.62516 .30902 L
.62526 .30902 L
.62534 .30902 L
.62542 .30902 L
.62551 .30902 L
.62569 .30902 L
.6259 .30902 L
.6261 .30902 L
.62654 .30902 L
.62734 .30902 L
.629 .30902 L
.6298 .30902 L
.63053 .30902 L
.6309 .30902 L
.6313 .30902 L
.63148 .30902 L
.63168 .30902 L
.63186 .30902 L
.63202 .30902 L
.63221 .30902 L
.63231 .30902 L
.63241 .30902 L
.6325 .30902 L
.63259 .30902 L
.63268 .30902 L
.63278 .30902 L
.63287 .30902 L
.63298 .30902 L
.63308 .30902 L
.63317 .30902 L
.63338 .30902 L
.6336 .30902 L
.63401 .30902 L
.63437 .30902 L
.63519 .30902 L
.63667 .30902 L
.63742 .30902 L
.63821 .30902 L
.63862 .30902 L
.63884 .30902 L
.63908 .30902 L
.63929 .30902 L
.63949 .30902 L
.63969 .30902 L
.63988 .30902 L
.63997 .30902 L
Mistroke
.64007 .30902 L
.64016 .30902 L
.64025 .30902 L
.64034 .30902 L
.64044 .30902 L
.6405 .30902 L
.64055 .30902 L
.64065 .30902 L
.64076 .30902 L
.64087 .30902 L
.64108 .30902 L
.64147 .30902 L
.64224 .30902 L
.64295 .30902 L
.64374 .30902 L
.64458 .30902 L
.64538 .30902 L
.64574 .30902 L
.64611 .30902 L
.6465 .30902 L
.64686 .30902 L
.64708 .30902 L
.64718 .30902 L
.64728 .30902 L
.64737 .30902 L
.64747 .30902 L
.64757 .30902 L
.64767 .30902 L
.64777 .30902 L
.64786 .30902 L
.64795 .30902 L
.64804 .30902 L
.64814 .30902 L
.64824 .30902 L
.64844 .30902 L
.64861 .30902 L
.64877 .30902 L
.64915 .30902 L
.65063 .30902 L
.65147 .30902 L
.65226 .30902 L
.65303 .30902 L
.65347 .30902 L
.65387 .30902 L
.65407 .30902 L
.65428 .30902 L
.65452 .30902 L
.65462 .30902 L
.65474 .30902 L
.65484 .30902 L
Mistroke
.65494 .30902 L
.65504 .30902 L
.65513 .30902 L
.65518 .30902 L
.65524 .30902 L
.65533 .30902 L
.6554 .30902 L
.65545 .30902 L
.6555 .30902 L
.65556 .30902 L
.65566 .30902 L
.65575 .30902 L
.65596 .30902 L
.65632 .30902 L
.65676 .30902 L
.65716 .30902 L
.65886 .30902 L
.65963 .30902 L
.66006 .30902 L
.66046 .30902 L
.66083 .30902 L
.66116 .30902 L
.66154 .30902 L
.66174 .30902 L
.66194 .30902 L
.66204 .30902 L
.66215 .30902 L
.66224 .30902 L
.66234 .30902 L
.66243 .30902 L
.66253 .30902 L
.66262 .30902 L
.66271 .30902 L
.66276 .30902 L
.66281 .30902 L
.66291 .30902 L
.66301 .30902 L
.6631 .30902 L
.66331 .30902 L
.66353 .30902 L
.66423 .30902 L
.665 .30902 L
.66582 .30902 L
.66668 .30902 L
.66742 .30902 L
.66784 .30902 L
.66823 .30902 L
.66863 .30902 L
.669 .30902 L
.66921 .30902 L
Mistroke
.6694 .30902 L
.6695 .30902 L
.66961 .30902 L
.66967 .30902 L
.66973 .30902 L
.66978 .30902 L
.66983 .30902 L
.66993 .30902 L
.67003 .30902 L
.67012 .30902 L
.6702 .30902 L
.6703 .30902 L
.67041 .30902 L
.6706 .30902 L
.67079 .30902 L
.67098 .30902 L
.67133 .30902 L
.67293 .30902 L
.67362 .30902 L
.67438 .30902 L
.6748 .30902 L
.67519 .30902 L
.67556 .30902 L
.67595 .30902 L
.67615 .30902 L
.67636 .30902 L
.67656 .30902 L
.67675 .30902 L
.67685 .30902 L
.67695 .30902 L
.67701 .30902 L
.67706 .30902 L
.67712 .30902 L
.67718 .30902 L
.67723 .30902 L
.67729 .30902 L
.67739 .30902 L
.67745 .30902 L
.67751 .30902 L
.67763 .30902 L
.67784 .30902 L
.67803 .30902 L
.67847 .30902 L
.67926 .30902 L
.68075 .30902 L
.68147 .30902 L
.68224 .30902 L
.68269 .30902 L
.68288 .30902 L
.6831 .30902 L
Mistroke
.68328 .30902 L
.68348 .30902 L
.6837 .30902 L
.6839 .30902 L
.68399 .30902 L
.6841 .30902 L
.68416 .30902 L
.68422 .30902 L
.68432 .30902 L
.68443 .30902 L
.68453 .30902 L
.68462 .30902 L
.68472 .30902 L
.68483 .30902 L
.68494 .30902 L
.68518 .30902 L
.68561 .30902 L
.68722 .30902 L
.68797 .30902 L
.68877 .30902 L
.68918 .30902 L
.68964 .30902 L
.69005 .30902 L
.69044 .30902 L
.69065 .30902 L
.69084 .30902 L
.69095 .30902 L
.69105 .30902 L
.69116 .30902 L
.69122 .30902 L
.69128 .30902 L
.69137 .30902 L
.69148 .30902 L
.69157 .30902 L
.69166 .30902 L
.69176 .30902 L
.69186 .30902 L
.69197 .30902 L
.69207 .30902 L
.69244 .30902 L
.69279 .30902 L
.69356 .30902 L
.69435 .30902 L
.6952 .30902 L
.69599 .30902 L
.69672 .30902 L
.69711 .30902 L
.69747 .30902 L
.69768 .30902 L
.69787 .30902 L
Mistroke
.69797 .30902 L
.69808 .30902 L
.69819 .30902 L
.69829 .30902 L
.69837 .30902 L
.69846 .30902 L
.69855 .30902 L
.69863 .30902 L
.69872 .30902 L
.69882 .30902 L
.69892 .30902 L
.69901 .30902 L
.69918 .30902 L
.69937 .30902 L
.69977 .30902 L
.70145 .30902 L
.70219 .30902 L
.703 .30902 L
.70338 .30902 L
.70378 .30902 L
.70417 .30902 L
.70451 .30902 L
.70472 .30902 L
.70491 .30902 L
.70501 .30902 L
.70511 .30902 L
.70522 .30902 L
.70527 .30902 L
.70533 .30902 L
.70543 .30902 L
.70553 .30902 L
.70562 .30902 L
.70571 .30902 L
.7058 .30902 L
.7059 .30902 L
.70601 .30902 L
.70611 .30902 L
.70648 .30902 L
.70689 .30902 L
.70773 .30902 L
.70921 .30902 L
.70963 .30902 L
.71003 .30902 L
.7104 .30902 L
.71078 .30902 L
.71098 .30902 L
.7112 .30902 L
.7114 .30902 L
.71159 .30902 L
.71181 .30902 L
Mistroke
.71193 .30902 L
.71204 .30902 L
.71215 .30902 L
.71224 .30902 L
.7123 .30902 L
.71235 .30902 L
.71241 .30902 L
.71246 .30902 L
.71256 .30902 L
.71266 .30902 L
.71275 .30902 L
.71284 .30902 L
.71294 .30902 L
.71305 .30902 L
.71325 .30902 L
.71368 .30902 L
.71408 .30902 L
.71556 .30902 L
.71628 .30902 L
.71706 .30902 L
.7175 .30902 L
.71791 .30902 L
.7183 .30902 L
.7185 .30902 L
.71861 .30902 L
.71871 .30902 L
.71881 .30902 L
.71892 .30902 L
.71902 .30902 L
.71908 .30902 L
.71914 .30902 L
.71924 .30902 L
.71929 .30902 L
.71934 .30902 L
.71944 .30902 L
.71954 .30902 L
.71964 .30902 L
.71973 .30902 L
.71993 .30902 L
.72011 .30902 L
.72029 .30902 L
.7211 .30902 L
.72197 .30902 L
.7228 .30902 L
.72357 .30902 L
.724 .30902 L
.72438 .30902 L
.72481 .30902 L
.72504 .30902 L
.72527 .30902 L
Mistroke
.72546 .30902 L
.72564 .30902 L
.72574 .30902 L
.72583 .30902 L
.72589 .30902 L
.72594 .30902 L
.72604 .30902 L
.7261 .30902 L
.72615 .30902 L
.72625 .30902 L
.72636 .30902 L
.72642 .30902 L
.72647 .30902 L
.72656 .30902 L
.72667 .30902 L
.72687 .30902 L
.72724 .30902 L
.72764 .30902 L
.72835 .30902 L
.72994 .30902 L
.73037 .30902 L
.73084 .30902 L
.73123 .30902 L
.73144 .30902 L
.73167 .30902 L
.73187 .30902 L
.73208 .30902 L
.73228 .30902 L
.73246 .30902 L
.73257 .30902 L
.73268 .30902 L
.73277 .30902 L
.73288 .30902 L
.73293 .30902 L
.73299 .30902 L
.73305 .30902 L
.73311 .30902 L
.73321 .30902 L
.73327 .30902 L
.73332 .30902 L
.73351 .30902 L
.7337 .30902 L
.73411 .30902 L
.73487 .30902 L
.73638 .30902 L
.73679 .30902 L
.73723 .30902 L
.73761 .30902 L
.73801 .30902 L
.73823 .30902 L
Mistroke
.73844 .30902 L
.73864 .30902 L
.73883 .30902 L
.73905 .30902 L
.73917 .30902 L
.73929 .30902 L
.73935 .30902 L
.7394 .30902 L
.7395 .30902 L
.73956 .30902 L
.73962 .30902 L
.73967 .30902 L
.73973 .30902 L
.73978 .30902 L
.73984 .30902 L
.73994 .30902 L
.74004 .30902 L
.74014 .30902 L
.74035 .30902 L
.74057 .30902 L
.74135 .30902 L
.74294 .30902 L
.74364 .30902 L
.7444 .30902 L
.74481 .30902 L
.745 .30902 L
.7452 .30902 L
.74538 .30902 L
.74557 .30902 L
.74567 .30902 L
.74577 .30902 L
.74587 .30902 L
.74596 .30902 L
.74606 .30902 L
.74616 .30902 L
.74626 .30902 L
.74635 .30902 L
.7464 .30902 L
.74646 .30902 L
.74655 .30902 L
.74666 .30902 L
.74678 .30902 L
.74699 .30902 L
.74722 .30902 L
.74764 .30902 L
.74922 .30902 L
.75006 .30902 L
.75051 .30902 L
.75095 .30902 L
.75136 .30902 L
Mistroke
.75158 .30902 L
.75181 .30902 L
.75201 .30902 L
.75222 .30902 L
.75232 .30902 L
.75242 .30902 L
.75251 .30902 L
.7526 .30902 L
.7527 .30902 L
.7528 .30902 L
.7529 .30902 L
.75296 .30902 L
.75301 .30902 L
.75311 .30902 L
.7532 .30902 L
.7533 .30902 L
.7534 .30902 L
.75358 .30902 L
.75375 .30902 L
.75413 .30902 L
.75564 .30902 L
.75643 .30902 L
.75727 .30902 L
.75769 .30902 L
.75792 .30902 L
.75816 .30902 L
.75838 .30902 L
.75859 .30902 L
.75879 .30902 L
.75898 .30902 L
.75909 .30902 L
.75918 .30902 L
.75923 .30902 L
.75928 .30902 L
.75939 .30902 L
.75948 .30902 L
.75958 .30902 L
.75966 .30902 L
.75976 .30902 L
.75981 .30902 L
.75987 .30902 L
.75997 .30902 L
.76019 .30902 L
.76039 .30902 L
.7606 .30902 L
.76216 .30902 L
.76299 .30902 L
.76345 .30902 L
.76388 .30902 L
.76429 .30902 L
Mistroke
.7645 .30902 L
.76473 .30902 L
.76494 .30902 L
.76513 .30902 L
.76533 .30902 L
.76551 .30902 L
.7656 .30902 L
.76569 .30902 L
.7658 .30902 L
.76589 .30902 L
.76598 .30902 L
.76606 .30902 L
.76615 .30902 L
.76624 .30902 L
.76634 .30902 L
.76644 .30902 L
.76662 .30902 L
.76682 .30902 L
.76704 .30902 L
.76872 .30902 L
.76945 .30902 L
.76984 .30902 L
.77026 .30902 L
.77067 .30902 L
.77104 .30902 L
.77122 .30902 L
.77142 .30902 L
.7716 .30902 L
.77177 .30902 L
.77196 .30902 L
.77207 .30902 L
.77217 .30902 L
.77223 .30902 L
.77229 .30902 L
.77235 .30902 L
.7724 .30902 L
.7725 .30902 L
.7726 .30902 L
.7727 .30902 L
.77276 .30902 L
.77281 .30902 L
.7729 .30902 L
.773 .30902 L
.77317 .30902 L
.77336 .30902 L
.77418 .30902 L
.77493 .30902 L
.7758 .30902 L
.77619 .30902 L
.77661 .30902 L
Mistroke
.77697 .30902 L
.77736 .30902 L
.77757 .30902 L
.77776 .30902 L
.77795 .30902 L
.77815 .30902 L
.77825 .30902 L
.77835 .30902 L
.77844 .30902 L
.77853 .30902 L
.77864 .30902 L
.77869 .30902 L
.77875 .30902 L
.77885 .30902 L
.77891 .30902 L
.77896 .30902 L
.77901 .30902 L
.77907 .30902 L
.77917 .30902 L
.77928 .30902 L
.77937 .30902 L
.77958 .30902 L
.77981 .30902 L
.78142 .30902 L
.78227 .30902 L
.78273 .30902 L
.78316 .30902 L
.78354 .30902 L
.78396 .30902 L
.78419 .30902 L
.78442 .30902 L
.78462 .30902 L
.78473 .30902 L
.78484 .30902 L
.78493 .30902 L
.78502 .30902 L
.78512 .30902 L
.78523 .30902 L
.78533 .30902 L
.78538 .30902 L
.78544 .30902 L
.78553 .30902 L
.78564 .30902 L
.78573 .30902 L
.78584 .30902 L
.78603 .30902 L
.78638 .30902 L
.78795 .30902 L
.78878 .30902 L
.78924 .30902 L
Mistroke
.78967 .30902 L
.79008 .30902 L
.7903 .30902 L
.79053 .30902 L
.79072 .30902 L
.79093 .30902 L
.79103 .30902 L
.79113 .30902 L
.79122 .30902 L
.79131 .30902 L
.79141 .30902 L
.79149 .30902 L
.79155 .30902 L
.7916 .30902 L
.7917 .30902 L
.7918 .30902 L
.79189 .30902 L
.792 .30902 L
.79211 .30902 L
.79229 .30902 L
.79246 .30902 L
.79284 .30902 L
.79433 .30902 L
.79512 .30902 L
.79555 .30902 L
.79596 .30902 L
.79618 .30902 L
.79642 .30902 L
.79684 .30902 L
.79704 .30902 L
.79726 .30902 L
.79745 .30902 L
.79756 .30902 L
.79765 .30902 L
.79776 .30902 L
.79781 .30902 L
.79786 .30902 L
.79796 .30902 L
.79806 .30902 L
.79815 .30902 L
.79824 .30902 L
.79833 .30902 L
.79843 .30902 L
.79865 .30902 L
.79887 .30902 L
.79927 .30902 L
.80087 .30902 L
.80157 .30902 L
.80194 .30902 L
.80233 .30902 L
Mistroke
.80275 .30902 L
.80295 .30902 L
.80314 .30902 L
.80333 .30902 L
.80351 .30902 L
.8037 .30902 L
.80381 .30902 L
.80391 .30902 L
.804 .30902 L
.80406 .30902 L
.80411 .30902 L
.80421 .30902 L
.80427 .30902 L
.80433 .30902 L
.80442 .30902 L
.80451 .30902 L
.80462 .30902 L
.80471 .30902 L
.80494 .30902 L
.80514 .30902 L
.80559 .30902 L
.8064 .30902 L
.80726 .30902 L
.80799 .30902 L
.80841 .30902 L
.8088 .30902 L
.80899 .30902 L
.8092 .30902 L
.80938 .30902 L
.80957 .30902 L
.80977 .30902 L
.80994 .30902 L
.81003 .30902 L
.81012 .30902 L
.8102 .30902 L
.81028 .30902 L
.81038 .30902 L
.81048 .30902 L
.81057 .30902 L
.81065 .30902 L
.81075 .30902 L
.81086 .30902 L
.81106 .30902 L
.81149 .30902 L
.81188 .30902 L
.81266 .30902 L
.81351 .30902 L
.8139 .30902 L
.8143 .30902 L
.81469 .30902 L
Mistroke
.81503 .30902 L
.8154 .30902 L
.8156 .30902 L
.81579 .30902 L
.81596 .30902 L
.81612 .30902 L
.8162 .30902 L
.8163 .30902 L
.81639 .30902 L
.81648 .30902 L
.81658 .30902 L
.81664 .30902 L
.81669 .30902 L
.81678 .30902 L
.81688 .30902 L
.81698 .30902 L
.81707 .30902 L
.81725 .30902 L
.81764 .30902 L
.81807 .30902 L
.81964 .30902 L
.82007 .30902 L
.82053 .30902 L
.82097 .30902 L
.82136 .30902 L
.82156 .30902 L
.82177 .30902 L
.82195 .30902 L
.82215 .30902 L
.82226 .30902 L
.82236 .30902 L
.82241 .30902 L
.82247 .30902 L
.82253 .30902 L
.82258 .30902 L
.82269 .30902 L
.82278 .30902 L
.82284 .30902 L
.82289 .30902 L
.82299 .30902 L
.82309 .30902 L
.82318 .30902 L
.82339 .30902 L
.8238 .30902 L
.82454 .30902 L
.82526 .30902 L
.82603 .30902 L
.82643 .30902 L
.82688 .30902 L
.82728 .30902 L
Mistroke
.82766 .30902 L
.82787 .30902 L
.82809 .30902 L
.82827 .30902 L
.82838 .30902 L
.82848 .30902 L
.82853 .30902 L
.82859 .30902 L
.82865 .30902 L
.8287 .30902 L
.8288 .30902 L
.82891 .30902 L
.82896 .30902 L
.82902 .30902 L
.82912 .30902 L
.82925 .30902 L
.82936 .30902 L
.82976 .30902 L
.83019 .30902 L
.83098 .30902 L
.83179 .30902 L
.83256 .30902 L
.83298 .30902 L
.83321 .30902 L
.83344 .30902 L
.83364 .30902 L
.83386 .30902 L
.83406 .30902 L
.83424 .30902 L
.83435 .30902 L
.83445 .30902 L
.83455 .30902 L
.83465 .30902 L
.8347 .30902 L
.83476 .30902 L
.83481 .30902 L
.83487 .30902 L
.83497 .30902 L
.83503 .30902 L
.83508 .30902 L
.83519 .30902 L
.83529 .30902 L
.83547 .30902 L
.83588 .30902 L
.83737 .30902 L
.83815 .30902 L
.83858 .30902 L
.83898 .30902 L
.83932 .30902 L
.83968 .30902 L
Mistroke
.83989 .30902 L
.84009 .30902 L
.84027 .30902 L
.84037 .30902 L
.84046 .30902 L
.84055 .30902 L
.84065 .30902 L
.84074 .30902 L
.84085 .30902 L
.84094 .30902 L
.84104 .30902 L
.84113 .30902 L
.84121 .30902 L
.84132 .30902 L
.84142 .30902 L
.84164 .30902 L
.84204 .30902 L
.84291 .30902 L
.84373 .30902 L
.84445 .30902 L
.84486 .30902 L
.84523 .30902 L
.84564 .30902 L
.84587 .30902 L
.84608 .30902 L
.84619 .30902 L
.84629 .30902 L
.84638 .30902 L
.84647 .30902 L
.84658 .30902 L
.84667 .30902 L
.84678 .30902 L
.84683 .30902 L
.84689 .30902 L
.84699 .30902 L
.84704 .30902 L
.8471 .30902 L
.8472 .30902 L
.84729 .30902 L
.8475 .30902 L
.84773 .30902 L
.84852 .30902 L
.85001 .30902 L
.85038 .30902 L
.85078 .30902 L
.85122 .30902 L
.85162 .30902 L
.85184 .30902 L
.85196 .30902 L
.85208 .30902 L
Mistroke
.85218 .30902 L
.8523 .30902 L
.85241 .30902 L
.85251 .30902 L
.85261 .30902 L
.85271 .30902 L
.8528 .30902 L
.8529 .30902 L
.853 .30902 L
.85306 .30902 L
.85311 .30902 L
.85331 .30902 L
.8535 .30902 L
.85371 .30902 L
.85412 .30902 L
.85486 .30902 L
.85574 .30902 L
.85654 .30902 L
.85692 .30902 L
.85713 .30902 L
.85734 .30902 L
.85753 .30902 L
.85774 .30902 L
.85793 .30902 L
.8581 .30902 L
.8582 .30902 L
.85831 .30902 L
.85836 .30902 L
.85842 .30902 L
.85853 .30902 L
.85863 .30902 L
.85873 .30902 L
.85882 .30902 L
.85891 .30902 L
.85902 .30902 L
.85913 .30902 L
.85937 .30902 L
.85978 .30902 L
.86066 .30902 L
.86148 .30902 L
.86222 .30902 L
.86264 .30902 L
.86303 .30902 L
.86321 .30902 L
.8634 .30902 L
.86356 .30902 L
.86375 .30902 L
.86395 .30902 L
.86406 .30902 L
.86416 .30902 L
Mistroke
.86426 .30902 L
.86434 .30902 L
.86444 .30902 L
.86454 .30902 L
.86463 .30902 L
.86473 .30902 L
.86479 .30902 L
.86484 .30902 L
.86494 .30902 L
.86513 .30902 L
.86531 .30902 L
.86615 .30902 L
.86695 .30902 L
.8678 .30902 L
.86822 .30902 L
.86861 .30902 L
.86896 .30902 L
.86915 .30902 L
.86934 .30902 L
.86953 .30902 L
.86971 .30902 L
.8699 .30902 L
.87001 .30902 L
.87011 .30902 L
.87021 .30902 L
.87032 .30902 L
.87041 .30902 L
.87051 .30902 L
.87056 .30902 L
.87061 .30902 L
.87067 .30902 L
.87073 .30902 L
.87094 .30902 L
.87111 .30902 L
.8713 .30902 L
.87164 .30902 L
.8724 .30902 L
.87323 .30902 L
.87366 .30902 L
.87412 .30902 L
.87452 .30902 L
.87473 .30902 L
.87496 .30902 L
.87517 .30902 L
.87536 .30902 L
.87556 .30902 L
.87574 .30902 L
.87584 .30902 L
.87589 .30902 L
.87595 .30902 L
Mistroke
.87605 .30902 L
.87614 .30902 L
.87623 .30902 L
.87632 .30902 L
.87641 .30902 L
.87651 .30902 L
.87662 .30902 L
.87673 .30902 L
.87694 .30902 L
.87733 .30902 L
.87881 .30902 L
.87957 .30902 L
.88 .30902 L
.8804 .30902 L
.88062 .30902 L
.88083 .30902 L
.88101 .30902 L
.88121 .30902 L
.88133 .30902 L
.88143 .30902 L
.88154 .30902 L
.88163 .30902 L
.88169 .30902 L
.88175 .30902 L
.8818 .30902 L
.88187 .30902 L
.88192 .30902 L
.88198 .30902 L
.88204 .30902 L
.88209 .30902 L
.88218 .30902 L
.88227 .30902 L
.88237 .30902 L
.88247 .30902 L
.88288 .30902 L
.88362 .30902 L
.88442 .30902 L
.88484 .30902 L
.88529 .30902 L
.88572 .30902 L
.88612 .30902 L
.88631 .30902 L
.88652 .30902 L
.88671 .30902 L
.88689 .30902 L
.8871 .30902 L
.88721 .30902 L
.88732 .30902 L
.88738 .30902 L
.88744 .30902 L
Mistroke
.8875 .30902 L
.88756 .30902 L
.88766 .30902 L
.88772 .30902 L
.88778 .30902 L
.88788 .30902 L
.88798 .30902 L
.88808 .30902 L
.88819 .30902 L
.88838 .30902 L
.88859 .30902 L
.88946 .30902 L
.89029 .30902 L
.89103 .30902 L
.89145 .30902 L
.89184 .30902 L
.89202 .30902 L
.89221 .30902 L
.89238 .30902 L
.89256 .30902 L
.89276 .30902 L
.89287 .30902 L
.89297 .30902 L
.89307 .30902 L
.89316 .30902 L
.89326 .30902 L
.89335 .30902 L
.89345 .30902 L
.89355 .30902 L
.8936 .30902 L
.89366 .30902 L
.89376 .30902 L
.89386 .30902 L
.89395 .30902 L
.89413 .30902 L
.89453 .30902 L
.89496 .30902 L
.89571 .30902 L
.89652 .30902 L
.89698 .30902 L
.8974 .30902 L
.89781 .30902 L
.89801 .30902 L
.89823 .30902 L
.89834 .30902 L
.89845 .30902 L
.89854 .30902 L
.89865 .30902 L
.89874 .30902 L
.89884 .30902 L
Mistroke
.89893 .30902 L
.89902 .30902 L
.89907 .30902 L
.89913 .30902 L
.89923 .30902 L
.89933 .30902 L
.89943 .30902 L
.89954 .30902 L
.89964 .30902 L
.89986 .30902 L
.90065 .30902 L
.90138 .30902 L
.90217 .30902 L
.90256 .30902 L
.90299 .30902 L
.90336 .30902 L
.90357 .30902 L
.90376 .30902 L
.90394 .30902 L
.90403 .30902 L
.90413 .30902 L
.90422 .30902 L
.90431 .30902 L
.9044 .30902 L
.90448 .30902 L
.90457 .30902 L
.90467 .30902 L
.90477 .30902 L
.90485 .30902 L
.90496 .30902 L
.90501 .30902 L
.90507 .30902 L
.90527 .30902 L
.90546 .30902 L
.90567 .30902 L
.9061 .30902 L
.90758 .30902 L
.908 .30902 L
.9084 .30902 L
.90876 .30902 L
.90915 .30902 L
.90937 .30902 L
.90957 .30902 L
.90968 .30902 L
.9098 .30902 L
.90991 .30902 L
.91002 .30902 L
.91011 .30902 L
.9102 .30902 L
.9103 .30902 L
Mistroke
.91041 .30902 L
.91046 .30902 L
.91052 .30902 L
.91063 .30902 L
.91073 .30902 L
.91082 .30902 L
.9112 .30902 L
.9116 .30902 L
.91232 .30902 L
.91318 .30902 L
.9136 .30902 L
.91398 .30902 L
.91437 .30902 L
.91479 .30902 L
.91501 .30902 L
.91512 .30902 L
.91525 .30902 L
.91535 .30902 L
.91547 .30902 L
.91558 .30902 L
.91567 .30902 L
.91577 .30902 L
.91583 .30902 L
.91588 .30902 L
.91598 .30902 L
.91608 .30902 L
.91617 .30902 L
.91626 .30902 L
.91645 .30902 L
.91666 .30902 L
.91685 .30902 L
.91729 .30902 L
.91808 .30902 L
.91852 .30902 L
.91893 .30902 L
.91932 .30902 L
.91974 .30902 L
.92012 .30902 L
.92047 .30902 L
.92064 .30902 L
.92083 .30902 L
.92092 .30902 L
.92101 .30902 L
.92109 .30902 L
.92117 .30902 L
.92127 .30902 L
.92137 .30902 L
.92146 .30902 L
.92154 .30902 L
.92165 .30902 L
Mistroke
.92174 .30902 L
.92184 .30902 L
.92195 .30902 L
.92234 .30902 L
.9227 .30902 L
.92352 .30902 L
.92436 .30902 L
.92478 .30902 L
.92516 .30902 L
.9255 .30902 L
.92587 .30902 L
.92606 .30902 L
.92624 .30902 L
.92644 .30902 L
.92655 .30902 L
.92665 .30902 L
.92675 .30902 L
.92685 .30902 L
.92694 .30902 L
.92703 .30902 L
.92713 .30902 L
.92718 .30902 L
.92724 .30902 L
.92734 .30902 L
.92744 .30902 L
.92779 .30902 L
.92817 .30902 L
.92903 .30902 L
.92983 .30902 L
.93026 .30902 L
.93065 .30902 L
.93108 .30902 L
.93131 .30902 L
.93153 .30902 L
.93173 .30902 L
.93184 .30902 L
.93194 .30902 L
.93203 .30902 L
.93212 .30902 L
.93221 .30902 L
.93231 .30902 L
.93236 .30902 L
.93242 .30902 L
.93252 .30902 L
.93257 .30902 L
.93262 .30902 L
.93268 .30902 L
.93274 .30902 L
.93285 .30902 L
.93295 .30902 L
Mistroke
.93315 .30902 L
.93475 .30902 L
.93546 .30902 L
.93582 .30902 L
.93621 .30902 L
.93641 .30902 L
.93664 .30902 L
.93684 .30902 L
.93703 .30902 L
.93722 .30902 L
.93732 .30902 L
.93742 .30902 L
.93752 .30902 L
.93761 .30902 L
.9377 .30902 L
.93779 .30902 L
.9379 .30902 L
.93799 .30902 L
.93809 .30902 L
.93815 .30902 L
.9382 .30902 L
.9383 .30902 L
.93841 .30902 L
.93859 .30902 L
.93905 .30902 L
.93948 .30902 L
.94022 .30902 L
.94102 .30902 L
.94143 .30902 L
.94165 .30902 L
.94188 .30902 L
.9421 .30902 L
.9423 .30902 L
.9425 .30902 L
.94268 .30902 L
.94278 .30902 L
.94289 .30902 L
.943 .30902 L
.94309 .30902 L
.94317 .30902 L
.94327 .30902 L
.94337 .30902 L
.94346 .30902 L
.94351 .30902 L
.94356 .30902 L
.94366 .30902 L
.94376 .30902 L
.94385 .30902 L
.94428 .30902 L
.94575 .30902 L
Mistroke
.94613 .30902 L
.94653 .30902 L
.94688 .30902 L
.94726 .30902 L
.94746 .30902 L
.94768 .30902 L
.94791 .30902 L
.94812 .30902 L
.94822 .30902 L
.94833 .30902 L
.94844 .30902 L
.94853 .30902 L
.94862 .30902 L
.94872 .30902 L
.94882 .30902 L
.94891 .30902 L
.94901 .30902 L
.94906 .30902 L
.94912 .30902 L
.94931 .30902 L
.94954 .30902 L
.94975 .30902 L
.95054 .30902 L
.95125 .30902 L
.95203 .30902 L
.95244 .30902 L
.95282 .30902 L
.95303 .30902 L
.95322 .30902 L
.95333 .30902 L
.95344 .30902 L
.95355 .30902 L
.95365 .30902 L
.95374 .30902 L
.95383 .30902 L
.95392 .30902 L
.95402 .30902 L
.95412 .30902 L
.95418 .30902 L
.95423 .30902 L
.95432 .30902 L
.95442 .30902 L
.95451 .30902 L
.95461 .30902 L
.95479 .30902 L
.95513 .30902 L
.9567 .30902 L
.95713 .30902 L
.95759 .30902 L
.95782 .30902 L
Mistroke
.95803 .30902 L
.95822 .30902 L
.95843 .30902 L
.95862 .30902 L
.95881 .30902 L
.959 .30902 L
.95911 .30902 L
.95922 .30902 L
.9593 .30902 L
.95939 .30902 L
.95948 .30902 L
.95957 .30902 L
.95967 .30902 L
.95977 .30902 L
.95985 .30902 L
.95995 .30902 L
.96014 .30902 L
.96036 .30902 L
.9608 .30902 L
.9616 .30902 L
.96198 .30902 L
.9624 .30902 L
.96277 .30902 L
.96316 .30902 L
.9634 .30902 L
.96361 .30902 L
.96382 .30902 L
.96404 .30902 L
.96414 .30902 L
.96425 .30902 L
.96435 .30902 L
.96445 .30902 L
.96454 .30902 L
.96463 .30902 L
.96469 .30902 L
.96474 .30902 L
.96484 .30902 L
.96493 .30902 L
.96503 .30902 L
.96512 .30902 L
.96521 .30902 L
.96542 .30902 L
.96561 .30902 L
.96644 .30902 L
.96722 .30902 L
.96792 .30902 L
.96831 .30902 L
.96869 .30902 L
.96888 .30902 L
.96908 .30902 L
Mistroke
.9693 .30902 L
.96941 .30902 L
.96951 .30902 L
.96968 .30902 L
.96978 .30902 L
.96987 .30902 L
.96996 .30902 L
.97003 .30902 L
.97012 .30902 L
.97021 .30902 L
.9703 .30902 L
.9704 .30902 L
.97049 .30902 L
.97058 .30902 L
.97078 .30902 L
.97098 .30902 L
.97246 .30902 L
.97289 .30902 L
.97329 .30902 L
.97365 .30902 L
.97404 .30902 L
.9743 .30902 L
.97458 .30902 L
.97473 .30902 L
.97488 .30902 L
.97496 .30902 L
.97503 .30902 L
.9751 .30902 L
.97516 .30902 L
.97522 .30902 L
.97528 .30902 L
.97535 .30902 L
.97542 .30902 L
.97548 .30902 L
.97554 .30902 L
.97559 .30902 L
.97565 .30902 L
.97572 .30902 L
.97579 .30902 L
.97593 .30902 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{421.375, 260.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008>0001AB000`400?l00000o`00003ooooooooo
oooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo
003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooo
oooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool0
0?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooooooo
ool@ooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooo
ooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo0ol0003o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0
003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo
00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`
ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLoooo
o`00<?ooool3o`000?oooooog?ooool0033ooooo00?o0000ooooooooool0D?ooool00ol0003ooooo
ooooo`3oooooohWooooo000`ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0oooo
oon9ooooo`00<?ooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo0?ooooooROooool0
033ooooo00?o0000ooooooooool0D?ooool2o`000?ooooooR_ooool0033ooooo00?o0000oooooooo
ool0D?ooool2o`000?ooooooR_ooool0033ooooo00?o0000ooooooooool0D?ooool2o`000?oooooo
R_ooool0033ooooo00?o0000ooooooooool0D?ooool2o`000?ooooooR_ooool0033ooooo00?o0000
ooooooooool0D?ooool2o`000?ooooooR_ooool0033ooooo00?o0000ooooooooool0D?ooool2o`00
0?ooooooR_ooool0033ooooo00?o0000ooooooooool0D?ooool2o`000?ooooooR_ooool0033ooooo
0ol0001?ooooo`03o`000?oooooo00000?ooooooR_ooool0033ooooo00?o0000ooooooooool0Cooo
ool00ol0003oooooo`00003ooooooh[ooooo000`ooooo`03o`000?oooooooooo04oooooo00?o0000
ooooool00000oooooon:ooooo`00<?ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooo0000
0?ooooooR_ooool0033ooooo00?o0000ooooooooool0Coooool00ol0003oooooo`00003ooooooh[o
oooo000`ooooo`03o`000?oooooooooo04oooooo00?o0000ooooool00000oooooon:ooooo`00<?oo
ool00ol0003oooooooooo`1?ooooo`03o`000?oooooo00000?ooooooR_ooool0013ooooo0_o^k^h3
ooooo`;ok^k^6Oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooo00000?ooooooR_ooool0
00_ooooo0_l000002_l@413oooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h3ooooo`Co
000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP[ooooo00?o0000ooooooooool0Cooo
ool00ol0003oooooo`00003ooooooh[ooooo000<ooooo`03o`000?oooooooooo00;ooooo00Gok^k^
oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0:ooooo`03o`000?oooooooooo04oooooo00?o0000ooooool00000oooooon:ooooo`0000?o
ooooo`000?l000001?l00002ooooo`Go00001?ooool00ooMgMgo0000omgMg@07ooooo`03o`000?oo
oooooooo00;ooooo00Go410@oooooooooooooooooa0@400:ooooo`03o`000?oooooooooo04oooooo
00?o0000ooooool00000oooooon:ooooo`002Oooool01?m4A4CogMgMooooool00004ooooo`05onk^
k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000002_ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ool00000oooooon:ooooo`002Oooool01?oMgMgoEEEEooooool00003ooooo`07onk^k_mEEEGok^k^
ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000:ooooo`Co0000@oooool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`000?oo
ooooROooool000[ooooo00?oMgMgolc<c?l000000oooool2onk^kP?ooooo0_o^k^h5ooooo`03o`00
0?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400:ooooo`03o`000?oooooooooo04Co
oooo0_l00009ooooo`04o`000?ooooooooooo`000?ooooooROooool000[ooooo00?ok^k^odA4A?l0
00003oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool2o`00
00Gooooo00?o0000ooooooooool0A?ooool2o`0000Wooooo00Co0000oooooooooooo0000oooooon9
ooooo`002oooool00omgMgOo0000ooooo`0<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP02ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0A?oo
ool2o`0000Wooooo00Co0000oooooooooooo00002?ooool2o`000?ooooooOoooool002Sooooo00Co
0000oooooooooooo00001?ooool00ol0003oooooooooo`14ooooo`;o00002Oooool01?l0003ooooo
ooooool00008ooooo`;o0000oooooomoooooo`00:?ooool3o`0000Gooooo00?o0000ooooooooool0
A?ooool2o`0000Wooooo00Co0000oooooooooooo00002?ooool2o`000?ooooooOoooool002Wooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`14ooooo`;o00002Oooool01?l0003ooooo
ooooool00008ooooo`;o0000oooooomoooooo`00:_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo04Cooooo0_l00009ooooo`04o`000?ooooooooooo`0000Sooooo0_l0003oooooogoo
oooo000`ooooo`03o`000?oooooooooo04Cooooo0_l00009ooooo`04o`000?ooooooooooo`0000So
oooo0_l0003oooooogoooooo000`ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooool00000
2Oooool01?l0003oooooooooool00008ooooo`;o0000oooooomoooooo`00<?ooool00ol0003ooooo
ooooo`13ooooo`03o`000?oooooo000000Wooooo00Co0000oooooooooooo00002?ooool2o`000?oo
ooooOoooool0033ooooo00?o0000ooooooooool0@oooool00ol0003oooooo`000009ooooo`04o`00
0?ooooooooooo`0000Sooooo0_l0003oooooogoooooo000`ooooo`?o0000@oooool00ol0003ooooo
o`000009ooooo`04o`000?ooooooooooo`0000Sooooo0_l0003oooooogoooooo000`ooooo`03o`00
0?oooooooooo04?ooooo00?o0000ooooool000002Oooool01?l0003oooooooooool00008ooooo`;o
0000oooooomoooooo`00<?ooool00ol0003oooooooooo`13ooooo`03o`000?oooooo000000Wooooo
00Co0000oooooooooooo00002?ooool2o`000?ooooooOoooool0033ooooo00?o0000ooooooooool0
@oooool00ol0003oooooo`000009ooooo`04o`000?ooooooooooo`0000Sooooo0_l0003oooooogoo
oooo000`ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooool000002Oooool01?l0003ooooo
ooooool00008ooooo`03o`000?oooooo00000?ooooooO_ooool0033ooooo00?o0000ooooooooool0
@oooool00ol0003oooooo`000009ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool0
0000oooooomnooooo`00<?ooool00ol0003oooooooooo`13ooooo`03o`000?oooooo000000Wooooo
00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003oooooogkooooo000`ooooo`03o`00
0?oooooooooo04?ooooo00?o0000ooooool000002Oooool01?l0003oooooooooool00008ooooo`03
o`000?oooooo00000?ooooooO_ooool0033ooooo00?o0000ooooooooool0@oooool01?l0003ooooo
ooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooomnoooo
o`00<?ooool00ol0003oooooooooo`13ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooo
oooooooo00001oooool01?l0003oooooooooool0003oooooogkooooo000`ooooo`03o`000?oooooo
oooo04?ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00007ooooo`04o`00
0?ooooooooooo`000?ooooooO_ooool0033ooooo00?o0000ooooooooool0@oooool01?l0003ooooo
ooooool00008ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo0000oooooomn
ooooo`00<?ooool3o`0004?ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0
0007ooooo`04o`000?ooooooooooo`000?ooooooO_ooool0033ooooo00?o0000ooooooooool0@ooo
ool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooo
oooo0000oooooomnooooo`00<?ooool00ol0003oooooooooo`13ooooo`04o`000?ooooooooooo`00
00Sooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool0003oooooogkooooo000`
ooooo`03o`000?oooooooooo04?ooooo00Co0000oooooooooooo00002?ooool01?l0003ooooooooo
ool00007ooooo`04o`000?ooooooooooo`000?ooooooO_ooool0033ooooo00?o0000ooooooooool0
@oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooo
oooooooo0000oooooomnooooo`00<?ooool00ol0003oooooooooo`13ooooo`04o`000?oooooooooo
o`0000Sooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool0003oooooogkooooo
000`ooooo`03o`000?oooooooooo04?ooooo00Co0000oooooooooooo00002?ooool01?l0003ooooo
ooooool00007ooooo`04o`000?ooooooooooo`000?ooooooO_ooool0033ooooo00?o0000oooooooo
ool0@_ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007
ooooo`04o`000?ooooooooooo`000?ooooooO_ooool0033ooooo00?o0000ooooooooool0@_ooool0
1Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04o`00
0?ooooooooooo`000?ooooooO_ooool0033ooooo00?o0000ooooooooool0@_ooool01Ol0003ooooo
oooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?oooooooooo
o`000?ooooooO_ooool0033ooooo00?o0000ooooooooool0@_ooool01Ol0003ooooooooooooooooo
000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`000?oooooo
O_ooool0033ooooo0ol00012ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooo
oooooooooooo000000Oooooo00Co0000oooooooooooo0000oooooomnooooo`00<?ooool00ol0003o
ooooooooo`12ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo
000000Oooooo00Co0000oooooooooooo0000oooooomnooooo`00<?ooool00ol0003oooooooooo`12
ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo
00Co0000oooooooooooo0000oooooomnooooo`00<?ooool00ol0003oooooooooo`12ooooo`05o`00
0?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooo
oooooooo0000oooooomnooooo`00<?ooool00ol0003oooooooooo`12ooooo`05o`000?oooooooooo
ooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000
oooooomnooooo`00<?ooool00ol0003oooooooooo`12ooooo`05o`000?ooooooooooooooool00000
1oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000oooooomnoooo
o`00<?ooool00ol0003oooooooooo`12ooooo`05o`000?ooooooooooooooool000001oooool01Ol0
003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000oooooomnooooo`004?ooool2
onk^kP?ooooo0_o^k^hIooooo`03o`000?oooooooooo04;ooooo00Go0000ooooooooooooooooo`00
0007ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool0003oooooogko
oooo0009ooooo`Go00000_ooool01oo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`00
0008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h:ooooo`03o`000?oooooooooo04;ooooo
00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool01?l0
003oooooooooool0003oooooogkooooo0009ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool0
1Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00[ooooo00?o0000ooooooooool0@_ooool01Ol0003ooooooooooooooooo000000Oo
oooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000
ooooooooool0oooooomcooooo`0000?oooooo`000?l000001?l00003ooooo`03oiRHV?lQ8B7ok^k^
00Gooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@41002_ooool00ol0003oooooooooo`12ooooo`05o`000?ooooooooooooooool000001ooo
ool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo00002?ooool2o`000?oo
ooooM?ooool000_ooooo00?oV9RHob4Q8Oo^k^h00oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Ko
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000[ooooo00?o0000oooo
ooooool0@_ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`00
0007ooooo`04o`000?ooooooooooo`0000Sooooo0_l0003oooooogCooooo000<ooooo`0;ogMgMomV
IVKoooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000002_ooool4o`00047ooooo00Go0000oooooooooooooooo
o`000007ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool00008oooo
o`;o0000oooooomdooooo`003Oooool00ol0003oooooooooo`02onk^kP?ooooo0_o^k^h5ooooo`03
o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400:ooooo`03o`000?oooooooooo
04;ooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001ooo
ool01?l0003oooooooooool00008ooooo`;o0000oooooomdooooo`002Oooool01Ol0003o^[Zjoooo
oonHV9So410@00kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo0_l00005ooooo`03o`000?oooooooooo03Oooooo0_l00009ooooo`05o`000?oooooooooooooo
ool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo00002?oo
ool2o`000?ooooooM?ooool000Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00<ooooo`03oeEEEOmV
IVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`04o`000?ooooooooooo`0000Co
oooo00?o0000ooooooooool0=oooool2o`0000Wooooo00Go0000ooooooooooooooooo`000007oooo
o`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool00007ooooo`03o`000?oo
oooo00000?ooooooM?ooool002Sooooo00Co0000oooooooooooo00001?ooool00ol0003ooooooooo
o`0gooooo`;o00002Oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooooooooooo
ooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool00000oooooomdoooo
o`00:?ooool3o`0000Gooooo00?o0000ooooooooool0=oooool2o`0000Wooooo00Go0000oooooooo
ooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool0
0007ooooo`03o`000?oooooo00000?ooooooM?ooool002Wooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0gooooo`;o00002Oooool01Ol0003ooooooooooooooooo000000Oooooo00Go
0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool0
0000oooooomdooooo`00:_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Oooooo
0_l00009ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo0000
00Oooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00003oooooogCooooo000`oooo
o`03o`000?oooooooooo03Kooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooo
oooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oo
oooo00?o0000ooooool00000oooooomdooooo`00<?ooool00ol0003oooooooooo`0fooooo`04o`00
0?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooooooo
ooooool000001oooool01?l0003oooooooooool00007ooooo`03o`000?oooooo00000?ooooooM?oo
ool0033ooooo00?o0000ooooooooool0=_ooool01?l0003oooooooooool00008ooooo`05o`000?oo
ooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000oooooooo
ooooooooo`000007ooooo`03o`000?oooooo00000?ooooooM?ooool0033ooooo00?o0000oooooooo
ool0=_ooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool000001oooool0
1Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000007ooooo`03o`00
0?oooooo00000?ooooooM?ooool0033ooooo0ol0000fooooo`04o`000?ooooooooooo`0000Sooooo
00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0
003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000oooooomcooooo`00<?ooool0
0ol0003oooooooooo`0fooooo`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooooooooooo
o`000007ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Cooooo00Co0000oooooooooooo0000oooooomcooooo`00<?ooool00ol0003o
ooooooooo`0fooooo`04o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000007
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00Co0000oooooooooooo0000oooooomcooooo`00<?ooool00ol0003ooooooooo
o`0fooooo`04o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000007ooooo`05
o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00Co0000oooooooooooo0000oooooomcooooo`00<?ooool00ol0003oooooooooo`0foooo
o`04o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00Co0000oooooooooooo0000oooooomcooooo`00<?ooool00ol0003ooooooooo
o`0fooooo`04o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000007ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Cooooo00Co0000oooooooooooo0000oooooomcooooo`00<?ooool00ol0003o
ooooooooo`0eooooo`05o`000?ooooooooooooooool000002?ooool01Ol0003ooooooooooooooooo
000000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0003oooooog?ooooo000`
ooooo`03o`000?oooooooooo03Gooooo00Go0000ooooooooooooooooo`000008ooooo`05o`000?oo
ooooooooooooool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`000?oo
ooooLoooool0033ooooo00?o0000ooooooooool0=Oooool01Ol0003ooooooooooooooooo000000So
oooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Co0000oooo
oooooooo0000oooooomcooooo`00<?ooool00ol0003oooooooooo`0eooooo`05o`000?oooooooooo
ooooool000002?ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool01?l0003oooooooooool0003oooooog?ooooo000`ooooo`03o`000?oooooooooo03Gooooo00Go
0000ooooooooooooooooo`000008ooooo`05o`000?ooooooooooooooool000001oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`04o`000?ooooooooooo`000?ooooooLoooool0033ooooo00?o0000oooooooo
ool0=Oooool01Ol0003ooooooooooooooooo000000Sooooo00Go0000ooooooooooooooooo`000007
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo0000oooooomcooooo`00<?ooool3
o`0003Gooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`000?oooooo
Loooool0033ooooo00?o0000ooooooooool0=Oooool01Ol0003ooooooooooooooooo000000Sooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
00Go0000ooooooooooooooooo`00003oooooog?ooooo000`ooooo`03o`000?oooooooooo03Gooooo
00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool00000oooooomcoooo
o`00<?ooool00ol0003oooooooooo`0eooooo`05o`000?ooooooooooooooool000002?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0
003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0oooooomXooooo`00<?ooool00ol0
003oooooooooo`0eooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0
003ooooooooooooooooo000000Oooooo0_l0003oooooof[ooooo000`ooooo`03o`000?oooooooooo
03Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool00ol0003ok^k^ooooo`02ooooo`03o`000?o^k^kooooo
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooooooo
ooooool000001oooool2o`0003[ooooo0_o^k^h3ooooo`;ok^k^H?ooool2onk^kP?ooooo0_o^k^i>
ooooo`;ok^k^0oooool2onk^kVcooooo000`ooooo`03o`000?oooooooooo03Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00ko0000odA4
A?l0003o0000oc8b<_oMgMgoooooo`000?mEEEGok^k^ooooooo^k^ko0000onk^kP?ooooo1?l00000
2Ol@413oooooo`000?o^k^ko<S8bo`000?lb<S;ok^k^o`000003ooooo`03o`000?oooooooooo00Go
oooo0_l0000dooooo`Co000000Wo410@ooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00ooo
ool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hkooooo`Co000000?o410@oooo
ooooool00_ooool2ob4Q8@Gooooo00goA4A4o`000?l0003o<S8bomgMgOooooook^k^oeEEEOo^k^ko
ooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^
>?ooool5o`0000;ooooo00Ook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@
413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^GOooool0033ooooo00?o0000ooooooooool0=Ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_oo
ool03Ol0003oooooooooooooooooMgMgoc8b<_oooooo0000onk^k_mEEEGogMgMoeEEEOl000001Ooo
ool2o`0000?ooooo00Oo0000ogMgMonHV9SooooooiRHV?mgMgOo000000?ooooo00?o0000oooooooo
ool01Oooool2o`0003Kooooo00?o0000ooooooooool00_ooool01Oo^k^koEEEEomgMgOmEEEGok^k^
00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg03gooooo00?o0000
ooooooooool01?ooool2ob4Q8@Sooooo00WoMgMgoc8b<_ooooooooooonk^k_mEEEGogMgMoeEEEOo^
k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0>?ooool01OnH
V9So8B4Qonk^k_ooooooA4A400?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Mooooo`00<?ooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00;ooooo00So0000ooooool0003oooooomgMgOl0003ogMgMo`00
00Gooooo0_l00003ooooo`03o`000?l@413ooooo00;ooooo00?o410@o`000?ooool00_ooool00ol0
003oooooooooo`04ooooo`04o`000?ooooooooooo`0003Gooooo00?o0000ooooooooool00oooool0
0ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
400mooooo`03o`000?oooooooooo00oooooo00Oo0000ooooooooooooooooomgMgOl0003ogMgM00Oo
oooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@03Wooooo00?oV9RHob4Q
8Oo^k^h01Oooool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooo
oooooooooooooa0@401Mooooo`00<?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`0=o`000?oooooooooo
oooooomgMgOo<S8booooool0003ok^k^oeEEEOoMgMgoEEEEo`000005ooooo`;o00000oooool2o`00
00?ooooo0_l00003ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo0000=Oooool0
0ol0003oooooooooo`02ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool00000?Oooool00ol0003oooooooooo`0>ooooo`09ogMg
Molb<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000003[ooooo00?oV9RHob4Q8Oo^k^h00oooool01Oo^k^koEEEEomgM
gOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000005go
oooo000`ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00;ooooo0_l000003?lQ8B7o0000oc8b<_o<c<coooooo`00
0?mEEEGok^k^ooooooo^k^ko0000onk^kPCooooo0_l00003ooooo`;o00000oooool2o`0000?ooooo
00?o0000ooooooooool01?ooool01?l0003oooooooooool0000eooooo`0;o`000?oooooooooooooo
ooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000?Oooool00ol0003oooooooooo`0;ooooo`0=o`000?lQ8B7o0000oc8b
<_o<c<coooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`00000kooooo`0;ogMgMomVIVKoooooooooooo^k^koEEEEonk^
k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000GOooool0033ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool2o`0000Gooooo00?o0000onk^k_oo
ool00_ooool00ol0003ok^k^ooooo`03ooooo`;o00000oooool00ol0003o410@ooooo`02ooooo`03
oa0@4?l0003ooooo00;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0000eoooo
o`04o`000?ooooooooooooooo`;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@03gooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`03ooooo`;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@03cooooo00?o0000ooooooooool00_o^k^h3ooooo`;ok^k^1Oooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@4100GOooool0033ooooo0ol0000Yooooo`;o0000
2Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0oooool2o`0000Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`;o0000
0oooool01ol0003oMgMgoiRHV?ooooooV9RHogMgMol000000oooool01Ol0003ooooooooooooooooo
000000;ooooo00Co0000oooooooooooo0000=Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`;o0000<oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Sooooo0_l0000^ooooo`05o`000?nj^[[ooooooiRHV?l@41003_ooool00ol0
003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool2o`0005?ooooo000`oooo
o`03o`000?oooooooooo02Wooooo0_l00009ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`03ooooo`Go00000_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00;ooooo00?oEEEEo`000?l000000oooool01ol0003ok^k^oc8b<_l0003o
<S8bonk^k_l000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo
0000<oooool00omEEEGoIVIVo`00000=ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP07ooooo`04o`000?ooooooooooo`00033ooooo00?oEEEEofIVI_l000003Oooool4
o`0000cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oooooo00Co
0000oooooooooooo0000;Oooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo00?oEEEEofIVI_l0
00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oooooo00Co0000oooooooooooo0000D_ooool0
033ooooo00?o0000ooooooooool0:?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooo`000003o`0000?ooooo00?o0000
ooooool000000_ooool00ol0003oooooooooo`1?ooooo`Co000000Goooooo`000?ooooooooooo`00
001Nooooo`Co000000Goooooo`000?ooooooooooo`00001<ooooo`Co000000Goooooo`000?oooooo
ooooo`00001Booooo`00<?ooool00ol0003oooooooooo`0Xooooo`04o`000?ooooooooooo`0000So
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooooooooooo
ool000001?ooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo05Cooooo0ol0001Toooo
o`?o0000D_ooool3o`0005?ooooo000`ooooo`03o`000?oooooooooo02Oooooo00Go0000oooooooo
ooooooooo`000008ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooo000000;ooooo0_l00003ooooo`03o`000?oooooooooo
05Cooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo
05;ooooo000`ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooo000000Co00000oooool00ol0003oooooooooo`04ooooo`;o
0000Coooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo05;ooooo00?o0000oooooooo
ool0DOooool0033ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Go
oooo0ol0003oooooof3ooooo000`ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooo
ooooo`000005ooooo`03o`000?oooooo00000?oooooo9_ooool00omgMgOoIVIVooooo`0]ooooo`03
ofIVI_mgMgOooooo00Oooooo000`ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooo
ooooo`000005ooooo`04o`000?ooooooooooo`000?oooooo9?ooool00ooMgMgo410@onk^kP0^oooo
o`03onk^k_l@413ogMgM00Oooooo000`ooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooo
ooooooooo`000005ooooo`04o`000?ooooooooooo`000?oooooo4_ooool2o`0000;ooooo0_l0000<
ooooo`03oeEEEOnHV9Sooooo00;o00000_ooool01ol0003oooooooooool0003o410@onk^k_mEEED0
0_l000000om4A4Co^[Zjooooo`02ooooo`05oiRHV?l0003o0000odA4A?nj^[X00_ooool02?o^k^ko
EEEEo`000?l0003oA4A4okZj^_oooooo410@1Ol00003ooooo`08oa0@4?lb<S;o0000o`000?l@413o
ZJVYohN7QomVIVH7ooooo`00<?ooool00ol0003oooooooooo`0Iooooo`?o00002_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003o
oooooooooooooooo000000Gooooo00Co0000oooooooooooo00001Oooool3o`000?oooooo2_ooool0
1_o^k^ko8B4QohN7Qonj^[[o0000omgMg@cooooo00Go0000ooooooooooooooooo`000002ooooo`0;
o`000?ooooooooooo`000?ooooooEEEEogMgMoooooook^k^ogMgMol@41000oooool01Ol@413o^[Zj
onk^k_mgMgOo410@00;ooooo00KoEEEEogMgMoooooook^k^ogMgMol@4103ooooo`03o`000?oooooo
oooo00Cooooo00So0000ojVYZOoooooooooookZj^_l0003ok^k^o`0000Oooooo003oo`000;Co0000
3oooool01?oMgMgo0000oa0@4?o<c<`=ooooo`05oc8b<_ooooooooooooooool000000_ooool01_l0
003oooooooooool0003oooooo`0000Sooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Gooooo00Oo^[ZjohN7QomVIVKoIVIVoa0@4?oooooo000000Oo
oooo000:ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0@ooooo`Co00002_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000Oooooo
00?o0000ooooooooool01?ooool2o`0000Gooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooool000000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00_ooool2o`0000?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000001Oooool4o`0000Sooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool05oooool01?o^k^ko8B4Qoa0@4?o^k^h=ooooo`05oc8b<_ooooooooooooooool000000_ooool0
1Ol0003oooooooooool0003ooooo00Ko00000oooool00ol0003oooooooooo`04ooooo`Ko00000ooo
ool00ol0003oooooooooo`04ooooo`08oc8b<_lQ8B7oMgMgogMgMon7QhOok^k^ooooool00007oooo
o`002_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0<ooooo`07o`000?ooooooooooooooool0003oooooo`000007
ooooo`03o`000?oooooooooo00Cooooo0_l00005ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool2o`0000Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00Co0000ooooool0003o00004Oooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0Gooooo`04ob4Q8OmgMgOoMgMgoc8b<Pgooooo00Go0000onk^k_ooooooooooo`000002olc<c00;
o`000?nYZJWogMgMob4Q8OooooooEEEEohN7Qoo^k^koooooohN7Qolb<S800oooool00ol0003ooooo
ooooo`04ooooo`06oeEEEOn7QhOok^k^oooooon7QhOo<S8b0oooool00ol0003o<S8bomgMg@04oooo
o`08o`000?nj^[[oooooonk^k_mgMgOo0000onk^k_l00007ooooo`00<?ooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo00;o00002?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooo000000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo
0ol0000hooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool0Foooool00ol0003ooooo
ooooo`0Fooooo`;o00000_ooool2o`0000cooooo00koEEEEogMgMooooooo410@o`000?lQ8B7o0000
ogMgMol@413o0000ojVYZOooooook^k^oeEEE@;o000000CoA4A4onk^k_oooooo410@1Ol00003oooo
o`06onk^k_mEEEGo0000o`000?m4A4Cok^k^0_ooool2o`000004ojVYZOlQ8B7o0000ob4Q8@;ooooo
00SoZJVYob4Q8Ol0003o0000oc8b<_l0003oMgMgoeEEE@Oooooo000`ooooo`03o`000?oooooooooo
023ooooo1?l00009ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000oooooolYooooo`03omgMgOl@413o
k^k^01;ooooo00?o0000ooooooooool06Oooool00oo^k^ko410@omgMg@07ooooo`00<?ooool00ol0
003oooooooooo`0]ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`04o`000?ooooooooooo`000?oooooo:_ooool00omgMgOoIVIVooooo`0A
ooooo`03o`000?oooooooooo01Wooooo00?oIVIVogMgMoooool01oooool0033ooooo00?o0000oooo
ooooool0;Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool01?l0003oooooooooool0003oooooofCooooo000`ooooo`03o`000?oooooooooo
02gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00?ooooo00Co0000oooooooooooo0000oooooomTooooo`00<?ooool00ol0003oooooooooo`0]oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`04o`000?ooooooooooo`000?ooooooI?ooool0033ooooo00?o0000ooooooooool0;_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooo`00003o
ooooofGooooo000`ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0
003ooooooooooooooooo000000Kooooo0_l0003oooooofGooooo000`ooooo`03o`000?oooooooooo
02kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`05o`000?oooooooooo
ooooool000001_ooool01Ol0003ooooooooooooooooo000000Kooooo0_l0003oooooofGooooo000`
ooooo`?o0000;_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooooooo
o`000006ooooo`05o`000?ooooooooooooooool000001_ooool2o`000?ooooooIOooool0033ooooo
00?o0000ooooooooool0;_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooo
ooooooooo`000006ooooo`04o`000?ooooooooooo`000?ooooooK_ooool0033ooooo00?o0000oooo
ooooool0;_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00
0006ooooo`04o`000?ooooooooooo`000?ooooooK_ooool0033ooooo00?o0000ooooooooool0;_oo
ool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000006ooooo`04
o`000?ooooooooooo`000?ooooooK_ooool0033ooooo00?o0000ooooooooool0;_ooool01Ol0003o
oooooooooooooooo000000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?oooooo
ooooo`000?ooooooK_ooool0033ooooo00?o0000ooooooooool0;oooool01?l0003oooooooooool0
0008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool0003oooooofko
oooo000`ooooo`03o`000?oooooooooo02oooooo00Co0000oooooooooooo00002?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003o
oooooooooooooooo000000Kooooo00Co0000oooooooooooo0000oooooom^ooooo`00<?ooool00ol0
003oooooooooo`0_ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00
0006ooooo`04o`000?ooooooooooo`000?ooooooK_ooool0033ooooo00?o0000ooooooooool0;ooo
ool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooo
ooooo`000006ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool0003o
ooooofkooooo000`ooooo`03o`000?oooooooooo02oooooo00Co0000oooooooooooo00002?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooo
oooooooo000000Kooooo00Co0000oooooooooooo0000oooooom^ooooo`00<?ooool00ol0003ooooo
ooooo`0_ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003o
oooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?oooooo
ooooo`000?ooooooK_ooool0033ooooo00?o0000ooooooooool0<?ooool2o`0000Wooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooo00000?ooooooKoooool0033ooooo0ol0000`ooooo`;o00002Ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooool00000oooooom_ooooo`00<?ooool00ol0003ooooo
ooooo`0`ooooo`;o00002Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool0
00001_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooool00000oooooom_oooo
o`00<?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooo
ooooooooo`000006ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooo`00003o
ooooofoooooo000`ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0
003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oo
oooo00000?ooooooKoooool0033ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Oooooo
0_l0003oooooofoooooo000`ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000007ooooo`;o
0000oooooom_ooooo`00<?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo
00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001oooool2o`00
0?ooooooKoooool0033ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05
o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Oooooo0_l0003o
ooooofoooooo000`ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0
003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000007ooooo`;o0000oooo
oom_ooooo`00<?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000
ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001oooool2o`000?oooooo
Koooool0033ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oo
ooooooooooooool000001_ooool01Ol0003ooooooooooooooooo00000?ooooooN?ooool0033ooooo
00?o0000ooooooooool0??ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0
003ooooooooooooooooo00000?ooooooN?ooool0033ooooo0ol0000looooo`05o`000?oooooooooo
ooooool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000
ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool00000oooooomhooooo`00<?oo
ool00ol0003oooooooooo`0looooo`05o`000?ooooooooooooooool000001oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`05
o`000?ooooooooooooooool00000oooooomhooooo`00<?ooool00ol0003oooooooooo`0looooo`05
o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool00000oooo
oomhooooo`00<?ooool00ol0003oooooooooo`0looooo`05o`000?ooooooooooooooool000001ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooooooo
o`000006ooooo`05o`000?ooooooooooooooool00000oooooomhooooo`00<?ooool00ol0003ooooo
ooooo`0looooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo
00000?ooooooN?ooool0033ooooo00?o0000ooooooooool0??ooool01?l0003oooooooooool00008
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooo
oooo000000Kooooo00Go0000ooooooooooooooooo`00003oooooogSooooo000?ooooo`;ok^k^0ooo
ool2onk^kQ[ooooo00?o0000ooooooooool0??ooool01?l0003oooooooooool00008ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Ko
oooo00Go0000ooooooooooooooooo`00003oooooogSooooo0008ooooo`Go00000_ooool01oo^k^ko
EEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000
oc8b<_o^k^h;ooooo`03o`000?oooooooooo03cooooo00Co0000oooooooooooo00002?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006
ooooo`05o`000?ooooooooooooooool00000oooooomhooooo`002?ooool01OnHV9So8B4Qonk^k_oo
ooooA4A400?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03o`000?oooooooooo03cooooo00Co0000oooooooo
oooo00002?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooo
ooooooooooooo`000006ooooo`05o`000?ooooooooooooooool00000oooooomhooooo`002Oooool0
0onHV9So8B4Qonk^kP05ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@00_ooooo00?o0000ooooooooool0??ooool01?l0003ooooooooo
ool00008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooo
oooooooooooo000000Kooooo00Co0000oooooooooooo0000oooooomiooooo`002_ooool00onHV9So
8B4Qonk^kP03ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`0looooo`04o`000?oooooo
ooooo`0000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oo
ooooooooooooool000001oooool00ol0003oooooo`00003oooooogWooooo000;ooooo`0;ogMgMomV
IVKoooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000002oooool4o`0003_ooooo00Co0000oooooooooooo0000
2?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooo
ooooo`000007ooooo`03o`000?oooooo00000?ooooooNOooool000cooooo00?o0000ooooooooool0
0_o^k^h3ooooo`;ok^k^1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41002oooool00ol0003oooooooooo`0looooo`04o`000?ooooooooooo`0000Sooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001oooool0
0ol0003oooooo`00003oooooogWooooo0008ooooo`05o`000?nj^[[ooooooiRHV?l@41003_ooool0
0ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ol0003ooooooooo
o`0looooo`04o`000?ooooooooooo`0000Wooooo00Go0000ooooooooooooooooo`000006ooooo`05
o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003oooooogWooooo0008ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`03?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h00oooool2o`0000Kooooo00?o0000ooooooooool0??ooool01?l0003oooooooooool0
0009ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Oo
oooo00?o0000ooooool00000oooooomiooooo`009oooool01?l0003oooooooooool00005ooooo`03
o`000?oooooooooo03cooooo00Co0000oooooooooooo00002Oooool01Ol0003ooooooooooooooooo
000000Kooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?ooooooNOoo
ool002Oooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`0looooo`04o`000?oo
ooooooooo`0000Wooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?oooooooooooooo
ool000001oooool00ol0003oooooo`00003oooooogWooooo000Wooooo`?o00001_ooool00ol0003o
ooooooooo`0looooo`04o`000?ooooooooooo`0000Wooooo00Go0000ooooooooooooooooo`000006
ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003oooooogWooooo000X
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0??ooool01?l0003oooooooooool0
0009ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Oo
oooo00?o0000ooooool00000oooooomiooooo`00:Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo03cooooo00Co0000oooooooooooo00002Oooool01Ol0003ooooooooooooooooo0000
00Kooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?ooooooNOooool0
033ooooo00?o0000ooooooooool0?Oooool00ol0003oooooo`000009ooooo`04o`000?oooooooooo
o`0000Oooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?ooooooNOoo
ool0033ooooo00?o0000ooooooooool0?Oooool00ol0003oooooo`000009ooooo`04o`000?oooooo
ooooo`0000Oooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?oooooo
NOooool0033ooooo00?o0000ooooooooool0?Oooool00ol0003oooooo`000009ooooo`04o`000?oo
ooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?oo
ooooNOooool0033ooooo0ol0000mooooo`03o`000?oooooo000000Wooooo00Co0000oooooooooooo
00001oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooool00000oooooomioooo
o`00<?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooo000000Wooooo00Co0000oooooooo
oooo00001oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooool00000oooooomi
ooooo`00<?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooo000000Wooooo00Co0000oooo
oooooooo00001oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooool00000oooo
oomiooooo`00<?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooo000000Wooooo00Co0000
oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooool00000
oooooomiooooo`00<?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooo000000Wooooo00Co
0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooool0
0000oooooomiooooo`00<?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooo000000Wooooo
00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000oooo
ool00000oooooomiooooo`00<?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooo000000Wo
oooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000
ooooool00000oooooomiooooo`00<?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooo0000
00Wooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Oooooo00?o
0000ooooool00000oooooomiooooo`00<?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
000000Wooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Oooooo
0_l0003oooooog[ooooo000`ooooo`03o`000?oooooooooo03gooooo00?o0000ooooool000002Ooo
ool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003o
ooooooooo`3oooooogSooooo000`ooooo`03o`000?oooooooooo03gooooo0_l0000:ooooo`04o`00
0?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo
0?ooooooN?ooool0033ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`08ooooo`04
o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooo
oooo0?ooooooN?ooool0033ooooo0ol0000nooooo`03o`000?oooooooooo00Sooooo00Co0000oooo
oooooooo00001oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0oooo
oomhooooo`00<?ooool00ol0003oooooooooo`19ooooo`04o`000?ooooooooooo`0000Oooooo00Go
0000ooooooooooooooooo`00003ooooooh?ooooo000`ooooo`03o`000?oooooooooo04Wooooo00Co
0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo00000?ooooooPoooool0033ooooo
00?o0000ooooooooool0BOooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`00
0?ooooooQ?ooool0033ooooo00?o0000ooooooooool0BOooool01?l0003oooooooooool00007oooo
o`04o`000?ooooooooooo`000?ooooooQ?ooool0033ooooo00?o0000ooooooooool0BOooool01?l0
003oooooooooool00007ooooo`04o`000?ooooooooooo`000?ooooooQ?ooool0033ooooo00?o0000
ooooooooool0BOooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`000?oooooo
Q?ooool0033ooooo00?o0000ooooooooool0BOooool01?l0003oooooooooool00008ooooo`03o`00
0?oooooo00000?ooooooQ?ooool0033ooooo00?o0000ooooooooool0BOooool01?l0003ooooooooo
ool00008ooooo`03o`000?oooooo00000?ooooooQ?ooool0033ooooo00?o0000ooooooooool0BOoo
ool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?ooooooQ?ooool0033ooooo00?o
0000ooooooooool0BOooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?oooooo
Q?ooool0033ooooo00?o0000ooooooooool0BOooool01?l0003oooooooooool00008ooooo`03o`00
0?oooooo00000?ooooooQ?ooool0033ooooo0ol00019ooooo`04o`000?ooooooooooo`0000Sooooo
00?o0000ooooool00000oooooon4ooooo`00<?ooool00ol0003oooooooooo`19ooooo`04o`000?oo
ooooooooo`0000Sooooo00?o0000ooooool00000oooooon4ooooo`00<?ooool00ol0003ooooooooo
o`19ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooon4ooooo`00<?oo
ool00ol0003oooooooooo`19ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000
oooooon4ooooo`00<?ooool00ol0003oooooooooo`19ooooo`04o`000?ooooooooooo`0000Sooooo
00?o0000ooooool00000oooooon4ooooo`00<?ooool00ol0003oooooooooo`19ooooo`04o`000?oo
ooooooooo`0000Sooooo00?o0000ooooool00000oooooon4ooooo`003oooool2onk^kP?ooooo0_o^
k^hJooooo`03o`000?oooooooooo04Wooooo00Co0000oooooooooooo00002?ooool00ol0003ooooo
o`00003oooooohCooooo000:ooooo`;o000000[o410@ooooooooooook^k^oeEEEOo^k^koooooonk^
k_mEEEGok^k^0oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`03
o`000?oooooooooo04Wooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003ooooo
ohCooooo000;ooooo`03o`000?oooooooooo00;ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06oooo
o`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03o`000?oooooo
oooo04Wooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003oooooohCooooo0008
ooooo`Go00001?ooool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@400;ooooo`03o`000?oooooooooo04Wooooo00Co0000oooooooooooo0000
2?ooool00ol0003oooooo`00003oooooohCooooo0008ooooo`04odA4A?oMgMgoooooo`0000Cooooo
00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`00000;ooooo`03o`000?oooooooooo04Wooooo00Co0000oooooooooooo00002?ooool0
0ol0003oooooo`00003oooooohCooooo0008ooooo`04omgMgOmEEEGoooooo`0000?ooooo00Ook^k^
oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000_ooooo1?l00018ooooo`03o`000?oooooo000000Wooooo00?o0000ooooool0
0000oooooon4ooooo`002Oooool00omgMgOoc<c<o`000003ooooo`;ok^k^0oooool2onk^kPGooooo
00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00_ooooo00?o0000oooooooo
ool0BOooool00ol0003oooooo`000009ooooo`03o`000?oooooo00000?ooooooQ?ooool000Wooooo
00?ok^k^odA4A?l000003oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool00ol0003oooooooooo`19ooooo`03o`000?oooooo000000Wooooo00?o0000ooooool0
0000oooooon4ooooo`002_ooool00omgMgOo0000ooooo`0<ooooo`03oeEEEOmVIVKo000000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`;o00001_ooool00ol0003oooooooooo`19ooooo`03
o`000?oooooo000000Wooooo00?o0000ooooool00000oooooon4ooooo`009oooool01?l0003ooooo
ooooool00005ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooool000002Oooool00ol0003o
ooooo`00003oooooohCooooo000Wooooo`04o`000?ooooooooooo`0000Gooooo00?o0000oooooooo
ool0BOooool00ol0003oooooo`000009ooooo`03o`000?oooooo00000?ooooooQ?ooool002Oooooo
0ol00006ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooool000002Oooool00ol0003ooooo
o`00003oooooohCooooo000Xooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0BOoo
ool00ol0003oooooo`000009ooooo`03o`000?oooooo00000?ooooooQ?ooool002Wooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`1:ooooo`;o00002Oooool00ol0003oooooo`00003o
ooooohCooooo000`ooooo`03o`000?oooooooooo04[ooooo0_l00009ooooo`03o`000?oooooo0000
0?ooooooQ?ooool0033ooooo00?o0000ooooooooool0B_ooool2o`0000Wooooo0_l0003oooooohGo
oooo000`ooooo`03o`000?oooooooooo04[ooooo0_l0000:ooooo`03o`000?oooooooooo0?oooooo
Poooool0033ooooo0ol0001:ooooo`;o00002_ooool00ol0003oooooooooo`3ooooooh?ooooo000`
ooooo`03o`000?oooooooooo04[ooooo0_l0000:ooooo`03o`000?oooooooooo0?ooooooPoooool0
033ooooo00?o0000ooooooooool0B_ooool2o`0000[ooooo00?o0000ooooooooool0oooooon3oooo
o`00<?ooool00ol0003oooooooooo`1:ooooo`;o0000oooooon@ooooo`00<?ooool00ol0003ooooo
ooooo`1:ooooo`;o0000oooooon@ooooo`00<?ooool00ol0003oooooooooo`1:ooooo`;o0000oooo
oon@ooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooo
ooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000
ooooooooool0oooooooLooooo`00<?ooool3o`000?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0
003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo
00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`
ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLoooo
o`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`?o0000oooooooLooooo`00<?oo
ool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0
033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomco
oooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooo
oooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?oo
ool00?ooooooooooool@ooooo`00X?ooool2o`0000Cooooo00?o^[Zjoc8b<_ooool01?ooool2o`00
00Kooooo00?o0000okZj^_ooool0oooooomGooooo`00X?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool2oc8b<_ooooooF?ooool008gooooo
0ol00002ooooo`06oc8b<_l@413oooooooooooo^k^koEEEE0_l000000om4A4Co^[Zjooooo`03oooo
o`03o`000?oooooooooo00;ooooo00GoV9RHoa0@4?l0003o0000ojVYZ@04ooooo`03o`000?oooooo
oooo00Cooooo00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj00Wooooo00Go
V9RHoa0@4?l0003o<S8bolc<c005ooooo`;o8B4Q1?ooool02oo<c<co8B4Qo`000?lQ8B7oc<c<oooo
ooo<c<cok^k^ooooooo^k^koc<c<00Cooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb
<S;ok^k^4oooool01_l@413o<S8bo`000?l0003o410@ojVYZ@;ooooo00Kok^k^oeEEEOl0003o0000
odA4A?nj^[X3ooooo`05ofIVI_l0003o0000odA4A?o<c<`0j?ooool008kooooo00Go0000oooooooo
ooooc<c<oa0@4003ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo410@1?ooool00ol0003ooooooooo
o`02ooooo`06o`000?nYZJWoEEEEoiRHV?mEEEGo^[Zj0oooool00ol0003oooooooooo`04ooooo`03
olc<c?l0003o410@00cooooo00Ko410@okZj^_o^k^koMgMgoa0@4?ooool6o`0000;ooooo00Go410@
okZj^_ooooooMgMgoc8b<P05ooooo`;o8B4Q1?ooool02olQ8B7oV9RHoooooonHV9So8B4Qooooooo^
k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg01?ooooo00Ko0000ojVYZOoooooooooookZj^_l00002ooooo`06oeEEEOmgMgOoooooonk^
k_mgMgOo410@0_ooool01_mVIVKoMgMgooooooooooooQhN7oa0@4>Sooooo002>ooooo`05o`000?oo
oooooooooeEEEOn7QhL00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo
00Ko<S8bonk^k_nHV9SoEEEEomgMgOl@4103ooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`09ooooo`05o`000?ooooooooooooooool000000_ooool0
0ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
400Dooooo`05okZj^_n7QhOoIVIVofIVI_l@41000_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0>_ooooo002>ooooo`05o`000?oooooogMgMo`000?o^k^h00oooool6o`0000Cooooo
00?o0000ooooooooool00_ooool01onj^[[oA4A4olc<c?lQ8B7ooooooa0@4?o<c<`00_ooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo00?ooooo1_l00005ooooo`03ojVYZOl@413ooooo
00[ooooo00_o<S8boiRHV?ooooooV9RHoc8b<_ooooook^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03
o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Cooooo`06oc8b<_lQ8B7oMgMg
ogMgMon7QhOok^k^0_ooool6o`0000;ooooo00?o0000ooooooooool0joooool008kooooo0ol00000
0ol@413oV9RHooooo`02ooooo`06oeEEEOn7QhOok^k^oooooon7QhOo<S8b1?ooool00ol0003ooooo
ooooo`02ooooo`07onk^k_l0003oooooo`000?ooooooIVIVohN7Q`02ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool03Oooool00ol@413o0000okZj^P0;ooooo`0;olc<c?l0003o0000
o`000?o<c<coooooolc<c?o^k^koooooonk^k_o<c<`01_ooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000004oooool01_l0003o^[Zjooooooo^k^koMgMgo`0000;ooooo00Ko
EEEEohN7Qoo^k^koooooohN7Qolb<S82ooooo`06ofIVI_mgMgOooooooooooon7QhOo0000j?ooool0
08kooooo00Go0000ooooooooooooc<c<o`000003ooooo`06onk^k_mEEEGo0000o`000?m4A4Cok^k^
1?ooool00ol0003oooooooooo`02ooooo`04ofIVI_nHV9Sooooooc8b<P;o^[Zj00Co0000oooooooo
oooo00004oooool00ol@413o0000o`000003o`0000gooooo00?o^[Zjob4Q8Oooool02_ooool01Ol@
413o^[Zjoooooonj^[[o410@00cooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@00Oooooo0ol00002ooooo`?o00001?ooool01_nYZJWo8B4Qo`000?l0003o<S8bo`0000;o
oooo00Kok^k^oeEEEOl0003o0000odA4A?o^k^h2ooooo`06onk^k_mVIVKo0000o`000?m4A4Co0000
j?ooool008kooooo00Go0000ooooooooooooc<c<o`00000=ooooo`03o`000?oooooooooo00Gooooo
00?oIVIVohN7Qoooool00oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00_ooooo
00Go410@oiRHV?oooooo^[Zjo`00000;ooooo`05o`000?nj^[[ooooookZj^_l000003?ooool00ol0
003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo0?oooooo0_ooool008gooooo1?l000000ol@413oZJVYooooo`0<oooo
o`;o00001_ooool00onYZJWoA4A4ooooo`02ooooo`;o00005Oooool00ol0003oooooooooo`0;oooo
o`05ojVYZOl@413o0000oa0@4?nYZJT02oooool01OnYZJWo410@o`000?l@413oZJVY00[ooooo00?o
EEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo1?l00002ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0ooooool2ooooo`00ooooool6ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0ooooool2ooooo`00ooooool6ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0ooooool2ooooo`00ooooool5ooooo`;o00000oooool2o`00
0?oooooo1?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?oo
ool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooo
ooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@oooo
o`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooo
oooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo
003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo0000\
\>"],
  ImageRangeCache->{{{0, 525.688}, {324.5, 0}} -> {0, -6.34248*^6, 0, 53093}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0.309017 5.42214e-08 [
[.32684 .29652 -16.5 -12.5 ]
[.32684 .29652 16.5 0 ]
[.54329 .29652 -16.5 -12.5 ]
[.54329 .29652 16.5 0 ]
[.75974 .29652 -22.5 -12.5 ]
[.75974 .29652 22.5 0 ]
[.97619 .29652 -16.5 -12.5 ]
[.97619 .29652 16.5 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 64 6 ]
[.09789 .09213 -34.5 -6.25 ]
[.09789 .09213 0 6.25 ]
[.09789 .20057 -34.5 -6.25 ]
[.09789 .20057 0 6.25 ]
[.09789 .41746 -28.5 -6.25 ]
[.09789 .41746 0 6.25 ]
[.09789 .5259 -28.5 -6.25 ]
[.09789 .5259 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -59.8125 0 ]
[.5 .63053 59.8125 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 .30902 m
.32684 .31527 L
s
gsave
.32684 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 .30902 m
.54329 .31527 L
s
gsave
.54329 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 .30902 m
.75974 .31527 L
s
gsave
.75974 .29652 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 .30902 m
.15368 .31277 L
s
.19697 .30902 m
.19697 .31277 L
s
.24026 .30902 m
.24026 .31277 L
s
.28355 .30902 m
.28355 .31277 L
s
.37013 .30902 m
.37013 .31277 L
s
.41342 .30902 m
.41342 .31277 L
s
.45671 .30902 m
.45671 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.58658 .30902 m
.58658 .31277 L
s
.62987 .30902 m
.62987 .31277 L
s
.67316 .30902 m
.67316 .31277 L
s
.71645 .30902 m
.71645 .31277 L
s
.80303 .30902 m
.80303 .31277 L
s
.84632 .30902 m
.84632 .31277 L
s
.88961 .30902 m
.88961 .31277 L
s
.9329 .30902 m
.9329 .31277 L
s
.0671 .30902 m
.0671 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09213 m
.11664 .09213 L
s
gsave
.09789 .09213 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .20057 m
.11664 .20057 L
s
gsave
.09789 .20057 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .41746 m
.11664 .41746 L
s
gsave
.09789 .41746 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .5259 m
.11664 .5259 L
s
gsave
.09789 .5259 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.11039 .11924 m
.11414 .11924 L
s
.11039 .14635 m
.11414 .14635 L
s
.11039 .17346 m
.11414 .17346 L
s
.11039 .22768 m
.11414 .22768 L
s
.11039 .2548 m
.11414 .2548 L
s
.11039 .28191 m
.11414 .28191 L
s
.11039 .33613 m
.11414 .33613 L
s
.11039 .36324 m
.11414 .36324 L
s
.11039 .39035 m
.11414 .39035 L
s
.11039 .44457 m
.11414 .44457 L
s
.11039 .47168 m
.11414 .47168 L
s
.11039 .49879 m
.11414 .49879 L
s
.11039 .06502 m
.11414 .06502 L
s
.11039 .03791 m
.11414 .03791 L
s
.11039 .0108 m
.11414 .0108 L
s
.11039 .55301 m
.11414 .55301 L
s
.11039 .58012 m
.11414 .58012 L
s
.11039 .60723 m
.11414 .60723 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -120.812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.812 moveto
(@) show
81.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.812 moveto
(D) show
93.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.) show
129.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
135.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
147.000 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
151.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
160.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
178.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02453 .30902 L
.02532 .30902 L
.02615 .30902 L
.02652 .30902 L
.02691 .30902 L
.02714 .30902 L
.02724 .30902 L
.02735 .30902 L
.02744 .30902 L
.02755 .30902 L
.0276 .30902 L
.02765 .30902 L
.02776 .30902 L
.02781 .30902 L
.02787 .30902 L
.02793 .30902 L
.02798 .30902 L
.02804 .30902 L
.0281 .30902 L
.02816 .30902 L
.02822 .30902 L
.02832 .30902 L
.02844 .30902 L
.02866 .30902 L
.02887 .30902 L
.02907 .30902 L
.02951 .30902 L
.02991 .30902 L
.03029 .30902 L
.03107 .30902 L
.03146 .30902 L
.03189 .30902 L
.03265 .30902 L
.03337 .30902 L
.03416 .30902 L
.03499 .30902 L
.03647 .30902 L
.03724 .30902 L
.03806 .30902 L
.03953 .30902 L
.04125 .30902 L
.04286 .30902 L
.04447 .30902 L
.04595 .30902 L
.04759 .30902 L
.04911 .30902 L
.05216 .30902 L
.05527 .30902 L
.05686 .30902 L
Mistroke
.05859 .30902 L
.05939 .30902 L
.06024 .30902 L
.06066 .30902 L
.06105 .30902 L
.0614 .30902 L
.0616 .30902 L
.06178 .30902 L
.06188 .30902 L
.06198 .30902 L
.06206 .30902 L
.06216 .30902 L
.06226 .30902 L
.06231 .30902 L
.06237 .30902 L
.06247 .30902 L
.06256 .30902 L
.06265 .30902 L
.06274 .30902 L
.06291 .30902 L
.06309 .30902 L
.06329 .30902 L
.06371 .30902 L
.06394 .30902 L
.06415 .30902 L
.06495 .30902 L
.06534 .30902 L
.06575 .30902 L
.06649 .30902 L
.06729 .30902 L
.06816 .30902 L
.06973 .30902 L
.07061 .30902 L
.07141 .30902 L
.07294 .30902 L
.0746 .30902 L
.07619 .30902 L
.07787 .30902 L
.0809 .30902 L
.08412 .30902 L
.08723 .30902 L
.08883 .30902 L
.08964 .30902 L
.08986 .30902 L
.0901 .30902 L
.0903 .30902 L
.09053 .30902 L
.09063 .30902 L
.09073 .30902 L
.09079 .30902 L
Mistroke
.09085 .30902 L
.0909 .30902 L
.09095 .30902 L
.09105 .30902 L
.09116 .30902 L
.09125 .30902 L
.09135 .30902 L
.09141 .30902 L
.09146 .30902 L
.09159 .30902 L
.0917 .30902 L
.09182 .30902 L
.09202 .30902 L
.09224 .30902 L
.09264 .30902 L
.09308 .30902 L
.09348 .30902 L
.09386 .30902 L
.09465 .30902 L
.09539 .30902 L
.0962 .30902 L
.09706 .30902 L
.09862 .30902 L
.10009 .30902 L
.10171 .30902 L
.10319 .30902 L
.10638 .30902 L
.10944 .30902 L
.11114 .30902 L
.11269 .30902 L
.11347 .30902 L
.11431 .30902 L
.11469 .30902 L
.1151 .30902 L
.11545 .30902 L
.11565 .30902 L
.11583 .30902 L
.11603 .30902 L
.11614 .30902 L
.11619 .30902 L
.11625 .30902 L
.1163 .30902 L
.11636 .30902 L
.11646 .30902 L
.11655 .30902 L
.11665 .30902 L
.11674 .30902 L
.11683 .30902 L
.11692 .30902 L
.117 .30902 L
Mistroke
.1172 .30902 L
.11739 .30902 L
.11759 .30902 L
.11781 .30902 L
.1182 .30902 L
.11861 .30902 L
.11907 .30902 L
.11988 .30902 L
.12063 .30902 L
.12149 .30902 L
.1223 .30902 L
.12389 .30902 L
.12537 .30901 L
.12701 .30901 L
.12851 .309 L
.13172 .30899 L
.13482 .30898 L
.13638 .30897 L
.13721 .30897 L
.13767 .30897 L
.13811 .30897 L
.13852 .30897 L
.13875 .30897 L
.13896 .30897 L
.13905 .30897 L
.13914 .30897 L
.13924 .30897 L
.13934 .30897 L
.13944 .30897 L
.13949 .30897 L
.13955 .30897 L
.13965 .30897 L
.13974 .30897 L
.13984 .30897 L
.13994 .30897 L
.14013 .30897 L
.14031 .30897 L
.14048 .30897 L
.14087 .30897 L
.14127 .30897 L
.14167 .30897 L
.14203 .30897 L
.14284 .30898 L
.1436 .30898 L
.14431 .30899 L
.14591 .30901 L
.14738 .30904 L
.15053 .30911 L
.15387 .30922 L
.15555 .30928 L
Mistroke
.15709 .30933 L
.15787 .30935 L
.15859 .30936 L
.15899 .30937 L
.15935 .30937 L
.15975 .30938 L
.15998 .30938 L
.16008 .30938 L
.16018 .30938 L
.16028 .30938 L
.16038 .30938 L
.16046 .30938 L
.16055 .30938 L
.16065 .30938 L
.16075 .30938 L
.16085 .30938 L
.16091 .30938 L
.16096 .30938 L
.16107 .30938 L
.16116 .30938 L
.16139 .30938 L
.16158 .30938 L
.16179 .30937 L
.16215 .30937 L
.16249 .30936 L
.16326 .30934 L
.16367 .30932 L
.1641 .3093 L
.1649 .30926 L
.16638 .30914 L
.16797 .30897 L
.16965 .30873 L
.17268 .3082 L
.17436 .30788 L
.1759 .3076 L
.17668 .30748 L
.17751 .30736 L
.17828 .30727 L
.17901 .3072 L
.17939 .30718 L
.1796 .30717 L
.1798 .30716 L
.17997 .30716 L
.18006 .30716 L
.18015 .30715 L
.18024 .30715 L
.18033 .30715 L
.18043 .30715 L
.18052 .30715 L
.18063 .30716 L
Mistroke
.18072 .30716 L
.18083 .30716 L
.18093 .30716 L
.18112 .30717 L
.18132 .30718 L
.18177 .30722 L
.18218 .30727 L
.18296 .30739 L
.18369 .30755 L
.18449 .30777 L
.18535 .30808 L
.18706 .30887 L
.18867 .30985 L
.19175 .31214 L
.19331 .31336 L
.19502 .31458 L
.19581 .31506 L
.19665 .31548 L
.19704 .31564 L
.19745 .31577 L
.1978 .31587 L
.19799 .31591 L
.19818 .31594 L
.19838 .31597 L
.19849 .31598 L
.19854 .31598 L
.1986 .31598 L
.1987 .31599 L
.19879 .31599 L
.19885 .31599 L
.1989 .31599 L
.199 .31599 L
.19909 .31598 L
.19919 .31598 L
.19928 .31597 L
.19936 .31596 L
.19956 .31593 L
.19975 .31589 L
.20017 .31577 L
.20056 .31562 L
.20099 .3154 L
.20143 .31511 L
.2022 .31449 L
.20301 .31362 L
.20449 .31154 L
.20619 .30834 L
.20781 .30469 L
.21089 .29705 L
.21245 .2935 L
.21328 .2919 L
Mistroke
.21417 .2905 L
.21461 .28995 L
.21502 .28953 L
.21539 .28924 L
.2156 .28911 L
.2158 .28902 L
.2159 .28898 L
.216 .28895 L
.2161 .28893 L
.21619 .28892 L
.21627 .28891 L
.21636 .2889 L
.21645 .28891 L
.21654 .28891 L
.21664 .28893 L
.21674 .28895 L
.21682 .28898 L
.21692 .28902 L
.21713 .28912 L
.21733 .28925 L
.2177 .28957 L
.2181 .29005 L
.21882 .29126 L
.21969 .29329 L
.22048 .29572 L
.22199 .30184 L
.22366 .31048 L
.22691 .33076 L
.22841 .33996 L
.23004 .34835 L
.23093 .3518 L
.23132 .353 L
.23175 .35407 L
.23195 .35446 L
.23216 .35482 L
.23234 .35507 L
.23254 .35528 L
.23265 .35537 L
.23271 .35541 L
.23276 .35543 L
.23286 .35548 L
.23292 .35549 L
.23297 .3555 L
.23307 .35551 L
.23316 .3555 L
.23326 .35547 L
.23337 .35542 L
.23347 .35535 L
.23358 .35526 L
.23377 .35504 L
Mistroke
.23396 .35476 L
.23413 .35443 L
.23453 .35348 L
.23495 .35213 L
.23565 .3491 L
.23642 .34463 L
.23798 .33212 L
.23965 .31408 L
.24295 .27074 L
.2446 .24978 L
.24541 .24083 L
.24614 .2338 L
.24685 .22816 L
.24722 .22574 L
.24762 .22363 L
.24782 .22274 L
.24804 .22192 L
.24824 .2213 L
.24843 .22086 L
.24852 .22069 L
.24862 .22054 L
.24873 .22041 L
.24883 .22033 L
.24892 .22028 L
.24902 .22027 L
.24911 .22029 L
.2492 .22034 L
.2493 .22043 L
.24939 .22054 L
.24948 .2207 L
.24959 .22091 L
.24981 .22147 L
.25001 .22214 L
.25039 .22386 L
.25075 .226 L
.25155 .2326 L
.25242 .24255 L
.25401 .26776 L
.2557 .30254 L
.25874 .37433 L
.26043 .41074 L
.26123 .42512 L
.26197 .43616 L
.26273 .44476 L
.26314 .44805 L
.26334 .44939 L
.26357 .45056 L
.26367 .451 L
.26378 .45139 L
.26388 .4517 L
Mistroke
.26397 .45192 L
.26406 .45209 L
.26416 .4522 L
.26426 .45227 L
.26436 .45227 L
.26445 .45222 L
.26454 .45212 L
.26463 .45196 L
.26473 .45172 L
.2649 .45119 L
.26508 .45039 L
.26527 .44935 L
.26548 .44794 L
.26589 .44427 L
.26628 .43986 L
.26663 .4349 L
.26744 .4207 L
.26831 .40122 L
.27164 .29494 L
.27331 .23391 L
.27485 .18194 L
.27635 .14147 L
.2771 .12656 L
.27753 .12003 L
.27794 .1153 L
.27813 .11352 L
.27833 .11198 L
.27845 .11127 L
.27856 .11073 L
.27867 .11029 L
.27877 .10999 L
.27887 .10978 L
.27897 .10966 L
.27907 .10963 L
.27913 .10965 L
.27918 .1097 L
.27928 .10987 L
.27936 .11009 L
.27947 .11044 L
.27956 .11087 L
.27974 .11189 L
.27993 .11331 L
.28028 .11673 L
.28064 .12166 L
.28105 .12856 L
.28186 .14686 L
.28261 .1686 L
.28428 .23237 L
.28747 .38382 L
.28907 .45636 L
Mistroke
.29053 .50888 L
.29092 .5199 L
.29134 .53015 L
.29171 .53753 L
.29211 .54396 L
.29231 .54655 L
.29253 .54879 L
.29265 .54978 L
.29276 .55054 L
.29288 .55115 L
.29298 .55159 L
.29308 .55187 L
.29318 .55205 L
.29328 .5521 L
.29334 .55208 L
.2934 .55201 L
.29349 .55181 L
.29358 .55152 L
.29368 .55108 L
.29379 .55049 L
.29399 .54894 L
.29419 .547 L
.29455 .54213 L
.29495 .5351 L
.29537 .52543 L
.29614 .50288 L
.29684 .47663 L
.3 .31451 L
.30304 .14823 L
.30384 .11333 L
.3046 .08598 L
.30502 .07368 L
.30548 .06269 L
.30589 .05502 L
.30608 .05231 L
.30628 .04996 L
.30638 .04897 L
.30649 .04804 L
.30659 .04734 L
.30669 .04682 L
.3068 .04637 L
.30686 .04619 L
.30691 .04607 L
.30702 .04596 L
.30707 .04597 L
.30713 .04602 L
.30722 .0462 L
.30731 .04649 L
.30741 .04693 L
.30751 .04756 L
Mistroke
.30773 .04932 L
.30793 .0515 L
.30827 .05665 L
.30865 .06416 L
.30942 .08501 L
.31024 .11541 L
.31099 .14926 L
.31268 .24117 L
.31435 .3426 L
.31589 .43151 L
.31739 .50238 L
.31814 .52923 L
.31857 .54125 L
.31898 .55045 L
.31937 .55718 L
.31959 .56004 L
.31979 .56206 L
.31989 .56282 L
.31998 .5634 L
.32006 .56383 L
.32015 .56417 L
.32025 .56442 L
.32035 .56453 L
.32044 .5645 L
.32054 .56434 L
.32059 .5642 L
.32065 .56399 L
.32076 .56349 L
.32086 .56284 L
.32096 .5621 L
.32117 .55994 L
.32141 .55692 L
.32179 .55024 L
.32222 .54057 L
.32303 .51565 L
.32377 .48624 L
.32545 .40238 L
.3271 .30731 L
.32863 .22137 L
.33012 .15181 L
.33095 .1221 L
.3317 .10212 L
.33209 .09457 L
.3323 .09129 L
.3325 .08878 L
.33269 .08693 L
.33285 .08565 L
.33295 .08509 L
.33304 .08468 L
.33314 .08436 L
Mistroke
.33324 .08416 L
.33334 .0841 L
.33344 .08418 L
.3335 .08429 L
.33355 .08442 L
.3336 .0846 L
.33366 .08484 L
.33377 .08541 L
.33388 .08609 L
.33411 .08815 L
.33431 .09052 L
.3345 .09315 L
.33491 .10059 L
.33571 .12071 L
.33645 .14533 L
.33812 .21719 L
.33975 .29878 L
.34128 .37308 L
.34275 .43244 L
.34357 .45778 L
.34432 .47485 L
.3447 .48114 L
.34492 .48388 L
.34511 .486 L
.3453 .48757 L
.3454 .48823 L
.3455 .48881 L
.34559 .4892 L
.34568 .48954 L
.34577 .48975 L
.34585 .48987 L
.34595 .48991 L
.34601 .48988 L
.34606 .48981 L
.34616 .48961 L
.34627 .48927 L
.34636 .48886 L
.34645 .48839 L
.34665 .48698 L
.34687 .48497 L
.34707 .48268 L
.34751 .47601 L
.3483 .45946 L
.34903 .43925 L
.35069 .38074 L
.35383 .25826 L
.35466 .23131 L
.35555 .20721 L
.35596 .19822 L
.35639 .19024 L
Mistroke
.3568 .18427 L
.35717 .18011 L
.35735 .17848 L
.35755 .17708 L
.35765 .17657 L
.35775 .17611 L
.35784 .17575 L
.35792 .1755 L
.35802 .1753 L
.35812 .17517 L
.35822 .17513 L
.35831 .17518 L
.35842 .17533 L
.35852 .17555 L
.35862 .1759 L
.35874 .17639 L
.35893 .17744 L
.35913 .17892 L
.35951 .18253 L
.35987 .18711 L
.36021 .19222 L
.36171 .22392 L
.36337 .26993 L
.36506 .31948 L
.3666 .35902 L
.36737 .37456 L
.36777 .38145 L
.3682 .38768 L
.36861 .39256 L
.36898 .39602 L
.36917 .39735 L
.36936 .39855 L
.36954 .39944 L
.36971 .40006 L
.36982 .40034 L
.36991 .40054 L
.37 .40067 L
.37009 .40075 L
.37019 .40078 L
.37025 .40076 L
.3703 .40073 L
.3704 .40062 L
.3705 .40046 L
.37059 .40025 L
.37068 .39998 L
.37085 .39935 L
.37103 .39848 L
.37123 .39731 L
.37164 .3941 L
.37209 .38964 L
Mistroke
.37288 .37917 L
.3746 .34904 L
.37622 .31648 L
.37769 .28879 L
.37852 .2755 L
.3793 .26532 L
.38007 .25776 L
.3805 .25467 L
.3809 .25258 L
.38111 .25174 L
.38131 .25115 L
.38143 .25089 L
.38153 .25071 L
.38159 .25063 L
.38165 .25056 L
.38171 .25051 L
.38177 .25048 L
.38186 .25046 L
.38196 .25047 L
.38206 .25053 L
.38211 .25059 L
.38217 .25065 L
.38227 .2508 L
.38238 .25102 L
.38259 .25156 L
.38278 .25221 L
.38298 .25306 L
.38334 .25499 L
.38418 .26114 L
.38506 .26981 L
.38587 .27917 L
.38752 .30025 L
.38905 .31888 L
.38981 .32679 L
.39053 .33306 L
.39093 .33597 L
.39136 .33862 L
.39172 .34045 L
.39211 .34199 L
.39232 .34263 L
.39251 .34311 L
.3927 .34348 L
.39288 .34374 L
.39298 .34384 L
.39303 .34389 L
.39308 .34392 L
.39318 .34397 L
.39328 .34399 L
.39333 .34399 L
.39339 .34398 L
Mistroke
.39349 .34394 L
.39354 .34391 L
.39359 .34387 L
.39371 .34375 L
.39382 .34362 L
.39393 .34344 L
.39414 .34303 L
.39453 .34199 L
.39498 .34032 L
.3954 .3384 L
.39691 .32912 L
.39856 .3166 L
.40025 .30425 L
.40106 .29931 L
.4018 .29551 L
.40256 .29251 L
.40297 .29133 L
.40317 .29083 L
.4034 .29038 L
.40361 .29002 L
.40381 .28977 L
.40399 .28959 L
.40409 .28952 L
.40419 .28946 L
.40429 .28942 L
.40437 .2894 L
.40447 .28939 L
.40457 .2894 L
.40465 .28942 L
.40473 .28944 L
.40482 .28949 L
.40491 .28954 L
.4051 .2897 L
.40531 .28993 L
.40567 .29049 L
.40605 .29128 L
.40648 .29235 L
.40795 .29742 L
.40965 .30469 L
.4112 .31104 L
.41198 .31375 L
.41282 .31615 L
.4132 .31704 L
.41361 .31783 L
.41398 .31842 L
.41434 .31885 L
.41453 .31903 L
.41474 .31918 L
.41483 .31924 L
.41492 .31929 L
Mistroke
.41501 .31933 L
.4151 .31936 L
.4152 .31938 L
.41526 .31939 L
.41532 .3194 L
.41542 .31941 L
.41547 .31941 L
.41552 .3194 L
.41562 .31939 L
.41571 .31937 L
.41581 .31934 L
.41591 .3193 L
.41609 .31922 L
.41628 .31909 L
.41662 .3188 L
.41698 .3184 L
.41738 .31785 L
.41894 .31493 L
.42061 .31112 L
.4222 .30774 L
.42303 .30628 L
.42349 .30561 L
.42392 .30507 L
.42434 .30464 L
.42479 .30428 L
.42499 .30415 L
.4252 .30404 L
.4254 .30395 L
.42558 .30389 L
.42576 .30385 L
.42586 .30383 L
.42595 .30382 L
.42604 .30381 L
.42612 .30381 L
.42621 .30381 L
.42631 .30381 L
.4264 .30382 L
.4265 .30384 L
.4266 .30385 L
.42669 .30387 L
.42689 .30393 L
.42711 .30401 L
.42751 .30421 L
.42788 .30445 L
.42869 .30512 L
.43017 .30668 L
.43184 .3086 L
.43257 .30936 L
.43338 .3101 L
.4341 .31064 L
Mistroke
.43488 .31108 L
.4353 .31126 L
.4357 .31138 L
.43588 .31142 L
.43609 .31145 L
.43618 .31147 L
.43628 .31148 L
.43638 .31149 L
.43646 .31149 L
.43656 .3115 L
.43665 .3115 L
.43675 .3115 L
.43686 .31149 L
.43691 .31149 L
.43697 .31149 L
.43707 .31148 L
.43717 .31147 L
.43727 .31146 L
.43763 .3114 L
.43781 .31136 L
.43801 .3113 L
.43887 .311 L
.43968 .31063 L
.44279 .30897 L
.44363 .30859 L
.4444 .30831 L
.44521 .30809 L
.44564 .30801 L
.44586 .30797 L
.4461 .30794 L
.4463 .30792 L
.44641 .30791 L
.44653 .30791 L
.44663 .3079 L
.44673 .3079 L
.44683 .30789 L
.44692 .30789 L
.44697 .30789 L
.44703 .30789 L
.44709 .30789 L
.44714 .30789 L
.44724 .30789 L
.4473 .3079 L
.44735 .3079 L
.44746 .3079 L
.44757 .30791 L
.44781 .30793 L
.44802 .30795 L
.44822 .30797 L
.44865 .30803 L
Mistroke
.44943 .30817 L
.4511 .30856 L
.45264 .30894 L
.45413 .30925 L
.45489 .30936 L
.45532 .30941 L
.45572 .30945 L
.45612 .30947 L
.45635 .30949 L
.45655 .30949 L
.45666 .3095 L
.45676 .3095 L
.45684 .3095 L
.45694 .3095 L
.45704 .3095 L
.45709 .3095 L
.45715 .3095 L
.45725 .3095 L
.45735 .3095 L
.45744 .3095 L
.45754 .3095 L
.45763 .3095 L
.45772 .3095 L
.45806 .30948 L
.45824 .30948 L
.45844 .30947 L
.45883 .30944 L
.46039 .3093 L
.46206 .30912 L
.46364 .30896 L
.46453 .3089 L
.46496 .30887 L
.46537 .30885 L
.46575 .30884 L
.46596 .30883 L
.46617 .30883 L
.46635 .30882 L
.46655 .30882 L
.46664 .30882 L
.46673 .30882 L
.46682 .30882 L
.4669 .30882 L
.46696 .30882 L
.46701 .30882 L
.46711 .30882 L
.46717 .30882 L
.46723 .30882 L
.46729 .30882 L
.46734 .30882 L
.46744 .30882 L
Mistroke
.46755 .30882 L
.46766 .30882 L
.46776 .30882 L
.46814 .30883 L
.46855 .30883 L
.46937 .30886 L
.47026 .3089 L
.47187 .30897 L
.47343 .30903 L
.47432 .30906 L
.47474 .30907 L
.47515 .30908 L
.47553 .30909 L
.47573 .30909 L
.47594 .30909 L
.47614 .30909 L
.47632 .3091 L
.47641 .3091 L
.4765 .3091 L
.47658 .3091 L
.47667 .3091 L
.47677 .3091 L
.47687 .3091 L
.47693 .3091 L
.47698 .3091 L
.47708 .3091 L
.47714 .3091 L
.47719 .3091 L
.47729 .3091 L
.4774 .3091 L
.47752 .3091 L
.47772 .30909 L
.47793 .30909 L
.47831 .30909 L
.47907 .30908 L
.47991 .30907 L
.48161 .30904 L
.48248 .30902 L
.48331 .30901 L
.48406 .309 L
.48444 .309 L
.48486 .30899 L
.48527 .30899 L
.48565 .30899 L
.48586 .30899 L
.48606 .30899 L
.48616 .30899 L
.48622 .30899 L
.48628 .30899 L
.48634 .30899 L
Mistroke
.48639 .30899 L
.48649 .30899 L
.48658 .30899 L
.48668 .30899 L
.48677 .30899 L
.48686 .30899 L
.48696 .30899 L
.48707 .30899 L
.48726 .30899 L
.48746 .30899 L
.48765 .30899 L
.48799 .30899 L
.48877 .30899 L
.48959 .309 L
.49107 .30901 L
.49184 .30901 L
.49266 .30902 L
.49341 .30902 L
.49411 .30903 L
.49446 .30903 L
.49485 .30903 L
.49507 .30903 L
.49527 .30903 L
.49546 .30903 L
.49566 .30903 L
.49576 .30903 L
.49586 .30903 L
.49592 .30903 L
.49597 .30903 L
.49603 .30903 L
.49608 .30903 L
.49614 .30903 L
.49619 .30903 L
.4963 .30903 L
.49636 .30903 L
.49642 .30903 L
.49653 .30903 L
.49673 .30903 L
.49692 .30903 L
.49733 .30903 L
.49771 .30903 L
.49812 .30903 L
.49885 .30902 L
.50051 .30902 L
.50211 .30902 L
.50254 .30902 L
.50301 .30901 L
.50341 .30901 L
.50384 .30901 L
.50425 .30901 L
Mistroke
.50462 .30901 L
.50481 .30901 L
.5049 .30901 L
.505 .30901 L
.5051 .30901 L
.50519 .30901 L
.50528 .30901 L
.50536 .30901 L
.50546 .30901 L
.50552 .30901 L
.50557 .30901 L
.50567 .30901 L
.50573 .30901 L
.50578 .30901 L
.50588 .30901 L
.50598 .30901 L
.50617 .30901 L
.50639 .30901 L
.50662 .30901 L
.50704 .30901 L
.50861 .30901 L
.51007 .30902 L
.51086 .30902 L
.51169 .30902 L
.5124 .30902 L
.51277 .30902 L
.51318 .30902 L
.5134 .30902 L
.5136 .30902 L
.51379 .30902 L
.514 .30902 L
.51409 .30902 L
.51419 .30902 L
.51427 .30902 L
.51437 .30902 L
.51447 .30902 L
.51457 .30902 L
.51466 .30902 L
.51475 .30902 L
.51486 .30902 L
.51492 .30902 L
.51497 .30902 L
.51507 .30902 L
.51518 .30902 L
.51536 .30902 L
.51557 .30902 L
.51601 .30902 L
.51643 .30902 L
.51956 .30902 L
.52038 .30902 L
Mistroke
.52081 .30902 L
.52127 .30902 L
.52167 .30902 L
.52211 .30902 L
.52251 .30902 L
.52288 .30902 L
.52308 .30902 L
.52326 .30902 L
.52337 .30902 L
.52346 .30902 L
.52352 .30902 L
.52357 .30902 L
.52368 .30902 L
.52378 .30902 L
.52383 .30902 L
.52389 .30902 L
.52394 .30902 L
.52399 .30902 L
.52411 .30902 L
.52421 .30902 L
.52431 .30902 L
.52451 .30902 L
.52488 .30902 L
.52528 .30902 L
.52599 .30902 L
.52757 .30902 L
.52902 .30902 L
.52976 .30902 L
.53057 .30902 L
.53099 .30902 L
.53139 .30902 L
.5316 .30902 L
.5318 .30902 L
.53203 .30902 L
.53214 .30902 L
.53225 .30902 L
.53235 .30902 L
.53244 .30902 L
.53253 .30902 L
.53262 .30902 L
.53272 .30902 L
.53281 .30902 L
.53291 .30902 L
.53297 .30902 L
.53302 .30902 L
.53313 .30902 L
.53323 .30902 L
.53345 .30902 L
.53364 .30902 L
.53385 .30902 L
Mistroke
.53456 .30902 L
.53533 .30902 L
.53703 .30902 L
.53858 .30902 L
.53935 .30902 L
.53978 .30902 L
.54018 .30902 L
.54053 .30902 L
.54073 .30902 L
.54092 .30902 L
.54101 .30902 L
.54111 .30902 L
.5412 .30902 L
.5413 .30902 L
.5414 .30902 L
.54149 .30902 L
.54155 .30902 L
.5416 .30902 L
.5417 .30902 L
.54179 .30902 L
.54189 .30902 L
.54199 .30902 L
.54207 .30902 L
.54228 .30902 L
.54248 .30902 L
.54288 .30902 L
.54331 .30902 L
.54479 .30902 L
.54651 .30902 L
.54731 .30902 L
.54806 .30902 L
.54844 .30902 L
.54884 .30902 L
.54924 .30902 L
.54947 .30902 L
.54957 .30902 L
.54968 .30902 L
.54978 .30902 L
.54988 .30902 L
.54997 .30902 L
.55007 .30902 L
.55015 .30902 L
.55023 .30902 L
.55032 .30902 L
.55042 .30902 L
.55052 .30902 L
.55057 .30902 L
.55063 .30902 L
.55083 .30902 L
.55101 .30902 L
Mistroke
.5512 .30902 L
.55163 .30902 L
.55203 .30902 L
.55292 .30902 L
.55454 .30902 L
.55527 .30902 L
.55605 .30902 L
.5565 .30902 L
.55691 .30902 L
.55732 .30902 L
.55752 .30902 L
.55771 .30902 L
.5579 .30902 L
.55808 .30902 L
.55827 .30902 L
.55838 .30902 L
.55848 .30902 L
.55858 .30902 L
.55869 .30902 L
.55879 .30902 L
.55888 .30902 L
.55898 .30902 L
.55904 .30902 L
.5591 .30902 L
.5592 .30902 L
.55931 .30902 L
.55948 .30902 L
.55967 .30902 L
.56001 .30902 L
.56079 .30902 L
.56237 .30902 L
.56321 .30902 L
.5641 .30902 L
.56454 .30902 L
.56497 .30902 L
.56538 .30902 L
.56575 .30902 L
.56611 .30902 L
.56649 .30902 L
.56669 .30902 L
.56687 .30902 L
.56698 .30902 L
.56707 .30902 L
.56713 .30902 L
.56718 .30902 L
.56729 .30902 L
.56739 .30902 L
.56748 .30902 L
.56757 .30902 L
.56768 .30902 L
Mistroke
.56777 .30902 L
.56785 .30902 L
.56804 .30902 L
.56825 .30902 L
.56845 .30902 L
.56888 .30902 L
.57056 .30902 L
.57138 .30902 L
.57224 .30902 L
.57303 .30902 L
.57342 .30902 L
.57378 .30902 L
.57412 .30902 L
.57449 .30902 L
.57469 .30902 L
.57488 .30902 L
.57506 .30902 L
.57516 .30902 L
.57525 .30902 L
.57534 .30902 L
.57544 .30902 L
.57553 .30902 L
.57562 .30902 L
.57572 .30902 L
.57578 .30902 L
.57583 .30902 L
.57594 .30902 L
.57603 .30902 L
.57613 .30902 L
.57624 .30902 L
.57643 .30902 L
.57664 .30902 L
.57687 .30902 L
.57768 .30902 L
.57843 .30902 L
.5801 .30902 L
.58084 .30902 L
.58163 .30902 L
.58208 .30902 L
.58249 .30902 L
.58269 .30902 L
.5829 .30902 L
.5831 .30902 L
.58329 .30902 L
.58348 .30902 L
.58358 .30902 L
.58368 .30902 L
.58378 .30902 L
.58387 .30902 L
.58396 .30902 L
Mistroke
.58405 .30902 L
.58415 .30902 L
.58421 .30902 L
.58426 .30902 L
.58435 .30902 L
.58445 .30902 L
.58456 .30902 L
.58466 .30902 L
.58489 .30902 L
.58532 .30902 L
.58571 .30902 L
.58658 .30902 L
.58825 .30902 L
.58898 .30902 L
.58979 .30902 L
.59016 .30902 L
.59057 .30902 L
.59094 .30902 L
.59129 .30902 L
.59149 .30902 L
.59168 .30902 L
.59179 .30902 L
.59189 .30902 L
.59194 .30902 L
.592 .30902 L
.59211 .30902 L
.5922 .30902 L
.5923 .30902 L
.59235 .30902 L
.59241 .30902 L
.59251 .30902 L
.59261 .30902 L
.5927 .30902 L
.59288 .30902 L
.59307 .30902 L
.59325 .30902 L
.59366 .30902 L
.59448 .30902 L
.59596 .30902 L
.59675 .30902 L
.59758 .30902 L
.59829 .30902 L
.5987 .30902 L
.59907 .30902 L
.59927 .30902 L
.59948 .30902 L
.59971 .30902 L
.59981 .30902 L
.59992 .30902 L
.60002 .30902 L
Mistroke
.60011 .30902 L
.60021 .30902 L
.6003 .30902 L
.6004 .30902 L
.6005 .30902 L
.6006 .30902 L
.60066 .30902 L
.60072 .30902 L
.60081 .30902 L
.60091 .30902 L
.60109 .30902 L
.60149 .30902 L
.60183 .30902 L
.60221 .30902 L
.60391 .30902 L
.60546 .30902 L
.60623 .30902 L
.60667 .30902 L
.60707 .30902 L
.60742 .30902 L
.60762 .30902 L
.60781 .30902 L
.60791 .30902 L
.60801 .30902 L
.60809 .30902 L
.60819 .30902 L
.60829 .30902 L
.60835 .30902 L
.6084 .30902 L
.6085 .30902 L
.60859 .30902 L
.60869 .30902 L
.60879 .30902 L
.60897 .30902 L
.60918 .30902 L
.60938 .30902 L
.61021 .30902 L
.61169 .30902 L
.6125 .30902 L
.61335 .30902 L
.61408 .30902 L
.6145 .30902 L
.61489 .30902 L
.61527 .30902 L
.61546 .30902 L
.61566 .30902 L
.61584 .30902 L
.61594 .30902 L
.61603 .30902 L
.61612 .30902 L
Mistroke
.61621 .30902 L
.61629 .30902 L
.61637 .30902 L
.61647 .30902 L
.61656 .30902 L
.61666 .30902 L
.61674 .30902 L
.61695 .30902 L
.61715 .30902 L
.61754 .30902 L
.61797 .30902 L
.61969 .30902 L
.62124 .30902 L
.62202 .30902 L
.62246 .30902 L
.62286 .30902 L
.62321 .30902 L
.62342 .30902 L
.6236 .30902 L
.6237 .30902 L
.6238 .30902 L
.62389 .30902 L
.62398 .30902 L
.62408 .30902 L
.62413 .30902 L
.62419 .30902 L
.62429 .30902 L
.62439 .30902 L
.62449 .30902 L
.62454 .30902 L
.62459 .30902 L
.62478 .30902 L
.62501 .30902 L
.62522 .30902 L
.62601 .30902 L
.6275 .30902 L
.62897 .30902 L
.62938 .30902 L
.62981 .30902 L
.63018 .30902 L
.63059 .30902 L
.63081 .30902 L
.63102 .30902 L
.63122 .30902 L
.63132 .30902 L
.63143 .30902 L
.63153 .30902 L
.63161 .30902 L
.6317 .30902 L
.63179 .30902 L
Mistroke
.63189 .30902 L
.63198 .30902 L
.63208 .30902 L
.63214 .30902 L
.63219 .30902 L
.6323 .30902 L
.63241 .30902 L
.63261 .30902 L
.63282 .30902 L
.63306 .30902 L
.63388 .30902 L
.63557 .30902 L
.63638 .30902 L
.63712 .30902 L
.63752 .30902 L
.63788 .30902 L
.63829 .30902 L
.63851 .30902 L
.63872 .30902 L
.6389 .30902 L
.6391 .30902 L
.63926 .30902 L
.63936 .30902 L
.63945 .30902 L
.63955 .30902 L
.63965 .30902 L
.63973 .30902 L
.63983 .30902 L
.63993 .30902 L
.63998 .30902 L
.64004 .30902 L
.64023 .30902 L
.64042 .30902 L
.64063 .30902 L
.64105 .30902 L
.64179 .30902 L
.64347 .30902 L
.64428 .30902 L
.64504 .30902 L
.64547 .30902 L
.64569 .30902 L
.64592 .30902 L
.64612 .30902 L
.64634 .30902 L
.64654 .30902 L
.64673 .30902 L
.64683 .30902 L
.64693 .30902 L
.64702 .30902 L
.64713 .30902 L
Mistroke
.64718 .30902 L
.64723 .30902 L
.64729 .30902 L
.64735 .30902 L
.64745 .30902 L
.64751 .30902 L
.64756 .30902 L
.64767 .30902 L
.64776 .30902 L
.64795 .30902 L
.64836 .30902 L
.64907 .30902 L
.64985 .30902 L
.65141 .30902 L
.65183 .30902 L
.65229 .30902 L
.65273 .30902 L
.65313 .30902 L
.65353 .30902 L
.65374 .30902 L
.65397 .30902 L
.65408 .30902 L
.65419 .30902 L
.65429 .30902 L
.65439 .30902 L
.65449 .30902 L
.65459 .30902 L
.65469 .30902 L
.65478 .30902 L
.65487 .30902 L
.65497 .30902 L
.65507 .30902 L
.65516 .30902 L
.65533 .30902 L
.65551 .30902 L
.65588 .30902 L
.65629 .30902 L
.65797 .30902 L
.65871 .30902 L
.65951 .30902 L
.65989 .30902 L
.6603 .30902 L
.66065 .30902 L
.66103 .30902 L
.66125 .30902 L
.66146 .30902 L
.66165 .30902 L
.66175 .30902 L
.66186 .30902 L
.66196 .30902 L
Mistroke
.66205 .30902 L
.66216 .30902 L
.66225 .30902 L
.66235 .30902 L
.66243 .30902 L
.66252 .30902 L
.66262 .30902 L
.66272 .30902 L
.66283 .30902 L
.66305 .30902 L
.66345 .30902 L
.66434 .30902 L
.66596 .30902 L
.66677 .30902 L
.66753 .30902 L
.66796 .30902 L
.66818 .30902 L
.66841 .30902 L
.66861 .30902 L
.66883 .30902 L
.66903 .30902 L
.66921 .30902 L
.66931 .30902 L
.66937 .30902 L
.66942 .30902 L
.66952 .30902 L
.66961 .30902 L
.66966 .30902 L
.66972 .30902 L
.66982 .30902 L
.66988 .30902 L
.66993 .30902 L
.67005 .30902 L
.67015 .30902 L
.67025 .30902 L
.67043 .30902 L
.67084 .30902 L
.67155 .30902 L
.67232 .30902 L
.67388 .30902 L
.67431 .30902 L
.67476 .30902 L
.67516 .30902 L
.67537 .30902 L
.6756 .30902 L
.67581 .30902 L
.67601 .30902 L
.67621 .30902 L
.6764 .30902 L
.6765 .30902 L
Mistroke
.67661 .30902 L
.6767 .30902 L
.6768 .30902 L
.67686 .30902 L
.67691 .30902 L
.67697 .30902 L
.67703 .30902 L
.67713 .30902 L
.67719 .30902 L
.67724 .30902 L
.67733 .30902 L
.67744 .30902 L
.67762 .30902 L
.67797 .30902 L
.67837 .30902 L
.67875 .30902 L
.68039 .30902 L
.68119 .30902 L
.68192 .30902 L
.68228 .30902 L
.68268 .30902 L
.68286 .30902 L
.68305 .30902 L
.68339 .30902 L
.68358 .30902 L
.68368 .30902 L
.68378 .30902 L
.68387 .30902 L
.68397 .30902 L
.68406 .30902 L
.68414 .30902 L
.68419 .30902 L
.68425 .30902 L
.68435 .30902 L
.68445 .30902 L
.68454 .30902 L
.68464 .30902 L
.68475 .30902 L
.68497 .30902 L
.68539 .30902 L
.68579 .30902 L
.68653 .30902 L
.68735 .30902 L
.68821 .30902 L
.68897 .30902 L
.6894 .30902 L
.6898 .30902 L
.69018 .30902 L
.69052 .30902 L
.69069 .30902 L
Mistroke
.69089 .30902 L
.69099 .30902 L
.69109 .30902 L
.69119 .30902 L
.69128 .30902 L
.69138 .30902 L
.69147 .30902 L
.69156 .30902 L
.69167 .30902 L
.69172 .30902 L
.69178 .30902 L
.69189 .30902 L
.69208 .30902 L
.69246 .30902 L
.69282 .30902 L
.69449 .30902 L
.69534 .30902 L
.69613 .30902 L
.69648 .30902 L
.69685 .30902 L
.69705 .30902 L
.69726 .30902 L
.69763 .30902 L
.69783 .30902 L
.69794 .30902 L
.69805 .30902 L
.69815 .30902 L
.6982 .30902 L
.69826 .30902 L
.69835 .30902 L
.69845 .30902 L
.69854 .30902 L
.69864 .30902 L
.69874 .30902 L
.69884 .30902 L
.69893 .30902 L
.69901 .30902 L
.69919 .30902 L
.69961 .30902 L
.70006 .30902 L
.70087 .30902 L
.70244 .30902 L
.70287 .30902 L
.70333 .30902 L
.70376 .30902 L
.70416 .30902 L
.70456 .30902 L
.70478 .30902 L
.70489 .30902 L
.70501 .30902 L
Mistroke
.70512 .30902 L
.70522 .30902 L
.70532 .30902 L
.70543 .30902 L
.70552 .30902 L
.70561 .30902 L
.70571 .30902 L
.70581 .30902 L
.70591 .30902 L
.70601 .30902 L
.70622 .30902 L
.7064 .30902 L
.7066 .30902 L
.70732 .30902 L
.7089 .30902 L
.7096 .30902 L
.71036 .30902 L
.71075 .30902 L
.71111 .30902 L
.7115 .30902 L
.71172 .30902 L
.71191 .30902 L
.71202 .30902 L
.71213 .30902 L
.71222 .30902 L
.71233 .30902 L
.71238 .30902 L
.71244 .30902 L
.7125 .30902 L
.71256 .30902 L
.71266 .30902 L
.71272 .30902 L
.71277 .30902 L
.71287 .30902 L
.71296 .30902 L
.71306 .30902 L
.71317 .30902 L
.71359 .30902 L
.71398 .30902 L
.71435 .30902 L
.71519 .30902 L
.71606 .30902 L
.71689 .30902 L
.71727 .30902 L
.71767 .30902 L
.71812 .30902 L
.71831 .30902 L
.71853 .30902 L
.71872 .30902 L
.71889 .30902 L
Mistroke
.71898 .30902 L
.71907 .30902 L
.71916 .30902 L
.71924 .30902 L
.71934 .30902 L
.71943 .30902 L
.71953 .30902 L
.71959 .30902 L
.71964 .30902 L
.71973 .30902 L
.71982 .30902 L
.71992 .30902 L
.72002 .30902 L
.72023 .30902 L
.72042 .30902 L
.72086 .30902 L
.72165 .30902 L
.72314 .30902 L
.72392 .30902 L
.72427 .30902 L
.72464 .30902 L
.72506 .30902 L
.72544 .30902 L
.72565 .30902 L
.72585 .30902 L
.72596 .30902 L
.72606 .30902 L
.72612 .30902 L
.72618 .30902 L
.72624 .30902 L
.7263 .30902 L
.7264 .30902 L
.72649 .30902 L
.72658 .30902 L
.72667 .30902 L
.72677 .30902 L
.72688 .30902 L
.72707 .30902 L
.72727 .30902 L
.72746 .30902 L
.7278 .30902 L
.72946 .30902 L
.73025 .30902 L
.73068 .30902 L
.73108 .30902 L
.73145 .30902 L
.73178 .30902 L
.73216 .30902 L
.73237 .30902 L
.73256 .30902 L
Mistroke
.73265 .30902 L
.73275 .30902 L
.73284 .30902 L
.73293 .30902 L
.73299 .30902 L
.73304 .30902 L
.73314 .30902 L
.73324 .30902 L
.73334 .30902 L
.73339 .30902 L
.73345 .30902 L
.7335 .30902 L
.73356 .30902 L
.73366 .30902 L
.73377 .30902 L
.73397 .30902 L
.73416 .30902 L
.73488 .30902 L
.73564 .30902 L
.73641 .30902 L
.73723 .30902 L
.73766 .30902 L
.73813 .30902 L
.73856 .30902 L
.73875 .30902 L
.73896 .30902 L
.73915 .30902 L
.73935 .30902 L
.73946 .30902 L
.73957 .30902 L
.73967 .30902 L
.73976 .30902 L
.73985 .30902 L
.73995 .30902 L
.74004 .30902 L
.74014 .30902 L
.74023 .30902 L
.74033 .30902 L
.74042 .30902 L
.7405 .30902 L
.74071 .30902 L
.74091 .30902 L
.74135 .30902 L
.74216 .30902 L
.74367 .30902 L
.74408 .30902 L
.74452 .30902 L
.7449 .30902 L
.7453 .30902 L
.74553 .30902 L
Mistroke
.74573 .30902 L
.74593 .30902 L
.74612 .30902 L
.74623 .30902 L
.74635 .30902 L
.74646 .30902 L
.74653 .30902 L
.74659 .30902 L
.74664 .30902 L
.7467 .30902 L
.7468 .30902 L
.74685 .30902 L
.74691 .30902 L
.74696 .30902 L
.74703 .30902 L
.74713 .30902 L
.74723 .30902 L
.74746 .30902 L
.74766 .30902 L
.74787 .30902 L
.74864 .30902 L
.74946 .30902 L
.75024 .30902 L
.75099 .30902 L
.75169 .30902 L
.75205 .30902 L
.75244 .30902 L
.75264 .30902 L
.75282 .30902 L
.75293 .30902 L
.75303 .30902 L
.75309 .30902 L
.75315 .30902 L
.7532 .30902 L
.75325 .30902 L
.75331 .30902 L
.75337 .30902 L
.75342 .30902 L
.75347 .30902 L
.75357 .30902 L
.75367 .30902 L
.75373 .30902 L
.75378 .30902 L
.7539 .30902 L
.75412 .30902 L
.75432 .30902 L
.75454 .30902 L
.75493 .30902 L
.75664 .30902 L
.75745 .30902 L
Mistroke
.75819 .30902 L
.75857 .30902 L
.75897 .30902 L
.75918 .30902 L
.75937 .30902 L
.75958 .30902 L
.7597 .30902 L
.75975 .30902 L
.75981 .30902 L
.75991 .30902 L
.76001 .30902 L
.7601 .30902 L
.76019 .30902 L
.76029 .30902 L
.76038 .30902 L
.76049 .30902 L
.76059 .30902 L
.76095 .30902 L
.76134 .30902 L
.76304 .30902 L
.76385 .30902 L
.76459 .30902 L
.76497 .30902 L
.76537 .30902 L
.76557 .30902 L
.76577 .30902 L
.76598 .30902 L
.7661 .30902 L
.7662 .30902 L
.7663 .30902 L
.7664 .30902 L
.76649 .30902 L
.76658 .30902 L
.76668 .30902 L
.76674 .30902 L
.76679 .30902 L
.76688 .30902 L
.76699 .30902 L
.76707 .30902 L
.76717 .30902 L
.76734 .30902 L
.76773 .30902 L
.76932 .30902 L
.77016 .30902 L
.77062 .30902 L
.77105 .30902 L
.77143 .30902 L
.77184 .30902 L
.77208 .30902 L
.7723 .30902 L
Mistroke
.7725 .30902 L
.77261 .30902 L
.77272 .30902 L
.77281 .30902 L
.77292 .30902 L
.77301 .30902 L
.7731 .30902 L
.7732 .30902 L
.7733 .30902 L
.77336 .30902 L
.77341 .30902 L
.77351 .30902 L
.77361 .30902 L
.77371 .30902 L
.7739 .30902 L
.77425 .30902 L
.77581 .30902 L
.77664 .30902 L
.77707 .30902 L
.77753 .30902 L
.77793 .30902 L
.77814 .30902 L
.77837 .30902 L
.77858 .30902 L
.77878 .30902 L
.77897 .30902 L
.77915 .30902 L
.77924 .30902 L
.77934 .30902 L
.77944 .30902 L
.77953 .30902 L
.77962 .30902 L
.7797 .30902 L
.77979 .30902 L
.77988 .30902 L
.77998 .30902 L
.78008 .30902 L
.78026 .30902 L
.78048 .30902 L
.78068 .30902 L
.78235 .30902 L
.78309 .30902 L
.78348 .30902 L
.78389 .30902 L
.7843 .30902 L
.78467 .30902 L
.78485 .30902 L
.78505 .30902 L
.78523 .30902 L
.7854 .30902 L
Mistroke
.78559 .30902 L
.78569 .30902 L
.78574 .30902 L
.7858 .30902 L
.78585 .30902 L
.78591 .30902 L
.78597 .30902 L
.78602 .30902 L
.78608 .30902 L
.78613 .30902 L
.78623 .30902 L
.78632 .30902 L
.78642 .30902 L
.7865 .30902 L
.78659 .30902 L
.7868 .30902 L
.78699 .30902 L
.78848 .30902 L
.78927 .30902 L
.79011 .30902 L
.79057 .30902 L
.79099 .30902 L
.7912 .30902 L
.79141 .30902 L
.79162 .30902 L
.79181 .30902 L
.7919 .30902 L
.79201 .30902 L
.79209 .30902 L
.79219 .30902 L
.79224 .30902 L
.7923 .30902 L
.7924 .30902 L
.7925 .30902 L
.7926 .30902 L
.79269 .30902 L
.7928 .30902 L
.7929 .30902 L
.79299 .30902 L
.79321 .30902 L
.79343 .30902 L
.79503 .30902 L
.79573 .30902 L
.79649 .30902 L
.79691 .30902 L
.7973 .30902 L
.79768 .30902 L
.79786 .30902 L
.79807 .30902 L
.79818 .30902 L
Mistroke
.79829 .30902 L
.79839 .30902 L
.79849 .30902 L
.79854 .30902 L
.7986 .30902 L
.79871 .30902 L
.79876 .30902 L
.79883 .30902 L
.79889 .30902 L
.79894 .30902 L
.79904 .30902 L
.79913 .30902 L
.79923 .30902 L
.79934 .30902 L
.79955 .30902 L
.79975 .30902 L
.80142 .30902 L
.80216 .30902 L
.80254 .30902 L
.80296 .30902 L
.80337 .30902 L
.80374 .30902 L
.80391 .30902 L
.80411 .30902 L
.80429 .30902 L
.80446 .30902 L
.80456 .30902 L
.80467 .30902 L
.80477 .30902 L
.80486 .30902 L
.80496 .30902 L
.80501 .30902 L
.80507 .30902 L
.80517 .30902 L
.80523 .30902 L
.80529 .30902 L
.80538 .30902 L
.80547 .30902 L
.80557 .30902 L
.80568 .30902 L
.80605 .30902 L
.80644 .30902 L
.8068 .30902 L
.80761 .30902 L
.80833 .30902 L
.80908 .30902 L
.8095 .30902 L
.80987 .30902 L
.81005 .30902 L
.81025 .30902 L
Mistroke
.81043 .30902 L
.8106 .30902 L
.81081 .30902 L
.81091 .30902 L
.81103 .30902 L
.81108 .30902 L
.81114 .30902 L
.8112 .30902 L
.81126 .30902 L
.81136 .30902 L
.81141 .30902 L
.81147 .30902 L
.81157 .30902 L
.81167 .30902 L
.81177 .30902 L
.81188 .30902 L
.81207 .30902 L
.81227 .30902 L
.81397 .30902 L
.81478 .30902 L
.81552 .30902 L
.8159 .30902 L
.81629 .30902 L
.8165 .30902 L
.81669 .30902 L
.8169 .30902 L
.81702 .30902 L
.81713 .30902 L
.81722 .30902 L
.81732 .30902 L
.81742 .30902 L
.8175 .30902 L
.8176 .30902 L
.81766 .30902 L
.81771 .30902 L
.81781 .30902 L
.81791 .30902 L
.818 .30902 L
.81809 .30902 L
.81826 .30902 L
.81865 .30902 L
.82024 .30902 L
.82108 .30902 L
.82154 .30902 L
.82197 .30902 L
.82235 .30902 L
.82255 .30902 L
.82276 .30902 L
.82298 .30902 L
.8231 .30902 L
Mistroke
.82322 .30902 L
.82333 .30902 L
.82343 .30902 L
.82354 .30902 L
.82364 .30902 L
.82372 .30902 L
.82382 .30902 L
.82392 .30902 L
.82402 .30902 L
.82411 .30902 L
.82419 .30902 L
.82437 .30902 L
.82478 .30902 L
.82517 .30902 L
.826 .30902 L
.82678 .30902 L
.82749 .30902 L
.82785 .30902 L
.82824 .30902 L
.82865 .30902 L
.82886 .30902 L
.82907 .30902 L
.82926 .30902 L
.82943 .30902 L
.82953 .30902 L
.82964 .30902 L
.82974 .30902 L
.82983 .30902 L
.82992 .30902 L
.83003 .30902 L
.83013 .30902 L
.83022 .30902 L
.83032 .30902 L
.83044 .30902 L
.83064 .30902 L
.83109 .30902 L
.83151 .30902 L
.83302 .30902 L
.83343 .30902 L
.83387 .30902 L
.83424 .30902 L
.83465 .30902 L
.83488 .30902 L
.83508 .30902 L
.83519 .30902 L
.83532 .30902 L
.83542 .30902 L
.83554 .30902 L
.83565 .30902 L
.83575 .30902 L
Mistroke
.8358 .30902 L
.83585 .30902 L
.83591 .30902 L
.83597 .30902 L
.83607 .30902 L
.83616 .30902 L
.83626 .30902 L
.83632 .30902 L
.83637 .30902 L
.83658 .30902 L
.83677 .30902 L
.8372 .30902 L
.83799 .30902 L
.83871 .30902 L
.83949 .30902 L
.83994 .30902 L
.84035 .30902 L
.84054 .30902 L
.84076 .30902 L
.84096 .30902 L
.84115 .30902 L
.84135 .30902 L
.84146 .30902 L
.84158 .30902 L
.84168 .30902 L
.84177 .30902 L
.84187 .30902 L
.84193 .30902 L
.84198 .30902 L
.84207 .30902 L
.84216 .30902 L
.84226 .30902 L
.84236 .30902 L
.84245 .30902 L
.84254 .30902 L
.84273 .30902 L
.84315 .30902 L
.84354 .30902 L
.84441 .30902 L
.84515 .30902 L
.84594 .30902 L
.84639 .30902 L
.8468 .30902 L
.84699 .30902 L
.84721 .30902 L
.84741 .30902 L
.8476 .30902 L
.8477 .30902 L
.84779 .30902 L
.84788 .30902 L
Mistroke
.84797 .30902 L
.84808 .30902 L
.84813 .30902 L
.84818 .30902 L
.84828 .30902 L
.84838 .30902 L
.84847 .30902 L
.84856 .30902 L
.84873 .30902 L
.84911 .30902 L
.85076 .30902 L
.85153 .30902 L
.85196 .30902 L
.85235 .30902 L
.85271 .30902 L
.85291 .30902 L
.8531 .30902 L
.85327 .30902 L
.85345 .30902 L
.85354 .30902 L
.85364 .30902 L
.85373 .30902 L
.85382 .30902 L
.85392 .30902 L
.85402 .30902 L
.85411 .30902 L
.8542 .30902 L
.8543 .30902 L
.85436 .30902 L
.85441 .30902 L
.85461 .30902 L
.85479 .30902 L
.85499 .30902 L
.85534 .30902 L
.85701 .30902 L
.85782 .30902 L
.85828 .30902 L
.8585 .30902 L
.85871 .30902 L
.85891 .30902 L
.85908 .30902 L
.85928 .30902 L
.85939 .30902 L
.85949 .30902 L
.85959 .30902 L
.85969 .30902 L
.85975 .30902 L
.8598 .30902 L
.8599 .30902 L
.85995 .30902 L
Mistroke
.86001 .30902 L
.8601 .30902 L
.86021 .30902 L
.86027 .30902 L
.86033 .30902 L
.86053 .30902 L
.86073 .30902 L
.86116 .30902 L
.86196 .30902 L
.86267 .30902 L
.86344 .30902 L
.86389 .30902 L
.86429 .30902 L
.86468 .30902 L
.86488 .30902 L
.86509 .30902 L
.86519 .30902 L
.86529 .30902 L
.86547 .30902 L
.86557 .30902 L
.86566 .30902 L
.86576 .30902 L
.86581 .30902 L
.86587 .30902 L
.86596 .30902 L
.86605 .30902 L
.86614 .30902 L
.86624 .30902 L
.86641 .30902 L
.86659 .30902 L
.86701 .30902 L
.86742 .30902 L
.86817 .30902 L
.86898 .30902 L
.86943 .30902 L
.86985 .30902 L
.87022 .30902 L
.87062 .30902 L
.87084 .30902 L
.87106 .30902 L
.87125 .30902 L
.87136 .30902 L
.87146 .30902 L
.87154 .30902 L
.87163 .30902 L
.87172 .30902 L
.8718 .30902 L
.87189 .30902 L
.87198 .30902 L
.87208 .30902 L
Mistroke
.87218 .30902 L
.87237 .30902 L
.87255 .30902 L
.87294 .30902 L
.87375 .30902 L
.87461 .30902 L
.87534 .30902 L
.87576 .30902 L
.87615 .30902 L
.87634 .30902 L
.87655 .30902 L
.87674 .30902 L
.87692 .30902 L
.87702 .30902 L
.8771 .30902 L
.87718 .30902 L
.87727 .30902 L
.87736 .30902 L
.87744 .30902 L
.87754 .30902 L
.87763 .30902 L
.87769 .30902 L
.87774 .30902 L
.87784 .30902 L
.87794 .30902 L
.87803 .30902 L
.87824 .30902 L
.87846 .30902 L
.87923 .30902 L
.88 .30902 L
.88082 .30902 L
.88151 .30902 L
.8819 .30902 L
.88227 .30902 L
.88247 .30902 L
.88266 .30902 L
.88283 .30902 L
.88293 .30902 L
.88302 .30902 L
.88311 .30902 L
.8832 .30902 L
.8833 .30902 L
.88341 .30902 L
.88346 .30902 L
.88352 .30902 L
.88362 .30902 L
.88372 .30902 L
.88382 .30902 L
.88404 .30902 L
.88425 .30902 L
Mistroke
.88463 .30902 L
.88549 .30902 L
.88628 .30902 L
.88671 .30902 L
.88711 .30902 L
.88748 .30902 L
.88782 .30902 L
.888 .30902 L
.88819 .30902 L
.8884 .30902 L
.8885 .30902 L
.88859 .30902 L
.88868 .30902 L
.88878 .30902 L
.88889 .30902 L
.88899 .30902 L
.88908 .30902 L
.88918 .30902 L
.88927 .30902 L
.88935 .30902 L
.8894 .30902 L
.88946 .30902 L
.88956 .30902 L
.88978 .30902 L
.88997 .30902 L
.89019 .30902 L
.89107 .30902 L
.89187 .30902 L
.89226 .30902 L
.89268 .30902 L
.89304 .30902 L
.89344 .30902 L
.89366 .30902 L
.89386 .30902 L
.89408 .30902 L
.89419 .30902 L
.89431 .30902 L
.89441 .30902 L
.89452 .30902 L
.89458 .30902 L
.89463 .30902 L
.89473 .30902 L
.89483 .30902 L
.89493 .30902 L
.89503 .30902 L
.89512 .30902 L
.89522 .30902 L
.89531 .30902 L
.89549 .30902 L
.8959 .30902 L
Mistroke
.89662 .30902 L
.89743 .30902 L
.89787 .30902 L
.89828 .30902 L
.89868 .30902 L
.89912 .30902 L
.89931 .30902 L
.89951 .30902 L
.8997 .30902 L
.89987 .30902 L
.90005 .30902 L
.90015 .30902 L
.90024 .30902 L
.90032 .30902 L
.9004 .30902 L
.90049 .30902 L
.90058 .30902 L
.90067 .30902 L
.90077 .30902 L
.90086 .30902 L
.90094 .30902 L
.90114 .30902 L
.90135 .30902 L
.90295 .30902 L
.90365 .30902 L
.90402 .30902 L
.90441 .30902 L
.90461 .30902 L
.90483 .30902 L
.90522 .30902 L
.90541 .30902 L
.90552 .30902 L
.90562 .30902 L
.90571 .30902 L
.90581 .30902 L
.9059 .30902 L
.90599 .30902 L
.90609 .30902 L
.90619 .30902 L
.90625 .30902 L
.90631 .30902 L
.90636 .30902 L
.90641 .30902 L
.90647 .30902 L
.90652 .30902 L
.90665 .30902 L
.90676 .30902 L
.90686 .30902 L
.90725 .30902 L
.90767 .30902 L
Mistroke
.90842 .30902 L
.90923 .30902 L
.9097 .30902 L
.91012 .30902 L
.91032 .30902 L
.91055 .30902 L
.91074 .30902 L
.91095 .30902 L
.91117 .30902 L
.91126 .30902 L
.91137 .30902 L
.91146 .30902 L
.91156 .30902 L
.91166 .30902 L
.91175 .30902 L
.9118 .30902 L
.91186 .30902 L
.91196 .30902 L
.91206 .30902 L
.91215 .30902 L
.91225 .30902 L
.91237 .30902 L
.91259 .30902 L
.91297 .30902 L
.91338 .30902 L
.91411 .30902 L
.91495 .30902 L
.91535 .30902 L
.91572 .30902 L
.91611 .30902 L
.91633 .30902 L
.91653 .30902 L
.91675 .30902 L
.91695 .30902 L
.91706 .30902 L
.91718 .30902 L
.91724 .30902 L
.9173 .30902 L
.91736 .30902 L
.91742 .30902 L
.91752 .30902 L
.91762 .30902 L
.9177 .30902 L
.9178 .30902 L
.9179 .30902 L
.91801 .30902 L
.91821 .30902 L
.91856 .30902 L
.91894 .30902 L
.91981 .30902 L
Mistroke
.92061 .30902 L
.92099 .30902 L
.92141 .30902 L
.92161 .30902 L
.92181 .30902 L
.922 .30902 L
.92218 .30902 L
.92238 .30902 L
.92248 .30902 L
.92259 .30902 L
.92269 .30902 L
.92279 .30902 L
.92288 .30902 L
.92298 .30902 L
.92304 .30902 L
.92309 .30902 L
.92315 .30902 L
.92321 .30902 L
.92327 .30902 L
.92332 .30902 L
.92338 .30902 L
.92344 .30902 L
.92366 .30902 L
.92386 .30902 L
.92552 .30902 L
.92625 .30902 L
.92666 .30902 L
.92705 .30902 L
.92724 .30902 L
.92743 .30902 L
.92759 .30902 L
.92777 .30902 L
.92796 .30902 L
.92814 .30902 L
.92825 .30902 L
.92835 .30902 L
.92844 .30902 L
.92854 .30902 L
.92864 .30902 L
.92874 .30902 L
.92884 .30902 L
.92889 .30902 L
.92894 .30902 L
.92905 .30902 L
.92916 .30902 L
.92937 .30902 L
.92976 .30902 L
.93013 .30902 L
.93086 .30902 L
.93164 .30902 L
Mistroke
.93205 .30902 L
.93249 .30902 L
.93269 .30902 L
.93289 .30902 L
.93309 .30902 L
.93327 .30902 L
.93349 .30902 L
.93361 .30902 L
.93373 .30902 L
.93384 .30902 L
.93394 .30902 L
.934 .30902 L
.93405 .30902 L
.93411 .30902 L
.93417 .30902 L
.93427 .30902 L
.93438 .30902 L
.93447 .30902 L
.93456 .30902 L
.93479 .30902 L
.93499 .30902 L
.93661 .30902 L
.93739 .30902 L
.93779 .30902 L
.93822 .30902 L
.93859 .30902 L
.9388 .30902 L
.93899 .30902 L
.93916 .30902 L
.93926 .30902 L
.93935 .30902 L
.93944 .30902 L
.93952 .30902 L
.93962 .30902 L
.9397 .30902 L
.9398 .30902 L
.9399 .30902 L
.93999 .30902 L
.94008 .30902 L
.94029 .30902 L
.94049 .30902 L
.94132 .30902 L
.94203 .30902 L
.9428 .30902 L
.94321 .30902 L
.94358 .30902 L
.94398 .30902 L
.9442 .30902 L
.94441 .30902 L
.9445 .30902 L
Mistroke
.9446 .30902 L
.94468 .30902 L
.94477 .30902 L
.94483 .30902 L
.94488 .30902 L
.94498 .30902 L
.94507 .30902 L
.94517 .30902 L
.94525 .30902 L
.94534 .30902 L
.94543 .30902 L
.94551 .30902 L
.9457 .30902 L
.94589 .30902 L
.94735 .30902 L
.94775 .30902 L
.94818 .30902 L
.94856 .30902 L
.94896 .30902 L
.94937 .30902 L
.94959 .30902 L
.94979 .30902 L
.94989 .30902 L
.94998 .30902 L
.95007 .30902 L
.95016 .30902 L
.95026 .30902 L
.95035 .30902 L
.95044 .30902 L
.9505 .30902 L
.95055 .30902 L
.95066 .30902 L
.95071 .30902 L
.95077 .30902 L
.95087 .30902 L
.95098 .30902 L
.95118 .30902 L
.95136 .30902 L
.95224 .30902 L
.95299 .30902 L
.95379 .30902 L
.9542 .30902 L
.95442 .30902 L
.95466 .30902 L
.95487 .30902 L
.95507 .30902 L
.95527 .30902 L
.95546 .30902 L
.95555 .30902 L
.95565 .30902 L
Mistroke
.95574 .30902 L
.95583 .30902 L
.95592 .30902 L
.95603 .30902 L
.95608 .30902 L
.95613 .30902 L
.95623 .30902 L
.95629 .30902 L
.95634 .30902 L
.95646 .30902 L
.95667 .30902 L
.95706 .30902 L
.95854 .30902 L
.95891 .30902 L
.95932 .30902 L
.9597 .30902 L
.96005 .30902 L
.96026 .30902 L
.96045 .30902 L
.96067 .30902 L
.96078 .30902 L
.9609 .30902 L
.961 .30902 L
.9611 .30902 L
.9612 .30902 L
.96126 .30902 L
.96131 .30902 L
.96141 .30902 L
.96152 .30902 L
.96162 .30902 L
.96171 .30902 L
.96189 .30902 L
.96209 .30902 L
.9625 .30902 L
.96324 .30902 L
.96411 .30902 L
.96453 .30902 L
.96491 .30902 L
.96529 .30902 L
.9655 .30902 L
.96571 .30902 L
.96592 .30902 L
.96602 .30902 L
.96611 .30902 L
.96628 .30902 L
.96637 .30902 L
.96647 .30902 L
.96658 .30902 L
.96667 .30902 L
.96672 .30902 L
Mistroke
.96678 .30902 L
.96688 .30902 L
.96698 .30902 L
.96708 .30902 L
.96727 .30902 L
.96749 .30902 L
.96769 .30902 L
.96815 .30902 L
.96886 .30902 L
.96963 .30902 L
.97007 .30902 L
.97047 .30902 L
.97067 .30902 L
.97087 .30902 L
.97107 .30902 L
.97125 .30902 L
.97145 .30902 L
.97155 .30902 L
.97166 .30902 L
.97172 .30902 L
.97178 .30902 L
.97183 .30902 L
.97189 .30902 L
.97199 .30902 L
.97209 .30902 L
.97219 .30902 L
.97225 .30902 L
.9723 .30902 L
.9724 .30902 L
.9725 .30902 L
.97267 .30902 L
.97286 .30902 L
.97368 .30902 L
.97456 .30902 L
.975 .30902 L
.97541 .30902 L
.97579 .30902 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{421.375, 260.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008>0001AB000`400?l00000o`00003ooooooooo
oooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo
003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooo
oooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool0
0?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooooooo
ool@ooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooo
ooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo0ol0003o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0
003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo
00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`
ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLoooo
o`00<?ooool3o`000?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?oo
ool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo05;ooooo0_l0003o
ooooohSooooo000`ooooo`03o`000?oooooooooo05;ooooo0_l0003oooooohSooooo000`ooooo`03
o`000?oooooooooo05;ooooo0_l0003oooooohSooooo000`ooooo`03o`000?oooooooooo05;ooooo
0_l0003oooooohSooooo000`ooooo`03o`000?oooooooooo05;ooooo0_l0003oooooohSooooo000`
ooooo`03o`000?oooooooooo05;ooooo0_l0003oooooohSooooo000`ooooo`03o`000?oooooooooo
05;ooooo0_l0003oooooohSooooo000`ooooo`03o`000?oooooooooo05;ooooo0_l0003oooooohSo
oooo000`ooooo`?o0000D_ooool2o`000?ooooooR?ooool0033ooooo00?o0000ooooooooool0D_oo
ool2o`000?ooooooR?ooool0033ooooo00?o0000ooooooooool0D_ooool2o`000?ooooooR?ooool0
033ooooo00?o0000ooooooooool0D_ooool2o`000?ooooooR?ooool0033ooooo00?o0000oooooooo
ool0D_ooool2o`000?ooooooR?ooool0033ooooo00?o0000ooooooooool0D_ooool2o`000?oooooo
R?ooool0033ooooo00?o0000ooooooooool0D_ooool2o`000?ooooooR?ooool0013ooooo0_o^k^h3
ooooo`;ok^k^6Oooool00ol0003oooooooooo`1Aooooo`03o`000?oooooo00000?ooooooR?ooool0
00_ooooo0_l000002_l@413oooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h3ooooo`Co
000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP[ooooo00?o0000ooooooooool0DOoo
ool00ol0003oooooo`00000:ooooo`03o`000?oooooooooo0?ooooooNoooool000cooooo00?o0000
ooooooooool00_ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00[ooooo00?o0000ooooooooool0DOooool00ol0003ooooo
o`00000:ooooo`03o`000?oooooooooo0?ooooooNoooool00003ooooool0003o000000Co00000_oo
ool5o`0000Cooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?oo
ooooooooooooool@41002_ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooo000000[ooooo
00?o0000ooooooooool0oooooomkooooo`002Oooool01?m4A4CogMgMooooool00004ooooo`05onk^
k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000002_ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooo000000Wooooo0_l0003ooooo
oggooooo0009ooooo`04omgMgOmEEEGoooooo`0000?ooooo00Ook^k^oeEEEOo^k^koooooonk^k_mE
EEGok^k^00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000[ooooo
1?l0001@ooooo`03o`000?oooooo000000Wooooo0_l0003ooooooggooooo000:ooooo`03ogMgMoo<
c<co000000?ooooo0_o^k^h3ooooo`;ok^k^1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oo
ooooooooooooool@41002_ooool00ol0003oooooooooo`1Aooooo`03o`000?oooooo000000Wooooo
0_l0003ooooooggooooo000:ooooo`03onk^k_m4A4Co000000oooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo0_l00005ooooo`03o`000?oooooooooo057ooooo
00?o0000ooooool000002Oooool2o`000?ooooooOOooool000_ooooo00?oMgMgo`000?ooool03?oo
ool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_ooool01?l0003ooooo
ooooool00004ooooo`03o`000?oooooooooo057ooooo00?o0000ooooool000002Oooool00ol0003o
ooooo`00003oooooogcooooo000Xooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool0DOooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?ooooooO?ooool002So
oooo0ol00005ooooo`03o`000?oooooooooo057ooooo00Co0000oooooooooooo00002?ooool00ol0
003oooooo`00003oooooogcooooo000Yooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0DOooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?ooooooO?ooool002[o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Aooooo`04o`000?ooooooooooo`00
00Sooooo00?o0000ooooool00000oooooomlooooo`00<?ooool00ol0003oooooooooo`16ooooo`;o
00002Oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?ooooooO?ooool0033o
oooo00?o0000ooooooooool0A_ooool2o`0000Wooooo00Co0000oooooooooooo00002?ooool00ol0
003oooooo`00003oooooogcooooo000`ooooo`03o`000?oooooooooo04Kooooo0_l00009ooooo`04
o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooomlooooo`00<?ooool00ol0003o
ooooooooo`16ooooo`;o00002Oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo0000
0?ooooooO?ooool0033ooooo0ol00016ooooo`;o00002Oooool01?l0003oooooooooool00008oooo
o`03o`000?oooooo00000?ooooooO?ooool0033ooooo00?o0000ooooooooool0A_ooool2o`0000Wo
oooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003oooooogcooooo000`ooooo`03
o`000?oooooooooo04Gooooo00?o0000ooooool000002Oooool01?l0003oooooooooool00008oooo
o`03o`000?oooooo00000?ooooooO?ooool0033ooooo00?o0000ooooooooool0AOooool00ol0003o
ooooo`000009ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooomloooo
o`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooo000000Wooooo00Co0000oooooooo
oooo00002?ooool00ol0003oooooo`00003oooooogcooooo000`ooooo`03o`000?oooooooooo04Go
oooo00?o0000ooooool000002Oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo0000
0?ooooooO?ooool0033ooooo00?o0000ooooooooool0AOooool00ol0003oooooo`000009ooooo`04
o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooomlooooo`00<?ooool00ol0003o
ooooooooo`15ooooo`03o`000?oooooo000000Wooooo00Co0000oooooooooooo00002?ooool00ol0
003oooooo`00003oooooogcooooo000`ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooool0
00002Oooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`000?ooooooO?ooool0
033ooooo00?o0000ooooooooool0AOooool01?l0003oooooooooool00008ooooo`04o`000?oooooo
ooooo`0000Oooooo00Co0000oooooooooooo0000oooooomlooooo`00<?ooool00ol0003ooooooooo
o`15ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001oooool01?l0003o
ooooooooool0003oooooogcooooo000`ooooo`03o`000?oooooooooo04Gooooo00Co0000oooooooo
oooo00002?ooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`000?ooooooO?oo
ool0033ooooo0ol00015ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000
1oooool01?l0003oooooooooool0003oooooogcooooo000`ooooo`03o`000?oooooooooo04Gooooo
00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00007ooooo`04o`000?oooooooooo
o`000?ooooooO?ooool0033ooooo00?o0000ooooooooool0AOooool01?l0003oooooooooool00008
ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo0000oooooomlooooo`00<?oo
ool00ol0003oooooooooo`15ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo
00001oooool01?l0003oooooooooool0003oooooogcooooo000`ooooo`03o`000?oooooooooo04Go
oooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00007ooooo`04o`000?oooooo
ooooo`000?ooooooO?ooool0033ooooo00?o0000ooooooooool0AOooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo0000oooooomlooooo`00
<?ooool00ol0003oooooooooo`15ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooo
oooo00001oooool01?l0003oooooooooool0003oooooogcooooo000`ooooo`03o`000?oooooooooo
04Cooooo00Go0000ooooooooooooooooo`000008ooooo`04o`000?ooooooooooo`0000Oooooo00Co
0000oooooooooooo0000oooooomlooooo`00<?ooool00ol0003oooooooooo`14ooooo`05o`000?oo
ooooooooooooool000002?ooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`00
0?ooooooO?ooool0033ooooo00?o0000ooooooooool0A?ooool01Ol0003ooooooooooooooooo0000
00Sooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool0003oooooogcooooo000`
ooooo`03o`000?oooooooooo04Cooooo00Go0000ooooooooooooooooo`000008ooooo`04o`000?oo
ooooooooo`0000Oooooo00Co0000oooooooooooo0000oooooomlooooo`00<?ooool3o`0004Cooooo
00Go0000ooooooooooooooooo`000008ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooo
oooooooo0000oooooomlooooo`00<?ooool00ol0003oooooooooo`14ooooo`05o`000?oooooooooo
ooooool000002?ooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Wooooo
00?o0000ooooooooool0oooooom`ooooo`00<?ooool00ol0003oooooooooo`14ooooo`05o`000?oo
ooooooooooooool000002?ooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`00
00Sooooo0_l0003oooooog;ooooo000`ooooo`03o`000?oooooooooo04Cooooo00Go0000oooooooo
ooooooooo`000008ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00002?oo
ool2o`000?ooooooL_ooool0033ooooo00?o0000ooooooooool0A?ooool01Ol0003ooooooooooooo
oooo000000Sooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Oo
oooo0_l0003oooooog;ooooo000`ooooo`03o`000?oooooooooo04Cooooo00Go0000oooooooooooo
ooooo`000008ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000007
ooooo`;o0000oooooombooooo`00<?ooool00ol0003oooooooooo`14ooooo`05o`000?oooooooooo
ooooool000002?ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool00000
1oooool2o`000?ooooooL_ooool0013ooooo0_o^k^h3ooooo`;ok^k^6Oooool00ol0003ooooooooo
o`14ooooo`05o`000?ooooooooooooooool000002?ooool01?l0003oooooooooool00007ooooo`05
o`000?ooooooooooooooool000001oooool2o`000?ooooooL_ooool000Wooooo1Ol00002ooooo`07
onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co000000So410@ooooooooooook^k^oc8b
<_l0003o<S8bonk^kP[ooooo00?o0000ooooooooool0A?ooool01Ol0003ooooooooooooooooo0000
00Sooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Oooooo00?o
0000ooooool00000oooooomaooooo`002Oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00Go
k^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0:ooooo`03o`000?oooooooooo04Cooooo00Go0000ooooooooooooooooo`000007oooo
o`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00?o
0000ooooool00000oooooomaooooo`0000?oooooo`000?l000001?l00003ooooo`03oiRHV?lQ8B7o
k^k^00Gooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooo
ooooooooool@41002_ooool00ol0003oooooooooo`14ooooo`05o`000?ooooooooooooooool00000
1oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007oooo
o`03o`000?oooooo00000?ooooooLOooool000_ooooo00?oV9RHob4Q8Oo^k^h00oooool01Oo^k^ko
EEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo
000000[ooooo00?o0000ooooooooool0A?ooool01Ol0003ooooooooooooooooo000000Oooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000
1oooool00ol0003oooooo`00003oooooog7ooooo000<ooooo`0;ogMgMomVIVKoooooooooooo^k^ko
EEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000002_ooool4o`0004?ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Oo
oooo00?o0000ooooool00000oooooomaooooo`003Oooool00ol0003oooooooooo`02onk^kP?ooooo
0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400:ooooo`03
o`000?oooooooooo04Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000
00Oooooo00?o0000ooooool00000oooooomaooooo`002Oooool01Ol0003o^[ZjoooooonHV9So410@
00kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo0_l00005
ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooo
oooo000000Oooooo00?o0000ooooool00000oooooomaooooo`002Oooool01OnHV9So410@o`000?lQ
8B7oc<c<00cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?ooooooLOooool002So
oooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?ooooooLOooool0
02Sooooo0ol00005ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0
003ooooooooooooooooo000000Oooooo00?o0000ooooool00000oooooomaooooo`00:Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0
003ooooooooooooooooo000000Oooooo00?o0000ooooool00000oooooomaooooo`00:_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0
003ooooooooooooooooo000000Oooooo00?o0000ooooool00000oooooomaooooo`00<?ooool00ol0
003oooooooooo`14ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000007
ooooo`03o`000?oooooo00000?ooooooLOooool0033ooooo00?o0000ooooooooool0>Oooool2o`00
00Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000
oooooooooooo0000oooooomaooooo`00<?ooool00ol0003oooooooooo`0iooooo`;o00002Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003ooooooooo
ool0003oooooog7ooooo000`ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooool000002Ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003ooooo
ooooool0003oooooog7ooooo000`ooooo`?o0000>?ooool00ol0003oooooo`000009ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`00
0?ooooooLOooool0033ooooo00?o0000ooooooooool0>?ooool00ol0003oooooo`000009ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?oooooooooo
o`000?ooooooLOooool0033ooooo00?o0000ooooooooool0>?ooool00ol0003oooooo`000009oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?oooooo
ooooo`000?ooooooLOooool0033ooooo00?o0000ooooooooool0>?ooool00ol0003oooooo`000009
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?oo
ooooooooo`000?ooooooLOooool0033ooooo00?o0000ooooooooool0>?ooool00ol0003oooooo`00
0009ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`04o`00
0?ooooooooooo`000?ooooooLOooool0033ooooo00?o0000ooooooooool0>?ooool01?l0003ooooo
ooooool00008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006oooo
o`04o`000?ooooooooooo`000?ooooooLOooool0033ooooo00?o0000ooooooooool0>?ooool01?l0
003oooooooooool00008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00
0006ooooo`04o`000?ooooooooooo`000?ooooooLOooool0033ooooo00?o0000ooooooooool0>?oo
ool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooo
ooooo`000006ooooo`04o`000?ooooooooooo`000?ooooooLOooool0033ooooo00?o0000oooooooo
ool0>?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooo
ooooooooooooo`000006ooooo`04o`000?ooooooooooo`000?ooooooLOooool0033ooooo00?o0000
ooooooooool0=oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`00003oooooog3o
oooo000`ooooo`03o`000?oooooooooo03Oooooo00Go0000ooooooooooooooooo`000008ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?oooooooooo
ooooool000001oooool00ol0003oooooooooo`3oooooofKooooo000`ooooo`03o`000?oooooooooo
03Oooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000
ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001oooool00ol0003ooooo
ooooo`3oooooofKooooo000`ooooo`?o0000=oooool01Ol0003ooooooooooooooooo000000Sooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000oooooooo
ooooooooo`000006ooooo`03o`000?oooooo00000?ooooooIoooool0033ooooo00?o0000oooooooo
ool0=oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0
003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oo
oooo00000?ooooooIoooool0033ooooo00?o0000ooooooooool0=oooool01Ol0003ooooooooooooo
oooo000000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo00000?oooooo
Ioooool0033ooooo00?o0000ooooooooool0=oooool01Ol0003ooooooooooooooooo000000Sooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo00000?ooooooIoooool0033ooooo
00?o0000ooooooooool0=oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooo
ooooooooo`000006ooooo`03o`000?oooooo00000?ooooooIoooool0033ooooo00?o0000oooooooo
ool0=oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`;ok^k^00?o0000ooooooooool00_o^k^h00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo
000000Kooooo00?o0000ooooool00000=oooool2onk^kP?ooooo0_o^k^iPooooo`;ok^k^0oooool2
onk^kTkooooo0_o^k^h3ooooo`;ok^k^K?ooool0033ooooo00?o0000ooooooooool0=oooool01Ol0
003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00_ooool03_m4A4Co0000o`000?lb
<S;ogMgMooooooo^k^koEEEEo`000?ooooook^k^oeEEEOo^k^ko00000_ooool4o`000008oa0@4?oo
ooooooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`05o`000?ooooooooooooooool000001_ooool0
0ol0003oooooo`00000aooooo`Co000000Wo410@ooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^
k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hkooooo`Co000000?o
410@ooooooooool00_ooool2ob4Q8@Gooooo00goA4A4o`000?l0003o<S8bomgMgOooooook^k^oeEE
EOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb
<S;ok^k^>?ooool5o`0000;ooooo00Ook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l0
00002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^GOooool0033ooooo00?o0000oooooooo
ool0=oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00oooool01?l0
003oooooogMgMolb<S82ooooo`07onk^k_l0003ogMgMoeEEEOo^k^koooooo`000004ooooo`;o0000
0oooool01OmgMgOoV9RHo`000?nHV9SoMgMg00?ooooo00Go0000ooooooooooooooooo`000005oooo
o`04o`000?ooooooooooo`0003?ooooo00?o0000ooooooooool00_ooool01Oo^k^koEEEEomgMgOmE
EEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg03gooooo
00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00WoMgMgoc8b<_ooooooooooonk^k_mEEEGogMgM
oeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0>?oo
ool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Mooooo`00<?ooool00ol0003o
ooooooooo`0gooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`03oooo
o`04o`000?ooooooooooo`0000?ooooo0_l000001?oMgMgoooooooooool00004ooooo`;o00000ooo
ool01Ol@413oooooo`000?oooooo410@00?ooooo00Go0000ooooooooooooooooo`000005ooooo`04
o`000?ooooooooooo`0003?ooooo00?o0000ooooooooool00oooool00ooMgMgo0000omgMg@07oooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400mooooo`03o`000?oooooo
oooo00oooooo00Oo0000ooooooooooooooooomgMgOl0003ogMgM00Oooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@03Wooooo00?oV9RHob4Q8Oo^k^h01Oooool00ooMgMgo
0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@401Moooo
o`00<?ooool00ol0003oooooooooo`0gooooo`05o`000?ooooooooooooooool000001oooool00ol0
003oooooooooo`03ooooo`04o`000?ooooooMgMgoc8b<P;ooooo00Oo0000oeEEEOoMgMgoEEEEonk^
k_oooooo000000Cooooo0_l00003ooooo`05o`000?oooooo0000ooooool000000oooool01Ol0003o
oooooooooooooooo000000Gooooo00Go0000ooooooooooooooooo`00000booooo`03o`000?oooooo
oooo00;ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`00000mooooo`03o`000?oooooooooo00kooooo00WoMgMgoc8b<_oooooo
ooooonk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool00000>_ooool00onHV9So8B4Qonk^kP03ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h0
1_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000GOooool0033ooooo
00?o0000ooooooooool0=oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000oooooooo
ool00_ooool3o`00000;oc8b<_o<c<coooooonk^k_l0003ok^k^ooooooo^k^koEEEEonk^k_l00000
1?ooool2o`0000?ooooo00Go0000ooooool0003oooooo`000003ooooo`05o`000?oooooooooooooo
ool000001Oooool01Ol0003ooooooooooooooooo000003;ooooo00_o0000ooooooooooooooooonk^
k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`00000mooooo`03o`000?oooooooooo00_ooooo00go0000ob4Q8Ol0003o<S8bolc<
c?ooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000003_ooooo00_oMgMgofIVI_ooooooooooonk^k_mEEEGok^k^oooo
ooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
001Mooooo`00<?ooool00ol0003oooooooooo`0gooooo`05o`000?ooooooooooooooool000001ooo
ool00ol0003oooooooooo`02ooooo`;o00001?ooool00oo^k^ko0000ooooo`02ooooo`;ok^k^00?o
0000ooooooooool00_ooool2o`0000?ooooo00Go410@ooooool0003ooooooa0@4003ooooo`05o`00
0?ooooooooooooooool000001Oooool01Ol0003ooooooooooooooooo000003;ooooo00Co0000oooo
oooooooooooo0_o^k^h3ooooo`;ok^k^1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooo
ooooooooool@4100?Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo0_o^
k^h3ooooo`;ok^k^1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100
??ooool00ol0003oooooooooo`02onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo
00Go410@oooooooooooooooooa0@401Mooooo`00<?ooool3o`0003Oooooo00Go0000oooooooooooo
ooooo`000007ooooo`03o`000?oooooooooo00;ooooo0_l00005ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool2o`0000?ooooo00GoMgMgoiRHV?l0003oV9RHogMgM`03oooo
o`04o`000?ooooooooooooooo`;o00001?ooool01Ol0003ooooooooooooooooo000003;ooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2?ooool2o`0003?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`;o0000;_ooool01Ol0003o
^[ZjoooooonHV9So410@00kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Sooooo0_l0001Cooooo`00<?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`Co00000oooool00ol0
003oooooooooo`03ooooo`05o`000?oooooooooooeEEEOmVIVH00_l00003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00oooool01?l0003oooooooooooooool2o`0000Cooooo00Go0000oooooooooooo
ooooo`00000`ooooo`03oeEEEOmVIVKo000000gooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Oooooo00Co0000oooooooooooo0000<?ooool00omEEEGoIVIVo`00000=
ooooo`Co00003?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01ooo
ool01?l0003oooooooooool0000]ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?ooool00omEEEGo
IVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01oooool01?l0003oooooooooool0001B
ooooo`00<?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`Co000000Coooooo`000?oooooo00000oooool0
1Ol0003ooooooooooooooooo000004kooooo1?l000001Ooooooo0000oooooooooooo000005kooooo
1?l000001Ooooooo0000oooooooooooo000004cooooo1?l000001Ooooooo0000oooooooooooo0000
05;ooooo000`ooooo`03o`000?oooooooooo02[ooooo0ol00009ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000?o
oooo00Go0000ooooooooooooooooo`000006ooooo`;o0000Boooool3o`0006Cooooo0ol0001Boooo
o`?o0000Doooool0033ooooo00?o0000ooooooooool0:_ooool01?l0003oooooo`000?l00008oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`000006ooooo`?o0000Booo
ool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0D_oo
ool0033ooooo00?o0000ooooooooool0:Oooool01Ol0003ooooooooooooooooo000000Sooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo1?l0
0002ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooo`00001<ooooo`03o`00
0?oooooooooo06Cooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`1Aooooo`00<?oo
ool00ol0003oooooooooo`0Yooooo`05o`000?ooooooooooooooool000002?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooo`00003ooooooego
oooo000`ooooo`03o`000?oooooooooo02Wooooo00Go0000ooooooooooooooooo`000008ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000005ooooo`04o`000?oooooooooo
o`000?oooooo8oooool00omgMgOoIVIVooooo`0]ooooo`03ofIVI_mgMgOooooo00Oooooo000`oooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000005ooooo`05o`000?oooooo
ooooooooool00000oooooolQooooo`03omgMgOl@413ok^k^02kooooo00?ok^k^oa0@4?oMgMd01ooo
ool0033ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Gooooo00Go
0000ooooooooooooooooo`000005ooooo`?o0000ooooool7ooooo`;o00000_ooool2o`0000cooooo
00?oEEEEoiRHV?ooool00_l00002ooooo`07o`000?ooooooooooo`000?l@413ok^k^oeEEE@02o`00
0003odA4A?nj^[[ooooo00;ooooo00GoV9RHo`000?l0003oA4A4okZj^P02ooooo`08onk^k_mEEEGo
0000o`000?m4A4Co^[Zjooooool@4105o`0000?ooooo00So410@oc8b<_l0003o0000oa0@4?nYZJWo
QhN7ofIVIPOooooo000`ooooo`03o`000?oooooooooo01_ooooo0_l0000:ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Cooooo00?o
0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Gooooo00Co0000ooooool0003o
0000ooooool6ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM3?ooool01Ol0003ooooooooooooo
oooo000000;ooooo00_o0000oooooooooooo0000oooooomEEEGoMgMgooooooo^k^koMgMgoa0@4003
ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000_ooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40?o
oooo00?o0000ooooooooool01?ooool02?l0003oZJVYoooooooooooo^[Zjo`000?o^k^ko00001ooo
ool00?oo0000]?l0000?ooooo`04omgMgOl0003o410@olc<c0gooooo00Go<S8boooooooooooooooo
o`000002ooooo`06o`000?ooooooooooo`000?oooooo00002?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool01onj^[[oQhN7ofIVI_mVIVKo
410@ooooool000001oooool000[ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03?ooool01Ol0003ooooooooooooo
oooo000000;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooo000000Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oo
oooo0000ooooool000001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
0_l00002ooooo`03o`000?oooooooooo00;ooooo1?l00006ooooo`;o00004Oooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool05oooool01?o^k^ko8B4Q
oa0@4?o^k^h=ooooo`05oc8b<_ooooooooooooooool000000_ooool01Ol0003oooooooooool0003o
oooo00Ko00000oooool00ol0003oooooooooo`04ooooo`Ko00000oooool00ol0003oooooooooo`04
ooooo`08oc8b<_lQ8B7oMgMgogMgMon7QhOok^k^ooooool00007ooooo`002_ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0=ooooo`;o000000Coooooo`000?oooooo00002?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooo000000Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05
o`000?oooooo0000ooooool000001Oooool01Ol0003ooooooooooooooooo000000Gooooo0_l00002
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool05oooool01?lQ8B7oMgMgogMgMolb
<S8=ooooo`05o`000?o^k^koooooooooool000000_o<c<`02ol0003oZJVYomgMgOlQ8B7ooooooeEE
EOn7QhOok^k^oooooon7QhOo<S8b00?ooooo00?o0000ooooooooool01?ooool01_mEEEGoQhN7onk^
k_ooooooQhN7oc8b<P?ooooo00?o0000oc8b<_oMgMd01?ooool02?l0003o^[Zjooooooo^k^koMgMg
o`000?o^k^ko00001oooool0033ooooo00?o0000ooooooooool08_ooool4o`0000Sooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool01Ol0003ooooooooooooooooo000000Gooooo00Go0000oooooooooooooooo
o`000005ooooo`04o`000?ooooooooooo`0003Gooooo00?o0000ooooooooool0Foooool00ol0003o
ooooooooo`1Kooooo`03o`000?oooooooooo01Kooooo0_l00002ooooo`;o00003?ooool03_mEEEGo
MgMgooooool@413o0000ob4Q8Ol0003oMgMgoa0@4?l0003oZJVYooooooo^k^koEEEE0_l000001?m4
A4Cok^k^ooooool@4105o`0000?ooooo00Kok^k^oeEEEOl0003o0000odA4A?o^k^h2ooooo`;o0000
00CoZJVYob4Q8Ol0003o8B4Q0_ooool02?nYZJWo8B4Qo`000?l0003o<S8bo`000?mgMgOoEEEE1ooo
ool0033ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooo
ooooooooool000001Oooool01Ol0003ooooooooooooooooo000000Kooooo0_l0003ooooooakooooo
00?ogMgMoa0@4?o^k^h04_ooool00ol0003oooooooooo`0Iooooo`03onk^k_l@413ogMgM00Oooooo
000`ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooo
oooooooo000000Gooooo00Go0000ooooooooooooooooo`000006ooooo`;o0000oooooolOooooo`03
ogMgMomVIVKooooo017ooooo00?o0000ooooooooool06Oooool00omVIVKoMgMgooooo`07ooooo`00
<?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooo
ooooo`000005ooooo`05o`000?ooooooooooooooool00000oooooomQooooo`00<?ooool00ol0003o
ooooooooo`0_ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000005oooo
o`04o`000?ooooooooooo`000?ooooooH_ooool0033ooooo00?o0000ooooooooool0;oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001Oooool01?l0003oooooooooool0
003oooooof;ooooo000`ooooo`03o`000?oooooooooo033ooooo00Go0000ooooooooooooooooo`00
0007ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooo
oooooooo000000Gooooo00Co0000oooooooooooo0000oooooomRooooo`00<?ooool00ol0003ooooo
ooooo`0`ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo0000
0?ooooooH_ooool0033ooooo00?o0000ooooooooool0<?ooool01Ol0003ooooooooooooooooo0000
00Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooooooo
ooooool000001_ooool00ol0003oooooo`00003oooooof;ooooo000`ooooo`?o0000<?ooool01Ol0
003ooooooooooooooooo000000Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooo`00003oooooof;ooooo000`
ooooo`03o`000?oooooooooo033ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooool00000oooooomRooooo`00<?ooool00ol0003oooooooooo`0`ooooo`05o`000?oo
ooooooooooooool000002?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo00000?ooooooH_ooool0033ooooo
00?o0000ooooooooool0<?ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001_ooool2o`00
0?ooooooHoooool0033ooooo00?o0000ooooooooool0<Oooool01?l0003oooooooooool00008oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo
000000Oooooo00?o0000ooooooooool0oooooomQooooo`00<?ooool00ol0003oooooooooo`0aoooo
o`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`05o`000?ooooooooooooooool00000oooooom[ooooo`00<?ooool00ol0003oooooooooo`0a
ooooo`03o`000?oooooo000000Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`05o`000?ooooooooooooooool00000oooooom[ooooo`00<?ooool00ol0003oooooooooo`0a
ooooo`?o00002Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000oooooooooooooooo
o`00003oooooof_ooooo000`ooooo`03o`000?oooooooooo03;ooooo0_l00009ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oo
ooooooooooooool000001_ooool01Ol0003ooooooooooooooooo00000?ooooooJoooool0033ooooo
00?o0000ooooooooool0<_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo
00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0
003ooooooooooooooooo00000?ooooooJoooool0033ooooo00?o0000ooooooooool0?Oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooo
oooo000000Kooooo00Go0000ooooooooooooooooo`00003oooooof_ooooo000`ooooo`03o`000?oo
oooooooo03gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo
00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool00000oooooom[oooo
o`00<?ooool3o`0003gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000
00Kooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool00000oooo
oom[ooooo`00<?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000
ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003ooooo
ooooool0003oooooofcooooo000`ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000007oooo
o`03o`000?oooooo00000?ooooooK?ooool0033ooooo00?o0000ooooooooool0?Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo
000000Oooooo00?o0000ooooool00000oooooom/ooooo`00<?ooool00ol0003oooooooooo`0moooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?oooooo
ooooooooool000001oooool00ol0003oooooo`00003oooooofcooooo000`ooooo`03o`000?oooooo
oooo03gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go
0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?ooooooK?ooool0033ooooo00?o
0000ooooooooool0?Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000
1_ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooool00000oooooom/ooooo`00
<?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooo
ooooo`000006ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003ooooo
ofcooooo000`ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003o
oooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo
00000?ooooooK?ooool0033ooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04oooo
o`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Oooooo00?o
0000ooooool00000oooooom/ooooo`00<?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool00000
1oooool00ol0003oooooo`00003oooooofcooooo000`ooooo`03o`000?oooooooooo03gooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000oooooooooooo
ooooo`000007ooooo`03o`000?oooooo00000?ooooooK?ooool0033ooooo0ol0000mooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?oooooooooooooo
ool000001oooool00ol0003oooooo`00003oooooofcooooo000`ooooo`03o`000?oooooooooo03ko
oooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`00
0007ooooo`;o0000oooooom]ooooo`00<?ooool00ol0003oooooooooo`0nooooo`05o`000?oooooo
ooooooooool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go
0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001oooool2o`000?oo
ooooKOooool0033ooooo00?o0000ooooooooool0?_ooool01Ol0003ooooooooooooooooo000000Oo
oooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool0
1Ol0003ooooooooooooooooo000000Oooooo0_l0003oooooofgooooo000`ooooo`03o`000?oooooo
oooo03kooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool00000
1oooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000008oooo
o`03o`000?oooooooooo0?ooooooJoooool0033ooooo00?o0000ooooooooool0?_ooool01Ol0003o
oooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooo
ooooooooool000001_ooool01Ol0003ooooooooooooooooo00000?ooooooM_ooool000oooooo0_o^
k^h3ooooo`;ok^k^6_ooool00ol0003oooooooooo`0nooooo`05o`000?ooooooooooooooool00000
1oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007oooo
o`04o`000?ooooooooooo`000?ooooooM_ooool000Sooooo1Ol00002ooooo`07onk^k_mEEEGok^k^
ooooooo^k^koEEEEonk^kP03ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^
kP_ooooo00?o0000ooooooooool0?_ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000
ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool01?l0003ooooo
ooooool0003oooooogKooooo0008ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01Oo^k^ko
EEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00?o0000ooooooooool0?_ooool01Ol0003ooooooooooooooooo000000Oooooo00Go
0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool01?l0003o
ooooooooool0003oooooogKooooo0009ooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?ogMgMo`000?oM
gMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41002oooool00ol0
003oooooooooo`0nooooo`04o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`00
0007ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool0003oooooogKo
oooo000:ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03
o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000;ooooo`03o`000?oooooooooo
03kooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go
0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`000?ooooooM_ooool000_ooooo
00_oMgMgofIVI_ooooooooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000;ooooo`Co0000?Oooool01?l0003ooooo
ooooool00008ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo
000000Oooooo00Co0000oooooooooooo0000oooooomfooooo`003?ooool00ol0003oooooooooo`02
onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03o`000?oooooooooo03oooooo00?o0000ooooool000002?ooool01Ol0003ooooooooo
oooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`00
0?ooooooM_ooool000Sooooo00Go0000okZj^_ooooooV9RHoa0@400>ooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03o`000?oooooooooo03oooooo00?o0000
ooooool000002Oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool00000
1oooool01?l0003oooooooooool0003oooooogKooooo0008ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`03?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool2o`00
00Kooooo00?o0000ooooooooool0?oooool00ol0003oooooo`000009ooooo`04o`000?oooooooooo
o`0000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`000?oooooo
M_ooool002Oooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`0oooooo`03o`00
0?oooooo000000Wooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000
00Oooooo00Co0000oooooooooooo0000oooooomfooooo`009oooool01?l0003oooooooooool00005
ooooo`03o`000?oooooooooo03oooooo00?o0000ooooool000002Oooool01?l0003oooooooooool0
0007ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool0003oooooogKo
oooo000Wooooo`?o00001_ooool00ol0003oooooooooo`0oooooo`03o`000?oooooo000000Wooooo
00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooo
oooooooo0000oooooomfooooo`00:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
03oooooo00?o0000ooooool000002Oooool01?l0003oooooooooool00007ooooo`05o`000?oooooo
ooooooooool000001oooool01?l0003oooooooooool0003oooooogKooooo000Yooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0?oooool00ol0003oooooo`000009ooooo`04o`000?oo
ooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`00
0?ooooooM_ooool0033ooooo00?o0000ooooooooool0?oooool00ol0003oooooo`000009ooooo`04
o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?oooooo
ooooo`000?ooooooM_ooool0033ooooo00?o0000ooooooooool0?oooool00ol0003oooooo`000009
ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04o`00
0?ooooooooooo`000?ooooooM_ooool0033ooooo00?o0000ooooooooool0?oooool00ol0003ooooo
o`000009ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000007oooo
o`04o`000?ooooooooooo`000?ooooooM_ooool0033ooooo0ol0000oooooo`03o`000?oooooo0000
00Wooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co
0000oooooooooooo0000oooooomfooooo`00<?ooool00ol0003oooooooooo`0oooooo`03o`000?oo
oooo000000Wooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Oo
oooo00Co0000oooooooooooo0000oooooomfooooo`00<?ooool00ol0003oooooooooo`0oooooo`;o
00002_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001oooool0
1?l0003oooooooooool0003oooooogKooooo000`ooooo`03o`000?oooooooooo043ooooo00?o0000
ooooooooool02?ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool00000
1oooool00ol0003oooooo`00003oooooogOooooo000`ooooo`03o`000?oooooooooo043ooooo00?o
0000ooooooooool02?ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool0
00001oooool00ol0003oooooo`00003oooooogOooooo000`ooooo`03o`000?oooooooooo04_ooooo
00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000oooo
ool00000oooooomgooooo`00<?ooool00ol0003oooooooooo`1;ooooo`04o`000?ooooooooooo`00
00Oooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?ooooooMoooool0
033ooooo00?o0000ooooooooool0Boooool01?l0003oooooooooool00007ooooo`05o`000?oooooo
ooooooooool000001oooool00ol0003oooooo`00003oooooogOooooo000`ooooo`03o`000?oooooo
oooo04_ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Oooooo
00?o0000ooooool00000oooooomgooooo`00<?ooool00ol0003oooooooooo`1;ooooo`04o`000?oo
ooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?oo
ooooMoooool0033ooooo00?o0000ooooooooool0Boooool01?l0003oooooooooool00007ooooo`05
o`000?ooooooooooooooool000002?ooool2o`000?ooooooMoooool0033ooooo00?o0000oooooooo
ool0Boooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo0_l0003o
ooooogOooooo000`ooooo`?o0000Boooool01?l0003oooooooooool00008ooooo`04o`000?oooooo
ooooo`0000Sooooo0_l0003oooooogOooooo000`ooooo`03o`000?oooooooooo04_ooooo00Co0000
oooooooooooo00002?ooool01?l0003oooooooooool00008ooooo`;o0000oooooomgooooo`00<?oo
ool00ol0003oooooooooo`1;ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo
00002?ooool2o`000?ooooooMoooool0033ooooo00?o0000ooooooooool0Boooool01?l0003ooooo
ooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo0_l0003oooooogOooooo000`ooooo`03
o`000?oooooooooo04_ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00008
ooooo`;o0000oooooomgooooo`00<?ooool00ol0003oooooooooo`1;ooooo`04o`000?oooooooooo
o`0000Sooooo00Co0000oooooooooooo00002?ooool2o`000?ooooooMoooool0033ooooo00?o0000
ooooooooool0Boooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo
0_l0003oooooogOooooo000`ooooo`03o`000?oooooooooo04_ooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool00008ooooo`;o0000oooooomgooooo`00<?ooool00ol0003ooooo
ooooo`1;ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002?ooool2o`00
0?ooooooMoooool0033ooooo00?o0000ooooooooool0Boooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`000?ooooooPOooool0033ooooo00?o0000ooooooooool0Boooool01?l0
003oooooooooool00008ooooo`04o`000?ooooooooooo`000?ooooooPOooool0033ooooo00?o0000
ooooooooool0Boooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`000?oooooo
POooool0033ooooo0ol0001;ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo
0000oooooon1ooooo`00<?ooool00ol0003oooooooooo`1;ooooo`04o`000?ooooooooooo`0000So
oooo00?o0000ooooool00000oooooon2ooooo`00<?ooool00ol0003oooooooooo`1;ooooo`04o`00
0?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooon2ooooo`00<?ooool00ol0003ooooo
ooooo`1;ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooon2ooooo`00
<?ooool00ol0003oooooooooo`1;ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool0
0000oooooon2ooooo`00<?ooool00ol0003oooooooooo`1;ooooo`04o`000?ooooooooooo`0000So
oooo00?o0000ooooool00000oooooon2ooooo`003oooool2onk^kP?ooooo0_o^k^hJooooo`03o`00
0?oooooooooo04_ooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003ooooooh;o
oooo000:ooooo`;o000000[o410@ooooooooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^0ooo
ool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`03o`000?oooooooooo
04_ooooo00?o0000ooooool000002Oooool00ol0003oooooo`00003ooooooh;ooooo000;ooooo`03
o`000?oooooooooo00;ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03o`000?oooooooooo04_ooooo00?o0000
ooooool000002Oooool00ol0003oooooo`00003ooooooh;ooooo0008ooooo`Go00001?ooool00ooM
gMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400;
ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooool000002Oooool00ol0003oooooo`00003o
oooooh;ooooo0008ooooo`04odA4A?oMgMgoooooo`0000Cooooo00Gok^k^oeEEEOoMgMgoEEEEonk^
kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000;ooooo`03o`00
0?oooooooooo04_ooooo00?o0000ooooool000002Oooool00ol0003oooooo`00003ooooooh;ooooo
0008ooooo`04omgMgOmEEEGoooooo`0000?ooooo00Ook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^
00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000_ooooo1?l0001:
ooooo`03o`000?oooooo000000Wooooo00?o0000ooooool00000oooooon2ooooo`002Oooool00omg
MgOoc<c<o`000003ooooo`;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@
413ooooooooooooooooo410@00_ooooo00?o0000ooooooooool0C?ooool2o`0000Wooooo00?o0000
ooooool00000oooooon2ooooo`002Oooool00oo^k^koA4A4o`00000?ooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03o`000?oooooooooo04cooooo0_l00009
ooooo`03o`000?oooooo00000?ooooooP_ooool000[ooooo00?oMgMgo`000?ooool03?ooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool2o`0000Kooooo00?o0000
ooooooooool0C?ooool2o`0000Wooooo00?o0000ooooool00000oooooon2ooooo`009oooool01?l0
003oooooooooool00005ooooo`03o`000?oooooooooo04cooooo0_l00009ooooo`03o`000?oooooo
00000?ooooooP_ooool002Oooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`1<
ooooo`;o00002Oooool00ol0003oooooo`00003ooooooh;ooooo000Wooooo`?o00001_ooool00ol0
003oooooooooo`1<ooooo`;o00002Oooool00ol0003oooooo`00003ooooooh;ooooo000Xooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0C?ooool2o`0000Wooooo00?o0000ooooool0
0000oooooon2ooooo`00:Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04cooooo
0_l00009ooooo`03o`000?oooooo00000?ooooooP_ooool0033ooooo00?o0000ooooooooool0C?oo
ool2o`0000Wooooo00?o0000ooooool00000oooooon2ooooo`00<?ooool00ol0003oooooooooo`1<
ooooo`;o00002_ooool2o`000?ooooooP_ooool0033ooooo00?o0000ooooooooool0C?ooool2o`00
00[ooooo0_l0003ooooooh;ooooo000`ooooo`?o0000C?ooool2o`0000[ooooo0_l0003ooooooh;o
oooo000`ooooo`03o`000?oooooooooo05Sooooo0_l0003ooooooh;ooooo000`ooooo`03o`000?oo
oooooooo05Sooooo0_l0003ooooooh;ooooo000`ooooo`03o`000?oooooooooo05Sooooo0_l0003o
oooooh;ooooo000`ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool0oooooon1oooo
o`00<?ooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo0?ooooooPOooool0033ooooo
00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`
ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLoooo
o`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooo
g?ooool0033ooooo0ol0003oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0
033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomco
oooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooo
oooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooo
ooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000
ooooooooool0oooooooLooooo`00<?ooool3o`000?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00oooooooooooo
oa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003o
oooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo
4?ooool00:Cooooo0_l00003ooooo`03okZj^_lb<S;ooooo00Gooooo0_l00005ooooo`03o`000?nj
^[[ooooo0?ooooooE?ooool00:Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00?ooooo0_lb<S;ooooooeGooooo002Aooooo`?o00000_ooool01_lb
<S;o410@ooooooooooook^k^oeEEE@;o000000?oA4A4okZj^_ooool00oooool01_l0003ooooooooo
ooooooooV9RHoa0@40;o000000?oZJVYooooooooool00oooool00ol0003oooooooooo`03ooooo`03
ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0;ooooo`;o000000?o410@oooo
ooooool00oooool2ob4Q8@?ooooo00Goc<c<onk^k_ooooook^k^olc<c004ooooo`Co000000So410@
ooooooooooook^k^oc8b<_l0003o<S8bonk^kQ?ooooo00Ko410@oc8b<_l0003o0000oa0@4?nYZJT2
ooooo`06onk^k_mEEEGo0000o`000?m4A4Co^[Zj0oooool01OmVIVKo0000o`000?m4A4Coc<c<0>co
oooo002Booooo`05o`000?ooooooooooolc<c?l@41000oooool01_mEEEGoMgMgooooooo^k^koMgMg
oa0@40Cooooo00[o0000ooooooooooooooooo`000?nYZJWoEEEEoiRHV?mEEEGo^[Zj1?ooool00ol0
003oooooooooo`03ooooo`03olc<c?l0003o410@00cooooo00Go410@okZj^_o^k^koMgMgoa0@4002
ooooo`Ko00001?ooool00ol0003oooooooooo`04ooooo`;o8B4Q0oooool01Oo^k^koEEEEomgMgOmE
EEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01?ooooo
00Ko0000ojVYZOoooooooooookZj^_l00002ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo410@0_oo
ool01_mVIVKoMgMgooooooooooooQhN7oa0@4>cooooo002Booooo`05o`000?oooooooooooeEEEOn7
QhL00oooool00ol0003oooooooooo`07ooooo`0:o`000?oooooooooooooooolb<S;ok^k^oiRHV?mE
EEGogMgMoa0@40Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0;ooooo`Go0000
2oooool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@400Dooooo`05okZj^_n7QhOoIVIVofIVI_l@41000_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo0>oooooo002Booooo`05o`000?oooooogMgMo`000?o^k^h00oooool6o`00
00Cooooo00_o0000oooooooooooooooookZj^_m4A4Coc<c<ob4Q8Ooooooo410@olc<c003ooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool01?ooool6o`000005oooooom4A4CogMgMoooo
ool000002oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000001?ooooo00Ko<S8bob4Q8OmgMgOoMgMgohN7Qoo^k^h2ooooo`Ko
00000_ooool00ol0003oooooooooo`3_ooooo`00T_ooool3o`000003oa0@4?nHV9Sooooo00;ooooo
00KoEEEEohN7Qoo^k^koooooohN7Qolb<S84ooooo`0;o`000?ooooooooooooooooo^k^ko0000oooo
ool0003oooooofIVI_n7QhL00oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00_o
oooo00CogMgMoeEEEOoooooo00002oooool01Oo<c<cok^k^ooooooo^k^koc<c<00Kooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000001?ooooo00Ko0000okZj^_ooooook^k^
ogMgMol00002ooooo`06oeEEEOn7QhOok^k^oooooon7QhOo<S8b0_ooool01_mVIVKoMgMgoooooooo
ooooQhN7o`000>cooooo002Booooo`05o`000?ooooooooooolc<c?l000000oooool01_o^k^koEEEE
o`000?l0003oA4A4onk^kPCooooo00So0000ooooooooooooooooofIVI_nHV9Sooooooc8b<P;o^[Zj
00Go0000ooooooooooooooooo`00000Booooo`03oa0@4?l0003o000000?o00002oooool00omgMgOo
c<c<o`00000Fooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4007oooo
o`?o00000_ooool3o`0000Cooooo00KoZJVYob4Q8Ol0003o0000oc8b<_l00002ooooo`06onk^k_mE
EEGo0000o`000?m4A4Cok^k^0_ooool01_o^k^koIVIVo`000?l0003oA4A4o`000>cooooo002Boooo
o`05o`000?ooooooooooolc<c?l000003Oooool00ol0003oooooooooo`04ooooo`03ofIVI_n7QhOo
oooo00Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0<ooooo`03onk^k_m4A4Co
000001Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`3oooooo`Kooooo002Aooooo`Co000000?o410@
ojVYZOooool03?ooool2o`0000Gooooo00?oZJVYodA4A?ooool00oooool2o`0001Cooooo00?o0000
ooooooooool03Oooool00omgMgOo0000ooooo`0Cooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP02ooooo`Co00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo0?oooooo1_ooool00?oooooo0_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo0?oooooo1_ooool00?oooooo0_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
0?oooooo1_ooool00?oooooo0Oooool2o`0000?ooooo0_l0003oooooo`Sooooo003ooooooooooooo
4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oo
ooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@
ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooo
oooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3o
oooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooo
oooooooo4?ooool00?ooooooooooool@ooooo`00\
\>"],
  ImageRangeCache->{{{0, 525.688}, {324.5, 0}} -> {0, -6.34248*^6, 0, 53093}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0.309017 5.42214e-08 [
[.32684 .29652 -16.5 -12.5 ]
[.32684 .29652 16.5 0 ]
[.54329 .29652 -16.5 -12.5 ]
[.54329 .29652 16.5 0 ]
[.75974 .29652 -22.5 -12.5 ]
[.75974 .29652 22.5 0 ]
[.97619 .29652 -16.5 -12.5 ]
[.97619 .29652 16.5 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 64 6 ]
[.09789 .09213 -34.5 -6.25 ]
[.09789 .09213 0 6.25 ]
[.09789 .20057 -34.5 -6.25 ]
[.09789 .20057 0 6.25 ]
[.09789 .41746 -28.5 -6.25 ]
[.09789 .41746 0 6.25 ]
[.09789 .5259 -28.5 -6.25 ]
[.09789 .5259 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -62.8125 0 ]
[.5 .63053 62.8125 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 .30902 m
.32684 .31527 L
s
gsave
.32684 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 .30902 m
.54329 .31527 L
s
gsave
.54329 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 .30902 m
.75974 .31527 L
s
gsave
.75974 .29652 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 .30902 m
.15368 .31277 L
s
.19697 .30902 m
.19697 .31277 L
s
.24026 .30902 m
.24026 .31277 L
s
.28355 .30902 m
.28355 .31277 L
s
.37013 .30902 m
.37013 .31277 L
s
.41342 .30902 m
.41342 .31277 L
s
.45671 .30902 m
.45671 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.58658 .30902 m
.58658 .31277 L
s
.62987 .30902 m
.62987 .31277 L
s
.67316 .30902 m
.67316 .31277 L
s
.71645 .30902 m
.71645 .31277 L
s
.80303 .30902 m
.80303 .31277 L
s
.84632 .30902 m
.84632 .31277 L
s
.88961 .30902 m
.88961 .31277 L
s
.9329 .30902 m
.9329 .31277 L
s
.0671 .30902 m
.0671 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09213 m
.11664 .09213 L
s
gsave
.09789 .09213 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .20057 m
.11664 .20057 L
s
gsave
.09789 .20057 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .41746 m
.11664 .41746 L
s
gsave
.09789 .41746 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .5259 m
.11664 .5259 L
s
gsave
.09789 .5259 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.11039 .11924 m
.11414 .11924 L
s
.11039 .14635 m
.11414 .14635 L
s
.11039 .17346 m
.11414 .17346 L
s
.11039 .22768 m
.11414 .22768 L
s
.11039 .2548 m
.11414 .2548 L
s
.11039 .28191 m
.11414 .28191 L
s
.11039 .33613 m
.11414 .33613 L
s
.11039 .36324 m
.11414 .36324 L
s
.11039 .39035 m
.11414 .39035 L
s
.11039 .44457 m
.11414 .44457 L
s
.11039 .47168 m
.11414 .47168 L
s
.11039 .49879 m
.11414 .49879 L
s
.11039 .06502 m
.11414 .06502 L
s
.11039 .03791 m
.11414 .03791 L
s
.11039 .0108 m
.11414 .0108 L
s
.11039 .55301 m
.11414 .55301 L
s
.11039 .58012 m
.11414 .58012 L
s
.11039 .60723 m
.11414 .60723 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -123.812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.812 moveto
(@) show
81.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.812 moveto
(D) show
93.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.2) show
135.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
141.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
153.000 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
157.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
166.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
184.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02418 .30902 L
.02453 .30902 L
.02494 .30902 L
.02532 .30902 L
.02609 .30902 L
.02691 .30902 L
.02774 .30902 L
.02865 .30902 L
.0295 .30902 L
.03029 .30902 L
.0318 .30902 L
.03265 .30902 L
.03345 .30902 L
.03508 .30902 L
.03656 .30902 L
.03809 .30902 L
.03975 .30902 L
.04133 .30902 L
.04301 .30902 L
.04473 .30902 L
.04635 .30902 L
.04945 .30902 L
.05274 .30902 L
.05591 .30902 L
.05672 .30902 L
.0575 .30902 L
.05826 .30902 L
.05859 .30902 L
.05895 .30902 L
.05932 .30902 L
.05941 .30902 L
.05952 .30902 L
.05961 .30902 L
.0597 .30902 L
.0598 .30902 L
.05986 .30902 L
.05991 .30902 L
.05997 .30902 L
.06003 .30902 L
.06013 .30902 L
.06023 .30902 L
.06032 .30902 L
.06042 .30902 L
.06052 .30902 L
.06072 .30902 L
.06093 .30902 L
.06113 .30902 L
.06132 .30902 L
.06177 .30902 L
Mistroke
.0622 .30902 L
.06297 .30902 L
.0634 .30902 L
.06379 .30902 L
.06455 .30902 L
.06527 .30902 L
.06605 .30902 L
.06688 .30902 L
.06837 .30902 L
.06913 .30902 L
.06995 .30902 L
.07142 .30902 L
.07313 .30902 L
.07474 .30902 L
.07782 .30902 L
.07941 .30902 L
.0811 .30902 L
.08414 .30902 L
.08582 .30902 L
.08737 .30902 L
.08815 .30902 L
.08888 .30902 L
.08928 .30902 L
.08964 .30902 L
.08984 .30902 L
.09005 .30902 L
.09016 .30902 L
.09027 .30902 L
.09037 .30902 L
.09043 .30902 L
.09048 .30902 L
.09057 .30902 L
.09063 .30902 L
.09068 .30902 L
.09077 .30902 L
.09087 .30902 L
.09096 .30902 L
.09106 .30902 L
.09115 .30902 L
.09124 .30902 L
.09143 .30902 L
.09163 .30902 L
.09185 .30902 L
.09205 .30902 L
.09242 .30902 L
.09276 .30902 L
.09352 .30902 L
.09391 .30902 L
.09432 .30902 L
.09506 .30902 L
Mistroke
.09585 .30902 L
.09673 .30902 L
.09829 .30902 L
.09916 .30902 L
.09996 .30902 L
.10149 .30902 L
.10315 .30902 L
.10642 .30902 L
.10956 .30902 L
.1129 .30902 L
.11371 .30902 L
.11458 .30902 L
.11537 .30902 L
.11576 .30902 L
.11612 .30902 L
.11629 .30902 L
.11648 .30902 L
.11665 .30902 L
.11683 .30902 L
.11693 .30902 L
.11702 .30902 L
.11712 .30902 L
.11723 .30902 L
.11732 .30902 L
.11742 .30902 L
.1175 .30902 L
.11759 .30902 L
.1177 .30902 L
.11781 .30902 L
.118 .30902 L
.11821 .30902 L
.11843 .30902 L
.11884 .30902 L
.11921 .30902 L
.11959 .30902 L
.11999 .30902 L
.12072 .30902 L
.12159 .30902 L
.12238 .30902 L
.12391 .30902 L
.12477 .30902 L
.12557 .30902 L
.12872 .30901 L
.13044 .30901 L
.13206 .309 L
.13516 .309 L
.13673 .30899 L
.13757 .30899 L
.13846 .30899 L
.1389 .30899 L
Mistroke
.13932 .30899 L
.13973 .30899 L
.1401 .30899 L
.14029 .30899 L
.14046 .30899 L
.14064 .30899 L
.14073 .30899 L
.14084 .30899 L
.14094 .30899 L
.141 .30899 L
.14105 .30899 L
.14115 .30899 L
.14125 .30899 L
.14135 .30899 L
.14145 .30899 L
.14154 .30899 L
.14163 .30899 L
.14182 .30899 L
.14203 .30899 L
.1424 .30899 L
.14262 .30899 L
.14283 .30899 L
.14323 .30899 L
.14404 .30899 L
.1445 .30899 L
.14492 .30899 L
.14642 .309 L
.14727 .30901 L
.14807 .30902 L
.15118 .30906 L
.15279 .30909 L
.15448 .30912 L
.15754 .30919 L
.15924 .30923 L
.16005 .30924 L
.16079 .30925 L
.16116 .30926 L
.16157 .30926 L
.16197 .30926 L
.1622 .30927 L
.16229 .30927 L
.1624 .30927 L
.16251 .30927 L
.1626 .30927 L
.16269 .30927 L
.16279 .30927 L
.16288 .30927 L
.16297 .30927 L
.16305 .30927 L
.16314 .30927 L
Mistroke
.16323 .30927 L
.16334 .30927 L
.16345 .30927 L
.16355 .30927 L
.16373 .30927 L
.16393 .30926 L
.16435 .30926 L
.16474 .30925 L
.16517 .30925 L
.16563 .30924 L
.1664 .30921 L
.16725 .30918 L
.1688 .3091 L
.17048 .30897 L
.17378 .30862 L
.17697 .3082 L
.17857 .308 L
.18003 .30783 L
.18079 .30777 L
.18161 .30771 L
.18183 .3077 L
.18206 .30769 L
.18227 .30768 L
.18247 .30767 L
.18266 .30767 L
.18277 .30767 L
.18286 .30767 L
.18297 .30767 L
.18303 .30767 L
.18308 .30767 L
.18318 .30767 L
.18323 .30767 L
.18329 .30767 L
.18339 .30767 L
.18348 .30767 L
.18358 .30767 L
.18368 .30767 L
.1839 .30768 L
.1841 .30769 L
.18448 .30771 L
.18484 .30773 L
.18526 .30777 L
.18564 .30781 L
.18651 .30794 L
.18729 .3081 L
.18802 .30827 L
.18967 .3088 L
.1913 .30948 L
.19278 .31023 L
.19597 .31204 L
Mistroke
.19758 .31293 L
.19904 .31361 L
.19985 .31391 L
.20062 .31413 L
.20082 .31417 L
.20104 .31421 L
.20123 .31424 L
.20143 .31427 L
.20154 .31428 L
.20164 .31429 L
.20175 .31429 L
.20184 .3143 L
.2019 .3143 L
.20196 .3143 L
.20201 .3143 L
.20208 .3143 L
.20213 .3143 L
.20219 .3143 L
.20225 .3143 L
.2023 .3143 L
.2024 .3143 L
.2025 .31429 L
.20268 .31427 L
.20288 .31425 L
.20309 .31421 L
.20347 .31413 L
.20382 .31403 L
.20463 .31369 L
.20504 .31346 L
.20548 .31318 L
.20704 .31181 L
.20872 .30972 L
.21203 .3041 L
.21523 .29808 L
.21684 .29553 L
.21754 .29465 L
.2183 .2939 L
.21872 .29359 L
.21891 .29347 L
.21911 .29337 L
.21929 .29329 L
.21949 .29323 L
.21959 .29321 L
.21969 .29319 L
.21979 .29318 L
.21988 .29317 L
.21998 .29316 L
.22003 .29316 L
.22008 .29317 L
.22019 .29317 L
Mistroke
.22025 .29318 L
.2203 .29319 L
.22039 .29321 L
.2205 .29324 L
.22069 .2933 L
.22091 .2934 L
.22114 .29355 L
.22156 .29389 L
.22199 .29435 L
.22239 .29489 L
.22328 .29647 L
.22407 .29831 L
.2249 .3007 L
.22795 .31289 L
.23119 .32913 L
.23268 .3362 L
.23431 .34244 L
.23474 .34372 L
.23519 .34487 L
.23562 .34574 L
.23582 .34608 L
.23601 .34635 L
.23619 .34656 L
.23638 .34675 L
.23658 .34689 L
.23668 .34694 L
.23678 .34697 L
.23683 .34699 L
.23689 .347 L
.237 .34701 L
.2371 .347 L
.23719 .34698 L
.23729 .34694 L
.23735 .34691 L
.2374 .34688 L
.23751 .34681 L
.23763 .34671 L
.23784 .34649 L
.23803 .34622 L
.23846 .3454 L
.23888 .34435 L
.23926 .34315 L
.24002 .34002 L
.24074 .33621 L
.24236 .32483 L
.24384 .31134 L
.24701 .27706 L
.24861 .26018 L
.25006 .2472 L
.25087 .24157 L
Mistroke
.25163 .23753 L
.25205 .23592 L
.25243 .23484 L
.25264 .23444 L
.25275 .23427 L
.25286 .23414 L
.25291 .23408 L
.25297 .23403 L
.25307 .23397 L
.25313 .23396 L
.25319 .23395 L
.25325 .23395 L
.25331 .23396 L
.25341 .234 L
.25346 .23404 L
.25352 .23408 L
.25362 .23419 L
.25374 .23435 L
.25394 .23475 L
.25413 .23523 L
.25459 .23685 L
.25502 .23902 L
.2558 .2444 L
.25664 .25244 L
.25823 .27331 L
.25991 .30238 L
.26325 .36948 L
.26493 .40005 L
.26567 .41122 L
.26648 .42132 L
.26685 .42516 L
.26726 .42859 L
.26764 .43114 L
.26799 .43284 L
.26819 .43356 L
.26838 .43404 L
.26848 .43422 L
.26853 .43429 L
.26858 .43435 L
.26869 .43443 L
.26875 .43444 L
.2688 .43444 L
.2689 .43439 L
.26899 .4343 L
.26909 .43415 L
.2692 .43393 L
.2694 .43336 L
.26958 .43265 L
.26997 .43049 L
.27038 .42728 L
Mistroke
.27112 .41914 L
.27192 .40704 L
.27279 .38997 L
.27604 .30004 L
.27916 .20186 L
.27998 .17983 L
.28086 .15938 L
.28127 .15149 L
.2817 .14424 L
.28211 .1386 L
.28248 .13445 L
.28285 .13138 L
.28303 .13022 L
.28323 .12926 L
.28334 .12889 L
.28343 .12863 L
.28349 .12851 L
.28355 .12842 L
.28365 .12832 L
.28375 .1283 L
.28385 .12838 L
.28394 .12851 L
.28404 .12874 L
.28414 .12904 L
.28423 .12941 L
.28441 .13028 L
.2846 .13152 L
.2848 .1332 L
.28517 .13711 L
.28551 .14175 L
.28636 .15749 L
.28716 .17748 L
.28865 .22664 L
.29175 .35851 L
.29332 .4262 L
.29416 .45829 L
.29505 .488 L
.29591 .5109 L
.29631 .51946 L
.29669 .52596 L
.29707 .53105 L
.29727 .53314 L
.29748 .5349 L
.29756 .53549 L
.29766 .53603 L
.29774 .53642 L
.29783 .53677 L
.29793 .53704 L
.29803 .53722 L
.29813 .53727 L
Mistroke
.29822 .53723 L
.29832 .53707 L
.29838 .53694 L
.29843 .53677 L
.29853 .53638 L
.29863 .53591 L
.29884 .53448 L
.29907 .53238 L
.29948 .52704 L
.29987 .52048 L
.30063 .50255 L
.30136 .48003 L
.30295 .41437 L
.30443 .33937 L
.30606 .25093 L
.30758 .17235 L
.30904 .11053 L
.30986 .08428 L
.31061 .06675 L
.31099 .0605 L
.3112 .0578 L
.31139 .05584 L
.31157 .05446 L
.31168 .05386 L
.31177 .05344 L
.31185 .05316 L
.31194 .05295 L
.31204 .05286 L
.31213 .05288 L
.31223 .05303 L
.31229 .05317 L
.31234 .05335 L
.31244 .05378 L
.31254 .05437 L
.31274 .05592 L
.31293 .05778 L
.31337 .06414 L
.31379 .07246 L
.31457 .09397 L
.3154 .12436 L
.31688 .19511 L
.31993 .37305 L
.32163 .46481 L
.32243 .50066 L
.32318 .52783 L
.32395 .54894 L
.32435 .55697 L
.32456 .56021 L
.32478 .56304 L
.32498 .56493 L
Mistroke
.32506 .56559 L
.32515 .56619 L
.32524 .56662 L
.32532 .56698 L
.32542 .56723 L
.3255 .56735 L
.32561 .56736 L
.32567 .5673 L
.32572 .5672 L
.32582 .56691 L
.32592 .56645 L
.32601 .56591 L
.3261 .56529 L
.3263 .56348 L
.32651 .561 L
.3267 .55816 L
.32714 .54985 L
.32752 .54042 L
.32793 .52833 L
.32942 .46837 L
.33276 .28037 L
.33444 .18773 L
.33518 .15309 L
.33598 .12115 L
.33636 .10869 L
.33676 .09728 L
.33711 .08909 L
.33749 .08201 L
.33771 .07876 L
.33792 .07636 L
.33812 .07461 L
.33822 .07393 L
.33832 .07334 L
.33842 .07295 L
.33851 .07271 L
.33862 .07257 L
.33872 .07258 L
.33881 .07271 L
.33889 .07294 L
.33898 .0733 L
.33908 .07381 L
.33929 .07533 L
.33951 .07759 L
.33991 .08326 L
.34033 .09163 L
.3408 .10341 L
.34164 .13072 L
.34242 .16245 L
.34554 .32191 L
.34713 .40135 L
Mistroke
.34797 .43698 L
.34886 .46793 L
.34965 .48831 L
.3501 .49669 L
.3503 .49971 L
.35052 .50234 L
.3507 .50411 L
.3508 .50488 L
.35091 .50558 L
.351 .50609 L
.35109 .50647 L
.35118 .50675 L
.35126 .50692 L
.35136 .50702 L
.35146 .507 L
.35155 .50688 L
.35164 .50664 L
.35174 .50625 L
.35186 .50569 L
.35206 .5043 L
.35226 .5024 L
.35248 .49983 L
.35287 .49385 L
.35333 .48456 L
.35376 .47422 L
.35537 .4205 L
.35859 .28159 L
.36006 .22411 L
.3609 .19777 L
.36131 .18701 L
.36168 .17852 L
.36206 .17137 L
.36246 .16513 L
.36268 .1624 L
.36288 .16031 L
.36308 .15872 L
.36319 .158 L
.36329 .15745 L
.36338 .15702 L
.36349 .15665 L
.36359 .15639 L
.36365 .15629 L
.3637 .15624 L
.3638 .15621 L
.36389 .15626 L
.36399 .15643 L
.36409 .15668 L
.3642 .15707 L
.36431 .15761 L
.36452 .15889 L
Mistroke
.36474 .16071 L
.36498 .16324 L
.3654 .16889 L
.3658 .17564 L
.36654 .19162 L
.36822 .23977 L
.37129 .34189 L
.37288 .38427 L
.37368 .39992 L
.37413 .40679 L
.37456 .41182 L
.37494 .41507 L
.37515 .41642 L
.37535 .41737 L
.37546 .41775 L
.37556 .41803 L
.37565 .41821 L
.37575 .41834 L
.3758 .41837 L
.37586 .41839 L
.37592 .41838 L
.37597 .41834 L
.37607 .41822 L
.37613 .41812 L
.37618 .41801 L
.37627 .41776 L
.37637 .41743 L
.37654 .41666 L
.37675 .41545 L
.37694 .41409 L
.37731 .41069 L
.37766 .40666 L
.37845 .39504 L
.37927 .37944 L
.38076 .34585 L
.38235 .30727 L
.38381 .2756 L
.38456 .26209 L
.38537 .2503 L
.38582 .24526 L
.38623 .24156 L
.38663 .23889 L
.38683 .23788 L
.38705 .23702 L
.38724 .23649 L
.38735 .23628 L
.38745 .23614 L
.38755 .23605 L
.38765 .23602 L
.3877 .23603 L
Mistroke
.38776 .23605 L
.38786 .23614 L
.38795 .23626 L
.38805 .23644 L
.38825 .23695 L
.38843 .23761 L
.3886 .23838 L
.38903 .24086 L
.38941 .24384 L
.39028 .25272 L
.3918 .27391 L
.39347 .30067 L
.39518 .32641 L
.39599 .3364 L
.39674 .34385 L
.39752 .34966 L
.39792 .35184 L
.39813 .35271 L
.39836 .35346 L
.39855 .35397 L
.39873 .35432 L
.39882 .35444 L
.39891 .35455 L
.399 .35461 L
.39908 .35465 L
.39918 .35467 L
.39927 .35465 L
.39937 .3546 L
.39947 .35451 L
.39958 .35439 L
.39969 .35421 L
.39988 .3538 L
.40009 .35323 L
.40028 .35257 L
.40065 .35102 L
.40147 .3462 L
.40294 .33392 L
.40604 .30346 L
.40686 .29651 L
.40764 .29107 L
.40844 .28669 L
.40887 .28495 L
.40909 .28421 L
.40933 .28355 L
.40953 .28309 L
.40975 .28268 L
.40985 .28254 L
.40995 .28242 L
.41005 .28232 L
.41014 .28225 L
Mistroke
.4102 .28221 L
.41025 .28219 L
.41031 .28217 L
.41037 .28215 L
.41043 .28215 L
.41049 .28215 L
.41055 .28216 L
.4106 .28218 L
.4107 .28222 L
.41076 .28226 L
.41081 .28229 L
.41091 .28239 L
.41103 .28252 L
.41124 .28282 L
.41144 .28319 L
.41181 .28408 L
.41224 .28542 L
.41264 .28694 L
.41429 .29519 L
.41579 .30405 L
.41746 .31341 L
.4182 .31683 L
.419 .31989 L
.41938 .32104 L
.41978 .32206 L
.42016 .32282 L
.42051 .32335 L
.42071 .32358 L
.4209 .32375 L
.421 .32381 L
.42111 .32387 L
.42116 .3239 L
.42122 .32392 L
.42133 .32395 L
.42142 .32396 L
.42152 .32396 L
.42158 .32395 L
.42163 .32394 L
.42173 .32392 L
.42183 .32388 L
.42192 .32383 L
.4221 .32371 L
.42229 .32354 L
.42247 .32335 L
.42288 .32277 L
.42328 .32205 L
.42371 .32111 L
.42519 .31692 L
.42678 .31167 L
.4285 .30639 L
Mistroke
.42931 .30442 L
.42975 .30353 L
.43016 .30281 L
.43055 .30225 L
.43097 .30177 L
.43115 .3016 L
.43135 .30146 L
.43152 .30135 L
.4317 .30126 L
.4318 .30122 L
.4319 .30119 L
.432 .30117 L
.4321 .30115 L
.43219 .30114 L
.43227 .30114 L
.43236 .30114 L
.43246 .30115 L
.43257 .30117 L
.43263 .30118 L
.43268 .30119 L
.43289 .30127 L
.43308 .30135 L
.43328 .30147 L
.43368 .30178 L
.43405 .30215 L
.43475 .30301 L
.43785 .3082 L
.43941 .31061 L
.4403 .31166 L
.44073 .31206 L
.44114 .31237 L
.44152 .31261 L
.44172 .31271 L
.44194 .3128 L
.44212 .31286 L
.44231 .31291 L
.4424 .31292 L
.4425 .31294 L
.44258 .31295 L
.44267 .31296 L
.44276 .31296 L
.44286 .31297 L
.44296 .31297 L
.44305 .31296 L
.44315 .31295 L
.44321 .31295 L
.44326 .31294 L
.44346 .31291 L
.44366 .31286 L
.44387 .31279 L
Mistroke
.4443 .31262 L
.44512 .31215 L
.44587 .31161 L
.44754 .31016 L
.4492 .30876 L
.45 .30819 L
.45073 .30777 L
.4511 .3076 L
.4515 .30744 L
.45184 .30733 L
.45222 .30724 L
.45243 .3072 L
.45262 .30717 L
.45282 .30715 L
.45294 .30714 L
.45304 .30713 L
.45314 .30713 L
.45323 .30713 L
.45333 .30713 L
.45343 .30713 L
.45352 .30713 L
.45361 .30714 L
.4537 .30714 L
.4538 .30715 L
.45399 .30717 L
.4542 .3072 L
.45457 .30727 L
.45501 .30738 L
.45541 .3075 L
.45711 .30814 L
.45878 .30885 L
.45951 .30913 L
.46032 .3094 L
.4611 .30961 L
.46182 .30975 L
.46222 .30981 L
.46259 .30984 L
.46279 .30986 L
.4629 .30987 L
.46301 .30987 L
.46311 .30987 L
.46316 .30988 L
.46322 .30988 L
.46332 .30988 L
.46341 .30988 L
.46351 .30988 L
.4636 .30988 L
.46371 .30988 L
.46381 .30988 L
.4639 .30987 L
Mistroke
.46399 .30987 L
.46418 .30986 L
.46437 .30985 L
.46459 .30983 L
.46502 .30979 L
.46589 .30967 L
.46671 .30952 L
.4682 .30923 L
.46982 .30894 L
.4707 .30881 L
.47113 .30876 L
.47152 .30873 L
.4719 .3087 L
.4723 .30867 L
.47252 .30866 L
.47273 .30865 L
.47293 .30865 L
.47302 .30864 L
.47313 .30864 L
.47324 .30864 L
.47333 .30864 L
.47339 .30864 L
.47344 .30864 L
.4735 .30864 L
.47355 .30864 L
.47365 .30864 L
.47375 .30864 L
.47385 .30864 L
.47395 .30864 L
.47414 .30865 L
.47431 .30865 L
.4747 .30866 L
.47512 .30868 L
.47551 .30871 L
.47638 .30877 L
.47805 .30891 L
.47959 .30904 L
.48036 .30909 L
.48109 .30913 L
.48148 .30914 L
.48185 .30915 L
.48225 .30916 L
.48247 .30917 L
.48268 .30917 L
.48278 .30917 L
.48289 .30917 L
.48298 .30917 L
.48308 .30918 L
.48317 .30918 L
.48327 .30918 L
Mistroke
.48336 .30918 L
.48345 .30918 L
.4835 .30918 L
.48356 .30918 L
.48366 .30918 L
.48375 .30918 L
.48385 .30917 L
.48405 .30917 L
.48427 .30917 L
.48463 .30916 L
.48497 .30916 L
.48575 .30914 L
.48886 .30903 L
.48967 .309 L
.49055 .30898 L
.49096 .30897 L
.49139 .30896 L
.4918 .30896 L
.49217 .30896 L
.49235 .30895 L
.49256 .30895 L
.49266 .30895 L
.49277 .30895 L
.49287 .30895 L
.49297 .30895 L
.49306 .30895 L
.49315 .30895 L
.49325 .30895 L
.49335 .30895 L
.49344 .30895 L
.49352 .30895 L
.49371 .30895 L
.49391 .30895 L
.49413 .30896 L
.49451 .30896 L
.49538 .30897 L
.49844 .30901 L
.49925 .30902 L
.50001 .30903 L
.50043 .30903 L
.50089 .30904 L
.50131 .30904 L
.50151 .30904 L
.50169 .30904 L
.50187 .30904 L
.50207 .30904 L
.50217 .30904 L
.50227 .30904 L
.50237 .30904 L
.50247 .30904 L
Mistroke
.50256 .30904 L
.50266 .30904 L
.50276 .30904 L
.50285 .30904 L
.50293 .30904 L
.50302 .30904 L
.5032 .30904 L
.50341 .30904 L
.50361 .30904 L
.50405 .30904 L
.50485 .30904 L
.50651 .30903 L
.50805 .30902 L
.50882 .30901 L
.50955 .30901 L
.5103 .30901 L
.5107 .30901 L
.51091 .30901 L
.51113 .30901 L
.51134 .30901 L
.51153 .30901 L
.51162 .30901 L
.51172 .30901 L
.51181 .30901 L
.5119 .30901 L
.512 .30901 L
.5121 .30901 L
.5122 .30901 L
.51226 .30901 L
.51231 .30901 L
.51242 .30901 L
.51253 .30901 L
.51274 .30901 L
.51297 .30901 L
.51317 .30901 L
.51362 .30901 L
.51444 .30901 L
.51612 .30901 L
.51766 .30902 L
.51844 .30902 L
.51917 .30902 L
.51954 .30902 L
.51993 .30902 L
.52015 .30902 L
.52036 .30902 L
.52055 .30902 L
.52066 .30902 L
.52076 .30902 L
.52085 .30902 L
.52095 .30902 L
Mistroke
.52105 .30902 L
.52115 .30902 L
.52124 .30902 L
.52134 .30902 L
.52143 .30902 L
.52152 .30902 L
.52157 .30902 L
.52162 .30902 L
.52172 .30902 L
.52195 .30902 L
.52214 .30902 L
.52235 .30902 L
.52277 .30902 L
.52322 .30902 L
.52404 .30902 L
.52563 .30902 L
.52647 .30902 L
.52736 .30902 L
.52815 .30902 L
.5286 .30902 L
.52902 .30902 L
.52921 .30902 L
.52941 .30902 L
.52958 .30902 L
.52976 .30902 L
.52986 .30902 L
.52996 .30902 L
.53005 .30902 L
.53014 .30902 L
.53024 .30902 L
.5303 .30902 L
.53036 .30902 L
.53045 .30902 L
.53056 .30902 L
.53066 .30902 L
.53076 .30902 L
.53086 .30902 L
.53098 .30902 L
.53118 .30902 L
.53137 .30902 L
.53176 .30902 L
.53212 .30902 L
.5338 .30902 L
.53527 .30902 L
.53611 .30902 L
.53689 .30902 L
.53767 .30902 L
.5381 .30902 L
.5385 .30902 L
.53871 .30902 L
Mistroke
.53891 .30902 L
.53902 .30902 L
.53913 .30902 L
.53919 .30902 L
.53925 .30902 L
.53931 .30902 L
.53937 .30902 L
.53947 .30902 L
.53956 .30902 L
.53966 .30902 L
.53972 .30902 L
.53977 .30902 L
.53987 .30902 L
.53998 .30902 L
.54019 .30902 L
.54058 .30902 L
.54095 .30902 L
.54179 .30902 L
.54348 .30902 L
.54497 .30902 L
.54582 .30902 L
.5466 .30902 L
.54699 .30902 L
.54722 .30902 L
.54742 .30902 L
.54764 .30902 L
.54776 .30902 L
.54788 .30902 L
.54798 .30902 L
.54808 .30902 L
.54814 .30902 L
.54819 .30902 L
.54825 .30902 L
.5483 .30902 L
.54839 .30902 L
.5485 .30902 L
.54855 .30902 L
.5486 .30902 L
.5487 .30902 L
.5489 .30902 L
.54908 .30902 L
.54951 .30902 L
.54992 .30902 L
.55151 .30902 L
.55298 .30902 L
.55383 .30902 L
.55463 .30902 L
.55535 .30902 L
.55575 .30902 L
.55612 .30902 L
Mistroke
.55632 .30902 L
.5565 .30902 L
.5566 .30902 L
.55671 .30902 L
.55681 .30902 L
.55691 .30902 L
.55699 .30902 L
.55708 .30902 L
.55716 .30902 L
.55726 .30902 L
.55736 .30902 L
.55746 .30902 L
.55764 .30902 L
.55784 .30902 L
.55805 .30902 L
.55843 .30902 L
.5593 .30902 L
.5609 .30902 L
.56174 .30902 L
.56263 .30902 L
.56342 .30902 L
.56388 .30902 L
.5643 .30902 L
.5645 .30902 L
.56469 .30902 L
.56486 .30902 L
.56504 .30902 L
.56515 .30902 L
.56524 .30902 L
.56534 .30902 L
.56542 .30902 L
.56553 .30902 L
.56558 .30902 L
.56564 .30902 L
.56573 .30902 L
.56584 .30902 L
.56594 .30902 L
.56604 .30902 L
.56615 .30902 L
.56626 .30902 L
.56645 .30902 L
.56666 .30902 L
.56705 .30902 L
.56741 .30902 L
.56909 .30902 L
.57058 .30902 L
.57136 .30902 L
.5722 .30902 L
.57266 .30902 L
.57308 .30902 L
Mistroke
.57328 .30902 L
.5735 .30902 L
.5736 .30902 L
.57371 .30902 L
.5738 .30902 L
.5739 .30902 L
.574 .30902 L
.57409 .30902 L
.57419 .30902 L
.57424 .30902 L
.57429 .30902 L
.57438 .30902 L
.57447 .30902 L
.57457 .30902 L
.57466 .30902 L
.57488 .30902 L
.57507 .30902 L
.57551 .30902 L
.57629 .30902 L
.57703 .30902 L
.57869 .30902 L
.57953 .30902 L
.58033 .30902 L
.58068 .30902 L
.58104 .30902 L
.58145 .30902 L
.58182 .30902 L
.58202 .30902 L
.58212 .30902 L
.58222 .30902 L
.58231 .30902 L
.58239 .30902 L
.58248 .30902 L
.58258 .30902 L
.58268 .30902 L
.58278 .30902 L
.58288 .30902 L
.58294 .30902 L
.583 .30902 L
.5831 .30902 L
.5832 .30902 L
.58339 .30902 L
.58379 .30902 L
.58416 .30902 L
.58486 .30902 L
.58633 .30902 L
.58716 .30902 L
.58794 .30902 L
.58871 .30902 L
.58914 .30902 L
Mistroke
.58953 .30902 L
.58992 .30902 L
.59015 .30902 L
.59035 .30902 L
.59046 .30902 L
.59057 .30902 L
.59067 .30902 L
.59077 .30902 L
.59082 .30902 L
.59088 .30902 L
.59094 .30902 L
.591 .30902 L
.59111 .30902 L
.59116 .30902 L
.59122 .30902 L
.59131 .30902 L
.5914 .30902 L
.5916 .30902 L
.5918 .30902 L
.59201 .30902 L
.59275 .30902 L
.59441 .30902 L
.59599 .30902 L
.59642 .30902 L
.59688 .30902 L
.59731 .30902 L
.59771 .30902 L
.59812 .30902 L
.59834 .30902 L
.59857 .30902 L
.59866 .30902 L
.59876 .30902 L
.59885 .30902 L
.59895 .30902 L
.59901 .30902 L
.59906 .30902 L
.59912 .30902 L
.59917 .30902 L
.59928 .30902 L
.59937 .30902 L
.59947 .30902 L
.59957 .30902 L
.59965 .30902 L
.59975 .30902 L
.59996 .30902 L
.60015 .30902 L
.60051 .30902 L
.60089 .30902 L
.60248 .30902 L
.60332 .30902 L
Mistroke
.60421 .30902 L
.605 .30902 L
.60545 .30902 L
.60587 .30902 L
.60606 .30902 L
.60625 .30902 L
.60643 .30902 L
.60661 .30902 L
.60681 .30902 L
.60689 .30902 L
.60699 .30902 L
.60705 .30902 L
.6071 .30902 L
.60721 .30902 L
.6073 .30902 L
.60741 .30902 L
.6075 .30902 L
.60761 .30902 L
.60771 .30902 L
.6078 .30902 L
.60798 .30902 L
.60816 .30902 L
.60859 .30902 L
.60898 .30902 L
.61045 .30902 L
.61126 .30902 L
.61213 .30902 L
.61286 .30902 L
.61328 .30902 L
.61367 .30902 L
.61407 .30902 L
.61444 .30902 L
.61465 .30902 L
.61484 .30902 L
.61494 .30902 L
.61505 .30902 L
.6151 .30902 L
.61516 .30902 L
.61522 .30902 L
.61527 .30902 L
.61537 .30902 L
.61545 .30902 L
.61556 .30902 L
.61565 .30902 L
.61575 .30902 L
.61586 .30902 L
.61605 .30902 L
.61623 .30902 L
.61642 .30902 L
.61677 .30902 L
Mistroke
.61834 .30902 L
.61981 .30902 L
.62065 .30902 L
.62106 .30902 L
.62144 .30902 L
.62178 .30902 L
.62216 .30902 L
.62234 .30902 L
.62253 .30902 L
.62274 .30902 L
.62284 .30902 L
.62293 .30902 L
.62303 .30902 L
.62313 .30902 L
.62323 .30902 L
.62333 .30902 L
.62342 .30902 L
.62352 .30902 L
.62361 .30902 L
.6237 .30902 L
.62381 .30902 L
.62391 .30902 L
.62413 .30902 L
.62454 .30902 L
.62496 .30902 L
.62541 .30902 L
.62623 .30902 L
.62712 .30902 L
.62795 .30902 L
.62869 .30902 L
.62908 .30902 L
.6295 .30902 L
.62991 .30902 L
.6303 .30902 L
.63051 .30902 L
.6307 .30902 L
.63081 .30902 L
.63092 .30902 L
.63098 .30902 L
.63103 .30902 L
.63114 .30902 L
.63123 .30902 L
.63131 .30902 L
.63141 .30902 L
.63151 .30902 L
.63159 .30902 L
.63167 .30902 L
.63185 .30902 L
.63205 .30902 L
.63223 .30902 L
Mistroke
.63264 .30902 L
.63431 .30902 L
.63505 .30902 L
.63585 .30902 L
.63663 .30902 L
.637 .30902 L
.63735 .30902 L
.63775 .30902 L
.63812 .30902 L
.63832 .30902 L
.63851 .30902 L
.63862 .30902 L
.63872 .30902 L
.63878 .30902 L
.63884 .30902 L
.63889 .30902 L
.63894 .30902 L
.63904 .30902 L
.63914 .30902 L
.63923 .30902 L
.63932 .30902 L
.63942 .30902 L
.63953 .30902 L
.63973 .30902 L
.64007 .30902 L
.64046 .30902 L
.64212 .30902 L
.64298 .30902 L
.64381 .30902 L
.64455 .30902 L
.64496 .30902 L
.64535 .30902 L
.64555 .30902 L
.64576 .30902 L
.64594 .30902 L
.64614 .30902 L
.64632 .30902 L
.64642 .30902 L
.64651 .30902 L
.6466 .30902 L
.64668 .30902 L
.64677 .30902 L
.64686 .30902 L
.64695 .30902 L
.64705 .30902 L
.64716 .30902 L
.64726 .30902 L
.64743 .30902 L
.64763 .30902 L
.64806 .30902 L
Mistroke
.64846 .30902 L
.65011 .30902 L
.65091 .30902 L
.65164 .30902 L
.65201 .30902 L
.6524 .30902 L
.65275 .30902 L
.65312 .30902 L
.65331 .30902 L
.65352 .30902 L
.65374 .30902 L
.65384 .30902 L
.65394 .30902 L
.65405 .30902 L
.65415 .30902 L
.65424 .30902 L
.65434 .30902 L
.65444 .30902 L
.65453 .30902 L
.65461 .30902 L
.6547 .30902 L
.6548 .30902 L
.65489 .30902 L
.6551 .30902 L
.65547 .30902 L
.6559 .30902 L
.6563 .30902 L
.658 .30902 L
.65877 .30902 L
.6596 .30902 L
.65994 .30902 L
.6603 .30902 L
.6607 .30902 L
.66108 .30902 L
.66127 .30902 L
.66138 .30902 L
.66148 .30902 L
.66157 .30902 L
.66167 .30902 L
.66176 .30902 L
.66185 .30902 L
.66195 .30902 L
.66204 .30902 L
.66214 .30902 L
.6622 .30902 L
.66226 .30902 L
.66236 .30902 L
.66248 .30902 L
.66269 .30902 L
.66311 .30902 L
Mistroke
.66357 .30902 L
.66438 .30902 L
.66596 .30902 L
.66665 .30902 L
.66704 .30902 L
.66741 .30902 L
.6678 .30902 L
.66816 .30902 L
.66835 .30902 L
.66855 .30902 L
.66876 .30902 L
.66896 .30902 L
.66906 .30902 L
.66916 .30902 L
.66922 .30902 L
.66927 .30902 L
.66933 .30902 L
.66938 .30902 L
.66944 .30902 L
.66949 .30902 L
.6696 .30902 L
.66966 .30902 L
.66972 .30902 L
.66983 .30902 L
.66993 .30902 L
.67003 .30902 L
.67022 .30902 L
.67063 .30902 L
.67139 .30902 L
.67221 .30902 L
.67368 .30902 L
.6745 .30902 L
.67496 .30902 L
.67539 .30902 L
.67576 .30902 L
.67597 .30902 L
.67617 .30902 L
.67627 .30902 L
.67638 .30902 L
.67647 .30902 L
.67657 .30902 L
.67663 .30902 L
.67668 .30902 L
.67674 .30902 L
.6768 .30902 L
.6769 .30902 L
.67695 .30902 L
.677 .30902 L
.6771 .30902 L
.6772 .30902 L
Mistroke
.67729 .30902 L
.67738 .30902 L
.67759 .30902 L
.67778 .30902 L
.67851 .30902 L
.68017 .30902 L
.68102 .30902 L
.68182 .30902 L
.68217 .30902 L
.68254 .30902 L
.68273 .30902 L
.68294 .30902 L
.68314 .30902 L
.68331 .30902 L
.68352 .30902 L
.68362 .30902 L
.68374 .30902 L
.68384 .30902 L
.68393 .30902 L
.68403 .30902 L
.68408 .30902 L
.68414 .30902 L
.68423 .30902 L
.68432 .30902 L
.68442 .30902 L
.68452 .30902 L
.68462 .30902 L
.68471 .30902 L
.68488 .30902 L
.6853 .30902 L
.68569 .30902 L
.68656 .30902 L
.68735 .30902 L
.6882 .30902 L
.689 .30902 L
.68936 .30902 L
.68973 .30902 L
.69012 .30902 L
.69048 .30902 L
.69068 .30902 L
.69087 .30902 L
.69098 .30902 L
.69107 .30902 L
.69118 .30902 L
.69124 .30902 L
.6913 .30902 L
.6914 .30902 L
.69149 .30902 L
.69157 .30902 L
.69167 .30902 L
Mistroke
.69177 .30902 L
.69187 .30902 L
.69206 .30902 L
.69224 .30902 L
.6924 .30902 L
.69278 .30902 L
.69427 .30902 L
.69505 .30902 L
.69589 .30902 L
.69636 .30902 L
.69677 .30902 L
.69719 .30902 L
.69759 .30902 L
.69779 .30902 L
.698 .30902 L
.69817 .30902 L
.69827 .30902 L
.69837 .30902 L
.69842 .30902 L
.69848 .30902 L
.69858 .30902 L
.69868 .30902 L
.69877 .30902 L
.69887 .30902 L
.69893 .30902 L
.69898 .30902 L
.69909 .30902 L
.6992 .30902 L
.6994 .30902 L
.6996 .30902 L
.69997 .30902 L
.70081 .30902 L
.70251 .30902 L
.70333 .30902 L
.7038 .30902 L
.70422 .30902 L
.7046 .30902 L
.70481 .30902 L
.70501 .30902 L
.70512 .30902 L
.70522 .30902 L
.70531 .30902 L
.70541 .30902 L
.70546 .30902 L
.70552 .30902 L
.70562 .30902 L
.70567 .30902 L
.70573 .30902 L
.70579 .30902 L
.70584 .30902 L
Mistroke
.70594 .30902 L
.70604 .30902 L
.70613 .30902 L
.70622 .30902 L
.70643 .30902 L
.70663 .30902 L
.70698 .30902 L
.70736 .30902 L
.70902 .30902 L
.70977 .30902 L
.71019 .30902 L
.71059 .30902 L
.71095 .30902 L
.71135 .30902 L
.71172 .30902 L
.71188 .30902 L
.71206 .30902 L
.71216 .30902 L
.71227 .30902 L
.71237 .30902 L
.71246 .30902 L
.71257 .30902 L
.71263 .30902 L
.71269 .30902 L
.71279 .30902 L
.71285 .30902 L
.7129 .30902 L
.713 .30902 L
.71309 .30902 L
.71319 .30902 L
.71329 .30902 L
.7134 .30902 L
.71351 .30902 L
.7137 .30902 L
.71407 .30902 L
.71442 .30902 L
.7152 .30902 L
.7167 .30902 L
.71711 .30902 L
.71755 .30902 L
.71793 .30902 L
.71833 .30902 L
.71855 .30902 L
.71875 .30902 L
.71896 .30902 L
.71915 .30902 L
.71937 .30902 L
.71948 .30902 L
.71954 .30902 L
.71961 .30902 L
Mistroke
.71967 .30902 L
.71973 .30902 L
.71978 .30902 L
.71984 .30902 L
.71994 .30902 L
.71999 .30902 L
.72004 .30902 L
.72015 .30902 L
.7202 .30902 L
.72025 .30902 L
.72045 .30902 L
.72063 .30902 L
.72083 .30902 L
.72166 .30902 L
.72325 .30902 L
.72394 .30902 L
.7247 .30902 L
.72509 .30902 L
.72546 .30902 L
.72584 .30902 L
.72606 .30902 L
.72625 .30902 L
.72636 .30902 L
.72647 .30902 L
.72656 .30902 L
.72667 .30902 L
.72673 .30902 L
.72678 .30902 L
.72684 .30902 L
.7269 .30902 L
.727 .30902 L
.72706 .30902 L
.72712 .30902 L
.72721 .30902 L
.7273 .30902 L
.72751 .30902 L
.72771 .30902 L
.72793 .30902 L
.7295 .30902 L
.73034 .30902 L
.73079 .30902 L
.73123 .30902 L
.73164 .30902 L
.73209 .30902 L
.73229 .30902 L
.7325 .30902 L
.73287 .30902 L
.73306 .30902 L
.73316 .30902 L
.73325 .30902 L
Mistroke
.73334 .30902 L
.73343 .30902 L
.73352 .30902 L
.7336 .30902 L
.73371 .30902 L
.73381 .30902 L
.7339 .30902 L
.73399 .30902 L
.7341 .30902 L
.73421 .30902 L
.73441 .30902 L
.73461 .30902 L
.7348 .30902 L
.73517 .30902 L
.73598 .30902 L
.73746 .30902 L
.73823 .30902 L
.73862 .30902 L
.73905 .30902 L
.73942 .30902 L
.73963 .30902 L
.73982 .30902 L
.73998 .30902 L
.74017 .30902 L
.74026 .30902 L
.74036 .30902 L
.74045 .30902 L
.74053 .30902 L
.74063 .30902 L
.74072 .30902 L
.74082 .30902 L
.74092 .30902 L
.74098 .30902 L
.74103 .30902 L
.74114 .30902 L
.74134 .30902 L
.74172 .30902 L
.74207 .30902 L
.74374 .30902 L
.7446 .30902 L
.74501 .30902 L
.7454 .30902 L
.74574 .30902 L
.74612 .30902 L
.74649 .30902 L
.7467 .30902 L
.74689 .30902 L
.74699 .30902 L
.7471 .30902 L
.74719 .30902 L
Mistroke
.7473 .30902 L
.74735 .30902 L
.7474 .30902 L
.74746 .30902 L
.74752 .30902 L
.74762 .30902 L
.74768 .30902 L
.74773 .30902 L
.74784 .30902 L
.74794 .30902 L
.74812 .30902 L
.74853 .30902 L
.74925 .30902 L
.75002 .30902 L
.75085 .30902 L
.75162 .30902 L
.75204 .30902 L
.75243 .30902 L
.75285 .30902 L
.75309 .30902 L
.75331 .30902 L
.7535 .30902 L
.75368 .30902 L
.75378 .30902 L
.75387 .30902 L
.75398 .30902 L
.75403 .30902 L
.75409 .30902 L
.75414 .30902 L
.75419 .30902 L
.75429 .30902 L
.7544 .30902 L
.75446 .30902 L
.75451 .30902 L
.7547 .30902 L
.75491 .30902 L
.75527 .30902 L
.75561 .30902 L
.75639 .30902 L
.75788 .30902 L
.75829 .30902 L
.75872 .30902 L
.7591 .30902 L
.7595 .30902 L
.75974 .30902 L
.75996 .30902 L
.76017 .30902 L
.76028 .30902 L
.76039 .30902 L
.7605 .30902 L
Mistroke
.76059 .30902 L
.76069 .30902 L
.76078 .30902 L
.76088 .30902 L
.76098 .30902 L
.76103 .30902 L
.76109 .30902 L
.76115 .30902 L
.7612 .30902 L
.7614 .30902 L
.76161 .30902 L
.76198 .30902 L
.76281 .30902 L
.76364 .30902 L
.76442 .30902 L
.76512 .30902 L
.76548 .30902 L
.76588 .30902 L
.76628 .30902 L
.76649 .30902 L
.7667 .30902 L
.76689 .30902 L
.76706 .30902 L
.76716 .30902 L
.76726 .30902 L
.76736 .30902 L
.76745 .30902 L
.76755 .30902 L
.76765 .30902 L
.76775 .30902 L
.76784 .30902 L
.76794 .30902 L
.76805 .30902 L
.76827 .30902 L
.76872 .30902 L
.76914 .30902 L
.77064 .30902 L
.77143 .30902 L
.77186 .30902 L
.77227 .30902 L
.77269 .30902 L
.77291 .30902 L
.77316 .30902 L
.77338 .30902 L
.77348 .30902 L
.77358 .30902 L
.77368 .30902 L
.77377 .30902 L
.77387 .30902 L
.77398 .30902 L
Mistroke
.77408 .30902 L
.77413 .30902 L
.77418 .30902 L
.77428 .30902 L
.77438 .30902 L
.77449 .30902 L
.77459 .30902 L
.77481 .30902 L
.77521 .30902 L
.77559 .30902 L
.77706 .30902 L
.77789 .30902 L
.7783 .30902 L
.77867 .30902 L
.77904 .30902 L
.77943 .30902 L
.77964 .30902 L
.77983 .30902 L
.78004 .30902 L
.78015 .30902 L
.78026 .30902 L
.78036 .30902 L
.78042 .30902 L
.78048 .30902 L
.78058 .30902 L
.78067 .30902 L
.78073 .30902 L
.78079 .30902 L
.78089 .30902 L
.78095 .30902 L
.781 .30902 L
.78113 .30902 L
.78133 .30902 L
.78152 .30902 L
.78194 .30902 L
.78362 .30902 L
.78436 .30902 L
.78475 .30902 L
.78517 .30902 L
.78557 .30902 L
.78595 .30902 L
.78613 .30902 L
.78632 .30902 L
.7865 .30902 L
.78667 .30902 L
.78677 .30902 L
.78686 .30902 L
.78696 .30902 L
.78704 .30902 L
.78714 .30902 L
Mistroke
.7872 .30902 L
.78725 .30902 L
.78734 .30902 L
.78745 .30902 L
.78755 .30902 L
.78767 .30902 L
.78788 .30902 L
.78827 .30902 L
.78983 .30902 L
.79066 .30902 L
.79112 .30902 L
.79155 .30902 L
.79196 .30902 L
.79218 .30902 L
.79241 .30902 L
.7926 .30902 L
.79282 .30902 L
.79291 .30902 L
.79301 .30902 L
.7931 .30902 L
.79319 .30902 L
.79329 .30902 L
.79338 .30902 L
.79343 .30902 L
.79348 .30902 L
.79358 .30902 L
.79368 .30902 L
.79378 .30902 L
.79388 .30902 L
.79399 .30902 L
.79417 .30902 L
.79434 .30902 L
.79472 .30902 L
.79621 .30902 L
.797 .30902 L
.79784 .30902 L
.7983 .30902 L
.79872 .30902 L
.79892 .30902 L
.79914 .30902 L
.79924 .30902 L
.79934 .30902 L
.79944 .30902 L
.79953 .30902 L
.79964 .30902 L
.79973 .30902 L
.79983 .30902 L
.79988 .30902 L
.79993 .30902 L
.80002 .30902 L
Mistroke
.80011 .30902 L
.80021 .30902 L
.8003 .30902 L
.80041 .30902 L
.80052 .30902 L
.80071 .30902 L
.80115 .30902 L
.80275 .30902 L
.80345 .30902 L
.80421 .30902 L
.80463 .30902 L
.80502 .30902 L
.80539 .30902 L
.80558 .30902 L
.80578 .30902 L
.8059 .30902 L
.806 .30902 L
.8061 .30902 L
.8062 .30902 L
.80626 .30902 L
.80632 .30902 L
.80638 .30902 L
.80644 .30902 L
.80654 .30902 L
.8066 .30902 L
.80665 .30902 L
.80684 .30902 L
.80705 .30902 L
.80747 .30902 L
.80917 .30902 L
.80997 .30902 L
.81072 .30902 L
.81109 .30902 L
.81149 .30902 L
.8117 .30902 L
.81189 .30902 L
.8121 .30902 L
.81222 .30902 L
.81228 .30902 L
.81233 .30902 L
.81242 .30902 L
.81252 .30902 L
.81261 .30902 L
.8127 .30902 L
.8128 .30902 L
.8129 .30902 L
.813 .30902 L
.81311 .30902 L
.81329 .30902 L
.81346 .30902 L
Mistroke
.81385 .30902 L
.81534 .30902 L
.81613 .30902 L
.81656 .30902 L
.81697 .30902 L
.81739 .30902 L
.81761 .30902 L
.81786 .30902 L
.81806 .30902 L
.81818 .30902 L
.81828 .30902 L
.81838 .30902 L
.81847 .30902 L
.81857 .30902 L
.81868 .30902 L
.81878 .30902 L
.81883 .30902 L
.81888 .30902 L
.81898 .30902 L
.81907 .30902 L
.81913 .30902 L
.81918 .30902 L
.81928 .30902 L
.81951 .30902 L
.8197 .30902 L
.81988 .30902 L
.82029 .30902 L
.8218 .30902 L
.8226 .30902 L
.82303 .30902 L
.82343 .30902 L
.82386 .30902 L
.82409 .30902 L
.82433 .30902 L
.82444 .30902 L
.82455 .30902 L
.82466 .30902 L
.82476 .30902 L
.82486 .30902 L
.82492 .30902 L
.82497 .30902 L
.82506 .30902 L
.82516 .30902 L
.82526 .30902 L
.82535 .30902 L
.82546 .30902 L
.82557 .30902 L
.8258 .30902 L
.826 .30902 L
.82678 .30902 L
Mistroke
.82759 .30902 L
.82845 .30902 L
.82918 .30902 L
.8296 .30902 L
.82999 .30902 L
.83018 .30902 L
.83039 .30902 L
.83059 .30902 L
.83068 .30902 L
.83077 .30902 L
.83085 .30902 L
.83093 .30902 L
.83102 .30902 L
.83111 .30902 L
.8312 .30902 L
.83129 .30902 L
.83139 .30902 L
.83148 .30902 L
.83158 .30902 L
.83164 .30902 L
.83169 .30902 L
.83189 .30902 L
.83206 .30902 L
.83225 .30902 L
.83308 .30902 L
.83389 .30902 L
.83467 .30902 L
.83536 .30902 L
.83575 .30902 L
.83612 .30902 L
.83632 .30902 L
.83652 .30902 L
.83669 .30902 L
.83687 .30902 L
.83697 .30902 L
.83708 .30902 L
.83713 .30902 L
.83719 .30902 L
.83729 .30902 L
.8374 .30902 L
.83749 .30902 L
.83758 .30902 L
.83768 .30902 L
.83778 .30902 L
.83788 .30902 L
.8381 .30902 L
.83832 .30902 L
.83855 .30902 L
.83935 .30902 L
.84012 .30902 L
Mistroke
.84093 .30902 L
.8414 .30902 L
.84183 .30902 L
.84203 .30902 L
.84225 .30902 L
.84246 .30902 L
.84266 .30902 L
.84284 .30902 L
.84304 .30902 L
.84315 .30902 L
.84321 .30902 L
.84326 .30902 L
.84336 .30902 L
.84346 .30902 L
.84352 .30902 L
.84357 .30902 L
.84368 .30902 L
.84378 .30902 L
.84387 .30902 L
.84398 .30902 L
.84409 .30902 L
.84431 .30902 L
.8447 .30902 L
.8451 .30902 L
.84584 .30902 L
.84666 .30902 L
.84709 .30902 L
.84755 .30902 L
.84795 .30902 L
.84816 .30902 L
.84839 .30902 L
.8486 .30902 L
.84879 .30902 L
.84898 .30902 L
.84917 .30902 L
.84927 .30902 L
.84932 .30902 L
.84937 .30902 L
.84947 .30902 L
.84957 .30902 L
.84966 .30902 L
.84974 .30902 L
.84984 .30902 L
.84993 .30902 L
.85004 .30902 L
.85015 .30902 L
.85036 .30902 L
.85075 .30902 L
.85223 .30902 L
.85305 .30902 L
Mistroke
.85345 .30902 L
.85382 .30902 L
.8542 .30902 L
.85462 .30902 L
.85482 .30902 L
.85505 .30902 L
.85516 .30902 L
.85522 .30902 L
.85528 .30902 L
.85534 .30902 L
.8554 .30902 L
.8555 .30902 L
.8556 .30902 L
.85569 .30902 L
.8558 .30902 L
.85589 .30902 L
.85599 .30902 L
.85607 .30902 L
.85626 .30902 L
.85667 .30902 L
.8571 .30902 L
.85879 .30902 L
.85919 .30902 L
.85961 .30902 L
.85983 .30902 L
.86008 .30902 L
.8603 .30902 L
.86051 .30902 L
.8607 .30902 L
.86091 .30902 L
.86103 .30902 L
.86113 .30902 L
.86124 .30902 L
.86129 .30902 L
.86134 .30902 L
.86144 .30902 L
.86154 .30902 L
.86162 .30902 L
.86172 .30902 L
.86182 .30902 L
.86191 .30902 L
.86202 .30902 L
.86213 .30902 L
.86233 .30902 L
.86255 .30902 L
.86295 .30902 L
.86384 .30902 L
.86462 .30902 L
.86505 .30902 L
.86546 .30902 L
Mistroke
.86585 .30902 L
.86606 .30902 L
.86628 .30902 L
.86647 .30902 L
.86667 .30902 L
.86686 .30902 L
.86703 .30902 L
.86712 .30902 L
.86721 .30902 L
.86731 .30902 L
.8674 .30902 L
.86749 .30902 L
.86757 .30902 L
.86766 .30902 L
.86774 .30902 L
.86783 .30902 L
.86793 .30902 L
.86811 .30902 L
.8683 .30902 L
.8685 .30902 L
.87019 .30902 L
.87099 .30902 L
.87138 .30902 L
.87174 .30902 L
.87211 .30902 L
.8725 .30902 L
.87271 .30902 L
.87282 .30902 L
.87293 .30902 L
.87303 .30902 L
.87314 .30902 L
.87324 .30902 L
.87333 .30902 L
.87343 .30902 L
.87353 .30902 L
.87363 .30902 L
.87372 .30902 L
.8738 .30902 L
.87389 .30902 L
.87407 .30902 L
.87426 .30902 L
.87447 .30902 L
.87485 .30902 L
.87643 .30902 L
.87686 .30902 L
.87732 .30902 L
.87776 .30902 L
.87815 .30902 L
.87835 .30902 L
.87856 .30902 L
Mistroke
.87874 .30902 L
.87884 .30902 L
.87894 .30902 L
.87899 .30902 L
.87905 .30902 L
.87915 .30902 L
.87921 .30902 L
.87927 .30902 L
.87933 .30902 L
.87938 .30902 L
.87948 .30902 L
.87954 .30902 L
.87959 .30902 L
.87969 .30902 L
.87979 .30902 L
.87997 .30902 L
.88017 .30902 L
.88053 .30902 L
.88133 .30902 L
.88215 .30902 L
.88258 .30902 L
.88304 .30902 L
.88344 .30902 L
.88365 .30902 L
.88388 .30902 L
.88409 .30902 L
.88428 .30902 L
.88447 .30902 L
.88466 .30902 L
.88476 .30902 L
.88487 .30902 L
.88497 .30902 L
.88506 .30902 L
.88515 .30902 L
.88524 .30902 L
.88534 .30902 L
.88543 .30902 L
.88553 .30902 L
.88563 .30902 L
.88582 .30902 L
.88602 .30902 L
.88625 .30902 L
.88772 .30902 L
.88854 .30902 L
.88894 .30902 L
.88931 .30902 L
.88969 .30902 L
.88989 .30902 L
.89011 .30902 L
.89021 .30902 L
Mistroke
.89033 .30902 L
.89042 .30902 L
.89053 .30902 L
.8906 .30902 L
.89065 .30902 L
.89071 .30902 L
.89077 .30902 L
.89083 .30902 L
.89088 .30902 L
.89093 .30902 L
.89099 .30902 L
.89105 .30902 L
.8911 .30902 L
.8912 .30902 L
.8913 .30902 L
.89136 .30902 L
.89141 .30902 L
.8916 .30902 L
.8918 .30902 L
.89269 .30902 L
.89347 .30902 L
.8939 .30902 L
.8943 .30902 L
.8947 .30902 L
.89513 .30902 L
.89532 .30902 L
.89552 .30902 L
.89569 .30902 L
.89588 .30902 L
.89607 .30902 L
.89624 .30902 L
.89641 .30902 L
.89649 .30902 L
.89658 .30902 L
.89668 .30902 L
.89677 .30902 L
.89683 .30902 L
.89688 .30902 L
.89698 .30902 L
.89708 .30902 L
.89717 .30902 L
.89735 .30902 L
.89756 .30902 L
.89775 .30902 L
.89811 .30902 L
.89893 .30902 L
.8997 .30902 L
.9004 .30902 L
.90079 .30902 L
.90117 .30902 L
Mistroke
.90136 .30902 L
.90156 .30902 L
.90179 .30902 L
.90189 .30902 L
.90199 .30902 L
.90208 .30902 L
.90217 .30902 L
.90226 .30902 L
.90236 .30902 L
.90244 .30902 L
.90253 .30902 L
.90261 .30902 L
.9027 .30902 L
.9028 .30902 L
.90289 .30902 L
.90299 .30902 L
.90309 .30902 L
.90347 .30902 L
.90508 .30902 L
.90578 .30902 L
.90614 .30902 L
.90653 .30902 L
.90673 .30902 L
.90696 .30902 L
.90716 .30902 L
.90735 .30902 L
.90754 .30902 L
.90764 .30902 L
.90774 .30902 L
.90784 .30902 L
.90793 .30902 L
.90802 .30902 L
.90811 .30902 L
.90822 .30902 L
.90831 .30902 L
.90841 .30902 L
.90847 .30902 L
.90852 .30902 L
.90862 .30902 L
.90873 .30902 L
.90891 .30902 L
.90937 .30902 L
.90979 .30902 L
.91061 .30902 L
.91146 .30902 L
.91182 .30902 L
.9122 .30902 L
.91241 .30902 L
.91261 .30902 L
.91282 .30902 L
Mistroke
.913 .30902 L
.91319 .30902 L
.91329 .30902 L
.9134 .30902 L
.91349 .30902 L
.91358 .30902 L
.91367 .30902 L
.91376 .30902 L
.91386 .30902 L
.91396 .30902 L
.91406 .30902 L
.91416 .30902 L
.91421 .30902 L
.91426 .30902 L
.91438 .30902 L
.91459 .30902 L
.91493 .30902 L
.91532 .30902 L
.91609 .30902 L
.91685 .30902 L
.91726 .30902 L
.91765 .30902 L
.91806 .30902 L
.91828 .30902 L
.91852 .30902 L
.91874 .30902 L
.91894 .30902 L
.91912 .30902 L
.91923 .30902 L
.91932 .30902 L
.91942 .30902 L
.91952 .30902 L
.9196 .30902 L
.9197 .30902 L
.9198 .30902 L
.91985 .30902 L
.91991 .30902 L
.9201 .30902 L
.92028 .30902 L
.92048 .30902 L
.92083 .30902 L
.92162 .30902 L
.92249 .30902 L
.92289 .30902 L
.92332 .30902 L
.92372 .30902 L
.92409 .30902 L
.92431 .30902 L
.92451 .30902 L
.92462 .30902 L
Mistroke
.92473 .30902 L
.92479 .30902 L
.92485 .30902 L
.92491 .30902 L
.92496 .30902 L
.92507 .30902 L
.92512 .30902 L
.92518 .30902 L
.92524 .30902 L
.92529 .30902 L
.92539 .30902 L
.92549 .30902 L
.92558 .30902 L
.92579 .30902 L
.92598 .30902 L
.92616 .30902 L
.92657 .30902 L
.9273 .30902 L
.92816 .30902 L
.92854 .30902 L
.92896 .30902 L
.92934 .30902 L
.9297 .30902 L
.9299 .30902 L
.93008 .30902 L
.93028 .30902 L
.93038 .30902 L
.93049 .30902 L
.93054 .30902 L
.9306 .30902 L
.93066 .30902 L
.93071 .30902 L
.9308 .30902 L
.93091 .30902 L
.93096 .30902 L
.93102 .30902 L
.93112 .30902 L
.93124 .30902 L
.93135 .30902 L
.93176 .30902 L
.93216 .30902 L
.93299 .30902 L
.93377 .30902 L
.93447 .30902 L
.93486 .30902 L
.93523 .30902 L
.93542 .30902 L
.93559 .30902 L
.93579 .30902 L
.9359 .30902 L
Mistroke
.936 .30902 L
.9361 .30902 L
.9362 .30902 L
.9363 .30902 L
.93636 .30902 L
.93641 .30902 L
.93651 .30902 L
.93662 .30902 L
.93672 .30902 L
.93681 .30902 L
.93702 .30902 L
.93722 .30902 L
.93767 .30902 L
.93849 .30902 L
.93934 .30902 L
.93976 .30902 L
.94014 .30902 L
.94049 .30902 L
.94086 .30902 L
.94105 .30902 L
.94123 .30902 L
.94133 .30902 L
.94142 .30902 L
.94153 .30902 L
.94163 .30902 L
.94172 .30902 L
.94182 .30902 L
.94192 .30902 L
.942 .30902 L
.9421 .30902 L
.9422 .30902 L
.94231 .30902 L
.94241 .30902 L
.94281 .30902 L
.94323 .30902 L
.94471 .30902 L
.94511 .30902 L
.94553 .30902 L
.94575 .30902 L
.94599 .30902 L
.94622 .30902 L
.94642 .30902 L
.94663 .30902 L
.94682 .30902 L
.94693 .30902 L
.94703 .30902 L
.94709 .30902 L
.94714 .30902 L
.9472 .30902 L
.94726 .30902 L
Mistroke
.94735 .30902 L
.94745 .30902 L
.94754 .30902 L
.94763 .30902 L
.94773 .30902 L
.94784 .30902 L
.94804 .30902 L
.94846 .30902 L
.94886 .30902 L
.94974 .30902 L
.95015 .30902 L
.95058 .30902 L
.95095 .30902 L
.95136 .30902 L
.95174 .30902 L
.95195 .30902 L
.95214 .30902 L
.95224 .30902 L
.95232 .30902 L
.95241 .30902 L
.95249 .30902 L
.95258 .30902 L
.95267 .30902 L
.95276 .30902 L
.95286 .30902 L
.95291 .30902 L
.95297 .30902 L
.95308 .30902 L
.95318 .30902 L
.95327 .30902 L
.95349 .30902 L
.95372 .30902 L
.95451 .30902 L
.95534 .30902 L
.95578 .30902 L
.95624 .30902 L
.95664 .30902 L
.95686 .30902 L
.95708 .30902 L
.95729 .30902 L
.95748 .30902 L
.95758 .30902 L
.95768 .30902 L
.95777 .30902 L
.95786 .30902 L
.95796 .30902 L
.95805 .30902 L
.95814 .30902 L
.95825 .30902 L
.95834 .30902 L
Mistroke
.95844 .30902 L
.95853 .30902 L
.95862 .30902 L
.95882 .30902 L
.95905 .30902 L
.95945 .30902 L
.96026 .30902 L
.96114 .30902 L
.96154 .30902 L
.96197 .30902 L
.96217 .30902 L
.96237 .30902 L
.96255 .30902 L
.96274 .30902 L
.96294 .30902 L
.96305 .30902 L
.96316 .30902 L
.96327 .30902 L
.96336 .30902 L
.96345 .30902 L
.96355 .30902 L
.96365 .30902 L
.96371 .30902 L
.96377 .30902 L
.96387 .30902 L
.96397 .30902 L
.96403 .30902 L
.96409 .30902 L
.96419 .30902 L
.96443 .30902 L
.96602 .30902 L
.96671 .30902 L
.96708 .30902 L
.96747 .30902 L
.96769 .30902 L
.96789 .30902 L
.96809 .30902 L
.96827 .30902 L
.96846 .30902 L
.96856 .30902 L
.96866 .30902 L
.96875 .30902 L
.96884 .30902 L
.96893 .30902 L
.96903 .30902 L
.96909 .30902 L
.96914 .30902 L
.96925 .30902 L
.96931 .30902 L
.96936 .30902 L
Mistroke
.96948 .30902 L
.96969 .30902 L
.96991 .30902 L
.97071 .30902 L
.97154 .30902 L
.97232 .30902 L
.97271 .30902 L
.97313 .30902 L
.97337 .30902 L
.97359 .30902 L
.9738 .30902 L
.97391 .30902 L
.97402 .30902 L
.97409 .30902 L
.97415 .30902 L
.97421 .30902 L
.97427 .30902 L
.97434 .30902 L
.97442 .30902 L
.97448 .30902 L
.97455 .30902 L
.97462 .30902 L
.97468 .30902 L
.97474 .30902 L
.97481 .30902 L
.97505 .30902 L
.97533 .30902 L
.9756 .30902 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{421.375, 260.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008>0001AB000`400?l00000o`00003ooooooooo
oooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo
003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooo
oooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool0
0?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooooooo
ool@ooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooo
ooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo0ol0003o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0
003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo
00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`
ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLoooo
o`00<?ooool3o`000?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?oo
ool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0
033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomco
oooo000`ooooo`03o`000?oooooooooo05Cooooo0_l0003oooooohKooooo000`ooooo`03o`000?oo
oooooooo05Cooooo0_l0003oooooohKooooo000`ooooo`03o`000?oooooooooo05Cooooo0_l0003o
ooooohKooooo000`ooooo`03o`000?oooooooooo05Cooooo0_l0003oooooohKooooo000`ooooo`03
o`000?oooooooooo05Cooooo0_l0003oooooohKooooo000`ooooo`?o0000E?ooool2o`000?oooooo
Q_ooool0033ooooo00?o0000ooooooooool0E?ooool2o`000?ooooooQ_ooool0033ooooo00?o0000
ooooooooool0E?ooool2o`000?ooooooQ_ooool0033ooooo00?o0000ooooooooool0E?ooool2o`00
0?ooooooQ_ooool0033ooooo00?o0000ooooooooool0E?ooool2o`0000[ooooo00?o0000oooooooo
ool0oooooomiooooo`00<?ooool00ol0003oooooooooo`1Dooooo`;o00002_ooool00ol0003ooooo
ooooo`3oooooogWooooo000`ooooo`03o`000?oooooooooo05Cooooo0_l0000:ooooo`;o0000oooo
oomjooooo`004?ooool2onk^kP?ooooo0_o^k^hIooooo`03o`000?oooooooooo05Cooooo0_l0000:
ooooo`;o0000oooooomjooooo`002oooool2o`00000:oa0@4?ooooooooooonk^k_mEEEGok^k^oooo
ooo^k^koEEEEonk^kP?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^2_oo
ool00ol0003oooooooooo`1Dooooo`;o00002_ooool2o`000?ooooooN_ooool000cooooo00?o0000
ooooooooool00_ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00[ooooo00?o0000ooooooooool0E?ooool00ol0003ooooo
o`000009ooooo`;o0000oooooomjooooo`0000?oooooo`000?l000001?l00002ooooo`Go00001?oo
ool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooo
oa0@400:ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooool000002Oooool2o`000?oooooo
N_ooool000Wooooo00CoA4A4omgMgOoooooo00001?ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Ko
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000[ooooo00?o0000oooo
ooooool0E?ooool00ol0003oooooo`000009ooooo`;o0000oooooomjooooo`002Oooool01?oMgMgo
EEEEooooool00003ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000:ooooo`Co0000Doooool00ol0003ooooo
o`000009ooooo`;o0000oooooomjooooo`002_ooool00omgMgOoc<c<o`000003ooooo`;ok^k^0ooo
ool2onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00[ooooo
00?o0000ooooooooool0E?ooool00ol0003oooooo`000008ooooo`03o`000?oooooo00000?oooooo
N_ooool000[ooooo00?ok^k^odA4A?l000003oooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL00oooool2o`0000Gooooo00?o0000ooooooooool0E?ooool00ol0003ooooo
o`000008ooooo`03o`000?oooooo00000?ooooooN_ooool000_ooooo00?oMgMgo`000?ooool03?oo
ool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_ooool01?l0003ooooo
ooooool00004ooooo`03o`000?oooooooooo05?ooooo00Co0000oooooooooooo00002?ooool00ol0
003oooooo`00003oooooog[ooooo000Xooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooo
ooooool0Doooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?ooooooN_ooool0
02Sooooo0ol00005ooooo`03o`000?oooooooooo05?ooooo00Co0000oooooooooooo00002?ooool0
0ol0003oooooo`00003oooooog[ooooo000Yooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0Doooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?ooooooN_ooool0
02[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Cooooo`04o`000?oooooooooo
o`0000Sooooo00?o0000ooooool00000oooooomjooooo`00<?ooool00ol0003oooooooooo`1Coooo
o`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooomjooooo`00<?ooool00ol0
003oooooooooo`1Cooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooomj
ooooo`00<?ooool00ol0003oooooooooo`1Cooooo`04o`000?ooooooooooo`0000Sooooo00?o0000
ooooool00000oooooomjooooo`00<?ooool00ol0003oooooooooo`1Cooooo`04o`000?oooooooooo
o`0000Sooooo00?o0000ooooool00000oooooomjooooo`00<?ooool3o`0005?ooooo00Co0000oooo
oooooooo00002?ooool00ol0003oooooo`00003oooooog[ooooo000`ooooo`03o`000?oooooooooo
05?ooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003oooooog[ooooo000`oooo
o`03o`000?oooooooooo05?ooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003o
ooooog[ooooo000`ooooo`03o`000?oooooooooo05?ooooo00Co0000oooooooooooo00002?ooool0
0ol0003oooooo`00003oooooog[ooooo000`ooooo`03o`000?oooooooooo04Sooooo0_l00009oooo
o`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooomjooooo`00<?ooool00ol0
003oooooooooo`18ooooo`;o00002Oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo
00000?ooooooN_ooool0033ooooo00?o0000ooooooooool0B?ooool2o`0000Wooooo00Co0000oooo
oooooooo00002?ooool00ol0003oooooo`00003oooooog[ooooo000`ooooo`03o`000?oooooooooo
04Sooooo0_l00009ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooomj
ooooo`00<?ooool00ol0003oooooooooo`18ooooo`;o00002Oooool01?l0003oooooooooool00008
ooooo`03o`000?oooooo00000?ooooooN_ooool0033ooooo00?o0000ooooooooool0B?ooool2o`00
00Wooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003oooooog[ooooo000`oooo
o`03o`000?oooooooooo04Oooooo00?o0000ooooool000002Oooool01?l0003oooooooooool00008
ooooo`03o`000?oooooo00000?ooooooN_ooool0033ooooo00?o0000ooooooooool0Aoooool00ol0
003oooooo`000009ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooomj
ooooo`00<?ooool3o`0004Oooooo00?o0000ooooool000002Oooool01?l0003oooooooooool00008
ooooo`03o`000?oooooo00000?ooooooN_ooool0033ooooo00?o0000ooooooooool0Aoooool00ol0
003oooooo`000009ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000oooo
oomiooooo`00<?ooool00ol0003oooooooooo`17ooooo`03o`000?oooooo000000Wooooo00Co0000
oooooooooooo00002?ooool01?l0003oooooooooool0003oooooogWooooo000`ooooo`03o`000?oo
oooooooo04Oooooo00?o0000ooooool000002Oooool01?l0003oooooooooool00008ooooo`04o`00
0?ooooooooooo`000?ooooooNOooool0033ooooo00?o0000ooooooooool0Aoooool00ol0003ooooo
o`000009ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002?ooool00ol0
003oooooooooo`3oooooofkooooo000`ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooool0
00002Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000
ooooooooool0oooooom^ooooo`00<?ooool00ol0003oooooooooo`17ooooo`03o`000?oooooo0000
00Wooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Sooooo00?o
0000ooooooooool0oooooom^ooooo`00<?ooool00ol0003oooooooooo`17ooooo`03o`000?oooooo
000000Wooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Sooooo
0_l0003oooooofoooooo000`ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooool000002Ooo
ool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo00002?ooool2o`000?oo
ooooKoooool0033ooooo00?o0000ooooooooool0Aoooool00ol0003oooooo`000009ooooo`05o`00
0?ooooooooooooooool000001oooool01?l0003oooooooooool00008ooooo`;o0000oooooom_oooo
o`00<?ooool00ol0003oooooooooo`17ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000oooo
ooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool00000oooo
oom_ooooo`00<?ooool3o`0004Oooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooo
oooooooo000000Kooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?oo
ooooKoooool0033ooooo00?o0000ooooooooool0Aoooool01?l0003oooooooooool00008ooooo`05
o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000
ooooool00000oooooom_ooooo`00<?ooool00ol0003oooooooooo`17ooooo`04o`000?oooooooooo
o`0000Sooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool00000
1oooool00ol0003oooooo`00003oooooofoooooo000`ooooo`03o`000?oooooooooo04Oooooo00Co
0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000oooooooo
ooooooooo`000007ooooo`03o`000?oooooo00000?ooooooKoooool0033ooooo00?o0000oooooooo
ool0Aoooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool000001_ooool0
1Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooool00000oooooom_ooooo`00<?ooool0
0ol0003oooooooooo`17ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooooooooooo
o`000006ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003oooooofoo
oooo000`ooooo`03o`000?oooooooooo04Oooooo00Co0000oooooooooooo00002?ooool01Ol0003o
oooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo
00000?ooooooKoooool0013ooooo0_o^k^h3ooooo`;ok^k^6Oooool00ol0003oooooooooo`17oooo
o`04o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?oo
ooooooooooooool000001oooool00ol0003oooooo`00003oooooofoooooo0009ooooo`Go00000_oo
ool01oo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^
k_lb<S;o0000oc8b<_o^k^h:ooooo`03o`000?oooooooooo04Oooooo00Co0000oooooooooooo0000
2?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000007oooo
o`03o`000?oooooo00000?ooooooKoooool000Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A003oooo
o`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02_ooool00ol0003oooooooooo`16ooooo`05o`000?ooooooooooooooool00000
2?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000007oooo
o`03o`000?oooooo00000?ooooooKoooool00003ooooool0003o000000Co00000oooool00onHV9So
8B4Qonk^kP05ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@413o
oooooooooooooooo410@00[ooooo00?o0000ooooooooool0A_ooool01Ol0003ooooooooooooooooo
000000Sooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool00000
1oooool00ol0003oooooo`00003oooooofoooooo000;ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go
k^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`00000:ooooo`03o`000?oooooooooo04Kooooo00Go0000ooooooooooooooooo`000008oooo
o`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Oooooo00?o
0000ooooool00000oooooom_ooooo`003?ooool02omgMgOoIVIVooooooooooook^k^oeEEEOo^k^ko
ooooonk^k_mEEEGok^k^00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo
000000[ooooo1?l00015ooooo`05o`000?ooooooooooooooool000002?ooool01Ol0003ooooooooo
oooooooo000000Kooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?oo
ooooKoooool000gooooo00?o0000ooooooooool00_o^k^h3ooooo`;ok^k^1Oooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41002_ooool00ol0003oooooooooo`16ooooo`05
o`000?ooooooooooooooool000002?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000
ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?ooooooKoooool000Wooooo00Go0000
okZj^_ooooooV9RHoa0@400>ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`;o00001Oooool00ol0003oooooooooo`16ooooo`05o`000?ooooooooooooooool0
00002?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000007
ooooo`03o`000?oooooo00000?ooooooKoooool000Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00<
ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool0A_ooool01Ol0003ooooooooooooooooo000000So
oooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001oooool0
0ol0003oooooo`00003oooooofoooooo000Xooooo`04o`000?ooooooooooo`0000Cooooo00?o0000
ooooooooool0A_ooool01Ol0003ooooooooooooooooo000000Sooooo00Go0000oooooooooooooooo
o`000006ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003oooooofoo
oooo000Xooooo`?o00001Oooool00ol0003oooooooooo`16ooooo`05o`000?ooooooooooooooool0
00002?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000006
ooooo`04o`000?ooooooooooo`000?ooooooKoooool002Wooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`16ooooo`05o`000?ooooooooooooooool000001oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`04o`00
0?ooooooooooo`000?ooooooKoooool002[ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`16ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?oooooooooo
ooooool00000oooooom^ooooo`00<?ooool00ol0003oooooooooo`16ooooo`05o`000?oooooooooo
ooooool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000
ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool00000oooooom^ooooo`00<?oo
ool00ol0003oooooooooo`16ooooo`05o`000?ooooooooooooooool000001oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`05
o`000?ooooooooooooooool00000oooooom^ooooo`00<?ooool00ol0003oooooooooo`16ooooo`05
o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool00000oooo
oom^ooooo`00<?ooool00ol0003oooooooooo`16ooooo`05o`000?ooooooooooooooool000001ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooooooo
o`000006ooooo`05o`000?ooooooooooooooool00000oooooom^ooooo`00<?ooool3o`0004Kooooo
00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`00003o
ooooofkooooo000`ooooo`03o`000?oooooooooo04Kooooo00Go0000ooooooooooooooooo`000007
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooo
oooo000000Kooooo00Go0000ooooooooooooooooo`00003oooooofkooooo000`ooooo`03o`000?oo
oooooooo04Kooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000oooooooo
ooooooooo`00003oooooofkooooo000`ooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool02?ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooo
oooo000000Sooooo00?o0000ooooooooool0oooooomSooooo`00<?ooool00ol0003oooooooooo`0j
ooooo`?o00002Oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooo
oooooooooooo000000Oooooo0_l0003oooooofGooooo000`ooooo`03o`000?oooooooooo03[ooooo
00?o0000ooooool000002Oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0
003ooooooooooooooooo000000Oooooo0_l0003oooooofGooooo000`ooooo`03o`000?oooooooooo
03[ooooo00?o0000ooooool000002Oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_oo
ool01Ol0003ooooooooooooooooo000000Oooooo0_l0003oooooofGooooo000`ooooo`03o`000?oo
oooooooo03[ooooo00?o0000ooooool000002Oooool01Ol0003ooooooooooooooooo000000Oooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Oooooo0_l0003oooooofGo
oooo000`ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooool000002Oooool01Ol0003ooooo
oooooooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo0000
00Oooooo0_l0003oooooofGooooo000`ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooool0
00002Oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0
003ooooooooooooooooo000000Oooooo0_l0003oooooofGooooo000`ooooo`03o`000?oooooooooo
03[ooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Oooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo
0000oooooomTooooo`00<?ooool00ol0003oooooooooo`0jooooo`04o`000?ooooooooooo`0000Oo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`000?ooooooI?ooool0
033ooooo0ol0000iooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooo
oooo000000Kooooo00Co0000oooooooooooo0000oooooomTooooo`00<?ooool00ol0003ooooooooo
o`0iooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Ko
oooo00Co0000oooooooooooo0000oooooomTooooo`00<?ooool00ol0003oooooooooo`0iooooo`05
o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000
oooooooooooo0000oooooomTooooo`00<?ooool00ol0003oooooooooo`0iooooo`05o`000?oooooo
ooooooooool000001oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo
0000oooooomTooooo`00<?ooool00ol0003oooooooooo`0iooooo`05o`000?ooooooooooooooool0
00001oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo0000oooooomT
ooooo`00<?ooool00ol0003oooooooooo`0iooooo`05o`000?ooooooooooooooool000001oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ok^k^0_ooool00ol0003ok^k^onk^kP02
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool0000dooooo`;ok^k^
0oooool2onk^kV3ooooo0_o^k^h3ooooo`;ok^k^C_ooool2onk^kP?ooooo0_o^k^i/ooooo`00<?oo
ool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Ooo
ool01?l0003ooooooooooom4A4@3o`000009omgMgOooooook^k^oeEEEOo^k^koooooo`000?mEEEGo
k^k^00;ooooo1Ol000002?l@413oooooo`000?o^k^ko<S8bo`000?lb<S;o00001Oooool01Ol0003o
oooooooooooooooo000000Kooooo00Co0000oooooooooooo0000;_ooool4o`000009oa0@4?oooooo
k^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8b
o`000?lb<S;ok^k^>oooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`0=odA4A?l0
003o0000oc8b<_oMgMgoooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co000000So
410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kSSooooo1Ol00002ooooo`07onk^k_mEEEGok^k^
ooooooo^k^koEEEEonk^kP03ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^
kUgooooo000`ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00Wo0000oc8b<_ooooooooooonk^k_mEEEGo
gMgMo`000?o^k^h00oooool01?l0003oooooooooool00003ooooo`06o`000?mgMgOoV9RHoooooonH
V9So00001Oooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo0000<?oo
ool00ol0003oooooooooo`02ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?Oooool00ol0003oooooooooo`04ooooo`;o
8B4Q2?ooool02OmgMgOo<S8booooooooooook^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0hooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@00oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg05gooooo000`ooooo`03o`000?oooooooooo03Sooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo0_l00003oooo
o`03omgMgOl0003o000000Cooooo00Co0000oooooooooooo00000oooool00ol0003o410@ooooo`02
ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?oo
ooooooooo`00033ooooo00?o0000ooooooooool00oooool00ooMgMgo0000omgMg@07ooooo`03o`00
0?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400mooooo`03o`000?oooooooooo00oo
oooo00Oo0000ooooooooooooooooomgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@03Wooooo00?oV9RHob4Q8Oo^k^h01Oooool00ooMgMgo0000omgM
g@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@401Mooooo`00<?oo
ool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`03ooooo`09o`000?lb<S;oooooooooooo^k^koEEEEomgMgOl0003ok^k^
00?ooooo00Co0000oooooooooooo00000oooool2o`0000?ooooo00?o0000ooooooooool00oooool0
1Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo0000<?ooool00ol0003ooooo
ooooo`02ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool00000?Oooool00ol0003oooooooooo`0>ooooo`09ogMgMolb<S;ooooo
ooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000003[ooooo00?oV9RHob4Q8Oo^k^h00oooool01Oo^k^koEEEEomgMgOmEEEGok^k^
00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000005gooooo000`oooo
o`03o`000?oooooooooo03Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05oooo
o`05o`000?ooooooooooo`000?lQ8B400_l000002Oo<c<coooooonk^k_mEEEGok^k^ooooool0003o
EEEEonk^kP02ooooo`04o`000?ooooooooooo`0000?ooooo0_l00003ooooo`03o`000?oooooooooo
00?ooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`00033ooooo00_o
0000ooooooooooooooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`00000mooooo`03o`000?oooooooooo00_ooooo00go
0000ob4Q8Ol0003o<S8bolc<c?ooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000003_ooooo00_oMgMgofIVI_oooooo
ooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`00001Mooooo`00<?ooool00ol0003oooooooooo`0hooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooooooo00;ok^k^0_ooool00ol0003ok^k^onk^kP02ooooo`04o`000?ooooooooooo`0000?o
oooo00?o0000oa0@4?ooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooooooooooo
ool000001_ooool01?l0003oooooooooool00007ooooo`;o00009oooool01?l0003ooooooooooooo
ool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooo
oa0@400mooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00oooool2onk^kP?ooooo
0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400looooo`03
o`000?oooooooooo00;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@413o
oooooooooooooooo410@05gooooo000`ooooo`?o0000>?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Gooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000oooool01_l0003oMgMgoiRHV?oo
ooooV9RHo`0000Gooooo00?o0000ooooooooool00_l00006ooooo`04o`000?ooooooooooo`0000Oo
oooo0_l0000Wooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Sooooo0_l0000cooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool2
o`0002kooooo00Go0000okZj^_ooooooV9RHoa0@400>ooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`08ooooo`;o0000Doooool0033ooooo00?o0000ooooooooool0>?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?l0
0006ooooo`03o`000?oooooooooo00?ooooo00?o0000ofIVI_l000000oooool01_l0003ok^k^oc8b
<_l0003o<S8bo`0000Gooooo00?o0000ooooooooool00_l00006ooooo`04o`000?ooooooooooo`00
00Oooooo0_l0000Uooooo`03oeEEEOmVIVKo000000gooooo00?oEEEEofIVI_l000001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Oooooo00Co0000oooooooooooo0000<?ooool00omEEEGoIVIVo`00
000=ooooo`Co00003?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1oooool01?l0003oooooooooool0000]ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?ooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01oooool01?l0003oooooooooool0
001Booooo`00<?ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?l00003ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00001_oo
ool00ol0003oooooo`000013ooooo`Co000000Goooooo`000?ooooooooooo`00001Nooooo`Co0000
00Goooooo`000?ooooooooooo`00001<ooooo`Co000000Goooooo`000?ooooooooooo`00001Boooo
o`00<?ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000005
ooooo`03o`000?oooooo000004Sooooo0ol0001Tooooo`?o0000D_ooool3o`0005?ooooo000`oooo
o`03o`000?oooooooooo02cooooo0_l0000:ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00?ooooo00Go0000oooo
ooooooooooooo`000005ooooo`04o`000?ooooooooooo`0004Sooooo00?o0000ooooooooool0I?oo
ool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo05;ooooo000`ooooo`03o`000?oooooo
oooo02_ooooo1?l00008ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool0
0ol0003oooooo`000003o`0000Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`04o`000?ooooooooooo`0004Wooooo00?o0000ooooooooool0I?ooool00ol0003ooooooooo
o`1Booooo`03o`000?oooooooooo057ooooo000`ooooo`03o`000?oooooooooo02_ooooo00Co0000
oooooooooooo00002?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool01?l0003oooooooooool0003ooooooe[ooooo000`ooooo`03o`000?oo
oooooooo02_ooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool0003oooooob3o
oooo00?oMgMgofIVI_ooool0;Oooool00omVIVKoMgMgooooo`07ooooo`00<?ooool00ol0003ooooo
ooooo`0Zooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo0ol0003ooooooaKooooo00?ogMgMoa0@4?o^k^h0
;_ooool00oo^k^ko410@omgMg@07ooooo`00<?ooool00ol0003oooooooooo`0Yooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooool00000ooooool4ooooo`;o00000_ooool2o`0000cooooo00?o
EEEEoiRHV?ooool00_l00002ooooo`07o`000?ooooooooooo`000?l@413ok^k^oeEEE@02o`000003
odA4A?nj^[[ooooo00;ooooo00GoV9RHo`000?l0003oA4A4okZj^P02ooooo`08onk^k_mEEEGo0000
o`000?m4A4Co^[Zjooooool@4105o`0000?ooooo00So410@oc8b<_l0003o0000oa0@4?nYZJWoQhN7
ofIVIPOooooo000`ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool00007ooooo`03o`000?oooooooooo0?Wooooo00Kok^k^ob4Q8On7QhOo^[Zjo`00
0?oMgMd<ooooo`05o`000?ooooooooooooooool000000_ooool02ol0003oooooooooool0003ooooo
oeEEEOmgMgOoooooonk^k_mgMgOo410@00?ooooo00Go410@okZj^_o^k^koMgMgoa0@4002ooooo`06
oeEEEOmgMgOoooooonk^k_mgMgOo410@0oooool00ol0003oooooooooo`04ooooo`08o`000?nYZJWo
oooooooooonj^[[o0000onk^k_l00007ooooo`00ool0002do`0000oooooo00CogMgMo`000?l@413o
c<c<3Oooool01Olb<S;ooooooooooooooooo000000;ooooo00Ko0000oooooooooooo0000ooooool0
0008ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`05ooooo`07okZj^_n7QhOoIVIVofIVI_l@413oooooo`000007ooooo`002_ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0=ooooo`;o000000?oooooo`000?ooool00oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooool000001_ooool00ol0003oooooooooo`04ooooo`04o`00
0?ooooooooooo`0000;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`04
o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooooooo0_l00003ooooo`03o`000?oooooo
oooo00?ooooo00Co0000oooooooooooo00000oooool00ol0003oooooo`000003o`0000gooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Oooooo00Co
k^k^ob4Q8Ol@413ok^k^3Oooool01Olb<S;ooooooooooooooooo000000;ooooo00Go0000oooooooo
oooo0000ooooo`06o`0000?ooooo00?o0000ooooooooool01?ooool6o`0000?ooooo00?o0000oooo
ooooool01?ooool02?lb<S;o8B4QogMgMomgMgOoQhN7onk^k_oooooo00001oooool000[ooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool03oooool6o`0000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooo`00
0006ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00000_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooooooool2o`0000?ooooo00?o0000ooooooooool00oooool3o`0000Cooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool05oooool01?lQ8B7oMgMgogMgMolb<S8=ooooo`05o`000?o^k^koooooooooool000000_o<
c<`02ol0003oZJVYomgMgOlQ8B7ooooooeEEEOn7QhOok^k^oooooon7QhOo<S8b00?ooooo00?o0000
ooooooooool01?ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<P?ooooo00?o0000oc8b<_oMgMd0
1?ooool02?l0003o^[Zjooooooo^k^koMgMgo`000?o^k^ko00001oooool0033ooooo00?o0000oooo
ooooool09?ooool2o`0000[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oo
ooooooooooooool00000<_ooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo05_ooooo
00?o0000ooooooooool05_ooool2o`0000;ooooo0_l0000<ooooo`0>oeEEEOmgMgOooooooa0@4?l0
003o8B4Qo`000?mgMgOo410@o`000?nYZJWoooooonk^k_mEEED2o`000004odA4A?o^k^kooooooa0@
40Go00000oooool01_o^k^koEEEEo`000?l0003oA4A4onk^kP;ooooo0_l000001?nYZJWo8B4Qo`00
0?lQ8B42ooooo`08ojVYZOlQ8B7o0000o`000?lb<S;o0000ogMgMomEEED7ooooo`00<?ooool00ol0
003oooooooooo`0`ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001Oooool01?l0003oooooooooool0
003ooooooa[ooooo00?ogMgMoa0@4?o^k^h04_ooool00ol0003oooooooooo`0Iooooo`03onk^k_l@
413ogMgM00Oooooo000`ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00001_oo
ool01?l0003oooooooooool0003ooooooa_ooooo00?oMgMgofIVI_ooool04Oooool00ol0003ooooo
ooooo`0Iooooo`03ofIVI_mgMgOooooo00Oooooo000`ooooo`03o`000?oooooooooo037ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Co
0000oooooooooooo00001_ooool3o`000?ooooooE_ooool0033ooooo00?o0000ooooooooool0<Ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooo
ool01?l0003oooooooooool00007ooooo`;o0000oooooomFooooo`00<?ooool00ol0003ooooooooo
o`0booooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`04o`00
0?ooooooooooo`000?ooooooGoooool0033ooooo00?o0000ooooooooool0<_ooool01Ol0003ooooo
oooooooooooo000000Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05
o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool0003ooooooeoooooo000`oooo
o`03o`000?oooooooooo03;ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Kooooo00Co
0000oooooooooooo0000oooooomOooooo`00<?ooool00ol0003oooooooooo`0booooo`05o`000?oo
ooooooooooooool000001oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`000?ooooooGoooool0033o
oooo0ol0000booooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?oooooo
ooooo`000?ooooooGoooool0033ooooo00?o0000ooooooooool0<_ooool01Ol0003ooooooooooooo
oooo000000Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oo
ooooooooooooool000001_ooool01?l0003oooooooooool0003ooooooeoooooo000`ooooo`03o`00
0?oooooooooo03?ooooo00?o0000ooooool000002Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo00000?oo
ooooH?ooool0033ooooo00?o0000ooooooooool0<oooool00ol0003oooooo`000009ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooool00000oooooomPooooo`00<?ooool00ol0003oooooooooo`0cooooo`?o0000
2Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooo
ooooo`000006ooooo`03o`000?oooooo00000?ooooooH?ooool0033ooooo00?o0000ooooooooool0
=?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool01Ol0003ooooooooooooooooo000000Oooooo0_l0003oooooof3ooooo000`ooooo`03o`00
0?oooooooooo03oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`00
0?ooooooooooooooool000001oooool2o`000?ooooooH?ooool0033ooooo00?o0000ooooooooool0
?oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooo
ooooo`000007ooooo`;o0000oooooomPooooo`00<?ooool00ol0003oooooooooo`0oooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Oo
oooo0_l0003oooooof3ooooo000`ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool00000oooooomYooooo`00
<?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool01Ol0003ooooooooooooooooo00000?ooooooJOooool0033ooooo00?o0000ooooooooool0
?oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooo
ooooo`00003oooooofWooooo000`ooooo`?o0000?oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Go
oooo00Go0000ooooooooooooooooo`00003oooooofWooooo000`ooooo`03o`000?oooooooooo03oo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`000?ooooooJOooool0
033ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000
oooooooooooo0000oooooomYooooo`00<?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooo
ooooooooool000001_ooool01?l0003oooooooooool0003oooooofWooooo000`ooooo`03o`000?oo
oooooooo03oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`000?oo
ooooJOooool0033ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Ko
oooo00Co0000oooooooooooo0000oooooomYooooo`00<?ooool00ol0003oooooooooo`0oooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05
o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool0003oooooofWooooo000`oooo
o`03o`000?oooooooooo03oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?oooooo
ooooo`000?ooooooJOooool0033ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooo
oooo000000Kooooo00Co0000oooooooooooo0000oooooomYooooo`00<?ooool00ol0003ooooooooo
o`0oooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`04ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool0003oooooofWo
oooo000`ooooo`03o`000?oooooooooo043ooooo00Go0000ooooooooooooooooo`000007ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?oooooooooo
o`000?ooooooJOooool0033ooooo00?o0000ooooooooool0@?ooool01Ol0003ooooooooooooooooo
000000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00007ooooo`03o`000?oo
oooo00000?ooooooJ_ooool0033ooooo0ol00010ooooo`05o`000?ooooooooooooooool000001ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool00000
oooooomZooooo`00<?ooool00ol0003oooooooooo`10ooooo`05o`000?ooooooooooooooool00000
1oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool0
0000oooooomZooooo`00<?ooool00ol0003oooooooooo`10ooooo`05o`000?ooooooooooooooool0
00001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000oooo
ool00000oooooomZooooo`00<?ooool00ol0003oooooooooo`10ooooo`05o`000?oooooooooooooo
ool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000
ooooool00000oooooomZooooo`00<?ooool00ol0003oooooooooo`10ooooo`04o`000?oooooooooo
o`0000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00007ooooo`03o`000?oo
oooo00000?ooooooJ_ooool0033ooooo00?o0000ooooooooool0@?ooool01?l0003oooooooooool0
0008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00001oooool00ol0003ooooo
o`00003oooooof[ooooo000?ooooo`;ok^k^0oooool2onk^kQ[ooooo00?o0000ooooooooool0@?oo
ool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo
00002?ooool2o`000?ooooooJ_ooool000Sooooo1Ol00002ooooo`07onk^k_mEEEGok^k^ooooooo^
k^koEEEEonk^kP03ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo
00?o0000ooooooooool0@?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00Co0000oooooooooooo00002?ooool2o`000?ooooooJ_ooool000Sooooo00GoV9RHob4Q8Oo^
k^koooooodA4A003ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ol0003oooooooooo`10ooooo`04o`000?oo
ooooooooo`0000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00008ooooo`;o
0000oooooomZooooo`002Oooool00onHV9So8B4Qonk^kP05ooooo`03omgMgOl0003ogMgM00Oooooo
00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00_ooooo00?o0000oooooooo
ool0@?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Co0000oooo
oooooooo00002?ooool2o`000?ooooooJ_ooool000[ooooo00?oV9RHob4Q8Oo^k^h00oooool01Oo^
k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000000_ooooo00?o0000ooooooooool0@?ooool01?l0003oooooooooool00008ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00Co0000oooooooooooo00002?ooool2o`000?ooooooJ_ooool000_ooooo
00_oMgMgofIVI_ooooooooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000;ooooo`Co0000?oooool01?l0003ooooo
ooooool00008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00002?ooool2o`00
0?ooooooJ_ooool000cooooo00?o0000ooooooooool00_o^k^h3ooooo`;ok^k^1Oooool00ol0003o
ooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41002oooool00ol0003oooooooooo`11oooo
o`03o`000?oooooo000000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00008
ooooo`;o0000oooooomZooooo`002?ooool01Ol0003o^[ZjoooooonHV9So410@00kooooo00?o0000
ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?o0000ooooooooool0@Ooo
ool00ol0003oooooo`000008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Ooo
ool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo0000oooooomdooooo`00
2?ooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00?ooooo0_l00006ooooo`03o`000?oooooooooo047ooooo00?o0000oooo
ool000002?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00Co0000oooo
oooooooo00001oooool01?l0003oooooooooool0003oooooogCooooo000Wooooo`04o`000?oooooo
ooooo`0000Gooooo00?o0000ooooooooool0@Oooool00ol0003oooooo`000008ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00007ooooo`04o`00
0?ooooooooooo`000?ooooooM?ooool002Oooooo00Co0000oooooooooooo00001Oooool00ol0003o
ooooooooo`11ooooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`05ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo0000oooooomd
ooooo`009oooool3o`0000Kooooo00?o0000ooooooooool0@Oooool2o`0000Wooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000
oooooooooooo0000oooooomdooooo`00:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo047ooooo0_l00009ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool0
1?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`000?ooooooM?ooool002Wooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Oooooo
00Co0000oooooooooooo0000oooooomdooooo`00<?ooool00ol0003oooooooooo`1<ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00007ooooo`04
o`000?ooooooooooo`000?ooooooM?ooool0033ooooo00?o0000ooooooooool0C?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00001oooool01?l0
003oooooooooool0003oooooogCooooo000`ooooo`03o`000?oooooooooo04cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000
oooooooooooo0000oooooomdooooo`00<?ooool3o`0004gooooo00Go0000ooooooooooooooooo`00
0007ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo0000oooooomdooooo`00
<?ooool00ol0003oooooooooo`1=ooooo`05o`000?ooooooooooooooool000001oooool01?l0003o
ooooooooool00007ooooo`04o`000?ooooooooooo`000?ooooooM?ooool0033ooooo00?o0000oooo
ooooool0COooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Oooooo00Co
0000oooooooooooo0000oooooomdooooo`00<?ooool00ol0003oooooooooo`1=ooooo`04o`000?oo
ooooooooo`0000Sooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool0003ooooo
ogCooooo000`ooooo`03o`000?oooooooooo04gooooo00Co0000oooooooooooo00002?ooool01?l0
003oooooooooool00008ooooo`03o`000?oooooo00000?ooooooM?ooool0033ooooo00?o0000oooo
ooooool0COooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo00?o
0000ooooool00000oooooomdooooo`00<?ooool00ol0003oooooooooo`1=ooooo`04o`000?oooooo
ooooo`0000Sooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003oooooogCooooo
000`ooooo`03o`000?oooooooooo04gooooo00Co0000oooooooooooo00002?ooool01?l0003ooooo
ooooool00008ooooo`03o`000?oooooo00000?ooooooM?ooool0033ooooo00?o0000ooooooooool0
COooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000oooo
ool00000oooooomdooooo`00<?ooool00ol0003oooooooooo`1=ooooo`04o`000?ooooooooooo`00
00Sooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003oooooogCooooo000`oooo
o`03o`000?oooooooooo04gooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0
0008ooooo`03o`000?oooooo00000?ooooooM?ooool0033ooooo00?o0000ooooooooool0COooool0
1?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000
oooooomdooooo`00<?ooool3o`0004gooooo00Co0000oooooooooooo00002?ooool01?l0003ooooo
ooooool00008ooooo`03o`000?oooooo00000?ooooooM?ooool0033ooooo00?o0000ooooooooool0
COooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000oooo
ool00000oooooomdooooo`00<?ooool00ol0003oooooooooo`1=ooooo`04o`000?ooooooooooo`00
00Sooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003oooooogCooooo000`oooo
o`03o`000?oooooooooo04gooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0
0008ooooo`03o`000?oooooo00000?ooooooM?ooool0033ooooo00?o0000ooooooooool0COooool0
1?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000
oooooomdooooo`00<?ooool00ol0003oooooooooo`1=ooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003oooooogCooooo000`ooooo`03o`00
0?oooooooooo04gooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00008oooo
o`03o`000?oooooo00000?ooooooM?ooool0033ooooo00?o0000ooooooooool0COooool01?l0003o
ooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooomd
ooooo`00<?ooool00ol0003oooooooooo`1=ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000
oooooooooooo00002?ooool00ol0003oooooo`00003oooooogCooooo000`ooooo`03o`000?oooooo
oooo04gooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00008ooooo`;o0000
oooooomeooooo`00<?ooool00ol0003oooooooooo`1=ooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00002?ooool2o`000?ooooooMOooool0033ooooo00?o0000ooooooooool0
COooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo0_l0003ooooo
ogGooooo000`ooooo`?o0000COooool01?l0003oooooooooool00008ooooo`04o`000?oooooooooo
o`0000Sooooo0_l0003oooooogGooooo000`ooooo`03o`000?oooooooooo04kooooo00?o0000oooo
ool000002?ooool01?l0003oooooooooool00008ooooo`;o0000oooooomeooooo`00<?ooool00ol0
003oooooooooo`1>ooooo`03o`000?oooooo000000Sooooo00Co0000oooooooooooo00002?ooool2
o`000?ooooooMOooool0033ooooo00?o0000ooooooooool0C_ooool00ol0003oooooo`000008oooo
o`04o`000?ooooooooooo`0000Sooooo0_l0003oooooogGooooo000`ooooo`03o`000?oooooooooo
04kooooo00?o0000ooooool000002?ooool01?l0003oooooooooool0003oooooogoooooo000`oooo
o`03o`000?oooooooooo04kooooo00?o0000ooooool000002?ooool01?l0003oooooooooool0003o
ooooogoooooo000?ooooo`;ok^k^0oooool2onk^kQ[ooooo00?o0000ooooooooool0C_ooool2o`00
00Wooooo00Co0000oooooooooooo0000oooooomoooooo`002_ooool2o`00000:oa0@4?oooooooooo
onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP?ooooo1?l000002?l@413oooooooooooo^k^ko<S8b
o`000?lb<S;ok^k^2oooool00ol0003oooooooooo`1>ooooo`;o00002Oooool01?l0003ooooooooo
ool0003oooooogoooooo000;ooooo`03o`000?oooooooooo00;ooooo00Gok^k^oeEEEOoMgMgoEEEE
onk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03
o`000?oooooooooo04kooooo0_l00009ooooo`04o`000?ooooooooooo`000?ooooooOoooool000So
oooo1Ol00004ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@413o
oooooooooooooooo410@00_ooooo00?o0000ooooooooool0C_ooool2o`0000Wooooo00Co0000oooo
oooooooo0000oooooomoooooo`002?ooool01?m4A4CogMgMooooool00004ooooo`05onk^k_mEEEGo
gMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
2oooool00ol0003oooooooooo`1>ooooo`;o00002Oooool01?l0003oooooooooool0003oooooogoo
oooo0008ooooo`04omgMgOmEEEGoooooo`0000?ooooo00Ook^k^oeEEEOo^k^koooooonk^k_mEEEGo
k^k^00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000_ooooo1?l0
001=ooooo`;o00002Oooool01?l0003oooooooooool0003oooooogoooooo0009ooooo`03ogMgMoo<
c<co000000?ooooo0_o^k^h3ooooo`;ok^k^1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oo
ooooooooooooool@41002oooool00ol0003oooooooooo`1>ooooo`;o00002Oooool01?l0003ooooo
ooooool0003oooooogoooooo0009ooooo`03onk^k_m4A4Co000000oooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?o0000ooooooooool0C_ooool2o`0000Wo
oooo00Co0000oooooooooooo0000oooooomoooooo`002_ooool00omgMgOo0000ooooo`0<ooooo`03
oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`;o00001_ooool00ol0
003oooooooooo`1>ooooo`;o00002Oooool01?l0003oooooooooool0003oooooogoooooo000Woooo
o`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0C_ooool2o`0000Wooooo00Co0000
oooooooooooo0000oooooomoooooo`009oooool01?l0003oooooooooool00005ooooo`03o`000?oo
oooooooo04kooooo0_l00009ooooo`03o`000?oooooo00000?ooooooP?ooool002Oooooo0ol00006
ooooo`03o`000?oooooooooo05[ooooo0_l0003ooooooh3ooooo000Xooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0F_ooool2o`000?ooooooP?ooool002Wooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`1Jooooo`;o0000oooooon0ooooo`00<?ooool00ol0003ooooo
ooooo`1Jooooo`;o0000oooooon0ooooo`00<?ooool00ol0003oooooooooo`1Jooooo`;o0000oooo
oon0ooooo`00<?ooool00ol0003oooooooooo`1Jooooo`;o0000oooooon0ooooo`00<?ooool3o`00
05[ooooo0_l0003ooooooh3ooooo000`ooooo`03o`000?oooooooooo05[ooooo0_l0003ooooooh3o
oooo000`ooooo`03o`000?oooooooooo05[ooooo0_l0003ooooooh3ooooo000`ooooo`03o`000?oo
oooooooo05[ooooo0_l0003ooooooh3ooooo000`ooooo`03o`000?oooooooooo05[ooooo0_l0003o
oooooh3ooooo000`ooooo`03o`000?oooooooooo05[ooooo0_l0003ooooooh3ooooo000`ooooo`03
o`000?oooooooooo05[ooooo0_l0003ooooooh3ooooo000`ooooo`03o`000?oooooooooo0?oooooo
g?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool3o`000?oooooog?ooool0033ooooo00?o0000ooooooooool0oooo
oooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooo
ooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000
ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03
o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?oo
ool00ol0003oooooooooo`3oooooomcooooo000`ooooo`?o0000oooooooLooooo`00<?ooool00ol0
003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo
00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo003o
oooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo
4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oo
ooooooooool@ooooo`00X?ooool2o`0000Cooooo00?o^[Zjoc8b<_ooool01?ooool2o`0000Kooooo
00?o0000okZj^_ooool0oooooomGooooo`00X?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool2oc8b<_ooooooF?ooool008gooooo0ol00002
ooooo`06oc8b<_l@413oooooooooooo^k^koEEEE0_l000000om4A4Co^[Zjooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00GoV9RHoa0@4?l0003o0000ojVYZ@04ooooo`03o`000?oooooooooo00Co
oooo00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj00_ooooo0_l000000ol@
413oooooooooo`03ooooo`;o8B4Q1?ooool5o`000006ooooooo<c<cok^k^ooooooo^k^koc<c<1?oo
ool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hCooooo`06oa0@4?lb<S;o0000
o`000?l@413oZJVY0_ooool01_o^k^koEEEEo`000?l0003oA4A4okZj^P?ooooo00GoIVIVo`000?l0
003oA4A4olc<c03Xooooo`00S_ooool01Ol0003oooooooooooo<c<co410@00?ooooo00KoEEEEogMg
Moooooook^k^ogMgMol@4104ooooo`03o`000?oooooooooo00;ooooo00Ko0000ojVYZOmEEEGoV9RH
oeEEEOnj^[X3ooooo`03o`000?oooooooooo00Cooooo00?oc<c<o`000?l@41003?ooool01_l@413o
^[Zjonk^k_mgMgOo410@ooooo`Ko00001Oooool00ol0003oooooooooo`04ooooo`;o8B4Q1?ooool0
2onHV9So8B4Qonk^k_ooooooA4A4ooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000oooo
ooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01?ooooo00Ko0000ojVYZOoooooooooookZj
^_l00002ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo410@0_ooool01_mVIVKoMgMgoooooooooooo
QhN7oa0@4>Sooooo002>ooooo`05o`000?oooooooooooeEEEOn7QhL00oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00;ooooo00Ko<S8bonk^k_nHV9SoEEEEomgMgOl@4103ooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool02oooool5o`0000cooooo00?oV9RHob4Q8Oo^
k^h00oooool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooo
oooooooooa0@400Dooooo`05okZj^_n7QhOoIVIVofIVI_l@41000_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0>_ooooo002>ooooo`05o`000?oooooogMgMo`000?o^k^h00oooool6
o`0000Cooooo00?o0000ooooooooool00_ooool01onj^[[oA4A4olc<c?lQ8B7ooooooa0@4?o<c<`0
0_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00?ooooo1_l00002ooooo`04odA4
A?oMgMgoooooo`0000kooooo00WoV9RHob4Q8Oo^k^koooooonk^k_mEEEGogMgMoeEEEOo^k^h01_oo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000004oooool01_lb<S;o8B4Q
ogMgMomgMgOoQhN7onk^kP;ooooo1_l00002ooooo`03o`000?oooooooooo0>_ooooo002>ooooo`?o
000000?o410@oiRHV?ooool00_ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<PCooooo00?o0000
ooooooooool00_ooool01oo^k^ko0000ooooool0003oooooofIVI_n7QhL00_ooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo00_ooooo00CogMgMoeEEEOoooooo00003oooool02?mgMgOo
IVIVooooooo<c<cok^k^ooooooo^k^koc<c<1_ooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000004oooool01_l0003o^[Zjooooooo^k^koMgMgo`0000;ooooo00KoEEEEohN7
Qoo^k^koooooohN7Qolb<S82ooooo`06ofIVI_mgMgOooooooooooon7QhOo0000j?ooool008kooooo
00Go0000ooooooooooooc<c<o`000003ooooo`06onk^k_mEEEGo0000o`000?m4A4Cok^k^1?ooool0
0ol0003oooooooooo`02ooooo`04ofIVI_nHV9Sooooooc8b<P;o^[Zj00Co0000oooooooooooo0000
4oooool00ol@413o0000o`000003o`0000_ooooo00?oMgMgolc<c?l000004?ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4007ooooo`?o
00000_ooool3o`0000Cooooo00KoZJVYob4Q8Ol0003o0000oc8b<_l00002ooooo`06onk^k_mEEEGo
0000o`000?m4A4Cok^k^0_ooool01_o^k^koIVIVo`000?l0003oA4A4o`000>Sooooo002>ooooo`05
o`000?ooooooooooolc<c?l000003Oooool00ol0003oooooooooo`05ooooo`03ofIVI_n7QhOooooo
00?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0<ooooo`03onk^k_m4A4Co0000
00cooooo00Go0000okZj^_ooooooV9RHoa0@400<ooooo`03o`000?oooooooooo00;ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0oooo
ool2ooooo`00SOooool4o`000003oa0@4?nYZJWooooo00cooooo0_l00006ooooo`03ojVYZOm4A4Co
oooo00;ooooo0_l0000Eooooo`03o`000?oooooooooo00gooooo00?oMgMgo`000?ooool02oooool0
1OnHV9So410@o`000?lQ8B7oc<c<00[ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00;ooooo1?l00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
ooooool2ooooo`00ooooool6ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0oooo
ool2ooooo`00ooooool6ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0ooooool2
ooooo`00ooooool5ooooo`;o00000oooool2o`000?oooooo1?ooool00?ooooooooooool@ooooo`00
oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooo
oa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003o
oooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo
4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oo
ooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@
ooooo`00oooooooooooooa3ooooo0000\
\>"],
  ImageRangeCache->{{{0, 525.688}, {324.5, 0}} -> {-2.58312*^-7, -6.34248*^6, \
6.65005*^-9, 53093.5}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0.309017 5.42214e-08 [
[.32684 .29652 -16.5 -12.5 ]
[.32684 .29652 16.5 0 ]
[.54329 .29652 -16.5 -12.5 ]
[.54329 .29652 16.5 0 ]
[.75974 .29652 -22.5 -12.5 ]
[.75974 .29652 22.5 0 ]
[.97619 .29652 -16.5 -12.5 ]
[.97619 .29652 16.5 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 64 6 ]
[.09789 .09213 -34.5 -6.25 ]
[.09789 .09213 0 6.25 ]
[.09789 .20057 -34.5 -6.25 ]
[.09789 .20057 0 6.25 ]
[.09789 .41746 -28.5 -6.25 ]
[.09789 .41746 0 6.25 ]
[.09789 .5259 -28.5 -6.25 ]
[.09789 .5259 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -62.8125 0 ]
[.5 .63053 62.8125 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 .30902 m
.32684 .31527 L
s
gsave
.32684 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 .30902 m
.54329 .31527 L
s
gsave
.54329 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 .30902 m
.75974 .31527 L
s
gsave
.75974 .29652 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 .30902 m
.15368 .31277 L
s
.19697 .30902 m
.19697 .31277 L
s
.24026 .30902 m
.24026 .31277 L
s
.28355 .30902 m
.28355 .31277 L
s
.37013 .30902 m
.37013 .31277 L
s
.41342 .30902 m
.41342 .31277 L
s
.45671 .30902 m
.45671 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.58658 .30902 m
.58658 .31277 L
s
.62987 .30902 m
.62987 .31277 L
s
.67316 .30902 m
.67316 .31277 L
s
.71645 .30902 m
.71645 .31277 L
s
.80303 .30902 m
.80303 .31277 L
s
.84632 .30902 m
.84632 .31277 L
s
.88961 .30902 m
.88961 .31277 L
s
.9329 .30902 m
.9329 .31277 L
s
.0671 .30902 m
.0671 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09213 m
.11664 .09213 L
s
gsave
.09789 .09213 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .20057 m
.11664 .20057 L
s
gsave
.09789 .20057 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .41746 m
.11664 .41746 L
s
gsave
.09789 .41746 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .5259 m
.11664 .5259 L
s
gsave
.09789 .5259 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.11039 .11924 m
.11414 .11924 L
s
.11039 .14635 m
.11414 .14635 L
s
.11039 .17346 m
.11414 .17346 L
s
.11039 .22768 m
.11414 .22768 L
s
.11039 .2548 m
.11414 .2548 L
s
.11039 .28191 m
.11414 .28191 L
s
.11039 .33613 m
.11414 .33613 L
s
.11039 .36324 m
.11414 .36324 L
s
.11039 .39035 m
.11414 .39035 L
s
.11039 .44457 m
.11414 .44457 L
s
.11039 .47168 m
.11414 .47168 L
s
.11039 .49879 m
.11414 .49879 L
s
.11039 .06502 m
.11414 .06502 L
s
.11039 .03791 m
.11414 .03791 L
s
.11039 .0108 m
.11414 .0108 L
s
.11039 .55301 m
.11414 .55301 L
s
.11039 .58012 m
.11414 .58012 L
s
.11039 .60723 m
.11414 .60723 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -123.812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.812 moveto
(@) show
81.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.812 moveto
(D) show
93.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.4) show
135.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
141.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
153.000 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
157.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
166.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
184.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02453 .30902 L
.02532 .30902 L
.02691 .30902 L
.02776 .30902 L
.02866 .30902 L
.03029 .30902 L
.032 .30902 L
.03362 .30902 L
.03522 .30902 L
.0367 .30902 L
.03821 .30902 L
.03986 .30902 L
.04155 .30902 L
.0431 .30902 L
.04621 .30902 L
.04939 .30902 L
.05246 .30902 L
.05417 .30902 L
.05498 .30902 L
.05572 .30902 L
.0561 .30902 L
.0565 .30902 L
.05671 .30902 L
.05681 .30902 L
.0569 .30902 L
.05695 .30902 L
.05701 .30902 L
.05711 .30902 L
.05717 .30902 L
.05723 .30902 L
.05728 .30902 L
.05734 .30902 L
.05744 .30902 L
.05754 .30902 L
.05762 .30902 L
.05772 .30902 L
.05793 .30902 L
.05813 .30902 L
.05848 .30902 L
.05868 .30902 L
.05886 .30902 L
.05925 .30902 L
.05966 .30902 L
.0604 .30902 L
.0612 .30902 L
.06207 .30902 L
.06289 .30902 L
.06363 .30902 L
.0645 .30902 L
Mistroke
.06531 .30902 L
.06684 .30902 L
.0685 .30902 L
.07015 .30902 L
.07165 .30902 L
.0732 .30902 L
.07487 .30902 L
.07816 .30902 L
.08134 .30902 L
.08439 .30902 L
.08609 .30902 L
.08764 .30902 L
.08841 .30902 L
.08884 .30902 L
.08905 .30902 L
.08924 .30902 L
.08941 .30902 L
.0895 .30902 L
.0896 .30902 L
.08969 .30902 L
.0898 .30902 L
.08989 .30902 L
.08998 .30902 L
.09008 .30902 L
.09018 .30902 L
.09027 .30902 L
.09036 .30902 L
.09046 .30902 L
.09057 .30902 L
.09077 .30902 L
.09097 .30902 L
.09116 .30902 L
.09152 .30902 L
.09191 .30902 L
.09234 .30902 L
.0931 .30902 L
.09381 .30902 L
.09458 .30902 L
.09531 .30902 L
.09611 .30902 L
.09696 .30902 L
.09858 .30902 L
.10006 .30902 L
.10165 .30902 L
.10312 .30902 L
.10625 .30902 L
.10958 .30902 L
.11279 .30902 L
.11425 .30902 L
.11509 .30902 L
Mistroke
.11587 .30902 L
.11626 .30902 L
.11664 .30902 L
.11684 .30902 L
.11707 .30902 L
.11727 .30902 L
.11737 .30902 L
.11746 .30902 L
.11757 .30902 L
.11763 .30902 L
.11768 .30902 L
.11778 .30902 L
.11784 .30902 L
.11789 .30902 L
.11799 .30902 L
.11808 .30902 L
.11818 .30902 L
.11828 .30902 L
.1185 .30902 L
.1187 .30902 L
.11892 .30902 L
.11915 .30902 L
.11954 .30902 L
.11991 .30902 L
.12072 .30902 L
.12143 .30902 L
.12218 .30902 L
.12295 .30902 L
.12377 .30902 L
.12524 .30902 L
.12696 .30902 L
.12858 .30901 L
.13167 .30901 L
.13495 .30901 L
.13812 .309 L
.13893 .309 L
.13971 .309 L
.14046 .309 L
.14116 .309 L
.14152 .309 L
.14171 .309 L
.14191 .309 L
.14202 .309 L
.14213 .309 L
.14223 .309 L
.14228 .309 L
.14233 .309 L
.14243 .309 L
.14252 .309 L
.14262 .309 L
Mistroke
.14272 .309 L
.14283 .309 L
.14288 .309 L
.14294 .309 L
.14313 .309 L
.14325 .309 L
.14337 .309 L
.14358 .309 L
.14401 .309 L
.1444 .309 L
.14478 .309 L
.14519 .309 L
.14592 .309 L
.14679 .309 L
.14759 .30901 L
.14913 .30901 L
.1508 .30903 L
.1524 .30904 L
.15409 .30906 L
.15714 .3091 L
.16038 .30915 L
.16188 .30917 L
.16266 .30918 L
.1635 .30918 L
.16392 .30919 L
.16416 .30919 L
.16439 .30919 L
.16449 .30919 L
.16459 .30919 L
.16468 .30919 L
.16478 .30919 L
.16489 .30919 L
.16499 .30919 L
.16505 .30919 L
.1651 .30919 L
.16521 .30919 L
.1653 .30919 L
.1654 .30919 L
.16551 .30919 L
.16561 .30919 L
.16579 .30919 L
.16598 .30919 L
.16642 .30919 L
.16682 .30918 L
.16721 .30918 L
.16761 .30917 L
.16835 .30916 L
.16922 .30914 L
.17001 .30911 L
.17156 .30905 L
Mistroke
.17323 .30896 L
.17653 .3087 L
.1797 .30841 L
.1813 .30826 L
.18275 .30815 L
.1835 .3081 L
.18432 .30807 L
.18454 .30806 L
.18477 .30805 L
.18498 .30804 L
.18518 .30804 L
.18537 .30804 L
.18547 .30804 L
.18557 .30804 L
.18567 .30803 L
.18573 .30803 L
.18578 .30803 L
.18583 .30803 L
.18588 .30803 L
.18594 .30803 L
.186 .30803 L
.18609 .30804 L
.18619 .30804 L
.18628 .30804 L
.18637 .30804 L
.18658 .30804 L
.18678 .30805 L
.18718 .30806 L
.18761 .30808 L
.18798 .30811 L
.18838 .30814 L
.18909 .30821 L
.18984 .30831 L
.19065 .30845 L
.19212 .30877 L
.19372 .30923 L
.19541 .30983 L
.19847 .3111 L
.20017 .31181 L
.20172 .31238 L
.20249 .31261 L
.2029 .31272 L
.20333 .31282 L
.20371 .31289 L
.20412 .31295 L
.2043 .31297 L
.2045 .31299 L
.20468 .31301 L
.20485 .31302 L
.20496 .31302 L
Mistroke
.20505 .31303 L
.20514 .31303 L
.20523 .31303 L
.20534 .31303 L
.20539 .31303 L
.20545 .31302 L
.20555 .31302 L
.20564 .31302 L
.20583 .31301 L
.206 .31299 L
.20619 .31297 L
.20638 .31294 L
.20679 .31286 L
.20717 .31277 L
.20804 .31247 L
.20881 .3121 L
.20954 .31166 L
.21119 .31032 L
.21281 .30858 L
.2143 .30666 L
.21748 .30205 L
.21908 .29984 L
.22054 .29815 L
.22135 .29743 L
.22172 .29716 L
.22211 .29692 L
.22231 .29682 L
.22253 .29673 L
.22274 .29666 L
.22292 .2966 L
.22302 .29658 L
.22314 .29656 L
.2232 .29655 L
.22326 .29655 L
.22331 .29654 L
.22337 .29654 L
.22343 .29653 L
.22349 .29653 L
.22354 .29653 L
.22359 .29653 L
.22369 .29654 L
.2238 .29655 L
.22389 .29656 L
.224 .29658 L
.22419 .29663 L
.22438 .2967 L
.22456 .29677 L
.22495 .297 L
.22538 .29732 L
.22608 .29804 L
Mistroke
.22685 .29913 L
.22766 .30062 L
.2284 .30227 L
.23008 .30697 L
.23327 .31875 L
.23633 .33075 L
.23791 .33573 L
.23879 .33782 L
.23917 .33852 L
.23959 .33915 L
.23998 .33958 L
.24019 .33975 L
.2403 .33982 L
.24039 .33987 L
.24048 .33991 L
.24058 .33994 L
.24067 .33996 L
.24075 .33997 L
.24084 .33998 L
.24094 .33997 L
.24104 .33995 L
.24113 .33992 L
.24123 .33989 L
.24134 .33983 L
.24155 .33968 L
.24175 .33949 L
.24194 .33927 L
.24236 .33862 L
.2428 .33768 L
.24362 .3353 L
.24452 .33174 L
.24613 .32277 L
.24773 .31114 L
.24941 .29667 L
.25245 .2695 L
.25332 .26262 L
.25414 .25689 L
.25495 .25225 L
.25534 .25039 L
.25569 .24896 L
.25604 .24779 L
.25641 .24682 L
.25662 .24642 L
.25681 .24613 L
.2569 .24603 L
.25699 .24594 L
.25708 .24587 L
.25718 .24582 L
.25728 .24579 L
.25734 .24579 L
Mistroke
.25739 .24579 L
.25749 .24582 L
.25759 .24587 L
.25768 .24593 L
.25777 .24601 L
.25796 .24627 L
.25818 .24666 L
.25837 .24711 L
.2588 .2485 L
.25919 .25013 L
.25959 .25229 L
.26032 .25729 L
.2612 .26507 L
.26199 .27377 L
.2652 .32158 L
.26829 .37402 L
.26989 .39664 L
.27069 .40554 L
.27114 .40964 L
.27158 .41284 L
.27197 .41512 L
.27217 .41608 L
.27239 .4169 L
.2726 .41748 L
.27269 .41769 L
.27278 .41785 L
.27287 .41798 L
.27296 .41807 L
.27305 .41812 L
.27314 .41814 L
.27324 .41812 L
.27334 .41805 L
.27339 .418 L
.27345 .41792 L
.27355 .41775 L
.27365 .41754 L
.27375 .41728 L
.27394 .41667 L
.27415 .41576 L
.27436 .41471 L
.27482 .41159 L
.27521 .40808 L
.27565 .40339 L
.27644 .39258 L
.27793 .365 L
.28119 .28082 L
.28433 .19692 L
.28515 .17935 L
.28605 .16398 L
.28646 .15839 L
Mistroke
.28689 .15358 L
.28726 .15043 L
.28747 .14904 L
.28767 .14802 L
.28777 .14759 L
.28788 .14722 L
.28797 .14697 L
.28807 .14675 L
.28813 .14667 L
.28818 .14661 L
.28823 .14657 L
.28829 .14655 L
.2884 .14657 L
.28845 .14662 L
.28851 .14669 L
.28861 .14687 L
.28871 .14712 L
.28889 .14778 L
.28909 .14876 L
.2893 .15014 L
.28968 .15341 L
.29008 .15802 L
.29079 .16919 L
.29155 .18496 L
.29236 .2061 L
.29383 .25368 L
.29714 .38387 L
.2988 .44503 L
.2996 .4702 L
.30033 .48935 L
.3007 .4975 L
.3011 .50506 L
.30144 .51049 L
.30182 .51521 L
.30201 .51712 L
.30222 .51877 L
.30234 .5195 L
.30244 .52005 L
.30255 .5205 L
.30265 .52082 L
.30274 .52103 L
.30283 .52116 L
.30293 .5212 L
.30298 .52118 L
.30304 .52114 L
.30313 .52098 L
.30321 .52077 L
.30331 .52045 L
.3034 .52002 L
.30361 .51878 L
Mistroke
.30381 .51722 L
.30417 .51324 L
.30457 .50745 L
.30499 .49943 L
.30576 .48056 L
.30647 .45846 L
.30963 .31851 L
.31268 .16845 L
.31424 .10871 L
.31469 .09544 L
.31512 .08477 L
.3155 .07693 L
.3157 .07343 L
.31592 .07019 L
.31613 .06762 L
.31632 .06572 L
.3165 .06431 L
.31659 .06376 L
.31669 .06327 L
.31675 .06306 L
.3168 .06289 L
.3169 .06267 L
.317 .06257 L
.31706 .06257 L
.31712 .06261 L
.31721 .06276 L
.31731 .06305 L
.31742 .06349 L
.31752 .06403 L
.31771 .06542 L
.31789 .06716 L
.31823 .07153 L
.31859 .07783 L
.31899 .08656 L
.31982 .11054 L
.32057 .13859 L
.32226 .21906 L
.32547 .40168 L
.32695 .47614 L
.32779 .5106 L
.32857 .53611 L
.32897 .5463 L
.32934 .55411 L
.32955 .55764 L
.32978 .56081 L
.32998 .56311 L
.33017 .56471 L
.33027 .56534 L
.33037 .56588 L
.33047 .56624 L
Mistroke
.33056 .56646 L
.33066 .56656 L
.33072 .56656 L
.33077 .56652 L
.33083 .56643 L
.33088 .56632 L
.33094 .56614 L
.33099 .56593 L
.3311 .5654 L
.33121 .56468 L
.33141 .56294 L
.33163 .56046 L
.33186 .557 L
.33228 .54904 L
.33268 .53937 L
.33342 .51595 L
.3351 .4418 L
.33817 .26501 L
.33989 .17158 L
.3407 .1349 L
.34144 .10706 L
.34222 .08487 L
.34263 .07634 L
.34284 .07286 L
.34306 .06979 L
.34326 .06766 L
.34344 .06619 L
.34353 .06565 L
.34362 .06517 L
.34371 .06484 L
.34379 .06463 L
.34388 .0645 L
.34397 .0645 L
.34407 .06462 L
.34418 .06491 L
.34423 .06511 L
.34429 .06537 L
.34439 .06597 L
.34459 .06749 L
.34479 .06965 L
.34501 .07264 L
.34541 .07972 L
.34616 .0985 L
.34704 .12875 L
.34785 .16333 L
.35102 .33248 L
.35261 .41483 L
.35406 .47416 L
.35445 .48634 L
.35487 .49767 L
Mistroke
.35523 .50578 L
.35563 .51284 L
.35585 .51584 L
.35605 .5181 L
.35627 .5199 L
.35639 .52064 L
.3565 .52115 L
.3566 .52147 L
.35669 .52165 L
.35679 .52173 L
.35689 .52167 L
.35695 .52158 L
.357 .52145 L
.35711 .5211 L
.35721 .52062 L
.35731 .52005 L
.3575 .51853 L
.35768 .51671 L
.35808 .51117 L
.35846 .50431 L
.35881 .49632 L
.3596 .47365 L
.36047 .44239 L
.36373 .29217 L
.36524 .22565 L
.36604 .19623 L
.36688 .17091 L
.3673 .16059 L
.36777 .15144 L
.36798 .14816 L
.3682 .14517 L
.36841 .14284 L
.3686 .14112 L
.36881 .1397 L
.36892 .13915 L
.36897 .13892 L
.36903 .13871 L
.36913 .13845 L
.36923 .13831 L
.36928 .13827 L
.36934 .13827 L
.36944 .13836 L
.36954 .13854 L
.36964 .13884 L
.36973 .13921 L
.36981 .13963 L
.37002 .141 L
.37022 .1427 L
.37059 .14703 L
.371 .15338 L
Mistroke
.37183 .17091 L
.37331 .21518 L
.37655 .33616 L
.37804 .38478 L
.37889 .4063 L
.37967 .42139 L
.38006 .42705 L
.38049 .43175 L
.38071 .43349 L
.38082 .43424 L
.38094 .4349 L
.38105 .43538 L
.38117 .43578 L
.38127 .43605 L
.38137 .43622 L
.38147 .4363 L
.38153 .4363 L
.38158 .43628 L
.38168 .43618 L
.38178 .43599 L
.38187 .43575 L
.38195 .43545 L
.38215 .43455 L
.38236 .43323 L
.38255 .4317 L
.38298 .4272 L
.38337 .42205 L
.38377 .41544 L
.38451 .40095 L
.38617 .35898 L
.38777 .31346 L
.38951 .26822 L
.39032 .25091 L
.39118 .23644 L
.39154 .23176 L
.39192 .22762 L
.39214 .22566 L
.39234 .22414 L
.39252 .22296 L
.39273 .22192 L
.39282 .22153 L
.39292 .22117 L
.39301 .22092 L
.39311 .2207 L
.39322 .22053 L
.39327 .22047 L
.39332 .22044 L
.39342 .22042 L
.39352 .22046 L
.39362 .22055 L
Mistroke
.39372 .22072 L
.39382 .22094 L
.39391 .2212 L
.39408 .22182 L
.39426 .22267 L
.39467 .2253 L
.39505 .22862 L
.39592 .23891 L
.39755 .2659 L
.39904 .29504 L
.4007 .32637 L
.4015 .33944 L
.40223 .34941 L
.4026 .35366 L
.403 .35763 L
.40334 .3605 L
.40372 .36304 L
.40412 .36505 L
.40434 .36583 L
.40444 .36613 L
.40454 .36637 L
.40464 .36655 L
.40474 .3667 L
.40483 .3668 L
.40491 .36686 L
.405 .36689 L
.4051 .36688 L
.4052 .36682 L
.4053 .36672 L
.4054 .36659 L
.4055 .36641 L
.40568 .36597 L
.4059 .36527 L
.40609 .36448 L
.40652 .36223 L
.40693 .3595 L
.40841 .34533 L
.4115 .30647 L
.41307 .28935 L
.41396 .28202 L
.41439 .27926 L
.41479 .27712 L
.41518 .27554 L
.41538 .27488 L
.41559 .27432 L
.41577 .27395 L
.41587 .27379 L
.41597 .27365 L
.41606 .27355 L
.41615 .27348 L
Mistroke
.41623 .27343 L
.41632 .2734 L
.41642 .2734 L
.41652 .27342 L
.41657 .27344 L
.41662 .27347 L
.41673 .27356 L
.41682 .27366 L
.41692 .27379 L
.4171 .2741 L
.41731 .27457 L
.41751 .27512 L
.41796 .2767 L
.41879 .28079 L
.41959 .28582 L
.42107 .29708 L
.42268 .30977 L
.42414 .31963 L
.42496 .32389 L
.42572 .32689 L
.42614 .32809 L
.42653 .32891 L
.42673 .32923 L
.42696 .32949 L
.42707 .32959 L
.42713 .32963 L
.42719 .32967 L
.42724 .3297 L
.4273 .32972 L
.42741 .32975 L
.4275 .32976 L
.42759 .32975 L
.42769 .32973 L
.4278 .32969 L
.42789 .32964 L
.42797 .32958 L
.42816 .3294 L
.42837 .32913 L
.42856 .32883 L
.42899 .32795 L
.42986 .32546 L
.43068 .32238 L
.43377 .3084 L
.43537 .30237 L
.43617 .30016 L
.43663 .29919 L
.43706 .29849 L
.43746 .29801 L
.43768 .29781 L
.43779 .29774 L
Mistroke
.43789 .29768 L
.43799 .29764 L
.43809 .2976 L
.43819 .29757 L
.43828 .29756 L
.43837 .29755 L
.43848 .29755 L
.43853 .29756 L
.43859 .29757 L
.43869 .29759 L
.43879 .29763 L
.43888 .29767 L
.43909 .29778 L
.43927 .29792 L
.43947 .2981 L
.44017 .29901 L
.44093 .30037 L
.44174 .30217 L
.44321 .30589 L
.44479 .30983 L
.44563 .31161 L
.44652 .31315 L
.44697 .31376 L
.44739 .31423 L
.44776 .31456 L
.44796 .3147 L
.44817 .31482 L
.44837 .31491 L
.44856 .31498 L
.44866 .31501 L
.44876 .31502 L
.44881 .31503 L
.44887 .31504 L
.44897 .31505 L
.44906 .31505 L
.44916 .31505 L
.44926 .31504 L
.44935 .31503 L
.44944 .31501 L
.44952 .315 L
.44971 .31494 L
.44991 .31487 L
.45009 .31478 L
.45049 .31453 L
.45122 .31391 L
.45289 .31194 L
.45455 .30966 L
.45529 .30873 L
.45609 .30782 L
.45682 .30713 L
Mistroke
.45759 .30657 L
.45802 .30634 L
.45841 .30618 L
.4586 .30612 L
.45881 .30606 L
.4589 .30605 L
.459 .30603 L
.45909 .30601 L
.45918 .306 L
.45928 .30599 L
.45933 .30599 L
.45939 .30599 L
.45945 .30598 L
.45951 .30598 L
.45961 .30598 L
.45971 .30599 L
.4598 .30599 L
.4599 .306 L
.46001 .30601 L
.46023 .30605 L
.46043 .30609 L
.4609 .30623 L
.46131 .30639 L
.46168 .30657 L
.46252 .30704 L
.46417 .30816 L
.46571 .30917 L
.46647 .3096 L
.46719 .30993 L
.46759 .31009 L
.46802 .31022 L
.46841 .31032 L
.46877 .31039 L
.46897 .31042 L
.46914 .31044 L
.46924 .31045 L
.46935 .31046 L
.46945 .31047 L
.46955 .31047 L
.46964 .31047 L
.46973 .31048 L
.46983 .31048 L
.46993 .31048 L
.47002 .31047 L
.47011 .31047 L
.47019 .31047 L
.47028 .31046 L
.47049 .31045 L
.47069 .31042 L
.47114 .31036 L
Mistroke
.47155 .31028 L
.47193 .31019 L
.47502 .30922 L
.47658 .30877 L
.47747 .30857 L
.47789 .3085 L
.4783 .30844 L
.47868 .3084 L
.47888 .30838 L
.4791 .30837 L
.47929 .30836 L
.47947 .30835 L
.47956 .30835 L
.47965 .30835 L
.47974 .30834 L
.47982 .30834 L
.47992 .30834 L
.48002 .30834 L
.48011 .30834 L
.4802 .30835 L
.4803 .30835 L
.48042 .30835 L
.48062 .30836 L
.48083 .30837 L
.48106 .30838 L
.48146 .30842 L
.48221 .3085 L
.48302 .30861 L
.48449 .30884 L
.48607 .30906 L
.4869 .30916 L
.48736 .30921 L
.48779 .30924 L
.48821 .30927 L
.48843 .30928 L
.48866 .30929 L
.48885 .3093 L
.48907 .30931 L
.48926 .30931 L
.48944 .30931 L
.48954 .30931 L
.48964 .30932 L
.48974 .30932 L
.48983 .30932 L
.48992 .30932 L
.49 .30932 L
.49009 .30932 L
.49018 .30931 L
.49028 .30931 L
.49038 .30931 L
Mistroke
.49056 .30931 L
.49076 .3093 L
.49097 .3093 L
.4918 .30926 L
.49254 .30922 L
.49422 .30911 L
.49589 .309 L
.49662 .30896 L
.49701 .30894 L
.49743 .30893 L
.49783 .30891 L
.4982 .3089 L
.49838 .3089 L
.49857 .3089 L
.49875 .30889 L
.49892 .30889 L
.49902 .30889 L
.49913 .30889 L
.49922 .30889 L
.49932 .30889 L
.49938 .30889 L
.49943 .30889 L
.49948 .30889 L
.49954 .30889 L
.4996 .30889 L
.49965 .30889 L
.49975 .30889 L
.49984 .30889 L
.49994 .30889 L
.50002 .30889 L
.50011 .30889 L
.50032 .30889 L
.50051 .30889 L
.50089 .3089 L
.5013 .30891 L
.50213 .30893 L
.50361 .30897 L
.50532 .30902 L
.50612 .30904 L
.50687 .30905 L
.50724 .30906 L
.50764 .30906 L
.50805 .30907 L
.50827 .30907 L
.50848 .30907 L
.50857 .30907 L
.50867 .30907 L
.50876 .30907 L
.50886 .30907 L
.50896 .30907 L
Mistroke
.50904 .30907 L
.50913 .30907 L
.50921 .30907 L
.50931 .30907 L
.50941 .30907 L
.5095 .30907 L
.50959 .30907 L
.50969 .30907 L
.5098 .30907 L
.51 .30907 L
.51042 .30907 L
.51082 .30906 L
.51171 .30905 L
.51332 .30903 L
.51495 .30902 L
.51575 .30901 L
.51648 .309 L
.51684 .309 L
.51719 .309 L
.51755 .309 L
.51773 .309 L
.51794 .309 L
.51814 .309 L
.51825 .309 L
.51836 .309 L
.51845 .309 L
.51855 .309 L
.51861 .309 L
.51866 .309 L
.51876 .309 L
.51886 .309 L
.51896 .309 L
.51906 .309 L
.51915 .309 L
.51932 .309 L
.51951 .309 L
.51994 .309 L
.52034 .309 L
.52123 .309 L
.52285 .30901 L
.52365 .30901 L
.5245 .30902 L
.52523 .30902 L
.52603 .30902 L
.52646 .30902 L
.52664 .30902 L
.52685 .30902 L
.52703 .30902 L
.52723 .30902 L
.52734 .30902 L
Mistroke
.52744 .30902 L
.52753 .30903 L
.52763 .30903 L
.52773 .30903 L
.52781 .30903 L
.5279 .30903 L
.52799 .30903 L
.52808 .30903 L
.52817 .30903 L
.52827 .30903 L
.52837 .30903 L
.52855 .30903 L
.52871 .30902 L
.52908 .30902 L
.52949 .30902 L
.52992 .30902 L
.53072 .30902 L
.53221 .30902 L
.53376 .30902 L
.53465 .30902 L
.53505 .30901 L
.53548 .30901 L
.53586 .30901 L
.53606 .30901 L
.53627 .30901 L
.53647 .30901 L
.53665 .30901 L
.53673 .30901 L
.53683 .30901 L
.53692 .30901 L
.537 .30901 L
.53709 .30901 L
.53719 .30901 L
.53729 .30901 L
.53737 .30901 L
.53748 .30901 L
.53759 .30901 L
.53779 .30901 L
.538 .30901 L
.53823 .30901 L
.53863 .30901 L
.53946 .30901 L
.54035 .30902 L
.54197 .30902 L
.5428 .30902 L
.54358 .30902 L
.54438 .30902 L
.54481 .30902 L
.54503 .30902 L
.54527 .30902 L
Mistroke
.54547 .30902 L
.54558 .30902 L
.54569 .30902 L
.5458 .30902 L
.5459 .30902 L
.54599 .30902 L
.54609 .30902 L
.54614 .30902 L
.54619 .30902 L
.54625 .30902 L
.54631 .30902 L
.54641 .30902 L
.54646 .30902 L
.54651 .30902 L
.54662 .30902 L
.54674 .30902 L
.54698 .30902 L
.54719 .30902 L
.54738 .30902 L
.54781 .30902 L
.54859 .30902 L
.55025 .30902 L
.55098 .30902 L
.55179 .30902 L
.5525 .30902 L
.55328 .30902 L
.5537 .30902 L
.55389 .30902 L
.55409 .30902 L
.55428 .30902 L
.55447 .30902 L
.55458 .30902 L
.55467 .30902 L
.55477 .30902 L
.55486 .30902 L
.55495 .30902 L
.55505 .30902 L
.5551 .30902 L
.55515 .30902 L
.55525 .30902 L
.55535 .30902 L
.55545 .30902 L
.55555 .30902 L
.55566 .30902 L
.55586 .30902 L
.55605 .30902 L
.5564 .30902 L
.5572 .30902 L
.55807 .30902 L
.55964 .30902 L
Mistroke
.56047 .30902 L
.56136 .30902 L
.5618 .30902 L
.56222 .30902 L
.56259 .30902 L
.56279 .30902 L
.563 .30902 L
.5632 .30902 L
.56339 .30902 L
.56349 .30902 L
.56358 .30902 L
.56369 .30902 L
.56374 .30902 L
.5638 .30902 L
.56389 .30902 L
.56398 .30902 L
.56408 .30902 L
.56418 .30902 L
.56427 .30902 L
.56435 .30902 L
.56453 .30902 L
.56473 .30902 L
.56491 .30902 L
.56531 .30902 L
.56604 .30902 L
.5677 .30902 L
.5685 .30902 L
.56935 .30902 L
.57016 .30902 L
.57089 .30902 L
.57129 .30902 L
.57165 .30902 L
.57184 .30902 L
.57205 .30902 L
.57216 .30902 L
.57227 .30902 L
.57232 .30902 L
.57238 .30902 L
.57247 .30902 L
.57256 .30902 L
.57265 .30902 L
.57275 .30902 L
.57284 .30902 L
.57293 .30902 L
.57301 .30902 L
.57319 .30902 L
.57338 .30902 L
.57358 .30902 L
.57396 .30902 L
.57479 .30902 L
Mistroke
.57554 .30902 L
.57722 .30902 L
.57797 .30902 L
.57877 .30902 L
.57918 .30902 L
.57964 .30902 L
.57984 .30902 L
.58005 .30902 L
.58023 .30902 L
.58044 .30902 L
.58064 .30902 L
.58076 .30902 L
.58086 .30902 L
.58096 .30902 L
.58105 .30902 L
.58115 .30902 L
.58125 .30902 L
.58136 .30902 L
.58142 .30902 L
.58147 .30902 L
.58158 .30902 L
.58168 .30902 L
.5819 .30902 L
.58214 .30902 L
.58255 .30902 L
.58298 .30902 L
.58376 .30902 L
.58534 .30902 L
.5868 .30902 L
.58718 .30902 L
.5876 .30902 L
.58799 .30902 L
.58836 .30902 L
.58856 .30902 L
.58878 .30902 L
.5889 .30902 L
.58901 .30902 L
.58912 .30902 L
.58923 .30902 L
.58932 .30902 L
.58941 .30902 L
.58951 .30902 L
.58962 .30902 L
.58972 .30902 L
.58978 .30902 L
.58983 .30902 L
.58993 .30902 L
.59003 .30902 L
.59012 .30902 L
.59022 .30902 L
Mistroke
.59043 .30902 L
.59079 .30902 L
.59121 .30902 L
.5916 .30902 L
.59307 .30902 L
.59457 .30902 L
.59542 .30902 L
.5962 .30902 L
.5966 .30902 L
.59704 .30902 L
.59726 .30902 L
.59738 .30902 L
.59749 .30902 L
.5976 .30902 L
.59772 .30902 L
.59782 .30902 L
.59792 .30902 L
.59801 .30902 L
.59811 .30902 L
.59821 .30902 L
.59829 .30902 L
.59839 .30902 L
.59849 .30902 L
.5987 .30902 L
.59891 .30902 L
.59913 .30902 L
.59954 .30902 L
.60125 .30902 L
.60203 .30902 L
.60286 .30902 L
.60363 .30902 L
.60403 .30902 L
.60447 .30902 L
.60487 .30902 L
.60523 .30902 L
.60541 .30902 L
.6056 .30902 L
.60578 .30902 L
.60586 .30902 L
.60595 .30902 L
.60605 .30902 L
.60611 .30902 L
.60616 .30902 L
.60625 .30902 L
.60636 .30902 L
.60641 .30902 L
.60647 .30902 L
.60653 .30902 L
.60659 .30902 L
.60669 .30902 L
Mistroke
.6068 .30902 L
.60699 .30902 L
.60718 .30902 L
.6076 .30902 L
.60831 .30902 L
.60909 .30902 L
.61067 .30902 L
.6115 .30902 L
.61196 .30902 L
.61239 .30902 L
.61281 .30902 L
.61302 .30902 L
.61326 .30902 L
.61345 .30902 L
.61366 .30902 L
.61386 .30902 L
.61404 .30902 L
.61414 .30902 L
.61424 .30902 L
.61434 .30902 L
.61443 .30902 L
.61452 .30902 L
.6146 .30902 L
.61469 .30902 L
.61478 .30902 L
.61488 .30902 L
.61498 .30902 L
.61516 .30902 L
.61536 .30902 L
.61557 .30902 L
.61639 .30902 L
.61714 .30902 L
.61882 .30902 L
.61957 .30902 L
.62036 .30902 L
.62077 .30902 L
.62099 .30902 L
.62122 .30902 L
.62144 .30902 L
.62164 .30902 L
.62183 .30902 L
.62203 .30902 L
.62213 .30902 L
.62223 .30902 L
.62233 .30902 L
.62243 .30902 L
.62251 .30902 L
.62261 .30902 L
.6227 .30902 L
.62279 .30902 L
Mistroke
.6229 .30902 L
.623 .30902 L
.62319 .30902 L
.62339 .30902 L
.62361 .30902 L
.62438 .30902 L
.62509 .30902 L
.62671 .30902 L
.62751 .30902 L
.62824 .30902 L
.62895 .30902 L
.6293 .30902 L
.62951 .30902 L
.6297 .30902 L
.6299 .30902 L
.63009 .30902 L
.63019 .30902 L
.63029 .30902 L
.63034 .30902 L
.6304 .30902 L
.63045 .30902 L
.63051 .30902 L
.63061 .30902 L
.6307 .30902 L
.63078 .30902 L
.63087 .30902 L
.63097 .30902 L
.63108 .30902 L
.63127 .30902 L
.63148 .30902 L
.6317 .30902 L
.63209 .30902 L
.63299 .30902 L
.63461 .30902 L
.63537 .30902 L
.63579 .30902 L
.63618 .30902 L
.63655 .30902 L
.63695 .30902 L
.63732 .30902 L
.63766 .30902 L
.63785 .30902 L
.63803 .30902 L
.63812 .30902 L
.63822 .30902 L
.63828 .30902 L
.63833 .30902 L
.63843 .30902 L
.63852 .30902 L
.63863 .30902 L
Mistroke
.63872 .30902 L
.63881 .30902 L
.63898 .30902 L
.63916 .30902 L
.63956 .30902 L
.63994 .30902 L
.64081 .30902 L
.6423 .30902 L
.64309 .30902 L
.64393 .30902 L
.64439 .30902 L
.64481 .30902 L
.64501 .30902 L
.64523 .30902 L
.64544 .30902 L
.64563 .30902 L
.64583 .30902 L
.64593 .30902 L
.64604 .30902 L
.6461 .30902 L
.64616 .30902 L
.64621 .30902 L
.64627 .30902 L
.64637 .30902 L
.64647 .30902 L
.64656 .30902 L
.64666 .30902 L
.64684 .30902 L
.64705 .30902 L
.64724 .30902 L
.64803 .30902 L
.64877 .30902 L
.65043 .30902 L
.65128 .30902 L
.65169 .30902 L
.65208 .30902 L
.65242 .30902 L
.6528 .30902 L
.65298 .30902 L
.65317 .30902 L
.65338 .30902 L
.65357 .30902 L
.65367 .30902 L
.65378 .30902 L
.65383 .30902 L
.65389 .30902 L
.654 .30902 L
.65409 .30902 L
.6542 .30902 L
.65429 .30902 L
Mistroke
.65439 .30902 L
.6545 .30902 L
.65461 .30902 L
.65485 .30902 L
.65528 .30902 L
.65611 .30902 L
.65689 .30902 L
.65836 .30902 L
.6592 .30902 L
.6596 .30902 L
.65998 .30902 L
.66037 .30902 L
.66075 .30902 L
.66095 .30902 L
.66114 .30902 L
.66125 .30902 L
.66135 .30902 L
.66141 .30902 L
.66146 .30902 L
.66152 .30902 L
.66157 .30902 L
.66167 .30902 L
.66178 .30902 L
.66187 .30902 L
.66196 .30902 L
.66207 .30902 L
.66219 .30902 L
.66239 .30902 L
.66261 .30902 L
.66285 .30902 L
.66326 .30902 L
.66485 .30902 L
.6663 .30902 L
.66705 .30902 L
.66743 .30902 L
.66785 .30902 L
.66827 .30902 L
.66851 .30902 L
.66862 .30902 L
.66872 .30902 L
.66881 .30902 L
.66892 .30902 L
.66902 .30902 L
.66908 .30902 L
.66913 .30902 L
.66923 .30902 L
.66932 .30902 L
.66943 .30902 L
.66953 .30902 L
.66962 .30902 L
Mistroke
.66972 .30902 L
.66989 .30902 L
.67011 .30902 L
.6703 .30902 L
.67112 .30902 L
.6726 .30902 L
.67333 .30902 L
.67412 .30902 L
.67457 .30902 L
.67498 .30902 L
.67539 .30902 L
.67559 .30902 L
.67578 .30902 L
.67597 .30902 L
.67615 .30902 L
.67634 .30902 L
.67645 .30902 L
.67656 .30902 L
.67665 .30902 L
.67676 .30902 L
.67686 .30902 L
.67695 .30902 L
.67701 .30902 L
.67706 .30902 L
.67717 .30902 L
.67727 .30902 L
.67738 .30902 L
.67775 .30902 L
.67809 .30902 L
.67886 .30902 L
.68036 .30902 L
.68115 .30902 L
.68199 .30902 L
.68241 .30902 L
.68263 .30902 L
.68287 .30902 L
.68309 .30902 L
.68329 .30902 L
.68349 .30902 L
.68359 .30902 L
.68369 .30902 L
.68378 .30902 L
.68388 .30902 L
.68394 .30902 L
.68399 .30902 L
.68409 .30902 L
.68418 .30902 L
.68427 .30902 L
.68437 .30902 L
.68446 .30902 L
Mistroke
.68452 .30902 L
.68457 .30902 L
.68468 .30902 L
.68487 .30902 L
.6851 .30902 L
.68531 .30902 L
.68616 .30902 L
.68696 .30902 L
.68845 .30902 L
.68924 .30902 L
.68963 .30902 L
.69007 .30902 L
.69044 .30902 L
.69065 .30902 L
.69084 .30902 L
.69101 .30902 L
.69111 .30902 L
.6912 .30902 L
.69129 .30902 L
.69139 .30902 L
.69147 .30902 L
.69155 .30902 L
.69165 .30902 L
.69171 .30902 L
.69176 .30902 L
.69186 .30902 L
.69195 .30902 L
.69206 .30902 L
.69216 .30902 L
.69238 .30902 L
.69277 .30902 L
.69318 .30902 L
.69466 .30902 L
.69548 .30902 L
.69626 .30902 L
.69695 .30902 L
.69735 .30902 L
.69771 .30902 L
.69788 .30902 L
.69807 .30902 L
.69828 .30902 L
.69847 .30902 L
.69857 .30902 L
.69867 .30902 L
.69873 .30902 L
.69878 .30902 L
.69889 .30902 L
.69899 .30902 L
.69909 .30902 L
.69918 .30902 L
Mistroke
.69927 .30902 L
.69948 .30902 L
.6997 .30902 L
.70015 .30902 L
.70095 .30902 L
.70264 .30902 L
.70345 .30902 L
.70419 .30902 L
.70456 .30902 L
.70495 .30902 L
.70518 .30902 L
.70539 .30902 L
.70558 .30902 L
.70569 .30902 L
.70579 .30902 L
.70587 .30902 L
.70597 .30902 L
.70606 .30902 L
.70614 .30902 L
.70623 .30902 L
.70634 .30902 L
.70643 .30902 L
.70652 .30902 L
.7067 .30902 L
.7069 .30902 L
.7073 .30902 L
.70812 .30902 L
.70886 .30902 L
.70973 .30902 L
.71053 .30902 L
.71127 .30902 L
.71168 .30902 L
.71205 .30902 L
.71227 .30902 L
.71247 .30902 L
.71268 .30902 L
.71279 .30902 L
.71291 .30902 L
.71302 .30902 L
.71311 .30902 L
.71316 .30902 L
.71322 .30902 L
.71333 .30902 L
.71343 .30902 L
.71353 .30902 L
.71362 .30902 L
.71372 .30902 L
.7139 .30902 L
.71411 .30902 L
.71452 .30902 L
Mistroke
.71527 .30902 L
.71694 .30902 L
.71775 .30902 L
.71851 .30902 L
.71893 .30902 L
.71916 .30902 L
.71939 .30902 L
.71959 .30902 L
.71969 .30902 L
.71981 .30902 L
.71991 .30902 L
.72001 .30902 L
.7201 .30902 L
.72019 .30902 L
.72029 .30902 L
.72035 .30902 L
.7204 .30902 L
.72049 .30902 L
.7206 .30902 L
.72069 .30902 L
.72077 .30902 L
.72096 .30902 L
.72117 .30902 L
.72136 .30902 L
.72178 .30902 L
.72326 .30902 L
.724 .30902 L
.72479 .30902 L
.7252 .30902 L
.72565 .30902 L
.72607 .30902 L
.72627 .30902 L
.72646 .30902 L
.72665 .30902 L
.72683 .30902 L
.72693 .30902 L
.72703 .30902 L
.72709 .30902 L
.72714 .30902 L
.72724 .30902 L
.72734 .30902 L
.72744 .30902 L
.72754 .30902 L
.7276 .30902 L
.72765 .30902 L
.72775 .30902 L
.72781 .30902 L
.72787 .30902 L
.72808 .30902 L
.72827 .30902 L
Mistroke
.72845 .30902 L
.7288 .30902 L
.72956 .30902 L
.73104 .30902 L
.73188 .30902 L
.73229 .30902 L
.73266 .30902 L
.73306 .30902 L
.73343 .30902 L
.73364 .30902 L
.73383 .30902 L
.73393 .30902 L
.73404 .30902 L
.7341 .30902 L
.73416 .30902 L
.73421 .30902 L
.73426 .30902 L
.73432 .30902 L
.73437 .30902 L
.73447 .30902 L
.73452 .30902 L
.73458 .30902 L
.73464 .30902 L
.73469 .30902 L
.7348 .30902 L
.73491 .30902 L
.73515 .30902 L
.73535 .30902 L
.73556 .30902 L
.73596 .30902 L
.73754 .30902 L
.73838 .30902 L
.73884 .30902 L
.73927 .30902 L
.73968 .30902 L
.74006 .30902 L
.74026 .30902 L
.74048 .30902 L
.7407 .30902 L
.74082 .30902 L
.74093 .30902 L
.74103 .30902 L
.74113 .30902 L
.74123 .30902 L
.74132 .30902 L
.7414 .30902 L
.74149 .30902 L
.74159 .30902 L
.74167 .30902 L
.74178 .30902 L
Mistroke
.74187 .30902 L
.74206 .30902 L
.74247 .30902 L
.74324 .30902 L
.74406 .30902 L
.74483 .30902 L
.74554 .30902 L
.74593 .30902 L
.74636 .30902 L
.7468 .30902 L
.74703 .30902 L
.74726 .30902 L
.74747 .30902 L
.74757 .30902 L
.74766 .30902 L
.74775 .30902 L
.74784 .30902 L
.74794 .30902 L
.74804 .30902 L
.74809 .30902 L
.74815 .30902 L
.74825 .30902 L
.7483 .30902 L
.74835 .30902 L
.74841 .30902 L
.74847 .30902 L
.74858 .30902 L
.74868 .30902 L
.74888 .30902 L
.74925 .30902 L
.74966 .30902 L
.75048 .30902 L
.75196 .30902 L
.75238 .30902 L
.75278 .30902 L
.75314 .30902 L
.75353 .30902 L
.75375 .30902 L
.75394 .30902 L
.75414 .30902 L
.75433 .30902 L
.75455 .30902 L
.75466 .30902 L
.75472 .30902 L
.75478 .30902 L
.75488 .30902 L
.75498 .30902 L
.75504 .30902 L
.7551 .30902 L
.7552 .30902 L
Mistroke
.7553 .30902 L
.7554 .30902 L
.75549 .30902 L
.75557 .30902 L
.75598 .30902 L
.7564 .30902 L
.75681 .30902 L
.75829 .30902 L
.75906 .30902 L
.75948 .30902 L
.75988 .30902 L
.76025 .30902 L
.76044 .30902 L
.76065 .30902 L
.76082 .30902 L
.76101 .30902 L
.76119 .30902 L
.76135 .30902 L
.76145 .30902 L
.76151 .30902 L
.76156 .30902 L
.76165 .30902 L
.76175 .30902 L
.76181 .30902 L
.76186 .30902 L
.76196 .30902 L
.76202 .30902 L
.76207 .30902 L
.76219 .30902 L
.76229 .30902 L
.76239 .30902 L
.76257 .30902 L
.76298 .30902 L
.76447 .30902 L
.76518 .30902 L
.76594 .30902 L
.76638 .30902 L
.76678 .30902 L
.76718 .30902 L
.76756 .30902 L
.76775 .30902 L
.76786 .30902 L
.76796 .30902 L
.76805 .30902 L
.76815 .30902 L
.76824 .30902 L
.76832 .30902 L
.76842 .30902 L
.76852 .30902 L
.76862 .30902 L
Mistroke
.76868 .30902 L
.76873 .30902 L
.76883 .30902 L
.76895 .30902 L
.76915 .30902 L
.76936 .30902 L
.76958 .30902 L
.77003 .30902 L
.77084 .30902 L
.77167 .30902 L
.77253 .30902 L
.77327 .30902 L
.77369 .30902 L
.77407 .30902 L
.77427 .30902 L
.77448 .30902 L
.77458 .30902 L
.77468 .30902 L
.77477 .30902 L
.77486 .30902 L
.77495 .30902 L
.77504 .30902 L
.77512 .30902 L
.7752 .30902 L
.7753 .30902 L
.77538 .30902 L
.77548 .30902 L
.77558 .30902 L
.77577 .30902 L
.77597 .30902 L
.77634 .30902 L
.77718 .30902 L
.77876 .30902 L
.77919 .30902 L
.77965 .30902 L
.78009 .30902 L
.78048 .30902 L
.78068 .30902 L
.78089 .30902 L
.78107 .30902 L
.78126 .30902 L
.78138 .30902 L
.78148 .30902 L
.78153 .30902 L
.78159 .30902 L
.78165 .30902 L
.7817 .30902 L
.78181 .30902 L
.7819 .30902 L
.78196 .30902 L
Mistroke
.78201 .30902 L
.78211 .30902 L
.78221 .30902 L
.7823 .30902 L
.78251 .30902 L
.78292 .30902 L
.78366 .30902 L
.78515 .30902 L
.78556 .30902 L
.786 .30902 L
.78638 .30902 L
.78678 .30902 L
.787 .30902 L
.7872 .30902 L
.7874 .30902 L
.78759 .30902 L
.7878 .30902 L
.78791 .30902 L
.78803 .30902 L
.78809 .30902 L
.78815 .30902 L
.78821 .30902 L
.78827 .30902 L
.78838 .30902 L
.78843 .30902 L
.78849 .30902 L
.78854 .30902 L
.7886 .30902 L
.7887 .30902 L
.7888 .30902 L
.78889 .30902 L
.78932 .30902 L
.7897 .30902 L
.7901 .30902 L
.79171 .30902 L
.79215 .30902 L
.79261 .30902 L
.79302 .30902 L
.79324 .30902 L
.79345 .30902 L
.79365 .30902 L
.79386 .30902 L
.79406 .30902 L
.79424 .30902 L
.79441 .30902 L
.79451 .30902 L
.7946 .30902 L
.7947 .30902 L
.79478 .30902 L
.79489 .30902 L
Mistroke
.79498 .30902 L
.79509 .30902 L
.79518 .30902 L
.79529 .30902 L
.7954 .30902 L
.79579 .30902 L
.79621 .30902 L
.79667 .30902 L
.79823 .30902 L
.79866 .30902 L
.79912 .30902 L
.79956 .30902 L
.79996 .30902 L
.80015 .30902 L
.80036 .30902 L
.80057 .30902 L
.80069 .30902 L
.80081 .30902 L
.8009 .30902 L
.80101 .30902 L
.80111 .30902 L
.80117 .30902 L
.80122 .30902 L
.80132 .30902 L
.80141 .30902 L
.80151 .30902 L
.80161 .30902 L
.8017 .30902 L
.8018 .30902 L
.80199 .30902 L
.80234 .30902 L
.80312 .30902 L
.80399 .30902 L
.80481 .30902 L
.80555 .30902 L
.80597 .30902 L
.80636 .30902 L
.80656 .30902 L
.80677 .30902 L
.80697 .30902 L
.80715 .30902 L
.80732 .30902 L
.80741 .30902 L
.8075 .30902 L
.80759 .30902 L
.80768 .30902 L
.80777 .30902 L
.80787 .30902 L
.80796 .30902 L
.80806 .30902 L
Mistroke
.80817 .30902 L
.80827 .30902 L
.80864 .30902 L
.80904 .30902 L
.80947 .30902 L
.81105 .30902 L
.81149 .30902 L
.81195 .30902 L
.81238 .30902 L
.81278 .30902 L
.81298 .30902 L
.81319 .30902 L
.81337 .30902 L
.81356 .30902 L
.81368 .30902 L
.81378 .30902 L
.81383 .30902 L
.81389 .30902 L
.81395 .30902 L
.814 .30902 L
.81411 .30902 L
.8142 .30902 L
.81426 .30902 L
.81431 .30902 L
.81442 .30902 L
.81451 .30902 L
.8146 .30902 L
.81481 .30902 L
.81522 .30902 L
.81596 .30902 L
.81746 .30902 L
.81787 .30902 L
.81831 .30902 L
.81869 .30902 L
.81909 .30902 L
.81931 .30902 L
.81951 .30902 L
.81971 .30902 L
.8199 .30902 L
.82001 .30902 L
.82007 .30902 L
.82013 .30902 L
.82018 .30902 L
.82023 .30902 L
.82033 .30902 L
.82039 .30902 L
.82045 .30902 L
.82052 .30902 L
.82058 .30902 L
.82063 .30902 L
Mistroke
.82068 .30902 L
.8208 .30902 L
.8209 .30902 L
.82101 .30902 L
.8212 .30902 L
.82163 .30902 L
.82242 .30902 L
.82319 .30902 L
.824 .30902 L
.82469 .30902 L
.82508 .30902 L
.82545 .30902 L
.82565 .30902 L
.82584 .30902 L
.82601 .30902 L
.8262 .30902 L
.82629 .30902 L
.8264 .30902 L
.82645 .30902 L
.82651 .30902 L
.82662 .30902 L
.82672 .30902 L
.82682 .30902 L
.8269 .30902 L
.827 .30902 L
.82711 .30902 L
.82722 .30902 L
.82742 .30902 L
.82787 .30902 L
.82867 .30902 L
.83015 .30902 L
.83056 .30902 L
.83099 .30902 L
.8314 .30902 L
.83177 .30902 L
.83198 .30902 L
.83217 .30902 L
.83238 .30902 L
.83248 .30902 L
.8326 .30902 L
.8327 .30902 L
.83279 .30902 L
.83289 .30902 L
.83294 .30902 L
.833 .30902 L
.83309 .30902 L
.83319 .30902 L
.83329 .30902 L
.83338 .30902 L
.83359 .30902 L
Mistroke
.83379 .30902 L
.83425 .30902 L
.83507 .30902 L
.83586 .30902 L
.83629 .30902 L
.8367 .30902 L
.83709 .30902 L
.8375 .30902 L
.83788 .30902 L
.83823 .30902 L
.83841 .30902 L
.8385 .30902 L
.8386 .30902 L
.83868 .30902 L
.83877 .30902 L
.83886 .30902 L
.83894 .30902 L
.83904 .30902 L
.83913 .30902 L
.83922 .30902 L
.83931 .30902 L
.83941 .30902 L
.83946 .30902 L
.83952 .30902 L
.83971 .30902 L
.83991 .30902 L
.8401 .30902 L
.84052 .30902 L
.84128 .30902 L
.84202 .30902 L
.8428 .30902 L
.84326 .30902 L
.84367 .30902 L
.84386 .30902 L
.84408 .30902 L
.84428 .30902 L
.84447 .30902 L
.84466 .30902 L
.84476 .30902 L
.84486 .30902 L
.84496 .30902 L
.84505 .30902 L
.84514 .30902 L
.84523 .30902 L
.84533 .30902 L
.84539 .30902 L
.84544 .30902 L
.84553 .30902 L
.84563 .30902 L
.84574 .30902 L
Mistroke
.84584 .30902 L
.84607 .30902 L
.8465 .30902 L
.84689 .30902 L
.84776 .30902 L
.84851 .30902 L
.8493 .30902 L
.84971 .30902 L
.84993 .30902 L
.85017 .30902 L
.85039 .30902 L
.85058 .30902 L
.85078 .30902 L
.85097 .30902 L
.85107 .30902 L
.85112 .30902 L
.85118 .30902 L
.85128 .30902 L
.85138 .30902 L
.85147 .30902 L
.85155 .30902 L
.85164 .30902 L
.85174 .30902 L
.85185 .30902 L
.85196 .30902 L
.85217 .30902 L
.85256 .30902 L
.85404 .30902 L
.85486 .30902 L
.85563 .30902 L
.85602 .30902 L
.85644 .30902 L
.85667 .30902 L
.85679 .30902 L
.8569 .30902 L
.857 .30902 L
.8571 .30902 L
.85721 .30902 L
.85727 .30902 L
.85732 .30902 L
.85741 .30902 L
.85751 .30902 L
.85761 .30902 L
.85769 .30902 L
.85779 .30902 L
.8579 .30902 L
.8581 .30902 L
.85831 .30902 L
.85853 .30902 L
.85893 .30902 L
Mistroke
.86041 .30902 L
.86117 .30902 L
.86159 .30902 L
.86198 .30902 L
.86232 .30902 L
.86251 .30902 L
.86269 .30902 L
.86288 .30902 L
.86298 .30902 L
.86308 .30902 L
.86318 .30902 L
.86327 .30902 L
.86335 .30902 L
.86344 .30902 L
.86354 .30902 L
.86365 .30902 L
.86375 .30902 L
.86384 .30902 L
.86393 .30902 L
.86401 .30902 L
.8642 .30902 L
.86462 .30902 L
.86501 .30902 L
.86648 .30902 L
.86727 .30902 L
.86766 .30902 L
.8681 .30902 L
.86847 .30902 L
.86867 .30902 L
.86886 .30902 L
.86904 .30902 L
.86914 .30902 L
.86923 .30902 L
.86931 .30902 L
.8694 .30902 L
.86949 .30902 L
.86958 .30902 L
.86967 .30902 L
.86978 .30902 L
.86987 .30902 L
.86996 .30902 L
.87017 .30902 L
.87037 .30902 L
.8712 .30902 L
.87269 .30902 L
.87347 .30902 L
.87386 .30902 L
.87409 .30902 L
.8743 .30902 L
.87447 .30902 L
Mistroke
.87467 .30902 L
.87487 .30902 L
.87496 .30902 L
.87506 .30902 L
.87516 .30902 L
.87524 .30902 L
.87534 .30902 L
.87543 .30902 L
.87552 .30902 L
.87561 .30902 L
.87569 .30902 L
.87578 .30902 L
.87588 .30902 L
.87598 .30902 L
.8762 .30902 L
.8766 .30902 L
.87735 .30902 L
.87822 .30902 L
.87903 .30902 L
.8794 .30902 L
.87975 .30902 L
.87995 .30902 L
.88016 .30902 L
.88035 .30902 L
.88053 .30902 L
.88075 .30902 L
.88095 .30902 L
.88106 .30902 L
.88116 .30902 L
.88122 .30902 L
.88127 .30902 L
.88134 .30902 L
.88139 .30902 L
.8815 .30902 L
.88159 .30902 L
.88168 .30902 L
.88178 .30902 L
.88188 .30902 L
.88199 .30902 L
.88219 .30902 L
.88258 .30902 L
.88294 .30902 L
.88375 .30902 L
.88446 .30902 L
.88522 .30902 L
.88563 .30902 L
.88601 .30902 L
.88619 .30902 L
.88638 .30902 L
.88657 .30902 L
Mistroke
.88674 .30902 L
.88683 .30902 L
.88694 .30902 L
.88703 .30902 L
.88712 .30902 L
.88723 .30902 L
.88729 .30902 L
.88734 .30902 L
.88744 .30902 L
.88755 .30902 L
.8876 .30902 L
.88766 .30902 L
.88778 .30902 L
.88799 .30902 L
.8884 .30902 L
.89004 .30902 L
.89085 .30902 L
.89122 .30902 L
.89157 .30902 L
.89194 .30902 L
.89213 .30902 L
.89233 .30902 L
.89251 .30902 L
.89267 .30902 L
.89277 .30902 L
.89285 .30902 L
.89295 .30902 L
.89305 .30902 L
.89315 .30902 L
.89324 .30902 L
.89334 .30902 L
.89344 .30902 L
.89353 .30902 L
.89361 .30902 L
.8938 .30902 L
.8942 .30902 L
.89463 .30902 L
.89544 .30902 L
.89622 .30902 L
.89692 .30902 L
.89731 .30902 L
.89767 .30902 L
.89803 .30902 L
.89824 .30902 L
.89843 .30902 L
.89853 .30902 L
.89863 .30902 L
.89872 .30902 L
.89882 .30902 L
.89892 .30902 L
Mistroke
.89898 .30902 L
.89904 .30902 L
.89914 .30902 L
.89924 .30902 L
.89933 .30902 L
.89944 .30902 L
.89966 .30902 L
.90004 .30902 L
.90092 .30902 L
.90172 .30902 L
.90247 .30902 L
.90289 .30902 L
.90311 .30902 L
.90335 .30902 L
.90357 .30902 L
.90377 .30902 L
.90397 .30902 L
.90415 .30902 L
.90434 .30902 L
.90444 .30902 L
.90454 .30902 L
.9046 .30902 L
.90465 .30902 L
.90476 .30902 L
.90486 .30902 L
.90496 .30902 L
.90504 .30902 L
.90513 .30902 L
.90522 .30902 L
.90532 .30902 L
.9057 .30902 L
.90612 .30902 L
.90657 .30902 L
.90737 .30902 L
.90814 .30902 L
.90856 .30902 L
.90896 .30902 L
.90933 .30902 L
.90954 .30902 L
.90973 .30902 L
.90989 .30902 L
.91007 .30902 L
.91016 .30902 L
.91026 .30902 L
.91035 .30902 L
.91043 .30902 L
.91053 .30902 L
.91063 .30902 L
.91072 .30902 L
.91081 .30902 L
Mistroke
.91092 .30902 L
.91103 .30902 L
.91122 .30902 L
.91157 .30902 L
.91196 .30902 L
.91283 .30902 L
.91362 .30902 L
.91401 .30902 L
.91443 .30902 L
.91483 .30902 L
.91519 .30902 L
.91539 .30902 L
.91558 .30902 L
.91579 .30902 L
.9159 .30902 L
.91601 .30902 L
.91606 .30902 L
.91612 .30902 L
.91622 .30902 L
.91628 .30902 L
.91634 .30902 L
.9164 .30902 L
.91645 .30902 L
.9165 .30902 L
.91656 .30902 L
.91667 .30902 L
.91687 .30902 L
.91708 .30902 L
.91729 .30902 L
.91769 .30902 L
.91844 .30902 L
.91924 .30902 L
.91966 .30902 L
.92012 .30902 L
.92055 .30902 L
.92073 .30902 L
.92094 .30902 L
.92112 .30902 L
.92131 .30902 L
.92142 .30902 L
.92152 .30902 L
.92161 .30902 L
.92171 .30902 L
.9218 .30902 L
.92186 .30902 L
.92191 .30902 L
.92201 .30902 L
.92207 .30902 L
.92213 .30902 L
.92222 .30902 L
Mistroke
.92232 .30902 L
.92242 .30902 L
.92251 .30902 L
.92294 .30902 L
.92339 .30902 L
.92417 .30902 L
.925 .30902 L
.92543 .30902 L
.9259 .30902 L
.92611 .30902 L
.92633 .30902 L
.92653 .30902 L
.92673 .30902 L
.92695 .30902 L
.92715 .30902 L
.92726 .30902 L
.92736 .30902 L
.92742 .30902 L
.92748 .30902 L
.92754 .30902 L
.9276 .30902 L
.9277 .30902 L
.9278 .30902 L
.9279 .30902 L
.92799 .30902 L
.9281 .30902 L
.92821 .30902 L
.92842 .30902 L
.92922 .30902 L
.92995 .30902 L
.93068 .30902 L
.93108 .30902 L
.93146 .30902 L
.93167 .30902 L
.93191 .30902 L
.9321 .30902 L
.93232 .30902 L
.93252 .30902 L
.93262 .30902 L
.93273 .30902 L
.93284 .30902 L
.93293 .30902 L
.93302 .30902 L
.93312 .30902 L
.93322 .30902 L
.93327 .30902 L
.93332 .30902 L
.93342 .30902 L
.93352 .30902 L
.93361 .30902 L
Mistroke
.93369 .30902 L
.93388 .30902 L
.93428 .30902 L
.9347 .30902 L
.93617 .30902 L
.93657 .30902 L
.93699 .30902 L
.93723 .30902 L
.93744 .30902 L
.93767 .30902 L
.93787 .30902 L
.93807 .30902 L
.93827 .30902 L
.93838 .30902 L
.93848 .30902 L
.93858 .30902 L
.93865 .30902 L
.9387 .30902 L
.9388 .30902 L
.93889 .30902 L
.939 .30902 L
.93905 .30902 L
.9391 .30902 L
.9392 .30902 L
.9393 .30902 L
.93948 .30902 L
.93988 .30902 L
.94025 .30902 L
.94109 .30902 L
.94196 .30902 L
.94239 .30902 L
.94279 .30902 L
.94317 .30902 L
.94336 .30902 L
.94358 .30902 L
.94379 .30902 L
.94391 .30902 L
.94402 .30902 L
.94412 .30902 L
.94418 .30902 L
.94423 .30902 L
.94433 .30902 L
.94443 .30902 L
.94453 .30902 L
.94462 .30902 L
.94473 .30902 L
.94483 .30902 L
.94501 .30902 L
.94521 .30902 L
.94592 .30902 L
Mistroke
.9468 .30902 L
.94762 .30902 L
.94798 .30902 L
.94837 .30902 L
.94856 .30902 L
.94878 .30902 L
.94897 .30902 L
.94917 .30902 L
.94928 .30902 L
.94938 .30902 L
.94948 .30902 L
.94958 .30902 L
.94967 .30902 L
.94976 .30902 L
.94985 .30902 L
.94995 .30902 L
.95005 .30902 L
.95011 .30902 L
.95016 .30902 L
.95022 .30902 L
.95027 .30902 L
.95039 .30902 L
.95059 .30902 L
.95079 .30902 L
.95151 .30902 L
.9523 .30902 L
.95312 .30902 L
.95352 .30902 L
.95389 .30902 L
.95427 .30902 L
.95447 .30902 L
.95469 .30902 L
.95479 .30902 L
.95491 .30902 L
.955 .30902 L
.95511 .30902 L
.95517 .30902 L
.95523 .30902 L
.95529 .30902 L
.95535 .30902 L
.95546 .30902 L
.95552 .30902 L
.95557 .30902 L
.95567 .30902 L
.95573 .30902 L
.95578 .30902 L
.95597 .30902 L
.95608 .30902 L
.9562 .30902 L
.95641 .30902 L
Mistroke
.9572 .30902 L
.95797 .30902 L
.95869 .30902 L
.95906 .30902 L
.95945 .30902 L
.95968 .30902 L
.95989 .30902 L
.96008 .30902 L
.96019 .30902 L
.96029 .30902 L
.96039 .30902 L
.96049 .30902 L
.9606 .30902 L
.96066 .30902 L
.96072 .30902 L
.96082 .30902 L
.96088 .30902 L
.96094 .30902 L
.961 .30902 L
.96106 .30902 L
.96111 .30902 L
.96117 .30902 L
.96127 .30902 L
.96137 .30902 L
.96159 .30902 L
.96198 .30902 L
.96285 .30902 L
.96367 .30902 L
.96441 .30902 L
.96483 .30902 L
.96522 .30902 L
.96542 .30902 L
.96563 .30902 L
.96573 .30902 L
.96583 .30902 L
.96592 .30902 L
.96601 .30902 L
.96611 .30902 L
.96619 .30902 L
.96628 .30902 L
.96636 .30902 L
.96645 .30902 L
.96654 .30902 L
.96663 .30902 L
.96673 .30902 L
.96683 .30902 L
.96692 .30902 L
.96713 .30902 L
.9675 .30902 L
.96834 .30902 L
Mistroke
.96908 .30902 L
.96986 .30902 L
.97032 .30902 L
.97073 .30902 L
.97092 .30902 L
.97114 .30902 L
.97124 .30902 L
.97134 .30902 L
.97144 .30902 L
.97153 .30902 L
.97162 .30902 L
.97168 .30902 L
.97173 .30902 L
.97182 .30902 L
.97192 .30902 L
.97201 .30902 L
.97211 .30902 L
.9722 .30902 L
.97229 .30902 L
.97248 .30902 L
.97268 .30902 L
.9731 .30902 L
.97457 .30902 L
.97498 .30902 L
.97536 .30902 L
.97557 .30902 L
.97579 .30902 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{421.375, 260.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008>0001AB000`400?l00000o`00003ooooooooo
oooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo
003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooo
oooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool0
0?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooooooo
ool@ooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooo
ooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo0ol0003o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0
003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo
00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`
ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLoooo
o`00<?ooool3o`000?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?oo
ool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0
033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomco
oooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooo
oooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`3ooooooh;o
oooo000`ooooo`?o0000Eoooool00ol0003oooooooooo`08ooooo`;o0000oooooomhooooo`00<?oo
ool00ol0003oooooooooo`1Fooooo`;o00002_ooool2o`000?ooooooN?ooool0033ooooo00?o0000
ooooooooool0E_ooool2o`0000[ooooo0_l0003oooooogSooooo000`ooooo`03o`000?oooooooooo
05Kooooo0_l0000:ooooo`;o0000oooooomhooooo`00<?ooool00ol0003oooooooooo`1Fooooo`;o
00002_ooool2o`000?ooooooN?ooool0033ooooo00?o0000ooooooooool0E_ooool2o`0000[ooooo
0_l0003oooooogSooooo000`ooooo`03o`000?oooooooooo05Kooooo0_l0000:ooooo`;o0000oooo
oomhooooo`004?ooool2onk^kP?ooooo0_o^k^hIooooo`03o`000?oooooooooo05Kooooo0_l0000:
ooooo`;o0000oooooomhooooo`002oooool2o`00000:oa0@4?ooooooooooonk^k_mEEEGok^k^oooo
ooo^k^koEEEEonk^kP?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^2_oo
ool00ol0003oooooooooo`1Fooooo`;o00002_ooool2o`000?ooooooN?ooool000cooooo00?o0000
ooooooooool00_ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00[ooooo00?o0000ooooooooool0E_ooool00ol0003ooooo
o`000009ooooo`;o0000oooooomhooooo`0000?oooooo`000?l000001?l00002ooooo`Go00001?oo
ool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooo
oa0@400:ooooo`03o`000?oooooooooo05Kooooo00?o0000ooooool000002Oooool2o`000?oooooo
N?ooool000Wooooo00CoA4A4omgMgOoooooo00001?ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Ko
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000[ooooo00?o0000oooo
ooooool0E_ooool00ol0003oooooo`000009ooooo`;o0000oooooomhooooo`002Oooool01?oMgMgo
EEEEooooool00003ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000:ooooo`Co0000EOooool00ol0003ooooo
o`000009ooooo`;o0000oooooomhooooo`002_ooool00omgMgOoc<c<o`000003ooooo`;ok^k^0ooo
ool2onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00[ooooo
00?o0000ooooooooool0E_ooool00ol0003oooooo`000009ooooo`;o0000oooooomhooooo`002_oo
ool00oo^k^koA4A4o`00000?ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`;o00001Oooool00ol0003oooooooooo`1Fooooo`03o`000?oooooo000000Wooooo
0_l0003oooooogSooooo000;ooooo`03ogMgMol0003ooooo00cooooo00?oEEEEofIVI_l000001?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`1Fooooo`03o`000?oooooo000000Sooooo00?o0000ooooool00000oooooomhooooo`00
:?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo05Kooooo00?o0000ooooool0
00002?ooool00ol0003oooooo`00003oooooogSooooo000Xooooo`?o00001Oooool00ol0003ooooo
ooooo`1Fooooo`03o`000?oooooo000000Sooooo00?o0000ooooool00000oooooomhooooo`00:Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05Kooooo00?o0000ooooool000002?oo
ool00ol0003oooooo`00003oooooogSooooo000Zooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0E_ooool00ol0003oooooo`000008ooooo`03o`000?oooooo00000?ooooooN?ooool0
033ooooo00?o0000ooooooooool0E_ooool00ol0003oooooo`000008ooooo`03o`000?oooooo0000
0?ooooooN?ooool0033ooooo00?o0000ooooooooool0E_ooool00ol0003oooooo`000008ooooo`03
o`000?oooooo00000?ooooooN?ooool0033ooooo00?o0000ooooooooool0E_ooool00ol0003ooooo
o`000008ooooo`04o`000?ooooooooooo`000?ooooooMoooool0033ooooo00?o0000ooooooooool0
E_ooool00ol0003oooooo`000008ooooo`04o`000?ooooooooooo`000?ooooooMoooool0033ooooo
0ol0001Fooooo`03o`000?oooooo000000Sooooo00Co0000oooooooooooo0000oooooomgooooo`00
<?ooool00ol0003oooooooooo`1Fooooo`03o`000?oooooo000000Sooooo00Co0000oooooooooooo
0000oooooomgooooo`00<?ooool00ol0003oooooooooo`1Fooooo`03o`000?oooooo000000Sooooo
00Co0000oooooooooooo0000oooooomgooooo`00<?ooool00ol0003oooooooooo`1Fooooo`03o`00
0?oooooo000000Sooooo00Co0000oooooooooooo0000oooooomgooooo`00<?ooool00ol0003ooooo
ooooo`1Fooooo`03o`000?oooooo000000Sooooo00Co0000oooooooooooo0000oooooomgooooo`00
<?ooool00ol0003oooooooooo`1Fooooo`03o`000?oooooo000000Sooooo00Co0000oooooooooooo
0000oooooomgooooo`00<?ooool00ol0003oooooooooo`1Fooooo`03o`000?oooooo000000Sooooo
00Co0000oooooooooooo0000oooooomgooooo`00<?ooool00ol0003oooooooooo`1Fooooo`03o`00
0?oooooo000000Sooooo00Co0000oooooooooooo0000oooooomgooooo`00<?ooool00ol0003ooooo
ooooo`1Fooooo`03o`000?oooooo000000Sooooo00Co0000oooooooooooo00002?ooool2o`000?oo
ooooKOooool0033ooooo00?o0000ooooooooool0EOooool01?l0003oooooooooool00008ooooo`04
o`000?ooooooooooo`0000Sooooo0_l0003oooooofgooooo000`ooooo`03o`000?oooooooooo05Go
oooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00008ooooo`;o0000oooooom]
ooooo`00<?ooool00ol0003oooooooooo`1Eooooo`04o`000?ooooooooooo`0000Sooooo00Co0000
oooooooooooo00002?ooool2o`000?ooooooKOooool0033ooooo0ol0001:ooooo`;o00002Oooool0
1?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo0_l0003oooooofgooooo
000`ooooo`03o`000?oooooooooo04[ooooo0_l00009ooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00002?ooool2o`000?ooooooKOooool0033ooooo00?o0000ooooooooool0
B_ooool2o`0000Wooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00008oooo
o`;o0000oooooom]ooooo`00<?ooool00ol0003oooooooooo`1:ooooo`;o00002Oooool01?l0003o
ooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo0_l0003oooooofgooooo000`oooo
o`03o`000?oooooooooo04[ooooo0_l00009ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000
oooooooooooo00002?ooool2o`000?ooooooKOooool0033ooooo00?o0000ooooooooool0B_ooool2
o`0000Wooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00008ooooo`;o0000
oooooom]ooooo`00<?ooool00ol0003oooooooooo`1:ooooo`;o00002Oooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0000Sooooo0_l0003oooooofgooooo000`ooooo`03o`00
0?oooooooooo04Wooooo00?o0000ooooool000002Oooool01?l0003oooooooooool00008ooooo`04
o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooom/ooooo`00<?ooool00ol0003o
ooooooooo`19ooooo`03o`000?oooooo000000Wooooo00Co0000oooooooooooo00002?ooool01?l0
003oooooooooool00008ooooo`03o`000?oooooo00000?ooooooK?ooool0033ooooo00?o0000oooo
ooooool0BOooool00ol0003oooooo`000009ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000
oooooooooooo00001oooool01?l0003oooooooooool0003oooooofcooooo000`ooooo`03o`000?oo
oooooooo04Wooooo00?o0000ooooool000002Oooool01?l0003oooooooooool00008ooooo`04o`00
0?ooooooooooo`0000Oooooo00Co0000oooooooooooo0000oooooom/ooooo`00<?ooool3o`0004Wo
oooo00?o0000ooooool000002Oooool01?l0003oooooooooool00008ooooo`04o`000?oooooooooo
o`0000Oooooo00Co0000oooooooooooo0000oooooom/ooooo`00<?ooool00ol0003oooooooooo`19
ooooo`03o`000?oooooo000000Wooooo00Co0000oooooooooooo00002?ooool01?l0003ooooooooo
ool00007ooooo`04o`000?ooooooooooo`000?ooooooK?ooool0033ooooo00?o0000ooooooooool0
BOooool00ol0003oooooo`000009ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooo
oooo00001oooool01?l0003oooooooooool0003oooooofcooooo000`ooooo`03o`000?oooooooooo
04Wooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Co
0000oooooooooooo00001oooool01?l0003oooooooooool0003oooooofcooooo000`ooooo`03o`00
0?oooooooooo04Wooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo0000
00Oooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool0003oooooofcooooo000`
ooooo`03o`000?oooooooooo04Wooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooo
oooooooo000000Oooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool0003ooooo
ofcooooo000`ooooo`03o`000?oooooooooo04Wooooo00Co0000oooooooooooo00002?ooool01Ol0
003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo00001oooool01?l0003ooooooooo
ool0003oooooofcooooo000@ooooo`;ok^k^0oooool2onk^kQWooooo00?o0000ooooooooool0BOoo
ool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool000001oooool01?l0003o
ooooooooool00007ooooo`04o`000?ooooooooooo`000?ooooooK?ooool000Wooooo1Ol00002oooo
o`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co000000So410@ooooooooooook^k^
oc8b<_l0003o<S8bonk^kP[ooooo00?o0000ooooooooool0BOooool01?l0003oooooooooool00008
ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool00007ooooo`04o`00
0?ooooooooooo`000?ooooooK?ooool000Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05
onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02_ooool00ol0003oooooooooo`19ooooo`04o`000?ooooooooooo`0000Sooooo00Go
0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooo
oooo0000oooooom/ooooo`0000?oooooo`000?l000001?l00003ooooo`03oiRHV?lQ8B7ok^k^00Go
oooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooo
ool@41002_ooool00ol0003oooooooooo`19ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000
ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo
0000oooooom/ooooo`002oooool00onHV9So8B4Qonk^kP03ooooo`05onk^k_mEEEGogMgMoeEEEOo^
k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000002_ooool00ol0
003oooooooooo`19ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`00
0007ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo0000oooooom/ooooo`00
3?ooool02omgMgOoIVIVooooooooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000[ooooo1?l00018ooooo`04o`00
0?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?oooooooooo
o`0000Oooooo00Co0000oooooooooooo0000oooooom/ooooo`003Oooool00ol0003oooooooooo`02
onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
400:ooooo`03o`000?oooooooooo04Wooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooo
oooooooooooo000000Oooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool0003o
ooooofcooooo0009ooooo`05o`000?nj^[[ooooooiRHV?l@41003_ooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool2o`0000Gooooo00?o0000ooooooooool0BOoo
ool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool000001oooool01?l0003o
ooooooooool00007ooooo`04o`000?ooooooooooo`000?ooooooK?ooool000Wooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP02ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0BOooool01?l0003ooooo
ooooool00008ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo
000000Kooooo00Co0000oooooooooooo0000oooooom/ooooo`00:?ooool01?l0003oooooooooool0
0004ooooo`03o`000?oooooooooo04Wooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooo
oooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?oooooooooo
o`000?ooooooK?ooool002Sooooo0ol00005ooooo`03o`000?oooooooooo04Wooooo00Co0000oooo
oooooooo00002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooooooooooooooo
o`000006ooooo`04o`000?ooooooooooo`000?ooooooK?ooool002Wooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`19ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooo
ooooooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool0
003oooooofcooooo000Zooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0BOooool0
1?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooo
oooooooooooo000000Kooooo00Co0000oooooooooooo0000oooooom/ooooo`00<?ooool00ol0003o
ooooooooo`19ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000007
ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool0003oooooofcooooo
000`ooooo`03o`000?oooooooooo04Sooooo00Go0000ooooooooooooooooo`000008ooooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`3oooooof7ooooo000`ooooo`03
o`000?oooooooooo04Sooooo00Go0000ooooooooooooooooo`000008ooooo`05o`000?oooooooooo
ooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Co0000
oooooooooooo00001oooool2o`000?ooooooHoooool0033ooooo00?o0000ooooooooool0B?ooool0
1Ol0003ooooooooooooooooo000000Sooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00007ooooo`;o
0000oooooomSooooo`00<?ooool3o`0004Sooooo00Go0000ooooooooooooooooo`000008ooooo`05
o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00003oooooof;ooooo000`oooo
o`03o`000?oooooooooo04Sooooo00Go0000ooooooooooooooooo`000008ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Co
0000oooooooooooo00001oooool00ol0003oooooo`00003oooooof;ooooo000`ooooo`03o`000?oo
oooooooo04Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo
00Co0000oooooooooooo00001oooool00ol0003oooooo`00003oooooof;ooooo000`ooooo`03o`00
0?oooooooooo04Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00003oooooof;ooooo000`ooooo`03
o`000?oooooooooo04Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`05
o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00003oooooof;ooooo000`oooo
o`03o`000?oooooooooo04Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05oooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00003oooooof;ooooo000`
ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00003oooooof;ooooo
000`ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00001oooool00ol0003ooooo
o`00003oooooof;ooooo000`ooooo`03o`000?oooooooooo03cooooo0_l0000:ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`04o`000?oo
ooooooooo`0000Oooooo00?o0000ooooool00000oooooomRooooo`00<?ooool00ol0003ooooooooo
o`0looooo`;o00002_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooool00000
oooooomRooooo`00<?ooool00ol0003oooooooooo`0looooo`03o`000?oooooo000000Wooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooo00000?ooooooH_ooool0033ooooo00?o
0000ooooooooool0??ooool00ol0003oooooo`000009ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooo`00003oooooof;ooooo000`ooooo`?o0000??ooool00ol0003oooooo`00
0009ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`04ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool0003oooooof7o
oooo000`ooooo`03o`000?oooooooooo03_ooooo00Co0000oooooooooooo00002Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003o
oooooooooooooooo000000Kooooo00Co0000oooooooooooo0000oooooomQooooo`00<?ooool00ol0
003oooooooooo`0kooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`000?ooooooHOooool0033ooooo00?o0000
ooooooooool0>oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool00000oooooomQooooo`00<?oo
ool00ol0003oooooooooo`0kooooo`05o`000?ooooooooooooooool000001oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00003oooooof7o
oooo000`ooooo`03o`000?oooooooooo03_ooooo00Go0000ooooooooooooooooo`000007ooooo`03
o`000?oooooooooo00?ooooo00?o0000onk^k_o^k^h00oooool00oo^k^ko0000ooooo`03ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo0000
037ooooo0_o^k^h3ooooo`;ok^k^H?ooool2onk^kP?ooooo0_o^k^i>ooooo`;ok^k^0oooool2onk^
kVcooooo000`ooooo`03o`000?oooooooooo03_ooooo00Go0000ooooooooooooooooo`000007oooo
o`0>o`000?m4A4Co0000o`000?lb<S;ogMgMo`000?o^k^koEEEEonk^k_ooooook^k^oeEEEOl00003
ooooo`Co000000Co410@ooooooooooook^k^0_l000001?lb<S;ok^k^ooooool00005ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000002_o
oooo1?l000002Ol@413oooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co000000So
410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kS_ooooo1?l000000ol@413oooooooooo`02oooo
o`;o8B4Q1Oooool03Om4A4Co0000o`000?lb<S;ogMgMooooooo^k^koEEEEonk^k_ooooook^k^oeEE
EOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hhooooo`Go0000
0_ooool01oo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^iMooooo`00<?ooool00ol0003oooooooooo`0kooooo`05o`000?oo
ooooooooooooool000001oooool03_l0003oooooooooooooooooMgMgoc8b<_l0003oooooonk^k_mE
EEGogMgMoeEEEOo^k^ko00001?ooool2o`0000Cooooo00OoMgMgo`000?ooooooV9RHogMgMooooooo
000000Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooo
ooooooooool00000;Oooool00ol0003oooooooooo`02ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h0
1_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?Oooool00ol0003o
ooooooooo`04ooooo`;o8B4Q2?ooool02OmgMgOo<S8booooooooooook^k^oeEEEOoMgMgoEEEEonk^
kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0hooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@00oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000oooo
ooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg05gooooo000`ooooo`03o`000?oooooooooo
03_ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo0_l00002
ooooo`05omgMgOl0003ogMgMooooool000001?ooool2o`0000Cooooo00Oo410@o`000?oooooooooo
oa0@4?oooooo000000Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05
o`000?ooooooooooooooool000001_ooool2o`0002Gooooo00?o0000ooooooooool00oooool00ooM
gMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400m
ooooo`03o`000?oooooooooo00oooooo00Oo0000ooooooooooooooooomgMgOl0003ogMgM00Oooooo
00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@03Wooooo00?oV9RHob4Q8Oo^
k^h01Oooool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooo
oooooooooa0@401Mooooo`00<?ooool00ol0003oooooooooo`0kooooo`05o`000?oooooooooooooo
ool000001oooool03_l0003oooooooooooooooooMgMgoc8b<_l0003oooooonk^k_mEEEGogMgMoeEE
EOo^k^ko00001?ooool2o`0000Cooooo0_l00002ooooo`03o`000?oooooo000000Gooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001_oo
ool3o`0002Cooooo00?o0000ooooooooool00_ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000003gooooo00?o0000oooooooo
ool03_ooool02OmgMgOo<S8booooooooooook^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000jooooo`03oiRHV?lQ8B7ok^k^00?ooooo
00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`00001Mooooo`00<?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01Oooool2o`00000<ob4Q8Ol0003o<S8bolc<c?l0003ok^k^oeEEEOo^
k^koooooonk^k_mEEEGo00001?ooool2o`0000Cooooo0_l00002ooooo`03o`000?oooooo000000Go
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooooooooooo
ool000001_ooool00ol0003oooooo`00000Tooooo`0;o`000?ooooooooooooooooo^k^koEEEEonk^
k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000?Oooool00ol0003oooooooooo`0;ooooo`0=o`000?lQ8B7o0000oc8b<_o<c<coooooonk^
k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`00000kooooo`0;ogMgMomVIVKoooooooooooo^k^koEEEEonk^k_ooooook^k^oeEE
EOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000GOooool0
033ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Gooooo0_l00004ooooo`03o`000?o^k^kok^k^00?ooooo00?ok^k^o`000?ooool00oooool2o`00
00Cooooo00Oo410@o`000?oooooooooooa0@4?oooooo000000Gooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooo
o`00000Tooooo`04o`000?ooooooooooooooo`;ok^k^0oooool2onk^kPGooooo00?o0000oooooooo
ool00_ooool01Ol@413ooooooooooooooooo410@03gooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`03ooooo`;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@
413ooooooooooooooooo410@03cooooo00?o0000ooooooooool00_o^k^h3ooooo`;ok^k^1Oooool0
0ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100GOooool0033ooooo0ol0000j
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool2o`0000Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`02ooooo`;o00001?ooool01omgMgOo0000oooooonH
V9SoMgMgooooool000001Oooool2o`0000?ooooo00?o0000ooooooooool00oooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooool000009?ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`;o0000<oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Sooooo0_l0000^ooooo`05o`000?nj^[[ooooooiRHV?l@41003_oo
ool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool2o`0005?ooooo
000`ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`05ooooo`Go000000?oooooo`000?ooool01Oooool01Ol0003oooooooooooooooooEEEE00;o0000
1?ooool01oo^k^ko0000o`000?lb<S;ok^k^ooooool000001Oooool2o`0000?ooooo00?o0000oooo
ooooool00oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooool000008_ooool0
0omEEEGoIVIVo`00000=ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP07ooooo`04o`000?ooooooooooo`00033ooooo00?oEEEEofIVI_l000003Oooool4o`0000cooooo
00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oooooo00Co0000oooooooo
oooo0000;Oooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo00?oEEEEofIVI_l000001?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Oooooo00Co0000oooooooooooo0000D_ooool0033ooooo00?o
0000ooooooooool0>_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`Go000000Coooooo`000?oooooo0000
0_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001Oooool01?l0003o
ooooooooool00010ooooo`Co000000Goooooo`000?ooooooooooo`00001Nooooo`Co000000Gooooo
o`000?ooooooooooo`00001<ooooo`Co000000Goooooo`000?ooooooooooo`00001Booooo`00<?oo
ool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooooooo
o`000005ooooo`04o`000?ooooooooooo`0004Gooooo0ol0001Tooooo`?o0000D_ooool3o`0005?o
oooo000`ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`06o`000?ooooooooooo`000?oooooo00001?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000015ooooo`03o`000?oooooo
oooo06Cooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`1Booooo`00<?ooool00ol0
003oooooooooo`0iooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool4o`00
0003ooooool0003ooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`05o`000?ooooooooooooooool00000A_ooool00ol0003oooooooooo`1Tooooo`03o`000?oooooo
oooo05;ooooo00?o0000ooooooooool0DOooool0033ooooo00?o0000ooooooooool0;Oooool3o`00
00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00?ooooo00Go0000ooooooooooooooooo`000006ooooo`;o0000oooooom?ooooo`00<?ooool00ol0
003oooooooooo`0/ooooo`;o000000?oooooo`000?l000002?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo
000000Kooooo0_l0003ooooooaGooooo00?oMgMgofIVI_ooool0;Oooool00omVIVKoMgMgooooo`07
ooooo`00<?ooool00ol0003oooooooooo`0/ooooo`05o`000?ooooooooooooooool000002?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool0
1Ol0003ooooooooooooooooo000000Gooooo00Co0000oooooooooooo0000oooooolCooooo`03omgM
gOl@413ok^k^02kooooo00?ok^k^oa0@4?oMgMd01oooool0033ooooo00?o0000ooooooooool0:ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooooooo
o`000005ooooo`04o`000?ooooooooooo`000?oooooo0Oooool2o`0000;ooooo0_l0000<ooooo`03
oeEEEOnHV9Sooooo00;o00000_ooool01ol0003oooooooooool0003o410@onk^k_mEEED00_l00000
0om4A4Co^[Zjooooo`02ooooo`05oiRHV?l0003o0000odA4A?nj^[X00_ooool02?o^k^koEEEEo`00
0?l0003oA4A4okZj^_oooooo410@1Ol00003ooooo`08oa0@4?lb<S;o0000o`000?l@413oZJVYohN7
QomVIVH7ooooo`00<?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
1?ooool00ol0003oooooooooo`03ooooo`?o0000moooool01_o^k^ko8B4QohN7Qonj^[[o0000omgM
g@cooooo00Go0000ooooooooooooooooo`000002ooooo`0;o`000?ooooooooooo`000?ooooooEEEE
ogMgMoooooook^k^ogMgMol@41000oooool01Ol@413o^[Zjonk^k_mgMgOo410@00;ooooo00KoEEEE
ogMgMoooooook^k^ogMgMol@4103ooooo`03o`000?oooooooooo00Cooooo00So0000ojVYZOoooooo
oooookZj^_l0003ok^k^o`0000Oooooo003oo`000;Co00003oooool01?oMgMgo0000oa0@4?o<c<`=
ooooo`05oc8b<_ooooooooooooooool000000_ooool01_l0003oooooooooool0003oooooo`0000So
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Go
oooo00Oo^[ZjohN7QomVIVKoIVIVoa0@4?oooooo000000Oooooo000:ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
00oooooo0_l00004ooooo`;o00001oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`;o00001?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000001?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01Ol0003ooooooooo
oooooooo000000Cooooo00?o0000ooooooooool00oooool2o`0000?ooooo00Go0000oooooooooooo
ooooo`000004ooooo`;o00000_ooool2o`0000Cooooo0ol0000;ooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Gooooo`04onk^k_lQ8B7o410@onk^
kPgooooo00Go<S8booooooooooooooooo`000002ooooo`05o`000?ooooooooooo`000?ooool01_l0
0003ooooo`03o`000?oooooooooo00Cooooo1_l00003ooooo`03o`000?oooooooooo00Cooooo00So
<S8bob4Q8OmgMgOoMgMgohN7Qoo^k^koooooo`0000Oooooo000:ooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013o
oooo1_l00008ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo0_l00004ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool2o`0000Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oo
oooooooo00;ooooo0_l00003ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003ooooo
o`000002o`0001;ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo01Oooooo00Co8B4QogMgMomgMgOo<S8b3Oooool01Ol0003ok^k^oooooooooooo0000
00;oc<c<00_o0000ojVYZOoMgMgo8B4QoooooomEEEGoQhN7onk^k_ooooooQhN7oc8b<P03ooooo`03
o`000?oooooooooo00Cooooo00KoEEEEohN7Qoo^k^koooooohN7Qolb<S83ooooo`03o`000?lb<S;o
gMgM00Cooooo00So0000okZj^_ooooook^k^ogMgMol0003ok^k^o`0000Oooooo000`ooooo`03o`00
0?oooooooooo03;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000005oooo
o`?o00009oooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo05_ooooo00?o0000oooo
ooooool05_ooool2o`0000;ooooo0_l0000<ooooo`0>oeEEEOmgMgOooooooa0@4?l0003o8B4Qo`00
0?mgMgOo410@o`000?nYZJWoooooonk^k_mEEED2o`000004odA4A?o^k^kooooooa0@40Go00000ooo
ool01_o^k^koEEEEo`000?l0003oA4A4onk^kP;ooooo0_l000001?nYZJWo8B4Qo`000?lQ8B42oooo
o`08ojVYZOlQ8B7o0000o`000?lb<S;o0000ogMgMomEEED7ooooo`00<?ooool00ol0003ooooooooo
o`0booooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000005ooooo`05o`00
0?ooooooooooooooool000001Oooool01?l0003oooooooooool0003ooooooaSooooo00?ogMgMoa0@
4?o^k^h04_ooool00ol0003oooooooooo`0Iooooo`03onk^k_l@413ogMgM00Oooooo000`ooooo`03
o`000?oooooooooo03;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo0000
00Gooooo00Go0000ooooooooooooooooo`000005ooooo`04o`000?ooooooooooo`000?oooooo6Ooo
ool00omgMgOoIVIVooooo`0Aooooo`03o`000?oooooooooo01Wooooo00?oIVIVogMgMoooool01ooo
ool0033ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooo
ooooooooool000001Oooool01Ol0003ooooooooooooooooo000000Gooooo00Co0000oooooooooooo
0000oooooomCooooo`00<?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
00Go0000ooooooooooooooooo`000005ooooo`05o`000?ooooooooooooooool000001_ooool00ol0
003oooooo`00003ooooooe?ooooo000`ooooo`03o`000?oooooooooo03?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool01Ol0003ooooooooooooooooo000000Gooooo00Go0000ooooooooooooooooo`000006
ooooo`03o`000?oooooo00000?ooooooDoooool0033ooooo00?o0000ooooooooool0<oooool01Ol0
003ooooooooooooooooo000000Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0003ooooooooooooooooo000000Kooooo
0_l0003ooooooeCooooo000`ooooo`03o`000?oooooooooo03Cooooo00Co0000oooooooooooo0000
2?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooo
ooooo`000005ooooo`05o`000?ooooooooooooooool00000oooooomLooooo`00<?ooool00ol0003o
ooooooooo`0dooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0003ooooooooooooo
oooo00000?ooooooG?ooool0033ooooo0ol0000dooooo`04o`000?ooooooooooo`0000Sooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool00000
1Oooool01Ol0003ooooooooooooooooo00000?ooooooG?ooool0033ooooo00?o0000ooooooooool0
=Oooool3o`0000Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`00
0?ooooooooooooooool000001Oooool01?l0003oooooooooool0003ooooooegooooo000`ooooo`03
o`000?oooooooooo03Gooooo0_l0000:ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool01Ol0003ooooooooooooooooo000000Gooooo00Co0000oooooooooooo0000oooooomM
ooooo`00<?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool01Ol0003ooooooooooooooooo000000Gooooo00Co0000oooooooooooo0000oooo
oomMooooo`00<?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool01Ol0003ooooooooooooooooo000000Gooooo00Co0000oooooooooooo0000
oooooomMooooo`00<?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooool00000
oooooomMooooo`00<?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooool00000
oooooomMooooo`00<?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooool00000
oooooomMooooo`00<?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooool00000
oooooomMooooo`00<?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooool00000
oooooomMooooo`00<?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooool00000
oooooomMooooo`00<?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooool00000
oooooomMooooo`00<?ooool3o`0004;ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`00
0?ooooooooooooooool000001_ooool2o`000?ooooooG_ooool0033ooooo00?o0000ooooooooool0
@_ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000007oooo
o`03o`000?oooooooooo0?ooooooG?ooool0033ooooo00?o0000ooooooooool0@_ooool01Ol0003o
oooooooooooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo
000000Kooooo00Go0000ooooooooooooooooo`00003oooooofKooooo000`ooooo`03o`000?oooooo
oooo04;ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go
0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool00000oooooomVooooo`00
<?ooool00ol0003oooooooooo`12ooooo`05o`000?ooooooooooooooool000001oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo
00000?ooooooI_ooool0033ooooo00?o0000ooooooooool0@_ooool01Ol0003ooooooooooooooooo
000000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go
0000ooooooooooooooooo`00003oooooofKooooo000`ooooo`03o`000?oooooooooo04;ooooo00Go
0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooo
ooooo`000006ooooo`05o`000?ooooooooooooooool00000oooooomVooooo`00<?ooool00ol0003o
ooooooooo`12ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04oooo
o`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo00000?ooooooI_oo
ool0033ooooo00?o0000ooooooooool0@_ooool01?l0003oooooooooool00008ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`000?oo
ooooIoooool0033ooooo00?o0000ooooooooool0@_ooool01?l0003oooooooooool00008ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?oooooooooo
o`000?ooooooIoooool0033ooooo00?o0000ooooooooool0@_ooool01?l0003oooooooooool00008
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?oo
ooooooooo`000?ooooooIoooool0033ooooo00?o0000ooooooooool0@_ooool01?l0003ooooooooo
ool00008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`04
o`000?ooooooooooo`000?ooooooIoooool0033ooooo0ol00012ooooo`04o`000?ooooooooooo`00
00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000
oooooooooooo0000oooooomWooooo`00<?ooool00ol0003oooooooooo`12ooooo`04o`000?oooooo
ooooo`0000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo
00Co0000oooooooooooo0000oooooomWooooo`00<?ooool00ol0003oooooooooo`12ooooo`04o`00
0?ooooooooooo`0000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000
00Kooooo00Co0000oooooooooooo0000oooooomWooooo`00<?ooool00ol0003oooooooooo`12oooo
o`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooo
oooo000000Oooooo00?o0000ooooool00000oooooomWooooo`00<?ooool00ol0003oooooooooo`12
ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000Oooooo00?o0000ooooool00000oooooomWooooo`00<?ooool00ol0003ooooooooo
o`13ooooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000Oooooo00?o0000ooooool00000oooooomWooooo`003oooool2onk^kP?ooooo0_o^
k^hJooooo`03o`000?oooooooooo04?ooooo00?o0000ooooool000002?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`04ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003oooooofOooooo
0008ooooo`Go00000_ooool01oo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008
oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`03o`000?oooooooooo04?ooooo00?o
0000ooooool000002?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000
1oooool00ol0003oooooo`00003oooooofOooooo0008ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
0oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?o0000ooooooooool0@oooool00ol0003oooooo`000008oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo
00000?ooooooIoooool000Wooooo00?oV9RHob4Q8Oo^k^h01Oooool00ooMgMgo0000omgMg@07oooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400;ooooo`03o`000?oooooo
oooo04?ooooo0_l00009ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00
0007ooooo`03o`000?oooooo00000?ooooooIoooool000[ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000_ooooo00?o0000ooooooooool0@oooool2o`0000Wooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooool00000oooooomWooooo`00
2oooool02omgMgOoIVIVooooooooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000_ooooo1?l00012ooooo`;o0000
2_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003ooooo
ofOooooo000<ooooo`03o`000?oooooooooo00;ok^k^0oooool2onk^kPGooooo00?o0000oooooooo
ool00_ooool01Ol@413ooooooooooooooooo410@00_ooooo00?o0000ooooooooool0A?ooool00ol0
003oooooooooo`08ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oo
oooo00000?ooooooIoooool000Sooooo00Go0000okZj^_ooooooV9RHoa0@400>ooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03o`000?oooooooooo04oooooo
00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooool00000oooooomWoooo
o`002?ooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo00?oEEEEofIVI_l000001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo0_l00006ooooo`03o`000?oooooooooo04oooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooool00000oooooomWooooo`009ooo
ool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo04oooooo00Co0000oooooooooooo
00001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooo
ooooooooo`000007ooooo`;o0000oooooomXooooo`009oooool01?l0003oooooooooool00005oooo
o`03o`000?oooooooooo04oooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000007ooooo`;o0000oooo
oomXooooo`009oooool3o`0000Kooooo00?o0000ooooooooool0Coooool01?l0003oooooooooool0
0007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000Oooooo0_l0003oooooofSooooo000Xooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0Coooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Oooooo0_l0003oooooofSo
oooo000Yooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Coooool01?l0003ooooo
ooooool00007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003o
oooooooooooooooo000000Oooooo0_l0003oooooofSooooo000`ooooo`03o`000?oooooooooo04oo
oooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo0?ooooooI_ooool0
033ooooo00?o0000ooooooooool0Coooool01?l0003oooooooooool00007ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo00000?ooooooLOoo
ool0033ooooo00?o0000ooooooooool0Coooool01?l0003oooooooooool00008ooooo`05o`000?oo
ooooooooooooool000001_ooool01Ol0003ooooooooooooooooo00000?ooooooLOooool0033ooooo
0ol0001?ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000006oooo
o`05o`000?ooooooooooooooool00000oooooomaooooo`00<?ooool00ol0003oooooooooo`1?oooo
o`04o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?oo
ooooooooo`000?ooooooLOooool0033ooooo00?o0000ooooooooool0Coooool01?l0003ooooooooo
ool00008ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool0003ooooo
og7ooooo000`ooooo`03o`000?oooooooooo04oooooo00Co0000oooooooooooo00002?ooool01Ol0
003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000oooooomaooooo`00<?ooool0
0ol0003oooooooooo`1?ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooooooooooo
o`000007ooooo`04o`000?ooooooooooo`000?ooooooLOooool0033ooooo00?o0000ooooooooool0
Coooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool000001oooool01?l0
003oooooooooool0003oooooog7ooooo000`ooooo`03o`000?oooooooooo04oooooo00Co0000oooo
oooooooo00002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000
oooooomaooooo`00<?ooool00ol0003oooooooooo`1?ooooo`04o`000?ooooooooooo`0000Sooooo
00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?ooooooL_ooool0033ooooo
00?o0000ooooooooool0Coooool01?l0003oooooooooool00008ooooo`05o`000?oooooooooooooo
ool000001oooool00ol0003oooooo`00003oooooog;ooooo000`ooooo`03o`000?oooooooooo04oo
oooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000
ooooool00000oooooombooooo`00<?ooool00ol0003oooooooooo`1?ooooo`04o`000?oooooooooo
o`0000Sooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?ooooooL_oo
ool0033ooooo00?o0000ooooooooool0Coooool01?l0003oooooooooool00008ooooo`05o`000?oo
ooooooooooooool000001oooool00ol0003oooooo`00003oooooog;ooooo000`ooooo`?o0000Cooo
ool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool000001oooool00ol0003o
ooooo`00003oooooog;ooooo000`ooooo`03o`000?oooooooooo04oooooo00Co0000oooooooooooo
00002?ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooool00000oooooomboooo
o`00<?ooool00ol0003oooooooooo`1?ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000oooo
ooooooooooooo`000007ooooo`03o`000?oooooo00000?ooooooL_ooool0033ooooo00?o0000oooo
ooooool0Coooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool000001ooo
ool00ol0003oooooo`00003oooooog;ooooo000`ooooo`03o`000?oooooooooo053ooooo00?o0000
ooooool000002?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?ooooooL_oo
ool0033ooooo00?o0000ooooooooool0D?ooool00ol0003oooooo`000008ooooo`04o`000?oooooo
ooooo`0000Sooooo00?o0000ooooool00000oooooombooooo`00<?ooool00ol0003oooooooooo`1@
ooooo`03o`000?oooooo000000Sooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00
003oooooog;ooooo000`ooooo`03o`000?oooooooooo053ooooo00?o0000ooooool000002?ooool0
1?l0003oooooooooool00008ooooo`03o`000?oooooo00000?ooooooL_ooool0033ooooo00?o0000
ooooooooool0D?ooool00ol0003oooooo`000008ooooo`04o`000?ooooooooooo`0000Sooooo00?o
0000ooooool00000oooooombooooo`00<?ooool00ol0003oooooooooo`1@ooooo`03o`000?oooooo
000000Sooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003oooooog;ooooo000`
ooooo`03o`000?oooooooooo053ooooo00?o0000ooooool000002?ooool01?l0003oooooooooool0
0008ooooo`03o`000?oooooo00000?ooooooL_ooool0033ooooo00?o0000ooooooooool0D?ooool0
0ol0003oooooo`000008ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooo
oombooooo`00<?ooool3o`00053ooooo00?o0000ooooool000002?ooool01?l0003oooooooooool0
0008ooooo`03o`000?oooooo00000?ooooooL_ooool0033ooooo00?o0000ooooooooool0D?ooool0
0ol0003oooooo`000008ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooo
oombooooo`00<?ooool00ol0003oooooooooo`1@ooooo`;o00002Oooool01?l0003oooooooooool0
0008ooooo`03o`000?oooooo00000?ooooooL_ooool0033ooooo00?o0000ooooooooool0D?ooool2
o`0000Wooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003oooooog;ooooo000`
ooooo`03o`000?oooooooooo053ooooo0_l00009ooooo`04o`000?ooooooooooo`0000Sooooo00?o
0000ooooool00000oooooombooooo`00<?ooool00ol0003oooooooooo`1@ooooo`;o00002Oooool0
1?l0003oooooooooool00009ooooo`;o0000oooooombooooo`003oooool2onk^kP?ooooo0_o^k^hJ
ooooo`03o`000?oooooooooo053ooooo0_l00009ooooo`04o`000?ooooooooooo`0000Wooooo0_l0
003oooooog;ooooo000:ooooo`;o000000[o410@ooooooooooook^k^oeEEEOo^k^koooooonk^k_mE
EEGok^k^0oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`03o`00
0?oooooooooo053ooooo0_l00009ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000oooooooo
ool0oooooomaooooo`002oooool00ol0003oooooooooo`02ooooo`05onk^k_mEEEGogMgMoeEEEOo^
k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ol0
003oooooooooo`1@ooooo`;o00002Oooool01?l0003oooooooooool00009ooooo`03o`000?oooooo
oooo0?ooooooLOooool000Sooooo1Ol00004ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@00_ooooo00?o0000ooooooooool0D?ooool2
o`0000Wooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`3oooooog7ooooo0008
ooooo`04odA4A?oMgMgoooooo`0000Cooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000;ooooo`03o`000?oooooooooo05_o
oooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`3oooooog7ooooo0008ooooo`04
omgMgOmEEEGoooooo`0000?ooooo00Ook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000_ooooo1?l0001Kooooo`03o`00
0?oooooo00000?ooooooOOooool000Wooooo00?oMgMgolc<c?l000000oooool2onk^kP?ooooo0_o^
k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400;ooooo`03o`00
0?oooooooooo05cooooo00?o0000ooooool00000oooooommooooo`002Oooool00oo^k^koA4A4o`00
000?ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03o`00
0?oooooooooo05cooooo00?o0000ooooool00000oooooommooooo`002_ooool00omgMgOo0000oooo
o`0<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`;o0000
1_ooool00ol0003oooooooooo`1Looooo`03o`000?oooooo00000?ooooooOOooool002Oooooo00Co
0000oooooooooooo00001Oooool00ol0003oooooooooo`1Looooo`03o`000?oooooo00000?oooooo
OOooool002Oooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`1Looooo`03o`00
0?oooooo00000?ooooooOOooool002Oooooo0ol00006ooooo`03o`000?oooooooooo05cooooo00?o
0000ooooool00000oooooommooooo`00:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo05cooooo00?o0000ooooool00000oooooommooooo`00:Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo05cooooo00?o0000ooooool00000oooooommooooo`00<?ooool00ol0003o
ooooooooo`1Looooo`;o0000oooooomnooooo`00<?ooool00ol0003oooooooooo`1Looooo`;o0000
oooooomnooooo`00<?ooool00ol0003oooooooooo`1Looooo`;o0000oooooomnooooo`00<?ooool3
o`0005cooooo0_l0003oooooogkooooo000`ooooo`03o`000?oooooooooo05cooooo0_l0003ooooo
ogkooooo000`ooooo`03o`000?oooooooooo05cooooo0_l0003oooooogkooooo000`ooooo`03o`00
0?oooooooooo05cooooo0_l0003oooooogkooooo000`ooooo`03o`000?oooooooooo05cooooo0_l0
003oooooogkooooo000`ooooo`03o`000?oooooooooo05cooooo0_l0003oooooogkooooo000`oooo
o`03o`000?oooooooooo05gooooo00?o0000ooooooooool0oooooomlooooo`00<?ooool00ol0003o
ooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o
0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`oooo
o`03o`000?oooooooooo0?oooooog?ooool0033ooooo0ol0003oooooomcooooo000`ooooo`03o`00
0?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool0
0ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033o
oooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo
000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooL
ooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oo
oooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool3o`000?oooooog?oo
ool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3ooooo
omcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0
oooooooLooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@oooo
o`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooo
oooooa3ooooo003ooooooooooooo4?ooool00:3ooooo0_l00004ooooo`03okZj^_lb<S;ooooo00Co
oooo0_l00006ooooo`03o`000?nj^[[ooooo0?ooooooEoooool00:3ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo0_lb<S;ooooooeSooooo
002=ooooo`?o00000_ooool01_lb<S;o410@ooooooooooook^k^oeEEE@;o000000?oA4A4okZj^_oo
ool00oooool00ol0003oooooooooo`02ooooo`05oiRHV?l@413o0000o`000?nYZJT01?ooool00ol0
003oooooooooo`04ooooo`03ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0;
ooooo`;o000000?o410@ooooooooool00oooool2ob4Q8@Kooooo0_l000001ol@413oooooolc<c?o^
k^koooooonk^k_o<c<`01?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hC
ooooo`06oa0@4?lb<S;o0000o`000?l@413oZJVY0_ooool01_o^k^koEEEEo`000?l0003oA4A4okZj
^P?ooooo00GoIVIVo`000?l0003oA4A4olc<c03Xooooo`00S_ooool01Ol0003oooooooooooo<c<co
410@00?ooooo00KoEEEEogMgMoooooook^k^ogMgMol@4104ooooo`03o`000?oooooooooo00;ooooo
00Ko0000ojVYZOmEEEGoV9RHoeEEEOnj^[X3ooooo`03o`000?oooooooooo00Cooooo00?oc<c<o`00
0?l@41003?ooool01_l@413o^[Zjonk^k_mgMgOo410@ooooo`Ko00001Oooool00ol0003ooooooooo
o`04ooooo`;o8B4Q1oooool02?l0003oooooooooooo^k^koEEEEomgMgOmEEEGok^k^1_ooool00ol0
003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool01_l0003oZJVYoooooooo
oooo^[Zjo`0000;ooooo00KoEEEEogMgMoooooook^k^ogMgMol@4102ooooo`06ofIVI_mgMgOooooo
oooooon7QhOo410@j?ooool008kooooo00Go0000ooooooooooooEEEEohN7Q`03ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool00_ooool01_lb<S;ok^k^oiRHV?mEEEGogMgMoa0@40?o
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0;ooooo`Go00002oooool5o`0000;o
oooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooo
ool@41005?ooool01Onj^[[oQhN7ofIVI_mVIVKo410@00;ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`3[ooooo`00S_ooool01Ol0003oooooomgMgOl0003ok^k^00?ooooo1_l00004
ooooo`03o`000?oooooooooo00;ooooo00Oo^[ZjodA4A?o<c<co8B4Qooooool@413oc<c<00;ooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`03ooooo`Ko00000_ooool01?m4A4CogMgM
ooooool0000<ooooo`04odA4A?oMgMgoooooo`0000;ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Cooooo`06oc8b<_lQ
8B7oMgMgogMgMon7QhOok^k^0_ooool6o`0000;ooooo00?o0000ooooooooool0joooool008kooooo
0ol000000ol@413oV9RHooooo`02ooooo`06oeEEEOn7QhOok^k^oooooon7QhOo<S8b1?ooool00ol0
003oooooooooo`02ooooo`07onk^k_l0003oooooo`000?ooooooIVIVohN7Q`02ooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool02oooool01?oMgMgoEEEEooooool0000<ooooo`04omgM
gOmEEEGoooooo`0000;ooooo00Goc<c<onk^k_ooooook^k^olc<c006ooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`00000Cooooo`06o`000?nj^[[oooooonk^k_mgMgOo0000
0_ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<P;ooooo00KoIVIVogMgMoooooooooooohN7Qol0
003Xooooo`00S_ooool01Ol0003oooooooooooo<c<co000000?ooooo00Kok^k^oeEEEOl0003o0000
odA4A?o^k^h4ooooo`03o`000?oooooooooo00;ooooo00CoIVIVoiRHV?oooooo<S8b0_nj^[X01?l0
003oooooooooool0000Cooooo`03oa0@4?l0003o000000?o00002oooool00omgMgOoc<c<o`00000=
ooooo`03ogMgMoo<c<co000000gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@00Oooooo0ol00002ooooo`?o00001?ooool01_nYZJWo8B4Qo`000?l0003o<S8bo`0000;o
oooo00Kok^k^oeEEEOl0003o0000odA4A?o^k^h2ooooo`06onk^k_mVIVKo0000o`000?m4A4Co0000
j?ooool008kooooo00Go0000ooooooooooooc<c<o`00000=ooooo`03o`000?oooooooooo00Gooooo
00?oIVIVohN7Qoooool00oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00cooooo
00?ok^k^odA4A?l000003Oooool00oo^k^koA4A4o`00000=ooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0ooooool2ooooo`00SOooool4o`000003oa0@4?nYZJWooooo00cooooo0_l00006ooooo`03ojVY
ZOm4A4Cooooo00;ooooo0_l0000Eooooo`03o`000?oooooooooo00gooooo00?oMgMgo`000?ooool0
3Oooool00omgMgOo0000ooooo`0:ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP02ooooo`Co00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oo
oooo0_ooool00?oooooo1_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo
0_ooool00?oooooo1_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo0_oo
ool00?oooooo1Oooool2o`0000?ooooo0_l0003oooooo`Cooooo003ooooooooooooo4?ooool00?oo
ooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@
ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooo
oooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3o
oooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooo
oooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?oo
ool00?ooooooooooool@ooooo`00\
\>"],
  ImageRangeCache->{{{0, 525.688}, {324.5, 0}} -> {-2.58312*^-7, -6.34248*^6, \
6.65005*^-9, 53093.5}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0.309017 5.42214e-08 [
[.32684 .29652 -16.5 -12.5 ]
[.32684 .29652 16.5 0 ]
[.54329 .29652 -16.5 -12.5 ]
[.54329 .29652 16.5 0 ]
[.75974 .29652 -22.5 -12.5 ]
[.75974 .29652 22.5 0 ]
[.97619 .29652 -16.5 -12.5 ]
[.97619 .29652 16.5 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 64 6 ]
[.09789 .09213 -34.5 -6.25 ]
[.09789 .09213 0 6.25 ]
[.09789 .20057 -34.5 -6.25 ]
[.09789 .20057 0 6.25 ]
[.09789 .41746 -28.5 -6.25 ]
[.09789 .41746 0 6.25 ]
[.09789 .5259 -28.5 -6.25 ]
[.09789 .5259 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -62.8125 0 ]
[.5 .63053 62.8125 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 .30902 m
.32684 .31527 L
s
gsave
.32684 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 .30902 m
.54329 .31527 L
s
gsave
.54329 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 .30902 m
.75974 .31527 L
s
gsave
.75974 .29652 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 .30902 m
.15368 .31277 L
s
.19697 .30902 m
.19697 .31277 L
s
.24026 .30902 m
.24026 .31277 L
s
.28355 .30902 m
.28355 .31277 L
s
.37013 .30902 m
.37013 .31277 L
s
.41342 .30902 m
.41342 .31277 L
s
.45671 .30902 m
.45671 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.58658 .30902 m
.58658 .31277 L
s
.62987 .30902 m
.62987 .31277 L
s
.67316 .30902 m
.67316 .31277 L
s
.71645 .30902 m
.71645 .31277 L
s
.80303 .30902 m
.80303 .31277 L
s
.84632 .30902 m
.84632 .31277 L
s
.88961 .30902 m
.88961 .31277 L
s
.9329 .30902 m
.9329 .31277 L
s
.0671 .30902 m
.0671 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09213 m
.11664 .09213 L
s
gsave
.09789 .09213 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .20057 m
.11664 .20057 L
s
gsave
.09789 .20057 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .41746 m
.11664 .41746 L
s
gsave
.09789 .41746 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .5259 m
.11664 .5259 L
s
gsave
.09789 .5259 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.11039 .11924 m
.11414 .11924 L
s
.11039 .14635 m
.11414 .14635 L
s
.11039 .17346 m
.11414 .17346 L
s
.11039 .22768 m
.11414 .22768 L
s
.11039 .2548 m
.11414 .2548 L
s
.11039 .28191 m
.11414 .28191 L
s
.11039 .33613 m
.11414 .33613 L
s
.11039 .36324 m
.11414 .36324 L
s
.11039 .39035 m
.11414 .39035 L
s
.11039 .44457 m
.11414 .44457 L
s
.11039 .47168 m
.11414 .47168 L
s
.11039 .49879 m
.11414 .49879 L
s
.11039 .06502 m
.11414 .06502 L
s
.11039 .03791 m
.11414 .03791 L
s
.11039 .0108 m
.11414 .0108 L
s
.11039 .55301 m
.11414 .55301 L
s
.11039 .58012 m
.11414 .58012 L
s
.11039 .60723 m
.11414 .60723 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -123.812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.812 moveto
(@) show
81.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.812 moveto
(D) show
93.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.6) show
135.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
141.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
153.000 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
157.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
166.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
184.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02532 .30902 L
.02691 .30902 L
.02852 .30902 L
.03029 .30902 L
.03186 .30902 L
.03354 .30902 L
.03525 .30902 L
.03687 .30902 L
.03995 .30902 L
.04323 .30902 L
.04639 .30902 L
.04943 .30902 L
.05112 .30902 L
.05192 .30902 L
.05266 .30902 L
.05303 .30902 L
.05324 .30902 L
.05343 .30902 L
.05353 .30902 L
.05363 .30902 L
.05369 .30902 L
.05375 .30902 L
.0538 .30902 L
.05386 .30902 L
.05396 .30902 L
.05405 .30902 L
.0541 .30902 L
.05416 .30902 L
.05426 .30902 L
.05435 .30902 L
.05444 .30902 L
.05464 .30902 L
.05484 .30902 L
.05505 .30902 L
.05543 .30902 L
.05578 .30902 L
.05616 .30902 L
.05656 .30902 L
.0573 .30902 L
.05817 .30902 L
.05896 .30902 L
.05976 .30902 L
.0605 .30902 L
.06136 .30902 L
.06217 .30902 L
.06367 .30902 L
.06533 .30902 L
.06696 .30902 L
.06845 .30902 L
Mistroke
.06997 .30902 L
.07164 .30902 L
.07335 .30902 L
.0749 .30902 L
.07805 .30902 L
.08127 .30902 L
.08437 .30902 L
.08594 .30902 L
.08677 .30902 L
.08723 .30902 L
.08766 .30902 L
.08807 .30902 L
.08831 .30902 L
.08842 .30902 L
.08852 .30902 L
.08862 .30902 L
.0887 .30902 L
.0888 .30902 L
.0889 .30902 L
.089 .30902 L
.0891 .30902 L
.08915 .30902 L
.08921 .30902 L
.0893 .30902 L
.08941 .30902 L
.0895 .30902 L
.08972 .30902 L
.08991 .30902 L
.09011 .30902 L
.09045 .30902 L
.09084 .30902 L
.09126 .30902 L
.09165 .30902 L
.0924 .30902 L
.0932 .30902 L
.09408 .30902 L
.09483 .30902 L
.09566 .30902 L
.09735 .30902 L
.0989 .30902 L
.10057 .30902 L
.10218 .30902 L
.10387 .30902 L
.10693 .30902 L
.11018 .30902 L
.11331 .30902 L
.11491 .30902 L
.11575 .30902 L
.11621 .30902 L
.11664 .30902 L
Mistroke
.11703 .30902 L
.11722 .30902 L
.11744 .30902 L
.11756 .30902 L
.11767 .30902 L
.11779 .30902 L
.11789 .30902 L
.118 .30902 L
.11809 .30902 L
.1182 .30902 L
.11826 .30902 L
.11831 .30902 L
.1184 .30902 L
.11849 .30902 L
.11859 .30902 L
.11867 .30902 L
.11887 .30902 L
.11906 .30902 L
.11944 .30902 L
.11965 .30902 L
.11985 .30902 L
.12022 .30902 L
.12062 .30902 L
.12135 .30902 L
.12221 .30902 L
.123 .30902 L
.12452 .30902 L
.12538 .30902 L
.12618 .30902 L
.12783 .30902 L
.12932 .30902 L
.13253 .30901 L
.13562 .30901 L
.13891 .30901 L
.14054 .30901 L
.14134 .309 L
.14207 .309 L
.14243 .309 L
.14282 .309 L
.143 .309 L
.14319 .309 L
.14337 .309 L
.14345 .309 L
.14354 .309 L
.14364 .309 L
.14374 .309 L
.14384 .309 L
.14393 .309 L
.14398 .309 L
.14404 .309 L
Mistroke
.14413 .309 L
.14424 .309 L
.14435 .309 L
.14454 .309 L
.14475 .309 L
.14511 .309 L
.14551 .309 L
.14587 .309 L
.14668 .30901 L
.14743 .30901 L
.14815 .30901 L
.14892 .30901 L
.14974 .30901 L
.15121 .30902 L
.15293 .30903 L
.15455 .30904 L
.15764 .30906 L
.16093 .3091 L
.16257 .30911 L
.1641 .30913 L
.16486 .30913 L
.16557 .30913 L
.16597 .30914 L
.16618 .30914 L
.1664 .30914 L
.16658 .30914 L
.16669 .30914 L
.16679 .30914 L
.16688 .30914 L
.16696 .30914 L
.16705 .30914 L
.16715 .30914 L
.16725 .30914 L
.1673 .30914 L
.16736 .30914 L
.16745 .30914 L
.16755 .30914 L
.16772 .30914 L
.16792 .30914 L
.16812 .30914 L
.16834 .30913 L
.16873 .30913 L
.16913 .30913 L
.1695 .30913 L
.17021 .30912 L
.17098 .30911 L
.1718 .30909 L
.17328 .30905 L
.175 .30899 L
.17662 .30892 L
Mistroke
.17972 .30873 L
.18301 .30851 L
.18465 .30842 L
.18545 .30838 L
.18618 .30835 L
.18655 .30833 L
.18694 .30832 L
.18731 .30831 L
.18766 .30831 L
.18784 .3083 L
.18802 .3083 L
.18812 .3083 L
.18821 .3083 L
.18831 .3083 L
.18837 .3083 L
.18842 .3083 L
.18848 .3083 L
.18853 .3083 L
.18862 .3083 L
.18873 .3083 L
.18879 .3083 L
.18884 .3083 L
.18903 .3083 L
.18923 .30831 L
.18944 .30831 L
.18963 .30832 L
.18999 .30833 L
.19038 .30834 L
.19081 .30837 L
.19157 .30842 L
.19228 .30848 L
.19377 .30867 L
.19543 .30896 L
.19865 .30976 L
.20175 .31072 L
.20333 .3112 L
.20416 .31144 L
.20505 .31166 L
.20591 .31183 L
.20669 .31196 L
.20707 .312 L
.20727 .31202 L
.20748 .31204 L
.20767 .31205 L
.20776 .31205 L
.20787 .31206 L
.20797 .31206 L
.20805 .31206 L
.20814 .31206 L
.20823 .31206 L
Mistroke
.20833 .31206 L
.20838 .31206 L
.20843 .31206 L
.20853 .31206 L
.20863 .31206 L
.20872 .31205 L
.20881 .31205 L
.209 .31204 L
.2092 .31202 L
.20939 .312 L
.20982 .31195 L
.21018 .31188 L
.21058 .31179 L
.21129 .31159 L
.21205 .3113 L
.21288 .3109 L
.21457 .30982 L
.21612 .30853 L
.21779 .30686 L
.2211 .30318 L
.22275 .30147 L
.22355 .30075 L
.22428 .30019 L
.22504 .29972 L
.22539 .29955 L
.22576 .2994 L
.22595 .29934 L
.22615 .29928 L
.22634 .29924 L
.22652 .29922 L
.22662 .2992 L
.22672 .2992 L
.22681 .29919 L
.22691 .29919 L
.22697 .29919 L
.22702 .29919 L
.22708 .29919 L
.22713 .29919 L
.22723 .2992 L
.22734 .29921 L
.22744 .29923 L
.22753 .29925 L
.22773 .29929 L
.22792 .29935 L
.2281 .29942 L
.22851 .29961 L
.22894 .29988 L
.22982 .30066 L
.23063 .30165 L
.23214 .30417 L
Mistroke
.23379 .30793 L
.23702 .31746 L
.24013 .32708 L
.24094 .32921 L
.24183 .33121 L
.24223 .33198 L
.24266 .33269 L
.24304 .33321 L
.24344 .33364 L
.24364 .33382 L
.24387 .33398 L
.24397 .33403 L
.24407 .33409 L
.24417 .33413 L
.24426 .33415 L
.24432 .33417 L
.24438 .33418 L
.24444 .33419 L
.2445 .3342 L
.24456 .3342 L
.24462 .3342 L
.24468 .3342 L
.24473 .33419 L
.24483 .33417 L
.24489 .33416 L
.24494 .33414 L
.24504 .33411 L
.24516 .33405 L
.24537 .33393 L
.24559 .33374 L
.246 .33327 L
.24641 .33266 L
.24678 .33195 L
.24755 .33001 L
.24828 .32763 L
.24994 .32027 L
.25156 .31068 L
.25305 .3004 L
.25624 .27699 L
.25785 .26679 L
.25855 .26316 L
.25931 .25995 L
.25973 .25852 L
.26012 .25747 L
.2605 .25672 L
.26068 .25643 L
.26089 .25619 L
.261 .2561 L
.26106 .25606 L
.26111 .25603 L
Mistroke
.26121 .25598 L
.26131 .25596 L
.26141 .25596 L
.26147 .25596 L
.26153 .25598 L
.26159 .256 L
.26164 .25602 L
.26176 .2561 L
.26186 .25618 L
.26195 .25628 L
.26216 .25657 L
.26236 .25693 L
.26257 .25742 L
.263 .25868 L
.2634 .2602 L
.26429 .26488 L
.26507 .27045 L
.26591 .27774 L
.26895 .31452 L
.27219 .36112 L
.27368 .38002 L
.27447 .38831 L
.27531 .39541 L
.27577 .39846 L
.27619 .40063 L
.27639 .40147 L
.27661 .40221 L
.27682 .40276 L
.27701 .40313 L
.2771 .40326 L
.2772 .40337 L
.2773 .40343 L
.27738 .40346 L
.27749 .40346 L
.27754 .40344 L
.2776 .40341 L
.27769 .40333 L
.2778 .40321 L
.27789 .40305 L
.278 .40284 L
.27819 .40235 L
.27842 .40157 L
.27862 .40068 L
.27901 .39859 L
.27941 .39571 L
.28015 .38884 L
.28102 .37792 L
.28181 .36558 L
.28503 .29712 L
.28812 .22289 L
Mistroke
.28972 .19161 L
.29053 .17959 L
.29098 .17418 L
.29141 .17005 L
.2918 .16718 L
.29202 .16595 L
.29223 .16508 L
.2924 .16453 L
.2925 .16431 L
.29259 .16415 L
.29269 .16404 L
.29278 .16398 L
.29287 .16398 L
.29298 .16405 L
.29308 .16419 L
.29318 .16437 L
.29329 .16466 L
.29339 .165 L
.29358 .16578 L
.29378 .16687 L
.29423 .17034 L
.29466 .17473 L
.29543 .18583 L
.29616 .1996 L
.29782 .24189 L
.30093 .34824 L
.30252 .40436 L
.30336 .43142 L
.30425 .45687 L
.30512 .47731 L
.3059 .49133 L
.30628 .49639 L
.30648 .49859 L
.30669 .50054 L
.30688 .50193 L
.30708 .50312 L
.30717 .50353 L
.30727 .50389 L
.30736 .50416 L
.30744 .50433 L
.30753 .50447 L
.30762 .50451 L
.30772 .50449 L
.30782 .50436 L
.30793 .50413 L
.30798 .50398 L
.30804 .50378 L
.30824 .50289 L
.30842 .50172 L
.30862 .50013 L
Mistroke
.30897 .49636 L
.30942 .48993 L
.30985 .4822 L
.31064 .46355 L
.31225 .41067 L
.31373 .34829 L
.3169 .20117 L
.31849 .13801 L
.31919 .1159 L
.31994 .09666 L
.32036 .08846 L
.32075 .08248 L
.32111 .07829 L
.3213 .07674 L
.32151 .07549 L
.32161 .07504 L
.32167 .07485 L
.32172 .0747 L
.32182 .07452 L
.32192 .07445 L
.32198 .07447 L
.32204 .07452 L
.32214 .07471 L
.3222 .07487 L
.32225 .07505 L
.32237 .07559 L
.32256 .07676 L
.32277 .07853 L
.32298 .08091 L
.32318 .08363 L
.32358 .09036 L
.32402 .09975 L
.32481 .12209 L
.3263 .18021 L
.32956 .35194 L
.33107 .43197 L
.3327 .50348 L
.33314 .51858 L
.3336 .53233 L
.33403 .54291 L
.33442 .5508 L
.3348 .55641 L
.335 .55876 L
.3352 .56042 L
.3353 .56114 L
.3354 .56168 L
.33551 .56211 L
.33557 .56226 L
.33563 .56239 L
.33573 .56249 L
Mistroke
.33579 .56248 L
.33584 .56244 L
.33594 .56225 L
.33604 .56193 L
.33614 .56148 L
.33625 .56084 L
.33644 .55929 L
.33663 .55729 L
.33681 .55503 L
.33721 .54839 L
.33763 .53916 L
.33833 .51893 L
.3391 .49026 L
.34234 .31987 L
.34383 .23299 L
.34546 .14935 L
.34634 .11308 L
.34677 .09845 L
.34716 .08708 L
.34754 .07788 L
.34794 .07001 L
.34817 .06662 L
.34837 .0641 L
.34857 .06224 L
.34867 .0615 L
.34877 .06086 L
.34883 .06061 L
.34888 .06038 L
.34898 .06008 L
.34907 .05992 L
.34917 .05988 L
.34926 .05997 L
.34936 .06019 L
.34945 .06053 L
.34954 .06093 L
.34974 .0623 L
.34985 .06332 L
.34996 .06443 L
.35035 .06998 L
.35073 .07712 L
.35107 .08516 L
.35183 .10829 L
.35337 .17388 L
.35504 .2636 L
.35661 .35284 L
.35833 .441 L
.35912 .47395 L
.35997 .50209 L
.36038 .51272 L
.36077 .52084 L
Mistroke
.36112 .52648 L
.36132 .52895 L
.3615 .53078 L
.36159 .53154 L
.36169 .53222 L
.36178 .5327 L
.36187 .53311 L
.36197 .53342 L
.36206 .53359 L
.36212 .53364 L
.36217 .53364 L
.36227 .53355 L
.36236 .53336 L
.36245 .53305 L
.36253 .53269 L
.36262 .53219 L
.36281 .53073 L
.363 .52891 L
.36341 .52316 L
.36379 .51601 L
.36465 .4937 L
.36544 .46625 L
.36618 .43594 L
.36784 .35584 L
.36935 .27903 L
.37098 .20441 L
.37188 .17139 L
.37227 .15926 L
.3727 .14777 L
.37309 .1393 L
.37349 .13204 L
.37372 .12885 L
.37392 .12646 L
.37413 .12456 L
.37422 .12387 L
.37432 .12323 L
.37442 .12273 L
.37451 .12237 L
.3746 .12212 L
.37469 .12196 L
.37479 .12189 L
.37489 .12194 L
.37499 .1221 L
.37505 .12225 L
.3751 .12242 L
.37521 .12286 L
.3753 .12338 L
.37552 .12496 L
.37572 .12682 L
.37592 .12924 L
Mistroke
.37663 .141 L
.37703 .14992 L
.3774 .15961 L
.37903 .21434 L
.38052 .27533 L
.38218 .34432 L
.38291 .372 L
.38372 .39908 L
.38443 .41924 L
.38521 .43619 L
.38563 .4432 L
.38602 .44812 L
.38622 .45 L
.3864 .45143 L
.38658 .45258 L
.38668 .45305 L
.38679 .45344 L
.38689 .45371 L
.38694 .45382 L
.387 .45389 L
.3871 .45396 L
.38716 .45395 L
.38722 .45391 L
.38731 .45378 L
.38742 .45352 L
.38752 .45319 L
.38761 .45279 L
.38784 .45148 L
.38804 .44989 L
.3885 .44495 L
.3889 .43918 L
.38933 .4315 L
.39012 .41416 L
.39341 .31366 L
.39505 .26391 L
.39585 .24357 L
.39658 .22824 L
.39694 .22193 L
.39733 .2161 L
.39767 .21197 L
.39805 .2084 L
.39825 .2069 L
.39845 .20578 L
.39865 .2049 L
.39876 .20454 L
.39887 .2043 L
.39896 .20415 L
.39904 .20407 L
.39914 .20405 L
.39924 .2041 L
Mistroke
.39934 .20422 L
.39944 .20441 L
.39953 .20465 L
.39963 .20497 L
.39982 .20578 L
.40002 .20694 L
.40039 .20974 L
.40082 .21422 L
.40122 .21932 L
.40291 .24962 L
.4061 .32301 L
.40693 .3402 L
.40771 .35416 L
.40847 .36519 L
.40917 .37281 L
.40954 .37581 L
.40993 .37816 L
.41014 .37906 L
.41033 .37969 L
.41043 .37997 L
.41053 .38016 L
.41059 .38025 L
.41065 .38032 L
.4107 .38037 L
.41076 .38041 L
.41085 .38043 L
.41096 .3804 L
.41105 .38032 L
.41114 .38021 L
.41124 .38003 L
.41135 .37977 L
.41157 .37908 L
.41179 .37815 L
.41202 .37692 L
.41244 .37406 L
.41326 .36629 L
.41416 .3552 L
.41578 .33067 L
.41734 .3057 L
.41817 .29358 L
.41906 .28231 L
.41992 .27365 L
.4207 .26793 L
.42108 .26596 L
.42128 .26513 L
.42149 .26441 L
.42167 .26392 L
.42177 .26371 L
.42187 .26352 L
.42197 .26338 L
Mistroke
.42206 .26329 L
.42214 .26322 L
.42223 .26318 L
.42233 .26317 L
.42239 .26318 L
.42244 .2632 L
.42253 .26326 L
.42263 .26335 L
.42272 .26347 L
.42281 .2636 L
.423 .264 L
.4232 .26456 L
.42339 .26519 L
.42381 .26701 L
.42457 .27152 L
.42529 .27707 L
.42836 .30747 L
.42924 .31596 L
.43007 .323 L
.43088 .32865 L
.43123 .3307 L
.43162 .33262 L
.43197 .33407 L
.43235 .33529 L
.43256 .33582 L
.43276 .33621 L
.43295 .33651 L
.43313 .33671 L
.43322 .33679 L
.43333 .33685 L
.43338 .33687 L
.43343 .33688 L
.43354 .33689 L
.43363 .33688 L
.43373 .33684 L
.43382 .33679 L
.43391 .33672 L
.43402 .33661 L
.43413 .33648 L
.43435 .33613 L
.43476 .33521 L
.43515 .33405 L
.43556 .33252 L
.4363 .32915 L
.43797 .31947 L
.43956 .30951 L
.44102 .30154 L
.44182 .29808 L
.44258 .29556 L
.443 .29453 L
Mistroke
.44338 .2938 L
.4436 .29348 L
.44381 .29325 L
.44392 .29315 L
.44404 .29306 L
.44415 .29299 L
.44426 .29295 L
.44436 .29292 L
.44445 .29291 L
.44454 .29291 L
.44464 .29292 L
.44474 .29295 L
.44479 .29297 L
.44485 .29299 L
.44504 .29311 L
.44522 .29326 L
.44542 .29347 L
.44577 .29397 L
.44622 .2948 L
.44664 .29577 L
.44743 .298 L
.4505 .30883 L
.45138 .31171 L
.45221 .31402 L
.45295 .31567 L
.45334 .31635 L
.45376 .31696 L
.45396 .31719 L
.45417 .3174 L
.45435 .31755 L
.45455 .31769 L
.45467 .31775 L
.45478 .3178 L
.45488 .31783 L
.45494 .31785 L
.45499 .31786 L
.45509 .31788 L
.45518 .31789 L
.45524 .31789 L
.45529 .31789 L
.45539 .31788 L
.45549 .31787 L
.45557 .31785 L
.45567 .31782 L
.45577 .31779 L
.45593 .31771 L
.45611 .31761 L
.45652 .31729 L
.4569 .3169 L
.45768 .31584 L
Mistroke
.4584 .31461 L
.46006 .31135 L
.46155 .30844 L
.46234 .30711 L
.46318 .30595 L
.46364 .30543 L
.46406 .30505 L
.46448 .30475 L
.46488 .30454 L
.46507 .30447 L
.46518 .30443 L
.46528 .30441 L
.46537 .30439 L
.46546 .30437 L
.46555 .30436 L
.46565 .30435 L
.4657 .30435 L
.46576 .30434 L
.46586 .30434 L
.46591 .30435 L
.46596 .30435 L
.46602 .30435 L
.46608 .30436 L
.46618 .30437 L
.46629 .30439 L
.46649 .30444 L
.4667 .30451 L
.46689 .30459 L
.46726 .30477 L
.46808 .30534 L
.46955 .30673 L
.47102 .3083 L
.47186 .30915 L
.47264 .30986 L
.47348 .31049 L
.47424 .31092 L
.47466 .3111 L
.47505 .31123 L
.47527 .31128 L
.47547 .31132 L
.47569 .31135 L
.47581 .31136 L
.47587 .31137 L
.47593 .31137 L
.47603 .31137 L
.47612 .31138 L
.47617 .31138 L
.47623 .31138 L
.47632 .31137 L
.47643 .31137 L
Mistroke
.47652 .31136 L
.47663 .31135 L
.47674 .31134 L
.47709 .31128 L
.47729 .31124 L
.47748 .31119 L
.47829 .31092 L
.47915 .31053 L
.48074 .30969 L
.48246 .3088 L
.48326 .30846 L
.4837 .30831 L
.48412 .30818 L
.4845 .30808 L
.48492 .308 L
.48511 .30797 L
.4853 .30794 L
.48547 .30792 L
.48565 .3079 L
.48576 .30789 L
.48586 .30789 L
.48595 .30788 L
.48605 .30788 L
.48614 .30788 L
.48623 .30787 L
.48632 .30787 L
.48641 .30787 L
.48651 .30788 L
.48657 .30788 L
.48662 .30788 L
.48673 .30788 L
.48684 .30789 L
.48704 .3079 L
.48723 .30792 L
.48759 .30796 L
.48799 .30802 L
.4887 .30815 L
.49026 .30854 L
.49199 .30899 L
.49277 .30917 L
.49362 .30933 L
.49403 .30939 L
.49442 .30944 L
.4948 .30948 L
.49515 .30951 L
.49534 .30952 L
.49555 .30953 L
.49575 .30954 L
.49592 .30955 L
.49602 .30955 L
Mistroke
.49611 .30955 L
.49621 .30955 L
.49627 .30955 L
.49632 .30955 L
.49642 .30955 L
.49648 .30955 L
.49654 .30955 L
.49664 .30955 L
.49674 .30955 L
.49692 .30954 L
.49711 .30953 L
.49745 .30952 L
.49785 .30949 L
.49822 .30946 L
.49974 .3093 L
.50141 .30909 L
.50298 .30892 L
.50344 .30888 L
.50387 .30885 L
.50425 .30883 L
.50467 .30881 L
.50486 .3088 L
.50507 .30879 L
.50525 .30879 L
.50545 .30878 L
.50556 .30878 L
.50567 .30878 L
.50577 .30878 L
.50583 .30878 L
.50588 .30878 L
.50598 .30878 L
.50607 .30878 L
.50612 .30878 L
.50618 .30878 L
.50628 .30878 L
.50637 .30878 L
.50645 .30878 L
.50655 .30878 L
.50664 .30878 L
.50681 .30878 L
.50698 .30879 L
.50739 .3088 L
.50776 .30881 L
.50854 .30884 L
.50926 .30888 L
.51092 .30897 L
.51241 .30905 L
.51325 .30908 L
.51403 .3091 L
.51447 .30911 L
Mistroke
.51486 .30912 L
.51507 .30912 L
.51519 .30912 L
.51531 .30912 L
.51541 .30912 L
.51547 .30912 L
.51553 .30912 L
.51563 .30912 L
.51573 .30912 L
.51578 .30912 L
.51584 .30912 L
.51594 .30912 L
.516 .30912 L
.51605 .30912 L
.5161 .30912 L
.51617 .30912 L
.51627 .30912 L
.51638 .30912 L
.51658 .30912 L
.51694 .30911 L
.51735 .30911 L
.51817 .30909 L
.51892 .30908 L
.5206 .30904 L
.52142 .30902 L
.52228 .309 L
.52301 .30899 L
.52343 .30898 L
.52382 .30898 L
.524 .30898 L
.52421 .30898 L
.52441 .30898 L
.52459 .30897 L
.52479 .30897 L
.52491 .30897 L
.52501 .30897 L
.52511 .30897 L
.52521 .30897 L
.52531 .30897 L
.52541 .30897 L
.52551 .30897 L
.52559 .30897 L
.52569 .30897 L
.52578 .30897 L
.52595 .30897 L
.52613 .30897 L
.52653 .30898 L
.52691 .30898 L
.52768 .30898 L
.52841 .30899 L
Mistroke
.53006 .30901 L
.53155 .30902 L
.53239 .30903 L
.5328 .30903 L
.53318 .30903 L
.53338 .30903 L
.53361 .30903 L
.53379 .30903 L
.534 .30903 L
.53422 .30903 L
.53434 .30903 L
.5344 .30903 L
.53445 .30903 L
.53456 .30903 L
.53466 .30903 L
.53476 .30903 L
.53482 .30903 L
.53487 .30903 L
.53496 .30903 L
.53506 .30903 L
.53516 .30903 L
.53524 .30903 L
.53544 .30903 L
.53565 .30903 L
.53605 .30903 L
.53648 .30903 L
.53806 .30903 L
.53974 .30902 L
.54056 .30902 L
.54145 .30901 L
.54186 .30901 L
.5423 .30901 L
.54266 .30901 L
.54307 .30901 L
.54327 .30901 L
.54338 .30901 L
.54349 .30901 L
.5436 .30901 L
.5437 .30901 L
.54379 .30901 L
.54389 .30901 L
.54398 .30901 L
.54407 .30901 L
.54416 .30901 L
.54425 .30901 L
.54434 .30901 L
.54445 .30901 L
.54463 .30901 L
.54485 .30901 L
.54508 .30901 L
Mistroke
.54551 .30901 L
.54631 .30901 L
.54787 .30901 L
.5487 .30902 L
.54959 .30902 L
.55044 .30902 L
.55081 .30902 L
.55122 .30902 L
.55158 .30902 L
.55196 .30902 L
.55217 .30902 L
.55237 .30902 L
.55246 .30902 L
.55256 .30902 L
.55265 .30902 L
.55274 .30902 L
.55284 .30902 L
.55293 .30902 L
.55303 .30902 L
.55309 .30902 L
.55314 .30902 L
.55322 .30902 L
.55331 .30902 L
.55341 .30902 L
.5535 .30902 L
.55371 .30902 L
.55391 .30902 L
.55434 .30902 L
.55473 .30902 L
.55516 .30902 L
.55603 .30902 L
.55773 .30902 L
.55854 .30902 L
.55928 .30902 L
.56006 .30902 L
.56046 .30902 L
.56067 .30902 L
.56089 .30902 L
.56109 .30902 L
.56127 .30902 L
.56145 .30902 L
.56162 .30902 L
.56171 .30902 L
.56182 .30902 L
.56191 .30902 L
.562 .30902 L
.5621 .30902 L
.56216 .30902 L
.56221 .30902 L
.56231 .30902 L
Mistroke
.56242 .30902 L
.56251 .30902 L
.56262 .30902 L
.56281 .30902 L
.56318 .30902 L
.5636 .30902 L
.56399 .30902 L
.56546 .30902 L
.56709 .30902 L
.56789 .30902 L
.56862 .30902 L
.56933 .30902 L
.56969 .30902 L
.56989 .30902 L
.57008 .30902 L
.57028 .30902 L
.57037 .30902 L
.57047 .30902 L
.57058 .30902 L
.57067 .30902 L
.57078 .30902 L
.57084 .30902 L
.57089 .30902 L
.57099 .30902 L
.57108 .30902 L
.57117 .30902 L
.57126 .30902 L
.57136 .30902 L
.57146 .30902 L
.57165 .30902 L
.57208 .30902 L
.57248 .30902 L
.57337 .30902 L
.57499 .30902 L
.57579 .30902 L
.57664 .30902 L
.57705 .30902 L
.57744 .30902 L
.57779 .30902 L
.57817 .30902 L
.57854 .30902 L
.57874 .30902 L
.57893 .30902 L
.57911 .30902 L
.57927 .30902 L
.57936 .30902 L
.57945 .30902 L
.57955 .30902 L
.57963 .30902 L
.57973 .30902 L
Mistroke
.57979 .30902 L
.57984 .30902 L
.57993 .30902 L
.58004 .30902 L
.58021 .30902 L
.5804 .30902 L
.58083 .30902 L
.58122 .30902 L
.58285 .30902 L
.58434 .30902 L
.58509 .30902 L
.58587 .30902 L
.58629 .30902 L
.58674 .30902 L
.58694 .30902 L
.58715 .30902 L
.58736 .30902 L
.58754 .30902 L
.58773 .30902 L
.58784 .30902 L
.58794 .30902 L
.58803 .30902 L
.58812 .30902 L
.58821 .30902 L
.58831 .30902 L
.58841 .30902 L
.58846 .30902 L
.58852 .30902 L
.58861 .30902 L
.58871 .30902 L
.58892 .30902 L
.58915 .30902 L
.58957 .30902 L
.59003 .30902 L
.59084 .30902 L
.59245 .30902 L
.59329 .30902 L
.59418 .30902 L
.59457 .30902 L
.59498 .30902 L
.59522 .30902 L
.59544 .30902 L
.59566 .30902 L
.59586 .30902 L
.59604 .30902 L
.59624 .30902 L
.59634 .30902 L
.59644 .30902 L
.59654 .30902 L
.5966 .30902 L
Mistroke
.59665 .30902 L
.59674 .30902 L
.59683 .30902 L
.59692 .30902 L
.59702 .30902 L
.59712 .30902 L
.59722 .30902 L
.5974 .30902 L
.59759 .30902 L
.59777 .30902 L
.59818 .30902 L
.59901 .30902 L
.60049 .30902 L
.60199 .30902 L
.60239 .30902 L
.60283 .30902 L
.60321 .30902 L
.60361 .30902 L
.60383 .30902 L
.60403 .30902 L
.60423 .30902 L
.60442 .30902 L
.60463 .30902 L
.60474 .30902 L
.60486 .30902 L
.60491 .30902 L
.60498 .30902 L
.60504 .30902 L
.6051 .30902 L
.6052 .30902 L
.60525 .30902 L
.60531 .30902 L
.60537 .30902 L
.60542 .30902 L
.60552 .30902 L
.60562 .30902 L
.60572 .30902 L
.60592 .30902 L
.60615 .30902 L
.60656 .30902 L
.60693 .30902 L
.6086 .30902 L
.60934 .30902 L
.61014 .30902 L
.61087 .30902 L
.61165 .30902 L
.61208 .30902 L
.61247 .30902 L
.61266 .30902 L
.61287 .30902 L
Mistroke
.61296 .30902 L
.61306 .30902 L
.61315 .30902 L
.61324 .30902 L
.61334 .30902 L
.61343 .30902 L
.61353 .30902 L
.61358 .30902 L
.61363 .30902 L
.61374 .30902 L
.61379 .30902 L
.61385 .30902 L
.61405 .30902 L
.61422 .30902 L
.61441 .30902 L
.61479 .30902 L
.61566 .30902 L
.61647 .30902 L
.61796 .30902 L
.61875 .30902 L
.61958 .30902 L
.62005 .30902 L
.62047 .30902 L
.62067 .30902 L
.62089 .30902 L
.62109 .30902 L
.62128 .30902 L
.62138 .30902 L
.62148 .30902 L
.62157 .30902 L
.62166 .30902 L
.62176 .30902 L
.62182 .30902 L
.62187 .30902 L
.62197 .30902 L
.62207 .30902 L
.62217 .30902 L
.62227 .30902 L
.62246 .30902 L
.6229 .30902 L
.6233 .30902 L
.62367 .30902 L
.62451 .30902 L
.6262 .30902 L
.62705 .30902 L
.62747 .30902 L
.62785 .30902 L
.62819 .30902 L
.62857 .30902 L
.62894 .30902 L
Mistroke
.62915 .30902 L
.62934 .30902 L
.62944 .30902 L
.6295 .30902 L
.62955 .30902 L
.62964 .30902 L
.62974 .30902 L
.6298 .30902 L
.62985 .30902 L
.62995 .30902 L
.63001 .30902 L
.63006 .30902 L
.63018 .30902 L
.63028 .30902 L
.63038 .30902 L
.63056 .30902 L
.63097 .30902 L
.63169 .30902 L
.63246 .30902 L
.63403 .30902 L
.63485 .30902 L
.63531 .30902 L
.63575 .30902 L
.63615 .30902 L
.63637 .30902 L
.6366 .30902 L
.63681 .30902 L
.637 .30902 L
.6372 .30902 L
.63738 .30902 L
.63747 .30902 L
.63756 .30902 L
.63767 .30902 L
.63776 .30902 L
.63785 .30902 L
.63793 .30902 L
.63802 .30902 L
.63811 .30902 L
.63821 .30902 L
.63831 .30902 L
.63849 .30902 L
.63869 .30902 L
.63891 .30902 L
.63972 .30902 L
.64046 .30902 L
.64214 .30902 L
.64287 .30902 L
.64366 .30902 L
.64411 .30902 L
.64452 .30902 L
Mistroke
.64472 .30902 L
.64493 .30902 L
.64513 .30902 L
.64532 .30902 L
.64542 .30902 L
.64551 .30902 L
.6456 .30902 L
.64569 .30902 L
.6458 .30902 L
.64585 .30902 L
.6459 .30902 L
.646 .30902 L
.6461 .30902 L
.64619 .30902 L
.64628 .30902 L
.64645 .30902 L
.64683 .30902 L
.64724 .30902 L
.64762 .30902 L
.64848 .30902 L
.64998 .30902 L
.65077 .30902 L
.65161 .30902 L
.65204 .30902 L
.65226 .30902 L
.6525 .30902 L
.65272 .30902 L
.65293 .30902 L
.65302 .30902 L
.65313 .30902 L
.65322 .30902 L
.65332 .30902 L
.65338 .30902 L
.65343 .30902 L
.65353 .30902 L
.65363 .30902 L
.65373 .30902 L
.65378 .30902 L
.65383 .30902 L
.65393 .30902 L
.65399 .30902 L
.65405 .30902 L
.65416 .30902 L
.65435 .30902 L
.65453 .30902 L
.65494 .30902 L
.65571 .30902 L
.65644 .30902 L
.65724 .30902 L
.65809 .30902 L
Mistroke
.65886 .30902 L
.65927 .30902 L
.65971 .30902 L
.66011 .30902 L
.66048 .30902 L
.66066 .30902 L
.66085 .30902 L
.66094 .30902 L
.66103 .30902 L
.66111 .30902 L
.66119 .30902 L
.6613 .30902 L
.66139 .30902 L
.6615 .30902 L
.66156 .30902 L
.66161 .30902 L
.66171 .30902 L
.66182 .30902 L
.66201 .30902 L
.6622 .30902 L
.6624 .30902 L
.66276 .30902 L
.66443 .30902 L
.66525 .30902 L
.66603 .30902 L
.66673 .30902 L
.66709 .30902 L
.66748 .30902 L
.66788 .30902 L
.6681 .30902 L
.6683 .30902 L
.66849 .30902 L
.66866 .30902 L
.66875 .30902 L
.66885 .30902 L
.66896 .30902 L
.66905 .30902 L
.66916 .30902 L
.66922 .30902 L
.66927 .30902 L
.66937 .30902 L
.66942 .30902 L
.66948 .30902 L
.66968 .30902 L
.66987 .30902 L
.67028 .30902 L
.67073 .30902 L
.67232 .30902 L
.67316 .30902 L
.67405 .30902 L
Mistroke
.67484 .30902 L
.67529 .30902 L
.67549 .30902 L
.67571 .30902 L
.67589 .30902 L
.67609 .30902 L
.67618 .30902 L
.67628 .30902 L
.67637 .30902 L
.67645 .30902 L
.67655 .30902 L
.6766 .30902 L
.67666 .30902 L
.67676 .30902 L
.67681 .30902 L
.67686 .30902 L
.67696 .30902 L
.67705 .30902 L
.67715 .30902 L
.67724 .30902 L
.67745 .30902 L
.67765 .30902 L
.67801 .30902 L
.67883 .30902 L
.68031 .30902 L
.6811 .30902 L
.68192 .30902 L
.68226 .30902 L
.68263 .30902 L
.68303 .30902 L
.68341 .30902 L
.68361 .30902 L
.68373 .30902 L
.68383 .30902 L
.68392 .30902 L
.68402 .30902 L
.68407 .30902 L
.68413 .30902 L
.68422 .30902 L
.68428 .30902 L
.68433 .30902 L
.68439 .30902 L
.68444 .30902 L
.68454 .30902 L
.6846 .30902 L
.68465 .30902 L
.68487 .30902 L
.68499 .30902 L
.68511 .30902 L
.68551 .30902 L
Mistroke
.68595 .30902 L
.68673 .30902 L
.68831 .30902 L
.68921 .30902 L
.68964 .30902 L
.69004 .30902 L
.69043 .30902 L
.69064 .30902 L
.69085 .30902 L
.69104 .30902 L
.69113 .30902 L
.69124 .30902 L
.69133 .30902 L
.69142 .30902 L
.69151 .30902 L
.69159 .30902 L
.69168 .30902 L
.69179 .30902 L
.69184 .30902 L
.6919 .30902 L
.692 .30902 L
.6921 .30902 L
.6922 .30902 L
.69238 .30902 L
.69259 .30902 L
.69279 .30902 L
.69323 .30902 L
.69474 .30902 L
.69554 .30902 L
.69637 .30902 L
.6968 .30902 L
.69727 .30902 L
.69769 .30902 L
.69809 .30902 L
.6983 .30902 L
.6985 .30902 L
.69868 .30902 L
.69878 .30902 L
.69887 .30902 L
.69897 .30902 L
.69907 .30902 L
.69917 .30902 L
.69923 .30902 L
.69928 .30902 L
.69938 .30902 L
.69944 .30902 L
.69949 .30902 L
.6996 .30902 L
.69971 .30902 L
.69992 .30902 L
Mistroke
.70011 .30902 L
.70055 .30902 L
.70135 .30902 L
.70284 .30902 L
.7036 .30902 L
.70402 .30902 L
.70441 .30902 L
.70478 .30902 L
.70518 .30902 L
.70536 .30902 L
.70554 .30902 L
.70571 .30902 L
.70588 .30902 L
.70599 .30902 L
.70609 .30902 L
.7062 .30902 L
.70626 .30902 L
.70631 .30902 L
.70641 .30902 L
.70652 .30902 L
.70662 .30902 L
.70671 .30902 L
.70676 .30902 L
.70682 .30902 L
.70692 .30902 L
.70714 .30902 L
.70738 .30902 L
.7076 .30902 L
.70839 .30902 L
.70922 .30902 L
.71005 .30902 L
.71083 .30902 L
.71153 .30902 L
.71192 .30902 L
.71228 .30902 L
.71265 .30902 L
.71286 .30902 L
.71305 .30902 L
.71315 .30902 L
.71325 .30902 L
.71334 .30902 L
.71344 .30902 L
.71354 .30902 L
.71364 .30902 L
.71375 .30902 L
.7138 .30902 L
.71386 .30902 L
.71396 .30902 L
.71401 .30902 L
.71407 .30902 L
Mistroke
.71417 .30902 L
.71428 .30902 L
.71448 .30902 L
.71467 .30902 L
.71554 .30902 L
.71721 .30902 L
.71794 .30902 L
.71833 .30902 L
.71875 .30902 L
.71915 .30902 L
.71952 .30902 L
.7197 .30902 L
.71989 .30902 L
.72007 .30902 L
.72024 .30902 L
.72034 .30902 L
.72045 .30902 L
.72054 .30902 L
.72064 .30902 L
.7207 .30902 L
.72075 .30902 L
.7208 .30902 L
.72086 .30902 L
.72092 .30902 L
.72097 .30902 L
.72107 .30902 L
.72116 .30902 L
.72126 .30902 L
.72134 .30902 L
.72143 .30902 L
.72164 .30902 L
.72183 .30902 L
.72262 .30902 L
.72345 .30902 L
.72494 .30902 L
.7257 .30902 L
.72613 .30902 L
.72652 .30902 L
.72689 .30902 L
.72709 .30902 L
.72728 .30902 L
.72745 .30902 L
.72763 .30902 L
.72772 .30902 L
.72782 .30902 L
.72791 .30902 L
.728 .30902 L
.7281 .30902 L
.7282 .30902 L
.72828 .30902 L
Mistroke
.72838 .30902 L
.72848 .30902 L
.72859 .30902 L
.72879 .30902 L
.72914 .30902 L
.72952 .30902 L
.73119 .30902 L
.73199 .30902 L
.73276 .30902 L
.73318 .30902 L
.73364 .30902 L
.73384 .30902 L
.73405 .30902 L
.73424 .30902 L
.73444 .30902 L
.73463 .30902 L
.73473 .30902 L
.73483 .30902 L
.73492 .30902 L
.735 .30902 L
.7351 .30902 L
.73519 .30902 L
.73529 .30902 L
.73539 .30902 L
.73548 .30902 L
.73558 .30902 L
.7358 .30902 L
.736 .30902 L
.73637 .30902 L
.73671 .30902 L
.73747 .30902 L
.73827 .30902 L
.73913 .30902 L
.73986 .30902 L
.74028 .30902 L
.74067 .30902 L
.74104 .30902 L
.74123 .30902 L
.74144 .30902 L
.74161 .30902 L
.74171 .30902 L
.7418 .30902 L
.74189 .30902 L
.74198 .30902 L
.74207 .30902 L
.74215 .30902 L
.74224 .30902 L
.74234 .30902 L
.74243 .30902 L
.74251 .30902 L
Mistroke
.74261 .30902 L
.74272 .30902 L
.74292 .30902 L
.74335 .30902 L
.74374 .30902 L
.74525 .30902 L
.74604 .30902 L
.74688 .30902 L
.74731 .30902 L
.74754 .30902 L
.74778 .30902 L
.748 .30902 L
.74821 .30902 L
.74841 .30902 L
.7486 .30902 L
.7487 .30902 L
.7488 .30902 L
.74885 .30902 L
.74891 .30902 L
.74901 .30902 L
.7491 .30902 L
.7492 .30902 L
.74929 .30902 L
.74938 .30902 L
.74944 .30902 L
.74949 .30902 L
.74959 .30902 L
.74982 .30902 L
.75001 .30902 L
.75022 .30902 L
.75179 .30902 L
.75262 .30902 L
.75307 .30902 L
.75351 .30902 L
.75392 .30902 L
.75436 .30902 L
.75456 .30902 L
.75477 .30902 L
.75496 .30902 L
.75514 .30902 L
.75534 .30902 L
.75545 .30902 L
.75556 .30902 L
.75566 .30902 L
.75575 .30902 L
.75584 .30902 L
.75595 .30902 L
.75604 .30902 L
.75614 .30902 L
.75624 .30902 L
Mistroke
.75633 .30902 L
.75641 .30902 L
.75649 .30902 L
.75667 .30902 L
.75709 .30902 L
.75749 .30902 L
.75823 .30902 L
.75904 .30902 L
.75991 .30902 L
.76033 .30902 L
.76074 .30902 L
.76113 .30902 L
.76149 .30902 L
.76184 .30902 L
.76201 .30902 L
.7622 .30902 L
.7624 .30902 L
.7625 .30902 L
.7626 .30902 L
.76269 .30902 L
.76279 .30902 L
.76288 .30902 L
.76297 .30902 L
.76306 .30902 L
.76316 .30902 L
.76325 .30902 L
.76334 .30902 L
.76355 .30902 L
.76374 .30902 L
.76447 .30902 L
.76612 .30902 L
.76697 .30902 L
.76738 .30902 L
.76776 .30902 L
.7681 .30902 L
.76848 .30902 L
.76867 .30902 L
.76886 .30902 L
.76905 .30902 L
.76916 .30902 L
.76925 .30902 L
.76936 .30902 L
.76946 .30902 L
.76954 .30902 L
.76964 .30902 L
.76974 .30902 L
.76979 .30902 L
.76985 .30902 L
.76995 .30902 L
.77005 .30902 L
Mistroke
.77023 .30902 L
.7704 .30902 L
.77078 .30902 L
.77164 .30902 L
.77245 .30902 L
.77322 .30902 L
.77405 .30902 L
.77438 .30902 L
.77475 .30902 L
.77496 .30902 L
.77515 .30902 L
.77534 .30902 L
.77553 .30902 L
.77573 .30902 L
.77591 .30902 L
.77601 .30902 L
.7761 .30902 L
.7762 .30902 L
.77626 .30902 L
.77631 .30902 L
.77641 .30902 L
.7765 .30902 L
.7766 .30902 L
.77669 .30902 L
.77678 .30902 L
.77686 .30902 L
.77705 .30902 L
.77743 .30902 L
.77785 .30902 L
.77871 .30902 L
.77953 .30902 L
.78039 .30902 L
.78113 .30902 L
.78154 .30902 L
.78193 .30902 L
.78213 .30902 L
.78234 .30902 L
.78243 .30902 L
.78253 .30902 L
.78262 .30902 L
.78272 .30902 L
.78281 .30902 L
.78289 .30902 L
.78298 .30902 L
.78306 .30902 L
.78315 .30902 L
.78324 .30902 L
.78333 .30902 L
.78343 .30902 L
.78354 .30902 L
Mistroke
.78364 .30902 L
.78386 .30902 L
.78427 .30902 L
.78503 .30902 L
.78583 .30902 L
.78667 .30902 L
.78709 .30902 L
.78747 .30902 L
.78782 .30902 L
.7882 .30902 L
.78857 .30902 L
.78877 .30902 L
.78896 .30902 L
.78914 .30902 L
.7893 .30902 L
.78939 .30902 L
.78948 .30902 L
.78958 .30902 L
.78967 .30902 L
.78976 .30902 L
.78982 .30902 L
.78987 .30902 L
.78997 .30902 L
.79007 .30902 L
.79024 .30902 L
.79043 .30902 L
.79086 .30902 L
.79125 .30902 L
.79274 .30902 L
.79353 .30902 L
.79396 .30902 L
.79437 .30902 L
.79459 .30902 L
.79483 .30902 L
.79525 .30902 L
.79546 .30902 L
.79557 .30902 L
.79568 .30902 L
.79578 .30902 L
.79587 .30902 L
.79596 .30902 L
.79607 .30902 L
.79617 .30902 L
.79622 .30902 L
.79628 .30902 L
.79638 .30902 L
.79647 .30902 L
.79652 .30902 L
.79658 .30902 L
.79668 .30902 L
Mistroke
.7969 .30902 L
.79709 .30902 L
.79727 .30902 L
.79768 .30902 L
.79919 .30902 L
.79998 .30902 L
.80082 .30902 L
.80125 .30902 L
.80147 .30902 L
.80172 .30902 L
.80194 .30902 L
.80214 .30902 L
.80224 .30902 L
.80235 .30902 L
.80245 .30902 L
.80254 .30902 L
.80263 .30902 L
.80273 .30902 L
.80283 .30902 L
.80291 .30902 L
.80301 .30902 L
.80311 .30902 L
.80322 .30902 L
.80332 .30902 L
.80354 .30902 L
.80373 .30902 L
.80416 .30902 L
.80583 .30902 L
.80656 .30902 L
.80695 .30902 L
.80737 .30902 L
.80777 .30902 L
.80814 .30902 L
.80832 .30902 L
.80851 .30902 L
.80869 .30902 L
.80886 .30902 L
.80896 .30902 L
.80902 .30902 L
.80907 .30902 L
.80917 .30902 L
.80927 .30902 L
.80936 .30902 L
.80944 .30902 L
.80953 .30902 L
.80963 .30902 L
.80974 .30902 L
.80985 .30902 L
.81006 .30902 L
.81045 .30902 L
Mistroke
.81201 .30902 L
.81284 .30902 L
.81327 .30902 L
.81373 .30902 L
.81413 .30902 L
.81435 .30902 L
.81458 .30902 L
.81479 .30902 L
.81498 .30902 L
.81507 .30902 L
.81517 .30902 L
.81526 .30902 L
.81536 .30902 L
.81545 .30902 L
.81554 .30902 L
.81564 .30902 L
.81574 .30902 L
.81584 .30902 L
.8159 .30902 L
.81595 .30902 L
.81605 .30902 L
.81615 .30902 L
.81635 .30902 L
.81653 .30902 L
.81688 .30902 L
.81836 .30902 L
.8192 .30902 L
.81961 .30902 L
.81998 .30902 L
.82035 .30902 L
.82076 .30902 L
.82098 .30902 L
.82118 .30902 L
.82138 .30902 L
.82149 .30902 L
.82159 .30902 L
.82168 .30902 L
.82179 .30902 L
.82185 .30902 L
.8219 .30902 L
.822 .30902 L
.8221 .30902 L
.82219 .30902 L
.8223 .30902 L
.82239 .30902 L
.82244 .30902 L
.8225 .30902 L
.82262 .30902 L
.82282 .30902 L
.82328 .30902 L
Mistroke
.82498 .30902 L
.82578 .30902 L
.82652 .30902 L
.8269 .30902 L
.82729 .30902 L
.8275 .30902 L
.82769 .30902 L
.8279 .30902 L
.82802 .30902 L
.82813 .30902 L
.82822 .30902 L
.82831 .30902 L
.8284 .30902 L
.82848 .30902 L
.82858 .30902 L
.82868 .30902 L
.82878 .30902 L
.82887 .30902 L
.82905 .30902 L
.82925 .30902 L
.82965 .30902 L
.83134 .30902 L
.83214 .30902 L
.83289 .30902 L
.83326 .30902 L
.83365 .30902 L
.83388 .30902 L
.83409 .30902 L
.83428 .30902 L
.83439 .30902 L
.83448 .30902 L
.83457 .30902 L
.83467 .30902 L
.83476 .30902 L
.83484 .30902 L
.83493 .30902 L
.83503 .30902 L
.83513 .30902 L
.83522 .30902 L
.8354 .30902 L
.8356 .30902 L
.836 .30902 L
.83769 .30902 L
.83843 .30902 L
.83882 .30902 L
.83923 .30902 L
.83964 .30902 L
.84002 .30902 L
.8402 .30902 L
.84039 .30902 L
Mistroke
.84048 .30902 L
.84058 .30902 L
.84067 .30902 L
.84075 .30902 L
.84085 .30902 L
.84094 .30902 L
.84103 .30902 L
.84114 .30902 L
.84123 .30902 L
.84133 .30902 L
.84141 .30902 L
.84151 .30902 L
.84171 .30902 L
.84194 .30902 L
.84234 .30902 L
.84392 .30902 L
.84475 .30902 L
.84522 .30902 L
.84564 .30902 L
.84605 .30902 L
.84628 .30902 L
.84649 .30902 L
.84667 .30902 L
.84678 .30902 L
.84688 .30902 L
.84698 .30902 L
.84707 .30902 L
.84713 .30902 L
.84718 .30902 L
.84729 .30902 L
.84739 .30902 L
.84749 .30902 L
.84758 .30902 L
.84767 .30902 L
.84788 .30902 L
.84808 .30902 L
.84882 .30902 L
.84961 .30902 L
.85046 .30902 L
.85087 .30902 L
.85126 .30902 L
.85161 .30902 L
.85199 .30902 L
.85236 .30902 L
.85256 .30902 L
.85275 .30902 L
.85283 .30902 L
.85292 .30902 L
.853 .30902 L
.85309 .30902 L
Mistroke
.85318 .30902 L
.85326 .30902 L
.85336 .30902 L
.85345 .30902 L
.85355 .30902 L
.85365 .30902 L
.85374 .30902 L
.85384 .30902 L
.85406 .30902 L
.85427 .30902 L
.85504 .30902 L
.85653 .30902 L
.85694 .30902 L
.85737 .30902 L
.85775 .30902 L
.85816 .30902 L
.8584 .30902 L
.85862 .30902 L
.85883 .30902 L
.85893 .30902 L
.85905 .30902 L
.85915 .30902 L
.85925 .30902 L
.85934 .30902 L
.85943 .30902 L
.85954 .30902 L
.85964 .30902 L
.85969 .30902 L
.85974 .30902 L
.8598 .30902 L
.85986 .30902 L
.85996 .30902 L
.86006 .30902 L
.86026 .30902 L
.86063 .30902 L
.86147 .30902 L
.86235 .30902 L
.86318 .30902 L
.86354 .30902 L
.86393 .30902 L
.86413 .30902 L
.86435 .30902 L
.86453 .30902 L
.86473 .30902 L
.86494 .30902 L
.86504 .30902 L
.86514 .30902 L
.86523 .30902 L
.86534 .30902 L
.86543 .30902 L
Mistroke
.86552 .30902 L
.86562 .30902 L
.86567 .30902 L
.86573 .30902 L
.86583 .30902 L
.86592 .30902 L
.86598 .30902 L
.86603 .30902 L
.86613 .30902 L
.86636 .30902 L
.86673 .30902 L
.86708 .30902 L
.86787 .30902 L
.8686 .30902 L
.86938 .30902 L
.86982 .30902 L
.87023 .30902 L
.87043 .30902 L
.87064 .30902 L
.87085 .30902 L
.87103 .30902 L
.87124 .30902 L
.87135 .30902 L
.8714 .30902 L
.87146 .30902 L
.87156 .30902 L
.87165 .30902 L
.87171 .30902 L
.87176 .30902 L
.87186 .30902 L
.87195 .30902 L
.87205 .30902 L
.87213 .30902 L
.87222 .30902 L
.87242 .30902 L
.87261 .30902 L
.87343 .30902 L
.8743 .30902 L
.87513 .30902 L
.87591 .30902 L
.8763 .30902 L
.8765 .30902 L
.87672 .30902 L
.87696 .30902 L
.87707 .30902 L
.87718 .30902 L
.87729 .30902 L
.8774 .30902 L
.87751 .30902 L
.8776 .30902 L
Mistroke
.8777 .30902 L
.87776 .30902 L
.87781 .30902 L
.87791 .30902 L
.878 .30902 L
.87806 .30902 L
.87811 .30902 L
.87821 .30902 L
.87844 .30902 L
.87882 .30902 L
.87923 .30902 L
.88072 .30902 L
.88115 .30902 L
.88155 .30902 L
.88191 .30902 L
.88229 .30902 L
.88249 .30902 L
.88271 .30902 L
.88291 .30902 L
.8831 .30902 L
.88321 .30902 L
.88332 .30902 L
.88342 .30902 L
.88352 .30902 L
.88358 .30902 L
.88364 .30902 L
.8837 .30902 L
.88376 .30902 L
.88386 .30902 L
.88392 .30902 L
.88397 .30902 L
.88408 .30902 L
.88417 .30902 L
.88435 .30902 L
.88455 .30902 L
.88476 .30902 L
.88549 .30902 L
.88627 .30902 L
.88714 .30902 L
.88754 .30902 L
.88796 .30902 L
.88836 .30902 L
.88873 .30902 L
.88894 .30902 L
.88912 .30902 L
.88923 .30902 L
.88933 .30902 L
.88939 .30902 L
.88945 .30902 L
.8895 .30902 L
Mistroke
.88955 .30902 L
.88966 .30902 L
.88975 .30902 L
.88986 .30902 L
.88992 .30902 L
.88997 .30902 L
.89008 .30902 L
.8902 .30902 L
.89042 .30902 L
.89085 .30902 L
.89125 .30902 L
.892 .30902 L
.89282 .30902 L
.89327 .30902 L
.89369 .30902 L
.89406 .30902 L
.89446 .30902 L
.89468 .30902 L
.8949 .30902 L
.89509 .30902 L
.8952 .30902 L
.8953 .30902 L
.89539 .30902 L
.89548 .30902 L
.89556 .30902 L
.89564 .30902 L
.89573 .30902 L
.89583 .30902 L
.89593 .30902 L
.89602 .30902 L
.89621 .30902 L
.89639 .30902 L
.89678 .30902 L
.89846 .30902 L
.89919 .30902 L
.89961 .30902 L
.9 .30902 L
.90019 .30902 L
.90038 .30902 L
.90054 .30902 L
.90072 .30902 L
.90082 .30902 L
.90092 .30902 L
.90101 .30902 L
.9011 .30902 L
.9012 .30902 L
.90125 .30902 L
.9013 .30902 L
.9014 .30902 L
.9015 .30902 L
Mistroke
.90155 .30902 L
.90161 .30902 L
.90171 .30902 L
.90181 .30902 L
.9019 .30902 L
.90211 .30902 L
.90232 .30902 L
.90309 .30902 L
.9039 .30902 L
.90468 .30902 L
.90537 .30902 L
.90576 .30902 L
.90613 .30902 L
.90633 .30902 L
.90653 .30902 L
.9067 .30902 L
.90688 .30902 L
.90698 .30902 L
.90709 .30902 L
.90714 .30902 L
.9072 .30902 L
.9073 .30902 L
.90741 .30902 L
.9075 .30902 L
.90759 .30902 L
.90769 .30902 L
.90789 .30902 L
.90811 .30902 L
.90856 .30902 L
.90936 .30902 L
.91012 .30902 L
.91092 .30902 L
.91134 .30902 L
.91156 .30902 L
.91179 .30902 L
.91201 .30902 L
.91221 .30902 L
.91241 .30902 L
.91259 .30902 L
.91269 .30902 L
.91279 .30902 L
.91288 .30902 L
.91297 .30902 L
.91307 .30902 L
.91312 .30902 L
.91318 .30902 L
.91327 .30902 L
.91337 .30902 L
.91343 .30902 L
.91348 .30902 L
Mistroke
.9136 .30902 L
.91381 .30902 L
.9142 .30902 L
.91568 .30902 L
.91642 .30902 L
.91682 .30902 L
.9172 .30902 L
.91741 .30902 L
.91765 .30902 L
.91784 .30902 L
.91806 .30902 L
.91826 .30902 L
.91837 .30902 L
.91847 .30902 L
.91857 .30902 L
.91866 .30902 L
.91876 .30902 L
.91886 .30902 L
.91896 .30902 L
.91901 .30902 L
.91907 .30902 L
.91916 .30902 L
.91926 .30902 L
.91944 .30902 L
.91963 .30902 L
.92005 .30902 L
.92045 .30902 L
.92192 .30902 L
.92233 .30902 L
.92276 .30902 L
.92318 .30902 L
.92337 .30902 L
.92356 .30902 L
.92374 .30902 L
.9239 .30902 L
.92408 .30902 L
.92418 .30902 L
.92428 .30902 L
.92437 .30902 L
.92447 .30902 L
.92456 .30902 L
.92465 .30902 L
.92474 .30902 L
.9248 .30902 L
.92485 .30902 L
.92495 .30902 L
.92505 .30902 L
.92525 .30902 L
.92544 .30902 L
.9258 .30902 L
Mistroke
.92662 .30902 L
.92739 .30902 L
.92809 .30902 L
.92846 .30902 L
.92886 .30902 L
.92908 .30902 L
.92928 .30902 L
.92949 .30902 L
.92968 .30902 L
.92984 .30902 L
.92994 .30902 L
.93002 .30902 L
.93011 .30902 L
.93021 .30902 L
.93031 .30902 L
.9304 .30902 L
.93049 .30902 L
.93057 .30902 L
.93067 .30902 L
.93077 .30902 L
.93097 .30902 L
.93116 .30902 L
.93281 .30902 L
.93361 .30902 L
.93399 .30902 L
.93434 .30902 L
.93471 .30902 L
.93489 .30902 L
.9351 .30902 L
.93528 .30902 L
.93545 .30902 L
.93554 .30902 L
.93563 .30902 L
.93573 .30902 L
.93582 .30902 L
.93591 .30902 L
.93601 .30902 L
.93612 .30902 L
.93621 .30902 L
.93631 .30902 L
.93639 .30902 L
.93658 .30902 L
.93677 .30902 L
.93698 .30902 L
.9374 .30902 L
.93828 .30902 L
.93911 .30902 L
.93985 .30902 L
.94027 .30902 L
.94045 .30902 L
Mistroke
.94065 .30902 L
.94085 .30902 L
.94103 .30902 L
.94111 .30902 L
.94121 .30902 L
.9413 .30902 L
.94138 .30902 L
.94148 .30902 L
.94158 .30902 L
.94168 .30902 L
.94174 .30902 L
.94179 .30902 L
.94188 .30902 L
.94198 .30902 L
.94208 .30902 L
.94217 .30902 L
.94238 .30902 L
.94258 .30902 L
.94295 .30902 L
.94379 .30902 L
.94456 .30902 L
.94499 .30902 L
.94538 .30902 L
.94575 .30902 L
.94609 .30902 L
.94627 .30902 L
.94646 .30902 L
.94665 .30902 L
.94676 .30902 L
.94686 .30902 L
.94697 .30902 L
.94702 .30902 L
.94707 .30902 L
.94717 .30902 L
.94727 .30902 L
.94733 .30902 L
.94738 .30902 L
.94748 .30902 L
.94754 .30902 L
.94759 .30902 L
.94771 .30902 L
.94791 .30902 L
.94809 .30902 L
.94851 .30902 L
.95 .30902 L
.95039 .30902 L
.95081 .30902 L
.95116 .30902 L
.95155 .30902 L
.95176 .30902 L
Mistroke
.95196 .30902 L
.95216 .30902 L
.95234 .30902 L
.95245 .30902 L
.95256 .30902 L
.95266 .30902 L
.95276 .30902 L
.95282 .30902 L
.95288 .30902 L
.95294 .30902 L
.953 .30902 L
.9531 .30902 L
.95316 .30902 L
.95322 .30902 L
.95343 .30902 L
.95363 .30902 L
.95407 .30902 L
.95487 .30902 L
.95559 .30902 L
.95636 .30902 L
.95677 .30902 L
.95714 .30902 L
.95732 .30902 L
.95751 .30902 L
.9577 .30902 L
.95787 .30902 L
.95796 .30902 L
.95807 .30902 L
.95816 .30902 L
.95825 .30902 L
.95835 .30902 L
.9584 .30902 L
.95846 .30902 L
.95856 .30902 L
.95862 .30902 L
.95867 .30902 L
.95878 .30902 L
.95888 .30902 L
.95911 .30902 L
.95953 .30902 L
.96031 .30902 L
.96116 .30902 L
.96157 .30902 L
.96196 .30902 L
.96234 .30902 L
.96269 .30902 L
.96286 .30902 L
.96305 .30902 L
.96325 .30902 L
.96334 .30902 L
Mistroke
.96344 .30902 L
.96353 .30902 L
.96362 .30902 L
.96372 .30902 L
.96381 .30902 L
.9639 .30902 L
.96398 .30902 L
.96406 .30902 L
.96414 .30902 L
.96424 .30902 L
.96433 .30902 L
.96454 .30902 L
.96475 .30902 L
.96497 .30902 L
.96573 .30902 L
.96656 .30902 L
.96734 .30902 L
.96773 .30902 L
.96815 .30902 L
.96839 .30902 L
.96861 .30902 L
.96881 .30902 L
.96893 .30902 L
.96903 .30902 L
.96913 .30902 L
.96923 .30902 L
.96931 .30902 L
.96941 .30902 L
.96951 .30902 L
.96957 .30902 L
.96962 .30902 L
.96972 .30902 L
.96981 .30902 L
.96999 .30902 L
.97016 .30902 L
.97054 .30902 L
.9714 .30902 L
.9722 .30902 L
.97293 .30902 L
.97334 .30902 L
.97371 .30902 L
.97393 .30902 L
.97412 .30902 L
.97434 .30902 L
.97445 .30902 L
.97457 .30902 L
.97467 .30902 L
.97477 .30902 L
.97482 .30902 L
.97488 .30902 L
Mistroke
.97498 .30902 L
.97508 .30902 L
.97519 .30902 L
.97528 .30902 L
.97537 .30902 L
.97558 .30902 L
.97577 .30902 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{421.375, 260.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008>0001AB000`400?l00000o`00003ooooooooo
oooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo
003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooo
oooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool0
0?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooooooo
ool@ooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooo
ooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo0ol0003o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0
003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo
00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`
ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLoooo
o`00<?ooool3o`000?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?oo
ool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0
033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomco
oooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooo
oooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
06Gooooo00?o0000ooooooooool0oooooomdooooo`00<?ooool00ol0003oooooooooo`1Tooooo`;o
0000oooooomfooooo`00<?ooool3o`0006Cooooo0_l0003oooooogKooooo000`ooooo`03o`000?oo
oooooooo06Cooooo0_l0003oooooogKooooo000`ooooo`03o`000?oooooooooo06Cooooo0_l0003o
ooooogKooooo000`ooooo`03o`000?oooooooooo06Cooooo0_l0003oooooogKooooo000`ooooo`03
o`000?oooooooooo05Wooooo00?o0000ooooooooool02?ooool2o`000?ooooooM_ooool0033ooooo
00?o0000ooooooooool0FOooool00ol0003oooooooooo`08ooooo`;o0000oooooomfooooo`00<?oo
ool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo00Sooooo0_l0003oooooogKooooo000@
ooooo`;ok^k^0oooool2onk^kQWooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`08
ooooo`;o0000oooooomfooooo`002oooool2o`00000:oa0@4?ooooooooooonk^k_mEEEGok^k^oooo
ooo^k^koEEEEonk^kP?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^2_oo
ool00ol0003oooooooooo`1Hooooo`;o00002_ooool00ol0003oooooo`00003oooooogGooooo000<
ooooo`03o`000?oooooooooo00;ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0:ooooo`03o`000?oooooooooo05Sooooo
0_l0000:ooooo`03o`000?oooooo00000?ooooooMOooool00003ooooool0003o000000Co00000_oo
ool5o`0000Cooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?oo
ooooooooooooool@41002_ooool00ol0003oooooooooo`1Hooooo`03o`000?oooooo000000Wooooo
00?o0000ooooool00000oooooomeooooo`002Oooool01?m4A4CogMgMooooool00004ooooo`05onk^
k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000002_ooool00ol0003oooooooooo`1Hooooo`03o`000?oooooo000000Wooooo00?o0000oooo
ool00000oooooomeooooo`002Oooool01?oMgMgoEEEEooooool00003ooooo`07onk^k_mEEEGok^k^
ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000:ooooo`Co0000Eoooool00ol0003oooooo`000009ooooo`03o`000?oooooo00000?oooooo
MOooool000[ooooo00?oMgMgolc<c?l000000oooool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oo
oooooooo00;ooooo00Go410@oooooooooooooooooa0@400:ooooo`03o`000?oooooooooo05Sooooo
00?o0000ooooool000002Oooool00ol0003oooooo`00003oooooogGooooo000:ooooo`03onk^k_m4
A4Co000000oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo
0_l00005ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooool000002Oooool00ol0003ooooo
o`00003oooooogGooooo000;ooooo`03ogMgMol0003ooooo00cooooo00?oEEEEofIVI_l000001?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`1Hooooo`03o`000?oooooo000000Wooooo00?o0000ooooool00000oooooomeooooo`00
:?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooool0
00002Oooool00ol0003oooooo`00003oooooogGooooo000Xooooo`?o00001Oooool00ol0003ooooo
ooooo`1Hooooo`03o`000?oooooo000000Wooooo00?o0000ooooool00000oooooomeooooo`00:Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooool000002Ooo
ool00ol0003oooooo`00003oooooogGooooo000Zooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0F?ooool00ol0003oooooo`000009ooooo`03o`000?oooooo00000?ooooooMOooool0
033ooooo00?o0000ooooooooool0F?ooool00ol0003oooooo`000009ooooo`03o`000?oooooo0000
0?ooooooMOooool0033ooooo00?o0000ooooooooool0F?ooool00ol0003oooooo`000009ooooo`03
o`000?oooooo00000?ooooooMOooool0033ooooo00?o0000ooooooooool0F?ooool00ol0003ooooo
o`000009ooooo`03o`000?oooooo00000?ooooooMOooool0033ooooo00?o0000ooooooooool0F?oo
ool00ol0003oooooo`000009ooooo`03o`000?oooooo00000?ooooooMOooool0033ooooo0ol0001H
ooooo`03o`000?oooooo000000Wooooo00?o0000ooooool00000oooooomeooooo`00<?ooool00ol0
003oooooooooo`1Hooooo`03o`000?oooooo000000Wooooo00?o0000ooooool000002Oooool00ol0
003oooooooooo`3oooooofWooooo000`ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooool0
00002Oooool00ol0003oooooo`000009ooooo`03o`000?oooooooooo0?ooooooJOooool0033ooooo
00?o0000ooooooooool0F?ooool00ol0003oooooo`000009ooooo`03o`000?oooooo000000Sooooo
0_l0003oooooof_ooooo000`ooooo`03o`000?oooooooooo05Oooooo00Co0000oooooooooooo0000
2Oooool00ol0003oooooo`000008ooooo`;o0000oooooom[ooooo`00<?ooool00ol0003ooooooooo
o`1Gooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooool000002?ooool2o`000?oooooo
Joooool0033ooooo00?o0000ooooooooool0Eoooool01?l0003oooooooooool00008ooooo`04o`00
0?ooooooooooo`0000Sooooo0_l0003oooooof_ooooo000`ooooo`03o`000?oooooooooo05Oooooo
00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo0000
0?ooooooJ_ooool0033ooooo00?o0000ooooooooool0Eoooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooomZooooo`00<?ooool00ol0
003oooooooooo`1Gooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002?oo
ool00ol0003oooooo`00003oooooof[ooooo000`ooooo`03o`000?oooooooooo05Oooooo00Co0000
oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooool00000
oooooomZooooo`00<?ooool00ol0003oooooooooo`1Gooooo`04o`000?ooooooooooo`0000Sooooo
00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?ooooooJ_ooool0033ooooo
0ol0001Gooooo`04o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000007oooo
o`03o`000?oooooo00000?ooooooJ_ooool0033ooooo00?o0000ooooooooool0Eoooool01?l0003o
ooooooooool00008ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003o
ooooof[ooooo000`ooooo`03o`000?oooooooooo05Oooooo00Go0000ooooooooooooooooo`000007
ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003oooooof[ooooo000`
ooooo`03o`000?oooooooooo05Oooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oo
ooooooooooooool000001oooool00ol0003oooooo`00003oooooof[ooooo000`ooooo`03o`000?oo
oooooooo05Oooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool0
00001oooool00ol0003oooooo`00003oooooof[ooooo000`ooooo`03o`000?oooooooooo05Oooooo
00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool00ol0
003oooooo`00003oooooof[ooooo000`ooooo`03o`000?oooooooooo05Oooooo00Go0000oooooooo
ooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003o
ooooof[ooooo000`ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool02?ooool01Ol0
003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oo
oooo00000?ooooooJ_ooool0033ooooo00?o0000ooooooooool0C?ooool2o`0000Wooooo00Go0000
ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool00ol0003ooooo
o`00003oooooof[ooooo000`ooooo`03o`000?oooooooooo04cooooo0_l00009ooooo`05o`000?oo
ooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooool0
0000oooooomZooooo`00<?ooool00ol0003oooooooooo`1<ooooo`;o00002Oooool01Ol0003ooooo
oooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo0000
0?ooooooJ_ooool0033ooooo0ol0001<ooooo`;o00002Oooool01Ol0003ooooooooooooooooo0000
00Oooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?ooooooJ_ooool0
033ooooo00?o0000ooooooooool0Boooool00ol0003oooooo`000009ooooo`05o`000?oooooooooo
ooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooool00000oooo
oomZooooo`00<?ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooo000000Wooooo00Go0000
ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool00ol0003ooooo
o`00003oooooof[ooooo000`ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooool000002Ooo
ool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`03
o`000?oooooo00000?ooooooJ_ooool0033ooooo00?o0000ooooooooool0Boooool00ol0003ooooo
o`000009ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo0000
00Oooooo00?o0000ooooool00000oooooomZooooo`00<?ooool00ol0003oooooooooo`1;ooooo`03
o`000?oooooo000000Wooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooooooo
ooooool000001oooool00ol0003oooooo`00003oooooof[ooooo000`ooooo`03o`000?oooooooooo
04_ooooo00?o0000ooooool000002Oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000
ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?ooooooJ_ooool0013ooooo0_o^k^h3
ooooo`;ok^k^6Oooool00ol0003oooooooooo`1;ooooo`03o`000?oooooo000000Wooooo00Go0000
ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool01?l0003ooooo
ooooool0003oooooofWooooo0009ooooo`Go00000_ooool01oo^k^koEEEEonk^k_ooooook^k^oeEE
EOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h:ooooo`03o`00
0?oooooooooo04_ooooo00?o0000ooooool000002Oooool01Ol0003ooooooooooooooooo000000Oo
oooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool00000oooooomY
ooooo`002Oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^
kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0:ooooo`03o`00
0?oooooooooo04_ooooo00?o0000ooooool000002Oooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooooooo
ool00000oooooomYooooo`0000?oooooo`000?l000001?l00003ooooo`03oiRHV?lQ8B7ok^k^00Go
oooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooo
ool@41002_ooool00ol0003oooooooooo`1;ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool01Ol0003ooooooooooooooooo00000?ooooooJOooool000_ooooo00?oV9RHob4Q8Oo^k^h00ooo
ool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000[ooooo00?o0000ooooooooool0Boooool01?l0003oooooooooool00008oooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00Go0000ooooooooooooooooo`00003oooooofWooooo000<ooooo`0;ogMgMomVIVKo
ooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000002_ooool4o`0004[ooooo00Co0000oooooooooooo00002?oo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`04ooooo`05o`000?ooooooooooooooool00000oooooomYooooo`003Oooool00ol0003ooooo
ooooo`02onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@400:ooooo`03o`000?oooooooooo04_ooooo00Co0000oooooooooooo00002?ooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`05o`000?ooooooooooooooool00000oooooomYooooo`002Oooool01Ol0003o^[ZjoooooonH
V9So410@00kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo
0_l00005ooooo`03o`000?oooooooooo04_ooooo00Co0000oooooooooooo00002?ooool01Ol0003o
oooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04oooo
o`05o`000?ooooooooooooooool000001oooool2o`000?ooooooH?ooool000Wooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP02ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0Boooool01?l0003ooooo
ooooool00008ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000007ooooo`;o0000oooooomP
ooooo`00:?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo04[ooooo00Go0000
ooooooooooooooooo`000008ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000007ooooo`;o
0000oooooomPooooo`00:?ooool3o`0000Gooooo00?o0000ooooooooool0B_ooool01Ol0003ooooo
oooooooooooo000000Sooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Oooooo0_l0003o
ooooof3ooooo000Yooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0B_ooool01Ol0
003ooooooooooooooooo000000Sooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Oooooo
0_l0003oooooof3ooooo000Zooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0B_oo
ool01Ol0003ooooooooooooooooo000000Sooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000
00Oooooo0_l0003oooooof3ooooo000`ooooo`03o`000?oooooooooo04[ooooo00Go0000oooooooo
ooooooooo`000008ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000007ooooo`;o0000oooo
oomPooooo`00<?ooool00ol0003oooooooooo`1:ooooo`05o`000?ooooooooooooooool000002?oo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooo`00003oooooof3o
oooo000`ooooo`03o`000?oooooooooo04[ooooo00Go0000ooooooooooooooooo`000008ooooo`05
o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo00000?ooooooH?ooool0
033ooooo00?o0000ooooooooool0B_ooool01Ol0003ooooooooooooooooo000000Sooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooool00000oooooomPooooo`00<?oo
ool3o`0004[ooooo00Go0000ooooooooooooooooo`000008ooooo`05o`000?ooooooooooooooool0
00001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooo
ooooooooo`000006ooooo`03o`000?oooooo00000?ooooooH?ooool0033ooooo00?o0000oooooooo
ool0B_ooool01Ol0003ooooooooooooooooo000000Sooooo00Go0000ooooooooooooooooo`000006
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooo
oooo000000Kooooo00?o0000ooooool00000oooooomPooooo`00<?ooool00ol0003oooooooooo`1:
ooooo`05o`000?ooooooooooooooool000002?ooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool0
00001_ooool00ol0003oooooo`00003oooooof3ooooo000`ooooo`03o`000?oooooooooo04[ooooo
00Go0000ooooooooooooooooo`000008ooooo`05o`000?ooooooooooooooool000001_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006
ooooo`03o`000?oooooo00000?ooooooH?ooool0033ooooo00?o0000ooooooooool0B_ooool01Ol0
003ooooooooooooooooo000000Sooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo
00Co0000oooooooooooo0000oooooomOooooo`00<?ooool00ol0003oooooooooo`1:ooooo`05o`00
0?ooooooooooooooool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooooooo
ool000001_ooool01?l0003oooooooooool0003ooooooeoooooo000`ooooo`03o`000?oooooooooo
04[ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000
ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`000?ooooooGoooool0033ooooo00?o
0000ooooooooool0B_ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo
0000oooooomOooooo`00<?ooool00ol0003oooooooooo`1:ooooo`05o`000?ooooooooooooooool0
00001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool01?l0003oooooooooool0003ooooooeoooooo000`ooooo`03o`000?oooooooooo04[o
oooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`000?ooooooGoooool0
033ooooo00?o0000ooooooooool0B_ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Co0000
oooooooooooo0000oooooomOooooo`00<?ooool00ol0003oooooooooo`1:ooooo`05o`000?oooooo
ooooooooool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool01?l0003oooooooooool0003ooooooeoooooo000`ooooo`?o0000?_oo
ool2o`0000[ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`000?oo
ooooGoooool0033ooooo00?o0000ooooooooool0?_ooool2o`0000[ooooo00Go0000oooooooooooo
ooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`04o`000?ooooooooooo`000?ooooooGoooool0033ooooo00?o0000oooooooo
ool0?_ooool2o`0000[ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`04o`000?oooooooooo
o`000?ooooooGoooool0033ooooo00?o0000ooooooooool0?Oooool00ol0003oooooo`000009oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00007
ooooo`;o0000oooooomFooooo`00<?ooool00ol0003oooooooooo`0mooooo`04o`000?oooooooooo
o`0000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`04o`000?oooooo
ooooo`0000Oooooo0_l0003ooooooeKooooo000`ooooo`03o`000?oooooooooo03gooooo00Co0000
oooooooooooo00002?ooool00ol0003oooooooooo`02ooooo`03o`000?o^k^kooooo00;ooooo0_o^
k^h00ooooooo0000ooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool01?l0003oooooooooool00007ooooo`;o00009_ooool2onk^kP?ooooo0_o^k^iPooooo`;ok^k^
0oooool2onk^kTkooooo0_o^k^h3ooooo`;ok^k^K?ooool0033ooooo00?o0000ooooooooool0?Ooo
ool01?l0003oooooooooool00007ooooo`0@odA4A?l0003o0000oc8b<_oMgMgoooooonk^k_l0003o
k^k^ooooooo^k^koEEEEonk^k_oooooo0000ooooo`Go00000_ooool01Oo^k^ko<S8bo`000?l0003o
k^k^00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00Co0000oooooooooooo00001oooool2o`00023ooooo1?l000002Ol@413oooooonk^
k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0
003o<S8bonk^kS_ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool03Om4A4Co0000
o`000?lb<S;ogMgMooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@
4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hhooooo`Go00000_ooool01oo^k^koEEEEonk^k_oo
ooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^iM
ooooo`00<?ooool00ol0003oooooooooo`0mooooo`04o`000?ooooooooooo`0000Sooooo00Co0000
oooooomgMgOo<S8b0_ooool01Ol0003oEEEEomgMgOmEEEGok^k^00;ooooo00Oo0000oooooooooooo
ooooo`000?oooooo000000;ooooo00GoMgMgoiRHV?oooooo0000ogMgM`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`04o`000?oooooo
ooooo`0000Kooooo00?o0000ooooool000008_ooool00ol0003oooooooooo`02ooooo`05onk^k_mE
EEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL0?Oooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool02OmgMgOo<S8booooooooooook^k^
oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0hooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01Oo^k^koEEEEomgMgOmEEEGok^k^
00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg05gooooo000`oooo
o`03o`000?oooooooooo03cooooo00Go0000ooooooooooooooooo`000008ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000omgMgOl0003ogMgM0oooool01ol0003ooooooooooooooooo0000oooo
ool000000_ooool01Ol@413oooooooooool0003o410@00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00001_oo
ool00ol0003oooooo`00000Rooooo`03o`000?oooooooooo00?ooooo00?ogMgMo`000?oMgMd01ooo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100?Oooool00ol0003ooooo
ooooo`0?ooooo`07o`000?oooooooooooooooooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo
00;ooooo00Go410@oooooooooooooooooa0@400iooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?ogMgM
o`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100GOoo
ool0033ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Gooooo00Co0000oooooomgMgOo<S8b0_ooool01Ol0003oEEEEomgMgOmEEEGok^k^00;ooooo
00Oo0000ooooooooooooooooo`000?oooooo000000;ooooo00?o0000ooooooooool00_l00003oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04oooo
o`04o`000?ooooooooooo`0000Kooooo00Co0000oooooooooooo00008Oooool00ol0003ooooooooo
o`02ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000?Oooool00ol0003oooooooooo`0>ooooo`09ogMgMolb<S;ooooooooo
ooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000003[ooooo00?oV9RHob4Q8Oo^k^h00oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Ko
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000005gooooo000`ooooo`03
o`000?oooooooooo03cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`?o
000000co<S8bolc<c?ooooook^k^o`000?o^k^koooooonk^k_mEEEGok^k^ooooool00003ooooo`03
o`000?oooooo000000;ooooo00?o0000ooooooooool00_l00003ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`00
00Kooooo00Co0000oooooooooooo00008Oooool02ol0003oooooooooooooooook^k^oeEEEOo^k^ko
ooooonk^k_mEEEGok^k^00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo
000003gooooo00?o0000ooooooooool02oooool03Ol0003o8B4Qo`000?lb<S;oc<c<ooooooo^k^ko
EEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool00000>oooool02omgMgOoIVIVooooooooooook^k^oeEEEOo^k^koooooonk^k_mEEEGo
k^k^00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000005gooooo000`
ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`;o00001?ooool00oo^k^ko0000ooooo`02ooooo`;ok^k^00?oooooo`000?ooool00_ooool0
0ol0003oooooo`000002ooooo`05oa0@4?ooooooooooo`000?l@41000oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01?l0003ooooooooo
ool00006ooooo`04o`000?ooooooooooo`00027ooooo00Co0000oooooooooooooooo0_o^k^h3oooo
o`;ok^k^1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100?Oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo0_o^k^h3ooooo`;ok^k^1Oooool0
0ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100??ooool00ol0003ooooooooo
o`02onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooo
oa0@401Mooooo`00<?ooool3o`0003cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`04ooooo`;o00001Oooool00ol0003oooooooooo`04ooooo`07o`000?ooooooooooooooool0003o
ooooo`000002ooooo`05ogMgMonHV9Soooooo`000?mgMgL00oooool00ol0003oooooooooo`02oooo
o`;o00001?ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000Kooooo00Co0000
oooooooooooo00008Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`08ooooo`;o0000<oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00So
oooo0_l0000^ooooo`05o`000?nj^[[ooooooiRHV?l@41003_ooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool2o`0005?ooooo000`ooooo`03o`000?oooooooooo
03cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`Co00000oooool00ol0
003oooooooooo`04ooooo`07o`000?ooooooEEEEofIVI_l0003oooooo`000002ooooo`05onk^k_lb
<S;o0000o`000?o^k^h00oooool00ol0003oooooooooo`02ooooo`;o00001?ooool00ol0003ooooo
ooooo`04ooooo`04o`000?ooooooooooo`0000Kooooo00Co0000oooooooooooo00007oooool00omE
EEGoIVIVo`00000=ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP07
ooooo`04o`000?ooooooooooo`00033ooooo00?oEEEEofIVI_l000003Oooool4o`0000cooooo00?o
EEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oooooo00Co0000oooooooooooo
0000;Oooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo00?oEEEEofIVI_l000001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Oooooo00Co0000oooooooooooo0000D_ooool0033ooooo00?o0000
ooooooooool0??ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool01?l0003oooooooooooooool4o`0000?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001Oooool01?l0003ooooo
ooooool0000mooooo`Co000000Goooooo`000?ooooooooooo`00001Nooooo`Co000000Goooooo`00
0?ooooooooooo`00001<ooooo`Co000000Goooooo`000?ooooooooooo`00001Booooo`00<?ooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0004;ooooo0ol0001Tooooo`?o0000D_oo
ool3o`0005?ooooo000`ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool0
1_l0003ooooooooooooooooo0000ooooo`;o00000oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00007ooooo`03
o`000?oooooooooo03Wooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`1Booooo`03
o`000?oooooooooo05;ooooo000`ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooooooool4o`0000?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000005oooo
o`?o0000>oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo05;ooooo00?o0000oooo
ooooool0DOooool0033ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo0000
00Gooooo00?o0000ooooool00000oooooom<ooooo`00<?ooool00ol0003oooooooooo`0_ooooo`?o
00002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooool00000oooooolBoooo
o`03ogMgMomVIVKooooo02gooooo00?oIVIVogMgMoooool01oooool0033ooooo00?o0000oooooooo
ool0;_ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool00ol0003oooooo`00003ooooooa7ooooo00?ogMgMoa0@4?o^k^h0;_ooool00oo^
k^ko410@omgMg@07ooooo`00<?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00Co0000oooooooooooo00001_ooool2o`000?Gooooo0_l00002ooooo`;o00003?ooool00omE
EEGoV9RHooooo`02o`0000;ooooo00Oo0000oooooooooooo0000oa0@4?o^k^koEEEE00;o000000?o
A4A4okZj^_ooool00_ooool01OnHV9So0000o`000?m4A4Co^[Zj00;ooooo00Sok^k^oeEEEOl0003o
0000odA4A?nj^[[ooooooa0@40Go00000oooool02?l@413o<S8bo`000?l0003o410@ojVYZOn7QhOo
IVIV1oooool0033ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`04o`00
0?ooooooooooo`0000Gooooo1?l0003dooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM3?ooool0
1Ol0003ooooooooooooooooo000000;ooooo00_o0000oooooooooooo0000oooooomEEEGoMgMgoooo
ooo^k^koMgMgoa0@4003ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000_ooool01_mEEEGoMgMgoooo
ooo^k^koMgMgoa0@40?ooooo00?o0000ooooooooool01?ooool02?l0003oZJVYoooooooooooo^[Zj
o`000?o^k^ko00001oooool00?oo0000]?l0000?ooooo`04omgMgOl0003o410@olc<c0gooooo00Go
<S8booooooooooooooooo`000002ooooo`06o`000?ooooooooooo`000?oooooo00002?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool01onj
^[[oQhN7ofIVI_mVIVKo410@ooooool000001oooool000[ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool4
o`000004ooooool0003o0000o`0000Sooooo00?o0000ooooool000001?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00?ooooo0_l00005ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00_ooool2o`0000Gooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`;o00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0_ooool01Ol0003oooooo`000?oooooo000000Cooooo1Ol00005ooooo`?o00004_ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo01Oooooo00Cok^k^ob4Q8Ol@413ok^k^3Oooool01Olb
<S;ooooooooooooooooo000000;ooooo00Go0000oooooooooooo0000ooooo`06o`0000?ooooo00?o
0000ooooooooool01?ooool6o`0000?ooooo00?o0000ooooooooool01?ooool02?lb<S;o8B4QogMg
MomgMgOoQhN7onk^k_oooooo00001oooool000[ooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool01?l0003o
ooooooooooooool3o`0000Wooooo00?o0000ooooool000001?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00?ooooo0_l00005ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool2o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`;o00001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooooooo0_l00005ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003oooooo`00
0?oooooo0000013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo01Oooooo00Co8B4QogMgMomgMgOo<S8b3Oooool01Ol0003ok^k^oooooooooooo0000
00;oc<c<00_o0000ojVYZOoMgMgo8B4QoooooomEEEGoQhN7onk^k_ooooooQhN7oc8b<P03ooooo`03
o`000?oooooooooo00Cooooo00KoEEEEohN7Qoo^k^koooooohN7Qolb<S83ooooo`03o`000?lb<S;o
gMgM00Cooooo00So0000okZj^_ooooook^k^ogMgMol0003ok^k^o`0000Oooooo000`ooooo`03o`00
0?oooooooooo03Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo0_l00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooo
ooooo`000005ooooo`03o`000?oooooo000002Cooooo00?o0000ooooooooool0Foooool00ol0003o
ooooooooo`1Kooooo`03o`000?oooooooooo01Kooooo0_l00002ooooo`;o00003?ooool03_mEEEGo
MgMgooooool@413o0000ob4Q8Ol0003oMgMgoa0@4?l0003oZJVYooooooo^k^koEEEE0_l000001?m4
A4Cok^k^ooooool@4105o`0000?ooooo00Kok^k^oeEEEOl0003o0000odA4A?o^k^h2ooooo`;o0000
00CoZJVYob4Q8Ol0003o8B4Q0_ooool02?nYZJWo8B4Qo`000?l0003o<S8bo`000?mgMgOoEEEE1ooo
ool0033ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00Co0000oooooooooooo00001_ooool3o`000?oooooo3?ooool00ooMgMgo410@onk^
kP0Booooo`03o`000?oooooooooo01Wooooo00?ok^k^oa0@4?oMgMd01oooool0033ooooo00?o0000
ooooooooool0=?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Co0000
oooooooooooo0000oooooolFooooo`03ogMgMomVIVKooooo017ooooo00?o0000ooooooooool06Ooo
ool00omVIVKoMgMgooooo`07ooooo`00<?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool0003ooooooe3ooooo000`
ooooo`03o`000?oooooooooo03Gooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`04o`000?oo
ooooooooo`000?ooooooD?ooool0033ooooo00?o0000ooooooooool0=Oooool01Ol0003ooooooooo
oooooooo000000Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00Co0000oooooooooooo0000oooooom@ooooo`00<?ooool00ol0003ooooo
ooooo`0fooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo0000oooooom@oooo
o`00<?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooo000000Wooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooo
oooo0000oooooom@ooooo`00<?ooool00ol0003oooooooooo`0fooooo`?o00002Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`05o`000?ooooooooooooooool000001_ooool2o`000?ooooooDOooool0033o
oooo0ol00012ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000006oooo
o`;o0000oooooomAooooo`00<?ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00Go0000ooooooooooooooooo`00003ooooooeWooooo000`ooooo`03o`000?oooooooooo04?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo00000?ooooooFOooool0033o
oooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooooooooooo
ool00000oooooomIooooo`00<?ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00Co0000oooooooooooo0000oooooomJooooo`00<?ooool00ol0003oooooooooo`13ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00?ooooo00Co0000oooooooooooo0000oooooomJooooo`00<?ooool00ol0003o
ooooooooo`13ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo0000oooooomJooooo`00<?ooool00ol0
003oooooooooo`13ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo0000oooooomJooooo`00<?ooool0
0ol0003oooooooooo`13ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo0000oooooomJooooo`00<?oo
ool00ol0003oooooooooo`13ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo0000oooooomJooooo`00
<?ooool00ol0003oooooooooo`13ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo0000oooooomJoooo
o`00<?ooool00ol0003oooooooooo`13ooooo`05o`000?ooooooooooooooool000002?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo0000oooooomJ
ooooo`00<?ooool3o`0004?ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool0003ooooooe[ooooo000`
ooooo`03o`000?oooooooooo04?ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oo
ooooooooooooool000001_ooool01?l0003oooooooooool0003ooooooe[ooooo000`ooooo`03o`00
0?oooooooooo04?ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooooooooooo
ool000001_ooool01?l0003oooooooooool0003ooooooe[ooooo000`ooooo`03o`000?oooooooooo
04?ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001ooo
ool00ol0003oooooo`00003ooooooe[ooooo000`ooooo`03o`000?oooooooooo04Cooooo00Co0000
oooooooooooo00002?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Oooooo0_l0003ooooooe_ooooo
000`ooooo`03o`000?oooooooooo04Cooooo00Co0000oooooooooooo00002?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooo
oooooooooooo000000Oooooo0_l0003ooooooe_ooooo000`ooooo`03o`000?oooooooooo04Cooooo
00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Oooooo0_l0003ooooo
oe_ooooo000`ooooo`03o`000?oooooooooo04Cooooo00Co0000oooooooooooo00002?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0
003ooooooooooooooooo000000Oooooo0_l0003ooooooe_ooooo000`ooooo`03o`000?oooooooooo
04Cooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo00000?ooooooI?oo
ool0033ooooo00?o0000ooooooooool0A?ooool01?l0003oooooooooool00008ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oo
ooooooooooooool00000oooooomTooooo`00<?ooool00ol0003oooooooooo`14ooooo`04o`000?oo
ooooooooo`0000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00Co0000oooooooooooo0000oooooomTooooo`00<?ooool00ol0003ooooo
ooooo`14ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo0000oooooomToooo
o`00<?ooool3o`0004Cooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0003o
ooooofCooooo000`ooooo`03o`000?oooooooooo04Gooooo0_l00009ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`000?ooooooI?oo
ool0033ooooo00?o0000ooooooooool0AOooool2o`0000Wooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo0000oooooomTooooo`00<?oo
ool00ol0003oooooooooo`15ooooo`;o00002Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Gooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oo
oooo00Co0000oooooooooooo0000oooooomTooooo`00<?ooool00ol0003oooooooooo`15ooooo`;o
00002Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00Go0000oooooooo
ooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo0000oooo
oomTooooo`00<?ooool00ol0003oooooooooo`15ooooo`;o00002Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?oo
ooooooooo`0000Oooooo00Co0000oooooooooooo0000oooooomTooooo`003oooool2onk^kP?ooooo
0_o^k^hJooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`05ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool00007oooo
o`04o`000?ooooooooooo`000?ooooooI?ooool000Sooooo1Ol00002ooooo`07onk^k_mEEEGok^k^
ooooooo^k^koEEEEonk^kP03ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^
kP_ooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Gooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo00Co
0000oooooooooooo0000oooooomTooooo`002?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo
00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`05ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool0
0007ooooo`04o`000?ooooooooooo`000?ooooooI?ooool000Wooooo00?oV9RHob4Q8Oo^k^h01Ooo
ool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooo
oa0@400;ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`05ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool00007oooo
o`04o`000?ooooooooooo`000?ooooooI?ooool000[ooooo00?oV9RHob4Q8Oo^k^h00oooool01Oo^
k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000000_ooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Gooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oo
oooo00Co0000oooooooooooo0000oooooomTooooo`002oooool02omgMgOoIVIVooooooooooook^k^
oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000_ooooo1?l0001?ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01Oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo00001oooool0
1?l0003oooooooooool0003oooooofCooooo000<ooooo`03o`000?oooooooooo00;ok^k^0oooool2
onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00_ooooo00?o
0000ooooooooool0DOooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooooooooooo
ooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo0000oooooomT
ooooo`002?ooool01Ol0003o^[ZjoooooonHV9So410@00kooooo00?o0000ooooooooool00_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?o0000ooooooooool0DOooool01Ol0003ooooooooo
oooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`00
00Oooooo00Co0000oooooooooooo0000oooooomTooooo`002?ooool01OnHV9So410@o`000?lQ8B7o
c<c<00cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo0_l0
0006ooooo`03o`000?oooooooooo057ooooo00Go0000ooooooooooooooooo`000007ooooo`05o`00
0?ooooooooooooooool000001oooool01?l0003oooooooooool00007ooooo`04o`000?oooooooooo
o`000?ooooooI?ooool002Oooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`1A
ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo
00Co0000oooooooooooo00001oooool00ol0003oooooo`00003oooooofGooooo000Wooooo`04o`00
0?ooooooooooo`0000Gooooo00?o0000ooooooooool0DOooool01Ol0003ooooooooooooooooo0000
00Oooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo00?o
0000ooooool00000oooooomUooooo`009oooool3o`0000Kooooo00?o0000ooooooooool0DOooool0
1Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04o`00
0?ooooooooooo`0000Oooooo00?o0000ooooool00000oooooomUooooo`00:?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo057ooooo00Go0000ooooooooooooooooo`000007ooooo`05
o`000?ooooooooooooooool000001oooool01?l0003oooooooooool00007ooooo`03o`000?oooooo
00000?ooooooIOooool002Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Aoooo
o`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co
0000oooooooooooo00001oooool00ol0003oooooo`00003oooooofGooooo000`ooooo`03o`000?oo
oooooooo057ooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Oo
oooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00003oooooofGooooo000`ooooo`03
o`000?oooooooooo057ooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo
000000Oooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00003oooooofGooooo000`
ooooo`03o`000?oooooooooo057ooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooo
oooooooo000000Oooooo00Co0000oooooooooooo00002?ooool2o`000?ooooooIOooool0033ooooo
0ol0001Aooooo`04o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000007oooo
o`04o`000?ooooooooooo`0000Sooooo0_l0003oooooofGooooo000`ooooo`03o`000?oooooooooo
057ooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Co
0000oooooooooooo00002?ooool2o`000?ooooooIOooool0033ooooo00?o0000ooooooooool0DOoo
ool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooo
oooo00002?ooool2o`000?ooooooIOooool0033ooooo00?o0000ooooooooool0DOooool01?l0003o
ooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002?oo
ool2o`000?ooooooIOooool0033ooooo00?o0000ooooooooool0DOooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002?ooool00ol0003o
ooooooooo`3oooooofCooooo000`ooooo`03o`000?oooooooooo057ooooo00Co0000oooooooooooo
00002?ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`000?ooooooKoooool0
033ooooo00?o0000ooooooooool0DOooool01?l0003oooooooooool00008ooooo`04o`000?oooooo
ooooo`0000Sooooo00Co0000oooooooooooo0000oooooom_ooooo`00<?ooool00ol0003ooooooooo
o`1Aooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002?ooool01?l0003o
ooooooooool0003oooooofoooooo000`ooooo`03o`000?oooooooooo057ooooo00Co0000oooooooo
oooo00002?ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`000?ooooooKooo
ool0033ooooo00?o0000ooooooooool0DOooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000Sooooo00Co0000oooooooooooo0000oooooom_ooooo`00<?ooool00ol0003ooooo
ooooo`1Aooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002?ooool01?l0
003oooooooooool0003oooooofoooooo000`ooooo`03o`000?oooooooooo05;ooooo00?o0000oooo
ool000002Oooool00ol0003oooooo`000008ooooo`04o`000?ooooooooooo`000?ooooooKoooool0
033ooooo0ol0001Booooo`03o`000?oooooo000000Wooooo00?o0000ooooool000002?ooool01?l0
003oooooooooool0003oooooofoooooo000`ooooo`03o`000?oooooooooo05;ooooo00?o0000oooo
ool000002Oooool00ol0003oooooo`000008ooooo`04o`000?ooooooooooo`000?ooooooKoooool0
033ooooo00?o0000ooooooooool0D_ooool00ol0003oooooo`000009ooooo`03o`000?oooooo0000
00Sooooo00Co0000oooooooooooo0000oooooom_ooooo`00<?ooool00ol0003oooooooooo`1Boooo
o`03o`000?oooooo000000Wooooo00?o0000ooooool000002?ooool01?l0003oooooooooool0003o
ooooofoooooo000`ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooool000002Oooool00ol0
003oooooo`000008ooooo`04o`000?ooooooooooo`000?ooooooKoooool0033ooooo00?o0000oooo
ooooool0D_ooool00ol0003oooooo`000009ooooo`03o`000?oooooo000000Sooooo00?o0000oooo
ool00000oooooom`ooooo`00<?ooool00ol0003oooooooooo`1Booooo`03o`000?oooooo000000Wo
oooo00?o0000ooooool000002?ooool00ol0003oooooo`00003oooooog3ooooo000`ooooo`03o`00
0?oooooooooo05;ooooo0_l0000:ooooo`03o`000?oooooo000000Sooooo00?o0000ooooool00000
oooooom`ooooo`00<?ooool00ol0003oooooooooo`1Booooo`;o00002_ooool00ol0003oooooo`00
0008ooooo`03o`000?oooooo00000?ooooooL?ooool0033ooooo00?o0000ooooooooool0D_ooool2
o`0000[ooooo00?o0000ooooool000002?ooool00ol0003oooooo`00003oooooog3ooooo000`oooo
o`03o`000?oooooooooo05;ooooo0_l0000:ooooo`03o`000?oooooo000000Sooooo00?o0000oooo
ool00000oooooom`ooooo`00<?ooool00ol0003oooooooooo`1Booooo`;o00002_ooool00ol0003o
ooooo`000008ooooo`03o`000?oooooo00000?ooooooL?ooool0033ooooo0ol0001Booooo`;o0000
2_ooool00ol0003oooooo`000008ooooo`03o`000?oooooo00000?ooooooL?ooool0033ooooo00?o
0000ooooooooool0D_ooool2o`0000[ooooo00?o0000ooooool000002?ooool00ol0003oooooo`00
003oooooog3ooooo000`ooooo`03o`000?oooooooooo05;ooooo0_l0000:ooooo`03o`000?oooooo
000000Sooooo00?o0000ooooool00000oooooom`ooooo`00<?ooool00ol0003oooooooooo`1Noooo
o`03o`000?oooooo000000Sooooo00?o0000ooooool00000oooooom`ooooo`00<?ooool00ol0003o
ooooooooo`1Nooooo`03o`000?oooooo000000Wooooo0_l0003oooooog3ooooo000`ooooo`03o`00
0?oooooooooo05kooooo00?o0000ooooool000002Oooool2o`000?ooooooL?ooool000oooooo0_o^
k^h3ooooo`;ok^k^6_ooool00ol0003oooooooooo`1Nooooo`03o`000?oooooo000000Wooooo0_l0
003oooooog3ooooo000:ooooo`;o000000[o410@ooooooooooook^k^oeEEEOo^k^koooooonk^k_mE
EEGok^k^0oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`03o`00
0?oooooooooo05kooooo00?o0000ooooool000002Oooool2o`000?ooooooL?ooool000_ooooo00?o
0000ooooooooool00_ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?o0000ooooooooool0G_ooool00ol0003o
ooooo`000009ooooo`;o0000oooooom`ooooo`002?ooool5o`0000Cooooo00?ogMgMo`000?oMgMd0
1oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41002oooool00ol0003o
ooooooooo`1Nooooo`03o`000?oooooo000000Wooooo0_l0003oooooog3ooooo0008ooooo`04odA4
A?oMgMgoooooo`0000Cooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`00000;ooooo`03o`000?oooooooooo05kooooo00?o0000
ooooool000002Oooool2o`000?ooooooL?ooool000Sooooo00CogMgMoeEEEOoooooo00000oooool0
1oo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000002oooool4o`0005gooooo00?o0000ooooool000002Oooool2o`000?oo
ooooL?ooool000Wooooo00?oMgMgolc<c?l000000oooool2onk^kP?ooooo0_o^k^h5ooooo`03o`00
0?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400;ooooo`03o`000?oooooooooo05ko
oooo00?o0000ooooool000002Oooool2o`000?ooooooL?ooool000Wooooo00?ok^k^odA4A?l00000
3oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ol0003o
ooooooooo`1Nooooo`03o`000?oooooo000000Wooooo0_l0003oooooog3ooooo000:ooooo`03ogMg
Mol0003ooooo00cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?o
oooo0_l00006ooooo`03o`000?oooooooooo05kooooo00?o0000ooooool000002Oooool2o`000?oo
ooooL?ooool002Oooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`1Nooooo`03
o`000?oooooo000000Wooooo0_l0003oooooog3ooooo000Wooooo`04o`000?ooooooooooo`0000Go
oooo00?o0000ooooooooool0G_ooool00ol0003oooooo`00003oooooog_ooooo000Wooooo`?o0000
1_ooool00ol0003oooooooooo`1Nooooo`03o`000?oooooo00000?ooooooNoooool002Sooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooo00000?ooooooNooo
ool002Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Nooooo`03o`000?oooooo
00000?ooooooNoooool0033ooooo00?o0000ooooooooool0G_ooool00ol0003oooooo`00003ooooo
og_ooooo000`ooooo`03o`000?oooooooooo05kooooo00?o0000ooooool00000oooooomkooooo`00
<?ooool00ol0003oooooooooo`1Nooooo`03o`000?oooooo00000?ooooooNoooool0033ooooo0ol0
001Nooooo`;o0000oooooomlooooo`00<?ooool00ol0003oooooooooo`1Nooooo`;o0000ooooooml
ooooo`00<?ooool00ol0003oooooooooo`1Nooooo`;o0000oooooomlooooo`00<?ooool00ol0003o
ooooooooo`1Oooooo`03o`000?oooooooooo0?ooooooN_ooool0033ooooo00?o0000ooooooooool0
Goooool00ol0003oooooooooo`3oooooog[ooooo000`ooooo`03o`000?oooooooooo0?oooooog?oo
ool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3ooooo
omcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0
oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooo
oooo0?oooooog?ooool0033ooooo0ol0003oooooomcooooo000`ooooo`03o`000?oooooooooo0?oo
oooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooooooo
o`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooo
ooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`00
0?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool0
0ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033o
oooo00?o0000ooooooooool0oooooooLooooo`00<?ooool3o`000?oooooog?ooool0033ooooo00?o
0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`oooo
o`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00
oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooo
oa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003o
oooooooooooo4?ooool00:3ooooo0_l00004ooooo`03okZj^_lb<S;ooooo00Cooooo0_l00006oooo
o`03o`000?nj^[[ooooo0?ooooooEoooool00:3ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Cooooo0_lb<S;ooooooeSooooo002=ooooo`?o0000
0_ooool01_lb<S;o410@ooooooooooook^k^oeEEE@;o000000?oA4A4okZj^_ooool00oooool00ol0
003oooooooooo`02ooooo`05oiRHV?l@413o0000o`000?nYZJT01?ooool00ol0003oooooooooo`04
ooooo`03ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0;ooooo`;o000000?o
410@ooooooooool00oooool2ob4Q8@Cooooo00_ok^k^oc8b<_l0003o410@olc<c?ooooooc<c<onk^
k_ooooook^k^olc<c004ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kQ?o
oooo00Ko410@oc8b<_l0003o0000oa0@4?nYZJT2ooooo`06onk^k_mEEEGo0000o`000?m4A4Co^[Zj
0oooool01OmVIVKo0000o`000?m4A4Coc<c<0>Sooooo002>ooooo`05o`000?ooooooooooolc<c?l@
41000oooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40Cooooo00?o0000ooooooooool00_ooool0
1_l0003oZJVYoeEEEOnHV9SoEEEEokZj^P?ooooo00?o0000ooooooooool01?ooool00oo<c<co0000
oa0@400<ooooo`06oa0@4?nj^[[ok^k^ogMgMol@413ooooo1_l00005ooooo`03o`000?oooooooooo
00Cooooo0_lQ8B44ooooo`0;oeEEEOmgMgOooooooiRHV?lQ8B7oooooonk^k_mEEEGogMgMoeEEEOo^
k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool01_l0
003oZJVYoooooooooooo^[Zjo`0000;ooooo00KoEEEEogMgMoooooook^k^ogMgMol@4102ooooo`06
ofIVI_mgMgOooooooooooon7QhOo410@j?ooool008kooooo00Go0000ooooooooooooEEEEohN7Q`03
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool01_lb<S;ok^k^oiRHV?mE
EEGogMgMoa0@40?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0;ooooo`Go0000
2oooool01Ol0003ooooooooooooooooo000000;ooooo00?ogMgMo`000?oMgMd01oooool00ol0003o
ooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41005?ooool01Onj^[[oQhN7ofIVI_mVIVKo
410@00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3[ooooo`00S_ooool01Ol0
003oooooomgMgOl0003ok^k^00?ooooo1_l00004ooooo`03o`000?oooooooooo00;ooooo00Oo^[Zj
odA4A?o<c<co8B4Qooooool@413oc<c<00;ooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`03ooooo`Ko00000_ooool01?m4A4CogMgMooooool0000<ooooo`0;o`000?nHV9SooooooiRH
V?lQ8B7oooooonk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000004oooool01_lb<S;o8B4QogMgMomgMgOoQhN7onk^kP;ooooo1_l00002
ooooo`03o`000?oooooooooo0>_ooooo002>ooooo`?o000000?o410@oiRHV?ooool00_ooool01_mE
EEGoQhN7onk^k_ooooooQhN7oc8b<PCooooo00?o0000ooooooooool00_ooool01oo^k^ko0000oooo
ool0003oooooofIVI_n7QhL00_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00_o
oooo00CogMgMoeEEEOoooooo00003?ooool02ol0003oEEEEo`000?l@413oc<c<ooooooo<c<cok^k^
ooooooo^k^koc<c<00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
01?ooooo00Ko0000okZj^_ooooook^k^ogMgMol00002ooooo`06oeEEEOn7QhOok^k^oooooon7QhOo
<S8b0_ooool01_mVIVKoMgMgooooooooooooQhN7o`000>Sooooo002>ooooo`05o`000?oooooooooo
olc<c?l000000oooool01_o^k^koEEEEo`000?l0003oA4A4onk^kPCooooo00?o0000ooooooooool0
0_ooool01?mVIVKoV9RHoooooolb<S82okZj^P04o`000?ooooooooooo`0001?ooooo00?o410@o`00
0?l000000ol0000;ooooo`03ogMgMoo<c<co000000cooooo00?oEEEEohN7Qoooool03_ooool00ol0
003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41001oooool3o`0000;ooooo0ol00004
ooooo`06ojVYZOlQ8B7o0000o`000?lb<S;o00000_ooool01_o^k^koEEEEo`000?l0003oA4A4onk^
kP;ooooo00Kok^k^ofIVI_l0003o0000odA4A?l0003Xooooo`00S_ooool01Ol0003oooooooooooo<
c<co000000gooooo00?o0000ooooooooool01Oooool00omVIVKoQhN7ooooo`03ooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool03?ooool00oo^k^koA4A4o`00000<ooooo`03omgMgOl@
413oV9RH00kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`3oooooo`;ooooo002=ooooo`Co000000?o
410@ojVYZOooool03?ooool2o`0000Kooooo00?oZJVYodA4A?ooool00_ooool2o`0001Gooooo00?o
0000ooooooooool03Oooool00omgMgOo0000ooooo`0<ooooo`04olc<c?m4A4Co0000oa0@40[ooooo
00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo1?l00002ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0ooooool2ooooo`00ooooool6ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0ooooool2ooooo`00ooooool6ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0ooooool2ooooo`00ooooool5ooooo`;o00000oooool2
o`000?oooooo1?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo
4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oo
ooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@
ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooo
oooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3o
oooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo0000\
\>"],
  ImageRangeCache->{{{0, 525.688}, {324.5, 0}} -> {-2.58312*^-7, -6.34248*^6, \
6.65005*^-9, 53093.5}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0.309017 5.42214e-08 [
[.32684 .29652 -16.5 -12.5 ]
[.32684 .29652 16.5 0 ]
[.54329 .29652 -16.5 -12.5 ]
[.54329 .29652 16.5 0 ]
[.75974 .29652 -22.5 -12.5 ]
[.75974 .29652 22.5 0 ]
[.97619 .29652 -16.5 -12.5 ]
[.97619 .29652 16.5 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 64 6 ]
[.09789 .09213 -34.5 -6.25 ]
[.09789 .09213 0 6.25 ]
[.09789 .20057 -34.5 -6.25 ]
[.09789 .20057 0 6.25 ]
[.09789 .41746 -28.5 -6.25 ]
[.09789 .41746 0 6.25 ]
[.09789 .5259 -28.5 -6.25 ]
[.09789 .5259 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -62.8125 0 ]
[.5 .63053 62.8125 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 .30902 m
.32684 .31527 L
s
gsave
.32684 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 .30902 m
.54329 .31527 L
s
gsave
.54329 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 .30902 m
.75974 .31527 L
s
gsave
.75974 .29652 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 .30902 m
.15368 .31277 L
s
.19697 .30902 m
.19697 .31277 L
s
.24026 .30902 m
.24026 .31277 L
s
.28355 .30902 m
.28355 .31277 L
s
.37013 .30902 m
.37013 .31277 L
s
.41342 .30902 m
.41342 .31277 L
s
.45671 .30902 m
.45671 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.58658 .30902 m
.58658 .31277 L
s
.62987 .30902 m
.62987 .31277 L
s
.67316 .30902 m
.67316 .31277 L
s
.71645 .30902 m
.71645 .31277 L
s
.80303 .30902 m
.80303 .31277 L
s
.84632 .30902 m
.84632 .31277 L
s
.88961 .30902 m
.88961 .31277 L
s
.9329 .30902 m
.9329 .31277 L
s
.0671 .30902 m
.0671 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09213 m
.11664 .09213 L
s
gsave
.09789 .09213 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .20057 m
.11664 .20057 L
s
gsave
.09789 .20057 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .41746 m
.11664 .41746 L
s
gsave
.09789 .41746 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .5259 m
.11664 .5259 L
s
gsave
.09789 .5259 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.11039 .11924 m
.11414 .11924 L
s
.11039 .14635 m
.11414 .14635 L
s
.11039 .17346 m
.11414 .17346 L
s
.11039 .22768 m
.11414 .22768 L
s
.11039 .2548 m
.11414 .2548 L
s
.11039 .28191 m
.11414 .28191 L
s
.11039 .33613 m
.11414 .33613 L
s
.11039 .36324 m
.11414 .36324 L
s
.11039 .39035 m
.11414 .39035 L
s
.11039 .44457 m
.11414 .44457 L
s
.11039 .47168 m
.11414 .47168 L
s
.11039 .49879 m
.11414 .49879 L
s
.11039 .06502 m
.11414 .06502 L
s
.11039 .03791 m
.11414 .03791 L
s
.11039 .0108 m
.11414 .0108 L
s
.11039 .55301 m
.11414 .55301 L
s
.11039 .58012 m
.11414 .58012 L
s
.11039 .60723 m
.11414 .60723 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -123.812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.812 moveto
(@) show
81.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.812 moveto
(D) show
93.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4.8) show
135.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
141.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
153.000 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
157.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
166.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
184.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02532 .30902 L
.02691 .30902 L
.02852 .30902 L
.03029 .30902 L
.032 .30902 L
.03354 .30902 L
.03667 .30902 L
.03988 .30902 L
.04296 .30902 L
.04452 .30902 L
.04624 .30902 L
.04703 .30902 L
.04787 .30902 L
.04828 .30902 L
.04867 .30902 L
.04902 .30902 L
.04922 .30902 L
.0494 .30902 L
.04961 .30902 L
.04971 .30902 L
.04977 .30902 L
.04983 .30902 L
.04993 .30902 L
.05002 .30902 L
.05008 .30902 L
.05013 .30902 L
.05023 .30902 L
.05032 .30902 L
.05042 .30902 L
.0505 .30902 L
.05059 .30902 L
.05079 .30902 L
.05098 .30902 L
.05119 .30902 L
.0514 .30902 L
.05179 .30902 L
.05221 .30902 L
.05266 .30902 L
.05349 .30902 L
.05424 .30902 L
.0551 .30902 L
.05592 .30902 L
.0567 .30902 L
.05753 .30902 L
.05901 .30902 L
.05976 .30902 L
.06058 .30902 L
.06205 .30902 L
.06375 .30902 L
Mistroke
.06536 .30902 L
.06695 .30902 L
.06843 .30902 L
.07158 .30902 L
.0733 .30902 L
.07492 .30902 L
.07802 .30902 L
.08131 .30902 L
.08295 .30902 L
.08449 .30902 L
.08524 .30902 L
.08596 .30902 L
.08636 .30902 L
.08656 .30902 L
.08679 .30902 L
.08697 .30902 L
.08707 .30902 L
.08718 .30902 L
.08727 .30902 L
.08736 .30902 L
.08745 .30902 L
.08754 .30902 L
.08764 .30902 L
.08769 .30902 L
.08775 .30902 L
.08784 .30902 L
.08794 .30902 L
.08803 .30902 L
.08812 .30902 L
.08831 .30902 L
.08851 .30902 L
.0887 .30902 L
.08913 .30902 L
.08949 .30902 L
.08988 .30902 L
.0906 .30902 L
.09135 .30902 L
.09219 .30902 L
.09306 .30902 L
.09387 .30902 L
.09549 .30902 L
.09697 .30902 L
.09849 .30902 L
.10015 .30902 L
.10173 .30902 L
.10341 .30902 L
.10673 .30902 L
.10994 .30902 L
.11303 .30902 L
.11459 .30902 L
Mistroke
.11542 .30902 L
.11631 .30902 L
.11674 .30902 L
.11716 .30902 L
.11753 .30902 L
.11774 .30902 L
.11794 .30902 L
.11804 .30902 L
.11814 .30902 L
.11824 .30902 L
.11833 .30902 L
.11841 .30902 L
.1185 .30902 L
.11859 .30902 L
.11868 .30902 L
.11878 .30902 L
.11888 .30902 L
.11906 .30902 L
.11926 .30902 L
.11947 .30902 L
.11986 .30902 L
.12022 .30902 L
.12062 .30902 L
.12106 .30902 L
.12194 .30902 L
.12274 .30902 L
.12353 .30902 L
.12426 .30902 L
.12593 .30902 L
.12757 .30902 L
.12906 .30902 L
.13227 .30901 L
.13536 .30901 L
.13865 .30901 L
.14028 .30901 L
.14181 .30901 L
.14256 .30901 L
.14328 .30901 L
.14367 .30901 L
.14388 .30901 L
.1441 .30901 L
.14431 .30901 L
.14449 .30901 L
.14458 .30901 L
.14468 .30901 L
.14477 .30901 L
.14485 .30901 L
.14496 .30901 L
.14505 .30901 L
.14514 .30901 L
Mistroke
.14523 .30901 L
.14534 .30901 L
.14539 .30901 L
.14544 .30901 L
.14564 .30901 L
.14582 .30901 L
.14602 .30901 L
.14637 .30901 L
.14681 .30901 L
.14724 .30901 L
.14803 .30901 L
.1488 .30901 L
.14962 .30901 L
.15109 .30901 L
.15192 .30902 L
.15281 .30902 L
.15443 .30902 L
.15772 .30904 L
.16089 .30906 L
.16394 .30908 L
.16563 .30909 L
.16644 .30909 L
.16718 .3091 L
.16755 .3091 L
.16795 .3091 L
.16815 .3091 L
.16835 .3091 L
.16845 .3091 L
.16856 .3091 L
.16861 .3091 L
.16867 .3091 L
.16873 .3091 L
.16878 .3091 L
.16889 .3091 L
.16898 .3091 L
.16908 .3091 L
.16916 .3091 L
.16926 .3091 L
.16936 .3091 L
.16947 .3091 L
.16957 .3091 L
.16975 .3091 L
.16992 .3091 L
.1703 .3091 L
.17069 .3091 L
.17109 .30909 L
.17183 .30909 L
.1727 .30908 L
.17349 .30907 L
.17504 .30905 L
Mistroke
.17671 .30901 L
.17832 .30896 L
.18001 .30889 L
.18306 .30876 L
.18476 .30868 L
.18631 .30861 L
.18709 .30858 L
.18793 .30855 L
.18871 .30852 L
.18943 .30851 L
.18978 .3085 L
.18996 .3085 L
.19016 .3085 L
.19037 .30849 L
.19048 .30849 L
.19058 .30849 L
.19068 .30849 L
.19077 .30849 L
.19087 .30849 L
.19097 .30849 L
.19106 .30849 L
.19117 .30849 L
.19122 .30849 L
.19128 .30849 L
.19138 .30849 L
.19158 .3085 L
.19177 .3085 L
.19198 .3085 L
.19221 .30851 L
.19263 .30852 L
.19302 .30853 L
.19339 .30854 L
.19422 .30859 L
.19503 .30864 L
.1959 .30872 L
.19751 .30891 L
.1992 .30917 L
.20226 .30978 L
.20551 .31054 L
.20701 .31086 L
.20864 .31114 L
.20907 .3112 L
.20953 .31125 L
.20992 .31128 L
.21014 .3113 L
.21035 .31131 L
.21056 .31132 L
.21075 .31133 L
.21086 .31133 L
.21096 .31133 L
Mistroke
.21102 .31134 L
.21107 .31134 L
.21113 .31134 L
.21119 .31134 L
.21128 .31134 L
.21138 .31134 L
.21147 .31133 L
.21156 .31133 L
.21166 .31133 L
.21177 .31133 L
.21197 .31132 L
.21217 .3113 L
.21239 .31129 L
.21278 .31125 L
.21321 .31119 L
.21367 .31111 L
.21451 .31091 L
.21529 .31068 L
.21691 .30999 L
.21839 .30915 L
.22157 .30677 L
.22463 .30415 L
.22634 .30282 L
.22715 .3023 L
.22789 .30189 L
.22866 .30157 L
.22907 .30144 L
.22928 .30139 L
.2295 .30134 L
.2297 .30131 L
.22988 .30129 L
.22996 .30129 L
.23006 .30128 L
.23015 .30128 L
.23023 .30128 L
.23033 .30128 L
.23043 .30128 L
.23052 .30128 L
.23061 .30129 L
.23072 .3013 L
.23083 .30132 L
.23103 .30135 L
.23123 .30139 L
.23142 .30145 L
.23179 .30158 L
.23218 .30176 L
.23261 .302 L
.23337 .30258 L
.23408 .30328 L
.23558 .30527 L
Mistroke
.23723 .30822 L
.24047 .31571 L
.24358 .32338 L
.24439 .32511 L
.24527 .32676 L
.24611 .32801 L
.24651 .3285 L
.24688 .32886 L
.24729 .32917 L
.2475 .32929 L
.24761 .32934 L
.24773 .32939 L
.24783 .32942 L
.24793 .32944 L
.24802 .32946 L
.24811 .32947 L
.24822 .32948 L
.24831 .32948 L
.24842 .32947 L
.24847 .32946 L
.24853 .32945 L
.24862 .32943 L
.24872 .3294 L
.2489 .32933 L
.24909 .32923 L
.2493 .32908 L
.24967 .32874 L
.25002 .32833 L
.25087 .32692 L
.25166 .32507 L
.25315 .32022 L
.25476 .31315 L
.25624 .30524 L
.2594 .2863 L
.26099 .27739 L
.26244 .27071 L
.26324 .26792 L
.26361 .26689 L
.264 .26599 L
.26422 .26559 L
.26442 .26528 L
.26462 .26502 L
.2648 .26484 L
.26491 .26475 L
.26502 .26469 L
.26507 .26466 L
.26513 .26464 L
.26519 .26462 L
.26525 .26461 L
.26531 .26461 L
Mistroke
.26537 .26461 L
.26542 .26461 L
.26547 .26462 L
.26557 .26465 L
.26568 .2647 L
.26577 .26476 L
.26587 .26484 L
.26607 .26505 L
.26626 .26531 L
.26643 .26561 L
.26682 .26647 L
.26724 .26769 L
.26801 .27075 L
.26871 .27445 L
.27025 .28559 L
.27192 .30175 L
.27521 .34074 L
.27684 .35994 L
.27837 .37513 L
.27912 .38106 L
.27984 .38548 L
.28023 .38735 L
.28044 .38817 L
.28066 .38891 L
.28087 .38946 L
.28105 .38985 L
.28114 .39001 L
.28124 .39014 L
.28133 .39025 L
.28142 .39032 L
.28152 .39037 L
.28161 .3904 L
.2817 .39039 L
.28179 .39036 L
.2819 .3903 L
.28195 .39025 L
.282 .39019 L
.2822 .3899 L
.28238 .38951 L
.28258 .38897 L
.28293 .38767 L
.28338 .38544 L
.2838 .38269 L
.28459 .37589 L
.28536 .36731 L
.28618 .35614 L
.28766 .33141 L
.29099 .26281 L
.29267 .22909 L
.2934 .216 L
Mistroke
.29421 .20346 L
.29494 .19415 L
.29571 .18661 L
.29614 .18365 L
.29635 .18256 L
.29654 .18174 L
.29672 .18111 L
.29682 .18085 L
.29693 .18063 L
.29702 .18048 L
.29711 .18039 L
.2972 .18033 L
.2973 .18033 L
.2974 .18037 L
.2975 .18047 L
.2976 .18063 L
.2977 .18084 L
.29788 .18136 L
.29807 .18211 L
.29828 .18319 L
.29851 .1846 L
.29891 .18785 L
.29972 .19708 L
.30061 .21133 L
.30217 .24584 L
.30384 .29344 L
.30716 .39846 L
.30881 .44348 L
.30962 .46082 L
.31035 .4732 L
.31071 .4781 L
.31111 .48232 L
.3113 .48386 L
.31149 .48522 L
.31167 .48623 L
.31183 .48692 L
.31193 .48724 L
.31202 .48746 L
.31212 .48763 L
.31222 .48772 L
.31232 .48773 L
.31241 .48767 L
.3125 .48756 L
.31259 .48736 L
.3127 .48705 L
.31279 .48668 L
.31302 .48556 L
.31321 .48423 L
.31342 .4825 L
.31382 .47809 L
Mistroke
.31418 .47295 L
.315 .45754 L
.31576 .43872 L
.31648 .41731 L
.31957 .29613 L
.32114 .22847 L
.32286 .16158 L
.32365 .13625 L
.3245 .11423 L
.32491 .10575 L
.3253 .09916 L
.32564 .09449 L
.32584 .09237 L
.32603 .09079 L
.32621 .08952 L
.32631 .089 L
.32641 .08856 L
.3265 .08827 L
.32659 .08807 L
.32668 .08795 L
.32678 .08791 L
.32683 .08794 L
.32689 .08799 L
.32694 .08808 L
.327 .08822 L
.3271 .08853 L
.32721 .089 L
.32742 .09022 L
.32761 .09177 L
.32803 .09661 L
.32842 .10271 L
.3293 .12214 L
.33009 .14614 L
.33082 .1733 L
.33248 .24859 L
.33563 .41062 L
.33723 .48217 L
.33813 .51379 L
.33856 .52605 L
.33897 .53571 L
.33936 .54335 L
.33971 .54876 L
.33991 .55115 L
.34011 .55296 L
.34031 .55436 L
.34042 .55492 L
.34053 .5553 L
.34062 .55551 L
.34073 .55561 L
.34082 .55559 L
Mistroke
.34091 .55547 L
.34101 .55521 L
.34106 .55501 L
.34112 .55479 L
.34133 .5535 L
.34144 .55261 L
.34155 .55162 L
.34174 .54941 L
.34218 .54268 L
.34255 .53512 L
.34296 .52491 L
.34379 .4985 L
.34527 .4345 L
.34851 .25463 L
.35 .17491 L
.35079 .1386 L
.35163 .1062 L
.35209 .09152 L
.35251 .08041 L
.35294 .07136 L
.35333 .06513 L
.35352 .06279 L
.35373 .06088 L
.35383 .06011 L
.35393 .05953 L
.35404 .05906 L
.3541 .05886 L
.35416 .05873 L
.35426 .05859 L
.35435 .05859 L
.35445 .05873 L
.35451 .05885 L
.35456 .05903 L
.35466 .05942 L
.35476 .05998 L
.35494 .06135 L
.35515 .06341 L
.35536 .06621 L
.35575 .07284 L
.35622 .08329 L
.35664 .09508 L
.35825 .15821 L
.36146 .33444 L
.36294 .41515 L
.36378 .45525 L
.36456 .48713 L
.36533 .51221 L
.36576 .52318 L
.36616 .53111 L
.36657 .53725 L
Mistroke
.36681 .5397 L
.36692 .54061 L
.36702 .5413 L
.36712 .54178 L
.36721 .54217 L
.36727 .54233 L
.36732 .54245 L
.36742 .54257 L
.36753 .54254 L
.36763 .54238 L
.36768 .54223 L
.36773 .54205 L
.36785 .54153 L
.36794 .54096 L
.36803 .54032 L
.36824 .53845 L
.36843 .5361 L
.36865 .533 L
.36939 .51782 L
.36983 .50543 L
.37026 .49162 L
.37106 .46088 L
.37412 .30689 L
.37584 .21998 L
.37739 .157 L
.37817 .13404 L
.37861 .12409 L
.37901 .11695 L
.37936 .11232 L
.37956 .11037 L
.37975 .10901 L
.37985 .10846 L
.37995 .10806 L
.38003 .10779 L
.38013 .10761 L
.38023 .10753 L
.38028 .10754 L
.38034 .1076 L
.38044 .10778 L
.38053 .10808 L
.38063 .10848 L
.38073 .10903 L
.38091 .11034 L
.38113 .11241 L
.38132 .11478 L
.38175 .12149 L
.38215 .12969 L
.38287 .14832 L
.38364 .17372 L
.38693 .31591 L
Mistroke
.38856 .38544 L
.38936 .41403 L
.39009 .43573 L
.39045 .4447 L
.39085 .45303 L
.39119 .45899 L
.39156 .46418 L
.39175 .46626 L
.39196 .46806 L
.39207 .46886 L
.39218 .46948 L
.39228 .46998 L
.39238 .47035 L
.39247 .47058 L
.39256 .47074 L
.39266 .47082 L
.39275 .47079 L
.39284 .47067 L
.39295 .47043 L
.39305 .4701 L
.39314 .46971 L
.39333 .46857 L
.39351 .46719 L
.39391 .46292 L
.39429 .45757 L
.39464 .4513 L
.39543 .43352 L
.3963 .40902 L
.39956 .29368 L
.40107 .24458 L
.40186 .22356 L
.4027 .20612 L
.40313 .19933 L
.40335 .19633 L
.4036 .1936 L
.40382 .19152 L
.40402 .18999 L
.40423 .18881 L
.40433 .18836 L
.40442 .18802 L
.40451 .18775 L
.40461 .18755 L
.40471 .18743 L
.40477 .1874 L
.40482 .18739 L
.40491 .18744 L
.405 .18756 L
.4051 .18776 L
.40519 .18803 L
.4053 .18843 L
Mistroke
.40541 .18891 L
.4056 .19002 L
.40581 .19156 L
.40604 .19361 L
.4068 .20321 L
.40763 .21811 L
.40932 .25837 L
.41102 .3047 L
.41256 .34426 L
.41333 .36081 L
.41416 .37558 L
.41454 .38105 L
.41495 .38591 L
.4153 .38933 L
.41568 .39207 L
.41588 .3932 L
.41599 .39368 L
.41611 .39412 L
.41622 .39444 L
.41631 .39467 L
.41641 .39484 L
.41651 .39495 L
.41656 .39498 L
.41661 .395 L
.41667 .395 L
.41673 .39498 L
.41683 .3949 L
.41688 .39482 L
.41693 .39474 L
.41704 .3945 L
.41716 .39416 L
.4174 .39323 L
.41761 .39211 L
.41781 .39088 L
.41824 .38736 L
.41902 .37865 L
.42056 .35435 L
.42223 .32241 L
.4238 .29307 L
.42463 .27958 L
.42552 .26761 L
.42596 .26284 L
.42638 .25905 L
.42678 .2561 L
.42696 .25503 L
.42716 .25402 L
.42733 .25329 L
.42751 .25264 L
.42762 .25236 L
.42771 .25213 L
Mistroke
.4278 .25196 L
.42789 .25181 L
.42799 .25169 L
.42808 .25163 L
.42813 .2516 L
.42818 .25159 L
.42828 .25161 L
.42838 .25166 L
.42848 .25176 L
.42858 .2519 L
.42869 .25211 L
.42889 .25262 L
.42908 .25326 L
.42945 .25486 L
.42983 .25713 L
.43026 .26022 L
.43173 .27487 L
.43344 .29649 L
.43499 .31615 L
.43577 .32486 L
.43661 .33285 L
.43741 .33873 L
.43779 .34093 L
.43814 .34255 L
.43851 .3439 L
.43872 .34445 L
.43892 .34486 L
.43901 .345 L
.4391 .34513 L
.43918 .34522 L
.43927 .34529 L
.43936 .34535 L
.43945 .34537 L
.43955 .34538 L
.43965 .34535 L
.43974 .3453 L
.43985 .34522 L
.43995 .34511 L
.44003 .34499 L
.44025 .3446 L
.44046 .34412 L
.44086 .34283 L
.44131 .34099 L
.44207 .33684 L
.4429 .33115 L
.44459 .3176 L
.44629 .30408 L
.44783 .29429 L
.4486 .29085 L
.44903 .28939 L
Mistroke
.44943 .28836 L
.44963 .28796 L
.44982 .28766 L
.44999 .28744 L
.45017 .28727 L
.45026 .2872 L
.45037 .28715 L
.45042 .28713 L
.45048 .28712 L
.45058 .28711 L
.45068 .28712 L
.45077 .28714 L
.45086 .28718 L
.45095 .28723 L
.45105 .28731 L
.45114 .28739 L
.45134 .28763 L
.45171 .28823 L
.45214 .2892 L
.45254 .29037 L
.45423 .29715 L
.4573 .31203 L
.45811 .31531 L
.45887 .31785 L
.4593 .319 L
.45976 .32001 L
.46017 .32071 L
.46037 .32098 L
.46056 .32118 L
.46074 .32134 L
.46093 .32148 L
.46104 .32153 L
.46114 .32157 L
.46124 .32159 L
.46134 .32161 L
.46142 .32161 L
.46152 .32161 L
.4616 .3216 L
.46168 .32158 L
.46177 .32155 L
.46187 .32151 L
.46207 .32139 L
.46229 .32122 L
.46248 .32102 L
.46293 .32045 L
.46373 .319 L
.46527 .31514 L
.46693 .31034 L
.4685 .30628 L
.46939 .30448 L
Mistroke
.46981 .30378 L
.47022 .30322 L
.4706 .3028 L
.4708 .30261 L
.47101 .30245 L
.47121 .30232 L
.47139 .30223 L
.47148 .3022 L
.47157 .30216 L
.47165 .30214 L
.47174 .30212 L
.47184 .3021 L
.47194 .30209 L
.472 .30209 L
.47205 .30209 L
.47216 .30209 L
.47221 .30209 L
.47227 .3021 L
.47237 .30212 L
.47248 .30214 L
.4726 .30218 L
.47279 .30225 L
.473 .30236 L
.47338 .30261 L
.47378 .30295 L
.47415 .30333 L
.47499 .30439 L
.47669 .307 L
.47819 .30934 L
.47899 .31041 L
.47982 .31135 L
.48025 .31174 L
.48072 .31209 L
.48114 .31234 L
.48154 .31251 L
.48175 .31257 L
.48195 .31262 L
.48203 .31264 L
.48213 .31265 L
.48223 .31266 L
.48232 .31267 L
.48242 .31267 L
.48247 .31267 L
.48253 .31267 L
.48262 .31267 L
.48272 .31267 L
.48277 .31266 L
.48283 .31266 L
.48293 .31264 L
.48316 .3126 L
Mistroke
.48336 .31255 L
.48358 .31248 L
.48398 .31232 L
.48487 .31182 L
.48649 .31057 L
.48807 .30923 L
.48952 .30818 L
.49032 .30774 L
.49108 .30743 L
.4915 .30731 L
.49188 .30723 L
.49211 .3072 L
.49231 .30718 L
.49242 .30717 L
.49248 .30717 L
.49254 .30716 L
.49259 .30716 L
.49265 .30716 L
.4927 .30716 L
.49276 .30716 L
.49286 .30716 L
.49291 .30716 L
.49297 .30716 L
.49307 .30717 L
.49316 .30718 L
.49337 .3072 L
.4936 .30722 L
.49401 .3073 L
.49439 .30739 L
.49512 .30761 L
.49588 .3079 L
.49894 .30918 L
.49975 .30945 L
.50052 .30966 L
.50094 .30975 L
.5014 .30983 L
.5016 .30985 L
.50181 .30988 L
.502 .30989 L
.5022 .30991 L
.5023 .30991 L
.5024 .30992 L
.50249 .30992 L
.50259 .30992 L
.50269 .30992 L
.50278 .30992 L
.50287 .30992 L
.50296 .30992 L
.50305 .30992 L
.50311 .30992 L
Mistroke
.50316 .30992 L
.50338 .30991 L
.50357 .3099 L
.50377 .30988 L
.50417 .30985 L
.50454 .3098 L
.50524 .30969 L
.50832 .30906 L
.50914 .3089 L
.50991 .30878 L
.51072 .30869 L
.51114 .30865 L
.51136 .30863 L
.5116 .30862 L
.51182 .30861 L
.51202 .3086 L
.51212 .3086 L
.51222 .30859 L
.51232 .30859 L
.51241 .30859 L
.51247 .30859 L
.51252 .30859 L
.51257 .30859 L
.51263 .30859 L
.51269 .30859 L
.51276 .30859 L
.51282 .30859 L
.51287 .30859 L
.51297 .30859 L
.51302 .30859 L
.51308 .30859 L
.5133 .3086 L
.51349 .3086 L
.5137 .30861 L
.51407 .30863 L
.51491 .30868 L
.51649 .30883 L
.51796 .30898 L
.51881 .30906 L
.51961 .30912 L
.52032 .30916 L
.52072 .30918 L
.5211 .30919 L
.52147 .3092 L
.52168 .30921 L
.52187 .30921 L
.52205 .30921 L
.52215 .30921 L
.52225 .30921 L
.52234 .30921 L
Mistroke
.52242 .30921 L
.52251 .30921 L
.5226 .30921 L
.5227 .30921 L
.5228 .30921 L
.52291 .30921 L
.52302 .30921 L
.5232 .30921 L
.5234 .3092 L
.52385 .30919 L
.52426 .30918 L
.52579 .30912 L
.52746 .30904 L
.52905 .30898 L
.52985 .30896 L
.53031 .30895 L
.53073 .30894 L
.53111 .30893 L
.53133 .30893 L
.53152 .30893 L
.53163 .30893 L
.53174 .30893 L
.53183 .30893 L
.53193 .30893 L
.53198 .30893 L
.53204 .30893 L
.5321 .30893 L
.53215 .30893 L
.53225 .30893 L
.53231 .30893 L
.53236 .30893 L
.53255 .30893 L
.53272 .30893 L
.53291 .30893 L
.53312 .30894 L
.53384 .30894 L
.53467 .30896 L
.53557 .30898 L
.53719 .30901 L
.53802 .30902 L
.53879 .30904 L
.5396 .30905 L
.54003 .30905 L
.54025 .30905 L
.54048 .30905 L
.54069 .30905 L
.5408 .30905 L
.54091 .30905 L
.54102 .30905 L
.54111 .30905 L
Mistroke
.54121 .30905 L
.5413 .30905 L
.54136 .30905 L
.54141 .30905 L
.54147 .30905 L
.54153 .30905 L
.54162 .30905 L
.54168 .30905 L
.54173 .30905 L
.54184 .30905 L
.54196 .30905 L
.54219 .30905 L
.54241 .30905 L
.5426 .30905 L
.54303 .30905 L
.54381 .30904 L
.54547 .30903 L
.54701 .30902 L
.54778 .30901 L
.5485 .30901 L
.54889 .30901 L
.54925 .309 L
.54965 .309 L
.54986 .309 L
.55009 .309 L
.55018 .309 L
.55029 .309 L
.55039 .309 L
.55049 .309 L
.55058 .309 L
.55068 .309 L
.55077 .309 L
.55085 .309 L
.55096 .309 L
.55106 .309 L
.55115 .309 L
.55125 .309 L
.55147 .309 L
.55167 .309 L
.55204 .309 L
.55238 .309 L
.55314 .30901 L
.55482 .30901 L
.55636 .30902 L
.55714 .30902 L
.55787 .30902 L
.55824 .30902 L
.55863 .30902 L
.55885 .30902 L
.55907 .30902 L
Mistroke
.55926 .30902 L
.55936 .30902 L
.55946 .30902 L
.55955 .30902 L
.55965 .30902 L
.55975 .30902 L
.55985 .30902 L
.55995 .30902 L
.56004 .30902 L
.56014 .30902 L
.56022 .30902 L
.56033 .30902 L
.56043 .30902 L
.56065 .30902 L
.56085 .30902 L
.56105 .30902 L
.56186 .30902 L
.56274 .30902 L
.56444 .30902 L
.56598 .30902 L
.56675 .30902 L
.56718 .30902 L
.56758 .30901 L
.56793 .30901 L
.56813 .30901 L
.56832 .30901 L
.56842 .30901 L
.56852 .30901 L
.5686 .30901 L
.5687 .30901 L
.5688 .30901 L
.56889 .30901 L
.56895 .30901 L
.569 .30901 L
.5691 .30901 L
.5692 .30901 L
.56929 .30901 L
.56939 .30901 L
.56947 .30901 L
.56968 .30901 L
.56988 .30901 L
.57028 .30901 L
.57071 .30901 L
.57219 .30902 L
.5739 .30902 L
.57471 .30902 L
.57545 .30902 L
.57582 .30902 L
.57623 .30902 L
.57664 .30902 L
Mistroke
.57686 .30902 L
.57707 .30902 L
.57727 .30902 L
.57737 .30902 L
.57745 .30902 L
.57753 .30902 L
.57762 .30902 L
.57771 .30902 L
.57781 .30902 L
.57791 .30902 L
.578 .30902 L
.5781 .30902 L
.57816 .30902 L
.57821 .30902 L
.57841 .30902 L
.57859 .30902 L
.579 .30902 L
.57944 .30902 L
.58024 .30902 L
.58173 .30902 L
.58329 .30902 L
.58418 .30902 L
.58461 .30902 L
.58502 .30902 L
.5854 .30902 L
.5856 .30902 L
.58581 .30902 L
.58601 .30902 L
.58619 .30902 L
.58628 .30902 L
.58637 .30902 L
.58646 .30902 L
.58654 .30902 L
.58664 .30902 L
.58674 .30902 L
.58683 .30902 L
.58692 .30902 L
.58702 .30902 L
.58714 .30902 L
.58734 .30902 L
.58755 .30902 L
.58778 .30902 L
.58818 .30902 L
.58975 .30902 L
.59122 .30902 L
.59205 .30902 L
.59284 .30902 L
.59355 .30902 L
.59395 .30902 L
.59433 .30902 L
Mistroke
.59454 .30902 L
.59473 .30902 L
.59484 .30902 L
.59495 .30902 L
.595 .30902 L
.59506 .30902 L
.59512 .30902 L
.59517 .30902 L
.59528 .30902 L
.59533 .30902 L
.59539 .30902 L
.59549 .30902 L
.59554 .30902 L
.59559 .30902 L
.59569 .30902 L
.59578 .30902 L
.59597 .30902 L
.59615 .30902 L
.59632 .30902 L
.5967 .30902 L
.59747 .30902 L
.59897 .30902 L
.6006 .30902 L
.60103 .30902 L
.60149 .30902 L
.60191 .30902 L
.60231 .30902 L
.60268 .30902 L
.60287 .30902 L
.60308 .30902 L
.6032 .30902 L
.60331 .30902 L
.60342 .30902 L
.60352 .30902 L
.60363 .30902 L
.60372 .30902 L
.60382 .30902 L
.60388 .30902 L
.60393 .30902 L
.60403 .30902 L
.60413 .30902 L
.60421 .30902 L
.60431 .30902 L
.60452 .30902 L
.60471 .30902 L
.60507 .30902 L
.60544 .30902 L
.6071 .30902 L
.60868 .30902 L
.60938 .30902 L
Mistroke
.61013 .30902 L
.61053 .30902 L
.61089 .30902 L
.61128 .30902 L
.61149 .30902 L
.61169 .30902 L
.61179 .30902 L
.61191 .30902 L
.612 .30902 L
.6121 .30902 L
.61216 .30902 L
.61222 .30902 L
.61228 .30902 L
.61234 .30902 L
.61244 .30902 L
.6125 .30902 L
.61255 .30902 L
.61265 .30902 L
.61274 .30902 L
.61295 .30902 L
.61315 .30902 L
.61336 .30902 L
.61413 .30902 L
.61497 .30902 L
.61666 .30902 L
.61747 .30902 L
.61823 .30902 L
.61866 .30902 L
.61911 .30902 L
.61932 .30902 L
.61953 .30902 L
.61971 .30902 L
.61992 .30902 L
.62012 .30902 L
.62021 .30902 L
.62031 .30902 L
.62041 .30902 L
.6205 .30902 L
.62059 .30902 L
.62067 .30902 L
.62077 .30902 L
.62087 .30902 L
.62096 .30902 L
.62106 .30902 L
.62117 .30902 L
.62128 .30902 L
.62148 .30902 L
.62188 .30902 L
.62225 .30902 L
.62295 .30902 L
Mistroke
.62442 .30902 L
.62525 .30902 L
.62603 .30902 L
.62679 .30902 L
.62722 .30902 L
.62762 .30902 L
.62801 .30902 L
.62823 .30902 L
.62844 .30902 L
.62855 .30902 L
.62866 .30902 L
.62875 .30902 L
.62886 .30902 L
.62891 .30902 L
.62897 .30902 L
.62903 .30902 L
.62909 .30902 L
.62919 .30902 L
.62925 .30902 L
.6293 .30902 L
.62951 .30902 L
.62969 .30902 L
.6301 .30902 L
.63047 .30902 L
.63083 .30902 L
.6325 .30902 L
.63397 .30902 L
.63438 .30902 L
.63481 .30902 L
.63519 .30902 L
.63559 .30902 L
.63582 .30902 L
.63603 .30902 L
.63622 .30902 L
.63643 .30902 L
.63653 .30902 L
.63663 .30902 L
.63671 .30902 L
.63681 .30902 L
.63691 .30902 L
.63701 .30902 L
.63711 .30902 L
.6372 .30902 L
.6373 .30902 L
.63736 .30902 L
.63742 .30902 L
.63752 .30902 L
.63763 .30902 L
.63781 .30902 L
.63802 .30902 L
Mistroke
.63847 .30902 L
.63889 .30902 L
.64038 .30902 L
.64201 .30902 L
.64244 .30902 L
.6429 .30902 L
.64332 .30902 L
.64371 .30902 L
.64408 .30902 L
.64429 .30902 L
.64448 .30902 L
.64468 .30902 L
.64479 .30902 L
.64489 .30902 L
.64495 .30902 L
.645 .30902 L
.6451 .30902 L
.64516 .30902 L
.64521 .30902 L
.64527 .30902 L
.64533 .30902 L
.64543 .30902 L
.64553 .30902 L
.64563 .30902 L
.64572 .30902 L
.6459 .30902 L
.64609 .30902 L
.64651 .30902 L
.6469 .30902 L
.64837 .30902 L
.64918 .30902 L
.65004 .30902 L
.65078 .30902 L
.6512 .30902 L
.65159 .30902 L
.65198 .30902 L
.65217 .30902 L
.65236 .30902 L
.65257 .30902 L
.65276 .30902 L
.65286 .30902 L
.65296 .30902 L
.65302 .30902 L
.65307 .30902 L
.65313 .30902 L
.65319 .30902 L
.65328 .30902 L
.65337 .30902 L
.65347 .30902 L
.65356 .30902 L
Mistroke
.65372 .30902 L
.6539 .30902 L
.65431 .30902 L
.65468 .30902 L
.65632 .30902 L
.65712 .30902 L
.65785 .30902 L
.65855 .30902 L
.65932 .30902 L
.65974 .30902 L
.65994 .30902 L
.66012 .30902 L
.6603 .30902 L
.6605 .30902 L
.6606 .30902 L
.6607 .30902 L
.66079 .30902 L
.66089 .30902 L
.66099 .30902 L
.66105 .30902 L
.6611 .30902 L
.66119 .30902 L
.66129 .30902 L
.66138 .30902 L
.66146 .30902 L
.66165 .30902 L
.66186 .30902 L
.66205 .30902 L
.66247 .30902 L
.66323 .30902 L
.66395 .30902 L
.66555 .30902 L
.66625 .30902 L
.66701 .30902 L
.66743 .30902 L
.66762 .30902 L
.66782 .30902 L
.668 .30902 L
.6682 .30902 L
.6683 .30902 L
.6684 .30902 L
.66849 .30902 L
.66859 .30902 L
.66869 .30902 L
.66875 .30902 L
.6688 .30902 L
.6689 .30902 L
.669 .30902 L
.66906 .30902 L
.66912 .30902 L
Mistroke
.66918 .30902 L
.66924 .30902 L
.66934 .30902 L
.66945 .30902 L
.66967 .30902 L
.66988 .30902 L
.67027 .30902 L
.67105 .30902 L
.67188 .30902 L
.67336 .30902 L
.67412 .30902 L
.67453 .30902 L
.67493 .30902 L
.6753 .30902 L
.67549 .30902 L
.6757 .30902 L
.67589 .30902 L
.67606 .30902 L
.67615 .30902 L
.67624 .30902 L
.67632 .30902 L
.6764 .30902 L
.6765 .30902 L
.67659 .30902 L
.67669 .30902 L
.67674 .30902 L
.6768 .30902 L
.67688 .30902 L
.67697 .30902 L
.67707 .30902 L
.67716 .30902 L
.67738 .30902 L
.67757 .30902 L
.678 .30902 L
.67883 .30902 L
.67969 .30902 L
.68052 .30902 L
.6813 .30902 L
.682 .30902 L
.68236 .30902 L
.68276 .30902 L
.68316 .30902 L
.68337 .30902 L
.68358 .30902 L
.68368 .30902 L
.68377 .30902 L
.68385 .30902 L
.68394 .30902 L
.68404 .30902 L
.68413 .30902 L
Mistroke
.68423 .30902 L
.68428 .30902 L
.68433 .30902 L
.68443 .30902 L
.68449 .30902 L
.68454 .30902 L
.68464 .30902 L
.68476 .30902 L
.68496 .30902 L
.68514 .30902 L
.68559 .30902 L
.68602 .30902 L
.68748 .30902 L
.68832 .30902 L
.6891 .30902 L
.68987 .30902 L
.6903 .30902 L
.69069 .30902 L
.69091 .30902 L
.69111 .30902 L
.69133 .30902 L
.69145 .30902 L
.69156 .30902 L
.69167 .30902 L
.69176 .30902 L
.69181 .30902 L
.69187 .30902 L
.69193 .30902 L
.69198 .30902 L
.69208 .30902 L
.69218 .30902 L
.69228 .30902 L
.69238 .30902 L
.69257 .30902 L
.69275 .30902 L
.69316 .30902 L
.69398 .30902 L
.69546 .30902 L
.69625 .30902 L
.69708 .30902 L
.69742 .30902 L
.69779 .30902 L
.698 .30902 L
.69819 .30902 L
.69857 .30902 L
.69875 .30902 L
.69896 .30902 L
.69906 .30902 L
.69912 .30902 L
.69917 .30902 L
Mistroke
.69927 .30902 L
.69937 .30902 L
.69946 .30902 L
.69955 .30902 L
.69964 .30902 L
.69972 .30902 L
.69982 .30902 L
.69992 .30902 L
.70011 .30902 L
.70053 .30902 L
.70098 .30902 L
.70178 .30902 L
.70338 .30902 L
.70407 .30902 L
.70483 .30902 L
.70525 .30902 L
.70543 .30902 L
.70564 .30902 L
.70582 .30902 L
.70601 .30902 L
.70621 .30902 L
.7063 .30902 L
.7064 .30902 L
.70651 .30902 L
.70661 .30902 L
.70668 .30902 L
.70674 .30902 L
.70679 .30902 L
.70685 .30902 L
.7069 .30902 L
.70696 .30902 L
.70702 .30902 L
.70707 .30902 L
.70717 .30902 L
.70728 .30902 L
.70749 .30902 L
.7077 .30902 L
.70808 .30902 L
.70885 .30902 L
.70968 .30902 L
.71116 .30902 L
.71191 .30902 L
.71233 .30902 L
.71272 .30902 L
.71306 .30902 L
.71325 .30902 L
.71343 .30902 L
.71362 .30902 L
.7138 .30902 L
.71389 .30902 L
Mistroke
.714 .30902 L
.71409 .30902 L
.71418 .30902 L
.71428 .30902 L
.71438 .30902 L
.71447 .30902 L
.71456 .30902 L
.71466 .30902 L
.71477 .30902 L
.71496 .30902 L
.71534 .30902 L
.71569 .30902 L
.71735 .30902 L
.7181 .30902 L
.71889 .30902 L
.71931 .30902 L
.71976 .30902 L
.72018 .30902 L
.72056 .30902 L
.72077 .30902 L
.72097 .30902 L
.72107 .30902 L
.72118 .30902 L
.72123 .30902 L
.7213 .30902 L
.72135 .30902 L
.7214 .30902 L
.7215 .30902 L
.72159 .30902 L
.72169 .30902 L
.72179 .30902 L
.72184 .30902 L
.7219 .30902 L
.72201 .30902 L
.7222 .30902 L
.72258 .30902 L
.72298 .30902 L
.72369 .30902 L
.72528 .30902 L
.72598 .30902 L
.72673 .30902 L
.72715 .30902 L
.72733 .30902 L
.72754 .30902 L
.72771 .30902 L
.7279 .30902 L
.72811 .30902 L
.7283 .30902 L
.7284 .30902 L
.7285 .30902 L
Mistroke
.72856 .30902 L
.72861 .30902 L
.72867 .30902 L
.72872 .30902 L
.72878 .30902 L
.72883 .30902 L
.72894 .30902 L
.72899 .30902 L
.72905 .30902 L
.72917 .30902 L
.72937 .30902 L
.72956 .30902 L
.72997 .30902 L
.73076 .30902 L
.7315 .30902 L
.73235 .30902 L
.73316 .30902 L
.73395 .30902 L
.7344 .30902 L
.73461 .30902 L
.73481 .30902 L
.73499 .30902 L
.73516 .30902 L
.73534 .30902 L
.73544 .30902 L
.73554 .30902 L
.73563 .30902 L
.73573 .30902 L
.73581 .30902 L
.7359 .30902 L
.736 .30902 L
.73606 .30902 L
.73611 .30902 L
.7362 .30902 L
.7363 .30902 L
.73651 .30902 L
.7367 .30902 L
.73707 .30902 L
.73789 .30902 L
.73936 .30902 L
.74014 .30902 L
.74057 .30902 L
.74097 .30902 L
.74134 .30902 L
.74167 .30902 L
.74205 .30902 L
.74225 .30902 L
.74245 .30902 L
.74255 .30902 L
.74266 .30902 L
Mistroke
.74276 .30902 L
.74285 .30902 L
.74294 .30902 L
.74303 .30902 L
.74313 .30902 L
.74322 .30902 L
.74327 .30902 L
.74333 .30902 L
.74343 .30902 L
.74362 .30902 L
.74384 .30902 L
.74404 .30902 L
.74476 .30902 L
.74552 .30902 L
.74629 .30902 L
.7471 .30902 L
.7478 .30902 L
.74819 .30902 L
.74855 .30902 L
.74894 .30902 L
.74916 .30902 L
.74936 .30902 L
.74945 .30902 L
.74955 .30902 L
.74963 .30902 L
.74972 .30902 L
.74982 .30902 L
.74991 .30902 L
.74996 .30902 L
.75001 .30902 L
.75011 .30902 L
.75021 .30902 L
.75031 .30902 L
.75036 .30902 L
.75042 .30902 L
.75053 .30902 L
.75073 .30902 L
.75091 .30902 L
.75134 .30902 L
.75178 .30902 L
.75339 .30902 L
.75408 .30902 L
.75484 .30902 L
.75526 .30902 L
.75565 .30902 L
.75602 .30902 L
.75621 .30902 L
.75641 .30902 L
.75653 .30902 L
.75663 .30902 L
Mistroke
.75673 .30902 L
.75683 .30902 L
.75689 .30902 L
.75694 .30902 L
.75701 .30902 L
.75707 .30902 L
.75717 .30902 L
.75723 .30902 L
.75728 .30902 L
.75738 .30902 L
.75747 .30902 L
.75768 .30902 L
.75788 .30902 L
.75809 .30902 L
.75891 .30902 L
.7598 .30902 L
.76057 .30902 L
.76142 .30902 L
.76181 .30902 L
.76224 .30902 L
.76264 .30902 L
.763 .30902 L
.76321 .30902 L
.7634 .30902 L
.76351 .30902 L
.7636 .30902 L
.76366 .30902 L
.76372 .30902 L
.76377 .30902 L
.76383 .30902 L
.76393 .30902 L
.76403 .30902 L
.76413 .30902 L
.76419 .30902 L
.76425 .30902 L
.76436 .30902 L
.76447 .30902 L
.76469 .30902 L
.76512 .30902 L
.76552 .30902 L
.76627 .30902 L
.76709 .30902 L
.76796 .30902 L
.76873 .30902 L
.76917 .30902 L
.76958 .30902 L
.76977 .30902 L
.76995 .30902 L
.77012 .30902 L
.77029 .30902 L
Mistroke
.77038 .30902 L
.77048 .30902 L
.77058 .30902 L
.77066 .30902 L
.77076 .30902 L
.77085 .30902 L
.77096 .30902 L
.77106 .30902 L
.77116 .30902 L
.77127 .30902 L
.77146 .30902 L
.77165 .30902 L
.77183 .30902 L
.77265 .30902 L
.77412 .30902 L
.77485 .30902 L
.77563 .30902 L
.77608 .30902 L
.77649 .30902 L
.77669 .30902 L
.7769 .30902 L
.777 .30902 L
.77711 .30902 L
.7772 .30902 L
.77729 .30902 L
.77738 .30902 L
.77748 .30902 L
.77758 .30902 L
.77769 .30902 L
.77778 .30902 L
.77787 .30902 L
.77796 .30902 L
.77804 .30902 L
.77825 .30902 L
.77847 .30902 L
.77886 .30902 L
.78032 .30902 L
.78114 .30902 L
.78191 .30902 L
.78261 .30902 L
.783 .30902 L
.78336 .30902 L
.78357 .30902 L
.78376 .30902 L
.78393 .30902 L
.78403 .30902 L
.78412 .30902 L
.78421 .30902 L
.78431 .30902 L
.7844 .30902 L
Mistroke
.78451 .30902 L
.78456 .30902 L
.78462 .30902 L
.78473 .30902 L
.78483 .30902 L
.78492 .30902 L
.78512 .30902 L
.78531 .30902 L
.78574 .30902 L
.7866 .30902 L
.78809 .30902 L
.78849 .30902 L
.78893 .30902 L
.7893 .30902 L
.78971 .30902 L
.78993 .30902 L
.79014 .30902 L
.79034 .30902 L
.79044 .30902 L
.79055 .30902 L
.79065 .30902 L
.79074 .30902 L
.79083 .30902 L
.79092 .30902 L
.79102 .30902 L
.79111 .30902 L
.79121 .30902 L
.79126 .30902 L
.79132 .30902 L
.79137 .30902 L
.79143 .30902 L
.79154 .30902 L
.79174 .30902 L
.79197 .30902 L
.79219 .30902 L
.79301 .30902 L
.79452 .30902 L
.79531 .30902 L
.79574 .30902 L
.79614 .30902 L
.79657 .30902 L
.79679 .30902 L
.79703 .30902 L
.79714 .30902 L
.79725 .30902 L
.79736 .30902 L
.79746 .30902 L
.79752 .30902 L
.79757 .30902 L
.79767 .30902 L
Mistroke
.79776 .30902 L
.79786 .30902 L
.79796 .30902 L
.79805 .30902 L
.79815 .30902 L
.79826 .30902 L
.79849 .30902 L
.7987 .30902 L
.79947 .30902 L
.80113 .30902 L
.80186 .30902 L
.80225 .30902 L
.80267 .30902 L
.80307 .30902 L
.80325 .30902 L
.80344 .30902 L
.80361 .30902 L
.80379 .30902 L
.80389 .30902 L
.80398 .30902 L
.80408 .30902 L
.80416 .30902 L
.80425 .30902 L
.80436 .30902 L
.80446 .30902 L
.80456 .30902 L
.80465 .30902 L
.80473 .30902 L
.80483 .30902 L
.80492 .30902 L
.80532 .30902 L
.80575 .30902 L
.80746 .30902 L
.80827 .30902 L
.80902 .30902 L
.80939 .30902 L
.80979 .30902 L
.81 .30902 L
.8102 .30902 L
.81041 .30902 L
.81053 .30902 L
.81064 .30902 L
.81073 .30902 L
.81083 .30902 L
.81092 .30902 L
.81101 .30902 L
.81111 .30902 L
.81117 .30902 L
.81122 .30902 L
.81132 .30902 L
Mistroke
.81142 .30902 L
.8116 .30902 L
.81177 .30902 L
.81216 .30902 L
.81367 .30902 L
.81446 .30902 L
.8153 .30902 L
.81573 .30902 L
.81595 .30902 L
.81619 .30902 L
.81642 .30902 L
.81662 .30902 L
.81682 .30902 L
.81702 .30902 L
.81711 .30902 L
.81721 .30902 L
.81726 .30902 L
.81732 .30902 L
.81742 .30902 L
.81751 .30902 L
.81761 .30902 L
.8177 .30902 L
.81779 .30902 L
.8179 .30902 L
.818 .30902 L
.81823 .30902 L
.81864 .30902 L
.8203 .30902 L
.82104 .30902 L
.82143 .30902 L
.82184 .30902 L
.82225 .30902 L
.82262 .30902 L
.8228 .30902 L
.82299 .30902 L
.82317 .30902 L
.82334 .30902 L
.82344 .30902 L
.82355 .30902 L
.82365 .30902 L
.82374 .30902 L
.82384 .30902 L
.8239 .30902 L
.82395 .30902 L
.82405 .30902 L
.82411 .30902 L
.82417 .30902 L
.82426 .30902 L
.82435 .30902 L
.82456 .30902 L
Mistroke
.82474 .30902 L
.82493 .30902 L
.82651 .30902 L
.8272 .30902 L
.82796 .30902 L
.82833 .30902 L
.82872 .30902 L
.82894 .30902 L
.82913 .30902 L
.82932 .30902 L
.82952 .30902 L
.82962 .30902 L
.82973 .30902 L
.82984 .30902 L
.82993 .30902 L
.83004 .30902 L
.8301 .30902 L
.83016 .30902 L
.83027 .30902 L
.83032 .30902 L
.83038 .30902 L
.83043 .30902 L
.83048 .30902 L
.83058 .30902 L
.83068 .30902 L
.83077 .30902 L
.83098 .30902 L
.83119 .30902 L
.83159 .30902 L
.83195 .30902 L
.83277 .30902 L
.83349 .30902 L
.83425 .30902 L
.83463 .30902 L
.83504 .30902 L
.83543 .30902 L
.83578 .30902 L
.836 .30902 L
.8361 .30902 L
.8362 .30902 L
.8363 .30902 L
.83639 .30902 L
.83648 .30902 L
.83659 .30902 L
.83664 .30902 L
.8367 .30902 L
.8368 .30902 L
.83686 .30902 L
.83691 .30902 L
.83697 .30902 L
Mistroke
.83703 .30902 L
.83714 .30902 L
.83725 .30902 L
.83745 .30902 L
.83782 .30902 L
.83822 .30902 L
.83905 .30902 L
.83977 .30902 L
.84053 .30902 L
.84091 .30902 L
.84134 .30902 L
.84172 .30902 L
.84208 .30902 L
.8423 .30902 L
.8424 .30902 L
.8425 .30902 L
.84259 .30902 L
.84269 .30902 L
.84279 .30902 L
.84289 .30902 L
.84295 .30902 L
.843 .30902 L
.8431 .30902 L
.84316 .30902 L
.84321 .30902 L
.84327 .30902 L
.84334 .30902 L
.84345 .30902 L
.84355 .30902 L
.84375 .30902 L
.84413 .30902 L
.84454 .30902 L
.84537 .30902 L
.84613 .30902 L
.84685 .30902 L
.84725 .30902 L
.84767 .30902 L
.84806 .30902 L
.84842 .30902 L
.84862 .30902 L
.84881 .30902 L
.84892 .30902 L
.84901 .30902 L
.84912 .30902 L
.84918 .30902 L
.84924 .30902 L
.84929 .30902 L
.84935 .30902 L
.84945 .30902 L
.84951 .30902 L
Mistroke
.84956 .30902 L
.84962 .30902 L
.84968 .30902 L
.84988 .30902 L
.8501 .30902 L
.85052 .30902 L
.85092 .30902 L
.85166 .30902 L
.85248 .30902 L
.85292 .30902 L
.85334 .30902 L
.85374 .30902 L
.8541 .30902 L
.8545 .30902 L
.85471 .30902 L
.85494 .30902 L
.85511 .30902 L
.85521 .30902 L
.8553 .30902 L
.85539 .30902 L
.85548 .30902 L
.85556 .30902 L
.85564 .30902 L
.85574 .30902 L
.85582 .30902 L
.85592 .30902 L
.85602 .30902 L
.85623 .30902 L
.85642 .30902 L
.85721 .30902 L
.85794 .30902 L
.8588 .30902 L
.85922 .30902 L
.8596 .30902 L
.85998 .30902 L
.8604 .30902 L
.8606 .30902 L
.86081 .30902 L
.86104 .30902 L
.86115 .30902 L
.86125 .30902 L
.86134 .30902 L
.86144 .30902 L
.86155 .30902 L
.8616 .30902 L
.86165 .30902 L
.86175 .30902 L
.86184 .30902 L
.86193 .30902 L
.86203 .30902 L
Mistroke
.86212 .30902 L
.86221 .30902 L
.86237 .30902 L
.86257 .30902 L
.86275 .30902 L
.86442 .30902 L
.86515 .30902 L
.86554 .30902 L
.86596 .30902 L
.86636 .30902 L
.86673 .30902 L
.86691 .30902 L
.8671 .30902 L
.86729 .30902 L
.86746 .30902 L
.86756 .30902 L
.86761 .30902 L
.86767 .30902 L
.86777 .30902 L
.86786 .30902 L
.86795 .30902 L
.86804 .30902 L
.86813 .30902 L
.86823 .30902 L
.86833 .30902 L
.86845 .30902 L
.86866 .30902 L
.86905 .30902 L
.87061 .30902 L
.87143 .30902 L
.87189 .30902 L
.87232 .30902 L
.87273 .30902 L
.87296 .30902 L
.87318 .30902 L
.87337 .30902 L
.87355 .30902 L
.87365 .30902 L
.87376 .30902 L
.87386 .30902 L
.87395 .30902 L
.87404 .30902 L
.87414 .30902 L
.87423 .30902 L
.87431 .30902 L
.8744 .30902 L
.87451 .30902 L
.8747 .30902 L
.8749 .30902 L
.87511 .30902 L
Mistroke
.87548 .30902 L
.87706 .30902 L
.87775 .30902 L
.87815 .30902 L
.87851 .30902 L
.87888 .30902 L
.87906 .30902 L
.87927 .30902 L
.87948 .30902 L
.87958 .30902 L
.87968 .30902 L
.87978 .30902 L
.87988 .30902 L
.87998 .30902 L
.88006 .30902 L
.88017 .30902 L
.88023 .30902 L
.88028 .30902 L
.88038 .30902 L
.88048 .30902 L
.88059 .30902 L
.88069 .30902 L
.88087 .30902 L
.88129 .30902 L
.88174 .30902 L
.88331 .30902 L
.88374 .30902 L
.8842 .30902 L
.88463 .30902 L
.88503 .30902 L
.88523 .30902 L
.88544 .30902 L
.88562 .30902 L
.88571 .30902 L
.88581 .30902 L
.88586 .30902 L
.88592 .30902 L
.88602 .30902 L
.88608 .30902 L
.88614 .30902 L
.8862 .30902 L
.88625 .30902 L
.88635 .30902 L
.88641 .30902 L
.88646 .30902 L
.88656 .30902 L
.88666 .30902 L
.88684 .30902 L
.88704 .30902 L
.8874 .30902 L
Mistroke
.8882 .30902 L
.88897 .30902 L
.88979 .30902 L
.89022 .30902 L
.89069 .30902 L
.89089 .30902 L
.89112 .30902 L
.89133 .30902 L
.89152 .30902 L
.89171 .30902 L
.89181 .30902 L
.89191 .30902 L
.89201 .30902 L
.89207 .30902 L
.89212 .30902 L
.89222 .30902 L
.89233 .30902 L
.89243 .30902 L
.89249 .30902 L
.89254 .30902 L
.89274 .30902 L
.89285 .30902 L
.89297 .30902 L
.89319 .30902 L
.89471 .30902 L
.89553 .30902 L
.89629 .30902 L
.89672 .30902 L
.89694 .30902 L
.89718 .30902 L
.89738 .30902 L
.89748 .30902 L
.89759 .30902 L
.8977 .30902 L
.89779 .30902 L
.89789 .30902 L
.89798 .30902 L
.89807 .30902 L
.89817 .30902 L
.89826 .30902 L
.89835 .30902 L
.89844 .30902 L
.89854 .30902 L
.89865 .30902 L
.89875 .30902 L
.89915 .30902 L
.89958 .30902 L
.90105 .30902 L
.90188 .30902 L
.90234 .30902 L
Mistroke
.90277 .30902 L
.90314 .30902 L
.90335 .30902 L
.90355 .30902 L
.90366 .30902 L
.90376 .30902 L
.90385 .30902 L
.90395 .30902 L
.90401 .30902 L
.90406 .30902 L
.90412 .30902 L
.90418 .30902 L
.90428 .30902 L
.90433 .30902 L
.90439 .30902 L
.90449 .30902 L
.90458 .30902 L
.90476 .30902 L
.90517 .30902 L
.9059 .30902 L
.9067 .30902 L
.90756 .30902 L
.90793 .30902 L
.90832 .30902 L
.90855 .30902 L
.90875 .30902 L
.90896 .30902 L
.90916 .30902 L
.90933 .30902 L
.90951 .30902 L
.90961 .30902 L
.9097 .30902 L
.90979 .30902 L
.90988 .30902 L
.90997 .30902 L
.91007 .30902 L
.91018 .30902 L
.91028 .30902 L
.91037 .30902 L
.91045 .30902 L
.91064 .30902 L
.91082 .30902 L
.91103 .30902 L
.91143 .30902 L
.91217 .30902 L
.91304 .30902 L
.91342 .30902 L
.91384 .30902 L
.9142 .30902 L
.91459 .30902 L
Mistroke
.91481 .30902 L
.915 .30902 L
.9152 .30902 L
.91539 .30902 L
.91548 .30902 L
.91559 .30902 L
.91564 .30902 L
.9157 .30902 L
.91581 .30902 L
.91591 .30902 L
.91601 .30902 L
.91609 .30902 L
.91619 .30902 L
.9163 .30902 L
.91641 .30902 L
.91664 .30902 L
.91706 .30902 L
.91874 .30902 L
.91947 .30902 L
.91989 .30902 L
.92028 .30902 L
.92047 .30902 L
.92066 .30902 L
.92083 .30902 L
.92101 .30902 L
.9211 .30902 L
.9212 .30902 L
.92129 .30902 L
.92138 .30902 L
.92148 .30902 L
.92153 .30902 L
.92159 .30902 L
.92168 .30902 L
.92179 .30902 L
.92184 .30902 L
.92189 .30902 L
.92199 .30902 L
.92209 .30902 L
.92218 .30902 L
.92239 .30902 L
.92261 .30902 L
.92338 .30902 L
.92419 .30902 L
.92497 .30902 L
.92566 .30902 L
.92605 .30902 L
.92642 .30902 L
.92662 .30902 L
.92682 .30902 L
.92699 .30902 L
Mistroke
.92709 .30902 L
.92718 .30902 L
.92727 .30902 L
.92736 .30902 L
.92746 .30902 L
.92757 .30902 L
.92762 .30902 L
.92768 .30902 L
.92778 .30902 L
.92789 .30902 L
.92798 .30902 L
.92818 .30902 L
.92837 .30902 L
.92879 .30902 L
.92966 .30902 L
.93049 .30902 L
.9309 .30902 L
.93128 .30902 L
.93166 .30902 L
.93199 .30902 L
.93217 .30902 L
.93237 .30902 L
.93258 .30902 L
.93268 .30902 L
.93277 .30902 L
.93286 .30902 L
.93296 .30902 L
.93306 .30902 L
.93316 .30902 L
.93326 .30902 L
.93336 .30902 L
.93344 .30902 L
.93353 .30902 L
.93359 .30902 L
.93364 .30902 L
.93374 .30902 L
.93396 .30902 L
.93437 .30902 L
.93606 .30902 L
.93683 .30902 L
.93725 .30902 L
.93764 .30902 L
.93801 .30902 L
.93821 .30902 L
.9384 .30902 L
.93857 .30902 L
.93866 .30902 L
.93875 .30902 L
.93884 .30902 L
.93893 .30902 L
Mistroke
.93903 .30902 L
.93912 .30902 L
.93922 .30902 L
.93928 .30902 L
.93933 .30902 L
.93952 .30902 L
.9397 .30902 L
.93989 .30902 L
.94071 .30902 L
.94219 .30902 L
.94258 .30902 L
.94295 .30902 L
.94315 .30902 L
.94338 .30902 L
.94356 .30902 L
.94377 .30902 L
.94396 .30902 L
.94414 .30902 L
.94424 .30902 L
.94433 .30902 L
.94443 .30902 L
.94453 .30902 L
.94462 .30902 L
.94471 .30902 L
.94479 .30902 L
.94487 .30902 L
.94496 .30902 L
.94506 .30902 L
.94515 .30902 L
.94524 .30902 L
.94562 .30902 L
.94602 .30902 L
.94675 .30902 L
.94761 .30902 L
.94841 .30902 L
.9488 .30902 L
.94922 .30902 L
.94944 .30902 L
.94964 .30902 L
.94975 .30902 L
.94987 .30902 L
.94999 .30902 L
.95005 .30902 L
.95011 .30902 L
.95021 .30902 L
.9503 .30902 L
.9504 .30902 L
.95046 .30902 L
.95051 .30902 L
.95059 .30902 L
Mistroke
.95069 .30902 L
.95079 .30902 L
.95088 .30902 L
.95109 .30902 L
.95128 .30902 L
.95172 .30902 L
.95252 .30902 L
.95338 .30902 L
.95379 .30902 L
.95418 .30902 L
.95453 .30902 L
.95473 .30902 L
.95491 .30902 L
.9551 .30902 L
.95528 .30902 L
.95548 .30902 L
.95558 .30902 L
.95569 .30902 L
.95579 .30902 L
.95589 .30902 L
.95598 .30902 L
.95608 .30902 L
.95619 .30902 L
.95625 .30902 L
.9563 .30902 L
.9564 .30902 L
.95651 .30902 L
.95668 .30902 L
.95687 .30902 L
.95721 .30902 L
.95798 .30902 L
.9588 .30902 L
.95923 .30902 L
.95969 .30902 L
.96009 .30902 L
.9603 .30902 L
.96053 .30902 L
.96074 .30902 L
.96093 .30902 L
.96103 .30902 L
.96113 .30902 L
.96121 .30902 L
.96131 .30902 L
.96136 .30902 L
.96142 .30902 L
.96151 .30902 L
.96157 .30902 L
.96163 .30902 L
.96169 .30902 L
.96174 .30902 L
Mistroke
.96184 .30902 L
.96189 .30902 L
.96194 .30902 L
.96214 .30902 L
.96231 .30902 L
.9625 .30902 L
.96289 .30902 L
.96377 .30902 L
.96458 .30902 L
.96496 .30902 L
.96537 .30902 L
.96577 .30902 L
.96613 .30902 L
.96635 .30902 L
.96656 .30902 L
.96674 .30902 L
.96685 .30902 L
.96694 .30902 L
.96705 .30902 L
.96714 .30902 L
.96725 .30902 L
.96731 .30902 L
.96736 .30902 L
.96742 .30902 L
.96747 .30902 L
.96759 .30902 L
.9677 .30902 L
.96781 .30902 L
.9682 .30902 L
.96856 .30902 L
.96937 .30902 L
.97008 .30902 L
.97084 .30902 L
.97125 .30902 L
.97162 .30902 L
.9718 .30902 L
.972 .30902 L
.97218 .30902 L
.97235 .30902 L
.97245 .30902 L
.97255 .30902 L
.97265 .30902 L
.97274 .30902 L
.97284 .30902 L
.9729 .30902 L
.97296 .30902 L
.97306 .30902 L
.97316 .30902 L
.97339 .30902 L
.97361 .30902 L
Mistroke
.97402 .30902 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{421.375, 260.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008>0001AB000`400?l00000o`00003ooooooooo
oooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo
003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooo
oooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool0
0?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooooooo
ool@ooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooo
ooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo0ol0003o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0
003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo
00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`
ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLoooo
o`00<?ooool3o`000?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?oo
ool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0
033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomco
oooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooo
oooLooooo`00<?ooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo0?ooooooL_ooool0
033ooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`3oooooog;ooooo000`ooooo`03
o`000?oooooooooo06Oooooo00?o0000ooooooooool0oooooombooooo`00<?ooool3o`0006Oooooo
00?o0000ooooooooool0oooooombooooo`00<?ooool00ol0003oooooooooo`1Wooooo`03o`000?oo
oooooooo0?ooooooL_ooool0033ooooo00?o0000ooooooooool0I_ooool2o`000?ooooooM?ooool0
033ooooo00?o0000ooooooooool0I_ooool00ol0003oooooo`00003oooooog?ooooo000`ooooo`03
o`000?oooooooooo06Kooooo00?o0000ooooool00000oooooomcooooo`00<?ooool00ol0003ooooo
ooooo`1Vooooo`03o`000?oooooo00000?ooooooLoooool0033ooooo00?o0000ooooooooool0I_oo
ool00ol0003oooooo`00003oooooog?ooooo000@ooooo`;ok^k^0oooool2onk^kQWooooo00?o0000
ooooooooool0I_ooool00ol0003oooooo`00003oooooog?ooooo000;ooooo`;o000000[o410@oooo
ooooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^0oooool4o`000008oa0@4?ooooooooooonk^
k_lb<S;o0000oc8b<_o^k^h:ooooo`03o`000?oooooooooo06Kooooo00?o0000ooooool00000oooo
oomcooooo`003?ooool00ol0003oooooooooo`02ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_oo
ool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02_ooool00ol0003ooooo
ooooo`1Vooooo`03o`000?oooooo00000?ooooooLoooool00003ooooool0003o000000Co00000_oo
ool5o`0000Cooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?oo
ooooooooooooool@41002_ooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooool00000oooooomcooooo`002Oooool01?m4A4CogMgMooooool00004ooooo`05onk^
k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000002_ooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ool00000oooooomcooooo`002Oooool01?oMgMgoEEEEooooool00003ooooo`07onk^k_mEEEGok^k^
ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000:ooooo`Co0000F_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo00000?oooooo
Loooool000[ooooo00?oMgMgolc<c?l000000oooool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oo
oooooooo00;ooooo00Go410@oooooooooooooooooa0@400:ooooo`03o`000?oooooooooo05_ooooo
00?o0000ooooooooool02?ooool00ol0003oooooo`00003oooooog?ooooo000:ooooo`03onk^k_m4
A4Co000000oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo
0_l00005ooooo`03o`000?oooooooooo05_ooooo0_l00009ooooo`03o`000?oooooo00000?oooooo
Loooool000_ooooo00?oMgMgo`000?ooool03?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo05[o
oooo00?o0000ooooool000002Oooool00ol0003oooooo`00003oooooog?ooooo000Xooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool0F_ooool00ol0003oooooo`000009ooooo`03
o`000?oooooo00000?ooooooLoooool002Sooooo0ol00005ooooo`03o`000?oooooooooo05[ooooo
00?o0000ooooool000002Oooool00ol0003oooooo`00003oooooog?ooooo000Yooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0F_ooool00ol0003oooooo`000009ooooo`03o`000?oo
oooo00000?ooooooLoooool002[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1J
ooooo`03o`000?oooooo000000Wooooo00?o0000ooooool000002Oooool00ol0003oooooooooo`3o
ooooofOooooo000`ooooo`03o`000?oooooooooo05[ooooo00?o0000ooooool000002Oooool00ol0
003oooooo`000009ooooo`;o0000oooooomXooooo`00<?ooool00ol0003oooooooooo`1Jooooo`03
o`000?oooooo000000Wooooo00?o0000ooooool000002Oooool2o`000?ooooooJ?ooool0033ooooo
00?o0000ooooooooool0F_ooool00ol0003oooooo`000009ooooo`03o`000?oooooo000000Wooooo
0_l0003oooooofSooooo000`ooooo`03o`000?oooooooooo05[ooooo00?o0000ooooool000002Ooo
ool00ol0003oooooo`000009ooooo`;o0000oooooomXooooo`00<?ooool3o`0005[ooooo00?o0000
ooooool000002Oooool00ol0003oooooo`000009ooooo`;o0000oooooomXooooo`00<?ooool00ol0
003oooooooooo`1Jooooo`03o`000?oooooo000000Wooooo00?o0000ooooool000002Oooool2o`00
0?ooooooJ?ooool0033ooooo00?o0000ooooooooool0F_ooool00ol0003oooooo`000008ooooo`04
o`000?ooooooooooo`0000Wooooo0_l0003oooooofSooooo000`ooooo`03o`000?oooooooooo05[o
oooo00?o0000ooooool000002?ooool01?l0003oooooooooool00009ooooo`;o0000oooooomXoooo
o`00<?ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooo000000Sooooo00Go0000oooooooo
ooooooooo`000008ooooo`;o0000oooooomXooooo`00<?ooool00ol0003oooooooooo`1Jooooo`03
o`000?oooooo000000Sooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo0000
0?ooooooJ?ooool0033ooooo00?o0000ooooooooool0F_ooool00ol0003oooooo`000008ooooo`05
o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003oooooofSooooo000`ooooo`03
o`000?oooooooooo05[ooooo00?o0000ooooool000002?ooool01Ol0003ooooooooooooooooo0000
00Oooooo00?o0000ooooool00000oooooomXooooo`00<?ooool00ol0003oooooooooo`1Jooooo`03
o`000?oooooo000000Sooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo0000
0?ooooooJ?ooool0033ooooo00?o0000ooooooooool0F_ooool00ol0003oooooo`000008ooooo`05
o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003oooooofSooooo000`ooooo`03
o`000?oooooooooo05[ooooo00?o0000ooooool000002?ooool01Ol0003ooooooooooooooooo0000
00Oooooo00?o0000ooooool00000oooooomXooooo`00<?ooool00ol0003oooooooooo`1Jooooo`03
o`000?oooooo000000Sooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo0000
0?ooooooJ?ooool0033ooooo0ol0001Jooooo`03o`000?oooooo000000Sooooo00Go0000oooooooo
ooooooooo`000007ooooo`03o`000?oooooo00000?ooooooJ?ooool0033ooooo00?o0000oooooooo
ool0FOooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool000001oooool0
0ol0003oooooo`00003oooooofSooooo000`ooooo`03o`000?oooooooooo05Wooooo00Co0000oooo
oooooooo00002?ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooool00000oooo
oomXooooo`00<?ooool00ol0003oooooooooo`1Iooooo`04o`000?ooooooooooo`0000Sooooo00Go
0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?ooooooJ?ooool0033ooooo00?o
0000ooooooooool0FOooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool0
00001oooool00ol0003oooooo`00003oooooofSooooo000`ooooo`03o`000?oooooooooo05Wooooo
00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000oooo
ool00000oooooomXooooo`00<?ooool00ol0003oooooooooo`1Iooooo`05o`000?oooooooooooooo
ool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooool00000oooooomX
ooooo`00<?ooool00ol0003oooooooooo`1Iooooo`05o`000?ooooooooooooooool000001oooool0
1Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000oooooomWooooo`00<?oo
ool00ol0003oooooooooo`1Iooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooo
oooooooooooo000000Oooooo00Co0000oooooooooooo0000oooooomWooooo`00<?ooool00ol0003o
ooooooooo`1Iooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo
000000Oooooo00Co0000oooooooooooo0000oooooomWooooo`00<?ooool00ol0003oooooooooo`1I
ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo
00Co0000oooooooooooo0000oooooomWooooo`00<?ooool3o`0005Wooooo00Go0000oooooooooooo
ooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool0003o
ooooofOooooo000`ooooo`03o`000?oooooooooo05Wooooo00Go0000ooooooooooooooooo`000007
ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool0003oooooofOooooo
000`ooooo`03o`000?oooooooooo05Wooooo00Go0000ooooooooooooooooo`000007ooooo`05o`00
0?ooooooooooooooool000001oooool01?l0003oooooooooool0003oooooofOooooo000`ooooo`03
o`000?oooooooooo04kooooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooooooo0000
00Oooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`000?ooooooIooo
ool0033ooooo00?o0000ooooooooool0C_ooool2o`0000Wooooo00Go0000ooooooooooooooooo`00
0007ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool0003oooooofOo
oooo000`ooooo`03o`000?oooooooooo04kooooo0_l00009ooooo`05o`000?ooooooooooooooool0
00001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000oooooomW
ooooo`00<?ooool00ol0003oooooooooo`1>ooooo`;o00002Oooool01Ol0003ooooooooooooooooo
000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Sooooo
00?o0000ooooooooool0oooooomLooooo`004?ooool2onk^kP?ooooo0_o^k^hIooooo`03o`000?oo
oooooooo04kooooo0_l00009ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooo
oooooooooooo000000Oooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`3ooooo
oecooooo0009ooooo`Go00000_ooool01oo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4
o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h:ooooo`03o`000?oooooooooo04go
oooo00?o0000ooooool000002Oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooo
ooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001oooool2o`000?ooooooG_oo
ool000Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h0
1_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02_ooool00ol0003o
ooooooooo`1=ooooo`03o`000?oooooo000000Wooooo00Go0000ooooooooooooooooo`000007oooo
o`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Oooooo0_l0
003ooooooekooooo00000ooooooo0000o`000004o`0000?ooooo00?oV9RHob4Q8Oo^k^h01Oooool0
0ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
400:ooooo`03o`000?oooooooooo04gooooo00?o0000ooooool000002Oooool01Ol0003ooooooooo
oooooooo000000Oooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?oooooooooooooo
ool000001oooool2o`000?ooooooG_ooool000_ooooo00?oV9RHob4Q8Oo^k^h00oooool01Oo^k^ko
EEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo
000000[ooooo00?o0000ooooooooool0COooool00ol0003oooooo`000009ooooo`05o`000?oooooo
ooooooooool000001oooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000oooooooooooo
ooooo`000007ooooo`;o0000oooooomNooooo`003?ooool02omgMgOoIVIVooooooooooook^k^oeEE
EOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000[ooooo1?l0001<ooooo`03o`000?oooooo000000Wooooo00Go0000oooooooooooo
ooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo
000000Oooooo00?o0000ooooool00000oooooomMooooo`003Oooool00ol0003oooooooooo`02onk^
kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400:
ooooo`03o`000?oooooooooo04gooooo00?o0000ooooool000002Oooool01Ol0003ooooooooooooo
oooo000000Oooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool0
00001oooool00ol0003oooooo`00003ooooooegooooo0009ooooo`05o`000?nj^[[ooooooiRHV?l@
41003_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool2o`00
00Gooooo00?o0000ooooooooool0COooool00ol0003oooooo`000009ooooo`05o`000?oooooooooo
ooooool000001oooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000oooooooooooooooo
o`000007ooooo`03o`000?oooooo00000?ooooooGOooool000Wooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c00<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`04
o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0COooool01?l0003oooooooooool00008
ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Kooooo
00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?ooooooGOooool002Sooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1=ooooo`04o`000?ooooooooooo`00
00Sooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001_oo
ool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooool00000oooooomMooooo`00:?oo
ool3o`0000Gooooo00?o0000ooooooooool0COooool01?l0003oooooooooool00008ooooo`05o`00
0?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000oooo
ooooooooooooo`000007ooooo`03o`000?oooooo00000?ooooooGOooool002Wooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`1=ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000
ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooo
oooooooooooo000000Oooooo00?o0000ooooool00000oooooomMooooo`00:_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo04gooooo00Co0000oooooooooooo00002?ooool01Ol0003o
oooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04oooo
o`05o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003ooooooegooooo000`oooo
o`03o`000?oooooooooo04gooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooo
oooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oo
ooooooooooooool000001oooool00ol0003oooooo`00003ooooooegooooo000`ooooo`03o`000?oo
oooooooo04gooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooooooo
ool000001oooool00ol0003oooooo`00003ooooooegooooo000`ooooo`03o`000?oooooooooo04go
oooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001ooo
ool00ol0003oooooo`00003ooooooegooooo000`ooooo`03o`000?oooooooooo04cooooo00Go0000
ooooooooooooooooo`000008ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000007ooooo`03
o`000?oooooo00000?ooooooGOooool0033ooooo0ol0001<ooooo`05o`000?ooooooooooooooool0
00002?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003o
oooooegooooo000`ooooo`03o`000?oooooooooo04cooooo00Go0000ooooooooooooooooo`000008
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?oooooo
GOooool0033ooooo00?o0000ooooooooool0C?ooool01Ol0003ooooooooooooooooo000000Sooooo
00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooool00000oooooomMoooo
o`00<?ooool00ol0003oooooooooo`1<ooooo`05o`000?ooooooooooooooool000002?ooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool0003ooooooegooooo
000`ooooo`03o`000?oooooooooo04cooooo00Go0000ooooooooooooooooo`000008ooooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`000?ooooooGOooool0
033ooooo00?o0000ooooooooool0C?ooool01Ol0003ooooooooooooooooo000000Sooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`00003ooooooeco
oooo000`ooooo`03o`000?oooooooooo04cooooo00Go0000ooooooooooooooooo`000008ooooo`05
o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool00000oooo
oomLooooo`00<?ooool00ol0003oooooooooo`1<ooooo`05o`000?ooooooooooooooool000002?oo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo0000
0?ooooooG?ooool0033ooooo00?o0000ooooooooool0C?ooool01Ol0003ooooooooooooooooo0000
00Sooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000
ooooooooooooooooo`00003ooooooecooooo000`ooooo`03o`000?oooooooooo04_ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool000001_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool00000oooooomLooooo`00<?oo
ool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_oo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooo
oooooooooooo000000Oooooo00?o0000ooooooooool0oooooomBooooo`00<?ooool00ol0003ooooo
ooooo`1;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo0000
00Oooooo00?o0000ooooooooool0oooooomBooooo`00<?ooool3o`0004_ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool000001_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?ooooooDoooool0
033ooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Kooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooo00000?ooooooDoooool0033ooooo00?o0000
ooooooooool0Boooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooo00000?ooooooDoooool0033ooooo00?o0000ooooooooool0Booo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooo00000?ooooooDoooool0033ooooo00?o0000ooooooooool0@?ooool2o`0000Wooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool0
00001_ooool00ol0003oooooo`00003ooooooe?ooooo000`ooooo`03o`000?oooooooooo03oooooo
0ol00009ooooo`03o`000?oooooooooo00;ok^k^00?o0000ooooooooool00_o^k^h3ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooo`00000Sooooo`;ok^k^0oooool2onk^kV3o
oooo0_o^k^h3ooooo`;ok^k^C_ooool2onk^kP?ooooo0_o^k^i/ooooo`00<?ooool00ol0003ooooo
ooooo`0oooooo`03o`000?oooooo000000Kooooo00goA4A4o`000?l0003o0000omgMgOooooook^k^
oeEEEOl0003oooooonk^k_mEEEGok^k^00?ooooo1?l000002Ol@413o0000ooooooo^k^ko<S8bo`00
0?lb<S;ok^k^o`000005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003ooooooooo
ool0000Looooo`Co000000Wo410@ooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4
o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hkooooo`Co000000?o410@oooooooo
ool00_ooool2ob4Q8@Gooooo00goA4A4o`000?l0003o<S8bomgMgOooooook^k^oeEEEOo^k^kooooo
onk^k_mEEEGok^k^00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^>?oo
ool5o`0000;ooooo00Ook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413o
ooooooooooo^k^ko<S8bo`000?lb<S;ok^k^GOooool0033ooooo00?o0000ooooooooool0?oooool0
0ol0003oooooo`000009ooooo`09o`000?lb<S;oooooooooooo^k^koEEEEo`000?mEEEGok^k^00Co
oooo00?o0000ooooool000000_ooool02?l0003oooooogMgMonHV9SooooooiRHV?mgMgOo00001Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooo
ool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo00007_ooool00ol0003o
ooooooooo`02ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL0?Oooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool0
2OmgMgOo<S8booooooooooook^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0hooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool0
1Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg05gooooo000`ooooo`03o`000?oooooooooo03oooooo00Co0000oooooooooooo0000
2?ooool2o`0000?ooooo00?ogMgMo`000?oMgMd01Oooool00ol0003oooooo`000002ooooo`03o`00
0?oooooo410@00?ooooo00?o410@o`000?ooool01?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Ko
oooo00Co0000oooooooooooo00007_ooool00ol0003oooooooooo`03ooooo`03omgMgOl0003ogMgM
00Oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@03gooooo00?o0000
ooooooooool03oooool01ol0003ooooooooooooooooogMgMo`000?oMgMd01oooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@4100>Oooool00onHV9So8B4Qonk^kP05ooooo`03
omgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@
05gooooo000`ooooo`03o`000?oooooooooo03kooooo00Go0000ooooooooooooooooo`000008oooo
o`09o`000?lb<S;oooooooooooo^k^koEEEEo`000?mEEEGok^k^00Cooooo00?o0000ooooool00000
0_ooool00ol0003oooooo`000003ooooo`;o00001Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Ko
oooo00Co0000oooooooooooo00007_ooool00ol0003oooooooooo`02ooooo`05onk^k_mEEEGogMgM
oeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000?Ooo
ool00ol0003oooooooooo`0>ooooo`09ogMgMolb<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^
00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000003[ooooo00?oV9RH
ob4Q8Oo^k^h00oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000005gooooo000`ooooo`03o`000?oooooooooo03kooooo00Go
0000ooooooooooooooooo`000005ooooo`0=o`000?lQ8B7o0000o`000?o<c<coooooonk^k_mEEEGo
k^k^o`000?o^k^koEEEEonk^kP03ooooo`03o`000?oooooo000000;ooooo00?o0000ooooool00000
0oooool2o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`00
01kooooo00_o0000ooooooooooooooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03
o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000mooooo`03o`000?oooooooooo
00_ooooo00go0000ob4Q8Ol0003o<S8bolc<c?ooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^
00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000003_ooooo00_oMgMg
ofIVI_ooooooooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`00001Mooooo`00<?ooool00ol0003oooooooooo`0noooo
o`05o`000?ooooooooooooooool000001Oooool01?l0003oooooooooool00002ooooo`;ok^k^00?o
ooooo`000?ooool00_o^k^h3ooooo`03o`000?oooooo000000;ooooo00?o0000ooooool@41000ooo
ool00ol@413o0000ooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003ooooo
ooooool0000Nooooo`04o`000?ooooooooooooooo`;ok^k^0oooool2onk^kPGooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@03gooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`03ooooo`;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@03cooooo00?o0000ooooooooool00_o^k^h3ooooo`;ok^k^1Ooo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100GOooool0033ooooo0ol0
000nooooo`05o`000?ooooooooooooooool000001Oooool01?l0003oooooooooool00005ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooool000000_ooool02?l0003oooooogMgMonHV9Sooooo
oiRHV?mgMgOo00001Oooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Co
0000oooooooooooo00007_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`;o0000<oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Sooooo0_l0000^ooooo`05o`000?nj^[[ooooooiRHV?l@41003_ooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool2o`0005?ooooo000`ooooo`03o`000?oooooo
oooo03kooooo00Go0000ooooooooooooooooo`000005ooooo`Co00001Oooool00ol0003ooooooooo
o`04ooooo`03o`000?mVIVKo000000;ooooo00So0000ooooooo^k^ko<S8bo`000?lb<S;ok^k^o`00
00Gooooo00?o0000ooooool000000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`04o`000?oooooooooo
o`0001cooooo00?oEEEEofIVI_l000003Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01oooool01?l0003oooooooooool0000`ooooo`03oeEEEOmVIVKo000000gooooo
1?l0000<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP07ooooo`04
o`000?ooooooooooo`0002gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00<ooooo`03oeEEEOmVIVKo
000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP07ooooo`04o`000?ooooooooooo`0005;ooooo
000`ooooo`03o`000?oooooooooo03kooooo00Go0000ooooooooooooooooo`000008ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooool000001?l00002ooooo`04o`000?ooooooooooo`0000Co
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`000006ooooo`;o0000<_ooool4o`000005ooooool0003ooooo
ooooool00000G_ooool4o`000005ooooool0003oooooooooool00000C?ooool4o`000005ooooool0
003oooooooooool00000D_ooool0033ooooo00?o0000ooooooooool0?_ooool01Ol0003ooooooooo
oooooooo000000Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`04o`00
0?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
00Kooooo0ol0000fooooo`?o0000I?ooool3o`0005;ooooo0ol0001Cooooo`00<?ooool00ol0003o
ooooooooo`0mooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo0_l00002ooooo`03o`000?oooooo000000Co
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo000003Oooooo00?o0000oooo
ooooool0I?ooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo05;ooooo000`ooooo`03
o`000?oooooooooo03gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool5o`000003ooooool0003ooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo000003Sooooo00?o0000oooo
ooooool0I?ooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo057ooooo000`ooooo`03
o`000?oooooooooo03gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo0000
0?ooooooBOooool0033ooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
00Kooooo00?o0000ooooool00000ooooool?ooooo`03ogMgMomVIVKooooo02gooooo00?oIVIVogMg
Moooool01oooool0033ooooo00?o0000ooooooooool0<?ooool3o`0000[ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`000005ooooo`04o`000?ooooooooooo`0000Oooooo0_l0003oooooo`Gooooo00?ogMgM
oa0@4?o^k^h0;_ooool00oo^k^ko410@omgMg@07ooooo`00<?ooool00ol0003oooooooooo`0^oooo
o`;o00000_ooool2o`0000Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000005ooooo`05o`000?oooooo
ooooooooool000001Oooool3o`000?;ooooo0_l00002ooooo`;o00003?ooool00omEEEGoV9RHoooo
o`02o`0000;ooooo00Oo0000oooooooooooo0000oa0@4?o^k^koEEEE00;o000000?oA4A4okZj^_oo
ool00_ooool01OnHV9So0000o`000?m4A4Co^[Zj00;ooooo00Sok^k^oeEEEOl0003o0000odA4A?nj
^[[ooooooa0@40Go00000oooool02?l@413o<S8bo`000?l0003o410@ojVYZOn7QhOoIVIV1oooool0
033ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`000005ooooo`05o`000?ooooooooooooooool000001Ooo
ool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo0>Sooooo00Kok^k^ob4Q8On7QhOo
^[Zjo`000?oMgMd<ooooo`05o`000?ooooooooooooooool000000_ooool02ol0003oooooooooool0
003ooooooeEEEOmgMgOoooooonk^k_mgMgOo410@00?ooooo00Go410@okZj^_o^k^koMgMgoa0@4002
ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo410@0oooool00ol0003oooooooooo`04ooooo`08o`00
0?nYZJWooooooooooonj^[[o0000onk^k_l00007ooooo`00ool0002do`0000oooooo00CogMgMo`00
0?l@413oc<c<3Oooool01Olb<S;ooooooooooooooooo000000;ooooo00Ko0000oooooooooooo0000
ooooool00008ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`05ooooo`07okZj^_n7QhOoIVIVofIVI_l@413oooooo`000007ooooo`002_ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooo000000Ko00002?ooool2o`0000Kooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000Kooooo00?o0000oooo
ooooool01?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool01ol0003ooooooooooooooooo0000ooooool000001?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooooooool2o`0000?ooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool00005ooooo`Co00003oooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo01Oooooo00Cok^k^ob4Q8Ol@413ok^k^3Oooool01Olb<S;ooooooooooooo
oooo000000;ooooo00Go0000oooooooooooo0000ooooo`06o`0000?ooooo00?o0000ooooooooool0
1?ooool6o`0000?ooooo00?o0000ooooooooool01?ooool02?lb<S;o8B4QogMgMomgMgOoQhN7onk^
k_oooooo00001oooool000[ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool01ol0003ooooooooooooooooo
0000ooooool000001_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`07o`000?ooooooooooooooool0
003oooooo`000004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool2o`00
00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Cooooo0_l00003
ooooo`03o`000?oooooooooo00?ooooo0ol00005ooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0Gooooo`04ob4Q8OmgMgOoMgMgoc8b<Pgooooo00Go
0000onk^k_ooooooooooo`000002olc<c00;o`000?nYZJWogMgMob4Q8OooooooEEEEohN7Qoo^k^ko
ooooohN7Qolb<S800oooool00ol0003oooooooooo`04ooooo`06oeEEEOn7QhOok^k^oooooon7QhOo
<S8b0oooool00ol0003o<S8bomgMg@04ooooo`08o`000?nj^[[oooooonk^k_mgMgOo0000onk^k_l0
0007ooooo`00<?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
1Oooool01Ol0003ooooooooooooooooo000000Gooooo00Co0000oooooooooooo00008Oooool00ol0
003oooooooooo`1Kooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool05_ooool2o`00
00;ooooo0_l0000<ooooo`0>oeEEEOmgMgOooooooa0@4?l0003o8B4Qo`000?mgMgOo410@o`000?nY
ZJWoooooonk^k_mEEED2o`000004odA4A?o^k^kooooooa0@40Go00000oooool01_o^k^koEEEEo`00
0?l0003oA4A4onk^kP;ooooo0_l000001?nYZJWo8B4Qo`000?lQ8B42ooooo`08ojVYZOlQ8B7o0000
o`000?lb<S;o0000ogMgMomEEED7ooooo`00<?ooool00ol0003oooooooooo`0fooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000001Oooool01Ol0003ooooooooooooooooo000000Gooooo00Co0000oooooooo
oooo0000ooooool9ooooo`03omgMgOl@413ok^k^01;ooooo00?o0000ooooooooool06Oooool00oo^
k^ko410@omgMg@07ooooo`00<?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000001Oooool01Ol0003ooooooooooooooooo000000Kooooo0_l0003oooooo`_ooooo00?oMgMg
ofIVI_ooool04Oooool00ol0003oooooooooo`0Iooooo`03ofIVI_mgMgOooooo00Oooooo000`oooo
o`03o`000?oooooooooo03Oooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000005ooooo`05o`000?ooooooooooooooool00000
1_ooool2o`000?ooooooAOooool0033ooooo00?o0000ooooooooool0=oooool01?l0003ooooooooo
ool00009ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000005ooooo`05
o`000?ooooooooooooooool00000oooooom=ooooo`00<?ooool00ol0003oooooooooo`0hooooo`03
o`000?oooooo000000Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo0000
00Gooooo00Co0000oooooooooooo0000oooooom>ooooo`00<?ooool00ol0003oooooooooo`0hoooo
o`?o00002Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001Oooool0
1?l0003oooooooooool0003oooooodkooooo000`ooooo`03o`000?oooooooooo04Cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooool00000oooo
oom>ooooo`00<?ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooo00000?ooooooC_ooool0033ooooo0ol00015
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oo
oooo00000?ooooooC_ooool0033ooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooo`00003oooooodkooooo000`
ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooo
oooo000000Kooooo00?o0000ooooool00000oooooom>ooooo`00<?ooool00ol0003oooooooooo`15
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000006ooooo`?o0000oooo
oom>ooooo`00<?ooool00ol0003oooooooooo`15ooooo`05o`000?ooooooooooooooool000001ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooooooo
o`000007ooooo`03o`000?oooooooooo0?ooooooCOooool0033ooooo00?o0000ooooooooool0AOoo
ool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`05o`000?ooooooooooooooool00000oooooomGooooo`00<?ooool00ol0003ooooo
ooooo`15ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00003ooooooeOooooo000`ooooo`03
o`000?oooooooooo04Gooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooo
ooooool000001Oooool01Ol0003ooooooooooooooooo00000?ooooooEoooool0033ooooo00?o0000
ooooooooool0AOooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooooooo
o`000006ooooo`04o`000?ooooooooooo`000?ooooooEoooool0033ooooo00?o0000ooooooooool0
AOooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006oooo
o`04o`000?ooooooooooo`000?ooooooEoooool0033ooooo00?o0000ooooooooool0AOooool01Ol0
003ooooooooooooooooo000000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?oo
ooooooooo`000?ooooooEoooool0033ooooo00?o0000ooooooooool0AOooool01Ol0003ooooooooo
oooooooo000000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`00
0?ooooooEoooool0033ooooo0ol00015ooooo`05o`000?ooooooooooooooool000002?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0
003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo0000oooooomGooooo`00<?ooool0
0ol0003oooooooooo`15ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000Kooooo00Co0000oooooooooooo0000oooooomGooooo`00<?ooool00ol0003ooooo
ooooo`16ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006oooo
o`03o`000?oooooo00000?ooooooF?ooool0033ooooo00?o0000ooooooooool0A_ooool01?l0003o
ooooooooool00008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooo`00003ooooooeSooooo000`
ooooo`03o`000?oooooooooo04Kooooo00Co0000oooooooooooo00002?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooool00000oooooomHooooo`00<?ooool00ol0003oooooooooo`16ooooo`04o`00
0?ooooooooooo`0000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`05
o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooo00000?ooooooF?ooool0033ooooo00?o0000
ooooooooool0A_ooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooooooooooo
ooooo`000006ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooo`00003ooooo
oeSooooo000`ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooool000002Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000007oooo
o`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o
0000ooooool00000oooooomHooooo`00<?ooool00ol0003oooooooooo`16ooooo`03o`000?oooooo
000000Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`05o`000?oooooo
ooooooooool000001oooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo
00001oooool00ol0003oooooo`00003ooooooeSooooo000`ooooo`03o`000?oooooooooo04Kooooo
00?o0000ooooool000002Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo
00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool01?l0
003oooooooooool00007ooooo`03o`000?oooooo00000?ooooooF?ooool0033ooooo00?o0000oooo
ooooool0Aoooool2o`0000Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05oooo
o`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Kooooo00Co
0000oooooooooooo00001oooool00ol0003oooooo`00003ooooooeSooooo000`ooooo`03o`000?oo
oooooooo04Oooooo0_l00009ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Ooo
ool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000006ooooo`04
o`000?ooooooooooo`0000Oooooo00?o0000ooooool00000oooooomHooooo`00<?ooool3o`0004Oo
oooo0_l00009ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool01Ol0003o
oooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?oooooo
ooooo`0000Sooooo0_l0003ooooooeSooooo000`ooooo`03o`000?oooooooooo05;ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000001ooo
ool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo00002?ooool00ol0003o
ooooooooo`3ooooooeOooooo000`ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003o
oooooooooooooooo000000Kooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`3o
oooooeOooooo000`ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`05ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooo
oooo000000Kooooo00Co0000oooooooooooo0000oooooomRooooo`00<?ooool00ol0003ooooooooo
o`1Booooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooo
oooooooo000000Oooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`00
0?ooooooH_ooool0033ooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooooooo
ooooool000001_ooool01?l0003oooooooooool0003oooooof;ooooo000?ooooo`;ok^k^0oooool2
onk^kQ[ooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Gooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool00000
1_ooool01?l0003oooooooooool0003oooooof;ooooo0008ooooo`Go00000_ooool01oo^k^koEEEE
onk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b
<_o^k^h;ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`05ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo0000
00Kooooo00Co0000oooooooooooo0000oooooomRooooo`002?ooool01OnHV9So8B4Qonk^k_oooooo
A4A400?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003o
oooooooooooooooo000000Kooooo00Co0000oooooooooooo0000oooooomRooooo`002Oooool00onH
V9So8B4Qonk^kP05ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@
413ooooooooooooooooo410@00_ooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oo
ooooooooooooool000001_ooool01?l0003oooooooooool0003oooooof;ooooo000:ooooo`03oiRH
V?lQ8B7ok^k^00?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`00000;ooooo`03o`000?oooooooooo05;ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000001oooool0
1Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo0000oooooomRooooo`002ooo
ool02omgMgOoIVIVooooooooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000000_ooooo1?l0001Aooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000Oooooo
00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`000?ooooooH_ooool000co
oooo00?o0000ooooooooool00_o^k^h3ooooo`;ok^k^1Oooool00ol0003oooooooooo`02ooooo`05
oa0@4?ooooooooooooooool@41002oooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000
ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`000?ooooooH_ooool000Sooooo00Go
0000okZj^_ooooooV9RHoa0@400>ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`05ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo
000000Kooooo00Co0000oooooooooooo0000oooooomRooooo`002?ooool01OnHV9So410@o`000?lQ
8B7oc<c<00cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo
0_l00006ooooo`03o`000?oooooooooo05?ooooo00Go0000ooooooooooooooooo`000007ooooo`05
o`000?ooooooooooooooool000001oooool01?l0003oooooooooool00007ooooo`04o`000?oooooo
ooooo`000?ooooooH_ooool002Oooooo00Co0000oooooooooooo00001Oooool00ol0003ooooooooo
o`1Cooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oo
oooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003oooooof;ooooo000Wooooo`04
o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0Doooool01Ol0003ooooooooooooooooo
000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Sooooo
00?o0000ooooool00000oooooomRooooo`009oooool3o`0000Kooooo00?o0000ooooooooool0Dooo
ool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool000001oooool01?l0003o
ooooooooool00008ooooo`03o`000?oooooo00000?ooooooH_ooool002Sooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`1Cooooo`04o`000?ooooooooooo`0000Sooooo00Go0000oooo
ooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooo
oomRooooo`00:Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05?ooooo00Co0000
oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo
00002?ooool00ol0003oooooo`00003oooooof;ooooo000`ooooo`03o`000?oooooooooo05?ooooo
00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooo
oooooooo00002?ooool00ol0003oooooo`00003oooooof;ooooo000`ooooo`03o`000?oooooooooo
05?ooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Co
0000oooooooooooo00002?ooool00ol0003oooooo`00003oooooof;ooooo000`ooooo`03o`000?oo
oooooooo05?ooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Oo
oooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003oooooof;ooooo000`ooooo`?o
0000Doooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool000001oooool0
1?l0003oooooooooool00008ooooo`;o0000oooooomSooooo`00<?ooool00ol0003oooooooooo`1C
ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000007ooooo`04o`00
0?ooooooooooo`0000Sooooo0_l0003oooooof?ooooo000`ooooo`03o`000?oooooooooo05?ooooo
00Co0000oooooooooooo00002Oooool01?l0003oooooooooool00007ooooo`04o`000?oooooooooo
o`0000Sooooo0_l0003oooooof?ooooo000`ooooo`03o`000?oooooooooo05?ooooo00Co0000oooo
oooooooo00002Oooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Sooooo
0_l0003oooooof?ooooo000`ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooool000002Ooo
ool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Sooooo0_l0003oooooof?o
oooo000`ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooool000002Oooool01?l0003ooooo
ooooool00007ooooo`04o`000?ooooooooooo`0000Sooooo0_l0003oooooof?ooooo000`ooooo`03
o`000?oooooooooo05Cooooo00?o0000ooooool000002Oooool01?l0003oooooooooool00007oooo
o`04o`000?ooooooooooo`0000Sooooo0_l0003oooooof?ooooo000`ooooo`03o`000?oooooooooo
05Cooooo00?o0000ooooool000002Oooool01?l0003oooooooooool00007ooooo`04o`000?oooooo
ooooo`0000Sooooo0_l0003oooooof?ooooo000`ooooo`03o`000?oooooooooo05Cooooo00?o0000
ooooool000002Oooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Sooooo
0_l0003oooooof?ooooo000`ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooool000002Ooo
ool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Sooooo0_l0003oooooof?o
oooo000`ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooool000002Oooool01?l0003ooooo
ooooool00007ooooo`04o`000?ooooooooooo`0000Sooooo0_l0003oooooof?ooooo000`ooooo`03
o`000?oooooooooo05Cooooo00?o0000ooooool000002Oooool00ol0003oooooo`000008ooooo`04
o`000?ooooooooooo`0000Sooooo0_l0003oooooof?ooooo000`ooooo`?o0000E?ooool00ol0003o
ooooo`000009ooooo`03o`000?oooooo000000Sooooo00Co0000oooooooooooo00002Oooool00ol0
003oooooooooo`3oooooof7ooooo000`ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooool0
00002Oooool00ol0003oooooo`000008ooooo`04o`000?ooooooooooo`000?ooooooKOooool0033o
oooo00?o0000ooooooooool0E?ooool00ol0003oooooo`000009ooooo`03o`000?oooooo000000So
oooo00Co0000oooooooooooo0000oooooom]ooooo`00<?ooool00ol0003oooooooooo`1Dooooo`;o
00002_ooool00ol0003oooooo`000008ooooo`04o`000?ooooooooooo`000?ooooooKOooool0033o
oooo00?o0000ooooooooool0E?ooool2o`0000[ooooo00?o0000ooooool000002?ooool01?l0003o
ooooooooool0003oooooofgooooo000`ooooo`03o`000?oooooooooo05Cooooo0_l0000:ooooo`03
o`000?oooooo000000Sooooo00Co0000oooooooooooo0000oooooom]ooooo`00<?ooool00ol0003o
ooooooooo`1Dooooo`;o00002_ooool00ol0003oooooo`000008ooooo`04o`000?ooooooooooo`00
0?ooooooKOooool0033ooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`08ooooo`03
o`000?oooooo000000Sooooo00Co0000oooooooooooo0000oooooom]ooooo`00<?ooool00ol0003o
ooooooooo`1Pooooo`03o`000?oooooo000000Sooooo00Co0000oooooooooooo0000oooooom]oooo
o`00<?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo000000Sooooo00Co0000oooooooo
oooo0000oooooom]ooooo`00<?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo000000So
oooo00Co0000oooooooooooo0000oooooom]ooooo`00<?ooool00ol0003oooooooooo`1Pooooo`03
o`000?oooooo000000Sooooo00Co0000oooooooooooo0000oooooom]ooooo`00<?ooool3o`00063o
oooo00?o0000ooooool000002?ooool01?l0003oooooooooool0003oooooofgooooo000`ooooo`03
o`000?oooooooooo063ooooo00?o0000ooooool000002Oooool00ol0003oooooo`00003oooooofgo
oooo000`ooooo`03o`000?oooooooooo063ooooo00?o0000ooooool000002Oooool00ol0003ooooo
o`00003oooooofgooooo000`ooooo`03o`000?oooooooooo063ooooo00?o0000ooooool000002Ooo
ool00ol0003oooooo`00003oooooofgooooo000`ooooo`03o`000?oooooooooo063ooooo00?o0000
ooooool000002Oooool00ol0003oooooo`00003oooooofgooooo000`ooooo`03o`000?oooooooooo
063ooooo00?o0000ooooool000002Oooool00ol0003oooooo`00003oooooofgooooo000?ooooo`;o
k^k^0oooool2onk^kQ[ooooo00?o0000ooooooooool0H?ooool00ol0003oooooo`000009ooooo`03
o`000?oooooo00000?ooooooKOooool000[ooooo0_l000002_l@413oooooooooooo^k^koEEEEonk^
k_ooooook^k^oeEEEOo^k^h3ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^
kP_ooooo00?o0000ooooooooool0H?ooool00ol0003oooooo`000009ooooo`03o`000?oooooo0000
0?ooooooKOooool000_ooooo00?o0000ooooooooool00_ooool01Oo^k^koEEEEomgMgOmEEEGok^k^
00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?o0000
ooooooooool0H?ooool00ol0003oooooo`000009ooooo`03o`000?oooooo00000?ooooooKOooool0
00Sooooo1Ol00004ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@
413ooooooooooooooooo410@00_ooooo00?o0000ooooooooool0H?ooool00ol0003oooooo`000009
ooooo`03o`000?oooooo00000?ooooooKOooool000Sooooo00CoA4A4omgMgOoooooo00001?ooool0
1Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000_ooooo00?o0000ooooooooool0H?ooool00ol0003oooooo`000009ooooo`03o`00
0?oooooo00000?ooooooKOooool000Sooooo00CogMgMoeEEEOoooooo00000oooool01oo^k^koEEEE
onk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool000002oooool4o`0005oooooo00?o0000ooooool000002Oooool00ol0003oooooo`00003o
ooooofgooooo0009ooooo`03ogMgMoo<c<co000000?ooooo0_o^k^h3ooooo`;ok^k^1Oooool00ol0
003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41002oooool00ol0003oooooooooo`1P
ooooo`03o`000?oooooo000000Wooooo0_l0003oooooofkooooo0009ooooo`03onk^k_m4A4Co0000
00oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?o0000
ooooooooool0H?ooool00ol0003oooooo`000009ooooo`;o0000oooooom^ooooo`002_ooool00omg
MgOo0000ooooo`0<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03
ooooo`;o00001_ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo000000Wooooo0_l0003o
ooooofkooooo000Wooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0H?ooool0
0ol0003oooooo`000009ooooo`;o0000oooooom^ooooo`009oooool01?l0003oooooooooool00005
ooooo`03o`000?oooooooooo063ooooo00?o0000ooooool000002Oooool2o`000?ooooooK_ooool0
02Oooooo0ol00006ooooo`03o`000?oooooooooo063ooooo00?o0000ooooool000002Oooool2o`00
0?ooooooK_ooool002Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Pooooo`03
o`000?oooooo000000Wooooo0_l0003oooooofkooooo000Yooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0H?ooool00ol0003oooooo`00000:ooooo`03o`000?oooooooooo0?oooooo
K?ooool0033ooooo00?o0000ooooooooool0H?ooool00ol0003oooooo`00003oooooogWooooo000`
ooooo`03o`000?oooooooooo067ooooo0_l0003oooooogWooooo000`ooooo`03o`000?oooooooooo
067ooooo0_l0003oooooogWooooo000`ooooo`?o0000HOooool00ol0003oooooooooo`3oooooogSo
oooo000`ooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0oooooomhooooo`00<?oo
ool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0
033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomco
oooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooo
oooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooo
ooooo`3oooooomcooooo000`ooooo`?o0000oooooooLooooo`00<?ooool00ol0003oooooooooo`3o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0
003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo
00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`
ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo0ol0003oooooomcooooo000`ooooo`03
o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?oo
ool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0
0?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooooooo
ool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00
oooooooooooooa3ooooo002Pooooo`;o00001?ooool00onj^[[o<S8booooo`04ooooo`;o00001_oo
ool00ol0003o^[Zjooooo`3ooooooeOooooo002Pooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`;o<S8boooooomHooooo`00SOooool3o`00
00;ooooo00Ko<S8boa0@4?ooooooooooonk^k_mEEED2o`000003odA4A?nj^[[ooooo00?ooooo00?o
0000ooooooooool00_ooool01OnHV9So410@o`000?l0003oZJVY00Cooooo00?o0000ooooooooool0
1?ooool00on7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X02oooool2o`000003
oa0@4?oooooooooo00?ooooo0_lQ8B44ooooo`0;olc<c?lQ8B7o0000ob4Q8Oo<c<coooooolc<c?o^
k^koooooonk^k_o<c<`01?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hC
ooooo`06oa0@4?lb<S;o0000o`000?l@413oZJVY0_ooool01_o^k^koEEEEo`000?l0003oA4A4okZj
^P?ooooo00GoIVIVo`000?l0003oA4A4olc<c03Xooooo`00S_ooool01Ol0003oooooooooooo<c<co
410@00?ooooo00KoEEEEogMgMoooooook^k^ogMgMol@4104ooooo`03o`000?oooooooooo00;ooooo
00Ko0000ojVYZOmEEEGoV9RHoeEEEOnj^[X3ooooo`03o`000?oooooooooo00Cooooo00?oc<c<o`00
0?l@41003?ooool01_l@413o^[Zjonk^k_mgMgOo410@ooooo`Ko00001Oooool00ol0003ooooooooo
o`04ooooo`;o8B4Q1?ooool02olQ8B7oV9RHoooooonHV9So8B4Qooooooo^k^koEEEEomgMgOmEEEGo
k^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01?ooooo00Ko
0000ojVYZOoooooooooookZj^_l00002ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo410@0_ooool0
1_mVIVKoMgMgooooooooooooQhN7oa0@4>Sooooo002>ooooo`05o`000?oooooooooooeEEEOn7QhL0
0oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00Ko<S8bonk^k_nHV9So
EEEEomgMgOl@4103ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02oooool5o`00
00_ooooo00Go0000ooooooooooooooooo`000002ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01Cooooo00Go^[ZjohN7QomVIVKoIVIV
oa0@4002ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0joooool008kooooo00Go
0000oooooooMgMgo0000onk^kP03ooooo`Ko00001?ooool00ol0003oooooooooo`02ooooo`07okZj
^_m4A4Coc<c<ob4Q8Ooooooo410@olc<c002ooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool00oooool6o`0000;ooooo00CoA4A4omgMgOoooooo00003?ooool02olb<S;oV9RHoooooonH
V9So<S8booooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0
003ooooooooooooooooo000001?ooooo00Ko<S8bob4Q8OmgMgOoMgMgohN7Qoo^k^h2ooooo`Ko0000
0_ooool00ol0003oooooooooo`3[ooooo`00S_ooool3o`000003oa0@4?nHV9Sooooo00;ooooo00Ko
EEEEohN7Qoo^k^koooooohN7Qolb<S84ooooo`03o`000?oooooooooo00;ooooo00Ook^k^o`000?oo
oooo0000oooooomVIVKoQhN700;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0;
ooooo`04omgMgOmEEEGoooooo`0000cooooo00_oc<c<o`000?l0003o0000olc<c?ooooooc<c<onk^
k_ooooook^k^olc<c006ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
000Cooooo`06o`000?nj^[[oooooonk^k_mgMgOo00000_ooool01_mEEEGoQhN7onk^k_ooooooQhN7
oc8b<P;ooooo00KoIVIVogMgMoooooooooooohN7Qol0003Xooooo`00S_ooool01Ol0003ooooooooo
ooo<c<co000000?ooooo00Kok^k^oeEEEOl0003o0000odA4A?o^k^h4ooooo`03o`000?oooooooooo
00;ooooo00CoIVIVoiRHV?oooooo<S8b0_nj^[X01?l0003oooooooooool0000Cooooo`03oa0@4?l0
003o000000?o00002oooool00omgMgOoc<c<o`00000<ooooo`05oa0@4?nj^[[ooooookZj^_l@4100
3?ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41001oooool3o`0000;o
oooo0ol00004ooooo`06ojVYZOlQ8B7o0000o`000?lb<S;o00000_ooool01_o^k^koEEEEo`000?l0
003oA4A4onk^kP;ooooo00Kok^k^ofIVI_l0003o0000odA4A?l0003Xooooo`00S_ooool01Ol0003o
ooooooooooo<c<co000000gooooo00?o0000ooooooooool01Oooool00omVIVKoQhN7ooooo`03oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool03?ooool00oo^k^koA4A4o`00000<oooo
o`05o`000?nj^[[ooooookZj^_l000003?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo0_oo
ool008gooooo1?l000000ol@413oZJVYooooo`0<ooooo`;o00001_ooool00onYZJWoA4A4ooooo`02
ooooo`;o00005Oooool00ol0003oooooooooo`0=ooooo`03ogMgMol0003ooooo00_ooooo00GoZJVY
oa0@4?l0003o410@ojVYZ@0:ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP02ooooo`Co00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo
0_ooool00?oooooo1_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo0_oo
ool00?oooooo1_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo0_ooool0
0?oooooo1Oooool2o`0000?ooooo0_l0003oooooo`Cooooo003ooooooooooooo4?ooool00?oooooo
ooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@oooo
o`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooo
oooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo
003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooo
oooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool0
0?ooooooooooool@ooooo`00\
\>"],
  ImageRangeCache->{{{0, 525.688}, {324.5, 0}} -> {-2.58312*^-7, -6.34248*^6, \
6.65005*^-9, 53093.5}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0.309017 5.42214e-08 [
[.32684 .29652 -16.5 -12.5 ]
[.32684 .29652 16.5 0 ]
[.54329 .29652 -16.5 -12.5 ]
[.54329 .29652 16.5 0 ]
[.75974 .29652 -22.5 -12.5 ]
[.75974 .29652 22.5 0 ]
[.97619 .29652 -16.5 -12.5 ]
[.97619 .29652 16.5 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 64 6 ]
[.09789 .09213 -34.5 -6.25 ]
[.09789 .09213 0 6.25 ]
[.09789 .20057 -34.5 -6.25 ]
[.09789 .20057 0 6.25 ]
[.09789 .41746 -28.5 -6.25 ]
[.09789 .41746 0 6.25 ]
[.09789 .5259 -28.5 -6.25 ]
[.09789 .5259 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -59.8125 0 ]
[.5 .63053 59.8125 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 .30902 m
.32684 .31527 L
s
gsave
.32684 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 .30902 m
.54329 .31527 L
s
gsave
.54329 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 .30902 m
.75974 .31527 L
s
gsave
.75974 .29652 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 .30902 m
.15368 .31277 L
s
.19697 .30902 m
.19697 .31277 L
s
.24026 .30902 m
.24026 .31277 L
s
.28355 .30902 m
.28355 .31277 L
s
.37013 .30902 m
.37013 .31277 L
s
.41342 .30902 m
.41342 .31277 L
s
.45671 .30902 m
.45671 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.58658 .30902 m
.58658 .31277 L
s
.62987 .30902 m
.62987 .31277 L
s
.67316 .30902 m
.67316 .31277 L
s
.71645 .30902 m
.71645 .31277 L
s
.80303 .30902 m
.80303 .31277 L
s
.84632 .30902 m
.84632 .31277 L
s
.88961 .30902 m
.88961 .31277 L
s
.9329 .30902 m
.9329 .31277 L
s
.0671 .30902 m
.0671 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09213 m
.11664 .09213 L
s
gsave
.09789 .09213 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .20057 m
.11664 .20057 L
s
gsave
.09789 .20057 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .41746 m
.11664 .41746 L
s
gsave
.09789 .41746 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .5259 m
.11664 .5259 L
s
gsave
.09789 .5259 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.11039 .11924 m
.11414 .11924 L
s
.11039 .14635 m
.11414 .14635 L
s
.11039 .17346 m
.11414 .17346 L
s
.11039 .22768 m
.11414 .22768 L
s
.11039 .2548 m
.11414 .2548 L
s
.11039 .28191 m
.11414 .28191 L
s
.11039 .33613 m
.11414 .33613 L
s
.11039 .36324 m
.11414 .36324 L
s
.11039 .39035 m
.11414 .39035 L
s
.11039 .44457 m
.11414 .44457 L
s
.11039 .47168 m
.11414 .47168 L
s
.11039 .49879 m
.11414 .49879 L
s
.11039 .06502 m
.11414 .06502 L
s
.11039 .03791 m
.11414 .03791 L
s
.11039 .0108 m
.11414 .0108 L
s
.11039 .55301 m
.11414 .55301 L
s
.11039 .58012 m
.11414 .58012 L
s
.11039 .60723 m
.11414 .60723 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -120.812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.812 moveto
(@) show
81.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.812 moveto
(D) show
93.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5.) show
129.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
135.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
147.000 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
151.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
160.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
178.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02532 .30902 L
.02691 .30902 L
.03029 .30902 L
.03335 .30902 L
.0366 .30902 L
.03973 .30902 L
.04132 .30902 L
.04216 .30902 L
.04306 .30902 L
.04385 .30902 L
.0443 .30902 L
.04452 .30902 L
.04472 .30902 L
.04491 .30902 L
.045 .30902 L
.04511 .30902 L
.04521 .30902 L
.04529 .30902 L
.04538 .30902 L
.04546 .30902 L
.04556 .30902 L
.04566 .30902 L
.04575 .30902 L
.04585 .30902 L
.04595 .30902 L
.04606 .30902 L
.04626 .30902 L
.04647 .30902 L
.04668 .30902 L
.04708 .30902 L
.0475 .30902 L
.04797 .30902 L
.04837 .30902 L
.0488 .30902 L
.04958 .30902 L
.05035 .30902 L
.05119 .30902 L
.05207 .30902 L
.05288 .30902 L
.05373 .30902 L
.05452 .30902 L
.05602 .30902 L
.05762 .30902 L
.0591 .30902 L
.06061 .30902 L
.06227 .30902 L
.06383 .30902 L
.06551 .30902 L
.0672 .30902 L
Mistroke
.06882 .30902 L
.07189 .30902 L
.07515 .30902 L
.0783 .30902 L
.08164 .30902 L
.08246 .30902 L
.08332 .30902 L
.08412 .30902 L
.08451 .30902 L
.08486 .30902 L
.08504 .30902 L
.08523 .30902 L
.08539 .30902 L
.08558 .30902 L
.08568 .30902 L
.08577 .30902 L
.08587 .30902 L
.08597 .30902 L
.08607 .30902 L
.08616 .30902 L
.08625 .30902 L
.08634 .30902 L
.08645 .30902 L
.08655 .30902 L
.08675 .30902 L
.08695 .30902 L
.08718 .30902 L
.08759 .30902 L
.08796 .30902 L
.08834 .30902 L
.08874 .30902 L
.08947 .30902 L
.09034 .30902 L
.09113 .30902 L
.09266 .30902 L
.09352 .30902 L
.09432 .30902 L
.09582 .30902 L
.09747 .30902 L
.09902 .30902 L
.1007 .30902 L
.104 .30902 L
.10717 .30902 L
.11023 .30902 L
.11348 .30902 L
.11499 .30902 L
.11578 .30902 L
.11662 .30902 L
.11704 .30902 L
.11726 .30902 L
Mistroke
.11751 .30902 L
.11773 .30902 L
.11793 .30902 L
.11803 .30902 L
.11808 .30902 L
.11813 .30902 L
.11823 .30902 L
.11833 .30902 L
.11838 .30902 L
.11844 .30902 L
.11854 .30902 L
.11859 .30902 L
.11864 .30902 L
.11876 .30902 L
.11887 .30902 L
.11896 .30902 L
.11918 .30902 L
.11936 .30902 L
.11957 .30902 L
.11994 .30902 L
.12033 .30902 L
.1207 .30902 L
.12153 .30902 L
.12234 .30902 L
.12322 .30902 L
.12399 .30902 L
.12483 .30902 L
.12652 .30902 L
.1281 .30902 L
.12978 .30902 L
.13311 .30902 L
.13632 .30901 L
.13941 .30901 L
.14098 .30901 L
.1427 .30901 L
.14349 .30901 L
.14392 .30901 L
.14433 .30901 L
.14472 .30901 L
.14492 .30901 L
.14513 .30901 L
.14533 .30901 L
.14551 .30901 L
.1456 .30901 L
.14569 .30901 L
.14578 .30901 L
.14586 .30901 L
.14596 .30901 L
.14606 .30901 L
.14615 .30901 L
Mistroke
.14624 .30901 L
.14634 .30901 L
.1464 .30901 L
.14645 .30901 L
.14665 .30901 L
.14683 .30901 L
.14702 .30901 L
.14738 .30901 L
.14782 .30901 L
.14824 .30901 L
.14904 .30901 L
.14981 .30901 L
.15063 .30901 L
.1521 .30901 L
.15293 .30902 L
.15382 .30902 L
.15544 .30902 L
.15873 .30903 L
.1619 .30904 L
.16495 .30906 L
.16664 .30907 L
.16819 .30907 L
.16896 .30907 L
.16939 .30907 L
.1696 .30907 L
.16979 .30907 L
.16997 .30908 L
.17014 .30908 L
.17033 .30908 L
.17043 .30908 L
.17053 .30908 L
.17062 .30908 L
.17072 .30908 L
.17082 .30908 L
.1709 .30908 L
.171 .30908 L
.17106 .30908 L
.17111 .30908 L
.17121 .30908 L
.17131 .30908 L
.17151 .30908 L
.17169 .30907 L
.17209 .30907 L
.17244 .30907 L
.17282 .30907 L
.17368 .30907 L
.17447 .30906 L
.17532 .30906 L
.17612 .30905 L
.17762 .30903 L
Mistroke
.17923 .309 L
.18071 .30896 L
.18389 .30887 L
.18694 .30877 L
.18864 .30871 L
.19019 .30867 L
.19096 .30866 L
.19136 .30865 L
.19179 .30864 L
.19217 .30864 L
.19237 .30864 L
.19258 .30863 L
.19268 .30863 L
.19278 .30863 L
.19287 .30863 L
.19296 .30863 L
.19304 .30863 L
.19313 .30863 L
.19323 .30863 L
.19331 .30863 L
.19341 .30863 L
.1935 .30863 L
.1936 .30863 L
.1937 .30863 L
.19392 .30863 L
.19412 .30864 L
.1945 .30864 L
.19486 .30865 L
.19527 .30865 L
.19565 .30867 L
.19653 .3087 L
.1973 .30873 L
.19802 .30878 L
.19967 .30891 L
.20129 .30908 L
.20278 .30927 L
.20595 .30978 L
.20901 .31031 L
.21071 .31055 L
.21152 .31065 L
.21226 .31071 L
.21263 .31074 L
.21303 .31076 L
.21324 .31077 L
.21343 .31078 L
.21354 .31078 L
.21364 .31078 L
.2137 .31078 L
.21376 .31079 L
.21381 .31079 L
Mistroke
.21387 .31079 L
.21397 .31079 L
.21407 .31079 L
.21416 .31079 L
.21425 .31079 L
.21435 .31079 L
.21445 .31078 L
.21456 .31078 L
.21466 .31078 L
.21484 .31077 L
.21501 .31076 L
.21539 .31074 L
.21578 .31071 L
.21619 .31066 L
.21692 .31055 L
.21771 .3104 L
.21859 .31017 L
.22014 .30964 L
.22182 .30888 L
.22512 .30692 L
.2283 .30484 L
.2299 .30393 L
.2306 .3036 L
.23136 .3033 L
.23178 .30317 L
.23217 .30307 L
.23254 .303 L
.23273 .30297 L
.23293 .30294 L
.23305 .30293 L
.23315 .30292 L
.23325 .30292 L
.23335 .30291 L
.23341 .30291 L
.23347 .30291 L
.23353 .30291 L
.23359 .30291 L
.23369 .30292 L
.23375 .30292 L
.2338 .30292 L
.2339 .30293 L
.23399 .30294 L
.2342 .30296 L
.2344 .30299 L
.23462 .30303 L
.23504 .30315 L
.23544 .30329 L
.23633 .30373 L
.23711 .30428 L
.23794 .30502 L
Mistroke
.23951 .30685 L
.24098 .30905 L
.24409 .31486 L
.24567 .31802 L
.24739 .32125 L
.24819 .32255 L
.24904 .32375 L
.24985 .32464 L
.2502 .32495 L
.25058 .32523 L
.25097 .32544 L
.25118 .32552 L
.25129 .32555 L
.25138 .32558 L
.25147 .3256 L
.25157 .32562 L
.25166 .32563 L
.25174 .32563 L
.25183 .32563 L
.25192 .32563 L
.25203 .32562 L
.25212 .32561 L
.25222 .32559 L
.25233 .32556 L
.25254 .32549 L
.25274 .3254 L
.25293 .32529 L
.25334 .32497 L
.25379 .32451 L
.25461 .32334 L
.2555 .32157 L
.25712 .31708 L
.25872 .31115 L
.2604 .30361 L
.26344 .28871 L
.26513 .28116 L
.26668 .27576 L
.26744 .27386 L
.26788 .27305 L
.26808 .27273 L
.26828 .27248 L
.26846 .27229 L
.26866 .27212 L
.26875 .27206 L
.26884 .27201 L
.26892 .27198 L
.26901 .27195 L
.26911 .27193 L
.26921 .27193 L
.26926 .27193 L
Mistroke
.26931 .27193 L
.26942 .27195 L
.26951 .27199 L
.26961 .27203 L
.26979 .27215 L
.26999 .27233 L
.27019 .27257 L
.27055 .27314 L
.27093 .27397 L
.27136 .27512 L
.27212 .27786 L
.27283 .28116 L
.27447 .29154 L
.27596 .30384 L
.27917 .33574 L
.28065 .35039 L
.28226 .36437 L
.28303 .36973 L
.28386 .37427 L
.28432 .37617 L
.28473 .37748 L
.28493 .37797 L
.28515 .37838 L
.28525 .37853 L
.28536 .37866 L
.28546 .37876 L
.28555 .37882 L
.28565 .37887 L
.28574 .37889 L
.28584 .37889 L
.28589 .37887 L
.28594 .37885 L
.28605 .37879 L
.2861 .37875 L
.28616 .37869 L
.28636 .37843 L
.28653 .37812 L
.28672 .37768 L
.2871 .37648 L
.28752 .3747 L
.28796 .37224 L
.28877 .36633 L
.28958 .35858 L
.29047 .34814 L
.29208 .32454 L
.29534 .26652 L
.29685 .24022 L
.29848 .2164 L
.29938 .20654 L
.29977 .20311 L
Mistroke
.3002 .20002 L
.3004 .19886 L
.30061 .1978 L
.30079 .19703 L
.30099 .19637 L
.30111 .19606 L
.30121 .19582 L
.30132 .19565 L
.30137 .19558 L
.30142 .19552 L
.30152 .19545 L
.30161 .19542 L
.30167 .19542 L
.30172 .19544 L
.30182 .1955 L
.30192 .19562 L
.30198 .1957 L
.30203 .19579 L
.30222 .19625 L
.3024 .19682 L
.30259 .19759 L
.30298 .19974 L
.30341 .20296 L
.30417 .21087 L
.30488 .22076 L
.30651 .25164 L
.308 .28807 L
.31119 .37771 L
.3128 .41916 L
.31426 .44859 L
.31465 .45469 L
.31507 .46029 L
.31544 .46426 L
.31584 .46763 L
.31606 .46903 L
.31627 .47004 L
.31638 .47047 L
.31648 .47078 L
.31654 .47092 L
.3166 .47105 L
.31666 .47115 L
.31672 .47121 L
.31681 .47128 L
.3169 .47128 L
.317 .47121 L
.31706 .47115 L
.31711 .47106 L
.3172 .47086 L
.31731 .47055 L
.31752 .4697 L
Mistroke
.31773 .46856 L
.31795 .46699 L
.31835 .46322 L
.31874 .45842 L
.3191 .45304 L
.31992 .43743 L
.32078 .41614 L
.32383 .31177 L
.32552 .24485 L
.32707 .18762 L
.32784 .16281 L
.32867 .13971 L
.32946 .12243 L
.32984 .11586 L
.33019 .11092 L
.33056 .10687 L
.33075 .10525 L
.33096 .10393 L
.33105 .10349 L
.33114 .1031 L
.33123 .10281 L
.33131 .10261 L
.3314 .10245 L
.3315 .10237 L
.3316 .10239 L
.33168 .10249 L
.33178 .10268 L
.33188 .10299 L
.33198 .10337 L
.33207 .1038 L
.33228 .10517 L
.33249 .10689 L
.33289 .11155 L
.33334 .11846 L
.33417 .13635 L
.33492 .15786 L
.3366 .22158 L
.33982 .37533 L
.34129 .443 L
.34213 .47628 L
.34291 .50256 L
.34369 .5231 L
.34412 .53197 L
.34452 .53827 L
.34472 .54082 L
.34493 .54302 L
.34504 .54395 L
.34517 .54482 L
.34528 .54545 L
.34538 .5459 L
Mistroke
.34548 .54621 L
.34559 .54641 L
.34569 .54647 L
.34575 .54645 L
.34581 .54639 L
.34591 .54619 L
.346 .54591 L
.34611 .54545 L
.34621 .54489 L
.3464 .54349 L
.34658 .54178 L
.34699 .53644 L
.34739 .52935 L
.34781 .51972 L
.34859 .4972 L
.3493 .47138 L
.35249 .31189 L
.35556 .15174 L
.35638 .11868 L
.35714 .09355 L
.35757 .08244 L
.35803 .07287 L
.35823 .06947 L
.35844 .06646 L
.35863 .06434 L
.35883 .06255 L
.35893 .0618 L
.35903 .06125 L
.35913 .06084 L
.35923 .06053 L
.35932 .06037 L
.3594 .06032 L
.35949 .06037 L
.35959 .06055 L
.3597 .06088 L
.35975 .06113 L
.35981 .06141 L
.36002 .06282 L
.36021 .06459 L
.36041 .06701 L
.36081 .07332 L
.36118 .08112 L
.36188 .10031 L
.36266 .1283 L
.36349 .1644 L
.36497 .24146 L
.36802 .41287 L
.36959 .48478 L
.37046 .51486 L
.37085 .52533 L
Mistroke
.37126 .5344 L
.37164 .54078 L
.37186 .54357 L
.37206 .54562 L
.37215 .54636 L
.37224 .54701 L
.37233 .54748 L
.37241 .54788 L
.37251 .5482 L
.37259 .54838 L
.3727 .54846 L
.37279 .54841 L
.3729 .5482 L
.37295 .54805 L
.37301 .54783 L
.37311 .54734 L
.37321 .54675 L
.37342 .54497 L
.37365 .54236 L
.37407 .53578 L
.37446 .52775 L
.37525 .50566 L
.37599 .47903 L
.37765 .40167 L
.38079 .23252 L
.38162 .19284 L
.38252 .1559 L
.38336 .12817 L
.38376 .11766 L
.38413 .10979 L
.38451 .10349 L
.38472 .10079 L
.38492 .09875 L
.3851 .0973 L
.38527 .09635 L
.38536 .096 L
.38545 .09572 L
.38555 .09556 L
.38565 .09554 L
.38574 .09563 L
.38585 .09587 L
.3859 .09605 L
.38596 .09628 L
.38606 .09679 L
.38626 .09819 L
.38645 .09989 L
.38689 .10575 L
.38731 .11343 L
.38809 .13308 L
.38892 .16053 L
Mistroke
.3904 .22276 L
.39344 .36803 L
.395 .43014 L
.39588 .45629 L
.39627 .46544 L
.39668 .47342 L
.39706 .47907 L
.39727 .48158 L
.39748 .48346 L
.39766 .48478 L
.39783 .48564 L
.39792 .48596 L
.39802 .48621 L
.39812 .48636 L
.39821 .48639 L
.39832 .4863 L
.39837 .4862 L
.39843 .48608 L
.39853 .48576 L
.39863 .4853 L
.39882 .48421 L
.39902 .48258 L
.39923 .48037 L
.39946 .47745 L
.39988 .47078 L
.40069 .45301 L
.40157 .42735 L
.40319 .36869 L
.4049 .29984 L
.40645 .24241 L
.40723 .21834 L
.40807 .19721 L
.40845 .18944 L
.40886 .18266 L
.40921 .17807 L
.40959 .17433 L
.40979 .1729 L
.4099 .17231 L
.41001 .17179 L
.41011 .17144 L
.41016 .17129 L
.41022 .17116 L
.41032 .171 L
.41041 .17093 L
.4105 .17094 L
.4106 .17104 L
.4107 .17125 L
.4108 .17152 L
.41089 .17186 L
.41097 .17223 L
Mistroke
.41116 .17329 L
.41137 .1749 L
.41157 .17676 L
.41202 .18216 L
.41283 .19601 L
.41361 .21345 L
.41434 .23272 L
.416 .28295 L
.41749 .32908 L
.41911 .37195 L
.42 .38948 L
.42043 .3962 L
.42081 .40119 L
.42122 .40523 L
.4214 .40669 L
.4216 .40795 L
.4218 .409 L
.4219 .40936 L
.422 .40968 L
.42205 .40983 L
.4221 .40994 L
.4222 .41012 L
.42226 .41018 L
.42232 .41022 L
.42237 .41024 L
.42243 .41024 L
.42252 .41018 L
.42262 .41005 L
.42271 .40988 L
.4228 .40964 L
.42301 .40887 L
.4232 .4079 L
.42355 .40548 L
.42393 .40203 L
.4248 .39087 L
.42558 .37745 L
.4288 .30663 L
.43027 .27605 L
.43111 .26187 L
.43189 .25141 L
.43229 .24726 L
.43266 .24408 L
.43287 .24264 L
.43309 .24134 L
.4333 .2404 L
.43349 .23972 L
.43359 .23945 L
.43369 .23921 L
.43375 .23911 L
.43381 .23902 L
Mistroke
.43386 .23896 L
.43391 .23891 L
.43397 .23888 L
.43403 .23886 L
.43413 .23887 L
.43419 .2389 L
.43425 .23895 L
.43431 .23902 L
.43437 .2391 L
.43446 .23928 L
.43455 .23949 L
.43476 .24012 L
.43496 .24094 L
.43518 .24204 L
.4356 .2448 L
.43599 .24805 L
.43688 .25758 L
.43849 .2805 L
.44 .30461 L
.44163 .3286 L
.44253 .33926 L
.44292 .34316 L
.44335 .34686 L
.44373 .34957 L
.44414 .3519 L
.44436 .35292 L
.44457 .35368 L
.44478 .35429 L
.44487 .35452 L
.44497 .35472 L
.44507 .35489 L
.44516 .355 L
.44525 .35509 L
.44534 .35515 L
.44544 .35518 L
.44553 .35517 L
.44564 .35513 L
.4457 .35509 L
.44575 .35504 L
.44585 .35491 L
.44595 .35476 L
.44617 .3543 L
.44637 .35376 L
.44657 .35305 L
.44728 .34963 L
.44805 .34431 L
.44961 .32996 L
.45129 .31233 L
.45288 .29703 L
.45371 .2905 L
Mistroke
.45417 .28752 L
.4546 .28516 L
.45502 .28328 L
.45524 .28247 L
.45547 .28174 L
.45567 .28123 L
.45589 .28078 L
.45608 .28047 L
.45617 .28035 L
.45626 .28026 L
.45636 .28019 L
.45646 .28013 L
.45655 .2801 L
.45665 .28009 L
.45674 .28011 L
.45682 .28013 L
.45691 .28018 L
.457 .28025 L
.45711 .28035 L
.45722 .28049 L
.45742 .2808 L
.4578 .28164 L
.45822 .28292 L
.45863 .28444 L
.45938 .28798 L
.46106 .29818 L
.46253 .30795 L
.46337 .31313 L
.46415 .3174 L
.46499 .32118 L
.46575 .32377 L
.46617 .32481 L
.46657 .32555 L
.46679 .32585 L
.46699 .32607 L
.46709 .32615 L
.46721 .32623 L
.46727 .32626 L
.46733 .32628 L
.46739 .3263 L
.46744 .32631 L
.46755 .32633 L
.46764 .32632 L
.46773 .32631 L
.46782 .32628 L
.46793 .32624 L
.46804 .32617 L
.46823 .32602 L
.46841 .32582 L
.46858 .32561 L
Mistroke
.46896 .32497 L
.46976 .3231 L
.47062 .32041 L
.47221 .31438 L
.47394 .30764 L
.47474 .30491 L
.47559 .3025 L
.47601 .30154 L
.4764 .30077 L
.47677 .30017 L
.47713 .29973 L
.4775 .29938 L
.4777 .29926 L
.47781 .2992 L
.47791 .29916 L
.47802 .29913 L
.47812 .29911 L
.47817 .2991 L
.47822 .29909 L
.47828 .29909 L
.47834 .29909 L
.47844 .2991 L
.47853 .29912 L
.47863 .29914 L
.47874 .29918 L
.47892 .29926 L
.47911 .29938 L
.47945 .29966 L
.47986 .3001 L
.48022 .3006 L
.48177 .30347 L
.48344 .30727 L
.485 .31064 L
.48583 .31209 L
.48629 .31276 L
.48673 .3133 L
.48713 .31372 L
.48735 .31391 L
.48758 .31407 L
.48777 .31419 L
.48799 .3143 L
.48818 .31437 L
.48836 .31443 L
.48845 .31445 L
.48855 .31446 L
.48865 .31447 L
.48875 .31448 L
.48883 .31448 L
.48892 .31448 L
.48901 .31447 L
Mistroke
.4891 .31446 L
.48919 .31445 L
.4893 .31442 L
.48948 .31437 L
.48967 .3143 L
.48989 .3142 L
.49031 .31395 L
.49071 .31365 L
.49145 .31295 L
.49313 .31095 L
.49473 .30893 L
.49619 .30742 L
.49658 .3071 L
.49701 .30681 L
.49737 .30659 L
.49777 .3064 L
.4982 .30625 L
.49843 .3062 L
.49854 .30618 L
.49865 .30616 L
.49875 .30615 L
.49885 .30613 L
.49895 .30613 L
.49904 .30612 L
.49913 .30612 L
.49924 .30612 L
.49929 .30613 L
.49935 .30613 L
.49946 .30614 L
.49956 .30615 L
.49965 .30616 L
.49985 .30619 L
.50004 .30623 L
.50022 .30628 L
.50063 .30641 L
.50107 .30659 L
.50276 .30757 L
.50432 .30863 L
.50515 .30916 L
.50604 .30966 L
.5069 .31004 L
.50768 .31029 L
.50805 .31038 L
.50825 .31041 L
.50846 .31044 L
.50867 .31047 L
.50885 .31048 L
.50894 .31049 L
.50903 .31049 L
.50912 .31049 L
Mistroke
.50921 .3105 L
.50931 .3105 L
.50941 .31049 L
.50949 .31049 L
.50959 .31049 L
.50969 .31048 L
.5098 .31048 L
.50999 .31046 L
.51034 .31042 L
.51072 .31035 L
.51158 .31015 L
.51238 .30991 L
.51549 .30887 L
.5163 .30865 L
.51673 .30855 L
.51719 .30846 L
.51763 .3084 L
.51802 .30835 L
.51822 .30833 L
.51842 .30832 L
.51862 .3083 L
.5188 .3083 L
.5189 .30829 L
.519 .30829 L
.51908 .30829 L
.51918 .30829 L
.51928 .30829 L
.51933 .30829 L
.51939 .30829 L
.51949 .30829 L
.51958 .30829 L
.51967 .30829 L
.51976 .3083 L
.51993 .3083 L
.52011 .30831 L
.52031 .30833 L
.52072 .30836 L
.52117 .30841 L
.52197 .30852 L
.52356 .30879 L
.5253 .30908 L
.52611 .30918 L
.52655 .30923 L
.52697 .30927 L
.52735 .30931 L
.5277 .30933 L
.52809 .30935 L
.5283 .30935 L
.5285 .30936 L
.5286 .30936 L
Mistroke
.52871 .30936 L
.52882 .30936 L
.52891 .30937 L
.52899 .30937 L
.52909 .30937 L
.52918 .30937 L
.52928 .30936 L
.52933 .30936 L
.52938 .30936 L
.52948 .30936 L
.52967 .30936 L
.52989 .30935 L
.5301 .30935 L
.53081 .30931 L
.53157 .30927 L
.53461 .30902 L
.53536 .30897 L
.53616 .30892 L
.53658 .3089 L
.53703 .30888 L
.53745 .30887 L
.53783 .30886 L
.53805 .30886 L
.53824 .30886 L
.53834 .30886 L
.53845 .30886 L
.53851 .30886 L
.53857 .30886 L
.53863 .30886 L
.53868 .30886 L
.53878 .30886 L
.53888 .30886 L
.53898 .30886 L
.53904 .30886 L
.53909 .30886 L
.53929 .30886 L
.53948 .30886 L
.53985 .30887 L
.5402 .30887 L
.54097 .30889 L
.54262 .30895 L
.54415 .30901 L
.54491 .30904 L
.54562 .30906 L
.54602 .30907 L
.54645 .30908 L
.54684 .30908 L
.5472 .30908 L
.5474 .30909 L
.54758 .30909 L
Mistroke
.54767 .30909 L
.54778 .30909 L
.54788 .30909 L
.54798 .30909 L
.54807 .30909 L
.54816 .30909 L
.54824 .30909 L
.54833 .30909 L
.54842 .30909 L
.54853 .30909 L
.54861 .30909 L
.5487 .30909 L
.54892 .30909 L
.54912 .30909 L
.54956 .30908 L
.54997 .30908 L
.55036 .30907 L
.55344 .30902 L
.55426 .30901 L
.55502 .309 L
.55583 .30899 L
.55625 .30899 L
.55647 .30899 L
.55671 .30899 L
.55692 .30899 L
.55711 .30899 L
.5572 .30899 L
.5573 .30899 L
.55739 .30899 L
.55748 .30899 L
.55758 .30899 L
.55767 .30899 L
.55778 .30899 L
.55783 .30899 L
.55789 .30899 L
.55799 .30899 L
.55811 .30899 L
.55832 .30899 L
.55854 .30899 L
.55874 .30899 L
.5592 .30899 L
.56001 .30899 L
.56169 .30901 L
.56323 .30902 L
.56401 .30902 L
.56474 .30903 L
.56511 .30903 L
.5655 .30903 L
.56572 .30903 L
.56593 .30903 L
Mistroke
.56612 .30903 L
.56623 .30903 L
.56633 .30903 L
.56642 .30903 L
.56652 .30903 L
.56662 .30903 L
.56672 .30903 L
.56681 .30903 L
.56691 .30903 L
.567 .30903 L
.56709 .30903 L
.56719 .30903 L
.56729 .30903 L
.56752 .30903 L
.56771 .30903 L
.56792 .30903 L
.56873 .30903 L
.56961 .30903 L
.5713 .30902 L
.57285 .30902 L
.57362 .30901 L
.57405 .30901 L
.57445 .30901 L
.5748 .30901 L
.575 .30901 L
.57519 .30901 L
.57528 .30901 L
.57538 .30901 L
.57547 .30901 L
.57556 .30901 L
.57567 .30901 L
.57576 .30901 L
.57582 .30901 L
.57587 .30901 L
.57597 .30901 L
.57606 .30901 L
.57616 .30901 L
.57626 .30901 L
.57634 .30901 L
.57655 .30901 L
.57675 .30901 L
.57714 .30901 L
.57758 .30901 L
.57906 .30901 L
.58077 .30902 L
.58158 .30902 L
.58232 .30902 L
.5831 .30902 L
.58351 .30902 L
.58371 .30902 L
Mistroke
.58394 .30902 L
.58413 .30902 L
.58431 .30902 L
.5844 .30902 L
.58449 .30902 L
.58458 .30902 L
.58466 .30902 L
.58476 .30902 L
.58485 .30902 L
.58495 .30902 L
.58505 .30902 L
.58516 .30902 L
.58521 .30902 L
.58527 .30902 L
.58546 .30902 L
.58567 .30902 L
.58589 .30902 L
.58629 .30902 L
.58704 .30902 L
.58872 .30902 L
.59028 .30902 L
.59117 .30902 L
.5916 .30902 L
.592 .30902 L
.59239 .30902 L
.59259 .30902 L
.5928 .30902 L
.593 .30902 L
.59318 .30902 L
.59327 .30902 L
.59336 .30902 L
.59345 .30902 L
.59353 .30902 L
.59363 .30902 L
.59373 .30902 L
.59382 .30902 L
.59391 .30902 L
.59401 .30902 L
.59407 .30902 L
.59413 .30902 L
.59433 .30902 L
.59452 .30902 L
.59474 .30902 L
.59517 .30902 L
.59598 .30902 L
.59673 .30902 L
.5984 .30902 L
.59914 .30902 L
.59992 .30902 L
.60038 .30902 L
Mistroke
.60079 .30902 L
.6012 .30902 L
.6014 .30902 L
.60159 .30902 L
.60177 .30902 L
.60196 .30902 L
.60207 .30902 L
.60218 .30902 L
.60227 .30902 L
.60237 .30902 L
.60247 .30902 L
.60253 .30902 L
.60258 .30902 L
.60264 .30902 L
.60269 .30902 L
.6028 .30902 L
.60289 .30902 L
.60299 .30902 L
.6032 .30902 L
.60357 .30902 L
.60397 .30902 L
.60468 .30902 L
.60628 .30902 L
.60712 .30902 L
.60801 .30902 L
.60881 .30902 L
.60926 .30902 L
.60968 .30902 L
.60988 .30902 L
.61007 .30902 L
.61024 .30902 L
.61042 .30902 L
.61053 .30902 L
.61062 .30902 L
.61072 .30902 L
.6108 .30902 L
.61091 .30902 L
.61096 .30902 L
.61102 .30902 L
.61111 .30902 L
.61122 .30902 L
.61132 .30902 L
.61142 .30902 L
.61153 .30902 L
.61164 .30902 L
.61183 .30902 L
.61204 .30902 L
.61243 .30902 L
.61279 .30902 L
.61447 .30902 L
Mistroke
.61595 .30902 L
.61679 .30902 L
.6172 .30902 L
.61758 .30902 L
.61795 .30902 L
.61835 .30902 L
.61858 .30902 L
.61878 .30902 L
.61898 .30902 L
.61908 .30902 L
.61919 .30902 L
.61924 .30902 L
.6193 .30902 L
.61935 .30902 L
.61941 .30902 L
.61951 .30902 L
.61961 .30902 L
.61966 .30902 L
.61972 .30902 L
.61982 .30902 L
.61988 .30902 L
.61995 .30902 L
.62006 .30902 L
.62026 .30902 L
.62045 .30902 L
.62088 .30902 L
.62172 .30902 L
.62252 .30902 L
.62401 .30902 L
.62479 .30902 L
.62561 .30902 L
.62632 .30902 L
.62672 .30902 L
.62709 .30902 L
.6273 .30902 L
.62749 .30902 L
.6276 .30902 L
.6277 .30902 L
.62776 .30902 L
.62782 .30902 L
.62788 .30902 L
.62793 .30902 L
.62802 .30902 L
.62811 .30902 L
.62821 .30902 L
.62831 .30902 L
.62842 .30902 L
.62853 .30902 L
.62872 .30902 L
.62909 .30902 L
Mistroke
.62943 .30902 L
.63021 .30902 L
.63183 .30902 L
.63263 .30902 L
.63336 .30902 L
.63407 .30902 L
.63443 .30902 L
.63482 .30902 L
.63502 .30902 L
.63521 .30902 L
.6354 .30902 L
.63557 .30902 L
.63577 .30902 L
.63588 .30902 L
.63599 .30902 L
.63609 .30902 L
.63618 .30902 L
.63628 .30902 L
.63634 .30902 L
.63639 .30902 L
.63649 .30902 L
.63659 .30902 L
.63668 .30902 L
.63677 .30902 L
.63699 .30902 L
.63718 .30902 L
.63754 .30902 L
.63792 .30902 L
.63958 .30902 L
.6404 .30902 L
.64118 .30902 L
.64194 .30902 L
.64263 .30902 L
.643 .30902 L
.64339 .30902 L
.64359 .30902 L
.64378 .30902 L
.64398 .30902 L
.6441 .30902 L
.6442 .30902 L
.6443 .30902 L
.64441 .30902 L
.64451 .30902 L
.6446 .30902 L
.6447 .30902 L
.64476 .30902 L
.64482 .30902 L
.64492 .30902 L
.64502 .30902 L
.64524 .30902 L
Mistroke
.64543 .30902 L
.64588 .30902 L
.64672 .30902 L
.64752 .30902 L
.64901 .30902 L
.64978 .30902 L
.6502 .30902 L
.6506 .30902 L
.65097 .30902 L
.6513 .30902 L
.65168 .30902 L
.65187 .30902 L
.65197 .30902 L
.65208 .30902 L
.65219 .30902 L
.65229 .30902 L
.65238 .30902 L
.65248 .30902 L
.65257 .30902 L
.65265 .30902 L
.65275 .30902 L
.65284 .30902 L
.65295 .30902 L
.65306 .30902 L
.65327 .30902 L
.65347 .30902 L
.65366 .30902 L
.65438 .30902 L
.65514 .30902 L
.65674 .30902 L
.65759 .30902 L
.65805 .30902 L
.65848 .30902 L
.65889 .30902 L
.65928 .30902 L
.6597 .30902 L
.65993 .30902 L
.66004 .30902 L
.66015 .30902 L
.66024 .30902 L
.66034 .30902 L
.66044 .30902 L
.66054 .30902 L
.66063 .30902 L
.66072 .30902 L
.6608 .30902 L
.66089 .30902 L
.661 .30902 L
.66109 .30902 L
.66131 .30902 L
Mistroke
.66151 .30902 L
.66169 .30902 L
.66248 .30902 L
.6633 .30902 L
.66478 .30902 L
.66554 .30902 L
.66596 .30902 L
.66636 .30902 L
.66672 .30902 L
.66713 .30902 L
.66749 .30902 L
.66765 .30902 L
.66783 .30902 L
.66793 .30902 L
.66804 .30902 L
.66814 .30902 L
.66824 .30902 L
.66835 .30902 L
.66841 .30902 L
.66847 .30902 L
.66857 .30902 L
.66863 .30902 L
.66868 .30902 L
.66877 .30902 L
.66886 .30902 L
.66896 .30902 L
.66907 .30902 L
.66928 .30902 L
.66948 .30902 L
.66985 .30902 L
.67025 .30902 L
.67097 .30902 L
.67269 .30902 L
.67349 .30902 L
.67424 .30902 L
.67461 .30902 L
.67501 .30902 L
.67541 .30902 L
.67564 .30902 L
.67585 .30902 L
.67595 .30902 L
.67605 .30902 L
.67615 .30902 L
.67624 .30902 L
.67632 .30902 L
.67641 .30902 L
.6765 .30902 L
.67659 .30902 L
.67668 .30902 L
.67679 .30902 L
Mistroke
.67687 .30902 L
.67697 .30902 L
.67718 .30902 L
.67738 .30902 L
.67778 .30902 L
.67822 .30902 L
.67902 .30902 L
.68051 .30902 L
.68133 .30902 L
.68211 .30902 L
.68249 .30902 L
.68291 .30902 L
.68315 .30902 L
.68337 .30902 L
.68357 .30902 L
.68369 .30902 L
.68379 .30902 L
.68389 .30902 L
.684 .30902 L
.68411 .30902 L
.68417 .30902 L
.68422 .30902 L
.68432 .30902 L
.68442 .30902 L
.68447 .30902 L
.68452 .30902 L
.68462 .30902 L
.68471 .30902 L
.68481 .30902 L
.68501 .30902 L
.68538 .30902 L
.68579 .30902 L
.68625 .30902 L
.68706 .30902 L
.68864 .30902 L
.68907 .30902 L
.68953 .30902 L
.68997 .30902 L
.69037 .30902 L
.69078 .30902 L
.691 .30902 L
.69123 .30902 L
.69132 .30902 L
.69142 .30902 L
.69151 .30902 L
.69161 .30902 L
.69167 .30902 L
.69173 .30902 L
.69178 .30902 L
.69183 .30902 L
Mistroke
.69193 .30902 L
.69198 .30902 L
.69204 .30902 L
.69212 .30902 L
.69222 .30902 L
.69232 .30902 L
.69242 .30902 L
.69258 .30902 L
.69276 .30902 L
.69318 .30902 L
.69355 .30902 L
.69522 .30902 L
.69595 .30902 L
.69676 .30902 L
.69713 .30902 L
.69753 .30902 L
.69788 .30902 L
.69825 .30902 L
.69847 .30902 L
.69868 .30902 L
.69887 .30902 L
.69897 .30902 L
.69908 .30902 L
.69919 .30902 L
.69929 .30902 L
.69938 .30902 L
.69948 .30902 L
.69957 .30902 L
.69965 .30902 L
.69974 .30902 L
.69984 .30902 L
.69994 .30902 L
.70005 .30902 L
.70027 .30902 L
.70047 .30902 L
.70066 .30902 L
.70155 .30902 L
.70316 .30902 L
.70395 .30902 L
.70478 .30902 L
.70513 .30902 L
.70549 .30902 L
.70589 .30902 L
.70627 .30902 L
.70648 .30902 L
.70659 .30902 L
.7067 .30902 L
.70679 .30902 L
.70688 .30902 L
.70694 .30902 L
Mistroke
.70699 .30902 L
.70709 .30902 L
.70715 .30902 L
.7072 .30902 L
.70726 .30902 L
.70731 .30902 L
.70741 .30902 L
.70747 .30902 L
.70752 .30902 L
.70774 .30902 L
.70798 .30902 L
.70838 .30902 L
.70875 .30902 L
.7096 .30902 L
.7111 .30902 L
.71189 .30902 L
.71273 .30902 L
.71315 .30902 L
.71338 .30902 L
.71362 .30902 L
.71384 .30902 L
.71404 .30902 L
.71414 .30902 L
.71424 .30902 L
.71434 .30902 L
.71444 .30902 L
.71454 .30902 L
.7146 .30902 L
.71465 .30902 L
.71475 .30902 L
.71485 .30902 L
.71494 .30902 L
.71503 .30902 L
.71522 .30902 L
.71543 .30902 L
.71562 .30902 L
.71605 .30902 L
.71771 .30902 L
.71844 .30902 L
.71925 .30902 L
.71962 .30902 L
.72002 .30902 L
.72036 .30902 L
.72074 .30902 L
.72094 .30902 L
.72114 .30902 L
.72136 .30902 L
.72146 .30902 L
.72157 .30902 L
.72167 .30902 L
Mistroke
.72177 .30902 L
.72187 .30902 L
.72196 .30902 L
.72205 .30902 L
.72214 .30902 L
.72223 .30902 L
.72233 .30902 L
.72243 .30902 L
.72253 .30902 L
.72275 .30902 L
.72314 .30902 L
.72359 .30902 L
.72402 .30902 L
.72564 .30902 L
.72642 .30902 L
.72685 .30902 L
.72725 .30902 L
.72762 .30902 L
.72796 .30902 L
.72833 .30902 L
.72854 .30902 L
.72873 .30902 L
.72883 .30902 L
.72893 .30902 L
.72902 .30902 L
.7291 .30902 L
.7292 .30902 L
.7293 .30902 L
.72935 .30902 L
.72941 .30902 L
.72951 .30902 L
.72957 .30902 L
.72962 .30902 L
.72973 .30902 L
.72983 .30902 L
.72994 .30902 L
.73033 .30902 L
.7307 .30902 L
.73104 .30902 L
.73181 .30902 L
.73331 .30902 L
.73415 .30902 L
.73455 .30902 L
.73493 .30902 L
.73532 .30902 L
.73553 .30902 L
.73576 .30902 L
.73598 .30902 L
.73609 .30902 L
.73621 .30902 L
Mistroke
.73632 .30902 L
.73638 .30902 L
.73643 .30902 L
.73654 .30902 L
.73663 .30902 L
.73673 .30902 L
.73683 .30902 L
.73688 .30902 L
.73694 .30902 L
.73704 .30902 L
.73723 .30902 L
.73741 .30902 L
.73784 .30902 L
.73825 .30902 L
.73986 .30902 L
.74056 .30902 L
.74131 .30902 L
.74174 .30902 L
.74213 .30902 L
.7425 .30902 L
.74289 .30902 L
.74309 .30902 L
.7432 .30902 L
.74331 .30902 L
.74341 .30902 L
.74351 .30902 L
.74361 .30902 L
.7437 .30902 L
.7438 .30902 L
.7439 .30902 L
.74396 .30902 L
.74401 .30902 L
.74406 .30902 L
.74412 .30902 L
.74424 .30902 L
.74434 .30902 L
.74458 .30902 L
.74498 .30902 L
.74542 .30902 L
.74622 .30902 L
.74771 .30902 L
.74847 .30902 L
.74891 .30902 L
.74931 .30902 L
.74973 .30902 L
.74996 .30902 L
.75018 .30902 L
.75038 .30902 L
.75048 .30902 L
.75057 .30902 L
Mistroke
.75068 .30902 L
.75078 .30902 L
.75088 .30902 L
.75094 .30902 L
.751 .30902 L
.7511 .30902 L
.75119 .30902 L
.75128 .30902 L
.75137 .30902 L
.75158 .30902 L
.75178 .30902 L
.75213 .30902 L
.75251 .30902 L
.75417 .30902 L
.75492 .30902 L
.75574 .30902 L
.75611 .30902 L
.7565 .30902 L
.75684 .30902 L
.75703 .30902 L
.7572 .30902 L
.75741 .30902 L
.75752 .30902 L
.75763 .30902 L
.75773 .30902 L
.75782 .30902 L
.75792 .30902 L
.75798 .30902 L
.75803 .30902 L
.75813 .30902 L
.75822 .30902 L
.75831 .30902 L
.75842 .30902 L
.75851 .30902 L
.75859 .30902 L
.75878 .30902 L
.7592 .30902 L
.75959 .30902 L
.76046 .30902 L
.76126 .30902 L
.76211 .30902 L
.76252 .30902 L
.76291 .30902 L
.76326 .30902 L
.76364 .30902 L
.76401 .30902 L
.76421 .30902 L
.7644 .30902 L
.7645 .30902 L
.76458 .30902 L
Mistroke
.76466 .30902 L
.76474 .30902 L
.76483 .30902 L
.76492 .30902 L
.76502 .30902 L
.76511 .30902 L
.76521 .30902 L
.76531 .30902 L
.7654 .30902 L
.7655 .30902 L
.76572 .30902 L
.76593 .30902 L
.7663 .30902 L
.7667 .30902 L
.76829 .30902 L
.76913 .30902 L
.76959 .30902 L
.77002 .30902 L
.77043 .30902 L
.77081 .30902 L
.77102 .30902 L
.77123 .30902 L
.77145 .30902 L
.77157 .30902 L
.77168 .30902 L
.77178 .30902 L
.77188 .30902 L
.77198 .30902 L
.77207 .30902 L
.77215 .30902 L
.77224 .30902 L
.77234 .30902 L
.77243 .30902 L
.77263 .30902 L
.77281 .30902 L
.77322 .30902 L
.77401 .30902 L
.77475 .30902 L
.77561 .30902 L
.77641 .30902 L
.7768 .30902 L
.77721 .30902 L
.77742 .30902 L
.77765 .30902 L
.77787 .30902 L
.77807 .30902 L
.77826 .30902 L
.77844 .30902 L
.77854 .30902 L
.77863 .30902 L
Mistroke
.77873 .30902 L
.77878 .30902 L
.77884 .30902 L
.77893 .30902 L
.77902 .30902 L
.77912 .30902 L
.77921 .30902 L
.7793 .30902 L
.77938 .30902 L
.77956 .30902 L
.77977 .30902 L
.77997 .30902 L
.78041 .30902 L
.78121 .30902 L
.7827 .30902 L
.78348 .30902 L
.78386 .30902 L
.78421 .30902 L
.78441 .30902 L
.78463 .30902 L
.78481 .30902 L
.78501 .30902 L
.78523 .30902 L
.78535 .30902 L
.78546 .30902 L
.78556 .30902 L
.78565 .30902 L
.78576 .30902 L
.78581 .30902 L
.78587 .30902 L
.78597 .30902 L
.78607 .30902 L
.78612 .30902 L
.78618 .30902 L
.78629 .30902 L
.7865 .30902 L
.78669 .30902 L
.78744 .30902 L
.78912 .30902 L
.78996 .30902 L
.79037 .30902 L
.79075 .30902 L
.79112 .30902 L
.79146 .30902 L
.79166 .30902 L
.79184 .30902 L
.79203 .30902 L
.79214 .30902 L
.79224 .30902 L
.79234 .30902 L
Mistroke
.79244 .30902 L
.79252 .30902 L
.79262 .30902 L
.79272 .30902 L
.79277 .30902 L
.79283 .30902 L
.79293 .30902 L
.79302 .30902 L
.79321 .30902 L
.79337 .30902 L
.79375 .30902 L
.79456 .30902 L
.79541 .30902 L
.79618 .30902 L
.797 .30902 L
.7974 .30902 L
.79777 .30902 L
.79811 .30902 L
.79847 .30902 L
.79866 .30902 L
.79877 .30902 L
.79887 .30902 L
.79896 .30902 L
.79906 .30902 L
.79915 .30902 L
.79924 .30902 L
.79933 .30902 L
.79943 .30902 L
.79953 .30902 L
.79959 .30902 L
.79964 .30902 L
.79974 .30902 L
.79985 .30902 L
.80007 .30902 L
.80049 .30902 L
.80095 .30902 L
.80176 .30902 L
.80254 .30902 L
.80336 .30902 L
.80379 .30902 L
.80426 .30902 L
.80469 .30902 L
.80509 .30902 L
.80529 .30902 L
.80539 .30902 L
.8055 .30902 L
.80561 .30902 L
.80571 .30902 L
.8058 .30902 L
.8059 .30902 L
Mistroke
.80599 .30902 L
.80608 .30902 L
.80616 .30902 L
.80625 .30902 L
.80635 .30902 L
.80645 .30902 L
.80663 .30902 L
.80685 .30902 L
.80708 .30902 L
.8075 .30902 L
.80829 .30902 L
.80985 .30902 L
.81028 .30902 L
.81074 .30902 L
.81117 .30902 L
.81136 .30902 L
.81157 .30902 L
.81177 .30902 L
.81195 .30902 L
.81213 .30902 L
.81221 .30902 L
.8123 .30902 L
.8124 .30902 L
.8125 .30902 L
.8126 .30902 L
.81269 .30902 L
.81279 .30902 L
.81289 .30902 L
.81294 .30902 L
.813 .30902 L
.8131 .30902 L
.81332 .30902 L
.81351 .30902 L
.81394 .30902 L
.81472 .30902 L
.81554 .30902 L
.8164 .30902 L
.81714 .30902 L
.81755 .30902 L
.81794 .30902 L
.81814 .30902 L
.81835 .30902 L
.81854 .30902 L
.81873 .30902 L
.81889 .30902 L
.81898 .30902 L
.81907 .30902 L
.81916 .30902 L
.81925 .30902 L
.81935 .30902 L
Mistroke
.81944 .30902 L
.81954 .30902 L
.81963 .30902 L
.81974 .30902 L
.81984 .30902 L
.82021 .30902 L
.82061 .30902 L
.82104 .30902 L
.82261 .30902 L
.82304 .30902 L
.8235 .30902 L
.82393 .30902 L
.82433 .30902 L
.82474 .30902 L
.82495 .30902 L
.82506 .30902 L
.82518 .30902 L
.82528 .30902 L
.82538 .30902 L
.82547 .30902 L
.82556 .30902 L
.82567 .30902 L
.82577 .30902 L
.82582 .30902 L
.82587 .30902 L
.82593 .30902 L
.82599 .30902 L
.82607 .30902 L
.82617 .30902 L
.82627 .30902 L
.82636 .30902 L
.82671 .30902 L
.82709 .30902 L
.8275 .30902 L
.82908 .30902 L
.82992 .30902 L
.83039 .30902 L
.83081 .30902 L
.83122 .30902 L
.83145 .30902 L
.83166 .30902 L
.83185 .30902 L
.83195 .30902 L
.83205 .30902 L
.83216 .30902 L
.83225 .30902 L
.8323 .30902 L
.83236 .30902 L
.83246 .30902 L
.83256 .30902 L
Mistroke
.83265 .30902 L
.83275 .30902 L
.83285 .30902 L
.83307 .30902 L
.83326 .30902 L
.834 .30902 L
.83565 .30902 L
.83645 .30902 L
.83683 .30902 L
.83718 .30902 L
.83755 .30902 L
.83774 .30902 L
.83794 .30902 L
.83812 .30902 L
.83829 .30902 L
.83838 .30902 L
.83847 .30902 L
.83857 .30902 L
.83866 .30902 L
.83876 .30902 L
.83885 .30902 L
.83896 .30902 L
.83906 .30902 L
.83915 .30902 L
.83923 .30902 L
.83942 .30902 L
.83982 .30902 L
.84024 .30902 L
.84184 .30902 L
.84254 .30902 L
.8433 .30902 L
.84372 .30902 L
.8439 .30902 L
.84411 .30902 L
.84428 .30902 L
.84448 .30902 L
.84458 .30902 L
.84468 .30902 L
.84478 .30902 L
.84487 .30902 L
.84497 .30902 L
.84503 .30902 L
.84508 .30902 L
.84518 .30902 L
.84528 .30902 L
.84533 .30902 L
.84539 .30902 L
.84546 .30902 L
.84551 .30902 L
.84573 .30902 L
Mistroke
.84594 .30902 L
.84613 .30902 L
.84655 .30902 L
.84821 .30902 L
.84894 .30902 L
.84933 .30902 L
.84975 .30902 L
.85015 .30902 L
.85032 .30902 L
.85052 .30902 L
.85069 .30902 L
.85087 .30902 L
.85097 .30902 L
.85106 .30902 L
.85115 .30902 L
.85124 .30902 L
.85134 .30902 L
.85144 .30902 L
.85154 .30902 L
.85163 .30902 L
.85168 .30902 L
.85174 .30902 L
.85183 .30902 L
.85194 .30902 L
.85205 .30902 L
.85225 .30902 L
.85245 .30902 L
.85282 .30902 L
.85443 .30902 L
.85527 .30902 L
.85574 .30902 L
.85617 .30902 L
.85655 .30902 L
.85677 .30902 L
.85697 .30902 L
.85718 .30902 L
.8573 .30902 L
.85742 .30902 L
.85752 .30902 L
.85762 .30902 L
.85768 .30902 L
.85774 .30902 L
.85779 .30902 L
.85784 .30902 L
.85793 .30902 L
.85803 .30902 L
.85812 .30902 L
.8582 .30902 L
.8584 .30902 L
.85859 .30902 L
Mistroke
.85897 .30902 L
.85939 .30902 L
.86095 .30902 L
.86178 .30902 L
.86225 .30902 L
.86267 .30902 L
.86308 .30902 L
.8633 .30902 L
.86351 .30902 L
.8637 .30902 L
.8638 .30902 L
.8639 .30902 L
.864 .30902 L
.8641 .30902 L
.8642 .30902 L
.86425 .30902 L
.86431 .30902 L
.86441 .30902 L
.86451 .30902 L
.86469 .30902 L
.86489 .30902 L
.8651 .30902 L
.86584 .30902 L
.8674 .30902 L
.86783 .30902 L
.86829 .30902 L
.86872 .30902 L
.86912 .30902 L
.86932 .30902 L
.86952 .30902 L
.86972 .30902 L
.8699 .30902 L
.87001 .30902 L
.87011 .30902 L
.87016 .30902 L
.87022 .30902 L
.87028 .30902 L
.87033 .30902 L
.87044 .30902 L
.87053 .30902 L
.87058 .30902 L
.87064 .30902 L
.87074 .30902 L
.87093 .30902 L
.87113 .30902 L
.87154 .30902 L
.87228 .30902 L
.8731 .30902 L
.87397 .30902 L
.8747 .30902 L
Mistroke
.87512 .30902 L
.87551 .30902 L
.8757 .30902 L
.87581 .30902 L
.87592 .30902 L
.87601 .30902 L
.87611 .30902 L
.87621 .30902 L
.8763 .30902 L
.87639 .30902 L
.87648 .30902 L
.87656 .30902 L
.87664 .30902 L
.87674 .30902 L
.87683 .30902 L
.87693 .30902 L
.87701 .30902 L
.87722 .30902 L
.87741 .30902 L
.87784 .30902 L
.87862 .30902 L
.87941 .30902 L
.88026 .30902 L
.88067 .30902 L
.88106 .30902 L
.88141 .30902 L
.88161 .30902 L
.88179 .30902 L
.88197 .30902 L
.88216 .30902 L
.88227 .30902 L
.88237 .30902 L
.88246 .30902 L
.88256 .30902 L
.88262 .30902 L
.88267 .30902 L
.88277 .30902 L
.88287 .30902 L
.88293 .30902 L
.88299 .30902 L
.88308 .30902 L
.88318 .30902 L
.88338 .30902 L
.88374 .30902 L
.88414 .30902 L
.88485 .30902 L
.88566 .30902 L
.88609 .30902 L
.88655 .30902 L
.88695 .30902 L
Mistroke
.88739 .30902 L
.88758 .30902 L
.88779 .30902 L
.88798 .30902 L
.88816 .30902 L
.88836 .30902 L
.88846 .30902 L
.88856 .30902 L
.88865 .30902 L
.88874 .30902 L
.88883 .30902 L
.88893 .30902 L
.88903 .30902 L
.88909 .30902 L
.88914 .30902 L
.88933 .30902 L
.88944 .30902 L
.88956 .30902 L
.88977 .30902 L
.89065 .30902 L
.89146 .30902 L
.89231 .30902 L
.89273 .30902 L
.89311 .30902 L
.89346 .30902 L
.89383 .30902 L
.89402 .30902 L
.8942 .30902 L
.8944 .30902 L
.89451 .30902 L
.89461 .30902 L
.8947 .30902 L
.89479 .30902 L
.89489 .30902 L
.895 .30902 L
.8951 .30902 L
.89515 .30902 L
.89521 .30902 L
.89541 .30902 L
.89559 .30902 L
.89579 .30902 L
.89614 .30902 L
.89781 .30902 L
.89863 .30902 L
.8991 .30902 L
.89953 .30902 L
.8999 .30902 L
.90011 .30902 L
.90031 .30902 L
.90042 .30902 L
Mistroke
.90052 .30902 L
.90061 .30902 L
.90071 .30902 L
.90076 .30902 L
.90082 .30902 L
.90088 .30902 L
.90094 .30902 L
.90104 .30902 L
.90109 .30902 L
.90114 .30902 L
.90125 .30902 L
.90134 .30902 L
.90152 .30902 L
.90172 .30902 L
.90193 .30902 L
.90266 .30902 L
.90345 .30902 L
.90432 .30902 L
.90472 .30902 L
.90514 .30902 L
.90554 .30902 L
.90591 .30902 L
.90613 .30902 L
.90633 .30902 L
.90644 .30902 L
.90655 .30902 L
.9066 .30902 L
.90667 .30902 L
.90672 .30902 L
.90678 .30902 L
.90688 .30902 L
.90697 .30902 L
.90707 .30902 L
.90713 .30902 L
.90718 .30902 L
.90728 .30902 L
.9074 .30902 L
.9076 .30902 L
.90799 .30902 L
.90836 .30902 L
.90919 .30902 L
.91001 .30902 L
.91046 .30902 L
.91087 .30902 L
.91128 .30902 L
.91165 .30902 L
.91186 .30902 L
.91206 .30902 L
.91227 .30902 L
.91239 .30902 L
Mistroke
.91249 .30902 L
.91258 .30902 L
.91267 .30902 L
.91276 .30902 L
.91284 .30902 L
.91293 .30902 L
.91303 .30902 L
.91313 .30902 L
.91322 .30902 L
.91332 .30902 L
.91341 .30902 L
.91359 .30902 L
.91398 .30902 L
.91546 .30902 L
.9163 .30902 L
.91671 .30902 L
.91708 .30902 L
.91748 .30902 L
.91785 .30902 L
.91806 .30902 L
.91825 .30902 L
.91835 .30902 L
.91846 .30902 L
.91852 .30902 L
.91858 .30902 L
.91863 .30902 L
.91868 .30902 L
.91878 .30902 L
.91889 .30902 L
.91899 .30902 L
.91908 .30902 L
.91913 .30902 L
.91918 .30902 L
.9193 .30902 L
.91951 .30902 L
.91993 .30902 L
.92037 .30902 L
.92119 .30902 L
.92197 .30902 L
.92266 .30902 L
.92306 .30902 L
.92342 .30902 L
.92378 .30902 L
.92399 .30902 L
.92418 .30902 L
.92428 .30902 L
.92438 .30902 L
.92447 .30902 L
.92457 .30902 L
.92467 .30902 L
Mistroke
.92473 .30902 L
.92478 .30902 L
.92489 .30902 L
.92498 .30902 L
.92508 .30902 L
.92519 .30902 L
.9254 .30902 L
.92579 .30902 L
.92666 .30902 L
.92753 .30902 L
.92796 .30902 L
.92835 .30902 L
.92874 .30902 L
.92909 .30902 L
.92948 .30902 L
.9297 .30902 L
.9299 .30902 L
.93008 .30902 L
.93018 .30902 L
.93028 .30902 L
.93038 .30902 L
.93047 .30902 L
.93052 .30902 L
.93058 .30902 L
.93068 .30902 L
.93076 .30902 L
.93086 .30902 L
.93096 .30902 L
.93105 .30902 L
.9314 .30902 L
.9318 .30902 L
.93217 .30902 L
.93301 .30902 L
.93375 .30902 L
.93415 .30902 L
.93453 .30902 L
.93475 .30902 L
.93498 .30902 L
.93539 .30902 L
.9356 .30902 L
.93571 .30902 L
.93581 .30902 L
.93591 .30902 L
.93599 .30902 L
.93609 .30902 L
.9362 .30902 L
.9363 .30902 L
.9364 .30902 L
.93648 .30902 L
.93658 .30902 L
Mistroke
.93668 .30902 L
.93679 .30902 L
.93699 .30902 L
.93734 .30902 L
.93772 .30902 L
.9386 .30902 L
.93939 .30902 L
.93978 .30902 L
.9402 .30902 L
.94056 .30902 L
.94096 .30902 L
.94118 .30902 L
.94138 .30902 L
.9416 .30902 L
.94172 .30902 L
.94183 .30902 L
.94194 .30902 L
.94203 .30902 L
.94213 .30902 L
.94219 .30902 L
.94225 .30902 L
.94234 .30902 L
.94245 .30902 L
.94255 .30902 L
.94264 .30902 L
.94284 .30902 L
.94302 .30902 L
.94342 .30902 L
.94415 .30902 L
.94501 .30902 L
.94539 .30902 L
.94581 .30902 L
.94617 .30902 L
.94655 .30902 L
.94676 .30902 L
.94696 .30902 L
.94714 .30902 L
.94734 .30902 L
.94744 .30902 L
.94754 .30902 L
.94759 .30902 L
.94765 .30902 L
.94775 .30902 L
.94785 .30902 L
.94795 .30902 L
.94804 .30902 L
.94814 .30902 L
.94819 .30902 L
.94825 .30902 L
.94835 .30902 L
Mistroke
.94859 .30902 L
.94879 .30902 L
.94901 .30902 L
.95072 .30902 L
.95111 .30902 L
.95153 .30902 L
.95191 .30902 L
.95227 .30902 L
.95264 .30902 L
.95284 .30902 L
.95305 .30902 L
.95316 .30902 L
.95328 .30902 L
.95333 .30902 L
.95339 .30902 L
.95349 .30902 L
.95359 .30902 L
.95368 .30902 L
.95378 .30902 L
.95384 .30902 L
.95389 .30902 L
.95398 .30902 L
.95408 .30902 L
.95425 .30902 L
.95464 .30902 L
.95542 .30902 L
.95619 .30902 L
.95702 .30902 L
.95745 .30902 L
.95768 .30902 L
.95792 .30902 L
.95814 .30902 L
.95835 .30902 L
.95856 .30902 L
.95866 .30902 L
.95875 .30902 L
.95885 .30902 L
.95893 .30902 L
.95903 .30902 L
.95914 .30902 L
.95923 .30902 L
.95934 .30902 L
.95939 .30902 L
.95945 .30902 L
.95955 .30902 L
.95964 .30902 L
.95975 .30902 L
.95994 .30902 L
.96029 .30902 L
.96116 .30902 L
Mistroke
.96196 .30902 L
.96269 .30902 L
.96309 .30902 L
.96347 .30902 L
.96368 .30902 L
.96391 .30902 L
.96413 .30902 L
.96432 .30902 L
.96443 .30902 L
.96453 .30902 L
.96462 .30902 L
.96471 .30902 L
.96481 .30902 L
.96491 .30902 L
.96501 .30902 L
.96507 .30902 L
.96512 .30902 L
.96522 .30902 L
.96528 .30902 L
.96533 .30902 L
.96553 .30902 L
.96575 .30902 L
.96596 .30902 L
.96676 .30902 L
.96747 .30902 L
.96825 .30902 L
.96863 .30902 L
.96904 .30902 L
.96926 .30902 L
.96947 .30902 L
.96968 .30902 L
.96987 .30902 L
.97005 .30902 L
.97014 .30902 L
.97023 .30902 L
.97033 .30902 L
.97042 .30902 L
.97048 .30902 L
.97053 .30902 L
.97063 .30902 L
.97072 .30902 L
.97081 .30902 L
.9709 .30902 L
.97098 .30902 L
.97117 .30902 L
.97135 .30902 L
.97173 .30902 L
.97214 .30902 L
.97297 .30902 L
.97375 .30902 L
Mistroke
.97445 .30902 L
.97466 .30902 L
.97488 .30902 L
.97508 .30902 L
.97529 .30902 L
.97552 .30902 L
.97564 .30902 L
.97576 .30902 L
.97587 .30902 L
.97597 .30902 L
.97602 .30902 L
.97608 .30902 L
.97614 .30902 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{421.375, 260.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008>0001AB000`400?l00000o`00003ooooooooo
oooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo
003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooo
oooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool0
0?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooooooo
ool@ooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooo
ooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo0ol0003o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0
003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo
00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`
ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLoooo
o`00<?ooool3o`000?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?oo
ool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0
033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomco
oooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooo
oooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
06Wooooo00?o0000ooooooooool0oooooom`ooooo`00<?ooool00ol0003oooooooooo`1Yooooo`03
o`000?oooooooooo0?ooooooL?ooool0033ooooo0ol0001Yooooo`;o0000oooooomaooooo`00<?oo
ool00ol0003oooooooooo`1Yooooo`;o0000oooooomaooooo`00<?ooool00ol0003oooooooooo`1Y
ooooo`;o0000oooooomaooooo`00<?ooool00ol0003oooooooooo`1Yooooo`;o0000oooooomaoooo
o`00<?ooool00ol0003oooooooooo`1Yooooo`;o0000oooooomaooooo`00<?ooool00ol0003ooooo
ooooo`1Yooooo`;o0000oooooomaooooo`00<?ooool00ol0003oooooooooo`1Yooooo`;o0000oooo
oomaooooo`004?ooool2onk^kP?ooooo0_o^k^hIooooo`03o`000?oooooooooo06Sooooo00?o0000
ooooool00000oooooomaooooo`002oooool2o`00000:oa0@4?ooooooooooonk^k_mEEEGok^k^oooo
ooo^k^koEEEEonk^kP?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^2_oo
ool00ol0003oooooooooo`1Xooooo`03o`000?oooooo00000?ooooooLOooool000cooooo00?o0000
ooooooooool00_ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00[ooooo00?o0000ooooooooool0J?ooool00ol0003ooooo
o`00003oooooog7ooooo00000ooooooo0000o`000004o`0000;ooooo1Ol00004ooooo`03omgMgOl0
003ogMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00[ooooo
00?o0000ooooooooool0J?ooool00ol0003oooooo`00003oooooog7ooooo0009ooooo`04odA4A?oM
gMgoooooo`0000Cooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`00000:ooooo`03o`000?oooooooooo06Sooooo00?o0000oooo
ool00000oooooomaooooo`002Oooool01?oMgMgoEEEEooooool00003ooooo`07onk^k_mEEEGok^k^
ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000:ooooo`Co0000Ioooool00ol0003oooooo`00003oooooog7ooooo000:ooooo`03ogMgMoo<
c<co000000?ooooo0_o^k^h3ooooo`;ok^k^1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oo
ooooooooooooool@41002_ooool00ol0003oooooooooo`1Xooooo`03o`000?oooooo000000[ooooo
00?o0000ooooooooool0oooooomTooooo`002_ooool00oo^k^koA4A4o`00000?ooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`;o00001Oooool00ol0003ooooo
ooooo`1Xooooo`03o`000?oooooo000000Wooooo0_l0003oooooofKooooo000;ooooo`03ogMgMol0
003ooooo00cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1Xooooo`03o`000?oooooo000000Wo
oooo0_l0003oooooofKooooo000Xooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool0GOooool00ol0003oooooooooo`08ooooo`03o`000?oooooo000000Wooooo0_l0003oooooofKo
oooo000Xooooo`?o00001Oooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooool000002Oooool2o`000?ooooooI_ooool002Wooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo00Sooooo00?o0000ooooool000002Ooo
ool2o`000?ooooooI_ooool002[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1M
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooool000002Oooool2o`000?ooooooI_ooool0
033ooooo00?o0000ooooooooool0G?ooool2o`0000[ooooo00?o0000ooooool000002Oooool2o`00
0?ooooooI_ooool0033ooooo00?o0000ooooooooool0G?ooool00ol0003oooooo`000009ooooo`03
o`000?oooooo000000Wooooo0_l0003oooooofKooooo000`ooooo`03o`000?oooooooooo05cooooo
00?o0000ooooool000002Oooool00ol0003oooooo`000009ooooo`;o0000oooooomVooooo`00<?oo
ool00ol0003oooooooooo`1Looooo`03o`000?oooooo000000Wooooo00Co0000oooooooooooo0000
2?ooool2o`000?ooooooI_ooool0033ooooo0ol0001Looooo`03o`000?oooooo000000Wooooo00Co
0000oooooooooooo00002?ooool2o`000?ooooooI_ooool0033ooooo00?o0000ooooooooool0G?oo
ool00ol0003oooooo`000009ooooo`04o`000?ooooooooooo`0000Sooooo0_l0003oooooofKooooo
000`ooooo`03o`000?oooooooooo05cooooo00?o0000ooooool000002Oooool01?l0003ooooooooo
ool00008ooooo`03o`000?oooooo00000?ooooooIOooool0033ooooo00?o0000ooooooooool0G?oo
ool00ol0003oooooo`000009ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000
oooooomUooooo`00<?ooool00ol0003oooooooooo`1Looooo`03o`000?oooooo000000Wooooo00Co
0000oooooooooooo00002?ooool00ol0003oooooo`00003oooooofGooooo000`ooooo`03o`000?oo
oooooooo05cooooo00?o0000ooooool000002Oooool01?l0003oooooooooool00008ooooo`03o`00
0?oooooo00000?ooooooIOooool0033ooooo00?o0000ooooooooool0G?ooool00ol0003oooooo`00
0009ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooomUooooo`00<?oo
ool00ol0003oooooooooo`1Looooo`03o`000?oooooo000000Wooooo00Co0000oooooooooooo0000
2?ooool00ol0003oooooo`00003oooooofGooooo000`ooooo`03o`000?oooooooooo05cooooo00?o
0000ooooool000002Oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?oooooo
IOooool0033ooooo00?o0000ooooooooool0G?ooool00ol0003oooooo`000009ooooo`04o`000?oo
ooooooooo`0000Sooooo00?o0000ooooool00000oooooomUooooo`00<?ooool00ol0003ooooooooo
o`1Looooo`03o`000?oooooo000000Wooooo00Co0000oooooooooooo00002?ooool00ol0003ooooo
o`00003oooooofGooooo000`ooooo`03o`000?oooooooooo05cooooo00?o0000ooooool000002Ooo
ool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`000?ooooooIOooool0033ooooo
0ol0001Looooo`03o`000?oooooo000000Wooooo00Co0000oooooooooooo00001oooool01?l0003o
ooooooooool0003oooooofGooooo000`ooooo`03o`000?oooooooooo05cooooo00Co0000oooooooo
oooo00002?ooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`000?ooooooIOoo
ool0033ooooo00?o0000ooooooooool0G?ooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000Oooooo00Co0000oooooooooooo0000oooooomUooooo`00<?ooool00ol0003ooooo
ooooo`1Kooooo`05o`000?ooooooooooooooool000002?ooool01?l0003oooooooooool00007oooo
o`04o`000?ooooooooooo`000?ooooooIOooool0033ooooo00?o0000ooooooooool0Foooool01Ol0
003ooooooooooooooooo000000Sooooo00Co0000oooooooooooo00001oooool01?l0003ooooooooo
ool0003oooooofGooooo000`ooooo`03o`000?oooooooooo05_ooooo00Go0000oooooooooooooooo
o`000008ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo0000oooooomUoooo
o`00<?ooool00ol0003oooooooooo`1Kooooo`05o`000?ooooooooooooooool000002?ooool01?l0
003oooooooooool00007ooooo`04o`000?ooooooooooo`000?ooooooIOooool0033ooooo00?o0000
ooooooooool0Foooool01Ol0003ooooooooooooooooo000000Sooooo00Co0000oooooooooooo0000
1oooool01?l0003oooooooooool0003oooooofGooooo000`ooooo`03o`000?oooooooooo05_ooooo
00Go0000ooooooooooooooooo`000008ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooo
oooooooo0000oooooomUooooo`00<?ooool00ol0003oooooooooo`1Kooooo`05o`000?oooooooooo
ooooool000002?ooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`000?oooooo
IOooool0033ooooo00?o0000ooooooooool0Foooool01Ol0003ooooooooooooooooo000000Sooooo
00Co0000oooooooooooo00001oooool01?l0003oooooooooool00008ooooo`;o0000oooooomKoooo
o`00<?ooool3o`0005_ooooo00Go0000ooooooooooooooooo`000008ooooo`04o`000?oooooooooo
o`0000Oooooo00Co0000oooooooooooo00002?ooool2o`000?ooooooFoooool0033ooooo00?o0000
ooooooooool0Foooool01Ol0003ooooooooooooooooo000000Sooooo00Co0000oooooooooooo0000
1oooool01?l0003oooooooooool00008ooooo`;o0000oooooomKooooo`00<?ooool00ol0003ooooo
ooooo`1Kooooo`05o`000?ooooooooooooooool000002?ooool01?l0003oooooooooool00007oooo
o`04o`000?ooooooooooo`0000Sooooo0_l0003ooooooe_ooooo000`ooooo`03o`000?oooooooooo
05_ooooo00Go0000ooooooooooooooooo`000008ooooo`04o`000?ooooooooooo`0000Oooooo00Co
0000oooooooooooo00002?ooool2o`000?ooooooFoooool0033ooooo00?o0000ooooooooool0Fooo
ool01Ol0003ooooooooooooooooo000000Sooooo00Co0000oooooooooooo00001oooool01?l0003o
ooooooooool00008ooooo`;o0000oooooomKooooo`00<?ooool00ol0003oooooooooo`1Kooooo`05
o`000?ooooooooooooooool000002?ooool01?l0003oooooooooool00007ooooo`04o`000?oooooo
ooooo`0000Sooooo0_l0003ooooooe_ooooo000`ooooo`03o`000?oooooooooo05_ooooo00Go0000
ooooooooooooooooo`000008ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo
00001oooool00ol0003oooooo`00003ooooooe_ooooo000@ooooo`;ok^k^0oooool2onk^kQWooooo
00?o0000ooooooooool0Foooool01Ol0003ooooooooooooooooo000000Sooooo00Co0000oooooooo
oooo00001oooool01?l0003oooooooooool00007ooooo`03o`000?oooooo00000?ooooooFoooool0
00Wooooo1Ol00002ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co000000So
410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP[ooooo00?o0000ooooooooool0Foooool01Ol0
003ooooooooooooooooo000000Sooooo00Co0000oooooooooooo00001oooool01?l0003ooooooooo
ool00007ooooo`03o`000?oooooo00000?ooooooFoooool000Wooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A003ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02_ooool00ol0003oooooooooo`1Kooooo`05o`000?oooooooooo
ooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooo00000?ooooooFoooool00003ooooool0003o000000Co00000ooo
ool00onHV9So8B4Qonk^kP05ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@00[ooooo00?o0000ooooooooool0D?ooool00ol0003ooooo
ooooo`08ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo0000
00Oooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo00000?ooooooFoooool0
00_ooooo00?oV9RHob4Q8Oo^k^h00oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000000[ooooo00?o0000ooooooooool0D?oo
ool2o`0000Wooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool0
00001oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooool00000oooooomKoooo
o`003?ooool02omgMgOoIVIVooooooooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000[ooooo1?l0001>ooooo`03
o`000?oooooo000000Wooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooooooo
ooooool000001oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooool00000oooo
oomKooooo`003Oooool00ol0003oooooooooo`02onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooo
oooo00;ooooo00Go410@oooooooooooooooooa0@400:ooooo`03o`000?oooooooooo04oooooo00?o
0000ooooool000002Oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooooooooooo
ooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooo`00003ooooo
oe_ooooo0009ooooo`05o`000?nj^[[ooooooiRHV?l@41003_ooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL00oooool2o`0000Gooooo00?o0000ooooooooool0Coooool0
0ol0003oooooo`000009ooooo`05o`000?ooooooooooooooool000001oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooo00000?ooooooFoooool000Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00<ooooo`03oeEE
EOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooooooool0Coooool00ol0003oooooo`000009ooooo`05o`000?oooooooooo
ooooool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000
ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`000?ooooooF_ooool002Sooooo00Co
0000oooooooooooo00001?ooool00ol0003oooooooooo`1?ooooo`03o`000?oooooo000000Wooooo
00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo0000oooooomJ
ooooo`00:?ooool3o`0000Gooooo00?o0000ooooooooool0Coooool00ol0003oooooo`000009oooo
o`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`000?oooooo
F_ooool002Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1?ooooo`03o`000?oo
oooo000000Wooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo
00Co0000oooooooooooo0000oooooomJooooo`00:_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo04oooooo00?o0000ooooool000002Oooool01Ol0003ooooooooooooooooo000000Oo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0003ooooooe[ooooo000`ooooo`03
o`000?oooooooooo04oooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0003o
oooooe[ooooo000`ooooo`03o`000?oooooooooo04oooooo00Co0000oooooooooooo00001oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
1?l0003oooooooooool0003ooooooe[ooooo000`ooooo`03o`000?oooooooooo04oooooo00Co0000
oooooooooooo00001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool01?l0003oooooooooool0003ooooooe[ooooo000`ooooo`03o`000?oo
oooooooo04oooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0003ooooooe[o
oooo000`ooooo`?o0000Coooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`00
0?ooooooF_ooool0033ooooo00?o0000ooooooooool0C_ooool01Ol0003ooooooooooooooooo0000
00Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00Co0000oooooooooooo0000oooooomJooooo`00<?ooool00ol0003oooooooooo`1>oooo
o`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0003ooooooe[ooooo000`
ooooo`03o`000?oooooooooo04kooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`04o`000?oo
ooooooooo`000?ooooooF_ooool0033ooooo00?o0000ooooooooool0C_ooool01Ol0003ooooooooo
oooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00Co0000oooooooooooo0000oooooomJooooo`00<?ooool00ol0003ooooo
ooooo`1>ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00007oooo
o`;o0000oooooomAooooo`00<?ooool00ol0003oooooooooo`1>ooooo`05o`000?oooooooooooooo
ool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01?ooool01?l0003oooooooooool00007ooooo`;o0000oooooomAooooo`00<?ooool00ol0
003oooooooooo`1>ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0
0007ooooo`;o0000oooooomAooooo`00<?ooool00ol0003oooooooooo`1>ooooo`05o`000?oooooo
ooooooooool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool01?l0003oooooooooool00007ooooo`;o0000oooooomAooooo`00<?oo
ool00ol0003oooooooooo`1>ooooo`05o`000?ooooooooooooooool000001oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01?l0003ooooo
ooooool00007ooooo`;o0000oooooomAooooo`00<?ooool00ol0003oooooooooo`1>ooooo`05o`00
0?ooooooooooooooool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00007ooooo`;o0000oooooomAoooo
o`00<?ooool00ol0003oooooooooo`1>ooooo`05o`000?ooooooooooooooool000001oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01?l0
003oooooooooool00007ooooo`;o0000oooooomAooooo`00<?ooool3o`0004gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000
ooooool00000oooooom@ooooo`00<?ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00006ooooo`04o`000?oooooo
ooooo`000?ooooooD?ooool0033ooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000005ooooo`04o`000?oo
ooooooooo`000?ooooooD?ooool0033ooooo00?o0000ooooooooool0COooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000005ooooo`04o`00
0?ooooooooooo`000?ooooooD?ooool0033ooooo00?o0000ooooooooool0COooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000005ooooo`04
o`000?ooooooooooo`000?ooooooD?ooool0033ooooo00?o0000ooooooooool0COooool00ol0003o
k^k^onk^kP02ooooo`03o`000?o^k^kok^k^00Gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000005oooo
o`04o`000?ooooooooooo`00023ooooo0_o^k^h3ooooo`;ok^k^H?ooool2onk^kP?ooooo0_o^k^i>
ooooo`;ok^k^0oooool2onk^kVcooooo000`ooooo`03o`000?oooooooooo04Sooooo00goA4A4o`00
0?l0003o<S8bomgMgOl0003ok^k^oeEEEOo^k^koooooo`000?mEEEGok^k^00?ooooo1?l000001?l@
413oooooooooooo^k^h2o`000003oc8b<_o^k^kooooo00;ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
1Ol0003ooooooooooooooooo000000Gooooo00Co0000oooooooooooo00006_ooool4o`000009oa0@
4?ooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413oooooooooooo^
k^ko<S8bo`000?lb<S;ok^k^>oooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`0=
odA4A?l0003o0000oc8b<_oMgMgoooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co
000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kSSooooo1Ol00002ooooo`07onk^k_mE
EEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o
<S8bonk^kUgooooo000`ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool01_ooool0
2OmgMgOo<S8bo`000?ooooook^k^oeEEEOoMgMgoEEEEo`000006ooooo`03o`000?oooooooooo00;o
oooo00GoMgMgo`000?ooooooV9RHogMgM`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000006oooool0
0ol0003oooooooooo`02ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?Oooool00ol0003oooooooooo`04ooooo`;o8B4Q
2?ooool02OmgMgOo<S8booooooooooook^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0hooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
0oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg05gooooo000`ooooo`03o`000?oooooooooo047ooooo0ol00008ooooo`;o
00000_ooool01?oMgMgo0000omgMgOl00006ooooo`03o`000?oooooooooo00;ooooo00Go410@o`00
0?oooooooooooa0@4002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000006oooool00ol0003ooooooooo
o`03ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@03gooooo00?o0000ooooooooool03oooool01ol0003ooooooooooooooooogMgMo`00
0?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100>Oooool0
0onHV9So8B4Qonk^kP05ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@05gooooo000`ooooo`03o`000?oooooooooo047ooooo00?o0000
ooooool000001oooool02OmgMgOo<S8bo`000?ooooook^k^oeEEEOoMgMgoEEEEo`000006ooooo`03
o`000?oooooooooo00;ooooo0_l00002ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000006oooool0
0ol0003oooooooooo`02ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool00000?Oooool00ol0003oooooooooo`0>ooooo`09ogMg
Molb<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000003[ooooo00?oV9RHob4Q8Oo^k^h00oooool01Oo^k^koEEEEomgM
gOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000005go
oooo000`ooooo`03o`000?oooooooooo047ooooo00?o0000ooooool000001?ooool03Ol0003o8B4Q
o`000?lb<S;oc<c<o`000?o^k^koEEEEonk^k_ooooook^k^o`000?o^k^h01Oooool00ol0003ooooo
ooooo`02ooooo`;o00000_ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000001_ooooo00_o0000oooo
ooooooooooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`00000mooooo`03o`000?oooooooooo00_ooooo00go0000ob4Q
8Ol0003o<S8bolc<c?ooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000003_ooooo00_oMgMgofIVI_ooooooooooonk^
k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`00001Mooooo`00<?ooool00ol0003oooooooooo`10ooooo`05o`000?oooooooooo
ooooool000000oooool00ol0003oooooooooo`02ooooo`03o`000?o^k^kok^k^00?ooooo00?o0000
onk^k_ooool01?ooool00ol0003oooooooooo`02ooooo`05oa0@4?l0003oooooooooool@41000_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooo
ool01Ol0003ooooooooooooooooo000000Kooooo0_l0000Cooooo`04o`000?ooooooooooooooo`;o
k^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@
03gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`03ooooo`;ok^k^0oooool2onk^
kPGooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@03cooooo00?o0000
ooooooooool00_o^k^h3ooooo`;ok^k^1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooo
ooooooooool@4100GOooool0033ooooo0ol00010ooooo`05o`000?ooooooooooooooool000000ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`02ooooo`05ogMgMol0003ooooooiRHV?mgMgL00_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooo
oooooooooooo000000Kooooo0_l0000Cooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo0_l0000cooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02?ooool2o`0002kooooo00Go0000okZj^_ooooooV9RHoa0@400>ooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`;o0000Doooool0033ooooo00?o
0000ooooooooool0@?ooool01Ol0003ooooooooooooooooo000000?ooooo1?l000000ooooooo0000
ooooo`04ooooo`03o`000?oooooooooo00;ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko0000
o`000?lb<S;ok^k^00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000006ooooo`;o00004Oooool00omE
EEGoIVIVo`00000=ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP07
ooooo`04o`000?ooooooooooo`00033ooooo00?oEEEEofIVI_l000003Oooool4o`0000cooooo00?o
EEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oooooo00Co0000oooooooooooo
0000;Oooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo00?oEEEEofIVI_l000001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Oooooo00Co0000oooooooooooo0000D_ooool0033ooooo00?o0000
ooooooooool0@?ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool4o`0000;ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooooooo
o`000005ooooo`04o`000?ooooooooooo`0002kooooo1?l000001Ooooooo0000oooooooooooo0000
05kooooo1?l000001Ooooooo0000oooooooooooo000004cooooo1?l000001Ooooooo0000oooooooo
oooo000005;ooooo000`ooooo`03o`000?oooooooooo043ooooo00Go0000ooooooooooooooooo`00
0008ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool2o`0000Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Gooooo00Co0000oooooooooooo
0000<oooool3o`0006Cooooo0ol0001Booooo`?o0000Doooool0033ooooo00?o0000ooooooooool0
@?ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`;o000000?oooooo`000?ooool00_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool0000doooo
o`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`1Boooo
o`00<?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo1?l00003ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`04
o`000?ooooooooooo`0003Gooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`1Boooo
o`03o`000?oooooooooo057ooooo000`ooooo`03o`000?oooooooooo03oooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`000?ooooooA_ooool0033o
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00Co0000oooooooooooo00001_ooool2o`000?oooooo1?ooool00omgMgOoIVIVooooo`0]oooo
o`03ofIVI_mgMgOooooo00Oooooo000`ooooo`03o`000?oooooooooo03?ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooo
oooo00001_ooool00ol0003oooooo`00003oooooo`;ooooo00?ogMgMoa0@4?o^k^h0;_ooool00oo^
k^ko410@omgMg@07ooooo`00<?ooool00ol0003oooooooooo`0aooooo`Co00002Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00001_ooool00ol0
003oooooo`00003_ooooo`;o00000_ooool2o`0000cooooo00?oEEEEoiRHV?ooool00_l00002oooo
o`07o`000?ooooooooooo`000?l@413ok^k^oeEEE@02o`000003odA4A?nj^[[ooooo00;ooooo00Go
V9RHo`000?l0003oA4A4okZj^P02ooooo`08onk^k_mEEEGo0000o`000?m4A4Co^[Zjooooool@4105
o`0000?ooooo00So410@oc8b<_l0003o0000oa0@4?nYZJWoQhN7ofIVIPOooooo000`ooooo`03o`00
0?oooooooooo02kooooo0ol00003ooooo`;o00002?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`04o`00
0?ooooooooooo`0000Kooooo0ol0003Vooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM3?ooool0
1Ol0003ooooooooooooooooo000000;ooooo00_o0000oooooooooooo0000oooooomEEEGoMgMgoooo
ooo^k^koMgMgoa0@4003ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000_ooool01_mEEEGoMgMgoooo
ooo^k^koMgMgoa0@40?ooooo00?o0000ooooooooool01?ooool02?l0003oZJVYoooooooooooo^[Zj
o`000?o^k^ko00001oooool00?oo0000]?l0000?ooooo`04omgMgOl0003o410@olc<c0gooooo00Go
<S8booooooooooooooooo`000002ooooo`06o`000?ooooooooooo`000?oooooo00002?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool01onj
^[[oQhN7ofIVI_mVIVKo410@ooooool000001oooool000[ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool0
1?l0003oooooooooooooool7o`0000Oooooo0_l00006ooooo`03o`000?oooooooooo00Gooooo00Co
0000oooooooooooo00000oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
0_l00004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
o`000003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooooooool2o`0000Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooo000000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01?l0000<ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool05oooool01?o^k^ko8B4Qoa0@4?o^k^h=ooooo`05oc8b<_oooooo
ooooooooool000000_ooool01Ol0003oooooooooool0003ooooo00Ko00000oooool00ol0003ooooo
ooooo`04ooooo`Ko00000oooool00ol0003oooooooooo`04ooooo`08oc8b<_lQ8B7oMgMgogMgMon7
QhOok^k^ooooool00007ooooo`002_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`05ooooo`04o`000?oooooooooo
o`0000?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`;o00001?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000000oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooooooo0_l0
0004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooo`00
0002ooooo`05o`000?ooooooooooooooool000001Oooool4o`0000;ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Oooooo00Co8B4QogMgMomgMgOo
<S8b3Oooool01Ol0003ok^k^oooooooooooo000000;oc<c<00_o0000ojVYZOoMgMgo8B4QoooooomE
EEGoQhN7onk^k_ooooooQhN7oc8b<P03ooooo`03o`000?oooooooooo00Cooooo00KoEEEEohN7Qoo^
k^koooooohN7Qolb<S83ooooo`03o`000?lb<S;ogMgM00Cooooo00So0000okZj^_ooooook^k^ogMg
Mol0003ok^k^o`0000Oooooo000`ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`04ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000001_ooool2o`0001Kooooo00?o0000ooooooooool0Foooool00ol0003o
ooooooooo`1Kooooo`03o`000?oooooooooo01Kooooo0_l00002ooooo`;o00003?ooool03_mEEEGo
MgMgooooool@413o0000ob4Q8Ol0003oMgMgoa0@4?l0003oZJVYooooooo^k^koEEEE0_l000001?m4
A4Cok^k^ooooool@4105o`0000?ooooo00Kok^k^oeEEEOl0003o0000odA4A?o^k^h2ooooo`;o0000
00CoZJVYob4Q8Ol0003o8B4Q0_ooool02?nYZJWo8B4Qo`000?l0003o<S8bo`000?mgMgOoEEEE1ooo
ool0033ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00Go0000ooooooooooooooooo`000005ooooo`04o`000?ooooooooooo`000?oooooo
1_ooool00ooMgMgo410@onk^kP0Booooo`03o`000?oooooooooo01Wooooo00?ok^k^oa0@4?oMgMd0
1oooool0033ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooo00000?oooooo
2?ooool00omgMgOoIVIVooooo`0Aooooo`03o`000?oooooooooo01Wooooo00?oIVIVogMgMoooool0
1oooool0033ooooo00?o0000ooooooooool0>Oooool01?l0003oooooooooool00009ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`04o`00
0?ooooooooooo`0000Kooooo00?o0000ooooool00000oooooom2ooooo`00<?ooool00ol0003ooooo
ooooo`0iooooo`Co00002Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool01?l0003oooooooooool00006ooooo`?o0000oooooom2ooooo`00
<?ooool00ol0003oooooooooo`0jooooo`;o00002_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00007ooooo`;o
0000oooooom2ooooo`00<?ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool0
00001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`000?ooooooBoooool0033o
oooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool01?l0003oooooooooool0003ooooood_ooooo000`ooooo`03o`000?oooooooooo
04Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Co0000
oooooooooooo0000oooooom;ooooo`00<?ooool3o`0004Kooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00
0006ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00Co0000oooooooooooo0000oooooom;ooooo`00<?ooool00ol0003ooooo
ooooo`16ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo0000
00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`04o`000?oooooooooo
o`000?ooooooBoooool0033ooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo
000000Kooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool01?l0003oooooooooool0003ooooood_ooooo000`ooooo`03o`000?oo
oooooooo04Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool0
00001Oooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo0000oooooom;
ooooo`00<?ooool00ol0003oooooooooo`17ooooo`05o`000?ooooooooooooooool000002?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooo
oooooooo000000Gooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`00
0?ooooooBoooool0033ooooo00?o0000ooooooooool0Aoooool01Ol0003ooooooooooooooooo0000
00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000
ooooooooooooooooo`000005ooooo`05o`000?ooooooooooooooool000001oooool00ol0003ooooo
o`00003ooooood_ooooo000`ooooo`03o`000?oooooooooo04Oooooo00Go0000oooooooooooooooo
o`000008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`05
o`000?ooooooooooooooool000001Oooool01Ol0003ooooooooooooooooo000000Oooooo0_l0003o
ooooodcooooo000`ooooo`03o`000?oooooooooo04Oooooo00Go0000ooooooooooooooooo`000008
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?oo
ooooooooooooool000001_ooool01?l0003oooooooooool00007ooooo`;o0000oooooom<ooooo`00
<?ooool00ol0003oooooooooo`17ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo
000000Kooooo00Co0000oooooooooooo00001oooool2o`000?ooooooC?ooool0033ooooo00?o0000
ooooooooool0Aoooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000006ooooo`04
o`000?ooooooooooo`000?ooooooEOooool0033ooooo00?o0000ooooooooool0B?ooool01?l0003o
ooooooooool00008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006
ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool0003ooooooeGooooo
000`ooooo`03o`000?oooooooooo04Sooooo00Co0000oooooooooooo00002?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo0000
00Kooooo00Co0000oooooooooooo0000oooooomEooooo`00<?ooool3o`0004Sooooo00Co0000oooo
oooooooo00002?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_oo
ool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo0000oooooomEooooo`00
<?ooool00ol0003oooooooooo`18ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000006
ooooo`04o`000?ooooooooooo`000?ooooooEOooool0033ooooo00?o0000ooooooooool0B?ooool0
1?l0003oooooooooool00008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooooooo
o`000006ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool0003ooooo
oeGooooo000`ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooool000002Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo
000000Kooooo00Co0000oooooooooooo0000oooooomEooooo`00<?ooool00ol0003oooooooooo`18
ooooo`03o`000?oooooo000000Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooo
oooo000000Kooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`000?oo
ooooEOooool0033ooooo00?o0000ooooooooool0B?ooool3o`0000Wooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000006oooo
o`04o`000?ooooooooooo`000?ooooooEOooool0033ooooo00?o0000ooooooooool0BOooool2o`00
00Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000
ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`000?ooooooEOooool0033ooooo00?o
0000ooooooooool0BOooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go
0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003o
ooooooooool0003ooooooeGooooo000`ooooo`03o`000?oooooooooo05Cooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000006
ooooo`04o`000?ooooooooooo`000?ooooooEOooool0033ooooo00?o0000ooooooooool0E?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooo
oooooooo000000Kooooo00Co0000oooooooooooo0000oooooomEooooo`00<?ooool00ol0003ooooo
ooooo`1Dooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`05
o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool0003ooooooeGooooo000`oooo
o`03o`000?oooooooooo05Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo
000000Kooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`000?oooooo
EOooool0033ooooo0ol0001Dooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooooooo
o`000006ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool0003ooooo
oeGooooo000`ooooo`03o`000?oooooooooo05Cooooo00Go0000ooooooooooooooooo`000008oooo
o`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Kooooo00Go
0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?ooooooEOooool0033ooooo00?o
0000ooooooooool0E?ooool01Ol0003ooooooooooooooooo000000Sooooo00Go0000oooooooooooo
ooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo
000000Oooooo00?o0000ooooool00000oooooomEooooo`00<?ooool00ol0003oooooooooo`1Doooo
o`05o`000?ooooooooooooooool000002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go
0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001oooool2o`000?oo
ooooE_ooool0033ooooo00?o0000ooooooooool0EOooool01?l0003oooooooooool00008ooooo`05
o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000
ooooool000002?ooool2o`000?ooooooE_ooool0033ooooo00?o0000ooooooooool0EOooool01?l0
003oooooooooool00008ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooo
oooooooo000000Oooooo00?o0000ooooool000002?ooool2o`000?ooooooE_ooool000oooooo0_o^
k^h3ooooo`;ok^k^6_ooool00ol0003oooooooooo`1Eooooo`04o`000?ooooooooooo`0000Sooooo
00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool00ol0
003oooooo`000008ooooo`;o0000oooooomFooooo`002?ooool5o`0000;ooooo00Ook^k^oeEEEOo^
k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;o
k^k^2oooool00ol0003oooooooooo`1Eooooo`04o`000?ooooooooooo`0000Sooooo00Go0000oooo
ooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooo`00
0008ooooo`;o0000oooooomFooooo`002?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00Go
k^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`03o`000?oooooooooo05Gooooo00Co0000oooooooooooo00002?ooool01Ol0
003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oo
oooo000000Sooooo0_l0003ooooooeKooooo0009ooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?ogMgM
o`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41002ooo
ool00ol0003oooooooooo`1Eooooo`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooooooo
ooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003ooooo
of3ooooo000:ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06oooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000;ooooo`03o`000?oooooo
oooo05Gooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Oooooo
00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?ooooooH?ooool000_ooooo
00_oMgMgofIVI_ooooooooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000;ooooo`Co0000E?ooool01?l0003ooooo
ooooool00008ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo
000000Oooooo00?o0000ooooool00000oooooomPooooo`003?ooool00ol0003oooooooooo`02onk^
kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400;
ooooo`03o`000?oooooooooo05Gooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooo
oooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?oo
ooooH?ooool000Sooooo00Go0000okZj^_ooooooV9RHoa0@400>ooooo`03o`000?oooooooooo00;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03o`000?oooooooooo05Gooooo00Co0000oooo
oooooooo00002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooooooooooooooo
o`000007ooooo`03o`000?oooooo00000?ooooooH?ooool000Sooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c00<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`;o
00001_ooool00ol0003oooooooooo`1Eooooo`04o`000?ooooooooooo`0000Sooooo00Go0000oooo
ooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooo`00
003oooooof3ooooo000Wooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0EOoo
ool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003o
oooooooooooooooo000000Oooooo00?o0000ooooool00000oooooomPooooo`009oooool01?l0003o
ooooooooool00005ooooo`03o`000?oooooooooo05Gooooo00Co0000oooooooooooo00002?ooool0
1Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`03o`00
0?oooooo00000?ooooooH?ooool002Oooooo0ol00006ooooo`03o`000?oooooooooo05Gooooo00Co
0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooooooo
ooooooooo`000007ooooo`03o`000?oooooo00000?ooooooH?ooool002Sooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`1Eooooo`04o`000?ooooooooooo`0000Sooooo00Go0000oooo
ooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooo`00
003oooooof3ooooo000Yooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0E_ooool0
0ol0003oooooo`000008ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooo
oooooooo000000Oooooo00?o0000ooooool00000oooooomPooooo`00<?ooool00ol0003ooooooooo
o`1Fooooo`03o`000?oooooo000000Sooooo00Go0000ooooooooooooooooo`000007ooooo`05o`00
0?ooooooooooooooool000001oooool00ol0003oooooo`00003oooooof3ooooo000`ooooo`03o`00
0?oooooooooo05Kooooo00?o0000ooooool000002?ooool01Ol0003ooooooooooooooooo000000Oo
oooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?ooooooH?ooool0033o
oooo00?o0000ooooooooool0E_ooool00ol0003oooooo`000008ooooo`05o`000?oooooooooooooo
ool000001oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?ooooooH?ooool0
033ooooo0ol0001Fooooo`03o`000?oooooo000000Sooooo00Go0000ooooooooooooooooo`000007
ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooomPooooo`00<?ooool0
0ol0003oooooooooo`1Fooooo`03o`000?oooooo000000Sooooo00Go0000ooooooooooooooooo`00
0007ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooomPooooo`00<?oo
ool00ol0003oooooooooo`1Fooooo`03o`000?oooooo000000Sooooo00Go0000oooooooooooooooo
o`000007ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooomPooooo`00
<?ooool00ol0003oooooooooo`1Fooooo`03o`000?oooooo000000Sooooo00Go0000oooooooooooo
ooooo`000008ooooo`03o`000?oooooo000000Sooooo00?o0000ooooool00000oooooomPooooo`00
<?ooool00ol0003oooooooooo`1Fooooo`03o`000?oooooo000000Sooooo00Go0000oooooooooooo
ooooo`000008ooooo`03o`000?oooooo000000Sooooo00?o0000ooooool00000oooooomPooooo`00
<?ooool00ol0003oooooooooo`1Fooooo`03o`000?oooooo000000Sooooo00Go0000oooooooooooo
ooooo`000008ooooo`03o`000?oooooo000000Sooooo00?o0000ooooool00000oooooomPooooo`00
<?ooool00ol0003oooooooooo`1Fooooo`03o`000?oooooo000000Sooooo00Go0000oooooooooooo
ooooo`000008ooooo`03o`000?oooooo000000Sooooo00?o0000ooooool00000oooooomPooooo`00
<?ooool00ol0003oooooooooo`1Fooooo`03o`000?oooooo000000Wooooo00Co0000oooooooooooo
00002?ooool00ol0003oooooo`000008ooooo`03o`000?oooooo00000?ooooooH?ooool0033ooooo
00?o0000ooooooooool0E_ooool2o`0000[ooooo00Co0000oooooooooooo00002?ooool00ol0003o
ooooo`000008ooooo`03o`000?oooooo00000?ooooooH?ooool0033ooooo00?o0000ooooooooool0
E_ooool2o`0000[ooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`000008ooooo`03
o`000?oooooo00000?ooooooH?ooool0033ooooo00?o0000ooooooooool0E_ooool2o`0000[ooooo
00Co0000oooooooooooo00002?ooool00ol0003oooooo`000008ooooo`03o`000?oooooo00000?oo
ooooH?ooool0033ooooo00?o0000ooooooooool0E_ooool2o`0000[ooooo00Co0000oooooooooooo
00002?ooool00ol0003oooooo`000008ooooo`03o`000?oooooo00000?ooooooH?ooool0033ooooo
0ol0001Gooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooo00002?ooool00ol0003o
ooooo`000008ooooo`03o`000?oooooo00000?ooooooH?ooool0033ooooo00?o0000ooooooooool0
H_ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo000000Sooooo00?o0000ooooool0
0000oooooomPooooo`00<?ooool00ol0003oooooooooo`1Rooooo`04o`000?ooooooooooo`0000So
oooo00?o0000ooooool000002?ooool00ol0003oooooo`00003oooooof3ooooo000`ooooo`03o`00
0?oooooooooo06;ooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`000009ooooo`;o
0000oooooomPooooo`00<?ooool00ol0003oooooooooo`1Rooooo`04o`000?ooooooooooo`0000So
oooo00?o0000ooooool000002Oooool00ol0003oooooooooo`3ooooooeoooooo000`ooooo`03o`00
0?oooooooooo06;ooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`000009ooooo`03
o`000?oooooooooo0?ooooooGoooool0033ooooo00?o0000ooooooooool0H_ooool00ol0003ooooo
o`000009ooooo`03o`000?oooooo000000Wooooo00?o0000ooooooooool0oooooomOooooo`00<?oo
ool00ol0003oooooooooo`1Rooooo`03o`000?oooooo000000Wooooo00?o0000ooooool00000oooo
oom[ooooo`00<?ooool00ol0003oooooooooo`1Rooooo`03o`000?oooooo000000Wooooo00?o0000
ooooool00000oooooom[ooooo`00<?ooool00ol0003oooooooooo`1Rooooo`03o`000?oooooo0000
00Wooooo00?o0000ooooool00000oooooom[ooooo`00<?ooool00ol0003oooooooooo`1Rooooo`03
o`000?oooooo000000Wooooo00?o0000ooooool00000oooooom[ooooo`00<?ooool00ol0003ooooo
ooooo`1Rooooo`03o`000?oooooo000000Wooooo00?o0000ooooool00000oooooom[ooooo`00<?oo
ool3o`0006;ooooo00?o0000ooooool000002Oooool00ol0003oooooo`00003oooooof_ooooo000`
ooooo`03o`000?oooooooooo06;ooooo00?o0000ooooool000002Oooool00ol0003oooooo`00003o
ooooof_ooooo000`ooooo`03o`000?oooooooooo06;ooooo00?o0000ooooool000002Oooool00ol0
003oooooo`00003oooooof_ooooo000`ooooo`03o`000?oooooooooo06;ooooo00?o0000ooooool0
00002Oooool00ol0003oooooo`00003oooooof_ooooo000`ooooo`03o`000?oooooooooo06;ooooo
00?o0000ooooool000002Oooool00ol0003oooooo`00003oooooof_ooooo000`ooooo`03o`000?oo
oooooooo06;ooooo00?o0000ooooool000002Oooool00ol0003oooooo`00003oooooof_ooooo000?
ooooo`;ok^k^0oooool2onk^kQ[ooooo00?o0000ooooooooool0H_ooool00ol0003oooooo`000009
ooooo`03o`000?oooooo00000?ooooooJoooool000[ooooo0_l000002_l@413oooooooooooo^k^ko
EEEEonk^k_ooooook^k^oeEEEOo^k^h3ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o
<S8bonk^kP_ooooo00?o0000ooooooooool0H_ooool00ol0003oooooo`000009ooooo`03o`000?oo
oooo00000?ooooooJoooool000_ooooo00?o0000ooooooooool00_ooool01Oo^k^koEEEEomgMgOmE
EEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00?o0000ooooooooool0H_ooool00ol0003oooooo`000009ooooo`03o`000?oooooo00000?oooooo
Joooool000Sooooo1Ol00004ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00?o0000ooooooooool0H_ooool00ol0003ooooo
o`000009ooooo`03o`000?oooooo00000?ooooooJoooool000Sooooo00CoA4A4omgMgOoooooo0000
1?ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000000_ooooo00?o0000ooooooooool0H_ooool00ol0003oooooo`000009oooo
o`03o`000?oooooo00000?ooooooJoooool000Sooooo00CogMgMoeEEEOoooooo00000oooool01oo^
k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000002oooool4o`00067ooooo00?o0000ooooool000002Oooool00ol0003ooooo
o`00003oooooof_ooooo0009ooooo`03ogMgMoo<c<co000000?ooooo0_o^k^h3ooooo`;ok^k^1Ooo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41002oooool00ol0003ooooo
ooooo`1Rooooo`03o`000?oooooo000000Wooooo00?o0000ooooool00000oooooom[ooooo`002Ooo
ool00oo^k^koA4A4o`00000?ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`03o`000?oooooooooo06?ooooo0_l00009ooooo`03o`000?oooooo00000?oooooo
Joooool000[ooooo00?oMgMgo`000?ooool03?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00oooool2o`0000Kooooo00?o0000ooooooooool0Hoooool2o`0000Wooooo
00?o0000ooooool00000oooooom[ooooo`009oooool01?l0003oooooooooool00005ooooo`03o`00
0?oooooooooo06?ooooo0_l00009ooooo`03o`000?oooooo00000?ooooooJoooool002Oooooo00Co
0000oooooooooooo00001Oooool00ol0003oooooooooo`1Sooooo`;o00002Oooool00ol0003ooooo
o`00003oooooof_ooooo000Wooooo`?o00001_ooool00ol0003oooooooooo`1Sooooo`;o00002Ooo
ool00ol0003oooooo`00003oooooof_ooooo000Xooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0Hoooool2o`0000Wooooo0_l0003oooooofcooooo000Yooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0Hoooool2o`0000[ooooo00?o0000ooooooooool0oooooomZoooo
o`00<?ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool0oooooomZooooo`00<?ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo0?oooooo
J_ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool3o`000?oooooog?ooool0
033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomco
oooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooo
oooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooo
ooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000
ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`?o
0000oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0
003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo
00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`
ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLoooo
o`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooo
g?ooool0033ooooo0ol0003oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0
033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomco
oooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool00?ooooooooooool@ooooo`00oooooooo
oooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo
003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo002Tooooo`;o
00000oooool00onj^[[o<S8booooo`05ooooo`;o00001Oooool00ol0003o^[Zjooooo`3ooooooeCo
oooo002Tooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`03ooooo`;o<S8boooooomEooooo`00TOooool3o`0000;ooooo00Ko<S8boa0@4?oooooooooo
onk^k_mEEED2o`000003odA4A?nj^[[ooooo00?ooooo00Ko0000oooooooooooooooooiRHV?l@4102
o`000003ojVYZOoooooooooo00?ooooo00?o0000ooooooooool00oooool00on7QhOo0000okZj^P0<
ooooo`05oiRHV?l0003o0000odA4A?nj^[X02_ooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo
0_lQ8B43ooooo`05olc<c?o^k^koooooonk^k_o<c<`01?ooool4o`000008oa0@4?ooooooooooonk^
k_lb<S;o0000oc8b<_o^k^hCooooo`06oa0@4?lb<S;o0000o`000?l@413oZJVY0_ooool01_o^k^ko
EEEEo`000?l0003oA4A4okZj^P?ooooo00GoIVIVo`000?l0003oA4A4olc<c03/ooooo`00T_ooool0
1Ol0003oooooooooooo<c<co410@00?ooooo00KoEEEEogMgMoooooook^k^ogMgMol@4104ooooo`0:
o`000?ooooooooooooooool0003oZJVYoeEEEOnHV9SoEEEEokZj^PCooooo00?o0000ooooooooool0
0oooool00oo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000_ooool6o`0000Go
oooo00?oMgMgoc8b<_ooool00oooool2ob4Q8@?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06oooo
o`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Cooooo`06o`000?nYZJWo
oooooooooonj^[[o00000_ooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40;ooooo00KoIVIVogMg
MoooooooooooohN7Qol@413/ooooo`00T_ooool01Ol0003ooooooooooomEEEGoQhN700?ooooo00?o
0000ooooooooool01oooool02_l0003ooooooooooooooooo<S8bonk^k_nHV9SoEEEEomgMgOl@4104
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`08
ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@01Cooooo00Go^[ZjohN7QomVIVKoIVIVoa0@4002ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0koooool009;ooooo00Go0000oooooooMgMgo0000onk^kP03ooooo`Ko0000
1?ooool02ol0003ooooooooooooooooo^[ZjodA4A?o<c<co8B4Qooooool@413oc<c<00?ooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`04ooooo`Ko00001Oooool00omgMgOo<S8boooo
o`08ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000004oooool01_lb<S;o8B4QogMgMomgMgOoQhN7onk^kP;ooooo1_l00002
ooooo`03o`000?oooooooooo0>oooooo002Booooo`?o000000?o410@oiRHV?ooool00_ooool01_mE
EEGoQhN7onk^k_ooooooQhN7oc8b<PCooooo00_o0000ooooooooooooooooonk^k_l0003oooooo`00
0?ooooooIVIVohN7Q`03ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03?ooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00Wooooo00Goc<c<onk^k_ooooook^k^olc<c006ooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Cooooo`06o`000?nj^[[oooooonk^
k_mgMgOo00000_ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<P;ooooo00KoIVIVogMgMooooooo
ooooohN7Qol0003/ooooo`00T_ooool01Ol0003oooooooooooo<c<co000000?ooooo00Kok^k^oeEE
EOl0003o0000odA4A?o^k^h4ooooo`08o`000?oooooooooooooooomVIVKoV9RHoooooolb<S82okZj
^P05o`000?ooooooooooooooool000004_ooool00ol@413o0000o`000003o`0000_ooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41001ooo
ool3o`0000;ooooo0ol00004ooooo`06ojVYZOlQ8B7o0000o`000?lb<S;o00000_ooool01_o^k^ko
EEEEo`000?l0003oA4A4onk^kP;ooooo00Kok^k^ofIVI_l0003o0000odA4A?l0003/ooooo`00T_oo
ool01Ol0003oooooooooooo<c<co000000gooooo00?o0000ooooooooool01?ooool00omVIVKoQhN7
ooooo`04ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0ooooool6ooooo`00TOooool4o`000003oa0@
4?nYZJWooooo00cooooo0_l00005ooooo`03ojVYZOm4A4Cooooo00?ooooo0_l0000Dooooo`03o`00
0?oooooooooo00cooooo1?l0000Cooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP02ooooo`Co00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oo
oooo1_ooool00?oooooo0_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo
1_ooool00?oooooo0_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo1_oo
ool00?oooooo0Oooool2o`0000?ooooo0_l0003oooooo`Sooooo003ooooooooooooo4?ooool00?oo
ooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@
ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooo
oooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3o
oooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooo
oooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?oo
ool00?ooooooooooool@ooooo`00\
\>"],
  ImageRangeCache->{{{0, 525.688}, {324.5, 0}} -> {-2.58312*^-7, -6.34248*^6, \
6.65005*^-9, 53093.5}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0.309017 5.42214e-08 [
[.32684 .29652 -16.5 -12.5 ]
[.32684 .29652 16.5 0 ]
[.54329 .29652 -16.5 -12.5 ]
[.54329 .29652 16.5 0 ]
[.75974 .29652 -22.5 -12.5 ]
[.75974 .29652 22.5 0 ]
[.97619 .29652 -16.5 -12.5 ]
[.97619 .29652 16.5 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 64 6 ]
[.09789 .09213 -34.5 -6.25 ]
[.09789 .09213 0 6.25 ]
[.09789 .20057 -34.5 -6.25 ]
[.09789 .20057 0 6.25 ]
[.09789 .41746 -28.5 -6.25 ]
[.09789 .41746 0 6.25 ]
[.09789 .5259 -28.5 -6.25 ]
[.09789 .5259 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -62.8125 0 ]
[.5 .63053 62.8125 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 .30902 m
.32684 .31527 L
s
gsave
.32684 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 .30902 m
.54329 .31527 L
s
gsave
.54329 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 .30902 m
.75974 .31527 L
s
gsave
.75974 .29652 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 .30902 m
.15368 .31277 L
s
.19697 .30902 m
.19697 .31277 L
s
.24026 .30902 m
.24026 .31277 L
s
.28355 .30902 m
.28355 .31277 L
s
.37013 .30902 m
.37013 .31277 L
s
.41342 .30902 m
.41342 .31277 L
s
.45671 .30902 m
.45671 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.58658 .30902 m
.58658 .31277 L
s
.62987 .30902 m
.62987 .31277 L
s
.67316 .30902 m
.67316 .31277 L
s
.71645 .30902 m
.71645 .31277 L
s
.80303 .30902 m
.80303 .31277 L
s
.84632 .30902 m
.84632 .31277 L
s
.88961 .30902 m
.88961 .31277 L
s
.9329 .30902 m
.9329 .31277 L
s
.0671 .30902 m
.0671 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09213 m
.11664 .09213 L
s
gsave
.09789 .09213 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .20057 m
.11664 .20057 L
s
gsave
.09789 .20057 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .41746 m
.11664 .41746 L
s
gsave
.09789 .41746 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .5259 m
.11664 .5259 L
s
gsave
.09789 .5259 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.11039 .11924 m
.11414 .11924 L
s
.11039 .14635 m
.11414 .14635 L
s
.11039 .17346 m
.11414 .17346 L
s
.11039 .22768 m
.11414 .22768 L
s
.11039 .2548 m
.11414 .2548 L
s
.11039 .28191 m
.11414 .28191 L
s
.11039 .33613 m
.11414 .33613 L
s
.11039 .36324 m
.11414 .36324 L
s
.11039 .39035 m
.11414 .39035 L
s
.11039 .44457 m
.11414 .44457 L
s
.11039 .47168 m
.11414 .47168 L
s
.11039 .49879 m
.11414 .49879 L
s
.11039 .06502 m
.11414 .06502 L
s
.11039 .03791 m
.11414 .03791 L
s
.11039 .0108 m
.11414 .0108 L
s
.11039 .55301 m
.11414 .55301 L
s
.11039 .58012 m
.11414 .58012 L
s
.11039 .60723 m
.11414 .60723 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -123.812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.812 moveto
(@) show
81.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.812 moveto
(D) show
93.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5.2) show
135.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
141.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
153.000 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
157.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
166.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
184.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02691 .30902 L
.03029 .30902 L
.03347 .30902 L
.03652 .30902 L
.03733 .30902 L
.03809 .30902 L
.03852 .30902 L
.03874 .30902 L
.03897 .30902 L
.03917 .30902 L
.03939 .30902 L
.03949 .30902 L
.03959 .30902 L
.03969 .30902 L
.03978 .30902 L
.03988 .30902 L
.03998 .30902 L
.04006 .30902 L
.04016 .30902 L
.04026 .30902 L
.04031 .30902 L
.04037 .30902 L
.04057 .30902 L
.04075 .30902 L
.04094 .30902 L
.0413 .30902 L
.04151 .30902 L
.04175 .30902 L
.04217 .30902 L
.04258 .30902 L
.04296 .30902 L
.04374 .30902 L
.04446 .30902 L
.04526 .30902 L
.04611 .30902 L
.04688 .30902 L
.04772 .30902 L
.04861 .30902 L
.04942 .30902 L
.05099 .30902 L
.05186 .30902 L
.05267 .30902 L
.05428 .30902 L
.05576 .30902 L
.05727 .30902 L
.05892 .30902 L
.06048 .30902 L
.06216 .30902 L
.06386 .30902 L
Mistroke
.06547 .30902 L
.06854 .30902 L
.07181 .30902 L
.07496 .30902 L
.0783 .30902 L
.07998 .30902 L
.08071 .30902 L
.08152 .30902 L
.0823 .30902 L
.08267 .30902 L
.08303 .30902 L
.08322 .30902 L
.08343 .30902 L
.08352 .30902 L
.08362 .30902 L
.08371 .30902 L
.08379 .30902 L
.08389 .30902 L
.084 .30902 L
.08409 .30902 L
.08418 .30902 L
.08424 .30902 L
.08429 .30902 L
.08439 .30902 L
.08445 .30902 L
.08451 .30902 L
.08462 .30902 L
.08481 .30902 L
.08499 .30902 L
.0852 .30902 L
.0854 .30902 L
.0858 .30902 L
.08623 .30902 L
.08699 .30902 L
.08771 .30902 L
.08848 .30902 L
.0893 .30902 L
.09078 .30902 L
.09153 .30902 L
.09234 .30902 L
.09381 .30902 L
.09542 .30902 L
.09711 .30902 L
.09869 .30902 L
.10017 .30902 L
.1033 .30902 L
.10663 .30902 L
.10983 .30902 L
.11292 .30902 L
.11448 .30902 L
Mistroke
.11531 .30902 L
.11576 .30902 L
.1162 .30902 L
.11661 .30902 L
.11705 .30902 L
.11725 .30902 L
.11746 .30902 L
.11756 .30902 L
.11765 .30902 L
.11774 .30902 L
.11783 .30902 L
.11792 .30902 L
.11802 .30902 L
.11811 .30902 L
.11821 .30902 L
.11831 .30902 L
.1184 .30902 L
.11848 .30902 L
.11857 .30902 L
.11877 .30902 L
.11898 .30902 L
.11916 .30902 L
.11936 .30902 L
.11975 .30902 L
.12017 .30902 L
.12091 .30902 L
.12133 .30902 L
.12171 .30902 L
.12259 .30902 L
.12343 .30902 L
.12423 .30902 L
.12572 .30902 L
.12733 .30902 L
.12881 .30902 L
.13032 .30902 L
.13198 .30902 L
.13522 .30902 L
.13833 .30901 L
.14165 .30901 L
.14331 .30901 L
.14411 .30901 L
.14484 .30901 L
.14521 .30901 L
.14561 .30901 L
.14598 .30901 L
.14615 .30901 L
.14633 .30901 L
.14643 .30901 L
.14652 .30901 L
.14661 .30901 L
Mistroke
.1467 .30901 L
.1468 .30901 L
.14685 .30901 L
.14691 .30901 L
.147 .30901 L
.1471 .30901 L
.14721 .30901 L
.1473 .30901 L
.14741 .30901 L
.14752 .30901 L
.14771 .30901 L
.14791 .30901 L
.14834 .30901 L
.14874 .30901 L
.1491 .30901 L
.14949 .30901 L
.15037 .30901 L
.15118 .30901 L
.15196 .30901 L
.15269 .30902 L
.15434 .30902 L
.15598 .30902 L
.15747 .30902 L
.16066 .30903 L
.16374 .30904 L
.16701 .30905 L
.16864 .30905 L
.16943 .30905 L
.17016 .30906 L
.17087 .30906 L
.17123 .30906 L
.17162 .30906 L
.17183 .30906 L
.17201 .30906 L
.17212 .30906 L
.17218 .30906 L
.17223 .30906 L
.17233 .30906 L
.17243 .30906 L
.17252 .30906 L
.17262 .30906 L
.17271 .30906 L
.17279 .30906 L
.17289 .30906 L
.173 .30906 L
.17319 .30906 L
.1734 .30906 L
.17362 .30906 L
.17402 .30906 L
.17441 .30906 L
Mistroke
.17477 .30905 L
.17559 .30905 L
.17646 .30905 L
.17722 .30904 L
.17804 .30904 L
.17951 .30902 L
.18122 .309 L
.18283 .30897 L
.18591 .30891 L
.18919 .30883 L
.19082 .30879 L
.19234 .30876 L
.19305 .30875 L
.1938 .30874 L
.1942 .30874 L
.1944 .30874 L
.19462 .30874 L
.19483 .30873 L
.19501 .30873 L
.1951 .30873 L
.1952 .30873 L
.19529 .30873 L
.19538 .30873 L
.19548 .30873 L
.19557 .30873 L
.19566 .30873 L
.19575 .30873 L
.19585 .30873 L
.19596 .30873 L
.19616 .30873 L
.19633 .30874 L
.1965 .30874 L
.19688 .30874 L
.1973 .30875 L
.19768 .30875 L
.19854 .30877 L
.19933 .3088 L
.20006 .30883 L
.20172 .30891 L
.20336 .30904 L
.20485 .30917 L
.20806 .30955 L
.21114 .30994 L
.2127 .31012 L
.21353 .31021 L
.21442 .31028 L
.21486 .31031 L
.21527 .31033 L
.21564 .31035 L
.21586 .31036 L
Mistroke
.21605 .31036 L
.21625 .31037 L
.21634 .31037 L
.21643 .31037 L
.21654 .31037 L
.21663 .31037 L
.21673 .31037 L
.21679 .31037 L
.21684 .31037 L
.21694 .31037 L
.21703 .31037 L
.21711 .31037 L
.2172 .31037 L
.2174 .31037 L
.21758 .31036 L
.21777 .31035 L
.21795 .31035 L
.21835 .31032 L
.21871 .3103 L
.21908 .31027 L
.21987 .31017 L
.22073 .31004 L
.22231 .30969 L
.22399 .30917 L
.22732 .30774 L
.23053 .30612 L
.232 .30541 L
.23284 .30506 L
.23362 .30476 L
.23445 .30451 L
.23521 .30434 L
.23541 .3043 L
.23563 .30427 L
.23584 .30424 L
.23603 .30422 L
.23613 .30422 L
.23625 .30421 L
.23631 .30421 L
.23637 .3042 L
.23643 .3042 L
.23648 .3042 L
.23658 .3042 L
.23663 .3042 L
.23669 .3042 L
.23674 .3042 L
.2368 .3042 L
.2369 .3042 L
.23699 .30421 L
.23709 .30421 L
.23727 .30423 L
Mistroke
.23749 .30425 L
.23768 .30428 L
.2381 .30436 L
.2385 .30446 L
.23921 .30471 L
.23998 .30508 L
.24081 .3056 L
.24156 .30619 L
.24324 .30786 L
.24646 .31224 L
.24955 .31712 L
.25112 .31937 L
.25195 .3204 L
.25284 .32131 L
.25328 .32168 L
.2537 .32198 L
.25407 .32219 L
.25426 .32228 L
.25448 .32236 L
.25468 .32242 L
.25486 .32247 L
.25497 .32248 L
.25506 .3225 L
.25516 .32251 L
.25522 .32251 L
.25527 .32251 L
.25537 .32251 L
.25546 .32251 L
.25556 .3225 L
.25565 .32249 L
.25574 .32247 L
.25582 .32246 L
.25601 .32241 L
.2562 .32234 L
.25638 .32226 L
.25679 .32203 L
.25716 .32174 L
.25751 .32141 L
.2583 .32043 L
.25917 .31899 L
.26075 .31539 L
.26243 .31027 L
.26577 .29752 L
.26745 .29085 L
.26899 .28535 L
.2705 .28113 L
.27126 .27961 L
.27169 .27897 L
.27209 .27852 L
.2723 .27834 L
Mistroke
.27249 .27822 L
.27259 .27817 L
.2727 .27813 L
.27276 .27811 L
.27282 .2781 L
.27288 .27809 L
.27293 .27808 L
.27302 .27808 L
.27311 .27809 L
.27321 .27811 L
.27332 .27813 L
.27343 .27818 L
.27353 .27823 L
.27372 .27837 L
.2739 .27853 L
.2741 .27874 L
.27444 .27923 L
.27481 .2799 L
.27521 .28083 L
.27603 .28331 L
.27678 .28626 L
.27845 .29524 L
.28165 .31932 L
.28472 .34526 L
.28644 .35747 L
.28725 .362 L
.28799 .36526 L
.28837 .36655 L
.28877 .36761 L
.28898 .36804 L
.28917 .36835 L
.28938 .36861 L
.2895 .36871 L
.28955 .36875 L
.28961 .36878 L
.28971 .36882 L
.28981 .36883 L
.2899 .36883 L
.28999 .36881 L
.29009 .36876 L
.29018 .3687 L
.29029 .3686 L
.29039 .36848 L
.29058 .3682 L
.29075 .36788 L
.29114 .36689 L
.29154 .36546 L
.29198 .36347 L
.29278 .35867 L
.29356 .35255 L
Mistroke
.29428 .34572 L
.29745 .3042 L
.30049 .2569 L
.30219 .23378 L
.30299 .22487 L
.30374 .21817 L
.3041 .2155 L
.30451 .21306 L
.30491 .21119 L
.30513 .21041 L
.30534 .20986 L
.30553 .2095 L
.30562 .20937 L
.30572 .20927 L
.30581 .20921 L
.3059 .20919 L
.30599 .2092 L
.30607 .20923 L
.30617 .20931 L
.30627 .20942 L
.30637 .20959 L
.30648 .20981 L
.30666 .21029 L
.30686 .21097 L
.30728 .21294 L
.30768 .21549 L
.30842 .22205 L
.30922 .23165 L
.3101 .24497 L
.31336 .3151 L
.31651 .39254 L
.31734 .41039 L
.31823 .42713 L
.319 .43893 L
.31941 .44401 L
.31985 .44849 L
.32007 .45037 L
.32028 .45188 L
.32049 .45311 L
.32068 .45402 L
.32086 .45468 L
.32095 .45494 L
.32105 .45516 L
.32115 .45533 L
.32121 .45539 L
.32126 .45543 L
.32135 .45547 L
.32145 .45544 L
.32151 .4554 L
.32156 .45535 L
Mistroke
.32166 .4552 L
.32176 .45497 L
.32187 .45465 L
.32208 .45386 L
.32226 .4529 L
.32269 .44983 L
.32315 .44529 L
.3239 .43477 L
.32472 .41953 L
.32619 .38274 L
.32951 .27138 L
.33117 .21353 L
.3327 .16737 L
.33347 .14881 L
.33419 .13487 L
.33458 .12888 L
.33494 .12443 L
.33534 .12072 L
.33555 .11931 L
.33566 .11874 L
.33578 .11823 L
.33588 .11786 L
.33598 .1176 L
.33608 .11744 L
.33618 .11735 L
.33627 .11735 L
.33635 .11741 L
.33644 .11755 L
.33654 .11778 L
.33665 .11812 L
.33676 .11861 L
.33697 .11979 L
.33717 .12132 L
.33736 .12306 L
.33773 .12747 L
.33807 .13253 L
.33883 .14747 L
.33964 .16846 L
.34038 .19201 L
.34205 .25717 L
.34522 .39995 L
.34682 .46366 L
.34751 .48663 L
.34827 .50722 L
.34869 .51639 L
.34907 .52335 L
.34944 .52859 L
.34965 .53088 L
.34984 .53259 L
.35003 .53397 L
Mistroke
.35014 .53453 L
.35025 .53499 L
.35034 .53528 L
.35043 .53546 L
.35053 .53555 L
.35063 .53554 L
.35069 .53547 L
.35075 .53538 L
.35081 .53524 L
.35087 .53505 L
.35098 .53462 L
.3511 .53401 L
.35131 .53247 L
.35151 .53055 L
.35192 .52543 L
.35235 .51784 L
.35314 .49887 L
.35392 .4744 L
.35463 .447 L
.35778 .29179 L
.35939 .20806 L
.36023 .16811 L
.36112 .13122 L
.36192 .10396 L
.36235 .09216 L
.3628 .08174 L
.36322 .07426 L
.3636 .06929 L
.36378 .06754 L
.36388 .06678 L
.36398 .06611 L
.36407 .06563 L
.36417 .06522 L
.36426 .06496 L
.36434 .06481 L
.36444 .06474 L
.3645 .06476 L
.36455 .06481 L
.36465 .06501 L
.36474 .06531 L
.36485 .0658 L
.36495 .06638 L
.36518 .06817 L
.36536 .0701 L
.36556 .07272 L
.36597 .07954 L
.36634 .08753 L
.36674 .09791 L
.36745 .12111 L
.36916 .19565 L
Mistroke
.37077 .28296 L
.37385 .44901 L
.37467 .48433 L
.37543 .51163 L
.37624 .53302 L
.37666 .54118 L
.3769 .54474 L
.37712 .54735 L
.37732 .54916 L
.3775 .55034 L
.3776 .55081 L
.37766 .55101 L
.37771 .55116 L
.3778 .55133 L
.37791 .55139 L
.37799 .55132 L
.37809 .55114 L
.37817 .55086 L
.37825 .55051 L
.37835 .54999 L
.37845 .54929 L
.37864 .54765 L
.37886 .54514 L
.37906 .54233 L
.3795 .53417 L
.3803 .51335 L
.38111 .48506 L
.38185 .45351 L
.38352 .36831 L
.38516 .27691 L
.38669 .19727 L
.38816 .13603 L
.38859 .12235 L
.38899 .11128 L
.38938 .1024 L
.38974 .09578 L
.39011 .0908 L
.39031 .08887 L
.39041 .08808 L
.39052 .08736 L
.39063 .08681 L
.39073 .08644 L
.39078 .0863 L
.39083 .0862 L
.39089 .08613 L
.39095 .0861 L
.39105 .08616 L
.39114 .08632 L
.39124 .08663 L
.39134 .08709 L
Mistroke
.39152 .08819 L
.39171 .08981 L
.39205 .09389 L
.39245 .10063 L
.39282 .10852 L
.39361 .13067 L
.39435 .15687 L
.39601 .23129 L
.39764 .31364 L
.39916 .38798 L
.40062 .44639 L
.40144 .47103 L
.40183 .48037 L
.40219 .48737 L
.40257 .49315 L
.40278 .49562 L
.40297 .49747 L
.40306 .49814 L
.40316 .49876 L
.40324 .49921 L
.40332 .4996 L
.40342 .49992 L
.40351 .50013 L
.40361 .50025 L
.40371 .50025 L
.40381 .50013 L
.40386 .50001 L
.40392 .49986 L
.40402 .49949 L
.40411 .49903 L
.40433 .49761 L
.40456 .49547 L
.40498 .49001 L
.40537 .48327 L
.40615 .465 L
.40688 .44294 L
.40854 .37949 L
.41166 .24675 L
.41248 .21741 L
.41336 .19092 L
.41377 .181 L
.4142 .17212 L
.41461 .16545 L
.41478 .16304 L
.41498 .16076 L
.41516 .15902 L
.41535 .15751 L
.41545 .15683 L
.41555 .15631 L
.41564 .1559 L
Mistroke
.41573 .15557 L
.41584 .15531 L
.41593 .15516 L
.41603 .15511 L
.41609 .15513 L
.41615 .15519 L
.41625 .15536 L
.41634 .1556 L
.41644 .15598 L
.41654 .15644 L
.41672 .15751 L
.41691 .15898 L
.41724 .16246 L
.41765 .16799 L
.41801 .17421 L
.41956 .21189 L
.42123 .2665 L
.4228 .32157 L
.42363 .34894 L
.42453 .37506 L
.42539 .39595 L
.42617 .41053 L
.42655 .41588 L
.42695 .4204 L
.42714 .42202 L
.42734 .42342 L
.42751 .42435 L
.4277 .4251 L
.4278 .42538 L
.42789 .42557 L
.42799 .4257 L
.42804 .42573 L
.4281 .42575 L
.4282 .4257 L
.42826 .42564 L
.42831 .42556 L
.42841 .42535 L
.42851 .42505 L
.4287 .4243 L
.42887 .42336 L
.42926 .42041 L
.42968 .41593 L
.43006 .41078 L
.43093 .39583 L
.43246 .36079 L
.43413 .3167 L
.43568 .27753 L
.43651 .25981 L
.4374 .24425 L
.43781 .2385 L
Mistroke
.43824 .23352 L
.43862 .23018 L
.43883 .22864 L
.43902 .2275 L
.43922 .22657 L
.4394 .22592 L
.43951 .22565 L
.4396 .22546 L
.4397 .22532 L
.43975 .22527 L
.43981 .22523 L
.43991 .22522 L
.43999 .22526 L
.4401 .22537 L
.44019 .22552 L
.44028 .22571 L
.44036 .22593 L
.44055 .22658 L
.44076 .22756 L
.44096 .2287 L
.4414 .23202 L
.4422 .24054 L
.44292 .25068 L
.44369 .26331 L
.44674 .32047 L
.44831 .3451 L
.44876 .3507 L
.44919 .35526 L
.44957 .35869 L
.44999 .36173 L
.45018 .36287 L
.45039 .3639 L
.45057 .36464 L
.45076 .36528 L
.45086 .36554 L
.45097 .36577 L
.45103 .36588 L
.45109 .36596 L
.45114 .36603 L
.45119 .36608 L
.45129 .36614 L
.45139 .36617 L
.45149 .36615 L
.45159 .36609 L
.45168 .36599 L
.45176 .36587 L
.45195 .3655 L
.45212 .36502 L
.45229 .36444 L
.45266 .36277 L
Mistroke
.45306 .36035 L
.4539 .35363 L
.45465 .34587 L
.45633 .32493 L
.45801 .30321 L
.45875 .29465 L
.45956 .2865 L
.46034 .28014 L
.46106 .27577 L
.46147 .27405 L
.46183 .27291 L
.46204 .27246 L
.46214 .27227 L
.46226 .27211 L
.46235 .272 L
.46241 .27196 L
.46246 .27192 L
.46256 .27188 L
.46266 .27186 L
.46271 .27186 L
.46276 .27188 L
.46286 .27192 L
.46296 .272 L
.46302 .27205 L
.46308 .27212 L
.46327 .2724 L
.46347 .27281 L
.46389 .27403 L
.46435 .27589 L
.46519 .28045 L
.46596 .28586 L
.46909 .31186 L
.4699 .31802 L
.47079 .32369 L
.4712 .32586 L
.47163 .32783 L
.47203 .32934 L
.47241 .33045 L
.47277 .33126 L
.47296 .33157 L
.47316 .33183 L
.47326 .33193 L
.47336 .332 L
.47341 .33203 L
.47347 .33206 L
.47358 .3321 L
.47368 .33211 L
.47378 .33211 L
.47387 .33208 L
.47397 .33204 L
Mistroke
.47407 .33198 L
.47416 .33191 L
.47433 .33173 L
.47452 .33147 L
.47473 .33112 L
.47509 .33031 L
.47543 .32937 L
.47628 .32631 L
.47708 .32271 L
.47858 .31493 L
.48006 .3072 L
.4809 .30333 L
.48168 .30028 L
.48245 .29792 L
.48288 .29691 L
.48328 .2962 L
.48348 .29591 L
.4837 .29567 L
.48381 .29556 L
.48393 .29546 L
.48405 .29539 L
.48415 .29533 L
.48425 .2953 L
.48435 .29527 L
.48446 .29526 L
.48452 .29525 L
.48457 .29526 L
.48467 .29527 L
.48477 .29529 L
.48487 .29533 L
.48497 .29538 L
.48516 .29551 L
.48534 .29566 L
.48575 .29614 L
.48615 .29678 L
.48658 .29762 L
.48806 .30151 L
.48965 .30655 L
.49138 .31172 L
.49218 .31366 L
.49262 .31455 L
.49304 .31526 L
.49342 .31581 L
.49377 .31621 L
.49416 .31655 L
.49436 .31669 L
.49446 .31674 L
.49457 .31679 L
.49468 .31683 L
.49478 .31686 L
Mistroke
.49487 .31688 L
.49497 .31689 L
.49506 .3169 L
.49515 .3169 L
.49524 .31689 L
.49534 .31688 L
.49544 .31686 L
.49556 .31683 L
.49577 .31675 L
.49597 .31665 L
.49616 .31653 L
.49687 .31588 L
.49763 .3149 L
.49923 .3122 L
.50097 .30902 L
.50178 .30768 L
.50264 .30648 L
.50338 .30568 L
.5038 .30532 L
.50419 .30506 L
.50459 .30486 L
.50481 .30478 L
.50492 .30475 L
.50502 .30472 L
.50512 .3047 L
.50521 .30469 L
.50531 .30468 L
.50541 .30467 L
.50551 .30467 L
.50561 .30467 L
.50566 .30467 L
.50572 .30468 L
.50582 .30469 L
.50592 .3047 L
.50601 .30472 L
.50622 .30476 L
.50641 .30482 L
.5066 .30489 L
.50731 .30527 L
.50807 .30583 L
.50888 .30656 L
.51035 .30805 L
.51194 .30959 L
.51277 .31025 L
.51323 .31056 L
.51367 .3108 L
.51408 .31099 L
.5143 .31108 L
.51453 .31115 L
.51473 .31121 L
Mistroke
.51494 .31125 L
.51514 .31129 L
.51532 .31131 L
.51542 .31132 L
.51552 .31133 L
.51562 .31133 L
.51571 .31133 L
.51579 .31133 L
.51588 .31133 L
.51598 .31133 L
.51606 .31132 L
.51617 .31131 L
.51626 .3113 L
.51645 .31128 L
.51664 .31125 L
.51686 .3112 L
.51728 .31108 L
.51768 .31095 L
.51844 .31063 L
.52012 .30975 L
.52159 .30896 L
.52243 .30857 L
.52321 .30827 L
.52398 .30804 L
.52442 .30795 L
.52481 .30789 L
.52503 .30786 L
.52523 .30785 L
.52533 .30784 L
.52544 .30783 L
.5255 .30783 L
.52556 .30783 L
.52562 .30783 L
.52568 .30783 L
.52578 .30783 L
.52587 .30783 L
.52597 .30783 L
.52603 .30783 L
.52608 .30783 L
.52618 .30783 L
.5263 .30784 L
.5265 .30785 L
.52669 .30787 L
.52689 .30789 L
.52726 .30794 L
.52809 .3081 L
.52978 .30855 L
.53137 .30899 L
.5322 .3092 L
.53309 .30938 L
Mistroke
.53354 .30945 L
.53396 .30951 L
.53434 .30955 L
.53454 .30957 L
.53475 .30958 L
.53494 .30959 L
.53514 .3096 L
.53525 .3096 L
.53535 .30961 L
.53545 .30961 L
.53555 .30961 L
.53564 .30961 L
.53573 .30961 L
.53581 .30961 L
.5359 .30961 L
.536 .30961 L
.5361 .30961 L
.53628 .3096 L
.53648 .30959 L
.53668 .30958 L
.53705 .30956 L
.53789 .30948 L
.53959 .30925 L
.54119 .30903 L
.54203 .30893 L
.54292 .30884 L
.54331 .30881 L
.54372 .30878 L
.54396 .30877 L
.54417 .30876 L
.54439 .30875 L
.54459 .30874 L
.54478 .30874 L
.54497 .30873 L
.54508 .30873 L
.54519 .30873 L
.54528 .30873 L
.54538 .30873 L
.54548 .30873 L
.54557 .30873 L
.54568 .30873 L
.54578 .30873 L
.54587 .30873 L
.54595 .30873 L
.54613 .30874 L
.54652 .30875 L
.54693 .30876 L
.54767 .3088 L
.54934 .30891 L
.55092 .30902 L
Mistroke
.55162 .30906 L
.55238 .30909 L
.55279 .30911 L
.55317 .30912 L
.55357 .30914 L
.55393 .30914 L
.55414 .30915 L
.55436 .30915 L
.55446 .30915 L
.55456 .30915 L
.55465 .30915 L
.55474 .30915 L
.5548 .30915 L
.55486 .30915 L
.55496 .30915 L
.55502 .30915 L
.55507 .30915 L
.55513 .30915 L
.55519 .30915 L
.55529 .30915 L
.55539 .30915 L
.5555 .30915 L
.55561 .30915 L
.55601 .30914 L
.55638 .30914 L
.55722 .30912 L
.55891 .30907 L
.56042 .30902 L
.56121 .309 L
.56205 .30898 L
.56247 .30897 L
.56294 .30896 L
.56314 .30896 L
.56336 .30896 L
.56357 .30896 L
.56376 .30896 L
.56397 .30896 L
.56408 .30896 L
.56413 .30896 L
.56419 .30896 L
.56425 .30896 L
.5643 .30896 L
.56441 .30896 L
.5645 .30896 L
.5646 .30896 L
.5647 .30896 L
.56479 .30896 L
.56497 .30896 L
.56518 .30896 L
.56538 .30896 L
Mistroke
.56576 .30896 L
.56617 .30897 L
.56691 .30897 L
.56858 .309 L
.57016 .30902 L
.57086 .30903 L
.57161 .30904 L
.57201 .30904 L
.57237 .30904 L
.57276 .30904 L
.57297 .30904 L
.57317 .30904 L
.57327 .30904 L
.57338 .30904 L
.57348 .30904 L
.57358 .30904 L
.57364 .30904 L
.57369 .30904 L
.57376 .30904 L
.57381 .30904 L
.57392 .30904 L
.57398 .30904 L
.57403 .30904 L
.57422 .30904 L
.57432 .30904 L
.57442 .30904 L
.57484 .30904 L
.57522 .30904 L
.57563 .30904 L
.57646 .30903 L
.57795 .30902 L
.57882 .30902 L
.57965 .30901 L
.58046 .30901 L
.58081 .30901 L
.5812 .30901 L
.58158 .30901 L
.58193 .30901 L
.58212 .30901 L
.5823 .30901 L
.5824 .30901 L
.58251 .30901 L
.58261 .30901 L
.5827 .30901 L
.5828 .30901 L
.58286 .30901 L
.58291 .30901 L
.58301 .30901 L
.58311 .30901 L
.58321 .30901 L
Mistroke
.58329 .30901 L
.58349 .30901 L
.5837 .30901 L
.5839 .30901 L
.58433 .30901 L
.58513 .30901 L
.58586 .30901 L
.58753 .30902 L
.58903 .30902 L
.58944 .30902 L
.58988 .30902 L
.5903 .30902 L
.59068 .30902 L
.59106 .30902 L
.59126 .30902 L
.59145 .30902 L
.59156 .30902 L
.59166 .30902 L
.59171 .30902 L
.59177 .30902 L
.59183 .30902 L
.59189 .30902 L
.59199 .30902 L
.59208 .30902 L
.59213 .30902 L
.59219 .30902 L
.59229 .30902 L
.59241 .30902 L
.59252 .30902 L
.59272 .30902 L
.59317 .30902 L
.59356 .30902 L
.59399 .30902 L
.59556 .30902 L
.59639 .30902 L
.59728 .30902 L
.59814 .30902 L
.59893 .30902 L
.59931 .30902 L
.5995 .30902 L
.59971 .30902 L
.5999 .30902 L
.6001 .30901 L
.60019 .30901 L
.60029 .30901 L
.60038 .30901 L
.60046 .30901 L
.60051 .30901 L
.60057 .30901 L
.60066 .30901 L
Mistroke
.60072 .30901 L
.60078 .30901 L
.60088 .30901 L
.60098 .30901 L
.60107 .30901 L
.60116 .30901 L
.60127 .30901 L
.60151 .30901 L
.60173 .30902 L
.60215 .30902 L
.60293 .30902 L
.60377 .30902 L
.60532 .30902 L
.60615 .30902 L
.60704 .30902 L
.60745 .30902 L
.60789 .30902 L
.60826 .30902 L
.60847 .30902 L
.60866 .30902 L
.60885 .30902 L
.60905 .30902 L
.60916 .30902 L
.60926 .30902 L
.60935 .30902 L
.60945 .30902 L
.60954 .30902 L
.60964 .30902 L
.60972 .30902 L
.6098 .30902 L
.6099 .30902 L
.61 .30902 L
.61019 .30902 L
.6104 .30902 L
.61062 .30902 L
.61102 .30902 L
.61177 .30902 L
.61346 .30902 L
.61503 .30902 L
.61546 .30902 L
.61592 .30902 L
.61635 .30902 L
.61675 .30902 L
.61716 .30902 L
.61737 .30902 L
.6176 .30902 L
.6177 .30902 L
.6178 .30902 L
.61789 .30902 L
.61799 .30902 L
Mistroke
.61804 .30902 L
.61809 .30902 L
.61815 .30902 L
.61821 .30902 L
.61831 .30902 L
.61841 .30902 L
.6185 .30902 L
.6186 .30902 L
.61869 .30902 L
.61878 .30902 L
.61899 .30902 L
.61919 .30902 L
.61954 .30902 L
.61992 .30902 L
.62151 .30902 L
.62324 .30902 L
.62404 .30902 L
.62448 .30902 L
.6249 .30902 L
.62528 .30902 L
.62563 .30902 L
.62581 .30902 L
.62601 .30902 L
.62622 .30902 L
.62633 .30902 L
.62643 .30902 L
.62653 .30902 L
.62664 .30902 L
.62674 .30902 L
.6268 .30902 L
.62686 .30902 L
.62696 .30902 L
.62705 .30902 L
.6271 .30902 L
.62716 .30902 L
.62726 .30902 L
.62744 .30902 L
.62764 .30902 L
.628 .30902 L
.62846 .30902 L
.62889 .30902 L
.62969 .30902 L
.63116 .30902 L
.632 .30902 L
.63278 .30902 L
.63355 .30902 L
.63399 .30902 L
.63438 .30902 L
.6346 .30902 L
.6348 .30902 L
Mistroke
.6349 .30902 L
.63502 .30902 L
.63507 .30902 L
.63514 .30902 L
.6352 .30902 L
.63525 .30902 L
.63535 .30902 L
.63544 .30902 L
.63554 .30902 L
.6356 .30902 L
.63565 .30902 L
.63575 .30902 L
.63587 .30902 L
.63607 .30902 L
.63646 .30902 L
.63683 .30902 L
.63767 .30902 L
.63936 .30902 L
.64019 .30902 L
.64099 .30902 L
.6417 .30902 L
.6421 .30902 L
.64247 .30902 L
.64267 .30902 L
.64288 .30902 L
.64299 .30902 L
.64311 .30902 L
.64322 .30902 L
.64332 .30902 L
.64343 .30902 L
.64352 .30902 L
.64363 .30902 L
.64368 .30902 L
.64374 .30902 L
.64383 .30902 L
.64393 .30902 L
.64403 .30902 L
.64412 .30902 L
.64431 .30902 L
.6445 .30902 L
.64484 .30902 L
.64562 .30902 L
.64723 .30902 L
.64868 .30902 L
.64949 .30902 L
.64987 .30902 L
.65026 .30902 L
.65068 .30902 L
.65107 .30902 L
.65128 .30902 L
Mistroke
.65149 .30902 L
.6516 .30902 L
.65171 .30902 L
.65176 .30902 L
.65183 .30902 L
.65189 .30902 L
.65194 .30902 L
.65204 .30902 L
.65214 .30902 L
.65222 .30902 L
.65231 .30902 L
.65241 .30902 L
.65252 .30902 L
.65271 .30902 L
.65309 .30902 L
.65344 .30902 L
.65509 .30902 L
.6559 .30902 L
.65676 .30902 L
.65756 .30902 L
.65794 .30902 L
.6583 .30902 L
.65864 .30902 L
.65901 .30902 L
.65921 .30902 L
.6594 .30902 L
.65958 .30902 L
.65968 .30902 L
.65977 .30902 L
.65987 .30902 L
.65992 .30902 L
.65998 .30902 L
.66008 .30902 L
.66017 .30902 L
.66022 .30902 L
.66028 .30902 L
.66038 .30902 L
.66043 .30902 L
.66048 .30902 L
.6606 .30902 L
.66078 .30902 L
.66098 .30902 L
.66139 .30902 L
.6622 .30902 L
.66294 .30902 L
.66461 .30902 L
.66535 .30902 L
.66613 .30902 L
.66659 .30902 L
.667 .30902 L
Mistroke
.66719 .30902 L
.66741 .30902 L
.66761 .30902 L
.6678 .30902 L
.6679 .30902 L
.66799 .30902 L
.66808 .30902 L
.66817 .30902 L
.66827 .30902 L
.66833 .30902 L
.66838 .30902 L
.66848 .30902 L
.66858 .30902 L
.66876 .30902 L
.66893 .30902 L
.6693 .30902 L
.66969 .30902 L
.67011 .30902 L
.67096 .30902 L
.67266 .30902 L
.67347 .30902 L
.67421 .30902 L
.67459 .30902 L
.67498 .30902 L
.67519 .30902 L
.67538 .30902 L
.67559 .30902 L
.67571 .30902 L
.67582 .30902 L
.67592 .30902 L
.67601 .30902 L
.67611 .30902 L
.67619 .30902 L
.67629 .30902 L
.67635 .30902 L
.6764 .30902 L
.6765 .30902 L
.6766 .30902 L
.67678 .30902 L
.67695 .30902 L
.67734 .30902 L
.67774 .30902 L
.67818 .30902 L
.67898 .30902 L
.68046 .30902 L
.68128 .30902 L
.68205 .30902 L
.68244 .30902 L
.68285 .30902 L
.68308 .30902 L
Mistroke
.68331 .30902 L
.68352 .30902 L
.68363 .30902 L
.68374 .30902 L
.68384 .30902 L
.68389 .30902 L
.68395 .30902 L
.68405 .30902 L
.68414 .30902 L
.6842 .30902 L
.68425 .30902 L
.68435 .30902 L
.68441 .30902 L
.68446 .30902 L
.68458 .30902 L
.68478 .30902 L
.68497 .30902 L
.68538 .30902 L
.68615 .30902 L
.68687 .30902 L
.68835 .30902 L
.68919 .30902 L
.6896 .30902 L
.68997 .30902 L
.69034 .30902 L
.69074 .30902 L
.69096 .30902 L
.69117 .30902 L
.69137 .30902 L
.69146 .30902 L
.69157 .30902 L
.69168 .30902 L
.69173 .30902 L
.69179 .30902 L
.6919 .30902 L
.69199 .30902 L
.69205 .30902 L
.69211 .30902 L
.69221 .30902 L
.69227 .30902 L
.69232 .30902 L
.69245 .30902 L
.69264 .30902 L
.69284 .30902 L
.69326 .30902 L
.69408 .30902 L
.69483 .30902 L
.6957 .30902 L
.69651 .30902 L
.69723 .30902 L
Mistroke
.69762 .30902 L
.69804 .30902 L
.69825 .30902 L
.69845 .30902 L
.69865 .30902 L
.69884 .30902 L
.69904 .30902 L
.69916 .30902 L
.69926 .30902 L
.69937 .30902 L
.69947 .30902 L
.69953 .30902 L
.69958 .30902 L
.69964 .30902 L
.6997 .30902 L
.6998 .30902 L
.6999 .30902 L
.7 .30902 L
.7001 .30902 L
.70027 .30902 L
.70046 .30902 L
.70088 .30902 L
.70127 .30902 L
.70274 .30902 L
.70355 .30902 L
.70441 .30902 L
.70515 .30902 L
.70557 .30902 L
.70596 .30902 L
.70615 .30902 L
.70636 .30902 L
.70654 .30902 L
.70674 .30902 L
.70691 .30902 L
.70701 .30902 L
.70711 .30902 L
.70719 .30902 L
.70727 .30902 L
.70736 .30902 L
.70745 .30902 L
.70755 .30902 L
.70764 .30902 L
.70775 .30902 L
.70785 .30902 L
.70802 .30902 L
.70822 .30902 L
.70865 .30902 L
.70905 .30902 L
.71069 .30902 L
.71149 .30902 L
Mistroke
.71222 .30902 L
.71258 .30902 L
.71297 .30902 L
.71334 .30902 L
.71368 .30902 L
.71387 .30902 L
.71408 .30902 L
.7143 .30902 L
.71439 .30902 L
.7145 .30902 L
.7146 .30902 L
.71469 .30902 L
.71479 .30902 L
.71489 .30902 L
.71499 .30902 L
.71508 .30902 L
.71517 .30902 L
.71526 .30902 L
.71536 .30902 L
.71545 .30902 L
.71565 .30902 L
.71601 .30902 L
.71644 .30902 L
.71685 .30902 L
.71854 .30902 L
.71931 .30902 L
.72013 .30902 L
.72052 .30902 L
.7209 .30902 L
.72124 .30902 L
.7216 .30902 L
.72179 .30902 L
.7219 .30902 L
.72199 .30902 L
.72209 .30902 L
.72219 .30902 L
.72228 .30902 L
.72236 .30902 L
.72246 .30902 L
.72256 .30902 L
.72266 .30902 L
.72272 .30902 L
.72277 .30902 L
.72287 .30902 L
.72298 .30902 L
.7232 .30902 L
.72342 .30902 L
.72362 .30902 L
.72408 .30902 L
.72489 .30902 L
Mistroke
.72656 .30902 L
.72729 .30902 L
.72768 .30902 L
.7281 .30902 L
.7285 .30902 L
.72887 .30902 L
.72905 .30902 L
.72924 .30902 L
.72933 .30902 L
.72943 .30902 L
.72951 .30902 L
.7296 .30902 L
.72965 .30902 L
.7297 .30902 L
.7298 .30902 L
.72986 .30902 L
.72992 .30902 L
.72997 .30902 L
.73003 .30902 L
.73013 .30902 L
.73018 .30902 L
.73023 .30902 L
.73043 .30902 L
.7306 .30902 L
.7308 .30902 L
.73118 .30902 L
.732 .30902 L
.73274 .30902 L
.73361 .30902 L
.73441 .30902 L
.73515 .30902 L
.73556 .30902 L
.73593 .30902 L
.73613 .30902 L
.73635 .30902 L
.73658 .30902 L
.73668 .30902 L
.73679 .30902 L
.73689 .30902 L
.73699 .30902 L
.73708 .30902 L
.73717 .30902 L
.73728 .30902 L
.73738 .30902 L
.73743 .30902 L
.73748 .30902 L
.73754 .30902 L
.7376 .30902 L
.73769 .30902 L
.73779 .30902 L
Mistroke
.73797 .30902 L
.73819 .30902 L
.73838 .30902 L
.73921 .30902 L
.7407 .30902 L
.74144 .30902 L
.74224 .30902 L
.74265 .30902 L
.7431 .30902 L
.7433 .30902 L
.74352 .30902 L
.74372 .30902 L
.7439 .30902 L
.74411 .30902 L
.74422 .30902 L
.74432 .30902 L
.74442 .30902 L
.74451 .30902 L
.74461 .30902 L
.74471 .30902 L
.74482 .30902 L
.74488 .30902 L
.74493 .30902 L
.74514 .30902 L
.74525 .30902 L
.74537 .30902 L
.7456 .30902 L
.74644 .30902 L
.74721 .30902 L
.74799 .30902 L
.74884 .30902 L
.74963 .30902 L
.75001 .30902 L
.75036 .30902 L
.75071 .30902 L
.75088 .30902 L
.75107 .30902 L
.75118 .30902 L
.75128 .30902 L
.75137 .30902 L
.75147 .30902 L
.75157 .30902 L
.75165 .30902 L
.75174 .30902 L
.75184 .30902 L
.75194 .30902 L
.75204 .30902 L
.75215 .30902 L
.7522 .30902 L
.75226 .30902 L
Mistroke
.75246 .30902 L
.75265 .30902 L
.75301 .30902 L
.75339 .30902 L
.75497 .30902 L
.7558 .30902 L
.75626 .30902 L
.75669 .30902 L
.7571 .30902 L
.75755 .30902 L
.75775 .30902 L
.75796 .30902 L
.75815 .30902 L
.75833 .30902 L
.75851 .30902 L
.75861 .30902 L
.75871 .30902 L
.7588 .30902 L
.75888 .30902 L
.75897 .30902 L
.75906 .30902 L
.75917 .30902 L
.75922 .30902 L
.75928 .30902 L
.75938 .30902 L
.75948 .30902 L
.75966 .30902 L
.75986 .30902 L
.76028 .30902 L
.76068 .30902 L
.76143 .30902 L
.76224 .30902 L
.76311 .30902 L
.76386 .30902 L
.7643 .30902 L
.7647 .30902 L
.76488 .30902 L
.76507 .30902 L
.76524 .30902 L
.76541 .30902 L
.7656 .30902 L
.76569 .30902 L
.76578 .30902 L
.76584 .30902 L
.76589 .30902 L
.76599 .30902 L
.76608 .30902 L
.76618 .30902 L
.76628 .30902 L
.76638 .30902 L
Mistroke
.76648 .30902 L
.76658 .30902 L
.76675 .30902 L
.76694 .30902 L
.76736 .30902 L
.76775 .30902 L
.76922 .30902 L
.76997 .30902 L
.77077 .30902 L
.77118 .30902 L
.77164 .30902 L
.77184 .30902 L
.77205 .30902 L
.77223 .30902 L
.77244 .30902 L
.77264 .30902 L
.77276 .30902 L
.77286 .30902 L
.77296 .30902 L
.77305 .30902 L
.77315 .30902 L
.77325 .30902 L
.77331 .30902 L
.77336 .30902 L
.77342 .30902 L
.77347 .30902 L
.77357 .30902 L
.77368 .30902 L
.77392 .30902 L
.77414 .30902 L
.77452 .30902 L
.77493 .30902 L
.77576 .30902 L
.77663 .30902 L
.77745 .30902 L
.77819 .30902 L
.77861 .30902 L
.779 .30902 L
.77919 .30902 L
.77941 .30902 L
.77961 .30902 L
.7797 .30902 L
.77979 .30902 L
.77988 .30902 L
.77996 .30902 L
.78005 .30902 L
.78014 .30902 L
.78023 .30902 L
.78033 .30902 L
.78042 .30902 L
Mistroke
.78051 .30902 L
.7806 .30902 L
.7807 .30902 L
.78088 .30902 L
.78109 .30902 L
.78129 .30902 L
.78212 .30902 L
.78377 .30902 L
.78457 .30902 L
.7853 .30902 L
.78567 .30902 L
.78586 .30902 L
.78607 .30902 L
.78624 .30902 L
.78644 .30902 L
.78662 .30902 L
.78679 .30902 L
.78688 .30902 L
.78694 .30902 L
.78699 .30902 L
.78708 .30902 L
.78718 .30902 L
.78727 .30902 L
.78736 .30902 L
.78745 .30902 L
.78755 .30902 L
.78765 .30902 L
.78776 .30902 L
.78798 .30902 L
.78837 .30902 L
.78919 .30902 L
.78994 .30902 L
.79082 .30902 L
.79162 .30902 L
.79237 .30902 L
.79275 .30902 L
.79296 .30902 L
.79316 .30902 L
.79338 .30902 L
.79358 .30902 L
.79369 .30902 L
.79379 .30902 L
.79385 .30902 L
.7939 .30902 L
.79397 .30902 L
.79402 .30902 L
.79412 .30902 L
.79423 .30902 L
.79431 .30902 L
.79441 .30902 L
Mistroke
.79452 .30902 L
.79463 .30902 L
.79483 .30902 L
.79526 .30902 L
.79565 .30902 L
.79654 .30902 L
.79737 .30902 L
.79815 .30902 L
.79888 .30902 L
.79928 .30902 L
.79965 .30902 L
.79984 .30902 L
.80004 .30902 L
.80026 .30902 L
.80036 .30902 L
.80046 .30902 L
.80057 .30902 L
.80063 .30902 L
.80069 .30902 L
.80079 .30902 L
.80085 .30902 L
.80091 .30902 L
.80101 .30902 L
.8011 .30902 L
.80115 .30902 L
.80121 .30902 L
.80131 .30902 L
.8015 .30902 L
.8017 .30902 L
.80206 .30902 L
.80289 .30902 L
.8037 .30902 L
.80458 .30902 L
.80498 .30902 L
.80541 .30902 L
.80578 .30902 L
.80618 .30902 L
.80642 .30902 L
.80664 .30902 L
.80685 .30902 L
.80696 .30902 L
.80707 .30902 L
.80717 .30902 L
.80727 .30902 L
.80736 .30902 L
.80745 .30902 L
.80756 .30902 L
.80766 .30902 L
.80771 .30902 L
.80776 .30902 L
Mistroke
.80782 .30902 L
.80788 .30902 L
.80797 .30902 L
.80807 .30902 L
.80825 .30902 L
.80847 .30902 L
.80866 .30902 L
.80949 .30902 L
.81097 .30902 L
.81172 .30902 L
.81251 .30902 L
.81292 .30902 L
.81314 .30902 L
.81337 .30902 L
.81359 .30902 L
.81378 .30902 L
.81397 .30902 L
.81407 .30902 L
.81417 .30902 L
.81428 .30902 L
.81438 .30902 L
.81443 .30902 L
.81448 .30902 L
.81454 .30902 L
.8146 .30902 L
.8147 .30902 L
.81479 .30902 L
.8149 .30902 L
.815 .30902 L
.81536 .30902 L
.81575 .30902 L
.81743 .30902 L
.81824 .30902 L
.81901 .30902 L
.81944 .30902 L
.81966 .30902 L
.81989 .30902 L
.82009 .30902 L
.82031 .30902 L
.82051 .30902 L
.8206 .30902 L
.8207 .30902 L
.8208 .30902 L
.82085 .30902 L
.82091 .30902 L
.821 .30902 L
.8211 .30902 L
.82115 .30902 L
.82122 .30902 L
.82127 .30902 L
Mistroke
.82133 .30902 L
.82143 .30902 L
.82154 .30902 L
.82175 .30902 L
.82195 .30902 L
.82233 .30902 L
.82382 .30902 L
.82453 .30902 L
.8253 .30902 L
.82573 .30902 L
.82613 .30902 L
.82633 .30902 L
.82654 .30902 L
.82673 .30902 L
.82692 .30902 L
.82711 .30902 L
.82721 .30902 L
.82732 .30902 L
.82743 .30902 L
.82748 .30902 L
.82754 .30902 L
.82765 .30902 L
.82775 .30902 L
.82785 .30902 L
.82794 .30902 L
.82803 .30902 L
.82812 .30902 L
.82832 .30902 L
.82851 .30902 L
.82891 .30902 L
.82934 .30902 L
.83021 .30902 L
.83107 .30902 L
.8319 .30902 L
.83225 .30902 L
.83263 .30902 L
.83285 .30902 L
.83305 .30902 L
.83324 .30902 L
.83344 .30902 L
.83364 .30902 L
.83374 .30902 L
.83384 .30902 L
.83394 .30902 L
.83403 .30902 L
.83413 .30902 L
.83421 .30902 L
.83431 .30902 L
.83436 .30902 L
.83442 .30902 L
Mistroke
.83452 .30902 L
.83461 .30902 L
.83472 .30902 L
.83482 .30902 L
.83505 .30902 L
.8354 .30902 L
.83578 .30902 L
.83656 .30902 L
.83743 .30902 L
.83826 .30902 L
.83901 .30902 L
.83943 .30902 L
.83961 .30902 L
.83981 .30902 L
.84001 .30902 L
.84019 .30902 L
.84028 .30902 L
.84037 .30902 L
.84046 .30902 L
.84054 .30902 L
.84065 .30902 L
.84074 .30902 L
.84084 .30902 L
.8409 .30902 L
.84095 .30902 L
.84104 .30902 L
.84114 .30902 L
.84124 .30902 L
.84134 .30902 L
.84155 .30902 L
.84175 .30902 L
.84212 .30902 L
.84295 .30902 L
.84442 .30902 L
.84482 .30902 L
.84525 .30902 L
.84563 .30902 L
.84603 .30902 L
.84625 .30902 L
.84646 .30902 L
.84666 .30902 L
.84676 .30902 L
.84686 .30902 L
.84697 .30902 L
.84707 .30902 L
.84716 .30902 L
.84726 .30902 L
.84735 .30902 L
.84744 .30902 L
.84753 .30902 L
Mistroke
.84763 .30902 L
.84774 .30902 L
.84784 .30902 L
.84808 .30902 L
.84851 .30902 L
.84931 .30902 L
.8501 .30902 L
.85094 .30902 L
.85133 .30902 L
.85173 .30902 L
.85212 .30902 L
.85246 .30902 L
.85283 .30902 L
.85303 .30902 L
.85312 .30902 L
.85321 .30902 L
.8533 .30902 L
.85339 .30902 L
.85347 .30902 L
.85355 .30902 L
.85364 .30902 L
.85372 .30902 L
.85382 .30902 L
.85391 .30902 L
.85401 .30902 L
.8541 .30902 L
.85421 .30902 L
.8543 .30902 L
.85467 .30902 L
.85507 .30902 L
.85549 .30902 L
.85707 .30902 L
.8575 .30902 L
.85796 .30902 L
.85839 .30902 L
.85879 .30902 L
.8592 .30902 L
.85941 .30902 L
.85952 .30902 L
.85964 .30902 L
.85975 .30902 L
.85984 .30902 L
.85993 .30902 L
.86003 .30902 L
.86013 .30902 L
.86023 .30902 L
.86029 .30902 L
.86034 .30902 L
.8604 .30902 L
.86045 .30902 L
Mistroke
.86063 .30902 L
.86073 .30902 L
.86083 .30902 L
.86118 .30902 L
.86196 .30902 L
.86283 .30902 L
.86366 .30902 L
.8644 .30902 L
.86482 .30902 L
.86521 .30902 L
.86538 .30902 L
.86558 .30902 L
.86574 .30902 L
.86592 .30902 L
.86603 .30902 L
.86613 .30902 L
.86623 .30902 L
.86629 .30902 L
.86634 .30902 L
.86643 .30902 L
.86653 .30902 L
.86663 .30902 L
.86672 .30902 L
.86681 .30902 L
.86691 .30902 L
.86709 .30902 L
.8673 .30902 L
.8675 .30902 L
.86833 .30902 L
.86913 .30902 L
.86998 .30902 L
.87039 .30902 L
.87078 .30902 L
.87113 .30902 L
.87151 .30902 L
.87189 .30902 L
.87209 .30902 L
.87219 .30902 L
.87228 .30902 L
.87237 .30902 L
.87246 .30902 L
.87254 .30902 L
.87262 .30902 L
.87271 .30902 L
.8728 .30902 L
.8729 .30902 L
.87299 .30902 L
.87308 .30902 L
.87318 .30902 L
.87329 .30902 L
Mistroke
.87339 .30902 L
.87375 .30902 L
.87415 .30902 L
.87458 .30902 L
.87618 .30902 L
.87662 .30902 L
.87708 .30902 L
.87748 .30902 L
.8777 .30902 L
.87791 .30902 L
.87811 .30902 L
.87833 .30902 L
.87843 .30902 L
.87853 .30902 L
.87863 .30902 L
.87871 .30902 L
.87882 .30902 L
.87888 .30902 L
.87895 .30902 L
.87905 .30902 L
.87911 .30902 L
.87916 .30902 L
.87927 .30902 L
.87936 .30902 L
.87947 .30902 L
.87957 .30902 L
.87976 .30902 L
.87996 .30902 L
.88032 .30902 L
.88112 .30902 L
.88194 .30902 L
.88271 .30902 L
.8834 .30902 L
.88379 .30902 L
.88416 .30902 L
.88436 .30902 L
.88455 .30902 L
.88473 .30902 L
.88482 .30902 L
.88491 .30902 L
.88501 .30902 L
.88506 .30902 L
.88512 .30902 L
.88517 .30902 L
.88523 .30902 L
.88533 .30902 L
.88543 .30902 L
.88552 .30902 L
.88561 .30902 L
.88572 .30902 L
Mistroke
.88591 .30902 L
.88613 .30902 L
.88651 .30902 L
.88739 .30902 L
.88815 .30902 L
.88897 .30902 L
.88944 .30902 L
.88986 .30902 L
.89007 .30902 L
.89029 .30902 L
.8905 .30902 L
.89069 .30902 L
.89088 .30902 L
.89097 .30902 L
.89108 .30902 L
.89113 .30902 L
.89119 .30902 L
.89124 .30902 L
.89129 .30902 L
.89139 .30902 L
.8915 .30902 L
.89155 .30902 L
.89161 .30902 L
.89171 .30902 L
.89176 .30902 L
.89182 .30902 L
.89193 .30902 L
.89213 .30902 L
.89235 .30902 L
.89314 .30902 L
.89387 .30902 L
.89462 .30902 L
.89541 .30902 L
.89582 .30902 L
.89604 .30902 L
.89627 .30902 L
.89649 .30902 L
.89669 .30902 L
.89687 .30902 L
.89707 .30902 L
.89717 .30902 L
.89728 .30902 L
.89738 .30902 L
.89748 .30902 L
.89756 .30902 L
.89765 .30902 L
.89775 .30902 L
.89784 .30902 L
.89795 .30902 L
.89805 .30902 L
Mistroke
.89824 .30902 L
.89844 .30902 L
.89866 .30902 L
.90013 .30902 L
.90095 .30902 L
.90172 .30902 L
.9021 .30902 L
.90252 .30902 L
.90274 .30902 L
.90298 .30902 L
.90318 .30902 L
.9033 .30902 L
.9034 .30902 L
.90351 .30902 L
.90356 .30902 L
.90361 .30902 L
.90371 .30902 L
.90381 .30902 L
.90387 .30902 L
.90392 .30902 L
.90402 .30902 L
.90408 .30902 L
.90413 .30902 L
.90425 .30902 L
.90445 .30902 L
.90463 .30902 L
.90504 .30902 L
.90653 .30902 L
.90729 .30902 L
.9077 .30902 L
.90808 .30902 L
.90849 .30902 L
.90871 .30902 L
.90895 .30902 L
.90905 .30902 L
.90917 .30902 L
.90926 .30902 L
.90937 .30902 L
.90946 .30902 L
.90957 .30902 L
.90966 .30902 L
.90975 .30902 L
.90985 .30902 L
.90995 .30902 L
.91004 .30902 L
.91013 .30902 L
.91023 .30902 L
.91034 .30902 L
.91054 .30902 L
.91097 .30902 L
Mistroke
.91137 .30902 L
.91286 .30902 L
.91358 .30902 L
.91398 .30902 L
.91436 .30902 L
.91458 .30902 L
.91481 .30902 L
.91502 .30902 L
.91522 .30902 L
.91532 .30902 L
.91542 .30902 L
.91551 .30902 L
.91561 .30902 L
.91571 .30902 L
.91576 .30902 L
.91582 .30902 L
.91592 .30902 L
.91602 .30902 L
.91612 .30902 L
.91623 .30902 L
.91642 .30902 L
.91663 .30902 L
.91686 .30902 L
.91766 .30902 L
.91915 .30902 L
.91954 .30902 L
.91996 .30902 L
.92032 .30902 L
.9207 .30902 L
.92092 .30902 L
.92112 .30902 L
.92123 .30902 L
.92135 .30902 L
.92147 .30902 L
.92157 .30902 L
.92167 .30902 L
.92176 .30902 L
.92186 .30902 L
.92191 .30902 L
.92196 .30902 L
.92207 .30902 L
.92212 .30902 L
.92218 .30902 L
.92238 .30902 L
.92257 .30902 L
.92275 .30902 L
.92315 .30902 L
.92388 .30902 L
.92473 .30902 L
.92553 .30902 L
Mistroke
.92591 .30902 L
.92626 .30902 L
.92646 .30902 L
.92667 .30902 L
.92687 .30902 L
.92705 .30902 L
.92725 .30902 L
.92735 .30902 L
.92747 .30902 L
.92752 .30902 L
.92758 .30902 L
.92764 .30902 L
.9277 .30902 L
.9278 .30902 L
.92786 .30902 L
.92791 .30902 L
.92801 .30902 L
.92811 .30902 L
.92821 .30902 L
.92832 .30902 L
.92871 .30902 L
.92911 .30902 L
.92947 .30902 L
.93028 .30902 L
.931 .30902 L
.93176 .30902 L
.93214 .30902 L
.93234 .30902 L
.93255 .30902 L
.93275 .30902 L
.93293 .30902 L
.93311 .30902 L
.9332 .30902 L
.93329 .30902 L
.93339 .30902 L
.93349 .30902 L
.93359 .30902 L
.93365 .30902 L
.9337 .30902 L
.93379 .30902 L
.93389 .30902 L
.93399 .30902 L
.93409 .30902 L
.93431 .30902 L
.93451 .30902 L
.93496 .30902 L
.93661 .30902 L
.93703 .30902 L
.93742 .30902 L
.9378 .30902 L
Mistroke
.93815 .30902 L
.9385 .30902 L
.93867 .30902 L
.93887 .30902 L
.93906 .30902 L
.93917 .30902 L
.93927 .30902 L
.93936 .30902 L
.93946 .30902 L
.93955 .30902 L
.93964 .30902 L
.93973 .30902 L
.93983 .30902 L
.93992 .30902 L
.94 .30902 L
.94021 .30902 L
.94041 .30902 L
.94122 .30902 L
.94205 .30902 L
.94283 .30902 L
.94353 .30902 L
.94392 .30902 L
.94429 .30902 L
.94448 .30902 L
.94465 .30902 L
.94485 .30902 L
.94496 .30902 L
.94505 .30902 L
.94516 .30902 L
.94525 .30902 L
.94536 .30902 L
.94541 .30902 L
.94547 .30902 L
.94557 .30902 L
.94567 .30902 L
.94577 .30902 L
.94587 .30902 L
.94607 .30902 L
.94626 .30902 L
.94669 .30902 L
.94755 .30902 L
.94839 .30902 L
.94881 .30902 L
.94919 .30902 L
.94953 .30902 L
.94991 .30902 L
.95028 .30902 L
.95049 .30902 L
.95068 .30902 L
.95078 .30902 L
Mistroke
.95089 .30902 L
.95099 .30902 L
.95108 .30902 L
.95114 .30902 L
.95119 .30902 L
.95125 .30902 L
.95131 .30902 L
.95141 .30902 L
.95146 .30902 L
.95152 .30902 L
.95162 .30902 L
.95172 .30902 L
.9519 .30902 L
.95231 .30902 L
.95302 .30902 L
.9538 .30902 L
.95462 .30902 L
.95502 .30902 L
.95539 .30902 L
.95577 .30902 L
.95598 .30902 L
.95619 .30902 L
.9563 .30902 L
.95641 .30902 L
.95651 .30902 L
.95661 .30902 L
.95668 .30902 L
.95674 .30902 L
.95679 .30902 L
.95686 .30902 L
.95691 .30902 L
.95696 .30902 L
.95702 .30902 L
.95707 .30902 L
.95717 .30902 L
.95723 .30902 L
.95728 .30902 L
.95738 .30902 L
.9575 .30902 L
.9577 .30902 L
.95789 .30902 L
.95878 .30902 L
.95961 .30902 L
.96039 .30902 L
.96077 .30902 L
.96112 .30902 L
.96132 .30902 L
.96153 .30902 L
.96173 .30902 L
.96191 .30902 L
Mistroke
.96211 .30902 L
.96222 .30902 L
.96233 .30902 L
.96244 .30902 L
.96254 .30902 L
.9626 .30902 L
.96265 .30902 L
.96271 .30902 L
.96277 .30902 L
.96288 .30902 L
.96293 .30902 L
.96299 .30902 L
.96309 .30902 L
.96319 .30902 L
.96337 .30902 L
.96357 .30902 L
.96399 .30902 L
.96439 .30902 L
.96514 .30902 L
.96595 .30902 L
.9664 .30902 L
.96681 .30902 L
.96718 .30902 L
.96737 .30902 L
.96757 .30902 L
.96779 .30902 L
.9679 .30902 L
.96801 .30902 L
.96812 .30902 L
.96822 .30902 L
.96832 .30902 L
.96841 .30902 L
.9685 .30902 L
.96859 .30902 L
.96869 .30902 L
.96878 .30902 L
.96887 .30902 L
.96895 .30902 L
.96912 .30902 L
.96952 .30902 L
.96989 .30902 L
.97072 .30902 L
.9715 .30902 L
.97221 .30902 L
.9726 .30902 L
.97296 .30902 L
.97314 .30902 L
.97333 .30902 L
.97353 .30902 L
.97372 .30902 L
Mistroke
.97383 .30902 L
.97388 .30902 L
.97394 .30902 L
.97405 .30902 L
.97414 .30902 L
.97424 .30902 L
.97433 .30902 L
.97442 .30902 L
.97453 .30902 L
.97464 .30902 L
.97474 .30902 L
.97497 .30902 L
.9754 .30902 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{421.375, 260.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008>0001AB000`400?l00000o`00003ooooooooo
oooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo
003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooo
oooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool0
0?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooooooo
ool@ooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooo
ooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo0ol0003o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0
003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo
00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`
ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLoooo
o`00<?ooool3o`000?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?oo
ool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0
033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomco
oooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooo
oooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool3o`0006_ooooo
0_l0003oooooofoooooo000`ooooo`03o`000?oooooooooo06_ooooo0_l0003oooooofoooooo000`
ooooo`03o`000?oooooooooo06_ooooo0_l0003oooooofoooooo000`ooooo`03o`000?oooooooooo
06_ooooo0_l0003oooooofoooooo000`ooooo`03o`000?oooooooooo06_ooooo0_l0003oooooofoo
oooo000`ooooo`03o`000?oooooooooo06_ooooo0_l0003oooooofoooooo000`ooooo`03o`000?oo
oooooooo06_ooooo0_l0003oooooofoooooo000@ooooo`;ok^k^0oooool2onk^kQWooooo00?o0000
ooooooooool0Joooool2o`000?ooooooKoooool000_ooooo0_l000002_l@413oooooooooooo^k^ko
EEEEonk^k_ooooook^k^oeEEEOo^k^h3ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o
<S8bonk^kP[ooooo00?o0000ooooooooool0Joooool2o`000?ooooooKoooool000cooooo00?o0000
ooooooooool00_ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00[ooooo00?o0000ooooooooool0Joooool2o`0000[ooooo
00?o0000ooooooooool0oooooomRooooo`0000?oooooo`000?l000001?l00002ooooo`Go00001?oo
ool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooo
oa0@400:ooooo`03o`000?oooooooooo06_ooooo0_l0000:ooooo`03o`000?oooooooooo0?oooooo
H_ooool000Wooooo00CoA4A4omgMgOoooooo00001?ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Ko
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000[ooooo00?o0000oooo
ooooool0J_ooool00ol0003oooooo`00000:ooooo`03o`000?oooooooooo0?ooooooH_ooool000Wo
oooo00CogMgMoeEEEOoooooo00000oooool01oo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Ooo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000002_ooool4o`0006Wooooo
00?o0000ooooool000002_ooool00ol0003oooooooooo`3oooooof;ooooo000:ooooo`03ogMgMoo<
c<co000000?ooooo0_o^k^h3ooooo`;ok^k^1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oo
ooooooooooooool@41002_ooool00ol0003oooooooooo`1Zooooo`03o`000?oooooo000000[ooooo
00?o0000ooooooooool0oooooomRooooo`002_ooool00oo^k^koA4A4o`00000?ooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`;o00001Oooool00ol0003ooooo
ooooo`1Zooooo`03o`000?oooooo000000Wooooo0_l0003oooooofCooooo000;ooooo`03ogMgMol0
003ooooo00cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1Zooooo`03o`000?oooooo000000Wo
oooo00?o0000ooooool00000oooooomSooooo`00:?ooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo06[ooooo00?o0000ooooool000002Oooool00ol0003oooooo`00003oooooof?o
oooo000Xooooo`?o00001Oooool00ol0003oooooooooo`1Zooooo`03o`000?oooooo000000Wooooo
00?o0000ooooool00000oooooomSooooo`00:Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo06[ooooo00?o0000ooooool000002Oooool00ol0003oooooo`00003oooooof?ooooo000Z
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0J_ooool00ol0003oooooo`000009
ooooo`03o`000?oooooo00000?ooooooHoooool0033ooooo00?o0000ooooooooool0J_ooool00ol0
003oooooo`000009ooooo`03o`000?oooooo00000?ooooooHoooool0033ooooo00?o0000oooooooo
ool0J_ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?ooooooHoooool0033o
oooo00?o0000ooooooooool0J_ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo0000
0?ooooooHoooool0033ooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`08ooooo`04
o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooomSooooo`00<?ooool3o`0005oo
oooo00?o0000ooooooooool02?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo0000
0?ooooooHoooool0033ooooo00?o0000ooooooooool0Goooool2o`0000Wooooo00Co0000oooooooo
oooo00002?ooool00ol0003oooooo`00003oooooof?ooooo000`ooooo`03o`000?oooooooooo05oo
oooo0_l00009ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooomSoooo
o`00<?ooool00ol0003oooooooooo`1Oooooo`;o00002Oooool01?l0003oooooooooool00008oooo
o`03o`000?oooooo00000?ooooooHoooool0033ooooo00?o0000ooooooooool0G_ooool00ol0003o
ooooo`000009ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooomSoooo
o`00<?ooool00ol0003oooooooooo`1Nooooo`03o`000?oooooo000000Wooooo00Co0000oooooooo
oooo00002?ooool00ol0003oooooo`00003oooooof?ooooo000`ooooo`03o`000?oooooooooo05ko
oooo00?o0000ooooool000002Oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo0000
0?ooooooHoooool0033ooooo00?o0000ooooooooool0G_ooool00ol0003oooooo`000009ooooo`04
o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooomSooooo`00<?ooool00ol0003o
ooooooooo`1Nooooo`03o`000?oooooo000000Wooooo00Co0000oooooooooooo00002?ooool00ol0
003oooooo`00003oooooof?ooooo000`ooooo`03o`000?oooooooooo05kooooo00?o0000ooooool0
00002Oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?ooooooHoooool0033o
oooo00?o0000ooooooooool0G_ooool00ol0003oooooo`000009ooooo`04o`000?ooooooooooo`00
00Sooooo00?o0000ooooool00000oooooomSooooo`00<?ooool00ol0003oooooooooo`1Nooooo`03
o`000?oooooo000000Wooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003ooooo
of?ooooo000`ooooo`?o0000G_ooool00ol0003oooooo`000009ooooo`04o`000?ooooooooooo`00
00Sooooo00?o0000ooooool00000oooooomSooooo`00<?ooool00ol0003oooooooooo`1Nooooo`03
o`000?oooooo000000Wooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003ooooo
of?ooooo000`ooooo`03o`000?oooooooooo05kooooo00?o0000ooooool000002Oooool01?l0003o
ooooooooool00008ooooo`03o`000?oooooo00000?ooooooHoooool0033ooooo00?o0000oooooooo
ool0G_ooool00ol0003oooooo`000009ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000oooo
ool000002Oooool00ol0003oooooooooo`3ooooooeOooooo000`ooooo`03o`000?oooooooooo05ko
oooo00?o0000ooooool000002Oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo0000
00Wooooo00?o0000ooooooooool0oooooomGooooo`00<?ooool00ol0003oooooooooo`1Nooooo`04
o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`000008
ooooo`;o0000oooooomIooooo`00<?ooool00ol0003oooooooooo`1Nooooo`04o`000?oooooooooo
o`0000Sooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`000008ooooo`;o0000oooo
oomIooooo`00<?ooool00ol0003oooooooooo`1Nooooo`04o`000?ooooooooooo`0000Sooooo00Co
0000oooooooooooo00002?ooool00ol0003oooooo`000008ooooo`;o0000oooooomIooooo`00<?oo
ool00ol0003oooooooooo`1Nooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo
00002?ooool00ol0003oooooo`000008ooooo`;o0000oooooomIooooo`00<?ooool00ol0003ooooo
ooooo`1Nooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001oooool01?l0
003oooooooooool00008ooooo`;o0000oooooomIooooo`00<?ooool00ol0003oooooooooo`1Noooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001oooool01?l0003ooooooooo
ool00008ooooo`;o0000oooooomIooooo`00<?ooool3o`0005kooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000oooo
ool00000oooooomHooooo`00<?ooool00ol0003oooooooooo`1Nooooo`04o`000?ooooooooooo`00
00Sooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool00008ooooo`03o`000?oo
oooo00000?ooooooF?ooool0033ooooo00?o0000ooooooooool0G_ooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00002?ooool00ol0003o
ooooo`00003ooooooeSooooo000`ooooo`03o`000?oooooooooo05kooooo00Co0000oooooooooooo
00002?ooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000
ooooool00000oooooomHooooo`00<?ooool00ol0003oooooooooo`1Nooooo`04o`000?oooooooooo
o`0000Sooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool00008ooooo`03o`00
0?oooooo00000?ooooooF?ooool0033ooooo00?o0000ooooooooool0G_ooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00002?ooool00ol0
003oooooo`00003ooooooeSooooo000`ooooo`03o`000?oooooooooo05kooooo00Co0000oooooooo
oooo00002?ooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Sooooo00?o
0000ooooool00000oooooomHooooo`004?ooool2onk^kP?ooooo0_o^k^hIooooo`03o`000?oooooo
oooo05kooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Oooooo
00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003ooooooeSooooo0009ooooo`Go0000
0_ooool01oo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^h:ooooo`03o`000?oooooooooo05kooooo00Co0000oooooooooooo
00001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo00002?ooool0
0ol0003oooooo`00003ooooooeSooooo0009ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool0
1Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00[ooooo00?o0000ooooooooool0GOooool01Ol0003ooooooooooooooooo000000Oo
oooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000
ooooool00000oooooomHooooo`0000?oooooo`000?l000001?l00003ooooo`03oiRHV?lQ8B7ok^k^
00Gooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@41002_ooool00ol0003oooooooooo`1Mooooo`05o`000?ooooooooooooooool000001ooo
ool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`03
o`000?oooooo00000?ooooooF?ooool000_ooooo00?oV9RHob4Q8Oo^k^h00oooool01Oo^k^koEEEE
omgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
00[ooooo00?o0000ooooooooool0GOooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000
ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool00ol0003ooooo
o`00003ooooooeSooooo000<ooooo`0;ogMgMomVIVKoooooooooooo^k^koEEEEonk^k_ooooook^k^
oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000002_oo
ool4o`0005cooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool0
00001oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooool00000oooooomHoooo
o`003Oooool00ol0003oooooooooo`02onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;o
oooo00Go410@oooooooooooooooooa0@400:ooooo`03o`000?oooooooooo05gooooo00Go0000oooo
ooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooo
oooooooo000000Oooooo00?o0000ooooool00000oooooomHooooo`002Oooool01Ol0003o^[Zjoooo
oonHV9So410@00kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo0_l00005ooooo`03o`000?oooooooooo05gooooo00Go0000ooooooooooooooooo`000007oooo
o`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00?o
0000ooooool00000oooooomHooooo`002Oooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo00?o
EEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`1Mooooo`05o`000?ooooooooooooooool000001oooool01Ol0
003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?oo
ooooooooo`000?ooooooF?ooool002Sooooo00Co0000oooooooooooo00001?ooool00ol0003ooooo
ooooo`1Booooo`03o`000?oooooooooo00Sooooo00Go0000ooooooooooooooooo`000007ooooo`05
o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000
oooooooooooo0000oooooomHooooo`00:?ooool3o`0000Gooooo00?o0000ooooooooool0D_ooool0
0ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooo
oooooooo000000Oooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`00
0?ooooooF?ooool002Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Aooooo`03
o`000?oooooo000000Wooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooooooo
ooooool000001oooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo0000
oooooomHooooo`00:_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo057ooooo00?o
0000ooooool000002Oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooooooooooo
ooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool0003o
oooooeSooooo000`ooooo`03o`000?oooooooooo057ooooo00?o0000ooooool000002Oooool01Ol0
003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oo
ooooooooooooool000001_ooool01?l0003oooooooooool0003ooooooeSooooo000`ooooo`03o`00
0?oooooooooo057ooooo00?o0000ooooool000002Oooool01Ol0003ooooooooooooooooo000000Oo
oooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool0
1?l0003oooooooooool0003ooooooeSooooo000`ooooo`03o`000?oooooooooo057ooooo00?o0000
ooooool000002Oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooooooooooooooo
o`000007ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool0003ooooo
oeSooooo000`ooooo`03o`000?oooooooooo057ooooo00?o0000ooooool000002Oooool01Ol0003o
oooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooo
ooooooooool000001_ooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo0?oooooo
COooool0033ooooo0ol0001Aooooo`03o`000?oooooo000000Wooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooo
oooooooooooo000000Kooooo00Co0000oooooooooooo00002?ooool2o`000?ooooooC_ooool0033o
oooo00?o0000ooooooooool0DOooool00ol0003oooooo`000009ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooo
ooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Sooooo0_l0003oooooodkooooo000`
ooooo`03o`000?oooooooooo053ooooo00Co0000oooooooooooo00002Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000007ooooo`05o`00
0?ooooooooooooooool000001_ooool01?l0003oooooooooool00008ooooo`;o0000oooooom>oooo
o`00<?ooool00ol0003oooooooooo`1@ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001oooool0
1Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo00001oooool00ol0003ooooo
o`00003oooooodkooooo000`ooooo`03o`000?oooooooooo053ooooo00Co0000oooooooooooo0000
2Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooo
ooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool00007
ooooo`03o`000?oooooo00000?ooooooC_ooool0033ooooo00?o0000ooooooooool0D?ooool01?l0
003oooooooooool00009ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
1Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`04ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool00000oooooom>ooooo`00<?oo
ool00ol0003oooooooooo`1@ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooool00000oooooom>ooooo`00<?ooool00ol0003ooooo
ooooo`1@ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000
00Kooooo00?o0000ooooool00000oooooom>ooooo`00<?ooool00ol0003oooooooooo`1@ooooo`05
o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000
ooooool00000oooooom>ooooo`00<?ooool00ol0003oooooooooo`1@ooooo`05o`000?oooooooooo
ooooool000001oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooool00000oooo
oom>ooooo`00<?ooool00ol0003oooooooooo`1@ooooo`05o`000?ooooooooooooooool000001ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooool00000oooooom>ooooo`00<?oo
ool00ol0003oooooooooo`1@ooooo`05o`000?ooooooooooooooool000001oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooool00000oooooom>ooooo`00<?ooool3o`00053ooooo
00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool00ol0
003oooooo`00003oooooodkooooo000`ooooo`03o`000?oooooooooo053ooooo00Go0000oooooooo
ooooooooo`000007ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool0
003oooooodgooooo000`ooooo`03o`000?oooooooooo053ooooo00Go0000ooooooooooooooooo`00
0007ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`04ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool0003oooooodgo
oooo000`ooooo`03o`000?oooooooooo053ooooo00Go0000ooooooooooooooooo`000007ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05
o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool0003oooooodgooooo000`oooo
o`03o`000?oooooooooo053ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooo
ooooooooool000001_ooool01?l0003oooooooooool0003oooooodgooooo000`ooooo`03o`000?oo
oooooooo04kooooo0_o^k^h01Ol0003oooooooooooo^k^ko000000Oooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooo
ooooo`000006ooooo`04o`000?ooooooooooo`0001gooooo0_o^k^h3ooooo`;ok^k^H?ooool2onk^
kP?ooooo0_o^k^i>ooooo`;ok^k^0oooool2onk^kVcooooo000`ooooo`03o`000?oooooooooo04So
oooo00goA4A4o`000?l0003o<S8bomgMgOooooook^k^oeEEEOl0003oooooonk^k_mEEEGo000000?o
oooo1Ol00002ooooo`05onk^k_lb<S;o0000o`000?o^k^h01?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04oooo
o`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool0000Gooooo`Co000000Wo
410@ooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^hkooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo
00goA4A4o`000?l0003o<S8bomgMgOooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo
1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^>?ooool5o`0000;ooooo00Ook^k^
oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`00
0?lb<S;ok^k^GOooool0033ooooo00?o0000ooooooooool0Boooool02_mgMgOo<S8boooooooooooo
0000oeEEEOoMgMgoEEEEonk^k_l00005ooooo`03o`000?oooooo000000;ooooo00GoMgMgoiRHV?oo
oooo0000ogMgM`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000005
ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00;ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0mooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`09
ogMgMolb<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg03Sooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05
onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL0GOooool0033ooooo00?o0000ooooooooool0C?ooool02Ol0003oooooooooool0003o
gMgMo`000?oMgMgoooooo`000005ooooo`03o`000?oooooo000000;ooooo00Go410@oooooooooooo
0000oa0@4004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000005oooo
o`05o`000?ooooooooooooooool000001_ooool3o`00013ooooo00?o0000ooooooooool00oooool0
0ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
400mooooo`03o`000?oooooooooo00oooooo00Oo0000ooooooooooooooooomgMgOl0003ogMgM00Oo
oooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@03Wooooo00?oV9RHob4Q
8Oo^k^h01Oooool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooo
oooooooooooooa0@401Mooooo`00<?ooool00ol0003oooooooooo`1;ooooo`0:ogMgMolb<S;ooooo
ooooool0003oEEEEomgMgOmEEEGok^k^o`0000Gooooo00?o0000ooooool000000_ooool00ol0003o
ooooooooo`02o`0000Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo0000
00Gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo0000013ooooo00?o0000
ooooooooool00_ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000003gooooo00?o0000ooooooooool03_ooool02OmgMgOo<S8b
ooooooooooook^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`00000jooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Gok^k^oeEEEOoMgMgoEEEE
onk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001Mooooo`00
<?ooool00ol0003oooooooooo`13ooooo`;o00000oooool03Ol0003o8B4Qo`000?lb<S;oc<c<oooo
ooo^k^ko0000onk^k_ooooook^k^oeEEEOl000001Oooool00ol0003oooooo`000002ooooo`03o`00
0?oooooooooo00;o00001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool0
00001Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooool000004?ooool02ol0
003oooooooooooooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000oooooooo
ool00_ooool01Ol0003ooooooooooooooooo000003gooooo00?o0000ooooooooool02oooool03Ol0
003o8B4Qo`000?lb<S;oc<c<ooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000>oooool02omgMgOoIVIVoooooooo
ooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000ooooooooool00_ooool01Ol0
003ooooooooooooooooo000005gooooo000`ooooo`03o`000?oooooooooo04?ooooo0ol00002oooo
o`03o`000?oooooooooo00?ooooo00?ok^k^o`000?ooool00_ooool00oo^k^ko0000ooooo`04oooo
o`03o`000?oooooo000000;ooooo00Go410@oooooooooooo0000oa0@4004ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00Go0000ooooooooooooooooo`000005ooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooo`00000@ooooo`04o`000?ooooooooooooooo`;ok^k^0oooool2onk^kPGo
oooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@03gooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`03ooooo`;ok^k^0oooool2onk^kPGooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@03cooooo00?o0000ooooooooool00_o^k^h3
ooooo`;ok^k^1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100GOoo
ool0033ooooo0ol00013ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000000_ooool0
1OmgMgOoV9RHooooool0003oMgMg00Cooooo00Oo0000ooooooooooooooooo`000?oooooo000000Go
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`05o`000?oooooooooooooo
ool000001Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooool000004?ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`08ooooo`;o0000<oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo0_l0000^ooooo`05o`00
0?nj^[[ooooooiRHV?l@41003_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02?ooool2o`0005?ooooo000`ooooo`03o`000?oooooooooo04;ooooo00Co0000oooooooo
oooo00000_ooool4o`0000?ooooo00?o0000ooooooooool00oooool02?l0003ooooooooooomEEEGo
IVIVo`000?oooooo00000_ooool01Oo^k^ko<S8bo`000?l0003ok^k^00Cooooo00Oo0000oooooooo
ooooooooo`000?oooooo000000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooool000003_ooool00omEEEGoIVIVo`00000=ooooo`03oeEEEOmVIVKo000000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP07ooooo`04o`000?ooooooooooo`00033ooooo00?oEEEEofIV
I_l000003Oooool4o`0000cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Oooooo00Co0000oooooooooooo0000;Oooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo
00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oooooo00Co0000oooooooo
oooo0000D_ooool0033ooooo00?o0000ooooooooool0@_ooool01?l0003oooooooooool00009oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`04o`000?ooooooooooooooo`Co00000oooool2o`0000Gooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooool00000;?ooool4o`000005ooooool0003oooooooooool0
0000G_ooool4o`000005ooooool0003oooooooooool00000C?ooool4o`000005ooooool0003ooooo
ooooool00000D_ooool0033ooooo00?o0000ooooooooool0@Oooool01Ol0003ooooooooooooooooo
000000Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`;o00001Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00
0005ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooo`00000aooooo`?o0000
I?ooool3o`0005;ooooo0ol0001Cooooo`00<?ooool00ol0003oooooooooo`11ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`04o`000?oo
ooooooooo`0000;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000booooo`03o`000?oooooooooo
06Cooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`1Booooo`00<?ooool00ol0003o
ooooooooo`11ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Co00001Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo0_l0000Z
ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`1A
ooooo`00<?ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo0_l0003ooooooc_ooooo000`oooo
o`03o`000?oooooooooo047ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000001_ooool2o`000?oooooo0Oooool00omgMgOoIVIVooooo`0]
ooooo`03ofIVI_mgMgOooooo00Oooooo000`ooooo`03o`000?oooooooooo043ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001Oooool0
1?l0003oooooooooool0003nooooo`03omgMgOl@413ok^k^02kooooo00?ok^k^oa0@4?oMgMd01ooo
ool0033ooooo00?o0000ooooooooool0<oooool3o`0000[ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001Oooool01?l0003ooooooooo
ool00006ooooo`;o0000i?ooool2o`0000;ooooo0_l0000<ooooo`03oeEEEOnHV9Sooooo00;o0000
0_ooool01ol0003oooooooooool0003o410@onk^k_mEEED00_l000000om4A4Co^[Zjooooo`02oooo
o`05oiRHV?l0003o0000odA4A?nj^[X00_ooool02?o^k^koEEEEo`000?l0003oA4A4okZj^_oooooo
410@1Ol00003ooooo`08oa0@4?lb<S;o0000o`000?l@413oZJVYohN7QomVIVH7ooooo`00<?ooool0
0ol0003oooooooooo`0aooooo`;o00000_ooool2o`0000Wooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0003ooooooooo
oooooooo000000Cooooo1?l0003Sooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM3?ooool01Ol0
003ooooooooooooooooo000000;ooooo00_o0000oooooooooooo0000oooooomEEEGoMgMgooooooo^
k^koMgMgoa0@4003ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000_ooool01_mEEEGoMgMgooooooo^
k^koMgMgoa0@40?ooooo00?o0000ooooooooool01?ooool02?l0003oZJVYoooooooooooo^[Zjo`00
0?o^k^ko00001oooool00?oo0000]?l0000?ooooo`04omgMgOl0003o410@olc<c0gooooo00Go<S8b
ooooooooooooooooo`000002ooooo`06o`000?ooooooooooo`000?oooooo00002?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool01onj^[[o
QhN7ofIVI_mVIVKo410@ooooool000001oooool000[ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool01?l0
003oooooooooooooool8o`0000Kooooo00?o0000ooooool000001oooool00ol0003oooooooooo`05
ooooo`;o00001Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo0_l00005
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool2o`0000?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooooooo`;o00001?oo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool2o`0000?ooooo
1Ol00005ooooo`?o000000?oooooo`000?ooool04Oooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Gooooo`04onk^
k_lQ8B7o410@onk^kPgooooo00Go<S8booooooooooooooooo`000002ooooo`05o`000?oooooooooo
o`000?ooool01_l00003ooooo`03o`000?oooooooooo00Cooooo1_l00003ooooo`03o`000?oooooo
oooo00Cooooo00So<S8bob4Q8OmgMgOoMgMgohN7Qoo^k^koooooo`0000Oooooo000:ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool03oooool01?l0003oooooooooool00006ooooo`03
o`000?oooooooooo00Gooooo0_l00005ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00oooool2o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`;o
00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooooooo0_l00004ooooo`05o`000?ooooooooooooooool000001Oooool01?l0003oooooooooool0
000Booooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool05oooool01?lQ8B7oMgMgogMg
Molb<S8=ooooo`05o`000?o^k^koooooooooool000000_o<c<`02ol0003oZJVYomgMgOlQ8B7ooooo
oeEEEOn7QhOok^k^oooooon7QhOo<S8b00?ooooo00?o0000ooooooooool01?ooool01_mEEEGoQhN7
onk^k_ooooooQhN7oc8b<P?ooooo00?o0000oc8b<_oMgMd01?ooool02?l0003o^[Zjooooooo^k^ko
MgMgo`000?o^k^ko00001oooool0033ooooo00?o0000ooooooooool0>?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00?ooooo0_l00005ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Gooooo00Go0000oooooooooooo
ooooo`000005ooooo`?o00004oooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo05_o
oooo00?o0000ooooooooool05_ooool2o`0000;ooooo0_l0000<ooooo`0>oeEEEOmgMgOooooooa0@
4?l0003o8B4Qo`000?mgMgOo410@o`000?nYZJWoooooonk^k_mEEED2o`000004odA4A?o^k^kooooo
oa0@40Go00000oooool01_o^k^koEEEEo`000?l0003oA4A4onk^kP;ooooo0_l000001?nYZJWo8B4Q
o`000?lQ8B42ooooo`08ojVYZOlQ8B7o0000o`000?lb<S;o0000ogMgMomEEED7ooooo`00<?ooool0
0ol0003oooooooooo`0iooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000000Gooooo00Go0000ooooooooooooooooo`000006ooooo`;o0000
n_ooool00ooMgMgo410@onk^kP0Booooo`03o`000?oooooooooo01Wooooo00?ok^k^oa0@4?oMgMd0
1oooool0033ooooo00?o0000ooooooooool0>_ooool2o`000003ooooool0003o000000Sooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000005ooooo`04o`000?ooooooooooo`000?oooooo1Oooool00omgMgOo
IVIVooooo`0Aooooo`03o`000?oooooooooo01Wooooo00?oIVIVogMgMoooool01oooool0033ooooo
00?o0000ooooooooool0>oooool3o`0000Wooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooo00000?oooooo?oooool0033ooooo00?o0000ooooooooool0Aoooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooool00000ooooooloooooo`00<?ooool00ol0003ooooo
ooooo`17ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooo`00003oooooocoo
oooo000`ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooo00000?oooooo?oooool0033ooooo00?o0000ooooooooool0B?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000Kooooo0_l0003ooooood3ooooo000`ooooo`03o`000?oooooooooo04Sooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
00Co0000oooooooooooo0000oooooom8ooooo`00<?ooool3o`0004Sooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo
0000oooooom8ooooo`00<?ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`000?oo
ooooB?ooool0033ooooo00?o0000ooooooooool0BOooool01Ol0003ooooooooooooooooo000000So
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooooooooooo
ool000001_ooool01?l0003oooooooooool0003oooooodSooooo000`ooooo`03o`000?oooooooooo
04Wooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo0000
oooooom8ooooo`00<?ooool00ol0003oooooooooo`19ooooo`05o`000?ooooooooooooooool00000
2?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooo
ooooo`000006ooooo`04o`000?ooooooooooo`000?ooooooB?ooool0033ooooo00?o0000oooooooo
ool0BOooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool0
003oooooodSooooo000`ooooo`03o`000?oooooooooo04Wooooo00Go0000ooooooooooooooooo`00
0008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooo
oooooooo000000Kooooo00Co0000oooooooooooo0000oooooom8ooooo`00<?ooool00ol0003ooooo
ooooo`19ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo0000
0?ooooooBOooool0033ooooo00?o0000ooooooooool0BOooool01Ol0003ooooooooooooooooo0000
00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooooooo
ooooool000001_ooool00ol0003oooooo`00003oooooodWooooo000`ooooo`03o`000?oooooooooo
04Wooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo00000?ooooooBOoo
ool0033ooooo00?o0000ooooooooool0BOooool01?l0003oooooooooool00009ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooool00000oooooom9ooooo`00<?ooool00ol0003oooooooooo`1:ooooo`03o`000?oo
oooo000000Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oo
ooooooooooooool000001oooool2o`000?ooooooBOooool0033ooooo0ol0001:ooooo`03o`000?oo
oooo000000Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oo
ooooooooooooool000001oooool2o`000?ooooooBOooool0033ooooo00?o0000ooooooooool0B_oo
ool00ol0003oooooo`000009ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooo
ool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool0oooooom8ooooo`00<?oo
ool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool00000oooooomBooooo`00<?oo
ool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Ooo
ool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooo
oooooooooooo00000?ooooooD_ooool0033ooooo00?o0000ooooooooool0E_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000007ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00003ooooooe;ooooo000`ooooo`03
o`000?oooooooooo05Oooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooooooo
ooooool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool00000oooo
oomBooooo`00<?ooool00ol0003oooooooooo`1Gooooo`05o`000?ooooooooooooooool000001ooo
ool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooo
oooooooooooo00000?ooooooD_ooool0033ooooo00?o0000ooooooooool0Eoooool01Ol0003ooooo
oooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00?ooooo00Co0000oooooooooooo0000oooooomCooooo`00<?ooool00ol0003oooooooooo`1Goooo
o`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool01?l0003oooooooooool0003ooooooe?ooooo000`ooooo`03o`000?oo
oooooooo05Oooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool0
00001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`000?ooooooDoooool0033o
oooo00?o0000ooooooooool0Eoooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooo
ooooooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooool00000oooooomC
ooooo`00<?ooool00ol0003oooooooooo`1Gooooo`05o`000?ooooooooooooooool000001oooool0
1Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooo`00
003ooooooe?ooooo000`ooooo`?o0000Eoooool01Ol0003ooooooooooooooooo000000Oooooo00Go
0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooool00000
oooooomCooooo`00<?ooool00ol0003oooooooooo`1Gooooo`05o`000?ooooooooooooooool00000
1oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooo`00003ooooooe?ooooo000`ooooo`03o`000?oooooooooo05Oooooo00Go0000oooooooooooo
ooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooo00000?ooooooDoooool0033ooooo00?o0000ooooooooool0Eoooool01Ol0003o
oooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooool00000oooooomCooooo`00<?ooool00ol0003oooooooooo`1Goooo
o`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooo`00003ooooooe?ooooo000`ooooo`03o`000?oooooo
oooo05Oooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Oooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool00ol0003oooooo`00003ooooooe?ooooo000?ooooo`;ok^k^0ooo
ool2onk^kQ[ooooo00?o0000ooooooooool0Eoooool01?l0003oooooooooool00008ooooo`05o`00
0?ooooooooooooooool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo00000?oo
ooooDoooool000Sooooo1Ol00002ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00?o0000ooooooooool0
Eoooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool000001oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooo00000?ooooooDoooool000Sooooo00GoV9RHob4Q8Oo^
k^koooooodA4A003ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ol0003oooooooooo`1Gooooo`04o`000?oo
ooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooool00000oooooomCooooo`002Oooool00onHV9So8B4Qonk^kP05ooooo`03omgM
gOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00_o
oooo00?o0000ooooooooool0Eoooool01?l0003oooooooooool00008ooooo`05o`000?oooooooooo
ooooool000001oooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000oooooooooooooooo
o`000007ooooo`03o`000?oooooo00000?ooooooDoooool000[ooooo00?oV9RHob4Q8Oo^k^h00ooo
ool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000_ooooo00?o0000ooooooooool0Eoooool01?l0003oooooooooool00008oooo
o`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Kooooo00Go
0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?ooooooDoooool000_ooooo00_o
MgMgofIVI_ooooooooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`00000;ooooo`Co0000E_ooool01?l0003ooooooooo
ool00008ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo0000
00Kooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?ooooooDoooool0
00cooooo00?o0000ooooooooool00_o^k^h3ooooo`;ok^k^1Oooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@41002oooool00ol0003oooooooooo`1Gooooo`04o`000?oooooo
ooooo`0000Sooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool0
00001oooool01?l0003oooooooooool00007ooooo`03o`000?oooooo00000?ooooooDoooool000So
oooo00Go0000okZj^_ooooooV9RHoa0@400>ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0;ooooo`03o`000?oooooooooo05Oooooo00Co0000oooooooooooo00002?oo
ool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04
o`000?ooooooooooo`0000Sooooo0_l0003ooooooe?ooooo0008ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`03?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool2
o`0000Kooooo00?o0000ooooooooool0Eoooool01?l0003oooooooooool00008ooooo`05o`000?oo
ooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooo
oooo00002?ooool00ol0003oooooooooo`3ooooooe;ooooo000Wooooo`04o`000?ooooooooooo`00
00Gooooo00?o0000ooooooooool0Eoooool01?l0003oooooooooool00008ooooo`05o`000?oooooo
ooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo
00002?ooool00ol0003oooooooooo`3ooooooe;ooooo000Wooooo`04o`000?ooooooooooo`0000Go
oooo00?o0000ooooooooool0Eoooool01?l0003oooooooooool00008ooooo`05o`000?oooooooooo
ooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000
oooooomMooooo`009oooool3o`0000Kooooo00?o0000ooooooooool0Eoooool01?l0003ooooooooo
ool00008ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo0000
00Oooooo00Co0000oooooooooooo0000oooooomMooooo`00:?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo05Oooooo00Co0000oooooooooooo00002Oooool01?l0003oooooooooool0
0007ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool0003ooooooego
oooo000Yooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0F?ooool00ol0003ooooo
o`000009ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000007oooo
o`04o`000?ooooooooooo`000?ooooooGOooool0033ooooo00?o0000ooooooooool0F?ooool00ol0
003oooooo`000009ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00
0007ooooo`04o`000?ooooooooooo`000?ooooooGOooool0033ooooo00?o0000ooooooooool0F?oo
ool00ol0003oooooo`000009ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooooooo
ooooo`000007ooooo`04o`000?ooooooooooo`000?ooooooGOooool0033ooooo00?o0000oooooooo
ool0F?ooool2o`0000[ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo
000000Oooooo00Co0000oooooooooooo0000oooooomMooooo`00<?ooool3o`0005Sooooo0_l0000:
ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04o`00
0?ooooooooooo`000?ooooooGOooool0033ooooo00?o0000ooooooooool0F?ooool2o`0000[ooooo
00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooo
oooooooo0000oooooomMooooo`00<?ooool00ol0003oooooooooo`1Hooooo`;o00002_ooool01?l0
003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001oooool01?l0003ooooooooo
ool0003ooooooegooooo000`ooooo`03o`000?oooooooooo05Sooooo0_l0000:ooooo`04o`000?oo
ooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`00
0?ooooooGOooool0033ooooo00?o0000ooooooooool0F?ooool2o`0000[ooooo00Co0000oooooooo
oooo00001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000oooo
oomMooooo`00<?ooool00ol0003oooooooooo`1Hooooo`;o00002_ooool01?l0003oooooooooool0
0007ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003ooooooekooooo
000`ooooo`03o`000?oooooooooo06Cooooo00Co0000oooooooooooo00001oooool01Ol0003ooooo
oooooooooooo000000Oooooo00?o0000ooooool00000oooooomNooooo`00<?ooool00ol0003ooooo
ooooo`1Tooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000007oooo
o`03o`000?oooooo00000?ooooooG_ooool0033ooooo00?o0000ooooooooool0I?ooool01?l0003o
ooooooooool00007ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003o
oooooekooooo000`ooooo`03o`000?oooooooooo06Cooooo00Co0000oooooooooooo00001oooool0
1Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooool00000oooooomNooooo`00<?ooool0
0ol0003oooooooooo`1Tooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000
1oooool00ol0003oooooo`00003ooooooekooooo000`ooooo`03o`000?oooooooooo06Cooooo00Co
0000oooooooooooo00002?ooool01?l0003oooooooooool00007ooooo`03o`000?oooooo00000?oo
ooooG_ooool0033ooooo0ol0001Tooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooo
oooo00001oooool00ol0003oooooo`00003ooooooekooooo000`ooooo`03o`000?oooooooooo06Co
oooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00007ooooo`03o`000?oooooo
00000?ooooooG_ooool0033ooooo00?o0000ooooooooool0I?ooool01?l0003oooooooooool00008
ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool00000oooooomNooooo`00<?ooool0
0ol0003oooooooooo`1Tooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000
2?ooool2o`000?ooooooG_ooool0033ooooo00?o0000ooooooooool0I?ooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0000Sooooo0_l0003ooooooekooooo000`ooooo`03o`00
0?oooooooooo06Cooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00008oooo
o`;o0000oooooomNooooo`00<?ooool00ol0003oooooooooo`1Tooooo`04o`000?ooooooooooo`00
00Sooooo00Co0000oooooooooooo00002?ooool2o`000?ooooooG_ooool0033ooooo00?o0000oooo
ooooool0I?ooool00ol0003oooooo`000009ooooo`04o`000?ooooooooooo`0000Sooooo0_l0003o
oooooekooooo000`ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooool000002Oooool01?l0
003oooooooooool00008ooooo`;o0000oooooomNooooo`00<?ooool00ol0003oooooooooo`1Toooo
o`03o`000?oooooo000000Wooooo00Co0000oooooooooooo00002?ooool2o`000?ooooooG_ooool0
033ooooo00?o0000ooooooooool0I?ooool00ol0003oooooo`000009ooooo`04o`000?oooooooooo
o`0000Sooooo0_l0003ooooooekooooo000`ooooo`03o`000?oooooooooo06Cooooo00?o0000oooo
ool000002Oooool01?l0003oooooooooool00008ooooo`;o0000oooooomNooooo`00<?ooool3o`00
06Cooooo00?o0000ooooool000002Oooool01?l0003oooooooooool00008ooooo`;o0000oooooomN
ooooo`00<?ooool00ol0003oooooooooo`1Tooooo`03o`000?oooooo000000Wooooo00?o0000oooo
ool00000oooooomYooooo`00<?ooool00ol0003oooooooooo`1Tooooo`03o`000?oooooo000000Wo
oooo00?o0000ooooool00000oooooomYooooo`00<?ooool00ol0003oooooooooo`1Tooooo`03o`00
0?oooooo000000Wooooo00?o0000ooooool00000oooooomYooooo`00<?ooool00ol0003ooooooooo
o`1Tooooo`03o`000?oooooo000000Wooooo00?o0000ooooool00000oooooomYooooo`00<?ooool0
0ol0003oooooooooo`1Tooooo`03o`000?oooooo000000Wooooo00?o0000ooooool00000oooooomY
ooooo`003oooool2onk^kP?ooooo0_o^k^hJooooo`03o`000?oooooooooo06Gooooo0_l00009oooo
o`03o`000?oooooo00000?ooooooJOooool000[ooooo0_l000002_l@413oooooooooooo^k^koEEEE
onk^k_ooooook^k^oeEEEOo^k^h3ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8b
onk^kP_ooooo00?o0000ooooooooool0IOooool2o`0000Wooooo00?o0000ooooool00000oooooomY
ooooo`002oooool00ol0003oooooooooo`02ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool0
0ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ol0003ooooooooo
o`1Uooooo`;o00002Oooool00ol0003oooooo`00003oooooofWooooo0008ooooo`Go00001?ooool0
0ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03o`000?oooooooooo06Gooooo0_l00009ooooo`03o`000?oooooo00000?ooooooJOoo
ool000Sooooo00CoA4A4omgMgOoooooo00001?ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000_ooooo00?o0000oooooooo
ool0IOooool2o`0000Wooooo00?o0000ooooool00000oooooomYooooo`002?ooool01?oMgMgoEEEE
ooooool00003ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`00000;ooooo`Co0000I?ooool2o`0000Wooooo00?o
0000ooooool00000oooooomYooooo`002Oooool00omgMgOoc<c<o`000003ooooo`;ok^k^0oooool2
onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00_ooooo00?o
0000ooooooooool0IOooool2o`0000Wooooo00?o0000ooooool00000oooooomYooooo`002Oooool0
0oo^k^koA4A4o`00000?ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`03o`000?oooooooooo06Gooooo0_l00009ooooo`03o`000?oooooo00000?ooooooJOoo
ool000[ooooo00?oMgMgo`000?ooool03?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00oooool2o`0000Kooooo00?o0000ooooooooool0IOooool2o`0000Wooooo00?o
0000ooooool00000oooooomYooooo`009oooool01?l0003oooooooooool00005ooooo`03o`000?oo
oooooooo06Gooooo0_l00009ooooo`03o`000?oooooo00000?ooooooJOooool002Oooooo00Co0000
oooooooooooo00001Oooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooool00000oooooomYooooo`009oooool3o`0000Kooooo00?o0000ooooooooool0LOooool2
o`000?ooooooJOooool002Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1aoooo
o`;o0000oooooomYooooo`00:Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo077o
oooo0_l0003oooooofWooooo000`ooooo`03o`000?oooooooooo077ooooo0_l0003oooooofWooooo
000`ooooo`03o`000?oooooooooo077ooooo0_l0003oooooofWooooo000`ooooo`03o`000?oooooo
oooo077ooooo00?o0000ooooooooool0oooooomXooooo`00<?ooool3o`00077ooooo00?o0000oooo
ooooool0oooooomXooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`00
0?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool0
0ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033o
oooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo
000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooL
ooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oo
oooog?ooool0033ooooo0ol0003oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?oo
ool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3ooooo
omcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0
oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooo
oooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003o
ooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o
0000ooooooooool0oooooooLooooo`00<?ooool3o`000?oooooog?ooool0033ooooo00?o0000oooo
ooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`00
0?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00oooooooo
oooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo
003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooo
oooo4?ooool00:3ooooo0_l00004ooooo`03okZj^_lb<S;ooooo00Cooooo0_l00006ooooo`03o`00
0?nj^[[ooooo0?ooooooEoooool00:3ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo0_lb<S;ooooooeSooooo002=ooooo`?o00000_ooool0
1_lb<S;o410@ooooooooooook^k^oeEEE@;o000000?oA4A4okZj^_ooool00oooool00ol0003ooooo
ooooo`02ooooo`05oiRHV?l@413o0000o`000?nYZJT01?ooool00ol0003oooooooooo`04ooooo`03
ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0:ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01?ooool2ob4Q8@Cooooo1Ol000001_ooooooc<c<onk^k_ooooook^k^olc<c0Cooooo
1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^4oooool01_l@413o<S8bo`000?l0
003o410@ojVYZ@;ooooo00Kok^k^oeEEEOl0003o0000odA4A?nj^[X3ooooo`05ofIVI_l0003o0000
odA4A?o<c<`0j?ooool008kooooo00Go0000ooooooooooooc<c<oa0@4003ooooo`06oeEEEOmgMgOo
ooooonk^k_mgMgOo410@1?ooool00ol0003oooooooooo`02ooooo`06o`000?nYZJWoEEEEoiRHV?mE
EEGo^[Zj0oooool00ol0003oooooooooo`04ooooo`03olc<c?l0003o410@00cooooo00Ko410@okZj
^_o^k^koMgMgoa0@4?ooool6o`0000Kooooo00?oMgMgoc8b<_ooool00oooool2ob4Q8@Cooooo00_o
V9RHob4Q8Oo^k^koooooodA4A?ooooook^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Cooooo`06o`000?nYZJWooooooooooonj^[[o
00000_ooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40;ooooo00KoIVIVogMgMoooooooooooohN7
Qol@413Xooooo`00S_ooool01Ol0003ooooooooooomEEEGoQhN700?ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`02ooooo`06oc8b<_o^k^koV9RHoeEEEOoMgMgo410@0oooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02Oooool00onH
V9So8B4Qonk^kP03ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@
413ooooooooooooooooo410@01Cooooo00Go^[ZjohN7QomVIVKoIVIVoa0@4002ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0joooool008kooooo00Go0000oooooooMgMgo0000onk^
kP03ooooo`Ko00001?ooool00ol0003oooooooooo`02ooooo`07okZj^_m4A4Coc<c<ob4Q8Ooooooo
410@olc<c002ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00oooool6o`0000Ko
oooo00?oMgMgoc8b<_ooool02oooool02OnHV9So8B4Qonk^k_ooooook^k^oeEEEOoMgMgoEEEEonk^
kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Cooooo`06oc8b
<_lQ8B7oMgMgogMgMon7QhOok^k^0_ooool6o`0000;ooooo00?o0000ooooooooool0joooool008ko
oooo0ol000000ol@413oV9RHooooo`02ooooo`06oeEEEOn7QhOok^k^oooooon7QhOo<S8b1?ooool0
0ol0003oooooooooo`02ooooo`07onk^k_l0003oooooo`000?ooooooIVIVohN7Q`02ooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool03?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00go
oooo00SoMgMgofIVI_ooooooc<c<onk^k_ooooook^k^olc<c0Kooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000001?ooooo00Ko0000okZj^_ooooook^k^ogMgMol00002oooo
o`06oeEEEOn7QhOok^k^oooooon7QhOo<S8b0_ooool01_mVIVKoMgMgooooooooooooQhN7o`000>So
oooo002>ooooo`05o`000?ooooooooooolc<c?l000000oooool01_o^k^koEEEEo`000?l0003oA4A4
onk^kPCooooo00?o0000ooooooooool00_ooool01?mVIVKoV9RHoooooolb<S82okZj^P04o`000?oo
ooooooooo`0001?ooooo00?o410@o`000?l000000ol0000;ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41001oooool3o`0000;ooooo0ol00004ooooo`06ojVYZOlQ8B7o0000o`000?lb<S;o00000_ooool0
1_o^k^koEEEEo`000?l0003oA4A4onk^kP;ooooo00Kok^k^ofIVI_l0003o0000odA4A?l0003Xoooo
o`00S_ooool01Ol0003oooooooooooo<c<co000000gooooo00?o0000ooooooooool01Oooool00omV
IVKoQhN7ooooo`03ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`05o`000?nj^[[ooooooiRHV?l@41003?ooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo0?oooooo0_ooool008gooooo1?l000000ol@413oZJVYooooo`0<ooooo`;o00001_ooool0
0onYZJWoA4A4ooooo`02ooooo`;o00005Oooool00ol0003oooooooooo`0<ooooo`Co00002oooool0
1OnHV9So410@o`000?lQ8B7oc<c<00[ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00;ooooo1?l00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
ooooool2ooooo`00ooooool6ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0oooo
ool2ooooo`00ooooool6ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0ooooool2
ooooo`00ooooool5ooooo`;o00000oooool2o`000?oooooo1?ooool00?ooooooooooool@ooooo`00
oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooo
oa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003o
oooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo
4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oo
ooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@
ooooo`00oooooooooooooa3ooooo0000\
\>"],
  ImageRangeCache->{{{0, 525.688}, {324.5, 0}} -> {-2.58312*^-7, -6.34248*^6, \
6.65005*^-9, 53093.5}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0.309017 5.42214e-08 [
[.32684 .29652 -16.5 -12.5 ]
[.32684 .29652 16.5 0 ]
[.54329 .29652 -16.5 -12.5 ]
[.54329 .29652 16.5 0 ]
[.75974 .29652 -22.5 -12.5 ]
[.75974 .29652 22.5 0 ]
[.97619 .29652 -16.5 -12.5 ]
[.97619 .29652 16.5 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 64 6 ]
[.09789 .09213 -34.5 -6.25 ]
[.09789 .09213 0 6.25 ]
[.09789 .20057 -34.5 -6.25 ]
[.09789 .20057 0 6.25 ]
[.09789 .41746 -28.5 -6.25 ]
[.09789 .41746 0 6.25 ]
[.09789 .5259 -28.5 -6.25 ]
[.09789 .5259 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -62.8125 0 ]
[.5 .63053 62.8125 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 .30902 m
.32684 .31527 L
s
gsave
.32684 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 .30902 m
.54329 .31527 L
s
gsave
.54329 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 .30902 m
.75974 .31527 L
s
gsave
.75974 .29652 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 .30902 m
.15368 .31277 L
s
.19697 .30902 m
.19697 .31277 L
s
.24026 .30902 m
.24026 .31277 L
s
.28355 .30902 m
.28355 .31277 L
s
.37013 .30902 m
.37013 .31277 L
s
.41342 .30902 m
.41342 .31277 L
s
.45671 .30902 m
.45671 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.58658 .30902 m
.58658 .31277 L
s
.62987 .30902 m
.62987 .31277 L
s
.67316 .30902 m
.67316 .31277 L
s
.71645 .30902 m
.71645 .31277 L
s
.80303 .30902 m
.80303 .31277 L
s
.84632 .30902 m
.84632 .31277 L
s
.88961 .30902 m
.88961 .31277 L
s
.9329 .30902 m
.9329 .31277 L
s
.0671 .30902 m
.0671 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09213 m
.11664 .09213 L
s
gsave
.09789 .09213 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .20057 m
.11664 .20057 L
s
gsave
.09789 .20057 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .41746 m
.11664 .41746 L
s
gsave
.09789 .41746 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .5259 m
.11664 .5259 L
s
gsave
.09789 .5259 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.11039 .11924 m
.11414 .11924 L
s
.11039 .14635 m
.11414 .14635 L
s
.11039 .17346 m
.11414 .17346 L
s
.11039 .22768 m
.11414 .22768 L
s
.11039 .2548 m
.11414 .2548 L
s
.11039 .28191 m
.11414 .28191 L
s
.11039 .33613 m
.11414 .33613 L
s
.11039 .36324 m
.11414 .36324 L
s
.11039 .39035 m
.11414 .39035 L
s
.11039 .44457 m
.11414 .44457 L
s
.11039 .47168 m
.11414 .47168 L
s
.11039 .49879 m
.11414 .49879 L
s
.11039 .06502 m
.11414 .06502 L
s
.11039 .03791 m
.11414 .03791 L
s
.11039 .0108 m
.11414 .0108 L
s
.11039 .55301 m
.11414 .55301 L
s
.11039 .58012 m
.11414 .58012 L
s
.11039 .60723 m
.11414 .60723 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -123.812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.812 moveto
(@) show
81.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.812 moveto
(D) show
93.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5.4) show
135.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
141.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
153.000 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
157.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
166.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
184.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02691 .30902 L
.02852 .30902 L
.03029 .30902 L
.03109 .30902 L
.03152 .30902 L
.03194 .30902 L
.03232 .30902 L
.03252 .30902 L
.03274 .30902 L
.03292 .30902 L
.03302 .30902 L
.03312 .30902 L
.03321 .30902 L
.03329 .30902 L
.03338 .30902 L
.03347 .30902 L
.03357 .30902 L
.03363 .30902 L
.03368 .30902 L
.03377 .30902 L
.03387 .30902 L
.03405 .30902 L
.03424 .30902 L
.03444 .30902 L
.03466 .30902 L
.03506 .30902 L
.03546 .30902 L
.03583 .30902 L
.03653 .30902 L
.03731 .30902 L
.03813 .30902 L
.03884 .30902 L
.03961 .30902 L
.04116 .30902 L
.04204 .30902 L
.04284 .30902 L
.04436 .30902 L
.04522 .30902 L
.04602 .30902 L
.04766 .30902 L
.04915 .30902 L
.05069 .30902 L
.05236 .30902 L
.05396 .30902 L
.05565 .30902 L
.05722 .30902 L
.05869 .30902 L
.0618 .30902 L
.0635 .30902 L
Mistroke
.06512 .30902 L
.06819 .30902 L
.07145 .30902 L
.0746 .30902 L
.07621 .30902 L
.07794 .30902 L
.07876 .30902 L
.07962 .30902 L
.08035 .30902 L
.08077 .30902 L
.08096 .30902 L
.08116 .30902 L
.08126 .30902 L
.08137 .30902 L
.08147 .30902 L
.08156 .30902 L
.08162 .30902 L
.08167 .30902 L
.08178 .30902 L
.08183 .30902 L
.08188 .30902 L
.08194 .30902 L
.082 .30902 L
.08211 .30902 L
.08216 .30902 L
.08222 .30902 L
.08242 .30902 L
.0826 .30902 L
.0828 .30902 L
.08316 .30902 L
.08351 .30902 L
.08388 .30902 L
.08429 .30902 L
.0851 .30902 L
.08556 .30902 L
.08599 .30902 L
.08682 .30902 L
.08761 .30902 L
.0891 .30902 L
.0899 .30902 L
.09075 .30902 L
.09236 .30902 L
.09405 .30902 L
.09564 .30902 L
.09711 .30902 L
.10024 .30902 L
.10195 .30902 L
.10357 .30902 L
.10666 .30902 L
.10994 .30902 L
Mistroke
.1131 .30902 L
.11468 .30902 L
.11538 .30902 L
.11614 .30902 L
.11655 .30902 L
.11675 .30902 L
.11694 .30902 L
.11711 .30902 L
.1173 .30902 L
.11741 .30902 L
.11751 .30902 L
.1176 .30902 L
.1177 .30902 L
.1178 .30902 L
.11789 .30902 L
.11795 .30902 L
.118 .30902 L
.11811 .30902 L
.11821 .30902 L
.11831 .30902 L
.11849 .30902 L
.11871 .30902 L
.11891 .30902 L
.11937 .30902 L
.11975 .30902 L
.12016 .30902 L
.12099 .30902 L
.12176 .30902 L
.12248 .30902 L
.12332 .30902 L
.12412 .30902 L
.12561 .30902 L
.12722 .30902 L
.1287 .30902 L
.13021 .30902 L
.13187 .30902 L
.13511 .30902 L
.13823 .30902 L
.14154 .30902 L
.1432 .30901 L
.144 .30901 L
.14473 .30901 L
.14545 .30901 L
.14622 .30901 L
.14643 .30901 L
.14665 .30901 L
.14685 .30901 L
.14704 .30901 L
.14721 .30901 L
.14731 .30901 L
Mistroke
.1474 .30901 L
.1475 .30901 L
.14756 .30901 L
.14761 .30901 L
.1477 .30901 L
.1478 .30901 L
.1479 .30901 L
.14801 .30901 L
.14811 .30901 L
.1482 .30901 L
.14837 .30901 L
.14856 .30901 L
.14878 .30901 L
.14899 .30901 L
.14937 .30901 L
.14974 .30901 L
.15008 .30901 L
.15084 .30901 L
.15162 .30902 L
.15235 .30902 L
.1532 .30902 L
.15401 .30902 L
.15564 .30902 L
.15713 .30902 L
.16021 .30902 L
.16348 .30903 L
.16663 .30904 L
.16966 .30904 L
.17121 .30904 L
.17164 .30904 L
.17208 .30905 L
.1725 .30905 L
.17289 .30905 L
.17307 .30905 L
.17328 .30905 L
.17337 .30905 L
.17347 .30905 L
.17357 .30905 L
.17365 .30905 L
.17375 .30905 L
.17385 .30905 L
.17395 .30905 L
.17404 .30905 L
.17409 .30905 L
.17415 .30905 L
.17425 .30905 L
.17431 .30905 L
.17436 .30905 L
.17447 .30905 L
.17465 .30905 L
Mistroke
.17484 .30905 L
.17518 .30905 L
.17554 .30905 L
.17594 .30904 L
.17676 .30904 L
.17751 .30904 L
.17837 .30904 L
.17919 .30903 L
.18079 .30902 L
.18227 .30901 L
.18543 .30897 L
.18846 .30893 L
.19169 .30887 L
.19317 .30885 L
.19402 .30883 L
.1948 .30882 L
.19564 .30882 L
.19601 .30881 L
.19641 .30881 L
.19663 .30881 L
.19683 .30881 L
.19702 .30881 L
.19723 .30881 L
.19733 .30881 L
.19739 .30881 L
.19744 .30881 L
.19755 .30881 L
.19765 .30881 L
.1977 .30881 L
.19776 .30881 L
.19786 .30881 L
.19792 .30881 L
.19798 .30881 L
.1981 .30881 L
.1982 .30881 L
.1983 .30881 L
.19848 .30881 L
.19869 .30881 L
.19889 .30881 L
.19932 .30881 L
.19972 .30882 L
.20043 .30883 L
.20121 .30884 L
.20196 .30886 L
.2028 .30889 L
.20449 .30897 L
.20604 .30906 L
.20772 .30918 L
.21103 .30947 L
.21422 .30978 L
Mistroke
.21583 .30991 L
.21653 .30996 L
.21728 .31 L
.21771 .31002 L
.2181 .31003 L
.21847 .31005 L
.21866 .31005 L
.21886 .31005 L
.21898 .31005 L
.21908 .31006 L
.21918 .31006 L
.21928 .31006 L
.21934 .31006 L
.2194 .31006 L
.21946 .31006 L
.21952 .31006 L
.21962 .31006 L
.21968 .31006 L
.21973 .31006 L
.21983 .31006 L
.21992 .31005 L
.22013 .31005 L
.22033 .31005 L
.22055 .31004 L
.22098 .31002 L
.22137 .31 L
.2218 .30997 L
.22226 .30994 L
.22303 .30985 L
.22388 .30974 L
.22544 .30945 L
.22712 .30903 L
.23043 .30792 L
.23362 .30667 L
.23523 .30608 L
.23669 .30564 L
.23751 .30544 L
.23828 .30531 L
.23848 .30528 L
.2387 .30526 L
.23889 .30524 L
.23909 .30523 L
.2392 .30522 L
.2393 .30521 L
.23941 .30521 L
.2395 .30521 L
.23956 .30521 L
.23962 .3052 L
.23972 .3052 L
.23978 .3052 L
Mistroke
.23984 .3052 L
.2399 .30521 L
.23996 .30521 L
.24007 .30521 L
.24016 .30522 L
.24038 .30523 L
.24058 .30525 L
.24077 .30527 L
.2412 .30533 L
.24166 .30542 L
.2425 .30567 L
.24327 .30598 L
.24478 .30683 L
.24644 .30813 L
.24968 .31162 L
.2528 .31553 L
.25439 .31736 L
.25523 .31819 L
.25612 .31894 L
.25691 .31945 L
.25736 .31967 L
.25756 .31976 L
.25778 .31983 L
.25796 .31988 L
.25816 .31993 L
.25825 .31994 L
.25835 .31996 L
.25844 .31997 L
.25852 .31997 L
.25862 .31998 L
.25871 .31998 L
.25882 .31998 L
.25887 .31998 L
.25893 .31997 L
.25902 .31997 L
.25913 .31995 L
.25922 .31994 L
.25931 .31992 L
.25951 .31988 L
.2597 .31982 L
.26011 .31965 L
.26048 .31943 L
.26084 .31918 L
.26164 .31842 L
.2625 .31732 L
.26411 .31446 L
.2658 .3104 L
.26885 .30111 L
.27055 .29554 L
.27209 .2908 L
Mistroke
.27286 .28871 L
.2737 .28674 L
.27448 .28522 L
.27522 .28416 L
.27558 .28378 L
.27577 .28362 L
.27597 .28347 L
.27619 .28336 L
.2763 .28331 L
.27641 .28328 L
.27651 .28326 L
.2766 .28325 L
.27671 .28324 L
.27681 .28324 L
.27691 .28326 L
.27696 .28327 L
.27701 .28328 L
.27712 .28331 L
.27723 .28335 L
.27743 .28347 L
.27762 .2836 L
.27807 .28406 L
.27849 .28467 L
.27927 .28623 L
.28009 .28852 L
.28157 .29429 L
.28329 .30343 L
.28491 .31389 L
.28801 .33587 L
.28959 .34607 L
.29042 .35068 L
.29131 .35478 L
.29175 .35643 L
.29217 .35773 L
.29255 .35868 L
.29274 .35907 L
.29295 .35944 L
.29315 .35971 L
.29334 .3599 L
.29344 .35998 L
.29354 .36004 L
.29359 .36006 L
.29365 .36008 L
.29375 .3601 L
.29385 .36011 L
.29393 .36009 L
.29404 .36006 L
.29413 .36001 L
.29422 .35995 L
.2943 .35989 L
Mistroke
.29449 .35968 L
.29468 .3594 L
.29486 .35907 L
.29527 .35809 L
.29564 .3569 L
.296 .35551 L
.29679 .35148 L
.29765 .34569 L
.29924 .33147 L
.30093 .31215 L
.30396 .27207 L
.30564 .25097 L
.30638 .24289 L
.30718 .23522 L
.30792 .22955 L
.30832 .22702 L
.3087 .22505 L
.3089 .22415 L
.30913 .22332 L
.30932 .22276 L
.30952 .22226 L
.30972 .22192 L
.30982 .22179 L
.30992 .2217 L
.31001 .22164 L
.3101 .22162 L
.3102 .22162 L
.31029 .22165 L
.31039 .22172 L
.31045 .22177 L
.3105 .22183 L
.31059 .22196 L
.31069 .22214 L
.31087 .22253 L
.31106 .22307 L
.31149 .22476 L
.31188 .22691 L
.3126 .23221 L
.31336 .23988 L
.31507 .26396 L
.31668 .29407 L
.31976 .36088 L
.32132 .39285 L
.32215 .40762 L
.32304 .42104 L
.32345 .42624 L
.32389 .43092 L
.32429 .43448 L
.32467 .43708 L
.32502 .43887 L
Mistroke
.32522 .4396 L
.3254 .44007 L
.3255 .44027 L
.3256 .4404 L
.3257 .44048 L
.32575 .44051 L
.32581 .44051 L
.32591 .44048 L
.32601 .44039 L
.32611 .44025 L
.3262 .44007 L
.32638 .43958 L
.32658 .43881 L
.32679 .43775 L
.32699 .43654 L
.32734 .43381 L
.32773 .43006 L
.32859 .41852 L
.32939 .40437 L
.33091 .36908 L
.33257 .32085 L
.33582 .21798 L
.33732 .17755 L
.33811 .16041 L
.33895 .14627 L
.33938 .14088 L
.3396 .13854 L
.33984 .13643 L
.34006 .13488 L
.34027 .13379 L
.34036 .13337 L
.34047 .13301 L
.34057 .13274 L
.34066 .13256 L
.34077 .13245 L
.34082 .13242 L
.34088 .13242 L
.34097 .13247 L
.34107 .1326 L
.34117 .1328 L
.34125 .13304 L
.34145 .1338 L
.34166 .13498 L
.34185 .13636 L
.34228 .14055 L
.34267 .14557 L
.34308 .15219 L
.34381 .1673 L
.34548 .21531 L
.34851 .33511 L
Mistroke
.3502 .405 L
.35174 .46078 L
.35252 .48375 L
.35325 .50092 L
.35365 .5084 L
.35401 .51395 L
.35442 .51865 L
.35464 .52056 L
.35474 .52127 L
.35485 .52192 L
.35495 .52241 L
.35504 .52278 L
.35513 .52306 L
.35522 .52324 L
.35532 .52336 L
.35541 .52337 L
.35552 .52328 L
.35557 .52318 L
.35563 .52306 L
.35573 .52273 L
.35583 .52232 L
.35605 .52104 L
.35625 .51948 L
.35645 .51741 L
.35682 .51266 L
.35716 .507 L
.35793 .48987 L
.35878 .46495 L
.35957 .43598 L
.36106 .37063 L
.36415 .2175 L
.36571 .14914 L
.36653 .11972 L
.36699 .10611 L
.36742 .09508 L
.36783 .08656 L
.36805 .0828 L
.36828 .07936 L
.36849 .07672 L
.36868 .07478 L
.36887 .07327 L
.36905 .07226 L
.36914 .07191 L
.36924 .07164 L
.36934 .07148 L
.36944 .07144 L
.36952 .0715 L
.36961 .07164 L
.3697 .0719 L
.36979 .07225 L
Mistroke
.36988 .07274 L
.36999 .07337 L
.37017 .07483 L
.37036 .07685 L
.37058 .07963 L
.37098 .08611 L
.37139 .09489 L
.37213 .1154 L
.37293 .14381 L
.37381 .18137 L
.37706 .35402 L
.37856 .43228 L
.38019 .50063 L
.38063 .51458 L
.38109 .52711 L
.38151 .53651 L
.38191 .5433 L
.3821 .54585 L
.38228 .54784 L
.38238 .54876 L
.38249 .54961 L
.38258 .55025 L
.38268 .55073 L
.38273 .55096 L
.38279 .55116 L
.38289 .55141 L
.38295 .55149 L
.38301 .55153 L
.38306 .55153 L
.38312 .55148 L
.38322 .55129 L
.38328 .55113 L
.38333 .55094 L
.38343 .55047 L
.38352 .5499 L
.38371 .54841 L
.38389 .54658 L
.3843 .54086 L
.3847 .53327 L
.38512 .52293 L
.3859 .49892 L
.3866 .47147 L
.38979 .30695 L
.39139 .21947 L
.39285 .15177 L
.39366 .12213 L
.39442 .10076 L
.39484 .09202 L
.39523 .08594 L
.39543 .08353 L
Mistroke
.39566 .08151 L
.39577 .08074 L
.39589 .0801 L
.39595 .07986 L
.396 .07967 L
.39611 .07943 L
.3962 .07933 L
.3963 .07935 L
.39639 .07949 L
.39647 .07972 L
.39657 .08008 L
.39667 .08061 L
.39688 .08211 L
.39709 .08415 L
.39731 .08694 L
.3977 .09351 L
.3981 .10205 L
.39848 .11183 L
.39918 .1343 L
.40078 .20215 L
.40226 .27765 L
.40389 .36294 L
.40542 .43325 L
.40617 .46129 L
.40689 .48281 L
.40728 .4923 L
.40771 .50062 L
.4079 .50358 L
.4081 .50626 L
.40827 .50816 L
.40846 .50982 L
.40856 .51053 L
.40867 .51114 L
.40873 .51142 L
.40878 .51163 L
.40884 .51181 L
.40889 .51194 L
.40899 .5121 L
.40909 .51214 L
.40919 .51206 L
.40928 .51185 L
.40939 .5115 L
.4095 .51097 L
.40971 .5096 L
.40995 .50731 L
.41018 .50458 L
.41055 .49868 L
.41097 .49039 L
.4118 .4683 L
.41337 .41029 L
Mistroke
.41505 .33442 L
.41665 .26122 L
.41749 .22632 L
.41838 .19432 L
.41918 .17127 L
.4196 .16146 L
.42005 .15292 L
.42027 .14965 L
.42047 .14699 L
.42067 .14483 L
.42085 .14321 L
.42102 .14201 L
.42111 .14153 L
.42121 .1411 L
.42131 .14074 L
.42141 .14051 L
.42151 .14039 L
.42159 .14038 L
.4217 .14046 L
.42179 .14064 L
.42188 .14089 L
.42197 .14126 L
.42207 .14176 L
.42218 .14241 L
.42238 .1439 L
.42272 .14753 L
.42311 .15295 L
.42396 .17004 L
.42477 .19158 L
.42788 .30417 L
.42946 .36211 L
.43029 .3884 L
.43118 .41144 L
.43163 .4207 L
.43205 .42791 L
.43243 .43308 L
.43262 .43526 L
.43284 .43725 L
.43302 .43866 L
.43322 .43982 L
.43333 .4403 L
.43344 .44064 L
.43354 .44089 L
.43363 .44104 L
.43372 .4411 L
.43382 .44109 L
.4339 .44102 L
.43399 .44087 L
.43408 .44063 L
.43418 .44029 L
Mistroke
.43437 .43943 L
.43456 .43823 L
.43477 .43659 L
.43514 .43277 L
.43558 .4268 L
.43598 .42013 L
.43767 .38107 L
.44088 .28636 L
.44234 .24901 L
.44318 .23259 L
.44359 .22613 L
.44396 .22118 L
.44435 .217 L
.44473 .21404 L
.44493 .21284 L
.44512 .212 L
.44523 .21163 L
.44533 .21137 L
.44539 .21126 L
.44545 .21116 L
.4455 .21109 L
.44555 .21104 L
.44565 .21101 L
.44576 .21105 L
.44586 .21115 L
.44595 .21131 L
.44605 .21156 L
.44617 .21193 L
.44638 .21282 L
.44659 .21406 L
.44683 .21572 L
.44724 .21955 L
.448 .229 L
.44881 .24233 L
.45028 .27228 L
.45185 .30778 L
.45358 .34306 L
.45438 .35616 L
.45481 .3622 L
.45523 .36707 L
.45561 .37084 L
.45603 .37406 L
.45622 .37519 L
.45641 .37619 L
.45658 .37688 L
.45676 .37747 L
.45687 .37773 L
.45696 .37791 L
.45706 .37804 L
.45716 .37813 L
Mistroke
.45726 .37817 L
.45735 .37816 L
.45743 .37811 L
.45752 .37802 L
.45762 .37787 L
.45773 .37765 L
.45794 .37703 L
.45815 .37625 L
.45833 .37534 L
.45871 .37307 L
.45904 .37047 L
.4598 .36296 L
.46134 .34235 L
.46301 .31599 L
.46457 .2925 L
.4654 .28199 L
.46629 .2729 L
.46672 .26942 L
.46714 .26674 L
.46751 .26489 L
.46773 .26406 L
.46792 .26346 L
.46801 .26322 L
.46812 .263 L
.4682 .26284 L
.4683 .26269 L
.46841 .26258 L
.46846 .26253 L
.46851 .2625 L
.46861 .26247 L
.46871 .26247 L
.46881 .26251 L
.46891 .26259 L
.46901 .2627 L
.4691 .26283 L
.46927 .26315 L
.46945 .26361 L
.46984 .26497 L
.4702 .26665 L
.47101 .27181 L
.47248 .28489 L
.47412 .30243 L
.47566 .31815 L
.47642 .32483 L
.47713 .33012 L
.47753 .33256 L
.47796 .33478 L
.47832 .3363 L
.47871 .33755 L
.47892 .33806 L
Mistroke
.47911 .33842 L
.4792 .33857 L
.47929 .3387 L
.47939 .3388 L
.47947 .33888 L
.47953 .33892 L
.47958 .33895 L
.47968 .33899 L
.47974 .339 L
.4798 .339 L
.47985 .339 L
.47991 .33898 L
.48001 .33894 L
.48006 .33891 L
.48011 .33887 L
.48031 .33867 L
.48041 .33852 L
.48052 .33834 L
.48072 .33794 L
.48118 .33672 L
.48157 .33532 L
.482 .33346 L
.48355 .3245 L
.48523 .31292 L
.48681 .30261 L
.48764 .2981 L
.4881 .29602 L
.48853 .29433 L
.48895 .293 L
.4894 .29186 L
.4896 .29147 L
.48981 .29113 L
.48999 .29089 L
.49018 .2907 L
.49029 .29062 L
.49038 .29056 L
.49047 .29052 L
.49057 .2905 L
.49067 .29048 L
.49072 .29048 L
.49078 .29049 L
.49088 .29051 L
.49098 .29055 L
.49107 .29059 L
.49116 .29066 L
.49133 .2908 L
.49152 .29101 L
.49172 .29129 L
.49214 .29206 L
.49254 .29301 L
Mistroke
.49329 .29525 L
.49497 .30185 L
.49644 .30821 L
.49727 .31158 L
.49805 .31437 L
.49889 .3168 L
.49965 .31847 L
.50006 .31913 L
.50046 .31959 L
.50068 .31977 L
.50088 .3199 L
.50099 .31995 L
.5011 .31999 L
.50116 .32001 L
.50122 .32002 L
.50128 .32003 L
.50133 .32003 L
.50144 .32003 L
.50153 .32002 L
.50162 .32001 L
.50171 .31998 L
.50181 .31995 L
.50192 .3199 L
.50212 .31978 L
.50246 .31949 L
.50285 .31905 L
.5037 .31767 L
.50451 .31598 L
.50761 .30816 L
.50845 .30633 L
.50922 .30491 L
.51003 .30378 L
.51046 .30334 L
.51068 .30316 L
.51091 .303 L
.51112 .30289 L
.51123 .30284 L
.51134 .3028 L
.51145 .30276 L
.51155 .30274 L
.51164 .30272 L
.51174 .30271 L
.51179 .30271 L
.51184 .30271 L
.5119 .3027 L
.51196 .30271 L
.51206 .30271 L
.51211 .30272 L
.51216 .30273 L
.51227 .30275 L
Mistroke
.51239 .30278 L
.51263 .30286 L
.51284 .30296 L
.51303 .30307 L
.51347 .30338 L
.51425 .30415 L
.51578 .30619 L
.51745 .30868 L
.51901 .3107 L
.51944 .31114 L
.5199 .31156 L
.52033 .31188 L
.52073 .31212 L
.52113 .31231 L
.52135 .31238 L
.52145 .31241 L
.52157 .31244 L
.52169 .31246 L
.52179 .31248 L
.52189 .31249 L
.52199 .3125 L
.52209 .31251 L
.52218 .31251 L
.52227 .31251 L
.52238 .31251 L
.52248 .3125 L
.52257 .31249 L
.52267 .31247 L
.52278 .31246 L
.52296 .31242 L
.52317 .31236 L
.52354 .31223 L
.52389 .31207 L
.52467 .31161 L
.5255 .31101 L
.52699 .30978 L
.52859 .30853 L
.52929 .30807 L
.53005 .30767 L
.53047 .3075 L
.53085 .30737 L
.53123 .30727 L
.53141 .30723 L
.53162 .3072 L
.53173 .30718 L
.53184 .30717 L
.53193 .30716 L
.53204 .30716 L
.5321 .30715 L
.53215 .30715 L
Mistroke
.53225 .30715 L
.53231 .30715 L
.53237 .30715 L
.53243 .30715 L
.53249 .30715 L
.53258 .30715 L
.53268 .30716 L
.53278 .30716 L
.53288 .30717 L
.5331 .3072 L
.5333 .30723 L
.53369 .30731 L
.5341 .30741 L
.53483 .30765 L
.5365 .30835 L
.53808 .30905 L
.53953 .30957 L
.54029 .30977 L
.54067 .30984 L
.54109 .30991 L
.54131 .30994 L
.54151 .30995 L
.54162 .30996 L
.54174 .30997 L
.54184 .30998 L
.54196 .30998 L
.54206 .30998 L
.54216 .30999 L
.54226 .30999 L
.54232 .30999 L
.54238 .30999 L
.54247 .30999 L
.54257 .30998 L
.54267 .30998 L
.54276 .30998 L
.54298 .30997 L
.54317 .30995 L
.54361 .30991 L
.544 .30985 L
.54441 .30979 L
.54591 .30948 L
.54751 .3091 L
.54896 .30881 L
.54977 .30868 L
.55014 .30864 L
.55054 .3086 L
.55073 .30858 L
.55095 .30856 L
.55116 .30855 L
.55134 .30854 L
Mistroke
.55156 .30854 L
.55168 .30853 L
.55173 .30853 L
.55179 .30853 L
.5519 .30853 L
.552 .30853 L
.55205 .30853 L
.55211 .30853 L
.55222 .30853 L
.55231 .30853 L
.55241 .30853 L
.5525 .30853 L
.55259 .30853 L
.5528 .30854 L
.553 .30855 L
.5534 .30857 L
.55383 .3086 L
.55531 .30874 L
.55687 .30893 L
.55769 .30902 L
.55858 .30911 L
.55943 .30918 L
.5598 .3092 L
.56021 .30922 L
.56059 .30924 L
.56095 .30925 L
.56115 .30925 L
.56133 .30925 L
.56143 .30926 L
.56148 .30926 L
.56154 .30926 L
.56164 .30926 L
.56174 .30926 L
.56183 .30926 L
.56194 .30926 L
.56204 .30926 L
.56213 .30925 L
.56231 .30925 L
.56249 .30925 L
.56271 .30924 L
.56292 .30924 L
.56331 .30923 L
.56401 .3092 L
.56478 .30916 L
.56635 .30907 L
.56718 .30902 L
.56807 .30898 L
.56893 .30894 L
.56934 .30893 L
.56971 .30892 L
Mistroke
.57009 .30891 L
.57029 .30891 L
.5705 .30891 L
.57068 .30891 L
.57085 .3089 L
.57095 .3089 L
.57104 .3089 L
.57114 .3089 L
.57125 .3089 L
.57134 .3089 L
.5714 .3089 L
.57145 .3089 L
.57155 .3089 L
.57165 .3089 L
.57182 .3089 L
.57201 .30891 L
.57244 .30891 L
.57283 .30892 L
.57354 .30893 L
.57431 .30895 L
.5759 .309 L
.57673 .30902 L
.57763 .30904 L
.57841 .30905 L
.57886 .30906 L
.57928 .30906 L
.57947 .30907 L
.57967 .30907 L
.57984 .30907 L
.58002 .30907 L
.58013 .30907 L
.58022 .30907 L
.58031 .30907 L
.5804 .30907 L
.58051 .30907 L
.5806 .30907 L
.58071 .30907 L
.58076 .30907 L
.58082 .30907 L
.58092 .30907 L
.58102 .30907 L
.58124 .30907 L
.58143 .30907 L
.58163 .30907 L
.58203 .30906 L
.58238 .30906 L
.58406 .30904 L
.58573 .30902 L
.58647 .30901 L
.58727 .309 L
Mistroke
.58765 .309 L
.58805 .309 L
.5884 .309 L
.58878 .30899 L
.589 .30899 L
.58921 .30899 L
.5894 .30899 L
.5895 .30899 L
.58956 .30899 L
.58961 .30899 L
.58971 .30899 L
.5898 .30899 L
.5899 .30899 L
.59 .30899 L
.59009 .30899 L
.59019 .30899 L
.59029 .30899 L
.59037 .30899 L
.59055 .30899 L
.59076 .30899 L
.59117 .309 L
.59191 .309 L
.59358 .30901 L
.59527 .30902 L
.59608 .30902 L
.59682 .30902 L
.59719 .30903 L
.59758 .30903 L
.59781 .30903 L
.59802 .30903 L
.59821 .30903 L
.59832 .30903 L
.59842 .30903 L
.59852 .30903 L
.5986 .30903 L
.5987 .30903 L
.5988 .30903 L
.5989 .30903 L
.59896 .30903 L
.59901 .30903 L
.59911 .30903 L
.59921 .30903 L
.5993 .30903 L
.59939 .30903 L
.59956 .30903 L
.59976 .30903 L
.59994 .30903 L
.60032 .30903 L
.60073 .30903 L
.60146 .30902 L
Mistroke
.60312 .30902 L
.60473 .30902 L
.60516 .30901 L
.60563 .30901 L
.60603 .30901 L
.60646 .30901 L
.60667 .30901 L
.60687 .30901 L
.60707 .30901 L
.60725 .30901 L
.60742 .30901 L
.60751 .30901 L
.60761 .30901 L
.6077 .30901 L
.60781 .30901 L
.6079 .30901 L
.60799 .30901 L
.60809 .30901 L
.60819 .30901 L
.60829 .30901 L
.60838 .30901 L
.6086 .30901 L
.60881 .30901 L
.60923 .30901 L
.60967 .30901 L
.61124 .30901 L
.61296 .30902 L
.61375 .30902 L
.61418 .30902 L
.61459 .30902 L
.61497 .30902 L
.61539 .30902 L
.61557 .30902 L
.61577 .30902 L
.61594 .30902 L
.61612 .30902 L
.61622 .30902 L
.61633 .30902 L
.61644 .30902 L
.6165 .30902 L
.61655 .30902 L
.61661 .30902 L
.61666 .30902 L
.61676 .30902 L
.61685 .30902 L
.61695 .30902 L
.61705 .30902 L
.61711 .30902 L
.61717 .30902 L
.61737 .30902 L
Mistroke
.6176 .30902 L
.61784 .30902 L
.61861 .30902 L
.61946 .30902 L
.62117 .30902 L
.62272 .30902 L
.62349 .30902 L
.62393 .30902 L
.62433 .30902 L
.62469 .30902 L
.62489 .30902 L
.62507 .30902 L
.62518 .30902 L
.62527 .30902 L
.62536 .30902 L
.62545 .30902 L
.62555 .30902 L
.6256 .30902 L
.62566 .30902 L
.62576 .30902 L
.62586 .30902 L
.62595 .30902 L
.62605 .30902 L
.62623 .30902 L
.62664 .30902 L
.62708 .30902 L
.62747 .30902 L
.62896 .30902 L
.63062 .30902 L
.63136 .30902 L
.63175 .30902 L
.63216 .30902 L
.63257 .30902 L
.63294 .30902 L
.63311 .30902 L
.63331 .30902 L
.63349 .30902 L
.63366 .30902 L
.63376 .30902 L
.63381 .30902 L
.63387 .30902 L
.63397 .30902 L
.63406 .30902 L
.63415 .30902 L
.63424 .30902 L
.63433 .30902 L
.63443 .30902 L
.63453 .30902 L
.63465 .30902 L
.63486 .30902 L
Mistroke
.63506 .30902 L
.63525 .30902 L
.63602 .30902 L
.63675 .30902 L
.6384 .30902 L
.63919 .30902 L
.64002 .30902 L
.64073 .30902 L
.64113 .30902 L
.64151 .30902 L
.64172 .30902 L
.64191 .30902 L
.64212 .30902 L
.64223 .30902 L
.64229 .30902 L
.64235 .30902 L
.64245 .30902 L
.64255 .30902 L
.64265 .30902 L
.64271 .30902 L
.64276 .30902 L
.64286 .30902 L
.64295 .30902 L
.64305 .30902 L
.64315 .30902 L
.64333 .30902 L
.64352 .30902 L
.64387 .30902 L
.64464 .30902 L
.64624 .30902 L
.64769 .30902 L
.64844 .30902 L
.64926 .30902 L
.64971 .30902 L
.64991 .30902 L
.65013 .30902 L
.65033 .30902 L
.65052 .30902 L
.65063 .30902 L
.65072 .30902 L
.65083 .30902 L
.65088 .30902 L
.65094 .30902 L
.65099 .30902 L
.65105 .30902 L
.65115 .30902 L
.65125 .30902 L
.65131 .30902 L
.65137 .30902 L
.65147 .30902 L
Mistroke
.65156 .30902 L
.65177 .30902 L
.65195 .30902 L
.65215 .30902 L
.65252 .30902 L
.65339 .30902 L
.6542 .30902 L
.65583 .30902 L
.65662 .30902 L
.65697 .30902 L
.65735 .30902 L
.65769 .30902 L
.65806 .30902 L
.65826 .30902 L
.65845 .30902 L
.65862 .30902 L
.65881 .30902 L
.6589 .30902 L
.65901 .30902 L
.65911 .30902 L
.6592 .30902 L
.6593 .30902 L
.6594 .30902 L
.65945 .30902 L
.65951 .30902 L
.65962 .30902 L
.65972 .30902 L
.65981 .30902 L
.66001 .30902 L
.6602 .30902 L
.66038 .30902 L
.66116 .30902 L
.66199 .30902 L
.66348 .30902 L
.66424 .30902 L
.66505 .30902 L
.66545 .30902 L
.66582 .30902 L
.66619 .30902 L
.66653 .30902 L
.66672 .30902 L
.6669 .30902 L
.66709 .30902 L
.66719 .30902 L
.6673 .30902 L
.6674 .30902 L
.66751 .30902 L
.66761 .30902 L
.6677 .30902 L
.66775 .30902 L
Mistroke
.6678 .30902 L
.66786 .30902 L
.66792 .30902 L
.66802 .30902 L
.66813 .30902 L
.66832 .30902 L
.66849 .30902 L
.66889 .30902 L
.66961 .30902 L
.67126 .30902 L
.67207 .30902 L
.6728 .30902 L
.67357 .30902 L
.67392 .30902 L
.67429 .30902 L
.67448 .30902 L
.67468 .30902 L
.67488 .30902 L
.67505 .30902 L
.67525 .30902 L
.67537 .30902 L
.67547 .30902 L
.67557 .30902 L
.67566 .30902 L
.67576 .30902 L
.67582 .30902 L
.67587 .30902 L
.67597 .30902 L
.67607 .30902 L
.67618 .30902 L
.67629 .30902 L
.6765 .30902 L
.67668 .30902 L
.67707 .30902 L
.67743 .30902 L
.6791 .30902 L
.68058 .30902 L
.68142 .30902 L
.68182 .30902 L
.6822 .30902 L
.68259 .30902 L
.68297 .30902 L
.68318 .30902 L
.68337 .30902 L
.68347 .30902 L
.68358 .30902 L
.68363 .30902 L
.68369 .30902 L
.68375 .30902 L
.6838 .30902 L
Mistroke
.6839 .30902 L
.684 .30902 L
.6841 .30902 L
.68419 .30902 L
.6843 .30902 L
.68441 .30902 L
.68462 .30902 L
.68507 .30902 L
.68549 .30902 L
.68712 .30902 L
.68792 .30902 L
.68865 .30902 L
.68935 .30902 L
.68972 .30902 L
.69012 .30902 L
.69054 .30902 L
.69072 .30902 L
.69092 .30902 L
.69113 .30902 L
.69123 .30902 L
.69133 .30902 L
.69142 .30902 L
.69152 .30902 L
.69161 .30902 L
.69169 .30902 L
.69179 .30902 L
.69184 .30902 L
.6919 .30902 L
.692 .30902 L
.69209 .30902 L
.6922 .30902 L
.69231 .30902 L
.69253 .30902 L
.69292 .30902 L
.69333 .30902 L
.69482 .30902 L
.69564 .30902 L
.69642 .30902 L
.69718 .30902 L
.69788 .30902 L
.69825 .30902 L
.69864 .30902 L
.69884 .30902 L
.69903 .30902 L
.69913 .30902 L
.69924 .30902 L
.69929 .30902 L
.69935 .30902 L
.69946 .30902 L
.69956 .30902 L
Mistroke
.69966 .30902 L
.69971 .30902 L
.69977 .30902 L
.69982 .30902 L
.69988 .30902 L
.69993 .30902 L
.69999 .30902 L
.7001 .30902 L
.70033 .30902 L
.70055 .30902 L
.70075 .30902 L
.70114 .30902 L
.70261 .30902 L
.70344 .30902 L
.70422 .30902 L
.70506 .30902 L
.70542 .30902 L
.70582 .30902 L
.70603 .30902 L
.70623 .30902 L
.70644 .30902 L
.70663 .30902 L
.70674 .30902 L
.70685 .30902 L
.70695 .30902 L
.70705 .30902 L
.70717 .30902 L
.70723 .30902 L
.70729 .30902 L
.70739 .30902 L
.70745 .30902 L
.70751 .30902 L
.7076 .30902 L
.70769 .30902 L
.70779 .30902 L
.70789 .30902 L
.70811 .30902 L
.7083 .30902 L
.70866 .30902 L
.70904 .30902 L
.71071 .30902 L
.71153 .30902 L
.71231 .30902 L
.71301 .30902 L
.71337 .30902 L
.71377 .30902 L
.71416 .30902 L
.71438 .30902 L
.71458 .30902 L
.71468 .30902 L
Mistroke
.71478 .30902 L
.71486 .30902 L
.71495 .30902 L
.71505 .30902 L
.71515 .30902 L
.71525 .30902 L
.71534 .30902 L
.71545 .30902 L
.7155 .30902 L
.71556 .30902 L
.71576 .30902 L
.71599 .30902 L
.71621 .30902 L
.71702 .30902 L
.71852 .30902 L
.71931 .30902 L
.72015 .30902 L
.72057 .30902 L
.72104 .30902 L
.72146 .30902 L
.72186 .30902 L
.72207 .30902 L
.72217 .30902 L
.72227 .30902 L
.72236 .30902 L
.72244 .30902 L
.72254 .30902 L
.72264 .30902 L
.72269 .30902 L
.72275 .30902 L
.72284 .30902 L
.7229 .30902 L
.72295 .30902 L
.72301 .30902 L
.72307 .30902 L
.72318 .30902 L
.72328 .30902 L
.72348 .30902 L
.72367 .30902 L
.72384 .30902 L
.72425 .30902 L
.72507 .30902 L
.72655 .30902 L
.72734 .30902 L
.72817 .30902 L
.72851 .30902 L
.72888 .30902 L
.72909 .30902 L
.72928 .30902 L
.72947 .30902 L
Mistroke
.72965 .30902 L
.72984 .30902 L
.72994 .30902 L
.73004 .30902 L
.7301 .30902 L
.73015 .30902 L
.73026 .30902 L
.73036 .30902 L
.73046 .30902 L
.73055 .30902 L
.73064 .30902 L
.73072 .30902 L
.73081 .30902 L
.73101 .30902 L
.73119 .30902 L
.73158 .30902 L
.73201 .30902 L
.73286 .30902 L
.73456 .30902 L
.73537 .30902 L
.73611 .30902 L
.73648 .30902 L
.73688 .30902 L
.73708 .30902 L
.73728 .30902 L
.73739 .30902 L
.73749 .30902 L
.7376 .30902 L
.73765 .30902 L
.73772 .30902 L
.73782 .30902 L
.73792 .30902 L
.738 .30902 L
.7381 .30902 L
.7382 .30902 L
.73831 .30902 L
.7385 .30902 L
.73868 .30902 L
.73885 .30902 L
.73924 .30902 L
.74087 .30902 L
.74235 .30902 L
.74274 .30902 L
.74315 .30902 L
.7435 .30902 L
.74388 .30902 L
.7441 .30902 L
.74429 .30902 L
.74449 .30902 L
.74467 .30902 L
Mistroke
.74478 .30902 L
.74488 .30902 L
.74499 .30902 L
.74504 .30902 L
.7451 .30902 L
.74515 .30902 L
.74521 .30902 L
.74527 .30902 L
.74533 .30902 L
.74538 .30902 L
.74544 .30902 L
.74555 .30902 L
.7456 .30902 L
.74566 .30902 L
.74575 .30902 L
.74597 .30902 L
.74616 .30902 L
.74636 .30902 L
.74725 .30902 L
.74886 .30902 L
.74969 .30902 L
.75046 .30902 L
.75085 .30902 L
.75126 .30902 L
.7515 .30902 L
.75173 .30902 L
.75193 .30902 L
.75204 .30902 L
.75215 .30902 L
.75224 .30902 L
.75234 .30902 L
.75243 .30902 L
.75254 .30902 L
.75263 .30902 L
.75273 .30902 L
.75282 .30902 L
.7529 .30902 L
.75296 .30902 L
.75301 .30902 L
.75311 .30902 L
.75333 .30902 L
.75352 .30902 L
.75374 .30902 L
.75461 .30902 L
.75542 .30902 L
.75691 .30902 L
.75732 .30902 L
.75776 .30902 L
.75813 .30902 L
.75854 .30902 L
Mistroke
.75878 .30902 L
.759 .30902 L
.75921 .30902 L
.75932 .30902 L
.75943 .30902 L
.75954 .30902 L
.75963 .30902 L
.75973 .30902 L
.75982 .30902 L
.75992 .30902 L
.76002 .30902 L
.76007 .30902 L
.76013 .30902 L
.76018 .30902 L
.76024 .30902 L
.76033 .30902 L
.76044 .30902 L
.76064 .30902 L
.76084 .30902 L
.76102 .30902 L
.76185 .30902 L
.76336 .30902 L
.76415 .30902 L
.76499 .30902 L
.76542 .30902 L
.76564 .30902 L
.76588 .30902 L
.76611 .30902 L
.76631 .30902 L
.76651 .30902 L
.76671 .30902 L
.7668 .30902 L
.7669 .30902 L
.76695 .30902 L
.76701 .30902 L
.76711 .30902 L
.7672 .30902 L
.7673 .30902 L
.76739 .30902 L
.76748 .30902 L
.76759 .30902 L
.76769 .30902 L
.76792 .30902 L
.76813 .30902 L
.76833 .30902 L
.7691 .30902 L
.76993 .30902 L
.77141 .30902 L
.77217 .30902 L
.77259 .30902 L
Mistroke
.77298 .30902 L
.77334 .30902 L
.77354 .30902 L
.77373 .30902 L
.77383 .30902 L
.77392 .30902 L
.774 .30902 L
.77408 .30902 L
.77417 .30902 L
.77426 .30902 L
.77435 .30902 L
.77445 .30902 L
.77455 .30902 L
.77465 .30902 L
.77476 .30902 L
.77487 .30902 L
.77506 .30902 L
.77527 .30902 L
.77566 .30902 L
.77602 .30902 L
.7777 .30902 L
.77849 .30902 L
.77892 .30902 L
.77932 .30902 L
.77969 .30902 L
.78003 .30902 L
.7804 .30902 L
.78061 .30902 L
.7808 .30902 L
.7809 .30902 L
.781 .30902 L
.78108 .30902 L
.78118 .30902 L
.78123 .30902 L
.78128 .30902 L
.78139 .30902 L
.78148 .30902 L
.78158 .30902 L
.78164 .30902 L
.78169 .30902 L
.78181 .30902 L
.78191 .30902 L
.78202 .30902 L
.78221 .30902 L
.78241 .30902 L
.78318 .30902 L
.78389 .30902 L
.78539 .30902 L
.7858 .30902 L
.78624 .30902 L
Mistroke
.78662 .30902 L
.78702 .30902 L
.78724 .30902 L
.78744 .30902 L
.78765 .30902 L
.78783 .30902 L
.78795 .30902 L
.78805 .30902 L
.78817 .30902 L
.78823 .30902 L
.78829 .30902 L
.78835 .30902 L
.7884 .30902 L
.7885 .30902 L
.78856 .30902 L
.78861 .30902 L
.78867 .30902 L
.78873 .30902 L
.78878 .30902 L
.78884 .30902 L
.78894 .30902 L
.78916 .30902 L
.78936 .30902 L
.78958 .30902 L
.79035 .30902 L
.79203 .30902 L
.79277 .30902 L
.79316 .30902 L
.79357 .30902 L
.79398 .30902 L
.79436 .30902 L
.79454 .30902 L
.79473 .30902 L
.79492 .30902 L
.79509 .30902 L
.79518 .30902 L
.79528 .30902 L
.79537 .30902 L
.79545 .30902 L
.79555 .30902 L
.79561 .30902 L
.79566 .30902 L
.79576 .30902 L
.79586 .30902 L
.79597 .30902 L
.79608 .30902 L
.79629 .30902 L
.79668 .30902 L
.79744 .30902 L
.79828 .30902 L
Mistroke
.79917 .30902 L
.79997 .30902 L
.80036 .30902 L
.80078 .30902 L
.80117 .30902 L
.80154 .30902 L
.80174 .30902 L
.80193 .30902 L
.80204 .30902 L
.80213 .30902 L
.80219 .30902 L
.80224 .30902 L
.8023 .30902 L
.80236 .30902 L
.80241 .30902 L
.80247 .30902 L
.80252 .30902 L
.80257 .30902 L
.80267 .30902 L
.80277 .30902 L
.80288 .30902 L
.80299 .30902 L
.80322 .30902 L
.80362 .30902 L
.80406 .30902 L
.80485 .30902 L
.80634 .30902 L
.80709 .30902 L
.80752 .30902 L
.80792 .30902 L
.80813 .30902 L
.80835 .30902 L
.80853 .30902 L
.80874 .30902 L
.80885 .30902 L
.80895 .30902 L
.80901 .30902 L
.80907 .30902 L
.80913 .30902 L
.80919 .30902 L
.80929 .30902 L
.80934 .30902 L
.80939 .30902 L
.8095 .30902 L
.80956 .30902 L
.80961 .30902 L
.80971 .30902 L
.80981 .30902 L
.80999 .30902 L
.8104 .30902 L
Mistroke
.81113 .30902 L
.8128 .30902 L
.81358 .30902 L
.81401 .30902 L
.81441 .30902 L
.81475 .30902 L
.81512 .30902 L
.81533 .30902 L
.81552 .30902 L
.8157 .30902 L
.8158 .30902 L
.81589 .30902 L
.81599 .30902 L
.81609 .30902 L
.81617 .30902 L
.81627 .30902 L
.81637 .30902 L
.81642 .30902 L
.81647 .30902 L
.81667 .30902 L
.81685 .30902 L
.81704 .30902 L
.81739 .30902 L
.81905 .30902 L
.81987 .30902 L
.82064 .30902 L
.82103 .30902 L
.82145 .30902 L
.82168 .30902 L
.82191 .30902 L
.82211 .30902 L
.82223 .30902 L
.82233 .30902 L
.82243 .30902 L
.82254 .30902 L
.82264 .30902 L
.8227 .30902 L
.82276 .30902 L
.82286 .30902 L
.82295 .30902 L
.823 .30902 L
.82306 .30902 L
.82316 .30902 L
.82325 .30902 L
.82335 .30902 L
.82355 .30902 L
.82391 .30902 L
.82433 .30902 L
.82478 .30902 L
.8256 .30902 L
Mistroke
.82641 .30902 L
.82684 .30902 L
.82729 .30902 L
.82773 .30902 L
.82813 .30902 L
.82832 .30902 L
.82853 .30902 L
.82873 .30902 L
.82891 .30902 L
.8291 .30902 L
.8292 .30902 L
.8293 .30902 L
.82939 .30902 L
.82948 .30902 L
.82957 .30902 L
.82967 .30902 L
.82977 .30902 L
.82982 .30902 L
.82987 .30902 L
.82997 .30902 L
.83006 .30902 L
.83027 .30902 L
.8305 .30902 L
.83093 .30902 L
.83138 .30902 L
.83219 .30902 L
.83302 .30902 L
.83345 .30902 L
.83391 .30902 L
.83431 .30902 L
.83475 .30902 L
.83494 .30902 L
.83515 .30902 L
.83535 .30902 L
.83552 .30902 L
.83573 .30902 L
.83584 .30902 L
.83594 .30902 L
.83604 .30902 L
.83613 .30902 L
.83623 .30902 L
.83634 .30902 L
.83644 .30902 L
.8365 .30902 L
.83655 .30902 L
.83666 .30902 L
.83676 .30902 L
.83698 .30902 L
.83722 .30902 L
.83763 .30902 L
Mistroke
.83806 .30902 L
.83883 .30902 L
.83961 .30902 L
.84042 .30902 L
.84111 .30902 L
.8415 .30902 L
.84187 .30902 L
.84207 .30902 L
.84226 .30902 L
.84243 .30902 L
.84253 .30902 L
.84262 .30902 L
.84272 .30902 L
.8428 .30902 L
.8429 .30902 L
.84301 .30902 L
.84306 .30902 L
.84312 .30902 L
.84322 .30902 L
.84333 .30902 L
.84342 .30902 L
.84364 .30902 L
.84385 .30902 L
.84423 .30902 L
.8451 .30902 L
.84658 .30902 L
.84698 .30902 L
.84742 .30902 L
.84779 .30902 L
.8482 .30902 L
.84842 .30902 L
.84863 .30902 L
.84883 .30902 L
.84893 .30902 L
.84904 .30902 L
.84914 .30902 L
.84923 .30902 L
.84932 .30902 L
.8494 .30902 L
.8495 .30902 L
.84959 .30902 L
.84969 .30902 L
.84975 .30902 L
.8498 .30902 L
.85002 .30902 L
.85022 .30902 L
.85067 .30902 L
.8515 .30902 L
.85229 .30902 L
.85313 .30902 L
Mistroke
.85355 .30902 L
.85393 .30902 L
.85428 .30902 L
.85466 .30902 L
.85503 .30902 L
.85523 .30902 L
.85542 .30902 L
.85551 .30902 L
.8556 .30902 L
.85568 .30902 L
.85576 .30902 L
.85585 .30902 L
.85593 .30902 L
.85603 .30902 L
.85612 .30902 L
.85622 .30902 L
.85633 .30902 L
.85642 .30902 L
.85652 .30902 L
.85674 .30902 L
.85694 .30902 L
.85771 .30902 L
.8592 .30902 L
.85999 .30902 L
.86042 .30902 L
.86083 .30902 L
.86105 .30902 L
.86129 .30902 L
.86149 .30902 L
.86171 .30902 L
.86192 .30902 L
.86203 .30902 L
.86214 .30902 L
.86223 .30902 L
.86233 .30902 L
.86243 .30902 L
.86253 .30902 L
.86262 .30902 L
.86272 .30902 L
.86277 .30902 L
.86283 .30902 L
.86293 .30902 L
.86312 .30902 L
.8633 .30902 L
.86371 .30902 L
.86414 .30902 L
.86575 .30902 L
.86645 .30902 L
.86681 .30902 L
.8672 .30902 L
Mistroke
.86741 .30902 L
.86763 .30902 L
.86802 .30902 L
.86821 .30902 L
.86831 .30902 L
.86841 .30902 L
.8685 .30902 L
.8686 .30902 L
.8687 .30902 L
.86878 .30902 L
.86888 .30902 L
.86898 .30902 L
.86908 .30902 L
.86917 .30902 L
.86927 .30902 L
.86938 .30902 L
.8696 .30902 L
.86981 .30902 L
.87005 .30902 L
.87046 .30902 L
.87206 .30902 L
.8729 .30902 L
.87332 .30902 L
.87379 .30902 L
.87421 .30902 L
.87444 .30902 L
.87465 .30902 L
.87475 .30902 L
.87485 .30902 L
.87496 .30902 L
.87507 .30902 L
.87517 .30902 L
.87527 .30902 L
.87536 .30902 L
.87546 .30902 L
.87556 .30902 L
.87564 .30902 L
.87574 .30902 L
.87585 .30902 L
.87626 .30902 L
.87665 .30902 L
.877 .30902 L
.8778 .30902 L
.87866 .30902 L
.87939 .30902 L
.87981 .30902 L
.8802 .30902 L
.88057 .30902 L
.88076 .30902 L
.88096 .30902 L
Mistroke
.88107 .30902 L
.88117 .30902 L
.88128 .30902 L
.88139 .30902 L
.88149 .30902 L
.88158 .30902 L
.88168 .30902 L
.88179 .30902 L
.88188 .30902 L
.88196 .30902 L
.88206 .30902 L
.88215 .30902 L
.88249 .30902 L
.88287 .30902 L
.88328 .30902 L
.88416 .30902 L
.88499 .30902 L
.88574 .30902 L
.88616 .30902 L
.88654 .30902 L
.88673 .30902 L
.88692 .30902 L
.88709 .30902 L
.88727 .30902 L
.88739 .30902 L
.88749 .30902 L
.88759 .30902 L
.88769 .30902 L
.88779 .30902 L
.88787 .30902 L
.88797 .30902 L
.88807 .30902 L
.88813 .30902 L
.88818 .30902 L
.88828 .30902 L
.8884 .30902 L
.88851 .30902 L
.88892 .30902 L
.88932 .30902 L
.88969 .30902 L
.89116 .30902 L
.89157 .30902 L
.892 .30902 L
.89238 .30902 L
.89278 .30902 L
.89301 .30902 L
.89321 .30902 L
.89341 .30902 L
.89351 .30902 L
.89362 .30902 L
Mistroke
.89372 .30902 L
.89381 .30902 L
.89389 .30902 L
.89398 .30902 L
.89408 .30902 L
.89417 .30902 L
.89427 .30902 L
.89433 .30902 L
.89438 .30902 L
.89449 .30902 L
.89454 .30902 L
.8946 .30902 L
.8948 .30902 L
.89503 .30902 L
.89525 .30902 L
.89607 .30902 L
.89756 .30902 L
.89797 .30902 L
.89841 .30902 L
.89878 .30902 L
.89919 .30902 L
.89943 .30902 L
.89965 .30902 L
.89986 .30902 L
.89996 .30902 L
.90008 .30902 L
.90018 .30902 L
.90028 .30902 L
.90033 .30902 L
.90039 .30902 L
.9005 .30902 L
.90059 .30902 L
.9007 .30902 L
.90079 .30902 L
.90089 .30902 L
.9011 .30902 L
.90129 .30902 L
.90172 .30902 L
.9025 .30902 L
.9033 .30902 L
.90415 .30902 L
.90456 .30902 L
.90495 .30902 L
.9053 .30902 L
.9055 .30902 L
.90568 .30902 L
.90586 .30902 L
.90605 .30902 L
.90616 .30902 L
.90626 .30902 L
Mistroke
.90636 .30902 L
.90646 .30902 L
.90656 .30902 L
.90661 .30902 L
.90666 .30902 L
.90677 .30902 L
.90683 .30902 L
.90688 .30902 L
.90697 .30902 L
.90707 .30902 L
.90728 .30902 L
.90764 .30902 L
.90804 .30902 L
.90874 .30902 L
.90952 .30902 L
.91034 .30902 L
.91077 .30902 L
.91124 .30902 L
.91145 .30902 L
.91167 .30902 L
.91186 .30902 L
.91207 .30902 L
.91218 .30902 L
.91228 .30902 L
.91239 .30902 L
.91248 .30902 L
.91254 .30902 L
.91259 .30902 L
.9127 .30902 L
.91275 .30902 L
.91281 .30902 L
.91287 .30902 L
.91293 .30902 L
.91304 .30902 L
.91315 .30902 L
.91336 .30902 L
.91356 .30902 L
.91375 .30902 L
.91528 .30902 L
.916 .30902 L
.91678 .30902 L
.91722 .30902 L
.91742 .30902 L
.91763 .30902 L
.91782 .30902 L
.91802 .30902 L
.91813 .30902 L
.91823 .30902 L
.91833 .30902 L
.91843 .30902 L
Mistroke
.91852 .30902 L
.91861 .30902 L
.91867 .30902 L
.91872 .30902 L
.91882 .30902 L
.91892 .30902 L
.91902 .30902 L
.91912 .30902 L
.91918 .30902 L
.91923 .30902 L
.91941 .30902 L
.91961 .30902 L
.91997 .30902 L
.92164 .30902 L
.92247 .30902 L
.92287 .30902 L
.92324 .30902 L
.92363 .30902 L
.92385 .30902 L
.92405 .30902 L
.92416 .30902 L
.92427 .30902 L
.92437 .30902 L
.92447 .30902 L
.92453 .30902 L
.92459 .30902 L
.92469 .30902 L
.92475 .30902 L
.92481 .30902 L
.92488 .30902 L
.92493 .30902 L
.92504 .30902 L
.92509 .30902 L
.92515 .30902 L
.92525 .30902 L
.92534 .30902 L
.92555 .30902 L
.92578 .30902 L
.92658 .30902 L
.92807 .30902 L
.92889 .30902 L
.92935 .30902 L
.92957 .30902 L
.92978 .30902 L
.92997 .30902 L
.93015 .30902 L
.93035 .30902 L
.93045 .30902 L
.93056 .30902 L
.93066 .30902 L
Mistroke
.93071 .30902 L
.93076 .30902 L
.93086 .30902 L
.93096 .30902 L
.93101 .30902 L
.93106 .30902 L
.93116 .30902 L
.93122 .30902 L
.93127 .30902 L
.93139 .30902 L
.9316 .30902 L
.93179 .30902 L
.93223 .30902 L
.93302 .30902 L
.93373 .30902 L
.93451 .30902 L
.93495 .30902 L
.93535 .30902 L
.93574 .30902 L
.93594 .30902 L
.93615 .30902 L
.93625 .30902 L
.93635 .30902 L
.93644 .30902 L
.93653 .30902 L
.93663 .30902 L
.93672 .30902 L
.93682 .30902 L
.93687 .30902 L
.93693 .30902 L
.93701 .30902 L
.93711 .30902 L
.93719 .30902 L
.93727 .30902 L
.93747 .30902 L
.93765 .30902 L
.93805 .30902 L
.93849 .30902 L
.93929 .30902 L
.94006 .30902 L
.94078 .30902 L
.94115 .30902 L
.94154 .30902 L
.94177 .30902 L
.94198 .30902 L
.94217 .30902 L
.94238 .30902 L
.9425 .30902 L
.94255 .30902 L
.9426 .30902 L
Mistroke
.9427 .30902 L
.94281 .30902 L
.94291 .30902 L
.94297 .30902 L
.94303 .30902 L
.94308 .30902 L
.94314 .30902 L
.94326 .30902 L
.94346 .30902 L
.94368 .30902 L
.94407 .30902 L
.94563 .30902 L
.94646 .30902 L
.94692 .30902 L
.94735 .30902 L
.94775 .30902 L
.94798 .30902 L
.94808 .30902 L
.94819 .30902 L
.94828 .30902 L
.94839 .30902 L
.94848 .30902 L
.94857 .30902 L
.94867 .30902 L
.94877 .30902 L
.94882 .30902 L
.94888 .30902 L
.94898 .30902 L
.94908 .30902 L
.94918 .30902 L
.94939 .30902 L
.94958 .30902 L
.94978 .30902 L
.95051 .30902 L
.95128 .30902 L
.95209 .30902 L
.95278 .30902 L
.95317 .30902 L
.95354 .30902 L
.95374 .30902 L
.95393 .30902 L
.9541 .30902 L
.9542 .30902 L
.95429 .30902 L
.95438 .30902 L
.95447 .30902 L
.95457 .30902 L
.95468 .30902 L
.95473 .30902 L
.95479 .30902 L
Mistroke
.95489 .30902 L
.95499 .30902 L
.95509 .30902 L
.95531 .30902 L
.95552 .30902 L
.9559 .30902 L
.95676 .30902 L
.95748 .30902 L
.95824 .30902 L
.95868 .30902 L
.95908 .30902 L
.95927 .30902 L
.95948 .30902 L
.95968 .30902 L
.95986 .30902 L
.96005 .30902 L
.96016 .30902 L
.96021 .30902 L
.96027 .30902 L
.96032 .30902 L
.96037 .30902 L
.96043 .30902 L
.96049 .30902 L
.96054 .30902 L
.9606 .30902 L
.96069 .30902 L
.96079 .30902 L
.96089 .30902 L
.96106 .30902 L
.96125 .30902 L
.96146 .30902 L
.96316 .30902 L
.96396 .30902 L
.96435 .30902 L
.96472 .30902 L
.96514 .30902 L
.96536 .30902 L
.9656 .30902 L
.96569 .30902 L
.96579 .30902 L
.96588 .30902 L
.96598 .30902 L
.96608 .30902 L
.96614 .30902 L
.9662 .30902 L
.96629 .30902 L
.9664 .30902 L
.9665 .30902 L
.96655 .30902 L
.9666 .30902 L
Mistroke
.96671 .30902 L
.96682 .30902 L
.96703 .30902 L
.96722 .30902 L
.96811 .30902 L
.96895 .30902 L
.96973 .30902 L
.97011 .30902 L
.97046 .30902 L
.97066 .30902 L
.97088 .30902 L
.97107 .30902 L
.97125 .30902 L
.97145 .30902 L
.97156 .30902 L
.97167 .30902 L
.97173 .30902 L
.97179 .30902 L
.97185 .30902 L
.9719 .30902 L
.97196 .30902 L
.97201 .30902 L
.97212 .30902 L
.97222 .30902 L
.97231 .30902 L
.97242 .30902 L
.97253 .30902 L
.97271 .30902 L
.97291 .30902 L
.97334 .30902 L
.97374 .30902 L
.97449 .30902 L
.97536 .30902 L
.97617 .30902 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{421.375, 260.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008>0001AB000`400?l00000o`00003ooooooooo
oooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo
003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooo
oooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool0
0?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooooooo
ool@ooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooo
ooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo0ol0003o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0
003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo
00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`
ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLoooo
o`00<?ooool3o`000?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?oo
ool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0
033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomco
oooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooo
oooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool3o`000?oooooo
g?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3o
ooooomcooooo000`ooooo`03o`000?oooooooooo06gooooo0_l0003oooooofgooooo000`ooooo`03
o`000?oooooooooo06gooooo0_l0003oooooofgooooo000`ooooo`03o`000?oooooooooo06gooooo
0_l0003oooooofgooooo000`ooooo`03o`000?oooooooooo06gooooo0_l0003oooooofgooooo000@
ooooo`;ok^k^0oooool2onk^kQWooooo00?o0000ooooooooool0KOooool2o`0000[ooooo00?o0000
ooooooooool0oooooomPooooo`002oooool2o`00000:oa0@4?ooooooooooonk^k_mEEEGok^k^oooo
ooo^k^koEEEEonk^kP?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^2_oo
ool00ol0003oooooooooo`1]ooooo`;o00002_ooool00ol0003oooooooooo`3oooooof3ooooo000<
ooooo`03o`000?oooooooooo00;ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0:ooooo`03o`000?oooooooooo06gooooo
0_l0000:ooooo`;o0000oooooomQooooo`0000?oooooo`000?l000001?l00002ooooo`Go00001?oo
ool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooo
oa0@400:ooooo`03o`000?oooooooooo06gooooo0_l0000:ooooo`;o0000oooooomQooooo`002Ooo
ool01?m4A4CogMgMooooool00004ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000002_ooool00ol0003oooooooooo`1]oooo
o`;o00002_ooool2o`000?ooooooHOooool000Wooooo00CogMgMoeEEEOoooooo00000oooool01oo^
k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000002_ooool4o`0006cooooo0_l0000:ooooo`;o0000oooooomQooooo`002_oo
ool00omgMgOoc<c<o`000003ooooo`;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@00[ooooo00?o0000ooooooooool0KOooool2o`0000[ooooo
0_l0003oooooof7ooooo000:ooooo`03onk^k_m4A4Co000000oooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo0_l00005ooooo`03o`000?oooooooooo06gooooo
0_l0000:ooooo`;o0000oooooomQooooo`002oooool00omgMgOo0000ooooo`0<ooooo`03oeEEEOmV
IVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`04o`000?ooooooooooo`0000Co
oooo00?o0000ooooooooool0KOooool2o`0000Wooooo00?o0000ooooool00000oooooomQooooo`00
:?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo06cooooo00?o0000ooooool0
00002Oooool00ol0003oooooo`00003oooooof7ooooo000Xooooo`?o00001Oooool00ol0003ooooo
ooooo`1/ooooo`03o`000?oooooo000000Wooooo00?o0000ooooool00000oooooomQooooo`00:Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06cooooo00Co0000oooooooooooo0000
2?ooool00ol0003oooooo`00003oooooof7ooooo000Zooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0K?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?oooooo
HOooool0033ooooo00?o0000ooooooooool0K?ooool01?l0003oooooooooool00008ooooo`03o`00
0?oooooo00000?ooooooHOooool0033ooooo00?o0000ooooooooool0K?ooool01?l0003ooooooooo
ool00008ooooo`03o`000?oooooo00000?ooooooHOooool0033ooooo00?o0000ooooooooool0K?oo
ool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?ooooooHOooool0033ooooo00?o
0000ooooooooool0K?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?oooooo
HOooool0033ooooo0ol0001/ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000
oooooomQooooo`00<?ooool00ol0003oooooooooo`1/ooooo`04o`000?ooooooooooo`0000Sooooo
00?o0000ooooool00000oooooomQooooo`00<?ooool00ol0003oooooooooo`1/ooooo`04o`000?oo
ooooooooo`0000Sooooo00?o0000ooooool00000oooooomQooooo`00<?ooool00ol0003ooooooooo
o`1/ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooomQooooo`00<?oo
ool00ol0003oooooooooo`1/ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000
oooooomQooooo`00<?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo00Sooooo00Co
0000oooooooooooo00002?ooool00ol0003oooooo`00003oooooof7ooooo000`ooooo`03o`000?oo
oooooooo067ooooo00?o0000ooooooooool02?ooool01?l0003oooooooooool00008ooooo`03o`00
0?oooooo00000?ooooooHOooool0033ooooo00?o0000ooooooooool0HOooool2o`0000Wooooo00Co
0000oooooooooooo00002?ooool00ol0003oooooo`00003oooooof7ooooo000`ooooo`03o`000?oo
oooooooo067ooooo0_l00009ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000
oooooomQooooo`00<?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo000000Wooooo00Co
0000oooooooooooo00002?ooool00ol0003oooooo`000009ooooo`03o`000?oooooooooo0?oooooo
EOooool0033ooooo00?o0000ooooooooool0H?ooool00ol0003oooooo`000009ooooo`04o`000?oo
ooooooooo`0000Sooooo00?o0000ooooool000002Oooool00ol0003oooooooooo`3ooooooeGooooo
000`ooooo`03o`000?oooooooooo063ooooo00?o0000ooooool000002Oooool01?l0003ooooooooo
ool00008ooooo`03o`000?oooooo000000Wooooo0_l0003ooooooeKooooo000`ooooo`?o0000H?oo
ool00ol0003oooooo`000009ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000
2Oooool2o`000?ooooooE_ooool0033ooooo00?o0000ooooooooool0H?ooool00ol0003oooooo`00
0009ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool000002Oooool2o`000?oooooo
E_ooool0033ooooo00?o0000ooooooooool0H?ooool00ol0003oooooo`000009ooooo`04o`000?oo
ooooooooo`0000Sooooo00?o0000ooooool000002Oooool2o`000?ooooooE_ooool0033ooooo00?o
0000ooooooooool0H?ooool00ol0003oooooo`000009ooooo`04o`000?ooooooooooo`0000Sooooo
00?o0000ooooool000002Oooool2o`000?ooooooE_ooool0033ooooo00?o0000ooooooooool0H?oo
ool00ol0003oooooo`000009ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000
2Oooool2o`000?ooooooE_ooool0033ooooo00?o0000ooooooooool0H?ooool00ol0003oooooo`00
0009ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool000002?ooool00ol0003ooooo
o`00003ooooooeKooooo000`ooooo`03o`000?oooooooooo063ooooo00?o0000ooooool000002Ooo
ool01?l0003oooooooooool00008ooooo`03o`000?oooooo000000Sooooo00?o0000ooooool00000
oooooomFooooo`00<?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo000000Wooooo00Co
0000oooooooooooo00002?ooool00ol0003oooooo`000008ooooo`03o`000?oooooo00000?oooooo
E_ooool0033ooooo00?o0000ooooooooool0H?ooool00ol0003oooooo`000009ooooo`04o`000?oo
ooooooooo`0000Sooooo00?o0000ooooool000002?ooool00ol0003oooooo`00003ooooooeKooooo
000`ooooo`03o`000?oooooooooo063ooooo00?o0000ooooool000002Oooool01?l0003ooooooooo
ool00008ooooo`03o`000?oooooo000000Sooooo00?o0000ooooool00000oooooomFooooo`00<?oo
ool00ol0003oooooooooo`1Pooooo`03o`000?oooooo000000Wooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool00007ooooo`03o`000?oooooo00000?ooooooE_ooool0033ooooo
0ol0001Pooooo`03o`000?oooooo000000Wooooo00Co0000oooooooooooo00002?ooool01?l0003o
ooooooooool00007ooooo`03o`000?oooooo00000?ooooooE_ooool0033ooooo00?o0000oooooooo
ool0H?ooool00ol0003oooooo`000009ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooo
oooooooo00001oooool00ol0003oooooo`00003ooooooeKooooo000`ooooo`03o`000?oooooooooo
063ooooo00?o0000ooooool000002Oooool01?l0003oooooooooool00008ooooo`04o`000?oooooo
ooooo`0000Oooooo00?o0000ooooool00000oooooomFooooo`00<?ooool00ol0003oooooooooo`1P
ooooo`03o`000?oooooo000000Wooooo00Co0000oooooooooooo00002?ooool01?l0003ooooooooo
ool00007ooooo`03o`000?oooooo00000?ooooooE_ooool0033ooooo00?o0000ooooooooool0H?oo
ool00ol0003oooooo`000009ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo
00001oooool01?l0003oooooooooool0003ooooooeGooooo000`ooooo`03o`000?oooooooooo063o
oooo00?o0000ooooool000002Oooool01?l0003oooooooooool00008ooooo`04o`000?oooooooooo
o`0000Oooooo00Co0000oooooooooooo0000oooooomEooooo`00<?ooool00ol0003oooooooooo`1P
ooooo`03o`000?oooooo000000Sooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oo
ooooooooooooool000001oooool01?l0003oooooooooool0003ooooooeGooooo000@ooooo`;ok^k^
0oooool2onk^kQWooooo00?o0000ooooooooool0H?ooool00ol0003oooooo`000008ooooo`05o`00
0?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooo
oooooooo0000oooooomEooooo`002Oooool5o`0000;ooooo00Ook^k^oeEEEOo^k^koooooonk^k_mE
EEGok^k^00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^2_ooool00ol0
003oooooooooo`1Pooooo`03o`000?oooooo000000Sooooo00Go0000ooooooooooooooooo`000007
ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool0003ooooooeGooooo
0009ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Ko
oooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00[ooooo00?o0000oooo
ooooool0H?ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001ooo
ool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000oooooomEooooo`00
00?oooooo`000?l000001?l00003ooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?ogMgMo`000?oMgMd0
1oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41002_ooool00ol0003o
ooooooooo`1Pooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000007
ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool0003ooooooeGooooo
000;ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000:ooooo`03o`000?oooooooooo063o
oooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000
ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`000?ooooooEOooool000cooooo00_o
MgMgofIVI_ooooooooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`00000:ooooo`Co0000G_ooool01Ol0003ooooooooo
oooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooooooooooo
ool000001oooool01?l0003oooooooooool0003ooooooeGooooo000=ooooo`03o`000?oooooooooo
00;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@00[ooooo00?o0000ooooooooool0Goooool01Ol0003ooooooooooooooooo000000Oooooo00Go
0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool01?l0003o
ooooooooool0003ooooooeGooooo0009ooooo`05o`000?nj^[[ooooooiRHV?l@41003_ooool00ol0
003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool2o`0000Gooooo00?o0000
ooooooooool0Goooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooooooooooooooo
o`000007ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool0003ooooo
oeGooooo0009ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?ooool00omEEEGoIVIVo`000004oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h00_ooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo05oooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool0
00001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000oooooomE
ooooo`00:?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo05oooooo00Go0000
ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooo
oooooooooooo000000Oooooo00Co0000oooooooooooo0000oooooomEooooo`00:?ooool3o`0000Go
oooo00?o0000ooooooooool0Goooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooo
ooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooo
oooooooo000000Oooooo0_l0003oooooodcooooo000Yooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0Goooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooooooooooo
ooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo
000000Oooooo0_l0003oooooodcooooo000Zooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0Goooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`00
0007ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Oo
oooo0_l0003oooooodcooooo000`ooooo`03o`000?oooooooooo05oooooo00Go0000oooooooooooo
ooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo
000000Kooooo00Go0000ooooooooooooooooo`000007ooooo`;o0000oooooom<ooooo`00<?ooool0
0ol0003oooooooooo`1Dooooo`03o`000?oooooooooo00Sooooo00Go0000ooooooooooooooooo`00
0007ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Ko
oooo00Go0000ooooooooooooooooo`000007ooooo`;o0000oooooom<ooooo`00<?ooool00ol0003o
ooooooooo`1Cooooo`;o00002_ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooo
ooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooo
oooooooo000000Oooooo0_l0003oooooodcooooo000`ooooo`03o`000?oooooooooo05?ooooo0_l0
000:ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oo
oooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001oooool0
0ol0003oooooo`00003ooooood_ooooo000`ooooo`?o0000Doooool00ol0003oooooo`000009oooo
o`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool00000
1oooool00ol0003oooooo`00003ooooood_ooooo000`ooooo`03o`000?oooooooooo05?ooooo00?o
0000ooooool000002Oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003o
oooooooooooooooo000000Oooooo00?o0000ooooool00000oooooom;ooooo`00<?ooool00ol0003o
ooooooooo`1Cooooo`03o`000?oooooo000000Wooooo00Go0000ooooooooooooooooo`000007oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo
000000Kooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?ooooooBooo
ool0033ooooo00?o0000ooooooooool0Doooool00ol0003oooooo`000009ooooo`05o`000?oooooo
ooooooooool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go
0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001oooool00ol0003o
ooooo`00003ooooood_ooooo000`ooooo`03o`000?oooooooooo05?ooooo00?o0000ooooool00000
2Oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo
000000Oooooo00?o0000ooooool00000oooooom;ooooo`00<?ooool00ol0003oooooooooo`1Coooo
o`03o`000?oooooo000000Wooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go
0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?ooooooBoooool0033ooooo00?o
0000ooooooooool0D_ooool01?l0003oooooooooool00009ooooo`05o`000?ooooooooooooooool0
00001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001_ooool01?l0
003oooooooooool0003ooooood_ooooo000`ooooo`03o`000?oooooooooo05;ooooo00Co0000oooo
oooooooo00002Oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooo
ool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo0000oooooom;ooooo`00
<?ooool00ol0003oooooooooo`1Booooo`04o`000?ooooooooooo`0000Wooooo00Go0000oooooooo
ooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000006
ooooo`04o`000?ooooooooooo`000?ooooooBoooool0033ooooo00?o0000ooooooooool0D_ooool0
1?l0003oooooooooool00009ooooo`05o`000?ooooooooooooooool000001oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01?l0003ooooo
ooooool0003ooooood_ooooo000`ooooo`03o`000?oooooooooo05;ooooo00Co0000oooooooooooo
00002Oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo0000oooooom;
ooooo`00<?ooool00ol0003oooooooooo`1Booooo`05o`000?ooooooooooooooool000002?ooool0
1Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo0000oooooom;ooooo`00<?oo
ool3o`0005;ooooo00Go0000ooooooooooooooooo`000008ooooo`05o`000?ooooooooooooooool0
00001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool01?l0003oooooooooool0003ooooood_ooooo000`ooooo`03o`000?oooooooooo05;o
oooo00Go0000ooooooooooooooooo`000008ooooo`05o`000?ooooooooooooooool000001oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool0
1Ol0003ooooooooooooooooo00000?ooooooB_ooool0033ooooo00?o0000ooooooooool0D_ooool0
1Ol0003ooooooooooooooooo000000Sooooo00Go0000ooooooooooooooooo`000007ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`00
0?ooooooooooooooool00000oooooom:ooooo`00<?ooool00ol0003oooooooooo`1Aooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo000000Oo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00Go0000ooooooooooooooooo`000006ooooo`;o0000oooooom2ooooo`00<?ooool00ol0003o
ooooooooo`1Aooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool01Ol0003o
oooooooooooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000006ooooo`;o0000oooooom2
ooooo`00<?ooool00ol0003oooooooooo`1>ooooo`;ok^k^00?oooooo`000?ooool00_o^k^h00ooo
oooo0000ooooo`07ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooo
oooo000000Kooooo0_l0000Booooo`;ok^k^0oooool2onk^kV3ooooo0_o^k^h3ooooo`;ok^k^C_oo
ool2onk^kP?ooooo0_o^k^i/ooooo`00<?ooool00ol0003oooooooooo`18ooooo`0@odA4A?l0003o
0000oc8b<_oMgMgoooooonk^k_mEEEGok^k^o`000?o^k^koEEEEonk^k_oooooo0000ooooo`Co0000
00So410@oooooooooooo0000oc8b<_l0003o<S8bo`0000Oooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00
0006ooooo`;o00003?ooool4o`000009oa0@4?ooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^
00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^>oooool4o`000003oa0@
4?oooooooooo00;ooooo0_lQ8B45ooooo`0=odA4A?l0003o0000oc8b<_oMgMgoooooonk^k_mEEEGo
k^k^ooooooo^k^koEEEEonk^kP03ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8b
onk^kSSooooo1Ol00002ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co0000
00So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kUgooooo000`ooooo`03o`000?oooooooooo
04_ooooo00WoMgMgoc8b<_ooooooooooonk^k_mEEEGo0000oeEEEOo^k^h00_ooool01Ol0003ooooo
oooooooooooo000000?ooooo00Ko0000ogMgMonHV9SooooooiRHV?l00007ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooo`00000=ooooo`03o`000?oooooooooo00;ooooo00Go
k^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0mooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`09ogMgMolb<S;ooooooooo
ooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg03Sooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05onk^k_mEEEGogMgMoeEE
EOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0GOooool0
033ooooo00?o0000ooooooooool0C?ooool01ol0003ooooooooooooooooogMgMo`000?oMgMd00ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oa0@4?ooool00_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooo`00000=ooooo`03
o`000?oooooooooo00?ooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05
oa0@4?ooooooooooooooool@4100?Oooool00ol0003oooooooooo`0?ooooo`07o`000?oooooooooo
oooooooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooo
oa0@400iooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?ogMgMo`000?oMgMd01oooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@4100GOooool0033ooooo00?o0000ooooooooool0
Boooool02OmgMgOo<S8booooooooooook^k^oeEEEOl0003oEEEEonk^kP02ooooo`05o`000?oooooo
ooooooooool000000oooool2o`0000?ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooool000003Oooool00ol0003oooooooooo`02ooooo`05onk^
k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000?Oooool00ol0003oooooooooo`0>ooooo`09ogMgMolb<S;oooooooooooo^k^koEEEEomgM
gOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000003[o
oooo00?oV9RHob4Q8Oo^k^h00oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000005gooooo000`ooooo`03o`000?oooooooooo
04Sooooo00oo0000ob4Q8Ol0003o<S8bolc<c?ooooook^k^oeEEEOo^k^ko0000onk^k_mEEEGok^k^
ooooool000000oooool01?l0003oooooooooooooool2o`0000?ooooo0_l00006ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooo`00000=ooooo`0;o`000?ooooooooooooooooo^
k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool00000?Oooool00ol0003oooooooooo`0;ooooo`0=o`000?lQ8B7o0000oc8b<_o<
c<coooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo
00Go0000ooooooooooooooooo`00000kooooo`0;ogMgMomVIVKoooooooooooo^k^koEEEEonk^k_oo
ooook^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
0000GOooool0033ooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`03ooooo`;ok^k^
00?oooooo`000?ooool00_o^k^h2ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oa0@4?oo
ool00_ooool00ol@413o0000ooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001Oooool01?l0
003oooooooooool0000=ooooo`04o`000?ooooooooooooooo`;ok^k^0oooool2onk^kPGooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@03gooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`03ooooo`;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@03cooooo00?o0000ooooooooool00_o^k^h3ooooo`;o
k^k^1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100GOooool0033o
oooo0ol00015ooooo`;o000000?oooooo`000?ooool01oooool00ol0003oooooooooo`03ooooo`04
o`000?ooooooooooo`0000?ooooo00Oo0000ogMgMonHV9SooooooiRHV?mgMgOo000000Kooooo0_l0
0003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooo
oooooooo000000Gooooo00Co0000oooooooooooo00003Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`;o0000<oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Sooooo0_l0000^ooooo`05o`000?nj^[[ooooooiRHV?l@41003_oo
ool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool2o`0005?ooooo
000`ooooo`03o`000?oooooooooo04Cooooo0ol000000ooooooo0000o`000002o`0000Gooooo00?o
0000ooooooooool00oooool01?l0003oEEEEofIVI_l00003ooooo`07o`000?o^k^ko<S8bo`000?lb
<S;ok^k^o`000006ooooo`;o00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00?ooooo00Go0000ooooooooooooooooo`000005ooooo`04o`000?ooooooooooo`0000_ooooo00?o
EEEEofIVI_l000003Oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1oooool01?l0003oooooooooool0000`ooooo`03oeEEEOmVIVKo000000gooooo1?l0000<ooooo`03
oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP07ooooo`04o`000?oooooooooo
o`0002gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00<ooooo`03oeEEEOmVIVKo000000Cooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP07ooooo`04o`000?ooooooooooo`0005;ooooo000`ooooo`03o`00
0?oooooooooo04Cooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooo`000003o`000004
ooooool0003oooooo`0000;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`05o`000?ooooooooooooooool000001Oooool01?l0003oooooooooool0000Yooooo`Co000000Go
ooooo`000?ooooooooooo`00001Nooooo`Co000000Goooooo`000?ooooooooooo`00001<ooooo`Co
000000Goooooo`000?ooooooooooo`00001Booooo`00<?ooool00ol0003oooooooooo`13ooooo`;o
00000_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooool0
00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooo
ooooooooo`000005ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool09?ooool3
o`0006Cooooo0ol0001Booooo`?o0000Doooool0033ooooo00?o0000ooooooooool0@oooool01Ol0
003ooooooooooooooooo000000Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool01_l0003oooooooooool0
003oooooo`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Go
oooo00Co0000oooooooooooo00001_ooool3o`0002Kooooo00?o0000ooooooooool0I?ooool00ol0
003oooooooooo`1Booooo`03o`000?oooooooooo05;ooooo000`ooooo`03o`000?oooooooooo04?o
oooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo1?l000000ooo
oooo0000ooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000005
ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooo`00000Wooooo`03o`000?oo
oooooooo06Cooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`1Aooooo`00<?ooool0
0ol0003oooooooooo`13ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0003ooooooooooooooooo000000Go
oooo00?o0000ooooool00000oooooolhooooo`00<?ooool00ol0003oooooooooo`12ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`05o`00
0?ooooooooooooooool000001Oooool01Ol0003ooooooooooooooooo000000Gooooo00Co0000oooo
oooooooo0000o?ooool00omgMgOoIVIVooooo`0]ooooo`03ofIVI_mgMgOooooo00Oooooo000`oooo
o`03o`000?oooooooooo04;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000005ooooo`05o`000?oooooo
ooooooooool000001Oooool01?l0003oooooooooool00006ooooo`;o0000loooool00ooMgMgo410@
onk^kP0^ooooo`03onk^k_l@413ogMgM00Oooooo000`ooooo`03o`000?oooooooooo03Gooooo0_l0
000;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0003ooooooooooooooooo000000Go
oooo00Co0000oooooooooooo00001_ooool2o`000>7ooooo0_l00002ooooo`;o00003?ooool00omE
EEGoV9RHooooo`02o`0000;ooooo00Oo0000oooooooooooo0000oa0@4?o^k^koEEEE00;o000000?o
A4A4okZj^_ooool00_ooool01OnHV9So0000o`000?m4A4Co^[Zj00;ooooo00Sok^k^oeEEEOl0003o
0000odA4A?nj^[[ooooooa0@40Go00000oooool02?l@413o<S8bo`000?l0003o410@ojVYZOn7QhOo
IVIV1oooool0033ooooo00?o0000ooooooooool0<_ooool6o`0000[ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooo
ooooo`000004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003o
oooooooooooooooo000000Cooooo00Co0000oooooooooooo00001_ooool2o`000=Sooooo00Kok^k^
ob4Q8On7QhOo^[Zjo`000?oMgMd<ooooo`05o`000?ooooooooooooooool000000_ooool02ol0003o
ooooooooool0003ooooooeEEEOmgMgOoooooonk^k_mgMgOo410@00?ooooo00Go410@okZj^_o^k^ko
MgMgoa0@4002ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo410@0oooool00ol0003oooooooooo`04
ooooo`08o`000?nYZJWooooooooooonj^[[o0000onk^k_l00007ooooo`00ool0002do`0000oooooo
00CogMgMo`000?l@413oc<c<3Oooool01Olb<S;ooooooooooooooooo000000;ooooo00Ko0000oooo
oooooooo0000ooooool00008ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`05ooooo`07okZj^_n7QhOoIVIVofIVI_l@413oooooo`000007ooooo`00
2_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00?ooooo1ol00005ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`;o0000
1_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00Oo0000ooooooooooooooooo`000?oooooo
000000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
000000;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Cooooo0_l0
0003ooooo`04o`000?ooooooooooooooo`;o000000?oooooo`000?l000001?ooool4o`00017ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool05oooool01?o^k^ko8B4Qoa0@4?o^k^h=ooooo`05oc8b<_oooooooooooooo
ool000000_ooool01Ol0003oooooooooool0003ooooo00Ko00000oooool00ol0003oooooooooo`04
ooooo`Ko00000oooool00ol0003oooooooooo`04ooooo`08oc8b<_lQ8B7oMgMgogMgMon7QhOok^k^
ooooool00007ooooo`002_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
0_l00006ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000002ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo0000
00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooooooo
ooooool000001?ooool2o`0000;ooooo00?o0000ooooooooool00oooool3o`0000Oooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0Gooooo`04ob4Q8OmgMgOoMgMgoc8b<Pgooooo00Go
0000onk^k_ooooooooooo`000002olc<c00;o`000?nYZJWogMgMob4Q8OooooooEEEEohN7Qoo^k^ko
ooooohN7Qolb<S800oooool00ol0003oooooooooo`04ooooo`06oeEEEOn7QhOok^k^oooooon7QhOo
<S8b0oooool00ol0003o<S8bomgMg@04ooooo`08o`000?nj^[[oooooonk^k_mgMgOo0000onk^k_l0
0007ooooo`00<?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00Go0000
ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooo
ool01Ol0003ooooooooooooooooo000000Cooooo00Co0000oooooooooooo00004?ooool00ol0003o
ooooooooo`1Kooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool05_ooool2o`0000;o
oooo0_l0000<ooooo`0>oeEEEOmgMgOooooooa0@4?l0003o8B4Qo`000?mgMgOo410@o`000?nYZJWo
ooooonk^k_mEEED2o`000004odA4A?o^k^kooooooa0@40Go00000oooool01_o^k^koEEEEo`000?l0
003oA4A4onk^kP;ooooo0_l000001?nYZJWo8B4Qo`000?lQ8B42ooooo`08ojVYZOlQ8B7o0000o`00
0?lb<S;o0000ogMgMomEEED7ooooo`00<?ooool00ol0003oooooooooo`0looooo`04o`000?oooooo
ooooo`0000Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oo
ooooooooooooool000001Oooool00ol0003oooooo`00003gooooo`03omgMgOl@413ok^k^01;ooooo
00?o0000ooooooooool06Oooool00oo^k^ko410@omgMg@07ooooo`00<?ooool00ol0003ooooooooo
o`0looooo`?o00002_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Co
0000oooooooooooo00001_ooool2o`000?Wooooo00?oMgMgofIVI_ooool04Oooool00ol0003ooooo
ooooo`0Iooooo`03ofIVI_mgMgOooooo00Oooooo000`ooooo`03o`000?oooooooooo04Wooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`000?oooooo
??ooool0033ooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00Co0000oooooooooooo0000oooooollooooo`00<?ooool00ol0003ooooooooo
o`1:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`05o`000?ooooooooooooooool000001Oooool01?l0003oooooooooool0003oooooocco
oooo000`ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000005ooooo`04
o`000?ooooooooooo`000?oooooo??ooool0033ooooo00?o0000ooooooooool0B_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01?l0003o
ooooooooool00006ooooo`03o`000?oooooo00000?oooooo?Oooool0033ooooo00?o0000oooooooo
ool0B_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001Oooool01?l0
003oooooooooool00006ooooo`03o`000?oooooo00000?oooooo?Oooool0033ooooo0ol0001:oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000005ooooo`04o`000?oooooo
ooooo`0000Oooooo0_l0003oooooocgooooo000`ooooo`03o`000?oooooooooo04[ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Gooooo00Co0000oooooooooooo0000
1oooool2o`000?oooooo?Oooool0033ooooo00?o0000ooooooooool0B_ooool01Ol0003ooooooooo
oooooooo000000Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`00
0?ooooooooooooooool000001Oooool01?l0003oooooooooool0003oooooodKooooo000`ooooo`03
o`000?oooooooooo04_ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000005ooooo`04o`000?oooooo
ooooo`000?ooooooA_ooool0033ooooo00?o0000ooooooooool0Boooool01?l0003oooooooooool0
0009ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000Gooooo00Co0000oooooooooooo0000oooooom6ooooo`00<?ooool00ol0003ooooo
ooooo`1;ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`05o`000?ooooooooooooooool000001Oooool01?l0003oooooooooool0003o
ooooodKooooo000`ooooo`03o`000?oooooooooo04_ooooo00Co0000oooooooooooo00002Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00
0005ooooo`04o`000?ooooooooooo`000?ooooooA_ooool0033ooooo00?o0000ooooooooool0Booo
ool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool01Ol0003ooooooooooooooooo000000Gooooo00Co0000oooooooooooo0000oooooom6oooo
o`00<?ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooo000000Wooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001Oooool01?l0
003oooooooooool0003oooooodKooooo000`ooooo`03o`000?oooooooooo04cooooo0ol00009oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo
000000Gooooo00Co0000oooooooooooo0000oooooom6ooooo`00<?ooool00ol0003oooooooooo`1<
ooooo`;o00002_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Co0000
oooooooooooo00001_ooool01?l0003oooooooooool0003oooooodKooooo000`ooooo`03o`000?oo
oooooooo04gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00003oooooodKooooo
000`ooooo`?o0000F?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Co
0000oooooooooooo00001oooool00ol0003oooooo`00003oooooodKooooo000`ooooo`03o`000?oo
oooooooo05Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`04o`000?oo
ooooooooo`0000Oooooo00?o0000ooooool00000oooooom6ooooo`00<?ooool00ol0003ooooooooo
o`1Hooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01?l0003ooooooooo
ool00007ooooo`;o0000oooooom7ooooo`00<?ooool00ol0003oooooooooo`1Hooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00007ooooo`;o0000
oooooom7ooooo`00<?ooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool01?l0003oooooooooool00007ooooo`;o0000oooooom7ooooo`00<?oo
ool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool01?l0003oooooooooool00007ooooo`;o0000oooooom7ooooo`00<?ooool00ol0003ooooooooo
o`1Hooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01?l0003ooooooooo
ool00007ooooo`;o0000oooooom7ooooo`00<?ooool00ol0003oooooooooo`1Iooooo`05o`000?oo
ooooooooooooool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool01?l0003oooooooooool0003ooooooe3ooooo000`ooooo`03o`00
0?oooooooooo05Wooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`00
0?ooooooD?ooool0033ooooo00?o0000ooooooooool0FOooool01Ol0003ooooooooooooooooo0000
00Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00Co0000oooooooooooo0000oooooom@ooooo`00<?ooool00ol0003oooooooooo`1Ioooo
o`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0003ooooooe3ooooo000`
ooooo`03o`000?oooooooooo05Wooooo00Co0000oooooooooooo00002?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01?l0003ooooooooo
ool0003ooooooe3ooooo000`ooooo`?o0000FOooool01?l0003oooooooooool00008ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`00
0?ooooooD?ooool0033ooooo00?o0000ooooooooool0FOooool01?l0003oooooooooool00008oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo
000000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`04o`000?oooooo
ooooo`000?ooooooD?ooool0033ooooo00?o0000ooooooooool0FOooool01?l0003oooooooooool0
0008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`04o`00
0?ooooooooooo`000?ooooooD?ooool0033ooooo00?o0000ooooooooool0FOooool01?l0003ooooo
ooooool00008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003o
oooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04oooo
o`04o`000?ooooooooooo`000?ooooooD?ooool0033ooooo00?o0000ooooooooool0FOooool01?l0
003oooooooooool00008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
1Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000006ooooo`04o`00
0?ooooooooooo`000?ooooooD?ooool0033ooooo00?o0000ooooooooool0FOooool01?l0003ooooo
ooooool00008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003o
oooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
00000?ooooooDOooool000oooooo0_o^k^h3ooooo`;ok^k^6_ooool00ol0003oooooooooo`1Ioooo
o`04o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oo
ooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooool0
0000oooooomAooooo`002?ooool5o`0000;ooooo00Ook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^
00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool00ol0003ooooo
ooooo`1Iooooo`04o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000007oooo
o`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Kooooo00?o
0000ooooool00000oooooomAooooo`002?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00Go
k^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`03o`000?oooooooooo05Wooooo00Co0000oooooooooooo00002?ooool01Ol0
003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooo`00003ooooooe7ooooo0009ooooo`03oiRHV?lQ
8B7ok^k^00Gooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?oo
ooooooooooooool@41002oooool00ol0003oooooooooo`1Iooooo`04o`000?ooooooooooo`0000So
oooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool0
1Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooool00000oooooomAooooo`002_ooool0
0onHV9So8B4Qonk^kP03ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`1Iooooo`04o`00
0?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooooooo
ooooool000001oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooool00000oooo
oomAooooo`002oooool02omgMgOoIVIVooooooooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^
00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000_ooooo1?l0001H
ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000007ooooo`05o`00
0?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooo
ool00000oooooomAooooo`003?ooool00ol0003oooooooooo`02onk^kP?ooooo0_o^k^h5ooooo`03
o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400;ooooo`03o`000?oooooooooo
05Wooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go
0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool2o`000?oo
ooooDOooool000Sooooo00Go0000okZj^_ooooooV9RHoa0@400>ooooo`03o`000?oooooooooo00;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03o`000?oooooooooo05Wooooo00Co0000oooo
oooooooo00002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooooooooooooooo
o`000007ooooo`05o`000?ooooooooooooooool000001oooool2o`000?ooooooDOooool000Sooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c00<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP03ooooo`;o00001_ooool00ol0003oooooooooo`1Iooooo`04o`000?oooooooooo
o`0000Sooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool00000
1oooool01Ol0003ooooooooooooooooo000000Oooooo0_l0003ooooooe7ooooo000Wooooo`04o`00
0?ooooooooooo`0000Gooooo00?o0000ooooooooool0F_ooool2o`0000Wooooo00Go0000oooooooo
ooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooo
oooo000000Oooooo0_l0003ooooooe7ooooo000Wooooo`04o`000?ooooooooooo`0000Gooooo00?o
0000ooooooooool0F_ooool2o`0000Wooooo00Go0000ooooooooooooooooo`000007ooooo`05o`00
0?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo0_l0003ooooo
oe7ooooo000Wooooo`?o00001_ooool00ol0003oooooooooo`1Jooooo`;o00002Oooool01Ol0003o
oooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooo
ooooooooool000001oooool2o`000?ooooooDOooool002Sooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`1Jooooo`;o00002Oooool01Ol0003ooooooooooooooooo000000Oooooo00Go
0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool2o`000?oo
ooooDOooool002Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Jooooo`;o0000
2_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001oooool01Ol0
003ooooooooooooooooo000000Oooooo0_l0003ooooooe7ooooo000`ooooo`03o`000?oooooooooo
05[ooooo0_l0000:ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00
0007ooooo`05o`000?ooooooooooooooool000001oooool2o`000?ooooooDOooool0033ooooo00?o
0000ooooooooool0F_ooool2o`0000[ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooo
oooooooooooo000000Oooooo00Co0000oooooooooooo00002?ooool2o`000?ooooooDOooool0033o
oooo00?o0000ooooooooool0I_ooool01?l0003oooooooooool00007ooooo`05o`000?oooooooooo
ooooool000001oooool01?l0003oooooooooool00008ooooo`;o0000oooooomAooooo`00<?ooool3
o`0006Kooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Oooooo
00Co0000oooooooooooo0000oooooomKooooo`00<?ooool00ol0003oooooooooo`1Vooooo`04o`00
0?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?oooooooooo
o`000?ooooooFoooool0033ooooo00?o0000ooooooooool0I_ooool01?l0003oooooooooool00007
ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool0003ooooooe_ooooo
000`ooooo`03o`000?oooooooooo06Kooooo00Co0000oooooooooooo00001oooool01Ol0003ooooo
oooooooooooo000000Oooooo00Co0000oooooooooooo0000oooooomKooooo`00<?ooool00ol0003o
ooooooooo`1Vooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000007
ooooo`04o`000?ooooooooooo`000?ooooooFoooool0033ooooo00?o0000ooooooooool0I_ooool0
1?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001oooool01?l0003ooooo
ooooool0003ooooooe_ooooo000`ooooo`03o`000?oooooooooo06Kooooo00Co0000oooooooooooo
00001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000oooooomK
ooooo`00<?ooool00ol0003oooooooooo`1Vooooo`04o`000?ooooooooooo`0000Oooooo00Go0000
ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`000?ooooooFoooool0033ooooo00?o
0000ooooooooool0I_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool0
00001oooool01?l0003oooooooooool0003ooooooe_ooooo000`ooooo`03o`000?oooooooooo06Ko
oooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000
oooooooooooo0000oooooomKooooo`00<?ooool00ol0003oooooooooo`1Vooooo`04o`000?oooooo
ooooo`0000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`000?oo
ooooFoooool0033ooooo00?o0000ooooooooool0I_ooool01?l0003oooooooooool00008ooooo`04
o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo0000oooooomKooooo`00<?ooool3o`00
06Kooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00007ooooo`04o`000?oo
ooooooooo`000?ooooooFoooool0033ooooo00?o0000ooooooooool0I_ooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooomKooooo`00
<?ooool00ol0003oooooooooo`1Vooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooo
oooo00002?ooool00ol0003oooooo`00003ooooooe_ooooo000`ooooo`03o`000?oooooooooo06Ko
oooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo
00000?ooooooFoooool0033ooooo00?o0000ooooooooool0I_ooool01?l0003oooooooooool00008
ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooomKooooo`00<?ooool0
0ol0003oooooooooo`1Vooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000
2?ooool00ol0003oooooo`00003ooooooe_ooooo000`ooooo`03o`000?oooooooooo06Kooooo00Co
0000oooooooooooo00002?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?oo
ooooFoooool0033ooooo00?o0000ooooooooool0I_ooool01?l0003oooooooooool00008ooooo`04
o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooomKooooo`00<?ooool00ol0003o
ooooooooo`1Vooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002?ooool0
0ol0003oooooo`00003ooooooe_ooooo000`ooooo`03o`000?oooooooooo06Kooooo00Co0000oooo
oooooooo00002?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?ooooooFooo
ool0033ooooo00?o0000ooooooooool0Ioooool00ol0003oooooo`000008ooooo`04o`000?oooooo
ooooo`0000Sooooo00?o0000ooooool00000oooooomKooooo`00<?ooool00ol0003oooooooooo`1W
ooooo`03o`000?oooooo000000Sooooo00Co0000oooooooooooo00002?ooool2o`000?ooooooG?oo
ool0033ooooo0ol0001Wooooo`;o00002Oooool01?l0003oooooooooool00008ooooo`;o0000oooo
oomLooooo`00<?ooool00ol0003oooooooooo`1Wooooo`;o00002Oooool01?l0003oooooooooool0
0008ooooo`;o0000oooooomLooooo`00<?ooool00ol0003oooooooooo`1Wooooo`;o00002Oooool0
1?l0003oooooooooool00008ooooo`;o0000oooooomLooooo`00<?ooool00ol0003oooooooooo`1W
ooooo`;o00002Oooool01?l0003oooooooooool00008ooooo`;o0000oooooomLooooo`00<?ooool0
0ol0003oooooooooo`1Wooooo`;o00002Oooool01?l0003oooooooooool00008ooooo`;o0000oooo
oomLooooo`00<?ooool00ol0003oooooooooo`1Wooooo`;o00002Oooool01?l0003oooooooooool0
0008ooooo`;o0000oooooomLooooo`003oooool2onk^kP?ooooo0_o^k^hJooooo`03o`000?oooooo
oooo06Oooooo0_l00009ooooo`03o`000?oooooo000000[ooooo00?o0000ooooooooool0oooooomJ
ooooo`002_ooool2o`00000:oa0@4?ooooooooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP?o
oooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool00ol0003ooooooooo
o`1Wooooo`;o00002Oooool00ol0003oooooo`00003oooooofOooooo000;ooooo`03o`000?oooooo
oooo00;ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03o`000?oooooooooo06Oooooo0_l00009ooooo`03o`00
0?oooooo00000?ooooooIoooool000Sooooo1Ol00004ooooo`03omgMgOl0003ogMgM00Oooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00_ooooo00?o0000ooooooooool0
Ioooool2o`0000Wooooo00?o0000ooooool00000oooooomWooooo`002?ooool01?m4A4CogMgMoooo
ool00004ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`1Wooooo`;o00002_ooool2o`00
0?ooooooIoooool000Sooooo00CogMgMoeEEEOoooooo00000oooool01oo^k^koEEEEonk^k_oooooo
k^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
2oooool4o`0007;ooooo0_l0003oooooofOooooo0009ooooo`03ogMgMoo<c<co000000?ooooo0_o^
k^h3ooooo`;ok^k^1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100
2oooool00ol0003oooooooooo`1cooooo`;o0000oooooomWooooo`002Oooool00oo^k^koA4A4o`00
000?ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03o`00
0?oooooooooo07?ooooo0_l0003oooooofOooooo000:ooooo`03ogMgMol0003ooooo00cooooo00?o
EEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo0_l00006ooooo`03o`00
0?oooooooooo07?ooooo0_l0003oooooofOooooo000Wooooo`04o`000?ooooooooooo`0000Gooooo
00?o0000ooooooooool0Loooool2o`000?ooooooIoooool002Oooooo00Co0000oooooooooooo0000
1Oooool00ol0003oooooooooo`1cooooo`;o0000oooooomWooooo`009oooool3o`0000Kooooo00?o
0000ooooooooool0Loooool2o`000?ooooooIoooool002Sooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`1cooooo`;o0000oooooomWooooo`00:Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo07?ooooo0_l0003oooooofOooooo000`ooooo`03o`000?oooooooooo07?o
oooo0_l0003oooooofOooooo000`ooooo`03o`000?oooooooooo07?ooooo0_l0003oooooofOooooo
000`ooooo`03o`000?oooooooooo07?ooooo0_l0003oooooofOooooo000`ooooo`?o0000Loooool2
o`000?ooooooIoooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003o
ooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o
0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`oooo
o`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00
<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?oo
ool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3ooooo
omcooooo000`ooooo`?o0000oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo
000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooL
ooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oo
oooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooooooo
o`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooo
ooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`00
0?oooooooooo0?oooooog?ooool0033ooooo0ol0003oooooomcooooo000`ooooo`03o`000?oooooo
oooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003o
ooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool00?oooooooooo
ool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00
oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooo
oa3ooooo002Pooooo`;o00001?ooool00onj^[[o<S8booooo`04ooooo`;o00001_ooool00ol0003o
^[Zjooooo`3ooooooeOooooo002Pooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`04ooooo`;o<S8boooooomHooooo`00SOooool3o`0000;ooooo00Ko
<S8boa0@4?ooooooooooonk^k_mEEED2o`000003odA4A?nj^[[ooooo00?ooooo00?o0000oooooooo
ool00_ooool01OnHV9So410@o`000?l0003oZJVY00Cooooo00?o0000ooooooooool01?ooool00on7
QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X02_ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Cooooo0_lQ8B46ooooo`;o000000Oo410@ooooooo<c<cok^k^ooooooo^k^koc<c<00Co
oooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^4oooool01_l@413o<S8bo`00
0?l0003o410@ojVYZ@;ooooo00Kok^k^oeEEEOl0003o0000odA4A?nj^[X3ooooo`05ofIVI_l0003o
0000odA4A?o<c<`0j?ooool008kooooo00Go0000ooooooooooooc<c<oa0@4003ooooo`06oeEEEOmg
MgOoooooonk^k_mgMgOo410@1?ooool00ol0003oooooooooo`02ooooo`06o`000?nYZJWoEEEEoiRH
V?mEEEGo^[Zj0oooool00ol0003oooooooooo`04ooooo`03olc<c?l0003o410@00cooooo00Ko410@
okZj^_o^k^koMgMgoa0@4?ooool6o`0000Kooooo00?oMgMgoc8b<_ooool00oooool2ob4Q8@Oooooo
00So0000ooooooooooook^k^oeEEEOoMgMgoEEEEonk^kPKooooo00?o0000ooooooooool00_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg01?ooooo00Ko0000ojVYZOoooooooooookZj^_l00002ooooo`06
oeEEEOmgMgOoooooonk^k_mgMgOo410@0_ooool01_mVIVKoMgMgooooooooooooQhN7oa0@4>Sooooo
002>ooooo`05o`000?oooooooooooeEEEOn7QhL00oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00;ooooo00Ko<S8bonk^k_nHV9SoEEEEomgMgOl@4103ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`08ooooo`Go00000_ooool00ooM
gMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400D
ooooo`05okZj^_n7QhOoIVIVofIVI_l@41000_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0>_ooooo002>ooooo`05o`000?oooooogMgMo`000?o^k^h00oooool6o`0000Cooooo00?o
0000ooooooooool00_ooool01onj^[[oA4A4olc<c?lQ8B7ooooooa0@4?o<c<`00_ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo00?ooooo1_l00006ooooo`03ogMgMolb<S;ooooo00Wo
oooo00CoA4A4omgMgOoooooo00000_ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000001?ooooo00Ko<S8bob4Q8OmgMgOoMgMg
ohN7Qoo^k^h2ooooo`Ko00000_ooool00ol0003oooooooooo`3[ooooo`00S_ooool3o`000003oa0@
4?nHV9Sooooo00;ooooo00KoEEEEohN7Qoo^k^koooooohN7Qolb<S84ooooo`03o`000?oooooooooo
00;ooooo00Ook^k^o`000?oooooo0000oooooomVIVKoQhN700;ooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`02_ooool01?oMgMgoEEEE
ooooool00002ooooo`05olc<c?o^k^koooooonk^k_o<c<`01_ooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000004oooool01_l0003o^[Zjooooooo^k^koMgMgo`0000;ooooo
00KoEEEEohN7Qoo^k^koooooohN7Qolb<S82ooooo`06ofIVI_mgMgOooooooooooon7QhOo0000j?oo
ool008kooooo00Go0000ooooooooooooc<c<o`000003ooooo`06onk^k_mEEEGo0000o`000?m4A4Co
k^k^1?ooool00ol0003oooooooooo`02ooooo`04ofIVI_nHV9Sooooooc8b<P;o^[Zj00Co0000oooo
oooooooo00004oooool00ol@413o0000o`000003o`0000_ooooo00?o0000ooooooooool03Oooool0
0omgMgOoc<c<o`00000=ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4007ooooo`?o00000_ooool3o`0000Cooooo00KoZJVYob4Q8Ol0003o0000oc8b<_l00002ooooo`06
onk^k_mEEEGo0000o`000?m4A4Cok^k^0_ooool01_o^k^koIVIVo`000?l0003oA4A4o`000>Sooooo
002>ooooo`05o`000?ooooooooooolc<c?l000003Oooool00ol0003oooooooooo`05ooooo`03ofIV
I_n7QhOooooo00?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00gooooo00?ok^k^odA4A?l000003Oooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oo
oooo0_ooool008gooooo1?l000000ol@413oZJVYooooo`0<ooooo`;o00001_ooool00onYZJWoA4A4
ooooo`02ooooo`;o00005Oooool00ol0003oooooooooo`0<ooooo`Co00003Oooool00omgMgOo0000
ooooo`0:ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`Co
00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo0_ooool00?oooooo
1_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo0_ooool00?oooooo1_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo0_ooool00?oooooo1Oooool2
o`0000?ooooo0_l0003oooooo`Cooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00
oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooo
oa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003o
oooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo
4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oo
ooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@
ooooo`00\
\>"],
  ImageRangeCache->{{{0, 525.688}, {324.5, 0}} -> {-2.58312*^-7, -6.34248*^6, \
6.65005*^-9, 53093.5}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0.309017 5.42214e-08 [
[.32684 .29652 -16.5 -12.5 ]
[.32684 .29652 16.5 0 ]
[.54329 .29652 -16.5 -12.5 ]
[.54329 .29652 16.5 0 ]
[.75974 .29652 -22.5 -12.5 ]
[.75974 .29652 22.5 0 ]
[.97619 .29652 -16.5 -12.5 ]
[.97619 .29652 16.5 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 64 6 ]
[.09789 .09213 -34.5 -6.25 ]
[.09789 .09213 0 6.25 ]
[.09789 .20057 -34.5 -6.25 ]
[.09789 .20057 0 6.25 ]
[.09789 .41746 -28.5 -6.25 ]
[.09789 .41746 0 6.25 ]
[.09789 .5259 -28.5 -6.25 ]
[.09789 .5259 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -62.8125 0 ]
[.5 .63053 62.8125 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 .30902 m
.32684 .31527 L
s
gsave
.32684 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 .30902 m
.54329 .31527 L
s
gsave
.54329 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 .30902 m
.75974 .31527 L
s
gsave
.75974 .29652 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 .30902 m
.15368 .31277 L
s
.19697 .30902 m
.19697 .31277 L
s
.24026 .30902 m
.24026 .31277 L
s
.28355 .30902 m
.28355 .31277 L
s
.37013 .30902 m
.37013 .31277 L
s
.41342 .30902 m
.41342 .31277 L
s
.45671 .30902 m
.45671 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.58658 .30902 m
.58658 .31277 L
s
.62987 .30902 m
.62987 .31277 L
s
.67316 .30902 m
.67316 .31277 L
s
.71645 .30902 m
.71645 .31277 L
s
.80303 .30902 m
.80303 .31277 L
s
.84632 .30902 m
.84632 .31277 L
s
.88961 .30902 m
.88961 .31277 L
s
.9329 .30902 m
.9329 .31277 L
s
.0671 .30902 m
.0671 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09213 m
.11664 .09213 L
s
gsave
.09789 .09213 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .20057 m
.11664 .20057 L
s
gsave
.09789 .20057 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .41746 m
.11664 .41746 L
s
gsave
.09789 .41746 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .5259 m
.11664 .5259 L
s
gsave
.09789 .5259 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.11039 .11924 m
.11414 .11924 L
s
.11039 .14635 m
.11414 .14635 L
s
.11039 .17346 m
.11414 .17346 L
s
.11039 .22768 m
.11414 .22768 L
s
.11039 .2548 m
.11414 .2548 L
s
.11039 .28191 m
.11414 .28191 L
s
.11039 .33613 m
.11414 .33613 L
s
.11039 .36324 m
.11414 .36324 L
s
.11039 .39035 m
.11414 .39035 L
s
.11039 .44457 m
.11414 .44457 L
s
.11039 .47168 m
.11414 .47168 L
s
.11039 .49879 m
.11414 .49879 L
s
.11039 .06502 m
.11414 .06502 L
s
.11039 .03791 m
.11414 .03791 L
s
.11039 .0108 m
.11414 .0108 L
s
.11039 .55301 m
.11414 .55301 L
s
.11039 .58012 m
.11414 .58012 L
s
.11039 .60723 m
.11414 .60723 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -123.812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.812 moveto
(@) show
81.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.812 moveto
(D) show
93.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5.6) show
135.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
141.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
153.000 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
157.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
166.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
184.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02418 .30902 L
.02453 .30902 L
.02473 .30902 L
.02491 .30902 L
.02501 .30902 L
.02506 .30902 L
.02512 .30902 L
.02522 .30902 L
.02532 .30902 L
.02542 .30902 L
.02551 .30902 L
.02561 .30902 L
.02571 .30902 L
.0258 .30902 L
.02589 .30902 L
.02608 .30902 L
.02629 .30902 L
.02648 .30902 L
.02691 .30902 L
.02735 .30902 L
.02775 .30902 L
.02819 .30902 L
.02865 .30902 L
.02943 .30902 L
.03029 .30902 L
.03111 .30902 L
.03186 .30902 L
.03272 .30902 L
.03354 .30902 L
.03431 .30902 L
.03514 .30902 L
.03661 .30902 L
.03818 .30902 L
.03964 .30902 L
.04126 .30902 L
.04275 .30902 L
.04427 .30902 L
.04593 .30902 L
.0475 .30902 L
.04919 .30902 L
.0509 .30902 L
.05252 .30902 L
.0556 .30902 L
.0572 .30902 L
.05889 .30902 L
.06193 .30902 L
.06517 .30902 L
.06828 .30902 L
.0716 .30902 L
Mistroke
.07479 .30902 L
.07562 .30902 L
.0764 .30902 L
.07716 .30902 L
.07786 .30902 L
.07823 .30902 L
.07842 .30902 L
.07862 .30902 L
.07872 .30902 L
.07882 .30902 L
.07888 .30902 L
.07894 .30902 L
.07904 .30902 L
.07914 .30902 L
.07925 .30902 L
.07934 .30902 L
.07944 .30902 L
.07949 .30902 L
.07955 .30902 L
.07966 .30902 L
.07986 .30902 L
.08009 .30902 L
.08031 .30902 L
.0807 .30902 L
.08113 .30902 L
.08155 .30902 L
.08195 .30902 L
.08284 .30902 L
.08363 .30902 L
.08446 .30902 L
.08522 .30902 L
.08603 .30902 L
.08751 .30902 L
.08832 .30902 L
.08921 .30902 L
.09082 .30902 L
.09241 .30902 L
.09409 .30902 L
.09566 .30902 L
.09712 .30902 L
.10022 .30902 L
.10352 .30902 L
.1067 .30902 L
.10976 .30902 L
.11146 .30902 L
.11301 .30902 L
.11378 .30902 L
.11462 .30902 L
.11501 .30902 L
.11541 .30902 L
Mistroke
.11579 .30902 L
.11614 .30902 L
.11633 .30902 L
.11654 .30902 L
.11663 .30902 L
.11673 .30902 L
.11682 .30902 L
.1169 .30902 L
.117 .30902 L
.11706 .30902 L
.11712 .30902 L
.11722 .30902 L
.11727 .30902 L
.11733 .30902 L
.11742 .30902 L
.11751 .30902 L
.11761 .30902 L
.11771 .30902 L
.11789 .30902 L
.11808 .30902 L
.11842 .30902 L
.11878 .30902 L
.11918 .30902 L
.11958 .30902 L
.11999 .30902 L
.12074 .30902 L
.12154 .30902 L
.12241 .30902 L
.12399 .30902 L
.12487 .30902 L
.12567 .30902 L
.12721 .30902 L
.12888 .30902 L
.13047 .30902 L
.13216 .30902 L
.13521 .30902 L
.13845 .30902 L
.14156 .30902 L
.14315 .30902 L
.14488 .30902 L
.14568 .30902 L
.14612 .30902 L
.14654 .30902 L
.14692 .30902 L
.14713 .30902 L
.14734 .30902 L
.14752 .30902 L
.14772 .30902 L
.14781 .30902 L
.1479 .30902 L
Mistroke
.14799 .30902 L
.14807 .30902 L
.14817 .30902 L
.14822 .30902 L
.14828 .30902 L
.14834 .30902 L
.14839 .30902 L
.1485 .30902 L
.1486 .30902 L
.14869 .30902 L
.14879 .30902 L
.14889 .30902 L
.14913 .30902 L
.14936 .30902 L
.14978 .30902 L
.15019 .30902 L
.15056 .30902 L
.1514 .30902 L
.15218 .30902 L
.15291 .30902 L
.15376 .30902 L
.15457 .30902 L
.1562 .30902 L
.15769 .30902 L
.16076 .30902 L
.16235 .30902 L
.16404 .30902 L
.16707 .30903 L
.17029 .30903 L
.17177 .30904 L
.17261 .30904 L
.1734 .30904 L
.1738 .30904 L
.17417 .30904 L
.17438 .30904 L
.17461 .30904 L
.17481 .30904 L
.175 .30904 L
.1751 .30904 L
.17521 .30904 L
.17531 .30904 L
.1754 .30904 L
.1755 .30904 L
.17556 .30904 L
.17562 .30904 L
.17572 .30904 L
.17578 .30904 L
.17583 .30904 L
.17604 .30904 L
.17616 .30904 L
Mistroke
.17628 .30904 L
.1767 .30904 L
.17708 .30904 L
.17748 .30904 L
.17821 .30904 L
.17908 .30903 L
.17987 .30903 L
.1814 .30903 L
.18227 .30902 L
.18307 .30902 L
.18623 .30899 L
.18926 .30896 L
.19249 .30892 L
.1956 .30889 L
.19721 .30887 L
.19802 .30887 L
.19848 .30886 L
.1987 .30886 L
.1989 .30886 L
.1991 .30886 L
.19931 .30886 L
.19942 .30886 L
.19952 .30886 L
.19958 .30886 L
.19963 .30886 L
.19969 .30886 L
.19975 .30886 L
.19985 .30886 L
.19995 .30886 L
.20004 .30886 L
.20013 .30886 L
.20024 .30886 L
.20035 .30886 L
.20055 .30886 L
.20073 .30886 L
.20093 .30886 L
.20133 .30887 L
.2017 .30887 L
.20204 .30887 L
.20288 .30888 L
.20368 .30889 L
.20517 .30893 L
.20678 .30898 L
.20826 .30905 L
.21142 .30923 L
.21445 .30944 L
.21614 .30956 L
.21769 .30967 L
.21845 .30971 L
.21928 .30975 L
Mistroke
.22007 .30978 L
.22045 .3098 L
.2208 .3098 L
.22121 .30981 L
.22142 .30982 L
.22153 .30982 L
.22165 .30982 L
.22175 .30982 L
.22185 .30982 L
.2219 .30982 L
.22196 .30982 L
.22206 .30982 L
.22216 .30982 L
.22226 .30982 L
.22235 .30982 L
.22245 .30982 L
.22264 .30982 L
.22282 .30981 L
.22301 .30981 L
.22322 .3098 L
.22356 .30979 L
.22394 .30978 L
.22477 .30973 L
.22552 .30968 L
.22638 .30959 L
.2272 .30949 L
.2288 .30923 L
.23029 .30892 L
.23345 .30808 L
.23649 .30715 L
.23818 .30667 L
.23973 .30631 L
.24049 .30618 L
.2409 .30612 L
.24133 .30607 L
.24154 .30605 L
.24174 .30603 L
.24194 .30602 L
.24212 .30601 L
.24229 .306 L
.24237 .306 L
.24247 .306 L
.24256 .30599 L
.24266 .30599 L
.24276 .30599 L
.24285 .30599 L
.24294 .306 L
.24303 .306 L
.24313 .306 L
.24323 .30601 L
Mistroke
.24345 .30602 L
.24364 .30603 L
.24402 .30607 L
.24438 .30612 L
.2448 .30619 L
.24518 .30628 L
.24605 .30652 L
.2469 .30684 L
.2477 .30721 L
.24919 .3081 L
.25228 .31061 L
.25557 .31386 L
.25721 .31542 L
.25874 .31665 L
.25949 .31713 L
.26021 .3175 L
.2606 .31766 L
.26081 .31773 L
.26103 .31779 L
.26122 .31784 L
.26142 .31788 L
.26151 .31789 L
.26161 .31791 L
.2617 .31792 L
.26178 .31792 L
.26188 .31793 L
.26198 .31793 L
.26207 .31793 L
.26213 .31793 L
.26218 .31793 L
.26227 .31793 L
.26236 .31792 L
.26246 .31791 L
.26255 .3179 L
.26276 .31787 L
.26296 .31783 L
.26339 .31769 L
.26381 .31751 L
.26426 .31725 L
.26508 .31661 L
.26591 .31574 L
.26666 .31476 L
.26835 .31192 L
.27157 .30447 L
.27466 .29627 L
.27623 .29254 L
.27707 .29087 L
.27796 .28939 L
.2784 .2888 L
.27882 .28833 L
Mistroke
.27919 .288 L
.27938 .28787 L
.2796 .28774 L
.2798 .28765 L
.27989 .28762 L
.27998 .28759 L
.28009 .28757 L
.28018 .28756 L
.28028 .28755 L
.28034 .28755 L
.28039 .28755 L
.28049 .28755 L
.28058 .28756 L
.28066 .28758 L
.28075 .2876 L
.28095 .28767 L
.28113 .28776 L
.28133 .28788 L
.2815 .28802 L
.28191 .28842 L
.28228 .28891 L
.28264 .28947 L
.28343 .29109 L
.28429 .29343 L
.28588 .2992 L
.28756 .30721 L
.29091 .32652 L
.29259 .33622 L
.29413 .34391 L
.29491 .34708 L
.29564 .34947 L
.29604 .35051 L
.2964 .35129 L
.2968 .35194 L
.29702 .35221 L
.29712 .35231 L
.29723 .3524 L
.29733 .35246 L
.29742 .35251 L
.29751 .35255 L
.2976 .35257 L
.2977 .35258 L
.2978 .35257 L
.2979 .35256 L
.29796 .35254 L
.29801 .35252 L
.29811 .35246 L
.29821 .35239 L
.29843 .35219 L
.29863 .35194 L
Mistroke
.29883 .35161 L
.2992 .35085 L
.29954 .34995 L
.30031 .34717 L
.30115 .34303 L
.30195 .33805 L
.30344 .32616 L
.30651 .29388 L
.30807 .27605 L
.30979 .25771 L
.31057 .25044 L
.31141 .24372 L
.31221 .23866 L
.31259 .23674 L
.31294 .2353 L
.31332 .23407 L
.31353 .23356 L
.31372 .23319 L
.31381 .23306 L
.31391 .23294 L
.31399 .23286 L
.31407 .23279 L
.31417 .23275 L
.31427 .23273 L
.31437 .23273 L
.31446 .23276 L
.31456 .23283 L
.31461 .23288 L
.31467 .23293 L
.31486 .2332 L
.31497 .23341 L
.31509 .23367 L
.31531 .23425 L
.31573 .2358 L
.31612 .2377 L
.3169 .24295 L
.31763 .24952 L
.31929 .27002 L
.32242 .32427 L
.32401 .35496 L
.32574 .38594 L
.32655 .3984 L
.32741 .40959 L
.32814 .41715 L
.32852 .42031 L
.32894 .42306 L
.32934 .42494 L
.32955 .42567 L
.32966 .42594 L
.32975 .42616 L
Mistroke
.32985 .42631 L
.32994 .42644 L
.33003 .42652 L
.33011 .42655 L
.3302 .42655 L
.3303 .42651 L
.3304 .42642 L
.3305 .42629 L
.3306 .42609 L
.33072 .42582 L
.33092 .42517 L
.33112 .42433 L
.33131 .42337 L
.33173 .42058 L
.33217 .41664 L
.33292 .40782 L
.33373 .39532 L
.3352 .36556 L
.3385 .27652 L
.34015 .23003 L
.34168 .19207 L
.34244 .1766 L
.34315 .1646 L
.34355 .1592 L
.34398 .15442 L
.34437 .15109 L
.34456 .14987 L
.34473 .14892 L
.34483 .1485 L
.34493 .14811 L
.34502 .14782 L
.34511 .1476 L
.34521 .14741 L
.34526 .14734 L
.34532 .14729 L
.34541 .14725 L
.34551 .14728 L
.3456 .14736 L
.34569 .14752 L
.3458 .14775 L
.34589 .14803 L
.34606 .1487 L
.34624 .14964 L
.34645 .15105 L
.34668 .15296 L
.3471 .15743 L
.34789 .1692 L
.34865 .18444 L
.34948 .20543 L
.35117 .25906 L
Mistroke
.3544 .38182 L
.35588 .43433 L
.35672 .45975 L
.3575 .4795 L
.35828 .49475 L
.35872 .50116 L
.35911 .50556 L
.35933 .50739 L
.35953 .50869 L
.35964 .50923 L
.35975 .5097 L
.35981 .50989 L
.35987 .51006 L
.35993 .51018 L
.35998 .51027 L
.36009 .51036 L
.36019 .51035 L
.36024 .51031 L
.36029 .51024 L
.36035 .51013 L
.36041 .51 L
.36051 .50969 L
.3606 .50932 L
.36081 .50818 L
.361 .50671 L
.36119 .50505 L
.36159 .50019 L
.36197 .49431 L
.36232 .48755 L
.36312 .46836 L
.36398 .44165 L
.36726 .30166 L
.36889 .22492 L
.37042 .16058 L
.37117 .13419 L
.37188 .11328 L
.37227 .10373 L
.3727 .09504 L
.37309 .08879 L
.37345 .08445 L
.37366 .08257 L
.37386 .08129 L
.37396 .0808 L
.37407 .08038 L
.37413 .08023 L
.37419 .08011 L
.37425 .08003 L
.3743 .07999 L
.3744 .08001 L
.3745 .08013 L
Mistroke
.3746 .08038 L
.37465 .08055 L
.37471 .08078 L
.37491 .08187 L
.3751 .08331 L
.37547 .0874 L
.37582 .09254 L
.37659 .10893 L
.37738 .13195 L
.37811 .1586 L
.37977 .23393 L
.3829 .39847 L
.3845 .47175 L
.3854 .50442 L
.38583 .51718 L
.38623 .52733 L
.38662 .53536 L
.38698 .54114 L
.38716 .54359 L
.38737 .54576 L
.38748 .54673 L
.38759 .54748 L
.38769 .54811 L
.38779 .54856 L
.3879 .5489 L
.38795 .54903 L
.38801 .54911 L
.3881 .54917 L
.38816 .54915 L
.38821 .54909 L
.38831 .54889 L
.38839 .54861 L
.3885 .54817 L
.38859 .54763 L
.3888 .54601 L
.389 .544 L
.38944 .53769 L
.38981 .5305 L
.39022 .52091 L
.39094 .49894 L
.3926 .42986 L
.3959 .25155 L
.39755 .16906 L
.39836 .13595 L
.39908 .11135 L
.39945 .10122 L
.39985 .09204 L
.40022 .08514 L
.40057 .08036 L
.40075 .07838 L
Mistroke
.40093 .07696 L
.40103 .07633 L
.40113 .07588 L
.40118 .07567 L
.40123 .07549 L
.40133 .07527 L
.40143 .07518 L
.40149 .07518 L
.40154 .07522 L
.40164 .07542 L
.4017 .07559 L
.40176 .07579 L
.40185 .07621 L
.40195 .07679 L
.40215 .07836 L
.40235 .08048 L
.40257 .08339 L
.40297 .09023 L
.40372 .10827 L
.40459 .13721 L
.4054 .17038 L
.40856 .33309 L
.41014 .41322 L
.41159 .47203 L
.41198 .48422 L
.41239 .49571 L
.41279 .50483 L
.41315 .51146 L
.41335 .51447 L
.41357 .51715 L
.41369 .51837 L
.4138 .51932 L
.41392 .52014 L
.41402 .52076 L
.41411 .52117 L
.41421 .5215 L
.41426 .52164 L
.41432 .52173 L
.41441 .52181 L
.41452 .52176 L
.41461 .52159 L
.41472 .52128 L
.41477 .52107 L
.41483 .52079 L
.41502 .51961 L
.41522 .51781 L
.41544 .51536 L
.41564 .51258 L
.41638 .49814 L
.41681 .48714 L
Mistroke
.41719 .47555 L
.41806 .4446 L
.42127 .29543 L
.42274 .2277 L
.42357 .19449 L
.42435 .16848 L
.42512 .14856 L
.42555 .1401 L
.42595 .13418 L
.42616 .13169 L
.42636 .12985 L
.42658 .12837 L
.4267 .12778 L
.42676 .12758 L
.42681 .1274 L
.42687 .12727 L
.42692 .12717 L
.42702 .12707 L
.42707 .12706 L
.42713 .12709 L
.42719 .12715 L
.42724 .12724 L
.42734 .1275 L
.42739 .1277 L
.42744 .12791 L
.42764 .12898 L
.42783 .13048 L
.42801 .13222 L
.42841 .13741 L
.42877 .14339 L
.42914 .15104 L
.42993 .1715 L
.43079 .19948 L
.43405 .331 L
.43556 .3876 L
.43635 .41213 L
.43719 .43274 L
.43762 .44085 L
.43809 .44781 L
.43829 .45019 L
.43851 .4523 L
.43872 .45384 L
.43891 .45488 L
.43901 .45529 L
.43906 .45547 L
.43912 .45561 L
.43921 .4558 L
.43931 .45591 L
.43936 .45592 L
.43942 .45591 L
Mistroke
.43952 .45582 L
.43957 .45573 L
.43962 .45561 L
.43974 .45525 L
.43984 .45483 L
.43994 .45434 L
.44012 .45319 L
.44032 .4516 L
.44053 .44948 L
.44092 .44449 L
.44129 .43864 L
.44212 .4214 L
.44381 .37361 L
.44692 .27086 L
.44774 .2477 L
.44862 .22651 L
.44903 .21852 L
.44946 .21128 L
.44984 .20609 L
.45023 .20182 L
.45044 .2001 L
.45067 .19861 L
.45076 .19808 L
.45087 .1976 L
.45097 .19724 L
.45106 .19697 L
.45112 .19684 L
.45118 .19673 L
.45124 .19664 L
.4513 .19658 L
.45136 .19656 L
.45142 .19656 L
.45148 .19659 L
.45153 .19664 L
.45163 .19679 L
.45168 .19691 L
.45174 .19705 L
.45184 .19738 L
.45195 .19783 L
.45217 .19894 L
.45237 .20029 L
.45274 .20359 L
.45317 .20866 L
.45357 .21442 L
.45508 .24382 L
.45674 .28503 L
.45843 .3282 L
.45998 .36131 L
.46074 .37377 L
.46115 .37907 L
Mistroke
.46158 .38367 L
.46199 .38705 L
.46237 .38921 L
.46255 .38995 L
.46264 .39025 L
.46274 .39051 L
.46283 .39069 L
.46293 .39083 L
.46302 .39091 L
.4631 .39095 L
.4632 .39093 L
.46325 .3909 L
.46331 .39084 L
.46341 .3907 L
.4635 .39051 L
.46361 .39023 L
.46371 .38991 L
.46394 .38896 L
.46413 .38792 L
.46435 .38654 L
.46473 .38341 L
.46551 .37499 L
.46623 .36493 L
.46937 .30804 L
.47097 .28074 L
.47187 .26855 L
.4723 .26381 L
.4727 .26008 L
.47309 .25711 L
.47345 .25499 L
.47364 .25409 L
.47384 .2533 L
.47396 .25295 L
.47406 .25267 L
.47416 .25245 L
.47427 .25227 L
.47437 .25214 L
.47446 .25207 L
.47455 .25203 L
.47465 .25203 L
.47475 .25207 L
.47485 .25216 L
.47495 .2523 L
.47507 .2525 L
.4753 .25308 L
.47551 .25382 L
.47592 .25571 L
.47629 .25799 L
.4767 .26106 L
.47752 .26883 L
Mistroke
.479 .28651 L
.4807 .30885 L
.48224 .32721 L
.48301 .33453 L
.48341 .33779 L
.48384 .34074 L
.48425 .34306 L
.48463 .3447 L
.48481 .34533 L
.485 .3459 L
.48519 .34633 L
.48536 .34663 L
.48546 .34676 L
.48556 .34686 L
.48564 .34693 L
.48574 .34697 L
.48584 .34698 L
.48589 .34698 L
.48595 .34697 L
.48605 .34692 L
.48614 .34684 L
.48623 .34675 L
.48632 .34662 L
.48649 .34633 L
.48667 .34593 L
.48687 .34539 L
.48729 .3439 L
.48773 .34183 L
.48853 .33701 L
.49187 .30902 L
.49268 .30231 L
.49354 .29608 L
.49433 .29135 L
.49472 .28947 L
.49508 .28802 L
.49542 .28687 L
.49579 .2859 L
.49599 .28549 L
.49618 .28519 L
.49636 .28498 L
.49645 .28489 L
.49655 .28482 L
.49665 .28477 L
.4967 .28475 L
.49676 .28474 L
.49686 .28473 L
.49695 .28474 L
.49701 .28476 L
.49706 .28478 L
.49716 .28483 L
Mistroke
.49727 .28491 L
.49738 .28503 L
.49758 .28528 L
.49779 .28562 L
.49817 .28645 L
.49856 .28757 L
.49892 .28881 L
.49974 .29224 L
.50121 .29999 L
.50286 .30937 L
.50367 .31356 L
.50439 .3169 L
.50511 .31962 L
.50588 .32187 L
.5063 .32276 L
.50649 .32308 L
.50669 .32337 L
.50687 .32358 L
.50707 .32375 L
.50717 .32382 L
.50727 .32388 L
.50737 .32392 L
.50746 .32395 L
.50755 .32396 L
.50765 .32397 L
.50774 .32396 L
.50783 .32395 L
.50792 .32392 L
.50803 .32387 L
.50814 .32381 L
.50824 .32374 L
.50845 .32355 L
.50863 .32334 L
.50906 .32271 L
.50982 .32112 L
.51054 .31917 L
.51363 .30864 L
.51522 .30393 L
.51603 .30219 L
.51648 .30142 L
.51691 .30087 L
.51731 .30049 L
.51754 .30034 L
.51765 .30028 L
.51775 .30023 L
.51785 .3002 L
.51795 .30017 L
.51805 .30015 L
.51813 .30014 L
.51823 .30014 L
Mistroke
.51833 .30014 L
.51838 .30015 L
.51844 .30015 L
.51854 .30018 L
.51864 .3002 L
.51873 .30024 L
.51894 .30034 L
.51913 .30045 L
.51932 .3006 L
.52003 .30135 L
.52078 .30247 L
.5216 .30395 L
.52306 .307 L
.52465 .31019 L
.52548 .31162 L
.52594 .31228 L
.52637 .31282 L
.52679 .31325 L
.52724 .31362 L
.52744 .31376 L
.52765 .31387 L
.52784 .31396 L
.52802 .31402 L
.52821 .31407 L
.52831 .31409 L
.5284 .3141 L
.52849 .31411 L
.52857 .31411 L
.52866 .31411 L
.52875 .31411 L
.52885 .3141 L
.52895 .31409 L
.52905 .31407 L
.52914 .31405 L
.52934 .31399 L
.52956 .31391 L
.52996 .31371 L
.53032 .31347 L
.53114 .31277 L
.53261 .31113 L
.53428 .30911 L
.53502 .3083 L
.53582 .30753 L
.5366 .30693 L
.53697 .3067 L
.53732 .30653 L
.53772 .30637 L
.5379 .30632 L
.53809 .30627 L
.53819 .30625 L
Mistroke
.53829 .30623 L
.53839 .30621 L
.53848 .3062 L
.53859 .30619 L
.53864 .30619 L
.5387 .30619 L
.5388 .30618 L
.53886 .30618 L
.53891 .30618 L
.53901 .30619 L
.53906 .30619 L
.53912 .30619 L
.53922 .3062 L
.53931 .30621 L
.53952 .30625 L
.53975 .30629 L
.54016 .30641 L
.54054 .30655 L
.54127 .3069 L
.54203 .30735 L
.54509 .30937 L
.54591 .30981 L
.54667 .31013 L
.54709 .31028 L
.54755 .3104 L
.54776 .31044 L
.54797 .31047 L
.54815 .3105 L
.54835 .31052 L
.54846 .31053 L
.54856 .31053 L
.54865 .31054 L
.54875 .31054 L
.54885 .31054 L
.54894 .31054 L
.54902 .31054 L
.54911 .31054 L
.54921 .31054 L
.54932 .31053 L
.54943 .31052 L
.54954 .31051 L
.54993 .31046 L
.5503 .3104 L
.55064 .31033 L
.5514 .31012 L
.55306 .30954 L
.5546 .30898 L
.5561 .30854 L
.55685 .30838 L
.55728 .30832 L
Mistroke
.55749 .30829 L
.55768 .30827 L
.55789 .30825 L
.55808 .30824 L
.55829 .30823 L
.55841 .30822 L
.55846 .30822 L
.55852 .30822 L
.55861 .30822 L
.55872 .30822 L
.55881 .30822 L
.5589 .30822 L
.559 .30822 L
.5591 .30822 L
.55921 .30823 L
.55931 .30823 L
.55949 .30824 L
.55968 .30825 L
.56002 .30828 L
.56039 .30832 L
.5608 .30837 L
.56402 .30896 L
.56551 .30921 L
.56591 .30926 L
.56635 .30931 L
.56672 .30935 L
.56713 .30938 L
.56735 .30939 L
.56756 .3094 L
.56776 .30941 L
.56786 .30941 L
.56797 .30942 L
.56807 .30942 L
.56816 .30942 L
.56825 .30942 L
.56834 .30942 L
.56844 .30942 L
.56853 .30942 L
.56863 .30942 L
.56869 .30942 L
.56874 .30942 L
.56884 .30942 L
.56896 .30942 L
.56916 .30941 L
.56937 .30941 L
.56961 .3094 L
.57003 .30938 L
.57043 .30935 L
.57207 .30921 L
.57356 .30906 L
Mistroke
.57509 .30892 L
.57551 .3089 L
.57596 .30887 L
.57638 .30885 L
.57676 .30884 L
.57713 .30883 L
.57731 .30882 L
.57751 .30882 L
.57762 .30882 L
.57772 .30882 L
.57777 .30882 L
.57783 .30882 L
.57794 .30882 L
.57803 .30882 L
.57814 .30882 L
.57823 .30882 L
.57833 .30882 L
.57842 .30882 L
.57852 .30882 L
.57869 .30882 L
.57888 .30882 L
.57909 .30883 L
.57945 .30884 L
.57979 .30885 L
.58129 .30891 L
.58294 .30899 L
.58449 .30906 L
.58492 .30907 L
.58537 .30909 L
.58579 .3091 L
.58617 .3091 L
.58636 .30911 L
.58656 .30911 L
.58674 .30911 L
.58693 .30911 L
.58704 .30911 L
.58714 .30911 L
.58724 .30911 L
.5873 .30911 L
.58736 .30911 L
.58745 .30911 L
.58756 .30911 L
.58766 .30911 L
.58775 .30911 L
.58784 .30911 L
.58794 .30911 L
.58812 .30911 L
.5883 .30911 L
.58846 .30911 L
.58883 .30911 L
Mistroke
.58922 .3091 L
.5908 .30907 L
.59227 .30903 L
.59377 .309 L
.59418 .30899 L
.59462 .30899 L
.59499 .30898 L
.5954 .30898 L
.59562 .30898 L
.59582 .30897 L
.59602 .30897 L
.59621 .30897 L
.59632 .30897 L
.59642 .30897 L
.59653 .30897 L
.59659 .30897 L
.59665 .30897 L
.5967 .30897 L
.59676 .30897 L
.59687 .30897 L
.59692 .30897 L
.59698 .30897 L
.59704 .30897 L
.5971 .30897 L
.59721 .30897 L
.59731 .30897 L
.59754 .30897 L
.59774 .30897 L
.59795 .30897 L
.59872 .30898 L
.59955 .30899 L
.60044 .309 L
.60206 .30902 L
.60289 .30902 L
.60367 .30903 L
.60409 .30903 L
.60447 .30904 L
.6049 .30904 L
.60514 .30904 L
.60536 .30904 L
.60545 .30904 L
.60555 .30904 L
.60564 .30904 L
.60573 .30904 L
.60583 .30904 L
.60589 .30904 L
.60594 .30904 L
.60603 .30904 L
.60614 .30904 L
.60619 .30904 L
Mistroke
.60624 .30904 L
.60636 .30904 L
.60646 .30904 L
.60657 .30904 L
.60696 .30904 L
.60733 .30904 L
.60767 .30903 L
.60844 .30903 L
.60994 .30902 L
.61156 .30902 L
.61245 .30901 L
.61284 .30901 L
.61327 .30901 L
.61367 .30901 L
.61405 .30901 L
.61426 .30901 L
.61445 .30901 L
.61455 .30901 L
.61466 .30901 L
.61472 .30901 L
.61478 .30901 L
.61483 .30901 L
.61488 .30901 L
.61498 .30901 L
.61507 .30901 L
.61517 .30901 L
.61527 .30901 L
.61532 .30901 L
.61538 .30901 L
.61549 .30901 L
.61568 .30901 L
.61587 .30901 L
.61607 .30901 L
.61642 .30901 L
.6173 .30901 L
.61809 .30901 L
.61977 .30902 L
.6205 .30902 L
.62131 .30902 L
.62169 .30902 L
.62209 .30902 L
.62244 .30902 L
.62282 .30902 L
.62304 .30902 L
.62324 .30902 L
.62344 .30902 L
.62354 .30902 L
.62359 .30902 L
.62365 .30902 L
.62375 .30902 L
Mistroke
.62384 .30902 L
.62393 .30902 L
.62404 .30902 L
.62413 .30902 L
.62423 .30902 L
.62432 .30902 L
.62441 .30902 L
.62459 .30902 L
.6248 .30902 L
.62521 .30902 L
.62595 .30902 L
.62762 .30902 L
.62931 .30902 L
.63012 .30902 L
.63086 .30902 L
.63123 .30902 L
.63163 .30902 L
.63183 .30902 L
.63202 .30902 L
.63223 .30902 L
.63235 .30902 L
.63246 .30902 L
.63255 .30902 L
.63264 .30902 L
.63273 .30902 L
.63281 .30902 L
.63291 .30902 L
.63301 .30902 L
.63311 .30902 L
.6332 .30902 L
.63338 .30902 L
.63358 .30902 L
.63398 .30902 L
.6344 .30902 L
.63479 .30902 L
.63554 .30902 L
.63721 .30902 L
.63798 .30902 L
.6388 .30902 L
.6392 .30902 L
.63958 .30902 L
.63994 .30902 L
.64028 .30902 L
.64048 .30902 L
.64065 .30902 L
.64085 .30902 L
.64096 .30902 L
.64106 .30902 L
.64116 .30902 L
.64127 .30902 L
Mistroke
.64136 .30902 L
.64146 .30902 L
.64152 .30902 L
.64157 .30902 L
.64162 .30902 L
.64168 .30902 L
.64178 .30902 L
.64189 .30902 L
.64209 .30902 L
.64226 .30902 L
.64266 .30902 L
.64338 .30902 L
.64505 .30902 L
.64659 .30902 L
.64736 .30902 L
.64809 .30902 L
.64845 .30902 L
.64884 .30902 L
.64906 .30902 L
.64928 .30902 L
.64947 .30902 L
.64957 .30902 L
.64967 .30902 L
.64978 .30902 L
.64983 .30902 L
.64989 .30902 L
.64999 .30902 L
.65008 .30902 L
.65014 .30902 L
.65019 .30902 L
.6503 .30902 L
.65035 .30902 L
.6504 .30902 L
.65052 .30902 L
.65071 .30902 L
.65091 .30902 L
.65132 .30902 L
.6521 .30902 L
.65282 .30902 L
.6543 .30902 L
.65515 .30902 L
.65593 .30902 L
.65671 .30902 L
.65714 .30902 L
.65754 .30902 L
.65776 .30902 L
.65796 .30902 L
.65806 .30902 L
.65818 .30902 L
.65824 .30902 L
Mistroke
.6583 .30902 L
.65836 .30902 L
.65841 .30902 L
.65852 .30902 L
.65862 .30902 L
.65867 .30902 L
.65872 .30902 L
.65878 .30902 L
.65884 .30902 L
.65903 .30902 L
.65914 .30902 L
.65924 .30902 L
.65962 .30902 L
.66002 .30902 L
.66075 .30902 L
.66241 .30902 L
.66401 .30902 L
.66445 .30902 L
.66491 .30902 L
.66531 .30902 L
.66553 .30902 L
.66574 .30902 L
.66594 .30902 L
.66616 .30902 L
.66626 .30902 L
.66636 .30902 L
.66645 .30902 L
.66654 .30902 L
.66665 .30902 L
.66671 .30902 L
.66677 .30902 L
.66688 .30902 L
.66694 .30902 L
.66699 .30902 L
.66709 .30902 L
.66719 .30902 L
.6673 .30902 L
.6674 .30902 L
.66759 .30902 L
.66779 .30902 L
.66814 .30902 L
.66895 .30902 L
.67053 .30902 L
.67198 .30902 L
.67274 .30902 L
.67312 .30902 L
.67354 .30902 L
.67395 .30902 L
.67414 .30902 L
.67434 .30902 L
Mistroke
.67446 .30902 L
.67457 .30902 L
.67468 .30902 L
.67479 .30902 L
.6749 .30902 L
.675 .30902 L
.6751 .30902 L
.67516 .30902 L
.67521 .30902 L
.67532 .30902 L
.67541 .30902 L
.6755 .30902 L
.6756 .30902 L
.67581 .30902 L
.676 .30902 L
.67636 .30902 L
.67674 .30902 L
.6784 .30902 L
.68 .30902 L
.6807 .30902 L
.68146 .30902 L
.68188 .30902 L
.68206 .30902 L
.68227 .30902 L
.68244 .30902 L
.68264 .30902 L
.68274 .30902 L
.68284 .30902 L
.68294 .30902 L
.68303 .30902 L
.68313 .30902 L
.68319 .30902 L
.68324 .30902 L
.68334 .30902 L
.68344 .30902 L
.6835 .30902 L
.68356 .30902 L
.68362 .30902 L
.68368 .30902 L
.68378 .30902 L
.68389 .30902 L
.68411 .30902 L
.68432 .30902 L
.68471 .30902 L
.68548 .30902 L
.68631 .30902 L
.68779 .30902 L
.68854 .30902 L
.68893 .30902 L
.68935 .30902 L
Mistroke
.68971 .30902 L
.69011 .30902 L
.69029 .30902 L
.69048 .30902 L
.69064 .30902 L
.69082 .30902 L
.69092 .30902 L
.69102 .30902 L
.69114 .30902 L
.69119 .30902 L
.69124 .30902 L
.69135 .30902 L
.69145 .30902 L
.69155 .30902 L
.69164 .30902 L
.69169 .30902 L
.69175 .30902 L
.69186 .30902 L
.69197 .30902 L
.69207 .30902 L
.69229 .30902 L
.69253 .30902 L
.6933 .30902 L
.69415 .30902 L
.69585 .30902 L
.69665 .30902 L
.69739 .30902 L
.69777 .30902 L
.69816 .30902 L
.69856 .30902 L
.69879 .30902 L
.69889 .30902 L
.699 .30902 L
.69909 .30902 L
.69919 .30902 L
.69929 .30902 L
.69938 .30902 L
.69948 .30902 L
.69957 .30902 L
.69965 .30902 L
.69973 .30902 L
.69983 .30902 L
.69993 .30902 L
.70014 .30902 L
.70034 .30902 L
.70052 .30902 L
.70136 .30902 L
.70215 .30902 L
.70364 .30902 L
.70441 .30902 L
Mistroke
.70524 .30902 L
.70557 .30902 L
.70594 .30902 L
.70615 .30902 L
.70634 .30902 L
.70653 .30902 L
.70671 .30902 L
.70681 .30902 L
.70691 .30902 L
.707 .30902 L
.70709 .30902 L
.7072 .30902 L
.70725 .30902 L
.70731 .30902 L
.7074 .30902 L
.7075 .30902 L
.70759 .30902 L
.7077 .30902 L
.70779 .30902 L
.70788 .30902 L
.70805 .30902 L
.70823 .30902 L
.70868 .30902 L
.7091 .30902 L
.70989 .30902 L
.71137 .30902 L
.71221 .30902 L
.71299 .30902 L
.71338 .30902 L
.71376 .30902 L
.71397 .30902 L
.71419 .30902 L
.7144 .30902 L
.71459 .30902 L
.71479 .30902 L
.7149 .30902 L
.71495 .30902 L
.71501 .30902 L
.71507 .30902 L
.71513 .30902 L
.71519 .30902 L
.71525 .30902 L
.71531 .30902 L
.71536 .30902 L
.71547 .30902 L
.71557 .30902 L
.71567 .30902 L
.71586 .30902 L
.71606 .30902 L
.71628 .30902 L
Mistroke
.7171 .30902 L
.71784 .30902 L
.71952 .30902 L
.72026 .30902 L
.72105 .30902 L
.7215 .30902 L
.72191 .30902 L
.72211 .30902 L
.72232 .30902 L
.72242 .30902 L
.72253 .30902 L
.72262 .30902 L
.72271 .30902 L
.72281 .30902 L
.72286 .30902 L
.72292 .30902 L
.72301 .30902 L
.72311 .30902 L
.7232 .30902 L
.7233 .30902 L
.72339 .30902 L
.72347 .30902 L
.72367 .30902 L
.72389 .30902 L
.72429 .30902 L
.72506 .30902 L
.72576 .30902 L
.72727 .30902 L
.72807 .30902 L
.7289 .30902 L
.72933 .30902 L
.72956 .30902 L
.7298 .30902 L
.73002 .30902 L
.73022 .30902 L
.73032 .30902 L
.73043 .30902 L
.73053 .30902 L
.73062 .30902 L
.73071 .30902 L
.73081 .30902 L
.73091 .30902 L
.73099 .30902 L
.73109 .30902 L
.73119 .30902 L
.73141 .30902 L
.73161 .30902 L
.73184 .30902 L
.73224 .30902 L
.73384 .30902 L
Mistroke
.73468 .30902 L
.73557 .30902 L
.73636 .30902 L
.73682 .30902 L
.73703 .30902 L
.73724 .30902 L
.73742 .30902 L
.73763 .30902 L
.73781 .30902 L
.73789 .30902 L
.73798 .30902 L
.73808 .30902 L
.73818 .30902 L
.73828 .30902 L
.73837 .30902 L
.73846 .30902 L
.73857 .30902 L
.73862 .30902 L
.73868 .30902 L
.73878 .30902 L
.73898 .30902 L
.7392 .30902 L
.7396 .30902 L
.74048 .30902 L
.7421 .30902 L
.74285 .30902 L
.74366 .30902 L
.74404 .30902 L
.74443 .30902 L
.74477 .30902 L
.74496 .30902 L
.74513 .30902 L
.74534 .30902 L
.74544 .30902 L
.74556 .30902 L
.74566 .30902 L
.74575 .30902 L
.74585 .30902 L
.74591 .30902 L
.74596 .30902 L
.74605 .30902 L
.74614 .30902 L
.74624 .30902 L
.74634 .30902 L
.74652 .30902 L
.74671 .30902 L
.74713 .30902 L
.74758 .30902 L
.74839 .30902 L
.74997 .30902 L
Mistroke
.7508 .30902 L
.75126 .30902 L
.75169 .30902 L
.7521 .30902 L
.75234 .30902 L
.75255 .30902 L
.75273 .30902 L
.75293 .30902 L
.75303 .30902 L
.75309 .30902 L
.75314 .30902 L
.75324 .30902 L
.75333 .30902 L
.75343 .30902 L
.75352 .30902 L
.75362 .30902 L
.75371 .30902 L
.7538 .30902 L
.75388 .30902 L
.75407 .30902 L
.75445 .30902 L
.75487 .30902 L
.75646 .30902 L
.75791 .30902 L
.7583 .30902 L
.75872 .30902 L
.75908 .30902 L
.75948 .30902 L
.75968 .30902 L
.7599 .30902 L
.76002 .30902 L
.76013 .30902 L
.76025 .30902 L
.76035 .30902 L
.76044 .30902 L
.76054 .30902 L
.76059 .30902 L
.76065 .30902 L
.76074 .30902 L
.76085 .30902 L
.76094 .30902 L
.76105 .30902 L
.7611 .30902 L
.76116 .30902 L
.76136 .30902 L
.76158 .30902 L
.76197 .30902 L
.76272 .30902 L
.7644 .30902 L
.76521 .30902 L
Mistroke
.76598 .30902 L
.7664 .30902 L
.76663 .30902 L
.76686 .30902 L
.76706 .30902 L
.76728 .30902 L
.76748 .30902 L
.76766 .30902 L
.76777 .30902 L
.76782 .30902 L
.76787 .30902 L
.76797 .30902 L
.76807 .30902 L
.76812 .30902 L
.76818 .30902 L
.76828 .30902 L
.76833 .30902 L
.76839 .30902 L
.7685 .30902 L
.76861 .30902 L
.76871 .30902 L
.76889 .30902 L
.7693 .30902 L
.77002 .30902 L
.77079 .30902 L
.77236 .30902 L
.77279 .30902 L
.77325 .30902 L
.77368 .30902 L
.77408 .30902 L
.77449 .30902 L
.7747 .30902 L
.77481 .30902 L
.77493 .30902 L
.77503 .30902 L
.77513 .30902 L
.77522 .30902 L
.77531 .30902 L
.77542 .30902 L
.77551 .30902 L
.77557 .30902 L
.77562 .30902 L
.77568 .30902 L
.77574 .30902 L
.77592 .30902 L
.77611 .30902 L
.77646 .30902 L
.77683 .30902 L
.77725 .30902 L
.77894 .30902 L
Mistroke
.77974 .30902 L
.78048 .30902 L
.78085 .30902 L
.78125 .30902 L
.78147 .30902 L
.78168 .30902 L
.78187 .30902 L
.78198 .30902 L
.78208 .30902 L
.78217 .30902 L
.78226 .30902 L
.78236 .30902 L
.78246 .30902 L
.78256 .30902 L
.78262 .30902 L
.78267 .30902 L
.78277 .30902 L
.78287 .30902 L
.78295 .30902 L
.78305 .30902 L
.78321 .30902 L
.78341 .30902 L
.7836 .30902 L
.78438 .30902 L
.78512 .30902 L
.78597 .30902 L
.78678 .30902 L
.78757 .30902 L
.78801 .30902 L
.78842 .30902 L
.78877 .30902 L
.78896 .30902 L
.78915 .30902 L
.78925 .30902 L
.78934 .30902 L
.78943 .30902 L
.78952 .30902 L
.78962 .30902 L
.78971 .30902 L
.78976 .30902 L
.78982 .30902 L
.78991 .30902 L
.79001 .30902 L
.79011 .30902 L
.7902 .30902 L
.79029 .30902 L
.7905 .30902 L
.7907 .30902 L
.7911 .30902 L
.79153 .30902 L
Mistroke
.79301 .30902 L
.79384 .30902 L
.79461 .30902 L
.79502 .30902 L
.79541 .30902 L
.79583 .30902 L
.79607 .30902 L
.79618 .30902 L
.79629 .30902 L
.7964 .30902 L
.7965 .30902 L
.7966 .30902 L
.7967 .30902 L
.79679 .30902 L
.79687 .30902 L
.79696 .30902 L
.79706 .30902 L
.79717 .30902 L
.79728 .30902 L
.79749 .30902 L
.79769 .30902 L
.79788 .30902 L
.7986 .30902 L
.79936 .30902 L
.80013 .30902 L
.80094 .30902 L
.80163 .30902 L
.80203 .30902 L
.80239 .30902 L
.80278 .30902 L
.80299 .30902 L
.80319 .30902 L
.80328 .30902 L
.80338 .30902 L
.80346 .30902 L
.80355 .30902 L
.80365 .30902 L
.80374 .30902 L
.80379 .30902 L
.80384 .30902 L
.80394 .30902 L
.80405 .30902 L
.80414 .30902 L
.80419 .30902 L
.80425 .30902 L
.80436 .30902 L
.80456 .30902 L
.80474 .30902 L
.80517 .30902 L
.80561 .30902 L
Mistroke
.80721 .30902 L
.80791 .30902 L
.80866 .30902 L
.80908 .30902 L
.80947 .30902 L
.80984 .30902 L
.81003 .30902 L
.81023 .30902 L
.81034 .30902 L
.81045 .30902 L
.81055 .30902 L
.81065 .30902 L
.81071 .30902 L
.81076 .30902 L
.81083 .30902 L
.81088 .30902 L
.81099 .30902 L
.81105 .30902 L
.8111 .30902 L
.8112 .30902 L
.81129 .30902 L
.81149 .30902 L
.8117 .30902 L
.81191 .30902 L
.81273 .30902 L
.81361 .30902 L
.81438 .30902 L
.81523 .30902 L
.81562 .30902 L
.81605 .30902 L
.81645 .30902 L
.81681 .30902 L
.81702 .30902 L
.81721 .30902 L
.81731 .30902 L
.81741 .30902 L
.81747 .30902 L
.81753 .30902 L
.81758 .30902 L
.81763 .30902 L
.81774 .30902 L
.81779 .30902 L
.81785 .30902 L
.81791 .30902 L
.81797 .30902 L
.81803 .30902 L
.81808 .30902 L
.81819 .30902 L
.8183 .30902 L
.8185 .30902 L
Mistroke
.81893 .30902 L
.81933 .30902 L
.82022 .30902 L
.82106 .30902 L
.82184 .30902 L
.82257 .30902 L
.82298 .30902 L
.82335 .30902 L
.82355 .30902 L
.82376 .30902 L
.82387 .30902 L
.82399 .30902 L
.8241 .30902 L
.8242 .30902 L
.8243 .30902 L
.8244 .30902 L
.8245 .30902 L
.82456 .30902 L
.82462 .30902 L
.82472 .30902 L
.82481 .30902 L
.82491 .30902 L
.82501 .30902 L
.8251 .30902 L
.8252 .30902 L
.82538 .30902 L
.82579 .30902 L
.82661 .30902 L
.8281 .30902 L
.82891 .30902 L
.82934 .30902 L
.8298 .30902 L
.83002 .30902 L
.83024 .30902 L
.83044 .30902 L
.83063 .30902 L
.83082 .30902 L
.83101 .30902 L
.83111 .30902 L
.8312 .30902 L
.8313 .30902 L
.83136 .30902 L
.83141 .30902 L
.83151 .30902 L
.83159 .30902 L
.83169 .30902 L
.8318 .30902 L
.83191 .30902 L
.83201 .30902 L
.83221 .30902 L
Mistroke
.83256 .30902 L
.83295 .30902 L
.83461 .30902 L
.83543 .30902 L
.83619 .30902 L
.83661 .30902 L
.83684 .30902 L
.83707 .30902 L
.83727 .30902 L
.83749 .30902 L
.83759 .30902 L
.83769 .30902 L
.83778 .30902 L
.83787 .30902 L
.83797 .30902 L
.83802 .30902 L
.83808 .30902 L
.83813 .30902 L
.83819 .30902 L
.8383 .30902 L
.83839 .30902 L
.83848 .30902 L
.83858 .30902 L
.83869 .30902 L
.83893 .30902 L
.83915 .30902 L
.83958 .30902 L
.84119 .30902 L
.84197 .30902 L
.8424 .30902 L
.8428 .30902 L
.84317 .30902 L
.8435 .30902 L
.84388 .30902 L
.84408 .30902 L
.84428 .30902 L
.84438 .30902 L
.84449 .30902 L
.84459 .30902 L
.84468 .30902 L
.84477 .30902 L
.84486 .30902 L
.84496 .30902 L
.84505 .30902 L
.8451 .30902 L
.84515 .30902 L
.84526 .30902 L
.84535 .30902 L
.84544 .30902 L
.84565 .30902 L
Mistroke
.84587 .30902 L
.84657 .30902 L
.84735 .30902 L
.84817 .30902 L
.84903 .30902 L
.84977 .30902 L
.85019 .30902 L
.85057 .30902 L
.85077 .30902 L
.85087 .30902 L
.85098 .30902 L
.85108 .30902 L
.85118 .30902 L
.85127 .30902 L
.85136 .30902 L
.85146 .30902 L
.85154 .30902 L
.85162 .30902 L
.85171 .30902 L
.8518 .30902 L
.8519 .30902 L
.85199 .30902 L
.85208 .30902 L
.85229 .30902 L
.85248 .30902 L
.8529 .30902 L
.85368 .30902 L
.85448 .30902 L
.85533 .30902 L
.85574 .30902 L
.85613 .30902 L
.85648 .30902 L
.85686 .30902 L
.85723 .30902 L
.85743 .30902 L
.85762 .30902 L
.85771 .30902 L
.8578 .30902 L
.85788 .30902 L
.85796 .30902 L
.85805 .30902 L
.85813 .30902 L
.85823 .30902 L
.85832 .30902 L
.85842 .30902 L
.85853 .30902 L
.85862 .30902 L
.85872 .30902 L
.85894 .30902 L
.85914 .30902 L
Mistroke
.85991 .30902 L
.86141 .30902 L
.8622 .30902 L
.86263 .30902 L
.86304 .30902 L
.86346 .30902 L
.86368 .30902 L
.86392 .30902 L
.86413 .30902 L
.86423 .30902 L
.86435 .30902 L
.86445 .30902 L
.86455 .30902 L
.86465 .30902 L
.86474 .30902 L
.86484 .30902 L
.86489 .30902 L
.86495 .30902 L
.86505 .30902 L
.86514 .30902 L
.86535 .30902 L
.86557 .30902 L
.86598 .30902 L
.86636 .30902 L
.86801 .30902 L
.86882 .30902 L
.86955 .30902 L
.86991 .30902 L
.87011 .30902 L
.87031 .30902 L
.87049 .30902 L
.87069 .30902 L
.87077 .30902 L
.87087 .30902 L
.87095 .30902 L
.87103 .30902 L
.87114 .30902 L
.87124 .30902 L
.87134 .30902 L
.8714 .30902 L
.87146 .30902 L
.87156 .30902 L
.87165 .30902 L
.87186 .30902 L
.87204 .30902 L
.87223 .30902 L
.87262 .30902 L
.87433 .30902 L
.87513 .30902 L
.87588 .30902 L
Mistroke
.87625 .30902 L
.87665 .30902 L
.87686 .30902 L
.87705 .30902 L
.87726 .30902 L
.87738 .30902 L
.87743 .30902 L
.87749 .30902 L
.87759 .30902 L
.87769 .30902 L
.87778 .30902 L
.87787 .30902 L
.87797 .30902 L
.87806 .30902 L
.87816 .30902 L
.87827 .30902 L
.87863 .30902 L
.87901 .30902 L
.88072 .30902 L
.88152 .30902 L
.88227 .30902 L
.88264 .30902 L
.88304 .30902 L
.88324 .30902 L
.88344 .30902 L
.88365 .30902 L
.88377 .30902 L
.88388 .30902 L
.88397 .30902 L
.88407 .30902 L
.88416 .30902 L
.88425 .30902 L
.88435 .30902 L
.88441 .30902 L
.88446 .30902 L
.88456 .30902 L
.88466 .30902 L
.88484 .30902 L
.88501 .30902 L
.8854 .30902 L
.88689 .30902 L
.88768 .30902 L
.88852 .30902 L
.88894 .30902 L
.88917 .30902 L
.88941 .30902 L
.88963 .30902 L
.88983 .30902 L
.89002 .30902 L
.89012 .30902 L
Mistroke
.89023 .30902 L
.89028 .30902 L
.89034 .30902 L
.89044 .30902 L
.89054 .30902 L
.89063 .30902 L
.89073 .30902 L
.89079 .30902 L
.89084 .30902 L
.89095 .30902 L
.89107 .30902 L
.89127 .30902 L
.89147 .30902 L
.89184 .30902 L
.89346 .30902 L
.89416 .30902 L
.89491 .30902 L
.89534 .30902 L
.89553 .30902 L
.89573 .30902 L
.89591 .30902 L
.8961 .30902 L
.89621 .30902 L
.89631 .30902 L
.8964 .30902 L
.8965 .30902 L
.8966 .30902 L
.89666 .30902 L
.89671 .30902 L
.89681 .30902 L
.89691 .30902 L
.89697 .30902 L
.89703 .30902 L
.89709 .30902 L
.89715 .30902 L
.89725 .30902 L
.89736 .30902 L
.89758 .30902 L
.89779 .30902 L
.89818 .30902 L
.89966 .30902 L
.90049 .30902 L
.9009 .30902 L
.90128 .30902 L
.90165 .30902 L
.90205 .30902 L
.90227 .30902 L
.90247 .30902 L
.90267 .30902 L
.90277 .30902 L
Mistroke
.90282 .30902 L
.90288 .30902 L
.90293 .30902 L
.90298 .30902 L
.90304 .30902 L
.90309 .30902 L
.9032 .30902 L
.90329 .30902 L
.90335 .30902 L
.90341 .30902 L
.90347 .30902 L
.90353 .30902 L
.90375 .30902 L
.90395 .30902 L
.90414 .30902 L
.90457 .30902 L
.90606 .30902 L
.90684 .30902 L
.90727 .30902 L
.90768 .30902 L
.9079 .30902 L
.90814 .30902 L
.90834 .30902 L
.90856 .30902 L
.90877 .30902 L
.90887 .30902 L
.90899 .30902 L
.90909 .30902 L
.90919 .30902 L
.90929 .30902 L
.90938 .30902 L
.90947 .30902 L
.90957 .30902 L
.90963 .30902 L
.90968 .30902 L
.90978 .30902 L
.90988 .30902 L
.90997 .30902 L
.91015 .30902 L
.91055 .30902 L
.91099 .30902 L
.91187 .30902 L
.9127 .30902 L
.91309 .30902 L
.91351 .30902 L
.91389 .30902 L
.91425 .30902 L
.9146 .30902 L
.91479 .30902 L
.91497 .30902 L
Mistroke
.91516 .30902 L
.91527 .30902 L
.91537 .30902 L
.91546 .30902 L
.91556 .30902 L
.91566 .30902 L
.91576 .30902 L
.91585 .30902 L
.91596 .30902 L
.91607 .30902 L
.91617 .30902 L
.91635 .30902 L
.91654 .30902 L
.91739 .30902 L
.91898 .30902 L
.91942 .30902 L
.91988 .30902 L
.92028 .30902 L
.9205 .30902 L
.92072 .30902 L
.92091 .30902 L
.92113 .30902 L
.92123 .30902 L
.92133 .30902 L
.92142 .30902 L
.92151 .30902 L
.92157 .30902 L
.92162 .30902 L
.92168 .30902 L
.92174 .30902 L
.9218 .30902 L
.92186 .30902 L
.92196 .30902 L
.92202 .30902 L
.92207 .30902 L
.92218 .30902 L
.92228 .30902 L
.92237 .30902 L
.92273 .30902 L
.92312 .30902 L
.92392 .30902 L
.92474 .30902 L
.9256 .30902 L
.92596 .30902 L
.92634 .30902 L
.92656 .30902 L
.92676 .30902 L
.92694 .30902 L
.92715 .30902 L
.92734 .30902 L
Mistroke
.92744 .30902 L
.92755 .30902 L
.92765 .30902 L
.92774 .30902 L
.92783 .30902 L
.92791 .30902 L
.92801 .30902 L
.92807 .30902 L
.92812 .30902 L
.92822 .30902 L
.92831 .30902 L
.92842 .30902 L
.92852 .30902 L
.92875 .30902 L
.9291 .30902 L
.92948 .30902 L
.93025 .30902 L
.93106 .30902 L
.93182 .30902 L
.93224 .30902 L
.93247 .30902 L
.9327 .30902 L
.9329 .30902 L
.93312 .30902 L
.93332 .30902 L
.9335 .30902 L
.9336 .30902 L
.9337 .30902 L
.93379 .30902 L
.93388 .30902 L
.93398 .30902 L
.93404 .30902 L
.93409 .30902 L
.93419 .30902 L
.93429 .30902 L
.93439 .30902 L
.9345 .30902 L
.93469 .30902 L
.93492 .30902 L
.93513 .30902 L
.93661 .30902 L
.93735 .30902 L
.93814 .30902 L
.93855 .30902 L
.93877 .30902 L
.93901 .30902 L
.93922 .30902 L
.93942 .30902 L
.93961 .30902 L
.9397 .30902 L
Mistroke
.93981 .30902 L
.93991 .30902 L
.94001 .30902 L
.94006 .30902 L
.94012 .30902 L
.94018 .30902 L
.94023 .30902 L
.94033 .30902 L
.94043 .30902 L
.94053 .30902 L
.94063 .30902 L
.94099 .30902 L
.94138 .30902 L
.94306 .30902 L
.94388 .30902 L
.94428 .30902 L
.94464 .30902 L
.94507 .30902 L
.94529 .30902 L
.9454 .30902 L
.94553 .30902 L
.94563 .30902 L
.94572 .30902 L
.94582 .30902 L
.94591 .30902 L
.94601 .30902 L
.94611 .30902 L
.94621 .30902 L
.94627 .30902 L
.94633 .30902 L
.94642 .30902 L
.94652 .30902 L
.94662 .30902 L
.94672 .30902 L
.94714 .30902 L
.94753 .30902 L
.94788 .30902 L
.94875 .30902 L
.94956 .30902 L
.9503 .30902 L
.95068 .30902 L
.9511 .30902 L
.95131 .30902 L
.95151 .30902 L
.95162 .30902 L
.95174 .30902 L
.9518 .30902 L
.95186 .30902 L
.95196 .30902 L
.95206 .30902 L
Mistroke
.95212 .30902 L
.95218 .30902 L
.95228 .30902 L
.95238 .30902 L
.95248 .30902 L
.95257 .30902 L
.95277 .30902 L
.95298 .30902 L
.95317 .30902 L
.95361 .30902 L
.95441 .30902 L
.95512 .30902 L
.9559 .30902 L
.9563 .30902 L
.95667 .30902 L
.95685 .30902 L
.95704 .30902 L
.95723 .30902 L
.9574 .30902 L
.9575 .30902 L
.95762 .30902 L
.95772 .30902 L
.95781 .30902 L
.95792 .30902 L
.95797 .30902 L
.95803 .30902 L
.95809 .30902 L
.95814 .30902 L
.9582 .30902 L
.95826 .30902 L
.95835 .30902 L
.95846 .30902 L
.95854 .30902 L
.95864 .30902 L
.95905 .30902 L
.95945 .30902 L
.95986 .30902 L
.96061 .30902 L
.96142 .30902 L
.96186 .30902 L
.96228 .30902 L
.96268 .30902 L
.9629 .30902 L
.96311 .30902 L
.96328 .30902 L
.96348 .30902 L
.96357 .30902 L
.96368 .30902 L
.96377 .30902 L
.96386 .30902 L
Mistroke
.96396 .30902 L
.96405 .30902 L
.96414 .30902 L
.96423 .30902 L
.96432 .30902 L
.96443 .30902 L
.96462 .30902 L
.9648 .30902 L
.96499 .30902 L
.96534 .30902 L
.96694 .30902 L
.96763 .30902 L
.968 .30902 L
.96839 .30902 L
.96859 .30902 L
.96881 .30902 L
.96901 .30902 L
.9692 .30902 L
.96939 .30902 L
.96948 .30902 L
.96959 .30902 L
.96968 .30902 L
.96977 .30902 L
.96986 .30902 L
.96996 .30902 L
.97001 .30902 L
.97007 .30902 L
.97018 .30902 L
.97023 .30902 L
.97029 .30902 L
.97041 .30902 L
.97062 .30902 L
.97084 .30902 L
.97164 .30902 L
.97323 .30902 L
.97366 .30902 L
.97412 .30902 L
.97452 .30902 L
.97474 .30902 L
.97495 .30902 L
.97511 .30902 L
.97526 .30902 L
.9754 .30902 L
.97548 .30902 L
.97555 .30902 L
.97563 .30902 L
.97571 .30902 L
.97578 .30902 L
.97586 .30902 L
.97594 .30902 L
Mistroke
.97603 .30902 L
.97611 .30902 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{421.375, 260.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008>0001AB000`400?l00000o`00003ooooooooo
oooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo
003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooo
oooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool0
0?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooooooo
ool@ooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooo
ooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo0ol0003o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0
003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo
00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`
ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLoooo
o`00<?ooool3o`000?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?oo
ool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0
033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomco
oooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooo
oooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool3o`000?oooooo
g?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`1kooooo`;o0000oooooomOooooo`00<?oo
ool00ol0003oooooooooo`1kooooo`;o0000oooooomOooooo`004?ooool2onk^kP?ooooo0_o^k^hI
ooooo`03o`000?oooooooooo06oooooo0_l0000:ooooo`;o0000oooooomOooooo`002oooool2o`00
000:oa0@4?ooooooooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP?ooooo1?l000002?l@413o
ooooooooooo^k^ko<S8bo`000?lb<S;ok^k^2_ooool00ol0003oooooooooo`1_ooooo`;o00002_oo
ool2o`000?ooooooGoooool000cooooo00?o0000ooooooooool00_ooool01Oo^k^koEEEEomgMgOmE
EEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00[ooooo
00?o0000ooooooooool0Koooool2o`0000[ooooo0_l0003ooooooeoooooo00000ooooooo0000o`00
0004o`0000;ooooo1Ol00004ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@00[ooooo00?o0000ooooooooool0Koooool2o`0000[ooooo
0_l0003ooooooeoooooo0009ooooo`04odA4A?oMgMgoooooo`0000Cooooo00Gok^k^oeEEEOoMgMgo
EEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000:oooo
o`03o`000?oooooooooo06oooooo0_l0000:ooooo`;o0000oooooomOooooo`002Oooool01?oMgMgo
EEEEooooool00003ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000:ooooo`Co0000K_ooool2o`0000[ooooo
0_l0003ooooooeoooooo000:ooooo`03ogMgMoo<c<co000000?ooooo0_o^k^h3ooooo`;ok^k^1Ooo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41002_ooool00ol0003ooooo
ooooo`1_ooooo`;o00002_ooool2o`000?ooooooGoooool000[ooooo00?ok^k^odA4A?l000003ooo
ool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool2o`0000Gooooo
00?o0000ooooooooool0Koooool2o`0000[ooooo0_l0003ooooooeoooooo000;ooooo`03ogMgMol0
003ooooo00cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1_ooooo`;o00002_ooool2o`000?oo
ooooGoooool002Sooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1_ooooo`03
o`000?oooooo000000Wooooo0_l0003ooooooeoooooo000Xooooo`?o00001Oooool00ol0003ooooo
ooooo`1_ooooo`03o`000?oooooo000000Wooooo0_l0003ooooooeoooooo000Yooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0Koooool00ol0003oooooo`000009ooooo`;o0000oooo
oomOooooo`00:_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo06oooooo00?o0000
ooooool000002?ooool00ol0003oooooo`00003ooooooeoooooo000`ooooo`03o`000?oooooooooo
06oooooo00?o0000ooooool000002?ooool00ol0003oooooo`00003ooooooeoooooo000`ooooo`03
o`000?oooooooooo06oooooo00?o0000ooooool000002?ooool00ol0003oooooo`00003ooooooeoo
oooo000`ooooo`03o`000?oooooooooo06oooooo00?o0000ooooool000002?ooool00ol0003ooooo
o`00003ooooooeoooooo000`ooooo`03o`000?oooooooooo06oooooo00?o0000ooooool000002?oo
ool00ol0003oooooo`00003ooooooeoooooo000`ooooo`?o0000Koooool00ol0003oooooo`000008
ooooo`03o`000?oooooo00000?ooooooGoooool0033ooooo00?o0000ooooooooool0Koooool00ol0
003oooooo`000008ooooo`03o`000?oooooo00000?ooooooGoooool0033ooooo00?o0000oooooooo
ool0K_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`000?ooooooG_ooool0
033ooooo00?o0000ooooooooool0K_ooool01?l0003oooooooooool00008ooooo`04o`000?oooooo
ooooo`0000Sooooo0_l0003ooooooeCooooo000`ooooo`03o`000?oooooooooo06kooooo00Co0000
oooooooooooo00002?ooool01?l0003oooooooooool00008ooooo`;o0000oooooomDooooo`00<?oo
ool00ol0003oooooooooo`1^ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo
00002?ooool2o`000?ooooooE?ooool0033ooooo00?o0000ooooooooool0K_ooool01?l0003ooooo
ooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo0_l0003ooooooeCooooo000`ooooo`03
o`000?oooooooooo06kooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00008
ooooo`;o0000oooooomDooooo`00<?ooool00ol0003oooooooooo`1^ooooo`04o`000?oooooooooo
o`0000Sooooo00Co0000oooooooooooo00002?ooool2o`000?ooooooE?ooool0033ooooo00?o0000
ooooooooool0K_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo
0_l0003ooooooeCooooo000`ooooo`03o`000?oooooooooo06kooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool00008ooooo`;o0000oooooomDooooo`00<?ooool00ol0003ooooo
ooooo`1^ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002?ooool2o`00
0?ooooooE?ooool0033ooooo0ol0001Sooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooo
oooo00002?ooool01?l0003oooooooooool00008ooooo`;o0000oooooomDooooo`00<?ooool00ol0
003oooooooooo`1Sooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooo00002?ooool0
1?l0003oooooooooool00008ooooo`;o0000oooooomDooooo`00<?ooool00ol0003oooooooooo`1S
ooooo`;o00002Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo
0_l0003ooooooeCooooo000`ooooo`03o`000?oooooooooo06;ooooo00?o0000ooooool000002Ooo
ool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo0_l0003ooooooeCo
oooo000`ooooo`03o`000?oooooooooo06;ooooo00?o0000ooooool000002Oooool01?l0003ooooo
ooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo0_l0003ooooooeCooooo000`ooooo`03
o`000?oooooooooo06;ooooo00?o0000ooooool000002Oooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000Sooooo0_l0003ooooooeCooooo000`ooooo`03o`000?oooooooooo
06;ooooo00?o0000ooooool000002Oooool01?l0003oooooooooool00008ooooo`04o`000?oooooo
ooooo`0000Oooooo00?o0000ooooool00000oooooomDooooo`00<?ooool00ol0003oooooooooo`1R
ooooo`03o`000?oooooo000000Wooooo00Co0000oooooooooooo00002?ooool01?l0003ooooooooo
ool00007ooooo`04o`000?ooooooooooo`000?ooooooDoooool0033ooooo00?o0000ooooooooool0
H_ooool00ol0003oooooo`000009ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooo
oooo00001oooool01?l0003oooooooooool0003ooooooe?ooooo000`ooooo`03o`000?oooooooooo
06;ooooo00?o0000ooooool000002Oooool01?l0003oooooooooool00008ooooo`04o`000?oooooo
ooooo`0000Oooooo00Co0000oooooooooooo0000oooooomCooooo`00<?ooool00ol0003ooooooooo
o`1Rooooo`03o`000?oooooo000000Wooooo00Co0000oooooooooooo00002?ooool01?l0003ooooo
ooooool00007ooooo`04o`000?ooooooooooo`000?ooooooDoooool0033ooooo0ol0001Rooooo`03
o`000?oooooo000000Wooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00007
ooooo`04o`000?ooooooooooo`000?ooooooDoooool0033ooooo00?o0000ooooooooool0H_ooool0
0ol0003oooooo`000009ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000
1oooool01?l0003oooooooooool0003ooooooe?ooooo000`ooooo`03o`000?oooooooooo06;ooooo
00?o0000ooooool000002Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00
00Oooooo00Co0000oooooooooooo0000oooooomCooooo`00<?ooool00ol0003oooooooooo`1Roooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002?ooool01?l0003ooooooooo
ool00007ooooo`04o`000?ooooooooooo`000?ooooooDoooool0033ooooo00?o0000ooooooooool0
H_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooo
oooooooo00001oooool01?l0003oooooooooool0003ooooooe?ooooo000`ooooo`03o`000?oooooo
oooo06;ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00008ooooo`04o`00
0?ooooooooooo`0000Oooooo00Co0000oooooooooooo0000oooooomCooooo`00<?ooool00ol0003o
ooooooooo`1Qooooo`05o`000?ooooooooooooooool000002?ooool01?l0003oooooooooool00008
ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo0000oooooomCooooo`004?oo
ool2onk^kP?ooooo0_o^k^hIooooo`03o`000?oooooooooo067ooooo00Go0000oooooooooooooooo
o`000008ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001oooool01?l0
003oooooooooool0003ooooooe?ooooo0009ooooo`Go00000_ooool01oo^k^koEEEEonk^k_oooooo
k^k^oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h:oooo
o`03o`000?oooooooooo067ooooo00Go0000ooooooooooooooooo`000008ooooo`04o`000?oooooo
ooooo`0000Sooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool0003ooooooe?o
oooo0009ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01Oo^k^koEEEEomgMgOmEEEGok^k^
00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00[ooooo00?o0000
ooooooooool0HOooool01Ol0003ooooooooooooooooo000000Sooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`000?ooooooDoooool00003
ooooool0003o000000Co00000oooool00onHV9So8B4Qonk^kP05ooooo`03omgMgOl0003ogMgM00Oo
oooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00[ooooo00?o0000oooo
ooooool0HOooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`00
0008ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00002?ooool00ol0003o
ooooooooo`3oooooodSooooo000;ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Gok^k^oeEEEOoMgMgo
EEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000:oooo
o`03o`000?oooooooooo067ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00007ooooo`04o`000?oo
ooooooooo`0000Sooooo00?o0000ooooooooool0oooooom8ooooo`003?ooool02omgMgOoIVIVoooo
ooooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000000[ooooo1?l0001Pooooo`05o`000?ooooooooooooooool00000
1oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo
00001oooool01?l0003oooooooooool00008ooooo`;o0000oooooom9ooooo`003Oooool00ol0003o
ooooooooo`02onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooo
oooooooooa0@400:ooooo`03o`000?oooooooooo067ooooo00Go0000ooooooooooooooooo`000007
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0
0007ooooo`04o`000?ooooooooooo`0000Sooooo0_l0003oooooodWooooo0009ooooo`05o`000?nj
^[[ooooooiRHV?l@41003_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL00oooool2o`0000Gooooo00?o0000ooooooooool0HOooool01Ol0003ooooooooooooooooo0000
00Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`04o`000?oooooooooo
o`0000Oooooo00Co0000oooooooooooo00002?ooool2o`000?ooooooBOooool000Wooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c00<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP02ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0HOooool01Ol0003o
oooooooooooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05oooo
o`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00
003oooooodWooooo000Xooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0HOoo
ool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`05ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00001oooool00ol0
003oooooo`00003oooooodWooooo000Xooooo`?o00001Oooool00ol0003oooooooooo`1Qooooo`05
o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo00?o
0000ooooool00000oooooom9ooooo`00:Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo067ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Co
0000oooooooooooo00001oooool00ol0003oooooo`00003oooooodWooooo000Zooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0HOooool01Ol0003ooooooooooooooooo000000Oooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool01?l0003oooooooooool00007ooooo`03o`000?oooooo00000?oo
ooooBOooool0033ooooo00?o0000ooooooooool0HOooool01Ol0003ooooooooooooooooo000000Oo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00007ooooo`03o`000?oooooo0000
0?ooooooBOooool0033ooooo00?o0000ooooooooool0HOooool01Ol0003ooooooooooooooooo0000
00Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00007ooooo`03o`000?oooooo
00000?ooooooBOooool0033ooooo00?o0000ooooooooool0HOooool01Ol0003ooooooooooooooooo
000000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00007ooooo`03o`000?oo
oooo00000?ooooooBOooool0033ooooo00?o0000ooooooooool0HOooool01Ol0003ooooooooooooo
oooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00007ooooo`03o`00
0?oooooo00000?ooooooBOooool0033ooooo0ol0001Qooooo`05o`000?ooooooooooooooool00000
1oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool0
0000oooooom9ooooo`00<?ooool00ol0003oooooooooo`1Qooooo`05o`000?ooooooooooooooool0
00001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooo
oooooooo0000oooooom8ooooo`00<?ooool00ol0003oooooooooo`1Eooooo`;o00002_ooool01Ol0
003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0
0007ooooo`04o`000?ooooooooooo`000?ooooooB?ooool0033ooooo00?o0000ooooooooool0EOoo
ool2o`0000[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`000?oo
ooooB?ooool0033ooooo00?o0000ooooooooool0EOooool2o`0000[ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooo
ooooo`000006ooooo`04o`000?ooooooooooo`000?ooooooB?ooool0033ooooo00?o0000oooooooo
ool0EOooool2o`0000[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?oooooooooo
o`000?ooooooB?ooool0033ooooo00?o0000ooooooooool0EOooool00ol0003oooooo`000009oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04oooo
o`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool0003oooooodSooooo000`
ooooo`03o`000?oooooooooo05Cooooo00Co0000oooooooooooo00002Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000Kooooo00Co0000oooooooooooo0000oooooom8ooooo`00<?ooool00ol0003ooooo
ooooo`1Dooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006oooo
o`04o`000?ooooooooooo`000?ooooooB?ooool0033ooooo00?o0000ooooooooool0E?ooool01?l0
003oooooooooool00009ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003ooooooooo
ool0003oooooodSooooo000`ooooo`03o`000?oooooooooo05Cooooo00Co0000oooooooooooo0000
2Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo00001oooool00ol0
003oooooooooo`3oooooockooooo000`ooooo`03o`000?oooooooooo05Cooooo00Co0000oooooooo
oooo00002Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo00001ooo
ool2o`000?oooooo?oooool0033ooooo0ol0001Dooooo`04o`000?ooooooooooo`0000Sooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go
0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Oooooo0_l0003oooooocoo
oooo000`ooooo`03o`000?oooooooooo05Cooooo00Co0000oooooooooooo00002?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003o
oooooooooooooooo000000Kooooo00Co0000oooooooooooo00001oooool2o`000?oooooo?oooool0
033ooooo00?o0000ooooooooool0E?ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000
ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooool00000
ooooooloooooo`00<?ooool00ol0003oooooooooo`1Dooooo`05o`000?ooooooooooooooool00000
1oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooo
ooooo`000006ooooo`03o`000?oooooo00000?oooooo?oooool0033ooooo00?o0000ooooooooool0
E?ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooo`00003ooooo
ocoooooo000`ooooo`03o`000?oooooooooo04kooooo0_o^k^h3ooooo`03onk^k_l0003ooooo00;o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo000000oooooo0_o^k^h3oooo
o`;ok^k^H?ooool2onk^kP?ooooo0_o^k^i>ooooo`;ok^k^0oooool2onk^kVcooooo000`ooooo`03
o`000?oooooooooo04Sooooo00goA4A4o`000?l0003o<S8bomgMgOooooook^k^oeEEEOo^k^kooooo
onk^k_l0003ok^k^00?ooooo1?l000001?l@413oooooooooooo^k^h2o`000005oc8b<_o^k^kooooo
ooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooool000002Ooo
ool4o`000009oa0@4?ooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@
413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^>oooool4o`000003oa0@4?oooooooooo00;ooooo
0_lQ8B45ooooo`0=odA4A?l0003o0000oc8b<_oMgMgoooooonk^k_mEEEGok^k^ooooooo^k^koEEEE
onk^kP03ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kSSooooo1Ol00002
ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co000000So410@oooooooooooo
k^k^oc8b<_l0003o<S8bonk^kUgooooo000`ooooo`03o`000?oooooooooo04_ooooo00WoMgMgoc8b
<_ooooooooooonk^k_mEEEGogMgMoeEEEOl000001?ooool00ol0003oooooo`000004ooooo`05ogMg
Mol0003ooooooiRHV?mgMgL00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooooooooooo
ool000001_ooool00ol0003oooooo`00000;ooooo`03o`000?oooooooooo00;ooooo00Gok^k^oeEE
EOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0mooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`09ogMgMolb<S;oooooooooooo^k^ko
EEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg03Sooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h0
1_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0GOooool0033ooooo
00?o0000ooooooooool0C?ooool02?l0003ooooooooooooooooogMgMo`000?oMgMgo00001?ooool0
0ol0003oooooo`000004ooooo`05oa0@4?l0003oooooooooool@41000_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooo`00000;ooooo`03o`00
0?oooooooooo00?ooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@
4?ooooooooooooooool@4100?Oooool00ol0003oooooooooo`0?ooooo`07o`000?oooooooooooooo
oooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
400iooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?ogMgMo`000?oMgMd01oooool00ol0003ooooooooo
o`02ooooo`05oa0@4?ooooooooooooooool@4100GOooool0033ooooo00?o0000ooooooooool0Booo
ool02OmgMgOo<S8booooooooooook^k^oeEEEOoMgMgoEEEEo`000004ooooo`03o`000?oooooo0000
00Cooooo0_l00002ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooo000000_ooooo00?o0000ooooooooool00_ooool01Oo^k^koEEEEomgM
gOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000003go
oooo00?o0000ooooooooool03_ooool02OmgMgOo<S8booooooooooook^k^oeEEEOoMgMgoEEEEonk^
kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000jooooo`03oiRH
V?lQ8B7ok^k^00?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`00001Mooooo`00<?ooool00ol0003oooooooooo`18ooooo`0=
o`000?lQ8B7o0000oc8b<_o<c<coooooonk^k_mEEEGok^k^ooooooo^k^ko0000onk^kP03ooooo`03
o`000?oooooo000000Cooooo0_l00002ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooo000000_ooooo00_o0000ooooooooooooooooonk^
k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`00000mooooo`03o`000?oooooooooo00_ooooo00go0000ob4Q8Ol0003o<S8bolc<
c?ooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000003_ooooo00_oMgMgofIVI_ooooooooooonk^k_mEEEGok^k^oooo
ooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
001Mooooo`00<?ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00?ooooo0_o^k^h3
ooooo`03o`000?o^k^kooooo00;ooooo00?o0000ooooool000001?ooool01Ol@413o0000oooooooo
oooo410@00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Kooooo
00Co0000oooooooooooo00002_ooool01?l0003oooooooooooooool2onk^kP?ooooo0_o^k^h5oooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400mooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool00oooool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooo
oooo00;ooooo00Go410@oooooooooooooooooa0@400looooo`03o`000?oooooooooo00;ok^k^0ooo
ool2onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@05gooooo
000`ooooo`?o0000B?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooool000001?ooool01OmgMgOo0000oooooonHV9SoMgMg00;ooooo00?o0000ooooooooool0
0oooool2o`0000Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`00
0?ooooooooooooooool000001_ooool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo0_l0000c
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool2o`0002kooooo00Go0000okZj^_ooooooV9RH
oa0@400>ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`;o
0000Doooool0033ooooo00?o0000ooooooooool0B?ooool4o`0000Oooooo00?o0000ooooooooool0
0_ooool00ol0003oIVIVo`000004ooooo`05onk^k_l0003o0000oc8b<_o^k^h00_ooool00ol0003o
ooooooooo`03ooooo`;o00001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Kooooo0_l00000
0omEEEGoIVIVo`00000=ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP07ooooo`04o`000?ooooooooooo`00033ooooo00?oEEEEofIVI_l000003Oooool4o`0000cooooo
00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oooooo00Co0000oooooooo
oooo0000;Oooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo00?oEEEEofIVI_l000001?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Oooooo00Co0000oooooooooooo0000D_ooool0033ooooo00?o
0000ooooooooool0A_ooool3o`0000Wooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00?ooooo1?l00003ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool00000
1_ooool01?l0003oooooooooool00006ooooo`?o00007Oooool4o`000005ooooool0003ooooooooo
ool00000G_ooool4o`000005ooooool0003oooooooooool00000C?ooool4o`000005ooooool0003o
ooooooooool00000D_ooool0033ooooo00?o0000ooooooooool0AOooool2o`000003ooooool0003o
oooo00Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Kooooo00Co
0000oooooooooooo00001_ooool00ol0003oooooo`00000Rooooo`?o0000I?ooool3o`0005;ooooo
0ol0001Cooooo`00<?ooool00ol0003oooooooooo`15ooooo`04o`000?ooooooooooo`0000Wooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00_ooool01?l0003oooooo`000?l00003ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooo
oooooooo00001_ooool00ol0003oooooo`00000Sooooo`03o`000?oooooooooo06Cooooo00?o0000
ooooooooool0D_ooool00ol0003oooooooooo`1Booooo`00<?ooool00ol0003oooooooooo`15oooo
o`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`Co00000oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00
0006ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooool000009?ooool00ol0003ooooo
ooooo`1Tooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0DOooool0033ooooo00?o
0000ooooooooool0A?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Gooooo00Go0000oooooooooooo
ooooo`000005ooooo`05o`000?ooooooooooooooool00000ooooooldooooo`00<?ooool00ol0003o
ooooooooo`14ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
oooo0?3ooooo00?oMgMgofIVI_ooool0;Oooool00omVIVKoMgMgooooo`07ooooo`00<?ooool00ol0
003oooooooooo`13ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000005ooooo`?o0000l?oo
ool00ooMgMgo410@onk^kP0^ooooo`03onk^k_l@413ogMgM00Oooooo000`ooooo`03o`000?oooooo
oooo04?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Gooooo00Co0000oooooooooooo
0000gOooool2o`0000;ooooo0_l0000<ooooo`03oeEEEOnHV9Sooooo00;o00000_ooool01ol0003o
ooooooooool0003o410@onk^k_mEEED00_l000000om4A4Co^[Zjooooo`02ooooo`05oiRHV?l0003o
0000odA4A?nj^[X00_ooool02?o^k^koEEEEo`000?l0003oA4A4okZj^_oooooo410@1Ol00003oooo
o`08oa0@4?lb<S;o0000o`000?l@413oZJVYohN7QomVIVH7ooooo`00<?ooool00ol0003ooooooooo
o`0eooooo`Co00002_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001Oooool01?l0003o
ooooooooool00005ooooo`?o0000eOooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@cooooo00Go
0000ooooooooooooooooo`000002ooooo`0;o`000?ooooooooooo`000?ooooooEEEEogMgMooooooo
k^k^ogMgMol@41000oooool01Ol@413o^[Zjonk^k_mgMgOo410@00;ooooo00KoEEEEogMgMooooooo
k^k^ogMgMol@4103ooooo`03o`000?oooooooooo00Cooooo00So0000ojVYZOoooooooooookZj^_l0
003ok^k^o`0000Oooooo003oo`000;Co00003oooool01?oMgMgo0000oa0@4?o<c<`=ooooo`05oc8b
<_ooooooooooooooool000000_ooool01_l0003oooooooooool0003oooooo`0000Sooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00Oo^[Zj
ohN7QomVIVKoIVIVoa0@4?oooooo000000Oooooo000:ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool01?ooool7o`0000Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000001oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooo000000Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`04ooooo`;o00000oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooool000000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`02o`0000Cooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00004ooooo`Go00003_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Gooooo`04onk^k_lQ8B7o410@onk^
kPgooooo00Go<S8booooooooooooooooo`000002ooooo`05o`000?ooooooooooo`000?ooool01_l0
0003ooooo`03o`000?oooooooooo00Cooooo1_l00003ooooo`03o`000?oooooooooo00Cooooo00So
<S8bob4Q8OmgMgOoMgMgohN7Qoo^k^koooooo`0000Oooooo000:ooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooo`000006ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooool000001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Co
oooo0_l00003ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooo`000002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01?l0003o
ooooooooooooool2o`0000Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02oooo
o`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`02ooooo`Co00001?oo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Oooooo00Co8B4QogMgMomgMgOo<S8b
3Oooool01Ol0003ok^k^oooooooooooo000000;oc<c<00_o0000ojVYZOoMgMgo8B4QoooooomEEEGo
QhN7onk^k_ooooooQhN7oc8b<P03ooooo`03o`000?oooooooooo00Cooooo00KoEEEEohN7Qoo^k^ko
ooooohN7Qolb<S83ooooo`03o`000?lb<S;ogMgM00Cooooo00So0000okZj^_ooooook^k^ogMgMol0
003ok^k^o`0000Oooooo000`ooooo`03o`000?oooooooooo03gooooo00Go0000oooooooooooooooo
o`000008ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
o`000004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001_ooool2o`0000Go
oooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo01Ko
oooo0_l00002ooooo`;o00003?ooool03_mEEEGoMgMgooooool@413o0000ob4Q8Ol0003oMgMgoa0@
4?l0003oZJVYooooooo^k^koEEEE0_l000001?m4A4Cok^k^ooooool@4105o`0000?ooooo00Kok^k^
oeEEEOl0003o0000odA4A?o^k^h2ooooo`;o000000CoZJVYob4Q8Ol0003o8B4Q0_ooool02?nYZJWo
8B4Qo`000?l0003o<S8bo`000?mgMgOoEEEE1oooool0033ooooo00?o0000ooooooooool0?Oooool4
o`0000Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000001Oooool01?l0003oooooooooool0003dooooo`03omgMgOl@413ok^k^01;ooooo
00?o0000ooooooooool06Oooool00oo^k^ko410@omgMg@07ooooo`00<?ooool00ol0003ooooooooo
o`1;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01?l0003ooooooooo
ool00005ooooo`04o`000?ooooooooooo`000?Gooooo00?oMgMgofIVI_ooool04Oooool00ol0003o
ooooooooo`0Iooooo`03ofIVI_mgMgOooooo00Oooooo000`ooooo`03o`000?oooooooooo04_ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Ko
oooo0_l0003ooooooc7ooooo000`ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`04o`000?ooooooooooo`0000Kooooo0_l0003ooooooc7ooooo000`ooooo`03
o`000?oooooooooo04_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo0000
00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`04o`000?oooooooooo
o`000?oooooo>Oooool0033ooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00Co0000oooooooooooo0000ooooooliooooo`00<?ooool00ol0003oooooooooo`1;
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooo`00003ooooooc[ooooo000`
ooooo`03o`000?oooooooooo04cooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Gooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo00000?oooooo
>_ooool0033ooooo0ol0001<ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000005ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooo`00003ooooooc[o
oooo000`ooooo`03o`000?oooooooooo04cooooo00Go0000ooooooooooooooooo`000008ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo0000
00Gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo00000?oooooo>_ooool0
033ooooo00?o0000ooooooooool0COooool01?l0003oooooooooool00009ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Gooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooo00000?oooooo>_ooool0033ooooo00?o
0000ooooooooool0COooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Gooooo00Go0000oooooooo
ooooooooo`000006ooooo`03o`000?oooooo00000?oooooo>_ooool0033ooooo00?o0000oooooooo
ool0COooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool01Ol0003ooooooooooooooooo000000Gooooo00Go0000ooooooooooooooooo`00
0007ooooo`;o0000ooooooljooooo`00<?ooool00ol0003oooooooooo`1=ooooo`04o`000?oooooo
ooooo`0000Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oo
ooooooooooooool000001_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo0?oo
oooo>Oooool0033ooooo00?o0000ooooooooool0COooool3o`0000[ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003o
ooooooooool0003ooooood?ooooo000`ooooo`03o`000?oooooooooo04kooooo0_l0000:ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo0000
00Kooooo00Co0000oooooooooooo0000oooooom3ooooo`00<?ooool00ol0003oooooooooo`1Joooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo
000000Kooooo00Co0000oooooooooooo0000oooooom3ooooo`00<?ooool00ol0003oooooooooo`1J
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooo
oooo000000Kooooo00Co0000oooooooooooo0000oooooom3ooooo`00<?ooool00ol0003ooooooooo
o`1Jooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooo
oooooooo000000Kooooo00Co0000oooooooooooo0000oooooom3ooooo`00<?ooool00ol0003ooooo
ooooo`1Jooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooo
oooooooooooo000000Kooooo00Co0000oooooooooooo0000oooooom3ooooo`00<?ooool3o`0005[o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooooooooooo
ool000001_ooool01?l0003oooooooooool0003ooooood?ooooo000`ooooo`03o`000?oooooooooo
05[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooooooo
ooooool000001_ooool01?l0003oooooooooool0003ooooood?ooooo000`ooooo`03o`000?oooooo
oooo05[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooo
ooooooooool000001_ooool01?l0003oooooooooool0003ooooood?ooooo000`ooooo`03o`000?oo
oooooooo05[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool0
00001_ooool01?l0003oooooooooool0003ooooood?ooooo000`ooooo`03o`000?oooooooooo05_o
oooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooo
ooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooo`00
003oooooodCooooo000`ooooo`03o`000?oooooooooo05_ooooo00Go0000ooooooooooooooooo`00
0007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooo`00003oooooodCooooo000`ooooo`03o`00
0?oooooooooo05_ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001_ooool0
0ol0003oooooo`00003oooooodCooooo000`ooooo`03o`000?oooooooooo05_ooooo00Go0000oooo
ooooooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00
0006ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooo`00003oooooodCooooo
000`ooooo`03o`000?oooooooooo05_ooooo00Co0000oooooooooooo00002?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo0000
00Kooooo00?o0000ooooool00000oooooom4ooooo`00<?ooool00ol0003oooooooooo`1Kooooo`04
o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo
000000Kooooo00Go0000ooooooooooooooooo`000007ooooo`;o0000oooooom4ooooo`00<?ooool0
0ol0003oooooooooo`1Kooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000007ooooo`;o
0000oooooom4ooooo`00<?ooool00ol0003oooooooooo`1Kooooo`04o`000?ooooooooooo`0000So
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000oooo
ooooooooooooo`000007ooooo`;o0000oooooom4ooooo`00<?ooool3o`0005_ooooo00Co0000oooo
oooooooo00002?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_oo
ool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool0oooooom3ooooo`00<?oo
ool00ol0003oooooooooo`1Kooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`00003ooooo
odgooooo000`ooooo`03o`000?oooooooooo05_ooooo00Co0000oooooooooooo00002?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooo
oooo00000?ooooooCOooool0033ooooo00?o0000ooooooooool0Foooool01?l0003oooooooooool0
0008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`04o`00
0?ooooooooooo`000?ooooooC_ooool0033ooooo00?o0000ooooooooool0Foooool01?l0003ooooo
ooooool00008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000007oooo
o`03o`000?oooooo00000?ooooooC_ooool0033ooooo00?o0000ooooooooool0Foooool01?l0003o
ooooooooool00008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000007
ooooo`03o`000?oooooo00000?ooooooC_ooool000oooooo0_o^k^h3ooooo`;ok^k^6_ooool00ol0
003oooooooooo`1Kooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
1Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooool00000oooooom>ooooo`002?ooool5
o`0000;ooooo00Ook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool00ol0003oooooooooo`1Kooooo`04o`000?oooooo
ooooo`0000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Oooooo
00?o0000ooooool00000oooooom>ooooo`002?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo
00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`03o`000?oooooooooo05_ooooo00Co0000oooooooooooo00002Oooool0
1?l0003oooooooooool00007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooool00000oooooom>ooooo`002Ooo
ool00onHV9So8B4Qonk^kP05ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00?o0000ooooooooool0Foooool01?l0003ooooo
ooooool00009ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003o
ooooodkooooo000:ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000;ooooo`03o`000?oo
oooooooo05cooooo0_l0000:ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001oooool00ol0003o
ooooo`00003oooooodkooooo000;ooooo`0;ogMgMomVIVKoooooooooooo^k^koEEEEonk^k_oooooo
k^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
2oooool4o`0005_ooooo0_l0000:ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001oooool00ol0
003oooooo`00003oooooodkooooo000<ooooo`03o`000?oooooooooo00;ok^k^0oooool2onk^kPGo
oooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00_ooooo00?o0000oooo
ooooool0G?ooool2o`0000[ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oo
oooo00000?ooooooC_ooool000Sooooo00Go0000okZj^_ooooooV9RHoa0@400>ooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03o`000?oooooooooo05cooooo
0_l0000:ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003ooooo
odkooooo0008ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?ooool00omEEEGoIVIVo`000004oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool2o`0000Kooooo00?o0000ooooooooool0G?ooool2
o`0000[ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?oooooo
C_ooool002Oooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`1Looooo`;o0000
2_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooool00000oooooom>oooo
o`009oooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo06Sooooo00Co0000oooo
oooooooo00001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000
ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?ooooooC_ooool002Oooooo0ol00006
ooooo`03o`000?oooooooooo06Sooooo00Co0000oooooooooooo00001oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000007ooooo`03o`00
0?oooooo00000?ooooooC_ooool002Sooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`1Xooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`04ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003oooooodko
oooo000Yooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0J?ooool01?l0003ooooo
ooooool00007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003o
oooooooooooooooo000000Oooooo00?o0000ooooool00000oooooom>ooooo`00<?ooool00ol0003o
ooooooooo`1Xooooo`04o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000006
ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003oooooodkooooo000`
ooooo`03o`000?oooooooooo06Sooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooo
oooooooo000000Kooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?oo
ooooC_ooool0033ooooo00?o0000ooooooooool0J?ooool01?l0003oooooooooool00008ooooo`05
o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000
ooooool00000oooooom>ooooo`00<?ooool3o`0006Sooooo00Co0000oooooooooooo00002?ooool0
1Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo00001oooool00ol0003ooooo
o`00003oooooodkooooo000`ooooo`03o`000?oooooooooo06Sooooo00Co0000oooooooooooo0000
2?ooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo00001oooool00ol0
003oooooo`00003oooooodkooooo000`ooooo`03o`000?oooooooooo06Sooooo00Co0000oooooooo
oooo00002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo00001ooo
ool2o`000?ooooooCoooool0033ooooo00?o0000ooooooooool0J?ooool01?l0003oooooooooool0
0008ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool00007ooooo`;o
0000oooooom?ooooo`00<?ooool00ol0003oooooooooo`1Xooooo`04o`000?ooooooooooo`0000So
oooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000
ooooooooool0oooooom=ooooo`00<?ooool00ol0003oooooooooo`1Xooooo`04o`000?oooooooooo
o`0000Sooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Sooooo
00?o0000ooooooooool0oooooom=ooooo`00<?ooool00ol0003oooooooooo`1Xooooo`04o`000?oo
ooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`00
0?ooooooF?ooool0033ooooo00?o0000ooooooooool0J?ooool01?l0003oooooooooool00008oooo
o`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool0003ooooooeSooooo000`
ooooo`03o`000?oooooooooo06Sooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooo
oooooooo000000Oooooo00?o0000ooooool00000oooooomIooooo`00<?ooool00ol0003ooooooooo
o`1Xooooo`04o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000007ooooo`03
o`000?oooooo00000?ooooooFOooool0033ooooo00?o0000ooooooooool0J?ooool01?l0003ooooo
ooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooomIoooo
o`00<?ooool00ol0003oooooooooo`1Xooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooo
oooooooo00002?ooool00ol0003oooooo`00003ooooooeWooooo000`ooooo`?o0000J?ooool01?l0
003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooo
oomIooooo`00<?ooool00ol0003oooooooooo`1Xooooo`04o`000?ooooooooooo`0000Sooooo00Co
0000oooooooooooo00002?ooool00ol0003oooooo`00003ooooooeWooooo000`ooooo`03o`000?oo
oooooooo06Sooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00008ooooo`03
o`000?oooooo00000?ooooooFOooool0033ooooo00?o0000ooooooooool0J?ooool01?l0003ooooo
ooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooomIoooo
o`00<?ooool00ol0003oooooooooo`1Xooooo`03o`000?oooooo000000Wooooo00Co0000oooooooo
oooo00002?ooool00ol0003oooooo`00003ooooooeWooooo000`ooooo`03o`000?oooooooooo06So
oooo00?o0000ooooool000002Oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo0000
0?ooooooFOooool0033ooooo00?o0000ooooooooool0J?ooool00ol0003oooooo`000009ooooo`04
o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooomIooooo`00<?ooool00ol0003o
ooooooooo`1Yooooo`;o00002Oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo0000
0?ooooooFOooool0033ooooo00?o0000ooooooooool0JOooool2o`0000Wooooo00Co0000oooooooo
oooo00002?ooool00ol0003oooooo`00003ooooooeWooooo000`ooooo`03o`000?oooooooooo06Wo
oooo0_l00009ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooomIoooo
o`00<?ooool00ol0003oooooooooo`1Yooooo`;o00002Oooool01?l0003oooooooooool00008oooo
o`03o`000?oooooo00000?ooooooFOooool0033ooooo00?o0000ooooooooool0JOooool2o`0000Wo
oooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003ooooooeWooooo000`ooooo`?o
0000JOooool2o`0000Wooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003ooooo
oeWooooo000`ooooo`03o`000?oooooooooo06Wooooo0_l00009ooooo`04o`000?ooooooooooo`00
00Sooooo00?o0000ooooool00000oooooomIooooo`00<?ooool00ol0003oooooooooo`1Yooooo`;o
00002Oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?ooooooFOooool0033o
oooo00?o0000ooooooooool0JOooool2o`0000Wooooo00Co0000oooooooooooo00002?ooool00ol0
003oooooo`00003ooooooeWooooo000`ooooo`03o`000?oooooooooo06Wooooo0_l00009ooooo`04
o`000?ooooooooooo`0000Wooooo0_l0003ooooooeWooooo000`ooooo`03o`000?oooooooooo06Wo
oooo0_l00009ooooo`04o`000?ooooooooooo`0000Wooooo0_l0003ooooooeWooooo000?ooooo`;o
k^k^0oooool2onk^kQ[ooooo00?o0000ooooooooool0MOooool00ol0003oooooo`000009ooooo`;o
0000oooooomIooooo`002_ooool2o`00000:oa0@4?ooooooooooonk^k_mEEEGok^k^ooooooo^k^ko
EEEEonk^kP?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool00ol0
003oooooooooo`1eooooo`03o`000?oooooo000000Wooooo0_l0003ooooooeWooooo000;ooooo`03
o`000?oooooooooo00;ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03o`000?oooooooooo07Gooooo00?o0000
ooooool000002Oooool00ol0003oooooooooo`3ooooooeSooooo0008ooooo`Go00001?ooool00ooM
gMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400;
ooooo`03o`000?oooooooooo07Gooooo00?o0000ooooool000002Oooool00ol0003oooooooooo`3o
oooooeSooooo0008ooooo`04odA4A?oMgMgoooooo`0000Cooooo00Gok^k^oeEEEOoMgMgoEEEEonk^
kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000;ooooo`03o`00
0?oooooooooo07Gooooo00?o0000ooooool000002Oooool00ol0003oooooooooo`3ooooooeSooooo
0008ooooo`04omgMgOmEEEGoooooo`0000?ooooo00Ook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^
00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000_ooooo1?l0001d
ooooo`03o`000?oooooo00000?ooooooI?ooool000Wooooo00?oMgMgolc<c?l000000oooool2onk^
kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400;
ooooo`03o`000?oooooooooo07Gooooo0_l0003oooooofGooooo0009ooooo`03onk^k_m4A4Co0000
00oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?o0000
ooooooooool0MOooool2o`000?ooooooIOooool000[ooooo00?oMgMgo`000?ooool03?ooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool2o`0000Kooooo00?o0000
ooooooooool0MOooool2o`000?ooooooIOooool002Oooooo00Co0000oooooooooooo00001Oooool0
0ol0003oooooooooo`1eooooo`;o0000oooooomUooooo`009oooool01?l0003oooooooooool00005
ooooo`03o`000?oooooooooo07Gooooo0_l0003oooooofGooooo000Wooooo`?o00001_ooool00ol0
003oooooooooo`1eooooo`;o0000oooooomUooooo`00:?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo07Gooooo0_l0003oooooofGooooo000Yooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0MOooool2o`000?ooooooIOooool0033ooooo00?o0000ooooooooool0MOoo
ool2o`000?ooooooIOooool0033ooooo00?o0000ooooooooool0MOooool2o`000?ooooooIOooool0
033ooooo00?o0000ooooooooool0M_ooool00ol0003oooooooooo`3oooooof?ooooo000`ooooo`?o
0000oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0
003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo
00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`
ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLoooo
o`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooo
g?ooool0033ooooo0ol0003oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0
033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomco
oooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooo
oooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooo
ooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000
ooooooooool0oooooooLooooo`00<?ooool3o`000?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00oooooooooooo
oa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003o
oooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo
4?ooool00:3ooooo0_l00004ooooo`03okZj^_lb<S;ooooo00Cooooo0_l00006ooooo`03o`000?nj
^[[ooooo0?ooooooEoooool00:3ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo0_lb<S;ooooooeSooooo002=ooooo`?o00000_ooool01_lb
<S;o410@ooooooooooook^k^oeEEE@;o000000?oA4A4okZj^_ooool00oooool00ol0003ooooooooo
o`02ooooo`05oiRHV?l@413o0000o`000?nYZJT01?ooool00ol0003oooooooooo`04ooooo`03ohN7
Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0:ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01?ooool2ob4Q8@Cooooo00_ok^k^oc8b<_l0003o410@olc<c?ooooooc<c<onk^k_oooooo
k^k^olc<c004ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kQ?ooooo00Ko
410@oc8b<_l0003o0000oa0@4?nYZJT2ooooo`06onk^k_mEEEGo0000o`000?m4A4Co^[Zj0oooool0
1OmVIVKo0000o`000?m4A4Coc<c<0>Sooooo002>ooooo`05o`000?ooooooooooolc<c?l@41000ooo
ool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40Cooooo00?o0000ooooooooool00_ooool01_l0003o
ZJVYoeEEEOnHV9SoEEEEokZj^P?ooooo00?o0000ooooooooool01?ooool00oo<c<co0000oa0@400<
ooooo`06oa0@4?nj^[[ok^k^ogMgMol@413ooooo1_l00006ooooo`03ogMgMolb<S;ooooo00?ooooo
0_lQ8B44ooooo`0;oeEEEOmgMgOooooooiRHV?lQ8B7oooooonk^k_mEEEGogMgMoeEEEOo^k^h01_oo
ool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool01_l0003oZJVY
oooooooooooo^[Zjo`0000;ooooo00KoEEEEogMgMoooooook^k^ogMgMol@4102ooooo`06ofIVI_mg
MgOooooooooooon7QhOo410@j?ooool008kooooo00Go0000ooooooooooooEEEEohN7Q`03ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool01_lb<S;ok^k^oiRHV?mEEEGogMgM
oa0@40?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo00Sooooo00Go0000ooooooooooooooooo`000002ooooo`03omgMgOl0003ogMgM00Oooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01Cooooo00Go^[ZjohN7QomVIVKo
IVIVoa0@4002ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0joooool008kooooo
00Go0000oooooooMgMgo0000onk^kP03ooooo`Ko00001?ooool00ol0003oooooooooo`02ooooo`07
okZj^_m4A4Coc<c<ob4Q8Ooooooo410@olc<c002ooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool00oooool6o`0000Kooooo00?oMgMgoc8b<_ooool02Oooool02ol0003oV9RHoooooonH
V9So8B4Qooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0
003ooooooooooooooooo000001?ooooo00Ko<S8bob4Q8OmgMgOoMgMgohN7Qoo^k^h2ooooo`Ko0000
0_ooool00ol0003oooooooooo`3[ooooo`00S_ooool3o`000003oa0@4?nHV9Sooooo00;ooooo00Ko
EEEEohN7Qoo^k^koooooohN7Qolb<S84ooooo`03o`000?oooooooooo00;ooooo00Ook^k^o`000?oo
oooo0000oooooomVIVKoQhN700;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0<
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`02_ooool02ol0003oEEEEo`000?l@413oc<c<ooooooo<
c<cok^k^ooooooo^k^koc<c<00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000001?ooooo00Ko0000okZj^_ooooook^k^ogMgMol00002ooooo`06oeEEEOn7QhOok^k^oooo
oon7QhOo<S8b0_ooool01_mVIVKoMgMgooooooooooooQhN7o`000>Sooooo002>ooooo`05o`000?oo
ooooooooolc<c?l000000oooool01_o^k^koEEEEo`000?l0003oA4A4onk^kPCooooo00?o0000oooo
ooooool00_ooool01?mVIVKoV9RHoooooolb<S82okZj^P04o`000?ooooooooooo`0001?ooooo00?o
410@o`000?l000000ol0000;ooooo`03o`000?oooooooooo00cooooo00?oEEEEohN7Qoooool03_oo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41001oooool3o`0000;ooooo
0ol00004ooooo`06ojVYZOlQ8B7o0000o`000?lb<S;o00000_ooool01_o^k^koEEEEo`000?l0003o
A4A4onk^kP;ooooo00Kok^k^ofIVI_l0003o0000odA4A?l0003Xooooo`00S_ooool01Ol0003ooooo
ooooooo<c<co000000gooooo00?o0000ooooooooool01Oooool00omVIVKoQhN7ooooo`03ooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03
omgMgOl@413oV9RH00kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3oooooo`;ooooo002=ooooo`Co
000000?o410@ojVYZOooool03?ooool2o`0000Kooooo00?oZJVYodA4A?ooool00_ooool2o`0001Go
oooo00?o0000ooooooooool03?ooool4o`0000cooooo00Coc<c<odA4A?l0003o410@2_ooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_ooool4o`0000;ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`3oooooo`;ooooo003oooooo`Kooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`3oooooo`;ooooo003oooooo`Kooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`3oooooo`;ooooo003oooooo`Gooooo0_l00003ooooo`;o0000
ooooool4ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@oooo
o`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooo
oooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo
003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooo
oooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool0
0?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00001\
\>"],
  ImageRangeCache->{{{0, 525.688}, {324.5, 0}} -> {-2.58312*^-7, -6.34248*^6, \
6.65005*^-9, 53093.5}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0.309017 5.42214e-08 [
[.32684 .29652 -16.5 -12.5 ]
[.32684 .29652 16.5 0 ]
[.54329 .29652 -16.5 -12.5 ]
[.54329 .29652 16.5 0 ]
[.75974 .29652 -22.5 -12.5 ]
[.75974 .29652 22.5 0 ]
[.97619 .29652 -16.5 -12.5 ]
[.97619 .29652 16.5 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 64 6 ]
[.09789 .09213 -34.5 -6.25 ]
[.09789 .09213 0 6.25 ]
[.09789 .20057 -34.5 -6.25 ]
[.09789 .20057 0 6.25 ]
[.09789 .41746 -28.5 -6.25 ]
[.09789 .41746 0 6.25 ]
[.09789 .5259 -28.5 -6.25 ]
[.09789 .5259 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -62.8125 0 ]
[.5 .63053 62.8125 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 .30902 m
.32684 .31527 L
s
gsave
.32684 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 .30902 m
.54329 .31527 L
s
gsave
.54329 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 .30902 m
.75974 .31527 L
s
gsave
.75974 .29652 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 .30902 m
.15368 .31277 L
s
.19697 .30902 m
.19697 .31277 L
s
.24026 .30902 m
.24026 .31277 L
s
.28355 .30902 m
.28355 .31277 L
s
.37013 .30902 m
.37013 .31277 L
s
.41342 .30902 m
.41342 .31277 L
s
.45671 .30902 m
.45671 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.58658 .30902 m
.58658 .31277 L
s
.62987 .30902 m
.62987 .31277 L
s
.67316 .30902 m
.67316 .31277 L
s
.71645 .30902 m
.71645 .31277 L
s
.80303 .30902 m
.80303 .31277 L
s
.84632 .30902 m
.84632 .31277 L
s
.88961 .30902 m
.88961 .31277 L
s
.9329 .30902 m
.9329 .31277 L
s
.0671 .30902 m
.0671 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09213 m
.11664 .09213 L
s
gsave
.09789 .09213 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .20057 m
.11664 .20057 L
s
gsave
.09789 .20057 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .41746 m
.11664 .41746 L
s
gsave
.09789 .41746 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .5259 m
.11664 .5259 L
s
gsave
.09789 .5259 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.11039 .11924 m
.11414 .11924 L
s
.11039 .14635 m
.11414 .14635 L
s
.11039 .17346 m
.11414 .17346 L
s
.11039 .22768 m
.11414 .22768 L
s
.11039 .2548 m
.11414 .2548 L
s
.11039 .28191 m
.11414 .28191 L
s
.11039 .33613 m
.11414 .33613 L
s
.11039 .36324 m
.11414 .36324 L
s
.11039 .39035 m
.11414 .39035 L
s
.11039 .44457 m
.11414 .44457 L
s
.11039 .47168 m
.11414 .47168 L
s
.11039 .49879 m
.11414 .49879 L
s
.11039 .06502 m
.11414 .06502 L
s
.11039 .03791 m
.11414 .03791 L
s
.11039 .0108 m
.11414 .0108 L
s
.11039 .55301 m
.11414 .55301 L
s
.11039 .58012 m
.11414 .58012 L
s
.11039 .60723 m
.11414 .60723 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -123.812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.812 moveto
(@) show
81.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.812 moveto
(D) show
93.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5.8) show
135.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
141.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
153.000 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
157.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
166.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
184.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02453 .30902 L
.02532 .30902 L
.02691 .30902 L
.02776 .30902 L
.02866 .30902 L
.03029 .30902 L
.032 .30902 L
.03362 .30902 L
.03522 .30902 L
.0367 .30902 L
.03821 .30902 L
.03986 .30902 L
.04142 .30902 L
.0431 .30902 L
.04479 .30902 L
.0464 .30902 L
.04947 .30902 L
.05105 .30902 L
.05273 .30902 L
.05434 .30902 L
.05607 .30902 L
.05929 .30902 L
.06258 .30902 L
.06575 .30902 L
.06879 .30902 L
.07049 .30902 L
.07204 .30902 L
.07281 .30902 L
.07364 .30902 L
.07443 .30902 L
.07481 .30902 L
.07516 .30902 L
.07534 .30902 L
.07553 .30902 L
.07573 .30902 L
.07584 .30902 L
.07594 .30902 L
.07603 .30902 L
.07612 .30902 L
.0762 .30902 L
.07629 .30902 L
.07638 .30902 L
.07648 .30902 L
.07657 .30902 L
.07666 .30902 L
.07688 .30902 L
.07707 .30902 L
.0773 .30902 L
.07752 .30902 L
Mistroke
.0779 .30902 L
.07831 .30902 L
.07874 .30902 L
.07914 .30902 L
.0799 .30902 L
.08071 .30902 L
.08158 .30902 L
.08235 .30902 L
.08318 .30902 L
.08407 .30902 L
.08488 .30902 L
.08645 .30902 L
.08813 .30902 L
.08966 .30902 L
.09133 .30902 L
.09292 .30902 L
.09461 .30902 L
.09764 .30902 L
.0992 .30902 L
.10087 .30902 L
.10418 .30902 L
.10736 .30902 L
.11043 .30902 L
.11213 .30902 L
.11369 .30902 L
.11446 .30902 L
.11487 .30902 L
.1153 .30902 L
.11548 .30902 L
.11568 .30902 L
.11579 .30902 L
.11589 .30902 L
.116 .30902 L
.11609 .30902 L
.11618 .30902 L
.11627 .30902 L
.11637 .30902 L
.11647 .30902 L
.11656 .30902 L
.11665 .30902 L
.11674 .30902 L
.11682 .30902 L
.11702 .30902 L
.1172 .30902 L
.11741 .30902 L
.11761 .30902 L
.11796 .30902 L
.11834 .30902 L
.11876 .30902 L
.1192 .30902 L
Mistroke
.12 .30902 L
.12076 .30902 L
.12157 .30902 L
.12304 .30902 L
.12385 .30902 L
.12474 .30902 L
.12635 .30902 L
.12793 .30902 L
.12961 .30902 L
.13295 .30902 L
.13617 .30902 L
.13927 .30902 L
.14256 .30902 L
.1442 .30902 L
.14573 .30902 L
.14649 .30902 L
.1472 .30902 L
.1476 .30902 L
.14781 .30902 L
.14803 .30902 L
.14821 .30902 L
.14831 .30902 L
.14842 .30902 L
.14852 .30902 L
.14861 .30902 L
.14869 .30902 L
.14878 .30902 L
.14888 .30902 L
.14894 .30902 L
.14899 .30902 L
.14908 .30902 L
.14918 .30902 L
.14927 .30902 L
.14936 .30902 L
.14955 .30902 L
.14975 .30902 L
.14994 .30902 L
.15037 .30902 L
.15073 .30902 L
.15112 .30902 L
.15184 .30902 L
.15267 .30902 L
.15343 .30902 L
.1543 .30902 L
.15511 .30902 L
.15666 .30902 L
.15833 .30902 L
.15985 .30902 L
.16151 .30902 L
.16476 .30902 L
Mistroke
.16789 .30902 L
.17121 .30903 L
.17288 .30903 L
.17361 .30903 L
.17442 .30903 L
.17479 .30903 L
.17519 .30903 L
.17553 .30903 L
.17591 .30903 L
.17613 .30903 L
.17624 .30903 L
.17634 .30903 L
.17644 .30903 L
.17653 .30903 L
.17663 .30903 L
.17669 .30903 L
.17674 .30903 L
.17683 .30903 L
.17692 .30903 L
.17701 .30903 L
.17711 .30903 L
.17721 .30903 L
.17731 .30903 L
.1775 .30903 L
.17769 .30903 L
.17787 .30903 L
.17827 .30903 L
.17867 .30903 L
.1791 .30903 L
.17987 .30903 L
.18057 .30903 L
.18136 .30903 L
.18209 .30903 L
.18375 .30902 L
.1854 .30901 L
.18689 .30901 L
.1901 .30898 L
.19318 .30896 L
.19647 .30893 L
.1981 .30891 L
.1989 .30891 L
.19963 .3089 L
.19999 .3089 L
.20038 .3089 L
.20075 .3089 L
.20091 .3089 L
.20109 .3089 L
.2012 .3089 L
.2013 .3089 L
.20139 .3089 L
Mistroke
.20149 .3089 L
.20158 .3089 L
.20167 .3089 L
.20176 .3089 L
.20186 .3089 L
.20196 .3089 L
.20202 .3089 L
.20207 .3089 L
.20217 .3089 L
.20228 .3089 L
.20246 .3089 L
.20267 .3089 L
.20306 .3089 L
.20348 .3089 L
.20383 .30891 L
.20422 .30891 L
.20509 .30892 L
.2059 .30893 L
.20754 .30896 L
.20903 .309 L
.21058 .30905 L
.21225 .30911 L
.21553 .30928 L
.2187 .30945 L
.22029 .30953 L
.22175 .30959 L
.22255 .30961 L
.22292 .30962 L
.22331 .30963 L
.22351 .30963 L
.22373 .30963 L
.22392 .30963 L
.22411 .30964 L
.22422 .30964 L
.22427 .30964 L
.22433 .30964 L
.22444 .30964 L
.22453 .30964 L
.22459 .30964 L
.22465 .30964 L
.22475 .30964 L
.22481 .30964 L
.22486 .30964 L
.22499 .30964 L
.22518 .30963 L
.22536 .30963 L
.22576 .30962 L
.22614 .30962 L
.22649 .30961 L
.22728 .30957 L
Mistroke
.22815 .30952 L
.22897 .30946 L
.22973 .30939 L
.23141 .30918 L
.23295 .30893 L
.23463 .30861 L
.23792 .30786 L
.23956 .30747 L
.24109 .30714 L
.24256 .30687 L
.24338 .30676 L
.24414 .30668 L
.24452 .30665 L
.24473 .30664 L
.24493 .30663 L
.2451 .30662 L
.24519 .30662 L
.24528 .30662 L
.24538 .30662 L
.24548 .30661 L
.24558 .30661 L
.24567 .30661 L
.24577 .30661 L
.24583 .30662 L
.24589 .30662 L
.24599 .30662 L
.24609 .30662 L
.24627 .30663 L
.24647 .30664 L
.24669 .30665 L
.24692 .30667 L
.24733 .30672 L
.24776 .30678 L
.24815 .30684 L
.24903 .30704 L
.24982 .30727 L
.25065 .30757 L
.25237 .30839 L
.25399 .30937 L
.25709 .31167 L
.26039 .31423 L
.26203 .31528 L
.26283 .31568 L
.26356 .31597 L
.26392 .31608 L
.26412 .31613 L
.26432 .31617 L
.2645 .31621 L
.26469 .31624 L
.26478 .31625 L
Mistroke
.26487 .31626 L
.26495 .31626 L
.26504 .31627 L
.26514 .31627 L
.26524 .31628 L
.2653 .31628 L
.26535 .31628 L
.26546 .31628 L
.26556 .31627 L
.26565 .31627 L
.26575 .31626 L
.26586 .31625 L
.26604 .31622 L
.26622 .31619 L
.26661 .3161 L
.26701 .31596 L
.26745 .31577 L
.26825 .3153 L
.26902 .31468 L
.26973 .31397 L
.27123 .31207 L
.27288 .30936 L
.27611 .30277 L
.27921 .29625 L
.28082 .29354 L
.28163 .2925 L
.28208 .29203 L
.28251 .29167 L
.28291 .29142 L
.28313 .29131 L
.28334 .29123 L
.28351 .29118 L
.28361 .29116 L
.2837 .29115 L
.2838 .29114 L
.28389 .29113 L
.28399 .29113 L
.28409 .29114 L
.28419 .29115 L
.28429 .29117 L
.2844 .2912 L
.2845 .29123 L
.28469 .2913 L
.28489 .2914 L
.28535 .29173 L
.28577 .29214 L
.28655 .29322 L
.28728 .29458 L
.28894 .29894 L
.29057 .30485 L
Mistroke
.29206 .31136 L
.29526 .32706 L
.29673 .33391 L
.29756 .33739 L
.29834 .34026 L
.29917 .34277 L
.29993 .34451 L
.30033 .34518 L
.30053 .34546 L
.30074 .3457 L
.30096 .34589 L
.30106 .34596 L
.30116 .34601 L
.30123 .34604 L
.30129 .34607 L
.30134 .34608 L
.3014 .3461 L
.30151 .34611 L
.30156 .34611 L
.30162 .34611 L
.30172 .3461 L
.30178 .34608 L
.30183 .34607 L
.30193 .34603 L
.30202 .34598 L
.30223 .34582 L
.30246 .34559 L
.30266 .34533 L
.30287 .34499 L
.30325 .34423 L
.30396 .34227 L
.30474 .33931 L
.30631 .33084 L
.30799 .31843 L
.31131 .28744 L
.31298 .27151 L
.31452 .25856 L
.31529 .25315 L
.31602 .24895 L
.31677 .24561 L
.31717 .24431 L
.31738 .24377 L
.3176 .24331 L
.31772 .24311 L
.31782 .24296 L
.31793 .24283 L
.31802 .24274 L
.31811 .24267 L
.31821 .24263 L
.31831 .2426 L
Mistroke
.31841 .2426 L
.31847 .24261 L
.31853 .24262 L
.31863 .24268 L
.31869 .24272 L
.31875 .24277 L
.31887 .2429 L
.31908 .24322 L
.3193 .24367 L
.31969 .2448 L
.32007 .24623 L
.32091 .25083 L
.3217 .2568 L
.32253 .26475 L
.32402 .28284 L
.32707 .33085 L
.32878 .35923 L
.33033 .3825 L
.3311 .39237 L
.33194 .40128 L
.33233 .40466 L
.33273 .40769 L
.33311 .40996 L
.33346 .41164 L
.33365 .41233 L
.33386 .41293 L
.33395 .41314 L
.33405 .41332 L
.33414 .41346 L
.33422 .41356 L
.33433 .41365 L
.33438 .41367 L
.33444 .41368 L
.33454 .41367 L
.3346 .41365 L
.33465 .41362 L
.33475 .41352 L
.33483 .4134 L
.33494 .41322 L
.33503 .413 L
.33521 .4125 L
.3354 .41183 L
.33574 .41023 L
.3361 .40796 L
.3365 .40478 L
.33732 .39625 L
.33806 .38605 L
.33974 .35553 L
.34292 .27855 L
.34598 .2053 L
Mistroke
.34679 .19007 L
.34756 .17828 L
.34798 .17299 L
.34844 .16832 L
.34864 .16664 L
.34886 .16511 L
.34904 .16401 L
.34924 .16305 L
.34935 .16264 L
.34945 .16232 L
.34954 .16207 L
.34964 .16186 L
.34973 .16172 L
.34981 .16164 L
.3499 .16161 L
.35 .16163 L
.3501 .16171 L
.35016 .16178 L
.35021 .16187 L
.35031 .16209 L
.35043 .16241 L
.35063 .16321 L
.35082 .16416 L
.35118 .16666 L
.35157 .17034 L
.35229 .17954 L
.35304 .19275 L
.35388 .21113 L
.35557 .25872 L
.3588 .37041 L
.36029 .41956 L
.36192 .46304 L
.36234 .47194 L
.3628 .48006 L
.36319 .48588 L
.36361 .49084 L
.36384 .49291 L
.36405 .49444 L
.36425 .49556 L
.36435 .496 L
.36446 .49639 L
.36456 .49664 L
.36465 .49681 L
.36476 .4969 L
.36486 .49691 L
.36495 .49684 L
.36503 .49671 L
.36513 .49649 L
.36523 .49617 L
.36542 .49533 L
Mistroke
.36562 .49409 L
.36598 .491 L
.36637 .48642 L
.36679 .47993 L
.36755 .46456 L
.36826 .44618 L
.3699 .39049 L
.37139 .32863 L
.37306 .25456 L
.3746 .19 L
.3761 .13806 L
.37686 .11802 L
.37729 .1089 L
.37769 .10182 L
.37808 .0965 L
.3783 .09417 L
.37851 .09247 L
.37861 .09181 L
.3787 .09128 L
.37878 .09088 L
.37887 .09053 L
.37897 .09025 L
.37906 .09007 L
.37915 .08998 L
.37925 .08999 L
.37931 .09004 L
.37937 .09013 L
.37942 .09025 L
.37947 .09039 L
.37957 .09074 L
.37967 .09121 L
.37989 .09256 L
.38012 .09462 L
.38054 .09972 L
.38093 .10618 L
.38176 .12512 L
.38256 .14925 L
.38404 .20821 L
.38711 .36028 L
.38882 .44183 L
.39037 .50026 L
.39114 .52133 L
.39158 .5304 L
.39198 .53683 L
.39234 .54091 L
.39254 .54256 L
.39263 .54314 L
.39272 .54367 L
.39283 .54409 L
.39292 .54437 L
Mistroke
.39302 .54454 L
.3931 .5446 L
.3932 .54456 L
.3933 .54439 L
.39335 .54426 L
.39341 .54408 L
.39351 .54365 L
.39361 .5431 L
.3937 .54249 L
.39391 .54076 L
.39428 .53634 L
.39471 .5291 L
.39512 .52026 L
.39593 .49717 L
.39681 .46464 L
.40009 .2994 L
.40172 .21249 L
.40325 .14334 L
.404 .11655 L
.40472 .09661 L
.40511 .08813 L
.40532 .08441 L
.40554 .08103 L
.40575 .07846 L
.40593 .07659 L
.40602 .07584 L
.40612 .07515 L
.40621 .07462 L
.40629 .07422 L
.40639 .07386 L
.40648 .07365 L
.40658 .07354 L
.40664 .07354 L
.40669 .07357 L
.40677 .0737 L
.40687 .07395 L
.40697 .07433 L
.40706 .0748 L
.40727 .0763 L
.40746 .07818 L
.4079 .08413 L
.40829 .09157 L
.40872 .10183 L
.40959 .1288 L
.41116 .19585 L
.41285 .28361 L
.41445 .36996 L
.41529 .41215 L
.41618 .45182 L
.41698 .48153 L
Mistroke
.4174 .49467 L
.41785 .50658 L
.41827 .51539 L
.41865 .52158 L
.41883 .52391 L
.41903 .52597 L
.41912 .52675 L
.41922 .52745 L
.41931 .528 L
.41939 .52842 L
.41948 .52877 L
.41958 .52903 L
.41968 .52915 L
.41978 .52916 L
.41988 .52904 L
.41997 .52881 L
.42005 .52852 L
.42014 .5281 L
.42035 .52676 L
.42056 .52476 L
.42095 .51969 L
.42131 .51335 L
.42165 .50603 L
.42242 .48463 L
.42404 .42135 L
.42553 .34947 L
.42718 .26603 L
.42872 .19677 L
.42948 .16841 L
.4302 .14663 L
.4306 .13687 L
.43103 .1283 L
.43142 .12236 L
.43161 .12019 L
.43178 .1185 L
.43188 .11774 L
.43198 .11704 L
.43207 .11656 L
.43216 .11612 L
.43226 .11577 L
.43232 .11563 L
.43237 .11554 L
.43246 .11545 L
.43256 .11547 L
.43265 .11559 L
.43275 .11583 L
.43285 .1162 L
.43295 .11665 L
.43311 .11772 L
.43329 .11923 L
Mistroke
.43351 .12152 L
.43374 .1246 L
.43416 .13171 L
.43495 .15 L
.43571 .17306 L
.43655 .20351 L
.43824 .27539 L
.43993 .35003 L
.44148 .40912 L
.44224 .43231 L
.44264 .44252 L
.44307 .45172 L
.44349 .45885 L
.44386 .4638 L
.44404 .46567 L
.44424 .4673 L
.44442 .46847 L
.4445 .46888 L
.44459 .46924 L
.44469 .46955 L
.44479 .46974 L
.44488 .46984 L
.44497 .46984 L
.44506 .46976 L
.44517 .46956 L
.44522 .46942 L
.44527 .46924 L
.44538 .46882 L
.44556 .46779 L
.44576 .46632 L
.44611 .46274 L
.44652 .45702 L
.4469 .45031 L
.44777 .43054 L
.44941 .37944 L
.4509 .32481 L
.45258 .26476 L
.45331 .24154 L
.45412 .21961 L
.4549 .20277 L
.45527 .19638 L
.45562 .19138 L
.45581 .18912 L
.45602 .18701 L
.4562 .18555 L
.45639 .18424 L
.4566 .18319 L
.45671 .18278 L
.45676 .18263 L
.45682 .18249 L
Mistroke
.45691 .18232 L
.45701 .18223 L
.4571 .18222 L
.45716 .18225 L
.45721 .18231 L
.45731 .18248 L
.45736 .1826 L
.45742 .18276 L
.45761 .18352 L
.45772 .18408 L
.45784 .1848 L
.45805 .18639 L
.45847 .19056 L
.45885 .19554 L
.45962 .20865 L
.46034 .22442 L
.46341 .31013 L
.46512 .35611 L
.46593 .37378 L
.46667 .38683 L
.46704 .39206 L
.46745 .39676 L
.46786 .40035 L
.46808 .40182 L
.46829 .40287 L
.46839 .40325 L
.46849 .4036 L
.46859 .40385 L
.46868 .40403 L
.46876 .40414 L
.46885 .40421 L
.46894 .40423 L
.46903 .40419 L
.46912 .40409 L
.46923 .40391 L
.46931 .4037 L
.46941 .40341 L
.46962 .40256 L
.46982 .40151 L
.47022 .39856 L
.47066 .39424 L
.47146 .38369 L
.47295 .35661 L
.47452 .32262 L
.47624 .28604 L
.47703 .2716 L
.47787 .25871 L
.47828 .2536 L
.47867 .2495 L
.47905 .24627 L
Mistroke
.4794 .24389 L
.4796 .24286 L
.47981 .24197 L
.4799 .24165 L
.48 .24137 L
.48009 .24115 L
.48018 .24098 L
.48027 .24084 L
.48038 .24074 L
.48048 .2407 L
.48057 .24071 L
.48062 .24073 L
.48068 .24077 L
.48077 .24088 L
.48083 .24097 L
.48088 .24106 L
.481 .24132 L
.48119 .24188 L
.48137 .24258 L
.48171 .24432 L
.48208 .24679 L
.48248 .25013 L
.48405 .26885 L
.48574 .2947 L
.48734 .31967 L
.48818 .33127 L
.48907 .34155 L
.48987 .3486 L
.49033 .3516 L
.49054 .35277 L
.49075 .35371 L
.49093 .35442 L
.49114 .35504 L
.49132 .35547 L
.4914 .35562 L
.49149 .35576 L
.49159 .35587 L
.49168 .35594 L
.49178 .35599 L
.49188 .35599 L
.49197 .35597 L
.49208 .3559 L
.49213 .35585 L
.49219 .35578 L
.49229 .35564 L
.4925 .35523 L
.49272 .35463 L
.49311 .35314 L
.49354 .35098 L
.494 .348 L
Mistroke
.49562 .33375 L
.49731 .31541 L
.49886 .2992 L
.49962 .29234 L
.50045 .28617 L
.50084 .28388 L
.50124 .28184 L
.5016 .2804 L
.50197 .27925 L
.50218 .27877 L
.50229 .27856 L
.5024 .27838 L
.50251 .27824 L
.50261 .27813 L
.50271 .27806 L
.5028 .27801 L
.50285 .27799 L
.50291 .27798 L
.50297 .27798 L
.50302 .27798 L
.50312 .27801 L
.50318 .27804 L
.50323 .27807 L
.50334 .27816 L
.50345 .27829 L
.50369 .27866 L
.50391 .2791 L
.5041 .27959 L
.50453 .28099 L
.50531 .28446 L
.50686 .29399 L
.50853 .30613 L
.51009 .31674 L
.51092 .32133 L
.51138 .32345 L
.51181 .32514 L
.51222 .32646 L
.51244 .32703 L
.51267 .32756 L
.51286 .32792 L
.51307 .32825 L
.51327 .32848 L
.51345 .32864 L
.51354 .32869 L
.51364 .32873 L
.51374 .32876 L
.51383 .32877 L
.51392 .32877 L
.514 .32875 L
.5141 .32872 L
Mistroke
.51419 .32868 L
.51428 .32861 L
.51438 .32853 L
.51457 .32834 L
.51476 .32808 L
.51498 .32772 L
.5154 .32684 L
.51579 .32579 L
.51654 .32332 L
.51821 .31614 L
.51982 .30865 L
.52128 .30277 L
.52209 .30023 L
.52286 .29846 L
.52328 .29776 L
.52367 .2973 L
.52387 .29713 L
.52399 .29705 L
.5241 .29699 L
.52421 .29694 L
.52427 .29692 L
.52433 .29691 L
.52443 .29689 L
.52449 .29688 L
.52454 .29688 L
.52464 .29689 L
.52474 .2969 L
.52482 .29693 L
.52492 .29696 L
.52502 .29701 L
.52512 .29707 L
.52532 .29721 L
.5257 .29759 L
.52604 .29805 L
.52689 .2996 L
.5277 .3015 L
.53079 .31018 L
.53161 .31221 L
.53238 .31379 L
.53319 .31504 L
.53361 .31553 L
.53383 .31573 L
.53407 .31591 L
.53429 .31604 L
.53449 .31613 L
.53459 .31616 L
.53469 .31619 L
.53479 .31621 L
.53488 .31622 L
.53494 .31622 L
Mistroke
.53499 .31623 L
.53509 .31623 L
.53515 .31622 L
.53521 .31622 L
.53526 .31621 L
.53532 .3162 L
.53543 .31617 L
.53555 .31613 L
.53577 .31604 L
.53596 .31594 L
.53617 .31581 L
.53654 .3155 L
.53738 .31456 L
.53908 .31193 L
.54069 .30915 L
.54152 .30785 L
.5423 .30679 L
.54306 .30595 L
.54376 .30539 L
.54412 .30517 L
.54431 .30508 L
.54451 .30501 L
.54472 .30495 L
.5449 .3049 L
.54496 .3049 L
.54502 .30489 L
.54507 .30488 L
.54513 .30488 L
.54518 .30487 L
.54524 .30487 L
.54533 .30487 L
.54544 .30487 L
.54549 .30487 L
.54555 .30488 L
.54566 .30489 L
.54575 .3049 L
.54597 .30495 L
.5462 .30501 L
.54663 .30519 L
.54702 .3054 L
.54782 .30596 L
.54856 .3066 L
.55022 .30825 L
.55186 .30977 L
.55266 .31037 L
.55339 .31081 L
.55374 .31097 L
.55414 .31112 L
.55432 .31118 L
.55451 .31122 L
Mistroke
.55469 .31126 L
.55485 .31129 L
.55495 .3113 L
.55505 .31131 L
.55516 .31132 L
.55522 .31133 L
.55528 .31133 L
.55538 .31133 L
.55547 .31133 L
.55552 .31133 L
.55558 .31133 L
.55568 .31133 L
.55577 .31132 L
.55586 .31132 L
.55607 .31129 L
.55625 .31126 L
.55642 .31123 L
.5568 .31114 L
.55722 .31101 L
.55805 .31066 L
.55953 .30988 L
.56124 .30893 L
.56205 .30854 L
.56279 .30824 L
.56357 .308 L
.56397 .3079 L
.56418 .30787 L
.5644 .30783 L
.5646 .30781 L
.56478 .30779 L
.56487 .30778 L
.56496 .30777 L
.56505 .30777 L
.56513 .30776 L
.56524 .30776 L
.56533 .30776 L
.56543 .30776 L
.56549 .30776 L
.56554 .30776 L
.56563 .30776 L
.56573 .30776 L
.56583 .30777 L
.56593 .30777 L
.56614 .30779 L
.56633 .30781 L
.56677 .30787 L
.56716 .30794 L
.56757 .30802 L
.56906 .30843 L
.57064 .30892 L
Mistroke
.57209 .30931 L
.57289 .30947 L
.57326 .30953 L
.57365 .30959 L
.57387 .30961 L
.57407 .30963 L
.57427 .30965 L
.57445 .30966 L
.57467 .30967 L
.57478 .30967 L
.5749 .30968 L
.57501 .30968 L
.57511 .30968 L
.57516 .30968 L
.57521 .30968 L
.57527 .30968 L
.57533 .30968 L
.57542 .30968 L
.57552 .30968 L
.57561 .30968 L
.5757 .30967 L
.57589 .30967 L
.5761 .30966 L
.5765 .30963 L
.57693 .30959 L
.57769 .3095 L
.5784 .30939 L
.57991 .30915 L
.58154 .3089 L
.58243 .3088 L
.58282 .30876 L
.58325 .30873 L
.58366 .30871 L
.58404 .30869 L
.58425 .30868 L
.58444 .30868 L
.58454 .30868 L
.5846 .30868 L
.58466 .30868 L
.58472 .30868 L
.58477 .30868 L
.58487 .30867 L
.58497 .30867 L
.58506 .30868 L
.58515 .30868 L
.58526 .30868 L
.58537 .30868 L
.58548 .30868 L
.58568 .30869 L
.58603 .3087 L
Mistroke
.58642 .30872 L
.58729 .30877 L
.58809 .30883 L
.58972 .30897 L
.59051 .30903 L
.59124 .30908 L
.59194 .30913 L
.59271 .30916 L
.5931 .30917 L
.59347 .30918 L
.59368 .30918 L
.59386 .30919 L
.59397 .30919 L
.59408 .30919 L
.59418 .30919 L
.59428 .30919 L
.59438 .30919 L
.59448 .30919 L
.59456 .30919 L
.59465 .30919 L
.59476 .30919 L
.59486 .30919 L
.59506 .30918 L
.59524 .30918 L
.59541 .30918 L
.59579 .30917 L
.59659 .30915 L
.59745 .30912 L
.59902 .30905 L
.59985 .30901 L
.60074 .30898 L
.60119 .30897 L
.60161 .30896 L
.60201 .30895 L
.60239 .30894 L
.60275 .30894 L
.60293 .30894 L
.60313 .30893 L
.60332 .30893 L
.60344 .30893 L
.60354 .30893 L
.60363 .30893 L
.60373 .30893 L
.60383 .30893 L
.60392 .30893 L
.60403 .30893 L
.60408 .30893 L
.60414 .30893 L
.60433 .30893 L
.60444 .30893 L
Mistroke
.60456 .30894 L
.60477 .30894 L
.60519 .30894 L
.60557 .30895 L
.60707 .30897 L
.60873 .30901 L
.60946 .30902 L
.61026 .30904 L
.61064 .30904 L
.61103 .30905 L
.61138 .30905 L
.61176 .30905 L
.61195 .30905 L
.61216 .30906 L
.61238 .30906 L
.61258 .30906 L
.61268 .30906 L
.61273 .30906 L
.61279 .30906 L
.61289 .30906 L
.61298 .30906 L
.61307 .30906 L
.61315 .30906 L
.61325 .30906 L
.61334 .30906 L
.61345 .30906 L
.61355 .30906 L
.61377 .30906 L
.61416 .30905 L
.61461 .30905 L
.61504 .30905 L
.61666 .30903 L
.61814 .30902 L
.61898 .30901 L
.61976 .30901 L
.62016 .309 L
.62053 .309 L
.62074 .309 L
.62097 .309 L
.62117 .309 L
.62136 .309 L
.62157 .309 L
.62167 .309 L
.62179 .309 L
.62185 .309 L
.62191 .309 L
.62197 .309 L
.62203 .309 L
.62213 .309 L
.62219 .309 L
Mistroke
.62224 .309 L
.62235 .309 L
.62244 .309 L
.62255 .309 L
.62266 .309 L
.62285 .309 L
.62305 .309 L
.62347 .309 L
.62387 .309 L
.62462 .309 L
.6263 .30901 L
.62776 .30902 L
.62859 .30902 L
.629 .30902 L
.62937 .30902 L
.62975 .30902 L
.63014 .30903 L
.63034 .30903 L
.63053 .30903 L
.63064 .30903 L
.63074 .30903 L
.63079 .30903 L
.63085 .30903 L
.63091 .30903 L
.63096 .30903 L
.63106 .30903 L
.63116 .30903 L
.63126 .30903 L
.63135 .30903 L
.63145 .30903 L
.63157 .30903 L
.63178 .30903 L
.632 .30903 L
.63223 .30903 L
.63265 .30902 L
.63347 .30902 L
.63437 .30902 L
.63599 .30902 L
.63682 .30902 L
.63759 .30901 L
.63801 .30901 L
.6384 .30901 L
.63882 .30901 L
.63906 .30901 L
.63928 .30901 L
.63937 .30901 L
.63947 .30901 L
.63956 .30901 L
.63965 .30901 L
.63975 .30901 L
Mistroke
.63981 .30901 L
.63986 .30901 L
.63996 .30901 L
.64006 .30901 L
.64011 .30901 L
.64016 .30901 L
.64022 .30901 L
.64028 .30901 L
.64038 .30901 L
.64049 .30901 L
.64069 .30901 L
.64088 .30901 L
.64125 .30901 L
.64159 .30901 L
.64236 .30901 L
.64402 .30902 L
.64475 .30902 L
.64556 .30902 L
.64627 .30902 L
.64704 .30902 L
.64747 .30902 L
.64766 .30902 L
.64786 .30902 L
.64805 .30902 L
.64823 .30902 L
.64833 .30902 L
.64842 .30902 L
.64853 .30902 L
.64863 .30902 L
.64872 .30902 L
.64882 .30902 L
.64891 .30902 L
.649 .30902 L
.6491 .30902 L
.64921 .30902 L
.64941 .30902 L
.64961 .30902 L
.64983 .30902 L
.65023 .30902 L
.65101 .30902 L
.65171 .30902 L
.65339 .30902 L
.65412 .30902 L
.65493 .30902 L
.6553 .30902 L
.65571 .30902 L
.65609 .30902 L
.65643 .30902 L
.65664 .30902 L
.65682 .30902 L
Mistroke
.65692 .30902 L
.65703 .30902 L
.65709 .30902 L
.65714 .30902 L
.65725 .30902 L
.65734 .30902 L
.65745 .30902 L
.6575 .30902 L
.65755 .30902 L
.65765 .30902 L
.65775 .30902 L
.65785 .30902 L
.65802 .30902 L
.65822 .30902 L
.65839 .30902 L
.6588 .30902 L
.65963 .30902 L
.66111 .30902 L
.6626 .30902 L
.66345 .30902 L
.66423 .30902 L
.66466 .30902 L
.66505 .30902 L
.66527 .30902 L
.66539 .30902 L
.6655 .30902 L
.6656 .30902 L
.66571 .30902 L
.66576 .30902 L
.66582 .30902 L
.66593 .30902 L
.66598 .30902 L
.66604 .30902 L
.66614 .30902 L
.66619 .30902 L
.66624 .30902 L
.66636 .30902 L
.66656 .30902 L
.66677 .30902 L
.66717 .30902 L
.66754 .30902 L
.66906 .30902 L
.67073 .30902 L
.67154 .30902 L
.6723 .30902 L
.67273 .30902 L
.67295 .30902 L
.67319 .30902 L
.67339 .30902 L
.6736 .30902 L
Mistroke
.6738 .30902 L
.67389 .30902 L
.67399 .30902 L
.67409 .30902 L
.67414 .30902 L
.6742 .30902 L
.67429 .30902 L
.67439 .30902 L
.67444 .30902 L
.6745 .30902 L
.67456 .30902 L
.67462 .30902 L
.67472 .30902 L
.67483 .30902 L
.67504 .30902 L
.67524 .30902 L
.67562 .30902 L
.67633 .30902 L
.67711 .30902 L
.67867 .30902 L
.6795 .30902 L
.67996 .30902 L
.68039 .30902 L
.6808 .30902 L
.68124 .30902 L
.68144 .30902 L
.68165 .30902 L
.68184 .30902 L
.68202 .30902 L
.68222 .30902 L
.68233 .30902 L
.68238 .30902 L
.68244 .30902 L
.68253 .30902 L
.68262 .30902 L
.68268 .30902 L
.68273 .30902 L
.68282 .30902 L
.68291 .30902 L
.68301 .30902 L
.68309 .30902 L
.68317 .30902 L
.68337 .30902 L
.68355 .30902 L
.68393 .30902 L
.68434 .30902 L
.68517 .30902 L
.68666 .30902 L
.68747 .30902 L
.68823 .30902 L
Mistroke
.68866 .30902 L
.68912 .30902 L
.68953 .30902 L
.68973 .30902 L
.68992 .30902 L
.6901 .30902 L
.69029 .30902 L
.6904 .30902 L
.6905 .30902 L
.6906 .30902 L
.6907 .30902 L
.69078 .30902 L
.69088 .30902 L
.69097 .30902 L
.69105 .30902 L
.69114 .30902 L
.69123 .30902 L
.69133 .30902 L
.69142 .30902 L
.69164 .30902 L
.69184 .30902 L
.69222 .30902 L
.69308 .30902 L
.69455 .30902 L
.69538 .30902 L
.69616 .30902 L
.69693 .30902 L
.69736 .30902 L
.69776 .30902 L
.69817 .30902 L
.6984 .30902 L
.69852 .30902 L
.69862 .30902 L
.69872 .30902 L
.69883 .30902 L
.69893 .30902 L
.69902 .30902 L
.69912 .30902 L
.69917 .30902 L
.69923 .30902 L
.69933 .30902 L
.69939 .30902 L
.69944 .30902 L
.69963 .30902 L
.69973 .30902 L
.69983 .30902 L
.70024 .30902 L
.70059 .30902 L
.70098 .30902 L
.70264 .30902 L
Mistroke
.70422 .30902 L
.70465 .30902 L
.70511 .30902 L
.70554 .30902 L
.70594 .30902 L
.70614 .30902 L
.70635 .30902 L
.70657 .30902 L
.70669 .30902 L
.7068 .30902 L
.7069 .30902 L
.707 .30902 L
.70709 .30902 L
.70719 .30902 L
.7073 .30902 L
.70735 .30902 L
.70741 .30902 L
.70751 .30902 L
.70761 .30902 L
.70779 .30902 L
.70799 .30902 L
.70834 .30902 L
.70871 .30902 L
.70912 .30902 L
.71082 .30902 L
.71237 .30902 L
.71314 .30902 L
.71358 .30902 L
.71398 .30902 L
.71433 .30902 L
.71453 .30902 L
.71472 .30902 L
.71481 .30902 L
.71491 .30902 L
.715 .30902 L
.71509 .30902 L
.71519 .30902 L
.71525 .30902 L
.7153 .30902 L
.7154 .30902 L
.7155 .30902 L
.71559 .30902 L
.71569 .30902 L
.71587 .30902 L
.71609 .30902 L
.71628 .30902 L
.71711 .30902 L
.71859 .30902 L
.71939 .30902 L
.72025 .30902 L
Mistroke
.72098 .30902 L
.72139 .30902 L
.72179 .30902 L
.72216 .30902 L
.72235 .30902 L
.72246 .30902 L
.72256 .30902 L
.72264 .30902 L
.72273 .30902 L
.72283 .30902 L
.72292 .30902 L
.72301 .30902 L
.7231 .30902 L
.72318 .30902 L
.72326 .30902 L
.72331 .30902 L
.72337 .30902 L
.72347 .30902 L
.72357 .30902 L
.72366 .30902 L
.72387 .30902 L
.72409 .30902 L
.72449 .30902 L
.72486 .30902 L
.72653 .30902 L
.72727 .30902 L
.72808 .30902 L
.72845 .30902 L
.72885 .30902 L
.7292 .30902 L
.72958 .30902 L
.7298 .30902 L
.73001 .30902 L
.7302 .30902 L
.7303 .30902 L
.73041 .30902 L
.73051 .30902 L
.7306 .30902 L
.73068 .30902 L
.73077 .30902 L
.73087 .30902 L
.73096 .30902 L
.73106 .30902 L
.73112 .30902 L
.73117 .30902 L
.73127 .30902 L
.73136 .30902 L
.73156 .30902 L
.73176 .30902 L
.73197 .30902 L
Mistroke
.73271 .30902 L
.73438 .30902 L
.73515 .30902 L
.73597 .30902 L
.73644 .30902 L
.73686 .30902 L
.73729 .30902 L
.73749 .30902 L
.7377 .30902 L
.73788 .30902 L
.73809 .30902 L
.7382 .30902 L
.7383 .30902 L
.7384 .30902 L
.7385 .30902 L
.73858 .30902 L
.73868 .30902 L
.73876 .30902 L
.73885 .30902 L
.73894 .30902 L
.73905 .30902 L
.73914 .30902 L
.73923 .30902 L
.73944 .30902 L
.73964 .30902 L
.74008 .30902 L
.74089 .30902 L
.7424 .30902 L
.74319 .30902 L
.74403 .30902 L
.74445 .30902 L
.74492 .30902 L
.74513 .30902 L
.74535 .30902 L
.74555 .30902 L
.74575 .30902 L
.74584 .30902 L
.74595 .30902 L
.74606 .30902 L
.74612 .30902 L
.74618 .30902 L
.74628 .30902 L
.74638 .30902 L
.74648 .30902 L
.74653 .30902 L
.74659 .30902 L
.74669 .30902 L
.74678 .30902 L
.74699 .30902 L
.74718 .30902 L
Mistroke
.74736 .30902 L
.74814 .30902 L
.74897 .30902 L
.75045 .30902 L
.75121 .30902 L
.75162 .30902 L
.75202 .30902 L
.75239 .30902 L
.75279 .30902 L
.75296 .30902 L
.75315 .30902 L
.75333 .30902 L
.75349 .30902 L
.75359 .30902 L
.75368 .30902 L
.75378 .30902 L
.75388 .30902 L
.75393 .30902 L
.75399 .30902 L
.7541 .30902 L
.7542 .30902 L
.7543 .30902 L
.75438 .30902 L
.75447 .30902 L
.75465 .30902 L
.75504 .30902 L
.75546 .30902 L
.75584 .30902 L
.75671 .30902 L
.75751 .30902 L
.75836 .30902 L
.75909 .30902 L
.75948 .30902 L
.75989 .30902 L
.7601 .30902 L
.76032 .30902 L
.76053 .30902 L
.76072 .30902 L
.76091 .30902 L
.76102 .30902 L
.76112 .30902 L
.76121 .30902 L
.7613 .30902 L
.76139 .30902 L
.7615 .30902 L
.76159 .30902 L
.76167 .30902 L
.76176 .30902 L
.76185 .30902 L
.76201 .30902 L
Mistroke
.76219 .30902 L
.76258 .30902 L
.76295 .30902 L
.76445 .30902 L
.76608 .30902 L
.76651 .30902 L
.76697 .30902 L
.76736 .30902 L
.76759 .30902 L
.76779 .30902 L
.76799 .30902 L
.7682 .30902 L
.76831 .30902 L
.76842 .30902 L
.76853 .30902 L
.76863 .30902 L
.76872 .30902 L
.76883 .30902 L
.76892 .30902 L
.76901 .30902 L
.7691 .30902 L
.7692 .30902 L
.76925 .30902 L
.76931 .30902 L
.76941 .30902 L
.76962 .30902 L
.76983 .30902 L
.77023 .30902 L
.77111 .30902 L
.77273 .30902 L
.77348 .30902 L
.77388 .30902 L
.77429 .30902 L
.77466 .30902 L
.77506 .30902 L
.77523 .30902 L
.77542 .30902 L
.77558 .30902 L
.77576 .30902 L
.77587 .30902 L
.77597 .30902 L
.77607 .30902 L
.77613 .30902 L
.77619 .30902 L
.77628 .30902 L
.77639 .30902 L
.77649 .30902 L
.77658 .30902 L
.77664 .30902 L
.7767 .30902 L
Mistroke
.77681 .30902 L
.77701 .30902 L
.77725 .30902 L
.77747 .30902 L
.77826 .30902 L
.77909 .30902 L
.77991 .30902 L
.78069 .30902 L
.78144 .30902 L
.78178 .30902 L
.78214 .30902 L
.78251 .30902 L
.78271 .30902 L
.7829 .30902 L
.783 .30902 L
.7831 .30902 L
.78319 .30902 L
.78329 .30902 L
.78339 .30902 L
.78349 .30902 L
.78355 .30902 L
.78361 .30902 L
.78371 .30902 L
.78381 .30902 L
.78386 .30902 L
.78392 .30902 L
.78402 .30902 L
.78413 .30902 L
.78433 .30902 L
.78452 .30902 L
.78497 .30902 L
.78539 .30902 L
.78685 .30902 L
.78768 .30902 L
.78847 .30902 L
.78884 .30902 L
.78923 .30902 L
.78966 .30902 L
.79005 .30902 L
.79025 .30902 L
.79036 .30902 L
.79047 .30902 L
.79057 .30902 L
.79067 .30902 L
.79077 .30902 L
.79086 .30902 L
.79096 .30902 L
.79106 .30902 L
.79112 .30902 L
.79117 .30902 L
Mistroke
.79128 .30902 L
.7914 .30902 L
.79152 .30902 L
.79174 .30902 L
.79216 .30902 L
.79257 .30902 L
.79332 .30902 L
.79414 .30902 L
.795 .30902 L
.79577 .30902 L
.79618 .30902 L
.79661 .30902 L
.79682 .30902 L
.79702 .30902 L
.79721 .30902 L
.79738 .30902 L
.79755 .30902 L
.79772 .30902 L
.79782 .30902 L
.7979 .30902 L
.798 .30902 L
.7981 .30902 L
.7982 .30902 L
.79829 .30902 L
.7984 .30902 L
.7985 .30902 L
.79867 .30902 L
.79887 .30902 L
.7993 .30902 L
.79971 .30902 L
.8014 .30902 L
.80213 .30902 L
.80291 .30902 L
.80336 .30902 L
.80377 .30902 L
.80396 .30902 L
.80418 .30902 L
.80438 .30902 L
.80457 .30902 L
.80477 .30902 L
.80488 .30902 L
.80494 .30902 L
.80499 .30902 L
.80509 .30902 L
.80519 .30902 L
.80524 .30902 L
.8053 .30902 L
.8054 .30902 L
.80549 .30902 L
.80558 .30902 L
Mistroke
.80567 .30902 L
.80576 .30902 L
.80596 .30902 L
.80615 .30902 L
.80657 .30902 L
.80696 .30902 L
.80783 .30902 L
.80863 .30902 L
.80949 .30902 L
.8099 .30902 L
.81029 .30902 L
.81064 .30902 L
.81102 .30902 L
.81139 .30902 L
.8116 .30902 L
.81169 .30902 L
.81179 .30902 L
.81187 .30902 L
.81197 .30902 L
.81205 .30902 L
.81213 .30902 L
.81221 .30902 L
.8123 .30902 L
.8124 .30902 L
.81249 .30902 L
.81259 .30902 L
.81269 .30902 L
.81279 .30902 L
.81289 .30902 L
.81326 .30902 L
.81366 .30902 L
.81409 .30902 L
.81568 .30902 L
.81652 .30902 L
.81698 .30902 L
.81742 .30902 L
.81783 .30902 L
.81821 .30902 L
.81843 .30902 L
.81863 .30902 L
.81885 .30902 L
.81897 .30902 L
.81903 .30902 L
.81908 .30902 L
.81918 .30902 L
.81929 .30902 L
.81938 .30902 L
.81948 .30902 L
.81956 .30902 L
.81964 .30902 L
Mistroke
.81973 .30902 L
.81983 .30902 L
.82004 .30902 L
.82025 .30902 L
.82062 .30902 L
.8214 .30902 L
.82222 .30902 L
.8237 .30902 L
.82446 .30902 L
.82488 .30902 L
.82508 .30902 L
.82527 .30902 L
.82545 .30902 L
.82561 .30902 L
.82579 .30902 L
.82589 .30902 L
.82598 .30902 L
.82608 .30902 L
.82617 .30902 L
.82626 .30902 L
.82635 .30902 L
.82644 .30902 L
.82655 .30902 L
.82665 .30902 L
.82674 .30902 L
.82692 .30902 L
.82712 .30902 L
.82753 .30902 L
.82827 .30902 L
.82993 .30902 L
.83069 .30902 L
.83148 .30902 L
.8319 .30902 L
.83213 .30902 L
.83235 .30902 L
.83256 .30902 L
.83274 .30902 L
.83284 .30902 L
.8329 .30902 L
.83295 .30902 L
.83306 .30902 L
.83316 .30902 L
.83325 .30902 L
.83336 .30902 L
.83346 .30902 L
.83355 .30902 L
.83364 .30902 L
.83373 .30902 L
.83391 .30902 L
.83411 .30902 L
Mistroke
.83433 .30902 L
.83472 .30902 L
.83619 .30902 L
.83702 .30902 L
.83779 .30902 L
.83822 .30902 L
.8386 .30902 L
.83903 .30902 L
.83926 .30902 L
.83937 .30902 L
.83949 .30902 L
.83958 .30902 L
.83968 .30902 L
.83976 .30902 L
.83985 .30902 L
.83995 .30902 L
.84005 .30902 L
.84015 .30902 L
.84021 .30902 L
.84026 .30902 L
.84037 .30902 L
.84046 .30902 L
.84057 .30902 L
.84068 .30902 L
.84108 .30902 L
.84145 .30902 L
.84179 .30902 L
.84256 .30902 L
.84405 .30902 L
.84446 .30902 L
.8449 .30902 L
.84527 .30902 L
.84568 .30902 L
.84592 .30902 L
.84614 .30902 L
.84635 .30902 L
.84646 .30902 L
.84652 .30902 L
.84657 .30902 L
.84668 .30902 L
.84677 .30902 L
.84688 .30902 L
.84694 .30902 L
.84699 .30902 L
.84708 .30902 L
.84718 .30902 L
.84728 .30902 L
.84738 .30902 L
.84759 .30902 L
.84779 .30902 L
Mistroke
.84816 .30902 L
.84899 .30902 L
.8506 .30902 L
.8513 .30902 L
.85167 .30902 L
.85206 .30902 L
.85226 .30902 L
.85248 .30902 L
.85268 .30902 L
.85287 .30902 L
.85306 .30902 L
.85317 .30902 L
.85327 .30902 L
.85336 .30902 L
.85344 .30902 L
.85354 .30902 L
.85363 .30902 L
.85374 .30902 L
.85383 .30902 L
.85394 .30902 L
.85399 .30902 L
.85405 .30902 L
.85425 .30902 L
.85443 .30902 L
.85486 .30902 L
.85532 .30902 L
.85691 .30902 L
.85776 .30902 L
.85822 .30902 L
.85865 .30902 L
.85903 .30902 L
.85923 .30902 L
.85944 .30902 L
.85956 .30902 L
.85968 .30902 L
.85979 .30902 L
.8599 .30902 L
.86 .30902 L
.8601 .30902 L
.8602 .30902 L
.86026 .30902 L
.86032 .30902 L
.8604 .30902 L
.8605 .30902 L
.86059 .30902 L
.86067 .30902 L
.86077 .30902 L
.86087 .30902 L
.86106 .30902 L
.86147 .30902 L
Mistroke
.86185 .30902 L
.86348 .30902 L
.86428 .30902 L
.86463 .30902 L
.86501 .30902 L
.86535 .30902 L
.86572 .30902 L
.86592 .30902 L
.86611 .30902 L
.86628 .30902 L
.86647 .30902 L
.86656 .30902 L
.86667 .30902 L
.86677 .30902 L
.86686 .30902 L
.86696 .30902 L
.86706 .30902 L
.86711 .30902 L
.86717 .30902 L
.86728 .30902 L
.86738 .30902 L
.86747 .30902 L
.86767 .30902 L
.86804 .30902 L
.86843 .30902 L
.86885 .30902 L
.86959 .30902 L
.8704 .30902 L
.87126 .30902 L
.87169 .30902 L
.87209 .30902 L
.87245 .30902 L
.87266 .30902 L
.87284 .30902 L
.87302 .30902 L
.87318 .30902 L
.87328 .30902 L
.87337 .30902 L
.87346 .30902 L
.87356 .30902 L
.87365 .30902 L
.87375 .30902 L
.87384 .30902 L
.87392 .30902 L
.87402 .30902 L
.87413 .30902 L
.87432 .30902 L
.87471 .30902 L
.87508 .30902 L
.87592 .30902 L
Mistroke
.87679 .30902 L
.87761 .30902 L
.87839 .30902 L
.87883 .30902 L
.87904 .30902 L
.87924 .30902 L
.87942 .30902 L
.87959 .30902 L
.87977 .30902 L
.87986 .30902 L
.87996 .30902 L
.88006 .30902 L
.88015 .30902 L
.88025 .30902 L
.88033 .30902 L
.88043 .30902 L
.88049 .30902 L
.88054 .30902 L
.88073 .30902 L
.88093 .30902 L
.88111 .30902 L
.88151 .30902 L
.88224 .30902 L
.8831 .30902 L
.88389 .30902 L
.88463 .30902 L
.88505 .30902 L
.88542 .30902 L
.88562 .30902 L
.88583 .30902 L
.88594 .30902 L
.88606 .30902 L
.88618 .30902 L
.88628 .30902 L
.88638 .30902 L
.88648 .30902 L
.88658 .30902 L
.88664 .30902 L
.8867 .30902 L
.88679 .30902 L
.88688 .30902 L
.88699 .30902 L
.88709 .30902 L
.88728 .30902 L
.88746 .30902 L
.88788 .30902 L
.88871 .30902 L
.89019 .30902 L
.8906 .30902 L
.89104 .30902 L
Mistroke
.89143 .30902 L
.89184 .30902 L
.89221 .30902 L
.89242 .30902 L
.89252 .30902 L
.89262 .30902 L
.8927 .30902 L
.8928 .30902 L
.89288 .30902 L
.89296 .30902 L
.89305 .30902 L
.89314 .30902 L
.89324 .30902 L
.89333 .30902 L
.89343 .30902 L
.89353 .30902 L
.89371 .30902 L
.89392 .30902 L
.89412 .30902 L
.89495 .30902 L
.89643 .30902 L
.89718 .30902 L
.89759 .30902 L
.89797 .30902 L
.89839 .30902 L
.8986 .30902 L
.89884 .30902 L
.89894 .30902 L
.89905 .30902 L
.89915 .30902 L
.89926 .30902 L
.89936 .30902 L
.89946 .30902 L
.89955 .30902 L
.89964 .30902 L
.89973 .30902 L
.89983 .30902 L
.89993 .30902 L
.90002 .30902 L
.90023 .30902 L
.90043 .30902 L
.90082 .30902 L
.90125 .30902 L
.90274 .30902 L
.90356 .30902 L
.90396 .30902 L
.90433 .30902 L
.90471 .30902 L
.90491 .30902 L
.90513 .30902 L
Mistroke
.90523 .30902 L
.90535 .30902 L
.90544 .30902 L
.90555 .30902 L
.90561 .30902 L
.90567 .30902 L
.90573 .30902 L
.90579 .30902 L
.9059 .30902 L
.90596 .30902 L
.90601 .30902 L
.90611 .30902 L
.90617 .30902 L
.90622 .30902 L
.90632 .30902 L
.90641 .30902 L
.90662 .30902 L
.90685 .30902 L
.90764 .30902 L
.90913 .30902 L
.90996 .30902 L
.91036 .30902 L
.91073 .30902 L
.91112 .30902 L
.91134 .30902 L
.91154 .30902 L
.91165 .30902 L
.91176 .30902 L
.91186 .30902 L
.91197 .30902 L
.91202 .30902 L
.91208 .30902 L
.91218 .30902 L
.91224 .30902 L
.91231 .30902 L
.91237 .30902 L
.91243 .30902 L
.91253 .30902 L
.91258 .30902 L
.91264 .30902 L
.91283 .30902 L
.91306 .30902 L
.91327 .30902 L
.91407 .30902 L
.91557 .30902 L
.91597 .30902 L
.9164 .30902 L
.91679 .30902 L
.9172 .30902 L
.91757 .30902 L
Mistroke
.91777 .30902 L
.91797 .30902 L
.91806 .30902 L
.91815 .30902 L
.91823 .30902 L
.91832 .30902 L
.91841 .30902 L
.91849 .30902 L
.91859 .30902 L
.91869 .30902 L
.91878 .30902 L
.91887 .30902 L
.91897 .30902 L
.91908 .30902 L
.91929 .30902 L
.91949 .30902 L
.92023 .30902 L
.92109 .30902 L
.9219 .30902 L
.92231 .30902 L
.9227 .30902 L
.92307 .30902 L
.92342 .30902 L
.92381 .30902 L
.92401 .30902 L
.92412 .30902 L
.92423 .30902 L
.92434 .30902 L
.92444 .30902 L
.92454 .30902 L
.92464 .30902 L
.92469 .30902 L
.92475 .30902 L
.92485 .30902 L
.92491 .30902 L
.92496 .30902 L
.92502 .30902 L
.92509 .30902 L
.92519 .30902 L
.92528 .30902 L
.92548 .30902 L
.92586 .30902 L
.92629 .30902 L
.9267 .30902 L
.92752 .30902 L
.92839 .30902 L
.92916 .30902 L
.92959 .30902 L
.9298 .30902 L
.93 .30902 L
Mistroke
.93018 .30902 L
.93037 .30902 L
.93046 .30902 L
.93055 .30902 L
.93064 .30902 L
.93071 .30902 L
.9308 .30902 L
.9309 .30902 L
.93099 .30902 L
.93108 .30902 L
.93118 .30902 L
.93127 .30902 L
.93137 .30902 L
.93148 .30902 L
.93169 .30902 L
.93191 .30902 L
.9323 .30902 L
.93319 .30902 L
.93397 .30902 L
.93481 .30902 L
.93523 .30902 L
.93563 .30902 L
.93599 .30902 L
.93619 .30902 L
.93638 .30902 L
.93657 .30902 L
.93675 .30902 L
.93684 .30902 L
.93693 .30902 L
.93703 .30902 L
.93714 .30902 L
.93722 .30902 L
.93731 .30902 L
.9374 .30902 L
.93748 .30902 L
.93757 .30902 L
.93767 .30902 L
.93785 .30902 L
.93803 .30902 L
.93823 .30902 L
.9386 .30902 L
.93943 .30902 L
.94024 .30902 L
.94066 .30902 L
.94112 .30902 L
.94156 .30902 L
.94195 .30902 L
.94214 .30902 L
.94235 .30902 L
.94255 .30902 L
Mistroke
.94273 .30902 L
.94283 .30902 L
.94293 .30902 L
.94304 .30902 L
.9431 .30902 L
.94316 .30902 L
.94321 .30902 L
.94327 .30902 L
.94337 .30902 L
.94344 .30902 L
.9435 .30902 L
.94355 .30902 L
.94361 .30902 L
.94371 .30902 L
.94382 .30902 L
.94403 .30902 L
.94442 .30902 L
.94612 .30902 L
.94693 .30902 L
.94767 .30902 L
.94804 .30902 L
.94844 .30902 L
.94865 .30902 L
.94884 .30902 L
.94895 .30902 L
.94905 .30902 L
.94916 .30902 L
.94922 .30902 L
.94928 .30902 L
.94938 .30902 L
.94948 .30902 L
.94957 .30902 L
.94966 .30902 L
.94976 .30902 L
.94987 .30902 L
.95007 .30902 L
.95025 .30902 L
.95042 .30902 L
.9508 .30902 L
.95229 .30902 L
.95308 .30902 L
.95351 .30902 L
.95392 .30902 L
.95434 .30902 L
.95456 .30902 L
.9548 .30902 L
.95501 .30902 L
.95512 .30902 L
.95518 .30902 L
.95523 .30902 L
Mistroke
.95533 .30902 L
.95543 .30902 L
.95553 .30902 L
.95562 .30902 L
.95572 .30902 L
.95582 .30902 L
.95593 .30902 L
.95603 .30902 L
.9562 .30902 L
.9564 .30902 L
.95724 .30902 L
.95882 .30902 L
.95925 .30902 L
.95972 .30902 L
.96015 .30902 L
.96055 .30902 L
.96075 .30902 L
.96086 .30902 L
.96096 .30902 L
.96114 .30902 L
.96124 .30902 L
.96134 .30902 L
.96139 .30902 L
.96145 .30902 L
.96151 .30902 L
.96157 .30902 L
.96167 .30902 L
.96173 .30902 L
.96178 .30902 L
.96189 .30902 L
.96198 .30902 L
.96219 .30902 L
.96255 .30902 L
.96294 .30902 L
.96374 .30902 L
.96455 .30902 L
.96531 .30902 L
.96574 .30902 L
.96596 .30902 L
.96619 .30902 L
.96639 .30902 L
.96661 .30902 L
.96681 .30902 L
.96699 .30902 L
.9671 .30902 L
.9672 .30902 L
.9673 .30902 L
.9674 .30902 L
.96745 .30902 L
.9675 .30902 L
Mistroke
.96756 .30902 L
.96762 .30902 L
.96772 .30902 L
.96778 .30902 L
.96783 .30902 L
.96793 .30902 L
.96803 .30902 L
.96821 .30902 L
.96862 .30902 L
.96934 .30902 L
.97011 .30902 L
.97093 .30902 L
.97171 .30902 L
.97209 .30902 L
.97229 .30902 L
.97251 .30902 L
.97274 .30902 L
.97285 .30902 L
.97297 .30902 L
.97309 .30902 L
.97319 .30902 L
.97329 .30902 L
.97339 .30902 L
.97348 .30902 L
.97357 .30902 L
.97365 .30902 L
.97373 .30902 L
.97382 .30902 L
.97392 .30902 L
.9741 .30902 L
.97429 .30902 L
.97449 .30902 L
.97485 .30902 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{421.375, 260.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008>0001AB000`400?l00000o`00003ooooooooo
oooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo
003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooo
oooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool0
0?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooooooo
ool@ooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooo
ooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo0ol0003o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0
003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo
00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`
ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLoooo
o`00<?ooool3o`000?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?oo
ool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0
033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomco
oooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooo
oooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool3o`000?oooooo
g?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0O_ooool00ol0003oooooooooo`3ooooooe_ooooo000`ooooo`03o`000?oooooooooo07gooooo
0_l0003ooooooegooooo000`ooooo`03o`000?oooooooooo07gooooo0_l0003ooooooegooooo000@
ooooo`;ok^k^0oooool2onk^kQWooooo00?o0000ooooooooool0OOooool2o`000?ooooooGOooool0
00_ooooo0_l000002_l@413oooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h3ooooo`Co
000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP[ooooo00?o0000ooooooooool0OOoo
ool2o`000?ooooooGOooool000cooooo00?o0000ooooooooool00_ooool01Oo^k^koEEEEomgMgOmE
EEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00[ooooo
00?o0000ooooooooool0OOooool2o`000?ooooooGOooool00003ooooool0003o000000Co00000_oo
ool5o`0000Cooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?oo
ooooooooooooool@41002_ooool00ol0003oooooooooo`1mooooo`;o0000oooooomMooooo`002Ooo
ool01?m4A4CogMgMooooool00004ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000002_ooool00ol0003oooooooooo`1boooo
o`03o`000?oooooooooo00Sooooo0_l0003ooooooegooooo0009ooooo`04omgMgOmEEEGoooooo`00
00?ooooo00Ook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000000[ooooo1?l0001`ooooo`;o00002_ooool2o`000?oooooo
GOooool000[ooooo00?oMgMgolc<c?l000000oooool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oo
oooooooo00;ooooo00Go410@oooooooooooooooooa0@400:ooooo`03o`000?oooooooooo077ooooo
0_l0000:ooooo`;o0000oooooomMooooo`002_ooool00oo^k^koA4A4o`00000?ooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`;o00001Oooool00ol0003ooooo
ooooo`1aooooo`;o00002_ooool2o`000?ooooooGOooool000_ooooo00?oMgMgo`000?ooool03?oo
ool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_ooool01?l0003ooooo
ooooool00004ooooo`03o`000?oooooooooo077ooooo0_l0000:ooooo`03o`000?oooooo00000?oo
ooooG?ooool002Sooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1aooooo`;o
00002_ooool00ol0003oooooo`00003ooooooecooooo000Xooooo`?o00001Oooool00ol0003ooooo
ooooo`1aooooo`03o`000?oooooo000000Wooooo00?o0000ooooool00000oooooomLooooo`00:Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo077ooooo00?o0000ooooool000002Ooo
ool00ol0003oooooo`00003ooooooecooooo000Zooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0LOooool00ol0003oooooo`000009ooooo`03o`000?oooooo00000?ooooooG?ooool0
033ooooo00?o0000ooooooooool0LOooool00ol0003oooooo`000009ooooo`03o`000?oooooo0000
0?ooooooG?ooool0033ooooo00?o0000ooooooooool0LOooool00ol0003oooooo`000009ooooo`03
o`000?oooooo00000?ooooooG?ooool0033ooooo00?o0000ooooooooool0LOooool00ol0003ooooo
o`000009ooooo`03o`000?oooooo000000Wooooo00?o0000ooooooooool0oooooom@ooooo`00<?oo
ool00ol0003oooooooooo`1aooooo`03o`000?oooooo000000Wooooo00?o0000ooooool000002Ooo
ool00ol0003oooooooooo`3ooooooe3ooooo000`ooooo`?o0000LOooool00ol0003oooooo`000009
ooooo`03o`000?oooooo000000Wooooo00?o0000ooooooooool0oooooom@ooooo`00<?ooool00ol0
003oooooooooo`1aooooo`03o`000?oooooo000000Wooooo00?o0000ooooool000002?ooool2o`00
0?ooooooD_ooool0033ooooo00?o0000ooooooooool0LOooool00ol0003oooooo`000009ooooo`03
o`000?oooooo000000Sooooo0_l0003ooooooe;ooooo000`ooooo`03o`000?oooooooooo077ooooo
00?o0000ooooool000002Oooool00ol0003oooooo`000008ooooo`;o0000oooooomBooooo`00<?oo
ool00ol0003oooooooooo`1`ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooool00000
2?ooool00ol0003oooooo`00003ooooooe7ooooo000`ooooo`03o`000?oooooooooo073ooooo00Co
0000oooooooooooo00002?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?oo
ooooDOooool0033ooooo00?o0000ooooooooool0L?ooool01?l0003oooooooooool00008ooooo`04
o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooomAooooo`00<?ooool00ol0003o
ooooooooo`1`ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002?ooool0
0ol0003oooooo`00003ooooooe7ooooo000`ooooo`03o`000?oooooooooo073ooooo00Co0000oooo
oooooooo00002?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?ooooooDOoo
ool0033ooooo00?o0000ooooooooool0L?ooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000Sooooo00?o0000ooooool00000oooooomAooooo`00<?ooool00ol0003ooooooooo
o`1`ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002?ooool00ol0003o
ooooo`00003ooooooe7ooooo000`ooooo`03o`000?oooooooooo073ooooo00Co0000oooooooooooo
00002?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?ooooooDOooool0033o
oooo0ol0001`ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002?ooool0
0ol0003oooooo`00003ooooooe7ooooo000`ooooo`03o`000?oooooooooo073ooooo00Co0000oooo
oooooooo00002?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?ooooooDOoo
ool0033ooooo00?o0000ooooooooool0L?ooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000Sooooo00?o0000ooooool00000oooooomAooooo`00<?ooool00ol0003ooooooooo
o`1`ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002?ooool00ol0003o
ooooo`00003ooooooe7ooooo000`ooooo`03o`000?oooooooooo073ooooo00Co0000oooooooooooo
00002?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?ooooooDOooool0033o
oooo00?o0000ooooooooool0L?ooool01?l0003oooooooooool00008ooooo`04o`000?oooooooooo
o`0000Sooooo00?o0000ooooool00000oooooomAooooo`00<?ooool00ol0003oooooooooo`1Uoooo
o`03o`000?oooooooooo00Sooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0
0008ooooo`03o`000?oooooo00000?ooooooDOooool0033ooooo00?o0000ooooooooool0IOooool0
0ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooooooooooo
o`000007ooooo`03o`000?oooooo00000?ooooooDOooool0033ooooo00?o0000ooooooooool0IOoo
ool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooooooo
ooooo`000007ooooo`03o`000?oooooo00000?ooooooDOooool0033ooooo00?o0000ooooooooool0
I?ooool3o`0000Wooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo0000
00Oooooo00?o0000ooooool00000oooooomAooooo`00<?ooool00ol0003oooooooooo`1Tooooo`03
o`000?oooooo000000Wooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo
000000Oooooo00?o0000ooooool00000oooooomAooooo`00<?ooool3o`0006Cooooo00?o0000oooo
ool000002Oooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool000001ooo
ool00ol0003oooooo`00003ooooooe7ooooo000`ooooo`03o`000?oooooooooo06Cooooo00?o0000
ooooool000002Oooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool00000
1oooool00ol0003oooooo`00003ooooooe7ooooo000`ooooo`03o`000?oooooooooo06Cooooo00?o
0000ooooool000002Oooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool0
00001oooool00ol0003oooooo`00003ooooooe7ooooo000`ooooo`03o`000?oooooooooo06Cooooo
00?o0000ooooool000002Oooool01?l0003oooooooooool00008ooooo`05o`000?oooooooooooooo
ool000001oooool00ol0003oooooo`00003ooooooe7ooooo000`ooooo`03o`000?oooooooooo06Co
oooo00?o0000ooooool000002Oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooo
ooooooooooooo`000007ooooo`03o`000?oooooo000000Sooooo0_l0003oooooodOooooo000`oooo
o`03o`000?oooooooooo06Cooooo00?o0000ooooool000002Oooool01Ol0003ooooooooooooooooo
000000Oooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Sooooo
0_l0003oooooodOooooo000`ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooool000002Ooo
ool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000006ooooo`04
o`000?ooooooooooo`0000Sooooo0_l0003oooooodOooooo000@ooooo`;ok^k^0oooool2onk^kQWo
oooo00?o0000ooooooooool0I?ooool00ol0003oooooo`000009ooooo`05o`000?oooooooooooooo
ool000001oooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo00002?oo
ool2o`000?ooooooAoooool000Wooooo1Ol00002ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEE
onk^kP03ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP[ooooo00?o0000
ooooooooool0I?ooool00ol0003oooooo`000009ooooo`05o`000?ooooooooooooooool000001ooo
ool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000007ooooo`;o
0000oooooom7ooooo`002Oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00Gok^k^oeEEEOoM
gMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0:
ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooool000002Oooool01Ol0003ooooooooooooo
oooo000000Oooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool0
00001oooool2o`000?ooooooAoooool00003ooooool0003o000000Co00000oooool00onHV9So8B4Q
onk^kP05ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@413ooooo
oooooooooooo410@00[ooooo00?o0000ooooooooool0I?ooool00ol0003oooooo`000009ooooo`05
o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000
ooooooooooooooooo`000007ooooo`;o0000oooooom7ooooo`002oooool00onHV9So8B4Qonk^kP03
ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000002_ooool00ol0003oooooooooo`1Tooooo`03o`000?oooooo000000Wooooo
00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0
003ooooooooooooooooo000000Oooooo0_l0003oooooodOooooo000<ooooo`0;ogMgMomVIVKooooo
ooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000002_ooool4o`0006;ooooo00Co0000oooooooooooo00002Oooool0
1Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000006ooooo`05o`00
0?ooooooooooooooool000001oooool2o`000?ooooooAoooool000gooooo00?o0000ooooooooool0
0_o^k^h3ooooo`;ok^k^1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41002_ooool00ol0003oooooooooo`1Sooooo`04o`000?ooooooooooo`0000Wooooo00Go0000oooo
ooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooo
oooooooo000000Oooooo0_l0003oooooodOooooo0009ooooo`05o`000?nj^[[ooooooiRHV?l@4100
3_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool2o`0000Go
oooo00?o0000ooooooooool0Hoooool01Ol0003ooooooooooooooooo000000Sooooo00Go0000oooo
ooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooo
oooooooo000000Oooooo00?o0000ooooool00000oooooom6ooooo`002Oooool01OnHV9So410@o`00
0?lQ8B7oc<c<00cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;o
oooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1Sooooo`05o`000?oooooooooo
ooooool000002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooooooooooooooo
o`000006ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003oooooodKo
oooo000Xooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0Hoooool01Ol0003o
oooooooooooooooo000000Sooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooo
ooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooool00000
oooooom6ooooo`00:?ooool3o`0000Gooooo00?o0000ooooooooool0Hoooool01Ol0003ooooooooo
oooooooo000000Sooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooooooooooo
ool000001_ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooool00000oooooom6
ooooo`00:Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06?ooooo00Go0000oooo
ooooooooooooo`000008ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooo
oooooooo000000Kooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`00
0?ooooooA_ooool002[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Sooooo`05
o`000?ooooooooooooooool000002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000
ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003ooooo
ooooool0003oooooodKooooo000`ooooo`03o`000?oooooooooo06?ooooo00Go0000oooooooooooo
ooooo`000008ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo
000000Kooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`000?oooooo
A_ooool0033ooooo00?o0000ooooooooool0Hoooool01Ol0003ooooooooooooooooo000000Sooooo
00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0
003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo0000oooooom6ooooo`00<?ooool0
0ol0003oooooooooo`1Sooooo`05o`000?ooooooooooooooool000002?ooool01Ol0003ooooooooo
oooooooo000000Oooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?oooooooooooooo
ool000001_ooool01?l0003oooooooooool0003oooooodKooooo000`ooooo`03o`000?oooooooooo
06?ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01Oooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000oooooooooooooooo
o`000006ooooo`04o`000?ooooooooooo`000?ooooooA_ooool0033ooooo0ol0001Sooooo`05o`00
0?ooooooooooooooool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Go
oooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001_ooool0
1?l0003oooooooooool0003oooooodKooooo000`ooooo`03o`000?oooooooooo06?ooooo00Go0000
ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Ooo
ool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000006ooooo`04
o`000?ooooooooooo`000?ooooooA_ooool0033ooooo00?o0000ooooooooool0Hoooool01Ol0003o
oooooooooooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05oooo
o`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Kooooo00Co
0000oooooooooooo0000oooooom6ooooo`00<?ooool00ol0003oooooooooo`1Sooooo`05o`000?oo
ooooooooooooool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo
00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001_ooool01?l0
003oooooooooool0003oooooodKooooo000`ooooo`03o`000?oooooooooo06?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01Oooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`00
0006ooooo`04o`000?ooooooooooo`000?ooooooA_ooool0033ooooo00?o0000ooooooooool0Hooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooo
oooooooooooo000000Kooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`3ooooo
oc_ooooo000`ooooo`03o`000?oooooooooo05Oooooo0_l0000:ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Go
oooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001_ooool0
1?l0003oooooooooool00007ooooo`;o0000oooooolmooooo`00<?ooool00ol0003oooooooooo`1G
ooooo`;o00002Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000001_oo
ool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo00001oooool2o`000?oo
oooo?Oooool0033ooooo00?o0000ooooooooool0Eoooool2o`0000Wooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1Oooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000006oooo
o`04o`000?ooooooooooo`0000Oooooo0_l0003oooooocgooooo000`ooooo`03o`000?oooooooooo
05Kooooo00?o0000ooooool000002Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`05o`000?oooooooooo
ooooool000001_ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo0000
1oooool2o`000?oooooo?Oooool0033ooooo00?o0000ooooooooool0E_ooool00ol0003oooooo`00
0009ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000006ooooo`05o`00
0?ooooooooooooooool000001_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooo0000
0?oooooo??ooool0033ooooo00?o0000ooooooooool0E_ooool00ol0003oooooo`000009ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?oooooooooo
ooooool000001_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooo00000?oooooo??oo
ool0033ooooo0ol0001Fooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Ooo
ool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000006ooooo`04
o`000?ooooooooooo`0000Oooooo00?o0000ooooool00000oooooollooooo`00<?ooool00ol0003o
ooooooooo`1Fooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006
ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool00000oooooollooooo`00<?ooool0
0ol0003oooooooooo`1Fooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooooooo
o`000006ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool00000oooooollooooo`00
<?ooool00ol0003oooooooooo`1Fooooo`04o`000?ooooooooooo`0000Sooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooo
ooooooooo`000006ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool00000ooooooll
ooooo`00<?ooool00ol0003oooooooooo`1Fooooo`04o`000?ooooooooooo`0000Sooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000
ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool00000
oooooollooooo`00<?ooool00ol0003oooooooooo`1>ooooo`;ok^k^0oooool2onk^kP05o`000?oo
ooooooooooooool000002?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooo
oooo00001_ooool01?l0003oooooooooool0000<ooooo`;ok^k^0oooool2onk^kV3ooooo0_o^k^h3
ooooo`;ok^k^C_ooool2onk^kP?ooooo0_o^k^i/ooooo`00<?ooool00ol0003oooooooooo`18oooo
o`0>odA4A?l0003o0000oc8b<_oMgMgoooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^k_l00002
ooooo`Co000000Go410@ooooooooooook^k^oc8b<P02o`000003onk^k_oooooooooo00;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000
1_ooool01Ol0003ooooooooooooooooo000000Gooooo00Co0000oooooooooooo00001_ooool4o`00
0009oa0@4?ooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^>oooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45
ooooo`0=odA4A?l0003o0000oc8b<_oMgMgoooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03
ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kSSooooo1Ol00002ooooo`07
onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co000000So410@ooooooooooook^k^oc8b
<_l0003o<S8bonk^kUgooooo000`ooooo`03o`000?oooooooooo04_ooooo00_oMgMgoc8b<_oooooo
ooooonk^k_mEEEGogMgMoeEEEOo^k^koooooo`000003ooooo`;o00001?ooool01OmgMgOoV9RHoooo
ool0003oMgMg00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`00
0?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Gooooo00Co0000oooo
oooooooo00002?ooool00ol0003oooooooooo`02ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_oo
ool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?Oooool00ol0003ooooo
ooooo`04ooooo`;o8B4Q2?ooool02OmgMgOo<S8booooooooooook^k^oeEEEOoMgMgoEEEEonk^kP06
ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0hooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@00oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg05gooooo000`ooooo`03o`000?oooooooooo04co
oooo00Oo0000ooooooooooooooooomgMgOl0003ogMgM00;ooooo00Co0000oooooooooooooooo0_l0
0004ooooo`05oa0@4?ooooooooooo`000?l@41001?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?oooooooooooooo
ool000001Oooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00?ooooo00?ogMgM
o`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100?Ooo
ool00ol0003oooooooooo`0?ooooo`07o`000?oooooooooooooooooMgMgo0000omgMg@07ooooo`03
o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400iooooo`03oiRHV?lQ8B7ok^k^
00Gooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@4100GOooool0033ooooo00?o0000ooooooooool0Boooool02omgMgOo<S8boooooooooooo
k^k^oeEEEOoMgMgoEEEEonk^k_oooooo000000Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`02o`0000Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05
o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Gooooo00Co0000
oooooooooooo00002?ooool00ol0003oooooooooo`02ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h0
1_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000?Oooool00ol0003o
ooooooooo`0>ooooo`09ogMgMolb<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000003[ooooo00?oV9RHob4Q8Oo^k^h0
0oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000005gooooo000`ooooo`03o`000?oooooooooo04Sooooo00ko0000ob4Q8Ol0
003o<S8bolc<c?ooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^o`0000Cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`02o`0000Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooo
oooo000000Gooooo00Co0000oooooooooooo00001oooool2o`0000?ooooo00Ook^k^oeEEEOo^k^ko
ooooonk^k_mEEEGok^k^00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo
000003gooooo00?o0000ooooooooool02oooool03Ol0003o8B4Qo`000?lb<S;oc<c<ooooooo^k^ko
EEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool00000>oooool02omgMgOoIVIVooooooooooook^k^oeEEEOo^k^koooooonk^k_mEEEGo
k^k^00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000005gooooo000`
ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool00oooool2onk^kP?ooooo00?ok^k^
o`000?ooool01?ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooo`000?l@41001?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooooooo
o`000006ooooo`05o`000?ooooooooooooooool000001Oooool01?l0003oooooooooool00007oooo
o`;o00000oooool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooo
oooooooooooooa0@400mooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00oooool2
onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
400looooo`03o`000?oooooooooo00;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@05gooooo000`ooooo`?o0000B?ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooo
ool0003oMgMg00Cooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001Oooool0
1Ol0003ooooooooooooooooo000000Kooooo0_l0000?ooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`08ooooo`;o0000<oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00So
oooo0_l0000^ooooo`05o`000?nj^[[ooooooiRHV?l@41003_ooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool2o`0005?ooooo000`ooooo`03o`000?oooooooooo
04Sooooo1?l00008ooooo`07o`000?oooooooooooooooomEEEGoIVIVo`000004ooooo`05onk^k_lb
<S;o0000o`000?o^k^h01?ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000005
ooooo`05o`000?ooooooooooooooool000001Oooool01?l0003oIVIVo`000?l0000<ooooo`03oeEE
EOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP07ooooo`04o`000?ooooooooooo`00
033ooooo00?oEEEEofIVI_l000003Oooool4o`0000cooooo00?oEEEEofIVI_l000001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Oooooo00Co0000oooooooooooo0000;Oooool01OnHV9So410@o`00
0?lQ8B7oc<c<00cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oo
oooo00Co0000oooooooooooo0000D_ooool0033ooooo00?o0000ooooooooool0E?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooooooo1?l00003oooo
o`03o`000?oooooo000000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?oooooo
ooooooooool000001Oooool01Ol0003ooooooooooooooooo000000Gooooo00Co0000oooooooooooo
00006_ooool4o`000005ooooool0003oooooooooool00000G_ooool4o`000005ooooool0003ooooo
ooooool00000C?ooool4o`000005ooooool0003oooooooooool00000D_ooool0033ooooo00?o0000
ooooooooool0B?ooool2o`0000[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooo`000005
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Gooooo
00Go0000ooooooooooooooooo`000005ooooo`04o`000?ooooooooooo`0001oooooo0ol0001Toooo
o`?o0000D_ooool3o`0005?ooooo000`ooooo`03o`000?oooooooooo04Oooooo1?l00009ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`04
o`000?ooooooooooo`0000;ooooo0_l00005ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool0
1Ol0003ooooooooooooooooo000000Gooooo00Go0000ooooooooooooooooo`000005ooooo`04o`00
0?ooooooooooo`00023ooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`1Booooo`03
o`000?oooooooooo05;ooooo000`ooooo`03o`000?oooooooooo04Oooooo00Co0000oooooooooooo
00002Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`04o`0000Kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006oooo
o`05o`000?ooooooooooooooool000001Oooool01Ol0003ooooooooooooooooo000000Gooooo00Co
0000oooooooooooo00008Oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo05;ooooo
00?o0000ooooooooool0DOooool0033ooooo00?o0000ooooooooool0A_ooool01Ol0003ooooooooo
oooooooo000000Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`00
0?ooooooooooooooool000001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00Go0000ooooooooooooooooo`000005ooooo`04o`000?ooooooooooo`0000Kooooo0_l0003o
ooooob[ooooo000`ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0
003ooooooooooooooooo000000Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`05o`000?ooooooooooooooool000001Oooool01?l0003oooooooooool00006ooooo`03o`00
0?oooooo00000>kooooo00?oMgMgofIVI_ooool0;Oooool00omVIVKoMgMgooooo`07ooooo`00<?oo
ool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooooooo
o`000005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooo
oooooooooooo000000Gooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooo0000
0>gooooo00?ogMgMoa0@4?o^k^h0;_ooool00oo^k^ko410@omgMg@07ooooo`00<?ooool00ol0003o
ooooooooo`15ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000005oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo
000000Gooooo00Go0000ooooooooooooooooo`000004ooooo`04o`000?ooooooooooo`0000Oooooo
00?o0000ooooooooool0dOooool2o`0000;ooooo0_l0000<ooooo`03oeEEEOnHV9Sooooo00;o0000
0_ooool01ol0003oooooooooool0003o410@onk^k_mEEED00_l000000om4A4Co^[Zjooooo`02oooo
o`05oiRHV?l0003o0000odA4A?nj^[X00_ooool02?o^k^koEEEEo`000?l0003oA4A4okZj^_oooooo
410@1Ol00003ooooo`08oa0@4?lb<S;o0000o`000?l@413oZJVYohN7QomVIVH7ooooo`00<?ooool0
0ol0003oooooooooo`0fooooo`Co00002oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooo
ooooooooool000001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool00000
1?ooool01Ol0003ooooooooooooooooo000000Gooooo0ol0003Booooo`06onk^k_lQ8B7oQhN7okZj
^_l0003ogMgM3?ooool01Ol0003ooooooooooooooooo000000;ooooo00_o0000oooooooooooo0000
oooooomEEEGoMgMgooooooo^k^koMgMgoa0@4003ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000_oo
ool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40?ooooo00?o0000ooooooooool01?ooool02?l0003o
ZJVYoooooooooooo^[Zjo`000?o^k^ko00001oooool00?oo0000]?l0000?ooooo`04omgMgOl0003o
410@olc<c0gooooo00Go<S8booooooooooooooooo`000002ooooo`06o`000?ooooooooooo`000?oo
oooo00002?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01Oooool01onj^[[oQhN7ofIVI_mVIVKo410@ooooool000001oooool000[ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`06ooooo`Ko00000oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00_ooool2o`0000Cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooo`;o00000oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooooooo0_l00003ooooo`Co
00001Oooool3o`0000?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool05oooool01?o^k^ko8B4Qoa0@4?o^k^h=oooo
o`05oc8b<_ooooooooooooooool000000_ooool01Ol0003oooooooooool0003ooooo00Ko00000ooo
ool00ol0003oooooooooo`04ooooo`Ko00000oooool00ol0003oooooooooo`04ooooo`08oc8b<_lQ
8B7oMgMgogMgMon7QhOok^k^ooooool00007ooooo`002_ooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`;o
00001?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool2o`00
00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo0000
00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`04o`000?oooooooooo
ooooo`;o00001?ooool01?l0003oooooooooool00005ooooo`06o`000?ooooooooooo`000?oooooo
00004_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0Gooooo`04ob4Q8OmgMgOoMgMgoc8b<Pgooooo00Go0000onk^
k_ooooooooooo`000002olc<c00;o`000?nYZJWogMgMob4Q8OooooooEEEEohN7Qoo^k^koooooohN7
Qolb<S800oooool00ol0003oooooooooo`04ooooo`06oeEEEOn7QhOok^k^oooooon7QhOo<S8b0ooo
ool00ol0003o<S8bomgMg@04ooooo`08o`000?nj^[[oooooonk^k_mgMgOo0000onk^k_l00007oooo
o`00<?ooool00ol0003oooooooooo`0nooooo`Go00002Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000005ooooo`04o`000?oooooooooo
o`0000Kooooo0_l00002ooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool0Foooool0
0ol0003oooooooooo`0Fooooo`;o00000_ooool2o`0000cooooo00koEEEEogMgMooooooo410@o`00
0?lQ8B7o0000ogMgMol@413o0000ojVYZOooooook^k^oeEEE@;o000000CoA4A4onk^k_oooooo410@
1Ol00003ooooo`06onk^k_mEEEGo0000o`000?m4A4Cok^k^0_ooool2o`000004ojVYZOlQ8B7o0000
ob4Q8@;ooooo00SoZJVYob4Q8Ol0003o0000oc8b<_l0003oMgMgoeEEE@Oooooo000`ooooo`03o`00
0?oooooooooo04cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`00
0?ooooooooooooooool000001Oooool01?l0003oooooooooool0003aooooo`03omgMgOl@413ok^k^
01;ooooo00?o0000ooooooooool06Oooool00oo^k^ko410@omgMg@07ooooo`00<?ooool00ol0003o
ooooooooo`1=ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003o
oooooooooooooooo000000Gooooo00Co0000oooooooooooo0000l_ooool00omgMgOoIVIVooooo`0A
ooooo`03o`000?oooooooooo01Wooooo00?oIVIVogMgMoooool01oooool0033ooooo00?o0000oooo
ooooool0COooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000oooo
ooooooooooooo`000005ooooo`03o`000?oooooo00000?oooooo;_ooool0033ooooo00?o0000oooo
ooooool0COooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000oooo
ooooooooooooo`000005ooooo`03o`000?oooooo00000?oooooo;_ooool0033ooooo00?o0000oooo
ooooool0COooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Co0000oooo
oooooooo00001oooool2o`000?oooooo;_ooool0033ooooo00?o0000ooooooooool0COooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00001oooool2
o`000?oooooo;_ooool0033ooooo00?o0000ooooooooool0C_ooool01Ol0003ooooooooooooooooo
000000Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00Co0000oooooooooooo0000oooooolgooooo`00<?ooool00ol0003oooooooooo`1>
ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool0003oooooocOooooo
000`ooooo`?o0000C_ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
00Go0000ooooooooooooooooo`000005ooooo`04o`000?ooooooooooo`000?oooooo=oooool0033o
oooo00?o0000ooooooooool0C_ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00?ooooo00Go0000ooooooooooooooooo`000005ooooo`04o`000?ooooooooooo`000?oooooo=ooo
ool0033ooooo00?o0000ooooooooool0Coooool00ol0003oooooo`000009ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00Co0000oooooooooooo00001_ooool01?l0003oooooooooool0003oooooocOooooo
000`ooooo`03o`000?oooooooooo04oooooo00?o0000ooooool000002Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`04o`000?ooooooooooo`0000Kooooo00Co0000oooooooooooo0000oooooolgooooo`00
<?ooool00ol0003oooooooooo`1?ooooo`?o00002Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`04o`00
0?ooooooooooo`0000Kooooo00Co0000oooooooooooo0000oooooolgooooo`00<?ooool00ol0003o
ooooooooo`1Looooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00001oooool00ol0
003oooooo`00003oooooocOooooo000`ooooo`03o`000?oooooooooo05cooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool01?l0003oooooooooool00007ooooo`03o`000?oooooo00000?oooooo=oooool0033o
oooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`00
00Oooooo0_l0003oooooocSooooo000`ooooo`03o`000?oooooooooo05cooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001_ooool01?l0
003oooooooooool00007ooooo`;o0000oooooolhooooo`00<?ooool00ol0003oooooooooo`1Loooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo
000000Kooooo00Co0000oooooooooooo00001oooool2o`000?oooooo>?ooool0033ooooo00?o0000
ooooooooool0G?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000
ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`000?oooooo@Oooool0033ooooo00?o
0000ooooooooool0G?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go
0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`000?oooooo@Oooool0033ooooo
0ol0001Looooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooo
oooooooooooo000000Kooooo00Co0000oooooooooooo0000oooooom1ooooo`00<?ooool00ol0003o
ooooooooo`1Looooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003o
oooooooooooooooo000000Kooooo00Co0000oooooooooooo0000oooooom1ooooo`00<?ooool00ol0
003oooooooooo`1Looooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0
003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo0000oooooom1ooooo`00<?ooool0
0ol0003oooooooooo`1Looooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool0
1Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo0000oooooom1ooooo`00<?oo
ool00ol0003oooooooooo`1Mooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooo
ooooo`000006ooooo`04o`000?ooooooooooo`000?oooooo@Oooool0033ooooo00?o0000oooooooo
ool0GOooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001_ooool0
1?l0003oooooooooool0003ooooood7ooooo000`ooooo`03o`000?oooooooooo05gooooo00Co0000
oooooooooooo00002?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo
0000oooooom1ooooo`00<?ooool00ol0003oooooooooo`1Mooooo`04o`000?ooooooooooo`0000So
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`000?oooooo@Oooool0
033ooooo00?o0000ooooooooool0GOooool01?l0003oooooooooool00008ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`04o`000?oooooo
ooooo`0000Oooooo00?o0000ooooool00000oooooom1ooooo`00<?ooool00ol0003oooooooooo`1M
ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00001oooool00ol0003ooooo
o`00003ooooood7ooooo000`ooooo`03o`000?oooooooooo05gooooo00Co0000oooooooooooo0000
2?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001oooool01?l0003o
ooooooooool00007ooooo`03o`000?oooooo00000?oooooo@Oooool0033ooooo00?o0000oooooooo
ool0GOooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooo
ooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool00000oooo
oom1ooooo`00<?ooool3o`0005gooooo00Co0000oooooooooooo00002?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`04ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool00007ooooo`;o
0000oooooom2ooooo`00<?ooool00ol0003oooooooooo`1Mooooo`04o`000?ooooooooooo`0000So
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooo
oooooooo00001oooool2o`000?oooooo@_ooool0033ooooo00?o0000ooooooooool0GOooool01?l0
003oooooooooool00009ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000007ooooo`04o`00
0?ooooooooooo`0000Oooooo0_l0003ooooood;ooooo000`ooooo`03o`000?oooooooooo05gooooo
00Co0000oooooooooooo00002Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001oooool0
1?l0003oooooooooool00007ooooo`;o0000oooooom2ooooo`00<?ooool00ol0003oooooooooo`1M
ooooo`04o`000?ooooooooooo`0000Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Oo
oooo00Co0000oooooooooooo00001oooool2o`000?oooooo@_ooool0033ooooo00?o0000oooooooo
ool0GOooool00ol0003oooooo`00000:ooooo`05o`000?ooooooooooooooool000001oooool01Ol0
003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?oo
ooooooooo`0000Oooooo0_l0003ooooood;ooooo000?ooooo`;ok^k^0oooool2onk^kQ[ooooo00?o
0000ooooooooool0GOooool00ol0003oooooo`00000:ooooo`05o`000?ooooooooooooooool00000
1oooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000007oooo
o`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool0oooooom0ooooo`002?ooool5o`00
00;ooooo00Ook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413ooooooooo
ooo^k^ko<S8bo`000?lb<S;ok^k^2oooool00ol0003oooooooooo`1Nooooo`;o00002_ooool01Ol0
003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?oo
ooooooooooooool000001oooool01?l0003oooooooooool0003ooooood_ooooo0008ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@00oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000oooo
ooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?o0000ooooooooool0G_ooool2
o`0000[ooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool00000
1_ooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000oooooom;oooo
o`002Oooool00onHV9So8B4Qonk^kP05ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000oooooooo
ool00_ooool01Ol@413ooooooooooooooooo410@00_ooooo00?o0000ooooooooool0G_ooool2o`00
00[ooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001_oo
ool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000oooooom;ooooo`00
2_ooool00onHV9So8B4Qonk^kP03ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`1Noooo
o`;o00002_ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`00
0006ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool0003ooooood_o
oooo000;ooooo`0;ogMgMomVIVKoooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Ooo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000002oooool4o`0006Wooooo
00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0
003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000oooooom;ooooo`003?ooool0
0ol0003oooooooooo`02onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@400;ooooo`03o`000?oooooooooo06[ooooo00Go0000oooooooooooooooo
o`000007ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo0000
00Oooooo00Co0000oooooooooooo0000oooooom;ooooo`002?ooool01Ol0003o^[ZjoooooonHV9So
410@00kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?o
0000ooooooooool0J_ooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool0
00001_ooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000oooooom;
ooooo`002?ooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo00?oEEEEofIVI_l000001?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo0_l00006ooooo`03o`000?oooooooooo06[ooooo00Co
0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000oooooooo
ooooooooo`000007ooooo`04o`000?ooooooooooo`000?ooooooBoooool002Oooooo00Co0000oooo
oooooooo00001Oooool00ol0003oooooooooo`1Zooooo`04o`000?ooooooooooo`0000Sooooo00Co
0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooo
oooo0000oooooom;ooooo`009oooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo
06[ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00007ooooo`05o`000?oo
ooooooooooooool000001oooool01?l0003oooooooooool0003ooooood_ooooo000Wooooo`?o0000
1_ooool00ol0003oooooooooo`1Zooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooo
oooo00001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000oooo
oom;ooooo`00:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo06[ooooo00Co0000
oooooooooooo00002?ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Oo
oooo00Co0000oooooooooooo0000oooooom;ooooo`00:Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo06[ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00008
ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo0000oooooom;ooooo`00<?oo
ool00ol0003oooooooooo`1Zooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo
00002?ooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`000?ooooooBoooool0
033ooooo00?o0000ooooooooool0J_ooool01?l0003oooooooooool00008ooooo`04o`000?oooooo
ooooo`0000Sooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool0003ooooood_o
oooo000`ooooo`03o`000?oooooooooo06[ooooo00Co0000oooooooooooo00002?ooool01?l0003o
ooooooooool00008ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool00000oooooom<
ooooo`00<?ooool3o`0006[ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool00000oooooom<ooooo`00<?oo
ool00ol0003oooooooooo`1Zooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo
00002?ooool01?l0003oooooooooool00007ooooo`03o`000?oooooo00000?ooooooC?ooool0033o
oooo00?o0000ooooooooool0J_ooool01?l0003oooooooooool00008ooooo`04o`000?oooooooooo
o`0000Sooooo00Co0000oooooooooooo00002?ooool2o`000?ooooooC?ooool0033ooooo00?o0000
ooooooooool0J_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00002?ooool2o`000?ooooooC?ooool0033ooooo00?o0000ooooooooool0
J_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooo
oooooooo00002?ooool2o`000?ooooooC?ooool0033ooooo00?o0000ooooooooool0J_ooool01?l0
003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000
2?ooool2o`000?ooooooC?ooool0033ooooo00?o0000ooooooooool0J_ooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002?ooool2o`00
0?ooooooC?ooool0033ooooo00?o0000ooooooooool0J_ooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002?ooool2o`000?ooooooC?oo
ool0033ooooo00?o0000ooooooooool0J_ooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000Sooooo00Co0000oooooooooooo00002?ooool2o`000?ooooooC?ooool0033ooooo
00?o0000ooooooooool0J_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00
00Sooooo00Co0000oooooooooooo00002?ooool2o`000?ooooooC?ooool0033ooooo00?o0000oooo
ooooool0J_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo00Co
0000oooooooooooo00002?ooool2o`000?ooooooC?ooool0033ooooo00?o0000ooooooooool0J_oo
ool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooo
oooo00002?ooool2o`000?ooooooC?ooool0033ooooo0ol0001Zooooo`04o`000?ooooooooooo`00
00Wooooo00?o0000ooooool000002?ooool01?l0003oooooooooool0003ooooooeKooooo000`oooo
o`03o`000?oooooooooo06[ooooo00?o0000ooooool000002_ooool00ol0003oooooo`000008oooo
o`04o`000?ooooooooooo`000?ooooooE_ooool0033ooooo00?o0000ooooooooool0J_ooool00ol0
003oooooo`00000:ooooo`03o`000?oooooo000000Sooooo00Co0000oooooooooooo0000oooooomF
ooooo`00<?ooool00ol0003oooooooooo`1[ooooo`;o00002_ooool00ol0003oooooo`000008oooo
o`04o`000?ooooooooooo`000?ooooooE_ooool0033ooooo00?o0000ooooooooool0Joooool2o`00
00[ooooo00?o0000ooooool000002?ooool01?l0003oooooooooool0003ooooooeKooooo000`oooo
o`03o`000?oooooooooo06_ooooo0_l0000:ooooo`03o`000?oooooo000000Sooooo00Co0000oooo
oooooooo0000oooooomFooooo`00<?ooool00ol0003oooooooooo`1[ooooo`;o00002_ooool00ol0
003oooooo`000008ooooo`04o`000?ooooooooooo`000?ooooooE_ooool0033ooooo00?o0000oooo
ooooool0Joooool2o`0000[ooooo00?o0000ooooool000002?ooool01?l0003oooooooooool0003o
oooooeKooooo000`ooooo`03o`000?oooooooooo06_ooooo0_l0000:ooooo`03o`000?oooooo0000
00Sooooo00Co0000oooooooooooo0000oooooomFooooo`00<?ooool00ol0003oooooooooo`1[oooo
o`;o00002_ooool00ol0003oooooo`000008ooooo`04o`000?ooooooooooo`000?ooooooE_ooool0
033ooooo00?o0000ooooooooool0Joooool2o`0000[ooooo00?o0000ooooool000002?ooool01?l0
003oooooooooool0003ooooooeKooooo000`ooooo`03o`000?oooooooooo06_ooooo0_l0000:oooo
o`03o`000?oooooo000000Sooooo00?o0000ooooool00000oooooomGooooo`00<?ooool3o`0007Oo
oooo00?o0000ooooool000002?ooool00ol0003oooooo`00003ooooooeOooooo000`ooooo`03o`00
0?oooooooooo07Oooooo00?o0000ooooool000002Oooool2o`000?ooooooEoooool0033ooooo00?o
0000ooooooooool0Moooool00ol0003oooooo`000009ooooo`;o0000oooooomGooooo`00<?ooool0
0ol0003oooooooooo`1gooooo`03o`000?oooooo000000Wooooo0_l0003ooooooeOooooo000`oooo
o`03o`000?oooooooooo07Oooooo00?o0000ooooool000002Oooool2o`000?ooooooEoooool0033o
oooo00?o0000ooooooooool0Moooool00ol0003oooooo`000009ooooo`;o0000oooooomGooooo`00
3oooool2onk^kP?ooooo0_o^k^hJooooo`03o`000?oooooooooo07Oooooo00?o0000ooooool00000
2Oooool2o`000?ooooooEoooool000[ooooo0_l000002_l@413oooooooooooo^k^koEEEEonk^k_oo
ooook^k^oeEEEOo^k^h3ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP_o
oooo00?o0000ooooooooool0Moooool00ol0003oooooo`000009ooooo`;o0000oooooomGooooo`00
2oooool00ol0003oooooooooo`02ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ol0003oooooooooo`1goooo
o`03o`000?oooooo000000Wooooo0_l0003ooooooeOooooo0008ooooo`Go00001?ooool00ooMgMgo
0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400;oooo
o`03o`000?oooooooooo07Oooooo00?o0000ooooool000002Oooool2o`000?ooooooEoooool000So
oooo00CoA4A4omgMgOoooooo00001?ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000000_ooooo00?o0000ooooooooool0Mooo
ool00ol0003oooooo`000009ooooo`;o0000oooooomGooooo`002?ooool01?oMgMgoEEEEooooool0
0003ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`00000;ooooo`Co0000M_ooool00ol0003oooooo`000009oooo
o`;o0000oooooomGooooo`002Oooool00omgMgOoc<c<o`000003ooooo`;ok^k^0oooool2onk^kPGo
oooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00_ooooo00?o0000oooo
ooooool0Moooool00ol0003oooooo`000009ooooo`;o0000oooooomGooooo`002Oooool00oo^k^ko
A4A4o`00000?ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;oooo
o`03o`000?oooooooooo07Oooooo00?o0000ooooool000002Oooool2o`000?ooooooEoooool000[o
oooo00?oMgMgo`000?ooool03?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool2o`0000Kooooo00?o0000ooooooooool0Moooool00ol0003oooooo`00003ooooo
of;ooooo000Wooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0Moooool2o`00
0?ooooooHoooool002Oooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`1goooo
o`;o0000oooooomSooooo`009oooool3o`0000Kooooo00?o0000ooooooooool0Moooool2o`000?oo
ooooHoooool002Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1gooooo`;o0000
oooooomSooooo`00:Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo07Sooooo00?o
0000ooooooooool0oooooomQooooo`00<?ooool00ol0003oooooooooo`1hooooo`03o`000?oooooo
oooo0?ooooooHOooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003o
ooooooooo`3oooooomcooooo000`ooooo`?o0000oooooooLooooo`00<?ooool00ol0003ooooooooo
o`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooo
ooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`00
0?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool0
0ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033o
oooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo
000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo0ol0003oooooomcooooo000`oooo
o`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00
<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?oo
ool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3ooooo
omcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0
oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooo
oooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool3o`000?oo
oooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooooooo
o`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooo
ooooool0oooooooLooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooooooo
ool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00
oooooooooooooa3ooooo003ooooooooooooo4?ooool00:3ooooo0_l00004ooooo`03okZj^_lb<S;o
oooo00Cooooo0_l00006ooooo`03o`000?nj^[[ooooo0?ooooooEoooool00:3ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo0_lb<S;ooooo
oeSooooo002=ooooo`?o00000_ooool01_lb<S;o410@ooooooooooook^k^oeEEE@;o000000?oA4A4
okZj^_ooool00oooool00ol0003oooooooooo`02ooooo`05oiRHV?l@413o0000o`000?nYZJT01?oo
ool00ol0003oooooooooo`04ooooo`03ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4
okZj^P0:ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool2ob4Q8@Cooooo00_oc<c<ob4Q8Ol0
003o8B4Qolc<c?ooooooc<c<onk^k_ooooook^k^olc<c004ooooo`Co000000So410@oooooooooooo
k^k^oc8b<_l0003o<S8bonk^kQ?ooooo00Ko410@oc8b<_l0003o0000oa0@4?nYZJT2ooooo`06onk^
k_mEEEGo0000o`000?m4A4Co^[Zj0oooool01OmVIVKo0000o`000?m4A4Coc<c<0>Sooooo002>oooo
o`05o`000?ooooooooooolc<c?l@41000oooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40Cooooo
00?o0000ooooooooool00_ooool01_l0003oZJVYoeEEEOnHV9SoEEEEokZj^P?ooooo00?o0000oooo
ooooool01?ooool00oo<c<co0000oa0@400<ooooo`06oa0@4?nj^[[ok^k^ogMgMol@413ooooo1_l0
0006ooooo`03ogMgMolb<S;ooooo00?ooooo0_lQ8B44ooooo`0;ob4Q8OnHV9SooooooiRHV?lQ8B7o
ooooonk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL04oooool01_l0003oZJVYoooooooooooo^[Zjo`0000;ooooo00KoEEEEogMgMooo
ooook^k^ogMgMol@4102ooooo`06ofIVI_mgMgOooooooooooon7QhOo410@j?ooool008kooooo00Go
0000ooooooooooooEEEEohN7Q`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
0_ooool01_lb<S;ok^k^oiRHV?mEEEGogMgMoa0@40?ooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo00Sooooo00Go0000ooooooooooooooooo`000002
ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@01Cooooo00Go^[ZjohN7QomVIVKoIVIVoa0@4002ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0joooool008kooooo00Go0000oooooooMgMgo0000onk^kP03ooooo`Ko0000
1?ooool00ol0003oooooooooo`02ooooo`07okZj^_m4A4Coc<c<ob4Q8Ooooooo410@olc<c002oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00oooool6o`0000Kooooo00?oMgMgoc8b
<_ooool02Oooool02olb<S;oV9RHoooooonHV9So<S8booooooo^k^koEEEEomgMgOmEEEGok^k^00Ko
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000001?ooooo00Ko<S8bob4Q
8OmgMgOoMgMgohN7Qoo^k^h2ooooo`Ko00000_ooool00ol0003oooooooooo`3[ooooo`00S_ooool3
o`000003oa0@4?nHV9Sooooo00;ooooo00KoEEEEohN7Qoo^k^koooooohN7Qolb<S84ooooo`03o`00
0?oooooooooo00;ooooo00Ook^k^o`000?oooooo0000oooooomVIVKoQhN700;ooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`02_ooool0
2oo<c<co0000o`000?l0003oc<c<ooooooo<c<cok^k^ooooooo^k^koc<c<00Kooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000001?ooooo00Ko0000okZj^_ooooook^k^ogMg
Mol00002ooooo`06oeEEEOn7QhOok^k^oooooon7QhOo<S8b0_ooool01_mVIVKoMgMgoooooooooooo
QhN7o`000>Sooooo002>ooooo`05o`000?ooooooooooolc<c?l000000oooool01_o^k^koEEEEo`00
0?l0003oA4A4onk^kPCooooo00?o0000ooooooooool00_ooool01?mVIVKoV9RHoooooolb<S82okZj
^P04o`000?ooooooooooo`0001?ooooo00?o410@o`000?l000000ol0000;ooooo`03o`000?oooooo
oooo00cooooo00Go410@okZj^_oooooo^[Zjoa0@400<ooooo`03o`000?oooooooooo00;ooooo00Go
410@oooooooooooooooooa0@4007ooooo`?o00000_ooool3o`0000Cooooo00KoZJVYob4Q8Ol0003o
0000oc8b<_l00002ooooo`06onk^k_mEEEGo0000o`000?m4A4Cok^k^0_ooool01_o^k^koIVIVo`00
0?l0003oA4A4o`000>Sooooo002>ooooo`05o`000?ooooooooooolc<c?l000003Oooool00ol0003o
ooooooooo`05ooooo`03ofIVI_n7QhOooooo00?ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00Go0000okZj^_oooooo^[Zjo`00000<oooo
o`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0ooooool2ooooo`00SOooool4o`000003oa0@4?nYZJWooooo
00cooooo0_l00006ooooo`03ojVYZOm4A4Cooooo00;ooooo0_l0000Eooooo`03o`000?oooooooooo
00cooooo1?l0000;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT02_ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_ooool4o`0000;ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`3oooooo`;ooooo003oooooo`Kooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`3oooooo`;ooooo003oooooo`Kooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`3oooooo`;ooooo003oooooo`Gooooo0_l00003ooooo`;o0000ooooool4ooooo`00
oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooo
oa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003o
oooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo
4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oo
ooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@
ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00001\
\>"],
  ImageRangeCache->{{{0, 525.688}, {324.5, 0}} -> {-2.58312*^-7, -6.34248*^6, \
6.65005*^-9, 53093.5}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0.309017 5.42214e-08 [
[.32684 .29652 -16.5 -12.5 ]
[.32684 .29652 16.5 0 ]
[.54329 .29652 -16.5 -12.5 ]
[.54329 .29652 16.5 0 ]
[.75974 .29652 -22.5 -12.5 ]
[.75974 .29652 22.5 0 ]
[.97619 .29652 -16.5 -12.5 ]
[.97619 .29652 16.5 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 64 6 ]
[.09789 .09213 -34.5 -6.25 ]
[.09789 .09213 0 6.25 ]
[.09789 .20057 -34.5 -6.25 ]
[.09789 .20057 0 6.25 ]
[.09789 .41746 -28.5 -6.25 ]
[.09789 .41746 0 6.25 ]
[.09789 .5259 -28.5 -6.25 ]
[.09789 .5259 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -59.8125 0 ]
[.5 .63053 59.8125 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 .30902 m
.32684 .31527 L
s
gsave
.32684 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 .30902 m
.54329 .31527 L
s
gsave
.54329 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 .30902 m
.75974 .31527 L
s
gsave
.75974 .29652 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 .30902 m
.15368 .31277 L
s
.19697 .30902 m
.19697 .31277 L
s
.24026 .30902 m
.24026 .31277 L
s
.28355 .30902 m
.28355 .31277 L
s
.37013 .30902 m
.37013 .31277 L
s
.41342 .30902 m
.41342 .31277 L
s
.45671 .30902 m
.45671 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.58658 .30902 m
.58658 .31277 L
s
.62987 .30902 m
.62987 .31277 L
s
.67316 .30902 m
.67316 .31277 L
s
.71645 .30902 m
.71645 .31277 L
s
.80303 .30902 m
.80303 .31277 L
s
.84632 .30902 m
.84632 .31277 L
s
.88961 .30902 m
.88961 .31277 L
s
.9329 .30902 m
.9329 .31277 L
s
.0671 .30902 m
.0671 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09213 m
.11664 .09213 L
s
gsave
.09789 .09213 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .20057 m
.11664 .20057 L
s
gsave
.09789 .20057 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .41746 m
.11664 .41746 L
s
gsave
.09789 .41746 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .5259 m
.11664 .5259 L
s
gsave
.09789 .5259 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.11039 .11924 m
.11414 .11924 L
s
.11039 .14635 m
.11414 .14635 L
s
.11039 .17346 m
.11414 .17346 L
s
.11039 .22768 m
.11414 .22768 L
s
.11039 .2548 m
.11414 .2548 L
s
.11039 .28191 m
.11414 .28191 L
s
.11039 .33613 m
.11414 .33613 L
s
.11039 .36324 m
.11414 .36324 L
s
.11039 .39035 m
.11414 .39035 L
s
.11039 .44457 m
.11414 .44457 L
s
.11039 .47168 m
.11414 .47168 L
s
.11039 .49879 m
.11414 .49879 L
s
.11039 .06502 m
.11414 .06502 L
s
.11039 .03791 m
.11414 .03791 L
s
.11039 .0108 m
.11414 .0108 L
s
.11039 .55301 m
.11414 .55301 L
s
.11039 .58012 m
.11414 .58012 L
s
.11039 .60723 m
.11414 .60723 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -120.812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.812 moveto
(@) show
81.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.812 moveto
(D) show
93.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6.) show
129.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
135.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
147.000 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
151.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
160.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
178.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02532 .30902 L
.02691 .30902 L
.02852 .30902 L
.03029 .30902 L
.03186 .30902 L
.03354 .30902 L
.03525 .30902 L
.03687 .30902 L
.03847 .30902 L
.03995 .30902 L
.04159 .30902 L
.04311 .30902 L
.04615 .30902 L
.04778 .30902 L
.04926 .30902 L
.05245 .30902 L
.05552 .30902 L
.05878 .30902 L
.06192 .30902 L
.06526 .30902 L
.06693 .30902 L
.06847 .30902 L
.06924 .30902 L
.07007 .30902 L
.07084 .30902 L
.07122 .30902 L
.07157 .30902 L
.07195 .30902 L
.07214 .30902 L
.07225 .30902 L
.07236 .30902 L
.07245 .30902 L
.07253 .30902 L
.07261 .30902 L
.0727 .30902 L
.07279 .30902 L
.07288 .30902 L
.07298 .30902 L
.07308 .30902 L
.07319 .30902 L
.07329 .30902 L
.07352 .30902 L
.07373 .30902 L
.07395 .30902 L
.07432 .30902 L
.07474 .30902 L
.07515 .30902 L
.07555 .30902 L
.0763 .30902 L
Mistroke
.0771 .30902 L
.07797 .30902 L
.0788 .30902 L
.07956 .30902 L
.08043 .30902 L
.08124 .30902 L
.08279 .30902 L
.08446 .30902 L
.08598 .30902 L
.08763 .30902 L
.0892 .30902 L
.09088 .30902 L
.09259 .30902 L
.09421 .30902 L
.09729 .30902 L
.10057 .30902 L
.10372 .30902 L
.10676 .30902 L
.10999 .30902 L
.11147 .30902 L
.11232 .30902 L
.1131 .30902 L
.11388 .30902 L
.11431 .30902 L
.11451 .30902 L
.11471 .30902 L
.11481 .30902 L
.11493 .30902 L
.11503 .30902 L
.11513 .30902 L
.11518 .30902 L
.11524 .30902 L
.1153 .30902 L
.11536 .30902 L
.11542 .30902 L
.11548 .30902 L
.11558 .30902 L
.11568 .30902 L
.11578 .30902 L
.11588 .30902 L
.11597 .30902 L
.11618 .30902 L
.1164 .30902 L
.11661 .30902 L
.1168 .30902 L
.11717 .30902 L
.11756 .30902 L
.11799 .30902 L
.11875 .30902 L
.11946 .30902 L
Mistroke
.12024 .30902 L
.12096 .30902 L
.12181 .30902 L
.12262 .30902 L
.12425 .30902 L
.12573 .30902 L
.12732 .30902 L
.1288 .30902 L
.13194 .30902 L
.13366 .30902 L
.13528 .30902 L
.13838 .30902 L
.14167 .30902 L
.14331 .30902 L
.14484 .30902 L
.14632 .30902 L
.14714 .30902 L
.1475 .30902 L
.14789 .30902 L
.14828 .30902 L
.14849 .30902 L
.14859 .30902 L
.14869 .30902 L
.14878 .30902 L
.14887 .30902 L
.14896 .30902 L
.14904 .30902 L
.14914 .30902 L
.14923 .30902 L
.14933 .30902 L
.14943 .30902 L
.14952 .30902 L
.14963 .30902 L
.14974 .30902 L
.14984 .30902 L
.15003 .30902 L
.15023 .30902 L
.15068 .30902 L
.15109 .30902 L
.15148 .30902 L
.15189 .30902 L
.15262 .30902 L
.15349 .30902 L
.15429 .30902 L
.15583 .30902 L
.15671 .30902 L
.15751 .30902 L
.15915 .30902 L
.16068 .30902 L
.16374 .30902 L
Mistroke
.16687 .30902 L
.17019 .30902 L
.17186 .30902 L
.1734 .30903 L
.17416 .30903 L
.17499 .30903 L
.17575 .30903 L
.17648 .30903 L
.17685 .30903 L
.17705 .30903 L
.17726 .30903 L
.17746 .30903 L
.17763 .30903 L
.17772 .30903 L
.17781 .30903 L
.1779 .30903 L
.17798 .30903 L
.17808 .30903 L
.17818 .30903 L
.17827 .30903 L
.17836 .30903 L
.17847 .30903 L
.17858 .30903 L
.17878 .30903 L
.179 .30903 L
.17923 .30903 L
.17964 .30903 L
.18003 .30903 L
.18039 .30903 L
.1812 .30903 L
.18191 .30903 L
.18266 .30902 L
.18425 .30902 L
.18572 .30902 L
.18736 .30901 L
.18886 .30901 L
.19206 .30899 L
.19515 .30897 L
.19843 .30895 L
.20007 .30894 L
.20087 .30894 L
.2016 .30893 L
.20195 .30893 L
.20235 .30893 L
.20253 .30893 L
.20272 .30893 L
.2029 .30893 L
.20306 .30893 L
.20316 .30893 L
.20327 .30893 L
Mistroke
.20337 .30893 L
.20343 .30893 L
.20349 .30893 L
.20359 .30893 L
.20368 .30893 L
.20373 .30893 L
.20379 .30893 L
.20389 .30893 L
.20398 .30893 L
.20408 .30893 L
.20428 .30893 L
.20446 .30893 L
.20464 .30893 L
.20501 .30893 L
.20543 .30893 L
.20586 .30893 L
.20626 .30894 L
.20698 .30894 L
.20774 .30895 L
.20857 .30896 L
.20946 .30897 L
.21108 .309 L
.21268 .30904 L
.21437 .30909 L
.21741 .30921 L
.22065 .30934 L
.22214 .3094 L
.22377 .30945 L
.22465 .30947 L
.22504 .30948 L
.22547 .30949 L
.22588 .30949 L
.22606 .30949 L
.22626 .3095 L
.22635 .3095 L
.22646 .3095 L
.22656 .3095 L
.22666 .3095 L
.22671 .3095 L
.22676 .3095 L
.22682 .3095 L
.22688 .3095 L
.22693 .3095 L
.22699 .3095 L
.22709 .3095 L
.22718 .3095 L
.22729 .3095 L
.22739 .3095 L
.22748 .3095 L
.22766 .3095 L
Mistroke
.22784 .30949 L
.22827 .30949 L
.22866 .30948 L
.22941 .30946 L
.23012 .30943 L
.23091 .30939 L
.23174 .30934 L
.23322 .30921 L
.2348 .30904 L
.23627 .30884 L
.23939 .30831 L
.24271 .30771 L
.24437 .30744 L
.2451 .30734 L
.24591 .30724 L
.24628 .30721 L
.24668 .30717 L
.24703 .30715 L
.2474 .30713 L
.24761 .30712 L
.24781 .30711 L
.24801 .30711 L
.24813 .3071 L
.24823 .3071 L
.24833 .3071 L
.24842 .3071 L
.24852 .3071 L
.24862 .3071 L
.24871 .3071 L
.2488 .3071 L
.24889 .30711 L
.24899 .30711 L
.24919 .30712 L
.24941 .30713 L
.2498 .30715 L
.25027 .30719 L
.25069 .30724 L
.25152 .30737 L
.2523 .30753 L
.25392 .30798 L
.2554 .30856 L
.25858 .31022 L
.26163 .31214 L
.26333 .31318 L
.26488 .314 L
.26565 .31433 L
.26649 .31462 L
.26687 .31473 L
.26728 .31482 L
.26762 .31487 L
Mistroke
.26782 .3149 L
.26801 .31492 L
.26811 .31492 L
.26821 .31493 L
.26831 .31493 L
.2684 .31494 L
.26846 .31494 L
.26851 .31494 L
.26857 .31494 L
.26863 .31494 L
.26873 .31493 L
.26878 .31493 L
.26884 .31493 L
.26894 .31492 L
.26904 .31492 L
.26922 .3149 L
.26942 .31487 L
.26963 .31483 L
.27 .31474 L
.2704 .31462 L
.27112 .31432 L
.27187 .3139 L
.27268 .31331 L
.27414 .31191 L
.27575 .30989 L
.27744 .3073 L
.2805 .30197 L
.28221 .29905 L
.28376 .29676 L
.28453 .29583 L
.28537 .29501 L
.28575 .29472 L
.28616 .29446 L
.2865 .2943 L
.2867 .29423 L
.28689 .29418 L
.28699 .29416 L
.28709 .29414 L
.2872 .29413 L
.28729 .29412 L
.28734 .29412 L
.28739 .29412 L
.28745 .29412 L
.28751 .29412 L
.28761 .29412 L
.28767 .29413 L
.28772 .29414 L
.28782 .29415 L
.28792 .29417 L
.2881 .29423 L
Mistroke
.2883 .2943 L
.28851 .2944 L
.28889 .29463 L
.28929 .29496 L
.29 .29575 L
.29075 .29688 L
.29157 .29843 L
.29303 .30209 L
.29634 .31369 L
.29952 .32676 L
.30113 .33269 L
.30258 .33698 L
.30297 .33788 L
.30339 .33873 L
.30376 .33935 L
.30416 .33989 L
.30436 .34011 L
.30458 .3403 L
.3047 .34038 L
.30482 .34045 L
.30493 .3405 L
.30503 .34054 L
.30513 .34056 L
.30523 .34058 L
.30529 .34058 L
.30534 .34058 L
.30545 .34058 L
.30555 .34056 L
.30564 .34053 L
.30574 .34049 L
.30584 .34044 L
.30605 .34031 L
.30624 .34013 L
.3066 .3397 L
.307 .33906 L
.30742 .33817 L
.30819 .33603 L
.30889 .33344 L
.3104 .3261 L
.31205 .31542 L
.31529 .28964 L
.3184 .26568 L
.31921 .26076 L
.32009 .2564 L
.3205 .25481 L
.32093 .25342 L
.32114 .25286 L
.32134 .25241 L
.32152 .25207 L
.32171 .25177 L
Mistroke
.32181 .25164 L
.3219 .25154 L
.32199 .25146 L
.32208 .2514 L
.32218 .25134 L
.32223 .25132 L
.32229 .25131 L
.32239 .2513 L
.32249 .25131 L
.32254 .25133 L
.3226 .25135 L
.3227 .2514 L
.3228 .25148 L
.32292 .2516 L
.32312 .25188 L
.32332 .25223 L
.32369 .25313 L
.32403 .25423 L
.3248 .25763 L
.3256 .26257 L
.32634 .26835 L
.32801 .28537 L
.33117 .32818 L
.33421 .3707 L
.33577 .38772 L
.33622 .39158 L
.33665 .39473 L
.33707 .39732 L
.33745 .39919 L
.33764 .39995 L
.33785 .40064 L
.33804 .40116 L
.33822 .40152 L
.33832 .40167 L
.33841 .40178 L
.33851 .40186 L
.33857 .40189 L
.33862 .40191 L
.33872 .40192 L
.33878 .40191 L
.33884 .40189 L
.33894 .40182 L
.33904 .40171 L
.33913 .40158 L
.33922 .40143 L
.33941 .40101 L
.33957 .40053 L
.33975 .39991 L
.34012 .39821 L
.34052 .39577 L
Mistroke
.34135 .38887 L
.3421 .38045 L
.34378 .35469 L
.34699 .2871 L
.35008 .22008 L
.35168 .194 L
.35249 .18467 L
.35294 .18071 L
.35317 .17916 L
.35337 .17795 L
.35356 .17703 L
.35377 .17623 L
.35388 .17591 L
.35398 .17567 L
.35409 .17548 L
.35415 .1754 L
.35421 .17535 L
.3543 .17529 L
.35439 .17529 L
.35449 .17533 L
.3546 .17544 L
.35465 .17552 L
.35471 .17563 L
.35481 .17586 L
.355 .17646 L
.35518 .17721 L
.35538 .17824 L
.35578 .18101 L
.35615 .18439 L
.35649 .18826 L
.35733 .20031 L
.35812 .21517 L
.35961 .25092 L
.36267 .34484 L
.36438 .39823 L
.36594 .4396 L
.36671 .45614 L
.36712 .46346 L
.36755 .47004 L
.36793 .47478 L
.36813 .47689 L
.36835 .47883 L
.36855 .48032 L
.36873 .48142 L
.36891 .48228 L
.36908 .48287 L
.36917 .48309 L
.36927 .48325 L
.36936 .48334 L
.36945 .48336 L
Mistroke
.36954 .48331 L
.36964 .48319 L
.3697 .48309 L
.36975 .48296 L
.36985 .48267 L
.36996 .48227 L
.37008 .48174 L
.37028 .48051 L
.37068 .47727 L
.37105 .47305 L
.37145 .46739 L
.37216 .45429 L
.37291 .43628 L
.37373 .41276 L
.3752 .36135 L
.37851 .22718 L
.38017 .16727 L
.38098 .14347 L
.38171 .12593 L
.38207 .1187 L
.38247 .1122 L
.38285 .10739 L
.38319 .10412 L
.38338 .10281 L
.38356 .10191 L
.38366 .10153 L
.38376 .10127 L
.38381 .10117 L
.38386 .10108 L
.38396 .101 L
.38406 .10103 L
.38412 .10108 L
.38417 .10116 L
.38427 .10141 L
.38433 .10159 L
.38439 .10179 L
.38459 .10279 L
.38478 .10411 L
.38498 .10596 L
.38518 .1081 L
.38555 .11311 L
.38637 .12905 L
.38707 .14779 L
.38784 .17279 L
.39113 .31797 L
.39277 .39666 L
.3943 .46148 L
.39505 .4878 L
.39577 .50825 L
.39616 .51744 L
Mistroke
.39659 .52562 L
.39698 .53134 L
.39716 .53336 L
.39735 .53511 L
.39754 .53652 L
.39762 .53701 L
.39772 .53744 L
.39782 .53779 L
.39791 .53801 L
.39796 .5381 L
.39802 .53815 L
.39812 .53815 L
.39821 .53806 L
.3983 .53786 L
.39838 .53761 L
.39847 .53726 L
.39866 .53613 L
.39884 .53468 L
.39906 .53249 L
.39926 .52992 L
.39964 .52382 L
.40005 .51545 L
.4005 .50426 L
.40208 .44902 L
.40376 .36976 L
.40537 .28487 L
.4071 .19631 L
.40792 .15982 L
.40878 .12694 L
.40951 .10446 L
.4099 .09497 L
.41032 .08659 L
.41054 .08306 L
.41074 .08031 L
.41093 .07819 L
.41114 .07637 L
.41123 .07576 L
.41133 .07521 L
.41142 .07481 L
.4115 .07453 L
.41159 .07433 L
.41169 .07423 L
.41179 .07425 L
.41189 .07439 L
.41199 .07469 L
.41205 .07491 L
.41211 .07516 L
.41231 .07644 L
.4125 .07808 L
.4127 .08029 L
Mistroke
.41311 .08645 L
.41357 .0956 L
.41439 .11804 L
.41513 .1446 L
.41681 .22107 L
.42 .39125 L
.42146 .45843 L
.42229 .48893 L
.4227 .50131 L
.42308 .51106 L
.42344 .51896 L
.42384 .52578 L
.42403 .52838 L
.42424 .53064 L
.42435 .53165 L
.42446 .53243 L
.42455 .53303 L
.42466 .53354 L
.42476 .53391 L
.42482 .53405 L
.42488 .53414 L
.42497 .53422 L
.42508 .53416 L
.42513 .53407 L
.4252 .53392 L
.42526 .53373 L
.42531 .53352 L
.42542 .53301 L
.42553 .53231 L
.42575 .53045 L
.42596 .52813 L
.42635 .52234 L
.42672 .51506 L
.42713 .50519 L
.42796 .47971 L
.42944 .41865 L
.43268 .25398 L
.43418 .18577 L
.43497 .15644 L
.43581 .1319 L
.43623 .12245 L
.43645 .11826 L
.43669 .1144 L
.43691 .11149 L
.43712 .10933 L
.43731 .10774 L
.43741 .10711 L
.43751 .10656 L
.43757 .10634 L
.43762 .10614 L
Mistroke
.43773 .10587 L
.43783 .10574 L
.43792 .10573 L
.43802 .10584 L
.43807 .10596 L
.43813 .1061 L
.43823 .1065 L
.43835 .10708 L
.43856 .10854 L
.43876 .11042 L
.43913 .11519 L
.43953 .1222 L
.4399 .13012 L
.44072 .15282 L
.4422 .20795 L
.44542 .35555 L
.4469 .41545 L
.44774 .44254 L
.44815 .45348 L
.44852 .46202 L
.44889 .46912 L
.44929 .47516 L
.44951 .47773 L
.44972 .47962 L
.44991 .48099 L
.45001 .48152 L
.45012 .48198 L
.45018 .48216 L
.45023 .4823 L
.45028 .48242 L
.45034 .4825 L
.45044 .48256 L
.45054 .48251 L
.4506 .48243 L
.45066 .4823 L
.45072 .48214 L
.45078 .48195 L
.45088 .4815 L
.45099 .4809 L
.4512 .47946 L
.45138 .47773 L
.45181 .47239 L
.45221 .46572 L
.45265 .45671 L
.45345 .43609 L
.45493 .38583 L
.45649 .32447 L
.45821 .25782 L
.45899 .23122 L
.45983 .2068 L
Mistroke
.46062 .18872 L
.46101 .18196 L
.46135 .17696 L
.46173 .17278 L
.46194 .17107 L
.46214 .16982 L
.46223 .16939 L
.46232 .16901 L
.4624 .16875 L
.46249 .16854 L
.46259 .16839 L
.46269 .16833 L
.46278 .16836 L
.46287 .16846 L
.46297 .16868 L
.46303 .16884 L
.46308 .16901 L
.46328 .16989 L
.46339 .17054 L
.46351 .17137 L
.46372 .17319 L
.46415 .17793 L
.46453 .18361 L
.46532 .19859 L
.46605 .21626 L
.4677 .26562 L
.4692 .31443 L
.47083 .36302 L
.47172 .38456 L
.47211 .39254 L
.47254 .40017 L
.47291 .40578 L
.47332 .41065 L
.47354 .4128 L
.47375 .41443 L
.47394 .41569 L
.47415 .41668 L
.47425 .41705 L
.47436 .41735 L
.47446 .41755 L
.47455 .41767 L
.47464 .41772 L
.47473 .41771 L
.47483 .41763 L
.47492 .41749 L
.47502 .41725 L
.47512 .41694 L
.47531 .41615 L
.47552 .41502 L
.47574 .41344 L
Mistroke
.47611 .41002 L
.4765 .40538 L
.47721 .39464 L
.47894 .35855 L
.48056 .31799 L
.48203 .2821 L
.48287 .26442 L
.48366 .25061 L
.48443 .23999 L
.48487 .23551 L
.48526 .2324 L
.48548 .23109 L
.48568 .23014 L
.4859 .22937 L
.48601 .22909 L
.48607 .22896 L
.48613 .22887 L
.48618 .2288 L
.48624 .22875 L
.48634 .2287 L
.48639 .2287 L
.48645 .22872 L
.48656 .2288 L
.48661 .22886 L
.48666 .22895 L
.48676 .22916 L
.48695 .2297 L
.48714 .23045 L
.48735 .23148 L
.48772 .23392 L
.48815 .23772 L
.48855 .24199 L
.49024 .26688 L
.4919 .29741 L
.49344 .32534 L
.49493 .3475 L
.49569 .35576 L
.49611 .35942 L
.49652 .36213 L
.49689 .36402 L
.49711 .3648 L
.49731 .36534 L
.49741 .36557 L
.49752 .36573 L
.49761 .36583 L
.49771 .3659 L
.49776 .36592 L
.49782 .36593 L
.49787 .36592 L
.49793 .3659 L
Mistroke
.49803 .36583 L
.49809 .36577 L
.49814 .36571 L
.49823 .36556 L
.49833 .36537 L
.4985 .36492 L
.49871 .36422 L
.4989 .36343 L
.49962 .35914 L
.50001 .35604 L
.50043 .35225 L
.50117 .34432 L
.50284 .32301 L
.50444 .30199 L
.50589 .28577 L
.5067 .27893 L
.50707 .27641 L
.50746 .27419 L
.50766 .27325 L
.50788 .27236 L
.50808 .27168 L
.50827 .27117 L
.50848 .27072 L
.5086 .27054 L
.50866 .27047 L
.50872 .2704 L
.50882 .27031 L
.50892 .27026 L
.50898 .27025 L
.50904 .27024 L
.50914 .27026 L
.50923 .27031 L
.50933 .27038 L
.50943 .27049 L
.50951 .2706 L
.50972 .27098 L
.50992 .27146 L
.51032 .27275 L
.51075 .27462 L
.51152 .27908 L
.51223 .28425 L
.51538 .31217 L
.51615 .31849 L
.51696 .32427 L
.51771 .3286 L
.51841 .33161 L
.51876 .33274 L
.51915 .33364 L
.51937 .33401 L
.51947 .33415 L
Mistroke
.51957 .33426 L
.51966 .33434 L
.51976 .3344 L
.51985 .33445 L
.51996 .33447 L
.52001 .33448 L
.52007 .33448 L
.52017 .33445 L
.52028 .33441 L
.52037 .33435 L
.52049 .33425 L
.52059 .33414 L
.52082 .33381 L
.52102 .33344 L
.52124 .33295 L
.52163 .33185 L
.52239 .32898 L
.52323 .32494 L
.52492 .3151 L
.52662 .30513 L
.52742 .30107 L
.52817 .29792 L
.52894 .29542 L
.52934 .29443 L
.52955 .29402 L
.52977 .29364 L
.52997 .29338 L
.53015 .29318 L
.53032 .29304 L
.5304 .29299 L
.53049 .29294 L
.5306 .2929 L
.53069 .29288 L
.53075 .29287 L
.5308 .29287 L
.53091 .29288 L
.53101 .2929 L
.53111 .29293 L
.5312 .29298 L
.53129 .29304 L
.53149 .2932 L
.53171 .29344 L
.53211 .29402 L
.5325 .29477 L
.53285 .29561 L
.53453 .30095 L
.53604 .30675 L
.53768 .31263 L
.53857 .31524 L
.53897 .31619 L
Mistroke
.5394 .31708 L
.53978 .31772 L
.54019 .31826 L
.54041 .31849 L
.54062 .31865 L
.54072 .31872 L
.54082 .31878 L
.54093 .31883 L
.54102 .31887 L
.54112 .31889 L
.54121 .31891 L
.5413 .31892 L
.54141 .31893 L
.5415 .31892 L
.5416 .31891 L
.54169 .31889 L
.54178 .31886 L
.54198 .31877 L
.54221 .31863 L
.54261 .31828 L
.54304 .31777 L
.54349 .3171 L
.5443 .31561 L
.54734 .30858 L
.54891 .30551 L
.54936 .30483 L
.54979 .30428 L
.55017 .30388 L
.55059 .30353 L
.55078 .30341 L
.55099 .3033 L
.55118 .30322 L
.55136 .30317 L
.55146 .30315 L
.55155 .30314 L
.55165 .30313 L
.55171 .30312 L
.55176 .30312 L
.55187 .30312 L
.55192 .30313 L
.55198 .30313 L
.55208 .30315 L
.55218 .30317 L
.55236 .30321 L
.55255 .30328 L
.55289 .30345 L
.55329 .30372 L
.55366 .30403 L
.55519 .30579 L
.55685 .30814 L
Mistroke
.55773 .30936 L
.55856 .31039 L
.55937 .31122 L
.55973 .31152 L
.56012 .3118 L
.56047 .31201 L
.56085 .31219 L
.56106 .31227 L
.56125 .31233 L
.56145 .31237 L
.56154 .31239 L
.56163 .3124 L
.56172 .31241 L
.56182 .31242 L
.56193 .31242 L
.56198 .31242 L
.56203 .31242 L
.56212 .31242 L
.56222 .31242 L
.56232 .31241 L
.56241 .3124 L
.56263 .31236 L
.56282 .31231 L
.56326 .31217 L
.56365 .312 L
.56406 .31178 L
.5648 .3113 L
.56647 .30997 L
.56806 .30869 L
.56876 .3082 L
.56952 .30776 L
.56993 .30756 L
.57032 .30741 L
.57069 .30729 L
.57108 .3072 L
.5713 .30716 L
.57141 .30714 L
.57153 .30713 L
.57164 .30712 L
.57169 .30712 L
.57175 .30711 L
.57186 .30711 L
.57196 .3071 L
.57206 .3071 L
.57212 .3071 L
.57217 .30711 L
.57227 .30711 L
.57238 .30711 L
.57247 .30712 L
.57256 .30713 L
Mistroke
.57276 .30715 L
.57296 .30718 L
.57315 .30722 L
.57359 .30732 L
.57438 .30757 L
.57587 .3082 L
.57738 .30891 L
.57901 .30957 L
.57944 .3097 L
.5799 .30982 L
.58033 .30991 L
.58073 .30998 L
.5811 .31002 L
.58131 .31004 L
.5815 .31005 L
.58161 .31006 L
.58171 .31006 L
.58176 .31006 L
.58182 .31006 L
.58188 .31006 L
.58193 .31006 L
.58204 .31006 L
.58213 .31006 L
.58224 .31006 L
.58229 .31006 L
.58235 .31005 L
.58255 .31004 L
.58277 .31003 L
.58317 .30998 L
.58356 .30993 L
.58392 .30987 L
.5856 .30949 L
.58724 .30907 L
.58803 .30888 L
.58876 .30873 L
.58952 .30861 L
.58986 .30856 L
.59023 .30853 L
.59044 .30851 L
.59062 .30849 L
.59081 .30848 L
.59098 .30847 L
.59119 .30847 L
.59129 .30846 L
.59135 .30846 L
.59141 .30846 L
.59151 .30846 L
.5916 .30846 L
.59165 .30846 L
.59171 .30846 L
Mistroke
.59181 .30846 L
.5919 .30846 L
.592 .30846 L
.59209 .30846 L
.59217 .30847 L
.59237 .30847 L
.59258 .30848 L
.59298 .30851 L
.59341 .30854 L
.59489 .30871 L
.59659 .30895 L
.59815 .30914 L
.59892 .30921 L
.59933 .30924 L
.59976 .30927 L
.60014 .30929 L
.60035 .30929 L
.60055 .3093 L
.60074 .3093 L
.60083 .3093 L
.60091 .30931 L
.601 .30931 L
.6011 .30931 L
.60119 .30931 L
.60128 .30931 L
.60137 .30931 L
.60147 .30931 L
.60158 .30931 L
.60168 .3093 L
.60185 .3093 L
.60203 .3093 L
.60246 .30929 L
.60284 .30927 L
.6036 .30923 L
.60431 .30918 L
.60578 .30908 L
.60661 .30902 L
.6074 .30897 L
.60823 .30893 L
.60899 .3089 L
.60941 .30888 L
.6098 .30888 L
.61002 .30887 L
.61022 .30887 L
.61034 .30887 L
.61044 .30887 L
.6105 .30887 L
.61056 .30887 L
.61062 .30887 L
.61068 .30887 L
Mistroke
.61078 .30887 L
.61088 .30887 L
.61096 .30887 L
.61106 .30887 L
.61116 .30887 L
.61127 .30887 L
.61146 .30887 L
.61181 .30888 L
.61219 .30889 L
.61305 .30891 L
.61385 .30894 L
.61533 .30899 L
.61617 .30902 L
.61696 .30905 L
.61773 .30907 L
.61813 .30907 L
.61857 .30908 L
.6188 .30908 L
.61902 .30909 L
.61923 .30909 L
.61934 .30909 L
.61945 .30909 L
.61956 .30909 L
.61965 .30909 L
.61975 .30909 L
.61984 .30909 L
.61994 .30909 L
.62004 .30909 L
.6201 .30909 L
.62015 .30909 L
.6202 .30909 L
.62026 .30909 L
.62035 .30909 L
.62045 .30909 L
.62063 .30909 L
.62085 .30909 L
.62105 .30909 L
.62147 .30908 L
.62188 .30908 L
.62336 .30905 L
.62483 .30903 L
.62566 .30901 L
.62644 .309 L
.62721 .30899 L
.62764 .30899 L
.62803 .30898 L
.62825 .30898 L
.62845 .30898 L
.62866 .30898 L
.62879 .30898 L
Mistroke
.62884 .30898 L
.6289 .30898 L
.629 .30898 L
.6291 .30898 L
.62921 .30898 L
.62927 .30898 L
.62932 .30898 L
.62942 .30898 L
.62951 .30898 L
.62962 .30898 L
.62972 .30898 L
.62991 .30898 L
.63009 .30898 L
.63049 .30898 L
.63089 .30899 L
.63132 .30899 L
.6328 .309 L
.63437 .30902 L
.63521 .30902 L
.63566 .30903 L
.6361 .30903 L
.63651 .30903 L
.63696 .30903 L
.63716 .30903 L
.63737 .30903 L
.63755 .30903 L
.63774 .30903 L
.63785 .30903 L
.63794 .30903 L
.63803 .30903 L
.63813 .30903 L
.63823 .30903 L
.63829 .30903 L
.63834 .30903 L
.63844 .30903 L
.63854 .30903 L
.63863 .30903 L
.63872 .30903 L
.63889 .30903 L
.63908 .30903 L
.63928 .30903 L
.6397 .30903 L
.6401 .30903 L
.64084 .30903 L
.64252 .30902 L
.64399 .30901 L
.64482 .30901 L
.64523 .30901 L
.6456 .30901 L
.64598 .30901 L
Mistroke
.64617 .30901 L
.64637 .30901 L
.64657 .30901 L
.64676 .30901 L
.64682 .30901 L
.64688 .30901 L
.64693 .30901 L
.64699 .30901 L
.64704 .30901 L
.6471 .30901 L
.64719 .30901 L
.64725 .30901 L
.64731 .30901 L
.64736 .30901 L
.64741 .30901 L
.64751 .30901 L
.64761 .30901 L
.64772 .30901 L
.64783 .30901 L
.64807 .30901 L
.64846 .30901 L
.64888 .30901 L
.65049 .30901 L
.65218 .30902 L
.65294 .30902 L
.65376 .30902 L
.65416 .30902 L
.65453 .30902 L
.65487 .30902 L
.65523 .30902 L
.65542 .30902 L
.65553 .30902 L
.65563 .30902 L
.65572 .30902 L
.65582 .30902 L
.65591 .30902 L
.65599 .30902 L
.65604 .30902 L
.6561 .30902 L
.6562 .30902 L
.6563 .30902 L
.6564 .30902 L
.6565 .30902 L
.65661 .30902 L
.65683 .30902 L
.65725 .30902 L
.6577 .30902 L
.65851 .30902 L
.66011 .30902 L
.66094 .30902 L
Mistroke
.66184 .30902 L
.66263 .30902 L
.66307 .30902 L
.6635 .30902 L
.66369 .30902 L
.66388 .30902 L
.66405 .30902 L
.66424 .30902 L
.66434 .30902 L
.66443 .30902 L
.66453 .30902 L
.66462 .30902 L
.66472 .30902 L
.66482 .30902 L
.66492 .30902 L
.66498 .30902 L
.66503 .30902 L
.66514 .30902 L
.66523 .30902 L
.66545 .30902 L
.66565 .30902 L
.66585 .30902 L
.6666 .30902 L
.66748 .30902 L
.66827 .30902 L
.66995 .30902 L
.67069 .30902 L
.67108 .30902 L
.67149 .30902 L
.6719 .30902 L
.67227 .30902 L
.67245 .30902 L
.67265 .30902 L
.67283 .30902 L
.67292 .30902 L
.673 .30902 L
.67309 .30902 L
.67319 .30902 L
.67328 .30902 L
.67337 .30902 L
.67347 .30902 L
.67356 .30902 L
.67366 .30902 L
.67377 .30902 L
.67388 .30902 L
.67399 .30902 L
.6742 .30902 L
.67459 .30902 L
.67535 .30902 L
.67619 .30902 L
Mistroke
.67788 .30902 L
.67868 .30902 L
.67945 .30902 L
.67987 .30902 L
.68032 .30902 L
.68052 .30902 L
.68074 .30902 L
.68092 .30902 L
.68112 .30902 L
.68131 .30902 L
.68142 .30902 L
.68152 .30902 L
.68161 .30902 L
.68169 .30902 L
.68178 .30902 L
.68188 .30902 L
.68197 .30902 L
.68208 .30902 L
.68217 .30902 L
.68226 .30902 L
.68237 .30902 L
.68248 .30902 L
.68269 .30902 L
.68308 .30902 L
.68345 .30902 L
.68415 .30902 L
.68576 .30902 L
.68722 .30902 L
.68803 .30902 L
.68841 .30902 L
.6888 .30902 L
.689 .30902 L
.68922 .30902 L
.68942 .30902 L
.68961 .30902 L
.68971 .30902 L
.68983 .30902 L
.68989 .30902 L
.68995 .30902 L
.69001 .30902 L
.69006 .30902 L
.69016 .30902 L
.69021 .30902 L
.69027 .30902 L
.69032 .30902 L
.69038 .30902 L
.69048 .30902 L
.69058 .30902 L
.69069 .30902 L
.69089 .30902 L
Mistroke
.69108 .30902 L
.69125 .30902 L
.69165 .30902 L
.69207 .30902 L
.69355 .30902 L
.69514 .30902 L
.69583 .30902 L
.69659 .30902 L
.697 .30902 L
.69739 .30902 L
.69776 .30902 L
.69796 .30902 L
.69815 .30902 L
.69826 .30902 L
.69831 .30902 L
.69837 .30902 L
.69846 .30902 L
.69857 .30902 L
.69863 .30902 L
.69868 .30902 L
.69878 .30902 L
.69884 .30902 L
.69889 .30902 L
.69902 .30902 L
.6992 .30902 L
.69941 .30902 L
.69983 .30902 L
.70025 .30902 L
.70064 .30902 L
.70139 .30902 L
.70306 .30902 L
.70383 .30902 L
.70425 .30902 L
.70465 .30902 L
.70502 .30902 L
.70543 .30902 L
.7056 .30902 L
.70579 .30902 L
.70595 .30902 L
.70613 .30902 L
.70623 .30902 L
.70633 .30902 L
.70642 .30902 L
.70652 .30902 L
.70662 .30902 L
.7067 .30902 L
.70679 .30902 L
.70689 .30902 L
.70699 .30902 L
.70704 .30902 L
Mistroke
.70709 .30902 L
.7072 .30902 L
.70731 .30902 L
.70752 .30902 L
.7077 .30902 L
.70807 .30902 L
.70846 .30902 L
.70917 .30902 L
.71074 .30902 L
.71157 .30902 L
.71246 .30902 L
.7129 .30902 L
.71331 .30902 L
.71369 .30902 L
.7139 .30902 L
.71409 .30902 L
.71429 .30902 L
.71448 .30902 L
.71458 .30902 L
.71467 .30902 L
.71478 .30902 L
.71483 .30902 L
.71489 .30902 L
.71498 .30902 L
.71507 .30902 L
.71517 .30902 L
.71527 .30902 L
.71535 .30902 L
.71544 .30902 L
.71562 .30902 L
.71582 .30902 L
.71599 .30902 L
.7164 .30902 L
.71712 .30902 L
.71878 .30902 L
.7203 .30902 L
.72071 .30902 L
.72116 .30902 L
.72158 .30902 L
.72196 .30902 L
.72215 .30902 L
.72235 .30902 L
.72245 .30902 L
.72256 .30902 L
.72267 .30902 L
.72276 .30902 L
.72286 .30902 L
.72294 .30902 L
.72304 .30902 L
.72314 .30902 L
Mistroke
.72323 .30902 L
.72331 .30902 L
.7234 .30902 L
.7235 .30902 L
.72371 .30902 L
.72393 .30902 L
.72437 .30902 L
.72517 .30902 L
.72688 .30902 L
.72768 .30902 L
.72843 .30902 L
.7292 .30902 L
.7296 .30902 L
.72981 .30902 L
.73004 .30902 L
.73023 .30902 L
.73041 .30902 L
.7305 .30902 L
.73059 .30902 L
.73068 .30902 L
.73076 .30902 L
.73086 .30902 L
.73096 .30902 L
.73105 .30902 L
.73115 .30902 L
.73125 .30902 L
.7313 .30902 L
.73136 .30902 L
.73156 .30902 L
.73176 .30902 L
.73198 .30902 L
.73238 .30902 L
.73312 .30902 L
.7348 .30902 L
.73562 .30902 L
.73639 .30902 L
.73681 .30902 L
.73719 .30902 L
.73762 .30902 L
.73784 .30902 L
.73808 .30902 L
.73818 .30902 L
.73828 .30902 L
.73838 .30902 L
.73848 .30902 L
.73857 .30902 L
.73867 .30902 L
.73876 .30902 L
.73884 .30902 L
.73895 .30902 L
Mistroke
.73905 .30902 L
.73914 .30902 L
.73924 .30902 L
.73935 .30902 L
.73946 .30902 L
.73966 .30902 L
.74006 .30902 L
.74044 .30902 L
.74114 .30902 L
.74262 .30902 L
.74345 .30902 L
.74424 .30902 L
.74463 .30902 L
.74501 .30902 L
.74522 .30902 L
.74545 .30902 L
.74565 .30902 L
.74584 .30902 L
.74604 .30902 L
.74615 .30902 L
.74627 .30902 L
.74633 .30902 L
.74639 .30902 L
.74645 .30902 L
.7465 .30902 L
.74661 .30902 L
.74667 .30902 L
.74672 .30902 L
.74683 .30902 L
.74692 .30902 L
.74703 .30902 L
.74714 .30902 L
.74733 .30902 L
.74753 .30902 L
.74795 .30902 L
.74835 .30902 L
.7491 .30902 L
.75078 .30902 L
.75155 .30902 L
.75197 .30902 L
.75237 .30902 L
.75274 .30902 L
.75308 .30902 L
.75345 .30902 L
.75365 .30902 L
.75374 .30902 L
.75385 .30902 L
.75396 .30902 L
.75406 .30902 L
.75415 .30902 L
Mistroke
.75425 .30902 L
.75434 .30902 L
.75443 .30902 L
.75452 .30902 L
.75462 .30902 L
.75472 .30902 L
.75484 .30902 L
.75504 .30902 L
.75525 .30902 L
.75543 .30902 L
.75615 .30902 L
.75691 .30902 L
.75851 .30902 L
.75936 .30902 L
.75982 .30902 L
.76025 .30902 L
.76064 .30902 L
.76105 .30902 L
.76128 .30902 L
.7614 .30902 L
.76151 .30902 L
.7616 .30902 L
.76171 .30902 L
.76181 .30902 L
.76187 .30902 L
.76193 .30902 L
.76202 .30902 L
.76212 .30902 L
.76222 .30902 L
.76231 .30902 L
.7624 .30902 L
.76249 .30902 L
.76267 .30902 L
.76287 .30902 L
.76308 .30902 L
.76347 .30902 L
.76503 .30902 L
.76586 .30902 L
.76676 .30902 L
.76719 .30902 L
.76761 .30902 L
.76802 .30902 L
.76839 .30902 L
.76875 .30902 L
.76893 .30902 L
.76903 .30902 L
.76912 .30902 L
.76922 .30902 L
.76932 .30902 L
.76942 .30902 L
Mistroke
.76948 .30902 L
.76953 .30902 L
.76963 .30902 L
.76972 .30902 L
.76982 .30902 L
.76992 .30902 L
.77001 .30902 L
.77011 .30902 L
.77029 .30902 L
.7705 .30902 L
.7707 .30902 L
.77152 .30902 L
.773 .30902 L
.7738 .30902 L
.77466 .30902 L
.77507 .30902 L
.77546 .30902 L
.77581 .30902 L
.77601 .30902 L
.77619 .30902 L
.77639 .30902 L
.77656 .30902 L
.77666 .30902 L
.77676 .30902 L
.77681 .30902 L
.77687 .30902 L
.77697 .30902 L
.77707 .30902 L
.77716 .30902 L
.77726 .30902 L
.77731 .30902 L
.77737 .30902 L
.77746 .30902 L
.77757 .30902 L
.77779 .30902 L
.77798 .30902 L
.77816 .30902 L
.77855 .30902 L
.77926 .30902 L
.78093 .30902 L
.78166 .30902 L
.78205 .30902 L
.78247 .30902 L
.78287 .30902 L
.78324 .30902 L
.78342 .30902 L
.78361 .30902 L
.7838 .30902 L
.78397 .30902 L
.78407 .30902 L
Mistroke
.78418 .30902 L
.78427 .30902 L
.78437 .30902 L
.78446 .30902 L
.78452 .30902 L
.78457 .30902 L
.78468 .30902 L
.78474 .30902 L
.78479 .30902 L
.78489 .30902 L
.78498 .30902 L
.78518 .30902 L
.78536 .30902 L
.78555 .30902 L
.78631 .30902 L
.78712 .30902 L
.78859 .30902 L
.78942 .30902 L
.7902 .30902 L
.79059 .30902 L
.79079 .30902 L
.79101 .30902 L
.79113 .30902 L
.79125 .30902 L
.79136 .30902 L
.79147 .30902 L
.79158 .30902 L
.79168 .30902 L
.79178 .30902 L
.79184 .30902 L
.7919 .30902 L
.79199 .30902 L
.79208 .30902 L
.79218 .30902 L
.79228 .30902 L
.79238 .30902 L
.79249 .30902 L
.79269 .30902 L
.79304 .30902 L
.79343 .30902 L
.79509 .30902 L
.79597 .30902 L
.79679 .30902 L
.79754 .30902 L
.79796 .30902 L
.79814 .30902 L
.79834 .30902 L
.79854 .30902 L
.79872 .30902 L
.7988 .30902 L
Mistroke
.7989 .30902 L
.79899 .30902 L
.79907 .30902 L
.79917 .30902 L
.79927 .30902 L
.79936 .30902 L
.79945 .30902 L
.79956 .30902 L
.79961 .30902 L
.79967 .30902 L
.79986 .30902 L
.80008 .30902 L
.80027 .30902 L
.8007 .30902 L
.80148 .30902 L
.80314 .30902 L
.80387 .30902 L
.80426 .30902 L
.80468 .30902 L
.80508 .30902 L
.80525 .30902 L
.80545 .30902 L
.80562 .30902 L
.8058 .30902 L
.8059 .30902 L
.80599 .30902 L
.80608 .30902 L
.80617 .30902 L
.80627 .30902 L
.80637 .30902 L
.80647 .30902 L
.80656 .30902 L
.80662 .30902 L
.80667 .30902 L
.80676 .30902 L
.80687 .30902 L
.80698 .30902 L
.80718 .30902 L
.80738 .30902 L
.80775 .30902 L
.80858 .30902 L
.80948 .30902 L
.81025 .30902 L
.8111 .30902 L
.8115 .30902 L
.81193 .30902 L
.81233 .30902 L
.8127 .30902 L
.81292 .30902 L
.81312 .30902 L
Mistroke
.81322 .30902 L
.81334 .30902 L
.8134 .30902 L
.81346 .30902 L
.81352 .30902 L
.81357 .30902 L
.81368 .30902 L
.81377 .30902 L
.81383 .30902 L
.81388 .30902 L
.81394 .30902 L
.81399 .30902 L
.81409 .30902 L
.81419 .30902 L
.81439 .30902 L
.81477 .30902 L
.81518 .30902 L
.81591 .30902 L
.81756 .30902 L
.81838 .30902 L
.81881 .30902 L
.81927 .30902 L
.81967 .30902 L
.81989 .30902 L
.82011 .30902 L
.8202 .30902 L
.8203 .30902 L
.82039 .30902 L
.82048 .30902 L
.82058 .30902 L
.82067 .30902 L
.82073 .30902 L
.82078 .30902 L
.82088 .30902 L
.82097 .30902 L
.82107 .30902 L
.82117 .30902 L
.82125 .30902 L
.82146 .30902 L
.82166 .30902 L
.82206 .30902 L
.82249 .30902 L
.82397 .30902 L
.82478 .30902 L
.82555 .30902 L
.82598 .30902 L
.82643 .30902 L
.82664 .30902 L
.82685 .30902 L
.82704 .30902 L
Mistroke
.82723 .30902 L
.82734 .30902 L
.82744 .30902 L
.82753 .30902 L
.82763 .30902 L
.82772 .30902 L
.82781 .30902 L
.8279 .30902 L
.828 .30902 L
.8281 .30902 L
.82815 .30902 L
.8282 .30902 L
.82831 .30902 L
.82842 .30902 L
.82863 .30902 L
.82881 .30902 L
.82957 .30902 L
.83029 .30902 L
.83176 .30902 L
.8326 .30902 L
.833 .30902 L
.83338 .30902 L
.83357 .30902 L
.83377 .30902 L
.83395 .30902 L
.83415 .30902 L
.83436 .30902 L
.83447 .30902 L
.83458 .30902 L
.83468 .30902 L
.83477 .30902 L
.83487 .30902 L
.83497 .30902 L
.83508 .30902 L
.83518 .30902 L
.83523 .30902 L
.83529 .30902 L
.83539 .30902 L
.83559 .30902 L
.83578 .30902 L
.83621 .30902 L
.83666 .30902 L
.83825 .30902 L
.83895 .30902 L
.8397 .30902 L
.84012 .30902 L
.8405 .30902 L
.84087 .30902 L
.84107 .30902 L
.84126 .30902 L
Mistroke
.84137 .30902 L
.84148 .30902 L
.84157 .30902 L
.84168 .30902 L
.84173 .30902 L
.84179 .30902 L
.84185 .30902 L
.84191 .30902 L
.84201 .30902 L
.84207 .30902 L
.84212 .30902 L
.84222 .30902 L
.84231 .30902 L
.84252 .30902 L
.84272 .30902 L
.84294 .30902 L
.84371 .30902 L
.84455 .30902 L
.84543 .30902 L
.84624 .30902 L
.84663 .30902 L
.84705 .30902 L
.84745 .30902 L
.84781 .30902 L
.84802 .30902 L
.8482 .30902 L
.84831 .30902 L
.84841 .30902 L
.84846 .30902 L
.84852 .30902 L
.84858 .30902 L
.84863 .30902 L
.84869 .30902 L
.84874 .30902 L
.8488 .30902 L
.84885 .30902 L
.84895 .30902 L
.84905 .30902 L
.8491 .30902 L
.84916 .30902 L
.84926 .30902 L
.8495 .30902 L
.8497 .30902 L
.84992 .30902 L
.85032 .30902 L
.8512 .30902 L
.85198 .30902 L
.85282 .30902 L
.85324 .30902 L
.85364 .30902 L
Mistroke
.85403 .30902 L
.85439 .30902 L
.85473 .30902 L
.85492 .30902 L
.85509 .30902 L
.85519 .30902 L
.85528 .30902 L
.85538 .30902 L
.85548 .30902 L
.85558 .30902 L
.85566 .30902 L
.85576 .30902 L
.85586 .30902 L
.85595 .30902 L
.85606 .30902 L
.85628 .30902 L
.85648 .30902 L
.85667 .30902 L
.85756 .30902 L
.85917 .30902 L
.85996 .30902 L
.86039 .30902 L
.86079 .30902 L
.86114 .30902 L
.8615 .30902 L
.86171 .30902 L
.86181 .30902 L
.86191 .30902 L
.86199 .30902 L
.86209 .30902 L
.86218 .30902 L
.86228 .30902 L
.86238 .30902 L
.86248 .30902 L
.86258 .30902 L
.86264 .30902 L
.8627 .30902 L
.86279 .30902 L
.8629 .30902 L
.86309 .30902 L
.86348 .30902 L
.86384 .30902 L
.86551 .30902 L
.86624 .30902 L
.86703 .30902 L
.86748 .30902 L
.86788 .30902 L
.86808 .30902 L
.8683 .30902 L
.8685 .30902 L
Mistroke
.86869 .30902 L
.86878 .30902 L
.86888 .30902 L
.86897 .30902 L
.86906 .30902 L
.86916 .30902 L
.86921 .30902 L
.86927 .30902 L
.86937 .30902 L
.86946 .30902 L
.86955 .30902 L
.86964 .30902 L
.86981 .30902 L
.87019 .30902 L
.87059 .30902 L
.87097 .30902 L
.87184 .30902 L
.87256 .30902 L
.87333 .30902 L
.87378 .30902 L
.87418 .30902 L
.87458 .30902 L
.87496 .30902 L
.87517 .30902 L
.87528 .30902 L
.87538 .30902 L
.87548 .30902 L
.87557 .30902 L
.87567 .30902 L
.87578 .30902 L
.87583 .30902 L
.87589 .30902 L
.87599 .30902 L
.87605 .30902 L
.87611 .30902 L
.87623 .30902 L
.87634 .30902 L
.87644 .30902 L
.87666 .30902 L
.87706 .30902 L
.87749 .30902 L
.87827 .30902 L
.87915 .30902 L
.87998 .30902 L
.88073 .30902 L
.88115 .30902 L
.88134 .30902 L
.88154 .30902 L
.88173 .30902 L
.88191 .30902 L
Mistroke
.882 .30902 L
.88209 .30902 L
.88218 .30902 L
.88226 .30902 L
.88236 .30902 L
.88247 .30902 L
.88257 .30902 L
.88263 .30902 L
.88268 .30902 L
.88277 .30902 L
.88287 .30902 L
.88297 .30902 L
.88306 .30902 L
.88347 .30902 L
.88384 .30902 L
.88468 .30902 L
.88549 .30902 L
.88635 .30902 L
.88708 .30902 L
.8875 .30902 L
.88789 .30902 L
.88808 .30902 L
.88828 .30902 L
.88848 .30902 L
.88857 .30902 L
.88866 .30902 L
.88875 .30902 L
.88884 .30902 L
.88893 .30902 L
.88901 .30902 L
.88909 .30902 L
.88919 .30902 L
.88928 .30902 L
.88937 .30902 L
.88947 .30902 L
.88958 .30902 L
.88978 .30902 L
.89015 .30902 L
.89058 .30902 L
.89097 .30902 L
.8926 .30902 L
.8934 .30902 L
.89375 .30902 L
.89413 .30902 L
.8945 .30902 L
.89484 .30902 L
.89503 .30902 L
.8952 .30902 L
.8953 .30902 L
.8954 .30902 L
Mistroke
.8955 .30902 L
.89559 .30902 L
.89568 .30902 L
.89578 .30902 L
.89587 .30902 L
.89595 .30902 L
.89605 .30902 L
.89616 .30902 L
.89635 .30902 L
.89677 .30902 L
.89716 .30902 L
.89879 .30902 L
.89958 .30902 L
.89993 .30902 L
.90031 .30902 L
.90065 .30902 L
.90102 .30902 L
.90122 .30902 L
.90141 .30902 L
.90159 .30902 L
.90177 .30902 L
.90186 .30902 L
.90196 .30902 L
.90206 .30902 L
.90216 .30902 L
.90225 .30902 L
.90233 .30902 L
.90243 .30902 L
.90252 .30902 L
.90262 .30902 L
.90272 .30902 L
.90291 .30902 L
.90334 .30902 L
.90494 .30902 L
.90579 .30902 L
.90625 .30902 L
.90668 .30902 L
.9071 .30902 L
.90748 .30902 L
.90769 .30902 L
.9079 .30902 L
.90812 .30902 L
.90824 .30902 L
.9083 .30902 L
.90835 .30902 L
.90844 .30902 L
.90854 .30902 L
.90862 .30902 L
.90871 .30902 L
.90881 .30902 L
Mistroke
.9089 .30902 L
.909 .30902 L
.9091 .30902 L
.90932 .30902 L
.90952 .30902 L
.9099 .30902 L
.91137 .30902 L
.9122 .30902 L
.91261 .30902 L
.91298 .30902 L
.91335 .30902 L
.91375 .30902 L
.91397 .30902 L
.91418 .30902 L
.91437 .30902 L
.91458 .30902 L
.91469 .30902 L
.9148 .30902 L
.91486 .30902 L
.91492 .30902 L
.91498 .30902 L
.91504 .30902 L
.91509 .30902 L
.91515 .30902 L
.91524 .30902 L
.9153 .30902 L
.91535 .30902 L
.91547 .30902 L
.91565 .30902 L
.91586 .30902 L
.91627 .30902 L
.91796 .30902 L
.91876 .30902 L
.9195 .30902 L
.91987 .30902 L
.92026 .30902 L
.92049 .30902 L
.9207 .30902 L
.92089 .30902 L
.921 .30902 L
.9211 .30902 L
.92118 .30902 L
.92128 .30902 L
.92137 .30902 L
.92145 .30902 L
.92154 .30902 L
.92165 .30902 L
.92174 .30902 L
.92183 .30902 L
.92201 .30902 L
Mistroke
.92221 .30902 L
.92261 .30902 L
.9243 .30902 L
.92503 .30902 L
.92542 .30902 L
.92584 .30902 L
.92625 .30902 L
.92662 .30902 L
.9268 .30902 L
.927 .30902 L
.92718 .30902 L
.92735 .30902 L
.92744 .30902 L
.92754 .30902 L
.92763 .30902 L
.92772 .30902 L
.92782 .30902 L
.92787 .30902 L
.92793 .30902 L
.92802 .30902 L
.92812 .30902 L
.92823 .30902 L
.92835 .30902 L
.92855 .30902 L
.92894 .30902 L
.93051 .30902 L
.93135 .30902 L
.9318 .30902 L
.93224 .30902 L
.93265 .30902 L
.93287 .30902 L
.9331 .30902 L
.93329 .30902 L
.93339 .30902 L
.9335 .30902 L
.9336 .30902 L
.9337 .30902 L
.93379 .30902 L
.93388 .30902 L
.93397 .30902 L
.93406 .30902 L
.93416 .30902 L
.93426 .30902 L
.93435 .30902 L
.93443 .30902 L
.93461 .30902 L
.9348 .30902 L
.935 .30902 L
.93541 .30902 L
.9371 .30902 L
Mistroke
.93791 .30902 L
.93865 .30902 L
.93902 .30902 L
.93942 .30902 L
.93962 .30902 L
.93981 .30902 L
.93992 .30902 L
.94002 .30902 L
.94008 .30902 L
.94013 .30902 L
.9402 .30902 L
.94025 .30902 L
.94035 .30902 L
.94045 .30902 L
.94055 .30902 L
.94064 .30902 L
.94072 .30902 L
.94081 .30902 L
.94098 .30902 L
.94139 .30902 L
.94177 .30902 L
.94326 .30902 L
.94404 .30902 L
.94448 .30902 L
.94488 .30902 L
.9451 .30902 L
.94534 .30902 L
.94554 .30902 L
.94576 .30902 L
.94597 .30902 L
.94608 .30902 L
.94619 .30902 L
.94629 .30902 L
.94638 .30902 L
.94648 .30902 L
.94658 .30902 L
.94667 .30902 L
.94677 .30902 L
.94682 .30902 L
.94688 .30902 L
.94698 .30902 L
.94717 .30902 L
.94735 .30902 L
.94776 .30902 L
.94819 .30902 L
.94979 .30902 L
.95049 .30902 L
.95086 .30902 L
.95125 .30902 L
.95145 .30902 L
Mistroke
.95167 .30902 L
.95188 .30902 L
.95206 .30902 L
.95225 .30902 L
.95236 .30902 L
.95246 .30902 L
.95255 .30902 L
.95263 .30902 L
.95273 .30902 L
.95282 .30902 L
.95288 .30902 L
.95294 .30902 L
.95304 .30902 L
.95316 .30902 L
.95328 .30902 L
.9535 .30902 L
.95371 .30902 L
.95451 .30902 L
.95601 .30902 L
.95642 .30902 L
.95685 .30902 L
.95723 .30902 L
.95763 .30902 L
.95785 .30902 L
.95805 .30902 L
.95825 .30902 L
.95835 .30902 L
.95845 .30902 L
.95855 .30902 L
.95861 .30902 L
.95867 .30902 L
.95877 .30902 L
.95882 .30902 L
.95888 .30902 L
.95893 .30902 L
.95898 .30902 L
.95904 .30902 L
.9591 .30902 L
.95917 .30902 L
.95923 .30902 L
.95934 .30902 L
.95954 .30902 L
.95974 .30902 L
.96012 .30902 L
.96096 .30902 L
.96173 .30902 L
.96254 .30902 L
.96323 .30902 L
.96362 .30902 L
.96399 .30902 L
Mistroke
.96419 .30902 L
.96438 .30902 L
.96455 .30902 L
.96465 .30902 L
.96474 .30902 L
.96483 .30902 L
.96492 .30902 L
.96502 .30902 L
.96513 .30902 L
.96518 .30902 L
.96524 .30902 L
.96534 .30902 L
.96554 .30902 L
.96576 .30902 L
.96596 .30902 L
.96641 .30902 L
.96721 .30902 L
.96803 .30902 L
.96847 .30902 L
.96889 .30902 L
.96927 .30902 L
.96962 .30902 L
.97001 .30902 L
.97023 .30902 L
.97043 .30902 L
.97061 .30902 L
.97071 .30902 L
.9708 .30902 L
.9709 .30902 L
.97099 .30902 L
.97109 .30902 L
.9712 .30902 L
.97129 .30902 L
.97138 .30902 L
.97154 .30902 L
.97174 .30902 L
.97191 .30902 L
.97274 .30902 L
.97353 .30902 L
.9742 .30902 L
.97491 .30902 L
.97552 .30902 L
.97587 .30902 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{421.375, 260.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008>0001AB000`400?l00000o`00003ooooooooo
oooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo
003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooo
oooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool0
0?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooooooo
ool@ooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooo
ooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo0ol0003o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0
003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo
00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`
ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLoooo
o`00<?ooool3o`000?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?oo
ool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0
033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomco
oooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooo
oooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool3o`000?oooooo
g?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0P?ooool00ol0003oooooooooo`3ooooooeWooooo000`ooooo`03o`000?oooooooooo083ooooo
00?o0000ooooooooool0oooooomIooooo`00<?ooool00ol0003oooooooooo`20ooooo`03o`000?oo
oooooooo0?ooooooFOooool0013ooooo0_o^k^h3ooooo`;ok^k^6Oooool00ol0003oooooooooo`1o
ooooo`;o0000oooooomKooooo`002oooool2o`00000:oa0@4?ooooooooooonk^k_mEEEGok^k^oooo
ooo^k^koEEEEonk^kP?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^2_oo
ool00ol0003oooooooooo`1oooooo`;o0000oooooomKooooo`003?ooool00ol0003oooooooooo`02
ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02_ooool00ol0003oooooooooo`1oooooo`;o0000oooooomKooooo`0000?o
ooooo`000?l000001?l00002ooooo`Go00001?ooool00ooMgMgo0000omgMg@07ooooo`03o`000?oo
oooooooo00;ooooo00Go410@oooooooooooooooooa0@400:ooooo`03o`000?oooooooooo07oooooo
0_l0003ooooooe_ooooo0009ooooo`04odA4A?oMgMgoooooo`0000Cooooo00Gok^k^oeEEEOoMgMgo
EEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000:oooo
o`03o`000?oooooooooo07oooooo0_l0003ooooooe_ooooo0009ooooo`04omgMgOmEEEGoooooo`00
00?ooooo00Ook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000000[ooooo1?l0001nooooo`;o0000oooooomKooooo`002_oo
ool00omgMgOoc<c<o`000003ooooo`;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@00[ooooo00?o0000ooooooooool0Ooooool00ol0003ooooo
o`00003ooooooe[ooooo000:ooooo`03onk^k_m4A4Co000000oooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo0_l00005ooooo`03o`000?oooooooooo07oooooo
00?o0000ooooool00000oooooomJooooo`002oooool00omgMgOo0000ooooo`0<ooooo`03oeEEEOmV
IVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`04o`000?ooooooooooo`0000Co
oooo00?o0000ooooooooool0Ooooool00ol0003oooooo`00003ooooooe[ooooo000Xooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooo00000?ooooooF_ooool002Sooooo0ol00005ooooo`03o`000?oooooooooo07Cooooo
00?o0000ooooooooool02?ooool00ol0003oooooo`00003ooooooe[ooooo000Yooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooo000000Wooooo00?o0000ooooooooool0oooooom>ooooo`00:_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo07?ooooo0_l0000:ooooo`03o`000?oooooo000000Wooooo0_l0003o
ooooodoooooo000`ooooo`03o`000?oooooooooo07?ooooo0_l0000:ooooo`03o`000?oooooo0000
00Wooooo0_l0003oooooodoooooo000`ooooo`03o`000?oooooooooo07?ooooo00?o0000ooooool0
00002Oooool00ol0003oooooo`000009ooooo`;o0000oooooom?ooooo`00<?ooool00ol0003ooooo
ooooo`1cooooo`03o`000?oooooo000000Wooooo00?o0000ooooool000002Oooool2o`000?oooooo
Coooool0033ooooo00?o0000ooooooooool0Loooool00ol0003oooooo`000009ooooo`03o`000?oo
oooo000000Wooooo0_l0003oooooodoooooo000`ooooo`?o0000Loooool00ol0003oooooo`000009
ooooo`03o`000?oooooo000000Wooooo0_l0003oooooodoooooo000`ooooo`03o`000?oooooooooo
07?ooooo00?o0000ooooool000002Oooool00ol0003oooooo`000009ooooo`;o0000oooooom?oooo
o`00<?ooool00ol0003oooooooooo`1cooooo`03o`000?oooooo000000Wooooo00?o0000ooooool0
00002Oooool2o`000?ooooooCoooool0033ooooo00?o0000ooooooooool0Loooool00ol0003ooooo
o`000009ooooo`03o`000?oooooo000000Wooooo0_l0003oooooodoooooo000`ooooo`03o`000?oo
oooooooo07?ooooo00?o0000ooooool000002Oooool00ol0003oooooo`000008ooooo`03o`000?oo
oooo00000?ooooooCoooool0033ooooo00?o0000ooooooooool0Loooool00ol0003oooooo`000009
ooooo`03o`000?oooooo000000Sooooo00?o0000ooooool00000oooooom?ooooo`00<?ooool00ol0
003oooooooooo`1cooooo`03o`000?oooooo000000Wooooo00?o0000ooooool000002?ooool00ol0
003oooooo`00003oooooodoooooo000`ooooo`03o`000?oooooooooo07?ooooo00?o0000ooooool0
00002Oooool00ol0003oooooo`000008ooooo`03o`000?oooooo00000?ooooooCoooool0033ooooo
00?o0000ooooooooool0Loooool00ol0003oooooo`000009ooooo`03o`000?oooooo000000Sooooo
00?o0000ooooool00000oooooom?ooooo`00<?ooool00ol0003oooooooooo`1cooooo`03o`000?oo
oooo000000Wooooo00?o0000ooooool000002?ooool00ol0003oooooo`00003oooooodoooooo000`
ooooo`03o`000?oooooooooo07?ooooo00?o0000ooooool000002Oooool00ol0003oooooo`000008
ooooo`03o`000?oooooo00000?ooooooCoooool0033ooooo00?o0000ooooooooool0Loooool00ol0
003oooooo`000008ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooom?
ooooo`00<?ooool3o`0007?ooooo00?o0000ooooool000002?ooool01?l0003oooooooooool00008
ooooo`03o`000?oooooo00000?ooooooCoooool0033ooooo00?o0000ooooooooool0Loooool00ol0
003oooooo`000008ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooom?
ooooo`00<?ooool00ol0003oooooooooo`1cooooo`03o`000?oooooo000000Sooooo00Co0000oooo
oooooooo00002?ooool00ol0003oooooo`00003oooooodoooooo000`ooooo`03o`000?oooooooooo
07?ooooo00?o0000ooooool000002?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo
00000?ooooooCoooool0033ooooo00?o0000ooooooooool0L_ooool01?l0003oooooooooool00008
ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooom?ooooo`00<?ooool0
0ol0003oooooooooo`1booooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000
2?ooool00ol0003oooooo`00003oooooodoooooo000`ooooo`03o`000?oooooooooo07;ooooo00Go
0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool0
0000oooooom?ooooo`00<?ooool00ol0003oooooooooo`1booooo`05o`000?ooooooooooooooool0
00001oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?ooooooCoooool0033o
oooo00?o0000ooooooooool0L_ooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooo
oooooooo00002?ooool00ol0003oooooo`00003oooooodoooooo000`ooooo`03o`000?oooooooooo
07;ooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Sooooo00?o
0000ooooool000002Oooool00ol0003oooooooooo`3ooooood?ooooo000`ooooo`03o`000?oooooo
oooo07;ooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Sooooo
00?o0000ooooool000002Oooool00ol0003oooooooooo`3ooooood?ooooo000`ooooo`?o0000L_oo
ool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo00002?ooool00ol0003o
ooooo`000009ooooo`03o`000?oooooooooo0?oooooo@oooool0033ooooo00?o0000ooooooooool0
Ioooool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool000001oooool01?l0003o
ooooooooool00008ooooo`03o`000?oooooo000000Wooooo00?o0000ooooooooool0oooooom3oooo
o`00<?ooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo00Sooooo00Go0000oooooooo
ooooooooo`000007ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool000002?ooool0
0ol0003oooooo`00003oooooodCooooo000`ooooo`03o`000?oooooooooo06Kooooo0_l0000:oooo
o`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool00008ooooo`03o`000?oo
oooo000000Sooooo00?o0000ooooool00000oooooom4ooooo`00<?ooool00ol0003oooooooooo`1V
ooooo`03o`000?oooooo000000Wooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?oo
ooooooooo`0000Sooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00003oooooodCo
oooo000`ooooo`03o`000?oooooooooo06Kooooo00?o0000ooooool000002Oooool01Ol0003ooooo
oooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?oooooooooo
o`0000Oooooo00?o0000ooooool00000oooooom4ooooo`00<?ooool00ol0003oooooooooo`1Voooo
o`03o`000?oooooo000000Wooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooo
ooooooooool000001oooool01?l0003oooooooooool00007ooooo`03o`000?oooooo00000?oooooo
A?ooool0013ooooo0_o^k^h3ooooo`;ok^k^6Oooool00ol0003oooooooooo`1Vooooo`03o`000?oo
oooo000000Wooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool0
00001oooool01?l0003oooooooooool00007ooooo`03o`000?oooooo00000?ooooooA?ooool000Wo
oooo1Ol00002ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co000000So410@
ooooooooooook^k^oc8b<_l0003o<S8bonk^kP[ooooo00?o0000ooooooooool0I_ooool00ol0003o
ooooo`000009ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo
000000Oooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00003oooooodCooooo0009
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00[ooooo00?o0000oooooooo
ool0I_ooool00ol0003oooooo`000009ooooo`05o`000?ooooooooooooooool000001oooool01Ol0
003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00
003oooooodCooooo00000ooooooo0000o`000004o`0000?ooooo00?oV9RHob4Q8Oo^k^h01Oooool0
0ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
400:ooooo`03o`000?oooooooooo06Kooooo00?o0000ooooool000002Oooool01Ol0003ooooooooo
oooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`00
00Oooooo00?o0000ooooool00000oooooom4ooooo`002oooool00onHV9So8B4Qonk^kP03ooooo`05
onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool000002_ooool00ol0003oooooooooo`1Vooooo`03o`000?oooooo000000Wooooo00Go0000
ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool01?l0003ooooo
ooooool00007ooooo`03o`000?oooooo00000?ooooooA?ooool000cooooo00_oMgMgofIVI_oooooo
ooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`00000:ooooo`Co0000IOooool00ol0003oooooo`000008ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000Oo
oooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00003oooooodCooooo000=ooooo`03
o`000?oooooooooo00;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@413o
oooooooooooooooo410@00[ooooo00?o0000ooooooooool0I_ooool00ol0003oooooo`000008oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo
000000Oooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00003oooooodCooooo0009
ooooo`05o`000?nj^[[ooooooiRHV?l@41003_ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL00oooool2o`0000Gooooo00?o0000ooooooooool0I_ooool00ol0003ooooo
o`000008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool01Ol0003ooooo
oooooooooooo000000Oooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00003ooooo
odCooooo0009ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?ooool00omEEEGoIVIVo`000004oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h00_ooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo06Kooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Gooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oo
oooo00?o0000ooooool00000oooooom4ooooo`00:?ooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo06Gooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000
oooooooooooo00001oooool00ol0003oooooo`00003oooooodCooooo000Xooooo`?o00001Oooool0
0ol0003oooooooooo`1Uooooo`05o`000?ooooooooooooooool000001oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000007ooooo`04o`00
0?ooooooooooo`0000Oooooo00?o0000ooooool00000oooooom4ooooo`00:Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo06Gooooo00Go0000ooooooooooooooooo`000007ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo0000
00Oooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00003oooooodCooooo000Zoooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0IOooool01Ol0003ooooooooooooooooo
000000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`05o`000?oooooo
ooooooooool000001oooool01?l0003oooooooooool00007ooooo`03o`000?oooooo00000?oooooo
A?ooool0033ooooo00?o0000ooooooooool0IOooool01Ol0003ooooooooooooooooo000000Oooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool0
00001oooool01?l0003oooooooooool00007ooooo`03o`000?oooooo00000?ooooooA?ooool0033o
oooo00?o0000ooooooooool0IOooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000001_ooool0
1Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo0000oooooom4ooooo`00<?oo
ool00ol0003oooooooooo`1Uooooo`05o`000?ooooooooooooooool000001oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000006ooooo`05
o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool0003oooooodCooooo000`oooo
o`03o`000?oooooooooo06Gooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000Kooooo00Go
0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`000?ooooooA?ooool0033ooooo
0ol0001Uooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?oooooooooo
ooooool000001_ooool01?l0003oooooooooool00008ooooo`;o0000ooooooljooooo`00<?ooool0
0ol0003oooooooooo`1Uooooo`05o`000?ooooooooooooooool000001oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000006ooooo`05o`00
0?ooooooooooooooool000001_ooool01?l0003oooooooooool00008ooooo`;o0000ooooooljoooo
o`00<?ooool00ol0003oooooooooo`1Uooooo`05o`000?ooooooooooooooool000001oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000006
ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool00008ooooo`;o0000
ooooooljooooo`00<?ooool00ol0003oooooooooo`1Uooooo`05o`000?ooooooooooooooool00000
1oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00Go0000oooooooooooo
ooooo`000006ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool00008
ooooo`;o0000ooooooljooooo`00<?ooool00ol0003oooooooooo`1Uooooo`05o`000?oooooooooo
ooooool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00Go0000
ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003ooooo
ooooool00008ooooo`;o0000ooooooljooooo`00<?ooool00ol0003oooooooooo`1Uooooo`05o`00
0?ooooooooooooooool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Go
oooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001_ooool0
1?l0003oooooooooool00007ooooo`03o`000?oooooo00000?oooooo>_ooool0033ooooo00?o0000
ooooooooool0IOooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooo00000?oooooo>_ooool0033ooooo00?o0000ooooooooool0IOooool01Ol0003ooooo
oooooooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000
00Kooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo00000?oooooo>_ooool0
033ooooo00?o0000ooooooooool0IOooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooo00000?oooooo>_ooool0033ooooo00?o0000
ooooooooool0IOooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooo00000?oooooo>_ooool0033ooooo00?o0000ooooooooool0FOoo
ool00ol0003oooooooooo`09ooooo`05o`000?ooooooooooooooool000001oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooool00000ooooooljooooo`00<?ooool00ol0003ooooo
ooooo`1Hooooo`?o00002_ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooo
ooooooooo`000006ooooo`03o`000?oooooo00000?oooooo>_ooool0033ooooo0ol0001Hooooo`03
o`000?oooooo000000Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05
o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool0003oooooocWooooo000`oooo
o`03o`000?oooooooooo05Sooooo00?o0000ooooool000002Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?oooooo
ooooo`000?oooooo>Oooool0033ooooo00?o0000ooooooooool0F?ooool00ol0003oooooo`000009
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooo
oooo000000Kooooo00Co0000oooooooooooo0000ooooooliooooo`00<?ooool00ol0003ooooooooo
o`1Hooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool0003ooooo
ocWooooo000`ooooo`03o`000?oooooooooo05Oooooo00Go0000ooooooooooooooooo`000008oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo
000000Kooooo00Co0000oooooooooooo0000ooooooliooooo`00<?ooool00ol0003oooooooooo`1>
ooooo`;ok^k^0oooool2onk^kP;ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Kooooo
00Co0000oooooooooooo00002Oooool2onk^kP?ooooo0_o^k^iPooooo`;ok^k^0oooool2onk^kTko
oooo0_o^k^h3ooooo`;ok^k^K?ooool0033ooooo00?o0000ooooooooool0B?ooool03Om4A4Co0000
o`000?lb<S;ogMgMooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00_ooool5o`000009oa0@
4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^ko000000Cooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool0
1Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo00000oooool5o`000008oooo
ooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h3ooooo`Co000000So410@ooooooooooook^k^oc8b
<_l0003o<S8bonk^kS_ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool03Om4A4Co
0000o`000?lb<S;ogMgMooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008
oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hhooooo`Go00000_ooool01oo^k^koEEEEonk^
k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^iMooooo`00<?ooool00ol0003oooooooooo`1;ooooo`09ogMgMolb<S;oooooooooooo^k^koEEEE
omgMgOmEEEGok^k^00?ooooo00?o0000ooooooooool00_l00003ooooo`06ogMgMonHV9SooooooiRH
V?mgMgOo00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001_oo
ool01?l0003oooooooooool00005ooooo`0:o`000?oooooo0000o`000?ooooook^k^oeEEEOoMgMgo
EEEEonk^kPKooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg03gooooo
00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00WoMgMgoc8b<_ooooooooooonk^k_mEEEGogMgM
oeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0>?oo
ool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Mooooo`00<?ooool00ol0003o
ooooooooo`1<ooooo`07o`000?oooooooooooooooooMgMgo0000omgMg@04ooooo`03o`000?oooooo
oooo00;o00000oooool01_l@413ooooooooooooooooo410@o`0000Cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo00001Oooool4o`00
00;ooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@4100?Oooool00ol0003oooooooooo`0?ooooo`07o`000?oooooooooooooooooMgMgo0000
omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400iooooo`03
oiRHV?lQ8B7ok^k^00Gooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05
oa0@4?ooooooooooooooool@4100GOooool0033ooooo00?o0000ooooooooool0Boooool02OmgMgOo
<S8booooooooooook^k^oeEEEOoMgMgoEEEEonk^kP03ooooo`03o`000?oooooooooo00;o00000ooo
ool01?l0003oooooooooooooool2o`0000Gooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooo
oooooooooooo000000Gooooo00Go0000ooooooooooooooooo`000005ooooo`;o000000Soooooo`00
0?ooooook^k^oeEEEOoMgMgoEEEEonk^kPKooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000003gooooo00?o0000ooooooooool03_ooool02OmgMgOo<S8booooooooooook^k^
oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000jooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03
o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001Mooooo`00<?ooool00ol0003o
ooooooooo`18ooooo`0=o`000?lQ8B7o0000oc8b<_o<c<coooooonk^k_mEEEGok^k^ooooooo^k^ko
EEEEonk^kP02ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool01?l0003ooooooooooooo
ool2o`0000Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Gooooo
00Go0000ooooooooooooooooo`000005ooooo`;o000000Woooooo`000?o^k^koEEEEonk^k_oooooo
k^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
?Oooool00ol0003oooooooooo`0;ooooo`0=o`000?lQ8B7o0000oc8b<_o<c<coooooonk^k_mEEEGo
k^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`00000kooooo`0;ogMgMomVIVKoooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h0
1Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000GOooool0033ooooo
00?o0000ooooooooool0B?ooool00ol0003oooooooooo`03ooooo`;ok^k^0oooool2onk^kP03oooo
ool0003ooooo00;ooooo00?o0000ooooool000000_ooool01_l@413ooooooooooooooooo410@o`00
00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Gooooo00Go0000
ooooooooooooooooo`000005ooooo`;o000000Coooooo`000?o^k^kok^k^0oooool2onk^kPGooooo
00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@03gooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`03ooooo`;ok^k^0oooool2onk^kPGooooo00?o0000oooooooo
ool00_ooool01Ol@413ooooooooooooooooo410@03cooooo00?o0000ooooooooool00_o^k^h3oooo
o`;ok^k^1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100GOooool0
033ooooo0ol00018ooooo`03o`000?oooooooooo00_ooooo00Oo0000ooooooooooooooooo`000?oo
oooo000000;ooooo00KoMgMgoiRHV?ooooooV9RHogMgMol00005ooooo`03o`000?oooooo000000Co
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00_ooool2o`0000;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool2o`0003?ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`08ooooo`;o0000;_ooool01Ol0003o^[ZjoooooonHV9So410@00kooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo0_l0001Cooooo`00<?ooool00ol0003ooooo
ooooo`18ooooo`Co00002_ooool01ol0003ooooooeEEEOmVIVKo0000ooooool000000_ooool01_o^
k^ko<S8bo`000?lb<S;ok^k^o`0000Gooooo00?o0000ooooool000001?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooo
oooooooo000000Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooomEEEGoIVIV00;o
00000_ooool00ol0003oooooooooo`07ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP07ooooo`04o`000?ooooooooooo`00033ooooo00?oEEEEofIVI_l000003Oooool4
o`0000cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oooooo00Co
0000oooooooooooo0000;Oooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo00?oEEEEofIVI_l0
00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oooooo00Co0000oooooooooooo0000D_ooool0
033ooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooool000001?l00002ooooo`05o`000?ooooooooooooooool000001Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00
0005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01?l0003ooooooooo
ool0000Gooooo`Co000000Goooooo`000?ooooooooooo`00001Nooooo`Co000000Goooooo`000?oo
ooooooooo`00001<ooooo`Co000000Goooooo`000?ooooooooooo`00001Booooo`00<?ooool00ol0
003oooooooooo`1Fooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`03ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00
0005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01?l0003ooooooooo
ool0000Looooo`?o0000I?ooool3o`0005;ooooo0ol0001Cooooo`00<?ooool00ol0003ooooooooo
o`1Fooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`03ooooo`;o00000_ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Ko
oooo0_l0000Eooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool0D_ooool00ol0003o
ooooooooo`1Booooo`00<?ooool00ol0003oooooooooo`19ooooo`?o00002_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool5o`0000;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo0_l0000Fooooo`03
o`000?oooooooooo06Cooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`1Aooooo`00
<?ooool00ol0003oooooooooo`18ooooo`;o000000?oooooo`000?ooool02Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`;o
0000oooooolWooooo`00<?ooool00ol0003oooooooooo`18ooooo`05o`000?ooooooooooooooool0
00002Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`000005ooooo`04o`000?ooooooooooo`000>_ooooo00?oMgMgofIVI_ooool0;Oooool0
0omVIVKoMgMgooooo`07ooooo`00<?ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`000>[ooooo00?ogMgMoa0@4?o^k^h0;_ooool00oo^k^ko410@omgMg@07ooooo`00<?ooool00ol0
003oooooooooo`17ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Kooooo0ol0003?ooooo`;o00000_ooool2
o`0000cooooo00?oEEEEoiRHV?ooool00_l00002ooooo`07o`000?ooooooooooo`000?l@413ok^k^
oeEEE@02o`000003odA4A?nj^[[ooooo00;ooooo00GoV9RHo`000?l0003oA4A4okZj^P02ooooo`08
onk^k_mEEEGo0000o`000?m4A4Co^[Zjooooool@4105o`0000?ooooo00So410@oc8b<_l0003o0000
oa0@4?nYZJWoQhN7ofIVIPOooooo000`ooooo`03o`000?oooooooooo03Wooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00_ooool01Ol0003ooooooooooooooooo000000Cooooo0_l000000ooooooo0000ooooo`05oooo
o`;o0000aoooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@cooooo00Go0000oooooooooooooooo
o`000002ooooo`0;o`000?ooooooooooo`000?ooooooEEEEogMgMoooooook^k^ogMgMol@41000ooo
ool01Ol@413o^[Zjonk^k_mgMgOo410@00;ooooo00KoEEEEogMgMoooooook^k^ogMgMol@4103oooo
o`03o`000?oooooooooo00Cooooo00So0000ojVYZOoooooooooookZj^_l0003ok^k^o`0000Oooooo
003oo`000;Co00003oooool01?oMgMgo0000oa0@4?o<c<`=ooooo`05oc8b<_ooooooooooooooool0
00000_ooool01_l0003oooooooooool0003oooooo`0000Sooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00Oo^[ZjohN7QomVIVKoIVIVoa0@
4?oooooo000000Oooooo000:ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02?oo
ool4o`0000?ooooo00?o0000ooooooooool01Oooool2o`0000Kooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool00000
1Oooool00ol0003oooooooooo`04ooooo`07o`000?ooooooooooooooool0003oooooo`000006oooo
o`03o`000?oooooooooo00?ooooo00Oo0000ooooooooooooooooo`000?oooooo000000Gooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`06o`000?ooooooooooo`000?oooooo
00001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooool0
003oooooo`000004ooooo`04o`000?oooooo0000o`0000Gooooo1?l0000Booooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Gooooo`04onk^k_lQ8B7o
410@onk^kPgooooo00Go<S8booooooooooooooooo`000002ooooo`05o`000?ooooooooooo`000?oo
ool01_l00003ooooo`03o`000?oooooooooo00Cooooo1_l00003ooooo`03o`000?oooooooooo00Co
oooo00So<S8bob4Q8OmgMgOoMgMgohN7Qoo^k^koooooo`0000Oooooo000:ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`07ooooo`;o00000_ooool2
o`0000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`04ooooo`07o`000?oooooo
ooooooooool0003oooooo`000006ooooo`03o`000?oooooooooo00?ooooo00Oo0000oooooooooooo
ooooo`000?oooooo000000Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00;o00001Oooool01Ol0003ooooooooooooooooo000000Gooooo00Co0000
ooooool0003o00001Oooool3o`0000Wooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool05oooool01?lQ8B7oMgMgogMg
Molb<S8=ooooo`05o`000?o^k^koooooooooool000000_o<c<`02ol0003oZJVYomgMgOlQ8B7ooooo
oeEEEOn7QhOok^k^oooooon7QhOo<S8b00?ooooo00?o0000ooooooooool01?ooool01_mEEEGoQhN7
onk^k_ooooooQhN7oc8b<P?ooooo00?o0000oc8b<_oMgMd01?ooool02?l0003o^[Zjooooooo^k^ko
MgMgo`000?o^k^ko00001oooool0033ooooo00?o0000ooooooooool0@?ooool4o`0000[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Gooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
1Oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooool00000GOooool00ol0003o
ooooooooo`1Kooooo`03o`000?oooooooooo01Kooooo0_l00002ooooo`;o00003?ooool03_mEEEGo
MgMgooooool@413o0000ob4Q8Ol0003oMgMgoa0@4?l0003oZJVYooooooo^k^koEEEE0_l000001?m4
A4Cok^k^ooooool@4105o`0000?ooooo00Kok^k^oeEEEOl0003o0000odA4A?o^k^h2ooooo`;o0000
00CoZJVYob4Q8Ol0003o8B4Q0_ooool02?nYZJWo8B4Qo`000?l0003o<S8bo`000?mgMgOoEEEE1ooo
ool0033ooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000005ooooo`05o`000?ooooooooooooooool00000
1Oooool3o`000>Kooooo00?ogMgMoa0@4?o^k^h04_ooool00ol0003oooooooooo`0Iooooo`03onk^
k_l@413ogMgM00Oooooo000`ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool0i_ooool00omgMgOoIVIVooooo`0Aooooo`03
o`000?oooooooooo01Wooooo00?oIVIVogMgMoooool01oooool0033ooooo00?o0000ooooooooool0
Coooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006oooo
o`03o`000?oooooo00000?oooooo:oooool0033ooooo00?o0000ooooooooool0Coooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
00000?oooooo:oooool0033ooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo00000?oooooo:ooo
ool0033ooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`05o`000?oooooo
ooooooooool000001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooo00000?oooooo:oooool0033ooooo00?o
0000ooooooooool0D?ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0
003oooooo`00003oooooob_ooooo000`ooooo`03o`000?oooooooooo053ooooo00Co0000oooooooo
oooo00002Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00Go0000oooo
ooooooooooooo`000005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000000Kooooo0_l0003oooooobcooooo000`ooooo`?o0000DOooool0
0ol0003oooooo`000009ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
1Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool00000ooooooldooooo`00<?ooool00ol0003ooooooooo
o`1Aooooo`?o00002Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go
0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool01?l0003oooooooooool0003oooooocCooooo000`ooooo`03o`000?oooooooooo057ooooo
0_l0000:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooo
oooooooooooo000000Kooooo00Co0000oooooooooooo00001_ooool01?l0003oooooooooool0003o
ooooocCooooo000`ooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool0
0006ooooo`04o`000?ooooooooooo`000?oooooo=?ooool0033ooooo00?o0000ooooooooool0GOoo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooooooo
o`000006ooooo`04o`000?ooooooooooo`0000Kooooo00Co0000oooooooooooo0000ooooooldoooo
o`00<?ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo00001_ooool0
1?l0003oooooooooool0003oooooocCooooo000`ooooo`03o`000?oooooooooo05gooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_oo
ool01?l0003oooooooooool00006ooooo`03o`000?oooooo00000?oooooo=Oooool0033ooooo00?o
0000ooooooooool0G_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooo
ooooo`000006ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooool00000ooooooleoooo
o`00<?ooool00ol0003oooooooooo`1Nooooo`05o`000?ooooooooooooooool000002?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0
003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo00001_ooool00ol0003oooooo`00
003oooooocGooooo000`ooooo`03o`000?oooooooooo05kooooo00Go0000ooooooooooooooooo`00
0008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`04ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool00006ooooo`03
o`000?oooooo00000?oooooo=Oooool0033ooooo00?o0000ooooooooool0G_ooool01Ol0003ooooo
oooooooooooo000000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`05
o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Oooooo0_l0
003oooooocGooooo000`ooooo`03o`000?oooooooooo05kooooo00Go0000ooooooooooooooooo`00
0008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`00
0?ooooooooooooooool000001_ooool01?l0003oooooooooool00007ooooo`;o0000ooooooleoooo
o`00<?ooool3o`0005kooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_oo
ool01?l0003oooooooooool00007ooooo`;o0000ooooooleooooo`00<?ooool00ol0003ooooooooo
o`1Nooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooo
oooooooo00001oooool2o`000?oooooo=Oooool0033ooooo00?o0000ooooooooool0G_ooool01Ol0
003ooooooooooooooooo000000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`000?oo
oooo?_ooool0033ooooo00?o0000ooooooooool0G_ooool01Ol0003ooooooooooooooooo000000So
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`05o`000?oooooooooooooo
ool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooo
ooooooooooooo`000006ooooo`04o`000?ooooooooooo`000?oooooo?_ooool0033ooooo00?o0000
ooooooooool0G_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`04
o`000?ooooooooooo`000?oooooo?_ooool0033ooooo00?o0000ooooooooool0G_ooool01Ol0003o
oooooooooooooooo000000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05oooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`000?oooooo
?_ooool0033ooooo00?o0000ooooooooool0G_ooool01Ol0003ooooooooooooooooo000000Sooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool0
00001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooo
ooooooooo`000006ooooo`03o`000?oooooo00000?oooooo?oooool0033ooooo00?o0000oooooooo
ool0Goooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooo`00
003oooooocoooooo000`ooooo`03o`000?oooooooooo05oooooo00Co0000oooooooooooo00002?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooool00000ooooooloooooo`00<?ooool00ol0003ooooo
ooooo`1Oooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`05ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
00000?oooooo?oooool0033ooooo00?o0000ooooooooool0Goooool00ol0003oooooo`000009oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo
000000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooo`00003oooooocoooooo000`ooooo`03o`000?oooooo
oooo05oooooo00?o0000ooooool000002Oooool01Ol0003ooooooooooooooooo000000Sooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooool00000ooooooloooooo`00
<?ooool3o`0005oooooo00?o0000ooooool000002Oooool01Ol0003ooooooooooooooooo000000So
oooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooool00000oooooolo
ooooo`00<?ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooo000000Wooooo00Go0000oooo
ooooooooooooo`000008ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooo00000?oooooo?oooool0033ooooo00?o0000ooooooooool0Goooool00ol0003oooooo`00
0009ooooo`05o`000?ooooooooooooooool000002?ooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooooooo
ool000001_ooool00ol0003oooooo`00003oooooocoooooo000`ooooo`03o`000?oooooooooo05oo
oooo0ol00009ooooo`05o`000?ooooooooooooooool000002?ooool01Ol0003ooooooooooooooooo
000000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooo`00003oooooocoooooo000`ooooo`03o`000?oooooo
oooo063ooooo0_l00009ooooo`05o`000?ooooooooooooooool000002?ooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooo`00003oooooocoooooo000`ooooo`03o`00
0?oooooooooo063ooooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooooooo000000So
oooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooool00000oooooolo
ooooo`003oooool2onk^kP?ooooo0_o^k^hJooooo`03o`000?oooooooooo06_ooooo00Go0000oooo
ooooooooooooo`000008ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooo00000?oooooo?oooool000Sooooo1Ol00002ooooo`07onk^k_mEEEGok^k^ooooooo^k^ko
EEEEonk^kP03ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00?o
0000ooooooooool0Joooool01Ol0003ooooooooooooooooo000000Sooooo00Go0000oooooooooooo
ooooo`000006ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003o
oooooooooooooooo000000Kooooo00?o0000ooooool00000ooooooloooooo`002?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03o`000?oooooooooo06_ooooo00Go
0000ooooooooooooooooo`000008ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000007oooo
o`;o0000ooooooloooooo`002Oooool00onHV9So8B4Qonk^kP05ooooo`03omgMgOl0003ogMgM00Oo
oooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00_ooooo00?o0000oooo
ooooool0Joooool01Ol0003ooooooooooooooooo000000Sooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01?l0003ooooooooo
ool00008ooooo`;o0000ooooooloooooo`002_ooool00onHV9So8B4Qonk^kP03ooooo`05onk^k_mE
EEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
00002oooool00ol0003oooooooooo`1[ooooo`05o`000?ooooooooooooooool000002?ooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`04o`000?ooooooooooo`0000Sooooo0_l0003oooooocoooooo000;ooooo`0;ogMgMomVIVKo
ooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000002oooool4o`0006[ooooo00Go0000ooooooooooooooooo`00
0008ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00Co0000oooooooooooo00002?ooool2o`000?oooooo?oooool000cooooo
00?o0000ooooooooool00_o^k^h3ooooo`;ok^k^1Oooool00ol0003oooooooooo`02ooooo`05oa0@
4?ooooooooooooooool@41002oooool00ol0003oooooooooo`1[ooooo`05o`000?oooooooooooooo
ool000002?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool0oooo
oolnooooo`002?ooool01Ol0003o^[ZjoooooonHV9So410@00kooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?o0000ooooooooool0K?ooool01?l0003ooooo
ooooool00008ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo0000oooooom9ooooo`002?ooool01OnH
V9So410@o`000?lQ8B7oc<c<00cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00?ooooo0_l00006ooooo`03o`000?oooooooooo06cooooo00Co0000oooooooooooo0000
2?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`04o`000?ooooooooooo`000?ooooooBOooool002Oooooo00Co0000oooooooo
oooo00001Oooool00ol0003oooooooooo`1/ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000
ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003ooooo
ooooool0003oooooodWooooo000Wooooo`04o`000?ooooooooooo`0000Gooooo00?o0000oooooooo
ool0K?ooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool000001oooool0
1Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo0000oooooom9ooooo`009ooo
ool3o`0000Kooooo00?o0000ooooooooool0K?ooool01?l0003oooooooooool00008ooooo`05o`00
0?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000oooo
ool00000oooooom9ooooo`00:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo06co
oooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000
ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?ooooooBOooool002Wooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`1/ooooo`04o`000?ooooooooooo`0000Sooooo00Go
0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool00ol0003o
ooooo`00003oooooodWooooo000`ooooo`03o`000?oooooooooo06cooooo00Co0000oooooooooooo
00002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007
ooooo`03o`000?oooooo00000?ooooooBOooool0033ooooo00?o0000ooooooooool0K?ooool01?l0
003oooooooooool00008ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooo
oooooooo000000Oooooo00?o0000ooooool00000oooooom9ooooo`00<?ooool00ol0003ooooooooo
o`1/ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000007ooooo`05
o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003oooooodWooooo000`ooooo`?o
0000K?ooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool000001oooool0
1Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooool00000oooooom9ooooo`00<?ooool0
0ol0003oooooooooo`1/ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooooooooooo
o`000007ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003oooooodWo
oooo000`ooooo`03o`000?oooooooooo06cooooo00Co0000oooooooooooo00002?ooool01Ol0003o
oooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo
00000?ooooooBOooool0033ooooo00?o0000ooooooooool0K?ooool01?l0003oooooooooool00008
ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool00008ooooo`03o`00
0?oooooo00000?ooooooBOooool0033ooooo00?o0000ooooooooool0K?ooool01?l0003ooooooooo
ool00008ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool00008oooo
o`03o`000?oooooo00000?ooooooBOooool0033ooooo00?o0000ooooooooool0K?ooool01?l0003o
ooooooooool00008ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool0
0008ooooo`03o`000?oooooo00000?ooooooBOooool0033ooooo00?o0000ooooooooool0K?ooool0
1?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool000001oooool01?l0003ooooo
ooooool00008ooooo`03o`000?oooooo00000?ooooooBOooool0033ooooo00?o0000ooooooooool0
KOooool00ol0003oooooo`000008ooooo`05o`000?ooooooooooooooool000001oooool01?l0003o
ooooooooool00008ooooo`03o`000?oooooo00000?ooooooBOooool0033ooooo00?o0000oooooooo
ool0KOooool2o`0000Wooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?oooooooooo
o`0000Sooooo0_l0003ooooood[ooooo000`ooooo`03o`000?oooooooooo06gooooo0_l00009oooo
o`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool00008ooooo`;o0000oooo
oom:ooooo`00<?ooool00ol0003oooooooooo`1]ooooo`;o00002Oooool01Ol0003ooooooooooooo
oooo000000Oooooo00Co0000oooooooooooo00002?ooool2o`000?ooooooB_ooool0033ooooo00?o
0000ooooooooool0KOooool2o`0000Wooooo00Go0000ooooooooooooooooo`000007ooooo`04o`00
0?ooooooooooo`0000Sooooo0_l0003ooooood[ooooo000`ooooo`?o0000KOooool2o`0000Wooooo
00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Sooooo0_l0003ooooo
od[ooooo000`ooooo`03o`000?oooooooooo06gooooo0_l00009ooooo`05o`000?oooooooooooooo
ool000001oooool01?l0003oooooooooool00008ooooo`;o0000oooooom:ooooo`00<?ooool00ol0
003oooooooooo`1]ooooo`;o00002_ooool01?l0003oooooooooool00007ooooo`04o`000?oooooo
ooooo`0000Sooooo0_l0003ooooood[ooooo000`ooooo`03o`000?oooooooooo06gooooo0_l0000:
ooooo`03o`000?oooooo000000Sooooo00Co0000oooooooooooo00002?ooool2o`000?ooooooB_oo
ool0033ooooo00?o0000ooooooooool0KOooool2o`0000[ooooo00?o0000ooooool000002?ooool0
1?l0003oooooooooool00008ooooo`;o0000oooooom:ooooo`00<?ooool00ol0003oooooooooo`1]
ooooo`;o00002_ooool00ol0003oooooo`000008ooooo`04o`000?ooooooooooo`0000Wooooo00?o
0000ooooooooool0oooooom8ooooo`00<?ooool00ol0003oooooooooo`1iooooo`03o`000?oooooo
000000Sooooo00Co0000oooooooooooo0000oooooomDooooo`00<?ooool00ol0003oooooooooo`1i
ooooo`03o`000?oooooo000000Sooooo00Co0000oooooooooooo0000oooooomDooooo`00<?ooool0
0ol0003oooooooooo`1iooooo`03o`000?oooooo000000Sooooo00Co0000oooooooooooo0000oooo
oomDooooo`00<?ooool00ol0003oooooooooo`1iooooo`03o`000?oooooo000000Sooooo00Co0000
oooooooooooo0000oooooomDooooo`00<?ooool00ol0003oooooooooo`1iooooo`03o`000?oooooo
000000Sooooo00Co0000oooooooooooo0000oooooomDooooo`00<?ooool00ol0003oooooooooo`1i
ooooo`03o`000?oooooo000000Wooooo00?o0000ooooool00000oooooomDooooo`00<?ooool3o`00
07Wooooo00?o0000ooooool000002Oooool00ol0003oooooo`00003ooooooeCooooo000`ooooo`03
o`000?oooooooooo07Wooooo00?o0000ooooool000002Oooool00ol0003oooooo`00003ooooooeCo
oooo000`ooooo`03o`000?oooooooooo07Wooooo00?o0000ooooool000002Oooool00ol0003ooooo
o`00003ooooooeCooooo000`ooooo`03o`000?oooooooooo07Wooooo00?o0000ooooool000002Ooo
ool00ol0003oooooo`00003ooooooeCooooo000`ooooo`03o`000?oooooooooo07Wooooo00?o0000
ooooool000002Oooool00ol0003oooooo`00003ooooooeCooooo000`ooooo`03o`000?oooooooooo
07Wooooo00?o0000ooooool000002Oooool00ol0003oooooo`00003ooooooeCooooo000?ooooo`;o
k^k^0oooool2onk^kQ[ooooo00?o0000ooooooooool0NOooool00ol0003oooooo`000009ooooo`;o
0000oooooomEooooo`002_ooool2o`00000:oa0@4?ooooooooooonk^k_mEEEGok^k^ooooooo^k^ko
EEEEonk^kP?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool00ol0
003oooooooooo`1iooooo`03o`000?oooooo000000Wooooo0_l0003ooooooeGooooo000;ooooo`03
o`000?oooooooooo00;ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03o`000?oooooooooo07Wooooo00?o0000
ooooool000002Oooool2o`000?ooooooEOooool000Sooooo1Ol00004ooooo`03omgMgOl0003ogMgM
00Oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00_ooooo00?o0000
ooooooooool0NOooool00ol0003oooooo`000009ooooo`;o0000oooooomEooooo`002?ooool01?m4
A4CogMgMooooool00004ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`1iooooo`03o`00
0?oooooo000000Wooooo0_l0003ooooooeGooooo0008ooooo`04omgMgOmEEEGoooooo`0000?ooooo
00Ook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000ooooooooool00_ooool01Ol0
003ooooooooooooooooo000000_ooooo1?l0001hooooo`03o`000?oooooo000000Wooooo0_l0003o
oooooeGooooo0009ooooo`03ogMgMoo<c<co000000?ooooo0_o^k^h3ooooo`;ok^k^1Oooool00ol0
003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41002oooool00ol0003oooooooooo`1i
ooooo`03o`000?oooooo000000Wooooo0_l0003ooooooeGooooo0009ooooo`03onk^k_m4A4Co0000
00oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?o0000
ooooooooool0NOooool2o`0000[ooooo0_l0003ooooooeGooooo000:ooooo`03ogMgMol0003ooooo
00cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo0_l00006
ooooo`03o`000?oooooooooo07Wooooo0_l0000:ooooo`;o0000oooooomEooooo`009oooool01?l0
003oooooooooool00005ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool02?ooool2
o`000?ooooooEOooool002Oooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`1j
ooooo`03o`000?oooooooooo0?ooooooGoooool002Oooooo0ol00006ooooo`03o`000?oooooooooo
07[ooooo00?o0000ooooooooool0oooooomOooooo`00:?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0?oooooog?ooool002Wooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000
ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`?o
0000oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0
003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo
00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`
ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLoooo
o`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooo
g?ooool0033ooooo0ol0003oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0
033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomco
oooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooo
oooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooo
ooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000
ooooooooool0oooooooLooooo`00<?ooool3o`000?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00oooooooooooo
oa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003o
oooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo
4?ooool00:Cooooo0_l00003ooooo`03okZj^_lb<S;ooooo00Gooooo0_l00005ooooo`03o`000?nj
^[[ooooo0?ooooooE?ooool00:Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00?ooooo0_lb<S;ooooooeGooooo002Aooooo`?o00000_ooool01_lb
<S;o410@ooooooooooook^k^oeEEE@;o000000?oA4A4okZj^_ooool00oooool01_l0003ooooooooo
ooooooooV9RHoa0@40;o000000?oZJVYooooooooool00oooool00ol0003oooooooooo`03ooooo`03
ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P09ooooo`05onk^k_lb<S;o0000
oa0@4?o<c<`01Oooool2ob4Q8@?ooooo00Goc<c<onk^k_ooooook^k^olc<c004ooooo`Co000000So
410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kQ?ooooo00Ko410@oc8b<_l0003o0000oa0@4?nY
ZJT2ooooo`06onk^k_mEEEGo0000o`000?m4A4Co^[Zj0oooool01OmVIVKo0000o`000?m4A4Coc<c<
0>cooooo002Booooo`05o`000?ooooooooooolc<c?l@41000oooool01_mEEEGoMgMgooooooo^k^ko
MgMgoa0@40Cooooo00[o0000ooooooooooooooooo`000?nYZJWoEEEEoiRHV?mEEEGo^[Zj1?ooool0
0ol0003oooooooooo`03ooooo`03olc<c?l0003o410@00cooooo00Go410@okZj^_o^k^koMgMgoa0@
4002ooooo`Ko000000KooooooeEEEOmgMgOooooooiRHV?lQ8B45ooooo`;o8B4Q0oooool01Oo^k^ko
EEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg01?ooooo00Ko0000ojVYZOoooooooooookZj^_l00002ooooo`06oeEEEOmgMgOoooooonk^k_mg
MgOo410@0_ooool01_mVIVKoMgMgooooooooooooQhN7oa0@4>cooooo002Booooo`05o`000?oooooo
oooooeEEEOn7QhL00oooool00ol0003oooooooooo`07ooooo`0:o`000?oooooooooooooooolb<S;o
k^k^oiRHV?mEEEGogMgMoa0@40Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0;
ooooo`05o`000?ooooooooooooooool000002oooool00ooMgMgo0000omgMg@07ooooo`03o`000?oo
oooooooo00;ooooo00Go410@oooooooooooooooooa0@400Dooooo`05okZj^_n7QhOoIVIVofIVI_l@
41000_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0>oooooo002Booooo`05o`00
0?oooooogMgMo`000?o^k^h00oooool6o`0000Cooooo00_o0000oooooooooooooooookZj^_m4A4Co
c<c<ob4Q8Ooooooo410@olc<c003ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
1?ooool6o`000006ooooool0003oV9RHoooooonHV9So8B4Q2_ooool01Oo^k^koEEEEomgMgOmEEEGo
k^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000001?ooooo00Ko
<S8bob4Q8OmgMgOoMgMgohN7Qoo^k^h2ooooo`Ko00000_ooool00ol0003oooooooooo`3_ooooo`00
T_ooool3o`000003oa0@4?nHV9Sooooo00;ooooo00KoEEEEohN7Qoo^k^koooooohN7Qolb<S84oooo
o`0;o`000?ooooooooooooooooo^k^ko0000ooooool0003oooooofIVI_n7QhL00oooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo00_ooooo00Go0000oeEEEOl0003o410@olc<c00:oooo
o`05olc<c?o^k^koooooonk^k_o<c<`01_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000004oooool01_l0003o^[Zjooooooo^k^koMgMgo`0000;ooooo00KoEEEEohN7Qoo^
k^koooooohN7Qolb<S82ooooo`06ofIVI_mgMgOooooooooooon7QhOo0000k?ooool009;ooooo00Go
0000ooooooooooooc<c<o`000003ooooo`06onk^k_mEEEGo0000o`000?m4A4Cok^k^1?ooool02?l0
003oooooooooooooooooIVIVoiRHV?oooooo<S8b0_nj^[X01Ol0003ooooooooooooooooo000001;o
oooo00?o410@o`000?l000000ol0000:ooooo`03oeEEEOn7QhOooooo01Oooooo00?o0000oooooooo
ool00_ooool01Ol@413ooooooooooooooooo410@00Oooooo0ol00002ooooo`?o00001?ooool01_nY
ZJWo8B4Qo`000?l0003o<S8bo`0000;ooooo00Kok^k^oeEEEOl0003o0000odA4A?o^k^h2ooooo`06
onk^k_mVIVKo0000o`000?m4A4Co0000k?ooool009;ooooo00Go0000ooooooooooooc<c<o`00000=
ooooo`03o`000?oooooooooo00Cooooo00?oIVIVohN7Qoooool01?ooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo00_ooooo00?ogMgMoa0@4?nHV9P05oooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo0?oooooo1_ooool0097ooooo1?l000000ol@413oZJVYooooo`0<ooooo`;o00001Oooool0
0onYZJWoA4A4ooooo`03ooooo`;o00005?ooool00ol0003oooooooooo`0<ooooo`04olc<c?m4A4Co
0000oa0@41?ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo
1?l00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0ooooool6ooooo`00oooo
ool2ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0ooooool6ooooo`00ooooool2
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0ooooool6ooooo`00ooooool1oooo
o`;o00000oooool2o`000?oooooo2?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo
003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooo
oooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool0
0?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooooooo
ool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00
oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooo
oa3ooooo0000\
\>"],
  ImageRangeCache->{{{0, 525.688}, {324.5, 0}} -> {-2.58312*^-7, -6.34248*^6, \
6.65005*^-9, 53093.5}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0.309017 5.42214e-08 [
[.32684 .29652 -16.5 -12.5 ]
[.32684 .29652 16.5 0 ]
[.54329 .29652 -16.5 -12.5 ]
[.54329 .29652 16.5 0 ]
[.75974 .29652 -22.5 -12.5 ]
[.75974 .29652 22.5 0 ]
[.97619 .29652 -16.5 -12.5 ]
[.97619 .29652 16.5 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 64 6 ]
[.09789 .09213 -34.5 -6.25 ]
[.09789 .09213 0 6.25 ]
[.09789 .20057 -34.5 -6.25 ]
[.09789 .20057 0 6.25 ]
[.09789 .41746 -28.5 -6.25 ]
[.09789 .41746 0 6.25 ]
[.09789 .5259 -28.5 -6.25 ]
[.09789 .5259 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -62.8125 0 ]
[.5 .63053 62.8125 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 .30902 m
.32684 .31527 L
s
gsave
.32684 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 .30902 m
.54329 .31527 L
s
gsave
.54329 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 .30902 m
.75974 .31527 L
s
gsave
.75974 .29652 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 .30902 m
.15368 .31277 L
s
.19697 .30902 m
.19697 .31277 L
s
.24026 .30902 m
.24026 .31277 L
s
.28355 .30902 m
.28355 .31277 L
s
.37013 .30902 m
.37013 .31277 L
s
.41342 .30902 m
.41342 .31277 L
s
.45671 .30902 m
.45671 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.58658 .30902 m
.58658 .31277 L
s
.62987 .30902 m
.62987 .31277 L
s
.67316 .30902 m
.67316 .31277 L
s
.71645 .30902 m
.71645 .31277 L
s
.80303 .30902 m
.80303 .31277 L
s
.84632 .30902 m
.84632 .31277 L
s
.88961 .30902 m
.88961 .31277 L
s
.9329 .30902 m
.9329 .31277 L
s
.0671 .30902 m
.0671 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09213 m
.11664 .09213 L
s
gsave
.09789 .09213 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .20057 m
.11664 .20057 L
s
gsave
.09789 .20057 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .41746 m
.11664 .41746 L
s
gsave
.09789 .41746 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .5259 m
.11664 .5259 L
s
gsave
.09789 .5259 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.11039 .11924 m
.11414 .11924 L
s
.11039 .14635 m
.11414 .14635 L
s
.11039 .17346 m
.11414 .17346 L
s
.11039 .22768 m
.11414 .22768 L
s
.11039 .2548 m
.11414 .2548 L
s
.11039 .28191 m
.11414 .28191 L
s
.11039 .33613 m
.11414 .33613 L
s
.11039 .36324 m
.11414 .36324 L
s
.11039 .39035 m
.11414 .39035 L
s
.11039 .44457 m
.11414 .44457 L
s
.11039 .47168 m
.11414 .47168 L
s
.11039 .49879 m
.11414 .49879 L
s
.11039 .06502 m
.11414 .06502 L
s
.11039 .03791 m
.11414 .03791 L
s
.11039 .0108 m
.11414 .0108 L
s
.11039 .55301 m
.11414 .55301 L
s
.11039 .58012 m
.11414 .58012 L
s
.11039 .60723 m
.11414 .60723 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -123.812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.812 moveto
(@) show
81.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.812 moveto
(D) show
93.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6.2) show
135.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
141.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
153.000 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
157.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
166.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
184.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02532 .30902 L
.02691 .30902 L
.02852 .30902 L
.03029 .30902 L
.03186 .30902 L
.03354 .30902 L
.03514 .30902 L
.03687 .30902 L
.04008 .30902 L
.04167 .30902 L
.04336 .30902 L
.04639 .30902 L
.04963 .30902 L
.05274 .30902 L
.05605 .30902 L
.05924 .30902 L
.0623 .30902 L
.06401 .30902 L
.06556 .30902 L
.06634 .30902 L
.06675 .30902 L
.06718 .30902 L
.06756 .30902 L
.06776 .30902 L
.06797 .30902 L
.06817 .30902 L
.06835 .30902 L
.06844 .30902 L
.06853 .30902 L
.06862 .30902 L
.0687 .30902 L
.0688 .30902 L
.0689 .30902 L
.06898 .30902 L
.06908 .30902 L
.06918 .30902 L
.06928 .30902 L
.06948 .30902 L
.06967 .30902 L
.06986 .30902 L
.0702 .30902 L
.07062 .30902 L
.071 .30902 L
.07141 .30902 L
.07186 .30902 L
.07263 .30902 L
.07336 .30902 L
.07423 .30902 L
.07502 .30902 L
Mistroke
.07655 .30902 L
.07741 .30902 L
.07821 .30902 L
.07986 .30902 L
.08136 .30902 L
.0829 .30902 L
.08458 .30902 L
.08618 .30902 L
.08787 .30902 L
.09092 .30902 L
.09249 .30902 L
.09417 .30902 L
.0975 .30902 L
.1007 .30902 L
.10378 .30902 L
.10706 .30902 L
.10869 .30902 L
.11021 .30902 L
.11167 .30902 L
.1125 .30902 L
.11289 .30902 L
.11325 .30902 L
.11343 .30902 L
.11363 .30902 L
.11374 .30902 L
.11384 .30902 L
.11394 .30902 L
.11404 .30902 L
.11412 .30902 L
.11421 .30902 L
.1143 .30902 L
.11439 .30902 L
.11449 .30902 L
.11459 .30902 L
.11468 .30902 L
.11477 .30902 L
.11497 .30902 L
.11515 .30902 L
.11536 .30902 L
.11558 .30902 L
.11602 .30902 L
.11643 .30902 L
.11722 .30902 L
.11795 .30902 L
.11875 .30902 L
.11961 .30902 L
.12043 .30902 L
.12132 .30902 L
.12294 .30902 L
.12453 .30902 L
Mistroke
.12622 .30902 L
.12779 .30902 L
.12926 .30902 L
.13237 .30902 L
.13568 .30902 L
.13887 .30902 L
.14194 .30902 L
.14365 .30902 L
.1452 .30902 L
.14598 .30902 L
.14682 .30902 L
.14762 .30902 L
.148 .30902 L
.14835 .30902 L
.14872 .30902 L
.14882 .30902 L
.14893 .30902 L
.14903 .30902 L
.14913 .30902 L
.14922 .30902 L
.14931 .30902 L
.14941 .30902 L
.14951 .30902 L
.1496 .30902 L
.14969 .30902 L
.14977 .30902 L
.14986 .30902 L
.14997 .30902 L
.15008 .30902 L
.15027 .30902 L
.15049 .30902 L
.15072 .30902 L
.15113 .30902 L
.15152 .30902 L
.1523 .30902 L
.15302 .30902 L
.15382 .30902 L
.15468 .30902 L
.1555 .30902 L
.15638 .30902 L
.158 .30902 L
.15958 .30902 L
.16126 .30902 L
.16461 .30902 L
.16783 .30902 L
.17093 .30902 L
.17423 .30902 L
.17587 .30902 L
.17667 .30902 L
.1774 .30902 L
Mistroke
.17777 .30902 L
.17816 .30902 L
.17834 .30902 L
.17853 .30902 L
.1787 .30902 L
.17878 .30902 L
.17888 .30902 L
.17898 .30902 L
.17908 .30902 L
.17918 .30902 L
.17927 .30902 L
.17933 .30902 L
.17938 .30902 L
.17947 .30902 L
.17958 .30902 L
.17969 .30902 L
.17989 .30902 L
.18009 .30902 L
.18046 .30902 L
.18085 .30902 L
.18122 .30902 L
.18203 .30902 L
.18279 .30902 L
.1835 .30902 L
.18428 .30902 L
.1851 .30902 L
.18658 .30902 L
.18814 .30902 L
.18961 .30901 L
.19271 .309 L
.19601 .30899 L
.19919 .30897 L
.2008 .30896 L
.20225 .30896 L
.20301 .30895 L
.20382 .30895 L
.20427 .30895 L
.20447 .30895 L
.20469 .30895 L
.20489 .30895 L
.20499 .30895 L
.20509 .30895 L
.20519 .30895 L
.20529 .30895 L
.20539 .30895 L
.20545 .30895 L
.20551 .30895 L
.20561 .30895 L
.20566 .30895 L
.20572 .30895 L
Mistroke
.20582 .30895 L
.20591 .30895 L
.20613 .30895 L
.20636 .30895 L
.20657 .30895 L
.20677 .30895 L
.20716 .30895 L
.20787 .30895 L
.20828 .30896 L
.20865 .30896 L
.21015 .30897 L
.211 .30898 L
.2118 .30899 L
.21343 .30901 L
.21491 .30904 L
.2181 .30912 L
.22116 .30922 L
.22287 .30927 L
.22442 .30931 L
.22605 .30935 L
.22677 .30937 L
.22717 .30938 L
.22756 .30938 L
.22795 .30939 L
.2283 .30939 L
.2285 .30939 L
.22869 .30939 L
.22878 .30939 L
.22888 .30939 L
.22894 .30939 L
.22899 .30939 L
.2291 .30939 L
.2292 .30939 L
.22926 .30939 L
.22931 .30939 L
.22942 .30939 L
.22951 .30939 L
.22957 .30939 L
.22962 .30939 L
.22973 .30939 L
.22996 .30939 L
.23016 .30939 L
.23035 .30939 L
.23077 .30938 L
.23114 .30938 L
.23154 .30937 L
.23227 .30935 L
.23314 .30932 L
.23393 .30928 L
.23545 .30919 L
Mistroke
.23711 .30905 L
.24038 .30867 L
.24352 .30823 L
.24512 .308 L
.24686 .30778 L
.24767 .30769 L
.24853 .30761 L
.24927 .30755 L
.24969 .30753 L
.25007 .30751 L
.25027 .3075 L
.25048 .3075 L
.25058 .30749 L
.2507 .30749 L
.25081 .30749 L
.25091 .30749 L
.25101 .30749 L
.25111 .30749 L
.25121 .30749 L
.25127 .30749 L
.25132 .30749 L
.25142 .30749 L
.25151 .30749 L
.25161 .30749 L
.25171 .30749 L
.25189 .3075 L
.25208 .3075 L
.25242 .30752 L
.25279 .30754 L
.2532 .30757 L
.25401 .30766 L
.25476 .30776 L
.25562 .30792 L
.25644 .30811 L
.25803 .30858 L
.25951 .30912 L
.26265 .31057 L
.266 .31225 L
.26767 .31298 L
.26841 .31326 L
.26922 .3135 L
.26959 .3136 L
.27 .31369 L
.27035 .31375 L
.27072 .3138 L
.27095 .31382 L
.27104 .31383 L
.27115 .31384 L
.27125 .31385 L
.27135 .31385 L
Mistroke
.27141 .31385 L
.27146 .31385 L
.27156 .31385 L
.27165 .31385 L
.27174 .31385 L
.27184 .31385 L
.27195 .31385 L
.27205 .31384 L
.27214 .31384 L
.27232 .31382 L
.27251 .3138 L
.27269 .31378 L
.2731 .3137 L
.2735 .31361 L
.27393 .31348 L
.2747 .31317 L
.27541 .3128 L
.27694 .31172 L
.2786 .31012 L
.28188 .30594 L
.28503 .30141 L
.2866 .29938 L
.28805 .29789 L
.28881 .2973 L
.28919 .29707 L
.28961 .29686 L
.28982 .29678 L
.29002 .29671 L
.29022 .29666 L
.2904 .29663 L
.29051 .29661 L
.29057 .29661 L
.29062 .2966 L
.29072 .29659 L
.29082 .29659 L
.29088 .29659 L
.29094 .29659 L
.29104 .2966 L
.2911 .2966 L
.29116 .29661 L
.29128 .29663 L
.29138 .29665 L
.29149 .29667 L
.29169 .29673 L
.2919 .2968 L
.29213 .29691 L
.29254 .29715 L
.29293 .29744 L
.29365 .29816 L
.29442 .29918 L
Mistroke
.29613 .30233 L
.29774 .30638 L
.30082 .3162 L
.30238 .32158 L
.3041 .3272 L
.3049 .32953 L
.30574 .3317 L
.30653 .33336 L
.30725 .33457 L
.30761 .33503 L
.308 .33541 L
.30821 .33558 L
.30842 .33571 L
.30861 .33579 L
.30871 .33582 L
.30881 .33584 L
.3089 .33586 L
.30901 .33587 L
.30911 .33586 L
.30919 .33585 L
.3093 .33583 L
.30936 .33582 L
.30941 .3358 L
.30962 .33571 L
.30973 .33564 L
.30984 .33557 L
.31004 .33541 L
.31048 .33491 L
.31086 .33434 L
.31127 .33357 L
.3121 .3315 L
.31287 .32899 L
.31358 .32615 L
.31671 .30887 L
.32004 .28573 L
.3217 .27481 L
.32244 .27059 L
.32324 .26653 L
.32396 .26353 L
.32474 .26107 L
.32517 .2601 L
.32556 .25946 L
.32575 .25924 L
.32585 .25915 L
.32595 .25907 L
.32605 .25901 L
.32615 .25897 L
.32624 .25895 L
.32633 .25894 L
.32642 .25895 L
Mistroke
.32652 .25897 L
.32661 .25901 L
.3267 .25906 L
.3268 .25914 L
.32691 .25924 L
.32711 .25949 L
.32732 .25982 L
.32754 .26026 L
.32794 .26129 L
.32864 .26384 L
.32942 .26775 L
.33023 .273 L
.33097 .27883 L
.33265 .29513 L
.33583 .33371 L
.33889 .36953 L
.33969 .37698 L
.34046 .38279 L
.34088 .38542 L
.34134 .38776 L
.34176 .38939 L
.34196 .39 L
.34214 .39045 L
.34233 .39082 L
.34242 .39095 L
.34252 .39107 L
.34262 .39116 L
.34271 .39122 L
.34277 .39124 L
.34282 .39126 L
.34292 .39126 L
.34301 .39123 L
.3431 .39117 L
.34318 .39111 L
.34327 .39101 L
.34346 .3907 L
.34365 .3903 L
.34386 .38969 L
.34407 .38897 L
.34445 .38727 L
.34486 .3849 L
.3453 .38171 L
.34606 .37483 L
.34689 .36522 L
.34858 .33994 L
.35181 .27777 L
.3533 .24841 L
.35492 .22017 L
.3557 .20905 L
.35653 .19947 L
Mistroke
.35699 .19533 L
.35741 .19234 L
.35761 .19118 L
.35783 .19012 L
.35804 .18933 L
.35823 .18878 L
.35833 .18856 L
.35842 .18839 L
.35851 .18828 L
.3586 .1882 L
.3587 .18816 L
.35876 .18816 L
.35881 .18818 L
.35891 .18824 L
.35901 .18835 L
.3591 .18849 L
.35919 .18869 L
.35936 .18914 L
.35954 .18979 L
.35974 .19069 L
.36015 .19323 L
.36059 .1969 L
.36139 .20601 L
.36221 .21857 L
.3631 .2356 L
.36472 .27408 L
.368 .36734 L
.36963 .41091 L
.37043 .4292 L
.37116 .4435 L
.37191 .45533 L
.37226 .45969 L
.37263 .46352 L
.37283 .46528 L
.37302 .46664 L
.37321 .46779 L
.37338 .46864 L
.37348 .46902 L
.37358 .46936 L
.37369 .46963 L
.37375 .46975 L
.3738 .46983 L
.3739 .46993 L
.37399 .46996 L
.3741 .46992 L
.3742 .46981 L
.37429 .46965 L
.37439 .4694 L
.37457 .46879 L
.37478 .46776 L
Mistroke
.37498 .46653 L
.37538 .46315 L
.3758 .45834 L
.37651 .44753 L
.37728 .43189 L
.37885 .38903 L
.38054 .33108 L
.38213 .27047 L
.38387 .20696 L
.38468 .1805 L
.38554 .15617 L
.38634 .13761 L
.38708 .12484 L
.38747 .11985 L
.38784 .1163 L
.38804 .11486 L
.38823 .11386 L
.38833 .11342 L
.38843 .11312 L
.38849 .11298 L
.38854 .11287 L
.38865 .11275 L
.38874 .11273 L
.38883 .11278 L
.38892 .11291 L
.38902 .11314 L
.38913 .11348 L
.38923 .11391 L
.38942 .11494 L
.38959 .11621 L
.38975 .11763 L
.39012 .12174 L
.39049 .12719 L
.3909 .13445 L
.39162 .1511 L
.39328 .20413 L
.39658 .34843 L
.39824 .42111 L
.39904 .45242 L
.39977 .47726 L
.40048 .49753 L
.40125 .51437 L
.40168 .52117 L
.40186 .52357 L
.40207 .52579 L
.40225 .52737 L
.40244 .52869 L
.40255 .52924 L
.40264 .52964 L
.40274 .52994 L
Mistroke
.40284 .53012 L
.40293 .53021 L
.40302 .5302 L
.40312 .53009 L
.4032 .52991 L
.4033 .52961 L
.4034 .52918 L
.40361 .52794 L
.40382 .52624 L
.40404 .52391 L
.40443 .51839 L
.40483 .51114 L
.40521 .50278 L
.40591 .48335 L
.40752 .42298 L
.409 .35293 L
.41063 .26915 L
.41216 .19439 L
.41362 .13482 L
.41445 .10929 L
.4152 .09202 L
.41558 .08565 L
.41579 .08288 L
.41599 .08075 L
.41617 .07919 L
.41627 .07853 L
.41637 .07797 L
.41646 .07759 L
.41656 .07728 L
.41664 .0771 L
.41672 .07701 L
.41683 .07701 L
.41689 .07707 L
.41694 .07716 L
.41704 .07743 L
.41714 .07784 L
.41724 .07832 L
.41733 .07887 L
.41753 .08049 L
.41774 .08277 L
.41794 .08536 L
.41839 .09291 L
.41918 .11182 L
.41991 .13533 L
.42157 .20605 L
.42471 .37089 L
.42631 .4477 L
.42715 .48082 L
.42761 .49612 L
.42804 .50842 L
Mistroke
.42846 .51834 L
.42884 .52562 L
.42926 .53165 L
.42949 .53402 L
.4296 .53486 L
.42971 .53563 L
.4298 .53611 L
.4299 .53651 L
.43 .53681 L
.4301 .53697 L
.43019 .53701 L
.43028 .53694 L
.43036 .53679 L
.43045 .53653 L
.43056 .53609 L
.43065 .53556 L
.43087 .53397 L
.43107 .53197 L
.43125 .52962 L
.43162 .52373 L
.43203 .51533 L
.43286 .49259 L
.43434 .4352 L
.43757 .27072 L
.43906 .19839 L
.43985 .16582 L
.44068 .13712 L
.44115 .12439 L
.44156 .1149 L
.44198 .10742 L
.44238 .10234 L
.44258 .10054 L
.44268 .09976 L
.44278 .09916 L
.44288 .09872 L
.44296 .09841 L
.44305 .09817 L
.44316 .09803 L
.44321 .09801 L
.44326 .09803 L
.44336 .09815 L
.44342 .09827 L
.44347 .09842 L
.44359 .09888 L
.44369 .09943 L
.44378 .10004 L
.44399 .10181 L
.44419 .10399 L
.44437 .10638 L
.44478 .11315 L
Mistroke
.44551 .13005 L
.44637 .15669 L
.44717 .18761 L
.45026 .33281 L
.45183 .40332 L
.45266 .43477 L
.45355 .46204 L
.45398 .47259 L
.4544 .48072 L
.45477 .48639 L
.45499 .48893 L
.45518 .49077 L
.45528 .49152 L
.45538 .49221 L
.45547 .49271 L
.45556 .49315 L
.45567 .4935 L
.45573 .49364 L
.45578 .49373 L
.45587 .49382 L
.45597 .4938 L
.45607 .49368 L
.45617 .49342 L
.45627 .49307 L
.45636 .49265 L
.45653 .4916 L
.45671 .49013 L
.4571 .48566 L
.45746 .48011 L
.45828 .46276 L
.45899 .44247 L
.45974 .41693 L
.46281 .29028 L
.46452 .22411 L
.46532 .19875 L
.46607 .18 L
.46644 .17251 L
.46684 .16578 L
.46725 .16065 L
.46747 .15855 L
.46768 .15705 L
.46778 .15651 L
.46788 .15603 L
.46798 .15568 L
.46807 .15544 L
.46815 .15529 L
.46824 .15521 L
.46833 .1552 L
.46842 .15528 L
.46851 .15546 L
Mistroke
.46862 .15574 L
.4687 .15607 L
.4688 .15651 L
.46901 .15782 L
.46921 .15943 L
.46961 .16389 L
.47005 .17044 L
.47085 .18649 L
.47234 .22833 L
.47562 .34261 L
.47641 .3675 L
.47725 .39072 L
.47798 .40707 L
.47878 .42035 L
.4792 .4253 L
.47941 .42717 L
.47959 .42855 L
.47979 .42967 L
.47997 .43044 L
.48007 .43074 L
.48016 .43094 L
.48026 .43108 L
.48031 .43111 L
.48037 .43113 L
.48047 .43109 L
.48056 .43099 L
.48064 .43083 L
.48073 .43059 L
.48083 .43026 L
.48093 .42982 L
.48112 .42881 L
.48145 .42631 L
.48182 .42254 L
.48263 .41077 L
.48337 .39629 L
.48505 .3543 L
.4867 .30748 L
.48823 .26702 L
.48899 .25012 L
.48971 .2369 L
.49011 .23088 L
.49054 .22548 L
.49093 .22162 L
.49129 .21898 L
.49149 .21792 L
.49167 .21717 L
.49177 .21686 L
.49187 .21659 L
.49198 .21641 L
.49207 .2163 L
Mistroke
.49217 .21626 L
.49226 .21627 L
.49234 .21633 L
.49242 .21645 L
.49252 .21663 L
.49262 .21688 L
.4928 .2175 L
.493 .21843 L
.49321 .2197 L
.49359 .22267 L
.49404 .22732 L
.49446 .23251 L
.49599 .25846 L
.49766 .29366 L
.49922 .32676 L
.50005 .34233 L
.50094 .35643 L
.50138 .36213 L
.50179 .36673 L
.50219 .37039 L
.50257 .37305 L
.50292 .37488 L
.50312 .37563 L
.5033 .37612 L
.5034 .37633 L
.5035 .37648 L
.5036 .37658 L
.50365 .37661 L
.50371 .37663 L
.50381 .37662 L
.50391 .37656 L
.50401 .37646 L
.5041 .37632 L
.50419 .37612 L
.50428 .3759 L
.50448 .37525 L
.50468 .37443 L
.50489 .37334 L
.50563 .368 L
.50605 .36392 L
.5065 .35894 L
.50729 .34853 L
.51035 .30112 L
.51193 .28007 L
.51281 .27128 L
.51319 .2683 L
.51361 .26564 L
.514 .26376 L
.51421 .26298 L
.51441 .26241 L
Mistroke
.5145 .26219 L
.51459 .26201 L
.51468 .26187 L
.51476 .26176 L
.51486 .26167 L
.51495 .26162 L
.51505 .26159 L
.51515 .26161 L
.51525 .26166 L
.5153 .2617 L
.51536 .26176 L
.51547 .2619 L
.51556 .26206 L
.51578 .26254 L
.51601 .26324 L
.51643 .26498 L
.51682 .26708 L
.51761 .27276 L
.51835 .27935 L
.52002 .29717 L
.52165 .31515 L
.52244 .323 L
.52317 .32921 L
.52387 .33405 L
.52424 .33613 L
.52463 .33796 L
.52503 .33939 L
.52521 .33988 L
.5254 .34033 L
.52551 .34054 L
.52562 .34071 L
.52572 .34083 L
.52582 .34095 L
.52592 .34102 L
.52601 .34106 L
.5261 .34109 L
.52621 .34109 L
.5263 .34106 L
.52636 .34104 L
.52641 .341 L
.52652 .34092 L
.52663 .34079 L
.52683 .34049 L
.52702 .34012 L
.52745 .33894 L
.52791 .33724 L
.52868 .33343 L
.52952 .32816 L
.53123 .31556 L
.53278 .30406 L
Mistroke
.53355 .29905 L
.53439 .29451 L
.53477 .29279 L
.53518 .29124 L
.53555 .29009 L
.53591 .28922 L
.5361 .28886 L
.5363 .28854 L
.53649 .28832 L
.53657 .28825 L
.53666 .28818 L
.53672 .28814 L
.53677 .28812 L
.53687 .28808 L
.53696 .28806 L
.53706 .28805 L
.53716 .28807 L
.53726 .2881 L
.53736 .28815 L
.53748 .28823 L
.53766 .28841 L
.53787 .28867 L
.53824 .28932 L
.53861 .29017 L
.53894 .29112 L
.54044 .29694 L
.5421 .30507 L
.54378 .31314 L
.54452 .31613 L
.54532 .31881 L
.5457 .31982 L
.54611 .32071 L
.54649 .32138 L
.54684 .32182 L
.54704 .32201 L
.54723 .32215 L
.54733 .3222 L
.54744 .32224 L
.54749 .32226 L
.54755 .32227 L
.54766 .32228 L
.54776 .32228 L
.54781 .32228 L
.54787 .32227 L
.54796 .32225 L
.54806 .32221 L
.54816 .32217 L
.54826 .32211 L
.54843 .32198 L
.54881 .3216 L
Mistroke
.54922 .32101 L
.55005 .31936 L
.55153 .31526 L
.55323 .30984 L
.55478 .30537 L
.55555 .30361 L
.55596 .30284 L
.55639 .30216 L
.55676 .30168 L
.55696 .30147 L
.55718 .30128 L
.55738 .30114 L
.55756 .30103 L
.55764 .30099 L
.55774 .30096 L
.55782 .30093 L
.55791 .30091 L
.55796 .30089 L
.55801 .30089 L
.55811 .30088 L
.55817 .30087 L
.55823 .30087 L
.55828 .30088 L
.55833 .30088 L
.55843 .30089 L
.55849 .3009 L
.55854 .30092 L
.55874 .30098 L
.55891 .30106 L
.5591 .30117 L
.55949 .30147 L
.5599 .3019 L
.56035 .30247 L
.56117 .30374 L
.56274 .30672 L
.56447 .31004 L
.56527 .31135 L
.56612 .31248 L
.56653 .31292 L
.56692 .31326 L
.56727 .3135 L
.56765 .3137 L
.56784 .31377 L
.56794 .3138 L
.56804 .31382 L
.56813 .31384 L
.56823 .31386 L
.56832 .31387 L
.56841 .31387 L
.56846 .31387 L
Mistroke
.56852 .31387 L
.56862 .31387 L
.56872 .31386 L
.56881 .31385 L
.56891 .31384 L
.56902 .31381 L
.56924 .31375 L
.56946 .31367 L
.56966 .31357 L
.57012 .31331 L
.57093 .31265 L
.57413 .30904 L
.5756 .30755 L
.57643 .30692 L
.57684 .30668 L
.57721 .3065 L
.57758 .30636 L
.57777 .30631 L
.57798 .30626 L
.57818 .30623 L
.5783 .30622 L
.5784 .30621 L
.5785 .3062 L
.57856 .3062 L
.57861 .3062 L
.5787 .3062 L
.5788 .3062 L
.5789 .30621 L
.579 .30622 L
.57911 .30623 L
.57922 .30624 L
.5794 .30628 L
.5796 .30632 L
.58006 .30647 L
.58049 .30664 L
.58214 .30759 L
.58363 .30862 L
.58445 .30917 L
.58531 .30968 L
.58611 .31007 L
.5865 .31022 L
.58686 .31034 L
.5872 .31044 L
.58757 .31052 L
.58778 .31055 L
.58797 .31057 L
.58815 .31059 L
.58824 .3106 L
.58834 .3106 L
.58839 .31061 L
Mistroke
.58844 .31061 L
.58855 .31061 L
.58865 .31061 L
.58874 .31061 L
.5888 .31061 L
.58885 .3106 L
.58895 .3106 L
.58906 .31059 L
.58917 .31058 L
.58937 .31056 L
.58958 .31054 L
.58996 .31047 L
.59072 .31028 L
.59153 .31002 L
.59301 .30945 L
.5946 .30885 L
.59543 .30858 L
.59589 .30846 L
.59633 .30836 L
.59674 .30828 L
.59712 .30822 L
.59753 .30818 L
.59775 .30816 L
.59788 .30815 L
.59799 .30815 L
.59808 .30815 L
.59817 .30814 L
.59826 .30814 L
.59837 .30814 L
.59846 .30814 L
.59855 .30814 L
.59863 .30814 L
.59872 .30814 L
.59883 .30815 L
.59892 .30815 L
.59914 .30816 L
.59933 .30818 L
.59952 .30819 L
.6003 .30829 L
.60112 .30843 L
.60259 .30874 L
.6042 .30908 L
.60504 .30923 L
.60551 .3093 L
.60594 .30936 L
.60635 .30941 L
.60674 .30944 L
.60716 .30947 L
.60739 .30948 L
.6075 .30948 L
Mistroke
.60761 .30948 L
.6077 .30949 L
.6078 .30949 L
.6079 .30949 L
.608 .30949 L
.60809 .30949 L
.60818 .30949 L
.60826 .30949 L
.60835 .30949 L
.60846 .30949 L
.60855 .30948 L
.60877 .30948 L
.60897 .30947 L
.60916 .30946 L
.60994 .30941 L
.61076 .30933 L
.61225 .30916 L
.61384 .30898 L
.61453 .30891 L
.61529 .30885 L
.61571 .30882 L
.61609 .3088 L
.61646 .30879 L
.61667 .30878 L
.61686 .30878 L
.61705 .30877 L
.61716 .30877 L
.61727 .30877 L
.61736 .30877 L
.61745 .30877 L
.61755 .30877 L
.61765 .30877 L
.61771 .30877 L
.61777 .30877 L
.61783 .30877 L
.61789 .30877 L
.618 .30877 L
.61811 .30877 L
.61833 .30878 L
.61853 .30878 L
.61893 .30879 L
.61937 .30881 L
.62016 .30885 L
.62165 .30894 L
.62336 .30904 L
.62417 .30908 L
.62491 .30911 L
.62529 .30912 L
.62569 .30913 L
.62609 .30914 L
Mistroke
.62632 .30914 L
.62642 .30914 L
.62653 .30914 L
.62663 .30914 L
.62673 .30914 L
.62682 .30914 L
.62691 .30914 L
.627 .30915 L
.62708 .30914 L
.62717 .30914 L
.62727 .30914 L
.62736 .30914 L
.62747 .30914 L
.62768 .30914 L
.62787 .30914 L
.62805 .30914 L
.62846 .30913 L
.6289 .30912 L
.6297 .3091 L
.63119 .30905 L
.63275 .309 L
.63358 .30898 L
.63404 .30897 L
.63448 .30897 L
.63488 .30896 L
.6351 .30896 L
.63533 .30896 L
.63554 .30895 L
.63574 .30895 L
.63583 .30895 L
.63593 .30895 L
.63602 .30895 L
.63611 .30895 L
.6362 .30895 L
.63629 .30895 L
.63638 .30895 L
.63647 .30895 L
.63656 .30895 L
.63667 .30895 L
.63685 .30895 L
.63705 .30895 L
.63726 .30896 L
.63764 .30896 L
.63839 .30897 L
.63921 .30898 L
.64068 .309 L
.64226 .30903 L
.64269 .30903 L
.64315 .30904 L
.64358 .30904 L
Mistroke
.64398 .30904 L
.6444 .30905 L
.64461 .30905 L
.64472 .30905 L
.64484 .30905 L
.64495 .30905 L
.64504 .30905 L
.64514 .30905 L
.64523 .30905 L
.64534 .30905 L
.64543 .30905 L
.64548 .30905 L
.64554 .30905 L
.6456 .30905 L
.64565 .30905 L
.64574 .30905 L
.64584 .30905 L
.64603 .30905 L
.64621 .30905 L
.64638 .30905 L
.64676 .30905 L
.64717 .30904 L
.64888 .30903 L
.6505 .30902 L
.65128 .30901 L
.6521 .30901 L
.65281 .309 L
.65321 .309 L
.65359 .309 L
.65379 .309 L
.65398 .309 L
.6541 .309 L
.6542 .309 L
.65425 .309 L
.65431 .309 L
.65437 .309 L
.65442 .309 L
.65452 .309 L
.6546 .309 L
.6547 .309 L
.65481 .309 L
.65492 .309 L
.65502 .309 L
.65521 .309 L
.65558 .309 L
.65593 .309 L
.6567 .30901 L
.65833 .30901 L
.65986 .30902 L
.66057 .30902 L
Mistroke
.66132 .30902 L
.66171 .30902 L
.66192 .30902 L
.66214 .30902 L
.66234 .30902 L
.66253 .30902 L
.66271 .30902 L
.66289 .30902 L
.66298 .30902 L
.66308 .30902 L
.66318 .30902 L
.66326 .30902 L
.66336 .30902 L
.66342 .30902 L
.66347 .30902 L
.66357 .30902 L
.66367 .30902 L
.66377 .30902 L
.66387 .30902 L
.66406 .30902 L
.66429 .30902 L
.6645 .30902 L
.66522 .30902 L
.66598 .30902 L
.66758 .30902 L
.66903 .30902 L
.66984 .30901 L
.67021 .30901 L
.67061 .30901 L
.67081 .30901 L
.67103 .30901 L
.67123 .30901 L
.67141 .30901 L
.67163 .30901 L
.67175 .30901 L
.6718 .30901 L
.67186 .30901 L
.67197 .30901 L
.67207 .30901 L
.67213 .30901 L
.67218 .30901 L
.67229 .30901 L
.67238 .30901 L
.67248 .30901 L
.67266 .30901 L
.67288 .30901 L
.67307 .30901 L
.6735 .30901 L
.6739 .30901 L
.67538 .30902 L
Mistroke
.67684 .30902 L
.67768 .30902 L
.67846 .30902 L
.67883 .30902 L
.67922 .30902 L
.67943 .30902 L
.67965 .30902 L
.67985 .30902 L
.68005 .30902 L
.68015 .30902 L
.68027 .30902 L
.68036 .30902 L
.68047 .30902 L
.68053 .30902 L
.68058 .30902 L
.68064 .30902 L
.6807 .30902 L
.68076 .30902 L
.68082 .30902 L
.68092 .30902 L
.68102 .30902 L
.68112 .30902 L
.68122 .30902 L
.68131 .30902 L
.68153 .30902 L
.68173 .30902 L
.68211 .30902 L
.68252 .30902 L
.68335 .30902 L
.68483 .30902 L
.68571 .30902 L
.68653 .30902 L
.68727 .30902 L
.68769 .30902 L
.68808 .30902 L
.68826 .30902 L
.68845 .30902 L
.68862 .30902 L
.6888 .30902 L
.68891 .30902 L
.68901 .30902 L
.68911 .30902 L
.68917 .30902 L
.68922 .30902 L
.68931 .30902 L
.68941 .30902 L
.68951 .30902 L
.6896 .30902 L
.68969 .30902 L
.68979 .30902 L
Mistroke
.68997 .30902 L
.69019 .30902 L
.69038 .30902 L
.69081 .30902 L
.69121 .30902 L
.69428 .30902 L
.6951 .30902 L
.69587 .30902 L
.69625 .30902 L
.69667 .30902 L
.69689 .30902 L
.69713 .30902 L
.69733 .30902 L
.69745 .30902 L
.6975 .30902 L
.69755 .30902 L
.69766 .30902 L
.69771 .30902 L
.69777 .30902 L
.69786 .30902 L
.69796 .30902 L
.69802 .30902 L
.69808 .30902 L
.69819 .30902 L
.6983 .30902 L
.6984 .30902 L
.6986 .30902 L
.69878 .30902 L
.6992 .30902 L
.69996 .30902 L
.70069 .30902 L
.70216 .30902 L
.703 .30902 L
.70378 .30902 L
.70418 .30902 L
.70456 .30902 L
.70476 .30902 L
.70499 .30902 L
.70519 .30902 L
.70538 .30902 L
.70559 .30902 L
.7057 .30902 L
.70581 .30902 L
.70593 .30902 L
.70598 .30902 L
.70605 .30902 L
.7061 .30902 L
.70616 .30902 L
.70626 .30902 L
.70637 .30902 L
Mistroke
.70643 .30902 L
.70648 .30902 L
.70658 .30902 L
.70669 .30902 L
.70687 .30902 L
.70708 .30902 L
.7075 .30902 L
.70789 .30902 L
.70864 .30902 L
.71032 .30902 L
.71109 .30902 L
.71191 .30902 L
.71231 .30902 L
.71269 .30902 L
.71305 .30902 L
.71339 .30902 L
.71358 .30902 L
.71376 .30902 L
.71396 .30902 L
.71407 .30902 L
.71418 .30902 L
.71428 .30902 L
.71433 .30902 L
.71438 .30902 L
.71448 .30902 L
.71457 .30902 L
.71463 .30902 L
.71468 .30902 L
.71478 .30902 L
.71484 .30902 L
.71489 .30902 L
.715 .30902 L
.7152 .30902 L
.71538 .30902 L
.71572 .30902 L
.71649 .30902 L
.71796 .30902 L
.7188 .30902 L
.71958 .30902 L
.72035 .30902 L
.72075 .30902 L
.72118 .30902 L
.72142 .30902 L
.72164 .30902 L
.72184 .30902 L
.72195 .30902 L
.72207 .30902 L
.72217 .30902 L
.72227 .30902 L
.72236 .30902 L
Mistroke
.72246 .30902 L
.72256 .30902 L
.72266 .30902 L
.72276 .30902 L
.72282 .30902 L
.72287 .30902 L
.72297 .30902 L
.72306 .30902 L
.72316 .30902 L
.72326 .30902 L
.72348 .30902 L
.72367 .30902 L
.72441 .30902 L
.72527 .30902 L
.72608 .30902 L
.72691 .30902 L
.72769 .30902 L
.72845 .30902 L
.72915 .30902 L
.72952 .30902 L
.72991 .30902 L
.73011 .30902 L
.7303 .30902 L
.73041 .30902 L
.73051 .30902 L
.73057 .30902 L
.73063 .30902 L
.73068 .30902 L
.73073 .30902 L
.73083 .30902 L
.73093 .30902 L
.73103 .30902 L
.73112 .30902 L
.73122 .30902 L
.73133 .30902 L
.73155 .30902 L
.73177 .30902 L
.732 .30902 L
.73242 .30902 L
.73402 .30902 L
.73486 .30902 L
.73575 .30902 L
.73655 .30902 L
.737 .30902 L
.73742 .30902 L
.73762 .30902 L
.73781 .30902 L
.73799 .30902 L
.73817 .30902 L
.73826 .30902 L
Mistroke
.73837 .30902 L
.73846 .30902 L
.73855 .30902 L
.73865 .30902 L
.73871 .30902 L
.73876 .30902 L
.73886 .30902 L
.73897 .30902 L
.73907 .30902 L
.73917 .30902 L
.73928 .30902 L
.73939 .30902 L
.73958 .30902 L
.73979 .30902 L
.74017 .30902 L
.74054 .30902 L
.74222 .30902 L
.74371 .30902 L
.74411 .30902 L
.74455 .30902 L
.74492 .30902 L
.74533 .30902 L
.74557 .30902 L
.74579 .30902 L
.746 .30902 L
.74611 .30902 L
.74622 .30902 L
.74633 .30902 L
.74642 .30902 L
.74652 .30902 L
.74661 .30902 L
.74671 .30902 L
.74681 .30902 L
.74686 .30902 L
.74691 .30902 L
.74697 .30902 L
.74703 .30902 L
.74712 .30902 L
.74723 .30902 L
.74743 .30902 L
.74763 .30902 L
.7478 .30902 L
.74864 .30902 L
.75015 .30902 L
.75178 .30902 L
.75221 .30902 L
.75267 .30902 L
.75309 .30902 L
.7533 .30902 L
.75349 .30902 L
Mistroke
.75367 .30902 L
.75386 .30902 L
.75397 .30902 L
.75407 .30902 L
.75416 .30902 L
.75426 .30902 L
.75432 .30902 L
.75437 .30902 L
.75448 .30902 L
.75457 .30902 L
.75467 .30902 L
.75472 .30902 L
.75478 .30902 L
.75488 .30902 L
.75494 .30902 L
.755 .30902 L
.75511 .30902 L
.7553 .30902 L
.75548 .30902 L
.75589 .30902 L
.75671 .30902 L
.75819 .30902 L
.75968 .30902 L
.76008 .30902 L
.76052 .30902 L
.76089 .30902 L
.7613 .30902 L
.76154 .30902 L
.76176 .30902 L
.76197 .30902 L
.76207 .30902 L
.76213 .30902 L
.76219 .30902 L
.76229 .30902 L
.76239 .30902 L
.76249 .30902 L
.76255 .30902 L
.76261 .30902 L
.7627 .30902 L
.7628 .30902 L
.7629 .30902 L
.763 .30902 L
.7634 .30902 L
.76377 .30902 L
.76461 .30902 L
.76625 .30902 L
.76706 .30902 L
.76779 .30902 L
.76815 .30902 L
.76855 .30902 L
Mistroke
.76892 .30902 L
.76927 .30902 L
.76945 .30902 L
.76963 .30902 L
.76973 .30902 L
.76982 .30902 L
.76987 .30902 L
.76993 .30902 L
.77003 .30902 L
.77009 .30902 L
.77014 .30902 L
.77024 .30902 L
.77034 .30902 L
.7704 .30902 L
.77045 .30902 L
.77064 .30902 L
.77074 .30902 L
.77084 .30902 L
.77127 .30902 L
.77167 .30902 L
.77241 .30902 L
.77409 .30902 L
.77487 .30902 L
.77529 .30902 L
.77569 .30902 L
.77606 .30902 L
.7764 .30902 L
.77677 .30902 L
.77697 .30902 L
.77717 .30902 L
.77727 .30902 L
.77738 .30902 L
.77748 .30902 L
.77757 .30902 L
.77766 .30902 L
.77775 .30902 L
.77785 .30902 L
.77794 .30902 L
.77804 .30902 L
.77815 .30902 L
.77833 .30902 L
.77854 .30902 L
.77876 .30902 L
.77952 .30902 L
.78023 .30902 L
.78186 .30902 L
.78265 .30902 L
.783 .30902 L
.78338 .30902 L
.78372 .30902 L
Mistroke
.78409 .30902 L
.78429 .30902 L
.78448 .30902 L
.78466 .30902 L
.78484 .30902 L
.78493 .30902 L
.78503 .30902 L
.78513 .30902 L
.78523 .30902 L
.78532 .30902 L
.7854 .30902 L
.7855 .30902 L
.78559 .30902 L
.78569 .30902 L
.78579 .30902 L
.78598 .30902 L
.7862 .30902 L
.78641 .30902 L
.78721 .30902 L
.78795 .30902 L
.78962 .30902 L
.79035 .30902 L
.79075 .30902 L
.79113 .30902 L
.79135 .30902 L
.79158 .30902 L
.79178 .30902 L
.79199 .30902 L
.79219 .30902 L
.7923 .30902 L
.79241 .30902 L
.79251 .30902 L
.79261 .30902 L
.7927 .30902 L
.79279 .30902 L
.79289 .30902 L
.79295 .30902 L
.793 .30902 L
.79309 .30902 L
.79319 .30902 L
.79337 .30902 L
.79356 .30902 L
.79398 .30902 L
.79438 .30902 L
.79585 .30902 L
.79734 .30902 L
.79775 .30902 L
.79819 .30902 L
.79856 .30902 L
.79897 .30902 L
Mistroke
.79921 .30902 L
.79943 .30902 L
.79964 .30902 L
.79974 .30902 L
.79986 .30902 L
.79997 .30902 L
.80006 .30902 L
.80011 .30902 L
.80017 .30902 L
.80028 .30902 L
.80038 .30902 L
.80048 .30902 L
.80057 .30902 L
.80067 .30902 L
.80088 .30902 L
.80107 .30902 L
.8015 .30902 L
.80228 .30902 L
.80393 .30902 L
.80474 .30902 L
.80547 .30902 L
.80583 .30902 L
.80623 .30902 L
.80641 .30902 L
.8066 .30902 L
.80678 .30902 L
.80695 .30902 L
.80714 .30902 L
.80724 .30902 L
.80734 .30902 L
.80743 .30902 L
.80751 .30902 L
.8076 .30902 L
.8077 .30902 L
.8078 .30902 L
.8079 .30902 L
.808 .30902 L
.80809 .30902 L
.80831 .30902 L
.80853 .30902 L
.80893 .30902 L
.80929 .30902 L
.81011 .30902 L
.81159 .30902 L
.81233 .30902 L
.81312 .30902 L
.81354 .30902 L
.81376 .30902 L
.81399 .30902 L
.81421 .30902 L
Mistroke
.8144 .30902 L
.8145 .30902 L
.8146 .30902 L
.8147 .30902 L
.81479 .30902 L
.8149 .30902 L
.81495 .30902 L
.815 .30902 L
.81511 .30902 L
.8152 .30902 L
.81526 .30902 L
.81531 .30902 L
.81541 .30902 L
.81564 .30902 L
.81584 .30902 L
.81602 .30902 L
.81644 .30902 L
.81793 .30902 L
.81872 .30902 L
.81956 .30902 L
.81995 .30902 L
.82036 .30902 L
.82074 .30902 L
.82109 .30902 L
.82127 .30902 L
.82145 .30902 L
.82164 .30902 L
.82174 .30902 L
.82184 .30902 L
.82192 .30902 L
.822 .30902 L
.82209 .30902 L
.82218 .30902 L
.82227 .30902 L
.82237 .30902 L
.82245 .30902 L
.82254 .30902 L
.82264 .30902 L
.82275 .30902 L
.82293 .30902 L
.82336 .30902 L
.82412 .30902 L
.8256 .30902 L
.82644 .30902 L
.82685 .30902 L
.82722 .30902 L
.82759 .30902 L
.828 .30902 L
.82822 .30902 L
.82842 .30902 L
Mistroke
.82862 .30902 L
.82873 .30902 L
.82883 .30902 L
.82892 .30902 L
.82903 .30902 L
.82908 .30902 L
.82914 .30902 L
.82924 .30902 L
.82934 .30902 L
.82943 .30902 L
.82953 .30902 L
.82963 .30902 L
.82974 .30902 L
.82985 .30902 L
.83006 .30902 L
.83028 .30902 L
.83052 .30902 L
.83134 .30902 L
.83208 .30902 L
.83295 .30902 L
.83376 .30902 L
.8345 .30902 L
.83488 .30902 L
.83509 .30902 L
.83529 .30902 L
.83549 .30902 L
.83571 .30902 L
.83592 .30902 L
.83604 .30902 L
.83609 .30902 L
.83615 .30902 L
.83626 .30902 L
.83636 .30902 L
.83645 .30902 L
.83654 .30902 L
.83664 .30902 L
.83674 .30902 L
.8368 .30902 L
.83685 .30902 L
.83696 .30902 L
.83716 .30902 L
.83738 .30902 L
.83777 .30902 L
.83866 .30902 L
.84027 .30902 L
.8411 .30902 L
.84153 .30902 L
.84199 .30902 L
.84239 .30902 L
.84262 .30902 L
Mistroke
.84284 .30902 L
.84294 .30902 L
.84303 .30902 L
.84312 .30902 L
.84321 .30902 L
.84331 .30902 L
.8434 .30902 L
.8435 .30902 L
.84356 .30902 L
.84361 .30902 L
.84371 .30902 L
.84381 .30902 L
.8439 .30902 L
.84399 .30902 L
.8442 .30902 L
.8444 .30902 L
.8448 .30902 L
.84523 .30902 L
.84672 .30902 L
.84755 .30902 L
.84832 .30902 L
.84874 .30902 L
.84912 .30902 L
.84955 .30902 L
.84979 .30902 L
.84989 .30902 L
.85001 .30902 L
.85011 .30902 L
.8502 .30902 L
.85028 .30902 L
.85038 .30902 L
.85048 .30902 L
.85057 .30902 L
.85067 .30902 L
.85073 .30902 L
.85078 .30902 L
.85089 .30902 L
.85098 .30902 L
.8512 .30902 L
.8514 .30902 L
.8516 .30902 L
.85231 .30902 L
.85308 .30902 L
.85395 .30902 L
.85477 .30902 L
.85551 .30902 L
.85593 .30902 L
.85632 .30902 L
.85651 .30902 L
.85672 .30902 L
Mistroke
.85682 .30902 L
.85692 .30902 L
.85701 .30902 L
.85711 .30902 L
.8572 .30902 L
.85728 .30902 L
.85737 .30902 L
.85745 .30902 L
.85754 .30902 L
.85763 .30902 L
.85772 .30902 L
.85782 .30902 L
.85792 .30902 L
.85801 .30902 L
.85822 .30902 L
.85859 .30902 L
.859 .30902 L
.85943 .30902 L
.86103 .30902 L
.86173 .30902 L
.86249 .30902 L
.86291 .30902 L
.86309 .30902 L
.8633 .30902 L
.86348 .30902 L
.86367 .30902 L
.86378 .30902 L
.86387 .30902 L
.86397 .30902 L
.86406 .30902 L
.86417 .30902 L
.86422 .30902 L
.86428 .30902 L
.86437 .30902 L
.86448 .30902 L
.86453 .30902 L
.86459 .30902 L
.86465 .30902 L
.86471 .30902 L
.86481 .30902 L
.86493 .30902 L
.86515 .30902 L
.86535 .30902 L
.86574 .30902 L
.86721 .30902 L
.86804 .30902 L
.86883 .30902 L
.86922 .30902 L
.86959 .30902 L
.8698 .30902 L
Mistroke
.87002 .30902 L
.87023 .30902 L
.87042 .30902 L
.87052 .30902 L
.87064 .30902 L
.87073 .30902 L
.87084 .30902 L
.87095 .30902 L
.87102 .30902 L
.87108 .30902 L
.87118 .30902 L
.87124 .30902 L
.87129 .30902 L
.8714 .30902 L
.87149 .30902 L
.8716 .30902 L
.87171 .30902 L
.8719 .30902 L
.8721 .30902 L
.8725 .30902 L
.87291 .30902 L
.87366 .30902 L
.87447 .30902 L
.87533 .30902 L
.87576 .30902 L
.87616 .30902 L
.87655 .30902 L
.87691 .30902 L
.87726 .30902 L
.87743 .30902 L
.87753 .30902 L
.87762 .30902 L
.87772 .30902 L
.87781 .30902 L
.87791 .30902 L
.87796 .30902 L
.87802 .30902 L
.87811 .30902 L
.8782 .30902 L
.87829 .30902 L
.87839 .30902 L
.87858 .30902 L
.87876 .30902 L
.87917 .30902 L
.88 .30902 L
.88148 .30902 L
.88232 .30902 L
.88274 .30902 L
.88312 .30902 L
.88347 .30902 L
Mistroke
.88383 .30902 L
.88402 .30902 L
.8842 .30902 L
.8843 .30902 L
.8844 .30902 L
.8845 .30902 L
.88455 .30902 L
.88461 .30902 L
.88466 .30902 L
.88471 .30902 L
.88481 .30902 L
.88492 .30902 L
.88498 .30902 L
.88503 .30902 L
.88513 .30902 L
.88523 .30902 L
.88543 .30902 L
.88562 .30902 L
.88582 .30902 L
.88618 .30902 L
.88787 .30902 L
.88868 .30902 L
.88945 .30902 L
.88988 .30902 L
.8901 .30902 L
.89034 .30902 L
.89053 .30902 L
.89075 .30902 L
.89085 .30902 L
.89095 .30902 L
.89105 .30902 L
.89114 .30902 L
.89123 .30902 L
.89129 .30902 L
.89134 .30902 L
.8914 .30902 L
.89146 .30902 L
.89156 .30902 L
.89166 .30902 L
.89175 .30902 L
.89185 .30902 L
.89196 .30902 L
.8922 .30902 L
.89242 .30902 L
.89285 .30902 L
.89446 .30902 L
.89525 .30902 L
.89567 .30902 L
.89607 .30902 L
.89644 .30902 L
Mistroke
.89678 .30902 L
.89715 .30902 L
.89736 .30902 L
.89745 .30902 L
.89756 .30902 L
.89766 .30902 L
.89775 .30902 L
.89783 .30902 L
.89792 .30902 L
.89803 .30902 L
.89812 .30902 L
.89822 .30902 L
.89828 .30902 L
.89833 .30902 L
.89844 .30902 L
.89853 .30902 L
.89875 .30902 L
.89895 .30902 L
.89915 .30902 L
.89986 .30902 L
.90063 .30902 L
.9015 .30902 L
.90232 .30902 L
.90268 .30902 L
.90306 .30902 L
.90328 .30902 L
.90348 .30902 L
.90367 .30902 L
.90387 .30902 L
.90407 .30902 L
.90417 .30902 L
.90427 .30902 L
.90437 .30902 L
.90446 .30902 L
.90456 .30902 L
.90464 .30902 L
.90474 .30902 L
.90479 .30902 L
.90485 .30902 L
.90495 .30902 L
.90504 .30902 L
.90515 .30902 L
.90525 .30902 L
.90548 .30902 L
.90583 .30902 L
.90621 .30902 L
.90699 .30902 L
.90787 .30902 L
.9087 .30902 L
.90944 .30902 L
Mistroke
.90986 .30902 L
.91005 .30902 L
.91025 .30902 L
.91044 .30902 L
.91062 .30902 L
.91071 .30902 L
.9108 .30902 L
.91089 .30902 L
.91097 .30902 L
.91107 .30902 L
.91117 .30902 L
.91128 .30902 L
.91133 .30902 L
.91139 .30902 L
.91148 .30902 L
.91157 .30902 L
.91168 .30902 L
.91177 .30902 L
.91198 .30902 L
.91218 .30902 L
.91255 .30902 L
.91338 .30902 L
.91485 .30902 L
.91525 .30902 L
.91569 .30902 L
.91606 .30902 L
.91647 .30902 L
.91669 .30902 L
.9169 .30902 L
.91709 .30902 L
.91719 .30902 L
.9173 .30902 L
.91741 .30902 L
.91751 .30902 L
.9176 .30902 L
.9177 .30902 L
.91779 .30902 L
.91787 .30902 L
.91796 .30902 L
.91806 .30902 L
.91812 .30902 L
.91817 .30902 L
.91828 .30902 L
.91852 .30902 L
.91895 .30902 L
.91975 .30902 L
.92052 .30902 L
.92133 .30902 L
.92208 .30902 L
.92245 .30902 L
Mistroke
.92278 .30902 L
.92314 .30902 L
.92334 .30902 L
.92352 .30902 L
.92362 .30902 L
.92373 .30902 L
.92382 .30902 L
.92391 .30902 L
.92402 .30902 L
.92411 .30902 L
.92417 .30902 L
.92423 .30902 L
.92434 .30902 L
.92444 .30902 L
.92454 .30902 L
.92465 .30902 L
.92475 .30902 L
.92494 .30902 L
.92514 .30902 L
.92559 .30902 L
.92601 .30902 L
.92765 .30902 L
.92846 .30902 L
.92883 .30902 L
.92919 .30902 L
.92955 .30902 L
.92974 .30902 L
.92994 .30902 L
.93012 .30902 L
.93028 .30902 L
.93038 .30902 L
.93047 .30902 L
.93057 .30902 L
.93066 .30902 L
.93076 .30902 L
.93085 .30902 L
.93095 .30902 L
.93105 .30902 L
.93123 .30902 L
.93141 .30902 L
.93184 .30902 L
.93224 .30902 L
.93388 .30902 L
.93468 .30902 L
.93541 .30902 L
.93577 .30902 L
.93596 .30902 L
.93616 .30902 L
.93634 .30902 L
.93643 .30902 L
Mistroke
.93653 .30902 L
.93663 .30902 L
.93671 .30902 L
.93679 .30902 L
.93688 .30902 L
.93698 .30902 L
.93707 .30902 L
.93717 .30902 L
.93727 .30902 L
.93736 .30902 L
.93744 .30902 L
.93763 .30902 L
.93782 .30902 L
.93803 .30902 L
.93845 .30902 L
.94014 .30902 L
.94095 .30902 L
.94169 .30902 L
.94206 .30902 L
.94225 .30902 L
.94245 .30902 L
.94268 .30902 L
.94278 .30902 L
.94289 .30902 L
.94299 .30902 L
.94304 .30902 L
.9431 .30902 L
.9432 .30902 L
.94329 .30902 L
.94339 .30902 L
.94348 .30902 L
.94359 .30902 L
.94364 .30902 L
.9437 .30902 L
.94389 .30902 L
.94408 .30902 L
.94443 .30902 L
.94481 .30902 L
.94638 .30902 L
.94722 .30902 L
.94768 .30902 L
.94811 .30902 L
.94853 .30902 L
.94876 .30902 L
.94898 .30902 L
.94916 .30902 L
.94926 .30902 L
.94936 .30902 L
.94946 .30902 L
.94955 .30902 L
Mistroke
.9496 .30902 L
.94966 .30902 L
.94976 .30902 L
.94985 .30902 L
.94994 .30902 L
.95004 .30902 L
.95015 .30902 L
.95036 .30902 L
.95056 .30902 L
.95129 .30902 L
.95294 .30902 L
.95374 .30902 L
.95412 .30902 L
.95447 .30902 L
.95483 .30902 L
.95503 .30902 L
.95523 .30902 L
.95541 .30902 L
.95549 .30902 L
.95557 .30902 L
.95567 .30902 L
.95575 .30902 L
.95584 .30902 L
.95595 .30902 L
.956 .30902 L
.95605 .30902 L
.95615 .30902 L
.95625 .30902 L
.95634 .30902 L
.95655 .30902 L
.95677 .30902 L
.95713 .30902 L
.95753 .30902 L
.95922 .30902 L
.95961 .30902 L
.96003 .30902 L
.96041 .30902 L
.96077 .30902 L
.96114 .30902 L
.96133 .30902 L
.96154 .30902 L
.96164 .30902 L
.96175 .30902 L
.96181 .30902 L
.96187 .30902 L
.96192 .30902 L
.96197 .30902 L
.96203 .30902 L
.96208 .30902 L
.96218 .30902 L
Mistroke
.96228 .30902 L
.96237 .30902 L
.96247 .30902 L
.96255 .30902 L
.96275 .30902 L
.96293 .30902 L
.9631 .30902 L
.96389 .30902 L
.96472 .30902 L
.96551 .30902 L
.96627 .30902 L
.9666 .30902 L
.96696 .30902 L
.96733 .30902 L
.96754 .30902 L
.96772 .30902 L
.96783 .30902 L
.96793 .30902 L
.96802 .30902 L
.96812 .30902 L
.96817 .30902 L
.96823 .30902 L
.96829 .30902 L
.96834 .30902 L
.96844 .30902 L
.96855 .30902 L
.9686 .30902 L
.96865 .30902 L
.96875 .30902 L
.96898 .30902 L
.96921 .30902 L
.96943 .30902 L
.97023 .30902 L
.97104 .30902 L
.9719 .30902 L
.97264 .30902 L
.97306 .30902 L
.97324 .30902 L
.97344 .30902 L
.97363 .30902 L
.9738 .30902 L
.97396 .30902 L
.97405 .30902 L
.97414 .30902 L
.97422 .30902 L
.97429 .30902 L
.97438 .30902 L
.97446 .30902 L
.97454 .30902 L
.97461 .30902 L
Mistroke
.97469 .30902 L
.97477 .30902 L
.97486 .30902 L
.97495 .30902 L
.97515 .30902 L
.97551 .30902 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{421.375, 260.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008>0001AB000`400?l00000o`00003ooooooooo
oooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo
003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooo
oooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool0
0?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooooooo
ool@ooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooo
ooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo0ol0003o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0
003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo
00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`
ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLoooo
o`00<?ooool3o`000?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?oo
ool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0
033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomco
oooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooo
oooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool3o`000?oooooo
g?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo0?oooooo
Eoooool0033ooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`3ooooooeOooooo000@
ooooo`;ok^k^0oooool2onk^kQWooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`3o
oooooeOooooo000;ooooo`;o000000[o410@ooooooooooook^k^oeEEEOo^k^koooooonk^k_mEEEGo
k^k^0oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h:ooooo`03o`000?oo
oooooooo08;ooooo0_l0003ooooooeSooooo000<ooooo`03o`000?oooooooooo00;ooooo00Gok^k^
oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0:ooooo`03o`000?oooooooooo08;ooooo0_l0003ooooooeSooooo00000ooooooo0000o`00
0004o`0000;ooooo1Ol00004ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@00[ooooo00?o0000ooooooooool0P_ooool2o`000?oooooo
F?ooool000Wooooo00CoA4A4omgMgOoooooo00001?ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Ko
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000[ooooo00?o0000oooo
ooooool0POooool00ol0003oooooo`00003ooooooeSooooo0009ooooo`04omgMgOmEEEGoooooo`00
00?ooooo00Ook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000000[ooooo1?l00020ooooo`03o`000?oooooo00000?oooooo
F?ooool000[ooooo00?oMgMgolc<c?l000000oooool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oo
oooooooo00;ooooo00Go410@oooooooooooooooooa0@400:ooooo`03o`000?oooooooooo087ooooo
00?o0000ooooool00000oooooomHooooo`002_ooool00oo^k^koA4A4o`00000?ooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`;o00001Oooool00ol0003ooooo
ooooo`21ooooo`03o`000?oooooo00000?ooooooF?ooool000_ooooo00?oMgMgo`000?ooool03?oo
ool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_ooool01?l0003ooooo
ooooool00004ooooo`03o`000?oooooooooo087ooooo00?o0000ooooool000002Oooool2o`000?oo
ooooCOooool002Sooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`21ooooo`03
o`000?oooooo000000Wooooo0_l0003oooooodgooooo000Xooooo`?o00001Oooool00ol0003ooooo
ooooo`21ooooo`03o`000?oooooo000000Wooooo0_l0003oooooodgooooo000Yooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0POooool00ol0003oooooo`000009ooooo`;o0000oooo
oom=ooooo`00:_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo087ooooo00?o0000
ooooool000002Oooool2o`000?ooooooCOooool0033ooooo00?o0000ooooooooool0POooool00ol0
003oooooo`000009ooooo`;o0000oooooom=ooooo`00<?ooool00ol0003oooooooooo`1fooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooool000002Oooool2o`000?ooooooCOooool0033ooooo
00?o0000ooooooooool0M_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo000000Wooooo
0_l0003oooooodgooooo000`ooooo`03o`000?oooooooooo07Kooooo00?o0000ooooooooool02?oo
ool00ol0003oooooo`000009ooooo`;o0000oooooom=ooooo`00<?ooool3o`0007Gooooo0_l0000:
ooooo`03o`000?oooooo000000Wooooo0_l0003oooooodgooooo000`ooooo`03o`000?oooooooooo
07Gooooo00?o0000ooooool000002Oooool00ol0003oooooo`000009ooooo`;o0000oooooom=oooo
o`00<?ooool00ol0003oooooooooo`1eooooo`03o`000?oooooo000000Wooooo00?o0000ooooool0
00002Oooool00ol0003oooooo`00003oooooodcooooo000`ooooo`03o`000?oooooooooo07Gooooo
00?o0000ooooool000002Oooool00ol0003oooooo`000009ooooo`03o`000?oooooo00000?oooooo
C?ooool0033ooooo00?o0000ooooooooool0MOooool00ol0003oooooo`000009ooooo`03o`000?oo
oooo000000Wooooo00?o0000ooooool00000oooooom<ooooo`00<?ooool00ol0003oooooooooo`1e
ooooo`03o`000?oooooo000000Wooooo00?o0000ooooool000002Oooool00ol0003oooooo`00003o
ooooodcooooo000`ooooo`03o`000?oooooooooo07Gooooo00?o0000ooooool000002Oooool00ol0
003oooooo`000008ooooo`04o`000?ooooooooooo`000?ooooooC?ooool0033ooooo00?o0000oooo
ooooool0MOooool00ol0003oooooo`000009ooooo`03o`000?oooooo000000Sooooo00Co0000oooo
oooooooo0000oooooom<ooooo`00<?ooool00ol0003oooooooooo`1eooooo`03o`000?oooooo0000
00Wooooo00?o0000ooooool000002?ooool01?l0003oooooooooool0003oooooodcooooo000`oooo
o`03o`000?oooooooooo07Gooooo00?o0000ooooool000002Oooool00ol0003oooooo`000008oooo
o`04o`000?ooooooooooo`000?ooooooC?ooool0033ooooo00?o0000ooooooooool0MOooool00ol0
003oooooo`000009ooooo`03o`000?oooooo000000Sooooo00Co0000oooooooooooo0000oooooom<
ooooo`00<?ooool00ol0003oooooooooo`1eooooo`03o`000?oooooo000000Wooooo00?o0000oooo
ool000002?ooool01?l0003oooooooooool0003oooooodcooooo000`ooooo`?o0000MOooool00ol0
003oooooo`000009ooooo`03o`000?oooooo000000Sooooo00Co0000oooooooooooo0000oooooom<
ooooo`00<?ooool00ol0003oooooooooo`1eooooo`03o`000?oooooo000000Wooooo00?o0000oooo
ool000002?ooool01?l0003oooooooooool0003oooooodcooooo000`ooooo`03o`000?oooooooooo
07Gooooo00?o0000ooooool000002Oooool00ol0003oooooo`000008ooooo`04o`000?oooooooooo
o`000?ooooooC?ooool0033ooooo00?o0000ooooooooool0MOooool00ol0003oooooo`000009oooo
o`03o`000?oooooo000000Sooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`3o
oooood3ooooo000`ooooo`03o`000?oooooooooo07Gooooo00?o0000ooooool000002Oooool00ol0
003oooooo`000008ooooo`04o`000?ooooooooooo`0000Sooooo0_l0003ooooood;ooooo000`oooo
o`03o`000?oooooooooo07Gooooo00?o0000ooooool000002Oooool00ol0003oooooo`000008oooo
o`04o`000?ooooooooooo`0000Sooooo0_l0003ooooood;ooooo000`ooooo`03o`000?oooooooooo
07Gooooo00?o0000ooooool000002Oooool00ol0003oooooo`000008ooooo`04o`000?oooooooooo
o`0000Sooooo0_l0003ooooood;ooooo000`ooooo`03o`000?oooooooooo07Gooooo00?o0000oooo
ool000002Oooool00ol0003oooooo`000008ooooo`04o`000?ooooooooooo`0000Sooooo0_l0003o
oooood;ooooo000`ooooo`03o`000?oooooooooo07Gooooo00?o0000ooooool000002Oooool00ol0
003oooooo`000008ooooo`04o`000?ooooooooooo`0000Sooooo0_l0003ooooood;ooooo000`oooo
o`03o`000?oooooooooo07Gooooo00?o0000ooooool000002?ooool01?l0003oooooooooool00008
ooooo`04o`000?ooooooooooo`0000Sooooo0_l0003ooooood;ooooo000`ooooo`03o`000?oooooo
oooo07Cooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00008ooooo`04o`00
0?ooooooooooo`0000Sooooo0_l0003ooooood;ooooo000`ooooo`?o0000M?ooool01?l0003ooooo
ooooool00008ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool00008
ooooo`;o0000oooooom2ooooo`00<?ooool00ol0003oooooooooo`1dooooo`04o`000?oooooooooo
o`0000Sooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Sooooo
0_l0003ooooood;ooooo000`ooooo`03o`000?oooooooooo07Cooooo00Co0000oooooooooooo0000
2?ooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo00001oooool00ol0
003oooooo`00003ooooood;ooooo000`ooooo`03o`000?oooooooooo07Cooooo00Go0000oooooooo
ooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool0
0007ooooo`04o`000?ooooooooooo`000?oooooo@Oooool0033ooooo00?o0000ooooooooool0M?oo
ool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04
o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo0000oooooom1ooooo`00<?ooool00ol0
003oooooooooo`1dooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooo
oooo000000Oooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool0003ooooood7o
oooo000`ooooo`03o`000?oooooooooo07Cooooo00Go0000ooooooooooooooooo`000007ooooo`05
o`000?ooooooooooooooool000001oooool01?l0003oooooooooool00007ooooo`04o`000?oooooo
ooooo`000?oooooo@Oooool0013ooooo0_o^k^h3ooooo`;ok^k^6Oooool00ol0003oooooooooo`1Y
ooooo`03o`000?oooooooooo00Sooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oo
ooooooooooooool000001oooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`00
0?oooooo@Oooool000Wooooo1Ol00002ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03
ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP[ooooo00?o0000oooooooo
ool0J?ooool2o`0000[ooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooooooo
ooooool000001oooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`000?oooooo
@Oooool000Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05onk^k_mEEEGogMgMoeEEEOo^
k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02_ooool00ol0
003oooooooooo`1Xooooo`03o`000?oooooo000000Wooooo00Go0000ooooooooooooooooo`000007
ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool00007ooooo`04o`00
0?ooooooooooo`000?oooooo@Oooool00003ooooool0003o000000Co00000oooool00onHV9So8B4Q
onk^kP05ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@413ooooo
oooooooooooo410@00[ooooo00?o0000ooooooooool0J?ooool00ol0003oooooo`000009ooooo`05
o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000
oooooooooooo00001oooool01?l0003oooooooooool0003ooooood7ooooo000;ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo
00Go0000ooooooooooooooooo`00000:ooooo`03o`000?oooooooooo06Sooooo00?o0000ooooool0
00002Oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007
ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo0000oooooom1ooooo`003?oo
ool02omgMgOoIVIVooooooooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000000[ooooo1?l0001Wooooo`03o`000?oo
oooo000000Wooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool0
00001oooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`000?oooooo@Oooool0
00gooooo00?o0000ooooooooool00_o^k^h3ooooo`;ok^k^1Oooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@41002_ooool00ol0003oooooooooo`1Xooooo`03o`000?oooooo
000000Wooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool00000
1oooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`000?oooooo@Oooool000Wo
oooo00Go0000okZj^_ooooooV9RHoa0@400>ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`03ooooo`;o00001Oooool00ol0003oooooooooo`1Xooooo`03o`000?oooooo
000000Wooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool00000
1oooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`000?oooooo@Oooool000Wo
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c00<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP02ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0J?oo
ool00ol0003oooooo`000009ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooo
oooooooooooo000000Oooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool0003o
oooood7ooooo000Xooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0J?ooool0
0ol0003oooooo`000009ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooo
oooooooo000000Oooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool0003ooooo
od7ooooo000Xooooo`?o00001Oooool00ol0003oooooooooo`1Xooooo`03o`000?oooooo000000Wo
oooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool0
1?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`000?oooooo@Oooool002Wooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`1Xooooo`03o`000?oooooo000000Wooooo00Go
0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool01?l0003o
ooooooooool00007ooooo`04o`000?ooooooooooo`000?oooooo@Oooool002[ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`1Wooooo`04o`000?ooooooooooo`0000Wooooo00Go0000
ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool01?l0003ooooo
ooooool00007ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool0oooooolfoooo
o`00<?ooool00ol0003oooooooooo`1Wooooo`04o`000?ooooooooooo`0000Wooooo00Go0000oooo
ooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool01?l0003ooooooooo
ool00007ooooo`04o`000?ooooooooooo`0000Oooooo0_l0003oooooocSooooo000`ooooo`03o`00
0?oooooooooo06Oooooo00Co0000oooooooooooo00002Oooool01Ol0003ooooooooooooooooo0000
00Oooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo00Co
0000oooooooooooo00001oooool2o`000?oooooo>?ooool0033ooooo00?o0000ooooooooool0Iooo
ool01?l0003oooooooooool00009ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003o
oooooooooooooooo000000Oooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool0
0007ooooo`;o0000oooooolhooooo`00<?ooool00ol0003oooooooooo`1Wooooo`04o`000?oooooo
ooooo`0000Wooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool0
00001oooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Oooooo0_l0003o
ooooocSooooo000`ooooo`?o0000Ioooool01Ol0003ooooooooooooooooo000000Sooooo00Go0000
ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooo
oooooooooooo000000Kooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00003ooooo
ocOooooo000`ooooo`03o`000?oooooooooo06Oooooo00Go0000ooooooooooooooooo`000008oooo
o`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Go
0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool0
0000oooooolgooooo`00<?ooool00ol0003oooooooooo`1Wooooo`05o`000?ooooooooooooooool0
00002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007
ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool00007ooooo`03o`00
0?oooooo00000?oooooo=oooool0033ooooo00?o0000ooooooooool0Ioooool01Ol0003ooooooooo
oooooooo000000Sooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooo
oooooooo00001oooool00ol0003oooooo`00003oooooocOooooo000`ooooo`03o`000?oooooooooo
06Oooooo00Go0000ooooooooooooooooo`000008ooooo`05o`000?ooooooooooooooool000001_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool00000
oooooolgooooo`00<?ooool00ol0003oooooooooo`1Wooooo`05o`000?ooooooooooooooool00000
2?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01?l0003o
ooooooooool00007ooooo`03o`000?oooooo00000?oooooo=oooool0033ooooo00?o0000oooooooo
ool0Ioooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00001oooool0
0ol0003oooooo`00003oooooocOooooo000`ooooo`03o`000?oooooooooo06Oooooo00Go0000oooo
ooooooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool00000oooo
oolgooooo`00<?ooool00ol0003oooooooooo`1Wooooo`05o`000?ooooooooooooooool000001ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool01?l0003oooooooooool00006ooooo`04o`000?ooooooooooo`000?oooooo=oooool0033ooooo
00?o0000ooooooooool0Ioooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooo
oooo00001_ooool01?l0003oooooooooool0003oooooocOooooo000`ooooo`03o`000?oooooooooo
06Oooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000Kooooo00Co
0000oooooooooooo0000oooooolgooooo`00<?ooool00ol0003oooooooooo`1Wooooo`05o`000?oo
ooooooooooooool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool01?l0003oooooooooool00006ooooo`04o`000?ooooooooooo`00
0?oooooo=oooool0033ooooo0ol0001Wooooo`05o`000?ooooooooooooooool000001oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01?l0
003oooooooooool00006ooooo`04o`000?ooooooooooo`000?oooooo=oooool0033ooooo00?o0000
ooooooooool0Foooool00ol0003oooooooooo`09ooooo`05o`000?ooooooooooooooool000001ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo0000
oooooolgooooo`00<?ooool00ol0003oooooooooo`1Jooooo`;o00002oooool01Ol0003ooooooooo
oooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`04o`00
0?ooooooooooo`000?oooooo=oooool0033ooooo00?o0000ooooooooool0F_ooool00ol0003ooooo
o`00000:ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00?ooooo00Co0000oooooooooooo00001oooool2o`000?oooooo;_ooool0033o
oooo00?o0000ooooooooool0F_ooool00ol0003oooooo`000009ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00Co0000oooooooooooo00001oooool2o`000?oooooo;_ooool0033ooooo00?o0000oooooooo
ool0C_ooool2onk^kP?ooooo0_o^k^h4ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool01?l0003oooooooooool00007ooooo`03o`000?o^k^ko000000;ooooo0_o^k^iP
ooooo`;ok^k^0oooool2onk^kTkooooo0_o^k^h3ooooo`;ok^k^K?ooool0033ooooo00?o0000oooo
ooooool0B?ooool03Om4A4Co0000o`000?lb<S;ogMgMooooooo^k^koEEEEonk^k_ooooook^k^oeEE
EOo^k^h00oooool5o`0000;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00Go0000oooooooooooo0000ooooo`04o`000009oa0@4?oooooo0000oeEEEOl0003o
ooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^
>oooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`0=odA4A?l0003o0000oc8b<_oM
gMgoooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co000000So410@oooooooooooo
k^k^oc8b<_l0003o<S8bonk^kSSooooo1Ol00002ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEE
onk^kP03ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kUgooooo000`oooo
o`03o`000?oooooooooo04_ooooo00WoMgMgoc8b<_ooooooooooonk^k_mEEEGogMgMoeEEEOo^k^h0
1Oooool2o`0000;ooooo00Oo0000oooooomgMgOoV9RHoooooonHV9SoMgMg00;ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool01?l0003oooooooooool00003ooooo`0:o`000?ooooooooooooooool0003ok^k^
o`000?oMgMgoEEEEonk^kPKooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg03gooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00WoMgMgoc8b<_ooooooooooonk^
k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL0>?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^
kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Mooooo`00<?oo
ool00ol0003oooooooooo`1<ooooo`07o`000?oooooooooooooooooMgMgo0000omgMg@06ooooo`;o
00000_ooool00ol0003ooooooa0@4003ooooo`04oa0@4?ooooooooooo`0000Cooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Co0000oooo
oooooooo00000oooool01_l0003ooooooooooooooooo0000ooooo`;o000000?ogMgMooooooooool0
1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100?Oooool00ol0003o
ooooooooo`0?ooooo`07o`000?oooooooooooooooooMgMgo0000omgMg@07ooooo`03o`000?oooooo
oooo00;ooooo00Go410@oooooooooooooooooa0@400iooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?o
gMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100
GOooool0033ooooo00?o0000ooooooooool0Boooool02OmgMgOo<S8booooooooooook^k^oeEEEOoM
gMgoEEEEonk^kP05ooooo`;o00000_ooool00ol0003oooooo`000003ooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00Co0000oooooooooooo00000oooool02_l0003ooooooooooooooooo0000onk^k_l0
003ogMgMoeEEEOo^k^h6ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
000mooooo`03o`000?oooooooooo00kooooo00WoMgMgoc8b<_ooooooooooonk^k_mEEEGogMgMoeEE
EOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000>_ooool0
0onHV9So8B4Qonk^kP03ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool00000GOooool0033ooooo00?o0000ooooooooool0B?oo
ool03Ol0003o8B4Qo`000?lb<S;oc<c<ooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01?oo
ool2o`0000;ooooo00?o0000ooooool000000oooool01?l0003oooooooooool00004ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`00
0?ooooooooooooooool000000_ooool02ol0003oooooooooool0003ok^k^oeEEEOl0003oooooonk^
k_mEEEGok^k^00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000003go
oooo00?o0000ooooooooool02oooool03Ol0003o8B4Qo`000?lb<S;oc<c<ooooooo^k^koEEEEonk^
k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000>oooool02omgMgOoIVIVooooooooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Go
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000005gooooo000`ooooo`03
o`000?oooooooooo04Sooooo00?o0000ooooooooool00oooool2onk^kP?ooooo0_o^k^h3ooooo`03
o`000?oooooo000000;ooooo00?o0000ooooool@41000oooool01?l@413oooooooooool00004oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002onk^kP03o`000?oo
oooooooo00;ok^k^1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100
?Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo0_o^k^h3ooooo`;ok^k^
1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100??ooool00ol0003o
ooooooooo`02onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooo
oooooooooa0@401Mooooo`00<?ooool3o`0004Sooooo00?o0000ooooooooool03Oooool00ol0003o
ooooo`000002ooooo`07o`000?ooooooMgMgoiRHV?ooooooV9RHogMgM`02ooooo`03o`000?oooooo
oooo00;ooooo0_l00006ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`;o
0000<oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo0_l0000^ooooo`05o`000?nj^[[ooooo
oiRHV?l@41003_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?oo
ool2o`0005?ooooo000`ooooo`03o`000?oooooooooo04Sooooo1?l0000<ooooo`03o`000?mVIVKo
000000;ooooo00Oo0000ooooooo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo00?o0000ooooooooool0
0_ooool2o`0000Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`08o`00
0?ooooooooooooooool0003oEEEEofIVI_l00002ooooo`04o`000?ooooooooooo`0000Oooooo00?o
EEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oooooo00Co0000oooooooooooo
0000<?ooool00omEEEGoIVIVo`00000=ooooo`Co00003?ooool00omEEEGoIVIVo`000004ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01oooool01?l0003oooooooooool0000]ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`03?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1oooool01?l0003oooooooooool0001Booooo`00<?ooool00ol0003oooooooooo`1Hooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01Oooool4o`000004ooooool0003oooooo`0000Go
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooooooooooo
ool000001Oooool01?l0003oooooooooool00007ooooo`;o00003?ooool4o`000005ooooool0003o
ooooooooool00000G_ooool4o`000005ooooool0003oooooooooool00000C?ooool4o`000005oooo
ool0003oooooooooool00000D_ooool0033ooooo00?o0000ooooooooool0F?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003ooooo
o`000005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000006ooooo`;o
00004Oooool3o`0006Cooooo0ol0001Booooo`?o0000Doooool0033ooooo00?o0000ooooooooool0
F?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooo
ooooooooo`000005ooooo`?o00004_ooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo
05;ooooo00?o0000ooooooooool0D_ooool0033ooooo00?o0000ooooooooool0F?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool4o`0000Co
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000oooo
ool000004oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo05;ooooo00?o0000oooo
ooooool0DOooool0033ooooo00?o0000ooooooooool0B_ooool3o`0000_ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001Oooool01?l0
003oooooooooool0003oooooob?ooooo000`ooooo`03o`000?oooooooooo04[ooooo00Co0000oooo
oooooooo00002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000
ooooooooooooooooo`000005ooooo`04o`000?ooooooooooo`000>Sooooo00?oMgMgofIVI_ooool0
;Oooool00omVIVKoMgMgooooo`07ooooo`00<?ooool00ol0003oooooooooo`19ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00Go0000ooooooooooooooooo`000005ooooo`04o`000?ooooooooooo`0000Ko
oooo0_l0003Oooooo`03omgMgOl@413ok^k^02kooooo00?ok^k^oa0@4?oMgMd01oooool0033ooooo
00?o0000ooooooooool0BOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool0
00001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo0_l000000ooooooo
0000ooooo`3;ooooo`;o00000_ooool2o`0000cooooo00?oEEEEoiRHV?ooool00_l00002ooooo`07
o`000?ooooooooooo`000?l@413ok^k^oeEEE@02o`000003odA4A?nj^[[ooooo00;ooooo00GoV9RH
o`000?l0003oA4A4okZj^P02ooooo`08onk^k_mEEEGo0000o`000?m4A4Co^[Zjooooool@4105o`00
00?ooooo00So410@oc8b<_l0003o0000oa0@4?nYZJWoQhN7ofIVIPOooooo000`ooooo`03o`000?oo
oooooooo03[ooooo0_l0000<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooooooo
o`000004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00005ooooo`?o0000a?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@cooooo00Go0000
ooooooooooooooooo`000002ooooo`0;o`000?ooooooooooo`000?ooooooEEEEogMgMoooooook^k^
ogMgMol@41000oooool01Ol@413o^[Zjonk^k_mgMgOo410@00;ooooo00KoEEEEogMgMoooooook^k^
ogMgMol@4103ooooo`03o`000?oooooooooo00Cooooo00So0000ojVYZOoooooooooookZj^_l0003o
k^k^o`0000Oooooo003oo`000;Co00003oooool01?oMgMgo0000oa0@4?o<c<`=ooooo`05oc8b<_oo
ooooooooooooool000000_ooool01_l0003oooooooooool0003oooooo`0000Sooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00Oo^[ZjohN7
QomVIVKoIVIVoa0@4?oooooo000000Oooooo000:ooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`07ooooo`;o00001?ooool2o`000003ooooool0003o
oooo00Gooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo000000?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000;ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo0_l0
0004ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`00
0?ooooooooooooooool000001?ooool2o`0000;ooooo00?o0000ooooooooool00_ooool5o`0000Go
oooo0_l00008ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0Gooooo`04onk^k_lQ8B7o410@onk^kPgooooo00Go<S8booooooooooooooooo`000002
ooooo`05o`000?ooooooooooo`000?ooool01_l00003ooooo`03o`000?oooooooooo00Cooooo1_l0
0003ooooo`03o`000?oooooooooo00Cooooo00So<S8bob4Q8OmgMgOoMgMgohN7Qoo^k^koooooo`00
00Oooooo000:ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`09ooooo`Go00000_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Go
oooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`00
0005ooooo`?o00001_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0Gooooo`04ob4Q8OmgMgOoMgMgoc8b<Pgooooo
00Go0000onk^k_ooooooooooo`000002olc<c00;o`000?nYZJWogMgMob4Q8OooooooEEEEohN7Qoo^
k^koooooohN7Qolb<S800oooool00ol0003oooooooooo`04ooooo`06oeEEEOn7QhOok^k^oooooon7
QhOo<S8b0oooool00ol0003o<S8bomgMg@04ooooo`08o`000?nj^[[oooooonk^k_mgMgOo0000onk^
k_l00007ooooo`00<?ooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooo
ooooo`000005ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0003ooooooooooooooooo
000000Cooooo0_l00002ooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool0Foooool0
0ol0003oooooooooo`0Fooooo`;o00000_ooool2o`0000cooooo00koEEEEogMgMooooooo410@o`00
0?lQ8B7o0000ogMgMol@413o0000ojVYZOooooook^k^oeEEE@;o000000CoA4A4onk^k_oooooo410@
1Ol00003ooooo`06onk^k_mEEEGo0000o`000?m4A4Cok^k^0_ooool2o`000004ojVYZOlQ8B7o0000
ob4Q8@;ooooo00SoZJVYob4Q8Ol0003o0000oc8b<_l0003oMgMgoeEEE@Oooooo000`ooooo`03o`00
0?oooooooooo053ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000005ooooo`05o`000?oooooooooooooo
ool000001Oooool01Ol0003ooooooooooooooooo000000Gooooo00Co0000oooooooooooo0000h_oo
ool00ooMgMgo410@onk^kP0Booooo`03o`000?oooooooooo01Wooooo00?ok^k^oa0@4?oMgMd01ooo
ool0033ooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Gooooo00Go
0000ooooooooooooooooo`000005ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003o
ooooo`00003Tooooo`03ogMgMomVIVKooooo017ooooo00?o0000ooooooooool06Oooool00omVIVKo
MgMgooooo`07ooooo`00<?ooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool0
00001Oooool01Ol0003ooooooooooooooooo000000Gooooo00Go0000ooooooooooooooooo`000005
ooooo`?o0000oooooolOooooo`00<?ooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooooooo
ooooool000001Oooool01Ol0003ooooooooooooooooo000000Gooooo00Co0000oooooooooooo0000
oooooolXooooo`00<?ooool00ol0003oooooooooo`1Aooooo`05o`000?ooooooooooooooool00000
2Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0003o
oooooooooooooooo000000Gooooo00Co0000oooooooooooo0000oooooolXooooo`00<?ooool00ol0
003oooooooooo`1Booooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool0
1Ol0003ooooooooooooooooo000000Gooooo00Go0000ooooooooooooooooo`000005ooooo`04o`00
0?ooooooooooo`000?oooooo:?ooool0033ooooo00?o0000ooooooooool0D_ooool01?l0003ooooo
ooooool00009ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000005oooo
o`05o`000?ooooooooooooooool000001Oooool01?l0003oooooooooool0003oooooobSooooo000`
ooooo`03o`000?oooooooooo05;ooooo0ol0000:ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000
ooooooooooooooooo`000005ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooo
o`00003oooooobSooooo000`ooooo`?o0000Doooool2o`0000[ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooo
ool01Ol0003ooooooooooooooooo000000Gooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooo00000?oooooo:?ooool0033ooooo00?o0000ooooooooool0Goooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`05o`000?ooooooooooooooool000001Oooool01?l0003oooooooooool00007oooo
o`;o0000oooooolYooooo`00<?ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00Go0000ooooooooooooooooo`000005ooooo`04o`000?ooooooooooo`0000Oooooo0_l0003o
ooooobWooooo000`ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0
003ooooooooooooooooo000000Gooooo00Co0000oooooooooooo0000oooooolbooooo`00<?ooool0
0ol0003oooooooooo`1Oooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00
0005ooooo`04o`000?ooooooooooo`000?oooooo<_ooool0033ooooo00?o0000ooooooooool0Gooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001Oooool01?l0003ooooo
ooooool0003ooooooc;ooooo000`ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool01Ol0003ooooooooooooooooo000000Gooooo00Co0000oooooooooooo0000oooooolboooo
o`00<?ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooo
ooooooooo`000006ooooo`03o`000?oooooo00000?oooooo<_ooool0033ooooo00?o0000oooooooo
ool0H?ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool01Ol0
003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooo`00003ooooooc;ooooo000`ooooo`03o`000?oo
oooooooo063ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooool00000oooooolbooooo`00<?ooool00ol0
003oooooooooo`1Pooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04
ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Kooooo
00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo00000?oooooo<_ooool0033ooooo
00?o0000ooooooooool0H?ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000006
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooo`00003ooooooc;ooooo000`
ooooo`?o0000H?ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000006ooooo`05
o`000?ooooooooooooooool000001_ooool00ol0003oooooo`00003ooooooc;ooooo000`ooooo`03
o`000?oooooooooo063ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Cooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001_oo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooool00000oooooolbooooo`00<?oo
ool00ol0003oooooooooo`1Pooooo`05o`000?ooooooooooooooool000002?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo0000
00Kooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo00000?oooooo<_ooool0
033ooooo00?o0000ooooooooool0H?ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000oooooooooooooooo
o`000006ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooo`00003ooooooc;o
oooo000`ooooo`03o`000?oooooooooo063ooooo00Co0000oooooooooooo00002Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo
000000Kooooo00Go0000ooooooooooooooooo`000006ooooo`;o0000oooooolcooooo`00<?ooool0
0ol0003oooooooooo`1Qooooo`03o`000?oooooo000000Wooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool0
1Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000006ooooo`05o`00
0?ooooooooooooooool000001_ooool2o`000?oooooo<oooool0033ooooo00?o0000ooooooooool0
HOooool00ol0003oooooo`000009ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooo
ooooo`000006ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool00008
ooooo`03o`000?oooooooooo0?oooooo<Oooool0033ooooo00?o0000ooooooooool0HOooool00ol0
003oooooo`000009ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006
ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool0003ooooooccooooo
000`ooooo`03o`000?oooooooooo067ooooo00?o0000ooooool000002Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`04ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Ko
oooo00Co0000oooooooooooo0000oooooollooooo`00<?ooool00ol0003oooooooooo`1Qooooo`03
o`000?oooooo000000Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000
00Kooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`000?oooooo??oo
ool0033ooooo00?o0000ooooooooool0HOooool00ol0003oooooo`000009ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool00000
1_ooool01?l0003oooooooooool0003ooooooccooooo000`ooooo`03o`000?oooooooooo067ooooo
0ol00009ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool01Ol0003ooooo
oooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?oooooooooo
ooooool000001_ooool01?l0003oooooooooool0003ooooooccooooo000`ooooo`?o0000H_ooool0
0ol0003oooooooooo`09ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooo
oooooooo000000Oooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?oooooooooooooo
ool000001_ooool01?l0003oooooooooool0003ooooooccooooo000`ooooo`03o`000?oooooooooo
06kooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001ooo
ool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000006ooooo`04
o`000?ooooooooooo`000?oooooo??ooool0033ooooo00?o0000ooooooooool0K_ooool01Ol0003o
oooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooo
ooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo
0000oooooollooooo`00<?ooool00ol0003oooooooooo`1^ooooo`05o`000?ooooooooooooooool0
00001oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000006
ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool0003ooooooccooooo
000`ooooo`03o`000?oooooooooo06kooooo00Go0000ooooooooooooooooo`000007ooooo`05o`00
0?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000oooo
ooooooooooooo`000007ooooo`03o`000?oooooo00000?oooooo??ooool0033ooooo00?o0000oooo
ooooool0K_ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`00
0007ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Oo
oooo00?o0000ooooool00000oooooollooooo`003oooool2onk^kP?ooooo0_o^k^hJooooo`03o`00
0?oooooooooo06kooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooooooooooo
ool000001oooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`00
0007ooooo`03o`000?oooooo00000?oooooo??ooool000Sooooo1Ol00002ooooo`07onk^k_mEEEGo
k^k^ooooooo^k^koEEEEonk^kP03ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8b
onk^kP_ooooo00?o0000ooooooooool0K_ooool01Ol0003ooooooooooooooooo000000Oooooo00Go
0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003o
oooooooooooooooo000000Oooooo00?o0000ooooool00000oooooollooooo`002?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03o`000?oooooooooo06kooooo00Go
0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003o
oooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo
00000?oooooo??ooool000Wooooo00?oV9RHob4Q8Oo^k^h01Oooool00ooMgMgo0000omgMg@07oooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400;ooooo`03o`000?oooooo
oooo06kooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Oooooo
00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001oooool00ol0
003oooooo`00003ooooooccooooo000:ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Gok^k^oeEEEOoM
gMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000;
ooooo`03o`000?oooooooooo06kooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooo
oooooooo000000Oooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?oooooooooooooo
ool000001oooool00ol0003oooooo`00003ooooooccooooo000;ooooo`0;ogMgMomVIVKooooooooo
ooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000002oooool4o`0006gooooo00Co0000oooooooooooo00002?ooool01Ol0
003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?oo
ooooooooooooool000001oooool00ol0003oooooo`00003ooooooccooooo000<ooooo`03o`000?oo
oooooooo00;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@00_ooooo00?o0000ooooooooool0K_ooool01?l0003oooooooooool00008ooooo`05
o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000
ooooooooooooooooo`000007ooooo`;o0000oooooolmooooo`002?ooool01Ol0003o^[ZjoooooonH
V9So410@00kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00?o0000ooooooooool0K_ooool01?l0003oooooooooool00008ooooo`05o`000?oooooooooooooo
ool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo00001ooo
ool2o`000?oooooo?Oooool000Sooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00<ooooo`03oeEEEOmV
IVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`;o00001_ooool00ol0003ooooo
ooooo`1^ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000007oooo
o`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool00007ooooo`;o0000oooo
oolmooooo`009oooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo06kooooo00Co
0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooooooo
ooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo0_l0003oooooocgooooo000Woooo
o`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0K_ooool01?l0003oooooooooool0
0008ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oo
oooo00Co0000oooooooooooo00001oooool2o`000?oooooo?Oooool002Oooooo0ol00006ooooo`03
o`000?oooooooooo06kooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo
000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo000000Sooooo0_l0
003oooooocgooooo000Xooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0K_ooool0
1?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooo
oooooooooooo000000Oooooo00?o0000ooooool00000oooooom7ooooo`00:Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo06kooooo00Co0000oooooooooooo00002?ooool01Ol0003o
oooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo
00000?ooooooAoooool0033ooooo00?o0000ooooooooool0K_ooool01?l0003oooooooooool00008
ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo
00?o0000ooooool00000oooooom7ooooo`00<?ooool00ol0003oooooooooo`1^ooooo`04o`000?oo
ooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooooooooooo
ool000001oooool00ol0003oooooo`00003oooooodOooooo000`ooooo`03o`000?oooooooooo06ko
oooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000
ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?ooooooAoooool0033ooooo0ol0001^
ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000007ooooo`05o`00
0?ooooooooooooooool000001oooool00ol0003oooooo`00003oooooodOooooo000`ooooo`03o`00
0?oooooooooo06kooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo0000
00Oooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?ooooooAoooool0
033ooooo00?o0000ooooooooool0K_ooool01?l0003oooooooooool00008ooooo`05o`000?oooooo
ooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooool00000
oooooom7ooooo`00<?ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooo000000Sooooo00Go
0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool00ol0003o
ooooo`00003oooooodOooooo000`ooooo`03o`000?oooooooooo06oooooo0_l00009ooooo`05o`00
0?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000oooo
ool00000oooooom7ooooo`00<?ooool00ol0003oooooooooo`1_ooooo`;o00002Oooool01?l0003o
ooooooooool00008ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003o
ooooodOooooo000`ooooo`03o`000?oooooooooo06oooooo0_l00009ooooo`04o`000?oooooooooo
o`0000Sooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?ooooooAooo
ool0033ooooo00?o0000ooooooooool0Koooool2o`0000Wooooo00Co0000oooooooooooo00002?oo
ool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooool00000oooooom7ooooo`00<?oo
ool00ol0003oooooooooo`1_ooooo`;o00002Oooool01?l0003oooooooooool00008ooooo`05o`00
0?ooooooooooooooool000001oooool00ol0003oooooo`00003oooooodOooooo000`ooooo`03o`00
0?oooooooooo06oooooo0_l00009ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooo
oooo00002?ooool00ol0003oooooo`00003oooooodOooooo000`ooooo`03o`000?oooooooooo06oo
oooo0_l0000:ooooo`03o`000?oooooo000000Wooooo00?o0000ooooool000002?ooool00ol0003o
ooooo`00003oooooodOooooo000`ooooo`03o`000?oooooooooo06oooooo0_l0000:ooooo`03o`00
0?oooooo000000Wooooo00?o0000ooooool000002?ooool00ol0003oooooo`00003oooooodOooooo
000`ooooo`?o0000Noooool00ol0003oooooo`000009ooooo`03o`000?oooooo000000Sooooo00?o
0000ooooool00000oooooom7ooooo`00<?ooool00ol0003oooooooooo`1kooooo`03o`000?oooooo
000000Wooooo00?o0000ooooool000002?ooool00ol0003oooooo`00003oooooodOooooo000`oooo
o`03o`000?oooooooooo07_ooooo00?o0000ooooool000002Oooool00ol0003oooooo`000008oooo
o`03o`000?oooooo00000?ooooooAoooool0033ooooo00?o0000ooooooooool0Noooool00ol0003o
ooooo`000009ooooo`03o`000?oooooo000000Sooooo00?o0000ooooool00000oooooom7ooooo`00
<?ooool00ol0003oooooooooo`1kooooo`03o`000?oooooo000000Wooooo00?o0000ooooool00000
2?ooool00ol0003oooooo`00003oooooodOooooo000`ooooo`03o`000?oooooooooo07_ooooo00?o
0000ooooool000002Oooool00ol0003oooooo`000008ooooo`03o`000?oooooo00000?ooooooAooo
ool0033ooooo00?o0000ooooooooool0Noooool00ol0003oooooo`000009ooooo`03o`000?oooooo
000000Wooooo0_l0003oooooodOooooo000`ooooo`03o`000?oooooooooo07_ooooo00?o0000oooo
ool000002Oooool00ol0003oooooo`000009ooooo`;o0000oooooom7ooooo`00<?ooool00ol0003o
ooooooooo`1kooooo`03o`000?oooooo000000Wooooo00?o0000ooooool000002Oooool00ol0003o
ooooooooo`3oooooodKooooo000`ooooo`03o`000?oooooooooo07_ooooo00?o0000ooooool00000
2Oooool00ol0003oooooo`000009ooooo`03o`000?oooooooooo0?ooooooA_ooool0033ooooo00?o
0000ooooooooool0Noooool00ol0003oooooo`000009ooooo`03o`000?oooooo000000Wooooo00?o
0000ooooooooool0oooooom6ooooo`00<?ooool00ol0003oooooooooo`1kooooo`03o`000?oooooo
000000Wooooo00?o0000ooooool00000oooooomBooooo`00<?ooool3o`0007_ooooo00?o0000oooo
ool000002Oooool00ol0003oooooo`00003ooooooe;ooooo000`ooooo`03o`000?oooooooooo07_o
oooo00?o0000ooooool000002Oooool00ol0003oooooo`00003ooooooe;ooooo000`ooooo`03o`00
0?oooooooooo07_ooooo00?o0000ooooool000002Oooool00ol0003oooooo`00003ooooooe;ooooo
000`ooooo`03o`000?oooooooooo07_ooooo00?o0000ooooool000002Oooool00ol0003oooooo`00
003ooooooe;ooooo000`ooooo`03o`000?oooooooooo07_ooooo00?o0000ooooool000002Oooool0
0ol0003oooooo`00003ooooooe;ooooo000`ooooo`03o`000?oooooooooo07_ooooo00?o0000oooo
ool000002Oooool00ol0003oooooo`00003ooooooe;ooooo000?ooooo`;ok^k^0oooool2onk^kQ[o
oooo00?o0000ooooooooool0Noooool00ol0003oooooo`000009ooooo`03o`000?oooooo00000?oo
ooooD_ooool000[ooooo0_l000002_l@413oooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^
k^h3ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00?o0000oooo
ooooool0Noooool00ol0003oooooo`000009ooooo`03o`000?oooooo00000?ooooooD_ooool000_o
oooo00?o0000ooooooooool00_ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000oooo
ooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?o0000ooooooooool0O?ooool2
o`0000Wooooo00?o0000ooooool00000oooooomBooooo`002?ooool5o`0000Cooooo00?ogMgMo`00
0?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41002oooool0
0ol0003oooooooooo`1looooo`;o00002Oooool00ol0003oooooo`00003ooooooe;ooooo0008oooo
o`04odA4A?oMgMgoooooo`0000Cooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000;ooooo`03o`000?oooooooooo07cooooo
0_l00009ooooo`03o`000?oooooo00000?ooooooD_ooool000Sooooo00CogMgMoeEEEOoooooo0000
0oooool01oo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000002oooool4o`0007_ooooo0_l00009ooooo`03o`000?oooooo
00000?ooooooD_ooool000Wooooo00?oMgMgolc<c?l000000oooool2onk^kP?ooooo0_o^k^h5oooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400;ooooo`03o`000?oooooo
oooo07cooooo00?o0000ooooooooool02?ooool00ol0003oooooo`00003ooooooe;ooooo0009oooo
o`03onk^k_m4A4Co000000oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00?o0000ooooooooool0O?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo0?ooooooDOooool000[ooooo00?oMgMgo`000?ooool03?ooool00omEEEGoIVIVo`000004oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool2o`0000Kooooo00?o0000ooooooooool0R?ooool0
0ol0003oooooooooo`3ooooooe7ooooo000Wooooo`04o`000?ooooooooooo`0000Gooooo00?o0000
ooooooooool0R?ooool00ol0003oooooooooo`3ooooooe7ooooo000Wooooo`04o`000?oooooooooo
o`0000Gooooo00?o0000ooooooooool0R?ooool00ol0003oooooooooo`3ooooooe7ooooo000Woooo
o`?o00001_ooool00ol0003oooooooooo`3oooooomcooooo000Xooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0oooooooLooooo`00:Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool0
0ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033o
oooo0ol0003oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o
0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`oooo
o`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00
<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?oo
ool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3ooooo
omcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0
oooooooLooooo`00<?ooool3o`000?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooL
ooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oo
oooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooooooo
o`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooo
ooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`00
0?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool0
0ol0003oooooooooo`3oooooomcooooo000`ooooo`?o0000oooooooLooooo`00<?ooool00ol0003o
ooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o
0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo003ooooo
oooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?oo
ool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooo
ooooool@ooooo`00X?ooool2o`0000Cooooo00?o^[Zjoc8b<_ooool01?ooool2o`0000Kooooo00?o
0000okZj^_ooool0oooooomGooooo`00X?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool2oc8b<_ooooooF?ooool008gooooo0ol00002oooo
o`06oc8b<_l@413oooooooooooo^k^koEEEE0_l000000om4A4Co^[Zjooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00GoV9RHoa0@4?l0003o0000ojVYZ@04ooooo`03o`000?oooooooooo00Cooooo
00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj00Wooooo00Gok^k^oc8b<_l0
003o410@olc<c005ooooo`;o8B4Q1?ooool5o`000006ooooooo<c<cok^k^ooooooo^k^koc<c<1?oo
ool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hCooooo`06oa0@4?lb<S;o0000
o`000?l@413oZJVY0_ooool01_o^k^koEEEEo`000?l0003oA4A4okZj^P?ooooo00GoIVIVo`000?l0
003oA4A4olc<c03Xooooo`00S_ooool01Ol0003oooooooooooo<c<co410@00?ooooo00KoEEEEogMg
Moooooook^k^ogMgMol@4104ooooo`03o`000?oooooooooo00;ooooo00Ko0000ojVYZOmEEEGoV9RH
oeEEEOnj^[X3ooooo`03o`000?oooooooooo00Cooooo00?oc<c<o`000?l@41003?ooool01_l@413o
^[Zjonk^k_mgMgOo410@ooooo`Ko00000_ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Gooooo0_lQ
8B44ooooo`0;oiRHV?lQ8B7ok^k^oooooom4A4Coooooonk^k_mEEEGogMgMoeEEEOo^k^h01_ooool0
0ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool01_l0003oZJVYoooo
oooooooo^[Zjo`0000;ooooo00KoEEEEogMgMoooooook^k^ogMgMol@4102ooooo`06ofIVI_mgMgOo
oooooooooon7QhOo410@j?ooool008kooooo00Go0000ooooooooooooEEEEohN7Q`03ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool00_ooool01_lb<S;ok^k^oiRHV?mEEEGogMgMoa0@
40?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0;ooooo`05o`000?oooooooooo
ooooool000003?ooool00onHV9So8B4Qonk^kP03ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01Cooooo00Go^[ZjohN7QomVIVKoIVIV
oa0@4002ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0joooool008kooooo00Go
0000oooooooMgMgo0000onk^kP03ooooo`Ko00001?ooool00ol0003oooooooooo`02ooooo`07okZj
^_m4A4Coc<c<ob4Q8Ooooooo410@olc<c002ooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool00oooool6o`0000;ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0=ooooo`09oiRHV?lQ8B7o
k^k^ooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000001?ooooo00Ko<S8bob4Q8OmgMgOoMgMgohN7Qoo^k^h2ooooo`Ko00000_oo
ool00ol0003oooooooooo`3[ooooo`00S_ooool3o`000003oa0@4?nHV9Sooooo00;ooooo00KoEEEE
ohN7Qoo^k^koooooohN7Qolb<S84ooooo`03o`000?oooooooooo00;ooooo00Ook^k^o`000?oooooo
0000oooooomVIVKoQhN700;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0;oooo
o`05o`000?mEEEGo0000oa0@4?o<c<`03_ooool02?mgMgOoIVIVooooooo<c<cok^k^ooooooo^k^ko
c<c<1_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000004oooool01_l0
003o^[Zjooooooo^k^koMgMgo`0000;ooooo00KoEEEEohN7Qoo^k^koooooohN7Qolb<S82ooooo`06
ofIVI_mgMgOooooooooooon7QhOo0000j?ooool008kooooo00Go0000ooooooooooooc<c<o`000003
ooooo`06onk^k_mEEEGo0000o`000?m4A4Cok^k^1?ooool00ol0003oooooooooo`02ooooo`04ofIV
I_nHV9Sooooooc8b<P;o^[Zj00Co0000oooooooooooo00004oooool00ol@413o0000o`000003o`00
00[ooooo00?oEEEEohN7Qoooool04Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00;ooooo00Go410@oooooooooooooooooa0@4007ooooo`?o00000_ooool3o`0000Cooooo00KoZJVY
ob4Q8Ol0003o0000oc8b<_l00002ooooo`06onk^k_mEEEGo0000o`000?m4A4Cok^k^0_ooool01_o^
k^koIVIVo`000?l0003oA4A4o`000>Sooooo002>ooooo`05o`000?ooooooooooolc<c?l000003Ooo
ool00ol0003oooooooooo`05ooooo`03ofIVI_n7QhOooooo00?ooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0;ooooo`03omgMgOl@413oV9RH00gooooo00Go0000okZj^_ooooooV9RH
oa0@400<ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0ooooool2ooooo`00SOooool4o`000003oa0@
4?nYZJWooooo00cooooo0_l00006ooooo`03ojVYZOm4A4Cooooo00;ooooo0_l0000Eooooo`03o`00
0?oooooooooo00cooooo00Coc<c<odA4A?l0003o410@2oooool01OnHV9So410@o`000?lQ8B7oc<c<
00[ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo1?l00002
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0ooooool2ooooo`00ooooool6oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0ooooool2ooooo`00ooooool6ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0ooooool2ooooo`00ooooool5ooooo`;o0000
0oooool2o`000?oooooo1?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooo
oooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?oo
ool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooo
ooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@oooo
o`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooo
oooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo
0000\
\>"],
  ImageRangeCache->{{{0, 525.688}, {324.5, 0}} -> {-2.58312*^-7, -6.34248*^6, \
6.65005*^-9, 53093.5}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0.309017 5.42214e-08 [
[.32684 .29652 -16.5 -12.5 ]
[.32684 .29652 16.5 0 ]
[.54329 .29652 -16.5 -12.5 ]
[.54329 .29652 16.5 0 ]
[.75974 .29652 -22.5 -12.5 ]
[.75974 .29652 22.5 0 ]
[.97619 .29652 -16.5 -12.5 ]
[.97619 .29652 16.5 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 64 6 ]
[.09789 .09213 -34.5 -6.25 ]
[.09789 .09213 0 6.25 ]
[.09789 .20057 -34.5 -6.25 ]
[.09789 .20057 0 6.25 ]
[.09789 .41746 -28.5 -6.25 ]
[.09789 .41746 0 6.25 ]
[.09789 .5259 -28.5 -6.25 ]
[.09789 .5259 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -62.8125 0 ]
[.5 .63053 62.8125 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 .30902 m
.32684 .31527 L
s
gsave
.32684 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 .30902 m
.54329 .31527 L
s
gsave
.54329 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 .30902 m
.75974 .31527 L
s
gsave
.75974 .29652 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 .30902 m
.15368 .31277 L
s
.19697 .30902 m
.19697 .31277 L
s
.24026 .30902 m
.24026 .31277 L
s
.28355 .30902 m
.28355 .31277 L
s
.37013 .30902 m
.37013 .31277 L
s
.41342 .30902 m
.41342 .31277 L
s
.45671 .30902 m
.45671 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.58658 .30902 m
.58658 .31277 L
s
.62987 .30902 m
.62987 .31277 L
s
.67316 .30902 m
.67316 .31277 L
s
.71645 .30902 m
.71645 .31277 L
s
.80303 .30902 m
.80303 .31277 L
s
.84632 .30902 m
.84632 .31277 L
s
.88961 .30902 m
.88961 .31277 L
s
.9329 .30902 m
.9329 .31277 L
s
.0671 .30902 m
.0671 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09213 m
.11664 .09213 L
s
gsave
.09789 .09213 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .20057 m
.11664 .20057 L
s
gsave
.09789 .20057 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .41746 m
.11664 .41746 L
s
gsave
.09789 .41746 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .5259 m
.11664 .5259 L
s
gsave
.09789 .5259 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.11039 .11924 m
.11414 .11924 L
s
.11039 .14635 m
.11414 .14635 L
s
.11039 .17346 m
.11414 .17346 L
s
.11039 .22768 m
.11414 .22768 L
s
.11039 .2548 m
.11414 .2548 L
s
.11039 .28191 m
.11414 .28191 L
s
.11039 .33613 m
.11414 .33613 L
s
.11039 .36324 m
.11414 .36324 L
s
.11039 .39035 m
.11414 .39035 L
s
.11039 .44457 m
.11414 .44457 L
s
.11039 .47168 m
.11414 .47168 L
s
.11039 .49879 m
.11414 .49879 L
s
.11039 .06502 m
.11414 .06502 L
s
.11039 .03791 m
.11414 .03791 L
s
.11039 .0108 m
.11414 .0108 L
s
.11039 .55301 m
.11414 .55301 L
s
.11039 .58012 m
.11414 .58012 L
s
.11039 .60723 m
.11414 .60723 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -123.812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.812 moveto
(@) show
81.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.812 moveto
(D) show
93.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6.4) show
135.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
141.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
153.000 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
157.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
166.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
184.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02532 .30902 L
.02691 .30902 L
.02866 .30902 L
.03029 .30902 L
.03335 .30902 L
.03499 .30902 L
.03648 .30902 L
.03968 .30902 L
.04277 .30902 L
.04605 .30902 L
.0492 .30902 L
.05224 .30902 L
.05548 .30902 L
.05859 .30902 L
.06017 .30902 L
.06101 .30902 L
.0619 .30902 L
.06234 .30902 L
.06276 .30902 L
.06317 .30902 L
.06335 .30902 L
.06355 .30902 L
.06372 .30902 L
.06391 .30902 L
.06401 .30902 L
.0641 .30902 L
.0642 .30902 L
.06429 .30902 L
.06438 .30902 L
.06448 .30902 L
.06457 .30902 L
.06467 .30902 L
.06477 .30902 L
.06488 .30902 L
.06508 .30902 L
.06528 .30902 L
.06548 .30902 L
.06585 .30902 L
.06629 .30902 L
.06669 .30902 L
.06711 .30902 L
.06756 .30902 L
.06839 .30902 L
.06915 .30902 L
.06998 .30902 L
.07085 .30902 L
.07167 .30902 L
.0733 .30902 L
.07479 .30902 L
Mistroke
.07631 .30902 L
.07798 .30902 L
.07956 .30902 L
.08124 .30902 L
.08297 .30902 L
.08459 .30902 L
.08769 .30902 L
.08929 .30902 L
.09098 .30902 L
.09403 .30902 L
.09728 .30902 L
.10041 .30902 L
.10373 .30902 L
.10694 .30902 L
.1084 .30902 L
.10923 .30902 L
.11002 .30902 L
.11085 .30902 L
.11161 .30902 L
.112 .30902 L
.1122 .30902 L
.11242 .30902 L
.11253 .30902 L
.11264 .30902 L
.1127 .30902 L
.11276 .30902 L
.11281 .30902 L
.11287 .30902 L
.11293 .30902 L
.11298 .30902 L
.11303 .30902 L
.11309 .30902 L
.1132 .30902 L
.11329 .30902 L
.11339 .30902 L
.11348 .30902 L
.11368 .30902 L
.11388 .30902 L
.11409 .30902 L
.11447 .30902 L
.11482 .30902 L
.11521 .30902 L
.11564 .30902 L
.11649 .30902 L
.11731 .30902 L
.11806 .30902 L
.11893 .30902 L
.11974 .30902 L
.12135 .30902 L
.12283 .30902 L
Mistroke
.12433 .30902 L
.12599 .30902 L
.12755 .30902 L
.12922 .30902 L
.13253 .30902 L
.13572 .30902 L
.13879 .30902 L
.14205 .30902 L
.1452 .30902 L
.14602 .30902 L
.14692 .30902 L
.14733 .30902 L
.14776 .30902 L
.14817 .30902 L
.14854 .30902 L
.14872 .30902 L
.14893 .30902 L
.14902 .30902 L
.14912 .30902 L
.14921 .30902 L
.1493 .30902 L
.14939 .30902 L
.1495 .30902 L
.14959 .30902 L
.14969 .30902 L
.14979 .30902 L
.14989 .30902 L
.14995 .30902 L
.15 .30902 L
.15011 .30902 L
.1503 .30902 L
.15048 .30902 L
.15087 .30902 L
.15122 .30902 L
.15159 .30902 L
.15234 .30902 L
.15277 .30902 L
.15316 .30902 L
.15463 .30902 L
.15542 .30902 L
.15616 .30902 L
.15782 .30902 L
.15947 .30902 L
.16097 .30902 L
.16419 .30902 L
.16729 .30902 L
.17059 .30902 L
.17376 .30902 L
.17536 .30902 L
.17682 .30902 L
Mistroke
.17757 .30902 L
.17839 .30902 L
.17884 .30902 L
.17903 .30902 L
.17925 .30902 L
.17944 .30902 L
.17965 .30902 L
.17976 .30902 L
.17986 .30902 L
.17997 .30902 L
.18007 .30902 L
.18017 .30902 L
.18022 .30902 L
.18027 .30902 L
.18037 .30902 L
.18047 .30902 L
.18056 .30902 L
.18064 .30902 L
.18074 .30902 L
.18084 .30902 L
.18106 .30902 L
.18126 .30902 L
.18166 .30902 L
.18202 .30902 L
.18236 .30902 L
.18313 .30902 L
.1839 .30902 L
.18463 .30902 L
.18543 .30902 L
.18628 .30902 L
.1879 .30902 L
.18939 .30902 L
.19244 .30901 L
.1957 .309 L
.19883 .30899 L
.20216 .30898 L
.20383 .30897 L
.20456 .30897 L
.20495 .30897 L
.20537 .30897 L
.20578 .30897 L
.20614 .30897 L
.20632 .30897 L
.20652 .30897 L
.2067 .30897 L
.20679 .30897 L
.20687 .30897 L
.20697 .30897 L
.20702 .30897 L
.20708 .30897 L
Mistroke
.20717 .30897 L
.20727 .30897 L
.20736 .30897 L
.20746 .30897 L
.20755 .30897 L
.20764 .30897 L
.20784 .30897 L
.20806 .30897 L
.20827 .30897 L
.20846 .30897 L
.20883 .30897 L
.20923 .30897 L
.20996 .30897 L
.21082 .30897 L
.21161 .30898 L
.21313 .30899 L
.2148 .30901 L
.21637 .30903 L
.21805 .30906 L
.22139 .30913 L
.2246 .3092 L
.22769 .30927 L
.22852 .30929 L
.22929 .3093 L
.22971 .3093 L
.2301 .30931 L
.23052 .30931 L
.23076 .30931 L
.23086 .30931 L
.23098 .30931 L
.23108 .30931 L
.23117 .30931 L
.23126 .30931 L
.23135 .30931 L
.23145 .30931 L
.23154 .30931 L
.23164 .30931 L
.2317 .30931 L
.23175 .30931 L
.23186 .30931 L
.23196 .30931 L
.23206 .30931 L
.23218 .30931 L
.23237 .30931 L
.23258 .30931 L
.23294 .3093 L
.23334 .3093 L
.23405 .30929 L
.23486 .30927 L
.23575 .30924 L
Mistroke
.23736 .30917 L
.23894 .30908 L
.24063 .30895 L
.24396 .30862 L
.24718 .30826 L
.24866 .3081 L
.25028 .30795 L
.25105 .30789 L
.25188 .30784 L
.25233 .30782 L
.25275 .30781 L
.25295 .3078 L
.25317 .3078 L
.25327 .30779 L
.25338 .30779 L
.25348 .30779 L
.25357 .30779 L
.25366 .30779 L
.25376 .30779 L
.25386 .30779 L
.25396 .30779 L
.25406 .30779 L
.25415 .30779 L
.25423 .30779 L
.25432 .30779 L
.25452 .3078 L
.25474 .3078 L
.25493 .30781 L
.25513 .30781 L
.2555 .30783 L
.25589 .30785 L
.2566 .30791 L
.25741 .308 L
.2583 .30813 L
.25991 .30844 L
.26149 .30885 L
.26318 .30939 L
.26652 .31069 L
.2682 .31137 L
.26974 .31196 L
.27135 .31247 L
.27213 .31267 L
.27284 .31281 L
.27319 .31287 L
.27357 .31292 L
.27378 .31294 L
.27398 .31295 L
.27416 .31296 L
.27425 .31297 L
.27436 .31297 L
Mistroke
.27441 .31297 L
.27447 .31298 L
.27457 .31298 L
.27467 .31298 L
.27477 .31298 L
.27483 .31298 L
.27488 .31298 L
.27498 .31297 L
.27504 .31297 L
.27509 .31297 L
.27521 .31296 L
.2754 .31295 L
.2756 .31293 L
.27602 .31288 L
.27644 .31281 L
.27683 .31272 L
.27758 .31249 L
.27838 .31217 L
.27926 .31172 L
.28084 .31066 L
.28253 .30919 L
.28556 .30588 L
.28878 .30213 L
.29027 .30063 L
.29111 .29993 L
.29189 .29939 L
.29266 .29898 L
.29289 .29889 L
.2931 .29882 L
.29329 .29877 L
.29349 .29872 L
.2937 .29868 L
.29381 .29867 L
.29392 .29866 L
.29401 .29865 L
.2941 .29865 L
.29421 .29865 L
.29431 .29865 L
.29441 .29865 L
.29447 .29866 L
.29452 .29866 L
.29463 .29867 L
.29473 .29869 L
.29495 .29873 L
.29519 .29879 L
.29558 .29894 L
.29595 .29913 L
.29679 .29972 L
.29761 .30054 L
.29848 .30168 L
Mistroke
.30019 .30466 L
.3018 .3083 L
.30488 .31674 L
.30644 .3212 L
.30816 .32572 L
.30894 .3275 L
.30978 .32915 L
.31058 .33039 L
.31096 .33086 L
.31131 .33122 L
.31169 .33152 L
.3119 .33165 L
.3121 .33174 L
.31219 .33177 L
.31228 .3318 L
.31236 .33182 L
.31245 .33184 L
.31255 .33185 L
.31265 .33185 L
.31274 .33185 L
.31283 .33184 L
.31293 .33183 L
.31299 .33181 L
.31304 .3318 L
.31324 .33173 L
.31335 .33168 L
.31347 .33161 L
.31368 .33147 L
.31411 .33107 L
.31449 .33059 L
.31528 .32924 L
.31601 .32753 L
.31767 .32209 L
.31931 .31478 L
.3208 .30679 L
.324 .28778 L
.32547 .27962 L
.32631 .27552 L
.32709 .27217 L
.32792 .26927 L
.32868 .2673 L
.3291 .26652 L
.32929 .26624 L
.32949 .266 L
.32961 .26589 L
.32971 .26581 L
.32981 .26574 L
.32991 .26569 L
.32997 .26567 L
.33002 .26565 L
Mistroke
.33008 .26563 L
.33015 .26563 L
.3302 .26562 L
.33026 .26562 L
.33032 .26563 L
.33037 .26564 L
.33046 .26567 L
.33055 .26571 L
.33065 .26576 L
.33075 .26584 L
.33097 .26605 L
.33116 .26631 L
.33152 .26693 L
.3319 .26781 L
.33269 .27041 L
.33357 .27441 L
.33514 .2846 L
.33682 .29914 L
.34015 .33443 L
.34182 .35205 L
.34336 .366 L
.34413 .37169 L
.34486 .37599 L
.34525 .37786 L
.34562 .37926 L
.34602 .38046 L
.34624 .38095 L
.34634 .38113 L
.34645 .38129 L
.34656 .38143 L
.34666 .38153 L
.34675 .3816 L
.34685 .38164 L
.34694 .38166 L
.34703 .38166 L
.34712 .38163 L
.34722 .38158 L
.34732 .38149 L
.34744 .38136 L
.34765 .38104 L
.34785 .3806 L
.34804 .3801 L
.34838 .37893 L
.34876 .37726 L
.34952 .37266 L
.35033 .36597 L
.35107 .35831 L
.35275 .33624 L
.35593 .28237 L
.35899 .23156 L
Mistroke
.35981 .22091 L
.36057 .21259 L
.36099 .20881 L
.36145 .20544 L
.36187 .20306 L
.36207 .20216 L
.36225 .20148 L
.36245 .20092 L
.36263 .20052 L
.36273 .20037 L
.36282 .20026 L
.36293 .20019 L
.36298 .20017 L
.36303 .20016 L
.36313 .20018 L
.36321 .20023 L
.36331 .20032 L
.36341 .20046 L
.3635 .20062 L
.36358 .2008 L
.36376 .20131 L
.36398 .2021 L
.36418 .20304 L
.36456 .2053 L
.36497 .20846 L
.36542 .21274 L
.36618 .22199 L
.36701 .23493 L
.3687 .26872 L
.37194 .35029 L
.37343 .38776 L
.37505 .42262 L
.37593 .43732 L
.37636 .44315 L
.37675 .44761 L
.37712 .45113 L
.37753 .45403 L
.37775 .4552 L
.37785 .45563 L
.37796 .45602 L
.37805 .45631 L
.37815 .45656 L
.37821 .45667 L
.37826 .45675 L
.37836 .45687 L
.37846 .45692 L
.37854 .45692 L
.37864 .45686 L
.37875 .45672 L
.37885 .45652 L
Mistroke
.37896 .45623 L
.37916 .45552 L
.37934 .45464 L
.37951 .45363 L
.37989 .45065 L
.38032 .44628 L
.3807 .44133 L
.38156 .42694 L
.3831 .39081 L
.38477 .3399 L
.38806 .22676 L
.38969 .17769 L
.39049 .1583 L
.39122 .14402 L
.39158 .13832 L
.39197 .1332 L
.39234 .12945 L
.39251 .12812 L
.39269 .12694 L
.39279 .12635 L
.39289 .1259 L
.39299 .12554 L
.39309 .12523 L
.39318 .12503 L
.39326 .12491 L
.39335 .12484 L
.39345 .12484 L
.39356 .12494 L
.39361 .12503 L
.39367 .12514 L
.39377 .12541 L
.39388 .1258 L
.39406 .12669 L
.39426 .128 L
.39468 .1318 L
.39508 .13677 L
.39582 .1496 L
.39662 .16827 L
.3975 .19388 L
.40076 .32206 L
.40226 .38651 L
.4039 .44881 L
.40479 .47669 L
.40561 .49705 L
.40602 .50498 L
.4064 .51103 L
.4068 .51586 L
.40701 .5178 L
.40711 .51861 L
.40723 .51938 L
Mistroke
.40733 .51991 L
.40744 .52038 L
.4075 .52058 L
.40755 .52074 L
.40766 .52096 L
.40775 .52106 L
.40785 .52107 L
.40795 .52097 L
.40805 .52078 L
.4081 .52063 L
.40816 .52042 L
.40827 .51996 L
.40848 .51875 L
.40872 .5168 L
.40894 .51447 L
.40931 .50939 L
.40972 .50218 L
.41055 .4826 L
.41137 .45739 L
.41211 .42976 L
.41379 .35559 L
.41544 .27432 L
.41698 .20156 L
.41774 .16934 L
.41856 .13889 L
.41928 .11668 L
.42005 .09871 L
.42046 .09159 L
.42067 .08857 L
.42091 .08593 L
.42112 .08404 L
.42131 .08279 L
.42141 .08234 L
.42151 .08197 L
.42161 .08173 L
.4217 .08161 L
.42178 .08158 L
.42187 .08165 L
.42196 .0818 L
.42204 .08202 L
.42213 .08235 L
.42223 .08282 L
.42242 .0841 L
.42261 .08581 L
.42282 .08811 L
.42319 .09348 L
.42362 .10164 L
.42401 .11095 L
.42491 .13787 L
.42652 .20434 L
Mistroke
.42969 .367 L
.43128 .44312 L
.43198 .47127 L
.43273 .49709 L
.43315 .50885 L
.43353 .51805 L
.43393 .52567 L
.4343 .53117 L
.43448 .53331 L
.43468 .53515 L
.43479 .53594 L
.4349 .53661 L
.435 .53706 L
.43505 .53724 L
.43511 .53741 L
.43517 .53754 L
.43522 .53762 L
.43533 .53768 L
.43538 .53765 L
.43545 .53757 L
.4355 .53747 L
.43556 .53731 L
.43566 .53693 L
.43577 .53637 L
.43597 .53496 L
.43618 .53303 L
.43639 .5304 L
.43678 .52423 L
.43725 .51455 L
.43767 .50366 L
.43928 .44556 L
.4425 .28367 L
.44397 .2095 L
.44481 .17263 L
.44559 .14333 L
.44637 .12024 L
.4468 .11015 L
.44719 .10285 L
.44761 .0972 L
.44785 .09495 L
.44796 .09412 L
.44806 .09349 L
.44815 .09305 L
.44825 .09269 L
.44831 .09255 L
.44836 .09244 L
.44846 .09234 L
.44857 .09238 L
.44866 .09253 L
.44872 .09267 L
Mistroke
.44877 .09284 L
.44889 .09332 L
.44898 .09386 L
.44907 .09446 L
.44927 .0962 L
.44947 .09839 L
.44969 .10128 L
.45043 .11542 L
.45087 .12696 L
.4513 .13984 L
.45209 .16851 L
.45516 .31299 L
.45688 .39522 L
.45843 .45527 L
.45921 .47736 L
.45965 .487 L
.46005 .49396 L
.46041 .49853 L
.46061 .50046 L
.46079 .50184 L
.4609 .50241 L
.46099 .50284 L
.46108 .50313 L
.46117 .50334 L
.46127 .50345 L
.46133 .50346 L
.46138 .50343 L
.46148 .50329 L
.46158 .50305 L
.46167 .50271 L
.46177 .50222 L
.46196 .50103 L
.46217 .49912 L
.46237 .49692 L
.4628 .49062 L
.4632 .48285 L
.46391 .46508 L
.46469 .44065 L
.46798 .3015 L
.46961 .232 L
.47041 .20304 L
.47114 .18081 L
.4715 .17152 L
.4719 .16281 L
.47224 .15651 L
.47261 .15093 L
.4728 .14865 L
.47301 .14663 L
.47312 .14571 L
.47323 .14498 L
Mistroke
.47333 .14437 L
.47343 .1439 L
.47352 .14359 L
.47361 .14333 L
.47371 .14315 L
.4738 .14309 L
.4739 .14312 L
.474 .14326 L
.4741 .1435 L
.47419 .14381 L
.47429 .14425 L
.47438 .14478 L
.47456 .14601 L
.47476 .14771 L
.47497 .15 L
.47569 .16125 L
.47611 .16987 L
.47655 .18065 L
.47735 .20369 L
.48069 .32708 L
.48236 .38499 L
.4831 .40558 L
.48391 .4236 L
.48428 .43018 L
.48469 .43587 L
.48488 .4381 L
.48507 .4399 L
.48523 .44123 L
.48541 .44242 L
.4856 .44333 L
.48571 .44369 L
.48581 .44394 L
.4859 .44408 L
.48598 .44415 L
.48608 .44415 L
.48617 .44406 L
.48627 .44388 L
.48638 .44359 L
.48648 .44323 L
.48657 .44282 L
.48679 .4415 L
.487 .43987 L
.48737 .43604 L
.48778 .43051 L
.48861 .4155 L
.49009 .37817 L
.49179 .32613 L
.49333 .27846 L
.4941 .25731 L
.49493 .23741 L
Mistroke
.49572 .22237 L
.4961 .21659 L
.49645 .21219 L
.49686 .20818 L
.49707 .20657 L
.4973 .20525 L
.4974 .20481 L
.4975 .20442 L
.49759 .20415 L
.49768 .20391 L
.49774 .20381 L
.4978 .20373 L
.49785 .20368 L
.4979 .20364 L
.498 .20364 L
.4981 .20371 L
.4982 .20386 L
.4983 .20407 L
.49838 .20431 L
.49847 .20463 L
.49868 .20558 L
.49887 .20674 L
.49922 .2095 L
.4996 .21336 L
.50042 .22492 L
.50131 .24145 L
.50293 .27856 L
.5045 .31722 L
.50533 .3364 L
.50622 .35459 L
.50708 .36893 L
.50786 .37873 L
.50824 .38223 L
.50844 .38375 L
.50865 .3851 L
.50883 .38607 L
.50903 .3869 L
.50912 .38719 L
.50922 .38744 L
.50931 .38764 L
.50939 .38777 L
.5095 .38788 L
.50959 .38792 L
.50968 .38792 L
.50977 .38786 L
.50988 .38774 L
.50993 .38766 L
.50998 .38755 L
.51018 .38703 L
.51036 .38635 L
Mistroke
.51056 .38542 L
.51091 .3832 L
.51136 .3795 L
.51178 .37511 L
.51257 .36483 L
.51564 .31091 L
.51736 .28167 L
.51816 .27053 L
.51891 .26238 L
.51928 .25915 L
.51969 .2563 L
.5201 .25417 L
.52032 .25333 L
.52042 .25302 L
.52053 .25274 L
.52063 .25252 L
.52073 .25237 L
.52082 .25226 L
.52091 .25218 L
.521 .25214 L
.52108 .25214 L
.52117 .25217 L
.52126 .25224 L
.52136 .25235 L
.52146 .25251 L
.52157 .25274 L
.52168 .25299 L
.52205 .25431 L
.52226 .2553 L
.52246 .25637 L
.5229 .2593 L
.5237 .26626 L
.52519 .2836 L
.52683 .30556 L
.52836 .32484 L
.52911 .33282 L
.52982 .33907 L
.53022 .3419 L
.53065 .34442 L
.53104 .34621 L
.5314 .34742 L
.53159 .34789 L
.53177 .34822 L
.53186 .34835 L
.53197 .34846 L
.53202 .3485 L
.53207 .34853 L
.53217 .34857 L
.53226 .34858 L
.53237 .34856 L
Mistroke
.53246 .34851 L
.53255 .34843 L
.53263 .34834 L
.53272 .34822 L
.5329 .34791 L
.53311 .3474 L
.53331 .34682 L
.53375 .34511 L
.53455 .34073 L
.53607 .32888 L
.53774 .31335 L
.53945 .29823 L
.54026 .29238 L
.541 .28807 L
.54137 .28634 L
.54178 .2848 L
.54219 .28364 L
.54241 .28316 L
.54262 .28282 L
.54271 .2827 L
.54282 .2826 L
.54291 .28252 L
.543 .28246 L
.54308 .28243 L
.54317 .28241 L
.54327 .28241 L
.54335 .28243 L
.54345 .28247 L
.54355 .28253 L
.54364 .2826 L
.54373 .2827 L
.54394 .28298 L
.54414 .28333 L
.54455 .2843 L
.54499 .2857 L
.54578 .28906 L
.54728 .29741 L
.54884 .30739 L
.54967 .31247 L
.55056 .31733 L
.55142 .32118 L
.5522 .32382 L
.55257 .32477 L
.55277 .32518 L
.55298 .32555 L
.55318 .32584 L
.55337 .32605 L
.55346 .32613 L
.55355 .3262 L
.55364 .32626 L
Mistroke
.55373 .3263 L
.55383 .32633 L
.55392 .32635 L
.55402 .32635 L
.55407 .32635 L
.55412 .32634 L
.55421 .32632 L
.5543 .32628 L
.5544 .32623 L
.55449 .32617 L
.5547 .32598 L
.5549 .32576 L
.55533 .32506 L
.55574 .32418 L
.5562 .32298 L
.55702 .32031 L
.55873 .31348 L
.56028 .30711 L
.56106 .30429 L
.5619 .30173 L
.56228 .30076 L
.56269 .29989 L
.56307 .29923 L
.56342 .29874 L
.56361 .29853 L
.56382 .29835 L
.56401 .29822 L
.56418 .29814 L
.56428 .2981 L
.56437 .29808 L
.56447 .29806 L
.56453 .29806 L
.56458 .29806 L
.56467 .29806 L
.56473 .29807 L
.56478 .29808 L
.56489 .2981 L
.565 .29814 L
.56519 .29824 L
.56539 .29838 L
.56577 .29873 L
.56613 .29919 L
.56647 .29971 L
.56797 .30287 L
.56963 .30722 L
.57132 .31145 L
.57212 .31308 L
.57287 .31428 L
.57327 .31479 L
.57363 .31516 L
Mistroke
.57403 .31546 L
.57425 .31558 L
.57435 .31563 L
.57446 .31567 L
.57455 .31569 L
.57465 .31572 L
.57475 .31574 L
.57484 .31575 L
.57494 .31575 L
.57503 .31575 L
.5751 .31575 L
.57519 .31574 L
.57529 .31572 L
.57539 .3157 L
.5755 .31567 L
.5756 .31563 L
.5758 .31554 L
.57598 .31544 L
.57636 .31518 L
.57677 .3148 L
.5776 .31383 L
.57909 .31157 L
.58059 .30909 L
.58222 .30679 L
.58266 .30631 L
.58312 .30588 L
.58354 .30555 L
.58394 .30531 L
.58431 .30515 L
.58452 .30508 L
.58471 .30504 L
.58482 .30502 L
.58492 .305 L
.58498 .305 L
.58503 .30499 L
.58509 .30499 L
.58514 .30499 L
.58525 .30499 L
.58534 .30499 L
.58545 .305 L
.5855 .30501 L
.58556 .30501 L
.58576 .30505 L
.58587 .30508 L
.58598 .3051 L
.58638 .30525 L
.58674 .30543 L
.58713 .30566 L
.58881 .30706 L
.59039 .30863 L
Mistroke
.59185 .30994 L
.59259 .31048 L
.5934 .31094 L
.59385 .31112 L
.59407 .31119 L
.59426 .31124 L
.59445 .31129 L
.59466 .31132 L
.59477 .31134 L
.59487 .31135 L
.59497 .31136 L
.59508 .31136 L
.59518 .31137 L
.59523 .31137 L
.59528 .31137 L
.59538 .31136 L
.59548 .31136 L
.59557 .31135 L
.59565 .31135 L
.59584 .31133 L
.59604 .31129 L
.59623 .31126 L
.59666 .31115 L
.59737 .31089 L
.59813 .31053 L
.60119 .3088 L
.602 .30841 L
.60276 .3081 L
.60318 .30797 L
.60364 .30785 L
.60384 .30781 L
.60406 .30777 L
.60424 .30774 L
.60444 .30772 L
.60455 .30771 L
.60464 .3077 L
.60475 .30769 L
.60484 .30769 L
.60493 .30768 L
.60501 .30768 L
.6051 .30768 L
.6052 .30768 L
.6053 .30768 L
.60535 .30768 L
.60541 .30768 L
.60551 .30769 L
.60562 .3077 L
.60583 .30771 L
.60601 .30773 L
.60637 .30778 L
Mistroke
.60677 .30785 L
.60748 .30801 L
.60904 .30849 L
.61076 .30906 L
.61154 .30929 L
.61239 .30949 L
.61278 .30957 L
.61319 .30963 L
.61356 .30968 L
.61392 .30972 L
.61411 .30973 L
.61432 .30975 L
.61441 .30975 L
.61451 .30975 L
.61459 .30976 L
.61468 .30976 L
.61474 .30976 L
.61479 .30976 L
.61489 .30976 L
.61499 .30976 L
.61505 .30976 L
.61511 .30976 L
.6152 .30976 L
.6153 .30975 L
.6154 .30975 L
.6155 .30975 L
.61587 .30972 L
.61621 .3097 L
.61698 .30961 L
.6185 .30936 L
.62016 .30905 L
.62173 .3088 L
.62218 .30874 L
.62261 .3087 L
.62299 .30867 L
.62319 .30865 L
.62341 .30864 L
.62362 .30863 L
.62381 .30862 L
.6239 .30862 L
.624 .30862 L
.6241 .30862 L
.62419 .30862 L
.62424 .30862 L
.6243 .30861 L
.6244 .30861 L
.62445 .30861 L
.62451 .30861 L
.62462 .30861 L
.62471 .30861 L
Mistroke
.62481 .30862 L
.62491 .30862 L
.62501 .30862 L
.6252 .30862 L
.62541 .30863 L
.62579 .30865 L
.62649 .30869 L
.62725 .30876 L
.62808 .30884 L
.62977 .30901 L
.63053 .30908 L
.63132 .30914 L
.63174 .30917 L
.6322 .30919 L
.63261 .30921 L
.633 .30922 L
.63321 .30922 L
.6334 .30923 L
.63351 .30923 L
.63362 .30923 L
.63367 .30923 L
.63373 .30923 L
.63379 .30923 L
.63384 .30923 L
.63394 .30923 L
.63404 .30923 L
.63414 .30923 L
.6342 .30923 L
.63425 .30923 L
.63435 .30923 L
.63445 .30923 L
.63464 .30923 L
.63482 .30922 L
.63502 .30922 L
.63542 .30921 L
.63613 .30918 L
.63783 .3091 L
.63938 .30901 L
.64015 .30898 L
.64099 .30894 L
.64138 .30893 L
.64178 .30892 L
.64213 .30891 L
.64233 .30891 L
.64251 .30891 L
.64271 .30891 L
.64282 .30891 L
.64293 .30891 L
.64298 .30891 L
.64304 .30891 L
Mistroke
.64314 .30891 L
.64323 .30891 L
.64333 .30891 L
.64341 .30891 L
.6435 .30891 L
.64359 .30891 L
.64369 .30891 L
.64379 .30891 L
.64389 .30891 L
.64407 .30891 L
.64449 .30891 L
.64487 .30892 L
.64574 .30894 L
.64737 .30898 L
.6489 .30903 L
.64961 .30904 L
.65035 .30906 L
.65074 .30906 L
.65117 .30907 L
.65136 .30907 L
.65156 .30907 L
.65173 .30907 L
.65192 .30907 L
.65202 .30907 L
.65213 .30907 L
.65219 .30907 L
.65225 .30907 L
.6523 .30907 L
.65235 .30907 L
.65245 .30907 L
.65255 .30907 L
.65265 .30907 L
.65275 .30907 L
.65281 .30907 L
.65286 .30907 L
.65299 .30907 L
.65321 .30907 L
.65342 .30907 L
.65364 .30907 L
.65441 .30906 L
.65525 .30905 L
.65695 .30903 L
.6585 .30901 L
.65927 .309 L
.65968 .309 L
.66011 .30899 L
.66048 .30899 L
.6607 .30899 L
.6609 .30899 L
.66108 .30899 L
Mistroke
.66125 .30899 L
.66134 .30899 L
.66143 .30899 L
.66153 .30899 L
.66163 .30899 L
.66173 .30899 L
.66178 .30899 L
.66184 .30899 L
.66194 .30899 L
.66203 .30899 L
.66225 .30899 L
.66247 .30899 L
.66289 .30899 L
.66327 .30899 L
.66477 .309 L
.66642 .30901 L
.66715 .30902 L
.66796 .30902 L
.66833 .30903 L
.66873 .30903 L
.66907 .30903 L
.66945 .30903 L
.66966 .30903 L
.66985 .30903 L
.67006 .30903 L
.67017 .30903 L
.67027 .30903 L
.67037 .30903 L
.67046 .30903 L
.67056 .30903 L
.67066 .30903 L
.67076 .30903 L
.67084 .30903 L
.67093 .30903 L
.67103 .30903 L
.67124 .30903 L
.67145 .30903 L
.67184 .30903 L
.67231 .30903 L
.67273 .30903 L
.67434 .30902 L
.67602 .30902 L
.67675 .30901 L
.67714 .30901 L
.67756 .30901 L
.67797 .30901 L
.67834 .30901 L
.67852 .30901 L
.67871 .30901 L
.67889 .30901 L
Mistroke
.67906 .30901 L
.67915 .30901 L
.67925 .30901 L
.67935 .30901 L
.67943 .30901 L
.67952 .30901 L
.67963 .30901 L
.67968 .30901 L
.67973 .30901 L
.67983 .30901 L
.67994 .30901 L
.68006 .30901 L
.68026 .30901 L
.68065 .30901 L
.68105 .30901 L
.68141 .30901 L
.68225 .30901 L
.68394 .30902 L
.68477 .30902 L
.68557 .30902 L
.68628 .30902 L
.68668 .30902 L
.68706 .30902 L
.68727 .30902 L
.68746 .30902 L
.68768 .30902 L
.68779 .30902 L
.68785 .30902 L
.68791 .30902 L
.68801 .30902 L
.68811 .30902 L
.68821 .30902 L
.68827 .30902 L
.68832 .30902 L
.68841 .30902 L
.68851 .30902 L
.68861 .30902 L
.68871 .30902 L
.68889 .30902 L
.68908 .30902 L
.68943 .30902 L
.6902 .30902 L
.69326 .30902 L
.69408 .30902 L
.69484 .30902 L
.69527 .30902 L
.69549 .30902 L
.69572 .30902 L
.69592 .30902 L
.69614 .30902 L
Mistroke
.69624 .30902 L
.69634 .30902 L
.69644 .30902 L
.69652 .30902 L
.69662 .30902 L
.69667 .30902 L
.69673 .30902 L
.69679 .30902 L
.69684 .30902 L
.69695 .30902 L
.69705 .30902 L
.69714 .30902 L
.69723 .30902 L
.69734 .30902 L
.69758 .30902 L
.69781 .30902 L
.69823 .30902 L
.699 .30902 L
.69984 .30902 L
.70141 .30902 L
.70223 .30902 L
.70269 .30902 L
.70313 .30902 L
.70353 .30902 L
.70398 .30902 L
.70417 .30902 L
.70438 .30902 L
.70458 .30902 L
.70476 .30902 L
.70485 .30902 L
.70496 .30902 L
.70506 .30902 L
.70512 .30902 L
.70517 .30902 L
.70527 .30902 L
.70536 .30902 L
.70546 .30902 L
.70556 .30902 L
.70565 .30902 L
.70574 .30902 L
.70591 .30902 L
.70609 .30902 L
.70629 .30902 L
.70668 .30902 L
.7071 .30902 L
.70784 .30902 L
.70951 .30902 L
.71034 .30902 L
.71112 .30902 L
.71182 .30902 L
Mistroke
.71221 .30902 L
.71258 .30902 L
.71294 .30902 L
.71315 .30902 L
.71334 .30902 L
.71345 .30902 L
.71355 .30902 L
.71363 .30902 L
.71373 .30902 L
.71384 .30902 L
.7139 .30902 L
.71395 .30902 L
.71405 .30902 L
.71415 .30902 L
.71425 .30902 L
.71436 .30902 L
.71457 .30902 L
.71496 .30902 L
.71541 .30902 L
.71583 .30902 L
.71733 .30902 L
.71896 .30902 L
.71985 .30902 L
.72024 .30902 L
.72067 .30902 L
.72087 .30902 L
.72108 .30902 L
.72126 .30902 L
.72146 .30902 L
.72157 .30902 L
.72168 .30902 L
.72178 .30902 L
.72183 .30902 L
.72189 .30902 L
.72195 .30902 L
.722 .30902 L
.7221 .30902 L
.72219 .30902 L
.72229 .30902 L
.72239 .30902 L
.72244 .30902 L
.72249 .30902 L
.72269 .30902 L
.72286 .30902 L
.72305 .30902 L
.72344 .30902 L
.72386 .30902 L
.72534 .30902 L
.72702 .30902 L
.72776 .30902 L
Mistroke
.72815 .30902 L
.72856 .30902 L
.72897 .30902 L
.72935 .30902 L
.72953 .30902 L
.72972 .30902 L
.72991 .30902 L
.72999 .30902 L
.73008 .30902 L
.73017 .30902 L
.73027 .30902 L
.73036 .30902 L
.73044 .30902 L
.73054 .30902 L
.73064 .30902 L
.73074 .30902 L
.73085 .30902 L
.73096 .30902 L
.73107 .30902 L
.73128 .30902 L
.73167 .30902 L
.73243 .30902 L
.73327 .30902 L
.73496 .30902 L
.73577 .30902 L
.73653 .30902 L
.73695 .30902 L
.73717 .30902 L
.73741 .30902 L
.73761 .30902 L
.73783 .30902 L
.73803 .30902 L
.73812 .30902 L
.73821 .30902 L
.73831 .30902 L
.73841 .30902 L
.7385 .30902 L
.73859 .30902 L
.73869 .30902 L
.73879 .30902 L
.73889 .30902 L
.73894 .30902 L
.739 .30902 L
.73921 .30902 L
.73943 .30902 L
.73983 .30902 L
.74061 .30902 L
.74132 .30902 L
.74298 .30902 L
.74371 .30902 L
Mistroke
.7441 .30902 L
.74452 .30902 L
.74492 .30902 L
.74528 .30902 L
.74563 .30902 L
.74581 .30902 L
.746 .30902 L
.74611 .30902 L
.74621 .30902 L
.7463 .30902 L
.7464 .30902 L
.74651 .30902 L
.7466 .30902 L
.74671 .30902 L
.74677 .30902 L
.74682 .30902 L
.74692 .30902 L
.74702 .30902 L
.7471 .30902 L
.74719 .30902 L
.7474 .30902 L
.74759 .30902 L
.748 .30902 L
.74844 .30902 L
.74924 .30902 L
.75073 .30902 L
.75156 .30902 L
.75233 .30902 L
.75275 .30902 L
.75314 .30902 L
.75357 .30902 L
.7538 .30902 L
.75402 .30902 L
.75411 .30902 L
.75421 .30902 L
.7543 .30902 L
.75439 .30902 L
.7545 .30902 L
.75455 .30902 L
.7546 .30902 L
.7547 .30902 L
.7548 .30902 L
.75485 .30902 L
.7549 .30902 L
.75496 .30902 L
.75502 .30902 L
.75523 .30902 L
.75542 .30902 L
.75562 .30902 L
.75599 .30902 L
Mistroke
.75639 .30902 L
.7571 .30902 L
.75869 .30902 L
.75952 .30902 L
.75998 .30902 L
.76041 .30902 L
.76083 .30902 L
.76128 .30902 L
.76148 .30902 L
.76169 .30902 L
.76187 .30902 L
.76207 .30902 L
.76218 .30902 L
.76227 .30902 L
.76236 .30902 L
.76246 .30902 L
.76256 .30902 L
.76261 .30902 L
.76267 .30902 L
.76277 .30902 L
.76287 .30902 L
.76296 .30902 L
.76305 .30902 L
.76322 .30902 L
.76341 .30902 L
.76361 .30902 L
.76403 .30902 L
.76443 .30902 L
.76519 .30902 L
.76687 .30902 L
.76765 .30902 L
.76808 .30902 L
.76848 .30902 L
.76885 .30902 L
.76919 .30902 L
.76956 .30902 L
.76977 .30902 L
.76986 .30902 L
.76996 .30902 L
.77006 .30902 L
.77015 .30902 L
.77024 .30902 L
.77033 .30902 L
.77043 .30902 L
.77052 .30902 L
.77063 .30902 L
.77068 .30902 L
.77074 .30902 L
.77084 .30902 L
.77094 .30902 L
Mistroke
.77116 .30902 L
.77135 .30902 L
.77156 .30902 L
.77226 .30902 L
.77304 .30902 L
.77473 .30902 L
.77553 .30902 L
.77627 .30902 L
.77664 .30902 L
.77704 .30902 L
.77726 .30902 L
.77747 .30902 L
.77766 .30902 L
.77777 .30902 L
.77787 .30902 L
.77796 .30902 L
.77805 .30902 L
.77814 .30902 L
.77822 .30902 L
.77832 .30902 L
.77842 .30902 L
.77852 .30902 L
.77861 .30902 L
.77879 .30902 L
.77899 .30902 L
.77939 .30902 L
.77978 .30902 L
.7802 .30902 L
.78094 .30902 L
.78262 .30902 L
.78338 .30902 L
.78381 .30902 L
.7842 .30902 L
.78458 .30902 L
.78477 .30902 L
.78498 .30902 L
.78515 .30902 L
.78534 .30902 L
.78543 .30902 L
.78552 .30902 L
.7856 .30902 L
.78568 .30902 L
.78578 .30902 L
.78583 .30902 L
.78588 .30902 L
.78594 .30902 L
.786 .30902 L
.7861 .30902 L
.7862 .30902 L
.78629 .30902 L
Mistroke
.78639 .30902 L
.78649 .30902 L
.78673 .30902 L
.78696 .30902 L
.78738 .30902 L
.78899 .30902 L
.79046 .30902 L
.7913 .30902 L
.7917 .30902 L
.79208 .30902 L
.79227 .30902 L
.79247 .30902 L
.79267 .30902 L
.79285 .30902 L
.79305 .30902 L
.79317 .30902 L
.79322 .30902 L
.79327 .30902 L
.79337 .30902 L
.79346 .30902 L
.79356 .30902 L
.79362 .30902 L
.79367 .30902 L
.79378 .30902 L
.79383 .30902 L
.79389 .30902 L
.7941 .30902 L
.79429 .30902 L
.79449 .30902 L
.7949 .30902 L
.79536 .30902 L
.79704 .30902 L
.79778 .30902 L
.79859 .30902 L
.79896 .30902 L
.79937 .30902 L
.79975 .30902 L
.8001 .30902 L
.8003 .30902 L
.80049 .30902 L
.8006 .30902 L
.8007 .30902 L
.8008 .30902 L
.80086 .30902 L
.80092 .30902 L
.80102 .30902 L
.80107 .30902 L
.80113 .30902 L
.80122 .30902 L
.80132 .30902 L
Mistroke
.80142 .30902 L
.80152 .30902 L
.80169 .30902 L
.80189 .30902 L
.80207 .30902 L
.80248 .30902 L
.80331 .30902 L
.80479 .30902 L
.80563 .30902 L
.80643 .30902 L
.80677 .30902 L
.80714 .30902 L
.80733 .30902 L
.80754 .30902 L
.80774 .30902 L
.80792 .30902 L
.80811 .30902 L
.80821 .30902 L
.80831 .30902 L
.80837 .30902 L
.80843 .30902 L
.80853 .30902 L
.80863 .30902 L
.80873 .30902 L
.80882 .30902 L
.8089 .30902 L
.80899 .30902 L
.80909 .30902 L
.80929 .30902 L
.80947 .30902 L
.80989 .30902 L
.81033 .30902 L
.81115 .30902 L
.8127 .30902 L
.81353 .30902 L
.81396 .30902 L
.81442 .30902 L
.81482 .30902 L
.81505 .30902 L
.81527 .30902 L
.81537 .30902 L
.81546 .30902 L
.81555 .30902 L
.81564 .30902 L
.81574 .30902 L
.81583 .30902 L
.81593 .30902 L
.81599 .30902 L
.81604 .30902 L
.81614 .30902 L
Mistroke
.81624 .30902 L
.81634 .30902 L
.81643 .30902 L
.8166 .30902 L
.81678 .30902 L
.81719 .30902 L
.81757 .30902 L
.81925 .30902 L
.81998 .30902 L
.82079 .30902 L
.82116 .30902 L
.82157 .30902 L
.82191 .30902 L
.82229 .30902 L
.82251 .30902 L
.82272 .30902 L
.82292 .30902 L
.82302 .30902 L
.82307 .30902 L
.82312 .30902 L
.82322 .30902 L
.82331 .30902 L
.82341 .30902 L
.82352 .30902 L
.82361 .30902 L
.82371 .30902 L
.8238 .30902 L
.82388 .30902 L
.82407 .30902 L
.82427 .30902 L
.82468 .30902 L
.82542 .30902 L
.82709 .30902 L
.8279 .30902 L
.82866 .30902 L
.82908 .30902 L
.8293 .30902 L
.82953 .30902 L
.82975 .30902 L
.82995 .30902 L
.83004 .30902 L
.83015 .30902 L
.83024 .30902 L
.83033 .30902 L
.83043 .30902 L
.83052 .30902 L
.83062 .30902 L
.83068 .30902 L
.83073 .30902 L
.83081 .30902 L
Mistroke
.83091 .30902 L
.83101 .30902 L
.8311 .30902 L
.83131 .30902 L
.8315 .30902 L
.83194 .30902 L
.83281 .30902 L
.83363 .30902 L
.83446 .30902 L
.83524 .30902 L
.83594 .30902 L
.83633 .30902 L
.8367 .30902 L
.83687 .30902 L
.83706 .30902 L
.83727 .30902 L
.83737 .30902 L
.83746 .30902 L
.83757 .30902 L
.83762 .30902 L
.83768 .30902 L
.83778 .30902 L
.83783 .30902 L
.83789 .30902 L
.83798 .30902 L
.83807 .30902 L
.83817 .30902 L
.83827 .30902 L
.83847 .30902 L
.83869 .30902 L
.83908 .30902 L
.83996 .30902 L
.84155 .30902 L
.8424 .30902 L
.84286 .30902 L
.84329 .30902 L
.84367 .30902 L
.84408 .30902 L
.84432 .30902 L
.84443 .30902 L
.84454 .30902 L
.84464 .30902 L
.84474 .30902 L
.84484 .30902 L
.8449 .30902 L
.84496 .30902 L
.84505 .30902 L
.84514 .30902 L
.84525 .30902 L
.84534 .30902 L
Mistroke
.84543 .30902 L
.84551 .30902 L
.8457 .30902 L
.84589 .30902 L
.84611 .30902 L
.8465 .30902 L
.84805 .30902 L
.84888 .30902 L
.84977 .30902 L
.85019 .30902 L
.85062 .30902 L
.85099 .30902 L
.8512 .30902 L
.8514 .30902 L
.8515 .30902 L
.8516 .30902 L
.85169 .30902 L
.85179 .30902 L
.85187 .30902 L
.85197 .30902 L
.85206 .30902 L
.85214 .30902 L
.85224 .30902 L
.85234 .30902 L
.85242 .30902 L
.85252 .30902 L
.85262 .30902 L
.85273 .30902 L
.85293 .30902 L
.85332 .30902 L
.85368 .30902 L
.85449 .30902 L
.85595 .30902 L
.85669 .30902 L
.85747 .30902 L
.8577 .30902 L
.85792 .30902 L
.85813 .30902 L
.85833 .30902 L
.85852 .30902 L
.85871 .30902 L
.85882 .30902 L
.85891 .30902 L
.85902 .30902 L
.85908 .30902 L
.85913 .30902 L
.85923 .30902 L
.85933 .30902 L
.85942 .30902 L
.85951 .30902 L
Mistroke
.85962 .30902 L
.85973 .30902 L
.85992 .30902 L
.86027 .30902 L
.86066 .30902 L
.86232 .30902 L
.86312 .30902 L
.86389 .30902 L
.86431 .30902 L
.86476 .30902 L
.86497 .30902 L
.86518 .30902 L
.86536 .30902 L
.86556 .30902 L
.86576 .30902 L
.86586 .30902 L
.86596 .30902 L
.86605 .30902 L
.86613 .30902 L
.86623 .30902 L
.86632 .30902 L
.86641 .30902 L
.86652 .30902 L
.86661 .30902 L
.86671 .30902 L
.86692 .30902 L
.86713 .30902 L
.86784 .30902 L
.8686 .30902 L
.87018 .30902 L
.87062 .30902 L
.87108 .30902 L
.87151 .30902 L
.87191 .30902 L
.87211 .30902 L
.87232 .30902 L
.87254 .30902 L
.87266 .30902 L
.87277 .30902 L
.87288 .30902 L
.87298 .30902 L
.87307 .30902 L
.87316 .30902 L
.87327 .30902 L
.87332 .30902 L
.87338 .30902 L
.87349 .30902 L
.87358 .30902 L
.87378 .30902 L
.87397 .30902 L
Mistroke
.87431 .30902 L
.8751 .30902 L
.87671 .30902 L
.87741 .30902 L
.87816 .30902 L
.87859 .30902 L
.87877 .30902 L
.87898 .30902 L
.87916 .30902 L
.87935 .30902 L
.87946 .30902 L
.87955 .30902 L
.87964 .30902 L
.87974 .30902 L
.87985 .30902 L
.8799 .30902 L
.87996 .30902 L
.88005 .30902 L
.88016 .30902 L
.88021 .30902 L
.88027 .30902 L
.88033 .30902 L
.88039 .30902 L
.8805 .30902 L
.88061 .30902 L
.88083 .30902 L
.88104 .30902 L
.88143 .30902 L
.88289 .30902 L
.88373 .30902 L
.88451 .30902 L
.88491 .30902 L
.88528 .30902 L
.88549 .30902 L
.88571 .30902 L
.88591 .30902 L
.88611 .30902 L
.88621 .30902 L
.88633 .30902 L
.88642 .30902 L
.88653 .30902 L
.88664 .30902 L
.88671 .30902 L
.88676 .30902 L
.88687 .30902 L
.88693 .30902 L
.88698 .30902 L
.88709 .30902 L
.88718 .30902 L
.88729 .30902 L
Mistroke
.8874 .30902 L
.88759 .30902 L
.88779 .30902 L
.88819 .30902 L
.88861 .30902 L
.88935 .30902 L
.89016 .30902 L
.89102 .30902 L
.89145 .30902 L
.89185 .30902 L
.89225 .30902 L
.89261 .30902 L
.89279 .30902 L
.89295 .30902 L
.89313 .30902 L
.89322 .30902 L
.89332 .30902 L
.89342 .30902 L
.89351 .30902 L
.8936 .30902 L
.89369 .30902 L
.89379 .30902 L
.89388 .30902 L
.89399 .30902 L
.89408 .30902 L
.89428 .30902 L
.89446 .30902 L
.89487 .30902 L
.8957 .30902 L
.89719 .30902 L
.89803 .30902 L
.89844 .30902 L
.89882 .30902 L
.89917 .30902 L
.89954 .30902 L
.89973 .30902 L
.89991 .30902 L
.90001 .30902 L
.9001 .30902 L
.90016 .30902 L
.90021 .30902 L
.90031 .30902 L
.90037 .30902 L
.90042 .30902 L
.90052 .30902 L
.90063 .30902 L
.90069 .30902 L
.90074 .30902 L
.90084 .30902 L
.90093 .30902 L
Mistroke
.90114 .30902 L
.90153 .30902 L
.90189 .30902 L
.90358 .30902 L
.90435 .30902 L
.90478 .30902 L
.90517 .30902 L
.90554 .30902 L
.90588 .30902 L
.90625 .30902 L
.90645 .30902 L
.90665 .30902 L
.90675 .30902 L
.9068 .30902 L
.90686 .30902 L
.90696 .30902 L
.90705 .30902 L
.90714 .30902 L
.90723 .30902 L
.90732 .30902 L
.90742 .30902 L
.90752 .30902 L
.90764 .30902 L
.90785 .30902 L
.90824 .30902 L
.909 .30902 L
.90971 .30902 L
.91122 .30902 L
.91164 .30902 L
.91207 .30902 L
.91245 .30902 L
.91266 .30902 L
.91286 .30902 L
.91308 .30902 L
.91329 .30902 L
.9134 .30902 L
.91351 .30902 L
.91356 .30902 L
.91362 .30902 L
.91369 .30902 L
.91375 .30902 L
.91385 .30902 L
.9139 .30902 L
.91396 .30902 L
.91406 .30902 L
.91415 .30902 L
.91426 .30902 L
.91436 .30902 L
.91458 .30902 L
.91498 .30902 L
Mistroke
.91541 .30902 L
.9162 .30902 L
.91777 .30902 L
.91819 .30902 L
.91865 .30902 L
.91909 .30902 L
.91949 .30902 L
.91968 .30902 L
.91979 .30902 L
.91989 .30902 L
.91998 .30902 L
.92007 .30902 L
.92016 .30902 L
.92026 .30902 L
.92037 .30902 L
.92046 .30902 L
.92057 .30902 L
.92062 .30902 L
.92068 .30902 L
.92078 .30902 L
.9209 .30902 L
.92111 .30902 L
.9215 .30902 L
.92191 .30902 L
.92265 .30902 L
.92347 .30902 L
.92424 .30902 L
.92493 .30902 L
.92533 .30902 L
.92569 .30902 L
.9259 .30902 L
.92609 .30902 L
.92626 .30902 L
.92645 .30902 L
.92654 .30902 L
.92665 .30902 L
.9267 .30902 L
.92676 .30902 L
.92687 .30902 L
.92697 .30902 L
.92707 .30902 L
.92715 .30902 L
.92725 .30902 L
.92735 .30902 L
.92745 .30902 L
.92767 .30902 L
.92789 .30902 L
.92812 .30902 L
.92893 .30902 L
.9305 .30902 L
Mistroke
.93094 .30902 L
.9314 .30902 L
.93183 .30902 L
.93223 .30902 L
.93243 .30902 L
.93264 .30902 L
.93285 .30902 L
.93297 .30902 L
.93309 .30902 L
.93319 .30902 L
.93329 .30902 L
.93338 .30902 L
.93348 .30902 L
.93358 .30902 L
.93364 .30902 L
.9337 .30902 L
.9338 .30902 L
.9339 .30902 L
.93408 .30902 L
.93428 .30902 L
.93463 .30902 L
.93541 .30902 L
.93701 .30902 L
.93771 .30902 L
.93808 .30902 L
.93847 .30902 L
.93866 .30902 L
.93888 .30902 L
.93909 .30902 L
.93927 .30902 L
.93946 .30902 L
.93957 .30902 L
.93967 .30902 L
.93976 .30902 L
.93984 .30902 L
.93994 .30902 L
.94004 .30902 L
.94009 .30902 L
.94015 .30902 L
.94025 .30902 L
.94037 .30902 L
.94049 .30902 L
.94071 .30902 L
.94092 .30902 L
.94172 .30902 L
.94321 .30902 L
.944 .30902 L
.94443 .30902 L
.94484 .30902 L
.94526 .30902 L
Mistroke
.94548 .30902 L
.9456 .30902 L
.94572 .30902 L
.94582 .30902 L
.94593 .30902 L
.94599 .30902 L
.94604 .30902 L
.94615 .30902 L
.94625 .30902 L
.94635 .30902 L
.94645 .30902 L
.94654 .30902 L
.94663 .30902 L
.94673 .30902 L
.94691 .30902 L
.94713 .30902 L
.94733 .30902 L
.94816 .30902 L
.94896 .30902 L
.94981 .30902 L
.95055 .30902 L
.95094 .30902 L
.95135 .30902 L
.95155 .30902 L
.95178 .30902 L
.95198 .30902 L
.95218 .30902 L
.95228 .30902 L
.95237 .30902 L
.95246 .30902 L
.95255 .30902 L
.95265 .30902 L
.95271 .30902 L
.95276 .30902 L
.95286 .30902 L
.95296 .30902 L
.95304 .30902 L
.95313 .30902 L
.95332 .30902 L
.9535 .30902 L
.95366 .30902 L
.95441 .30902 L
.95592 .30902 L
.95671 .30902 L
.95715 .30902 L
.95755 .30902 L
.95798 .30902 L
.9582 .30902 L
.95832 .30902 L
.95844 .30902 L
Mistroke
.95856 .30902 L
.95867 .30902 L
.95877 .30902 L
.95882 .30902 L
.95887 .30902 L
.95897 .30902 L
.95908 .30902 L
.95918 .30902 L
.95927 .30902 L
.95936 .30902 L
.95946 .30902 L
.95964 .30902 L
.95986 .30902 L
.96006 .30902 L
.96089 .30902 L
.96169 .30902 L
.96255 .30902 L
.96328 .30902 L
.9637 .30902 L
.96409 .30902 L
.96428 .30902 L
.96449 .30902 L
.96468 .30902 L
.96478 .30902 L
.96487 .30902 L
.96495 .30902 L
.96505 .30902 L
.96513 .30902 L
.96521 .30902 L
.9653 .30902 L
.96539 .30902 L
.96549 .30902 L
.96558 .30902 L
.96568 .30902 L
.96578 .30902 L
.96598 .30902 L
.96617 .30902 L
.96635 .30902 L
.96717 .30902 L
.96796 .30902 L
.9688 .30902 L
.96919 .30902 L
.9696 .30902 L
.96998 .30902 L
.97033 .30902 L
.97069 .30902 L
.97089 .30902 L
.97108 .30902 L
.97116 .30902 L
.97125 .30902 L
Mistroke
.97133 .30902 L
.97141 .30902 L
.9715 .30902 L
.9716 .30902 L
.97169 .30902 L
.97177 .30902 L
.97187 .30902 L
.97198 .30902 L
.97207 .30902 L
.97216 .30902 L
.97238 .30902 L
.97259 .30902 L
.97336 .30902 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{421.375, 260.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008>0001AB000`400?l00000o`00003ooooooooo
oooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo
003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooo
oooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool0
0?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooooooo
ool@ooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooo
ooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo0ol0003o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0
003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo
00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`
ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLoooo
o`00<?ooool3o`000?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?oo
ool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0
033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomco
oooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooo
oooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool3o`000?oooooo
g?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0013ooooo0_o^k^h3ooooo`;ok^k^6Oooool00ol0003oooooooooo`24
ooooo`03o`000?oooooooooo0?ooooooEOooool000_ooooo0_l000002_l@413oooooooooooo^k^ko
EEEEonk^k_ooooook^k^oeEEEOo^k^h3ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o
<S8bonk^kP[ooooo00?o0000ooooooooool0Q?ooool00ol0003oooooooooo`3ooooooeGooooo000<
ooooo`03o`000?oooooooooo00;ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0:ooooo`03o`000?oooooooooo08Cooooo
0_l0003ooooooeKooooo00000ooooooo0000o`000004o`0000;ooooo1Ol00004ooooo`03omgMgOl0
003ogMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00[ooooo
00?o0000ooooooooool0Q?ooool2o`000?ooooooE_ooool000Wooooo00CoA4A4omgMgOoooooo0000
1?ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000000[ooooo00?o0000ooooooooool0Q?ooool2o`000?ooooooE_ooool000Wo
oooo00CogMgMoeEEEOoooooo00000oooool01oo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Ooo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000002_ooool4o`0008?ooooo
0_l0000:ooooo`03o`000?oooooooooo0?ooooooBOooool000[ooooo00?oMgMgolc<c?l000000ooo
ool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooo
oa0@400:ooooo`03o`000?oooooooooo08Cooooo0_l0000:ooooo`03o`000?oooooooooo0?oooooo
BOooool000[ooooo00?ok^k^odA4A?l000003oooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL00oooool2o`0000Gooooo00?o0000ooooooooool0Q?ooool2o`0000Wooooo
0_l0003ooooood_ooooo000;ooooo`03ogMgMol0003ooooo00cooooo00?oEEEEofIVI_l000001?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`24ooooo`;o00002Oooool2o`000?ooooooBoooool002Sooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`24ooooo`;o00002Oooool2o`000?ooooooBoooool002Sooooo
0ol00005ooooo`03o`000?oooooooooo08Cooooo0_l00009ooooo`;o0000oooooom;ooooo`00:Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo08Cooooo0_l00009ooooo`;o0000oooo
oom;ooooo`00:_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo08Cooooo0_l00009
ooooo`;o0000oooooom;ooooo`00<?ooool00ol0003oooooooooo`23ooooo`03o`000?oooooo0000
00Wooooo00?o0000ooooool00000oooooom:ooooo`00<?ooool00ol0003oooooooooo`23ooooo`03
o`000?oooooo000000Wooooo00?o0000ooooool00000oooooom:ooooo`00<?ooool00ol0003ooooo
ooooo`23ooooo`03o`000?oooooo000000Wooooo00?o0000ooooool00000oooooom:ooooo`00<?oo
ool00ol0003oooooooooo`23ooooo`03o`000?oooooo000000Wooooo00?o0000ooooool00000oooo
oom:ooooo`00<?ooool3o`0008?ooooo00?o0000ooooool000002Oooool00ol0003oooooo`00003o
oooood[ooooo000`ooooo`03o`000?oooooooooo08?ooooo00?o0000ooooool000002Oooool00ol0
003oooooo`00003ooooood[ooooo000`ooooo`03o`000?oooooooooo07Sooooo00?o0000oooooooo
ool02?ooool00ol0003oooooo`000009ooooo`03o`000?oooooo00000?ooooooB_ooool0033ooooo
00?o0000ooooooooool0N?ooool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`0000So
oooo00?o0000ooooool00000oooooom:ooooo`00<?ooool00ol0003oooooooooo`1gooooo`;o0000
2_ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?ooooooB_ooool0033ooooo
00?o0000ooooooooool0Moooool2o`0000[ooooo00Co0000oooooooooooo00002?ooool00ol0003o
ooooo`00003ooooood[ooooo000`ooooo`03o`000?oooooooooo07Oooooo0_l0000:ooooo`04o`00
0?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooom:ooooo`00<?ooool00ol0003ooooo
ooooo`1gooooo`03o`000?oooooo000000Wooooo00Co0000oooooooooooo00002?ooool00ol0003o
ooooo`00003ooooood[ooooo000`ooooo`03o`000?oooooooooo07Oooooo00?o0000ooooool00000
2Oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?ooooooB_ooool0033ooooo
00?o0000ooooooooool0Moooool00ol0003oooooo`000009ooooo`04o`000?ooooooooooo`0000So
oooo00?o0000ooooool00000oooooom:ooooo`00<?ooool00ol0003oooooooooo`1gooooo`03o`00
0?oooooo000000Wooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`000009ooooo`03
o`000?oooooooooo0?oooooo?_ooool0033ooooo00?o0000ooooooooool0Moooool00ol0003ooooo
o`000009ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool000002Oooool00ol0003o
ooooooooo`3oooooockooooo000`ooooo`?o0000Moooool00ol0003oooooo`000009ooooo`04o`00
0?ooooooooooo`0000Sooooo00?o0000ooooool000002Oooool00ol0003oooooooooo`3oooooocko
oooo000`ooooo`03o`000?oooooooooo07Oooooo00?o0000ooooool000002Oooool01?l0003ooooo
ooooool00008ooooo`03o`000?oooooo000000Sooooo0_l0003ooooood3ooooo000`ooooo`03o`00
0?oooooooooo07Oooooo00?o0000ooooool000002Oooool01?l0003oooooooooool00008ooooo`03
o`000?oooooo000000Sooooo0_l0003ooooood3ooooo000`ooooo`03o`000?oooooooooo07Oooooo
00?o0000ooooool000002Oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo000000So
oooo0_l0003ooooood3ooooo000`ooooo`03o`000?oooooooooo07Oooooo00?o0000ooooool00000
2Oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo000000Sooooo00?o0000ooooool0
0000ooooooloooooo`00<?ooool00ol0003oooooooooo`1gooooo`03o`000?oooooo000000Wooooo
00Co0000oooooooooooo00001oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo0000
0?oooooo?oooool0033ooooo00?o0000ooooooooool0Moooool00ol0003oooooo`000009ooooo`04
o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003o
ooooocoooooo000`ooooo`03o`000?oooooooooo07Oooooo00?o0000ooooool000002Oooool01?l0
003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooo
ooloooooo`00<?ooool00ol0003oooooooooo`1gooooo`03o`000?oooooo000000Wooooo00Co0000
oooooooooooo00001oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?oooooo
?oooool0033ooooo00?o0000ooooooooool0Moooool00ol0003oooooo`000009ooooo`04o`000?oo
ooooooooo`0000Oooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003oooooocoo
oooo000`ooooo`03o`000?oooooooooo07Kooooo00Co0000oooooooooooo00002Oooool01?l0003o
ooooooooool00007ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooolo
ooooo`00<?ooool3o`0007Kooooo00Co0000oooooooooooo00002Oooool01?l0003oooooooooool0
0007ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000ooooooloooooo`00<?oo
ool00ol0003oooooooooo`1fooooo`04o`000?ooooooooooo`0000Wooooo00Co0000oooooooooooo
00001oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?oooooo?oooool0033o
oooo00?o0000ooooooooool0M_ooool01?l0003oooooooooool00009ooooo`04o`000?oooooooooo
o`0000Oooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003oooooocoooooo000`
ooooo`03o`000?oooooooooo07Kooooo00Co0000oooooooooooo00002Oooool01?l0003ooooooooo
ool00007ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000ooooooloooooo`00
<?ooool00ol0003oooooooooo`1fooooo`05o`000?ooooooooooooooool000002?ooool01?l0003o
ooooooooool00007ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooolo
ooooo`00<?ooool00ol0003oooooooooo`1fooooo`05o`000?ooooooooooooooool000002?ooool0
1?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000
ooooooloooooo`00<?ooool00ol0003oooooooooo`1fooooo`05o`000?ooooooooooooooool00000
2?ooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000oooo
ool00000ooooooloooooo`004?ooool2onk^kP?ooooo0_o^k^hIooooo`03o`000?oooooooooo07Ko
oooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool0
1?l0003oooooooooool00008ooooo`03o`000?oooooo00000?oooooo?oooool000Wooooo1Ol00002
ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co000000So410@oooooooooooo
k^k^oc8b<_l0003o<S8bonk^kP[ooooo00?o0000ooooooooool0M_ooool01Ol0003ooooooooooooo
oooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000So
oooo00?o0000ooooool00000ooooooloooooo`002Oooool01OnHV9So8B4Qonk^k_ooooooA4A400?o
oooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0:ooooo`03o`000?oooooooooo07Kooooo00Go0000ooooooooooooooooo`00
0007ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool00007ooooo`04
o`000?ooooooooooo`000?oooooo?oooool00003ooooool0003o000000Co00000oooool00onHV9So
8B4Qonk^kP05ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@413o
oooooooooooooooo410@00[ooooo00?o0000ooooooooool0M_ooool01Ol0003ooooooooooooooooo
000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo
00Co0000oooooooooooo0000ooooooloooooo`002oooool00onHV9So8B4Qonk^kP03ooooo`05onk^
k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000002_ooool00ol0003oooooooooo`1fooooo`05o`000?ooooooooooooooool000001oooool0
1Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo00001oooool01?l0003ooooo
ooooool0003oooooocoooooo000<ooooo`0;ogMgMomVIVKoooooooooooo^k^koEEEEonk^k_oooooo
k^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
2_ooool4o`0006[ooooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooooooo000000Oo
oooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000
oooooooooooo0000ooooooloooooo`003Oooool00ol0003oooooooooo`02onk^kP?ooooo0_o^k^h5
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400:ooooo`03o`000?oo
oooooooo06[ooooo0_l0000:ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooo
oooooooooooo000000Oooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool00008
ooooo`;o0000ooooooleooooo`002Oooool01Ol0003o^[ZjoooooonHV9So410@00kooooo00?o0000
ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo0_l00005ooooo`03o`000?oo
oooooooo06[ooooo0_l0000:ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooo
oooooooooooo000000Oooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool00008
ooooo`;o0000ooooooleooooo`002Oooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo00?oEEEE
ofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`1Zooooo`;o00002_ooool01Ol0003ooooooooooooooooo000000Oo
oooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool0
1?l0003oooooooooool00008ooooo`;o0000ooooooleooooo`00:?ooool01?l0003oooooooooool0
0004ooooo`03o`000?oooooooooo06[ooooo00?o0000ooooool000002Oooool01Ol0003ooooooooo
oooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooooooooooo
ool000001_ooool01?l0003oooooooooool00008ooooo`;o0000ooooooleooooo`00:?ooool3o`00
00Gooooo00?o0000ooooooooool0J_ooool00ol0003oooooo`000009ooooo`05o`000?oooooooooo
ooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooooooooooooooo
o`000006ooooo`04o`000?ooooooooooo`0000Sooooo0_l0003oooooocGooooo000Yooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0J_ooool00ol0003oooooo`000009ooooo`05o`00
0?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooo
ooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Sooooo0_l0003oooooocGooooo000Z
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0J_ooool00ol0003oooooo`000009
ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo
00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Sooooo0_l0003ooooo
ocGooooo000`ooooo`03o`000?oooooooooo06Wooooo00Co0000oooooooooooo00002Oooool01Ol0
003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oo
ooooooooooooool000001_ooool01?l0003oooooooooool00008ooooo`;o0000ooooooleooooo`00
<?ooool00ol0003oooooooooo`1Yooooo`04o`000?ooooooooooo`0000Wooooo00Go0000oooooooo
ooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooo
oooo000000Kooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00003oooooocGooooo
000`ooooo`03o`000?oooooooooo06Wooooo00Co0000oooooooooooo00002Oooool01Ol0003ooooo
oooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooooooo
ooooool000001_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooo00000?oooooo=Ooo
ool0033ooooo00?o0000ooooooooool0JOooool01?l0003oooooooooool00009ooooo`05o`000?oo
ooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooooooo
ooooooooo`000006ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool00000oooooole
ooooo`00<?ooool3o`0006Wooooo00Co0000oooooooooooo00002Oooool01Ol0003ooooooooooooo
oooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool0
00001_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooo00000?oooooo=Oooool0033o
oooo00?o0000ooooooooool0JOooool01?l0003oooooooooool00009ooooo`05o`000?oooooooooo
ooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooooooooooooooo
o`000006ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool00000ooooooleooooo`00
<?ooool00ol0003oooooooooo`1Yooooo`04o`000?ooooooooooo`0000Wooooo00Go0000oooooooo
ooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooo
oooo000000Kooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00003oooooocGooooo
000`ooooo`03o`000?oooooooooo06Wooooo00Co0000oooooooooooo00002Oooool01Ol0003ooooo
oooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooooooo
ooooool000001_ooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`000?oooooo
=?ooool0033ooooo00?o0000ooooooooool0JOooool01?l0003oooooooooool00009ooooo`05o`00
0?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooo
ooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003ooooooooo
ool0003oooooocCooooo000`ooooo`03o`000?oooooooooo06Wooooo00Co0000oooooooooooo0000
2Oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007oooo
o`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Kooooo00Co
0000oooooooooooo0000ooooooldooooo`00<?ooool00ol0003oooooooooo`1Yooooo`04o`000?oo
ooooooooo`0000Wooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooooooooooo
ool000001oooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`00
0006ooooo`04o`000?ooooooooooo`000?oooooo=?ooool0033ooooo00?o0000ooooooooool0JOoo
ool01?l0003oooooooooool00009ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003o
oooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?oooooo
ooooooooool000001_ooool01?l0003oooooooooool0003oooooocCooooo000`ooooo`03o`000?oo
oooooooo06Wooooo00Co0000oooooooooooo00002Oooool01Ol0003ooooooooooooooooo000000Oo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooooooo
ool000001_ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo0000oooo
ooldooooo`00<?ooool00ol0003oooooooooo`1Yooooo`04o`000?ooooooooooo`0000Wooooo00Go
0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooo
ooooo`000006ooooo`04o`000?ooooooooooo`000?oooooo=?ooool0033ooooo00?o0000oooooooo
ool0JOooool01?l0003oooooooooool00009ooooo`05o`000?ooooooooooooooool000001oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003ooooooooo
ool00007ooooo`03o`000?oooooooooo0?oooooo:_ooool0033ooooo00?o0000ooooooooool0JOoo
ool01Ol0003ooooooooooooooooo000000Sooooo00Go0000ooooooooooooooooo`000007ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?oooooooooo
o`0000Oooooo0_l0003oooooob_ooooo000`ooooo`?o0000JOooool01Ol0003ooooooooooooooooo
000000Sooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go
0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Oooooo0_l0003oooooob_o
oooo000`ooooo`03o`000?oooooooooo06Wooooo00Go0000ooooooooooooooooo`000007ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05
o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool00007ooooo`;o0000ooooool[
ooooo`00<?ooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo00001ooo
ool2o`000?oooooo:oooool0033ooooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?oo
ooooooooooooool000001Oooool00ol0003oooooo`00003oooooob_ooooo000`ooooo`03o`000?oo
oooooooo05cooooo0_l0000:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000005ooooo`04
o`000?ooooooooooo`000?oooooo:_ooool0033ooooo00?o0000ooooooooool0C_ooool2onk^kP?o
oooo0_o^k^h7ooooo`;o00002_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000000oooool2
onk^kP05o`000?ooooooooooo`000?o^k^h0H?ooool2onk^kP?ooooo0_o^k^i>ooooo`;ok^k^0ooo
ool2onk^kVcooooo000`ooooo`03o`000?oooooooooo04Sooooo00goA4A4o`000?l0003o<S8bomgM
gOooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1_l000001_ooooook^k^oc8b<_l0
003o<S8bonk^kPCooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04o`000009oa0@
4?ooooook^k^oeEEEOl0003oooooonk^k_l0003ok^k^00?ooooo1?l000002?l@413oooooooooooo^
k^ko<S8bo`000?lb<S;ok^k^>oooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`0=
odA4A?l0003o0000oc8b<_oMgMgoooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co
000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kSSooooo1Ol00002ooooo`07onk^k_mE
EEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o
<S8bonk^kUgooooo000`ooooo`03o`000?oooooooooo04_ooooo00WoMgMgoc8b<_ooooooooooonk^
k_mEEEGogMgMoeEEEOo^k^h01_ooool2o`0000;ooooo00Ko0000ogMgMonHV9SooooooiRHV?mgMgL4
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02
ooooo`05onk^k_l0003ogMgMoeEEEOl000001_ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL0?Oooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool02OmgMgOo<S8b
ooooooooooook^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0hooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01Oo^k^koEEEE
omgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
05gooooo000`ooooo`03o`000?oooooooooo04cooooo00Oo0000ooooooooooooooooomgMgOl0003o
gMgM00Oooooo0_l00002ooooo`03o`000?l@413ooooo00;ooooo00?o410@ooooooooool00_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool2
o`000003omgMgOl0003ooooo00Gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@03gooooo00?o0000ooooooooool03oooool01ol0003ooooooooooooooooogMgMo`000?oM
gMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100>Oooool00onH
V9So8B4Qonk^kP05ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@
413ooooooooooooooooo410@05gooooo000`ooooo`03o`000?oooooooooo04_ooooo00WoMgMgoc8b
<_ooooooooooonk^k_mEEEGogMgMoeEEEOo^k^h01_ooool2o`0000;ooooo0_l00003ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo00Gok^k^o`000?oMgMgoEEEEo`000006ooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`00000mooooo`03o`000?oooooooooo00kooooo00WoMgMgoc8b
<_ooooooooooonk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000>_ooool00onHV9So8B4Qonk^kP03ooooo`05onk^k_mEEEGogMgMoeEE
EOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000GOooool0
033ooooo00?o0000ooooooooool0B?ooool03Ol0003o8B4Qo`000?lb<S;oc<c<ooooooo^k^koEEEE
onk^k_ooooook^k^oeEEEOo^k^h01Oooool2o`0000;ooooo0_l00003ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`0;o`000?oooooooooo
ooooooo^k^koEEEEo`000?ooooook^k^o`000?o^k^h01Oooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool00000?Oooool00ol0003oooooooooo`0;ooooo`0=o`000?lQ8B7o0000
oc8b<_o<c<coooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`00000kooooo`0;ogMgMomVIVKoooooooooooo^k^koEEEE
onk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool00000GOooool0033ooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`03oooo
o`;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo
410@00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooooooo`;ok^k^00Go0000oooooooooooo0000onk^kP05ooooo`03o`000?oooooooooo00;ooooo
00Go410@oooooooooooooooooa0@400mooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool00oooool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooo
oooooooooa0@400looooo`03o`000?oooooooooo00;ok^k^0oooool2onk^kPGooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@05gooooo000`ooooo`?o0000B?ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00Go0000oiRHV?ooooooV9RHogMgM`04
ooooo`04o`000?ooooooooooooooo`;o00001oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`04o`000?oo
ooooooooo`0000Kooooo0_l00003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool2o`0003?o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`;o0000;_ooool01Ol0003o^[ZjoooooonHV9So
410@00kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo0_l0
001Cooooo`00<?ooool00ol0003oooooooooo`18ooooo`Co00003?ooool00omEEEGoIVIVo`000004
ooooo`05o`000?lb<S;o0000oc8b<_o^k^h01?ooool01?l0003oooooooooooooool2o`0000Oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`06o`000?oooooooooooeEEEOmV
IVKo00001Oooool01?l0003oooooooooool00004ooooo`05oeEEEOmVIVKo0000ooooool000000_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oooooo00Co0000oooooooooooo0000<?ooool00omEEEGo
IVIVo`00000=ooooo`Co00003?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01oooool01?l0003oooooooooool0000]ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?oo
ool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01oooool01?l0003ooooo
ooooool0001Booooo`00<?ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool4o`0000?ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooool000002Oooool4o`000005
ooooool0003oooooooooool00000G_ooool4o`000005ooooool0003oooooooooool00000C?ooool4
o`000005ooooool0003oooooooooool00000D_ooool0033ooooo00?o0000ooooooooool0F_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00001_oo
ool00ol0003oooooo`00000>ooooo`?o0000I?ooool3o`0005;ooooo0ol0001Cooooo`00<?ooool0
0ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool0
1?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooo
ool01?l0003oooooooooool00006ooooo`03o`000?oooooo000000oooooo00?o0000ooooooooool0
I?ooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo05;ooooo000`ooooo`03o`000?oo
oooooooo05Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Co00001_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Kooooo
00Co0000oooooooooooo00003oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo05;o
oooo00?o0000ooooooooool0DOooool0033ooooo00?o0000ooooooooool0FOooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool2o`000?oooooo6?ooool0033ooooo
00?o0000ooooooooool0C?ooool3o`0000[ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000Gooooo0ol0003Mooooo`03ogMgMomVIVKooooo02gooooo00?oIVIVogMgMooo
ool01oooool0033ooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`02o`0000Wooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooool0
0000g?ooool00ooMgMgo410@onk^kP0^ooooo`03onk^k_l@413ogMgM00Oooooo000`ooooo`03o`00
0?oooooooooo04[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000005ooooo`04o`000?ooooooooooo`00
00Kooooo0_l00031ooooo`;o00000_ooool2o`0000cooooo00?oEEEEoiRHV?ooool00_l00002oooo
o`07o`000?ooooooooooo`000?l@413ok^k^oeEEE@02o`000003odA4A?nj^[[ooooo00;ooooo00Go
V9RHo`000?l0003oA4A4okZj^P02ooooo`08onk^k_mEEEGo0000o`000?m4A4Co^[Zjooooool@4105
o`0000?ooooo00So410@oc8b<_l0003o0000oa0@4?nYZJWoQhN7ofIVIPOooooo000`ooooo`03o`00
0?oooooooooo04Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oooooooooooooo
ool000001Oooool4o`000<3ooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd<ooooo`05o`000?oo
ooooooooooooool000000_ooool02ol0003oooooooooool0003ooooooeEEEOmgMgOoooooonk^k_mg
MgOo410@00?ooooo00Go410@okZj^_o^k^koMgMgoa0@4002ooooo`06oeEEEOmgMgOoooooonk^k_mg
MgOo410@0oooool00ol0003oooooooooo`04ooooo`08o`000?nYZJWooooooooooonj^[[o0000onk^
k_l00007ooooo`00ool0002do`0000oooooo00CogMgMo`000?l@413oc<c<3Oooool01Olb<S;ooooo
oooooooooooo000000;ooooo00Ko0000oooooooooooo0000ooooool00008ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`07okZj^_n7QhOo
IVIVofIVI_l@413oooooo`000007ooooo`002_ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool02Oooool2o`0000?ooooo0ol00007ooooo`03o`000?oo
oooooooo00Gooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_ooool01_l0003oooooooooool0003oooooo`0000Cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`02ooooo`05o`000?oooooo0000ooooool000001?ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooo`000003o`0000Gooooo0ol0
0005ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0Gooooo`04onk^k_lQ8B7o410@onk^kPgooooo00Go<S8booooooooooooooooo`000002ooooo`05
o`000?ooooooooooo`000?ooool01_l00003ooooo`03o`000?oooooooooo00Cooooo1_l00003oooo
o`03o`000?oooooooooo00Cooooo00So<S8bob4Q8OmgMgOoMgMgohN7Qoo^k^koooooo`0000Oooooo
000:ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0:ooooo`Go000000?oooooo`000?ooool01oooool00ol0003oooooooooo`04ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`;o0000
1?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Ko0000oooooooooooo
0000ooooool00004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooo`000002ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooo`000003
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo01Oooooo00Co8B4QogMgMomgMgOo<S8b3Oooool01Ol0003ok^k^oooo
oooooooo000000;oc<c<00_o0000ojVYZOoMgMgo8B4QoooooomEEEGoQhN7onk^k_ooooooQhN7oc8b
<P03ooooo`03o`000?oooooooooo00Cooooo00KoEEEEohN7Qoo^k^koooooohN7Qolb<S83ooooo`03
o`000?lb<S;ogMgM00Cooooo00So0000okZj^_ooooook^k^ogMgMol0003ok^k^o`0000Oooooo000`
ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0
0004ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooo000000;ooooo00Go0000ooooooooooooooooo`000005ooooo`?o0000
C_ooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo01Kooooo0_l00002ooooo`;o0000
3?ooool03_mEEEGoMgMgooooool@413o0000ob4Q8Ol0003oMgMgoa0@4?l0003oZJVYooooooo^k^ko
EEEE0_l000001?m4A4Cok^k^ooooool@4105o`0000?ooooo00Kok^k^oeEEEOl0003o0000odA4A?o^
k^h2ooooo`;o000000CoZJVYob4Q8Ol0003o8B4Q0_ooool02?nYZJWo8B4Qo`000?l0003o<S8bo`00
0?mgMgOoEEEE1oooool0033ooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`05o`000?ooooooooooooooool000001?ooool01?l0003oooooooooool0003Pooooo`03omgMgOl@
413ok^k^01;ooooo00?o0000ooooooooool06Oooool00oo^k^ko410@omgMg@07ooooo`00<?ooool0
0ol0003oooooooooo`1Booooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00
0004ooooo`04o`000?ooooooooooo`000>7ooooo00?oMgMgofIVI_ooool04Oooool00ol0003ooooo
ooooo`0Iooooo`03ofIVI_mgMgOooooo00Oooooo000`ooooo`03o`000?oooooooooo05;ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool01?l0003oooooooooool00006ooooo`03o`000?oooooo00000?oooooo
7?ooool0033ooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`04o`000?oo
ooooooooo`0000Kooooo0_l0003ooooooagooooo000`ooooo`03o`000?oooooooooo05?ooooo00Co
0000oooooooooooo00002_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
00Co0000oooooooooooo00001_ooool2o`000?oooooo7Oooool0033ooooo00?o0000ooooooooool0
E?ooool00ol0003oooooo`00000:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001Oooool01?l0003o
ooooooooool0003oooooobGooooo000`ooooo`03o`000?oooooooooo05Cooooo0ol0000:ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05
o`000?ooooooooooooooool000001Oooool01?l0003oooooooooool0003oooooobGooooo000`oooo
o`03o`000?oooooooooo067ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000005ooooo`04o`000?oooooo
ooooo`000?oooooo9Oooool0033ooooo0ol0001Qooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001Ooo
ool00ol0003oooooo`00003oooooobKooooo000`ooooo`03o`000?oooooooooo067ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000
ooooooooooooooooo`000005ooooo`03o`000?oooooo00000?oooooo9_ooool0033ooooo00?o0000
ooooooooool0HOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool01?l0003oooooooooool00006ooooo`03o`000?oooooo00000?oooooo9_oo
ool0033ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00006ooooo`03o`000?oo
oooo00000?oooooo9_ooool0033ooooo00?o0000ooooooooool0H_ooool01Ol0003ooooooooooooo
oooo000000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00007ooooo`;o0000
oooooolVooooo`00<?ooool00ol0003oooooooooo`1Rooooo`05o`000?ooooooooooooooool00000
2?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Oooooo0_l0003oooooobKo
oooo000`ooooo`03o`000?oooooooooo06;ooooo00Go0000ooooooooooooooooo`000008ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00?ooooo00Co0000oooooooooooo0000ooooool_ooooo`00<?ooool00ol0003o
ooooooooo`1Rooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`04o`000?ooooooooooo`000?oooooo;oooool0033ooooo00?o0000ooooooooool0H_ooool01Ol0
003ooooooooooooooooo000000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool0003ooooooboooooo
000`ooooo`03o`000?oooooooooo06;ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`00
0?ooooooooooooooool000001_ooool01?l0003oooooooooool00006ooooo`04o`000?oooooooooo
o`000?oooooo;oooool0033ooooo00?o0000ooooooooool0H_ooool01Ol0003ooooooooooooooooo
000000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Kooooo
00Co0000oooooooooooo0000ooooool_ooooo`00<?ooool00ol0003oooooooooo`1Rooooo`05o`00
0?ooooooooooooooool000002?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooo
oooooooo00001_ooool01?l0003oooooooooool0003ooooooboooooo000`ooooo`?o0000H_ooool0
1?l0003oooooooooool00009ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003ooooo
ooooool00006ooooo`04o`000?ooooooooooo`000?oooooo;oooool0033ooooo00?o0000oooooooo
ool0H_ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooo
ooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003ooooooooo
ool00006ooooo`04o`000?ooooooooooo`000?oooooo;oooool0033ooooo00?o0000ooooooooool0
H_ooool01?l0003oooooooooool00009ooooo`05o`000?ooooooooooooooool000002?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000007
ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool00006ooooo`04o`00
0?ooooooooooo`000?oooooo;oooool0033ooooo00?o0000ooooooooool0Hoooool00ol0003ooooo
o`000009ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooooooo
ooooool000001_ooool01?l0003oooooooooool00006ooooo`04o`000?ooooooooooo`000?oooooo
;oooool0033ooooo00?o0000ooooooooool0Hoooool00ol0003oooooo`000009ooooo`05o`000?oo
ooooooooooooool000002?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo
00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooo
oooooooo00001_ooool00ol0003oooooo`00003ooooooc3ooooo000`ooooo`03o`000?oooooooooo
06?ooooo00?o0000ooooool000002Oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001ooo
ool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Oooooo0_l0003ooooooc3o
oooo000`ooooo`03o`000?oooooooooo06?ooooo00?o0000ooooool000002Oooool01Ol0003ooooo
oooooooooooo000000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05
o`000?ooooooooooooooool000001oooool01?l0003oooooooooool00007ooooo`04o`000?oooooo
ooooo`0000Oooooo0_l0003ooooooc3ooooo000`ooooo`03o`000?oooooooooo06?ooooo0_l0000:
ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oo
oooo00Co0000oooooooooooo00001oooool2o`000?oooooo<?ooool0033ooooo00?o0000oooooooo
ool0Hoooool2o`0000[ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000
oooooooooooo00001oooool01?l0003oooooooooool00007ooooo`;o0000ooooool`ooooo`00<?oo
ool00ol0003oooooooooo`1_ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000007ooooo`04
o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00001oooool2o`000?oooooo<?ooool0
033ooooo00?o0000ooooooooool0Koooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001ooo
ool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Oooooo0_l0003ooooooc3o
oooo000`ooooo`03o`000?oooooooooo06oooooo00Go0000ooooooooooooooooo`000008ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000
00Oooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool00007ooooo`;o0000oooo
ool`ooooo`00<?ooool3o`0006oooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Oooooo
00Co0000oooooooooooo00001oooool01?l0003oooooooooool0003oooooocWooooo000`ooooo`03
o`000?oooooooooo06oooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000
oooooooooooo00001oooool01?l0003oooooooooool0003oooooocWooooo000`ooooo`03o`000?oo
oooooooo06oooooo00Go0000ooooooooooooooooo`000008ooooo`05o`000?ooooooooooooooool0
00001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo00001oooool0
1?l0003oooooooooool0003oooooocWooooo000`ooooo`03o`000?oooooooooo06oooooo00Go0000
ooooooooooooooooo`000008ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooo
oooooooooooo000000Oooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00003ooooo
oc[ooooo000`ooooo`03o`000?oooooooooo06oooooo00Go0000ooooooooooooooooo`000008oooo
o`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co
0000oooooooooooo00001oooool00ol0003oooooo`00003ooooooc[ooooo000`ooooo`03o`000?oo
oooooooo06oooooo00Go0000ooooooooooooooooo`000008ooooo`05o`000?ooooooooooooooool0
00001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo00001oooool0
0ol0003oooooo`00003ooooooc[ooooo000?ooooo`;ok^k^0oooool2onk^kQ[ooooo00?o0000oooo
ooooool0Koooool01Ol0003ooooooooooooooooo000000Sooooo00Go0000ooooooooooooooooo`00
0007ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool00007ooooo`03
o`000?oooooo00000?oooooo>_ooool000Sooooo1Ol00002ooooo`07onk^k_mEEEGok^k^ooooooo^
k^koEEEEonk^kP03ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo
00?o0000ooooooooool0L?ooool01?l0003oooooooooool00008ooooo`05o`000?oooooooooooooo
ool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo00001ooo
ool00ol0003oooooo`00003ooooooc[ooooo0008ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00ooo
ool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00?o0000ooooooooool0L?ooool01?l0003oooooooooool00008oooo
o`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co
0000oooooooooooo00001oooool00ol0003oooooo`00003ooooooc[ooooo0009ooooo`03oiRHV?lQ
8B7ok^k^00Gooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?oo
ooooooooooooool@41002oooool00ol0003oooooooooo`1`ooooo`04o`000?ooooooooooo`0000So
oooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool0
1?l0003oooooooooool00007ooooo`03o`000?oooooo00000?oooooo>_ooool000[ooooo00?oV9RH
ob4Q8Oo^k^h00oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000000_ooooo00?o0000ooooooooool0L?ooool01?l0003ooooo
ooooool00008ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo
000000Oooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00003ooooooc[ooooo000;
ooooo`0;ogMgMomVIVKoooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000002oooool4o`0006oooooo00Co0000
oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooooooooooo
ooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool00000ooooooljoooo
o`003?ooool00ol0003oooooooooo`02onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;o
oooo00Go410@oooooooooooooooooa0@400;ooooo`03o`000?oooooooooo073ooooo00Co0000oooo
oooooooo00002Oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool00000
1oooool01?l0003oooooooooool00007ooooo`03o`000?oooooo00000?oooooo>_ooool000Sooooo
00Go0000okZj^_ooooooV9RHoa0@400>ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`03o`000?oooooooooo073ooooo00Co0000oooooooooooo00002Oooool0
1?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001oooool01?l0003ooooo
ooooool00007ooooo`03o`000?oooooo00000?oooooo>_ooool000Sooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c00<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03oooo
o`;o00001_ooool00ol0003oooooooooo`1`ooooo`04o`000?ooooooooooo`0000Wooooo00Co0000
oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo
00001oooool00ol0003oooooo`00003ooooooc[ooooo000Wooooo`04o`000?ooooooooooo`0000Go
oooo00?o0000ooooooooool0L?ooool01?l0003oooooooooool00009ooooo`04o`000?oooooooooo
o`0000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo
00?o0000ooooool00000ooooooljooooo`009oooool01?l0003oooooooooool00005ooooo`03o`00
0?oooooooooo073ooooo00Co0000oooooooooooo00002Oooool01?l0003oooooooooool00007oooo
o`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool00007ooooo`03o`000?oo
oooo00000?oooooo>_ooool002Oooooo0ol00006ooooo`03o`000?oooooooooo073ooooo00Co0000
oooooooooooo00002Oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool0
00001oooool01?l0003oooooooooool00007ooooo`03o`000?oooooo00000?oooooo>_ooool002So
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1`ooooo`04o`000?ooooooooooo`00
00Wooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co
0000oooooooooooo00001oooool00ol0003oooooo`00003ooooooc[ooooo000Yooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0L?ooool01?l0003oooooooooool00009ooooo`04o`00
0?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?oooooooooo
o`0000Sooooo0_l0003ooooooc[ooooo000`ooooo`03o`000?oooooooooo073ooooo00?o0000oooo
ool000002_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001ooo
ool01?l0003oooooooooool00008ooooo`;o0000ooooooljooooo`00<?ooool00ol0003ooooooooo
o`1`ooooo`03o`000?oooooo000000[ooooo00Co0000oooooooooooo00001oooool01Ol0003ooooo
oooooooooooo000000Oooooo00Co0000oooooooooooo00002?ooool2o`000?oooooo>_ooool0033o
oooo00?o0000ooooooooool0LOooool2o`0000[ooooo00Co0000oooooooooooo00001oooool01Ol0
003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo00002?ooool00ol0003ooooooooo
o`3oooooocWooooo000`ooooo`?o0000LOooool2o`0000[ooooo00Co0000oooooooooooo00001ooo
ool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo00002?ooool00ol0003o
ooooooooo`3oooooocWooooo000`ooooo`03o`000?oooooooooo077ooooo0_l0000:ooooo`04o`00
0?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?oooooooooo
o`000?ooooooA?ooool0033ooooo00?o0000ooooooooool0LOooool2o`0000[ooooo00Co0000oooo
oooooooo00001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000
oooooom4ooooo`00<?ooool00ol0003oooooooooo`1aooooo`;o00002_ooool01?l0003ooooooooo
ool00007ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool0003ooooo
odCooooo000`ooooo`03o`000?oooooooooo077ooooo0_l0000:ooooo`04o`000?ooooooooooo`00
00Oooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`000?ooooooA?oo
ool0033ooooo00?o0000ooooooooool0LOooool2o`0000[ooooo00Co0000oooooooooooo00001ooo
ool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000oooooom4ooooo`00
<?ooool00ol0003oooooooooo`1aooooo`;o00002_ooool01?l0003oooooooooool00007ooooo`05
o`000?ooooooooooooooool000001oooool01?l0003oooooooooool0003oooooodCooooo000`oooo
o`03o`000?oooooooooo07gooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0
0007ooooo`04o`000?ooooooooooo`000?ooooooA?ooool0033ooooo00?o0000ooooooooool0OOoo
ool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooo
oooo0000oooooom4ooooo`00<?ooool00ol0003oooooooooo`1mooooo`04o`000?ooooooooooo`00
00Sooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool0003oooooodCooooo000`
ooooo`03o`000?oooooooooo07gooooo00Co0000oooooooooooo00002?ooool01?l0003ooooooooo
ool00008ooooo`03o`000?oooooo00000?ooooooA?ooool0033ooooo00?o0000ooooooooool0OOoo
ool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool0
0000oooooom4ooooo`00<?ooool3o`0007gooooo00?o0000ooooool000002Oooool01?l0003ooooo
ooooool00008ooooo`03o`000?oooooo00000?ooooooA?ooool0033ooooo00?o0000ooooooooool0
OOooool00ol0003oooooo`000009ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool0
0000oooooom4ooooo`00<?ooool00ol0003oooooooooo`1mooooo`03o`000?oooooo000000Wooooo
00?o0000ooooool000002Oooool2o`000?ooooooAOooool0033ooooo00?o0000ooooooooool0OOoo
ool00ol0003oooooo`000009ooooo`03o`000?oooooo000000Wooooo0_l0003oooooodGooooo000`
ooooo`03o`000?oooooooooo07gooooo00?o0000ooooool000002Oooool00ol0003oooooo`000009
ooooo`;o0000oooooom5ooooo`00<?ooool00ol0003oooooooooo`1mooooo`03o`000?oooooo0000
00Wooooo00?o0000ooooool000002Oooool2o`000?ooooooAOooool0033ooooo00?o0000oooooooo
ool0OOooool00ol0003oooooo`000009ooooo`03o`000?oooooo000000Wooooo0_l0003oooooodGo
oooo000`ooooo`03o`000?oooooooooo07gooooo00?o0000ooooool000002Oooool00ol0003ooooo
o`000009ooooo`;o0000oooooom5ooooo`00<?ooool00ol0003oooooooooo`1mooooo`03o`000?oo
oooo000000Wooooo00?o0000ooooool000002Oooool2o`000?ooooooAOooool0033ooooo00?o0000
ooooooooool0OOooool00ol0003oooooo`000009ooooo`03o`000?oooooo000000Wooooo0_l0003o
ooooodGooooo000`ooooo`03o`000?oooooooooo07gooooo00?o0000ooooool000002Oooool00ol0
003oooooo`000009ooooo`;o0000oooooom5ooooo`00<?ooool00ol0003oooooooooo`1mooooo`03
o`000?oooooo000000Wooooo00?o0000ooooool000002Oooool2o`000?ooooooAOooool0033ooooo
0ol0001mooooo`03o`000?oooooo000000Wooooo00?o0000ooooool000002Oooool2o`000?oooooo
AOooool0033ooooo00?o0000ooooooooool0OOooool00ol0003oooooo`000009ooooo`03o`000?oo
oooo000000Wooooo0_l0003oooooodGooooo000`ooooo`03o`000?oooooooooo07gooooo00?o0000
ooooool000002Oooool00ol0003oooooo`000009ooooo`;o0000oooooom5ooooo`00<?ooool00ol0
003oooooooooo`1mooooo`03o`000?oooooo000000Wooooo00?o0000ooooool00000oooooom@oooo
o`00<?ooool00ol0003oooooooooo`1nooooo`;o00002Oooool00ol0003oooooo`00003ooooooe3o
oooo000`ooooo`03o`000?oooooooooo07kooooo0_l00009ooooo`03o`000?oooooo00000?oooooo
D?ooool000oooooo0_o^k^h3ooooo`;ok^k^6_ooool00ol0003oooooooooo`1nooooo`;o00002Ooo
ool00ol0003oooooo`00003ooooooe3ooooo000:ooooo`;o000000[o410@ooooooooooook^k^oeEE
EOo^k^koooooonk^k_mEEEGok^k^0oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b
<_o^k^h;ooooo`03o`000?oooooooooo07kooooo0_l00009ooooo`03o`000?oooooo00000?oooooo
D?ooool000_ooooo00?o0000ooooooooool00_ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?o0000oooooooo
ool0O_ooool2o`0000Wooooo00?o0000ooooool00000oooooom@ooooo`002?ooool5o`0000Cooooo
00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41002oooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00Sooooo00?o0000ooooool0
0000oooooom@ooooo`002?ooool01?m4A4CogMgMooooool00004ooooo`05onk^k_mEEEGogMgMoeEE
EOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000002oooool0
0ol0003oooooooooo`2:ooooo`;o0000oooooom@ooooo`002?ooool01?oMgMgoEEEEooooool00003
ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo
00Go0000ooooooooooooooooo`00000;ooooo`Co0000ROooool2o`000?ooooooD?ooool000Wooooo
00?oMgMgolc<c?l000000oooool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo
00Go410@oooooooooooooooooa0@400;ooooo`03o`000?oooooooooo08[ooooo0_l0003ooooooe3o
oooo0009ooooo`03onk^k_m4A4Co000000oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00?o0000ooooooooool0R_ooool2o`000?ooooooD?ooool000[ooooo
00?oMgMgo`000?ooool03?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00oooool2o`0000Kooooo00?o0000ooooooooool0R_ooool2o`000?ooooooD?ooool002Oooooo
00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`2:ooooo`;o0000oooooom@ooooo`00
9oooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo08[ooooo00?o0000oooooooo
ool0oooooom?ooooo`009oooool3o`0000Kooooo00?o0000ooooooooool0R_ooool00ol0003ooooo
ooooo`3oooooodoooooo000Xooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooo
oooLooooo`00:Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooog?ooool0
033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomco
oooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo0ol0003oooooomcooooo000`
ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLoooo
o`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooo
g?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool3o`00
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooo
ooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000
ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03
o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?oo
ool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0
033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomco
oooo000`ooooo`?o0000oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`
ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLoooo
o`00<?ooool00ol0003oooooooooo`3oooooomcooooo003ooooooooooooo4?ooool00?oooooooooo
ool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00
oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00X?ooool2o`00
00Cooooo00?o^[Zjoc8b<_ooool01?ooool2o`0000Kooooo00?o0000okZj^_ooool0oooooomGoooo
o`00X?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01?ooool2oc8b<_ooooooF?ooool008gooooo0ol00002ooooo`06oc8b<_l@413oooooooooooo^
k^koEEEE0_l000000om4A4Co^[Zjooooo`03ooooo`03o`000?oooooooooo00;ooooo00GoV9RHoa0@
4?l0003o0000ojVYZ@04ooooo`03o`000?oooooooooo00Cooooo00?oQhN7o`000?nj^[X03?ooool0
1OnHV9So0000o`000?m4A4Co^[Zj00Wooooo00Gok^k^oc8b<_l0003o410@olc<c005ooooo`;o8B4Q
1_ooool2o`000007oa0@4?ooooooc<c<onk^k_ooooook^k^olc<c004ooooo`Co000000So410@oooo
ooooooook^k^oc8b<_l0003o<S8bonk^kQ?ooooo00Ko410@oc8b<_l0003o0000oa0@4?nYZJT2oooo
o`06onk^k_mEEEGo0000o`000?m4A4Co^[Zj0oooool01OmVIVKo0000o`000?m4A4Coc<c<0>Sooooo
002>ooooo`05o`000?ooooooooooolc<c?l@41000oooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@
40Cooooo00?o0000ooooooooool00_ooool01_l0003oZJVYoeEEEOnHV9SoEEEEokZj^P?ooooo00?o
0000ooooooooool01?ooool00oo<c<co0000oa0@400<ooooo`06oa0@4?nj^[[ok^k^ogMgMol@413o
oooo1_l00002ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401Oooool2ob4Q8@Oooooo00So0000oooo
ooooooook^k^oeEEEOoMgMgoEEEEonk^kPKooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg01?ooooo00Ko0000ojVYZOoooooooooookZj^_l00002ooooo`06oeEEEOmgMgOo
ooooonk^k_mgMgOo410@0_ooool01_mVIVKoMgMgooooooooooooQhN7oa0@4>Sooooo002>ooooo`05
o`000?oooooooooooeEEEOn7QhL00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00;ooooo00Ko<S8bonk^k_nHV9SoEEEEomgMgOl@4103ooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool02oooool01Ol0003ooooooooooooooooo000000_ooooo1Ol00002ooooo`03omgM
gOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01Co
oooo00Go^[ZjohN7QomVIVKoIVIVoa0@4002ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0joooool008kooooo00Go0000oooooooMgMgo0000onk^kP03ooooo`Ko00001?ooool00ol0
003oooooooooo`02ooooo`07okZj^_m4A4Coc<c<ob4Q8Ooooooo410@olc<c002ooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool00oooool6o`0000;ooooo00Go0000oiRHV?ooooooV9RH
ob4Q8@0;ooooo`04odA4A?oMgMgoooooo`0000;ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06oooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Cooooo`06oc8b<_lQ8B7o
MgMgogMgMon7QhOok^k^0_ooool6o`0000;ooooo00?o0000ooooooooool0joooool008kooooo0ol0
00000ol@413oV9RHooooo`02ooooo`06oeEEEOn7QhOok^k^oooooon7QhOo<S8b1?ooool00ol0003o
ooooooooo`02ooooo`07onk^k_l0003oooooo`000?ooooooIVIVohN7Q`02ooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool02oooool01Ol0003oEEEEo`000?l@413oc<c<00_ooooo00Co
gMgMoeEEEOoooooo00000_ooool01Oo<c<cok^k^ooooooo^k^koc<c<00Kooooo00?o0000oooooooo
ool00_ooool01Ol0003ooooooooooooooooo000001?ooooo00Ko0000okZj^_ooooook^k^ogMgMol0
0002ooooo`06oeEEEOn7QhOok^k^oooooon7QhOo<S8b0_ooool01_mVIVKoMgMgooooooooooooQhN7
o`000>Sooooo002>ooooo`05o`000?ooooooooooolc<c?l000000oooool01_o^k^koEEEEo`000?l0
003oA4A4onk^kPCooooo00?o0000ooooooooool00_ooool01?mVIVKoV9RHoooooolb<S82okZj^P04
o`000?ooooooooooo`0001?ooooo00?o410@o`000?l000000ol0000:ooooo`03oeEEEOn7QhOooooo
00kooooo00?oMgMgolc<c?l000003Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@41001oooool3o`0000;ooooo0ol00004ooooo`06ojVYZOlQ8B7o0000o`000?lb<S;o0000
0_ooool01_o^k^koEEEEo`000?l0003oA4A4onk^kP;ooooo00Kok^k^ofIVI_l0003o0000odA4A?l0
003Xooooo`00S_ooool01Ol0003oooooooooooo<c<co000000gooooo00?o0000ooooooooool01Ooo
ool00omVIVKoQhN7ooooo`03ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02ooo
ool00ooMgMgo410@oiRHV00>ooooo`03onk^k_m4A4Co000000gooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`3oooooo`;ooooo002=ooooo`Co000000?o410@ojVYZOooool03?ooool2o`0000Kooooo00?o
ZJVYodA4A?ooool00_ooool2o`0001Gooooo00?o0000ooooooooool03?ooool01?o<c<coA4A4o`00
0?l@410=ooooo`03ogMgMol0003ooooo00[ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00;ooooo1?l00002ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0ooooool2ooooo`00ooooool6ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
ooooool2ooooo`00ooooool6ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0oooo
ool2ooooo`00ooooool5ooooo`;o00000oooool2o`000?oooooo1?ooool00?ooooooooooool@oooo
o`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooo
oooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo
003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooo
oooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool0
0?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooooooo
ool@ooooo`00oooooooooooooa3ooooo0000\
\>"],
  ImageRangeCache->{{{0, 525.688}, {324.5, 0}} -> {-2.58312*^-7, -6.34248*^6, \
6.65005*^-9, 53093.5}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0.309017 5.42214e-08 [
[.32684 .29652 -16.5 -12.5 ]
[.32684 .29652 16.5 0 ]
[.54329 .29652 -16.5 -12.5 ]
[.54329 .29652 16.5 0 ]
[.75974 .29652 -22.5 -12.5 ]
[.75974 .29652 22.5 0 ]
[.97619 .29652 -16.5 -12.5 ]
[.97619 .29652 16.5 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 64 6 ]
[.09789 .09213 -34.5 -6.25 ]
[.09789 .09213 0 6.25 ]
[.09789 .20057 -34.5 -6.25 ]
[.09789 .20057 0 6.25 ]
[.09789 .41746 -28.5 -6.25 ]
[.09789 .41746 0 6.25 ]
[.09789 .5259 -28.5 -6.25 ]
[.09789 .5259 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -62.8125 0 ]
[.5 .63053 62.8125 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 .30902 m
.32684 .31527 L
s
gsave
.32684 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 .30902 m
.54329 .31527 L
s
gsave
.54329 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 .30902 m
.75974 .31527 L
s
gsave
.75974 .29652 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 .30902 m
.15368 .31277 L
s
.19697 .30902 m
.19697 .31277 L
s
.24026 .30902 m
.24026 .31277 L
s
.28355 .30902 m
.28355 .31277 L
s
.37013 .30902 m
.37013 .31277 L
s
.41342 .30902 m
.41342 .31277 L
s
.45671 .30902 m
.45671 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.58658 .30902 m
.58658 .31277 L
s
.62987 .30902 m
.62987 .31277 L
s
.67316 .30902 m
.67316 .31277 L
s
.71645 .30902 m
.71645 .31277 L
s
.80303 .30902 m
.80303 .31277 L
s
.84632 .30902 m
.84632 .31277 L
s
.88961 .30902 m
.88961 .31277 L
s
.9329 .30902 m
.9329 .31277 L
s
.0671 .30902 m
.0671 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09213 m
.11664 .09213 L
s
gsave
.09789 .09213 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .20057 m
.11664 .20057 L
s
gsave
.09789 .20057 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .41746 m
.11664 .41746 L
s
gsave
.09789 .41746 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .5259 m
.11664 .5259 L
s
gsave
.09789 .5259 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.11039 .11924 m
.11414 .11924 L
s
.11039 .14635 m
.11414 .14635 L
s
.11039 .17346 m
.11414 .17346 L
s
.11039 .22768 m
.11414 .22768 L
s
.11039 .2548 m
.11414 .2548 L
s
.11039 .28191 m
.11414 .28191 L
s
.11039 .33613 m
.11414 .33613 L
s
.11039 .36324 m
.11414 .36324 L
s
.11039 .39035 m
.11414 .39035 L
s
.11039 .44457 m
.11414 .44457 L
s
.11039 .47168 m
.11414 .47168 L
s
.11039 .49879 m
.11414 .49879 L
s
.11039 .06502 m
.11414 .06502 L
s
.11039 .03791 m
.11414 .03791 L
s
.11039 .0108 m
.11414 .0108 L
s
.11039 .55301 m
.11414 .55301 L
s
.11039 .58012 m
.11414 .58012 L
s
.11039 .60723 m
.11414 .60723 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -123.812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.812 moveto
(@) show
81.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.812 moveto
(D) show
93.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6.6) show
135.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
141.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
153.000 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
157.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
166.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
184.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02532 .30902 L
.02691 .30902 L
.02866 .30902 L
.03029 .30902 L
.03335 .30902 L
.03648 .30902 L
.0398 .30902 L
.04301 .30902 L
.04609 .30902 L
.04937 .30902 L
.05253 .30902 L
.05557 .30902 L
.05637 .30902 L
.05713 .30902 L
.05754 .30902 L
.058 .30902 L
.0582 .30902 L
.05842 .30902 L
.05862 .30902 L
.0588 .30902 L
.0589 .30902 L
.05899 .30902 L
.05909 .30902 L
.05919 .30902 L
.05925 .30902 L
.0593 .30902 L
.05941 .30902 L
.05951 .30902 L
.05961 .30902 L
.05978 .30902 L
.05997 .30902 L
.06016 .30902 L
.06035 .30902 L
.06077 .30902 L
.06115 .30902 L
.06157 .30902 L
.06202 .30902 L
.06278 .30902 L
.0636 .30902 L
.06438 .30902 L
.06508 .30902 L
.06662 .30902 L
.06749 .30902 L
.06829 .30902 L
.06979 .30902 L
.07145 .30902 L
.07301 .30902 L
.07469 .30902 L
.07639 .30902 L
Mistroke
.078 .30902 L
.07959 .30902 L
.08107 .30902 L
.08422 .30902 L
.08594 .30902 L
.08756 .30902 L
.09066 .30902 L
.09395 .30902 L
.09712 .30902 L
.10018 .30902 L
.10343 .30902 L
.10655 .30902 L
.10815 .30902 L
.10899 .30902 L
.10945 .30902 L
.10988 .30902 L
.11029 .30902 L
.11067 .30902 L
.11087 .30902 L
.11109 .30902 L
.1112 .30902 L
.11131 .30902 L
.11137 .30902 L
.11142 .30902 L
.11148 .30902 L
.11154 .30902 L
.11163 .30902 L
.11173 .30902 L
.11183 .30902 L
.11193 .30902 L
.11202 .30902 L
.1121 .30902 L
.11228 .30902 L
.11248 .30902 L
.11269 .30902 L
.11308 .30902 L
.11347 .30902 L
.11383 .30902 L
.11466 .30902 L
.11548 .30902 L
.11635 .30902 L
.11712 .30902 L
.11796 .30902 L
.11965 .30902 L
.12122 .30902 L
.1229 .30902 L
.12461 .30902 L
.12623 .30902 L
.12932 .30902 L
.13091 .30902 L
Mistroke
.1326 .30902 L
.13564 .30902 L
.13887 .30902 L
.14199 .30902 L
.14357 .30902 L
.1453 .30902 L
.1461 .30902 L
.14695 .30902 L
.14776 .30902 L
.1481 .30902 L
.14849 .30902 L
.14888 .30902 L
.14909 .30902 L
.14919 .30902 L
.14929 .30902 L
.14938 .30902 L
.14948 .30902 L
.14957 .30902 L
.14965 .30902 L
.14974 .30902 L
.14983 .30902 L
.14994 .30902 L
.15003 .30902 L
.15013 .30902 L
.15024 .30902 L
.15045 .30902 L
.15065 .30902 L
.15084 .30902 L
.15126 .30902 L
.1517 .30902 L
.15213 .30902 L
.15253 .30902 L
.15342 .30902 L
.1542 .30902 L
.15504 .30902 L
.15661 .30902 L
.15808 .30902 L
.15971 .30902 L
.1612 .30902 L
.16439 .30902 L
.16746 .30902 L
.17073 .30902 L
.17388 .30902 L
.17548 .30902 L
.17722 .30902 L
.17804 .30902 L
.1789 .30902 L
.17963 .30902 L
.18005 .30902 L
.18044 .30902 L
Mistroke
.18065 .30902 L
.18084 .30902 L
.18095 .30902 L
.181 .30902 L
.18106 .30902 L
.18111 .30902 L
.18117 .30902 L
.18123 .30902 L
.18128 .30902 L
.18138 .30902 L
.18148 .30902 L
.18158 .30902 L
.18166 .30902 L
.18177 .30902 L
.18188 .30902 L
.18208 .30902 L
.18226 .30902 L
.18246 .30902 L
.18286 .30902 L
.18323 .30902 L
.18357 .30902 L
.18441 .30902 L
.1852 .30902 L
.18592 .30902 L
.18669 .30902 L
.18828 .30902 L
.18996 .30902 L
.19153 .30901 L
.19299 .30901 L
.1961 .30901 L
.1994 .309 L
.20258 .30899 L
.20418 .30898 L
.20564 .30898 L
.20639 .30898 L
.20721 .30898 L
.20766 .30898 L
.20786 .30898 L
.20807 .30898 L
.20828 .30898 L
.20847 .30898 L
.20858 .30898 L
.20867 .30898 L
.20873 .30898 L
.20879 .30898 L
.20889 .30898 L
.20894 .30898 L
.209 .30898 L
.2091 .30898 L
.2092 .30898 L
Mistroke
.20932 .30898 L
.20942 .30898 L
.20953 .30898 L
.20972 .30898 L
.21011 .30898 L
.21047 .30898 L
.21089 .30898 L
.21134 .30898 L
.21216 .30898 L
.21291 .30899 L
.21375 .30899 L
.21543 .309 L
.21699 .30901 L
.21866 .30903 L
.22197 .30908 L
.22515 .30914 L
.22822 .30919 L
.22992 .30922 L
.23073 .30923 L
.23147 .30924 L
.23225 .30924 L
.23266 .30925 L
.23286 .30925 L
.23309 .30925 L
.23319 .30925 L
.23329 .30925 L
.23338 .30925 L
.23347 .30925 L
.23357 .30925 L
.23366 .30925 L
.23376 .30925 L
.23382 .30925 L
.23388 .30925 L
.23397 .30925 L
.23406 .30925 L
.23414 .30925 L
.23423 .30925 L
.23443 .30925 L
.23461 .30925 L
.23502 .30924 L
.23524 .30924 L
.23545 .30924 L
.23625 .30923 L
.23697 .30922 L
.23774 .3092 L
.23931 .30915 L
.24078 .30909 L
.24389 .3089 L
.2472 .30863 L
.25039 .30835 L
Mistroke
.252 .30822 L
.25346 .30812 L
.25427 .30808 L
.25504 .30805 L
.25524 .30805 L
.25546 .30804 L
.25564 .30804 L
.25584 .30803 L
.25596 .30803 L
.25606 .30803 L
.25616 .30803 L
.25626 .30803 L
.25632 .30803 L
.25638 .30803 L
.25648 .30803 L
.25654 .30803 L
.25659 .30803 L
.25665 .30803 L
.25672 .30803 L
.25682 .30803 L
.25691 .30803 L
.25702 .30803 L
.25712 .30803 L
.2573 .30804 L
.25749 .30804 L
.25793 .30805 L
.25833 .30807 L
.25915 .30812 L
.25957 .30815 L
.26002 .30819 L
.26158 .30838 L
.26246 .30853 L
.26326 .30868 L
.26645 .30947 L
.26952 .31044 L
.27124 .311 L
.27279 .31147 L
.27359 .31169 L
.27443 .31189 L
.27521 .31204 L
.27594 .31215 L
.27629 .31219 L
.27667 .31223 L
.27689 .31224 L
.2771 .31225 L
.27719 .31226 L
.27728 .31226 L
.27739 .31226 L
.27748 .31227 L
.27759 .31227 L
Mistroke
.27768 .31227 L
.27773 .31227 L
.27779 .31227 L
.2779 .31226 L
.27799 .31226 L
.27809 .31226 L
.27828 .31225 L
.27852 .31224 L
.27874 .31222 L
.27916 .31217 L
.27953 .31211 L
.27994 .31203 L
.28077 .31182 L
.28153 .31156 L
.28225 .31126 L
.28388 .31038 L
.28537 .30934 L
.28857 .30653 L
.29164 .30358 L
.2932 .30224 L
.29402 .30164 L
.29491 .30109 L
.29533 .30088 L
.29576 .3007 L
.29616 .30056 L
.29636 .3005 L
.29654 .30046 L
.29671 .30042 L
.29689 .30039 L
.29699 .30038 L
.29708 .30037 L
.29717 .30036 L
.29727 .30036 L
.29736 .30035 L
.29745 .30035 L
.29756 .30035 L
.29765 .30035 L
.29775 .30036 L
.29781 .30036 L
.29786 .30037 L
.29806 .30039 L
.29817 .3004 L
.29828 .30042 L
.29847 .30047 L
.29891 .3006 L
.29929 .30076 L
.29971 .30099 L
.30048 .30153 L
.30121 .30219 L
.30284 .30424 L
Mistroke
.30433 .30675 L
.30753 .31368 L
.31061 .32098 L
.31217 .32421 L
.313 .32565 L
.31389 .32692 L
.3143 .32739 L
.31474 .3278 L
.31511 .32807 L
.31532 .3282 L
.31551 .32829 L
.31561 .32833 L
.31571 .32836 L
.3158 .32839 L
.3159 .32841 L
.316 .32843 L
.31606 .32843 L
.31611 .32844 L
.3162 .32844 L
.3163 .32844 L
.3164 .32843 L
.3165 .32842 L
.3166 .3284 L
.31669 .32838 L
.31686 .32832 L
.31704 .32824 L
.31725 .32813 L
.31747 .32797 L
.31787 .32761 L
.3183 .32711 L
.31876 .32642 L
.3196 .32481 L
.32038 .32289 L
.32202 .3176 L
.32351 .31148 L
.32672 .29575 L
.3298 .28109 L
.33139 .27546 L
.3322 .27344 L
.33265 .27259 L
.33288 .27225 L
.33308 .27199 L
.33329 .27178 L
.33348 .27163 L
.33359 .27156 L
.33369 .27151 L
.3338 .27147 L
.33386 .27146 L
.33391 .27145 L
.33401 .27144 L
Mistroke
.3341 .27144 L
.3342 .27146 L
.3343 .27149 L
.33435 .27151 L
.33441 .27153 L
.33451 .27159 L
.33471 .27173 L
.33488 .27191 L
.33508 .27215 L
.33548 .2728 L
.33585 .27359 L
.33619 .2745 L
.33698 .27719 L
.33781 .28092 L
.3393 .28979 L
.34236 .31501 L
.34561 .3454 L
.34712 .35756 L
.34791 .36288 L
.34875 .36746 L
.34917 .36931 L
.34964 .37094 L
.34984 .37151 L
.35006 .37203 L
.35027 .37243 L
.35046 .37271 L
.35056 .37283 L
.35067 .37292 L
.35073 .37297 L
.35078 .373 L
.35084 .37303 L
.35089 .37305 L
.351 .37307 L
.35105 .37306 L
.35111 .37306 L
.35121 .37302 L
.3513 .37297 L
.3514 .37289 L
.3515 .37279 L
.35168 .37255 L
.35187 .37221 L
.35208 .37174 L
.35247 .37057 L
.35283 .36913 L
.35367 .36464 L
.35448 .35866 L
.35535 .35053 L
.35866 .30714 L
.36184 .25786 L
.36345 .23627 L
Mistroke
.36415 .22846 L
.36491 .22143 L
.36533 .21823 L
.36572 .21579 L
.36609 .21392 L
.36648 .21247 L
.36668 .21194 L
.36679 .21172 L
.3669 .21154 L
.36699 .21142 L
.3671 .21132 L
.3672 .21127 L
.36729 .21125 L
.36739 .21127 L
.36749 .21133 L
.36754 .21138 L
.3676 .21143 L
.36771 .21159 L
.36782 .21179 L
.36793 .21205 L
.36817 .21273 L
.36837 .21351 L
.36859 .21453 L
.36899 .21687 L
.36974 .22295 L
.37061 .23275 L
.37142 .24425 L
.37458 .30699 L
.37762 .37724 L
.37931 .41065 L
.38011 .42331 L
.38085 .43269 L
.38125 .43668 L
.38162 .43962 L
.38202 .44208 L
.38224 .44307 L
.38234 .44343 L
.38245 .44376 L
.38254 .44398 L
.38263 .44416 L
.38273 .4443 L
.38283 .44438 L
.38292 .44442 L
.38301 .4444 L
.38309 .44435 L
.38318 .44425 L
.38327 .44409 L
.38338 .44386 L
.38359 .4432 L
.38378 .44236 L
Mistroke
.38397 .44136 L
.38434 .43871 L
.38475 .43488 L
.38559 .42422 L
.38636 .411 L
.38707 .39603 L
.39021 .30794 L
.39181 .25676 L
.39354 .20505 L
.39435 .18419 L
.39521 .16553 L
.39594 .15292 L
.39633 .14766 L
.39675 .14309 L
.39697 .14121 L
.39717 .13977 L
.39736 .13868 L
.39746 .13823 L
.39757 .13782 L
.39767 .13751 L
.39777 .13729 L
.39786 .13715 L
.39796 .13707 L
.39804 .13706 L
.39813 .1371 L
.39822 .13721 L
.39831 .1374 L
.39842 .13771 L
.39853 .13808 L
.39876 .13923 L
.39897 .1406 L
.39919 .14242 L
.39957 .14645 L
.39999 .15217 L
.4008 .167 L
.40155 .18463 L
.40322 .23647 L
.40641 .3608 L
.40801 .42166 L
.40947 .46713 L
.41028 .48646 L
.41105 .4999 L
.41147 .50513 L
.41167 .50706 L
.41186 .50852 L
.41206 .50974 L
.41217 .51023 L
.41228 .51063 L
.41234 .51078 L
.4124 .51091 L
Mistroke
.41246 .511 L
.41252 .51105 L
.41262 .51107 L
.41267 .51104 L
.41273 .51098 L
.41283 .5108 L
.41292 .51054 L
.41302 .51018 L
.41313 .50968 L
.41334 .50831 L
.41354 .50667 L
.41392 .50245 L
.41428 .49718 L
.41509 .48112 L
.41596 .45739 L
.41755 .39951 L
.41924 .32445 L
.42228 .18651 L
.42384 .13152 L
.42429 .11923 L
.42472 .10929 L
.42514 .10124 L
.42552 .09551 L
.42571 .09322 L
.42591 .09118 L
.42611 .08968 L
.42629 .08867 L
.42639 .08827 L
.42648 .08799 L
.42658 .08779 L
.42664 .08773 L
.42669 .08771 L
.42679 .08775 L
.42685 .08783 L
.4269 .08793 L
.427 .08821 L
.42711 .08863 L
.42728 .0896 L
.42747 .09102 L
.42781 .0946 L
.42822 .10052 L
.42859 .10749 L
.42937 .12706 L
.43011 .1506 L
.43177 .21961 L
.43491 .37735 L
.43651 .45051 L
.43735 .48213 L
.43781 .49677 L
.43824 .50857 L
Mistroke
.43866 .51811 L
.43904 .52515 L
.43946 .53101 L
.43969 .53334 L
.4398 .53417 L
.43991 .53494 L
.44 .53543 L
.4401 .53584 L
.4402 .53615 L
.44029 .53633 L
.44038 .5364 L
.44048 .53636 L
.44056 .53624 L
.44065 .53602 L
.44075 .53563 L
.44085 .53516 L
.44107 .53369 L
.44126 .53184 L
.44145 .52964 L
.44182 .52409 L
.44223 .51613 L
.44306 .4944 L
.44382 .46814 L
.44454 .43893 L
.44765 .28249 L
.44923 .20345 L
.45007 .16713 L
.45096 .1347 L
.4514 .12133 L
.45182 .1107 L
.45223 .10227 L
.45261 .09626 L
.45297 .09214 L
.45315 .09066 L
.45325 .09001 L
.45335 .08951 L
.45345 .0891 L
.45355 .08885 L
.45365 .0887 L
.45371 .08868 L
.45376 .08869 L
.45385 .08879 L
.45395 .08902 L
.45405 .08939 L
.45415 .08985 L
.45434 .09114 L
.45452 .09277 L
.45493 .09796 L
.45534 .10498 L
.45577 .11453 L
Mistroke
.45654 .1369 L
.45725 .1623 L
.46046 .3148 L
.46193 .38746 L
.46277 .42436 L
.46355 .45427 L
.46438 .48005 L
.46475 .48908 L
.46514 .49724 L
.46536 .50094 L
.46556 .50387 L
.46577 .50637 L
.46596 .50825 L
.46606 .50911 L
.46618 .50988 L
.46628 .5104 L
.46638 .51084 L
.46644 .51103 L
.4665 .51116 L
.46655 .51127 L
.46662 .51133 L
.46667 .51135 L
.46673 .51133 L
.46683 .51119 L
.46692 .51096 L
.46702 .5106 L
.46712 .51015 L
.4672 .50964 L
.4674 .50813 L
.46761 .50604 L
.468 .50071 L
.46843 .49288 L
.4692 .47406 L
.46991 .45153 L
.47305 .316 L
.47465 .24304 L
.4755 .20903 L
.47639 .17851 L
.47718 .15706 L
.47764 .14768 L
.47806 .14086 L
.47826 .13831 L
.47845 .13631 L
.47862 .13483 L
.4788 .13362 L
.4789 .13314 L
.479 .13273 L
.4791 .13246 L
.47919 .1323 L
.47929 .13222 L
Mistroke
.47939 .13226 L
.47949 .13242 L
.47954 .13255 L
.4796 .13272 L
.47971 .13313 L
.4798 .13362 L
.48002 .13511 L
.48022 .13686 L
.48042 .13916 L
.48078 .14418 L
.48117 .15119 L
.48204 .1718 L
.48285 .19663 L
.48597 .31876 L
.48755 .37948 L
.48839 .40649 L
.48928 .42968 L
.48973 .4388 L
.49015 .44573 L
.49052 .45052 L
.49074 .45261 L
.49093 .45414 L
.49112 .45524 L
.49121 .45565 L
.49129 .45597 L
.49139 .45625 L
.49148 .45642 L
.49157 .45652 L
.49168 .45653 L
.49177 .45644 L
.49188 .45624 L
.49193 .4561 L
.49199 .45592 L
.49209 .45551 L
.49229 .45445 L
.49247 .45314 L
.49285 .4494 L
.49326 .44397 L
.49399 .43069 L
.49486 .40974 L
.49565 .38682 L
.49886 .27885 L
.50033 .23579 L
.50117 .21672 L
.50158 .20915 L
.50195 .20335 L
.50232 .19869 L
.50272 .19485 L
.50294 .19331 L
.50305 .19271 L
Mistroke
.50315 .19225 L
.50324 .19187 L
.50334 .19155 L
.5034 .19141 L
.50345 .1913 L
.50355 .19115 L
.50365 .19109 L
.50375 .19111 L
.50385 .19121 L
.50394 .19137 L
.50405 .19164 L
.50416 .19204 L
.50437 .19304 L
.50459 .19446 L
.50482 .19636 L
.50524 .20078 L
.50599 .21189 L
.50681 .22771 L
.50827 .26376 L
.50986 .3074 L
.51158 .35183 L
.51238 .3688 L
.51323 .38325 L
.51365 .38873 L
.51404 .3929 L
.51439 .3958 L
.51459 .39708 L
.51477 .39802 L
.51496 .39877 L
.51506 .39908 L
.51516 .39931 L
.51525 .39946 L
.51534 .39955 L
.51543 .3996 L
.51553 .39958 L
.51563 .3995 L
.51569 .39943 L
.51574 .39934 L
.51583 .39914 L
.51593 .39887 L
.51614 .39808 L
.51637 .3969 L
.51679 .39388 L
.51724 .3895 L
.51806 .37891 L
.51977 .34798 L
.52139 .31362 L
.52286 .28382 L
.52369 .26934 L
.52448 .25817 L
Mistroke
.52524 .24986 L
.52568 .24646 L
.52607 .24418 L
.52629 .24328 L
.52649 .24266 L
.5266 .24239 L
.5267 .24221 L
.52676 .24214 L
.52682 .24207 L
.52688 .24203 L
.52694 .24201 L
.52704 .24201 L
.52713 .24205 L
.52723 .24215 L
.52729 .24223 L
.52734 .24231 L
.52744 .24252 L
.52755 .24281 L
.52776 .24349 L
.52795 .2443 L
.52815 .24535 L
.52852 .24772 L
.52935 .25521 L
.53023 .26578 L
.53104 .27724 L
.53269 .30323 L
.53422 .32641 L
.53498 .33628 L
.5357 .34407 L
.5361 .34766 L
.53653 .35092 L
.53689 .35312 L
.53728 .35493 L
.53749 .35565 L
.53768 .35616 L
.53777 .35636 L
.53787 .35654 L
.53796 .35667 L
.53804 .35677 L
.53814 .35684 L
.5382 .35687 L
.53825 .35688 L
.53831 .35688 L
.53837 .35687 L
.53842 .35685 L
.53848 .35681 L
.53858 .35672 L
.53864 .35665 L
.53869 .35658 L
.53888 .35622 L
Mistroke
.5391 .35566 L
.5393 .35499 L
.53975 .35299 L
.54015 .35067 L
.54057 .34771 L
.54214 .3331 L
.54361 .31656 L
.5451 .30007 L
.54588 .29244 L
.54672 .28563 L
.54718 .28259 L
.5476 .2803 L
.54802 .27847 L
.54842 .2772 L
.54861 .27673 L
.54872 .27652 L
.54882 .27636 L
.54891 .27623 L
.549 .27613 L
.54909 .27605 L
.54919 .27599 L
.54925 .27596 L
.5493 .27595 L
.5494 .27594 L
.54945 .27595 L
.54951 .27597 L
.54956 .27599 L
.54962 .27603 L
.54973 .27612 L
.54984 .27624 L
.55003 .27653 L
.55024 .27695 L
.55043 .27745 L
.5508 .27862 L
.55162 .28232 L
.55232 .28653 L
.55309 .29189 L
.55466 .30415 L
.55638 .31713 L
.55716 .32208 L
.55801 .32633 L
.55842 .32794 L
.55881 .32917 L
.55916 .33003 L
.55936 .33041 L
.55954 .33069 L
.55975 .33093 L
.55985 .33102 L
.55991 .33106 L
.55997 .3311 L
Mistroke
.56007 .33114 L
.56016 .33116 L
.56022 .33117 L
.56027 .33117 L
.56037 .33115 L
.56046 .33112 L
.56056 .33107 L
.56064 .33102 L
.56073 .33094 L
.56093 .33072 L
.56112 .33045 L
.56155 .32961 L
.56193 .32859 L
.56281 .32552 L
.56433 .3183 L
.56599 .30941 L
.56687 .30499 L
.5677 .30133 L
.56851 .29843 L
.56886 .2974 L
.56925 .29644 L
.56963 .2957 L
.56999 .29518 L
.57018 .29497 L
.57036 .29482 L
.57046 .29475 L
.57057 .29469 L
.57067 .29465 L
.57076 .29463 L
.57085 .29462 L
.57096 .29461 L
.57105 .29463 L
.57114 .29464 L
.57123 .29468 L
.57134 .29473 L
.57155 .29487 L
.57176 .29506 L
.57199 .29533 L
.57239 .29594 L
.57321 .2977 L
.57411 .30021 L
.57572 .3057 L
.57728 .31104 L
.57811 .31348 L
.579 .31562 L
.57944 .31644 L
.57986 .31708 L
.58023 .31752 L
.58044 .31772 L
.58064 .31787 L
Mistroke
.58084 .31798 L
.58093 .31802 L
.58102 .31806 L
.58112 .31809 L
.58122 .31811 L
.58132 .31812 L
.58138 .31812 L
.58143 .31812 L
.58153 .31812 L
.58162 .31811 L
.5817 .31809 L
.58179 .31806 L
.58198 .31799 L
.58217 .31789 L
.58254 .31761 L
.58294 .31719 L
.58367 .31618 L
.58532 .31296 L
.5869 .30944 L
.58773 .30768 L
.58862 .30605 L
.58949 .3048 L
.5899 .30434 L
.59027 .30399 L
.59065 .30373 L
.59085 .30362 L
.59106 .30353 L
.59115 .3035 L
.59125 .30347 L
.59133 .30345 L
.59142 .30344 L
.59152 .30342 L
.59162 .30341 L
.59172 .30341 L
.59181 .30341 L
.59191 .30342 L
.59196 .30343 L
.59202 .30343 L
.59212 .30345 L
.59222 .30347 L
.59243 .30354 L
.59266 .30364 L
.59308 .30388 L
.59346 .30417 L
.59423 .30491 L
.59496 .30577 L
.59804 .30991 L
.59886 .31083 L
.59963 .31151 L
.60005 .31181 L
Mistroke
.60043 .31203 L
.60086 .31221 L
.6011 .31228 L
.6012 .31231 L
.60132 .31233 L
.60143 .31235 L
.60153 .31236 L
.60162 .31237 L
.60172 .31238 L
.60181 .31238 L
.6019 .31238 L
.60199 .31238 L
.60209 .31238 L
.60219 .31237 L
.60231 .31235 L
.60252 .31231 L
.60272 .31227 L
.60291 .31221 L
.60362 .31191 L
.60438 .31145 L
.60741 .30902 L
.60897 .30792 L
.60939 .30768 L
.60984 .30747 L
.61026 .30731 L
.61064 .3072 L
.61083 .30715 L
.61104 .30711 L
.61123 .30708 L
.61141 .30706 L
.6115 .30706 L
.6116 .30705 L
.6117 .30705 L
.61175 .30705 L
.6118 .30704 L
.61191 .30704 L
.61197 .30705 L
.61202 .30705 L
.61212 .30705 L
.61223 .30706 L
.61233 .30707 L
.61242 .30708 L
.61262 .3071 L
.613 .30717 L
.61334 .30725 L
.6137 .30736 L
.61528 .30801 L
.61675 .30873 L
.61825 .30942 L
.6191 .30973 L
Mistroke
.61988 .30994 L
.62027 .31002 L
.62071 .31009 L
.62093 .31011 L
.62104 .31012 L
.62116 .31013 L
.62127 .31014 L
.62132 .31014 L
.62138 .31014 L
.62149 .31014 L
.62159 .31015 L
.62164 .31015 L
.6217 .31015 L
.6218 .31015 L
.62185 .31015 L
.6219 .31014 L
.62196 .31014 L
.62202 .31014 L
.62213 .31014 L
.62224 .31013 L
.62243 .31011 L
.6228 .31008 L
.6232 .31002 L
.62396 .30987 L
.62479 .30967 L
.62647 .3092 L
.62729 .30897 L
.62815 .30876 L
.62895 .3086 L
.62934 .30853 L
.6297 .30849 L
.63004 .30845 L
.63041 .30842 L
.63062 .3084 L
.63081 .3084 L
.63099 .30839 L
.63108 .30839 L
.63118 .30839 L
.63123 .30838 L
.63129 .30838 L
.63139 .30838 L
.63149 .30838 L
.63158 .30839 L
.63164 .30839 L
.63169 .30839 L
.63179 .30839 L
.6319 .30839 L
.63202 .3084 L
.63242 .30842 L
.6328 .30845 L
Mistroke
.63358 .30853 L
.63431 .30863 L
.63597 .3089 L
.63747 .30912 L
.63826 .30922 L
.6391 .3093 L
.63952 .30932 L
.63974 .30934 L
.63998 .30935 L
.6402 .30935 L
.6403 .30936 L
.64041 .30936 L
.6405 .30936 L
.6406 .30936 L
.6407 .30936 L
.6408 .30936 L
.64085 .30936 L
.64091 .30936 L
.64101 .30936 L
.64107 .30936 L
.64112 .30936 L
.64118 .30936 L
.64124 .30936 L
.64135 .30936 L
.64145 .30936 L
.64165 .30935 L
.64202 .30934 L
.64242 .30932 L
.64325 .30927 L
.644 .30921 L
.64569 .30906 L
.6465 .30899 L
.64736 .30893 L
.6481 .30889 L
.64852 .30887 L
.64891 .30885 L
.6491 .30885 L
.64931 .30884 L
.64948 .30884 L
.64968 .30883 L
.64978 .30883 L
.64989 .30883 L
.65001 .30883 L
.65006 .30883 L
.65011 .30883 L
.65017 .30883 L
.65022 .30883 L
.65032 .30883 L
.65041 .30883 L
.65051 .30883 L
Mistroke
.65061 .30883 L
.65071 .30883 L
.65081 .30883 L
.65092 .30883 L
.6511 .30884 L
.6513 .30884 L
.65166 .30885 L
.65201 .30886 L
.65364 .30892 L
.65513 .309 L
.65593 .30903 L
.65679 .30907 L
.65752 .30909 L
.65794 .3091 L
.65833 .30911 L
.6587 .30911 L
.65889 .30911 L
.659 .30911 L
.6591 .30911 L
.65918 .30911 L
.65928 .30911 L
.65937 .30912 L
.65946 .30912 L
.65955 .30912 L
.65964 .30912 L
.65972 .30912 L
.65981 .30912 L
.65986 .30912 L
.65991 .30912 L
.66001 .30911 L
.6602 .30911 L
.66042 .30911 L
.66063 .30911 L
.661 .30911 L
.6614 .3091 L
.66312 .30906 L
.66474 .30902 L
.66553 .309 L
.66636 .30899 L
.66706 .30898 L
.66747 .30897 L
.66784 .30897 L
.66805 .30897 L
.66824 .30897 L
.66834 .30897 L
.66846 .30897 L
.66851 .30897 L
.66857 .30897 L
.66863 .30897 L
.66868 .30897 L
Mistroke
.66878 .30897 L
.66887 .30897 L
.66896 .30897 L
.66907 .30897 L
.66912 .30897 L
.66918 .30897 L
.66928 .30897 L
.66948 .30897 L
.66966 .30897 L
.66985 .30897 L
.67025 .30897 L
.67097 .30898 L
.67266 .309 L
.67421 .30902 L
.67497 .30903 L
.67538 .30903 L
.67581 .30904 L
.67618 .30904 L
.6766 .30904 L
.67678 .30904 L
.67697 .30904 L
.67716 .30904 L
.67733 .30904 L
.67743 .30904 L
.67753 .30904 L
.67761 .30904 L
.67771 .30904 L
.67781 .30904 L
.67786 .30904 L
.67792 .30904 L
.67802 .30904 L
.67811 .30904 L
.67821 .30904 L
.6783 .30904 L
.67846 .30904 L
.67865 .30904 L
.67884 .30904 L
.67926 .30904 L
.6797 .30904 L
.6805 .30903 L
.68211 .30902 L
.68295 .30902 L
.68384 .30901 L
.68464 .30901 L
.68509 .30901 L
.68552 .30901 L
.68572 .309 L
.68591 .309 L
.68608 .309 L
.68626 .309 L
Mistroke
.68636 .309 L
.68646 .309 L
.68655 .309 L
.68664 .309 L
.68675 .309 L
.68684 .309 L
.68695 .309 L
.687 .309 L
.68706 .309 L
.68716 .309 L
.68726 .309 L
.68748 .309 L
.68768 .309 L
.68788 .30901 L
.68863 .30901 L
.68943 .30901 L
.69031 .30901 L
.69201 .30902 L
.69281 .30902 L
.69355 .30902 L
.69392 .30902 L
.69432 .30902 L
.69454 .30902 L
.69476 .30902 L
.69495 .30902 L
.69505 .30902 L
.69515 .30902 L
.69524 .30902 L
.69534 .30902 L
.69544 .30902 L
.69554 .30902 L
.69564 .30902 L
.69569 .30902 L
.69575 .30902 L
.69584 .30902 L
.69594 .30902 L
.69612 .30902 L
.69629 .30902 L
.69667 .30902 L
.69705 .30902 L
.69746 .30902 L
.69829 .30902 L
.69978 .30902 L
.70066 .30902 L
.70149 .30902 L
.70223 .30901 L
.70265 .30901 L
.70304 .30901 L
.70322 .30901 L
.70342 .30901 L
Mistroke
.70358 .30901 L
.70377 .30901 L
.70388 .30901 L
.70398 .30901 L
.70408 .30901 L
.70418 .30901 L
.70428 .30901 L
.70437 .30901 L
.70446 .30901 L
.70457 .30901 L
.70467 .30901 L
.70476 .30901 L
.70498 .30901 L
.70518 .30901 L
.70541 .30901 L
.70618 .30901 L
.707 .30902 L
.70789 .30902 L
.70951 .30902 L
.71033 .30902 L
.7111 .30902 L
.71149 .30902 L
.71191 .30902 L
.71214 .30902 L
.71226 .30902 L
.71237 .30902 L
.71247 .30902 L
.71257 .30902 L
.71262 .30902 L
.71268 .30902 L
.71273 .30902 L
.71279 .30902 L
.71289 .30902 L
.71298 .30902 L
.71309 .30902 L
.71319 .30902 L
.71328 .30902 L
.71336 .30902 L
.71355 .30902 L
.71375 .30902 L
.71396 .30902 L
.71439 .30902 L
.71526 .30902 L
.71608 .30902 L
.71757 .30902 L
.71841 .30902 L
.71919 .30902 L
.71959 .30902 L
.71997 .30902 L
.72018 .30902 L
Mistroke
.7204 .30902 L
.72061 .30902 L
.7208 .30902 L
.72091 .30902 L
.721 .30902 L
.72111 .30902 L
.72117 .30902 L
.72123 .30902 L
.72128 .30902 L
.72134 .30902 L
.72145 .30902 L
.72151 .30902 L
.72157 .30902 L
.72162 .30902 L
.72168 .30902 L
.72178 .30902 L
.72189 .30902 L
.72211 .30902 L
.72231 .30902 L
.72249 .30902 L
.72334 .30902 L
.72413 .30902 L
.72562 .30902 L
.7264 .30902 L
.72723 .30902 L
.72793 .30902 L
.72833 .30902 L
.72871 .30902 L
.72891 .30902 L
.72911 .30902 L
.72932 .30902 L
.72943 .30902 L
.72949 .30902 L
.72954 .30902 L
.72964 .30902 L
.72974 .30902 L
.72984 .30902 L
.72989 .30902 L
.72995 .30902 L
.73004 .30902 L
.73013 .30902 L
.73024 .30902 L
.73033 .30902 L
.73051 .30902 L
.7307 .30902 L
.73104 .30902 L
.73182 .30902 L
.73485 .30902 L
.7356 .30902 L
.7364 .30902 L
Mistroke
.73682 .30902 L
.73704 .30902 L
.73727 .30902 L
.73749 .30902 L
.73769 .30902 L
.73778 .30902 L
.73789 .30902 L
.73798 .30902 L
.73807 .30902 L
.73818 .30902 L
.73827 .30902 L
.73836 .30902 L
.73845 .30902 L
.73855 .30902 L
.73866 .30902 L
.73885 .30902 L
.73923 .30902 L
.73958 .30902 L
.74043 .30902 L
.74124 .30902 L
.74271 .30902 L
.74355 .30902 L
.74396 .30902 L
.74434 .30902 L
.74471 .30902 L
.74511 .30902 L
.74533 .30902 L
.74554 .30902 L
.74573 .30902 L
.74584 .30902 L
.74594 .30902 L
.74604 .30902 L
.74614 .30902 L
.74624 .30902 L
.7463 .30902 L
.74635 .30902 L
.74645 .30902 L
.74654 .30902 L
.74665 .30902 L
.74674 .30902 L
.74685 .30902 L
.74696 .30902 L
.74717 .30902 L
.74763 .30902 L
.74803 .30902 L
.74839 .30902 L
.7492 .30902 L
.75067 .30902 L
.75142 .30902 L
.7522 .30902 L
Mistroke
.75262 .30902 L
.75307 .30902 L
.75327 .30902 L
.75348 .30902 L
.75369 .30902 L
.75387 .30902 L
.75406 .30902 L
.75417 .30902 L
.75427 .30902 L
.75436 .30902 L
.75444 .30902 L
.75454 .30902 L
.75464 .30902 L
.75474 .30902 L
.75479 .30902 L
.75484 .30902 L
.75504 .30902 L
.75514 .30902 L
.75526 .30902 L
.75548 .30902 L
.7559 .30902 L
.75635 .30902 L
.75717 .30902 L
.75877 .30902 L
.75962 .30902 L
.76008 .30902 L
.76051 .30902 L
.76093 .30902 L
.76131 .30902 L
.76151 .30902 L
.76173 .30902 L
.76185 .30902 L
.76196 .30902 L
.76207 .30902 L
.76218 .30902 L
.76228 .30902 L
.76237 .30902 L
.76245 .30902 L
.76254 .30902 L
.76264 .30902 L
.76273 .30902 L
.76283 .30902 L
.76293 .30902 L
.76303 .30902 L
.76315 .30902 L
.76335 .30902 L
.76372 .30902 L
.76412 .30902 L
.76449 .30902 L
.76532 .30902 L
Mistroke
.76701 .30902 L
.76785 .30902 L
.76826 .30902 L
.76864 .30902 L
.76901 .30902 L
.76935 .30902 L
.76973 .30902 L
.76993 .30902 L
.77013 .30902 L
.77022 .30902 L
.77032 .30902 L
.77042 .30902 L
.7705 .30902 L
.7706 .30902 L
.77066 .30902 L
.77071 .30902 L
.77081 .30902 L
.77091 .30902 L
.77101 .30902 L
.77112 .30902 L
.77131 .30902 L
.77154 .30902 L
.77174 .30902 L
.7725 .30902 L
.77323 .30902 L
.77483 .30902 L
.77553 .30902 L
.77629 .30902 L
.77671 .30902 L
.7771 .30902 L
.77748 .30902 L
.77766 .30902 L
.77787 .30902 L
.77798 .30902 L
.77809 .30902 L
.77819 .30902 L
.77829 .30902 L
.77834 .30902 L
.7784 .30902 L
.77846 .30902 L
.77852 .30902 L
.77863 .30902 L
.77869 .30902 L
.77874 .30902 L
.77884 .30902 L
.77893 .30902 L
.77914 .30902 L
.77934 .30902 L
.77955 .30902 L
.78037 .30902 L
Mistroke
.78126 .30902 L
.78288 .30902 L
.78371 .30902 L
.78448 .30902 L
.78486 .30902 L
.78528 .30902 L
.78552 .30902 L
.78563 .30902 L
.78574 .30902 L
.78585 .30902 L
.78594 .30902 L
.78605 .30902 L
.78611 .30902 L
.78616 .30902 L
.78626 .30902 L
.78636 .30902 L
.78645 .30902 L
.78654 .30902 L
.78664 .30902 L
.78675 .30902 L
.78695 .30902 L
.78716 .30902 L
.78738 .30902 L
.78778 .30902 L
.78926 .30902 L
.79084 .30902 L
.79154 .30902 L
.79229 .30902 L
.79269 .30902 L
.79305 .30902 L
.79325 .30902 L
.79344 .30902 L
.79354 .30902 L
.79365 .30902 L
.79375 .30902 L
.79385 .30902 L
.79395 .30902 L
.79405 .30902 L
.79415 .30902 L
.79424 .30902 L
.79434 .30902 L
.7944 .30902 L
.79446 .30902 L
.79466 .30902 L
.79486 .30902 L
.79508 .30902 L
.79552 .30902 L
.79633 .30902 L
.79707 .30902 L
.79794 .30902 L
Mistroke
.79875 .30902 L
.79954 .30902 L
.79989 .30902 L
.80026 .30902 L
.80048 .30902 L
.80068 .30902 L
.80088 .30902 L
.80107 .30902 L
.80126 .30902 L
.80137 .30902 L
.80148 .30902 L
.80154 .30902 L
.8016 .30902 L
.80166 .30902 L
.80171 .30902 L
.80181 .30902 L
.80187 .30902 L
.80192 .30902 L
.80202 .30902 L
.80211 .30902 L
.80221 .30902 L
.80232 .30902 L
.80253 .30902 L
.80273 .30902 L
.80347 .30902 L
.80514 .30902 L
.80595 .30902 L
.8068 .30902 L
.80753 .30902 L
.80795 .30902 L
.80813 .30902 L
.80834 .30902 L
.80852 .30902 L
.80871 .30902 L
.80882 .30902 L
.80892 .30902 L
.80902 .30902 L
.80911 .30902 L
.8092 .30902 L
.80929 .30902 L
.80937 .30902 L
.80945 .30902 L
.80954 .30902 L
.80964 .30902 L
.80973 .30902 L
.80982 .30902 L
.81002 .30902 L
.81021 .30902 L
.81064 .30902 L
.81142 .30902 L
Mistroke
.81293 .30902 L
.81372 .30902 L
.81456 .30902 L
.81499 .30902 L
.81546 .30902 L
.81566 .30902 L
.81588 .30902 L
.81609 .30902 L
.81628 .30902 L
.81638 .30902 L
.81649 .30902 L
.8166 .30902 L
.81666 .30902 L
.81672 .30902 L
.81682 .30902 L
.81692 .30902 L
.81702 .30902 L
.81707 .30902 L
.81713 .30902 L
.81723 .30902 L
.81732 .30902 L
.81753 .30902 L
.81772 .30902 L
.8179 .30902 L
.81868 .30902 L
.81951 .30902 L
.82099 .30902 L
.82175 .30902 L
.82217 .30902 L
.82257 .30902 L
.82294 .30902 L
.82313 .30902 L
.82334 .30902 L
.82351 .30902 L
.8237 .30902 L
.82379 .30902 L
.82388 .30902 L
.82396 .30902 L
.82404 .30902 L
.82414 .30902 L
.82423 .30902 L
.82433 .30902 L
.82439 .30902 L
.82444 .30902 L
.82452 .30902 L
.82462 .30902 L
.82471 .30902 L
.82481 .30902 L
.82502 .30902 L
.82521 .30902 L
Mistroke
.82565 .30902 L
.82651 .30902 L
.82734 .30902 L
.82817 .30902 L
.82895 .30902 L
.82965 .30902 L
.83001 .30902 L
.83041 .30902 L
.83081 .30902 L
.83103 .30902 L
.83113 .30902 L
.83123 .30902 L
.83132 .30902 L
.83142 .30902 L
.83151 .30902 L
.8316 .30902 L
.83169 .30902 L
.83179 .30902 L
.83189 .30902 L
.83199 .30902 L
.83209 .30902 L
.83219 .30902 L
.83231 .30902 L
.83241 .30902 L
.8328 .30902 L
.83322 .30902 L
.83367 .30902 L
.83527 .30902 L
.83611 .30902 L
.83657 .30902 L
.837 .30902 L
.83742 .30902 L
.8378 .30902 L
.838 .30902 L
.83822 .30902 L
.83834 .30902 L
.83845 .30902 L
.83856 .30902 L
.83867 .30902 L
.83878 .30902 L
.83888 .30902 L
.83897 .30902 L
.83907 .30902 L
.83915 .30902 L
.83924 .30902 L
.83932 .30902 L
.83942 .30902 L
.83952 .30902 L
.83963 .30902 L
.83984 .30902 L
Mistroke
.84021 .30902 L
.84061 .30902 L
.84097 .30902 L
.84181 .30902 L
.84267 .30902 L
.84349 .30902 L
.84427 .30902 L
.84471 .30902 L
.84512 .30902 L
.84531 .30902 L
.8455 .30902 L
.84566 .30902 L
.84584 .30902 L
.84593 .30902 L
.84603 .30902 L
.84612 .30902 L
.84621 .30902 L
.84631 .30902 L
.8464 .30902 L
.8465 .30902 L
.8466 .30902 L
.8467 .30902 L
.84679 .30902 L
.84697 .30902 L
.84718 .30902 L
.84738 .30902 L
.84778 .30902 L
.8482 .30902 L
.84968 .30902 L
.8505 .30902 L
.85128 .30902 L
.85198 .30902 L
.85238 .30902 L
.85274 .30902 L
.85293 .30902 L
.8531 .30902 L
.8532 .30902 L
.8533 .30902 L
.85335 .30902 L
.8534 .30902 L
.8535 .30902 L
.85356 .30902 L
.85361 .30902 L
.85371 .30902 L
.85381 .30902 L
.85387 .30902 L
.85392 .30902 L
.85401 .30902 L
.85411 .30902 L
.85431 .30902 L
Mistroke
.85453 .30902 L
.85473 .30902 L
.85518 .30902 L
.85599 .30902 L
.85766 .30902 L
.85839 .30902 L
.85878 .30902 L
.85919 .30902 L
.8596 .30902 L
.85977 .30902 L
.85997 .30902 L
.86015 .30902 L
.86032 .30902 L
.86041 .30902 L
.8605 .30902 L
.8606 .30902 L
.86069 .30902 L
.86078 .30902 L
.86088 .30902 L
.86099 .30902 L
.86109 .30902 L
.86118 .30902 L
.86126 .30902 L
.86145 .30902 L
.86165 .30902 L
.86187 .30902 L
.86227 .30902 L
.86383 .30902 L
.86465 .30902 L
.86554 .30902 L
.86596 .30902 L
.86639 .30902 L
.86676 .30902 L
.86697 .30902 L
.86717 .30902 L
.86726 .30902 L
.86737 .30902 L
.86746 .30902 L
.86755 .30902 L
.86764 .30902 L
.86774 .30902 L
.86782 .30902 L
.8679 .30902 L
.86801 .30902 L
.8681 .30902 L
.86819 .30902 L
.86828 .30902 L
.86839 .30902 L
.8685 .30902 L
.86869 .30902 L
Mistroke
.86912 .30902 L
.86952 .30902 L
.87041 .30902 L
.87125 .30902 L
.87203 .30902 L
.87282 .30902 L
.87317 .30902 L
.87354 .30902 L
.87376 .30902 L
.87395 .30902 L
.87416 .30902 L
.87434 .30902 L
.87454 .30902 L
.87465 .30902 L
.8747 .30902 L
.87476 .30902 L
.87482 .30902 L
.87487 .30902 L
.87493 .30902 L
.87499 .30902 L
.87505 .30902 L
.8751 .30902 L
.8752 .30902 L
.87529 .30902 L
.87539 .30902 L
.87557 .30902 L
.87579 .30902 L
.87598 .30902 L
.87681 .30902 L
.87829 .30902 L
.87903 .30902 L
.87982 .30902 L
.88027 .30902 L
.88068 .30902 L
.88088 .30902 L
.88109 .30902 L
.8813 .30902 L
.88148 .30902 L
.88158 .30902 L
.88168 .30902 L
.88177 .30902 L
.88186 .30902 L
.88196 .30902 L
.88201 .30902 L
.88207 .30902 L
.88217 .30902 L
.88227 .30902 L
.88236 .30902 L
.88245 .30902 L
.88262 .30902 L
Mistroke
.883 .30902 L
.88341 .30902 L
.88379 .30902 L
.88466 .30902 L
.88616 .30902 L
.88658 .30902 L
.88701 .30902 L
.88739 .30902 L
.8878 .30902 L
.88802 .30902 L
.88822 .30902 L
.88832 .30902 L
.88842 .30902 L
.88852 .30902 L
.88861 .30902 L
.88867 .30902 L
.88872 .30902 L
.88878 .30902 L
.88884 .30902 L
.8889 .30902 L
.88896 .30902 L
.88902 .30902 L
.88908 .30902 L
.88914 .30902 L
.88919 .30902 L
.88929 .30902 L
.8894 .30902 L
.88951 .30902 L
.88992 .30902 L
.89035 .30902 L
.89113 .30902 L
.89272 .30902 L
.89341 .30902 L
.89417 .30902 L
.89459 .30902 L
.89479 .30902 L
.89497 .30902 L
.89516 .30902 L
.89534 .30902 L
.89544 .30902 L
.89553 .30902 L
.89563 .30902 L
.89573 .30902 L
.89583 .30902 L
.89593 .30902 L
.89598 .30902 L
.89604 .30902 L
.89614 .30902 L
.89624 .30902 L
.89634 .30902 L
Mistroke
.89653 .30902 L
.89695 .30902 L
.89741 .30902 L
.89909 .30902 L
.89983 .30902 L
.90022 .30902 L
.90064 .30902 L
.90105 .30902 L
.90142 .30902 L
.9016 .30902 L
.9018 .30902 L
.90198 .30902 L
.90215 .30902 L
.90224 .30902 L
.90234 .30902 L
.90243 .30902 L
.90252 .30902 L
.90262 .30902 L
.90268 .30902 L
.90273 .30902 L
.90282 .30902 L
.90292 .30902 L
.90298 .30902 L
.90303 .30902 L
.90315 .30902 L
.90335 .30902 L
.90374 .30902 L
.90412 .30902 L
.90453 .30902 L
.90526 .30902 L
.90692 .30902 L
.90732 .30902 L
.90774 .30902 L
.90796 .30902 L
.9082 .30902 L
.90843 .30902 L
.90863 .30902 L
.90884 .30902 L
.90893 .30902 L
.90903 .30902 L
.90914 .30902 L
.90924 .30902 L
.9093 .30902 L
.90936 .30902 L
.90941 .30902 L
.90946 .30902 L
.90956 .30902 L
.90966 .30902 L
.90971 .30902 L
.90977 .30902 L
Mistroke
.90987 .30902 L
.91007 .30902 L
.91025 .30902 L
.91063 .30902 L
.91104 .30902 L
.91178 .30902 L
.91258 .30902 L
.91344 .30902 L
.91384 .30902 L
.91426 .30902 L
.91465 .30902 L
.91501 .30902 L
.91535 .30902 L
.91554 .30902 L
.91571 .30902 L
.91581 .30902 L
.9159 .30902 L
.916 .30902 L
.9161 .30902 L
.91619 .30902 L
.91628 .30902 L
.91637 .30902 L
.91647 .30902 L
.91653 .30902 L
.91658 .30902 L
.91668 .30902 L
.9169 .30902 L
.91729 .30902 L
.91771 .30902 L
.91817 .30902 L
.91979 .30902 L
.92062 .30902 L
.92102 .30902 L
.92139 .30902 L
.92178 .30902 L
.92199 .30902 L
.9222 .30902 L
.9223 .30902 L
.92242 .30902 L
.92251 .30902 L
.92262 .30902 L
.92268 .30902 L
.92274 .30902 L
.9228 .30902 L
.92286 .30902 L
.92291 .30902 L
.92297 .30902 L
.92302 .30902 L
.92308 .30902 L
.92318 .30902 L
Mistroke
.92329 .30902 L
.9234 .30902 L
.92351 .30902 L
.92391 .30902 L
.92434 .30902 L
.9248 .30902 L
.92642 .30902 L
.92723 .30902 L
.92766 .30902 L
.92812 .30902 L
.92852 .30902 L
.92874 .30902 L
.92885 .30902 L
.92896 .30902 L
.92905 .30902 L
.92915 .30902 L
.92925 .30902 L
.92933 .30902 L
.92943 .30902 L
.92953 .30902 L
.92958 .30902 L
.92963 .30902 L
.92973 .30902 L
.92983 .30902 L
.92992 .30902 L
.93013 .30902 L
.93031 .30902 L
.93049 .30902 L
.93133 .30902 L
.93302 .30902 L
.93379 .30902 L
.93421 .30902 L
.93461 .30902 L
.93498 .30902 L
.93519 .30902 L
.93538 .30902 L
.93554 .30902 L
.93572 .30902 L
.93581 .30902 L
.93591 .30902 L
.936 .30902 L
.93608 .30902 L
.93618 .30902 L
.93627 .30902 L
.93636 .30902 L
.93647 .30902 L
.93657 .30902 L
.93668 .30902 L
.93688 .30902 L
.93723 .30902 L
Mistroke
.93762 .30902 L
.93928 .30902 L
.94009 .30902 L
.94086 .30902 L
.94128 .30902 L
.9415 .30902 L
.94174 .30902 L
.94194 .30902 L
.94204 .30902 L
.94216 .30902 L
.94226 .30902 L
.94235 .30902 L
.94245 .30902 L
.94254 .30902 L
.94264 .30902 L
.9427 .30902 L
.94275 .30902 L
.94284 .30902 L
.94294 .30902 L
.94304 .30902 L
.94312 .30902 L
.94331 .30902 L
.94352 .30902 L
.94371 .30902 L
.94413 .30902 L
.94561 .30902 L
.94636 .30902 L
.94715 .30902 L
.94756 .30902 L
.94778 .30902 L
.94801 .30902 L
.94823 .30902 L
.94843 .30902 L
.94852 .30902 L
.94863 .30902 L
.94872 .30902 L
.94881 .30902 L
.94886 .30902 L
.94892 .30902 L
.94902 .30902 L
.94907 .30902 L
.94913 .30902 L
.94919 .30902 L
.94924 .30902 L
.94934 .30902 L
.94939 .30902 L
.94945 .30902 L
.94954 .30902 L
.94964 .30902 L
.94983 .30902 L
Mistroke
.95 .30902 L
.95039 .30902 L
.9512 .30902 L
.95208 .30902 L
.95291 .30902 L
.95368 .30902 L
.95407 .30902 L
.95449 .30902 L
.95473 .30902 L
.95495 .30902 L
.95516 .30902 L
.95527 .30902 L
.95538 .30902 L
.95548 .30902 L
.95557 .30902 L
.95566 .30902 L
.95575 .30902 L
.95585 .30902 L
.95591 .30902 L
.95596 .30902 L
.95606 .30902 L
.95615 .30902 L
.95634 .30902 L
.9565 .30902 L
.95688 .30902 L
.95769 .30902 L
.95854 .30902 L
.9593 .30902 L
.95972 .30902 L
.96012 .30902 L
.96049 .30902 L
.96089 .30902 L
.96106 .30902 L
.96125 .30902 L
.96141 .30902 L
.96159 .30902 L
.96169 .30902 L
.96178 .30902 L
.96188 .30902 L
.96198 .30902 L
.96208 .30902 L
.96217 .30902 L
.96225 .30902 L
.96234 .30902 L
.96244 .30902 L
.96255 .30902 L
.96276 .30902 L
.96297 .30902 L
.96315 .30902 L
.96386 .30902 L
Mistroke
.96462 .30902 L
.96544 .30902 L
.96587 .30902 L
.96632 .30902 L
.96672 .30902 L
.96716 .30902 L
.96735 .30902 L
.96756 .30902 L
.96776 .30902 L
.96794 .30902 L
.96804 .30902 L
.96814 .30902 L
.96822 .30902 L
.96832 .30902 L
.96842 .30902 L
.96847 .30902 L
.96853 .30902 L
.96863 .30902 L
.96872 .30902 L
.96882 .30902 L
.96891 .30902 L
.96908 .30902 L
.96926 .30902 L
.96945 .30902 L
.97032 .30902 L
.97111 .30902 L
.97196 .30902 L
.97276 .30902 L
.97311 .30902 L
.97348 .30902 L
.97367 .30902 L
.97388 .30902 L
.97406 .30902 L
.97426 .30902 L
.97439 .30902 L
.97444 .30902 L
.97451 .30902 L
.97456 .30902 L
.97462 .30902 L
.97468 .30902 L
.97474 .30902 L
.9748 .30902 L
.97486 .30902 L
.97492 .30902 L
.97498 .30902 L
.97508 .30902 L
.97514 .30902 L
.97519 .30902 L
.97532 .30902 L
.97544 .30902 L
Mistroke
.9757 .30902 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{421.375, 260.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008>0001AB000`400?l00000o`00003ooooooooo
oooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo
003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooo
oooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool0
0?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooooooo
ool@ooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooo
ooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo0ol0003o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0
003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo
00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`
ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLoooo
o`00<?ooool3o`000?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?oo
ool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0
033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomco
oooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooo
oooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool3o`000?oooooo
g?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0013ooooo0_o^k^h3ooooo`;ok^k^6Oooool00ol0003oooooooooo`3o
ooooomcooooo000;ooooo`;o000000[o410@ooooooooooook^k^oeEEEOo^k^koooooonk^k_mEEEGo
k^k^0oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h:ooooo`03o`000?oo
oooooooo0?oooooog?ooool000cooooo00?o0000ooooooooool00_ooool01Oo^k^koEEEEomgMgOmE
EEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00[ooooo
00?o0000ooooooooool0oooooooLooooo`0000?oooooo`000?l000001?l00002ooooo`Go00001?oo
ool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooo
oa0@400:ooooo`03o`000?oooooooooo08Kooooo0_l0000:ooooo`03o`000?oooooooooo0?oooooo
Aoooool000Wooooo00CoA4A4omgMgOoooooo00001?ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Ko
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000[ooooo00?o0000oooo
ooooool0Q_ooool2o`0000[ooooo00?o0000ooooooooool0oooooom7ooooo`002Oooool01?oMgMgo
EEEEooooool00003ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000:ooooo`Co0000QOooool2o`0000[ooooo
00?o0000ooooooooool0oooooom7ooooo`002_ooool00omgMgOoc<c<o`000003ooooo`;ok^k^0ooo
ool2onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00[ooooo
00?o0000ooooooooool0Q_ooool2o`0000[ooooo00?o0000ooooooooool0oooooom7ooooo`002_oo
ool00oo^k^koA4A4o`00000?ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`;o00001Oooool00ol0003oooooooooo`26ooooo`;o00002_ooool2o`000?oooooo
B?ooool000_ooooo00?oMgMgo`000?ooool03?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo08Ko
oooo0_l0000:ooooo`;o0000oooooom8ooooo`00:?ooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo08Kooooo0_l00009ooooo`03o`000?oooooo00000?ooooooB?ooool002Sooooo
0ol00005ooooo`03o`000?oooooooooo08Kooooo0_l00009ooooo`03o`000?oooooo00000?oooooo
B?ooool002Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`26ooooo`;o00002Ooo
ool00ol0003oooooo`00003oooooodSooooo000Zooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0Q_ooool2o`0000Wooooo00?o0000ooooool00000oooooom8ooooo`00<?ooool00ol0
003oooooooooo`26ooooo`;o00002Oooool00ol0003oooooo`00003oooooodSooooo000`ooooo`03
o`000?oooooooooo08Kooooo0_l00009ooooo`03o`000?oooooo00000?ooooooB?ooool0033ooooo
00?o0000ooooooooool0Q_ooool2o`0000Wooooo00?o0000ooooool00000oooooom8ooooo`00<?oo
ool00ol0003oooooooooo`25ooooo`03o`000?oooooo000000Wooooo00?o0000ooooool00000oooo
oom8ooooo`00<?ooool3o`0008Gooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00
003oooooodSooooo000`ooooo`03o`000?oooooooooo08Gooooo00Co0000oooooooooooo00002?oo
ool00ol0003oooooo`00003oooooodSooooo000`ooooo`03o`000?oooooooooo08Gooooo00Co0000
oooooooooooo00002?ooool00ol0003oooooo`00003oooooodSooooo000`ooooo`03o`000?oooooo
oooo08Gooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003oooooodSooooo000`
ooooo`03o`000?oooooooooo08Gooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00
003oooooodSooooo000`ooooo`03o`000?oooooooooo08Gooooo00Co0000oooooooooooo00002?oo
ool00ol0003oooooo`00003oooooodSooooo000`ooooo`03o`000?oooooooooo08Gooooo00Co0000
oooooooooooo00002?ooool00ol0003oooooo`000009ooooo`03o`000?oooooooooo0?oooooo??oo
ool0033ooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`08ooooo`04o`000?oooooo
ooooo`0000Sooooo00?o0000ooooool000002Oooool2o`000?oooooo?Oooool0033ooooo00?o0000
ooooooooool0N_ooool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`0000Sooooo00?o
0000ooooool000002Oooool2o`000?oooooo?Oooool0033ooooo00?o0000ooooooooool0NOooool2
o`0000[ooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`000009ooooo`;o0000oooo
oolmooooo`00<?ooool00ol0003oooooooooo`1iooooo`;o00002_ooool01?l0003oooooooooool0
0008ooooo`03o`000?oooooo000000Wooooo0_l0003oooooocgooooo000`ooooo`03o`000?oooooo
oooo07Wooooo0_l0000:ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool000002Ooo
ool2o`000?oooooo?Oooool0033ooooo0ol0001iooooo`03o`000?oooooo000000Wooooo00Co0000
oooooooooooo00002?ooool00ol0003oooooo`000009ooooo`;o0000oooooolmooooo`00<?ooool0
0ol0003oooooooooo`1iooooo`03o`000?oooooo000000Wooooo00Co0000oooooooooooo00002?oo
ool00ol0003oooooo`000009ooooo`;o0000oooooolmooooo`00<?ooool00ol0003oooooooooo`1i
ooooo`03o`000?oooooo000000Wooooo00Co0000oooooooooooo00002?ooool01?l0003ooooooooo
ool00008ooooo`;o0000oooooolmooooo`00<?ooool00ol0003oooooooooo`1iooooo`03o`000?oo
oooo000000Wooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00007ooooo`03
o`000?oooooo00000?oooooo?Oooool0033ooooo00?o0000ooooooooool0NOooool00ol0003ooooo
o`000009ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001oooool00ol0
003oooooo`00003oooooocgooooo000`ooooo`03o`000?oooooooooo07Wooooo00?o0000ooooool0
00002Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000
ooooool00000oooooolmooooo`00<?ooool00ol0003oooooooooo`1iooooo`03o`000?oooooo0000
00Sooooo00Go0000ooooooooooooooooo`000008ooooo`04o`000?ooooooooooo`0000Oooooo00?o
0000ooooool00000oooooolmooooo`00<?ooool00ol0003oooooooooo`1iooooo`03o`000?oooooo
000000Sooooo00Go0000ooooooooooooooooo`000008ooooo`04o`000?ooooooooooo`0000Oooooo
00?o0000ooooool00000oooooolmooooo`00<?ooool00ol0003oooooooooo`1iooooo`03o`000?oo
oooo000000Sooooo00Go0000ooooooooooooooooo`000008ooooo`04o`000?ooooooooooo`0000Oo
oooo00?o0000ooooool00000oooooolmooooo`00<?ooool00ol0003oooooooooo`1iooooo`03o`00
0?oooooo000000Sooooo00Go0000ooooooooooooooooo`000008ooooo`04o`000?ooooooooooo`00
00Oooooo00?o0000ooooool00000oooooolmooooo`00<?ooool00ol0003oooooooooo`1iooooo`03
o`000?oooooo000000Sooooo00Go0000ooooooooooooooooo`000008ooooo`04o`000?oooooooooo
o`0000Oooooo00?o0000ooooool00000oooooolmooooo`00<?ooool3o`0007Wooooo00?o0000oooo
ool000002?ooool01Ol0003ooooooooooooooooo000000Sooooo00Co0000oooooooooooo00001ooo
ool00ol0003oooooo`00003oooooocgooooo000`ooooo`03o`000?oooooooooo07Wooooo00?o0000
ooooool000002?ooool01Ol0003ooooooooooooooooo000000Sooooo00Co0000oooooooooooo0000
1oooool00ol0003oooooo`00003oooooocgooooo000`ooooo`03o`000?oooooooooo07Sooooo00Co
0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Sooooo00Co0000oooooooo
oooo00001oooool00ol0003oooooo`00003oooooocgooooo000`ooooo`03o`000?oooooooooo07So
oooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Sooooo00Co0000
oooooooooooo00001oooool00ol0003oooooo`00003oooooocgooooo000`ooooo`03o`000?oooooo
oooo07Sooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Sooooo
00Co0000oooooooooooo00001oooool00ol0003oooooo`00003oooooocgooooo000`ooooo`03o`00
0?oooooooooo07Sooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo0000
00Sooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00003oooooocgooooo000`oooo
o`03o`000?oooooooooo07Sooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooo
oooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`000?oo
oooo??ooool0013ooooo0_o^k^h3ooooo`;ok^k^6Oooool00ol0003oooooooooo`1hooooo`04o`00
0?ooooooooooo`0000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05
o`000?ooooooooooooooool000001oooool01?l0003oooooooooool0003ooooooccooooo0009oooo
o`Go00000_ooool01oo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?oo
ooooooooonk^k_lb<S;o0000oc8b<_o^k^h:ooooo`03o`000?oooooooooo07Sooooo00Co0000oooo
oooooooo00002?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000
ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool0
oooooolaooooo`002Oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00Gok^k^oeEEEOoMgMgo
EEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0:oooo
o`03o`000?oooooooooo07Sooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?oo
ooooooooo`0000Sooooo00?o0000ooooooooool0oooooolaooooo`0000?oooooo`000?l000001?l0
0003ooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?ogMgMo`000?oMgMd01oooool00ol0003ooooooooo
o`02ooooo`05oa0@4?ooooooooooooooool@41002_ooool00ol0003oooooooooo`1hooooo`04o`00
0?ooooooooooo`0000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05
o`000?ooooooooooooooool000001oooool01?l0003oooooooooool00007ooooo`;o0000oooooolc
ooooo`002oooool00onHV9So8B4Qonk^kP03ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000002_ooool00ol0003ooooooooo
o`1hooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`04ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool00007oooo
o`;o0000oooooolcooooo`003?ooool02omgMgOoIVIVooooooooooook^k^oeEEEOo^k^koooooonk^
k_mEEEGok^k^00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000[o
oooo1?l0001gooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool0
0007ooooo`03o`000?oooooo00000?oooooo<_ooool000gooooo00?o0000ooooooooool00_o^k^h3
ooooo`;ok^k^1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41002_oo
ool00ol0003oooooooooo`1hooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001oooool01?l0003o
ooooooooool00007ooooo`03o`000?oooooo00000?oooooo<_ooool000Wooooo00Go0000okZj^_oo
ooooV9RHoa0@400>ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03
ooooo`;o00001Oooool00ol0003oooooooooo`1hooooo`04o`000?ooooooooooo`0000Sooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000
1oooool01?l0003oooooooooool00007ooooo`03o`000?oooooo00000?oooooo<_ooool000Wooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c00<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP02ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0N?ooool0
1?l0003oooooooooool00008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo00001oooool00ol0003o
ooooo`00003ooooooc;ooooo000Xooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool0N?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01?ooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo00001ooo
ool00ol0003oooooo`00003ooooooc;ooooo000Xooooo`?o00001Oooool00ol0003oooooooooo`1/
ooooo`;o00002_ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001oooool01?l0003ooooo
ooooool00007ooooo`03o`000?oooooo00000?oooooo<_ooool002Wooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`1/ooooo`;o00002_ooool01Ol0003ooooooooooooooooo000000Oo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooooooo
ool000001oooool01?l0003oooooooooool00007ooooo`03o`000?oooooo00000?oooooo<_ooool0
02[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1/ooooo`;o00002_ooool01Ol0
003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool00007ooooo`03o`00
0?oooooo00000?oooooo<_ooool0033ooooo00?o0000ooooooooool0K?ooool2o`0000[ooooo00Go
0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo00001oooool00ol0
003oooooo`00003ooooooc;ooooo000`ooooo`03o`000?oooooooooo06cooooo00?o0000ooooool0
00002Oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool0
0007ooooo`03o`000?oooooo00000?oooooo<_ooool0033ooooo00?o0000ooooooooool0K?ooool0
0ol0003oooooo`000009ooooo`05o`000?ooooooooooooooool000001oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000007ooooo`04o`00
0?ooooooooooo`0000Oooooo00?o0000ooooool00000oooooolbooooo`00<?ooool00ol0003ooooo
ooooo`1[ooooo`04o`000?ooooooooooo`0000Wooooo00Go0000ooooooooooooooooo`000007oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo
000000Oooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00003ooooooc;ooooo000`
ooooo`?o0000Joooool01?l0003oooooooooool00009ooooo`05o`000?ooooooooooooooool00000
1oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooo
ooooo`000006ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool0003o
oooooc;ooooo000`ooooo`03o`000?oooooooooo06_ooooo00Co0000oooooooooooo00002Oooool0
1Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`04ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Ko
oooo00Co0000oooooooooooo0000oooooolbooooo`00<?ooool00ol0003oooooooooo`1[ooooo`04
o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo
000000Kooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`000?oooooo
<_ooool0033ooooo00?o0000ooooooooool0Joooool01?l0003oooooooooool00008ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?oooooooooooooo
ool000001_ooool01?l0003oooooooooool0003ooooooc;ooooo000`ooooo`03o`000?oooooooooo
06_ooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooo
ooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo
0000oooooolbooooo`00<?ooool00ol0003oooooooooo`1[ooooo`04o`000?ooooooooooo`0000So
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000oooo
ooooooooooooo`000006ooooo`04o`000?ooooooooooo`000?oooooo<_ooool0033ooooo00?o0000
ooooooooool0Joooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool00000
1_ooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo0?oooooo9oooool0033ooooo
00?o0000ooooooooool0Joooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`05o`000?oooooooooooooo
ool000001_ooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo0?oooooo9oooool0
033ooooo00?o0000ooooooooool0Joooool01?l0003oooooooooool00008ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`05o`000?oooooo
ooooooooool000001_ooool01?l0003oooooooooool00007ooooo`;o0000oooooolYooooo`00<?oo
ool00ol0003oooooooooo`1Zooooo`05o`000?ooooooooooooooool000002?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool01Ol0003ooooo
oooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo0000
0?oooooo:?ooool0033ooooo00?o0000ooooooooool0J_ooool01Ol0003ooooooooooooooooo0000
00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001_oo
ool00ol0003oooooo`00003oooooobSooooo000`ooooo`03o`000?oooooooooo06[ooooo00Go0000
ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooool00000oooooolXooooo`00<?ooool3o`0006[ooooo
00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooool00000oooooolXooooo`00<?ooool00ol0
003oooooooooo`1Zooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooo
oooo000000Kooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo00000?oooooo
:?ooool0033ooooo00?o0000ooooooooool0J_ooool01Ol0003ooooooooooooooooo000000Sooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool0
00001_ooool00ol0003oooooo`00003oooooobSooooo000`ooooo`03o`000?oooooooooo06[ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooool0
0000oooooolXooooo`00<?ooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo00000?oooooo:?ooool0033ooooo
00?o0000ooooooooool0C_ooool2onk^kP?ooooo0_o^k^hEooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
00Ko0000ooooooooooooooooo`000?ooool2onk^kP?ooooo00?o0000onk^k_l00000Goooool2onk^
kP?ooooo0_o^k^i>ooooo`;ok^k^0oooool2onk^kVcooooo000`ooooo`03o`000?oooooooooo04So
oooo00goA4A4o`000?l0003o<S8bomgMgOooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?o
oooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^1_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`Go000000Woooooonk^k_mEEEGok^k^ooooooo^k^ko0000onk^k_l000000_ooool4o`00
0008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hkooooo`Co000000?o410@ooooooooool0
0_ooool2ob4Q8@Gooooo00goA4A4o`000?l0003o<S8bomgMgOooooook^k^oeEEEOo^k^koooooonk^
k_mEEEGok^k^00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^>?ooool5
o`0000;ooooo00Ook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^GOooool0033ooooo00?o0000ooooooooool0Boooool02Omg
MgOo<S8booooooooooook^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`04o`000?ooooooooooooooo`;o
000000CoV9RHoooooonHV9SoMgMg1_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooo0000
ooooool000000_ooool01oo^k^koEEEEomgMgOmEEEGo0000ooooool000001?ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0?Oooool00ol0003oooooooooo`04ooooo`;o
8B4Q2?ooool02OmgMgOo<S8booooooooooook^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0hooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@00oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg05gooooo000`ooooo`03o`000?oooooooooo04cooooo00Oo0000oooo
ooooooooooooomgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00ol00003ooooo`03oa0@4?oo
oooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003oooooo`000?oooooo000000?ooooo
00CogMgMo`000?oMgMgo00000_ooool01Ol0003ooooooooooooooooo000000Cooooo00Go410@oooo
oooooooooooooa0@400mooooo`03o`000?oooooooooo00oooooo00Oo0000ooooooooooooooooomgM
gOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@03Wo
oooo00?oV9RHob4Q8Oo^k^h01Oooool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;o
oooo00Go410@oooooooooooooooooa0@401Mooooo`00<?ooool00ol0003oooooooooo`1;ooooo`09
ogMgMolb<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00Ko0000oooooooooooo0000
ooooool00003ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003o
ooooo`000?oooooo000000;ooooo00Gok^k^oeEEEOoMgMgoEEEEo`000002ooooo`05o`000?oooooo
ooooooooool000000_ooool3o`0000?ooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`0>ooooo`09ogMgMolb<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000003[ooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000005gooooo000`ooooo`03o`000?oooooooooo04Sooooo00go0000ob4Q8Ol0003o<S8b
olc<c?ooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00Ko0000oooooooooooo0000
ooooool00003ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool03ol0003o
ooooo`000?oooooo0000ooooooo^k^koEEEEonk^k_oooooo0000oeEEEOo^k^koooooo`000003oooo
o`03o`000?oooooooooo00?o00000oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
00_ooooo00go0000ob4Q8Ol0003o<S8bolc<c?ooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^
00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000003_ooooo00_oMgMg
ofIVI_ooooooooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`00001Mooooo`00<?ooool00ol0003oooooooooo`18oooo
o`03o`000?oooooooooo00?ooooo0_o^k^h3ooooo`;ok^k^1Oooool00ol0003oooooo`000002oooo
o`05oa0@4?l0003oooooooooool@41001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`06o`000?oooooo
0000ooooool0003ooooo0_o^k^h2ooooo`05o`000?o^k^kok^k^ooooool000000oooool00ol0003o
ooooooooo`02o`000005oa0@4?ooooooooooooooool@4100?Oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00?ooooo0_o^k^h3ooooo`;ok^k^1Oooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@4100??ooool00ol0003oooooooooo`02onk^kP?ooooo0_o^k^h5
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@401Mooooo`00<?ooool3
o`0004Sooooo00?o0000ooooooooool03oooool00ol0003oooooo`000002ooooo`05ogMgMol0003o
oooooiRHV?mgMgL01_ooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooo0000ooooool00000
1Oooool01Ol0003ooooooooooooooooo000000?ooooo00[o0000oooooooooooo0000ooooool0003o
V9RHoooooonHV9SoMgMg2?ooool2o`0003?ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`;o
0000;_ooool01Ol0003o^[ZjoooooonHV9So410@00kooooo00?o0000ooooooooool00_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Sooooo0_l0001Cooooo`00<?ooool00ol0003oooooooooo`18oooo
o`Co00003?ooool01OmEEEGoIVIVo`000?oooooo000000;ooooo00Gok^k^o`000?l0003o<S8bonk^
kP05ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ofIVI_l0003oooooo`000005ooooo`09
o`000?ooooooooooooooool0003ooooooeEEEOmVIVKo000000;ooooo00Oo0000ooooool0003o<S8b
o`000?lb<S;ok^k^00Oooooo00Co0000oooooooooooo0000<?ooool00omEEEGoIVIVo`00000=oooo
o`Co00003?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01oooool0
1?l0003oooooooooool0000]ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?ooool00omEEEGoIVIV
o`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01oooool01?l0003oooooooooool0001Boooo
o`00<?ooool00ol0003oooooooooo`1Looooo`05o`000?ooooooooooooooool000001Oooool4o`00
00?ooooo00?o0000ooooool000001oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool000001_ooool00ol0003oooooo`000006ooooo`Co000000Goooooo`000?ooooooooooo`00
001Nooooo`Co000000Goooooo`000?ooooooooooo`00001<ooooo`Co000000Goooooo`000?oooooo
ooooo`00001Booooo`00<?ooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01_ooool01ol0003ooooooooooooooooo0000ooooool000001oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001Oooool01?l0003oooooooooool0
000;ooooo`?o0000I?ooool3o`0005;ooooo0ol0001Cooooo`00<?ooool00ol0003oooooooooo`1K
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooo`000002
ooooo`03o`000?oooooo000000Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000000Gooooo00Co0000oooooooooooo00003?ooool00ol0003oooooooooo`1Tooooo`03o`00
0?oooooooooo05;ooooo00?o0000ooooooooool0D_ooool0033ooooo00?o0000ooooooooool0Fooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooool000000ol0
00000ooooooo0000ooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`000005ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`1Tooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0DOooool0033ooooo
00?o0000ooooooooool0Foooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo
00Go0000ooooooooooooooooo`000005ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000oooo
ool00000oooooolEooooo`00<?ooool00ol0003oooooooooo`1>ooooo`;o00002oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000005oooo
o`05o`000?ooooooooooooooool000001Oooool00ol0003oooooo`00003Jooooo`03ogMgMomVIVKo
oooo02gooooo00?oIVIVogMgMoooool01oooool0033ooooo00?o0000ooooooooool0C?ooool5o`00
00[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool000001Oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooool00000fOoo
ool00ooMgMgo410@onk^kP0^ooooo`03onk^k_l@413ogMgM00Oooooo000`ooooo`03o`000?oooooo
oooo04_ooooo0_l00004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0003ooooooooo
oooooooo000000Gooooo00Co0000oooooooooooo00001Oooool3o`000;kooooo0_l00002ooooo`;o
00003?ooool00omEEEGoV9RHooooo`02o`0000;ooooo00Oo0000oooooooooooo0000oa0@4?o^k^ko
EEEE00;o000000?oA4A4okZj^_ooool00_ooool01OnHV9So0000o`000?m4A4Co^[Zj00;ooooo00So
k^k^oeEEEOl0003o0000odA4A?nj^[[ooooooa0@40Go00000oooool02?l@413o<S8bo`000?l0003o
410@ojVYZOn7QhOoIVIV1oooool0033ooooo00?o0000ooooooooool0B_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0003ooooooooooooooooo000000Co
oooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooo000000Kooooo0_l0002foooo
o`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM3?ooool01Ol0003ooooooooooooooooo000000;ooooo
00_o0000oooooooooooo0000oooooomEEEGoMgMgooooooo^k^koMgMgoa0@4003ooooo`05oa0@4?nj
^[[ok^k^ogMgMol@41000_ooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40?ooooo00?o0000oooo
ooooool01?ooool02?l0003oZJVYoooooooooooo^[Zjo`000?o^k^ko00001oooool00?oo0000]?l0
000?ooooo`04omgMgOl0003o410@olc<c0gooooo00Go<S8booooooooooooooooo`000002ooooo`06
o`000?ooooooooooo`000?oooooo00002?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01Oooool01onj^[[oQhN7ofIVI_mVIVKo410@ooooool00000
1oooool000[ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00Wooooo1?l00002ooooo`;o00002Oooool00ol0003oooooooooo`05ooooo`;o00001_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000001_oo
ool00ol0003oooooooooo`03ooooo`07o`000?ooooooooooooooool0003oooooo`000006ooooo`03
o`000?oooooooooo00;ooooo00Oo0000ooooooooooooooooo`000?oooooo000000Gooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`02ooooo`;o00001?ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo
00Co0000oooooooooooo00001Oooool3o`0000;ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo01Oooooo00Cok^k^ob4Q8Ol@413ok^k^3Oooool01Olb
<S;ooooooooooooooooo000000;ooooo00Go0000oooooooooooo0000ooooo`06o`0000?ooooo00?o
0000ooooooooool01?ooool6o`0000?ooooo00?o0000ooooooooool01?ooool02?lb<S;o8B4QogMg
MomgMgOoQhN7onk^k_oooooo00001oooool000[ooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00cooooo1Ol0000:ooooo`03o`000?oooooooooo00Co
oooo0_l00006ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooo`000006ooooo`03o`000?oooooooooo00?ooooo00Oo0000ooooooooooooooooo`000?oooooo
000000Kooooo00?o0000ooooooooool00_ooool01ol0003ooooooooooooooooo0000ooooool00000
1Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo0_l00004ooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00?o
oooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00;o00001Oooool2o`00
00_ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
01Oooooo00Co8B4QogMgMomgMgOo<S8b3Oooool01Ol0003ok^k^oooooooooooo000000;oc<c<00_o
0000ojVYZOoMgMgo8B4QoooooomEEEGoQhN7onk^k_ooooooQhN7oc8b<P03ooooo`03o`000?oooooo
oooo00Cooooo00KoEEEEohN7Qoo^k^koooooohN7Qolb<S83ooooo`03o`000?lb<S;ogMgM00Cooooo
00So0000okZj^_ooooook^k^ogMgMol0003ok^k^o`0000Oooooo000`ooooo`03o`000?oooooooooo
05?ooooo00?o0000ooooooooool00oooool00ol0003oooooo`000006ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00?ooooo00Co0000
oooooooooooo00001_ooool00ol0003oooooo`00001;ooooo`03o`000?oooooooooo05_ooooo00?o
0000ooooooooool05_ooool2o`0000;ooooo0_l0000<ooooo`0>oeEEEOmgMgOooooooa0@4?l0003o
8B4Qo`000?mgMgOo410@o`000?nYZJWoooooonk^k_mEEED2o`000004odA4A?o^k^kooooooa0@40Go
00000oooool01_o^k^koEEEEo`000?l0003oA4A4onk^kP;ooooo0_l000001?nYZJWo8B4Qo`000?lQ
8B42ooooo`08ojVYZOlQ8B7o0000o`000?lb<S;o0000ogMgMomEEED7ooooo`00<?ooool00ol0003o
ooooooooo`1Cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000005oooo
o`04o`000?ooooooooooo`0000Kooooo0_l0003Eooooo`03omgMgOl@413ok^k^01;ooooo00?o0000
ooooooooool06Oooool00oo^k^ko410@omgMg@07ooooo`00<?ooool00ol0003oooooooooo`1Doooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000005ooooo`04o`000?oooooo
ooooo`000=kooooo00?oMgMgofIVI_ooool04Oooool00ol0003oooooooooo`0Iooooo`03ofIVI_mg
MgOooooo00Oooooo000`ooooo`03o`000?oooooooooo05Cooooo00Go0000ooooooooooooooooo`00
0009ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000Gooooo00Co0000oooooooooooo0000oooooolIooooo`00<?ooool00ol0003ooooo
ooooo`1Eooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000001Oooool01?l0003oooooooooool0003o
oooooaWooooo000`ooooo`03o`000?oooooooooo05Gooooo1?l00009ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Gooooo00Co0000
oooooooooooo0000oooooolIooooo`00<?ooool00ol0003oooooooooo`1Fooooo`;o00002_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0006ooooo`;o0000oooooolJooooo`00<?ooool00ol0003oooooooooo`1Sooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooo
ooooooooool000001Oooool01Ol0003ooooooooooooooooo000000Kooooo0_l0003ooooooa[ooooo
000`ooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000005ooooo`05o`00
0?ooooooooooooooool00000oooooolRooooo`00<?ooool3o`0006?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooo
ooooo`000005ooooo`05o`000?ooooooooooooooool00000oooooolRooooo`00<?ooool00ol0003o
ooooooooo`1Sooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0003ooooooooooooooooo
00000?oooooo8_ooool0033ooooo00?o0000ooooooooool0Hoooool01Ol0003ooooooooooooooooo
000000Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Gooooo00Go
0000ooooooooooooooooo`00003oooooob;ooooo000`ooooo`03o`000?oooooooooo06?ooooo00Go
0000ooooooooooooooooo`000009ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooo
ooooo`000006ooooo`03o`000?oooooo00000?oooooo8oooool0033ooooo00?o0000ooooooooool0
Hoooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003o
oooooooooooooooo000000Kooooo00?o0000ooooool00000oooooolSooooo`00<?ooool00ol0003o
ooooooooo`1Sooooo`05o`000?ooooooooooooooool000002Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooo`00003oooooob?ooooo000`oooo
o`03o`000?oooooooooo06?ooooo00Go0000ooooooooooooooooo`000009ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo00000?oooooo8ooo
ool0033ooooo00?o0000ooooooooool0I?ooool01?l0003oooooooooool00009ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oo
ooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Gooooo00Go0000oooooooo
ooooooooo`000006ooooo`;o0000oooooolTooooo`00<?ooool00ol0003oooooooooo`1Tooooo`04
o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?oooooo
ooooooooool000001Oooool01Ol0003ooooooooooooooooo000000Kooooo0_l0003oooooobCooooo
000`ooooo`03o`000?oooooooooo06Cooooo00Co0000oooooooooooo00002Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooo
oooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000005ooooo`05o`000?oooooooooo
ooooool000001oooool00ol0003oooooooooo`3oooooob;ooooo000`ooooo`03o`000?oooooooooo
06Cooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go
0000ooooooooooooooooo`000005ooooo`05o`000?ooooooooooooooool00000ooooool/ooooo`00
<?ooool00ol0003oooooooooo`1Tooooo`04o`000?ooooooooooo`0000Wooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooo
ooooooooo`000006ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo0000oooo
ool/ooooo`00<?ooool3o`0006Cooooo00Co0000oooooooooooo00002Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000007ooooo`05o`00
0?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooo
oooooooo00001oooool01?l0003oooooooooool0003oooooobcooooo000`ooooo`03o`000?oooooo
oooo06Cooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Gooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool0
00001oooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo00001oooool0
0ol0003oooooo`00003oooooobgooooo000`ooooo`03o`000?oooooooooo06Gooooo0_l0000:oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo
000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool00000
1_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooo00000?oooooo;Oooool0033ooooo
00?o0000ooooooooool0IOooool2o`0000[ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`05ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo0000
00Oooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Oooooo00?o
0000ooooool00000ooooool]ooooo`00<?ooool00ol0003oooooooooo`1Uooooo`;o00002_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`00
0007ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Ko
oooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00003oooooobgooooo000`ooooo`03
o`000?oooooooooo077ooooo00Go0000ooooooooooooooooo`000008ooooo`05o`000?oooooooooo
ooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooooooooooooooo
o`000006ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool00000ooooool]ooooo`00
<?ooool00ol0003oooooooooo`1aooooo`05o`000?ooooooooooooooool000002?ooool01Ol0003o
oooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooo
ooooooooool000001_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooo00000?oooooo
;Oooool0033ooooo00?o0000ooooooooool0LOooool01Ol0003ooooooooooooooooo000000Sooooo
00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool01Ol0
003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00
003oooooobgooooo000`ooooo`03o`000?oooooooooo077ooooo00Go0000ooooooooooooooooo`00
0008ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oo
oooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000
ooooool00000ooooool]ooooo`00<?ooool00ol0003oooooooooo`1aooooo`05o`000?oooooooooo
ooooool000002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooooooooooooooo
o`000007ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool00007oooo
o`03o`000?oooooo00000?oooooo;Oooool0033ooooo00?o0000ooooooooool0LOooool01Ol0003o
oooooooooooooooo000000Sooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooo
ooooooooool000001oooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo
00001oooool00ol0003oooooo`00003oooooobgooooo000`ooooo`03o`000?oooooooooo077ooooo
00Go0000ooooooooooooooooo`000008ooooo`05o`000?ooooooooooooooool000001oooool01Ol0
003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?oo
ooooooooo`0000Oooooo00?o0000ooooool00000ooooool]ooooo`00<?ooool3o`00077ooooo00Go
0000ooooooooooooooooo`000008ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003o
oooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?oooooo
ooooo`0000Oooooo00?o0000ooooool00000ooooool]ooooo`00<?ooool00ol0003oooooooooo`1a
ooooo`05o`000?ooooooooooooooool000002?ooool01Ol0003ooooooooooooooooo000000Oooooo
00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool01?l0
003oooooooooool00007ooooo`03o`000?oooooo00000?oooooo;Oooool0033ooooo00?o0000oooo
ooooool0L_ooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool000001ooo
ool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000006ooooo`04
o`000?ooooooooooo`0000Oooooo0_l0003oooooobkooooo000`ooooo`03o`000?oooooooooo07;o
oooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000
ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003ooooo
ooooool00008ooooo`03o`000?oooooooooo0?oooooo;?ooool0033ooooo00?o0000ooooooooool0
L_ooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool000001oooool01Ol0
003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?oo
ooooooooo`0000Sooooo00?o0000ooooooooool0ooooool/ooooo`00<?ooool00ol0003ooooooooo
o`1booooo`04o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000007ooooo`05
o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000
oooooooooooo0000oooooolgooooo`003oooool2onk^kP?ooooo0_o^k^hJooooo`03o`000?oooooo
oooo07;ooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Oooooo
00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool01?l0
003oooooooooool0003oooooocOooooo0008ooooo`Go00000_ooool01oo^k^koEEEEonk^k_oooooo
k^k^oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h;oooo
o`03o`000?oooooooooo07;ooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooo
oooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool0
00001_ooool01?l0003oooooooooool0003oooooocOooooo0008ooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@00oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?o0000ooooooooool0L_ooool01?l0003ooooooooo
ool00008ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo0000
00Oooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`000?oooooo=ooo
ool000Wooooo00?oV9RHob4Q8Oo^k^h01Oooool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooo
oooo00;ooooo00Go410@oooooooooooooooooa0@400;ooooo`03o`000?oooooooooo07;ooooo00Co
0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooooooo
ooooooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool0
003oooooocOooooo000:ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^
kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000;ooooo`03o`00
0?oooooooooo07;ooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo0000
00Oooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001_oo
ool01?l0003oooooooooool0003oooooocOooooo000;ooooo`0;ogMgMomVIVKoooooooooooo^k^ko
EEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000002oooool4o`00077ooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooo
oooooooooooo000000Sooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo
000000Kooooo00Co0000oooooooooooo0000oooooolgooooo`003?ooool00ol0003oooooooooo`02
onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
400;ooooo`03o`000?oooooooooo07;ooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooo
oooooooooooo000000Sooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool00007
ooooo`04o`000?ooooooooooo`000?oooooo=oooool000Sooooo00Go0000okZj^_ooooooV9RHoa0@
400>ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03o`00
0?oooooooooo07;ooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo0000
00Sooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool00008ooooo`03o`000?oo
oooo00000?oooooo=oooool000Sooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00<ooooo`03oeEEEOmV
IVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`;o00001_ooool00ol0003ooooo
ooooo`1booooo`04o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000008oooo
o`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00
003oooooocOooooo000Wooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0L_oo
ool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool000002?ooool01?l0003o
ooooooooool00007ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooolg
ooooo`009oooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo07;ooooo00Co0000
oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Sooooo00Co0000oooooooooooo
00001oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?oooooo=oooool002Oo
oooo0ol00006ooooo`03o`000?oooooooooo07;ooooo00?o0000ooooool000002Oooool01Ol0003o
oooooooooooooooo000000Sooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool0
0008ooooo`03o`000?oooooo00000?oooooo=oooool002Sooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`1booooo`03o`000?oooooo000000Wooooo00Go0000ooooooooooooooooo`00
0008ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00002?ooool00ol0003o
ooooo`00003oooooocOooooo000Yooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
L_ooool00ol0003oooooo`000009ooooo`05o`000?ooooooooooooooool000002?ooool01?l0003o
ooooooooool00007ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooolg
ooooo`00<?ooool00ol0003oooooooooo`1cooooo`;o00002Oooool01Ol0003ooooooooooooooooo
000000Sooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool00008ooooo`03o`00
0?oooooo00000?oooooo=oooool0033ooooo00?o0000ooooooooool0Loooool2o`0000Wooooo00Go
0000ooooooooooooooooo`000008ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooo
oooo00002?ooool2o`000?oooooo>?ooool0033ooooo00?o0000ooooooooool0Loooool2o`0000Wo
oooo00Go0000ooooooooooooooooo`000008ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000
oooooooooooo00002?ooool2o`000?oooooo>?ooool0033ooooo0ol0001cooooo`;o00002Oooool0
1Ol0003ooooooooooooooooo000000Sooooo00Co0000oooooooooooo00001oooool01?l0003ooooo
ooooool00008ooooo`;o0000oooooolhooooo`00<?ooool00ol0003oooooooooo`1oooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool00008
ooooo`;o0000oooooolhooooo`00<?ooool00ol0003oooooooooo`1oooooo`04o`000?oooooooooo
o`0000Sooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool00008ooooo`;o0000
oooooolhooooo`00<?ooool00ol0003oooooooooo`1oooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00001oooool01?l0003oooooooooool00008ooooo`;o0000oooooolhoooo
o`00<?ooool00ol0003oooooooooo`1oooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooo
oooooooo00001oooool01?l0003oooooooooool00008ooooo`;o0000oooooolhooooo`00<?ooool0
0ol0003oooooooooo`1oooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000
1oooool01?l0003oooooooooool00008ooooo`;o0000oooooolhooooo`00<?ooool00ol0003ooooo
ooooo`1oooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001oooool01?l0
003oooooooooool0003ooooood;ooooo000`ooooo`03o`000?oooooooooo07oooooo00Co0000oooo
oooooooo00002?ooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`000?oooooo
@_ooool0033ooooo00?o0000ooooooooool0Ooooool01?l0003oooooooooool00008ooooo`04o`00
0?ooooooooooo`0000Oooooo00Co0000oooooooooooo0000oooooom2ooooo`00<?ooool00ol0003o
ooooooooo`1oooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001oooool0
1?l0003oooooooooool0003ooooood;ooooo000`ooooo`03o`000?oooooooooo07oooooo00Co0000
oooooooooooo00002?ooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`000?oo
oooo@_ooool0033ooooo00?o0000ooooooooool0Ooooool01?l0003oooooooooool00008ooooo`04
o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooom2ooooo`00<?ooool3o`0007oo
oooo00?o0000ooooool000002Oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo0000
0?oooooo@_ooool0033ooooo00?o0000ooooooooool0Ooooool00ol0003oooooo`000009ooooo`04
o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooom2ooooo`00<?ooool00ol0003o
ooooooooo`1oooooo`03o`000?oooooo000000Wooooo00Co0000oooooooooooo00002?ooool00ol0
003oooooo`00003ooooood;ooooo000`ooooo`03o`000?oooooooooo07oooooo00?o0000ooooool0
00002Oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?oooooo@_ooool0033o
oooo00?o0000ooooooooool0Ooooool00ol0003oooooo`000009ooooo`04o`000?ooooooooooo`00
00Sooooo00?o0000ooooool00000oooooom2ooooo`00<?ooool00ol0003oooooooooo`1oooooo`03
o`000?oooooo000000Wooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003ooooo
od;ooooo000`ooooo`03o`000?oooooooooo07oooooo00?o0000ooooool000002Oooool01?l0003o
ooooooooool00008ooooo`03o`000?oooooo00000?oooooo@_ooool0033ooooo00?o0000oooooooo
ool0Ooooool00ol0003oooooo`000009ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000oooo
ool00000oooooom2ooooo`00<?ooool00ol0003oooooooooo`1oooooo`03o`000?oooooo000000Wo
oooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003ooooood;ooooo000`ooooo`03
o`000?oooooooooo07oooooo00?o0000ooooool000002Oooool01?l0003oooooooooool00008oooo
o`03o`000?oooooo00000?oooooo@_ooool0033ooooo00?o0000ooooooooool0P?ooool2o`0000Wo
oooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003ooooood;ooooo000`ooooo`03
o`000?oooooooooo083ooooo0_l00009ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000oooo
ool00000oooooom2ooooo`00<?ooool3o`00083ooooo0_l00009ooooo`04o`000?ooooooooooo`00
00Sooooo0_l0003ooooood?ooooo000`ooooo`03o`000?oooooooooo083ooooo0_l00009ooooo`04
o`000?ooooooooooo`0000Sooooo0_l0003ooooood?ooooo000`ooooo`03o`000?oooooooooo083o
oooo0_l00009ooooo`04o`000?ooooooooooo`0000Sooooo0_l0003ooooood?ooooo000`ooooo`03
o`000?oooooooooo083ooooo0_l00009ooooo`03o`000?oooooo000000Wooooo0_l0003ooooood?o
oooo000`ooooo`03o`000?oooooooooo083ooooo0_l00009ooooo`03o`000?oooooo000000Wooooo
0_l0003ooooood?ooooo000`ooooo`03o`000?oooooooooo083ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooo`00000:ooooo`03o`000?oooooooooo0?oooooo@Oooool000oooooo0_o^k^h3
ooooo`;ok^k^6_ooool00ol0003oooooooooo`2;ooooo`03o`000?oooooo00000?ooooooC_ooool0
00[ooooo0_l000002_l@413oooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h3ooooo`Co
000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00?o0000ooooooooool0S?oo
ool2o`000?ooooooC_ooool000_ooooo00?o0000ooooooooool00_ooool01Oo^k^koEEEEomgMgOmE
EEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00?o0000ooooooooool0S?ooool2o`000?ooooooC_ooool000Sooooo1Ol00004ooooo`03omgMgOl0
003ogMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00_ooooo
00?o0000ooooooooool0S?ooool2o`000?ooooooC_ooool000Sooooo00CoA4A4omgMgOoooooo0000
1?ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000000_ooooo00?o0000ooooooooool0S?ooool2o`000?ooooooC_ooool000So
oooo00CogMgMoeEEEOoooooo00000oooool01oo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Ooo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000002oooool4o`0008_ooooo
0_l0003oooooodkooooo0009ooooo`03ogMgMoo<c<co000000?ooooo0_o^k^h3ooooo`;ok^k^1Ooo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41002oooool00ol0003ooooo
ooooo`2<ooooo`;o0000oooooom>ooooo`002Oooool00oo^k^koA4A4o`00000?ooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03o`000?oooooooooo08cooooo
0_l0003oooooodkooooo000:ooooo`03ogMgMol0003ooooo00cooooo00?oEEEEofIVI_l000001?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo0_l00006ooooo`03o`000?oooooooooo08cooooo
0_l0003oooooodkooooo000Wooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0
S?ooool2o`000?ooooooC_ooool002Oooooo00Co0000oooooooooooo00001Oooool00ol0003ooooo
ooooo`2<ooooo`;o0000oooooom>ooooo`009oooool3o`0000Kooooo00?o0000ooooooooool0oooo
oooLooooo`00:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooog?ooool0
02Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03
o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?oo
ool00ol0003oooooooooo`3oooooomcooooo000`ooooo`?o0000oooooooLooooo`00<?ooool00ol0
003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo
00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`
ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLoooo
o`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooo
g?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo0ol0003oooooomco
oooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooo
oooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooo
ooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000
ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03
o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?oo
ool3o`000?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0
003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo
00?o0000ooooooooool0oooooooLooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool0
0?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooooooo
ool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00:3ooooo0_l00004ooooo`03
okZj^_lb<S;ooooo00Cooooo0_l00006ooooo`03o`000?nj^[[ooooo0?ooooooEoooool00:3ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
0_lb<S;ooooooeSooooo002=ooooo`?o00000_ooool01_lb<S;o410@ooooooooooook^k^oeEEE@;o
000000?oA4A4okZj^_ooool00oooool00ol0003oooooooooo`02ooooo`05oiRHV?l@413o0000o`00
0?nYZJT01?ooool00ol0003oooooooooo`04ooooo`03ohN7Qol0003o^[Zj00cooooo00GoV9RHo`00
0?l0003oA4A4okZj^P09ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01Oooool2ob4Q8@Cooooo00_o
k^k^oc8b<_l0003o410@olc<c?ooooooc<c<onk^k_ooooook^k^olc<c004ooooo`Co000000So410@
ooooooooooook^k^oc8b<_l0003o<S8bonk^kQ?ooooo00Ko410@oc8b<_l0003o0000oa0@4?nYZJT2
ooooo`06onk^k_mEEEGo0000o`000?m4A4Co^[Zj0oooool01OmVIVKo0000o`000?m4A4Coc<c<0>So
oooo002>ooooo`05o`000?ooooooooooolc<c?l@41000oooool01_mEEEGoMgMgooooooo^k^koMgMg
oa0@40Cooooo00?o0000ooooooooool00_ooool01_l0003oZJVYoeEEEOnHV9SoEEEEokZj^P?ooooo
00?o0000ooooooooool01?ooool00oo<c<co0000oa0@400<ooooo`06oa0@4?nj^[[ok^k^ogMgMol@
413ooooo1_l00002ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401Oooool2ob4Q8@Cooooo00_oEEEE
ogMgMoooooooV9RHob4Q8Oooooook^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Cooooo`06o`000?nYZJWooooooooooonj^[[o0000
0_ooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40;ooooo00KoIVIVogMgMoooooooooooohN7Qol@
413Xooooo`00S_ooool01Ol0003ooooooooooomEEEGoQhN700?ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`02ooooo`06oc8b<_o^k^koV9RHoeEEEOoMgMgo410@0oooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`00000;oooo
o`05o`000?ooooooooooooooool000000_ooool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooo
oooo00;ooooo00Go410@oooooooooooooooooa0@400Dooooo`05okZj^_n7QhOoIVIVofIVI_l@4100
0_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0>_ooooo002>ooooo`05o`000?oo
oooogMgMo`000?o^k^h00oooool6o`0000Cooooo00?o0000ooooooooool00_ooool01onj^[[oA4A4
olc<c?lQ8B7ooooooa0@4?o<c<`00_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
00?ooooo1_l00002ooooo`05o`000?nHV9SooooooiRHV?lQ8B402oooool02ol0003oV9RHoooooonH
V9So8B4Qooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0
003ooooooooooooooooo000001?ooooo00Ko<S8bob4Q8OmgMgOoMgMgohN7Qoo^k^h2ooooo`Ko0000
0_ooool00ol0003oooooooooo`3[ooooo`00S_ooool3o`000003oa0@4?nHV9Sooooo00;ooooo00Ko
EEEEohN7Qoo^k^koooooohN7Qolb<S84ooooo`03o`000?oooooooooo00;ooooo00Ook^k^o`000?oo
oooo0000oooooomVIVKoQhN700;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0;
ooooo`05o`000?mEEEGo0000oa0@4?o<c<`02oooool02ol0003oEEEEo`000?l@413oc<c<ooooooo<
c<cok^k^ooooooo^k^koc<c<00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000001?ooooo00Ko0000okZj^_ooooook^k^ogMgMol00002ooooo`06oeEEEOn7QhOok^k^oooo
oon7QhOo<S8b0_ooool01_mVIVKoMgMgooooooooooooQhN7o`000>Sooooo002>ooooo`05o`000?oo
ooooooooolc<c?l000000oooool01_o^k^koEEEEo`000?l0003oA4A4onk^kPCooooo00?o0000oooo
ooooool00_ooool01?mVIVKoV9RHoooooolb<S82okZj^P04o`000?ooooooooooo`0001?ooooo00?o
410@o`000?l000000ol0000:ooooo`03oeEEEOn7QhOooooo00gooooo00?oEEEEohN7Qoooool03_oo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41001oooool3o`0000;ooooo
0ol00004ooooo`06ojVYZOlQ8B7o0000o`000?lb<S;o00000_ooool01_o^k^koEEEEo`000?l0003o
A4A4onk^kP;ooooo00Kok^k^ofIVI_l0003o0000odA4A?l0003Xooooo`00S_ooool01Ol0003ooooo
ooooooo<c<co000000gooooo00?o0000ooooooooool01Oooool00omVIVKoQhN7ooooo`03ooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool02oooool00ooMgMgo410@oiRHV00=ooooo`03
omgMgOl@413oV9RH00kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3oooooo`;ooooo002=ooooo`Co
000000?o410@ojVYZOooool03?ooool2o`0000Kooooo00?oZJVYodA4A?ooool00_ooool2o`0001Go
oooo00?o0000ooooooooool03?ooool01?o<c<coA4A4o`000?l@410<ooooo`04olc<c?m4A4Co0000
oa0@40[ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo1?l0
0002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0ooooool2ooooo`00ooooool6
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0ooooool2ooooo`00ooooool6oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0ooooool2ooooo`00ooooool5ooooo`;o
00000oooool2o`000?oooooo1?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003o
oooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo
4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oo
ooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@
ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooo
oooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3o
oooo0000\
\>"],
  ImageRangeCache->{{{0, 525.688}, {324.5, 0}} -> {-2.58312*^-7, -6.34248*^6, \
6.65005*^-9, 53093.5}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0.309017 5.42214e-08 [
[.32684 .29652 -16.5 -12.5 ]
[.32684 .29652 16.5 0 ]
[.54329 .29652 -16.5 -12.5 ]
[.54329 .29652 16.5 0 ]
[.75974 .29652 -22.5 -12.5 ]
[.75974 .29652 22.5 0 ]
[.97619 .29652 -16.5 -12.5 ]
[.97619 .29652 16.5 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 64 6 ]
[.09789 .09213 -34.5 -6.25 ]
[.09789 .09213 0 6.25 ]
[.09789 .20057 -34.5 -6.25 ]
[.09789 .20057 0 6.25 ]
[.09789 .41746 -28.5 -6.25 ]
[.09789 .41746 0 6.25 ]
[.09789 .5259 -28.5 -6.25 ]
[.09789 .5259 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -62.8125 0 ]
[.5 .63053 62.8125 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 .30902 m
.32684 .31527 L
s
gsave
.32684 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 .30902 m
.54329 .31527 L
s
gsave
.54329 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 .30902 m
.75974 .31527 L
s
gsave
.75974 .29652 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 .30902 m
.15368 .31277 L
s
.19697 .30902 m
.19697 .31277 L
s
.24026 .30902 m
.24026 .31277 L
s
.28355 .30902 m
.28355 .31277 L
s
.37013 .30902 m
.37013 .31277 L
s
.41342 .30902 m
.41342 .31277 L
s
.45671 .30902 m
.45671 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.58658 .30902 m
.58658 .31277 L
s
.62987 .30902 m
.62987 .31277 L
s
.67316 .30902 m
.67316 .31277 L
s
.71645 .30902 m
.71645 .31277 L
s
.80303 .30902 m
.80303 .31277 L
s
.84632 .30902 m
.84632 .31277 L
s
.88961 .30902 m
.88961 .31277 L
s
.9329 .30902 m
.9329 .31277 L
s
.0671 .30902 m
.0671 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09213 m
.11664 .09213 L
s
gsave
.09789 .09213 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .20057 m
.11664 .20057 L
s
gsave
.09789 .20057 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .41746 m
.11664 .41746 L
s
gsave
.09789 .41746 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .5259 m
.11664 .5259 L
s
gsave
.09789 .5259 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.11039 .11924 m
.11414 .11924 L
s
.11039 .14635 m
.11414 .14635 L
s
.11039 .17346 m
.11414 .17346 L
s
.11039 .22768 m
.11414 .22768 L
s
.11039 .2548 m
.11414 .2548 L
s
.11039 .28191 m
.11414 .28191 L
s
.11039 .33613 m
.11414 .33613 L
s
.11039 .36324 m
.11414 .36324 L
s
.11039 .39035 m
.11414 .39035 L
s
.11039 .44457 m
.11414 .44457 L
s
.11039 .47168 m
.11414 .47168 L
s
.11039 .49879 m
.11414 .49879 L
s
.11039 .06502 m
.11414 .06502 L
s
.11039 .03791 m
.11414 .03791 L
s
.11039 .0108 m
.11414 .0108 L
s
.11039 .55301 m
.11414 .55301 L
s
.11039 .58012 m
.11414 .58012 L
s
.11039 .60723 m
.11414 .60723 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -123.812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.812 moveto
(@) show
81.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.812 moveto
(D) show
93.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6.8) show
135.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
141.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
153.000 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
157.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
166.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
184.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02691 .30902 L
.03029 .30902 L
.03347 .30902 L
.03652 .30902 L
.03978 .30902 L
.04291 .30902 L
.04623 .30902 L
.0479 .30902 L
.04944 .30902 L
.05093 .30902 L
.05169 .30902 L
.05212 .30902 L
.05233 .30902 L
.05252 .30902 L
.05271 .30902 L
.05282 .30902 L
.05292 .30902 L
.05297 .30902 L
.05303 .30902 L
.05308 .30902 L
.05314 .30902 L
.05324 .30902 L
.0533 .30902 L
.05335 .30902 L
.05346 .30902 L
.05355 .30902 L
.05364 .30902 L
.05374 .30902 L
.05395 .30902 L
.05415 .30902 L
.05449 .30902 L
.05487 .30902 L
.05526 .30902 L
.05563 .30902 L
.05642 .30902 L
.05725 .30902 L
.05796 .30902 L
.05874 .30902 L
.06031 .30902 L
.06119 .30902 L
.06199 .30902 L
.06353 .30902 L
.0652 .30902 L
.0668 .30902 L
.06849 .30902 L
.07006 .30902 L
.07153 .30902 L
.07316 .30902 L
.07464 .30902 L
Mistroke
.0763 .30902 L
.07784 .30902 L
.08091 .30902 L
.08256 .30902 L
.08405 .30902 L
.08727 .30902 L
.09037 .30902 L
.09367 .30902 L
.09684 .30902 L
.09989 .30902 L
.10314 .30902 L
.10627 .30902 L
.10709 .30902 L
.10752 .30902 L
.10798 .30902 L
.10838 .30902 L
.10859 .30902 L
.10882 .30902 L
.10902 .30902 L
.10922 .30902 L
.1094 .30902 L
.10949 .30902 L
.10959 .30902 L
.10964 .30902 L
.1097 .30902 L
.1098 .30902 L
.1099 .30902 L
.10996 .30902 L
.11002 .30902 L
.11012 .30902 L
.11021 .30902 L
.11032 .30902 L
.11042 .30902 L
.1106 .30902 L
.11078 .30902 L
.11117 .30902 L
.11156 .30902 L
.11198 .30902 L
.11243 .30902 L
.11285 .30902 L
.11364 .30902 L
.11447 .30902 L
.11518 .30902 L
.11595 .30902 L
.11753 .30902 L
.11841 .30902 L
.11921 .30902 L
.12075 .30902 L
.12241 .30902 L
.12401 .30902 L
Mistroke
.1257 .30902 L
.12873 .30902 L
.13197 .30902 L
.13508 .30902 L
.13839 .30902 L
.14158 .30902 L
.14465 .30902 L
.14636 .30902 L
.14717 .30902 L
.14791 .30902 L
.14829 .30902 L
.14869 .30902 L
.1489 .30902 L
.14909 .30902 L
.1492 .30902 L
.14931 .30902 L
.14936 .30902 L
.14942 .30902 L
.14948 .30902 L
.14953 .30902 L
.14962 .30902 L
.14971 .30902 L
.1498 .30902 L
.14988 .30902 L
.14997 .30902 L
.15007 .30902 L
.15027 .30902 L
.15047 .30902 L
.15068 .30902 L
.15106 .30902 L
.15149 .30902 L
.15188 .30902 L
.15277 .30902 L
.15356 .30902 L
.15439 .30902 L
.15515 .30902 L
.15596 .30902 L
.15743 .30902 L
.15913 .30902 L
.16075 .30902 L
.16382 .30902 L
.1654 .30902 L
.16709 .30902 L
.17043 .30902 L
.17365 .30902 L
.17675 .30902 L
.17833 .30902 L
.17916 .30902 L
.18005 .30902 L
.18049 .30902 L
Mistroke
.18091 .30902 L
.18129 .30902 L
.1815 .30902 L
.18159 .30902 L
.18169 .30902 L
.18179 .30902 L
.18188 .30902 L
.18196 .30902 L
.18205 .30902 L
.18214 .30902 L
.18223 .30902 L
.18233 .30902 L
.18244 .30902 L
.18254 .30902 L
.18265 .30902 L
.18285 .30902 L
.18304 .30902 L
.18322 .30902 L
.1836 .30902 L
.18401 .30902 L
.18473 .30902 L
.18518 .30902 L
.1856 .30902 L
.18639 .30902 L
.18717 .30902 L
.18799 .30902 L
.18947 .30902 L
.19103 .30902 L
.1925 .30902 L
.1956 .30901 L
.1989 .30901 L
.20208 .309 L
.20514 .30899 L
.20685 .30899 L
.20765 .30899 L
.2084 .30899 L
.20876 .30899 L
.20917 .30899 L
.20958 .30899 L
.2098 .30899 L
.2099 .30899 L
.21001 .30899 L
.21011 .30899 L
.2102 .30899 L
.21029 .30899 L
.21039 .30899 L
.21048 .30899 L
.21057 .30899 L
.21065 .30899 L
.21074 .30899 L
Mistroke
.21084 .30899 L
.21094 .30899 L
.21115 .30899 L
.21135 .30899 L
.21153 .30899 L
.21193 .30899 L
.21237 .30899 L
.21278 .30899 L
.21316 .30899 L
.21389 .30899 L
.21465 .30899 L
.21622 .309 L
.21769 .30901 L
.21931 .30902 L
.2208 .30903 L
.22398 .30907 L
.22704 .30911 L
.2303 .30916 L
.23181 .30917 L
.2326 .30918 L
.23344 .30919 L
.23386 .30919 L
.23433 .3092 L
.23476 .3092 L
.23495 .3092 L
.23515 .3092 L
.23526 .3092 L
.23536 .3092 L
.23546 .3092 L
.23556 .3092 L
.23566 .3092 L
.23574 .3092 L
.23584 .3092 L
.23594 .3092 L
.23604 .3092 L
.23609 .3092 L
.23615 .3092 L
.23626 .3092 L
.23637 .3092 L
.23658 .3092 L
.23677 .3092 L
.23716 .3092 L
.23757 .30919 L
.23792 .30919 L
.23831 .30919 L
.23917 .30918 L
.23998 .30916 L
.2416 .30912 L
.24309 .30907 L
.24628 .30892 L
Mistroke
.24935 .30872 L
.25261 .30849 L
.25412 .30839 L
.25575 .30831 L
.25665 .30827 L
.25704 .30825 L
.25747 .30824 L
.25788 .30823 L
.25826 .30823 L
.25847 .30822 L
.25866 .30822 L
.25876 .30822 L
.25882 .30822 L
.25888 .30822 L
.25898 .30822 L
.25903 .30822 L
.25909 .30822 L
.25919 .30822 L
.25928 .30822 L
.25938 .30822 L
.25948 .30822 L
.2596 .30822 L
.2597 .30822 L
.2599 .30823 L
.26026 .30823 L
.26064 .30824 L
.26107 .30826 L
.26151 .30828 L
.26232 .30833 L
.26307 .30839 L
.26389 .30847 L
.26536 .30866 L
.26706 .30894 L
.26867 .30928 L
.27174 .31004 L
.27501 .31089 L
.27652 .31123 L
.27732 .31138 L
.27815 .31151 L
.27858 .31157 L
.27905 .31162 L
.27948 .31165 L
.27967 .31166 L
.27988 .31167 L
.27999 .31168 L
.28009 .31168 L
.28018 .31169 L
.28029 .31169 L
.28038 .31169 L
.28047 .31169 L
Mistroke
.28056 .31169 L
.28066 .31169 L
.28072 .31169 L
.28077 .31169 L
.28082 .31169 L
.28088 .31169 L
.281 .31168 L
.2811 .31168 L
.2813 .31167 L
.2815 .31166 L
.28187 .31163 L
.28228 .31159 L
.28271 .31153 L
.28311 .31146 L
.28382 .3113 L
.28459 .31108 L
.28629 .31042 L
.28791 .30957 L
.29098 .30746 L
.29425 .30487 L
.29588 .30367 L
.2974 .30273 L
.29811 .30238 L
.29886 .30209 L
.29925 .30197 L
.29946 .30192 L
.29968 .30187 L
.29988 .30183 L
.30007 .30181 L
.30016 .3018 L
.30026 .30179 L
.30035 .30178 L
.30043 .30177 L
.30053 .30177 L
.30062 .30176 L
.30072 .30176 L
.30082 .30176 L
.30092 .30177 L
.30101 .30177 L
.30111 .30178 L
.30119 .30178 L
.3014 .30181 L
.30162 .30184 L
.30183 .30189 L
.30203 .30194 L
.30242 .30206 L
.30285 .30224 L
.30371 .30272 L
.30453 .30334 L
.30528 .30405 L
Mistroke
.30696 .30611 L
.31016 .31154 L
.31324 .31766 L
.3148 .32058 L
.31563 .32196 L
.31652 .32325 L
.31737 .32425 L
.31774 .32461 L
.31814 .32495 L
.31853 .3252 L
.31889 .32537 L
.31909 .32544 L
.31927 .32549 L
.31937 .32551 L
.31942 .32552 L
.31947 .32553 L
.31958 .32554 L
.31967 .32555 L
.31977 .32555 L
.31987 .32555 L
.31997 .32554 L
.32007 .32552 L
.32016 .32551 L
.32024 .32549 L
.32043 .32543 L
.32063 .32535 L
.32085 .32524 L
.32124 .32497 L
.32162 .32464 L
.32201 .32421 L
.32271 .32322 L
.32348 .32183 L
.32429 .31999 L
.32577 .31578 L
.32909 .30303 L
.3323 .28937 L
.33377 .28393 L
.3346 .28134 L
.33538 .27935 L
.33615 .27786 L
.33658 .27724 L
.33697 .27684 L
.33719 .27668 L
.33729 .27662 L
.33739 .27658 L
.33744 .27656 L
.3375 .27654 L
.33761 .27651 L
.33767 .2765 L
.33773 .2765 L
Mistroke
.33778 .27649 L
.33784 .27649 L
.33789 .2765 L
.33795 .27651 L
.33804 .27653 L
.33815 .27656 L
.33826 .27661 L
.33847 .27674 L
.33866 .2769 L
.33903 .27734 L
.33943 .27798 L
.34016 .27961 L
.34102 .28234 L
.34181 .28558 L
.34333 .29368 L
.34499 .30495 L
.34825 .33099 L
.34975 .3428 L
.35138 .35381 L
.35227 .35858 L
.35267 .36033 L
.3531 .36198 L
.35347 .36318 L
.35388 .36419 L
.35411 .36463 L
.35431 .36494 L
.35441 .36506 L
.35452 .36518 L
.35461 .36526 L
.35471 .36533 L
.35476 .36535 L
.35482 .36537 L
.35492 .3654 L
.35497 .36541 L
.35503 .36541 L
.35509 .3654 L
.35514 .36539 L
.35524 .36535 L
.3553 .36532 L
.35535 .36529 L
.35545 .3652 L
.35554 .36511 L
.35572 .36489 L
.35591 .36457 L
.3563 .3637 L
.35672 .36238 L
.35711 .36084 L
.35798 .35623 L
.35877 .35071 L
.3595 .34449 L
Mistroke
.36116 .32696 L
.3643 .28556 L
.3659 .2639 L
.36764 .24334 L
.36845 .23549 L
.36931 .22886 L
.36966 .22669 L
.37004 .22475 L
.37026 .22383 L
.37046 .22312 L
.37065 .22256 L
.37085 .22207 L
.37095 .22189 L
.37105 .22173 L
.37115 .22161 L
.37123 .22152 L
.37133 .22146 L
.37143 .22142 L
.37149 .22142 L
.37154 .22143 L
.37164 .22147 L
.37174 .22153 L
.37184 .22164 L
.37194 .22178 L
.37203 .22193 L
.3722 .22229 L
.37238 .22279 L
.37279 .22433 L
.37317 .2263 L
.37404 .23268 L
.37488 .24117 L
.37567 .25127 L
.37716 .27499 L
.38023 .33634 L
.38194 .3715 L
.38349 .39935 L
.38427 .41083 L
.38511 .42084 L
.38549 .42449 L
.3859 .42764 L
.38625 .42973 L
.38645 .43067 L
.38663 .43138 L
.38683 .43196 L
.38694 .43219 L
.38699 .43228 L
.38705 .43237 L
.38715 .43247 L
.38724 .43253 L
.38729 .43254 L
Mistroke
.38735 .43254 L
.38745 .43249 L
.38754 .43241 L
.38764 .43228 L
.38773 .43211 L
.38781 .43192 L
.38801 .43131 L
.3882 .43055 L
.38862 .42819 L
.389 .42522 L
.38988 .41569 L
.39066 .40402 L
.39138 .3906 L
.39304 .35231 L
.39616 .26386 L
.39774 .21987 L
.39858 .1993 L
.39947 .18046 L
.40034 .16582 L
.40075 .16038 L
.40113 .15628 L
.40151 .15306 L
.40171 .15175 L
.40192 .15065 L
.40201 .15028 L
.40211 .14994 L
.40219 .1497 L
.40228 .14949 L
.40238 .14931 L
.40248 .14921 L
.40258 .14918 L
.40267 .14921 L
.40277 .14931 L
.40286 .14947 L
.40295 .14967 L
.40304 .14995 L
.40325 .15079 L
.40344 .15184 L
.40379 .15444 L
.40417 .15817 L
.40461 .1639 L
.40504 .17055 L
.40582 .1861 L
.40743 .22919 L
.40892 .27904 L
.41208 .39566 L
.41368 .44614 L
.41437 .46409 L
.41513 .47998 L
.41555 .48693 L
Mistroke
.41593 .49215 L
.4163 .49599 L
.41649 .49749 L
.4167 .49879 L
.4168 .49932 L
.41691 .49977 L
.41701 .50007 L
.41711 .50031 L
.41717 .5004 L
.41722 .50045 L
.41729 .50048 L
.41734 .50048 L
.41745 .50041 L
.41751 .50032 L
.41756 .50021 L
.41766 .49995 L
.41775 .49963 L
.41796 .49863 L
.41816 .49728 L
.41837 .49543 L
.4188 .49062 L
.41919 .48475 L
.42007 .46665 L
.42085 .4455 L
.42169 .41827 L
.42503 .27852 L
.4267 .2064 L
.42744 .17803 L
.42825 .15055 L
.42897 .12979 L
.42975 .1125 L
.43018 .10536 L
.43057 .10045 L
.43076 .09864 L
.43097 .09709 L
.43106 .09652 L
.43116 .09602 L
.43126 .09566 L
.43134 .09539 L
.43143 .0952 L
.43153 .0951 L
.43163 .09509 L
.43174 .0952 L
.43183 .09541 L
.43192 .0957 L
.43201 .09603 L
.4321 .09647 L
.4323 .09782 L
.43252 .09972 L
.43291 .10439 L
Mistroke
.43327 .11013 L
.43361 .11669 L
.43438 .13578 L
.43601 .19307 L
.43749 .26005 L
.43915 .34193 L
.44069 .41494 L
.44218 .47434 L
.44293 .49774 L
.44333 .50811 L
.44376 .51722 L
.44415 .52378 L
.44435 .52657 L
.44457 .52904 L
.44477 .53083 L
.44495 .53205 L
.44504 .5325 L
.44514 .53288 L
.44523 .53315 L
.44531 .5333 L
.44541 .53338 L
.44551 .53335 L
.44561 .5332 L
.4457 .53296 L
.4458 .53256 L
.44592 .53198 L
.44612 .53053 L
.44634 .52849 L
.44657 .52571 L
.44698 .51917 L
.44741 .51035 L
.44781 .50047 L
.4487 .47241 L
.45032 .40465 L
.45349 .2434 L
.45509 .17018 L
.45578 .14373 L
.45654 .12001 L
.45696 .10945 L
.45734 .10141 L
.45771 .09533 L
.45792 .09266 L
.45811 .09065 L
.4583 .089 L
.45841 .08832 L
.45852 .08776 L
.45861 .08738 L
.4587 .08714 L
.4588 .08698 L
.4589 .08694 L
Mistroke
.45896 .08698 L
.45902 .08705 L
.45908 .08718 L
.45914 .08736 L
.45925 .08777 L
.45937 .08839 L
.45958 .08997 L
.45979 .09197 L
.46019 .09737 L
.46062 .1054 L
.46141 .12546 L
.46219 .15113 L
.4629 .17959 L
.46605 .33428 L
.46765 .41203 L
.4685 .44706 L
.46939 .47753 L
.47019 .49813 L
.47064 .50665 L
.47086 .50987 L
.47107 .51241 L
.47125 .51427 L
.47135 .51508 L
.47146 .5158 L
.47155 .51631 L
.47164 .51677 L
.47173 .51708 L
.47181 .51728 L
.47191 .51742 L
.47201 .51744 L
.4721 .51735 L
.4722 .51714 L
.4723 .5168 L
.47241 .51628 L
.47261 .51498 L
.47282 .5131 L
.47304 .51055 L
.47343 .50457 L
.47386 .49614 L
.47433 .48464 L
.47595 .42905 L
.47919 .27791 L
.48068 .21152 L
.48147 .1819 L
.48231 .15612 L
.48273 .14574 L
.48319 .13643 L
.4834 .13309 L
.48361 .13 L
.48382 .1276 L
Mistroke
.48401 .12579 L
.48421 .12438 L
.48431 .12381 L
.48442 .12334 L
.48448 .12315 L
.48454 .12299 L
.48459 .12288 L
.48465 .12281 L
.48475 .12277 L
.48485 .12285 L
.48494 .12303 L
.48504 .12332 L
.48514 .1237 L
.48522 .12413 L
.48543 .12554 L
.48563 .12732 L
.48603 .13231 L
.4864 .13835 L
.48722 .15677 L
.48798 .17924 L
.48869 .20434 L
.49179 .33448 L
.49336 .39608 L
.49419 .42285 L
.49465 .43527 L
.49508 .44534 L
.49549 .45327 L
.49594 .46002 L
.49614 .46236 L
.49635 .4644 L
.49653 .46579 L
.49672 .46694 L
.49682 .46735 L
.49692 .46768 L
.49701 .46788 L
.4971 .46801 L
.49721 .46804 L
.49726 .46801 L
.49732 .46796 L
.49742 .46777 L
.49751 .46749 L
.4976 .46714 L
.4977 .46669 L
.49787 .46564 L
.49805 .46419 L
.49825 .46221 L
.49867 .45684 L
.49907 .45025 L
.49982 .43422 L
.50149 .38415 L
Mistroke
.50457 .27227 L
.50615 .22315 L
.50703 .20249 L
.50742 .19542 L
.50783 .18906 L
.50823 .18446 L
.50844 .18252 L
.50864 .18108 L
.50883 .18005 L
.50892 .17968 L
.509 .17939 L
.50909 .17914 L
.5092 .17896 L
.50929 .17887 L
.50938 .17886 L
.50949 .17894 L
.50958 .1791 L
.50963 .17922 L
.50969 .17938 L
.50979 .17974 L
.50999 .18069 L
.51018 .18189 L
.5106 .18572 L
.51106 .19139 L
.51188 .20565 L
.51277 .22595 L
.51439 .27153 L
.51596 .31944 L
.51679 .34346 L
.51768 .36652 L
.51854 .38497 L
.51932 .39791 L
.5197 .40266 L
.52011 .40669 L
.5203 .40813 L
.52049 .40937 L
.52066 .4102 L
.52085 .41087 L
.52095 .41112 L
.52104 .41128 L
.52114 .41139 L
.5212 .41142 L
.52125 .41143 L
.52135 .41139 L
.52141 .41133 L
.52146 .41126 L
.52156 .41106 L
.52166 .41079 L
.52184 .41011 L
.52202 .40926 L
Mistroke
.5224 .40659 L
.52283 .40255 L
.52321 .39789 L
.52408 .38434 L
.5256 .35263 L
.52727 .31264 L
.52898 .27388 L
.52979 .25872 L
.53054 .24737 L
.53131 .23857 L
.53172 .2353 L
.53193 .23403 L
.53216 .23291 L
.53226 .2325 L
.53235 .23218 L
.53244 .23193 L
.53254 .23171 L
.53264 .23154 L
.53273 .23143 L
.53283 .23137 L
.53289 .23136 L
.53294 .23137 L
.53303 .23143 L
.53313 .23153 L
.53321 .23167 L
.5333 .23186 L
.5335 .23244 L
.53368 .23317 L
.53409 .23544 L
.53453 .23887 L
.53532 .24741 L
.53682 .26976 L
.53838 .29811 L
.5401 .32871 L
.54089 .34076 L
.54174 .35148 L
.54215 .35569 L
.54254 .35905 L
.54292 .36168 L
.54327 .36357 L
.54345 .36431 L
.54364 .36495 L
.54374 .36523 L
.54385 .36547 L
.54394 .36563 L
.54404 .36576 L
.5441 .36582 L
.54415 .36585 L
.54425 .36589 L
.54436 .36589 L
Mistroke
.54442 .36586 L
.54447 .36582 L
.54456 .36573 L
.54466 .36559 L
.54477 .36539 L
.54487 .36516 L
.54506 .36461 L
.54524 .36394 L
.54558 .36233 L
.54594 .36009 L
.54634 .3571 L
.54792 .34065 L
.54961 .31837 L
.55121 .29722 L
.55206 .28757 L
.55295 .27921 L
.55375 .27364 L
.5542 .27138 L
.55442 .27054 L
.55462 .26989 L
.55481 .26942 L
.55491 .26922 L
.55501 .26904 L
.5551 .26892 L
.5552 .26882 L
.55528 .26875 L
.55537 .26871 L
.55546 .26869 L
.55557 .26871 L
.55565 .26875 L
.55575 .26882 L
.55585 .26893 L
.55596 .26909 L
.55616 .26947 L
.55637 .26999 L
.55659 .27069 L
.55699 .27229 L
.55788 .27739 L
.55865 .2832 L
.55949 .29065 L
.56119 .307 L
.56273 .32088 L
.5635 .32654 L
.5639 .3291 L
.56433 .33144 L
.56475 .3333 L
.56512 .33465 L
.5653 .33518 L
.5655 .33567 L
.56568 .33605 L
Mistroke
.56585 .33632 L
.56594 .33644 L
.56604 .33655 L
.56615 .33663 L
.56625 .33669 L
.56634 .33672 L
.56644 .33674 L
.56652 .33673 L
.56662 .3367 L
.56667 .33668 L
.56673 .33664 L
.56682 .33657 L
.56693 .33646 L
.56705 .33631 L
.56726 .33597 L
.56746 .33557 L
.56788 .33441 L
.56827 .33305 L
.56915 .32907 L
.57236 .30857 L
.57384 .29978 L
.57467 .29585 L
.57508 .29428 L
.57545 .29308 L
.57582 .29212 L
.57623 .29132 L
.57645 .291 L
.57654 .29088 L
.57665 .29077 L
.57674 .29069 L
.57685 .29062 L
.5769 .29059 L
.57695 .29056 L
.57705 .29053 L
.57715 .29051 L
.57726 .29051 L
.57736 .29052 L
.57745 .29055 L
.57755 .2906 L
.57767 .29067 L
.57788 .29086 L
.5781 .29112 L
.57833 .29148 L
.57874 .29231 L
.5795 .29437 L
.58031 .29726 L
.58178 .30356 L
.58337 .31063 L
.5842 .31398 L
.58509 .31696 L
Mistroke
.58554 .31818 L
.58596 .31915 L
.58637 .3199 L
.58655 .32017 L
.58675 .32042 L
.58692 .32061 L
.58711 .32077 L
.58721 .32085 L
.5873 .3209 L
.58739 .32095 L
.58749 .32099 L
.58759 .32102 L
.58768 .32103 L
.58778 .32104 L
.58784 .32104 L
.5879 .32104 L
.58799 .32102 L
.58808 .321 L
.58818 .32096 L
.58828 .32091 L
.58849 .32078 L
.58869 .32062 L
.58905 .32022 L
.58944 .31965 L
.58987 .31889 L
.59135 .31533 L
.59291 .31075 L
.59463 .306 L
.59542 .30425 L
.59586 .30344 L
.59627 .30279 L
.59665 .3023 L
.59685 .30208 L
.59707 .30188 L
.59727 .30173 L
.59745 .30162 L
.59763 .30153 L
.5978 .30147 L
.59789 .30144 L
.59799 .30142 L
.59809 .30141 L
.59817 .30141 L
.59827 .30141 L
.59833 .30141 L
.59838 .30142 L
.59848 .30144 L
.59858 .30146 L
.59868 .30149 L
.59879 .30153 L
.59898 .30162 L
Mistroke
.59921 .30176 L
.59941 .30191 L
.60018 .30269 L
.6009 .30369 L
.60396 .30924 L
.60554 .31174 L
.606 .3123 L
.60643 .31275 L
.60681 .31308 L
.60723 .31337 L
.60742 .31347 L
.60763 .31356 L
.60783 .31363 L
.60801 .31367 L
.60812 .31369 L
.60821 .3137 L
.60826 .31371 L
.60832 .31371 L
.60838 .31371 L
.60844 .31371 L
.60854 .31371 L
.60863 .31371 L
.60873 .31369 L
.60878 .31369 L
.60884 .31368 L
.60903 .31363 L
.60921 .31358 L
.60961 .31342 L
.60997 .31321 L
.61032 .31297 L
.61193 .31143 L
.61341 .30971 L
.61504 .30793 L
.61584 .30724 L
.61657 .30674 L
.61693 .30656 L
.61732 .30639 L
.6175 .30634 L
.61769 .30628 L
.61787 .30625 L
.61804 .30622 L
.61814 .30621 L
.61824 .3062 L
.61835 .30619 L
.61841 .30619 L
.61846 .30619 L
.61856 .30619 L
.61866 .30619 L
.61871 .30619 L
.61876 .30619 L
Mistroke
.61886 .3062 L
.61895 .30621 L
.61905 .30623 L
.61925 .30626 L
.61961 .30635 L
.62001 .30648 L
.62042 .30666 L
.62117 .30706 L
.62284 .30819 L
.62445 .3093 L
.62515 .30973 L
.62591 .31011 L
.62633 .31029 L
.62672 .31042 L
.62709 .31052 L
.62748 .31061 L
.62768 .31064 L
.62779 .31065 L
.6279 .31066 L
.62799 .31067 L
.6281 .31068 L
.6282 .31068 L
.62828 .31068 L
.62839 .31069 L
.62849 .31069 L
.62854 .31068 L
.6286 .31068 L
.62865 .31068 L
.62871 .31068 L
.62882 .31067 L
.62893 .31066 L
.62917 .31064 L
.62938 .31061 L
.62957 .31058 L
.63001 .31048 L
.63081 .31025 L
.6323 .30968 L
.63393 .309 L
.63473 .30869 L
.63546 .30846 L
.63582 .30836 L
.63621 .30827 L
.63658 .3082 L
.63692 .30814 L
.63732 .3081 L
.63753 .30808 L
.63763 .30807 L
.63774 .30807 L
.63783 .30806 L
.63793 .30806 L
Mistroke
.63802 .30806 L
.6381 .30805 L
.6382 .30805 L
.63829 .30805 L
.6384 .30806 L
.6385 .30806 L
.63859 .30806 L
.63869 .30807 L
.63886 .30808 L
.63908 .30809 L
.63927 .30811 L
.63967 .30816 L
.64009 .30822 L
.64157 .30853 L
.64318 .30892 L
.64463 .30924 L
.64544 .30938 L
.64621 .30948 L
.64663 .30952 L
.64683 .30953 L
.64702 .30954 L
.64722 .30955 L
.64733 .30955 L
.64744 .30956 L
.6475 .30956 L
.64756 .30956 L
.64762 .30956 L
.64768 .30956 L
.64778 .30956 L
.64784 .30956 L
.64789 .30956 L
.64799 .30956 L
.64808 .30956 L
.64818 .30956 L
.64828 .30955 L
.6485 .30955 L
.6487 .30954 L
.64908 .30952 L
.64944 .30949 L
.65024 .30941 L
.65111 .3093 L
.65267 .30908 L
.6535 .30897 L
.65439 .30887 L
.65483 .30883 L
.65524 .30879 L
.65565 .30877 L
.65602 .30875 L
.65637 .30873 L
.65657 .30873 L
Mistroke
.65675 .30872 L
.65685 .30872 L
.65695 .30872 L
.657 .30872 L
.65706 .30872 L
.65716 .30872 L
.65726 .30872 L
.65736 .30872 L
.65746 .30872 L
.65755 .30872 L
.65764 .30872 L
.65773 .30872 L
.65793 .30872 L
.65813 .30873 L
.65834 .30873 L
.65873 .30875 L
.65908 .30876 L
.66075 .30887 L
.66239 .309 L
.6632 .30906 L
.66393 .3091 L
.66429 .30912 L
.66469 .30914 L
.66503 .30915 L
.6654 .30916 L
.6658 .30917 L
.66602 .30918 L
.66613 .30918 L
.66623 .30918 L
.66632 .30918 L
.66642 .30918 L
.66651 .30918 L
.66659 .30918 L
.66669 .30918 L
.66678 .30918 L
.66689 .30918 L
.66698 .30918 L
.66708 .30918 L
.66718 .30918 L
.66736 .30918 L
.66757 .30917 L
.66777 .30917 L
.66819 .30916 L
.6686 .30915 L
.67008 .30909 L
.67155 .30903 L
.67238 .309 L
.67316 .30897 L
.67393 .30895 L
.67436 .30894 L
Mistroke
.67475 .30894 L
.67494 .30893 L
.67514 .30893 L
.67526 .30893 L
.67537 .30893 L
.67547 .30893 L
.67557 .30893 L
.67563 .30893 L
.67568 .30893 L
.67579 .30893 L
.67584 .30893 L
.67591 .30893 L
.67596 .30893 L
.67602 .30893 L
.67612 .30893 L
.67618 .30893 L
.67623 .30893 L
.67633 .30893 L
.67644 .30893 L
.67663 .30893 L
.67683 .30893 L
.67719 .30894 L
.67757 .30894 L
.678 .30895 L
.67946 .30898 L
.68117 .30902 L
.68197 .30903 L
.68272 .30905 L
.68308 .30905 L
.68349 .30906 L
.68389 .30906 L
.68412 .30906 L
.68432 .30906 L
.68442 .30906 L
.68452 .30906 L
.68461 .30906 L
.68471 .30906 L
.6848 .30906 L
.68489 .30906 L
.68498 .30906 L
.68506 .30906 L
.68515 .30906 L
.68525 .30906 L
.68534 .30906 L
.68544 .30906 L
.68565 .30906 L
.68585 .30906 L
.68625 .30906 L
.68668 .30906 L
.68748 .30905 L
Mistroke
.68897 .30903 L
.69053 .30901 L
.69135 .309 L
.69179 .309 L
.69224 .309 L
.69265 .309 L
.69286 .309 L
.69309 .30899 L
.6933 .30899 L
.69349 .30899 L
.69359 .30899 L
.69369 .30899 L
.69378 .30899 L
.69387 .30899 L
.69396 .30899 L
.69405 .30899 L
.69414 .30899 L
.69422 .30899 L
.69432 .30899 L
.69442 .30899 L
.69452 .30899 L
.69461 .30899 L
.69499 .30899 L
.6952 .309 L
.6954 .309 L
.6962 .309 L
.69694 .309 L
.69862 .30901 L
.70013 .30902 L
.70055 .30902 L
.70099 .30903 L
.70138 .30903 L
.70179 .30903 L
.70199 .30903 L
.70222 .30903 L
.70231 .30903 L
.70242 .30903 L
.70252 .30903 L
.70261 .30903 L
.70267 .30903 L
.70272 .30903 L
.70277 .30903 L
.70284 .30903 L
.70289 .30903 L
.70296 .30903 L
.70302 .30903 L
.70307 .30903 L
.70317 .30903 L
.70323 .30903 L
.70328 .30903 L
Mistroke
.70339 .30903 L
.7035 .30903 L
.70371 .30903 L
.70391 .30903 L
.70428 .30903 L
.70512 .30903 L
.70667 .30902 L
.7075 .30902 L
.70839 .30902 L
.70923 .30901 L
.7096 .30901 L
.71001 .30901 L
.7104 .30901 L
.71075 .30901 L
.71095 .30901 L
.71113 .30901 L
.71123 .30901 L
.71134 .30901 L
.71144 .30901 L
.71154 .30901 L
.71164 .30901 L
.71173 .30901 L
.71182 .30901 L
.71191 .30901 L
.71201 .30901 L
.71212 .30901 L
.71231 .30901 L
.71251 .30901 L
.71269 .30901 L
.71304 .30901 L
.71384 .30901 L
.7147 .30901 L
.71627 .30902 L
.7171 .30902 L
.71799 .30902 L
.71843 .30902 L
.71885 .30902 L
.71922 .30902 L
.71942 .30902 L
.71963 .30902 L
.71973 .30902 L
.71983 .30902 L
.71992 .30902 L
.72002 .30902 L
.72012 .30902 L
.72018 .30902 L
.72023 .30902 L
.72033 .30902 L
.72043 .30902 L
.72052 .30902 L
Mistroke
.72062 .30902 L
.72072 .30902 L
.72081 .30902 L
.72098 .30902 L
.72116 .30902 L
.72156 .30902 L
.72192 .30902 L
.72273 .30902 L
.7242 .30902 L
.72501 .30902 L
.72586 .30902 L
.7266 .30902 L
.72699 .30902 L
.7274 .30902 L
.72761 .30902 L
.72783 .30902 L
.72804 .30902 L
.72823 .30902 L
.72843 .30902 L
.72853 .30902 L
.72863 .30902 L
.72873 .30902 L
.72881 .30902 L
.72891 .30902 L
.72901 .30902 L
.7291 .30902 L
.72918 .30902 L
.72928 .30902 L
.72937 .30902 L
.72953 .30902 L
.72971 .30902 L
.7301 .30902 L
.73047 .30902 L
.73132 .30902 L
.73212 .30902 L
.73361 .30902 L
.73439 .30902 L
.73522 .30902 L
.73593 .30902 L
.73612 .30902 L
.73633 .30902 L
.73651 .30902 L
.7367 .30902 L
.73691 .30902 L
.73702 .30902 L
.73713 .30902 L
.73723 .30902 L
.73732 .30902 L
.73742 .30902 L
.73752 .30902 L
Mistroke
.73758 .30902 L
.73763 .30902 L
.73769 .30902 L
.73774 .30902 L
.73784 .30902 L
.73795 .30902 L
.73819 .30902 L
.73841 .30902 L
.73878 .30902 L
.73919 .30902 L
.74002 .30902 L
.74172 .30902 L
.74326 .30902 L
.74403 .30902 L
.74446 .30902 L
.74467 .30902 L
.74486 .30902 L
.74505 .30902 L
.74525 .30902 L
.74533 .30902 L
.74543 .30902 L
.74551 .30902 L
.74559 .30902 L
.74569 .30902 L
.74579 .30902 L
.74588 .30902 L
.74597 .30902 L
.74607 .30902 L
.74616 .30902 L
.74627 .30902 L
.74638 .30902 L
.74657 .30902 L
.74677 .30902 L
.74713 .30902 L
.74794 .30902 L
.74941 .30902 L
.75024 .30902 L
.75102 .30902 L
.75178 .30902 L
.75247 .30902 L
.75284 .30902 L
.75323 .30902 L
.75343 .30902 L
.75362 .30902 L
.75373 .30902 L
.75383 .30902 L
.75388 .30902 L
.75394 .30902 L
.754 .30902 L
.75405 .30902 L
Mistroke
.75415 .30902 L
.75425 .30902 L
.75435 .30902 L
.75444 .30902 L
.75454 .30902 L
.75465 .30902 L
.75487 .30902 L
.75508 .30902 L
.75531 .30902 L
.75573 .30902 L
.75655 .30902 L
.75744 .30902 L
.75906 .30902 L
.75988 .30902 L
.76065 .30902 L
.76104 .30902 L
.76124 .30902 L
.76146 .30902 L
.76158 .30902 L
.76169 .30902 L
.76181 .30902 L
.76192 .30902 L
.76202 .30902 L
.76212 .30902 L
.76223 .30902 L
.76229 .30902 L
.76234 .30902 L
.76244 .30902 L
.76254 .30902 L
.76263 .30902 L
.76272 .30902 L
.76282 .30902 L
.76293 .30902 L
.76312 .30902 L
.76347 .30902 L
.76385 .30902 L
.76471 .30902 L
.76551 .30902 L
.767 .30902 L
.76784 .30902 L
.76825 .30902 L
.76862 .30902 L
.76899 .30902 L
.7694 .30902 L
.76962 .30902 L
.76983 .30902 L
.77002 .30902 L
.77012 .30902 L
.77023 .30902 L
.77028 .30902 L
Mistroke
.77034 .30902 L
.7704 .30902 L
.77045 .30902 L
.77055 .30902 L
.77065 .30902 L
.77071 .30902 L
.77077 .30902 L
.77089 .30902 L
.771 .30902 L
.7711 .30902 L
.7715 .30902 L
.77192 .30902 L
.77269 .30902 L
.7735 .30902 L
.77498 .30902 L
.77579 .30902 L
.77623 .30902 L
.77668 .30902 L
.77708 .30902 L
.7773 .30902 L
.77752 .30902 L
.77773 .30902 L
.77793 .30902 L
.77802 .30902 L
.77812 .30902 L
.77821 .30902 L
.7783 .30902 L
.7784 .30902 L
.77846 .30902 L
.77851 .30902 L
.77861 .30902 L
.77871 .30902 L
.77876 .30902 L
.77882 .30902 L
.77892 .30902 L
.77903 .30902 L
.77915 .30902 L
.77935 .30902 L
.77956 .30902 L
.77995 .30902 L
.78066 .30902 L
.78144 .30902 L
.78312 .30902 L
.78386 .30902 L
.78425 .30902 L
.78467 .30902 L
.78508 .30902 L
.78545 .30902 L
.78563 .30902 L
.78582 .30902 L
Mistroke
.78591 .30902 L
.78601 .30902 L
.78609 .30902 L
.78618 .30902 L
.78628 .30902 L
.78637 .30902 L
.78646 .30902 L
.78657 .30902 L
.78666 .30902 L
.78676 .30902 L
.78685 .30902 L
.78694 .30902 L
.78714 .30902 L
.78737 .30902 L
.78777 .30902 L
.78853 .30902 L
.78937 .30902 L
.79106 .30902 L
.79187 .30902 L
.79263 .30902 L
.79305 .30902 L
.79327 .30902 L
.79351 .30902 L
.79371 .30902 L
.79381 .30902 L
.79393 .30902 L
.79403 .30902 L
.79412 .30902 L
.79422 .30902 L
.79431 .30902 L
.79441 .30902 L
.79447 .30902 L
.79452 .30902 L
.79461 .30902 L
.79471 .30902 L
.7948 .30902 L
.79489 .30902 L
.79508 .30902 L
.79528 .30902 L
.79547 .30902 L
.7959 .30902 L
.79737 .30902 L
.79903 .30902 L
.79976 .30902 L
.80015 .30902 L
.80057 .30902 L
.80097 .30902 L
.80114 .30902 L
.80133 .30902 L
.8015 .30902 L
Mistroke
.80169 .30902 L
.80179 .30902 L
.80188 .30902 L
.80197 .30902 L
.80206 .30902 L
.80215 .30902 L
.80225 .30902 L
.80235 .30902 L
.80245 .30902 L
.80254 .30902 L
.80263 .30902 L
.80281 .30902 L
.80302 .30902 L
.80324 .30902 L
.80364 .30902 L
.80447 .30902 L
.80522 .30902 L
.8061 .30902 L
.8069 .30902 L
.80764 .30902 L
.80803 .30902 L
.80845 .30902 L
.80867 .30902 L
.80887 .30902 L
.80907 .30902 L
.80926 .30902 L
.80947 .30902 L
.80958 .30902 L
.80964 .30902 L
.8097 .30902 L
.8098 .30902 L
.8099 .30902 L
.80995 .30902 L
.81001 .30902 L
.81012 .30902 L
.81022 .30902 L
.81027 .30902 L
.81032 .30902 L
.81052 .30902 L
.8107 .30902 L
.81088 .30902 L
.81127 .30902 L
.8117 .30902 L
.81318 .30902 L
.81404 .30902 L
.81487 .30902 L
.81561 .30902 L
.81603 .30902 L
.81641 .30902 L
.81661 .30902 L
Mistroke
.81682 .30902 L
.81702 .30902 L
.81712 .30902 L
.81721 .30902 L
.81729 .30902 L
.81737 .30902 L
.81746 .30902 L
.81756 .30902 L
.81765 .30902 L
.81775 .30902 L
.81784 .30902 L
.81792 .30902 L
.81802 .30902 L
.81812 .30902 L
.8183 .30902 L
.81851 .30902 L
.8187 .30902 L
.81953 .30902 L
.82118 .30902 L
.82199 .30902 L
.82272 .30902 L
.82308 .30902 L
.82348 .30902 L
.82382 .30902 L
.8242 .30902 L
.82441 .30902 L
.8246 .30902 L
.8247 .30902 L
.8248 .30902 L
.82486 .30902 L
.82492 .30902 L
.82502 .30902 L
.82511 .30902 L
.82521 .30902 L
.82532 .30902 L
.82541 .30902 L
.82551 .30902 L
.82559 .30902 L
.82578 .30902 L
.82598 .30902 L
.82616 .30902 L
.82656 .30902 L
.8273 .30902 L
.82896 .30902 L
.8297 .30902 L
.8305 .30902 L
.83091 .30902 L
.83136 .30902 L
.83156 .30902 L
.83178 .30902 L
Mistroke
.83198 .30902 L
.83216 .30902 L
.83226 .30902 L
.83237 .30902 L
.83243 .30902 L
.83248 .30902 L
.83259 .30902 L
.83268 .30902 L
.83278 .30902 L
.83288 .30902 L
.83298 .30902 L
.83303 .30902 L
.83309 .30902 L
.8332 .30902 L
.8334 .30902 L
.83364 .30902 L
.83386 .30902 L
.83464 .30902 L
.83547 .30902 L
.83706 .30902 L
.83775 .30902 L
.83851 .30902 L
.8389 .30902 L
.83926 .30902 L
.83947 .30902 L
.83965 .30902 L
.83975 .30902 L
.83986 .30902 L
.83996 .30902 L
.84006 .30902 L
.84016 .30902 L
.84026 .30902 L
.84036 .30902 L
.84045 .30902 L
.84055 .30902 L
.84067 .30902 L
.84087 .30902 L
.84109 .30902 L
.84132 .30902 L
.84174 .30902 L
.84334 .30902 L
.84419 .30902 L
.84508 .30902 L
.84588 .30902 L
.8461 .30902 L
.84633 .30902 L
.84654 .30902 L
.84676 .30902 L
.84697 .30902 L
.84707 .30902 L
Mistroke
.84717 .30902 L
.84727 .30902 L
.84736 .30902 L
.84746 .30902 L
.84757 .30902 L
.84766 .30902 L
.84776 .30902 L
.84786 .30902 L
.84795 .30902 L
.84804 .30902 L
.84812 .30902 L
.8483 .30902 L
.84869 .30902 L
.8491 .30902 L
.84985 .30902 L
.85152 .30902 L
.85228 .30902 L
.85269 .30902 L
.85309 .30902 L
.85346 .30902 L
.85365 .30902 L
.85386 .30902 L
.85403 .30902 L
.85423 .30902 L
.8544 .30902 L
.85456 .30902 L
.85466 .30902 L
.85476 .30902 L
.85485 .30902 L
.85494 .30902 L
.85504 .30902 L
.8551 .30902 L
.85515 .30902 L
.85525 .30902 L
.85535 .30902 L
.85545 .30902 L
.85556 .30902 L
.85575 .30902 L
.85618 .30902 L
.85696 .30902 L
.85767 .30902 L
.85847 .30902 L
.85932 .30902 L
.86013 .30902 L
.86048 .30902 L
.86086 .30902 L
.86105 .30902 L
.86125 .30902 L
.86144 .30902 L
.86162 .30902 L
Mistroke
.86172 .30902 L
.86182 .30902 L
.86188 .30902 L
.86194 .30902 L
.86199 .30902 L
.86204 .30902 L
.86213 .30902 L
.86224 .30902 L
.86233 .30902 L
.86244 .30902 L
.86253 .30902 L
.86262 .30902 L
.86282 .30902 L
.86301 .30902 L
.86322 .30902 L
.86393 .30902 L
.86553 .30902 L
.86637 .30902 L
.86683 .30902 L
.86726 .30902 L
.86768 .30902 L
.86806 .30902 L
.86848 .30902 L
.86871 .30902 L
.86882 .30902 L
.86893 .30902 L
.86902 .30902 L
.86912 .30902 L
.86922 .30902 L
.86932 .30902 L
.86941 .30902 L
.8695 .30902 L
.86958 .30902 L
.86967 .30902 L
.86978 .30902 L
.86987 .30902 L
.87009 .30902 L
.87029 .30902 L
.87047 .30902 L
.87125 .30902 L
.87208 .30902 L
.87356 .30902 L
.87431 .30902 L
.87473 .30902 L
.87513 .30902 L
.87549 .30902 L
.8757 .30902 L
.87589 .30902 L
.87607 .30902 L
.87623 .30902 L
Mistroke
.87632 .30902 L
.87642 .30902 L
.87651 .30902 L
.8766 .30902 L
.8767 .30902 L
.87679 .30902 L
.87688 .30902 L
.87697 .30902 L
.87707 .30902 L
.87718 .30902 L
.87738 .30902 L
.87772 .30902 L
.87811 .30902 L
.87977 .30902 L
.88059 .30902 L
.88145 .30902 L
.88181 .30902 L
.88219 .30902 L
.88241 .30902 L
.8826 .30902 L
.88279 .30902 L
.88299 .30902 L
.88319 .30902 L
.88329 .30902 L
.88339 .30902 L
.88349 .30902 L
.88357 .30902 L
.88367 .30902 L
.88376 .30902 L
.88386 .30902 L
.88392 .30902 L
.88397 .30902 L
.88407 .30902 L
.88416 .30902 L
.88437 .30902 L
.88459 .30902 L
.88497 .30902 L
.88538 .30902 L
.8861 .30902 L
.8877 .30902 L
.88839 .30902 L
.88915 .30902 L
.88936 .30902 L
.88957 .30902 L
.88977 .30902 L
.88996 .30902 L
.89013 .30902 L
.89032 .30902 L
.89043 .30902 L
.89053 .30902 L
Mistroke
.89062 .30902 L
.89072 .30902 L
.89078 .30902 L
.89084 .30902 L
.89089 .30902 L
.89094 .30902 L
.89104 .30902 L
.89114 .30902 L
.89125 .30902 L
.89136 .30902 L
.89159 .30902 L
.89198 .30902 L
.8924 .30902 L
.89399 .30902 L
.89483 .30902 L
.89529 .30902 L
.89572 .30902 L
.89613 .30902 L
.89651 .30902 L
.89671 .30902 L
.89693 .30902 L
.89715 .30902 L
.89727 .30902 L
.89738 .30902 L
.89748 .30902 L
.89758 .30902 L
.89768 .30902 L
.89777 .30902 L
.89785 .30902 L
.89794 .30902 L
.89803 .30902 L
.89812 .30902 L
.89822 .30902 L
.89832 .30902 L
.89851 .30902 L
.89892 .30902 L
.89932 .30902 L
.89969 .30902 L
.90051 .30902 L
.90198 .30902 L
.90238 .30902 L
.90279 .30902 L
.90315 .30902 L
.90353 .30902 L
.90375 .30902 L
.90394 .30902 L
.90414 .30902 L
.90423 .30902 L
.90433 .30902 L
.90443 .30902 L
Mistroke
.90449 .30902 L
.90455 .30902 L
.90464 .30902 L
.90475 .30902 L
.9048 .30902 L
.90486 .30902 L
.90493 .30902 L
.90498 .30902 L
.90509 .30902 L
.9052 .30902 L
.90541 .30902 L
.90563 .30902 L
.90603 .30902 L
.90692 .30902 L
.90854 .30902 L
.90929 .30902 L
.90971 .30902 L
.91011 .30902 L
.91048 .30902 L
.91068 .30902 L
.91088 .30902 L
.91106 .30902 L
.91122 .30902 L
.91131 .30902 L
.9114 .30902 L
.9115 .30902 L
.91158 .30902 L
.91168 .30902 L
.91178 .30902 L
.91186 .30902 L
.91196 .30902 L
.91206 .30902 L
.91217 .30902 L
.91236 .30902 L
.91271 .30902 L
.91309 .30902 L
.91476 .30902 L
.91555 .30902 L
.91631 .30902 L
.91673 .30902 L
.91695 .30902 L
.91719 .30902 L
.91741 .30902 L
.9176 .30902 L
.9178 .30902 L
.91799 .30902 L
.91808 .30902 L
.91818 .30902 L
.91828 .30902 L
.91836 .30902 L
Mistroke
.91846 .30902 L
.91852 .30902 L
.91857 .30902 L
.91867 .30902 L
.91877 .30902 L
.91887 .30902 L
.91898 .30902 L
.91917 .30902 L
.91939 .30902 L
.9196 .30902 L
.92032 .30902 L
.92108 .30902 L
.92191 .30902 L
.92269 .30902 L
.92338 .30902 L
.92378 .30902 L
.92414 .30902 L
.92432 .30902 L
.92451 .30902 L
.92461 .30902 L
.92471 .30902 L
.92481 .30902 L
.92491 .30902 L
.92501 .30902 L
.9251 .30902 L
.92516 .30902 L
.92522 .30902 L
.92532 .30902 L
.92542 .30902 L
.92551 .30902 L
.92561 .30902 L
.92572 .30902 L
.92592 .30902 L
.92613 .30902 L
.92652 .30902 L
.9274 .30902 L
.92899 .30902 L
.92943 .30902 L
.92989 .30902 L
.93029 .30902 L
.93072 .30902 L
.93092 .30902 L
.93113 .30902 L
.93131 .30902 L
.93141 .30902 L
.93151 .30902 L
.9316 .30902 L
.93169 .30902 L
.93179 .30902 L
.93189 .30902 L
Mistroke
.93198 .30902 L
.93207 .30902 L
.93215 .30902 L
.93224 .30902 L
.9323 .30902 L
.93236 .30902 L
.93246 .30902 L
.93266 .30902 L
.9329 .30902 L
.93311 .30902 L
.93392 .30902 L
.93555 .30902 L
.93634 .30902 L
.93669 .30902 L
.93707 .30902 L
.93744 .30902 L
.93778 .30902 L
.93797 .30902 L
.93814 .30902 L
.93824 .30902 L
.93834 .30902 L
.93844 .30902 L
.93853 .30902 L
.93862 .30902 L
.93872 .30902 L
.93881 .30902 L
.93889 .30902 L
.93899 .30902 L
.9391 .30902 L
.93929 .30902 L
.93949 .30902 L
.93971 .30902 L
.9401 .30902 L
.9417 .30902 L
.94255 .30902 L
.94301 .30902 L
.94344 .30902 L
.94386 .30902 L
.94424 .30902 L
.94445 .30902 L
.94466 .30902 L
.94477 .30902 L
.94488 .30902 L
.945 .30902 L
.94506 .30902 L
.94511 .30902 L
.94521 .30902 L
.9453 .30902 L
.94539 .30902 L
.94549 .30902 L
Mistroke
.94558 .30902 L
.94568 .30902 L
.94577 .30902 L
.94585 .30902 L
.94605 .30902 L
.94626 .30902 L
.94666 .30902 L
.94822 .30902 L
.94905 .30902 L
.94951 .30902 L
.94994 .30902 L
.95035 .30902 L
.95057 .30902 L
.9508 .30902 L
.95101 .30902 L
.9512 .30902 L
.95129 .30902 L
.95139 .30902 L
.95148 .30902 L
.95158 .30902 L
.95167 .30902 L
.95176 .30902 L
.95182 .30902 L
.95187 .30902 L
.95196 .30902 L
.95207 .30902 L
.95216 .30902 L
.95226 .30902 L
.95237 .30902 L
.95255 .30902 L
.95272 .30902 L
.95311 .30902 L
.95394 .30902 L
.95473 .30902 L
.95551 .30902 L
.95622 .30902 L
.95659 .30902 L
.95699 .30902 L
.9572 .30902 L
.95741 .30902 L
.95761 .30902 L
.95781 .30902 L
.95797 .30902 L
.95805 .30902 L
.95815 .30902 L
.95825 .30902 L
.95834 .30902 L
.95844 .30902 L
.95852 .30902 L
.95861 .30902 L
Mistroke
.9587 .30902 L
.95879 .30902 L
.95889 .30902 L
.95899 .30902 L
.95909 .30902 L
.95928 .30902 L
.95968 .30902 L
.96005 .30902 L
.96086 .30902 L
.96234 .30902 L
.96273 .30902 L
.96314 .30902 L
.96349 .30902 L
.96388 .30902 L
.96409 .30902 L
.96429 .30902 L
.96438 .30902 L
.96448 .30902 L
.96458 .30902 L
.96467 .30902 L
.96473 .30902 L
.96479 .30902 L
.96489 .30902 L
.96495 .30902 L
.96501 .30902 L
.96507 .30902 L
.96513 .30902 L
.96523 .30902 L
.96529 .30902 L
.96534 .30902 L
.96545 .30902 L
.96555 .30902 L
.96574 .30902 L
.96592 .30902 L
.96632 .30902 L
.96715 .30902 L
.96863 .30902 L
.96942 .30902 L
.96981 .30902 L
.97025 .30902 L
.97062 .30902 L
.97083 .30902 L
.97093 .30902 L
.97102 .30902 L
.9711 .30902 L
.97119 .30902 L
.97129 .30902 L
.97139 .30902 L
.97147 .30902 L
.97157 .30902 L
Mistroke
.97165 .30902 L
.97173 .30902 L
.97183 .30902 L
.97192 .30902 L
.97212 .30902 L
.97232 .30902 L
.97253 .30902 L
.97326 .30902 L
.97493 .30902 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{421.375, 260.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008>0001AB000`400?l00000o`00003ooooooooo
oooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo
003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooo
oooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool0
0?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooooooo
ool@ooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooo
ooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo0ol0003o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0
003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo
00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`
ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLoooo
o`00<?ooool3o`000?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?oo
ool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0
033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomco
oooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooo
oooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool3o`000?oooooo
g?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0013ooooo0_o^k^h3ooooo`;ok^k^6Oooool00ol0003oooooooooo`3o
ooooomcooooo000;ooooo`;o000000[o410@ooooooooooook^k^oeEEEOo^k^koooooonk^k_mEEEGo
k^k^0oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h:ooooo`03o`000?oo
oooooooo0?oooooog?ooool000cooooo00?o0000ooooooooool00_ooool01Oo^k^koEEEEomgMgOmE
EEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00[ooooo
00?o0000ooooooooool0oooooooLooooo`0000?oooooo`000?l000001?l00002ooooo`Go00001?oo
ool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooo
oa0@400:ooooo`03o`000?oooooooooo09Cooooo0_l0003oooooodKooooo0009ooooo`04odA4A?oM
gMgoooooo`0000Cooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`00000:ooooo`03o`000?oooooooooo09Cooooo0_l0003ooooo
odKooooo0009ooooo`04omgMgOmEEEGoooooo`0000?ooooo00Ook^k^oeEEEOo^k^koooooonk^k_mE
EEGok^k^00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000[ooooo
1?l0002Cooooo`;o0000oooooom6ooooo`002_ooool00omgMgOoc<c<o`000003ooooo`;ok^k^0ooo
ool2onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00[ooooo
00?o0000ooooooooool0R?ooool2o`0000[ooooo0_l0003oooooodKooooo000:ooooo`03onk^k_m4
A4Co000000oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo
0_l00005ooooo`03o`000?oooooooooo08Sooooo0_l0000:ooooo`;o0000oooooom6ooooo`002ooo
ool00omgMgOo0000ooooo`0<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP02ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0R?ooool2o`0000[o
oooo0_l0003oooooodKooooo000Xooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool0R?ooool2o`0000[ooooo0_l0003oooooodKooooo000Xooooo`?o00001Oooool00ol0003ooooo
ooooo`28ooooo`;o00002_ooool2o`000?ooooooA_ooool002Wooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`28ooooo`;o00002_ooool2o`000?ooooooA_ooool002[ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`28ooooo`;o00002_ooool2o`000?ooooooA_ooool0
033ooooo00?o0000ooooooooool0R?ooool2o`0000[ooooo0_l0003oooooodKooooo000`ooooo`03
o`000?oooooooooo08Sooooo0_l0000:ooooo`;o0000oooooom6ooooo`00<?ooool00ol0003ooooo
ooooo`28ooooo`;o00002_ooool2o`000?ooooooA_ooool0033ooooo00?o0000ooooooooool0R?oo
ool2o`0000Wooooo00?o0000ooooool00000oooooom6ooooo`00<?ooool3o`0008Sooooo0_l00009
ooooo`03o`000?oooooo00000?ooooooA_ooool0033ooooo00?o0000ooooooooool0Qoooool00ol0
003oooooo`000009ooooo`03o`000?oooooo000000[ooooo00?o0000ooooooooool0oooooolioooo
o`00<?ooool00ol0003oooooooooo`27ooooo`03o`000?oooooo000000Wooooo00?o0000ooooool0
00002Oooool2o`000?oooooo>oooool0033ooooo00?o0000ooooooooool0Qoooool00ol0003ooooo
o`000009ooooo`03o`000?oooooo000000Wooooo0_l0003ooooooc_ooooo000`ooooo`03o`000?oo
oooooooo08Oooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`000009ooooo`;o0000
oooooolkooooo`00<?ooool00ol0003oooooooooo`27ooooo`04o`000?ooooooooooo`0000Sooooo
00?o0000ooooool000002Oooool2o`000?oooooo>oooool0033ooooo00?o0000ooooooooool0Qooo
ool01?l0003oooooooooool00008ooooo`03o`000?oooooo000000Wooooo0_l0003ooooooc_ooooo
000`ooooo`03o`000?oooooooooo08Oooooo00Co0000oooooooooooo00002?ooool00ol0003ooooo
o`000009ooooo`;o0000oooooolkooooo`00<?ooool00ol0003oooooooooo`27ooooo`04o`000?oo
ooooooooo`0000Sooooo00?o0000ooooool000002Oooool2o`000?oooooo>oooool0033ooooo00?o
0000ooooooooool0Qoooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000So
oooo0_l0003ooooooc_ooooo000`ooooo`03o`000?oooooooooo08Oooooo00Co0000oooooooooooo
00002?ooool01?l0003oooooooooool00008ooooo`;o0000oooooolkooooo`00<?ooool00ol0003o
ooooooooo`27ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002?ooool2
o`000?oooooo>oooool0033ooooo0ol00027ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000
oooooooooooo00002?ooool2o`000?oooooo>oooool0033ooooo00?o0000ooooooooool0O?ooool0
0ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000
2?ooool00ol0003oooooo`00003ooooooc[ooooo000`ooooo`03o`000?oooooooooo07cooooo00?o
0000ooooooooool02?ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000So
oooo00?o0000ooooool00000ooooooljooooo`00<?ooool00ol0003oooooooooo`1kooooo`;o0000
2_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000oooo
ool00000ooooooljooooo`00<?ooool00ol0003oooooooooo`1kooooo`;o00002_ooool01?l0003o
ooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooolj
ooooo`00<?ooool00ol0003oooooooooo`1kooooo`03o`000?oooooo000000Wooooo00Co0000oooo
oooooooo00002?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?oooooo>_oo
ool0033ooooo00?o0000ooooooooool0Noooool00ol0003oooooo`000009ooooo`04o`000?oooooo
ooooo`0000Sooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003ooooooc[ooooo
000`ooooo`03o`000?oooooooooo07_ooooo00?o0000ooooool000002Oooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000ooooooljooooo`00
<?ooool00ol0003oooooooooo`1kooooo`03o`000?oooooo000000Wooooo00Co0000oooooooooooo
00002?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?oooooo>_ooool0033o
oooo00?o0000ooooooooool0Noooool00ol0003oooooo`000009ooooo`04o`000?ooooooooooo`00
00Sooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003ooooooc[ooooo000`oooo
o`03o`000?oooooooooo07_ooooo00?o0000ooooool000002Oooool01?l0003oooooooooool00008
ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo0000ooooooljooooo`00<?oo
ool3o`0007_ooooo00?o0000ooooool000002Oooool01?l0003oooooooooool00008ooooo`04o`00
0?ooooooooooo`0000Oooooo00Co0000oooooooooooo0000ooooooljooooo`00<?ooool00ol0003o
ooooooooo`1kooooo`03o`000?oooooo000000Wooooo00Co0000oooooooooooo00002?ooool01?l0
003oooooooooool00007ooooo`04o`000?ooooooooooo`000?oooooo>_ooool0033ooooo00?o0000
ooooooooool0Noooool00ol0003oooooo`000009ooooo`04o`000?ooooooooooo`0000Sooooo00Co
0000oooooooooooo00001oooool01?l0003oooooooooool0003ooooooc[ooooo000`ooooo`03o`00
0?oooooooooo07_ooooo00?o0000ooooool000002Oooool01?l0003oooooooooool00008ooooo`04
o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`3o
oooooboooooo000`ooooo`03o`000?oooooooooo07_ooooo00?o0000ooooool000002Oooool01?l0
003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo0000
2?ooool2o`000?oooooo<?ooool0033ooooo00?o0000ooooooooool0Noooool00ol0003oooooo`00
0009ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001oooool01?l0003o
ooooooooool00008ooooo`;o0000ooooool`ooooo`00<?ooool00ol0003oooooooooo`1kooooo`03
o`000?oooooo000000Wooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00007
ooooo`04o`000?ooooooooooo`0000Sooooo0_l0003ooooooc3ooooo000@ooooo`;ok^k^0oooool2
onk^kQWooooo00?o0000ooooooooool0Noooool00ol0003oooooo`000009ooooo`04o`000?oooooo
ooooo`0000Sooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool00008ooooo`;o
0000ooooool`ooooo`002Oooool5o`0000;ooooo00Ook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^
00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^2_ooool00ol0003ooooo
ooooo`1kooooo`03o`000?oooooo000000Wooooo00Co0000oooooooooooo00002?ooool01?l0003o
ooooooooool00007ooooo`04o`000?ooooooooooo`0000Sooooo0_l0003ooooooc3ooooo0009oooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00[ooooo00?o0000ooooooooool0
N_ooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool000002?ooool01?l0
003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool00000oooo
ool`ooooo`0000?oooooo`000?l000001?l00003ooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?ogMgM
o`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41002_oo
ool00ol0003oooooooooo`1jooooo`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooooooo
ooooo`000008ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00001oooool0
0ol0003oooooo`00003ooooooc3ooooo000;ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Gok^k^oeEE
EOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
000:ooooo`03o`000?oooooooooo07[ooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooo
oooooooooooo000000Sooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool00007
ooooo`03o`000?oooooo00000?oooooo<?ooool000cooooo00_oMgMgofIVI_ooooooooooonk^k_mE
EEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`00000:ooooo`Co0000NOooool01?l0003oooooooooool00008ooooo`05o`000?oooooo
ooooooooool000002?ooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Oo
oooo00?o0000ooooool00000ooooool`ooooo`003Oooool00ol0003oooooooooo`02onk^kP?ooooo
0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400:ooooo`03
o`000?oooooooooo07[ooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo
000000Sooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool00007ooooo`03o`00
0?oooooo00000?oooooo<?ooool000Wooooo00Go0000okZj^_ooooooV9RHoa0@400>ooooo`03o`00
0?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`;o00001Oooool00ol0003o
ooooooooo`1jooooo`04o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000008
ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00001oooool00ol0003ooooo
o`00003ooooooc3ooooo0009ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?ooool00omEEEGoIVIV
o`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_ooool01?l0003oooooooooool00004oooo
o`03o`000?oooooooooo07[ooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooo
oooo000000Sooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool00007ooooo`03
o`000?oooooo00000?oooooo<?ooool002Sooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`1jooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo
000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo
00?o0000ooooool00000ooooool`ooooo`00:?ooool3o`0000Gooooo00?o0000ooooooooool0N_oo
ool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`05
o`000?ooooooooooooooool000001oooool01?l0003oooooooooool00007ooooo`03o`000?oooooo
00000?oooooo<?ooool002Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1joooo
o`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Go
0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool0
0000ooooool`ooooo`00:_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07[ooooo
00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool01Ol0
003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo00001oooool01?l0003ooooooooo
ool0003ooooooboooooo000`ooooo`03o`000?oooooooooo07[ooooo00Go0000oooooooooooooooo
o`000007ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo0000
00Oooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool0003ooooooboooooo000`
ooooo`03o`000?oooooooooo06kooooo0_l0000:ooooo`05o`000?ooooooooooooooool000001ooo
ool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04
o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo0000ooooool_ooooo`00<?ooool00ol0
003oooooooooo`1^ooooo`;o00002_ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000
ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool01?l0003ooooo
ooooool00007ooooo`04o`000?ooooooooooo`000?oooooo;oooool0033ooooo00?o0000oooooooo
ool0K_ooool2o`0000[ooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooooooo
ooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000
1oooool01?l0003oooooooooool0003ooooooboooooo000`ooooo`?o0000K_ooool2o`0000[ooooo
00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo00001oooool0
1?l0003oooooooooool0003ooooooboooooo000`ooooo`03o`000?oooooooooo06gooooo00Co0000
oooooooooooo00002Oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001oooool01?l0003o
ooooooooool00007ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool0oooooolT
ooooo`00<?ooool00ol0003oooooooooo`1]ooooo`04o`000?ooooooooooo`0000Wooooo00Go0000
ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo00001oooool01?l0003o
ooooooooool00007ooooo`;o0000oooooolVooooo`00<?ooool00ol0003oooooooooo`1]ooooo`04
o`000?ooooooooooo`0000Wooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Oooooo00Co
0000oooooooooooo00001oooool01?l0003oooooooooool00007ooooo`;o0000oooooolVooooo`00
<?ooool00ol0003oooooooooo`1]ooooo`04o`000?ooooooooooo`0000Wooooo00Go0000oooooooo
ooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0
003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo00001oooool01?l0003ooooooooo
ool00007ooooo`;o0000oooooolVooooo`00<?ooool00ol0003oooooooooo`1]ooooo`04o`000?oo
ooooooooo`0000Wooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooo
ooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Oooooo0_l0003oooooobKooooo000`
ooooo`03o`000?oooooooooo06gooooo00Co0000oooooooooooo00002Oooool01Ol0003ooooooooo
oooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`00
0?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooo
oooooooo00001oooool2o`000?oooooo9_ooool0033ooooo00?o0000ooooooooool0KOooool01?l0
003oooooooooool00008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00
0007ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool00007ooooo`;o
0000oooooolVooooo`00<?ooool00ol0003oooooooooo`1]ooooo`04o`000?ooooooooooo`0000So
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000Kooooo00Co0000
oooooooooooo0000oooooolUooooo`00<?ooool00ol0003oooooooooo`1]ooooo`04o`000?oooooo
ooooo`0000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool0
00001_ooool01?l0003oooooooooool0003oooooobGooooo000`ooooo`03o`000?oooooooooo06go
oooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooo
ooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000
ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`000?oooooo9Oooool0033ooooo00?o
0000ooooooooool0KOooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo
00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo0000oooooolU
ooooo`00<?ooool3o`0006cooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo
0000oooooolUooooo`00<?ooool00ol0003oooooooooo`1/ooooo`05o`000?ooooooooooooooool0
00002?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooo
ooooooooo`000006ooooo`04o`000?ooooooooooo`000?oooooo9Oooool0033ooooo00?o0000oooo
ooooool0K?ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003ooooooooo
ool0003oooooobGooooo000`ooooo`03o`000?oooooooooo06cooooo00Go0000oooooooooooooooo
o`000008ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooo
oooooooooooo000000Kooooo00Co0000oooooooooooo0000oooooolUooooo`00<?ooool00ol0003o
ooooooooo`1/ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000006oooo
o`04o`000?ooooooooooo`000?oooooo9Oooool0033ooooo00?o0000ooooooooool0C_ooool2onk^
kP?ooooo0_o^k^hGooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Ko0000ooooooooooooooooo`000?o^
k^h3ooooo`;ok^k^00Co0000oooooooooooo0000G?ooool2onk^kP?ooooo0_o^k^i>ooooo`;ok^k^
0oooool2onk^kVcooooo000`ooooo`03o`000?oooooooooo04Sooooo00goA4A4o`000?l0003o<S8b
omgMgOooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413ooooooooo
ooo^k^ko<S8bo`000?lb<S;ok^k^2?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooooooool4o`00000:oa0@4?oooooo
0000oeEEEOo^k^koooooonk^k_mEEEGok^k^o`0000;ooooo1?l000001?l@413oooooooooooo^k^h2
o`000003oc8b<_o^k^kooooo03[ooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool0
3Om4A4Co0000o`000?lb<S;ogMgMooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4
o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hhooooo`Go00000_ooool01oo^k^ko
EEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000
oc8b<_o^k^iMooooo`00<?ooool00ol0003oooooooooo`1;ooooo`09ogMgMolb<S;oooooooooooo^
k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool03?l0003ooooooooooooooooo0000onk^k_mE
EEGogMgMoeEEEOo^k^koooooo`0000;ooooo00?o0000ooooool000001?ooool01OmgMgOo0000o`00
0?nHV9SoMgMg03gooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00WoMgMgoc8b<_oooooo
ooooonk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL0>?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00Gok^k^oeEEEOoMgMgo
EEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Moooo
o`00<?ooool00ol0003oooooooooo`1<ooooo`07o`000?oooooooooooooooooMgMgo0000omgMg@07
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4008ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00Wo0000ooooooooooooooooo`000?oooooogMgMo`000?oMgMd00_ooool01_l0
003oooooooooool0003oooooo`0000Cooooo00Go410@o`000?l0003ooooooa0@400mooooo`03o`00
0?oooooooooo00oooooo00Oo0000ooooooooooooooooomgMgOl0003ogMgM00Oooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@03Wooooo00?oV9RHob4Q8Oo^k^h01Oooool0
0ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
401Mooooo`00<?ooool00ol0003oooooooooo`1;ooooo`09ogMgMolb<S;oooooooooooo^k^koEEEE
omgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool2o`0000;ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`0<o`000?ooooooooooooooool0003ok^k^oeEEEOoM
gMgoEEEEonk^k_oooooo00000_ooool00ol0003oooooo`000004ooooo`?o000000?oooooo`000?oo
ool0??ooool00ol0003oooooooooo`0>ooooo`09ogMgMolb<S;oooooooooooo^k^koEEEEomgMgOmE
EEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000003[ooooo
00?oV9RHob4Q8Oo^k^h00oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000oooooooo
ool00_ooool01Ol0003ooooooooooooooooo000005gooooo000`ooooo`03o`000?oooooooooo04So
oooo00go0000ob4Q8Ol0003o<S8bolc<c?ooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Go
oooo00?o0000ooooooooool00_ooool3o`000003ooooool0003ooooo00Kooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool03?l0003ooooooooooooooooo0000oeEEEOo^k^koooooonk^k_mEEEGok^k^o`0000;o
oooo00?o0000ooooool000001?ooool01Ol0003oooooo`000?oooooo000003gooooo00?o0000oooo
ooooool02oooool03Ol0003o8B4Qo`000?lb<S;oc<c<ooooooo^k^koEEEEonk^k_ooooook^k^oeEE
EOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000>oooool0
2omgMgOoIVIVooooooooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000005gooooo000`ooooo`03o`000?oooooooooo
04Sooooo00?o0000ooooooooool00oooool2onk^kP?ooooo0_o^k^h5ooooo`0:o`000?oooooooooo
ooooool0003o410@ooooool0003ooooooa0@40Oooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01_l0003o
oooooooooooooooo0000onk^kP?ooooo0_o^k^h01_l0003oooooooooool0003oooooo`0000Cooooo
00Go0000ooooool0003ooooooa0@400mooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool00oooool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooo
oooooooooa0@400looooo`03o`000?oooooooooo00;ok^k^0oooool2onk^kPGooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@05gooooo000`ooooo`?o0000B?ooool00ol0
003oooooooooo`0?ooooo`0:o`000?ooooooooooooooool0003oMgMgoiRHV?l0003oV9RHogMgM`Oo
oooo0_l00004ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`05o`000?ooooooooooooooool000001_ooool01_l0003oooooooooool0003o
ooooo`0000Cooooo00Go0000oiRHV?oooooo0000ogMgM`08ooooo`;o0000<oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Sooooo0_l0000^ooooo`05o`000?nj^[[ooooooiRHV?l@41003_ooool00ol0
003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool2o`0005?ooooo000`oooo
o`03o`000?oooooooooo04Sooooo1?l0000<ooooo`03oeEEEOmVIVKo000000?ooooo00?o0000onk^
k_lb<S800_l000000oo^k^koooooooooo`05ooooo`;o00001?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00Oo0000oooooooooooooooooeEEEOmVIVKo000000?ooooo00?o
0000ooooooooool01?ooool01?l0003ooooooooooomEEED2o`0000Cooooo00Go0000oc8b<_l0003o
0000onk^kP07ooooo`04o`000?ooooooooooo`00033ooooo00?oEEEEofIVI_l000003Oooool4o`00
00cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oooooo00Co0000
oooooooooooo0000;Oooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo00?oEEEEofIVI_l00000
1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oooooo00Co0000oooooooooooo0000D_ooool0033o
oooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooooooo
o`Co000000Coooooo`000?oooooo00000oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Kooooo00Go
0000ooooooooooooooooo`000005ooooo`04o`000?ooooooooooo`0000?ooooo1?l000001Ooooooo
0000oooooooooooo000005kooooo1?l000001Ooooooo0000oooooooooooo000004cooooo1?l00000
1Ooooooo0000oooooooooooo000005;ooooo000`ooooo`03o`000?oooooooooo05gooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo000000?ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000
ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001Oooool01?l0003ooooo
ooooool00006ooooo`Go0000I?ooool3o`0005;ooooo0ol0001Cooooo`00<?ooool00ol0003ooooo
ooooo`1Mooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool01?l0003ooooo
ooooool00002ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo
000000Gooooo00Co0000oooooooooooo00001_ooool2o`000003ooooool0003ooooo06Gooooo00?o
0000ooooooooool0D_ooool00ol0003oooooooooo`1Booooo`00<?ooool00ol0003oooooooooo`1M
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool4o`0000;ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000
ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooool0003oooooo`00001Vooooo`03
o`000?oooooooooo05;ooooo00?o0000ooooooooool0DOooool0033ooooo00?o0000ooooooooool0
GOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooo`00003ooooooa;ooooo000`ooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
0000eoooool00omgMgOoIVIVooooo`0]ooooo`03ofIVI_mgMgOooooo00Oooooo000`ooooo`03o`00
0?oooooooooo04oooooo0ol0000:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001Oooool2o`000<ko
oooo00?ogMgMoa0@4?o^k^h0;_ooool00oo^k^ko410@omgMg@07ooooo`00<?ooool00ol0003ooooo
ooooo`1>ooooo`03o`000?oooooooooo00;o00002Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Go
oooo00?o0000ooooool00000^oooool2o`0000;ooooo0_l0000<ooooo`03oeEEEOnHV9Sooooo00;o
00000_ooool01ol0003oooooooooool0003o410@onk^k_mEEED00_l000000om4A4Co^[Zjooooo`02
ooooo`05oiRHV?l0003o0000odA4A?nj^[X00_ooool02?o^k^koEEEEo`000?l0003oA4A4okZj^_oo
oooo410@1Ol00003ooooo`08oa0@4?lb<S;o0000o`000?l@413oZJVYohN7QomVIVH7ooooo`00<?oo
ool00ol0003oooooooooo`1<ooooo`;o00001?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000001?ooool01?l0003oooooooooool00006ooooo`?o0000/_ooool01_o^k^ko
8B4QohN7Qonj^[[o0000omgMg@cooooo00Go0000ooooooooooooooooo`000002ooooo`0;o`000?oo
ooooooooo`000?ooooooEEEEogMgMoooooook^k^ogMgMol@41000oooool01Ol@413o^[Zjonk^k_mg
MgOo410@00;ooooo00KoEEEEogMgMoooooook^k^ogMgMol@4103ooooo`03o`000?oooooooooo00Co
oooo00So0000ojVYZOoooooooooookZj^_l0003ok^k^o`0000Oooooo003oo`000;Co00003oooool0
1?oMgMgo0000oa0@4?o<c<`=ooooo`05oc8b<_ooooooooooooooool000000_ooool01_l0003ooooo
ooooool0003oooooo`0000Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Gooooo00Oo^[ZjohN7QomVIVKoIVIVoa0@4?oooooo000000Oooooo000:
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0;
ooooo`So00002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooo000000Cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`;o00000oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00Ko0000oooooooooooo0000ooooool00004ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00_ooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00_ooool01ol0003ooooooooooooooooo0000ooooool000000_ooool0
1Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00oooool4o`0000Gooooo0_l0
0009ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool05oooool01?o^k^ko8B4Qoa0@
4?o^k^h=ooooo`05oc8b<_ooooooooooooooool000000_ooool01Ol0003oooooooooool0003ooooo
00Ko00000oooool00ol0003oooooooooo`04ooooo`Ko00000oooool00ol0003oooooooooo`04oooo
o`08oc8b<_lQ8B7oMgMgogMgMon7QhOok^k^ooooool00007ooooo`002_ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`04ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooool000001?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo0_l00003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool01_l0003oooooooooool0003oooooo`0000Cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`03o`000?oooooooooo
00;ooooo0ol00008ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0Gooooo`04ob4Q8OmgMgOoMgMgoc8b<Pgooooo00Go0000onk^k_ooooooooooo`00
0002olc<c00;o`000?nYZJWogMgMob4Q8OooooooEEEEohN7Qoo^k^koooooohN7Qolb<S800oooool0
0ol0003oooooooooo`04ooooo`06oeEEEOn7QhOok^k^oooooon7QhOo<S8b0oooool00ol0003o<S8b
omgMg@04ooooo`08o`000?nj^[[oooooonk^k_mgMgOo0000onk^k_l00007ooooo`00<?ooool00ol0
003oooooooooo`1Eooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo0_l00002ooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`000005ooooo`04o`000?ooooooooooo`0004Sooooo00?o
0000ooooooooool0Foooool00ol0003oooooooooo`0Fooooo`;o00000_ooool2o`0000cooooo00ko
EEEEogMgMooooooo410@o`000?lQ8B7o0000ogMgMol@413o0000ojVYZOooooook^k^oeEEE@;o0000
00CoA4A4onk^k_oooooo410@1Ol00003ooooo`06onk^k_mEEEGo0000o`000?m4A4Cok^k^0_ooool2
o`000004ojVYZOlQ8B7o0000ob4Q8@;ooooo00SoZJVYob4Q8Ol0003o0000oc8b<_l0003oMgMgoeEE
E@Oooooo000`ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003o
oooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000005ooooo`04o`000?oooooo
ooooo`000=7ooooo00?ogMgMoa0@4?o^k^h04_ooool00ol0003oooooooooo`0Iooooo`03onk^k_l@
413ogMgM00Oooooo000`ooooo`03o`000?oooooooooo05Kooooo00Go0000ooooooooooooooooo`00
0009ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooo
oooooooo000000Cooooo00Go0000ooooooooooooooooo`000006ooooo`;o0000doooool00omgMgOo
IVIVooooo`0Aooooo`03o`000?oooooooooo01Wooooo00?oIVIVogMgMoooool01oooool0033ooooo
00?o0000ooooooooool0E_ooool00ol0003oooooooooo`02o`0000Wooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003o
oooooooooooooooo000000Kooooo0_l0003oooooo`kooooo000`ooooo`03o`000?oooooooooo05Oo
oooo0ol0000:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003o
oooooooooooooooo000000Gooooo00Co0000oooooooooooo0000oooooolFooooo`00<?ooool00ol0
003oooooooooo`1Hooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooo`00003o
oooooaOooooo000`ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool01Ol0
003ooooooooooooooooo000000Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooo`00003ooooooaOooooo000`
ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooo
oooo000000Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`04o`000?oo
ooooooooo`0000Kooooo00?o0000ooooool00000oooooolGooooo`00<?ooool00ol0003ooooooooo
o`1Tooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000006ooooo`04o`00
0?ooooooooooo`0000Kooooo00Co0000oooooooooooo00001_ooool3o`000?oooooo5oooool0033o
oooo0ol0001Tooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000006oooo
o`04o`000?ooooooooooo`0000Kooooo00Co0000oooooooooooo00001oooool2o`000?oooooo5ooo
ool0033ooooo00?o0000ooooooooool0IOooool01Ol0003ooooooooooooooooo000000Sooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool00000
1_ooool01?l0003oooooooooool00006ooooo`04o`000?ooooooooooo`000?oooooo8?ooool0033o
oooo00?o0000ooooooooool0IOooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001_ooool0
1?l0003oooooooooool00006ooooo`04o`000?ooooooooooo`000?oooooo8?ooool0033ooooo00?o
0000ooooooooool0IOooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003o
ooooooooool00006ooooo`04o`000?ooooooooooo`000?oooooo8?ooool0033ooooo00?o0000oooo
ooooool0IOooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003ooooooooo
ool00006ooooo`04o`000?ooooooooooo`000?oooooo8?ooool0033ooooo00?o0000ooooooooool0
IOooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool00006
ooooo`04o`000?ooooooooooo`000?oooooo8?ooool0033ooooo00?o0000ooooooooool0I_ooool0
1?l0003oooooooooool00008ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo00001_ooool00ol0003o
ooooo`00003oooooob7ooooo000`ooooo`03o`000?oooooooooo06Kooooo00Co0000oooooooooooo
00002?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooo
ooooooooo`000006ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooool00000oooooolQ
ooooo`00<?ooool00ol0003oooooooooo`1Vooooo`04o`000?ooooooooooo`0000Wooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_oo
ool01?l0003oooooooooool00006ooooo`03o`000?oooooo00000?oooooo8Oooool0033ooooo00?o
0000ooooooooool0I_ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooo
oooo00001oooool2o`000?oooooo8Oooool0033ooooo00?o0000ooooooooool0I_ooool01?l0003o
ooooooooool00009ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0
003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo00001oooool2o`000?oooooo8Ooo
ool0033ooooo00?o0000ooooooooool0I_ooool00ol0003oooooo`00000:ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00Co
0000oooooooooooo00001oooool2o`000?oooooo8Oooool0033ooooo0ol0001Wooooo`;o00002_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooooooo
o`000006ooooo`04o`000?ooooooooooo`0000Oooooo0_l0003oooooob7ooooo000`ooooo`03o`00
0?oooooooooo06Oooooo0_l0000:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo00001oooool2o`00
0?oooooo8Oooool0033ooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?oooooooooo
o`000?oooooo:_ooool0033ooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?oooooo
ooooo`000?oooooo:_ooool0033ooooo00?o0000ooooooooool0Loooool01Ol0003ooooooooooooo
oooo000000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`000?oo
oooo:_ooool0033ooooo00?o0000ooooooooool0Loooool01Ol0003ooooooooooooooooo000000So
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000oooo
ooooooooooooo`000006ooooo`04o`000?ooooooooooo`000?oooooo:_ooool0033ooooo00?o0000
ooooooooool0Loooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000006ooooo`04
o`000?ooooooooooo`000?oooooo:_ooool0033ooooo00?o0000ooooooooool0Loooool01Ol0003o
oooooooooooooooo000000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo
000000Kooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`000?oooooo
:_ooool0033ooooo00?o0000ooooooooool0Loooool01Ol0003ooooooooooooooooo000000Sooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000oooooooo
ooooooooo`000006ooooo`04o`000?ooooooooooo`000?oooooo:_ooool0033ooooo00?o0000oooo
ooooool0Loooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
1Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000006ooooo`04o`00
0?ooooooooooo`000?oooooo:_ooool0033ooooo00?o0000ooooooooool0M?ooool01?l0003ooooo
ooooool00008ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?oooooo
ooooooooool000001_ooool01?l0003oooooooooool0003oooooob[ooooo000`ooooo`03o`000?oo
oooooooo07Cooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Oo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooooooo
ool000001_ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo0000oooo
oolZooooo`00<?ooool3o`0007Cooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooo
oooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`00
0?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooo
oooooooo0000oooooolZooooo`00<?ooool00ol0003oooooooooo`1dooooo`04o`000?oooooooooo
o`0000Sooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000oooooooooooo
ooooo`000007ooooo`;o0000ooooool[ooooo`00<?ooool00ol0003oooooooooo`1dooooo`04o`00
0?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000
ooooooooooooooooo`000007ooooo`;o0000ooooool[ooooo`00<?ooool00ol0003oooooooooo`1d
ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000007ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Ko
oooo00Go0000ooooooooooooooooo`000007ooooo`;o0000ooooool[ooooo`00<?ooool00ol0003o
ooooooooo`1dooooo`04o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000007
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooo
oooo000000Kooooo00Go0000ooooooooooooooooo`000007ooooo`;o0000ooooool[ooooo`00<?oo
ool00ol0003oooooooooo`1dooooo`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooooooo
ooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003o
oooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000007ooooo`;o0000ooooool[
ooooo`003oooool2onk^kP?ooooo0_o^k^hJooooo`03o`000?oooooooooo07Cooooo00Co0000oooo
oooooooo00002?ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooo
oooooooooooo000000Oooooo0_l0003oooooob_ooooo0008ooooo`Go00000_ooool01oo^k^koEEEE
onk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b
<_o^k^h;ooooo`03o`000?oooooooooo07Cooooo00Co0000oooooooooooo00002?ooool01Ol0003o
oooooooooooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04oooo
o`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Oooooo0_l0
003oooooob_ooooo0008ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01Oo^k^koEEEEomgM
gOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00?o0000ooooooooool0M?ooool01?l0003oooooooooool00008ooooo`05o`000?oooooooooo
ooooool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000
ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001oooool2o`000?oooooo
:oooool000Wooooo00?oV9RHob4Q8Oo^k^h01Oooool00ooMgMgo0000omgMg@07ooooo`03o`000?oo
oooooooo00;ooooo00Go410@oooooooooooooooooa0@400;ooooo`03o`000?oooooooooo07Cooooo
00?o0000ooooool000002Oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001oooool00ol0
003oooooo`000008ooooo`;o0000ooooool[ooooo`002_ooool00onHV9So8B4Qonk^kP03ooooo`05
onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool000002oooool00ol0003oooooooooo`1dooooo`03o`000?oooooo000000Wooooo00Go0000
ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooool00000ooooooleooooo`002ooo
ool02omgMgOoIVIVooooooooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000000_ooooo1?l0001cooooo`03o`000?oo
oooo000000Wooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooool0
0000ooooooleooooo`003?ooool00ol0003oooooooooo`02onk^kP?ooooo0_o^k^h5ooooo`03o`00
0?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400;ooooo`03o`000?oooooooooo07Co
oooo00?o0000ooooool000002Oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001oooool0
0ol0003oooooo`00003oooooocGooooo0008ooooo`05o`000?nj^[[ooooooiRHV?l@41003_ooool0
0ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ol0003ooooooooo
o`1dooooo`03o`000?oooooo000000Wooooo00Go0000ooooooooooooooooo`000007ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Oo
oooo00?o0000ooooool00000ooooooleooooo`002?ooool01OnHV9So410@o`000?lQ8B7oc<c<00co
oooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo0_l00006oooo
o`03o`000?oooooooooo07Gooooo0_l0000:ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001ooo
ool00ol0003oooooo`00003oooooocGooooo000Wooooo`04o`000?ooooooooooo`0000Gooooo00?o
0000ooooooooool0MOooool2o`0000[ooooo00Co0000oooooooooooo00001oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000007ooooo`03
o`000?oooooo00000?oooooo=Oooool002Oooooo00Co0000oooooooooooo00001Oooool00ol0003o
ooooooooo`1eooooo`;o00002_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000
ooooool00000ooooooleooooo`009oooool3o`0000Kooooo00?o0000ooooooooool0MOooool2o`00
00[ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Gooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00003oooooocGooooo000X
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0MOooool2o`0000[ooooo00Co0000
oooooooooooo00001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00Co
0000oooooooooooo00001oooool00ol0003oooooo`00003oooooocGooooo000Yooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0POooool01?l0003oooooooooool00007ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00007ooooo`03
o`000?oooooo00000?oooooo=Oooool0033ooooo00?o0000ooooooooool0POooool01?l0003ooooo
ooooool00007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool01?l0003o
ooooooooool00007ooooo`03o`000?oooooo00000?oooooo=Oooool0033ooooo00?o0000oooooooo
ool0POooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000002?ooool0
1?l0003oooooooooool00007ooooo`03o`000?oooooo00000?oooooo=Oooool0033ooooo00?o0000
ooooooooool0POooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool00000
2?ooool01?l0003oooooooooool00007ooooo`03o`000?oooooo00000?oooooo=Oooool0033ooooo
0ol00021ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000008oooo
o`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool00000ooooooleooooo`00<?ooool00ol0
003oooooooooo`21ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002?oo
ool01?l0003oooooooooool00007ooooo`03o`000?oooooo00000?oooooo=Oooool0033ooooo00?o
0000ooooooooool0POooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000So
oooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00003oooooocGooooo000`ooooo`03
o`000?oooooooooo087ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00008
ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool00000ooooooleooooo`00<?ooool0
0ol0003oooooooooo`21ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool00007ooooo`03o`000?oooooo00000?oooooo=Oooool0033ooooo
00?o0000ooooooooool0POooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00
00Sooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00003oooooocGooooo000`oooo
o`03o`000?oooooooooo087ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0
0008ooooo`03o`000?oooooo000000Sooooo00?o0000ooooool00000ooooooleooooo`00<?ooool0
0ol0003oooooooooo`21ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000
2?ooool00ol0003oooooo`000008ooooo`03o`000?oooooo00000?oooooo=Oooool0033ooooo00?o
0000ooooooooool0POooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000So
oooo00?o0000ooooool000002Oooool00ol0003oooooooooo`3oooooocCooooo000`ooooo`03o`00
0?oooooooooo087ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00008oooo
o`03o`000?oooooo000000Wooooo00?o0000ooooooooool0ooooooldooooo`00<?ooool00ol0003o
ooooooooo`21ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002?ooool0
0ol0003oooooo`000009ooooo`03o`000?oooooooooo0?oooooo=?ooool0033ooooo00?o0000oooo
ooooool0POooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo00?o
0000ooooool00000oooooom0ooooo`00<?ooool3o`00087ooooo00Co0000oooooooooooo00002?oo
ool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?oooooo@?ooool0033ooooo00?o
0000ooooooooool0POooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000So
oooo00?o0000ooooool00000oooooom0ooooo`00<?ooool00ol0003oooooooooo`21ooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003ooooo
od3ooooo000`ooooo`03o`000?oooooooooo087ooooo00?o0000ooooool000002Oooool01?l0003o
ooooooooool00008ooooo`03o`000?oooooo00000?oooooo@?ooool0033ooooo00?o0000oooooooo
ool0POooool00ol0003oooooo`000009ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000oooo
ool00000oooooom0ooooo`00<?ooool00ol0003oooooooooo`21ooooo`03o`000?oooooo000000Wo
oooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003ooooood3ooooo000`ooooo`03
o`000?oooooooooo08;ooooo0_l00009ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000oooo
ool00000oooooom0ooooo`00<?ooool00ol0003oooooooooo`22ooooo`;o00002Oooool01?l0003o
ooooooooool00008ooooo`03o`000?oooooo00000?oooooo@?ooool0033ooooo00?o0000oooooooo
ool0P_ooool2o`0000Wooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003ooooo
od3ooooo000`ooooo`03o`000?oooooooooo08;ooooo0_l00009ooooo`04o`000?ooooooooooo`00
00Sooooo00?o0000ooooool00000oooooom0ooooo`00<?ooool00ol0003oooooooooo`22ooooo`;o
00002Oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?oooooo@?ooool0033o
oooo00?o0000ooooooooool0P_ooool2o`0000Wooooo00Co0000oooooooooooo00002?ooool00ol0
003oooooo`00003ooooood3ooooo000`ooooo`?o0000P_ooool2o`0000Wooooo00Co0000oooooooo
oooo00002?ooool00ol0003oooooo`00003ooooood3ooooo000`ooooo`03o`000?oooooooooo08go
oooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003ooooood3ooooo000`ooooo`03
o`000?oooooooooo08kooooo00?o0000ooooool000002?ooool00ol0003oooooo`00003ooooood3o
oooo000`ooooo`03o`000?oooooooooo08kooooo0_l00009ooooo`03o`000?oooooo00000?oooooo
@?ooool0033ooooo00?o0000ooooooooool0S_ooool2o`0000Wooooo00?o0000ooooool00000oooo
oom0ooooo`00<?ooool00ol0003oooooooooo`2>ooooo`;o00002_ooool2o`000?oooooo@?ooool0
00oooooo0_o^k^h3ooooo`;ok^k^6_ooool00ol0003oooooooooo`2>ooooo`;o00002_ooool00ol0
003oooooooooo`3oooooocoooooo000:ooooo`;o000000[o410@ooooooooooook^k^oeEEEOo^k^ko
ooooonk^k_mEEEGok^k^0oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h;
ooooo`03o`000?oooooooooo08kooooo0_l0000:ooooo`03o`000?oooooooooo0?oooooo?oooool0
00_ooooo00?o0000ooooooooool00_ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000
ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?o0000ooooooooool0S_oo
ool2o`0000[ooooo00?o0000ooooooooool0ooooooloooooo`002?ooool5o`0000Cooooo00?ogMgM
o`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41002ooo
ool00ol0003oooooooooo`2>ooooo`;o0000oooooom<ooooo`002?ooool01?m4A4CogMgMooooool0
0004ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000002oooool00ol0003oooooooooo`2>ooooo`;o0000oooooom<ooooo`00
2?ooool01?oMgMgoEEEEooooool00003ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000;ooooo`Co0000SOoo
ool2o`000?ooooooC?ooool000Wooooo00?oMgMgolc<c?l000000oooool2onk^kP?ooooo0_o^k^h5
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400;ooooo`03o`000?oo
oooooooo08kooooo0_l0003oooooodcooooo0009ooooo`03onk^k_m4A4Co000000oooooo00?o0000
ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?o0000ooooooooool0S_oo
ool2o`000?ooooooC?ooool000[ooooo00?oMgMgo`000?ooool03?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool2o`0000Kooooo00?o0000ooooooooool0S_oo
ool2o`000?ooooooC?ooool002Oooooo00Co0000oooooooooooo00001Oooool00ol0003ooooooooo
o`2>ooooo`;o0000oooooom<ooooo`009oooool01?l0003oooooooooool00005ooooo`03o`000?oo
oooooooo0?oooooog?ooool002Oooooo0ol00006ooooo`03o`000?oooooooooo0?oooooog?ooool0
02Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooomcooooo000Yooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooo
ooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000
ooooooooool0oooooooLooooo`00<?ooool3o`000?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0
003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo
00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`
ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLoooo
o`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`?o0000oooooooLooooo`00<?oo
ool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0
033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomco
oooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooo
oooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooo
ooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo0ol0003o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooo
oooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool0
0?ooooooooooool@ooooo`00oooooooooooooa3ooooo002Pooooo`;o00001?ooool00onj^[[o<S8b
ooooo`04ooooo`;o00001_ooool00ol0003o^[Zjooooo`3ooooooeOooooo002Pooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`;o<S8boooo
oomHooooo`00SOooool3o`0000;ooooo00Ko<S8boa0@4?ooooooooooonk^k_mEEED2o`000003odA4
A?nj^[[ooooo00?ooooo00?o0000ooooooooool00_ooool01OnHV9So410@o`000?l0003oZJVY00Co
oooo00?o0000ooooooooool01?ooool00on7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4
A?nj^[X02Oooool01Oo^k^ko<S8bo`000?l@413oc<c<00Gooooo0_lQ8B44ooooo`0;olc<c?lQ8B7o
0000ob4Q8Oo<c<coooooolc<c?o^k^koooooonk^k_o<c<`01?ooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^hCooooo`06oa0@4?lb<S;o0000o`000?l@413oZJVY0_ooool01_o^
k^koEEEEo`000?l0003oA4A4okZj^P?ooooo00GoIVIVo`000?l0003oA4A4olc<c03Xooooo`00S_oo
ool01Ol0003oooooooooooo<c<co410@00?ooooo00KoEEEEogMgMoooooook^k^ogMgMol@4104oooo
o`03o`000?oooooooooo00;ooooo00Ko0000ojVYZOmEEEGoV9RHoeEEEOnj^[X3ooooo`03o`000?oo
oooooooo00Cooooo00?oc<c<o`000?l@41003?ooool01_l@413o^[Zjonk^k_mgMgOo410@ooooo`Ko
00000_ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Gooooo0_lQ8B44ooooo`0;ob4Q8OnHV9Sooooo
oiRHV?lQ8B7oooooonk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL04oooool01_l0003oZJVYoooooooooooo^[Zjo`0000;ooooo00Ko
EEEEogMgMoooooook^k^ogMgMol@4102ooooo`06ofIVI_mgMgOooooooooooon7QhOo410@j?ooool0
08kooooo00Go0000ooooooooooooEEEEohN7Q`03ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool00_ooool01_lb<S;ok^k^oiRHV?mEEEGogMgMoa0@40?ooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003o
oooooooooooooooo000000;ooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@41005?ooool01Onj^[[oQhN7ofIVI_mVIVKo410@00;ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`3[ooooo`00S_ooool01Ol0003oooooomgMgOl0
003ok^k^00?ooooo1_l00004ooooo`03o`000?oooooooooo00;ooooo00Oo^[ZjodA4A?o<c<co8B4Q
ooooool@413oc<c<00;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`03ooooo`Ko
00000_ooool01Ol0003oV9RHoooooonHV9So8B4Q00_ooooo00_o<S8boiRHV?ooooooV9RHoc8b<_oo
ooook^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`00000Cooooo`06oc8b<_lQ8B7oMgMgogMgMon7QhOok^k^0_ooool6o`0000;ooooo00?o
0000ooooooooool0joooool008kooooo0ol000000ol@413oV9RHooooo`02ooooo`06oeEEEOn7QhOo
k^k^oooooon7QhOo<S8b1?ooool00ol0003oooooooooo`02ooooo`07onk^k_l0003oooooo`000?oo
ooooIVIVohN7Q`02ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02oooool01Ol0
003oEEEEo`000?l@413oc<c<00_ooooo00_oc<c<o`000?l0003o0000olc<c?ooooooc<c<onk^k_oo
ooook^k^olc<c006ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000C
ooooo`06o`000?nj^[[oooooonk^k_mgMgOo00000_ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b
<P;ooooo00KoIVIVogMgMoooooooooooohN7Qol0003Xooooo`00S_ooool01Ol0003oooooooooooo<
c<co000000?ooooo00Kok^k^oeEEEOl0003o0000odA4A?o^k^h4ooooo`03o`000?oooooooooo00;o
oooo00CoIVIVoiRHV?oooooo<S8b0_nj^[X01?l0003oooooooooool0000Cooooo`03oa0@4?l0003o
000000?o00002_ooool00omEEEGoQhN7ooooo`0=ooooo`05oa0@4?nj^[[ooooookZj^_l@41003?oo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41001oooool3o`0000;ooooo
0ol00004ooooo`06ojVYZOlQ8B7o0000o`000?lb<S;o00000_ooool01_o^k^koEEEEo`000?l0003o
A4A4onk^kP;ooooo00Kok^k^ofIVI_l0003o0000odA4A?l0003Xooooo`00S_ooool01Ol0003ooooo
ooooooo<c<co000000gooooo00?o0000ooooooooool01Oooool00omVIVKoQhN7ooooo`03ooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool02oooool00ooMgMgo410@oiRHV00=ooooo`05
o`000?nj^[[ooooookZj^_l000003?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo0_ooool0
08gooooo1?l000000ol@413oZJVYooooo`0<ooooo`;o00001_ooool00onYZJWoA4A4ooooo`02oooo
o`;o00005Oooool00ol0003oooooooooo`0<ooooo`04olc<c?m4A4Co0000oa0@40_ooooo00GoZJVY
oa0@4?l0003o410@ojVYZ@0:ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP02ooooo`Co00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo
0_ooool00?oooooo1_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo0_oo
ool00?oooooo1_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo0_ooool0
0?oooooo1Oooool2o`0000?ooooo0_l0003oooooo`Cooooo003ooooooooooooo4?ooool00?oooooo
ooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@oooo
o`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooo
oooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo
003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooo
oooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool0
0?ooooooooooool@ooooo`00\
\>"],
  ImageRangeCache->{{{0, 525.688}, {324.5, 0}} -> {-2.58312*^-7, -6.34248*^6, \
6.65005*^-9, 53093.5}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0.309017 5.42214e-08 [
[.32684 .29652 -16.5 -12.5 ]
[.32684 .29652 16.5 0 ]
[.54329 .29652 -16.5 -12.5 ]
[.54329 .29652 16.5 0 ]
[.75974 .29652 -22.5 -12.5 ]
[.75974 .29652 22.5 0 ]
[.97619 .29652 -16.5 -12.5 ]
[.97619 .29652 16.5 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 64 6 ]
[.09789 .09213 -34.5 -6.25 ]
[.09789 .09213 0 6.25 ]
[.09789 .20057 -34.5 -6.25 ]
[.09789 .20057 0 6.25 ]
[.09789 .41746 -28.5 -6.25 ]
[.09789 .41746 0 6.25 ]
[.09789 .5259 -28.5 -6.25 ]
[.09789 .5259 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -59.8125 0 ]
[.5 .63053 59.8125 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 .30902 m
.32684 .31527 L
s
gsave
.32684 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 .30902 m
.54329 .31527 L
s
gsave
.54329 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 .30902 m
.75974 .31527 L
s
gsave
.75974 .29652 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 .30902 m
.15368 .31277 L
s
.19697 .30902 m
.19697 .31277 L
s
.24026 .30902 m
.24026 .31277 L
s
.28355 .30902 m
.28355 .31277 L
s
.37013 .30902 m
.37013 .31277 L
s
.41342 .30902 m
.41342 .31277 L
s
.45671 .30902 m
.45671 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.58658 .30902 m
.58658 .31277 L
s
.62987 .30902 m
.62987 .31277 L
s
.67316 .30902 m
.67316 .31277 L
s
.71645 .30902 m
.71645 .31277 L
s
.80303 .30902 m
.80303 .31277 L
s
.84632 .30902 m
.84632 .31277 L
s
.88961 .30902 m
.88961 .31277 L
s
.9329 .30902 m
.9329 .31277 L
s
.0671 .30902 m
.0671 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09213 m
.11664 .09213 L
s
gsave
.09789 .09213 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .20057 m
.11664 .20057 L
s
gsave
.09789 .20057 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .41746 m
.11664 .41746 L
s
gsave
.09789 .41746 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .5259 m
.11664 .5259 L
s
gsave
.09789 .5259 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.11039 .11924 m
.11414 .11924 L
s
.11039 .14635 m
.11414 .14635 L
s
.11039 .17346 m
.11414 .17346 L
s
.11039 .22768 m
.11414 .22768 L
s
.11039 .2548 m
.11414 .2548 L
s
.11039 .28191 m
.11414 .28191 L
s
.11039 .33613 m
.11414 .33613 L
s
.11039 .36324 m
.11414 .36324 L
s
.11039 .39035 m
.11414 .39035 L
s
.11039 .44457 m
.11414 .44457 L
s
.11039 .47168 m
.11414 .47168 L
s
.11039 .49879 m
.11414 .49879 L
s
.11039 .06502 m
.11414 .06502 L
s
.11039 .03791 m
.11414 .03791 L
s
.11039 .0108 m
.11414 .0108 L
s
.11039 .55301 m
.11414 .55301 L
s
.11039 .58012 m
.11414 .58012 L
s
.11039 .60723 m
.11414 .60723 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -120.812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.812 moveto
(@) show
81.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.812 moveto
(D) show
93.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7.) show
129.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
135.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
147.000 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
151.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
160.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
178.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02691 .30902 L
.03029 .30902 L
.03347 .30902 L
.03652 .30902 L
.03978 .30902 L
.04128 .30902 L
.04291 .30902 L
.04379 .30902 L
.04419 .30902 L
.04462 .30902 L
.04502 .30902 L
.04522 .30902 L
.0454 .30902 L
.0455 .30902 L
.04561 .30902 L
.04571 .30902 L
.0458 .30902 L
.04586 .30902 L
.04591 .30902 L
.04601 .30902 L
.04607 .30902 L
.04612 .30902 L
.04617 .30902 L
.04623 .30902 L
.04633 .30902 L
.04644 .30902 L
.04654 .30902 L
.04663 .30902 L
.04681 .30902 L
.04699 .30902 L
.04738 .30902 L
.0476 .30902 L
.04781 .30902 L
.04852 .30902 L
.04891 .30902 L
.04928 .30902 L
.05007 .30902 L
.0508 .30902 L
.0516 .30902 L
.05246 .30902 L
.05328 .30902 L
.05417 .30902 L
.05494 .30902 L
.05579 .30902 L
.05739 .30902 L
.05908 .30902 L
.06064 .30902 L
.06231 .30902 L
.06401 .30902 L
Mistroke
.06563 .30902 L
.06722 .30902 L
.0687 .30902 L
.07184 .30902 L
.07356 .30902 L
.07518 .30902 L
.07828 .30902 L
.07989 .30902 L
.08158 .30902 L
.08463 .30902 L
.08788 .30902 L
.09101 .30902 L
.09433 .30902 L
.09753 .30902 L
.10061 .30902 L
.10217 .30902 L
.10389 .30902 L
.10468 .30902 L
.10552 .30902 L
.10591 .30902 L
.10632 .30902 L
.10669 .30902 L
.10705 .30902 L
.10724 .30902 L
.10745 .30902 L
.10754 .30902 L
.10764 .30902 L
.10772 .30902 L
.10782 .30902 L
.10787 .30902 L
.10792 .30902 L
.10802 .30902 L
.10812 .30902 L
.10818 .30902 L
.10824 .30902 L
.10833 .30902 L
.10843 .30902 L
.10854 .30902 L
.10863 .30902 L
.10882 .30902 L
.109 .30902 L
.10934 .30902 L
.10971 .30902 L
.11011 .30902 L
.11093 .30902 L
.11168 .30902 L
.11255 .30902 L
.11336 .30902 L
.11414 .30902 L
.11497 .30902 L
Mistroke
.11645 .30902 L
.11802 .30902 L
.11949 .30902 L
.12111 .30902 L
.1226 .30902 L
.12425 .30902 L
.12579 .30902 L
.12886 .30902 L
.132 .30902 L
.13534 .30902 L
.13856 .30902 L
.14165 .30902 L
.14322 .30902 L
.14494 .30902 L
.14574 .30902 L
.14659 .30902 L
.14738 .30902 L
.14812 .30902 L
.14851 .30902 L
.14871 .30902 L
.14883 .30902 L
.14893 .30902 L
.14904 .30902 L
.14915 .30902 L
.14921 .30902 L
.14927 .30902 L
.14933 .30902 L
.14939 .30902 L
.14945 .30902 L
.14951 .30902 L
.14956 .30902 L
.14962 .30902 L
.14972 .30902 L
.14982 .30902 L
.14992 .30902 L
.15001 .30902 L
.15022 .30902 L
.15041 .30902 L
.15059 .30902 L
.151 .30902 L
.15144 .30902 L
.15187 .30902 L
.15227 .30902 L
.15302 .30902 L
.15383 .30902 L
.15471 .30902 L
.15631 .30902 L
.15712 .30902 L
.158 .30902 L
.15957 .30902 L
Mistroke
.16125 .30902 L
.16285 .30902 L
.16458 .30902 L
.16778 .30902 L
.17106 .30902 L
.17422 .30902 L
.17726 .30902 L
.17894 .30902 L
.18049 .30902 L
.18125 .30902 L
.18168 .30902 L
.18189 .30902 L
.18208 .30902 L
.18227 .30902 L
.18247 .30902 L
.18256 .30902 L
.18265 .30902 L
.18273 .30902 L
.18282 .30902 L
.18292 .30902 L
.18301 .30902 L
.18306 .30902 L
.18312 .30902 L
.18322 .30902 L
.18332 .30902 L
.18342 .30902 L
.1836 .30902 L
.18379 .30902 L
.18399 .30902 L
.18435 .30902 L
.18474 .30902 L
.18516 .30902 L
.18592 .30902 L
.18663 .30902 L
.18747 .30902 L
.18827 .30902 L
.18976 .30902 L
.19137 .30902 L
.19285 .30902 L
.19601 .30901 L
.19905 .30901 L
.20229 .30901 L
.2054 .309 L
.20699 .309 L
.20782 .309 L
.20872 .309 L
.20958 .309 L
.21037 .30899 L
.21075 .30899 L
.21095 .30899 L
Mistroke
.21116 .30899 L
.21135 .30899 L
.21144 .30899 L
.21155 .30899 L
.21165 .30899 L
.21173 .30899 L
.21182 .30899 L
.21191 .30899 L
.212 .30899 L
.2121 .30899 L
.21219 .30899 L
.21228 .30899 L
.21237 .30899 L
.21247 .30899 L
.21268 .30899 L
.21289 .30899 L
.21311 .30899 L
.21351 .30899 L
.21391 .30899 L
.21428 .309 L
.21499 .309 L
.21577 .309 L
.21659 .309 L
.21808 .309 L
.21965 .30901 L
.22112 .30902 L
.22424 .30904 L
.22756 .30908 L
.23075 .30911 L
.23382 .30914 L
.23541 .30915 L
.23621 .30916 L
.23667 .30916 L
.23689 .30916 L
.23709 .30916 L
.23728 .30916 L
.23747 .30916 L
.23758 .30916 L
.23769 .30916 L
.23778 .30916 L
.23788 .30916 L
.23798 .30916 L
.23804 .30916 L
.23809 .30916 L
.23815 .30916 L
.2382 .30916 L
.23831 .30916 L
.23841 .30916 L
.23852 .30916 L
.23871 .30916 L
Mistroke
.23891 .30916 L
.23908 .30916 L
.23948 .30916 L
.23985 .30916 L
.2402 .30915 L
.24098 .30915 L
.24181 .30914 L
.24329 .30911 L
.24487 .30907 L
.24634 .30902 L
.24946 .30889 L
.25278 .30872 L
.25598 .30854 L
.25745 .30847 L
.25828 .30844 L
.25906 .30841 L
.25982 .30839 L
.26025 .30838 L
.26046 .30838 L
.26065 .30838 L
.26085 .30837 L
.26104 .30837 L
.26115 .30837 L
.26125 .30837 L
.2613 .30837 L
.26135 .30837 L
.26141 .30837 L
.26147 .30837 L
.26157 .30837 L
.26163 .30837 L
.26168 .30837 L
.26178 .30837 L
.26188 .30837 L
.26199 .30837 L
.2621 .30837 L
.26233 .30838 L
.26255 .30838 L
.26274 .30838 L
.26318 .30839 L
.26357 .3084 L
.26398 .30842 L
.2647 .30845 L
.26548 .3085 L
.26705 .30863 L
.26873 .30883 L
.27205 .30937 L
.27526 .31003 L
.27834 .31067 L
.27993 .31094 L
.28074 .31105 L
Mistroke
.28119 .3111 L
.28162 .31114 L
.28201 .31117 L
.28221 .31118 L
.28243 .3112 L
.28264 .3112 L
.28282 .31121 L
.28291 .31121 L
.28301 .31122 L
.28309 .31122 L
.28318 .31122 L
.28327 .31122 L
.28336 .31122 L
.28346 .31122 L
.28355 .31122 L
.28365 .31122 L
.28376 .31122 L
.28386 .31122 L
.28395 .31121 L
.28411 .31121 L
.28429 .3112 L
.28465 .31118 L
.28505 .31115 L
.28546 .3111 L
.2862 .311 L
.287 .31084 L
.28788 .31062 L
.28945 .31009 L
.29113 .30934 L
.29446 .30741 L
.29767 .30533 L
.29914 .30445 L
.29997 .30401 L
.30075 .30365 L
.30158 .30334 L
.30235 .30312 L
.30276 .30304 L
.30296 .30301 L
.30316 .30298 L
.30327 .30297 L
.30338 .30296 L
.30348 .30295 L
.30358 .30294 L
.30363 .30294 L
.30369 .30294 L
.30375 .30294 L
.30381 .30294 L
.30387 .30294 L
.30393 .30294 L
.30398 .30294 L
Mistroke
.30403 .30294 L
.30413 .30294 L
.30422 .30294 L
.30432 .30295 L
.30442 .30296 L
.30464 .30298 L
.30483 .30301 L
.30519 .30308 L
.30557 .30317 L
.30598 .30331 L
.30636 .30346 L
.30724 .30392 L
.30808 .3045 L
.30888 .30518 L
.31037 .30677 L
.31346 .31117 L
.31675 .31663 L
.31838 .31916 L
.31991 .32113 L
.32067 .32189 L
.32138 .32246 L
.32177 .3227 L
.32198 .32281 L
.3222 .3229 L
.32241 .32297 L
.32259 .32303 L
.32268 .32305 L
.32278 .32306 L
.32287 .32308 L
.32296 .32309 L
.32306 .32309 L
.32315 .3231 L
.32325 .3231 L
.3233 .3231 L
.32335 .32309 L
.32344 .32309 L
.32353 .32308 L
.32363 .32306 L
.32372 .32304 L
.32393 .32298 L
.32413 .32292 L
.32456 .3227 L
.32498 .32242 L
.32543 .32202 L
.32625 .32104 L
.32708 .31974 L
.32783 .31829 L
.32952 .31415 L
.33273 .30357 L
.33583 .29234 L
Mistroke
.33739 .28736 L
.33823 .28515 L
.33912 .28321 L
.33956 .28245 L
.33997 .28186 L
.34035 .28144 L
.34054 .28126 L
.34076 .28111 L
.34085 .28105 L
.34095 .281 L
.34104 .28096 L
.34114 .28093 L
.34124 .2809 L
.3413 .28089 L
.34135 .28088 L
.34145 .28087 L
.34155 .28087 L
.34165 .28088 L
.34175 .2809 L
.34185 .28093 L
.34194 .28096 L
.34211 .28104 L
.34229 .28116 L
.34268 .28152 L
.34304 .28199 L
.34346 .28268 L
.34386 .2835 L
.34456 .28532 L
.34533 .28786 L
.34691 .29481 L
.34859 .30441 L
.35193 .32734 L
.35361 .33877 L
.35515 .34786 L
.35593 .35163 L
.35666 .3545 L
.35742 .35675 L
.35782 .3576 L
.35805 .35796 L
.35825 .35823 L
.35844 .35841 L
.35854 .35849 L
.35864 .35854 L
.35874 .35858 L
.35884 .3586 L
.35894 .35861 L
.35899 .35861 L
.35905 .3586 L
.35915 .35857 L
.35923 .35853 L
Mistroke
.35934 .35846 L
.35943 .35839 L
.3596 .35821 L
.35979 .35796 L
.36021 .35717 L
.36066 .35597 L
.36104 .35467 L
.36145 .35293 L
.36227 .34863 L
.36302 .34369 L
.3647 .32934 L
.36789 .29337 L
.37097 .25768 L
.37255 .24322 L
.37335 .23772 L
.37378 .23536 L
.37424 .23336 L
.37462 .23209 L
.37484 .23154 L
.37504 .23115 L
.37514 .23101 L
.37523 .2309 L
.37531 .23082 L
.3754 .23075 L
.3755 .23071 L
.3756 .23069 L
.37569 .2307 L
.37579 .23074 L
.37584 .23077 L
.3759 .23081 L
.376 .23092 L
.37611 .23105 L
.3762 .23121 L
.37642 .23165 L
.37665 .23229 L
.37708 .23388 L
.37746 .23579 L
.37827 .24124 L
.37901 .24793 L
.38068 .26853 L
.38385 .32262 L
.3869 .37786 L
.38846 .40055 L
.38934 .41016 L
.38973 .41354 L
.39014 .41651 L
.39052 .41864 L
.39072 .41953 L
.39094 .42029 L
.39104 .42057 L
Mistroke
.39114 .42082 L
.39123 .42101 L
.39132 .42115 L
.3914 .42125 L
.39149 .42133 L
.39159 .42137 L
.39168 .42137 L
.39178 .42133 L
.39183 .42129 L
.39189 .42123 L
.39199 .42109 L
.39209 .42092 L
.3923 .42037 L
.39253 .41955 L
.39275 .41856 L
.39296 .41741 L
.39334 .41473 L
.39411 .40734 L
.39494 .39658 L
.39641 .37038 L
.39976 .28881 L
.40144 .24479 L
.40298 .20859 L
.40449 .18108 L
.40525 .17126 L
.40568 .16707 L
.40608 .16413 L
.40629 .16297 L
.40648 .16214 L
.40659 .16177 L
.40669 .16149 L
.4068 .16127 L
.40686 .16118 L
.40692 .16111 L
.40702 .16104 L
.40708 .16104 L
.40713 .16105 L
.40723 .16111 L
.40734 .16125 L
.40744 .16146 L
.40753 .16171 L
.40772 .16235 L
.4079 .1632 L
.40809 .16433 L
.40843 .16694 L
.4088 .17059 L
.40921 .17559 L
.41002 .18877 L
.41077 .20417 L
.41245 .24892 L
Mistroke
.41565 .35603 L
.41711 .40419 L
.41794 .42867 L
.41872 .44876 L
.41955 .46625 L
.42031 .47831 L
.4207 .48294 L
.42112 .48652 L
.42134 .48785 L
.42154 .48875 L
.42165 .48911 L
.42176 .48935 L
.42182 .48945 L
.42188 .48952 L
.42194 .48955 L
.42199 .48956 L
.42209 .48951 L
.42219 .48938 L
.42228 .4892 L
.42237 .48894 L
.42247 .48857 L
.42258 .48808 L
.42277 .48697 L
.42315 .48386 L
.4235 .48 L
.42391 .47416 L
.42435 .46634 L
.42516 .44837 L
.42676 .39957 L
.42845 .33449 L
.4315 .20907 L
.43307 .1556 L
.43395 .13255 L
.43434 .1243 L
.43475 .11696 L
.43513 .11156 L
.43533 .10923 L
.43555 .10716 L
.43574 .10565 L
.43583 .10512 L
.43593 .10462 L
.43601 .10425 L
.4361 .10393 L
.43619 .10368 L
.43628 .10353 L
.43634 .10347 L
.43639 .10345 L
.4365 .10348 L
.43656 .10355 L
.43661 .10364 L
Mistroke
.43667 .10378 L
.43673 .10396 L
.43685 .10439 L
.43695 .10492 L
.43716 .10623 L
.43735 .1079 L
.43754 .10979 L
.43795 .11529 L
.43832 .12163 L
.43872 .12993 L
.43944 .14864 L
.4411 .2067 L
.4444 .35816 L
.44604 .43115 L
.44684 .46172 L
.44757 .48542 L
.44833 .50513 L
.44868 .51231 L
.44905 .51857 L
.44924 .5212 L
.44944 .52365 L
.44963 .5255 L
.4498 .52684 L
.4499 .52744 L
.45001 .52798 L
.45007 .52823 L
.45012 .52841 L
.45018 .52857 L
.45023 .52869 L
.45033 .52883 L
.45042 .52886 L
.45052 .52879 L
.45058 .5287 L
.45063 .52858 L
.45073 .52827 L
.45082 .52786 L
.451 .52682 L
.4512 .52529 L
.45141 .52314 L
.45179 .51803 L
.45214 .51191 L
.45294 .49297 L
.4538 .46598 L
.45683 .32984 L
.45851 .24461 L
.46005 .17431 L
.46084 .14458 L
.46157 .12175 L
.46233 .10366 L
.46273 .09665 L
Mistroke
.46294 .09375 L
.46316 .09123 L
.46336 .08943 L
.46347 .08867 L
.46359 .08801 L
.46369 .08755 L
.46379 .08725 L
.46389 .08707 L
.46398 .08699 L
.46404 .087 L
.46409 .08704 L
.46415 .08713 L
.4642 .08725 L
.4643 .08755 L
.46441 .08802 L
.46453 .08869 L
.46465 .08958 L
.46487 .09163 L
.46527 .09679 L
.46564 .10327 L
.46649 .12371 L
.46733 .15124 L
.46813 .18291 L
.46962 .25293 L
.4727 .40743 L
.47429 .47088 L
.47509 .49439 L
.47555 .50472 L
.47598 .51226 L
.47636 .51712 L
.47657 .51912 L
.47677 .52047 L
.47688 .52101 L
.47698 .52138 L
.47707 .52161 L
.47717 .52173 L
.47722 .52175 L
.47728 .52173 L
.47734 .52167 L
.47739 .52157 L
.47749 .52131 L
.47755 .52111 L
.4776 .52089 L
.47779 .5198 L
.47797 .5184 L
.47816 .51643 L
.47836 .51386 L
.47871 .50845 L
.47909 .5009 L
.4799 .47967 L
Mistroke
.48064 .45463 L
.48231 .38328 L
.48396 .3027 L
.48549 .22975 L
.48697 .171 L
.48779 .14597 L
.48855 .12922 L
.48893 .12301 L
.48915 .12033 L
.48935 .1183 L
.48952 .11694 L
.4897 .11585 L
.4898 .11541 L
.4899 .1151 L
.48999 .11493 L
.49008 .11484 L
.49014 .11484 L
.4902 .11488 L
.49025 .11495 L
.4903 .11505 L
.4904 .11532 L
.4905 .11573 L
.49061 .11631 L
.49072 .11697 L
.49095 .11893 L
.49134 .12356 L
.49175 .13037 L
.49257 .14901 L
.49346 .1763 L
.49508 .23996 L
.49663 .30991 L
.49835 .38404 L
.49913 .41321 L
.49998 .43963 L
.50037 .44973 L
.50077 .45882 L
.50115 .46572 L
.5015 .4709 L
.5017 .47317 L
.50191 .47517 L
.5021 .47658 L
.50227 .47754 L
.50237 .47793 L
.50246 .4782 L
.50256 .47839 L
.50262 .47845 L
.50267 .47848 L
.50277 .47844 L
.50283 .47837 L
.50288 .47827 L
Mistroke
.50298 .478 L
.50309 .47761 L
.50319 .47712 L
.50328 .47658 L
.50349 .47503 L
.50386 .4711 L
.50421 .4663 L
.50456 .46001 L
.50533 .44278 L
.50615 .41922 L
.50762 .36697 L
.50921 .30397 L
.51094 .23985 L
.51175 .21482 L
.51261 .19331 L
.51334 .17973 L
.51376 .17415 L
.51415 .17038 L
.51436 .16897 L
.51455 .16803 L
.51466 .16764 L
.51476 .16739 L
.51481 .16729 L
.51487 .16722 L
.51493 .16719 L
.51498 .16718 L
.51508 .16723 L
.51517 .16736 L
.51526 .16759 L
.51537 .16793 L
.51548 .16839 L
.51558 .16893 L
.51577 .17022 L
.51614 .17361 L
.51649 .17781 L
.51726 .19089 L
.51803 .20829 L
.51876 .22791 L
.52041 .28025 L
.52189 .32943 L
.52273 .35532 L
.52352 .37678 L
.52436 .39606 L
.52512 .40945 L
.52554 .41496 L
.52594 .41889 L
.52616 .42052 L
.52636 .42168 L
.52648 .42219 L
.52658 .42258 L
Mistroke
.52669 .42288 L
.52675 .423 L
.52682 .4231 L
.52687 .42316 L
.52692 .42319 L
.52702 .42319 L
.52713 .42311 L
.52718 .42303 L
.52724 .42293 L
.52733 .4227 L
.52743 .42239 L
.52763 .42151 L
.52785 .42018 L
.52809 .41835 L
.52852 .41401 L
.52895 .40831 L
.52936 .4018 L
.53013 .38701 L
.53321 .30839 L
.53477 .26915 L
.5356 .2517 L
.53603 .24385 L
.53649 .23671 L
.53689 .23139 L
.53734 .22673 L
.53753 .22508 L
.53774 .22359 L
.53794 .22245 L
.53811 .22162 L
.53831 .22095 L
.53842 .22071 L
.53847 .22061 L
.53853 .22052 L
.53862 .22042 L
.53871 .22039 L
.53877 .22039 L
.53882 .22041 L
.53892 .2205 L
.539 .22063 L
.5391 .22082 L
.53926 .2213 L
.53944 .22202 L
.53964 .22304 L
.54004 .22577 L
.54045 .22961 L
.54119 .23873 L
.54287 .26763 L
.54592 .33051 L
.54673 .34489 L
.54749 .35639 L
Mistroke
.54791 .36171 L
.54837 .36656 L
.54879 .37007 L
.54899 .37147 L
.54917 .37257 L
.54935 .37345 L
.54954 .37423 L
.54964 .37458 L
.54974 .37486 L
.54983 .37507 L
.54993 .37525 L
.54999 .37534 L
.55004 .3754 L
.55014 .37548 L
.55024 .3755 L
.55034 .37548 L
.55039 .37545 L
.55044 .3754 L
.55054 .37527 L
.5506 .37517 L
.55066 .37506 L
.55077 .37481 L
.55097 .37417 L
.55119 .37328 L
.55158 .37113 L
.55199 .36806 L
.55245 .36385 L
.55401 .34449 L
.55568 .31848 L
.55726 .29417 L
.55809 .28301 L
.55899 .27319 L
.55943 .26926 L
.55985 .26621 L
.56023 .26403 L
.56042 .26311 L
.56063 .26228 L
.56083 .26166 L
.56102 .26122 L
.56112 .26104 L
.56122 .26091 L
.56127 .26085 L
.56133 .2608 L
.56143 .26074 L
.56153 .26073 L
.56162 .26074 L
.56172 .26079 L
.56181 .26088 L
.5619 .26099 L
.56198 .26112 L
Mistroke
.56217 .2615 L
.56237 .26205 L
.56255 .26267 L
.56295 .26447 L
.56368 .26905 L
.56453 .27624 L
.56534 .28443 L
.56842 .31936 L
.56924 .32733 L
.57001 .33356 L
.57082 .3385 L
.57124 .34041 L
.57147 .3412 L
.5717 .34189 L
.57192 .34239 L
.57212 .34272 L
.57222 .34284 L
.57232 .34294 L
.57242 .343 L
.57251 .34304 L
.57262 .34305 L
.57272 .34303 L
.57277 .343 L
.57283 .34298 L
.57294 .34288 L
.57305 .34276 L
.57318 .34259 L
.5734 .34217 L
.57359 .3417 L
.5738 .34108 L
.57423 .33947 L
.57501 .33556 L
.57656 .32472 L
.57823 .31099 L
.57981 .29896 L
.58064 .29378 L
.5811 .29142 L
.58153 .28954 L
.58195 .28808 L
.58217 .28745 L
.5824 .28689 L
.58259 .2865 L
.5828 .28616 L
.5829 .28605 L
.583 .28594 L
.58309 .28586 L
.58318 .2858 L
.58328 .28575 L
.58338 .28572 L
.58344 .28572 L
Mistroke
.58349 .28571 L
.58359 .28573 L
.58369 .28576 L
.58378 .28581 L
.58388 .28588 L
.58398 .28597 L
.58416 .28619 L
.58433 .28644 L
.58471 .28721 L
.58512 .28828 L
.58555 .28974 L
.58635 .29306 L
.58784 .30087 L
.5894 .30971 L
.59022 .31406 L
.59111 .31812 L
.59196 .32117 L
.59234 .32222 L
.59274 .32314 L
.59293 .32349 L
.59313 .32381 L
.5933 .32404 L
.59349 .32424 L
.5936 .32433 L
.5937 .3244 L
.59379 .32446 L
.5939 .3245 L
.59399 .32453 L
.59407 .32454 L
.59417 .32455 L
.59427 .32454 L
.59432 .32453 L
.59438 .32451 L
.59447 .32447 L
.59458 .32442 L
.59469 .32435 L
.5949 .32417 L
.59508 .32396 L
.59552 .32331 L
.59597 .3224 L
.59674 .32038 L
.59758 .31764 L
.59929 .31125 L
.60084 .30564 L
.60161 .30329 L
.60245 .30125 L
.60283 .30051 L
.60324 .29988 L
.60358 .29947 L
.60378 .29929 L
Mistroke
.60397 .29915 L
.60407 .29909 L
.60417 .29904 L
.60426 .299 L
.60436 .29897 L
.60443 .29895 L
.60448 .29894 L
.60454 .29894 L
.60459 .29893 L
.60469 .29893 L
.60475 .29893 L
.6048 .29894 L
.6049 .29896 L
.605 .29899 L
.60509 .29902 L
.60518 .29906 L
.60539 .29918 L
.60559 .29933 L
.60593 .29967 L
.60631 .30014 L
.60708 .3014 L
.60863 .30484 L
.6103 .30901 L
.61188 .31244 L
.61231 .3132 L
.61278 .31389 L
.61321 .31443 L
.61361 .31482 L
.61402 .31512 L
.61423 .31524 L
.61435 .31529 L
.61446 .31533 L
.61457 .31536 L
.61466 .31538 L
.61476 .3154 L
.61485 .31541 L
.61495 .31541 L
.61505 .31541 L
.61511 .3154 L
.61516 .3154 L
.61522 .31539 L
.61527 .31538 L
.61536 .31536 L
.61546 .31534 L
.61565 .31527 L
.61583 .31519 L
.616 .3151 L
.61638 .31483 L
.61679 .31448 L
.61761 .31354 L
Mistroke
.6185 .31229 L
.62011 .30973 L
.62167 .30743 L
.62256 .30639 L
.62296 .30601 L
.62339 .30567 L
.62377 .30543 L
.62397 .30533 L
.62418 .30524 L
.62438 .30517 L
.62456 .30512 L
.62465 .30511 L
.62474 .30509 L
.62483 .30508 L
.62491 .30507 L
.625 .30506 L
.6251 .30506 L
.6252 .30506 L
.62529 .30506 L
.62539 .30507 L
.62545 .30508 L
.6255 .30508 L
.6257 .30512 L
.6259 .30517 L
.62611 .30524 L
.62654 .30543 L
.62694 .30565 L
.62735 .30593 L
.6281 .30653 L
.62977 .30814 L
.63137 .30967 L
.63207 .31023 L
.63282 .31074 L
.63325 .31096 L
.63363 .31113 L
.634 .31125 L
.63421 .31131 L
.6344 .31135 L
.6346 .31138 L
.63471 .31139 L
.63481 .3114 L
.63491 .31141 L
.635 .31141 L
.63509 .31141 L
.6352 .31141 L
.63526 .31141 L
.63531 .31141 L
.63537 .31141 L
.63544 .3114 L
.63554 .31139 L
Mistroke
.63566 .31138 L
.63588 .31135 L
.63608 .31131 L
.63648 .31121 L
.63692 .31106 L
.63771 .3107 L
.6392 .30986 L
.64076 .30892 L
.64159 .30848 L
.64248 .30809 L
.64289 .30794 L
.64333 .30781 L
.6437 .30773 L
.64391 .30769 L
.6441 .30766 L
.6443 .30763 L
.64449 .30761 L
.64459 .30761 L
.64468 .3076 L
.64479 .3076 L
.64484 .3076 L
.6449 .3076 L
.64499 .3076 L
.64508 .3076 L
.64518 .3076 L
.64528 .3076 L
.64536 .30761 L
.64545 .30761 L
.64563 .30763 L
.64584 .30765 L
.64604 .30767 L
.64648 .30775 L
.64728 .30794 L
.64878 .30843 L
.65042 .30903 L
.65122 .30929 L
.65195 .30949 L
.65232 .30958 L
.65271 .30966 L
.65305 .30972 L
.65343 .30977 L
.65383 .30981 L
.65404 .30982 L
.65415 .30983 L
.65425 .30983 L
.65434 .30984 L
.65444 .30984 L
.65453 .30984 L
.65461 .30984 L
.65471 .30984 L
Mistroke
.6548 .30984 L
.65491 .30984 L
.65501 .30984 L
.6551 .30984 L
.6552 .30983 L
.65538 .30982 L
.65559 .30981 L
.65579 .30979 L
.65621 .30975 L
.65662 .30969 L
.6581 .30943 L
.65956 .30912 L
.66039 .30895 L
.66117 .30881 L
.66194 .3087 L
.66233 .30865 L
.66276 .30861 L
.66319 .30858 L
.66342 .30857 L
.66364 .30856 L
.66375 .30855 L
.66384 .30855 L
.66393 .30855 L
.66403 .30855 L
.66414 .30855 L
.66419 .30855 L
.66425 .30855 L
.66435 .30855 L
.66445 .30855 L
.66455 .30855 L
.6646 .30855 L
.66465 .30855 L
.66485 .30855 L
.66507 .30856 L
.66528 .30857 L
.66566 .30859 L
.66607 .30862 L
.66756 .30878 L
.66913 .30897 L
.66997 .30906 L
.67086 .30915 L
.6713 .30919 L
.67172 .30922 L
.67212 .30924 L
.6725 .30926 L
.67285 .30927 L
.67303 .30927 L
.67314 .30927 L
.67323 .30928 L
.67333 .30928 L
Mistroke
.67343 .30928 L
.67353 .30928 L
.67359 .30928 L
.67364 .30928 L
.67374 .30928 L
.67383 .30928 L
.67393 .30928 L
.67403 .30928 L
.67412 .30928 L
.67422 .30928 L
.6744 .30927 L
.67462 .30927 L
.67481 .30926 L
.67524 .30925 L
.67564 .30923 L
.67712 .30914 L
.67858 .30904 L
.67941 .30899 L
.68019 .30894 L
.68095 .30891 L
.68138 .3089 L
.68178 .30889 L
.68217 .30888 L
.68239 .30888 L
.68249 .30887 L
.6826 .30887 L
.68271 .30887 L
.68276 .30887 L
.68282 .30887 L
.68292 .30887 L
.68302 .30887 L
.68307 .30887 L
.68313 .30887 L
.68323 .30887 L
.68329 .30887 L
.68335 .30887 L
.68346 .30887 L
.68367 .30888 L
.68387 .30888 L
.68423 .30888 L
.68463 .30889 L
.68505 .3089 L
.68653 .30895 L
.6881 .30901 L
.68893 .30904 L
.68982 .30907 L
.69026 .30908 L
.69068 .30908 L
.69105 .30909 L
.69125 .30909 L
Mistroke
.69146 .30909 L
.69166 .30909 L
.69175 .30909 L
.69185 .30909 L
.69195 .30909 L
.69204 .30909 L
.69214 .3091 L
.6922 .3091 L
.69225 .3091 L
.69235 .3091 L
.69244 .30909 L
.69252 .30909 L
.69261 .30909 L
.69281 .30909 L
.69299 .30909 L
.69337 .30909 L
.69377 .30908 L
.6945 .30907 L
.69615 .30904 L
.69774 .30901 L
.69858 .309 L
.69904 .30899 L
.69947 .30898 L
.69989 .30898 L
.7001 .30898 L
.70034 .30898 L
.70053 .30898 L
.70064 .30898 L
.70075 .30898 L
.70085 .30898 L
.70094 .30898 L
.70104 .30898 L
.70112 .30898 L
.70121 .30898 L
.70131 .30898 L
.70141 .30898 L
.70151 .30898 L
.7016 .30898 L
.70168 .30898 L
.70186 .30898 L
.70205 .30898 L
.70225 .30898 L
.70266 .30898 L
.70349 .30899 L
.70424 .30899 L
.70592 .30901 L
.70746 .30903 L
.70789 .30903 L
.70833 .30903 L
.70875 .30904 L
Mistroke
.70913 .30904 L
.70932 .30904 L
.70952 .30904 L
.70972 .30904 L
.7098 .30904 L
.70989 .30904 L
.70999 .30904 L
.71008 .30904 L
.71013 .30904 L
.71019 .30904 L
.71029 .30904 L
.71039 .30904 L
.71049 .30904 L
.71059 .30904 L
.71071 .30904 L
.7109 .30904 L
.7111 .30904 L
.71148 .30904 L
.71218 .30903 L
.71377 .30903 L
.71546 .30902 L
.71622 .30901 L
.71663 .30901 L
.71703 .30901 L
.7174 .30901 L
.7178 .30901 L
.71798 .30901 L
.71816 .30901 L
.71832 .30901 L
.7185 .30901 L
.7186 .30901 L
.71871 .30901 L
.71877 .30901 L
.71882 .30901 L
.71888 .30901 L
.71893 .30901 L
.71903 .30901 L
.71913 .30901 L
.71923 .30901 L
.71933 .30901 L
.71943 .30901 L
.71955 .30901 L
.71975 .30901 L
.72 .30901 L
.72022 .30901 L
.72101 .30901 L
.72184 .30901 L
.72344 .30902 L
.7249 .30902 L
.72571 .30902 L
Mistroke
.72608 .30902 L
.72648 .30902 L
.72668 .30902 L
.7269 .30902 L
.7271 .30902 L
.72728 .30902 L
.7274 .30902 L
.7275 .30902 L
.72761 .30902 L
.72768 .30902 L
.72774 .30902 L
.72779 .30902 L
.72784 .30902 L
.72794 .30902 L
.72805 .30902 L
.7281 .30902 L
.72816 .30902 L
.72826 .30902 L
.72836 .30902 L
.72854 .30902 L
.72873 .30902 L
.72894 .30902 L
.72967 .30902 L
.73054 .30902 L
.73133 .30902 L
.73297 .30902 L
.73376 .30902 L
.73449 .30902 L
.73485 .30901 L
.73524 .30901 L
.73542 .30901 L
.73561 .30901 L
.73579 .30901 L
.73596 .30901 L
.73605 .30901 L
.73616 .30901 L
.73627 .30901 L
.73633 .30901 L
.73638 .30901 L
.73648 .30901 L
.73657 .30901 L
.73662 .30901 L
.73668 .30901 L
.73678 .30901 L
.73687 .30901 L
.73697 .30901 L
.73717 .30901 L
.73736 .30901 L
.73753 .30901 L
.73832 .30901 L
Mistroke
.73915 .30902 L
.74063 .30902 L
.74146 .30902 L
.74224 .30902 L
.74294 .30902 L
.7433 .30902 L
.74369 .30902 L
.74409 .30902 L
.74431 .30902 L
.74441 .30902 L
.74451 .30902 L
.7446 .30902 L
.7447 .30902 L
.74479 .30902 L
.74488 .30902 L
.74497 .30902 L
.74506 .30902 L
.74517 .30902 L
.74527 .30902 L
.74536 .30902 L
.74547 .30902 L
.74558 .30902 L
.74569 .30902 L
.74607 .30902 L
.7463 .30902 L
.7465 .30902 L
.74695 .30902 L
.74861 .30902 L
.75015 .30902 L
.75092 .30902 L
.75164 .30902 L
.75201 .30902 L
.7524 .30902 L
.75261 .30902 L
.75283 .30902 L
.75302 .30902 L
.75313 .30902 L
.75323 .30902 L
.75333 .30902 L
.75338 .30902 L
.75344 .30902 L
.75354 .30902 L
.75364 .30902 L
.75369 .30902 L
.75375 .30902 L
.75385 .30902 L
.75396 .30902 L
.75408 .30902 L
.75428 .30902 L
.75449 .30902 L
Mistroke
.75487 .30902 L
.75558 .30902 L
.75637 .30902 L
.75805 .30902 L
.75879 .30902 L
.75959 .30902 L
.75997 .30902 L
.76037 .30902 L
.76076 .30902 L
.7611 .30902 L
.76131 .30902 L
.76149 .30902 L
.76159 .30902 L
.76165 .30902 L
.7617 .30902 L
.76176 .30902 L
.76181 .30902 L
.76192 .30902 L
.76202 .30902 L
.76211 .30902 L
.76221 .30902 L
.76232 .30902 L
.76251 .30902 L
.76269 .30902 L
.76309 .30902 L
.7635 .30902 L
.76424 .30902 L
.76591 .30902 L
.76673 .30902 L
.76751 .30902 L
.7682 .30902 L
.7686 .30902 L
.76896 .30902 L
.76932 .30902 L
.76953 .30902 L
.76972 .30902 L
.76982 .30902 L
.76992 .30902 L
.77001 .30902 L
.77011 .30902 L
.77021 .30902 L
.77027 .30902 L
.77033 .30902 L
.77043 .30902 L
.77053 .30902 L
.77062 .30902 L
.77073 .30902 L
.77095 .30902 L
.77133 .30902 L
.77178 .30902 L
Mistroke
.77221 .30902 L
.7737 .30902 L
.77532 .30902 L
.77575 .30902 L
.77621 .30902 L
.7766 .30902 L
.77702 .30902 L
.77725 .30902 L
.77746 .30902 L
.77766 .30902 L
.77776 .30902 L
.77787 .30902 L
.77797 .30902 L
.77806 .30902 L
.77815 .30902 L
.77824 .30902 L
.77834 .30902 L
.77843 .30902 L
.77853 .30902 L
.77858 .30902 L
.77864 .30902 L
.77874 .30902 L
.77884 .30902 L
.77905 .30902 L
.77925 .30902 L
.77945 .30902 L
.78019 .30902 L
.78187 .30902 L
.78347 .30902 L
.78391 .30902 L
.78437 .30902 L
.78478 .30902 L
.78521 .30902 L
.78542 .30902 L
.78562 .30902 L
.7858 .30902 L
.78589 .30902 L
.786 .30902 L
.78609 .30902 L
.78618 .30902 L
.78629 .30902 L
.78638 .30902 L
.78647 .30902 L
.78657 .30902 L
.78665 .30902 L
.78674 .30902 L
.78679 .30902 L
.78685 .30902 L
.78696 .30902 L
.78716 .30902 L
Mistroke
.78739 .30902 L
.78761 .30902 L
.78842 .30902 L
.79005 .30902 L
.79085 .30902 L
.79158 .30902 L
.79228 .30902 L
.79265 .30902 L
.79305 .30902 L
.79327 .30902 L
.79347 .30902 L
.79367 .30902 L
.79385 .30902 L
.79404 .30902 L
.79414 .30902 L
.79425 .30902 L
.79434 .30902 L
.79443 .30902 L
.79452 .30902 L
.79462 .30902 L
.79472 .30902 L
.79478 .30902 L
.79483 .30902 L
.79493 .30902 L
.79505 .30902 L
.79525 .30902 L
.79544 .30902 L
.79587 .30902 L
.79633 .30902 L
.79794 .30902 L
.79877 .30902 L
.79955 .30902 L
.80031 .30902 L
.80064 .30902 L
.80101 .30902 L
.80137 .30902 L
.80157 .30902 L
.80176 .30902 L
.80187 .30902 L
.80197 .30902 L
.80206 .30902 L
.80216 .30902 L
.80226 .30902 L
.80236 .30902 L
.80247 .30902 L
.80253 .30902 L
.80258 .30902 L
.80268 .30902 L
.80274 .30902 L
.80279 .30902 L
Mistroke
.80289 .30902 L
.803 .30902 L
.80321 .30902 L
.80339 .30902 L
.80384 .30902 L
.80426 .30902 L
.80573 .30902 L
.80657 .30902 L
.80735 .30902 L
.80811 .30902 L
.80851 .30902 L
.80894 .30902 L
.80917 .30902 L
.80939 .30902 L
.8096 .30902 L
.80971 .30902 L
.80982 .30902 L
.80993 .30902 L
.81004 .30902 L
.81014 .30902 L
.81024 .30902 L
.81034 .30902 L
.81043 .30902 L
.81052 .30902 L
.81063 .30902 L
.81073 .30902 L
.81083 .30902 L
.81105 .30902 L
.81125 .30902 L
.81144 .30902 L
.81233 .30902 L
.81395 .30902 L
.81543 .30902 L
.81584 .30902 L
.81627 .30902 L
.81665 .30902 L
.81705 .30902 L
.81728 .30902 L
.81749 .30902 L
.81769 .30902 L
.81779 .30902 L
.81784 .30902 L
.8179 .30902 L
.818 .30902 L
.81809 .30902 L
.81818 .30902 L
.81824 .30902 L
.81829 .30902 L
.81839 .30902 L
.81847 .30902 L
Mistroke
.81857 .30902 L
.81866 .30902 L
.81887 .30902 L
.81909 .30902 L
.81948 .30902 L
.82036 .30902 L
.82195 .30902 L
.82265 .30902 L
.82341 .30902 L
.82383 .30902 L
.82421 .30902 L
.82458 .30902 L
.82498 .30902 L
.82518 .30902 L
.82528 .30902 L
.82539 .30902 L
.82549 .30902 L
.82559 .30902 L
.82569 .30902 L
.82578 .30902 L
.82583 .30902 L
.82589 .30902 L
.82595 .30902 L
.826 .30902 L
.8261 .30902 L
.8262 .30902 L
.82631 .30902 L
.82642 .30902 L
.82666 .30902 L
.82706 .30902 L
.82749 .30902 L
.82829 .30902 L
.82978 .30902 L
.83059 .30902 L
.83136 .30902 L
.83178 .30902 L
.83216 .30902 L
.83259 .30902 L
.83281 .30902 L
.83293 .30902 L
.83305 .30902 L
.83316 .30902 L
.83325 .30902 L
.83335 .30902 L
.83345 .30902 L
.83354 .30902 L
.83362 .30902 L
.83371 .30902 L
.83381 .30902 L
.83392 .30902 L
Mistroke
.83403 .30902 L
.83424 .30902 L
.83444 .30902 L
.83463 .30902 L
.83534 .30902 L
.8361 .30902 L
.83771 .30902 L
.83855 .30902 L
.83901 .30902 L
.83944 .30902 L
.83983 .30902 L
.84003 .30902 L
.84024 .30902 L
.84037 .30902 L
.84048 .30902 L
.84059 .30902 L
.8407 .30902 L
.84081 .30902 L
.8409 .30902 L
.84101 .30902 L
.84107 .30902 L
.84112 .30902 L
.84121 .30902 L
.84131 .30902 L
.8414 .30902 L
.84148 .30902 L
.84168 .30902 L
.84187 .30902 L
.84225 .30902 L
.84266 .30902 L
.84423 .30902 L
.84506 .30902 L
.84595 .30902 L
.84639 .30902 L
.8468 .30902 L
.84721 .30902 L
.8474 .30902 L
.84758 .30902 L
.84775 .30902 L
.84794 .30902 L
.84804 .30902 L
.84813 .30902 L
.84822 .30902 L
.84832 .30902 L
.84841 .30902 L
.8485 .30902 L
.84855 .30902 L
.84861 .30902 L
.8487 .30902 L
.84881 .30902 L
Mistroke
.8489 .30902 L
.849 .30902 L
.84911 .30902 L
.84931 .30902 L
.84951 .30902 L
.84987 .30902 L
.85068 .30902 L
.85215 .30902 L
.85292 .30902 L
.85374 .30902 L
.85414 .30902 L
.85451 .30902 L
.85485 .30902 L
.85521 .30902 L
.8554 .30902 L
.85551 .30902 L
.85561 .30902 L
.8557 .30902 L
.8558 .30902 L
.85589 .30902 L
.85598 .30902 L
.85608 .30902 L
.85617 .30902 L
.85627 .30902 L
.85633 .30902 L
.85638 .30902 L
.85648 .30902 L
.85659 .30902 L
.85681 .30902 L
.85703 .30902 L
.85724 .30902 L
.85769 .30902 L
.8585 .30902 L
.86017 .30902 L
.86091 .30902 L
.86129 .30902 L
.86171 .30902 L
.86212 .30902 L
.86249 .30902 L
.86266 .30902 L
.86286 .30902 L
.86295 .30902 L
.86304 .30902 L
.86312 .30902 L
.86321 .30902 L
.86326 .30902 L
.86332 .30902 L
.86342 .30902 L
.86347 .30902 L
.86353 .30902 L
Mistroke
.86359 .30902 L
.86364 .30902 L
.86374 .30902 L
.8638 .30902 L
.86385 .30902 L
.86404 .30902 L
.86422 .30902 L
.86441 .30902 L
.8648 .30902 L
.86561 .30902 L
.86635 .30902 L
.86722 .30902 L
.86803 .30902 L
.86876 .30902 L
.86918 .30902 L
.86955 .30902 L
.86975 .30902 L
.86996 .30902 L
.87007 .30902 L
.87019 .30902 L
.8703 .30902 L
.87041 .30902 L
.87051 .30902 L
.87061 .30902 L
.87071 .30902 L
.87077 .30902 L
.87082 .30902 L
.87091 .30902 L
.87101 .30902 L
.87112 .30902 L
.87121 .30902 L
.87141 .30902 L
.87159 .30902 L
.872 .30902 L
.8724 .30902 L
.87283 .30902 L
.87431 .30902 L
.87513 .30902 L
.87557 .30902 L
.87603 .30902 L
.87643 .30902 L
.87664 .30902 L
.87687 .30902 L
.87708 .30902 L
.87727 .30902 L
.87746 .30902 L
.87764 .30902 L
.87774 .30902 L
.87779 .30902 L
.87785 .30902 L
Mistroke
.87795 .30902 L
.87805 .30902 L
.87814 .30902 L
.87822 .30902 L
.87831 .30902 L
.87841 .30902 L
.87852 .30902 L
.87863 .30902 L
.87884 .30902 L
.87923 .30902 L
.8796 .30902 L
.88 .30902 L
.88071 .30902 L
.88229 .30902 L
.88298 .30902 L
.88337 .30902 L
.88374 .30902 L
.88411 .30902 L
.88429 .30902 L
.8845 .30902 L
.88461 .30902 L
.88471 .30902 L
.88481 .30902 L
.88491 .30902 L
.88501 .30902 L
.8851 .30902 L
.88519 .30902 L
.88529 .30902 L
.88535 .30902 L
.8854 .30902 L
.88551 .30902 L
.88557 .30902 L
.88563 .30902 L
.88574 .30902 L
.88595 .30902 L
.88617 .30902 L
.88658 .30902 L
.88697 .30902 L
.88861 .30902 L
.88941 .30902 L
.89014 .30902 L
.8905 .30902 L
.8909 .30902 L
.89127 .30902 L
.89162 .30902 L
.8918 .30902 L
.89198 .30902 L
.89208 .30902 L
.89217 .30902 L
.89222 .30902 L
Mistroke
.89228 .30902 L
.89238 .30902 L
.89244 .30902 L
.89249 .30902 L
.89259 .30902 L
.89269 .30902 L
.89275 .30902 L
.8928 .30902 L
.89299 .30902 L
.89309 .30902 L
.89319 .30902 L
.89361 .30902 L
.89401 .30902 L
.89476 .30902 L
.89644 .30902 L
.89721 .30902 L
.89764 .30902 L
.89803 .30902 L
.89837 .30902 L
.89874 .30902 L
.89893 .30902 L
.89904 .30902 L
.89914 .30902 L
.89923 .30902 L
.89932 .30902 L
.89941 .30902 L
.89951 .30902 L
.89961 .30902 L
.8997 .30902 L
.89979 .30902 L
.8999 .30902 L
.90001 .30902 L
.90012 .30902 L
.90031 .30902 L
.90067 .30902 L
.90105 .30902 L
.90272 .30902 L
.9036 .30902 L
.90443 .30902 L
.90479 .30902 L
.90518 .30902 L
.90538 .30902 L
.9056 .30902 L
.90578 .30902 L
.90598 .30902 L
.90609 .30902 L
.90619 .30902 L
.90629 .30902 L
.90639 .30902 L
.90649 .30902 L
Mistroke
.90657 .30902 L
.90667 .30902 L
.90677 .30902 L
.90687 .30902 L
.90693 .30902 L
.90698 .30902 L
.90721 .30902 L
.9074 .30902 L
.90761 .30902 L
.90841 .30902 L
.90913 .30902 L
.90994 .30902 L
.9108 .30902 L
.91153 .30902 L
.91195 .30902 L
.91234 .30902 L
.91253 .30902 L
.91274 .30902 L
.91294 .30902 L
.91303 .30902 L
.91312 .30902 L
.9132 .30902 L
.9133 .30902 L
.91338 .30902 L
.91346 .30902 L
.91355 .30902 L
.91364 .30902 L
.91374 .30902 L
.91383 .30902 L
.91393 .30902 L
.91398 .30902 L
.91404 .30902 L
.91423 .30902 L
.91441 .30902 L
.9146 .30902 L
.91543 .30902 L
.91701 .30902 L
.91771 .30902 L
.91847 .30902 L
.91888 .30902 L
.91926 .30902 L
.91963 .30902 L
.91984 .30902 L
.92002 .30902 L
.92013 .30902 L
.92024 .30902 L
.92033 .30902 L
.92044 .30902 L
.9205 .30902 L
.92055 .30902 L
Mistroke
.92061 .30902 L
.92067 .30902 L
.92077 .30902 L
.92083 .30902 L
.92089 .30902 L
.92107 .30902 L
.92118 .30902 L
.92128 .30902 L
.9217 .30902 L
.92208 .30902 L
.92249 .30902 L
.92332 .30902 L
.9248 .30902 L
.92523 .30902 L
.92563 .30902 L
.92599 .30902 L
.92638 .30902 L
.92658 .30902 L
.9268 .30902 L
.92689 .30902 L
.927 .30902 L
.92709 .30902 L
.92718 .30902 L
.92724 .30902 L
.9273 .30902 L
.92736 .30902 L
.92742 .30902 L
.92747 .30902 L
.92753 .30902 L
.92759 .30902 L
.92764 .30902 L
.92774 .30902 L
.92779 .30902 L
.92784 .30902 L
.92806 .30902 L
.92827 .30902 L
.92846 .30902 L
.9289 .30902 L
.9297 .30902 L
.93119 .30902 L
.93191 .30902 L
.93229 .30902 L
.93269 .30902 L
.9329 .30902 L
.93313 .30902 L
.93335 .30902 L
.93354 .30902 L
.93374 .30902 L
.93385 .30902 L
.93396 .30902 L
Mistroke
.93405 .30902 L
.93414 .30902 L
.93424 .30902 L
.93434 .30902 L
.93444 .30902 L
.93449 .30902 L
.93455 .30902 L
.93464 .30902 L
.93474 .30902 L
.93491 .30902 L
.9351 .30902 L
.93552 .30902 L
.93592 .30902 L
.93739 .30902 L
.93817 .30902 L
.939 .30902 L
.93935 .30902 L
.93971 .30902 L
.93992 .30902 L
.94012 .30902 L
.94031 .30902 L
.94049 .30902 L
.94067 .30902 L
.94077 .30902 L
.94088 .30902 L
.94093 .30902 L
.94099 .30902 L
.94109 .30902 L
.94119 .30902 L
.94129 .30902 L
.94139 .30902 L
.94148 .30902 L
.94165 .30902 L
.94183 .30902 L
.94203 .30902 L
.94245 .30902 L
.9429 .30902 L
.9437 .30902 L
.94452 .30902 L
.94529 .30902 L
.94599 .30902 L
.94638 .30902 L
.94674 .30902 L
.94692 .30902 L
.94711 .30902 L
.94721 .30902 L
.94731 .30902 L
.94741 .30902 L
.9475 .30902 L
.9476 .30902 L
Mistroke
.94769 .30902 L
.94775 .30902 L
.9478 .30902 L
.9479 .30902 L
.948 .30902 L
.9481 .30902 L
.9482 .30902 L
.94831 .30902 L
.94851 .30902 L
.94873 .30902 L
.94911 .30902 L
.94999 .30902 L
.95158 .30902 L
.95201 .30902 L
.95247 .30902 L
.95291 .30902 L
.95331 .30902 L
.9535 .30902 L
.95372 .30902 L
.95394 .30902 L
.95406 .30902 L
.95417 .30902 L
.95427 .30902 L
.95437 .30902 L
.95446 .30902 L
.95456 .30902 L
.95467 .30902 L
.95472 .30902 L
.95478 .30902 L
.95488 .30902 L
.95498 .30902 L
.95518 .30902 L
.95536 .30902 L
.95571 .30902 L
.9565 .30902 L
.95811 .30902 L
.95881 .30902 L
.95956 .30902 L
.95999 .30902 L
.96017 .30902 L
.96038 .30902 L
.96057 .30902 L
.96075 .30902 L
.96085 .30902 L
.96094 .30902 L
.96104 .30902 L
.96114 .30902 L
.96124 .30902 L
.96129 .30902 L
.96134 .30902 L
Mistroke
.96145 .30902 L
.96151 .30902 L
.96156 .30902 L
.96175 .30902 L
.96195 .30902 L
.96237 .30902 L
.96282 .30902 L
.96453 .30902 L
.96533 .30902 L
.96608 .30902 L
.96645 .30902 L
.96685 .30902 L
.96706 .30902 L
.96725 .30902 L
.96736 .30902 L
.96746 .30902 L
.96752 .30902 L
.96758 .30902 L
.96764 .30902 L
.96769 .30902 L
.96779 .30902 L
.96789 .30902 L
.96799 .30902 L
.96808 .30902 L
.96816 .30902 L
.96825 .30902 L
.96843 .30902 L
.96862 .30902 L
.96883 .30902 L
.96921 .30902 L
.9708 .30902 L
.97164 .30902 L
.9721 .30902 L
.97253 .30902 L
.97295 .30902 L
.97333 .30902 L
.97353 .30902 L
.97375 .30902 L
.97385 .30902 L
.97396 .30902 L
.97403 .30902 L
.97408 .30902 L
.97414 .30902 L
.9742 .30902 L
.97429 .30902 L
.9744 .30902 L
.97449 .30902 L
.97458 .30902 L
.97468 .30902 L
.97478 .30902 L
Mistroke
.97489 .30902 L
.97499 .30902 L
.97535 .30902 L
.97574 .30902 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{421.375, 260.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008>0001AB000`400?l00000o`00003ooooooooo
oooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo
003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooo
oooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool0
0?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooooooo
ool@ooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooo
ooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo0ol0003o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0
003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo
00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`
ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLoooo
o`00<?ooool3o`000?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?oo
ool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0
033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomco
oooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooo
oooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool3o`000?oooooo
g?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0013ooooo0_o^k^h3ooooo`;ok^k^6Oooool00ol0003oooooooooo`3o
ooooomcooooo000;ooooo`;o000000[o410@ooooooooooook^k^oeEEEOo^k^koooooonk^k_mEEEGo
k^k^0oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h:ooooo`03o`000?oo
oooooooo0?oooooog?ooool000cooooo00?o0000ooooooooool00_ooool01Oo^k^koEEEEomgMgOmE
EEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00[ooooo
00?o0000ooooooooool0oooooooLooooo`0000?oooooo`000?l000001?l00002ooooo`Go00001?oo
ool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooo
oa0@400:ooooo`03o`000?oooooooooo09Kooooo0_l0003oooooodCooooo0009ooooo`04odA4A?oM
gMgoooooo`0000Cooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`00000:ooooo`03o`000?oooooooooo09Kooooo0_l0003ooooo
odCooooo0009ooooo`04omgMgOmEEEGoooooo`0000?ooooo00Ook^k^oeEEEOo^k^koooooonk^k_mE
EEGok^k^00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000[ooooo
1?l0002Eooooo`;o0000oooooom4ooooo`002_ooool00omgMgOoc<c<o`000003ooooo`;ok^k^0ooo
ool2onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00[ooooo
00?o0000ooooooooool0U_ooool2o`000?ooooooA?ooool000[ooooo00?ok^k^odA4A?l000003ooo
ool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool2o`0000Gooooo
00?o0000ooooooooool0U_ooool2o`000?ooooooA?ooool000_ooooo00?oMgMgo`000?ooool03?oo
ool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_ooool01?l0003ooooo
ooooool00004ooooo`03o`000?oooooooooo09Kooooo0_l0003oooooodCooooo000Xooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool0U_ooool2o`000?ooooooA?ooool002Sooooo
0ol00005ooooo`03o`000?oooooooooo08[ooooo0_l0000:ooooo`;o0000oooooom4ooooo`00:Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo08[ooooo0_l0000:ooooo`;o0000oooo
oom4ooooo`00:_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo08[ooooo0_l0000:
ooooo`;o0000oooooom4ooooo`00<?ooool00ol0003oooooooooo`2:ooooo`;o00002_ooool2o`00
0?ooooooA?ooool0033ooooo00?o0000ooooooooool0R_ooool2o`0000[ooooo0_l0003oooooodCo
oooo000`ooooo`03o`000?oooooooooo08[ooooo0_l0000:ooooo`03o`000?oooooo000000Wooooo
00?o0000ooooooooool0oooooolgooooo`00<?ooool00ol0003oooooooooo`2:ooooo`;o00002_oo
ool00ol0003oooooo`000009ooooo`03o`000?oooooooooo0?oooooo=oooool0033ooooo0ol0002:
ooooo`;o00002_ooool00ol0003oooooo`000009ooooo`03o`000?oooooooooo0?oooooo=oooool0
033ooooo00?o0000ooooooooool0R_ooool2o`0000[ooooo00?o0000ooooool000002Oooool00ol0
003oooooooooo`3oooooocOooooo000`ooooo`03o`000?oooooooooo08[ooooo0_l0000:ooooo`03
o`000?oooooo000000Sooooo0_l0003oooooocWooooo000`ooooo`03o`000?oooooooooo08[ooooo
0_l0000:ooooo`03o`000?oooooo000000Sooooo0_l0003oooooocWooooo000`ooooo`03o`000?oo
oooooooo08[ooooo00?o0000ooooool000002Oooool00ol0003oooooo`000008ooooo`03o`000?oo
oooo00000?oooooo>?ooool0033ooooo00?o0000ooooooooool0R_ooool00ol0003oooooo`000009
ooooo`03o`000?oooooo000000Sooooo00?o0000ooooool00000oooooolhooooo`00<?ooool00ol0
003oooooooooo`2:ooooo`03o`000?oooooo000000Wooooo00?o0000ooooool000002?ooool00ol0
003oooooo`00003oooooocSooooo000`ooooo`03o`000?oooooooooo08[ooooo00?o0000ooooool0
00002?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?oooooo>?ooool0033o
oooo00?o0000ooooooooool0R_ooool00ol0003oooooo`000008ooooo`04o`000?ooooooooooo`00
00Sooooo00?o0000ooooool00000oooooolhooooo`00<?ooool00ol0003oooooooooo`2:ooooo`03
o`000?oooooo000000Sooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003ooooo
ocSooooo000`ooooo`03o`000?oooooooooo08[ooooo00?o0000ooooool000002?ooool01?l0003o
ooooooooool00008ooooo`03o`000?oooooo00000?oooooo>?ooool0033ooooo00?o0000oooooooo
ool0R_ooool00ol0003oooooo`000008ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000oooo
ool00000oooooolhooooo`00<?ooool3o`0008Wooooo00Co0000oooooooooooo00002?ooool01?l0
003oooooooooool00008ooooo`03o`000?oooooo00000?oooooo>?ooool0033ooooo00?o0000oooo
ooooool0ROooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo00?o
0000ooooool00000oooooolhooooo`00<?ooool00ol0003oooooooooo`29ooooo`04o`000?oooooo
ooooo`0000Sooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003oooooocSooooo
000`ooooo`03o`000?oooooooooo08Wooooo00Co0000oooooooooooo00002?ooool01?l0003ooooo
ooooool00008ooooo`03o`000?oooooo00000?oooooo>?ooool0033ooooo00?o0000ooooooooool0
ROooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000oooo
ool00000oooooolhooooo`00<?ooool00ol0003oooooooooo`29ooooo`04o`000?ooooooooooo`00
00Sooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003oooooocSooooo000`oooo
o`03o`000?oooooooooo07kooooo00?o0000ooooooooool02?ooool01?l0003oooooooooool00008
ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooolhooooo`00<?ooool0
0ol0003oooooooooo`1mooooo`;o00002_ooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000Sooooo00?o0000ooooool00000oooooolhooooo`00<?ooool00ol0003ooooooooo
o`1mooooo`;o00002_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000So
oooo00?o0000ooooool00000oooooolhooooo`00<?ooool00ol0003oooooooooo`1mooooo`;o0000
2_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000oooo
ool000002Oooool00ol0003oooooooooo`3oooooobcooooo000`ooooo`03o`000?oooooooooo07go
oooo00?o0000ooooool000002Oooool01?l0003oooooooooool00008ooooo`04o`000?oooooooooo
o`0000Sooooo00?o0000ooooool000002?ooool2o`000?oooooo;_ooool0033ooooo0ol0001moooo
o`03o`000?oooooo000000Wooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0
0008ooooo`03o`000?oooooo000000Sooooo0_l0003oooooobkooooo000`ooooo`03o`000?oooooo
oooo07gooooo00?o0000ooooool000002Oooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000Sooooo00?o0000ooooool000002?ooool2o`000?oooooo;_ooool0033ooooo00?o
0000ooooooooool0OOooool00ol0003oooooo`000009ooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00002?ooool00ol0003oooooo`000008ooooo`;o0000ooooool^ooooo`00
<?ooool00ol0003oooooooooo`1mooooo`03o`000?oooooo000000Wooooo00Go0000oooooooooooo
ooooo`000007ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool000002?ooool2o`00
0?oooooo;_ooool0033ooooo00?o0000ooooooooool0OOooool00ol0003oooooo`000009ooooo`05
o`000?ooooooooooooooool000001oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo
000000Sooooo0_l0003oooooobkooooo000`ooooo`03o`000?oooooooooo07gooooo00?o0000oooo
ool000002?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00Co0000oooo
oooooooo00002?ooool00ol0003oooooo`000008ooooo`;o0000ooooool^ooooo`00<?ooool00ol0
003oooooooooo`1mooooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool000002?ooool0
0ol0003oooooo`00003oooooobgooooo000@ooooo`;ok^k^0oooool2onk^kQWooooo00?o0000oooo
ooooool0OOooool00ol0003oooooo`000008ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01Oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo000000Sooooo00?o0000
ooooool00000ooooool]ooooo`002Oooool5o`0000;ooooo00Ook^k^oeEEEOo^k^koooooonk^k_mE
EEGok^k^00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^2_ooool00ol0
003oooooooooo`1mooooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool000002?ooool0
0ol0003oooooo`00003oooooobgooooo0009ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool0
1Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00[ooooo00?o0000ooooooooool0OOooool00ol0003oooooo`000008ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00008ooooo`03
o`000?oooooo000000Sooooo00?o0000ooooool00000ooooool]ooooo`0000?oooooo`000?l00000
1?l00003ooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?ogMgMo`000?oMgMd01oooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41002_ooool00ol0003oooooooooo`1mooooo`03
o`000?oooooo000000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`04
o`000?ooooooooooo`0000Sooooo00?o0000ooooool000002?ooool00ol0003oooooo`00003ooooo
obgooooo000;ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06oooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000:ooooo`03o`000?oooooo
oooo07cooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Gooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`000008ooooo`03o`00
0?oooooo00000?oooooo;Oooool000cooooo00_oMgMgofIVI_ooooooooooonk^k_mEEEGok^k^oooo
ooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
000:ooooo`Co0000Noooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01Oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo000000So
oooo00?o0000ooooool00000ooooool]ooooo`003Oooool00ol0003oooooooooo`02onk^kP?ooooo
0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400:ooooo`03
o`000?oooooooooo07cooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool0
0008ooooo`03o`000?oooooo00000?oooooo;Oooool000Wooooo00Go0000okZj^_ooooooV9RHoa0@
400>ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`;o0000
1Oooool00ol0003oooooooooo`1looooo`04o`000?ooooooooooo`0000Sooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooo
oooooooo00001oooool01?l0003oooooooooool0003oooooobgooooo0009ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`03?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
0_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo07cooooo00Co0000oooooooo
oooo00002?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00Co0000oooo
oooooooo00001oooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`000?oooooo
;Oooool002Sooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1looooo`04o`00
0?ooooooooooo`0000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`04
o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?oooooo
ooooo`000?oooooo;Oooool002Sooooo0ol00005ooooo`03o`000?oooooooooo07cooooo00Co0000
oooooooooooo00002?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go
0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003o
ooooooooool0003oooooobgooooo000Yooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0O?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`00
0006ooooo`04o`000?ooooooooooo`000?oooooo;Oooool002[ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`1looooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003o
oooooooooooooooo000000Kooooo00Co0000oooooooooooo0000ooooool]ooooo`00<?ooool00ol0
003oooooooooo`1looooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooo
oooooooo000000Kooooo00Co0000oooooooooooo0000ooooool]ooooo`00<?ooool00ol0003ooooo
ooooo`1looooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003o
oooooooooooooooo000000Kooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`3o
ooooob;ooooo000`ooooo`03o`000?oooooooooo07cooooo00Co0000oooooooooooo00002?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003ooooooooo
ool00008ooooo`03o`000?oooooooooo0?oooooo8_ooool0033ooooo00?o0000ooooooooool0O?oo
ool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooo
ooooo`000006ooooo`04o`000?ooooooooooo`0000Sooooo0_l0003oooooob?ooooo000`ooooo`?o
0000Noooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo00001oooool0
0ol0003oooooo`00003oooooob?ooooo000`ooooo`03o`000?oooooooooo073ooooo0_l00009oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04oooo
o`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool00007ooooo`03o`000?oo
oooo00000?oooooo8oooool0033ooooo00?o0000ooooooooool0L?ooool2o`0000Wooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000
ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool00000
oooooolSooooo`00<?ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooo000000Wooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go
0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool0
0000oooooolSooooo`00<?ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooo000000Wooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo
00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000oooo
ool00000oooooolSooooo`00<?ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooo000000Wo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000
ooooool00000oooooolSooooo`00<?ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooo0000
00Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Oooooo00?o
0000ooooool00000oooooolSooooo`00<?ooool00ol0003oooooooooo`1_ooooo`03o`000?oooooo
000000Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Oooooo
00?o0000ooooool00000oooooolSooooo`00<?ooool00ol0003oooooooooo`1_ooooo`04o`000?oo
ooooooooo`0000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`00
00Oooooo00?o0000ooooool00000oooooolSooooo`00<?ooool00ol0003oooooooooo`1_ooooo`04
o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?oooooo
ooooo`0000Oooooo00?o0000ooooool00000oooooolSooooo`00<?ooool00ol0003oooooooooo`1_
ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`04o`00
0?ooooooooooo`0000Oooooo00?o0000ooooool00000oooooolSooooo`00<?ooool00ol0003ooooo
ooooo`1^ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000
00Kooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00003oooooob?ooooo000`oooo
o`?o0000K_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00
0006ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool0003oooooob;o
oooo000`ooooo`03o`000?oooooooooo06kooooo00Go0000ooooooooooooooooo`000008ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05
o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000
oooooooooooo0000oooooolRooooo`00<?ooool00ol0003oooooooooo`1^ooooo`05o`000?oooooo
ooooooooool000002?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000oooooooooooo
ooooo`000006ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool0oooooolHoooo
o`00<?ooool00ol0003oooooooooo`1^ooooo`05o`000?ooooooooooooooool000002?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0
003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000005ooooo`05o`000?oo
ooooooooooooool000001_ooool2o`000?oooooo6_ooool0033ooooo00?o0000ooooooooool0K_oo
ool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`05
o`000?ooooooooooooooool000001Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000
ooooool00000oooooolIooooo`00<?ooool00ol0003oooooooooo`1>ooooo`;ok^k^0oooool2onk^
kQWooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_oo
ool01_l0003ok^k^onk^k_oooooo0000ooooo`;ok^k^0_ooool01Ol0003ooooooooooooooooo0000
00Kooooo00?o0000ooooool00000D?ooool2onk^kP?ooooo0_o^k^i>ooooo`;ok^k^0oooool2onk^
kVcooooo000`ooooo`03o`000?oooooooooo04Sooooo00goA4A4o`000?l0003o<S8bomgMgOoooooo
k^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8b
o`000?lb<S;ok^k^2_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooo`000003o`000009oa0@4?l0003ok^k^oeEEEOo^k^ko0000onk^k_mEEEGo
k^k^00;ooooo1Ol000001Ol@413oooooooooooo^k^ko<S8b00;o000000?ok^k^o`000?ooool0>Ooo
ool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`0=odA4A?l0003o0000oc8b<_oMgMgo
ooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co000000So410@ooooooooooook^k^
oc8b<_l0003o<S8bonk^kSSooooo1Ol00002ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^
kP03ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kUgooooo000`ooooo`03
o`000?oooooooooo04_ooooo00WoMgMgoc8b<_ooooooooooonk^k_mEEEGogMgMoeEEEOo^k^h01_oo
ool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02_ooool01Ol0003ooooo
oooooooooooo000000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
00;ooooo00Oo0000ooooooo^k^koEEEEo`000?mEEEGok^k^00?ooooo00?o0000ooooooooool00_l0
0003ooooo`06ogMgMonHV9Soooooo`000?mgMgOo0000??ooool00ol0003oooooooooo`04ooooo`;o
8B4Q2?ooool02OmgMgOo<S8booooooooooook^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0hooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@00oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg05gooooo000`ooooo`03o`000?oooooooooo04cooooo00Oo0000oooo
ooooooooooooomgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@00[ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00Oo0000ooooooooooooooooo`000?oooooo000000?ooooo00?ogMgMo`000?oMgMd01?ooool0
0ol0003oooooooooo`02o`0000?ooooo00Ko410@oooooooooooo0000oa0@4?l0000looooo`03o`00
0?oooooooooo00oooooo00Oo0000ooooooooooooooooomgMgOl0003ogMgM00Oooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@03Wooooo00?oV9RHob4Q8Oo^k^h01Oooool0
0ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
401Mooooo`00<?ooool00ol0003oooooooooo`1;ooooo`09ogMgMolb<S;oooooooooooo^k^koEEEE
omgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
00[ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00Ko0000
oooooooooooo0000ooooool00002ooooo`05onk^k_mEEEGo0000oeEEEOo^k^h00oooool00ol0003o
ooooooooo`02o`0000?ooooo00?o0000ooooooooool00ol0000looooo`03o`000?oooooooooo00ko
oooo00WoMgMgoc8b<_ooooooooooonk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool00000>_ooool00onHV9So8B4Qonk^kP03ooooo`05onk^
k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000GOooool0033ooooo00?o0000ooooooooool0B?ooool03Ol0003o8B4Qo`000?lb<S;oc<c<
ooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000002Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool03_l0003oooooooooool0003oooooo`000?ooooook^k^
oeEEEOo^k^ko0000onk^k_mEEEGok^k^0_ooool00ol0003oooooooooo`02o`0000?ooooo00?o0000
ooooooooool00ol0000looooo`03o`000?oooooooooo00_ooooo00go0000ob4Q8Ol0003o<S8bolc<
c?ooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000003_ooooo00_oMgMgofIVI_ooooooooooonk^k_mEEEGok^k^oooo
ooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
001Mooooo`00<?ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00?ooooo0_o^k^h3
ooooo`;ok^k^1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooo0000o`000?l@41002Ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool01ol0003oooooooooool0003oooooo`000?ooool00_o^k^h00ooooooo0000ooooo`02onk^kP;o
oooo00?o0000ooooooooool00_l00003ooooo`06oa0@4?oooooo0000ooooool@413o0000??ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo0_o^k^h3ooooo`;ok^k^1Oooool0
0ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100??ooool00ol0003ooooooooo
o`02onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooo
oa0@401Mooooo`00<?ooool3o`0004Sooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`02ooooo`05ogMgMol0003o0000o`000?mgMgL02?ooool2o`0000Cooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`06o`000?ooooooooooo`000?oooooo00001?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;o00000oooool01omgMgOoV9RHo`000?nHV9So
MgMgooooool000001_ooool2o`0003?ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`;o0000
;_ooool01Ol0003o^[ZjoooooonHV9So410@00kooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Sooooo0_l0001Cooooo`00<?ooool00ol0003oooooooooo`18ooooo`Co
00003?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_l0003o0000oc8b<_l000002?ooool2o`00
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`06o`000?mEEEGoIVIV
o`000?oooooo00001?ooool00ol0003oooooooooo`03ooooo`03o`000?mEEEGoIVIV00;o00000ooo
ool01oo^k^ko<S8bo`000?lb<S;ok^k^ooooool000001Oooool4o`00033ooooo00?oEEEEofIVI_l0
00003Oooool4o`0000cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Oooooo00Co0000oooooooooooo0000;Oooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo00?o
EEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oooooo00Co0000oooooooooooo
0000D_ooool0033ooooo00?o0000ooooooooool0H?ooool01?l0003oooooooooool00002ooooo`Co
00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool01Ol0003ooooooooooooooooo000000Gooooo00Co0000oooooooooooooooo1Ol00000
0ooooooo0000o`000002o`0005kooooo1?l000001Ooooooo0000oooooooooooo000004cooooo1?l0
00001Ooooooo0000oooooooooooo000005;ooooo000`ooooo`03o`000?oooooooooo063ooooo00Co
0000oooooooooooo00002Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Gooooo00Go0000oooooooo
ooooooooo`000005ooooo`?o0000I?ooool3o`0005;ooooo0ol0001Cooooo`00<?ooool00ol0003o
ooooooooo`1Oooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01?l0003o
ooooo`000?l00004ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0
003ooooooooooooooooo000000Gooooo00Go0000ooooooooooooooooo`000005ooooo`;o000000?o
ooooo`000?ooool0Hoooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo05;ooooo000`
ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`Co00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000
ooooooooooooooooo`000005ooooo`05o`000?ooooooooooooooool000001Oooool01?l0003ooooo
o`000?l0001Uooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0DOooool0033ooooo
00?o0000ooooooooool0Goooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
00Go0000ooooooooooooooooo`000005ooooo`05o`000?ooooooooooooooool000001Oooool01?l0
003oooooooooool0003oooooo`oooooo000`ooooo`03o`000?oooooooooo05kooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001Oooool0
1Ol0003ooooooooooooooooo000000Gooooo00Co0000oooooooooooo00001_ooool2o`000<cooooo
00?oMgMgofIVI_ooool0;Oooool00omVIVKoMgMgooooo`07ooooo`00<?ooool00ol0003ooooooooo
o`1Aooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000Gooooo00Co0000oooooooooooo00001_ooool00ol0003oooooo`00003:ooooo`03
omgMgOl@413ok^k^02kooooo00?ok^k^oa0@4?oMgMd01oooool0033ooooo00?o0000ooooooooool0
Coooool5o`0000[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00007oooo
o`03o`000?oooooooooo0:kooooo0_l00002ooooo`;o00003?ooool00omEEEGoV9RHooooo`02o`00
00;ooooo00Oo0000oooooooooooo0000oa0@4?o^k^koEEEE00;o000000?oA4A4okZj^_ooool00_oo
ool01OnHV9So0000o`000?m4A4Co^[Zj00;ooooo00Sok^k^oeEEEOl0003o0000odA4A?nj^[[ooooo
oa0@40Go00000oooool02?l@413o<S8bo`000?l0003o410@ojVYZOn7QhOoIVIV1oooool0033ooooo
00?o0000ooooooooool0C_ooool00ol0003oooooooooo`02ooooo`;o00002Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`03
o`000?oooooooooo00?ooooo00Co0000oooooooooooo00001Oooool4o`000:oooooo00Kok^k^ob4Q
8On7QhOo^[Zjo`000?oMgMd<ooooo`05o`000?ooooooooooooooool000000_ooool02ol0003ooooo
ooooool0003ooooooeEEEOmgMgOoooooonk^k_mgMgOo410@00?ooooo00Go410@okZj^_o^k^koMgMg
oa0@4002ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo410@0oooool00ol0003oooooooooo`04oooo
o`08o`000?nYZJWooooooooooonj^[[o0000onk^k_l00007ooooo`00ool0002do`0000oooooo00Co
gMgMo`000?l@413oc<c<3Oooool01Olb<S;ooooooooooooooooo000000;ooooo00Ko0000oooooooo
oooo0000ooooool00008ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`07okZj^_n7QhOoIVIVofIVI_l@413oooooo`000007ooooo`002_oo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03Ooo
ool7o`0000Wooooo00?o0000ooooooooool00oooool00ol0003oooooo`000007ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo0_l00003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooooooool2o`0000?ooooo00?o0000ooooooooool00oooool01Ol0003ooooo
oooooooooooo000000?ooooo0_l00003ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`000004ooooo`Go00001?ooool4o`0000Gooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0Gooooo`04onk^k_lQ8B7o410@onk^kPgooooo00Go<S8booooooooooooooooo`00
0002ooooo`05o`000?ooooooooooo`000?ooool01_l00003ooooo`03o`000?oooooooooo00Cooooo
1_l00003ooooo`03o`000?oooooooooo00Cooooo00So<S8bob4Q8OmgMgOoMgMgohN7Qoo^k^kooooo
o`0000Oooooo000:ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00oooool00ol0
003oooooo`000007ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooool000001Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooooooool2o`0000?ooooo00?o0000
ooooooooool00oooool01Ol0003ooooooooooooooooo000000?ooooo0_l00003ooooo`03o`000?oo
oooooooo00?ooooo00Co0000ooooool0003o00001?ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool05oooool01?lQ8B7oMgMgogMgMolb<S8=ooooo`05
o`000?o^k^koooooooooool000000_o<c<`02ol0003oZJVYomgMgOlQ8B7ooooooeEEEOn7QhOok^k^
oooooon7QhOo<S8b00?ooooo00?o0000ooooooooool01?ooool01_mEEEGoQhN7onk^k_ooooooQhN7
oc8b<P?ooooo00?o0000oc8b<_oMgMd01?ooool02?l0003o^[Zjooooooo^k^koMgMgo`000?o^k^ko
00001oooool0033ooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`02ooooo`;o0000
2?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooooooo`;o00000oooool00ol0003o
ooooooooo`03ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo
000000Gooooo0ol0000mooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool05_ooool2
o`0000;ooooo0_l0000<ooooo`0>oeEEEOmgMgOooooooa0@4?l0003o8B4Qo`000?mgMgOo410@o`00
0?nYZJWoooooonk^k_mEEED2o`000004odA4A?o^k^kooooooa0@40Go00000oooool01_o^k^koEEEE
o`000?l0003oA4A4onk^kP;ooooo0_l000001?nYZJWo8B4Qo`000?lQ8B42ooooo`08ojVYZOlQ8B7o
0000o`000?lb<S;o0000ogMgMomEEED7ooooo`00<?ooool00ol0003oooooooooo`1Gooooo`05o`00
0?ooooooooooooooool000002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`000005ooooo`05o`000?ooooooooooooooool000001Oooool0
1?l0003oooooooooool0003>ooooo`03omgMgOl@413ok^k^01;ooooo00?o0000ooooooooool06Ooo
ool00oo^k^ko410@omgMg@07ooooo`00<?ooool00ol0003oooooooooo`1Gooooo`05o`000?oooooo
ooooooooool000002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000005ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooool0
0000d?ooool00omgMgOoIVIVooooo`0Aooooo`03o`000?oooooooooo01Wooooo00?oIVIVogMgMooo
ool01oooool0033ooooo00?o0000ooooooooool0F?ooool4o`0000[ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001Oooool01?l0003o
ooooooooool00006ooooo`03o`000?oooooo00000?oooooo2oooool0033ooooo00?o0000oooooooo
ool0I_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`000005ooooo`04o`000?ooooooooooo`0000Oooooo0_l0003oooooo`_ooooo000`oooo
o`03o`000?oooooooooo06Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000001Oooool01?l0003oooooooooool0003ooooooaCooooo000`
ooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000005ooooo`05o`000?oo
ooooooooooooool000001Oooool01?l0003oooooooooool0003ooooooaCooooo000`ooooo`03o`00
0?oooooooooo06Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000005ooooo`05o`000?oooooooooooooo
ool000001_ooool00ol0003oooooo`00003ooooooaCooooo000`ooooo`03o`000?oooooooooo06Oo
oooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000oooo
ooooooooooooo`000005ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooo`00
003ooooooaCooooo000`ooooo`?o0000Ioooool01Ol0003ooooooooooooooooo000000Sooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Gooooo00Go0000oooooooooooo
ooooo`000006ooooo`03o`000?oooooo00000?oooooo5?ooool0033ooooo00?o0000ooooooooool0
Ioooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003o
oooooooooooooooo000000Gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
00000?oooooo5?ooool0033ooooo00?o0000ooooooooool0Ioooool01Ol0003ooooooooooooooooo
000000Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Kooooo00Co
0000oooooooooooo00001_ooool2o`000?oooooo5Oooool0033ooooo00?o0000ooooooooool0Iooo
ool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooo
oooooooooooo000000Kooooo00Co0000oooooooooooo00001_ooool2o`000?oooooo5Oooool0033o
oooo00?o0000ooooooooool0Ioooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo0000oooo
oolMooooo`00<?ooool00ol0003oooooooooo`1Wooooo`04o`000?ooooooooooo`0000Wooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo
0000oooooolMooooo`00<?ooool00ol0003oooooooooo`1Wooooo`04o`000?ooooooooooo`0000Wo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooooooo
ool000001Oooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo0000oooo
oolMooooo`00<?ooool00ol0003oooooooooo`1Xooooo`03o`000?oooooo000000[ooooo00Go0000
ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0003ooooo
oooooooooooo000000Kooooo00Co0000oooooooooooo0000oooooolMooooo`00<?ooool00ol0003o
ooooooooo`1Xooooo`03o`000?oooooo000000[ooooo00Go0000ooooooooooooooooo`000008oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04oooo
o`05o`000?ooooooooooooooool000001Oooool01Ol0003ooooooooooooooooo000000Kooooo00Co
0000oooooooooooo0000oooooolMooooo`00<?ooool00ol0003oooooooooo`1Xooooo`03o`000?oo
oooo000000[ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool0
00001Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooool00000oooooolNoooo
o`00<?ooool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo00Wooooo00Go0000oooooooo
ooooooooo`000008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0003ooooooooooooo
oooo000000Kooooo00?o0000ooooool00000oooooolNooooo`00<?ooool00ol0003oooooooooo`1e
ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Gooooo
00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo00000?oooooo7_ooool0033ooooo
0ol0001eooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000
00Gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo00000?oooooo7_ooool0
033ooooo00?o0000ooooooooool0MOooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000
ooooooooooooooooo`000005ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooo
o`00003ooooooakooooo000`ooooo`03o`000?oooooooooo07Gooooo00Go0000oooooooooooooooo
o`000008ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05
o`000?ooooooooooooooool000001Oooool01?l0003oooooooooool00007ooooo`03o`000?oooooo
00000?oooooo7_ooool0033ooooo00?o0000ooooooooool0MOooool01Ol0003ooooooooooooooooo
000000Sooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go
0000ooooooooooooooooo`000005ooooo`04o`000?ooooooooooo`0000Oooooo0ol0003ooooooako
oooo000`ooooo`03o`000?oooooooooo07Gooooo00Go0000ooooooooooooooooo`000008ooooo`05
o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooo
ooooool000001Oooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo0?oooooo7Ooo
ool0033ooooo00?o0000ooooooooool0MOooool01Ol0003ooooooooooooooooo000000Sooooo00Go
0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooo
ooooo`000005ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool0oooooolMoooo
o`00<?ooool00ol0003oooooooooo`1eooooo`05o`000?ooooooooooooooool000002?ooool01Ol0
003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooo
oooo000000Gooooo00Co0000oooooooooooo0000oooooolXooooo`00<?ooool00ol0003ooooooooo
o`1eooooo`05o`000?ooooooooooooooool000002?ooool01Ol0003ooooooooooooooooo000000Oo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Gooooo00Co0000oooo
oooooooo0000oooooolXooooo`00<?ooool00ol0003oooooooooo`1eooooo`05o`000?oooooooooo
ooooool000002?ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool01Ol0003ooooooooooooooooo000000Gooooo00Co0000oooooooooooo0000oooooolXooooo`00
<?ooool00ol0003oooooooooo`1eooooo`05o`000?ooooooooooooooool000002?ooool01Ol0003o
oooooooooooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo
000000Gooooo00Co0000oooooooooooo0000oooooolXooooo`00<?ooool00ol0003oooooooooo`1e
ooooo`05o`000?ooooooooooooooool000002?ooool01Ol0003ooooooooooooooooo000000Oooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Gooooo00Co0000oooooooo
oooo0000oooooolXooooo`00<?ooool00ol0003oooooooooo`1eooooo`05o`000?oooooooooooooo
ool000002?ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
1Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooool00000oooooolXooooo`00<?ooool3
o`0007Kooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Oooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooool0
0000oooooolXooooo`00<?ooool00ol0003oooooooooo`1fooooo`04o`000?ooooooooooo`0000So
oooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Co0000oooo
oooooooo00001oooool00ol0003oooooo`00003oooooobSooooo000`ooooo`03o`000?oooooooooo
07Kooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Sooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool01?l0003oooooooooool00007ooooo`03o`000?oooooo00000?oooooo:?ooool0033ooooo
00?o0000ooooooooool0M_ooool01?l0003oooooooooool00008ooooo`05o`000?oooooooooooooo
ool000002?ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool01?l0003oooooooooool00007ooooo`03o`000?oooooo00000?oooooo:?oo
ool0033ooooo00?o0000ooooooooool0M_ooool01?l0003oooooooooool00008ooooo`05o`000?oo
ooooooooooooool000002?ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00007ooooo`03o`000?oooooo0000
0?oooooo:?ooool0033ooooo00?o0000ooooooooool0M_ooool00ol0003oooooo`000009ooooo`05
o`000?ooooooooooooooool000002?ooool01?l0003oooooooooool00007ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00007ooooo`03o`000?oo
oooo00000?oooooo:?ooool000oooooo0_o^k^h3ooooo`;ok^k^6_ooool00ol0003oooooooooo`1f
ooooo`03o`000?oooooo000000Wooooo00Go0000ooooooooooooooooo`000008ooooo`04o`000?oo
ooooooooo`0000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`04o`00
0?ooooooooooo`0000Oooooo00?o0000ooooool00000oooooolXooooo`002?ooool5o`0000;ooooo
00Ook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413oooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^2oooool00ol0003oooooooooo`1fooooo`03o`000?oooooo000000Wooooo
00Go0000ooooooooooooooooo`000008ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000
ooooool00000oooooolXooooo`002?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00Gok^k^
oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`03o`000?oooooooooo07Kooooo00?o0000ooooool000002Oooool01Ol0003ooooo
oooooooooooo000000Sooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00003o
ooooobSooooo0009ooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?ogMgMo`000?oMgMd01oooool00ol0
003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41002oooool00ol0003oooooooooo`1f
ooooo`03o`000?oooooo000000Wooooo00Go0000ooooooooooooooooo`000008ooooo`04o`000?oo
ooooooooo`0000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`04o`00
0?ooooooooooo`0000Oooooo00?o0000ooooool00000oooooolXooooo`002_ooool00onHV9So8B4Q
onk^kP03ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`1fooooo`03o`000?oooooo0000
00Wooooo00Go0000ooooooooooooooooo`000008ooooo`04o`000?ooooooooooo`0000Oooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000Oooooo
00?o0000ooooool00000oooooolXooooo`002oooool02omgMgOoIVIVooooooooooook^k^oeEEEOo^
k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000000_ooooo1?l0001fooooo`;o00002Oooool01Ol0003ooooooooooooooooo000000Sooooo
00Co0000oooooooooooo00001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00003oooooobSooooo000<ooooo`03
o`000?oooooooooo00;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@413o
oooooooooooooooo410@00_ooooo00?o0000ooooooooool0Moooool2o`0000[ooooo00Co0000oooo
oooooooo00002?ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool01?l0003oooooooooool00007ooooo`;o0000oooooolYooooo`002?oo
ool01Ol0003o^[ZjoooooonHV9So410@00kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00?o0000ooooooooool0Moooool00ol0003oooooooooo`09ooooo`04
o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooo
oooo000000Oooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`3oooooobOooooo
0008ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?ooool00omEEEGoIVIVo`000004ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h00oooool2o`0000Kooooo00?o0000ooooooooool0Poooool01?l0003o
ooooooooool00008ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00
0007ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool0oooooolWooooo`009ooo
ool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo08?ooooo00Co0000oooooooooooo
00002?ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001oooool0
1?l0003oooooooooool0003ooooooc;ooooo000Wooooo`04o`000?ooooooooooo`0000Gooooo00?o
0000ooooooooool0Poooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Oo
oooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`000?oooooo<_ooool0
02Oooooo0ol00006ooooo`03o`000?oooooooooo08?ooooo00Co0000oooooooooooo00002?ooool0
1?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001oooool01?l0003ooooo
ooooool0003ooooooc;ooooo000Xooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
Poooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooo
ooooooooooooo`000007ooooo`04o`000?ooooooooooo`000?oooooo<_ooool002Wooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`23ooooo`04o`000?ooooooooooo`0000Sooooo00Co
0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooo
oooo0000oooooolbooooo`00<?ooool00ol0003oooooooooo`23ooooo`04o`000?ooooooooooo`00
00Sooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co
0000oooooooooooo0000oooooolbooooo`00<?ooool00ol0003oooooooooo`23ooooo`04o`000?oo
ooooooooo`0000Sooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000
00Oooooo00Co0000oooooooooooo0000oooooolbooooo`00<?ooool00ol0003oooooooooo`23oooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002?ooool01?l0003ooooooooo
ool00007ooooo`04o`000?ooooooooooo`000?oooooo<_ooool0033ooooo0ol00023ooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00007
ooooo`04o`000?ooooooooooo`000?oooooo<_ooool0033ooooo00?o0000ooooooooool0Poooool0
1?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo
00001oooool01?l0003oooooooooool0003ooooooc;ooooo000`ooooo`03o`000?oooooooooo08?o
oooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00008ooooo`04o`000?oooooo
ooooo`0000Oooooo00Co0000oooooooooooo0000oooooolbooooo`00<?ooool00ol0003ooooooooo
o`23ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002?ooool01?l0003o
ooooooooool00007ooooo`04o`000?ooooooooooo`000?oooooo<_ooool0033ooooo00?o0000oooo
ooooool0Poooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo00Co
0000oooooooooooo00001oooool00ol0003oooooo`00003ooooooc?ooooo000`ooooo`03o`000?oo
oooooooo08?ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00008ooooo`04
o`000?ooooooooooo`0000Sooooo0_l0003ooooooc?ooooo000`ooooo`03o`000?oooooooooo08?o
oooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00008ooooo`04o`000?oooooo
ooooo`0000Sooooo0_l0003ooooooc?ooooo000`ooooo`03o`000?oooooooooo08?ooooo00?o0000
ooooool000002Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo
0_l0003ooooooc?ooooo000`ooooo`03o`000?oooooooooo08?ooooo00?o0000ooooool000002Ooo
ool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo0_l0003ooooooc?o
oooo000`ooooo`03o`000?oooooooooo08?ooooo00?o0000ooooool000002Oooool01?l0003ooooo
ooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo0_l0003ooooooc?ooooo000`ooooo`03
o`000?oooooooooo08?ooooo00?o0000ooooool000002Oooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000Sooooo0_l0003ooooooc?ooooo000`ooooo`03o`000?oooooooooo
08?ooooo00?o0000ooooool000002Oooool01?l0003oooooooooool00008ooooo`04o`000?oooooo
ooooo`0000Sooooo0_l0003ooooooc?ooooo000`ooooo`?o0000Poooool00ol0003oooooo`000009
ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002?ooool2o`000?oooooo
<oooool0033ooooo00?o0000ooooooooool0Q?ooool2o`0000Wooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool00008ooooo`;o0000oooooolcooooo`00<?ooool00ol0003ooooo
ooooo`24ooooo`;o00002Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00
00Sooooo0_l0003ooooooc?ooooo000`ooooo`03o`000?oooooooooo08Cooooo0_l00009ooooo`04
o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002?ooool2o`000?oooooo<oooool0
033ooooo00?o0000ooooooooool0Q?ooool2o`0000Wooooo00Co0000oooooooooooo00002?ooool0
1?l0003oooooooooool0003oooooocgooooo000`ooooo`03o`000?oooooooooo08Cooooo0_l00009
ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000oooooolmooooo`00<?oo
ool00ol0003oooooooooo`24ooooo`;o00002Oooool01?l0003oooooooooool00008ooooo`04o`00
0?ooooooooooo`000?oooooo?Oooool0033ooooo00?o0000ooooooooool0Q?ooool2o`0000Wooooo
00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0003oooooocgooooo000`ooooo`03
o`000?oooooooooo08Cooooo0_l00009ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooo
oooooooo0000oooooolmooooo`00<?ooool00ol0003oooooooooo`2?ooooo`04o`000?oooooooooo
o`0000Sooooo00?o0000ooooool00000oooooolnooooo`00<?ooool00ol0003oooooooooo`2?oooo
o`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooolnooooo`00<?ooool00ol0
003oooooooooo`2@ooooo`03o`000?oooooo000000Sooooo00?o0000ooooool00000oooooolnoooo
o`00<?ooool3o`00093ooooo00?o0000ooooool000002?ooool00ol0003oooooo`00003oooooocko
oooo000`ooooo`03o`000?oooooooooo093ooooo00?o0000ooooool000002Oooool2o`000?oooooo
?_ooool0033ooooo00?o0000ooooooooool0T?ooool2o`0000[ooooo0_l0003oooooockooooo000`
ooooo`03o`000?oooooooooo093ooooo0_l0000:ooooo`;o0000oooooolnooooo`00<?ooool00ol0
003oooooooooo`2@ooooo`;o00002_ooool2o`000?oooooo?_ooool0033ooooo00?o0000oooooooo
ool0T?ooool2o`0000[ooooo0_l0003oooooockooooo000?ooooo`;ok^k^0oooool2onk^kQ[ooooo
00?o0000ooooooooool0T?ooool2o`0000[ooooo0_l0003oooooockooooo000:ooooo`;o000000[o
410@ooooooooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^0oooool4o`000008oa0@4?oooooo
ooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`03o`000?oooooooooo093ooooo0_l0000:ooooo`;o
0000oooooolnooooo`002oooool00ol0003oooooooooo`02ooooo`05onk^k_mEEEGogMgMoeEEEOo^
k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ol0
003oooooooooo`2@ooooo`;o00002_ooool2o`000?oooooo?_ooool000Sooooo1Ol00004ooooo`03
omgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@
00_ooooo00?o0000ooooooooool0T?ooool2o`0000[ooooo0_l0003oooooockooooo0008ooooo`04
odA4A?oMgMgoooooo`0000Cooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`00000;ooooo`03o`000?oooooooooo093ooooo0_l0
000:ooooo`03o`000?oooooooooo0?oooooo?Oooool000Sooooo00CogMgMoeEEEOoooooo00000ooo
ool01oo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000002oooool4o`0008oooooo0_l0003ooooood[ooooo0009ooooo`03
ogMgMoo<c<co000000?ooooo0_o^k^h3ooooo`;ok^k^1Oooool00ol0003oooooooooo`02ooooo`05
oa0@4?ooooooooooooooool@41002oooool00ol0003oooooooooo`2@ooooo`;o0000oooooom:oooo
o`002Oooool00oo^k^koA4A4o`00000?ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`03o`000?oooooooooo097ooooo00?o0000ooooooooool0oooooom8oooo
o`002_ooool00omgMgOo0000ooooo`0<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP03ooooo`;o00001_ooool00ol0003oooooooooo`3oooooomcooooo000Wooooo`04
o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0oooooooLooooo`009oooool01?l0003o
ooooooooool00005ooooo`03o`000?oooooooooo0?oooooog?ooool002Oooooo0ol00006ooooo`03
o`000?oooooooooo0?oooooog?ooool002Sooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`3oooooomcooooo000Yooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooo
oooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool3o`000?oooooo
g?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0
003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo
00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`
ooooo`?o0000oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03
o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?oo
ool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0
033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomco
oooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooo
oooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo0ol0003oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooo
g?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool00?ooooooooooool@ooooo`00
oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooo
oa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo002T
ooooo`;o00000oooool00onj^[[o<S8booooo`05ooooo`;o00001Oooool00ol0003o^[Zjooooo`3o
oooooeCooooo002Tooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`03ooooo`;o<S8boooooomEooooo`00TOooool3o`0000;ooooo00Ko<S8boa0@4?oo
ooooooooonk^k_mEEED2o`000003odA4A?nj^[[ooooo00?ooooo00Ko0000oooooooooooooooooiRH
V?l@4102o`000003ojVYZOoooooooooo00?ooooo00?o0000ooooooooool00oooool00on7QhOo0000
okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X02oooool00ol0003ok^k^ooooo`05ooooo`;o
8B4Q0oooool01Oo<c<cok^k^ooooooo^k^koc<c<00Cooooo1?l000002?l@413oooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^4oooool01_l@413o<S8bo`000?l0003o410@ojVYZ@;ooooo00Kok^k^oeEE
EOl0003o0000odA4A?nj^[X3ooooo`05ofIVI_l0003o0000odA4A?o<c<`0k?ooool009;ooooo00Go
0000ooooooooooooc<c<oa0@4003ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo410@1?ooool02_l0
003ooooooooooooooooo0000ojVYZOmEEEGoV9RHoeEEEOnj^[X4ooooo`03o`000?oooooooooo00?o
oooo00?oc<c<o`000?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00;ooooo1_l00003oooo
o`03oeEEEOnYZJWooooo00Gooooo0_lQ8B43ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool0
0ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool01_l0003oZJVYoooo
oooooooo^[Zjo`0000;ooooo00KoEEEEogMgMoooooook^k^ogMgMol@4102ooooo`06ofIVI_mgMgOo
oooooooooon7QhOo410@k?ooool009;ooooo00Go0000ooooooooooooEEEEohN7Q`03ooooo`03o`00
0?oooooooooo00Oooooo00[o0000oooooooooooooooooc8b<_o^k^koV9RHoeEEEOoMgMgo410@1?oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00gooooo00?oZJVYoeEEEOooool02ooo
ool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooo
oa0@400Dooooo`05okZj^_n7QhOoIVIVofIVI_l@41000_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0>oooooo002Booooo`05o`000?oooooogMgMo`000?o^k^h00oooool6o`0000Co
oooo00_o0000oooooooooooooooookZj^_m4A4Coc<c<ob4Q8Ooooooo410@olc<c003ooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool01?ooool6o`0000Cooooo00?o8B4Qooooooooool0
2Oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000001?ooooo00Ko<S8bob4Q8OmgMgOoMgMgohN7Qoo^k^h2ooooo`Ko00000_oo
ool00ol0003oooooooooo`3_ooooo`00T_ooool3o`000003oa0@4?nHV9Sooooo00;ooooo00KoEEEE
ohN7Qoo^k^koooooohN7Qolb<S84ooooo`0;o`000?ooooooooooooooooo^k^ko0000ooooool0003o
ooooofIVI_n7QhL00oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00kooooo00?o
EEEEolc<c?ooool02Oooool01Oo<c<cok^k^ooooooo^k^koc<c<00Kooooo00?o0000ooooooooool0
0_ooool01Ol0003ooooooooooooooooo000001?ooooo00Ko0000okZj^_ooooook^k^ogMgMol00002
ooooo`06oeEEEOn7QhOok^k^oooooon7QhOo<S8b0_ooool01_mVIVKoMgMgooooooooooooQhN7o`00
0>cooooo002Booooo`05o`000?ooooooooooolc<c?l000000oooool01_o^k^koEEEEo`000?l0003o
A4A4onk^kPCooooo00So0000ooooooooooooooooofIVI_nHV9Sooooooc8b<P;o^[Zj00Go0000oooo
ooooooooooooo`00000Booooo`03oa0@4?l0003o000000?o00003Oooool00onYZJWoMgMgooooo`0D
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4007ooooo`?o00000_oo
ool3o`0000Cooooo00KoZJVYob4Q8Ol0003o0000oc8b<_l00002ooooo`06onk^k_mEEEGo0000o`00
0?m4A4Cok^k^0_ooool01_o^k^koIVIVo`000?l0003oA4A4o`000>cooooo002Booooo`05o`000?oo
ooooooooolc<c?l000003Oooool00ol0003oooooooooo`04ooooo`03ofIVI_n7QhOooooo00Cooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0;ooooo`05oa0@4?oooooooooooooooolb
<S805Oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo1_ooool0097ooooo1?l000000ol@413o
ZJVYooooo`0<ooooo`;o00001Oooool00onYZJWoA4A4ooooo`03ooooo`;o00005?ooool00ol0003o
ooooooooo`0;ooooo`Go00004oooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00_ooool4o`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3ooooo
o`Kooooo003oooooo`;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3oooooo`Ko
oooo003oooooo`;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3oooooo`Kooooo
003oooooo`7ooooo0_l00003ooooo`;o0000ooooool8ooooo`00oooooooooooooa3ooooo003ooooo
oooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?oo
ool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooo
ooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@oooo
o`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooo
oooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo
003ooooooooooooo4?ooool00001\
\>"],
  ImageRangeCache->{{{0, 525.688}, {324.5, 0}} -> {-2.58312*^-7, -6.34248*^6, \
6.65005*^-9, 53093.5}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0.309017 5.42214e-08 [
[.32684 .29652 -16.5 -12.5 ]
[.32684 .29652 16.5 0 ]
[.54329 .29652 -16.5 -12.5 ]
[.54329 .29652 16.5 0 ]
[.75974 .29652 -22.5 -12.5 ]
[.75974 .29652 22.5 0 ]
[.97619 .29652 -16.5 -12.5 ]
[.97619 .29652 16.5 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 64 6 ]
[.09789 .09213 -34.5 -6.25 ]
[.09789 .09213 0 6.25 ]
[.09789 .20057 -34.5 -6.25 ]
[.09789 .20057 0 6.25 ]
[.09789 .41746 -28.5 -6.25 ]
[.09789 .41746 0 6.25 ]
[.09789 .5259 -28.5 -6.25 ]
[.09789 .5259 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -62.8125 0 ]
[.5 .63053 62.8125 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 .30902 m
.32684 .31527 L
s
gsave
.32684 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 .30902 m
.54329 .31527 L
s
gsave
.54329 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 .30902 m
.75974 .31527 L
s
gsave
.75974 .29652 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 .30902 m
.15368 .31277 L
s
.19697 .30902 m
.19697 .31277 L
s
.24026 .30902 m
.24026 .31277 L
s
.28355 .30902 m
.28355 .31277 L
s
.37013 .30902 m
.37013 .31277 L
s
.41342 .30902 m
.41342 .31277 L
s
.45671 .30902 m
.45671 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.58658 .30902 m
.58658 .31277 L
s
.62987 .30902 m
.62987 .31277 L
s
.67316 .30902 m
.67316 .31277 L
s
.71645 .30902 m
.71645 .31277 L
s
.80303 .30902 m
.80303 .31277 L
s
.84632 .30902 m
.84632 .31277 L
s
.88961 .30902 m
.88961 .31277 L
s
.9329 .30902 m
.9329 .31277 L
s
.0671 .30902 m
.0671 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09213 m
.11664 .09213 L
s
gsave
.09789 .09213 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .20057 m
.11664 .20057 L
s
gsave
.09789 .20057 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .41746 m
.11664 .41746 L
s
gsave
.09789 .41746 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .5259 m
.11664 .5259 L
s
gsave
.09789 .5259 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.11039 .11924 m
.11414 .11924 L
s
.11039 .14635 m
.11414 .14635 L
s
.11039 .17346 m
.11414 .17346 L
s
.11039 .22768 m
.11414 .22768 L
s
.11039 .2548 m
.11414 .2548 L
s
.11039 .28191 m
.11414 .28191 L
s
.11039 .33613 m
.11414 .33613 L
s
.11039 .36324 m
.11414 .36324 L
s
.11039 .39035 m
.11414 .39035 L
s
.11039 .44457 m
.11414 .44457 L
s
.11039 .47168 m
.11414 .47168 L
s
.11039 .49879 m
.11414 .49879 L
s
.11039 .06502 m
.11414 .06502 L
s
.11039 .03791 m
.11414 .03791 L
s
.11039 .0108 m
.11414 .0108 L
s
.11039 .55301 m
.11414 .55301 L
s
.11039 .58012 m
.11414 .58012 L
s
.11039 .60723 m
.11414 .60723 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -123.812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.812 moveto
(@) show
81.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.812 moveto
(D) show
93.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7.2) show
135.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
141.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
153.000 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
157.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
166.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
184.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02691 .30902 L
.03029 .30902 L
.03194 .30902 L
.03347 .30902 L
.03494 .30902 L
.03537 .30902 L
.03577 .30902 L
.03613 .30902 L
.03632 .30902 L
.03652 .30902 L
.03663 .30902 L
.03673 .30902 L
.03683 .30902 L
.03691 .30902 L
.037 .30902 L
.03709 .30902 L
.03719 .30902 L
.03728 .30902 L
.03733 .30902 L
.03739 .30902 L
.03749 .30902 L
.03754 .30902 L
.03759 .30902 L
.03771 .30902 L
.03791 .30902 L
.03812 .30902 L
.03833 .30902 L
.03857 .30902 L
.039 .30902 L
.03942 .30902 L
.0398 .30902 L
.04058 .30902 L
.0413 .30902 L
.0421 .30902 L
.04296 .30902 L
.04372 .30902 L
.04456 .30902 L
.04545 .30902 L
.04626 .30902 L
.04783 .30902 L
.04951 .30902 L
.05105 .30902 L
.05272 .30902 L
.05432 .30902 L
.05601 .30902 L
.05758 .30902 L
.05905 .30902 L
.06068 .30902 L
.06216 .30902 L
Mistroke
.06382 .30902 L
.06536 .30902 L
.06843 .30902 L
.07008 .30902 L
.07157 .30902 L
.07325 .30902 L
.07479 .30902 L
.07789 .30902 L
.08106 .30902 L
.08412 .30902 L
.08736 .30902 L
.09049 .30902 L
.09382 .30902 L
.09702 .30902 L
.1001 .30902 L
.10166 .30902 L
.10249 .30902 L
.10338 .30902 L
.10379 .30902 L
.10423 .30902 L
.10463 .30902 L
.10483 .30902 L
.10501 .30902 L
.10518 .30902 L
.10536 .30902 L
.10546 .30902 L
.10555 .30902 L
.10564 .30902 L
.10574 .30902 L
.10583 .30902 L
.10593 .30902 L
.10603 .30902 L
.10612 .30902 L
.10622 .30902 L
.10628 .30902 L
.10633 .30902 L
.10653 .30902 L
.10673 .30902 L
.1069 .30902 L
.1073 .30902 L
.10766 .30902 L
.10803 .30902 L
.10882 .30902 L
.10927 .30902 L
.10968 .30902 L
.11053 .30902 L
.11132 .30902 L
.11281 .30902 L
.11359 .30902 L
.11442 .30902 L
Mistroke
.1159 .30902 L
.11747 .30902 L
.11894 .30902 L
.12056 .30902 L
.12205 .30902 L
.12371 .30902 L
.12524 .30902 L
.12831 .30902 L
.13145 .30902 L
.13479 .30902 L
.13801 .30902 L
.1411 .30902 L
.14267 .30902 L
.1444 .30902 L
.14605 .30902 L
.14678 .30902 L
.14757 .30902 L
.14798 .30902 L
.14817 .30902 L
.14837 .30902 L
.14855 .30902 L
.14874 .30902 L
.14885 .30902 L
.14894 .30902 L
.14904 .30902 L
.14913 .30902 L
.14924 .30902 L
.14933 .30902 L
.14939 .30902 L
.14945 .30902 L
.14955 .30902 L
.14965 .30902 L
.14975 .30902 L
.14994 .30902 L
.15015 .30902 L
.15035 .30902 L
.15081 .30902 L
.15121 .30902 L
.15165 .30902 L
.15244 .30902 L
.15322 .30902 L
.15393 .30902 L
.15478 .30902 L
.15558 .30902 L
.15708 .30902 L
.15869 .30902 L
.16018 .30902 L
.16182 .30902 L
.16335 .30902 L
.16641 .30902 L
Mistroke
.16954 .30902 L
.17286 .30902 L
.17607 .30902 L
.17915 .30902 L
.18074 .30902 L
.18154 .30902 L
.182 .30902 L
.18243 .30902 L
.18282 .30902 L
.18304 .30902 L
.18324 .30902 L
.18334 .30902 L
.18343 .30902 L
.18351 .30902 L
.1836 .30902 L
.1837 .30902 L
.1838 .30902 L
.18389 .30902 L
.18398 .30902 L
.18404 .30902 L
.1841 .30902 L
.1842 .30902 L
.18431 .30902 L
.1844 .30902 L
.18462 .30902 L
.18485 .30902 L
.18524 .30902 L
.18566 .30902 L
.18605 .30902 L
.18647 .30902 L
.18721 .30902 L
.18801 .30902 L
.18889 .30902 L
.19046 .30902 L
.19214 .30902 L
.19385 .30902 L
.19547 .30902 L
.19856 .30901 L
.20184 .30901 L
.205 .30901 L
.20804 .309 L
.20973 .309 L
.21054 .309 L
.21128 .309 L
.21204 .309 L
.21245 .309 L
.21267 .309 L
.21288 .309 L
.21297 .309 L
.21307 .309 L
Mistroke
.21316 .309 L
.21325 .309 L
.21335 .309 L
.21341 .309 L
.21346 .309 L
.21356 .309 L
.21366 .309 L
.21375 .309 L
.21384 .309 L
.21401 .309 L
.21419 .309 L
.2144 .309 L
.21479 .309 L
.21521 .309 L
.21556 .309 L
.21595 .309 L
.21682 .309 L
.21763 .309 L
.21847 .309 L
.21927 .30901 L
.22076 .30901 L
.22237 .30902 L
.22385 .30902 L
.22702 .30905 L
.23006 .30907 L
.2333 .3091 L
.2348 .30911 L
.23642 .30912 L
.23731 .30913 L
.2377 .30913 L
.23813 .30913 L
.2385 .30913 L
.23891 .30913 L
.23913 .30913 L
.23934 .30913 L
.23944 .30913 L
.23953 .30913 L
.23963 .30913 L
.23968 .30913 L
.23974 .30913 L
.23984 .30913 L
.2399 .30913 L
.23995 .30913 L
.24005 .30913 L
.24011 .30913 L
.24017 .30913 L
.24026 .30913 L
.24037 .30913 L
.24056 .30913 L
.24078 .30913 L
Mistroke
.24102 .30913 L
.24145 .30913 L
.24189 .30913 L
.2423 .30913 L
.24307 .30912 L
.24385 .30911 L
.24468 .3091 L
.24616 .30908 L
.24774 .30904 L
.24921 .309 L
.25234 .30889 L
.25566 .30875 L
.25885 .30861 L
.26032 .30856 L
.26115 .30853 L
.26193 .30851 L
.2623 .30851 L
.2627 .3085 L
.2629 .3085 L
.26313 .3085 L
.26333 .30849 L
.26352 .30849 L
.26363 .30849 L
.26368 .30849 L
.26374 .30849 L
.26379 .30849 L
.26385 .30849 L
.26395 .30849 L
.26404 .30849 L
.26415 .30849 L
.26425 .30849 L
.26434 .30849 L
.26445 .30849 L
.26455 .30849 L
.26478 .3085 L
.26499 .3085 L
.26521 .3085 L
.26564 .30851 L
.26603 .30852 L
.26693 .30855 L
.26772 .30858 L
.26855 .30863 L
.27013 .30875 L
.2716 .3089 L
.27473 .30932 L
.27805 .30988 L
.27972 .31017 L
.28126 .31041 L
.28285 .31062 L
.28363 .31071 L
Mistroke
.28434 .31077 L
.28468 .31079 L
.28506 .31081 L
.28527 .31082 L
.28546 .31083 L
.28564 .31083 L
.28574 .31083 L
.28584 .31084 L
.28589 .31084 L
.28595 .31084 L
.28605 .31084 L
.28611 .31084 L
.28617 .31084 L
.28623 .31084 L
.28629 .31084 L
.28639 .31084 L
.28645 .31084 L
.2865 .31084 L
.2866 .31084 L
.28671 .31083 L
.2869 .31083 L
.28708 .31082 L
.28749 .3108 L
.28787 .31078 L
.28828 .31074 L
.28911 .31064 L
.28988 .31052 L
.2906 .31037 L
.29224 .30993 L
.29373 .3094 L
.29694 .30792 L
.30002 .30627 L
.30159 .30546 L
.30331 .3047 L
.30409 .30442 L
.30494 .30418 L
.30535 .30409 L
.30574 .30402 L
.30609 .30397 L
.30628 .30395 L
.30647 .30393 L
.30657 .30392 L
.30668 .30392 L
.30677 .30391 L
.30687 .30391 L
.30693 .30391 L
.30698 .30391 L
.30705 .30391 L
.3071 .30391 L
.30721 .30391 L
Mistroke
.30726 .30391 L
.30732 .30392 L
.30741 .30392 L
.3075 .30393 L
.3077 .30394 L
.3079 .30396 L
.30812 .30399 L
.3085 .30406 L
.3089 .30416 L
.30961 .30439 L
.31038 .30473 L
.3112 .30519 L
.31267 .3063 L
.31439 .308 L
.316 .30994 L
.31909 .31418 L
.32066 .31634 L
.32238 .31844 L
.32317 .31926 L
.32402 .31998 L
.32443 .32028 L
.32482 .32051 L
.32519 .3207 L
.32555 .32084 L
.32574 .3209 L
.32595 .32095 L
.32604 .32097 L
.32614 .32099 L
.32623 .321 L
.32632 .32101 L
.32642 .32102 L
.32652 .32102 L
.32662 .32102 L
.32671 .32102 L
.32676 .32102 L
.32682 .32101 L
.32692 .321 L
.32702 .32099 L
.32714 .32097 L
.32733 .32093 L
.32751 .32087 L
.3279 .32072 L
.32827 .32052 L
.32862 .32028 L
.32939 .3196 L
.33021 .31861 L
.33168 .31618 L
.3334 .31236 L
.33502 .30797 L
.33811 .29845 L
Mistroke
.33968 .29374 L
.3414 .28927 L
.3422 .28762 L
.34304 .28621 L
.34345 .28567 L
.34384 .28526 L
.34419 .28498 L
.34439 .28486 L
.34457 .28478 L
.34467 .28474 L
.34477 .28471 L
.34485 .28469 L
.34495 .28467 L
.34505 .28466 L
.3451 .28466 L
.34515 .28466 L
.34525 .28466 L
.34535 .28468 L
.34543 .28469 L
.34553 .28472 L
.34569 .28478 L
.34587 .28487 L
.34607 .285 L
.34648 .28537 L
.34693 .28592 L
.34773 .28733 L
.34854 .28931 L
.34942 .29208 L
.35104 .29866 L
.3543 .31657 L
.35745 .33539 L
.35906 .34352 L
.3599 .34697 L
.36036 .34855 L
.36079 .34981 L
.36121 .35083 L
.36159 .35157 L
.36179 .35188 L
.36201 .35216 L
.36214 .35229 L
.36225 .35238 L
.36235 .35246 L
.36247 .35252 L
.36256 .35256 L
.36265 .35258 L
.36274 .3526 L
.36282 .3526 L
.36292 .35259 L
.36301 .35256 L
.36311 .35252 L
Mistroke
.36322 .35247 L
.36332 .35239 L
.36343 .3523 L
.36363 .35207 L
.36401 .35149 L
.3644 .35064 L
.36477 .34963 L
.36561 .34654 L
.36642 .34249 L
.3673 .33706 L
.37062 .30803 L
.37381 .27448 L
.37527 .26058 L
.3761 .25377 L
.37688 .24834 L
.37765 .24412 L
.37808 .24227 L
.37847 .24093 L
.37886 .23995 L
.37908 .23955 L
.37918 .23942 L
.37929 .23929 L
.37935 .23924 L
.3794 .2392 L
.37945 .23916 L
.37951 .23914 L
.37961 .2391 L
.37971 .2391 L
.37977 .2391 L
.37982 .23912 L
.37988 .23914 L
.37994 .23918 L
.38004 .23926 L
.38016 .23938 L
.38036 .23968 L
.38058 .24013 L
.38098 .24128 L
.38138 .24281 L
.38174 .24457 L
.38255 .24986 L
.38342 .25731 L
.385 .27539 L
.38647 .29654 L
.38959 .34789 L
.39118 .37265 L
.39202 .38409 L
.39291 .39445 L
.3937 .40179 L
.39412 .40488 L
.39458 .40753 L
Mistroke
.39478 .40848 L
.39499 .40932 L
.39519 .40994 L
.39537 .41039 L
.39554 .4107 L
.39564 .41082 L
.39572 .41089 L
.39582 .41094 L
.39592 .41096 L
.39602 .41093 L
.39611 .41087 L
.39621 .41077 L
.39631 .41063 L
.39649 .41027 L
.39668 .40974 L
.39689 .40899 L
.39727 .40718 L
.39762 .40498 L
.39842 .39807 L
.39928 .38791 L
.401 .35953 L
.40262 .32526 L
.40572 .25175 L
.40729 .2179 L
.40813 .20276 L
.40902 .18945 L
.40946 .18414 L
.40988 .17997 L
.41025 .17698 L
.41045 .17572 L
.41066 .17457 L
.41086 .17372 L
.41105 .17312 L
.41115 .17288 L
.41124 .1727 L
.4113 .17263 L
.41135 .17256 L
.41146 .1725 L
.41155 .17249 L
.41164 .17253 L
.41174 .17263 L
.41184 .17278 L
.41193 .17296 L
.41201 .17317 L
.41219 .17379 L
.41239 .17466 L
.41257 .17566 L
.41297 .17859 L
.41335 .18215 L
.4137 .18627 L
Mistroke
.4145 .19801 L
.41536 .21455 L
.41695 .25368 L
.41863 .30404 L
.42166 .39843 L
.42321 .43837 L
.42409 .45578 L
.42447 .46208 L
.42489 .46775 L
.4253 .47225 L
.42567 .47532 L
.42585 .47644 L
.42605 .47738 L
.42614 .47772 L
.42623 .47801 L
.42632 .47821 L
.4264 .47837 L
.42646 .47843 L
.42652 .47848 L
.42662 .4785 L
.42672 .47844 L
.42682 .47832 L
.42688 .4782 L
.42693 .47808 L
.42703 .47777 L
.42714 .47736 L
.42726 .47681 L
.42747 .47561 L
.42768 .474 L
.42807 .47024 L
.42846 .46517 L
.42883 .45952 L
.42964 .4434 L
.43112 .4035 L
.43432 .28571 L
.43578 .22906 L
.4374 .17404 L
.43816 .15275 L
.43899 .1343 L
.43944 .12637 L
.43986 .12061 L
.44025 .11652 L
.44045 .11499 L
.44057 .11429 L
.44067 .11374 L
.44077 .11333 L
.44088 .11297 L
.44093 .11283 L
.44098 .11272 L
.44104 .11263 L
Mistroke
.4411 .11257 L
.44115 .11254 L
.44121 .11254 L
.44131 .11261 L
.44141 .11278 L
.4415 .11301 L
.44159 .11331 L
.44167 .11367 L
.44186 .11472 L
.44205 .11607 L
.44225 .11789 L
.44268 .12302 L
.44313 .13023 L
.44393 .14757 L
.4447 .16894 L
.44551 .19647 L
.44699 .25559 L
.45031 .40399 L
.45112 .43628 L
.45198 .46632 L
.45277 .48928 L
.45316 .49856 L
.45352 .50583 L
.45386 .51161 L
.45423 .51661 L
.45443 .51876 L
.45462 .52037 L
.4548 .52156 L
.4549 .52208 L
.45499 .52245 L
.45509 .52276 L
.45514 .52288 L
.45519 .52298 L
.45529 .52306 L
.45539 .52305 L
.45544 .52299 L
.4555 .52291 L
.45559 .52267 L
.45565 .52249 L
.4557 .52229 L
.45582 .52174 L
.456 .52059 L
.4562 .51892 L
.4566 .51423 L
.457 .50798 L
.45741 .49966 L
.45816 .48059 L
.45983 .42039 L
.46289 .27485 L
.46459 .19501 L
Mistroke
.46614 .13659 L
.46692 .11504 L
.46733 .10611 L
.46776 .09859 L
.46813 .09371 L
.46835 .09166 L
.46845 .09086 L
.46855 .09022 L
.46864 .08974 L
.46873 .08931 L
.46882 .08902 L
.4689 .08883 L
.469 .08871 L
.46908 .08869 L
.46918 .08877 L
.46928 .08896 L
.46937 .08926 L
.46947 .08969 L
.46965 .09076 L
.46987 .09254 L
.47007 .09462 L
.47049 .10068 L
.47089 .10829 L
.47161 .12596 L
.47238 .15082 L
.47566 .3007 L
.47728 .38266 L
.47881 .44973 L
.47952 .47519 L
.48027 .49681 L
.48067 .50581 L
.48109 .51368 L
.48128 .51647 L
.48148 .51899 L
.48166 .52076 L
.48185 .52231 L
.48195 .52295 L
.48206 .5235 L
.48211 .52375 L
.48217 .52393 L
.48222 .52408 L
.48228 .52419 L
.48237 .52431 L
.48248 .5243 L
.48257 .52419 L
.48267 .52395 L
.48278 .52357 L
.48289 .523 L
.4831 .52158 L
.48334 .51924 L
Mistroke
.48356 .51646 L
.48394 .51049 L
.48435 .50212 L
.48518 .47974 L
.48675 .42035 L
.48844 .34073 L
.49003 .26126 L
.49176 .18462 L
.49257 .15593 L
.49302 .14275 L
.49343 .13222 L
.49381 .12413 L
.49416 .11816 L
.49455 .11318 L
.49477 .11118 L
.49497 .1098 L
.49507 .10929 L
.49512 .10908 L
.49518 .10889 L
.49528 .10863 L
.49538 .1085 L
.49547 .10848 L
.49555 .10855 L
.49564 .10872 L
.49574 .10901 L
.49585 .10946 L
.49596 .11009 L
.49617 .11164 L
.49637 .11364 L
.49656 .11591 L
.49728 .12817 L
.49764 .13645 L
.49804 .14709 L
.49959 .20155 L
.50127 .27569 L
.50285 .34908 L
.50368 .38537 L
.50457 .41993 L
.50544 .44782 L
.50622 .4673 L
.5066 .47449 L
.50701 .48056 L
.5072 .48273 L
.5074 .48461 L
.50757 .48586 L
.50766 .48639 L
.50775 .48686 L
.50786 .48725 L
.50795 .4875 L
.50801 .4876 L
Mistroke
.50807 .48766 L
.50817 .48768 L
.50827 .48759 L
.50836 .48741 L
.50846 .4871 L
.50857 .48666 L
.50875 .48559 L
.50893 .48426 L
.50932 .48006 L
.50974 .47368 L
.51013 .46631 L
.51099 .44475 L
.51253 .39276 L
.5142 .32478 L
.51576 .26084 L
.51659 .23028 L
.51748 .20195 L
.51833 .18053 L
.51873 .17257 L
.51911 .16654 L
.51948 .16188 L
.51968 .15998 L
.51989 .15838 L
.51999 .1578 L
.52009 .15727 L
.52018 .1569 L
.52028 .1566 L
.52037 .15641 L
.52047 .15629 L
.52055 .15626 L
.52064 .1563 L
.52074 .15645 L
.52079 .15656 L
.52084 .15672 L
.52094 .15707 L
.52104 .15749 L
.52125 .15874 L
.52147 .16057 L
.52189 .16518 L
.52227 .17078 L
.52299 .18489 L
.52376 .20404 L
.52682 .30685 L
.52852 .36484 L
.52933 .38812 L
.53007 .40604 L
.53084 .4204 L
.53125 .42605 L
.53146 .4284 L
.53168 .43051 L
Mistroke
.53188 .43201 L
.53206 .43309 L
.53214 .43351 L
.53224 .4339 L
.53232 .43419 L
.53241 .43441 L
.53251 .43459 L
.53261 .43468 L
.53271 .43468 L
.53277 .43465 L
.53282 .43459 L
.53291 .43443 L
.53301 .43419 L
.53311 .43384 L
.5332 .43344 L
.53341 .43229 L
.53361 .43091 L
.53404 .42666 L
.53443 .42169 L
.53484 .41522 L
.53633 .38294 L
.53936 .29559 L
.54019 .27271 L
.54105 .25126 L
.54185 .23467 L
.54224 .22794 L
.54259 .22267 L
.54294 .21835 L
.54331 .21459 L
.54352 .21295 L
.54371 .2117 L
.54389 .21075 L
.54408 .21 L
.54418 .20971 L
.54427 .20951 L
.54432 .20943 L
.54438 .20936 L
.54448 .20928 L
.54457 .20928 L
.54467 .20935 L
.54476 .20947 L
.54485 .20966 L
.54496 .20995 L
.54506 .2103 L
.54529 .21134 L
.54549 .21255 L
.5457 .21412 L
.54647 .22215 L
.5469 .22814 L
.54729 .23443 L
Mistroke
.54876 .2639 L
.55043 .30302 L
.55196 .33788 L
.55346 .36501 L
.55422 .37482 L
.55465 .37904 L
.55486 .38072 L
.55505 .38206 L
.55526 .38326 L
.55545 .38413 L
.55566 .38486 L
.55577 .38515 L
.55583 .38525 L
.55588 .38535 L
.55598 .38547 L
.55608 .38554 L
.55618 .38555 L
.55626 .38551 L
.55637 .38541 L
.55646 .38527 L
.55657 .38504 L
.55667 .38476 L
.55685 .38413 L
.55704 .38328 L
.55739 .38126 L
.55776 .37842 L
.55816 .37453 L
.55972 .35353 L
.56139 .32413 L
.56297 .29568 L
.5638 .2822 L
.56469 .27 L
.56514 .26495 L
.56556 .26091 L
.56596 .25768 L
.56634 .25534 L
.5667 .25371 L
.56688 .2531 L
.56708 .2526 L
.56718 .25241 L
.56728 .25228 L
.56733 .25223 L
.56738 .25218 L
.56749 .25213 L
.56759 .25213 L
.56769 .25218 L
.56779 .25226 L
.56787 .25238 L
.56797 .25254 L
.56806 .25273 L
Mistroke
.56827 .25329 L
.56847 .25401 L
.56868 .25495 L
.56942 .2596 L
.56987 .26337 L
.5703 .26752 L
.5711 .27653 L
.57418 .31769 L
.57577 .33567 L
.57657 .34235 L
.57703 .34527 L
.57746 .3474 L
.57785 .34882 L
.57808 .34939 L
.57819 .3496 L
.57829 .34976 L
.57838 .34988 L
.57849 .34998 L
.57858 .35003 L
.57867 .35006 L
.57877 .35006 L
.57887 .35002 L
.57892 .34999 L
.57898 .34994 L
.57908 .34984 L
.57918 .3497 L
.57927 .34955 L
.57948 .3491 L
.57986 .34794 L
.5802 .34652 L
.58057 .34465 L
.58132 .33976 L
.58213 .33319 L
.58359 .31919 L
.58517 .30369 L
.586 .29633 L
.58689 .28969 L
.58734 .28696 L
.58776 .28479 L
.58816 .28307 L
.58854 .28183 L
.5889 .28098 L
.58908 .28068 L
.58918 .28054 L
.58928 .28043 L
.58938 .28034 L
.58947 .28028 L
.58958 .28024 L
.58963 .28023 L
.58969 .28023 L
Mistroke
.58979 .28024 L
.58987 .28028 L
.58998 .28034 L
.59007 .28042 L
.59027 .28064 L
.59045 .28093 L
.59086 .28186 L
.59126 .28311 L
.59169 .2848 L
.59317 .29288 L
.59476 .30379 L
.59649 .3155 L
.5973 .32011 L
.59816 .32406 L
.59889 .32652 L
.59909 .32703 L
.5993 .32751 L
.59951 .32789 L
.59969 .32817 L
.59989 .32839 L
.59999 .32849 L
.60009 .32856 L
.60018 .32861 L
.60027 .32864 L
.60036 .32867 L
.60046 .32867 L
.60056 .32866 L
.60062 .32865 L
.60067 .32863 L
.60077 .32859 L
.60086 .32853 L
.60107 .32835 L
.6013 .32807 L
.60173 .32733 L
.60218 .32625 L
.603 .32366 L
.60472 .3162 L
.60634 .30839 L
.60782 .30211 L
.60866 .29937 L
.60907 .2983 L
.60944 .29749 L
.60984 .29681 L
.61022 .29634 L
.61043 .29616 L
.61062 .29604 L
.61072 .296 L
.61077 .29598 L
.61083 .29596 L
.61088 .29595 L
Mistroke
.61094 .29594 L
.611 .29593 L
.61105 .29593 L
.6111 .29593 L
.61116 .29594 L
.61125 .29596 L
.61136 .29599 L
.61147 .29604 L
.61167 .29616 L
.61186 .29631 L
.61229 .29681 L
.61274 .29753 L
.6135 .29916 L
.61432 .30135 L
.61579 .30598 L
.61738 .311 L
.61822 .31329 L
.61911 .31526 L
.61949 .31593 L
.6199 .31652 L
.62013 .3168 L
.62035 .31701 L
.62057 .31719 L
.62077 .31733 L
.62094 .31741 L
.62104 .31745 L
.62113 .31748 L
.62122 .3175 L
.62133 .31751 L
.62143 .31752 L
.62152 .31752 L
.62161 .31751 L
.6217 .3175 L
.6218 .31748 L
.6219 .31745 L
.62211 .31736 L
.62231 .31724 L
.62269 .31694 L
.6231 .31652 L
.62383 .3155 L
.6255 .31236 L
.6271 .30896 L
.62795 .30731 L
.62884 .30582 L
.62964 .30477 L
.63009 .30432 L
.63052 .304 L
.63072 .30388 L
.63091 .30379 L
.63108 .30372 L
Mistroke
.63126 .30367 L
.63136 .30365 L
.63146 .30363 L
.63152 .30363 L
.63157 .30362 L
.63168 .30362 L
.63177 .30362 L
.63188 .30362 L
.63196 .30363 L
.63206 .30365 L
.63217 .30367 L
.63226 .30369 L
.63249 .30377 L
.63268 .30385 L
.63289 .30396 L
.63364 .30451 L
.63444 .30532 L
.63532 .3064 L
.63701 .30869 L
.63856 .31058 L
.63933 .31131 L
.63973 .31163 L
.64016 .31191 L
.64054 .3121 L
.64074 .31218 L
.64095 .31225 L
.64115 .3123 L
.64123 .31232 L
.64133 .31234 L
.64141 .31235 L
.6415 .31236 L
.64159 .31237 L
.64168 .31237 L
.64178 .31237 L
.64184 .31237 L
.64189 .31237 L
.642 .31237 L
.64205 .31236 L
.64211 .31236 L
.64221 .31235 L
.64231 .31233 L
.6425 .31229 L
.64273 .31223 L
.64296 .31216 L
.64339 .31197 L
.64424 .31149 L
.64501 .31093 L
.64669 .30952 L
.64823 .30829 L
.64901 .30779 L
Mistroke
.64973 .30741 L
.6501 .30727 L
.65049 .30714 L
.65072 .30709 L
.65093 .30705 L
.65112 .30702 L
.65122 .307 L
.65132 .30699 L
.65142 .30699 L
.65151 .30698 L
.65161 .30698 L
.65171 .30697 L
.6518 .30697 L
.6519 .30698 L
.652 .30698 L
.65208 .30699 L
.65219 .30699 L
.65228 .307 L
.65251 .30703 L
.6527 .30707 L
.65291 .30711 L
.65372 .30735 L
.6546 .30771 L
.65629 .30857 L
.65784 .30934 L
.6586 .30966 L
.65901 .30981 L
.65944 .30994 L
.65985 .31004 L
.66023 .31012 L
.66041 .31015 L
.6606 .31018 L
.66079 .3102 L
.66096 .31021 L
.66105 .31022 L
.66115 .31023 L
.66125 .31023 L
.66135 .31023 L
.66145 .31024 L
.66154 .31024 L
.66163 .31024 L
.66172 .31023 L
.66178 .31023 L
.66183 .31023 L
.66193 .31023 L
.66204 .31022 L
.66215 .31021 L
.66237 .31019 L
.66256 .31017 L
.66299 .31011 L
Mistroke
.66338 .31003 L
.66425 .30982 L
.66593 .30932 L
.66747 .30885 L
.66825 .30865 L
.66897 .3085 L
.66937 .30844 L
.66973 .30839 L
.67013 .30835 L
.67035 .30833 L
.67056 .30832 L
.67065 .30832 L
.67075 .30831 L
.67084 .30831 L
.67093 .30831 L
.67103 .3083 L
.67109 .3083 L
.67114 .3083 L
.67123 .3083 L
.67134 .3083 L
.67139 .30831 L
.67144 .30831 L
.67156 .30831 L
.67166 .30831 L
.67177 .30832 L
.67195 .30833 L
.67216 .30834 L
.67253 .30837 L
.67292 .30841 L
.67364 .30851 L
.67522 .30878 L
.67695 .30909 L
.67775 .30922 L
.67819 .30927 L
.6786 .30932 L
.67899 .30936 L
.67941 .30939 L
.67959 .3094 L
.67979 .30941 L
.67996 .30941 L
.68014 .30942 L
.68025 .30942 L
.68034 .30942 L
.68044 .30943 L
.68054 .30943 L
.68063 .30943 L
.68071 .30943 L
.6808 .30943 L
.6809 .30943 L
.681 .30942 L
Mistroke
.68106 .30942 L
.68111 .30942 L
.68133 .30942 L
.68152 .30941 L
.68172 .3094 L
.68211 .30938 L
.68249 .30936 L
.68319 .3093 L
.68628 .30899 L
.68711 .30891 L
.68788 .30886 L
.6883 .30883 L
.68868 .30881 L
.68911 .3088 L
.68934 .30879 L
.68945 .30879 L
.68957 .30879 L
.68967 .30879 L
.68976 .30879 L
.68984 .30879 L
.68994 .30879 L
.69004 .30879 L
.69013 .30879 L
.69023 .30879 L
.69029 .30879 L
.69034 .30879 L
.69045 .30879 L
.69054 .30879 L
.69076 .30879 L
.69096 .3088 L
.69116 .3088 L
.69187 .30882 L
.69264 .30886 L
.69433 .30896 L
.69588 .30905 L
.69664 .30909 L
.69704 .3091 L
.69747 .30912 L
.69788 .30913 L
.69826 .30914 L
.69844 .30914 L
.69863 .30914 L
.69882 .30914 L
.69899 .30914 L
.69909 .30914 L
.69918 .30915 L
.69927 .30915 L
.69936 .30915 L
.69947 .30915 L
.69952 .30915 L
Mistroke
.69957 .30915 L
.69968 .30914 L
.69977 .30914 L
.69995 .30914 L
.70012 .30914 L
.7005 .30914 L
.70088 .30913 L
.70131 .30912 L
.70216 .3091 L
.70386 .30904 L
.70541 .30899 L
.70619 .30897 L
.7066 .30896 L
.70703 .30896 L
.7074 .30895 L
.70762 .30895 L
.70782 .30895 L
.708 .30895 L
.70809 .30895 L
.70817 .30895 L
.70826 .30895 L
.70836 .30895 L
.70845 .30895 L
.70855 .30895 L
.70865 .30895 L
.70871 .30895 L
.70876 .30895 L
.70887 .30895 L
.70898 .30895 L
.70919 .30895 L
.70938 .30895 L
.70984 .30895 L
.71027 .30896 L
.71189 .30898 L
.71336 .30901 L
.71419 .30903 L
.71497 .30904 L
.71574 .30905 L
.71617 .30905 L
.71637 .30905 L
.71656 .30905 L
.71677 .30905 L
.71696 .30905 L
.71706 .30905 L
.71716 .30905 L
.71722 .30905 L
.71728 .30905 L
.71733 .30905 L
.71739 .30905 L
.71749 .30905 L
Mistroke
.71759 .30905 L
.71764 .30905 L
.7177 .30905 L
.71781 .30905 L
.71786 .30905 L
.71792 .30905 L
.71802 .30905 L
.71825 .30905 L
.71844 .30905 L
.71864 .30905 L
.719 .30905 L
.71981 .30904 L
.72128 .30903 L
.72288 .30901 L
.72358 .30901 L
.72433 .309 L
.72476 .309 L
.72514 .309 L
.72551 .309 L
.7257 .309 L
.72591 .309 L
.72602 .309 L
.72613 .309 L
.72622 .309 L
.72633 .309 L
.72639 .309 L
.72644 .309 L
.7265 .309 L
.72656 .309 L
.72666 .309 L
.72672 .309 L
.72678 .309 L
.72687 .309 L
.72696 .309 L
.72717 .309 L
.72737 .309 L
.72759 .309 L
.72841 .309 L
.7293 .30901 L
.73091 .30901 L
.73247 .30902 L
.73289 .30902 L
.73335 .30902 L
.73375 .30903 L
.73396 .30903 L
.73419 .30903 L
.7344 .30903 L
.7346 .30903 L
.7347 .30903 L
.7348 .30903 L
Mistroke
.7349 .30903 L
.73499 .30903 L
.73509 .30903 L
.73514 .30903 L
.7352 .30903 L
.73526 .30903 L
.73532 .30903 L
.73537 .30903 L
.73543 .30903 L
.73553 .30903 L
.73559 .30903 L
.73564 .30903 L
.73583 .30903 L
.73593 .30903 L
.73603 .30903 L
.73621 .30903 L
.73661 .30903 L
.73734 .30902 L
.74039 .30902 L
.7412 .30901 L
.74196 .30901 L
.74239 .30901 L
.74261 .30901 L
.74284 .30901 L
.74304 .30901 L
.74326 .30901 L
.74346 .30901 L
.74356 .30901 L
.74365 .30901 L
.74375 .30901 L
.7438 .30901 L
.74385 .30901 L
.74394 .30901 L
.74404 .30901 L
.7441 .30901 L
.74415 .30901 L
.74421 .30901 L
.74427 .30901 L
.74437 .30901 L
.74448 .30901 L
.74469 .30901 L
.74489 .30901 L
.74527 .30901 L
.74598 .30901 L
.74676 .30901 L
.74831 .30902 L
.74914 .30902 L
.75003 .30902 L
.75044 .30902 L
.75088 .30902 L
Mistroke
.75125 .30902 L
.75146 .30902 L
.75165 .30902 L
.75184 .30902 L
.75204 .30902 L
.75215 .30902 L
.75225 .30902 L
.75234 .30902 L
.75245 .30902 L
.75253 .30902 L
.75263 .30902 L
.75271 .30902 L
.7528 .30902 L
.75289 .30902 L
.75299 .30902 L
.75309 .30902 L
.75318 .30902 L
.75339 .30902 L
.75359 .30902 L
.75403 .30902 L
.75483 .30902 L
.75633 .30902 L
.75712 .30902 L
.75797 .30902 L
.7587 .30902 L
.7595 .30902 L
.75993 .30902 L
.76011 .30902 L
.76032 .30902 L
.76051 .30902 L
.7607 .30902 L
.7608 .30902 L
.76089 .30902 L
.76099 .30902 L
.76104 .30902 L
.7611 .30902 L
.76119 .30902 L
.76129 .30902 L
.76137 .30902 L
.76146 .30902 L
.76156 .30902 L
.76166 .30902 L
.76185 .30902 L
.76218 .30902 L
.76255 .30902 L
.76337 .30902 L
.76411 .30902 L
.76579 .30902 L
.76653 .30902 L
.76732 .30902 L
Mistroke
.76773 .30902 L
.76819 .30902 L
.76838 .30902 L
.7686 .30902 L
.7688 .30902 L
.76899 .30902 L
.76918 .30902 L
.76928 .30902 L
.76938 .30902 L
.76948 .30902 L
.76956 .30902 L
.76965 .30902 L
.76975 .30902 L
.76985 .30902 L
.76991 .30902 L
.76996 .30902 L
.77015 .30902 L
.77026 .30902 L
.77038 .30902 L
.77059 .30902 L
.77102 .30902 L
.77147 .30902 L
.77229 .30902 L
.77389 .30902 L
.77473 .30902 L
.77562 .30902 L
.77601 .30902 L
.77642 .30902 L
.77666 .30902 L
.77688 .30902 L
.7771 .30902 L
.7773 .30902 L
.77748 .30902 L
.77758 .30902 L
.77768 .30902 L
.77778 .30902 L
.77784 .30902 L
.77789 .30902 L
.77799 .30902 L
.77809 .30902 L
.77818 .30902 L
.77828 .30902 L
.77837 .30902 L
.77845 .30902 L
.77865 .30902 L
.77884 .30902 L
.77921 .30902 L
.77962 .30902 L
.78045 .30902 L
.78193 .30902 L
Mistroke
.7828 .30902 L
.78362 .30902 L
.78436 .30902 L
.78478 .30902 L
.78517 .30902 L
.78537 .30902 L
.78558 .30902 L
.78568 .30902 L
.78578 .30902 L
.78587 .30902 L
.78596 .30902 L
.78606 .30902 L
.78614 .30902 L
.78622 .30902 L
.7863 .30902 L
.7864 .30902 L
.78648 .30902 L
.78658 .30902 L
.78668 .30902 L
.78687 .30902 L
.78707 .30902 L
.78744 .30902 L
.78788 .30902 L
.78829 .30902 L
.78994 .30902 L
.79074 .30902 L
.79147 .30902 L
.79219 .30902 L
.79256 .30902 L
.79296 .30902 L
.79316 .30902 L
.79338 .30902 L
.79358 .30902 L
.79377 .30902 L
.79396 .30902 L
.79407 .30902 L
.79417 .30902 L
.79426 .30902 L
.79434 .30902 L
.79444 .30902 L
.79454 .30902 L
.79463 .30902 L
.79473 .30902 L
.79483 .30902 L
.79493 .30902 L
.7951 .30902 L
.79529 .30902 L
.79571 .30902 L
.7961 .30902 L
.79757 .30902 L
Mistroke
.79923 .30902 L
.79997 .30902 L
.80036 .30902 L
.80077 .30902 L
.80118 .30902 L
.80155 .30902 L
.80173 .30902 L
.80192 .30902 L
.80201 .30902 L
.8021 .30902 L
.80219 .30902 L
.80227 .30902 L
.80237 .30902 L
.80248 .30902 L
.80257 .30902 L
.80267 .30902 L
.80277 .30902 L
.80283 .30902 L
.80288 .30902 L
.80309 .30902 L
.80328 .30902 L
.80349 .30902 L
.80386 .30902 L
.80462 .30902 L
.80545 .30902 L
.80714 .30902 L
.80789 .30902 L
.80869 .30902 L
.80911 .30902 L
.80933 .30902 L
.80956 .30902 L
.80978 .30902 L
.80998 .30902 L
.81008 .30902 L
.81018 .30902 L
.81028 .30902 L
.81037 .30902 L
.81047 .30902 L
.81056 .30902 L
.81065 .30902 L
.81074 .30902 L
.81084 .30902 L
.81095 .30902 L
.81114 .30902 L
.81132 .30902 L
.81149 .30902 L
.81187 .30902 L
.81267 .30902 L
.81353 .30902 L
.81511 .30902 L
Mistroke
.81594 .30902 L
.8164 .30902 L
.81683 .30902 L
.81724 .30902 L
.81747 .30902 L
.81769 .30902 L
.81787 .30902 L
.81798 .30902 L
.81807 .30902 L
.81817 .30902 L
.81823 .30902 L
.81828 .30902 L
.81837 .30902 L
.81847 .30902 L
.81858 .30902 L
.81868 .30902 L
.81876 .30902 L
.81886 .30902 L
.81907 .30902 L
.81927 .30902 L
.81963 .30902 L
.82001 .30902 L
.82158 .30902 L
.82305 .30902 L
.82389 .30902 L
.82431 .30902 L
.82469 .30902 L
.82503 .30902 L
.8254 .30902 L
.82559 .30902 L
.82577 .30902 L
.82587 .30902 L
.82597 .30902 L
.82607 .30902 L
.82612 .30902 L
.82618 .30902 L
.82628 .30902 L
.82638 .30902 L
.82643 .30902 L
.82649 .30902 L
.82655 .30902 L
.8266 .30902 L
.8267 .30902 L
.82679 .30902 L
.827 .30902 L
.82719 .30902 L
.82739 .30902 L
.82775 .30902 L
.82862 .30902 L
.82943 .30902 L
Mistroke
.83094 .30902 L
.8318 .30902 L
.8322 .30902 L
.83258 .30902 L
.83298 .30902 L
.83319 .30902 L
.83342 .30902 L
.83353 .30902 L
.83365 .30902 L
.83371 .30902 L
.83377 .30902 L
.83382 .30902 L
.83388 .30902 L
.83398 .30902 L
.83408 .30902 L
.83413 .30902 L
.83419 .30902 L
.8343 .30902 L
.8344 .30902 L
.83449 .30902 L
.8347 .30902 L
.83489 .30902 L
.83507 .30902 L
.83548 .30902 L
.83592 .30902 L
.83749 .30902 L
.83832 .30902 L
.83921 .30902 L
.83965 .30902 L
.84006 .30902 L
.84044 .30902 L
.84063 .30902 L
.84085 .30902 L
.84103 .30902 L
.84123 .30902 L
.84134 .30902 L
.84144 .30902 L
.84154 .30902 L
.84164 .30902 L
.84173 .30902 L
.84182 .30902 L
.84191 .30902 L
.84199 .30902 L
.84209 .30902 L
.84219 .30902 L
.84229 .30902 L
.84238 .30902 L
.84275 .30902 L
.84296 .30902 L
.84315 .30902 L
Mistroke
.84388 .30902 L
.84554 .30902 L
.84627 .30902 L
.84706 .30902 L
.84751 .30902 L
.84792 .30902 L
.84812 .30902 L
.84834 .30902 L
.84854 .30902 L
.84872 .30902 L
.84892 .30902 L
.84902 .30902 L
.84912 .30902 L
.84921 .30902 L
.8493 .30902 L
.84939 .30902 L
.84949 .30902 L
.84959 .30902 L
.84964 .30902 L
.84969 .30902 L
.84979 .30902 L
.84989 .30902 L
.8501 .30902 L
.85033 .30902 L
.85075 .30902 L
.8512 .30902 L
.85202 .30902 L
.85362 .30902 L
.85446 .30902 L
.85492 .30902 L
.85535 .30902 L
.85573 .30902 L
.85593 .30902 L
.85615 .30902 L
.85627 .30902 L
.85638 .30902 L
.8565 .30902 L
.8566 .30902 L
.85671 .30902 L
.85681 .30902 L
.85691 .30902 L
.85697 .30902 L
.85702 .30902 L
.85711 .30902 L
.85721 .30902 L
.8573 .30902 L
.85738 .30902 L
.85748 .30902 L
.85758 .30902 L
.85777 .30902 L
Mistroke
.85818 .30902 L
.85856 .30902 L
.86019 .30902 L
.86099 .30902 L
.86172 .30902 L
.86247 .30902 L
.86281 .30902 L
.86318 .30902 L
.86339 .30902 L
.86357 .30902 L
.86376 .30902 L
.86393 .30902 L
.86403 .30902 L
.86414 .30902 L
.86424 .30902 L
.8643 .30902 L
.86436 .30902 L
.86446 .30902 L
.86455 .30902 L
.86465 .30902 L
.86475 .30902 L
.86485 .30902 L
.86494 .30902 L
.86512 .30902 L
.86533 .30902 L
.86553 .30902 L
.86593 .30902 L
.86635 .30902 L
.86783 .30902 L
.86865 .30902 L
.86943 .30902 L
.87013 .30902 L
.87053 .30902 L
.87089 .30902 L
.87106 .30902 L
.87125 .30902 L
.87136 .30902 L
.87146 .30902 L
.87155 .30902 L
.87165 .30902 L
.87176 .30902 L
.87185 .30902 L
.87191 .30902 L
.87196 .30902 L
.87207 .30902 L
.87217 .30902 L
.87226 .30902 L
.87236 .30902 L
.87246 .30902 L
.87266 .30902 L
Mistroke
.87288 .30902 L
.87326 .30902 L
.87414 .30902 L
.87574 .30902 L
.87658 .30902 L
.87704 .30902 L
.87747 .30902 L
.87788 .30902 L
.87826 .30902 L
.87846 .30902 L
.87868 .30902 L
.87889 .30902 L
.87902 .30902 L
.87908 .30902 L
.87913 .30902 L
.87923 .30902 L
.87933 .30902 L
.87942 .30902 L
.87952 .30902 L
.87961 .30902 L
.87969 .30902 L
.87978 .30902 L
.87987 .30902 L
.88009 .30902 L
.88029 .30902 L
.88067 .30902 L
.88144 .30902 L
.88226 .30902 L
.88374 .30902 L
.88449 .30902 L
.88489 .30902 L
.8853 .30902 L
.88567 .30902 L
.88587 .30902 L
.88607 .30902 L
.88624 .30902 L
.88633 .30902 L
.88641 .30902 L
.88649 .30902 L
.88659 .30902 L
.88668 .30902 L
.88677 .30902 L
.88686 .30902 L
.88697 .30902 L
.88707 .30902 L
.88716 .30902 L
.88734 .30902 L
.88752 .30902 L
.88795 .30902 L
.88834 .30902 L
Mistroke
.88981 .30902 L
.89062 .30902 L
.89148 .30902 L
.89222 .30902 L
.89263 .30902 L
.89302 .30902 L
.89321 .30902 L
.89332 .30902 L
.89342 .30902 L
.89352 .30902 L
.89362 .30902 L
.89372 .30902 L
.8938 .30902 L
.89389 .30902 L
.89398 .30902 L
.89406 .30902 L
.89415 .30902 L
.89424 .30902 L
.89434 .30902 L
.89443 .30902 L
.89452 .30902 L
.89472 .30902 L
.89491 .30902 L
.89534 .30902 L
.89612 .30902 L
.89775 .30902 L
.89855 .30902 L
.89928 .30902 L
.89964 .30902 L
.90003 .30902 L
.90021 .30902 L
.9004 .30902 L
.90058 .30902 L
.90075 .30902 L
.90085 .30902 L
.90095 .30902 L
.90104 .30902 L
.90114 .30902 L
.90124 .30902 L
.9013 .30902 L
.90136 .30902 L
.90146 .30902 L
.90156 .30902 L
.90165 .30902 L
.90175 .30902 L
.90193 .30902 L
.90232 .30902 L
.90272 .30902 L
.90308 .30902 L
.90389 .30902 L
Mistroke
.90536 .30902 L
.90609 .30902 L
.9065 .30902 L
.90688 .30902 L
.9071 .30902 L
.90733 .30902 L
.90753 .30902 L
.90774 .30902 L
.90795 .30902 L
.90806 .30902 L
.90816 .30902 L
.90826 .30902 L
.90834 .30902 L
.90845 .30902 L
.90854 .30902 L
.90863 .30902 L
.90873 .30902 L
.90883 .30902 L
.90891 .30902 L
.90911 .30902 L
.90932 .30902 L
.90971 .30902 L
.91014 .30902 L
.91162 .30902 L
.91243 .30902 L
.91319 .30902 L
.91361 .30902 L
.91407 .30902 L
.91427 .30902 L
.91449 .30902 L
.91467 .30902 L
.91487 .30902 L
.91498 .30902 L
.91507 .30902 L
.91517 .30902 L
.91527 .30902 L
.91536 .30902 L
.91546 .30902 L
.91554 .30902 L
.91563 .30902 L
.91573 .30902 L
.91578 .30902 L
.91583 .30902 L
.91605 .30902 L
.91624 .30902 L
.91644 .30902 L
.91684 .30902 L
.91721 .30902 L
.91791 .30902 L
.91938 .30902 L
Mistroke
.92021 .30902 L
.92062 .30902 L
.92099 .30902 L
.92136 .30902 L
.92155 .30902 L
.92175 .30902 L
.92196 .30902 L
.92205 .30902 L
.92215 .30902 L
.92221 .30902 L
.92226 .30902 L
.92232 .30902 L
.92237 .30902 L
.92247 .30902 L
.92258 .30902 L
.92263 .30902 L
.92269 .30902 L
.92275 .30902 L
.9228 .30902 L
.9229 .30902 L
.923 .30902 L
.92324 .30902 L
.92345 .30902 L
.92387 .30902 L
.92427 .30902 L
.92575 .30902 L
.92658 .30902 L
.92737 .30902 L
.92777 .30902 L
.92814 .30902 L
.92835 .30902 L
.92858 .30902 L
.92878 .30902 L
.92897 .30902 L
.92907 .30902 L
.92917 .30902 L
.92927 .30902 L
.92936 .30902 L
.92947 .30902 L
.92953 .30902 L
.92958 .30902 L
.92969 .30902 L
.92974 .30902 L
.92979 .30902 L
.92991 .30902 L
.93001 .30902 L
.93024 .30902 L
.93045 .30902 L
.93066 .30902 L
.93142 .30902 L
Mistroke
.93224 .30902 L
.93371 .30902 L
.93453 .30902 L
.93499 .30902 L
.93521 .30902 L
.93542 .30902 L
.93561 .30902 L
.93579 .30902 L
.93599 .30902 L
.93609 .30902 L
.93615 .30902 L
.9362 .30902 L
.9363 .30902 L
.93635 .30902 L
.93641 .30902 L
.9365 .30902 L
.9366 .30902 L
.93665 .30902 L
.93671 .30902 L
.93677 .30902 L
.93682 .30902 L
.93692 .30902 L
.93703 .30902 L
.93724 .30902 L
.93743 .30902 L
.93787 .30902 L
.93866 .30902 L
.94015 .30902 L
.94098 .30902 L
.94141 .30902 L
.94187 .30902 L
.94227 .30902 L
.9425 .30902 L
.94271 .30902 L
.94281 .30902 L
.94291 .30902 L
.943 .30902 L
.94309 .30902 L
.94319 .30902 L
.94328 .30902 L
.94338 .30902 L
.94344 .30902 L
.94349 .30902 L
.94358 .30902 L
.94369 .30902 L
.94378 .30902 L
.94387 .30902 L
.94408 .30902 L
.94428 .30902 L
.94468 .30902 L
Mistroke
.94511 .30902 L
.9466 .30902 L
.94742 .30902 L
.9482 .30902 L
.94859 .30902 L
.949 .30902 L
.94924 .30902 L
.94946 .30902 L
.94967 .30902 L
.94978 .30902 L
.94989 .30902 L
.94998 .30902 L
.95008 .30902 L
.95017 .30902 L
.95026 .30902 L
.95036 .30902 L
.95041 .30902 L
.95047 .30902 L
.95056 .30902 L
.95066 .30902 L
.95084 .30902 L
.95101 .30902 L
.95138 .30902 L
.95219 .30902 L
.95304 .30902 L
.95385 .30902 L
.95462 .30902 L
.95532 .30902 L
.95571 .30902 L
.95607 .30902 L
.95628 .30902 L
.95647 .30902 L
.95664 .30902 L
.95674 .30902 L
.95683 .30902 L
.95693 .30902 L
.95702 .30902 L
.95711 .30902 L
.95722 .30902 L
.95727 .30902 L
.95733 .30902 L
.95744 .30902 L
.95763 .30902 L
.95783 .30902 L
.95806 .30902 L
.9585 .30902 L
.95931 .30902 L
.96013 .30902 L
.96099 .30902 L
.96173 .30902 L
Mistroke
.96215 .30902 L
.96254 .30902 L
.96273 .30902 L
.96294 .30902 L
.96314 .30902 L
.96324 .30902 L
.96332 .30902 L
.96341 .30902 L
.96349 .30902 L
.96358 .30902 L
.96367 .30902 L
.96376 .30902 L
.96386 .30902 L
.96395 .30902 L
.96404 .30902 L
.96414 .30902 L
.96425 .30902 L
.96445 .30902 L
.96464 .30902 L
.96482 .30902 L
.96564 .30902 L
.96729 .30902 L
.96809 .30902 L
.96882 .30902 L
.96918 .30902 L
.96937 .30902 L
.96958 .30902 L
.96975 .30902 L
.96985 .30902 L
.96995 .30902 L
.97004 .30902 L
.97013 .30902 L
.97021 .30902 L
.97029 .30902 L
.97039 .30902 L
.97048 .30902 L
.97059 .30902 L
.97069 .30902 L
.97078 .30902 L
.97086 .30902 L
.97105 .30902 L
.97124 .30902 L
.97145 .30902 L
.97187 .30902 L
.97357 .30902 L
.97436 .30902 L
.97512 .30902 L
.97563 .30902 L
.97592 .30902 L
.97619 .30902 L
Mistroke
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{421.375, 260.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008>0001AB000`400?l00000o`00003ooooooooo
oooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo
003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooo
oooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool0
0?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooooooo
ool@ooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooo
ooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo0ol0003o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0
003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo
00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`
ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLoooo
o`00<?ooool3o`000?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?oo
ool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0
033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomco
oooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooo
oooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool3o`000?oooooo
g?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0013ooooo0_o^k^h3ooooo`;ok^k^6Oooool00ol0003oooooooooo`3o
ooooomcooooo000;ooooo`;o000000[o410@ooooooooooook^k^oeEEEOo^k^koooooonk^k_mEEEGo
k^k^0oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h:ooooo`03o`000?oo
oooooooo0?oooooog?ooool000cooooo00?o0000ooooooooool00_ooool01Oo^k^koEEEEomgMgOmE
EEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00[ooooo
00?o0000ooooooooool0oooooooLooooo`0000?oooooo`000?l000001?l00002ooooo`Go00001?oo
ool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooo
oa0@400:ooooo`03o`000?oooooooooo09Wooooo00?o0000ooooooooool0oooooom0ooooo`002Ooo
ool01?m4A4CogMgMooooool00004ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000002_ooool00ol0003oooooooooo`2Ioooo
o`03o`000?oooooooooo0?oooooo@?ooool000Wooooo00CogMgMoeEEEOoooooo00000oooool01oo^
k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000002_ooool4o`0009Oooooo0_l0003ooooood;ooooo000:ooooo`03ogMgMoo<
c<co000000?ooooo0_o^k^h3ooooo`;ok^k^1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oo
ooooooooooooool@41002_ooool00ol0003oooooooooo`2Hooooo`;o0000oooooom2ooooo`002_oo
ool00oo^k^koA4A4o`00000?ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`;o00001Oooool00ol0003oooooooooo`2Hooooo`;o0000oooooom2ooooo`002ooo
ool00omgMgOo0000ooooo`0<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP02ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0V?ooool2o`000?oo
oooo@_ooool002Sooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`2Hooooo`;o
0000oooooom2ooooo`00:?ooool3o`0000Gooooo00?o0000ooooooooool0V?ooool2o`000?oooooo
@_ooool002Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2Hooooo`03o`000?oo
oooo00000?oooooo@Oooool002[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2H
ooooo`03o`000?oooooo000000Wooooo00?o0000ooooooooool0ooooooleooooo`00<?ooool00ol0
003oooooooooo`2Hooooo`03o`000?oooooo000000Wooooo00?o0000ooooooooool0ooooooleoooo
o`00<?ooool00ol0003oooooooooo`2=ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooool0
00002Oooool2o`000?oooooo=_ooool0033ooooo00?o0000ooooooooool0S?ooool2o`0000[ooooo
00?o0000ooooool000002Oooool2o`000?oooooo=_ooool0033ooooo00?o0000ooooooooool0S?oo
ool2o`0000[ooooo00?o0000ooooool000002Oooool2o`000?oooooo=_ooool0033ooooo0ol0002<
ooooo`;o00002_ooool00ol0003oooooo`000009ooooo`;o0000oooooolfooooo`00<?ooool00ol0
003oooooooooo`2<ooooo`;o00002_ooool00ol0003oooooo`000009ooooo`;o0000oooooolfoooo
o`00<?ooool00ol0003oooooooooo`2<ooooo`;o00002_ooool00ol0003oooooo`000009ooooo`;o
0000oooooolfooooo`00<?ooool00ol0003oooooooooo`2<ooooo`;o00002_ooool00ol0003ooooo
o`000009ooooo`;o0000oooooolfooooo`00<?ooool00ol0003oooooooooo`2<ooooo`03o`000?oo
oooo000000Wooooo00?o0000ooooool000002Oooool2o`000?oooooo=_ooool0033ooooo00?o0000
ooooooooool0S?ooool00ol0003oooooo`000009ooooo`03o`000?oooooo000000Sooooo00?o0000
ooooool00000oooooolfooooo`00<?ooool00ol0003oooooooooo`2<ooooo`03o`000?oooooo0000
00Wooooo00?o0000ooooool000002?ooool00ol0003oooooo`00003oooooocKooooo000`ooooo`03
o`000?oooooooooo08cooooo00?o0000ooooool000002Oooool00ol0003oooooo`000008ooooo`03
o`000?oooooo00000?oooooo=_ooool0033ooooo00?o0000ooooooooool0S?ooool00ol0003ooooo
o`000009ooooo`03o`000?oooooo000000Sooooo00?o0000ooooool00000oooooolfooooo`00<?oo
ool00ol0003oooooooooo`2<ooooo`03o`000?oooooo000000Wooooo00?o0000ooooool000002?oo
ool00ol0003oooooo`00003oooooocKooooo000`ooooo`03o`000?oooooooooo08cooooo00?o0000
ooooool000002Oooool00ol0003oooooo`000008ooooo`03o`000?oooooo00000?oooooo=_ooool0
033ooooo00?o0000ooooooooool0Roooool01?l0003oooooooooool00009ooooo`03o`000?oooooo
000000Sooooo00?o0000ooooool00000oooooolfooooo`00<?ooool3o`0008_ooooo00Co0000oooo
oooooooo00002Oooool00ol0003oooooo`000008ooooo`03o`000?oooooo00000?oooooo=_ooool0
033ooooo00?o0000ooooooooool0Roooool01?l0003oooooooooool00009ooooo`03o`000?oooooo
000000Sooooo00?o0000ooooool00000oooooolfooooo`00<?ooool00ol0003oooooooooo`2;oooo
o`04o`000?ooooooooooo`0000Wooooo00?o0000ooooool000002?ooool00ol0003oooooo`00003o
ooooocKooooo000`ooooo`03o`000?oooooooooo08_ooooo00Co0000oooooooooooo00002Oooool0
0ol0003oooooo`000008ooooo`03o`000?oooooo00000?oooooo=_ooool0033ooooo00?o0000oooo
ooooool0Roooool01?l0003oooooooooool00009ooooo`03o`000?oooooo000000Sooooo00?o0000
ooooool000002Oooool00ol0003oooooooooo`3oooooob[ooooo000`ooooo`03o`000?oooooooooo
08_ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooo`000008ooooo`03o`000?oooooo
000000Wooooo00?o0000ooooooooool0oooooolZooooo`00<?ooool00ol0003oooooooooo`2;oooo
o`04o`000?ooooooooooo`0000Wooooo00?o0000ooooool000002?ooool00ol0003oooooo`000009
ooooo`;o0000ooooool[ooooo`00<?ooool00ol0003oooooooooo`2;ooooo`04o`000?oooooooooo
o`0000Wooooo00?o0000ooooool000002?ooool00ol0003oooooo`000009ooooo`;o0000ooooool[
ooooo`00<?ooool00ol0003oooooooooo`2;ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000
ooooool000002?ooool00ol0003oooooo`000009ooooo`;o0000ooooool[ooooo`00<?ooool00ol0
003oooooooooo`2;ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002?oo
ool00ol0003oooooo`000009ooooo`;o0000ooooool[ooooo`00<?ooool00ol0003oooooooooo`2;
ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002?ooool00ol0003ooooo
o`000008ooooo`03o`000?oooooo00000?oooooo:oooool0033ooooo0ol00020ooooo`03o`000?oo
oooooooo00Sooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00008ooooo`03
o`000?oooooo000000Sooooo00?o0000ooooool00000ooooool[ooooo`00<?ooool00ol0003ooooo
ooooo`1oooooo`;o00002_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00
00Sooooo00?o0000ooooool000002?ooool00ol0003oooooo`00003oooooob_ooooo000`ooooo`03
o`000?oooooooooo07oooooo0_l0000:ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooo
oooooooo00002?ooool01?l0003oooooooooool00007ooooo`03o`000?oooooo00000?oooooo:ooo
ool0033ooooo00?o0000ooooooooool0Ooooool2o`0000[ooooo00Co0000oooooooooooo00002?oo
ool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool0
0000ooooool[ooooo`00<?ooool00ol0003oooooooooo`1oooooo`03o`000?oooooo000000Wooooo
00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00008ooooo`04o`000?oooooooooo
o`0000Oooooo00?o0000ooooool00000ooooool[ooooo`00<?ooool00ol0003oooooooooo`1ooooo
o`03o`000?oooooo000000Wooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?oooooo
ooooo`0000Sooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00003oooooob_ooooo
000`ooooo`03o`000?oooooooooo07oooooo00?o0000ooooool000002Oooool01Ol0003ooooooooo
oooooooo000000Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00007oooo
o`03o`000?oooooo00000?oooooo:oooool0013ooooo0_o^k^h3ooooo`;ok^k^6Oooool00ol0003o
ooooooooo`1oooooo`03o`000?oooooo000000Wooooo00Go0000ooooooooooooooooo`000007oooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00
003oooooob_ooooo0009ooooo`Go00000_ooool01oo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h0
0oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h:ooooo`03o`000?oooooo
oooo07oooooo00?o0000ooooool000002Oooool01Ol0003ooooooooooooooooo000000Oooooo00Go
0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool0
0000ooooool[ooooo`002Oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00Gok^k^oeEEEOoM
gMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0:
ooooo`03o`000?oooooooooo07oooooo00?o0000ooooool000002Oooool01Ol0003ooooooooooooo
oooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oo
oooo00?o0000ooooool00000ooooool[ooooo`0000?oooooo`000?l000001?l00003ooooo`03oiRH
V?lQ8B7ok^k^00Gooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@
4?ooooooooooooooool@41002_ooool00ol0003oooooooooo`1oooooo`03o`000?oooooo000000Wo
oooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool0
1?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`000?oooooo:_ooool000_ooooo00?o
V9RHob4Q8Oo^k^h00oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool0
0_ooool01Ol0003ooooooooooooooooo000000[ooooo00?o0000ooooooooool0O_ooool01?l0003o
ooooooooool00009ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooo
oooo000000Oooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool0003oooooob[o
oooo000<ooooo`0;ogMgMomVIVKoooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Ooo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000002_ooool4o`0007gooooo
00Co0000oooooooooooo00002Oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooo
ooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo0000
oooooolZooooo`003Oooool00ol0003oooooooooo`02onk^kP?ooooo0_o^k^h5ooooo`03o`000?oo
oooooooo00;ooooo00Go410@oooooooooooooooooa0@400:ooooo`03o`000?oooooooooo07kooooo
00Co0000oooooooooooo00002Oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooo
ooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo0000
oooooolZooooo`002Oooool01Ol0003o^[ZjoooooonHV9So410@00kooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo0_l00005ooooo`03o`000?oooooooooo07ko
oooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Gooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo00Co
0000oooooooooooo0000oooooolZooooo`002Oooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo
00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo00Co0000oooooooo
oooo00001?ooool00ol0003oooooooooo`1nooooo`04o`000?ooooooooooo`0000Sooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000001ooo
ool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`000?oooooo:_ooool002Sooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`1nooooo`04o`000?ooooooooooo`00
00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`05o`000?oooooooooo
ooooool000001oooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Oooooo
0_l0003oooooob7ooooo000Xooooo`?o00001Oooool00ol0003oooooooooo`1nooooo`04o`000?oo
ooooooooo`0000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`05o`00
0?ooooooooooooooool000001oooool01?l0003oooooooooool00007ooooo`04o`000?oooooooooo
o`0000Oooooo0_l0003oooooob7ooooo000Yooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0O_ooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01Oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000
1oooool01?l0003oooooooooool00007ooooo`;o0000oooooolQooooo`00:_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo07kooooo00Co0000oooooooooooo00002?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000007oooo
o`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00001oooool2o`000?oooooo8Ooo
ool0033ooooo00?o0000ooooooooool0O_ooool01?l0003oooooooooool00008ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000Oooooo
00Co0000oooooooooooo00001_ooool01Ol0003ooooooooooooooooo000000Oooooo0_l0003ooooo
ob7ooooo000`ooooo`03o`000?oooooooooo07kooooo00Co0000oooooooooooo00002?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000007
ooooo`04o`000?ooooooooooo`0000Kooooo00Go0000ooooooooooooooooo`000007ooooo`;o0000
oooooolQooooo`00<?ooool00ol0003oooooooooo`1nooooo`04o`000?ooooooooooo`0000Sooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool0
00001oooool01?l0003oooooooooool00006ooooo`05o`000?ooooooooooooooool000001oooool2
o`000?oooooo8Oooool0033ooooo00?o0000ooooooooool0O_ooool01?l0003oooooooooool00008
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooo
oooo000000Kooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool0
00001oooool2o`000?oooooo8Oooool0033ooooo0ol0001nooooo`04o`000?ooooooooooo`0000So
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`05o`000?oooooooooooooo
ool000001_ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`00
0007ooooo`03o`000?oooooo00000?oooooo8?ooool0033ooooo00?o0000ooooooooool0O_ooool0
1?l0003oooooooooool00008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Ooo
ool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000006ooooo`05
o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003oooooob3ooooo000`ooooo`03
o`000?oooooooooo07kooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?oooooo
ooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo
0000oooooolPooooo`00<?ooool00ol0003oooooooooo`1nooooo`05o`000?ooooooooooooooool0
00001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00Go0000oooooooo
ooooooooo`000006ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooo
oooo000000Kooooo00Co0000oooooooooooo0000oooooolPooooo`00<?ooool00ol0003ooooooooo
o`1mooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`04ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Ko
oooo00Co0000oooooooooooo0000oooooolPooooo`00<?ooool00ol0003oooooooooo`1booooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?oooooooooo
ooooool000001_ooool01?l0003oooooooooool0003oooooob3ooooo000`ooooo`03o`000?oooooo
oooo077ooooo00?o0000ooooool000002Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`000?oooooo
8?ooool0033ooooo00?o0000ooooooooool0LOooool00ol0003oooooo`000009ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Kooooo
00Co0000oooooooooooo0000oooooolPooooo`00<?ooool00ol0003oooooooooo`1aooooo`03o`00
0?oooooo000000Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`00
0?ooooooooooooooool000001_ooool01?l0003oooooooooool0003oooooob3ooooo000`ooooo`03
o`000?oooooooooo077ooooo00?o0000ooooool000002Oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?oooooooooo
o`000?oooooo8?ooool0033ooooo00?o0000ooooooooool0LOooool00ol0003oooooo`000009oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo
000000Kooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`3ooooooaGooooo000`
ooooo`03o`000?oooooooooo073ooooo00Co0000oooooooooooo00002Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000006ooooo`04o`00
0?ooooooooooo`0000Oooooo0_l0003ooooooaOooooo000`ooooo`?o0000L?ooool01Ol0003ooooo
oooooooooooo000000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05
o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool00007ooooo`;o0000oooooolG
ooooo`00<?ooool00ol0003oooooooooo`1`ooooo`05o`000?ooooooooooooooool000002?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Oooooo0_l0003ooooooaOooooo000`
ooooo`03o`000?oooooooooo073ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00Co0000oooooooooooo00001oooool2o`000?oooooo5oooool0033ooooo00?o
0000ooooooooool0L?ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool01?l0003oooooooooool00007ooooo`;o0000oooooolGooooo`00<?ooool00ol0003ooooo
ooooo`1`ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`04
o`000?ooooooooooo`0000Oooooo00?o0000ooooool00000oooooolFooooo`00<?ooool00ol0003o
ooooooooo`1>ooooo`;ok^k^0oooool2onk^kQ_ooooo00Go0000ooooooooooooooooo`000008oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00oo^k^ko0000ooooo`02oooo
o`03onk^k_l0003ooooo00Cooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00001=
ooooo`;ok^k^0oooool2onk^kTkooooo0_o^k^h3ooooo`;ok^k^K?ooool0033ooooo00?o0000oooo
ooooool0B?ooool03Om4A4Co0000o`000?lb<S;ogMgMooooooo^k^koEEEEonk^k_ooooook^k^oeEE
EOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool01?l0003oooooooooooooool4o`000009
oa0@4?ooooook^k^o`000?o^k^koooooonk^k_mEEEGo000000?ooooo1?l000002Ol@413o0000oooo
ooo^k^ko<S8bo`000?lb<S;ok^k^o`000002ooooo`03o`000?oooooooooo03Gooooo1?l000000ol@
413oooooooooo`02ooooo`;o8B4Q1Oooool03Om4A4Co0000o`000?lb<S;ogMgMooooooo^k^koEEEE
onk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b
<_o^k^hhooooo`Go00000_ooool01oo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`00
0008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^iMooooo`00<?ooool00ol0003ooooooooo
o`1;ooooo`09ogMgMolb<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000oooo
ooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo0_l00004ooooo`06o`000?mEEEGo
gMgMoeEEEOo^k^ko00001Oooool02ol0003oooooooooool0003oooooogMgMonHV9SooooooiRHV?mg
MgOo000000;ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`04ooooo`;o8B4Q2?oo
ool02OmgMgOo<S8booooooooooook^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0hooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00ooo
ool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg05gooooo000`ooooo`03o`000?oooooooooo04cooooo00Oo0000oooooooooooo
ooooomgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@00_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo0_l00004ooooo`06o`000?oMgMgo0000omgMgOoooooo00001Oooool01_l0003ooooo
ooooool0003ooooooa0@40?ooooo00Go410@o`000?ooooooooooo`00000iooooo`03o`000?oooooo
oooo00oooooo00Oo0000ooooooooooooooooomgMgOl0003ogMgM00Oooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@03Wooooo00?oV9RHob4Q8Oo^k^h01Oooool00ooMgMgo
0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@401Moooo
o`00<?ooool00ol0003oooooooooo`1;ooooo`09ogMgMolb<S;oooooooooooo^k^koEEEEomgMgOmE
EEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000_ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
0_l00004ooooo`06o`000?mEEEGogMgMoeEEEOo^k^ko00001Oooool01_l0003oooooooooool0003o
ooooo`0000?ooooo0_l00002ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool03_oo
ool02OmgMgOo<S8booooooooooook^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`00000jooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Gok^k^
oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00001Mooooo`00<?ooool00ol0003oooooooooo`18ooooo`0=o`000?lQ8B7o0000oc8b<_o<c<co
ooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`00000;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`;o00000oooool01oo^k^ko0000onk^k_ooooook^k^oeEE
EOl000001Oooool01_l0003oooooooooool0003oooooo`0000?ooooo0_l00002ooooo`03o`000?oo
oooooooo03Oooooo00?o0000ooooooooool02oooool03Ol0003o8B4Qo`000?lb<S;oc<c<ooooooo^
k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool00000>oooool02omgMgOoIVIVooooooooooook^k^oeEEEOo^k^koooooonk^k_mE
EEGok^k^00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000005gooooo
000`ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool00oooool2onk^kP?ooooo0_o^
k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400;ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`;o0000
0oooool00oo^k^ko0000ooooo`02ooooo`03onk^k_l0003ooooo00Cooooo00Ko0000oooooooooooo
0000ooooool@4103ooooo`05oa0@4?l0003oooooooooool000001oooool2o`00033ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`03ooooo`;ok^k^0oooool2onk^kPGooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@03cooooo00?o0000ooooooooool00_o^
k^h3ooooo`;ok^k^1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100
GOooool0033ooooo0ol00018ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo0_l00004ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool02ol0003oooooooooool0003oooooogMgMonHV9SooooooiRH
V?mgMgOo000000;ooooo00?o0000ooooooooool00_ooool2o`000003ooooool0003o0000033ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`;o0000;_ooool01Ol0003o^[ZjoooooonHV9So410@
00kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo0_l0001C
ooooo`00<?ooool00ol0003oooooooooo`18ooooo`Co00003?ooool00omEEEGoIVIVo`000004oooo
o`03onk^k_lb<S;o000000?o00001oooool01?l0003oooooooooool00004ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00Go0000oooooooooooooooooeEEE@02o`0000Cooooo00?o0000ooooooooool00_oo
ool01Ol0003oooooooooooooooooEEEE00;o00000oooool01ol0003ok^k^oc8b<_l0003o<S8bonk^
k_l000000_ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooool00000;_ooool0
0omEEEGoIVIVo`00000=ooooo`Co00003?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01oooool01?l0003oooooooooool0000]ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`03?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01oooool01?l0
003oooooooooool0001Booooo`00<?ooool00ol0003oooooooooo`1Rooooo`04o`000?oooooo0000
ooooo`Co00000oooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooool000000ol000001ooooooo0000oooooooooooo0000ooooool00000G?ooool4o`000005oooo
ool0003oooooooooool00000C?ooool4o`000005ooooool0003oooooooooool00000D_ooool0033o
oooo00?o0000ooooooooool0HOooool01?l0003oooooooooool00008ooooo`03o`000?oooooo0000
00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00003ooooo`Co00000_ooool0
0ol0003oooooooooo`1Nooooo`?o0000D_ooool3o`0005?ooooo000`ooooo`03o`000?oooooooooo
067ooooo00Go0000ooooooooooooooooo`000005ooooo`04o`000?ooooooooooo`0000Kooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool01?l0003oooooooooool00004ooooo`03o`000?oooooo000000;ooooo
00?o0000ooooooooool0Goooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo05;ooooo
000`ooooo`03o`000?oooooooooo067ooooo00Go0000ooooooooooooooooo`000005ooooo`Co0000
1_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Gooooo0_l00002ooooo`03
o`000?oooooooooo00Cooooo0_l0001Jooooo`03o`000?oooooooooo05;ooooo00?o0000oooooooo
ool0DOooool0033ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`04o`00
0?ooooooooooo`0000Kooooo00Co0000oooooooooooo00001_ooool2o`000?oooooo1?ooool0033o
oooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooooooooooo
ool000001Oooool01?l0003oooooooooool00005ooooo`;o000000?oooooo`000?ooool0aoooool0
0omgMgOoIVIVooooo`0]ooooo`03ofIVI_mgMgOooooo00Oooooo000`ooooo`03o`000?oooooooooo
063ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000
ooooooooooooooooo`000005ooooo`04o`000?ooooooooooo`000<Oooooo00?ogMgMoa0@4?o^k^h0
;_ooool00oo^k^ko410@omgMg@07ooooo`00<?ooool00ol0003oooooooooo`1Aooooo`Co00002ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooo
oooooooooooo000000Gooooo00Co0000oooooooooooo00001_ooool2o`000:gooooo0_l00002oooo
o`;o00003?ooool00omEEEGoV9RHooooo`02o`0000;ooooo00Oo0000oooooooooooo0000oa0@4?o^
k^koEEEE00;o000000?oA4A4okZj^_ooool00_ooool01OnHV9So0000o`000?m4A4Co^[Zj00;ooooo
00Sok^k^oeEEEOl0003o0000odA4A?nj^[[ooooooa0@40Go00000oooool02?l@413o<S8bo`000?l0
003o410@ojVYZOn7QhOoIVIV1oooool0033ooooo00?o0000ooooooooool0Coooool2o`0000?ooooo
0_l00009ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000004ooooo`05
o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo00001_ooool2o`000:Cooooo00Kok^k^ob4Q8On7QhOo^[Zjo`00
0?oMgMd<ooooo`05o`000?ooooooooooooooool000000_ooool02ol0003oooooooooool0003ooooo
oeEEEOmgMgOoooooonk^k_mgMgOo410@00?ooooo00Go410@okZj^_o^k^koMgMgoa0@4002ooooo`06
oeEEEOmgMgOoooooonk^k_mgMgOo410@0oooool00ol0003oooooooooo`04ooooo`08o`000?nYZJWo
oooooooooonj^[[o0000onk^k_l00007ooooo`00ool0002do`0000oooooo00CogMgMo`000?l@413o
c<c<3Oooool01Olb<S;ooooooooooooooooo000000;ooooo00Ko0000oooooooooooo0000ooooool0
0008ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`05ooooo`07okZj^_n7QhOoIVIVofIVI_l@413oooooo`000007ooooo`002_ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool7o`0000Wooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00_ooool00ol0003oooooo`000006ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00_ooool2o`0000Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooo000000;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo
000000Cooooo0_l00003ooooo`05o`000?ooooooooooooooool000001?ooool01ol0003ooooooooo
oooooooo0000ooooool000000_ooool2o`000003ooooool0003o000000Cooooo1?l00002ooooo`05
o`000?ooooooooooooooool000003_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Gooooo`04onk^k_lQ8B7o410@
onk^kPgooooo00Go<S8booooooooooooooooo`000002ooooo`05o`000?ooooooooooo`000?ooool0
1_l00003ooooo`03o`000?oooooooooo00Cooooo1_l00003ooooo`03o`000?oooooooooo00Cooooo
00So<S8bob4Q8OmgMgOoMgMgohN7Qoo^k^koooooo`0000Oooooo000:ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
00cooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00_ooool00ol0003oooooo`000006ooooo`03o`000?oooooooooo00?ooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00_ooool2o`0000Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00;ooooo0_l00003ooooo`05o`000?ooooooooooooooool00000
1Oooool01_l0003oooooooooool0003oooooo`0000?ooooo0_l0000<ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool05oooool01?lQ8B7oMgMgogMgMolb<S8=ooooo`05o`000?o^k^ko
ooooooooool000000_o<c<`02ol0003oZJVYomgMgOlQ8B7ooooooeEEEOn7QhOok^k^oooooon7QhOo
<S8b00?ooooo00?o0000ooooooooool01?ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<P?ooooo
00?o0000oc8b<_oMgMd01?ooool02?l0003o^[Zjooooooo^k^koMgMgo`000?o^k^ko00001oooool0
033ooooo00?o0000ooooooooool0F?ooool01_l0003oooooooooool0003oooooo`0000Wooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000005ooooo`03o`000?oooooo000003[ooooo00?o0000ooooooooool0
Foooool00ol0003oooooooooo`0Fooooo`;o00000_ooool2o`0000cooooo00koEEEEogMgMooooooo
410@o`000?lQ8B7o0000ogMgMol@413o0000ojVYZOooooook^k^oeEEE@;o000000CoA4A4onk^k_oo
oooo410@1Ol00003ooooo`06onk^k_mEEEGo0000o`000?m4A4Cok^k^0_ooool2o`000004ojVYZOlQ
8B7o0000ob4Q8@;ooooo00SoZJVYob4Q8Ol0003o0000oc8b<_l0003oMgMgoeEEE@Oooooo000`oooo
o`03o`000?oooooooooo05Sooooo0_l00003ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`000005ooooo`?o0000`oooool00ooMgMgo410@onk^kP0Booooo`03o`000?oooooo
oooo01Wooooo00?ok^k^oa0@4?oMgMd01oooool0033ooooo00?o0000ooooooooool0FOooool4o`00
00[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`00003<ooooo`03ogMgMomVIVKooooo017ooooo00?o0000
ooooooooool06Oooool00omVIVKoMgMgooooo`07ooooo`00<?ooool00ol0003oooooooooo`1Koooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooo0000ooooool8ooooo`00<?ooool00ol0003oooooooooo`1W
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooo
oooo000000Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooo00000?oooooo2?ooool0033ooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool3o`000?oooooo2?ooool0033ooooo00?o0000
ooooooooool0J?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000
ooooooooooooooooo`000005ooooo`04o`000?ooooooooooo`0000Kooooo0_l0003oooooo`Wooooo
000`ooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`05o`000?ooooooooooooooool000001Oooool01?l0003oooooooooool0003ooooooa7o
oooo000`ooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`05o`000?ooooooooooooooool000001Oooool01?l0003oooooooooool0003ooooo
oa7ooooo000`ooooo`?o0000J?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00Go0000ooooooooooooooooo`000005ooooo`04o`000?ooooooooooo`000?oooooo4Oooool0
033ooooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Gooooo00Go0000
ooooooooooooooooo`000005ooooo`04o`000?ooooooooooo`000?oooooo4Oooool0033ooooo00?o
0000ooooooooool0JOooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo
00Co0000oooooooooooo00001_ooool01?l0003oooooooooool00006ooooo`04o`000?oooooooooo
o`000?oooooo4Oooool0033ooooo00?o0000ooooooooool0JOooool01?l0003oooooooooool00009
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00001_ooool01?l0003ooooooooo
ool00006ooooo`04o`000?ooooooooooo`000?oooooo4Oooool0033ooooo00?o0000ooooooooool0
JOooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooo
oooo00001_ooool01?l0003oooooooooool00007ooooo`;o0000oooooolBooooo`00<?ooool00ol0
003oooooooooo`1Yooooo`;o000000?oooooo`000?ooool02?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04oooo
o`04o`000?ooooooooooo`0000Kooooo00Co0000oooooooooooo00001oooool2o`000?oooooo4_oo
ool0033ooooo00?o0000ooooooooool0J_ooool3o`0000Wooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
1?l0003oooooooooool00006ooooo`04o`000?ooooooooooo`0000Oooooo0_l0003ooooooa;ooooo
000`ooooo`03o`000?oooooooooo06[ooooo0_l0000:ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Co
0000oooooooooooo00001_ooool01?l0003oooooooooool0003ooooooa_ooooo000`ooooo`03o`00
0?oooooooooo07Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00006ooooo`04
o`000?ooooooooooo`000?oooooo6oooool0033ooooo00?o0000ooooooooool0M_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`04o`000?ooooooooooo`0000Kooooo00Co0000oooooooooooo0000oooooolK
ooooo`00<?ooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Co0000oooo
oooooooo00001_ooool01?l0003oooooooooool0003ooooooa_ooooo000`ooooo`03o`000?oooooo
oooo07Oooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool01?l0003oooooooooool00006ooooo`04o`000?ooooooooooo`000?oo
oooo6oooool0033ooooo0ol0001gooooo`05o`000?ooooooooooooooool000002?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00001_ooool01?l0
003oooooooooool0003ooooooa_ooooo000`ooooo`03o`000?oooooooooo07Oooooo00Go0000oooo
ooooooooooooo`000008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
1?l0003oooooooooool00006ooooo`03o`000?oooooo00000?oooooo7?ooool0033ooooo00?o0000
ooooooooool0Moooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooooooo
o`000006ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooool00000oooooolLooooo`00
<?ooool00ol0003oooooooooo`1gooooo`05o`000?ooooooooooooooool000002?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000006oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo
000000Kooooo00Co0000oooooooooooo00001_ooool00ol0003oooooo`00003ooooooacooooo000`
ooooo`03o`000?oooooooooo07Oooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool0
00001_ooool01?l0003oooooooooool00007ooooo`;o0000oooooolLooooo`00<?ooool00ol0003o
ooooooooo`1gooooo`04o`000?ooooooooooo`0000Wooooo00Go0000ooooooooooooooooo`000008
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Oo
oooo0_l0003ooooooacooooo000`ooooo`03o`000?oooooooooo07Oooooo00Co0000oooooooooooo
00002Oooool01Ol0003ooooooooooooooooo000000Sooooo00Go0000ooooooooooooooooo`000006
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooo
oooo000000Kooooo00Co0000oooooooooooo00001oooool2o`000?oooooo7?ooool0033ooooo00?o
0000ooooooooool0Moooool01?l0003oooooooooool00009ooooo`05o`000?ooooooooooooooool0
00002?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool0
0007ooooo`;o0000oooooolLooooo`00<?ooool00ol0003oooooooooo`1gooooo`04o`000?oooooo
ooooo`0000Wooooo00Go0000ooooooooooooooooo`000008ooooo`05o`000?ooooooooooooooool0
00001_ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000006
ooooo`04o`000?ooooooooooo`0000Oooooo0_l0003ooooooacooooo000`ooooo`03o`000?oooooo
oooo07Oooooo00Co0000oooooooooooo00002Oooool01Ol0003ooooooooooooooooo000000Sooooo
00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001oooool01Ol0
003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo00001oooool2o`000?oooooo7?oo
ool0033ooooo00?o0000ooooooooool0Moooool01?l0003oooooooooool00009ooooo`05o`000?oo
ooooooooooooool000002?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000oooooooo
ooooooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool0
0008ooooo`03o`000?oooooooooo0?oooooo6_ooool0033ooooo00?o0000ooooooooool0Moooool0
1?l0003oooooooooool00009ooooo`05o`000?ooooooooooooooool000002?ooool01Ol0003ooooo
oooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooooooo
ooooool000001_ooool01?l0003oooooooooool0003oooooobGooooo000`ooooo`?o0000N?ooool0
0ol0003oooooo`000009ooooo`05o`000?ooooooooooooooool000002?ooool01Ol0003ooooooooo
oooooooo000000Kooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooooooooooo
ool000001_ooool01?l0003oooooooooool0003oooooobGooooo000`ooooo`03o`000?oooooooooo
07Sooooo00?o0000ooooool000002Oooool01Ol0003ooooooooooooooooo000000Sooooo00Go0000
ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooo
oooooooooooo000000Kooooo00Co0000oooooooooooo0000oooooolUooooo`00<?ooool00ol0003o
ooooooooo`1hooooo`03o`000?oooooo000000Wooooo00Go0000ooooooooooooooooo`000008oooo
o`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Oooooo00Go
0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`000?oooooo9Oooool0033ooooo
00?o0000ooooooooool0N?ooool00ol0003oooooo`000009ooooo`05o`000?ooooooooooooooool0
00002?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000007
ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool0003oooooobGooooo
000`ooooo`03o`000?oooooooooo07Sooooo00?o0000ooooool000002Oooool01Ol0003ooooooooo
oooooooo000000Sooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?oooooooooooooo
ool000001oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooool00000oooooolV
ooooo`00<?ooool00ol0003oooooooooo`1hooooo`03o`000?oooooo000000Wooooo00Go0000oooo
ooooooooooooo`000008ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooo
oooooooo000000Oooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo00000?oo
oooo9_ooool000oooooo0_o^k^h3ooooo`;ok^k^6_ooool00ol0003oooooooooo`1hooooo`03o`00
0?oooooo000000Wooooo00Go0000ooooooooooooooooo`000008ooooo`05o`000?oooooooooooooo
ool000001_ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooo00000?oooooo9_ooool000Sooooo1Ol00002ooooo`07onk^k_mEEEGo
k^k^ooooooo^k^koEEEEonk^kP03ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8b
onk^kP_ooooo00?o0000ooooooooool0N?ooool00ol0003oooooo`000009ooooo`05o`000?oooooo
ooooooooool000002?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000oooooooooooo
ooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooo`00003ooooo
obKooooo0008ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01Oo^k^koEEEEomgMgOmEEEGo
k^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?o
0000ooooooooool0NOooool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool00000
2?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000007oooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooo`00003oooooobKooooo0009oooo
o`03oiRHV?lQ8B7ok^k^00Gooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@41002oooool00ol0003oooooooooo`1iooooo`03o`000?oooooo
oooo00Sooooo00Go0000ooooooooooooooooo`000008ooooo`05o`000?ooooooooooooooool00000
1_ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000006oooo
o`03o`000?oooooo00000?oooooo9_ooool000[ooooo00?oV9RHob4Q8Oo^k^h00oooool01Oo^k^ko
EEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo
000000_ooooo00?o0000ooooooooool0Q?ooool01Ol0003ooooooooooooooooo000000Sooooo00Go
0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003o
oooooooooooooooo000000Oooooo0_l0003oooooobKooooo000;ooooo`0;ogMgMomVIVKooooooooo
ooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000002oooool4o`0008?ooooo00Go0000ooooooooooooooooo`000008oooo
o`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool00007ooooo`05o`000?oo
ooooooooooooool000001oooool2o`000?oooooo9_ooool000cooooo00?o0000ooooooooool00_o^
k^h3ooooo`;ok^k^1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100
2oooool00ol0003oooooooooo`25ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooo
ooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00
0007ooooo`;o0000oooooolVooooo`002?ooool01Ol0003o^[ZjoooooonHV9So410@00kooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?o0000ooooooooool0
QOooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool000001oooool01?l0
003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Sooooo0_l0003oooooobKooooo0008
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00oooool2o`0000Kooooo00?o0000ooooooooool0QOooool01?l0003ooooo
ooooool00008ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool00007
ooooo`04o`000?ooooooooooo`0000Sooooo0_l0003oooooobKooooo000Wooooo`04o`000?oooooo
ooooo`0000Gooooo00?o0000ooooooooool0QOooool01?l0003oooooooooool00008ooooo`05o`00
0?ooooooooooooooool000001oooool01?l0003oooooooooool00007ooooo`04o`000?oooooooooo
o`0000Sooooo0_l0003oooooobKooooo000Wooooo`04o`000?ooooooooooo`0000Gooooo00?o0000
ooooooooool0QOooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool00000
1oooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Sooooo0_l0003ooooo
obKooooo000Wooooo`?o00001_ooool00ol0003oooooooooo`25ooooo`04o`000?ooooooooooo`00
00Sooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo00Co
0000oooooooooooo00002?ooool2o`000?oooooo9_ooool002Sooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`25ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooooooo
ooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00002?ooool2
o`000?oooooo9_ooool002Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`25oooo
o`04o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?oo
ooooooooo`0000Sooooo00?o0000ooooool000002?ooool2o`000?oooooo9_ooool0033ooooo00?o
0000ooooooooool0QOooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool0
00001oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?oooooo<?ooool0033o
oooo00?o0000ooooooooool0QOooool01?l0003oooooooooool00008ooooo`05o`000?oooooooooo
ooooool000001oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?oooooo<?oo
ool0033ooooo00?o0000ooooooooool0QOooool01?l0003oooooooooool00008ooooo`05o`000?oo
ooooooooooooool000001oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?oo
oooo<?ooool0033ooooo0ol00025ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooo
ooooooooo`000007ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000ooooool`
ooooo`00<?ooool00ol0003oooooooooo`25ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000
ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000
ooooool`ooooo`00<?ooool00ol0003oooooooooo`25ooooo`04o`000?ooooooooooo`0000Sooooo
00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000oooo
ool00000ooooool`ooooo`00<?ooool00ol0003oooooooooo`25ooooo`04o`000?ooooooooooo`00
00Sooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Sooooo00?o
0000ooooool00000ooooool`ooooo`00<?ooool00ol0003oooooooooo`25ooooo`03o`000?oooooo
000000Wooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00008ooooo`03o`00
0?oooooo00000?oooooo<?ooool0033ooooo00?o0000ooooooooool0QOooool00ol0003oooooo`00
0009ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002?ooool00ol0003o
ooooo`00003ooooooc3ooooo000`ooooo`03o`000?oooooooooo08Gooooo00?o0000ooooool00000
2Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000oooo
ool00000ooooool`ooooo`00<?ooool00ol0003oooooooooo`25ooooo`03o`000?oooooo000000Wo
oooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo
00000?oooooo<?ooool0033ooooo00?o0000ooooooooool0QOooool00ol0003oooooo`000009oooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00
003ooooooc3ooooo000`ooooo`03o`000?oooooooooo08Gooooo00?o0000ooooool000002Oooool0
1?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000
ooooool`ooooo`00<?ooool00ol0003oooooooooo`26ooooo`;o00002Oooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000ooooool`ooooo`00
<?ooool00ol0003oooooooooo`26ooooo`;o00002Oooool01?l0003oooooooooool00008ooooo`04
o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000ooooool`ooooo`00<?ooool3o`0008Ko
oooo0_l00009ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002?ooool2
o`000?oooooo<Oooool0033ooooo00?o0000ooooooooool0Q_ooool2o`0000Wooooo00Co0000oooo
oooooooo00002?ooool01?l0003oooooooooool00008ooooo`;o0000oooooolaooooo`00<?ooool0
0ol0003oooooooooo`26ooooo`;o00002Oooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000Sooooo0_l0003ooooooc7ooooo000`ooooo`03o`000?oooooooooo08Kooooo0_l0
0009ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002?ooool2o`000?oo
oooo<Oooool0033ooooo00?o0000ooooooooool0T_ooool00ol0003oooooo`000008ooooo`04o`00
0?ooooooooooo`0000Sooooo0_l0003ooooooc7ooooo000`ooooo`03o`000?oooooooooo09;ooooo
00?o0000ooooool000002?ooool01?l0003oooooooooool00008ooooo`;o0000oooooolaooooo`00
<?ooool00ol0003oooooooooo`2Booooo`03o`000?oooooo000000Sooooo00Co0000oooooooooooo
00002?ooool2o`000?oooooo<Oooool0033ooooo00?o0000ooooooooool0T_ooool00ol0003ooooo
o`000009ooooo`03o`000?oooooo000000Wooooo00?o0000ooooooooool0ooooool_ooooo`00<?oo
ool00ol0003oooooooooo`2Booooo`03o`000?oooooo000000Wooooo00?o0000ooooool00000oooo
oolkooooo`00<?ooool00ol0003oooooooooo`2Booooo`03o`000?oooooo000000Wooooo0_l0003o
oooooccooooo000`ooooo`03o`000?oooooooooo09;ooooo00?o0000ooooool000002Oooool2o`00
0?oooooo??ooool0033ooooo00?o0000ooooooooool0T_ooool00ol0003oooooo`000009ooooo`;o
0000oooooollooooo`00<?ooool3o`0009;ooooo00?o0000ooooool000002Oooool2o`000?oooooo
??ooool0033ooooo00?o0000ooooooooool0T_ooool00ol0003oooooo`000009ooooo`;o0000oooo
oollooooo`00<?ooool00ol0003oooooooooo`2Booooo`03o`000?oooooo000000Wooooo0_l0003o
oooooccooooo000`ooooo`03o`000?oooooooooo09;ooooo00?o0000ooooool000002Oooool2o`00
0?oooooo??ooool0033ooooo00?o0000ooooooooool0T_ooool00ol0003oooooo`000009ooooo`;o
0000oooooollooooo`00<?ooool00ol0003oooooooooo`2Booooo`03o`000?oooooo000000Wooooo
0_l0003ooooooccooooo000?ooooo`;ok^k^0oooool2onk^kQ[ooooo00?o0000ooooooooool0T_oo
ool2o`0000[ooooo0_l0003ooooooccooooo000:ooooo`;o000000[o410@ooooooooooook^k^oeEE
EOo^k^koooooonk^k_mEEEGok^k^0oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b
<_o^k^h;ooooo`03o`000?oooooooooo09;ooooo0_l0000:ooooo`;o0000oooooollooooo`002ooo
ool00ol0003oooooooooo`02ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ol0003oooooooooo`2Booooo`;o
00002_ooool2o`000?oooooo??ooool000Sooooo1Ol00004ooooo`03omgMgOl0003ogMgM00Oooooo
00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00_ooooo00?o0000oooooooo
ool0Toooool00ol0003oooooooooo`08ooooo`;o0000oooooollooooo`002?ooool01?m4A4CogMgM
ooooool00004ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`2Cooooo`03o`000?oooooo
oooo00Sooooo0_l0003ooooooccooooo0008ooooo`04omgMgOmEEEGoooooo`0000?ooooo00Ook^k^
oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000_ooooo1?l0002Mooooo`;o0000oooooollooooo`002Oooool00omgMgOoc<c<
o`000003ooooo`;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@413ooooo
oooooooooooo410@00_ooooo00?o0000ooooooooool0oooooooLooooo`002Oooool00oo^k^koA4A4
o`00000?ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03
o`000?oooooooooo0?oooooog?ooool000[ooooo00?oMgMgo`000?ooool03?ooool00omEEEGoIVIV
o`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool2o`0000Kooooo00?o0000oooooooo
ool0oooooooLooooo`009oooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo0?oo
oooog?ooool002Oooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`3oooooomco
oooo000Wooooo`?o00001_ooool00ol0003oooooooooo`3oooooomcooooo000Xooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0oooooooLooooo`00:Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLoooo
o`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooo
g?ooool0033ooooo0ol0003oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0
033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomco
oooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooo
oooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooo
ooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000
ooooooooool0oooooooLooooo`00<?ooool3o`000?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0
003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo
00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`
ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLoooo
o`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`?o0000oooooooLooooo`00<?oo
ool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0
033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomco
oooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooo
oooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?oo
ool00?ooooooooooool@ooooo`00X?ooool2o`0000Cooooo00?o^[Zjoc8b<_ooool01?ooool2o`00
00Kooooo00?o0000okZj^_ooool0oooooomGooooo`00X?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool2oc8b<_ooooooF?ooool008gooooo
0ol00002ooooo`06oc8b<_l@413oooooooooooo^k^koEEEE0_l000000om4A4Co^[Zjooooo`03oooo
o`03o`000?oooooooooo00;ooooo00GoV9RHoa0@4?l0003o0000ojVYZ@04ooooo`03o`000?oooooo
oooo00Cooooo00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj00_ooooo00?o
0000onk^k_ooool01Oooool2ob4Q8@Cooooo1Ol000001_ooooooc<c<onk^k_ooooook^k^olc<c0Co
oooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^4oooool01_l@413o<S8bo`00
0?l0003o410@ojVYZ@;ooooo00Kok^k^oeEEEOl0003o0000odA4A?nj^[X3ooooo`05ofIVI_l0003o
0000odA4A?o<c<`0j?ooool008kooooo00Go0000ooooooooooooc<c<oa0@4003ooooo`06oeEEEOmg
MgOoooooonk^k_mgMgOo410@1?ooool00ol0003oooooooooo`02ooooo`06o`000?nYZJWoEEEEoiRH
V?mEEEGo^[Zj0oooool00ol0003oooooooooo`04ooooo`03olc<c?l0003o410@00cooooo00Ko410@
okZj^_o^k^koMgMgoa0@4?ooool6o`0000Cooooo00?oEEEEojVYZOooool01Oooool2ob4Q8@Cooooo
00_oV9RHob4Q8Oo^k^koooooodA4A?ooooook^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Cooooo`06o`000?nYZJWooooooooooonj
^[[o00000_ooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40;ooooo00KoIVIVogMgMooooooooooo
ohN7Qol@413Xooooo`00S_ooool01Ol0003ooooooooooomEEEGoQhN700?ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`02ooooo`06oc8b<_o^k^koV9RHoeEEEOoMgMgo410@0oooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00gooooo00?oZJVYoeEEEOooool03?ooool0
0onHV9So8B4Qonk^kP03ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@01Cooooo00Go^[ZjohN7QomVIVKoIVIVoa0@4002ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0joooool008kooooo00Go0000oooooooMgMgo0000
onk^kP03ooooo`Ko00001?ooool00ol0003oooooooooo`02ooooo`07okZj^_m4A4Coc<c<ob4Q8Ooo
oooo410@olc<c002ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00oooool6o`00
00Gooooo00?o8B4Qooooooooool03?ooool02OnHV9So8B4Qonk^k_ooooook^k^oeEEEOoMgMgoEEEE
onk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Cooooo`06
oc8b<_lQ8B7oMgMgogMgMon7QhOok^k^0_ooool6o`0000;ooooo00?o0000ooooooooool0joooool0
08kooooo0ol000000ol@413oV9RHooooo`02ooooo`06oeEEEOn7QhOok^k^oooooon7QhOo<S8b1?oo
ool00ol0003oooooooooo`02ooooo`07onk^k_l0003oooooo`000?ooooooIVIVohN7Q`02ooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool03_ooool00omEEEGoc<c<ooooo`0=ooooo`08
ogMgMomVIVKoooooolc<c?o^k^koooooonk^k_o<c<`6ooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`00000Cooooo`06o`000?nj^[[oooooonk^k_mgMgOo00000_ooool01_mE
EEGoQhN7onk^k_ooooooQhN7oc8b<P;ooooo00KoIVIVogMgMoooooooooooohN7Qol0003Xooooo`00
S_ooool01Ol0003oooooooooooo<c<co000000?ooooo00Kok^k^oeEEEOl0003o0000odA4A?o^k^h4
ooooo`03o`000?oooooooooo00;ooooo00CoIVIVoiRHV?oooooo<S8b0_nj^[X01?l0003ooooooooo
ool0000Cooooo`03oa0@4?l0003o000000?o00003Oooool00onYZJWoMgMgooooo`0>ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Oo
oooo0ol00002ooooo`?o00001?ooool01_nYZJWo8B4Qo`000?l0003o<S8bo`0000;ooooo00Kok^k^
oeEEEOl0003o0000odA4A?o^k^h2ooooo`06onk^k_mVIVKo0000o`000?m4A4Co0000j?ooool008ko
oooo00Go0000ooooooooooooc<c<o`00000=ooooo`03o`000?oooooooooo00Gooooo00?oIVIVohN7
Qoooool00oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00_ooooo00Go410@oooo
oooooooooooooc8b<P0;ooooo`05o`000?nj^[[ooooooiRHV?l@41003?ooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo0?oooooo0_ooool008gooooo1?l000000ol@413oZJVYooooo`0<ooooo`;o00001_oo
ool00onYZJWoA4A4ooooo`02ooooo`;o00005Oooool00ol0003oooooooooo`0;ooooo`Go00002ooo
ool01OnHV9So410@o`000?lQ8B7oc<c<00[ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00;ooooo1?l00002ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0ooooool2ooooo`00ooooool6ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
ooooool2ooooo`00ooooool6ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0oooo
ool2ooooo`00ooooool5ooooo`;o00000oooool2o`000?oooooo1?ooool00?ooooooooooool@oooo
o`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooo
oooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo
003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooo
oooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool0
0?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooooooo
ool@ooooo`00oooooooooooooa3ooooo0000\
\>"],
  ImageRangeCache->{{{0, 525.688}, {324.5, 0}} -> {-2.58312*^-7, -6.34248*^6, \
6.65005*^-9, 53093.5}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0.309017 5.42214e-08 [
[.32684 .29652 -16.5 -12.5 ]
[.32684 .29652 16.5 0 ]
[.54329 .29652 -16.5 -12.5 ]
[.54329 .29652 16.5 0 ]
[.75974 .29652 -22.5 -12.5 ]
[.75974 .29652 22.5 0 ]
[.97619 .29652 -16.5 -12.5 ]
[.97619 .29652 16.5 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 64 6 ]
[.09789 .09213 -34.5 -6.25 ]
[.09789 .09213 0 6.25 ]
[.09789 .20057 -34.5 -6.25 ]
[.09789 .20057 0 6.25 ]
[.09789 .41746 -28.5 -6.25 ]
[.09789 .41746 0 6.25 ]
[.09789 .5259 -28.5 -6.25 ]
[.09789 .5259 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -62.8125 0 ]
[.5 .63053 62.8125 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 .30902 m
.32684 .31527 L
s
gsave
.32684 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 .30902 m
.54329 .31527 L
s
gsave
.54329 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 .30902 m
.75974 .31527 L
s
gsave
.75974 .29652 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 .30902 m
.15368 .31277 L
s
.19697 .30902 m
.19697 .31277 L
s
.24026 .30902 m
.24026 .31277 L
s
.28355 .30902 m
.28355 .31277 L
s
.37013 .30902 m
.37013 .31277 L
s
.41342 .30902 m
.41342 .31277 L
s
.45671 .30902 m
.45671 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.58658 .30902 m
.58658 .31277 L
s
.62987 .30902 m
.62987 .31277 L
s
.67316 .30902 m
.67316 .31277 L
s
.71645 .30902 m
.71645 .31277 L
s
.80303 .30902 m
.80303 .31277 L
s
.84632 .30902 m
.84632 .31277 L
s
.88961 .30902 m
.88961 .31277 L
s
.9329 .30902 m
.9329 .31277 L
s
.0671 .30902 m
.0671 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09213 m
.11664 .09213 L
s
gsave
.09789 .09213 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .20057 m
.11664 .20057 L
s
gsave
.09789 .20057 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .41746 m
.11664 .41746 L
s
gsave
.09789 .41746 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .5259 m
.11664 .5259 L
s
gsave
.09789 .5259 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.11039 .11924 m
.11414 .11924 L
s
.11039 .14635 m
.11414 .14635 L
s
.11039 .17346 m
.11414 .17346 L
s
.11039 .22768 m
.11414 .22768 L
s
.11039 .2548 m
.11414 .2548 L
s
.11039 .28191 m
.11414 .28191 L
s
.11039 .33613 m
.11414 .33613 L
s
.11039 .36324 m
.11414 .36324 L
s
.11039 .39035 m
.11414 .39035 L
s
.11039 .44457 m
.11414 .44457 L
s
.11039 .47168 m
.11414 .47168 L
s
.11039 .49879 m
.11414 .49879 L
s
.11039 .06502 m
.11414 .06502 L
s
.11039 .03791 m
.11414 .03791 L
s
.11039 .0108 m
.11414 .0108 L
s
.11039 .55301 m
.11414 .55301 L
s
.11039 .58012 m
.11414 .58012 L
s
.11039 .60723 m
.11414 .60723 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -123.812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.812 moveto
(@) show
81.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.812 moveto
(D) show
93.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7.4) show
135.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
141.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
153.000 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
157.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
166.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
184.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02418 .30902 L
.02453 .30902 L
.02473 .30902 L
.02491 .30902 L
.02501 .30902 L
.02512 .30902 L
.02523 .30902 L
.02532 .30902 L
.02541 .30902 L
.02551 .30902 L
.0256 .30902 L
.02569 .30902 L
.02579 .30902 L
.02584 .30902 L
.02589 .30902 L
.02609 .30902 L
.0262 .30902 L
.0263 .30902 L
.02649 .30902 L
.02669 .30902 L
.02691 .30902 L
.02732 .30902 L
.02776 .30902 L
.02854 .30902 L
.02897 .30902 L
.02944 .30902 L
.03029 .30902 L
.03111 .30902 L
.032 .30902 L
.03284 .30902 L
.03361 .30902 L
.03511 .30902 L
.03596 .30902 L
.03676 .30902 L
.03838 .30902 L
.03987 .30902 L
.04139 .30902 L
.04305 .30902 L
.04462 .30902 L
.04631 .30902 L
.04802 .30902 L
.04964 .30902 L
.05124 .30902 L
.05272 .30902 L
.05423 .30902 L
.05589 .30902 L
.05745 .30902 L
.05913 .30902 L
.06071 .30902 L
Mistroke
.06244 .30902 L
.06563 .30902 L
.06721 .30902 L
.0689 .30902 L
.0705 .30902 L
.07224 .30902 L
.07546 .30902 L
.07875 .30902 L
.08193 .30902 L
.08498 .30902 L
.08823 .30902 L
.09136 .30902 L
.09468 .30902 L
.09788 .30902 L
.09935 .30902 L
.10018 .30902 L
.10096 .30902 L
.10173 .30902 L
.10212 .30902 L
.10235 .30902 L
.10255 .30902 L
.10278 .30902 L
.10298 .30902 L
.10309 .30902 L
.1032 .30902 L
.10326 .30902 L
.10332 .30902 L
.10338 .30902 L
.10343 .30902 L
.10353 .30902 L
.10362 .30902 L
.10368 .30902 L
.10373 .30902 L
.10383 .30902 L
.10393 .30902 L
.10403 .30902 L
.10413 .30902 L
.10424 .30902 L
.10443 .30902 L
.10463 .30902 L
.10499 .30902 L
.10538 .30902 L
.1058 .30902 L
.10656 .30902 L
.10727 .30902 L
.10811 .30902 L
.10891 .30902 L
.1104 .30902 L
.11118 .30902 L
.112 .30902 L
Mistroke
.11349 .30902 L
.11505 .30902 L
.11652 .30902 L
.11815 .30902 L
.11964 .30902 L
.12129 .30902 L
.12283 .30902 L
.12589 .30902 L
.12904 .30902 L
.13238 .30902 L
.13559 .30902 L
.13869 .30902 L
.14198 .30902 L
.14362 .30902 L
.14515 .30902 L
.14591 .30902 L
.14663 .30902 L
.14702 .30902 L
.14745 .30902 L
.14784 .30902 L
.14802 .30902 L
.1482 .30902 L
.1483 .30902 L
.1484 .30902 L
.14849 .30902 L
.14858 .30902 L
.14868 .30902 L
.14873 .30902 L
.14878 .30902 L
.14888 .30902 L
.14898 .30902 L
.14906 .30902 L
.14916 .30902 L
.14926 .30902 L
.14935 .30902 L
.14952 .30902 L
.1497 .30902 L
.14991 .30902 L
.15015 .30902 L
.15057 .30902 L
.15098 .30902 L
.15136 .30902 L
.15221 .30902 L
.15301 .30902 L
.15373 .30902 L
.1545 .30902 L
.15611 .30902 L
.1578 .30902 L
.15938 .30902 L
.16085 .30902 L
Mistroke
.16398 .30902 L
.16569 .30902 L
.16731 .30902 L
.17039 .30902 L
.17367 .30902 L
.17683 .30902 L
.17986 .30902 L
.18142 .30902 L
.1823 .30902 L
.18268 .30902 L
.1831 .30902 L
.18331 .30902 L
.18351 .30902 L
.18371 .30902 L
.18389 .30902 L
.18406 .30902 L
.18414 .30902 L
.18424 .30902 L
.18433 .30902 L
.18444 .30902 L
.18453 .30902 L
.18462 .30902 L
.18472 .30902 L
.18477 .30902 L
.18483 .30902 L
.18503 .30902 L
.18514 .30902 L
.18526 .30902 L
.18547 .30902 L
.1859 .30902 L
.18628 .30902 L
.18666 .30902 L
.18707 .30902 L
.1878 .30902 L
.18867 .30902 L
.18946 .30902 L
.191 .30902 L
.19267 .30902 L
.19427 .30902 L
.19595 .30902 L
.19899 .30901 L
.20223 .30901 L
.20535 .30901 L
.20866 .30901 L
.21031 .309 L
.21112 .309 L
.21185 .309 L
.21256 .309 L
.21334 .309 L
.21376 .309 L
Mistroke
.21395 .309 L
.21415 .309 L
.21434 .309 L
.21444 .309 L
.21452 .309 L
.21462 .309 L
.21471 .309 L
.21481 .309 L
.21492 .309 L
.21502 .309 L
.21511 .309 L
.2152 .309 L
.21531 .309 L
.21548 .309 L
.21567 .309 L
.21588 .309 L
.21611 .309 L
.21651 .309 L
.21696 .309 L
.21739 .309 L
.21819 .309 L
.21898 .30901 L
.2198 .30901 L
.22129 .30901 L
.22286 .30901 L
.22433 .30902 L
.22745 .30903 L
.23077 .30905 L
.23396 .30907 L
.23703 .30909 L
.23862 .3091 L
.23942 .3091 L
.23985 .30911 L
.2403 .30911 L
.24069 .30911 L
.24089 .30911 L
.24111 .30911 L
.24131 .30911 L
.2415 .30911 L
.24158 .30911 L
.24168 .30911 L
.24177 .30911 L
.24185 .30911 L
.24195 .30911 L
.24205 .30911 L
.24215 .30911 L
.24224 .30911 L
.24234 .30911 L
.24246 .30911 L
.24267 .30911 L
Mistroke
.24288 .30911 L
.24311 .30911 L
.24353 .30911 L
.24396 .30911 L
.24435 .3091 L
.24525 .3091 L
.24603 .30909 L
.24686 .30908 L
.24844 .30906 L
.24991 .30903 L
.25304 .30896 L
.25636 .30885 L
.25956 .30874 L
.26102 .30869 L
.26263 .30864 L
.2634 .30862 L
.26422 .30861 L
.26468 .3086 L
.26509 .3086 L
.26549 .30859 L
.26569 .30859 L
.2658 .30859 L
.26591 .30859 L
.266 .30859 L
.26611 .30859 L
.26617 .30859 L
.26622 .30859 L
.26627 .30859 L
.26633 .30859 L
.26638 .30859 L
.26644 .30859 L
.26654 .30859 L
.26664 .30859 L
.26673 .30859 L
.26683 .30859 L
.26692 .30859 L
.2671 .30859 L
.26728 .30859 L
.26748 .30859 L
.26791 .3086 L
.26836 .30861 L
.26916 .30863 L
.26993 .30865 L
.27074 .30869 L
.27222 .30877 L
.27393 .30891 L
.27554 .30907 L
.27862 .30945 L
.2819 .30991 L
.28353 .31012 L
Mistroke
.28506 .3103 L
.28581 .31037 L
.28652 .31043 L
.28691 .31046 L
.28734 .31048 L
.2877 .3105 L
.28809 .31051 L
.28831 .31052 L
.28841 .31052 L
.28852 .31052 L
.28861 .31053 L
.28871 .31053 L
.28877 .31053 L
.28882 .31053 L
.28892 .31053 L
.28902 .31053 L
.2891 .31053 L
.2892 .31053 L
.28931 .31053 L
.28939 .31052 L
.28948 .31052 L
.28967 .31052 L
.28988 .31051 L
.29009 .31051 L
.29048 .31049 L
.2909 .31046 L
.29135 .31042 L
.29218 .31033 L
.29293 .31022 L
.29461 .30989 L
.29615 .30947 L
.29781 .30891 L
.3011 .30754 L
.30426 .30615 L
.30585 .30554 L
.3073 .3051 L
.3081 .30492 L
.30846 .30486 L
.30886 .3048 L
.30907 .30477 L
.30927 .30476 L
.30947 .30474 L
.30966 .30473 L
.30976 .30473 L
.30982 .30472 L
.30988 .30472 L
.30997 .30472 L
.31008 .30472 L
.31014 .30472 L
.31019 .30472 L
Mistroke
.3103 .30472 L
.31036 .30472 L
.31041 .30473 L
.31053 .30473 L
.31073 .30474 L
.31091 .30476 L
.31131 .30481 L
.31166 .30486 L
.31203 .30494 L
.31282 .30516 L
.31369 .3055 L
.31526 .30636 L
.31694 .30764 L
.32028 .31103 L
.32349 .31479 L
.32496 .31638 L
.3258 .31719 L
.32658 .31785 L
.32741 .31844 L
.32818 .31885 L
.32859 .31902 L
.32899 .31914 L
.32921 .31919 L
.32941 .31922 L
.32953 .31924 L
.32963 .31925 L
.32969 .31925 L
.32975 .31926 L
.32981 .31926 L
.32987 .31926 L
.32997 .31926 L
.33006 .31926 L
.33015 .31925 L
.33025 .31925 L
.33035 .31924 L
.33046 .31922 L
.33065 .31919 L
.33083 .31914 L
.331 .31909 L
.33138 .31895 L
.3318 .31874 L
.33218 .3185 L
.33304 .31778 L
.33383 .31691 L
.33457 .31592 L
.33623 .31306 L
.33937 .30579 L
.34271 .297 L
.34438 .29307 L
.34512 .29159 L
Mistroke
.34592 .29021 L
.3467 .28916 L
.34707 .28876 L
.34743 .28845 L
.34762 .28831 L
.34783 .28818 L
.348 .28809 L
.34819 .28802 L
.3483 .28799 L
.3484 .28796 L
.34851 .28795 L
.34857 .28794 L
.34862 .28793 L
.34871 .28793 L
.34881 .28793 L
.34892 .28794 L
.34902 .28796 L
.34912 .28798 L
.34923 .28801 L
.34942 .28809 L
.34963 .2882 L
.34986 .28836 L
.35027 .28873 L
.35066 .28918 L
.35138 .29031 L
.35215 .29192 L
.35385 .29691 L
.35546 .3033 L
.35853 .31849 L
.36025 .32748 L
.3618 .33502 L
.36258 .33836 L
.36342 .3415 L
.36421 .34391 L
.36494 .34563 L
.36531 .34628 L
.36571 .3468 L
.36593 .34701 L
.36604 .3471 L
.36615 .34716 L
.36624 .34721 L
.36634 .34725 L
.36644 .34728 L
.36649 .34729 L
.36655 .34729 L
.36665 .34729 L
.3667 .34729 L
.36675 .34728 L
.36686 .34725 L
.36692 .34723 L
Mistroke
.36697 .34721 L
.36707 .34716 L
.36717 .34709 L
.36736 .34693 L
.36758 .34668 L
.36782 .34635 L
.36824 .34557 L
.36864 .34461 L
.369 .34355 L
.36981 .34053 L
.37128 .33289 L
.37281 .32228 L
.37448 .30834 L
.37775 .27827 L
.37937 .26479 L
.38017 .25917 L
.3809 .25477 L
.38161 .25132 L
.38197 .2499 L
.38235 .24865 L
.38256 .24811 L
.38274 .24769 L
.38293 .24734 L
.3831 .24708 L
.3832 .24696 L
.38331 .24686 L
.38341 .24678 L
.38347 .24674 L
.38353 .24672 L
.38363 .24669 L
.38372 .24668 L
.38382 .2467 L
.38393 .24674 L
.38403 .24679 L
.38413 .24688 L
.38433 .24712 L
.38452 .24742 L
.3847 .24778 L
.38509 .24886 L
.38552 .2504 L
.38622 .25389 L
.38699 .25902 L
.38856 .27336 L
.39024 .29369 L
.39356 .34185 L
.39522 .36514 L
.39595 .37426 L
.39676 .38314 L
.39748 .38979 L
.39825 .39541 L
Mistroke
.39868 .39776 L
.39886 .39861 L
.39907 .39941 L
.39925 .4 L
.39944 .40051 L
.39955 .40074 L
.39965 .40092 L
.39974 .40106 L
.39984 .40117 L
.39993 .40124 L
.40002 .40129 L
.40008 .4013 L
.40013 .40131 L
.40023 .40128 L
.40033 .40123 L
.40042 .40114 L
.40053 .40101 L
.40064 .40082 L
.40084 .40038 L
.40103 .39983 L
.40138 .39846 L
.4018 .39623 L
.40218 .39363 L
.40305 .38583 L
.40383 .37655 L
.40456 .36613 L
.40622 .33707 L
.40935 .27091 L
.41094 .23798 L
.41178 .22253 L
.41268 .20831 L
.41347 .19799 L
.41389 .19353 L
.41434 .18959 L
.41476 .1868 L
.41514 .18496 L
.41532 .18433 L
.41541 .18406 L
.41552 .18383 L
.41562 .18366 L
.4157 .18354 L
.41579 .18347 L
.41588 .18343 L
.41597 .18344 L
.41607 .1835 L
.41617 .1836 L
.41625 .18373 L
.41635 .18394 L
.41646 .18422 L
.41666 .1849 L
Mistroke
.41687 .18583 L
.41709 .18707 L
.41749 .18994 L
.41819 .19704 L
.41897 .20779 L
.42052 .23756 L
.4222 .2796 L
.4255 .3747 L
.42715 .41717 L
.42795 .43433 L
.42868 .44725 L
.42904 .45263 L
.42944 .45758 L
.42978 .46109 L
.43016 .4641 L
.43036 .46535 L
.43056 .46627 L
.43066 .46666 L
.43076 .46697 L
.43081 .4671 L
.43087 .46723 L
.43098 .4674 L
.43108 .46748 L
.43117 .4675 L
.43127 .46746 L
.43137 .46734 L
.43146 .46717 L
.43155 .46697 L
.43174 .46632 L
.43193 .46538 L
.43211 .46428 L
.43252 .46099 L
.43289 .45691 L
.43325 .45217 L
.43404 .4385 L
.43491 .41917 L
.4365 .37332 L
.43818 .31465 L
.44122 .20648 L
.44277 .1621 L
.44365 .14342 L
.44403 .13687 L
.44445 .13114 L
.44466 .12872 L
.44486 .12678 L
.44506 .1252 L
.44524 .12404 L
.44541 .12319 L
.44549 .12285 L
.44559 .12256 L
Mistroke
.44568 .12234 L
.44578 .12219 L
.44588 .12214 L
.44597 .12216 L
.44607 .12226 L
.44612 .12235 L
.44618 .12248 L
.44628 .12278 L
.44638 .12313 L
.44659 .12423 L
.44682 .12586 L
.44724 .13005 L
.44763 .13524 L
.44842 .14962 L
.44915 .1674 L
.45081 .22127 L
.45394 .3518 L
.45553 .41716 L
.45637 .44734 L
.45726 .4745 L
.45806 .49357 L
.45851 .502 L
.45893 .50818 L
.45913 .5105 L
.45932 .51234 L
.45949 .51371 L
.45967 .51485 L
.45978 .51534 L
.45987 .51569 L
.45996 .51596 L
.46005 .51613 L
.46016 .51622 L
.46025 .5162 L
.46036 .51608 L
.46041 .51597 L
.46047 .51582 L
.46057 .51547 L
.46067 .51504 L
.46089 .51371 L
.46108 .51213 L
.46129 .51003 L
.46164 .5054 L
.46204 .49884 L
.4629 .47913 L
.46371 .45461 L
.46682 .32311 L
.4684 .24784 L
.47012 .17363 L
.47092 .1454 L
.47177 .12103 L
Mistroke
.47218 .11166 L
.47257 .10439 L
.47292 .09924 L
.4733 .09515 L
.47349 .09372 L
.4736 .09309 L
.4737 .09262 L
.47379 .09228 L
.47389 .09201 L
.47398 .09187 L
.47406 .09182 L
.47412 .09183 L
.47417 .09188 L
.47428 .09206 L
.47438 .09236 L
.47447 .09272 L
.47457 .09324 L
.47468 .09393 L
.4749 .09573 L
.47512 .09809 L
.47532 .10071 L
.47577 .10821 L
.47659 .12718 L
.47739 .15201 L
.47812 .17974 L
.47979 .25506 L
.48142 .33665 L
.48295 .40991 L
.48441 .4683 L
.48523 .49337 L
.48598 .51036 L
.48636 .51662 L
.48657 .51935 L
.48677 .52145 L
.48696 .523 L
.48705 .52366 L
.48715 .52423 L
.48724 .52461 L
.48734 .52493 L
.48742 .52513 L
.4875 .52523 L
.48761 .52525 L
.48766 .5252 L
.48772 .52512 L
.48782 .52488 L
.48792 .5245 L
.48802 .52405 L
.4881 .52353 L
.48831 .52201 L
.48852 .51984 L
Mistroke
.48872 .51737 L
.48917 .51014 L
.48995 .4921 L
.49068 .46968 L
.49234 .4025 L
.49548 .24854 L
.49707 .17867 L
.49791 .1492 L
.49837 .13584 L
.4988 .12529 L
.49922 .11702 L
.4996 .11116 L
.49981 .10857 L
.50002 .10661 L
.50024 .10509 L
.50036 .10447 L
.50042 .10424 L
.50047 .10406 L
.50057 .10384 L
.50067 .10372 L
.50077 .10372 L
.50086 .10384 L
.50095 .10404 L
.50103 .1043 L
.50112 .10469 L
.50122 .10521 L
.50143 .10675 L
.50163 .10871 L
.50201 .11364 L
.50238 .12001 L
.50279 .12875 L
.50361 .15157 L
.50509 .20693 L
.50832 .35742 L
.5098 .42014 L
.51064 .44909 L
.51143 .47038 L
.51183 .47892 L
.5122 .48541 L
.51241 .48834 L
.51264 .49095 L
.51285 .49282 L
.51304 .49412 L
.51313 .49463 L
.51324 .49506 L
.51334 .49534 L
.51343 .49551 L
.51353 .49558 L
.51359 .49556 L
.51365 .49551 L
Mistroke
.51375 .49532 L
.51381 .49517 L
.51386 .495 L
.51397 .49452 L
.51408 .49395 L
.51431 .49223 L
.51451 .49021 L
.51473 .48758 L
.51513 .4814 L
.51549 .47435 L
.51631 .45387 L
.51778 .4035 L
.52099 .26711 L
.52246 .21118 L
.52329 .18554 L
.5237 .17508 L
.52407 .16682 L
.52444 .16002 L
.52484 .1541 L
.52506 .15155 L
.52526 .14963 L
.52546 .14819 L
.52556 .1476 L
.52566 .1471 L
.52572 .14688 L
.52578 .14669 L
.52588 .14643 L
.52594 .14634 L
.526 .14628 L
.52606 .14626 L
.52612 .14628 L
.52622 .1464 L
.52628 .14652 L
.52634 .14667 L
.52644 .14701 L
.52655 .1475 L
.52674 .14869 L
.52693 .15017 L
.52735 .15481 L
.52773 .16042 L
.52814 .16805 L
.52897 .18777 L
.53046 .23462 L
.53216 .29858 L
.53371 .35624 L
.53448 .38189 L
.53532 .40584 L
.53611 .42386 L
.53684 .43592 L
.53722 .4403 L
Mistroke
.53743 .4422 L
.53762 .44357 L
.5378 .44455 L
.5379 .44497 L
.53799 .44528 L
.53808 .44549 L
.53817 .44562 L
.53826 .4457 L
.53835 .4457 L
.53845 .44561 L
.53855 .44542 L
.5386 .44529 L
.53866 .44511 L
.53876 .44473 L
.53896 .4437 L
.53915 .44246 L
.53959 .43824 L
.54001 .43274 L
.54078 .41892 L
.54161 .39979 L
.54309 .35705 L
.54612 .26183 L
.54688 .24188 L
.54767 .22432 L
.54809 .21675 L
.54855 .20988 L
.54896 .20497 L
.54935 .20159 L
.54956 .20023 L
.54976 .19928 L
.54986 .19891 L
.54997 .19859 L
.55003 .19847 L
.55009 .19836 L
.55014 .19829 L
.5502 .19825 L
.5503 .19822 L
.55039 .19827 L
.5505 .19841 L
.55055 .19851 L
.55061 .19864 L
.5507 .19892 L
.55081 .19931 L
.55099 .20021 L
.55118 .20133 L
.55137 .20282 L
.55177 .2067 L
.55249 .2163 L
.55331 .23111 L
.55406 .2474 L
Mistroke
.55574 .28996 L
.55741 .33312 L
.55814 .35018 L
.55895 .36655 L
.55967 .37849 L
.56006 .38384 L
.56044 .38805 L
.56065 .38996 L
.56087 .39175 L
.56108 .39311 L
.56126 .39411 L
.56145 .39491 L
.56156 .39525 L
.56166 .3955 L
.56175 .39568 L
.56184 .39579 L
.56193 .39587 L
.56203 .39588 L
.56213 .39583 L
.56218 .39578 L
.56223 .39572 L
.56233 .39555 L
.56243 .39531 L
.5626 .39476 L
.56279 .39394 L
.56299 .39282 L
.56321 .39135 L
.56361 .38799 L
.56437 .37909 L
.56508 .36855 L
.56826 .30575 L
.56986 .27543 L
.57056 .26458 L
.57132 .25506 L
.57174 .25089 L
.57213 .2478 L
.5725 .24556 L
.57269 .24469 L
.57289 .24395 L
.57301 .24363 L
.57311 .24339 L
.57321 .24323 L
.57331 .2431 L
.57337 .24305 L
.57343 .24303 L
.57349 .24301 L
.57355 .24302 L
.57365 .24307 L
.57371 .24312 L
.57376 .24319 L
Mistroke
.57386 .24334 L
.57395 .24352 L
.57416 .2441 L
.57436 .24485 L
.57458 .24587 L
.575 .2485 L
.5754 .25163 L
.57628 .26089 L
.5779 .28345 L
.57953 .30931 L
.58106 .33167 L
.58181 .34075 L
.58252 .34779 L
.58291 .35092 L
.58334 .35368 L
.58353 .35467 L
.58373 .35557 L
.5839 .35622 L
.58409 .3568 L
.5843 .35727 L
.58442 .35746 L
.58447 .35753 L
.58452 .35759 L
.58462 .35767 L
.58471 .35771 L
.58481 .35771 L
.58487 .3577 L
.58492 .35767 L
.58502 .35759 L
.58512 .35748 L
.58523 .35731 L
.58535 .35708 L
.58559 .35645 L
.58581 .35569 L
.58619 .35399 L
.5866 .3516 L
.58743 .34526 L
.589 .3291 L
.59068 .3093 L
.59228 .29208 L
.59318 .28436 L
.59361 .28136 L
.59401 .27899 L
.5944 .27714 L
.59475 .27582 L
.59494 .27527 L
.59515 .27479 L
.59526 .27458 L
.59536 .27441 L
.59547 .27428 L
Mistroke
.59557 .27419 L
.59567 .27412 L
.59573 .2741 L
.59579 .27408 L
.59588 .27408 L
.59594 .27409 L
.59599 .27411 L
.59608 .27416 L
.59617 .27423 L
.59627 .27434 L
.59637 .27447 L
.59658 .27485 L
.59678 .27531 L
.59722 .27671 L
.59759 .27827 L
.59799 .28029 L
.59872 .28477 L
.60037 .2977 L
.60195 .31114 L
.60279 .31771 L
.60368 .32378 L
.60412 .32634 L
.60454 .32842 L
.60495 .33012 L
.60533 .33138 L
.60569 .3323 L
.60587 .33267 L
.60606 .33298 L
.60626 .33322 L
.60637 .33331 L
.60648 .33337 L
.60657 .33341 L
.60667 .33343 L
.60677 .33343 L
.60686 .33341 L
.60697 .33337 L
.60702 .33334 L
.60708 .3333 L
.60727 .33311 L
.60738 .33298 L
.6075 .3328 L
.60771 .33242 L
.60813 .33142 L
.60851 .33024 L
.60928 .32718 L
.61001 .32361 L
.61309 .30559 L
.61468 .29789 L
.61549 .29514 L
.61594 .29398 L
Mistroke
.61617 .29353 L
.61637 .29317 L
.61658 .29288 L
.61677 .29267 L
.61687 .29259 L
.61698 .29251 L
.61704 .29247 L
.6171 .29245 L
.61715 .29242 L
.61721 .2924 L
.6173 .29238 L
.61739 .29238 L
.61749 .29238 L
.61759 .2924 L
.61769 .29244 L
.61775 .29246 L
.6178 .29249 L
.618 .29264 L
.61817 .29281 L
.61834 .29301 L
.61872 .29361 L
.61909 .29436 L
.61948 .29535 L
.62109 .30077 L
.62279 .30771 L
.62439 .31381 L
.62509 .31599 L
.62585 .31788 L
.62627 .31869 L
.62665 .31927 L
.62703 .31969 L
.62721 .31984 L
.62742 .31997 L
.62753 .32002 L
.62759 .32004 L
.62764 .32005 L
.62773 .32008 L
.62784 .32009 L
.6279 .32009 L
.62795 .32009 L
.62806 .32008 L
.62811 .32007 L
.62817 .32006 L
.62829 .32002 L
.62839 .31998 L
.62848 .31993 L
.62868 .31979 L
.62889 .31962 L
.6291 .3194 L
.62992 .31819 L
Mistroke
.63081 .31634 L
.63242 .31212 L
.63398 .30787 L
.63481 .30586 L
.6357 .30408 L
.63612 .30341 L
.63655 .30282 L
.63692 .30243 L
.63714 .30224 L
.63733 .3021 L
.63751 .302 L
.63771 .30191 L
.63782 .30187 L
.63792 .30185 L
.63802 .30183 L
.63812 .30182 L
.63821 .30181 L
.6383 .30181 L
.63839 .30182 L
.63847 .30183 L
.63857 .30185 L
.63867 .30187 L
.63886 .30194 L
.63904 .30202 L
.63925 .30214 L
.63961 .30242 L
.64005 .30284 L
.64044 .30332 L
.64213 .30596 L
.64377 .30894 L
.64458 .31029 L
.64531 .31138 L
.64602 .31226 L
.64678 .31298 L
.64721 .31326 L
.64739 .31336 L
.6476 .31345 L
.64779 .31351 L
.64797 .31356 L
.64807 .31358 L
.64816 .31359 L
.64826 .3136 L
.64836 .31361 L
.64846 .31361 L
.64852 .3136 L
.64857 .3136 L
.64867 .31359 L
.64877 .31358 L
.64886 .31356 L
.64894 .31355 L
Mistroke
.64913 .3135 L
.64934 .31342 L
.64953 .31334 L
.64995 .31311 L
.65071 .31254 L
.65143 .31186 L
.65451 .30839 L
.65533 .30759 L
.6561 .30698 L
.65651 .30672 L
.6569 .30651 L
.65732 .30634 L
.65755 .30628 L
.65778 .30622 L
.65788 .3062 L
.65799 .30619 L
.65809 .30617 L
.65818 .30616 L
.65827 .30616 L
.65836 .30616 L
.65846 .30615 L
.65855 .30616 L
.65866 .30616 L
.65876 .30617 L
.65885 .30618 L
.65894 .30619 L
.65916 .30623 L
.65937 .30627 L
.65974 .30638 L
.66008 .30652 L
.66084 .30689 L
.66252 .30801 L
.66406 .30913 L
.66557 .31005 L
.66633 .31039 L
.66676 .31054 L
.66717 .31064 L
.66737 .31068 L
.66757 .31071 L
.66778 .31074 L
.66789 .31075 L
.66801 .31076 L
.66811 .31076 L
.6682 .31077 L
.66826 .31077 L
.66831 .31077 L
.66842 .31077 L
.66851 .31077 L
.66862 .31076 L
.66871 .31075 L
Mistroke
.6688 .31075 L
.66899 .31073 L
.66917 .31071 L
.66957 .31063 L
.66992 .31055 L
.67029 .31045 L
.67187 .30984 L
.67334 .30918 L
.67484 .30857 L
.67568 .3083 L
.67646 .30812 L
.67686 .30805 L
.67708 .30802 L
.67729 .308 L
.6774 .30799 L
.67751 .30798 L
.67761 .30798 L
.67771 .30797 L
.67777 .30797 L
.67782 .30797 L
.67793 .30797 L
.67799 .30797 L
.67805 .30797 L
.67811 .30797 L
.67817 .30797 L
.67826 .30797 L
.67836 .30797 L
.67845 .30797 L
.67854 .30798 L
.67875 .30799 L
.67895 .30801 L
.67935 .30805 L
.67978 .30812 L
.68061 .30829 L
.68136 .30847 L
.68305 .30893 L
.68386 .30914 L
.68472 .30933 L
.68546 .30946 L
.68588 .30952 L
.68627 .30957 L
.68646 .30958 L
.68666 .3096 L
.68684 .30961 L
.68704 .30962 L
.68714 .30963 L
.68725 .30963 L
.68731 .30963 L
.68736 .30963 L
.68742 .30963 L
Mistroke
.68747 .30964 L
.68756 .30964 L
.68766 .30964 L
.68776 .30964 L
.68787 .30964 L
.68797 .30963 L
.68806 .30963 L
.68827 .30962 L
.68846 .30962 L
.68865 .3096 L
.68899 .30958 L
.68936 .30955 L
.69018 .30945 L
.69093 .30934 L
.6926 .30907 L
.69341 .30895 L
.69426 .30883 L
.69499 .30876 L
.69541 .30872 L
.6958 .3087 L
.69617 .30868 L
.69636 .30867 L
.69656 .30866 L
.69667 .30866 L
.69677 .30866 L
.69682 .30866 L
.69688 .30866 L
.69693 .30866 L
.69699 .30866 L
.69709 .30866 L
.69719 .30866 L
.69729 .30866 L
.69738 .30866 L
.69747 .30866 L
.69758 .30866 L
.69776 .30867 L
.69794 .30867 L
.6981 .30868 L
.69847 .30869 L
.69887 .30871 L
.6997 .30877 L
.70059 .30885 L
.70221 .309 L
.70381 .30913 L
.70462 .30918 L
.70507 .3092 L
.7053 .3092 L
.7055 .30921 L
.70569 .30921 L
.7059 .30922 L
Mistroke
.70601 .30922 L
.70612 .30922 L
.70622 .30922 L
.70629 .30922 L
.70634 .30922 L
.70644 .30922 L
.70653 .30922 L
.70662 .30922 L
.70673 .30922 L
.70678 .30922 L
.70684 .30922 L
.70694 .30922 L
.70714 .30922 L
.70732 .30921 L
.70751 .30921 L
.70791 .3092 L
.70863 .30917 L
.71032 .30909 L
.71186 .30901 L
.71263 .30897 L
.71346 .30894 L
.71384 .30893 L
.71425 .30892 L
.71463 .30891 L
.71481 .30891 L
.71498 .30891 L
.71517 .3089 L
.71527 .3089 L
.71537 .3089 L
.71543 .3089 L
.71548 .3089 L
.71559 .3089 L
.71569 .3089 L
.71579 .3089 L
.71588 .3089 L
.71596 .3089 L
.71605 .3089 L
.71615 .3089 L
.71635 .3089 L
.71653 .30891 L
.71692 .30891 L
.71734 .30892 L
.7182 .30894 L
.71991 .30899 L
.72146 .30903 L
.72224 .30905 L
.72265 .30906 L
.72308 .30907 L
.72346 .30907 L
.72366 .30907 L
Mistroke
.72387 .30908 L
.72407 .30908 L
.72425 .30908 L
.72433 .30908 L
.72443 .30908 L
.72452 .30908 L
.7246 .30908 L
.72469 .30908 L
.72479 .30908 L
.72488 .30908 L
.72497 .30908 L
.72507 .30908 L
.72513 .30908 L
.72518 .30908 L
.72537 .30908 L
.72555 .30908 L
.72574 .30908 L
.7261 .30907 L
.72651 .30907 L
.72696 .30906 L
.72775 .30905 L
.72934 .30903 L
.73079 .309 L
.73159 .30899 L
.73196 .30899 L
.73235 .30899 L
.73257 .30899 L
.73276 .30899 L
.73297 .30898 L
.73315 .30898 L
.73337 .30898 L
.73348 .30898 L
.73354 .30898 L
.7336 .30898 L
.73371 .30898 L
.7338 .30898 L
.73386 .30898 L
.73392 .30898 L
.73402 .30898 L
.73412 .30898 L
.73422 .30898 L
.73439 .30898 L
.73461 .30898 L
.7348 .30898 L
.7352 .30899 L
.73562 .30899 L
.7371 .309 L
.73871 .30902 L
.73941 .30902 L
.74016 .30903 L
Mistroke
.74059 .30903 L
.74098 .30903 L
.74137 .30903 L
.74174 .30903 L
.74193 .30903 L
.74213 .30904 L
.74224 .30904 L
.74235 .30904 L
.74245 .30904 L
.74251 .30904 L
.74256 .30904 L
.74261 .30904 L
.74267 .30904 L
.74273 .30904 L
.74278 .30904 L
.74287 .30904 L
.74298 .30904 L
.74303 .30904 L
.74309 .30904 L
.74319 .30904 L
.74342 .30903 L
.74363 .30903 L
.74385 .30903 L
.74424 .30903 L
.74513 .30903 L
.74675 .30902 L
.74833 .30901 L
.74903 .30901 L
.74978 .30901 L
.7502 .30901 L
.7504 .30901 L
.75058 .30901 L
.75076 .30901 L
.75095 .30901 L
.75106 .30901 L
.75115 .30901 L
.75124 .30901 L
.75134 .30901 L
.75145 .30901 L
.75154 .30901 L
.75159 .30901 L
.75165 .30901 L
.75176 .30901 L
.75185 .30901 L
.75196 .30901 L
.75214 .30901 L
.75236 .30901 L
.75256 .30901 L
.75302 .30901 L
.75381 .30901 L
Mistroke
.75464 .30901 L
.75612 .30902 L
.75689 .30902 L
.75771 .30902 L
.7581 .30902 L
.75848 .30902 L
.75884 .30902 L
.75918 .30902 L
.75936 .30902 L
.75955 .30902 L
.75966 .30902 L
.75977 .30902 L
.75986 .30902 L
.75996 .30902 L
.76002 .30902 L
.76007 .30902 L
.76017 .30902 L
.76022 .30902 L
.76028 .30902 L
.76033 .30902 L
.76039 .30902 L
.76049 .30902 L
.76058 .30902 L
.76068 .30902 L
.76079 .30902 L
.76098 .30902 L
.76119 .30902 L
.76156 .30902 L
.76227 .30902 L
.76383 .30902 L
.76465 .30902 L
.76555 .30902 L
.7664 .30902 L
.76677 .30902 L
.76717 .30901 L
.76756 .30901 L
.76792 .30901 L
.76812 .30901 L
.7683 .30901 L
.7684 .30901 L
.76845 .30901 L
.7685 .30901 L
.76861 .30901 L
.7687 .30901 L
.7688 .30901 L
.76885 .30901 L
.7689 .30901 L
.769 .30901 L
.7691 .30901 L
.76919 .30901 L
Mistroke
.76927 .30901 L
.76946 .30901 L
.76966 .30901 L
.76985 .30901 L
.77027 .30901 L
.77099 .30902 L
.77175 .30902 L
.77335 .30902 L
.77404 .30902 L
.7748 .30902 L
.77522 .30902 L
.77561 .30902 L
.77598 .30902 L
.77637 .30902 L
.77657 .30902 L
.77668 .30902 L
.77679 .30902 L
.77688 .30902 L
.77699 .30902 L
.77708 .30902 L
.77717 .30902 L
.77723 .30902 L
.77729 .30902 L
.77735 .30902 L
.7774 .30902 L
.7775 .30902 L
.7776 .30902 L
.77765 .30902 L
.77771 .30902 L
.77782 .30902 L
.77805 .30902 L
.77826 .30902 L
.77848 .30902 L
.77887 .30902 L
.77976 .30902 L
.78138 .30902 L
.78215 .30902 L
.78296 .30902 L
.78365 .30902 L
.78405 .30902 L
.78441 .30902 L
.7848 .30902 L
.78501 .30902 L
.78511 .30902 L
.78521 .30902 L
.7853 .30902 L
.7854 .30902 L
.78549 .30902 L
.78557 .30902 L
.78567 .30902 L
Mistroke
.78576 .30902 L
.78586 .30902 L
.78596 .30902 L
.78607 .30902 L
.78616 .30902 L
.78638 .30902 L
.78657 .30902 L
.78676 .30902 L
.78718 .30902 L
.78763 .30902 L
.78921 .30902 L
.79004 .30902 L
.79093 .30902 L
.79179 .30902 L
.7922 .30902 L
.79257 .30902 L
.79295 .30902 L
.79315 .30902 L
.79336 .30902 L
.79345 .30902 L
.79354 .30902 L
.79363 .30902 L
.79372 .30902 L
.79382 .30902 L
.79392 .30902 L
.79402 .30902 L
.79411 .30902 L
.79421 .30902 L
.79426 .30902 L
.79432 .30902 L
.79442 .30902 L
.79451 .30902 L
.79473 .30902 L
.79495 .30902 L
.79537 .30902 L
.79575 .30902 L
.79725 .30902 L
.79891 .30902 L
.79964 .30902 L
.80002 .30902 L
.80044 .30902 L
.80084 .30902 L
.80121 .30902 L
.80139 .30902 L
.80156 .30902 L
.80174 .30902 L
.80183 .30902 L
.80193 .30902 L
.80198 .30902 L
.80204 .30902 L
Mistroke
.80214 .30902 L
.80224 .30902 L
.8023 .30902 L
.80236 .30902 L
.80246 .30902 L
.80255 .30902 L
.80261 .30902 L
.80266 .30902 L
.80276 .30902 L
.80295 .30902 L
.80315 .30902 L
.80352 .30902 L
.80395 .30902 L
.80434 .30902 L
.80524 .30902 L
.80686 .30902 L
.80759 .30902 L
.80837 .30902 L
.80882 .30902 L
.80923 .30902 L
.80943 .30902 L
.80964 .30902 L
.80984 .30902 L
.81003 .30902 L
.81012 .30902 L
.81022 .30902 L
.81031 .30902 L
.8104 .30902 L
.8105 .30902 L
.81056 .30902 L
.81061 .30902 L
.81071 .30902 L
.8108 .30902 L
.81089 .30902 L
.81099 .30902 L
.81115 .30902 L
.81153 .30902 L
.81194 .30902 L
.81232 .30902 L
.81318 .30902 L
.81468 .30902 L
.81547 .30902 L
.8163 .30902 L
.81672 .30902 L
.81719 .30902 L
.81739 .30902 L
.81761 .30902 L
.81782 .30902 L
.818 .30902 L
.8181 .30902 L
Mistroke
.8182 .30902 L
.81829 .30902 L
.81838 .30902 L
.81848 .30902 L
.81854 .30902 L
.81859 .30902 L
.81869 .30902 L
.81879 .30902 L
.81889 .30902 L
.81899 .30902 L
.81918 .30902 L
.81941 .30902 L
.81962 .30902 L
.82041 .30902 L
.82114 .30902 L
.82281 .30902 L
.82365 .30902 L
.82445 .30902 L
.8248 .30902 L
.82517 .30902 L
.82536 .30902 L
.82558 .30902 L
.82577 .30902 L
.82595 .30902 L
.82604 .30902 L
.82615 .30902 L
.82626 .30902 L
.82631 .30902 L
.82637 .30902 L
.82647 .30902 L
.82656 .30902 L
.82666 .30902 L
.82677 .30902 L
.82686 .30902 L
.82695 .30902 L
.82712 .30902 L
.82733 .30902 L
.82751 .30902 L
.82793 .30902 L
.82838 .30902 L
.82919 .30902 L
.83076 .30902 L
.83159 .30902 L
.83204 .30902 L
.83248 .30902 L
.83289 .30902 L
.8331 .30902 L
.83333 .30902 L
.83354 .30902 L
.83374 .30902 L
Mistroke
.83383 .30902 L
.83393 .30902 L
.83402 .30902 L
.83411 .30902 L
.83421 .30902 L
.8343 .30902 L
.8344 .30902 L
.8345 .30902 L
.8346 .30902 L
.83466 .30902 L
.83471 .30902 L
.83481 .30902 L
.83491 .30902 L
.83509 .30902 L
.83526 .30902 L
.83564 .30902 L
.83602 .30902 L
.83643 .30902 L
.83726 .30902 L
.83875 .30902 L
.83956 .30902 L
.84033 .30902 L
.84075 .30902 L
.84097 .30902 L
.84121 .30902 L
.84141 .30902 L
.84163 .30902 L
.84172 .30902 L
.84182 .30902 L
.84192 .30902 L
.84201 .30902 L
.84211 .30902 L
.84216 .30902 L
.84221 .30902 L
.84227 .30902 L
.84233 .30902 L
.84243 .30902 L
.84253 .30902 L
.84262 .30902 L
.84272 .30902 L
.84282 .30902 L
.84306 .30902 L
.84329 .30902 L
.84371 .30902 L
.84449 .30902 L
.84533 .30902 L
.84689 .30902 L
.84778 .30902 L
.8482 .30902 L
.84861 .30902 L
Mistroke
.84899 .30902 L
.8492 .30902 L
.8494 .30902 L
.8495 .30902 L
.84959 .30902 L
.84967 .30902 L
.84976 .30902 L
.84985 .30902 L
.84994 .30902 L
.85003 .30902 L
.85013 .30902 L
.85018 .30902 L
.85024 .30902 L
.85035 .30902 L
.85045 .30902 L
.85054 .30902 L
.85075 .30902 L
.85098 .30902 L
.85135 .30902 L
.85177 .30902 L
.85345 .30902 L
.85419 .30902 L
.855 .30902 L
.85538 .30902 L
.85578 .30902 L
.85613 .30902 L
.85651 .30902 L
.85674 .30902 L
.85694 .30902 L
.85714 .30902 L
.85724 .30902 L
.85735 .30902 L
.85744 .30902 L
.85753 .30902 L
.85762 .30902 L
.85771 .30902 L
.85781 .30902 L
.8579 .30902 L
.858 .30902 L
.85805 .30902 L
.8581 .30902 L
.85829 .30902 L
.8584 .30902 L
.8585 .30902 L
.85891 .30902 L
.85927 .30902 L
.85965 .30902 L
.86133 .30902 L
.8621 .30902 L
.86292 .30902 L
Mistroke
.86335 .30902 L
.86382 .30902 L
.86403 .30902 L
.86425 .30902 L
.86444 .30902 L
.86465 .30902 L
.86476 .30902 L
.86487 .30902 L
.86497 .30902 L
.86506 .30902 L
.86517 .30902 L
.86523 .30902 L
.86529 .30902 L
.8654 .30902 L
.86546 .30902 L
.86551 .30902 L
.86562 .30902 L
.86572 .30902 L
.86581 .30902 L
.8659 .30902 L
.86612 .30902 L
.86633 .30902 L
.86668 .30902 L
.86707 .30902 L
.86786 .30902 L
.86954 .30902 L
.87028 .30902 L
.87067 .30902 L
.87108 .30902 L
.87149 .30902 L
.87187 .30902 L
.87205 .30902 L
.87224 .30902 L
.87242 .30902 L
.87259 .30902 L
.87269 .30902 L
.87278 .30902 L
.87288 .30902 L
.87296 .30902 L
.87306 .30902 L
.87312 .30902 L
.87317 .30902 L
.87327 .30902 L
.87337 .30902 L
.87347 .30902 L
.87359 .30902 L
.8738 .30902 L
.87419 .30902 L
.87458 .30902 L
.87495 .30902 L
Mistroke
.87579 .30902 L
.87666 .30902 L
.87748 .30902 L
.87827 .30902 L
.87868 .30902 L
.87912 .30902 L
.87949 .30902 L
.8797 .30902 L
.87989 .30902 L
.87998 .30902 L
.88007 .30902 L
.88015 .30902 L
.88024 .30902 L
.88033 .30902 L
.88041 .30902 L
.88052 .30902 L
.88061 .30902 L
.8807 .30902 L
.88079 .30902 L
.88089 .30902 L
.881 .30902 L
.88121 .30902 L
.88141 .30902 L
.88179 .30902 L
.88215 .30902 L
.88382 .30902 L
.88528 .30902 L
.88568 .30902 L
.88611 .30902 L
.88649 .30902 L
.8867 .30902 L
.88689 .30902 L
.8871 .30902 L
.8873 .30902 L
.8875 .30902 L
.88761 .30902 L
.88766 .30902 L
.88772 .30902 L
.88781 .30902 L
.88791 .30902 L
.888 .30902 L
.88808 .30902 L
.88818 .30902 L
.88827 .30902 L
.88838 .30902 L
.88848 .30902 L
.88868 .30902 L
.8889 .30902 L
.88928 .30902 L
.89016 .30902 L
Mistroke
.89177 .30902 L
.89261 .30902 L
.89307 .30902 L
.8935 .30902 L
.89392 .30902 L
.8943 .30902 L
.89452 .30902 L
.89472 .30902 L
.89483 .30902 L
.89494 .30902 L
.895 .30902 L
.89506 .30902 L
.89512 .30902 L
.89518 .30902 L
.89527 .30902 L
.89538 .30902 L
.89547 .30902 L
.89556 .30902 L
.89566 .30902 L
.89576 .30902 L
.89597 .30902 L
.89616 .30902 L
.89636 .30902 L
.89672 .30902 L
.89748 .30902 L
.89831 .30902 L
.8992 .30902 L
.9 .30902 L
.90039 .30902 L
.90081 .30902 L
.9012 .30902 L
.90157 .30902 L
.90178 .30902 L
.90199 .30902 L
.9022 .30902 L
.90232 .30902 L
.90238 .30902 L
.90244 .30902 L
.90253 .30902 L
.90262 .30902 L
.90268 .30902 L
.90273 .30902 L
.90283 .30902 L
.90293 .30902 L
.90303 .30902 L
.90313 .30902 L
.90324 .30902 L
.90344 .30902 L
.90364 .30902 L
.904 .30902 L
Mistroke
.90481 .30902 L
.90628 .30902 L
.90705 .30902 L
.90747 .30902 L
.90787 .30902 L
.90824 .30902 L
.90864 .30902 L
.90882 .30902 L
.90901 .30902 L
.90917 .30902 L
.90934 .30902 L
.90945 .30902 L
.90955 .30902 L
.90964 .30902 L
.90974 .30902 L
.90983 .30902 L
.90991 .30902 L
.91 .30902 L
.9101 .30902 L
.9102 .30902 L
.91026 .30902 L
.91031 .30902 L
.91053 .30902 L
.91071 .30902 L
.91092 .30902 L
.91131 .30902 L
.91169 .30902 L
.91239 .30902 L
.91386 .30902 L
.91469 .30902 L
.9151 .30902 L
.91547 .30902 L
.91587 .30902 L
.91624 .30902 L
.91645 .30902 L
.91664 .30902 L
.91675 .30902 L
.91685 .30902 L
.9169 .30902 L
.91696 .30902 L
.91702 .30902 L
.91707 .30902 L
.91717 .30902 L
.91727 .30902 L
.91737 .30902 L
.91746 .30902 L
.91756 .30902 L
.91768 .30902 L
.91789 .30902 L
.91811 .30902 L
Mistroke
.91834 .30902 L
.91876 .30902 L
.92034 .30902 L
.92179 .30902 L
.92255 .30902 L
.92293 .30902 L
.92334 .30902 L
.92356 .30902 L
.92376 .30902 L
.92387 .30902 L
.92399 .30902 L
.92405 .30902 L
.92411 .30902 L
.92421 .30902 L
.92431 .30902 L
.92441 .30902 L
.92451 .30902 L
.9246 .30902 L
.9247 .30902 L
.92481 .30902 L
.92502 .30902 L
.92522 .30902 L
.92545 .30902 L
.92585 .30902 L
.9266 .30902 L
.92829 .30902 L
.92912 .30902 L
.92952 .30902 L
.92989 .30902 L
.93028 .30902 L
.9305 .30902 L
.9307 .30902 L
.93081 .30902 L
.93092 .30902 L
.93102 .30902 L
.93112 .30902 L
.93118 .30902 L
.93124 .30902 L
.93134 .30902 L
.9314 .30902 L
.93147 .30902 L
.93153 .30902 L
.93158 .30902 L
.93169 .30902 L
.93174 .30902 L
.9318 .30902 L
.93199 .30902 L
.9321 .30902 L
.93222 .30902 L
.93243 .30902 L
Mistroke
.93323 .30902 L
.93472 .30902 L
.93554 .30902 L
.93597 .30902 L
.93643 .30902 L
.93683 .30902 L
.93704 .30902 L
.93727 .30902 L
.93748 .30902 L
.93767 .30902 L
.93785 .30902 L
.93804 .30902 L
.93814 .30902 L
.9382 .30902 L
.93825 .30902 L
.93835 .30902 L
.93845 .30902 L
.93854 .30902 L
.93862 .30902 L
.93871 .30902 L
.93881 .30902 L
.93892 .30902 L
.93903 .30902 L
.93924 .30902 L
.93963 .30902 L
.94 .30902 L
.94039 .30902 L
.9411 .30902 L
.94271 .30902 L
.94315 .30902 L
.94361 .30902 L
.94401 .30902 L
.94423 .30902 L
.94444 .30902 L
.94465 .30902 L
.94487 .30902 L
.94496 .30902 L
.94507 .30902 L
.94515 .30902 L
.94525 .30902 L
.9453 .30902 L
.94536 .30902 L
.94546 .30902 L
.94552 .30902 L
.94557 .30902 L
.94563 .30902 L
.94569 .30902 L
.94575 .30902 L
.94581 .30902 L
.94591 .30902 L
Mistroke
.94611 .30902 L
.9463 .30902 L
.9465 .30902 L
.94692 .30902 L
.94766 .30902 L
.94936 .30902 L
.95016 .30902 L
.95091 .30902 L
.95128 .30902 L
.95147 .30902 L
.95167 .30902 L
.95178 .30902 L
.95188 .30902 L
.95198 .30902 L
.95207 .30902 L
.95217 .30902 L
.95223 .30902 L
.95228 .30902 L
.95234 .30902 L
.9524 .30902 L
.95245 .30902 L
.95251 .30902 L
.9526 .30902 L
.95269 .30902 L
.95279 .30902 L
.95289 .30902 L
.9531 .30902 L
.9533 .30902 L
.95367 .30902 L
.95403 .30902 L
.95564 .30902 L
.95634 .30902 L
.95709 .30902 L
.95752 .30902 L
.95791 .30902 L
.95828 .30902 L
.95847 .30902 L
.95867 .30902 L
.95879 .30902 L
.95889 .30902 L
.95899 .30902 L
.95909 .30902 L
.95915 .30902 L
.95921 .30902 L
.95927 .30902 L
.95933 .30902 L
.95943 .30902 L
.95949 .30902 L
.95954 .30902 L
.95964 .30902 L
Mistroke
.95973 .30902 L
.95994 .30902 L
.96014 .30902 L
.96036 .30902 L
.96118 .30902 L
.96207 .30902 L
.96284 .30902 L
.96369 .30902 L
.96409 .30902 L
.96451 .30902 L
.96492 .30902 L
.96529 .30902 L
.9655 .30902 L
.9657 .30902 L
.96582 .30902 L
.96592 .30902 L
.96598 .30902 L
.96604 .30902 L
.9661 .30902 L
.96615 .30902 L
.96625 .30902 L
.96634 .30902 L
.96645 .30902 L
.9665 .30902 L
.96655 .30902 L
.96677 .30902 L
.96698 .30902 L
.96735 .30902 L
.96775 .30902 L
.96858 .30902 L
.97006 .30902 L
.97087 .30902 L
.97126 .30902 L
.97161 .30902 L
.97203 .30902 L
.97224 .30902 L
.97235 .30902 L
.97247 .30902 L
.97259 .30902 L
.97269 .30902 L
.97279 .30902 L
.97285 .30902 L
.9729 .30902 L
.973 .30902 L
.9731 .30902 L
.9732 .30902 L
.97329 .30902 L
.97338 .30902 L
.97346 .30902 L
.97364 .30902 L
Mistroke
.97382 .30902 L
.97401 .30902 L
.97468 .30902 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{421.375, 260.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008>0001AB000`400?l00000o`00003ooooooooo
oooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo
003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooo
oooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool0
0?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooooooo
ool@ooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooo
ooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo0ol0003o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0
003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo
00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`
ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLoooo
o`00<?ooool3o`000?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?oo
ool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0
033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomco
oooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooo
oooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool3o`000?oooooo
g?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0013ooooo0_o^k^h3ooooo`;ok^k^6Oooool00ol0003oooooooooo`3o
ooooomcooooo000;ooooo`;o000000[o410@ooooooooooook^k^oeEEEOo^k^koooooonk^k_mEEEGo
k^k^0oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h:ooooo`03o`000?oo
oooooooo0?oooooog?ooool000cooooo00?o0000ooooooooool00_ooool01Oo^k^koEEEEomgMgOmE
EEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00[ooooo
00?o0000ooooooooool0oooooooLooooo`0000?oooooo`000?l000001?l00002ooooo`Go00001?oo
ool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooo
oa0@400:ooooo`03o`000?oooooooooo0?oooooog?ooool000Wooooo00CoA4A4omgMgOoooooo0000
1?ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000000[ooooo00?o0000ooooooooool0oooooooLooooo`002Oooool01?oMgMgo
EEEEooooool00003ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000:ooooo`Co0000V_ooool00ol0003ooooo
ooooo`3oooooockooooo000:ooooo`03ogMgMoo<c<co000000?ooooo0_o^k^h3ooooo`;ok^k^1Ooo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41002_ooool00ol0003ooooo
ooooo`2Kooooo`03o`000?oooooooooo0?oooooo?_ooool000[ooooo00?ok^k^odA4A?l000003ooo
ool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool2o`0000Gooooo
00?o0000ooooooooool0Voooool00ol0003oooooooooo`3oooooockooooo000;ooooo`03ogMgMol0
003ooooo00cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`2Jooooo`;o0000oooooom0ooooo`00
:?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo09[ooooo00?o0000ooooool0
0000ooooooloooooo`00:?ooool3o`0000Gooooo00?o0000ooooooooool0V_ooool00ol0003ooooo
o`000009ooooo`;o0000ooooooldooooo`00:Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo09[ooooo00?o0000ooooool000002Oooool2o`000?oooooo=?ooool002[ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`2Jooooo`03o`000?oooooo000000Wooooo0_l0003o
ooooocCooooo000`ooooo`03o`000?oooooooooo09[ooooo00?o0000ooooool000002Oooool2o`00
0?oooooo=?ooool0033ooooo00?o0000ooooooooool0V_ooool00ol0003oooooo`000009ooooo`;o
0000ooooooldooooo`00<?ooool00ol0003oooooooooo`2Jooooo`03o`000?oooooo000000Wooooo
0_l0003oooooocCooooo000`ooooo`03o`000?oooooooooo09[ooooo00?o0000ooooool000002Ooo
ool2o`000?oooooo=?ooool0033ooooo0ol0002Jooooo`03o`000?oooooo000000Wooooo0_l0003o
ooooocCooooo000`ooooo`03o`000?oooooooooo08oooooo00?o0000ooooooooool02?ooool00ol0
003oooooo`000009ooooo`;o0000ooooooldooooo`00<?ooool00ol0003oooooooooo`2>ooooo`;o
00002_ooool00ol0003oooooo`000009ooooo`;o0000ooooooldooooo`00<?ooool00ol0003ooooo
ooooo`2>ooooo`;o00002_ooool00ol0003oooooo`000009ooooo`;o0000ooooooldooooo`00<?oo
ool00ol0003oooooooooo`2>ooooo`;o00002_ooool00ol0003oooooo`000009ooooo`;o0000oooo
ooldooooo`00<?ooool00ol0003oooooooooo`2>ooooo`;o00002_ooool00ol0003oooooo`000009
ooooo`;o0000ooooooldooooo`00<?ooool00ol0003oooooooooo`2>ooooo`;o00002_ooool00ol0
003oooooo`000009ooooo`;o0000ooooooldooooo`00<?ooool00ol0003oooooooooo`2>ooooo`;o
00002_ooool00ol0003oooooo`000009ooooo`;o0000ooooooldooooo`00<?ooool00ol0003ooooo
ooooo`2>ooooo`;o00002_ooool00ol0003oooooo`000009ooooo`;o0000ooooooldooooo`00<?oo
ool00ol0003oooooooooo`2>ooooo`;o00002_ooool00ol0003oooooo`000009ooooo`;o0000oooo
ooldooooo`00<?ooool00ol0003oooooooooo`2>ooooo`;o00002_ooool00ol0003oooooo`000009
ooooo`03o`000?oooooo00000?oooooo<oooool0033ooooo00?o0000ooooooooool0S_ooool00ol0
003oooooo`000009ooooo`03o`000?oooooo000000Sooooo00Co0000oooooooooooo00002Oooool0
0ol0003oooooooooo`3oooooobOooooo000`ooooo`?o0000S_ooool00ol0003oooooo`000009oooo
o`03o`000?oooooo000000Sooooo00Co0000oooooooooooo00002?ooool2o`000?oooooo:Oooool0
033ooooo00?o0000ooooooooool0S_ooool00ol0003oooooo`000009ooooo`03o`000?oooooo0000
00Sooooo00Co0000oooooooooooo00002?ooool2o`000?oooooo:Oooool0033ooooo00?o0000oooo
ooooool0S_ooool00ol0003oooooo`000009ooooo`03o`000?oooooo000000Sooooo00Co0000oooo
oooooooo00002?ooool2o`000?oooooo:Oooool0033ooooo00?o0000ooooooooool0SOooool01?l0
003oooooooooool00009ooooo`03o`000?oooooo000000Sooooo00Co0000oooooooooooo00002?oo
ool2o`000?oooooo:Oooool0033ooooo00?o0000ooooooooool0SOooool01?l0003oooooooooool0
0009ooooo`03o`000?oooooo000000Sooooo00Co0000oooooooooooo00002?ooool2o`000?oooooo
:Oooool0033ooooo00?o0000ooooooooool0SOooool01?l0003oooooooooool00009ooooo`03o`00
0?oooooo000000Sooooo00Co0000oooooooooooo00002?ooool2o`000?oooooo:Oooool0033ooooo
00?o0000ooooooooool0SOooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00
00Sooooo00Co0000oooooooooooo00002?ooool2o`000?oooooo:Oooool0033ooooo00?o0000oooo
ooooool0SOooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo00Co
0000oooooooooooo00002?ooool2o`000?oooooo:Oooool0033ooooo00?o0000ooooooooool0SOoo
ool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooo
oooo00002?ooool2o`000?oooooo:Oooool0033ooooo00?o0000ooooooooool0SOooool01?l0003o
ooooooooool00008ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool0
0008ooooo`;o0000oooooolYooooo`00<?ooool00ol0003oooooooooo`2=ooooo`04o`000?oooooo
ooooo`0000Sooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000So
oooo0_l0003oooooobWooooo000`ooooo`?o0000SOooool01?l0003oooooooooool00008ooooo`05
o`000?ooooooooooooooool000001oooool01?l0003oooooooooool00008ooooo`;o0000oooooolY
ooooo`00<?ooool00ol0003oooooooooo`2=ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000
ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Sooooo0_l0003oooooobWooooo
000`ooooo`03o`000?oooooooooo08gooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooo
oooooooooooo000000Oooooo00Co0000oooooooooooo00002?ooool2o`000?oooooo:Oooool0033o
oooo00?o0000ooooooooool0SOooool01?l0003oooooooooool00008ooooo`05o`000?oooooooooo
ooooool000001oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?oooooo:?oo
ool0033ooooo00?o0000ooooooooool0SOooool01?l0003oooooooooool00008ooooo`05o`000?oo
ooooooooooooool000001oooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`00
0?oooooo:?ooool0033ooooo00?o0000ooooooooool0POooool2o`0000[ooooo00Co0000oooooooo
oooo00002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo00001ooo
ool01?l0003oooooooooool0003oooooobSooooo000`ooooo`03o`000?oooooooooo087ooooo0_l0
000:ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000007ooooo`04
o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo0000oooooolXooooo`004?ooool2onk^
kP?ooooo0_o^k^hIooooo`03o`000?oooooooooo087ooooo0_l0000:ooooo`04o`000?oooooooooo
o`0000Sooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo
00Co0000oooooooooooo0000oooooolXooooo`002Oooool5o`0000;ooooo00Ook^k^oeEEEOo^k^ko
ooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^
2_ooool00ol0003oooooooooo`21ooooo`;o00002_ooool01?l0003oooooooooool00008ooooo`05
o`000?ooooooooooooooool000001oooool01?l0003oooooooooool00007ooooo`04o`000?oooooo
ooooo`000?oooooo:?ooool000Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05onk^k_mE
EEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02_ooool00ol0003oooooooooo`21ooooo`;o00002_ooool01?l0003oooooooooool00008oooo
o`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool00007ooooo`04o`000?oo
ooooooooo`000?oooooo:?ooool00003ooooool0003o000000Co00000oooool00onHV9So8B4Qonk^
kP05ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@00[ooooo00?o0000ooooooooool0POooool00ol0003oooooo`000009ooooo`05o`00
0?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooo
oooooooo00001oooool01?l0003oooooooooool0003oooooobSooooo000;ooooo`03oiRHV?lQ8B7o
k^k^00?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`00000:ooooo`03o`000?oooooooooo087ooooo00?o0000ooooool00000
2Oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007oooo
o`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00002?ooool00ol0003ooooooooo
o`3ooooooagooooo000<ooooo`0;ogMgMomVIVKoooooooooooo^k^koEEEEonk^k_ooooook^k^oeEE
EOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000002_ooool4
o`00083ooooo00?o0000ooooool000002Oooool01Ol0003ooooooooooooooooo000000Oooooo00Go
0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooo
oooo00002?ooool00ol0003oooooooooo`3ooooooagooooo000=ooooo`03o`000?oooooooooo00;o
k^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@
00[ooooo00?o0000ooooooooool0POooool00ol0003oooooo`000009ooooo`05o`000?oooooooooo
ooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000
1oooool01?l0003oooooooooool00008ooooo`;o0000oooooolNooooo`002Oooool01Ol0003o^[Zj
oooooonHV9So410@00kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo0_l00005ooooo`03o`000?oooooooooo083ooooo00Co0000oooooooooooo00002Oooool0
1Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04o`00
0?ooooooooooo`0000Oooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00003ooooo
oakooooo0009ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?ooool00omEEEGoIVIVo`000004oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h00_ooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo083ooooo00Co0000oooooooooooo00002Oooool01Ol0003ooooooooooooooooo000000Oo
oooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000
oooooooooooo00001oooool00ol0003oooooo`00003ooooooakooooo000Xooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool0P?ooool01?l0003oooooooooool00009ooooo`05o`00
0?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooo
oooooooo00001oooool01?l0003oooooooooool00007ooooo`03o`000?oooooo00000?oooooo7_oo
ool002Sooooo0ol00005ooooo`03o`000?oooooooooo083ooooo00Co0000oooooooooooo00002Ooo
ool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04
o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00003o
oooooakooooo000Yooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0P?ooool01?l0
003oooooooooool00009ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooo
oooooooo000000Oooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool00007oooo
o`03o`000?oooooo00000?oooooo7_ooool002[ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`20ooooo`04o`000?ooooooooooo`0000Wooooo00Go0000ooooooooooooooooo`000007
ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Oooooo
00Co0000oooooooooooo00001oooool00ol0003oooooo`00003ooooooakooooo000`ooooo`03o`00
0?oooooooooo083ooooo00Co0000oooooooooooo00002Oooool01Ol0003ooooooooooooooooo0000
00Oooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001ooo
ool01?l0003oooooooooool00007ooooo`03o`000?oooooo00000?oooooo7_ooool0033ooooo00?o
0000ooooooooool0P?ooool01?l0003oooooooooool00009ooooo`05o`000?ooooooooooooooool0
00001oooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000007
ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool00000oooooolNooooo`00<?ooool0
0ol0003oooooooooo`20ooooo`05o`000?ooooooooooooooool000002?ooool01Ol0003ooooooooo
oooooooo000000Oooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?oooooooooooooo
ool000001oooool01?l0003oooooooooool00007ooooo`03o`000?oooooo00000?oooooo7_ooool0
033ooooo00?o0000ooooooooool0P?ooool01Ol0003ooooooooooooooooo000000Sooooo00Go0000
ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooo
oooooooooooo000000Oooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00003ooooo
oakooooo000`ooooo`?o0000P?ooool01Ol0003ooooooooooooooooo000000Sooooo00Go0000oooo
ooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooo
oooooooo000000Oooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00003ooooooako
oooo000`ooooo`03o`000?oooooooooo083ooooo00Go0000ooooooooooooooooo`000008ooooo`05
o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000
ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool00000
oooooolNooooo`00<?ooool00ol0003oooooooooo`20ooooo`05o`000?ooooooooooooooool00000
2?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000006oooo
o`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool00007ooooo`03o`000?oo
oooo00000?oooooo7_ooool0033ooooo00?o0000ooooooooool0P?ooool01Ol0003ooooooooooooo
oooo000000Sooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool0
00001_ooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo00001oooool0
0ol0003oooooo`00003ooooooakooooo000`ooooo`03o`000?oooooooooo083ooooo00Go0000oooo
ooooooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool0
1Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000007ooooo`04o`00
0?ooooooooooo`0000Oooooo00?o0000ooooool00000oooooolNooooo`00<?ooool00ol0003ooooo
ooooo`20ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?oooooooooo
ooooool000001oooool01?l0003oooooooooool00007ooooo`03o`000?oooooo00000?oooooo7_oo
ool0033ooooo00?o0000ooooooooool0P?ooool01Ol0003ooooooooooooooooo000000Oooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool00000
1_ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000007oooo
o`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool0oooooolCooooo`00<?ooool00ol0
003oooooooooo`20ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?oo
ooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooo
oooo00001oooool2o`000?oooooo5?ooool0033ooooo00?o0000ooooooooool0Loooool2o`0000_o
oooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001oooool01?l0003ooooooooo
ool00007ooooo`;o0000oooooolDooooo`00<?ooool00ol0003oooooooooo`1cooooo`;o00002ooo
ool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`05ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?oooooooooo
o`0000Oooooo0_l0003ooooooaCooooo000`ooooo`03o`000?oooooooooo07?ooooo00?o0000oooo
ool000002_ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000007ooooo`04o`00
0?ooooooooooo`0000Kooooo00?o0000ooooool00000oooooolDooooo`00<?ooool00ol0003ooooo
ooooo`1cooooo`03o`000?oooooo000000[ooooo00Go0000ooooooooooooooooo`000007ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo0000
00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooooooo
ooooool000001_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooool00000oooo
oolDooooo`00<?ooool3o`0007?ooooo00?o0000ooooool000002Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool0
00001_ooool00ol0003oooooo`00003ooooooaCooooo000`ooooo`03o`000?oooooooooo07?ooooo
00?o0000ooooool000002Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool0
00001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooo
ooooooooo`000006ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooo`00003o
oooooaCooooo000`ooooo`03o`000?oooooooooo07;ooooo00Co0000oooooooooooo00002Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000006ooooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooo`00003ooooooaCooooo000`ooooo`03o`00
0?oooooooooo07;ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`05
o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00?ooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001_oo
ool00ol0003oooooo`00003ooooooaCooooo000`ooooo`03o`000?oooooooooo07;ooooo00Co0000
oooooooooooo00002Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooo
ooooo`000006ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooo`00003ooooo
oaCooooo000`ooooo`03o`000?oooooooooo04kooooo0_o^k^h3ooooo`;ok^k^7Oooool01?l0003o
ooooooooool00009ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000006
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_o^k^h00ooooooo0000ooooo`02
onk^kP03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oo
oooo000004_ooooo0_o^k^h3ooooo`;ok^k^C_ooool2onk^kP?ooooo0_o^k^i/ooooo`00<?ooool0
0ol0003oooooooooo`18ooooo`0=odA4A?l0003o0000oc8b<_oMgMgoooooonk^k_mEEEGok^k^oooo
ooo^k^koEEEEonk^kP03ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPko
oooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooo000000?o000000co410@ooooooo^k^koEEEEonk^
k_l0003ok^k^oeEEEOo^k^koooooo`000?ooool5o`0000;ooooo00Gok^k^o`000?l0003o<S8bonk^
kP03ooooo`03o`000?oooooo000003Gooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Ooo
ool03Om4A4Co0000o`000?lb<S;ogMgMooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00ooo
ool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hhooooo`Go00000_ooool01oo^
k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o
0000oc8b<_o^k^iMooooo`00<?ooool00ol0003oooooooooo`1;ooooo`09ogMgMolb<S;ooooooooo
ooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00kooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Go
oooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooooooo`;o00000oooool0
1Oo^k^koEEEEo`000?mEEEGok^k^00;ooooo00Oo0000ooooooooooooooooo`000?oooooo000000;o
oooo00GoMgMgo`000?ooooooV9RHogMgM`03ooooo`03o`000?oooooo000003Oooooo00?o0000oooo
ooooool01?ooool2ob4Q8@Sooooo00WoMgMgoc8b<_ooooooooooonk^k_mEEEGogMgMoeEEEOo^k^h0
1_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0>?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Mooooo`00<?ooool00ol0003oooooooooo`1<
ooooo`07o`000?oooooooooooooooooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo
00Go410@oooooooooooooooooa0@400=ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000001_ooool01?l0
003oooooooooooooool2o`0000Cooooo00?ogMgMo`000?oMgMd00oooool01ol0003ooooooooooooo
oooo0000ooooool000000_ooool01Ol@413o0000oooooooooooo410@00?ooooo00Co0000oooooooo
oooo00001oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00oooooo00Oo0000oooo
ooooooooooooomgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@03Wooooo00?oV9RHob4Q8Oo^k^h01Oooool00ooMgMgo0000omgMg@07ooooo`03o`00
0?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@401Mooooo`00<?ooool00ol0003ooooo
ooooo`1;ooooo`09ogMgMolb<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00Go0000oooooooooooooooo
o`000006ooooo`04o`000?ooooooooooooooo`;o00000oooool01Oo^k^koEEEEo`000?mEEEGok^k^
00;ooooo00Oo0000ooooooooooooooooo`000?oooooo000000;ooooo0_l00002ooooo`05o`000?oo
ooooooooooooool000000_ooool00ol0003oooooooooo`04ooooo`;o0000;_ooool00ol0003ooooo
ooooo`0>ooooo`09ogMgMolb<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000003[ooooo00?oV9RHob4Q8Oo^k^h00ooo
ool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000005gooooo000`ooooo`03o`000?oooooooooo04Sooooo00go0000ob4Q8Ol0003o
<S8bolc<c?ooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000ooooooooool0
0_ooool01Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000006oooo
o`04o`000?ooooooooooooooo`;o00000_ooool02Oo^k^koEEEEonk^k_l0003ok^k^oeEEEOo^k^ko
ooooo`000003ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`05o`000?oooooooooooooo
ool000000_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo000002gooooo00?o0000oooo
ooooool02oooool03Ol0003o8B4Qo`000?lb<S;oc<c<ooooooo^k^koEEEEonk^k_ooooook^k^oeEE
EOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000>oooool0
2omgMgOoIVIVooooooooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000005gooooo000`ooooo`03o`000?oooooooooo
04Sooooo00?o0000ooooooooool00oooool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo
00;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000001_oo
ool01?l0003oooooooooooooool2o`0000;ooooo0_o^k^h00ooooooo0000ooooo`02onk^kP03oooo
ool0003ooooo00;ooooo00?o0000ooooool000000_ooool01Ol@413o0000oooooooooooo410@00?o
oooo00Co0000oooooooooooo00001_ooool00ol0003oooooo`00000]ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool00oooool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo
00;ooooo00Go410@oooooooooooooooooa0@400looooo`03o`000?oooooooooo00;ok^k^0oooool2
onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@05gooooo000`
ooooo`?o0000B?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00Go0000oooooooooooooooo
o`000006ooooo`04o`000?ooooooooooooooo`;o00001Oooool00ol0003oooooooooo`02ooooo`07
o`000?ooooooooooooooool0003oooooo`000002ooooo`05ogMgMol0003ooooooiRHV?mgMgL00ooo
ool01Ol0003oooooooooool0003ooooo00;o00000oooool00ol0003oooooo`00000]ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02?ooool2o`0002kooooo00Go0000okZj^_ooooooV9RHoa0@400>oooo
o`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`;o0000Doooool0
033ooooo00?o0000ooooooooool0B?ooool4o`0000cooooo00?oEEEEofIVI_l000001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooo
oooo000000Kooooo00Co0000oooooomEEEGoIVIV0_l00005ooooo`03o`000?oooooooooo00;ooooo
00Oo0000oooooomEEEGoIVIVo`000?oooooo000000;ooooo00Gok^k^o`000?l0003o<S8bonk^kP03
ooooo`03o`000?oooooooooo00;o00000_ooool01_l0003oooooooooool0003oooooo`0002_ooooo
00?oEEEEofIVI_l000003Oooool4o`0000cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Oooooo00Co0000oooooooooooo0000;Oooool01OnHV9So410@o`000?lQ8B7o
c<c<00cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oooooo00Co
0000oooooooooooo0000D_ooool0033ooooo00?o0000ooooooooool0I?ooool6o`0000?ooooo00Go
0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool01Ol0003ooooooooooooooooo000000Gooooo1_l00002ooooo`06o`000?ooooooooooo`00
0?oooooo0000FOooool4o`000005ooooool0003oooooooooool00000C?ooool4o`000005ooooool0
003oooooooooool00000D_ooool0033ooooo00?o0000ooooooooool0Hoooool4o`0000Kooooo00Go
0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool01?l00002ooooo`04
o`000?ooooooooooo`0005kooooo0ol0001Booooo`?o0000Doooool0033ooooo00?o0000oooooooo
ool0Hoooool01?l0003oooooooooool00004ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000
ooooooooooooooooo`000005ooooo`07o`000?ooooooooooooooool0003oooooo`000003ooooo`05
o`000?ooooooooooooooool000001_ooool2o`0005Kooooo00?o0000ooooooooool0D_ooool00ol0
003oooooooooo`1Booooo`00<?ooool00ol0003oooooooooo`1Sooooo`04o`000?ooooooooooo`00
00Cooooo1?l000000ooooooo0000ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool01Ol0003ooooooooooooooooo000000Gooooo00Go0000ooooooooooooooooo`00
0002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool3o`0005Oooooo
00?o0000ooooooooool0D_ooool00ol0003oooooooooo`1Aooooo`00<?ooool00ol0003ooooooooo
o`1Rooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooo
oooooooo000000Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000001Oooool00ol0003oooooo`00003oooooo`7ooooo000`ooooo`03o`00
0?oooooooooo06;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`00
0?ooooooooooooooool000001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`000005ooooo`04o`000?ooooooooooo`000<Gooooo00?oMgMg
ofIVI_ooool0;Oooool00omVIVKoMgMgooooo`07ooooo`00<?ooool00ol0003oooooooooo`1Qoooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo
000000Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000001Oooool01?l0003oooooooooool00006ooooo`;o0000_?ooool00ooMgMgo410@
onk^kP0^ooooo`03onk^k_l@413ogMgM00Oooooo000`ooooo`03o`000?oooooooooo05?ooooo0_l0
000<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooo
oooooooo000000Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Gooooo0ol0002Zoooo
o`;o00000_ooool2o`0000cooooo00?oEEEEoiRHV?ooool00_l00002ooooo`07o`000?oooooooooo
o`000?l@413ok^k^oeEEE@02o`000003odA4A?nj^[[ooooo00;ooooo00GoV9RHo`000?l0003oA4A4
okZj^P02ooooo`08onk^k_mEEEGo0000o`000?m4A4Co^[Zjooooool@4105o`0000?ooooo00So410@
oc8b<_l0003o0000oa0@4?nYZJWoQhN7ofIVIPOooooo000`ooooo`03o`000?oooooooooo057ooooo
1_l00009ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooo
oooooooooooo000000Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo00001Oooool3o`000:7ooooo00Kok^k^ob4Q8On7QhOo^[Zjo`00
0?oMgMd<ooooo`05o`000?ooooooooooooooool000000_ooool02ol0003oooooooooool0003ooooo
oeEEEOmgMgOoooooonk^k_mgMgOo410@00?ooooo00Go410@okZj^_o^k^koMgMgoa0@4002ooooo`06
oeEEEOmgMgOoooooonk^k_mgMgOo410@0oooool00ol0003oooooooooo`04ooooo`08o`000?nYZJWo
oooooooooonj^[[o0000onk^k_l00007ooooo`00ool0002do`0000oooooo00CogMgMo`000?l@413o
c<c<3Oooool01Olb<S;ooooooooooooooooo000000;ooooo00Ko0000oooooooooooo0000ooooool0
0008ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`05ooooo`07okZj^_n7QhOoIVIVofIVI_l@413oooooo`000007ooooo`002_ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool9o`0000Wooooo
00Co0000oooooooooooo00000oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooool000001_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`00
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`;o00001?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000000_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01_l0
003oooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00;o00001?ooool01Ol0003ooooooooooooooooo000000Cooooo
1?l00005ooooo`?o00002_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Gooooo`04onk^k_lQ8B7o410@onk^kPgo
oooo00Go<S8booooooooooooooooo`000002ooooo`05o`000?ooooooooooo`000?ooool01_l00003
ooooo`03o`000?oooooooooo00Cooooo1_l00003ooooo`03o`000?oooooooooo00Cooooo00So<S8b
ob4Q8OmgMgOoMgMgohN7Qoo^k^koooooo`0000Oooooo000:ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooool000000oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooool000001_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`;o00001?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000000_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01_l0003o
ooooooooool0003oooooo`0000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00;o00001Oooool3o`0000Sooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0Gooooo`04ob4Q8OmgMgOoMgMgoc8b<Pgooooo00Go0000onk^k_oooooooooo
o`000002olc<c00;o`000?nYZJWogMgMob4Q8OooooooEEEEohN7Qoo^k^koooooohN7Qolb<S800ooo
ool00ol0003oooooooooo`04ooooo`06oeEEEOn7QhOok^k^oooooon7QhOo<S8b0oooool00ol0003o
<S8bomgMg@04ooooo`08o`000?nj^[[oooooonk^k_mgMgOo0000onk^k_l00007ooooo`00<?ooool0
0ol0003oooooooooo`1Jooooo`;o00000_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000001Oooool01?l0003oooooooooool0000fooooo`03o`000?oooooooooo05_ooooo
00?o0000ooooooooool05_ooool2o`0000;ooooo0_l0000<ooooo`0>oeEEEOmgMgOooooooa0@4?l0
003o8B4Qo`000?mgMgOo410@o`000?nYZJWoooooonk^k_mEEED2o`000004odA4A?o^k^kooooooa0@
40Go00000oooool01_o^k^koEEEEo`000?l0003oA4A4onk^kP;ooooo0_l000001?nYZJWo8B4Qo`00
0?lQ8B42ooooo`08ojVYZOlQ8B7o0000o`000?lb<S;o0000ogMgMomEEED7ooooo`00<?ooool00ol0
003oooooooooo`1Jooooo`;o000000?oooooo`000?l000002_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00006
ooooo`03o`000?oooooo00000<3ooooo00?ogMgMoa0@4?o^k^h04_ooool00ol0003oooooooooo`0I
ooooo`03onk^k_l@413ogMgM00Oooooo000`ooooo`03o`000?oooooooooo05cooooo0_l0000;oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000005ooooo`04o`000?oooooo
ooooo`0000Kooooo0_l00032ooooo`03ogMgMomVIVKooooo017ooooo00?o0000ooooooooool06Ooo
ool00omVIVKoMgMgooooo`07ooooo`00<?ooool00ol0003oooooooooo`1Yooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000005ooooo`04o`000?ooooooooooo`000?oooooo
1Oooool0033ooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00Go0000ooooooooooooooooo`000005ooooo`05o`000?ooooooooooooooool0
00001Oooool01?l0003oooooooooool0003oooooo`Gooooo000`ooooo`03o`000?oooooooooo06[o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooooooooooo
ool000001Oooool01Ol0003ooooooooooooooooo000000Gooooo00Co0000oooooooooooo0000oooo
ool5ooooo`00<?ooool00ol0003oooooooooo`1Zooooo`05o`000?ooooooooooooooool000002Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0003ooooo
oooooooooooo000000Gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo0000
0?oooooo1Oooool0033ooooo00?o0000ooooooooool0J_ooool01Ol0003ooooooooooooooooo0000
00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Gooooo00Go0000
ooooooooooooooooo`000005ooooo`05o`000?ooooooooooooooool000001_ooool2o`000?oooooo
1_ooool0033ooooo00?o0000ooooooooool0J_ooool01Ol0003ooooooooooooooooo000000Wooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Gooooo00Go0000oooooooo
ooooooooo`000005ooooo`05o`000?ooooooooooooooool000001_ooool2o`000?oooooo1_ooool0
033ooooo0ol0001Zooooo`05o`000?ooooooooooooooool000002Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?oo
ooooooooooooool000001Oooool01Ol0003ooooooooooooooooo000000Gooooo00Go0000oooooooo
ooooooooo`00003oooooo`kooooo000`ooooo`03o`000?oooooooooo06_ooooo00Co0000oooooooo
oooo00002Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooo
ooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooool00000ooooool?ooooo`00<?ooool00ol0003ooooooooo
o`1[ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo0000
00Gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo00000?oooooo3oooool0
033ooooo00?o0000ooooooooool0Joooool00ol0003oooooo`00000:ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000
ooooooooooooooooo`000005ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooo
o`00003oooooo`oooooo000`ooooo`03o`000?oooooooooo06cooooo0_l0000:ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo
00Go0000ooooooooooooooooo`000005ooooo`05o`000?ooooooooooooooool000001_ooool00ol0
003oooooo`00003oooooo`oooooo000`ooooo`03o`000?oooooooooo06cooooo0_l0000:ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000
00Kooooo00Go0000ooooooooooooooooo`000005ooooo`05o`000?ooooooooooooooool000001_oo
ool00ol0003oooooo`00003oooooo`oooooo000`ooooo`03o`000?oooooooooo07Sooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_oo
ool01Ol0003ooooooooooooooooo000000Gooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooo00000?oooooo3oooool0033ooooo00?o0000ooooooooool0N?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`05
o`000?ooooooooooooooool000001Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000
ooooool00000ooooool?ooooo`00<?ooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000
ooooooooooooooooo`000005ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool00000
ooooool?ooooo`00<?ooool00ol0003oooooooooo`1iooooo`05o`000?ooooooooooooooool00000
2?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000005oooo
o`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool0ooooool>ooooo`00<?ooool00ol0
003oooooooooo`1iooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooo
oooo000000Kooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo00000?oooooo
6Oooool0033ooooo00?o0000ooooooooool0NOooool01Ol0003ooooooooooooooooo000000Sooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo
00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001_ooool00ol0
003oooooo`00003ooooooaWooooo000`ooooo`?o0000NOooool01Ol0003ooooooooooooooooo0000
00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001_oo
ool00ol0003oooooo`00003ooooooaWooooo000`ooooo`03o`000?oooooooooo07Wooooo00Go0000
ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooool00000oooooolIooooo`00<?ooool00ol0003ooooo
ooooo`1iooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000
00Kooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo00000?oooooo6Oooool0
033ooooo00?o0000ooooooooool0NOooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000
ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooo
o`00003ooooooaWooooo000`ooooo`03o`000?oooooooooo07Wooooo00Co0000oooooooooooo0000
2Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000006oooo
o`03o`000?oooooo00000?oooooo6Oooool0033ooooo00?o0000ooooooooool0NOooool01?l0003o
ooooooooool00009ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000006
ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooool00000oooooolIooooo`00<?ooool00ol0003oooooooooo`1iooooo`04o`000?oo
ooooooooo`0000Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000Ko
oooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001_ooool0
0ol0003oooooo`00003ooooooaWooooo000`ooooo`03o`000?oooooooooo07Wooooo00Co0000oooo
oooooooo00002Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000001_oo
ool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo00001oooool00ol0003o
ooooo`00003ooooooaWooooo000`ooooo`03o`000?oooooooooo07Wooooo00Co0000oooooooooooo
00002Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0
003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00
003ooooooaWooooo000`ooooo`03o`000?oooooooooo07Wooooo00Co0000oooooooooooo00002Ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooo
oooooooooooo000000Kooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00003ooooo
oaWooooo000`ooooo`03o`000?oooooooooo07Wooooo00Co0000oooooooooooo00002Oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000007
ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Kooooo
00Co0000oooooooooooo00001oooool00ol0003oooooo`00003ooooooaWooooo000`ooooo`03o`00
0?oooooooooo07[ooooo00?o0000ooooool000002Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooooooooooo
ool000001_ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo00001ooo
ool3o`000?oooooo6Oooool0033ooooo0ol0001jooooo`03o`000?oooooo000000Wooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000001ooo
ool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000006ooooo`04
o`000?ooooooooooo`0000Sooooo0_l0003ooooooaWooooo000`ooooo`03o`000?oooooooooo07[o
oooo00?o0000ooooool000002Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Go
oooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool0
1Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo00002?ooool2o`000?oooooo
6Oooool0033ooooo00?o0000ooooooooool0N_ooool00ol0003oooooo`000009ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000Oooooo
00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001oooool00ol0
003oooooo`000008ooooo`03o`000?oooooooooo0?oooooo6?ooool0033ooooo00?o0000oooooooo
ool0N_ooool2o`0000_ooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo
000000Oooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool00000
1oooool00ol0003oooooo`00003oooooob?ooooo000`ooooo`03o`000?oooooooooo07[ooooo0_l0
000;ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000007ooooo`05
o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000
ooooool00000oooooolSooooo`00<?ooool00ol0003oooooooooo`27ooooo`04o`000?oooooooooo
o`0000Sooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool00000
1_ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooool00000oooooolSooooo`00
3oooool2onk^kP?ooooo0_o^k^hJooooo`03o`000?oooooooooo08Oooooo00Co0000oooooooooooo
00002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000006
ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003oooooob?ooooo0008
ooooo`Go00000_ooool01oo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@
4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`03o`000?oooooooooo08Oooooo00Co0000
oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooooooooooo
ooooo`000006ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003ooooo
ob?ooooo0008ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01Oo^k^koEEEEomgMgOmEEEGo
k^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?o
0000ooooooooool0Qoooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool0
00001oooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000007
ooooo`03o`000?oooooo00000?oooooo8oooool000Wooooo00?oV9RHob4Q8Oo^k^h01Oooool00ooM
gMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400;
ooooo`03o`000?oooooooooo08Oooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooo
oooooooo000000Oooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?oooooooooooooo
ool000001oooool00ol0003oooooo`00003oooooob?ooooo000:ooooo`03oiRHV?lQ8B7ok^k^00?o
oooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`03o`000?oooooooooo08Oooooo00Co0000oooooooooooo00002?oo
ool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000006ooooo`05
o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003oooooob?ooooo000;ooooo`0;
ogMgMomVIVKoooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000002oooool4o`0008Kooooo00Co0000oooooooo
oooo00002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`00
0006ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003oooooob?ooooo
000<ooooo`03o`000?oooooooooo00;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00?o0000ooooooooool0Qoooool01?l0003ooooo
ooooool00008ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo
000000Kooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?oooooo8ooo
ool000Sooooo00Go0000okZj^_ooooooV9RHoa0@400>ooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03o`000?oooooooooo08Oooooo00Co0000oooooooooooo
00002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000006
ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003oooooob?ooooo0008
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00oooool2o`0000Kooooo00?o0000ooooooooool0Qoooool01?l0003ooooo
ooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000006
ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003oooooob?ooooo000W
ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0Qoooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000006oooo
o`05o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003oooooob?ooooo000Woooo
o`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0Qoooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000006ooooo`05
o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003oooooob?ooooo000Wooooo`?o
00001_ooool00ol0003oooooooooo`27ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooo
oooooooo00002?ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo0000
2?ooool00ol0003oooooo`00003oooooob?ooooo000Xooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0Qoooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000So
oooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000
ooooool00000oooooolSooooo`00:Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
08Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00008ooooo`05o`000?oo
ooooooooooooool000001_ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?oo
oooo8oooool0033ooooo00?o0000ooooooooool0Qoooool01?l0003oooooooooool00008ooooo`04
o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`000008
ooooo`;o0000oooooolTooooo`00<?ooool00ol0003oooooooooo`27ooooo`04o`000?oooooooooo
o`0000Sooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00008ooooo`03o`00
0?oooooo000000Sooooo0_l0003oooooobCooooo000`ooooo`03o`000?oooooooooo08Oooooo00Co
0000oooooooooooo00002?ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00
00Sooooo00?o0000ooooool000002?ooool2o`000?oooooo9?ooool0033ooooo0ol00027ooooo`04
o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0
0008ooooo`03o`000?oooooo000000Wooooo00?o0000ooooooooool0oooooolRooooo`00<?ooool0
0ol0003oooooooooo`27ooooo`03o`000?oooooo000000Wooooo00Co0000oooooooooooo00002?oo
ool01?l0003oooooooooool00008ooooo`03o`000?oooooo000000Wooooo00?o0000ooooooooool0
oooooolRooooo`00<?ooool00ol0003oooooooooo`27ooooo`03o`000?oooooo000000Wooooo00Co
0000oooooooooooo00002?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?oo
oooo;_ooool0033ooooo00?o0000ooooooooool0Qoooool00ol0003oooooo`000009ooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003ooooo
obkooooo000`ooooo`03o`000?oooooooooo08Oooooo00?o0000ooooool000002Oooool01?l0003o
ooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000ooooool^
ooooo`00<?ooool00ol0003oooooooooo`27ooooo`03o`000?oooooo000000Wooooo00Co0000oooo
oooooooo00002?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?oooooo;_oo
ool0033ooooo00?o0000ooooooooool0R?ooool2o`0000Wooooo00Co0000oooooooooooo00002?oo
ool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?oooooo;_ooool0033ooooo00?o
0000ooooooooool0R?ooool2o`0000Wooooo00Co0000oooooooooooo00002?ooool01?l0003ooooo
ooooool00008ooooo`03o`000?oooooo00000?oooooo;_ooool0033ooooo00?o0000ooooooooool0
R?ooool2o`0000[ooooo00?o0000ooooool000002?ooool01?l0003oooooooooool00008ooooo`03
o`000?oooooo00000?oooooo;_ooool0033ooooo00?o0000ooooooooool0R?ooool2o`0000[ooooo
00?o0000ooooool000002?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?oo
oooo;_ooool0033ooooo00?o0000ooooooooool0R?ooool2o`0000[ooooo00?o0000ooooool00000
2?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?oooooo;_ooool0033ooooo
00?o0000ooooooooool0U?ooool00ol0003oooooo`000008ooooo`04o`000?ooooooooooo`0000So
oooo00?o0000ooooool00000ooooool^ooooo`00<?ooool3o`0009Cooooo00?o0000ooooool00000
2?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?oooooo;_ooool0033ooooo
00?o0000ooooooooool0U?ooool00ol0003oooooo`000008ooooo`04o`000?ooooooooooo`0000So
oooo00?o0000ooooool00000ooooool^ooooo`00<?ooool00ol0003oooooooooo`2Dooooo`03o`00
0?oooooo000000Sooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003oooooobko
oooo000`ooooo`03o`000?oooooooooo09Cooooo00?o0000ooooool000002?ooool01?l0003ooooo
ooooool00008ooooo`03o`000?oooooo00000?oooooo;_ooool0033ooooo00?o0000ooooooooool0
U?ooool00ol0003oooooo`000009ooooo`03o`000?oooooo000000Sooooo00?o0000ooooool00000
ooooool^ooooo`00<?ooool00ol0003oooooooooo`2Dooooo`03o`000?oooooo000000Wooooo00?o
0000ooooool000002Oooool2o`000?oooooo;_ooool0033ooooo00?o0000ooooooooool0U?ooool0
0ol0003oooooo`000009ooooo`03o`000?oooooo000000Wooooo0_l0003oooooobkooooo000`oooo
o`03o`000?oooooooooo09Cooooo00?o0000ooooool000002Oooool00ol0003oooooo`000009oooo
o`;o0000ooooool^ooooo`00<?ooool00ol0003oooooooooo`2Dooooo`03o`000?oooooo000000Wo
oooo00?o0000ooooool000002Oooool2o`000?oooooo;_ooool0033ooooo00?o0000ooooooooool0
U?ooool00ol0003oooooo`000009ooooo`03o`000?oooooo000000Wooooo00?o0000ooooooooool0
ooooool]ooooo`00<?ooool00ol0003oooooooooo`2Dooooo`03o`000?oooooo000000Wooooo00?o
0000ooooool000002Oooool00ol0003oooooooooo`3oooooobgooooo000`ooooo`03o`000?oooooo
oooo09Cooooo00?o0000ooooool000002Oooool00ol0003oooooo`00003oooooocWooooo000`oooo
o`?o0000U?ooool00ol0003oooooo`000009ooooo`03o`000?oooooo00000?oooooo>Oooool0033o
oooo00?o0000ooooooooool0U?ooool00ol0003oooooo`000009ooooo`03o`000?oooooo00000?oo
oooo>Oooool0033ooooo00?o0000ooooooooool0U?ooool00ol0003oooooo`000009ooooo`03o`00
0?oooooo00000?oooooo>Oooool0033ooooo00?o0000ooooooooool0U?ooool00ol0003oooooo`00
0009ooooo`03o`000?oooooo00000?oooooo>Oooool0033ooooo00?o0000ooooooooool0U?ooool0
0ol0003oooooo`000009ooooo`03o`000?oooooo00000?oooooo>Oooool0033ooooo00?o0000oooo
ooooool0U?ooool2o`0000[ooooo00?o0000ooooool00000ooooooliooooo`003oooool2onk^kP?o
oooo0_o^k^hJooooo`03o`000?oooooooooo09Gooooo00?o0000ooooooooool02?ooool00ol0003o
ooooo`00003oooooocWooooo000:ooooo`;o000000[o410@ooooooooooook^k^oeEEEOo^k^kooooo
onk^k_mEEEGok^k^0oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h;oooo
o`03o`000?oooooooooo09Gooooo00?o0000ooooooooool02?ooool2o`000?oooooo>_ooool000_o
oooo00?o0000ooooooooool00_ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000oooo
ooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?o0000ooooooooool0X?ooool2
o`000?oooooo>_ooool000Sooooo1Ol00004ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@00_ooooo00?o0000ooooooooool0X?ooool2
o`000?oooooo>_ooool000Sooooo00CoA4A4omgMgOoooooo00001?ooool01Oo^k^koEEEEomgMgOmE
EEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000_ooooo
00?o0000ooooooooool0X?ooool2o`000?oooooo>_ooool000Sooooo00CogMgMoeEEEOoooooo0000
0oooool01oo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000002oooool4o`000:3ooooo00?o0000ooooooooool0oooooolh
ooooo`002Oooool00omgMgOoc<c<o`000003ooooo`;ok^k^0oooool2onk^kPGooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@00_ooooo00?o0000ooooooooool0oooooooL
ooooo`002Oooool00oo^k^koA4A4o`00000?ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0;ooooo`03o`000?oooooooooo0?oooooog?ooool000[ooooo00?oMgMgo`00
0?ooool03?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool2
o`0000Kooooo00?o0000ooooooooool0oooooooLooooo`009oooool01?l0003oooooooooool00005
ooooo`03o`000?oooooooooo0?oooooog?ooool002Oooooo00Co0000oooooooooooo00001Oooool0
0ol0003oooooooooo`3oooooomcooooo000Wooooo`?o00001_ooool00ol0003oooooooooo`3ooooo
omcooooo000Xooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooooLooooo`00
:Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o
0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`oooo
o`03o`000?oooooooooo0?oooooog?ooool0033ooooo0ol0003oooooomcooooo000`ooooo`03o`00
0?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool0
0ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033o
oooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo
000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooL
ooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oo
oooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool3o`000?oooooog?oo
ool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3ooooo
omcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0
oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooo
oooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003o
ooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o
0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`oooo
o`?o0000oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`00
0?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool0
0ol0003oooooooooo`3oooooomcooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00
oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooo
oa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00X?ooool2o`0000Cooooo00?o
^[Zjoc8b<_ooool01?ooool2o`0000Kooooo00?o0000okZj^_ooool0oooooomGooooo`00X?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool2
oc8b<_ooooooF?ooool008gooooo0ol00002ooooo`06oc8b<_l@413oooooooooooo^k^koEEEE0_l0
00000om4A4Co^[Zjooooo`03ooooo`03o`000?oooooooooo00;ooooo00GoV9RHoa0@4?l0003o0000
ojVYZ@04ooooo`03o`000?oooooooooo00Cooooo00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000
o`000?m4A4Co^[Zj00_ooooo00?o0000onk^k_ooool01Oooool2ob4Q8@Kooooo0_l000001ol@413o
ooooolc<c?o^k^koooooonk^k_o<c<`01?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000
oc8b<_o^k^hCooooo`06oa0@4?lb<S;o0000o`000?l@413oZJVY0_ooool01_o^k^koEEEEo`000?l0
003oA4A4okZj^P?ooooo00GoIVIVo`000?l0003oA4A4olc<c03Xooooo`00S_ooool01Ol0003ooooo
ooooooo<c<co410@00?ooooo00KoEEEEogMgMoooooook^k^ogMgMol@4104ooooo`03o`000?oooooo
oooo00;ooooo00Ko0000ojVYZOmEEEGoV9RHoeEEEOnj^[X3ooooo`03o`000?oooooooooo00Cooooo
00?oc<c<o`000?l@41003?ooool01_l@413o^[Zjonk^k_mgMgOo410@ooooo`Ko00001?ooool00omE
EEGoZJVYooooo`05ooooo`;o8B4Q1oooool02?l0003oooooooooooo^k^koEEEEomgMgOmEEEGok^k^
1_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool01_l0003o
ZJVYoooooooooooo^[Zjo`0000;ooooo00KoEEEEogMgMoooooook^k^ogMgMol@4102ooooo`06ofIV
I_mgMgOooooooooooon7QhOo410@j?ooool008kooooo00Go0000ooooooooooooEEEEohN7Q`03oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool01_lb<S;ok^k^oiRHV?mEEEGo
gMgMoa0@40?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0=ooooo`03ojVYZOmE
EEGooooo00_ooooo1Ol00002ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@01Cooooo00Go^[ZjohN7QomVIVKoIVIVoa0@4002ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0joooool008kooooo00Go0000oooooooMgMgo
0000onk^kP03ooooo`Ko00001?ooool00ol0003oooooooooo`02ooooo`07okZj^_m4A4Coc<c<ob4Q
8Ooooooo410@olc<c002ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00oooool6
o`0000Gooooo00?o8B4Qooooooooool02_ooool01?m4A4CogMgMooooool00002ooooo`05onk^k_mE
EEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
00004oooool01_lb<S;o8B4QogMgMomgMgOoQhN7onk^kP;ooooo1_l00002ooooo`03o`000?oooooo
oooo0>_ooooo002>ooooo`?o000000?o410@oiRHV?ooool00_ooool01_mEEEGoQhN7onk^k_oooooo
QhN7oc8b<PCooooo00?o0000ooooooooool00_ooool01oo^k^ko0000ooooool0003oooooofIVI_n7
QhL00_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00kooooo00?oEEEEolc<c?oo
ool02_ooool01?oMgMgoEEEEooooool00002ooooo`05olc<c?o^k^koooooonk^k_o<c<`01_ooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000004oooool01_l0003o^[Zjoooo
ooo^k^koMgMgo`0000;ooooo00KoEEEEohN7Qoo^k^koooooohN7Qolb<S82ooooo`06ofIVI_mgMgOo
oooooooooon7QhOo0000j?ooool008kooooo00Go0000ooooooooooooc<c<o`000003ooooo`06onk^
k_mEEEGo0000o`000?m4A4Cok^k^1?ooool00ol0003oooooooooo`02ooooo`04ofIVI_nHV9Sooooo
oc8b<P;o^[Zj00Co0000oooooooooooo00004oooool00ol@413o0000o`000003o`0000gooooo00?o
ZJVYogMgMoooool02oooool00omgMgOoc<c<o`00000=ooooo`03o`000?oooooooooo00;ooooo00Go
410@oooooooooooooooooa0@4007ooooo`?o00000_ooool3o`0000Cooooo00KoZJVYob4Q8Ol0003o
0000oc8b<_l00002ooooo`06onk^k_mEEEGo0000o`000?m4A4Cok^k^0_ooool01_o^k^koIVIVo`00
0?l0003oA4A4o`000>Sooooo002>ooooo`05o`000?ooooooooooolc<c?l000003Oooool00ol0003o
ooooooooo`05ooooo`03ofIVI_n7QhOooooo00?ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0;ooooo`05oa0@4?oooooooooooooooolb<S803?ooool00oo^k^koA4A4o`00000=oooo
o`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0ooooool2ooooo`00SOooool4o`000003oa0@4?nYZJWooooo
00cooooo0_l00006ooooo`03ojVYZOm4A4Cooooo00;ooooo0_l0000Eooooo`03o`000?oooooooooo
00_ooooo1Ol0000=ooooo`03ogMgMol0003ooooo00[ooooo00?oEEEEofIVI_l000001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00;ooooo1?l00002ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0ooooool2ooooo`00ooooool6ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0ooooool2ooooo`00ooooool6ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0ooooool2ooooo`00ooooool5ooooo`;o00000oooool2o`000?oooooo1?ooool00?oooooooooo
ool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00
oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooo
oa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003o
oooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo
4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oo
ooooooooool@ooooo`00oooooooooooooa3ooooo0000\
\>"],
  ImageRangeCache->{{{0, 525.688}, {324.5, 0}} -> {-2.58312*^-7, -6.34248*^6, \
6.65005*^-9, 53093.5}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0.309017 5.42214e-08 [
[.32684 .29652 -16.5 -12.5 ]
[.32684 .29652 16.5 0 ]
[.54329 .29652 -16.5 -12.5 ]
[.54329 .29652 16.5 0 ]
[.75974 .29652 -22.5 -12.5 ]
[.75974 .29652 22.5 0 ]
[.97619 .29652 -16.5 -12.5 ]
[.97619 .29652 16.5 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 64 6 ]
[.09789 .09213 -34.5 -6.25 ]
[.09789 .09213 0 6.25 ]
[.09789 .20057 -34.5 -6.25 ]
[.09789 .20057 0 6.25 ]
[.09789 .41746 -28.5 -6.25 ]
[.09789 .41746 0 6.25 ]
[.09789 .5259 -28.5 -6.25 ]
[.09789 .5259 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -62.8125 0 ]
[.5 .63053 62.8125 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 .30902 m
.32684 .31527 L
s
gsave
.32684 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 .30902 m
.54329 .31527 L
s
gsave
.54329 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 .30902 m
.75974 .31527 L
s
gsave
.75974 .29652 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 .30902 m
.15368 .31277 L
s
.19697 .30902 m
.19697 .31277 L
s
.24026 .30902 m
.24026 .31277 L
s
.28355 .30902 m
.28355 .31277 L
s
.37013 .30902 m
.37013 .31277 L
s
.41342 .30902 m
.41342 .31277 L
s
.45671 .30902 m
.45671 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.58658 .30902 m
.58658 .31277 L
s
.62987 .30902 m
.62987 .31277 L
s
.67316 .30902 m
.67316 .31277 L
s
.71645 .30902 m
.71645 .31277 L
s
.80303 .30902 m
.80303 .31277 L
s
.84632 .30902 m
.84632 .31277 L
s
.88961 .30902 m
.88961 .31277 L
s
.9329 .30902 m
.9329 .31277 L
s
.0671 .30902 m
.0671 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09213 m
.11664 .09213 L
s
gsave
.09789 .09213 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .20057 m
.11664 .20057 L
s
gsave
.09789 .20057 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .41746 m
.11664 .41746 L
s
gsave
.09789 .41746 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .5259 m
.11664 .5259 L
s
gsave
.09789 .5259 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.11039 .11924 m
.11414 .11924 L
s
.11039 .14635 m
.11414 .14635 L
s
.11039 .17346 m
.11414 .17346 L
s
.11039 .22768 m
.11414 .22768 L
s
.11039 .2548 m
.11414 .2548 L
s
.11039 .28191 m
.11414 .28191 L
s
.11039 .33613 m
.11414 .33613 L
s
.11039 .36324 m
.11414 .36324 L
s
.11039 .39035 m
.11414 .39035 L
s
.11039 .44457 m
.11414 .44457 L
s
.11039 .47168 m
.11414 .47168 L
s
.11039 .49879 m
.11414 .49879 L
s
.11039 .06502 m
.11414 .06502 L
s
.11039 .03791 m
.11414 .03791 L
s
.11039 .0108 m
.11414 .0108 L
s
.11039 .55301 m
.11414 .55301 L
s
.11039 .58012 m
.11414 .58012 L
s
.11039 .60723 m
.11414 .60723 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -123.812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.812 moveto
(@) show
81.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.812 moveto
(D) show
93.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7.6) show
135.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
141.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
153.000 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
157.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
166.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
184.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02532 .30902 L
.02691 .30902 L
.02852 .30902 L
.03029 .30902 L
.03186 .30902 L
.03354 .30902 L
.03525 .30902 L
.03687 .30902 L
.03847 .30902 L
.03995 .30902 L
.04146 .30902 L
.04311 .30902 L
.04467 .30902 L
.04635 .30902 L
.04804 .30902 L
.04966 .30902 L
.05272 .30902 L
.0543 .30902 L
.05598 .30902 L
.05759 .30902 L
.05932 .30902 L
.06254 .30902 L
.06414 .30902 L
.06583 .30902 L
.06888 .30902 L
.07212 .30902 L
.07524 .30902 L
.07856 .30902 L
.08176 .30902 L
.08484 .30902 L
.08811 .30902 L
.09126 .30902 L
.09429 .30902 L
.09598 .30902 L
.09752 .30902 L
.09831 .30902 L
.09903 .30902 L
.09943 .30902 L
.0998 .30902 L
.1002 .30902 L
.10042 .30902 L
.10052 .30902 L
.10063 .30902 L
.10073 .30902 L
.10082 .30902 L
.10091 .30902 L
.101 .30902 L
.1011 .30902 L
.10119 .30902 L
Mistroke
.1013 .30902 L
.10136 .30902 L
.10141 .30902 L
.10151 .30902 L
.10161 .30902 L
.10183 .30902 L
.10203 .30902 L
.10223 .30902 L
.1026 .30902 L
.10294 .30902 L
.10371 .30902 L
.10412 .30902 L
.10456 .30902 L
.10535 .30902 L
.10613 .30902 L
.10684 .30902 L
.10834 .30902 L
.1092 .30902 L
.11 .30902 L
.11162 .30902 L
.11311 .30902 L
.11463 .30902 L
.11629 .30902 L
.11787 .30902 L
.11955 .30902 L
.12115 .30902 L
.12289 .30902 L
.1261 .30902 L
.12939 .30902 L
.13256 .30902 L
.1356 .30902 L
.13884 .30902 L
.14196 .30902 L
.14355 .30902 L
.14439 .30902 L
.14528 .30902 L
.14607 .30902 L
.14649 .30902 L
.14694 .30902 L
.14735 .30902 L
.14754 .30902 L
.14773 .30902 L
.14782 .30902 L
.14792 .30902 L
.148 .30902 L
.1481 .30902 L
.1482 .30902 L
.1483 .30902 L
.14839 .30902 L
.14848 .30902 L
Mistroke
.14858 .30902 L
.14867 .30902 L
.14876 .30902 L
.14885 .30902 L
.14906 .30902 L
.14925 .30902 L
.14961 .30902 L
.14998 .30902 L
.15043 .30902 L
.15085 .30902 L
.15164 .30902 L
.15242 .30902 L
.15325 .30902 L
.15473 .30902 L
.1555 .30902 L
.15631 .30902 L
.15778 .30902 L
.15949 .30902 L
.1611 .30902 L
.16418 .30902 L
.16746 .30902 L
.17061 .30902 L
.17364 .30902 L
.17687 .30902 L
.17998 .30902 L
.18156 .30902 L
.18239 .30902 L
.18285 .30902 L
.18328 .30902 L
.1837 .30902 L
.18392 .30902 L
.18415 .30902 L
.18434 .30902 L
.18444 .30902 L
.18456 .30902 L
.18466 .30902 L
.18475 .30902 L
.18484 .30902 L
.18493 .30902 L
.18503 .30902 L
.18512 .30902 L
.18522 .30902 L
.18531 .30902 L
.1854 .30902 L
.18548 .30902 L
.18567 .30902 L
.18585 .30902 L
.18605 .30902 L
.18646 .30902 L
.18689 .30902 L
Mistroke
.18729 .30902 L
.18804 .30902 L
.18884 .30902 L
.18972 .30902 L
.19131 .30902 L
.19211 .30902 L
.19299 .30902 L
.19455 .30902 L
.19623 .30902 L
.19954 .30902 L
.20272 .30901 L
.20579 .30901 L
.20905 .30901 L
.21219 .30901 L
.21301 .30901 L
.21391 .30901 L
.21432 .30901 L
.21475 .30901 L
.21512 .30901 L
.21533 .30901 L
.21552 .30901 L
.21573 .30901 L
.21583 .30901 L
.21589 .30901 L
.21594 .30901 L
.21604 .30901 L
.21613 .30901 L
.21619 .30901 L
.21624 .30901 L
.21634 .30901 L
.21643 .30901 L
.21653 .30901 L
.21662 .30901 L
.2167 .30901 L
.2169 .30901 L
.21709 .30901 L
.21729 .30901 L
.21751 .30901 L
.21789 .30901 L
.21831 .30901 L
.21877 .30901 L
.21958 .30901 L
.22033 .30901 L
.2212 .30901 L
.22201 .30901 L
.22353 .30901 L
.2252 .30902 L
.22834 .30903 L
.23168 .30904 L
.2349 .30906 L
Mistroke
.238 .30907 L
.23957 .30908 L
.2404 .30908 L
.24129 .30909 L
.24173 .30909 L
.24215 .30909 L
.24253 .30909 L
.24272 .30909 L
.24293 .30909 L
.24313 .30909 L
.24332 .30909 L
.24342 .30909 L
.24352 .30909 L
.24362 .30909 L
.24367 .30909 L
.24373 .30909 L
.24383 .30909 L
.24391 .30909 L
.24401 .30909 L
.24411 .30909 L
.2442 .30909 L
.24428 .30909 L
.24446 .30909 L
.24466 .30909 L
.24484 .30909 L
.24524 .30909 L
.24562 .30909 L
.24597 .30909 L
.24677 .30908 L
.24763 .30908 L
.24838 .30907 L
.24922 .30907 L
.2509 .30905 L
.25245 .30902 L
.25412 .30899 L
.25742 .30891 L
.2606 .30882 L
.26365 .30874 L
.26523 .3087 L
.2661 .30869 L
.26691 .30868 L
.26731 .30867 L
.26773 .30867 L
.26795 .30867 L
.26815 .30867 L
.26827 .30867 L
.26838 .30867 L
.26844 .30867 L
.2685 .30867 L
.26856 .30867 L
Mistroke
.26862 .30867 L
.26872 .30867 L
.26878 .30867 L
.26883 .30867 L
.26893 .30867 L
.26903 .30867 L
.26912 .30867 L
.26921 .30867 L
.2694 .30867 L
.26961 .30867 L
.2698 .30867 L
.27023 .30868 L
.27062 .30868 L
.27103 .30869 L
.27177 .3087 L
.27256 .30873 L
.27343 .30876 L
.27499 .30884 L
.27666 .30895 L
.27996 .30925 L
.28314 .3096 L
.2862 .30994 L
.28791 .3101 L
.28872 .31016 L
.28946 .31021 L
.29023 .31025 L
.29064 .31026 L
.29085 .31026 L
.29107 .31027 L
.29117 .31027 L
.29127 .31027 L
.29136 .31027 L
.29145 .31027 L
.29155 .31027 L
.29161 .31027 L
.29166 .31027 L
.29176 .31027 L
.29186 .31027 L
.29195 .31027 L
.29204 .31027 L
.29212 .31027 L
.29221 .31027 L
.29241 .31027 L
.2926 .31026 L
.293 .31025 L
.29344 .31023 L
.29385 .3102 L
.29423 .31017 L
.29496 .31011 L
.29572 .31001 L
Mistroke
.29729 .30976 L
.29876 .30944 L
.30187 .30852 L
.30518 .30733 L
.30683 .30673 L
.30836 .30622 L
.30984 .30581 L
.31067 .30563 L
.31142 .30551 L
.31181 .30546 L
.31203 .30544 L
.31223 .30543 L
.31241 .30542 L
.31258 .30541 L
.31267 .3054 L
.31277 .3054 L
.31287 .3054 L
.31297 .3054 L
.31307 .3054 L
.31317 .3054 L
.31327 .3054 L
.31333 .3054 L
.31339 .3054 L
.31349 .3054 L
.31361 .30541 L
.31384 .30542 L
.31404 .30544 L
.31425 .30546 L
.31464 .30551 L
.31507 .30558 L
.31546 .30566 L
.31635 .30591 L
.31714 .30621 L
.31797 .30659 L
.31954 .30751 L
.32101 .3086 L
.32412 .31142 L
.32743 .31465 L
.32909 .31604 L
.32989 .31661 L
.33062 .31704 L
.33099 .31723 L
.33139 .3174 L
.33173 .31752 L
.33211 .31763 L
.3323 .31768 L
.33251 .31771 L
.33262 .31773 L
.33273 .31774 L
.33283 .31775 L
Mistroke
.33293 .31776 L
.33302 .31777 L
.33312 .31777 L
.33321 .31777 L
.33327 .31777 L
.33332 .31777 L
.33341 .31777 L
.3335 .31776 L
.33359 .31775 L
.33369 .31774 L
.3339 .31771 L
.33409 .31768 L
.33446 .31758 L
.33485 .31744 L
.33528 .31724 L
.33604 .31676 L
.33675 .31617 L
.33826 .31446 L
.33992 .31191 L
.34316 .30535 L
.34627 .29836 L
.34786 .2952 L
.3487 .29378 L
.34959 .29251 L
.35004 .29199 L
.35046 .29158 L
.35087 .29125 L
.35125 .29102 L
.35143 .29093 L
.35161 .29087 L
.35179 .29081 L
.35188 .29079 L
.35199 .29077 L
.35209 .29076 L
.35215 .29076 L
.3522 .29076 L
.3523 .29076 L
.3524 .29076 L
.3525 .29077 L
.35258 .29078 L
.35268 .2908 L
.35278 .29083 L
.35299 .2909 L
.3532 .291 L
.35359 .29126 L
.35406 .29167 L
.35448 .29216 L
.35531 .29343 L
.35609 .295 L
.3577 .29935 L
Mistroke
.35919 .30453 L
.36236 .31814 L
.3654 .33148 L
.36697 .33703 L
.36785 .33944 L
.36823 .34032 L
.36865 .3411 L
.36903 .34169 L
.36923 .34195 L
.36944 .34218 L
.36964 .34235 L
.36982 .34247 L
.37 .34255 L
.37008 .34258 L
.37018 .34261 L
.37023 .34262 L
.37029 .34262 L
.3704 .34263 L
.3705 .34262 L
.3706 .3426 L
.3707 .34257 L
.37081 .34252 L
.37093 .34245 L
.37104 .34238 L
.37143 .342 L
.37165 .34172 L
.37184 .34141 L
.37264 .33973 L
.37337 .33752 L
.37418 .33439 L
.37504 .33027 L
.37838 .30789 L
.3816 .28195 L
.38308 .27104 L
.38391 .26567 L
.3847 .26137 L
.38547 .25793 L
.38587 .25652 L
.3863 .25527 L
.38654 .25472 L
.38675 .25431 L
.38696 .25399 L
.38707 .25385 L
.38718 .25373 L
.38729 .25365 L
.38738 .25359 L
.38747 .25354 L
.38757 .25352 L
.38767 .25351 L
.38777 .25351 L
Mistroke
.38783 .25353 L
.38788 .25354 L
.38794 .25357 L
.38799 .2536 L
.38808 .25367 L
.38818 .25376 L
.38836 .25397 L
.38858 .2543 L
.38877 .25469 L
.3892 .2558 L
.3896 .25718 L
.39031 .26043 L
.39108 .2651 L
.39267 .27816 L
.39435 .29641 L
.39738 .33539 L
.39906 .3567 L
.4006 .37345 L
.40139 .38032 L
.40211 .38549 L
.40251 .38775 L
.40287 .38944 L
.40328 .39088 L
.4035 .39148 L
.40371 .39191 L
.4038 .39206 L
.4039 .39219 L
.40399 .39229 L
.40408 .39235 L
.40418 .3924 L
.40423 .39241 L
.40429 .39241 L
.40438 .39239 L
.40448 .39234 L
.40454 .3923 L
.40459 .39225 L
.40471 .39212 L
.40481 .39196 L
.40492 .39176 L
.40511 .39132 L
.40531 .39072 L
.40568 .38928 L
.40608 .38725 L
.40679 .38231 L
.40761 .3747 L
.4085 .3642 L
.41011 .33989 L
.41339 .27825 L
.41501 .24751 L
.41654 .22263 L
Mistroke
.41725 .21314 L
.418 .20496 L
.41839 .20149 L
.41882 .19841 L
.41921 .19626 L
.41938 .19551 L
.41957 .19486 L
.41967 .19457 L
.41978 .19431 L
.41988 .19411 L
.41998 .19398 L
.42003 .19391 L
.42009 .19387 L
.42014 .19383 L
.4202 .19381 L
.42026 .19381 L
.42031 .19382 L
.42042 .19387 L
.42052 .19398 L
.42058 .19406 L
.42063 .19415 L
.42084 .19461 L
.42102 .19519 L
.42121 .19599 L
.42158 .19798 L
.42193 .20041 L
.42271 .20798 L
.42355 .21922 L
.42434 .2326 L
.42583 .26383 L
.42892 .34349 L
.43048 .3839 L
.4313 .40332 L
.4322 .42171 L
.43305 .43622 L
.43383 .44639 L
.4342 .45011 L
.4344 .45176 L
.43461 .45326 L
.43481 .45445 L
.43499 .45531 L
.43508 .45566 L
.43518 .45597 L
.43527 .45622 L
.43535 .45641 L
.43545 .45657 L
.43554 .45666 L
.43564 .4567 L
.4357 .4567 L
.43575 .45668 L
Mistroke
.43583 .45661 L
.43593 .45648 L
.43602 .45628 L
.43612 .45604 L
.43633 .45529 L
.43652 .45435 L
.43695 .45136 L
.43735 .44761 L
.43778 .4424 L
.43864 .42846 L
.44022 .39255 L
.4419 .34238 L
.44523 .23047 L
.4469 .18204 L
.44763 .16487 L
.44843 .1497 L
.44881 .14416 L
.44921 .13931 L
.4494 .13739 L
.44959 .13584 L
.44977 .13456 L
.44993 .13363 L
.45012 .13281 L
.45023 .13248 L
.45033 .13226 L
.45042 .13212 L
.4505 .13205 L
.4506 .13204 L
.45069 .1321 L
.45079 .13225 L
.4509 .13249 L
.451 .1328 L
.45109 .13315 L
.45131 .1343 L
.45152 .13576 L
.45189 .13919 L
.4523 .14424 L
.45312 .15842 L
.45388 .17603 L
.4546 .19609 L
.45771 .31087 L
.45929 .37506 L
.46101 .43807 L
.46181 .46212 L
.46266 .48296 L
.46308 .49103 L
.46347 .49731 L
.46382 .50181 L
.4642 .50541 L
.46439 .50671 L
Mistroke
.46449 .50728 L
.46459 .50772 L
.46468 .50805 L
.46478 .50831 L
.46487 .50847 L
.46496 .50854 L
.46506 .50854 L
.46515 .50845 L
.46525 .50826 L
.46531 .5081 L
.46536 .50793 L
.46557 .50699 L
.46568 .50636 L
.46579 .50554 L
.46622 .50144 L
.46645 .4984 L
.46667 .49517 L
.46748 .4791 L
.46828 .45778 L
.46902 .43372 L
.47069 .3672 L
.47385 .22412 L
.47543 .16204 L
.47613 .14004 L
.47689 .12062 L
.4773 .11223 L
.47768 .10596 L
.47805 .10139 L
.47826 .09945 L
.47844 .09808 L
.47855 .09748 L
.47866 .09696 L
.47875 .09663 L
.47886 .09638 L
.47892 .09629 L
.47897 .09624 L
.47903 .09623 L
.47909 .09625 L
.47919 .09638 L
.47925 .0965 L
.47931 .09665 L
.4794 .097 L
.47949 .09742 L
.4797 .0987 L
.4799 .10041 L
.48012 .10274 L
.48052 .10832 L
.48089 .115 L
.48173 .13525 L
.48255 .16122 L
Mistroke
.48342 .19478 L
.48675 .35227 L
.48842 .42842 L
.48916 .45701 L
.48996 .48356 L
.49034 .49387 L
.49074 .5034 L
.49108 .51028 L
.49146 .5163 L
.49168 .51908 L
.49189 .52117 L
.49208 .52271 L
.49219 .52338 L
.49229 .52386 L
.49239 .52423 L
.49248 .52447 L
.49258 .52462 L
.49268 .52466 L
.49277 .52459 L
.49286 .52444 L
.49295 .52418 L
.49305 .52379 L
.49315 .52328 L
.49326 .5226 L
.49348 .5208 L
.49368 .51864 L
.49387 .51619 L
.4943 .50918 L
.49476 .4994 L
.4956 .47588 L
.49637 .44864 L
.49956 .30053 L
.50117 .22272 L
.50262 .16293 L
.50343 .13692 L
.5042 .11834 L
.50462 .11082 L
.50501 .10567 L
.50521 .10367 L
.50543 .10203 L
.50555 .10143 L
.50561 .10116 L
.50567 .10095 L
.50572 .10079 L
.50578 .10065 L
.50588 .10052 L
.50598 .10051 L
.50607 .1006 L
.50617 .1008 L
.50627 .10115 L
Mistroke
.50636 .10155 L
.50645 .10201 L
.50664 .10337 L
.50685 .10536 L
.50704 .10762 L
.50747 .11423 L
.50788 .12255 L
.50834 .13365 L
.50915 .15884 L
.51075 .22288 L
.51244 .30312 L
.51402 .37844 L
.51548 .4376 L
.51627 .46341 L
.51703 .48231 L
.51745 .49011 L
.51784 .49564 L
.51806 .49806 L
.51826 .49977 L
.51837 .50051 L
.51849 .50116 L
.51855 .50139 L
.51861 .50161 L
.51871 .50189 L
.51881 .50204 L
.51886 .50207 L
.51892 .50207 L
.51901 .502 L
.51911 .5018 L
.5192 .50153 L
.51928 .50119 L
.51947 .50012 L
.51968 .4985 L
.51987 .49661 L
.52029 .4909 L
.52063 .48486 L
.52101 .47686 L
.52176 .45666 L
.52334 .39994 L
.52502 .32631 L
.52662 .25526 L
.52746 .22133 L
.52835 .19016 L
.52915 .16762 L
.52957 .158 L
.53002 .14964 L
.53024 .14642 L
.53044 .14381 L
.53064 .14169 L
.53082 .1401 L
Mistroke
.53099 .13892 L
.53108 .13845 L
.53117 .13803 L
.53128 .13768 L
.53138 .13746 L
.53147 .13735 L
.53156 .13733 L
.53166 .13742 L
.53176 .13761 L
.53185 .13786 L
.53194 .13823 L
.53215 .13939 L
.53235 .14089 L
.5327 .14463 L
.53308 .14998 L
.53387 .16564 L
.53474 .18908 L
.53797 .31027 L
.53946 .36779 L
.54108 .41867 L
.54151 .42891 L
.54196 .43814 L
.54235 .44464 L
.54278 .45007 L
.543 .45227 L
.54321 .45385 L
.54341 .45497 L
.54351 .45538 L
.54357 .45558 L
.54362 .45573 L
.54372 .45594 L
.54381 .45604 L
.54391 .45607 L
.54397 .45604 L
.54402 .45599 L
.54411 .45584 L
.5442 .4556 L
.5443 .45526 L
.54439 .45485 L
.54459 .45373 L
.54477 .45236 L
.54518 .44813 L
.54558 .44256 L
.54601 .4351 L
.54749 .39892 L
.55082 .28755 L
.55249 .23647 L
.55323 .21861 L
.55362 .21059 L
.55403 .20321 L
Mistroke
.55444 .19736 L
.55481 .19316 L
.55499 .19155 L
.55518 .19008 L
.55536 .18899 L
.55553 .18824 L
.55563 .1879 L
.55568 .18776 L
.55574 .18764 L
.55584 .18748 L
.55594 .18741 L
.55603 .18742 L
.55611 .18748 L
.5562 .18762 L
.5563 .18785 L
.55641 .18818 L
.55652 .18864 L
.55673 .18976 L
.55693 .19119 L
.55712 .19279 L
.55749 .19679 L
.55789 .20225 L
.55862 .21488 L
.56028 .25421 L
.56186 .29921 L
.56358 .34716 L
.56438 .36625 L
.56523 .38318 L
.56565 .38989 L
.56604 .39522 L
.56641 .39942 L
.56677 .40245 L
.56696 .40376 L
.56714 .40472 L
.56734 .40553 L
.56744 .40585 L
.56755 .40608 L
.56765 .40624 L
.56775 .40632 L
.56784 .40633 L
.56794 .40628 L
.568 .40622 L
.56805 .40614 L
.56817 .4059 L
.56827 .40562 L
.56837 .40524 L
.56855 .40445 L
.56874 .40337 L
.56908 .40084 L
.56949 .39687 L
Mistroke
.56986 .39241 L
.57139 .36647 L
.57306 .32958 L
.57462 .29353 L
.57545 .27606 L
.57634 .25981 L
.5772 .24748 L
.5776 .2429 L
.57797 .23943 L
.57835 .23676 L
.57855 .23566 L
.57876 .23474 L
.57885 .23441 L
.57896 .2341 L
.57905 .23389 L
.57915 .23371 L
.57924 .2336 L
.57933 .23353 L
.57942 .23351 L
.5795 .23353 L
.5796 .23361 L
.57965 .23367 L
.57971 .23376 L
.57981 .23395 L
.5799 .23418 L
.58012 .23488 L
.58034 .2359 L
.58076 .23846 L
.58114 .24157 L
.58186 .24933 L
.58263 .25973 L
.58569 .31312 L
.58656 .32816 L
.58739 .34078 L
.5882 .351 L
.58855 .35473 L
.58894 .35825 L
.5893 .36088 L
.58967 .36311 L
.58988 .36406 L
.59007 .36476 L
.59017 .36504 L
.59027 .3653 L
.59035 .36549 L
.59045 .36565 L
.5905 .36573 L
.59056 .3658 L
.59066 .36588 L
.59076 .36592 L
.59086 .36591 L
Mistroke
.59091 .36589 L
.59096 .36586 L
.59107 .36576 L
.59113 .36568 L
.59118 .36558 L
.59129 .36537 L
.59149 .36486 L
.59167 .36425 L
.59208 .36237 L
.59245 .36007 L
.59285 .35704 L
.59358 .35022 L
.59523 .32998 L
.59682 .30818 L
.59765 .29719 L
.59854 .28673 L
.59941 .27836 L
.60019 .27265 L
.60057 .2706 L
.60077 .26972 L
.60098 .26894 L
.60117 .26837 L
.60137 .26789 L
.60146 .26773 L
.60156 .26758 L
.60165 .26747 L
.60173 .26739 L
.60182 .26733 L
.60191 .2673 L
.60201 .2673 L
.60211 .26733 L
.60222 .26741 L
.60227 .26746 L
.60233 .26752 L
.60252 .26782 L
.60271 .26822 L
.6029 .26876 L
.60326 .27005 L
.60371 .2722 L
.60413 .27473 L
.60492 .28059 L
.60801 .31068 L
.60957 .32485 L
.61046 .33112 L
.61089 .33352 L
.61129 .3354 L
.61167 .33681 L
.61187 .3374 L
.61209 .33792 L
.61229 .33829 L
Mistroke
.61247 .33855 L
.61255 .33864 L
.61265 .33872 L
.61273 .33877 L
.61282 .3388 L
.61291 .33882 L
.61301 .33881 L
.61311 .33878 L
.6132 .33873 L
.6133 .33865 L
.61341 .33853 L
.61361 .33825 L
.61382 .33784 L
.61405 .3373 L
.61445 .33604 L
.61521 .33282 L
.61602 .32828 L
.61749 .31821 L
.61906 .30668 L
.6199 .3011 L
.62079 .29599 L
.62124 .29385 L
.62166 .29213 L
.62206 .29075 L
.62244 .28973 L
.6228 .28901 L
.62298 .28874 L
.62318 .28851 L
.62328 .28841 L
.62338 .28835 L
.62343 .28832 L
.62348 .28829 L
.62359 .28826 L
.62369 .28825 L
.62379 .28825 L
.62389 .28827 L
.62397 .28831 L
.62407 .28836 L
.62416 .28843 L
.62437 .28863 L
.62457 .2889 L
.62478 .28925 L
.62517 .29009 L
.62552 .29105 L
.62638 .29406 L
.6272 .29762 L
.63028 .31307 L
.6311 .31659 L
.63187 .3193 L
.63267 .32141 L
Mistroke
.6331 .32221 L
.63334 .32255 L
.63356 .32279 L
.63366 .32289 L
.63376 .32296 L
.63385 .32302 L
.63394 .32307 L
.63404 .32311 L
.63414 .32314 L
.63424 .32316 L
.6343 .32316 L
.63435 .32316 L
.63444 .32315 L
.63454 .32313 L
.63462 .3231 L
.6347 .32306 L
.6349 .32294 L
.63508 .32279 L
.63547 .32233 L
.63589 .32165 L
.63675 .31973 L
.6383 .31492 L
.63997 .30902 L
.64155 .30409 L
.64244 .30196 L
.64287 .30117 L
.64328 .30057 L
.64366 .30012 L
.64388 .29993 L
.64408 .2998 L
.64425 .29971 L
.64435 .29967 L
.64444 .29964 L
.64453 .29962 L
.64462 .29961 L
.64472 .2996 L
.64481 .2996 L
.64492 .29961 L
.64501 .29963 L
.64506 .29965 L
.64512 .29966 L
.64522 .2997 L
.64542 .2998 L
.6456 .29992 L
.64602 .30029 L
.64646 .30082 L
.64722 .30203 L
.64804 .30365 L
.64951 .30706 L
.6511 .31071 L
Mistroke
.65194 .31234 L
.6524 .31311 L
.65283 .31372 L
.65325 .31421 L
.65362 .31457 L
.65404 .31487 L
.65426 .31499 L
.65439 .31504 L
.6545 .31508 L
.65459 .3151 L
.65468 .31512 L
.65478 .31514 L
.65488 .31515 L
.65497 .31515 L
.65506 .31515 L
.65514 .31515 L
.65523 .31514 L
.65534 .31512 L
.65543 .3151 L
.65565 .31504 L
.65585 .31495 L
.65603 .31485 L
.6564 .31461 L
.65681 .31426 L
.65763 .31335 L
.65911 .31124 L
.66079 .30864 L
.66153 .30761 L
.66233 .30664 L
.66271 .30626 L
.66311 .3059 L
.66346 .30565 L
.66384 .30542 L
.66407 .30532 L
.66427 .30524 L
.66447 .30518 L
.66457 .30516 L
.66468 .30514 L
.66477 .30512 L
.66486 .30511 L
.66495 .3051 L
.66504 .3051 L
.66514 .3051 L
.66523 .3051 L
.66533 .30511 L
.66538 .30511 L
.66544 .30512 L
.66562 .30515 L
.66573 .30517 L
.66583 .30519 L
Mistroke
.66624 .30533 L
.6666 .3055 L
.66698 .30572 L
.66865 .30709 L
.67024 .30868 L
.67108 .30948 L
.67197 .31024 L
.67276 .31078 L
.67318 .31101 L
.67364 .3112 L
.67384 .31127 L
.67405 .31134 L
.67425 .31138 L
.67443 .31142 L
.6746 .31144 L
.6747 .31145 L
.67479 .31146 L
.67488 .31147 L
.67499 .31147 L
.67508 .31147 L
.67517 .31147 L
.67527 .31147 L
.67537 .31146 L
.67546 .31146 L
.67555 .31145 L
.67576 .31142 L
.67595 .31138 L
.67631 .31129 L
.67668 .31117 L
.67755 .31079 L
.67834 .31036 L
.68002 .30931 L
.68156 .30841 L
.68234 .30805 L
.68307 .30778 L
.68344 .30768 L
.68383 .3076 L
.68405 .30757 L
.68426 .30754 L
.68445 .30752 L
.68456 .30752 L
.68466 .30751 L
.68476 .30751 L
.68485 .30751 L
.68494 .30751 L
.68503 .30751 L
.68513 .30751 L
.68519 .30751 L
.68524 .30752 L
.68544 .30753 L
Mistroke
.68562 .30755 L
.68581 .30757 L
.68616 .30763 L
.68658 .30772 L
.68702 .30783 L
.68782 .30808 L
.69086 .30924 L
.69167 .3095 L
.69243 .30969 L
.69285 .30977 L
.69331 .30985 L
.69351 .30987 L
.69372 .30989 L
.69391 .30991 L
.69401 .30991 L
.69411 .30992 L
.69421 .30992 L
.6943 .30993 L
.6944 .30993 L
.69445 .30993 L
.6945 .30993 L
.69461 .30993 L
.6947 .30993 L
.69481 .30993 L
.69486 .30993 L
.69492 .30992 L
.6951 .30992 L
.69521 .30991 L
.6953 .3099 L
.69566 .30987 L
.69607 .30983 L
.69652 .30976 L
.69733 .30961 L
.69905 .30921 L
.7006 .30886 L
.70138 .30871 L
.70179 .30865 L
.70222 .30859 L
.7026 .30855 L
.7028 .30853 L
.70301 .30851 L
.70321 .3085 L
.70339 .30849 L
.70357 .30848 L
.70374 .30848 L
.70383 .30848 L
.70393 .30848 L
.70403 .30848 L
.70411 .30847 L
.70421 .30848 L
Mistroke
.70431 .30848 L
.70436 .30848 L
.70442 .30848 L
.70452 .30848 L
.70463 .30848 L
.70474 .30849 L
.70495 .30849 L
.70534 .30852 L
.70572 .30855 L
.70611 .30858 L
.70682 .30866 L
.70987 .30908 L
.71067 .30918 L
.71143 .30925 L
.71185 .30928 L
.71231 .3093 L
.71251 .30931 L
.71272 .30932 L
.71291 .30933 L
.71301 .30933 L
.71311 .30933 L
.71321 .30933 L
.7133 .30933 L
.7134 .30933 L
.71345 .30933 L
.7135 .30933 L
.7136 .30933 L
.7137 .30933 L
.71381 .30933 L
.71386 .30933 L
.71392 .30933 L
.7141 .30933 L
.7143 .30932 L
.71466 .30931 L
.71511 .30929 L
.71553 .30927 L
.71633 .30922 L
.7194 .30897 L
.72021 .30891 L
.72098 .30888 L
.7214 .30886 L
.72162 .30885 L
.72186 .30885 L
.72206 .30884 L
.72216 .30884 L
.72228 .30884 L
.72238 .30884 L
.72248 .30884 L
.72257 .30884 L
.72266 .30884 L
Mistroke
.72275 .30883 L
.72285 .30883 L
.72294 .30883 L
.72303 .30884 L
.72312 .30884 L
.72323 .30884 L
.72333 .30884 L
.72344 .30884 L
.72364 .30884 L
.72383 .30884 L
.72426 .30885 L
.72502 .30888 L
.72574 .30891 L
.72721 .30898 L
.72804 .30902 L
.72883 .30905 L
.72966 .30908 L
.73042 .3091 L
.73084 .30911 L
.73103 .30911 L
.73124 .30912 L
.73135 .30912 L
.73145 .30912 L
.73156 .30912 L
.73165 .30912 L
.73177 .30912 L
.73183 .30912 L
.73189 .30912 L
.73199 .30912 L
.73205 .30912 L
.73211 .30912 L
.73221 .30912 L
.73226 .30912 L
.73232 .30912 L
.73242 .30912 L
.73251 .30912 L
.73272 .30912 L
.73295 .30912 L
.73337 .30911 L
.73375 .3091 L
.73524 .30907 L
.73689 .30902 L
.73769 .309 L
.73842 .30899 L
.73879 .30898 L
.73919 .30897 L
.73953 .30897 L
.73991 .30897 L
.7401 .30896 L
.74031 .30896 L
Mistroke
.74042 .30896 L
.74052 .30896 L
.74063 .30896 L
.74073 .30896 L
.74082 .30896 L
.74092 .30896 L
.74101 .30896 L
.74107 .30896 L
.74112 .30896 L
.74121 .30896 L
.7413 .30896 L
.74139 .30896 L
.74149 .30896 L
.74159 .30896 L
.74169 .30896 L
.74189 .30896 L
.74225 .30896 L
.74268 .30897 L
.74307 .30897 L
.74454 .30899 L
.74618 .30902 L
.74697 .30903 L
.7477 .30904 L
.74806 .30904 L
.74846 .30904 L
.74883 .30905 L
.74917 .30905 L
.74937 .30905 L
.74957 .30905 L
.74965 .30905 L
.74974 .30905 L
.74984 .30905 L
.74993 .30905 L
.75003 .30905 L
.75013 .30905 L
.75023 .30905 L
.75032 .30905 L
.75042 .30905 L
.75054 .30905 L
.75074 .30905 L
.75093 .30905 L
.75113 .30905 L
.7515 .30905 L
.75233 .30904 L
.75402 .30903 L
.7556 .30901 L
.75649 .30901 L
.75692 .309 L
.75732 .309 L
.75771 .309 L
Mistroke
.75791 .309 L
.75813 .309 L
.75831 .309 L
.75841 .309 L
.75851 .309 L
.75861 .309 L
.75869 .309 L
.75878 .309 L
.75886 .309 L
.75897 .309 L
.75906 .309 L
.75911 .309 L
.75917 .309 L
.75927 .309 L
.75937 .309 L
.75947 .309 L
.75965 .309 L
.75986 .309 L
.76006 .309 L
.76051 .309 L
.76135 .30901 L
.76214 .30901 L
.76364 .30902 L
.76441 .30902 L
.76524 .30902 L
.76594 .30902 L
.76634 .30902 L
.76672 .30903 L
.76692 .30903 L
.76712 .30903 L
.76722 .30903 L
.76733 .30903 L
.76738 .30903 L
.76744 .30903 L
.7675 .30903 L
.76755 .30903 L
.76765 .30903 L
.76775 .30903 L
.76785 .30903 L
.76791 .30903 L
.76796 .30903 L
.76806 .30903 L
.76816 .30903 L
.76834 .30903 L
.76852 .30903 L
.76872 .30903 L
.76911 .30903 L
.76983 .30902 L
.77151 .30902 L
.77306 .30902 L
Mistroke
.77384 .30901 L
.77457 .30901 L
.77494 .30901 L
.77533 .30901 L
.77555 .30901 L
.77576 .30901 L
.77595 .30901 L
.77606 .30901 L
.77616 .30901 L
.77626 .30901 L
.77636 .30901 L
.77644 .30901 L
.77654 .30901 L
.77664 .30901 L
.77669 .30901 L
.77674 .30901 L
.77694 .30901 L
.77712 .30901 L
.77731 .30901 L
.77767 .30901 L
.77809 .30901 L
.77853 .30901 L
.77932 .30901 L
.78092 .30902 L
.78237 .30902 L
.78276 .30902 L
.78318 .30902 L
.78354 .30902 L
.78394 .30902 L
.78416 .30902 L
.78437 .30902 L
.78448 .30902 L
.78458 .30902 L
.7847 .30902 L
.78475 .30902 L
.78482 .30902 L
.78492 .30902 L
.78502 .30902 L
.78507 .30902 L
.78513 .30902 L
.78523 .30902 L
.78533 .30902 L
.78544 .30902 L
.78562 .30902 L
.78583 .30902 L
.78602 .30902 L
.78638 .30902 L
.7872 .30902 L
.78867 .30902 L
.79013 .30902 L
Mistroke
.79096 .30902 L
.79137 .30902 L
.79174 .30902 L
.79211 .30902 L
.7925 .30902 L
.79271 .30902 L
.7929 .30902 L
.79301 .30902 L
.7931 .30902 L
.79316 .30902 L
.79322 .30902 L
.79327 .30902 L
.79333 .30902 L
.79342 .30902 L
.79353 .30902 L
.79363 .30902 L
.79372 .30902 L
.79382 .30902 L
.79394 .30902 L
.79414 .30902 L
.79436 .30902 L
.79459 .30902 L
.79501 .30902 L
.79584 .30902 L
.79673 .30902 L
.79835 .30902 L
.79918 .30902 L
.79995 .30902 L
.80034 .30902 L
.80076 .30902 L
.801 .30902 L
.80111 .30902 L
.80122 .30902 L
.80132 .30902 L
.80142 .30902 L
.80153 .30902 L
.80159 .30902 L
.80164 .30902 L
.80174 .30902 L
.80184 .30902 L
.80193 .30902 L
.80202 .30902 L
.80212 .30902 L
.80218 .30902 L
.80223 .30902 L
.80243 .30902 L
.80262 .30902 L
.80284 .30902 L
.80326 .30902 L
.80403 .30902 L
Mistroke
.80475 .30902 L
.80624 .30902 L
.80703 .30902 L
.80787 .30902 L
.80833 .30902 L
.80875 .30902 L
.80895 .30902 L
.80917 .30902 L
.80938 .30902 L
.80957 .30902 L
.80967 .30902 L
.80976 .30902 L
.80987 .30902 L
.80992 .30902 L
.80998 .30902 L
.81003 .30902 L
.81008 .30902 L
.81018 .30902 L
.81024 .30902 L
.81029 .30902 L
.81035 .30902 L
.81041 .30902 L
.81051 .30902 L
.81061 .30902 L
.81081 .30902 L
.811 .30902 L
.81118 .30902 L
.81159 .30902 L
.81203 .30902 L
.81283 .30902 L
.81432 .30902 L
.81515 .30902 L
.81592 .30902 L
.81634 .30902 L
.81673 .30902 L
.81715 .30902 L
.81739 .30902 L
.81761 .30902 L
.8178 .30902 L
.81798 .30902 L
.81808 .30902 L
.81817 .30902 L
.81828 .30902 L
.81833 .30902 L
.81838 .30902 L
.81844 .30902 L
.81849 .30902 L
.81859 .30902 L
.8187 .30902 L
.81881 .30902 L
Mistroke
.81902 .30902 L
.81921 .30902 L
.81955 .30902 L
.81992 .30902 L
.82069 .30902 L
.82238 .30902 L
.82392 .30902 L
.82469 .30902 L
.82512 .30902 L
.82532 .30902 L
.82552 .30902 L
.8257 .30902 L
.8259 .30902 L
.82599 .30902 L
.82609 .30902 L
.82617 .30902 L
.82625 .30902 L
.82635 .30902 L
.82645 .30902 L
.82654 .30902 L
.82663 .30902 L
.82673 .30902 L
.82682 .30902 L
.82693 .30902 L
.82704 .30902 L
.82723 .30902 L
.82743 .30902 L
.82779 .30902 L
.8286 .30902 L
.83007 .30902 L
.83089 .30902 L
.83167 .30902 L
.83243 .30902 L
.83276 .30902 L
.83313 .30902 L
.8335 .30902 L
.8337 .30902 L
.83389 .30902 L
.83399 .30902 L
.83409 .30902 L
.83419 .30902 L
.83428 .30902 L
.83439 .30902 L
.83449 .30902 L
.83459 .30902 L
.83465 .30902 L
.83471 .30902 L
.8348 .30902 L
.83486 .30902 L
.83491 .30902 L
Mistroke
.83503 .30902 L
.83513 .30902 L
.83532 .30902 L
.83552 .30902 L
.83596 .30902 L
.83639 .30902 L
.83786 .30902 L
.83869 .30902 L
.83947 .30902 L
.8403 .30902 L
.84067 .30902 L
.84106 .30902 L
.84128 .30902 L
.84148 .30902 L
.84169 .30902 L
.84188 .30902 L
.84198 .30902 L
.8421 .30902 L
.84221 .30902 L
.8423 .30902 L
.84241 .30902 L
.84247 .30902 L
.84252 .30902 L
.84258 .30902 L
.84263 .30902 L
.84269 .30902 L
.84275 .30902 L
.84284 .30902 L
.84294 .30902 L
.84312 .30902 L
.84333 .30902 L
.84353 .30902 L
.84393 .30902 L
.84435 .30902 L
.84583 .30902 L
.84665 .30902 L
.84743 .30902 L
.84819 .30902 L
.84889 .30902 L
.84926 .30902 L
.84964 .30902 L
.84985 .30902 L
.85003 .30902 L
.85014 .30902 L
.85024 .30902 L
.8503 .30902 L
.85035 .30902 L
.85041 .30902 L
.85046 .30902 L
.85057 .30902 L
Mistroke
.85063 .30902 L
.85068 .30902 L
.85078 .30902 L
.85089 .30902 L
.85107 .30902 L
.85128 .30902 L
.85173 .30902 L
.85214 .30902 L
.85364 .30902 L
.85527 .30902 L
.8557 .30902 L
.85616 .30902 L
.85658 .30902 L
.85698 .30902 L
.85735 .30902 L
.85756 .30902 L
.85775 .30902 L
.85785 .30902 L
.85795 .30902 L
.85805 .30902 L
.85811 .30902 L
.85816 .30902 L
.85822 .30902 L
.85827 .30902 L
.85833 .30902 L
.85839 .30902 L
.85849 .30902 L
.85854 .30902 L
.8586 .30902 L
.8587 .30902 L
.8588 .30902 L
.859 .30902 L
.8592 .30902 L
.85943 .30902 L
.86023 .30902 L
.86172 .30902 L
.86254 .30902 L
.8634 .30902 L
.86413 .30902 L
.86455 .30902 L
.86494 .30902 L
.86513 .30902 L
.86534 .30902 L
.86544 .30902 L
.86554 .30902 L
.86563 .30902 L
.86573 .30902 L
.86582 .30902 L
.8659 .30902 L
.86599 .30902 L
Mistroke
.86607 .30902 L
.86616 .30902 L
.86625 .30902 L
.86634 .30902 L
.86644 .30902 L
.86655 .30902 L
.86665 .30902 L
.86687 .30902 L
.86728 .30902 L
.86765 .30902 L
.86804 .30902 L
.86964 .30902 L
.87109 .30902 L
.87148 .30902 L
.8719 .30902 L
.87226 .30902 L
.87266 .30902 L
.87288 .30902 L
.87308 .30902 L
.8733 .30902 L
.87342 .30902 L
.87348 .30902 L
.87353 .30902 L
.87363 .30902 L
.87372 .30902 L
.87378 .30902 L
.87383 .30902 L
.87393 .30902 L
.87403 .30902 L
.87412 .30902 L
.87423 .30902 L
.87434 .30902 L
.87454 .30902 L
.87474 .30902 L
.8751 .30902 L
.87591 .30902 L
.87738 .30902 L
.87821 .30902 L
.879 .30902 L
.8797 .30902 L
.88009 .30902 L
.88045 .30902 L
.88064 .30902 L
.88082 .30902 L
.88092 .30902 L
.88102 .30902 L
.88113 .30902 L
.88123 .30902 L
.88132 .30902 L
.88143 .30902 L
Mistroke
.88152 .30902 L
.88161 .30902 L
.88172 .30902 L
.88178 .30902 L
.88183 .30902 L
.88204 .30902 L
.88225 .30902 L
.88245 .30902 L
.8829 .30902 L
.88372 .30902 L
.88523 .30902 L
.88602 .30902 L
.88686 .30902 L
.88729 .30902 L
.88752 .30902 L
.88776 .30902 L
.88798 .30902 L
.88818 .30902 L
.88839 .30902 L
.88858 .30902 L
.88867 .30902 L
.88878 .30902 L
.88883 .30902 L
.88888 .30902 L
.88898 .30902 L
.88908 .30902 L
.88918 .30902 L
.88926 .30902 L
.88936 .30902 L
.88947 .30902 L
.88957 .30902 L
.88979 .30902 L
.8902 .30902 L
.89059 .30902 L
.891 .30902 L
.89174 .30902 L
.89341 .30902 L
.89416 .30902 L
.89458 .30902 L
.89498 .30902 L
.89535 .30902 L
.89554 .30902 L
.89575 .30902 L
.89594 .30902 L
.89611 .30902 L
.89619 .30902 L
.89628 .30902 L
.89637 .30902 L
.89645 .30902 L
.89655 .30902 L
Mistroke
.89665 .30902 L
.89673 .30902 L
.89683 .30902 L
.89693 .30902 L
.89704 .30902 L
.89723 .30902 L
.89758 .30902 L
.89796 .30902 L
.89882 .30902 L
.89962 .30902 L
.90111 .30902 L
.90151 .30902 L
.90195 .30902 L
.90232 .30902 L
.90273 .30902 L
.90296 .30902 L
.90316 .30902 L
.90336 .30902 L
.90346 .30902 L
.90357 .30902 L
.90367 .30902 L
.90377 .30902 L
.90387 .30902 L
.90397 .30902 L
.90406 .30902 L
.90415 .30902 L
.90424 .30902 L
.90434 .30902 L
.90444 .30902 L
.90454 .30902 L
.90476 .30902 L
.90515 .30902 L
.90558 .30902 L
.90604 .30902 L
.90764 .30902 L
.90833 .30902 L
.90909 .30902 L
.90951 .30902 L
.9099 .30902 L
.91027 .30902 L
.91046 .30902 L
.91066 .30902 L
.91077 .30902 L
.91088 .30902 L
.91098 .30902 L
.91108 .30902 L
.91114 .30902 L
.91119 .30902 L
.91125 .30902 L
.91131 .30902 L
Mistroke
.91142 .30902 L
.91148 .30902 L
.91153 .30902 L
.91163 .30902 L
.91172 .30902 L
.91182 .30902 L
.91193 .30902 L
.91214 .30902 L
.91234 .30902 L
.91314 .30902 L
.91388 .30902 L
.91554 .30902 L
.91626 .30902 L
.91664 .30902 L
.91704 .30902 L
.91725 .30902 L
.91749 .30902 L
.9177 .30902 L
.91789 .30902 L
.91809 .30902 L
.9182 .30902 L
.91831 .30902 L
.9184 .30902 L
.91849 .30902 L
.91859 .30902 L
.91869 .30902 L
.91879 .30902 L
.9189 .30902 L
.919 .30902 L
.91909 .30902 L
.91927 .30902 L
.91945 .30902 L
.91988 .30902 L
.92027 .30902 L
.92174 .30902 L
.92255 .30902 L
.92341 .30902 L
.92415 .30902 L
.92457 .30902 L
.92496 .30902 L
.92515 .30902 L
.92525 .30902 L
.92536 .30902 L
.92545 .30902 L
.92556 .30902 L
.92565 .30902 L
.92574 .30902 L
.92583 .30902 L
.92592 .30902 L
.926 .30902 L
Mistroke
.92608 .30902 L
.92618 .30902 L
.92628 .30902 L
.92637 .30902 L
.92645 .30902 L
.92666 .30902 L
.92685 .30902 L
.92728 .30902 L
.92806 .30902 L
.92969 .30902 L
.93049 .30902 L
.93122 .30902 L
.93159 .30902 L
.93198 .30902 L
.93216 .30902 L
.93235 .30902 L
.93251 .30902 L
.93269 .30902 L
.93279 .30902 L
.9329 .30902 L
.93299 .30902 L
.93308 .30902 L
.93319 .30902 L
.93325 .30902 L
.9333 .30902 L
.93341 .30902 L
.93351 .30902 L
.9336 .30902 L
.9337 .30902 L
.93387 .30902 L
.93427 .30902 L
.93467 .30902 L
.93503 .30902 L
.93584 .30902 L
.93731 .30902 L
.93805 .30902 L
.93845 .30902 L
.93883 .30902 L
.93905 .30902 L
.93929 .30902 L
.93948 .30902 L
.9397 .30902 L
.9398 .30902 L
.9399 .30902 L
.93996 .30902 L
.94001 .30902 L
.94012 .30902 L
.94021 .30902 L
.94031 .30902 L
.94041 .30902 L
Mistroke
.9405 .30902 L
.94059 .30902 L
.94069 .30902 L
.94087 .30902 L
.94106 .30902 L
.94127 .30902 L
.942 .30902 L
.94365 .30902 L
.94446 .30902 L
.94523 .30902 L
.94565 .30902 L
.94611 .30902 L
.94631 .30902 L
.94653 .30902 L
.94671 .30902 L
.94681 .30902 L
.94691 .30902 L
.94702 .30902 L
.94711 .30902 L
.94722 .30902 L
.94728 .30902 L
.94733 .30902 L
.94743 .30902 L
.94752 .30902 L
.94762 .30902 L
.94773 .30902 L
.94782 .30902 L
.94791 .30902 L
.94808 .30902 L
.94829 .30902 L
.94847 .30902 L
.94934 .30902 L
.95015 .30902 L
.95162 .30902 L
.95202 .30902 L
.95245 .30902 L
.95283 .30902 L
.95323 .30902 L
.95346 .30902 L
.95366 .30902 L
.95386 .30902 L
.95396 .30902 L
.95407 .30902 L
.95417 .30902 L
.95427 .30902 L
.95437 .30902 L
.95446 .30902 L
.95455 .30902 L
.95464 .30902 L
.95473 .30902 L
Mistroke
.95483 .30902 L
.95494 .30902 L
.95504 .30902 L
.95528 .30902 L
.95571 .30902 L
.95651 .30902 L
.95814 .30902 L
.95894 .30902 L
.95928 .30902 L
.95967 .30902 L
.96001 .30902 L
.96038 .30902 L
.96058 .30902 L
.96076 .30902 L
.96095 .30902 L
.96104 .30902 L
.96112 .30902 L
.96121 .30902 L
.96131 .30902 L
.96141 .30902 L
.96152 .30902 L
.96161 .30902 L
.96171 .30902 L
.96179 .30902 L
.96188 .30902 L
.96208 .30902 L
.9623 .30902 L
.9627 .30902 L
.96352 .30902 L
.96442 .30902 L
.96519 .30902 L
.96604 .30902 L
.96644 .30902 L
.96687 .30902 L
.96727 .30902 L
.96745 .30902 L
.96764 .30902 L
.96774 .30902 L
.96786 .30902 L
.96796 .30902 L
.96806 .30902 L
.96817 .30902 L
.96823 .30902 L
.96829 .30902 L
.9684 .30902 L
.96845 .30902 L
.96851 .30902 L
.96856 .30902 L
.96862 .30902 L
.96872 .30902 L
Mistroke
.96882 .30902 L
.96891 .30902 L
.96911 .30902 L
.96933 .30902 L
.96973 .30902 L
.97009 .30902 L
.97091 .30902 L
.97238 .30902 L
.97312 .30902 L
.97353 .30902 L
.97391 .30902 L
.97432 .30902 L
.97454 .30902 L
.97465 .30902 L
.97477 .30902 L
.97487 .30902 L
.97498 .30902 L
.97503 .30902 L
.97509 .30902 L
.97519 .30902 L
.97528 .30902 L
.97539 .30902 L
.97548 .30902 L
.97557 .30902 L
.97565 .30902 L
.97572 .30902 L
.97587 .30902 L
.97604 .30902 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{421.375, 260.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008>0001AB000`400?l00000o`00003ooooooooo
oooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo
003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooo
oooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool0
0?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooooooo
ool@ooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooo
ooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo0ol0003o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0
003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo
00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`
ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLoooo
o`00<?ooool3o`000?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?oo
ool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0
033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomco
oooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooo
oooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool3o`000?oooooo
g?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0013ooooo0_o^k^h3ooooo`;ok^k^6Oooool00ol0003oooooooooo`3o
ooooomcooooo000;ooooo`;o000000[o410@ooooooooooook^k^oeEEEOo^k^koooooonk^k_mEEEGo
k^k^0oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h:ooooo`03o`000?oo
oooooooo0?oooooog?ooool000cooooo00?o0000ooooooooool00_ooool01Oo^k^koEEEEomgMgOmE
EEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00[ooooo
00?o0000ooooooooool0oooooooLooooo`0000?oooooo`000?l000001?l00002ooooo`Go00001?oo
ool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooo
oa0@400:ooooo`03o`000?oooooooooo0?oooooog?ooool000Wooooo00CoA4A4omgMgOoooooo0000
1?ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000000[ooooo00?o0000ooooooooool0oooooooLooooo`002Oooool01?oMgMgo
EEEEooooool00003ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000:ooooo`Co0000oooooooKooooo`002_oo
ool00omgMgOoc<c<o`000003ooooo`;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@00[ooooo00?o0000ooooooooool0oooooooLooooo`002_oo
ool00oo^k^koA4A4o`00000?ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`;o00001Oooool00ol0003oooooooooo`2Mooooo`03o`000?oooooooooo0?oooooo
??ooool000_ooooo00?oMgMgo`000?ooool03?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo09go
oooo00?o0000ooooooooool0oooooollooooo`00:?ooool01?l0003oooooooooool00004ooooo`03
o`000?oooooooooo09gooooo0_l0000:ooooo`03o`000?oooooooooo0?oooooo<?ooool002Sooooo
0ol00005ooooo`03o`000?oooooooooo09gooooo0_l00009ooooo`;o0000oooooolbooooo`00:Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo09gooooo0_l00009ooooo`;o0000oooo
oolbooooo`00:_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo09gooooo0_l00009
ooooo`;o0000oooooolbooooo`00<?ooool00ol0003oooooooooo`2Looooo`03o`000?oooooo0000
00Wooooo0_l0003ooooooc;ooooo000`ooooo`03o`000?oooooooooo09cooooo00?o0000ooooool0
00002Oooool2o`000?oooooo<_ooool0033ooooo00?o0000ooooooooool0W?ooool00ol0003ooooo
o`000009ooooo`;o0000oooooolbooooo`00<?ooool00ol0003oooooooooo`2Looooo`03o`000?oo
oooo000000Wooooo0_l0003ooooooc;ooooo000`ooooo`?o0000W?ooool00ol0003oooooo`000009
ooooo`03o`000?oooooo00000?oooooo<Oooool0033ooooo00?o0000ooooooooool0W?ooool00ol0
003oooooo`000009ooooo`03o`000?oooooo00000?oooooo<Oooool0033ooooo00?o0000oooooooo
ool0W?ooool00ol0003oooooo`000009ooooo`03o`000?oooooo00000?oooooo<Oooool0033ooooo
00?o0000ooooooooool0W?ooool00ol0003oooooo`000009ooooo`03o`000?oooooo00000?oooooo
<Oooool0033ooooo00?o0000ooooooooool0W?ooool00ol0003oooooo`000009ooooo`03o`000?oo
oooo00000?oooooo<Oooool0033ooooo00?o0000ooooooooool0TOooool00ol0003oooooooooo`08
ooooo`03o`000?oooooo000000Wooooo00?o0000ooooool00000oooooolaooooo`00<?ooool00ol0
003oooooooooo`2@ooooo`;o00002_ooool00ol0003oooooo`000009ooooo`03o`000?oooooo0000
0?oooooo<Oooool0033ooooo00?o0000ooooooooool0T?ooool2o`0000[ooooo00?o0000ooooool0
00002Oooool00ol0003oooooo`00003ooooooc7ooooo000`ooooo`03o`000?oooooooooo093ooooo
0_l0000:ooooo`03o`000?oooooo000000Wooooo00?o0000ooooool000002Oooool00ol0003ooooo
ooooo`3oooooobGooooo000`ooooo`03o`000?oooooooooo093ooooo0_l0000:ooooo`03o`000?oo
oooo000000Wooooo00?o0000ooooool000002Oooool00ol0003oooooooooo`3oooooobGooooo000`
ooooo`03o`000?oooooooooo093ooooo0_l0000:ooooo`03o`000?oooooo000000Wooooo00?o0000
ooooool000002Oooool00ol0003oooooooooo`3oooooobGooooo000`ooooo`03o`000?oooooooooo
093ooooo00?o0000ooooool000002Oooool00ol0003oooooo`000009ooooo`03o`000?oooooo0000
00Sooooo0_l0003oooooobOooooo000`ooooo`?o0000T?ooool00ol0003oooooo`000009ooooo`03
o`000?oooooo000000Wooooo00?o0000ooooool000002?ooool2o`000?oooooo9oooool0033ooooo
00?o0000ooooooooool0T?ooool00ol0003oooooo`000009ooooo`04o`000?ooooooooooo`0000So
oooo00?o0000ooooool000002?ooool00ol0003oooooo`00003oooooobKooooo000`ooooo`03o`00
0?oooooooooo093ooooo00?o0000ooooool000002Oooool01?l0003oooooooooool00007ooooo`04
o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooolVooooo`00<?ooool00ol0003o
ooooooooo`2@ooooo`03o`000?oooooo000000Wooooo00Co0000oooooooooooo00001oooool01?l0
003oooooooooool00008ooooo`03o`000?oooooo00000?oooooo9_ooool0033ooooo00?o0000oooo
ooooool0T?ooool00ol0003oooooo`000009ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000
oooooooooooo00002?ooool00ol0003oooooo`00003oooooobKooooo000`ooooo`03o`000?oooooo
oooo08oooooo00Co0000oooooooooooo00002Oooool01?l0003oooooooooool00007ooooo`04o`00
0?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooolVooooo`00<?ooool00ol0003ooooo
ooooo`2?ooooo`04o`000?ooooooooooo`0000Wooooo00Co0000oooooooooooo00001oooool01?l0
003oooooooooool00008ooooo`03o`000?oooooo00000?oooooo9_ooool0033ooooo00?o0000oooo
ooooool0Soooool01?l0003oooooooooool00009ooooo`04o`000?ooooooooooo`0000Oooooo00Co
0000oooooooooooo00002?ooool00ol0003oooooo`00003oooooobKooooo000`ooooo`03o`000?oo
oooooooo08oooooo00Co0000oooooooooooo00002Oooool01?l0003oooooooooool00007ooooo`04
o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooolVooooo`00<?ooool00ol0003o
ooooooooo`2?ooooo`04o`000?ooooooooooo`0000Wooooo00Co0000oooooooooooo00001oooool0
1?l0003oooooooooool00008ooooo`03o`000?oooooo00000?oooooo9_ooool0033ooooo00?o0000
ooooooooool0Soooool01?l0003oooooooooool00009ooooo`04o`000?ooooooooooo`0000Oooooo
00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003oooooobKooooo000`ooooo`?o0000
Soooool01?l0003oooooooooool00009ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooo
oooooooo00002?ooool00ol0003oooooo`00003oooooobKooooo000`ooooo`03o`000?oooooooooo
08oooooo00Co0000oooooooooooo00002Oooool01?l0003oooooooooool00007ooooo`04o`000?oo
ooooooooo`0000Sooooo00?o0000ooooool00000oooooolVooooo`00<?ooool00ol0003ooooooooo
o`2?ooooo`04o`000?ooooooooooo`0000Wooooo00Co0000oooooooooooo00001oooool01?l0003o
ooooooooool00008ooooo`03o`000?oooooo00000?oooooo9_ooool0033ooooo00?o0000oooooooo
ool0Soooool01?l0003oooooooooool00009ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000
oooooooooooo00002?ooool00ol0003oooooo`00003oooooobKooooo000`ooooo`03o`000?oooooo
oooo08oooooo00Co0000oooooooooooo00002Oooool01?l0003oooooooooool00007ooooo`04o`00
0?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooolVooooo`00<?ooool00ol0003ooooo
ooooo`2?ooooo`04o`000?ooooooooooo`0000Wooooo00Co0000oooooooooooo00001oooool01?l0
003oooooooooool00008ooooo`03o`000?oooooo00000?oooooo9_ooool0033ooooo00?o0000oooo
ooooool0Soooool01?l0003oooooooooool00009ooooo`04o`000?ooooooooooo`0000Oooooo00Co
0000oooooooooooo00002?ooool00ol0003oooooo`000009ooooo`03o`000?oooooooooo0?oooooo
6_ooool0013ooooo0_o^k^h3ooooo`;ok^k^6Oooool00ol0003oooooooooo`2?ooooo`05o`000?oo
ooooooooooooool000002?ooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`00
00Sooooo00?o0000ooooool000002?ooool2o`000?oooooo7?ooool000Wooooo1Ol00002ooooo`07
onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co000000So410@ooooooooooook^k^oc8b
<_l0003o<S8bonk^kP[ooooo00?o0000ooooooooool0Soooool01Ol0003ooooooooooooooooo0000
00Sooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool00008ooooo`03o`000?oo
oooo000000Sooooo0_l0003ooooooacooooo0009ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00ooo
ool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00[ooooo00?o0000ooooooooool0Poooool2o`0000[ooooo00Go0000oooooooo
ooooooooo`000008ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00
0007ooooo`03o`000?oooooo000000Sooooo0_l0003ooooooacooooo00000ooooooo0000o`000004
o`0000?ooooo00?oV9RHob4Q8Oo^k^h01Oooool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooo
oooo00;ooooo00Go410@oooooooooooooooooa0@400:ooooo`03o`000?oooooooooo08?ooooo0_l0
000:ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oo
oooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo000000Sooooo0_l0003ooooo
oacooooo000;ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06oooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000:ooooo`03o`000?oooooo
oooo08?ooooo0_l0000:ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooo
oooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo000000So
oooo0_l0003ooooooacooooo000<ooooo`0;ogMgMomVIVKoooooooooooo^k^koEEEEonk^k_oooooo
k^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
2_ooool4o`0008;ooooo0_l0000:ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003o
oooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo
000000Sooooo0_l0003ooooooacooooo000=ooooo`03o`000?oooooooooo00;ok^k^0oooool2onk^
kPGooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00[ooooo00?o0000
ooooooooool0Poooool2o`0000[ooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oo
ooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooool0
00002?ooool2o`000?oooooo7?ooool000Wooooo00Go0000okZj^_ooooooV9RHoa0@400>ooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`;o00001Oooool00ol0
003oooooooooo`23ooooo`03o`000?oooooo000000Wooooo00Go0000ooooooooooooooooo`000007
ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo
00?o0000ooooool000002?ooool2o`000?oooooo7?ooool000Wooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c00<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`04
o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0Poooool00ol0003oooooo`000008oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo
000000Oooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Sooooo
0_l0003ooooooacooooo000Xooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0
Poooool00ol0003oooooo`000008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1Oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000006oooo
o`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooolKooooo`00:?ooool3o`00
00Gooooo00?o0000ooooooooool0P_ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000Oooooo00Go
0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool0
0000oooooolKooooo`00:Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo08;ooooo
00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Go
oooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool0
1?l0003oooooooooool00008ooooo`03o`000?oooooo00000?oooooo6oooool002[ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`22ooooo`04o`000?ooooooooooo`0000Sooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool00000
1oooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo00001oooool01?l0
003oooooooooool0003ooooooa_ooooo000`ooooo`03o`000?oooooooooo08;ooooo00Co0000oooo
oooooooo00002?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00Go0000
ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003ooooo
ooooool00007ooooo`04o`000?ooooooooooo`000?oooooo6oooool0033ooooo00?o0000oooooooo
ool0P_ooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01Oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`00
0006ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool0003ooooooa_o
oooo000`ooooo`03o`000?oooooooooo08;ooooo00Co0000oooooooooooo00002?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000007oooo
o`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Kooooo00Co
0000oooooooooooo0000oooooolKooooo`00<?ooool00ol0003oooooooooo`22ooooo`04o`000?oo
ooooooooo`0000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`05o`00
0?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000oooo
ooooooooooooo`000006ooooo`04o`000?ooooooooooo`000?oooooo6oooool0033ooooo0ol00022
ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`05ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Ko
oooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`000?oooooo6oooool0
033ooooo00?o0000ooooooooool0P_ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000Oooooo00Go
0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003o
ooooooooool0003ooooooa_ooooo000`ooooo`03o`000?oooooooooo08;ooooo00Co0000oooooooo
oooo00002?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00Go0000oooo
ooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooo
oooooooo000000Kooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`3ooooooa3o
oooo000`ooooo`03o`000?oooooooooo08;ooooo00Co0000oooooooooooo00002?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000007oooo
o`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Kooooo00Co
0000oooooooooooo00001oooool2o`000?oooooo4_ooool0033ooooo00?o0000ooooooooool0POoo
ool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`05ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo0000
00Kooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Oooooo0_l0
003ooooooa;ooooo000`ooooo`03o`000?oooooooooo087ooooo00Go0000ooooooooooooooooo`00
0008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooo
oooooooo000000Oooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?oooooooooooooo
ool000001_ooool01?l0003oooooooooool00007ooooo`;o0000oooooolBooooo`00<?ooool00ol0
003oooooooooo`21ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oo
ooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooo
oooo00001oooool2o`000?oooooo4_ooool0033ooooo00?o0000ooooooooool0POooool01Ol0003o
oooooooooooooooo000000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05oooo
o`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Kooooo00Go
0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Oooooo0_l0003ooooooa;o
oooo000`ooooo`03o`000?oooooooooo087ooooo00Go0000ooooooooooooooooo`000008ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo0000
00Oooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001_oo
ool01?l0003oooooooooool00007ooooo`03o`000?oooooo00000?oooooo4Oooool0033ooooo00?o
0000ooooooooool0POooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003o
oooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?oooooo
ooooo`0000Oooooo00?o0000ooooool00000oooooolAooooo`00<?ooool00ol0003oooooooooo`21
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oo
ooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooo
oooo00001oooool00ol0003oooooo`00003ooooooa7ooooo000`ooooo`03o`000?oooooooooo07Go
oooo0_l0000:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000007oooo
o`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Kooooo00Co
0000oooooooooooo00001oooool00ol0003oooooo`00003ooooooa7ooooo000`ooooo`?o0000MOoo
ool2o`0000[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Oooooo
00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001_ooool01?l0
003oooooooooool00006ooooo`04o`000?ooooooooooo`000?oooooo4Oooool0033ooooo00?o0000
ooooooooool0M?ooool3o`0000[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooo
oooo000000Oooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool0
00001_ooool01?l0003oooooooooool00006ooooo`04o`000?ooooooooooo`000?oooooo4Oooool0
033ooooo00?o0000ooooooooool0M?ooool01?l0003oooooooooool00009ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool00000
1_ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo00001_ooool01?l0
003oooooooooool0003ooooooa7ooooo000`ooooo`03o`000?oooooooooo07Cooooo00Co0000oooo
oooooooo00002Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001ooo
ool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000006ooooo`04
o`000?ooooooooooo`0000Kooooo00Co0000oooooooooooo0000oooooolAooooo`00<?ooool00ol0
003oooooooooo`1dooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool0
1Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0003ooooooooooooooooo000000Ko
oooo00Co0000oooooooooooo0000oooooolAooooo`00<?ooool00ol0003oooooooooo`1>ooooo`;o
k^k^0oooool2onk^kQoooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04oooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`03ooooo`03o`000?o^k^ko
oooo00;ooooo00?ok^k^o`000?ooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooo
ooooooooool000001_ooool01?l0003oooooooooool00007ooooo`;o0000?oooool2onk^kP?ooooo
0_o^k^i>ooooo`;ok^k^0oooool2onk^kVcooooo000`ooooo`03o`000?oooooooooo04Sooooo00go
A4A4o`000?l0003o<S8bomgMgOooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l0
00002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^3oooool01Ol0003ooooooooooooooooo
000000Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo1?l0
00002Ol@413oooooo`000?mEEEGok^k^ooooooo^k^koEEEEo`000003ooooo`Co000000Go410@oooo
ool0003ok^k^oc8b<P02o`000003onk^k_oooooooooo00?ooooo00Co0000oooooooooooo00001ooo
ool2o`0002Wooooo1?l000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool03Om4A4Co0000o`00
0?lb<S;ogMgMooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?oo
ooooooooonk^k_lb<S;o0000oc8b<_o^k^hhooooo`Go00000_ooool01oo^k^koEEEEonk^k_oooooo
k^k^oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^iMoooo
o`00<?ooool00ol0003oooooooooo`1;ooooo`09ogMgMolb<S;oooooooooooo^k^koEEEEomgMgOmE
EEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00oooooo
00Go0000ooooooooooooooooo`000009ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooo
ooooooooo`000006ooooo`03o`000?oooooo000000?ooooo00Oo0000onk^k_mEEEGogMgMoeEEEOo^
k^ko000000?ooooo00?o0000ooooool000000oooool01_l0003oMgMgoiRHV?oooooo0000ogMgM`Go
oooo00Co0000oooooooooooo00001oooool2o`0002_ooooo00?o0000ooooooooool01?ooool2ob4Q
8@Sooooo00WoMgMgoc8b<_ooooooooooonk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0>?ooool01OnHV9So8B4Qonk^k_ooooooA4A4
00?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`1Mooooo`00<?ooool00ol0003oooooooooo`1<ooooo`07o`000?oooooo
oooooooooooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooo`000003oooo
o`07o`000?oooooogMgMo`000?oMgMgoooooo`000003ooooo`03o`000?oooooo000000?ooooo00Ko
0000oa0@4?ooooooooooo`000?l@4105ooooo`04o`000?ooooooooooo`0000Oooooo0_l0000[oooo
o`03o`000?oooooooooo00oooooo00Oo0000ooooooooooooooooomgMgOl0003ogMgM00Oooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@03Wooooo00?oV9RHob4Q8Oo^k^h0
1Oooool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@401Mooooo`00<?ooool00ol0003oooooooooo`1;ooooo`09ogMgMolb<S;oooooooooooo^
k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000000oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooo000000?ooooo00Oo0000onk^k_mEEEGogMgMoeEEEOo^k^ko000000?ooooo00?o0000ooooool0
00000oooool2o`0000;ooooo0_l00005ooooo`04o`000?ooooooooooo`0000Oooooo0_l0000[oooo
o`03o`000?oooooooooo00kooooo00WoMgMgoc8b<_ooooooooooonk^k_mEEEGogMgMoeEEEOo^k^h0
1_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000>_ooool00onHV9So
8B4Qonk^kP03ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool00000GOooool0033ooooo00?o0000ooooooooool0B?ooool03Ol0
003o8B4Qo`000?lb<S;oc<c<ooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000003oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000000oooool01ol0003oEEEEonk^k_oo
ooook^k^oeEEEOl000000oooool00ol0003oooooo`000003ooooo`;o00000oooool00ol0003ooooo
ooooo`03ooooo`04o`000?ooooooooooo`0000Kooooo00Co0000oooooooooooo0000:_ooool00ol0
003oooooooooo`0;ooooo`0=o`000?lQ8B7o0000oc8b<_o<c<coooooonk^k_mEEEGok^k^ooooooo^
k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000k
ooooo`0;ogMgMomVIVKoooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000GOooool0033ooooo00?o0000oooo
ooooool0B?ooool00ol0003oooooooooo`03ooooo`;ok^k^0oooool2onk^kPGooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooo000000?ooooo00?o0000onk^k_ooool00_ooool0
0oo^k^ko0000ooooo`02ooooo`03o`000?oooooo000000?ooooo00?o0000oa0@4?ooool00_ooool0
0ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Kooooo00Co0000oooooooooooo0000
:_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo0_o^k^h3ooooo`;ok^k^
1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100??ooool00ol0003o
ooooooooo`02onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooo
oooooooooa0@401Mooooo`00<?ooool3o`0004Sooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooo`000003oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool2o`0000?ooooo00Ko0000ogMg
MonHV9SooooooiRHV?l00005ooooo`03o`000?oooooooooo00;o00001Oooool01?l0003ooooooooo
ool0000Zooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool2o`0002kooooo00Go0000okZj^_oo
ooooV9RHoa0@400>ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08
ooooo`;o0000Doooool0033ooooo00?o0000ooooooooool0B?ooool4o`0000cooooo00?oEEEEofIV
I_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ofIVI_l000000oooool0
0ol0003oooooooooo`03ooooo`05o`000?oooooooooooooooomEEED00_l00003ooooo`06o`000?o^
k^ko<S8bo`000?lb<S;o00001Oooool01_l0003oooooo`000?l0003oooooo`0000Cooooo00Co0000
oooooooooooo0000:?ooool00omEEEGoIVIVo`00000=ooooo`Co00003?ooool00omEEEGoIVIVo`00
0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01oooool01?l0003oooooooooool0000]ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`03?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01oooool01?l0003oooooooooool0001Booooo`00<?ooool00ol0003oooooooooo`1V
ooooo`Co00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?l000000ooooooo0000ooooo`02o`0000Cooooo00Co0000oooooooooooo00001ooo
ool00ol0003oooooooooo`1<ooooo`Co000000Goooooo`000?ooooooooooo`00001<ooooo`Co0000
00Goooooo`000?ooooooooooo`00001Booooo`00<?ooool00ol0003oooooooooo`1Vooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooool000000_l00005ooooo`04o`000?ooooooooooo`0000Ko
oooo0ol0001Booooo`?o0000D_ooool3o`0005?ooooo000`ooooo`03o`000?oooooooooo06Gooooo
0ol00003ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;o00001Oooool01?l0003oooooooooool00006oooo
o`03o`000?oooooo000005?ooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`1Boooo
o`00<?ooool00ol0003oooooooooo`1Tooooo`;o000000?oooooo`000?l000000_ooool4o`0000?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooooooooooo
ool000001Oooool01?l0003oooooooooool00006ooooo`03o`000?oooooo000005Cooooo00?o0000
ooooooooool0D_ooool00ol0003oooooooooo`1Aooooo`00<?ooool00ol0003oooooooooo`1Toooo
o`05o`000?ooooooooooooooool000002Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00Go0000ooooooooooooooooo`000005ooooo`05o`000?ooooooooooooooool00000
1Oooool00ol0003oooooo`00003mooooo`00<?ooool00ol0003oooooooooo`1Sooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00Go0000ooooooooooooooooo`000005ooooo`05o`000?ooooooooooooooool0
00001Oooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo0;Wooooo00?oMgMgofIVI_oo
ool0;Oooool00omVIVKoMgMgooooo`07ooooo`00<?ooool00ol0003oooooooooo`1Sooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000005ooooo`05o`000?oooooooooooooo
ool000001?ooool01?l0003oooooooooool00006ooooo`03o`000?oooooo00000;Wooooo00?ogMgM
oa0@4?o^k^h0;_ooool00oo^k^ko410@omgMg@07ooooo`00<?ooool00ol0003oooooooooo`1Roooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Gooooo00Co
0000oooooooooooo00001_ooool00ol0003oooooooooo`2Mooooo`;o00000_ooool2o`0000cooooo
00?oEEEEoiRHV?ooool00_l00002ooooo`07o`000?ooooooooooo`000?l@413ok^k^oeEEE@02o`00
0003odA4A?nj^[[ooooo00;ooooo00GoV9RHo`000?l0003oA4A4okZj^P02ooooo`08onk^k_mEEEGo
0000o`000?m4A4Co^[Zjooooool@4105o`0000?ooooo00So410@oc8b<_l0003o0000oa0@4?nYZJWo
QhN7ofIVIPOooooo000`ooooo`03o`000?oooooooooo05;ooooo1_l0000:ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Gooooo00Co0000oooooooooooo
00001Oooool3o`0000Oooooo00?o0000ooooooooool0U?ooool01_o^k^ko8B4QohN7Qonj^[[o0000
omgMg@cooooo00Go0000ooooooooooooooooo`000002ooooo`0;o`000?ooooooooooo`000?oooooo
EEEEogMgMoooooook^k^ogMgMol@41000oooool01Ol@413o^[Zjonk^k_mgMgOo410@00;ooooo00Ko
EEEEogMgMoooooook^k^ogMgMol@4103ooooo`03o`000?oooooooooo00Cooooo00So0000ojVYZOoo
oooooooookZj^_l0003ok^k^o`0000Oooooo003oo`000;Co00003oooool01?oMgMgo0000oa0@4?o<
c<`=ooooo`05oc8b<_ooooooooooooooool000000_ooool01_l0003oooooooooool0003oooooo`00
00Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Gooooo00Oo^[ZjohN7QomVIVKoIVIVoa0@4?oooooo000000Oooooo000:ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`So00002_ooool2
o`0000Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000Oooooo00?o0000ooooooooool01?ooool2o`0000Gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`;o00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00Co0000oooooooooooooooo0_l00003ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
00001?ooool01?l0003oooooooooool00005ooooo`Co00001?ooool4o`0000Oooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool05oooool01?o^k^ko8B4Qoa0@4?o^k^h=ooooo`05oc8b<_ooooooooooooooool000000_oo
ool01Ol0003oooooooooool0003ooooo00Ko00000oooool00ol0003oooooooooo`04ooooo`Ko0000
0oooool00ol0003oooooooooo`04ooooo`08oc8b<_lQ8B7oMgMgogMgMon7QhOok^k^ooooool00007
ooooo`002_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0?ooooo`;o00001Oooool00ol0003oooooooooo`06oooo
o`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo0_l00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool2
o`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
000000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00;ooooo0_l00003ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0005ooooo`04o`000?ooooooooooo`0000Gooooo0_l000000ooooooo0000ooooo`04ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool05oooool01?lQ8B7oMgMgogMgMolb<S8=ooooo`05
o`000?o^k^koooooooooool000000_o<c<`02ol0003oZJVYomgMgOlQ8B7ooooooeEEEOn7QhOok^k^
oooooon7QhOo<S8b00?ooooo00?o0000ooooooooool01?ooool01_mEEEGoQhN7onk^k_ooooooQhN7
oc8b<P?ooooo00?o0000oc8b<_oMgMd01?ooool02?l0003o^[Zjooooooo^k^koMgMgo`000?o^k^ko
00001oooool0033ooooo00?o0000ooooooooool0Foooool2o`0000;ooooo0_l00009ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooo000000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000001Oooool01?l0003oooooooooool00006ooooo`;o0000;?ooool00ol0
003oooooooooo`1Kooooo`03o`000?oooooooooo01Kooooo0_l00002ooooo`;o00003?ooool03_mE
EEGoMgMgooooool@413o0000ob4Q8Ol0003oMgMgoa0@4?l0003oZJVYooooooo^k^koEEEE0_l00000
1?m4A4Cok^k^ooooool@4105o`0000?ooooo00Kok^k^oeEEEOl0003o0000odA4A?o^k^h2ooooo`;o
000000CoZJVYob4Q8Ol0003o8B4Q0_ooool02?nYZJWo8B4Qo`000?l0003o<S8bo`000?mgMgOoEEEE
1oooool0033ooooo00?o0000ooooooooool0G?ooool4o`0000[ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`000005ooooo`04o`000?ooooooooooo`000;gooooo00?ogMgMoa0@4?o^k^h04_ooool00ol0003o
ooooooooo`0Iooooo`03onk^k_l@413ogMgM00Oooooo000`ooooo`03o`000?oooooooooo06[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
00Co0000oooooooooooo00001Oooool01?l0003oooooooooool0002nooooo`03ogMgMomVIVKooooo
017ooooo00?o0000ooooooooool06Oooool00omVIVKoMgMgooooo`07ooooo`00<?ooool00ol0003o
ooooooooo`1[ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000005oooo
o`04o`000?ooooooooooo`0000Kooooo0_l0003iooooo`00<?ooool00ol0003oooooooooo`1[oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo
000000Gooooo00Go0000ooooooooooooooooo`000005ooooo`04o`000?ooooooooooo`000?oooooo
0_ooool0033ooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00Go0000ooooooooooooooooo`000005ooooo`05o`000?ooooooooooooooool0
00001Oooool01?l0003oooooooooool0003oooooo`;ooooo000`ooooo`03o`000?oooooooooo06co
oooo00Go0000ooooooooooooooooo`000009ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001Oooool0
1Ol0003ooooooooooooooooo000000Gooooo00Co0000oooooooooooo0000ooooool2ooooo`00<?oo
ool00ol0003oooooooooo`1/ooooo`05o`000?ooooooooooooooool000002Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooo
oooooooooooo000000Gooooo00Go0000ooooooooooooooooo`000005ooooo`04o`000?oooooooooo
o`000?oooooo0_ooool0033ooooo00?o0000ooooooooool0K?ooool01Ol0003ooooooooooooooooo
000000Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00Go0000ooooooooooooooooo`000005ooooo`05o`000?ooooooooooooooool00000
1Oooool00ol0003oooooo`00003oooooo`?ooooo000`ooooo`?o0000K?ooool01Ol0003ooooooooo
oooooooo000000Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000005ooooo`05o`000?oooooooooooooo
ool000001_ooool2o`000?oooooo0oooool0033ooooo00?o0000ooooooooool0K?ooool01?l0003o
ooooooooool0000:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0003ooooooooooooo
oooo000000Kooooo0_l0003oooooo`?ooooo000`ooooo`03o`000?oooooooooo06gooooo00?o0000
ooooool000002_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool01Ol0003ooooooooooooooooo000000Gooooo00Co0000oooooooooooo0000
ooooool<ooooo`00<?ooool00ol0003oooooooooo`1]ooooo`;o00002oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooo
oooooooo000000Gooooo00Co0000oooooooooooo0000ooooool<ooooo`00<?ooool00ol0003ooooo
ooooo`1jooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000006ooooo`05
o`000?ooooooooooooooool000001Oooool01?l0003oooooooooool0003oooooo`cooooo000`oooo
o`03o`000?oooooooooo07[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo
000000Kooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo00000?oooooo3?oo
ool0033ooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooo
ooooooooool000001_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooo00000?oooooo
3?ooool0033ooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oo
ooooooooooooool000001_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooo00000?oo
oooo3?ooool0033ooooo00?o0000ooooooooool0N_ooool01Ol0003ooooooooooooooooo000000So
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooooooooooo
ool000001_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooo00000?oooooo3?ooool0
033ooooo00?o0000ooooooooool0N_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001_oo
ool01?l0003oooooooooool00007ooooo`03o`000?oooooo00000?oooooo3?ooool0033ooooo00?o
0000ooooooooool0N_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003o
ooooooooool00007ooooo`;o0000ooooool=ooooo`00<?ooool00ol0003oooooooooo`1jooooo`05
o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00?ooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Oooooo0_l0
003oooooo`gooooo000`ooooo`?o0000N_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool00000
1_ooool01?l0003oooooooooool00007ooooo`;o0000ooooool=ooooo`00<?ooool00ol0003ooooo
ooooo`1kooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000006oooo
o`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool00007ooooo`;o0000oooo
ool=ooooo`00<?ooool00ol0003oooooooooo`1kooooo`04o`000?ooooooooooo`0000Wooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00Go
0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003o
ooooooooool0003ooooooaKooooo000`ooooo`03o`000?oooooooooo07_ooooo00Co0000oooooooo
oooo00002Oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
1Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000006ooooo`04o`00
0?ooooooooooo`000?oooooo5_ooool0033ooooo00?o0000ooooooooool0Noooool01?l0003ooooo
ooooool00009ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Kooooo00Co
0000oooooooooooo0000oooooolFooooo`00<?ooool00ol0003oooooooooo`1kooooo`04o`000?oo
ooooooooo`0000Wooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001_ooool0
1?l0003oooooooooool0003ooooooaKooooo000`ooooo`03o`000?oooooooooo07_ooooo00Co0000
oooooooooooo00002Oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000007oooo
o`03o`000?oooooo00000?oooooo5_ooool0033ooooo00?o0000ooooooooool0Noooool01?l0003o
ooooooooool00009ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Oooooo
00?o0000ooooool00000oooooolFooooo`00<?ooool00ol0003oooooooooo`1kooooo`04o`000?oo
ooooooooo`0000Wooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001oooool0
0ol0003oooooo`00003ooooooaKooooo000`ooooo`03o`000?oooooooooo07cooooo00?o0000oooo
ool000002Oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
1Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000007ooooo`03o`00
0?oooooo00000?oooooo5_ooool0033ooooo00?o0000ooooooooool0O?ooool2o`0000[ooooo00Go
0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooo
ooooo`000006ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003ooooo
oaKooooo000`ooooo`03o`000?oooooooooo07cooooo0_l0000:ooooo`05o`000?oooooooooooooo
ool000002?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool0
1Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooool00000oooooolFooooo`00<?ooool3
o`0007cooooo0_l0000:ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`05o`00
0?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000oooo
ool00000oooooolFooooo`00<?ooool00ol0003oooooooooo`1mooooo`03o`000?oooooooooo00So
oooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`00
0006ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003ooooooaKooooo
000`ooooo`03o`000?oooooooooo08Sooooo00Go0000ooooooooooooooooo`000008ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Ko
oooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo0_l0003o
oooooaOooooo000`ooooo`03o`000?oooooooooo08Sooooo00Go0000ooooooooooooooooo`000008
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooo
oooo000000Kooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oo
oooo0_l0003ooooooaOooooo000`ooooo`03o`000?oooooooooo08Sooooo00Go0000oooooooooooo
ooooo`000008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003o
oooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?oooooo
ooooo`0000Oooooo0_l0003ooooooaOooooo000`ooooo`03o`000?oooooooooo08Sooooo00Go0000
ooooooooooooooooo`000008ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooo
oooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?oooooooooo
o`0000Oooooo0_l0003ooooooaOooooo000?ooooo`;ok^k^0oooool2onk^kQ[ooooo00?o0000oooo
ooooool0R?ooool01Ol0003ooooooooooooooooo000000Sooooo00Go0000ooooooooooooooooo`00
0007ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Oo
oooo00Co0000oooooooooooo00001oooool2o`000?oooooo5oooool000Sooooo1Ol00002ooooo`07
onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co000000So410@ooooooooooook^k^oc8b
<_l0003o<S8bonk^kP_ooooo00?o0000ooooooooool0R?ooool01Ol0003ooooooooooooooooo0000
00Sooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001_oo
ool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo00002?ooool00ol0003o
ooooooooo`3ooooooaGooooo0008ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01Oo^k^ko
EEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00?o0000ooooooooool0R?ooool01Ol0003ooooooooooooooooo000000Sooooo00Go
0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool01?l0003o
ooooooooool00007ooooo`04o`000?ooooooooooo`000?oooooo8?ooool000Wooooo00?oV9RHob4Q
8Oo^k^h01Oooool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooo
oooooooooooooa0@400;ooooo`03o`000?oooooooooo08Sooooo00Go0000ooooooooooooooooo`00
0008ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oo
oooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool0003oooooob3ooooo000:oooo
o`03oiRHV?lQ8B7ok^k^00?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`00000;ooooo`03o`000?oooooooooo08Wooooo00Co
0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooooooo
ooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo0000oooo
oolPooooo`002oooool02omgMgOoIVIVooooooooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^
00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000_ooooo1?l00028
ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000007ooooo`05o`00
0?ooooooooooooooool000001oooool01?l0003oooooooooool00007ooooo`04o`000?oooooooooo
o`000?oooooo8?ooool000cooooo00?o0000ooooooooool00_o^k^h3ooooo`;ok^k^1Oooool00ol0
003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41002oooool00ol0003oooooooooo`29
ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000007ooooo`05o`00
0?ooooooooooooooool000001oooool01?l0003oooooooooool00007ooooo`03o`000?oooooo0000
0?oooooo8Oooool000Sooooo00Go0000okZj^_ooooooV9RHoa0@400>ooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03o`000?oooooooooo08Wooooo00Co0000
oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooooooooooo
ooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool00000oooooolQoooo
o`002?ooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo00?oEEEEofIVI_l000001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo0_l00006ooooo`03o`000?oooooooooo08Wooooo00Co0000
oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooooooooooo
ooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool00000oooooolQoooo
o`009oooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo08Wooooo00Co0000oooo
oooooooo00002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooooooooooooooo
o`000007ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool00000oooooolQooooo`00
9oooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo08Wooooo00Co0000oooooooo
oooo00002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`00
0007ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool00000oooooolQooooo`009ooo
ool3o`0000Kooooo00?o0000ooooooooool0ROooool01?l0003oooooooooool00008ooooo`05o`00
0?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooo
oooooooo00001oooool00ol0003oooooo`00003oooooob7ooooo000Xooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0ROooool01?l0003oooooooooool00008ooooo`05o`000?oooooo
ooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo
00001oooool00ol0003oooooo`00003oooooob7ooooo000Yooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0ROooool01?l0003oooooooooool00008ooooo`05o`000?oooooooooooooo
ool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo00001ooo
ool00ol0003oooooo`00003oooooob7ooooo000`ooooo`03o`000?oooooooooo08Wooooo00?o0000
ooooool000002Oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooooooooooooooo
o`000007ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool00000oooooolQooooo`00
<?ooool00ol0003oooooooooo`29ooooo`03o`000?oooooo000000Wooooo00Go0000oooooooooooo
ooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool00007
ooooo`03o`000?oooooo00000?oooooo8Oooool0033ooooo00?o0000ooooooooool0ROooool00ol0
003oooooo`000009ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooo
oooo000000Oooooo00Co0000oooooooooooo00002?ooool2o`000?oooooo8Oooool0033ooooo0ol0
0029ooooo`03o`000?oooooo000000Wooooo00Go0000ooooooooooooooooo`000008ooooo`04o`00
0?ooooooooooo`0000Oooooo00Co0000oooooooooooo00002?ooool2o`000?oooooo8Oooool0033o
oooo00?o0000ooooooooool0ROooool00ol0003oooooo`000009ooooo`04o`000?ooooooooooo`00
00Wooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool00008ooooo`;o0000oooo
oolQooooo`00<?ooool00ol0003oooooooooo`29ooooo`03o`000?oooooo000000Wooooo00Co0000
oooooooooooo00002Oooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000So
oooo0_l0003oooooob7ooooo000`ooooo`03o`000?oooooooooo08[ooooo0_l0000:ooooo`03o`00
0?oooooo000000Wooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool00008oooo
o`;o0000oooooolQooooo`00<?ooool00ol0003oooooooooo`2:ooooo`;o00002_ooool00ol0003o
ooooo`000009ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00002?ooool2
o`000?oooooo8Oooool0033ooooo00?o0000ooooooooool0R_ooool2o`0000[ooooo00?o0000oooo
ool000002Oooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Sooooo0_l0
003oooooob7ooooo000`ooooo`03o`000?oooooooooo09Kooooo00?o0000ooooool000002Oooool0
1?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`000?oooooo:oooool0033ooooo00?o
0000ooooooooool0U_ooool00ol0003oooooo`000009ooooo`04o`000?ooooooooooo`0000Oooooo
00Co0000oooooooooooo0000ooooool[ooooo`00<?ooool00ol0003oooooooooo`2Fooooo`03o`00
0?oooooo000000Wooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool0003ooooo
ob_ooooo000`ooooo`03o`000?oooooooooo09Kooooo00?o0000ooooool000002Oooool00ol0003o
ooooo`000008ooooo`04o`000?ooooooooooo`000?oooooo:oooool0033ooooo00?o0000oooooooo
ool0U_ooool00ol0003oooooo`000009ooooo`03o`000?oooooo000000Sooooo00?o0000ooooool0
0000ooooool/ooooo`00<?ooool00ol0003oooooooooo`2Fooooo`03o`000?oooooo000000Wooooo
00?o0000ooooool000002?ooool00ol0003oooooo`00003oooooobcooooo000`ooooo`?o0000U_oo
ool00ol0003oooooo`000009ooooo`03o`000?oooooo000000Sooooo00?o0000ooooool00000oooo
ool/ooooo`00<?ooool00ol0003oooooooooo`2Fooooo`03o`000?oooooo000000Wooooo00?o0000
ooooool000002Oooool2o`000?oooooo;?ooool0033ooooo00?o0000ooooooooool0U_ooool00ol0
003oooooo`000009ooooo`03o`000?oooooo000000Wooooo0_l0003oooooobcooooo000`ooooo`03
o`000?oooooooooo09Kooooo00?o0000ooooool000002Oooool00ol0003oooooo`000009ooooo`;o
0000ooooool/ooooo`00<?ooool00ol0003oooooooooo`2Fooooo`03o`000?oooooo000000Wooooo
00?o0000ooooool000002Oooool2o`000?oooooo;?ooool0033ooooo00?o0000ooooooooool0U_oo
ool00ol0003oooooo`000009ooooo`03o`000?oooooo000000Wooooo0_l0003oooooobcooooo000`
ooooo`03o`000?oooooooooo09Kooooo00?o0000ooooool000002Oooool00ol0003oooooo`000009
ooooo`;o0000ooooool/ooooo`00<?ooool00ol0003oooooooooo`2Fooooo`03o`000?oooooo0000
00Wooooo00?o0000ooooool000002Oooool2o`000?oooooo;?ooool0033ooooo00?o0000oooooooo
ool0U_ooool00ol0003oooooo`000009ooooo`03o`000?oooooo000000Wooooo0_l0003oooooobco
oooo000`ooooo`03o`000?oooooooooo09Kooooo00?o0000ooooool000002Oooool00ol0003ooooo
o`000009ooooo`;o0000ooooool/ooooo`00<?ooool00ol0003oooooooooo`2Fooooo`03o`000?oo
oooo000000Wooooo00?o0000ooooool000002Oooool2o`000?oooooo;?ooool0033ooooo00?o0000
ooooooooool0U_ooool00ol0003oooooo`000009ooooo`03o`000?oooooo000000Wooooo0_l0003o
ooooobcooooo000`ooooo`?o0000U_ooool00ol0003oooooo`000009ooooo`03o`000?oooooo0000
00Wooooo0_l0003oooooobcooooo000`ooooo`03o`000?oooooooooo09Oooooo0_l00009ooooo`03
o`000?oooooo000000Wooooo0_l0003oooooobcooooo000`ooooo`03o`000?oooooooooo09Oooooo
0_l00009ooooo`03o`000?oooooo00000?oooooo=oooool0033ooooo00?o0000ooooooooool0Uooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooo00000?oooooo=oooool0033ooooo00?o0000
ooooooooool0Uoooool00ol0003oooooooooo`08ooooo`03o`000?oooooo00000?oooooo=oooool0
033ooooo00?o0000ooooooooool0X_ooool00ol0003oooooo`00003oooooocOooooo000?ooooo`;o
k^k^0oooool2onk^kQ[ooooo00?o0000ooooooooool0X_ooool00ol0003oooooo`00003oooooocOo
oooo000:ooooo`;o000000[o410@ooooooooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^0ooo
ool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`03o`000?oooooooooo
0:?ooooo0_l0003oooooocOooooo000;ooooo`03o`000?oooooooooo00;ooooo00Gok^k^oeEEEOoM
gMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`03o`000?oooooooooo0:?ooooo00?o0000ooooooooool0oooooolfooooo`002?ooool5o`00
00Cooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@41002oooool00ol0003oooooooooo`2Sooooo`03o`000?oooooooooo0?oooooo=_ooool0
00Sooooo00CoA4A4omgMgOoooooo00001?ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000_ooooo00?o0000ooooooooool0
Xoooool00ol0003oooooooooo`3oooooocKooooo0008ooooo`04omgMgOmEEEGoooooo`0000?ooooo
00Ook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000ooooooooool00_ooool01Ol0
003ooooooooooooooooo000000_ooooo1?l0002Rooooo`03o`000?oooooooooo0?oooooo=_ooool0
00Wooooo00?oMgMgolc<c?l000000oooool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo
00;ooooo00Go410@oooooooooooooooooa0@400;ooooo`03o`000?oooooooooo0?oooooog?ooool0
00Wooooo00?ok^k^odA4A?l000003oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool00ol0003oooooooooo`3oooooomcooooo000:ooooo`03ogMgMol0003ooooo
00cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo0_l00006
ooooo`03o`000?oooooooooo0?oooooog?ooool002Oooooo00Co0000oooooooooooo00001Oooool0
0ol0003oooooooooo`3oooooomcooooo000Wooooo`04o`000?ooooooooooo`0000Gooooo00?o0000
ooooooooool0oooooooLooooo`009oooool3o`0000Kooooo00?o0000ooooooooool0oooooooLoooo
o`00:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooog?ooool002Wooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0
003oooooooooo`3oooooomcooooo000`ooooo`?o0000oooooooLooooo`00<?ooool00ol0003ooooo
ooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000
ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03
o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?oo
ool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0
033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomco
oooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo0ol0003oooooomcooooo000`
ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLoooo
o`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooo
g?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool3o`00
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooo
ooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000
ooooooooool0oooooooLooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooo
ooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@oooo
o`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00:3ooooo0_l00004ooooo`03okZj^_lb
<S;ooooo00Cooooo0_l00006ooooo`03o`000?nj^[[ooooo0?ooooooEoooool00:3ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo0_lb<S;o
oooooeSooooo002=ooooo`?o00000_ooool01_lb<S;o410@ooooooooooook^k^oeEEE@;o000000?o
A4A4okZj^_ooool00oooool00ol0003oooooooooo`02ooooo`05oiRHV?l@413o0000o`000?nYZJT0
1?ooool00ol0003oooooooooo`04ooooo`03ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003o
A4A4okZj^P0;ooooo`03o`000?o^k^kooooo00Gooooo0_lQ8B44ooooo`0;onk^k_lb<S;o0000oa0@
4?o<c<coooooolc<c?o^k^koooooonk^k_o<c<`01?ooool4o`000008oa0@4?ooooooooooonk^k_lb
<S;o0000oc8b<_o^k^hCooooo`06oa0@4?lb<S;o0000o`000?l@413oZJVY0_ooool01_o^k^koEEEE
o`000?l0003oA4A4okZj^P?ooooo00GoIVIVo`000?l0003oA4A4olc<c03Xooooo`00S_ooool01Ol0
003oooooooooooo<c<co410@00?ooooo00KoEEEEogMgMoooooook^k^ogMgMol@4104ooooo`03o`00
0?oooooooooo00;ooooo00Ko0000ojVYZOmEEEGoV9RHoeEEEOnj^[X3ooooo`03o`000?oooooooooo
00Cooooo00?oc<c<o`000?l@41003?ooool01_l@413o^[Zjonk^k_mgMgOo410@ooooo`Ko00001?oo
ool00omEEEGoZJVYooooo`05ooooo`;o8B4Q1?ooool02omEEEGoMgMgoooooonHV9So8B4Qooooooo^
k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg01?ooooo00Ko0000ojVYZOoooooooooookZj^_l00002ooooo`06oeEEEOmgMgOoooooonk^
k_mgMgOo410@0_ooool01_mVIVKoMgMgooooooooooooQhN7oa0@4>Sooooo002>ooooo`05o`000?oo
oooooooooeEEEOn7QhL00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo
00Ko<S8bonk^k_nHV9SoEEEEomgMgOl@4103ooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool03Oooool00onYZJWoEEEEooooo`0;ooooo`05o`000?ooooooooooooooool000000_ooool0
0ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
400Dooooo`05okZj^_n7QhOoIVIVofIVI_l@41000_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0>_ooooo002>ooooo`05o`000?oooooogMgMo`000?o^k^h00oooool6o`0000Cooooo
00?o0000ooooooooool00_ooool01onj^[[oA4A4olc<c?lQ8B7ooooooa0@4?o<c<`00_ooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo00?ooooo1_l00005ooooo`03ob4Q8Ooooooooooo
00[ooooo00_o0000oiRHV?ooooooV9RHob4Q8Oooooook^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03
o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Cooooo`06oc8b<_lQ8B7oMgMg
ogMgMon7QhOok^k^0_ooool6o`0000;ooooo00?o0000ooooooooool0joooool008kooooo0ol00000
0ol@413oV9RHooooo`02ooooo`06oeEEEOn7QhOok^k^oooooon7QhOo<S8b1?ooool00ol0003ooooo
ooooo`02ooooo`07onk^k_l0003oooooo`000?ooooooIVIVohN7Q`02ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool03_ooool00omEEEGoc<c<ooooo`0:ooooo`0;o`000?mEEEGo0000
oa0@4?o<c<coooooolc<c?o^k^koooooonk^k_o<c<`01_ooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000004oooool01_l0003o^[Zjooooooo^k^koMgMgo`0000;ooooo00Ko
EEEEohN7Qoo^k^koooooohN7Qolb<S82ooooo`06ofIVI_mgMgOooooooooooon7QhOo0000j?ooool0
08kooooo00Go0000ooooooooooooc<c<o`000003ooooo`06onk^k_mEEEGo0000o`000?m4A4Cok^k^
1?ooool00ol0003oooooooooo`02ooooo`04ofIVI_nHV9Sooooooc8b<P;o^[Zj00Co0000oooooooo
oooo00004oooool00ol@413o0000o`000003o`0000gooooo00?oZJVYogMgMoooool02_ooool00omE
EEGoQhN7ooooo`0>ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4007
ooooo`?o00000_ooool3o`0000Cooooo00KoZJVYob4Q8Ol0003o0000oc8b<_l00002ooooo`06onk^
k_mEEEGo0000o`000?m4A4Cok^k^0_ooool01_o^k^koIVIVo`000?l0003oA4A4o`000>Sooooo002>
ooooo`05o`000?ooooooooooolc<c?l000003Oooool00ol0003oooooooooo`05ooooo`03ofIVI_n7
QhOooooo00?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0;ooooo`05oa0@4?oo
oooooooooooooolb<S802oooool00ooMgMgo410@oiRHV00>ooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0ooooool2ooooo`00SOooool4o`000003oa0@4?nYZJWooooo00cooooo0_l00006ooooo`03ojVY
ZOm4A4Cooooo00;ooooo0_l0000Eooooo`03o`000?oooooooooo00_ooooo1Ol0000<ooooo`04olc<
c?m4A4Co0000oa0@40[ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00;ooooo1?l00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0ooooool2oooo
o`00ooooool6ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0ooooool2ooooo`00
ooooool6ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0ooooool2ooooo`00oooo
ool5ooooo`;o00000oooool2o`000?oooooo1?ooool00?ooooooooooool@ooooo`00oooooooooooo
oa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003o
oooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo
4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oo
ooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@
ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooo
oooooooooa3ooooo0000\
\>"],
  ImageRangeCache->{{{0, 525.688}, {324.5, 0}} -> {-2.58312*^-7, -6.34248*^6, \
6.65005*^-9, 53093.5}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0.309017 5.42214e-08 [
[.32684 .29652 -16.5 -12.5 ]
[.32684 .29652 16.5 0 ]
[.54329 .29652 -16.5 -12.5 ]
[.54329 .29652 16.5 0 ]
[.75974 .29652 -22.5 -12.5 ]
[.75974 .29652 22.5 0 ]
[.97619 .29652 -16.5 -12.5 ]
[.97619 .29652 16.5 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 64 6 ]
[.09789 .09213 -34.5 -6.25 ]
[.09789 .09213 0 6.25 ]
[.09789 .20057 -34.5 -6.25 ]
[.09789 .20057 0 6.25 ]
[.09789 .41746 -28.5 -6.25 ]
[.09789 .41746 0 6.25 ]
[.09789 .5259 -28.5 -6.25 ]
[.09789 .5259 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -62.8125 0 ]
[.5 .63053 62.8125 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 .30902 m
.32684 .31527 L
s
gsave
.32684 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 .30902 m
.54329 .31527 L
s
gsave
.54329 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 .30902 m
.75974 .31527 L
s
gsave
.75974 .29652 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 .30902 m
.15368 .31277 L
s
.19697 .30902 m
.19697 .31277 L
s
.24026 .30902 m
.24026 .31277 L
s
.28355 .30902 m
.28355 .31277 L
s
.37013 .30902 m
.37013 .31277 L
s
.41342 .30902 m
.41342 .31277 L
s
.45671 .30902 m
.45671 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.58658 .30902 m
.58658 .31277 L
s
.62987 .30902 m
.62987 .31277 L
s
.67316 .30902 m
.67316 .31277 L
s
.71645 .30902 m
.71645 .31277 L
s
.80303 .30902 m
.80303 .31277 L
s
.84632 .30902 m
.84632 .31277 L
s
.88961 .30902 m
.88961 .31277 L
s
.9329 .30902 m
.9329 .31277 L
s
.0671 .30902 m
.0671 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09213 m
.11664 .09213 L
s
gsave
.09789 .09213 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .20057 m
.11664 .20057 L
s
gsave
.09789 .20057 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .41746 m
.11664 .41746 L
s
gsave
.09789 .41746 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .5259 m
.11664 .5259 L
s
gsave
.09789 .5259 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.11039 .11924 m
.11414 .11924 L
s
.11039 .14635 m
.11414 .14635 L
s
.11039 .17346 m
.11414 .17346 L
s
.11039 .22768 m
.11414 .22768 L
s
.11039 .2548 m
.11414 .2548 L
s
.11039 .28191 m
.11414 .28191 L
s
.11039 .33613 m
.11414 .33613 L
s
.11039 .36324 m
.11414 .36324 L
s
.11039 .39035 m
.11414 .39035 L
s
.11039 .44457 m
.11414 .44457 L
s
.11039 .47168 m
.11414 .47168 L
s
.11039 .49879 m
.11414 .49879 L
s
.11039 .06502 m
.11414 .06502 L
s
.11039 .03791 m
.11414 .03791 L
s
.11039 .0108 m
.11414 .0108 L
s
.11039 .55301 m
.11414 .55301 L
s
.11039 .58012 m
.11414 .58012 L
s
.11039 .60723 m
.11414 .60723 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -123.812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.812 moveto
(@) show
81.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.812 moveto
(D) show
93.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7.8) show
135.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
141.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
153.000 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
157.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
166.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
184.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02532 .30902 L
.02691 .30902 L
.02852 .30902 L
.03029 .30902 L
.03186 .30902 L
.03354 .30902 L
.03525 .30902 L
.03687 .30902 L
.03995 .30902 L
.04155 .30902 L
.04323 .30902 L
.04627 .30902 L
.04783 .30902 L
.04951 .30902 L
.05109 .30902 L
.05281 .30902 L
.056 .30902 L
.05758 .30902 L
.05926 .30902 L
.06087 .30902 L
.0626 .30902 L
.06582 .30902 L
.06911 .30902 L
.07228 .30902 L
.07533 .30902 L
.07857 .30902 L
.08169 .30902 L
.08501 .30902 L
.08821 .30902 L
.09129 .30902 L
.09285 .30902 L
.09456 .30902 L
.09535 .30902 L
.09619 .30902 L
.09658 .30902 L
.09698 .30902 L
.09733 .30902 L
.09753 .30902 L
.09771 .30902 L
.09782 .30902 L
.09793 .30902 L
.09802 .30902 L
.09812 .30902 L
.09818 .30902 L
.09823 .30902 L
.09829 .30902 L
.09835 .30902 L
.09845 .30902 L
.09851 .30902 L
Mistroke
.09856 .30902 L
.09866 .30902 L
.09876 .30902 L
.09895 .30902 L
.09914 .30902 L
.09936 .30902 L
.09974 .30902 L
.10013 .30902 L
.10085 .30902 L
.10125 .30902 L
.10161 .30902 L
.10243 .30902 L
.10318 .30902 L
.1039 .30902 L
.10468 .30902 L
.1055 .30902 L
.10698 .30902 L
.10855 .30902 L
.11002 .30902 L
.11164 .30902 L
.11313 .30902 L
.11478 .30902 L
.11631 .30902 L
.11937 .30902 L
.12102 .30902 L
.12251 .30902 L
.12572 .30902 L
.12882 .30902 L
.13211 .30902 L
.13527 .30902 L
.13832 .30902 L
.14156 .30902 L
.14305 .30902 L
.14468 .30902 L
.14556 .30902 L
.14595 .30902 L
.14638 .30902 L
.14679 .30902 L
.14697 .30902 L
.14717 .30902 L
.14727 .30902 L
.14737 .30902 L
.14747 .30902 L
.14757 .30902 L
.14762 .30902 L
.14767 .30902 L
.14773 .30902 L
.14779 .30902 L
.14784 .30902 L
.1479 .30902 L
Mistroke
.148 .30902 L
.14809 .30902 L
.1482 .30902 L
.1483 .30902 L
.14839 .30902 L
.14857 .30902 L
.14875 .30902 L
.14918 .30902 L
.14957 .30902 L
.14993 .30902 L
.15032 .30902 L
.15104 .30902 L
.1518 .30902 L
.15264 .30902 L
.15351 .30902 L
.15433 .30902 L
.15596 .30902 L
.15745 .30902 L
.15899 .30902 L
.16065 .30902 L
.16221 .30902 L
.16393 .30902 L
.16708 .30902 L
.17031 .30902 L
.17342 .30902 L
.17672 .30902 L
.1799 .30902 L
.18151 .30902 L
.18296 .30902 L
.18335 .30902 L
.18377 .30902 L
.18414 .30902 L
.18454 .30902 L
.18474 .30902 L
.18496 .30902 L
.18509 .30902 L
.1852 .30902 L
.18531 .30902 L
.18541 .30902 L
.18551 .30902 L
.18562 .30902 L
.18571 .30902 L
.1858 .30902 L
.18591 .30902 L
.18596 .30902 L
.18602 .30902 L
.18612 .30902 L
.18622 .30902 L
.18642 .30902 L
.1866 .30902 L
Mistroke
.18701 .30902 L
.18736 .30902 L
.18774 .30902 L
.1886 .30902 L
.1894 .30902 L
.19017 .30902 L
.1909 .30902 L
.19255 .30902 L
.19418 .30902 L
.19567 .30902 L
.19885 .30902 L
.20192 .30901 L
.20518 .30901 L
.20832 .30901 L
.21165 .30901 L
.21333 .30901 L
.21406 .30901 L
.21487 .30901 L
.21565 .30901 L
.21602 .30901 L
.21637 .30901 L
.21657 .30901 L
.21677 .30901 L
.21696 .30901 L
.21714 .30901 L
.21724 .30901 L
.21733 .30901 L
.21743 .30901 L
.21749 .30901 L
.21754 .30901 L
.21764 .30901 L
.21769 .30901 L
.21775 .30901 L
.21785 .30901 L
.21796 .30901 L
.21806 .30901 L
.21817 .30901 L
.21839 .30901 L
.21859 .30901 L
.21878 .30901 L
.21921 .30901 L
.21968 .30901 L
.22052 .30901 L
.22129 .30901 L
.22208 .30901 L
.22282 .30901 L
.22448 .30901 L
.22613 .30902 L
.22763 .30902 L
.23085 .30903 L
Mistroke
.23394 .30904 L
.23724 .30905 L
.24041 .30907 L
.24201 .30907 L
.24271 .30907 L
.24346 .30907 L
.24388 .30908 L
.24427 .30908 L
.24464 .30908 L
.24483 .30908 L
.24503 .30908 L
.24514 .30908 L
.24525 .30908 L
.24534 .30908 L
.24545 .30908 L
.24551 .30908 L
.24556 .30908 L
.24562 .30908 L
.24568 .30908 L
.24579 .30908 L
.24584 .30908 L
.2459 .30908 L
.246 .30908 L
.24609 .30908 L
.24629 .30908 L
.24649 .30908 L
.24671 .30908 L
.24713 .30908 L
.24753 .30907 L
.24841 .30907 L
.24919 .30907 L
.25003 .30906 L
.25159 .30905 L
.25305 .30904 L
.25616 .30899 L
.25945 .30893 L
.26263 .30886 L
.26569 .30879 L
.26739 .30876 L
.26819 .30875 L
.26894 .30874 L
.26931 .30874 L
.26971 .30873 L
.27012 .30873 L
.27034 .30873 L
.27044 .30873 L
.27055 .30873 L
.27065 .30873 L
.27074 .30873 L
.27083 .30873 L
Mistroke
.27093 .30873 L
.27103 .30873 L
.27111 .30873 L
.27119 .30873 L
.27128 .30873 L
.27138 .30873 L
.27148 .30873 L
.27169 .30873 L
.27189 .30873 L
.27207 .30873 L
.27247 .30874 L
.27291 .30874 L
.2737 .30875 L
.27448 .30877 L
.27519 .30879 L
.27669 .30884 L
.27834 .30892 L
.28157 .30914 L
.28468 .30941 L
.28798 .30972 L
.28963 .30986 L
.29043 .30992 L
.29116 .30996 L
.29187 .31 L
.29264 .31003 L
.29306 .31005 L
.29325 .31005 L
.29345 .31006 L
.29363 .31006 L
.29383 .31006 L
.29393 .31006 L
.29403 .31006 L
.29413 .31006 L
.29422 .31006 L
.29432 .31006 L
.29438 .31006 L
.29443 .31006 L
.29453 .31006 L
.29463 .31006 L
.29472 .31006 L
.2948 .31006 L
.29499 .31006 L
.2952 .31005 L
.29539 .31005 L
.29582 .31004 L
.29618 .31002 L
.29657 .31 L
.29729 .30995 L
.29805 .30989 L
.29888 .30979 L
Mistroke
.30057 .30954 L
.30213 .30923 L
.3038 .30883 L
.30711 .30787 L
.31029 .30691 L
.3119 .30649 L
.31336 .3062 L
.31375 .30614 L
.31417 .30608 L
.31454 .30604 L
.31494 .306 L
.31516 .30599 L
.31536 .30597 L
.31558 .30597 L
.3157 .30596 L
.31576 .30596 L
.31581 .30596 L
.31592 .30596 L
.31601 .30596 L
.31611 .30596 L
.31617 .30596 L
.31623 .30596 L
.31632 .30596 L
.31642 .30596 L
.31651 .30597 L
.31662 .30597 L
.31683 .30598 L
.31702 .30599 L
.31738 .30603 L
.31778 .30607 L
.3182 .30614 L
.31897 .3063 L
.31968 .30649 L
.32118 .30705 L
.32284 .3079 L
.32607 .31015 L
.32919 .31272 L
.33077 .31398 L
.3325 .31518 L
.3333 .31563 L
.33415 .31603 L
.33457 .31618 L
.33496 .3163 L
.33531 .31638 L
.33569 .31645 L
.33588 .31648 L
.33598 .31649 L
.33608 .31649 L
.33618 .3165 L
.33628 .3165 L
Mistroke
.33637 .31651 L
.33645 .31651 L
.33655 .31651 L
.33665 .3165 L
.33675 .3165 L
.33681 .31649 L
.33686 .31649 L
.33707 .31647 L
.33717 .31645 L
.33729 .31643 L
.33771 .31634 L
.33795 .31627 L
.33817 .3162 L
.33898 .31583 L
.33978 .31532 L
.34052 .31471 L
.34219 .3129 L
.3437 .31076 L
.34536 .30797 L
.3486 .3018 L
.35009 .29903 L
.35172 .29639 L
.3526 .29521 L
.35342 .29433 L
.3542 .2937 L
.35442 .29357 L
.35464 .29346 L
.35484 .29337 L
.35503 .2933 L
.35521 .29325 L
.35531 .29323 L
.35541 .29321 L
.35551 .2932 L
.35557 .2932 L
.35562 .29319 L
.35572 .29319 L
.35582 .29319 L
.35592 .2932 L
.35602 .29321 L
.35612 .29322 L
.35621 .29324 L
.35644 .29331 L
.35665 .29339 L
.35702 .29358 L
.35736 .29382 L
.35813 .29457 L
.35854 .29509 L
.35898 .29575 L
.35978 .2972 L
.36127 .30072 L
Mistroke
.36456 .31164 L
.36773 .32398 L
.36933 .32969 L
.37078 .334 L
.37158 .33586 L
.37235 .33721 L
.37276 .33776 L
.37315 .33814 L
.37335 .33829 L
.37357 .33841 L
.37369 .33846 L
.37374 .33848 L
.37381 .33849 L
.37386 .33851 L
.37392 .33852 L
.37402 .33853 L
.37413 .33853 L
.37423 .33852 L
.37428 .33851 L
.37434 .3385 L
.37445 .33846 L
.37455 .33842 L
.37466 .33837 L
.37485 .33824 L
.37505 .33807 L
.37524 .33788 L
.3756 .33741 L
.37602 .33671 L
.3764 .3359 L
.37728 .33352 L
.37813 .33049 L
.37893 .32703 L
.38042 .3191 L
.38352 .29845 L
.38509 .28727 L
.38682 .27591 L
.38761 .27135 L
.38846 .26713 L
.38926 .26391 L
.38999 .26168 L
.39039 .2608 L
.39059 .26044 L
.39081 .26012 L
.39092 .25999 L
.39103 .25988 L
.39113 .25979 L
.39123 .25973 L
.39134 .25967 L
.3914 .25965 L
.39146 .25963 L
Mistroke
.39152 .25962 L
.39159 .25962 L
.39164 .25962 L
.3917 .25963 L
.3918 .25966 L
.39189 .2597 L
.392 .25976 L
.39211 .25985 L
.39233 .26009 L
.39254 .2604 L
.39294 .26119 L
.39332 .26219 L
.39409 .26505 L
.39491 .26923 L
.39639 .27957 L
.39795 .2939 L
.39942 .30975 L
.40252 .34568 L
.40409 .36201 L
.40493 .36932 L
.40582 .37577 L
.40626 .37837 L
.40668 .38042 L
.40706 .3819 L
.40725 .38253 L
.40746 .38312 L
.40765 .38353 L
.40785 .38387 L
.40796 .38402 L
.40806 .38412 L
.40816 .38419 L
.40826 .38424 L
.40835 .38426 L
.40844 .38425 L
.40853 .38423 L
.40861 .38419 L
.40871 .38411 L
.40881 .38401 L
.409 .38373 L
.40919 .38336 L
.40939 .38284 L
.40976 .3816 L
.4102 .37962 L
.4106 .37733 L
.41147 .37083 L
.41229 .3628 L
.41389 .34252 L
.41537 .31943 L
.41852 .26459 L
.4201 .23937 L
Mistroke
.42155 .22073 L
.42231 .21336 L
.42269 .21034 L
.4231 .20769 L
.42332 .20655 L
.42352 .20567 L
.42372 .20493 L
.4239 .20438 L
.42401 .20414 L
.42412 .20392 L
.42423 .20376 L
.4243 .20369 L
.42435 .20364 L
.42441 .2036 L
.42446 .20358 L
.42456 .20357 L
.42466 .2036 L
.42472 .20364 L
.42478 .20369 L
.42488 .20382 L
.42499 .20401 L
.42519 .20446 L
.4254 .20513 L
.42563 .20609 L
.42604 .20836 L
.42643 .21114 L
.42715 .218 L
.42792 .22766 L
.42963 .25672 L
.43125 .29178 L
.43433 .36629 L
.43589 .40035 L
.43672 .41561 L
.43761 .42908 L
.43805 .43438 L
.43846 .43858 L
.43883 .44159 L
.43905 .44299 L
.43924 .44404 L
.43942 .44486 L
.43962 .44552 L
.43973 .4458 L
.43983 .44599 L
.43993 .44611 L
.44003 .44619 L
.44012 .44621 L
.44021 .44618 L
.4403 .44611 L
.44038 .446 L
.44048 .44583 L
Mistroke
.44058 .44558 L
.44077 .44497 L
.44096 .44415 L
.44116 .44304 L
.44152 .44043 L
.44196 .43632 L
.44235 .4316 L
.44318 .41909 L
.44404 .40213 L
.4471 .31866 L
.4488 .2647 L
.45035 .21817 L
.45112 .19754 L
.45196 .17805 L
.45275 .16309 L
.45348 .15246 L
.45385 .1485 L
.45424 .14527 L
.45447 .14392 L
.45458 .14339 L
.45468 .14297 L
.45478 .14264 L
.45487 .14241 L
.45497 .14222 L
.45503 .14214 L
.45508 .1421 L
.45518 .14206 L
.45523 .14207 L
.45528 .14211 L
.45539 .14223 L
.45545 .14234 L
.4555 .14246 L
.4556 .14273 L
.4557 .1431 L
.45589 .14398 L
.45611 .14536 L
.45635 .14722 L
.45677 .15159 L
.45752 .16266 L
.45833 .17902 L
.4598 .21895 L
.46311 .33911 L
.46476 .40051 L
.46629 .44908 L
.46705 .46828 L
.46777 .48264 L
.46817 .48886 L
.4686 .49412 L
.46879 .49595 L
.46899 .49753 L
Mistroke
.46916 .4986 L
.46935 .49947 L
.46946 .49982 L
.46955 .50005 L
.46966 .50021 L
.46971 .50025 L
.46977 .50026 L
.46987 .50022 L
.46992 .50015 L
.46998 .50007 L
.47007 .49985 L
.47017 .49954 L
.47035 .49871 L
.47052 .49766 L
.47091 .49428 L
.47113 .49179 L
.47134 .48904 L
.47172 .48289 L
.47259 .46447 L
.47337 .4429 L
.4742 .41547 L
.47568 .35725 L
.47871 .22539 L
.4804 .16247 L
.4812 .13895 L
.48195 .12179 L
.48232 .11511 L
.48271 .10943 L
.48293 .10686 L
.48315 .10491 L
.48334 .10355 L
.48344 .10295 L
.48354 .10249 L
.48363 .10217 L
.48373 .10192 L
.48383 .10175 L
.48393 .1017 L
.48403 .10174 L
.48408 .10181 L
.48413 .10191 L
.48423 .10216 L
.48433 .10253 L
.48451 .10343 L
.48468 .10459 L
.48506 .10831 L
.48544 .11345 L
.48585 .12071 L
.48668 .14028 L
.48816 .18987 L
.49142 .33762 L
Mistroke
.49292 .40675 L
.49455 .46911 L
.49545 .49448 L
.49584 .50325 L
.49627 .5111 L
.49646 .51402 L
.49667 .51669 L
.49686 .51861 L
.49705 .52029 L
.49717 .52107 L
.49728 .52166 L
.49738 .52209 L
.49743 .52227 L
.49749 .52243 L
.49754 .52255 L
.4976 .52263 L
.4977 .5227 L
.49779 .52266 L
.49789 .52251 L
.49798 .52226 L
.49804 .52206 L
.49809 .52185 L
.49829 .52079 L
.49846 .51945 L
.49865 .51765 L
.49904 .51267 L
.49947 .50527 L
.50023 .48742 L
.50094 .46564 L
.50405 .33029 L
.50563 .25247 L
.50735 .17674 L
.50815 .14839 L
.50859 .1352 L
.50901 .12448 L
.50939 .11605 L
.50981 .10875 L
.50999 .10615 L
.51019 .10381 L
.51036 .10216 L
.51054 .10073 L
.51065 .10008 L
.51074 .0996 L
.51084 .09924 L
.51094 .09897 L
.51103 .09883 L
.51111 .09878 L
.5112 .09882 L
.5113 .09898 L
.5114 .09925 L
Mistroke
.51145 .09946 L
.51151 .09968 L
.51172 .10096 L
.51191 .10251 L
.51211 .10463 L
.51251 .11014 L
.51288 .11695 L
.51359 .1337 L
.51436 .15792 L
.51519 .18911 L
.51667 .25534 L
.51971 .40004 L
.52127 .45906 L
.52172 .47233 L
.52214 .4831 L
.52256 .49186 L
.52294 .49815 L
.52314 .50069 L
.52334 .50296 L
.52354 .50467 L
.52372 .50585 L
.52381 .50634 L
.52391 .50669 L
.52401 .50697 L
.52406 .50707 L
.52411 .50713 L
.52422 .50716 L
.52428 .50712 L
.52433 .50705 L
.52443 .50683 L
.52454 .50647 L
.52463 .50606 L
.52471 .50559 L
.5249 .50425 L
.52506 .50274 L
.52524 .50081 L
.52561 .49558 L
.52601 .48817 L
.52684 .46786 L
.52759 .44402 L
.52927 .37642 L
.53094 .29962 L
.53248 .23148 L
.53398 .17698 L
.53474 .15636 L
.53517 .14715 L
.53557 .14014 L
.53596 .13502 L
.53618 .13286 L
.53639 .13134 L
Mistroke
.53648 .13078 L
.53658 .13035 L
.53666 .13004 L
.53675 .12979 L
.53685 .12962 L
.53695 .12956 L
.53704 .12959 L
.53713 .12973 L
.53719 .12986 L
.53725 .13003 L
.53735 .13044 L
.53746 .13095 L
.53755 .13154 L
.53777 .13323 L
.538 .13558 L
.53839 .14076 L
.53881 .1482 L
.53962 .16723 L
.54037 .18951 L
.54204 .25214 L
.5437 .32153 L
.54523 .38229 L
.54671 .42911 L
.54714 .43946 L
.54754 .44774 L
.54793 .45431 L
.54829 .45912 L
.54849 .46117 L
.54867 .4627 L
.54887 .46403 L
.54897 .46459 L
.54908 .46501 L
.54918 .46531 L
.54928 .46553 L
.54937 .46561 L
.54947 .46562 L
.54953 .46557 L
.54958 .46551 L
.54964 .4654 L
.5497 .46526 L
.5498 .46494 L
.54991 .46447 L
.5501 .46334 L
.55028 .46199 L
.55067 .45787 L
.55104 .45272 L
.55139 .44675 L
.55217 .42967 L
.55299 .40679 L
.55448 .35694 L
Mistroke
.55752 .24806 L
.55832 .22438 L
.55908 .20568 L
.55949 .19719 L
.55995 .18954 L
.56037 .18412 L
.56075 .18044 L
.56097 .17897 L
.56116 .17798 L
.56126 .1776 L
.56138 .17729 L
.56143 .17717 L
.56149 .17708 L
.56155 .17703 L
.5616 .17701 L
.5617 .17703 L
.5618 .17713 L
.5619 .17734 L
.56196 .17748 L
.56201 .17767 L
.56221 .17853 L
.5624 .17966 L
.56278 .18282 L
.56312 .18674 L
.5639 .19893 L
.56469 .21561 L
.56542 .23429 L
.56708 .28388 L
.56859 .33083 L
.57022 .37519 L
.57111 .39387 L
.5715 .40046 L
.57193 .40648 L
.57234 .41092 L
.57272 .41395 L
.57293 .41515 L
.57312 .41596 L
.57323 .41628 L
.57328 .41642 L
.57334 .41653 L
.57339 .41662 L
.57345 .41668 L
.57355 .41674 L
.57365 .41672 L
.57374 .41663 L
.57384 .41647 L
.5739 .41635 L
.57395 .41622 L
.57405 .41589 L
.57416 .41545 L
Mistroke
.57436 .41441 L
.57475 .41161 L
.5751 .4081 L
.57592 .39703 L
.57678 .38123 L
.57981 .30699 L
.5815 .26676 L
.5823 .25111 L
.58305 .23938 L
.58345 .23434 L
.58381 .23058 L
.58422 .22736 L
.58444 .22602 L
.58464 .22504 L
.58483 .22441 L
.58492 .22417 L
.58502 .22397 L
.58511 .22385 L
.58521 .22378 L
.58529 .22376 L
.58537 .22379 L
.58547 .22388 L
.58557 .22401 L
.58567 .22423 L
.58578 .22453 L
.58596 .22519 L
.58616 .22615 L
.58656 .22873 L
.58697 .23239 L
.58772 .24115 L
.58939 .2691 L
.59245 .33048 L
.59326 .3446 L
.59402 .35588 L
.59445 .3611 L
.59491 .36586 L
.59532 .3693 L
.59552 .37067 L
.59571 .37175 L
.59588 .37261 L
.59607 .37337 L
.59618 .37371 L
.59627 .37398 L
.59637 .37418 L
.59647 .37436 L
.59652 .37444 L
.59658 .37449 L
.59668 .37456 L
.59677 .37458 L
.59687 .37455 L
Mistroke
.59692 .37452 L
.59698 .37447 L
.59708 .37434 L
.59719 .37412 L
.5973 .37386 L
.59752 .37317 L
.59772 .37234 L
.59817 .36977 L
.59857 .36677 L
.59899 .36288 L
.60056 .34335 L
.60203 .32063 L
.60351 .29737 L
.60514 .27619 L
.60556 .27187 L
.60602 .26794 L
.60641 .26515 L
.60683 .26279 L
.60706 .26182 L
.60727 .2611 L
.60747 .26058 L
.60757 .26037 L
.60768 .26019 L
.60778 .26007 L
.60787 .26 L
.60797 .25995 L
.60807 .25995 L
.60817 .25998 L
.60825 .26004 L
.60834 .26013 L
.60844 .26027 L
.60863 .26065 L
.60884 .26119 L
.6092 .26252 L
.60958 .26445 L
.61001 .26713 L
.61147 .28016 L
.61318 .29981 L
.61473 .31802 L
.6155 .3261 L
.61634 .33355 L
.61672 .33641 L
.61713 .33901 L
.6175 .341 L
.61786 .34251 L
.61805 .34316 L
.61825 .34374 L
.61844 .34417 L
.61862 .34446 L
.61872 .3446 L
Mistroke
.61882 .3447 L
.61891 .34476 L
.61901 .3448 L
.61906 .34481 L
.61912 .34481 L
.61917 .34481 L
.61923 .34479 L
.61932 .34474 L
.61943 .34465 L
.61953 .34454 L
.61962 .34442 L
.61982 .34405 L
.62 .34363 L
.6202 .34308 L
.6209 .34028 L
.62165 .33601 L
.62246 .33024 L
.62393 .31787 L
.62551 .30413 L
.62634 .29761 L
.62724 .29174 L
.62768 .28933 L
.6281 .28742 L
.62851 .28591 L
.62888 .28485 L
.62907 .28444 L
.62924 .28412 L
.62942 .28387 L
.62952 .28376 L
.62962 .28367 L
.62972 .2836 L
.62978 .28357 L
.62983 .28355 L
.62993 .28353 L
.63004 .28354 L
.63014 .28356 L
.63024 .28361 L
.63032 .28367 L
.63042 .28375 L
.63061 .28397 L
.63081 .28429 L
.63118 .28508 L
.63162 .28635 L
.63202 .28781 L
.63372 .29638 L
.63538 .3068 L
.63692 .31595 L
.63769 .31979 L
.63842 .32271 L
.63881 .32399 L
Mistroke
.63917 .32496 L
.63957 .32579 L
.63979 .32614 L
.64 .3264 L
.6401 .32649 L
.64021 .32658 L
.64031 .32665 L
.64041 .32669 L
.64049 .32672 L
.64059 .32674 L
.64068 .32675 L
.64077 .32674 L
.64082 .32673 L
.64088 .32671 L
.64098 .32667 L
.64108 .32661 L
.64117 .32655 L
.64138 .32636 L
.64159 .32609 L
.64196 .32549 L
.6423 .32477 L
.64307 .32262 L
.64469 .31639 L
.64618 .30982 L
.64697 .30643 L
.64782 .30318 L
.64856 .30082 L
.64936 .29885 L
.64978 .29806 L
.64997 .29779 L
.65018 .29753 L
.65036 .29734 L
.65056 .29718 L
.65067 .2971 L
.65076 .29705 L
.65086 .29701 L
.65096 .29698 L
.65105 .29696 L
.65113 .29695 L
.65123 .29695 L
.65132 .29696 L
.6514 .29698 L
.65148 .297 L
.65157 .29703 L
.65165 .29707 L
.65184 .29718 L
.65202 .29732 L
.65241 .29775 L
.65282 .29834 L
.65326 .29913 L
Mistroke
.65405 .30094 L
.65554 .30516 L
.6571 .30986 L
.65793 .31213 L
.65882 .31419 L
.65923 .31499 L
.65967 .31569 L
.66007 .31621 L
.66045 .31659 L
.66063 .31673 L
.6608 .31684 L
.661 .31694 L
.66108 .31698 L
.66118 .31701 L
.66127 .31703 L
.66138 .31705 L
.66147 .31706 L
.66156 .31706 L
.66166 .31705 L
.66176 .31704 L
.66181 .31703 L
.66187 .31702 L
.66197 .31699 L
.66216 .31692 L
.66236 .31681 L
.66273 .31654 L
.66316 .31612 L
.66356 .31563 L
.66525 .31278 L
.66689 .30944 L
.66842 .3066 L
.66918 .30548 L
.6699 .30466 L
.6703 .30431 L
.67051 .30417 L
.67073 .30403 L
.67091 .30394 L
.67112 .30387 L
.67121 .30384 L
.6713 .30381 L
.67139 .3038 L
.67148 .30378 L
.67153 .30378 L
.67159 .30377 L
.67168 .30377 L
.67174 .30376 L
.6718 .30377 L
.6719 .30377 L
.672 .30378 L
.67209 .30379 L
Mistroke
.67219 .30381 L
.67229 .30384 L
.67253 .30392 L
.67275 .30402 L
.67318 .30427 L
.67395 .3049 L
.67479 .30581 L
.67635 .30783 L
.67806 .31005 L
.67885 .31089 L
.67926 .31127 L
.67969 .31162 L
.68007 .31187 L
.68049 .31209 L
.68067 .31217 L
.68087 .31224 L
.68103 .31228 L
.68122 .31233 L
.68133 .31235 L
.68143 .31236 L
.68153 .31237 L
.68159 .31238 L
.68165 .31238 L
.68174 .31238 L
.68185 .31238 L
.68195 .31238 L
.68204 .31237 L
.6821 .31237 L
.68216 .31236 L
.68227 .31235 L
.68247 .31231 L
.68271 .31224 L
.68293 .31217 L
.68372 .3118 L
.68455 .31126 L
.6876 .3087 L
.68841 .3081 L
.68917 .30761 L
.6896 .3074 L
.69005 .3072 L
.69047 .30707 L
.69067 .30702 L
.69085 .30698 L
.69105 .30695 L
.69123 .30692 L
.69133 .30691 L
.69142 .30691 L
.69152 .3069 L
.69158 .3069 L
.69163 .3069 L
Mistroke
.69172 .3069 L
.69181 .3069 L
.6919 .3069 L
.692 .30691 L
.69209 .30692 L
.69217 .30692 L
.69236 .30695 L
.69257 .30698 L
.69277 .30702 L
.69316 .30712 L
.69401 .30743 L
.69561 .30822 L
.69709 .30903 L
.69858 .30974 L
.69899 .30989 L
.69944 .31003 L
.69985 .31014 L
.70024 .31022 L
.70061 .31028 L
.70082 .3103 L
.70101 .31031 L
.70111 .31032 L
.70121 .31032 L
.70126 .31032 L
.70132 .31033 L
.70138 .31033 L
.70144 .31033 L
.70154 .31033 L
.70163 .31032 L
.70169 .31032 L
.70174 .31032 L
.70185 .31032 L
.70196 .31031 L
.70207 .3103 L
.70227 .31028 L
.70249 .31026 L
.70272 .31022 L
.70354 .31005 L
.7043 .30984 L
.70514 .30957 L
.70683 .309 L
.70764 .30875 L
.7084 .30855 L
.70882 .30845 L
.70928 .30837 L
.7097 .30831 L
.7099 .30829 L
.71008 .30827 L
.71026 .30825 L
.71045 .30824 L
Mistroke
.71065 .30823 L
.71076 .30823 L
.71086 .30822 L
.71095 .30822 L
.71104 .30822 L
.71112 .30822 L
.71121 .30822 L
.7113 .30822 L
.7114 .30822 L
.71149 .30823 L
.71158 .30823 L
.7118 .30824 L
.71199 .30825 L
.71244 .3083 L
.71285 .30834 L
.71324 .3084 L
.71631 .30901 L
.71786 .30929 L
.71829 .30934 L
.71875 .3094 L
.71918 .30944 L
.71937 .30945 L
.71958 .30946 L
.71978 .30947 L
.71996 .30948 L
.72004 .30949 L
.72014 .30949 L
.72023 .30949 L
.72031 .30949 L
.72041 .30949 L
.72051 .30949 L
.72062 .30949 L
.72067 .30949 L
.72073 .30949 L
.72082 .30949 L
.72092 .30949 L
.72102 .30949 L
.72111 .30949 L
.72132 .30948 L
.72152 .30947 L
.72189 .30945 L
.72229 .30942 L
.72273 .30938 L
.7243 .30921 L
.72602 .30899 L
.72681 .3089 L
.72766 .30883 L
.72807 .3088 L
.72846 .30878 L
.72881 .30876 L
Mistroke
.72919 .30875 L
.72938 .30874 L
.72947 .30874 L
.72958 .30874 L
.72967 .30874 L
.72977 .30874 L
.72986 .30874 L
.72994 .30874 L
.73 .30874 L
.73005 .30874 L
.73015 .30874 L
.73025 .30874 L
.73035 .30874 L
.73045 .30874 L
.73055 .30874 L
.73078 .30875 L
.731 .30875 L
.7312 .30876 L
.73165 .30878 L
.73246 .30882 L
.73412 .30894 L
.73565 .30905 L
.73642 .3091 L
.73714 .30913 L
.73754 .30915 L
.73797 .30916 L
.73816 .30917 L
.73836 .30917 L
.73854 .30917 L
.73872 .30918 L
.73883 .30918 L
.73893 .30918 L
.73902 .30918 L
.73912 .30918 L
.73921 .30918 L
.7393 .30918 L
.73939 .30918 L
.73949 .30918 L
.73959 .30918 L
.7397 .30918 L
.73991 .30918 L
.74012 .30917 L
.7403 .30917 L
.74102 .30915 L
.74178 .30913 L
.74338 .30906 L
.74422 .30902 L
.74511 .30899 L
.74591 .30896 L
.74633 .30895 L
Mistroke
.74679 .30894 L
.7472 .30893 L
.74758 .30893 L
.74777 .30893 L
.74786 .30893 L
.74796 .30892 L
.74805 .30892 L
.74815 .30892 L
.74824 .30892 L
.74833 .30892 L
.74842 .30892 L
.74852 .30892 L
.74862 .30892 L
.7487 .30892 L
.7488 .30892 L
.74891 .30893 L
.74911 .30893 L
.74932 .30893 L
.74955 .30893 L
.74995 .30894 L
.75065 .30895 L
.75143 .30897 L
.75312 .30901 L
.75467 .30904 L
.75543 .30906 L
.75586 .30906 L
.75626 .30906 L
.75646 .30907 L
.75665 .30907 L
.75682 .30907 L
.757 .30907 L
.75709 .30907 L
.7572 .30907 L
.75725 .30907 L
.7573 .30907 L
.75741 .30907 L
.75751 .30907 L
.7576 .30907 L
.75769 .30907 L
.75778 .30907 L
.75788 .30907 L
.75797 .30907 L
.75817 .30907 L
.75854 .30907 L
.75894 .30906 L
.75937 .30906 L
.76106 .30904 L
.76266 .30901 L
.76336 .30901 L
.76412 .309 L
Mistroke
.76454 .30899 L
.76493 .30899 L
.7653 .30899 L
.76549 .30899 L
.76569 .30899 L
.7658 .30899 L
.76591 .30899 L
.76601 .30899 L
.76611 .30899 L
.76617 .30899 L
.76622 .30899 L
.76629 .30899 L
.76635 .30899 L
.76645 .30899 L
.76651 .30899 L
.76656 .30899 L
.76666 .30899 L
.76675 .30899 L
.76685 .30899 L
.76696 .30899 L
.76718 .30899 L
.76737 .30899 L
.76776 .30899 L
.76817 .30899 L
.76891 .309 L
.77058 .30901 L
.77139 .30902 L
.77216 .30902 L
.77292 .30903 L
.77362 .30903 L
.77398 .30903 L
.77436 .30903 L
.77458 .30903 L
.77469 .30903 L
.77479 .30903 L
.77488 .30903 L
.77497 .30903 L
.77507 .30903 L
.77517 .30903 L
.77523 .30903 L
.77529 .30903 L
.77534 .30903 L
.77539 .30903 L
.77549 .30903 L
.77559 .30903 L
.7757 .30903 L
.7758 .30903 L
.77604 .30903 L
.77643 .30903 L
.77685 .30903 L
Mistroke
.77762 .30903 L
.77846 .30902 L
.78015 .30902 L
.78096 .30901 L
.78172 .30901 L
.78215 .30901 L
.7826 .30901 L
.78281 .30901 L
.78302 .30901 L
.78321 .30901 L
.78341 .30901 L
.78351 .30901 L
.78361 .30901 L
.7837 .30901 L
.7838 .30901 L
.7839 .30901 L
.78399 .30901 L
.78407 .30901 L
.78416 .30901 L
.78426 .30901 L
.78437 .30901 L
.78448 .30901 L
.78459 .30901 L
.78498 .30901 L
.78535 .30901 L
.78569 .30901 L
.78645 .30901 L
.78811 .30902 L
.78884 .30902 L
.78965 .30902 L
.79042 .30902 L
.79077 .30902 L
.79114 .30902 L
.79133 .30902 L
.79154 .30902 L
.79173 .30902 L
.79191 .30902 L
.79211 .30902 L
.79223 .30902 L
.79228 .30902 L
.79233 .30902 L
.79243 .30902 L
.79252 .30902 L
.79262 .30902 L
.79268 .30902 L
.79273 .30902 L
.79283 .30902 L
.79288 .30902 L
.79294 .30902 L
.79313 .30902 L
Mistroke
.79324 .30902 L
.79335 .30902 L
.79357 .30902 L
.79398 .30902 L
.79436 .30902 L
.79585 .30902 L
.79749 .30902 L
.7983 .30902 L
.79903 .30902 L
.79939 .30902 L
.79978 .30901 L
.79997 .30901 L
.80016 .30901 L
.80034 .30901 L
.8005 .30901 L
.80069 .30901 L
.80079 .30901 L
.80089 .30901 L
.80098 .30901 L
.80106 .30901 L
.80116 .30901 L
.80125 .30901 L
.80131 .30901 L
.80136 .30901 L
.80142 .30901 L
.80148 .30901 L
.80158 .30901 L
.80169 .30901 L
.80189 .30901 L
.80208 .30901 L
.80248 .30901 L
.80292 .30902 L
.80372 .30902 L
.80521 .30902 L
.80676 .30902 L
.80719 .30902 L
.80765 .30902 L
.80805 .30902 L
.80826 .30902 L
.80848 .30902 L
.8087 .30902 L
.8089 .30902 L
.80899 .30902 L
.80909 .30902 L
.80919 .30902 L
.80928 .30902 L
.80938 .30902 L
.80944 .30902 L
.80949 .30902 L
.80956 .30902 L
Mistroke
.80961 .30902 L
.80966 .30902 L
.80972 .30902 L
.80982 .30902 L
.80988 .30902 L
.80993 .30902 L
.81013 .30902 L
.81022 .30902 L
.81032 .30902 L
.8105 .30902 L
.8109 .30902 L
.81163 .30902 L
.81469 .30902 L
.81549 .30902 L
.81626 .30902 L
.81668 .30902 L
.8169 .30902 L
.81714 .30902 L
.81733 .30902 L
.81744 .30902 L
.81755 .30902 L
.81766 .30902 L
.81775 .30902 L
.81785 .30902 L
.81794 .30902 L
.81804 .30902 L
.81809 .30902 L
.81814 .30902 L
.81824 .30902 L
.81834 .30902 L
.81843 .30902 L
.81851 .30902 L
.8187 .30902 L
.8191 .30902 L
.81952 .30902 L
.8203 .30902 L
.821 .30902 L
.82266 .30902 L
.82339 .30902 L
.82378 .30902 L
.8242 .30902 L
.8246 .30902 L
.82497 .30902 L
.82532 .30902 L
.82549 .30902 L
.82569 .30902 L
.82579 .30902 L
.8259 .30902 L
.82599 .30902 L
.82608 .30902 L
Mistroke
.82614 .30902 L
.82619 .30902 L
.82625 .30902 L
.82631 .30902 L
.8264 .30902 L
.82651 .30902 L
.82661 .30902 L
.82671 .30902 L
.82691 .30902 L
.8271 .30902 L
.82727 .30902 L
.82768 .30902 L
.82812 .30902 L
.82892 .30902 L
.83042 .30902 L
.83124 .30902 L
.83202 .30902 L
.83282 .30902 L
.83325 .30902 L
.83349 .30902 L
.83371 .30902 L
.83389 .30902 L
.834 .30902 L
.8341 .30902 L
.8342 .30902 L
.83425 .30902 L
.83431 .30902 L
.8344 .30902 L
.83451 .30902 L
.8346 .30902 L
.83469 .30902 L
.83479 .30902 L
.83489 .30902 L
.83506 .30902 L
.83524 .30902 L
.83567 .30902 L
.83611 .30902 L
.83691 .30902 L
.8385 .30902 L
.83995 .30902 L
.84034 .30902 L
.84076 .30902 L
.84112 .30902 L
.84152 .30902 L
.84173 .30902 L
.84194 .30902 L
.84204 .30902 L
.84216 .30902 L
.84221 .30902 L
.84228 .30902 L
Mistroke
.84233 .30902 L
.84239 .30902 L
.84249 .30902 L
.84259 .30902 L
.84269 .30902 L
.84275 .30902 L
.84281 .30902 L
.8429 .30902 L
.84299 .30902 L
.8432 .30902 L
.84339 .30902 L
.84361 .30902 L
.84401 .30902 L
.84475 .30902 L
.84643 .30902 L
.84731 .30902 L
.84814 .30902 L
.84889 .30902 L
.84931 .30902 L
.84949 .30902 L
.84969 .30902 L
.84989 .30902 L
.85007 .30902 L
.85015 .30902 L
.85025 .30902 L
.85034 .30902 L
.85042 .30902 L
.85051 .30902 L
.8506 .30902 L
.8507 .30902 L
.85081 .30902 L
.85091 .30902 L
.85096 .30902 L
.85102 .30902 L
.85122 .30902 L
.85143 .30902 L
.85162 .30902 L
.85205 .30902 L
.85283 .30902 L
.8545 .30902 L
.85524 .30902 L
.85604 .30902 L
.85642 .30902 L
.85682 .30902 L
.85716 .30902 L
.85754 .30902 L
.85776 .30902 L
.85797 .30902 L
.85816 .30902 L
.85827 .30902 L
Mistroke
.85837 .30902 L
.85847 .30902 L
.85856 .30902 L
.85866 .30902 L
.85876 .30902 L
.85885 .30902 L
.85894 .30902 L
.85903 .30902 L
.85913 .30902 L
.85934 .30902 L
.85956 .30902 L
.85995 .30902 L
.86084 .30902 L
.86245 .30902 L
.86323 .30902 L
.86404 .30902 L
.86473 .30902 L
.86512 .30902 L
.86549 .30902 L
.86569 .30902 L
.86588 .30902 L
.86605 .30902 L
.86615 .30902 L
.86624 .30902 L
.86634 .30902 L
.86643 .30902 L
.86653 .30902 L
.86663 .30902 L
.86668 .30902 L
.86674 .30902 L
.86685 .30902 L
.86695 .30902 L
.86704 .30902 L
.86724 .30902 L
.86743 .30902 L
.86786 .30902 L
.86872 .30902 L
.8702 .30902 L
.87104 .30902 L
.87182 .30902 L
.8726 .30902 L
.87303 .30902 L
.87343 .30902 L
.87365 .30902 L
.87385 .30902 L
.87395 .30902 L
.87407 .30902 L
.87412 .30902 L
.87419 .30902 L
.87425 .30902 L
Mistroke
.8743 .30902 L
.8744 .30902 L
.8745 .30902 L
.87456 .30902 L
.87461 .30902 L
.87472 .30902 L
.87482 .30902 L
.87493 .30902 L
.87512 .30902 L
.87552 .30902 L
.87589 .30902 L
.87672 .30902 L
.87841 .30902 L
.87925 .30902 L
.88005 .30902 L
.8804 .30902 L
.88076 .30902 L
.88096 .30902 L
.88117 .30902 L
.88136 .30902 L
.88154 .30902 L
.88173 .30902 L
.88183 .30902 L
.88188 .30902 L
.88193 .30902 L
.88199 .30902 L
.88205 .30902 L
.88215 .30902 L
.88225 .30902 L
.88235 .30902 L
.88244 .30902 L
.88253 .30902 L
.8827 .30902 L
.88291 .30902 L
.88309 .30902 L
.88351 .30902 L
.88395 .30902 L
.88477 .30902 L
.88648 .30902 L
.88729 .30902 L
.88804 .30902 L
.88842 .30902 L
.88882 .30902 L
.88902 .30902 L
.88922 .30902 L
.88933 .30902 L
.88943 .30902 L
.88949 .30902 L
.88955 .30902 L
.8896 .30902 L
Mistroke
.88966 .30902 L
.88975 .30902 L
.88984 .30902 L
.88995 .30902 L
.89004 .30902 L
.89014 .30902 L
.89025 .30902 L
.89045 .30902 L
.89064 .30902 L
.89083 .30902 L
.89118 .30902 L
.89201 .30902 L
.8929 .30902 L
.89367 .30902 L
.89452 .30902 L
.89492 .30902 L
.89535 .30902 L
.89572 .30902 L
.89612 .30902 L
.89636 .30902 L
.89657 .30902 L
.89678 .30902 L
.89689 .30902 L
.897 .30902 L
.89711 .30902 L
.8972 .30902 L
.89729 .30902 L
.89739 .30902 L
.89749 .30902 L
.89759 .30902 L
.89765 .30902 L
.8977 .30902 L
.89781 .30902 L
.89791 .30902 L
.898 .30902 L
.8982 .30902 L
.89861 .30902 L
.89897 .30902 L
.89935 .30902 L
.90102 .30902 L
.90183 .30902 L
.90272 .30902 L
.90312 .30902 L
.90356 .30902 L
.90376 .30902 L
.90396 .30902 L
.90414 .30902 L
.90433 .30902 L
.90443 .30902 L
.90453 .30902 L
Mistroke
.90462 .30902 L
.90471 .30902 L
.90481 .30902 L
.90486 .30902 L
.90492 .30902 L
.90501 .30902 L
.90512 .30902 L
.90517 .30902 L
.90522 .30902 L
.90532 .30902 L
.90543 .30902 L
.90554 .30902 L
.90575 .30902 L
.90595 .30902 L
.90632 .30902 L
.90666 .30902 L
.90743 .30902 L
.9091 .30902 L
.90984 .30902 L
.91022 .30902 L
.91064 .30902 L
.91105 .30902 L
.91142 .30902 L
.9116 .30902 L
.91179 .30902 L
.91197 .30902 L
.91214 .30902 L
.91223 .30902 L
.91233 .30902 L
.91242 .30902 L
.91251 .30902 L
.9126 .30902 L
.91271 .30902 L
.91276 .30902 L
.91281 .30902 L
.91291 .30902 L
.91302 .30902 L
.91313 .30902 L
.91334 .30902 L
.91373 .30902 L
.91449 .30902 L
.91533 .30902 L
.91621 .30902 L
.91701 .30902 L
.91776 .30902 L
.91815 .30902 L
.91857 .30902 L
.91881 .30902 L
.91902 .30902 L
.91923 .30902 L
Mistroke
.91943 .30902 L
.91953 .30902 L
.91964 .30902 L
.91973 .30902 L
.91982 .30902 L
.91993 .30902 L
.91999 .30902 L
.92004 .30902 L
.92015 .30902 L
.92025 .30902 L
.92034 .30902 L
.92044 .30902 L
.92062 .30902 L
.92083 .30902 L
.92102 .30902 L
.92185 .30902 L
.92333 .30902 L
.92412 .30902 L
.92497 .30902 L
.92539 .30902 L
.92578 .30902 L
.92613 .30902 L
.92632 .30902 L
.92651 .30902 L
.92668 .30902 L
.92687 .30902 L
.92698 .30902 L
.92709 .30902 L
.92718 .30902 L
.92728 .30902 L
.92734 .30902 L
.92739 .30902 L
.92749 .30902 L
.92759 .30902 L
.92765 .30902 L
.9277 .30902 L
.9279 .30902 L
.9281 .30902 L
.92846 .30902 L
.9288 .30902 L
.92957 .30902 L
.93107 .30902 L
.93186 .30902 L
.93269 .30902 L
.93312 .30902 L
.93334 .30902 L
.93358 .30902 L
.9338 .30902 L
.93401 .30902 L
.9341 .30902 L
Mistroke
.93421 .30902 L
.9343 .30902 L
.9344 .30902 L
.93446 .30902 L
.93451 .30902 L
.93462 .30902 L
.93471 .30902 L
.93481 .30902 L
.93486 .30902 L
.93491 .30902 L
.93501 .30902 L
.93513 .30902 L
.93524 .30902 L
.93543 .30902 L
.93564 .30902 L
.93602 .30902 L
.93677 .30902 L
.9376 .30902 L
.93848 .30902 L
.93929 .30902 L
.94005 .30902 L
.94043 .30902 L
.94084 .30902 L
.94106 .30902 L
.94126 .30902 L
.94137 .30902 L
.94149 .30902 L
.9416 .30902 L
.94171 .30902 L
.9418 .30902 L
.9419 .30902 L
.94199 .30902 L
.94205 .30902 L
.9421 .30902 L
.9422 .30902 L
.94226 .30902 L
.94231 .30902 L
.94252 .30902 L
.94262 .30902 L
.94273 .30902 L
.94292 .30902 L
.94336 .30902 L
.94416 .30902 L
.94566 .30902 L
.94642 .30902 L
.94684 .30902 L
.94724 .30902 L
.94761 .30902 L
.94801 .30902 L
.94818 .30902 L
Mistroke
.94837 .30902 L
.94853 .30902 L
.94871 .30902 L
.94881 .30902 L
.9489 .30902 L
.949 .30902 L
.94905 .30902 L
.9491 .30902 L
.94921 .30902 L
.94926 .30902 L
.94932 .30902 L
.94942 .30902 L
.94952 .30902 L
.94961 .30902 L
.9497 .30902 L
.94987 .30902 L
.95026 .30902 L
.95071 .30902 L
.95114 .30902 L
.95194 .30902 L
.95277 .30902 L
.95355 .30902 L
.95425 .30902 L
.95461 .30902 L
.95501 .30902 L
.95541 .30902 L
.95563 .30902 L
.95574 .30902 L
.95584 .30902 L
.95593 .30902 L
.95603 .30902 L
.95612 .30902 L
.9562 .30902 L
.95629 .30902 L
.95639 .30902 L
.9565 .30902 L
.95659 .30902 L
.9567 .30902 L
.95681 .30902 L
.95702 .30902 L
.95722 .30902 L
.95741 .30902 L
.95828 .30902 L
.95979 .30902 L
.96058 .30902 L
.96142 .30902 L
.96185 .30902 L
.96207 .30902 L
.96231 .30902 L
.96254 .30902 L
Mistroke
.96274 .30902 L
.96284 .30902 L
.96294 .30902 L
.96304 .30902 L
.96314 .30902 L
.96324 .30902 L
.96333 .30902 L
.96339 .30902 L
.96344 .30902 L
.96355 .30902 L
.9636 .30902 L
.96365 .30902 L
.96375 .30902 L
.96387 .30902 L
.96398 .30902 L
.96417 .30902 L
.96438 .30902 L
.96476 .30902 L
.96552 .30902 L
.96635 .30902 L
.96723 .30902 L
.96804 .30902 L
.96842 .30902 L
.96884 .30902 L
.96924 .30902 L
.9696 .30902 L
.96982 .30902 L
.96993 .30902 L
.97003 .30902 L
.97012 .30902 L
.97021 .30902 L
.97031 .30902 L
.97041 .30902 L
.97047 .30902 L
.97053 .30902 L
.97063 .30902 L
.97069 .30902 L
.97074 .30902 L
.97086 .30902 L
.97096 .30902 L
.97106 .30902 L
.97128 .30902 L
.97167 .30902 L
.97209 .30902 L
.97283 .30902 L
.97451 .30902 L
.97493 .30902 L
.97538 .30902 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{421.375, 260.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008>0001AB000`400?l00000o`00003ooooooooo
oooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo
003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooo
oooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool0
0?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooooooo
ool@ooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooo
ooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo0ol0003o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0
003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo
00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`
ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLoooo
o`00<?ooool3o`000?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?oo
ool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0
033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomco
oooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooo
oooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool3o`000?oooooo
g?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0013ooooo0_o^k^h3ooooo`;ok^k^6Oooool00ol0003oooooooooo`3o
ooooomcooooo000;ooooo`;o000000[o410@ooooooooooook^k^oeEEEOo^k^koooooonk^k_mEEEGo
k^k^0oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h:ooooo`03o`000?oo
oooooooo0?oooooog?ooool000cooooo00?o0000ooooooooool00_ooool01Oo^k^koEEEEomgMgOmE
EEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00[ooooo
00?o0000ooooooooool0oooooooLooooo`0000?oooooo`000?l000001?l00002ooooo`Go00001?oo
ool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooo
oa0@400:ooooo`03o`000?oooooooooo0?oooooog?ooool000Wooooo00CoA4A4omgMgOoooooo0000
1?ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000000[ooooo00?o0000ooooooooool0oooooooLooooo`002Oooool01?oMgMgo
EEEEooooool00003ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000:ooooo`Co0000oooooooKooooo`002_oo
ool00omgMgOoc<c<o`000003ooooo`;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@00[ooooo00?o0000ooooooooool0oooooooLooooo`002_oo
ool00oo^k^koA4A4o`00000?ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`;o00001Oooool00ol0003oooooooooo`3oooooomcooooo000;ooooo`03ogMgMol0
003ooooo00cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`2[ooooo`03o`000?oooooooooo0?oo
oooo;_ooool002Sooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`2Oooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool0ooooool^ooooo`00:?ooool3o`0000Gooooo
00?o0000ooooooooool0Woooool2o`0000[ooooo00?o0000ooooooooool0ooooool^ooooo`00:Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo09oooooo0_l0000:ooooo`03o`000?oo
oooooooo0?oooooo;_ooool002[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2O
ooooo`;o00002Oooool2o`000?oooooo<?ooool0033ooooo00?o0000ooooooooool0Woooool2o`00
00Wooooo00?o0000ooooool00000ooooool_ooooo`00<?ooool00ol0003oooooooooo`2Oooooo`;o
00002Oooool00ol0003oooooo`00003ooooooboooooo000`ooooo`03o`000?oooooooooo09oooooo
0_l00009ooooo`03o`000?oooooo00000?oooooo;oooool0033ooooo00?o0000ooooooooool0Wooo
ool2o`0000Wooooo00?o0000ooooool00000ooooool_ooooo`00<?ooool3o`0009kooooo00?o0000
ooooool000002Oooool00ol0003oooooo`00003ooooooboooooo000`ooooo`03o`000?oooooooooo
09kooooo00?o0000ooooool000002Oooool00ol0003oooooo`00003ooooooboooooo000`ooooo`03
o`000?oooooooooo09kooooo00?o0000ooooool000002Oooool00ol0003oooooo`00003ooooooboo
oooo000`ooooo`03o`000?oooooooooo09kooooo00?o0000ooooool000002Oooool00ol0003ooooo
o`00003ooooooboooooo000`ooooo`03o`000?oooooooooo09kooooo00?o0000ooooool000002Ooo
ool00ol0003oooooo`000009ooooo`03o`000?oooooooooo0?oooooo8oooool0033ooooo00?o0000
ooooooooool0W_ooool00ol0003oooooo`000009ooooo`03o`000?oooooo000000Wooooo0_l0003o
ooooobCooooo000`ooooo`03o`000?oooooooooo09kooooo00?o0000ooooool000002Oooool00ol0
003oooooo`000009ooooo`;o0000oooooolTooooo`00<?ooool00ol0003oooooooooo`2Nooooo`03
o`000?oooooo000000Wooooo00?o0000ooooool000002Oooool2o`000?oooooo9?ooool0033ooooo
00?o0000ooooooooool0W_ooool00ol0003oooooo`000009ooooo`03o`000?oooooo000000Wooooo
0_l0003oooooobCooooo000`ooooo`03o`000?oooooooooo09kooooo00?o0000ooooool000002Ooo
ool00ol0003oooooo`000009ooooo`;o0000oooooolTooooo`00<?ooool00ol0003oooooooooo`2C
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooool000002Oooool00ol0003oooooo`000009
ooooo`;o0000oooooolTooooo`00<?ooool00ol0003oooooooooo`2Booooo`;o00002_ooool00ol0
003oooooo`000009ooooo`03o`000?oooooo000000Sooooo00?o0000ooooool00000oooooolToooo
o`00<?ooool3o`0009;ooooo0_l0000:ooooo`03o`000?oooooo000000Wooooo00?o0000ooooool0
00002?ooool00ol0003oooooo`00003oooooobCooooo000`ooooo`03o`000?oooooooooo09;ooooo
0_l0000:ooooo`03o`000?oooooo000000Wooooo00?o0000ooooool000002?ooool00ol0003ooooo
o`00003oooooobCooooo000`ooooo`03o`000?oooooooooo09;ooooo0_l0000:ooooo`03o`000?oo
oooo000000Wooooo00?o0000ooooool000002?ooool00ol0003oooooo`00003oooooobCooooo000`
ooooo`03o`000?oooooooooo09;ooooo0_l0000:ooooo`03o`000?oooooo000000Wooooo00?o0000
ooooool000002?ooool00ol0003oooooo`00003oooooobCooooo000`ooooo`03o`000?oooooooooo
09;ooooo0_l0000:ooooo`03o`000?oooooo000000Wooooo00?o0000ooooool000002?ooool00ol0
003oooooo`00003oooooobCooooo000`ooooo`03o`000?oooooooooo09;ooooo00?o0000ooooool0
00002Oooool00ol0003oooooo`000009ooooo`03o`000?oooooo000000Sooooo00?o0000ooooool0
0000oooooolTooooo`00<?ooool00ol0003oooooooooo`2Booooo`03o`000?oooooo000000Wooooo
00?o0000ooooool000002Oooool00ol0003oooooo`000008ooooo`03o`000?oooooo00000?oooooo
9?ooool0033ooooo00?o0000ooooooooool0T_ooool00ol0003oooooo`000009ooooo`03o`000?oo
oooo000000Wooooo00?o0000ooooool000002?ooool00ol0003oooooo`00003oooooobCooooo000`
ooooo`03o`000?oooooooooo09;ooooo00?o0000ooooool000002Oooool00ol0003oooooo`000008
ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooolTooooo`00<?ooool0
0ol0003oooooooooo`2Booooo`03o`000?oooooo000000Wooooo00Co0000oooooooooooo00001ooo
ool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?oooooo9?ooool0033ooooo00?o
0000ooooooooool0T_ooool00ol0003oooooo`000009ooooo`04o`000?ooooooooooo`0000Oooooo
00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003oooooobCooooo000`ooooo`?o0000
TOooool01?l0003oooooooooool00009ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooo
oooooooo00002?ooool00ol0003oooooo`00003oooooobCooooo000`ooooo`03o`000?oooooooooo
097ooooo00Co0000oooooooooooo00002Oooool01?l0003oooooooooool00007ooooo`05o`000?oo
ooooooooooooool000001oooool00ol0003oooooo`00003oooooobCooooo000`ooooo`03o`000?oo
oooooooo097ooooo00Co0000oooooooooooo00002Oooool01?l0003oooooooooool00007ooooo`05
o`000?ooooooooooooooool000001oooool00ol0003oooooo`000009ooooo`03o`000?oooooooooo
0?oooooo6?ooool0033ooooo00?o0000ooooooooool0TOooool01?l0003oooooooooool00009oooo
o`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?oo
ooooooooo`0000Sooooo00?o0000ooooooooool0oooooolHooooo`00<?ooool00ol0003ooooooooo
o`2Aooooo`04o`000?ooooooooooo`0000Wooooo00Co0000oooooooooooo00001oooool01Ol0003o
oooooooooooooooo000000Oooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`3o
oooooaSooooo000`ooooo`03o`000?oooooooooo097ooooo00Co0000oooooooooooo00002Oooool0
1?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001oooool01?l0003ooooo
ooooool00007ooooo`;o0000oooooolJooooo`00<?ooool00ol0003oooooooooo`2Aooooo`04o`00
0?ooooooooooo`0000Wooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo
000000Oooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00003ooooooaWooooo000@
ooooo`;ok^k^0oooool2onk^kQWooooo00?o0000ooooooooool0TOooool01?l0003oooooooooool0
0009ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04
o`000?ooooooooooo`0000Oooooo00?o0000ooooool00000oooooolIooooo`002Oooool5o`0000;o
oooo00Ook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413oooooooooooo^
k^ko<S8bo`000?lb<S;ok^k^2_ooool00ol0003oooooooooo`2Aooooo`04o`000?ooooooooooo`00
00Wooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co
0000oooooooooooo00001oooool00ol0003oooooo`00003ooooooaWooooo0009ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@00oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00[ooooo00?o0000ooooooooool0TOooool01?l0
003oooooooooool00009ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooooooooooo
o`000007ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool00000oooooolIooooo`00
00?oooooo`000?l000001?l00003ooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?ogMgMo`000?oMgMd0
1oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41002_ooool00ol0003o
ooooooooo`2Aooooo`04o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000007
ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool00007ooooo`03o`00
0?oooooo00000?oooooo6Oooool000_ooooo00?oV9RHob4Q8Oo^k^h00oooool01Oo^k^koEEEEomgM
gOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000[o
oooo00?o0000ooooooooool0TOooool01?l0003oooooooooool00008ooooo`05o`000?oooooooooo
ooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000
1oooool00ol0003oooooo`00003ooooooaWooooo000<ooooo`0;ogMgMomVIVKoooooooooooo^k^ko
EEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000002_ooool4o`00093ooooo00Go0000ooooooooooooooooo`000007ooooo`05o`00
0?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooo
oooooooo00001oooool00ol0003oooooo`00003ooooooaWooooo000=ooooo`03o`000?oooooooooo
00;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@00[ooooo00?o0000ooooooooool0Q_ooool00ol0003oooooooooo`08ooooo`05o`000?oooooo
ooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooooooooooo
ooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool00000oooooolIoooo
o`002Oooool01Ol0003o^[ZjoooooonHV9So410@00kooooo00?o0000ooooooooool00_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00?ooooo0_l00005ooooo`03o`000?oooooooooo08Gooooo0_l0000:
ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo
00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000oooo
ool00000oooooolIooooo`002Oooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo00?oEEEEofIV
I_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo00Co0000oooooooooooo00001?oo
ool00ol0003oooooooooo`25ooooo`;o00002_ooool01Ol0003ooooooooooooooooo000000Oooooo
00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0
003ooooooooooooooooo000000Oooooo00?o0000ooooool00000oooooolIooooo`00:?ooool01?l0
003oooooooooool00004ooooo`03o`000?oooooooooo08Gooooo0_l0000:ooooo`05o`000?oooooo
ooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooooooooooo
ooooo`000006ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003ooooo
oaWooooo000Xooooo`?o00001Oooool00ol0003oooooooooo`25ooooo`;o00002_ooool01Ol0003o
oooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooo
ooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooool00000
oooooolIooooo`00:Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo08Cooooo00?o
0000ooooool000002_ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooooooooooo
ooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo
000000Oooooo00?o0000ooooool00000oooooolIooooo`00:_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo08Cooooo00Co0000oooooooooooo00002Oooool01Ol0003ooooooooooooo
oooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool0
00001_ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooool00000oooooolIoooo
o`00<?ooool00ol0003oooooooooo`24ooooo`04o`000?ooooooooooo`0000Wooooo00Go0000oooo
ooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooo
oooooooo000000Kooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?oo
oooo6Oooool0033ooooo00?o0000ooooooooool0Q?ooool01?l0003oooooooooool00009ooooo`05
o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000
ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001oooool00ol0003ooooo
o`00003ooooooaWooooo000`ooooo`03o`000?oooooooooo08Cooooo00Co0000oooooooooooo0000
2Oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007oooo
o`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Oooooo00?o
0000ooooool000002?ooool00ol0003oooooooooo`3oooooo`kooooo000`ooooo`03o`000?oooooo
oooo08Cooooo00Co0000oooooooooooo00002Oooool01Ol0003ooooooooooooooooo000000Oooooo
00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0
003ooooooooooooooooo000000Oooooo00?o0000ooooool000002?ooool2o`000?oooooo3oooool0
033ooooo0ol00024ooooo`04o`000?ooooooooooo`0000Wooooo00Go0000ooooooooooooooooo`00
0007ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Ko
oooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo0_l0003o
ooooo`oooooo000`ooooo`03o`000?oooooooooo08Cooooo00Co0000oooooooooooo00002Oooool0
1Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`04ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Oo
oooo00Co0000oooooooooooo00001oooool2o`000?oooooo3oooool0033ooooo00?o0000oooooooo
ool0Q?ooool01?l0003oooooooooool00009ooooo`05o`000?ooooooooooooooool000001oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00
0006ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool00007ooooo`;o
0000ooooool?ooooo`00<?ooool00ol0003oooooooooo`24ooooo`04o`000?ooooooooooo`0000Wo
oooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`00
0007ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooool00000ooooool?ooooo`00<?oo
ool00ol0003oooooooooo`24ooooo`04o`000?ooooooooooo`0000Wooooo00Go0000oooooooooooo
ooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003o
oooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?oooooo
ooooo`0000Kooooo00?o0000ooooool00000ooooool?ooooo`00<?ooool00ol0003oooooooooo`24
ooooo`04o`000?ooooooooooo`0000Wooooo00Go0000ooooooooooooooooo`000007ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Ko
oooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001_ooool0
0ol0003oooooo`00003oooooo`oooooo000`ooooo`03o`000?oooooooooo08Cooooo00Co0000oooo
oooooooo00002Oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooo
oooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo0000
0?oooooo3oooool0033ooooo00?o0000ooooooooool0Q?ooool01Ol0003ooooooooooooooooo0000
00Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000
ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooo
o`00003oooooo`oooooo000`ooooo`03o`000?oooooooooo08Cooooo00Go0000oooooooooooooooo
o`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`05
o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000
ooooool00000ooooool?ooooo`00<?ooool00ol0003oooooooooo`24ooooo`05o`000?oooooooooo
ooooool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_oo
ool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooo00000?oooooo3oooool0033ooooo00?o0000ooooooooool0Q?ooool01Ol0003ooooo
oooooooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000
00Kooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001_oo
ool00ol0003oooooo`00003oooooo`oooooo000`ooooo`03o`000?oooooooooo08?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000
ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooool00000ooooool?ooooo`00<?ooool3o`0008?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo
00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooool00000ooooool?ooooo`00<?ooool00ol0
003oooooooooo`23ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooo
oooo000000Kooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`000?oo
oooo3_ooool0033ooooo00?o0000ooooooooool0Moooool2o`0000[ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooo
ooooo`000006ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo
000000Kooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`3oooooo`Cooooo000`
ooooo`03o`000?oooooooooo07Kooooo00?o0000ooooool000002_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooo
oooo000000Kooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool0
00001_ooool01?l0003oooooooooool00007ooooo`;o0000ooooool5ooooo`00<?ooool00ol0003o
ooooooooo`1fooooo`03o`000?oooooo000000[ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006oooo
o`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Kooooo00Co
0000oooooooooooo00001_ooool00ol0003oooooo`00003oooooo`Gooooo000`ooooo`03o`000?oo
oooooooo04kooooo0_o^k^h3ooooo`;ok^k^8Oooool00ol0003oooooo`00000:ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oo
ooooooooonk^k_l000000oooool2onk^kP03ooooool0003ooooo00;ooooo00?o0000ooooooooool0
1?ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo00001_ooool00ol0
003oooooo`00000looooo`;ok^k^0oooool2onk^kTkooooo0_o^k^h3ooooo`;ok^k^K?ooool0033o
oooo00?o0000ooooooooool0B?ooool03Om4A4Co0000o`000?lb<S;ogMgMooooooo^k^koEEEEonk^
k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^hBooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooooooo`Co000000co410@ooooooo^k^ko0000onk^k_oooooo
k^k^oeEEEOo^k^koooooo`000?ooool4o`00000:oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^koooooo`0000Kooooo00Co0000oooooooooooo00001_ooool00ol0003oooooo`00000Vooooo`Co
000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo00goA4A4o`000?l0003o<S8bomgMgOoooooo
k^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8b
o`000?lb<S;ok^k^>?ooool5o`0000;ooooo00Ook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?o
oooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^GOooool0033ooooo00?o0000
ooooooooool0Boooool02OmgMgOo<S8booooooooooook^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Aooooo`05o`000?oooooooooo
ooooool000002Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool2o`0000?ooooo00Go0000oeEEEOoMgMgoEEEEonk^kP02ooooo`05o`000?oo
ooooooooooooool000001?ooool01omgMgOoV9RHo`000?nHV9SoMgMgooooool000001_ooool01?l0
003oooooooooool00006ooooo`03o`000?oooooo000002Sooooo00?o0000ooooooooool01?ooool2
ob4Q8@Sooooo00WoMgMgoc8b<_ooooooooooonk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0>?ooool01OnHV9So8B4Qonk^k_oooooo
A4A400?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`1Mooooo`00<?ooool00ol0003oooooooooo`1<ooooo`07o`000?oo
oooooooooooooooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooo
oooooooooa0@400Aooooo`05o`000?ooooooooooooooool000002Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool2o`0000?ooooo00Co0000
omgMgOl0003ogMgM0oooool01Ol0003ooooooooooooooooo000000Cooooo00Oo410@ooooool0003o
oooooa0@4?oooooo000000Kooooo00Co0000oooooooooooo00001_ooool00ol0003oooooo`00000X
ooooo`03o`000?oooooooooo00oooooo00Oo0000ooooooooooooooooomgMgOl0003ogMgM00Oooooo
00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@03Wooooo00?oV9RHob4Q8Oo^
k^h01Oooool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooo
oooooooooa0@401Mooooo`00<?ooool00ol0003oooooooooo`1;ooooo`09ogMgMolb<S;ooooooooo
ooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo0000017ooooo00Go0000ooooooooooooooooo`000009ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`;o00000oooool01Ol0003o
EEEEomgMgOmEEEGok^k^00;ooooo00Go0000ooooooooooooooooo`000004ooooo`07o`000?oooooo
0000ooooool0003oooooo`000006ooooo`04o`000?ooooooooooo`0000Kooooo00Co0000oooooooo
oooo00009oooool00ol0003oooooooooo`0>ooooo`09ogMgMolb<S;oooooooooooo^k^koEEEEomgM
gOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000003[o
oooo00?oV9RHob4Q8Oo^k^h00oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000005gooooo000`ooooo`03o`000?oooooooooo
04Sooooo00go0000ob4Q8Ol0003o<S8bolc<c?ooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^
00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000017ooooo00Go0000
ooooooooooooooooo`000009ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`;o00000_ooool02Oo^k^ko0000onk^k_ooooook^k^oeEEEOo^
k^koooooo`000003ooooo`03o`000?oooooooooo00;ooooo00Oo0000ooooool0003oooooo`000?oo
oooo000000Kooooo00Co0000oooooooooooo00001_ooool01?l0003oooooooooool0000Wooooo`03
o`000?oooooooooo00_ooooo00go0000ob4Q8Ol0003o<S8bolc<c?ooooook^k^oeEEEOo^k^kooooo
onk^k_mEEEGok^k^00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
03_ooooo00_oMgMgofIVI_ooooooooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03
o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001Mooooo`00<?ooool00ol0003o
ooooooooo`18ooooo`03o`000?oooooooooo00?ooooo0_o^k^h3ooooo`;ok^k^1Oooool00ol0003o
ooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41004Oooool01Ol0003ooooooooooooooooo
000000Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo0_l00002ooooo`03onk^k_l0003ooooo00;ooooo0_o^k^h00ooooooo0000ooooo`02
ooooo`03o`000?oooooooooo00;ooooo00Oo410@ooooool0003ooooooa0@4?oooooo000000Kooooo
00Co0000oooooooooooo00001_ooool01?l0003oooooooooool0000Wooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool00oooool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo
00;ooooo00Go410@oooooooooooooooooa0@400looooo`03o`000?oooooooooo00;ok^k^0oooool2
onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@05gooooo000`
ooooo`?o0000B?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`;o00000oooool00ol0003oooooooooo`04ooooo`05o`000?oo
ooooooooooooool000001?ooool01omgMgOoV9RHo`000?nHV9SoMgMgooooool000001_ooool2o`00
0003ooooool0003ooooo00Gooooo00Co0000oooooooooooo00001_ooool2o`0001oooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`08ooooo`;o0000;_ooool01Ol0003o^[ZjoooooonHV9So410@00kooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo0_l0001Cooooo`00
<?ooool00ol0003oooooooooo`18ooooo`Co00003?ooool00omEEEGoIVIVo`000004ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;o
oooo00Ko0000oooooooooooooooooeEEEOmVIVH2o`0000?ooooo00?o0000ooooooooool01?ooool0
1Ol0003ooooooeEEEOmVIVKo000000Cooooo00Ook^k^oc8b<_l0003o<S8bonk^k_oooooo000000Go
oooo0_l000000ooooooo0000o`000006ooooo`04o`000?ooooooooooo`0000Kooooo0_l0000Moooo
o`03oeEEEOmVIVKo000000gooooo1?l0000<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP07ooooo`04o`000?ooooooooooo`0002gooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c00<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP07ooooo`04
o`000?ooooooooooo`0005;ooooo000`ooooo`03o`000?oooooooooo06Kooooo1?l00003ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05
o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000
oooooooooooooooo1Ol000001?oooooo0000ooooooooool2o`0000Gooooo00Go0000oooooooooooo
ooooo`000006ooooo`03o`000?oooooo000004[ooooo1?l000001Ooooooo0000oooooooooooo0000
04cooooo1?l000001Ooooooo0000oooooooooooo000005;ooooo000`ooooo`03o`000?oooooooooo
06gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool01Ol0003ooooooooooooooooo000000Gooooo0ol000000ooooooo0000oooo
o`04ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooo`00001?ooooo`?o0000
D_ooool3o`0005?ooooo000`ooooo`03o`000?oooooooooo06Oooooo0_l00002ooooo`04o`000?oo
ooooooooo`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00Go0000ooooooooooooooooo`000005ooooo`;o00000_ooool00ol0003oooooooooo`03oooo
o`05o`000?ooooooooooooooool000001Oooool01?l0003oooooooooool0001@ooooo`03o`000?oo
oooooooo05;ooooo00?o0000ooooooooool0D_ooool0033ooooo00?o0000ooooooooool0I_ooool4
o`000003ooooool0003o000000;o00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Gooooo00Go
0000ooooool0003oooooo`000005ooooo`05o`000?ooooooooooooooool000001Oooool01?l0003o
ooooooooool0001Aooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0DOooool0033o
oooo00?o0000ooooooooool0I_ooool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooooooo
ooooool000001Oooool01Ol0003ooooooooooooooooo000000Gooooo00Go0000oooooooooooooooo
o`000005ooooo`04o`000?ooooooooooo`0000Kooooo0_l0003booooo`00<?ooool00ol0003ooooo
ooooo`1Uooooo`05o`000?ooooooooooooooool000002_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo0000
00Gooooo00Go0000ooooooooooooooooo`000005ooooo`05o`000?ooooooooooooooool000001Ooo
ool01?l0003oooooooooool00006ooooo`03o`000?oooooo00000;Oooooo00?oMgMgofIVI_ooool0
;Oooool00omVIVKoMgMgooooo`07ooooo`00<?ooool00ol0003oooooooooo`1Tooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Gooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
00001Oooool01?l0003oooooooooool00006ooooo`03o`000?oooooo00000;Kooooo00?ogMgMoa0@
4?o^k^h0;_ooool00oo^k^ko410@omgMg@07ooooo`00<?ooool00ol0003oooooooooo`1Tooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000001Oooool01Ol0003ooooooooooooooooo000000Cooooo00Co0000
oooooooooooo00001_ooool2o`0009cooooo0_l00002ooooo`;o00003?ooool00omEEEGoV9RHoooo
o`02o`0000;ooooo00Oo0000oooooooooooo0000oa0@4?o^k^koEEEE00;o000000?oA4A4okZj^_oo
ool00_ooool01OnHV9So0000o`000?m4A4Co^[Zj00;ooooo00Sok^k^oeEEEOl0003o0000odA4A?nj
^[[ooooooa0@40Go00000oooool02?l@413o<S8bo`000?l0003o410@ojVYZOn7QhOoIVIV1oooool0
033ooooo00?o0000ooooooooool0Doooool7o`0000Wooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000005
ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo
0_l000000ooooooo0000ooooo`05ooooo`;o0000Toooool01_o^k^ko8B4QohN7Qonj^[[o0000omgM
g@cooooo00Go0000ooooooooooooooooo`000002ooooo`0;o`000?ooooooooooo`000?ooooooEEEE
ogMgMoooooook^k^ogMgMol@41000oooool01Ol@413o^[Zjonk^k_mgMgOo410@00;ooooo00KoEEEE
ogMgMoooooook^k^ogMgMol@4103ooooo`03o`000?oooooooooo00Cooooo00So0000ojVYZOoooooo
oooookZj^_l0003ok^k^o`0000Oooooo003oo`000;Co00003oooool01?oMgMgo0000oa0@4?o<c<`=
ooooo`05oc8b<_ooooooooooooooool000000_ooool01_l0003oooooooooool0003oooooo`0000So
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Go
oooo00Oo^[ZjohN7QomVIVKoIVIVoa0@4?oooooo000000Oooooo000:ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo0000
00Ko00002_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00Co0000oooo
oooooooo00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000000_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00Ko0000oooooooooooo0000
ooooool00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01_l0003o
ooooooooool0003oooooo`0000Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02
ooooo`05o`000?oooooo0000ooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo
00?o0000ooooool000000_ooool00ol0003oooooo`000005ooooo`Co00001?ooool4o`0000oooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Oooooo
00Cok^k^ob4Q8Ol@413ok^k^3Oooool01Olb<S;ooooooooooooooooo000000;ooooo00Go0000oooo
oooooooo0000ooooo`06o`0000?ooooo00?o0000ooooooooool01?ooool6o`0000?ooooo00?o0000
ooooooooool01?ooool02?lb<S;o8B4QogMgMomgMgOoQhN7onk^k_oooooo00001oooool000[ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool04?ooool3o`0000Cooooo00?o0000ooooooooool01_ooool01?l0003ooooo
ooooool00004ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000002oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool01_l0003oooooooooool0003o
ooooo`0000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`06o`000?oo
ooooooooo`000?oooooo00001?ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00;ooooo00Co0000
oooooooooooo00000_ooool00ol0003oooooooooo`03o`0000gooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool05ooo
ool01?lQ8B7oMgMgogMgMolb<S8=ooooo`05o`000?o^k^koooooooooool000000_o<c<`02ol0003o
ZJVYomgMgOlQ8B7ooooooeEEEOn7QhOok^k^oooooon7QhOo<S8b00?ooooo00?o0000ooooooooool0
1?ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<P?ooooo00?o0000oc8b<_oMgMd01?ooool02?l0
003o^[Zjooooooo^k^koMgMgo`000?o^k^ko00001oooool0033ooooo00?o0000ooooooooool0Fooo
ool00ol0003oooooo`000004o`0000[ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000005ooooo`04o`00
0?ooooooooooo`0000Gooooo0ol0000Yooooo`03o`000?oooooooooo05_ooooo00?o0000oooooooo
ool05_ooool2o`0000;ooooo0_l0000<ooooo`0>oeEEEOmgMgOooooooa0@4?l0003o8B4Qo`000?mg
MgOo410@o`000?nYZJWoooooonk^k_mEEED2o`000004odA4A?o^k^kooooooa0@40Go00000oooool0
1_o^k^koEEEEo`000?l0003oA4A4onk^kP;ooooo0_l000001?nYZJWo8B4Qo`000?lQ8B42ooooo`08
ojVYZOlQ8B7o0000o`000?lb<S;o0000ogMgMomEEED7ooooo`00<?ooool00ol0003oooooooooo`1O
ooooo`;o00002oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Gooooo00Co0000oooooooooooo0000
1_ooool2o`000;;ooooo00?ogMgMoa0@4?o^k^h04_ooool00ol0003oooooooooo`0Iooooo`03onk^
k_l@413ogMgM00Oooooo000`ooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`000005ooooo`04o`000?ooooooooooo`000;_ooooo00?oMgMgofIVI_ooool04Oooool00ol0003o
ooooooooo`0Iooooo`03ofIVI_mgMgOooooo00Oooooo000`ooooo`03o`000?oooooooooo06gooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo
00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooo00000?Kooooo000`ooooo`03o`00
0?oooooooooo06gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`;o0000m_ooool0033ooooo
00?o0000ooooooooool0KOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool00007ooooo`;o0000m_ooool0033ooooo
00?o0000ooooooooool0KOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00_ooool01?l0003oooooooooool0003oooooo`00<?ooool00ol0003ooooo
ooooo`1]ooooo`05o`000?ooooooooooooooool000002_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooo00000?oooooo000`ooooo`03o`000?oooooooooo06kooooo00Co0000oooooooooooo
00002_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`000006ooooo`03o`000?oooooo00000?oooooo000`ooooo`?o0000K_ooool01?l0003o
ooooo`000?l0000:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooool00000ooooool0033ooooo00?o0000oooo
ooooool0Koooool2o`0000_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooo`00003oooooo`00<?ooool00ol0
003oooooooooo`1looooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01?l0
003oooooooooool00006ooooo`03o`000?oooooo00000?oooooo000`ooooo`03o`000?oooooooooo
07cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`04o`000?oooooooooo
o`0000Kooooo0_l0003oooooo`7ooooo000`ooooo`03o`000?oooooooooo07cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000oooo
ooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool0o_oo
ool0033ooooo00?o0000ooooooooool0O?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Kooooo00Co
0000oooooooooooo0000ooooool9ooooo`00<?ooool00ol0003oooooooooo`1looooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oo
ooooooooooooool000001_ooool01?l0003oooooooooool0003oooooo`Wooooo000`ooooo`03o`00
0?oooooooooo07cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`00
0?oooooo2Oooool0033ooooo00?o0000ooooooooool0OOooool01?l0003oooooooooool00009oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo
000000Kooooo00Co0000oooooooooooo00001_ooool00ol0003oooooo`00003oooooo`[ooooo000`
ooooo`03o`000?oooooooooo07gooooo00Co0000oooooooooooo00002Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`04o`00
0?ooooooooooo`0000Kooooo00?o0000ooooool00000ooooool:ooooo`00<?ooool00ol0003ooooo
ooooo`1mooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool00006
ooooo`03o`000?oooooo00000?oooooo2_ooool0033ooooo00?o0000ooooooooool0OOooool01?l0
003oooooooooool00009ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
1Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo00001_ooool00ol0003ooooo
o`00003oooooo`[ooooo000`ooooo`?o0000OOooool01?l0003oooooooooool00009ooooo`05o`00
0?ooooooooooooooool000001oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooo
oooooooo00001_ooool00ol0003oooooo`00003oooooo`[ooooo000`ooooo`03o`000?oooooooooo
07gooooo00Co0000oooooooooooo00002Oooool01Ol0003ooooooooooooooooo000000Oooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000oooooooooooo
ooooo`000006ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooool00000ooooool:oooo
o`00<?ooool00ol0003oooooooooo`1mooooo`04o`000?ooooooooooo`0000Wooooo00Go0000oooo
ooooooooooooo`000007ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00
0006ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool00007ooooo`;o
0000ooooool:ooooo`00<?ooool00ol0003oooooooooo`1mooooo`04o`000?ooooooooooo`0000Wo
oooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooo
ooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003ooooooooo
ool00007ooooo`;o0000ooooool:ooooo`00<?ooool00ol0003oooooooooo`1mooooo`04o`000?oo
ooooooooo`0000Wooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001_ooool0
1?l0003oooooooooool00007ooooo`;o0000ooooool:ooooo`00<?ooool00ol0003oooooooooo`1m
ooooo`03o`000?oooooo000000[ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool0
00001_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo0?oooooo2Oooool0033o
oooo00?o0000ooooooooool0O_ooool2o`0000[ooooo00Go0000ooooooooooooooooo`000008oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?oooooo
ooooooooool000001_ooool01?l0003oooooooooool0003ooooooa?ooooo000`ooooo`03o`000?oo
oooooooo07kooooo0_l0000:ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo0000
00Kooooo00Co0000oooooooooooo0000oooooolCooooo`00<?ooool00ol0003oooooooooo`1noooo
o`;o00002_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
1Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000006ooooo`04o`00
0?ooooooooooo`000?oooooo4oooool0033ooooo00?o0000ooooooooool0O_ooool2o`0000[ooooo
00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooo
ooooooooo`000006ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo0000oooo
oolCooooo`00<?ooool00ol0003oooooooooo`2:ooooo`05o`000?ooooooooooooooool000002?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003ooooo
ooooool00007ooooo`04o`000?ooooooooooo`000?oooooo4oooool0033ooooo00?o0000oooooooo
ool0R_ooool01Ol0003ooooooooooooooooo000000Sooooo00Go0000ooooooooooooooooo`000007
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooo
oooo000000Kooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool0003ooooooa?o
oooo000`ooooo`?o0000R_ooool01Ol0003ooooooooooooooooo000000Sooooo00Go0000oooooooo
ooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0
003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00
003ooooooaCooooo000`ooooo`03o`000?oooooooooo08[ooooo00Go0000ooooooooooooooooo`00
0008ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`00
00Oooooo00?o0000ooooool00000oooooolDooooo`00<?ooool00ol0003oooooooooo`2:ooooo`05
o`000?ooooooooooooooool000002?ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_oo
ool01?l0003oooooooooool00007ooooo`03o`000?oooooo00000?oooooo5?ooool0033ooooo00?o
0000ooooooooool0R_ooool01Ol0003ooooooooooooooooo000000Sooooo00Go0000oooooooooooo
ooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003o
oooooooooooooooo000000Kooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00003o
oooooaCooooo000`ooooo`03o`000?oooooooooo08[ooooo00Go0000ooooooooooooooooo`000008
ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo
00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000oooo
ool00000oooooolDooooo`00<?ooool00ol0003oooooooooo`2:ooooo`05o`000?oooooooooooooo
ool000002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`00
0007ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool00007ooooo`03
o`000?oooooo00000?oooooo5?ooool000oooooo0_o^k^h3ooooo`;ok^k^6_ooool00ol0003ooooo
ooooo`2:ooooo`05o`000?ooooooooooooooool000002?ooool01Ol0003ooooooooooooooooo0000
00Oooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001_oo
ool01?l0003oooooooooool00007ooooo`03o`000?oooooo00000?oooooo5?ooool000Sooooo1Ol0
0002ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co000000So410@oooooooo
ooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00?o0000ooooooooool0R_ooool01Ol0003ooooooooo
oooooooo000000Sooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooooooooooo
ool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooool000001oooool0
0ol0003oooooo`00003ooooooaCooooo0008ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool0
1Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00?o0000ooooooooool0Roooool01?l0003oooooooooool00008ooooo`05
o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000
ooooooooooooooooo`000007ooooo`03o`000?oooooo000000Oooooo00?o0000ooooool00000oooo
oolDooooo`002Oooool00onHV9So8B4Qonk^kP05ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00_ooooo00?o0000ooooooooool0Rooo
ool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003o
oooooooooooooooo000000Oooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`000008
ooooo`;o0000oooooolDooooo`002_ooool00onHV9So8B4Qonk^kP03ooooo`05onk^k_mEEEGogMgM
oeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000002ooo
ool00ol0003oooooooooo`2;ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooooooo
ooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool00008
ooooo`03o`000?oooooo000000Sooooo0_l0003ooooooaCooooo000;ooooo`0;ogMgMomVIVKooooo
ooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000002oooool4o`0008[ooooo00Co0000oooooooooooo00002?ooool0
1Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04o`00
0?ooooooooooo`0000Sooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`3ooooooa?o
oooo000<ooooo`03o`000?oooooooooo00;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@00_ooooo00?o0000ooooooooool0Roooool01?l0003o
ooooooooool00008ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooo
oooo000000Oooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003ooooooakooooo
0008ooooo`05o`000?nj^[[ooooooiRHV?l@41003_ooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool00ol0003oooooooooo`2;ooooo`04o`000?ooooooooooo`00
00Sooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001ooo
ool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?oooooo7_ooool000Sooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c00<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP03ooooo`;o00001_ooool00ol0003oooooooooo`2;ooooo`04o`000?ooooooooooo`00
00Sooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001ooo
ool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?oooooo7_ooool002Oooooo00Co
0000oooooooooooo00001Oooool00ol0003oooooooooo`2;ooooo`04o`000?ooooooooooo`0000Wo
oooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000
oooooooooooo00002?ooool00ol0003oooooo`00003ooooooakooooo000Wooooo`04o`000?oooooo
ooooo`0000Gooooo00?o0000ooooooooool0Roooool00ol0003oooooo`00000:ooooo`04o`000?oo
ooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`00
00Sooooo00?o0000ooooool00000oooooolNooooo`009oooool3o`0000Kooooo00?o0000oooooooo
ool0Roooool00ol0003oooooo`00000:ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooo
ooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooo
oolNooooo`00:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo08_ooooo00?o0000
ooooool000002_ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool00000
1oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?oooooo7_ooool002Wooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`2;ooooo`03o`000?oooooo000000[ooooo
00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooo
oooooooo00002?ooool00ol0003oooooo`00003ooooooakooooo000`ooooo`03o`000?oooooooooo
08_ooooo00?o0000ooooool000002_ooool01?l0003oooooooooool00007ooooo`05o`000?oooooo
ooooooooool000001oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?oooooo
7_ooool0033ooooo00?o0000ooooooooool0S?ooool2o`0000[ooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000oooo
ool00000oooooolNooooo`00<?ooool00ol0003oooooooooo`2<ooooo`;o00002_ooool01?l0003o
ooooooooool00008ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00002?oo
ool00ol0003oooooo`00003ooooooakooooo000`ooooo`?o0000S?ooool2o`0000[ooooo00Co0000
oooooooooooo00002?ooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000So
oooo00?o0000ooooool00000oooooolNooooo`00<?ooool00ol0003oooooooooo`2<ooooo`03o`00
0?oooooooooo00Wooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00007oooo
o`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooooolNooooo`00<?ooool00ol0
003oooooooooo`2Hooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001ooo
ool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?oooooo7_ooool0033ooooo00?o
0000ooooooooool0V?ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Oo
oooo00Co0000oooooooooooo00002?ooool2o`000?oooooo7oooool0033ooooo00?o0000oooooooo
ool0V?ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000
oooooooooooo00002?ooool2o`000?oooooo7oooool0033ooooo00?o0000ooooooooool0V?ooool0
0ol0003oooooo`000009ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo0000
2?ooool2o`000?oooooo7oooool0033ooooo00?o0000ooooooooool0V?ooool00ol0003oooooo`00
0009ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00002?ooool2o`000?oo
oooo7oooool0033ooooo00?o0000ooooooooool0V?ooool00ol0003oooooo`000009ooooo`04o`00
0?ooooooooooo`0000Oooooo00Co0000oooooooooooo00002?ooool2o`000?oooooo7oooool0033o
oooo00?o0000ooooooooool0V?ooool00ol0003oooooo`000009ooooo`04o`000?ooooooooooo`00
00Oooooo00Co0000oooooooooooo00002?ooool2o`000?oooooo7oooool0033ooooo00?o0000oooo
ooooool0V?ooool00ol0003oooooo`000009ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000
oooooooooooo00002?ooool2o`000?oooooo7oooool0033ooooo00?o0000ooooooooool0V?ooool0
0ol0003oooooo`000009ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooo
oolYooooo`00<?ooool00ol0003oooooooooo`2Hooooo`03o`000?oooooo000000Wooooo00Co0000
oooooooooooo00002?ooool00ol0003oooooo`00003oooooobWooooo000`ooooo`?o0000V?ooool0
0ol0003oooooo`000009ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooo
oolYooooo`00<?ooool00ol0003oooooooooo`2Hooooo`03o`000?oooooo000000Wooooo00Co0000
oooooooooooo00002?ooool00ol0003oooooo`00003oooooobWooooo000`ooooo`03o`000?oooooo
oooo09Sooooo00?o0000ooooool000002Oooool01?l0003oooooooooool00008ooooo`03o`000?oo
oooo00000?oooooo:Oooool0033ooooo00?o0000ooooooooool0V?ooool00ol0003oooooo`000009
ooooo`03o`000?oooooo000000Wooooo00?o0000ooooool00000oooooolYooooo`00<?ooool00ol0
003oooooooooo`2Hooooo`03o`000?oooooo000000Wooooo00?o0000ooooool000002Oooool00ol0
003oooooo`00003oooooobWooooo000`ooooo`03o`000?oooooooooo09Sooooo00?o0000ooooool0
00002Oooool00ol0003oooooo`000009ooooo`03o`000?oooooo00000?oooooo:Oooool0033ooooo
00?o0000ooooooooool0V?ooool00ol0003oooooo`000009ooooo`03o`000?oooooo000000Wooooo
00?o0000ooooool00000oooooolYooooo`00<?ooool00ol0003oooooooooo`2Hooooo`03o`000?oo
oooo000000Wooooo00?o0000ooooool000002Oooool00ol0003oooooo`00003oooooobWooooo000`
ooooo`03o`000?oooooooooo09Sooooo00?o0000ooooool000002Oooool00ol0003oooooo`000009
ooooo`03o`000?oooooo00000?oooooo:Oooool0033ooooo00?o0000ooooooooool0VOooool2o`00
00Wooooo00?o0000ooooool000002Oooool2o`000?oooooo:_ooool0033ooooo00?o0000oooooooo
ool0VOooool2o`0000Wooooo00?o0000ooooool000002Oooool2o`000?oooooo:_ooool0033ooooo
00?o0000ooooooooool0VOooool00ol0003oooooooooo`08ooooo`03o`000?oooooo000000Wooooo
0_l0003oooooob[ooooo000`ooooo`?o0000VOooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooo000000Wooooo0_l0003oooooob[ooooo000`ooooo`03o`000?oooooooooo0:Cooooo00?o0000
ooooool000002Oooool2o`000?oooooo:_ooool0033ooooo00?o0000ooooooooool0Y?ooool00ol0
003oooooo`000009ooooo`;o0000oooooolZooooo`00<?ooool00ol0003oooooooooo`2Tooooo`03
o`000?oooooo000000[ooooo00?o0000ooooooooool0oooooolXooooo`00<?ooool00ol0003ooooo
ooooo`2Uooooo`;o0000ooooooleooooo`00<?ooool00ol0003oooooooooo`2Uooooo`;o0000oooo
ooleooooo`003oooool2onk^kP?ooooo0_o^k^hJooooo`03o`000?oooooooooo0:Gooooo0_l0003o
ooooocGooooo000:ooooo`;o000000[o410@ooooooooooook^k^oeEEEOo^k^koooooonk^k_mEEEGo
k^k^0oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`03o`000?oo
oooooooo0:Gooooo0_l0003oooooocGooooo000;ooooo`03o`000?oooooooooo00;ooooo00Gok^k^
oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`03o`000?oooooooooo0:Gooooo0_l0003oooooocGooooo0008ooooo`Go00001?oo
ool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooo
oa0@400;ooooo`03o`000?oooooooooo0:Gooooo0_l0003oooooocGooooo0008ooooo`04odA4A?oM
gMgoooooo`0000Cooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`00000;ooooo`03o`000?oooooooooo0:Gooooo00?o0000oooo
ooooool0ooooooldooooo`002?ooool01?oMgMgoEEEEooooool00003ooooo`07onk^k_mEEEGok^k^
ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000;ooooo`Co0000oooooooKooooo`002Oooool00omgMgOoc<c<o`000003ooooo`;ok^k^0ooo
ool2onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00_ooooo
00?o0000ooooooooool0oooooooLooooo`002Oooool00oo^k^koA4A4o`00000?ooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03o`000?oooooooooo0?oooooo
g?ooool000[ooooo00?oMgMgo`000?ooool03?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h00oooool2o`0000Kooooo00?o0000ooooooooool0oooooooLooooo`009ooo
ool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo0?oooooog?ooool002Oooooo00Co
0000oooooooooooo00001Oooool00ol0003oooooooooo`3oooooomcooooo000Wooooo`?o00001_oo
ool00ol0003oooooooooo`3oooooomcooooo000Xooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0oooooooLooooo`00:Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooo
ooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo0ol0003o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0
003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo
00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`
ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLoooo
o`00<?ooool3o`000?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?oo
ool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0
033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomco
oooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooo
oooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooo
ooooo`3oooooomcooooo000`ooooo`?o0000oooooooLooooo`00<?ooool00ol0003oooooooooo`3o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo003ooooooooooooo4?oo
ool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooo
ooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@oooo
o`00X?ooool2o`0000Cooooo00?o^[Zjoc8b<_ooool01?ooool2o`0000Kooooo00?o0000okZj^_oo
ool0oooooomGooooo`00X?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool2oc8b<_ooooooF?ooool008gooooo0ol00002ooooo`06oc8b<_l@
413oooooooooooo^k^koEEEE0_l000000om4A4Co^[Zjooooo`03ooooo`03o`000?oooooooooo00;o
oooo00GoV9RHoa0@4?l0003o0000ojVYZ@04ooooo`03o`000?oooooooooo00Cooooo00?oQhN7o`00
0?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj00_ooooo00?o0000onk^k_ooool01Oooool2
ob4Q8@Cooooo00_oc<c<ob4Q8Ol0003o8B4Qolc<c?ooooooc<c<onk^k_ooooook^k^olc<c004oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kQ?ooooo00Ko410@oc8b<_l0003o
0000oa0@4?nYZJT2ooooo`06onk^k_mEEEGo0000o`000?m4A4Co^[Zj0oooool01OmVIVKo0000o`00
0?m4A4Coc<c<0>Sooooo002>ooooo`05o`000?ooooooooooolc<c?l@41000oooool01_mEEEGoMgMg
ooooooo^k^koMgMgoa0@40Cooooo00?o0000ooooooooool00_ooool01_l0003oZJVYoeEEEOnHV9So
EEEEokZj^P?ooooo00?o0000ooooooooool01?ooool00oo<c<co0000oa0@400<ooooo`06oa0@4?nj
^[[ok^k^ogMgMol@413ooooo1_l00004ooooo`03oeEEEOnYZJWooooo00Gooooo0_lQ8B44ooooo`0;
ob4Q8OnHV9SooooooiRHV?lQ8B7oooooonk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool01_l0003oZJVYoooooooooooo^[Zj
o`0000;ooooo00KoEEEEogMgMoooooook^k^ogMgMol@4102ooooo`06ofIVI_mgMgOooooooooooon7
QhOo410@j?ooool008kooooo00Go0000ooooooooooooEEEEohN7Q`03ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool00_ooool01_lb<S;ok^k^oiRHV?mEEEGogMgMoa0@40?ooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0=ooooo`03ojVYZOmEEEGooooo00_ooooo00Go
0000ooooooooooooooooo`000002ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@01Cooooo00Go^[ZjohN7QomVIVKoIVIVoa0@4002oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0joooool008kooooo00Go0000oooooooM
gMgo0000onk^kP03ooooo`Ko00001?ooool00ol0003oooooooooo`02ooooo`07okZj^_m4A4Coc<c<
ob4Q8Ooooooo410@olc<c002ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00ooo
ool6o`0000Gooooo00?o8B4Qooooooooool02_ooool02olb<S;oV9RHoooooonHV9So<S8booooooo^
k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000001?ooooo00Ko<S8bob4Q8OmgMgOoMgMgohN7Qoo^k^h2ooooo`Ko00000_ooool00ol0003o
ooooooooo`3[ooooo`00S_ooool3o`000003oa0@4?nHV9Sooooo00;ooooo00KoEEEEohN7Qoo^k^ko
ooooohN7Qolb<S84ooooo`03o`000?oooooooooo00;ooooo00Ook^k^o`000?oooooo0000oooooomV
IVKoQhN700;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0>ooooo`03oeEEEOo<
c<cooooo00[ooooo00_oc<c<o`000?l0003o0000olc<c?ooooooc<c<onk^k_ooooook^k^olc<c006
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Cooooo`06o`000?nj
^[[oooooonk^k_mgMgOo00000_ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<P;ooooo00KoIVIV
ogMgMoooooooooooohN7Qol0003Xooooo`00S_ooool01Ol0003oooooooooooo<c<co000000?ooooo
00Kok^k^oeEEEOl0003o0000odA4A?o^k^h4ooooo`03o`000?oooooooooo00;ooooo00CoIVIVoiRH
V?oooooo<S8b0_nj^[X01?l0003oooooooooool0000Cooooo`03oa0@4?l0003o000000?o00003Ooo
ool00onYZJWoMgMgooooo`0:ooooo`05oa0@4?nj^[[ooooookZj^_l@41003?ooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41001oooool3o`0000;ooooo0ol00004ooooo`06
ojVYZOlQ8B7o0000o`000?lb<S;o00000_ooool01_o^k^koEEEEo`000?l0003oA4A4onk^kP;ooooo
00Kok^k^ofIVI_l0003o0000odA4A?l0003Xooooo`00S_ooool01Ol0003oooooooooooo<c<co0000
00gooooo00?o0000ooooooooool01Oooool00omVIVKoQhN7ooooo`03ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool02oooool01Ol@413ooooooooooooooooo<S8b00_ooooo00Go0000
okZj^_oooooo^[Zjo`00000<ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`08ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0ooooool2ooooo`00SOoo
ool4o`000003oa0@4?nYZJWooooo00cooooo0_l00006ooooo`03ojVYZOm4A4Cooooo00;ooooo0_l0
000Eooooo`03o`000?oooooooooo00_ooooo1Ol0000;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0
2_ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_ooool4o`0000;o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3oooooo`;ooooo003oooooo`Kooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`3oooooo`;ooooo003oooooo`Kooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`3oooooo`;ooooo003oooooo`Gooooo0_l00003
ooooo`;o0000ooooool4ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooo
ooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@oooo
o`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooo
oooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo
003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooo
oooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool0
0001\
\>"],
  ImageRangeCache->{{{0, 525.688}, {324.5, 0}} -> {-2.58312*^-7, -6.34248*^6, \
6.65005*^-9, 53093.5}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0.309017 5.42214e-08 [
[.32684 .29652 -16.5 -12.5 ]
[.32684 .29652 16.5 0 ]
[.54329 .29652 -16.5 -12.5 ]
[.54329 .29652 16.5 0 ]
[.75974 .29652 -22.5 -12.5 ]
[.75974 .29652 22.5 0 ]
[.97619 .29652 -16.5 -12.5 ]
[.97619 .29652 16.5 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 64 6 ]
[.09789 .09213 -34.5 -6.25 ]
[.09789 .09213 0 6.25 ]
[.09789 .20057 -34.5 -6.25 ]
[.09789 .20057 0 6.25 ]
[.09789 .41746 -28.5 -6.25 ]
[.09789 .41746 0 6.25 ]
[.09789 .5259 -28.5 -6.25 ]
[.09789 .5259 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -59.8125 0 ]
[.5 .63053 59.8125 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 .30902 m
.32684 .31527 L
s
gsave
.32684 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 .30902 m
.54329 .31527 L
s
gsave
.54329 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 .30902 m
.75974 .31527 L
s
gsave
.75974 .29652 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 .30902 m
.15368 .31277 L
s
.19697 .30902 m
.19697 .31277 L
s
.24026 .30902 m
.24026 .31277 L
s
.28355 .30902 m
.28355 .31277 L
s
.37013 .30902 m
.37013 .31277 L
s
.41342 .30902 m
.41342 .31277 L
s
.45671 .30902 m
.45671 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.58658 .30902 m
.58658 .31277 L
s
.62987 .30902 m
.62987 .31277 L
s
.67316 .30902 m
.67316 .31277 L
s
.71645 .30902 m
.71645 .31277 L
s
.80303 .30902 m
.80303 .31277 L
s
.84632 .30902 m
.84632 .31277 L
s
.88961 .30902 m
.88961 .31277 L
s
.9329 .30902 m
.9329 .31277 L
s
.0671 .30902 m
.0671 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09213 m
.11664 .09213 L
s
gsave
.09789 .09213 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .20057 m
.11664 .20057 L
s
gsave
.09789 .20057 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .41746 m
.11664 .41746 L
s
gsave
.09789 .41746 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .5259 m
.11664 .5259 L
s
gsave
.09789 .5259 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.11039 .11924 m
.11414 .11924 L
s
.11039 .14635 m
.11414 .14635 L
s
.11039 .17346 m
.11414 .17346 L
s
.11039 .22768 m
.11414 .22768 L
s
.11039 .2548 m
.11414 .2548 L
s
.11039 .28191 m
.11414 .28191 L
s
.11039 .33613 m
.11414 .33613 L
s
.11039 .36324 m
.11414 .36324 L
s
.11039 .39035 m
.11414 .39035 L
s
.11039 .44457 m
.11414 .44457 L
s
.11039 .47168 m
.11414 .47168 L
s
.11039 .49879 m
.11414 .49879 L
s
.11039 .06502 m
.11414 .06502 L
s
.11039 .03791 m
.11414 .03791 L
s
.11039 .0108 m
.11414 .0108 L
s
.11039 .55301 m
.11414 .55301 L
s
.11039 .58012 m
.11414 .58012 L
s
.11039 .60723 m
.11414 .60723 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -120.812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.812 moveto
(@) show
81.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.812 moveto
(D) show
93.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8.) show
129.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
135.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
147.000 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
151.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
160.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
178.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02532 .30902 L
.02691 .30902 L
.02866 .30902 L
.03029 .30902 L
.03335 .30902 L
.03499 .30902 L
.03648 .30902 L
.03814 .30902 L
.03968 .30902 L
.04277 .30902 L
.04427 .30902 L
.04592 .30902 L
.04761 .30902 L
.04916 .30902 L
.05227 .30902 L
.05546 .30902 L
.05852 .30902 L
.06179 .30902 L
.06493 .30902 L
.06826 .30902 L
.07148 .30902 L
.07457 .30902 L
.07787 .30902 L
.08104 .30902 L
.08408 .30902 L
.08733 .30902 L
.09045 .30902 L
.09127 .30902 L
.09216 .30902 L
.09292 .30902 L
.09333 .30902 L
.09377 .30902 L
.09398 .30902 L
.0942 .30902 L
.0944 .30902 L
.09459 .30902 L
.09477 .30902 L
.09487 .30902 L
.09496 .30902 L
.09506 .30902 L
.09511 .30902 L
.09516 .30902 L
.09526 .30902 L
.09536 .30902 L
.09546 .30902 L
.09556 .30902 L
.09567 .30902 L
.09577 .30902 L
.09596 .30902 L
Mistroke
.09616 .30902 L
.09638 .30902 L
.09662 .30902 L
.09704 .30902 L
.09748 .30902 L
.09787 .30902 L
.09877 .30902 L
.09955 .30902 L
.10039 .30902 L
.10115 .30902 L
.10197 .30902 L
.10344 .30902 L
.10515 .30902 L
.10676 .30902 L
.10836 .30902 L
.10984 .30902 L
.11134 .30902 L
.113 .30902 L
.11469 .30902 L
.11623 .30902 L
.11934 .30902 L
.12253 .30902 L
.12559 .30902 L
.12885 .30902 L
.13199 .30902 L
.13532 .30902 L
.13853 .30902 L
.14163 .30902 L
.14319 .30902 L
.14402 .30902 L
.14492 .30902 L
.14535 .30902 L
.14577 .30902 L
.14615 .30902 L
.14634 .30902 L
.14655 .30902 L
.14665 .30902 L
.14675 .30902 L
.14684 .30902 L
.14694 .30902 L
.14704 .30902 L
.1471 .30902 L
.14715 .30902 L
.14725 .30902 L
.14735 .30902 L
.14744 .30902 L
.14754 .30902 L
.14764 .30902 L
.14773 .30902 L
.1479 .30902 L
Mistroke
.14808 .30902 L
.14848 .30902 L
.14884 .30902 L
.14926 .30902 L
.14965 .30902 L
.15035 .30902 L
.15112 .30902 L
.15195 .30902 L
.1527 .30902 L
.15438 .30902 L
.15593 .30902 L
.1576 .30902 L
.1592 .30902 L
.1609 .30902 L
.16394 .30902 L
.16719 .30902 L
.17032 .30902 L
.17364 .30902 L
.17684 .30902 L
.17992 .30902 L
.18147 .30902 L
.1823 .30902 L
.18319 .30902 L
.18404 .30902 L
.18441 .30902 L
.18482 .30902 L
.185 .30902 L
.1852 .30902 L
.18537 .30902 L
.18556 .30902 L
.18567 .30902 L
.18577 .30902 L
.18587 .30902 L
.18597 .30902 L
.18606 .30902 L
.18615 .30902 L
.18624 .30902 L
.18634 .30902 L
.1864 .30902 L
.18645 .30902 L
.18655 .30902 L
.18665 .30902 L
.18677 .30902 L
.18697 .30902 L
.18716 .30902 L
.18759 .30902 L
.18804 .30902 L
.18844 .30902 L
.18882 .30902 L
.18966 .30902 L
Mistroke
.1905 .30902 L
.1913 .30902 L
.19279 .30902 L
.19439 .30902 L
.19587 .30902 L
.1975 .30902 L
.19903 .30902 L
.20206 .30902 L
.20517 .30901 L
.20848 .30901 L
.21167 .30901 L
.21473 .30901 L
.21555 .30901 L
.21631 .30901 L
.21674 .30901 L
.21719 .30901 L
.21761 .30901 L
.21781 .30901 L
.218 .30901 L
.21819 .30901 L
.21837 .30901 L
.21847 .30901 L
.21857 .30901 L
.21867 .30901 L
.21872 .30901 L
.21878 .30901 L
.21887 .30901 L
.21896 .30901 L
.21905 .30901 L
.21915 .30901 L
.21932 .30901 L
.21951 .30901 L
.21972 .30901 L
.21992 .30901 L
.22036 .30901 L
.22078 .30901 L
.22116 .30901 L
.22194 .30901 L
.22277 .30901 L
.22425 .30901 L
.22501 .30901 L
.22582 .30901 L
.22729 .30902 L
.2306 .30902 L
.23379 .30903 L
.23686 .30904 L
.24013 .30905 L
.24327 .30906 L
.2441 .30906 L
.24499 .30906 L
Mistroke
.2454 .30906 L
.24584 .30906 L
.24621 .30907 L
.24642 .30907 L
.24661 .30907 L
.24681 .30907 L
.24692 .30907 L
.24703 .30907 L
.24713 .30907 L
.24722 .30907 L
.24733 .30907 L
.24738 .30907 L
.24743 .30907 L
.24752 .30907 L
.24761 .30907 L
.2477 .30907 L
.2478 .30907 L
.248 .30907 L
.24818 .30907 L
.2484 .30907 L
.2486 .30907 L
.24905 .30906 L
.24944 .30906 L
.24986 .30906 L
.25062 .30906 L
.25143 .30906 L
.25291 .30905 L
.25461 .30904 L
.25622 .30902 L
.25929 .30898 L
.26256 .30893 L
.26571 .30887 L
.26874 .30882 L
.27029 .3088 L
.27071 .30879 L
.27116 .30879 L
.27158 .30879 L
.27196 .30878 L
.27215 .30878 L
.27236 .30878 L
.27253 .30878 L
.27273 .30878 L
.27283 .30878 L
.27293 .30878 L
.27304 .30878 L
.2731 .30878 L
.27315 .30878 L
.27325 .30878 L
.27335 .30878 L
.27345 .30878 L
Mistroke
.27354 .30878 L
.27364 .30878 L
.27374 .30878 L
.27392 .30878 L
.2741 .30878 L
.27426 .30878 L
.27463 .30878 L
.27502 .30879 L
.27578 .3088 L
.27659 .30881 L
.27736 .30882 L
.27807 .30884 L
.2796 .30889 L
.28127 .30897 L
.28454 .30916 L
.28769 .30939 L
.29072 .30962 L
.29241 .30974 L
.29314 .30978 L
.29395 .30982 L
.29468 .30985 L
.29508 .30986 L
.29546 .30987 L
.29567 .30988 L
.2959 .30988 L
.29608 .30989 L
.29629 .30989 L
.29648 .30989 L
.29659 .30989 L
.29669 .30989 L
.29678 .30989 L
.29687 .30989 L
.29696 .30989 L
.29706 .30989 L
.29716 .30989 L
.29721 .30989 L
.29726 .30989 L
.29736 .30989 L
.29746 .30989 L
.29764 .30989 L
.29783 .30988 L
.29825 .30987 L
.29865 .30986 L
.29936 .30983 L
.30013 .30979 L
.30095 .30972 L
.30184 .30963 L
.30345 .30942 L
.30504 .30915 L
.30673 .30881 L
Mistroke
.30976 .30807 L
.313 .30726 L
.31448 .30693 L
.31611 .30665 L
.31653 .30659 L
.31699 .30654 L
.31738 .3065 L
.3178 .30647 L
.31803 .30645 L
.31824 .30644 L
.31844 .30643 L
.31854 .30643 L
.31865 .30643 L
.31875 .30643 L
.31884 .30643 L
.31894 .30643 L
.31904 .30643 L
.31914 .30643 L
.31922 .30643 L
.31931 .30643 L
.31941 .30643 L
.3196 .30644 L
.31981 .30645 L
.32016 .30647 L
.32055 .30651 L
.32098 .30656 L
.32173 .30668 L
.32244 .30683 L
.32408 .30733 L
.32557 .30795 L
.32878 .30978 L
.33187 .31191 L
.33343 .31298 L
.33515 .31404 L
.33594 .31445 L
.33678 .31483 L
.33758 .31511 L
.33796 .31522 L
.33831 .3153 L
.33869 .31537 L
.3389 .31539 L
.339 .3154 L
.3391 .31541 L
.33919 .31542 L
.33929 .31543 L
.33937 .31543 L
.33945 .31543 L
.33955 .31543 L
.33964 .31544 L
.33974 .31543 L
Mistroke
.33984 .31543 L
.33993 .31543 L
.34004 .31542 L
.34015 .31541 L
.34025 .3154 L
.34043 .31538 L
.34063 .31535 L
.34109 .31525 L
.3415 .31513 L
.34229 .31481 L
.34302 .31441 L
.34468 .3131 L
.34633 .31132 L
.34782 .30932 L
.35103 .30425 L
.35412 .29937 L
.35572 .29734 L
.35652 .29653 L
.35698 .29616 L
.35741 .29586 L
.3578 .29564 L
.358 .29554 L
.35822 .29546 L
.35843 .29539 L
.35861 .29535 L
.3587 .29533 L
.3588 .29532 L
.35889 .2953 L
.35897 .2953 L
.35907 .29529 L
.35917 .29529 L
.35927 .29529 L
.35936 .2953 L
.35946 .29531 L
.35952 .29532 L
.35958 .29532 L
.35979 .29537 L
.35998 .29542 L
.3602 .2955 L
.36065 .29573 L
.36106 .29602 L
.36146 .29636 L
.3622 .29719 L
.36301 .29835 L
.36388 .29993 L
.36546 .30354 L
.36714 .30832 L
.37048 .31939 L
.37215 .32487 L
.3737 .32927 L
Mistroke
.3752 .33257 L
.37596 .33374 L
.37639 .33424 L
.37679 .33459 L
.377 .33472 L
.37719 .33482 L
.37729 .33485 L
.3774 .33489 L
.37746 .3349 L
.37752 .33491 L
.37758 .33492 L
.37763 .33493 L
.37772 .33493 L
.37781 .33493 L
.37791 .33492 L
.37802 .3349 L
.37807 .33488 L
.37812 .33487 L
.37823 .33483 L
.37842 .33474 L
.3786 .33462 L
.3788 .33446 L
.3792 .33405 L
.37957 .33354 L
.37991 .33296 L
.38075 .33112 L
.38154 .32884 L
.38303 .32317 L
.3861 .30688 L
.38936 .28672 L
.39088 .27825 L
.39251 .27091 L
.39294 .26938 L
.39341 .26799 L
.39383 .26693 L
.39423 .26615 L
.3946 .2656 L
.39481 .26538 L
.395 .26523 L
.39511 .26517 L
.39521 .26513 L
.39526 .26511 L
.39532 .2651 L
.39538 .26509 L
.39544 .26509 L
.39554 .26509 L
.39564 .26511 L
.39574 .26515 L
.39579 .26517 L
.39585 .2652 L
Mistroke
.39605 .26536 L
.39617 .26547 L
.39628 .26559 L
.39668 .26621 L
.39704 .26698 L
.39743 .26803 L
.39823 .27093 L
.39911 .27524 L
.40067 .2856 L
.40235 .29998 L
.40567 .33364 L
.40733 .34997 L
.40886 .36279 L
.40963 .36792 L
.41035 .3718 L
.41075 .37347 L
.41111 .37472 L
.41151 .37578 L
.41172 .37619 L
.41182 .37636 L
.41194 .37652 L
.41204 .37663 L
.41214 .37671 L
.41224 .37677 L
.41234 .3768 L
.41243 .37682 L
.41251 .37681 L
.4126 .37678 L
.4127 .37673 L
.41281 .37665 L
.41292 .37653 L
.41313 .37623 L
.41333 .37583 L
.41352 .37537 L
.41389 .37418 L
.41423 .3728 L
.41499 .36866 L
.4158 .36272 L
.41654 .35592 L
.41821 .33635 L
.42138 .28878 L
.42443 .24347 L
.426 .22602 L
.42645 .22217 L
.42688 .21908 L
.42726 .21681 L
.42746 .2158 L
.42768 .21486 L
.42788 .21412 L
.42808 .21357 L
Mistroke
.42826 .21317 L
.42835 .21302 L
.42845 .21288 L
.42851 .21282 L
.42856 .21278 L
.42866 .21272 L
.42876 .2127 L
.42882 .2127 L
.42888 .21272 L
.42897 .21277 L
.42907 .21287 L
.42918 .21301 L
.42928 .21318 L
.42947 .21361 L
.42965 .21415 L
.42999 .2155 L
.43035 .21744 L
.43075 .22014 L
.43159 .22766 L
.43234 .2366 L
.43402 .26321 L
.43724 .33076 L
.44034 .3954 L
.44117 .40915 L
.44195 .41978 L
.44276 .42827 L
.44318 .43157 L
.4434 .43294 L
.44364 .43414 L
.44384 .43494 L
.44395 .43529 L
.44407 .43559 L
.44417 .43581 L
.44427 .43596 L
.44437 .43606 L
.44446 .43611 L
.44452 .43612 L
.44457 .43611 L
.44462 .43608 L
.44468 .43604 L
.44478 .43593 L
.44483 .43585 L
.44488 .43576 L
.44511 .43518 L
.44522 .43479 L
.44535 .43428 L
.44575 .43207 L
.44618 .42874 L
.44697 .42026 L
.44778 .40812 L
Mistroke
.44867 .39139 L
.45028 .3531 L
.45356 .25947 L
.45518 .21533 L
.45598 .19658 L
.45671 .18172 L
.4574 .17004 L
.45816 .16038 L
.45856 .15676 L
.45893 .15429 L
.45913 .15331 L
.45932 .15267 L
.45942 .15241 L
.45948 .1523 L
.45953 .15221 L
.45964 .1521 L
.45974 .15207 L
.45983 .1521 L
.45994 .15221 L
.46004 .15238 L
.46013 .1526 L
.46031 .15319 L
.46049 .15404 L
.46071 .15536 L
.46092 .15691 L
.46131 .1606 L
.46201 .16995 L
.46277 .18372 L
.46438 .22366 L
.46607 .27812 L
.46912 .38671 L
.47082 .43892 L
.47162 .45863 L
.47237 .47316 L
.47273 .47887 L
.47314 .48399 L
.47354 .48783 L
.47376 .48937 L
.47386 .48993 L
.47397 .49045 L
.47406 .4908 L
.47416 .4911 L
.47426 .49133 L
.47436 .49147 L
.47445 .49153 L
.47454 .49152 L
.47462 .49146 L
.4747 .49132 L
.4748 .4911 L
.4749 .49077 L
Mistroke
.47501 .49033 L
.47512 .48982 L
.47549 .48716 L
.4757 .48518 L
.47589 .48301 L
.47633 .47697 L
.47712 .46204 L
.47785 .44431 L
.47861 .42155 L
.48164 .30515 L
.48332 .23533 L
.48486 .17834 L
.48564 .15439 L
.48637 .13599 L
.48713 .12141 L
.48753 .11577 L
.48774 .11343 L
.48796 .11141 L
.48817 .10996 L
.48827 .10936 L
.48839 .10884 L
.4885 .10847 L
.48859 .10824 L
.48869 .10809 L
.48878 .10805 L
.48884 .10806 L
.48889 .1081 L
.48895 .10817 L
.489 .10827 L
.4891 .10853 L
.48921 .10892 L
.48933 .10948 L
.48945 .11022 L
.48967 .11193 L
.49007 .11621 L
.49044 .1216 L
.49129 .13868 L
.49213 .1618 L
.49292 .18869 L
.49441 .2492 L
.49749 .38949 L
.49905 .45122 L
.49987 .47755 L
.50031 .48911 L
.50076 .49942 L
.50117 .50686 L
.50138 .51012 L
.50161 .51309 L
.50182 .51533 L
.50201 .51696 L
Mistroke
.50211 .5176 L
.50221 .51819 L
.5023 .51862 L
.50239 .51899 L
.50248 .51926 L
.50257 .51942 L
.50268 .51951 L
.50278 .51948 L
.50288 .51934 L
.50293 .51921 L
.50298 .51906 L
.50308 .5187 L
.50318 .51821 L
.50338 .51694 L
.50357 .51536 L
.50392 .51139 L
.50429 .50567 L
.5047 .49772 L
.50553 .47662 L
.50701 .42416 L
.51026 .27245 L
.51176 .20373 L
.51339 .14358 L
.51382 .13132 L
.51428 .12028 L
.5147 .11197 L
.5151 .10594 L
.51528 .10377 L
.51547 .10188 L
.51557 .10106 L
.51568 .10029 L
.51578 .09971 L
.51587 .09926 L
.51592 .09905 L
.51598 .09886 L
.51608 .09861 L
.51614 .09853 L
.5162 .09848 L
.51625 .09847 L
.51631 .09849 L
.51641 .09863 L
.51647 .09877 L
.51652 .09892 L
.51662 .09931 L
.51672 .09978 L
.51691 .10103 L
.51708 .10258 L
.51749 .10746 L
.51789 .11398 L
.51831 .12289 L
Mistroke
.51908 .14365 L
.51979 .16746 L
.52297 .31051 L
.52457 .38683 L
.52602 .44626 L
.52683 .47235 L
.5276 .49131 L
.52802 .49912 L
.5284 .50461 L
.52861 .5068 L
.52883 .50867 L
.52894 .5094 L
.52906 .51002 L
.52912 .51025 L
.52917 .51044 L
.52928 .5107 L
.52938 .51084 L
.52943 .51086 L
.52949 .51085 L
.52958 .51074 L
.52968 .51052 L
.52977 .51021 L
.52986 .50985 L
.53005 .5087 L
.53026 .50699 L
.53044 .50501 L
.53087 .49908 L
.53123 .49244 L
.53163 .48366 L
.53235 .46377 L
.53393 .40485 L
.53562 .32828 L
.5372 .25457 L
.53865 .19492 L
.5394 .16983 L
.54021 .14793 L
.54063 .13908 L
.54102 .13254 L
.54144 .12744 L
.54167 .12542 L
.54178 .12469 L
.54188 .12412 L
.54198 .12368 L
.54207 .12338 L
.54217 .12315 L
.54227 .12302 L
.54237 .12302 L
.54243 .12307 L
.54248 .12315 L
.54258 .12337 L
Mistroke
.54268 .12373 L
.54278 .12417 L
.54288 .12476 L
.54307 .12614 L
.54342 .12974 L
.54385 .13585 L
.54429 .1443 L
.54509 .16419 L
.54667 .21835 L
.54815 .28007 L
.54965 .34523 L
.55128 .40818 L
.55216 .43552 L
.55256 .44549 L
.55299 .45488 L
.55336 .46166 L
.55377 .46737 L
.55399 .4698 L
.5542 .47156 L
.5543 .47226 L
.55441 .47289 L
.5545 .47336 L
.5546 .47374 L
.55465 .4739 L
.55471 .47403 L
.55481 .4742 L
.55486 .47425 L
.55492 .47426 L
.55498 .47424 L
.55503 .47419 L
.55513 .47403 L
.55518 .47389 L
.55523 .47373 L
.55533 .47334 L
.55543 .47288 L
.5556 .4718 L
.55579 .47025 L
.55618 .46598 L
.5566 .45967 L
.55699 .45241 L
.55786 .43139 L
.55938 .38248 L
.56104 .31895 L
.56275 .25455 L
.5643 .20663 L
.56507 .18892 L
.56548 .18157 L
.56591 .17539 L
.56629 .17138 L
.5665 .16968 L
Mistroke
.5666 .16902 L
.5667 .16849 L
.56679 .16809 L
.56689 .16773 L
.56697 .16748 L
.56705 .16732 L
.56715 .1672 L
.56724 .16717 L
.56734 .16722 L
.56743 .16736 L
.56753 .16758 L
.56763 .1679 L
.56781 .16872 L
.56802 .17009 L
.56822 .1717 L
.56864 .17637 L
.56905 .18222 L
.56976 .19566 L
.57053 .21426 L
.57381 .31874 L
.57543 .36926 L
.57623 .38973 L
.57696 .40503 L
.57767 .41628 L
.57803 .42047 L
.57842 .42386 L
.57863 .42515 L
.57882 .42602 L
.57892 .42638 L
.57898 .42653 L
.57903 .42667 L
.57908 .42676 L
.57914 .42684 L
.57924 .42692 L
.57934 .42692 L
.57943 .42685 L
.57953 .42669 L
.57963 .42646 L
.57972 .42617 L
.5798 .42584 L
.58 .4249 L
.58019 .42365 L
.58037 .42225 L
.58077 .41822 L
.58149 .40802 L
.5823 .3928 L
.58314 .37316 L
.5862 .28919 L
.58707 .26672 L
.5879 .24817 L
Mistroke
.58871 .23345 L
.58906 .22817 L
.58945 .22328 L
.5898 .21973 L
.59018 .21684 L
.59039 .21566 L
.59058 .21485 L
.59067 .21455 L
.59077 .21428 L
.59087 .2141 L
.59095 .21398 L
.59106 .21391 L
.59111 .21391 L
.59117 .21392 L
.59126 .214 L
.59137 .21415 L
.59146 .21435 L
.59155 .21458 L
.59174 .21531 L
.59195 .21637 L
.59215 .2176 L
.59258 .22123 L
.59297 .2254 L
.59338 .23075 L
.59411 .24247 L
.59578 .27639 L
.59881 .34332 L
.59957 .35688 L
.60037 .36853 L
.60078 .3734 L
.60124 .37767 L
.60144 .3792 L
.60165 .38057 L
.60184 .38155 L
.60204 .3824 L
.60214 .38274 L
.60225 .38304 L
.60236 .38329 L
.60241 .38337 L
.60247 .38345 L
.60257 .38355 L
.60267 .38358 L
.60277 .38356 L
.60286 .3835 L
.60292 .38343 L
.60298 .38334 L
.60309 .38313 L
.6032 .38286 L
.60329 .38256 L
.60352 .38167 L
Mistroke
.60375 .38045 L
.60415 .37774 L
.60453 .37451 L
.60537 .36492 L
.60701 .33958 L
.6085 .31278 L
.61017 .28441 L
.6109 .2739 L
.6117 .26441 L
.61208 .26087 L
.61248 .2577 L
.61285 .25535 L
.6132 .25375 L
.6134 .25307 L
.61359 .25259 L
.6137 .25239 L
.61379 .25226 L
.61385 .2522 L
.61391 .25215 L
.61396 .25212 L
.61401 .25211 L
.6141 .25211 L
.61419 .25214 L
.61429 .25222 L
.61439 .25235 L
.61449 .25253 L
.6146 .25274 L
.61479 .25327 L
.61515 .25472 L
.61556 .25695 L
.61638 .26333 L
.61714 .27114 L
.61786 .27977 L
.62096 .32183 L
.6218 .33166 L
.62257 .33934 L
.62338 .34549 L
.62381 .3479 L
.62403 .3489 L
.62426 .34978 L
.62447 .35039 L
.62458 .35065 L
.62469 .35088 L
.6248 .35106 L
.62489 .35119 L
.62499 .35128 L
.62509 .35134 L
.62514 .35136 L
.62519 .35137 L
.62525 .35137 L
Mistroke
.62531 .35136 L
.6254 .35131 L
.62546 .35127 L
.62551 .35123 L
.62562 .3511 L
.62574 .35092 L
.62598 .35041 L
.62619 .3498 L
.62638 .34913 L
.62681 .3472 L
.62759 .34242 L
.62913 .32923 L
.63079 .31203 L
.63235 .29671 L
.63318 .28991 L
.63361 .28687 L
.63407 .28412 L
.63448 .28211 L
.63492 .28037 L
.63511 .27977 L
.63532 .27924 L
.63552 .27884 L
.6357 .27857 L
.63579 .27846 L
.63589 .27836 L
.63598 .27831 L
.63607 .27827 L
.63618 .27825 L
.63623 .27825 L
.63629 .27826 L
.63639 .2783 L
.63648 .27836 L
.63657 .27843 L
.63667 .27854 L
.63684 .27878 L
.63704 .27916 L
.63722 .27959 L
.63762 .28077 L
.63803 .28238 L
.63877 .2861 L
.64045 .29732 L
.64205 .3095 L
.6435 .31956 L
.64425 .32379 L
.64507 .32736 L
.64552 .32881 L
.64572 .32933 L
.64594 .32982 L
.64613 .33017 L
.64633 .33046 L
Mistroke
.64645 .33059 L
.64655 .33069 L
.64665 .33077 L
.64675 .33082 L
.64685 .33085 L
.64691 .33086 L
.64696 .33087 L
.64706 .33086 L
.64716 .33084 L
.64725 .3308 L
.64733 .33075 L
.64742 .33068 L
.64752 .33059 L
.64774 .33032 L
.64795 .32999 L
.64834 .32917 L
.64905 .32708 L
.64982 .32404 L
.65309 .30694 L
.65387 .30308 L
.65472 .29949 L
.65551 .29683 L
.65589 .29584 L
.65624 .2951 L
.65658 .29454 L
.65677 .2943 L
.65695 .29412 L
.65714 .29398 L
.65725 .29392 L
.65734 .29388 L
.65743 .29385 L
.65753 .29384 L
.65763 .29383 L
.65772 .29384 L
.65782 .29387 L
.65792 .29391 L
.65802 .29396 L
.65811 .29402 L
.65828 .29416 L
.65847 .29435 L
.65889 .29494 L
.65927 .29566 L
.66008 .29766 L
.66082 .29998 L
.66249 .30617 L
.66414 .31222 L
.66494 .31473 L
.66567 .31661 L
.66603 .31738 L
.66642 .31808 L
Mistroke
.6668 .3186 L
.66714 .31896 L
.66733 .31911 L
.66751 .31921 L
.66761 .31926 L
.6677 .3193 L
.6678 .31932 L
.66785 .31933 L
.66791 .31934 L
.66796 .31935 L
.66801 .31935 L
.66811 .31935 L
.66821 .31934 L
.66827 .31932 L
.66833 .31931 L
.66842 .31928 L
.66852 .31924 L
.66872 .31913 L
.66892 .31899 L
.66914 .31879 L
.66954 .31832 L
.67028 .31714 L
.67196 .31335 L
.67351 .30928 L
.67434 .30724 L
.67523 .30529 L
.67608 .30382 L
.67645 .30331 L
.67686 .30285 L
.67724 .30252 L
.67742 .30239 L
.6776 .3023 L
.67769 .30225 L
.6778 .30221 L
.67788 .30218 L
.67798 .30216 L
.67808 .30214 L
.67813 .30213 L
.67819 .30213 L
.67828 .30212 L
.67838 .30212 L
.67844 .30212 L
.67849 .30213 L
.67858 .30214 L
.67869 .30216 L
.6788 .30219 L
.67901 .30227 L
.67919 .30236 L
.67962 .30266 L
.68008 .30307 L
Mistroke
.68085 .304 L
.68169 .30528 L
.68339 .30823 L
.68494 .31078 L
.68571 .31182 L
.68611 .31228 L
.68654 .3127 L
.68692 .31299 L
.68712 .31312 L
.68733 .31324 L
.68753 .31334 L
.68771 .31341 L
.68788 .31346 L
.68806 .3135 L
.68816 .31351 L
.68822 .31352 L
.68827 .31353 L
.68836 .31353 L
.68846 .31353 L
.68855 .31353 L
.68864 .31353 L
.68873 .31352 L
.68883 .3135 L
.68893 .31348 L
.68905 .31346 L
.68926 .31339 L
.68965 .31323 L
.69002 .31302 L
.69041 .31275 L
.69112 .31214 L
.69273 .31039 L
.69447 .30841 L
.69528 .3076 L
.69614 .30691 L
.69688 .30648 L
.69708 .30639 L
.6973 .30631 L
.69748 .30625 L
.69769 .3062 L
.69789 .30616 L
.69801 .30614 L
.69811 .30613 L
.69821 .30612 L
.6983 .30611 L
.69841 .30611 L
.69851 .30611 L
.69856 .30611 L
.69861 .30612 L
.69867 .30612 L
.69873 .30612 L
Mistroke
.69883 .30613 L
.69893 .30615 L
.69917 .30619 L
.6994 .30624 L
.69977 .30636 L
.70018 .30653 L
.70101 .30697 L
.70271 .30817 L
.70426 .30931 L
.70502 .30982 L
.70586 .31027 L
.70624 .31044 L
.70665 .31059 L
.707 .31069 L
.70738 .31077 L
.70757 .3108 L
.70777 .31083 L
.70788 .31084 L
.70793 .31084 L
.70799 .31084 L
.70809 .31085 L
.70819 .31085 L
.70828 .31085 L
.70837 .31085 L
.70845 .31085 L
.70854 .31085 L
.70864 .31084 L
.70874 .31083 L
.70893 .31082 L
.70915 .31079 L
.70938 .31074 L
.70981 .31065 L
.7106 .31039 L
.71219 .30971 L
.71387 .30891 L
.7147 .30856 L
.71559 .30824 L
.716 .30813 L
.71643 .30803 L
.7168 .30797 L
.71702 .30794 L
.71721 .30791 L
.71741 .3079 L
.71752 .30789 L
.71763 .30788 L
.71773 .30788 L
.71782 .30788 L
.71792 .30788 L
.71798 .30787 L
.71803 .30787 L
Mistroke
.71812 .30788 L
.71821 .30788 L
.7183 .30788 L
.7184 .30788 L
.7185 .30789 L
.7186 .3079 L
.71878 .30791 L
.7192 .30796 L
.71959 .30802 L
.72046 .3082 L
.72209 .30866 L
.72362 .30911 L
.72438 .30931 L
.72509 .30947 L
.72549 .30954 L
.72592 .3096 L
.72631 .30965 L
.72667 .30968 L
.72686 .30969 L
.72704 .3097 L
.72714 .30971 L
.72723 .30971 L
.72733 .30971 L
.72738 .30971 L
.72744 .30972 L
.72753 .30972 L
.72763 .30972 L
.72773 .30972 L
.72782 .30971 L
.7279 .30971 L
.72799 .30971 L
.72816 .3097 L
.72838 .30969 L
.72858 .30968 L
.72902 .30964 L
.72982 .30955 L
.73134 .30929 L
.733 .30898 L
.73382 .30885 L
.73458 .30875 L
.73501 .3087 L
.73547 .30866 L
.73588 .30863 L
.73608 .30862 L
.73627 .30861 L
.73646 .3086 L
.73664 .3086 L
.73675 .3086 L
.73684 .3086 L
.73694 .3086 L
Mistroke
.73699 .3086 L
.73705 .3086 L
.73714 .3086 L
.73723 .3086 L
.73733 .3086 L
.73743 .3086 L
.73759 .3086 L
.73778 .30861 L
.738 .30862 L
.73819 .30863 L
.73864 .30865 L
.73944 .30872 L
.74111 .30889 L
.74265 .30906 L
.74342 .30913 L
.74415 .30919 L
.74454 .30921 L
.7449 .30923 L
.7453 .30925 L
.74553 .30926 L
.74574 .30926 L
.74584 .30926 L
.74594 .30926 L
.74605 .30927 L
.74614 .30927 L
.74623 .30927 L
.74632 .30927 L
.74642 .30927 L
.74651 .30927 L
.74656 .30927 L
.74661 .30927 L
.74671 .30927 L
.74681 .30926 L
.7469 .30926 L
.74711 .30926 L
.74733 .30926 L
.74769 .30924 L
.74803 .30923 L
.74881 .30919 L
.75192 .30899 L
.75275 .30895 L
.75353 .30891 L
.75392 .3089 L
.75434 .30889 L
.75458 .30888 L
.7548 .30888 L
.755 .30887 L
.75512 .30887 L
.75522 .30887 L
.75532 .30887 L
Mistroke
.75541 .30887 L
.75551 .30887 L
.75557 .30887 L
.75562 .30887 L
.7557 .30887 L
.75579 .30887 L
.75589 .30887 L
.75598 .30887 L
.75609 .30887 L
.75619 .30887 L
.75639 .30888 L
.75659 .30888 L
.75682 .30888 L
.7577 .3089 L
.75851 .30893 L
.76001 .30899 L
.76164 .30905 L
.76208 .30906 L
.76253 .30908 L
.76296 .30908 L
.76336 .30909 L
.76373 .3091 L
.76393 .3091 L
.76412 .3091 L
.76423 .3091 L
.76433 .3091 L
.76439 .3091 L
.76445 .3091 L
.76451 .3091 L
.76456 .3091 L
.76466 .3091 L
.76472 .3091 L
.76477 .3091 L
.76487 .3091 L
.76497 .3091 L
.76508 .3091 L
.76517 .3091 L
.76539 .3091 L
.76559 .3091 L
.76579 .3091 L
.76654 .30909 L
.76734 .30907 L
.76822 .30905 L
.7699 .30901 L
.77064 .309 L
.77145 .30899 L
.77183 .30898 L
.77223 .30898 L
.77262 .30897 L
.77296 .30897 L
Mistroke
.77317 .30897 L
.77336 .30897 L
.77345 .30897 L
.77351 .30897 L
.77356 .30897 L
.77367 .30897 L
.77373 .30897 L
.77378 .30897 L
.77388 .30897 L
.77397 .30897 L
.77407 .30897 L
.77418 .30897 L
.77438 .30897 L
.77456 .30897 L
.77495 .30897 L
.77536 .30898 L
.7761 .30898 L
.77778 .309 L
.77938 .30902 L
.78007 .30903 L
.78083 .30904 L
.78125 .30904 L
.78144 .30904 L
.78164 .30904 L
.78182 .30904 L
.78201 .30904 L
.78212 .30904 L
.78221 .30904 L
.78231 .30904 L
.7824 .30904 L
.78251 .30904 L
.78256 .30904 L
.78262 .30904 L
.78271 .30904 L
.78281 .30904 L
.78287 .30904 L
.78293 .30904 L
.78305 .30904 L
.78316 .30904 L
.78326 .30904 L
.78366 .30904 L
.78388 .30904 L
.78408 .30904 L
.78488 .30904 L
.78561 .30903 L
.78728 .30902 L
.78878 .30901 L
.78919 .30901 L
.78963 .30901 L
.79005 .309 L
Mistroke
.79025 .309 L
.79043 .309 L
.79061 .309 L
.79081 .309 L
.79092 .309 L
.79102 .309 L
.79112 .309 L
.79122 .309 L
.79131 .309 L
.7914 .309 L
.79149 .309 L
.79157 .309 L
.79166 .309 L
.79176 .309 L
.79186 .309 L
.79195 .309 L
.79217 .309 L
.79237 .309 L
.79276 .309 L
.79317 .309 L
.79361 .30901 L
.79518 .30901 L
.79602 .30902 L
.79691 .30902 L
.79777 .30902 L
.79855 .30902 L
.79893 .30902 L
.79912 .30902 L
.79934 .30902 L
.79952 .30903 L
.79962 .30903 L
.79972 .30903 L
.79982 .30903 L
.79991 .30903 L
.79999 .30903 L
.80008 .30903 L
.80018 .30903 L
.80024 .30903 L
.80029 .30903 L
.80038 .30903 L
.80048 .30903 L
.80057 .30903 L
.80066 .30903 L
.80085 .30903 L
.80105 .30902 L
.80124 .30902 L
.80167 .30902 L
.80242 .30902 L
.80314 .30902 L
.8046 .30902 L
Mistroke
.80543 .30902 L
.80622 .30901 L
.80698 .30901 L
.80741 .30901 L
.80761 .30901 L
.8078 .30901 L
.80801 .30901 L
.80819 .30901 L
.80829 .30901 L
.8084 .30901 L
.80846 .30901 L
.80851 .30901 L
.80857 .30901 L
.80862 .30901 L
.80872 .30901 L
.80882 .30901 L
.80888 .30901 L
.80894 .30901 L
.80904 .30901 L
.8091 .30901 L
.80915 .30901 L
.80925 .30901 L
.80949 .30901 L
.8097 .30901 L
.80992 .30901 L
.81031 .30901 L
.81121 .30901 L
.81283 .30902 L
.81364 .30902 L
.81442 .30902 L
.81518 .30902 L
.81587 .30902 L
.81624 .30902 L
.81642 .30902 L
.81662 .30902 L
.81683 .30902 L
.81694 .30902 L
.81705 .30902 L
.81714 .30902 L
.81724 .30902 L
.81734 .30902 L
.81744 .30902 L
.81755 .30902 L
.81761 .30902 L
.81766 .30902 L
.81776 .30902 L
.81787 .30902 L
.81805 .30902 L
.81825 .30902 L
.8187 .30902 L
Mistroke
.81912 .30902 L
.82224 .30902 L
.82305 .30902 L
.82348 .30902 L
.82394 .30902 L
.82438 .30902 L
.82478 .30902 L
.82497 .30902 L
.82518 .30902 L
.82527 .30902 L
.82537 .30902 L
.82546 .30902 L
.82555 .30902 L
.82566 .30902 L
.82575 .30902 L
.82581 .30902 L
.82586 .30902 L
.82592 .30902 L
.82597 .30902 L
.82607 .30902 L
.82617 .30902 L
.82637 .30902 L
.82656 .30902 L
.82676 .30902 L
.82712 .30902 L
.82799 .30902 L
.8288 .30902 L
.83031 .30902 L
.8311 .30902 L
.83194 .30902 L
.83237 .30902 L
.83259 .30902 L
.83284 .30902 L
.83306 .30902 L
.83326 .30902 L
.83347 .30902 L
.83366 .30902 L
.83375 .30902 L
.83385 .30902 L
.83391 .30902 L
.83396 .30902 L
.83406 .30902 L
.83416 .30902 L
.83426 .30902 L
.83434 .30902 L
.83443 .30902 L
.83454 .30902 L
.83464 .30902 L
.83487 .30902 L
.83508 .30902 L
Mistroke
.83528 .30902 L
.83606 .30902 L
.83688 .30902 L
.83836 .30902 L
.83912 .30902 L
.83993 .30902 L
.84033 .30902 L
.8407 .30902 L
.84106 .30902 L
.8414 .30902 L
.8416 .30902 L
.84181 .30902 L
.8419 .30902 L
.842 .30902 L
.84208 .30902 L
.84217 .30902 L
.84223 .30902 L
.84228 .30902 L
.84238 .30902 L
.84248 .30902 L
.84254 .30902 L
.8426 .30902 L
.84269 .30902 L
.84279 .30902 L
.8429 .30902 L
.84299 .30902 L
.84337 .30902 L
.84371 .30902 L
.84447 .30902 L
.84612 .30902 L
.84692 .30902 L
.84765 .30902 L
.84837 .30902 L
.84874 .30902 L
.84914 .30902 L
.84934 .30902 L
.84956 .30902 L
.84976 .30902 L
.84995 .30902 L
.85014 .30902 L
.85025 .30902 L
.85035 .30902 L
.85044 .30902 L
.85052 .30902 L
.85062 .30902 L
.85072 .30902 L
.85081 .30902 L
.85091 .30902 L
.85101 .30902 L
.85111 .30902 L
Mistroke
.85128 .30902 L
.85147 .30902 L
.85189 .30902 L
.85228 .30902 L
.85374 .30902 L
.85541 .30902 L
.85614 .30902 L
.85653 .30902 L
.85695 .30902 L
.85735 .30902 L
.85772 .30902 L
.8579 .30902 L
.85809 .30902 L
.85818 .30902 L
.85827 .30902 L
.85836 .30902 L
.85844 .30902 L
.8585 .30902 L
.85855 .30902 L
.85865 .30902 L
.85871 .30902 L
.85877 .30902 L
.85882 .30902 L
.85887 .30902 L
.85897 .30902 L
.85903 .30902 L
.85908 .30902 L
.85928 .30902 L
.85945 .30902 L
.85964 .30902 L
.86003 .30902 L
.86084 .30902 L
.86158 .30902 L
.86326 .30902 L
.86399 .30902 L
.86478 .30902 L
.86523 .30902 L
.86564 .30902 L
.86584 .30902 L
.86605 .30902 L
.86615 .30902 L
.86625 .30902 L
.86635 .30902 L
.86644 .30902 L
.86654 .30902 L
.86664 .30902 L
.86673 .30902 L
.86683 .30902 L
.86693 .30902 L
.86702 .30902 L
Mistroke
.86711 .30902 L
.8672 .30902 L
.8674 .30902 L
.86762 .30902 L
.86801 .30902 L
.86871 .30902 L
.86948 .30902 L
.87118 .30902 L
.87199 .30902 L
.87273 .30902 L
.8731 .30902 L
.8735 .30902 L
.87369 .30902 L
.8739 .30902 L
.87402 .30902 L
.87412 .30902 L
.87423 .30902 L
.87434 .30902 L
.87443 .30902 L
.87452 .30902 L
.87461 .30902 L
.87469 .30902 L
.87479 .30902 L
.87488 .30902 L
.87497 .30902 L
.87508 .30902 L
.87517 .30902 L
.87527 .30902 L
.87545 .30902 L
.87586 .30902 L
.87628 .30902 L
.87667 .30902 L
.87756 .30902 L
.87917 .30902 L
.87989 .30902 L
.88067 .30902 L
.88111 .30902 L
.88131 .30902 L
.88152 .30902 L
.88171 .30902 L
.88191 .30902 L
.88202 .30902 L
.88212 .30902 L
.88223 .30902 L
.88232 .30902 L
.88241 .30902 L
.88251 .30902 L
.88256 .30902 L
.88261 .30902 L
.88271 .30902 L
Mistroke
.88281 .30902 L
.88291 .30902 L
.88301 .30902 L
.88312 .30902 L
.88332 .30902 L
.88351 .30902 L
.88386 .30902 L
.88466 .30902 L
.88553 .30902 L
.8871 .30902 L
.88793 .30902 L
.88839 .30902 L
.88882 .30902 L
.88923 .30902 L
.88947 .30902 L
.88968 .30902 L
.88986 .30902 L
.88997 .30902 L
.89006 .30902 L
.89016 .30902 L
.89021 .30902 L
.89027 .30902 L
.89036 .30902 L
.89046 .30902 L
.89057 .30902 L
.89066 .30902 L
.89075 .30902 L
.89085 .30902 L
.89106 .30902 L
.89126 .30902 L
.89161 .30902 L
.89199 .30902 L
.89357 .30902 L
.89504 .30902 L
.89587 .30902 L
.89628 .30902 L
.89667 .30902 L
.89701 .30902 L
.89719 .30902 L
.89738 .30902 L
.89759 .30902 L
.89768 .30902 L
.89779 .30902 L
.89788 .30902 L
.89798 .30902 L
.89807 .30902 L
.89815 .30902 L
.89826 .30902 L
.89831 .30902 L
.89836 .30902 L
Mistroke
.89846 .30902 L
.89856 .30902 L
.89867 .30902 L
.89877 .30902 L
.899 .30902 L
.8994 .30902 L
.89979 .30902 L
.90128 .30902 L
.90211 .30902 L
.90289 .30902 L
.90365 .30902 L
.90435 .30902 L
.90472 .30902 L
.9049 .30902 L
.90511 .30902 L
.90531 .30902 L
.9054 .30902 L
.9055 .30902 L
.90556 .30902 L
.90561 .30902 L
.90566 .30902 L
.90572 .30902 L
.90582 .30902 L
.90593 .30902 L
.90603 .30902 L
.90609 .30902 L
.90614 .30902 L
.90625 .30902 L
.90634 .30902 L
.90656 .30902 L
.90679 .30902 L
.90722 .30902 L
.90761 .30902 L
.90928 .30902 L
.91001 .30902 L
.91082 .30902 L
.91119 .30902 L
.91159 .30902 L
.91194 .30902 L
.91232 .30902 L
.91254 .30902 L
.91274 .30902 L
.91294 .30902 L
.91305 .30902 L
.91315 .30902 L
.91324 .30902 L
.91333 .30902 L
.91343 .30902 L
.91354 .30902 L
.91363 .30902 L
Mistroke
.91371 .30902 L
.91381 .30902 L
.91391 .30902 L
.914 .30902 L
.91411 .30902 L
.91433 .30902 L
.91472 .30902 L
.91518 .30902 L
.91561 .30902 L
.91723 .30902 L
.91802 .30902 L
.91885 .30902 L
.91956 .30902 L
.91976 .30902 L
.91996 .30902 L
.92014 .30902 L
.92034 .30902 L
.92055 .30902 L
.92066 .30902 L
.92077 .30902 L
.92087 .30902 L
.92096 .30902 L
.92106 .30902 L
.92116 .30902 L
.92121 .30902 L
.92127 .30902 L
.92133 .30902 L
.92138 .30902 L
.92148 .30902 L
.92159 .30902 L
.92183 .30902 L
.92205 .30902 L
.92243 .30902 L
.92284 .30902 L
.92367 .30902 L
.92537 .30902 L
.92618 .30902 L
.92692 .30902 L
.9273 .30902 L
.9277 .30902 L
.9279 .30902 L
.92809 .30902 L
.9282 .30902 L
.92831 .30902 L
.92836 .30902 L
.92842 .30902 L
.92848 .30902 L
.92853 .30902 L
.92863 .30902 L
.92873 .30902 L
Mistroke
.92883 .30902 L
.92892 .30902 L
.929 .30902 L
.92909 .30902 L
.92927 .30902 L
.92947 .30902 L
.92968 .30902 L
.93005 .30902 L
.93176 .30902 L
.93254 .30902 L
.93337 .30902 L
.93413 .30902 L
.93457 .30902 L
.93477 .30902 L
.93497 .30902 L
.93515 .30902 L
.93534 .30902 L
.93552 .30902 L
.9356 .30902 L
.93568 .30902 L
.93578 .30902 L
.93588 .30902 L
.93597 .30902 L
.93606 .30902 L
.93615 .30902 L
.93625 .30902 L
.93635 .30902 L
.93645 .30902 L
.93666 .30902 L
.93685 .30902 L
.93729 .30902 L
.93808 .30902 L
.93957 .30902 L
.94042 .30902 L
.94122 .30902 L
.94157 .30902 L
.94194 .30902 L
.94213 .30902 L
.94234 .30902 L
.94254 .30902 L
.94271 .30902 L
.94292 .30902 L
.94302 .30902 L
.94308 .30902 L
.94314 .30902 L
.94323 .30902 L
.94333 .30902 L
.94338 .30902 L
.94344 .30902 L
.94354 .30902 L
Mistroke
.94363 .30902 L
.94372 .30902 L
.94381 .30902 L
.94389 .30902 L
.94409 .30902 L
.94428 .30902 L
.9447 .30902 L
.94509 .30902 L
.94596 .30902 L
.9476 .30902 L
.9484 .30902 L
.94913 .30902 L
.94949 .30902 L
.94968 .30902 L
.94989 .30902 L
.95006 .30902 L
.95016 .30902 L
.95026 .30902 L
.95035 .30902 L
.95044 .30902 L
.95052 .30902 L
.9506 .30902 L
.9507 .30902 L
.95079 .30902 L
.95089 .30902 L
.95099 .30902 L
.95108 .30902 L
.95117 .30902 L
.95135 .30902 L
.95154 .30902 L
.95175 .30902 L
.95218 .30902 L
.95299 .30902 L
.95374 .30902 L
.95461 .30902 L
.95541 .30902 L
.95615 .30902 L
.95657 .30902 L
.95694 .30902 L
.95715 .30902 L
.95735 .30902 L
.95746 .30902 L
.95757 .30902 L
.95768 .30902 L
.95773 .30902 L
.9578 .30902 L
.9579 .30902 L
.95796 .30902 L
.95801 .30902 L
.95811 .30902 L
Mistroke
.95822 .30902 L
.95831 .30902 L
.9584 .30902 L
.9586 .30902 L
.9588 .30902 L
.95898 .30902 L
.95939 .30902 L
.96023 .30902 L
.96171 .30902 L
.96256 .30902 L
.96297 .30902 L
.96336 .30902 L
.9637 .30902 L
.96407 .30902 L
.96425 .30902 L
.96445 .30902 L
.96456 .30902 L
.96465 .30902 L
.96475 .30902 L
.96485 .30902 L
.96495 .30902 L
.96505 .30902 L
.96514 .30902 L
.96523 .30902 L
.96533 .30902 L
.96543 .30902 L
.96548 .30902 L
.96554 .30902 L
.96564 .30902 L
.96584 .30902 L
.96603 .30902 L
.96638 .30902 L
.96717 .30902 L
.96804 .30902 L
.9696 .30902 L
.97003 .30902 L
.97049 .30902 L
.97092 .30902 L
.97132 .30902 L
.97152 .30902 L
.97172 .30902 L
.97182 .30902 L
.97192 .30902 L
.972 .30902 L
.9721 .30902 L
.9722 .30902 L
.97225 .30902 L
.97231 .30902 L
.9724 .30902 L
.9725 .30902 L
Mistroke
.97256 .30902 L
.97262 .30902 L
.97268 .30902 L
.97273 .30902 L
.97294 .30902 L
.97312 .30902 L
.9733 .30902 L
.97369 .30902 L
.97448 .30902 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{421.375, 260.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008>0001AB000`400?l00000o`00003ooooooooo
oooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo
003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooo
oooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool0
0?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooooooo
ool@ooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooo
ooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo0ol0003o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0
003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo
00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`
ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLoooo
o`00<?ooool3o`000?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?oo
ool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0
033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomco
oooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooo
oooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool3o`000?oooooo
g?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0013ooooo0_o^k^h3ooooo`;ok^k^6Oooool00ol0003oooooooooo`3o
ooooomcooooo000;ooooo`;o000000[o410@ooooooooooook^k^oeEEEOo^k^koooooonk^k_mEEEGo
k^k^0oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h:ooooo`03o`000?oo
oooooooo0?oooooog?ooool000cooooo00?o0000ooooooooool00_ooool01Oo^k^koEEEEomgMgOmE
EEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00[ooooo
00?o0000ooooooooool0oooooooLooooo`0000?oooooo`000?l000001?l00002ooooo`Go00001?oo
ool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooo
oa0@400:ooooo`03o`000?oooooooooo0?oooooog?ooool000Wooooo00CoA4A4omgMgOoooooo0000
1?ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000000[ooooo00?o0000ooooooooool0oooooooLooooo`002Oooool01?oMgMgo
EEEEooooool00003ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000:ooooo`Co0000oooooooKooooo`002_oo
ool00omgMgOoc<c<o`000003ooooo`;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@00[ooooo00?o0000ooooooooool0oooooooLooooo`002_oo
ool00oo^k^koA4A4o`00000?ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`;o00001Oooool00ol0003oooooooooo`3oooooomcooooo000;ooooo`03ogMgMol0
003ooooo00cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`2]ooooo`03o`000?oooooooooo0?oo
oooo;?ooool002Sooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`2]ooooo`;o
0000ooooool]ooooo`00:?ooool3o`0000Gooooo00?o0000ooooooooool0[Oooool2o`000?oooooo
;Oooool002Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2]ooooo`;o0000oooo
ool]ooooo`00:_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0:7ooooo0_l0000:
ooooo`;o0000ooooool]ooooo`00<?ooool00ol0003oooooooooo`2Qooooo`;o00002_ooool2o`00
0?oooooo;Oooool0033ooooo00?o0000ooooooooool0XOooool2o`0000[ooooo0_l0003oooooobgo
oooo000`ooooo`03o`000?oooooooooo0:7ooooo0_l0000:ooooo`;o0000ooooool]ooooo`00<?oo
ool00ol0003oooooooooo`2Qooooo`;o00002Oooool00ol0003oooooo`00003oooooobgooooo000`
ooooo`?o0000XOooool2o`0000Wooooo00?o0000ooooool00000ooooool]ooooo`00<?ooool00ol0
003oooooooooo`2Qooooo`;o00002Oooool00ol0003oooooo`00000:ooooo`03o`000?oooooooooo
0?oooooo8?ooool0033ooooo00?o0000ooooooooool0XOooool2o`0000Wooooo00?o0000ooooool0
00002Oooool2o`000?oooooo8_ooool0033ooooo00?o0000ooooooooool0XOooool2o`0000Wooooo
00?o0000ooooool000002Oooool2o`000?oooooo8_ooool0033ooooo00?o0000ooooooooool0XOoo
ool2o`0000Wooooo00?o0000ooooool000002Oooool2o`000?oooooo8_ooool0033ooooo00?o0000
ooooooooool0X?ooool00ol0003oooooo`000009ooooo`03o`000?oooooo000000Wooooo0_l0003o
ooooob;ooooo000`ooooo`03o`000?oooooooooo0:3ooooo00?o0000ooooool000002Oooool00ol0
003oooooo`000009ooooo`;o0000oooooolRooooo`00<?ooool00ol0003oooooooooo`2Pooooo`03
o`000?oooooo000000Wooooo00Co0000oooooooooooo00002?ooool2o`000?oooooo8_ooool0033o
oooo00?o0000ooooooooool0X?ooool00ol0003oooooo`000009ooooo`04o`000?ooooooooooo`00
00Sooooo0_l0003oooooob;ooooo000`ooooo`03o`000?oooooooooo0:3ooooo00?o0000ooooool0
00002Oooool01?l0003oooooooooool00008ooooo`;o0000oooooolRooooo`00<?ooool00ol0003o
ooooooooo`2Pooooo`03o`000?oooooo000000Wooooo00Co0000oooooooooooo00002?ooool2o`00
0?oooooo8_ooool0033ooooo00?o0000ooooooooool0X?ooool00ol0003oooooo`000009ooooo`04
o`000?ooooooooooo`0000Sooooo0_l0003oooooob;ooooo000`ooooo`?o0000X?ooool00ol0003o
ooooo`000009ooooo`04o`000?ooooooooooo`0000Sooooo0_l0003oooooob;ooooo000`ooooo`03
o`000?oooooooooo0:3ooooo00?o0000ooooool000002Oooool01?l0003oooooooooool00008oooo
o`;o0000oooooolRooooo`00<?ooool00ol0003oooooooooo`2Eooooo`03o`000?oooooooooo00So
oooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00008ooooo`;o0000oooooolR
ooooo`00<?ooool00ol0003oooooooooo`2Dooooo`;o00002_ooool01?l0003oooooooooool00008
ooooo`04o`000?ooooooooooo`0000Sooooo0_l0003oooooob;ooooo000`ooooo`03o`000?oooooo
oooo09Cooooo0_l0000:ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000
2?ooool00ol0003oooooo`00003oooooob7ooooo000`ooooo`03o`000?oooooooooo09Cooooo0_l0
000:ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002?ooool00ol0003o
ooooo`00003oooooob7ooooo000`ooooo`03o`000?oooooooooo09Cooooo0_l0000:ooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool0003o
ooooob7ooooo000`ooooo`03o`000?oooooooooo09Cooooo0_l0000:ooooo`04o`000?oooooooooo
o`0000Sooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool0003oooooob7ooooo
000`ooooo`03o`000?oooooooooo09Cooooo0_l0000:ooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00001oooool01?l0003oooooooooool0003oooooob7ooooo000`ooooo`03
o`000?oooooooooo09Cooooo00?o0000ooooool000002Oooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00002?ooool2o`000?oooooo5ooo
ool0033ooooo00?o0000ooooooooool0U?ooool00ol0003oooooo`000009ooooo`04o`000?oooooo
ooooo`0000Sooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool00008ooooo`;o
0000oooooolGooooo`00<?ooool3o`0009Cooooo00?o0000ooooool000002Oooool01?l0003ooooo
ooooool00008ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00002?ooool2
o`000?oooooo5oooool0033ooooo00?o0000ooooooooool0U?ooool00ol0003oooooo`000009oooo
o`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?oo
ooooooooo`0000Sooooo0_l0003ooooooaOooooo000`ooooo`03o`000?oooooooooo09?ooooo00Co
0000oooooooooooo00002Oooool01?l0003oooooooooool00007ooooo`05o`000?oooooooooooooo
ool000001oooool01?l0003oooooooooool00008ooooo`;o0000oooooolGooooo`00<?ooool00ol0
003oooooooooo`2Cooooo`04o`000?ooooooooooo`0000Wooooo00Co0000oooooooooooo00001ooo
ool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo00002?ooool2o`000?oo
oooo5oooool0033ooooo00?o0000ooooooooool0Toooool01?l0003oooooooooool00009ooooo`04
o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?oooooo
ooooo`0000Sooooo0_l0003ooooooaOooooo000`ooooo`03o`000?oooooooooo09?ooooo00Co0000
oooooooooooo00002Oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool0
00001oooool01?l0003oooooooooool00008ooooo`;o0000oooooolGooooo`00<?ooool00ol0003o
ooooooooo`2Cooooo`04o`000?ooooooooooo`0000Wooooo00Co0000oooooooooooo00001oooool0
1Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo00001oooool00ol0003ooooo
o`00003ooooooaOooooo000@ooooo`;ok^k^0oooool2onk^kQWooooo00?o0000ooooooooool0Tooo
ool01?l0003oooooooooool00009ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooo
ooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool00000oooooolG
ooooo`002Oooool5o`0000;ooooo00Ook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l0
00002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^2_ooool00ol0003oooooooooo`2Coooo
o`04o`000?ooooooooooo`0000Wooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooo
oooooooo000000Oooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool0003ooooo
oaKooooo0009ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01Oo^k^koEEEEomgMgOmEEEGo
k^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00[ooooo00?o
0000ooooooooool0Toooool01?l0003oooooooooool00009ooooo`04o`000?ooooooooooo`0000Oo
oooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000
oooooooooooo0000oooooolFooooo`0000?oooooo`000?l000001?l00003ooooo`03oiRHV?lQ8B7o
k^k^00Gooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooo
ooooooooool@41002_ooool00ol0003oooooooooo`2Cooooo`04o`000?ooooooooooo`0000Wooooo
00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooo
oooooooo00001oooool01?l0003oooooooooool0003ooooooaKooooo000;ooooo`03oiRHV?lQ8B7o
k^k^00?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`00000:ooooo`03o`000?oooooooooo09?ooooo00Co0000oooooooooooo
00002Oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001oooool0
1?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`000?oooooo5_ooool000cooooo00_o
MgMgofIVI_ooooooooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`00000:ooooo`Co0000T_ooool01?l0003ooooooooo
ool00009ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000007oooo
o`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo0000oooooolFooooo`003Oooool0
0ol0003oooooooooo`02onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@400:ooooo`03o`000?oooooooooo09?ooooo00Co0000oooooooooooo0000
2Oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001oooool01?l0
003oooooooooool00007ooooo`04o`000?ooooooooooo`000?oooooo5_ooool000Wooooo00Go0000
okZj^_ooooooV9RHoa0@400>ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`;o00001Oooool00ol0003oooooooooo`2Cooooo`05o`000?ooooooooooooooool0
00002?ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001oooool0
1?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`000?oooooo5_ooool000Wooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c00<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP02ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0Toooool01Ol0
003ooooooooooooooooo000000Sooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooo
oooooooo000000Oooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool0003ooooo
oaKooooo000Xooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0Toooool01Ol0
003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oo
ooooooooooooool000001oooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`00
0?oooooo5_ooool002Sooooo0ol00005ooooo`03o`000?oooooooooo08Oooooo00?o0000oooooooo
ool02Oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007
ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool00007ooooo`04o`00
0?ooooooooooo`000?oooooo5_ooool002Wooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`27ooooo`;o00002_ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooooooo
ooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool0
0007ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool0ooooool;ooooo`00:_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo08Oooooo0_l0000:ooooo`05o`000?oo
ooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooooooo
ooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00001ooo
ool2o`000?oooooo3Oooool0033ooooo00?o0000ooooooooool0Q_ooool00ol0003oooooo`00000:
ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo
00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooo
oooooooo00001oooool2o`000?oooooo3Oooool0033ooooo00?o0000ooooooooool0Q_ooool00ol0
003oooooo`00000:ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?oo
ooooooooo`0000Oooooo00Co0000oooooooooooo00001oooool2o`000?oooooo3Oooool0033ooooo
00?o0000ooooooooool0Q_ooool00ol0003oooooo`00000:ooooo`05o`000?ooooooooooooooool0
00001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooo
ooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00001ooo
ool2o`000?oooooo3Oooool0033ooooo00?o0000ooooooooool0Q_ooool01?l0003oooooooooool0
0009ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`00
00Oooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00003oooooo`cooooo000`oooo
o`?o0000Q_ooool01?l0003oooooooooool00009ooooo`05o`000?ooooooooooooooool000001ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooooooo
o`000006ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool00007oooo
o`03o`000?oooooo00000?oooooo3?ooool0033ooooo00?o0000ooooooooool0Q_ooool01?l0003o
ooooooooool00009ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?oo
ooooooooooooool000001oooool01?l0003oooooooooool00007ooooo`03o`000?oooooo00000?oo
oooo3?ooool0033ooooo00?o0000ooooooooool0Q_ooool01?l0003oooooooooool00009ooooo`05
o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001_oo
ool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooool00000ooooool<ooooo`00<?oo
ool00ol0003oooooooooo`26ooooo`04o`000?ooooooooooo`0000Wooooo00Go0000oooooooooooo
ooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003o
oooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?oooooo
ooooooooool000001oooool00ol0003oooooo`00003oooooo`cooooo000`ooooo`03o`000?oooooo
oooo08Gooooo00Go0000ooooooooooooooooo`000009ooooo`05o`000?ooooooooooooooool00000
1oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooo
ooooo`000006ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo
000000Oooooo00?o0000ooooool00000ooooool<ooooo`00<?ooool00ol0003oooooooooo`25oooo
o`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooo
ooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000oooooooooooo
ooooo`000007ooooo`03o`000?oooooo00000?oooooo3?ooool0033ooooo00?o0000ooooooooool0
QOooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000006oooo
o`05o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003oooooo`cooooo000`oooo
o`03o`000?oooooooooo08Gooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooo
ooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo
0000ooooool<ooooo`00<?ooool00ol0003oooooooooo`25ooooo`05o`000?ooooooooooooooool0
00002?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000006
ooooo`04o`000?ooooooooooo`000?oooooo3?ooool0033ooooo00?o0000ooooooooool0QOooool0
1Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000006ooooo`05o`00
0?ooooooooooooooool000001_ooool01?l0003oooooooooool0003oooooo`cooooo000`ooooo`03
o`000?oooooooooo08Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo0000
00Kooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`3oooooo`7ooooo000`oooo
o`03o`000?oooooooooo08Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo
000000Kooooo00Co0000oooooooooooo00001oooool2o`000?oooooo0oooool0033ooooo0ol00025
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?oo
ooooooooo`0000Oooooo0_l0003oooooo`?ooooo000`ooooo`03o`000?oooooooooo08Gooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo
00001oooool2o`000?oooooo0oooool0033ooooo00?o0000ooooooooool0QOooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo0000
00Kooooo0_l0003oooooo`?ooooo000`ooooo`03o`000?oooooooooo08Gooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000006
ooooo`03o`000?oooooo00000?oooooo0_ooool0033ooooo00?o0000ooooooooool0N?ooool2o`00
00_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooo00000?oooooo0_ooool0033ooooo00?o0000
ooooooooool0C_ooool2onk^kP?ooooo0_o^k^hSooooo`?o00002_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003ok^k^onk^kP02
ooooo`03o`000?o^k^kok^k^00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooool00000>Oooool2onk^kP?ooooo0_o^k^i>ooooo`;ok^k^0oooool2onk^kVcooooo
000`ooooo`03o`000?oooooooooo04Sooooo00goA4A4o`000?l0003o<S8bomgMgOooooook^k^oeEE
EOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb
<S;ok^k^5?ooool00ol0003oooooo`000009ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooo`000003o`000009oa0@4?l0003ok^k^oeEEEOo^k^koooooo`00
0?mEEEGok^k^00?ooooo1?l000002?l@413o0000ooooooo^k^ko<S8bo`000?lb<S;o00001?ooool0
0ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooo`00
000Sooooo`Co000000?o410@ooooooooool00_ooool2ob4Q8@Gooooo00goA4A4o`000?l0003o<S8b
omgMgOooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413ooooooooo
ooo^k^ko<S8bo`000?lb<S;ok^k^>?ooool5o`0000;ooooo00Ook^k^oeEEEOo^k^koooooonk^k_mE
EEGok^k^00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^GOooool0033o
oooo00?o0000ooooooooool0Boooool02OmgMgOo<S8booooooooooook^k^oeEEEOoMgMgoEEEEonk^
kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Dooooo`03o`00
0?oooooo000000Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`05o`00
0?ooooooooooooooool000000_ooool01ol0003oooooonk^k_mEEEGogMgMo`000?o^k^h01?ooool0
0ol0003oooooo`000002ooooo`07o`000?ooooooMgMgoiRHV?ooooooV9RHo`000004ooooo`03o`00
0?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000005ooooo`04o`000?ooooooooooo`00
02Gooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00WoMgMgoc8b<_ooooooooooonk^k_mE
EEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL0>?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06
ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Mooooo`00<?ooool0
0ol0003oooooooooo`1<ooooo`07o`000?oooooooooooooooooMgMgo0000omgMg@07ooooo`03o`00
0?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Dooooo`03o`000?oooooo000000Wo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003ooooooooooooMgMd2o`0000Gooooo00?o0000ooooool000000_ooool0
0ol0003ooooooa0@4003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool0
1Ol0003ooooooooooooooooo000000Gooooo00Co0000oooooooooooo00009Oooool00ol0003ooooo
ooooo`0?ooooo`07o`000?oooooooooooooooooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo
00;ooooo00Go410@oooooooooooooooooa0@400iooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?ogMgM
o`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100GOoo
ool0033ooooo00?o0000ooooooooool0Boooool02OmgMgOo<S8booooooooooook^k^oeEEEOoMgMgo
EEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Coooo
o`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03
ooooo`05o`000?ooooooooooooooool000000_ooool01ol0003oooooonk^k_mEEEGogMgMo`000?o^
k^h01?ooool00ol0003oooooo`000002ooooo`03o`000?oooooo000000?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001Oooool01?l0
003oooooooooool0000Uooooo`03o`000?oooooooooo00kooooo00WoMgMgoc8b<_ooooooooooonk^
k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000>_ooool00onHV9So8B4Qonk^kP03ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000GOooool0033ooooo00?o0000
ooooooooool0B?ooool03Ol0003o8B4Qo`000?lb<S;oc<c<ooooooo^k^koEEEEonk^k_ooooook^k^
oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000004ooo
ool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0oooool01Ol0003ooooooooooooooooo000000;ooooo00So0000onk^k_mEEEGok^k^ooooool0003o
EEEEonk^kP?ooooo00?o0000ooooool000000_ooool00ol0003oooooo`000003ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Gooooo
00Co0000oooooooooooo00001oooool2o`0001cooooo00?o0000ooooooooool02oooool03Ol0003o
8B4Qo`000?lb<S;oc<c<ooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool00000>oooool02omgMgOoIVIVoooooooooooo
k^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000005gooooo000`ooooo`03o`000?oooooooooo04Sooooo00?o0000oooooooo
ool00oooool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooo
oooooooooa0@400Cooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003ok^k^onk^
kP02ooooo`03o`000?o^k^kok^k^00?ooooo00?o0000ooooool000000_ooool00ol0003ooooooa0@
4003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooo
oooooooo000000Gooooo00Co0000oooooooooooo00001oooool2o`0001cooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`03ooooo`;ok^k^0oooool2onk^kPGooooo00?o0000oooooooo
ool00_ooool01Ol@413ooooooooooooooooo410@03cooooo00?o0000ooooooooool00_o^k^h3oooo
o`;ok^k^1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100GOooool0
033ooooo0ol00018ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooo
oooo000000Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`05o`000?oo
ooooooooooooool000000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooool000000_ooool01ol0003oooooogMgMonHV9SooooooiRHV?l000001?ooool01?l0
003oooooooooooooool3o`0000?ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool0
0007ooooo`;o00007?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo0_l0000^ooooo`05o`00
0?nj^[[ooooooiRHV?l@41003_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02?ooool2o`0005?ooooo000`ooooo`03o`000?oooooooooo04Sooooo1?l0000<ooooo`03
oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00oooool01Ol0003ooooooeEEEOmVIVKo000000;ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?mVIVKo000000;ooooo00Oo0000
ooooooo^k^ko<S8bo`000?lb<S;o000000Cooooo00Co0000oooooooooooo00000_ooool01Ol0003o
oooooooooooooooo000000Gooooo00Co0000oooooooooooo00001_ooool00ol0003oooooo`00000J
ooooo`03oeEEEOmVIVKo000000gooooo1?l0000<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP07ooooo`04o`000?ooooooooooo`0002gooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c00<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP07oooo
o`04o`000?ooooooooooo`0005;ooooo000`ooooo`03o`000?oooooooooo06Kooooo1?l00003oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?l000001Ooooooo0000oooooooooooo
000000?ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00006ooooo`03o`000?oo
oooo000004Sooooo1?l000001Ooooooo0000oooooooooooo000004cooooo1?l000001Ooooooo0000
oooooooooooo000005;ooooo000`ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co00000oooool00ol0003ooooo
ooooo`03ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooool00000COooool3o`0005;o
oooo0ol0001Cooooo`00<?ooool00ol0003oooooooooo`1[ooooo`04o`000?ooooooooooo`0000Oo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool01ol0003ooooooooooooooooo0000ooooool000000oooool0
0ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001Oooool01?l0003ooooooooo
ool0001=ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0D_ooool0033ooooo00?o
0000ooooooooool0JOooool6o`0000Oooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`02ooooo`;o00000oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool00000
1Oooool01?l0003oooooooooool00006ooooo`;o0000A_ooool00ol0003oooooooooo`1Booooo`03
o`000?oooooooooo057ooooo000`ooooo`03o`000?oooooooooo06Sooooo00?o0000ooooool00000
2oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooo
ooooo`000005ooooo`05o`000?ooooooooooooooool000001Oooool01?l0003oooooooooool00006
ooooo`?o0000k_ooool0033ooooo00?o0000ooooooooool0Ioooool01Ol0003ooooooooooooooooo
000000Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooo
ooooooooool000001Oooool01Ol0003ooooooooooooooooo000000Gooooo00Co0000oooooooooooo
00001Oooool01?l0003oooooooooool0002dooooo`03ogMgMomVIVKooooo02gooooo00?oIVIVogMg
Moooool01oooool0033ooooo00?o0000ooooooooool0Ioooool01Ol0003ooooooooooooooooo0000
00Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooooooo
ooooool000001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Co0000
oooooooooooo00001Oooool01?l0003oooooooooool00006ooooo`;o0000Zoooool00ooMgMgo410@
onk^kP0^ooooo`03onk^k_l@413ogMgM00Oooooo000`ooooo`03o`000?oooooooooo06Kooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Gooooo00Go0000oooooooo
ooooooooo`000005ooooo`?o0000V?ooool2o`0000;ooooo0_l0000<ooooo`03oeEEEOnHV9Sooooo
00;o00000_ooool01ol0003oooooooooool0003o410@onk^k_mEEED00_l000000om4A4Co^[Zjoooo
o`02ooooo`05oiRHV?l0003o0000odA4A?nj^[X00_ooool02?o^k^koEEEEo`000?l0003oA4A4okZj
^_oooooo410@1Ol00003ooooo`08oa0@4?lb<S;o0000o`000?l@413oZJVYohN7QomVIVH7ooooo`00
<?ooool00ol0003oooooooooo`1Fooooo`Co00002oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`00
0?ooooooooooooooool000001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000001?ooool01?l0003oooooooooool00005ooooo`Co0000Soooool01_o^k^ko8B4QohN7Qonj
^[[o0000omgMg@cooooo00Go0000ooooooooooooooooo`000002ooooo`0;o`000?ooooooooooo`00
0?ooooooEEEEogMgMoooooook^k^ogMgMol@41000oooool01Ol@413o^[Zjonk^k_mgMgOo410@00;o
oooo00KoEEEEogMgMoooooook^k^ogMgMol@4103ooooo`03o`000?oooooooooo00Cooooo00So0000
ojVYZOoooooooooookZj^_l0003ok^k^o`0000Oooooo003oo`000;Co00003oooool01?oMgMgo0000
oa0@4?o<c<`=ooooo`05oc8b<_ooooooooooooooool000000_ooool01_l0003oooooooooool0003o
ooooo`0000Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Gooooo00Oo^[ZjohN7QomVIVKoIVIVoa0@4?oooooo000000Oooooo000:ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo00Ko00002_ooool2o`0000Oooooo00?o0000ooooooooool01_ooool2o`0000Kooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Ko
oooo00?o0000ooooooooool00oooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool01_l0003oooooooooool0003oooooo`0000Gooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool2o`0000Cooooo
00Co0000oooooooooooo00001?ooool4o`000003ooooool0003ooooo00;ooooo0ol0000<ooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Gooooo`04
onk^k_lQ8B7o410@onk^kPgooooo00Go<S8booooooooooooooooo`000002ooooo`05o`000?oooooo
ooooo`000?ooool01_l00003ooooo`03o`000?oooooooooo00Cooooo1_l00003ooooo`03o`000?oo
oooooooo00Cooooo00So<S8bob4Q8OmgMgOoMgMgohN7Qoo^k^koooooo`0000Oooooo000:ooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo013ooooo00Co0000ooooool0003o00001?ooool00ol0003oooooooooo`07oooo
o`;o00001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooo00001_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`06o`000?ooooooooooo`000?oooooo0000
1Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo0_l00004ooooo`05o`00
0?ooooooooooooooool000001Oooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooo
ooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001Oooool3o`0000[ooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool05oooool01?lQ8B7oMgMgogMgMolb<S8=ooooo`05o`000?o^k^koooooooooool0
00000_o<c<`02ol0003oZJVYomgMgOlQ8B7ooooooeEEEOn7QhOok^k^oooooon7QhOo<S8b00?ooooo
00?o0000ooooooooool01?ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<P?ooooo00?o0000oc8b
<_oMgMd01?ooool02?l0003o^[Zjooooooo^k^koMgMgo`000?o^k^ko00001oooool0033ooooo00?o
0000ooooooooool0Foooool01?l0003oooooooooooooool4o`0000_ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool01Ol0003ooooooooooooooooo000000Gooooo00Go0000ooooooooooooooooo`000004
ooooo`05o`000?ooooooooooooooool000001Oooool01?l0003oooooooooool0000Uooooo`03o`00
0?oooooooooo05_ooooo00?o0000ooooooooool05_ooool2o`0000;ooooo0_l0000<ooooo`0>oeEE
EOmgMgOooooooa0@4?l0003o8B4Qo`000?mgMgOo410@o`000?nYZJWoooooonk^k_mEEED2o`000004
odA4A?o^k^kooooooa0@40Go00000oooool01_o^k^koEEEEo`000?l0003oA4A4onk^kP;ooooo0_l0
00001?nYZJWo8B4Qo`000?lQ8B42ooooo`08ojVYZOlQ8B7o0000o`000?lb<S;o0000ogMgMomEEED7
ooooo`00<?ooool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000oooo
ooooooooooooo`000005ooooo`05o`000?ooooooooooooooool000001Oooool01?l0003ooooooooo
ool00005ooooo`?o0000[oooool00ooMgMgo410@onk^kP0Booooo`03o`000?oooooooooo01Wooooo
00?ok^k^oa0@4?oMgMd01oooool0033ooooo00?o0000ooooooooool0K_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0003ooooooooooooooooo000000Go
oooo00Co0000oooooooooooo00001_ooool2o`000;3ooooo00?oMgMgofIVI_ooool04Oooool00ol0
003oooooooooo`0Iooooo`03ofIVI_mgMgOooooo00Oooooo000`ooooo`03o`000?oooooooooo06ko
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Gooooo00Co0000oooo
oooooooo00001_ooool00ol0003oooooo`00003cooooo`00<?ooool00ol0003oooooooooo`1_oooo
o`05o`000?ooooooooooooooool000002Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00Go0000ooooooooooooooooo`000005ooooo`04o`000?ooooooooooo`0000Kooooo
00?o0000ooooool00000loooool0033ooooo00?o0000ooooooooool0Koooool01Ol0003ooooooooo
oooooooo000000Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`00
0?ooooooooooooooool000001Oooool01?l0003oooooooooool00006ooooo`03o`000?oooooo0000
0??ooooo000`ooooo`03o`000?oooooooooo06oooooo00Go0000ooooooooooooooooo`000009oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo
000000Gooooo00Co0000oooooooooooo00001_ooool3o`000??ooooo000`ooooo`03o`000?oooooo
oooo06oooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00Go0000ooooooooooooooooo`000005ooooo`04o`000?ooooooooooo`0000Oo
oooo00?o0000ooooooooool0l_ooool0033ooooo00?o0000ooooooooool0L?ooool3o`0000[ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool0
00001Oooool01?l0003oooooooooool0003looooo`00<?ooool3o`00077ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooo
ooooooooo`000005ooooo`04o`000?ooooooooooo`000?cooooo000`ooooo`03o`000?oooooooooo
07gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooooooo
ooooool000001Oooool01?l0003oooooooooool0003looooo`00<?ooool00ol0003oooooooooo`1m
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooo
oooo000000Gooooo00Co0000oooooooooooo0000o?ooool0033ooooo00?o0000ooooooooool0O_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooo00000?cooooo000`ooooo`03o`000?oooooooooo07kooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go
0000ooooooooooooooooo`000005ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooo`00003looooo`00<?ooool00ol0003oooooooooo`1nooooo`05o`000?ooooooooooooooool0
00002?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0
003ooooooooooooooooo000000Kooooo0_l0003mooooo`00<?ooool00ol0003oooooooooo`1noooo
o`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooo
ooooooooool000001Oooool01Ol0003ooooooooooooooooo000000Kooooo0_l0003mooooo`00<?oo
ool00ol0003oooooooooo`1nooooo`05o`000?ooooooooooooooool000002?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000006ooooo`05
o`000?ooooooooooooooool000001Oooool01Ol0003ooooooooooooooooo000000Kooooo0_l0003m
ooooo`00<?ooool00ol0003oooooooooo`1nooooo`05o`000?ooooooooooooooool000002?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00
0006ooooo`04o`000?ooooooooooo`0000Kooooo00Co0000oooooooooooo0000ooooool7ooooo`00
<?ooool00ol0003oooooooooo`1nooooo`05o`000?ooooooooooooooool000002?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000006oooo
o`04o`000?ooooooooooo`0000Kooooo00Co0000oooooooooooo0000ooooool7ooooo`00<?ooool0
0ol0003oooooooooo`1oooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003ooooo
ooooool00006ooooo`04o`000?ooooooooooo`000?oooooo1oooool0033ooooo00?o0000oooooooo
ool0Ooooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo00001_oo
ool01?l0003oooooooooool0003oooooo`Oooooo000`ooooo`?o0000Ooooool01?l0003ooooooooo
ool00008ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooo
oooooooooooo000000Kooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00003ooooo
o`Oooooo000`ooooo`03o`000?oooooooooo07oooooo00Co0000oooooooooooo00002Oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000007
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?oo
ooooooooo`0000Oooooo00?o0000ooooool00000ooooool7ooooo`00<?ooool00ol0003ooooooooo
o`1oooooo`03o`000?oooooo000000[ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`05ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?oooooooooooooo
ool000001_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooo00000?oooooo1oooool0
033ooooo00?o0000ooooooooool0Ooooool00ol0003oooooo`00000:ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_oo
ool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo00001oooool00ol0003o
ooooo`00003oooooo`Oooooo000`ooooo`03o`000?oooooooooo07oooooo00?o0000ooooool00000
2_ooool01Ol0003ooooooooooooooooo000000Sooooo00Go0000ooooooooooooooooo`000007oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo
000000Kooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Oooooo
00?o0000ooooool00000ooooool7ooooo`00<?ooool00ol0003oooooooooo`20ooooo`;o00002_oo
ool01Ol0003ooooooooooooooooo000000Sooooo00Go0000ooooooooooooooooo`000007ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000
00Kooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Oooooo00?o
0000ooooool00000ooooool7ooooo`00<?ooool00ol0003oooooooooo`20ooooo`;o00002_ooool0
1Ol0003ooooooooooooooooo000000Sooooo00Go0000ooooooooooooooooo`000007ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Ko
oooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Oooooo0_l0003o
ooooo`Sooooo000`ooooo`03o`000?oooooooooo08cooooo00Go0000ooooooooooooooooo`000008
ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool0
00001_ooool01?l0003oooooooooool00007ooooo`;o0000ooooool8ooooo`00<?ooool00ol0003o
ooooooooo`2<ooooo`05o`000?ooooooooooooooool000002?ooool01Ol0003ooooooooooooooooo
000000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooo
ooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo
00001oooool2o`000?oooooo2?ooool0033ooooo00?o0000ooooooooool0S?ooool01Ol0003ooooo
oooooooooooo000000Sooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000
ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool0
ooooool6ooooo`00<?ooool00ol0003oooooooooo`2<ooooo`05o`000?ooooooooooooooool00000
2?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007oooo
o`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Kooooo00Co
0000oooooooooooo0000oooooolAooooo`00<?ooool00ol0003oooooooooo`2<ooooo`05o`000?oo
ooooooooooooool000002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooooooo
ooooooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooo
oooo000000Kooooo00Co0000oooooooooooo0000oooooolAooooo`00<?ooool3o`0008cooooo00Go
0000ooooooooooooooooo`000008ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003o
oooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?oooooo
ooooooooool000001_ooool01?l0003oooooooooool0003ooooooa7ooooo000`ooooo`03o`000?oo
oooooooo08cooooo00Go0000ooooooooooooooooo`000008ooooo`05o`000?ooooooooooooooool0
00001oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000006
ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool0003ooooooa7ooooo
000`ooooo`03o`000?oooooooooo08cooooo00Go0000ooooooooooooooooo`000008ooooo`05o`00
0?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooo
ooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003ooooooooo
ool0003ooooooa7ooooo000`ooooo`03o`000?oooooooooo08cooooo00Go0000oooooooooooooooo
o`000008ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo0000
00Oooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001ooo
ool00ol0003oooooo`00003ooooooa7ooooo000`ooooo`03o`000?oooooooooo08cooooo00Go0000
ooooooooooooooooo`000008ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooo
oooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?oooooooooo
ooooool000001oooool00ol0003oooooo`00003ooooooa7ooooo000`ooooo`03o`000?oooooooooo
08cooooo00Go0000ooooooooooooooooo`000008ooooo`05o`000?ooooooooooooooool000001ooo
ool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000006ooooo`05
o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003ooooooa7ooooo000?ooooo`;o
k^k^0oooool2onk^kQ[ooooo00?o0000ooooooooool0SOooool01?l0003oooooooooool00008oooo
o`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Go
0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001oooool00ol0003o
ooooo`00003ooooooa7ooooo0008ooooo`Go00000_ooool01oo^k^koEEEEonk^k_ooooook^k^oeEE
EOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`03o`00
0?oooooooooo08gooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo0000
00Oooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001_oo
ool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?oooooo4Oooool000Sooooo00Go
V9RHob4Q8Oo^k^koooooodA4A003ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ol0003oooooooooo`2=oooo
o`04o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oo
ooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooo
oooo00002?ooool00ol0003oooooo`00003ooooooa7ooooo0009ooooo`03oiRHV?lQ8B7ok^k^00Go
oooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooo
ool@41002oooool00ol0003oooooooooo`2=ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000
ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooo
oooooooooooo000000Kooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003ooooo
oa7ooooo000:ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06oooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000;ooooo`03o`000?oooooo
oooo08gooooo00Co0000oooooooooooo00002Oooool01?l0003oooooooooool00007ooooo`05o`00
0?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooo
oooooooo00002?ooool2o`000?oooooo4_ooool000_ooooo00_oMgMgofIVI_ooooooooooonk^k_mE
EEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`00000;ooooo`Co0000S?ooool00ol0003oooooo`00000:ooooo`04o`000?oooooooooo
o`0000Oooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool00000
1_ooool01?l0003oooooooooool00008ooooo`;o0000oooooolBooooo`003?ooool00ol0003ooooo
ooooo`02onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@400;ooooo`03o`000?oooooooooo08gooooo00?o0000ooooool000002_ooool01?l0003o
ooooooooool00007ooooo`05o`000?ooooooooooooooool000002?ooool01?l0003oooooooooool0
0006ooooo`04o`000?ooooooooooo`0000Sooooo0_l0003ooooooa;ooooo0008ooooo`05o`000?nj
^[[ooooooiRHV?l@41003_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool00ol0003oooooooooo`2=ooooo`03o`000?oooooo000000[ooooo00Co0000oooooooo
oooo00002?ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Kooooo00Co
0000oooooooooooo00002?ooool2o`000?oooooo4_ooool000Sooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c00<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`;o
00001_ooool00ol0003oooooooooo`2=ooooo`03o`000?oooooo000000[ooooo00Co0000oooooooo
oooo00002?ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Oooooo00?o
0000ooooool000002?ooool2o`000?oooooo4_ooool002Oooooo00Co0000oooooooooooo00001Ooo
ool00ol0003oooooooooo`2=ooooo`03o`000?oooooo000000[ooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000oooo
ool000002?ooool2o`000?oooooo4_ooool002Oooooo00Co0000oooooooooooo00001Oooool00ol0
003oooooooooo`2=ooooo`03o`000?oooooo000000[ooooo00Co0000oooooooooooo00002?ooool0
1?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool00000
2Oooool00ol0003oooooooooo`3ooooooa3ooooo000Wooooo`?o00001_ooool00ol0003ooooooooo
o`2=ooooo`03o`000?oooooo000000[ooooo00Co0000oooooooooooo00002?ooool01?l0003ooooo
ooooool00008ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool00000oooooolLoooo
o`00:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo08kooooo0_l0000:ooooo`04
o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0
0007ooooo`03o`000?oooooo00000?oooooo7?ooool002Wooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`2>ooooo`03o`000?oooooooooo00Wooooo00Co0000oooooooooooo00002?oo
ool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool0
0000oooooolLooooo`00<?ooool00ol0003oooooooooo`2>ooooo`03o`000?oooooooooo00Wooooo
00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo0000
00Sooooo00?o0000ooooool00000oooooolLooooo`00<?ooool00ol0003oooooooooo`2Jooooo`04
o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`000008
ooooo`03o`000?oooooo00000?oooooo7?ooool0033ooooo00?o0000ooooooooool0V_ooool01?l0
003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool000002?oo
ool00ol0003oooooo`00003ooooooacooooo000`ooooo`?o0000V_ooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool000002?ooool00ol0003ooooo
o`00003ooooooacooooo000`ooooo`03o`000?oooooooooo09[ooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo000000Sooooo00?o0000ooooool0
0000oooooolLooooo`00<?ooool00ol0003oooooooooo`2Jooooo`04o`000?ooooooooooo`0000So
oooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`000008ooooo`03o`000?oooooo0000
0?oooooo7?ooool0033ooooo00?o0000ooooooooool0V_ooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool000002?ooool00ol0003oooooo`00003o
oooooacooooo000`ooooo`03o`000?oooooooooo09[ooooo00Co0000oooooooooooo00002?ooool0
1?l0003oooooooooool00008ooooo`03o`000?oooooo000000Sooooo00?o0000ooooool00000oooo
oolLooooo`00<?ooool00ol0003oooooooooo`2Jooooo`03o`000?oooooo000000Wooooo00Co0000
oooooooooooo00002?ooool00ol0003oooooo`000008ooooo`03o`000?oooooo00000?oooooo7?oo
ool0033ooooo00?o0000ooooooooool0V_ooool00ol0003oooooo`000009ooooo`04o`000?oooooo
ooooo`0000Sooooo00?o0000ooooool000002?ooool00ol0003oooooo`00003ooooooacooooo000`
ooooo`03o`000?oooooooooo09[ooooo00?o0000ooooool000002Oooool01?l0003oooooooooool0
0008ooooo`03o`000?oooooo000000Sooooo00?o0000ooooool00000oooooolLooooo`00<?ooool0
0ol0003oooooooooo`2Jooooo`03o`000?oooooo000000Wooooo00Co0000oooooooooooo00002?oo
ool00ol0003oooooo`000008ooooo`03o`000?oooooo00000?oooooo7?ooool0033ooooo00?o0000
ooooooooool0V_ooool00ol0003oooooo`000009ooooo`04o`000?ooooooooooo`0000Sooooo00?o
0000ooooool000002?ooool00ol0003oooooo`00003ooooooacooooo000`ooooo`03o`000?oooooo
oooo09[ooooo00?o0000ooooool000002Oooool01?l0003oooooooooool00008ooooo`03o`000?oo
oooo000000Wooooo0_l0003ooooooacooooo000`ooooo`03o`000?oooooooooo09[ooooo00?o0000
ooooool000002Oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo000000Wooooo00?o
0000ooooooooool0oooooolKooooo`00<?ooool3o`0009[ooooo00?o0000ooooool000002Oooool0
1?l0003oooooooooool00008ooooo`03o`000?oooooo000000Wooooo00?o0000ooooooooool0oooo
oolKooooo`00<?ooool00ol0003oooooooooo`2Jooooo`03o`000?oooooo000000Wooooo00Co0000
oooooooooooo00002?ooool00ol0003oooooo`000009ooooo`03o`000?oooooooooo0?oooooo6ooo
ool0033ooooo00?o0000ooooooooool0V_ooool00ol0003oooooo`000009ooooo`04o`000?oooooo
ooooo`0000Sooooo00?o0000ooooool00000oooooolWooooo`00<?ooool00ol0003oooooooooo`2J
ooooo`03o`000?oooooo000000Wooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00
003oooooobOooooo000`ooooo`03o`000?oooooooooo09[ooooo00?o0000ooooool000002Oooool0
1?l0003oooooooooool00008ooooo`03o`000?oooooo00000?oooooo9oooool0033ooooo00?o0000
ooooooooool0Voooool2o`0000Wooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00
003oooooobOooooo000`ooooo`03o`000?oooooooooo09_ooooo0_l00009ooooo`04o`000?oooooo
ooooo`0000Sooooo00?o0000ooooool00000oooooolWooooo`00<?ooool00ol0003oooooooooo`2K
ooooo`;o00002Oooool00ol0003oooooo`000009ooooo`03o`000?oooooo00000?oooooo9oooool0
033ooooo00?o0000ooooooooool0Voooool00ol0003oooooooooo`08ooooo`03o`000?oooooo0000
00Wooooo00?o0000ooooool00000oooooolWooooo`00<?ooool00ol0003oooooooooo`2Kooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooool000002Oooool00ol0003oooooo`00003oooooobOo
oooo000`ooooo`03o`000?oooooooooo0:Kooooo00?o0000ooooool000002Oooool00ol0003ooooo
o`00003oooooobOooooo000`ooooo`03o`000?oooooooooo0:Oooooo0_l00009ooooo`03o`000?oo
oooo00000?oooooo9oooool0033ooooo0ol0002Wooooo`;o00002Oooool00ol0003oooooo`00003o
ooooobOooooo000`ooooo`03o`000?oooooooooo0:Oooooo0_l00009ooooo`03o`000?oooooo0000
0?oooooo9oooool0033ooooo00?o0000ooooooooool0Yoooool2o`0000[ooooo00?o0000oooooooo
ool0oooooolVooooo`00<?ooool00ol0003oooooooooo`2Wooooo`;o00002_ooool00ol0003ooooo
ooooo`3oooooobKooooo000`ooooo`03o`000?oooooooooo0:Oooooo0_l0000:ooooo`03o`000?oo
oooooooo0?oooooo9_ooool0033ooooo00?o0000ooooooooool0Yoooool2o`0000[ooooo00?o0000
ooooooooool0oooooolVooooo`003oooool2onk^kP?ooooo0_o^k^hJooooo`03o`000?oooooooooo
0:Oooooo0_l0003ooooooc?ooooo000:ooooo`;o000000[o410@ooooooooooook^k^oeEEEOo^k^ko
ooooonk^k_mEEEGok^k^0oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h;
ooooo`03o`000?oooooooooo0:Oooooo0_l0003ooooooc?ooooo000;ooooo`03o`000?oooooooooo
00;ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0;ooooo`03o`000?oooooooooo0:Oooooo0_l0003ooooooc?ooooo0008
ooooo`Go00001?ooool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@400;ooooo`03o`000?oooooooooo0:Oooooo0_l0003ooooooc?ooooo0008
ooooo`04odA4A?oMgMgoooooo`0000Cooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000;ooooo`03o`000?oooooooooo0?oo
oooog?ooool000Sooooo00CogMgMoeEEEOoooooo00000oooool01oo^k^koEEEEonk^k_ooooook^k^
oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000002ooo
ool4o`000?oooooofoooool000Wooooo00?oMgMgolc<c?l000000oooool2onk^kP?ooooo0_o^k^h5
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400;ooooo`03o`000?oo
oooooooo0?oooooog?ooool000Wooooo00?ok^k^odA4A?l000003oooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ol0003oooooooooo`3oooooomcooooo000:
ooooo`03ogMgMol0003ooooo00cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00?ooooo0_l00006ooooo`03o`000?oooooooooo0?oooooog?ooool002Oooooo00Co0000
oooooooooooo00001Oooool00ol0003oooooooooo`3oooooomcooooo000Wooooo`04o`000?oooooo
ooooo`0000Gooooo00?o0000ooooooooool0oooooooLooooo`009oooool3o`0000Kooooo00?o0000
ooooooooool0oooooooLooooo`00:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?oooooog?ooool002Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooomco
oooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooo
oooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`?o0000oooooooLoooo
o`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooo
g?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0
003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo
0ol0003oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000
ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03
o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?oo
ool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0
033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomco
oooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooo
oooLooooo`00<?ooool3o`000?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLoooo
o`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooo
g?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00oooooooooooooa3ooooo003ooooo
oooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?oo
ool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00:Cooooo
0_l00003ooooo`03okZj^_lb<S;ooooo00Gooooo0_l00005ooooo`03o`000?nj^[[ooooo0?oooooo
E?ooool00:Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00?ooooo0_lb<S;ooooooeGooooo002Aooooo`?o00000_ooool01_lb<S;o410@oooooooo
ooook^k^oeEEE@;o000000?oA4A4okZj^_ooool00oooool01_l0003oooooooooooooooooV9RHoa0@
40;o000000?oZJVYooooooooool00oooool00ol0003oooooooooo`03ooooo`03ohN7Qol0003o^[Zj
00cooooo00GoV9RHo`000?l0003oA4A4okZj^P09ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01Ooo
ool2ob4Q8@?ooooo00Goc<c<onk^k_ooooook^k^olc<c004ooooo`Co000000So410@oooooooooooo
k^k^oc8b<_l0003o<S8bonk^kQ?ooooo00Ko410@oc8b<_l0003o0000oa0@4?nYZJT2ooooo`06onk^
k_mEEEGo0000o`000?m4A4Co^[Zj0oooool01OmVIVKo0000o`000?m4A4Coc<c<0>cooooo002Boooo
o`05o`000?ooooooooooolc<c?l@41000oooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40Cooooo
00[o0000ooooooooooooooooo`000?nYZJWoEEEEoiRHV?mEEEGo^[Zj1?ooool00ol0003ooooooooo
o`03ooooo`03olc<c?l0003o410@00cooooo00Go410@okZj^_o^k^koMgMgoa0@4002ooooo`Ko0000
00Koooooob4Q8OnHV9SooooooiRHV?lQ8B45ooooo`;o8B4Q0oooool01Oo^k^koEEEEomgMgOmEEEGo
k^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01?ooooo00Ko
0000ojVYZOoooooooooookZj^_l00002ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo410@0_ooool0
1_mVIVKoMgMgooooooooooooQhN7oa0@4>cooooo002Booooo`05o`000?oooooooooooeEEEOn7QhL0
0oooool00ol0003oooooooooo`07ooooo`0:o`000?oooooooooooooooolb<S;ok^k^oiRHV?mEEEGo
gMgMoa0@40Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0;ooooo`05o`000?oo
ooooooooooooool000002oooool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo
00Go410@oooooooooooooooooa0@400Dooooo`05okZj^_n7QhOoIVIVofIVI_l@41000_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo0>oooooo002Booooo`05o`000?oooooogMgMo`00
0?o^k^h00oooool6o`0000Cooooo00_o0000oooooooooooooooookZj^_m4A4Coc<c<ob4Q8Ooooooo
410@olc<c003ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01?ooool6o`000006
oooooolb<S;oV9RHoooooonHV9So<S8b2_ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000001?ooooo00Ko<S8bob4Q8OmgMgOo
MgMgohN7Qoo^k^h2ooooo`Ko00000_ooool00ol0003oooooooooo`3_ooooo`00T_ooool3o`000003
oa0@4?nHV9Sooooo00;ooooo00KoEEEEohN7Qoo^k^koooooohN7Qolb<S84ooooo`0;o`000?oooooo
ooooooooooo^k^ko0000ooooool0003oooooofIVI_n7QhL00oooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo00_ooooo00Goc<c<o`000?l0003o0000olc<c00:ooooo`05olc<c?o^k^ko
ooooonk^k_o<c<`01_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
4oooool01_l0003o^[Zjooooooo^k^koMgMgo`0000;ooooo00KoEEEEohN7Qoo^k^koooooohN7Qolb
<S82ooooo`06ofIVI_mgMgOooooooooooon7QhOo0000k?ooool009;ooooo00Go0000oooooooooooo
c<c<o`000003ooooo`06onk^k_mEEEGo0000o`000?m4A4Cok^k^1?ooool02?l0003ooooooooooooo
ooooIVIVoiRHV?oooooo<S8b0_nj^[X01Ol0003ooooooooooooooooo000001;ooooo00?o410@o`00
0?l000000ol0000:ooooo`05oa0@4?nj^[[ooooookZj^_l@41005Oooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@41001oooool3o`0000;ooooo0ol00004ooooo`06ojVYZOlQ
8B7o0000o`000?lb<S;o00000_ooool01_o^k^koEEEEo`000?l0003oA4A4onk^kP;ooooo00Kok^k^
ofIVI_l0003o0000odA4A?l0003/ooooo`00T_ooool01Ol0003oooooooooooo<c<co000000gooooo
00?o0000ooooooooool01?ooool00omVIVKoQhN7ooooo`04ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool02oooool01Ol0003o^[Zjoooooonj^[[o000001Gooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`3oooooo`Kooooo002Aooooo`Co000000?o410@ojVYZOooool03?ooool2o`0000Go
oooo00?oZJVYodA4A?ooool00oooool2o`0001Cooooo00?o0000ooooooooool02oooool01OnYZJWo
410@o`000?l@413oZJVY01?ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00;ooooo1?l00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0ooooool6
ooooo`00ooooool2ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0ooooool6oooo
o`00ooooool2ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0ooooool6ooooo`00
ooooool1ooooo`;o00000oooool2o`000?oooooo2?ooool00?ooooooooooool@ooooo`00oooooooo
oooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo
003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooo
oooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool0
0?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooooooo
ool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00
oooooooooooooa3ooooo0000\
\>"],
  ImageRangeCache->{{{0, 525.688}, {324.5, 0}} -> {-2.58312*^-7, -6.34248*^6, \
6.65005*^-9, 53093.5}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0.309017 5.42214e-08 [
[.32684 .29652 -16.5 -12.5 ]
[.32684 .29652 16.5 0 ]
[.54329 .29652 -16.5 -12.5 ]
[.54329 .29652 16.5 0 ]
[.75974 .29652 -22.5 -12.5 ]
[.75974 .29652 22.5 0 ]
[.97619 .29652 -16.5 -12.5 ]
[.97619 .29652 16.5 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 64 6 ]
[.09789 .09213 -34.5 -6.25 ]
[.09789 .09213 0 6.25 ]
[.09789 .20057 -34.5 -6.25 ]
[.09789 .20057 0 6.25 ]
[.09789 .41746 -28.5 -6.25 ]
[.09789 .41746 0 6.25 ]
[.09789 .5259 -28.5 -6.25 ]
[.09789 .5259 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -62.8125 0 ]
[.5 .63053 62.8125 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 .30902 m
.32684 .31527 L
s
gsave
.32684 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 .30902 m
.54329 .31527 L
s
gsave
.54329 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 .30902 m
.75974 .31527 L
s
gsave
.75974 .29652 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 .30902 m
.15368 .31277 L
s
.19697 .30902 m
.19697 .31277 L
s
.24026 .30902 m
.24026 .31277 L
s
.28355 .30902 m
.28355 .31277 L
s
.37013 .30902 m
.37013 .31277 L
s
.41342 .30902 m
.41342 .31277 L
s
.45671 .30902 m
.45671 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.58658 .30902 m
.58658 .31277 L
s
.62987 .30902 m
.62987 .31277 L
s
.67316 .30902 m
.67316 .31277 L
s
.71645 .30902 m
.71645 .31277 L
s
.80303 .30902 m
.80303 .31277 L
s
.84632 .30902 m
.84632 .31277 L
s
.88961 .30902 m
.88961 .31277 L
s
.9329 .30902 m
.9329 .31277 L
s
.0671 .30902 m
.0671 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09213 m
.11664 .09213 L
s
gsave
.09789 .09213 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .20057 m
.11664 .20057 L
s
gsave
.09789 .20057 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .41746 m
.11664 .41746 L
s
gsave
.09789 .41746 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .5259 m
.11664 .5259 L
s
gsave
.09789 .5259 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.11039 .11924 m
.11414 .11924 L
s
.11039 .14635 m
.11414 .14635 L
s
.11039 .17346 m
.11414 .17346 L
s
.11039 .22768 m
.11414 .22768 L
s
.11039 .2548 m
.11414 .2548 L
s
.11039 .28191 m
.11414 .28191 L
s
.11039 .33613 m
.11414 .33613 L
s
.11039 .36324 m
.11414 .36324 L
s
.11039 .39035 m
.11414 .39035 L
s
.11039 .44457 m
.11414 .44457 L
s
.11039 .47168 m
.11414 .47168 L
s
.11039 .49879 m
.11414 .49879 L
s
.11039 .06502 m
.11414 .06502 L
s
.11039 .03791 m
.11414 .03791 L
s
.11039 .0108 m
.11414 .0108 L
s
.11039 .55301 m
.11414 .55301 L
s
.11039 .58012 m
.11414 .58012 L
s
.11039 .60723 m
.11414 .60723 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -123.812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.812 moveto
(@) show
81.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.812 moveto
(D) show
93.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8.2) show
135.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
141.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
153.000 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
157.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
166.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
184.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02532 .30902 L
.02691 .30902 L
.02866 .30902 L
.03029 .30902 L
.03335 .30902 L
.03499 .30902 L
.03648 .30902 L
.03814 .30902 L
.03968 .30902 L
.04277 .30902 L
.04592 .30902 L
.04896 .30902 L
.0522 .30902 L
.05531 .30902 L
.05862 .30902 L
.0618 .30902 L
.06487 .30902 L
.06813 .30902 L
.07127 .30902 L
.07461 .30902 L
.07783 .30902 L
.08092 .30902 L
.08421 .30902 L
.08585 .30902 L
.08738 .30902 L
.08813 .30902 L
.08895 .30902 L
.08967 .30902 L
.09043 .30902 L
.09083 .30902 L
.09106 .30902 L
.09128 .30902 L
.09137 .30902 L
.09147 .30902 L
.09156 .30902 L
.09166 .30902 L
.09176 .30902 L
.09181 .30902 L
.09187 .30902 L
.09197 .30902 L
.09206 .30902 L
.09215 .30902 L
.09224 .30902 L
.09234 .30902 L
.09243 .30902 L
.0926 .30902 L
.09278 .30902 L
.09318 .30902 L
.09355 .30902 L
Mistroke
.09394 .30902 L
.09434 .30902 L
.09508 .30902 L
.09595 .30902 L
.09674 .30902 L
.09829 .30902 L
.09916 .30902 L
.09996 .30902 L
.10148 .30902 L
.10314 .30902 L
.10471 .30902 L
.10639 .30902 L
.10809 .30902 L
.10971 .30902 L
.11279 .30902 L
.11438 .30902 L
.11607 .30902 L
.1191 .30902 L
.12234 .30902 L
.12544 .30902 L
.12875 .30902 L
.13194 .30902 L
.135 .30902 L
.13826 .30902 L
.1414 .30902 L
.14311 .30902 L
.1439 .30902 L
.14433 .30902 L
.14473 .30902 L
.14513 .30902 L
.1455 .30902 L
.14571 .30902 L
.14591 .30902 L
.14601 .30902 L
.14611 .30902 L
.14617 .30902 L
.14623 .30902 L
.14628 .30902 L
.14634 .30902 L
.14643 .30902 L
.14653 .30902 L
.14662 .30902 L
.14671 .30902 L
.14681 .30902 L
.1469 .30902 L
.14701 .30902 L
.14711 .30902 L
.14745 .30902 L
.14764 .30902 L
.14782 .30902 L
Mistroke
.1482 .30902 L
.1486 .30902 L
.14933 .30902 L
.15019 .30902 L
.15098 .30902 L
.15251 .30902 L
.15337 .30902 L
.15417 .30902 L
.15582 .30902 L
.15732 .30902 L
.15886 .30902 L
.16053 .30902 L
.16383 .30902 L
.167 .30902 L
.17005 .30902 L
.17329 .30902 L
.17642 .30902 L
.17974 .30902 L
.1814 .30902 L
.18294 .30902 L
.18371 .30902 L
.18443 .30902 L
.18519 .30902 L
.18559 .30902 L
.18581 .30902 L
.18602 .30902 L
.18612 .30902 L
.18622 .30902 L
.1863 .30902 L
.1864 .30902 L
.1865 .30902 L
.18655 .30902 L
.18661 .30902 L
.18671 .30902 L
.1868 .30902 L
.1869 .30902 L
.18699 .30902 L
.18716 .30902 L
.18734 .30902 L
.18754 .30902 L
.18796 .30902 L
.18819 .30902 L
.1884 .30902 L
.1892 .30902 L
.18959 .30902 L
.19001 .30902 L
.19075 .30902 L
.19155 .30902 L
.19242 .30902 L
.19399 .30902 L
Mistroke
.19567 .30902 L
.19738 .30902 L
.199 .30902 L
.20208 .30902 L
.20536 .30902 L
.20852 .30901 L
.21155 .30901 L
.21479 .30901 L
.21627 .30901 L
.21706 .30901 L
.2179 .30901 L
.21836 .30901 L
.21878 .30901 L
.21898 .30901 L
.2192 .30901 L
.2193 .30901 L
.2194 .30901 L
.2195 .30901 L
.21959 .30901 L
.21969 .30901 L
.21978 .30901 L
.21988 .30901 L
.21994 .30901 L
.21999 .30901 L
.22008 .30901 L
.22017 .30901 L
.22027 .30901 L
.22036 .30901 L
.22046 .30901 L
.22057 .30901 L
.22077 .30901 L
.22098 .30901 L
.2212 .30901 L
.22163 .30901 L
.22203 .30901 L
.22278 .30901 L
.22358 .30901 L
.22446 .30901 L
.22605 .30901 L
.22774 .30901 L
.22931 .30902 L
.23078 .30902 L
.2339 .30902 L
.23721 .30903 L
.2404 .30904 L
.24347 .30905 L
.24518 .30905 L
.24599 .30905 L
.24674 .30905 L
.24751 .30906 L
Mistroke
.24792 .30906 L
.24813 .30906 L
.24836 .30906 L
.24855 .30906 L
.24873 .30906 L
.24882 .30906 L
.24891 .30906 L
.249 .30906 L
.24908 .30906 L
.24918 .30906 L
.24927 .30906 L
.24936 .30906 L
.24947 .30906 L
.24957 .30906 L
.24968 .30906 L
.24988 .30906 L
.25009 .30906 L
.25028 .30906 L
.25065 .30906 L
.25104 .30906 L
.25147 .30905 L
.25223 .30905 L
.25294 .30905 L
.25445 .30905 L
.25531 .30904 L
.25611 .30904 L
.25923 .30901 L
.26093 .30899 L
.26254 .30897 L
.26562 .30893 L
.26889 .30888 L
.27051 .30886 L
.27203 .30884 L
.27274 .30883 L
.27349 .30883 L
.27388 .30882 L
.27409 .30882 L
.27431 .30882 L
.27451 .30882 L
.2747 .30882 L
.27479 .30882 L
.27489 .30882 L
.27498 .30882 L
.27506 .30882 L
.27516 .30882 L
.27525 .30882 L
.27535 .30882 L
.27545 .30882 L
.27554 .30882 L
.27564 .30882 L
Mistroke
.27574 .30882 L
.27582 .30882 L
.27603 .30882 L
.27625 .30882 L
.27646 .30882 L
.27665 .30882 L
.27705 .30883 L
.27747 .30883 L
.27834 .30884 L
.27916 .30885 L
.27991 .30886 L
.28159 .30891 L
.28312 .30896 L
.28479 .30903 L
.28806 .30921 L
.29121 .3094 L
.29424 .30959 L
.2958 .30966 L
.2966 .3097 L
.29702 .30971 L
.29747 .30972 L
.29791 .30973 L
.2983 .30974 L
.2985 .30974 L
.2987 .30975 L
.2989 .30975 L
.29908 .30975 L
.29918 .30975 L
.29928 .30975 L
.29938 .30975 L
.29947 .30975 L
.29958 .30975 L
.29964 .30975 L
.29969 .30975 L
.29979 .30975 L
.2999 .30975 L
.30002 .30975 L
.30014 .30975 L
.30036 .30974 L
.30077 .30974 L
.30117 .30973 L
.30154 .30972 L
.30238 .30968 L
.3032 .30963 L
.30407 .30957 L
.30578 .30939 L
.30739 .30917 L
.31048 .30863 L
.31375 .30794 L
.31538 .3076 L
Mistroke
.31691 .30731 L
.31847 .30707 L
.31923 .30697 L
.31995 .3069 L
.32032 .30687 L
.32072 .30685 L
.32095 .30684 L
.32117 .30683 L
.32136 .30682 L
.32147 .30682 L
.32157 .30682 L
.32166 .30682 L
.32175 .30682 L
.32183 .30682 L
.32191 .30682 L
.32201 .30682 L
.32211 .30682 L
.3222 .30682 L
.32229 .30683 L
.32247 .30683 L
.32266 .30684 L
.32306 .30686 L
.32345 .30689 L
.32387 .30693 L
.32461 .30703 L
.32541 .30718 L
.32628 .30738 L
.32785 .30787 L
.32954 .30855 L
.33286 .3103 L
.33607 .31218 L
.33754 .31299 L
.33916 .31374 L
.33993 .31402 L
.34075 .31426 L
.34121 .31437 L
.34162 .31444 L
.34182 .31447 L
.34204 .31449 L
.34214 .3145 L
.34225 .31451 L
.34235 .31451 L
.34244 .31452 L
.34254 .31452 L
.34259 .31452 L
.34265 .31452 L
.34271 .31453 L
.34276 .31453 L
.34287 .31452 L
.34297 .31452 L
Mistroke
.34306 .31452 L
.34316 .31451 L
.34327 .31451 L
.34349 .31449 L
.34369 .31446 L
.34392 .31443 L
.34416 .31438 L
.34457 .31429 L
.345 .31415 L
.34578 .31385 L
.34655 .31344 L
.34737 .31291 L
.34884 .31168 L
.35217 .30782 L
.35538 .30335 L
.35847 .29946 L
.3593 .29865 L
.36007 .29803 L
.36088 .29754 L
.3613 .29734 L
.36153 .29727 L
.36176 .2972 L
.36188 .29717 L
.36198 .29715 L
.36209 .29713 L
.36218 .29712 L
.36228 .29711 L
.36237 .2971 L
.36247 .2971 L
.36252 .2971 L
.36258 .2971 L
.36263 .2971 L
.36269 .2971 L
.36275 .29711 L
.3628 .29711 L
.3629 .29712 L
.363 .29714 L
.36322 .29718 L
.36346 .29724 L
.36386 .2974 L
.3643 .29763 L
.36508 .29821 L
.36589 .29906 L
.36677 .30026 L
.36839 .30315 L
.37165 .31129 L
.37479 .32043 L
.37639 .32476 L
.37723 .32676 L
.37813 .32859 L
Mistroke
.37892 .32993 L
.37935 .3305 L
.3798 .331 L
.38022 .33136 L
.3806 .33159 L
.38078 .33167 L
.38088 .33171 L
.38098 .33173 L
.38107 .33175 L
.38117 .33177 L
.38126 .33178 L
.38134 .33178 L
.38144 .33177 L
.38154 .33176 L
.38163 .33175 L
.38172 .33173 L
.38182 .3317 L
.38193 .33165 L
.38213 .33156 L
.38234 .33142 L
.38256 .33125 L
.38296 .33084 L
.38367 .32984 L
.38445 .3283 L
.38526 .32621 L
.38601 .32389 L
.38768 .31735 L
.39087 .30126 L
.39394 .28492 L
.39566 .27738 L
.39647 .27456 L
.39721 .27251 L
.39758 .27169 L
.39799 .27097 L
.3984 .27043 L
.39862 .27022 L
.39872 .27015 L
.39883 .27008 L
.39893 .27003 L
.39903 .27 L
.39912 .26998 L
.39922 .26997 L
.3993 .26997 L
.39938 .26997 L
.39947 .26999 L
.39957 .27002 L
.39966 .27007 L
.39977 .27013 L
.39998 .27029 L
.40017 .2705 L
Mistroke
.40036 .27074 L
.40076 .27143 L
.4012 .27242 L
.402 .2749 L
.40278 .27812 L
.40349 .28178 L
.40666 .30463 L
.4097 .33224 L
.4114 .34693 L
.41295 .35818 L
.41371 .36261 L
.41412 .36458 L
.41455 .36637 L
.41492 .36766 L
.41534 .36877 L
.41552 .36915 L
.41571 .36949 L
.4159 .36973 L
.41607 .3699 L
.41617 .36997 L
.41627 .37001 L
.41635 .37004 L
.41645 .37005 L
.41655 .37003 L
.4166 .37002 L
.41666 .37 L
.41676 .36994 L
.41685 .36986 L
.41704 .36966 L
.4172 .36942 L
.41758 .36863 L
.41799 .36742 L
.41843 .36568 L
.41924 .3614 L
.42007 .35554 L
.42082 .34902 L
.42251 .33073 L
.42573 .28695 L
.42882 .24633 L
.42965 .23778 L
.43042 .23118 L
.43123 .22594 L
.43166 .2239 L
.43188 .22306 L
.43211 .22234 L
.43231 .22185 L
.43242 .22165 L
.43254 .22147 L
.43264 .22134 L
.43274 .22126 L
Mistroke
.43283 .22121 L
.43293 .22119 L
.43299 .22119 L
.43304 .2212 L
.4331 .22122 L
.43315 .22125 L
.43325 .22133 L
.43335 .22146 L
.43347 .22164 L
.4336 .22188 L
.43382 .22244 L
.43422 .22387 L
.43459 .22569 L
.43543 .23158 L
.43627 .23971 L
.43706 .24943 L
.43855 .27228 L
.44162 .33155 L
.44334 .36562 L
.44489 .39273 L
.44567 .40402 L
.44651 .41396 L
.4469 .41764 L
.44731 .42087 L
.44766 .42307 L
.44804 .42487 L
.44824 .42555 L
.44835 .42584 L
.44846 .42609 L
.44856 .42625 L
.44861 .42632 L
.44867 .42638 L
.44877 .42646 L
.44886 .42648 L
.44895 .42646 L
.44906 .42639 L
.44916 .42628 L
.44925 .42613 L
.44942 .42575 L
.44961 .42518 L
.44982 .42429 L
.45006 .42307 L
.45049 .42018 L
.4509 .41653 L
.45129 .41245 L
.4528 .38999 L
.45446 .35521 L
.4577 .27041 L
.45919 .2318 L
.46082 .19629 L
Mistroke
.46171 .18139 L
.46209 .17604 L
.46252 .17107 L
.46293 .16734 L
.46331 .1647 L
.46352 .16361 L
.46371 .16285 L
.46381 .16255 L
.46392 .16228 L
.46397 .16217 L
.46403 .16208 L
.46409 .16202 L
.46414 .16197 L
.46423 .16194 L
.46432 .16195 L
.46442 .16203 L
.46453 .16218 L
.46458 .16229 L
.46464 .16242 L
.46474 .16271 L
.46494 .16346 L
.46513 .16439 L
.46532 .16562 L
.46568 .16846 L
.46613 .17321 L
.46655 .17884 L
.46735 .19224 L
.46896 .22992 L
.47044 .27412 L
.47362 .37965 L
.47521 .42667 L
.47591 .44378 L
.47667 .45929 L
.47709 .46631 L
.47747 .47175 L
.47787 .47619 L
.47824 .47931 L
.47842 .4805 L
.47862 .48147 L
.47873 .48187 L
.47879 .48205 L
.47885 .48219 L
.47894 .48238 L
.479 .48245 L
.47905 .48251 L
.47911 .48254 L
.47916 .48254 L
.47922 .48252 L
.47928 .48246 L
.47939 .4823 L
Mistroke
.47945 .48217 L
.4795 .48202 L
.4797 .48129 L
.47981 .48075 L
.47991 .48016 L
.4803 .47721 L
.48071 .47278 L
.48144 .46157 L
.48223 .44506 L
.48311 .42194 L
.48633 .30605 L
.48943 .18898 L
.49026 .16387 L
.49104 .1445 L
.49185 .12911 L
.49227 .12315 L
.4925 .12069 L
.49273 .11856 L
.49293 .11713 L
.49304 .11652 L
.49316 .11598 L
.49326 .1156 L
.49336 .11535 L
.49346 .11518 L
.49355 .1151 L
.49361 .11509 L
.49366 .11511 L
.49372 .11517 L
.49377 .11524 L
.49387 .11545 L
.49393 .11561 L
.49398 .11578 L
.4942 .11684 L
.49432 .11755 L
.49444 .11848 L
.49485 .12246 L
.49528 .12839 L
.49606 .14332 L
.49688 .1644 L
.49776 .19294 L
.49938 .25631 L
.50265 .39956 L
.50344 .43015 L
.50428 .45916 L
.50501 .48009 L
.50542 .49 L
.5058 .49785 L
.50621 .50458 L
.50657 .50932 L
.50678 .51134 L
Mistroke
.50697 .51287 L
.50717 .51408 L
.50728 .51458 L
.50739 .51492 L
.50747 .5151 L
.50756 .51522 L
.50764 .51526 L
.50772 .51522 L
.50781 .5151 L
.50791 .51487 L
.508 .51456 L
.50809 .51419 L
.50828 .5131 L
.50845 .51179 L
.50884 .50774 L
.50923 .50203 L
.50964 .49433 L
.51038 .47644 L
.51206 .41928 L
.51511 .28 L
.51681 .20324 L
.51836 .1467 L
.51913 .12579 L
.51953 .11705 L
.51996 .10963 L
.52034 .10477 L
.52055 .10269 L
.52075 .10121 L
.52084 .10069 L
.52094 .10024 L
.52102 .09994 L
.52111 .09969 L
.5212 .09952 L
.5213 .09945 L
.5214 .09949 L
.52148 .09961 L
.52158 .09985 L
.52167 .10017 L
.52177 .10062 L
.52188 .10123 L
.52209 .10286 L
.52229 .1048 L
.52267 .10975 L
.52303 .11589 L
.52383 .1343 L
.5247 .16122 L
.52797 .30488 L
.52959 .38238 L
.53112 .44539 L
.53183 .46901 L
Mistroke
.53258 .48896 L
.53297 .49716 L
.53339 .50426 L
.53358 .50674 L
.53378 .50896 L
.53396 .51049 L
.53415 .51178 L
.53425 .51233 L
.53435 .51272 L
.53446 .513 L
.53452 .51311 L
.53457 .51317 L
.53467 .51319 L
.53478 .51309 L
.53488 .51287 L
.53497 .51257 L
.53508 .51206 L
.53519 .51142 L
.5354 .50987 L
.53562 .50767 L
.53586 .50467 L
.53627 .49806 L
.5367 .48913 L
.53748 .46848 L
.53905 .41083 L
.54053 .34448 L
.54365 .20252 L
.54447 .17289 L
.54536 .147 L
.54576 .13767 L
.5462 .12963 L
.54656 .12437 L
.54677 .12204 L
.54697 .12031 L
.54707 .11963 L
.54717 .11902 L
.54725 .11859 L
.54735 .11822 L
.54741 .11804 L
.54746 .11791 L
.54757 .11775 L
.54766 .11771 L
.54776 .11778 L
.54786 .11797 L
.54797 .11829 L
.54807 .11871 L
.54816 .11919 L
.54838 .12076 L
.54859 .12277 L
.54896 .12744 L
Mistroke
.5493 .13307 L
.55008 .1502 L
.55093 .17537 L
.55173 .20408 L
.55323 .26671 L
.55633 .40009 L
.55716 .42887 L
.55793 .45082 L
.55874 .46787 L
.55917 .47426 L
.55941 .47701 L
.55962 .47898 L
.55981 .48026 L
.55991 .48082 L
.56001 .48123 L
.56011 .48156 L
.56021 .48176 L
.56026 .48183 L
.56032 .48187 L
.56042 .48185 L
.56052 .48173 L
.56061 .48153 L
.56071 .4812 L
.5608 .48079 L
.56098 .47981 L
.56116 .47841 L
.56158 .47387 L
.56203 .46711 L
.56283 .45031 L
.56359 .42932 L
.5644 .40234 L
.56587 .34577 L
.56746 .28117 L
.5683 .24906 L
.56919 .21851 L
.56998 .1957 L
.5704 .18552 L
.57085 .17622 L
.57127 .16932 L
.57165 .1644 L
.57201 .16099 L
.57219 .15977 L
.57229 .15925 L
.57239 .1588 L
.5725 .15844 L
.5726 .15822 L
.5727 .15807 L
.57276 .15804 L
.57282 .15804 L
.57292 .15813 L
Mistroke
.57301 .15829 L
.57306 .15841 L
.57311 .15858 L
.57322 .15895 L
.5734 .15992 L
.5736 .16133 L
.57397 .16481 L
.57442 .17089 L
.57485 .17825 L
.57565 .1959 L
.57726 .24383 L
.57874 .29603 L
.58039 .35335 L
.58119 .3782 L
.58192 .39784 L
.58262 .41348 L
.58339 .42619 L
.5836 .42877 L
.58381 .43111 L
.58401 .43293 L
.5842 .43431 L
.58438 .43533 L
.58447 .43575 L
.58457 .43612 L
.58467 .43642 L
.58472 .43654 L
.58478 .43663 L
.58487 .43674 L
.58497 .43676 L
.58507 .4367 L
.58512 .43663 L
.58518 .43654 L
.58528 .43629 L
.5854 .4359 L
.5856 .43492 L
.58579 .43372 L
.58625 .42957 L
.58668 .4241 L
.58746 .41091 L
.5883 .39221 L
.59157 .29711 L
.5932 .25224 L
.59399 .23436 L
.59472 .22122 L
.59543 .21185 L
.59579 .2085 L
.59599 .20702 L
.59618 .2059 L
.59628 .20543 L
.59638 .20499 L
Mistroke
.59647 .2047 L
.59657 .20444 L
.59668 .20424 L
.59673 .20417 L
.59679 .20413 L
.59689 .2041 L
.59699 .20415 L
.59709 .20427 L
.59719 .20448 L
.59729 .20476 L
.59739 .20508 L
.59756 .20585 L
.59775 .20692 L
.59818 .21031 L
.59857 .21452 L
.59947 .22757 L
.60109 .26106 L
.60273 .30182 L
.60426 .33908 L
.60573 .36837 L
.60615 .37498 L
.60655 .38034 L
.60694 .38466 L
.60731 .3879 L
.60767 .39035 L
.60787 .39131 L
.60797 .39172 L
.60808 .39208 L
.60819 .39237 L
.60829 .39257 L
.60835 .39266 L
.6084 .39271 L
.60846 .39276 L
.60851 .39279 L
.60861 .39279 L
.6087 .39274 L
.6088 .39262 L
.6089 .39243 L
.609 .39222 L
.60908 .39197 L
.60927 .39127 L
.60961 .38947 L
.61001 .38653 L
.61038 .38295 L
.61116 .37344 L
.61198 .36057 L
.61345 .33265 L
.61506 .30012 L
.61591 .28419 L
.6168 .26943 L
Mistroke
.6176 .25861 L
.61802 .25398 L
.61848 .24995 L
.61889 .24713 L
.61909 .24609 L
.61927 .24531 L
.61946 .24469 L
.61955 .24444 L
.61966 .24422 L
.61975 .24407 L
.61983 .24396 L
.61992 .24389 L
.62002 .24386 L
.62007 .24387 L
.62012 .24388 L
.62022 .24395 L
.62033 .24408 L
.62038 .24417 L
.62044 .24427 L
.62063 .24474 L
.62083 .24542 L
.62105 .24638 L
.62125 .24747 L
.62171 .25064 L
.62249 .25792 L
.62333 .26803 L
.62664 .3189 L
.62745 .33044 L
.6283 .34105 L
.62903 .34835 L
.62945 .35172 L
.62984 .35423 L
.63021 .3561 L
.6304 .35683 L
.6306 .35748 L
.63081 .35796 L
.63092 .35816 L
.63103 .35829 L
.63113 .35838 L
.63123 .35843 L
.63133 .35843 L
.63143 .3584 L
.63151 .35834 L
.6316 .35825 L
.63169 .35813 L
.63177 .358 L
.63196 .35757 L
.63215 .35703 L
.63252 .35559 L
.63292 .35349 L
Mistroke
.63374 .34752 L
.6345 .34052 L
.63618 .32132 L
.63786 .30118 L
.63859 .29319 L
.6394 .28557 L
.64018 .27967 L
.64055 .27742 L
.6409 .27567 L
.6411 .27486 L
.64131 .27412 L
.64148 .2736 L
.64167 .27314 L
.64188 .27277 L
.64199 .27262 L
.64205 .27257 L
.6421 .27252 L
.6422 .27246 L
.64229 .27242 L
.64239 .27242 L
.64244 .27243 L
.6425 .27244 L
.6426 .2725 L
.64265 .27254 L
.64271 .27259 L
.6429 .27285 L
.64301 .27304 L
.64313 .27329 L
.64334 .27383 L
.64376 .27525 L
.64414 .27694 L
.64491 .28135 L
.64563 .28659 L
.6487 .3136 L
.65029 .32568 L
.65074 .32842 L
.65117 .33061 L
.65155 .33225 L
.65197 .33367 L
.65217 .3342 L
.65238 .33467 L
.65258 .33502 L
.65276 .33525 L
.65287 .33536 L
.65296 .33543 L
.65302 .33546 L
.65307 .33549 L
.65313 .33551 L
.65319 .33552 L
.65329 .33552 L
Mistroke
.65338 .3355 L
.65343 .33548 L
.65349 .33546 L
.65359 .33539 L
.65369 .3353 L
.65379 .3352 L
.65396 .33495 L
.65415 .33461 L
.65436 .33416 L
.65507 .33194 L
.65584 .32861 L
.65667 .32403 L
.65837 .31315 L
.66006 .30238 L
.66087 .29807 L
.66161 .29481 L
.66238 .29231 L
.66278 .29137 L
.66299 .29101 L
.66321 .29068 L
.66331 .29057 L
.66341 .29047 L
.6635 .2904 L
.66359 .29034 L
.66369 .29028 L
.66378 .29025 L
.66384 .29024 L
.6639 .29023 L
.664 .29023 L
.66409 .29024 L
.66418 .29027 L
.66426 .29031 L
.66435 .29036 L
.66455 .29052 L
.66473 .29073 L
.66513 .29135 L
.66557 .2923 L
.66636 .29464 L
.66785 .30066 L
.66956 .30873 L
.67112 .31538 L
.67189 .31804 L
.6723 .3192 L
.67274 .32021 L
.67311 .32093 L
.67332 .32124 L
.67353 .32152 L
.67373 .32172 L
.67391 .32187 L
.67399 .32192 L
Mistroke
.67409 .32197 L
.67418 .32201 L
.67426 .32204 L
.67436 .32206 L
.67446 .32207 L
.67454 .32206 L
.67463 .32205 L
.67473 .32203 L
.67479 .32201 L
.67484 .32199 L
.67504 .32189 L
.67521 .32175 L
.67541 .32157 L
.67576 .32113 L
.67618 .32045 L
.67662 .31955 L
.67742 .31756 L
.68046 .30784 L
.68203 .30351 L
.68248 .30254 L
.6829 .30176 L
.68328 .30119 L
.68349 .30093 L
.6837 .3007 L
.68391 .30051 L
.6841 .30037 L
.68428 .30027 L
.68439 .30022 L
.68448 .30019 L
.68458 .30016 L
.68468 .30014 L
.68478 .30013 L
.68487 .30013 L
.68492 .30013 L
.68498 .30014 L
.68508 .30015 L
.68513 .30016 L
.68518 .30017 L
.6853 .30021 L
.68549 .30029 L
.68567 .3004 L
.68601 .30067 L
.68638 .30105 L
.68678 .30156 L
.68836 .30443 L
.69004 .30821 L
.69165 .31158 L
.69255 .31309 L
.69298 .31366 L
.69338 .31411 L
Mistroke
.69374 .31443 L
.69413 .31469 L
.69435 .3148 L
.69446 .31485 L
.69456 .31488 L
.69464 .3149 L
.69474 .31493 L
.69484 .31494 L
.69495 .31495 L
.69505 .31496 L
.6951 .31496 L
.69516 .31496 L
.69526 .31495 L
.69536 .31494 L
.69541 .31493 L
.69547 .31492 L
.69557 .31489 L
.6958 .31481 L
.696 .31472 L
.69618 .31462 L
.6966 .31433 L
.69738 .31358 L
.69811 .31268 L
.69976 .31023 L
.70125 .30802 L
.70204 .30701 L
.70288 .30614 L
.70334 .30577 L
.70376 .3055 L
.70397 .30539 L
.70418 .3053 L
.70439 .30523 L
.70458 .30518 L
.70468 .30516 L
.70478 .30514 L
.70488 .30513 L
.70494 .30512 L
.70499 .30512 L
.70504 .30512 L
.7051 .30511 L
.7052 .30511 L
.70525 .30512 L
.7053 .30512 L
.70536 .30512 L
.70542 .30513 L
.70552 .30514 L
.70563 .30516 L
.70583 .3052 L
.70602 .30526 L
.70619 .30532 L
Mistroke
.7066 .3055 L
.70704 .30576 L
.70784 .30636 L
.70933 .30777 L
.7109 .30934 L
.71173 .31008 L
.71262 .31074 L
.71306 .311 L
.71348 .3112 L
.71386 .31134 L
.71405 .3114 L
.71426 .31145 L
.71446 .31149 L
.71465 .31151 L
.71475 .31152 L
.71485 .31153 L
.71495 .31153 L
.715 .31154 L
.71506 .31154 L
.71515 .31154 L
.71524 .31153 L
.71534 .31153 L
.71544 .31152 L
.71561 .3115 L
.71579 .31147 L
.71598 .31144 L
.71619 .31139 L
.71655 .31127 L
.71739 .31092 L
.71908 .30992 L
.72066 .30888 L
.7215 .30839 L
.72239 .30795 L
.72284 .30778 L
.72326 .30765 L
.72363 .30755 L
.72383 .30751 L
.72404 .30748 L
.72424 .30745 L
.72443 .30743 L
.72454 .30743 L
.72463 .30742 L
.72468 .30742 L
.72474 .30742 L
.72484 .30742 L
.72493 .30742 L
.72503 .30742 L
.72513 .30742 L
.72523 .30743 L
.72531 .30743 L
Mistroke
.7254 .30744 L
.72558 .30746 L
.72578 .30748 L
.72596 .30751 L
.72637 .30759 L
.7271 .30779 L
.72876 .30842 L
.73043 .30912 L
.73117 .30939 L
.73197 .30965 L
.73235 .30975 L
.73275 .30984 L
.7331 .3099 L
.73348 .30995 L
.7337 .30998 L
.7339 .31 L
.7341 .31001 L
.7342 .31001 L
.73425 .31001 L
.73431 .31002 L
.73441 .31002 L
.7345 .31002 L
.73459 .31002 L
.7347 .31002 L
.73479 .31001 L
.73489 .31001 L
.73498 .31001 L
.73507 .31 L
.73525 .30999 L
.73545 .30997 L
.73586 .30993 L
.73625 .30987 L
.7366 .30981 L
.73827 .30942 L
.73976 .30903 L
.74055 .30883 L
.74138 .30866 L
.74184 .30858 L
.74226 .30852 L
.74268 .30847 L
.74308 .30844 L
.74328 .30842 L
.74348 .30841 L
.74366 .30841 L
.74376 .3084 L
.74385 .3084 L
.74391 .3084 L
.74396 .3084 L
.74407 .3084 L
.74417 .3084 L
Mistroke
.74426 .3084 L
.74436 .3084 L
.74442 .3084 L
.74447 .30841 L
.74469 .30841 L
.74489 .30842 L
.74507 .30843 L
.74548 .30846 L
.74631 .30855 L
.7478 .30877 L
.7493 .30902 L
.75009 .30914 L
.75093 .30924 L
.75136 .30929 L
.75182 .30933 L
.75225 .30936 L
.75265 .30938 L
.75286 .30938 L
.75296 .30938 L
.75305 .30939 L
.75315 .30939 L
.75323 .30939 L
.75333 .30939 L
.75343 .30939 L
.75348 .30939 L
.75353 .30939 L
.75363 .30939 L
.75369 .30939 L
.75374 .30939 L
.75386 .30939 L
.75396 .30939 L
.75405 .30939 L
.75426 .30938 L
.75465 .30936 L
.75506 .30934 L
.7558 .30929 L
.75747 .30914 L
.75905 .30898 L
.75975 .30892 L
.7605 .30887 L
.76087 .30884 L
.76126 .30883 L
.76148 .30882 L
.76167 .30881 L
.76186 .30881 L
.76206 .3088 L
.76216 .3088 L
.76227 .3088 L
.76238 .3088 L
.76247 .30879 L
Mistroke
.76253 .30879 L
.76258 .30879 L
.76265 .30879 L
.7627 .30879 L
.76276 .30879 L
.76282 .30879 L
.76292 .30879 L
.76302 .30879 L
.76312 .30879 L
.76322 .30879 L
.76331 .3088 L
.76352 .3088 L
.76373 .3088 L
.76413 .30881 L
.7645 .30883 L
.76532 .30886 L
.76679 .30895 L
.76846 .30905 L
.76919 .30908 L
.76958 .3091 L
.77 .30912 L
.7704 .30913 L
.77077 .30914 L
.77095 .30914 L
.77114 .30914 L
.77132 .30915 L
.7715 .30915 L
.7716 .30915 L
.77165 .30915 L
.77171 .30915 L
.7718 .30915 L
.77189 .30915 L
.772 .30915 L
.7721 .30915 L
.77215 .30915 L
.7722 .30915 L
.77226 .30915 L
.77232 .30915 L
.77241 .30915 L
.77251 .30915 L
.77269 .30915 L
.77287 .30914 L
.77308 .30914 L
.77348 .30913 L
.77389 .30912 L
.77464 .3091 L
.77631 .30904 L
.77714 .30901 L
.77792 .30899 L
.77867 .30897 L
Mistroke
.77937 .30895 L
.77974 .30895 L
.78013 .30894 L
.78033 .30894 L
.78052 .30894 L
.78063 .30894 L
.78073 .30894 L
.78078 .30894 L
.78084 .30894 L
.7809 .30894 L
.78095 .30894 L
.78105 .30894 L
.78111 .30894 L
.78117 .30894 L
.78127 .30894 L
.78132 .30894 L
.78138 .30894 L
.78147 .30894 L
.78158 .30894 L
.78176 .30894 L
.782 .30894 L
.78222 .30895 L
.78263 .30895 L
.78341 .30896 L
.78423 .30898 L
.78571 .30901 L
.78653 .30903 L
.7873 .30904 L
.78799 .30905 L
.78839 .30905 L
.78875 .30906 L
.78914 .30906 L
.78936 .30906 L
.78945 .30906 L
.78956 .30906 L
.78965 .30906 L
.78975 .30906 L
.78983 .30906 L
.78992 .30906 L
.79002 .30906 L
.79011 .30906 L
.79021 .30906 L
.79031 .30906 L
.7904 .30906 L
.79051 .30906 L
.79072 .30906 L
.79092 .30906 L
.79111 .30906 L
.79153 .30906 L
.79198 .30905 L
Mistroke
.79356 .30903 L
.79529 .30901 L
.79608 .30901 L
.79652 .309 L
.79693 .309 L
.79732 .309 L
.79774 .30899 L
.79792 .30899 L
.79812 .30899 L
.79828 .30899 L
.79847 .30899 L
.79857 .30899 L
.79867 .30899 L
.79877 .30899 L
.79883 .30899 L
.79888 .30899 L
.79898 .30899 L
.79904 .30899 L
.79909 .30899 L
.79918 .30899 L
.79928 .30899 L
.79937 .30899 L
.79946 .30899 L
.79964 .30899 L
.79984 .30899 L
.80003 .30899 L
.80044 .309 L
.80089 .309 L
.8017 .309 L
.80326 .30901 L
.80409 .30902 L
.80498 .30902 L
.80539 .30903 L
.80583 .30903 L
.80623 .30903 L
.80661 .30903 L
.80679 .30903 L
.80696 .30903 L
.80716 .30903 L
.80734 .30903 L
.80743 .30903 L
.80754 .30903 L
.80762 .30903 L
.80772 .30903 L
.80782 .30903 L
.80788 .30903 L
.80794 .30903 L
.80804 .30903 L
.80814 .30903 L
.80832 .30903 L
Mistroke
.8085 .30903 L
.80891 .30903 L
.8093 .30903 L
.80973 .30903 L
.81121 .30902 L
.81278 .30902 L
.81362 .30901 L
.81408 .30901 L
.81451 .30901 L
.81492 .30901 L
.81514 .30901 L
.81537 .30901 L
.81556 .30901 L
.81578 .30901 L
.81587 .30901 L
.81597 .30901 L
.81606 .30901 L
.81615 .30901 L
.81626 .30901 L
.81635 .30901 L
.81641 .30901 L
.81646 .30901 L
.81656 .30901 L
.81666 .30901 L
.81675 .30901 L
.81685 .30901 L
.81695 .30901 L
.81713 .30901 L
.8173 .30901 L
.81769 .30901 L
.81809 .30901 L
.81852 .30901 L
.81932 .30901 L
.82081 .30902 L
.8224 .30902 L
.8232 .30902 L
.82366 .30902 L
.82388 .30902 L
.82408 .30902 L
.82428 .30902 L
.82446 .30902 L
.82456 .30902 L
.82466 .30902 L
.82476 .30902 L
.82482 .30902 L
.82487 .30902 L
.82497 .30902 L
.82507 .30902 L
.82517 .30902 L
.82523 .30902 L
Mistroke
.82528 .30902 L
.82538 .30902 L
.8255 .30902 L
.8257 .30902 L
.8259 .30902 L
.82608 .30902 L
.82648 .30902 L
.82719 .30902 L
.82887 .30902 L
.82961 .30902 L
.83041 .30902 L
.83114 .30902 L
.83154 .30902 L
.83192 .30902 L
.83213 .30901 L
.83235 .30901 L
.83254 .30901 L
.83274 .30901 L
.83294 .30901 L
.83304 .30901 L
.83314 .30901 L
.83324 .30901 L
.83332 .30901 L
.83342 .30901 L
.83351 .30901 L
.83361 .30901 L
.83367 .30901 L
.83372 .30901 L
.83381 .30901 L
.83391 .30901 L
.83409 .30901 L
.83428 .30901 L
.8347 .30901 L
.8351 .30902 L
.83581 .30902 L
.83658 .30902 L
.83816 .30902 L
.839 .30902 L
.83946 .30902 L
.83989 .30902 L
.84031 .30902 L
.84068 .30902 L
.84088 .30902 L
.8411 .30902 L
.84132 .30902 L
.84144 .30902 L
.84155 .30902 L
.84165 .30902 L
.84175 .30902 L
.84185 .30902 L
Mistroke
.84194 .30902 L
.84203 .30902 L
.84212 .30902 L
.84221 .30902 L
.8423 .30902 L
.8424 .30902 L
.8425 .30902 L
.84268 .30902 L
.84309 .30902 L
.8435 .30902 L
.84386 .30902 L
.84468 .30902 L
.84616 .30902 L
.84691 .30902 L
.84771 .30902 L
.84812 .30902 L
.84858 .30902 L
.84899 .30902 L
.84938 .30902 L
.84959 .30902 L
.84978 .30902 L
.84988 .30902 L
.84999 .30902 L
.85005 .30902 L
.85011 .30902 L
.85017 .30902 L
.85022 .30902 L
.85031 .30902 L
.8504 .30902 L
.8505 .30902 L
.85061 .30902 L
.85072 .30902 L
.85082 .30902 L
.85101 .30902 L
.85139 .30902 L
.85173 .30902 L
.8525 .30902 L
.85414 .30902 L
.85494 .30902 L
.85567 .30902 L
.85637 .30902 L
.85674 .30902 L
.85714 .30902 L
.85734 .30902 L
.85756 .30902 L
.85776 .30902 L
.85795 .30902 L
.85814 .30902 L
.85824 .30902 L
.85834 .30902 L
Mistroke
.85843 .30902 L
.85852 .30902 L
.85861 .30902 L
.85871 .30902 L
.85881 .30902 L
.85887 .30902 L
.85892 .30902 L
.85914 .30902 L
.85933 .30902 L
.85953 .30902 L
.86 .30902 L
.86042 .30902 L
.86204 .30902 L
.86284 .30902 L
.86369 .30902 L
.86443 .30902 L
.86482 .30902 L
.86523 .30902 L
.86543 .30902 L
.86566 .30902 L
.86587 .30902 L
.86606 .30902 L
.86625 .30902 L
.86636 .30902 L
.86646 .30902 L
.86655 .30902 L
.86664 .30902 L
.86673 .30902 L
.86684 .30902 L
.86692 .30902 L
.86701 .30902 L
.8671 .30902 L
.86719 .30902 L
.86735 .30902 L
.86753 .30902 L
.86792 .30902 L
.86829 .30902 L
.86994 .30902 L
.87143 .30902 L
.87218 .30902 L
.87297 .30902 L
.87338 .30902 L
.8736 .30902 L
.87384 .30902 L
.87405 .30902 L
.87425 .30902 L
.87434 .30902 L
.87445 .30902 L
.87455 .30902 L
.87464 .30902 L
Mistroke
.87474 .30902 L
.87479 .30902 L
.87485 .30902 L
.87495 .30902 L
.87505 .30902 L
.8751 .30902 L
.87516 .30902 L
.87526 .30902 L
.87549 .30902 L
.87569 .30902 L
.87587 .30902 L
.87629 .30902 L
.87701 .30902 L
.87778 .30902 L
.87937 .30902 L
.88006 .30902 L
.88082 .30902 L
.88121 .30902 L
.88157 .30902 L
.88196 .30902 L
.88218 .30902 L
.88237 .30902 L
.88248 .30902 L
.88253 .30902 L
.88259 .30902 L
.88268 .30902 L
.88279 .30902 L
.88284 .30902 L
.8829 .30902 L
.883 .30902 L
.88306 .30902 L
.88311 .30902 L
.88323 .30902 L
.88333 .30902 L
.88342 .30902 L
.88363 .30902 L
.88405 .30902 L
.88442 .30902 L
.88484 .30902 L
.88567 .30902 L
.88715 .30902 L
.88796 .30902 L
.88872 .30902 L
.88914 .30902 L
.88937 .30902 L
.8896 .30902 L
.8898 .30902 L
.89002 .30902 L
.89022 .30902 L
.8904 .30902 L
Mistroke
.8905 .30902 L
.89056 .30902 L
.89061 .30902 L
.89071 .30902 L
.8908 .30902 L
.89086 .30902 L
.89091 .30902 L
.89101 .30902 L
.89107 .30902 L
.89112 .30902 L
.89124 .30902 L
.89144 .30902 L
.89162 .30902 L
.89203 .30902 L
.8924 .30902 L
.89279 .30902 L
.89352 .30902 L
.89507 .30902 L
.8959 .30902 L
.89634 .30902 L
.89679 .30902 L
.8972 .30902 L
.89741 .30902 L
.89764 .30902 L
.89785 .30902 L
.89804 .30902 L
.89814 .30902 L
.89824 .30902 L
.89833 .30902 L
.89842 .30902 L
.89851 .30902 L
.8986 .30902 L
.89871 .30902 L
.89881 .30902 L
.89891 .30902 L
.89896 .30902 L
.89901 .30902 L
.89911 .30902 L
.89921 .30902 L
.89941 .30902 L
.8996 .30902 L
.89995 .30902 L
.90073 .30902 L
.90156 .30902 L
.90305 .30902 L
.90381 .30902 L
.90423 .30902 L
.90463 .30902 L
.905 .30902 L
.9054 .30902 L
Mistroke
.90558 .30902 L
.90576 .30902 L
.90592 .30902 L
.9061 .30902 L
.9062 .30902 L
.9063 .30902 L
.9064 .30902 L
.90646 .30902 L
.90652 .30902 L
.90661 .30902 L
.90672 .30902 L
.90682 .30902 L
.90691 .30902 L
.90709 .30902 L
.90727 .30902 L
.90766 .30902 L
.90808 .30902 L
.90852 .30902 L
.90933 .30902 L
.91092 .30902 L
.91176 .30902 L
.91222 .30902 L
.91265 .30902 L
.91303 .30902 L
.91323 .30902 L
.91344 .30902 L
.91366 .30902 L
.91378 .30902 L
.9139 .30902 L
.914 .30902 L
.9141 .30902 L
.91415 .30902 L
.91421 .30902 L
.91431 .30902 L
.91441 .30902 L
.9145 .30902 L
.9146 .30902 L
.9147 .30902 L
.91492 .30902 L
.91511 .30902 L
.91549 .30902 L
.91585 .30902 L
.91892 .30902 L
.91973 .30902 L
.92013 .30902 L
.9205 .30902 L
.92092 .30902 L
.92115 .30902 L
.92126 .30902 L
.92138 .30902 L
Mistroke
.92149 .30902 L
.92158 .30902 L
.92168 .30902 L
.92177 .30902 L
.92187 .30902 L
.92197 .30902 L
.92207 .30902 L
.92213 .30902 L
.92218 .30902 L
.92228 .30902 L
.92237 .30902 L
.92258 .30902 L
.92278 .30902 L
.923 .30902 L
.92374 .30902 L
.92541 .30902 L
.92701 .30902 L
.92745 .30902 L
.92792 .30902 L
.92831 .30902 L
.92854 .30902 L
.92875 .30902 L
.92895 .30902 L
.92905 .30902 L
.92917 .30902 L
.92926 .30902 L
.92937 .30902 L
.92946 .30902 L
.92955 .30902 L
.92965 .30902 L
.92971 .30902 L
.92976 .30902 L
.92987 .30902 L
.92996 .30902 L
.93008 .30902 L
.93018 .30902 L
.93041 .30902 L
.93079 .30902 L
.93121 .30902 L
.93196 .30902 L
.93352 .30902 L
.93435 .30902 L
.93481 .30902 L
.93524 .30902 L
.93565 .30902 L
.93586 .30902 L
.93609 .30902 L
.93631 .30902 L
.9365 .30902 L
.93659 .30902 L
Mistroke
.93669 .30902 L
.93678 .30902 L
.93687 .30902 L
.93697 .30902 L
.93706 .30902 L
.93716 .30902 L
.93726 .30902 L
.93736 .30902 L
.93742 .30902 L
.93747 .30902 L
.93767 .30902 L
.93784 .30902 L
.93802 .30902 L
.9384 .30902 L
.93921 .30902 L
.93995 .30902 L
.94163 .30902 L
.94236 .30902 L
.94277 .30902 L
.94315 .30902 L
.94336 .30902 L
.9436 .30902 L
.94379 .30902 L
.94401 .30902 L
.94421 .30902 L
.94432 .30902 L
.94443 .30902 L
.94452 .30902 L
.94461 .30902 L
.94471 .30902 L
.94481 .30902 L
.94491 .30902 L
.94497 .30902 L
.94502 .30902 L
.94522 .30902 L
.94539 .30902 L
.94558 .30902 L
.94597 .30902 L
.9464 .30902 L
.94788 .30902 L
.94875 .30902 L
.94958 .30902 L
.95032 .30902 L
.95074 .30902 L
.95093 .30902 L
.95113 .30902 L
.95132 .30902 L
.9515 .30902 L
.95159 .30902 L
.95168 .30902 L
Mistroke
.95177 .30902 L
.95185 .30902 L
.95196 .30902 L
.95205 .30902 L
.95215 .30902 L
.95221 .30902 L
.95226 .30902 L
.95235 .30902 L
.95245 .30902 L
.95255 .30902 L
.95265 .30902 L
.95286 .30902 L
.95305 .30902 L
.95343 .30902 L
.95426 .30902 L
.95572 .30902 L
.95655 .30902 L
.95733 .30902 L
.9577 .30902 L
.9581 .30902 L
.9583 .30902 L
.95853 .30902 L
.95873 .30902 L
.95892 .30902 L
.95902 .30902 L
.95914 .30902 L
.95919 .30902 L
.95925 .30902 L
.95935 .30902 L
.95944 .30902 L
.95953 .30902 L
.95963 .30902 L
.95973 .30902 L
.95979 .30902 L
.95985 .30902 L
.95997 .30902 L
.96019 .30902 L
.96039 .30902 L
.9606 .30902 L
.96143 .30902 L
.96233 .30902 L
.9631 .30902 L
.96394 .30902 L
.96434 .30902 L
.96477 .30902 L
.96514 .30902 L
.96555 .30902 L
.96578 .30902 L
.966 .30902 L
.96621 .30902 L
Mistroke
.96632 .30902 L
.96643 .30902 L
.96654 .30902 L
.96663 .30902 L
.96674 .30902 L
.96679 .30902 L
.96685 .30902 L
.96695 .30902 L
.96705 .30902 L
.96715 .30902 L
.96724 .30902 L
.96742 .30902 L
.96763 .30902 L
.96804 .30902 L
.96878 .30902 L
.97045 .30902 L
.97125 .30902 L
.97201 .30902 L
.97243 .30902 L
.97265 .30902 L
.97289 .30902 L
.97311 .30902 L
.9733 .30902 L
.9735 .30902 L
.97359 .30902 L
.97369 .30902 L
.97377 .30902 L
.97385 .30902 L
.97392 .30902 L
.97399 .30902 L
.97408 .30902 L
.97415 .30902 L
.97424 .30902 L
.97432 .30902 L
.9744 .30902 L
.97449 .30902 L
.97464 .30902 L
.97483 .30902 L
.97499 .30902 L
.97561 .30902 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{421.375, 260.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008>0001AB000`400?l00000o`00003ooooooooo
oooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo
003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooo
oooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool0
0?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooooooo
ool@ooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooo
ooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo0ol0003o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0
003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo
00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`
ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLoooo
o`00<?ooool3o`000?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?oo
ool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0
033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomco
oooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooo
oooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool3o`000?oooooo
g?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0013ooooo0_o^k^h3ooooo`;ok^k^6Oooool00ol0003oooooooooo`3o
ooooomcooooo000;ooooo`;o000000[o410@ooooooooooook^k^oeEEEOo^k^koooooonk^k_mEEEGo
k^k^0oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h:ooooo`03o`000?oo
oooooooo0?oooooog?ooool000cooooo00?o0000ooooooooool00_ooool01Oo^k^koEEEEomgMgOmE
EEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00[ooooo
00?o0000ooooooooool0oooooooLooooo`0000?oooooo`000?l000001?l00002ooooo`Go00001?oo
ool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooo
oa0@400:ooooo`03o`000?oooooooooo0?oooooog?ooool000Wooooo00CoA4A4omgMgOoooooo0000
1?ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000000[ooooo00?o0000ooooooooool0oooooooLooooo`002Oooool01?oMgMgo
EEEEooooool00003ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000:ooooo`Co0000oooooooKooooo`002_oo
ool00omgMgOoc<c<o`000003ooooo`;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@00[ooooo00?o0000ooooooooool0oooooooLooooo`002_oo
ool00oo^k^koA4A4o`00000?ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`;o00001Oooool00ol0003oooooooooo`3oooooomcooooo000;ooooo`03ogMgMol0
003ooooo00cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`2_ooooo`;o0000ooooool[ooooo`00
:?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo0:oooooo0_l0003oooooob_o
oooo000Xooooo`?o00001Oooool00ol0003oooooooooo`2_ooooo`;o0000ooooool[ooooo`00:Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0:oooooo0_l0003oooooob_ooooo000Z
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0[oooool2o`000?oooooo:oooool0
033ooooo00?o0000ooooooooool0[oooool2o`000?oooooo:oooool0033ooooo00?o0000oooooooo
ool0[oooool2o`000?oooooo:oooool0033ooooo00?o0000ooooooooool0Xoooool2o`0000[ooooo
0_l0003oooooob_ooooo000`ooooo`03o`000?oooooooooo0:?ooooo0_l0000:ooooo`;o00002_oo
ool00ol0003oooooooooo`3ooooooakooooo000`ooooo`?o0000Xoooool2o`0000[ooooo0_l0000:
ooooo`03o`000?oooooooooo0?oooooo7_ooool0033ooooo00?o0000ooooooooool0Xoooool2o`00
00[ooooo0_l0000:ooooo`03o`000?oooooooooo0?oooooo7_ooool0033ooooo00?o0000oooooooo
ool0Xoooool2o`0000[ooooo0_l00009ooooo`;o0000oooooolPooooo`00<?ooool00ol0003ooooo
ooooo`2Sooooo`;o00002_ooool00ol0003oooooo`000008ooooo`;o0000oooooolPooooo`00<?oo
ool00ol0003oooooooooo`2Sooooo`;o00002_ooool00ol0003oooooo`000008ooooo`;o0000oooo
oolPooooo`00<?ooool00ol0003oooooooooo`2Sooooo`;o00002_ooool00ol0003oooooo`000008
ooooo`03o`000?oooooo00000?oooooo7oooool0033ooooo00?o0000ooooooooool0Xoooool2o`00
00[ooooo00?o0000ooooool000002?ooool00ol0003oooooo`00003ooooooaoooooo000`ooooo`03
o`000?oooooooooo0:?ooooo0_l0000:ooooo`03o`000?oooooo000000Sooooo00?o0000ooooool0
0000oooooolOooooo`00<?ooool00ol0003oooooooooo`2Rooooo`04o`000?ooooooooooo`0000So
oooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003ooooooaoooooo000`ooooo`03
o`000?oooooooooo0:;ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00008
ooooo`03o`000?oooooo00000?oooooo7oooool0033ooooo00?o0000ooooooooool0X_ooool01?l0
003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooo
oolOooooo`00<?ooool00ol0003oooooooooo`2Rooooo`04o`000?ooooooooooo`0000Sooooo00Co
0000oooooooooooo00002?ooool00ol0003oooooo`00003ooooooaoooooo000`ooooo`?o0000X_oo
ool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool0
0000oooooolOooooo`00<?ooool00ol0003oooooooooo`2Rooooo`04o`000?ooooooooooo`0000So
oooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003ooooooaoooooo000`ooooo`03
o`000?oooooooooo0:;ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00008
ooooo`03o`000?oooooo00000?oooooo7oooool0033ooooo00?o0000ooooooooool0X_ooool01?l0
003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oooo
oolOooooo`00<?ooool00ol0003oooooooooo`2Rooooo`04o`000?ooooooooooo`0000Sooooo00Co
0000oooooooooooo00002?ooool00ol0003oooooo`00003ooooooaoooooo000`ooooo`03o`000?oo
oooooooo0:;ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00008ooooo`03
o`000?oooooo000000Wooooo00?o0000ooooooooool0oooooolCooooo`00<?ooool00ol0003ooooo
ooooo`2Gooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooo00002?ooool01?l0003o
ooooooooool00008ooooo`03o`000?oooooo000000Sooooo0_l0003ooooooaGooooo000`ooooo`03
o`000?oooooooooo09Kooooo0_l0000:ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooo
oooooooo00002?ooool00ol0003oooooo`000008ooooo`;o0000oooooolEooooo`00<?ooool00ol0
003oooooooooo`2Fooooo`;o00002_ooool01?l0003oooooooooool00008ooooo`04o`000?oooooo
ooooo`0000Sooooo00?o0000ooooool000002?ooool2o`000?oooooo5Oooool0033ooooo00?o0000
ooooooooool0U_ooool2o`0000[ooooo00Co0000oooooooooooo00002?ooool01?l0003ooooooooo
ool00008ooooo`03o`000?oooooo000000Sooooo0_l0003ooooooaGooooo000`ooooo`03o`000?oo
oooooooo09Kooooo0_l0000:ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo
00002?ooool00ol0003oooooo`000008ooooo`03o`000?oooooo00000?oooooo5?ooool0033ooooo
0ol0002Fooooo`03o`000?oooooo000000Wooooo00Co0000oooooooooooo00002?ooool01?l0003o
ooooooooool00008ooooo`03o`000?oooooo000000Sooooo00?o0000ooooool00000oooooolDoooo
o`00<?ooool00ol0003oooooooooo`2Fooooo`03o`000?oooooo000000Wooooo00Co0000oooooooo
oooo00002?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo000000Sooooo00?o0000
ooooool00000oooooolDooooo`00<?ooool00ol0003oooooooooo`2Fooooo`03o`000?oooooo0000
00Wooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00008ooooo`03o`000?oo
oooo000000Sooooo00?o0000ooooool00000oooooolDooooo`00<?ooool00ol0003oooooooooo`2F
ooooo`03o`000?oooooo000000Wooooo00Co0000oooooooooooo00002?ooool01?l0003ooooooooo
ool00008ooooo`03o`000?oooooo000000Sooooo00?o0000ooooool00000oooooolDooooo`00<?oo
ool00ol0003oooooooooo`2Fooooo`03o`000?oooooo000000Wooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo000000Sooooo00?o0000ooooool0
0000oooooolDooooo`00<?ooool00ol0003oooooooooo`2Fooooo`03o`000?oooooo000000Wooooo
00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo0000
00Sooooo00?o0000ooooool00000oooooolDooooo`00<?ooool00ol0003oooooooooo`2Fooooo`03
o`000?oooooo000000Wooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00008
ooooo`03o`000?oooooo000000Sooooo00?o0000ooooool00000oooooolDooooo`004?ooool2onk^
kP?ooooo0_o^k^hIooooo`03o`000?oooooooooo09Kooooo00?o0000ooooool000002Oooool01?l0
003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo0000
2?ooool00ol0003oooooo`00003ooooooaCooooo0009ooooo`Go00000_ooool01oo^k^koEEEEonk^
k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h:ooooo`03o`000?oooooooooo09Gooooo00Co0000oooooooooooo00002Oooool01?l0003ooooo
ooooool00008ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000007
ooooo`03o`000?oooooo00000?oooooo5?ooool000Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A003
ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02_ooool00ol0003oooooooooo`2Eooooo`04o`000?ooooooooooo`0000Wo
oooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00007ooooo`05o`000?oooooo
ooooooooool000001oooool00ol0003oooooo`00003ooooooaCooooo00000ooooooo0000o`000004
o`0000?ooooo00?oV9RHob4Q8Oo^k^h01Oooool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooo
oooo00;ooooo00Go410@oooooooooooooooooa0@400:ooooo`03o`000?oooooooooo09Gooooo00Co
0000oooooooooooo00002Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00
00Oooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?oooooo5?ooool0
00_ooooo00?oV9RHob4Q8Oo^k^h00oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000000[ooooo00?o0000ooooooooool0UOoo
ool01?l0003oooooooooool00009ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooo
oooo00001oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooool00000oooooolD
ooooo`003?ooool02omgMgOoIVIVooooooooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Go
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000[ooooo1?l0002Doooo
o`04o`000?ooooooooooo`0000Wooooo00Co0000oooooooooooo00002?ooool01?l0003ooooooooo
ool00007ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003ooooooaCo
oooo000=ooooo`03o`000?oooooooooo00;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@00[ooooo00?o0000ooooooooool0UOooool01?l0003o
ooooooooool00009ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001ooo
ool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooool00000oooooolDooooo`002Ooo
ool01Ol0003o^[ZjoooooonHV9So410@00kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00?ooooo0_l00005ooooo`03o`000?oooooooooo09Gooooo00Co0000oooooooo
oooo00002Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Oooooo00Go
0000ooooooooooooooooo`000007ooooo`03o`000?oooooo000000Sooooo0_l0003oooooo`[ooooo
0009ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?ooool00omEEEGoIVIVo`000004ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h00_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo
09Gooooo00Co0000oooooooooooo00002Oooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo000000So
oooo0_l0003oooooo`[ooooo000Xooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool0UOooool01?l0003oooooooooool00009ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000
oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo
00002?ooool2o`000?oooooo2_ooool002Sooooo0ol00005ooooo`03o`000?oooooooooo09Gooooo
00Co0000oooooooooooo00002Oooool01?l0003oooooooooool00008ooooo`04o`000?oooooooooo
o`0000Oooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Sooooo
0_l0003oooooo`[ooooo000Yooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0UOoo
ool01Ol0003ooooooooooooooooo000000Sooooo00Co0000oooooooooooo00002?ooool01?l0003o
ooooooooool00007ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool0
0008ooooo`;o0000ooooool:ooooo`00:_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo09Gooooo00Go0000ooooooooooooooooo`000008ooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooo
oooooooo00002?ooool2o`000?oooooo2_ooool0033ooooo00?o0000ooooooooool0UOooool01Ol0
003ooooooooooooooooo000000Sooooo00Co0000oooooooooooo00002?ooool01?l0003ooooooooo
ool00007ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool00007oooo
o`03o`000?oooooo00000?oooooo2_ooool0033ooooo00?o0000ooooooooool0ROooool00ol0003o
ooooooooo`09ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo
000000Sooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Kooooo
00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo00000?oooooo2_ooool0033ooooo
00?o0000ooooooooool0ROooool2o`0000[ooooo00Go0000ooooooooooooooooo`000007ooooo`05
o`000?ooooooooooooooool000002?ooool01?l0003oooooooooool00007ooooo`05o`000?oooooo
ooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooool00000
ooooool:ooooo`00<?ooool00ol0003oooooooooo`28ooooo`03o`000?oooooo000000[ooooo00Go
0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1Oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooool00000ooooool:ooooo`00<?ooool3o`00
08Sooooo00?o0000ooooool000002_ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Oooooo00Go
0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooo`00003oooooo`[ooooo000`ooooo`03o`000?oooooooooo08Sooooo00?o0000ooooool00000
2_ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`05ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000006
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooo`00003oooooo`[ooooo000`
ooooo`03o`000?oooooooooo08Sooooo00?o0000ooooool000002_ooool01Ol0003ooooooooooooo
oooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`04o`000?oo
ooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?oooooooooooooo
ool000001_ooool00ol0003oooooo`00003oooooo`[ooooo000`ooooo`03o`000?oooooooooo08So
oooo00?o0000ooooool000002_ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000001_ooool0
1Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooo00000?oooooo2_ooool0033ooooo00?o0000ooooooooool0R?ooool01?l0003ooooooooo
ool00009ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?oooooooooo
ooooool000001_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooool00000oooo
ool:ooooo`00<?ooool00ol0003oooooooooo`28ooooo`04o`000?ooooooooooo`0000Wooooo00Go
0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1Oooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000006oooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooo`00003oooooo`[ooooo000`oooo
o`03o`000?oooooooooo08Sooooo00Co0000oooooooooooo00002Oooool01Ol0003ooooooooooooo
oooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`05o`000?oo
ooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000oooooooo
ooooooooo`000006ooooo`03o`000?oooooo00000?oooooo2_ooool0033ooooo00?o0000oooooooo
ool0Qoooool01Ol0003ooooooooooooooooo000000Wooooo00Go0000ooooooooooooooooo`000007
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooo`000008ooooo`;o0000ooooool0033ooooo00?o
0000ooooooooool0Qoooool01Ol0003ooooooooooooooooo000000Wooooo00Go0000oooooooooooo
ooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006oooo
o`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool00007ooooo`;o0000oooo
ool0033ooooo00?o0000ooooooooool0Qoooool01Ol0003ooooooooooooooooo000000Wooooo00Go
0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooo
ooooo`000006ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool00007
ooooo`;o0000ooooool0033ooooo00?o0000ooooooooool0Qoooool01Ol0003ooooooooooooooooo
000000Wooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go
0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003o
ooooooooool00007ooooo`;o0000ooooool0033ooooo00?o0000ooooooooool0Qoooool01Ol0003o
oooooooooooooooo000000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?oooooo
ooooooooool000001_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooo00000?oooooo
000`ooooo`?o0000Qoooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooo
ooooo`000006ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool00006
ooooo`03o`000?oooooo00000?oooooo000`ooooo`03o`000?oooooooooo08Oooooo00Go0000oooo
ooooooooooooo`000008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooo
oooooooo000000Kooooo00Co0000oooooooooooo00001_ooool00ol0003oooooo`00003oooooo`00
<?ooool00ol0003oooooooooo`27ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003o
oooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?oooooo
ooooo`0000Kooooo00?o0000ooooool00000ooooool0033ooooo00?o0000ooooooooool0Qoooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00
0006ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool00006ooooo`03
o`000?oooooo00000?oooooo000`ooooo`03o`000?oooooooooo08Oooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003o
oooooooooooooooo000000Kooooo00Co0000oooooooooooo00001_ooool01?l0003oooooooooool0
003nooooo`00<?ooool00ol0003oooooooooo`1>ooooo`;ok^k^0oooool2onk^kS;ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?ok^k^
o`000?ooool00_ooool00oo^k^ko0000ooooo`05ooooo`05o`000?ooooooooooooooool000001_oo
ool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo00001_ooool01?l0003o
ooooooooool0000fooooo`;ok^k^0oooool2onk^kTkooooo0_o^k^h3ooooo`;ok^k^K?ooool0033o
oooo00?o0000ooooooooool0B?ooool03Om4A4Co0000o`000?lb<S;ogMgMooooooo^k^koEEEEonk^
k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^hFooooo`;o00002_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo1?l0
00002Ol@413oooooonk^k_l0003ok^k^ooooooo^k^koEEEEo`000003ooooo`Co000000So410@oooo
oooooooo0000oc8b<_l0003o<S8bonk^kP;ooooo00Go0000ooooooooooooooooo`000006ooooo`04
o`000?ooooooooooo`0000Kooooo00Co0000oooooooooooo00008?ooool4o`000003oa0@4?oooooo
oooo00;ooooo0_lQ8B45ooooo`0=odA4A?l0003o0000oc8b<_oMgMgoooooonk^k_mEEEGok^k^oooo
ooo^k^koEEEEonk^kP03ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kSSo
oooo1Ol00002ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co000000So410@
ooooooooooook^k^oc8b<_l0003o<S8bonk^kUgooooo000`ooooo`03o`000?oooooooooo04_ooooo
00WoMgMgoc8b<_ooooooooooonk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL05_ooool2o`0000[ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000Cooooo00Ko0000oeEEEOoMgMgoEEEE
onk^k_l00005ooooo`;o00000oooool01Ol0003oV9RHoooooonHV9SoMgMg00;ooooo00Go0000oooo
ooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Kooooo00Co0000oooooooooooo0000
1oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`09ogMg
Molb<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg03Sooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05onk^
k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL0GOooool0033ooooo00?o0000ooooooooool0C?ooool01ol0003ooooooooooooooooogMgM
o`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41005Ooo
ool00ol0003oooooo`00000:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_oo
ool00ol0003oooooo`000004ooooo`06o`000?oMgMgo0000omgMgOoooooo00001Oooool2o`0000?o
oooo00Go0000oooooooooooooooooa0@4002ooooo`05o`000?ooooooooooooooool000001_ooool0
1?l0003oooooooooool00006ooooo`04o`000?ooooooooooo`0000Kooooo0_l0000Jooooo`03o`00
0?oooooooooo00oooooo00Oo0000ooooooooooooooooomgMgOl0003ogMgM00Oooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@03Wooooo00?oV9RHob4Q8Oo^k^h01Oooool0
0ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
401Mooooo`00<?ooool00ol0003oooooooooo`1;ooooo`09ogMgMolb<S;oooooooooooo^k^koEEEE
omgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
01Gooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooool000001?ooool01_l0003oEEEEomgMgOmEEEGok^k^o`0000Gooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooooooo
ooooooooo`000005ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool0
0006ooooo`03o`000?oooooo000001Wooooo00?o0000ooooooooool03_ooool02OmgMgOo<S8boooo
ooooooook^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`00000jooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^
kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001Mooooo`00<?oo
ool00ol0003oooooooooo`18ooooo`0=o`000?lQ8B7o0000oc8b<_o<c<coooooonk^k_mEEEGok^k^
ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Eooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooo000000?ooooo00Ook^k^o`000?o^k^koooooonk^k_mEEEGo
000000Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000;ooooo00Go
0000ooooooooooooooooo`000005ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003o
ooooooooool00006ooooo`03o`000?oooooo000001Wooooo00?o0000ooooooooool02oooool03Ol0
003o8B4Qo`000?lb<S;oc<c<ooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000>oooool02omgMgOoIVIVoooooooo
ooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000ooooooooool00_ooool01Ol0
003ooooooooooooooooo000005gooooo000`ooooo`03o`000?oooooooooo04Sooooo00?o0000oooo
ooooool00oooool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooo
oooooooooooooa0@400Eooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000?ooooo00?ok^k^o`000?ooool00_oo
ool00oo^k^ko0000ooooo`04ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
oa0@4002ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0003ooooooooooooooooo0000
00Kooooo00Co0000oooooooooooo00001_ooool00ol0003oooooo`00000Iooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool00oooool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooo
oooo00;ooooo00Go410@oooooooooooooooooa0@400looooo`03o`000?oooooooooo00;ok^k^0ooo
ool2onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@05gooooo
000`ooooo`?o0000B?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo00Wooooo00Go0000oooooooooooo
ooooo`000009ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooo`000004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`05o`000?nHV9SooooooiRHV?mgMgL00_ooool01_l0003ooooooooooooooooo
0000ooooo`;o00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Co
0000oooooooooooo00001_ooool00ol0003oooooo`00000Iooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02?ooool2o`0002kooooo00Go0000okZj^_ooooooV9RHoa0@400>ooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`;o0000Doooool0033ooooo00?o0000oooo
ooooool0B?ooool4o`0000cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Sooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooooooooooo000000Wooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?mVIVKo000000Cooooo00?o
0000ooooooooool00_ooool01ol0003oooooooooooooooooEEEEofIVI_l000001?ooool01Ol0003o
<S8bo`000?lb<S;ok^k^00;ooooo00Co0000oooooooooooooooo0_l00002ooooo`03o`000?oooooo
000000Cooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00006ooooo`03o`000?oo
oooo000001Oooooo00?oEEEEofIVI_l000003Oooool4o`0000cooooo00?oEEEEofIVI_l000001?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oooooo00Co0000oooooooooooo0000;Oooool01OnHV9So
410@o`000?lQ8B7oc<c<00cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Oooooo00Co0000oooooooooooo0000D_ooool0033ooooo00?o0000ooooooooool0I_ooool4
o`0000?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01?ooool6o`0000;ooooo00?o0000ooooool000001?ooool0
0ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooool00000AOoo
ool4o`000005ooooool0003oooooooooool00000C?ooool4o`000005ooooool0003oooooooooool0
0000D_ooool0033ooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`04o`00
0?ooooooooooooooo`Co00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00007ooooo`;o0000@Oooool3
o`0005;ooooo0ol0001Cooooo`00<?ooool00ol0003oooooooooo`1[ooooo`04o`000?oooooooooo
o`0000Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00Oo0000ooooooooooooooooo`000?oooooo000000?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooo
oooo00001oooool2o`0004;ooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`1Boooo
o`00<?ooool00ol0003oooooooooo`1[ooooo`Co00002?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000001Oooool01?l0003oooooooooool00006ooooo`03o`000?oooooo000004?ooooo
00?o0000ooooooooool0D_ooool00ol0003oooooooooo`1Aooooo`00<?ooool00ol0003ooooooooo
o`1Zooooo`;o00002oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0_ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooool00000k?ooool0033ooooo
00?o0000ooooooooool0JOooool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooooooo
ool000001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001Oooool0
1?l0003oooooooooool00006ooooo`;o0000ZOooool00omgMgOoIVIVooooo`0]ooooo`03ofIVI_mg
MgOooooo00Oooooo000`ooooo`03o`000?oooooooooo06Sooooo00Go0000ooooooooooooooooo`00
000:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000001Oooool01?l0003oooooooooool00006ooooo`;o0000Z?ooool00ooM
gMgo410@onk^kP0^ooooo`03onk^k_l@413ogMgM00Oooooo000`ooooo`03o`000?oooooooooo06Oo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`05o`000?oooooooooooooo
ool000001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001Oooool0
1?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Kooooo0_l0002=ooooo`;o0000
0_ooool2o`0000cooooo00?oEEEEoiRHV?ooool00_l00002ooooo`07o`000?ooooooooooo`000?l@
413ok^k^oeEEE@02o`000003odA4A?nj^[[ooooo00;ooooo00GoV9RHo`000?l0003oA4A4okZj^P02
ooooo`08onk^k_mEEEGo0000o`000?m4A4Co^[Zjooooool@4105o`0000?ooooo00So410@oc8b<_l0
003o0000oa0@4?nYZJWoQhN7ofIVIPOooooo000`ooooo`03o`000?oooooooooo05Oooooo1?l0000<
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooo
oooo000000Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Gooooo
00Go0000ooooooooooooooooo`000004ooooo`04o`000?ooooooooooo`0000Gooooo0ol00007oooo
o`03o`000?oooooooooo08?ooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd<ooooo`05o`000?oo
ooooooooooooool000000_ooool02ol0003oooooooooool0003ooooooeEEEOmgMgOoooooonk^k_mg
MgOo410@00?ooooo00Go410@okZj^_o^k^koMgMgoa0@4002ooooo`06oeEEEOmgMgOoooooonk^k_mg
MgOo410@0oooool00ol0003oooooooooo`04ooooo`08o`000?nYZJWooooooooooonj^[[o0000onk^
k_l00007ooooo`00ool0002do`0000oooooo00CogMgMo`000?l@413oc<c<3Oooool01Olb<S;ooooo
oooooooooooo000000;ooooo00Ko0000oooooooooooo0000ooooool00008ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`07okZj^_n7QhOo
IVIVofIVI_l@413oooooo`000007ooooo`002_ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`02ooooo`Go00002Ooo
ool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`000004ooooo`;o00000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00?o0000ooooooooool00_ooool4o`0000Gooooo0ol00009ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Gooooo`04onk^k_lQ
8B7o410@onk^kPgooooo00Go<S8booooooooooooooooo`000002ooooo`05o`000?ooooooooooo`00
0?ooool01_l00003ooooo`03o`000?oooooooooo00Cooooo1_l00003ooooo`03o`000?oooooooooo
00Cooooo00So<S8bob4Q8OmgMgOoMgMgohN7Qoo^k^koooooo`0000Oooooo000:ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo013ooooo00Co0000oooooooooooooooo0ol000000ooooooo0000o`000009ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00003ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool2o`0000Cooooo00?o0000oooooooo
ool00oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooool000001?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooool0003oooooo`000005
ooooo`05o`000?ooooooooooooooool000001Oooool01?l0003oooooooooool00005ooooo`03o`00
0?oooooo000000Oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool05oooool01?lQ8B7oMgMgogMgMolb<S8=ooooo`05
o`000?o^k^koooooooooool000000_o<c<`02ol0003oZJVYomgMgOlQ8B7ooooooeEEEOn7QhOok^k^
oooooon7QhOo<S8b00?ooooo00?o0000ooooooooool01?ooool01_mEEEGoQhN7onk^k_ooooooQhN7
oc8b<P?ooooo00?o0000oc8b<_oMgMd01?ooool02?l0003o^[Zjooooooo^k^koMgMgo`000?o^k^ko
00001oooool0033ooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`03ooooo`?o0000
2oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000001Oooool01Ol0003ooooooooooooooooo000000Gooooo00Co0000oooo
oooooooo00001Oooool3o`0001[ooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`0F
ooooo`;o00000_ooool2o`0000cooooo00koEEEEogMgMooooooo410@o`000?lQ8B7o0000ogMgMol@
413o0000ojVYZOooooook^k^oeEEE@;o000000CoA4A4onk^k_oooooo410@1Ol00003ooooo`06onk^
k_mEEEGo0000o`000?m4A4Cok^k^0_ooool2o`000004ojVYZOlQ8B7o0000ob4Q8@;ooooo00SoZJVY
ob4Q8Ol0003o0000oc8b<_l0003oMgMgoeEEE@Oooooo000`ooooo`03o`000?oooooooooo06oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Gooooo00Go0000oooooooo
ooooooooo`000005ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooo`00002/
ooooo`03omgMgOl@413ok^k^01;ooooo00?o0000ooooooooool06Oooool00oo^k^ko410@omgMg@07
ooooo`00<?ooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`000005ooooo`05o`000?ooooooooooooooool000001Oooool01?l0003ooooooooo
ool00006ooooo`03o`000?oooooo00000:gooooo00?oMgMgofIVI_ooool04Oooool00ol0003ooooo
ooooo`0Iooooo`03ofIVI_mgMgOooooo00Oooooo000`ooooo`03o`000?oooooooooo073ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Gooooo00Go0000oooooooooooo
ooooo`000005ooooo`04o`000?ooooooooooo`0000Kooooo0ol0003Wooooo`00<?ooool00ol0003o
ooooooooo`1aooooo`05o`000?ooooooooooooooool000002Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000005ooooo`05o`000?oooooo
ooooooooool000001Oooool01?l0003oooooooooool0003`ooooo`00<?ooool00ol0003ooooooooo
o`1aooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool00005oooo
o`04o`000?ooooooooooo`000?3ooooo000`ooooo`03o`000?oooooooooo077ooooo0_l000000ooo
oooo0000ooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0
003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo00001_ooool00ol0003oooooo`00
003`ooooo`00<?ooool00ol0003oooooooooo`1booooo`;o00002oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?oo
ooooooooo`0000Kooooo00?o0000ooooool00000l?ooool0033ooooo00?o0000ooooooooool0Oooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`000006ooooo`04o`000?ooooooooooo`0000Kooooo0_l0003aooooo`00<?ooool3o`0007oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
00001_ooool01?l0003oooooooooool00006ooooo`;o0000lOooool0033ooooo00?o0000oooooooo
ool0Ooooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`000006ooooo`04o`000?ooooooooooo`000?Wooooo000`ooooo`03o`000?oooooooooo
083ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool000001_ooool01?l0003oooooooooool0003iooooo`00<?ooool00ol0003oooooooooo`20
ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo
00Co0000oooooooooooo0000nOooool0033ooooo00?o0000ooooooooool0P?ooool01Ol0003ooooo
oooooooooooo000000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo0000
00Gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo00000?[ooooo000`oooo
o`03o`000?oooooooooo083ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00Go0000ooooooooooooooooo`000005ooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooo`00003jooooo`00<?ooool00ol0003oooooooooo`20ooooo`05o`000?oo
ooooooooooooool000002Oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooool00000n_ooool0033ooooo00?o0000oooo
ooooool0P?ooool01Ol0003ooooooooooooooooo000000Wooooo00Go0000ooooooooooooooooo`00
0007ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooo
oooooooo000000Gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo00000?[o
oooo000`ooooo`03o`000?oooooooooo083ooooo00Go0000ooooooooooooooooo`000009ooooo`05
o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00?ooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Oooooo0_l0
003jooooo`00<?ooool00ol0003oooooooooo`20ooooo`05o`000?ooooooooooooooool000002Ooo
ool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool00007oooo
o`;o0000n_ooool0033ooooo00?o0000ooooooooool0P?ooool01Ol0003ooooooooooooooooo0000
00Wooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo0000
1oooool2o`000?[ooooo000`ooooo`03o`000?oooooooooo083ooooo00Co0000oooooooooooo0000
2_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool0003o
ooooo`Cooooo000`ooooo`?o0000POooool00ol0003oooooo`00000:ooooo`05o`000?oooooooooo
ooooool000002?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000
ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`000?oooooo1?ooool0033ooooo00?o
0000ooooooooool0POooool00ol0003oooooo`00000:ooooo`05o`000?ooooooooooooooool00000
2?ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000006oooo
o`04o`000?ooooooooooo`000?oooooo1?ooool0033ooooo00?o0000ooooooooool0POooool3o`00
00[ooooo00Go0000ooooooooooooooooo`000008ooooo`05o`000?ooooooooooooooool000001ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooool00000ooooool5ooooo`00<?ooool00ol0003ooooo
ooooo`22ooooo`03o`000?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000008ooooo`05
o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooo
ooooool000001Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooool00000oooo
ool5ooooo`00<?ooool00ol0003oooooooooo`2>ooooo`05o`000?ooooooooooooooool000002?oo
ool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooo
oooooooooooo000000Gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo0000
0?oooooo1Oooool0033ooooo00?o0000ooooooooool0S_ooool01Ol0003ooooooooooooooooo0000
00Sooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Co0000
oooooooooooo00001_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooool00000
ooooool5ooooo`00<?ooool00ol0003oooooooooo`2>ooooo`05o`000?ooooooooooooooool00000
2?ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01?l0003o
ooooooooool00006ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooo`00003o
ooooo`Gooooo000`ooooo`03o`000?oooooooooo08kooooo00Go0000ooooooooooooooooo`000008
ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Ko
oooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo00000?oooooo1Oooool0033o
oooo00?o0000ooooooooool0S_ooool01Ol0003ooooooooooooooooo000000Sooooo00Go0000oooo
ooooooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
1Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo00001_ooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooool00000ooooool5ooooo`00<?ooool00ol0003ooooo
ooooo`2>ooooo`05o`000?ooooooooooooooool000002?ooool01Ol0003ooooooooooooooooo0000
00Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooo
ooooool000001oooool01?l0003oooooooooool00006ooooo`05o`000?ooooooooooooooool00000
1oooool2o`000?oooooo1Oooool0033ooooo00?o0000ooooooooool0S_ooool01Ol0003ooooooooo
oooooooo000000Sooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooooooooooo
ool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo00001_oo
ool01Ol0003ooooooooooooooooo000000Oooooo0_l0003oooooo`Gooooo000`ooooo`03o`000?oo
oooooooo08kooooo00Go0000ooooooooooooooooo`000008ooooo`05o`000?ooooooooooooooool0
00001oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007
ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00001oooool2o`000?oooooo
1Oooool0033ooooo0ol0002>ooooo`05o`000?ooooooooooooooool000002?ooool01Ol0003ooooo
oooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooooooo
ooooool000001oooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Oooooo
0_l0003oooooo`Gooooo000`ooooo`03o`000?oooooooooo08kooooo00Go0000oooooooooooooooo
o`000008ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo0000
00Oooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo00Co
0000oooooooooooo00001oooool2o`000?oooooo1Oooool0033ooooo00?o0000ooooooooool0S_oo
ool01Ol0003ooooooooooooooooo000000Sooooo00Go0000ooooooooooooooooo`000007ooooo`05
o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000
oooooooooooo00001oooool01?l0003oooooooooool0003oooooo`kooooo000`ooooo`03o`000?oo
oooooooo08kooooo00Go0000ooooooooooooooooo`000008ooooo`05o`000?ooooooooooooooool0
00001oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007
ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo0000ooooool>ooooo`00<?oo
ool00ol0003oooooooooo`2?ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooooooo
ooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo
000000Oooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool0003oooooo`kooooo
000`ooooo`03o`000?oooooooooo08oooooo00?o0000ooooool000002Oooool01Ol0003ooooooooo
oooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooooooooooo
ool000001oooool01?l0003oooooooooool00007ooooo`03o`000?oooooo00000?oooooo3oooool0
00oooooo0_o^k^h3ooooo`;ok^k^6_ooool00ol0003oooooooooo`2?ooooo`03o`000?oooooo0000
00Wooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001ooo
ool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo00001oooool00ol0003o
ooooo`00003oooooo`oooooo0008ooooo`Go00000_ooool01oo^k^koEEEEonk^k_ooooook^k^oeEE
EOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`03o`00
0?oooooooooo08oooooo00?o0000ooooool000002Oooool01Ol0003ooooooooooooooooo000000Oo
oooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool0
1?l0003oooooooooool00007ooooo`03o`000?oooooo00000?oooooo3oooool000Sooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ol0003oooooooooo`2?ooooo`03
o`000?oooooo000000Wooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooooooo
ooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000
1oooool00ol0003oooooo`00003oooooo`oooooo0009ooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?o
gMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100
2oooool00ol0003oooooooooo`2?ooooo`03o`000?oooooo000000Wooooo00Go0000oooooooooooo
ooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo
000000Oooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00003oooooo`oooooo000:
ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000;ooooo`03o`000?oooooooooo08oooooo
00?o0000ooooool000002Oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooooooo
ooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool0
0007ooooo`03o`000?oooooo00000?oooooo3oooool000_ooooo00_oMgMgofIVI_ooooooooooonk^
k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`Co0000S_ooool00ol0003oooooo`000009ooooo`05o`000?oooooo
ooooooooool000002?ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Oo
oooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00003oooooo`oooooo000<ooooo`03
o`000?oooooooooo00;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@413o
oooooooooooooooo410@00_ooooo00?o0000ooooooooool0Soooool00ol0003oooooo`000009oooo
o`05o`000?ooooooooooooooool000002?ooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000Oooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00003oooooo`oo
oooo0008ooooo`05o`000?nj^[[ooooooiRHV?l@41003_ooool00ol0003oooooooooo`02ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02oooool00ol0003oooooooooo`2?ooooo`03o`000?oooooo0000
00Wooooo00Go0000ooooooooooooooooo`000008ooooo`04o`000?ooooooooooo`0000Sooooo00Co
0000oooooooooooo00001oooool01?l0003oooooooooool00007ooooo`03o`000?oooooo00000?oo
oooo3oooool000Sooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00<ooooo`03oeEEEOmVIVKo000000Co
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`;o00001_ooool00ol0003oooooooooo`2@oooo
o`;o00002Oooool01Ol0003ooooooooooooooooo000000Sooooo00Co0000oooooooooooo00002?oo
ool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool0
0000ooooool?ooooo`009oooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo093o
oooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooooooo000000Sooooo00Co0000oooo
oooooooo00002?ooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Oooooo
00?o0000ooooool00000ooooool?ooooo`009oooool01?l0003oooooooooool00005ooooo`03o`00
0?oooooooooo09_ooooo00Go0000ooooooooooooooooo`000008ooooo`04o`000?ooooooooooo`00
00Sooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool00008ooooo`;o0000oooo
ool?ooooo`009oooool3o`0000Kooooo00?o0000ooooooooool0Voooool01Ol0003ooooooooooooo
oooo000000Sooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00007ooooo`04
o`000?ooooooooooo`0000Sooooo0_l0003oooooo`oooooo000Xooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0Voooool01Ol0003ooooooooooooooooo000000Sooooo00Co0000oooo
oooooooo00002?ooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Sooooo
00?o0000ooooooooool0ooooool>ooooo`00:Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo09_ooooo00Go0000ooooooooooooooooo`000008ooooo`04o`000?ooooooooooo`0000So
oooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo
oooo0?oooooo3_ooool0033ooooo00?o0000ooooooooool0W?ooool01?l0003oooooooooool00008
ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001oooool01?l0003ooooo
ooooool00008ooooo`03o`000?oooooooooo0?oooooo3_ooool0033ooooo00?o0000ooooooooool0
W?ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooo
oooooooo00001oooool01?l0003oooooooooool0003ooooooaWooooo000`ooooo`03o`000?oooooo
oooo09cooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00008ooooo`04o`00
0?ooooooooooo`0000Oooooo00Co0000oooooooooooo0000oooooolIooooo`00<?ooool3o`0009co
oooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00008ooooo`04o`000?oooooo
ooooo`0000Oooooo00Co0000oooooooooooo0000oooooolIooooo`00<?ooool00ol0003ooooooooo
o`2Looooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002?ooool01?l0003o
ooooooooool00007ooooo`04o`000?ooooooooooo`000?oooooo6Oooool0033ooooo00?o0000oooo
ooooool0W?ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo00Co
0000oooooooooooo00001oooool01?l0003oooooooooool0003ooooooaWooooo000`ooooo`03o`00
0?oooooooooo09cooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo0000oooooolIooooo`00<?ooool0
0ol0003oooooooooo`2Looooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`000?oooooo6Oooool0033o
oooo00?o0000ooooooooool0W?ooool00ol0003oooooo`000009ooooo`04o`000?ooooooooooo`00
00Sooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool0003ooooooaWooooo000`
ooooo`03o`000?oooooooooo09cooooo00?o0000ooooool000002Oooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo0000oooooolIooooo`00
<?ooool00ol0003oooooooooo`2Looooo`03o`000?oooooo000000Wooooo00Co0000oooooooooooo
00002?ooool01?l0003oooooooooool00008ooooo`;o0000oooooolJooooo`00<?ooool00ol0003o
ooooooooo`2Looooo`03o`000?oooooo000000Wooooo00Co0000oooooooooooo00002?ooool01?l0
003oooooooooool00008ooooo`;o0000oooooolJooooo`00<?ooool00ol0003oooooooooo`2Loooo
o`03o`000?oooooo000000Wooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0
0008ooooo`;o0000oooooolJooooo`00<?ooool00ol0003oooooooooo`2Looooo`03o`000?oooooo
000000Wooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00008ooooo`;o0000
oooooolJooooo`00<?ooool00ol0003oooooooooo`2Looooo`03o`000?oooooo000000Wooooo00Co
0000oooooooooooo00002?ooool01?l0003oooooooooool00008ooooo`;o0000oooooolJooooo`00
<?ooool3o`0009cooooo00?o0000ooooool000002Oooool01?l0003oooooooooool00008ooooo`04
o`000?ooooooooooo`0000Sooooo0_l0003ooooooa[ooooo000`ooooo`03o`000?oooooooooo09co
oooo00?o0000ooooool000002Oooool01?l0003oooooooooool00008ooooo`04o`000?oooooooooo
o`0000Sooooo0_l0003ooooooa[ooooo000`ooooo`03o`000?oooooooooo09gooooo0_l00009oooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002?ooool2o`000?oooooo6_oo
ool0033ooooo00?o0000ooooooooool0WOooool2o`0000Wooooo00Co0000oooooooooooo00002?oo
ool01?l0003oooooooooool00008ooooo`;o0000oooooolJooooo`00<?ooool00ol0003ooooooooo
o`2Mooooo`;o00002Oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo000000Wooooo
0_l0003ooooooa[ooooo000`ooooo`03o`000?oooooooooo09gooooo00?o0000ooooooooool02?oo
ool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?oooooo9Oooool0033ooooo00?o
0000ooooooooool0Z?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?oooooo
9Oooool0033ooooo00?o0000ooooooooool0ZOooool2o`0000Wooooo00?o0000ooooool00000oooo
oolUooooo`00<?ooool00ol0003oooooooooo`2Yooooo`;o00002Oooool00ol0003oooooo`00003o
ooooobGooooo000`ooooo`03o`000?oooooooooo0:Wooooo0_l00009ooooo`03o`000?oooooo0000
0?oooooo9Oooool0033ooooo00?o0000ooooooooool0ZOooool2o`0000[ooooo0_l0003oooooobGo
oooo000`ooooo`03o`000?oooooooooo0:Wooooo0_l0000:ooooo`;o0000oooooolUooooo`00<?oo
ool3o`000:Wooooo0_l0000:ooooo`;o0000oooooolUooooo`00<?ooool00ol0003oooooooooo`2Y
ooooo`;o00002_ooool2o`000?oooooo9Oooool0033ooooo00?o0000ooooooooool0ZOooool2o`00
00[ooooo0_l0003oooooobGooooo000`ooooo`03o`000?oooooooooo0:Wooooo0_l0000:ooooo`;o
0000oooooolUooooo`00<?ooool00ol0003oooooooooo`2Yooooo`;o00002_ooool2o`000?oooooo
9Oooool0033ooooo00?o0000ooooooooool0ZOooool2o`0000[ooooo0_l0003oooooobGooooo000?
ooooo`;ok^k^0oooool2onk^kQ[ooooo00?o0000ooooooooool0ZOooool2o`0000[ooooo00?o0000
ooooooooool0oooooolTooooo`002_ooool2o`00000:oa0@4?ooooooooooonk^k_mEEEGok^k^oooo
ooo^k^koEEEEonk^kP?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^2ooo
ool00ol0003oooooooooo`2Yooooo`;o0000oooooolaooooo`002oooool00ol0003oooooooooo`02
ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool00ol0003oooooooooo`3oooooomcooooo0008ooooo`Go00001?oo
ool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooo
oa0@400;ooooo`03o`000?oooooooooo0?oooooog?ooool000Sooooo00CoA4A4omgMgOoooooo0000
1?ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000000_ooooo00?o0000ooooooooool0oooooooLooooo`002?ooool01?oMgMgo
EEEEooooool00003ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000;ooooo`Co0000oooooooKooooo`002Ooo
ool00omgMgOoc<c<o`000003ooooo`;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00?o0000ooooooooool0oooooooLooooo`002Ooo
ool00oo^k^koA4A4o`00000?ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`03o`000?oooooooooo0?oooooog?ooool000[ooooo00?oMgMgo`000?ooool03?oo
ool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool2o`0000Kooooo
00?o0000ooooooooool0oooooooLooooo`009oooool01?l0003oooooooooool00005ooooo`03o`00
0?oooooooooo0?oooooog?ooool002Oooooo00Co0000oooooooooooo00001Oooool00ol0003ooooo
ooooo`3oooooomcooooo000Wooooo`?o00001_ooool00ol0003oooooooooo`3oooooomcooooo000X
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooooLooooo`00:Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0033ooooo0ol0003oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooo
ooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000
ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03
o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?oo
ool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0
033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool3o`000?oooooog?ooool0033ooooo
00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`
ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLoooo
o`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooo
g?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`?o0000oooo
oooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooo
ooooo`3oooooomcooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooo
oa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003o
oooooooooooo4?ooool00?ooooooooooool@ooooo`00X?ooool2o`0000Cooooo00?o^[Zjoc8b<_oo
ool01?ooool2o`0000Kooooo00?o0000okZj^_ooool0oooooomGooooo`00X?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool2oc8b<_oooooo
F?ooool008gooooo0ol00002ooooo`06oc8b<_l@413oooooooooooo^k^koEEEE0_l000000om4A4Co
^[Zjooooo`03ooooo`03o`000?oooooooooo00;ooooo00GoV9RHoa0@4?l0003o0000ojVYZ@04oooo
o`03o`000?oooooooooo00Cooooo00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co
^[Zj00Wooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c005ooooo`;o8B4Q1?ooool5o`000006ooooooo<
c<cok^k^ooooooo^k^koc<c<1?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^hCooooo`06oa0@4?lb<S;o0000o`000?l@413oZJVY0_ooool01_o^k^koEEEEo`000?l0003oA4A4
okZj^P?ooooo00GoIVIVo`000?l0003oA4A4olc<c03Xooooo`00S_ooool01Ol0003oooooooooooo<
c<co410@00?ooooo00KoEEEEogMgMoooooook^k^ogMgMol@4104ooooo`03o`000?oooooooooo00;o
oooo00Ko0000ojVYZOmEEEGoV9RHoeEEEOnj^[X3ooooo`03o`000?oooooooooo00Cooooo00?oc<c<
o`000?l@41003?ooool01_l@413o^[Zjonk^k_mgMgOo410@ooooo`Ko00000_ooool01OlQ8B7oV9RH
oooooonHV9So8B4Q00Gooooo0_lQ8B44ooooo`0;oiRHV?lQ8B7ok^k^oooooom4A4Coooooonk^k_mE
EEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL04oooool01_l0003oZJVYoooooooooooo^[Zjo`0000;ooooo00KoEEEEogMgMoooooook^k^ogMg
Mol@4102ooooo`06ofIVI_mgMgOooooooooooon7QhOo410@j?ooool008kooooo00Go0000oooooooo
ooooEEEEohN7Q`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool01_lb
<S;ok^k^oiRHV?mEEEGogMgMoa0@40?ooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0;ooooo`05o`000?ooooooooooooooool000003?ooool00onHV9So8B4Qonk^kP03ooooo`03omgM
gOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01Co
oooo00Go^[ZjohN7QomVIVKoIVIVoa0@4002ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0joooool008kooooo00Go0000oooooooMgMgo0000onk^kP03ooooo`Ko00001?ooool00ol0
003oooooooooo`02ooooo`07okZj^_m4A4Coc<c<ob4Q8Ooooooo410@olc<c002ooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool00oooool6o`0000;ooooo00Go<S8boiRHV?ooooooV9RH
oc8b<P0=ooooo`09oiRHV?lQ8B7ok^k^ooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000001?ooooo00Ko<S8bob4Q8OmgMgOoMgMg
ohN7Qoo^k^h2ooooo`Ko00000_ooool00ol0003oooooooooo`3[ooooo`00S_ooool3o`000003oa0@
4?nHV9Sooooo00;ooooo00KoEEEEohN7Qoo^k^koooooohN7Qolb<S84ooooo`03o`000?oooooooooo
00;ooooo00Ook^k^o`000?oooooo0000oooooomVIVKoQhN700;ooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0;ooooo`05olc<c?l0003o0000o`000?o<c<`03_ooool02?mgMgOoIVIV
ooooooo<c<cok^k^ooooooo^k^koc<c<1_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000004oooool01_l0003o^[Zjooooooo^k^koMgMgo`0000;ooooo00KoEEEEohN7Qoo^
k^koooooohN7Qolb<S82ooooo`06ofIVI_mgMgOooooooooooon7QhOo0000j?ooool008kooooo00Go
0000ooooooooooooc<c<o`000003ooooo`06onk^k_mEEEGo0000o`000?m4A4Cok^k^1?ooool00ol0
003oooooooooo`02ooooo`04ofIVI_nHV9Sooooooc8b<P;o^[Zj00Co0000oooooooooooo00004ooo
ool00ol@413o0000o`000003o`0000[ooooo00Go410@okZj^_oooooo^[Zjoa0@400?ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Oo
oooo0ol00002ooooo`?o00001?ooool01_nYZJWo8B4Qo`000?l0003o<S8bo`0000;ooooo00Kok^k^
oeEEEOl0003o0000odA4A?o^k^h2ooooo`06onk^k_mVIVKo0000o`000?m4A4Co0000j?ooool008ko
oooo00Go0000ooooooooooooc<c<o`00000=ooooo`03o`000?oooooooooo00Gooooo00?oIVIVohN7
Qoooool00oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00_ooooo00Go0000okZj
^_oooooo^[Zjo`00000;ooooo`05o`000?nj^[[ooooooiRHV?l@41003?ooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo0?oooooo0_ooool008gooooo1?l000000ol@413oZJVYooooo`0<ooooo`;o00001_oo
ool00onYZJWoA4A4ooooo`02ooooo`;o00005Oooool00ol0003oooooooooo`0;ooooo`05ojVYZOl@
413o0000oa0@4?nYZJT02oooool01OnHV9So410@o`000?lQ8B7oc<c<00[ooooo00?oEEEEofIVI_l0
00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo1?l00002ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0ooooool2ooooo`00ooooool6ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0ooooool2ooooo`00ooooool6ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0ooooool2ooooo`00ooooool5ooooo`;o00000oooool2o`000?oooooo1?oo
ool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooo
ooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@oooo
o`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooo
oooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo
003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooo
oooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo0000\
\>"],
  ImageRangeCache->{{{0, 525.688}, {324.5, 0}} -> {-2.58312*^-7, -6.34248*^6, \
6.65005*^-9, 53093.5}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0.309017 5.42214e-08 [
[.32684 .29652 -16.5 -12.5 ]
[.32684 .29652 16.5 0 ]
[.54329 .29652 -16.5 -12.5 ]
[.54329 .29652 16.5 0 ]
[.75974 .29652 -22.5 -12.5 ]
[.75974 .29652 22.5 0 ]
[.97619 .29652 -16.5 -12.5 ]
[.97619 .29652 16.5 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 64 6 ]
[.09789 .09213 -34.5 -6.25 ]
[.09789 .09213 0 6.25 ]
[.09789 .20057 -34.5 -6.25 ]
[.09789 .20057 0 6.25 ]
[.09789 .41746 -28.5 -6.25 ]
[.09789 .41746 0 6.25 ]
[.09789 .5259 -28.5 -6.25 ]
[.09789 .5259 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -62.8125 0 ]
[.5 .63053 62.8125 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 .30902 m
.32684 .31527 L
s
gsave
.32684 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 .30902 m
.54329 .31527 L
s
gsave
.54329 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 .30902 m
.75974 .31527 L
s
gsave
.75974 .29652 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 .30902 m
.15368 .31277 L
s
.19697 .30902 m
.19697 .31277 L
s
.24026 .30902 m
.24026 .31277 L
s
.28355 .30902 m
.28355 .31277 L
s
.37013 .30902 m
.37013 .31277 L
s
.41342 .30902 m
.41342 .31277 L
s
.45671 .30902 m
.45671 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.58658 .30902 m
.58658 .31277 L
s
.62987 .30902 m
.62987 .31277 L
s
.67316 .30902 m
.67316 .31277 L
s
.71645 .30902 m
.71645 .31277 L
s
.80303 .30902 m
.80303 .31277 L
s
.84632 .30902 m
.84632 .31277 L
s
.88961 .30902 m
.88961 .31277 L
s
.9329 .30902 m
.9329 .31277 L
s
.0671 .30902 m
.0671 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09213 m
.11664 .09213 L
s
gsave
.09789 .09213 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .20057 m
.11664 .20057 L
s
gsave
.09789 .20057 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .41746 m
.11664 .41746 L
s
gsave
.09789 .41746 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .5259 m
.11664 .5259 L
s
gsave
.09789 .5259 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.11039 .11924 m
.11414 .11924 L
s
.11039 .14635 m
.11414 .14635 L
s
.11039 .17346 m
.11414 .17346 L
s
.11039 .22768 m
.11414 .22768 L
s
.11039 .2548 m
.11414 .2548 L
s
.11039 .28191 m
.11414 .28191 L
s
.11039 .33613 m
.11414 .33613 L
s
.11039 .36324 m
.11414 .36324 L
s
.11039 .39035 m
.11414 .39035 L
s
.11039 .44457 m
.11414 .44457 L
s
.11039 .47168 m
.11414 .47168 L
s
.11039 .49879 m
.11414 .49879 L
s
.11039 .06502 m
.11414 .06502 L
s
.11039 .03791 m
.11414 .03791 L
s
.11039 .0108 m
.11414 .0108 L
s
.11039 .55301 m
.11414 .55301 L
s
.11039 .58012 m
.11414 .58012 L
s
.11039 .60723 m
.11414 .60723 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -123.812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.812 moveto
(@) show
81.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.812 moveto
(D) show
93.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8.4) show
135.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
141.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
153.000 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
157.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
166.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
184.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02532 .30902 L
.02691 .30902 L
.02866 .30902 L
.03029 .30902 L
.03335 .30902 L
.03648 .30902 L
.0398 .30902 L
.04301 .30902 L
.04609 .30902 L
.04937 .30902 L
.05253 .30902 L
.05557 .30902 L
.0588 .30902 L
.06191 .30902 L
.06522 .30902 L
.06841 .30902 L
.07148 .30902 L
.07474 .30902 L
.07788 .30902 L
.08122 .30902 L
.08289 .30902 L
.08443 .30902 L
.08594 .30902 L
.0867 .30902 L
.08713 .30902 L
.08732 .30902 L
.08753 .30902 L
.08763 .30902 L
.08774 .30902 L
.08784 .30902 L
.08793 .30902 L
.08798 .30902 L
.08804 .30902 L
.08809 .30902 L
.08815 .30902 L
.08821 .30902 L
.08826 .30902 L
.08837 .30902 L
.08847 .30902 L
.08853 .30902 L
.08858 .30902 L
.08868 .30902 L
.08878 .30902 L
.08897 .30902 L
.08916 .30902 L
.08953 .30902 L
.08993 .30902 L
.09031 .30902 L
.09065 .30902 L
Mistroke
.09144 .30902 L
.09218 .30902 L
.09298 .30902 L
.09384 .30902 L
.09467 .30902 L
.09556 .30902 L
.09718 .30902 L
.09879 .30902 L
.10048 .30902 L
.10206 .30902 L
.10353 .30902 L
.10666 .30902 L
.10837 .30902 L
.10998 .30902 L
.11306 .30902 L
.11465 .30902 L
.11634 .30902 L
.11938 .30902 L
.12261 .30902 L
.12572 .30902 L
.12902 .30902 L
.13221 .30902 L
.13527 .30902 L
.13853 .30902 L
.14167 .30902 L
.14249 .30902 L
.14339 .30902 L
.1438 .30902 L
.14423 .30902 L
.1446 .30902 L
.14481 .30902 L
.145 .30902 L
.14521 .30902 L
.14531 .30902 L
.14537 .30902 L
.14542 .30902 L
.14552 .30902 L
.14561 .30902 L
.14567 .30902 L
.14572 .30902 L
.14582 .30902 L
.14591 .30902 L
.14601 .30902 L
.1461 .30902 L
.14618 .30902 L
.14638 .30902 L
.14657 .30902 L
.14699 .30902 L
.14737 .30902 L
.1478 .30902 L
Mistroke
.14825 .30902 L
.149 .30902 L
.14982 .30902 L
.15058 .30902 L
.15128 .30902 L
.15281 .30902 L
.15447 .30902 L
.15605 .30902 L
.15774 .30902 L
.15946 .30902 L
.16108 .30902 L
.16417 .30902 L
.16747 .30902 L
.17064 .30902 L
.17369 .30902 L
.17693 .30902 L
.18006 .30902 L
.18165 .30902 L
.18338 .30902 L
.18419 .30902 L
.18504 .30902 L
.18539 .30902 L
.18577 .30902 L
.18599 .30902 L
.18619 .30902 L
.18638 .30902 L
.18658 .30902 L
.18668 .30902 L
.18673 .30902 L
.18679 .30902 L
.18689 .30902 L
.18698 .30902 L
.18707 .30902 L
.18715 .30902 L
.18725 .30902 L
.18735 .30902 L
.18745 .30902 L
.18757 .30902 L
.18777 .30902 L
.18798 .30902 L
.18816 .30902 L
.18854 .30902 L
.18888 .30902 L
.18964 .30902 L
.19003 .30902 L
.19045 .30902 L
.19119 .30902 L
.19199 .30902 L
.19286 .30902 L
.19443 .30902 L
Mistroke
.19611 .30902 L
.19782 .30902 L
.19944 .30902 L
.20252 .30902 L
.2058 .30902 L
.20896 .30901 L
.21199 .30901 L
.21523 .30901 L
.21671 .30901 L
.21834 .30901 L
.21876 .30901 L
.21922 .30901 L
.21961 .30901 L
.22003 .30901 L
.22026 .30901 L
.22047 .30901 L
.22067 .30901 L
.22077 .30901 L
.22082 .30901 L
.22088 .30901 L
.22098 .30901 L
.22107 .30901 L
.22117 .30901 L
.22122 .30901 L
.22127 .30901 L
.22136 .30901 L
.22145 .30901 L
.22155 .30901 L
.22164 .30901 L
.22184 .30901 L
.22202 .30901 L
.22243 .30901 L
.22283 .30901 L
.22326 .30901 L
.22404 .30901 L
.22475 .30901 L
.22555 .30901 L
.22629 .30901 L
.22796 .30901 L
.22946 .30902 L
.23112 .30902 L
.23436 .30902 L
.23747 .30903 L
.24078 .30903 L
.24397 .30904 L
.24558 .30904 L
.24704 .30905 L
.2478 .30905 L
.24862 .30905 L
.24908 .30905 L
Mistroke
.24949 .30905 L
.24989 .30905 L
.25009 .30905 L
.2502 .30905 L
.25031 .30905 L
.2504 .30905 L
.25051 .30905 L
.25057 .30905 L
.25062 .30905 L
.25067 .30905 L
.25073 .30905 L
.25083 .30905 L
.25088 .30905 L
.25094 .30905 L
.25104 .30905 L
.25113 .30905 L
.25123 .30905 L
.25132 .30905 L
.25149 .30905 L
.25168 .30905 L
.25188 .30905 L
.2523 .30905 L
.25275 .30905 L
.25356 .30905 L
.25432 .30905 L
.25513 .30904 L
.2566 .30904 L
.2583 .30903 L
.25992 .30902 L
.26299 .30899 L
.26626 .30896 L
.26941 .30892 L
.27244 .30888 L
.27399 .30887 L
.27478 .30886 L
.27521 .30886 L
.27566 .30886 L
.27609 .30886 L
.27649 .30886 L
.27668 .30885 L
.27689 .30885 L
.27698 .30885 L
.27708 .30885 L
.27718 .30885 L
.27726 .30885 L
.27737 .30885 L
.27746 .30885 L
.27757 .30885 L
.27763 .30885 L
.27768 .30885 L
Mistroke
.27778 .30885 L
.27787 .30885 L
.27797 .30885 L
.27807 .30885 L
.27829 .30885 L
.2785 .30886 L
.27896 .30886 L
.27933 .30886 L
.27974 .30886 L
.28047 .30887 L
.28134 .30888 L
.28213 .30889 L
.28366 .30892 L
.28533 .30897 L
.2886 .30909 L
.29175 .30925 L
.29478 .3094 L
.29647 .30949 L
.29801 .30955 L
.2988 .30958 L
.29952 .3096 L
.30029 .30962 L
.30069 .30962 L
.3009 .30963 L
.30112 .30963 L
.30132 .30963 L
.30143 .30963 L
.30155 .30963 L
.30165 .30963 L
.30175 .30963 L
.30185 .30963 L
.30194 .30963 L
.302 .30963 L
.30205 .30963 L
.30211 .30963 L
.30216 .30963 L
.30226 .30963 L
.30237 .30963 L
.30248 .30963 L
.30261 .30963 L
.30283 .30963 L
.30302 .30963 L
.30323 .30962 L
.3036 .30962 L
.30405 .3096 L
.30445 .30959 L
.30525 .30956 L
.30598 .30952 L
.30765 .3094 L
.30915 .30925 L
Mistroke
.31081 .30904 L
.31404 .30853 L
.31715 .30798 L
.31873 .30771 L
.32046 .30745 L
.32126 .30736 L
.32211 .30727 L
.32252 .30723 L
.32291 .30721 L
.32329 .30718 L
.32364 .30717 L
.32382 .30716 L
.32402 .30716 L
.32413 .30715 L
.32423 .30715 L
.32432 .30715 L
.32443 .30715 L
.32452 .30715 L
.32458 .30715 L
.32463 .30715 L
.32469 .30715 L
.32474 .30715 L
.3248 .30715 L
.32486 .30715 L
.32495 .30715 L
.32504 .30715 L
.32525 .30716 L
.32545 .30716 L
.32563 .30717 L
.32597 .30719 L
.32634 .30721 L
.32674 .30725 L
.32749 .30734 L
.32833 .30747 L
.33002 .30784 L
.33158 .30831 L
.33325 .30895 L
.33656 .31049 L
.33975 .31207 L
.34136 .31276 L
.34282 .31327 L
.34364 .31349 L
.34401 .31357 L
.3444 .31364 L
.3446 .31367 L
.34482 .31369 L
.34503 .31371 L
.34521 .31373 L
.34532 .31374 L
.34543 .31374 L
Mistroke
.34549 .31375 L
.34555 .31375 L
.34561 .31375 L
.34566 .31375 L
.34576 .31375 L
.34581 .31375 L
.34587 .31375 L
.34592 .31375 L
.34598 .31375 L
.34609 .31375 L
.34619 .31375 L
.34629 .31374 L
.34649 .31373 L
.34668 .31371 L
.34685 .31369 L
.34725 .31363 L
.34767 .31355 L
.34838 .31335 L
.34915 .31307 L
.34996 .31267 L
.35071 .31223 L
.35239 .31098 L
.35558 .30773 L
.35865 .30406 L
.36037 .3021 L
.36192 .30056 L
.3627 .29993 L
.36354 .29937 L
.36393 .29916 L
.36434 .29898 L
.36469 .29885 L
.36507 .29875 L
.36527 .29871 L
.36538 .2987 L
.36549 .29868 L
.36559 .29867 L
.36565 .29867 L
.3657 .29867 L
.36579 .29866 L
.36589 .29866 L
.36599 .29866 L
.36609 .29867 L
.36619 .29867 L
.36628 .29868 L
.36646 .29871 L
.36664 .29874 L
.36686 .2988 L
.36709 .29887 L
.36752 .29905 L
.36794 .29928 L
Mistroke
.36832 .29954 L
.3691 .30021 L
.36983 .301 L
.37149 .30342 L
.37312 .30654 L
.37461 .3099 L
.37781 .31792 L
.38089 .32489 L
.38171 .32631 L
.38247 .32741 L
.38328 .32828 L
.3837 .32861 L
.38394 .32876 L
.38416 .32886 L
.38436 .32893 L
.38445 .32896 L
.38454 .32898 L
.38464 .329 L
.38469 .32901 L
.38475 .32901 L
.38484 .32902 L
.38495 .32902 L
.38504 .32901 L
.38513 .329 L
.38523 .32898 L
.38533 .32896 L
.38549 .32891 L
.38568 .32883 L
.3859 .32871 L
.3861 .32858 L
.38654 .32819 L
.38695 .32772 L
.38734 .32718 L
.38813 .32578 L
.38896 .32389 L
.39044 .31947 L
.39349 .30701 L
.39674 .29164 L
.39824 .28513 L
.39987 .27936 L
.40075 .277 L
.40114 .27618 L
.40157 .27544 L
.40177 .27516 L
.40198 .2749 L
.40216 .27472 L
.40236 .27455 L
.40257 .27442 L
.40268 .27437 L
.40274 .27435 L
Mistroke
.40279 .27434 L
.40289 .27432 L
.40298 .27431 L
.40308 .27431 L
.40314 .27431 L
.40319 .27432 L
.40329 .27434 L
.40339 .27438 L
.40347 .27442 L
.40357 .27447 L
.40378 .27462 L
.40397 .2748 L
.40432 .27525 L
.4047 .27589 L
.40549 .27777 L
.40636 .28068 L
.40791 .28797 L
.40958 .29849 L
.41288 .32422 L
.41452 .33737 L
.41606 .34833 L
.41753 .35673 L
.41836 .36018 L
.41872 .36135 L
.41911 .36239 L
.4195 .36316 L
.41971 .36347 L
.41982 .36359 L
.41991 .36369 L
.42 .36376 L
.4201 .36382 L
.42019 .36387 L
.42027 .36389 L
.42037 .36391 L
.42045 .3639 L
.42056 .36388 L
.42065 .36385 L
.42075 .36379 L
.42085 .36371 L
.42107 .36348 L
.42127 .36318 L
.42145 .36284 L
.42187 .36182 L
.42232 .36034 L
.42314 .35662 L
.42403 .35113 L
.42564 .33758 L
.42892 .29984 L
.43054 .27915 L
.43207 .26088 L
Mistroke
.43355 .24591 L
.43435 .2394 L
.4351 .23463 L
.43547 .23276 L
.43587 .23117 L
.4361 .23045 L
.43632 .22991 L
.43651 .22953 L
.43662 .22936 L
.43672 .22924 L
.43681 .22916 L
.4369 .2291 L
.437 .22905 L
.4371 .22904 L
.43719 .22906 L
.43725 .22908 L
.4373 .22911 L
.43739 .22918 L
.43749 .22929 L
.43769 .22958 L
.43787 .22995 L
.43821 .23092 L
.43858 .2324 L
.43899 .23451 L
.43982 .24031 L
.44059 .24748 L
.44131 .25561 L
.44443 .30415 L
.44776 .36436 L
.44943 .39005 L
.45016 .39921 L
.45096 .40737 L
.45134 .41038 L
.45174 .41304 L
.45211 .41499 L
.45228 .41567 L
.45246 .41627 L
.45256 .41657 L
.45266 .41679 L
.45276 .41698 L
.45285 .41712 L
.45295 .41724 L
.45301 .41729 L
.45307 .41732 L
.45316 .41735 L
.45322 .41734 L
.45327 .41732 L
.45337 .41726 L
.45347 .41716 L
.45355 .41703 L
Mistroke
.45365 .41686 L
.45385 .41634 L
.45405 .41569 L
.45442 .41398 L
.45482 .41146 L
.45554 .40514 L
.45641 .39476 L
.4572 .38269 L
.46038 .31524 L
.46343 .24059 L
.46514 .20556 L
.46594 .19251 L
.46669 .183 L
.46705 .17929 L
.46746 .17601 L
.46787 .1736 L
.46809 .17267 L
.46819 .17235 L
.4683 .17206 L
.4684 .17184 L
.46849 .1717 L
.46858 .17161 L
.46868 .17157 L
.46878 .17158 L
.46887 .17164 L
.46895 .17173 L
.46903 .17187 L
.46913 .17207 L
.46923 .17236 L
.46944 .17313 L
.46964 .17408 L
.46982 .17516 L
.47022 .17825 L
.47066 .18268 L
.47146 .19349 L
.47223 .20727 L
.47295 .22262 L
.4761 .31161 L
.47913 .40367 L
.48069 .44085 L
.48156 .45634 L
.48195 .46173 L
.48236 .46641 L
.48258 .46837 L
.48278 .46993 L
.48297 .47117 L
.48315 .47208 L
.48332 .47273 L
.48341 .47297 L
.4835 .47318 L
Mistroke
.4836 .47332 L
.4837 .4734 L
.4838 .47341 L
.48388 .47335 L
.48399 .47322 L
.48404 .47312 L
.4841 .47298 L
.48429 .47235 L
.4844 .47186 L
.48452 .47124 L
.48474 .46984 L
.48516 .46612 L
.48555 .46155 L
.48633 .44902 L
.48706 .43363 L
.48872 .38711 L
.49185 .27381 L
.49345 .21622 L
.49429 .18923 L
.49518 .16454 L
.49597 .14676 L
.49639 .13915 L
.49685 .1325 L
.49706 .12995 L
.49726 .12786 L
.49746 .12617 L
.49764 .12489 L
.49781 .12395 L
.4979 .12357 L
.498 .12323 L
.4981 .12295 L
.4982 .12278 L
.4983 .12269 L
.49839 .12268 L
.49849 .12276 L
.49858 .12291 L
.49867 .12312 L
.49876 .12343 L
.49897 .12439 L
.49917 .12563 L
.49952 .12875 L
.4999 .13326 L
.50068 .14664 L
.50156 .1672 L
.50311 .21687 L
.50478 .28346 L
.50636 .35089 L
.50808 .42001 L
.50888 .44747 L
.50973 .47225 L
Mistroke
.51015 .48229 L
.51054 .49046 L
.51091 .49707 L
.51127 .50208 L
.51164 .50607 L
.51183 .50765 L
.51205 .50891 L
.51215 .50937 L
.51221 .50957 L
.51227 .50975 L
.51232 .50988 L
.51238 .50998 L
.51248 .51009 L
.51258 .5101 L
.51268 .51 L
.51278 .5098 L
.51287 .50953 L
.51296 .5092 L
.51305 .50876 L
.51322 .50776 L
.51341 .5062 L
.51359 .50445 L
.51398 .49952 L
.51435 .4935 L
.51513 .47666 L
.51595 .45307 L
.51743 .39848 L
.52047 .26136 L
.52216 .18953 L
.52289 .16287 L
.5237 .13841 L
.52408 .12881 L
.52449 .12006 L
.52484 .11381 L
.52522 .10845 L
.52544 .106 L
.52565 .10421 L
.52584 .10294 L
.52594 .10245 L
.526 .10223 L
.52605 .10204 L
.52615 .10179 L
.52624 .10165 L
.52634 .10159 L
.52644 .10165 L
.52654 .10181 L
.52663 .10207 L
.52672 .10238 L
.52681 .10281 L
.527 .10398 L
Mistroke
.5272 .1057 L
.52762 .11056 L
.528 .11668 L
.52836 .12376 L
.52917 .14434 L
.53003 .17272 L
.53336 .32063 L
.53503 .39806 L
.53576 .42846 L
.53657 .45781 L
.53729 .47959 L
.53807 .4975 L
.5385 .50472 L
.53889 .50959 L
.53908 .51132 L
.53918 .51207 L
.53928 .51275 L
.53938 .51328 L
.53948 .51367 L
.53957 .51395 L
.53966 .51413 L
.53975 .51423 L
.53985 .51422 L
.53994 .51411 L
.54003 .51392 L
.54013 .51359 L
.54024 .51309 L
.54044 .51185 L
.54065 .51006 L
.54087 .50763 L
.54127 .50191 L
.54197 .48764 L
.54275 .46619 L
.54431 .40849 L
.54598 .33208 L
.54756 .25717 L
.54928 .1848 L
.55008 .15809 L
.55052 .14577 L
.55093 .13585 L
.55132 .12817 L
.55174 .12163 L
.55192 .11935 L
.55212 .11735 L
.55228 .11598 L
.55247 .11484 L
.55257 .11437 L
.55267 .11403 L
.55277 .11379 L
.55283 .11371 L
Mistroke
.55289 .11367 L
.55298 .11369 L
.55304 .11375 L
.55309 .11383 L
.55318 .11406 L
.55328 .11442 L
.55337 .11483 L
.55347 .11537 L
.55364 .1166 L
.55384 .1185 L
.55403 .12063 L
.55444 .1267 L
.55489 .13534 L
.55571 .1561 L
.5573 .21234 L
.55899 .28628 L
.56057 .35813 L
.56202 .41658 L
.56277 .44134 L
.56358 .46304 L
.56403 .47228 L
.56444 .47905 L
.56483 .48384 L
.56506 .48578 L
.56516 .48651 L
.56526 .48708 L
.56535 .48755 L
.56544 .4879 L
.56554 .48817 L
.56565 .48835 L
.56575 .48841 L
.56581 .48839 L
.56586 .48834 L
.56596 .48816 L
.56606 .48787 L
.56615 .48753 L
.56624 .48707 L
.56641 .48599 L
.56661 .4843 L
.5668 .48237 L
.56719 .47717 L
.56761 .46973 L
.56847 .44957 L
.57004 .39771 L
.57173 .32929 L
.57332 .26265 L
.57416 .2306 L
.57506 .20099 L
.57585 .17948 L
.57627 .17024 L
Mistroke
.57673 .16214 L
.57714 .15644 L
.57752 .15274 L
.5777 .15148 L
.5778 .15095 L
.5779 .15049 L
.578 .15015 L
.57809 .14992 L
.57818 .14978 L
.57826 .14972 L
.57836 .14974 L
.57846 .14987 L
.57855 .15007 L
.57864 .15034 L
.57874 .15075 L
.57885 .15132 L
.57905 .15265 L
.57926 .15447 L
.57948 .15686 L
.57988 .16232 L
.58058 .1755 L
.58136 .19471 L
.58459 .30695 L
.58608 .36105 L
.58692 .38806 L
.5877 .40943 L
.58848 .42635 L
.58892 .43367 L
.58931 .43889 L
.58952 .44103 L
.58973 .44289 L
.58984 .4437 L
.58997 .44445 L
.59008 .44502 L
.59018 .44543 L
.59029 .44575 L
.59039 .44595 L
.5905 .44607 L
.59055 .4461 L
.59061 .44609 L
.5907 .44602 L
.5908 .44584 L
.59091 .44557 L
.59101 .44521 L
.5912 .44426 L
.59138 .44308 L
.59179 .43931 L
.5922 .43426 L
.59262 .42744 L
.59411 .39392 L
Mistroke
.59744 .28944 L
.5991 .2412 L
.59984 .22426 L
.60022 .21664 L
.60064 .20962 L
.60105 .20405 L
.60142 .20004 L
.60159 .1985 L
.60179 .19709 L
.60197 .19604 L
.60214 .19531 L
.60224 .19498 L
.60229 .19485 L
.60235 .19472 L
.60245 .19456 L
.60254 .19449 L
.60263 .19448 L
.60272 .19454 L
.60281 .19466 L
.60291 .19487 L
.60301 .19517 L
.60313 .19561 L
.60334 .19665 L
.60354 .19799 L
.60373 .1995 L
.6041 .20326 L
.6045 .20841 L
.60523 .22036 L
.60688 .25768 L
.60846 .30043 L
.61018 .34606 L
.61098 .3642 L
.61183 .38029 L
.61224 .38665 L
.61263 .39171 L
.61301 .39567 L
.61336 .39854 L
.61354 .39968 L
.61374 .40065 L
.61385 .4011 L
.61395 .40145 L
.61404 .40169 L
.61414 .4019 L
.6142 .40198 L
.61425 .40204 L
.61435 .4021 L
.61441 .4021 L
.61446 .40208 L
.61451 .40205 L
.61457 .40198 L
Mistroke
.61467 .40183 L
.61476 .40163 L
.61486 .40134 L
.61497 .40097 L
.61516 .40011 L
.61537 .39891 L
.61575 .39604 L
.61645 .38841 L
.61721 .3773 L
.61804 .36218 L
.61973 .32587 L
.62142 .28847 L
.62296 .2598 L
.62372 .24916 L
.62413 .24467 L
.62456 .24083 L
.62477 .23929 L
.62497 .23807 L
.62516 .2371 L
.62534 .23639 L
.62551 .23588 L
.6256 .23569 L
.62569 .23552 L
.62579 .23541 L
.62589 .23534 L
.62599 .23533 L
.62607 .23536 L
.62617 .23544 L
.62626 .23557 L
.62635 .23575 L
.62646 .23601 L
.62667 .23671 L
.62687 .23757 L
.62723 .23966 L
.6276 .24254 L
.6284 .25074 L
.62927 .26253 L
.63252 .31883 L
.63403 .34232 L
.63487 .35263 L
.63566 .35971 L
.63605 .3623 L
.63628 .36349 L
.63649 .36436 L
.63671 .36508 L
.63683 .36538 L
.63694 .36561 L
.63705 .36576 L
.63715 .36586 L
.6372 .3659 L
Mistroke
.63725 .36592 L
.63731 .36593 L
.63737 .36593 L
.63746 .36589 L
.63757 .3658 L
.63762 .36574 L
.63767 .36566 L
.63777 .36549 L
.63797 .36502 L
.63815 .36445 L
.63858 .36253 L
.63899 .36004 L
.63976 .35365 L
.64059 .34486 L
.64206 .32561 L
.64365 .30356 L
.6451 .28561 L
.64584 .27822 L
.64665 .27199 L
.64707 .26959 L
.64747 .26791 L
.64769 .26721 L
.64788 .26672 L
.64799 .26651 L
.64811 .26633 L
.64817 .26626 L
.64822 .2662 L
.64833 .26612 L
.64842 .26608 L
.64853 .26608 L
.64863 .26611 L
.64872 .26617 L
.64882 .26626 L
.6489 .26637 L
.64909 .26669 L
.64929 .26717 L
.6495 .26784 L
.6499 .26942 L
.65067 .2738 L
.65137 .27913 L
.65455 .31121 L
.65615 .32634 L
.65684 .33159 L
.6576 .33604 L
.65802 .3379 L
.65821 .33857 L
.65841 .3392 L
.65859 .33967 L
.65878 .34007 L
.65888 .34025 L
Mistroke
.65898 .34039 L
.65908 .3405 L
.65917 .34059 L
.65928 .34065 L
.65933 .34068 L
.65939 .34069 L
.65948 .3407 L
.65958 .34068 L
.65964 .34066 L
.6597 .34063 L
.65976 .34058 L
.65982 .34053 L
.65993 .34042 L
.66003 .34027 L
.66024 .33991 L
.66043 .33949 L
.66085 .33823 L
.66122 .3368 L
.66163 .3349 L
.66245 .33012 L
.66393 .31938 L
.66561 .30614 L
.66635 .30078 L
.66716 .29561 L
.66789 .29175 L
.66829 .29003 L
.66867 .28868 L
.66888 .28806 L
.6691 .28748 L
.66929 .28708 L
.66949 .28672 L
.66969 .28646 L
.66979 .28635 L
.66989 .28626 L
.66999 .2862 L
.67007 .28617 L
.67017 .28614 L
.67026 .28613 L
.67036 .28614 L
.67042 .28615 L
.67047 .28617 L
.67056 .28622 L
.67067 .28629 L
.67084 .28646 L
.67103 .28671 L
.67124 .28706 L
.67146 .28751 L
.67185 .28853 L
.67263 .29124 L
.67333 .29438 L
Mistroke
.67499 .30343 L
.67653 .31217 L
.67803 .31929 L
.67878 .32197 L
.67921 .32315 L
.67961 .32403 L
.67999 .32463 L
.68021 .32488 L
.6804 .32505 L
.68051 .32512 L
.68062 .32517 L
.68071 .3252 L
.68081 .32522 L
.68086 .32522 L
.68092 .32522 L
.68098 .32522 L
.68103 .32521 L
.68113 .32518 L
.68119 .32516 L
.68124 .32513 L
.68143 .32501 L
.6816 .32485 L
.68179 .32463 L
.682 .32435 L
.68272 .32292 L
.68347 .32083 L
.68428 .31804 L
.68575 .31218 L
.68733 .30589 L
.68816 .30302 L
.68905 .30055 L
.68949 .29958 L
.68991 .29886 L
.69029 .29836 L
.6905 .29814 L
.6907 .29799 L
.69078 .29793 L
.69088 .29788 L
.69096 .29784 L
.69105 .29781 L
.69115 .29778 L
.69125 .29777 L
.69135 .29776 L
.69144 .29777 L
.69154 .29778 L
.69164 .29781 L
.69173 .29784 L
.69182 .29788 L
.69203 .298 L
.69223 .29816 L
Mistroke
.69261 .29855 L
.69301 .29912 L
.69374 .30047 L
.6954 .30466 L
.69699 .30922 L
.69783 .31146 L
.69872 .31353 L
.69951 .31498 L
.69996 .31562 L
.70038 .31609 L
.70057 .31625 L
.70077 .3164 L
.70094 .3165 L
.70112 .31659 L
.70123 .31662 L
.70132 .31665 L
.70141 .31667 L
.7015 .31668 L
.70161 .31669 L
.7017 .31669 L
.70181 .31668 L
.70186 .31668 L
.70192 .31667 L
.70202 .31664 L
.70212 .31661 L
.70234 .31652 L
.70253 .31642 L
.70274 .31628 L
.70313 .31594 L
.70348 .31555 L
.70435 .31434 L
.70516 .31293 L
.70826 .30703 L
.70909 .30577 L
.70986 .30485 L
.71025 .3045 L
.71067 .30421 L
.71091 .30408 L
.71113 .30399 L
.71134 .30393 L
.71145 .30391 L
.71156 .30389 L
.71166 .30388 L
.71175 .30388 L
.71184 .30388 L
.71193 .30388 L
.71203 .30389 L
.71209 .30389 L
.71214 .3039 L
.71224 .30392 L
Mistroke
.71233 .30394 L
.71251 .304 L
.71271 .30407 L
.71306 .30425 L
.71344 .30451 L
.71386 .30485 L
.71471 .30573 L
.71641 .30789 L
.71796 .30989 L
.71872 .31075 L
.71956 .31151 L
.71994 .31178 L
.72035 .31202 L
.7207 .31218 L
.72089 .31225 L
.72108 .31231 L
.72127 .31235 L
.72137 .31237 L
.72147 .31238 L
.72153 .31239 L
.72159 .31239 L
.72169 .3124 L
.72179 .3124 L
.72189 .3124 L
.72198 .3124 L
.72206 .3124 L
.72215 .31239 L
.72225 .31237 L
.72245 .31234 L
.72263 .3123 L
.72304 .31216 L
.72349 .31196 L
.7243 .31147 L
.72602 .31007 L
.72757 .30872 L
.72835 .30811 L
.72919 .30756 L
.72958 .30735 L
.72998 .30717 L
.73036 .30703 L
.73071 .30694 L
.73091 .30689 L
.73111 .30686 L
.7312 .30685 L
.7313 .30684 L
.73139 .30683 L
.73148 .30683 L
.73158 .30682 L
.73168 .30682 L
.73173 .30682 L
Mistroke
.73179 .30682 L
.73184 .30682 L
.7319 .30682 L
.732 .30683 L
.73209 .30684 L
.73229 .30686 L
.73248 .30689 L
.73266 .30692 L
.73305 .30702 L
.73377 .30726 L
.73454 .30762 L
.73527 .308 L
.73693 .30896 L
.73842 .30972 L
.73927 .31005 L
.73967 .31018 L
.74005 .31027 L
.74044 .31034 L
.74065 .31037 L
.74076 .31038 L
.74088 .31039 L
.74098 .3104 L
.7411 .31041 L
.74116 .31041 L
.74122 .31042 L
.74128 .31042 L
.74133 .31042 L
.74144 .31042 L
.74153 .31042 L
.74164 .31042 L
.74169 .31041 L
.74175 .31041 L
.74186 .31041 L
.74196 .3104 L
.74215 .31038 L
.74236 .31036 L
.74259 .31033 L
.74337 .31017 L
.7442 .30993 L
.74495 .30967 L
.74663 .30905 L
.74744 .30877 L
.74831 .30851 L
.74904 .30834 L
.74946 .30827 L
.74985 .30821 L
.75004 .30819 L
.75025 .30817 L
.75045 .30815 L
.75054 .30815 L
Mistroke
.75063 .30814 L
.75071 .30814 L
.75079 .30814 L
.75088 .30814 L
.75097 .30814 L
.75106 .30814 L
.75115 .30814 L
.75125 .30814 L
.75134 .30814 L
.75144 .30814 L
.75155 .30815 L
.75175 .30816 L
.75194 .30817 L
.75211 .30819 L
.75252 .30823 L
.75294 .30829 L
.75451 .3086 L
.75598 .30895 L
.75747 .30926 L
.75832 .3094 L
.75872 .30945 L
.7591 .3095 L
.75931 .30951 L
.75953 .30953 L
.75972 .30954 L
.75992 .30955 L
.76003 .30955 L
.76015 .30956 L
.76021 .30956 L
.76027 .30956 L
.76033 .30956 L
.76038 .30956 L
.76048 .30956 L
.76054 .30956 L
.7606 .30956 L
.76069 .30956 L
.76075 .30956 L
.7608 .30956 L
.76089 .30956 L
.761 .30956 L
.76121 .30955 L
.7614 .30954 L
.76158 .30953 L
.76198 .30951 L
.76241 .30947 L
.76413 .30925 L
.76575 .30902 L
.76653 .30891 L
.76736 .30882 L
.76807 .30875 L
Mistroke
.76847 .30873 L
.76884 .30871 L
.76905 .3087 L
.76924 .30869 L
.76945 .30869 L
.76956 .30869 L
.76962 .30868 L
.76968 .30868 L
.76978 .30868 L
.76988 .30868 L
.76998 .30868 L
.77003 .30868 L
.77009 .30868 L
.77019 .30868 L
.77027 .30868 L
.77038 .30869 L
.77047 .30869 L
.77065 .30869 L
.77084 .3087 L
.77119 .30871 L
.77156 .30873 L
.77196 .30875 L
.77365 .30889 L
.7752 .30903 L
.77596 .30909 L
.77679 .30915 L
.77718 .30917 L
.77758 .30919 L
.77796 .3092 L
.77831 .30921 L
.7785 .30921 L
.7787 .30922 L
.77881 .30922 L
.77886 .30922 L
.77892 .30922 L
.77902 .30922 L
.77912 .30922 L
.77921 .30922 L
.7793 .30922 L
.77938 .30922 L
.77947 .30922 L
.77957 .30922 L
.77967 .30922 L
.77986 .30921 L
.78006 .30921 L
.78028 .30921 L
.78073 .30919 L
.78153 .30916 L
.78324 .30907 L
.78479 .30899 L
Mistroke
.78556 .30896 L
.78597 .30894 L
.7864 .30893 L
.78678 .30892 L
.78719 .30891 L
.78738 .3089 L
.78757 .3089 L
.78776 .3089 L
.78792 .3089 L
.78803 .3089 L
.78813 .3089 L
.78821 .3089 L
.78831 .3089 L
.78841 .3089 L
.78846 .3089 L
.78852 .3089 L
.78862 .3089 L
.78872 .3089 L
.78881 .3089 L
.7889 .3089 L
.78907 .3089 L
.78945 .3089 L
.78987 .30891 L
.79025 .30892 L
.79112 .30894 L
.79275 .309 L
.79355 .30902 L
.79428 .30904 L
.79497 .30906 L
.79574 .30907 L
.79616 .30908 L
.79636 .30908 L
.79655 .30908 L
.79672 .30909 L
.79692 .30909 L
.79702 .30909 L
.79712 .30909 L
.79721 .30909 L
.79731 .30909 L
.79741 .30909 L
.79747 .30909 L
.79752 .30909 L
.79761 .30909 L
.79771 .30909 L
.7978 .30909 L
.79788 .30909 L
.79807 .30909 L
.79828 .30908 L
.79846 .30908 L
.79889 .30908 L
Mistroke
.7996 .30907 L
.80036 .30906 L
.80196 .30903 L
.80342 .309 L
.80423 .30899 L
.8046 .30898 L
.80499 .30898 L
.80519 .30898 L
.80541 .30898 L
.80561 .30898 L
.8058 .30898 L
.80591 .30898 L
.80602 .30898 L
.80613 .30898 L
.80619 .30898 L
.80625 .30898 L
.80631 .30898 L
.80636 .30898 L
.80645 .30898 L
.80656 .30898 L
.80662 .30898 L
.80667 .30898 L
.80677 .30898 L
.80687 .30898 L
.80705 .30898 L
.80725 .30898 L
.80746 .30898 L
.80819 .30898 L
.80905 .30899 L
.80985 .309 L
.81147 .30902 L
.81227 .30903 L
.813 .30903 L
.81371 .30904 L
.81407 .30904 L
.81427 .30904 L
.81446 .30904 L
.81456 .30904 L
.81467 .30904 L
.81476 .30904 L
.81486 .30904 L
.81496 .30904 L
.81502 .30904 L
.81508 .30904 L
.81517 .30904 L
.81528 .30904 L
.81538 .30904 L
.81548 .30904 L
.81558 .30904 L
.81567 .30904 L
Mistroke
.81585 .30904 L
.81604 .30904 L
.81643 .30904 L
.81679 .30904 L
.8176 .30903 L
.81906 .30902 L
.82071 .30901 L
.82151 .30901 L
.82224 .30901 L
.8226 .30901 L
.8228 .309 L
.823 .309 L
.82318 .309 L
.82337 .309 L
.82346 .309 L
.82355 .309 L
.82363 .309 L
.82372 .309 L
.82382 .309 L
.82392 .309 L
.82398 .309 L
.82403 .309 L
.82414 .309 L
.82424 .309 L
.82433 .309 L
.82443 .309 L
.82454 .309 L
.82473 .309 L
.8249 .309 L
.8253 .309 L
.8257 .30901 L
.82614 .30901 L
.82693 .30901 L
.82842 .30902 L
.83001 .30902 L
.83081 .30902 L
.83127 .30902 L
.83149 .30902 L
.83169 .30902 L
.83189 .30902 L
.83207 .30902 L
.83217 .30902 L
.83227 .30902 L
.83233 .30902 L
.83238 .30902 L
.83248 .30902 L
.83258 .30902 L
.83268 .30902 L
.83278 .30902 L
.83284 .30902 L
Mistroke
.83289 .30902 L
.83299 .30902 L
.83311 .30902 L
.83332 .30902 L
.83351 .30902 L
.83369 .30902 L
.83409 .30902 L
.8348 .30902 L
.83648 .30902 L
.83802 .30902 L
.8388 .30901 L
.83953 .30901 L
.8399 .30901 L
.84029 .30901 L
.84051 .30901 L
.84062 .30901 L
.84073 .30901 L
.84082 .30901 L
.84092 .30901 L
.84102 .30901 L
.84107 .30901 L
.84112 .30901 L
.84122 .30901 L
.84128 .30901 L
.84133 .30901 L
.84143 .30901 L
.84152 .30901 L
.84163 .30901 L
.84173 .30901 L
.84195 .30901 L
.84214 .30901 L
.84234 .30901 L
.84275 .30901 L
.84351 .30901 L
.84423 .30901 L
.84573 .30902 L
.84652 .30902 L
.84735 .30902 L
.84777 .30902 L
.84824 .30902 L
.84844 .30902 L
.84866 .30902 L
.84887 .30902 L
.84906 .30902 L
.84925 .30902 L
.84936 .30902 L
.84947 .30902 L
.84952 .30902 L
.84958 .30902 L
.84964 .30902 L
Mistroke
.84969 .30902 L
.84979 .30902 L
.8499 .30902 L
.84999 .30902 L
.85009 .30902 L
.85018 .30902 L
.85027 .30902 L
.85048 .30902 L
.85067 .30902 L
.85108 .30902 L
.85144 .30902 L
.85226 .30902 L
.85374 .30902 L
.85456 .30902 L
.85542 .30902 L
.85615 .30902 L
.85657 .30902 L
.85696 .30902 L
.85715 .30902 L
.85736 .30902 L
.85756 .30902 L
.85765 .30902 L
.85774 .30902 L
.85783 .30902 L
.85791 .30902 L
.85799 .30902 L
.85809 .30902 L
.85817 .30902 L
.85827 .30902 L
.85836 .30902 L
.85845 .30902 L
.85856 .30902 L
.85866 .30902 L
.85886 .30902 L
.85923 .30902 L
.85966 .30902 L
.86006 .30902 L
.86169 .30902 L
.86322 .30902 L
.86398 .30902 L
.86469 .30902 L
.86508 .30902 L
.86529 .30902 L
.86551 .30902 L
.8657 .30902 L
.8658 .30902 L
.8659 .30902 L
.866 .30902 L
.86609 .30902 L
.86618 .30902 L
Mistroke
.86627 .30902 L
.86636 .30902 L
.86642 .30902 L
.86647 .30902 L
.86657 .30902 L
.86667 .30902 L
.86676 .30902 L
.86684 .30902 L
.86703 .30902 L
.86724 .30902 L
.86742 .30902 L
.86785 .30902 L
.8686 .30902 L
.86932 .30902 L
.87093 .30902 L
.87163 .30902 L
.87239 .30902 L
.87281 .30902 L
.8732 .30902 L
.87357 .30902 L
.87378 .30902 L
.87397 .30902 L
.87417 .30902 L
.87428 .30902 L
.87438 .30902 L
.87448 .30902 L
.87457 .30902 L
.87466 .30902 L
.87477 .30902 L
.87487 .30902 L
.87493 .30902 L
.87498 .30902 L
.87508 .30902 L
.87519 .30902 L
.87541 .30902 L
.87565 .30902 L
.87607 .30902 L
.87647 .30902 L
.87722 .30902 L
.8789 .30902 L
.87969 .30902 L
.88051 .30902 L
.88122 .30902 L
.88162 .30902 L
.88199 .30902 L
.8822 .30902 L
.88239 .30902 L
.8825 .30902 L
.8826 .30902 L
.88266 .30902 L
Mistroke
.88272 .30902 L
.88278 .30902 L
.88283 .30902 L
.88292 .30902 L
.88301 .30902 L
.88311 .30902 L
.88321 .30902 L
.88332 .30902 L
.88343 .30902 L
.88362 .30902 L
.88399 .30902 L
.88433 .30902 L
.88511 .30902 L
.88674 .30902 L
.88753 .30902 L
.88826 .30902 L
.88898 .30902 L
.88934 .30902 L
.88973 .30902 L
.88993 .30902 L
.89012 .30902 L
.89034 .30902 L
.89044 .30902 L
.89054 .30902 L
.89063 .30902 L
.89073 .30902 L
.89082 .30902 L
.89091 .30902 L
.891 .30902 L
.8911 .30902 L
.8912 .30902 L
.8913 .30902 L
.89139 .30902 L
.89149 .30902 L
.89167 .30902 L
.89188 .30902 L
.89207 .30902 L
.8929 .30902 L
.89437 .30902 L
.89517 .30902 L
.89602 .30902 L
.89675 .30902 L
.89714 .30902 L
.89755 .30902 L
.89776 .30902 L
.89798 .30902 L
.89819 .30902 L
.89837 .30902 L
.89857 .30902 L
.89867 .30902 L
Mistroke
.89878 .30902 L
.89887 .30902 L
.89896 .30902 L
.89905 .30902 L
.89915 .30902 L
.89925 .30902 L
.89934 .30902 L
.89944 .30902 L
.89955 .30902 L
.89972 .30902 L
.89992 .30902 L
.90027 .30902 L
.90061 .30902 L
.90373 .30902 L
.90455 .30902 L
.90498 .30902 L
.90544 .30902 L
.90584 .30902 L
.90607 .30902 L
.90628 .30902 L
.90637 .30902 L
.90647 .30902 L
.90656 .30902 L
.90665 .30902 L
.90675 .30902 L
.90684 .30902 L
.9069 .30902 L
.90695 .30902 L
.90705 .30902 L
.90715 .30902 L
.90725 .30902 L
.90734 .30902 L
.90743 .30902 L
.90764 .30902 L
.90784 .30902 L
.90823 .30902 L
.90866 .30902 L
.91014 .30902 L
.91103 .30902 L
.91186 .30902 L
.91267 .30902 L
.91302 .30902 L
.91341 .30902 L
.9136 .30902 L
.91379 .30902 L
.91396 .30902 L
.91415 .30902 L
.91426 .30902 L
.91436 .30902 L
.91445 .30902 L
Mistroke
.91455 .30902 L
.91465 .30902 L
.91473 .30902 L
.91483 .30902 L
.91493 .30902 L
.91498 .30902 L
.91503 .30902 L
.91513 .30902 L
.91525 .30902 L
.91536 .30902 L
.91558 .30902 L
.91578 .30902 L
.91615 .30902 L
.91656 .30902 L
.91813 .30902 L
.91896 .30902 L
.91985 .30902 L
.92029 .30902 L
.92071 .30902 L
.92111 .30902 L
.92149 .30902 L
.92184 .30902 L
.92202 .30902 L
.92213 .30902 L
.92222 .30902 L
.92232 .30902 L
.92242 .30902 L
.92252 .30902 L
.92258 .30902 L
.92263 .30902 L
.92273 .30902 L
.92282 .30902 L
.92292 .30902 L
.92302 .30902 L
.92321 .30902 L
.92339 .30902 L
.9238 .30902 L
.9242 .30902 L
.92462 .30902 L
.9261 .30902 L
.92769 .30902 L
.92812 .30902 L
.92859 .30902 L
.92902 .30902 L
.92942 .30902 L
.92962 .30902 L
.92973 .30902 L
.92983 .30902 L
.92992 .30902 L
.93001 .30902 L
Mistroke
.9301 .30902 L
.93021 .30902 L
.93026 .30902 L
.93032 .30902 L
.93042 .30902 L
.93047 .30902 L
.93053 .30902 L
.93058 .30902 L
.93065 .30902 L
.93075 .30902 L
.93086 .30902 L
.93106 .30902 L
.93125 .30902 L
.93144 .30902 L
.9318 .30902 L
.93261 .30902 L
.93421 .30902 L
.93505 .30902 L
.93551 .30902 L
.93594 .30902 L
.93636 .30902 L
.93674 .30902 L
.93694 .30902 L
.93716 .30902 L
.93739 .30902 L
.93751 .30902 L
.93761 .30902 L
.93771 .30902 L
.9378 .30902 L
.9379 .30902 L
.938 .30902 L
.9381 .30902 L
.9382 .30902 L
.93825 .30902 L
.93831 .30902 L
.93841 .30902 L
.93851 .30902 L
.93861 .30902 L
.9388 .30902 L
.93915 .30902 L
.93955 .30902 L
.93991 .30902 L
.94075 .30902 L
.94243 .30902 L
.94327 .30902 L
.94368 .30902 L
.94406 .30902 L
.9444 .30902 L
.94477 .30902 L
.94498 .30902 L
Mistroke
.94508 .30902 L
.94518 .30902 L
.94526 .30902 L
.94536 .30902 L
.94545 .30902 L
.94555 .30902 L
.94565 .30902 L
.94575 .30902 L
.9458 .30902 L
.94586 .30902 L
.94591 .30902 L
.94597 .30902 L
.94607 .30902 L
.94616 .30902 L
.94637 .30902 L
.94654 .30902 L
.94673 .30902 L
.94711 .30902 L
.94798 .30902 L
.94879 .30902 L
.9503 .30902 L
.95071 .30902 L
.95115 .30902 L
.95152 .30902 L
.95193 .30902 L
.95215 .30902 L
.95235 .30902 L
.95255 .30902 L
.95274 .30902 L
.95285 .30902 L
.95291 .30902 L
.95297 .30902 L
.95302 .30902 L
.95308 .30902 L
.95317 .30902 L
.95323 .30902 L
.95329 .30902 L
.95336 .30902 L
.95342 .30902 L
.95347 .30902 L
.95353 .30902 L
.95364 .30902 L
.95374 .30902 L
.95385 .30902 L
.95404 .30902 L
.95447 .30902 L
.95485 .30902 L
.95526 .30902 L
.95695 .30902 L
.95775 .30902 L
Mistroke
.95849 .30902 L
.95889 .30902 L
.95925 .30902 L
.95966 .30902 L
.95988 .30902 L
.96009 .30902 L
.96027 .30902 L
.96036 .30902 L
.96046 .30902 L
.96055 .30902 L
.96065 .30902 L
.96073 .30902 L
.96081 .30902 L
.96091 .30902 L
.96101 .30902 L
.96111 .30902 L
.96122 .30902 L
.9614 .30902 L
.9616 .30902 L
.962 .30902 L
.96241 .30902 L
.96315 .30902 L
.96483 .30902 L
.96559 .30902 L
.96601 .30902 L
.96641 .30902 L
.96678 .30902 L
.96698 .30902 L
.96718 .30902 L
.96736 .30902 L
.96755 .30902 L
.96763 .30902 L
.96772 .30902 L
.9678 .30902 L
.96788 .30902 L
.96794 .30902 L
.96799 .30902 L
.96809 .30902 L
.96814 .30902 L
.9682 .30902 L
.96831 .30902 L
.9684 .30902 L
.96849 .30902 L
.96859 .30902 L
.9687 .30902 L
.96893 .30902 L
.96916 .30902 L
.96958 .30902 L
.97035 .30902 L
.9712 .30902 L
Mistroke
.97275 .30902 L
.97318 .30902 L
.97364 .30902 L
.97404 .30902 L
.97447 .30902 L
.9747 .30902 L
.97491 .30902 L
.97502 .30902 L
.97513 .30902 L
.97519 .30902 L
.97526 .30902 L
.97531 .30902 L
.97537 .30902 L
.97547 .30902 L
.97552 .30902 L
.97558 .30902 L
.97564 .30902 L
.97569 .30902 L
.9758 .30902 L
.97589 .30902 L
.97598 .30902 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{421.375, 260.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008>0001AB000`400?l00000o`00003ooooooooo
oooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo
003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooo
oooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool0
0?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooooooo
ool@ooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooo
ooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo0ol0003o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0
003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo
00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`
ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLoooo
o`00<?ooool3o`000?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?oo
ool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0
033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomco
oooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooo
oooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool3o`000?oooooo
g?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0013ooooo0_o^k^h3ooooo`;ok^k^6Oooool00ol0003oooooooooo`3o
ooooomcooooo000;ooooo`;o000000[o410@ooooooooooook^k^oeEEEOo^k^koooooonk^k_mEEEGo
k^k^0oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h:ooooo`03o`000?oo
oooooooo0?oooooog?ooool000cooooo00?o0000ooooooooool00_ooool01Oo^k^koEEEEomgMgOmE
EEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00[ooooo
00?o0000ooooooooool0oooooooLooooo`0000?oooooo`000?l000001?l00002ooooo`Go00001?oo
ool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooo
oa0@400:ooooo`03o`000?oooooooooo0?oooooog?ooool000Wooooo00CoA4A4omgMgOoooooo0000
1?ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000000[ooooo00?o0000ooooooooool0oooooooLooooo`002Oooool01?oMgMgo
EEEEooooool00003ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000:ooooo`Co0000oooooooKooooo`002_oo
ool00omgMgOoc<c<o`000003ooooo`;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@00[ooooo00?o0000ooooooooool0oooooooLooooo`002_oo
ool00oo^k^koA4A4o`00000?ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`;o00001Oooool00ol0003oooooooooo`3oooooomcooooo000;ooooo`03ogMgMol0
003ooooo00cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`3oooooomcooooo000Xooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`3oooooobOo
oooo000Xooooo`?o00001Oooool00ol0003oooooooooo`2aooooo`;o0000oooooolYooooo`00:Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0;7ooooo0_l0003oooooobWooooo000Z
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/Oooool2o`000?oooooo:Oooool0
033ooooo00?o0000ooooooooool0/Oooool2o`000?oooooo:Oooool0033ooooo00?o0000oooooooo
ool0/Oooool2o`0000[ooooo00?o0000ooooooooool0oooooolLooooo`00<?ooool00ol0003ooooo
ooooo`2aooooo`;o00002_ooool00ol0003oooooooooo`3ooooooacooooo000`ooooo`03o`000?oo
oooooooo0;7ooooo0_l0000:ooooo`;o0000oooooolMooooo`00<?ooool3o`000;7ooooo0_l0000:
ooooo`;o0000oooooolMooooo`00<?ooool00ol0003oooooooooo`2Uooooo`;o00002_ooool00ol0
003oooooo`000009ooooo`;o0000oooooolMooooo`00<?ooool00ol0003oooooooooo`2Uooooo`;o
00002_ooool00ol0003oooooo`000009ooooo`;o0000oooooolMooooo`00<?ooool00ol0003ooooo
ooooo`2Uooooo`;o00002_ooool00ol0003oooooo`000009ooooo`;o0000oooooolMooooo`00<?oo
ool00ol0003oooooooooo`2Uooooo`;o00002_ooool00ol0003oooooo`000009ooooo`;o0000oooo
oolMooooo`00<?ooool00ol0003oooooooooo`2Uooooo`;o00002_ooool00ol0003oooooo`000009
ooooo`;o0000oooooolMooooo`00<?ooool00ol0003oooooooooo`2Uooooo`;o00002_ooool00ol0
003oooooo`000008ooooo`03o`000?oooooo00000?oooooo7Oooool0033ooooo00?o0000oooooooo
ool0YOooool2o`0000[ooooo00?o0000ooooool000002?ooool00ol0003oooooo`00003ooooooago
oooo000`ooooo`03o`000?oooooooooo0:Gooooo0_l0000:ooooo`03o`000?oooooo000000Sooooo
00?o0000ooooool00000oooooolMooooo`00<?ooool00ol0003oooooooooo`2Uooooo`;o00002_oo
ool00ol0003oooooo`000008ooooo`03o`000?oooooo00000?oooooo7Oooool0033ooooo00?o0000
ooooooooool0YOooool00ol0003oooooo`000009ooooo`03o`000?oooooo000000Sooooo00?o0000
ooooool00000oooooolMooooo`00<?ooool00ol0003oooooooooo`2Tooooo`04o`000?oooooooooo
o`0000Wooooo00?o0000ooooool000002?ooool00ol0003oooooo`00003ooooooagooooo000`oooo
o`?o0000Y?ooool01?l0003oooooooooool00009ooooo`03o`000?oooooo000000Sooooo00?o0000
ooooool00000oooooolMooooo`00<?ooool00ol0003oooooooooo`2Tooooo`04o`000?oooooooooo
o`0000Wooooo00?o0000ooooool000002?ooool00ol0003oooooo`000009ooooo`03o`000?oooooo
oooo0?oooooo4Oooool0033ooooo00?o0000ooooooooool0Y?ooool01?l0003oooooooooool00008
ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool000002Oooool2o`000?oooooo4_oo
ool0033ooooo00?o0000ooooooooool0Y?ooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000Sooooo00?o0000ooooool000002Oooool2o`000?oooooo4_ooool0033ooooo00?o
0000ooooooooool0Y?ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000So
oooo00?o0000ooooool000002Oooool2o`000?oooooo4_ooool0033ooooo00?o0000ooooooooool0
Y?ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000oooo
ool000002Oooool2o`000?oooooo4_ooool0033ooooo00?o0000ooooooooool0Y?ooool01?l0003o
ooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool000002Oooool2
o`000?oooooo4_ooool0033ooooo00?o0000ooooooooool0Y?ooool01?l0003oooooooooool00008
ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool000002Oooool2o`000?oooooo4_oo
ool0033ooooo00?o0000ooooooooool0Y?ooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000Sooooo00?o0000ooooool000002Oooool2o`000?oooooo4_ooool0033ooooo00?o
0000ooooooooool0Y?ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000So
oooo00?o0000ooooool000002?ooool00ol0003oooooo`00003ooooooa;ooooo000`ooooo`03o`00
0?oooooooooo09Wooooo00?o0000ooooooooool02?ooool01?l0003oooooooooool00008ooooo`04
o`000?ooooooooooo`0000Sooooo00?o0000ooooool000002?ooool00ol0003oooooo`00003ooooo
oa;ooooo000`ooooo`?o0000V?ooool2o`0000[ooooo00Co0000oooooooooooo00002?ooool01?l0
003oooooooooool00008ooooo`03o`000?oooooo000000Sooooo00?o0000ooooool00000oooooolB
ooooo`00<?ooool00ol0003oooooooooo`2Hooooo`;o00002_ooool01?l0003oooooooooool00008
ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool000002?ooool00ol0003oooooo`00
003ooooooa;ooooo000`ooooo`03o`000?oooooooooo09Sooooo0_l0000:ooooo`04o`000?oooooo
ooooo`0000Sooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`000008ooooo`03o`00
0?oooooo00000?oooooo4_ooool0033ooooo00?o0000ooooooooool0V?ooool2o`0000[ooooo00Co
0000oooooooooooo00002?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo000000So
oooo00?o0000ooooool00000oooooolBooooo`00<?ooool00ol0003oooooooooo`2Hooooo`;o0000
2_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000oooo
ool000002?ooool00ol0003oooooo`00003ooooooa;ooooo000`ooooo`03o`000?oooooooooo09So
oooo0_l0000:ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002?ooool0
0ol0003oooooo`000008ooooo`03o`000?oooooo00000?oooooo4_ooool0033ooooo00?o0000oooo
ooooool0V?ooool2o`0000[ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo0000oooooolAooooo`00
4?ooool2onk^kP?ooooo0_o^k^hIooooo`03o`000?oooooooooo09Sooooo00?o0000ooooool00000
2Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooo
oooooooo00001oooool01?l0003oooooooooool0003ooooooa7ooooo0009ooooo`Go00000_ooool0
1oo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb
<S;o0000oc8b<_o^k^h:ooooo`03o`000?oooooooooo09Oooooo00Co0000oooooooooooo00002Ooo
ool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooo
oooo00001oooool01?l0003oooooooooool0003ooooooa7ooooo0009ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00[ooooo00?o0000ooooooooool0Uoooool01?l0003ooooo
ooooool00009ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool00008
ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00002?ooool00ol0003ooooo
ooooo`3oooooo`Kooooo00000ooooooo0000o`000004o`0000?ooooo00?oV9RHob4Q8Oo^k^h01Ooo
ool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooo
oa0@400:ooooo`03o`000?oooooooooo09Oooooo00Co0000oooooooooooo00002Oooool01Ol0003o
oooooooooooooooo000000Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0
0007ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool0ooooool6ooooo`002ooo
ool00onHV9So8B4Qonk^kP03ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000002_ooool00ol0003oooooooooo`2Gooooo`04
o`000?ooooooooooo`0000Wooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?oooooo
ooooo`0000Sooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool00007ooooo`;o
0000ooooool8ooooo`003?ooool02omgMgOoIVIVooooooooooook^k^oeEEEOo^k^koooooonk^k_mE
EEGok^k^00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000[ooooo
1?l0002Fooooo`04o`000?ooooooooooo`0000Wooooo00Go0000ooooooooooooooooo`000007oooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001oooool01?l0003ooooooooo
ool00007ooooo`;o0000ooooool8ooooo`003Oooool00ol0003oooooooooo`02onk^kP?ooooo0_o^
k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400:ooooo`03o`00
0?oooooooooo09Oooooo00Co0000oooooooooooo00002Oooool01Ol0003ooooooooooooooooo0000
00Oooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00007ooooo`04o`000?oo
ooooooooo`0000Oooooo0_l0003oooooo`Sooooo0009ooooo`05o`000?nj^[[ooooooiRHV?l@4100
3_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool2o`0000Go
oooo00?o0000ooooooooool0Uoooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00008ooooo`04o`000?oooooo
ooooo`0000Oooooo00Co0000oooooooooooo00001oooool2o`000?oooooo2?ooool000Wooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c00<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP02ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0Uoooool01?l0
003oooooooooool00008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool0
1?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo
00001oooool00ol0003oooooo`00003oooooo`Oooooo000Xooooo`04o`000?ooooooooooo`0000Co
oooo00?o0000ooooooooool0Uoooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00008ooooo`04o`000?oooooo
ooooo`0000Oooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00003oooooo`Oooooo
000Xooooo`?o00001Oooool00ol0003oooooooooo`2Gooooo`04o`000?ooooooooooo`0000Sooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool0
00001oooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000
ooooool00000ooooool7ooooo`00:Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
09Oooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Gooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo
00Co0000oooooooooooo00001oooool00ol0003oooooo`00003oooooo`Oooooo000Zooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0Uoooool01?l0003oooooooooool00008ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo0000
00Oooooo00Co0000oooooooooooo00001_ooool01Ol0003ooooooooooooooooo000000Oooooo00?o
0000ooooool00000ooooool7ooooo`00<?ooool00ol0003oooooooooo`2Gooooo`04o`000?oooooo
ooooo`0000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`05o`000?oo
ooooooooooooool000001oooool01?l0003oooooooooool00006ooooo`05o`000?oooooooooooooo
ool000001oooool00ol0003oooooo`00003oooooo`Oooooo000`ooooo`03o`000?oooooooooo09Oo
oooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Gooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Kooooo00Go
0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?oooooo1oooool0033ooooo00?o
0000ooooooooool0Uoooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000oooooooo
ooooooooo`000006ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooo`00003o
ooooo`Oooooo000`ooooo`03o`000?oooooooooo09Kooooo00Go0000ooooooooooooooooo`000008
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooo
oooo000000Kooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool0
00001oooool00ol0003oooooo`00003oooooo`Oooooo000`ooooo`?o0000Roooool00ol0003ooooo
ooooo`08ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05
o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000
ooooool00000ooooool7ooooo`00<?ooool00ol0003oooooooooo`2:ooooo`;o00002_ooool01Ol0
003ooooooooooooooooo000000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooo
oooo000000Kooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?oooooo
1oooool0033ooooo00?o0000ooooooooool0R_ooool00ol0003oooooo`000009ooooo`05o`000?oo
ooooooooooooool000002?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool0
00001_ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooool00000ooooool7oooo
o`00<?ooool00ol0003oooooooooo`2:ooooo`03o`000?oooooo000000Wooooo00Go0000oooooooo
ooooooooo`000008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006
ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool00008ooooo`03o`00
0?oooooooooo0?_ooooo000`ooooo`03o`000?oooooooooo08[ooooo00?o0000ooooool000002Ooo
ool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooo
oooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?oooooooooo
o`0000Sooooo00?o0000ooooooooool0noooool0033ooooo00?o0000ooooooooool0R_ooool00ol0
003oooooo`000009ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Kooooo
00Co0000oooooooooooo00001oooool2o`000?gooooo000`ooooo`03o`000?oooooooooo08[ooooo
00?o0000ooooool000002Oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000006
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooo`00003looooo`00<?ooool0
0ol0003oooooooooo`29ooooo`04o`000?ooooooooooo`0000Wooooo00Go0000oooooooooooooooo
o`000008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`05
o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000
ooooool00000o?ooool0033ooooo00?o0000ooooooooool0ROooool01?l0003oooooooooool00009
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Kooooo
00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo00000?cooooo000`ooooo`03o`00
0?oooooooooo08Wooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000
00Kooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001_oo
ool00ol0003oooooo`00003looooo`00<?ooool00ol0003oooooooooo`29ooooo`04o`000?oooooo
ooooo`0000Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oo
ooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooool0
0000o?ooool0033ooooo00?o0000ooooooooool0ROooool01Ol0003ooooooooooooooooo000000So
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooo
ool00000o?ooool0033ooooo0ol00029ooooo`05o`000?ooooooooooooooool000002?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooo`00003l
ooooo`00<?ooool00ol0003oooooooooo`29ooooo`05o`000?ooooooooooooooool000002?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooo`00
003looooo`00<?ooool00ol0003oooooooooo`29ooooo`05o`000?ooooooooooooooool000002?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooo
o`00003looooo`00<?ooool00ol0003oooooooooo`29ooooo`05o`000?ooooooooooooooool00000
2?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooo`00003looooo`00<?ooool00ol0003oooooooooo`29ooooo`05o`000?ooooooooooooooool0
00002?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001_ooool00ol0
003oooooo`00003looooo`00<?ooool00ol0003oooooooooo`1>ooooo`;ok^k^0oooool2onk^kSCo
oooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooooooo`;ok^k^00?ooooo
o`000?ooool00_o^k^h00ooooooo0000ooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooo000000Oooooo0_l0000[ooooo`;ok^k^0ooo
ool2onk^kTkooooo0_o^k^h3ooooo`;ok^k^K?ooool0033ooooo00?o0000ooooooooool0B?ooool0
3Om4A4Co0000o`000?lb<S;ogMgMooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4
o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hUooooo`05o`000?oooooooooooooo
ool000002?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01?l000003?l@413oooooonk^k_mEEEGok^k^o`000?o^k^koEEEEonk^k_oooooo0000oooo
o`Co000000Go410@o`000?ooooook^k^oc8b<P02o`000003onk^k_oooooooooo00;ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001_oo
ool00ol0003oooooo`000007ooooo`;o00005Oooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ
8B45ooooo`0=odA4A?l0003o0000oc8b<_oMgMgoooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^
kP03ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kSSooooo1Ol00002oooo
o`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co000000So410@ooooooooooook^k^
oc8b<_l0003o<S8bonk^kUgooooo000`ooooo`03o`000?oooooooooo04_ooooo00WoMgMgoc8b<_oo
ooooooooonk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL09?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00_ooool01Oo^k^koEEEEo`000?mEEEGok^k^00;ooooo00Go0000oooooooo
ooooooooo`000002ooooo`07o`000?ooooooMgMgoiRHV?oooooo0000ogMgM`04ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooool000001oooool2o`0001Oooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo
00WoMgMgoc8b<_ooooooooooonk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0>?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo
00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`1Mooooo`00<?ooool00ol0003oooooooooo`1<ooooo`07o`000?oooooooooooooo
oooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
400Hooooo`;o00002_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool00ooMgMgo0000omgMg@03ooooo`05o`000?ooooooooooooooool00000
0_ooool00ol0003ooooooa0@4002ooooo`03o`000?l@413ooooo00?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooo`000007ooooo`03o`000?oooooo000001Kooooo00?o0000ooooooooool03oooool01ol0003o
oooooooooooooooogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooo
ooooooooool@4100>Oooool00onHV9So8B4Qonk^kP05ooooo`03omgMgOl0003ogMgM00Oooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@05gooooo000`ooooo`03o`000?oo
oooooooo04_ooooo00WoMgMgoc8b<_ooooooooooonk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000005oooool3o`0000[ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Gok^k^
oeEEEOl0003oEEEEonk^kP02ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003ooooo
o`000002ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
00Go0000ooooooooooooooooo`000005ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000oooo
ool000005_ooool00ol0003oooooooooo`0>ooooo`09ogMgMolb<S;oooooooooooo^k^koEEEEomgM
gOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000003[o
oooo00?oV9RHob4Q8Oo^k^h00oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000005gooooo000`ooooo`03o`000?oooooooooo
04Sooooo00go0000ob4Q8Ol0003o<S8bolc<c?ooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^
00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000001Oooooo00?o0000
ooooool000002_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00go0000
ooooooooooooooooonk^k_mEEEGok^k^o`000?o^k^koEEEEonk^k_oooooo000000?ooooo00Ko0000
oooooooooooo0000ooooool00002ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000005ooooo`05o`000?oooooooooooooo
ool000001_ooool00ol0003oooooo`00000Fooooo`03o`000?oooooooooo00_ooooo00go0000ob4Q
8Ol0003o<S8bolc<c?ooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000003_ooooo00_oMgMgofIVI_ooooooooooonk^
k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`00001Mooooo`00<?ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo
00?ooooo0_o^k^h3ooooo`;ok^k^1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@41005oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooooooool2onk^kP03ooooool0003ooooo00;ok^k^
00?oooooo`000?ooool00_ooool01_l0003oooooooooool0003ooooooa0@40;ooooo00?o0000oa0@
4?ooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000oooo
ooooooooooooo`000005ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooo`00
000Fooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00oooool2onk^kP?ooooo0_o^
k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400looooo`03o`00
0?oooooooooo00;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@413ooooo
oooooooooooo410@05gooooo000`ooooo`?o0000B?ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo00_o
oooo00Go0000ooooooooooooooooo`000009ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`000002ooooo`07o`000?ooooooMgMgoiRHV?oooooo0000ogMgM`04ooooo`04o`00
0?ooooooooooooooo`;o00001Oooool01Ol0003ooooooooooooooooo000000Gooooo00Go0000oooo
ooooooooooooo`000005ooooo`04o`000?ooooooooooo`0001Kooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`08ooooo`;o0000;_ooool01Ol0003o^[ZjoooooonHV9So410@00kooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo0_l0001Cooooo`00<?ooool00ol0003o
ooooooooo`18ooooo`Co00003?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02?ooool00ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool000002Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`05ooooo`06o`000?oooooooooooeEEEOmVIVKo00001_ooool00ol0003ooooo
ooooo`03ooooo`04o`000?mEEEGoIVIVo`0000;ooooo00Co0000ooooooo^k^ko<S8b0_l000000oo^
k^koooooooooo`02ooooo`05o`000?ooooooooooo`000?ooool00_l00004ooooo`05o`000?oooooo
ooooooooool000001Oooool01Ol0003ooooooooooooooooo000000Gooooo00Co0000oooooooooooo
00001oooool00ol0003oooooooooo`0:ooooo`03oeEEEOmVIVKo000000gooooo1?l0000<ooooo`03
oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP07ooooo`04o`000?oooooooooo
o`0002gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00<ooooo`03oeEEEOmVIVKo000000Cooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP07ooooo`04o`000?ooooooooooo`0005;ooooo000`ooooo`03o`00
0?oooooooooo06Kooooo1?l00003ooooo`03o`000?oooooooooo00[ooooo00Go0000oooooooooooo
ooooo`000009ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooooooo`Co000000?oooooo`000?ooool00_l00004oooo
o`05o`000?ooooooooooooooool000001Oooool01Ol0003ooooooooooooooooo000000Gooooo00Co
0000oooooooooooo00001_ooool3o`0003Wooooo1?l000001Ooooooo0000oooooooooooo000004co
oooo1?l000001Ooooooo0000oooooooooooo000005;ooooo000`ooooo`03o`000?oooooooooo06go
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03o`0000Gooooo00Go0000oooooooo
ooooooooo`000005ooooo`05o`000?ooooooooooooooool000001Oooool01?l0003oooooooooool0
0006ooooo`03o`000?oooooo000003kooooo0ol0001Booooo`?o0000Doooool0033ooooo00?o0000
ooooooooool0Joooool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooo`;o0000
1Oooool01Ol0003ooooooooooooooooo000000Gooooo00Go0000ooooooooooooooooo`000005oooo
o`04o`000?ooooooooooo`0000Kooooo00?o0000ooooool00000?oooool00ol0003oooooooooo`1B
ooooo`03o`000?oooooooooo05;ooooo000`ooooo`03o`000?oooooooooo06_ooooo1?l0000:oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo
000000Gooooo00Go0000ooooooooooooooooo`000005ooooo`04o`000?ooooooooooo`0000Kooooo
00?o0000ooooool00000@?ooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo057ooooo
000`ooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0003ooooooooooooooooo000000Go
oooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooo000000Oooooo0_l0003Poooo
o`00<?ooool00ol0003oooooooooo`1[ooooo`?o00002oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000005ooooo`05o`000?oooooooooo
ooooool000001Oooool01Ol0003ooooooooooooooooo000000Cooooo00Co0000oooooooooooo0000
1oooool2o`000:Kooooo00?oMgMgofIVI_ooool0;Oooool00omVIVKoMgMgooooo`07ooooo`00<?oo
ool00ol0003oooooooooo`1Zooooo`05o`000?ooooooooooooooool000002Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000005ooooo`05
o`000?ooooooooooooooool000001Oooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000
ooooooooooooooooo`000005ooooo`03o`000?oooooo00000:Gooooo00?ogMgMoa0@4?o^k^h0;_oo
ool00oo^k^ko410@omgMg@07ooooo`00<?ooool00ol0003oooooooooo`1Yooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00Go0000ooooooooooooooooo`000005ooooo`05o`000?ooooooooooooooool00000
1Oooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000005oooo
o`04o`000?ooooooooooo`0000Kooooo0_l0002:ooooo`;o00000_ooool2o`0000cooooo00?oEEEE
oiRHV?ooool00_l00002ooooo`07o`000?ooooooooooo`000?l@413ok^k^oeEEE@02o`000003odA4
A?nj^[[ooooo00;ooooo00GoV9RHo`000?l0003oA4A4okZj^P02ooooo`08onk^k_mEEEGo0000o`00
0?m4A4Co^[Zjooooool@4105o`0000?ooooo00So410@oc8b<_l0003o0000oa0@4?nYZJWoQhN7ofIV
IPOooooo000`ooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0003ooooooooooooooooo
000000Gooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool00000
1Oooool01?l0003oooooooooool00005ooooo`03o`000?oooooo000000Kooooo0_l00022ooooo`06
onk^k_lQ8B7oQhN7okZj^_l0003ogMgM3?ooool01Ol0003ooooooooooooooooo000000;ooooo00_o
0000oooooooooooo0000oooooomEEEGoMgMgooooooo^k^koMgMgoa0@4003ooooo`05oa0@4?nj^[[o
k^k^ogMgMol@41000_ooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40?ooooo00?o0000oooooooo
ool01?ooool02?l0003oZJVYoooooooooooo^[Zjo`000?o^k^ko00001oooool00?oo0000]?l0000?
ooooo`04omgMgOl0003o410@olc<c0gooooo00Go<S8booooooooooooooooo`000002ooooo`06o`00
0?ooooooooooo`000?oooooo00002?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01Oooool01onj^[[oQhN7ofIVI_mVIVKo410@ooooool000001ooo
ool000[ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool00oooool5o`0000Sooooo00Co0000oooooooooooooooo0_l0
0005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000001oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooo000000Kooooo00?o0000ooooooooool00oooool01ol0003ooooooooo
oooooooo0000ooooool000001_ooool00ol0003oooooooooo`03ooooo`04o`000?oooooooooooooo
o`;o00001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo0_l00004oooo
o`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`02ooooo`;o00001?ooool0
1Ol0003ooooooooooooooooo000000Cooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03
o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`?o000000?oooooo`00
0?ooool01?ooool4o`0000Gooooo0_l0000Aooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool05oooool01?o^k^ko8B4Qoa0@4?o^k^h=ooooo`05oc8b<_ooooooooooooooool000000_oo
ool01Ol0003oooooooooool0003ooooo00Ko00000oooool00ol0003oooooooooo`04ooooo`Ko0000
0oooool00ol0003oooooooooo`04ooooo`08oc8b<_lQ8B7oMgMgogMgMon7QhOok^k^ooooool00007
ooooo`002_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00?ooooo1Ol00008oooo
o`03o`000?oooooo000000Oooooo00?o0000ooooooooool01Oooool2o`0000Gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000Kooooo00?o0000oooo
ooooool00oooool01ol0003ooooooooooooooooo0000ooooool000001_ooool00ol0003ooooooooo
o`03ooooo`04o`000?ooooooooooooooo`;o00001Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo0_l00004ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003o
ooooooooo`02ooooo`;o00001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Ko0000oooo
oooooooo0000ooooool00003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000001?oo
ool01?l0003oooooo`000?l0000?ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0Gooooo`04ob4Q8OmgMgOoMgMgoc8b<Pgooooo00Go0000onk^k_oo
ooooooooo`000002olc<c00;o`000?nYZJWogMgMob4Q8OooooooEEEEohN7Qoo^k^koooooohN7Qolb
<S800oooool00ol0003oooooooooo`04ooooo`06oeEEEOn7QhOok^k^oooooon7QhOo<S8b0oooool0
0ol0003o<S8bomgMg@04ooooo`08o`000?nj^[[oooooonk^k_mgMgOo0000onk^k_l00007ooooo`00
<?ooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0oooool01?l0003oooooooooooooool2o`0000Gooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000004oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Gooooo0ol0
000Gooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool05_ooool2o`0000;ooooo0_l0
000<ooooo`0>oeEEEOmgMgOooooooa0@4?l0003o8B4Qo`000?mgMgOo410@o`000?nYZJWoooooonk^
k_mEEED2o`000004odA4A?o^k^kooooooa0@40Go00000oooool01_o^k^koEEEEo`000?l0003oA4A4
onk^kP;ooooo0_l000001?nYZJWo8B4Qo`000?lQ8B42ooooo`08ojVYZOlQ8B7o0000o`000?lb<S;o
0000ogMgMomEEED7ooooo`00<?ooool00ol0003oooooooooo`1aooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooooooooooo
ool000001?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooool000001_ooool2
o`000:7ooooo00?ogMgMoa0@4?o^k^h04_ooool00ol0003oooooooooo`0Iooooo`03onk^k_l@413o
gMgM00Oooooo000`ooooo`03o`000?oooooooooo077ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000005
ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooool00000Z_ooool00omgMgOoIVIVoooo
o`0Aooooo`03o`000?oooooooooo01Wooooo00?oIVIVogMgMoooool01oooool0033ooooo00?o0000
ooooooooool0L_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool01Ol0003ooooooooooooooooo000000Gooooo00Co0000oooooooooooo0000
1_ooool00ol0003oooooo`00003Tooooo`00<?ooool00ol0003oooooooooo`1cooooo`04o`000?oo
ooooooooo`0000Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Go
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooooooooooo
ool000001Oooool01Ol0003ooooooooooooooooo000000Gooooo00Co0000oooooooooooo00001_oo
ool2o`000>Gooooo000`ooooo`03o`000?oooooooooo07?ooooo00Co0000ooooool0003o00002Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000005ooooo`05
o`000?ooooooooooooooool000001Oooool01?l0003oooooooooool0003]ooooo`00<?ooool00ol0
003oooooooooo`1dooooo`;o00002_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooo
ooooool000001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000
ooooooooooooooooo`000005ooooo`05o`000?ooooooooooooooool000001Oooool01?l0003ooooo
ooooool0003]ooooo`00<?ooool00ol0003oooooooooo`20ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo
00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool01Ol0003ooooooooooooooooo000000Gooooo00Go0000ooooooooooooooooo`000005
ooooo`04o`000?ooooooooooo`000>gooooo000`ooooo`03o`000?oooooooooo087ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0003ooooo
oooooooooooo000000Gooooo00?o0000ooooool00000k_ooool0033ooooo0ol00021ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?oooooooooooooo
ool000001Oooool01Ol0003ooooooooooooooooo000000Gooooo00Go0000ooooooooooooooooo`00
0006ooooo`;o0000k_ooool0033ooooo00?o0000ooooooooool0POooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Gooooo
00Go0000ooooooooooooooooo`000005ooooo`04o`000?ooooooooooo`0000Oooooo0_l0003^oooo
o`00<?ooool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooo
ooooooooo`000006ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0003ooooooooooooo
oooo000000Gooooo00Co0000oooooooooooo00001oooool2o`000>kooooo000`ooooo`03o`000?oo
oooooooo087ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo
00Go0000ooooooooooooooooo`000005ooooo`05o`000?ooooooooooooooool000001Oooool01?l0
003oooooooooool0003gooooo`00<?ooool00ol0003oooooooooo`22ooooo`05o`000?oooooooooo
ooooool000002?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000
ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001Oooool01?l0003ooooo
ooooool00006ooooo`04o`000?ooooooooooo`000?Oooooo000`ooooo`03o`000?oooooooooo08;o
oooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001Ooo
ool01?l0003oooooooooool00006ooooo`04o`000?ooooooooooo`000?Oooooo000`ooooo`03o`00
0?oooooooooo08;ooooo00Co0000oooooooooooo00002_ooool01Ol0003ooooooooooooooooo0000
00Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001Ooo
ool01?l0003oooooooooool00007ooooo`03o`000?oooooo00000?Oooooo000`ooooo`03o`000?oo
oooooooo08;ooooo00Co0000oooooooooooo00002_ooool01Ol0003ooooooooooooooooo000000Oo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001Oooool0
1?l0003oooooooooool00007ooooo`03o`000?oooooo00000?Oooooo000`ooooo`03o`000?oooooo
oooo08;ooooo00Co0000oooooooooooo00002_ooool01Ol0003ooooooooooooooooo000000Oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo
00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001Oooool01?l0
003oooooooooool00007ooooo`03o`000?oooooo00000?Oooooo000`ooooo`03o`000?oooooooooo
08;ooooo00Co0000oooooooooooo00002_ooool01Ol0003ooooooooooooooooo000000Oooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go
0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001Oooool01?l0003o
ooooooooool00007ooooo`03o`000?oooooo00000?Oooooo000`ooooo`03o`000?oooooooooo08;o
oooo00Co0000oooooooooooo00002_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000
ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001Oooool01?l0003ooooo
ooooool00007ooooo`03o`000?oooooo00000?Oooooo000`ooooo`03o`000?oooooooooo08?ooooo
0_l0000;ooooo`05o`000?ooooooooooooooool000002?ooool01Ol0003ooooooooooooooooo0000
00Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000
ooooooooooooooooo`000005ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool00000
moooool0033ooooo0ol00023ooooo`;o00002oooool01Ol0003ooooooooooooooooo000000Sooooo
00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooo
ooooooooo`000006ooooo`05o`000?ooooooooooooooool000001Oooool01?l0003oooooooooool0
0007ooooo`;o0000n?ooool0033ooooo00?o0000ooooooooool0T?ooool01Ol0003ooooooooooooo
oooo000000Sooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo
00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001Oooool01?l0
003oooooooooool00008ooooo`03o`000?oooooooooo0?Kooooo000`ooooo`03o`000?oooooooooo
093ooooo00Go0000ooooooooooooooooo`000008ooooo`05o`000?ooooooooooooooool000001ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooo
oooooooooooo000000Gooooo00Co0000oooooooooooo0000ooooool2ooooo`00<?ooool00ol0003o
ooooooooo`2@ooooo`05o`000?ooooooooooooooool000002?ooool01Ol0003ooooooooooooooooo
000000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00Co
0000oooooooooooo00001_ooool01?l0003oooooooooool0003oooooo`;ooooo000`ooooo`03o`00
0?oooooooooo093ooooo00Go0000ooooooooooooooooo`000008ooooo`05o`000?oooooooooooooo
ool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooo
ooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003ooooooooo
ool00007ooooo`03o`000?oooooo00000?oooooo0_ooool0033ooooo00?o0000ooooooooool0T?oo
ool01Ol0003ooooooooooooooooo000000Sooooo00Go0000ooooooooooooooooo`000007ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000
00Oooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Oooooo00?o
0000ooooool00000ooooool2ooooo`00<?ooool00ol0003oooooooooo`2@ooooo`05o`000?oooooo
ooooooooool000002?ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003o
oooooooooooooooo000000Kooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00003o
ooooo`;ooooo000`ooooo`03o`000?oooooooooo093ooooo00Go0000ooooooooooooooooo`000008
ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool0
00001_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooo00000?oooooo0_ooool0033o
oooo00?o0000ooooooooool0T?ooool01Ol0003ooooooooooooooooo000000Sooooo00Go0000oooo
ooooooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
1Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000006ooooo`04o`00
0?ooooooooooo`0000Oooooo00?o0000ooooool00000ooooool2ooooo`00<?ooool00ol0003ooooo
ooooo`2@ooooo`05o`000?ooooooooooooooool000002?ooool01Ol0003ooooooooooooooooo0000
00Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooo
ooooool000001oooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo0000
1oooool00ol0003oooooo`00003oooooo`;ooooo000`ooooo`03o`000?oooooooooo093ooooo00Go
0000ooooooooooooooooo`000008ooooo`05o`000?ooooooooooooooool000001oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000007oooo
o`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool00007ooooo`03o`000?oo
oooo00000?oooooo0_ooool0033ooooo00?o0000ooooooooool0T?ooool01Ol0003ooooooooooooo
oooo000000Sooooo00Go0000ooooooooooooooooo`000008ooooo`05o`000?ooooooooooooooool0
00001_ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000006
ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool00000ooooool2ooooo`00<?ooool3
o`00093ooooo00Co0000oooooooooooo00002Oooool01Ol0003ooooooooooooooooo000000Sooooo
00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001oooool01Ol0
003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00
003oooooo`;ooooo000`ooooo`03o`000?oooooooooo093ooooo00Co0000oooooooooooo00002Ooo
ool01Ol0003ooooooooooooooooo000000Sooooo00Go0000ooooooooooooooooo`000006ooooo`05
o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000
oooooooooooo00001oooool2o`000?oooooo0oooool0033ooooo00?o0000ooooooooool0TOooool0
0ol0003oooooo`000009ooooo`05o`000?ooooooooooooooool000002?ooool01Ol0003ooooooooo
oooooooo000000Kooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooooooooooo
ool000001_ooool01?l0003oooooooooool00007ooooo`;o0000ooooool3ooooo`00<?ooool00ol0
003oooooooooo`2Aooooo`03o`000?oooooo000000Wooooo00Go0000ooooooooooooooooo`000008
ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Oooooo
00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Oooooo0_l0003ooooo
o`?ooooo000`ooooo`03o`000?oooooooooo097ooooo00?o0000ooooool000002Oooool01Ol0003o
oooooooooooooooo000000Sooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?oooooo
ooooooooool000001oooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo
00002?ooool00ol0003oooooooooo`3oooooo`7ooooo000`ooooo`03o`000?oooooooooo097ooooo
00?o0000ooooool000002Oooool01Ol0003ooooooooooooooooo000000Sooooo00Go0000oooooooo
ooooooooo`000006ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooo
oooo000000Kooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`3oooooo`7ooooo
000?ooooo`;ok^k^0oooool2onk^kQ[ooooo00?o0000ooooooooool0TOooool00ol0003oooooo`00
0009ooooo`05o`000?ooooooooooooooool000002?ooool01Ol0003ooooooooooooooooo000000Ko
oooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool0
1?l0003oooooooooool0003oooooo`cooooo0008ooooo`Go00000_ooool01oo^k^koEEEEonk^k_oo
ooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h;
ooooo`03o`000?oooooooooo097ooooo00?o0000ooooool000002Oooool01Ol0003ooooooooooooo
oooo000000Sooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool0
00001oooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo0000ooooool<
ooooo`002?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^
kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03o`00
0?oooooooooo097ooooo00?o0000ooooool000002Oooool01Ol0003ooooooooooooooooo000000So
oooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001oooool0
1Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo0000ooooool<ooooo`002Ooo
ool00onHV9So8B4Qonk^kP05ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00?o0000ooooooooool0TOooool00ol0003ooooo
o`000009ooooo`05o`000?ooooooooooooooool000002?ooool01Ol0003ooooooooooooooooo0000
00Kooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001_oo
ool00ol0003oooooo`00003oooooo`gooooo000:ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Gok^k^
oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000;ooooo`03o`000?oooooooooo097ooooo0_l0000:ooooo`05o`000?ooooooooooooooool0
00002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo00001oooool0
1Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooool00000ooooool=ooooo`002oooool0
2omgMgOoIVIVooooooooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000000_ooooo1?l0002Aooooo`03o`000?oooooo
oooo00Sooooo00Go0000ooooooooooooooooo`000008ooooo`05o`000?ooooooooooooooool00000
1oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001_ooool00ol0
003oooooo`00003oooooo`gooooo000<ooooo`03o`000?oooooooooo00;ok^k^0oooool2onk^kPGo
oooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00_ooooo00?o0000oooo
ooooool0WOooool01Ol0003ooooooooooooooooo000000Sooooo00Go0000ooooooooooooooooo`00
0007ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000007ooooo`;o
0000ooooool=ooooo`002?ooool01Ol0003o^[ZjoooooonHV9So410@00kooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?o0000ooooooooool0WOooool01Ol0
003ooooooooooooooooo000000Sooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?oo
ooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000007ooooo`;o0000ooooool=ooooo`00
2?ooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00?ooooo0_l00006ooooo`03o`000?oooooooooo09kooooo00Co0000oooo
oooooooo00002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000
1oooool01Ol0003ooooooooooooooooo000000Oooooo0_l0003oooooo`gooooo000Wooooo`04o`00
0?ooooooooooo`0000Gooooo00?o0000ooooooooool0W_ooool01?l0003oooooooooool00008oooo
o`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool00007ooooo`04o`000?oo
ooooooooo`0000Sooooo0_l0003oooooo`gooooo000Wooooo`04o`000?ooooooooooo`0000Gooooo
00?o0000ooooooooool0W_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00
00Sooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool00008ooooo`;o0000oooo
ool=ooooo`009oooool3o`0000Kooooo00?o0000ooooooooool0W_ooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001oooool01?l0003o
ooooooooool00008ooooo`;o0000ooooool=ooooo`00:?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo09kooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00008
ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00002?ooool2o`000?oooooo
3Oooool002Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2Nooooo`04o`000?oo
ooooooooo`0000Sooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00007oooo
o`04o`000?ooooooooooo`0000Sooooo0_l0003oooooo`gooooo000`ooooo`03o`000?oooooooooo
09kooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000Oooooo00Co0000oooooooooooo00002?ooool2o`000?oooooo3Oooool0033ooooo
00?o0000ooooooooool0W_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00
00Sooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool00008ooooo`;o0000oooo
ool=ooooo`00<?ooool00ol0003oooooooooo`2Nooooo`03o`000?oooooo000000Wooooo00Co0000
oooooooooooo00002?ooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000So
oooo0_l0003oooooo`gooooo000`ooooo`?o0000W_ooool00ol0003oooooo`000009ooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool00008
ooooo`;o0000ooooool=ooooo`00<?ooool00ol0003oooooooooo`2Nooooo`03o`000?oooooo0000
00Wooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00007ooooo`04o`000?oo
ooooooooo`0000Sooooo0_l0003oooooo`gooooo000`ooooo`03o`000?oooooooooo09kooooo00?o
0000ooooool000002Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Oo
oooo00Co0000oooooooooooo0000oooooolGooooo`00<?ooool00ol0003oooooooooo`2Nooooo`03
o`000?oooooo000000Wooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00007
ooooo`04o`000?ooooooooooo`000?oooooo5oooool0033ooooo00?o0000ooooooooool0W_ooool0
0ol0003oooooo`000009ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000
2?ooool00ol0003oooooo`00003ooooooaOooooo000`ooooo`03o`000?oooooooooo09kooooo00?o
0000ooooool000002Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000So
oooo00?o0000ooooool00000oooooolGooooo`00<?ooool00ol0003oooooooooo`2Nooooo`03o`00
0?oooooo000000Wooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00008oooo
o`03o`000?oooooo00000?oooooo5oooool0033ooooo00?o0000ooooooooool0W_ooool00ol0003o
ooooo`000009ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002?ooool0
0ol0003oooooo`00003ooooooaOooooo000`ooooo`03o`000?oooooooooo09kooooo00?o0000oooo
ool000002Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo00?o
0000ooooool00000oooooolGooooo`00<?ooool00ol0003oooooooooo`2Nooooo`03o`000?oooooo
000000Wooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00008ooooo`03o`00
0?oooooo00000?oooooo5oooool0033ooooo00?o0000ooooooooool0Woooool2o`0000Wooooo00Co
0000oooooooooooo00002?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?oo
oooo5oooool0033ooooo00?o0000ooooooooool0Woooool2o`0000Wooooo00Co0000oooooooooooo
00002?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?oooooo5oooool0033o
oooo0ol0002Oooooo`;o00002Oooool01?l0003oooooooooool00008ooooo`04o`000?oooooooooo
o`0000Sooooo00?o0000ooooool00000oooooolGooooo`00<?ooool00ol0003oooooooooo`2Ooooo
o`03o`000?oooooooooo00Sooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0
0008ooooo`;o0000oooooolHooooo`00<?ooool00ol0003oooooooooo`2Zooooo`04o`000?oooooo
ooooo`0000Sooooo00Co0000oooooooooooo00002?ooool2o`000?oooooo6?ooool0033ooooo00?o
0000ooooooooool0Zoooool00ol0003oooooo`000008ooooo`03o`000?oooooo000000Wooooo0_l0
003ooooooaSooooo000`ooooo`03o`000?oooooooooo0:_ooooo00?o0000ooooool000002?ooool0
0ol0003oooooo`000009ooooo`;o0000oooooolHooooo`00<?ooool00ol0003oooooooooo`2[oooo
o`03o`000?oooooo000000Sooooo00?o0000ooooool000002Oooool2o`000?oooooo6?ooool0033o
oooo00?o0000ooooooooool0Zoooool2o`0000Wooooo00?o0000ooooool000002Oooool2o`000?oo
oooo6?ooool0033ooooo00?o0000ooooooooool0Zoooool2o`0000Wooooo00?o0000ooooool00000
2_ooool00ol0003oooooooooo`3ooooooaKooooo000`ooooo`03o`000?oooooooooo0:_ooooo0_l0
000:ooooo`;o0000oooooolSooooo`00<?ooool00ol0003oooooooooo`2[ooooo`;o00002_ooool2
o`000?oooooo8oooool0033ooooo00?o0000ooooooooool0Zoooool2o`0000[ooooo0_l0003ooooo
ob?ooooo000`ooooo`03o`000?oooooooooo0:_ooooo0_l0000:ooooo`;o0000oooooolSooooo`00
<?ooool3o`000:_ooooo0_l0000:ooooo`;o0000oooooolSooooo`00<?ooool00ol0003ooooooooo
o`2[ooooo`;o00002_ooool2o`000?oooooo8oooool0033ooooo00?o0000ooooooooool0Zoooool2
o`0000[ooooo0_l0003oooooob?ooooo000`ooooo`03o`000?oooooooooo0:_ooooo0_l0000:oooo
o`;o0000oooooolSooooo`00<?ooool00ol0003oooooooooo`2[ooooo`;o00002_ooool2o`000?oo
oooo8oooool0033ooooo00?o0000ooooooooool0[?ooool00ol0003oooooooooo`08ooooo`;o0000
oooooolSooooo`003oooool2onk^kP?ooooo0_o^k^hJooooo`03o`000?oooooooooo0;Oooooo0_l0
003oooooob?ooooo000:ooooo`;o000000[o410@ooooooooooook^k^oeEEEOo^k^koooooonk^k_mE
EEGok^k^0oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`03o`00
0?oooooooooo0?oooooog?ooool000_ooooo00?o0000ooooooooool00_ooool01Oo^k^koEEEEomgM
gOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00?o0000ooooooooool0oooooooLooooo`002?ooool5o`0000Cooooo00?ogMgMo`000?oMgMd0
1oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41002oooool00ol0003o
ooooooooo`3oooooomcooooo0008ooooo`04odA4A?oMgMgoooooo`0000Cooooo00Gok^k^oeEEEOoM
gMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000;
ooooo`03o`000?oooooooooo0?oooooog?ooool000Sooooo00CogMgMoeEEEOoooooo00000oooool0
1oo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000002oooool4o`000?oooooofoooool000Wooooo00?oMgMgolc<c?l00000
0oooool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@400;ooooo`03o`000?oooooooooo0?oooooog?ooool000Wooooo00?ok^k^odA4A?l00000
3oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ol0003o
ooooooooo`3oooooomcooooo000:ooooo`03ogMgMol0003ooooo00cooooo00?oEEEEofIVI_l00000
1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo0_l00006ooooo`03o`000?oooooooooo0?oo
oooog?ooool002Oooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`3oooooomco
oooo000Wooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0oooooooLooooo`00
9oooool3o`0000Kooooo00?o0000ooooooooool0oooooooLooooo`00:?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo0?oooooog?ooool002Wooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033o
oooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo
000`ooooo`?o0000oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`oooo
o`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00
<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?oo
ool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3ooooo
omcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0
oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooo
oooo0?oooooog?ooool0033ooooo0ol0003oooooomcooooo000`ooooo`03o`000?oooooooooo0?oo
oooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooooooo
o`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooo
ooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`00
0?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool0
0ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033o
oooo00?o0000ooooooooool0oooooooLooooo`00<?ooool3o`000?oooooog?ooool0033ooooo00?o
0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`oooo
o`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00
oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooo
oa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003o
oooooooooooo4?ooool00:3ooooo0_l00004ooooo`03okZj^_lb<S;ooooo00Cooooo0_l00006oooo
o`03o`000?nj^[[ooooo0?ooooooEoooool00:3ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Cooooo0_lb<S;ooooooeSooooo002=ooooo`?o0000
0_ooool01_lb<S;o410@ooooooooooook^k^oeEEE@;o000000?oA4A4okZj^_ooool00oooool00ol0
003oooooooooo`02ooooo`05oiRHV?l@413o0000o`000?nYZJT01?ooool00ol0003oooooooooo`04
ooooo`03ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P09ooooo`05olc<c?lQ
8B7o0000ob4Q8Oo<c<`01Oooool2ob4Q8@Kooooo0_l000001ol@413oooooolc<c?o^k^koooooonk^
k_o<c<`01?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hCooooo`06oa0@
4?lb<S;o0000o`000?l@413oZJVY0_ooool01_o^k^koEEEEo`000?l0003oA4A4okZj^P?ooooo00Go
IVIVo`000?l0003oA4A4olc<c03Xooooo`00S_ooool01Ol0003oooooooooooo<c<co410@00?ooooo
00KoEEEEogMgMoooooook^k^ogMgMol@4104ooooo`03o`000?oooooooooo00;ooooo00Ko0000ojVY
ZOmEEEGoV9RHoeEEEOnj^[X3ooooo`03o`000?oooooooooo00Cooooo00?oc<c<o`000?l@41003?oo
ool01_l@413o^[Zjonk^k_mgMgOo410@ooooo`Ko00000_ooool01OlQ8B7oV9RHoooooonHV9So8B4Q
00Gooooo0_lQ8B47ooooo`08o`000?ooooooooooonk^k_mEEEGogMgMoeEEEOo^k^h6ooooo`03o`00
0?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Cooooo`06o`000?nYZJWooooooooo
oonj^[[o00000_ooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40;ooooo00KoIVIVogMgMooooooo
ooooohN7Qol@413Xooooo`00S_ooool01Ol0003ooooooooooomEEEGoQhN700?ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`02ooooo`06oc8b<_o^k^koV9RHoeEEEOoMgMgo410@0ooo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00_ooooo00Go0000oooooooooooooooo
o`00000;ooooo`Go00000_ooool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo
00Go410@oooooooooooooooooa0@400Dooooo`05okZj^_n7QhOoIVIVofIVI_l@41000_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo0>_ooooo002>ooooo`05o`000?oooooogMgMo`00
0?o^k^h00oooool6o`0000Cooooo00?o0000ooooooooool00_ooool01onj^[[oA4A4olc<c?lQ8B7o
oooooa0@4?o<c<`00_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00?ooooo1_l0
0002ooooo`05oc8b<_nHV9SooooooiRHV?lb<S802oooool01?m4A4CogMgMooooool00002ooooo`05
onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool000004oooool01_lb<S;o8B4QogMgMomgMgOoQhN7onk^kP;ooooo1_l00002ooooo`03o`00
0?oooooooooo0>_ooooo002>ooooo`?o000000?o410@oiRHV?ooool00_ooool01_mEEEGoQhN7onk^
k_ooooooQhN7oc8b<PCooooo00?o0000ooooooooool00_ooool01oo^k^ko0000ooooool0003ooooo
ofIVI_n7QhL00_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00_ooooo00Goc<c<
o`000?l0003o0000olc<c00;ooooo`04omgMgOmEEEGoooooo`0000;ooooo00Goc<c<onk^k_oooooo
k^k^olc<c006ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Coooo
o`06o`000?nj^[[oooooonk^k_mgMgOo00000_ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<P;o
oooo00KoIVIVogMgMoooooooooooohN7Qol0003Xooooo`00S_ooool01Ol0003oooooooooooo<c<co
000000?ooooo00Kok^k^oeEEEOl0003o0000odA4A?o^k^h4ooooo`03o`000?oooooooooo00;ooooo
00CoIVIVoiRHV?oooooo<S8b0_nj^[X01?l0003oooooooooool0000Cooooo`03oa0@4?l0003o0000
00?o00002_ooool01Ol@413o^[Zjoooooonj^[[o410@00cooooo00?oMgMgolc<c?l000003Oooool0
0ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41001oooool3o`0000;ooooo0ol0
0004ooooo`06ojVYZOlQ8B7o0000o`000?lb<S;o00000_ooool01_o^k^koEEEEo`000?l0003oA4A4
onk^kP;ooooo00Kok^k^ofIVI_l0003o0000odA4A?l0003Xooooo`00S_ooool01Ol0003ooooooooo
ooo<c<co000000gooooo00?o0000ooooooooool01Oooool00omVIVKoQhN7ooooo`03ooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool02oooool01Ol0003o^[Zjoooooonj^[[o000000co
oooo00?ok^k^odA4A?l000003Oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo0_ooool008go
oooo1?l000000ol@413oZJVYooooo`0<ooooo`;o00001_ooool00onYZJWoA4A4ooooo`02ooooo`;o
00005Oooool00ol0003oooooooooo`0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT03Oooool00omg
MgOo0000ooooo`0:ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02
ooooo`Co00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo0_ooool0
0?oooooo1_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo0_ooool00?oo
oooo1_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo0_ooool00?oooooo
1Oooool2o`0000?ooooo0_l0003oooooo`Cooooo003ooooooooooooo4?ooool00?ooooooooooool@
ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooo
oooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3o
oooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooo
oooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?oo
ool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooo
ooooool@ooooo`00\
\>"],
  ImageRangeCache->{{{0, 525.688}, {324.5, 0}} -> {-2.58312*^-7, -6.34248*^6, \
6.65005*^-9, 53093.5}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0.309017 5.42214e-08 [
[.32684 .29652 -16.5 -12.5 ]
[.32684 .29652 16.5 0 ]
[.54329 .29652 -16.5 -12.5 ]
[.54329 .29652 16.5 0 ]
[.75974 .29652 -22.5 -12.5 ]
[.75974 .29652 22.5 0 ]
[.97619 .29652 -16.5 -12.5 ]
[.97619 .29652 16.5 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 64 6 ]
[.09789 .09213 -34.5 -6.25 ]
[.09789 .09213 0 6.25 ]
[.09789 .20057 -34.5 -6.25 ]
[.09789 .20057 0 6.25 ]
[.09789 .41746 -28.5 -6.25 ]
[.09789 .41746 0 6.25 ]
[.09789 .5259 -28.5 -6.25 ]
[.09789 .5259 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -62.8125 0 ]
[.5 .63053 62.8125 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 .30902 m
.32684 .31527 L
s
gsave
.32684 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 .30902 m
.54329 .31527 L
s
gsave
.54329 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 .30902 m
.75974 .31527 L
s
gsave
.75974 .29652 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 .30902 m
.15368 .31277 L
s
.19697 .30902 m
.19697 .31277 L
s
.24026 .30902 m
.24026 .31277 L
s
.28355 .30902 m
.28355 .31277 L
s
.37013 .30902 m
.37013 .31277 L
s
.41342 .30902 m
.41342 .31277 L
s
.45671 .30902 m
.45671 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.58658 .30902 m
.58658 .31277 L
s
.62987 .30902 m
.62987 .31277 L
s
.67316 .30902 m
.67316 .31277 L
s
.71645 .30902 m
.71645 .31277 L
s
.80303 .30902 m
.80303 .31277 L
s
.84632 .30902 m
.84632 .31277 L
s
.88961 .30902 m
.88961 .31277 L
s
.9329 .30902 m
.9329 .31277 L
s
.0671 .30902 m
.0671 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09213 m
.11664 .09213 L
s
gsave
.09789 .09213 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .20057 m
.11664 .20057 L
s
gsave
.09789 .20057 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .41746 m
.11664 .41746 L
s
gsave
.09789 .41746 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .5259 m
.11664 .5259 L
s
gsave
.09789 .5259 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.11039 .11924 m
.11414 .11924 L
s
.11039 .14635 m
.11414 .14635 L
s
.11039 .17346 m
.11414 .17346 L
s
.11039 .22768 m
.11414 .22768 L
s
.11039 .2548 m
.11414 .2548 L
s
.11039 .28191 m
.11414 .28191 L
s
.11039 .33613 m
.11414 .33613 L
s
.11039 .36324 m
.11414 .36324 L
s
.11039 .39035 m
.11414 .39035 L
s
.11039 .44457 m
.11414 .44457 L
s
.11039 .47168 m
.11414 .47168 L
s
.11039 .49879 m
.11414 .49879 L
s
.11039 .06502 m
.11414 .06502 L
s
.11039 .03791 m
.11414 .03791 L
s
.11039 .0108 m
.11414 .0108 L
s
.11039 .55301 m
.11414 .55301 L
s
.11039 .58012 m
.11414 .58012 L
s
.11039 .60723 m
.11414 .60723 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -123.812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.812 moveto
(@) show
81.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.812 moveto
(D) show
93.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8.6) show
135.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
141.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
153.000 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
157.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
166.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
184.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02691 .30902 L
.03029 .30902 L
.03347 .30902 L
.03652 .30902 L
.03978 .30902 L
.04291 .30902 L
.04623 .30902 L
.04944 .30902 L
.05252 .30902 L
.0558 .30902 L
.05896 .30902 L
.062 .30902 L
.06523 .30902 L
.06834 .30902 L
.07165 .30902 L
.07484 .30902 L
.0779 .30902 L
.07962 .30902 L
.08117 .30902 L
.08194 .30902 L
.08235 .30902 L
.08278 .30902 L
.08316 .30902 L
.08338 .30902 L
.08358 .30902 L
.08367 .30902 L
.08376 .30902 L
.08384 .30902 L
.08393 .30902 L
.08402 .30902 L
.08413 .30902 L
.08421 .30902 L
.08431 .30902 L
.08441 .30902 L
.0845 .30902 L
.0846 .30902 L
.0847 .30902 L
.08492 .30902 L
.08512 .30902 L
.0855 .30902 L
.08586 .30902 L
.08628 .30902 L
.08666 .30902 L
.08753 .30902 L
.08831 .30902 L
.08904 .30902 L
.08984 .30902 L
.0907 .30902 L
.09151 .30902 L
Mistroke
.0924 .30902 L
.09401 .30902 L
.09559 .30902 L
.09728 .30902 L
.099 .30902 L
.10062 .30902 L
.10372 .30902 L
.10532 .30902 L
.10701 .30902 L
.11007 .30902 L
.11163 .30902 L
.11331 .30902 L
.11664 .30902 L
.11984 .30902 L
.12292 .30902 L
.1262 .30902 L
.12936 .30902 L
.13239 .30902 L
.13562 .30902 L
.13873 .30902 L
.14031 .30902 L
.14115 .30902 L
.14204 .30902 L
.14248 .30902 L
.1429 .30902 L
.14331 .30902 L
.14369 .30902 L
.14405 .30902 L
.14423 .30902 L
.14433 .30902 L
.14442 .30902 L
.14453 .30902 L
.14462 .30902 L
.14472 .30902 L
.14478 .30902 L
.14484 .30902 L
.14492 .30902 L
.14502 .30902 L
.14513 .30902 L
.14522 .30902 L
.14542 .30902 L
.1456 .30902 L
.1458 .30902 L
.14601 .30902 L
.14644 .30902 L
.14684 .30902 L
.1476 .30902 L
.14832 .30902 L
.1491 .30902 L
.14993 .30902 L
Mistroke
.15141 .30902 L
.15298 .30902 L
.15445 .30902 L
.15607 .30902 L
.15756 .30902 L
.15922 .30902 L
.16075 .30902 L
.16382 .30902 L
.16696 .30902 L
.1703 .30902 L
.17352 .30902 L
.17661 .30902 L
.17991 .30902 L
.18155 .30902 L
.18308 .30902 L
.18455 .30902 L
.18537 .30902 L
.18573 .30902 L
.18613 .30902 L
.18651 .30902 L
.18672 .30902 L
.18682 .30902 L
.18692 .30902 L
.18701 .30902 L
.18711 .30902 L
.1872 .30902 L
.18728 .30902 L
.18737 .30902 L
.18746 .30902 L
.18756 .30902 L
.18766 .30902 L
.18776 .30902 L
.18786 .30902 L
.18808 .30902 L
.18827 .30902 L
.18846 .30902 L
.18888 .30902 L
.18933 .30902 L
.19014 .30902 L
.1906 .30902 L
.19103 .30902 L
.19264 .30902 L
.19349 .30902 L
.19429 .30902 L
.19579 .30902 L
.1974 .30902 L
.19889 .30902 L
.20206 .30902 L
.20512 .30902 L
.20837 .30902 L
Mistroke
.2115 .30902 L
.21482 .30901 L
.21649 .30901 L
.21803 .30901 L
.21952 .30901 L
.22028 .30901 L
.22071 .30901 L
.22111 .30901 L
.2213 .30901 L
.22151 .30901 L
.22162 .30901 L
.22173 .30901 L
.22184 .30901 L
.22194 .30901 L
.22204 .30901 L
.22214 .30901 L
.22223 .30901 L
.22232 .30901 L
.22242 .30901 L
.22248 .30901 L
.22253 .30901 L
.22263 .30901 L
.22273 .30901 L
.22292 .30901 L
.2231 .30901 L
.2235 .30901 L
.22384 .30901 L
.22422 .30901 L
.22503 .30901 L
.22577 .30901 L
.22659 .30901 L
.22745 .30901 L
.22903 .30902 L
.2305 .30902 L
.23214 .30902 L
.23364 .30902 L
.23684 .30902 L
.23993 .30903 L
.24321 .30903 L
.24638 .30904 L
.24797 .30904 L
.24942 .30904 L
.25022 .30904 L
.25098 .30904 L
.25118 .30904 L
.25139 .30904 L
.25158 .30904 L
.25178 .30904 L
.2519 .30904 L
.25202 .30904 L
Mistroke
.25212 .30904 L
.25218 .30904 L
.25224 .30904 L
.25234 .30904 L
.25244 .30904 L
.25249 .30904 L
.25255 .30904 L
.25265 .30904 L
.25275 .30904 L
.25284 .30904 L
.25302 .30904 L
.25313 .30904 L
.25324 .30904 L
.25343 .30904 L
.25382 .30904 L
.25425 .30904 L
.25463 .30904 L
.25502 .30904 L
.25573 .30904 L
.25656 .30904 L
.25745 .30904 L
.25907 .30903 L
.26067 .30902 L
.26236 .30902 L
.2654 .30899 L
.26864 .30896 L
.27176 .30893 L
.27335 .30892 L
.27508 .3089 L
.27588 .3089 L
.27674 .30889 L
.27747 .30889 L
.27785 .30888 L
.27827 .30888 L
.27867 .30888 L
.27888 .30888 L
.27898 .30888 L
.27908 .30888 L
.27917 .30888 L
.27927 .30888 L
.27936 .30888 L
.27944 .30888 L
.27953 .30888 L
.27962 .30888 L
.27973 .30888 L
.27982 .30888 L
.27993 .30888 L
.28004 .30888 L
.28014 .30888 L
.28024 .30888 L
Mistroke
.28063 .30888 L
.28085 .30888 L
.28105 .30888 L
.28149 .30889 L
.2823 .30889 L
.28304 .3089 L
.28385 .30891 L
.28471 .30892 L
.28629 .30895 L
.28776 .30898 L
.29088 .30908 L
.2942 .30922 L
.2974 .30936 L
.29887 .30941 L
.30048 .30947 L
.30124 .30949 L
.30207 .30951 L
.30252 .30952 L
.30294 .30953 L
.30334 .30953 L
.30354 .30953 L
.30375 .30954 L
.30396 .30954 L
.30407 .30954 L
.30418 .30954 L
.30427 .30954 L
.30437 .30954 L
.30442 .30954 L
.30448 .30954 L
.30458 .30954 L
.30468 .30954 L
.30478 .30954 L
.30488 .30954 L
.30497 .30954 L
.30514 .30953 L
.30533 .30953 L
.30578 .30953 L
.30621 .30952 L
.30701 .3095 L
.3078 .30947 L
.30863 .30943 L
.31011 .30934 L
.31169 .30921 L
.31316 .30906 L
.31629 .30866 L
.31962 .30816 L
.32128 .30792 L
.32282 .30773 L
.32431 .30757 L
.32507 .30751 L
Mistroke
.32549 .30748 L
.3259 .30746 L
.32629 .30744 L
.32651 .30744 L
.32671 .30743 L
.32681 .30743 L
.3269 .30743 L
.32698 .30743 L
.32707 .30743 L
.32717 .30743 L
.32726 .30742 L
.32735 .30742 L
.32746 .30742 L
.32751 .30742 L
.32757 .30743 L
.32762 .30743 L
.32767 .30743 L
.32777 .30743 L
.32787 .30743 L
.32809 .30743 L
.32832 .30744 L
.32874 .30746 L
.32913 .30748 L
.32992 .30755 L
.33075 .30764 L
.33146 .30775 L
.33224 .30789 L
.33381 .30825 L
.33549 .30875 L
.33882 .31001 L
.34203 .31136 L
.34349 .31194 L
.34511 .31249 L
.34588 .3127 L
.3467 .31288 L
.34716 .31296 L
.34758 .31301 L
.34778 .31304 L
.348 .31306 L
.3482 .31307 L
.34839 .31308 L
.3485 .31309 L
.34855 .31309 L
.34861 .31309 L
.3487 .31309 L
.3488 .31309 L
.34886 .31309 L
.34891 .31309 L
.34901 .31309 L
.34907 .31309 L
Mistroke
.34912 .31309 L
.34924 .31309 L
.34934 .31308 L
.34943 .31308 L
.34963 .31307 L
.34983 .31305 L
.35004 .31303 L
.35042 .31297 L
.35082 .3129 L
.35154 .31273 L
.3523 .31247 L
.35312 .31213 L
.3546 .31132 L
.35631 .31008 L
.35793 .30866 L
.36102 .30556 L
.36259 .30396 L
.36431 .30236 L
.3651 .30171 L
.36594 .30112 L
.36674 .30066 L
.36747 .30033 L
.36787 .3002 L
.36829 .3001 L
.3684 .30008 L
.36853 .30005 L
.36864 .30004 L
.36875 .30003 L
.36886 .30002 L
.36892 .30001 L
.36897 .30001 L
.36907 .30001 L
.36917 .30001 L
.36923 .30001 L
.36928 .30001 L
.36938 .30001 L
.36944 .30002 L
.36949 .30002 L
.36961 .30003 L
.36981 .30006 L
.37002 .3001 L
.37022 .30014 L
.37042 .3002 L
.37079 .30033 L
.37156 .30072 L
.37238 .30131 L
.37315 .30204 L
.37385 .30283 L
.37707 .30796 L
.38016 .31449 L
Mistroke
.38173 .31792 L
.38345 .32139 L
.38424 .32279 L
.38509 .3241 L
.38589 .32511 L
.38662 .32584 L
.38702 .32613 L
.38744 .32637 L
.38766 .32646 L
.38786 .32653 L
.38798 .32656 L
.38809 .32658 L
.38814 .32658 L
.3882 .32659 L
.38827 .3266 L
.38833 .3266 L
.38843 .3266 L
.38848 .3266 L
.38854 .3266 L
.38863 .32659 L
.38874 .32657 L
.38883 .32655 L
.38891 .32653 L
.38911 .32647 L
.38932 .32639 L
.38951 .32628 L
.38994 .32598 L
.39033 .32563 L
.39073 .32517 L
.39147 .3241 L
.39234 .32245 L
.39313 .3206 L
.39635 .31012 L
.39945 .29739 L
.40102 .29104 L
.40275 .28497 L
.40354 .28268 L
.40439 .28068 L
.4048 .2799 L
.40519 .27929 L
.40554 .27885 L
.40592 .27849 L
.40611 .27836 L
.40621 .27831 L
.40631 .27826 L
.4064 .27822 L
.4065 .2782 L
.40659 .27818 L
.40668 .27817 L
.40673 .27817 L
Mistroke
.40678 .27817 L
.40689 .27818 L
.40699 .27819 L
.40708 .27822 L
.40718 .27826 L
.40729 .27831 L
.40751 .27845 L
.40773 .27864 L
.40793 .27886 L
.40838 .27949 L
.4088 .28026 L
.4092 .28116 L
.40997 .28338 L
.41079 .28639 L
.41227 .29338 L
.4153 .31262 L
.41852 .33557 L
.42 .34485 L
.42084 .3493 L
.42162 .35277 L
.4224 .35547 L
.42283 .35661 L
.42323 .35741 L
.42345 .35775 L
.42365 .358 L
.42376 .35811 L
.42387 .3582 L
.42398 .35827 L
.42404 .35829 L
.4241 .35832 L
.42421 .35835 L
.42427 .35835 L
.42432 .35835 L
.42442 .35834 L
.42448 .35833 L
.42453 .35831 L
.42463 .35827 L
.42473 .3582 L
.42492 .35804 L
.42511 .35781 L
.42532 .35749 L
.42569 .35674 L
.42613 .35554 L
.42652 .35415 L
.42739 .35019 L
.42822 .34528 L
.42981 .33278 L
.43129 .31835 L
.43445 .28303 L
.43603 .26595 L
Mistroke
.43748 .25257 L
.43822 .24697 L
.43903 .24205 L
.43943 .24017 L
.43985 .23855 L
.44008 .23783 L
.44029 .2373 L
.44051 .23687 L
.4406 .23672 L
.44071 .23657 L
.44081 .23646 L
.4409 .23639 L
.44099 .23633 L
.44108 .2363 L
.44118 .23629 L
.44127 .2363 L
.44138 .23634 L
.44143 .23638 L
.44149 .23642 L
.44159 .23652 L
.44169 .23664 L
.44191 .23701 L
.44211 .23745 L
.44231 .23802 L
.44268 .23932 L
.44302 .24086 L
.44379 .24552 L
.44464 .25237 L
.44543 .26046 L
.44692 .27932 L
.45001 .32821 L
.45157 .35389 L
.45328 .37909 L
.45407 .38868 L
.45491 .39719 L
.45532 .40054 L
.45571 .40324 L
.45609 .40535 L
.45644 .40689 L
.45664 .40754 L
.45684 .40809 L
.45694 .40828 L
.45704 .40844 L
.45712 .40856 L
.45721 .40865 L
.45727 .40869 L
.45732 .40871 L
.45741 .40874 L
.45752 .40872 L
.45758 .40869 L
Mistroke
.45763 .40865 L
.45773 .40856 L
.45783 .40843 L
.45793 .40824 L
.45803 .40803 L
.45821 .40754 L
.4584 .40689 L
.45874 .40536 L
.45911 .40321 L
.45951 .40026 L
.46033 .39224 L
.46108 .38279 L
.46276 .35495 L
.46597 .2856 L
.46905 .22043 L
.46988 .20682 L
.47065 .19633 L
.47145 .18808 L
.47188 .18491 L
.4721 .18361 L
.47234 .18251 L
.47245 .18207 L
.47256 .18172 L
.47266 .18144 L
.47276 .18124 L
.47285 .18108 L
.47295 .18097 L
.47304 .1809 L
.4731 .18089 L
.47315 .18089 L
.47321 .1809 L
.47326 .18094 L
.47332 .18099 L
.47337 .18105 L
.47347 .18121 L
.47358 .18143 L
.4738 .18209 L
.47404 .1831 L
.47444 .18549 L
.47487 .18902 L
.47565 .19789 L
.47642 .20964 L
.47726 .22561 L
.47895 .26608 L
.48221 .35946 L
.48372 .40024 L
.48535 .43593 L
.48578 .44334 L
.48624 .45006 L
.48667 .4552 L
Mistroke
.48707 .459 L
.48744 .46165 L
.48765 .46274 L
.48784 .46349 L
.48794 .4638 L
.48804 .46402 L
.4881 .46411 L
.48815 .46419 L
.48821 .46424 L
.48827 .46427 L
.48837 .46427 L
.48847 .46421 L
.48857 .46406 L
.48863 .46396 L
.48868 .46383 L
.48889 .46318 L
.489 .46269 L
.48911 .46216 L
.48951 .45945 L
.48987 .45604 L
.49025 .45145 L
.49105 .43882 L
.49194 .42035 L
.49349 .37772 L
.49517 .32196 L
.49675 .26584 L
.49848 .20838 L
.49928 .18531 L
.50013 .16437 L
.50094 .14876 L
.50128 .14341 L
.50167 .13856 L
.50206 .13476 L
.50227 .1332 L
.50247 .13207 L
.50257 .13164 L
.50266 .1313 L
.50274 .13106 L
.50283 .13086 L
.50292 .13071 L
.50301 .13065 L
.50311 .13065 L
.50321 .13073 L
.50332 .13091 L
.50337 .13104 L
.50343 .1312 L
.50363 .13198 L
.50374 .13256 L
.50386 .1333 L
.50407 .13493 L
Mistroke
.5045 .13926 L
.50488 .14446 L
.50568 .15904 L
.50642 .17669 L
.50809 .22919 L
.51125 .35466 L
.51284 .41546 L
.5143 .46094 L
.5151 .47997 L
.51586 .49326 L
.51606 .49594 L
.51627 .49839 L
.51646 .50017 L
.51666 .50173 L
.51678 .5025 L
.5169 .50309 L
.517 .50353 L
.51706 .50372 L
.51712 .50388 L
.51722 .50409 L
.51732 .50419 L
.51738 .50421 L
.51743 .5042 L
.51753 .50409 L
.51763 .50391 L
.51773 .50363 L
.51782 .50328 L
.5179 .50288 L
.5181 .50169 L
.51831 .50003 L
.51871 .49576 L
.51914 .48943 L
.5199 .47401 L
.52062 .45523 L
.52226 .3981 L
.52375 .33482 L
.52543 .25986 L
.52697 .19587 L
.52847 .14587 L
.52923 .12732 L
.52966 .11911 L
.53006 .11306 L
.53046 .10863 L
.53069 .10686 L
.5308 .10621 L
.5309 .1057 L
.53099 .10535 L
.53108 .10507 L
.53119 .10487 L
.53128 .10478 L
Mistroke
.53138 .1048 L
.53148 .10492 L
.53153 .10503 L
.53159 .10518 L
.53169 .10553 L
.53179 .10598 L
.53188 .10649 L
.53209 .10798 L
.53228 .10967 L
.53247 .11185 L
.53318 .12305 L
.53358 .13145 L
.53394 .14042 L
.53475 .16478 L
.53622 .22103 L
.53941 .36821 L
.54102 .43577 L
.54172 .46025 L
.54248 .48221 L
.5429 .49221 L
.54329 .49982 L
.54366 .50563 L
.54406 .51015 L
.54426 .5118 L
.54437 .51252 L
.54447 .51308 L
.54457 .51348 L
.54467 .51381 L
.54477 .514 L
.54486 .51408 L
.54496 .51406 L
.54506 .51393 L
.54512 .51381 L
.54517 .51366 L
.54529 .51323 L
.54539 .51271 L
.54551 .51199 L
.54574 .5101 L
.54594 .50795 L
.54616 .50511 L
.54657 .49863 L
.54732 .48207 L
.54819 .45604 L
.549 .42657 L
.55216 .28257 L
.55375 .21113 L
.55521 .15813 L
.55601 .13635 L
.55638 .12844 L
.55677 .12157 L
Mistroke
.55699 .11846 L
.55718 .1161 L
.55739 .11414 L
.55757 .11274 L
.55768 .11211 L
.55779 .11158 L
.5579 .1112 L
.55796 .11104 L
.55802 .11094 L
.55808 .11088 L
.55813 .11085 L
.55823 .11089 L
.55833 .11104 L
.55839 .11119 L
.55845 .11136 L
.55855 .11175 L
.55864 .11223 L
.55882 .11341 L
.55901 .11508 L
.55922 .11737 L
.5596 .12268 L
.55995 .12897 L
.56075 .14801 L
.5616 .17472 L
.56494 .31795 L
.56661 .39214 L
.56735 .42068 L
.56816 .44766 L
.56893 .46843 L
.56931 .47634 L
.56966 .48253 L
.56985 .48534 L
.57006 .48795 L
.57023 .48976 L
.57043 .49138 L
.57063 .49266 L
.57075 .49317 L
.5708 .49335 L
.57085 .49351 L
.57095 .49372 L
.57104 .49381 L
.57114 .49381 L
.5712 .49376 L
.57125 .49368 L
.57135 .49344 L
.5714 .49328 L
.57146 .49307 L
.57165 .49206 L
.57176 .49132 L
.57188 .49037 L
Mistroke
.57209 .48828 L
.57251 .48279 L
.57289 .4762 L
.57366 .45872 L
.57438 .43738 L
.57745 .31489 L
.57916 .2427 L
.58072 .18874 L
.5815 .16842 L
.5819 .1599 L
.58234 .15267 L
.58272 .14786 L
.58293 .14579 L
.58313 .14429 L
.58323 .14372 L
.58332 .14327 L
.5834 .14294 L
.58348 .14266 L
.58358 .14245 L
.58366 .14233 L
.58376 .1423 L
.58386 .14237 L
.58396 .14254 L
.58405 .14278 L
.58415 .14315 L
.58426 .14366 L
.58448 .14506 L
.58467 .14676 L
.58506 .15114 L
.58542 .15659 L
.58622 .173 L
.58709 .19669 L
.59038 .31838 L
.59202 .37903 L
.59282 .40419 L
.59355 .42341 L
.59391 .43138 L
.5943 .43882 L
.59464 .44415 L
.59501 .44881 L
.59521 .45068 L
.59541 .45231 L
.59552 .45303 L
.59563 .45359 L
.59573 .45405 L
.59583 .45438 L
.59592 .45459 L
.59601 .45474 L
.59611 .45481 L
.5962 .4548 L
Mistroke
.5963 .45469 L
.5964 .45448 L
.5965 .45418 L
.59659 .45383 L
.59679 .4528 L
.59696 .45155 L
.59737 .44767 L
.59774 .44279 L
.59809 .43706 L
.59889 .4207 L
.59975 .398 L
.60301 .28911 L
.60452 .24171 L
.60532 .22117 L
.60615 .20397 L
.60658 .19722 L
.60681 .19423 L
.60705 .19149 L
.60727 .1894 L
.60748 .18785 L
.60768 .18665 L
.60787 .18584 L
.60797 .18557 L
.60807 .18535 L
.60812 .18527 L
.60818 .18521 L
.60828 .18518 L
.60837 .18522 L
.60847 .18535 L
.60856 .18552 L
.60865 .18578 L
.60876 .18619 L
.60886 .18664 L
.60909 .18797 L
.6093 .18957 L
.60949 .19139 L
.61027 .20152 L
.61067 .20827 L
.6111 .21683 L
.61258 .25342 L
.61427 .30294 L
.61582 .34725 L
.61659 .36653 L
.61742 .38434 L
.6178 .39116 L
.61821 .3974 L
.61856 .40196 L
.61894 .40582 L
.61914 .40752 L
.61937 .40902 L
Mistroke
.61957 .41007 L
.61967 .41044 L
.61977 .41077 L
.61983 .41093 L
.61988 .41106 L
.61993 .41116 L
.61999 .41125 L
.62009 .41134 L
.6202 .41136 L
.62026 .41133 L
.62031 .41128 L
.62038 .4112 L
.62044 .4111 L
.62054 .41085 L
.62066 .41049 L
.62087 .40957 L
.62107 .40846 L
.6215 .40505 L
.6219 .40079 L
.62228 .39587 L
.62389 .36659 L
.62537 .33177 L
.62701 .29154 L
.62781 .27348 L
.62854 .25885 L
.62924 .24693 L
.63001 .23684 L
.63043 .2327 L
.63062 .23121 L
.63082 .22981 L
.631 .22878 L
.63119 .2279 L
.6313 .22751 L
.6314 .22721 L
.63149 .22699 L
.63159 .2268 L
.63169 .22667 L
.63179 .22661 L
.63188 .22661 L
.63197 .22665 L
.63206 .22675 L
.63216 .22691 L
.63227 .22716 L
.63237 .22745 L
.63256 .22814 L
.63273 .22894 L
.6331 .23134 L
.63351 .2348 L
.63396 .23954 L
.63477 .25049 L
Mistroke
.63803 .31203 L
.63954 .34003 L
.64034 .35225 L
.64117 .36251 L
.6416 .36654 L
.64183 .36833 L
.64207 .36997 L
.64229 .37122 L
.6425 .37215 L
.6427 .37287 L
.64289 .37336 L
.64299 .37353 L
.64309 .37367 L
.64314 .37372 L
.6432 .37375 L
.6433 .37378 L
.64339 .37376 L
.64349 .37369 L
.64358 .3736 L
.64367 .37345 L
.64378 .37322 L
.64388 .37296 L
.64411 .3722 L
.64432 .37128 L
.64451 .37023 L
.6453 .36442 L
.64612 .3557 L
.6476 .33522 L
.65065 .28832 L
.65145 .27814 L
.65221 .27024 L
.65263 .26673 L
.65309 .26364 L
.65329 .26254 L
.6535 .26154 L
.65369 .26083 L
.65389 .2602 L
.6541 .25972 L
.65421 .25953 L
.65427 .25946 L
.65432 .25941 L
.65442 .25933 L
.65451 .25929 L
.65461 .25929 L
.65467 .25931 L
.65472 .25933 L
.65477 .25937 L
.65482 .25942 L
.65492 .25954 L
.65504 .25973 L
Mistroke
.65515 .25996 L
.65539 .2606 L
.65561 .26141 L
.65601 .2633 L
.65639 .26554 L
.65723 .2722 L
.65888 .28982 L
.66037 .30815 L
.66205 .32715 L
.66278 .33396 L
.66317 .33704 L
.66359 .33989 L
.664 .3422 L
.66437 .34387 L
.66455 .34452 L
.66474 .34513 L
.66492 .34558 L
.66509 .34592 L
.66519 .34607 L
.66528 .34618 L
.66539 .34627 L
.66544 .34631 L
.66549 .34634 L
.6656 .34637 L
.6657 .34637 L
.66575 .34635 L
.6658 .34633 L
.66586 .34629 L
.66592 .34625 L
.66601 .34615 L
.66611 .34603 L
.66629 .34573 L
.66648 .34531 L
.66668 .34472 L
.6671 .34319 L
.6675 .34131 L
.66824 .33679 L
.66992 .32314 L
.67153 .30817 L
.67299 .29579 L
.67375 .2905 L
.67457 .28604 L
.67503 .2842 L
.67522 .28354 L
.67544 .28293 L
.67563 .28248 L
.67584 .2821 L
.67595 .28193 L
.67606 .2818 L
.67616 .2817 L
Mistroke
.67626 .28162 L
.67635 .28158 L
.67644 .28155 L
.67655 .28154 L
.67664 .28156 L
.67674 .28159 L
.67684 .28166 L
.67695 .28175 L
.67706 .28187 L
.67724 .28213 L
.67741 .28244 L
.67779 .28336 L
.6782 .28469 L
.67865 .28648 L
.67946 .29055 L
.68275 .3123 L
.68354 .31721 L
.68439 .32175 L
.68519 .32511 L
.68554 .32627 L
.68592 .32728 L
.6861 .32768 L
.6863 .32806 L
.68649 .32834 L
.68666 .32854 L
.68676 .32863 L
.68687 .32871 L
.68697 .32877 L
.68703 .32879 L
.68708 .32881 L
.68718 .32883 L
.68727 .32883 L
.68738 .32881 L
.68748 .32878 L
.68756 .32874 L
.68766 .32868 L
.68785 .32851 L
.68802 .32831 L
.68819 .32806 L
.68856 .32737 L
.68896 .32639 L
.68977 .32375 L
.69066 .32007 L
.69227 .31219 L
.69398 .30396 L
.69479 .30071 L
.69553 .29827 L
.69591 .29729 L
.69631 .29641 L
.69672 .29574 L
Mistroke
.69694 .29546 L
.69715 .29526 L
.69725 .29519 L
.69735 .29512 L
.69745 .29507 L
.69754 .29504 L
.69762 .29502 L
.69771 .295 L
.6978 .295 L
.69789 .295 L
.69799 .29502 L
.69809 .29505 L
.69817 .29509 L
.69827 .29514 L
.69848 .29529 L
.69868 .29549 L
.69908 .29602 L
.69952 .2968 L
.70032 .29868 L
.70181 .30339 L
.70338 .30898 L
.70421 .31178 L
.7051 .31443 L
.70595 .31646 L
.70636 .31721 L
.70673 .31778 L
.70711 .31822 L
.70731 .3184 L
.70752 .31855 L
.70762 .31861 L
.70772 .31866 L
.70781 .31869 L
.70791 .31872 L
.708 .31874 L
.70809 .31875 L
.70818 .31876 L
.70826 .31876 L
.70836 .31874 L
.70842 .31873 L
.70847 .31872 L
.70857 .31869 L
.70867 .31865 L
.70888 .31854 L
.7091 .31838 L
.70952 .31798 L
.7099 .31749 L
.71066 .31622 L
.71139 .31472 L
.71446 .30727 L
.71527 .30556 L
Mistroke
.71603 .30423 L
.71646 .30363 L
.71692 .30311 L
.71712 .30292 L
.71733 .30276 L
.71752 .30263 L
.71772 .30253 L
.71782 .30248 L
.71792 .30245 L
.71801 .30242 L
.71812 .3024 L
.71821 .30238 L
.71829 .30237 L
.71838 .30236 L
.71848 .30237 L
.71858 .30237 L
.71863 .30238 L
.71868 .30239 L
.71879 .30241 L
.7189 .30244 L
.71911 .30251 L
.71929 .3026 L
.71966 .30283 L
.72005 .30316 L
.72076 .30396 L
.72236 .30637 L
.72405 .30926 L
.72486 .31056 L
.72564 .31162 L
.72633 .3124 L
.72673 .31275 L
.72709 .31302 L
.72748 .31324 L
.72769 .31333 L
.7279 .3134 L
.72799 .31342 L
.72808 .31344 L
.72817 .31346 L
.72826 .31347 L
.72835 .31348 L
.72844 .31348 L
.7285 .31349 L
.72855 .31349 L
.72865 .31348 L
.72874 .31347 L
.7288 .31347 L
.72885 .31346 L
.72895 .31345 L
.72907 .31342 L
.72927 .31337 L
Mistroke
.72945 .3133 L
.72988 .3131 L
.73032 .31282 L
.73109 .31218 L
.73191 .31135 L
.73339 .30966 L
.73499 .3079 L
.73583 .30714 L
.73629 .30681 L
.73672 .30654 L
.7371 .30636 L
.73752 .30621 L
.73775 .30615 L
.73787 .30612 L
.73797 .3061 L
.73807 .30609 L
.73817 .30608 L
.73828 .30607 L
.73834 .30607 L
.73839 .30606 L
.73848 .30606 L
.73858 .30606 L
.73868 .30607 L
.73878 .30608 L
.73887 .30609 L
.73895 .3061 L
.73913 .30613 L
.73933 .30617 L
.73954 .30623 L
.73993 .30636 L
.74069 .30673 L
.74153 .30726 L
.74321 .30853 L
.7449 .30977 L
.7457 .31024 L
.74645 .31058 L
.74682 .31071 L
.74721 .31081 L
.74744 .31086 L
.74765 .31089 L
.74784 .31092 L
.74794 .31093 L
.74804 .31093 L
.74813 .31094 L
.74823 .31094 L
.74831 .31094 L
.7484 .31094 L
.74849 .31094 L
.74859 .31093 L
.74869 .31093 L
Mistroke
.74878 .31092 L
.74896 .3109 L
.74916 .31087 L
.74956 .31079 L
.74995 .31069 L
.75037 .31055 L
.75111 .31025 L
.75279 .30943 L
.75439 .30865 L
.75509 .30836 L
.75585 .3081 L
.75627 .30799 L
.75666 .30791 L
.75703 .30785 L
.75722 .30783 L
.75742 .30781 L
.75753 .3078 L
.75764 .30779 L
.75774 .30779 L
.75784 .30779 L
.7579 .30778 L
.75795 .30778 L
.75802 .30778 L
.75807 .30778 L
.75818 .30779 L
.75824 .30779 L
.75829 .30779 L
.75839 .30779 L
.75848 .3078 L
.75869 .30781 L
.75889 .30783 L
.7591 .30786 L
.75953 .30793 L
.75992 .30801 L
.76081 .30823 L
.76243 .30875 L
.76406 .30926 L
.76485 .30947 L
.76558 .30962 L
.76595 .30968 L
.7663 .30972 L
.76665 .30976 L
.76684 .30977 L
.76705 .30978 L
.76715 .30979 L
.76725 .30979 L
.76736 .3098 L
.76741 .3098 L
.76747 .3098 L
.76757 .3098 L
Mistroke
.76763 .3098 L
.76768 .3098 L
.76778 .3098 L
.76787 .30979 L
.76796 .30979 L
.76806 .30979 L
.76823 .30978 L
.76841 .30977 L
.76862 .30975 L
.76901 .30971 L
.76943 .30966 L
.77017 .30955 L
.77184 .30921 L
.77344 .30889 L
.77414 .30877 L
.7749 .30866 L
.77532 .30861 L
.77571 .30858 L
.77608 .30856 L
.77627 .30855 L
.77647 .30854 L
.77659 .30854 L
.77669 .30853 L
.77679 .30853 L
.77689 .30853 L
.77695 .30853 L
.777 .30853 L
.77707 .30853 L
.77712 .30853 L
.77723 .30853 L
.77729 .30853 L
.77734 .30853 L
.77744 .30853 L
.77753 .30854 L
.77774 .30854 L
.77794 .30855 L
.77815 .30856 L
.77858 .30859 L
.77897 .30862 L
.77986 .30872 L
.78148 .30892 L
.7831 .30913 L
.7839 .30921 L
.78425 .30923 L
.78463 .30926 L
.78497 .30928 L
.78534 .3093 L
.78554 .3093 L
.78573 .30931 L
.78582 .30931 L
Mistroke
.78591 .30931 L
.786 .30931 L
.78609 .30932 L
.78619 .30932 L
.78628 .30932 L
.78634 .30932 L
.78639 .30932 L
.78649 .30932 L
.78659 .30932 L
.78669 .30932 L
.7868 .30931 L
.78691 .30931 L
.78711 .30931 L
.7873 .3093 L
.78766 .30929 L
.78804 .30927 L
.78845 .30925 L
.78928 .30919 L
.79076 .30908 L
.79164 .309 L
.79247 .30894 L
.79327 .3089 L
.79362 .30888 L
.79401 .30886 L
.79439 .30885 L
.79474 .30884 L
.79494 .30884 L
.79511 .30884 L
.79521 .30884 L
.79532 .30884 L
.79542 .30884 L
.79551 .30883 L
.79562 .30883 L
.79567 .30883 L
.79573 .30883 L
.79582 .30884 L
.79593 .30884 L
.79602 .30884 L
.79611 .30884 L
.7963 .30884 L
.79652 .30884 L
.79671 .30885 L
.79714 .30886 L
.79794 .30889 L
.79867 .30892 L
.80034 .309 L
.80112 .30904 L
.80197 .30907 L
.80235 .30909 L
.80276 .3091 L
Mistroke
.80314 .30911 L
.80349 .30912 L
.80385 .30912 L
.80405 .30912 L
.80415 .30912 L
.80424 .30912 L
.80432 .30913 L
.80442 .30913 L
.8045 .30913 L
.80458 .30913 L
.80467 .30913 L
.80475 .30913 L
.80485 .30913 L
.80494 .30913 L
.80504 .30913 L
.80513 .30913 L
.80523 .30913 L
.80533 .30912 L
.8057 .30912 L
.8059 .30912 L
.80609 .30912 L
.80652 .30911 L
.80804 .30907 L
.8097 .30902 L
.8105 .309 L
.81126 .30898 L
.81169 .30897 L
.81214 .30896 L
.81256 .30896 L
.81276 .30896 L
.81294 .30895 L
.81313 .30895 L
.81332 .30895 L
.81342 .30895 L
.81351 .30895 L
.81361 .30895 L
.81367 .30895 L
.81372 .30895 L
.81381 .30895 L
.8139 .30895 L
.81399 .30895 L
.81409 .30895 L
.81418 .30895 L
.81426 .30895 L
.81444 .30895 L
.81466 .30895 L
.81486 .30896 L
.81524 .30896 L
.8161 .30897 L
.81917 .30902 L
Mistroke
.81999 .30904 L
.82076 .30905 L
.82114 .30905 L
.82156 .30905 L
.82178 .30905 L
.82202 .30905 L
.82222 .30905 L
.82234 .30905 L
.82239 .30905 L
.82244 .30906 L
.82255 .30906 L
.8226 .30906 L
.82265 .30906 L
.82275 .30906 L
.82285 .30906 L
.8229 .30906 L
.82296 .30906 L
.82308 .30905 L
.82319 .30905 L
.82329 .30905 L
.82367 .30905 L
.82389 .30905 L
.82408 .30905 L
.82485 .30905 L
.82557 .30904 L
.82705 .30902 L
.82789 .30901 L
.82867 .30901 L
.82944 .309 L
.82988 .309 L
.83027 .309 L
.83047 .309 L
.83069 .309 L
.8308 .309 L
.83092 .309 L
.83104 .309 L
.83114 .309 L
.83124 .30899 L
.83134 .30899 L
.83145 .30899 L
.83151 .30899 L
.83156 .30899 L
.83166 .30899 L
.83176 .30899 L
.83186 .30899 L
.83196 .309 L
.83215 .309 L
.83233 .309 L
.83274 .309 L
.83314 .309 L
Mistroke
.83357 .309 L
.83505 .30901 L
.83664 .30902 L
.83747 .30902 L
.83793 .30902 L
.83836 .30903 L
.83878 .30903 L
.839 .30903 L
.83923 .30903 L
.83943 .30903 L
.83964 .30903 L
.83974 .30903 L
.83984 .30903 L
.83994 .30903 L
.84002 .30903 L
.84012 .30903 L
.84022 .30903 L
.8403 .30903 L
.8404 .30903 L
.8405 .30903 L
.84056 .30903 L
.84061 .30903 L
.84081 .30903 L
.84099 .30903 L
.84119 .30903 L
.84156 .30903 L
.84238 .30903 L
.84314 .30902 L
.84482 .30902 L
.84557 .30902 L
.84636 .30901 L
.84678 .30901 L
.84723 .30901 L
.84765 .30901 L
.84803 .30901 L
.84824 .30901 L
.84843 .30901 L
.84853 .30901 L
.84865 .30901 L
.8487 .30901 L
.84876 .30901 L
.84882 .30901 L
.84887 .30901 L
.84897 .30901 L
.84906 .30901 L
.84915 .30901 L
.84926 .30901 L
.84937 .30901 L
.84947 .30901 L
.84967 .30901 L
Mistroke
.85004 .30901 L
.85038 .30901 L
.85115 .30901 L
.85279 .30902 L
.85432 .30902 L
.85507 .30902 L
.85578 .30902 L
.85617 .30902 L
.85638 .30902 L
.8566 .30902 L
.85681 .30902 L
.85699 .30902 L
.85708 .30902 L
.85718 .30902 L
.85727 .30902 L
.85736 .30902 L
.85746 .30902 L
.85755 .30902 L
.85764 .30902 L
.85773 .30902 L
.85784 .30902 L
.85794 .30902 L
.85814 .30902 L
.85832 .30902 L
.85849 .30902 L
.85887 .30902 L
.85967 .30902 L
.86053 .30902 L
.86211 .30902 L
.86294 .30902 L
.8634 .30902 L
.86383 .30902 L
.86425 .30902 L
.8647 .30901 L
.8649 .30901 L
.86511 .30901 L
.86529 .30901 L
.86548 .30901 L
.86558 .30901 L
.86568 .30901 L
.86577 .30901 L
.86586 .30901 L
.86597 .30901 L
.86602 .30901 L
.86608 .30901 L
.86618 .30901 L
.86627 .30901 L
.86637 .30901 L
.86646 .30901 L
.86663 .30901 L
Mistroke
.86702 .30901 L
.86742 .30902 L
.86778 .30902 L
.8686 .30902 L
.87007 .30902 L
.87088 .30902 L
.87174 .30902 L
.87247 .30902 L
.87289 .30902 L
.87328 .30902 L
.87347 .30902 L
.87367 .30902 L
.87377 .30902 L
.87387 .30902 L
.87396 .30902 L
.87405 .30902 L
.87414 .30902 L
.87424 .30902 L
.87433 .30902 L
.87442 .30902 L
.87451 .30902 L
.87458 .30902 L
.87467 .30902 L
.87476 .30902 L
.87497 .30902 L
.87519 .30902 L
.8756 .30902 L
.87599 .30902 L
.87636 .30902 L
.87798 .30902 L
.87951 .30902 L
.88022 .30902 L
.88097 .30902 L
.88136 .30902 L
.88157 .30902 L
.88179 .30902 L
.88199 .30902 L
.88218 .30902 L
.88227 .30902 L
.88237 .30902 L
.88246 .30902 L
.88254 .30902 L
.88264 .30902 L
.88274 .30902 L
.88282 .30902 L
.88292 .30902 L
.88302 .30902 L
.88313 .30902 L
.88332 .30902 L
.88352 .30902 L
Mistroke
.8837 .30902 L
.88405 .30902 L
.88484 .30902 L
.8857 .30902 L
.88728 .30902 L
.88811 .30902 L
.88857 .30902 L
.889 .30902 L
.88941 .30902 L
.88963 .30902 L
.88986 .30902 L
.89005 .30902 L
.89027 .30902 L
.89036 .30902 L
.89046 .30902 L
.89056 .30902 L
.89064 .30902 L
.89073 .30902 L
.89083 .30902 L
.89092 .30902 L
.891 .30902 L
.8911 .30902 L
.8912 .30902 L
.8913 .30902 L
.89139 .30902 L
.89157 .30902 L
.89177 .30902 L
.89217 .30902 L
.89259 .30902 L
.89299 .30902 L
.89374 .30902 L
.89542 .30902 L
.89619 .30902 L
.89701 .30902 L
.89735 .30902 L
.89771 .30902 L
.89792 .30902 L
.89811 .30902 L
.89831 .30902 L
.89849 .30902 L
.89859 .30902 L
.89869 .30902 L
.89878 .30902 L
.89887 .30902 L
.89896 .30902 L
.89907 .30902 L
.89912 .30902 L
.89917 .30902 L
.89928 .30902 L
.89937 .30902 L
Mistroke
.89947 .30902 L
.89966 .30902 L
.89984 .30902 L
.90001 .30902 L
.90043 .30902 L
.90081 .30902 L
.90167 .30902 L
.90334 .30902 L
.90408 .30902 L
.90489 .30902 L
.90526 .30902 L
.90566 .30902 L
.90604 .30902 L
.90621 .30902 L
.90639 .30902 L
.90649 .30902 L
.90659 .30902 L
.90669 .30902 L
.90678 .30902 L
.90689 .30902 L
.90694 .30902 L
.907 .30902 L
.9071 .30902 L
.90716 .30902 L
.90721 .30902 L
.90731 .30902 L
.9074 .30902 L
.90749 .30902 L
.90758 .30902 L
.90779 .30902 L
.90798 .30902 L
.90836 .30902 L
.90876 .30902 L
.90949 .30902 L
.91115 .30902 L
.91196 .30902 L
.91285 .30902 L
.91325 .30902 L
.91368 .30902 L
.91389 .30902 L
.91409 .30902 L
.91427 .30902 L
.91446 .30902 L
.91456 .30902 L
.91466 .30902 L
.91475 .30902 L
.91484 .30902 L
.91494 .30902 L
.91499 .30902 L
.91505 .30902 L
Mistroke
.91514 .30902 L
.91525 .30902 L
.9153 .30902 L
.91536 .30902 L
.91545 .30902 L
.91556 .30902 L
.91568 .30902 L
.91588 .30902 L
.91608 .30902 L
.91645 .30902 L
.9168 .30902 L
.91756 .30902 L
.91924 .30902 L
.91997 .30902 L
.92078 .30902 L
.92115 .30902 L
.92155 .30902 L
.92193 .30902 L
.92228 .30902 L
.92248 .30902 L
.92267 .30902 L
.92277 .30902 L
.92283 .30902 L
.92288 .30902 L
.92293 .30902 L
.92299 .30902 L
.9231 .30902 L
.92319 .30902 L
.92328 .30902 L
.92337 .30902 L
.92347 .30902 L
.92358 .30902 L
.92368 .30902 L
.92387 .30902 L
.92424 .30902 L
.92465 .30902 L
.92548 .30902 L
.92696 .30902 L
.92776 .30902 L
.92852 .30902 L
.92894 .30902 L
.92939 .30902 L
.92959 .30902 L
.92981 .30902 L
.92999 .30902 L
.93019 .30902 L
.9304 .30902 L
.93052 .30902 L
.93062 .30902 L
.93072 .30902 L
Mistroke
.93082 .30902 L
.93092 .30902 L
.93102 .30902 L
.93107 .30902 L
.93113 .30902 L
.93119 .30902 L
.93124 .30902 L
.93134 .30902 L
.93145 .30902 L
.93169 .30902 L
.93191 .30902 L
.93229 .30902 L
.9327 .30902 L
.93353 .30902 L
.93524 .30902 L
.93605 .30902 L
.93679 .30902 L
.93717 .30902 L
.93757 .30902 L
.93776 .30902 L
.93797 .30902 L
.93809 .30902 L
.9382 .30902 L
.9383 .30902 L
.93841 .30902 L
.9385 .30902 L
.9386 .30902 L
.9387 .30902 L
.93878 .30902 L
.93888 .30902 L
.93898 .30902 L
.93908 .30902 L
.93919 .30902 L
.93937 .30902 L
.93954 .30902 L
.93993 .30902 L
.94034 .30902 L
.94077 .30902 L
.94157 .30902 L
.94306 .30902 L
.94388 .30902 L
.94465 .30902 L
.94504 .30902 L
.94546 .30902 L
.94569 .30902 L
.94581 .30902 L
.94592 .30902 L
.94603 .30902 L
.94612 .30902 L
.94623 .30902 L
Mistroke
.94629 .30902 L
.94634 .30902 L
.94644 .30902 L
.94654 .30902 L
.94663 .30902 L
.94672 .30902 L
.94682 .30902 L
.94693 .30902 L
.94713 .30902 L
.94734 .30902 L
.94756 .30902 L
.94795 .30902 L
.94866 .30902 L
.94944 .30902 L
.95112 .30902 L
.95186 .30902 L
.95225 .30902 L
.95267 .30902 L
.95288 .30902 L
.95308 .30902 L
.95327 .30902 L
.95345 .30902 L
.95362 .30902 L
.9538 .30902 L
.95389 .30902 L
.95398 .30902 L
.95408 .30902 L
.95418 .30902 L
.95428 .30902 L
.95438 .30902 L
.95444 .30902 L
.95449 .30902 L
.95461 .30902 L
.95481 .30902 L
.95501 .30902 L
.95538 .30902 L
.95577 .30902 L
.95734 .30902 L
.95818 .30902 L
.95907 .30902 L
.95951 .30902 L
.95993 .30902 L
.96033 .30902 L
.96071 .30902 L
.96089 .30902 L
.96107 .30902 L
.96125 .30902 L
.96134 .30902 L
.96144 .30902 L
.96155 .30902 L
Mistroke
.9616 .30902 L
.96166 .30902 L
.96176 .30902 L
.96186 .30902 L
.96196 .30902 L
.96206 .30902 L
.96215 .30902 L
.96224 .30902 L
.96243 .30902 L
.96264 .30902 L
.963 .30902 L
.96344 .30902 L
.96384 .30902 L
.96553 .30902 L
.96627 .30902 L
.96706 .30902 L
.96747 .30902 L
.96793 .30902 L
.96813 .30902 L
.96834 .30902 L
.96854 .30902 L
.96873 .30902 L
.96892 .30902 L
.96903 .30902 L
.96913 .30902 L
.96922 .30902 L
.9693 .30902 L
.9694 .30902 L
.9695 .30902 L
.96959 .30902 L
.96965 .30902 L
.9697 .30902 L
.96989 .30902 L
.97 .30902 L
.97012 .30902 L
.97033 .30902 L
.97076 .30902 L
.97121 .30902 L
.97203 .30902 L
.97363 .30902 L
.97454 .30902 L
.97494 .30902 L
.97537 .30902 L
.97576 .30902 L
.97598 .30902 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{421.375, 260.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008>0001AB000`400?l00000o`00003ooooooooo
oooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo
003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooo
oooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool0
0?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooooooo
ool@ooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooo
ooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo0ol0003o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0
003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo
00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`
ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLoooo
o`00<?ooool3o`000?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?oo
ool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0
033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomco
oooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooo
oooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool3o`000?oooooo
g?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0013ooooo0_o^k^h3ooooo`;ok^k^6Oooool00ol0003oooooooooo`3o
ooooomcooooo000;ooooo`;o000000[o410@ooooooooooook^k^oeEEEOo^k^koooooonk^k_mEEEGo
k^k^0oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h:ooooo`03o`000?oo
oooooooo0?oooooog?ooool000cooooo00?o0000ooooooooool00_ooool01Oo^k^koEEEEomgMgOmE
EEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00[ooooo
00?o0000ooooooooool0oooooooLooooo`0000?oooooo`000?l000001?l00002ooooo`Go00001?oo
ool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooo
oa0@400:ooooo`03o`000?oooooooooo0?oooooog?ooool000Wooooo00CoA4A4omgMgOoooooo0000
1?ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000000[ooooo00?o0000ooooooooool0oooooooLooooo`002Oooool01?oMgMgo
EEEEooooool00003ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000:ooooo`Co0000oooooooKooooo`002_oo
ool00omgMgOoc<c<o`000003ooooo`;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@00[ooooo00?o0000ooooooooool0oooooooLooooo`002_oo
ool00oo^k^koA4A4o`00000?ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`;o00001Oooool00ol0003oooooooooo`3oooooomcooooo000;ooooo`03ogMgMol0
003ooooo00cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`3oooooomcooooo000Xooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool0oooooooLooooo`00:?ooool3o`0000Gooooo
00?o0000ooooooooool0]?ooool00ol0003oooooooooo`3oooooobGooooo000Yooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0]?ooool00ol0003oooooooooo`3oooooobGooooo000Z
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0/oooool2o`000?oooooo9oooool0
033ooooo00?o0000ooooooooool0/oooool2o`0000[ooooo0_l0003ooooooa_ooooo000`ooooo`03
o`000?oooooooooo0;?ooooo0_l0000:ooooo`;o0000oooooolKooooo`00<?ooool00ol0003ooooo
ooooo`2cooooo`;o00002_ooool2o`000?oooooo6oooool0033ooooo00?o0000ooooooooool0/ooo
ool2o`0000[ooooo0_l0003ooooooa_ooooo000`ooooo`?o0000/oooool00ol0003oooooo`000009
ooooo`;o0000oooooolKooooo`00<?ooool00ol0003oooooooooo`2cooooo`03o`000?oooooo0000
00Wooooo0_l0003ooooooa_ooooo000`ooooo`03o`000?oooooooooo0;?ooooo00?o0000ooooool0
00002Oooool2o`000?oooooo6oooool0033ooooo00?o0000ooooooooool0/oooool00ol0003ooooo
o`000009ooooo`;o0000oooooolKooooo`00<?ooool00ol0003oooooooooo`2cooooo`03o`000?oo
oooo000000Wooooo0_l0003ooooooa_ooooo000`ooooo`03o`000?oooooooooo0:Oooooo0_l0000:
ooooo`03o`000?oooooo000000Wooooo0_l0003ooooooa_ooooo000`ooooo`03o`000?oooooooooo
0:Oooooo0_l0000:ooooo`03o`000?oooooo000000Wooooo0_l0003ooooooa_ooooo000`ooooo`03
o`000?oooooooooo0:Oooooo0_l0000:ooooo`03o`000?oooooo000000Wooooo0_l0003ooooooa_o
oooo000`ooooo`03o`000?oooooooooo0:Oooooo0_l0000:ooooo`03o`000?oooooo000000Wooooo
0_l0003ooooooa_ooooo000`ooooo`03o`000?oooooooooo0:Oooooo0_l0000:ooooo`03o`000?oo
oooo000000Wooooo00?o0000ooooool00000oooooolJooooo`00<?ooool00ol0003oooooooooo`2W
ooooo`;o00002_ooool00ol0003oooooo`000009ooooo`03o`000?oooooo000000Sooooo0_l0003o
oooooa3ooooo000`ooooo`03o`000?oooooooooo0:Oooooo0_l0000:ooooo`03o`000?oooooo0000
00Wooooo00?o0000ooooool000002?ooool2o`000?oooooo4?ooool0033ooooo0ol0002Wooooo`;o
00002_ooool00ol0003oooooo`000009ooooo`03o`000?oooooo000000Sooooo0_l0003ooooooa3o
oooo000`ooooo`03o`000?oooooooooo0:Oooooo0_l0000:ooooo`03o`000?oooooo000000Sooooo
00Co0000oooooooooooo00002?ooool2o`000?oooooo4?ooool0033ooooo00?o0000ooooooooool0
Yoooool2o`0000[ooooo00?o0000ooooool000002?ooool01?l0003oooooooooool00008ooooo`;o
0000ooooool@ooooo`00<?ooool00ol0003oooooooooo`2Wooooo`03o`000?oooooo000000Wooooo
00?o0000ooooool000002?ooool01?l0003oooooooooool00008ooooo`;o0000ooooool@ooooo`00
<?ooool00ol0003oooooooooo`2Wooooo`03o`000?oooooo000000Wooooo00?o0000ooooool00000
2?ooool01?l0003oooooooooool00008ooooo`;o0000ooooool@ooooo`00<?ooool00ol0003ooooo
ooooo`2Vooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooool000002?ooool01?l0003o
ooooooooool00008ooooo`;o0000ooooool@ooooo`00<?ooool00ol0003oooooooooo`2Vooooo`04
o`000?ooooooooooo`0000Wooooo00?o0000ooooool000002?ooool01?l0003oooooooooool00008
ooooo`;o0000ooooool@ooooo`00<?ooool00ol0003oooooooooo`2Vooooo`04o`000?oooooooooo
o`0000Wooooo00?o0000ooooool000002?ooool01?l0003oooooooooool00008ooooo`;o0000oooo
ool@ooooo`00<?ooool00ol0003oooooooooo`2Vooooo`04o`000?ooooooooooo`0000Wooooo00?o
0000ooooool000002?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?oooooo
3oooool0033ooooo00?o0000ooooooooool0Y_ooool01?l0003oooooooooool00009ooooo`03o`00
0?oooooo000000Sooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003oooooo`oo
oooo000`ooooo`03o`000?oooooooooo0:Kooooo00Co0000oooooooooooo00002Oooool00ol0003o
ooooo`000008ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000ooooool?oooo
o`00<?ooool3o`000:Kooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00008
ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000ooooool?ooooo`00<?ooool0
0ol0003oooooooooo`2Vooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?oooooo3oooool0033ooooo
00?o0000ooooooooool0Y_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00
00Sooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003oooooo`oooooo000`oooo
o`03o`000?oooooooooo0:Kooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo0000ooooool?ooooo`00
<?ooool00ol0003oooooooooo`2Jooooo`;o00002_ooool01?l0003oooooooooool00008ooooo`04
o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool0
003oooooo`oooooo000`ooooo`03o`000?oooooooooo09[ooooo0_l0000:ooooo`04o`000?oooooo
ooooo`0000Sooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00007ooooo`04
o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool0ooooool4ooooo`00<?ooool00ol0003o
ooooooooo`2Jooooo`;o00002_ooool01?l0003oooooooooool00008ooooo`04o`000?oooooooooo
o`0000Sooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool00008ooooo`03o`00
0?oooooooooo0?oooooo1?ooool0013ooooo0_o^k^h3ooooo`;ok^k^6Oooool00ol0003ooooooooo
o`2Jooooo`;o00002_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000So
oooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool00008ooooo`;o0000ooooool5
ooooo`002Oooool5o`0000;ooooo00Ook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l0
00002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^2_ooool00ol0003oooooooooo`2Joooo
o`;o00002_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo00Co
0000oooooooooooo00001oooool01?l0003oooooooooool00008ooooo`;o0000ooooool5ooooo`00
2Oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06oooo
o`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0:ooooo`03o`000?oooooo
oooo09Wooooo00?o0000ooooool000002_ooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000Sooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool00008oooo
o`;o0000ooooool5ooooo`0000?oooooo`000?l000001?l00003ooooo`03oiRHV?lQ8B7ok^k^00Go
oooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooo
ool@41002_ooool00ol0003oooooooooo`2Iooooo`04o`000?ooooooooooo`0000Wooooo00Co0000
oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo
00001oooool01?l0003oooooooooool00008ooooo`;o0000ooooool5ooooo`002oooool00onHV9So
8B4Qonk^kP03ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000002_ooool00ol0003oooooooooo`2Iooooo`04o`000?oooooo
ooooo`0000Wooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Oo
oooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool00008ooooo`;o0000ooooool5
ooooo`003?ooool02omgMgOoIVIVooooooooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Go
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000[ooooo1?l0002Hoooo
o`04o`000?ooooooooooo`0000Wooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooo
oooooooo000000Oooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool00008oooo
o`;o0000ooooool5ooooo`003Oooool00ol0003oooooooooo`02onk^kP?ooooo0_o^k^h5ooooo`03
o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400:ooooo`03o`000?oooooooooo
09Wooooo00Co0000oooooooooooo00002Oooool01?l0003oooooooooool00008ooooo`05o`000?oo
ooooooooooooool000001oooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`00
00Oooooo00?o0000ooooool00000ooooool5ooooo`002Oooool01Ol0003o^[ZjoooooonHV9So410@
00kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo0_l00005
ooooo`03o`000?oooooooooo09Wooooo00Co0000oooooooooooo00002Oooool01Ol0003ooooooooo
oooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`00
00Oooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00003oooooo`Gooooo0009oooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`03?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo09Wooooo
00Co0000oooooooooooo00002Oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooo
ooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo0000
1oooool00ol0003oooooo`00003oooooo`Gooooo000Xooooo`04o`000?ooooooooooo`0000Cooooo
00?o0000ooooooooool0VOooool01?l0003oooooooooool00009ooooo`05o`000?oooooooooooooo
ool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo00001ooo
ool01?l0003oooooooooool00007ooooo`03o`000?oooooo00000?oooooo1Oooool002Sooooo0ol0
0005ooooo`03o`000?oooooooooo09Wooooo00Co0000oooooooooooo00002Oooool01Ol0003ooooo
oooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?oooooooooo
o`0000Oooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00003oooooo`Gooooo000Y
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0VOooool01?l0003oooooooooool0
0009ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oo
oooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool00007ooooo`03o`000?oooooo
00000?oooooo1Oooool002[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2Ioooo
o`04o`000?ooooooooooo`0000Wooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oo
ooooooooooooool000001oooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`00
00Oooooo00?o0000ooooool00000ooooool5ooooo`00<?ooool00ol0003oooooooooo`2Iooooo`04
o`000?ooooooooooo`0000Wooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooo
ooooooooool000001oooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Oo
oooo00?o0000ooooool00000ooooool5ooooo`00<?ooool00ol0003oooooooooo`2Iooooo`04o`00
0?ooooooooooo`0000Wooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooooooo
ooooool000001oooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Oooooo
00?o0000ooooool00000ooooool5ooooo`00<?ooool00ol0003oooooooooo`2Iooooo`04o`000?oo
ooooooooo`0000Wooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooooooooooo
ool000001oooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Oooooo00?o
0000ooooool00000ooooool5ooooo`00<?ooool00ol0003oooooooooo`2Iooooo`04o`000?oooooo
ooooo`0000Wooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool0
00001oooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000
ooooool000002Oooool00ol0003oooooooooo`3hooooo`00<?ooool3o`0009Wooooo00Co0000oooo
oooooooo00002Oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooooooooooooooo
o`000007ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00001oooool00ol0
003oooooo`000008ooooo`;o0000n_ooool0033ooooo00?o0000ooooooooool0VOooool01?l0003o
ooooooooool00009ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00001oooool01?l0003ooooooooo
ool00007ooooo`03o`000?oooooo000000Sooooo0_l0003jooooo`00<?ooool00ol0003ooooooooo
o`2Iooooo`04o`000?ooooooooooo`0000Wooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00007oooo
o`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool000002?ooool2o`000?[ooooo000`oooo
o`03o`000?oooooooooo09Wooooo00Co0000oooooooooooo00002Oooool01Ol0003ooooooooooooo
oooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`04o`000?oo
ooooooooo`0000Oooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`000008ooooo`;o
0000n_ooool0033ooooo00?o0000ooooooooool0S?ooool2o`0000_ooooo00Co0000oooooooooooo
00002Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00001ooo
ool01?l0003oooooooooool00007ooooo`;o0000n_ooool0033ooooo00?o0000ooooooooool0S?oo
ool2o`0000[ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo
00Co0000oooooooooooo00001oooool01?l0003oooooooooool00007ooooo`04o`000?oooooooooo
o`0000Oooooo0_l0003jooooo`00<?ooool00ol0003oooooooooo`2<ooooo`;o00002_ooool01Ol0
003ooooooooooooooooo000000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0
0007ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00001oooool2o`000?[o
oooo000`ooooo`03o`000?oooooooooo08cooooo0_l0000:ooooo`05o`000?ooooooooooooooool0
00002?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooo
oooooooo00001oooool01?l0003oooooooooool00006ooooo`03o`000?oooooo00000?[ooooo000`
ooooo`03o`000?oooooooooo08_ooooo00Co0000oooooooooooo00002Oooool01Ol0003ooooooooo
oooooooo000000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00007ooooo`04
o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00001_ooool01?l0003oooooooooool0
003iooooo`00<?ooool00ol0003oooooooooo`2;ooooo`04o`000?ooooooooooo`0000Wooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000Oooooo
00Co0000oooooooooooo00001_ooool01?l0003oooooooooool0003iooooo`00<?ooool00ol0003o
ooooooooo`2;ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`04ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00001_oo
ool01?l0003oooooooooool0003iooooo`00<?ooool00ol0003oooooooooo`2;ooooo`04o`000?oo
ooooooooo`0000Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`04o`00
0?ooooooooooo`0000Oooooo00Co0000oooooooooooo00001_ooool01?l0003oooooooooool0003i
ooooo`00<?ooool3o`0008_ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00001oooool01?l0003ooooooooo
ool00006ooooo`04o`000?ooooooooooo`000?Wooooo000`ooooo`03o`000?oooooooooo08_ooooo
00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Kooooo00Co0000
oooooooooooo0000nOooool0033ooooo00?o0000ooooooooool0Roooool01Ol0003ooooooooooooo
oooo000000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oo
ooooooooooooool000001_ooool01?l0003oooooooooool00006ooooo`04o`000?ooooooooooo`00
00Oooooo0_l0003`ooooo`00<?ooool00ol0003oooooooooo`2:ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Kooooo00Co0000
oooooooooooo00001oooool2o`000?3ooooo000`ooooo`03o`000?oooooooooo08[ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo0000
1_ooool01?l0003oooooooooool00007ooooo`;o0000l?ooool0033ooooo00?o0000ooooooooool0
C_ooool2onk^kP?ooooo0_o^k^heooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0_ooool01?l0003oooooonk^k_o^k^h3ooooo`03o`000?o^k^kooooo00;ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooo
ooooooooo`000005ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool0
0007ooooo`;o0000:?ooool2onk^kP?ooooo0_o^k^i>ooooo`;ok^k^0oooool2onk^kVcooooo000`
ooooo`03o`000?oooooooooo04Sooooo00goA4A4o`000?l0003o<S8bomgMgOooooook^k^oeEEEOo^
k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;o
k^k^9_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`05ooooo`Ko000000Soooooonk^k_mEEEGok^k^ooooooo^k^ko
0000onk^kP?ooooo1?l000002Ol@413oooooooooool0003o<S8bo`000?lb<S;ok^k^o`000006oooo
o`05o`000?ooooooooooooooool000001Oooool01Ol0003ooooooooooooooooo000000Kooooo00Co
0000oooooooooooo00001_ooool00ol0003oooooo`00000Booooo`Co000000?o410@ooooooooool0
0_ooool2ob4Q8@Gooooo00goA4A4o`000?l0003o<S8bomgMgOooooook^k^oeEEEOo^k^koooooonk^
k_mEEEGok^k^00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^>?ooool5
o`0000;ooooo00Ook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^GOooool0033ooooo00?o0000ooooooooool0Boooool02Omg
MgOo<S8booooooooooook^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0Vooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00Ko0000oooooooo
oooo0000ooooool00002ooooo`05onk^k_mEEEGogMgMoeEEEOl000001?ooool00ol0003oooooo`00
0004ooooo`06o`000?nHV9SooooooiRHV?mgMgOo00001_ooool01Ol0003ooooooooooooooooo0000
00Gooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Kooooo00?o
0000ooooool000005?ooool00ol0003oooooooooo`04ooooo`;o8B4Q2?ooool02OmgMgOo<S8boooo
ooooooook^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0hooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01Oo^k^koEEEEomgM
gOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg05go
oooo000`ooooo`03o`000?oooooooooo04cooooo00Oo0000ooooooooooooooooomgMgOl0003ogMgM
00Oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02Kooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01Oooool01_l0003oooooooooool0003oooooo`0000?ooooo00CogMgMo`000?oMgMgo
00001?ooool00ol0003oooooo`000004ooooo`06o`000?ooooooooooooooool@413o00001_ooool0
1Ol0003ooooooooooooooooo000000Gooooo00Go0000ooooooooooooooooo`000006ooooo`04o`00
0?ooooooooooo`0000Kooooo00?o0000ooooool000005?ooool00ol0003oooooooooo`0?ooooo`07
o`000?oooooooooooooooooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@400iooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?ogMgMo`000?oMgMd01ooo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100GOooool0033ooooo00?o
0000ooooooooool0Boooool02OmgMgOo<S8booooooooooook^k^oeEEEOoMgMgoEEEEonk^kP06oooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Vooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Gooooo00Ko0000oooooooooooo0000ooooool00002ooooo`05onk^k_mEEEGogMgMoeEEEOl0
00001?ooool00ol0003oooooo`000004ooooo`04o`000?ooooooooooooooo`;o00001_ooool01Ol0
003ooooooooooooooooo000000Gooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?oo
ooooooooo`0000Kooooo00?o0000ooooool000005?ooool00ol0003oooooooooo`0>ooooo`09ogMg
Molb<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000003[ooooo00?oV9RHob4Q8Oo^k^h00oooool01Oo^k^koEEEEomgM
gOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000005go
oooo000`ooooo`03o`000?oooooooooo04Sooooo00go0000ob4Q8Ol0003o<S8bolc<c?ooooook^k^
oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000001Wooooo0_l0000;ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00ko0000oooooooo
oooo0000ooooool0003oooooonk^k_mEEEGok^k^ooooooo^k^ko0000onk^kP?ooooo00?o0000oooo
ool000001?ooool01?l0003oooooooooooooool2o`0000Kooooo00Go0000ooooooooooooooooo`00
0005ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool00006ooooo`03
o`000?oooooo000001Cooooo00?o0000ooooooooool02oooool03Ol0003o8B4Qo`000?lb<S;oc<c<
ooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool00000>oooool02omgMgOoIVIVooooooooooook^k^oeEEEOo^k^kooooo
onk^k_mEEEGok^k^00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
05gooooo000`ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool00oooool2onk^kP?o
oooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Ioooo
o`?o00002_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`05ooooo`07o`000?ooooooooooo`000?oooooo0000oooo
o`02onk^kP?ooooo00?o0000onk^k_ooool00_ooool00ol0003oooooo`000004ooooo`06o`000?oo
ooooooooooooool@413o00001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`00
00Kooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool00oooool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo
00;ooooo00Go410@oooooooooooooooooa0@400looooo`03o`000?oooooooooo00;ok^k^0oooool2
onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@05gooooo000`
ooooo`?o0000B?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo00gooooo00Co0000oooooooooooo0000
2_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`05ooooo`06o`000?ooooooooooo`000?oooooo00001_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooo000000Cooooo00Ko0000oiRHV?ooooooV9RHogMgMol0
0005ooooo`06o`000?oooooo0000o`000?oooooo00001Oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000005ooooo`04o`000?oooooooooo
o`0000Kooooo0_l0000;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool2o`0002kooooo00Go
0000okZj^_ooooooV9RHoa0@400>ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`08ooooo`;o0000Doooool0033ooooo00?o0000ooooooooool0B?ooool4o`0000cooooo
00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000oooooooo
ool03Oooool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00Ko0000oeEE
EOmVIVKo0000ooooool00006ooooo`03o`000?oooooooooo00;ooooo00?o0000ofIVI_l000001?oo
ool01_l0003o<S8bo`000?lb<S;ok^k^o`0000Gooooo0_l00002ooooo`;o00001Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooool000002?ooool00omE
EEGoIVIVo`00000=ooooo`Co00003?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01oooool01?l0003oooooooooool0000]ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
3?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01oooool01?l0003o
ooooooooool0001Booooo`00<?ooool00ol0003oooooooooo`1Vooooo`Co00000oooool00ol0003o
ooooooooo`0<ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000001Ol00002oooo
o`;o00001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000
ooooool00000=_ooool4o`000005ooooool0003oooooooooool00000C?ooool4o`000005ooooool0
003oooooooooool00000D_ooool0033ooooo00?o0000ooooooooool0KOooool00ol0003ooooooooo
o`0;ooooo`05o`000?ooooooooooooooool000002_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`Co0000
00?oooooo`000?ooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Ko
oooo00?o0000ooooool00000>oooool3o`0005;ooooo0ol0001Cooooo`00<?ooool00ol0003ooooo
ooooo`1[ooooo`04o`000?ooooooooooo`0000cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000000_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00001_ooool00ol0
003oooooo`00000looooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0D_ooool0033o
oooo00?o0000ooooooooool0Joooool4o`0000cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Ko0000oooooooooooo0000ooooool00005
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00001Oooool01?l0003ooooooooo
ool00007ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0D_ooool00ol0003ooooo
ooooo`1Aooooo`00<?ooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Gooooo
00Go0000ooooooooooooooooo`000005ooooo`?o0000gOooool0033ooooo00?o0000ooooooooool0
KOooool2o`0000cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00Co0000oooooooooooo00001Oooool01Ol0003ooooooooooooooooo0000
00Gooooo00?o0000ooooool00000Xoooool00omgMgOoIVIVooooo`0]ooooo`03ofIVI_mgMgOooooo
00Oooooo000`ooooo`03o`000?oooooooooo06_ooooo1Ol0000:ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000oooo
ool000001oooool00ol0003oooooooooo`2Hooooo`03omgMgOl@413ok^k^02kooooo00?ok^k^oa0@
4?oMgMd01oooool0033ooooo00?o0000ooooooooool0Joooool01Ol0003ooooooooooooooooo0000
00[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool000001?ooool01Ol0003ooooooooooooooooo000000Gooooo0ol00027ooooo`;o00000_oo
ool2o`0000cooooo00?oEEEEoiRHV?ooool00_l00002ooooo`07o`000?ooooooooooo`000?l@413o
k^k^oeEEE@02o`000003odA4A?nj^[[ooooo00;ooooo00GoV9RHo`000?l0003oA4A4okZj^P02oooo
o`08onk^k_mEEEGo0000o`000?m4A4Co^[Zjooooool@4105o`0000?ooooo00So410@oc8b<_l0003o
0000oa0@4?nYZJWoQhN7ofIVIPOooooo000`ooooo`03o`000?oooooooooo05_ooooo0_l0000=oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oooooo
ooooooooool000001Oooool01?l0003oooooooooool00005ooooo`?o0000O_ooool01_o^k^ko8B4Q
ohN7Qonj^[[o0000omgMg@cooooo00Go0000ooooooooooooooooo`000002ooooo`0;o`000?oooooo
ooooo`000?ooooooEEEEogMgMoooooook^k^ogMgMol@41000oooool01Ol@413o^[Zjonk^k_mgMgOo
410@00;ooooo00KoEEEEogMgMoooooook^k^ogMgMol@4103ooooo`03o`000?oooooooooo00Cooooo
00So0000ojVYZOoooooooooookZj^_l0003ok^k^o`0000Oooooo003oo`000;Co00003oooool01?oM
gMgo0000oa0@4?o<c<`=ooooo`05oc8b<_ooooooooooooooool000000_ooool01_l0003ooooooooo
ool0003oooooo`0000Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Gooooo00Oo^[ZjohN7QomVIVKoIVIVoa0@4?oooooo000000Oooooo000:oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo00Gooooo1?l00007ooooo`03o`000?oooooooooo00;ooooo0ol00004oooo
o`;o00001Oooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooo`;o0000
1Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool00000
0_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001?ooool01?l0003o
ooooooooooooool2o`0000?ooooo00?o0000ooooooooool00_l00004ooooo`Co00000_ooool00ol0
003oooooo`000003o`0000gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Goooo
o`04onk^k_lQ8B7o410@onk^kPgooooo00Go<S8booooooooooooooooo`000002ooooo`05o`000?oo
ooooooooo`000?ooool01_l00003ooooo`03o`000?oooooooooo00Cooooo1_l00003ooooo`03o`00
0?oooooooooo00Cooooo00So<S8bob4Q8OmgMgOoMgMgohN7Qoo^k^koooooo`0000Oooooo000:oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool01?ooool5o`0000Oooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000Cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooooooo`;o00001Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000000_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000001?ooool01_l0003oooooooooool0003ooooo
o`0000Cooooo0ol0000;ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0Gooooo`04ob4Q8OmgMgOoMgMgoc8b<Pgooooo00Go0000onk^k_oooooooooo
o`000002olc<c00;o`000?nYZJWogMgMob4Q8OooooooEEEEohN7Qoo^k^koooooohN7Qolb<S800ooo
ool00ol0003oooooooooo`04ooooo`06oeEEEOn7QhOok^k^oooooon7QhOo<S8b0oooool00ol0003o
<S8bomgMg@04ooooo`08o`000?nj^[[oooooonk^k_mgMgOo0000onk^k_l00007ooooo`00<?ooool0
0ol0003oooooooooo`1Kooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooo`000003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000000Cooooo00Co0000oooooooooooo00005?ooool00ol0003ooooo
ooooo`1Kooooo`03o`000?oooooooooo01Kooooo0_l00002ooooo`;o00003?ooool03_mEEEGoMgMg
ooooool@413o0000ob4Q8Ol0003oMgMgoa0@4?l0003oZJVYooooooo^k^koEEEE0_l000001?m4A4Co
k^k^ooooool@4105o`0000?ooooo00Kok^k^oeEEEOl0003o0000odA4A?o^k^h2ooooo`;o000000Co
ZJVYob4Q8Ol0003o8B4Q0_ooool02?nYZJWo8B4Qo`000?l0003o<S8bo`000?mgMgOoEEEE1oooool0
033ooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`000005ooooo`04o`000?ooooooooooo`0000Kooooo0_l0
002Nooooo`03omgMgOl@413ok^k^01;ooooo00?o0000ooooooooool06Oooool00oo^k^ko410@omgM
g@07ooooo`00<?ooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Kooooo
0_l0002Oooooo`03ogMgMomVIVKooooo017ooooo00?o0000ooooooooool06Oooool00omVIVKoMgMg
ooooo`07ooooo`00<?ooool00ol0003oooooooooo`1dooooo`04o`000?ooooooooooo`0000[ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
00Co0000oooooooooooo00001Oooool01?l0003oooooooooool0003Qooooo`00<?ooool00ol0003o
ooooooooo`1dooooo`;o000000?oooooo`000?ooool02Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00006oooo
o`03o`000?oooooo00000>7ooooo000`ooooo`03o`000?oooooooooo07Gooooo0ol0000:ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo0000
00Cooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Kooooo0_l0
003Rooooo`00<?ooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool01Ol0003ooooooooooooooooo000000Gooooo00Co0000oooooooooooo0000
1_ooool01?l0003oooooooooool00006ooooo`;o0000h_ooool0033ooooo00?o0000ooooooooool0
Poooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooo
ooooo`000005ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooool00000joooool0033o
oooo00?o0000ooooooooool0Poooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00Go0000ooooooooooooooooo`000005ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000
ooooool00000joooool0033ooooo0ol00023ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool01Ol0003ooooooooooooooooo000000Gooooo00Co0000oooooooooooo00001_oo
ool00ol0003oooooo`00003[ooooo`00<?ooool00ol0003oooooooooo`23ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Gooooo00Co
0000oooooooooooo00001_ooool00ol0003oooooo`00003[ooooo`00<?ooool00ol0003ooooooooo
o`23ooooo`05o`000?ooooooooooooooool000002Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Go
oooo00Co0000oooooooooooo00001_ooool00ol0003oooooo`00003[ooooo`00<?ooool00ol0003o
ooooooooo`23ooooo`05o`000?ooooooooooooooool000002Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo
000000Gooooo00Co0000oooooooooooo00001_ooool3o`000>_ooooo000`ooooo`03o`000?oooooo
oooo08?ooooo00Go0000ooooooooooooooooo`000009ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000
1Oooool01?l0003oooooooooool00007ooooo`;o0000joooool0033ooooo00?o0000ooooooooool0
Poooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000005oooo
o`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool0j_ooool0033ooooo00?o0000oooo
ooooool0Q?ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00Go0000
ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Kooooo00Co0000oooooooooooo
0000m?ooool0033ooooo00?o0000ooooooooool0Q?ooool01?l0003oooooooooool00009ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo0000
00Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Kooooo00Co
0000oooooooooooo0000m?ooool0033ooooo00?o0000ooooooooool0QOooool2o`0000[ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool00000
1oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo00001_ooool01?l0
003oooooooooool0003dooooo`00<?ooool00ol0003oooooooooo`25ooooo`;o00002_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00Go0000ooooooooooooooooo`000007
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool00006ooooo`04o`00
0?ooooooooooo`000?Cooooo000`ooooo`03o`000?oooooooooo08Gooooo0_l0000:ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo000000Oo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000
ooooool00000m?ooool0033ooooo00?o0000ooooooooool0TOooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Kooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooo
ooooooooool000001_ooool01?l0003oooooooooool00007ooooo`;o0000mOooool0033ooooo0ol0
002Aooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooo
oooooooo000000Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`00
00Oooooo0_l0003eooooo`00<?ooool00ol0003oooooooooo`2Aooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000oooo
ooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Oooooo0_l0003eooooo`00<?ooool0
0ol0003oooooooooo`2Booooo`05o`000?ooooooooooooooool000002?ooool01Ol0003ooooooooo
oooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`00
00Oooooo0_l0003eooooo`00<?ooool00ol0003oooooooooo`2Booooo`04o`000?ooooooooooo`00
00Wooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001_oo
ool01?l0003oooooooooool00007ooooo`;o0000mOooool0033ooooo00?o0000ooooooooool0T_oo
ool01?l0003oooooooooool00009ooooo`05o`000?ooooooooooooooool000001oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003o
oooooooooooooooo000000Kooooo00Co0000oooooooooooo00001oooool2o`000?Gooooo000`oooo
o`03o`000?oooooooooo09;ooooo00Co0000oooooooooooo00002Oooool01Ol0003ooooooooooooo
oooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`000?ko
oooo000`ooooo`03o`000?oooooooooo09;ooooo00Co0000oooooooooooo00002Oooool01Ol0003o
oooooooooooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo
000000Kooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`000?kooooo
000`ooooo`03o`000?oooooooooo09;ooooo00Co0000oooooooooooo00002Oooool01Ol0003ooooo
oooooooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000
00Kooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`000?kooooo000`
ooooo`03o`000?oooooooooo09;ooooo00Co0000oooooooooooo00002Oooool01Ol0003ooooooooo
oooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Ko
oooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo00000?oooooo000`ooooo`03
o`000?oooooooooo09;ooooo00Co0000oooooooooooo00002Oooool01Ol0003ooooooooooooooooo
000000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooo00000?oooooo000`ooooo`03o`000?oo
oooooooo09;ooooo00Co0000oooooooooooo00002Oooool01Ol0003ooooooooooooooooo000000So
oooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooo00000?oooooo000`ooooo`03o`000?oooooooooo09;ooooo00Co0000
oooooooooooo00002Oooool01Ol0003ooooooooooooooooo000000Sooooo00Go0000oooooooooooo
ooooo`000006ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003o
oooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
00000?oooooo000`ooooo`?o0000T_ooool01?l0003oooooooooool00009ooooo`05o`000?oooooo
ooooooooool000002?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003o
oooooooooooooooo000000Kooooo00?o0000ooooool00000ooooool0033ooooo00?o0000oooooooo
ool0T_ooool01?l0003oooooooooool00009ooooo`05o`000?ooooooooooooooool000002?ooool0
1Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`04ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool00006ooooo`03
o`000?oooooo00000?oooooo000`ooooo`03o`000?oooooooooo09?ooooo00?o0000ooooool00000
2Oooool01Ol0003ooooooooooooooooo000000Sooooo00Go0000ooooooooooooooooo`000006oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo
000000Oooooo00Co0000oooooooooooo00001oooool2o`000?oooooo000`ooooo`03o`000?oooooo
oooo09?ooooo00?o0000ooooool000002Oooool01Ol0003ooooooooooooooooo000000Sooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo00001oooool2o`00
0?oooooo000`ooooo`03o`000?oooooooooo09?ooooo00?o0000ooooool000002Oooool01Ol0003o
oooooooooooooooo000000Sooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Oooooo00Co
0000oooooooooooo00001oooool2o`000?oooooo000`ooooo`03o`000?oooooooooo09?ooooo0_l0
000:ooooo`05o`000?ooooooooooooooool000002?ooool01Ol0003ooooooooooooooooo000000Oo
oooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001oooool0
1?l0003oooooooooool00007ooooo`;o0000ooooool000oooooo0_o^k^h3ooooo`;ok^k^6_ooool0
0ol0003oooooooooo`2Cooooo`;o00002_ooool01Ol0003ooooooooooooooooo000000Sooooo00Go
0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003o
oooooooooooooooo000000Oooooo00Co0000oooooooooooo00001oooool2o`000?oooooo0008oooo
o`Go00000_ooool01oo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?oo
ooooooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`03o`000?oooooooooo09?ooooo0_l0000:oooo
o`05o`000?ooooooooooooooool000002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go
0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001oooool01?l0003o
ooooooooool00007ooooo`;o0000ooooool000Sooooo00GoV9RHob4Q8Oo^k^koooooodA4A003oooo
o`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool00ol0003oooooooooo`2Dooooo`03o`000?oooooooooo00Sooooo00Go
0000ooooooooooooooooo`000008ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003o
oooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?oooooo
ooooo`0000Oooooo0_l0003oooooo`002Oooool00onHV9So8B4Qonk^kP05ooooo`03omgMgOl0003o
gMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00_ooooo00?o
0000ooooooooool0Woooool01Ol0003ooooooooooooooooo000000Sooooo00Go0000oooooooooooo
ooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo
000000Oooooo00?o0000ooooool000002?ooool2o`000?oooooo000:ooooo`03oiRHV?lQ8B7ok^k^
00?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`00000;ooooo`03o`000?oooooooooo09oooooo00Go0000oooooooooooooooo
o`000008ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo0000
00Kooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo00000?oooooo2_ooool0
00_ooooo00_oMgMgofIVI_ooooooooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03
o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000;ooooo`Co0000W_ooool01Ol0
003ooooooooooooooooo000000Sooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oo
ooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooool0
0000ooooool:ooooo`003?ooool00ol0003oooooooooo`02onk^kP?ooooo0_o^k^h5ooooo`03o`00
0?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400;ooooo`03o`000?oooooooooo0:3o
oooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000
ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001oooool00ol0003ooooo
o`00003oooooo`[ooooo0008ooooo`05o`000?nj^[[ooooooiRHV?l@41003_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ol0003oooooooooo`2Pooooo`04
o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooo
ooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooool00000
ooooool:ooooo`002?ooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo00?oEEEEofIVI_l00000
1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo0_l00006ooooo`03o`000?oooooooooo0:3o
oooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000
ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001oooool00ol0003ooooo
o`00003oooooo`[ooooo000Wooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0
X?ooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool000001oooool01Ol0
003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oo
oooo00000?oooooo2_ooool002Oooooo00Co0000oooooooooooo00001Oooool00ol0003ooooooooo
o`2Pooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002?ooool01Ol0003o
oooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo
00000?oooooo2_ooool002Oooooo0ol00006ooooo`03o`000?oooooooooo0:3ooooo00Co0000oooo
oooooooo00002?ooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool00000
1_ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooool00000ooooool:ooooo`00
:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0:3ooooo00?o0000ooooool00000
2Oooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0
003ooooooooooooooooo000000Oooooo00?o0000ooooool00000ooooool:ooooo`00:Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo0:3ooooo00?o0000ooooool000002Oooool01?l0
003oooooooooool00008ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooo
oooooooo000000Oooooo00?o0000ooooool00000ooooool:ooooo`00<?ooool00ol0003ooooooooo
o`2Pooooo`03o`000?oooooo000000Wooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooo
oooooooooooo000000Oooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00003ooooo
o`[ooooo000`ooooo`03o`000?oooooooooo0:3ooooo00?o0000ooooool000002Oooool01?l0003o
ooooooooool00008ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool0
0007ooooo`03o`000?oooooo00000?oooooo2_ooool0033ooooo00?o0000ooooooooool0X?ooool0
0ol0003oooooo`000009ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool00007ooooo`03o`000?oooooo00000?oooooo2_ooool0033ooooo
0ol0002Pooooo`03o`000?oooooo000000Wooooo00Co0000oooooooooooo00002?ooool01?l0003o
ooooooooool00008ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool00000ooooool:
ooooo`00<?ooool00ol0003oooooooooo`2Pooooo`03o`000?oooooo000000Wooooo00Co0000oooo
oooooooo00002?ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Oooooo
00?o0000ooooool00000ooooool:ooooo`00<?ooool00ol0003oooooooooo`2Pooooo`03o`000?oo
oooo000000Wooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00008ooooo`03
o`000?oooooo000000Sooooo00?o0000ooooool00000ooooool:ooooo`00<?ooool00ol0003ooooo
ooooo`2Pooooo`03o`000?oooooo000000Wooooo00Co0000oooooooooooo00002?ooool01?l0003o
ooooooooool00008ooooo`03o`000?oooooo000000Wooooo00?o0000ooooooooool0ooooool9oooo
o`00<?ooool00ol0003oooooooooo`2Pooooo`03o`000?oooooo000000Wooooo00Co0000oooooooo
oooo00002?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo000000Wooooo00?o0000
ooooooooool0ooooool9ooooo`00<?ooool00ol0003oooooooooo`2Pooooo`03o`000?oooooo0000
00Wooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00008ooooo`03o`000?oo
oooo000000Wooooo00?o0000ooooooooool0ooooool9ooooo`00<?ooool00ol0003oooooooooo`2Q
ooooo`;o00002Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo
00?o0000ooooool00000oooooolEooooo`00<?ooool00ol0003oooooooooo`2Qooooo`;o00002Ooo
ool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool0
0000oooooolEooooo`00<?ooool00ol0003oooooooooo`2Qooooo`03o`000?oooooooooo00Sooooo
00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo0000
0?oooooo5Oooool0033ooooo00?o0000ooooooooool0XOooool00ol0003oooooooooo`08ooooo`04
o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003o
oooooaGooooo000`ooooo`03o`000?oooooooooo0:cooooo00Co0000oooooooooooo00002?ooool0
1?l0003oooooooooool00008ooooo`03o`000?oooooo00000?oooooo5Oooool0033ooooo00?o0000
ooooooooool0[?ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo
00?o0000ooooool00000oooooolEooooo`00<?ooool3o`000:gooooo00?o0000ooooool000002?oo
ool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?oooooo5Oooool0033ooooo00?o
0000ooooooooool0[Oooool00ol0003oooooo`000009ooooo`03o`000?oooooo000000Sooooo00?o
0000ooooool00000oooooolEooooo`00<?ooool00ol0003oooooooooo`2]ooooo`03o`000?oooooo
000000Wooooo00?o0000ooooool000002?ooool00ol0003oooooo`00003ooooooaGooooo000`oooo
o`03o`000?oooooooooo0:gooooo00?o0000ooooool000002Oooool00ol0003oooooo`000008oooo
o`03o`000?oooooo00000?oooooo5Oooool0033ooooo00?o0000ooooooooool0[Oooool00ol0003o
ooooo`000009ooooo`03o`000?oooooo000000Sooooo00?o0000ooooool00000oooooolEooooo`00
<?ooool00ol0003oooooooooo`2]ooooo`03o`000?oooooo000000Wooooo00?o0000ooooool00000
2?ooool00ol0003oooooo`00003ooooooaGooooo000`ooooo`03o`000?oooooooooo0:gooooo00?o
0000ooooool000002Oooool00ol0003oooooo`000009ooooo`;o0000oooooolEooooo`00<?ooool0
0ol0003oooooooooo`2]ooooo`03o`000?oooooo000000Wooooo00?o0000ooooool000002Oooool2
o`000?oooooo5Oooool0033ooooo00?o0000ooooooooool0[Oooool00ol0003oooooo`000009oooo
o`03o`000?oooooo000000Wooooo00?o0000ooooooooool0oooooolDooooo`00<?ooool00ol0003o
ooooooooo`2]ooooo`03o`000?oooooo000000Wooooo0_l0000:ooooo`03o`000?oooooooooo0?oo
oooo5?ooool0033ooooo00?o0000ooooooooool0[Oooool2o`0000[ooooo0_l0000:ooooo`03o`00
0?oooooooooo0?oooooo5?ooool0033ooooo00?o0000ooooooooool0[Oooool2o`0000[ooooo0_l0
003oooooob7ooooo000`ooooo`?o0000[Oooool2o`0000[ooooo0_l0003oooooob7ooooo000`oooo
o`03o`000?oooooooooo0:gooooo0_l0000:ooooo`;o0000oooooolQooooo`00<?ooool00ol0003o
ooooooooo`2^ooooo`03o`000?oooooooooo00Sooooo0_l0003oooooob7ooooo000`ooooo`03o`00
0?oooooooooo0;Wooooo0_l0003oooooob7ooooo000`ooooo`03o`000?oooooooooo0;Wooooo0_l0
003oooooob7ooooo000`ooooo`03o`000?oooooooooo0;Wooooo0_l0003oooooob7ooooo000?oooo
o`;ok^k^0oooool2onk^kQ[ooooo00?o0000ooooooooool0^Oooool2o`000?oooooo8Oooool000[o
oooo0_l000002_l@413oooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h3ooooo`Co0000
00So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00?o0000ooooooooool0oooooooL
ooooo`002oooool00ol0003oooooooooo`02ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool0
0ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ol0003ooooooooo
o`3oooooomcooooo0008ooooo`Go00001?ooool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooo
oooo00;ooooo00Go410@oooooooooooooooooa0@400;ooooo`03o`000?oooooooooo0?oooooog?oo
ool000Sooooo00CoA4A4omgMgOoooooo00001?ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000_ooooo00?o0000oooooooo
ool0oooooooLooooo`002?ooool01?oMgMgoEEEEooooool00003ooooo`07onk^k_mEEEGok^k^oooo
ooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
000;ooooo`Co0000oooooooKooooo`002Oooool00omgMgOoc<c<o`000003ooooo`;ok^k^0oooool2
onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00_ooooo00?o
0000ooooooooool0oooooooLooooo`002Oooool00oo^k^koA4A4o`00000?ooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03o`000?oooooooooo0?oooooog?oo
ool000[ooooo00?oMgMgo`000?ooool03?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h00oooool2o`0000Kooooo00?o0000ooooooooool0oooooooLooooo`009oooool0
1?l0003oooooooooool00005ooooo`03o`000?oooooooooo0?oooooog?ooool002Oooooo00Co0000
oooooooooooo00001Oooool00ol0003oooooooooo`3oooooomcooooo000Wooooo`?o00001_ooool0
0ol0003oooooooooo`3oooooomcooooo000Xooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0oooooooLooooo`00:Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oo
oooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooooooo
o`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo0ol0003ooooo
omcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0
oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooo
oooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003o
ooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o
0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`oooo
o`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00
<?ooool3o`000?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool0
0ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033o
oooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo
000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooL
ooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oo
oooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooooooo
o`3oooooomcooooo000`ooooo`?o0000oooooooLooooo`00<?ooool00ol0003oooooooooo`3ooooo
omcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0
oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo003ooooooooooooo4?ooool0
0?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooooooo
ool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00
X?ooool2o`0000Cooooo00?o^[Zjoc8b<_ooool01?ooool2o`0000Kooooo00?o0000okZj^_ooool0
oooooomGooooo`00X?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool2oc8b<_ooooooF?ooool008gooooo0ol00002ooooo`06oc8b<_l@413o
ooooooooooo^k^koEEEE0_l000000om4A4Co^[Zjooooo`03ooooo`03o`000?oooooooooo00;ooooo
00GoV9RHoa0@4?l0003o0000ojVYZ@04ooooo`03o`000?oooooooooo00Cooooo00?oQhN7o`000?nj
^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj00Wooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c005
ooooo`;o8B4Q1?ooool02oo^k^ko<S8bo`000?l@413oc<c<ooooooo<c<cok^k^ooooooo^k^koc<c<
00Cooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^4oooool01_l@413o<S8b
o`000?l0003o410@ojVYZ@;ooooo00Kok^k^oeEEEOl0003o0000odA4A?nj^[X3ooooo`05ofIVI_l0
003o0000odA4A?o<c<`0j?ooool008kooooo00Go0000ooooooooooooc<c<oa0@4003ooooo`06oeEE
EOmgMgOoooooonk^k_mgMgOo410@1?ooool00ol0003oooooooooo`02ooooo`06o`000?nYZJWoEEEE
oiRHV?mEEEGo^[Zj0oooool00ol0003oooooooooo`04ooooo`03olc<c?l0003o410@00cooooo00Ko
410@okZj^_o^k^koMgMgoa0@4?ooool6o`0000;ooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@05oooo
o`;o8B4Q1?ooool02omEEEGoMgMgoooooonHV9So8B4Qooooooo^k^koEEEEomgMgOmEEEGok^k^00Ko
oooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01?ooooo00Ko0000ojVY
ZOoooooooooookZj^_l00002ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo410@0_ooool01_mVIVKo
MgMgooooooooooooQhN7oa0@4>Sooooo002>ooooo`05o`000?oooooooooooeEEEOn7QhL00oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00Ko<S8bonk^k_nHV9SoEEEEomgM
gOl@4103ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02oooool01Ol0003ooooo
oooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000002ooooo`03omgMgOl0003ogMgM
00Oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01Cooooo00Go^[Zj
ohN7QomVIVKoIVIVoa0@4002ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0jooo
ool008kooooo00Go0000oooooooMgMgo0000onk^kP03ooooo`Ko00001?ooool00ol0003ooooooooo
o`02ooooo`07okZj^_m4A4Coc<c<ob4Q8Ooooooo410@olc<c002ooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool00oooool6o`0000;ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P0;oooo
o`0;o`000?nHV9SooooooiRHV?lQ8B7oooooonk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000004oooool01_lb<S;o8B4QogMgMomgMgOo
QhN7onk^kP;ooooo1_l00002ooooo`03o`000?oooooooooo0>_ooooo002>ooooo`?o000000?o410@
oiRHV?ooool00_ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<PCooooo00?o0000ooooooooool0
0_ooool01oo^k^ko0000ooooool0003oooooofIVI_n7QhL00_ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo00_ooooo00Goc<c<o`000?l0003o0000olc<c00;ooooo`0;o`000?mEEEGo
0000oa0@4?o<c<coooooolc<c?o^k^koooooonk^k_o<c<`01_ooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000004oooool01_l0003o^[Zjooooooo^k^koMgMgo`0000;ooooo
00KoEEEEohN7Qoo^k^koooooohN7Qolb<S82ooooo`06ofIVI_mgMgOooooooooooon7QhOo0000j?oo
ool008kooooo00Go0000ooooooooooooc<c<o`000003ooooo`06onk^k_mEEEGo0000o`000?m4A4Co
k^k^1?ooool00ol0003oooooooooo`02ooooo`04ofIVI_nHV9Sooooooc8b<P;o^[Zj00Co0000oooo
oooooooo00004oooool00ol@413o0000o`000003o`0000[ooooo00Go410@okZj^_oooooo^[Zjoa0@
400;ooooo`03oeEEEOn7QhOooooo00kooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@00Oooooo0ol00002ooooo`?o00001?ooool01_nYZJWo8B4Qo`000?l0003o<S8bo`00
00;ooooo00Kok^k^oeEEEOl0003o0000odA4A?o^k^h2ooooo`06onk^k_mVIVKo0000o`000?m4A4Co
0000j?ooool008kooooo00Go0000ooooooooooooc<c<o`00000=ooooo`03o`000?oooooooooo00Go
oooo00?oIVIVohN7Qoooool00oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00_o
oooo00Go0000okZj^_oooooo^[Zjo`00000;ooooo`03omgMgOl@413oV9RH00kooooo00?o0000oooo
ooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`3oooooo`;ooooo002=ooooo`Co000000?o410@ojVYZOooool03?ooool2o`00
00Kooooo00?oZJVYodA4A?ooool00_ooool2o`0001Gooooo00?o0000ooooooooool02oooool01OnY
ZJWo410@o`000?l@413oZJVY00cooooo00Coc<c<odA4A?l0003o410@2_ooool00omEEEGoIVIVo`00
0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_ooool4o`0000;ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`3oooooo`;ooooo003oooooo`Kooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`3oooooo`;ooooo003oooooo`Kooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`3oooooo`;ooooo003oooooo`Gooooo0_l00003ooooo`;o0000ooooool4oooo
o`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooo
oooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo
003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooo
oooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool0
0?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooooooo
ool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00001\
\>"],
  ImageRangeCache->{{{0, 525.688}, {324.5, 0}} -> {-2.58312*^-7, -6.34248*^6, \
6.65005*^-9, 53093.5}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0.309017 5.42214e-08 [
[.32684 .29652 -16.5 -12.5 ]
[.32684 .29652 16.5 0 ]
[.54329 .29652 -16.5 -12.5 ]
[.54329 .29652 16.5 0 ]
[.75974 .29652 -22.5 -12.5 ]
[.75974 .29652 22.5 0 ]
[.97619 .29652 -16.5 -12.5 ]
[.97619 .29652 16.5 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 64 6 ]
[.09789 .09213 -34.5 -6.25 ]
[.09789 .09213 0 6.25 ]
[.09789 .20057 -34.5 -6.25 ]
[.09789 .20057 0 6.25 ]
[.09789 .41746 -28.5 -6.25 ]
[.09789 .41746 0 6.25 ]
[.09789 .5259 -28.5 -6.25 ]
[.09789 .5259 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -62.8125 0 ]
[.5 .63053 62.8125 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 .30902 m
.32684 .31527 L
s
gsave
.32684 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 .30902 m
.54329 .31527 L
s
gsave
.54329 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 .30902 m
.75974 .31527 L
s
gsave
.75974 .29652 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 .30902 m
.15368 .31277 L
s
.19697 .30902 m
.19697 .31277 L
s
.24026 .30902 m
.24026 .31277 L
s
.28355 .30902 m
.28355 .31277 L
s
.37013 .30902 m
.37013 .31277 L
s
.41342 .30902 m
.41342 .31277 L
s
.45671 .30902 m
.45671 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.58658 .30902 m
.58658 .31277 L
s
.62987 .30902 m
.62987 .31277 L
s
.67316 .30902 m
.67316 .31277 L
s
.71645 .30902 m
.71645 .31277 L
s
.80303 .30902 m
.80303 .31277 L
s
.84632 .30902 m
.84632 .31277 L
s
.88961 .30902 m
.88961 .31277 L
s
.9329 .30902 m
.9329 .31277 L
s
.0671 .30902 m
.0671 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09213 m
.11664 .09213 L
s
gsave
.09789 .09213 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .20057 m
.11664 .20057 L
s
gsave
.09789 .20057 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .41746 m
.11664 .41746 L
s
gsave
.09789 .41746 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .5259 m
.11664 .5259 L
s
gsave
.09789 .5259 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.11039 .11924 m
.11414 .11924 L
s
.11039 .14635 m
.11414 .14635 L
s
.11039 .17346 m
.11414 .17346 L
s
.11039 .22768 m
.11414 .22768 L
s
.11039 .2548 m
.11414 .2548 L
s
.11039 .28191 m
.11414 .28191 L
s
.11039 .33613 m
.11414 .33613 L
s
.11039 .36324 m
.11414 .36324 L
s
.11039 .39035 m
.11414 .39035 L
s
.11039 .44457 m
.11414 .44457 L
s
.11039 .47168 m
.11414 .47168 L
s
.11039 .49879 m
.11414 .49879 L
s
.11039 .06502 m
.11414 .06502 L
s
.11039 .03791 m
.11414 .03791 L
s
.11039 .0108 m
.11414 .0108 L
s
.11039 .55301 m
.11414 .55301 L
s
.11039 .58012 m
.11414 .58012 L
s
.11039 .60723 m
.11414 .60723 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -123.812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.812 moveto
(@) show
81.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.812 moveto
(D) show
93.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8.8) show
135.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
141.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
153.000 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
157.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
166.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
184.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02691 .30902 L
.03029 .30902 L
.03347 .30902 L
.03652 .30902 L
.03978 .30902 L
.04291 .30902 L
.04623 .30902 L
.04944 .30902 L
.05252 .30902 L
.0558 .30902 L
.05896 .30902 L
.062 .30902 L
.06523 .30902 L
.06834 .30902 L
.07165 .30902 L
.0733 .30902 L
.07484 .30902 L
.07642 .30902 L
.07719 .30902 L
.0779 .30902 L
.07829 .30902 L
.0787 .30902 L
.07891 .30902 L
.0791 .30902 L
.07922 .30902 L
.07932 .30902 L
.07938 .30902 L
.07944 .30902 L
.0795 .30902 L
.07955 .30902 L
.07964 .30902 L
.07973 .30902 L
.07982 .30902 L
.0799 .30902 L
.07998 .30902 L
.08008 .30902 L
.08028 .30902 L
.08047 .30902 L
.08067 .30902 L
.08104 .30902 L
.08147 .30902 L
.08187 .30902 L
.08276 .30902 L
.08354 .30902 L
.08438 .30902 L
.08513 .30902 L
.08595 .30902 L
.08742 .30902 L
.08823 .30902 L
Mistroke
.08912 .30902 L
.09073 .30902 L
.09231 .30902 L
.094 .30902 L
.09572 .30902 L
.09734 .30902 L
.10044 .30902 L
.10204 .30902 L
.10373 .30902 L
.10678 .30902 L
.10835 .30902 L
.11003 .30902 L
.11336 .30902 L
.11656 .30902 L
.11964 .30902 L
.12292 .30902 L
.12607 .30902 L
.12911 .30902 L
.13234 .30902 L
.13545 .30902 L
.13703 .30902 L
.13876 .30902 L
.14043 .30902 L
.14115 .30902 L
.14194 .30902 L
.14236 .30902 L
.14275 .30902 L
.14295 .30902 L
.14312 .30902 L
.14331 .30902 L
.14341 .30902 L
.14352 .30902 L
.14357 .30902 L
.14363 .30902 L
.14373 .30902 L
.14379 .30902 L
.14385 .30902 L
.14391 .30902 L
.14397 .30902 L
.14402 .30902 L
.14408 .30902 L
.14419 .30902 L
.1443 .30902 L
.1444 .30902 L
.1446 .30902 L
.14479 .30902 L
.1452 .30902 L
.14559 .30902 L
.146 .30902 L
.14674 .30902 L
Mistroke
.14753 .30902 L
.14841 .30902 L
.14922 .30902 L
.14997 .30902 L
.15164 .30902 L
.15317 .30902 L
.15483 .30902 L
.15641 .30902 L
.1581 .30902 L
.1597 .30902 L
.16144 .30902 L
.16465 .30902 L
.16795 .30902 L
.17112 .30902 L
.17417 .30902 L
.17741 .30902 L
.18054 .30902 L
.18213 .30902 L
.18386 .30902 L
.18467 .30902 L
.18552 .30902 L
.18587 .30902 L
.18625 .30902 L
.18647 .30902 L
.18667 .30902 L
.18687 .30902 L
.18706 .30902 L
.18715 .30902 L
.18725 .30902 L
.18735 .30902 L
.18744 .30902 L
.18753 .30902 L
.18764 .30902 L
.18769 .30902 L
.18775 .30902 L
.18785 .30902 L
.18794 .30902 L
.18804 .30902 L
.18823 .30902 L
.18841 .30902 L
.18858 .30902 L
.189 .30902 L
.18938 .30902 L
.18983 .30902 L
.19024 .30902 L
.19103 .30902 L
.19186 .30902 L
.19334 .30902 L
.1941 .30902 L
.19492 .30902 L
Mistroke
.19639 .30902 L
.1981 .30902 L
.19972 .30902 L
.2028 .30902 L
.20608 .30902 L
.20924 .30902 L
.21228 .30902 L
.21551 .30901 L
.21862 .30901 L
.21943 .30901 L
.22032 .30901 L
.22115 .30901 L
.22156 .30901 L
.22193 .30901 L
.22233 .30901 L
.22255 .30901 L
.22266 .30901 L
.22278 .30901 L
.22288 .30901 L
.22297 .30901 L
.22307 .30901 L
.22316 .30901 L
.22326 .30901 L
.22336 .30901 L
.22346 .30901 L
.22352 .30901 L
.22357 .30901 L
.22367 .30901 L
.22377 .30901 L
.22394 .30901 L
.22414 .30901 L
.22434 .30901 L
.22472 .30901 L
.22507 .30901 L
.22547 .30901 L
.22591 .30901 L
.22671 .30901 L
.22748 .30901 L
.2282 .30901 L
.22971 .30902 L
.23136 .30902 L
.23292 .30902 L
.2346 .30902 L
.23791 .30902 L
.2411 .30902 L
.24417 .30903 L
.24744 .30903 L
.24895 .30904 L
.25058 .30904 L
.25148 .30904 L
Mistroke
.25187 .30904 L
.2523 .30904 L
.25268 .30904 L
.25309 .30904 L
.25332 .30904 L
.25352 .30904 L
.25362 .30904 L
.25373 .30904 L
.25383 .30904 L
.25392 .30904 L
.25402 .30904 L
.25412 .30904 L
.2542 .30904 L
.25429 .30904 L
.2544 .30904 L
.2545 .30904 L
.2547 .30904 L
.25489 .30904 L
.25508 .30904 L
.25542 .30904 L
.25584 .30904 L
.25622 .30904 L
.25708 .30904 L
.25786 .30904 L
.25859 .30903 L
.26024 .30903 L
.26187 .30903 L
.26336 .30902 L
.26656 .309 L
.26963 .30898 L
.2729 .30895 L
.27605 .30893 L
.27763 .30892 L
.27907 .30891 L
.27983 .30891 L
.28021 .30891 L
.28063 .3089 L
.28084 .3089 L
.28104 .3089 L
.28115 .3089 L
.28127 .3089 L
.28133 .3089 L
.28139 .3089 L
.28149 .3089 L
.28159 .3089 L
.28169 .3089 L
.28179 .3089 L
.28188 .3089 L
.28198 .3089 L
.28209 .3089 L
Mistroke
.2823 .3089 L
.2825 .3089 L
.28272 .3089 L
.28313 .30891 L
.28352 .30891 L
.28388 .30891 L
.2847 .30891 L
.28556 .30892 L
.28714 .30894 L
.28861 .30896 L
.29024 .309 L
.29173 .30903 L
.29493 .30913 L
.29801 .30924 L
.30128 .30936 L
.30291 .3094 L
.30371 .30942 L
.30444 .30944 L
.30515 .30945 L
.3055 .30945 L
.30589 .30945 L
.3061 .30945 L
.30629 .30946 L
.30639 .30946 L
.30645 .30946 L
.3065 .30946 L
.30656 .30946 L
.30661 .30946 L
.30671 .30946 L
.30681 .30946 L
.3069 .30946 L
.307 .30946 L
.3071 .30946 L
.30719 .30946 L
.30728 .30946 L
.30747 .30945 L
.30768 .30945 L
.30788 .30945 L
.30832 .30945 L
.30871 .30944 L
.30912 .30943 L
.30983 .30941 L
.31061 .30939 L
.31218 .30932 L
.31386 .30921 L
.31719 .3089 L
.32039 .30852 L
.32347 .30814 L
.32503 .30796 L
.32586 .30788 L
Mistroke
.32675 .3078 L
.3276 .30774 L
.32838 .3077 L
.32875 .30768 L
.32895 .30768 L
.32916 .30767 L
.32936 .30766 L
.32955 .30766 L
.32964 .30766 L
.32973 .30766 L
.32982 .30766 L
.32991 .30766 L
.33001 .30766 L
.3301 .30766 L
.33019 .30766 L
.33028 .30766 L
.33038 .30766 L
.33044 .30766 L
.33049 .30766 L
.33069 .30766 L
.33087 .30767 L
.33106 .30767 L
.33142 .30768 L
.33184 .3077 L
.33228 .30773 L
.33307 .3078 L
.33384 .30788 L
.33466 .30799 L
.33613 .30826 L
.33784 .30866 L
.33946 .30913 L
.34255 .31018 L
.34583 .31135 L
.34746 .31185 L
.34826 .31206 L
.34899 .31222 L
.34969 .31235 L
.35006 .3124 L
.35045 .31245 L
.35067 .31248 L
.35087 .31249 L
.35107 .31251 L
.35126 .31252 L
.35145 .31253 L
.35155 .31253 L
.35166 .31253 L
.35175 .31253 L
.35183 .31253 L
.35193 .31253 L
.35203 .31253 L
Mistroke
.35213 .31253 L
.35218 .31253 L
.35223 .31253 L
.35234 .31253 L
.35245 .31252 L
.35266 .31251 L
.35285 .31249 L
.35328 .31245 L
.35373 .31239 L
.35451 .31223 L
.35535 .312 L
.35618 .3117 L
.35693 .31137 L
.35861 .31045 L
.36182 .30805 L
.36491 .30534 L
.36647 .30401 L
.3682 .30272 L
.36898 .30223 L
.36983 .30179 L
.37024 .30161 L
.37063 .30147 L
.37101 .30136 L
.37136 .30128 L
.37156 .30124 L
.37177 .30121 L
.37186 .3012 L
.37196 .30119 L
.37205 .30118 L
.37213 .30118 L
.37223 .30117 L
.37234 .30117 L
.37243 .30117 L
.37253 .30117 L
.37258 .30117 L
.37263 .30117 L
.37273 .30118 L
.37284 .30119 L
.37296 .3012 L
.37315 .30123 L
.37332 .30126 L
.37372 .30135 L
.37408 .30147 L
.37443 .3016 L
.3752 .30201 L
.37602 .30259 L
.3775 .30401 L
.37922 .30626 L
.38084 .30886 L
.38393 .3146 L
Mistroke
.3855 .31755 L
.38722 .32047 L
.38801 .32163 L
.38886 .32269 L
.38966 .32349 L
.39039 .32403 L
.39078 .32423 L
.39097 .32431 L
.39118 .32439 L
.39137 .32443 L
.39147 .32445 L
.39156 .32447 L
.39165 .32448 L
.39174 .32448 L
.39183 .32449 L
.39192 .32449 L
.39203 .32448 L
.39208 .32448 L
.39214 .32447 L
.39224 .32446 L
.39234 .32444 L
.39253 .32439 L
.39273 .32432 L
.39294 .32423 L
.39317 .32411 L
.39359 .32382 L
.39401 .32345 L
.3944 .32303 L
.39529 .3218 L
.3969 .31863 L
.39855 .31425 L
.40004 .30947 L
.40326 .29785 L
.40636 .28767 L
.40719 .28556 L
.40797 .28395 L
.40877 .28268 L
.4092 .2822 L
.40942 .282 L
.40966 .28183 L
.40986 .28172 L
.40998 .28168 L
.41008 .28164 L
.41018 .28162 L
.41027 .2816 L
.41037 .2816 L
.41048 .2816 L
.41053 .2816 L
.41058 .28161 L
.41064 .28162 L
Mistroke
.4107 .28163 L
.41079 .28165 L
.4109 .28169 L
.41114 .28182 L
.41137 .28198 L
.41174 .28234 L
.41215 .28289 L
.41298 .28445 L
.4138 .28659 L
.41455 .28905 L
.41622 .29622 L
.41942 .31459 L
.42249 .33391 L
.42405 .34235 L
.42487 .34608 L
.42576 .34936 L
.42618 .35057 L
.42661 .35163 L
.42698 .35234 L
.42719 .35266 L
.42739 .3529 L
.42758 .3531 L
.42777 .35323 L
.42787 .35328 L
.42796 .35331 L
.42807 .35334 L
.42812 .35334 L
.42818 .35334 L
.42827 .35334 L
.42836 .35332 L
.42846 .35328 L
.42856 .35323 L
.42873 .35312 L
.42891 .35294 L
.42912 .35268 L
.42934 .35233 L
.42974 .3515 L
.43013 .35045 L
.43049 .34928 L
.43131 .34589 L
.43218 .34124 L
.43375 .33016 L
.43522 .31732 L
.43835 .28601 L
.43994 .27054 L
.44078 .26321 L
.44167 .25635 L
.44246 .25127 L
.44288 .249 L
.44333 .24694 L
Mistroke
.44375 .2454 L
.44413 .24431 L
.44449 .24356 L
.44467 .24329 L
.44477 .24318 L
.44487 .24308 L
.44498 .24301 L
.44507 .24297 L
.44518 .24294 L
.44524 .24294 L
.44529 .24295 L
.4454 .24298 L
.44549 .24303 L
.44554 .24306 L
.44559 .24311 L
.44569 .24321 L
.44588 .24347 L
.44608 .24384 L
.44644 .24474 L
.4469 .24633 L
.44733 .24828 L
.44813 .2531 L
.44891 .25929 L
.44974 .26726 L
.45123 .28477 L
.45428 .329 L
.45598 .35417 L
.45753 .37439 L
.4583 .38282 L
.45914 .39038 L
.45952 .39322 L
.45993 .39576 L
.4603 .39765 L
.46066 .39903 L
.46085 .3996 L
.46105 .40008 L
.46114 .40025 L
.46124 .4004 L
.46133 .40051 L
.46141 .40058 L
.46152 .40064 L
.46161 .40067 L
.46172 .40066 L
.46177 .40063 L
.46183 .4006 L
.46193 .40052 L
.46203 .40039 L
.46213 .40023 L
.46223 .40006 L
.46259 .39907 L
Mistroke
.46279 .39831 L
.46298 .39748 L
.46369 .39317 L
.46407 .39022 L
.46447 .38651 L
.46519 .37843 L
.46684 .35412 L
.47015 .28943 L
.47179 .25557 L
.47332 .22749 L
.4748 .20635 L
.47523 .20168 L
.47563 .19793 L
.47602 .19495 L
.47638 .19276 L
.47658 .19183 L
.47675 .19113 L
.47695 .19053 L
.47706 .19028 L
.47716 .19009 L
.47726 .18996 L
.47737 .18987 L
.47747 .18983 L
.47756 .18984 L
.47761 .18987 L
.47766 .1899 L
.47772 .18996 L
.47778 .19003 L
.47788 .1902 L
.47799 .19043 L
.47818 .19099 L
.47836 .19166 L
.47875 .19372 L
.47912 .19632 L
.47947 .19938 L
.48024 .20828 L
.48107 .22072 L
.48255 .24985 L
.48558 .32735 L
.48727 .37237 L
.48881 .40887 L
.4896 .42433 L
.49033 .43626 L
.49109 .44585 L
.49149 .44962 L
.4917 .45121 L
.49192 .45262 L
.49212 .45365 L
.49223 .4541 L
.49235 .45449 L
Mistroke
.49245 .45478 L
.49255 .45499 L
.49265 .45513 L
.49274 .45522 L
.49279 .45524 L
.49285 .45525 L
.49291 .45523 L
.49296 .4552 L
.49306 .45509 L
.49312 .455 L
.49317 .4549 L
.49328 .45463 L
.4934 .45426 L
.49363 .45323 L
.49385 .45202 L
.49404 .45066 L
.49447 .44676 L
.49525 .43681 L
.49605 .42287 L
.49679 .40692 L
.49846 .36176 L
.50162 .25869 L
.5032 .20976 L
.50465 .17331 L
.50545 .15812 L
.50621 .14752 L
.50641 .14538 L
.50663 .14343 L
.50681 .14202 L
.50701 .14078 L
.50714 .14016 L
.50725 .1397 L
.50736 .13935 L
.50741 .13921 L
.50747 .13908 L
.50757 .13893 L
.50767 .13886 L
.50773 .13885 L
.50778 .13886 L
.50789 .13896 L
.50798 .13911 L
.50808 .13935 L
.50817 .13964 L
.50826 .13997 L
.50845 .14095 L
.50866 .14232 L
.50906 .14582 L
.50949 .15101 L
.51025 .16367 L
.51096 .17917 L
Mistroke
.51261 .22665 L
.5141 .28016 L
.51577 .34492 L
.51731 .40217 L
.51808 .42773 L
.5189 .45175 L
.51967 .47013 L
.5204 .48356 L
.52077 .48885 L
.52097 .49116 L
.52118 .49324 L
.52138 .49482 L
.52156 .49596 L
.52164 .49641 L
.52173 .49682 L
.52182 .49712 L
.5219 .49737 L
.52201 .49758 L
.5221 .49769 L
.52216 .49771 L
.52222 .4977 L
.52232 .49762 L
.52238 .49753 L
.52243 .49741 L
.52253 .49713 L
.52264 .49671 L
.52277 .49613 L
.52296 .49489 L
.52318 .49316 L
.52356 .489 L
.52396 .48328 L
.52433 .47672 L
.52517 .45763 L
.52687 .40376 L
.53 .27301 L
.53161 .20728 L
.53245 .17704 L
.53334 .14997 L
.53414 .13094 L
.53459 .1226 L
.53501 .11652 L
.53521 .11426 L
.5354 .11247 L
.53557 .11115 L
.53576 .11008 L
.53585 .10965 L
.53595 .10929 L
.53605 .10906 L
.53614 .10892 L
.53624 .10886 L
Mistroke
.53634 .1089 L
.53644 .10906 L
.5365 .10918 L
.53655 .10934 L
.53666 .10973 L
.53676 .11019 L
.53698 .11159 L
.53717 .11323 L
.53738 .11539 L
.53773 .12012 L
.53813 .12676 L
.53899 .14656 L
.53981 .17093 L
.54292 .29993 L
.5445 .37241 L
.54623 .4422 L
.54703 .46821 L
.54747 .48026 L
.54789 .49001 L
.54827 .49764 L
.54869 .50421 L
.54888 .50654 L
.54907 .5086 L
.54924 .51005 L
.54942 .51128 L
.54953 .51184 L
.54963 .51224 L
.54972 .51253 L
.54982 .51273 L
.54991 .51281 L
.54999 .51281 L
.55008 .51273 L
.55018 .51253 L
.55028 .51223 L
.55039 .51178 L
.5505 .51116 L
.55061 .51047 L
.55081 .50882 L
.551 .50686 L
.55137 .50188 L
.55171 .4961 L
.55247 .47898 L
.55325 .45586 L
.55408 .42612 L
.55556 .36278 L
.5586 .22207 L
.56016 .1628 L
.56104 .13783 L
.56143 .12908 L
.56184 .12145 L
Mistroke
.56206 .11819 L
.56226 .11557 L
.56246 .11345 L
.56264 .11188 L
.56281 .11071 L
.5629 .11025 L
.56299 .10985 L
.56308 .10954 L
.56317 .10934 L
.56328 .10923 L
.56337 .10922 L
.56347 .10934 L
.56353 .10944 L
.56358 .10959 L
.56369 .10995 L
.56378 .11038 L
.564 .11174 L
.56423 .11377 L
.56465 .119 L
.56504 .12546 L
.56583 .14337 L
.56656 .16519 L
.56822 .22934 L
.57136 .37283 L
.57297 .43611 L
.57387 .46368 L
.5743 .47422 L
.5747 .48241 L
.57509 .48879 L
.57544 .49318 L
.57565 .49508 L
.57584 .49645 L
.57594 .49703 L
.57604 .49746 L
.57615 .4978 L
.5762 .49793 L
.57626 .49803 L
.57637 .49811 L
.57642 .49811 L
.57648 .49807 L
.57658 .49791 L
.57667 .49766 L
.57673 .49746 L
.57678 .49723 L
.57689 .49672 L
.57711 .49517 L
.57731 .49334 L
.5775 .49127 L
.57791 .48526 L
.57869 .46934 L
Mistroke
.57942 .44934 L
.58108 .38925 L
.58419 .25373 L
.58578 .19409 L
.58667 .16805 L
.5871 .15809 L
.5875 .15031 L
.58789 .14432 L
.5881 .1418 L
.58832 .13962 L
.5885 .13815 L
.58859 .13752 L
.5887 .13696 L
.58879 .13654 L
.58888 .13624 L
.58897 .13603 L
.58905 .1359 L
.58914 .13583 L
.58925 .13588 L
.5893 .13595 L
.58936 .13605 L
.58946 .13632 L
.58956 .13668 L
.58966 .13717 L
.58984 .13831 L
.59005 .14007 L
.59025 .14213 L
.5907 .14826 L
.5911 .15552 L
.59154 .16509 L
.59234 .18659 L
.59383 .23818 L
.5954 .30119 L
.59712 .36948 L
.59791 .3971 L
.59876 .42242 L
.59956 .44127 L
.5999 .44772 L
.60029 .45356 L
.60067 .45802 L
.60088 .45986 L
.60108 .46118 L
.60117 .46165 L
.60127 .46206 L
.60135 .46235 L
.60143 .46258 L
.60153 .46274 L
.60163 .46282 L
.60173 .46279 L
.60182 .46269 L
Mistroke
.60192 .46247 L
.60197 .46232 L
.60203 .46213 L
.60223 .46121 L
.60234 .46053 L
.60246 .45966 L
.60267 .45775 L
.6031 .45274 L
.60348 .44675 L
.60427 .43059 L
.60501 .41143 L
.60667 .35724 L
.60981 .24601 L
.61064 .22199 L
.61153 .20093 L
.61194 .19326 L
.61237 .18664 L
.61274 .18225 L
.61296 .18029 L
.61315 .17881 L
.61335 .17765 L
.61346 .17718 L
.61357 .17679 L
.61367 .17655 L
.61376 .1764 L
.61386 .17632 L
.61392 .17631 L
.61397 .17633 L
.61406 .17643 L
.61414 .17658 L
.61424 .17681 L
.61433 .17715 L
.61453 .1781 L
.61472 .17926 L
.61513 .18297 L
.61558 .18857 L
.6164 .20266 L
.61716 .21981 L
.61799 .24222 L
.61968 .2943 L
.62137 .34687 L
.62292 .38672 L
.62369 .4015 L
.62409 .4077 L
.62452 .413 L
.62473 .41512 L
.62493 .41679 L
.62513 .41812 L
.62531 .41907 L
.62548 .41975 L
Mistroke
.62556 .42001 L
.62566 .42022 L
.62575 .42037 L
.62585 .42045 L
.62595 .42045 L
.62604 .42038 L
.62613 .42025 L
.62622 .42006 L
.62632 .41978 L
.62642 .4194 L
.62664 .41836 L
.62684 .4171 L
.62721 .4139 L
.62757 .40991 L
.62837 .39805 L
.62924 .38097 L
.6325 .29717 L
.63401 .26047 L
.6348 .24465 L
.63564 .2315 L
.63607 .22641 L
.63629 .22418 L
.63653 .22215 L
.63676 .22062 L
.63696 .21952 L
.63706 .21908 L
.63716 .21868 L
.63726 .21839 L
.63736 .21814 L
.63746 .21796 L
.63755 .21786 L
.63761 .21782 L
.63766 .2178 L
.63777 .21783 L
.63782 .21787 L
.63787 .21793 L
.63797 .21809 L
.63803 .21822 L
.63809 .21837 L
.6382 .2187 L
.63839 .21948 L
.63857 .22042 L
.63898 .22326 L
.63935 .22677 L
.63975 .23142 L
.64048 .24192 L
.64214 .27348 L
.64372 .30844 L
.64545 .34419 L
.64625 .35785 L
Mistroke
.64669 .36422 L
.6471 .3694 L
.64749 .37348 L
.64791 .37701 L
.64809 .37827 L
.64829 .3794 L
.64846 .3802 L
.64864 .3809 L
.64874 .38122 L
.64884 .38146 L
.64894 .38164 L
.64904 .38178 L
.64913 .38186 L
.64921 .38189 L
.6493 .38188 L
.6494 .38182 L
.6495 .38171 L
.64956 .38162 L
.64961 .38152 L
.64983 .38095 L
.65002 .38026 L
.65022 .37931 L
.65061 .37684 L
.65099 .37381 L
.65169 .36647 L
.6533 .34306 L
.65478 .31703 L
.65641 .28879 L
.65721 .27683 L
.65794 .26761 L
.6583 .26376 L
.6587 .26015 L
.65907 .25731 L
.65941 .25525 L
.6596 .25432 L
.65981 .2535 L
.65992 .25313 L
.66003 .25284 L
.66013 .2526 L
.66023 .25241 L
.66031 .25229 L
.66041 .25219 L
.66051 .25213 L
.6606 .25211 L
.66069 .25213 L
.6608 .2522 L
.6609 .25231 L
.66099 .25245 L
.66118 .25287 L
.66136 .2534 L
Mistroke
.66176 .25507 L
.66214 .2572 L
.66249 .25971 L
.66328 .26687 L
.66415 .27671 L
.66586 .29986 L
.66741 .32121 L
.66819 .33072 L
.66903 .33944 L
.66941 .34279 L
.66982 .34583 L
.67019 .34814 L
.67055 .34989 L
.67074 .35064 L
.67095 .35132 L
.67114 .3518 L
.67131 .35214 L
.67141 .35227 L
.6715 .35237 L
.6716 .35245 L
.67165 .35248 L
.67171 .35249 L
.6718 .35249 L
.67186 .35248 L
.67191 .35246 L
.67201 .35238 L
.67207 .35233 L
.67213 .35226 L
.67231 .35196 L
.67249 .35158 L
.67268 .35104 L
.67288 .35034 L
.6736 .34686 L
.67435 .34162 L
.67517 .33456 L
.67664 .31942 L
.67822 .30244 L
.67906 .29434 L
.67995 .28701 L
.6804 .28397 L
.68082 .28155 L
.68123 .27962 L
.68161 .27825 L
.68197 .2773 L
.68215 .27696 L
.68225 .27681 L
.68234 .27669 L
.68245 .27659 L
.68254 .27653 L
.68265 .27649 L
Mistroke
.6827 .27648 L
.68276 .27647 L
.68285 .27649 L
.68294 .27653 L
.68305 .2766 L
.68314 .27669 L
.68334 .27695 L
.68352 .27729 L
.68393 .27835 L
.68434 .27979 L
.68477 .28172 L
.68625 .291 L
.68785 .30369 L
.68959 .31735 L
.6904 .3228 L
.69126 .32746 L
.69199 .33037 L
.69219 .33098 L
.69241 .33154 L
.6926 .33195 L
.6928 .33231 L
.69301 .33259 L
.69312 .33271 L
.69322 .33279 L
.69332 .33285 L
.69341 .33288 L
.69351 .3329 L
.69362 .33289 L
.69372 .33287 L
.69378 .33284 L
.69383 .33282 L
.69394 .33274 L
.69404 .33265 L
.69426 .33238 L
.6945 .33198 L
.69491 .33105 L
.69534 .32975 L
.69612 .32669 L
.69769 .31839 L
.69916 .30954 L
.70064 .30124 L
.70143 .29765 L
.70227 .29468 L
.70273 .29347 L
.70315 .29266 L
.70335 .29236 L
.70357 .29211 L
.70367 .29202 L
.70378 .29195 L
.70387 .2919 L
Mistroke
.70397 .29185 L
.70402 .29184 L
.70407 .29183 L
.70418 .29182 L
.70428 .29182 L
.70437 .29184 L
.70447 .29188 L
.70453 .2919 L
.70458 .29193 L
.7048 .2921 L
.705 .29231 L
.70518 .29255 L
.70558 .29324 L
.70596 .29409 L
.70637 .29519 L
.7071 .29759 L
.70876 .30439 L
.71036 .31132 L
.7112 .31458 L
.71209 .31745 L
.71289 .31939 L
.71334 .32018 L
.71356 .32048 L
.71376 .32072 L
.71395 .32089 L
.71405 .32097 L
.71415 .32104 L
.71425 .32109 L
.71434 .32112 L
.71442 .32115 L
.71451 .32117 L
.7146 .32118 L
.71471 .32119 L
.71479 .32118 L
.71489 .32116 L
.71499 .32113 L
.71511 .32108 L
.7153 .32096 L
.71551 .3208 L
.71573 .32057 L
.71612 .32005 L
.71655 .31933 L
.71701 .31837 L
.71863 .31401 L
.72032 .30875 L
.72186 .30448 L
.72263 .30284 L
.72303 .30214 L
.72346 .30152 L
.72387 .30107 L
Mistroke
.72424 .30079 L
.72442 .30069 L
.72452 .30065 L
.72462 .30061 L
.72471 .30059 L
.7248 .30057 L
.72489 .30056 L
.72497 .30055 L
.72508 .30056 L
.72513 .30056 L
.72518 .30057 L
.72528 .30059 L
.72538 .30061 L
.72549 .30065 L
.72559 .30069 L
.72581 .30081 L
.7262 .30111 L
.72661 .30154 L
.72732 .30252 L
.7281 .30389 L
.7298 .3075 L
.73135 .31077 L
.73212 .31217 L
.73296 .31339 L
.73335 .31384 L
.73375 .31422 L
.7341 .31447 L
.7343 .31458 L
.73448 .31467 L
.73468 .31474 L
.73479 .31476 L
.73484 .31477 L
.7349 .31478 L
.73496 .31479 L
.73501 .3148 L
.73511 .31481 L
.7352 .31481 L
.7353 .3148 L
.73539 .31479 L
.73548 .31478 L
.73557 .31476 L
.73565 .31474 L
.73585 .31468 L
.73604 .3146 L
.73646 .31436 L
.73685 .31407 L
.73772 .31317 L
.74088 .30864 L
.74165 .30758 L
.74246 .30663 L
Mistroke
.74315 .30597 L
.74355 .30568 L
.74391 .30546 L
.7443 .30529 L
.74451 .30522 L
.74461 .30519 L
.74471 .30517 L
.7448 .30515 L
.7449 .30514 L
.74499 .30513 L
.74507 .30512 L
.74517 .30512 L
.74526 .30512 L
.74537 .30512 L
.74546 .30513 L
.74556 .30514 L
.74567 .30516 L
.74588 .3052 L
.74608 .30526 L
.74627 .30532 L
.74669 .30552 L
.74714 .30578 L
.74874 .30713 L
.75044 .30885 L
.75126 .30965 L
.75204 .31032 L
.75279 .31086 L
.75349 .31124 L
.75386 .31138 L
.75425 .3115 L
.75445 .31154 L
.75463 .31157 L
.75474 .31158 L
.75484 .31159 L
.7549 .3116 L
.75496 .3116 L
.75501 .3116 L
.75506 .3116 L
.75517 .3116 L
.75523 .3116 L
.75528 .3116 L
.75538 .3116 L
.75543 .31159 L
.75549 .31159 L
.75569 .31156 L
.75588 .31153 L
.7561 .31148 L
.7563 .31143 L
.75674 .31128 L
.75754 .31091 L
Mistroke
.75828 .31048 L
.75994 .30936 L
.76157 .30832 L
.76237 .30792 L
.76271 .30777 L
.7631 .30763 L
.76344 .30752 L
.76381 .30744 L
.76401 .3074 L
.76419 .30737 L
.76438 .30735 L
.76447 .30734 L
.76455 .30734 L
.76464 .30733 L
.76474 .30733 L
.76484 .30733 L
.76495 .30733 L
.76504 .30733 L
.76514 .30733 L
.76522 .30733 L
.76531 .30734 L
.76551 .30736 L
.76573 .30738 L
.76613 .30745 L
.76656 .30755 L
.76695 .30767 L
.76785 .30799 L
.76947 .3087 L
.77111 .3094 L
.77191 .30968 L
.77264 .30988 L
.77301 .30996 L
.7734 .31003 L
.77358 .31005 L
.77377 .31007 L
.77394 .31008 L
.77412 .3101 L
.77422 .3101 L
.77432 .3101 L
.77441 .31011 L
.77451 .31011 L
.77461 .31011 L
.77467 .31011 L
.77473 .31011 L
.77483 .3101 L
.77493 .3101 L
.77502 .3101 L
.77512 .31009 L
.7753 .31008 L
.77569 .31003 L
Mistroke
.77609 .30998 L
.77645 .30991 L
.77727 .30973 L
.77874 .30932 L
.7804 .30885 L
.78113 .30867 L
.78194 .30851 L
.78231 .30845 L
.78271 .3084 L
.78289 .30838 L
.78308 .30836 L
.78326 .30835 L
.78343 .30834 L
.78362 .30833 L
.78372 .30833 L
.78382 .30833 L
.78391 .30832 L
.78399 .30832 L
.78409 .30832 L
.78418 .30832 L
.78428 .30832 L
.78439 .30833 L
.78449 .30833 L
.78458 .30833 L
.7848 .30834 L
.78501 .30835 L
.78542 .30839 L
.78578 .30843 L
.7866 .30854 L
.78808 .3088 L
.78976 .3091 L
.79049 .30922 L
.7913 .30933 L
.79167 .30937 L
.79208 .3094 L
.79246 .30942 L
.79262 .30943 L
.7928 .30944 L
.7929 .30944 L
.79301 .30945 L
.7931 .30945 L
.79319 .30945 L
.7933 .30945 L
.79336 .30945 L
.79341 .30945 L
.79351 .30945 L
.79357 .30945 L
.79362 .30945 L
.79372 .30945 L
.79382 .30945 L
Mistroke
.7939 .30945 L
.79399 .30945 L
.7942 .30944 L
.79439 .30943 L
.79477 .30942 L
.79517 .30939 L
.7959 .30933 L
.79756 .30914 L
.79915 .30896 L
.79998 .30888 L
.80044 .30884 L
.80087 .30881 L
.80129 .30879 L
.80151 .30878 L
.80174 .30877 L
.80194 .30876 L
.80215 .30875 L
.80225 .30875 L
.80235 .30875 L
.80244 .30875 L
.80253 .30875 L
.80263 .30875 L
.80273 .30875 L
.80283 .30875 L
.80289 .30875 L
.80294 .30875 L
.80304 .30875 L
.80313 .30875 L
.80324 .30875 L
.80334 .30875 L
.80352 .30875 L
.80369 .30876 L
.80407 .30877 L
.80447 .30879 L
.80492 .30881 L
.80571 .30886 L
.80721 .30897 L
.80878 .30908 L
.80967 .30913 L
.81009 .30914 L
.8105 .30916 L
.81088 .30917 L
.8111 .30917 L
.8113 .30918 L
.81147 .30918 L
.81156 .30918 L
.81165 .30918 L
.81175 .30918 L
.81185 .30918 L
.81193 .30918 L
Mistroke
.81203 .30918 L
.81213 .30918 L
.81222 .30918 L
.81228 .30918 L
.81233 .30918 L
.81243 .30918 L
.81263 .30918 L
.81281 .30918 L
.81323 .30917 L
.81367 .30916 L
.81442 .30913 L
.81524 .3091 L
.81671 .30903 L
.81829 .30897 L
.81873 .30895 L
.81919 .30894 L
.81962 .30893 L
.82002 .30892 L
.82022 .30892 L
.82044 .30892 L
.82065 .30892 L
.82077 .30892 L
.82082 .30892 L
.82088 .30892 L
.82099 .30892 L
.82109 .30892 L
.82119 .30892 L
.82128 .30892 L
.82137 .30892 L
.82143 .30892 L
.82148 .30892 L
.8217 .30892 L
.82188 .30892 L
.82208 .30892 L
.82243 .30893 L
.82321 .30894 L
.8248 .30898 L
.82627 .30902 L
.82712 .30904 L
.82792 .30906 L
.82827 .30906 L
.82864 .30907 L
.82883 .30907 L
.82904 .30907 L
.82923 .30907 L
.82941 .30908 L
.82961 .30908 L
.82972 .30908 L
.82977 .30908 L
.82983 .30908 L
Mistroke
.82993 .30908 L
.83002 .30908 L
.83007 .30908 L
.83013 .30908 L
.83023 .30908 L
.83032 .30908 L
.83041 .30908 L
.8305 .30908 L
.83059 .30908 L
.83079 .30908 L
.83098 .30907 L
.83139 .30907 L
.83178 .30907 L
.83265 .30906 L
.83429 .30903 L
.83581 .30901 L
.83656 .309 L
.83728 .30899 L
.83767 .30899 L
.83788 .30898 L
.8381 .30898 L
.8383 .30898 L
.83849 .30898 L
.83858 .30898 L
.83868 .30898 L
.83877 .30898 L
.83885 .30898 L
.83895 .30898 L
.83905 .30898 L
.83913 .30898 L
.83923 .30898 L
.83933 .30898 L
.83944 .30898 L
.83963 .30898 L
.83981 .30898 L
.83998 .30898 L
.84036 .30899 L
.84116 .30899 L
.84202 .309 L
.8436 .30901 L
.84443 .30902 L
.84533 .30903 L
.84577 .30903 L
.84619 .30903 L
.84657 .30904 L
.84676 .30904 L
.84697 .30904 L
.84717 .30904 L
.84736 .30904 L
.84746 .30904 L
Mistroke
.84756 .30904 L
.84761 .30904 L
.84767 .30904 L
.84777 .30904 L
.84787 .30904 L
.84796 .30904 L
.84806 .30904 L
.84815 .30904 L
.84824 .30904 L
.84832 .30904 L
.84851 .30904 L
.8487 .30904 L
.84889 .30904 L
.84929 .30904 L
.85002 .30903 L
.85168 .30902 L
.85335 .30901 L
.85408 .30901 L
.85447 .30901 L
.85489 .30901 L
.85529 .30901 L
.85566 .30901 L
.85583 .30901 L
.85593 .30901 L
.85603 .30901 L
.85612 .30901 L
.85621 .309 L
.8563 .309 L
.85638 .309 L
.85647 .309 L
.85657 .309 L
.85668 .309 L
.85678 .309 L
.85687 .309 L
.85695 .30901 L
.85714 .30901 L
.85735 .30901 L
.85757 .30901 L
.85797 .30901 L
.85872 .30901 L
.85955 .30901 L
.86124 .30902 L
.86199 .30902 L
.86279 .30902 L
.86321 .30902 L
.86366 .30902 L
.86386 .30902 L
.86408 .30902 L
.86426 .30902 L
.86446 .30902 L
Mistroke
.86467 .30902 L
.86479 .30902 L
.86484 .30902 L
.86489 .30902 L
.86499 .30902 L
.86508 .30902 L
.86518 .30902 L
.86523 .30902 L
.86529 .30902 L
.86534 .30902 L
.8654 .30902 L
.86551 .30902 L
.86562 .30902 L
.86572 .30902 L
.86594 .30902 L
.86618 .30902 L
.86658 .30902 L
.86695 .30902 L
.86779 .30902 L
.86929 .30902 L
.87092 .30902 L
.87135 .30901 L
.87181 .30901 L
.87223 .30901 L
.87244 .30901 L
.87263 .30901 L
.8728 .30901 L
.873 .30901 L
.87319 .30901 L
.8733 .30901 L
.87339 .30901 L
.87345 .30901 L
.87351 .30901 L
.87361 .30901 L
.87371 .30901 L
.8738 .30901 L
.87391 .30901 L
.87396 .30901 L
.87402 .30901 L
.87413 .30901 L
.87424 .30901 L
.87445 .30901 L
.87467 .30901 L
.87506 .30901 L
.87594 .30901 L
.87756 .30902 L
.87833 .30902 L
.87914 .30902 L
.87989 .30902 L
.88058 .30902 L
Mistroke
.88094 .30902 L
.88132 .30902 L
.88154 .30902 L
.88165 .30902 L
.88175 .30902 L
.88184 .30902 L
.88193 .30902 L
.88203 .30902 L
.88213 .30902 L
.88219 .30902 L
.88225 .30902 L
.88235 .30902 L
.88245 .30902 L
.88255 .30902 L
.88266 .30902 L
.88277 .30902 L
.883 .30902 L
.88341 .30902 L
.88381 .30902 L
.88542 .30902 L
.8869 .30902 L
.88763 .30902 L
.88841 .30902 L
.88886 .30902 L
.88927 .30902 L
.88947 .30902 L
.88968 .30902 L
.88988 .30902 L
.89007 .30902 L
.89017 .30902 L
.89027 .30902 L
.89035 .30902 L
.89044 .30902 L
.89054 .30902 L
.8906 .30902 L
.89065 .30902 L
.89075 .30902 L
.89084 .30902 L
.89093 .30902 L
.89102 .30902 L
.89119 .30902 L
.89137 .30902 L
.89157 .30902 L
.89198 .30902 L
.89242 .30902 L
.89322 .30902 L
.89481 .30902 L
.89565 .30902 L
.89654 .30902 L
.89698 .30902 L
Mistroke
.89741 .30902 L
.89778 .30902 L
.898 .30902 L
.89819 .30902 L
.89828 .30902 L
.89838 .30902 L
.89846 .30902 L
.89855 .30902 L
.89865 .30902 L
.89875 .30902 L
.89885 .30902 L
.89894 .30902 L
.89903 .30902 L
.89912 .30902 L
.89922 .30902 L
.89932 .30902 L
.89953 .30902 L
.89973 .30902 L
.90011 .30902 L
.90052 .30902 L
.90125 .30902 L
.90291 .30902 L
.90374 .30902 L
.90463 .30902 L
.90504 .30902 L
.90547 .30902 L
.90584 .30902 L
.90605 .30902 L
.90625 .30902 L
.90645 .30902 L
.90655 .30902 L
.90667 .30902 L
.90677 .30902 L
.90686 .30902 L
.90696 .30902 L
.90701 .30902 L
.90707 .30902 L
.90716 .30902 L
.90724 .30902 L
.90733 .30902 L
.90743 .30902 L
.90753 .30902 L
.90763 .30902 L
.90781 .30902 L
.90823 .30902 L
.90862 .30902 L
.90949 .30902 L
.91112 .30902 L
.91192 .30902 L
.91265 .30902 L
Mistroke
.91301 .30902 L
.9134 .30902 L
.91378 .30902 L
.91411 .30902 L
.9143 .30902 L
.91451 .30902 L
.91462 .30902 L
.91473 .30902 L
.91483 .30902 L
.91493 .30902 L
.91502 .30902 L
.91511 .30902 L
.91521 .30902 L
.9153 .30902 L
.9154 .30902 L
.9155 .30902 L
.9156 .30902 L
.91569 .30902 L
.91588 .30902 L
.91606 .30902 L
.91646 .30902 L
.91719 .30902 L
.91884 .30902 L
.91964 .30902 L
.92049 .30902 L
.9209 .30902 L
.9213 .30902 L
.92164 .30902 L
.92202 .30902 L
.9224 .30902 L
.9226 .30902 L
.9227 .30902 L
.92279 .30902 L
.92287 .30902 L
.92297 .30902 L
.92305 .30902 L
.92313 .30902 L
.92322 .30902 L
.92331 .30902 L
.9234 .30902 L
.92349 .30902 L
.92359 .30902 L
.92369 .30902 L
.92389 .30902 L
.92408 .30902 L
.92426 .30902 L
.92466 .30902 L
.92509 .30902 L
.92668 .30902 L
.92752 .30902 L
Mistroke
.92841 .30902 L
.9292 .30902 L
.92965 .30902 L
.93008 .30902 L
.93028 .30902 L
.93046 .30902 L
.93063 .30902 L
.93082 .30902 L
.93092 .30902 L
.93102 .30902 L
.93107 .30902 L
.93113 .30902 L
.93123 .30902 L
.93133 .30902 L
.93143 .30902 L
.93152 .30902 L
.93162 .30902 L
.93172 .30902 L
.93182 .30902 L
.93204 .30902 L
.93223 .30902 L
.93243 .30902 L
.93318 .30902 L
.93486 .30902 L
.93563 .30902 L
.93644 .30902 L
.93713 .30902 L
.93753 .30902 L
.93789 .30902 L
.93828 .30902 L
.93849 .30902 L
.93859 .30902 L
.93869 .30902 L
.93878 .30902 L
.93888 .30902 L
.93897 .30902 L
.93905 .30902 L
.93915 .30902 L
.93924 .30902 L
.93934 .30902 L
.93944 .30902 L
.93955 .30902 L
.93964 .30902 L
.93986 .30902 L
.94005 .30902 L
.94024 .30902 L
.94066 .30902 L
.94111 .30902 L
.94269 .30902 L
.94352 .30902 L
Mistroke
.94441 .30902 L
.94485 .30902 L
.94527 .30902 L
.94567 .30902 L
.94585 .30902 L
.94605 .30902 L
.94622 .30902 L
.94641 .30902 L
.94651 .30902 L
.9466 .30902 L
.94669 .30902 L
.94678 .30902 L
.94688 .30902 L
.94697 .30902 L
.94703 .30902 L
.94708 .30902 L
.94717 .30902 L
.94728 .30902 L
.94737 .30902 L
.94747 .30902 L
.94758 .30902 L
.94779 .30902 L
.94798 .30902 L
.94834 .30902 L
.94916 .30902 L
.95063 .30902 L
.95209 .30902 L
.95249 .30902 L
.95292 .30902 L
.95329 .30902 L
.9537 .30902 L
.95389 .30902 L
.9541 .30902 L
.95422 .30902 L
.95432 .30902 L
.95443 .30902 L
.95453 .30902 L
.95462 .30902 L
.95471 .30902 L
.95481 .30902 L
.95486 .30902 L
.95492 .30902 L
.95501 .30902 L
.95509 .30902 L
.95519 .30902 L
.95528 .30902 L
.95549 .30902 L
.9557 .30902 L
.95609 .30902 L
.95655 .30902 L
Mistroke
.95697 .30902 L
.95864 .30902 L
.95938 .30902 L
.96019 .30902 L
.96056 .30902 L
.96096 .30902 L
.96134 .30902 L
.96169 .30902 L
.96189 .30902 L
.96208 .30902 L
.96218 .30902 L
.96229 .30902 L
.96234 .30902 L
.9624 .30902 L
.96251 .30902 L
.9626 .30902 L
.9627 .30902 L
.96276 .30902 L
.96281 .30902 L
.96291 .30902 L
.96301 .30902 L
.96311 .30902 L
.96328 .30902 L
.96347 .30902 L
.96365 .30902 L
.96406 .30902 L
.96489 .30902 L
.96637 .30902 L
.96709 .30902 L
.96786 .30902 L
.9683 .30902 L
.9687 .30902 L
.96911 .30902 L
.96949 .30902 L
.96969 .30902 L
.9698 .30902 L
.96991 .30902 L
.97001 .30902 L
.97012 .30902 L
.97021 .30902 L
.9703 .30902 L
.97036 .30902 L
.97042 .30902 L
.97052 .30902 L
.97058 .30902 L
.97063 .30902 L
.97076 .30902 L
.97096 .30902 L
.97119 .30902 L
.97162 .30902 L
Mistroke
.97203 .30902 L
.9728 .30902 L
.97428 .30902 L
.97586 .30902 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{421.375, 260.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008>0001AB000`400?l00000o`00003ooooooooo
oooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo
003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooo
oooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool0
0?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooooooo
ool@ooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooo
ooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo0ol0003o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0
003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo
00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`
ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLoooo
o`00<?ooool3o`000?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?oo
ool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0
033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomco
oooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooo
oooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool3o`000?oooooo
g?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0013ooooo0_o^k^h3ooooo`;ok^k^6Oooool00ol0003oooooooooo`3o
ooooomcooooo000;ooooo`;o000000[o410@ooooooooooook^k^oeEEEOo^k^koooooonk^k_mEEEGo
k^k^0oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h:ooooo`03o`000?oo
oooooooo0?oooooog?ooool000cooooo00?o0000ooooooooool00_ooool01Oo^k^koEEEEomgMgOmE
EEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00[ooooo
00?o0000ooooooooool0oooooooLooooo`0000?oooooo`000?l000001?l00002ooooo`Go00001?oo
ool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooo
oa0@400:ooooo`03o`000?oooooooooo0?oooooog?ooool000Wooooo00CoA4A4omgMgOoooooo0000
1?ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000000[ooooo00?o0000ooooooooool0oooooooLooooo`002Oooool01?oMgMgo
EEEEooooool00003ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000:ooooo`Co0000oooooooKooooo`002_oo
ool00omgMgOoc<c<o`000003ooooo`;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@00[ooooo00?o0000ooooooooool0oooooooLooooo`002_oo
ool00oo^k^koA4A4o`00000?ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`;o00001Oooool00ol0003oooooooooo`3oooooomcooooo000;ooooo`03ogMgMol0
003ooooo00cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`3oooooomcooooo000Xooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool0oooooooLooooo`00:?ooool3o`0000Gooooo
00?o0000ooooooooool0oooooooLooooo`00:Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo0?oooooog?ooool002[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2f
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0oooooolGooooo`00<?ooool00ol0
003oooooooooo`2fooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0oooooolGoooo
o`00<?ooool00ol0003oooooooooo`2fooooo`03o`000?oooooooooo00Sooooo0_l0003ooooooaWo
oooo000`ooooo`03o`000?oooooooooo0;Kooooo00?o0000ooooooooool02?ooool2o`000?oooooo
6Oooool0033ooooo00?o0000ooooooooool0]Oooool2o`0000[ooooo0_l0003ooooooaWooooo000`
ooooo`?o0000]Oooool00ol0003oooooo`000009ooooo`;o0000oooooolIooooo`00<?ooool00ol0
003oooooooooo`2eooooo`03o`000?oooooo000000Wooooo0_l0003ooooooaWooooo000`ooooo`03
o`000?oooooooooo0;Gooooo00?o0000ooooool000002Oooool2o`000?oooooo6Oooool0033ooooo
00?o0000ooooooooool0]Oooool00ol0003oooooo`000009ooooo`;o0000oooooolIooooo`00<?oo
ool00ol0003oooooooooo`2eooooo`03o`000?oooooo000000Wooooo0_l0003ooooooaWooooo000`
ooooo`03o`000?oooooooooo0;Gooooo00?o0000ooooool000002Oooool2o`000?oooooo6Oooool0
033ooooo00?o0000ooooooooool0]Oooool00ol0003oooooo`000009ooooo`;o0000oooooolIoooo
o`00<?ooool00ol0003oooooooooo`2eooooo`03o`000?oooooo000000Wooooo00?o0000ooooool0
00002Oooool00ol0003oooooooooo`3oooooo`cooooo000`ooooo`03o`000?oooooooooo0:[ooooo
00?o0000ooooooooool02?ooool00ol0003oooooo`000009ooooo`03o`000?oooooo000000Wooooo
00?o0000ooooooooool0ooooool<ooooo`00<?ooool00ol0003oooooooooo`2Yooooo`;o00002_oo
ool00ol0003oooooo`000009ooooo`03o`000?oooooo000000Wooooo00?o0000ooooooooool0oooo
ool<ooooo`00<?ooool00ol0003oooooooooo`2Yooooo`;o00002_ooool00ol0003oooooo`000009
ooooo`03o`000?oooooo000000Sooooo0_l0003oooooo`kooooo000`ooooo`03o`000?oooooooooo
0:Wooooo0_l0000:ooooo`03o`000?oooooo000000Wooooo00?o0000ooooool000002?ooool2o`00
0?oooooo3_ooool0033ooooo0ol0002Yooooo`;o00002_ooool00ol0003oooooo`000009ooooo`03
o`000?oooooo000000Sooooo00?o0000ooooool00000ooooool=ooooo`00<?ooool00ol0003ooooo
ooooo`2Yooooo`;o00002_ooool00ol0003oooooo`000009ooooo`03o`000?oooooo000000Sooooo
00?o0000ooooool00000ooooool=ooooo`00<?ooool00ol0003oooooooooo`2Yooooo`;o00002_oo
ool00ol0003oooooo`000008ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000
ooooool=ooooo`00<?ooool00ol0003oooooooooo`2Yooooo`;o00002_ooool00ol0003oooooo`00
0008ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000ooooool=ooooo`00<?oo
ool00ol0003oooooooooo`2Yooooo`;o00002_ooool00ol0003oooooo`000008ooooo`04o`000?oo
ooooooooo`0000Sooooo00?o0000ooooool00000ooooool=ooooo`00<?ooool00ol0003ooooooooo
o`2Yooooo`03o`000?oooooo000000Wooooo00?o0000ooooool000002?ooool01?l0003ooooooooo
ool00008ooooo`03o`000?oooooo00000?oooooo3Oooool0033ooooo00?o0000ooooooooool0ZOoo
ool00ol0003oooooo`000009ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo
00002?ooool00ol0003oooooo`00003oooooo`gooooo000`ooooo`03o`000?oooooooooo0:Wooooo
00?o0000ooooool000002Oooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`00
00Sooooo00?o0000ooooool00000ooooool=ooooo`00<?ooool00ol0003oooooooooo`2Yooooo`03
o`000?oooooo000000Sooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?oooooooooo
o`0000Sooooo00?o0000ooooool00000ooooool=ooooo`00<?ooool00ol0003oooooooooo`2Xoooo
o`04o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?oo
ooooooooo`0000Sooooo00?o0000ooooool00000ooooool=ooooo`00<?ooool00ol0003ooooooooo
o`2Xooooo`04o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000007ooooo`04
o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000ooooool=ooooo`00<?ooool3o`000:So
oooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000
oooooooooooo00002?ooool00ol0003oooooo`00003oooooo`gooooo000`ooooo`03o`000?oooooo
oooo0:Sooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Oooooo
00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003oooooo`gooooo000`ooooo`03o`00
0?oooooooooo0:Sooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo0000
00Oooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`000008ooooo`;o0000ooooool3
ooooo`00<?ooool00ol0003oooooooooo`2Xooooo`04o`000?ooooooooooo`0000Sooooo00Go0000
ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000
2?ooool2o`000?oooooo0oooool0033ooooo00?o0000ooooooooool0Z?ooool01?l0003ooooooooo
ool00008ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool00007oooo
o`04o`000?ooooooooooo`0000Sooooo0_l0003oooooo`?ooooo000`ooooo`03o`000?oooooooooo
0:Sooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Co
0000oooooooooooo00001oooool01?l0003oooooooooool00008ooooo`;o0000ooooool3ooooo`00
<?ooool00ol0003oooooooooo`2Xooooo`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooo
ooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00002?oo
ool2o`000?oooooo0oooool0013ooooo0_o^k^h3ooooo`;ok^k^6Oooool00ol0003oooooooooo`2M
ooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooo
oooooooo000000Oooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool00008oooo
o`;o0000ooooool3ooooo`002Oooool5o`0000;ooooo00Ook^k^oeEEEOo^k^koooooonk^k_mEEEGo
k^k^00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^2_ooool00ol0003o
ooooooooo`2Looooo`;o00002_ooool01?l0003oooooooooool00008ooooo`05o`000?oooooooooo
ooooool000001oooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Sooooo
0_l0003oooooo`?ooooo0009ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01Oo^k^koEEEE
omgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00[ooooo00?o0000ooooooooool0W?ooool2o`0000[ooooo00Co0000oooooooooooo00002?ooool0
1Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo00001oooool01?l0003ooooo
ooooool00008ooooo`;o0000ooooool3ooooo`0000?oooooo`000?l000001?l00003ooooo`03oiRH
V?lQ8B7ok^k^00Gooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@
4?ooooooooooooooool@41002_ooool00ol0003oooooooooo`2Looooo`;o00002_ooool01?l0003o
ooooooooool00008ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool0
0007ooooo`04o`000?ooooooooooo`0000Sooooo0_l0003oooooo`?ooooo000;ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo
00Go0000ooooooooooooooooo`00000:ooooo`03o`000?oooooooooo09cooooo0_l0000:ooooo`04
o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?oooooo
ooooo`0000Oooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003oooooo`;ooooo
000<ooooo`0;ogMgMomVIVKoooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000002_ooool4o`0009_ooooo0_l0
000:ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000007ooooo`05
o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo
00000?oooooo0_ooool000gooooo00?o0000ooooooooool00_o^k^h3ooooo`;ok^k^1Oooool00ol0
003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41002_ooool00ol0003oooooooooo`2K
ooooo`03o`000?oooooo000000[ooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooo
oooooooo000000Oooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`00
00Sooooo00?o0000ooooool00000ooooool2ooooo`002Oooool01Ol0003o^[ZjoooooonHV9So410@
00kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo0_l00005
ooooo`03o`000?oooooooooo09_ooooo00?o0000ooooool000002_ooool01Ol0003ooooooooooooo
oooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool0
00001_ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?oooooo0_ooool000Wo
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c00<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP02ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0Vooo
ool01?l0003oooooooooool00009ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003o
oooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?oooooo
ooooo`0000Sooooo00?o0000ooooool00000ooooool2ooooo`00:?ooool01?l0003oooooooooool0
0004ooooo`03o`000?oooooooooo09_ooooo00Co0000oooooooooooo00002Oooool01Ol0003ooooo
oooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooooooo
ooooool000001_ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?oooooo0_oo
ool002Sooooo0ol00005ooooo`03o`000?oooooooooo09_ooooo00Co0000oooooooooooo00002Ooo
ool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`05
o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo
00000?oooooo0_ooool002Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2Koooo
o`04o`000?ooooooooooo`0000Wooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oo
ooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000oooooooo
ooooooooo`000006ooooo`04o`000?ooooooooooo`000?oooooo0_ooool002[ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`2Kooooo`04o`000?ooooooooooo`0000Wooooo00Go0000
ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooo
oooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?oooooooooo
o`000?oooooo0_ooool0033ooooo00?o0000ooooooooool0Voooool01?l0003oooooooooool00009
ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo
00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001_ooool01?l0
003oooooooooool00008ooooo`03o`000?oooooooooo0?Kooooo000`ooooo`03o`000?oooooooooo
09_ooooo00Co0000oooooooooooo00002Oooool01Ol0003ooooooooooooooooo000000Oooooo00Go
0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003o
oooooooooooooooo000000Kooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`3f
ooooo`00<?ooool00ol0003oooooooooo`2Kooooo`04o`000?ooooooooooo`0000Wooooo00Go0000
ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooo
oooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?oooooooooo
o`0000Oooooo0ol0003gooooo`00<?ooool00ol0003oooooooooo`2Kooooo`04o`000?oooooooooo
o`0000Wooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool00000
1oooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000006oooo
o`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool00000moooool0033ooooo0ol0002Koooo
o`04o`000?ooooooooooo`0000Wooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oo
ooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000oooooooo
ooooooooo`000006ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool00000moooool0
033ooooo00?o0000ooooooooool0Voooool01?l0003oooooooooool00009ooooo`05o`000?oooooo
ooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooooooooooo
ooooo`000006ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool00007
ooooo`03o`000?oooooo00000?Oooooo000`ooooo`03o`000?oooooooooo09_ooooo00Co0000oooo
oooooooo00002Oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooooooooooooooo
o`000007ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo0000
00Kooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00003gooooo`00<?ooool00ol0
003oooooooooo`2Kooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooo
oooooooo000000Kooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`00
00Oooooo00?o0000ooooool00000moooool0033ooooo00?o0000ooooooooool0Voooool01Ol0003o
oooooooooooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo
000000Kooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Oooooo
00?o0000ooooool00000moooool0033ooooo00?o0000ooooooooool0Voooool01Ol0003ooooooooo
oooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Ko
oooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000
ooooool00000moooool0033ooooo00?o0000ooooooooool0Soooool00ol0003oooooooooo`09oooo
o`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05o`000?oooooo
ooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo
00001oooool00ol0003oooooo`00003gooooo`00<?ooool00ol0003oooooooooo`2>ooooo`;o0000
2_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000006oooo
o`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool00000moooool0033ooooo00?o0000oooo
ooooool0S_ooool2o`0000[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?oooooo
ooooooooool000001_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooo00000?Oooooo
000`ooooo`03o`000?oooooooooo08gooooo00?o0000ooooool000002_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000Kooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`00
00Oooooo00?o0000ooooool00000moooool0033ooooo00?o0000ooooooooool0SOooool00ol0003o
ooooo`00000:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo
000000Kooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00003gooooo`00<?ooool0
0ol0003oooooooooo`2=ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooooooo
o`000006ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool00006oooo
o`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool0k?ooool0033ooooo0ol0002=oooo
o`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?oo
ooooooooooooool000001_ooool01?l0003oooooooooool00006ooooo`04o`000?ooooooooooo`00
00Oooooo0_l0003^ooooo`00<?ooool00ol0003oooooooooo`2=ooooo`04o`000?ooooooooooo`00
00Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Cooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001_oo
ool01?l0003oooooooooool00006ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool0
0000kOooool0033ooooo00?o0000ooooooooool0SOooool01?l0003oooooooooool00009ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000
00Kooooo00Co0000oooooooooooo00001_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o
0000ooooool00000kOooool0033ooooo00?o0000ooooooooool0SOooool01?l0003oooooooooool0
0009ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000Kooooo00Co0000oooooooooooo00001_ooool01Ol0003ooooooooooooooooo0000
00Kooooo00?o0000ooooool00000kOooool0033ooooo00?o0000ooooooooool0SOooool01?l0003o
ooooooooool00009ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0
003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo00001_ooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooool00000kOooool0033ooooo00?o0000ooooooooool0C_oo
ool2onk^kP?ooooo0_o^k^hhooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000onk^k_ooool0
0_ooool2onk^kP03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`04
o`000?ooooooooooo`0000Kooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
000002Gooooo0_o^k^h3ooooo`;ok^k^C_ooool2onk^kP?ooooo0_o^k^i/ooooo`00<?ooool00ol0
003oooooooooo`18ooooo`0=odA4A?l0003o0000oc8b<_oMgMgoooooonk^k_mEEEGok^k^ooooooo^
k^koEEEEonk^kP03ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kRSooooo
00Go0000ooooooooooooooooo`000009ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool4o`00000:oa0@4?oooooo0000oeEEEOo^k^koooooonk^k_mEEEGok^k^o`0000;ooooo
1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^0_ooool00ol0003oooooooooo`04
ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Gooooo
00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo000000oooooo1?l000000ol@413o
ooooooooo`02ooooo`;o8B4Q1Oooool03Om4A4Co0000o`000?lb<S;ogMgMooooooo^k^koEEEEonk^
k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^hhooooo`Go00000_ooool01oo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008
oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^iMooooo`00<?ooool00ol0003oooooooooo`1;
ooooo`09ogMgMolb<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02Sooooo00Go0000ooooooooooooooooo`000009
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool2o`0000?ooooo00So0000
onk^k_mEEEGogMgMoeEEEOo^k^koooooo`0000Cooooo0_l00003ooooo`05ogMgMonHV9So0000oiRH
V?mgMgL00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool01Ol0003ooooooooooooooooo000000Gooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooo0000017ooooo00?o0000ooooooooool01?ooool2ob4Q8@Sooooo00Wo
MgMgoc8b<_ooooooooooonk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL0>?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00Go
k^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`1Mooooo`00<?ooool00ol0003oooooooooo`1<ooooo`07o`000?oooooooooooooooooM
gMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400X
ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Gooooo0_l00003ooooo`05o`000?oooooogMgMo`000?oMgMd00_ooool00ol0003ooooo
ooooo`02ooooo`;o00000oooool01Ol@413oooooo`000?oooooo410@00;ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooo
ooooooooo`000005ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0003ooooooooooooo
oooo0000013ooooo00?o0000ooooooooool03oooool01ol0003ooooooooooooooooogMgMo`000?oM
gMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100>Oooool00onH
V9So8B4Qonk^kP05ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@
413ooooooooooooooooo410@05gooooo000`ooooo`03o`000?oooooooooo04_ooooo00WoMgMgoc8b
<_ooooooooooonk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000:?ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`05ooooo`;o00000oooool02?l0003ok^k^oeEEEOoMgMgo
EEEEonk^k_oooooo00001?ooool2o`0000?ooooo00Go0000ooooool0003oooooo`000002ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05
o`000?ooooooooooooooool000001Oooool01Ol0003ooooooooooooooooo000000Gooooo00Go0000
ooooooooooooooooo`000006ooooo`;o00002?ooool00ol0003oooooooooo`0>ooooo`09ogMgMolb
<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0
003ooooooooooooooooo000003[ooooo00?oV9RHob4Q8Oo^k^h00oooool01Oo^k^koEEEEomgMgOmE
EEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000005gooooo
000`ooooo`03o`000?oooooooooo04Sooooo00go0000ob4Q8Ol0003o<S8bolc<c?ooooook^k^oeEE
EOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000002Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01Oooool2o`0000?ooooo00So0000oeEEEOo^k^ko
ooooonk^k_mEEEGok^k^o`0000Cooooo0_l00003ooooo`05o`000?oooooo0000ooooool000000_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooo
ool01Ol0003ooooooooooooooooo000000Gooooo00Go0000ooooooooooooooooo`000005ooooo`05
o`000?ooooooooooooooool000001_ooool2o`0000Sooooo00?o0000ooooooooool02oooool03Ol0
003o8B4Qo`000?lb<S;oc<c<ooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000>oooool02omgMgOoIVIVoooooooo
ooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000ooooooooool00_ooool01Ol0
003ooooooooooooooooo000005gooooo000`ooooo`03o`000?oooooooooo04Sooooo00?o0000oooo
ooooool00oooool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooo
oooooooooooooa0@400Kooooo`;o00002_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`;o00000oooool0
0ol0003ok^k^ooooo`02ooooo`;ok^k^00?o0000ooooooooool00_ooool2o`0000?ooooo00Go410@
ooooool0003ooooooa0@4002ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0003ooooo
oooooooooooo000000Gooooo00Go0000ooooooooooooooooo`000006ooooo`;o00002?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo0_o^k^h3ooooo`;ok^k^1Oooool00ol0
003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100??ooool00ol0003oooooooooo`02
onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
401Mooooo`00<?ooool3o`0004Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`0?ooooo`?o00002_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`05ooooo`;o00000oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00;ooooo0_l00003ooooo`05ogMgMonHV9So0000oiRHV?mgMgL00_ooool00ol0003ooooo
ooooo`03ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool0
00001Oooool01Ol0003ooooooooooooooooo000000Gooooo00Go0000ooooooooooooooooo`000006
ooooo`;o00002?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo0_l0000^ooooo`05o`000?nj
^[[ooooooiRHV?l@41003_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02?ooool2o`0005?ooooo000`ooooo`03o`000?oooooooooo04Sooooo1?l0000<ooooo`03oeEE
EOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooool000002_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03oeEEEOl0003o000000?o
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooomEEEGoIVIV00;o00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00;ooooo00?o0000ooooooooool00_ooool01?l0003oooooo`000?l0
0003ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000005ooooo`05o`00
0?ooooooooooooooool000001Oooool01Ol0003ooooooooooooooooo000000Kooooo0_l00006oooo
o`03oeEEEOmVIVKo000000gooooo1?l0000<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP07ooooo`04o`000?ooooooooooo`0002gooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c00<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP07ooooo`04
o`000?ooooooooooo`0005;ooooo000`ooooo`03o`000?oooooooooo06Kooooo1?l00003ooooo`03
o`000?oooooooooo00kooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool4o`000003ooooool0003ooooo
00;o00000oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001Oooool0
1Ol0003ooooooooooooooooo000000Gooooo00Go0000ooooooooooooooooo`000005ooooo`04o`00
0?ooooooooooo`0003?ooooo1?l000001Ooooooo0000oooooooooooo000004cooooo1?l000001Ooo
oooo0000oooooooooooo000005;ooooo000`ooooo`03o`000?oooooooooo06gooooo00?o0000oooo
ooooool03_ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo0ol00004
ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000005ooooo`05o`000?oo
ooooooooooooool000001Oooool01Ol0003ooooooooooooooooo000000Gooooo00Co0000oooooooo
oooo0000>?ooool3o`0005;ooooo0ol0001Cooooo`00<?ooool00ol0003oooooooooo`1[ooooo`04
o`000?ooooooooooo`0000kooooo00Go0000ooooooooooooooooo`000009ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`05o`000?oooooo
ooooooooool000001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000005ooooo`04o`000?ooooooooooo`0000Kooooo0_l0000aooooo`03
o`000?oooooooooo05;ooooo00?o0000ooooooooool0D_ooool0033ooooo00?o0000ooooooooool0
Joooool4o`0000kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooo
ooooo`000005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000000Gooooo00Co0000oooooooooooo00001_ooool00ol0003oooooo`00000a
ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0DOooool0033ooooo00?o0000oooo
ooooool0O?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00Go0000oooo
ooooooooooooo`000005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000000Gooooo00Co0000oooooooooooo00001_ooool00ol0003ooooo
o`00003Jooooo`00<?ooool00ol0003oooooooooo`1looooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0003o
oooooooooooooooo000000Gooooo00?o0000ooooool000001oooool00ol0003oooooooooo`2Foooo
o`03ogMgMomVIVKooooo02gooooo00?oIVIVogMgMoooool01oooool0033ooooo00?o0000oooooooo
ool0KOooool4o`0000_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`05
o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`000005ooooo`05o`000?ooooooooooooooool000001?oo
ool01Ol0003ooooooooooooooooo000000Gooooo0ol0002Fooooo`03omgMgOl@413ok^k^02kooooo
00?ok^k^oa0@4?oMgMd01oooool0033ooooo00?o0000ooooooooool0K?ooool2o`0000;ooooo0_l0
000:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0003ooooooooooooooooo000000Co
oooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooo000000Oooooo00?o0000oooo
ooooool0N_ooool2o`0000;ooooo0_l0000<ooooo`03oeEEEOnHV9Sooooo00;o00000_ooool01ol0
003oooooooooool0003o410@onk^k_mEEED00_l000000om4A4Co^[Zjooooo`02ooooo`05oiRHV?l0
003o0000odA4A?nj^[X00_ooool02?o^k^koEEEEo`000?l0003oA4A4okZj^_oooooo410@1Ol00003
ooooo`08oa0@4?lb<S;o0000o`000?l@413oZJVYohN7QomVIVH7ooooo`00<?ooool00ol0003ooooo
ooooo`1[ooooo`;o00001Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooooooo
ool00oooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000005
ooooo`03o`000?oooooo000000Kooooo0ol00006ooooo`;o0000Loooool01_o^k^ko8B4QohN7Qonj
^[[o0000omgMg@cooooo00Go0000ooooooooooooooooo`000002ooooo`0;o`000?ooooooooooo`00
0?ooooooEEEEogMgMoooooook^k^ogMgMol@41000oooool01Ol@413o^[Zjonk^k_mgMgOo410@00;o
oooo00KoEEEEogMgMoooooook^k^ogMgMol@4103ooooo`03o`000?oooooooooo00Cooooo00So0000
ojVYZOoooooooooookZj^_l0003ok^k^o`0000Oooooo003oo`000;Co00003oooool01?oMgMgo0000
oa0@4?o<c<`=ooooo`05oc8b<_ooooooooooooooool000000_ooool01_l0003oooooooooool0003o
ooooo`0000Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Gooooo00Oo^[ZjohN7QomVIVKoIVIVoa0@4?oooooo000000Oooooo000:ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo00Kooooo0ol00007ooooo`03o`000?oooooooooo00Cooooo0_l00004ooooo`;o0000
1?ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool00oooool00ol0003o
ooooo`000006ooooo`03o`000?oooooooooo00Gooooo0_l00005ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`;o00001?ooool01Ol0003o
oooooooooooooooo000000Cooooo00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooo
oooo000000Cooooo00?o0000ooooooooool00_ooool01Ol0003oooooo`000?oooooo000000Cooooo
00Co0000oooooooooooo00001?ooool5o`0000Cooooo1?l00005ooooo`;o00000oooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo01Oooooo00Cok^k^ob4Q8Ol@413ok^k^3Oooool01Olb
<S;ooooooooooooooooo000000;ooooo00Go0000oooooooooooo0000ooooo`06o`0000?ooooo00?o
0000ooooooooool01?ooool6o`0000?ooooo00?o0000ooooooooool01?ooool02?lb<S;o8B4QogMg
MomgMgOoQhN7onk^k_oooooo00001oooool000[ooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`06ooooo`Co00001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00oooool00ol0003oooooo`000006ooooo`03o`000?oooooooooo00Go
oooo0_l00005ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooo`000003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`02ooooo`;o00001?ooool01Ol0003ooooooooooooooooo000000Gooooo00Go0000oooo
ool0003oooooo`000005ooooo`05o`000?ooooooooooooooool000001?ooool01?l0003oooooo`00
0?l00005ooooo`?o00002Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool05oooool01?lQ8B7oMgMgogMgMolb<S8=ooooo`05o`000?o^k^kooooooooo
ool000000_o<c<`02ol0003oZJVYomgMgOlQ8B7ooooooeEEEOn7QhOok^k^oooooon7QhOo<S8b00?o
oooo00?o0000ooooooooool01?ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<P?ooooo00?o0000
oc8b<_oMgMd01?ooool02?l0003o^[Zjooooooo^k^koMgMgo`000?o^k^ko00001oooool0033ooooo
00?o0000ooooooooool0Foooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
00001Oooool01Ol0003ooooooooooooooooo000000Gooooo00Co0000oooooooooooo00001Oooool0
1?l0003oooooooooool00006ooooo`;o00002Oooool00ol0003oooooooooo`1Kooooo`03o`000?oo
oooooooo01Kooooo0_l00002ooooo`;o00003?ooool03_mEEEGoMgMgooooool@413o0000ob4Q8Ol0
003oMgMgoa0@4?l0003oZJVYooooooo^k^koEEEE0_l000001?m4A4Cok^k^ooooool@4105o`0000?o
oooo00Kok^k^oeEEEOl0003o0000odA4A?o^k^h2ooooo`;o000000CoZJVYob4Q8Ol0003o8B4Q0_oo
ool02?nYZJWo8B4Qo`000?l0003o<S8bo`000?mgMgOoEEEE1oooool0033ooooo00?o0000oooooooo
ool0MOooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01Ol0
003ooooooooooooooooo000000Gooooo00Go0000ooooooooooooooooo`000005ooooo`04o`000?oo
ooooooooo`0000Gooooo00?o0000ooooool00000Voooool00ooMgMgo410@onk^kP0Booooo`03o`00
0?oooooooooo01Wooooo00?ok^k^oa0@4?oMgMd01oooool0033ooooo00?o0000ooooooooool0MOoo
ool01Ol0003ooooooooooooooooo000000Wooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooo
oooooooooooo000000Gooooo00Go0000ooooooooooooooooo`000005ooooo`04o`000?oooooooooo
o`0000Kooooo0_l0002Looooo`03ogMgMomVIVKooooo017ooooo00?o0000ooooooooool06Oooool0
0omVIVKoMgMgooooo`07ooooo`00<?ooool00ol0003oooooooooo`1fooooo`04o`000?oooooo0000
o`0000[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooo
ooooooooool000001Oooool01Ol0003ooooooooooooooooo000000Gooooo00Go0000oooooooooooo
ooooo`000005ooooo`04o`000?ooooooooooo`0000Kooooo0_l0003Fooooo`00<?ooool00ol0003o
ooooooooo`1fooooo`?o00002oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00Go0000ooooooooooooooooo`000005ooooo`05o`000?ooooooooooooooool000001Oooool0
1Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooool00000goooool0033ooooo00?o0000
ooooooooool0Q?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000
ooooooooooooooooo`000005ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0003ooooo
oooooooooooo000000Gooooo00?o0000ooooool00000goooool0033ooooo00?o0000ooooooooool0
Q?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooo
ooooo`000005ooooo`05o`000?ooooooooooooooool000001Oooool01?l0003oooooooooool00006
ooooo`03o`000?oooooo00000=oooooo000`ooooo`03o`000?oooooooooo08Gooooo00Go0000oooo
ooooooooooooo`000008ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0003ooooooooo
oooooooo000000Gooooo00Co0000oooooooooooo00001oooool2o`000=oooooo000`ooooo`03o`00
0?oooooooooo08Gooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooooooooooo
ool000001Oooool01Ol0003ooooooooooooooooo000000Gooooo00Co0000oooooooooooo00001ooo
ool00ol0003oooooooooo`3Nooooo`00<?ooool3o`0008Gooooo00Go0000ooooooooooooooooo`00
0008ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0003ooooooooooooooooo000000Go
oooo00Co0000oooooooooooo0000j?ooool0033ooooo00?o0000ooooooooool0QOooool01Ol0003o
oooooooooooooooo000000Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00Go0000ooooooooooooooooo`000005ooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooo`00003Xooooo`00<?ooool00ol0003oooooooooo`25ooooo`05o`000?oo
ooooooooooooool000002?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool01Ol0003ooooooooooooooooo000000Gooooo00Go0000ooooooooooooooooo`000006
ooooo`03o`000?oooooo00000>Sooooo000`ooooo`03o`000?oooooooooo08Gooooo00Go0000oooo
ooooooooooooo`000009ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooool00000j?ooool0033ooooo00?o0000ooooooooool0Q_ooool00ol0003ooooo
o`00000:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`05ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05
o`000?ooooooooooooooool000001Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000
ooooool00000j?ooool0033ooooo00?o0000ooooooooool0Q_ooool00ol0003oooooo`00000:oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05oooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooo
ooooooooool000001Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooool00000
j?ooool0033ooooo00?o0000ooooooooool0Q_ooool00ol0003oooooo`00000:ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool0
00001Oooool01Ol0003ooooooooooooooooo000000Kooooo0_l0003Yooooo`00<?ooool00ol0003o
ooooooooo`26ooooo`?o00002_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool01Ol0003ooooooooooooooooo000000Gooooo00Go0000ooooooooooooooooo`00
0006ooooo`;o0000jOooool0033ooooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oo
ooooooooooooool000001_ooool01?l0003oooooooooool0003aooooo`00<?ooool00ol0003ooooo
ooooo`2Cooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`05ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo0000
00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooooooo
ooooool000001_ooool00ol0003oooooo`00003booooo`00<?ooool00ol0003oooooooooo`2Coooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05oooo
o`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooo`00003booooo`00<?ooool00ol0003oooooooooo`2Cooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`05o`000?oo
ooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001_ooool00ol0
003oooooo`00003booooo`00<?ooool3o`0009?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000006oooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00003booooo`00<?ooool0
0ol0003oooooooooo`2Dooooo`05o`000?ooooooooooooooool000002?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`05ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`00
00Oooooo00?o0000ooooool00000l_ooool0033ooooo00?o0000ooooooooool0U?ooool01?l0003o
ooooooooool00009ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000006
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooool000001oooool00ol0003oooooo`00003booooo`00<?ooool0
0ol0003oooooooooo`2Dooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Ooo
ool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooo`000007ooooo`03
o`000?oooooo00000?;ooooo000`ooooo`03o`000?oooooooooo09Cooooo00Co0000oooooooooooo
00002Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooo000000Oooooo00?o0000ooooool00000l_ooool0033ooooo00?o0000oooo
ooooool0U?ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01Oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooooooooooooooo
o`000006ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooool000001oooool00ol0003oooooo`00003booooo`00
<?ooool00ol0003oooooooooo`2Dooooo`04o`000?ooooooooooo`0000Wooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000001oooool01Ol0
003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooo`000007ooooo`?o0000l_oo
ool0033ooooo00?o0000ooooooooool0U?ooool01?l0003oooooooooool00009ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000Oooooo
00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooool000002?ooool00ol0
003oooooooooo`3aooooo`00<?ooool00ol0003oooooooooo`2Dooooo`04o`000?ooooooooooo`00
00Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`05o`000?oooooooooo
ooooool000001oooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
o`000008ooooo`03o`000?oooooooooo0?7ooooo000`ooooo`03o`000?oooooooooo09Cooooo00Co
0000oooooooooooo00002Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo
00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooo00000?cooooo000`ooooo`03o`000?oooooooooo09Cooooo00Co0000oooo
oooooooo00002Oooool01Ol0003ooooooooooooooooo000000Sooooo00Go0000oooooooooooooooo
o`000007ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo0000
00Oooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00003looooo`00<?ooool00ol0
003oooooooooo`2Dooooo`04o`000?ooooooooooo`0000Wooooo00Go0000ooooooooooooooooo`00
0008ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Ko
oooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000
ooooool00000o?ooool0033ooooo0ol0002Dooooo`04o`000?ooooooooooo`0000Wooooo00Go0000
ooooooooooooooooo`000008ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooo
oooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?oooooooooo
o`0000Oooooo00?o0000ooooool00000o?ooool0033ooooo00?o0000ooooooooool0UOooool2o`00
00[ooooo00Go0000ooooooooooooooooo`000008ooooo`05o`000?ooooooooooooooool000001ooo
ool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000007ooooo`04
o`000?ooooooooooo`0000Oooooo00?o0000ooooool00000o?ooool0033ooooo00?o0000oooooooo
ool0UOooool2o`0000[ooooo00Go0000ooooooooooooooooo`000008ooooo`05o`000?oooooooooo
ooooool000001oooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000oooooooooooooooo
o`000007ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool00000o?ooool0033ooooo
00?o0000ooooooooool0UOooool2o`0000[ooooo00Go0000ooooooooooooooooo`000008ooooo`05
o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000
ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool00000
o?ooool0033ooooo00?o0000ooooooooool0UOooool2o`0000[ooooo00Go0000oooooooooooooooo
o`000008ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo0000
00Kooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo00?o
0000ooooool00000o?ooool0033ooooo00?o0000ooooooooool0XOooool01Ol0003ooooooooooooo
oooo000000Sooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool0
00001_ooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo00001oooool0
0ol0003oooooo`00003looooo`003oooool2onk^kP?ooooo0_o^k^hJooooo`03o`000?oooooooooo
0:7ooooo00Go0000ooooooooooooooooo`000008ooooo`05o`000?ooooooooooooooool000001ooo
ool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000007ooooo`04
o`000?ooooooooooo`0000Oooooo00?o0000ooooool00000o?ooool000Sooooo1Ol00002ooooo`07
onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co000000So410@ooooooooooook^k^oc8b
<_l0003o<S8bonk^kP_ooooo00?o0000ooooooooool0XOooool01Ol0003ooooooooooooooooo0000
00Sooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001ooo
ool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool0
0000o?ooool000Sooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05onk^k_mEEEGogMgMoeEE
EOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
0ol0003oooooooooo`2Qooooo`05o`000?ooooooooooooooool000002?ooool01Ol0003ooooooooo
oooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`00
00Oooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00003looooo`002Oooool00onH
V9So8B4Qonk^kP05ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@
413ooooooooooooooooo410@00_ooooo00?o0000ooooooooool0XOooool01Ol0003ooooooooooooo
oooo000000Sooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool0
00001oooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000
ooooool00000o?ooool000[ooooo00?oV9RHob4Q8Oo^k^h00oooool01Oo^k^koEEEEomgMgOmEEEGo
k^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000_ooooo00?o
0000ooooooooool0XOooool01Ol0003ooooooooooooooooo000000Sooooo00Go0000oooooooooooo
ooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool00007
ooooo`04o`000?ooooooooooo`0000Oooooo0_l0003mooooo`002oooool02omgMgOoIVIVoooooooo
ooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000ooooooooool00_ooool01Ol0
003ooooooooooooooooo000000_ooooo1?l0002Pooooo`05o`000?ooooooooooooooool000002?oo
ool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04
o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00001oooool2o`000?gooooo000<oooo
o`03o`000?oooooooooo00;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@
413ooooooooooooooooo410@00_ooooo00?o0000ooooooooool0X_ooool01?l0003oooooooooool0
0008ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oo
oooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo
oooo0?_ooooo0008ooooo`05o`000?nj^[[ooooooiRHV?l@41003_ooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ol0003oooooooooo`2Rooooo`04o`000?oo
ooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooooooooooo
ool000001oooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Sooooo00?o
0000ooooooooool0noooool000Sooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00<ooooo`03oeEEEOmV
IVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`;o00001_ooool00ol0003ooooo
ooooo`2Rooooo`04o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000007oooo
o`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool00007ooooo`04o`000?oo
ooooooooo`000?oooooo1oooool002Oooooo00Co0000oooooooooooo00001Oooool00ol0003ooooo
ooooo`2Rooooo`04o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000007oooo
o`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool00007ooooo`04o`000?oo
ooooooooo`000?oooooo1oooool002Oooooo00Co0000oooooooooooo00001Oooool00ol0003ooooo
ooooo`2Rooooo`04o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000007oooo
o`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool00007ooooo`04o`000?oo
ooooooooo`000?oooooo1oooool002Oooooo0ol00006ooooo`03o`000?oooooooooo0:;ooooo00Co
0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooooooo
ooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo0000oooo
ool7ooooo`00:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0:;ooooo00?o0000
ooooool000002Oooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool00000
1oooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`000?oooooo1oooool002Wo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2Rooooo`03o`000?oooooo000000Wo
oooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000
oooooooooooo00001oooool01?l0003oooooooooool0003oooooo`Oooooo000`ooooo`03o`000?oo
oooooooo0:;ooooo00?o0000ooooool000002Oooool01?l0003oooooooooool00008ooooo`05o`00
0?ooooooooooooooool000001oooool01?l0003oooooooooool00007ooooo`04o`000?oooooooooo
o`000?oooooo1oooool0033ooooo00?o0000ooooooooool0X_ooool00ol0003oooooo`000009oooo
o`04o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?oo
ooooooooo`0000Oooooo00?o0000ooooool00000ooooool8ooooo`00<?ooool00ol0003ooooooooo
o`2Rooooo`03o`000?oooooo000000Wooooo00Co0000oooooooooooo00002?ooool01?l0003ooooo
ooooool00008ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool00000ooooool8oooo
o`00<?ooool3o`000:;ooooo00?o0000ooooool000002Oooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00
003oooooo`Sooooo000`ooooo`03o`000?oooooooooo0:;ooooo00?o0000ooooool000002Oooool0
1?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo
00002?ooool2o`000?oooooo2?ooool0033ooooo00?o0000ooooooooool0Xoooool2o`0000Wooooo
00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00008ooooo`04o`000?oooooooooo
o`0000Sooooo0_l0003oooooo`Sooooo000`ooooo`03o`000?oooooooooo0:?ooooo0_l00009oooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002?ooool01?l0003ooooooooo
ool00008ooooo`;o0000ooooool8ooooo`00<?ooool00ol0003oooooooooo`2Sooooo`03o`000?oo
oooooooo00Sooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00008ooooo`04
o`000?ooooooooooo`0000Sooooo0_l0003oooooo`Sooooo000`ooooo`03o`000?oooooooooo0:?o
oooo00?o0000ooooooooool02?ooool01?l0003oooooooooool00009ooooo`03o`000?oooooo0000
00Sooooo00Co0000oooooooooooo00002?ooool2o`000?oooooo2?ooool0033ooooo00?o0000oooo
ooooool0[_ooool01?l0003oooooooooool00009ooooo`03o`000?oooooo000000Sooooo00Co0000
oooooooooooo00002?ooool2o`000?oooooo2?ooool0033ooooo00?o0000ooooooooool0[_ooool0
1?l0003oooooooooool00009ooooo`03o`000?oooooo000000Sooooo00?o0000ooooool000002Ooo
ool2o`000?oooooo2?ooool0033ooooo00?o0000ooooooooool0[oooool00ol0003oooooo`000009
ooooo`03o`000?oooooo000000Sooooo00?o0000ooooool000002Oooool2o`000?oooooo2?ooool0
033ooooo00?o0000ooooooooool0[oooool00ol0003oooooo`000009ooooo`03o`000?oooooo0000
00Sooooo00?o0000ooooool00000oooooolCooooo`00<?ooool00ol0003oooooooooo`2_ooooo`03
o`000?oooooo000000Wooooo00?o0000ooooool000002?ooool00ol0003oooooo`00003ooooooa?o
oooo000`ooooo`03o`000?oooooooooo0:oooooo00?o0000ooooool000002Oooool00ol0003ooooo
o`000008ooooo`03o`000?oooooo00000?oooooo4oooool0033ooooo0ol0002_ooooo`03o`000?oo
oooo000000Wooooo00?o0000ooooool000002?ooool00ol0003oooooo`00003ooooooa?ooooo000`
ooooo`03o`000?oooooooooo0:oooooo00?o0000ooooool000002Oooool00ol0003oooooo`000008
ooooo`03o`000?oooooo00000?oooooo4oooool0033ooooo00?o0000ooooooooool0[oooool00ol0
003oooooo`000009ooooo`03o`000?oooooo000000Sooooo00?o0000ooooool00000oooooolCoooo
o`00<?ooool00ol0003oooooooooo`2_ooooo`03o`000?oooooo000000Wooooo00?o0000ooooool0
00002?ooool00ol0003oooooo`00003ooooooa?ooooo000`ooooo`03o`000?oooooooooo0:oooooo
00?o0000ooooool000002Oooool00ol0003oooooo`000009ooooo`;o0000oooooolCooooo`00<?oo
ool00ol0003oooooooooo`2_ooooo`03o`000?oooooo000000Wooooo00?o0000ooooool000002Ooo
ool2o`000?oooooo4oooool0033ooooo00?o0000ooooooooool0[oooool00ol0003oooooo`000009
ooooo`03o`000?oooooo000000Wooooo0_l0003ooooooa?ooooo000`ooooo`03o`000?oooooooooo
0:oooooo0_l0000:ooooo`03o`000?oooooo000000Wooooo0_l0003ooooooa?ooooo000`ooooo`03
o`000?oooooooooo0:oooooo0_l0000:ooooo`03o`000?oooooo000000Wooooo0_l0003ooooooa?o
oooo000`ooooo`03o`000?oooooooooo0:oooooo0_l0000:ooooo`03o`000?oooooo000000Wooooo
0_l0003ooooooa?ooooo000`ooooo`03o`000?oooooooooo0;3ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooo`000009ooooo`;o0000oooooolCooooo`00<?ooool00ol0003oooooooooo`2`
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooool000002Oooool2o`000?oooooo4oooool0
033ooooo0ol0002kooooo`03o`000?oooooo00000?oooooo7_ooool0033ooooo00?o0000oooooooo
ool0^oooool00ol0003oooooo`00003ooooooakooooo000`ooooo`03o`000?oooooooooo0;_ooooo
00?o0000ooooool00000oooooolNooooo`00<?ooool00ol0003oooooooooo`2kooooo`;o0000oooo
oolOooooo`00<?ooool00ol0003oooooooooo`2looooo`03o`000?oooooooooo0?oooooo7Oooool0
033ooooo00?o0000ooooooooool0_?ooool00ol0003oooooooooo`3ooooooagooooo000?ooooo`;o
k^k^0oooool2onk^kQ[ooooo00?o0000ooooooooool0_?ooool00ol0003oooooooooo`3ooooooago
oooo000:ooooo`;o000000[o410@ooooooooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^0ooo
ool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`03o`000?oooooooooo
0?oooooog?ooool000_ooooo00?o0000ooooooooool00_ooool01Oo^k^koEEEEomgMgOmEEEGok^k^
00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?o0000
ooooooooool0oooooooLooooo`002?ooool5o`0000Cooooo00?ogMgMo`000?oMgMd01oooool00ol0
003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41002oooool00ol0003oooooooooo`3o
ooooomcooooo0008ooooo`04odA4A?oMgMgoooooo`0000Cooooo00Gok^k^oeEEEOoMgMgoEEEEonk^
kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000;ooooo`03o`00
0?oooooooooo0?oooooog?ooool000Sooooo00CogMgMoeEEEOoooooo00000oooool01oo^k^koEEEE
onk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool000002oooool4o`000?oooooofoooool000Wooooo00?oMgMgolc<c?l000000oooool2onk^
kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400;
ooooo`03o`000?oooooooooo0?oooooog?ooool000Wooooo00?ok^k^odA4A?l000003oooool00ol0
003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ol0003oooooooooo`3o
ooooomcooooo000:ooooo`03ogMgMol0003ooooo00cooooo00?oEEEEofIVI_l000001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00?ooooo0_l00006ooooo`03o`000?oooooooooo0?oooooog?ooool0
02Oooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`3oooooomcooooo000Woooo
o`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0oooooooLooooo`009oooool3o`00
00Kooooo00?o0000ooooooooool0oooooooLooooo`00:?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0?oooooog?ooool002Wooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000
ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`?o
0000oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0
003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo
00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`
ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLoooo
o`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooo
g?ooool0033ooooo0ol0003oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0
033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomco
oooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooo
oooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooo
ooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000
ooooooooool0oooooooLooooo`00<?ooool3o`000?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00oooooooooooo
oa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003o
oooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo
4?ooool00:3ooooo0_l00004ooooo`03okZj^_lb<S;ooooo00Cooooo0_l00006ooooo`03o`000?nj
^[[ooooo0?ooooooEoooool00:3ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo0_lb<S;ooooooeSooooo002=ooooo`?o00000_ooool01_lb
<S;o410@ooooooooooook^k^oeEEE@;o000000?oA4A4okZj^_ooool00oooool00ol0003ooooooooo
o`02ooooo`05oiRHV?l@413o0000o`000?nYZJT01?ooool00ol0003oooooooooo`04ooooo`03ohN7
Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P09ooooo`05olc<c?lQ8B7o0000ob4Q
8Oo<c<`01Oooool2ob4Q8@Cooooo00_oc<c<ob4Q8Ol0003o8B4Qolc<c?ooooooc<c<onk^k_oooooo
k^k^olc<c004ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kQ?ooooo00Ko
410@oc8b<_l0003o0000oa0@4?nYZJT2ooooo`06onk^k_mEEEGo0000o`000?m4A4Co^[Zj0oooool0
1OmVIVKo0000o`000?m4A4Coc<c<0>Sooooo002>ooooo`05o`000?ooooooooooolc<c?l@41000ooo
ool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40Cooooo00?o0000ooooooooool00_ooool01_l0003o
ZJVYoeEEEOnHV9SoEEEEokZj^P?ooooo00?o0000ooooooooool01?ooool00oo<c<co0000oa0@400<
ooooo`06oa0@4?nj^[[ok^k^ogMgMol@413ooooo1_l00002ooooo`05ob4Q8OnHV9SooooooiRHV?lQ
8B401Oooool2ob4Q8@Cooooo00_o8B4QoiRHV?ooooooV9RHob4Q8Oooooook^k^oeEEEOoMgMgoEEEE
onk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Cooooo`06
o`000?nYZJWooooooooooonj^[[o00000_ooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40;ooooo
00KoIVIVogMgMoooooooooooohN7Qol@413Xooooo`00S_ooool01Ol0003ooooooooooomEEEGoQhN7
00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`06oc8b<_o^k^koV9RH
oeEEEOoMgMgo410@0oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00_ooooo00Go
0000ooooooooooooooooo`00000;ooooo`05o`000?ooooooooooooooool000000_ooool00ooMgMgo
0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Doooo
o`05okZj^_n7QhOoIVIVofIVI_l@41000_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo0>_ooooo002>ooooo`05o`000?oooooogMgMo`000?o^k^h00oooool6o`0000Cooooo00?o0000
ooooooooool00_ooool01onj^[[oA4A4olc<c?lQ8B7ooooooa0@4?o<c<`00_ooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo00?ooooo1_l00002ooooo`05oc8b<_nHV9SooooooiRHV?lb
<S802oooool02olb<S;oV9RHoooooonHV9So<S8booooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000001?ooooo00Ko<S8bob4Q8Omg
MgOoMgMgohN7Qoo^k^h2ooooo`Ko00000_ooool00ol0003oooooooooo`3[ooooo`00S_ooool3o`00
0003oa0@4?nHV9Sooooo00;ooooo00KoEEEEohN7Qoo^k^koooooohN7Qolb<S84ooooo`03o`000?oo
oooooooo00;ooooo00Ook^k^o`000?oooooo0000oooooomVIVKoQhN700;ooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0;ooooo`05olc<c?l0003o0000o`000?o<c<`02oooool02oo<
c<co0000o`000?l0003oc<c<ooooooo<c<cok^k^ooooooo^k^koc<c<00Kooooo00?o0000oooooooo
ool00_ooool01Ol0003ooooooooooooooooo000001?ooooo00Ko0000okZj^_ooooook^k^ogMgMol0
0002ooooo`06oeEEEOn7QhOok^k^oooooon7QhOo<S8b0_ooool01_mVIVKoMgMgooooooooooooQhN7
o`000>Sooooo002>ooooo`05o`000?ooooooooooolc<c?l000000oooool01_o^k^koEEEEo`000?l0
003oA4A4onk^kPCooooo00?o0000ooooooooool00_ooool01?mVIVKoV9RHoooooolb<S82okZj^P04
o`000?ooooooooooo`0001?ooooo00?o410@o`000?l000000ol0000:ooooo`05oa0@4?nj^[[ooooo
okZj^_l@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00cooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@00Oooooo0ol00002ooooo`?o00001?ooool01_nYZJWo8B4Q
o`000?l0003o<S8bo`0000;ooooo00Kok^k^oeEEEOl0003o0000odA4A?o^k^h2ooooo`06onk^k_mV
IVKo0000o`000?m4A4Co0000j?ooool008kooooo00Go0000ooooooooooooc<c<o`00000=ooooo`03
o`000?oooooooooo00Gooooo00?oIVIVohN7Qoooool00oooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo00_ooooo00Go0000okZj^_oooooo^[Zjo`00000;ooooo`05o`000?nj^[[ooooo
okZj^_l000003?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo0_ooool008gooooo1?l00000
0ol@413oZJVYooooo`0<ooooo`;o00001_ooool00onYZJWoA4A4ooooo`02ooooo`;o00005Oooool0
0ol0003oooooooooo`0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT02oooool01OnYZJWo410@o`00
0?l@413oZJVY00[ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;o
oooo1?l00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0ooooool2ooooo`00
ooooool6ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0ooooool2ooooo`00oooo
ool6ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0ooooool2ooooo`00ooooool5
ooooo`;o00000oooool2o`000?oooooo1?ooool00?ooooooooooool@ooooo`00oooooooooooooa3o
oooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooo
oooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?oo
ool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooo
ooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@oooo
o`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooo
oooooa3ooooo0000\
\>"],
  ImageRangeCache->{{{0, 525.688}, {324.5, 0}} -> {-2.58312*^-7, -6.34248*^6, \
6.65005*^-9, 53093.5}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0.309017 5.42214e-08 [
[.32684 .29652 -16.5 -12.5 ]
[.32684 .29652 16.5 0 ]
[.54329 .29652 -16.5 -12.5 ]
[.54329 .29652 16.5 0 ]
[.75974 .29652 -22.5 -12.5 ]
[.75974 .29652 22.5 0 ]
[.97619 .29652 -16.5 -12.5 ]
[.97619 .29652 16.5 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 64 6 ]
[.09789 .09213 -34.5 -6.25 ]
[.09789 .09213 0 6.25 ]
[.09789 .20057 -34.5 -6.25 ]
[.09789 .20057 0 6.25 ]
[.09789 .41746 -28.5 -6.25 ]
[.09789 .41746 0 6.25 ]
[.09789 .5259 -28.5 -6.25 ]
[.09789 .5259 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -59.8125 0 ]
[.5 .63053 59.8125 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 .30902 m
.32684 .31527 L
s
gsave
.32684 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 .30902 m
.54329 .31527 L
s
gsave
.54329 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 .30902 m
.75974 .31527 L
s
gsave
.75974 .29652 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 .30902 m
.15368 .31277 L
s
.19697 .30902 m
.19697 .31277 L
s
.24026 .30902 m
.24026 .31277 L
s
.28355 .30902 m
.28355 .31277 L
s
.37013 .30902 m
.37013 .31277 L
s
.41342 .30902 m
.41342 .31277 L
s
.45671 .30902 m
.45671 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.58658 .30902 m
.58658 .31277 L
s
.62987 .30902 m
.62987 .31277 L
s
.67316 .30902 m
.67316 .31277 L
s
.71645 .30902 m
.71645 .31277 L
s
.80303 .30902 m
.80303 .31277 L
s
.84632 .30902 m
.84632 .31277 L
s
.88961 .30902 m
.88961 .31277 L
s
.9329 .30902 m
.9329 .31277 L
s
.0671 .30902 m
.0671 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09213 m
.11664 .09213 L
s
gsave
.09789 .09213 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .20057 m
.11664 .20057 L
s
gsave
.09789 .20057 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .41746 m
.11664 .41746 L
s
gsave
.09789 .41746 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .5259 m
.11664 .5259 L
s
gsave
.09789 .5259 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.11039 .11924 m
.11414 .11924 L
s
.11039 .14635 m
.11414 .14635 L
s
.11039 .17346 m
.11414 .17346 L
s
.11039 .22768 m
.11414 .22768 L
s
.11039 .2548 m
.11414 .2548 L
s
.11039 .28191 m
.11414 .28191 L
s
.11039 .33613 m
.11414 .33613 L
s
.11039 .36324 m
.11414 .36324 L
s
.11039 .39035 m
.11414 .39035 L
s
.11039 .44457 m
.11414 .44457 L
s
.11039 .47168 m
.11414 .47168 L
s
.11039 .49879 m
.11414 .49879 L
s
.11039 .06502 m
.11414 .06502 L
s
.11039 .03791 m
.11414 .03791 L
s
.11039 .0108 m
.11414 .0108 L
s
.11039 .55301 m
.11414 .55301 L
s
.11039 .58012 m
.11414 .58012 L
s
.11039 .60723 m
.11414 .60723 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -120.812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.812 moveto
(@) show
81.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.812 moveto
(D) show
93.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(9.) show
129.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
135.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
147.000 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
151.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
160.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
178.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02691 .30902 L
.03029 .30902 L
.03347 .30902 L
.03652 .30902 L
.03978 .30902 L
.04291 .30902 L
.04623 .30902 L
.04944 .30902 L
.05252 .30902 L
.0558 .30902 L
.05896 .30902 L
.062 .30902 L
.06523 .30902 L
.06834 .30902 L
.06992 .30902 L
.07076 .30902 L
.07165 .30902 L
.07252 .30902 L
.07293 .30902 L
.0733 .30902 L
.07368 .30902 L
.07388 .30902 L
.07398 .30902 L
.07409 .30902 L
.07419 .30902 L
.07428 .30902 L
.07437 .30902 L
.07445 .30902 L
.07455 .30902 L
.07464 .30902 L
.07473 .30902 L
.07484 .30902 L
.07493 .30902 L
.07503 .30902 L
.07523 .30902 L
.07542 .30902 L
.07559 .30902 L
.07598 .30902 L
.0764 .30902 L
.0768 .30902 L
.07717 .30902 L
.07787 .30902 L
.07865 .30902 L
.07947 .30902 L
.08096 .30902 L
.08171 .30902 L
.08253 .30902 L
.084 .30902 L
.0857 .30902 L
Mistroke
.08731 .30902 L
.0889 .30902 L
.09038 .30902 L
.09203 .30902 L
.09353 .30902 L
.0952 .30902 L
.09675 .30902 L
.09984 .30902 L
.10136 .30902 L
.10302 .30902 L
.10627 .30902 L
.10939 .30902 L
.11272 .30902 L
.11592 .30902 L
.119 .30902 L
.12228 .30902 L
.12544 .30902 L
.12847 .30902 L
.1317 .30902 L
.13481 .30902 L
.13639 .30902 L
.13812 .30902 L
.13892 .30902 L
.13977 .30902 L
.14057 .30902 L
.1413 .30902 L
.1417 .30902 L
.1419 .30902 L
.14213 .30902 L
.14224 .30902 L
.14235 .30902 L
.14241 .30902 L
.14247 .30902 L
.14253 .30902 L
.14259 .30902 L
.14269 .30902 L
.14274 .30902 L
.1428 .30902 L
.14285 .30902 L
.1429 .30902 L
.14296 .30902 L
.14302 .30902 L
.14312 .30902 L
.14321 .30902 L
.14342 .30902 L
.14361 .30902 L
.14379 .30902 L
.1442 .30902 L
.14464 .30902 L
.14539 .30902 L
Mistroke
.14583 .30902 L
.14623 .30902 L
.14704 .30902 L
.14792 .30902 L
.14873 .30902 L
.14962 .30902 L
.15123 .30902 L
.15281 .30902 L
.15449 .30902 L
.15621 .30902 L
.15783 .30902 L
.16093 .30902 L
.16422 .30902 L
.16739 .30902 L
.17044 .30902 L
.17369 .30902 L
.17681 .30902 L
.18013 .30902 L
.1818 .30902 L
.18333 .30902 L
.18483 .30902 L
.18558 .30902 L
.18599 .30902 L
.18641 .30902 L
.1868 .30902 L
.18702 .30902 L
.18722 .30902 L
.18732 .30902 L
.18741 .30902 L
.18749 .30902 L
.18758 .30902 L
.18768 .30902 L
.18777 .30902 L
.18786 .30902 L
.18797 .30902 L
.18802 .30902 L
.18808 .30902 L
.18818 .30902 L
.18829 .30902 L
.18838 .30902 L
.1886 .30902 L
.18883 .30902 L
.18926 .30902 L
.18964 .30902 L
.19003 .30902 L
.19045 .30902 L
.19119 .30902 L
.19199 .30902 L
.19286 .30902 L
.19443 .30902 L
Mistroke
.19611 .30902 L
.19782 .30902 L
.19944 .30902 L
.20252 .30902 L
.2058 .30902 L
.20896 .30902 L
.21199 .30902 L
.21523 .30902 L
.21834 .30902 L
.21992 .30901 L
.22076 .30901 L
.22165 .30901 L
.22209 .30901 L
.22251 .30901 L
.22292 .30901 L
.2231 .30901 L
.2233 .30901 L
.22347 .30901 L
.22366 .30901 L
.22376 .30901 L
.22385 .30901 L
.22395 .30901 L
.22404 .30901 L
.22413 .30901 L
.22423 .30901 L
.22432 .30901 L
.22442 .30901 L
.22452 .30901 L
.22458 .30901 L
.22463 .30901 L
.22483 .30901 L
.22503 .30901 L
.22521 .30901 L
.22562 .30901 L
.226 .30901 L
.22635 .30901 L
.22715 .30901 L
.22801 .30901 L
.22877 .30902 L
.22961 .30902 L
.2313 .30902 L
.23286 .30902 L
.23453 .30902 L
.23784 .30902 L
.24104 .30902 L
.2441 .30903 L
.24737 .30903 L
.25051 .30903 L
.25134 .30903 L
.25224 .30903 L
Mistroke
.25301 .30903 L
.25342 .30903 L
.25385 .30903 L
.25429 .30903 L
.25468 .30904 L
.25487 .30904 L
.25498 .30904 L
.25508 .30904 L
.25517 .30904 L
.25528 .30904 L
.25537 .30904 L
.25546 .30904 L
.25556 .30904 L
.25561 .30904 L
.25566 .30904 L
.25577 .30904 L
.25583 .30904 L
.25588 .30904 L
.25598 .30904 L
.25608 .30904 L
.25627 .30904 L
.25649 .30904 L
.25673 .30903 L
.25715 .30903 L
.25755 .30903 L
.25791 .30903 L
.25872 .30903 L
.25948 .30903 L
.26019 .30903 L
.26179 .30903 L
.26327 .30902 L
.26476 .30902 L
.26641 .30901 L
.26964 .309 L
.27274 .30898 L
.27604 .30895 L
.27768 .30894 L
.27922 .30893 L
.28069 .30893 L
.28152 .30892 L
.28188 .30892 L
.28227 .30892 L
.28266 .30892 L
.28287 .30892 L
.28307 .30892 L
.28317 .30892 L
.28326 .30892 L
.28334 .30892 L
.28343 .30892 L
.28352 .30892 L
Mistroke
.28362 .30892 L
.28372 .30892 L
.28381 .30892 L
.28391 .30892 L
.28397 .30892 L
.28402 .30892 L
.28422 .30892 L
.28433 .30892 L
.28445 .30892 L
.28467 .30892 L
.28509 .30892 L
.28548 .30892 L
.28627 .30893 L
.28701 .30893 L
.28782 .30894 L
.28868 .30895 L
.29024 .30896 L
.29171 .30899 L
.29481 .30905 L
.29812 .30914 L
.3013 .30924 L
.30436 .30932 L
.30593 .30936 L
.30681 .30937 L
.30761 .30938 L
.308 .30939 L
.30821 .30939 L
.30841 .30939 L
.30858 .30939 L
.30877 .30939 L
.30887 .30939 L
.30897 .30939 L
.30906 .30939 L
.30915 .30939 L
.30921 .30939 L
.30927 .30939 L
.30932 .30939 L
.30937 .30939 L
.30947 .30939 L
.30957 .30939 L
.30968 .30939 L
.30979 .30939 L
.31002 .30939 L
.31022 .30939 L
.31041 .30938 L
.31082 .30938 L
.31121 .30937 L
.31162 .30937 L
.31236 .30935 L
.31315 .30933 L
Mistroke
.31403 .3093 L
.31558 .30922 L
.31726 .30911 L
.32056 .30883 L
.32375 .30851 L
.32681 .30819 L
.32852 .30804 L
.33007 .30793 L
.33085 .30789 L
.33129 .30788 L
.33169 .30787 L
.33204 .30786 L
.33214 .30786 L
.33224 .30786 L
.33234 .30785 L
.33243 .30785 L
.33253 .30785 L
.33258 .30785 L
.33264 .30785 L
.33273 .30785 L
.33284 .30785 L
.33293 .30785 L
.33303 .30785 L
.33313 .30785 L
.33321 .30785 L
.33341 .30786 L
.33359 .30786 L
.3338 .30787 L
.334 .30787 L
.33435 .30788 L
.33473 .3079 L
.33559 .30796 L
.33639 .30803 L
.3379 .30821 L
.33955 .30849 L
.34279 .30926 L
.3459 .31019 L
.34921 .31117 L
.35087 .31158 L
.35167 .31174 L
.3524 .31187 L
.35277 .31192 L
.35317 .31196 L
.35351 .312 L
.35389 .31203 L
.3541 .31204 L
.35429 .31205 L
.3544 .31205 L
.35449 .31205 L
.35455 .31205 L
Mistroke
.35461 .31205 L
.35466 .31206 L
.35471 .31206 L
.3548 .31206 L
.35489 .31206 L
.35498 .31206 L
.35508 .31205 L
.35518 .31205 L
.35528 .31205 L
.35547 .31204 L
.35568 .31203 L
.35587 .31202 L
.35624 .31198 L
.35663 .31194 L
.35706 .31187 L
.35782 .31172 L
.35853 .31154 L
.36004 .31101 L
.3617 .31022 L
.36494 .30814 L
.36806 .30578 L
.36964 .30462 L
.37137 .30351 L
.37217 .30308 L
.37303 .3027 L
.37344 .30255 L
.37383 .30243 L
.37421 .30233 L
.37456 .30226 L
.37476 .30223 L
.37494 .30221 L
.37514 .30219 L
.37525 .30218 L
.37535 .30218 L
.37545 .30217 L
.3755 .30217 L
.37556 .30217 L
.37566 .30217 L
.37575 .30217 L
.3758 .30218 L
.37586 .30218 L
.37596 .30218 L
.37606 .30219 L
.37618 .3022 L
.37638 .30222 L
.37655 .30225 L
.37695 .30233 L
.37732 .30244 L
.37767 .30256 L
.37845 .30291 L
Mistroke
.37928 .30342 L
.38076 .30466 L
.38234 .30642 L
.38381 .30842 L
.38693 .31339 L
.38852 .31601 L
.39025 .31863 L
.39105 .31971 L
.39191 .3207 L
.39271 .32148 L
.39345 .32203 L
.39381 .32224 L
.3942 .32242 L
.39439 .32249 L
.39459 .32254 L
.3947 .32257 L
.39481 .32259 L
.3949 .32261 L
.39501 .32262 L
.3951 .32263 L
.3952 .32264 L
.39529 .32264 L
.39537 .32264 L
.39547 .32263 L
.39556 .32262 L
.39567 .32261 L
.39576 .32259 L
.39594 .32256 L
.39611 .32251 L
.39648 .32237 L
.39689 .32214 L
.39733 .32183 L
.39813 .32105 L
.39891 .32004 L
.39962 .3189 L
.40114 .31583 L
.40279 .31157 L
.40604 .30154 L
.40917 .29202 L
.40999 .28993 L
.41088 .28798 L
.41172 .28649 L
.41209 .28596 L
.41249 .28548 L
.4129 .2851 L
.41308 .28497 L
.41327 .28485 L
.41345 .28476 L
.41362 .2847 L
.41372 .28468 L
Mistroke
.4138 .28466 L
.4139 .28464 L
.41399 .28464 L
.41409 .28464 L
.4142 .28464 L
.41425 .28465 L
.41431 .28466 L
.41441 .28468 L
.41451 .28472 L
.41461 .28475 L
.41479 .28484 L
.415 .28498 L
.4152 .28513 L
.41565 .2856 L
.41602 .28611 L
.41642 .28677 L
.41715 .28829 L
.41801 .29063 L
.4188 .29326 L
.42198 .30771 L
.42503 .32478 L
.42674 .33388 L
.42828 .34089 L
.42906 .34372 L
.42989 .34615 L
.43028 .34702 L
.43069 .34777 L
.43103 .34826 L
.43123 .34847 L
.43142 .34862 L
.43152 .34869 L
.43162 .34875 L
.43172 .34879 L
.43181 .34881 L
.43187 .34882 L
.43192 .34883 L
.43198 .34883 L
.43204 .34883 L
.43214 .34882 L
.4322 .3488 L
.43225 .34879 L
.43235 .34875 L
.43245 .34869 L
.43263 .34856 L
.43283 .34837 L
.43304 .3481 L
.43342 .34749 L
.43381 .34662 L
.43453 .34454 L
.43528 .3416 L
Mistroke
.43609 .33762 L
.43756 .32843 L
.44086 .30095 L
.44405 .27272 L
.44565 .26108 L
.44635 .25701 L
.44711 .25345 L
.44753 .25189 L
.44792 .25074 L
.44829 .24991 L
.44847 .2496 L
.44868 .24933 L
.44879 .24922 L
.4489 .24914 L
.449 .24909 L
.4491 .24905 L
.44916 .24904 L
.44921 .24904 L
.44928 .24904 L
.44933 .24905 L
.44944 .24909 L
.4495 .24912 L
.44955 .24916 L
.44974 .24933 L
.44985 .24946 L
.44995 .24961 L
.45016 .24999 L
.45036 .25044 L
.45077 .25161 L
.4512 .25327 L
.452 .25735 L
.45272 .26221 L
.45349 .26849 L
.45653 .30262 L
.45976 .34629 L
.46125 .36459 L
.46287 .38058 L
.4633 .38384 L
.46375 .38682 L
.46414 .38896 L
.46457 .3908 L
.46479 .39157 L
.465 .39215 L
.4652 .39258 L
.4653 .39275 L
.46541 .3929 L
.46551 .393 L
.4656 .39307 L
.46569 .39312 L
.46578 .39313 L
Mistroke
.46588 .39312 L
.46597 .39309 L
.46607 .39302 L
.46612 .39297 L
.46618 .39291 L
.46637 .39262 L
.46657 .39219 L
.46679 .39158 L
.46699 .39089 L
.46735 .38932 L
.46773 .38719 L
.46861 .38057 L
.4694 .37252 L
.47094 .35208 L
.47261 .32411 L
.47589 .26222 L
.47753 .23446 L
.47833 .223 L
.47906 .21414 L
.47981 .20689 L
.48015 .20426 L
.48052 .20196 L
.48073 .20092 L
.48091 .20013 L
.4811 .19947 L
.48127 .199 L
.48137 .19879 L
.48148 .19862 L
.48158 .19849 L
.48164 .19843 L
.4817 .1984 L
.4818 .19837 L
.48189 .19838 L
.482 .19844 L
.4821 .19855 L
.48219 .19868 L
.48229 .19887 L
.48246 .19931 L
.48268 .20003 L
.48287 .20087 L
.48327 .20312 L
.4837 .20627 L
.4844 .21329 L
.48517 .22335 L
.48675 .25086 L
.48843 .28824 L
.49177 .3707 L
.49344 .4067 L
.49417 .41965 L
.49498 .43128 L
Mistroke
.49535 .43564 L
.49576 .43955 L
.49613 .44245 L
.49648 .44442 L
.49668 .44526 L
.49687 .44584 L
.49697 .44606 L
.49708 .44623 L
.49713 .4463 L
.49719 .44635 L
.4973 .44639 L
.49739 .44637 L
.49749 .44629 L
.49754 .44623 L
.4976 .44614 L
.4977 .44594 L
.4978 .44569 L
.49789 .44539 L
.49807 .44469 L
.49844 .44264 L
.49885 .43944 L
.49927 .43508 L
.49967 .43006 L
.50115 .40401 L
.50278 .36396 L
.50427 .32021 L
.50592 .26864 L
.50745 .22319 L
.50821 .20317 L
.50903 .18418 L
.50976 .17025 L
.51052 .15882 L
.51093 .15422 L
.51114 .15224 L
.51138 .15047 L
.51159 .14917 L
.51179 .14827 L
.51188 .14793 L
.51198 .14763 L
.51208 .14742 L
.51217 .14728 L
.51225 .14721 L
.51234 .14718 L
.51243 .14722 L
.51251 .14729 L
.5126 .14744 L
.5127 .14766 L
.5128 .14796 L
.51289 .14831 L
.51309 .14924 L
Mistroke
.51326 .15033 L
.51366 .1536 L
.51405 .15791 L
.51446 .16363 L
.5152 .1768 L
.51687 .21881 L
.51991 .32383 L
.5216 .38508 L
.52315 .4339 L
.52391 .45365 L
.52475 .4709 L
.52513 .47712 L
.52554 .48252 L
.52573 .48467 L
.52592 .4864 L
.52609 .48772 L
.52627 .48887 L
.52637 .4894 L
.52646 .48981 L
.52655 .49015 L
.52664 .4904 L
.52674 .49061 L
.5268 .49068 L
.52685 .49073 L
.52695 .49075 L
.52705 .49069 L
.5271 .49062 L
.52716 .49053 L
.52726 .49029 L
.52736 .48994 L
.52748 .48944 L
.52769 .48826 L
.52788 .48683 L
.52826 .48313 L
.5286 .47873 L
.52936 .46538 L
.53017 .44649 L
.53091 .42512 L
.53258 .36575 L
.53575 .23616 L
.53734 .17874 L
.53803 .15807 L
.53879 .13954 L
.53921 .13131 L
.53959 .12502 L
.53996 .12027 L
.54017 .11818 L
.54036 .11661 L
.54055 .11532 L
.54066 .11479 L
Mistroke
.54077 .11435 L
.54086 .11405 L
.54095 .11386 L
.54105 .11374 L
.54115 .11371 L
.54121 .11374 L
.54127 .1138 L
.54133 .1139 L
.54139 .11405 L
.5415 .11438 L
.54161 .11487 L
.54183 .11613 L
.54203 .11772 L
.54243 .12202 L
.54287 .12843 L
.54366 .14456 L
.54443 .16538 L
.54515 .1887 L
.54829 .32011 L
.54989 .3905 L
.55074 .42401 L
.55163 .45492 L
.55243 .47768 L
.55285 .48754 L
.55331 .49626 L
.55372 .50251 L
.5541 .50668 L
.55429 .50816 L
.55438 .5088 L
.55449 .50937 L
.55457 .50978 L
.55467 .51013 L
.55476 .51036 L
.55485 .5105 L
.55494 .51057 L
.55504 .51053 L
.55514 .5104 L
.55522 .5102 L
.55533 .50986 L
.55544 .50936 L
.55564 .50814 L
.55585 .5064 L
.55607 .50405 L
.55647 .49857 L
.55718 .48493 L
.55795 .46453 L
.55952 .40914 L
.56119 .3353 L
.56278 .26153 L
.56451 .18873 L
Mistroke
.56531 .16086 L
.56617 .13697 L
.56658 .12779 L
.56697 .12073 L
.56732 .11574 L
.56752 .11349 L
.5677 .11182 L
.56789 .11043 L
.568 .10984 L
.5681 .10939 L
.56819 .10908 L
.56828 .10887 L
.56837 .10873 L
.56847 .10869 L
.56857 .10876 L
.56862 .10885 L
.56867 .10896 L
.56877 .10925 L
.56887 .10963 L
.56908 .11083 L
.5692 .11173 L
.56931 .1127 L
.56974 .11773 L
.57013 .12398 L
.571 .14354 L
.5718 .16774 L
.57254 .19448 L
.57422 .26606 L
.57585 .34231 L
.57738 .40869 L
.57885 .45968 L
.57928 .47109 L
.57968 .48033 L
.58007 .48774 L
.58043 .49327 L
.5808 .49742 L
.58099 .49902 L
.5811 .49968 L
.58121 .50028 L
.58131 .50073 L
.58141 .50103 L
.58147 .50115 L
.58152 .50123 L
.58158 .50128 L
.58163 .5013 L
.58173 .50125 L
.58182 .5011 L
.58192 .50084 L
.58203 .50044 L
.5822 .4995 L
Mistroke
.58239 .49811 L
.58273 .49463 L
.58314 .48888 L
.58351 .48214 L
.5843 .46322 L
.58503 .44074 L
.5867 .37632 L
.58984 .23769 L
.59067 .20561 L
.59156 .17602 L
.59197 .16457 L
.59241 .15413 L
.59281 .14598 L
.59318 .13999 L
.59337 .13749 L
.59357 .13519 L
.59375 .13356 L
.59395 .13215 L
.59405 .13155 L
.59415 .1311 L
.59426 .13074 L
.59432 .13059 L
.59437 .13048 L
.59446 .13038 L
.59456 .13037 L
.59467 .13048 L
.59476 .13068 L
.59485 .13097 L
.59495 .13138 L
.59514 .13241 L
.59531 .13374 L
.59547 .13526 L
.59584 .13974 L
.59623 .14597 L
.59699 .16225 L
.59781 .18523 L
.59928 .23793 L
.60087 .30376 L
.6026 .37427 L
.6034 .40309 L
.60425 .42919 L
.60498 .44692 L
.60537 .45438 L
.60579 .46093 L
.60618 .46548 L
.6064 .46731 L
.6065 .46802 L
.6066 .4686 L
.60669 .46904 L
.60679 .46943 L
Mistroke
.60688 .4697 L
.60696 .46988 L
.60705 .47 L
.60714 .47003 L
.60725 .46996 L
.60734 .4698 L
.60744 .46953 L
.60756 .4691 L
.60766 .46858 L
.60776 .468 L
.60815 .4648 L
.60837 .46233 L
.60857 .45968 L
.60901 .45242 L
.60982 .43499 L
.61056 .41462 L
.61223 .3575 L
.61387 .29495 L
.6154 .24033 L
.61616 .21731 L
.61687 .19894 L
.61727 .19045 L
.6177 .18266 L
.61806 .17735 L
.61826 .17487 L
.61845 .17292 L
.61864 .17127 L
.61884 .1699 L
.61901 .169 L
.61911 .16861 L
.61921 .16834 L
.61926 .16822 L
.61931 .16812 L
.61942 .16801 L
.61952 .16799 L
.61961 .16806 L
.61971 .16823 L
.61976 .16836 L
.61982 .16851 L
.61992 .1689 L
.62004 .16943 L
.62025 .17076 L
.62049 .17268 L
.62092 .17743 L
.62134 .18355 L
.62172 .19046 L
.62338 .23128 L
.62487 .27894 L
.62655 .33527 L
.62809 .38095 L
Mistroke
.62887 .39947 L
.6296 .41307 L
.62997 .41845 L
.63036 .42303 L
.63058 .42509 L
.63079 .42667 L
.63098 .42776 L
.63109 .42825 L
.63119 .42862 L
.63129 .4289 L
.63138 .42909 L
.63148 .42922 L
.63158 .42927 L
.63167 .42924 L
.63177 .42913 L
.63186 .42895 L
.63195 .42873 L
.63206 .42837 L
.63215 .42795 L
.63238 .42672 L
.63257 .4253 L
.63278 .42348 L
.6332 .41885 L
.63359 .4134 L
.63447 .39732 L
.6361 .35716 L
.63759 .31442 L
.63925 .26828 L
.63998 .25066 L
.64079 .23418 L
.64116 .22786 L
.64156 .222 L
.6419 .21778 L
.64228 .21409 L
.64247 .21257 L
.64268 .21125 L
.6428 .21065 L
.6429 .21019 L
.64301 .2098 L
.6431 .20951 L
.6432 .20931 L
.64329 .20915 L
.64339 .20907 L
.64344 .20905 L
.64349 .20905 L
.64359 .2091 L
.64367 .2092 L
.64377 .20937 L
.64386 .20961 L
.64396 .20992 L
Mistroke
.64407 .21034 L
.64427 .21131 L
.64463 .21382 L
.64506 .21786 L
.64545 .22257 L
.64693 .24761 L
.6501 .32179 L
.6517 .35609 L
.6524 .36811 L
.65315 .37849 L
.65357 .38288 L
.65396 .38605 L
.65433 .38824 L
.65451 .38904 L
.65461 .38937 L
.65472 .38967 L
.65483 .38989 L
.65488 .38999 L
.65494 .39006 L
.65503 .39014 L
.65514 .39016 L
.6552 .39015 L
.65526 .39011 L
.65532 .39005 L
.65537 .38998 L
.65548 .38979 L
.65559 .38953 L
.65579 .38886 L
.65597 .38803 L
.6564 .3854 L
.6568 .38203 L
.65724 .37743 L
.65803 .36686 L
.65952 .34118 L
.66124 .30727 L
.66279 .27862 L
.66357 .26661 L
.66441 .25624 L
.6648 .25251 L
.66521 .24933 L
.66555 .24725 L
.66575 .24634 L
.66594 .24566 L
.66604 .24536 L
.66615 .2451 L
.66624 .24492 L
.66634 .24477 L
.6664 .24471 L
.66645 .24467 L
.66651 .24464 L
Mistroke
.66657 .24463 L
.66667 .24464 L
.66672 .24468 L
.66678 .24472 L
.66688 .24485 L
.66698 .24502 L
.66716 .24546 L
.66736 .24611 L
.66757 .24702 L
.66795 .24914 L
.66835 .25205 L
.66907 .25885 L
.67064 .27946 L
.67211 .3025 L
.67361 .32552 L
.6744 .33617 L
.67524 .34565 L
.67566 .34955 L
.67612 .35312 L
.67654 .35566 L
.67694 .3574 L
.67714 .35804 L
.67725 .35832 L
.67735 .35854 L
.67744 .3587 L
.67752 .35883 L
.67762 .35893 L
.67772 .359 L
.67777 .35902 L
.67783 .35903 L
.67792 .35901 L
.67798 .35899 L
.67803 .35895 L
.67809 .3589 L
.67815 .35884 L
.67826 .35868 L
.67836 .35849 L
.67856 .35802 L
.67876 .35736 L
.67896 .35659 L
.67933 .35478 L
.68015 .34912 L
.68086 .34268 L
.68163 .33447 L
.6832 .31535 L
.68492 .29475 L
.68571 .28667 L
.68656 .27961 L
.68697 .27688 L
.68736 .27475 L
Mistroke
.68771 .27324 L
.68809 .27202 L
.68828 .27159 L
.68838 .27141 L
.68848 .27125 L
.68858 .27114 L
.68868 .27105 L
.68877 .271 L
.68885 .27097 L
.6889 .27096 L
.68896 .27097 L
.68906 .271 L
.68916 .27106 L
.68925 .27114 L
.68935 .27126 L
.68946 .27143 L
.68968 .27188 L
.6899 .27246 L
.69011 .27312 L
.69056 .275 L
.69137 .27969 L
.6929 .29194 L
.69457 .30769 L
.69612 .32153 L
.69695 .3276 L
.69738 .33028 L
.69784 .33268 L
.69824 .33441 L
.69846 .33517 L
.69868 .33587 L
.6989 .33639 L
.69909 .33678 L
.69918 .33693 L
.69928 .33707 L
.69937 .33718 L
.69946 .33727 L
.69956 .33734 L
.69964 .33738 L
.69975 .33741 L
.69985 .33742 L
.69995 .33739 L
.7 .33737 L
.70006 .33734 L
.70015 .33728 L
.70025 .33718 L
.70045 .33693 L
.70064 .33661 L
.70099 .3358 L
.70136 .33464 L
.70177 .33305 L
Mistroke
.7026 .32894 L
.70408 .31942 L
.70578 .30728 L
.70733 .29748 L
.7081 .29367 L
.7085 .29203 L
.70893 .29059 L
.70931 .28961 L
.70951 .2892 L
.70972 .28883 L
.70992 .28857 L
.71001 .28847 L
.7101 .28839 L
.71018 .28833 L
.71027 .28828 L
.71037 .28824 L
.71045 .28822 L
.71055 .28821 L
.71061 .28822 L
.71066 .28823 L
.71077 .28826 L
.71083 .28829 L
.71088 .28832 L
.71098 .28839 L
.71108 .28848 L
.71128 .2887 L
.7115 .28903 L
.71174 .28948 L
.71217 .29052 L
.71302 .29333 L
.71379 .2966 L
.71547 .30515 L
.71701 .31312 L
.71852 .31943 L
.71928 .32169 L
.71971 .32264 L
.72011 .3233 L
.72032 .32356 L
.72051 .32375 L
.72062 .32383 L
.72072 .32389 L
.72083 .32394 L
.72089 .32396 L
.72095 .32397 L
.72105 .32399 L
.72111 .32399 L
.72116 .32399 L
.72126 .32398 L
.72137 .32395 L
.72147 .3239 L
Mistroke
.72156 .32385 L
.72175 .32372 L
.72193 .32355 L
.72212 .32332 L
.72246 .3228 L
.72324 .32114 L
.724 .31897 L
.72481 .31619 L
.72628 .3106 L
.72787 .30483 L
.72871 .30232 L
.72917 .30117 L
.7296 .30027 L
.73001 .29956 L
.73039 .29906 L
.7306 .29885 L
.73081 .29867 L
.73103 .29854 L
.73115 .29849 L
.73121 .29847 L
.73126 .29845 L
.73136 .29843 L
.73146 .29842 L
.73155 .29842 L
.73165 .29843 L
.73174 .29844 L
.73182 .29846 L
.73191 .29849 L
.73201 .29853 L
.73222 .29866 L
.73242 .29881 L
.7328 .2992 L
.7332 .29974 L
.73357 .30034 L
.73439 .30202 L
.73587 .30578 L
.73755 .31033 L
.73828 .31212 L
.73909 .3138 L
.73946 .31446 L
.73987 .31507 L
.74022 .3155 L
.74059 .31588 L
.74082 .31606 L
.74102 .31618 L
.74122 .31628 L
.74132 .31632 L
.74143 .31635 L
.74152 .31637 L
.74161 .31638 L
Mistroke
.74171 .31639 L
.74182 .31639 L
.74191 .31639 L
.74199 .31638 L
.74209 .31636 L
.74218 .31634 L
.74228 .31631 L
.74239 .31627 L
.74261 .31616 L
.74301 .31589 L
.74347 .31545 L
.7439 .31494 L
.74552 .31233 L
.74701 .30948 L
.74864 .30661 L
.74952 .3054 L
.74991 .30498 L
.75034 .30459 L
.75074 .30431 L
.75093 .30421 L
.75112 .30412 L
.75133 .30404 L
.75142 .30402 L
.75152 .304 L
.75158 .30399 L
.75163 .30398 L
.75173 .30397 L
.75178 .30396 L
.75184 .30396 L
.7519 .30396 L
.75195 .30396 L
.75205 .30396 L
.75215 .30397 L
.75223 .30398 L
.75233 .304 L
.75254 .30405 L
.75273 .30412 L
.75308 .30429 L
.75346 .30452 L
.75433 .30527 L
.75511 .30614 L
.75679 .30832 L
.75833 .31026 L
.75911 .31107 L
.75983 .31168 L
.76023 .31194 L
.76059 .31213 L
.76099 .31229 L
.76122 .31235 L
.76132 .31237 L
Mistroke
.76142 .31239 L
.76152 .31241 L
.76161 .31242 L
.7617 .31243 L
.76179 .31243 L
.76189 .31243 L
.76199 .31243 L
.76209 .31243 L
.76215 .31242 L
.7622 .31242 L
.76231 .31241 L
.7624 .31239 L
.76262 .31235 L
.76282 .31229 L
.76302 .31222 L
.76373 .3119 L
.7645 .31139 L
.76619 .30997 L
.76774 .3086 L
.76851 .30799 L
.76934 .30745 L
.76972 .30725 L
.77013 .30707 L
.77051 .30693 L
.77086 .30684 L
.77104 .3068 L
.77125 .30677 L
.77135 .30676 L
.77141 .30676 L
.77146 .30675 L
.77157 .30675 L
.77166 .30674 L
.77175 .30674 L
.77185 .30674 L
.77193 .30675 L
.77202 .30675 L
.77212 .30676 L
.77222 .30677 L
.77241 .30679 L
.77261 .30683 L
.77283 .30687 L
.77328 .307 L
.77408 .30732 L
.77566 .30817 L
.77734 .30918 L
.77816 .30963 L
.77905 .31003 L
.77946 .31017 L
.7799 .3103 L
.78027 .31039 L
Mistroke
.78048 .31043 L
.78067 .31046 L
.78087 .31048 L
.78098 .31049 L
.78109 .3105 L
.78119 .3105 L
.78129 .31051 L
.78139 .31051 L
.78144 .31051 L
.78149 .31051 L
.78158 .31051 L
.78167 .31051 L
.78176 .31051 L
.78185 .3105 L
.78196 .31049 L
.78206 .31049 L
.78224 .31047 L
.78244 .31044 L
.78266 .31041 L
.78304 .31033 L
.78392 .31009 L
.78696 .30893 L
.78775 .30864 L
.78851 .30841 L
.78893 .30831 L
.78939 .30821 L
.78981 .30814 L
.79019 .30809 L
.7904 .30808 L
.7906 .30806 L
.7907 .30806 L
.79081 .30805 L
.79087 .30805 L
.79093 .30805 L
.79099 .30805 L
.79104 .30805 L
.79114 .30805 L
.79124 .30805 L
.79134 .30805 L
.79139 .30805 L
.79145 .30806 L
.79165 .30806 L
.79184 .30808 L
.79222 .30811 L
.79256 .30815 L
.79333 .30829 L
.79485 .30864 L
.79652 .30907 L
.79733 .30926 L
.79809 .30941 L
Mistroke
.79852 .30948 L
.79897 .30954 L
.79939 .30958 L
.79959 .3096 L
.79977 .30961 L
.79997 .30962 L
.80015 .30963 L
.80025 .30963 L
.80034 .30963 L
.80044 .30964 L
.8005 .30964 L
.80055 .30964 L
.80065 .30964 L
.80073 .30964 L
.80083 .30963 L
.80093 .30963 L
.80102 .30963 L
.8011 .30963 L
.80128 .30962 L
.8015 .30961 L
.8017 .3096 L
.80208 .30956 L
.80294 .30947 L
.80602 .30897 L
.80684 .30885 L
.80761 .30876 L
.80803 .30871 L
.80842 .30868 L
.80884 .30866 L
.80908 .30864 L
.8093 .30864 L
.8094 .30863 L
.80951 .30863 L
.8096 .30863 L
.80971 .30863 L
.8098 .30863 L
.8099 .30863 L
.80999 .30863 L
.81007 .30863 L
.81012 .30863 L
.81018 .30863 L
.81028 .30863 L
.81038 .30863 L
.81047 .30863 L
.81067 .30864 L
.81089 .30864 L
.81125 .30866 L
.81159 .30868 L
.81237 .30874 L
.81547 .30906 L
Mistroke
.8163 .30913 L
.81708 .30919 L
.8175 .30922 L
.81789 .30923 L
.81832 .30925 L
.81855 .30925 L
.81866 .30926 L
.81877 .30926 L
.81887 .30926 L
.81897 .30926 L
.81906 .30926 L
.81914 .30926 L
.81925 .30926 L
.81934 .30926 L
.81944 .30926 L
.8195 .30926 L
.81955 .30926 L
.81966 .30926 L
.81976 .30926 L
.81998 .30925 L
.82017 .30925 L
.82038 .30924 L
.82109 .30922 L
.82186 .30918 L
.82356 .30907 L
.82511 .30897 L
.82588 .30893 L
.82628 .30891 L
.82672 .30889 L
.82709 .30888 L
.82729 .30888 L
.82751 .30887 L
.8277 .30887 L
.82788 .30887 L
.82805 .30887 L
.82814 .30887 L
.82824 .30887 L
.82829 .30887 L
.82834 .30887 L
.82844 .30887 L
.82855 .30887 L
.82861 .30887 L
.82866 .30887 L
.82876 .30887 L
.82885 .30887 L
.82906 .30887 L
.82925 .30887 L
.82945 .30888 L
.82981 .30888 L
.83069 .30891 L
Mistroke
.83149 .30894 L
.83312 .309 L
.83391 .30904 L
.83464 .30906 L
.83535 .30908 L
.83571 .30909 L
.8361 .3091 L
.8363 .3091 L
.83649 .3091 L
.83668 .30911 L
.83685 .30911 L
.83705 .30911 L
.83716 .30911 L
.83721 .30911 L
.83727 .30911 L
.83737 .30911 L
.83746 .30911 L
.83752 .30911 L
.83757 .30911 L
.83767 .30911 L
.83777 .30911 L
.83783 .30911 L
.83788 .30911 L
.83807 .30911 L
.83825 .30911 L
.83844 .3091 L
.83883 .3091 L
.83926 .30909 L
.84074 .30906 L
.84244 .30902 L
.84324 .309 L
.84398 .30898 L
.84475 .30897 L
.84516 .30897 L
.84536 .30897 L
.84559 .30896 L
.84578 .30896 L
.84596 .30896 L
.84605 .30896 L
.84613 .30896 L
.84622 .30896 L
.84631 .30896 L
.84641 .30896 L
.84651 .30896 L
.8466 .30896 L
.8467 .30896 L
.8468 .30896 L
.84691 .30896 L
.84711 .30896 L
.84731 .30896 L
Mistroke
.8475 .30896 L
.84787 .30897 L
.84868 .30898 L
.85015 .309 L
.85176 .30902 L
.85246 .30903 L
.85322 .30904 L
.85365 .30904 L
.85404 .30905 L
.85441 .30905 L
.8546 .30905 L
.8548 .30905 L
.85492 .30905 L
.85502 .30905 L
.85512 .30905 L
.85522 .30905 L
.85528 .30905 L
.85534 .30905 L
.8554 .30905 L
.85546 .30905 L
.85556 .30905 L
.85562 .30905 L
.85568 .30905 L
.85587 .30905 L
.85599 .30905 L
.85609 .30905 L
.85649 .30905 L
.8569 .30905 L
.85734 .30904 L
.85813 .30904 L
.85963 .30902 L
.8612 .30901 L
.86163 .30901 L
.86209 .309 L
.86252 .309 L
.86292 .309 L
.86311 .309 L
.86332 .309 L
.86354 .309 L
.86366 .309 L
.86377 .309 L
.86387 .309 L
.86397 .309 L
.86406 .309 L
.86416 .309 L
.86426 .309 L
.86432 .309 L
.86437 .309 L
.86448 .309 L
.86457 .309 L
Mistroke
.86476 .309 L
.86495 .309 L
.8653 .309 L
.86567 .309 L
.86609 .309 L
.86778 .30901 L
.86932 .30902 L
.87009 .30902 L
.87049 .30902 L
.87092 .30903 L
.87133 .30903 L
.87171 .30903 L
.87189 .30903 L
.87208 .30903 L
.87227 .30903 L
.87244 .30903 L
.87254 .30903 L
.87263 .30903 L
.87272 .30903 L
.87281 .30903 L
.87292 .30903 L
.87297 .30903 L
.87303 .30903 L
.87313 .30903 L
.87322 .30903 L
.8734 .30903 L
.87357 .30903 L
.87395 .30903 L
.87434 .30903 L
.87476 .30903 L
.87561 .30902 L
.87732 .30902 L
.87887 .30901 L
.87964 .30901 L
.88008 .30901 L
.88029 .30901 L
.88048 .30901 L
.88067 .30901 L
.88083 .30901 L
.88102 .30901 L
.88112 .30901 L
.88122 .30901 L
.88132 .30901 L
.88142 .30901 L
.8815 .30901 L
.8816 .30901 L
.8817 .30901 L
.88175 .30901 L
.88181 .30901 L
.882 .30901 L
Mistroke
.8822 .30901 L
.88238 .30901 L
.88279 .30901 L
.88352 .30901 L
.88518 .30902 L
.88599 .30902 L
.88685 .30902 L
.88764 .30902 L
.88803 .30902 L
.88839 .30902 L
.88875 .30902 L
.88909 .30902 L
.88928 .30902 L
.88946 .30902 L
.88956 .30902 L
.88965 .30902 L
.88975 .30902 L
.88985 .30902 L
.88995 .30902 L
.89005 .30902 L
.8901 .30902 L
.89016 .30902 L
.89026 .30902 L
.89036 .30902 L
.89045 .30902 L
.89063 .30902 L
.89084 .30902 L
.89103 .30902 L
.89147 .30902 L
.89224 .30902 L
.89297 .30902 L
.89462 .30902 L
.89541 .30902 L
.89624 .30902 L
.89658 .30902 L
.89695 .30902 L
.89716 .30902 L
.89735 .30901 L
.89755 .30901 L
.89773 .30901 L
.89791 .30901 L
.89801 .30901 L
.89812 .30901 L
.89817 .30901 L
.89823 .30901 L
.89833 .30901 L
.89843 .30901 L
.89853 .30901 L
.89862 .30901 L
.89872 .30901 L
Mistroke
.8988 .30901 L
.89889 .30901 L
.89908 .30901 L
.89927 .30901 L
.89965 .30902 L
.90008 .30902 L
.90094 .30902 L
.90264 .30902 L
.90418 .30902 L
.90496 .30902 L
.90539 .30902 L
.9056 .30902 L
.90579 .30902 L
.90598 .30902 L
.90614 .30902 L
.90633 .30902 L
.90643 .30902 L
.90653 .30902 L
.90662 .30902 L
.90672 .30902 L
.90682 .30902 L
.9069 .30902 L
.907 .30902 L
.90706 .30902 L
.90711 .30902 L
.90731 .30902 L
.90751 .30902 L
.90769 .30902 L
.90809 .30902 L
.90882 .30902 L
.91048 .30902 L
.91128 .30902 L
.91214 .30902 L
.91287 .30902 L
.91329 .30902 L
.91368 .30902 L
.91405 .30902 L
.91423 .30902 L
.91444 .30902 L
.91454 .30902 L
.91464 .30902 L
.9147 .30902 L
.91476 .30902 L
.91486 .30902 L
.91496 .30902 L
.91507 .30902 L
.91516 .30902 L
.91526 .30902 L
.91536 .30902 L
.91545 .30902 L
Mistroke
.91563 .30902 L
.91582 .30902 L
.91603 .30902 L
.9164 .30902 L
.91675 .30902 L
.9184 .30902 L
.91989 .30902 L
.92064 .30902 L
.92144 .30902 L
.92185 .30902 L
.92207 .30902 L
.92231 .30902 L
.92253 .30902 L
.92272 .30902 L
.92282 .30902 L
.92292 .30902 L
.92302 .30902 L
.92311 .30902 L
.9232 .30902 L
.9233 .30902 L
.92339 .30902 L
.92348 .30902 L
.92358 .30902 L
.92369 .30902 L
.92388 .30902 L
.92408 .30902 L
.92426 .30902 L
.92461 .30902 L
.9254 .30902 L
.92626 .30902 L
.92783 .30902 L
.92866 .30902 L
.92912 .30902 L
.92955 .30902 L
.92996 .30902 L
.93017 .30902 L
.9304 .30902 L
.93062 .30902 L
.93081 .30902 L
.9309 .30902 L
.931 .30902 L
.9311 .30902 L
.93118 .30902 L
.93127 .30902 L
.93137 .30902 L
.93146 .30902 L
.93154 .30902 L
.93164 .30902 L
.93174 .30902 L
.93184 .30902 L
Mistroke
.93193 .30902 L
.93211 .30902 L
.93231 .30902 L
.93271 .30902 L
.93353 .30902 L
.93427 .30902 L
.93595 .30902 L
.93668 .30902 L
.93747 .30902 L
.93792 .30902 L
.93833 .30902 L
.93853 .30902 L
.93874 .30902 L
.93884 .30902 L
.93895 .30902 L
.93904 .30902 L
.93913 .30902 L
.93923 .30902 L
.93928 .30902 L
.93934 .30902 L
.93943 .30902 L
.93953 .30902 L
.93962 .30902 L
.93972 .30902 L
.93981 .30902 L
.93989 .30902 L
.94008 .30902 L
.94029 .30902 L
.94071 .30902 L
.94108 .30902 L
.94147 .30902 L
.94218 .30902 L
.94378 .30902 L
.94462 .30902 L
.94508 .30902 L
.94551 .30902 L
.94593 .30902 L
.9463 .30902 L
.94652 .30902 L
.94673 .30902 L
.94694 .30902 L
.94707 .30902 L
.94712 .30902 L
.94718 .30902 L
.94728 .30902 L
.94738 .30902 L
.94747 .30902 L
.94757 .30902 L
.94766 .30902 L
.94774 .30902 L
Mistroke
.94783 .30902 L
.94792 .30902 L
.94814 .30902 L
.94834 .30902 L
.94872 .30902 L
.94949 .30902 L
.95032 .30902 L
.9518 .30902 L
.95255 .30902 L
.95295 .30902 L
.95336 .30902 L
.95373 .30902 L
.95413 .30902 L
.95431 .30902 L
.95449 .30902 L
.95465 .30902 L
.95483 .30902 L
.95494 .30902 L
.95504 .30902 L
.95515 .30902 L
.95521 .30902 L
.95526 .30902 L
.95536 .30902 L
.95546 .30902 L
.95556 .30902 L
.95566 .30902 L
.95576 .30902 L
.95586 .30902 L
.95609 .30902 L
.95631 .30902 L
.95655 .30902 L
.95739 .30902 L
.95817 .30902 L
.95981 .30902 L
.96061 .30902 L
.96134 .30902 L
.96171 .30902 L
.9621 .30902 L
.96228 .30902 L
.96248 .30902 L
.96264 .30902 L
.96282 .30902 L
.96292 .30902 L
.96302 .30902 L
.96311 .30902 L
.96321 .30902 L
.96332 .30902 L
.96338 .30902 L
.96343 .30902 L
.96354 .30902 L
Mistroke
.96363 .30902 L
.96373 .30902 L
.96383 .30902 L
.964 .30902 L
.9644 .30902 L
.9648 .30902 L
.96516 .30902 L
.96598 .30902 L
.96745 .30902 L
.96819 .30902 L
.96898 .30902 L
.96939 .30902 L
.96961 .30902 L
.96985 .30902 L
.97006 .30902 L
.97026 .30902 L
.97045 .30902 L
.97065 .30902 L
.97075 .30902 L
.9708 .30902 L
.97085 .30902 L
.97095 .30902 L
.97105 .30902 L
.97114 .30902 L
.97122 .30902 L
.97131 .30902 L
.97141 .30902 L
.97152 .30902 L
.97163 .30902 L
.97184 .30902 L
.97223 .30902 L
.9726 .30902 L
.973 .30902 L
.97371 .30902 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{421.375, 260.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008>0001AB000`400?l00000o`00003ooooooooo
oooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo
003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooo
oooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool0
0?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooooooo
ool@ooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooo
ooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo0ol0003o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0
003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo
00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`
ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLoooo
o`00<?ooool3o`000?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?oo
ool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0
033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomco
oooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooo
oooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool3o`000?oooooo
g?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0013ooooo0_o^k^h3ooooo`;ok^k^6Oooool00ol0003oooooooooo`3o
ooooomcooooo000;ooooo`;o000000[o410@ooooooooooook^k^oeEEEOo^k^koooooonk^k_mEEEGo
k^k^0oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h:ooooo`03o`000?oo
oooooooo0?oooooog?ooool000cooooo00?o0000ooooooooool00_ooool01Oo^k^koEEEEomgMgOmE
EEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00[ooooo
00?o0000ooooooooool0oooooooLooooo`0000?oooooo`000?l000001?l00002ooooo`Go00001?oo
ool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooo
oa0@400:ooooo`03o`000?oooooooooo0?oooooog?ooool000Wooooo00CoA4A4omgMgOoooooo0000
1?ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000000[ooooo00?o0000ooooooooool0oooooooLooooo`002Oooool01?oMgMgo
EEEEooooool00003ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000:ooooo`Co0000oooooooKooooo`002_oo
ool00omgMgOoc<c<o`000003ooooo`;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@00[ooooo00?o0000ooooooooool0oooooooLooooo`002_oo
ool00oo^k^koA4A4o`00000?ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`;o00001Oooool00ol0003oooooooooo`3oooooomcooooo000;ooooo`03ogMgMol0
003ooooo00cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`3oooooomcooooo000Xooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool0oooooooLooooo`00:?ooool3o`0000Gooooo
00?o0000ooooooooool0oooooooLooooo`00:Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo0?oooooog?ooool002[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`34
ooooo`03o`000?oooooooooo0?oooooo5Oooool0033ooooo00?o0000ooooooooool0a?ooool00ol0
003oooooooooo`3ooooooaGooooo000`ooooo`03o`000?oooooooooo0;Sooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`3ooooooaGooooo000`ooooo`03o`000?oooooooooo0;Sooooo
00?o0000ooooooooool02?ooool2o`000?oooooo5oooool0033ooooo00?o0000ooooooooool0^?oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooo00000?oooooo5_ooool0033ooooo0ol0002h
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooool00000oooooolFooooo`00<?ooool00ol0
003oooooooooo`2hooooo`;o00002Oooool00ol0003oooooo`00003ooooooaKooooo000`ooooo`03
o`000?oooooooooo0;Oooooo00?o0000ooooool000002Oooool00ol0003oooooo`00003ooooooaKo
oooo000`ooooo`03o`000?oooooooooo0;Oooooo00?o0000ooooool000002Oooool00ol0003ooooo
o`00003ooooooaKooooo000`ooooo`03o`000?oooooooooo0;Oooooo00?o0000ooooool000002Ooo
ool00ol0003oooooo`00003ooooooaKooooo000`ooooo`03o`000?oooooooooo0;Oooooo00?o0000
ooooool000002Oooool00ol0003oooooo`000009ooooo`03o`000?oooooooooo0?oooooo2_ooool0
033ooooo00?o0000ooooooooool0]oooool00ol0003oooooo`000009ooooo`03o`000?oooooo0000
00Wooooo0_l0003oooooo`_ooooo000`ooooo`03o`000?oooooooooo0;Oooooo00?o0000ooooool0
00002Oooool00ol0003oooooo`000009ooooo`;o0000ooooool;ooooo`00<?ooool00ol0003ooooo
ooooo`2gooooo`03o`000?oooooo000000Wooooo00?o0000ooooool000002Oooool2o`000?oooooo
2oooool0033ooooo00?o0000ooooooooool0]oooool00ol0003oooooo`000009ooooo`03o`000?oo
oooo000000Wooooo0_l0003oooooo`_ooooo000`ooooo`03o`000?oooooooooo0;Oooooo00?o0000
ooooool000002Oooool00ol0003oooooo`000009ooooo`;o0000ooooool;ooooo`00<?ooool00ol0
003oooooooooo`2gooooo`03o`000?oooooo000000Wooooo00?o0000ooooool000002Oooool2o`00
0?oooooo2oooool0033ooooo0ol0002[ooooo`;o00002_ooool00ol0003oooooo`000009ooooo`03
o`000?oooooo000000Wooooo0_l0003oooooo`_ooooo000`ooooo`03o`000?oooooooooo0:_ooooo
0_l0000:ooooo`03o`000?oooooo000000Wooooo00?o0000ooooool000002Oooool2o`000?oooooo
2oooool0033ooooo00?o0000ooooooooool0Zoooool2o`0000[ooooo00?o0000ooooool000002Ooo
ool00ol0003oooooo`000008ooooo`03o`000?oooooo00000?oooooo2oooool0033ooooo00?o0000
ooooooooool0Zoooool2o`0000[ooooo00?o0000ooooool000002Oooool00ol0003oooooo`000008
ooooo`03o`000?oooooo00000?oooooo2oooool0033ooooo00?o0000ooooooooool0Zoooool2o`00
00[ooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`000008ooooo`03o`000?oooooo
00000?oooooo2oooool0033ooooo00?o0000ooooooooool0Zoooool2o`0000[ooooo00Co0000oooo
oooooooo00002?ooool00ol0003oooooo`000008ooooo`03o`000?oooooo00000?oooooo2oooool0
033ooooo00?o0000ooooooooool0Zoooool2o`0000[ooooo00Co0000oooooooooooo00002?ooool0
0ol0003oooooo`000008ooooo`03o`000?oooooo00000?oooooo2oooool0033ooooo00?o0000oooo
ooooool0Zoooool00ol0003oooooo`000009ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000
ooooool000002?ooool00ol0003oooooo`00003oooooo`_ooooo000`ooooo`03o`000?oooooooooo
0:[ooooo00Co0000oooooooooooo00002Oooool01?l0003oooooooooool00008ooooo`03o`000?oo
oooo000000Sooooo00?o0000ooooool00000ooooool;ooooo`00<?ooool00ol0003oooooooooo`2Z
ooooo`04o`000?ooooooooooo`0000Wooooo00Co0000oooooooooooo00002?ooool00ol0003ooooo
o`000008ooooo`03o`000?oooooo000000Wooooo00?o0000ooooooooool0o_ooool0033ooooo00?o
0000ooooooooool0Z_ooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool0
00002?ooool00ol0003oooooo`000008ooooo`03o`000?oooooo000000Wooooo00?o0000oooooooo
ool0o_ooool0033ooooo0ol0002Zooooo`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooo
ooooooooo`000008ooooo`03o`000?oooooo000000Sooooo00?o0000ooooool000002Oooool2o`00
0?oooooo000`ooooo`03o`000?oooooooooo0:[ooooo00Co0000oooooooooooo00002?ooool01Ol0
003ooooooooooooooooo000000Sooooo00?o0000ooooool000002?ooool00ol0003oooooo`000009
ooooo`;o0000ooooool0033ooooo00?o0000ooooooooool0Z_ooool01?l0003oooooooooool00008
ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool00008ooooo`04o`00
0?ooooooooooo`0000Oooooo00?o0000ooooool00000ooooool0033ooooo00?o0000ooooooooool0
Z_ooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool000001oooool01?l0
003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool00000oooo
ool0033ooooo00?o0000ooooooooool0Z_ooool01?l0003oooooooooool00008ooooo`05o`000?oo
ooooooooooooool000001oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00
00Oooooo00?o0000ooooool00000ooooool0033ooooo00?o0000ooooooooool0Z_ooool01?l0003o
ooooooooool00008ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooo
oooo000000Oooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00003oooooo`00<?oo
ool00ol0003oooooooooo`2Zooooo`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooooooo
ooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool00007
ooooo`03o`000?oooooo00000?oooooo000@ooooo`;ok^k^0oooool2onk^kQWooooo00?o0000oooo
ooooool0Z_ooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool000001ooo
ool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo00001oooool00ol0003o
ooooo`00003oooooo`002Oooool5o`0000;ooooo00Ook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^
00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^2_ooool00ol0003ooooo
ooooo`2Zooooo`04o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000007oooo
o`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool00007ooooo`03o`000?oo
oooo00000?oooooo0009ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01Oo^k^koEEEEomgM
gOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00[o
oooo00?o0000ooooooooool0Z_ooool01?l0003oooooooooool00008ooooo`05o`000?oooooooooo
ooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000
1oooool00ol0003oooooo`00003oooooo`0000?oooooo`000?l000001?l00003ooooo`03oiRHV?lQ
8B7ok^k^00Gooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?oo
ooooooooooooool@41002_ooool00ol0003oooooooooo`2Zooooo`04o`000?ooooooooooo`0000So
oooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool0
1?l0003oooooooooool00007ooooo`03o`000?oooooo00000?oooooo000;ooooo`03oiRHV?lQ8B7o
k^k^00?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`00000:ooooo`03o`000?oooooooooo09kooooo0_l0000:ooooo`04o`00
0?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooooooo
ooooool000001oooool01?l0003oooooooooool00007ooooo`03o`000?oooooo00000?oooooo000<
ooooo`0;ogMgMomVIVKoooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000002_ooool4o`0009gooooo0_l0000:
ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo
00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000oooo
ool00000ooooool000gooooo00?o0000ooooooooool00_o^k^h3ooooo`;ok^k^1Oooool00ol0003o
ooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41002_ooool00ol0003oooooooooo`2Noooo
o`;o00002_ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`00
0007ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool00007ooooo`03
o`000?oooooo00000?oooooo0009ooooo`05o`000?nj^[[ooooooiRHV?l@41003_ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool2o`0000Gooooo00?o0000oooo
ooooool0W_ooool2o`0000[ooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooo
ooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo
00001oooool00ol0003oooooo`00003oooooo`002Oooool01OnHV9So410@o`000?lQ8B7oc<c<00co
oooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo00Co0000oooo
oooooooo00001?ooool00ol0003oooooooooo`2Mooooo`03o`000?oooooo000000[ooooo00Go0000
ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooo
oooooooooooo000000Oooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00003ooooo
o`00:?ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo09gooooo00?o0000oooo
ool000002_ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`00
0007ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool00007ooooo`03
o`000?oooooo000000Sooooo0_l0003eooooo`00:?ooool3o`0000Gooooo00?o0000ooooooooool0
WOooool00ol0003oooooo`00000:ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003o
oooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?oooooo
ooooo`0000Oooooo00?o0000ooooool000002?ooool2o`000?Gooooo000Yooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0WOooool00ol0003oooooo`000009ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000Oooooo00Go
0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooo
oooo00001oooool2o`000?Gooooo000Zooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0WOooool00ol0003oooooo`000009ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01Oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007
ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00001oooool2o`000?Gooooo
000`ooooo`03o`000?oooooooooo09gooooo00?o0000ooooool000002Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000007ooooo`05o`00
0?ooooooooooooooool000001oooool01?l0003oooooooooool00007ooooo`04o`000?oooooooooo
o`0000Oooooo0_l0003eooooo`00<?ooool00ol0003oooooooooo`2Mooooo`04o`000?oooooooooo
o`0000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`05o`000?oooooo
ooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo
00001oooool01?l0003oooooooooool00007ooooo`;o0000mOooool0033ooooo00?o0000oooooooo
ool0WOooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01Oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`00
0006ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool00007ooooo`;o
0000mOooool0033ooooo00?o0000ooooooooool0WOooool01?l0003oooooooooool00008ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo0000
00Oooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001ooo
ool01?l0003oooooooooool00007ooooo`;o0000mOooool0033ooooo0ol0002Mooooo`04o`000?oo
ooooooooo`0000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo0_l0003e
ooooo`00<?ooool00ol0003oooooooooo`2Looooo`05o`000?ooooooooooooooool000002?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000Kooooo00Go0000ooooooooooooooooo`000007ooooo`;o0000mOooool0033ooooo
00?o0000ooooooooool0W?ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000001_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooo`00003eooooo`00<?ooool0
0ol0003oooooooooo`2Looooo`05o`000?ooooooooooooooool000002?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Ko
oooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo00000?Gooooo000`ooooo`03
o`000?oooooooooo09cooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_oo
ool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo0000m?ooool0033ooooo
00?o0000ooooooooool0W?ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000001_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006
ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool0003dooooo`00<?oo
ool00ol0003oooooooooo`2Looooo`05o`000?ooooooooooooooool000002?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000
00Kooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`000?Cooooo000`
ooooo`03o`000?oooooooooo09cooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool0
00001_ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo00001oooool2
o`000>_ooooo000`ooooo`03o`000?oooooooooo09cooooo00Go0000ooooooooooooooooo`000008
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooo
oooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oo
ooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooo
oooo00001oooool2o`000>_ooooo000`ooooo`03o`000?oooooooooo093ooooo00?o0000oooooooo
ool02Oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`05ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?oo
ooooooooooooool000001_ooool01?l0003oooooooooool00007ooooo`;o0000joooool0033ooooo
00?o0000ooooooooool0T?ooool2o`0000[ooooo00Go0000ooooooooooooooooo`000008ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo0000
00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooo
ooooool000001_ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo0000
1oooool2o`000>_ooooo000`ooooo`03o`000?oooooooooo08oooooo00?o0000ooooool000002_oo
ool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`05ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?oooooooooo
ooooool000001_ooool01?l0003oooooooooool00007ooooo`;o0000joooool0033ooooo0ol0002?
ooooo`03o`000?oooooo000000[ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oo
ooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooo
oooo00001oooool2o`000>_ooooo000`ooooo`03o`000?oooooooooo08oooooo00?o0000ooooool0
00002_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006
ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool00007ooooo`03o`00
0?oooooo00000>[ooooo000`ooooo`03o`000?oooooooooo08oooooo00?o0000ooooool000002_oo
ool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`05
o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooo
00000>[ooooo000`ooooo`03o`000?oooooooooo08oooooo00Co0000oooooooooooo00002Oooool0
1Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`05o`00
0?ooooooooooooooool000001_ooool01?l0003oooooooooool00006ooooo`04o`000?oooooooooo
o`000>[ooooo000`ooooo`03o`000?oooooooooo08oooooo00Co0000oooooooooooo00002Oooool0
1Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`05o`00
0?ooooooooooooooool000001_ooool01?l0003oooooooooool00006ooooo`04o`000?oooooooooo
o`000>[ooooo000`ooooo`03o`000?oooooooooo04kooooo0_o^k^h3ooooo`;ok^k^>_ooool01?l0
003oooooooooool00009ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003ooooooooo
o`02onk^kP03o`000?oooooooooo00;ok^k^0oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oo
ooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooo
oooo00001_ooool01?l0003oooooooooool0000Rooooo`;ok^k^0oooool2onk^kTkooooo0_o^k^h3
ooooo`;ok^k^K?ooool0033ooooo00?o0000ooooooooool0B?ooool03Om4A4Co0000o`000?lb<S;o
gMgMooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^hZooooo`05o`000?ooooooooooooooool000002Oooool01Ol0003o
oooooooooooooooo000000Gooooo1?l000002Ol@413oooooonk^k_mEEEGo0000ooooooo^k^koEEEE
onk^kP03ooooo`Co000000So410@o`000?ooooook^k^oc8b<_l0003o<S8bo`0000Cooooo00?o0000
ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000oooooooooooooooo
o`000006ooooo`04o`000?ooooooooooo`0000Kooooo00Co0000oooooooooooo00003?ooool4o`00
0003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`0=odA4A?l0003o0000oc8b<_oMgMgoooooonk^
k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0
003o<S8bonk^kSSooooo1Ol00002ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kUgooooo000`ooooo`03o`000?oo
oooooooo04_ooooo00WoMgMgoc8b<_ooooooooooonk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0
003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0:_ooool01Ol0003ooooooooooooo
oooo000000Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`;o00000ooo
ool01Oo^k^ko0000omgMgOmEEEGok^k^00?ooooo00Co0000oooooooooooo00000_ooool01ol0003o
ooooogMgMonHV9SooooooiRHV?l000001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Kooooo00Co
0000oooooooooooo00001_ooool01?l0003oooooooooool00007ooooo`;o00001Oooool00ol0003o
ooooooooo`04ooooo`;o8B4Q2?ooool02OmgMgOo<S8booooooooooook^k^oeEEEOoMgMgoEEEEonk^
kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0hooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@00oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000oooo
ooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg05gooooo000`ooooo`03o`000?oooooooooo
04cooooo00Oo0000ooooooooooooooooomgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@02[ooooo00Go0000ooooooooooooooooo`000009ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool2o`0000Cooooo00?ogMgMo`000?oM
gMd01?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo410@00?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo00001_oo
ool01?l0003oooooooooool00007ooooo`;o00001Oooool00ol0003oooooooooo`0?ooooo`07o`00
0?oooooooooooooooooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooo
oooooooooooooa0@400iooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?ogMgMo`000?oMgMd01oooool0
0ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100GOooool0033ooooo00?o0000
ooooooooool0Boooool02OmgMgOo<S8booooooooooook^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03
o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Zooooo`05o`000?oooooooooo
ooooool000002Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo0_l00003
ooooo`05onk^k_mEEEGo0000oeEEEOo^k^h00oooool01?l0003oooooooooool00002ooooo`03o`00
0?oooooo000000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Ko
oooo00Co0000oooooooooooo00001_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooo
000000Gooooo00?o0000ooooooooool03_ooool02OmgMgOo<S8booooooooooook^k^oeEEEOoMgMgo
EEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000joooo
o`03oiRHV?lQ8B7ok^k^00?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`00001Mooooo`00<?ooool00ol0003oooooooooo`18
ooooo`0=o`000?lQ8B7o0000oc8b<_o<c<coooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Zooooo`05o`000?oo
ooooooooooooool000002Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo
0_l00002ooooo`07onk^k_mEEEGok^k^o`000?o^k^koEEEEonk^kP02ooooo`04o`000?oooooooooo
o`0000;ooooo00?o0000ooooool000000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooo
ooooooooool000001_ooool01?l0003oooooooooool00006ooooo`04o`000?ooooooooooo`0000Ko
oooo00?o0000ooooool000001Oooool00ol0003oooooooooo`0;ooooo`0=o`000?lQ8B7o0000oc8b
<_o<c<coooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`00000kooooo`0;ogMgMomVIVKoooooooooooo^k^koEEEEonk^
k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000GOooool0033ooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`03ooooo`;o
k^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@
02[ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01?ooool2o`0000;ooooo0_o^k^h00ooooooo0000ooooo`02onk^kP;ooooo00Co0000
oooooooooooo00000_ooool00ol0003ooooooa0@4003ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go
0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Kooooo00Co0000oooooooo
oooo00001_ooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool00oooool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooo
oooooooooooooa0@400looooo`03o`000?oooooooooo00;ok^k^0oooool2onk^kPGooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@05gooooo000`ooooo`?o0000B?ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`08ooooo`03o`000?oooooooooo01oooooo00Go0000ooooooooooooooooo`000008ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01?ooool2o`0000Gooooo00?o0000ooooooooool0
0oooool01?l0003oooooooooool00002ooooo`07o`000?ooooooMgMgoiRHV?ooooooV9RHo`000004
ooooo`04o`000?ooooooooooooooo`;o000000?oooooo`000?ooool00oooool00ol0003ooooooooo
o`03ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool00006ooooo`04
o`000?ooooooooooo`0000Kooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Sooooo0_l0000^ooooo`05o`000?nj^[[ooooooiRHV?l@41003_ooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool2o`0005?ooooo000`ooooo`03o`000?oo
oooooooo04Sooooo1?l0000<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP08ooooo`03o`000?oooooooooo017ooooo0ol0000;ooooo`05o`000?ooooooooooooooool0
00002?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00CoEEEEofIVI_l0
003o00001Oooool00ol0003oooooooooo`03ooooo`04o`000?mEEEGoIVIVo`0000;ooooo00Oo0000
ooooooo^k^ko<S8bo`000?lb<S;o000000Cooooo00Co0000oooooooooooo00000_ooool2o`0000Co
oooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooo
oooooooo00001_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooo000000?ooooo00?o
EEEEofIVI_l000003Oooool4o`0000cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Oooooo00Co0000oooooooooooo0000;Oooool01OnHV9So410@o`000?lQ8B7oc<c<
00cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oooooo00Co0000
oooooooooooo0000D_ooool0033ooooo00?o0000ooooooooool0I_ooool4o`0000?ooooo00?o0000
ooooooooool04?ooool00ol0003oooooo`00000;ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`04o`000004ooooool0003oooooooooo`;o00001?oo
ool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooo
oooooooooooo000000Gooooo00Co0000oooooooooooo00001_ooool01?l0003oooooooooool00006
ooooo`;o0000:?ooool4o`000005ooooool0003oooooooooool00000C?ooool4o`000005ooooool0
003oooooooooool00000D_ooool0033ooooo00?o0000ooooooooool0KOooool00ol0003ooooooooo
o`0?ooooo`05o`000?ooooooooooooooool000002Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03o`000003oooo
ool0003ooooo00?ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Ko
oooo00Go0000ooooooooooooooooo`000005ooooo`04o`000?ooooooooooo`0000Kooooo00Co0000
oooooooooooo00001_ooool2o`0002gooooo0ol0001Booooo`?o0000Doooool0033ooooo00?o0000
ooooooooool0Joooool01?l0003oooooooooool0000@ooooo`05o`000?ooooooooooooooool00000
2Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo
000000Gooooo00Go0000ooooooooooooooooo`000005ooooo`04o`000?ooooooooooo`0000Kooooo
0_l0000^ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0D_ooool0033ooooo00?o
0000ooooooooool0Joooool4o`00013ooooo00Go0000ooooooooooooooooo`000009ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooool000001?ooool00ol0003oooooooooo`03ooooo`05o`00
0?ooooooooooooooool000001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`00
00Kooooo00?o0000ooooool00000;_ooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo
057ooooo000`ooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo0000eoooool0033ooooo00?o0000
ooooooooool0O_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000
ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo0000
1Oooool01?l0003oooooooooool00006ooooo`;o0000UOooool00omgMgOoIVIVooooo`0]ooooo`03
ofIVI_mgMgOooooo00Oooooo000`ooooo`03o`000?oooooooooo06oooooo0ol0000;ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Go
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Cooooo00Co0000oooo
oooooooo00001_ooool00ol0003oooooo`00002Cooooo`03omgMgOl@413ok^k^02kooooo00?ok^k^
oa0@4?oMgMd01oooool0033ooooo00?o0000ooooooooool0K_ooool2o`000003ooooool0003o0000
00[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooooooo
ooooool000001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001?oo
ool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooool000001_ooool2o`0007Wooooo
0_l00002ooooo`;o00003?ooool00omEEEGoV9RHooooo`02o`0000;ooooo00Oo0000oooooooooooo
0000oa0@4?o^k^koEEEE00;o000000?oA4A4okZj^_ooool00_ooool01OnHV9So0000o`000?m4A4Co
^[Zj00;ooooo00Sok^k^oeEEEOl0003o0000odA4A?nj^[[ooooooa0@40Go00000oooool02?l@413o
<S8bo`000?l0003o410@ojVYZOn7QhOoIVIV1oooool0033ooooo00?o0000ooooooooool0KOooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`;o000000?oooooo`000?oo
ool01Oooool2o`00073ooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd<ooooo`05o`000?oooooo
ooooooooool000000_ooool02ol0003oooooooooool0003ooooooeEEEOmgMgOoooooonk^k_mgMgOo
410@00?ooooo00Go410@okZj^_o^k^koMgMgoa0@4002ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo
410@0oooool00ol0003oooooooooo`04ooooo`08o`000?nYZJWooooooooooonj^[[o0000onk^k_l0
0007ooooo`00ool0002do`0000oooooo00CogMgMo`000?l@413oc<c<3Oooool01Olb<S;ooooooooo
oooooooo000000;ooooo00Ko0000oooooooooooo0000ooooool00008ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`07okZj^_n7QhOoIVIV
ofIVI_l@413oooooo`000007ooooo`002_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo00Gooooo0ol000000ooooooo0000o`000002o`0000?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Ooo
ool01ol0003ooooooooooooooooo0000ooooool000001_ooool00ol0003oooooooooo`03ooooo`07
o`000?ooooooooooooooool0003oooooo`000005ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000ooo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001?ooool2o`000003oooo
ool0003o000000Cooooo1?l00005ooooo`?o00004_ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Gooooo`04onk^
k_lQ8B7o410@onk^kPgooooo00Go<S8booooooooooooooooo`000002ooooo`05o`000?oooooooooo
o`000?ooool01_l00003ooooo`03o`000?oooooooooo00Cooooo1_l00003ooooo`03o`000?oooooo
oooo00Cooooo00So<S8bob4Q8OmgMgOoMgMgohN7Qoo^k^koooooo`0000Oooooo000:ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool02?ooool3o`0000Gooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo
00001oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01Oooool01ol0003ooooooooooooooooo0000ooooool000001_ooool00ol0003oooooooooo`03
ooooo`07o`000?ooooooooooooooool0003oooooo`000005ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
00000oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Gooooo0ol0000@oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool05oooool01?lQ8B7oMgMgogMgMolb<S8=
ooooo`05o`000?o^k^koooooooooool000000_o<c<`02ol0003oZJVYomgMgOlQ8B7ooooooeEEEOn7
QhOok^k^oooooon7QhOo<S8b00?ooooo00?o0000ooooooooool01?ooool01_mEEEGoQhN7onk^k_oo
ooooQhN7oc8b<P?ooooo00?o0000oc8b<_oMgMd01?ooool02?l0003o^[Zjooooooo^k^koMgMgo`00
0?o^k^ko00001oooool0033ooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`07o`000?ooooooooooooooool0003oooooo`000005ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool00000
1?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000005oooo
o`?o00001_ooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo01Kooooo0_l00002oooo
o`;o00003?ooool03_mEEEGoMgMgooooool@413o0000ob4Q8Ol0003oMgMgoa0@4?l0003oZJVYoooo
ooo^k^koEEEE0_l000001?m4A4Cok^k^ooooool@4105o`0000?ooooo00Kok^k^oeEEEOl0003o0000
odA4A?o^k^h2ooooo`;o000000CoZJVYob4Q8Ol0003o8B4Q0_ooool02?nYZJWo8B4Qo`000?l0003o
<S8bo`000?mgMgOoEEEE1oooool0033ooooo00?o0000ooooooooool0Moooool01Ol0003ooooooooo
oooooooo000000Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oooooooooooooo
ool000001Oooool01?l0003oooooooooool00006ooooo`03o`000?oooooooooo08kooooo00?ogMgM
oa0@4?o^k^h04_ooool00ol0003oooooooooo`0Iooooo`03onk^k_l@413ogMgM00Oooooo000`oooo
o`03o`000?oooooooooo07Oooooo00?o0000ooooooooool00_l00009ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooooooo
ooooool000001?ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooool00000VOoo
ool00omgMgOoIVIVooooo`0Aooooo`03o`000?oooooooooo01Wooooo00?oIVIVogMgMoooool01ooo
ool0033ooooo00?o0000ooooooooool0N?ooool3o`0000_ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00
0004ooooo`05o`000?ooooooooooooooool000001Oooool3o`000=?ooooo000`ooooo`03o`000?oo
oooooooo08Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool0
00001_ooool2o`000=?ooooo000`ooooo`03o`000?oooooooooo08Kooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0_ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo00001_ooool00ol0
003oooooo`00003Looooo`00<?ooool00ol0003oooooooooo`26ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000
ooooool00000g?ooool0033ooooo00?o0000ooooooooool0Q_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool00006ooooo`03o`000?oo
oooo00000=cooooo000`ooooo`03o`000?oooooooooo08Kooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo00001_ooool00ol0003ooooo
o`00003Looooo`00<?ooool3o`0008Kooooo00Go0000ooooooooooooooooo`000009ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Ko
oooo00Co0000oooooooooooo00001_ooool2o`000=gooooo000`ooooo`03o`000?oooooooooo08Oo
oooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Gooooo00Go0000
ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool0
foooool0033ooooo00?o0000ooooooooool0Qoooool01?l0003oooooooooool0000:ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000005ooooo`05o`000?oooooooooooooo
ool000001_ooool01?l0003oooooooooool00006ooooo`04o`000?ooooooooooo`000>Gooooo000`
ooooo`03o`000?oooooooooo08Oooooo00Co0000oooooooooooo00002_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`04ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0003ooooooooooooooooo000000Ko
oooo00Co0000oooooooooooo00001_ooool01?l0003oooooooooool0003Uooooo`00<?ooool00ol0
003oooooooooo`28ooooo`03o`000?oooooo000000[ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0
003ooooooooooooooooo000000Gooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?oo
ooooooooo`0000Kooooo00Co0000oooooooooooo0000iOooool0033ooooo00?o0000ooooooooool0
R?ooool2o`0000_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Go
oooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000
ooooool00000i_ooool0033ooooo00?o0000ooooooooool0R?ooool2o`0000_ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01?ooool01Ol0003ooooooooooooooooo000000Gooooo00Go0000ooooooooooooooooo`00
0006ooooo`04o`000?ooooooooooo`0000Oooooo0_l0003Vooooo`00<?ooool00ol0003ooooooooo
o`2Eooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooo
oooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000005ooooo`05o`000?oooooooooooooo
ool000001_ooool01?l0003oooooooooool00007ooooo`;o0000i_ooool0033ooooo00?o0000oooo
ooooool0UOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00Go0000oooo
ooooooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0003ooooooooo
oooooooo000000Kooooo00Co0000oooooooooooo00001oooool2o`000>Kooooo000`ooooo`03o`00
0?oooooooooo09Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`05o`00
0?ooooooooooooooool000002?ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01?ooool01Ol0003ooooooooooooooooo000000Gooooo00Go0000ooooooooooooooooo`00
0006ooooo`04o`000?ooooooooooo`0000Oooooo0_l0003Vooooo`00<?ooool00ol0003ooooooooo
o`2Eooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooo
oooooooo000000Sooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00Go0000ooooooooooooooooo`000005ooooo`05o`000?ooooooooooooooool000001_ooool0
1?l0003oooooooooool00007ooooo`;o0000i_ooool0033ooooo00?o0000ooooooooool0UOooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00Go0000ooooooooooooooooo`00
0008ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`00
0?ooooooooooooooool000001_ooool01?l0003oooooooooool00006ooooo`04o`000?oooooooooo
o`000>oooooo000`ooooo`?o0000UOooool01Ol0003ooooooooooooooooo000000Wooooo00Go0000
ooooooooooooooooo`000008ooooo`05o`000?ooooooooooooooool000001oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool00006oooo
o`04o`000?ooooooooooo`000>oooooo000`ooooo`03o`000?oooooooooo09Gooooo00Go0000oooo
ooooooooooooo`000009ooooo`05o`000?ooooooooooooooool000002?ooool01Ol0003ooooooooo
oooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Ko
oooo00Co0000oooooooooooo00001_ooool01?l0003oooooooooool0003_ooooo`00<?ooool00ol0
003oooooooooo`2Eooooo`05o`000?ooooooooooooooool000002Oooool01Ol0003ooooooooooooo
oooo000000Sooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo
00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Kooooo00Co0000oooo
oooooooo0000koooool0033ooooo00?o0000ooooooooool0UOooool01Ol0003ooooooooooooooooo
000000Wooooo00Go0000ooooooooooooooooo`000008ooooo`05o`000?ooooooooooooooool00000
1oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003o
ooooooooool00006ooooo`04o`000?ooooooooooo`000>oooooo000`ooooo`03o`000?oooooooooo
09Kooooo00Co0000oooooooooooo00002Oooool01Ol0003ooooooooooooooooo000000Sooooo00Go
0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooo
ooooo`000006ooooo`04o`000?ooooooooooo`0000Kooooo00Co0000oooooooooooo0000koooool0
033ooooo00?o0000ooooooooool0U_ooool01?l0003oooooooooool00009ooooo`05o`000?oooooo
ooooooooool000002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooooooooooo
ooooo`000006ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003o
oooooooooooooooo000000Kooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00003_
ooooo`00<?ooool00ol0003oooooooooo`2Fooooo`04o`000?ooooooooooo`0000Wooooo00Go0000
ooooooooooooooooo`000008ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooo
oooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?oooooooooo
ooooool000001_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooo00000>oooooo000`
ooooo`03o`000?oooooooooo09Kooooo00Co0000oooooooooooo00002Oooool01Ol0003ooooooooo
oooooooo000000Sooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooooooooooo
ool000001oooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`00
0006ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool00000koooool0033ooooo00?o
0000ooooooooool0U_ooool01?l0003oooooooooool00009ooooo`05o`000?ooooooooooooooool0
00002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007
ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Kooooo
00Co0000oooooooooooo00001oooool2o`000?3ooooo000`ooooo`03o`000?oooooooooo09Kooooo
00?o0000ooooool000002_ooool01Ol0003ooooooooooooooooo000000Sooooo00Go0000oooooooo
ooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooo
oooo000000Kooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Oo
oooo0_l0003`ooooo`00<?ooool00ol0003oooooooooo`2Fooooo`03o`000?oooooo000000[ooooo
00Go0000ooooooooooooooooo`000008ooooo`05o`000?ooooooooooooooool000001oooool01Ol0
003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?oo
ooooooooo`0000Oooooo00Co0000oooooooooooo00001oooool2o`000?3ooooo000`ooooo`03o`00
0?oooooooooo09Oooooo0_l0000:ooooo`05o`000?ooooooooooooooool000002?ooool01Ol0003o
oooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooo
ooooooooool000001_ooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Oo
oooo0_l0003`ooooo`00<?ooool3o`0009Oooooo0_l0000:ooooo`05o`000?ooooooooooooooool0
00002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007
ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool00007ooooo`04o`00
0?ooooooooooo`0000Sooooo00?o0000ooooooooool0k_ooool0033ooooo00?o0000ooooooooool0
Uoooool2o`0000[ooooo00Go0000ooooooooooooooooo`000008ooooo`05o`000?oooooooooooooo
ool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`00
0006ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo0000nOooool0033ooooo
00?o0000ooooooooool0Xoooool01Ol0003ooooooooooooooooo000000Sooooo00Go0000oooooooo
ooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooo
oooo000000Kooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool0003iooooo`00
<?ooool00ol0003oooooooooo`2Sooooo`05o`000?ooooooooooooooool000002?ooool01Ol0003o
oooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooo
ooooooooool000001_ooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`000?Wo
oooo000`ooooo`03o`000?oooooooooo0:?ooooo00Go0000ooooooooooooooooo`000008ooooo`05
o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000
ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo
0000nOooool0033ooooo00?o0000ooooooooool0Xoooool01Ol0003ooooooooooooooooo000000So
oooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool0
1Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo00001oooool01?l0003ooooo
ooooool0003iooooo`003oooool2onk^kP?ooooo0_o^k^hJooooo`03o`000?oooooooooo0:?ooooo
00Go0000ooooooooooooooooo`000008ooooo`05o`000?ooooooooooooooool000001oooool01Ol0
003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?oo
ooooooooo`0000Oooooo00Co0000oooooooooooo0000nOooool000Sooooo1Ol00002ooooo`07onk^
k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0
003o<S8bonk^kP_ooooo00?o0000ooooooooool0Xoooool01Ol0003ooooooooooooooooo000000So
oooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool0
1Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo00001oooool00ol0003ooooo
o`00003jooooo`002?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00Gok^k^oeEEEOoMgMgo
EEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;oooo
o`03o`000?oooooooooo0:?ooooo00Go0000ooooooooooooooooo`000008ooooo`05o`000?oooooo
ooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooooooooooo
ooooo`000006ooooo`04o`000?ooooooooooo`0000Sooooo0_l0003jooooo`002Oooool00onHV9So
8B4Qonk^kP05ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@413o
oooooooooooooooo410@00_ooooo00?o0000ooooooooool0Xoooool01Ol0003ooooooooooooooooo
000000Sooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool00000
1oooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Sooooo0_l0003joooo
o`002_ooool00onHV9So8B4Qonk^kP03ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`2T
ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000007ooooo`05o`00
0?ooooooooooooooool000001oooool01?l0003oooooooooool00007ooooo`04o`000?oooooooooo
o`0000Sooooo0_l0003jooooo`002oooool02omgMgOoIVIVooooooooooook^k^oeEEEOo^k^kooooo
onk^k_mEEEGok^k^00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
00_ooooo1?l0002Sooooo`04o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`00
0007ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool00007ooooo`04
o`000?ooooooooooo`0000Sooooo0_l0003jooooo`003?ooool00ol0003oooooooooo`02onk^kP?o
oooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400;oooo
o`03o`000?oooooooooo0:Cooooo00?o0000ooooool000002Oooool01Ol0003ooooooooooooooooo
000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo
00Co0000oooooooooooo00002?ooool2o`000?[ooooo0008ooooo`05o`000?nj^[[ooooooiRHV?l@
41003_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ol0
003oooooooooo`2Tooooo`03o`000?oooooo000000Wooooo00Go0000ooooooooooooooooo`000007
ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool00007ooooo`04o`00
0?ooooooooooo`0000Sooooo0_l0003jooooo`002?ooool01OnHV9So410@o`000?lQ8B7oc<c<00co
oooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo0_l00006oooo
o`03o`000?oooooooooo0:Cooooo00?o0000ooooool000002Oooool01Ol0003ooooooooooooooooo
000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo
00Co0000oooooooooooo00002?ooool2o`000?[ooooo000Wooooo`04o`000?ooooooooooo`0000Go
oooo00?o0000ooooooooool0Y?ooool00ol0003oooooo`000009ooooo`05o`000?oooooooooooooo
ool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo00001ooo
ool01?l0003oooooooooool00008ooooo`;o0000n_ooool002Oooooo00Co0000oooooooooooo0000
1Oooool00ol0003oooooooooo`2Tooooo`03o`000?oooooo000000Wooooo00Go0000oooooooooooo
ooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool00007
ooooo`04o`000?ooooooooooo`0000Sooooo0_l0003jooooo`009oooool3o`0000Kooooo00?o0000
ooooooooool0Y?ooool00ol0003oooooo`000009ooooo`05o`000?ooooooooooooooool000001ooo
ool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo00001oooool01?l0003o
ooooooooool00008ooooo`03o`000?oooooooooo0?Wooooo000Xooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0Y?ooool00ol0003oooooo`000009ooooo`05o`000?oooooooooooooo
ool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo00001ooo
ool01?l0003oooooooooool0003oooooo`Gooooo000Yooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0Y?ooool00ol0003oooooo`000009ooooo`05o`000?ooooooooooooooool00000
1oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo00001oooool01?l0
003oooooooooool0003oooooo`Gooooo000`ooooo`03o`000?oooooooooo0:Cooooo00?o0000oooo
ool000002Oooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool000001ooo
ool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`000?oooooo1Oooool0033ooooo
00?o0000ooooooooool0Y?ooool00ol0003oooooo`000009ooooo`04o`000?ooooooooooo`0000So
oooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo
00000?oooooo1Oooool0033ooooo00?o0000ooooooooool0YOooool2o`0000Wooooo00Co0000oooo
oooooooo00002Oooool00ol0003oooooo`000008ooooo`04o`000?ooooooooooo`0000Sooooo00?o
0000ooooool00000ooooool5ooooo`00<?ooool3o`000:Gooooo00?o0000ooooooooool02?ooool0
1?l0003oooooooooool00009ooooo`03o`000?oooooo000000Sooooo00Co0000oooooooooooo0000
2?ooool00ol0003oooooo`00003oooooo`Gooooo000`ooooo`03o`000?oooooooooo0:Gooooo00?o
0000ooooooooool02Oooool00ol0003oooooo`000009ooooo`03o`000?oooooo000000Sooooo00Co
0000oooooooooooo00002?ooool00ol0003oooooo`00003oooooo`Gooooo000`ooooo`03o`000?oo
oooooooo0;7ooooo00?o0000ooooool000002Oooool00ol0003oooooo`000008ooooo`04o`000?oo
ooooooooo`0000Sooooo00?o0000ooooool00000ooooool5ooooo`00<?ooool00ol0003ooooooooo
o`2aooooo`03o`000?oooooo000000Wooooo00?o0000ooooool000002?ooool01?l0003ooooooooo
ool00008ooooo`03o`000?oooooo00000?oooooo1Oooool0033ooooo00?o0000ooooooooool0/Ooo
ool00ol0003oooooo`000009ooooo`03o`000?oooooo000000Sooooo00Co0000oooooooooooo0000
2?ooool00ol0003oooooo`00003oooooo`Gooooo000`ooooo`03o`000?oooooooooo0;7ooooo00?o
0000ooooool000002Oooool00ol0003oooooo`000008ooooo`04o`000?ooooooooooo`0000Sooooo
00?o0000ooooool00000ooooool5ooooo`00<?ooool00ol0003oooooooooo`2aooooo`03o`000?oo
oooo000000Wooooo00?o0000ooooool000002?ooool01?l0003oooooooooool00008ooooo`;o0000
ooooool6ooooo`00<?ooool00ol0003oooooooooo`2aooooo`03o`000?oooooo000000Wooooo00?o
0000ooooool000002?ooool01?l0003oooooooooool00008ooooo`;o0000ooooool6ooooo`00<?oo
ool00ol0003oooooooooo`2aooooo`03o`000?oooooo000000Wooooo00?o0000ooooool000002?oo
ool01?l0003oooooooooool00008ooooo`;o0000ooooool6ooooo`00<?ooool00ol0003ooooooooo
o`2aooooo`03o`000?oooooo000000Wooooo00?o0000ooooool000002?ooool01?l0003ooooooooo
ool00008ooooo`;o0000ooooool6ooooo`00<?ooool00ol0003oooooooooo`2aooooo`03o`000?oo
oooo000000Wooooo00?o0000ooooool000002Oooool00ol0003oooooo`000008ooooo`;o0000oooo
ool6ooooo`00<?ooool00ol0003oooooooooo`2aooooo`03o`000?oooooo000000Wooooo00?o0000
ooooool000002Oooool00ol0003oooooo`000009ooooo`03o`000?oooooooooo0?oooooo1?ooool0
033ooooo0ol0002aooooo`03o`000?oooooo000000Wooooo00?o0000ooooool000002Oooool00ol0
003oooooo`00003ooooooa3ooooo000`ooooo`03o`000?oooooooooo0;7ooooo00?o0000ooooool0
00002Oooool00ol0003oooooo`000009ooooo`;o0000oooooolAooooo`00<?ooool00ol0003ooooo
ooooo`2aooooo`03o`000?oooooo000000Wooooo00?o0000ooooool000002Oooool2o`000?oooooo
4Oooool0033ooooo00?o0000ooooooooool0/Oooool00ol0003oooooo`000009ooooo`03o`000?oo
oooo000000Wooooo0_l0003ooooooa7ooooo000`ooooo`03o`000?oooooooooo0;7ooooo00?o0000
ooooool000002Oooool00ol0003oooooo`000009ooooo`;o0000oooooolAooooo`00<?ooool00ol0
003oooooooooo`2aooooo`;o00002_ooool00ol0003oooooo`000009ooooo`;o0000oooooolAoooo
o`00<?ooool00ol0003oooooooooo`2aooooo`;o00002_ooool00ol0003oooooo`000009ooooo`;o
0000oooooolAooooo`00<?ooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00Sooooo
00?o0000ooooool000002Oooool2o`000?oooooo4Oooool0033ooooo00?o0000ooooooooool0/_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooo000000Wooooo0_l0003ooooooa7ooooo000`
ooooo`03o`000?oooooooooo0;gooooo00?o0000ooooool000002Oooool2o`000?oooooo4Oooool0
033ooooo00?o0000ooooooooool0_Oooool00ol0003oooooo`000009ooooo`;o0000oooooolAoooo
o`00<?ooool00ol0003oooooooooo`2mooooo`03o`000?oooooo000000Wooooo0_l0003ooooooa7o
oooo000`ooooo`?o0000_Oooool00ol0003oooooo`000009ooooo`;o0000oooooolAooooo`00<?oo
ool00ol0003oooooooooo`2nooooo`;o00002_ooool00ol0003oooooooooo`3oooooo`oooooo000`
ooooo`03o`000?oooooooooo0;kooooo0_l0003ooooooacooooo000`ooooo`03o`000?oooooooooo
0;kooooo00?o0000ooooooooool0oooooolKooooo`00<?ooool00ol0003oooooooooo`2nooooo`03
o`000?oooooooooo0?oooooo6oooool0033ooooo00?o0000ooooooooool0__ooool00ol0003ooooo
ooooo`3ooooooa_ooooo000?ooooo`;ok^k^0oooool2onk^kQ[ooooo00?o0000ooooooooool0oooo
oooLooooo`002_ooool2o`00000:oa0@4?ooooooooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^
kP?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool00ol0003ooooo
ooooo`3oooooomcooooo000;ooooo`03o`000?oooooooooo00;ooooo00Gok^k^oeEEEOoMgMgoEEEE
onk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03
o`000?oooooooooo0?oooooog?ooool000Sooooo1Ol00004ooooo`03omgMgOl0003ogMgM00Oooooo
00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00_ooooo00?o0000oooooooo
ool0oooooooLooooo`002?ooool01?m4A4CogMgMooooool00004ooooo`05onk^k_mEEEGogMgMoeEE
EOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000002oooool0
0ol0003oooooooooo`3oooooomcooooo0008ooooo`04omgMgOmEEEGoooooo`0000?ooooo00Ook^k^
oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000_ooooo1?l0003oooooom_ooooo0009ooooo`03ogMgMoo<c<co000000?ooooo
0_o^k^h3ooooo`;ok^k^1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41002oooool00ol0003oooooooooo`3oooooomcooooo0009ooooo`03onk^k_m4A4Co000000oooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?o0000oooooooo
ool0oooooooLooooo`002_ooool00omgMgOo0000ooooo`0<ooooo`03oeEEEOmVIVKo000000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`;o00001_ooool00ol0003oooooooooo`3oooooomco
oooo000Wooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0oooooooLooooo`00
9oooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo0?oooooog?ooool002Oooooo
0ol00006ooooo`03o`000?oooooooooo0?oooooog?ooool002Sooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`3oooooomcooooo000Yooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03
o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?oo
ool3o`000?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0
003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo
00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`
ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLoooo
o`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooo
g?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3o
ooooomcooooo000`ooooo`?o0000oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomco
oooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooo
oooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooo
ooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000
ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03
o`000?oooooooooo0?oooooog?ooool0033ooooo0ol0003oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0
003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool00?oooooo
ooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@oooo
o`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooo
oooooa3ooooo002Tooooo`;o00000oooool00onj^[[o<S8booooo`05ooooo`;o00001Oooool00ol0
003o^[Zjooooo`3ooooooeCooooo002Tooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`03ooooo`;o<S8boooooomEooooo`00TOooool3o`0000;ooooo
00Ko<S8boa0@4?ooooooooooonk^k_mEEED2o`000003odA4A?nj^[[ooooo00?ooooo00Ko0000oooo
oooooooooooooiRHV?l@4102o`000003ojVYZOoooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00on7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X02Oooool01?l@413o0000
odA4A?o<c<`6ooooo`;o8B4Q0oooool01Oo<c<cok^k^ooooooo^k^koc<c<00Cooooo1?l000002?l@
413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^4oooool01_l@413o<S8bo`000?l0003o410@ojVY
Z@;ooooo00Kok^k^oeEEEOl0003o0000odA4A?nj^[X3ooooo`05ofIVI_l0003o0000odA4A?o<c<`0
k?ooool009;ooooo00Go0000ooooooooooooc<c<oa0@4003ooooo`06oeEEEOmgMgOoooooonk^k_mg
MgOo410@1?ooool02_l0003ooooooooooooooooo0000ojVYZOmEEEGoV9RHoeEEEOnj^[X4ooooo`03
o`000?oooooooooo00?ooooo00?oc<c<o`000?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@
00;ooooo1_l00003ooooo`03oiRHV?l@413ogMgM00Gooooo0_lQ8B43ooooo`05onk^k_mEEEGogMgM
oeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL04ooo
ool01_l0003oZJVYoooooooooooo^[Zjo`0000;ooooo00KoEEEEogMgMoooooook^k^ogMgMol@4102
ooooo`06ofIVI_mgMgOooooooooooon7QhOo410@k?ooool009;ooooo00Go0000ooooooooooooEEEE
ohN7Q`03ooooo`03o`000?oooooooooo00Oooooo00[o0000oooooooooooooooooc8b<_o^k^koV9RH
oeEEEOoMgMgo410@1?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00kooooo00?o
QhN7oeEEEOooool02_ooool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go
410@oooooooooooooooooa0@400Dooooo`05okZj^_n7QhOoIVIVofIVI_l@41000_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo0>oooooo002Booooo`05o`000?oooooogMgMo`000?o^
k^h00oooool6o`0000Cooooo00_o0000oooooooooooooooookZj^_m4A4Coc<c<ob4Q8Ooooooo410@
olc<c003ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01?ooool6o`000006oooo
ooo<c<co8B4Qo`000?mEEEGo00002_ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000001?ooooo00Ko<S8bob4Q8OmgMgOoMgMg
ohN7Qoo^k^h2ooooo`Ko00000_ooool00ol0003oooooooooo`3_ooooo`00T_ooool3o`000003oa0@
4?nHV9Sooooo00;ooooo00KoEEEEohN7Qoo^k^koooooohN7Qolb<S84ooooo`0;o`000?oooooooooo
ooooooo^k^ko0000ooooool0003oooooofIVI_n7QhL00oooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo00_ooooo00Go8B4QohN7QoooooooV9RHo`00000:ooooo`05olc<c?o^k^kooooo
onk^k_o<c<`01_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000004ooo
ool01_l0003o^[Zjooooooo^k^koMgMgo`0000;ooooo00KoEEEEohN7Qoo^k^koooooohN7Qolb<S82
ooooo`06ofIVI_mgMgOooooooooooon7QhOo0000k?ooool009;ooooo00Go0000ooooooooooooc<c<
o`000003ooooo`06onk^k_mEEEGo0000o`000?m4A4Cok^k^1?ooool02?l0003ooooooooooooooooo
IVIVoiRHV?oooooo<S8b0_nj^[X01Ol0003ooooooooooooooooo000001;ooooo00?o410@o`000?l0
00000ol0000:ooooo`05o`000?ooooooooooooooool000005Oooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@41001oooool3o`0000;ooooo0ol00004ooooo`06ojVYZOlQ8B7o
0000o`000?lb<S;o00000_ooool01_o^k^koEEEEo`000?l0003oA4A4onk^kP;ooooo00Kok^k^ofIV
I_l0003o0000odA4A?l0003/ooooo`00T_ooool01Ol0003oooooooooooo<c<co000000gooooo00?o
0000ooooooooool01?ooool00omVIVKoQhN7ooooo`04ooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool02oooool01OlQ8B7oV9RHoooooomgMgOoEEEE01Gooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`3oooooo`Kooooo002Aooooo`Co000000?o410@ojVYZOooool03?ooool2o`0000Gooooo
00?oZJVYodA4A?ooool00oooool2o`0001Cooooo00?o0000ooooooooool02oooool01Oo<c<co410@
o`000?lb<S;ok^k^01?ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00;ooooo1?l00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0ooooool6oooo
o`00ooooool2ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0ooooool6ooooo`00
ooooool2ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0ooooool6ooooo`00oooo
ool1ooooo`;o00000oooool2o`000?oooooo2?ooool00?ooooooooooool@ooooo`00oooooooooooo
oa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003o
oooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo
4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oo
ooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@
ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooo
oooooooooa3ooooo0000\
\>"],
  ImageRangeCache->{{{0, 525.688}, {324.5, 0}} -> {-2.58312*^-7, -6.34248*^6, \
6.65005*^-9, 53093.5}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0.309017 5.42214e-08 [
[.32684 .29652 -16.5 -12.5 ]
[.32684 .29652 16.5 0 ]
[.54329 .29652 -16.5 -12.5 ]
[.54329 .29652 16.5 0 ]
[.75974 .29652 -22.5 -12.5 ]
[.75974 .29652 22.5 0 ]
[.97619 .29652 -16.5 -12.5 ]
[.97619 .29652 16.5 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 64 6 ]
[.09789 .09213 -34.5 -6.25 ]
[.09789 .09213 0 6.25 ]
[.09789 .20057 -34.5 -6.25 ]
[.09789 .20057 0 6.25 ]
[.09789 .41746 -28.5 -6.25 ]
[.09789 .41746 0 6.25 ]
[.09789 .5259 -28.5 -6.25 ]
[.09789 .5259 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -62.8125 0 ]
[.5 .63053 62.8125 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 .30902 m
.32684 .31527 L
s
gsave
.32684 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 .30902 m
.54329 .31527 L
s
gsave
.54329 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 .30902 m
.75974 .31527 L
s
gsave
.75974 .29652 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 .30902 m
.15368 .31277 L
s
.19697 .30902 m
.19697 .31277 L
s
.24026 .30902 m
.24026 .31277 L
s
.28355 .30902 m
.28355 .31277 L
s
.37013 .30902 m
.37013 .31277 L
s
.41342 .30902 m
.41342 .31277 L
s
.45671 .30902 m
.45671 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.58658 .30902 m
.58658 .31277 L
s
.62987 .30902 m
.62987 .31277 L
s
.67316 .30902 m
.67316 .31277 L
s
.71645 .30902 m
.71645 .31277 L
s
.80303 .30902 m
.80303 .31277 L
s
.84632 .30902 m
.84632 .31277 L
s
.88961 .30902 m
.88961 .31277 L
s
.9329 .30902 m
.9329 .31277 L
s
.0671 .30902 m
.0671 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09213 m
.11664 .09213 L
s
gsave
.09789 .09213 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .20057 m
.11664 .20057 L
s
gsave
.09789 .20057 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .41746 m
.11664 .41746 L
s
gsave
.09789 .41746 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .5259 m
.11664 .5259 L
s
gsave
.09789 .5259 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.11039 .11924 m
.11414 .11924 L
s
.11039 .14635 m
.11414 .14635 L
s
.11039 .17346 m
.11414 .17346 L
s
.11039 .22768 m
.11414 .22768 L
s
.11039 .2548 m
.11414 .2548 L
s
.11039 .28191 m
.11414 .28191 L
s
.11039 .33613 m
.11414 .33613 L
s
.11039 .36324 m
.11414 .36324 L
s
.11039 .39035 m
.11414 .39035 L
s
.11039 .44457 m
.11414 .44457 L
s
.11039 .47168 m
.11414 .47168 L
s
.11039 .49879 m
.11414 .49879 L
s
.11039 .06502 m
.11414 .06502 L
s
.11039 .03791 m
.11414 .03791 L
s
.11039 .0108 m
.11414 .0108 L
s
.11039 .55301 m
.11414 .55301 L
s
.11039 .58012 m
.11414 .58012 L
s
.11039 .60723 m
.11414 .60723 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -123.812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.812 moveto
(@) show
81.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.812 moveto
(D) show
93.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(9.2) show
135.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
141.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
153.000 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
157.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
166.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
184.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02691 .30902 L
.03029 .30902 L
.03347 .30902 L
.03652 .30902 L
.03978 .30902 L
.04291 .30902 L
.04623 .30902 L
.04944 .30902 L
.05252 .30902 L
.0558 .30902 L
.05896 .30902 L
.062 .30902 L
.06368 .30902 L
.06523 .30902 L
.06599 .30902 L
.0664 .30902 L
.06683 .30902 L
.06724 .30902 L
.06761 .30902 L
.06779 .30902 L
.06799 .30902 L
.06808 .30902 L
.06817 .30902 L
.06826 .30902 L
.06834 .30902 L
.06844 .30902 L
.06849 .30902 L
.06855 .30902 L
.06864 .30902 L
.06874 .30902 L
.06883 .30902 L
.06893 .30902 L
.06902 .30902 L
.0691 .30902 L
.06929 .30902 L
.0695 .30902 L
.06972 .30902 L
.06992 .30902 L
.07029 .30902 L
.07063 .30902 L
.07139 .30902 L
.07178 .30902 L
.07219 .30902 L
.07293 .30902 L
.07372 .30902 L
.0746 .30902 L
.07616 .30902 L
.07704 .30902 L
.07784 .30902 L
Mistroke
.07936 .30902 L
.08103 .30902 L
.08261 .30902 L
.0843 .30902 L
.08602 .30902 L
.08764 .30902 L
.09074 .30902 L
.09234 .30902 L
.09403 .30902 L
.09708 .30902 L
.09865 .30902 L
.10033 .30902 L
.10366 .30902 L
.10686 .30902 L
.10994 .30902 L
.11322 .30902 L
.11637 .30902 L
.11941 .30902 L
.12264 .30902 L
.12575 .30902 L
.12905 .30902 L
.13224 .30902 L
.1353 .30902 L
.13701 .30902 L
.13856 .30902 L
.13934 .30902 L
.13975 .30902 L
.14018 .30902 L
.14056 .30902 L
.14077 .30902 L
.14097 .30902 L
.14107 .30902 L
.14115 .30902 L
.14124 .30902 L
.14132 .30902 L
.14142 .30902 L
.14152 .30902 L
.14161 .30902 L
.1417 .30902 L
.1418 .30902 L
.14189 .30902 L
.14199 .30902 L
.14209 .30902 L
.14231 .30902 L
.14251 .30902 L
.14289 .30902 L
.14325 .30902 L
.14367 .30902 L
.14405 .30902 L
.14493 .30902 L
Mistroke
.1457 .30902 L
.14643 .30902 L
.14728 .30902 L
.14809 .30902 L
.14971 .30902 L
.1512 .30902 L
.15279 .30902 L
.15427 .30902 L
.15741 .30902 L
.15913 .30902 L
.16075 .30902 L
.16384 .30902 L
.16714 .30902 L
.17031 .30902 L
.17336 .30902 L
.1766 .30902 L
.17973 .30902 L
.18132 .30902 L
.18305 .30902 L
.18386 .30902 L
.18471 .30902 L
.18551 .30902 L
.18625 .30902 L
.18662 .30902 L
.187 .30902 L
.1872 .30902 L
.18739 .30902 L
.1875 .30902 L
.1876 .30902 L
.18765 .30902 L
.18771 .30902 L
.18781 .30902 L
.18791 .30902 L
.18799 .30902 L
.18808 .30902 L
.18819 .30902 L
.18829 .30902 L
.18839 .30902 L
.18858 .30902 L
.18875 .30902 L
.18891 .30902 L
.18928 .30902 L
.18969 .30902 L
.19013 .30902 L
.19093 .30902 L
.19171 .30902 L
.19243 .30902 L
.19394 .30902 L
.1948 .30902 L
.1956 .30902 L
Mistroke
.19724 .30902 L
.19873 .30902 L
.2004 .30902 L
.20194 .30902 L
.20502 .30902 L
.20818 .30902 L
.21121 .30902 L
.21445 .30902 L
.21756 .30902 L
.21914 .30902 L
.22086 .30902 L
.22166 .30902 L
.22252 .30902 L
.22293 .30902 L
.22332 .30902 L
.2237 .30902 L
.22405 .30902 L
.22442 .30902 L
.22462 .30902 L
.22473 .30902 L
.22483 .30902 L
.22494 .30902 L
.22504 .30902 L
.22509 .30902 L
.22515 .30902 L
.2252 .30902 L
.22526 .30902 L
.22536 .30902 L
.22545 .30902 L
.22555 .30902 L
.22566 .30902 L
.22584 .30902 L
.22603 .30902 L
.22637 .30902 L
.22678 .30902 L
.22714 .30902 L
.22795 .30902 L
.22868 .30902 L
.22949 .30902 L
.23035 .30902 L
.23192 .30902 L
.23339 .30902 L
.23502 .30902 L
.23651 .30902 L
.2397 .30902 L
.24277 .30902 L
.24603 .30902 L
.24918 .30903 L
.25078 .30903 L
.25252 .30903 L
Mistroke
.25333 .30903 L
.2542 .30903 L
.25493 .30903 L
.25532 .30903 L
.25574 .30903 L
.25596 .30903 L
.25616 .30903 L
.25635 .30903 L
.25656 .30903 L
.25665 .30903 L
.25675 .30903 L
.25684 .30903 L
.25692 .30903 L
.25701 .30903 L
.25711 .30903 L
.25721 .30903 L
.25731 .30903 L
.25741 .30903 L
.25747 .30903 L
.25752 .30903 L
.25762 .30903 L
.25773 .30903 L
.25792 .30903 L
.25812 .30903 L
.25857 .30903 L
.25899 .30903 L
.25939 .30903 L
.25982 .30903 L
.26062 .30903 L
.26139 .30903 L
.2621 .30903 L
.2636 .30903 L
.26525 .30902 L
.2668 .30902 L
.26848 .30901 L
.27178 .309 L
.27495 .30898 L
.27801 .30896 L
.27971 .30895 L
.28126 .30895 L
.28203 .30894 L
.28287 .30894 L
.28366 .30894 L
.28404 .30894 L
.28439 .30894 L
.28476 .30894 L
.28497 .30894 L
.28507 .30894 L
.28517 .30894 L
.28526 .30894 L
Mistroke
.28535 .30894 L
.28543 .30894 L
.28551 .30894 L
.28561 .30894 L
.2857 .30894 L
.28579 .30894 L
.28589 .30894 L
.286 .30894 L
.28609 .30894 L
.2863 .30894 L
.2865 .30894 L
.28668 .30894 L
.2871 .30894 L
.28755 .30894 L
.2883 .30894 L
.28914 .30895 L
.29001 .30895 L
.29082 .30896 L
.29244 .30897 L
.29393 .30899 L
.29711 .30905 L
.30017 .30912 L
.30343 .3092 L
.30656 .30928 L
.30738 .30929 L
.30827 .30931 L
.30905 .30932 L
.30945 .30932 L
.30989 .30933 L
.31032 .30933 L
.31072 .30933 L
.31091 .30933 L
.31101 .30933 L
.31111 .30933 L
.31122 .30933 L
.31131 .30933 L
.3114 .30933 L
.31149 .30933 L
.31159 .30933 L
.31164 .30933 L
.31169 .30933 L
.3118 .30933 L
.31186 .30933 L
.31191 .30933 L
.31211 .30933 L
.3123 .30933 L
.31252 .30933 L
.31272 .30933 L
.31318 .30933 L
.31355 .30932 L
Mistroke
.31395 .30932 L
.31468 .3093 L
.31554 .30928 L
.31633 .30926 L
.31786 .3092 L
.31952 .30911 L
.32278 .30888 L
.32592 .30861 L
.32925 .30832 L
.33093 .30819 L
.33166 .30814 L
.33247 .3081 L
.33319 .30806 L
.33359 .30805 L
.33397 .30804 L
.33418 .30803 L
.3344 .30803 L
.33459 .30802 L
.33479 .30802 L
.33499 .30802 L
.33509 .30802 L
.33519 .30802 L
.33528 .30802 L
.33537 .30802 L
.33546 .30802 L
.33556 .30802 L
.33566 .30802 L
.33572 .30802 L
.33577 .30802 L
.33586 .30802 L
.33596 .30802 L
.33614 .30802 L
.33633 .30803 L
.33675 .30804 L
.33714 .30805 L
.33785 .30808 L
.33862 .30813 L
.33943 .3082 L
.34032 .30829 L
.34193 .30851 L
.34519 .30915 L
.34834 .30993 L
.35168 .31079 L
.35335 .31116 L
.35409 .3113 L
.3549 .31143 L
.35567 .31153 L
.35605 .31157 L
.3564 .3116 L
.35659 .31161 L
Mistroke
.3568 .31162 L
.35698 .31163 L
.35717 .31164 L
.35727 .31164 L
.35738 .31164 L
.35744 .31165 L
.35749 .31165 L
.35755 .31165 L
.3576 .31165 L
.35769 .31165 L
.35779 .31165 L
.35789 .31165 L
.35799 .31165 L
.35809 .31164 L
.3582 .31164 L
.35831 .31164 L
.35842 .31163 L
.35881 .31161 L
.35904 .3116 L
.35925 .31158 L
.35971 .31153 L
.36054 .3114 L
.36132 .31124 L
.36292 .31077 L
.3644 .31018 L
.36754 .3085 L
.37089 .30634 L
.37257 .30527 L
.37411 .30439 L
.37562 .3037 L
.37638 .30343 L
.37681 .30331 L
.37721 .30321 L
.37761 .30314 L
.37781 .3031 L
.37803 .30308 L
.37822 .30306 L
.37832 .30305 L
.37842 .30305 L
.37851 .30304 L
.3786 .30304 L
.37869 .30304 L
.37878 .30304 L
.37889 .30304 L
.37898 .30304 L
.37904 .30305 L
.37909 .30305 L
.3792 .30305 L
.3794 .30307 L
.37959 .30309 L
Mistroke
.37979 .30312 L
.38001 .30316 L
.38046 .30326 L
.38088 .30339 L
.38128 .30353 L
.38203 .30388 L
.38283 .30436 L
.38371 .305 L
.38529 .30647 L
.38698 .30842 L
.39001 .31259 L
.39324 .31707 L
.39472 .31879 L
.39556 .31959 L
.39634 .3202 L
.39712 .32064 L
.39734 .32074 L
.39755 .32082 L
.39774 .32088 L
.39795 .32094 L
.39816 .32098 L
.39827 .32099 L
.39837 .321 L
.39847 .32101 L
.39856 .32102 L
.39866 .32102 L
.39876 .32102 L
.39887 .32101 L
.39893 .32101 L
.39898 .321 L
.39909 .32099 L
.39918 .32098 L
.3994 .32093 L
.39964 .32086 L
.40004 .32071 L
.40041 .32051 L
.40125 .31989 L
.40206 .31905 L
.40294 .31788 L
.40465 .31486 L
.40626 .31122 L
.40934 .30291 L
.4109 .29854 L
.41262 .29409 L
.4134 .29231 L
.41425 .29063 L
.41504 .28932 L
.41578 .28838 L
.41615 .28801 L
.41655 .2877 L
Mistroke
.41677 .28756 L
.41699 .28746 L
.41718 .2874 L
.41729 .28737 L
.41739 .28735 L
.41748 .28734 L
.41759 .28733 L
.41769 .28733 L
.41778 .28734 L
.41789 .28735 L
.41795 .28736 L
.418 .28738 L
.41811 .28741 L
.41821 .28744 L
.41841 .28753 L
.41863 .28766 L
.41908 .28802 L
.41946 .28843 L
.41987 .28899 L
.4207 .29046 L
.42147 .29224 L
.42218 .29425 L
.42531 .3064 L
.42864 .32276 L
.43031 .33071 L
.43185 .33703 L
.43262 .33964 L
.43335 .34166 L
.4341 .34327 L
.4345 .3439 L
.43471 .34416 L
.43493 .34439 L
.43515 .34457 L
.43535 .34468 L
.43545 .34472 L
.43556 .34475 L
.43565 .34477 L
.43575 .34477 L
.4358 .34477 L
.43585 .34477 L
.43595 .34475 L
.43601 .34474 L
.43607 .34472 L
.43618 .34467 L
.43629 .34461 L
.43639 .34454 L
.43663 .34434 L
.437 .34388 L
.43741 .34319 L
.43784 .34225 L
Mistroke
.43824 .34116 L
.43903 .33849 L
.43986 .33489 L
.44135 .32665 L
.44441 .30418 L
.44767 .27809 L
.44917 .26783 L
.44996 .26335 L
.4508 .2595 L
.45123 .25794 L
.4517 .25655 L
.4519 .25605 L
.45212 .2556 L
.45233 .25525 L
.45252 .25499 L
.45272 .25478 L
.45283 .25471 L
.45289 .25467 L
.45295 .25465 L
.45301 .25463 L
.45306 .25462 L
.45317 .25461 L
.45326 .25462 L
.45336 .25464 L
.45345 .25469 L
.45355 .25475 L
.45373 .25491 L
.45394 .25518 L
.45414 .2555 L
.45452 .25635 L
.45493 .25758 L
.45567 .26059 L
.45646 .26498 L
.45734 .27113 L
.4589 .28514 L
.46057 .30362 L
.46388 .34399 L
.46553 .36214 L
.46634 .36962 L
.46706 .3754 L
.46783 .38024 L
.46818 .38201 L
.46855 .38355 L
.46874 .38421 L
.46894 .38482 L
.46913 .38528 L
.46931 .38561 L
.46941 .38576 L
.46951 .3859 L
.46957 .38596 L
Mistroke
.46963 .38601 L
.46968 .38605 L
.46973 .38608 L
.46982 .38612 L
.46992 .38613 L
.47002 .38611 L
.47013 .38606 L
.47023 .38599 L
.47032 .3859 L
.47053 .3856 L
.47072 .38521 L
.4709 .38476 L
.4713 .38339 L
.47174 .38137 L
.47262 .37565 L
.47343 .36847 L
.47493 .35078 L
.47659 .32599 L
.47983 .27032 L
.48132 .24631 L
.48294 .22491 L
.48382 .21628 L
.48425 .21299 L
.48464 .21056 L
.48483 .20955 L
.48504 .20862 L
.48522 .20795 L
.48542 .20735 L
.48563 .20688 L
.48575 .2067 L
.4858 .20663 L
.48586 .20658 L
.48596 .20651 L
.48605 .20648 L
.48615 .20648 L
.4862 .2065 L
.48625 .20653 L
.48635 .20661 L
.48645 .20674 L
.48653 .20687 L
.48663 .20706 L
.48684 .2076 L
.48703 .20826 L
.48738 .20985 L
.48775 .21211 L
.48862 .21948 L
.48941 .22869 L
.49095 .25299 L
.49262 .28672 L
.49591 .36191 L
Mistroke
.49754 .39552 L
.49834 .40928 L
.49907 .41983 L
.49943 .42423 L
.49983 .42837 L
.50017 .43137 L
.50054 .43405 L
.50073 .43514 L
.50094 .4361 L
.50105 .43655 L
.50116 .43689 L
.50126 .43719 L
.50136 .43741 L
.50145 .43756 L
.50154 .43767 L
.50164 .43775 L
.50173 .43778 L
.50183 .43776 L
.50193 .43768 L
.50203 .43755 L
.50212 .43738 L
.50222 .43715 L
.50231 .43687 L
.50249 .43623 L
.50268 .43534 L
.50289 .43415 L
.50327 .4314 L
.50362 .42817 L
.50442 .41837 L
.50528 .40442 L
.507 .36688 L
.50861 .32314 L
.51171 .23448 L
.51328 .19655 L
.51417 .17954 L
.5146 .17283 L
.515 .16741 L
.51538 .16317 L
.5158 .15958 L
.51599 .15835 L
.51618 .15729 L
.51635 .15658 L
.51643 .15628 L
.51653 .156 L
.51663 .15578 L
.51669 .15569 L
.51674 .15563 L
.51684 .15555 L
.51694 .15554 L
.51699 .15557 L
Mistroke
.51706 .15562 L
.51711 .15569 L
.51717 .15578 L
.51727 .156 L
.51738 .1563 L
.51757 .15706 L
.51775 .15801 L
.51817 .16101 L
.51857 .16499 L
.51901 .17054 L
.5198 .18375 L
.52129 .21834 L
.52455 .32391 L
.52607 .37595 L
.5277 .42577 L
.5286 .44802 L
.52942 .46423 L
.52983 .47055 L
.53021 .47536 L
.53061 .47922 L
.53082 .48077 L
.53092 .48143 L
.53104 .48205 L
.53114 .48248 L
.53125 .48286 L
.53131 .48303 L
.53136 .48316 L
.53147 .48335 L
.53156 .48344 L
.53166 .48346 L
.53176 .4834 L
.53186 .48325 L
.53192 .48314 L
.53198 .48299 L
.53209 .48263 L
.53229 .4817 L
.53253 .48019 L
.53275 .47838 L
.53312 .47442 L
.53354 .46878 L
.53437 .45345 L
.53518 .43355 L
.53593 .41172 L
.53761 .35277 L
.5408 .22771 L
.54227 .17847 L
.5431 .15577 L
.54388 .13893 L
.54425 .13263 L
.54464 .12725 L
Mistroke
.54485 .12497 L
.54507 .1229 L
.54527 .12141 L
.54546 .12036 L
.54557 .11992 L
.54562 .11973 L
.54568 .11956 L
.54573 .11944 L
.54579 .11934 L
.54589 .11922 L
.54599 .1192 L
.54609 .11927 L
.54619 .11943 L
.54628 .11966 L
.54639 .12004 L
.54649 .1205 L
.54673 .12191 L
.54693 .12356 L
.54715 .12576 L
.54758 .13135 L
.54798 .13796 L
.54887 .15777 L
.55049 .20878 L
.55366 .34109 L
.55526 .40717 L
.55671 .45724 L
.55752 .47861 L
.55828 .49375 L
.5587 .49977 L
.55908 .50381 L
.55928 .50533 L
.5594 .50602 L
.55951 .50654 L
.55962 .50695 L
.55968 .50712 L
.55974 .50725 L
.55984 .5074 L
.5599 .50743 L
.55996 .50742 L
.56006 .50733 L
.56011 .50725 L
.56017 .50712 L
.56027 .50682 L
.56036 .50644 L
.56057 .50525 L
.5608 .50347 L
.56122 .49884 L
.5616 .4931 L
.56237 .47737 L
.56309 .45763 L
Mistroke
.56469 .40062 L
.56616 .33646 L
.56931 .19816 L
.57014 .16847 L
.57103 .14221 L
.57145 .13248 L
.57188 .12396 L
.57225 .11816 L
.57266 .11343 L
.57286 .11172 L
.57296 .111 L
.57308 .11036 L
.57318 .10992 L
.57323 .10973 L
.57329 .10955 L
.57338 .10933 L
.57348 .10922 L
.57357 .10921 L
.57368 .1093 L
.57378 .1095 L
.57387 .10978 L
.57396 .11015 L
.57404 .11056 L
.57423 .11175 L
.57444 .1136 L
.57464 .11575 L
.57509 .12213 L
.57549 .12947 L
.57591 .1389 L
.57748 .18805 L
.57895 .24877 L
.58208 .39066 L
.58289 .42332 L
.58378 .45387 L
.58462 .47677 L
.58499 .48485 L
.58539 .492 L
.58559 .49487 L
.5858 .49745 L
.58599 .49944 L
.58617 .50093 L
.58633 .50201 L
.58642 .50245 L
.58651 .50283 L
.58662 .50314 L
.58671 .50332 L
.58681 .5034 L
.58689 .50339 L
.58699 .50329 L
.58709 .50306 L
Mistroke
.58719 .50274 L
.58727 .50235 L
.58749 .50105 L
.5877 .49935 L
.5881 .49463 L
.58855 .4875 L
.58938 .46888 L
.59013 .44665 L
.59181 .38237 L
.59503 .23912 L
.59651 .18343 L
.59735 .15883 L
.59776 .14909 L
.59813 .14163 L
.5985 .13558 L
.5989 .13064 L
.59912 .12866 L
.59922 .12796 L
.59933 .1273 L
.59942 .12683 L
.59952 .12643 L
.59958 .12626 L
.59963 .12613 L
.59973 .12596 L
.59983 .1259 L
.59994 .12595 L
.60004 .12612 L
.60013 .12636 L
.60023 .12675 L
.60035 .12732 L
.60056 .12871 L
.60078 .13068 L
.60101 .13331 L
.60142 .13942 L
.60218 .15495 L
.603 .17734 L
.60447 .22972 L
.60606 .29643 L
.60778 .36939 L
.60859 .39982 L
.60944 .42788 L
.61024 .4491 L
.61098 .46354 L
.61135 .46878 L
.61173 .47284 L
.61193 .47435 L
.61212 .47538 L
.61222 .47582 L
.61232 .4761 L
.61238 .47622 L
Mistroke
.61243 .47631 L
.61249 .47637 L
.61254 .47639 L
.61262 .47637 L
.61272 .47626 L
.6128 .47608 L
.61288 .47585 L
.61297 .4755 L
.61307 .47502 L
.61325 .47389 L
.61344 .47235 L
.61364 .47031 L
.61401 .46563 L
.61444 .45846 L
.61483 .45039 L
.61573 .42741 L
.61735 .37267 L
.61898 .30831 L
.62052 .24976 L
.62199 .20303 L
.62281 .18335 L
.62317 .17657 L
.62356 .17041 L
.62395 .16576 L
.62416 .16381 L
.62436 .16236 L
.62445 .16183 L
.62455 .16136 L
.62463 .16102 L
.62471 .16073 L
.62481 .1605 L
.6249 .16036 L
.625 .1603 L
.6251 .16033 L
.6252 .16046 L
.62525 .16057 L
.62531 .16072 L
.62541 .16106 L
.62551 .16146 L
.62572 .1627 L
.62595 .16451 L
.62638 .16908 L
.62676 .17465 L
.62756 .18993 L
.62829 .20821 L
.62996 .26038 L
.6331 .36869 L
.63393 .39229 L
.63482 .41303 L
.63524 .42062 L
Mistroke
.63567 .42718 L
.63604 .43156 L
.63625 .43354 L
.63644 .43503 L
.63665 .43623 L
.63675 .43672 L
.63687 .43713 L
.63696 .4374 L
.63706 .43757 L
.63716 .43768 L
.63721 .4377 L
.63727 .43769 L
.63736 .43762 L
.63745 .43748 L
.63755 .43726 L
.63765 .43692 L
.63784 .43607 L
.63801 .43503 L
.63843 .43152 L
.63888 .42616 L
.63969 .41261 L
.64046 .39599 L
.64129 .37423 L
.64298 .32357 L
.64468 .27224 L
.64623 .23335 L
.64699 .21889 L
.6474 .21283 L
.64783 .20766 L
.6482 .20427 L
.64842 .20281 L
.64862 .20176 L
.64871 .20139 L
.6488 .20106 L
.64888 .20084 L
.64897 .20065 L
.64906 .20051 L
.64915 .20045 L
.64925 .20044 L
.64935 .20051 L
.64944 .20065 L
.64953 .20084 L
.64963 .20112 L
.64974 .2015 L
.64995 .20253 L
.65015 .20377 L
.65053 .20693 L
.65089 .21085 L
.65168 .22252 L
.65256 .23927 L
Mistroke
.65582 .32142 L
.65733 .35732 L
.65813 .37274 L
.65896 .38549 L
.65939 .39041 L
.65962 .39256 L
.65986 .3945 L
.66008 .39595 L
.66029 .39699 L
.66038 .39739 L
.66049 .39776 L
.66058 .39802 L
.66068 .39824 L
.66078 .39839 L
.66088 .39847 L
.66093 .39849 L
.66099 .3985 L
.66109 .39845 L
.66114 .3984 L
.6612 .39832 L
.6613 .39814 L
.66142 .39784 L
.66153 .39749 L
.66172 .39668 L
.66193 .39554 L
.6623 .39281 L
.6627 .38908 L
.66306 .38483 L
.6639 .37266 L
.66559 .34022 L
.66871 .27453 L
.66952 .26078 L
.66995 .2546 L
.67041 .24896 L
.67085 .24449 L
.67125 .24132 L
.67144 .24009 L
.67165 .23898 L
.67185 .23815 L
.67203 .23758 L
.67213 .23733 L
.67222 .23715 L
.67231 .23703 L
.6724 .23695 L
.67251 .23691 L
.67256 .23692 L
.67262 .23694 L
.67272 .23702 L
.67281 .23714 L
.6729 .23731 L
Mistroke
.67299 .23752 L
.67316 .23803 L
.67334 .23874 L
.67354 .2397 L
.67396 .24238 L
.6744 .24615 L
.6752 .25506 L
.67692 .2812 L
.67854 .30983 L
.68001 .33434 L
.68085 .34601 L
.68163 .35478 L
.68203 .35833 L
.68241 .36109 L
.68261 .36235 L
.68284 .3635 L
.68304 .36435 L
.68323 .36498 L
.68344 .36547 L
.68354 .36566 L
.6836 .36573 L
.68366 .3658 L
.68372 .36585 L
.68377 .36588 L
.68383 .36589 L
.6839 .3659 L
.68395 .36588 L
.68401 .36586 L
.68411 .36577 L
.68421 .36565 L
.68431 .36547 L
.6845 .36503 L
.6847 .36439 L
.68492 .36349 L
.68534 .36125 L
.68574 .35851 L
.68649 .35188 L
.68816 .33163 L
.69123 .28972 L
.69205 .2807 L
.69281 .27384 L
.69324 .27084 L
.6937 .26827 L
.6939 .26737 L
.69411 .26658 L
.6943 .26603 L
.6945 .26557 L
.6946 .26538 L
.6947 .26524 L
.6948 .26515 L
Mistroke
.6949 .26508 L
.69499 .26505 L
.69507 .26504 L
.69516 .26507 L
.69526 .26513 L
.69536 .26522 L
.69547 .26537 L
.69558 .26556 L
.69569 .26578 L
.69589 .2663 L
.69608 .26692 L
.69645 .26847 L
.69679 .27024 L
.69755 .2754 L
.69916 .29039 L
.70064 .30659 L
.70228 .32354 L
.70308 .33041 L
.70381 .3355 L
.70417 .33753 L
.70456 .33935 L
.70493 .34068 L
.70528 .34158 L
.70546 .34192 L
.70564 .34216 L
.70574 .34225 L
.70583 .34231 L
.70593 .34235 L
.70599 .34236 L
.70604 .34237 L
.7061 .34236 L
.70615 .34235 L
.70624 .3423 L
.70635 .34222 L
.70646 .34211 L
.70667 .34181 L
.70685 .34143 L
.70723 .34042 L
.70763 .33894 L
.70836 .33535 L
.71001 .32377 L
.7116 .31055 L
.71332 .29709 L
.71413 .29207 L
.71456 .28977 L
.71498 .28795 L
.71537 .28656 L
.71557 .28595 L
.71578 .28541 L
.71596 .28503 L
Mistroke
.71616 .28469 L
.71625 .28457 L
.71634 .28446 L
.71643 .28437 L
.71651 .2843 L
.71661 .28424 L
.71666 .28422 L
.71672 .2842 L
.71677 .28419 L
.71683 .28419 L
.71694 .28419 L
.71703 .28422 L
.71713 .28427 L
.71722 .28434 L
.71733 .28443 L
.71757 .28474 L
.7178 .28513 L
.71822 .28613 L
.71862 .28739 L
.71899 .2888 L
.71983 .29271 L
.723 .31189 L
.72381 .31656 L
.72459 .32039 L
.72528 .32319 L
.72568 .32448 L
.72604 .32544 L
.72643 .32626 L
.72665 .32659 L
.72685 .32684 L
.72694 .32693 L
.72704 .32701 L
.72712 .32707 L
.72721 .32712 L
.72731 .32716 L
.7274 .32718 L
.72745 .32718 L
.72751 .32719 L
.7276 .32718 L
.7277 .32715 L
.72775 .32713 L
.72781 .32711 L
.72791 .32705 L
.72802 .32697 L
.72822 .32677 L
.72841 .32654 L
.72886 .32576 L
.72928 .32477 L
.73005 .32241 L
.73087 .31926 L
Mistroke
.73235 .31262 L
.73395 .30535 L
.73479 .30203 L
.73568 .29918 L
.73607 .29821 L
.73648 .29735 L
.73672 .29694 L
.73693 .29664 L
.73715 .29638 L
.73736 .29619 L
.73754 .29607 L
.73763 .29603 L
.73773 .29599 L
.73784 .29596 L
.73789 .29595 L
.73795 .29595 L
.73804 .29594 L
.73815 .29596 L
.73824 .29598 L
.73833 .29601 L
.73842 .29605 L
.73851 .29609 L
.73871 .29624 L
.7389 .29641 L
.73927 .29687 L
.73968 .29754 L
.7405 .29935 L
.74198 .30373 L
.74367 .30941 L
.74522 .31404 L
.74598 .31581 L
.74639 .31657 L
.74682 .31723 L
.74723 .31772 L
.74743 .3179 L
.74761 .31803 L
.74779 .31813 L
.74788 .31818 L
.74798 .31821 L
.74807 .31824 L
.74815 .31826 L
.74824 .31827 L
.74834 .31827 L
.74843 .31827 L
.74849 .31827 L
.74854 .31826 L
.74865 .31824 L
.74871 .31822 L
.74876 .3182 L
.74895 .31812 L
Mistroke
.74915 .318 L
.74958 .31764 L
.75004 .31709 L
.75088 .31575 L
.75166 .31418 L
.7548 .30687 L
.75562 .30526 L
.75605 .30454 L
.75651 .30389 L
.75691 .30342 L
.75735 .30302 L
.75755 .30289 L
.75775 .30277 L
.75795 .30268 L
.75813 .30262 L
.75822 .3026 L
.75831 .30258 L
.75841 .30257 L
.75851 .30256 L
.75862 .30256 L
.75867 .30257 L
.75873 .30257 L
.75883 .30258 L
.75892 .3026 L
.75902 .30263 L
.75911 .30266 L
.75928 .30272 L
.75966 .30293 L
.76007 .30325 L
.76046 .30361 L
.76132 .30468 L
.76296 .30726 L
.76448 .30982 L
.76595 .31185 L
.76637 .31231 L
.76677 .31267 L
.76716 .31296 L
.76752 .31318 L
.76771 .31326 L
.76792 .31334 L
.76802 .31337 L
.76811 .31339 L
.76821 .31341 L
.76829 .31343 L
.76839 .31344 L
.76849 .31345 L
.76859 .31345 L
.76868 .31345 L
.76873 .31345 L
.76879 .31345 L
Mistroke
.76889 .31344 L
.76894 .31343 L
.76899 .31342 L
.76911 .3134 L
.76929 .31336 L
.76948 .3133 L
.76982 .31315 L
.77019 .31294 L
.77059 .31267 L
.77216 .31116 L
.77384 .3092 L
.77544 .30751 L
.77588 .30713 L
.77634 .30679 L
.77674 .30653 L
.77717 .30632 L
.77739 .30623 L
.77759 .30616 L
.77778 .30611 L
.77796 .30607 L
.77814 .30604 L
.77823 .30603 L
.77832 .30602 L
.77841 .30602 L
.77852 .30601 L
.77861 .30601 L
.7787 .30601 L
.7788 .30602 L
.7789 .30603 L
.779 .30604 L
.77909 .30605 L
.77931 .3061 L
.77952 .30615 L
.77993 .30629 L
.78038 .30649 L
.78114 .30692 L
.78197 .3075 L
.78366 .30884 L
.78448 .30947 L
.78535 .31005 L
.78609 .31046 L
.78651 .31065 L
.78689 .31079 L
.78709 .31085 L
.7873 .3109 L
.78748 .31094 L
.78767 .31097 L
.78788 .311 L
.788 .31101 L
.78805 .31101 L
Mistroke
.78811 .31102 L
.78821 .31102 L
.7883 .31102 L
.7884 .31103 L
.78845 .31102 L
.78851 .31102 L
.78859 .31102 L
.78868 .31102 L
.78877 .31101 L
.78885 .311 L
.78904 .31098 L
.78923 .31095 L
.7896 .31087 L
.79 .31076 L
.79083 .31046 L
.79158 .31011 L
.79326 .30922 L
.79407 .3088 L
.79493 .3084 L
.79572 .30809 L
.79611 .30797 L
.79646 .30788 L
.7968 .30781 L
.79717 .30775 L
.79737 .30773 L
.79747 .30772 L
.79756 .30771 L
.79765 .3077 L
.79774 .3077 L
.79784 .3077 L
.79793 .30769 L
.79803 .30769 L
.79813 .30769 L
.79823 .30769 L
.79829 .3077 L
.79834 .3077 L
.79845 .3077 L
.79857 .30771 L
.79878 .30773 L
.79897 .30775 L
.79918 .30778 L
.79955 .30784 L
.8003 .30801 L
.80111 .30826 L
.80258 .30877 L
.80416 .30931 L
.805 .30954 L
.80545 .30965 L
.80589 .30973 L
.8063 .30979 L
Mistroke
.80652 .30982 L
.80675 .30984 L
.80695 .30986 L
.80705 .30986 L
.80716 .30987 L
.80726 .30987 L
.80735 .30988 L
.80745 .30988 L
.80754 .30988 L
.80763 .30988 L
.80772 .30988 L
.80782 .30988 L
.80792 .30988 L
.808 .30987 L
.80809 .30987 L
.80827 .30986 L
.80846 .30985 L
.80866 .30983 L
.80907 .30979 L
.80989 .30966 L
.81064 .30952 L
.81232 .30913 L
.81313 .30894 L
.81399 .30877 L
.81478 .30863 L
.81517 .30858 L
.81552 .30854 L
.81589 .30851 L
.81623 .30849 L
.81642 .30848 L
.81659 .30847 L
.8167 .30847 L
.81679 .30846 L
.81689 .30846 L
.81699 .30846 L
.81709 .30846 L
.81719 .30846 L
.81724 .30846 L
.8173 .30846 L
.8174 .30846 L
.8175 .30847 L
.81759 .30847 L
.81777 .30848 L
.81798 .30849 L
.81817 .3085 L
.81861 .30853 L
.81938 .30861 L
.82011 .3087 L
.82176 .30895 L
.82324 .30916 L
Mistroke
.82408 .30925 L
.82449 .30929 L
.82486 .30932 L
.82526 .30934 L
.82545 .30935 L
.82564 .30936 L
.82585 .30936 L
.82594 .30936 L
.82604 .30937 L
.82615 .30937 L
.82625 .30937 L
.82631 .30937 L
.82636 .30937 L
.82642 .30937 L
.82647 .30937 L
.82653 .30937 L
.82659 .30937 L
.82664 .30937 L
.82669 .30937 L
.82679 .30937 L
.8269 .30937 L
.82711 .30936 L
.82735 .30935 L
.82777 .30934 L
.82817 .30931 L
.82901 .30925 L
.8298 .30918 L
.83129 .30904 L
.83276 .30891 L
.83316 .30888 L
.83359 .30885 L
.83396 .30884 L
.83437 .30882 L
.83478 .30881 L
.835 .3088 L
.8351 .3088 L
.8352 .3088 L
.83529 .3088 L
.83539 .3088 L
.83549 .3088 L
.83557 .3088 L
.83566 .30879 L
.83576 .3088 L
.83586 .3088 L
.83596 .3088 L
.83607 .3088 L
.83618 .3088 L
.83639 .3088 L
.83659 .30881 L
.83678 .30881 L
Mistroke
.8372 .30882 L
.83765 .30884 L
.83921 .30892 L
.84068 .30901 L
.84146 .30906 L
.84229 .3091 L
.843 .30913 L
.8434 .30914 L
.84378 .30915 L
.84399 .30915 L
.84418 .30915 L
.84429 .30915 L
.8444 .30915 L
.8445 .30915 L
.84456 .30915 L
.84462 .30915 L
.84472 .30915 L
.84478 .30916 L
.84483 .30916 L
.84493 .30916 L
.84504 .30915 L
.84514 .30915 L
.84524 .30915 L
.84542 .30915 L
.8456 .30915 L
.84579 .30915 L
.84613 .30914 L
.84691 .30912 L
.84849 .30907 L
.84996 .30901 L
.8508 .30898 L
.85159 .30896 L
.85231 .30895 L
.85271 .30894 L
.8529 .30894 L
.85308 .30894 L
.85326 .30893 L
.85345 .30893 L
.85355 .30893 L
.85365 .30893 L
.85375 .30893 L
.8538 .30893 L
.85386 .30893 L
.85395 .30893 L
.85404 .30893 L
.85413 .30893 L
.85423 .30893 L
.85432 .30893 L
.8544 .30893 L
.85458 .30893 L
Mistroke
.8548 .30894 L
.855 .30894 L
.85538 .30894 L
.85624 .30896 L
.85931 .30903 L
.86012 .30904 L
.86089 .30906 L
.86131 .30906 L
.86154 .30906 L
.86177 .30907 L
.86197 .30907 L
.86219 .30907 L
.86229 .30907 L
.86239 .30907 L
.86249 .30907 L
.86257 .30907 L
.86267 .30907 L
.86276 .30907 L
.86286 .30907 L
.86296 .30907 L
.86301 .30907 L
.86307 .30907 L
.86318 .30907 L
.86328 .30907 L
.86337 .30907 L
.86373 .30907 L
.86393 .30906 L
.86411 .30906 L
.86497 .30906 L
.86578 .30905 L
.86725 .30902 L
.86809 .30901 L
.86887 .309 L
.86964 .30899 L
.87008 .30899 L
.87047 .30899 L
.87067 .30899 L
.87089 .30899 L
.871 .30899 L
.87112 .30899 L
.87123 .30899 L
.87134 .30899 L
.87144 .30899 L
.87154 .30899 L
.87165 .30899 L
.87171 .30899 L
.87176 .30899 L
.87186 .30899 L
.87195 .30899 L
.87206 .30899 L
Mistroke
.87216 .30899 L
.87235 .30899 L
.87253 .30899 L
.87294 .30899 L
.87334 .30899 L
.87377 .30899 L
.87525 .30901 L
.87683 .30902 L
.87767 .30903 L
.87813 .30903 L
.87856 .30903 L
.87898 .30903 L
.87919 .30903 L
.87943 .30903 L
.87962 .30903 L
.87984 .30904 L
.87993 .30904 L
.88003 .30904 L
.88013 .30904 L
.88021 .30904 L
.88031 .30904 L
.88041 .30904 L
.8805 .30904 L
.88059 .30904 L
.88069 .30904 L
.88075 .30904 L
.8808 .30904 L
.881 .30904 L
.88118 .30903 L
.88137 .30903 L
.88175 .30903 L
.88217 .30903 L
.88257 .30903 L
.88332 .30903 L
.88501 .30902 L
.88579 .30901 L
.88662 .30901 L
.88732 .30901 L
.88772 .30901 L
.8881 .30901 L
.8883 .30901 L
.8885 .30901 L
.88861 .30901 L
.88871 .30901 L
.88882 .30901 L
.88887 .30901 L
.88893 .30901 L
.88903 .30901 L
.88914 .30901 L
.88919 .30901 L
Mistroke
.88924 .30901 L
.88935 .30901 L
.88945 .30901 L
.88955 .30901 L
.88973 .30901 L
.88991 .30901 L
.8901 .30901 L
.89044 .30901 L
.89122 .30901 L
.89425 .30902 L
.89505 .30902 L
.89581 .30902 L
.89623 .30902 L
.89645 .30902 L
.89669 .30902 L
.8969 .30902 L
.8971 .30902 L
.8972 .30902 L
.8973 .30902 L
.8974 .30902 L
.89749 .30902 L
.89759 .30902 L
.89768 .30902 L
.89777 .30902 L
.89786 .30902 L
.89797 .30902 L
.89802 .30902 L
.89807 .30902 L
.89827 .30902 L
.89845 .30902 L
.89864 .30902 L
.899 .30902 L
.89942 .30902 L
.89986 .30902 L
.90066 .30902 L
.90226 .30902 L
.90372 .30901 L
.9041 .30901 L
.90453 .30901 L
.90492 .30901 L
.90529 .30901 L
.90549 .30901 L
.90568 .30901 L
.90579 .30901 L
.90588 .30901 L
.90594 .30901 L
.906 .30901 L
.90605 .30901 L
.90611 .30901 L
.90616 .30901 L
Mistroke
.90622 .30901 L
.90628 .30901 L
.90633 .30901 L
.90642 .30901 L
.90653 .30901 L
.90664 .30901 L
.90674 .30901 L
.90697 .30901 L
.90718 .30901 L
.90737 .30901 L
.90781 .30901 L
.90861 .30901 L
.9101 .30902 L
.91088 .30902 L
.91173 .30902 L
.91252 .30902 L
.9129 .30902 L
.91325 .30902 L
.9136 .30902 L
.91377 .30902 L
.91396 .30902 L
.91407 .30902 L
.91417 .30902 L
.91426 .30902 L
.91437 .30902 L
.91446 .30902 L
.91455 .30902 L
.91464 .30902 L
.91473 .30902 L
.91484 .30902 L
.91493 .30902 L
.91504 .30902 L
.91515 .30902 L
.91534 .30902 L
.91555 .30902 L
.91593 .30902 L
.91629 .30902 L
.91791 .30902 L
.91939 .30902 L
.92013 .30902 L
.92091 .30902 L
.92136 .30902 L
.92177 .30902 L
.92197 .30902 L
.92218 .30902 L
.92238 .30902 L
.92257 .30902 L
.92267 .30902 L
.92277 .30902 L
.92285 .30902 L
Mistroke
.92294 .30902 L
.92305 .30902 L
.9231 .30902 L
.92315 .30902 L
.92325 .30902 L
.92335 .30902 L
.92344 .30902 L
.92353 .30902 L
.9237 .30902 L
.92407 .30902 L
.92448 .30902 L
.92486 .30902 L
.92573 .30902 L
.92723 .30902 L
.92802 .30902 L
.92885 .30902 L
.92928 .30902 L
.92974 .30902 L
.92995 .30902 L
.93016 .30902 L
.93037 .30902 L
.93056 .30902 L
.93076 .30902 L
.93086 .30902 L
.93097 .30902 L
.93103 .30902 L
.93109 .30902 L
.93115 .30902 L
.9312 .30902 L
.9313 .30902 L
.9314 .30902 L
.9315 .30902 L
.93159 .30902 L
.93169 .30902 L
.93177 .30902 L
.93198 .30902 L
.93218 .30902 L
.93258 .30902 L
.93295 .30902 L
.93377 .30902 L
.93525 .30902 L
.93607 .30902 L
.93693 .30902 L
.93766 .30902 L
.93808 .30902 L
.93847 .30902 L
.93866 .30902 L
.93887 .30902 L
.93897 .30902 L
.93907 .30902 L
Mistroke
.93916 .30902 L
.93925 .30902 L
.93935 .30902 L
.93943 .30902 L
.93953 .30902 L
.93962 .30902 L
.93971 .30902 L
.93979 .30902 L
.93987 .30902 L
.93997 .30902 L
.94018 .30902 L
.9404 .30902 L
.94081 .30902 L
.94157 .30902 L
.94314 .30902 L
.94397 .30902 L
.94486 .30902 L
.9453 .30902 L
.94572 .30902 L
.94612 .30902 L
.9465 .30902 L
.94685 .30902 L
.94703 .30902 L
.94714 .30902 L
.94723 .30902 L
.94733 .30902 L
.94743 .30902 L
.94753 .30902 L
.94759 .30902 L
.94764 .30902 L
.94774 .30902 L
.94783 .30902 L
.94793 .30902 L
.94803 .30902 L
.94822 .30902 L
.9484 .30902 L
.94881 .30902 L
.94921 .30902 L
.94964 .30902 L
.95112 .30902 L
.9527 .30902 L
.95313 .30902 L
.9536 .30902 L
.95403 .30902 L
.95443 .30902 L
.95463 .30902 L
.95484 .30902 L
.95506 .30902 L
.95518 .30902 L
.95529 .30902 L
Mistroke
.9554 .30902 L
.9555 .30902 L
.95559 .30902 L
.95568 .30902 L
.95579 .30902 L
.95584 .30902 L
.9559 .30902 L
.956 .30902 L
.9561 .30902 L
.95629 .30902 L
.95648 .30902 L
.95683 .30902 L
.95721 .30902 L
.95762 .30902 L
.95933 .30902 L
.96088 .30902 L
.96165 .30902 L
.96209 .30902 L
.96249 .30902 L
.96285 .30902 L
.96305 .30902 L
.96323 .30902 L
.96333 .30902 L
.96343 .30902 L
.96352 .30902 L
.96361 .30902 L
.96371 .30902 L
.96376 .30902 L
.96382 .30902 L
.96392 .30902 L
.96402 .30902 L
.96411 .30902 L
.96421 .30902 L
.96439 .30902 L
.9648 .30902 L
.96524 .30902 L
.96563 .30902 L
.96712 .30902 L
.96793 .30902 L
.96878 .30902 L
.96952 .30902 L
.96993 .30902 L
.97032 .30902 L
.97051 .30902 L
.97072 .30902 L
.97092 .30902 L
.97101 .30902 L
.9711 .30902 L
.97119 .30902 L
.97128 .30902 L
Mistroke
.97136 .30902 L
.97144 .30902 L
.97153 .30902 L
.97162 .30902 L
.97172 .30902 L
.97181 .30902 L
.97191 .30902 L
.97202 .30902 L
.97221 .30902 L
.9724 .30902 L
.97258 .30902 L
.97298 .30902 L
.97341 .30902 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{421.375, 260.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008>0001AB000`400?l00000o`00003ooooooooo
oooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo
003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooo
oooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool0
0?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooooooo
ool@ooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooo
ooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo0ol0003o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0
003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo
00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`
ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLoooo
o`00<?ooool3o`000?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?oo
ool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0
033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomco
oooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooo
oooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool3o`000?oooooo
g?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0013ooooo0_o^k^h3ooooo`;ok^k^6Oooool00ol0003oooooooooo`3o
ooooomcooooo000;ooooo`;o000000[o410@ooooooooooook^k^oeEEEOo^k^koooooonk^k_mEEEGo
k^k^0oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h:ooooo`03o`000?oo
oooooooo0?oooooog?ooool000cooooo00?o0000ooooooooool00_ooool01Oo^k^koEEEEomgMgOmE
EEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00[ooooo
00?o0000ooooooooool0oooooooLooooo`0000?oooooo`000?l000001?l00002ooooo`Go00001?oo
ool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooo
oa0@400:ooooo`03o`000?oooooooooo0?oooooog?ooool000Wooooo00CoA4A4omgMgOoooooo0000
1?ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000000[ooooo00?o0000ooooooooool0oooooooLooooo`002Oooool01?oMgMgo
EEEEooooool00003ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000:ooooo`Co0000oooooooKooooo`002_oo
ool00omgMgOoc<c<o`000003ooooo`;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@00[ooooo00?o0000ooooooooool0oooooooLooooo`002_oo
ool00oo^k^koA4A4o`00000?ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`;o00001Oooool00ol0003oooooooooo`3oooooomcooooo000;ooooo`03ogMgMol0
003ooooo00cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`3oooooomcooooo000Xooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool0oooooooLooooo`00:?ooool3o`0000Gooooo
00?o0000ooooooooool0oooooooLooooo`00:Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo0?oooooog?ooool002[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`36
ooooo`03o`000?oooooooooo0?oooooo4oooool0033ooooo00?o0000ooooooooool0a_ooool00ol0
003oooooooooo`3ooooooa?ooooo000`ooooo`03o`000?oooooooooo0<Kooooo0_l0003ooooooaCo
oooo000`ooooo`03o`000?oooooooooo0<Kooooo0_l0003ooooooaCooooo000`ooooo`03o`000?oo
oooooooo0<Kooooo0_l0003ooooooaCooooo000`ooooo`?o0000^_ooool00ol0003oooooooooo`09
ooooo`;o0000oooooolDooooo`00<?ooool00ol0003oooooooooo`2jooooo`;o00002Oooool00ol0
003oooooo`00003ooooooaCooooo000`ooooo`03o`000?oooooooooo0;[ooooo0_l00009ooooo`03
o`000?oooooo00000?oooooo5?ooool0033ooooo00?o0000ooooooooool0^_ooool2o`0000Wooooo
00?o0000ooooool000002Oooool2o`000?oooooo2Oooool0033ooooo00?o0000ooooooooool0^_oo
ool2o`0000Wooooo00?o0000ooooool000002Oooool2o`000?oooooo2Oooool0033ooooo00?o0000
ooooooooool0^Oooool00ol0003oooooo`000009ooooo`03o`000?oooooo000000Wooooo0_l0003o
ooooo`Wooooo000`ooooo`03o`000?oooooooooo0;Wooooo00?o0000ooooool000002Oooool00ol0
003oooooo`000009ooooo`;o0000ooooool9ooooo`00<?ooool00ol0003oooooooooo`2iooooo`03
o`000?oooooo000000Wooooo00?o0000ooooool000002Oooool2o`000?oooooo2Oooool0033ooooo
00?o0000ooooooooool0^Oooool00ol0003oooooo`000009ooooo`03o`000?oooooo000000Wooooo
0_l0003oooooo`Wooooo000`ooooo`03o`000?oooooooooo0;Wooooo00?o0000ooooool000002Ooo
ool00ol0003oooooo`000009ooooo`;o0000ooooool9ooooo`00<?ooool00ol0003oooooooooo`2i
ooooo`03o`000?oooooo000000Wooooo00?o0000ooooool000002Oooool2o`000?oooooo2Oooool0
033ooooo00?o0000ooooooooool0^Oooool00ol0003oooooo`000009ooooo`03o`000?oooooo0000
00Wooooo0_l0003oooooo`Wooooo000`ooooo`?o0000^Oooool00ol0003oooooo`000009ooooo`03
o`000?oooooo000000Wooooo0_l0003oooooo`Wooooo000`ooooo`03o`000?oooooooooo0;Wooooo
00?o0000ooooool000002Oooool00ol0003oooooo`000009ooooo`03o`000?oooooo00000?oooooo
2?ooool0033ooooo00?o0000ooooooooool0^Oooool00ol0003oooooo`000009ooooo`03o`000?oo
oooo000000Wooooo00?o0000ooooool00000ooooool8ooooo`00<?ooool00ol0003oooooooooo`2i
ooooo`03o`000?oooooo000000Wooooo00?o0000ooooool000002Oooool00ol0003oooooo`00003o
ooooo`Sooooo000`ooooo`03o`000?oooooooooo0:gooooo0_l0000:ooooo`03o`000?oooooo0000
00Wooooo00?o0000ooooool000002?ooool01?l0003oooooooooool0003oooooo`Sooooo000`oooo
o`03o`000?oooooooooo0:gooooo0_l0000:ooooo`03o`000?oooooo000000Wooooo00?o0000oooo
ool000002?ooool01?l0003oooooooooool0003oooooo`Sooooo000`ooooo`03o`000?oooooooooo
0:gooooo0_l0000:ooooo`03o`000?oooooo000000Wooooo00?o0000ooooool000002?ooool01?l0
003oooooooooool00008ooooo`;o0000oOooool0033ooooo00?o0000ooooooooool0[Oooool2o`00
00[ooooo00?o0000ooooool000002Oooool00ol0003oooooo`000008ooooo`04o`000?oooooooooo
o`0000Sooooo0_l0003mooooo`00<?ooool00ol0003oooooooooo`2]ooooo`;o00002_ooool00ol0
003oooooo`000009ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00002?oo
ool2o`000?gooooo000`ooooo`03o`000?oooooooooo0:gooooo0_l0000:ooooo`03o`000?oooooo
000000Wooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool00008ooooo`;o0000
oOooool0033ooooo00?o0000ooooooooool0[Oooool2o`0000[ooooo00?o0000ooooool000002Ooo
ool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Sooooo0_l0003mooooo`00
<?ooool3o`000:gooooo0_l0000:ooooo`03o`000?oooooo000000Wooooo00Co0000oooooooooooo
00001oooool01?l0003oooooooooool00008ooooo`;o0000oOooool0033ooooo00?o0000oooooooo
ool0[Oooool2o`0000[ooooo00?o0000ooooool000002Oooool01?l0003oooooooooool00007oooo
o`04o`000?ooooooooooo`0000Sooooo0_l0003mooooo`00<?ooool00ol0003oooooooooo`2/oooo
o`03o`000?oooooo000000[ooooo00?o0000ooooool000002Oooool01?l0003oooooooooool00007
ooooo`04o`000?ooooooooooo`0000Sooooo0_l0003mooooo`00<?ooool00ol0003oooooooooo`2/
ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooool000002Oooool01?l0003ooooooooo
ool00007ooooo`04o`000?ooooooooooo`0000Sooooo0_l0003mooooo`00<?ooool00ol0003ooooo
ooooo`2/ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooool000002Oooool01?l0003o
ooooooooool00007ooooo`04o`000?ooooooooooo`0000Sooooo0_l0003mooooo`00<?ooool00ol0
003oooooooooo`2/ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooool000002?ooool0
1Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo00002?ooool00ol0003ooooo
o`00003looooo`00<?ooool00ol0003oooooooooo`2/ooooo`04o`000?ooooooooooo`0000Wooooo
00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooo
oooooooo00002?ooool00ol0003oooooo`00003looooo`004?ooool2onk^kP?ooooo0_o^k^hIoooo
o`03o`000?oooooooooo0:cooooo00Co0000oooooooooooo00002Oooool01?l0003oooooooooool0
0007ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool00008ooooo`03
o`000?oooooo00000?cooooo0009ooooo`Go00000_ooool01oo^k^koEEEEonk^k_ooooook^k^oeEE
EOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h:ooooo`03o`00
0?oooooooooo0:cooooo00Co0000oooooooooooo00002Oooool01?l0003oooooooooool00007oooo
o`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool00008ooooo`03o`000?oo
oooo00000?cooooo0009ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01Oo^k^koEEEEomgM
gOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00[o
oooo00?o0000ooooooooool0[?ooool01?l0003oooooooooool00009ooooo`04o`000?oooooooooo
o`0000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Sooooo
00?o0000ooooool00000o?ooool00003ooooool0003o000000Co00000oooool00onHV9So8B4Qonk^
kP05ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@00[ooooo00?o0000ooooooooool0[?ooool01?l0003oooooooooool00009ooooo`04
o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?oooooo
ooooo`0000Oooooo00Co0000oooooooooooo0000o?ooool000_ooooo00?oV9RHob4Q8Oo^k^h00ooo
ool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000[ooooo00?o0000ooooooooool0[?ooool01?l0003oooooooooool00009oooo
o`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?oo
ooooooooo`0000Oooooo00Co0000oooooooooooo0000o?ooool000cooooo00_oMgMgofIVI_oooooo
ooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`00000:ooooo`Co0000Zoooool01?l0003oooooooooool00009ooooo`04
o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?oooooo
ooooo`0000Oooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`3aooooo`003Ooo
ool00ol0003oooooooooo`02onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go
410@oooooooooooooooooa0@400:ooooo`03o`000?oooooooooo0:cooooo00Co0000oooooooooooo
00002Oooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001oooool0
1?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool0
lOooool000Wooooo00Go0000okZj^_ooooooV9RHoa0@400>ooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`;o00001Oooool00ol0003oooooooooo`2/ooooo`04
o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooo
ooooooooool000001oooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo
00002?ooool00ol0003oooooooooo`3aooooo`002Oooool01OnHV9So410@o`000?lQ8B7oc<c<00co
oooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo00Co0000oooo
oooooooo00001?ooool00ol0003oooooooooo`2Pooooo`;o00002_ooool01?l0003oooooooooool0
0008ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oo
oooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000
ooooool00000l_ooool002Sooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`2P
ooooo`;o00002_ooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool00000
1oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000006oooo
o`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool00000l_ooool002Sooooo0ol00005oooo
o`03o`000?oooooooooo0:3ooooo0_l0000:ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000
ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooo
oooooooooooo000000Kooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00003boooo
o`00:Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo09oooooo00?o0000ooooool0
00002_ooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool000001oooool0
1Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`04ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool00000l_ooool002[ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`2Oooooo`03o`000?oooooo000000Wooooo00Go
0000ooooooooooooooooo`000008ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003o
oooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04oooo
o`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool00000l_ooool0033ooooo00?o0000oooo
ooooool0Woooool00ol0003oooooo`000009ooooo`05o`000?ooooooooooooooool000002?ooool0
1Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00007ooooo`03
o`000?oooooo00000?;ooooo000`ooooo`03o`000?oooooooooo09oooooo00?o0000ooooool00000
2Oooool01Ol0003ooooooooooooooooo000000Sooooo00Go0000ooooooooooooooooo`000007oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00003b
ooooo`00<?ooool00ol0003oooooooooo`2Oooooo`03o`000?oooooo000000Wooooo00Go0000oooo
ooooooooooooo`000008ooooo`05o`000?ooooooooooooooool000001oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`04ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool00000l_ooool0033ooooo00?o
0000ooooooooool0Woooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool0
00002?ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01?l0
003oooooooooool00007ooooo`03o`000?oooooo00000?;ooooo000`ooooo`?o0000Woooool01?l0
003oooooooooool00008ooooo`05o`000?ooooooooooooooool000002?ooool01Ol0003ooooooooo
oooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00007ooooo`03
o`000?oooooo00000?;ooooo000`ooooo`03o`000?oooooooooo09oooooo00Co0000oooooooooooo
00002?ooool01Ol0003ooooooooooooooooo000000Sooooo00Go0000ooooooooooooooooo`000007
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00
003booooo`00<?ooool00ol0003oooooooooo`2Oooooo`04o`000?ooooooooooo`0000Sooooo00Go
0000ooooooooooooooooo`000008ooooo`05o`000?ooooooooooooooool000001oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool00000l_ooool0033o
oooo00?o0000ooooooooool0Woooool01?l0003oooooooooool00008ooooo`05o`000?oooooooooo
ooooool000002?ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool01?l0003oooooooooool00007ooooo`03o`000?oooooo00000?;ooooo000`ooooo`03o`000?oo
oooooooo09kooooo00Go0000ooooooooooooooooo`000008ooooo`05o`000?ooooooooooooooool0
00002?ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`3W
ooooo`00<?ooool00ol0003oooooooooo`2Nooooo`05o`000?ooooooooooooooool000002?ooool0
1Ol0003ooooooooooooooooo000000Sooooo00Go0000ooooooooooooooooo`000007ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo000000So
oooo0_l0003Xooooo`00<?ooool00ol0003oooooooooo`2Nooooo`05o`000?ooooooooooooooool0
00002?ooool01Ol0003ooooooooooooooooo000000Sooooo00Go0000ooooooooooooooooo`000007
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oo
oooo000000Sooooo0_l0003Xooooo`00<?ooool00ol0003oooooooooo`2Nooooo`05o`000?oooooo
ooooooooool000002?ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooo
ooooo`000006ooooo`03o`000?oooooo000000Oooooo00?o0000ooooool00000j?ooool0033ooooo
00?o0000ooooooooool0W_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool00ol0
003oooooo`000007ooooo`03o`000?oooooo00000>Sooooo000`ooooo`03o`000?oooooooooo09ko
oooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooool000001oooool0
0ol0003oooooo`00003Xooooo`00<?ooool00ol0003oooooooooo`2Nooooo`05o`000?oooooooooo
ooooool000002?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooo000000Oooooo00?o0000ooooool00000j?oo
ool0033ooooo00?o0000ooooooooool0W_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000
1Oooool01?l0003oooooooooool00007ooooo`03o`000?oooooo00000>Sooooo000`ooooo`?o0000
TOooool2o`0000_ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Gooooo00Co0000oooo
oooooooo00001oooool00ol0003oooooo`00003Xooooo`00<?ooool00ol0003oooooooooo`2Aoooo
o`03o`000?oooooo000000[ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Gooooo00Co
0000oooooooooooo00001oooool00ol0003oooooo`00003Xooooo`00<?ooool00ol0003ooooooooo
o`2Aooooo`03o`000?oooooo000000Wooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000Gooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00003Xooooo`00
<?ooool00ol0003oooooooooo`2Aooooo`03o`000?oooooo000000Wooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool01Ol0003ooooooooooooooooo000000Gooooo00Go0000ooooooooooooooooo`000006oooo
o`03o`000?oooooo00000>Sooooo000`ooooo`03o`000?oooooooooo097ooooo00?o0000ooooool0
00002Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`3M
ooooo`00<?ooool00ol0003oooooooooo`1>ooooo`;ok^k^0oooool2onk^kS_ooooo00Co0000oooo
oooooooo00002Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000
onk^k_o^k^h00_ooool00ol0003ok^k^onk^kP05ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001Ooo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooool000001oooool2o`0001Oooooo
0_o^k^h3ooooo`;ok^k^C_ooool2onk^kP?ooooo0_o^k^i/ooooo`00<?ooool00ol0003ooooooooo
o`18ooooo`0=odA4A?l0003o0000oc8b<_oMgMgoooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^
kP03ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kRcooooo00Go0000oooo
ooooooooooooo`000008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooooooo1?l0
00002Ol@413o0000onk^k_mEEEGok^k^ooooool0003oEEEEonk^kP03ooooo`Co000000[o410@oooo
oooooooo0000oc8b<_l0003o<S8bonk^k_oooooo00001Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000
00Gooooo00Go0000ooooooooooooooooo`000005ooooo`05o`000?ooooooooooooooool000001_oo
ool00ol0003oooooo`000004o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`0=odA4A?l0
003o0000oc8b<_oMgMgoooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co000000So
410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kSSooooo1Ol00002ooooo`07onk^k_mEEEGok^k^
ooooooo^k^koEEEEonk^kP03ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^
kUgooooo000`ooooo`03o`000?oooooooooo04_ooooo00WoMgMgoc8b<_ooooooooooonk^k_mEEEGo
gMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
;?ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`0:o`000?ooooooooooo`000?ooooook^k^oeEEEOoMgMgo0000onk^kPKooooo
00?o0000ooooooooool00_ooool01ol0003oV9RHoooooonHV9SoMgMgooooool000001Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0
003ooooooooooooooooo000000Gooooo00Go0000ooooooooooooooooo`000005ooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00Cooooo
0_lQ8B48ooooo`09ogMgMolb<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000
ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg03Sooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A003ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL0GOooool0033ooooo00?o0000ooooooooool0C?ooool01ol0003o
oooooooooooooooogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooo
ooooooooool@4100;?ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00?ogMgMo`000?l0
00001oooool00ol0003oooooooooo`02ooooo`07o`000?ooooooooooooooool@413oooooo`000005
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0003ooooooooooooooooo000000Gooooo
00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo000000;ooooo00?o0000oooooooo
ool03oooool01ol0003ooooooooooooooooogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@4100>Oooool00onHV9So8B4Qonk^kP05ooooo`03omgMgOl0
003ogMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@05gooooo
000`ooooo`03o`000?oooooooooo04_ooooo00WoMgMgoc8b<_ooooooooooonk^k_mEEEGogMgMoeEE
EOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000;?ooool0
1Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`0:o`000?ooooooooooo`000?ooooook^k^oeEEEOoMgMgo0000onk^kPKooooo00?o0000
ooooooooool00_ooool01ol0003ooooooooooooooooo0000ooooool000001Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooo
oooooooooooo000000Gooooo00Go0000ooooooooooooooooo`000005ooooo`05o`000?oooooooooo
ooooool000001_ooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00kooooo00WoMgMg
oc8b<_ooooooooooonk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool00000>_ooool00onHV9So8B4Qonk^kP03ooooo`05onk^k_mEEEGogMgM
oeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000GOoo
ool0033ooooo00?o0000ooooooooool0B?ooool03Ol0003o8B4Qo`000?lb<S;oc<c<ooooooo^k^ko
EEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool00000;?ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`0;o`000?ooooooooooo`000?o^k^koEEEEonk^k_oooooo
0000oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`07o`000?ooooooooooooooool0003o
ooooo`000005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0003ooooooooooooooooo
000000Gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo000000;ooooo00?o
0000ooooooooool02oooool03Ol0003o8B4Qo`000?lb<S;oc<c<ooooooo^k^koEEEEonk^k_oooooo
k^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
>oooool02omgMgOoIVIVooooooooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000005gooooo000`ooooo`03o`000?oo
oooooooo04Sooooo00?o0000ooooooooool00oooool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oo
oooooooo00;ooooo00Go410@oooooooooooooooooa0@400/ooooo`05o`000?ooooooooooooooool0
00002?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Co0000ooooool0
003ooooo0_o^k^h2ooooo`03o`000?o^k^kok^k^00Gooooo00?o0000ooooooooool00_ooool01ol0
003ooooooooooooooooo410@ooooool000001Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00Go0000ooooooooooooooooo`000005ooooo`05o`000?ooooooooooooooool0
00001_ooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool00oooool2onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooo
oooooooooa0@400looooo`03o`000?oooooooooo00;ok^k^0oooool2onk^kPGooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@05gooooo000`ooooo`?o0000B?ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08
ooooo`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooo`000005ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool00_ooool01ol0003oV9RHoooooonHV9SoMgMgooooool0
00001Oooool3o`0000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo0000
00Gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo000000;ooooo00?o0000
ooooooooool00_ooool2o`0000Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool2o`0002kooooo00Go0000okZj^_ooooooV9RH
oa0@400>ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`;o
0000Doooool0033ooooo00?o0000ooooooooool0B?ooool4o`0000cooooo00?oEEEEofIVI_l00000
1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool08Oooool01Ol0003o
oooooooooooooooo000000Sooooo00?o0000ooooooooool00oooool02?l0003ooooooooooomEEEGo
IVIVo`000?oooooo00001Oooool00ol0003oooooooooo`03ooooo`03oeEEEOmVIVKo000000Cooooo
00Oo0000oc8b<_l0003o<S8bonk^k_oooooo000000Gooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0003ooooooooo
oooooooo000000Kooooo00Ko0000oooooooooooo0000ofIVI_l00004ooooo`;o00001oooool4o`00
00cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oooooo00Co0000
oooooooooooo0000;Oooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo00?oEEEEofIVI_l00000
1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oooooo00Co0000oooooooooooo0000D_ooool0033o
oooo00?o0000ooooooooool0I_ooool4o`0000?ooooo00?o0000ooooooooool04_ooool2o`0000_o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`Go000000Goooooo`000?oo
ooooooooo`000002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000005
ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0003ooooooooooooooooo000000Kooooo
0_l0000Uooooo`Co000000Goooooo`000?ooooooooooo`00001<ooooo`Co000000Goooooo`000?oo
ooooooooo`00001Booooo`00<?ooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo017o
oooo00Co0000ooooool0003o00002_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool3o`0000?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0
003ooooooooooooooooo000000Gooooo00Go0000ooooooooooooooooo`000005ooooo`05o`000?oo
ooooooooooooool000001Oooool00ol0003oooooo`00000Zooooo`?o0000D_ooool3o`0005?ooooo
000`ooooo`03o`000?oooooooooo06_ooooo00Co0000oooooooooooo00004_ooool01?l0003ooooo
ooooool0000:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`;o00001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooooooooooo
ool000001Oooool01Ol0003ooooooooooooooooo000000Gooooo00Go0000ooooooooooooooooo`00
0005ooooo`04o`000?ooooooooooo`0002[ooooo00?o0000ooooooooool0D_ooool00ol0003ooooo
ooooo`1Booooo`00<?ooool00ol0003oooooooooo`1[ooooo`Co00004Oooool01Ol0003ooooooooo
oooooooo000000[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooool000000oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`00
0?ooooooooooooooool000001Oooool01Ol0003ooooooooooooooooo000000Gooooo00Go0000oooo
ooooooooooooo`000005ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo057ooooo000`ooooo`03o`000?oooooo
oooo083ooooo00Go0000ooooooooooooooooo`00000:ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001Oooool01?l0003o
ooooooooool00006ooooo`;o0000c?ooool0033ooooo00?o0000ooooooooool0P?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000005oooo
o`04o`000?ooooooooooo`0000Kooooo00?o0000ooooool00000TOooool00omgMgOoIVIVooooo`0]
ooooo`03ofIVI_mgMgOooooo00Oooooo000`ooooo`03o`000?oooooooooo083ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001Oooool0
1?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool0
Q_ooool00ooMgMgo410@onk^kP0^ooooo`03onk^k_l@413ogMgM00Oooooo000`ooooo`03o`000?oo
oooooooo073ooooo1?l0000;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000000Gooooo00Go0000ooooooooooooooooo`000004ooooo`04
o`000?ooooooooooo`0000Gooooo1?l0001eooooo`;o00000_ooool2o`0000cooooo00?oEEEEoiRH
V?ooool00_l00002ooooo`07o`000?ooooooooooo`000?l@413ok^k^oeEEE@02o`000003odA4A?nj
^[[ooooo00;ooooo00GoV9RHo`000?l0003oA4A4okZj^P02ooooo`08onk^k_mEEEGo0000o`000?m4
A4Co^[Zjooooool@4105o`0000?ooooo00So410@oc8b<_l0003o0000oa0@4?nYZJWoQhN7ofIVIPOo
oooo000`ooooo`03o`000?oooooooooo06kooooo0_l00004ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
00001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00001Oooool01?l0003oooooooooool00005ooooo`?o0000KOooool01_o^k^ko8B4QohN7Qonj
^[[o0000omgMg@cooooo00Go0000ooooooooooooooooo`000002ooooo`0;o`000?ooooooooooo`00
0?ooooooEEEEogMgMoooooook^k^ogMgMol@41000oooool01Ol@413o^[Zjonk^k_mgMgOo410@00;o
oooo00KoEEEEogMgMoooooook^k^ogMgMol@4103ooooo`03o`000?oooooooooo00Cooooo00So0000
ojVYZOoooooooooookZj^_l0003ok^k^o`0000Oooooo003oo`000;Co00003oooool01?oMgMgo0000
oa0@4?o<c<`=ooooo`05oc8b<_ooooooooooooooool000000_ooool01_l0003oooooooooool0003o
ooooo`0000Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Gooooo00Oo^[ZjohN7QomVIVKoIVIVoa0@4?oooooo000000Oooooo000:ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool01_ooool8o`0000;ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`06ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000Kooooo00?o0000oooooooo
ool01?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
1?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooool000000_ooool01Ol0003o
oooooooooooooooo000000Cooooo00?o0000ooooooooool00_ooool01Ol0003oooooo`000?oooooo
000000;ooooo00?o0000ooooooooool00oooool4o`0000Cooooo1?l0000?ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo01Oooooo00Cok^k^ob4Q8Ol@413ok^k^3Oooool01Olb<S;ooooooooooooooooo000000;ooooo
00Go0000oooooooooooo0000ooooo`06o`0000?ooooo00?o0000ooooooooool01?ooool6o`0000?o
oooo00?o0000ooooooooool01?ooool02?lb<S;o8B4QogMgMomgMgOoQhN7onk^k_oooooo00001ooo
ool000[ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooo`000006ooooo`03o`000?oo
oooooooo00Cooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooool000001?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00Ko0000oooooooooooo0000ooooool00005ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00?ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000;ooooo00Go
0000ooooooooooooooooo`000005ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000oooooooo
ool00ol0000=ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool05oooool01?lQ8B7o
MgMgogMgMolb<S8=ooooo`05o`000?o^k^koooooooooool000000_o<c<`02ol0003oZJVYomgMgOlQ
8B7ooooooeEEEOn7QhOok^k^oooooon7QhOo<S8b00?ooooo00?o0000ooooooooool01?ooool01_mE
EEGoQhN7onk^k_ooooooQhN7oc8b<P?ooooo00?o0000oc8b<_oMgMd01?ooool02?l0003o^[Zjoooo
ooo^k^koMgMgo`000?o^k^ko00001oooool0033ooooo00?o0000ooooooooool0Foooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooo000000Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000005oooo
o`05o`000?ooooooooooooooool000001Oooool01Ol0003ooooooooooooooooo000000Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
1Oooool01?l0003oooooo`000?l00002ooooo`03o`000?oooooooooo05_ooooo00?o0000oooooooo
ool05_ooool2o`0000;ooooo0_l0000<ooooo`0>oeEEEOmgMgOooooooa0@4?l0003o8B4Qo`000?mg
MgOo410@o`000?nYZJWoooooonk^k_mEEED2o`000004odA4A?o^k^kooooooa0@40Go00000oooool0
1_o^k^koEEEEo`000?l0003oA4A4onk^kP;ooooo0_l000001?nYZJWo8B4Qo`000?lQ8B42ooooo`08
ojVYZOlQ8B7o0000o`000?lb<S;o0000ogMgMomEEED7ooooo`00<?ooool00ol0003oooooooooo`1h
ooooo`05o`000?ooooooooooooooool000002_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00Go0000ooooooooooooooooo`000005ooooo`05o`000?ooooooooooooooool0
00001Oooool01Ol0003ooooooooooooooooo000000Gooooo00Go0000ooooooooooooooooo`000004
ooooo`04o`000?ooooooooooo`0000Kooooo0ol0002<ooooo`03omgMgOl@413ok^k^01;ooooo00?o
0000ooooooooool06Oooool00oo^k^ko410@omgMg@07ooooo`00<?ooool00ol0003oooooooooo`1i
ooooo`Co00002_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00Go0000
ooooooooooooooooo`000005ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0003ooooo
oooooooooooo000000Gooooo00Co0000oooooooooooo00001_ooool00ol0003oooooo`00002Foooo
o`03ogMgMomVIVKooooo017ooooo00?o0000ooooooooool06Oooool00omVIVKoMgMgooooo`07oooo
o`00<?ooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0003ooooooooooooo
oooo000000Gooooo00Go0000ooooooooooooooooo`000005ooooo`04o`000?ooooooooooo`0000Ko
oooo00?o0000ooooool00000d?ooool0033ooooo00?o0000ooooooooool0Qoooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`04ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000005ooooo`05o`000?oooooooooo
ooooool000001Oooool01Ol0003ooooooooooooooooo000000Gooooo00Co0000oooooooooooo0000
1_ooool00ol0003oooooo`00003@ooooo`00<?ooool00ol0003oooooooooo`27ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Gooooo00Go0000oooooooo
ooooooooo`000005ooooo`05o`000?ooooooooooooooool000001Oooool01?l0003oooooooooool0
0007ooooo`;o0000d?ooool0033ooooo00?o0000ooooooooool0R?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00Go0000ooooooooooooooooo`000005ooooo`05o`000?ooooooooooooooool0
00001Oooool01Ol0003ooooooooooooooooo000000Gooooo00Co0000oooooooooooo0000fOooool0
033ooooo00?o0000ooooooooool0R?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooo
ooooool000001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00Go0000
ooooooooooooooooo`000005ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0003ooooo
oooooooooooo000000Gooooo00Co0000oooooooooooo0000fOooool0033ooooo00?o0000oooooooo
ool0R?ooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000005ooooo`05o`000?oo
ooooooooooooool000001Oooool01Ol0003ooooooooooooooooo000000Gooooo00Co0000oooooooo
oooo0000fOooool0033ooooo0ol00029ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00
0005ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooool00000fOooool0033ooooo00?o0000ooooooooool0ROooool01?l0003ooooo
ooooool0000:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003o
oooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`05o`000?ooooooooooooooool000001Oooool01Ol0003ooooooooooooooooo000000Gooooo00Go
0000ooooooooooooooooo`000006ooooo`;o0000f_ooool0033ooooo00?o0000ooooooooool0ROoo
ool00ol0003oooooo`00000;ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05
o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool00006ooooo`04o`000?oooooo
ooooo`0000Kooooo0_l0003Jooooo`00<?ooool00ol0003oooooooooo`2:ooooo`;o00002oooool0
1Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`05o`00
0?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooo
oooooooo00001_ooool00ol0003oooooo`000007ooooo`;o0000f_ooool0033ooooo00?o0000oooo
ooooool0R_ooool2o`0000_ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooo
ooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000oooooooooooo
ooooo`000006ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooool00000hoooool0033o
oooo00?o0000ooooooooool0Uoooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooo
ooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooo
oooooooo000000Kooooo00Co0000oooooooooooo00001_ooool00ol0003oooooo`00003Sooooo`00
<?ooool00ol0003oooooooooo`2Gooooo`05o`000?ooooooooooooooool000002?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003o
oooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?oooooo
ooooooooool000001_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooo00000>?ooooo
000`ooooo`03o`000?oooooooooo09Oooooo00Go0000ooooooooooooooooo`000008ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`00
0?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000oooo
ooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooool00000hooo
ool0033ooooo00?o0000ooooooooool0Uoooool01Ol0003ooooooooooooooooo000000Sooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go
0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003o
oooooooooooooooo000000Kooooo00Co0000oooooooooooo00001_ooool00ol0003oooooo`00003S
ooooo`00<?ooool00ol0003oooooooooo`2Gooooo`05o`000?ooooooooooooooool000002?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
1Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000006ooooo`05o`00
0?ooooooooooooooool000001_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooo0000
0>?ooooo000`ooooo`03o`000?oooooooooo09Oooooo00Go0000ooooooooooooooooo`000008oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04oooo
o`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Kooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooo000000Oooooo00?o0000ooooool00000
hoooool0033ooooo00?o0000ooooooooool0Uoooool01Ol0003ooooooooooooooooo000000Sooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo
00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooool000001oooool3o`000>?ooooo000`oooo
o`?o0000Uoooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00
0006ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooool000002?ooool2o`000>?ooooo000`ooooo`03o`000?oooooooooo09Oooooo
00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0
003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oo
oooo000000Sooooo00?o0000ooooooooool0h_ooool0033ooooo00?o0000ooooooooool0V?ooool0
1?l0003oooooooooool00008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooo
oooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo0000
0>gooooo000`ooooo`03o`000?oooooooooo09Sooooo00Co0000oooooooooooo00002?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooo
oooo000000Kooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool0
00001_ooool00ol0003oooooo`00003]ooooo`00<?ooool00ol0003oooooooooo`2Hooooo`03o`00
0?oooooo000000Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Oo
oooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001_ooool0
1Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooool00000kOooool0033ooooo00?o0000
ooooooooool0V?ooool00ol0003oooooo`000009ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000
ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooo
oooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo0000
0>gooooo000`ooooo`03o`000?oooooooooo09Sooooo00?o0000ooooool000002Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo
000000Kooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooo`00003]ooooo`00<?ooool00ol0003oooooooooo`2Hooooo`03o`000?oo
oooo000000[ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooooooo
ooooooooo`000006ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooo
oooo000000Kooooo00?o0000ooooool00000kOooool0033ooooo00?o0000ooooooooool0V?ooool0
0ol0003oooooo`00000:ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000007ooooo`05o`00
0?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooo00000>gooooo000`ooooo`03o`000?oooooooooo
09Wooooo0_l0000:ooooo`05o`000?ooooooooooooooool000002?ooool01Ol0003ooooooooooooo
oooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool0
00001_ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000006
ooooo`03o`000?oooooo00000>gooooo000`ooooo`03o`000?oooooooooo09Wooooo00?o0000oooo
ooooool02Oooool01Ol0003ooooooooooooooooo000000Sooooo00Go0000ooooooooooooooooo`00
0007ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Ko
oooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000
ooooool00000kOooool0033ooooo00?o0000ooooooooool0YOooool01Ol0003ooooooooooooooooo
000000Sooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool00000
1oooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000006oooo
o`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool00000kOooool0033ooooo0ol0002Uoooo
o`05o`000?ooooooooooooooool000002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go
0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003o
oooooooooooooooo000000Kooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00003]
ooooo`00<?ooool00ol0003oooooooooo`2Uooooo`05o`000?ooooooooooooooool000002?ooool0
1Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`05o`00
0?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooo
oooooooo00002?ooool2o`000>gooooo000`ooooo`03o`000?oooooooooo0:Gooooo00Go0000oooo
ooooooooooooo`000008ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooo
oooooooo000000Oooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?oooooooooooooo
ool000001_ooool01?l0003oooooooooool00008ooooo`;o0000kOooool0033ooooo00?o0000oooo
ooooool0YOooool01Ol0003ooooooooooooooooo000000Sooooo00Go0000ooooooooooooooooo`00
0007ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Ko
oooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000
ooooooooool0k?ooool0033ooooo00?o0000ooooooooool0YOooool01Ol0003ooooooooooooooooo
000000Sooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool00000
1oooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000006oooo
o`04o`000?ooooooooooo`000?Oooooo000`ooooo`03o`000?oooooooooo0:Gooooo00Go0000oooo
ooooooooooooo`000008ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooo
oooooooo000000Oooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`00
00Sooooo00?o0000ooooool00000moooool000oooooo0_o^k^h3ooooo`;ok^k^6_ooool00ol0003o
ooooooooo`2Vooooo`04o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000007
ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Kooooo
00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003gooooo`002?ooool5o`0000;ooooo
00Ook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413oooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^2oooool00ol0003oooooooooo`2Vooooo`04o`000?ooooooooooo`0000So
oooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool0
1Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo00002?ooool00ol0003ooooo
o`00003gooooo`002?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00Gok^k^oeEEEOoMgMgo
EEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;oooo
o`03o`000?oooooooooo0:Kooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooo
oooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool0
00001_ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?Oooooo0009ooooo`03
oiRHV?lQ8B7ok^k^00Gooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05
oa0@4?ooooooooooooooool@41002oooool00ol0003oooooooooo`2Vooooo`04o`000?oooooooooo
o`0000Sooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool00000
1oooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo00002?ooool00ol0
003oooooo`00003gooooo`002_ooool00onHV9So8B4Qonk^kP03ooooo`05onk^k_mEEEGogMgMoeEE
EOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000002oooool0
0ol0003oooooooooo`2Vooooo`03o`000?oooooo000000Wooooo00Go0000ooooooooooooooooo`00
0007ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Ko
oooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003gooooo`002oooool02omgMgOo
IVIVooooooooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000ooooooooool0
0_ooool01Ol0003ooooooooooooooooo000000_ooooo1?l0002Uooooo`03o`000?oooooo000000Wo
oooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool0
1?l0003oooooooooool00008ooooo`03o`000?oooooo000000Sooooo00?o0000ooooool00000mooo
ool000cooooo00?o0000ooooooooool00_o^k^h3ooooo`;ok^k^1Oooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@41002oooool00ol0003oooooooooo`2Vooooo`03o`000?oo
oooo000000Wooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool0
00001oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo000000Sooooo00?o0000oooo
ool00000moooool000Sooooo00Go0000okZj^_ooooooV9RHoa0@400>ooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03o`000?oooooooooo0:Kooooo00?o0000
ooooool000002Oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooooooooooooooo
o`000007ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool000002?ooool00ol0003o
ooooo`00003gooooo`002?ooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo00?oEEEEofIVI_l0
00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo0_l00006ooooo`03o`000?oooooooooo
0:Kooooo00?o0000ooooool000002Oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000
ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000
2?ooool00ol0003oooooo`00003gooooo`009oooool01?l0003oooooooooool00005ooooo`03o`00
0?oooooooooo0:Kooooo00?o0000ooooool000002Oooool01Ol0003ooooooooooooooooo000000Oo
oooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000
ooooool000002?ooool00ol0003oooooo`00003gooooo`009oooool01?l0003oooooooooool00005
ooooo`03o`000?oooooooooo0:Kooooo00?o0000ooooool000002Oooool01Ol0003ooooooooooooo
oooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000So
oooo00?o0000ooooool000002?ooool00ol0003oooooo`00003gooooo`009oooool3o`0000Kooooo
00?o0000ooooooooool0Y_ooool00ol0003oooooo`000009ooooo`05o`000?ooooooooooooooool0
00001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo00002?ooool0
0ol0003oooooo`000008ooooo`;o0000n?ooool002Sooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`2Vooooo`03o`000?oooooo000000Wooooo00Go0000ooooooooooooooooo`000007
ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool00008ooooo`03o`00
0?oooooo000000Sooooo0_l0003hooooo`00:Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo0:Kooooo0_l0000:ooooo`05o`000?ooooooooooooooool000002?ooool01?l0003ooooo
ooooool00007ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool000002?ooool2o`00
0?Sooooo000`ooooo`03o`000?oooooooooo0:Oooooo00?o0000ooooooooool02?ooool01Ol0003o
oooooooooooooooo000000Sooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool0
0008ooooo`03o`000?oooooo000000Wooooo00?o0000ooooooooool0m_ooool0033ooooo00?o0000
ooooooooool0/oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo
00?o0000ooooool000002?ooool00ol0003oooooo`00003oooooo`?ooooo000`ooooo`03o`000?oo
oooooooo0;?ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00008ooooo`03
o`000?oooooo000000Sooooo00?o0000ooooool00000ooooool3ooooo`00<?ooool3o`000;?ooooo
00?o0000ooooool000002Oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo000000So
oooo00?o0000ooooool00000ooooool3ooooo`00<?ooool00ol0003oooooooooo`2cooooo`03o`00
0?oooooo000000Wooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`000008ooooo`03
o`000?oooooo00000?oooooo0oooool0033ooooo00?o0000ooooooooool0/oooool00ol0003ooooo
o`000009ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool000002?ooool00ol0003o
ooooo`00003oooooo`?ooooo000`ooooo`03o`000?oooooooooo0;?ooooo00?o0000ooooool00000
2Oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo000000Sooooo00?o0000ooooool0
0000ooooool3ooooo`00<?ooool00ol0003oooooooooo`2cooooo`03o`000?oooooo000000Wooooo
00Co0000oooooooooooo00002?ooool00ol0003oooooo`000008ooooo`03o`000?oooooo00000?oo
oooo0oooool0033ooooo00?o0000ooooooooool0/oooool00ol0003oooooo`000009ooooo`04o`00
0?ooooooooooo`0000Sooooo00?o0000ooooool000002?ooool00ol0003oooooo`00003oooooo`?o
oooo000`ooooo`03o`000?oooooooooo0;?ooooo00?o0000ooooool000002Oooool01?l0003ooooo
ooooool00008ooooo`03o`000?oooooo000000Sooooo00?o0000ooooool00000ooooool3ooooo`00
<?ooool00ol0003oooooooooo`2cooooo`03o`000?oooooo000000Wooooo00Co0000oooooooooooo
00002?ooool00ol0003oooooo`000008ooooo`03o`000?oooooo00000?oooooo0oooool0033ooooo
00?o0000ooooooooool0/oooool00ol0003oooooo`000009ooooo`04o`000?ooooooooooo`0000So
oooo00?o0000ooooool000002?ooool00ol0003oooooo`00003oooooo`?ooooo000`ooooo`03o`00
0?oooooooooo0;?ooooo00?o0000ooooool000002Oooool01?l0003oooooooooool00008ooooo`03
o`000?oooooo000000Sooooo00?o0000ooooool00000ooooool3ooooo`00<?ooool00ol0003ooooo
ooooo`2cooooo`03o`000?oooooo000000Wooooo00Co0000oooooooooooo00002?ooool00ol0003o
ooooo`000009ooooo`;o0000ooooool3ooooo`00<?ooool00ol0003oooooooooo`2cooooo`03o`00
0?oooooo000000Wooooo00?o0000ooooool000002Oooool00ol0003oooooo`000009ooooo`;o0000
ooooool3ooooo`00<?ooool3o`000;?ooooo00?o0000ooooool000002Oooool00ol0003oooooo`00
0009ooooo`03o`000?oooooo000000Wooooo00?o0000ooooooooool0ooooool2ooooo`00<?ooool0
0ol0003oooooooooo`2cooooo`03o`000?oooooo000000Wooooo00?o0000ooooool000002Oooool0
0ol0003oooooo`000009ooooo`03o`000?oooooooooo0?oooooo0_ooool0033ooooo00?o0000oooo
ooooool0/oooool00ol0003oooooo`000009ooooo`03o`000?oooooo000000Wooooo00?o0000oooo
ool000002Oooool00ol0003oooooooooo`3oooooo`;ooooo000`ooooo`03o`000?oooooooooo0;Co
oooo00?o0000ooooooooool02?ooool00ol0003oooooo`000009ooooo`03o`000?oooooo00000?oo
oooo3_ooool0033ooooo00?o0000ooooooooool0]?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooo000000Wooooo00?o0000ooooool00000ooooool>ooooo`00<?ooool00ol0003ooooooooo
o`2dooooo`03o`000?oooooooooo00Sooooo00?o0000ooooool000002Oooool00ol0003oooooo`00
003oooooo`kooooo000`ooooo`03o`000?oooooooooo0;oooooo00?o0000ooooool000002Oooool0
0ol0003oooooo`00003oooooo`kooooo000`ooooo`03o`000?oooooooooo0<3ooooo0_l00009oooo
o`03o`000?oooooo00000?oooooo3_ooool0033ooooo00?o0000ooooooooool0`?ooool2o`0000Wo
oooo00?o0000ooooool00000ooooool>ooooo`00<?ooool00ol0003oooooooooo`30ooooo`;o0000
2Oooool2o`000?oooooo3oooool0033ooooo00?o0000ooooooooool0`?ooool2o`0000Wooooo0_l0
003oooooo`oooooo000`ooooo`03o`000?oooooooooo0<3ooooo0_l00009ooooo`;o0000ooooool?
ooooo`00<?ooool3o`000<3ooooo0_l0000:ooooo`03o`000?oooooooooo0?oooooo3Oooool0033o
oooo00?o0000ooooooooool0`?ooool2o`0000[ooooo00?o0000ooooooooool0ooooool=ooooo`00
<?ooool00ol0003oooooooooo`30ooooo`;o00002_ooool00ol0003oooooooooo`3oooooo`gooooo
000`ooooo`03o`000?oooooooooo0<3ooooo0_l0003ooooooa[ooooo000`ooooo`03o`000?oooooo
oooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`003oooool2onk^kP?o
oooo0_o^k^hJooooo`03o`000?oooooooooo0?oooooog?ooool000[ooooo0_l000002_l@413ooooo
ooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h3ooooo`Co000000So410@ooooooooooook^k^
oc8b<_l0003o<S8bonk^kP_ooooo00?o0000ooooooooool0oooooooLooooo`002oooool00ol0003o
ooooooooo`02ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ol0003oooooooooo`3oooooomcooooo0008oooo
o`Go00001?ooool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooo
oooooooooooooa0@400;ooooo`03o`000?oooooooooo0?oooooog?ooool000Sooooo00CoA4A4omgM
gOoooooo00001?ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000000_ooooo00?o0000ooooooooool0oooooooLooooo`002?oo
ool01?oMgMgoEEEEooooool00003ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05oooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000;ooooo`Co0000oooooooK
ooooo`002Oooool00omgMgOoc<c<o`000003ooooo`;ok^k^0oooool2onk^kPGooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@00_ooooo00?o0000ooooooooool0oooooooL
ooooo`002Oooool00oo^k^koA4A4o`00000?ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0;ooooo`03o`000?oooooooooo0?oooooog?ooool000[ooooo00?oMgMgo`00
0?ooool03?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool2
o`0000Kooooo00?o0000ooooooooool0oooooooLooooo`009oooool01?l0003oooooooooool00005
ooooo`03o`000?oooooooooo0?oooooog?ooool002Oooooo00Co0000oooooooooooo00001Oooool0
0ol0003oooooooooo`3oooooomcooooo000Wooooo`?o00001_ooool00ol0003oooooooooo`3ooooo
omcooooo000Xooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooooLooooo`00
:Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o
0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`oooo
o`03o`000?oooooooooo0?oooooog?ooool0033ooooo0ol0003oooooomcooooo000`ooooo`03o`00
0?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool0
0ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033o
oooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo
000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooL
ooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oo
oooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool3o`000?oooooog?oo
ool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3ooooo
omcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0
oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooo
oooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003o
ooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o
0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`oooo
o`?o0000oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`00
0?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool0
0ol0003oooooooooo`3oooooomcooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00
oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooo
oa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00X?ooool2o`0000Cooooo00?o
^[Zjoc8b<_ooool01?ooool2o`0000Kooooo00?o0000okZj^_ooool0oooooomGooooo`00X?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool2
oc8b<_ooooooF?ooool008gooooo0ol00002ooooo`06oc8b<_l@413oooooooooooo^k^koEEEE0_l0
00000om4A4Co^[Zjooooo`03ooooo`03o`000?oooooooooo00;ooooo00GoV9RHoa0@4?l0003o0000
ojVYZ@04ooooo`03o`000?oooooooooo00Cooooo00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000
o`000?m4A4Co^[Zj00Wooooo00Co410@o`000?m4A4Coc<c<1_ooool2ob4Q8@Cooooo1Ol000001_oo
ooooc<c<onk^k_ooooook^k^olc<c0Cooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb
<S;ok^k^4oooool01_l@413o<S8bo`000?l0003o410@ojVYZ@;ooooo00Kok^k^oeEEEOl0003o0000
odA4A?nj^[X3ooooo`05ofIVI_l0003o0000odA4A?o<c<`0j?ooool008kooooo00Go0000oooooooo
ooooc<c<oa0@4003ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo410@1?ooool00ol0003ooooooooo
o`02ooooo`06o`000?nYZJWoEEEEoiRHV?mEEEGo^[Zj0oooool00ol0003oooooooooo`04ooooo`03
olc<c?l0003o410@00cooooo00Ko410@okZj^_o^k^koMgMgoa0@4?ooool6o`0000Cooooo00?oV9RH
oa0@4?oMgMd01Oooool2ob4Q8@Cooooo00_oV9RHob4Q8Oo^k^koooooodA4A?ooooook^k^oeEEEOoM
gMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0C
ooooo`06o`000?nYZJWooooooooooonj^[[o00000_ooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@
40;ooooo00KoIVIVogMgMoooooooooooohN7Qol@413Xooooo`00S_ooool01Ol0003ooooooooooomE
EEGoQhN700?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`06oc8b<_o^
k^koV9RHoeEEEOoMgMgo410@0oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00ko
oooo00?oQhN7oeEEEOooool02oooool00onHV9So8B4Qonk^kP03ooooo`03omgMgOl0003ogMgM00Oo
oooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@01Cooooo00Go^[ZjohN7
QomVIVKoIVIVoa0@4002ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0joooool0
08kooooo00Go0000oooooooMgMgo0000onk^kP03ooooo`Ko00001?ooool00ol0003oooooooooo`02
ooooo`07okZj^_m4A4Coc<c<ob4Q8Ooooooo410@olc<c002ooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool00oooool6o`0000;ooooo00Goc<c<ob4Q8Ol0003oEEEEo`00000=ooooo`09
oiRHV?lQ8B7ok^k^ooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000001?ooooo00Ko<S8bob4Q8OmgMgOoMgMgohN7Qoo^k^h2oooo
o`Ko00000_ooool00ol0003oooooooooo`3[ooooo`00S_ooool3o`000003oa0@4?nHV9Sooooo00;o
oooo00KoEEEEohN7Qoo^k^koooooohN7Qolb<S84ooooo`03o`000?oooooooooo00;ooooo00Ook^k^
o`000?oooooo0000oooooomVIVKoQhN700;ooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0;ooooo`05ob4Q8On7QhOooooooiRHV?l000003_ooool02?mgMgOoIVIVooooooo<c<cok^k^
ooooooo^k^koc<c<1_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
4oooool01_l0003o^[Zjooooooo^k^koMgMgo`0000;ooooo00KoEEEEohN7Qoo^k^koooooohN7Qolb
<S82ooooo`06ofIVI_mgMgOooooooooooon7QhOo0000j?ooool008kooooo00Go0000oooooooooooo
c<c<o`000003ooooo`06onk^k_mEEEGo0000o`000?m4A4Cok^k^1?ooool00ol0003oooooooooo`02
ooooo`04ofIVI_nHV9Sooooooc8b<P;o^[Zj00Co0000oooooooooooo00004oooool00ol@413o0000
o`000003o`0000[ooooo00Go0000ooooooooooooooooo`00000?ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Oooooo0ol00002oooo
o`?o00001?ooool01_nYZJWo8B4Qo`000?l0003o<S8bo`0000;ooooo00Kok^k^oeEEEOl0003o0000
odA4A?o^k^h2ooooo`06onk^k_mVIVKo0000o`000?m4A4Co0000j?ooool008kooooo00Go0000oooo
ooooooooc<c<o`00000=ooooo`03o`000?oooooooooo00Gooooo00?oIVIVohN7Qoooool00oooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00_ooooo00Go8B4QoiRHV?ooooooMgMgoeEE
E@0;ooooo`05o`000?nj^[[ooooooiRHV?l@41003?ooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oo
oooo0_ooool008gooooo1?l000000ol@413oZJVYooooo`0<ooooo`;o00001_ooool00onYZJWoA4A4
ooooo`02ooooo`;o00005Oooool00ol0003oooooooooo`0;ooooo`05olc<c?l@413o0000oc8b<_o^
k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00[ooooo00?oEEEEofIVI_l000001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00;ooooo1?l00002ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0ooooool2ooooo`00ooooool6ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0ooooool2ooooo`00ooooool6ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0ooooool2ooooo`00ooooool5ooooo`;o00000oooool2o`000?oooooo1?ooool00?oooooooooo
ool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00
oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooo
oa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003o
oooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo
4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oo
ooooooooool@ooooo`00oooooooooooooa3ooooo0000\
\>"],
  ImageRangeCache->{{{0, 525.688}, {324.5, 0}} -> {-2.58312*^-7, -6.34248*^6, \
6.65005*^-9, 53093.5}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0.309017 5.42214e-08 [
[.32684 .29652 -16.5 -12.5 ]
[.32684 .29652 16.5 0 ]
[.54329 .29652 -16.5 -12.5 ]
[.54329 .29652 16.5 0 ]
[.75974 .29652 -22.5 -12.5 ]
[.75974 .29652 22.5 0 ]
[.97619 .29652 -16.5 -12.5 ]
[.97619 .29652 16.5 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 64 6 ]
[.09789 .09213 -34.5 -6.25 ]
[.09789 .09213 0 6.25 ]
[.09789 .20057 -34.5 -6.25 ]
[.09789 .20057 0 6.25 ]
[.09789 .41746 -28.5 -6.25 ]
[.09789 .41746 0 6.25 ]
[.09789 .5259 -28.5 -6.25 ]
[.09789 .5259 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -62.8125 0 ]
[.5 .63053 62.8125 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 .30902 m
.32684 .31527 L
s
gsave
.32684 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 .30902 m
.54329 .31527 L
s
gsave
.54329 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 .30902 m
.75974 .31527 L
s
gsave
.75974 .29652 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 .30902 m
.15368 .31277 L
s
.19697 .30902 m
.19697 .31277 L
s
.24026 .30902 m
.24026 .31277 L
s
.28355 .30902 m
.28355 .31277 L
s
.37013 .30902 m
.37013 .31277 L
s
.41342 .30902 m
.41342 .31277 L
s
.45671 .30902 m
.45671 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.58658 .30902 m
.58658 .31277 L
s
.62987 .30902 m
.62987 .31277 L
s
.67316 .30902 m
.67316 .31277 L
s
.71645 .30902 m
.71645 .31277 L
s
.80303 .30902 m
.80303 .31277 L
s
.84632 .30902 m
.84632 .31277 L
s
.88961 .30902 m
.88961 .31277 L
s
.9329 .30902 m
.9329 .31277 L
s
.0671 .30902 m
.0671 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09213 m
.11664 .09213 L
s
gsave
.09789 .09213 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .20057 m
.11664 .20057 L
s
gsave
.09789 .20057 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .41746 m
.11664 .41746 L
s
gsave
.09789 .41746 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .5259 m
.11664 .5259 L
s
gsave
.09789 .5259 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.11039 .11924 m
.11414 .11924 L
s
.11039 .14635 m
.11414 .14635 L
s
.11039 .17346 m
.11414 .17346 L
s
.11039 .22768 m
.11414 .22768 L
s
.11039 .2548 m
.11414 .2548 L
s
.11039 .28191 m
.11414 .28191 L
s
.11039 .33613 m
.11414 .33613 L
s
.11039 .36324 m
.11414 .36324 L
s
.11039 .39035 m
.11414 .39035 L
s
.11039 .44457 m
.11414 .44457 L
s
.11039 .47168 m
.11414 .47168 L
s
.11039 .49879 m
.11414 .49879 L
s
.11039 .06502 m
.11414 .06502 L
s
.11039 .03791 m
.11414 .03791 L
s
.11039 .0108 m
.11414 .0108 L
s
.11039 .55301 m
.11414 .55301 L
s
.11039 .58012 m
.11414 .58012 L
s
.11039 .60723 m
.11414 .60723 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -123.812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.812 moveto
(@) show
81.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.812 moveto
(D) show
93.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(9.4) show
135.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
141.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
153.000 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
157.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
166.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
184.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02691 .30902 L
.03029 .30902 L
.03347 .30902 L
.03652 .30902 L
.03978 .30902 L
.04291 .30902 L
.04623 .30902 L
.04944 .30902 L
.05252 .30902 L
.0558 .30902 L
.05743 .30902 L
.05823 .30902 L
.05896 .30902 L
.05966 .30902 L
.06042 .30902 L
.06062 .30902 L
.06084 .30902 L
.06103 .30902 L
.06123 .30902 L
.06134 .30902 L
.06144 .30902 L
.06153 .30902 L
.06163 .30902 L
.06172 .30902 L
.06181 .30902 L
.0619 .30902 L
.062 .30902 L
.06209 .30902 L
.06215 .30902 L
.0622 .30902 L
.06232 .30902 L
.06242 .30902 L
.06261 .30902 L
.06281 .30902 L
.06325 .30902 L
.06346 .30902 L
.0637 .30902 L
.06411 .30902 L
.06454 .30902 L
.06532 .30902 L
.06614 .30902 L
.06703 .30902 L
.06787 .30902 L
.06865 .30902 L
.07015 .30902 L
.07181 .30902 L
.07337 .30902 L
.07505 .30902 L
.07675 .30902 L
Mistroke
.07836 .30902 L
.07995 .30902 L
.08143 .30902 L
.08458 .30902 L
.0863 .30902 L
.08792 .30902 L
.09102 .30902 L
.09262 .30902 L
.09431 .30902 L
.09736 .30902 L
.10061 .30902 L
.10374 .30902 L
.10706 .30902 L
.11027 .30902 L
.11335 .30902 L
.11663 .30902 L
.11978 .30902 L
.12282 .30902 L
.12605 .30902 L
.12916 .30902 L
.13246 .30902 L
.13411 .30902 L
.13565 .30902 L
.13713 .30902 L
.13796 .30902 L
.13871 .30902 L
.1391 .30902 L
.13931 .30902 L
.13951 .30902 L
.13968 .30902 L
.13987 .30902 L
.13997 .30902 L
.14007 .30902 L
.14016 .30902 L
.14025 .30902 L
.14036 .30902 L
.14045 .30902 L
.14056 .30902 L
.14062 .30902 L
.14067 .30902 L
.14089 .30902 L
.141 .30902 L
.14112 .30902 L
.14154 .30902 L
.14192 .30902 L
.14233 .30902 L
.14277 .30902 L
.14356 .30902 L
.14434 .30902 L
.14506 .30902 L
Mistroke
.14656 .30902 L
.14741 .30902 L
.14822 .30902 L
.14984 .30902 L
.15133 .30902 L
.15285 .30902 L
.15452 .30902 L
.15623 .30902 L
.15778 .30902 L
.16092 .30902 L
.16414 .30902 L
.16724 .30902 L
.17053 .30902 L
.1737 .30902 L
.17675 .30902 L
.18 .30902 L
.18312 .30902 L
.18394 .30902 L
.18483 .30902 L
.1856 .30902 L
.186 .30902 L
.18644 .30902 L
.18687 .30902 L
.18706 .30902 L
.18726 .30902 L
.18745 .30902 L
.18764 .30902 L
.18775 .30902 L
.18784 .30902 L
.18794 .30902 L
.18803 .30902 L
.18813 .30902 L
.18819 .30902 L
.18824 .30902 L
.18834 .30902 L
.1884 .30902 L
.18845 .30902 L
.18855 .30902 L
.18865 .30902 L
.18884 .30902 L
.18906 .30902 L
.1893 .30902 L
.18972 .30902 L
.19015 .30902 L
.19055 .30902 L
.19144 .30902 L
.19223 .30902 L
.19306 .30902 L
.19464 .30902 L
.19612 .30902 L
Mistroke
.19775 .30902 L
.19925 .30902 L
.20245 .30902 L
.20553 .30902 L
.20881 .30902 L
.21197 .30902 L
.215 .30902 L
.21824 .30902 L
.22135 .30902 L
.22216 .30902 L
.22304 .30902 L
.22389 .30902 L
.22466 .30902 L
.22505 .30902 L
.22527 .30902 L
.22547 .30902 L
.22565 .30902 L
.22575 .30902 L
.22584 .30902 L
.22594 .30902 L
.22603 .30902 L
.22614 .30902 L
.22624 .30902 L
.22633 .30902 L
.22639 .30902 L
.22644 .30902 L
.22654 .30902 L
.22665 .30902 L
.22686 .30902 L
.22704 .30902 L
.22747 .30902 L
.22768 .30902 L
.22792 .30902 L
.22834 .30902 L
.22874 .30902 L
.22949 .30902 L
.2303 .30902 L
.23117 .30902 L
.23277 .30902 L
.23446 .30902 L
.23603 .30902 L
.2375 .30902 L
.24061 .30902 L
.24392 .30902 L
.24711 .30902 L
.25018 .30903 L
.2519 .30903 L
.25345 .30903 L
.25509 .30903 L
.25581 .30903 L
Mistroke
.25659 .30903 L
.25696 .30903 L
.25735 .30903 L
.25756 .30903 L
.25776 .30903 L
.25794 .30903 L
.25814 .30903 L
.25824 .30903 L
.2583 .30903 L
.25835 .30903 L
.25846 .30903 L
.25855 .30903 L
.25861 .30903 L
.25867 .30903 L
.25873 .30903 L
.25879 .30903 L
.25889 .30903 L
.25895 .30903 L
.259 .30903 L
.2592 .30903 L
.25931 .30903 L
.25942 .30903 L
.25962 .30903 L
.25981 .30903 L
.26019 .30903 L
.26059 .30903 L
.26132 .30903 L
.26217 .30903 L
.26298 .30903 L
.26457 .30903 L
.26605 .30902 L
.26755 .30902 L
.2692 .30902 L
.27242 .309 L
.27552 .30899 L
.27882 .30898 L
.282 .30896 L
.2836 .30896 L
.2843 .30895 L
.28506 .30895 L
.28548 .30895 L
.28586 .30895 L
.28626 .30895 L
.28663 .30895 L
.28681 .30895 L
.28702 .30895 L
.28713 .30895 L
.28724 .30895 L
.28734 .30895 L
.28739 .30895 L
Mistroke
.28744 .30895 L
.2875 .30895 L
.28756 .30895 L
.28761 .30895 L
.28766 .30895 L
.28776 .30895 L
.28786 .30895 L
.28797 .30895 L
.28807 .30895 L
.28831 .30895 L
.28852 .30895 L
.28871 .30895 L
.28915 .30895 L
.28953 .30895 L
.28994 .30895 L
.29065 .30896 L
.29143 .30896 L
.29299 .30897 L
.29466 .30898 L
.29627 .309 L
.29796 .30903 L
.30102 .30908 L
.30428 .30915 L
.30741 .30921 L
.30901 .30924 L
.30985 .30926 L
.31074 .30927 L
.31154 .30928 L
.31196 .30928 L
.31241 .30928 L
.31263 .30928 L
.31283 .30929 L
.31303 .30929 L
.31321 .30929 L
.31338 .30929 L
.31348 .30929 L
.31357 .30929 L
.31366 .30929 L
.31377 .30929 L
.31386 .30929 L
.31395 .30929 L
.31406 .30929 L
.31415 .30929 L
.31424 .30929 L
.31433 .30929 L
.31454 .30929 L
.31474 .30929 L
.31509 .30928 L
.31547 .30928 L
.31588 .30928 L
Mistroke
.31626 .30927 L
.31713 .30926 L
.31796 .30924 L
.31875 .30922 L
.32024 .30917 L
.32183 .3091 L
.3233 .30902 L
.32644 .30881 L
.32978 .30856 L
.33145 .30844 L
.33299 .30833 L
.33459 .30825 L
.33537 .30821 L
.33608 .30819 L
.33643 .30818 L
.33681 .30817 L
.33702 .30817 L
.33721 .30816 L
.3374 .30816 L
.3375 .30816 L
.33759 .30816 L
.33769 .30816 L
.33779 .30816 L
.33789 .30816 L
.33795 .30816 L
.338 .30816 L
.3381 .30816 L
.33818 .30816 L
.33828 .30816 L
.33838 .30816 L
.33849 .30816 L
.3386 .30816 L
.3388 .30816 L
.33901 .30817 L
.33925 .30817 L
.33967 .30818 L
.34007 .3082 L
.34081 .30823 L
.34161 .30828 L
.34249 .30835 L
.34407 .30852 L
.34575 .30875 L
.34909 .30937 L
.35231 .31009 L
.35541 .31074 L
.35701 .31101 L
.35781 .31112 L
.35827 .31117 L
.3587 .31121 L
.35909 .31124 L
Mistroke
.35952 .31127 L
.35971 .31128 L
.35991 .31129 L
.36008 .31129 L
.36017 .31129 L
.36027 .3113 L
.36037 .3113 L
.36043 .3113 L
.36049 .3113 L
.36058 .3113 L
.36068 .3113 L
.36074 .3113 L
.36081 .3113 L
.36087 .3113 L
.36092 .3113 L
.36102 .31129 L
.36113 .31129 L
.36133 .31129 L
.36152 .31128 L
.36195 .31125 L
.36235 .31122 L
.36278 .31117 L
.36358 .31106 L
.36435 .31092 L
.36507 .31075 L
.36672 .31026 L
.36821 .30967 L
.37143 .30807 L
.37454 .30633 L
.37611 .30549 L
.37783 .30469 L
.37863 .30439 L
.37948 .30413 L
.37989 .30403 L
.38028 .30394 L
.38066 .30388 L
.38101 .30384 L
.38119 .30382 L
.38138 .30381 L
.38149 .3038 L
.38159 .3038 L
.38169 .30379 L
.38179 .30379 L
.38184 .30379 L
.3819 .30379 L
.38199 .30379 L
.3821 .30379 L
.38216 .30379 L
.38222 .3038 L
.38241 .30381 L
Mistroke
.38251 .30382 L
.38261 .30382 L
.38298 .30387 L
.38319 .3039 L
.38338 .30394 L
.38409 .30412 L
.38448 .30424 L
.38489 .3044 L
.38562 .30474 L
.38729 .30581 L
.38885 .30714 L
.39032 .30866 L
.39342 .31239 L
.395 .31436 L
.39673 .31636 L
.39839 .31797 L
.39912 .31853 L
.39991 .31902 L
.40033 .31922 L
.40072 .31938 L
.40109 .31949 L
.40127 .31953 L
.40148 .31956 L
.40159 .31958 L
.4017 .31959 L
.4018 .3196 L
.4019 .3196 L
.40196 .3196 L
.40201 .3196 L
.40207 .3196 L
.40213 .3196 L
.40224 .31959 L
.4023 .31959 L
.40235 .31959 L
.40254 .31956 L
.40265 .31954 L
.40274 .31953 L
.40296 .31947 L
.40316 .31941 L
.40357 .31925 L
.404 .31902 L
.4048 .31846 L
.40552 .31777 L
.40629 .31687 L
.40785 .3145 L
.40932 .31169 L
.41243 .30446 L
.41574 .29653 L
.41739 .29326 L
.41819 .29198 L
Mistroke
.41892 .29104 L
.41929 .29066 L
.41969 .29031 L
.42006 .29006 L
.4204 .28988 L
.42059 .28981 L
.42077 .28977 L
.42087 .28975 L
.42096 .28973 L
.42102 .28973 L
.42107 .28972 L
.42117 .28972 L
.42127 .28972 L
.42133 .28973 L
.42138 .28973 L
.42148 .28975 L
.42154 .28976 L
.42159 .28977 L
.42178 .28983 L
.42199 .28991 L
.42219 .29002 L
.42239 .29014 L
.42275 .29043 L
.42314 .29084 L
.42357 .29138 L
.42433 .29262 L
.42504 .29408 L
.42655 .29811 L
.4282 .30384 L
.43144 .31755 L
.43455 .3307 L
.43536 .33359 L
.43625 .33632 L
.43709 .33842 L
.43786 .33985 L
.43825 .34038 L
.43846 .3406 L
.43867 .3408 L
.43886 .34093 L
.43896 .34099 L
.43907 .34104 L
.43917 .34108 L
.43926 .3411 L
.43935 .34112 L
.43944 .34113 L
.43954 .34113 L
.43959 .34112 L
.43964 .34112 L
.43975 .34109 L
.43981 .34108 L
Mistroke
.43986 .34106 L
.44005 .34097 L
.44014 .34091 L
.44025 .34084 L
.44047 .34065 L
.4407 .34038 L
.44112 .33976 L
.44155 .33895 L
.44195 .33802 L
.44284 .33533 L
.44446 .32844 L
.44596 .31995 L
.44762 .3089 L
.45086 .28547 L
.45235 .27565 L
.45398 .26699 L
.45486 .26352 L
.45529 .26221 L
.45568 .26124 L
.45587 .26084 L
.45608 .26048 L
.45626 .26022 L
.45646 .25999 L
.45656 .2599 L
.45667 .25981 L
.45673 .25978 L
.45678 .25975 L
.45684 .25973 L
.45689 .25971 L
.45699 .25969 L
.45704 .25968 L
.4571 .25968 L
.45719 .25969 L
.45729 .25972 L
.45739 .25977 L
.45749 .25983 L
.4576 .25991 L
.45771 .26002 L
.45792 .26028 L
.4581 .26058 L
.45849 .26137 L
.45885 .26235 L
.45965 .26533 L
.46052 .26979 L
.46212 .28105 L
.46381 .2966 L
.46686 .3298 L
.46856 .34802 L
.4701 .36236 L
.47087 .3682 L
Mistroke
.47171 .37334 L
.47209 .37523 L
.47249 .37688 L
.47284 .378 L
.47322 .3789 L
.47341 .37922 L
.47352 .37936 L
.47362 .37946 L
.47372 .37955 L
.47378 .37958 L
.47383 .37961 L
.47393 .37963 L
.47403 .37963 L
.47412 .37961 L
.47422 .37957 L
.47432 .37949 L
.47442 .3794 L
.47459 .37917 L
.47478 .37885 L
.47499 .37835 L
.47523 .37768 L
.47565 .37608 L
.47607 .37408 L
.47645 .37182 L
.4773 .36552 L
.4781 .35801 L
.47959 .34036 L
.48269 .29382 L
.48426 .26903 L
.48599 .24455 L
.48678 .23506 L
.48763 .22657 L
.48804 .22316 L
.48843 .2204 L
.4888 .21819 L
.48916 .21653 L
.48953 .21525 L
.48972 .21477 L
.48982 .21457 L
.48993 .21439 L
.48999 .21432 L
.49004 .21426 L
.49014 .21418 L
.4902 .21415 L
.49026 .21413 L
.49036 .21413 L
.49046 .21416 L
.49055 .21422 L
.49065 .21433 L
.49076 .21448 L
Mistroke
.49093 .21481 L
.49112 .21531 L
.49146 .21653 L
.49187 .21854 L
.49224 .2209 L
.49303 .22765 L
.49377 .23587 L
.49543 .26071 L
.49858 .32359 L
.50161 .38509 L
.50316 .40924 L
.50358 .41444 L
.50403 .41915 L
.50445 .42281 L
.50483 .42548 L
.50502 .42655 L
.50522 .42753 L
.5054 .42821 L
.50559 .4288 L
.5057 .42904 L
.5058 .42922 L
.5059 .42936 L
.50596 .42941 L
.50602 .42944 L
.50611 .42946 L
.50622 .42944 L
.50632 .42936 L
.50641 .42925 L
.5065 .42909 L
.5066 .42888 L
.50678 .42836 L
.50696 .42769 L
.50712 .42695 L
.50749 .42476 L
.50788 .42171 L
.50864 .41365 L
.50946 .40203 L
.51093 .37407 L
.51425 .28955 L
.51591 .2452 L
.51745 .20908 L
.51822 .19407 L
.51894 .18237 L
.5197 .173 L
.5201 .1693 L
.5203 .16773 L
.52053 .16635 L
.52074 .16532 L
.52093 .16462 L
.52102 .16436 L
Mistroke
.52112 .16414 L
.52121 .16398 L
.5213 .16389 L
.5214 .16384 L
.52149 .16385 L
.52159 .16392 L
.52165 .164 L
.5217 .16408 L
.52181 .1643 L
.52193 .16462 L
.52214 .16543 L
.52236 .16659 L
.52256 .16791 L
.52301 .17181 L
.52343 .17656 L
.52383 .182 L
.52544 .21339 L
.52693 .25307 L
.5301 .35505 L
.5317 .40399 L
.53315 .44049 L
.53396 .45591 L
.53472 .46672 L
.53514 .47095 L
.53534 .47252 L
.53553 .47373 L
.53573 .47474 L
.53584 .47516 L
.53595 .47551 L
.53601 .47565 L
.53607 .47575 L
.53613 .47584 L
.53619 .47591 L
.53629 .47595 L
.53635 .47594 L
.5364 .4759 L
.5365 .47579 L
.53659 .47561 L
.53669 .47535 L
.53679 .47499 L
.53701 .47398 L
.53721 .47275 L
.53759 .46954 L
.53795 .4655 L
.53875 .45309 L
.53962 .43455 L
.5412 .38923 L
.54289 .32957 L
.54592 .21729 L
.54747 .17033 L
Mistroke
.54834 .15016 L
.54873 .14297 L
.54914 .13655 L
.54955 .13154 L
.54993 .12823 L
.55011 .12706 L
.5502 .12655 L
.5503 .12611 L
.55039 .12579 L
.55049 .12552 L
.55058 .12534 L
.55066 .12524 L
.55076 .1252 L
.55082 .12522 L
.55087 .12526 L
.55097 .12541 L
.55108 .12566 L
.55118 .126 L
.55128 .12641 L
.55146 .1274 L
.55167 .12895 L
.55187 .13074 L
.55232 .13604 L
.5527 .14185 L
.5531 .14939 L
.55383 .16627 L
.55549 .2182 L
.55881 .35313 L
.56048 .41801 L
.56121 .44258 L
.56201 .46567 L
.56278 .4831 L
.56314 .48939 L
.56351 .49481 L
.5637 .4971 L
.5639 .49921 L
.5641 .50078 L
.56427 .5019 L
.56437 .50241 L
.56447 .50286 L
.56453 .50305 L
.56459 .5032 L
.56464 .50333 L
.56469 .50341 L
.56479 .50351 L
.56489 .50351 L
.56499 .50342 L
.56509 .50321 L
.56515 .50306 L
.5652 .50289 L
Mistroke
.5653 .5025 L
.56551 .50129 L
.5657 .49986 L
.56591 .49793 L
.56637 .49206 L
.56679 .48488 L
.56758 .46733 L
.56841 .44331 L
.57146 .32092 L
.57316 .24538 L
.57471 .18421 L
.57548 .15904 L
.57632 .13699 L
.5767 .12895 L
.57711 .12196 L
.57746 .11728 L
.57766 .11516 L
.57784 .11355 L
.57804 .1122 L
.57814 .11166 L
.57826 .11121 L
.57831 .11105 L
.57836 .11091 L
.57846 .11073 L
.57856 .11066 L
.57865 .11069 L
.57874 .1108 L
.57883 .11098 L
.57892 .11126 L
.57901 .11166 L
.57921 .1128 L
.5794 .11419 L
.57981 .11863 L
.58026 .12543 L
.58107 .14281 L
.58183 .1642 L
.58266 .19296 L
.58435 .26325 L
.58603 .34037 L
.58757 .40708 L
.58908 .46001 L
.58984 .47977 L
.59027 .48851 L
.59068 .49507 L
.59107 .49986 L
.59129 .50182 L
.5914 .50257 L
.5915 .50316 L
.59159 .5036 L
.59167 .50393 L
Mistroke
.59177 .50421 L
.59186 .5044 L
.59196 .50448 L
.59206 .50447 L
.59216 .50434 L
.59225 .50413 L
.59236 .50378 L
.59247 .50325 L
.59268 .50195 L
.59288 .50023 L
.59306 .49826 L
.59349 .49244 L
.59393 .48433 L
.59469 .46598 L
.59551 .44072 L
.59698 .38366 L
.59858 .31241 L
.60031 .23548 L
.60111 .20339 L
.60197 .17386 L
.60277 .15151 L
.60351 .13626 L
.60388 .13068 L
.60426 .12633 L
.60446 .12471 L
.60465 .12358 L
.60476 .12311 L
.60485 .12279 L
.60491 .12265 L
.60497 .12255 L
.60502 .12248 L
.60507 .12244 L
.60516 .12245 L
.60525 .12255 L
.60533 .12272 L
.60541 .12295 L
.60551 .1233 L
.6056 .12379 L
.60579 .12495 L
.60598 .12654 L
.60618 .12866 L
.60654 .13353 L
.60729 .1478 L
.6081 .16905 L
.60957 .22014 L
.61287 .36117 L
.61366 .39286 L
.61451 .4229 L
.61525 .44471 L
.61604 .46316 L
Mistroke
.61647 .47059 L
.61666 .47328 L
.61687 .47582 L
.61705 .4777 L
.61724 .47933 L
.61735 .48005 L
.61745 .48061 L
.61754 .48105 L
.61764 .48141 L
.61774 .48166 L
.61783 .4818 L
.61792 .48186 L
.618 .48185 L
.6181 .48173 L
.61819 .48154 L
.61829 .48123 L
.61839 .48079 L
.61857 .4798 L
.61873 .47858 L
.6191 .47481 L
.6195 .46917 L
.61994 .46128 L
.62073 .44256 L
.62222 .39487 L
.6255 .26437 L
.62628 .23524 L
.62712 .20742 L
.62785 .18728 L
.62827 .17773 L
.62865 .17018 L
.62905 .16368 L
.62942 .15911 L
.62961 .15728 L
.62981 .15567 L
.62993 .15497 L
.63003 .15443 L
.63013 .15401 L
.63023 .15367 L
.63032 .15347 L
.63041 .15336 L
.63049 .15331 L
.63057 .15333 L
.63066 .15343 L
.63074 .15359 L
.63084 .15386 L
.63094 .15423 L
.63114 .15529 L
.63133 .15665 L
.63168 .1601 L
.63206 .16503 L
Mistroke
.63247 .17188 L
.6333 .18993 L
.63478 .23386 L
.63803 .35158 L
.63953 .39854 L
.64038 .41908 L
.64116 .4332 L
.64155 .43838 L
.64178 .44074 L
.64199 .4425 L
.64221 .44393 L
.64233 .44454 L
.64244 .44499 L
.64255 .44531 L
.64265 .4455 L
.6427 .44558 L
.64275 .44562 L
.64281 .44564 L
.64287 .44563 L
.64296 .44555 L
.64306 .44537 L
.64312 .44525 L
.64317 .44509 L
.64327 .44472 L
.64347 .44376 L
.64364 .4426 L
.64408 .43863 L
.64448 .43342 L
.64526 .42 L
.64608 .40118 L
.64756 .35862 L
.65059 .26164 L
.65214 .22214 L
.65256 .21381 L
.65301 .20639 L
.65343 .20078 L
.65381 .19686 L
.654 .19535 L
.65421 .19403 L
.6543 .19354 L
.6544 .19309 L
.65449 .19275 L
.65458 .1925 L
.65467 .19228 L
.65478 .19213 L
.65488 .19208 L
.65497 .19209 L
.65502 .19213 L
.65507 .19219 L
.65517 .19237 L
Mistroke
.65523 .19251 L
.65529 .19268 L
.6554 .19305 L
.65558 .19389 L
.65576 .19504 L
.6561 .1978 L
.65647 .20172 L
.65687 .2071 L
.65769 .22139 L
.65844 .23766 L
.66012 .28184 L
.66178 .32869 L
.66332 .36693 L
.66409 .38225 L
.66481 .39355 L
.66517 .39799 L
.66557 .40178 L
.66578 .40339 L
.666 .40475 L
.66619 .40565 L
.6663 .40604 L
.6664 .40633 L
.6665 .40655 L
.66655 .40664 L
.66661 .40671 L
.66671 .40679 L
.6668 .40679 L
.66686 .40676 L
.66691 .40671 L
.66701 .40657 L
.66707 .40646 L
.66712 .40634 L
.66724 .40599 L
.66745 .40517 L
.66763 .40419 L
.66804 .40119 L
.66841 .39757 L
.66881 .39275 L
.66953 .38178 L
.67114 .34945 L
.67283 .30945 L
.67443 .27343 L
.67513 .25999 L
.67589 .24772 L
.67631 .24213 L
.67669 .2378 L
.67709 .23427 L
.67746 .23177 L
.67764 .23081 L
.67784 .23001 L
Mistroke
.67796 .22966 L
.67807 .22941 L
.67817 .22923 L
.67822 .22916 L
.67827 .22911 L
.67833 .22908 L
.67839 .22906 L
.67844 .22906 L
.67849 .22908 L
.67859 .22915 L
.67869 .22929 L
.67874 .22939 L
.6788 .22951 L
.6789 .22977 L
.67914 .23061 L
.67934 .2316 L
.67956 .23291 L
.67995 .2359 L
.68084 .24553 L
.68161 .25658 L
.68246 .27105 L
.68414 .30356 L
.68568 .33277 L
.6872 .35583 L
.68796 .36414 L
.68839 .3677 L
.68879 .37021 L
.689 .37122 L
.68919 .37195 L
.68941 .37254 L
.68952 .37275 L
.68958 .37285 L
.68963 .37292 L
.68974 .37301 L
.68983 .37304 L
.68993 .37303 L
.68999 .373 L
.69005 .37296 L
.69014 .37285 L
.69023 .37271 L
.69033 .37249 L
.69043 .37225 L
.69061 .37167 L
.6908 .37089 L
.69115 .36907 L
.69152 .36653 L
.69192 .36311 L
.69349 .34452 L
.69517 .31885 L
.69676 .2941 L
Mistroke
.6976 .28258 L
.6985 .27237 L
.69929 .26548 L
.69974 .2626 L
.69994 .26154 L
.70016 .26061 L
.70034 .25997 L
.70055 .25942 L
.70064 .25923 L
.70073 .25906 L
.70082 .25894 L
.7009 .25886 L
.701 .25879 L
.7011 .25876 L
.7012 .25877 L
.70125 .2588 L
.70131 .25883 L
.70141 .25893 L
.70151 .25907 L
.7017 .25942 L
.7019 .25997 L
.70212 .26073 L
.70251 .26252 L
.70293 .26505 L
.7034 .2685 L
.70502 .28476 L
.7067 .30554 L
.70824 .32402 L
.70902 .33204 L
.70975 .33824 L
.71051 .34316 L
.71091 .34507 L
.71112 .34586 L
.71134 .34655 L
.71155 .34704 L
.71165 .34724 L
.71177 .34743 L
.71188 .34755 L
.71197 .34764 L
.71207 .34769 L
.71216 .34772 L
.71222 .34772 L
.71227 .34771 L
.71233 .34769 L
.71238 .34767 L
.71248 .34759 L
.71254 .34754 L
.71259 .34748 L
.71281 .34712 L
.71293 .34689 L
Mistroke
.71305 .34658 L
.71346 .34528 L
.71389 .34337 L
.71467 .33874 L
.71638 .32459 L
.71799 .30892 L
.71946 .2957 L
.72029 .28949 L
.7207 .28694 L
.72107 .28491 L
.72143 .28323 L
.72183 .28177 L
.72224 .28069 L
.72245 .28028 L
.72266 .28 L
.72276 .27989 L
.72282 .27985 L
.72288 .27981 L
.72293 .27978 L
.72299 .27976 L
.72309 .27975 L
.72318 .27975 L
.72329 .27979 L
.72338 .27984 L
.72347 .27991 L
.72358 .28003 L
.72369 .28016 L
.72392 .28056 L
.72413 .28101 L
.72434 .28159 L
.72517 .28473 L
.72607 .2895 L
.72769 .3006 L
.72926 .31222 L
.73009 .31787 L
.73098 .32305 L
.73143 .3252 L
.73185 .32694 L
.73225 .32833 L
.73263 .32934 L
.73298 .33006 L
.73316 .33033 L
.73336 .33055 L
.73347 .33064 L
.73356 .3307 L
.73361 .33072 L
.73367 .33074 L
.73377 .33077 L
.73387 .33077 L
.73397 .33076 L
Mistroke
.73407 .33073 L
.73416 .33068 L
.73426 .33062 L
.73435 .33054 L
.73455 .33031 L
.73475 .33002 L
.73496 .32962 L
.73535 .32871 L
.7357 .32768 L
.73656 .32444 L
.73737 .32061 L
.74045 .30397 L
.74127 .30017 L
.74204 .29723 L
.74245 .29594 L
.74284 .29495 L
.74326 .2941 L
.74349 .29376 L
.74372 .29347 L
.74382 .29338 L
.74393 .29329 L
.74402 .29323 L
.74412 .29318 L
.74421 .29314 L
.74431 .29312 L
.7444 .29311 L
.74449 .29311 L
.74459 .29313 L
.74469 .29316 L
.74478 .2932 L
.74488 .29325 L
.7451 .29343 L
.74531 .29365 L
.74568 .29419 L
.74602 .29483 L
.74678 .29674 L
.74833 .30213 L
.75 .30895 L
.75157 .31479 L
.75246 .31738 L
.75289 .31837 L
.75329 .31913 L
.75368 .3197 L
.75388 .31994 L
.7541 .32014 L
.75428 .32028 L
.75437 .32033 L
.75448 .32038 L
.75457 .32042 L
.75466 .32044 L
Mistroke
.75474 .32046 L
.75483 .32046 L
.75493 .32046 L
.75502 .32045 L
.75507 .32044 L
.75513 .32043 L
.75523 .32039 L
.75533 .32035 L
.75543 .3203 L
.75561 .32018 L
.75582 .31999 L
.75602 .31978 L
.75647 .31917 L
.7573 .3176 L
.7581 .31567 L
.75959 .3114 L
.76105 .30714 L
.76188 .30501 L
.76266 .30333 L
.76342 .30209 L
.76385 .30158 L
.76405 .30138 L
.76424 .30123 L
.76445 .3011 L
.76463 .30101 L
.76474 .30097 L
.76484 .30094 L
.76489 .30093 L
.76495 .30092 L
.76501 .30091 L
.76506 .30091 L
.76517 .3009 L
.76522 .3009 L
.76528 .30091 L
.76538 .30092 L
.76548 .30094 L
.76559 .30097 L
.76569 .30101 L
.76593 .30113 L
.76614 .30127 L
.76634 .30142 L
.76678 .30187 L
.76758 .30296 L
.76907 .30574 L
.77071 .30921 L
.77151 .3108 L
.77224 .31208 L
.77294 .31312 L
.77371 .31396 L
.77413 .31429 L
Mistroke
.77432 .31441 L
.77452 .31451 L
.77471 .31458 L
.77489 .31464 L
.77499 .31466 L
.77508 .31467 L
.77518 .31468 L
.77529 .31468 L
.77539 .31468 L
.77544 .31468 L
.77549 .31468 L
.77559 .31466 L
.77569 .31464 L
.77586 .3146 L
.77605 .31453 L
.77626 .31444 L
.77648 .31432 L
.77687 .31404 L
.77764 .31331 L
.77835 .31246 L
.78 .31007 L
.78154 .30785 L
.78231 .3069 L
.78303 .30617 L
.78343 .30584 L
.78386 .30555 L
.78425 .30535 L
.78443 .30527 L
.78461 .30522 L
.7847 .30519 L
.78481 .30517 L
.78489 .30515 L
.78499 .30514 L
.78509 .30512 L
.78515 .30512 L
.7852 .30512 L
.78529 .30511 L
.78539 .30511 L
.78548 .30512 L
.78558 .30513 L
.78568 .30514 L
.78578 .30515 L
.78594 .30519 L
.78612 .30523 L
.78657 .30541 L
.78699 .30563 L
.78778 .30618 L
.79088 .30922 L
.79244 .31061 L
.79287 .31091 L
Mistroke
.79333 .31117 L
.79377 .31138 L
.79417 .31152 L
.79436 .31157 L
.79457 .31161 L
.79467 .31163 L
.79478 .31164 L
.79485 .31165 L
.7949 .31166 L
.79496 .31166 L
.79502 .31166 L
.79511 .31167 L
.7952 .31167 L
.79526 .31167 L
.79531 .31167 L
.79541 .31167 L
.79551 .31166 L
.79561 .31165 L
.79571 .31164 L
.79582 .31162 L
.79619 .31154 L
.79654 .31144 L
.79733 .31111 L
.79817 .31064 L
.79896 .31012 L
.80045 .30906 L
.80128 .30851 L
.80206 .30805 L
.80282 .30769 L
.80351 .30745 L
.80388 .30735 L
.80407 .30732 L
.80427 .30729 L
.80438 .30727 L
.80448 .30726 L
.80458 .30725 L
.80467 .30725 L
.80477 .30724 L
.80483 .30724 L
.80489 .30724 L
.80499 .30724 L
.80504 .30724 L
.8051 .30724 L
.80519 .30724 L
.80525 .30724 L
.8053 .30725 L
.80541 .30725 L
.80552 .30726 L
.80572 .30729 L
.80591 .30731 L
Mistroke
.80636 .30741 L
.80678 .30752 L
.80756 .30779 L
.80839 .30814 L
.80987 .30885 L
.81069 .30923 L
.81146 .30955 L
.81221 .30981 L
.81291 .31 L
.81327 .31008 L
.81366 .31013 L
.81388 .31016 L
.81399 .31017 L
.81409 .31018 L
.81418 .31018 L
.81427 .31019 L
.81437 .31019 L
.81447 .31019 L
.81453 .3102 L
.81459 .3102 L
.81464 .3102 L
.81469 .3102 L
.81479 .31019 L
.81489 .31019 L
.81495 .31019 L
.815 .31019 L
.81511 .31018 L
.81534 .31016 L
.81556 .31014 L
.81577 .31012 L
.81615 .31006 L
.81692 .30989 L
.81774 .30967 L
.81922 .30921 L
.82082 .30872 L
.82172 .30851 L
.82215 .30842 L
.82255 .30836 L
.82291 .30831 L
.8233 .30828 L
.82352 .30826 L
.82363 .30826 L
.82373 .30825 L
.82382 .30825 L
.82391 .30825 L
.82401 .30825 L
.82412 .30824 L
.82422 .30824 L
.82427 .30825 L
.82433 .30825 L
Mistroke
.82443 .30825 L
.82453 .30825 L
.82464 .30825 L
.82474 .30826 L
.82497 .30827 L
.82517 .30829 L
.82538 .30831 L
.82577 .30835 L
.82653 .30846 L
.82737 .30861 L
.82905 .30896 L
.82992 .30914 L
.83075 .30928 L
.83149 .30939 L
.83191 .30943 L
.83229 .30947 L
.83249 .30948 L
.83269 .30949 L
.83289 .3095 L
.83307 .30951 L
.83317 .30951 L
.83327 .30951 L
.83337 .30952 L
.83343 .30952 L
.83348 .30952 L
.83359 .30952 L
.83364 .30952 L
.8337 .30952 L
.8338 .30952 L
.83385 .30951 L
.83391 .30951 L
.834 .30951 L
.8341 .30951 L
.83428 .3095 L
.83447 .3095 L
.83468 .30948 L
.83541 .30943 L
.83623 .30934 L
.83698 .30925 L
.83867 .30902 L
.84021 .30884 L
.84063 .3088 L
.84108 .30876 L
.8415 .30874 L
.84188 .30872 L
.84207 .30871 L
.84227 .3087 L
.84236 .3087 L
.84246 .3087 L
.84255 .3087 L
Mistroke
.84264 .3087 L
.84273 .3087 L
.84284 .3087 L
.84293 .3087 L
.84303 .3087 L
.84313 .3087 L
.84323 .3087 L
.84334 .3087 L
.84345 .3087 L
.84364 .30871 L
.84385 .30871 L
.84422 .30873 L
.84492 .30877 L
.84568 .30882 L
.84652 .30889 L
.84821 .30904 L
.849 .3091 L
.84976 .30915 L
.85018 .30917 L
.85064 .30919 L
.85084 .3092 L
.85106 .30921 L
.85124 .30921 L
.85144 .30921 L
.85165 .30922 L
.85176 .30922 L
.85182 .30922 L
.85187 .30922 L
.85197 .30922 L
.85206 .30922 L
.85216 .30922 L
.85222 .30922 L
.85227 .30922 L
.85232 .30922 L
.85237 .30922 L
.85247 .30922 L
.85259 .30922 L
.8527 .30922 L
.85292 .30921 L
.85316 .30921 L
.85356 .3092 L
.85393 .30918 L
.85478 .30915 L
.85628 .30906 L
.85791 .30898 L
.85881 .30894 L
.8592 .30892 L
.85963 .30891 L
.86003 .3089 L
.86041 .3089 L
Mistroke
.86062 .30889 L
.86082 .30889 L
.86092 .30889 L
.86098 .30889 L
.86104 .30889 L
.86114 .30889 L
.8612 .30889 L
.86125 .30889 L
.86134 .30889 L
.86143 .30889 L
.86153 .30889 L
.86164 .30889 L
.86175 .30889 L
.86186 .30889 L
.86205 .3089 L
.86241 .3089 L
.8628 .30891 L
.86366 .30893 L
.86447 .30896 L
.8661 .30901 L
.86689 .30904 L
.86762 .30906 L
.86798 .30907 L
.86837 .30908 L
.86875 .30908 L
.86909 .30909 L
.86928 .30909 L
.86948 .30909 L
.86959 .30909 L
.8697 .30909 L
.8698 .30909 L
.8699 .3091 L
.86999 .3091 L
.87008 .3091 L
.87018 .3091 L
.87027 .3091 L
.87037 .3091 L
.87047 .3091 L
.87057 .3091 L
.87066 .30909 L
.87085 .30909 L
.87103 .30909 L
.87143 .30909 L
.87179 .30908 L
.87216 .30908 L
.87381 .30905 L
.87541 .30901 L
.87611 .309 L
.87687 .30899 L
.87729 .30898 L
Mistroke
.87768 .30898 L
.87805 .30897 L
.87825 .30897 L
.87844 .30897 L
.87864 .30897 L
.87875 .30897 L
.87885 .30897 L
.87895 .30897 L
.87904 .30897 L
.87914 .30897 L
.87924 .30897 L
.8793 .30897 L
.87936 .30897 L
.87942 .30897 L
.87948 .30897 L
.87959 .30897 L
.8797 .30897 L
.87992 .30897 L
.88012 .30897 L
.88052 .30897 L
.88096 .30898 L
.88176 .30899 L
.88325 .30901 L
.88481 .30903 L
.88569 .30904 L
.8861 .30904 L
.88652 .30904 L
.8869 .30904 L
.88712 .30904 L
.88732 .30905 L
.88741 .30905 L
.8875 .30905 L
.88758 .30905 L
.88767 .30905 L
.88776 .30905 L
.88785 .30905 L
.88794 .30905 L
.88804 .30905 L
.8881 .30905 L
.88815 .30905 L
.88826 .30905 L
.88836 .30905 L
.88845 .30905 L
.88866 .30905 L
.88889 .30904 L
.88926 .30904 L
.88968 .30904 L
.89049 .30904 L
.89123 .30903 L
.8929 .30902 L
Mistroke
.89363 .30901 L
.89442 .30901 L
.89487 .309 L
.89528 .309 L
.89547 .309 L
.89569 .309 L
.89589 .309 L
.89608 .309 L
.89627 .309 L
.89637 .309 L
.89647 .309 L
.89656 .309 L
.89664 .309 L
.89674 .309 L
.89684 .309 L
.89689 .309 L
.89694 .309 L
.897 .309 L
.89706 .309 L
.89716 .309 L
.89727 .309 L
.89748 .309 L
.89767 .309 L
.8981 .309 L
.89848 .309 L
.89936 .30901 L
.90102 .30901 L
.90175 .30902 L
.90256 .30902 L
.90333 .30902 L
.90368 .30903 L
.90405 .30903 L
.90424 .30903 L
.90445 .30903 L
.90464 .30903 L
.90481 .30903 L
.90491 .30903 L
.90502 .30903 L
.90508 .30903 L
.90513 .30903 L
.90519 .30903 L
.90524 .30903 L
.90533 .30903 L
.90543 .30903 L
.90553 .30903 L
.90563 .30903 L
.90569 .30903 L
.90574 .30903 L
.90584 .30903 L
.90606 .30903 L
Mistroke
.90624 .30903 L
.90645 .30903 L
.90691 .30903 L
.90733 .30903 L
.90895 .30902 L
.91059 .30902 L
.91139 .30901 L
.91212 .30901 L
.91248 .30901 L
.91267 .30901 L
.91288 .30901 L
.91306 .30901 L
.91325 .30901 L
.91343 .30901 L
.91359 .30901 L
.91369 .30901 L
.91379 .30901 L
.91389 .30901 L
.91399 .30901 L
.91408 .30901 L
.91417 .30901 L
.91426 .30901 L
.91435 .30901 L
.91445 .30901 L
.91456 .30901 L
.91475 .30901 L
.91517 .30901 L
.91557 .30901 L
.91593 .30901 L
.91675 .30901 L
.91822 .30902 L
.91902 .30902 L
.91988 .30902 L
.92061 .30902 L
.92102 .30902 L
.92121 .30902 L
.92141 .30902 L
.9216 .30902 L
.92179 .30902 L
.9219 .30902 L
.92199 .30902 L
.92209 .30902 L
.92218 .30902 L
.92227 .30902 L
.92236 .30902 L
.92245 .30902 L
.92255 .30902 L
.92263 .30902 L
.92273 .30902 L
.92281 .30902 L
Mistroke
.92289 .30902 L
.9231 .30902 L
.92328 .30902 L
.92371 .30902 L
.92409 .30902 L
.92449 .30902 L
.92609 .30902 L
.92694 .30902 L
.92783 .30902 L
.92863 .30902 L
.92905 .30902 L
.9295 .30902 L
.92972 .30902 L
.92992 .30902 L
.93012 .30901 L
.9303 .30901 L
.93047 .30901 L
.93056 .30901 L
.93066 .30901 L
.93075 .30901 L
.93086 .30901 L
.93096 .30901 L
.93105 .30901 L
.93115 .30901 L
.93124 .30901 L
.93133 .30901 L
.93143 .30901 L
.93164 .30901 L
.93183 .30901 L
.93219 .30902 L
.93257 .30902 L
.93423 .30902 L
.93582 .30902 L
.93651 .30902 L
.93727 .30902 L
.93769 .30902 L
.93807 .30902 L
.93826 .30902 L
.93844 .30902 L
.93865 .30902 L
.93883 .30902 L
.93893 .30902 L
.93899 .30902 L
.93904 .30902 L
.93909 .30902 L
.93915 .30902 L
.93925 .30902 L
.93935 .30902 L
.93945 .30902 L
.93955 .30902 L
Mistroke
.93964 .30902 L
.93984 .30902 L
.94006 .30902 L
.94051 .30902 L
.94093 .30902 L
.94132 .30902 L
.94207 .30902 L
.94374 .30902 L
.94451 .30902 L
.94533 .30902 L
.94573 .30902 L
.94611 .30902 L
.94644 .30902 L
.94663 .30902 L
.94681 .30902 L
.947 .30902 L
.9471 .30902 L
.9472 .30902 L
.94729 .30902 L
.94738 .30902 L
.94747 .30902 L
.94757 .30902 L
.94767 .30902 L
.94772 .30902 L
.94778 .30902 L
.94787 .30902 L
.94797 .30902 L
.94818 .30902 L
.94841 .30902 L
.94883 .30902 L
.94928 .30902 L
.9501 .30902 L
.9517 .30902 L
.95254 .30902 L
.95343 .30902 L
.95381 .30902 L
.95422 .30902 L
.95446 .30902 L
.95467 .30902 L
.95489 .30902 L
.9551 .30902 L
.95528 .30902 L
.95538 .30902 L
.95547 .30902 L
.95558 .30902 L
.95563 .30902 L
.95569 .30902 L
.95578 .30902 L
.95589 .30902 L
.95598 .30902 L
Mistroke
.95607 .30902 L
.95624 .30902 L
.95645 .30902 L
.95664 .30902 L
.95702 .30902 L
.95743 .30902 L
.95817 .30902 L
.95984 .30902 L
.96061 .30902 L
.96142 .30902 L
.96211 .30902 L
.96251 .30902 L
.96287 .30902 L
.96307 .30902 L
.96327 .30902 L
.96335 .30902 L
.96344 .30902 L
.96353 .30902 L
.96362 .30902 L
.96372 .30902 L
.96382 .30902 L
.96392 .30902 L
.96401 .30902 L
.96411 .30902 L
.96417 .30902 L
.96422 .30902 L
.96443 .30902 L
.96463 .30902 L
.96481 .30902 L
.96524 .30902 L
.9661 .30902 L
.96758 .30902 L
.96842 .30902 L
.9692 .30902 L
.96998 .30902 L
.97041 .30902 L
.97081 .30902 L
.97103 .30902 L
.97123 .30902 L
.97134 .30902 L
.97145 .30902 L
.97156 .30902 L
.97162 .30902 L
.97168 .30902 L
.97178 .30902 L
.97184 .30902 L
.9719 .30902 L
.972 .30902 L
.97206 .30902 L
.97211 .30902 L
Mistroke
.97221 .30902 L
.97231 .30902 L
.9725 .30902 L
.97269 .30902 L
.9729 .30902 L
.97327 .30902 L
.9741 .30902 L
.97579 .30902 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{421.375, 260.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008>0001AB000`400?l00000o`00003ooooooooo
oooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo
003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooo
oooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool0
0?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooooooo
ool@ooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooo
ooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo0ol0003o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0
003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo
00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`
ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLoooo
o`00<?ooool3o`000?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?oo
ool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0
033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomco
oooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooo
oooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool3o`000?oooooo
g?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0013ooooo0_o^k^h3ooooo`;ok^k^6Oooool00ol0003oooooooooo`3o
ooooomcooooo000;ooooo`;o000000[o410@ooooooooooook^k^oeEEEOo^k^koooooonk^k_mEEEGo
k^k^0oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h:ooooo`03o`000?oo
oooooooo0?oooooog?ooool000cooooo00?o0000ooooooooool00_ooool01Oo^k^koEEEEomgMgOmE
EEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00[ooooo
00?o0000ooooooooool0oooooooLooooo`0000?oooooo`000?l000001?l00002ooooo`Go00001?oo
ool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooo
oa0@400:ooooo`03o`000?oooooooooo0?oooooog?ooool000Wooooo00CoA4A4omgMgOoooooo0000
1?ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000000[ooooo00?o0000ooooooooool0oooooooLooooo`002Oooool01?oMgMgo
EEEEooooool00003ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000:ooooo`Co0000oooooooKooooo`002_oo
ool00omgMgOoc<c<o`000003ooooo`;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@00[ooooo00?o0000ooooooooool0oooooooLooooo`002_oo
ool00oo^k^koA4A4o`00000?ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`;o00001Oooool00ol0003oooooooooo`3oooooomcooooo000;ooooo`03ogMgMol0
003ooooo00cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`3oooooomcooooo000Xooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool0oooooooLooooo`00:?ooool3o`0000Gooooo
00?o0000ooooooooool0oooooooLooooo`00:Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo0?oooooog?ooool002[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3o
ooooomcooooo000`ooooo`03o`000?oooooooooo0<Sooooo00?o0000ooooooooool0oooooolAoooo
o`00<?ooool00ol0003oooooooooo`38ooooo`;o0000oooooolBooooo`00<?ooool00ol0003ooooo
ooooo`38ooooo`;o0000oooooolBooooo`00<?ooool00ol0003oooooooooo`38ooooo`;o0000oooo
oolBooooo`00<?ooool3o`000<Sooooo0_l0003ooooooa;ooooo000`ooooo`03o`000?oooooooooo
0<Sooooo0_l0000:ooooo`03o`000?oooooooooo0?oooooo1Oooool0033ooooo00?o0000oooooooo
ool0_?ooool00ol0003oooooooooo`09ooooo`;o00002_ooool00ol0003oooooooooo`3oooooo`Go
oooo000`ooooo`03o`000?oooooooooo0;cooooo0_l0000:ooooo`;o00002Oooool2o`000?oooooo
1oooool0033ooooo00?o0000ooooooooool0_?ooool2o`0000[ooooo0_l00009ooooo`;o0000oooo
ool7ooooo`00<?ooool00ol0003oooooooooo`2looooo`;o00002_ooool2o`0000Wooooo0_l0003o
ooooo`Oooooo000`ooooo`03o`000?oooooooooo0;cooooo0_l0000:ooooo`;o00002Oooool2o`00
0?oooooo1oooool0033ooooo00?o0000ooooooooool0_?ooool2o`0000Wooooo00?o0000ooooool0
00002Oooool2o`000?oooooo1oooool0033ooooo00?o0000ooooooooool0_?ooool2o`0000Wooooo
00?o0000ooooool000002Oooool2o`000?oooooo1oooool0033ooooo00?o0000ooooooooool0^ooo
ool00ol0003oooooo`000009ooooo`03o`000?oooooo000000Wooooo0_l0003oooooo`Oooooo000`
ooooo`03o`000?oooooooooo0;_ooooo00?o0000ooooool000002Oooool00ol0003oooooo`000009
ooooo`03o`000?oooooo00000?oooooo1_ooool0033ooooo00?o0000ooooooooool0^oooool00ol0
003oooooo`000009ooooo`03o`000?oooooo000000Wooooo00?o0000ooooool00000ooooool6oooo
o`00<?ooool3o`000;_ooooo00?o0000ooooool000002Oooool00ol0003oooooo`000009ooooo`03
o`000?oooooo00000?oooooo1_ooool0033ooooo00?o0000ooooooooool0^oooool00ol0003ooooo
o`000009ooooo`03o`000?oooooo000000Wooooo00?o0000ooooool00000ooooool6ooooo`00<?oo
ool00ol0003oooooooooo`2kooooo`03o`000?oooooo000000Wooooo00?o0000ooooool000002Ooo
ool00ol0003oooooo`00003oooooo`Kooooo000`ooooo`03o`000?oooooooooo0;_ooooo00?o0000
ooooool000002Oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo000000Wooooo00?o
0000ooooooooool0nOooool0033ooooo00?o0000ooooooooool0^oooool00ol0003oooooo`000009
ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool000002Oooool00ol0003ooooooooo
o`3iooooo`00<?ooool00ol0003oooooooooo`2kooooo`04o`000?ooooooooooo`0000Sooooo00Co
0000oooooooooooo00002?ooool00ol0003oooooo`000008ooooo`;o0000noooool0033ooooo00?o
0000ooooooooool0^oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000So
oooo00?o0000ooooool000002?ooool2o`000?_ooooo000`ooooo`03o`000?oooooooooo0:oooooo
0_l0000:ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002?ooool00ol0
003oooooo`000008ooooo`;o0000noooool0033ooooo00?o0000ooooooooool0[oooool2o`0000[o
oooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo
000000Sooooo00?o0000ooooool00000n_ooool0033ooooo00?o0000ooooooooool0[oooool2o`00
00[ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00008ooooo`03o`000?oo
oooo000000Sooooo00?o0000ooooool00000n_ooool0033ooooo00?o0000ooooooooool0[oooool2
o`0000[ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00008ooooo`03o`00
0?oooooo000000Sooooo00?o0000ooooool00000n_ooool0033ooooo0ol0002_ooooo`;o00002_oo
ool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool0
00002?ooool00ol0003oooooo`00003jooooo`00<?ooool00ol0003oooooooooo`2_ooooo`;o0000
2_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000oooo
ool000002?ooool00ol0003oooooo`00003jooooo`00<?ooool00ol0003oooooooooo`2_ooooo`;o
00002_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000
ooooool000002?ooool00ol0003oooooo`00003jooooo`00<?ooool00ol0003oooooooooo`2^oooo
o`03o`000?oooooo000000[ooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0
0008ooooo`03o`000?oooooo000000Sooooo00?o0000ooooool00000n_ooool0033ooooo00?o0000
ooooooooool0[_ooool01?l0003oooooooooool00009ooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00002?ooool00ol0003oooooo`000008ooooo`03o`000?oooooo00000?[o
oooo000`ooooo`03o`000?oooooooooo0:kooooo00Co0000oooooooooooo00002Oooool01?l0003o
ooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool000002?ooool0
0ol0003oooooo`00003jooooo`00<?ooool00ol0003oooooooooo`2^ooooo`04o`000?oooooooooo
o`0000Wooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00008ooooo`03o`00
0?oooooo000000Sooooo00?o0000ooooool00000n_ooool0013ooooo0_o^k^h3ooooo`;ok^k^6Ooo
ool00ol0003oooooooooo`2^ooooo`04o`000?ooooooooooo`0000Wooooo00Co0000oooooooooooo
00002?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo000000Sooooo00?o0000oooo
ool00000n_ooool000Wooooo1Ol00002ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03
ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP[ooooo00?o0000oooooooo
ool0[_ooool01?l0003oooooooooool00009ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000
oooooooooooo00001oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo000000Wooooo
00?o0000ooooooooool0k_ooool000Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05onk^
k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02_ooool00ol0003oooooooooo`2^ooooo`04o`000?ooooooooooo`0000Wooooo00Co0000
oooooooooooo00002?ooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000So
oooo00?o0000ooooool000002?ooool2o`000?3ooooo00000ooooooo0000o`000004o`0000?ooooo
00?oV9RHob4Q8Oo^k^h01Oooool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo
00Go410@oooooooooooooooooa0@400:ooooo`03o`000?oooooooooo0:kooooo00Co0000oooooooo
oooo00002?ooool01Ol0003ooooooooooooooooo000000Sooooo00Co0000oooooooooooo00001ooo
ool01?l0003oooooooooool00008ooooo`03o`000?oooooo000000Sooooo0_l0003`ooooo`002ooo
ool00onHV9So8B4Qonk^kP03ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000002_ooool00ol0003oooooooooo`2^ooooo`04
o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000008ooooo`04o`000?oooooo
ooooo`0000Oooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000So
oooo0_l0003`ooooo`003?ooool02omgMgOoIVIVooooooooooook^k^oeEEEOo^k^koooooonk^k_mE
EEGok^k^00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000[ooooo
1?l0002]ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000008oooo
o`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?oo
ooooooooo`0000Sooooo0_l0003`ooooo`003Oooool00ol0003oooooooooo`02onk^kP?ooooo0_o^
k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400:ooooo`03o`00
0?oooooooooo0:kooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo0000
00Sooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Kooooo00Co
0000oooooooooooo00002?ooool2o`000?3ooooo0009ooooo`05o`000?nj^[[ooooooiRHV?l@4100
3_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool2o`0000Go
oooo00?o0000ooooooooool0[_ooool01?l0003oooooooooool00008ooooo`05o`000?oooooooooo
ooooool000002?ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool00000
1_ooool01?l0003oooooooooool00008ooooo`;o0000l?ooool000Wooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c00<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02oooo
o`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0[_ooool01?l0003oooooooooool0
0008ooooo`05o`000?ooooooooooooooool000002?ooool01?l0003oooooooooool00007ooooo`05
o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool00008ooooo`;o0000l?ooool0
02Sooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`2^ooooo`04o`000?oooooo
ooooo`0000Sooooo00Go0000ooooooooooooooooo`000008ooooo`04o`000?ooooooooooo`0000Oo
oooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Sooooo0_l0003`
ooooo`00:?ooool3o`0000Gooooo00?o0000ooooooooool0[_ooool01?l0003oooooooooool00008
ooooo`05o`000?ooooooooooooooool000002?ooool01?l0003oooooooooool00007ooooo`05o`00
0?ooooooooooooooool000001_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooo0000
0?3ooooo000Yooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0X_ooool00ol0003o
ooooooooo`09ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000008
ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000006ooooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooo`00003`ooooo`00:_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo0:;ooooo0_l0000:ooooo`04o`000?ooooooooooo`0000So
oooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool0
1Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000006ooooo`04o`00
0?ooooooooooo`000>oooooo000`ooooo`03o`000?oooooooooo0:7ooooo00?o0000ooooool00000
2_ooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool000001oooool01Ol0
003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?oo
ooooooooooooool000001_ooool01?l0003oooooooooool0003_ooooo`00<?ooool00ol0003ooooo
ooooo`2Qooooo`03o`000?oooooo000000[ooooo00Co0000oooooooooooo00002?ooool01Ol0003o
oooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooo
ooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo
0000koooool0033ooooo00?o0000ooooooooool0XOooool00ol0003oooooo`00000:ooooo`04o`00
0?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooooooo
ooooool000001oooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000oooooooooooooooo
o`000006ooooo`04o`000?ooooooooooo`000>oooooo000`ooooo`03o`000?oooooooooo0:7ooooo
00?o0000ooooool000002_ooool01?l0003oooooooooool00008ooooo`05o`000?oooooooooooooo
ool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`00
0006ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool0003_ooooo`00
<?ooool3o`000:7ooooo00?o0000ooooool000002_ooool01?l0003oooooooooool00008ooooo`05
o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000
ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003ooooo
ooooool00008ooooo`03o`000?oooooooooo0>Cooooo000`ooooo`03o`000?oooooooooo0:7ooooo
00?o0000ooooool000002Oooool01Ol0003ooooooooooooooooo000000Sooooo00Go0000oooooooo
ooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0
003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?oo
ooooooooo`0000Oooooo0_l0003Vooooo`00<?ooool00ol0003oooooooooo`2Pooooo`04o`000?oo
ooooooooo`0000Wooooo00Go0000ooooooooooooooooo`000008ooooo`05o`000?oooooooooooooo
ool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooo
ooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003ooooooooo
ool00007ooooo`;o0000i_ooool0033ooooo00?o0000ooooooooool0X?ooool01Ol0003ooooooooo
oooooooo000000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`05o`00
0?ooooooooooooooool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001_ooool0
1?l0003oooooooooool00007ooooo`;o0000i_ooool0033ooooo00?o0000ooooooooool0X?ooool0
1Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`05ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?oooooooooooooo
ool000001_ooool01?l0003oooooooooool00007ooooo`;o0000i_ooool0033ooooo00?o0000oooo
ooooool0X?ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000001oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`05o`00
0?ooooooooooooooool000001_ooool01?l0003oooooooooool00007ooooo`;o0000i_ooool0033o
oooo00?o0000ooooooooool0X?ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000001oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00
0006ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool00007ooooo`;o
0000i_ooool0033ooooo00?o0000ooooooooool0X?ooool01Ol0003ooooooooooooooooo000000So
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`05o`000?oooooooooooooo
ool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooo
ooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003ooooooooo
ool00007ooooo`03o`000?oooooo00000>Gooooo000`ooooo`03o`000?oooooooooo0:3ooooo00Go
0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1Oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo
000000Kooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00003Uooooo`00<?ooool0
0ol0003oooooooooo`2Pooooo`05o`000?ooooooooooooooool000002?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000007ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Ko
oooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000
ooooool00000iOooool0033ooooo00?o0000ooooooooool0X?ooool01Ol0003ooooooooooooooooo
000000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`05o`000?oooooo
ooooooooool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go
0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003o
ooooooooool00007ooooo`03o`000?oooooo00000>Gooooo000`ooooo`03o`000?oooooooooo0:3o
oooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool0
1Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo00001oooool00ol0003ooooo
o`00003Uooooo`00<?ooool3o`000:3ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`00
0?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooo
oooooooo00001_ooool01?l0003oooooooooool0003Uooooo`00<?ooool00ol0003oooooooooo`2O
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooo
oooo000000Kooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Ko
oooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`3Jooooo`00<?ooool00ol0003o
ooooooooo`2Cooooo`;o00002_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001_ooool0
1?l0003oooooooooool00006ooooo`04o`000?ooooooooooo`0000Oooooo0_l0003Looooo`00<?oo
ool00ol0003oooooooooo`2Cooooo`;o00002_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool0
00001_ooool01Ol0003ooooooooooooooooo000000Gooooo00Co0000oooooooooooo00001oooool2
o`000=cooooo000`ooooo`03o`000?oooooooooo09?ooooo00?o0000ooooool000002Oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006
ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Gooooo
00Co0000oooooooooooo00001oooool2o`000=cooooo000`ooooo`03o`000?oooooooooo04kooooo
0_o^k^h3ooooo`;ok^k^?Oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01Oooool00oo^k^ko0000ooooo`02ooooo`03onk^k_l0003ooooo00Ko
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000oooo
ooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001Oooool01?l0003ooooooooo
ool00007ooooo`;o00005?ooool2onk^kP?ooooo0_o^k^i>ooooo`;ok^k^0oooool2onk^kVcooooo
000`ooooo`03o`000?oooooooooo04Sooooo00goA4A4o`000?l0003o<S8bomgMgOooooook^k^oeEE
EOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb
<S;ok^k^;_ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooool000000ol000002Ol@413oooooo`000?mEEEGok^k^ooooooo^k^koEEEEo`000003ooooo`Go
00000_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooo
oooo000000Kooooo00Go0000ooooooooooooooooo`000005ooooo`04o`000?ooooooooooo`0000Ko
oooo1Ol000000ol@413oooooooooo`02ooooo`;o8B4Q1Oooool03Om4A4Co0000o`000?lb<S;ogMgM
ooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^
k_lb<S;o0000oc8b<_o^k^hhooooo`Go00000_ooool01oo^k^koEEEEonk^k_ooooook^k^oeEEEOo^
k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^iMooooo`00<?ooool0
0ol0003oooooooooo`1;ooooo`09ogMgMolb<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Ko
oooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02kooooo00Co0000oooo
oooooooo00002Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000ooo
ool01ol0003ok^k^oeEEEOoMgMgoEEEEonk^k_l000001Oooool00ol0003oooooo`000002ooooo`05
ogMgMonHV9So0000oiRHV?mgMgL01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001_oo
ool01Ol0003ooooooooooooooooo000000Gooooo00Co0000oooooooooooo00001_ooool01?l0003o
ooooooooool00006ooooo`;o8B4Q2?ooool02OmgMgOo<S8booooooooooook^k^oeEEEOoMgMgoEEEE
onk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0hooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000
ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg05gooooo000`ooooo`03o`000?oooooo
oooo04cooooo00Oo0000ooooooooooooooooomgMgOl0003ogMgM00Oooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@02kooooo00Co0000oooooooooooo00002Oooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01ol0003oooooomgMgOl0
003ogMgMooooool000001Oooool2o`0000?ooooo00Go410@ooooool0003ooooooa0@4004ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000
00Kooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001Ooo
ool01?l0003oooooooooool00006ooooo`04o`000?ooooooooooo`00017ooooo00Oo0000oooooooo
ooooooooomgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@03Wooooo00?oV9RHob4Q8Oo^k^h01Oooool00ooMgMgo0000omgMg@07ooooo`03o`000?oo
oooooooo00;ooooo00Go410@oooooooooooooooooa0@401Mooooo`00<?ooool00ol0003ooooooooo
o`1;ooooo`09ogMgMolb<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000002kooooo00Go0000ooooooooooooooooo`00
0008ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`07o`00
0?o^k^koEEEEomgMgOmEEEGok^k^o`000005ooooo`;o00000oooool01Ol0003oooooo`000?oooooo
000000Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go
0000ooooooooooooooooo`000005ooooo`04o`000?ooooooooooo`0000Kooooo00Co0000oooooooo
oooo00004?ooool02OmgMgOo<S8booooooooooook^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000jooooo`03oiRHV?lQ8B7ok^k^00?o
oooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`00001Mooooo`00<?ooool00ol0003oooooooooo`18ooooo`0=o`000?lQ8B7o0000
oc8b<_o<c<coooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`00000^ooooo`05o`000?ooooooooooooooool000002?oo
ool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000?ooooo00Oo0000oeEEEOo^k^ko
ooooonk^k_mEEEGo000000Gooooo0_l00003ooooo`05o`000?oooooo0000ooooool000001?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooo
oooooooo000000Gooooo00Co0000oooooooooooo00001_ooool01?l0003oooooooooool00007oooo
o`03o`000?oooooooooo00?ooooo00go0000ob4Q8Ol0003o<S8bolc<c?ooooook^k^oeEEEOo^k^ko
ooooonk^k_mEEEGok^k^00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo
000003_ooooo00_oMgMgofIVI_ooooooooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05oooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00001Mooooo`00<?ooool00ol0
003oooooooooo`18ooooo`03o`000?oooooooooo00?ooooo0_o^k^h3ooooo`;ok^k^1Oooool00ol0
003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100;_ooool01Ol0003ooooooooooooo
oooo000000Sooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00003ooooo`03o`00
0?o^k^kooooo00;ooooo00?ok^k^o`000?ooool01?ooool2o`0000?ooooo00Go410@ooooool0003o
oooooa0@4004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006oooo
o`05o`000?ooooooooooooooool000001Oooool01?l0003oooooooooool00006ooooo`04o`000?oo
ooooooooo`0000Oooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_o^k^h3ooooo`;ok^k^
1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100??ooool00ol0003o
ooooooooo`02onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooo
oooooooooa0@401Mooooo`00<?ooool3o`0004Sooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`0Roooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03oooo
o`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`;o00000oooool01OmgMgOoV9RHo`000?nHV9SoMgMg00Cooooo00Co0000oooooooooooooooo
0_l00005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooo
oooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000005ooooo`04o`000?oooooooooo
o`0000Kooooo00Co0000oooooooooooo00001_ooool00ol0003oooooo`000004ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo
0_l0000^ooooo`05o`000?nj^[[ooooooiRHV?l@41003_ooool00ol0003oooooooooo`02ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02?ooool2o`0005?ooooo000`ooooo`03o`000?oooooooooo04So
oooo1?l0000<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08oooo
o`03o`000?oooooooooo02;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00?ooooo00Co0000oeEEEOmVIVKo00000oooool00ol0003oooooooooo`03
ooooo`06o`000?oooooooooooooooomEEEGoIVIV0_l00003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00oooool01_l0003ooooooooooooooooo0000ooooo`;o00001?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?oo
ooooooooooooool000001Oooool01?l0003oooooooooool00006ooooo`04o`000?mEEEGoIVIVo`00
00Kooooo00?o0000ooooool000001?ooool4o`0000cooooo00?oEEEEofIVI_l000001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Oooooo00Co0000oooooooooooo0000;Oooool01OnHV9So410@o`00
0?lQ8B7oc<c<00cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oo
oooo00Co0000oooooooooooo0000D_ooool0033ooooo00?o0000ooooooooool0I_ooool4o`0000?o
oooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo1?l000000ooooooo0000ooooo`02o`0000Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00001_ooool01?l0003oooooooooool0
0006ooooo`03o`000?oooooo000002;ooooo1?l000001Ooooooo0000oooooooooooo000004cooooo
1?l000001Ooooooo0000oooooooooooo000005;ooooo000`ooooo`03o`000?oooooooooo06gooooo
00?o0000ooooooooool04oooool3o`0000_ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`04o`000?ooooooooooooooo`?o00001Oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Gooooo00Co0000
oooooooooooo00001_ooool00ol0003oooooo`00000Wooooo`?o0000D_ooool3o`0005?ooooo000`
ooooo`03o`000?oooooooooo06_ooooo00Co0000oooooooooooo00004oooool2o`000003ooooool0
003ooooo00Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo0_l00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`05o`000?ooooooooooooooool000001Oooool01?l0003oooooooooool00006oooo
o`03o`000?oooooo000000Oooooo0_l0000Oooooo`03o`000?oooooooooo05;ooooo00?o0000oooo
ooooool0D_ooool0033ooooo00?o0000ooooooooool0Joooool4o`0001?ooooo00Go0000oooooooo
ooooooooo`000009ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooool000001oooool2
o`00023ooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`1Aooooo`00<?ooool00ol0
003oooooooooo`22ooooo`05o`000?ooooooooooooooool000002Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooo
oooo000000Gooooo00Co0000oooooooooooo00001Oooool3o`000<Wooooo000`ooooo`03o`000?oo
oooooooo08;ooooo00Go0000ooooooooooooooooo`000009ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool0
00001Oooool01?l0003oooooooooool00005ooooo`03o`000?oooooo000008oooooo00?oMgMgofIV
I_ooool0;Oooool00omVIVKoMgMgooooo`07ooooo`00<?ooool00ol0003oooooooooo`21ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo0000
00Gooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00006ooooo`;o0000QOoo
ool00ooMgMgo410@onk^kP0^ooooo`03onk^k_l@413ogMgM00Oooooo000`ooooo`03o`000?oooooo
oooo077ooooo1Ol0000:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool0
1Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000005ooooo`04o`00
0?ooooooooooo`0000Gooooo00?o0000ooooool000001oooool00ol0003oooooooooo`1Yooooo`;o
00000_ooool2o`0000cooooo00?oEEEEoiRHV?ooool00_l00002ooooo`07o`000?ooooooooooo`00
0?l@413ok^k^oeEEE@02o`000003odA4A?nj^[[ooooo00;ooooo00GoV9RHo`000?l0003oA4A4okZj
^P02ooooo`08onk^k_mEEEGo0000o`000?m4A4Co^[Zjooooool@4105o`0000?ooooo00So410@oc8b
<_l0003o0000oa0@4?nYZJWoQhN7ofIVIPOooooo000`ooooo`03o`000?oooooooooo06oooooo0_l0
0004ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Go
oooo00Go0000ooooooooooooooooo`000004ooooo`04o`000?ooooooooooo`0000Gooooo1?l00006
ooooo`03o`000?oooooooooo063ooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd<ooooo`05o`00
0?ooooooooooooooool000000_ooool02ol0003oooooooooool0003ooooooeEEEOmgMgOoooooonk^
k_mgMgOo410@00?ooooo00Go410@okZj^_o^k^koMgMgoa0@4002ooooo`06oeEEEOmgMgOoooooonk^
k_mgMgOo410@0oooool00ol0003oooooooooo`04ooooo`08o`000?nYZJWooooooooooonj^[[o0000
onk^k_l00007ooooo`00ool0002do`0000oooooo00CogMgMo`000?l@413oc<c<3Oooool01Olb<S;o
oooooooooooooooo000000;ooooo00Ko0000oooooooooooo0000ooooool00008ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`07okZj^_n7
QhOoIVIVofIVI_l@413oooooo`000007ooooo`002_ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo00Sooooo2Ol00008ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool00000
1Oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooooooool2o`0000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oo
ooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo1?l000001?oooooo
0000ooooooooool4o`0000Gooooo0ol00004ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Oooooo00Cok^k^ob4Q
8Ol@413ok^k^3Oooool01Olb<S;ooooooooooooooooo000000;ooooo00Go0000oooooooooooo0000
ooooo`06o`0000?ooooo00?o0000ooooooooool01?ooool6o`0000?ooooo00?o0000ooooooooool0
1?ooool02?lb<S;o8B4QogMgMomgMgOoQhN7onk^k_oooooo00001oooool000[ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01?ooool00ol0003oooooo`000006ooooo`03o`000?oooooooooo00Cooooo00Go0000oooo
ooooooooooooo`000003ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooooooo`;o00001?ooool01Ol0003ooooo
oooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`;o000000?oooooo`00
0?ooool02Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Oooooo00Co8B4QogMg
MomgMgOo<S8b3Oooool01Ol0003ok^k^oooooooooooo000000;oc<c<00_o0000ojVYZOoMgMgo8B4Q
oooooomEEEGoQhN7onk^k_ooooooQhN7oc8b<P03ooooo`03o`000?oooooooooo00Cooooo00KoEEEE
ohN7Qoo^k^koooooohN7Qolb<S83ooooo`03o`000?lb<S;ogMgM00Cooooo00So0000okZj^_oooooo
k^k^ogMgMol0003ok^k^o`0000Oooooo000`ooooo`03o`000?oooooooooo05_ooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool00_l00005
ooooo`;o0000E_ooool00ol0003oooooooooo`0Fooooo`;o00000_ooool2o`0000cooooo00koEEEE
ogMgMooooooo410@o`000?lQ8B7o0000ogMgMol@413o0000ojVYZOooooook^k^oeEEE@;o000000Co
A4A4onk^k_oooooo410@1Ol00003ooooo`06onk^k_mEEEGo0000o`000?m4A4Cok^k^0_ooool2o`00
0004ojVYZOlQ8B7o0000ob4Q8@;ooooo00SoZJVYob4Q8Ol0003o0000oc8b<_l0003oMgMgoeEEE@Oo
oooo000`ooooo`03o`000?oooooooooo07Wooooo0_l00002ooooo`;o00002Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00001Oooool01?l0003o
ooooooooool00006ooooo`03o`000?oooooo000008Wooooo00?ogMgMoa0@4?o^k^h04_ooool00ol0
003oooooooooo`0Iooooo`03onk^k_l@413ogMgM00Oooooo000`ooooo`03o`000?oooooooooo07_o
oooo0ol0000:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`05o`000?ooooooooooooooool000001Oooool01?l0003oooooooooool00005
ooooo`04o`000?ooooooooooo`0000Kooooo0ol0002:ooooo`03ogMgMomVIVKooooo017ooooo00?o
0000ooooooooool06Oooool00omVIVKoMgMgooooo`07ooooo`00<?ooool00ol0003oooooooooo`29
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`05o`000?ooooooooooooooool000001Oooool01?l0003oooooooooool00006ooooo`03o`00
0?oooooo00000<gooooo000`ooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooooooo
o`000005ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooool00000cOooool0033ooooo
00?o0000ooooooooool0ROooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Gooooo00Co0000oooooooo
oooo00001_ooool00ol0003oooooo`00003=ooooo`00<?ooool00ol0003oooooooooo`2:ooooo`05
o`000?ooooooooooooooool000002Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooooooo
ooooool000001Oooool01?l0003oooooooooool00006ooooo`;o0000c_ooool0033ooooo00?o0000
ooooooooool0R_ooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooo
ool01Ol0003ooooooooooooooooo000000Gooooo00Co0000oooooooooooo00001_ooool2o`000<ko
oooo000`ooooo`03o`000?oooooooooo08[ooooo00Co0000oooooooooooo00002_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooool00000eoooool0033o
oooo0ol0002;ooooo`03o`000?oooooo000000[ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000005oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00006
ooooo`03o`000?oooooo00000=Oooooo000`ooooo`03o`000?oooooooooo08_ooooo00?o0000oooo
ool000002_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooool00000eooo
ool0033ooooo00?o0000ooooooooool0Roooool3o`0000_ooooo00Go0000ooooooooooooooooo`00
0008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00006ooooo`03
o`000?oooooo00000=Oooooo000`ooooo`03o`000?oooooooooo09Wooooo00Go0000oooooooooooo
ooooo`000008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000005oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00007
ooooo`;o0000eoooool0033ooooo00?o0000ooooooooool0VOooool01Ol0003ooooooooooooooooo
000000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Gooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Oooooo
0_l0003Gooooo`00<?ooool00ol0003oooooooooo`2Iooooo`05o`000?ooooooooooooooool00000
2?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooool000001oooool2o`000=Oo
oooo000`ooooo`03o`000?oooooooooo09Wooooo00Go0000ooooooooooooooooo`000008ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05
o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00?ooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001_oo
ool00ol0003oooooo`00003Pooooo`00<?ooool00ol0003oooooooooo`2Iooooo`05o`000?oooooo
ooooooooool000002?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003o
oooooooooooooooo000000Kooooo00?o0000ooooool00000h?ooool0033ooooo00?o0000oooooooo
ool0VOooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooo
oooo000000Kooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo00000>3ooooo
000`ooooo`03o`000?oooooooooo09Wooooo00Go0000ooooooooooooooooo`000009ooooo`05o`00
0?ooooooooooooooool000001oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooooooo
ool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000oooo
ooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooo`00
003Pooooo`00<?ooool00ol0003oooooooooo`2Iooooo`05o`000?ooooooooooooooool000002Ooo
ool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05
o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000
ooooool00000h?ooool0033ooooo00?o0000ooooooooool0VOooool01Ol0003ooooooooooooooooo
000000Wooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000006oooo
o`03o`000?oooooo00000>3ooooo000`ooooo`?o0000VOooool01?l0003oooooooooool0000:oooo
o`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go
0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooo`00003Pooooo`00<?ooool00ol0003oooooooooo`2Jooooo`03o`000?oooooo000000[ooooo
00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooo
ooooooooo`000006ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooo
oooo000000Kooooo00Go0000ooooooooooooooooo`000006ooooo`;o0000hOooool0033ooooo00?o
0000ooooooooool0V_ooool00ol0003oooooo`00000:ooooo`05o`000?ooooooooooooooool00000
1oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003o
oooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?oooooo
ooooo`0000Oooooo0_l0003Qooooo`00<?ooool00ol0003oooooooooo`2Jooooo`03o`000?oooooo
000000[ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go
0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003o
oooooooooooooooo000000Kooooo00Co0000oooooooooooo00001oooool2o`000>7ooooo000`oooo
o`03o`000?oooooooooo09[ooooo00?o0000ooooool000002_ooool01Ol0003ooooooooooooooooo
000000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go
0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003o
ooooooooool00007ooooo`;o0000hOooool0033ooooo00?o0000ooooooooool0V_ooool00ol0003o
ooooo`00000:ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04oooo
o`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Kooooo00Go
0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`000>[ooooo000`ooooo`03o`00
0?oooooooooo09[ooooo0_l0000;ooooo`05o`000?ooooooooooooooool000001oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo
000000Oooooo00Co0000oooooooooooo00001_ooool01?l0003oooooooooool0003Zooooo`00<?oo
ool00ol0003oooooooooo`2Kooooo`03o`000?oooooooooo00Wooooo00Go0000oooooooooooooooo
o`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000007ooooo`04
o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00001_ooool01?l0003oooooooooool0
003Zooooo`00<?ooool00ol0003oooooooooo`2Wooooo`05o`000?ooooooooooooooool000002?oo
ool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`04ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool00007oooo
o`04o`000?ooooooooooo`0000Kooooo00Co0000oooooooooooo0000j_ooool0033ooooo00?o0000
ooooooooool0Yoooool01Ol0003ooooooooooooooooo000000Sooooo00Go0000oooooooooooooooo
o`000007ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo0000
00Oooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool00006ooooo`04o`000?oo
ooooooooo`000>[ooooo000`ooooo`03o`000?oooooooooo0:Oooooo00Go0000oooooooooooooooo
o`000008ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo0000
00Oooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo00Co
0000oooooooooooo00001_ooool01?l0003oooooooooool0003Zooooo`00<?ooool00ol0003ooooo
ooooo`2Wooooo`05o`000?ooooooooooooooool000002?ooool01Ol0003ooooooooooooooooo0000
00Oooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001ooo
ool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool0
0000j_ooool0033ooooo0ol0002Wooooo`04o`000?ooooooooooo`0000Wooooo00Go0000oooooooo
ooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooo
oooo000000Oooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool00007ooooo`03
o`000?oooooo00000>[ooooo000`ooooo`03o`000?oooooooooo0:Oooooo00Co0000oooooooooooo
00002Oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007
ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool00007ooooo`04o`00
0?ooooooooooo`0000Oooooo00?o0000ooooool00000j_ooool0033ooooo00?o0000ooooooooool0
Yoooool01?l0003oooooooooool00009ooooo`05o`000?ooooooooooooooool000001oooool01Ol0
003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?oo
ooooooooo`0000Oooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00003Zooooo`00
<?ooool00ol0003oooooooooo`2Xooooo`03o`000?oooooo000000Wooooo00Go0000oooooooooooo
ooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo
000000Oooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool00007ooooo`;o0000
joooool0033ooooo00?o0000ooooooooool0Z?ooool00ol0003oooooo`000009ooooo`05o`000?oo
ooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooooooo
ooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00001ooo
ool2o`000>_ooooo000`ooooo`03o`000?oooooooooo0:Sooooo00?o0000ooooool000002Oooool0
1Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`05o`00
0?ooooooooooooooool000001oooool01?l0003oooooooooool00007ooooo`04o`000?oooooooooo
o`0000Oooooo0_l0003[ooooo`003oooool2onk^kP?ooooo0_o^k^hJooooo`03o`000?oooooooooo
0:Sooooo00?o0000ooooool000002Oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000
ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool01?l0003ooooo
ooooool00007ooooo`04o`000?ooooooooooo`0000Oooooo0_l0003[ooooo`002?ooool5o`0000;o
oooo00Ook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413oooooooooooo^
k^ko<S8bo`000?lb<S;ok^k^2oooool00ol0003oooooooooo`2Xooooo`03o`000?oooooo000000Wo
oooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool0
1Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo00001oooool01?l0003ooooo
ooooool00007ooooo`;o0000joooool000Sooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05
onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool00ol0003oooooooooo`2Xooooo`03o`000?oooooo000000Wooooo00Go0000
ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooo
oooooooooooo000000Oooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool0003d
ooooo`002Oooool00onHV9So8B4Qonk^kP05ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@00_ooooo00?o0000ooooooooool0Z?ooool0
0ol0003oooooo`000009ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooo
oooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`00
00Oooooo00?o0000ooooool00000mOooool000[ooooo00?oV9RHob4Q8Oo^k^h00oooool01Oo^k^ko
EEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo
000000_ooooo00?o0000ooooooooool0Z?ooool00ol0003oooooo`000009ooooo`04o`000?oooooo
ooooo`0000Sooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool0
00001oooool01?l0003oooooooooool00007ooooo`03o`000?oooooo00000?Gooooo000;ooooo`0;
ogMgMomVIVKoooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000002oooool4o`000:Oooooo00?o0000ooooool0
00002Oooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool000001oooool0
1Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo00001oooool00ol0003ooooo
o`00003eooooo`003?ooool00ol0003oooooooooo`02onk^kP?ooooo0_o^k^h5ooooo`03o`000?oo
oooooooo00;ooooo00Go410@oooooooooooooooooa0@400;ooooo`03o`000?oooooooooo0:Sooooo
00?o0000ooooool000002Oooool01?l0003oooooooooool00008ooooo`05o`000?oooooooooooooo
ool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo00001ooo
ool00ol0003oooooo`00003eooooo`002?ooool01Ol0003o^[ZjoooooonHV9So410@00kooooo00?o
0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?o0000ooooooooool0
Z?ooool00ol0003oooooo`000009ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooo
ooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool0
0007ooooo`03o`000?oooooo00000?Gooooo0008ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03?oo
ool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool2o`0000Kooooo
00?o0000ooooooooool0Z?ooool00ol0003oooooo`00000:ooooo`03o`000?oooooo000000Sooooo
00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool01?l0
003oooooooooool00007ooooo`03o`000?oooooo00000?Gooooo000Wooooo`04o`000?oooooooooo
o`0000Gooooo00?o0000ooooooooool0Z?ooool2o`0000_ooooo00?o0000ooooool000002?ooool0
1Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04o`00
0?ooooooooooo`0000Oooooo00?o0000ooooool00000mOooool002Oooooo00Co0000oooooooooooo
00001Oooool00ol0003oooooooooo`2Xooooo`;o00002oooool00ol0003oooooo`000008ooooo`05
o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000
oooooooooooo00002?ooool2o`000?Gooooo000Wooooo`?o00001_ooool00ol0003oooooooooo`2Y
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooool000002?ooool01Ol0003ooooooooooooo
oooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000So
oooo0_l0003eooooo`00:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;Gooooo
00?o0000ooooool000002Oooool01?l0003oooooooooool00007ooooo`05o`000?oooooooooooooo
ool000001oooool01?l0003oooooooooool00008ooooo`;o0000mOooool002Wooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`2eooooo`03o`000?oooooo000000Wooooo00Co0000oooo
oooooooo00002?ooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Sooooo
0_l0003eooooo`00<?ooool00ol0003oooooooooo`2eooooo`03o`000?oooooo000000Wooooo00Co
0000oooooooooooo00002?ooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`00
00Sooooo0_l0003eooooo`00<?ooool00ol0003oooooooooo`2eooooo`03o`000?oooooo000000Wo
oooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00007ooooo`04o`000?oooooo
ooooo`0000Sooooo0_l0003eooooo`00<?ooool00ol0003oooooooooo`2eooooo`03o`000?oooooo
000000Wooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00007ooooo`04o`00
0?ooooooooooo`0000Sooooo0_l0003eooooo`00<?ooool3o`000;Gooooo00?o0000ooooool00000
2Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooo
oooooooo00002?ooool2o`000?Gooooo000`ooooo`03o`000?oooooooooo0;Gooooo00?o0000oooo
ool000002Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Oooooo00Co
0000oooooooooooo00002?ooool00ol0003oooooooooo`3dooooo`00<?ooool00ol0003ooooooooo
o`2eooooo`03o`000?oooooo000000Wooooo00Co0000oooooooooooo00002?ooool01?l0003ooooo
ooooool00007ooooo`04o`000?ooooooooooo`000?oooooo000`ooooo`03o`000?oooooooooo0;Go
oooo00?o0000ooooool000002Oooool01?l0003oooooooooool00008ooooo`04o`000?oooooooooo
o`0000Oooooo00Co0000oooooooooooo0000ooooool0033ooooo00?o0000ooooooooool0]Oooool0
0ol0003oooooo`000009ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000
1oooool00ol0003oooooo`00003oooooo`7ooooo000`ooooo`03o`000?oooooooooo0;Gooooo00?o
0000ooooool000002Oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo000000Wooooo
0_l0003oooooo`7ooooo000`ooooo`03o`000?oooooooooo0;Gooooo00?o0000ooooool000002Ooo
ool01?l0003oooooooooool00008ooooo`03o`000?oooooo000000Wooooo0_l0003oooooo`7ooooo
000`ooooo`03o`000?oooooooooo0;Gooooo00?o0000ooooool000002Oooool01?l0003ooooooooo
ool00008ooooo`03o`000?oooooo000000Wooooo0_l0003oooooo`7ooooo000`ooooo`03o`000?oo
oooooooo0;Gooooo00?o0000ooooool000002Oooool01?l0003oooooooooool00008ooooo`03o`00
0?oooooo000000Wooooo0_l0003oooooo`7ooooo000`ooooo`03o`000?oooooooooo0;Gooooo00?o
0000ooooool000002Oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo000000Wooooo
0_l0003oooooo`7ooooo000`ooooo`03o`000?oooooooooo0;Gooooo00?o0000ooooool000002Ooo
ool01?l0003oooooooooool00008ooooo`03o`000?oooooo000000Wooooo0_l0003oooooo`7ooooo
000`ooooo`03o`000?oooooooooo0;Gooooo00?o0000ooooool000002Oooool01?l0003ooooooooo
ool00008ooooo`03o`000?oooooo000000Wooooo0_l0003oooooo`7ooooo000`ooooo`?o0000]Ooo
ool2o`0000[ooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`000009ooooo`;o0000
ooooool1ooooo`00<?ooool00ol0003oooooooooo`2fooooo`03o`000?oooooooooo00Sooooo00Co
0000oooooooooooo00002?ooool00ol0003oooooo`000009ooooo`;o0000ooooool1ooooo`00<?oo
ool00ol0003oooooooooo`2fooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooo0000
2?ooool00ol0003oooooo`000009ooooo`;o0000ooooool1ooooo`00<?ooool00ol0003ooooooooo
o`31ooooo`03o`000?oooooo000000Wooooo00?o0000ooooool000002Oooool2o`000?oooooo0Ooo
ool0033ooooo00?o0000ooooooooool0`Oooool00ol0003oooooo`000009ooooo`03o`000?oooooo
000000Wooooo0_l0003oooooo`7ooooo000`ooooo`03o`000?oooooooooo0<7ooooo00?o0000oooo
ool000002Oooool00ol0003oooooo`00003oooooo`cooooo000`ooooo`03o`000?oooooooooo0<7o
oooo00?o0000ooooool000002Oooool00ol0003oooooo`00003oooooo`cooooo000`ooooo`03o`00
0?oooooooooo0<;ooooo0_l00009ooooo`03o`000?oooooo00000?oooooo3?ooool0033ooooo00?o
0000ooooooooool0`_ooool2o`0000Wooooo00?o0000ooooool00000ooooool<ooooo`00<?ooool0
0ol0003oooooooooo`32ooooo`;o00002_ooool2o`000?oooooo3?ooool0033ooooo00?o0000oooo
ooooool0`_ooool2o`0000[ooooo0_l0003oooooo`cooooo000`ooooo`03o`000?oooooooooo0<;o
oooo0_l0000:ooooo`;o0000ooooool<ooooo`00<?ooool3o`000<;ooooo0_l0000:ooooo`;o0000
ooooool<ooooo`00<?ooool00ol0003oooooooooo`32ooooo`;o00002_ooool00ol0003ooooooooo
o`3oooooo`_ooooo000`ooooo`03o`000?oooooooooo0<;ooooo0_l0000:ooooo`03o`000?oooooo
oooo0?oooooo2oooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003o
ooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool000oooooo0_o^
k^h3ooooo`;ok^k^6_ooool00ol0003oooooooooo`3oooooomcooooo000:ooooo`;o000000[o410@
ooooooooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^0oooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^h;ooooo`03o`000?oooooooooo0?oooooog?ooool000_ooooo00?o
0000ooooooooool00_ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?o0000ooooooooool0oooooooLooooo`00
2?ooool5o`0000Cooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@
4?ooooooooooooooool@41002oooool00ol0003oooooooooo`3oooooomcooooo0008ooooo`04odA4
A?oMgMgoooooo`0000Cooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`00000;ooooo`03o`000?oooooooooo0?oooooog?ooool0
00Sooooo00CogMgMoeEEEOoooooo00000oooool01oo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h0
1Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000002oooool4o`000?oo
oooofoooool000Wooooo00?oMgMgolc<c?l000000oooool2onk^kP?ooooo0_o^k^h5ooooo`03o`00
0?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400;ooooo`03o`000?oooooooooo0?oo
oooog?ooool000Wooooo00?ok^k^odA4A?l000003oooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool00ol0003oooooooooo`3oooooomcooooo000:ooooo`03ogMg
Mol0003ooooo00cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?o
oooo0_l00006ooooo`03o`000?oooooooooo0?oooooog?ooool002Oooooo00Co0000oooooooooooo
00001Oooool00ol0003oooooooooo`3oooooomcooooo000Wooooo`04o`000?ooooooooooo`0000Go
oooo00?o0000ooooooooool0oooooooLooooo`009oooool3o`0000Kooooo00?o0000ooooooooool0
oooooooLooooo`00:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooog?oo
ool002Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooomcooooo000`oooo
o`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00
<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`?o0000oooooooLooooo`00<?ooool0
0ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033o
oooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo
000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooL
ooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oo
oooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooooooo
o`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo0ol0003ooooo
omcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0
oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooo
oooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003o
ooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o
0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`oooo
o`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00
<?ooool3o`000?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool0
0ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033o
oooo00?o0000ooooooooool0oooooooLooooo`00oooooooooooooa3ooooo003ooooooooooooo4?oo
ool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooo
ooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00:3ooooo0_l00004oooo
o`03okZj^_lb<S;ooooo00Cooooo0_l00006ooooo`03o`000?nj^[[ooooo0?ooooooEoooool00:3o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Co
oooo0_lb<S;ooooooeSooooo002=ooooo`?o00000_ooool01_lb<S;o410@ooooooooooook^k^oeEE
E@;o000000?oA4A4okZj^_ooool00oooool00ol0003oooooooooo`02ooooo`05oiRHV?l@413o0000
o`000?nYZJT01?ooool00ol0003oooooooooo`04ooooo`03ohN7Qol0003o^[Zj00cooooo00GoV9RH
o`000?l0003oA4A4okZj^P09ooooo`04oa0@4?l0003oA4A4olc<c0Kooooo0_lQ8B46ooooo`;o0000
00Oo410@ooooooo<c<cok^k^ooooooo^k^koc<c<00Cooooo1?l000002?l@413oooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^4oooool01_l@413o<S8bo`000?l0003o410@ojVYZ@;ooooo00Kok^k^oeEE
EOl0003o0000odA4A?nj^[X3ooooo`05ofIVI_l0003o0000odA4A?o<c<`0j?ooool008kooooo00Go
0000ooooooooooooc<c<oa0@4003ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo410@1?ooool00ol0
003oooooooooo`02ooooo`06o`000?nYZJWoEEEEoiRHV?mEEEGo^[Zj0oooool00ol0003ooooooooo
o`04ooooo`03olc<c?l0003o410@00cooooo00Ko410@okZj^_o^k^koMgMgoa0@4?ooool6o`0000Co
oooo00?oV9RHoa0@4?oMgMd01Oooool2ob4Q8@Oooooo00So0000ooooooooooook^k^oeEEEOoMgMgo
EEEEonk^kPKooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01?ooooo
00Ko0000ojVYZOoooooooooookZj^_l00002ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo410@0_oo
ool01_mVIVKoMgMgooooooooooooQhN7oa0@4>Sooooo002>ooooo`05o`000?oooooooooooeEEEOn7
QhL00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00Ko<S8bonk^k_nH
V9SoEEEEomgMgOl@4103ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool03_ooool0
0on7QhOoEEEEooooo`0:ooooo`Go00000_ooool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooo
oooo00;ooooo00Go410@oooooooooooooooooa0@400Dooooo`05okZj^_n7QhOoIVIVofIVI_l@4100
0_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0>_ooooo002>ooooo`05o`000?oo
oooogMgMo`000?o^k^h00oooool6o`0000Cooooo00?o0000ooooooooool00_ooool01onj^[[oA4A4
olc<c?lQ8B7ooooooa0@4?o<c<`00_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
00?ooooo1_l00002ooooo`05olc<c?lQ8B7o0000oeEEEOl000002oooool01?m4A4CogMgMooooool0
0002ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000004oooool01_lb<S;o8B4QogMgMomgMgOoQhN7onk^kP;ooooo1_l00002
ooooo`03o`000?oooooooooo0>_ooooo002>ooooo`?o000000?o410@oiRHV?ooool00_ooool01_mE
EEGoQhN7onk^k_ooooooQhN7oc8b<PCooooo00?o0000ooooooooool00_ooool01oo^k^ko0000oooo
ool0003oooooofIVI_n7QhL00_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00_o
oooo00Go8B4QohN7QoooooooV9RHo`00000;ooooo`04omgMgOmEEEGoooooo`0000;ooooo00Goc<c<
onk^k_ooooook^k^olc<c006ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Cooooo`06o`000?nj^[[oooooonk^k_mgMgOo00000_ooool01_mEEEGoQhN7onk^k_oooooo
QhN7oc8b<P;ooooo00KoIVIVogMgMoooooooooooohN7Qol0003Xooooo`00S_ooool01Ol0003ooooo
ooooooo<c<co000000?ooooo00Kok^k^oeEEEOl0003o0000odA4A?o^k^h4ooooo`03o`000?oooooo
oooo00;ooooo00CoIVIVoiRHV?oooooo<S8b0_nj^[X01?l0003oooooooooool0000Cooooo`03oa0@
4?l0003o000000?o00002_ooool01Ol0003ooooooooooooooooo000000cooooo00?oMgMgolc<c?l0
00003Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41001oooool3o`00
00;ooooo0ol00004ooooo`06ojVYZOlQ8B7o0000o`000?lb<S;o00000_ooool01_o^k^koEEEEo`00
0?l0003oA4A4onk^kP;ooooo00Kok^k^ofIVI_l0003o0000odA4A?l0003Xooooo`00S_ooool01Ol0
003oooooooooooo<c<co000000gooooo00?o0000ooooooooool01Oooool00omVIVKoQhN7ooooo`03
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02oooool01OlQ8B7oV9RHoooooomg
MgOoEEEE00cooooo00?ok^k^odA4A?l000003Oooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo
0_ooool008gooooo1?l000000ol@413oZJVYooooo`0<ooooo`;o00001_ooool00onYZJWoA4A4oooo
o`02ooooo`;o00005Oooool00ol0003oooooooooo`0;ooooo`05olc<c?l@413o0000oc8b<_o^k^h0
3Oooool00omgMgOo0000ooooo`0:ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP02ooooo`Co00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oo
oooo0_ooool00?oooooo1_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo
0_ooool00?oooooo1_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo0_oo
ool00?oooooo1Oooool2o`0000?ooooo0_l0003oooooo`Cooooo003ooooooooooooo4?ooool00?oo
ooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@
ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooo
oooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3o
oooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooo
oooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?oo
ool00?ooooooooooool@ooooo`00\
\>"],
  ImageRangeCache->{{{0, 525.688}, {324.5, 0}} -> {-2.58312*^-7, -6.34248*^6, \
6.65005*^-9, 53093.5}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0.309017 5.42214e-08 [
[.32684 .29652 -16.5 -12.5 ]
[.32684 .29652 16.5 0 ]
[.54329 .29652 -16.5 -12.5 ]
[.54329 .29652 16.5 0 ]
[.75974 .29652 -22.5 -12.5 ]
[.75974 .29652 22.5 0 ]
[.97619 .29652 -16.5 -12.5 ]
[.97619 .29652 16.5 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 64 6 ]
[.09789 .09213 -34.5 -6.25 ]
[.09789 .09213 0 6.25 ]
[.09789 .20057 -34.5 -6.25 ]
[.09789 .20057 0 6.25 ]
[.09789 .41746 -28.5 -6.25 ]
[.09789 .41746 0 6.25 ]
[.09789 .5259 -28.5 -6.25 ]
[.09789 .5259 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -62.8125 0 ]
[.5 .63053 62.8125 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 .30902 m
.32684 .31527 L
s
gsave
.32684 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 .30902 m
.54329 .31527 L
s
gsave
.54329 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 .30902 m
.75974 .31527 L
s
gsave
.75974 .29652 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 .30902 m
.15368 .31277 L
s
.19697 .30902 m
.19697 .31277 L
s
.24026 .30902 m
.24026 .31277 L
s
.28355 .30902 m
.28355 .31277 L
s
.37013 .30902 m
.37013 .31277 L
s
.41342 .30902 m
.41342 .31277 L
s
.45671 .30902 m
.45671 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.58658 .30902 m
.58658 .31277 L
s
.62987 .30902 m
.62987 .31277 L
s
.67316 .30902 m
.67316 .31277 L
s
.71645 .30902 m
.71645 .31277 L
s
.80303 .30902 m
.80303 .31277 L
s
.84632 .30902 m
.84632 .31277 L
s
.88961 .30902 m
.88961 .31277 L
s
.9329 .30902 m
.9329 .31277 L
s
.0671 .30902 m
.0671 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09213 m
.11664 .09213 L
s
gsave
.09789 .09213 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .20057 m
.11664 .20057 L
s
gsave
.09789 .20057 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .41746 m
.11664 .41746 L
s
gsave
.09789 .41746 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .5259 m
.11664 .5259 L
s
gsave
.09789 .5259 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.11039 .11924 m
.11414 .11924 L
s
.11039 .14635 m
.11414 .14635 L
s
.11039 .17346 m
.11414 .17346 L
s
.11039 .22768 m
.11414 .22768 L
s
.11039 .2548 m
.11414 .2548 L
s
.11039 .28191 m
.11414 .28191 L
s
.11039 .33613 m
.11414 .33613 L
s
.11039 .36324 m
.11414 .36324 L
s
.11039 .39035 m
.11414 .39035 L
s
.11039 .44457 m
.11414 .44457 L
s
.11039 .47168 m
.11414 .47168 L
s
.11039 .49879 m
.11414 .49879 L
s
.11039 .06502 m
.11414 .06502 L
s
.11039 .03791 m
.11414 .03791 L
s
.11039 .0108 m
.11414 .0108 L
s
.11039 .55301 m
.11414 .55301 L
s
.11039 .58012 m
.11414 .58012 L
s
.11039 .60723 m
.11414 .60723 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -123.812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.812 moveto
(@) show
81.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.812 moveto
(D) show
93.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(9.6) show
135.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
141.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
153.000 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
157.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
166.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
184.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02691 .30902 L
.03029 .30902 L
.03347 .30902 L
.03652 .30902 L
.03978 .30902 L
.04291 .30902 L
.04623 .30902 L
.0479 .30902 L
.04944 .30902 L
.05093 .30902 L
.05169 .30902 L
.05212 .30902 L
.05233 .30902 L
.05252 .30902 L
.05273 .30902 L
.05292 .30902 L
.05302 .30902 L
.05313 .30902 L
.05319 .30902 L
.05324 .30902 L
.0533 .30902 L
.05335 .30902 L
.05345 .30902 L
.05355 .30902 L
.05364 .30902 L
.05373 .30902 L
.05383 .30902 L
.05394 .30902 L
.05415 .30902 L
.05432 .30902 L
.05452 .30902 L
.05492 .30902 L
.05529 .30902 L
.05563 .30902 L
.05642 .30902 L
.05682 .30902 L
.05725 .30902 L
.05874 .30902 L
.05956 .30902 L
.06031 .30902 L
.06119 .30902 L
.06199 .30902 L
.06353 .30902 L
.0652 .30902 L
.06671 .30902 L
.06837 .30902 L
.06993 .30902 L
.0716 .30902 L
.0733 .30902 L
Mistroke
.07492 .30902 L
.07799 .30902 L
.07957 .30902 L
.08125 .30902 L
.08286 .30902 L
.0846 .30902 L
.08782 .30902 L
.08942 .30902 L
.09111 .30902 L
.09416 .30902 L
.09741 .30902 L
.10054 .30902 L
.10386 .30902 L
.10707 .30902 L
.11015 .30902 L
.11342 .30902 L
.11658 .30902 L
.11961 .30902 L
.12285 .30902 L
.12596 .30902 L
.12926 .30902 L
.13245 .30902 L
.13405 .30902 L
.13551 .30902 L
.13627 .30902 L
.13709 .30902 L
.13754 .30902 L
.13774 .30902 L
.13795 .30902 L
.13814 .30902 L
.13835 .30902 L
.13846 .30902 L
.13857 .30902 L
.13867 .30902 L
.13877 .30902 L
.13886 .30902 L
.13896 .30902 L
.13905 .30902 L
.13914 .30902 L
.13923 .30902 L
.13933 .30902 L
.13954 .30902 L
.13975 .30902 L
.13997 .30902 L
.14037 .30902 L
.14076 .30902 L
.14114 .30902 L
.14184 .30902 L
.14262 .30902 L
.14345 .30902 L
Mistroke
.14493 .30902 L
.14568 .30902 L
.1465 .30902 L
.14797 .30902 L
.14966 .30902 L
.15128 .30902 L
.15434 .30902 L
.15593 .30902 L
.15761 .30902 L
.16095 .30902 L
.16417 .30902 L
.16726 .30902 L
.17055 .30902 L
.17373 .30902 L
.17678 .30902 L
.18002 .30902 L
.18315 .30902 L
.18396 .30902 L
.18485 .30902 L
.18562 .30902 L
.18603 .30902 L
.18647 .30902 L
.1869 .30902 L
.18708 .30902 L
.18729 .30902 L
.18747 .30902 L
.18766 .30902 L
.18777 .30902 L
.18787 .30902 L
.18796 .30902 L
.18806 .30902 L
.18815 .30902 L
.18821 .30902 L
.18826 .30902 L
.18837 .30902 L
.18842 .30902 L
.18848 .30902 L
.18857 .30902 L
.18868 .30902 L
.18887 .30902 L
.18909 .30902 L
.18932 .30902 L
.18974 .30902 L
.19017 .30902 L
.19057 .30902 L
.19147 .30902 L
.19225 .30902 L
.19309 .30902 L
.19467 .30902 L
.19614 .30902 L
Mistroke
.19778 .30902 L
.19927 .30902 L
.20093 .30902 L
.20247 .30902 L
.20556 .30902 L
.20871 .30902 L
.21175 .30902 L
.21498 .30902 L
.21809 .30902 L
.2214 .30902 L
.22305 .30902 L
.22386 .30902 L
.22459 .30902 L
.22495 .30902 L
.22535 .30902 L
.22569 .30902 L
.22607 .30902 L
.22628 .30902 L
.22647 .30902 L
.22658 .30902 L
.22668 .30902 L
.22673 .30902 L
.22679 .30902 L
.22684 .30902 L
.22689 .30902 L
.22698 .30902 L
.22707 .30902 L
.22716 .30902 L
.22726 .30902 L
.22736 .30902 L
.22747 .30902 L
.22765 .30902 L
.22786 .30902 L
.22805 .30902 L
.22842 .30902 L
.22881 .30902 L
.22924 .30902 L
.23 .30902 L
.23071 .30902 L
.23222 .30902 L
.23307 .30902 L
.23387 .30902 L
.2355 .30902 L
.23699 .30902 L
.24018 .30902 L
.24325 .30902 L
.24651 .30902 L
.24966 .30902 L
.253 .30902 L
.25467 .30903 L
Mistroke
.25622 .30903 L
.257 .30903 L
.25772 .30903 L
.25848 .30903 L
.25888 .30903 L
.25909 .30903 L
.25931 .30903 L
.25952 .30903 L
.25963 .30903 L
.25974 .30903 L
.25984 .30903 L
.25993 .30903 L
.26003 .30903 L
.26013 .30903 L
.26019 .30903 L
.26024 .30903 L
.2603 .30903 L
.26035 .30903 L
.26045 .30903 L
.26056 .30903 L
.26067 .30903 L
.2608 .30903 L
.26102 .30903 L
.26142 .30903 L
.26179 .30903 L
.2622 .30903 L
.26264 .30903 L
.26345 .30903 L
.26434 .30903 L
.26595 .30902 L
.26754 .30902 L
.26922 .30902 L
.27225 .30901 L
.27547 .309 L
.27858 .30899 L
.28187 .30898 L
.28352 .30897 L
.28505 .30897 L
.28653 .30896 L
.28735 .30896 L
.28771 .30896 L
.28811 .30896 L
.28849 .30896 L
.28871 .30896 L
.28881 .30896 L
.28891 .30896 L
.28899 .30896 L
.28909 .30896 L
.28918 .30896 L
.28926 .30896 L
Mistroke
.28936 .30896 L
.28945 .30896 L
.28955 .30896 L
.28964 .30896 L
.28974 .30896 L
.28985 .30896 L
.28996 .30896 L
.29006 .30896 L
.29025 .30896 L
.29044 .30896 L
.2909 .30896 L
.29131 .30896 L
.29211 .30896 L
.29284 .30897 L
.29365 .30897 L
.29451 .30897 L
.29607 .30898 L
.29754 .309 L
.30065 .30903 L
.30395 .30909 L
.30713 .30914 L
.31019 .30919 L
.3119 .30922 L
.31345 .30924 L
.31422 .30924 L
.31466 .30924 L
.31487 .30925 L
.31506 .30925 L
.31524 .30925 L
.31541 .30925 L
.3156 .30925 L
.3157 .30925 L
.3158 .30925 L
.31589 .30925 L
.31599 .30925 L
.31609 .30925 L
.31617 .30925 L
.31627 .30925 L
.31633 .30925 L
.31638 .30925 L
.31658 .30925 L
.31668 .30925 L
.31678 .30925 L
.31696 .30925 L
.31737 .30924 L
.31772 .30924 L
.3181 .30924 L
.31896 .30923 L
.31976 .30922 L
.32126 .30919 L
Mistroke
.32291 .30914 L
.32447 .30907 L
.32614 .309 L
.32945 .3088 L
.33264 .3086 L
.3357 .30842 L
.33728 .30835 L
.33816 .30831 L
.33896 .30829 L
.33935 .30829 L
.33957 .30828 L
.33976 .30828 L
.33995 .30828 L
.34012 .30828 L
.34021 .30828 L
.3403 .30828 L
.3404 .30828 L
.3405 .30828 L
.34061 .30828 L
.3407 .30828 L
.34081 .30828 L
.34087 .30828 L
.34092 .30828 L
.34103 .30828 L
.34114 .30828 L
.34137 .30828 L
.34157 .30828 L
.34179 .30829 L
.34218 .3083 L
.3426 .30831 L
.343 .30832 L
.34389 .30836 L
.34467 .30841 L
.3455 .30847 L
.34707 .30863 L
.34854 .30881 L
.35166 .3093 L
.35497 .30993 L
.35662 .31024 L
.35816 .31051 L
.35974 .31074 L
.36051 .31083 L
.36123 .3109 L
.3616 .31093 L
.36202 .31096 L
.36244 .31098 L
.36266 .31099 L
.36288 .31099 L
.36297 .31099 L
.36307 .311 L
Mistroke
.36316 .311 L
.36325 .311 L
.36333 .311 L
.36342 .311 L
.36351 .311 L
.3636 .311 L
.36369 .311 L
.36379 .311 L
.36388 .311 L
.36397 .31099 L
.36418 .31099 L
.36437 .31098 L
.36478 .31096 L
.36521 .31093 L
.36563 .31089 L
.36601 .31085 L
.36674 .31075 L
.36751 .31062 L
.36908 .31025 L
.37055 .30979 L
.37367 .30852 L
.37698 .30693 L
.37864 .30614 L
.38018 .30548 L
.38166 .30497 L
.3825 .30474 L
.38325 .30459 L
.38364 .30453 L
.38386 .3045 L
.38406 .30448 L
.38424 .30447 L
.38441 .30446 L
.3845 .30445 L
.3846 .30445 L
.3847 .30444 L
.3848 .30444 L
.3849 .30444 L
.385 .30444 L
.38505 .30444 L
.38511 .30444 L
.38516 .30444 L
.38522 .30444 L
.38533 .30445 L
.38543 .30445 L
.38567 .30447 L
.38587 .30449 L
.38606 .30451 L
.38647 .30457 L
.38686 .30465 L
.38728 .30475 L
Mistroke
.38802 .30498 L
.38881 .30531 L
.38969 .30576 L
.39125 .30679 L
.39293 .30819 L
.39625 .31159 L
.39945 .315 L
.40091 .31634 L
.40174 .31699 L
.40252 .3175 L
.40329 .3179 L
.40372 .31807 L
.40411 .31819 L
.4043 .31824 L
.4045 .31829 L
.40462 .31831 L
.40473 .31832 L
.40483 .31833 L
.40493 .31835 L
.40499 .31835 L
.40504 .31835 L
.40515 .31836 L
.4052 .31836 L
.40527 .31836 L
.40532 .31836 L
.40538 .31836 L
.40548 .31836 L
.40554 .31836 L
.40559 .31835 L
.40569 .31834 L
.4058 .31833 L
.40601 .3183 L
.40623 .31826 L
.40663 .31815 L
.40705 .31798 L
.40752 .31774 L
.40836 .31717 L
.40914 .31647 L
.41078 .31449 L
.41227 .31213 L
.41547 .30575 L
.41855 .29915 L
.42011 .2962 L
.42093 .29486 L
.42183 .29365 L
.42224 .29318 L
.42268 .29276 L
.42308 .29243 L
.42345 .29219 L
.42381 .29202 L
Mistroke
.42401 .29195 L
.42418 .2919 L
.42429 .29187 L
.42438 .29186 L
.42449 .29185 L
.42454 .29184 L
.42459 .29184 L
.42469 .29184 L
.42479 .29184 L
.42489 .29185 L
.42498 .29186 L
.42508 .29188 L
.42516 .2919 L
.42537 .29196 L
.42556 .29203 L
.42578 .29214 L
.42616 .29239 L
.42651 .29268 L
.42732 .29361 L
.42818 .29496 L
.42976 .29842 L
.43123 .30267 L
.43436 .31404 L
.43769 .3268 L
.43936 .3321 L
.44009 .33399 L
.4409 .33569 L
.44127 .33632 L
.44167 .33689 L
.44205 .33731 L
.4424 .33759 L
.4426 .33771 L
.44269 .33775 L
.44278 .33779 L
.44284 .3378 L
.44289 .33782 L
.44299 .33784 L
.44305 .33785 L
.4431 .33785 L
.44321 .33786 L
.4433 .33785 L
.4434 .33783 L
.44349 .33781 L
.44358 .33779 L
.44379 .33769 L
.44398 .33757 L
.44435 .33724 L
.44476 .33673 L
.44518 .33604 L
.44558 .33524 L
Mistroke
.44629 .33344 L
.44706 .33098 L
.44867 .32422 L
.45036 .31508 L
.45342 .29561 L
.45513 .28476 L
.45668 .27607 L
.45746 .27242 L
.45829 .26911 L
.45868 .26785 L
.45909 .26672 L
.45946 .26585 L
.45982 .2652 L
.46001 .26493 L
.46021 .26468 L
.4604 .26451 L
.46048 .26445 L
.46057 .2644 L
.46063 .26437 L
.46068 .26435 L
.46078 .26432 L
.46087 .26431 L
.46097 .2643 L
.46107 .26432 L
.46117 .26434 L
.46128 .26439 L
.46139 .26445 L
.46158 .26461 L
.46178 .26484 L
.46216 .26542 L
.46252 .26619 L
.46286 .26708 L
.46363 .2698 L
.46436 .27315 L
.46602 .28356 L
.46913 .31106 L
.47243 .34382 L
.47409 .35776 L
.47489 .36329 L
.47562 .36741 L
.47599 .36912 L
.47638 .37068 L
.47673 .37177 L
.4771 .37269 L
.47731 .37307 L
.4775 .37333 L
.47761 .37345 L
.47771 .37353 L
.47776 .37356 L
.47782 .37359 L
Mistroke
.47788 .37361 L
.47793 .37363 L
.47802 .37364 L
.4781 .37363 L
.47819 .3736 L
.47829 .37355 L
.47839 .37348 L
.4785 .37338 L
.47868 .37313 L
.47889 .37277 L
.47909 .37233 L
.47945 .37128 L
.47984 .36979 L
.48027 .36778 L
.48103 .3631 L
.48174 .35763 L
.48325 .34264 L
.4849 .32187 L
.48814 .27553 L
.48963 .2555 L
.49126 .2375 L
.49214 .23016 L
.49257 .22732 L
.49295 .2252 L
.49336 .22347 L
.49354 .22284 L
.49373 .22229 L
.49394 .22184 L
.49404 .22168 L
.49413 .22155 L
.49419 .22148 L
.49424 .22144 L
.49434 .22136 L
.4944 .22134 L
.49446 .22132 L
.49451 .22132 L
.49457 .22132 L
.49466 .22136 L
.49476 .22142 L
.49485 .22151 L
.49494 .22163 L
.49515 .222 L
.49534 .22247 L
.49569 .22366 L
.49607 .22538 L
.49651 .22805 L
.49693 .23117 L
.49772 .23853 L
.49933 .25927 L
.50081 .28392 L
Mistroke
.50398 .34515 L
.50557 .37452 L
.50702 .39695 L
.50782 .40671 L
.50858 .41387 L
.509 .41685 L
.50939 .41897 L
.50959 .41982 L
.50981 .42057 L
.50992 .42086 L
.51004 .42111 L
.5101 .4212 L
.51016 .42129 L
.51026 .4214 L
.51036 .42147 L
.51042 .42148 L
.51047 .42148 L
.51056 .42146 L
.51066 .42139 L
.51075 .42128 L
.51084 .42115 L
.51103 .42074 L
.51123 .42011 L
.51142 .41936 L
.51184 .41708 L
.51221 .4145 L
.5126 .41101 L
.51332 .40291 L
.5149 .37777 L
.51658 .34195 L
.51992 .25887 L
.52159 .22069 L
.52233 .20645 L
.52313 .19321 L
.52391 .1832 L
.52429 .17946 L
.52464 .17659 L
.52483 .17532 L
.52504 .17416 L
.52521 .17338 L
.52541 .17272 L
.52551 .17245 L
.52561 .17225 L
.52572 .1721 L
.52578 .17205 L
.52583 .17201 L
.52593 .172 L
.52603 .17204 L
.52613 .17215 L
.52623 .1723 L
Mistroke
.52633 .17253 L
.52644 .17283 L
.52663 .17355 L
.52684 .17457 L
.52707 .17599 L
.52749 .17931 L
.52787 .1833 L
.52859 .19297 L
.52936 .20644 L
.53106 .24575 L
.53268 .29198 L
.53575 .38527 L
.53663 .40903 L
.53746 .42862 L
.53827 .44447 L
.53862 .45028 L
.53901 .45578 L
.53937 .45997 L
.53975 .46355 L
.53996 .46511 L
.54015 .46626 L
.54034 .46717 L
.54053 .46778 L
.54062 .46801 L
.54072 .46819 L
.54077 .46825 L
.54083 .46829 L
.54093 .46831 L
.54103 .46826 L
.54113 .46814 L
.54121 .46798 L
.54131 .46774 L
.54142 .46738 L
.54152 .46697 L
.54175 .46578 L
.54196 .46435 L
.54216 .46271 L
.54294 .45354 L
.54334 .44733 L
.54377 .43932 L
.54525 .40345 L
.54849 .29462 L
.54999 .24139 L
.55161 .19019 L
.5525 .16762 L
.55332 .15108 L
.55372 .14467 L
.5541 .13976 L
.55449 .13583 L
.5547 .13426 L
Mistroke
.55482 .13353 L
.55493 .13297 L
.55502 .13256 L
.55512 .13221 L
.55523 .13192 L
.55533 .13173 L
.55542 .13163 L
.55552 .1316 L
.55561 .13165 L
.5557 .13176 L
.55575 .13187 L
.55581 .13199 L
.55591 .13229 L
.55602 .13271 L
.55613 .13328 L
.55634 .13458 L
.55654 .13613 L
.55697 .14065 L
.55736 .14605 L
.55823 .16251 L
.55904 .18264 L
.55978 .20483 L
.56145 .26482 L
.56462 .39091 L
.56622 .44461 L
.56691 .46335 L
.56767 .47964 L
.56809 .48664 L
.56848 .49176 L
.56885 .4954 L
.56903 .49676 L
.56924 .49788 L
.56934 .4983 L
.5694 .49849 L
.56946 .49864 L
.56955 .49883 L
.56965 .49894 L
.56971 .49896 L
.56977 .49894 L
.56987 .49884 L
.56993 .49873 L
.56998 .49861 L
.5701 .49823 L
.5702 .49783 L
.57029 .49737 L
.5705 .49603 L
.5707 .49434 L
.57092 .4921 L
.57134 .48648 L
.57173 .47983 L
Mistroke
.57262 .4599 L
.57423 .40859 L
.57738 .27684 L
.57899 .21046 L
.57983 .18005 L
.58072 .15303 L
.58152 .13408 L
.58198 .12587 L
.5824 .11997 L
.5826 .11779 L
.58279 .1161 L
.58296 .11489 L
.58315 .11391 L
.58324 .11354 L
.58335 .11323 L
.5834 .11313 L
.58346 .11304 L
.58356 .11297 L
.58366 .11302 L
.58376 .11315 L
.58385 .11336 L
.58394 .11368 L
.58405 .11414 L
.58415 .11468 L
.58437 .11624 L
.58457 .11803 L
.58477 .12033 L
.58552 .13228 L
.58594 .14117 L
.58633 .15087 L
.58721 .1775 L
.59033 .30655 L
.59192 .37747 L
.59276 .41177 L
.59365 .44393 L
.59444 .46762 L
.59486 .47807 L
.59531 .48751 L
.59572 .49441 L
.5959 .49688 L
.5961 .4992 L
.59628 .50092 L
.59646 .50239 L
.59657 .50305 L
.59666 .50354 L
.59675 .50393 L
.59685 .50424 L
.59694 .50446 L
.59703 .50458 L
.59709 .5046 L
Mistroke
.59714 .5046 L
.59723 .50452 L
.59734 .50432 L
.59743 .50404 L
.59754 .50362 L
.59765 .50304 L
.59785 .50167 L
.59803 .5 L
.59838 .49587 L
.5988 .48931 L
.59919 .48175 L
.60005 .45964 L
.60157 .40682 L
.60323 .33526 L
.60493 .25833 L
.60648 .19547 L
.60724 .16959 L
.60808 .1469 L
.60846 .13865 L
.60887 .13147 L
.60922 .12668 L
.60942 .1245 L
.6096 .12286 L
.60979 .12156 L
.60989 .12102 L
.61 .12057 L
.61005 .12039 L
.61011 .12023 L
.61022 .12003 L
.61032 .11996 L
.61041 .11999 L
.6105 .12011 L
.61059 .1203 L
.61068 .1206 L
.61077 .12102 L
.61097 .12219 L
.61116 .12364 L
.61157 .12819 L
.61202 .13514 L
.61283 .15283 L
.61358 .17441 L
.61442 .20323 L
.6161 .27267 L
.61778 .34692 L
.61933 .40897 L
.62011 .43528 L
.62084 .45552 L
.6216 .47158 L
.622 .4778 L
.62221 .48038 L
Mistroke
.62243 .48263 L
.62263 .48423 L
.62274 .48491 L
.62285 .4855 L
.62296 .48591 L
.62306 .48619 L
.62316 .48636 L
.62325 .48643 L
.6233 .48643 L
.62336 .4864 L
.62341 .48633 L
.62347 .48623 L
.62357 .48598 L
.62367 .48559 L
.62379 .48501 L
.62392 .48425 L
.62414 .48248 L
.62454 .47803 L
.62491 .47243 L
.62576 .45483 L
.62659 .43134 L
.62739 .40449 L
.62888 .34599 L
.63196 .22245 L
.63278 .19604 L
.63354 .17574 L
.63435 .15998 L
.63477 .15406 L
.63501 .15151 L
.63523 .14968 L
.63533 .14898 L
.63543 .14843 L
.63552 .14801 L
.63561 .14765 L
.63571 .14735 L
.63581 .14717 L
.63591 .14708 L
.63596 .14708 L
.63602 .1471 L
.63611 .14721 L
.6362 .14741 L
.63628 .14765 L
.63637 .14798 L
.63657 .14902 L
.63675 .15033 L
.63717 .1546 L
.63756 .15993 L
.63841 .17662 L
.63922 .19771 L
.63996 .22088 L
Mistroke
.64163 .28184 L
.64328 .3447 L
.64481 .39647 L
.64557 .41718 L
.64628 .43287 L
.64668 .43972 L
.64711 .4456 L
.6473 .44766 L
.6475 .44949 L
.64767 .45075 L
.64786 .45182 L
.64797 .45227 L
.64806 .45259 L
.64816 .45282 L
.64826 .45297 L
.64835 .45303 L
.64844 .453 L
.64853 .45291 L
.64862 .45274 L
.64871 .45247 L
.64882 .45207 L
.64904 .45093 L
.64924 .4495 L
.64943 .44782 L
.6498 .44361 L
.65014 .43875 L
.6509 .42447 L
.65243 .38398 L
.65409 .32884 L
.65565 .27574 L
.65647 .24988 L
.65736 .22554 L
.65821 .20689 L
.65858 .20033 L
.65899 .19437 L
.65937 .18993 L
.65973 .18691 L
.65993 .1857 L
.66011 .18488 L
.66021 .18455 L
.66026 .18441 L
.66032 .18429 L
.66042 .18413 L
.66051 .18406 L
.66061 .18407 L
.66072 .18417 L
.66082 .18435 L
.66091 .1846 L
.661 .18491 L
.66108 .18525 L
Mistroke
.66127 .18623 L
.66147 .18761 L
.66169 .18946 L
.66208 .19377 L
.66285 .20542 L
.66355 .21956 L
.66673 .30803 L
.66832 .354 L
.66978 .3877 L
.67016 .39468 L
.67058 .40118 L
.67094 .40583 L
.67134 .40988 L
.67156 .4116 L
.67177 .4129 L
.67198 .41392 L
.67211 .41435 L
.67216 .4145 L
.67222 .41464 L
.67231 .41482 L
.6724 .41492 L
.67246 .41495 L
.67251 .41496 L
.67261 .41492 L
.67271 .41481 L
.67281 .41463 L
.67291 .41436 L
.67302 .41398 L
.67323 .41306 L
.67342 .41191 L
.67378 .40905 L
.67417 .40498 L
.6746 .39943 L
.67607 .37251 L
.67934 .29116 L
.68085 .25694 L
.6817 .24175 L
.68248 .2312 L
.68288 .22719 L
.68332 .22395 L
.68354 .22278 L
.68367 .22227 L
.68378 .22188 L
.68389 .22159 L
.68394 .22146 L
.684 .22135 L
.68411 .22122 L
.68421 .22116 L
.68431 .22116 L
.6844 .22121 L
Mistroke
.68451 .22135 L
.68461 .22154 L
.6847 .22177 L
.68478 .22204 L
.68498 .2228 L
.68519 .22393 L
.68539 .22519 L
.68583 .22883 L
.68663 .23823 L
.68737 .24959 L
.68904 .282 L
.69068 .31727 L
.69221 .34714 L
.69297 .35919 L
.69368 .36838 L
.69408 .3724 L
.69451 .37588 L
.6947 .3771 L
.6949 .37819 L
.69507 .37896 L
.69526 .3796 L
.69536 .37987 L
.69545 .38006 L
.69555 .38022 L
.69565 .38033 L
.69575 .38039 L
.69584 .38039 L
.69592 .38035 L
.69601 .38027 L
.69611 .38013 L
.69622 .37993 L
.69633 .37964 L
.69644 .37932 L
.69663 .37854 L
.69682 .37762 L
.69719 .37531 L
.69753 .37262 L
.69829 .36476 L
.69988 .34176 L
.70136 .31612 L
.70287 .29019 L
.70367 .27819 L
.70451 .26754 L
.70493 .26306 L
.7054 .25899 L
.70583 .25608 L
.70623 .25409 L
.70644 .25332 L
.70654 .25301 L
.70664 .25277 L
Mistroke
.70672 .25259 L
.70682 .25243 L
.70691 .25231 L
.70701 .25222 L
.70706 .25219 L
.70712 .25218 L
.70722 .25218 L
.70727 .25221 L
.70733 .25224 L
.70738 .25229 L
.70744 .25236 L
.70755 .25252 L
.70765 .25273 L
.70785 .25323 L
.70804 .25389 L
.70822 .25465 L
.70863 .25686 L
.70903 .25963 L
.70946 .26324 L
.71094 .27981 L
.71253 .30174 L
.71426 .32542 L
.71506 .33486 L
.71592 .34311 L
.71665 .34837 L
.71706 .35057 L
.71726 .35142 L
.71745 .35207 L
.71765 .35262 L
.71783 .353 L
.71793 .35317 L
.71803 .35329 L
.71813 .35338 L
.71819 .35341 L
.71824 .35343 L
.71834 .35344 L
.71843 .35342 L
.71853 .35336 L
.71859 .35332 L
.71864 .35326 L
.71875 .35312 L
.71886 .35293 L
.71907 .35246 L
.71927 .35188 L
.71944 .35125 L
.71984 .34946 L
.72055 .34507 L
.72136 .33854 L
.7221 .33138 L
.72377 .31309 L
Mistroke
.72541 .29559 L
.72621 .28835 L
.72694 .28291 L
.72731 .28069 L
.7277 .27867 L
.72807 .27714 L
.72842 .27608 L
.7286 .27565 L
.72878 .27533 L
.72887 .2752 L
.72897 .27508 L
.72902 .27504 L
.72908 .27499 L
.72918 .27494 L
.72923 .27492 L
.72929 .27491 L
.72938 .27492 L
.72949 .27495 L
.72955 .27499 L
.7296 .27503 L
.72969 .27511 L
.72979 .27523 L
.72999 .27555 L
.73019 .27598 L
.73041 .27657 L
.73081 .27795 L
.73155 .28155 L
.73243 .28715 L
.73323 .29335 L
.73638 .31966 L
.73721 .32531 L
.73764 .32783 L
.7381 .3301 L
.7385 .33174 L
.73895 .33314 L
.73914 .33362 L
.73935 .33404 L
.73954 .33434 L
.73972 .33455 L
.73982 .33463 L
.73991 .33469 L
.74 .33473 L
.74011 .33475 L
.74016 .33475 L
.74022 .33475 L
.74032 .33472 L
.74043 .33467 L
.74052 .3346 L
.74062 .33451 L
.74071 .33441 L
Mistroke
.74088 .33417 L
.74126 .33343 L
.74167 .33228 L
.74206 .33094 L
.74293 .32704 L
.74609 .30728 L
.74691 .30227 L
.74769 .29807 L
.74844 .2947 L
.74914 .29232 L
.7495 .29139 L
.74989 .29065 L
.75009 .29037 L
.75028 .29016 L
.75039 .29007 L
.75048 .29001 L
.75059 .28996 L
.75065 .28994 L
.75071 .28992 L
.75076 .28991 L
.75082 .28991 L
.75087 .28991 L
.75093 .28992 L
.75102 .28995 L
.75113 .28999 L
.75124 .29006 L
.75134 .29014 L
.75158 .29039 L
.75178 .29067 L
.75197 .29099 L
.75238 .29189 L
.75318 .29424 L
.75391 .29705 L
.75557 .3048 L
.75709 .31212 L
.75788 .31556 L
.75872 .31862 L
.75915 .3199 L
.75962 .32107 L
.76004 .3219 L
.76044 .32246 L
.76065 .32268 L
.76075 .32276 L
.76085 .32283 L
.76093 .32288 L
.76103 .32292 L
.76112 .32295 L
.76122 .32297 L
.76127 .32298 L
.76133 .32298 L
Mistroke
.76143 .32297 L
.76149 .32297 L
.76154 .32296 L
.76159 .32294 L
.76165 .32292 L
.76176 .32287 L
.76187 .3228 L
.76206 .32265 L
.76225 .32246 L
.76243 .32224 L
.76284 .3216 L
.76367 .3198 L
.76515 .31526 L
.76664 .30989 L
.76827 .30442 L
.76915 .30205 L
.76954 .3012 L
.76997 .30041 L
.77037 .29982 L
.77075 .2994 L
.77096 .29923 L
.77115 .29911 L
.77125 .29906 L
.77136 .29902 L
.77142 .299 L
.77148 .29899 L
.77153 .29898 L
.77159 .29897 L
.77168 .29896 L
.77177 .29897 L
.77187 .29898 L
.77197 .299 L
.77203 .29901 L
.77208 .29903 L
.77219 .29907 L
.77239 .29917 L
.77257 .2993 L
.77277 .29948 L
.77312 .29986 L
.77357 .3005 L
.774 .30123 L
.77479 .30287 L
.77789 .31074 L
.77871 .31261 L
.77949 .31406 L
.78029 .3152 L
.78072 .31563 L
.78096 .31581 L
.78118 .31595 L
.78136 .31603 L
Mistroke
.78147 .31607 L
.78156 .3161 L
.78167 .31612 L
.78172 .31613 L
.78178 .31614 L
.78187 .31615 L
.78197 .31615 L
.78207 .31615 L
.78216 .31614 L
.78226 .31612 L
.78236 .31609 L
.78253 .31604 L
.78271 .31595 L
.78291 .31584 L
.78313 .31568 L
.78358 .31528 L
.78438 .31431 L
.78594 .31171 L
.78762 .30857 L
.78843 .30717 L
.78931 .30587 L
.78972 .30537 L
.79015 .30492 L
.79053 .3046 L
.79093 .30434 L
.79113 .30423 L
.79136 .30414 L
.79146 .30411 L
.79157 .30408 L
.79166 .30406 L
.79176 .30404 L
.79181 .30404 L
.79187 .30403 L
.79193 .30403 L
.792 .30402 L
.79205 .30402 L
.79211 .30402 L
.79217 .30403 L
.79222 .30403 L
.79232 .30404 L
.79238 .30405 L
.79243 .30406 L
.79265 .30411 L
.79286 .30419 L
.79306 .30427 L
.79343 .30448 L
.79384 .30477 L
.79427 .30515 L
.79756 .3092 L
.79835 .31017 L
Mistroke
.7992 .31107 L
.79961 .31144 L
.8 .31174 L
.80034 .31197 L
.80073 .31217 L
.80109 .31232 L
.8013 .31237 L
.80139 .3124 L
.80148 .31242 L
.80157 .31243 L
.80166 .31244 L
.80174 .31245 L
.80182 .31246 L
.80191 .31246 L
.802 .31247 L
.80209 .31246 L
.80219 .31246 L
.80228 .31245 L
.80238 .31244 L
.80248 .31243 L
.80258 .31241 L
.80276 .31237 L
.80295 .31232 L
.80338 .31215 L
.80377 .31196 L
.80456 .31145 L
.8053 .31086 L
.80696 .30935 L
.80847 .30805 L
.80927 .30749 L
.81011 .30705 L
.81053 .30688 L
.81076 .30682 L
.811 .30676 L
.81122 .30671 L
.81143 .30669 L
.81153 .30668 L
.81158 .30667 L
.81163 .30667 L
.81173 .30667 L
.81183 .30667 L
.81193 .30667 L
.81202 .30667 L
.81212 .30667 L
.81222 .30668 L
.81232 .30669 L
.8124 .3067 L
.8126 .30673 L
.81281 .30677 L
.81301 .30682 L
Mistroke
.81345 .30696 L
.81425 .3073 L
.81499 .30769 L
.81666 .30873 L
.81829 .30969 L
.81909 .31007 L
.81982 .31033 L
.82018 .31043 L
.82037 .31047 L
.82057 .31051 L
.82077 .31054 L
.82095 .31057 L
.82103 .31057 L
.82112 .31058 L
.8212 .31059 L
.82129 .31059 L
.82139 .3106 L
.82148 .3106 L
.82154 .3106 L
.82159 .3106 L
.82169 .3106 L
.82179 .3106 L
.82189 .31059 L
.822 .31059 L
.82211 .31058 L
.8223 .31056 L
.82247 .31054 L
.82286 .31047 L
.82326 .31038 L
.8237 .31025 L
.82449 .30998 L
.82598 .30937 L
.82769 .30866 L
.82849 .30839 L
.82924 .30819 L
.82962 .30811 L
.83001 .30804 L
.83021 .30802 L
.83042 .308 L
.83053 .30799 L
.83064 .30798 L
.83075 .30797 L
.83086 .30797 L
.83095 .30797 L
.83105 .30796 L
.83114 .30796 L
.83123 .30796 L
.83133 .30796 L
.83143 .30797 L
.83153 .30797 L
Mistroke
.83164 .30797 L
.83182 .30799 L
.83199 .308 L
.83238 .30804 L
.83278 .3081 L
.83322 .30818 L
.83402 .30836 L
.83551 .30878 L
.83708 .30921 L
.83791 .30941 L
.83836 .3095 L
.8388 .30957 L
.8392 .30962 L
.83942 .30965 L
.83965 .30967 L
.83986 .30968 L
.84005 .30969 L
.84015 .3097 L
.84025 .3097 L
.84034 .30971 L
.84043 .30971 L
.84053 .30971 L
.84061 .30971 L
.84072 .30971 L
.84082 .30971 L
.84092 .30971 L
.84097 .30971 L
.84103 .30971 L
.84123 .3097 L
.8414 .30969 L
.84158 .30968 L
.84196 .30965 L
.84235 .30961 L
.84277 .30956 L
.84351 .30944 L
.84519 .30913 L
.84679 .30884 L
.84749 .30874 L
.84825 .30865 L
.84867 .30862 L
.84886 .30861 L
.84906 .30859 L
.84924 .30858 L
.84944 .30858 L
.84954 .30857 L
.84964 .30857 L
.84974 .30857 L
.84983 .30857 L
.84992 .30857 L
.84998 .30857 L
Mistroke
.85003 .30857 L
.85013 .30857 L
.85019 .30857 L
.85025 .30857 L
.85034 .30857 L
.85044 .30857 L
.85054 .30857 L
.85063 .30857 L
.85086 .30858 L
.85106 .30859 L
.85151 .30862 L
.85231 .30868 L
.85305 .30876 L
.85472 .30896 L
.8555 .30906 L
.85635 .30915 L
.85708 .30922 L
.85747 .30924 L
.85788 .30927 L
.8581 .30928 L
.8583 .30929 L
.8585 .30929 L
.85869 .3093 L
.85888 .3093 L
.85898 .30931 L
.85903 .30931 L
.85909 .30931 L
.85918 .30931 L
.85927 .30931 L
.85937 .30931 L
.85946 .30931 L
.85955 .30931 L
.85965 .30931 L
.85973 .30931 L
.85982 .3093 L
.86002 .3093 L
.86021 .3093 L
.86055 .30928 L
.86091 .30927 L
.86168 .30923 L
.86252 .30917 L
.86422 .30903 L
.8651 .30896 L
.86592 .30891 L
.86667 .30887 L
.86709 .30886 L
.86727 .30885 L
.86747 .30884 L
.86767 .30884 L
.86785 .30884 L
Mistroke
.86803 .30883 L
.86812 .30883 L
.8682 .30883 L
.8683 .30883 L
.8684 .30883 L
.86849 .30883 L
.86858 .30883 L
.86869 .30883 L
.86878 .30883 L
.86889 .30883 L
.869 .30883 L
.86919 .30884 L
.8694 .30884 L
.86977 .30885 L
.87021 .30886 L
.87061 .30887 L
.87228 .30895 L
.87381 .30903 L
.87459 .30907 L
.87531 .30909 L
.87606 .30912 L
.87646 .30912 L
.87669 .30913 L
.8769 .30913 L
.877 .30913 L
.8771 .30913 L
.87718 .30913 L
.87728 .30913 L
.87738 .30913 L
.87747 .30913 L
.87757 .30913 L
.87763 .30913 L
.87769 .30913 L
.87778 .30913 L
.87787 .30913 L
.87795 .30913 L
.87804 .30913 L
.87824 .30913 L
.87842 .30913 L
.8788 .30912 L
.87922 .30912 L
.88008 .3091 L
.88176 .30904 L
.88331 .30899 L
.88409 .30897 L
.88482 .30896 L
.88519 .30895 L
.88558 .30895 L
.8858 .30895 L
.88601 .30895 L
Mistroke
.8862 .30894 L
.88631 .30894 L
.88641 .30894 L
.88651 .30894 L
.88661 .30894 L
.88669 .30894 L
.88679 .30894 L
.88689 .30894 L
.88694 .30894 L
.88699 .30894 L
.88719 .30895 L
.88737 .30895 L
.88756 .30895 L
.88792 .30895 L
.88834 .30896 L
.88878 .30896 L
.88957 .30898 L
.89117 .30901 L
.89262 .30904 L
.89343 .30905 L
.8938 .30905 L
.89419 .30906 L
.89439 .30906 L
.89461 .30906 L
.89481 .30906 L
.895 .30906 L
.8951 .30906 L
.89522 .30906 L
.89531 .30906 L
.89542 .30906 L
.89548 .30906 L
.89553 .30906 L
.89559 .30906 L
.89565 .30906 L
.89576 .30906 L
.89582 .30906 L
.89587 .30906 L
.89607 .30906 L
.89625 .30906 L
.89645 .30906 L
.89665 .30906 L
.89738 .30905 L
.89817 .30904 L
.89904 .30903 L
.90059 .30901 L
.90141 .30901 L
.90185 .309 L
.9023 .309 L
.90271 .30899 L
.90292 .30899 L
Mistroke
.90315 .30899 L
.90336 .30899 L
.90355 .30899 L
.90375 .30899 L
.90393 .30899 L
.90402 .30899 L
.90411 .30899 L
.90421 .30899 L
.90431 .30899 L
.9044 .30899 L
.90448 .30899 L
.90457 .30899 L
.90466 .30899 L
.90475 .30899 L
.90486 .30899 L
.90504 .30899 L
.90526 .30899 L
.90545 .30899 L
.90626 .309 L
.907 .309 L
.90867 .30901 L
.90946 .30902 L
.91031 .30903 L
.91072 .30903 L
.91111 .30903 L
.91146 .30903 L
.91184 .30903 L
.91221 .30903 L
.91241 .30903 L
.9125 .30903 L
.9126 .30903 L
.91268 .30903 L
.91277 .30903 L
.91286 .30903 L
.91293 .30903 L
.91303 .30903 L
.91311 .30903 L
.91321 .30903 L
.9133 .30903 L
.91339 .30903 L
.91349 .30903 L
.91369 .30903 L
.91388 .30903 L
.91406 .30903 L
.91446 .30903 L
.91489 .30903 L
.91659 .30902 L
.9182 .30902 L
.91897 .30901 L
.91939 .30901 L
Mistroke
.91979 .30901 L
.92017 .30901 L
.92057 .30901 L
.92075 .30901 L
.92093 .30901 L
.92109 .30901 L
.92127 .30901 L
.92137 .30901 L
.92147 .30901 L
.92152 .30901 L
.92158 .30901 L
.92164 .30901 L
.92169 .30901 L
.92179 .30901 L
.92188 .30901 L
.92198 .30901 L
.92209 .30901 L
.92218 .30901 L
.92228 .30901 L
.92245 .30901 L
.92284 .30901 L
.92329 .30901 L
.92372 .30901 L
.92452 .30901 L
.92599 .30902 L
.92683 .30902 L
.92761 .30902 L
.92838 .30902 L
.92881 .30902 L
.92921 .30902 L
.92942 .30902 L
.92962 .30902 L
.92974 .30902 L
.92984 .30902 L
.92995 .30902 L
.93001 .30902 L
.93008 .30902 L
.93018 .30902 L
.93023 .30902 L
.93029 .30902 L
.93034 .30902 L
.93039 .30902 L
.93045 .30902 L
.93051 .30902 L
.9306 .30902 L
.93069 .30902 L
.9309 .30902 L
.93109 .30902 L
.93127 .30902 L
.93168 .30902 L
Mistroke
.9324 .30902 L
.93406 .30902 L
.93486 .30902 L
.93571 .30902 L
.93645 .30901 L
.93684 .30901 L
.93725 .30901 L
.93745 .30901 L
.93768 .30901 L
.93789 .30901 L
.93808 .30901 L
.93827 .30901 L
.93838 .30901 L
.93848 .30901 L
.93857 .30901 L
.93866 .30901 L
.93876 .30901 L
.93886 .30901 L
.93895 .30901 L
.93903 .30901 L
.93912 .30901 L
.93922 .30901 L
.93938 .30901 L
.93955 .30901 L
.93995 .30901 L
.94032 .30901 L
.94116 .30901 L
.94196 .30902 L
.94345 .30902 L
.94423 .30902 L
.94506 .30902 L
.9454 .30902 L
.94576 .30902 L
.94597 .30902 L
.94617 .30902 L
.94636 .30902 L
.94654 .30902 L
.94664 .30902 L
.94674 .30902 L
.94684 .30902 L
.94693 .30902 L
.94702 .30902 L
.94712 .30902 L
.94718 .30902 L
.94723 .30902 L
.94733 .30902 L
.94743 .30902 L
.94753 .30902 L
.94772 .30902 L
.9479 .30902 L
Mistroke
.94807 .30902 L
.94845 .30902 L
.94888 .30902 L
.94973 .30902 L
.95142 .30902 L
.95297 .30902 L
.95373 .30902 L
.95416 .30902 L
.95437 .30902 L
.95456 .30902 L
.95475 .30902 L
.95484 .30902 L
.95495 .30902 L
.95503 .30902 L
.95513 .30902 L
.95521 .30902 L
.9553 .30902 L
.9554 .30902 L
.95549 .30902 L
.95558 .30902 L
.95567 .30902 L
.95578 .30902 L
.95588 .30902 L
.95608 .30902 L
.95627 .30902 L
.95647 .30902 L
.95683 .30902 L
.95764 .30902 L
.95911 .30902 L
.95993 .30902 L
.96071 .30902 L
.96147 .30902 L
.96217 .30902 L
.96253 .30902 L
.96272 .30902 L
.96292 .30902 L
.96312 .30902 L
.96321 .30902 L
.96331 .30902 L
.96337 .30902 L
.96342 .30902 L
.96348 .30902 L
.96353 .30902 L
.96363 .30902 L
.96374 .30902 L
.96384 .30902 L
.9639 .30902 L
.96396 .30902 L
.96406 .30902 L
.96416 .30902 L
Mistroke
.96437 .30902 L
.9646 .30902 L
.96503 .30902 L
.96542 .30902 L
.96695 .30902 L
.96862 .30902 L
.96944 .30902 L
.97021 .30902 L
.9706 .30902 L
.97101 .30902 L
.97124 .30902 L
.97135 .30902 L
.97148 .30902 L
.97158 .30902 L
.97164 .30902 L
.97169 .30902 L
.97175 .30902 L
.9718 .30902 L
.9719 .30902 L
.972 .30902 L
.97209 .30902 L
.97219 .30902 L
.97229 .30902 L
.97247 .30902 L
.97266 .30902 L
.97287 .30902 L
.97309 .30902 L
.9735 .30902 L
.9743 .30902 L
.97519 .30902 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{421.375, 260.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008>0001AB000`400?l00000o`00003ooooooooo
oooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo
003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooo
oooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool0
0?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooooooo
ool@ooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooo
ooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo0ol0003o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0
003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo
00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`
ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLoooo
o`00<?ooool3o`000?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?oo
ool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0
033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomco
oooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooo
oooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool3o`000?oooooo
g?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0013ooooo0_o^k^h3ooooo`;ok^k^6Oooool00ol0003oooooooooo`3o
ooooomcooooo000;ooooo`;o000000[o410@ooooooooooook^k^oeEEEOo^k^koooooonk^k_mEEEGo
k^k^0oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h:ooooo`03o`000?oo
oooooooo0?oooooog?ooool000cooooo00?o0000ooooooooool00_ooool01Oo^k^koEEEEomgMgOmE
EEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00[ooooo
00?o0000ooooooooool0oooooooLooooo`0000?oooooo`000?l000001?l00002ooooo`Go00001?oo
ool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooo
oa0@400:ooooo`03o`000?oooooooooo0?oooooog?ooool000Wooooo00CoA4A4omgMgOoooooo0000
1?ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000000[ooooo00?o0000ooooooooool0oooooooLooooo`002Oooool01?oMgMgo
EEEEooooool00003ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000:ooooo`Co0000oooooooKooooo`002_oo
ool00omgMgOoc<c<o`000003ooooo`;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@00[ooooo00?o0000ooooooooool0oooooooLooooo`002_oo
ool00oo^k^koA4A4o`00000?ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`;o00001Oooool00ol0003oooooooooo`3oooooomcooooo000;ooooo`03ogMgMol0
003ooooo00cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`3oooooomcooooo000Xooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool0oooooooLooooo`00:?ooool3o`0000Gooooo
00?o0000ooooooooool0oooooooLooooo`00:Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo0?oooooog?ooool002[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0b_ooool2o`000?oooooo4?ooool0033ooooo00?o0000ooooooooool0b_ooool2o`000?oooooo
4?ooool0033ooooo00?o0000ooooooooool0b_ooool2o`000?oooooo4?ooool0033ooooo0ol0003:
ooooo`;o00002_ooool00ol0003oooooooooo`3oooooo`?ooooo000`ooooo`03o`000?oooooooooo
0<[ooooo0_l0000:ooooo`03o`000?oooooooooo0?oooooo0oooool0033ooooo00?o0000oooooooo
ool0b_ooool2o`0000[ooooo00?o0000ooooooooool0ooooool3ooooo`00<?ooool00ol0003ooooo
ooooo`3:ooooo`;o00002_ooool00ol0003oooooooooo`3oooooo`?ooooo000`ooooo`03o`000?oo
oooooooo0<[ooooo0_l0000:ooooo`;o0000ooooool4ooooo`00<?ooool00ol0003oooooooooo`2n
ooooo`;o00002_ooool2o`0000[ooooo0_l0003oooooo`Cooooo000`ooooo`03o`000?oooooooooo
0;kooooo0_l0000:ooooo`;o00002_ooool2o`000?oooooo1?ooool0033ooooo00?o0000oooooooo
ool0__ooool2o`0000[ooooo0_l00009ooooo`03o`000?oooooo00000?oooooo1?ooool0033ooooo
00?o0000ooooooooool0__ooool2o`0000[ooooo00?o0000ooooool000002?ooool00ol0003ooooo
o`00003oooooo`Cooooo000`ooooo`03o`000?oooooooooo0;kooooo0_l0000:ooooo`03o`000?oo
oooo000000Sooooo00?o0000ooooool00000ooooool4ooooo`00<?ooool00ol0003oooooooooo`2n
ooooo`;o00002_ooool00ol0003oooooo`000008ooooo`03o`000?oooooo00000?oooooo1?ooool0
033ooooo00?o0000ooooooooool0__ooool2o`0000Wooooo00Co0000oooooooooooo00002?ooool0
0ol0003oooooo`00003oooooo`Cooooo000`ooooo`?o0000__ooool2o`0000Wooooo00Co0000oooo
oooooooo00002?ooool00ol0003oooooo`000009ooooo`03o`000?oooooooooo0?Oooooo000`oooo
o`03o`000?oooooooooo0;gooooo00?o0000ooooool000002Oooool01?l0003oooooooooool00008
ooooo`03o`000?oooooo000000Wooooo0_l0003hooooo`00<?ooool00ol0003oooooooooo`2moooo
o`03o`000?oooooo000000Wooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`000009
ooooo`;o0000n?ooool0033ooooo00?o0000ooooooooool0_Oooool00ol0003oooooo`000009oooo
o`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool000002Oooool2o`000?Sooooo000`oooo
o`03o`000?oooooooooo0;gooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0
0008ooooo`03o`000?oooooo000000Wooooo0_l0003hooooo`00<?ooool00ol0003oooooooooo`2m
ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002?ooool00ol0003ooooo
o`000009ooooo`;o0000n?ooool0033ooooo00?o0000ooooooooool0_Oooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool000002Oooool2o`000?So
oooo000`ooooo`03o`000?oooooooooo0;gooooo00Co0000oooooooooooo00002?ooool01?l0003o
ooooooooool00008ooooo`03o`000?oooooo000000Wooooo0_l0003hooooo`00<?ooool00ol0003o
ooooooooo`2mooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002?ooool0
1?l0003oooooooooool00008ooooo`;o0000n?ooool0033ooooo00?o0000ooooooooool0_Oooool0
1?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo
00002?ooool2o`000?Sooooo000`ooooo`03o`000?oooooooooo0;gooooo00Co0000oooooooooooo
00002?ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000
ooooool00000n?ooool0033ooooo0ol0002aooooo`;o00002_ooool01?l0003oooooooooool00008
ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001oooool00ol0003ooooo
o`00003hooooo`00<?ooool00ol0003oooooooooo`2aooooo`;o00002_ooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001oooool00ol0
003oooooo`00003hooooo`00<?ooool00ol0003oooooooooo`2aooooo`;o00002_ooool01?l0003o
ooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001ooo
ool00ol0003oooooo`00003hooooo`00<?ooool00ol0003oooooooooo`2aooooo`;o00002_ooool0
1?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo
00001oooool00ol0003oooooo`00003hooooo`00<?ooool00ol0003oooooooooo`2aooooo`;o0000
2_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooo
oooooooo00001oooool00ol0003oooooo`00003hooooo`00<?ooool00ol0003oooooooooo`2aoooo
o`;o00002_ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Oooooo00Go
0000ooooooooooooooooo`000007ooooo`03o`000?oooooo000000Wooooo00?o0000ooooooooool0
k?ooool0033ooooo00?o0000ooooooooool0/Oooool2o`0000[ooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001oooool00ol0
003oooooo`000009ooooo`03o`000?oooooooooo0>cooooo000@ooooo`;ok^k^0oooool2onk^kQWo
oooo00?o0000ooooooooool0/Oooool2o`0000[ooooo00Co0000oooooooooooo00002?ooool01?l0
003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001oooool01?l0003ooooooooo
ool00008ooooo`03o`000?oooooooooo0>cooooo0009ooooo`Go00000_ooool01oo^k^koEEEEonk^
k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h:ooooo`03o`000?oooooooooo0;3ooooo00Co0000oooooooooooo00002Oooool01?l0003ooooo
ooooool00008ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000007
ooooo`04o`000?ooooooooooo`0000Oooooo0_l0003^ooooo`002Oooool01OnHV9So8B4Qonk^k_oo
ooooA4A400?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0:ooooo`03o`000?oooooooooo0;3ooooo00Co0000oooooooo
oooo00002Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Oooooo00Go
0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool0
0000kOooool00003ooooool0003o000000Co00000oooool00onHV9So8B4Qonk^kP05ooooo`03omgM
gOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00[o
oooo00?o0000ooooooooool0/?ooool01?l0003oooooooooool00009ooooo`04o`000?oooooooooo
o`0000Sooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Oooooo
00Co0000oooooooooooo00001oooool00ol0003oooooo`00003]ooooo`002oooool00onHV9So8B4Q
onk^kP03ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000002_ooool00ol0003oooooooooo`2`ooooo`04o`000?oooooooooo
o`0000Wooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00007ooooo`05o`00
0?ooooooooooooooool000001oooool01?l0003oooooooooool00007ooooo`03o`000?oooooo0000
0>gooooo000<ooooo`0;ogMgMomVIVKoooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h0
1Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000002_ooool4o`000:oo
oooo00Co0000oooooooooooo00002Oooool01?l0003oooooooooool00008ooooo`04o`000?oooooo
ooooo`0000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oo
oooo00?o0000ooooool00000kOooool000gooooo00?o0000ooooooooool00_o^k^h3ooooo`;ok^k^
1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41002_ooool00ol0003o
ooooooooo`2`ooooo`04o`000?ooooooooooo`0000Wooooo00Co0000oooooooooooo00002?ooool0
1?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001oooool01?l0003ooooo
ooooool00007ooooo`03o`000?oooooo00000>gooooo0009ooooo`05o`000?nj^[[ooooooiRHV?l@
41003_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool2o`00
00Gooooo00?o0000ooooooooool0/?ooool01?l0003oooooooooool00009ooooo`04o`000?oooooo
ooooo`0000Sooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Oo
oooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00003]ooooo`002Oooool01OnHV9So
410@o`000?lQ8B7oc<c<00cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00;ooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`2`ooooo`04o`000?oo
ooooooooo`0000Wooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00007oooo
o`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool00007ooooo`03o`000?oo
oooo00000>gooooo000Xooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0/?oo
ool01?l0003oooooooooool00009ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooo
oooo00001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo00001ooo
ool00ol0003oooooo`00003]ooooo`00:?ooool3o`0000Gooooo00?o0000ooooooooool0/?ooool0
1?l0003oooooooooool00009ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo
00001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo00001oooool0
0ol0003oooooo`00003]ooooo`00:Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
0;3ooooo00Co0000oooooooooooo00002Oooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`00
00Oooooo00?o0000ooooool00000kOooool002[ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`2`ooooo`04o`000?ooooooooooo`0000Wooooo00Co0000oooooooooooo00002?ooool0
1?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001oooool01?l0003ooooo
ooooool00007ooooo`03o`000?oooooo00000>gooooo000`ooooo`03o`000?oooooooooo0;3ooooo
00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Sooooo00Co0000oooo
oooooooo00001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000
1oooool00ol0003oooooo`00003]ooooo`00<?ooool00ol0003oooooooooo`2Tooooo`03o`000?oo
oooooooo00Wooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000So
oooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000
oooooooooooo00001oooool00ol0003oooooo`000008ooooo`03o`000?oooooooooo0>;ooooo000`
ooooo`03o`000?oooooooooo0:?ooooo0_l0000;ooooo`04o`000?ooooooooooo`0000Sooooo00Go
0000ooooooooooooooooo`000008ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooo
ooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool000002?ooool2
o`000>?ooooo000`ooooo`03o`000?oooooooooo0:?ooooo00?o0000ooooool000002_ooool01?l0
003oooooooooool00008ooooo`05o`000?ooooooooooooooool000002?ooool01?l0003ooooooooo
ool00007ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool00007oooo
o`03o`000?oooooo000000Sooooo0_l0003Sooooo`00<?ooool3o`000:?ooooo00?o0000ooooool0
00002_ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000008
ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04o`00
0?ooooooooooo`0000Oooooo00?o0000ooooool000002?ooool2o`000>?ooooo000`ooooo`03o`00
0?oooooooooo0:?ooooo00?o0000ooooool000002_ooool01Ol0003ooooooooooooooooo000000Oo
oooo00Go0000ooooooooooooooooo`000008ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000
ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool00000
2?ooool2o`000>?ooooo000`ooooo`03o`000?oooooooooo0:?ooooo00?o0000ooooool000002_oo
ool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000008ooooo`04
o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?oooooo
ooooo`0000Oooooo00?o0000ooooool000001oooool00ol0003oooooo`00003Sooooo`00<?ooool0
0ol0003oooooooooo`2Rooooo`04o`000?ooooooooooo`0000[ooooo00Go0000oooooooooooooooo
o`000007ooooo`05o`000?ooooooooooooooool000002?ooool01?l0003oooooooooool00007oooo
o`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool00007ooooo`03o`000?oo
oooo000000Oooooo00?o0000ooooool00000hoooool0033ooooo00?o0000ooooooooool0X_ooool0
1?l0003oooooooooool0000:ooooo`05o`000?ooooooooooooooool000001oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00001oooool01Ol0003o
oooooooooooooooo000000Oooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`000007
ooooo`03o`000?oooooo00000>?ooooo000`ooooo`03o`000?oooooooooo0:;ooooo00Co0000oooo
oooooooo00002_ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000Kooooo00Co0000oooooooo
oooo00001oooool00ol0003oooooo`00003Sooooo`00<?ooool00ol0003oooooooooo`2Rooooo`04
o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00007
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0
0006ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool00000hoooool0033ooooo00?o
0000ooooooooool0X_ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo
00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool01?l0003oooooooooool00006ooooo`05o`000?ooooooooooooooool000001_ooool0
0ol0003oooooo`00003Sooooo`00<?ooool00ol0003oooooooooo`2Rooooo`04o`000?oooooooooo
o`0000Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`04o`000?oooooo
ooooo`0000Kooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`000>;o
oooo000`ooooo`03o`000?oooooooooo0:;ooooo00Co0000oooooooooooo00002Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00001_ooool01Ol0
003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo0000h_ooool0033ooooo00?o0000
ooooooooool0X_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000Kooooo00Go0000oooooooooooo
ooooo`000006ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool0f?ooool0033o
oooo00?o0000ooooooooool0X_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001Oooool0
1Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo00001oooool2o`000=Wooooo
000`ooooo`?o0000X_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo00001oooool2o`00
0=Wooooo000`ooooo`03o`000?oooooooooo0:;ooooo00Go0000ooooooooooooooooo`000008oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?oooooo
ooooo`0000Oooooo0_l0003Iooooo`00<?ooool00ol0003oooooooooo`2Rooooo`05o`000?oooooo
ooooooooool000002?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool00000
1_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooo00000=Wooooo000`ooooo`03o`00
0?oooooooooo0:;ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000
ooooool00000fOooool0033ooooo00?o0000ooooooooool0UOooool2o`0000_ooooo00Go0000oooo
ooooooooooooo`000008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00
0006ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooool00000fOooool0033ooooo00?o
0000ooooooooool0C_ooool2onk^kP?ooooo0_o^k^hoooooo`?o00002_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo0_o^k^h00ooooooo0000ooooo`02onk^kP03ooooool0
003ooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oo
ooooooooooooool000001_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooo0000017o
oooo0_o^k^h3ooooo`;ok^k^C_ooool2onk^kP?ooooo0_o^k^i/ooooo`00<?ooool00ol0003ooooo
ooooo`18ooooo`0=odA4A?l0003o0000oc8b<_oMgMgoooooonk^k_mEEEGok^k^ooooooo^k^koEEEE
onk^kP03ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kS3ooooo00?o0000
ooooool000002_ooool00ol0003oooooooooo`02ooooo`Co000000co410@ooooooo^k^koEEEEonk^
k_l0003ok^k^oeEEEOo^k^koooooo`000?ooool4o`000008oa0@4?l0003oooooonk^k_lb<S;o0000
oc8b<_l00006ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool00004
ooooo`Go00001?ooool2ob4Q8@Gooooo00goA4A4o`000?l0003o<S8bomgMgOooooook^k^oeEEEOo^
k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;o
k^k^>?ooool5o`0000;ooooo00Ook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l00000
2?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^GOooool0033ooooo00?o0000ooooooooool0
Boooool02OmgMgOo<S8booooooooooook^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0`ooooo`03o`000?oooooo000000[ooooo00?o
0000ooooooooool00_ooool00ol0003oooooo`000004ooooo`05onk^k_mEEEGo0000oeEEEOo^k^h0
0_ooool01Ol0003ooooooooooooooooo000000;ooooo00Oo0000oooooomgMgOoV9RHoooooonHV9So
000000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Kooooo
00?o0000ooooool000001?ooool2ob4Q8@Sooooo00WoMgMgoc8b<_ooooooooooonk^k_mEEEGogMgM
oeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0>?oo
ool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Mooooo`00<?ooool00ol0003o
ooooooooo`1<ooooo`07o`000?oooooooooooooooooMgMgo0000omgMg@07ooooo`03o`000?oooooo
oooo00;ooooo00Go410@oooooooooooooooooa0@400`ooooo`04o`000?ooooooooooo`0000Wooooo
00?o0000ooooooooool00oooool2o`0000Gooooo00?ogMgMo`000?oMgMd00oooool01Ol0003ooooo
oooooooooooo000000;ooooo00?o0000ooooool@41000oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05
o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool00006ooooo`04o`000?oooooo
ooooo`0000Oooooo00?o0000ooooooooool01?ooool01ol0003ooooooooooooooooogMgMo`000?oM
gMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100>Oooool00onH
V9So8B4Qonk^kP05ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@
413ooooooooooooooooo410@05gooooo000`ooooo`03o`000?oooooooooo04_ooooo00WoMgMgoc8b
<_ooooooooooonk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool00000;oooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000oooo
ooooool00oooool2o`0000Cooooo00Gok^k^oeEEEOl0003oEEEEonk^kP02ooooo`05o`000?oooooo
ooooooooool000000_ooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go
0000ooooooooooooooooo`000005ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003o
ooooooooool00006ooooo`;o00001Oooool02OmgMgOo<S8booooooooooook^k^oeEEEOoMgMgoEEEE
onk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000jooooo`03
oiRHV?lQ8B7ok^k^00?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`00001Mooooo`00<?ooool00ol0003oooooooooo`18oooo
o`0=o`000?lQ8B7o0000oc8b<_o<c<coooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05oooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000_ooooo`05o`000?oooooo
ooooooooool000002Oooool00ol0003oooooooooo`03ooooo`;o00000oooool02Oo^k^koEEEEonk^
k_l0003ok^k^oeEEEOo^k^koooooo`000003ooooo`06o`000?ooooooooooo`000?oooooo00000ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0003ooooo
oooooooooooo000000Kooooo00Co0000oooooooooooo00001_ooool2o`0000;ooooo00go0000ob4Q
8Ol0003o<S8bolc<c?ooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000003_ooooo00_oMgMgofIVI_ooooooooooonk^
k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`00001Mooooo`00<?ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo
00?ooooo0_o^k^h3ooooo`;ok^k^1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@4100;oooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000ooooooooool00ooo
ool2o`0000?ooooo0_o^k^h00ooooooo0000ooooo`02onk^kP03ooooool0003ooooo00;ooooo00Ko
0000oooooooooooo0000ooooool@4103ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooo
ooooooooo`000005ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool0
0006ooooo`05o`000?oooooo0000ooooool000001Oooool2onk^kP?ooooo0_o^k^h5ooooo`03o`00
0?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400looooo`03o`000?oooooooooo00;o
k^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@
05gooooo000`ooooo`?o0000B?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`08ooooo`03o`000?oooooooooo02Cooooo00Go0000oooo
ooooooooooooo`000009ooooo`03o`000?oooooooooo00?ooooo0_l00005ooooo`03o`000?oooooo
oooo00?ooooo00Go0000ooooooooooooooooo`000002ooooo`07o`000?ooooooMgMgoiRHV?oooooo
V9RHo`000006ooooo`06o`000?oooooo0000o`000?oooooo00001_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0003ooooooooooooooooo000000Kooooo
00Co0000oooooooooooo00001_ooool01Ol0003oooooo`000?oooooo0000017ooooo00?o0000oooo
ooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo0_l0000^ooooo`05o`000?nj^[[o
oooooiRHV?l@41003_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2?ooool2o`0005?ooooo000`ooooo`03o`000?oooooooooo04Sooooo1?l0000<ooooo`03oeEEEOmV
IVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo02Cooooo
00Go0000ooooooooooooooooo`000009ooooo`03o`000?oooooooooo00;ooooo00?oEEEEo`000?l0
00001Oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooEEEEofIVI_l000000_ooool01ol0
003oooooonk^k_lb<S;o0000oc8b<_l000001_ooool2o`0000;ooooo0_l00006ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00Go0000ooooooooooooooooo`000005ooooo`05o`000?ooooooooooooooool0
00001?ooool00omEEEGo0000o`000002ooooo`03o`000?oooooooooo00Cooooo00Co0000ooooool0
003ooooo1?l0000<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP07
ooooo`04o`000?ooooooooooo`0002gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00<ooooo`03oeEE
EOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP07ooooo`04o`000?ooooooooooo`00
05;ooooo000`ooooo`03o`000?oooooooooo06Kooooo1?l00003ooooo`03o`000?oooooooooo02?o
oooo00Go0000ooooooooooooooooo`000009ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`06o`0000;ooooo0_l00006ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool000001Oooool01Ol0003ooooooooooooooooo000000Gooooo00Co0000oooooooooooo0000
7oooool4o`000005ooooool0003oooooooooool00000C?ooool4o`000005ooooool0003ooooooooo
ool00000D_ooool0033ooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Sooooo`05
o`000?ooooooooooooooool000002Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01?ooool4o`000003ooooool0003ooooo00Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`000005ooooo`05o`000?ooooooooooooooool000001Oooool01?l0003ooooooooo
ool00007ooooo`;o00006oooool3o`0005;ooooo0ol0001Cooooo`00<?ooool00ol0003ooooooooo
o`1[ooooo`04o`000?ooooooooooo`0001Gooooo0ol0000;ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01?ooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo
00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool00006ooooo`?o00007?ooool00ol0003oooooooooo`1Boooo
o`03o`000?oooooooooo05;ooooo000`ooooo`03o`000?oooooooooo06_ooooo1?l0000Eooooo`04
o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04oooo
o`06o`000?ooooooooooo`000?oooooo00001_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Gooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Ko
oooo00?o0000ooooool000007Oooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo057o
oooo000`ooooo`03o`000?oooooooooo08Cooooo00Co0000oooooooooooo00002_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001_ooool00ol0003oooooo`000036
ooooo`00<?ooool00ol0003oooooooooo`23ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001_oo
ool00ol0003oooooo`000007ooooo`;o0000Poooool00omgMgOoIVIVooooo`0]ooooo`03ofIVI_mg
MgOooooo00Oooooo000`ooooo`03o`000?oooooooooo08?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooool00005ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003ooooo
o`000022ooooo`03omgMgOl@413ok^k^02kooooo00?ok^k^oa0@4?oMgMd01oooool0033ooooo00?o
0000ooooooooool0Loooool3o`0000cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000Cooooo00Go0000ooooooooooooooooo`000005ooooo`04o`000?ooooooooooo`00
00Gooooo0ol0001Wooooo`;o00000_ooool2o`0000cooooo00?oEEEEoiRHV?ooool00_l00002oooo
o`07o`000?ooooooooooo`000?l@413ok^k^oeEEE@02o`000003odA4A?nj^[[ooooo00;ooooo00Go
V9RHo`000?l0003oA4A4okZj^P02ooooo`08onk^k_mEEEGo0000o`000?m4A4Co^[Zjooooool@4105
o`0000?ooooo00So410@oc8b<_l0003o0000oa0@4?nYZJWoQhN7ofIVIPOooooo000`ooooo`03o`00
0?oooooooooo073ooooo1?l00002ooooo`;o00002_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Co
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Gooooo00Co0000oooo
oooooooo00001Oooool00ol0003oooooo`000006ooooo`;o0000Goooool01_o^k^ko8B4QohN7Qonj
^[[o0000omgMg@cooooo00Go0000ooooooooooooooooo`000002ooooo`0;o`000?ooooooooooo`00
0?ooooooEEEEogMgMoooooook^k^ogMgMol@41000oooool01Ol@413o^[Zjonk^k_mgMgOo410@00;o
oooo00KoEEEEogMgMoooooook^k^ogMgMol@4103ooooo`03o`000?oooooooooo00Cooooo00So0000
ojVYZOoooooooooookZj^_l0003ok^k^o`0000Oooooo003oo`000;Co00003oooool01?oMgMgo0000
oa0@4?o<c<`=ooooo`05oc8b<_ooooooooooooooool000000_ooool01_l0003oooooooooool0003o
ooooo`0000Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Gooooo00Oo^[ZjohN7QomVIVKoIVIVoa0@4?oooooo000000Oooooo000:ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool02Oooool8o`0000[ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool00000
1Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo0_l00006ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooo`000005ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool2o`0000Gooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`;o0000
0_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000ooooool0
003o00001?ooool4o`0000Gooooo0ol000000ooooooo0000ooooo`0@ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Gooooo`04onk^k_lQ8B7o410@
onk^kPgooooo00Go<S8booooooooooooooooo`000002ooooo`05o`000?ooooooooooo`000?ooool0
1_l00003ooooo`03o`000?oooooooooo00Cooooo1_l00003ooooo`03o`000?oooooooooo00Cooooo
00So<S8bob4Q8OmgMgOoMgMgohN7Qoo^k^koooooo`0000Oooooo000:ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00?ooooo0_l00007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000001Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo0_l00006ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool2o`0000Gooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`;o00000_ooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Gooooo0ol0000Booooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo01Oooooo00Co8B4QogMgMomgMgOo<S8b3Oooool01Ol0003ok^k^oooooooooooo000000;oc<c<
00_o0000ojVYZOoMgMgo8B4QoooooomEEEGoQhN7onk^k_ooooooQhN7oc8b<P03ooooo`03o`000?oo
oooooooo00Cooooo00KoEEEEohN7Qoo^k^koooooohN7Qolb<S83ooooo`03o`000?lb<S;ogMgM00Co
oooo00So0000okZj^_ooooook^k^ogMgMol0003ok^k^o`0000Oooooo000`ooooo`03o`000?oooooo
oooo05_ooooo00?o0000ooooooooool07Oooool01Ol0003ooooooooooooooooo000000[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooo`000005ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
1Oooool01Ol0003ooooooooooooooooo000000Cooooo0_l000000ooooooo0000ooooo`05ooooo`?o
0000D_ooool00ol0003oooooooooo`0Fooooo`;o00000_ooool2o`0000cooooo00koEEEEogMgMooo
oooo410@o`000?lQ8B7o0000ogMgMol@413o0000ojVYZOooooook^k^oeEEE@;o000000CoA4A4onk^
k_oooooo410@1Ol00003ooooo`06onk^k_mEEEGo0000o`000?m4A4Cok^k^0_ooool2o`000004ojVY
ZOlQ8B7o0000ob4Q8@;ooooo00SoZJVYob4Q8Ol0003o0000oc8b<_l0003oMgMgoeEEE@Oooooo000`
ooooo`03o`000?oooooooooo07_ooooo1Ol0000:ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Gooooo00Go0000oooooooooooooooo
o`000005ooooo`03o`000?oooooo000008Kooooo00?ogMgMoa0@4?o^k^h04_ooool00ol0003ooooo
ooooo`0Iooooo`03onk^k_l@413ogMgM00Oooooo000`ooooo`03o`000?oooooooooo08[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
1Oooool01?l0003oooooooooool00006ooooo`03o`000?oooooo000008Oooooo00?oMgMgofIVI_oo
ool04Oooool00ol0003oooooooooo`0Iooooo`03ofIVI_mgMgOooooo00Oooooo000`ooooo`03o`00
0?oooooooooo08_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000001Oooool01?l0003oooooooooool00006ooooo`;o0000`_ooool0033o
oooo00?o0000ooooooooool0Roooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`000005ooooo`04o`000?ooooooooooo`000<[ooooo000`oooo
o`03o`000?oooooooooo08_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000001Oooool01?l0003oooooooooool0003:ooooo`00<?ooool0
0ol0003oooooooooo`2;ooooo`05o`000?ooooooooooooooool000002_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooool00000b_ooool0033ooooo00?o0000ooooooooool0S?oo
ool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`000006ooooo`04o`000?ooooooooooo`0000Kooooo0_l0003;ooooo`00<?ooool00ol0003o
ooooooooo`2<ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool0
0006ooooo`04o`000?ooooooooooo`0000Kooooo0_l0003;ooooo`00<?ooool3o`0008gooooo0ol0
000:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooo
oooooooo000000Kooooo00Co0000oooooooooooo00001_ooool00ol0003oooooo`00003Dooooo`00
<?ooool00ol0003oooooooooo`2=ooooo`;o00002oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`00
00Kooooo00?o0000ooooool00000e?ooool0033ooooo00?o0000ooooooooool0V_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000006oooo
o`04o`000?ooooooooooo`0000Kooooo00?o0000ooooool00000e?ooool0033ooooo00?o0000oooo
ooooool0V_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000oooo
ooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooool00000e?oo
ool0033ooooo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Kooooo
00?o0000ooooool00000e?ooool0033ooooo00?o0000ooooooooool0V_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000006ooooo`04o`00
0?ooooooooooo`0000Kooooo00?o0000ooooool00000e?ooool0033ooooo00?o0000ooooooooool0
V_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooo
ooooo`000006ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooool00000e?ooool0033o
oooo00?o0000ooooooooool0Voooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooooooo
ooooool000001_ooool01?l0003oooooooooool00007ooooo`;o0000e?ooool0033ooooo00?o0000
ooooooooool0Voooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool00000
1_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo0=?ooooo000`ooooo`03o`00
0?oooooooooo09_ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo0000
00Kooooo00?o0000ooooool00000g_ooool0033ooooo00?o0000ooooooooool0Voooool01?l0003o
ooooooooool00009ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000006
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooo`00003Nooooo`00<?ooool0
0ol0003oooooooooo`2Kooooo`04o`000?ooooooooooo`0000[ooooo00Go0000oooooooooooooooo
o`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooo
oooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo0000
0=kooooo000`ooooo`?o0000Voooool01?l0003oooooooooool0000:ooooo`05o`000?oooooooooo
ooooool000002?ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooooooo
o`000006ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooo`00003Nooooo`00
<?ooool00ol0003oooooooooo`2Kooooo`04o`000?ooooooooooo`0000[ooooo00Go0000oooooooo
ooooooooo`000008ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooo
oooo000000Kooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo00000=kooooo
000`ooooo`03o`000?oooooooooo09cooooo00?o0000ooooool000002_ooool01Ol0003ooooooooo
oooooooo000000Sooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooooooooooo
ool000001_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooool00000g_ooool0
033ooooo00?o0000ooooooooool0W?ooool2o`0000_ooooo00Go0000ooooooooooooooooo`000008
ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Kooooo
00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo00000=kooooo000`ooooo`03o`00
0?oooooooooo09cooooo0_l0000;ooooo`05o`000?ooooooooooooooool000002?ooool01Ol0003o
oooooooooooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04oooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool00006ooooo`03o`00
0?oooooo00000=kooooo000`ooooo`03o`000?oooooooooo0:Wooooo00Go0000oooooooooooooooo
o`000008ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00007ooooo`04o`000?oooooo
ooooo`0000Oooooo0_l0003Nooooo`00<?ooool00ol0003oooooooooo`2Yooooo`05o`000?oooooo
ooooooooool000002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooooooooooo
ooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool0
0007ooooo`;o0000g_ooool0033ooooo00?o0000ooooooooool0ZOooool01Ol0003ooooooooooooo
oooo000000Sooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool0
00001oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000006
ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00001oooool2o`000=kooooo
000`ooooo`03o`000?oooooooooo0:Wooooo00Go0000ooooooooooooooooo`000008ooooo`05o`00
0?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooo
ooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003ooooooooo
ool00007ooooo`04o`000?ooooooooooo`000>Oooooo000`ooooo`03o`000?oooooooooo0:Wooooo
00Go0000ooooooooooooooooo`000008ooooo`05o`000?ooooooooooooooool000001oooool01Ol0
003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oo
ooooooooooooool000001_ooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`00
0>Oooooo000`ooooo`03o`000?oooooooooo0:Wooooo00Go0000ooooooooooooooooo`000008oooo
o`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Go
0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003o
ooooooooool00007ooooo`04o`000?ooooooooooo`000>Oooooo000`ooooo`03o`000?oooooooooo
0:Wooooo00Go0000ooooooooooooooooo`000008ooooo`05o`000?ooooooooooooooool000001ooo
ool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`05
o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooo
00000>Sooooo000`ooooo`?o0000ZOooool01?l0003oooooooooool00009ooooo`05o`000?oooooo
ooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooooooooooo
ooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool00007
ooooo`03o`000?oooooo00000>Sooooo000`ooooo`03o`000?oooooooooo0:Wooooo00Co0000oooo
oooooooo00002Oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooooooooooooooo
o`000007ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo0000
00Kooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00003Xooooo`00<?ooool00ol0
003oooooooooo`2Yooooo`04o`000?ooooooooooo`0000Wooooo00Go0000ooooooooooooooooo`00
0007ooooo`05o`000?ooooooooooooooool000002?ooool01?l0003oooooooooool00007ooooo`05
o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooo
00000>Sooooo000`ooooo`03o`000?oooooooooo0:Wooooo00Co0000oooooooooooo00002Oooool0
1Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000008ooooo`04o`00
0?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?oooooooooo
o`0000Oooooo00?o0000ooooool00000j?ooool0033ooooo00?o0000ooooooooool0ZOooool01?l0
003oooooooooool00009ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooo
oooooooo000000Sooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo0000
00Kooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00003Xooooo`00<?ooool00ol0
003oooooooooo`2Yooooo`04o`000?ooooooooooo`0000Wooooo00Go0000ooooooooooooooooo`00
0007ooooo`05o`000?ooooooooooooooool000002?ooool01?l0003oooooooooool00007ooooo`05
o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooo
00000>Sooooo000?ooooo`;ok^k^0oooool2onk^kQ[ooooo00?o0000ooooooooool0Z_ooool00ol0
003oooooo`000009ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooo
oooo000000Sooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Ko
oooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00003Xooooo`002?ooool5o`0000;o
oooo00Ook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413oooooooooooo^
k^ko<S8bo`000?lb<S;ok^k^2oooool00ol0003oooooooooo`2Zooooo`03o`000?oooooo000000Wo
oooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000002?ooool0
1?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003ooooo
ooooool00007ooooo`03o`000?oooooo00000>Sooooo0008ooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@00oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00_ooooo00?o0000ooooooooool0Z_ooool00ol0003oooooo`000009
ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Sooooo
00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooo
oooooooo00002?ooool2o`000>Sooooo0009ooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?ogMgMo`00
0?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41002oooool0
0ol0003oooooooooo`2Zooooo`03o`000?oooooo000000Wooooo00Go0000ooooooooooooooooo`00
0007ooooo`05o`000?ooooooooooooooool000002?ooool01?l0003oooooooooool00007ooooo`05
o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool00008ooooo`;o0000j?ooool0
00[ooooo00?oV9RHob4Q8Oo^k^h00oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000000_ooooo00?o0000ooooooooool0Z_oo
ool00ol0003oooooo`000009ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooo
oooooooooooo000000Sooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo
000000Kooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`3Wooooo`002oooool0
2omgMgOoIVIVooooooooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000000_ooooo1?l0002Yooooo`;o00002_ooool0
1Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000008ooooo`04o`00
0?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?oooooooooo
o`000?;ooooo000<ooooo`03o`000?oooooooooo00;ok^k^0oooool2onk^kPGooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@00_ooooo00?o0000ooooooooool0Z_ooool2
o`0000[ooooo00Go0000ooooooooooooooooo`000008ooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00001oooool01?l0003oooooooooool00007ooooo`04o`000?oooooooooo
o`000?;ooooo0008ooooo`05o`000?nj^[[ooooooiRHV?l@41003_ooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ol0003oooooooooo`2Zooooo`;o00002_oo
ool01Ol0003ooooooooooooooooo000000Sooooo00Co0000oooooooooooo00002?ooool01?l0003o
ooooooooool00007ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo0000l_oo
ool000Sooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00<ooooo`03oeEEEOmVIVKo000000Cooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP03ooooo`;o00001_ooool00ol0003oooooooooo`2fooooo`04o`00
0?ooooooooooo`0000Wooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00007
ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo0000l_ooool002Oooooo00Co
0000oooooooooooo00001Oooool00ol0003oooooooooo`2fooooo`04o`000?ooooooooooo`0000Wo
oooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00007ooooo`04o`000?oooooo
ooooo`0000Sooooo00?o0000ooooool00000l_ooool002Oooooo00Co0000oooooooooooo00001Ooo
ool00ol0003oooooooooo`2fooooo`04o`000?ooooooooooo`0000Wooooo00Co0000oooooooooooo
00002?ooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000
ooooool00000l_ooool002Oooooo0ol00006ooooo`03o`000?oooooooooo0;Kooooo00Co0000oooo
oooooooo00002Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Oooooo
00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003booooo`00:?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo0;Kooooo00Co0000oooooooooooo00002Oooool01?l0003o
ooooooooool00008ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00002?oo
ool2o`000??ooooo000Yooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0]_ooool0
1?l0003oooooooooool00009ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo
00001oooool01?l0003oooooooooool00008ooooo`;o0000loooool0033ooooo00?o0000oooooooo
ool0]oooool00ol0003oooooo`000009ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooo
oooooooo00001oooool01?l0003oooooooooool00008ooooo`;o0000loooool0033ooooo00?o0000
ooooooooool0]oooool00ol0003oooooo`000009ooooo`04o`000?ooooooooooo`0000Sooooo00Co
0000oooooooooooo00001oooool01?l0003oooooooooool00008ooooo`;o0000loooool0033ooooo
00?o0000ooooooooool0]oooool00ol0003oooooo`000009ooooo`04o`000?ooooooooooo`0000So
oooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool00008ooooo`;o0000loooool0
033ooooo0ol0002gooooo`03o`000?oooooo000000Wooooo00Co0000oooooooooooo00002?ooool0
1?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Sooooo0_l0003cooooo`00<?oo
ool00ol0003oooooooooo`2gooooo`03o`000?oooooo000000Wooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo000000Sooooo0_l0003cooooo`00
<?ooool00ol0003oooooooooo`2gooooo`03o`000?oooooo000000Wooooo00Co0000oooooooooooo
00002?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo000000Sooooo0_l0003coooo
o`00<?ooool00ol0003oooooooooo`2gooooo`03o`000?oooooo000000Wooooo00Co0000oooooooo
oooo00002?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo000000Sooooo0_l0003c
ooooo`00<?ooool00ol0003oooooooooo`2gooooo`03o`000?oooooo000000Wooooo00Co0000oooo
oooooooo00002?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo000000Sooooo0_l0
003cooooo`00<?ooool00ol0003oooooooooo`2gooooo`03o`000?oooooo000000Wooooo00Co0000
oooooooooooo00002?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?gooooo
000`ooooo`03o`000?oooooooooo0;Oooooo00?o0000ooooool000002Oooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000oOooool0033ooooo
00?o0000ooooooooool0]oooool00ol0003oooooo`000009ooooo`04o`000?ooooooooooo`0000So
oooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003mooooo`00<?ooool00ol0003o
ooooooooo`2gooooo`03o`000?oooooo000000Wooooo00Co0000oooooooooooo00002?ooool01?l0
003oooooooooool00008ooooo`03o`000?oooooo00000?gooooo000`ooooo`03o`000?oooooooooo
0;Sooooo00?o0000ooooooooool02?ooool01?l0003oooooooooool00008ooooo`04o`000?oooooo
ooooo`0000Sooooo0_l0003nooooo`00<?ooool00ol0003oooooooooo`2hooooo`03o`000?oooooo
oooo00Sooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00008ooooo`;o0000
o_ooool0033ooooo00?o0000ooooooooool0`oooool01?l0003oooooooooool00008ooooo`04o`00
0?ooooooooooo`0000Sooooo0_l0003nooooo`00<?ooool3o`000<Cooooo0_l00009ooooo`03o`00
0?oooooo000000Wooooo0_l0003nooooo`00<?ooool00ol0003oooooooooo`34ooooo`;o00002Ooo
ool00ol0003oooooo`000009ooooo`;o0000o_ooool0033ooooo00?o0000ooooooooool0a?ooool2
o`0000Wooooo00?o0000ooooool000002Oooool2o`000?kooooo000`ooooo`03o`000?oooooooooo
0<Cooooo0_l00009ooooo`03o`000?oooooo000000Wooooo0_l0003nooooo`00<?ooool00ol0003o
ooooooooo`34ooooo`;o00002Oooool00ol0003oooooo`000009ooooo`;o0000o_ooool0033ooooo
00?o0000ooooooooool0a?ooool2o`0000Wooooo00?o0000ooooool000002Oooool2o`000?kooooo
000`ooooo`03o`000?oooooooooo0<Cooooo0_l0000:ooooo`;o00002_ooool00ol0003ooooooooo
o`3looooo`00<?ooool00ol0003oooooooooo`34ooooo`;o00002_ooool2o`000?oooooo2_ooool0
033ooooo00?o0000ooooooooool0a?ooool2o`0000[ooooo0_l0003oooooo`[ooooo000`ooooo`03
o`000?oooooooooo0<Cooooo0_l0000:ooooo`;o0000ooooool:ooooo`00<?ooool00ol0003ooooo
ooooo`34ooooo`;o00002_ooool2o`000?oooooo2_ooool0033ooooo00?o0000ooooooooool0a?oo
ool2o`0000[ooooo0_l0003oooooo`[ooooo000`ooooo`?o0000a?ooool2o`0000[ooooo0_l0003o
ooooo`[ooooo000`ooooo`03o`000?oooooooooo0=3ooooo0_l0003oooooo`[ooooo000`ooooo`03
o`000?oooooooooo0=3ooooo0_l0003oooooo`[ooooo000`ooooo`03o`000?oooooooooo0?oooooo
g?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3o
ooooomcooooo000?ooooo`;ok^k^0oooool2onk^kQ[ooooo00?o0000ooooooooool0oooooooLoooo
o`002_ooool2o`00000:oa0@4?ooooooooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP?ooooo
1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool00ol0003oooooooooo`3o
ooooomcooooo000;ooooo`03o`000?oooooooooo00;ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06
ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03o`000?oo
oooooooo0?oooooog?ooool000Sooooo1Ol00004ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00_ooooo00?o0000ooooooooool0oooo
oooLooooo`002?ooool01?m4A4CogMgMooooool00004ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h0
1_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000002oooool00ol0003o
ooooooooo`3oooooomcooooo0008ooooo`04omgMgOmEEEGoooooo`0000?ooooo00Ook^k^oeEEEOo^
k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000000_ooooo1?l0003oooooom_ooooo0009ooooo`03ogMgMoo<c<co000000?ooooo0_o^k^h3
ooooo`;ok^k^1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41002ooo
ool00ol0003oooooooooo`3oooooomcooooo0009ooooo`03onk^k_m4A4Co000000oooooo00?o0000
ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?o0000ooooooooool0oooo
oooLooooo`002_ooool00omgMgOo0000ooooo`0<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP03ooooo`;o00001_ooool00ol0003oooooooooo`3oooooomcooooo000W
ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool0oooooooLooooo`009oooool0
1?l0003oooooooooool00005ooooo`03o`000?oooooooooo0?oooooog?ooool002Oooooo0ol00006
ooooo`03o`000?oooooooooo0?oooooog?ooool002Sooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3oooooomcooooo000Yooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool3o`00
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooo
ooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000
ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03
o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?oo
ool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0
033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomco
oooo000`ooooo`?o0000oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`
ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLoooo
o`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooo
g?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0033ooooo0ol0003oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooo
ooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool00?ooooooooooool@
ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooo
oooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3o
oooo002Pooooo`;o00001?ooool00onj^[[o<S8booooo`04ooooo`;o00001_ooool00ol0003o^[Zj
ooooo`3ooooooeOooooo002Pooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`;o<S8boooooomHooooo`00SOooool3o`0000;ooooo00Ko<S8b
oa0@4?ooooooooooonk^k_mEEED2o`000003odA4A?nj^[[ooooo00?ooooo00?o0000ooooooooool0
0_ooool01OnHV9So410@o`000?l0003oZJVY00Cooooo00?o0000ooooooooool01?ooool00on7QhOo
0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X02Oooool01?l@413o0000odA4A?o<c<`6
ooooo`;o8B4Q1?ooool02oo^k^ko<S8bo`000?l@413oc<c<ooooooo<c<cok^k^ooooooo^k^koc<c<
00Cooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^4oooool01_l@413o<S8b
o`000?l0003o410@ojVYZ@;ooooo00Kok^k^oeEEEOl0003o0000odA4A?nj^[X3ooooo`05ofIVI_l0
003o0000odA4A?o<c<`0j?ooool008kooooo00Go0000ooooooooooooc<c<oa0@4003ooooo`06oeEE
EOmgMgOoooooonk^k_mgMgOo410@1?ooool00ol0003oooooooooo`02ooooo`06o`000?nYZJWoEEEE
oiRHV?mEEEGo^[Zj0oooool00ol0003oooooooooo`04ooooo`03olc<c?l0003o410@00cooooo00Ko
410@okZj^_o^k^koMgMgoa0@4?ooool6o`0000Cooooo00?oV9RHoa0@4?oMgMd01Oooool2ob4Q8@Co
oooo00_oEEEEogMgMoooooooV9RHob4Q8Oooooook^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`00
0?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Cooooo`06o`000?nYZJWooooooooo
oonj^[[o00000_ooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40;ooooo00KoIVIVogMgMooooooo
ooooohN7Qol@413Xooooo`00S_ooool01Ol0003ooooooooooomEEEGoQhN700?ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`02ooooo`06oc8b<_o^k^koV9RHoeEEEOoMgMgo410@0ooo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00kooooo00?oQhN7oeEEEOooool02_oo
ool01Ol0003ooooooooooooooooo000000;ooooo00?ogMgMo`000?oMgMd01oooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41005?ooool01Onj^[[oQhN7ofIVI_mVIVKo410@
00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3[ooooo`00S_ooool01Ol0003o
ooooomgMgOl0003ok^k^00?ooooo1_l00004ooooo`03o`000?oooooooooo00;ooooo00Oo^[ZjodA4
A?o<c<co8B4Qooooool@413oc<c<00;ooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`03ooooo`Ko00000_ooool01Oo<c<co8B4Qo`000?mEEEGo000000_ooooo00_o0000oiRHV?oooooo
V9RHob4Q8Oooooook^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`00000Cooooo`06oc8b<_lQ8B7oMgMgogMgMon7QhOok^k^0_ooool6o`00
00;ooooo00?o0000ooooooooool0joooool008kooooo0ol000000ol@413oV9RHooooo`02ooooo`06
oeEEEOn7QhOok^k^oooooon7QhOo<S8b1?ooool00ol0003oooooooooo`02ooooo`07onk^k_l0003o
ooooo`000?ooooooIVIVohN7Q`02ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
2oooool01OlQ8B7oQhN7oooooonHV9So000000_ooooo00_o0000oeEEEOl0003o410@olc<c?oooooo
c<c<onk^k_ooooook^k^olc<c006ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`00000Cooooo`06o`000?nj^[[oooooonk^k_mgMgOo00000_ooool01_mEEEGoQhN7onk^k_oo
ooooQhN7oc8b<P;ooooo00KoIVIVogMgMoooooooooooohN7Qol0003Xooooo`00S_ooool01Ol0003o
ooooooooooo<c<co000000?ooooo00Kok^k^oeEEEOl0003o0000odA4A?o^k^h4ooooo`03o`000?oo
oooooooo00;ooooo00CoIVIVoiRHV?oooooo<S8b0_nj^[X01?l0003oooooooooool0000Cooooo`03
oa0@4?l0003o000000?o00002_ooool01Ol0003ooooooooooooooooo000000_ooooo00?oEEEEohN7
Qoooool03_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41001oooool3
o`0000;ooooo0ol00004ooooo`06ojVYZOlQ8B7o0000o`000?lb<S;o00000_ooool01_o^k^koEEEE
o`000?l0003oA4A4onk^kP;ooooo00Kok^k^ofIVI_l0003o0000odA4A?l0003Xooooo`00S_ooool0
1Ol0003oooooooooooo<c<co000000gooooo00?o0000ooooooooool01Oooool00omVIVKoQhN7oooo
o`03ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02oooool01OlQ8B7oV9RHoooo
oomgMgOoEEEE00_ooooo00?ogMgMoa0@4?nHV9P03_ooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oo
oooo0_ooool008gooooo1?l000000ol@413oZJVYooooo`0<ooooo`;o00001_ooool00onYZJWoA4A4
ooooo`02ooooo`;o00005Oooool00ol0003oooooooooo`0;ooooo`05olc<c?l@413o0000oc8b<_o^
k^h03?ooool01?o<c<coA4A4o`000?l@410:ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP02ooooo`Co00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo0?oooooo0_ooool00?oooooo1_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
0?oooooo0_ooool00?oooooo1_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oo
oooo0_ooool00?oooooo1Oooool2o`0000?ooooo0_l0003oooooo`Cooooo003ooooooooooooo4?oo
ool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooo
ooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@oooo
o`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooo
oooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo
003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooo
oooo4?ooool00?ooooooooooool@ooooo`00\
\>"],
  ImageRangeCache->{{{0, 525.688}, {324.5, 0}} -> {-2.58312*^-7, -6.34248*^6, \
6.65005*^-9, 53093.5}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0.309017 5.42214e-08 [
[.32684 .29652 -16.5 -12.5 ]
[.32684 .29652 16.5 0 ]
[.54329 .29652 -16.5 -12.5 ]
[.54329 .29652 16.5 0 ]
[.75974 .29652 -22.5 -12.5 ]
[.75974 .29652 22.5 0 ]
[.97619 .29652 -16.5 -12.5 ]
[.97619 .29652 16.5 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 64 6 ]
[.09789 .09213 -34.5 -6.25 ]
[.09789 .09213 0 6.25 ]
[.09789 .20057 -34.5 -6.25 ]
[.09789 .20057 0 6.25 ]
[.09789 .41746 -28.5 -6.25 ]
[.09789 .41746 0 6.25 ]
[.09789 .5259 -28.5 -6.25 ]
[.09789 .5259 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -62.8125 0 ]
[.5 .63053 62.8125 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 .30902 m
.32684 .31527 L
s
gsave
.32684 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 .30902 m
.54329 .31527 L
s
gsave
.54329 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 .30902 m
.75974 .31527 L
s
gsave
.75974 .29652 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 .30902 m
.15368 .31277 L
s
.19697 .30902 m
.19697 .31277 L
s
.24026 .30902 m
.24026 .31277 L
s
.28355 .30902 m
.28355 .31277 L
s
.37013 .30902 m
.37013 .31277 L
s
.41342 .30902 m
.41342 .31277 L
s
.45671 .30902 m
.45671 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.58658 .30902 m
.58658 .31277 L
s
.62987 .30902 m
.62987 .31277 L
s
.67316 .30902 m
.67316 .31277 L
s
.71645 .30902 m
.71645 .31277 L
s
.80303 .30902 m
.80303 .31277 L
s
.84632 .30902 m
.84632 .31277 L
s
.88961 .30902 m
.88961 .31277 L
s
.9329 .30902 m
.9329 .31277 L
s
.0671 .30902 m
.0671 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09213 m
.11664 .09213 L
s
gsave
.09789 .09213 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .20057 m
.11664 .20057 L
s
gsave
.09789 .20057 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .41746 m
.11664 .41746 L
s
gsave
.09789 .41746 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .5259 m
.11664 .5259 L
s
gsave
.09789 .5259 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.11039 .11924 m
.11414 .11924 L
s
.11039 .14635 m
.11414 .14635 L
s
.11039 .17346 m
.11414 .17346 L
s
.11039 .22768 m
.11414 .22768 L
s
.11039 .2548 m
.11414 .2548 L
s
.11039 .28191 m
.11414 .28191 L
s
.11039 .33613 m
.11414 .33613 L
s
.11039 .36324 m
.11414 .36324 L
s
.11039 .39035 m
.11414 .39035 L
s
.11039 .44457 m
.11414 .44457 L
s
.11039 .47168 m
.11414 .47168 L
s
.11039 .49879 m
.11414 .49879 L
s
.11039 .06502 m
.11414 .06502 L
s
.11039 .03791 m
.11414 .03791 L
s
.11039 .0108 m
.11414 .0108 L
s
.11039 .55301 m
.11414 .55301 L
s
.11039 .58012 m
.11414 .58012 L
s
.11039 .60723 m
.11414 .60723 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -123.812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.812 moveto
(@) show
81.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.812 moveto
(D) show
93.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(9.8) show
135.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
141.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
153.000 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
157.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
166.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
184.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02691 .30902 L
.03029 .30902 L
.03347 .30902 L
.03652 .30902 L
.03823 .30902 L
.03978 .30902 L
.04055 .30902 L
.04098 .30902 L
.04138 .30902 L
.04155 .30902 L
.04174 .30902 L
.04184 .30902 L
.04194 .30902 L
.04203 .30902 L
.04212 .30902 L
.04222 .30902 L
.04231 .30902 L
.04237 .30902 L
.04242 .30902 L
.04252 .30902 L
.04262 .30902 L
.04271 .30902 L
.0428 .30902 L
.04291 .30902 L
.04311 .30902 L
.0433 .30902 L
.04367 .30902 L
.04406 .30902 L
.04448 .30902 L
.04525 .30902 L
.04595 .30902 L
.04673 .30902 L
.04745 .30902 L
.04825 .30902 L
.0491 .30902 L
.05071 .30902 L
.05152 .30902 L
.05241 .30902 L
.05398 .30902 L
.05566 .30902 L
.05738 .30902 L
.05899 .30902 L
.0606 .30902 L
.06208 .30902 L
.06359 .30902 L
.06524 .30902 L
.06681 .30902 L
.06848 .30902 L
.07007 .30902 L
Mistroke
.0718 .30902 L
.07499 .30902 L
.07657 .30902 L
.07825 .30902 L
.07986 .30902 L
.0816 .30902 L
.08482 .30902 L
.08642 .30902 L
.08811 .30902 L
.09116 .30902 L
.09441 .30902 L
.09754 .30902 L
.10086 .30902 L
.10407 .30902 L
.10715 .30902 L
.11042 .30902 L
.11358 .30902 L
.11661 .30902 L
.11985 .30902 L
.12296 .30902 L
.12626 .30902 L
.12945 .30902 L
.13251 .30902 L
.13409 .30902 L
.13497 .30902 L
.13577 .30902 L
.13616 .30902 L
.13637 .30902 L
.13657 .30902 L
.13676 .30902 L
.13693 .30902 L
.13701 .30902 L
.13711 .30902 L
.13722 .30902 L
.13731 .30902 L
.13742 .30902 L
.13751 .30902 L
.13762 .30902 L
.13768 .30902 L
.13773 .30902 L
.13784 .30902 L
.13795 .30902 L
.13818 .30902 L
.13838 .30902 L
.1386 .30902 L
.13898 .30902 L
.13941 .30902 L
.1398 .30902 L
.14069 .30902 L
.14148 .30902 L
Mistroke
.14231 .30902 L
.14307 .30902 L
.14388 .30902 L
.14535 .30902 L
.14705 .30902 L
.14866 .30902 L
.15025 .30902 L
.15173 .30902 L
.15487 .30902 L
.15659 .30902 L
.15821 .30902 L
.16131 .30902 L
.1646 .30902 L
.16777 .30902 L
.17082 .30902 L
.17407 .30902 L
.17719 .30902 L
.18051 .30902 L
.18217 .30902 L
.18371 .30902 L
.1852 .30902 L
.18596 .30902 L
.18636 .30902 L
.18679 .30902 L
.18718 .30902 L
.1874 .30902 L
.1876 .30902 L
.1877 .30902 L
.18779 .30902 L
.18787 .30902 L
.18796 .30902 L
.18806 .30902 L
.18814 .30902 L
.18824 .30902 L
.18834 .30902 L
.1884 .30902 L
.18846 .30902 L
.18851 .30902 L
.18856 .30902 L
.18876 .30902 L
.18888 .30902 L
.18898 .30902 L
.18921 .30902 L
.18963 .30902 L
.19002 .30902 L
.19039 .30902 L
.1908 .30902 L
.19163 .30902 L
.1924 .30902 L
.19312 .30902 L
Mistroke
.19476 .30902 L
.19625 .30902 L
.19778 .30902 L
.19945 .30902 L
.20101 .30902 L
.20273 .30902 L
.20589 .30902 L
.20912 .30902 L
.21223 .30902 L
.21554 .30902 L
.21873 .30902 L
.22179 .30902 L
.2235 .30902 L
.22505 .30902 L
.22583 .30902 L
.22627 .30902 L
.22667 .30902 L
.22702 .30902 L
.22722 .30902 L
.22741 .30902 L
.22751 .30902 L
.22761 .30902 L
.22769 .30902 L
.22779 .30902 L
.22789 .30902 L
.22794 .30902 L
.228 .30902 L
.2281 .30902 L
.22819 .30902 L
.22829 .30902 L
.22839 .30902 L
.22857 .30902 L
.22879 .30902 L
.22898 .30902 L
.22941 .30902 L
.22981 .30902 L
.23052 .30902 L
.2313 .30902 L
.23206 .30902 L
.23289 .30902 L
.23458 .30902 L
.23614 .30902 L
.23782 .30902 L
.24113 .30902 L
.24432 .30902 L
.24739 .30902 L
.25065 .30902 L
.2538 .30902 L
.2554 .30902 L
.25714 .30902 L
Mistroke
.25796 .30903 L
.25882 .30903 L
.25955 .30903 L
.25997 .30903 L
.26036 .30903 L
.26055 .30903 L
.26076 .30903 L
.26087 .30903 L
.26099 .30903 L
.2611 .30903 L
.2612 .30903 L
.2613 .30903 L
.2614 .30903 L
.2615 .30903 L
.26156 .30903 L
.26161 .30903 L
.26171 .30903 L
.2618 .30903 L
.2619 .30903 L
.26199 .30903 L
.26218 .30903 L
.26237 .30903 L
.26271 .30903 L
.26308 .30903 L
.26349 .30903 L
.2643 .30903 L
.26505 .30903 L
.26591 .30902 L
.26673 .30902 L
.26832 .30902 L
.2698 .30902 L
.27295 .30901 L
.27597 .30901 L
.2792 .309 L
.2823 .30899 L
.2856 .30898 L
.28724 .30897 L
.28805 .30897 L
.28877 .30897 L
.28914 .30897 L
.28953 .30897 L
.28988 .30897 L
.29025 .30897 L
.29046 .30897 L
.29065 .30897 L
.29085 .30897 L
.29097 .30897 L
.29107 .30897 L
.29117 .30897 L
.29126 .30897 L
Mistroke
.29136 .30897 L
.29146 .30897 L
.29156 .30897 L
.29165 .30897 L
.29183 .30897 L
.29202 .30897 L
.2922 .30897 L
.29261 .30897 L
.29301 .30897 L
.29344 .30897 L
.29422 .30897 L
.29493 .30897 L
.29646 .30898 L
.29732 .30898 L
.29812 .30899 L
.30128 .30902 L
.30431 .30905 L
.30753 .3091 L
.31064 .30915 L
.31222 .30917 L
.31394 .30919 L
.31474 .3092 L
.31559 .3092 L
.31601 .30921 L
.3164 .30921 L
.31677 .30921 L
.31712 .30921 L
.3175 .30921 L
.31769 .30921 L
.3178 .30921 L
.31791 .30921 L
.31801 .30922 L
.31811 .30922 L
.31816 .30922 L
.31822 .30922 L
.31827 .30922 L
.31833 .30922 L
.31843 .30922 L
.31852 .30922 L
.31862 .30921 L
.31873 .30921 L
.31891 .30921 L
.3191 .30921 L
.31944 .30921 L
.31984 .30921 L
.32021 .30921 L
.32101 .3092 L
.32175 .30919 L
.32256 .30918 L
.32342 .30916 L
Mistroke
.32498 .30912 L
.32645 .30908 L
.32956 .30895 L
.33287 .30878 L
.33605 .3086 L
.33766 .30852 L
.33912 .30846 L
.33987 .30843 L
.34069 .30841 L
.34115 .3084 L
.34156 .30839 L
.34196 .30838 L
.34217 .30838 L
.34238 .30838 L
.34257 .30838 L
.34268 .30838 L
.34278 .30838 L
.34286 .30838 L
.34295 .30838 L
.34305 .30838 L
.34314 .30838 L
.34324 .30838 L
.34334 .30838 L
.34343 .30838 L
.34353 .30838 L
.34364 .30838 L
.34375 .30838 L
.34395 .30838 L
.34435 .30839 L
.34472 .30839 L
.34542 .30841 L
.3462 .30844 L
.34703 .30848 L
.34851 .30858 L
.35008 .30872 L
.35155 .30888 L
.35466 .30932 L
.35797 .30986 L
.35963 .31013 L
.36116 .31035 L
.36274 .31055 L
.36352 .31062 L
.36423 .31067 L
.36461 .3107 L
.36502 .31072 L
.36522 .31072 L
.36544 .31073 L
.36556 .31073 L
.36567 .31074 L
.36577 .31074 L
Mistroke
.36588 .31074 L
.36597 .31074 L
.36607 .31074 L
.36616 .31074 L
.36625 .31074 L
.36635 .31074 L
.36644 .31074 L
.36654 .31074 L
.36659 .31074 L
.36665 .31074 L
.36683 .31074 L
.36702 .31073 L
.36737 .31072 L
.36758 .31071 L
.3678 .3107 L
.3682 .31067 L
.36909 .31059 L
.36986 .31049 L
.37071 .31034 L
.37227 .31001 L
.37395 .30953 L
.37726 .30831 L
.38046 .30696 L
.38353 .3058 L
.38511 .30536 L
.38557 .30526 L
.386 .30518 L
.38638 .30512 L
.3868 .30507 L
.38699 .30505 L
.38721 .30503 L
.3874 .30502 L
.38758 .30501 L
.38769 .30501 L
.38779 .305 L
.38784 .305 L
.3879 .305 L
.38796 .305 L
.38801 .305 L
.38811 .305 L
.38821 .305 L
.38826 .30501 L
.38831 .30501 L
.38841 .30501 L
.38861 .30502 L
.38879 .30503 L
.38899 .30505 L
.38918 .30507 L
.38953 .30512 L
.3899 .30518 L
Mistroke
.39066 .30535 L
.3915 .30562 L
.39237 .30597 L
.39319 .30637 L
.39631 .30851 L
.39963 .31151 L
.40283 .31446 L
.40429 .31561 L
.40512 .31616 L
.40591 .31659 L
.40667 .31692 L
.4071 .31706 L
.4073 .31711 L
.40749 .31716 L
.4077 .3172 L
.40789 .31723 L
.40809 .31725 L
.40821 .31726 L
.40826 .31727 L
.40831 .31727 L
.40842 .31727 L
.40848 .31727 L
.40853 .31728 L
.40863 .31728 L
.40873 .31727 L
.40879 .31727 L
.40885 .31727 L
.40896 .31726 L
.40908 .31725 L
.40918 .31724 L
.40939 .3172 L
.40959 .31716 L
.41003 .31704 L
.41042 .3169 L
.41083 .31671 L
.41154 .3163 L
.41232 .3157 L
.41389 .31409 L
.41557 .31179 L
.4189 .30597 L
.4221 .29995 L
.42356 .29753 L
.4244 .29635 L
.42518 .29541 L
.42594 .29467 L
.42634 .29437 L
.42677 .2941 L
.4272 .2939 L
.42743 .29382 L
.42754 .29379 L
Mistroke
.42765 .29376 L
.42775 .29375 L
.4278 .29374 L
.42785 .29373 L
.42795 .29372 L
.42804 .29372 L
.42814 .29371 L
.42824 .29372 L
.42834 .29372 L
.4284 .29373 L
.42846 .29374 L
.42864 .29377 L
.42874 .29379 L
.42884 .29382 L
.42905 .2939 L
.42925 .29398 L
.4296 .29418 L
.42999 .29446 L
.4308 .29528 L
.43165 .29646 L
.43323 .2995 L
.43471 .30324 L
.43784 .31326 L
.44117 .32462 L
.44283 .32941 L
.44357 .33115 L
.44437 .33272 L
.44474 .33332 L
.44515 .33386 L
.44549 .33425 L
.44587 .33457 L
.44609 .33471 L
.4462 .33477 L
.44629 .33481 L
.44639 .33485 L
.44649 .33488 L
.44655 .33489 L
.4466 .3349 L
.4467 .33492 L
.44679 .33492 L
.44687 .33492 L
.44697 .33492 L
.44707 .3349 L
.44717 .33488 L
.44727 .33485 L
.44746 .33477 L
.44765 .33466 L
.44783 .33453 L
.44823 .33414 L
.44863 .33363 L
Mistroke
.44906 .33294 L
.44983 .33131 L
.45053 .32939 L
.45205 .32398 L
.45372 .31631 L
.45697 .298 L
.46011 .28081 L
.46093 .27712 L
.46182 .27373 L
.46267 .27123 L
.46307 .2703 L
.46344 .26961 L
.46382 .26907 L
.46402 .26885 L
.46422 .26869 L
.46431 .26863 L
.4644 .26858 L
.46449 .26855 L
.46457 .26852 L
.46466 .2685 L
.46476 .2685 L
.46486 .2685 L
.46495 .26852 L
.46504 .26855 L
.46515 .2686 L
.46524 .26865 L
.46533 .26871 L
.46555 .26891 L
.46575 .26915 L
.46616 .26981 L
.4666 .27077 L
.46736 .27304 L
.4682 .27643 L
.46988 .28595 L
.47312 .31178 L
.47623 .33967 L
.47781 .35201 L
.47864 .35745 L
.47953 .36218 L
.47998 .36407 L
.4804 .36554 L
.48078 .36659 L
.48097 .36703 L
.48119 .36742 L
.48139 .36771 L
.48157 .36791 L
.48168 .368 L
.48177 .36805 L
.48183 .36807 L
.48188 .36809 L
Mistroke
.48199 .36811 L
.48207 .3681 L
.48217 .36808 L
.48227 .36804 L
.48237 .36798 L
.48246 .36791 L
.48254 .36782 L
.48272 .36759 L
.48292 .36726 L
.4831 .36688 L
.48351 .36578 L
.48388 .36446 L
.48424 .36294 L
.48504 .35857 L
.4859 .35241 L
.48749 .33753 L
.48918 .31784 L
.49222 .27806 L
.49391 .2575 L
.49546 .24224 L
.49622 .23646 L
.49663 .23397 L
.49706 .23177 L
.49747 .23012 L
.49784 .22903 L
.49802 .22865 L
.49812 .22848 L
.49822 .22834 L
.49831 .22824 L
.4984 .22815 L
.49849 .2281 L
.49857 .22807 L
.49868 .22806 L
.49873 .22807 L
.49878 .22808 L
.49888 .22814 L
.49898 .22822 L
.49909 .22834 L
.49919 .22849 L
.49941 .22893 L
.4996 .22941 L
.4998 .23005 L
.50021 .23173 L
.50058 .23371 L
.50098 .23629 L
.5017 .24211 L
.50342 .26173 L
.50503 .2863 L
.50812 .34128 L
.50969 .36811 L
Mistroke
.51052 .38076 L
.51141 .39257 L
.51227 .40177 L
.51305 .40808 L
.51342 .41032 L
.51362 .4113 L
.51383 .41216 L
.51402 .41277 L
.51411 .41304 L
.51422 .41329 L
.51432 .41348 L
.5144 .41362 L
.51449 .41373 L
.51458 .41381 L
.51468 .41386 L
.51473 .41387 L
.51478 .41386 L
.51488 .41383 L
.51498 .41376 L
.51507 .41366 L
.51515 .41353 L
.51534 .41314 L
.51555 .41254 L
.51574 .41184 L
.51616 .40972 L
.51652 .40732 L
.51691 .40409 L
.51763 .3966 L
.51921 .37338 L
.52089 .34029 L
.52423 .26315 L
.52591 .22736 L
.52664 .2139 L
.52745 .20128 L
.52823 .1916 L
.5286 .18793 L
.52895 .18507 L
.52915 .18377 L
.52936 .18257 L
.52953 .18174 L
.52972 .181 L
.52982 .1807 L
.52993 .18043 L
.52999 .18031 L
.53004 .18021 L
.5301 .18013 L
.53015 .18007 L
.53024 .18 L
.53034 .17997 L
.53044 .17999 L
Mistroke
.53054 .18008 L
.53064 .18021 L
.53075 .18042 L
.53087 .18071 L
.53097 .18104 L
.53116 .18179 L
.53137 .18281 L
.53183 .18598 L
.53226 .1899 L
.53309 .20027 L
.53387 .21326 L
.53547 .24767 L
.53694 .28684 L
.54009 .37686 L
.5417 .41645 L
.54254 .43321 L
.543 .44088 L
.54343 .44699 L
.54385 .45192 L
.54423 .45548 L
.54444 .45701 L
.54466 .45837 L
.54478 .45898 L
.54489 .45946 L
.545 .45985 L
.54511 .46017 L
.54521 .46038 L
.54529 .46052 L
.54538 .4606 L
.54547 .46064 L
.54556 .46062 L
.54565 .46054 L
.54575 .46039 L
.54586 .46016 L
.54596 .45987 L
.54607 .45947 L
.54628 .45853 L
.54665 .45604 L
.54705 .45242 L
.54741 .44812 L
.54825 .43513 L
.54907 .41845 L
.54994 .39664 L
.55326 .29037 L
.55492 .23476 L
.55646 .19007 L
.55722 .17187 L
.55795 .15796 L
.5587 .14719 L
.5591 .14313 L
Mistroke
.55932 .14138 L
.55953 .14011 L
.55963 .13961 L
.55973 .13921 L
.55982 .13891 L
.55991 .13865 L
.56001 .13845 L
.5601 .13834 L
.5602 .1383 L
.56026 .13831 L
.56032 .13835 L
.56041 .13847 L
.5605 .13865 L
.56058 .13886 L
.56067 .13915 L
.56086 .14003 L
.56105 .14112 L
.56147 .14466 L
.56185 .14907 L
.56271 .16299 L
.56351 .18087 L
.56425 .20097 L
.56593 .25657 L
.5691 .37777 L
.57069 .43168 L
.57139 .45115 L
.57215 .46867 L
.57256 .47652 L
.57295 .48255 L
.57332 .48714 L
.57371 .49074 L
.57391 .49204 L
.57402 .49258 L
.57413 .49305 L
.57422 .49337 L
.57433 .49363 L
.57442 .49378 L
.57451 .49384 L
.57457 .49384 L
.57463 .49381 L
.57468 .49375 L
.57474 .49367 L
.57483 .49346 L
.57494 .49313 L
.57505 .49267 L
.57515 .49214 L
.57539 .49056 L
.5756 .48877 L
.57579 .48676 L
.57623 .48099 L
Mistroke
.57702 .46634 L
.57774 .44865 L
.57851 .42575 L
.58185 .2946 L
.58353 .22554 L
.58508 .17162 L
.58586 .15006 L
.58659 .13433 L
.58695 .12814 L
.58735 .12289 L
.58757 .12055 L
.58778 .11878 L
.58797 .11756 L
.58808 .11703 L
.58818 .11664 L
.58828 .11635 L
.58837 .11616 L
.58846 .11607 L
.58855 .11605 L
.58865 .11613 L
.58871 .11621 L
.58876 .11632 L
.58886 .1166 L
.58895 .11696 L
.58913 .1179 L
.5893 .11905 L
.58968 .12267 L
.59006 .12777 L
.59048 .13496 L
.59134 .15434 L
.5929 .20475 L
.59458 .27368 L
.59617 .34428 L
.5979 .41582 L
.5987 .4441 L
.59956 .46907 L
.60029 .48548 L
.60071 .49261 L
.6011 .49775 L
.60128 .49962 L
.60147 .50125 L
.60158 .502 L
.60169 .50258 L
.60178 .50302 L
.60188 .50339 L
.60194 .50353 L
.60199 .50365 L
.60209 .50379 L
.60215 .50382 L
.6022 .50382 L
Mistroke
.60226 .50379 L
.60231 .50373 L
.60241 .50353 L
.60247 .50338 L
.60252 .5032 L
.60261 .50281 L
.60272 .50228 L
.60291 .50098 L
.60309 .49939 L
.60343 .4955 L
.60383 .48947 L
.6042 .48255 L
.60498 .46359 L
.60571 .44124 L
.60737 .37741 L
.6105 .23863 L
.61209 .17811 L
.61299 .15169 L
.61342 .14155 L
.61382 .13362 L
.61421 .12753 L
.61456 .12329 L
.61475 .12153 L
.61495 .12011 L
.61506 .11954 L
.61516 .11911 L
.61526 .11876 L
.61532 .11862 L
.61538 .11852 L
.61548 .11843 L
.61553 .11842 L
.61559 .11845 L
.61569 .11859 L
.61578 .11881 L
.61584 .119 L
.6159 .1192 L
.616 .11968 L
.61623 .12114 L
.61642 .12286 L
.61661 .12483 L
.61703 .13059 L
.6174 .13718 L
.6178 .14578 L
.61852 .16504 L
.62017 .22363 L
.62347 .36726 L
.62427 .39937 L
.62512 .42984 L
.62585 .45198 L
.62665 .47076 L
Mistroke
.62708 .47836 L
.62747 .48373 L
.62767 .48579 L
.62785 .48736 L
.62804 .48862 L
.62814 .48914 L
.62825 .48957 L
.62835 .48984 L
.62844 .49001 L
.62853 .49009 L
.62864 .49007 L
.62874 .48994 L
.62883 .48972 L
.62892 .48944 L
.62901 .48905 L
.62919 .48805 L
.62937 .48664 L
.62971 .48322 L
.6301 .47764 L
.63047 .47119 L
.63128 .45226 L
.63275 .40486 L
.63595 .27255 L
.63742 .21599 L
.63825 .18913 L
.63903 .1687 L
.63979 .15394 L
.64 .15087 L
.64022 .1481 L
.64043 .14594 L
.64062 .14436 L
.64082 .14306 L
.64093 .14252 L
.64104 .14213 L
.64113 .14187 L
.64122 .14171 L
.64132 .14164 L
.64142 .14167 L
.64153 .14181 L
.64159 .14193 L
.64164 .14208 L
.64174 .14245 L
.64184 .14291 L
.64206 .14428 L
.6423 .14633 L
.64273 .1514 L
.64314 .15777 L
.64389 .17356 L
.6447 .19563 L
.64557 .22431 L
Mistroke
.64887 .35179 L
.64966 .3805 L
.65051 .40767 L
.65125 .42731 L
.65204 .4438 L
.65247 .45034 L
.65266 .45269 L
.65286 .4549 L
.65305 .4565 L
.65324 .45787 L
.65335 .45847 L
.65345 .45892 L
.65355 .45928 L
.65364 .45954 L
.65373 .4597 L
.65382 .45978 L
.65391 .45978 L
.654 .45971 L
.65409 .45957 L
.65416 .45938 L
.65425 .45911 L
.65434 .45875 L
.65452 .45775 L
.6547 .45651 L
.6551 .45264 L
.6555 .44729 L
.65593 .43989 L
.65673 .42256 L
.65822 .37912 L
.65977 .32465 L
.66149 .26395 L
.66227 .23917 L
.66311 .21601 L
.66391 .19844 L
.66464 .18659 L
.66502 .18218 L
.66523 .18028 L
.66543 .17883 L
.66561 .17779 L
.66571 .17734 L
.66581 .177 L
.66589 .17678 L
.66598 .17661 L
.66607 .1765 L
.66616 .17647 L
.66626 .17651 L
.66632 .17658 L
.66637 .17667 L
.66647 .1769 L
.66658 .17724 L
Mistroke
.66678 .17815 L
.66696 .17928 L
.66717 .18095 L
.6674 .18319 L
.66782 .18835 L
.66858 .20124 L
.66942 .21989 L
.67111 .26798 L
.67281 .32212 L
.67436 .36766 L
.67513 .38659 L
.67596 .40321 L
.67635 .40926 L
.67675 .41452 L
.6771 .41802 L
.6773 .4196 L
.67748 .4208 L
.67767 .42174 L
.67777 .42213 L
.67788 .42246 L
.67793 .42259 L
.67799 .4227 L
.6781 .42285 L
.6782 .4229 L
.6783 .42287 L
.67838 .42278 L
.67847 .42265 L
.67856 .42243 L
.67866 .42213 L
.67886 .42129 L
.67904 .42025 L
.67945 .41699 L
.6799 .41205 L
.68071 .39961 L
.68155 .38295 L
.6823 .36513 L
.68398 .31978 L
.68566 .27456 L
.6864 .25703 L
.68721 .24054 L
.68799 .22788 L
.68836 .22313 L
.68872 .21947 L
.68891 .21782 L
.68912 .21632 L
.68929 .21529 L
.68948 .21441 L
.68959 .21402 L
.68969 .21374 L
.6898 .21351 L
Mistroke
.68986 .21341 L
.68991 .21335 L
.69001 .21329 L
.69011 .21329 L
.69021 .21336 L
.69031 .21349 L
.69041 .2137 L
.69052 .21401 L
.69071 .21475 L
.69092 .21583 L
.69116 .21734 L
.69157 .2209 L
.69195 .22516 L
.69267 .23533 L
.69345 .249 L
.69677 .32371 L
.69757 .3412 L
.69843 .35762 L
.69922 .37016 L
.69961 .37519 L
.69997 .3791 L
.7003 .38215 L
.70067 .38476 L
.70086 .38581 L
.70104 .38659 L
.70123 .38721 L
.70133 .38747 L
.70143 .38765 L
.70153 .38778 L
.70158 .38782 L
.70164 .38785 L
.70173 .38786 L
.70183 .38781 L
.70188 .38776 L
.70194 .3877 L
.70203 .38753 L
.70214 .38729 L
.70226 .38695 L
.70246 .3862 L
.70266 .38516 L
.70304 .38269 L
.70347 .37896 L
.70387 .37473 L
.70476 .36269 L
.70638 .33444 L
.70803 .30255 L
.70956 .27548 L
.71031 .26452 L
.71103 .25619 L
.71143 .25254 L
Mistroke
.71186 .2494 L
.71205 .24829 L
.71225 .24731 L
.71242 .24662 L
.71261 .24604 L
.71271 .2458 L
.7128 .24563 L
.7129 .24549 L
.713 .24539 L
.7131 .24535 L
.71319 .24535 L
.71327 .24539 L
.71336 .24546 L
.71346 .24559 L
.71357 .24579 L
.71368 .24605 L
.71379 .24635 L
.71399 .24706 L
.71418 .24791 L
.71455 .25003 L
.71488 .25248 L
.71564 .25963 L
.71724 .28049 L
.71872 .30359 L
.72034 .32832 L
.72114 .33873 L
.72187 .34673 L
.72258 .35279 L
.72293 .35514 L
.72332 .35714 L
.72353 .35795 L
.72372 .35854 L
.72382 .35881 L
.72393 .35904 L
.72404 .35922 L
.72414 .35935 L
.72423 .35943 L
.72431 .35947 L
.7244 .35949 L
.7245 .35947 L
.72461 .3594 L
.72471 .3593 L
.7248 .35918 L
.72489 .35901 L
.7251 .35853 L
.72532 .35783 L
.72572 .35609 L
.72611 .35385 L
.72647 .35135 L
.72816 .33497 L
Mistroke
.7298 .31471 L
.73133 .29592 L
.7328 .2812 L
.73322 .27793 L
.73363 .27531 L
.73401 .27323 L
.73438 .27171 L
.73457 .27108 L
.73475 .2706 L
.73494 .27019 L
.73505 .27003 L
.73515 .26989 L
.73525 .2698 L
.73536 .26974 L
.73546 .26971 L
.73555 .26972 L
.7356 .26973 L
.73565 .26976 L
.73571 .26979 L
.73577 .26984 L
.73587 .26995 L
.73598 .2701 L
.73617 .27046 L
.73635 .27088 L
.73674 .27218 L
.73711 .27378 L
.73746 .27563 L
.73905 .28754 L
.74053 .30171 L
.74204 .3165 L
.74284 .32348 L
.74367 .32973 L
.7441 .33238 L
.74457 .33482 L
.745 .33658 L
.7454 .33781 L
.74561 .3383 L
.74581 .33865 L
.74599 .33889 L
.74609 .33898 L
.74618 .33905 L
.74628 .33909 L
.74637 .33911 L
.74648 .3391 L
.74653 .33909 L
.74659 .33907 L
.74669 .339 L
.74675 .33896 L
.74681 .3389 L
.74702 .33864 L
Mistroke
.74723 .33826 L
.74742 .33781 L
.74787 .33649 L
.74825 .33498 L
.74866 .33306 L
.75016 .3238 L
.7532 .30107 L
.75401 .29597 L
.75477 .29199 L
.75519 .2902 L
.75565 .28863 L
.75585 .28806 L
.75606 .28755 L
.75625 .28718 L
.75645 .28685 L
.75664 .28662 L
.75674 .28652 L
.75684 .28645 L
.75693 .2864 L
.75701 .28637 L
.75711 .28635 L
.7572 .28635 L
.7573 .28637 L
.7574 .2864 L
.75749 .28645 L
.75759 .28653 L
.75781 .28675 L
.75801 .28705 L
.75838 .28777 L
.75872 .28864 L
.75948 .29125 L
.761 .29864 L
.76267 .30824 L
.76438 .31742 L
.76519 .32085 L
.76593 .32328 L
.76631 .32423 L
.76671 .32499 L
.76692 .32529 L
.76711 .32551 L
.76722 .32561 L
.76732 .32569 L
.76738 .32572 L
.76744 .32576 L
.7675 .32578 L
.76755 .3258 L
.76765 .32582 L
.76773 .32583 L
.76784 .32583 L
.76794 .32581 L
Mistroke
.76803 .32578 L
.76814 .32573 L
.76824 .32566 L
.76834 .32558 L
.7687 .32519 L
.7689 .32489 L
.76908 .32458 L
.76988 .32269 L
.77062 .32033 L
.77229 .31361 L
.77393 .30656 L
.77472 .30346 L
.77545 .30104 L
.77621 .29904 L
.77655 .29832 L
.77692 .29769 L
.77711 .29743 L
.77731 .2972 L
.7775 .29702 L
.77768 .2969 L
.77778 .29684 L
.77788 .29679 L
.77799 .29676 L
.77805 .29674 L
.7781 .29674 L
.7782 .29673 L
.77829 .29673 L
.7784 .29675 L
.7785 .29677 L
.77859 .29681 L
.77869 .29685 L
.77887 .29696 L
.77908 .29714 L
.77928 .29735 L
.7797 .29792 L
.7801 .29862 L
.78158 .30225 L
.78465 .31179 L
.78546 .31396 L
.78623 .31563 L
.78665 .31637 L
.78711 .31701 L
.78731 .31724 L
.78753 .31744 L
.78771 .31758 L
.78791 .31771 L
.78802 .31776 L
.78812 .3178 L
.78821 .31783 L
.78831 .31785 L
Mistroke
.7884 .31786 L
.78848 .31787 L
.78857 .31787 L
.78867 .31786 L
.78877 .31785 L
.78883 .31784 L
.78888 .31782 L
.78899 .31778 L
.7891 .31774 L
.78929 .31764 L
.78949 .3175 L
.78985 .31717 L
.79025 .31671 L
.79096 .31562 L
.79256 .31235 L
.79425 .30844 L
.79506 .30669 L
.79583 .30525 L
.79653 .3042 L
.79693 .30371 L
.79729 .30336 L
.79768 .30306 L
.79789 .30293 L
.7981 .30284 L
.79819 .30281 L
.79829 .30278 L
.79837 .30276 L
.79846 .30274 L
.79855 .30273 L
.79864 .30273 L
.7987 .30272 L
.79875 .30272 L
.79885 .30273 L
.79894 .30274 L
.799 .30275 L
.79905 .30276 L
.79916 .30279 L
.79927 .30282 L
.79945 .30289 L
.79965 .30299 L
.80008 .30327 L
.80053 .30367 L
.80129 .30456 L
.80211 .30573 L
.80359 .30815 L
.80519 .31069 L
.80603 .31179 L
.80649 .31229 L
.80692 .31268 L
.80734 .31298 L
Mistroke
.80772 .31319 L
.80794 .31328 L
.80814 .31335 L
.80826 .31337 L
.80836 .3134 L
.80848 .31341 L
.80853 .31342 L
.8086 .31343 L
.80869 .31343 L
.8088 .31343 L
.80888 .31343 L
.80898 .31342 L
.80908 .31341 L
.80919 .31339 L
.80939 .31334 L
.80959 .31328 L
.80978 .31321 L
.81014 .31303 L
.81092 .31249 L
.81174 .31172 L
.81322 .31005 L
.81481 .30823 L
.81551 .30753 L
.81626 .30689 L
.81668 .3066 L
.81706 .30638 L
.81743 .30621 L
.81782 .30608 L
.81804 .30603 L
.81816 .306 L
.81827 .30599 L
.81837 .30597 L
.81843 .30597 L
.81848 .30597 L
.81854 .30596 L
.8186 .30596 L
.8187 .30596 L
.8188 .30596 L
.8189 .30597 L
.819 .30598 L
.81911 .30599 L
.8193 .30602 L
.8195 .30606 L
.81989 .30618 L
.82031 .30635 L
.82105 .30676 L
.82273 .30799 L
.82433 .3093 L
.82579 .31031 L
.82618 .31052 L
Mistroke
.8266 .31071 L
.82696 .31085 L
.82736 .31097 L
.82758 .31102 L
.82779 .31105 L
.82801 .31108 L
.82813 .31109 L
.82818 .3111 L
.82824 .3111 L
.82834 .31111 L
.82844 .31111 L
.8285 .31111 L
.82855 .31111 L
.82865 .31111 L
.82875 .3111 L
.82884 .31109 L
.82894 .31109 L
.82905 .31107 L
.82925 .31105 L
.82945 .31101 L
.82981 .31092 L
.8302 .3108 L
.83063 .31065 L
.8321 .30993 L
.83366 .30905 L
.83449 .30861 L
.83538 .3082 L
.83582 .30803 L
.83623 .30789 L
.83664 .30779 L
.83701 .30771 L
.83736 .30765 L
.83756 .30763 L
.83774 .30762 L
.83784 .30761 L
.83794 .30761 L
.83804 .3076 L
.83809 .3076 L
.83815 .3076 L
.83825 .3076 L
.83835 .30761 L
.83845 .30761 L
.83854 .30761 L
.83872 .30763 L
.83892 .30765 L
.83914 .30767 L
.83933 .3077 L
.84007 .30786 L
.84087 .30809 L
.84174 .30839 L
Mistroke
.84331 .309 L
.84415 .3093 L
.84504 .30958 L
.84548 .30969 L
.8459 .30978 L
.84631 .30985 L
.84668 .3099 L
.84687 .30992 L
.84704 .30994 L
.84722 .30995 L
.84732 .30995 L
.84742 .30996 L
.84752 .30996 L
.84758 .30996 L
.84763 .30996 L
.84773 .30996 L
.84784 .30996 L
.84794 .30996 L
.84804 .30996 L
.84812 .30995 L
.84822 .30995 L
.84841 .30994 L
.84861 .30992 L
.84898 .30989 L
.84942 .30982 L
.84982 .30976 L
.85151 .30937 L
.85318 .30894 L
.85391 .30877 L
.85471 .30861 L
.85509 .30855 L
.85549 .3085 L
.85583 .30846 L
.85621 .30843 L
.85642 .30841 L
.85661 .3084 L
.85672 .3084 L
.85682 .3084 L
.85687 .3084 L
.85693 .30839 L
.85704 .30839 L
.85713 .30839 L
.85723 .30839 L
.85733 .30839 L
.85743 .30839 L
.85752 .3084 L
.85761 .3084 L
.85779 .3084 L
.85798 .30841 L
.85818 .30842 L
Mistroke
.85859 .30846 L
.85932 .30854 L
.86099 .30879 L
.86267 .30908 L
.86341 .30919 L
.86421 .30929 L
.86459 .30933 L
.865 .30937 L
.86538 .30939 L
.86572 .30941 L
.86593 .30942 L
.86612 .30942 L
.86622 .30942 L
.86632 .30942 L
.86638 .30943 L
.86644 .30943 L
.86654 .30943 L
.86664 .30943 L
.8667 .30943 L
.86675 .30943 L
.86685 .30942 L
.86695 .30942 L
.86705 .30942 L
.86714 .30942 L
.86732 .30941 L
.86769 .3094 L
.8681 .30937 L
.86893 .30931 L
.87041 .30915 L
.87211 .30896 L
.87291 .30889 L
.87366 .30883 L
.87402 .3088 L
.87443 .30878 L
.87483 .30877 L
.87505 .30876 L
.87515 .30876 L
.87526 .30876 L
.87535 .30876 L
.87545 .30875 L
.87555 .30875 L
.87564 .30875 L
.87574 .30875 L
.87583 .30875 L
.87591 .30875 L
.87599 .30875 L
.87609 .30875 L
.87619 .30875 L
.8763 .30876 L
.8764 .30876 L
Mistroke
.87678 .30877 L
.87699 .30877 L
.87718 .30878 L
.87762 .3088 L
.87841 .30884 L
.8799 .30895 L
.88141 .30906 L
.88221 .30911 L
.88305 .30915 L
.88347 .30916 L
.8837 .30917 L
.88394 .30918 L
.88417 .30918 L
.88437 .30918 L
.88447 .30918 L
.88457 .30919 L
.88467 .30919 L
.88477 .30919 L
.88486 .30919 L
.88496 .30919 L
.88506 .30919 L
.88514 .30919 L
.88524 .30919 L
.8853 .30919 L
.88535 .30919 L
.88555 .30918 L
.88577 .30918 L
.88596 .30918 L
.88639 .30917 L
.88719 .30914 L
.88793 .30911 L
.8896 .30903 L
.89039 .309 L
.89124 .30896 L
.89165 .30895 L
.89204 .30894 L
.89239 .30893 L
.89277 .30892 L
.89314 .30891 L
.89334 .30891 L
.89343 .30891 L
.89353 .30891 L
.89361 .30891 L
.8937 .30891 L
.89379 .30891 L
.89387 .30891 L
.89396 .30891 L
.89404 .30891 L
.89414 .30891 L
.89423 .30891 L
Mistroke
.89432 .30891 L
.89442 .30891 L
.89453 .30891 L
.89463 .30891 L
.89499 .30891 L
.8952 .30892 L
.89539 .30892 L
.89582 .30893 L
.89734 .30897 L
.89901 .30902 L
.89982 .30904 L
.90059 .30906 L
.90101 .30907 L
.90147 .30907 L
.90167 .30908 L
.90189 .30908 L
.90207 .30908 L
.90227 .30908 L
.90238 .30908 L
.90248 .30908 L
.90257 .30908 L
.90267 .30908 L
.90276 .30908 L
.90285 .30908 L
.90294 .30908 L
.90303 .30908 L
.90313 .30908 L
.90319 .30908 L
.90324 .30908 L
.90335 .30908 L
.90346 .30908 L
.90366 .30908 L
.90385 .30908 L
.90421 .30908 L
.90461 .30907 L
.90532 .30906 L
.90689 .30904 L
.90861 .309 L
.9094 .30899 L
.90983 .30899 L
.91025 .30898 L
.91063 .30898 L
.91083 .30898 L
.91105 .30898 L
.91123 .30898 L
.91132 .30898 L
.91142 .30898 L
.91152 .30898 L
.91161 .30897 L
.91169 .30897 L
Mistroke
.91178 .30897 L
.91187 .30897 L
.91193 .30897 L
.91198 .30897 L
.91208 .30897 L
.91218 .30897 L
.91226 .30898 L
.91235 .30898 L
.91254 .30898 L
.91275 .30898 L
.91293 .30898 L
.91336 .30898 L
.91411 .30899 L
.91483 .30899 L
.91644 .30901 L
.9179 .30903 L
.91829 .30903 L
.91871 .30904 L
.91907 .30904 L
.91948 .30904 L
.91968 .30904 L
.9199 .30904 L
.92002 .30904 L
.92013 .30904 L
.92025 .30904 L
.92035 .30904 L
.92045 .30904 L
.92055 .30904 L
.92065 .30904 L
.92071 .30904 L
.92077 .30904 L
.92086 .30904 L
.92095 .30904 L
.92105 .30904 L
.92116 .30904 L
.92136 .30904 L
.92156 .30904 L
.92192 .30904 L
.92232 .30904 L
.92274 .30904 L
.92422 .30903 L
.92578 .30901 L
.92661 .30901 L
.92707 .30901 L
.9275 .309 L
.92791 .309 L
.92813 .309 L
.92836 .309 L
.92857 .309 L
.92876 .309 L
Mistroke
.92885 .309 L
.92895 .309 L
.92905 .309 L
.92914 .309 L
.92922 .309 L
.92932 .309 L
.92941 .309 L
.92949 .309 L
.92959 .309 L
.92969 .309 L
.92979 .309 L
.92988 .309 L
.93006 .309 L
.93026 .309 L
.93066 .309 L
.93106 .309 L
.93148 .30901 L
.93222 .30901 L
.9339 .30902 L
.93472 .30902 L
.9355 .30902 L
.9362 .30902 L
.9366 .30903 L
.93696 .30903 L
.93715 .30903 L
.93732 .30903 L
.93752 .30903 L
.93763 .30903 L
.93773 .30903 L
.93783 .30903 L
.93793 .30903 L
.93803 .30903 L
.93808 .30903 L
.93814 .30903 L
.93824 .30903 L
.93835 .30903 L
.93845 .30903 L
.93854 .30903 L
.93874 .30903 L
.93893 .30903 L
.93936 .30903 L
.93977 .30902 L
.94022 .30902 L
.94182 .30902 L
.94266 .30902 L
.94355 .30901 L
.94434 .30901 L
.94476 .30901 L
.94522 .30901 L
.94543 .30901 L
Mistroke
.94563 .30901 L
.94583 .30901 L
.94601 .30901 L
.9461 .30901 L
.94618 .30901 L
.94628 .30901 L
.94637 .30901 L
.94646 .30901 L
.94655 .30901 L
.94665 .30901 L
.94675 .30901 L
.94685 .30901 L
.94696 .30901 L
.94715 .30901 L
.94734 .30901 L
.94752 .30901 L
.94791 .30901 L
.94833 .30901 L
.9498 .30901 L
.95139 .30902 L
.95208 .30902 L
.95284 .30902 L
.9532 .30902 L
.95359 .30902 L
.95381 .30902 L
.95401 .30902 L
.95419 .30902 L
.95439 .30902 L
.95449 .30902 L
.95461 .30902 L
.95471 .30902 L
.9548 .30902 L
.95486 .30902 L
.95492 .30902 L
.95502 .30902 L
.95508 .30902 L
.95513 .30902 L
.95519 .30902 L
.95525 .30902 L
.95536 .30902 L
.95547 .30902 L
.95568 .30902 L
.95588 .30902 L
.95606 .30902 L
.95685 .30902 L
.95758 .30902 L
.95924 .30902 L
.96074 .30902 L
.96115 .30902 L
.96159 .30902 L
Mistroke
.96196 .30902 L
.96237 .30902 L
.96259 .30902 L
.96279 .30901 L
.96289 .30901 L
.96299 .30901 L
.96309 .30901 L
.96318 .30901 L
.96324 .30901 L
.9633 .30901 L
.96336 .30901 L
.96341 .30901 L
.96351 .30901 L
.96362 .30901 L
.96367 .30901 L
.96373 .30901 L
.96384 .30901 L
.96396 .30901 L
.96408 .30901 L
.96448 .30902 L
.96491 .30902 L
.96569 .30902 L
.96725 .30902 L
.96808 .30902 L
.96897 .30902 L
.96938 .30902 L
.96981 .30902 L
.97022 .30902 L
.97059 .30902 L
.97094 .30902 L
.97114 .30902 L
.97132 .30902 L
.97142 .30902 L
.97152 .30902 L
.97162 .30902 L
.97167 .30902 L
.97173 .30902 L
.97183 .30902 L
.97193 .30902 L
.97203 .30902 L
.97212 .30902 L
.97232 .30902 L
.9725 .30902 L
.97291 .30902 L
.97329 .30902 L
.97364 .30902 L
.97531 .30902 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{421.375, 260.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008>0001AB000`400?l00000o`00003ooooooooo
oooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo
003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooo
oooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool0
0?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooooooo
ool@ooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooo
ooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo0ol0003o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0
003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo
00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`
ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLoooo
o`00<?ooool3o`000?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?oo
ool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0
033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomco
oooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooo
oooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool3o`000?oooooo
g?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0013ooooo0_o^k^h3ooooo`;ok^k^6Oooool00ol0003oooooooooo`3o
ooooomcooooo000;ooooo`;o000000[o410@ooooooooooook^k^oeEEEOo^k^koooooonk^k_mEEEGo
k^k^0oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h:ooooo`03o`000?oo
oooooooo0?oooooog?ooool000cooooo00?o0000ooooooooool00_ooool01Oo^k^koEEEEomgMgOmE
EEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00[ooooo
00?o0000ooooooooool0oooooooLooooo`0000?oooooo`000?l000001?l00002ooooo`Go00001?oo
ool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooo
oa0@400:ooooo`03o`000?oooooooooo0?oooooog?ooool000Wooooo00CoA4A4omgMgOoooooo0000
1?ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000000[ooooo00?o0000ooooooooool0oooooooLooooo`002Oooool01?oMgMgo
EEEEooooool00003ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000:ooooo`Co0000oooooooKooooo`002_oo
ool00omgMgOoc<c<o`000003ooooo`;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@00[ooooo00?o0000ooooooooool0oooooooLooooo`002_oo
ool00oo^k^koA4A4o`00000?ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`;o00001Oooool00ol0003oooooooooo`3oooooomcooooo000;ooooo`03ogMgMol0
003ooooo00cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`3oooooomcooooo000Xooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool0oooooooLooooo`00:?ooool3o`0000Gooooo
00?o0000ooooooooool0oooooooLooooo`00:Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo0?oooooog?ooool002[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3=ooooo`03o`000?oooooooooo0?oooooo
3?ooool0033ooooo00?o0000ooooooooool0c?ooool2o`0000_ooooo00?o0000ooooooooool0oooo
ool0033ooooo0ol0003<ooooo`;o00002_ooool2o`000?oooooo0_ooool0033ooooo00?o0000oooo
ooooool0c?ooool2o`0000[ooooo0_l0003oooooo`;ooooo000`ooooo`03o`000?oooooooooo0<co
oooo0_l0000:ooooo`;o0000ooooool2ooooo`00<?ooool00ol0003oooooooooo`3<ooooo`;o0000
2_ooool2o`000?oooooo0_ooool0033ooooo00?o0000ooooooooool0c?ooool2o`0000[ooooo0_l0
003oooooo`;ooooo000`ooooo`03o`000?oooooooooo0<cooooo0_l0000:ooooo`;o0000ooooool2
ooooo`00<?ooool00ol0003oooooooooo`3<ooooo`03o`000?oooooo000000Wooooo0_l0003ooooo
o`;ooooo000`ooooo`03o`000?oooooooooo0<cooooo00?o0000ooooool000002Oooool2o`000?oo
oooo0_ooool0033ooooo00?o0000ooooooooool0`?ooool2o`0000[ooooo00?o0000ooooool00000
2Oooool2o`000?oooooo0_ooool0033ooooo00?o0000ooooooooool0`?ooool2o`0000[ooooo00?o
0000ooooool000002?ooool00ol0003oooooo`00003oooooo`;ooooo000`ooooo`03o`000?oooooo
oooo0<3ooooo0_l0000:ooooo`03o`000?oooooo000000Sooooo00?o0000ooooool000002Oooool2
o`000?Kooooo000`ooooo`03o`000?oooooooooo0<3ooooo0_l0000:ooooo`03o`000?oooooo0000
00Sooooo00?o0000ooooool000002Oooool2o`000?Kooooo000`ooooo`?o0000`?ooool2o`0000[o
oooo00?o0000ooooool000002?ooool00ol0003oooooo`000009ooooo`;o0000m_ooool0033ooooo
00?o0000ooooooooool0`?ooool2o`0000[ooooo00?o0000ooooool000002?ooool00ol0003ooooo
o`000009ooooo`;o0000m_ooool0033ooooo00?o0000ooooooooool0`?ooool2o`0000[ooooo00?o
0000ooooool000002?ooool00ol0003oooooo`000009ooooo`;o0000m_ooool0033ooooo00?o0000
ooooooooool0_oooool00ol0003oooooo`00000:ooooo`03o`000?oooooo000000Sooooo00?o0000
ooooool000002Oooool2o`000?Kooooo000`ooooo`03o`000?oooooooooo0;oooooo00?o0000oooo
ool000002_ooool00ol0003oooooo`000008ooooo`04o`000?ooooooooooo`0000Sooooo0_l0003f
ooooo`00<?ooool00ol0003oooooooooo`2oooooo`03o`000?oooooo000000[ooooo00?o0000oooo
ool000002?ooool01?l0003oooooooooool00008ooooo`;o0000m_ooool0033ooooo00?o0000oooo
ooooool0_oooool00ol0003oooooo`00000:ooooo`03o`000?oooooo000000Sooooo00Co0000oooo
oooooooo00002?ooool2o`000?Kooooo000`ooooo`03o`000?oooooooooo0;oooooo00?o0000oooo
ool000002Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo0_l0
003fooooo`00<?ooool00ol0003oooooooooo`2oooooo`03o`000?oooooo000000Wooooo00Co0000
oooooooooooo00002?ooool01?l0003oooooooooool00008ooooo`;o0000m_ooool0033ooooo00?o
0000ooooooooool0_oooool00ol0003oooooo`000009ooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003eooooo`00<?ooool00ol0003ooooo
ooooo`2oooooo`03o`000?oooooo000000Wooooo00Co0000oooooooooooo00002?ooool01?l0003o
ooooooooool00008ooooo`03o`000?oooooo00000?Gooooo000`ooooo`?o0000_oooool00ol0003o
ooooo`000009ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002?ooool0
0ol0003oooooo`00003eooooo`00<?ooool00ol0003oooooooooo`2oooooo`04o`000?oooooooooo
o`0000Sooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00008ooooo`03o`00
0?oooooo00000?Gooooo000`ooooo`03o`000?oooooooooo0;oooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000oooo
ool000002?ooool2o`000>_ooooo000`ooooo`03o`000?oooooooooo0;?ooooo0_l0000:ooooo`04
o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0
0007ooooo`04o`000?ooooooooooo`0000Sooooo0_l0003[ooooo`00<?ooool00ol0003ooooooooo
o`2cooooo`;o00002_ooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool0
00001oooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Sooooo0_l0003[
ooooo`00<?ooool00ol0003oooooooooo`2cooooo`;o00002_ooool01?l0003oooooooooool00008
ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool00007ooooo`04o`00
0?ooooooooooo`0000Sooooo0_l0003[ooooo`00<?ooool00ol0003oooooooooo`2cooooo`;o0000
2_ooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool000001oooool01?l0
003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Sooooo0_l0003[ooooo`004?ooool2
onk^kP?ooooo0_o^k^hIooooo`03o`000?oooooooooo0;?ooooo0_l0000:ooooo`04o`000?oooooo
ooooo`0000Sooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oo
oooo00Co0000oooooooooooo00002?ooool2o`000>_ooooo0009ooooo`Go00000_ooool01oo^k^ko
EEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000
oc8b<_o^k^h:ooooo`03o`000?oooooooooo0;;ooooo00?o0000ooooool000002_ooool01?l0003o
ooooooooool00008ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool0
0007ooooo`04o`000?ooooooooooo`0000Sooooo0_l0003[ooooo`002Oooool01OnHV9So8B4Qonk^
k_ooooooA4A400?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0:ooooo`03o`000?oooooooooo0;;ooooo00?o0000oooo
ool000002_ooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool000001ooo
ool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool0
0000joooool00003ooooool0003o000000Co00000oooool00onHV9So8B4Qonk^kP05ooooo`03omgM
gOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00[o
oooo00?o0000ooooooooool0/_ooool00ol0003oooooo`00000:ooooo`04o`000?ooooooooooo`00
00Sooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo00Co
0000oooooooooooo00001oooool00ol0003oooooo`00003[ooooo`002oooool00onHV9So8B4Qonk^
kP03ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000002_ooool00ol0003oooooooooo`2booooo`04o`000?ooooooooooo`00
00Wooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Co
0000oooooooooooo00001oooool01?l0003oooooooooool00007ooooo`03o`000?oooooo00000>_o
oooo000<ooooo`0;ogMgMomVIVKoooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Ooo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000002_ooool4o`000;7ooooo
00Co0000oooooooooooo00002Oooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00007ooooo`04o`000?oooooo
ooooo`0000Oooooo00?o0000ooooool00000joooool000gooooo00?o0000ooooooooool00_o^k^h3
ooooo`;ok^k^1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41002_oo
ool00ol0003oooooooooo`2booooo`04o`000?ooooooooooo`0000Wooooo00Co0000oooooooooooo
00001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooo
oooo00001oooool01?l0003oooooooooool00007ooooo`03o`000?oooooo00000>_ooooo0009oooo
o`05o`000?nj^[[ooooooiRHV?l@41003_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL00oooool2o`0000Gooooo00?o0000ooooooooool0/_ooool01?l0003ooooooooo
ool00009ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`05ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00001oooool0
0ol0003oooooo`00003[ooooo`002Oooool01OnHV9So410@o`000?lQ8B7oc<c<00cooooo00?oEEEE
ofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooooooo`2booooo`04o`000?ooooooooooo`0000Wooooo00Co0000oooooooo
oooo00001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00Co0000oooo
oooooooo00001oooool01?l0003oooooooooool00007ooooo`03o`000?oooooo00000>_ooooo000X
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0/_ooool01?l0003ooooooooo
ool00009ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool00007
ooooo`03o`000?oooooo00000>_ooooo000Xooooo`?o00001Oooool00ol0003oooooooooo`2boooo
o`04o`000?ooooooooooo`0000Wooooo00Co0000oooooooooooo00001oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000007ooooo`04o`00
0?ooooooooooo`0000Oooooo00?o0000ooooool00000joooool002Wooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`2booooo`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooo
ooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0
003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo00001oooool01?l0003ooooooooo
ool00008ooooo`03o`000?oooooooooo0=oooooo000Zooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0/_ooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool0
00001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooo
ooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00001ooo
ool2o`000>7ooooo000`ooooo`03o`000?oooooooooo0;;ooooo00Co0000oooooooooooo00002?oo
ool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`04ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool00007oooo
o`04o`000?ooooooooooo`0000Oooooo0_l0003Qooooo`00<?ooool00ol0003oooooooooo`2boooo
o`04o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Oooooo
00Co0000oooooooooooo00001oooool01?l0003oooooooooool00007ooooo`;o0000hOooool0033o
oooo00?o0000ooooooooool0/Oooool01Ol0003ooooooooooooooooo000000Sooooo00Go0000oooo
ooooooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
1Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo00001oooool01?l0003ooooo
ooooool00007ooooo`;o0000hOooool0033ooooo00?o0000ooooooooool0/Oooool01Ol0003ooooo
oooooooooooo000000Sooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000
oooooooooooo00001oooool01?l0003oooooooooool00007ooooo`03o`000?oooooo00000>3ooooo
000`ooooo`?o0000YOooool2o`0000[ooooo00Go0000ooooooooooooooooo`000008ooooo`05o`00
0?ooooooooooooooool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000
oooooooooooo00001oooool00ol0003oooooo`00003Pooooo`00<?ooool00ol0003oooooooooo`2U
ooooo`;o00002_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo00001oooool01?l0003o
ooooooooool00007ooooo`03o`000?oooooo00000>3ooooo000`ooooo`03o`000?oooooooooo0:Go
oooo0_l0000:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool00007
ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool00000h?ooool0033ooooo00?o0000
ooooooooool0YOooool2o`0000[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?oo
ooooooooo`0000Oooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00003Pooooo`00
<?ooool00ol0003oooooooooo`2Uooooo`03o`000?oooooo000000Wooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooo
ooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00001oooool0
0ol0003oooooo`00003Pooooo`00<?ooool00ol0003oooooooooo`2Uooooo`03o`000?oooooo0000
00Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo00Co
0000oooooooooooo00001oooool00ol0003oooooo`00003Pooooo`00<?ooool00ol0003ooooooooo
o`2Tooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000007ooooo`04
o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00003P
ooooo`00<?ooool00ol0003oooooooooo`2Tooooo`04o`000?ooooooooooo`0000Wooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000
ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo
00001oooool00ol0003oooooo`000008ooooo`03o`000?oooooooooo0=Gooooo000`ooooo`03o`00
0?oooooooooo0:Cooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000
00Kooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001_oo
ool00ol0003oooooo`000007ooooo`;o0000eoooool0033ooooo00?o0000ooooooooool0Y?ooool0
1?l0003oooooooooool00009ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooo
oooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo0000
00Oooooo0_l0003Gooooo`00<?ooool00ol0003oooooooooo`2Tooooo`04o`000?ooooooooooo`00
00Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001ooo
ool01Ol0003ooooooooooooooooo000000Gooooo00Co0000oooooooooooo00001oooool2o`000=Oo
oooo000`ooooo`03o`000?oooooooooo0:Cooooo00Go0000ooooooooooooooooo`000008ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05
o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Oooooo00?o
0000ooooool00000e_ooool0033ooooo0ol0002Tooooo`05o`000?ooooooooooooooool000002?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00007oooo
o`03o`000?oooooo00000=Kooooo000`ooooo`03o`000?oooooooooo0:Cooooo00Go0000oooooooo
ooooooooo`000008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooo
oooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`04o`000?oo
ooooooooo`0000Oooooo00?o0000ooooool00000e_ooool0033ooooo00?o0000ooooooooool0Y?oo
ool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00?ooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00003Foooo
o`00<?ooool00ol0003oooooooooo`2Tooooo`05o`000?ooooooooooooooool000002?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01?l0
003oooooooooool00007ooooo`03o`000?oooooo00000=Kooooo000`ooooo`03o`000?oooooooooo
0:Cooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Oooooo00?o
0000ooooool00000e_ooool0033ooooo00?o0000ooooooooool0C_ooool2onk^kP?ooooo0_o^k^i?
ooooo`05o`000?ooooooooooooooool000000oooool2onk^kP?ooooo00?o0000onk^k_ooool00_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo0000
1oooool00ol0003oooooo`00000>ooooo`;ok^k^0oooool2onk^kTkooooo0_o^k^h3ooooo`;ok^k^
K?ooool0033ooooo00?o0000ooooooooool0B?ooool03Om4A4Co0000o`000?lb<S;ogMgMooooooo^
k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o
0000oc8b<_o^k^hbooooo`?o00002_ooool00ol0003oooooooooo`04o`000009oa0@4?ooooook^k^
oeEEEOo^k^koooooonk^k_l0003ok^k^00?ooooo1?l000002_l@413oooooooooool0003o<S8bo`00
0?lb<S;ok^k^ooooool00006ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooo
ool01_l0003ooooooooooooooooo0000ooooo`Co000000Go410@o`000?oooooo0000ooooo`02ob4Q
8@Cooooo1?l000002_lb<S;ogMgMooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h3ooooo`Co
000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kSSooooo1Ol00002ooooo`07onk^k_mE
EEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o
<S8bonk^kUgooooo000`ooooo`03o`000?oooooooooo04_ooooo00WoMgMgoc8b<_ooooooooooonk^
k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL0<_ooool00ol0003oooooo`00000:ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00_ooool01Oo^k^koEEEEomgMgOmEEEGo000000Cooooo00?o0000ooooool000001?ooool0
1ol0003oV9RHoooooonHV9SoMgMgooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo000000?o
oooo00?o0000ob4Q8OlQ8B401?ooool2o`0000;ooooo00WoMgMgoc8b<_ooooooooooonk^k_mEEEGo
gMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
>?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06oooo
o`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`1Mooooo`00<?ooool00ol0
003oooooooooo`1<ooooo`07o`000?oooooooooooooooooMgMgo0000omgMg@07ooooo`03o`000?oo
oooooooo00;ooooo00Go410@oooooooooooooooooa0@400booooo`03o`000?oooooo000000[ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`04omgMgOl0003ogMgMo`0000Co
oooo00?o0000ooooool000001?ooool01ol0003ooooooooooooooooo410@ooooool000001_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool01?ooool2o`0000?ooooo00Oo
0000ooooooooooooooooomgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@413o
oooooooooooooooo410@03Wooooo00?oV9RHob4Q8Oo^k^h01Oooool00ooMgMgo0000omgMg@07oooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@401Mooooo`00<?ooool00ol0
003oooooooooo`1;ooooo`09ogMgMolb<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000037ooooo00Co0000oooooooo
oooo00002_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Gok^k^oeEE
EOoMgMgoEEEEo`000004ooooo`03o`000?oooooo000000Cooooo00Oo0000ooooooooooooooooo`00
0?oooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`00
0?ooooooooooooooool000000oooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00Co
oooo0_l00002ooooo`09ogMgMolb<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000003[ooooo00?oV9RHob4Q8Oo^k^h0
0oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000005gooooo000`ooooo`03o`000?oooooooooo04Sooooo00go0000ob4Q8Ol0
003o<S8bolc<c?ooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000oooooooo
ool00_ooool01Ol0003ooooooooooooooooo0000037ooooo00Co0000oooooooooooo00002_ooool0
0ol0003oooooooooo`02ooooo`0;o`000?ooooooooooooooooo^k^koEEEEonk^k_ooooook^k^o`00
0?o^k^h00oooool00ol0003oooooo`000004ooooo`07o`000?ooooooooooooooool0003oooooo`00
0006ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooo
oooooooo000000?ooooo00?o0000ooooool000000oooool00ol0003oooooooooo`03ooooo`0?o`00
0?oooooo0000ob4Q8Ol0003o<S8bolc<c?ooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Go
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000003_ooooo00_oMgMgofIV
I_ooooooooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`00001Mooooo`00<?ooool00ol0003oooooooooo`18ooooo`03
o`000?oooooooooo00?ooooo0_o^k^h3ooooo`;ok^k^1Oooool00ol0003oooooooooo`02ooooo`05
oa0@4?ooooooooooooooool@4100<Oooool01?l0003oooooooooool0000:ooooo`03o`000?oooooo
oooo00;ooooo00Co0000oooooooooooooooo0_o^k^h3ooooo`03o`000?o^k^kooooo00;ooooo00?o
0000ooooool000001?ooool01ol0003ooooooooooooooooo410@ooooool000001_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooo000000?ooooo00?o0000ooooooooool00oooool00ol0003oooooo`000005oooo
o`;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@03cooooo00?o0000ooooooooool00_o^k^h3ooooo`;ok^k^1Oooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@4100GOooool0033ooooo0ol00018ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o
0000ooooooooool09_ooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool00000
1?ooool01ol0003oV9RHoooooonHV9SoMgMgooooool000001_ooool2o`0000?ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooool000000oooool0
0ol0003oooooooooo`03ooooo`04o`000?oooooo0000o`00013ooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo0_l0000^ooooo`05o`000?nj^[[ooooooiRHV?l@
41003_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool2o`00
05?ooooo000`ooooo`03o`000?oooooooooo04Sooooo1?l0000<ooooo`03oeEEEOmVIVKo000000Co
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo02Kooooo00Go0000oooo
ooooooooooooo`000009ooooo`06o`000?oooooooooooeEEEOmVIVKo00001oooool00ol0003ooooo
ooooo`03ooooo`03o`000?mVIVKo000000Cooooo00Oo0000oc8b<_l0003o<S8bonk^k_oooooo0000
00Gooooo0_l000001Ooooooo0000oooooooooooo000000Kooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00_o0000ooooooooooooooooo`00
0?ooooooEEEEofIVI_l0003oooooo`000003ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ool000000ol00005ooooo`03o`000?oooooooooo00Cooooo00?oEEEEofIVI_l000001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Oooooo00Co0000oooooooooooo0000;Oooool01OnHV9So410@o`00
0?lQ8B7oc<c<00cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oo
oooo00Co0000oooooooooooo0000D_ooool0033ooooo00?o0000ooooooooool0I_ooool4o`0000?o
oooo00?o0000ooooooooool09Oooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`03ooooo`Go000000Goooooo`000?l0003oooooo`000002
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000005ooooo`05o`000?oo
ooooooooooooool000001Oooool01?l0003oooooooooool00006ooooo`?o00004oooool4o`000005
ooooool0003oooooooooool00000C?ooool4o`000005ooooool0003oooooooooool00000D_ooool0
033ooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Uooooo`05o`000?oooooooooo
ooooool000002Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool3o`0000?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooo
oooo000000Gooooo00Go0000ooooooooooooooooo`000005ooooo`04o`000?ooooooooooo`0000Ko
oooo00?o0000ooooool000006?ooool3o`0005;ooooo0ol0001Cooooo`00<?ooool00ol0003ooooo
ooooo`1[ooooo`04o`000?ooooooooooo`0001Sooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0003ooooooooooooooooo
000000Gooooo00Co0000oooooooooooo00001_ooool00ol0003oooooo`00000Iooooo`03o`000?oo
oooooooo05;ooooo00?o0000ooooooooool0D_ooool0033ooooo00?o0000ooooooooool0Joooool4
o`0001Oooooo0ol0000;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool2
o`0000?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Gooooo00Go
0000ooooooooooooooooo`000005ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooool0
00006_ooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo057ooooo000`ooooo`03o`00
0?oooooooooo08Gooooo00Go0000ooooooooooooooooo`00000:ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00Go0000ooooooooooooooooo`000005ooooo`05o`000?ooooooooooooooool000001Oooool0
1Ol0003ooooooooooooooooo000000Gooooo00Co0000oooooooooooo00001Oooool2o`000;_ooooo
000`ooooo`03o`000?oooooooooo08Cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0003ooooooooooooooooo000000Go
oooo00Co0000oooooooooooo00001Oooool00ol0003oooooo`000020ooooo`03ogMgMomVIVKooooo
02gooooo00?oIVIVogMgMoooool01oooool0033ooooo00?o0000ooooooooool0Q?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000005oooo
o`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Gooooo00?o
0000ooooool000001oooool00ol0003oooooooooo`1eooooo`03omgMgOl@413ok^k^02kooooo00?o
k^k^oa0@4?oMgMd01oooool0033ooooo00?o0000ooooooooool0M_ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooo
oooo000000Gooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool0
00001Oooool00ol0003oooooo`000006ooooo`?o0000I?ooool2o`0000;ooooo0_l0000<ooooo`03
oeEEEOnHV9Sooooo00;o00000_ooool01ol0003oooooooooool0003o410@onk^k_mEEED00_l00000
0om4A4Co^[Zjooooo`02ooooo`05oiRHV?l0003o0000odA4A?nj^[X00_ooool02?o^k^koEEEEo`00
0?l0003oA4A4okZj^_oooooo410@1Ol00003ooooo`08oa0@4?lb<S;o0000o`000?l@413oZJVYohN7
QomVIVH7ooooo`00<?ooool00ol0003oooooooooo`1booooo`Oo00002_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000005ooooo`05o`00
0?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooo
ooooooooooooo`000004ooooo`;o000000?oooooo`000?ooool01Oooool3o`0005_ooooo00Kok^k^
ob4Q8On7QhOo^[Zjo`000?oMgMd<ooooo`05o`000?ooooooooooooooool000000_ooool02ol0003o
ooooooooool0003ooooooeEEEOmgMgOoooooonk^k_mgMgOo410@00?ooooo00Go410@okZj^_o^k^ko
MgMgoa0@4002ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo410@0oooool00ol0003oooooooooo`04
ooooo`08o`000?nYZJWooooooooooonj^[[o0000onk^k_l00007ooooo`00ool0002do`0000oooooo
00CogMgMo`000?l@413oc<c<3Oooool01Olb<S;ooooooooooooooooo000000;ooooo00Ko0000oooo
oooooooo0000ooooool00008ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`05ooooo`07okZj^_n7QhOoIVIVofIVI_l@413oooooo`000007ooooo`00
2_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00_ooooo1ol0000;ooooo`03o`00
0?oooooooooo00?ooooo0_l00008ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00000oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooool000000oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Oo0000ooooooooooooooooo`000?oo
oooo000000Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00;o00001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00_l00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooooooool2o`0000;ooooo00?o0000ooooooooool00oooool3o`0000Gooooo
0ol00006ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo01Oooooo00Cok^k^ob4Q8Ol@413ok^k^3Oooool01Olb<S;o
oooooooooooooooo000000;ooooo00Go0000oooooooooooo0000ooooo`06o`0000?ooooo00?o0000
ooooooooool01?ooool6o`0000?ooooo00?o0000ooooooooool01?ooool02?lb<S;o8B4QogMgMomg
MgOoQhN7onk^k_oooooo00001oooool000[ooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00oooool2o`0000Sooooo
00?o0000ooooooooool01?ooool2o`0000Oooooo00?o0000ooooooooool01?ooool01Ol0003ooooo
oooooooooooo000000;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooo000000?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooo000000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`07
o`000?ooooooooooooooool0003oooooo`000004ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`02o`0000Cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o00000oooool00ol0003oooooooooo`03
ooooo`04o`000?ooooooooooo`0000Cooooo1?l0000?ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Oooooo00Co
8B4QogMgMomgMgOo<S8b3Oooool01Ol0003ok^k^oooooooooooo000000;oc<c<00_o0000ojVYZOoM
gMgo8B4QoooooomEEEGoQhN7onk^k_ooooooQhN7oc8b<P03ooooo`03o`000?oooooooooo00Cooooo
00KoEEEEohN7Qoo^k^koooooohN7Qolb<S83ooooo`03o`000?lb<S;ogMgM00Cooooo00So0000okZj
^_ooooook^k^ogMgMol0003ok^k^o`0000Oooooo000`ooooo`03o`000?oooooooooo05_ooooo00?o
0000ooooooooool07_ooool2o`0000;ooooo0_l00009ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo000000?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`000003ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooo`00001?ooooo`03o`000?oooooooooo01Kooooo0_l00002ooooo`;o00003?ooool03_mEEEGo
MgMgooooool@413o0000ob4Q8Ol0003oMgMgoa0@4?l0003oZJVYooooooo^k^koEEEE0_l000001?m4
A4Cok^k^ooooool@4105o`0000?ooooo00Kok^k^oeEEEOl0003o0000odA4A?o^k^h2ooooo`;o0000
00CoZJVYob4Q8Ol0003o8B4Q0_ooool02?nYZJWo8B4Qo`000?l0003o<S8bo`000?mgMgOoEEEE1ooo
ool0033ooooo00?o0000ooooooooool0OOooool4o`0000_ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooo
oooooooo000000Gooooo00Co0000oooooooooooo00001_ooool2o`0007_ooooo00?ogMgMoa0@4?o^
k^h04_ooool00ol0003oooooooooo`0Iooooo`03onk^k_l@413ogMgM00Oooooo000`ooooo`03o`00
0?oooooooooo08cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000005ooooo`05o`000?oooooooooooooo
ool000001?ooool01Ol0003ooooooooooooooooo000000Gooooo00Co0000oooooooooooo0000Q?oo
ool00omgMgOoIVIVooooo`0Aooooo`03o`000?oooooooooo01Wooooo00?oIVIVogMgMoooool01ooo
ool0033ooooo00?o0000ooooooooool0S?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Gooooo00Go
0000ooooooooooooooooo`000005ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooool0
0000_oooool0033ooooo00?o0000ooooooooool0SOooool01Ol0003ooooooooooooooooo000000Wo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Gooooo00Go0000oooo
ooooooooooooo`000005ooooo`04o`000?ooooooooooo`0000Kooooo0_l0002oooooo`00<?ooool0
0ol0003oooooooooo`2=ooooo`05o`000?ooooooooooooooool000002Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`05o`000?ooooooooooooooool000001Oooool01?l0003oooooooooool00006ooooo`04
o`000?ooooooooooo`0000Kooooo0_l0002oooooo`00<?ooool00ol0003oooooooooo`2=ooooo`05
o`000?ooooooooooooooool000002_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooooooo
ooooool000001Oooool01?l0003oooooooooool00006ooooo`04o`000?ooooooooooo`000<Oooooo
000`ooooo`03o`000?oooooooooo08kooooo00?o0000ooooool000002oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`05o`000?ooooooooooooooool000001Oooool01?l0003oooooooooool00006ooooo`03
o`000?oooooo00000<Sooooo000`ooooo`03o`000?oooooooooo08kooooo0ol0000;ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000005ooooo`04o`000?ooooooooooo`00
00Kooooo00?o0000ooooool00000b?ooool0033ooooo0ol0002?ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Gooooo00Co0000oooo
oooooooo00001_ooool3o`000<Sooooo000`ooooo`03o`000?oooooooooo09cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool01Ol0003ooooooooooooooooo000000Gooooo00Co0000oooooooooooo00001ooo
ool2o`000<Sooooo000`ooooo`03o`000?oooooooooo09cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
1Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooo
oooooooo000000Gooooo00Co0000oooooooooooo0000dOooool0033ooooo00?o0000ooooooooool0
W?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`05o`000?ooooooooooooooool000001Oooool01?l0003oooooooooool0003A
ooooo`00<?ooool00ol0003oooooooooo`2Looooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooo00000=7ooooo000`ooooo`03o`000?oooooooooo09gooooo00Co0000oooooooooooo0000
2Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooo
ooooo`000006ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01?l0003o
ooooooooool00006ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooo`00003A
ooooo`00<?ooool00ol0003oooooooooo`2Mooooo`04o`000?ooooooooooo`0000Wooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo0000
1_ooool01?l0003oooooooooool00007ooooo`03o`000?oooooo00000=7ooooo000`ooooo`03o`00
0?oooooooooo09gooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00006ooooo`04o`000?oooooo
ooooo`0000Oooooo00?o0000ooooool00000dOooool0033ooooo00?o0000ooooooooool0WOooool0
1?l0003oooooooooool00009ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000006ooooo`04
o`000?ooooooooooo`0000Kooooo00Co0000oooooooooooo00001oooool2o`000=;ooooo000`oooo
o`03o`000?oooooooooo09gooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Kooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool0
00001_ooool01?l0003oooooooooool00006ooooo`04o`000?ooooooooooo`0000Oooooo0_l0003B
ooooo`00<?ooool00ol0003oooooooooo`2Mooooo`04o`000?ooooooooooo`0000Wooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool000001ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooo
oooooooooooo000000Kooooo00Co0000oooooooooooo00001_ooool01?l0003oooooooooool00007
ooooo`;o0000d_ooool0033ooooo00?o0000ooooooooool0WOooool01?l0003oooooooooool00009
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooo
oooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo
00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Kooooo00Co0000oooo
oooooooo0000foooool0033ooooo0ol0002Nooooo`;o00002_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Kooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool00000
1_ooool01?l0003oooooooooool00006ooooo`04o`000?ooooooooooo`000=_ooooo000`ooooo`03
o`000?oooooooooo09kooooo0_l0000:ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01_ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0
003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?oo
ooooooooo`0000Oooooo00?o0000ooooool00000foooool0033ooooo00?o0000ooooooooool0W_oo
ool2o`0000[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`05o`000?oo
ooooooooooooool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool0
00001_ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo00001oooool0
0ol0003oooooo`00003Kooooo`00<?ooool00ol0003oooooooooo`2Zooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000oooooooooooooooo
o`000006ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool00000foooool0033ooooo
00?o0000ooooooooool0Z_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo
00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooo
ooooooooo`000006ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool0
0007ooooo`03o`000?oooooo00000=_ooooo000`ooooo`03o`000?oooooooooo0:_ooooo00Go0000
ooooooooooooooooo`000008ooooo`05o`000?ooooooooooooooool000001oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo0000
00Kooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00003Kooooo`00<?ooool00ol0
003oooooooooo`2[ooooo`05o`000?ooooooooooooooool000002?ooool01Ol0003ooooooooooooo
oooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo
00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000oooo
ool00000foooool0033ooooo00?o0000ooooooooool0Zoooool01Ol0003ooooooooooooooooo0000
00Sooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000
ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003ooooo
ooooool00007ooooo`03o`000?oooooo00000=_ooooo000`ooooo`03o`000?oooooooooo0:_ooooo
00Go0000ooooooooooooooooo`000008ooooo`05o`000?ooooooooooooooool000001oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000006
ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Kooooo
00Co0000oooooooooooo00001oooool2o`000=cooooo000`ooooo`03o`000?oooooooooo0:_ooooo
00Go0000ooooooooooooooooo`000008ooooo`05o`000?ooooooooooooooool000001oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000006
ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Kooooo
00Co0000oooooooooooo00001oooool2o`000=cooooo000`ooooo`03o`000?oooooooooo0:_ooooo
00Co0000oooooooooooo00002Oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000001_ooool0
1Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000006ooooo`04o`00
0?ooooooooooo`0000Oooooo0_l0003Looooo`00<?ooool00ol0003oooooooooo`2[ooooo`04o`00
0?ooooooooooo`0000Wooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000
ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003ooooo
ooooool00008ooooo`03o`000?oooooooooo0=[ooooo000`ooooo`?o0000Zoooool01?l0003ooooo
ooooool00009ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?oooooo
ooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo
0000iOooool0033ooooo00?o0000ooooooooool0Zoooool01?l0003oooooooooool00009ooooo`05
o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Gooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001_oo
ool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo0000iOooool0033ooooo
00?o0000ooooooooool0Zoooool01?l0003oooooooooool00009ooooo`05o`000?oooooooooooooo
ool000001oooool01Ol0003ooooooooooooooooo000000Sooooo00Go0000ooooooooooooooooo`00
0006ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool00007ooooo`03
o`000?oooooo00000>Gooooo000`ooooo`03o`000?oooooooooo0:_ooooo00Co0000oooooooooooo
00002Oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000008
ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Oooooo
00Co0000oooooooooooo00001oooool00ol0003oooooo`00003Uooooo`00<?ooool00ol0003ooooo
ooooo`2/ooooo`03o`000?oooooo000000Wooooo00Go0000ooooooooooooooooo`000007ooooo`05
o`000?ooooooooooooooool000002?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000
ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool00000
iOooool0033ooooo00?o0000ooooooooool0[?ooool00ol0003oooooo`000009ooooo`05o`000?oo
ooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Sooooo00Go0000oooooooo
ooooooooo`000006ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooo`000008
ooooo`03o`000?oooooo00000>Gooooo000?ooooo`;ok^k^0oooool2onk^kQ[ooooo00?o0000oooo
ooooool0[?ooool00ol0003oooooo`000009ooooo`05o`000?ooooooooooooooool000001oooool0
1Ol0003ooooooooooooooooo000000Sooooo00Go0000ooooooooooooooooo`000006ooooo`05o`00
0?ooooooooooooooool000001oooool00ol0003oooooo`000008ooooo`03o`000?oooooo00000>Go
oooo0008ooooo`Go00000_ooool01oo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`00
0008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`03o`000?oooooooooo0:cooooo
0_l0000:ooooo`05o`000?ooooooooooooooool000002?ooool01?l0003oooooooooool00008oooo
o`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Oooooo00?o
0000ooooool000002?ooool2o`000>Kooooo0008ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00ooo
ool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00?o0000ooooooooool0[?ooool2o`0000[ooooo00Go0000oooooooo
ooooooooo`000008ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`00
0006ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooo`000008ooooo`;o0000
i_ooool000Wooooo00?oV9RHob4Q8Oo^k^h01Oooool00ooMgMgo0000omgMg@07ooooo`03o`000?oo
oooooooo00;ooooo00Go410@oooooooooooooooooa0@400;ooooo`03o`000?oooooooooo0:cooooo
0_l0000:ooooo`05o`000?ooooooooooooooool000002?ooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oo
oooo000000Sooooo0_l0003Vooooo`002_ooool00onHV9So8B4Qonk^kP03ooooo`05onk^k_mEEEGo
gMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
2oooool00ol0003oooooooooo`2/ooooo`;o00002_ooool01Ol0003ooooooooooooooooo000000So
oooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00007ooooo`05o`000?oooooo
ooooooooool000001oooool00ol0003oooooo`000008ooooo`;o0000i_ooool000_ooooo00_oMgMg
ofIVI_ooooooooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`00000;ooooo`Co0000]oooool01Ol0003ooooooooooooo
oooo000000Sooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00008ooooo`04
o`000?ooooooooooo`0000Oooooo00?o0000ooooool000002?ooool2o`000>Kooooo000<ooooo`03
o`000?oooooooooo00;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@413o
oooooooooooooooo410@00_ooooo00?o0000ooooooooool0^?ooool01Ol0003ooooooooooooooooo
000000Sooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00008ooooo`04o`00
0?ooooooooooo`0000Oooooo00?o0000ooooool000002?ooool2o`000>Kooooo0008ooooo`05o`00
0?nj^[[ooooooiRHV?l@41003_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool00ol0003oooooooooo`2hooooo`05o`000?ooooooooooooooool000002?ooool0
1?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo
00001oooool00ol0003oooooo`000008ooooo`;o0000i_ooool000Sooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c00<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03oooo
o`;o00001_ooool00ol0003oooooooooo`2hooooo`05o`000?ooooooooooooooool000002?ooool0
1?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo
00001oooool00ol0003oooooo`000008ooooo`;o0000i_ooool002Oooooo00Co0000oooooooooooo
00001Oooool00ol0003oooooooooo`2iooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooo
oooooooo00002?ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Oooooo
00?o0000ooooool00000l?ooool002Oooooo00Co0000oooooooooooo00001Oooool00ol0003ooooo
ooooo`2iooooo`03o`000?oooooo000000Wooooo00Co0000oooooooooooo00002?ooool01?l0003o
ooooooooool00008ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool00000l?ooool0
02Oooooo0ol00006ooooo`03o`000?oooooooooo0;Wooooo00?o0000ooooool000002Oooool01?l0
003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool000002?oo
ool00ol0003oooooo`00003`ooooo`00:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo0;Wooooo00?o0000ooooool000002Oooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000Sooooo00?o0000ooooool000002?ooool00ol0003oooooo`00003`ooooo`00:Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0;Wooooo00?o0000ooooool000002Ooo
ool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool0
00002?ooool00ol0003oooooo`00003`ooooo`00<?ooool00ol0003oooooooooo`2iooooo`03o`00
0?oooooo000000Wooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00008oooo
o`03o`000?oooooo000000Sooooo00?o0000ooooool00000l?ooool0033ooooo00?o0000oooooooo
ool0^Oooool00ol0003oooooo`000009ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooo
oooooooo00002?ooool00ol0003oooooo`000008ooooo`03o`000?oooooo00000?3ooooo000`oooo
o`03o`000?oooooooooo0;Wooooo00?o0000ooooool000002Oooool01?l0003oooooooooool00008
ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool000002?ooool00ol0003oooooo`00
003`ooooo`00<?ooool3o`000;Wooooo00?o0000ooooool000002Oooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool000002?ooool00ol0003ooooo
o`00003`ooooo`00<?ooool00ol0003oooooooooo`2iooooo`03o`000?oooooo000000Wooooo00Co
0000oooooooooooo00002?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo000000So
oooo00?o0000ooooool00000l?ooool0033ooooo00?o0000ooooooooool0^Oooool00ol0003ooooo
o`000009ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002?ooool00ol0
003oooooo`000008ooooo`03o`000?oooooo00000?3ooooo000`ooooo`03o`000?oooooooooo0;Wo
oooo00?o0000ooooool000002Oooool01?l0003oooooooooool00008ooooo`04o`000?oooooooooo
o`0000Sooooo00?o0000ooooool000002?ooool00ol0003oooooo`00003`ooooo`00<?ooool00ol0
003oooooooooo`2iooooo`03o`000?oooooo000000Wooooo00Co0000oooooooooooo00002?ooool0
1?l0003oooooooooool00008ooooo`03o`000?oooooo000000Wooooo0_l0003`ooooo`00<?ooool0
0ol0003oooooooooo`2iooooo`;o00002_ooool01?l0003oooooooooool00008ooooo`04o`000?oo
ooooooooo`0000Sooooo00?o0000ooooool000002Oooool00ol0003oooooooooo`3_ooooo`00<?oo
ool00ol0003oooooooooo`2jooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooo0000
2?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo000000Wooooo00?o0000oooooooo
ool0koooool0033ooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`08ooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`000009oooo
o`03o`000?oooooooooo0>oooooo000`ooooo`03o`000?oooooooooo0<Kooooo00?o0000ooooool0
00002?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?_ooooo000`ooooo`03
o`000?oooooooooo0<Kooooo00?o0000ooooool000002?ooool01?l0003oooooooooool00008oooo
o`03o`000?oooooo00000?_ooooo000`ooooo`03o`000?oooooooooo0<Kooooo00?o0000ooooool0
00002?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo00000?_ooooo000`ooooo`03
o`000?oooooooooo0<Kooooo00?o0000ooooool000002?ooool01?l0003oooooooooool00008oooo
o`03o`000?oooooo00000?_ooooo000`ooooo`?o0000a_ooool00ol0003oooooo`000008ooooo`04
o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000noooool0033ooooo00?o0000oooooooo
ool0a_ooool00ol0003oooooo`000008ooooo`03o`000?oooooo000000Wooooo00?o0000ooooool0
0000noooool0033ooooo00?o0000ooooooooool0a_ooool2o`0000Wooooo00?o0000ooooool00000
2Oooool00ol0003oooooo`00003kooooo`00<?ooool00ol0003oooooooooo`36ooooo`;o00002_oo
ool2o`0000Wooooo00?o0000ooooool00000noooool0033ooooo00?o0000ooooooooool0a_ooool2
o`0000[ooooo0_l00009ooooo`03o`000?oooooo00000?_ooooo000`ooooo`03o`000?oooooooooo
0<Kooooo0_l0000:ooooo`;o00002_ooool2o`000?_ooooo000`ooooo`03o`000?oooooooooo0<Ko
oooo0_l0000:ooooo`;o00002_ooool00ol0003oooooooooo`3jooooo`00<?ooool00ol0003ooooo
ooooo`36ooooo`;o00002_ooool2o`0000[ooooo00?o0000ooooooooool0n_ooool0033ooooo00?o
0000ooooooooool0a_ooool2o`0000[ooooo0_l0000:ooooo`03o`000?oooooooooo0?[ooooo000`
ooooo`03o`000?oooooooooo0<Kooooo0_l0000:ooooo`;o0000ooooool8ooooo`00<?ooool00ol0
003oooooooooo`37ooooo`03o`000?oooooooooo00Sooooo0_l0003oooooo`Sooooo000`ooooo`03
o`000?oooooooooo0=;ooooo0_l0003oooooo`Sooooo000`ooooo`?o0000d_ooool2o`000?oooooo
2?ooool0033ooooo00?o0000ooooooooool0d_ooool2o`000?oooooo2?ooool0033ooooo00?o0000
ooooooooool0d_ooool2o`000?oooooo2?ooool0033ooooo00?o0000ooooooooool0oooooooLoooo
o`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooo
g?ooool000oooooo0_o^k^h3ooooo`;ok^k^6_ooool00ol0003oooooooooo`3oooooomcooooo000:
ooooo`;o000000[o410@ooooooooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^0oooool4o`00
0008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`03o`000?oooooooooo0?oooooo
g?ooool000_ooooo00?o0000ooooooooool00_ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?o0000oooooooo
ool0oooooooLooooo`002?ooool5o`0000Cooooo00?ogMgMo`000?oMgMd01oooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41002oooool00ol0003oooooooooo`3oooooomco
oooo0008ooooo`04odA4A?oMgMgoooooo`0000Cooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06oooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000;ooooo`03o`000?oooooo
oooo0?oooooog?ooool000Sooooo00CogMgMoeEEEOoooooo00000oooool01oo^k^koEEEEonk^k_oo
ooook^k^oeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
00002oooool4o`000?oooooofoooool000Wooooo00?oMgMgolc<c?l000000oooool2onk^kP?ooooo
0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400;ooooo`03
o`000?oooooooooo0?oooooog?ooool000Wooooo00?ok^k^odA4A?l000003oooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ol0003oooooooooo`3oooooomco
oooo000:ooooo`03ogMgMol0003ooooo00cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00?ooooo0_l00006ooooo`03o`000?oooooooooo0?oooooog?ooool002Oooooo
00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`3oooooomcooooo000Wooooo`04o`00
0?ooooooooooo`0000Gooooo00?o0000ooooooooool0oooooooLooooo`009oooool3o`0000Kooooo
00?o0000ooooooooool0oooooooLooooo`00:?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooog?ooool002Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`?o0000oooo
oooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooo
ooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000
ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03
o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?oo
ool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0
033ooooo0ol0003oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo
00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`
ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLoooo
o`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooo
g?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool3o`000?oooooog?ooool0033ooooo00?o0000ooooooooool0oooo
oooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00oooooooooooooa3ooooo
003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooo
oooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool0
0:3ooooo0_l00004ooooo`03okZj^_lb<S;ooooo00Cooooo0_l00006ooooo`03o`000?nj^[[ooooo
0?ooooooEoooool00:3ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo0_lb<S;ooooooeSooooo002=ooooo`?o00000_ooool01_lb<S;o410@
ooooooooooook^k^oeEEE@;o000000?oA4A4okZj^_ooool00oooool00ol0003oooooooooo`02oooo
o`05oiRHV?l@413o0000o`000?nYZJT01?ooool00ol0003oooooooooo`04ooooo`03ohN7Qol0003o
^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P09ooooo`04oa0@4?l0003oA4A4olc<c0Kooooo
0_lQ8B44ooooo`0;olc<c?lQ8B7o0000ob4Q8Oo<c<coooooolc<c?o^k^koooooonk^k_o<c<`01?oo
ool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hCooooo`06oa0@4?lb<S;o0000
o`000?l@413oZJVY0_ooool01_o^k^koEEEEo`000?l0003oA4A4okZj^P?ooooo00GoIVIVo`000?l0
003oA4A4olc<c03Xooooo`00S_ooool01Ol0003oooooooooooo<c<co410@00?ooooo00KoEEEEogMg
Moooooook^k^ogMgMol@4104ooooo`03o`000?oooooooooo00;ooooo00Ko0000ojVYZOmEEEGoV9RH
oeEEEOnj^[X3ooooo`03o`000?oooooooooo00Cooooo00?oc<c<o`000?l@41003?ooool01_l@413o
^[Zjonk^k_mgMgOo410@ooooo`Ko00001?ooool00onHV9So410@omgMg@05ooooo`;o8B4Q1?ooool0
2olQ8B7oV9RHoooooonHV9So8B4Qooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000oooo
ooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01?ooooo00Ko0000ojVYZOoooooooooookZj
^_l00002ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo410@0_ooool01_mVIVKoMgMgoooooooooooo
QhN7oa0@4>Sooooo002>ooooo`05o`000?oooooooooooeEEEOn7QhL00oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00;ooooo00Ko<S8bonk^k_nHV9SoEEEEomgMgOl@4103ooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool03_ooool00on7QhOoEEEEooooo`0:ooooo`05
o`000?ooooooooooooooool000000_ooool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo
00;ooooo00Go410@oooooooooooooooooa0@400Dooooo`05okZj^_n7QhOoIVIVofIVI_l@41000_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0>_ooooo002>ooooo`05o`000?oooooo
gMgMo`000?o^k^h00oooool6o`0000Cooooo00?o0000ooooooooool00_ooool01onj^[[oA4A4olc<
c?lQ8B7ooooooa0@4?o<c<`00_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00?o
oooo1_l00002ooooo`05olc<c?lQ8B7o0000oeEEEOl000002oooool02olb<S;oV9RHoooooonHV9So
<S8booooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000001?ooooo00Ko<S8bob4Q8OmgMgOoMgMgohN7Qoo^k^h2ooooo`Ko00000_oo
ool00ol0003oooooooooo`3[ooooo`00S_ooool3o`000003oa0@4?nHV9Sooooo00;ooooo00KoEEEE
ohN7Qoo^k^koooooohN7Qolb<S84ooooo`03o`000?oooooooooo00;ooooo00Ook^k^o`000?oooooo
0000oooooomVIVKoQhN700;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0;oooo
o`05ob4Q8On7QhOooooooiRHV?l000002oooool02oo<c<co0000o`000?l0003oc<c<ooooooo<c<co
k^k^ooooooo^k^koc<c<00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo
000001?ooooo00Ko0000okZj^_ooooook^k^ogMgMol00002ooooo`06oeEEEOn7QhOok^k^oooooon7
QhOo<S8b0_ooool01_mVIVKoMgMgooooooooooooQhN7o`000>Sooooo002>ooooo`05o`000?oooooo
ooooolc<c?l000000oooool01_o^k^koEEEEo`000?l0003oA4A4onk^kPCooooo00?o0000oooooooo
ool00_ooool01?mVIVKoV9RHoooooolb<S82okZj^P04o`000?ooooooooooo`0001?ooooo00?o410@
o`000?l000000ol0000:ooooo`05o`000?ooooooooooooooool000002oooool01Ol@413o^[Zjoooo
oonj^[[o410@00cooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Oo
oooo0ol00002ooooo`?o00001?ooool01_nYZJWo8B4Qo`000?l0003o<S8bo`0000;ooooo00Kok^k^
oeEEEOl0003o0000odA4A?o^k^h2ooooo`06onk^k_mVIVKo0000o`000?m4A4Co0000j?ooool008ko
oooo00Go0000ooooooooooooc<c<o`00000=ooooo`03o`000?oooooooooo00Gooooo00?oIVIVohN7
Qoooool00oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00_ooooo00Go8B4QoiRH
V?ooooooMgMgoeEEE@0;ooooo`05o`000?nj^[[ooooookZj^_l000003?ooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo0?oooooo0_ooool008gooooo1?l000000ol@413oZJVYooooo`0<ooooo`;o00001_oo
ool00onYZJWoA4A4ooooo`02ooooo`;o00005Oooool00ol0003oooooooooo`0;ooooo`05olc<c?l@
413o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00[ooooo00?oEEEEofIVI_l0
00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo1?l00002ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0ooooool2ooooo`00ooooool6ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0ooooool2ooooo`00ooooool6ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0ooooool2ooooo`00ooooool5ooooo`;o00000oooool2o`000?oooooo1?oo
ool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooo
ooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@oooo
o`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooo
oooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo
003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooo
oooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo0000\
\>"],
  ImageRangeCache->{{{0, 525.688}, {324.5, 0}} -> {-2.58312*^-7, -6.34248*^6, \
6.65005*^-9, 53093.5}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0.309017 5.42214e-08 [
[.32684 .29652 -16.5 -12.5 ]
[.32684 .29652 16.5 0 ]
[.54329 .29652 -16.5 -12.5 ]
[.54329 .29652 16.5 0 ]
[.75974 .29652 -22.5 -12.5 ]
[.75974 .29652 22.5 0 ]
[.97619 .29652 -16.5 -12.5 ]
[.97619 .29652 16.5 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 64 6 ]
[.09789 .09213 -34.5 -6.25 ]
[.09789 .09213 0 6.25 ]
[.09789 .20057 -34.5 -6.25 ]
[.09789 .20057 0 6.25 ]
[.09789 .41746 -28.5 -6.25 ]
[.09789 .41746 0 6.25 ]
[.09789 .5259 -28.5 -6.25 ]
[.09789 .5259 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -62.8125 0 ]
[.5 .63053 62.8125 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 .30902 m
.32684 .31527 L
s
gsave
.32684 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 .30902 m
.54329 .31527 L
s
gsave
.54329 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 .30902 m
.75974 .31527 L
s
gsave
.75974 .29652 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 .30902 m
.15368 .31277 L
s
.19697 .30902 m
.19697 .31277 L
s
.24026 .30902 m
.24026 .31277 L
s
.28355 .30902 m
.28355 .31277 L
s
.37013 .30902 m
.37013 .31277 L
s
.41342 .30902 m
.41342 .31277 L
s
.45671 .30902 m
.45671 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.58658 .30902 m
.58658 .31277 L
s
.62987 .30902 m
.62987 .31277 L
s
.67316 .30902 m
.67316 .31277 L
s
.71645 .30902 m
.71645 .31277 L
s
.80303 .30902 m
.80303 .31277 L
s
.84632 .30902 m
.84632 .31277 L
s
.88961 .30902 m
.88961 .31277 L
s
.9329 .30902 m
.9329 .31277 L
s
.0671 .30902 m
.0671 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09213 m
.11664 .09213 L
s
gsave
.09789 .09213 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .20057 m
.11664 .20057 L
s
gsave
.09789 .20057 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .41746 m
.11664 .41746 L
s
gsave
.09789 .41746 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .5259 m
.11664 .5259 L
s
gsave
.09789 .5259 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.11039 .11924 m
.11414 .11924 L
s
.11039 .14635 m
.11414 .14635 L
s
.11039 .17346 m
.11414 .17346 L
s
.11039 .22768 m
.11414 .22768 L
s
.11039 .2548 m
.11414 .2548 L
s
.11039 .28191 m
.11414 .28191 L
s
.11039 .33613 m
.11414 .33613 L
s
.11039 .36324 m
.11414 .36324 L
s
.11039 .39035 m
.11414 .39035 L
s
.11039 .44457 m
.11414 .44457 L
s
.11039 .47168 m
.11414 .47168 L
s
.11039 .49879 m
.11414 .49879 L
s
.11039 .06502 m
.11414 .06502 L
s
.11039 .03791 m
.11414 .03791 L
s
.11039 .0108 m
.11414 .0108 L
s
.11039 .55301 m
.11414 .55301 L
s
.11039 .58012 m
.11414 .58012 L
s
.11039 .60723 m
.11414 .60723 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -123.812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.812 moveto
(@) show
81.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.812 moveto
(D) show
93.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10.) show
135.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
141.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
153.000 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
157.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
166.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
184.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02453 .30902 L
.02532 .30902 L
.02614 .30902 L
.02691 .30902 L
.02777 .30902 L
.02854 .30902 L
.02945 .30902 L
.03029 .30902 L
.03183 .30902 L
.03264 .30902 L
.0335 .30902 L
.03507 .30902 L
.03653 .30902 L
.03816 .30902 L
.03965 .30902 L
.04117 .30902 L
.04283 .30902 L
.04441 .30902 L
.0461 .30902 L
.04782 .30902 L
.04943 .30902 L
.05253 .30902 L
.05413 .30902 L
.05582 .30902 L
.05887 .30902 L
.06043 .30902 L
.06211 .30902 L
.0637 .30902 L
.06543 .30902 L
.06863 .30902 L
.07022 .30902 L
.0719 .30902 L
.07493 .30902 L
.07649 .30902 L
.07816 .30902 L
.08146 .30902 L
.08464 .30902 L
.0877 .30902 L
.09096 .30902 L
.09409 .30902 L
.09742 .30902 L
.10063 .30902 L
.10372 .30902 L
.10701 .30902 L
.11017 .30902 L
.11321 .30902 L
.11645 .30902 L
.11956 .30902 L
.12288 .30902 L
Mistroke
.12607 .30902 L
.12914 .30902 L
.13085 .30902 L
.1324 .30902 L
.13318 .30902 L
.13359 .30902 L
.13403 .30902 L
.1344 .30902 L
.13482 .30902 L
.135 .30902 L
.1352 .30902 L
.13538 .30902 L
.13555 .30902 L
.13564 .30902 L
.13573 .30902 L
.13583 .30902 L
.13594 .30902 L
.13604 .30902 L
.13609 .30902 L
.13615 .30902 L
.13625 .30902 L
.13635 .30902 L
.13653 .30902 L
.1367 .30902 L
.13708 .30902 L
.1373 .30902 L
.1375 .30902 L
.13794 .30902 L
.13875 .30902 L
.13953 .30902 L
.14026 .30902 L
.14106 .30902 L
.14192 .30902 L
.14362 .30902 L
.14524 .30902 L
.14683 .30902 L
.14831 .30902 L
.14993 .30902 L
.15146 .30902 L
.15449 .30902 L
.15759 .30902 L
.16089 .30902 L
.16407 .30902 L
.16712 .30902 L
.17038 .30902 L
.17351 .30902 L
.17684 .30902 L
.18004 .30902 L
.18313 .30902 L
.18472 .30902 L
Mistroke
.18553 .30902 L
.18598 .30902 L
.18641 .30902 L
.1868 .30902 L
.18701 .30902 L
.18722 .30902 L
.18743 .30902 L
.18761 .30902 L
.1877 .30902 L
.1878 .30902 L
.18788 .30902 L
.18797 .30902 L
.18807 .30902 L
.18817 .30902 L
.18823 .30902 L
.18829 .30902 L
.18839 .30902 L
.18845 .30902 L
.18851 .30902 L
.18861 .30902 L
.18872 .30902 L
.18884 .30902 L
.18904 .30902 L
.18926 .30902 L
.18965 .30902 L
.19004 .30902 L
.19041 .30902 L
.19126 .30902 L
.19207 .30902 L
.19295 .30902 L
.19377 .30902 L
.19466 .30902 L
.19628 .30902 L
.19788 .30902 L
.19957 .30902 L
.20261 .30902 L
.20417 .30902 L
.20585 .30902 L
.20917 .30902 L
.21236 .30902 L
.21543 .30902 L
.2187 .30902 L
.22184 .30902 L
.22345 .30902 L
.2243 .30902 L
.22519 .30902 L
.22599 .30902 L
.22641 .30902 L
.22687 .30902 L
.22729 .30902 L
Mistroke
.22767 .30902 L
.22785 .30902 L
.22805 .30902 L
.22814 .30902 L
.22824 .30902 L
.22833 .30902 L
.22841 .30902 L
.22851 .30902 L
.22861 .30902 L
.2287 .30902 L
.2288 .30902 L
.2289 .30902 L
.22899 .30902 L
.22908 .30902 L
.22916 .30902 L
.22937 .30902 L
.22959 .30902 L
.22998 .30902 L
.23034 .30902 L
.23068 .30902 L
.23145 .30902 L
.23228 .30902 L
.23308 .30902 L
.23457 .30902 L
.23617 .30902 L
.23764 .30902 L
.23927 .30902 L
.24079 .30902 L
.24382 .30902 L
.24693 .30902 L
.25023 .30902 L
.25341 .30902 L
.25647 .30902 L
.25817 .30902 L
.25972 .30902 L
.26049 .30902 L
.2609 .30902 L
.26133 .30902 L
.26171 .30902 L
.26191 .30902 L
.26212 .30902 L
.26232 .30902 L
.2625 .30902 L
.26259 .30902 L
.26268 .30902 L
.26277 .30902 L
.26285 .30902 L
.26296 .30902 L
.26301 .30902 L
.26307 .30902 L
Mistroke
.26317 .30902 L
.26326 .30902 L
.26337 .30902 L
.26348 .30902 L
.2637 .30902 L
.2639 .30902 L
.26412 .30902 L
.2645 .30902 L
.26488 .30902 L
.26528 .30902 L
.266 .30902 L
.26675 .30902 L
.26756 .30902 L
.26903 .30902 L
.27064 .30902 L
.27234 .30902 L
.2754 .30901 L
.27866 .30901 L
.2818 .309 L
.28513 .30899 L
.2868 .30898 L
.28834 .30898 L
.28984 .30898 L
.2906 .30898 L
.29103 .30898 L
.29143 .30898 L
.29182 .30898 L
.29203 .30898 L
.29225 .30898 L
.29243 .30898 L
.29253 .30898 L
.29264 .30898 L
.29273 .30898 L
.29282 .30898 L
.29291 .30898 L
.293 .30898 L
.2931 .30898 L
.2932 .30898 L
.29325 .30898 L
.29331 .30898 L
.29341 .30898 L
.29351 .30898 L
.29361 .30898 L
.2938 .30898 L
.29401 .30898 L
.29421 .30898 L
.29467 .30898 L
.29507 .30898 L
.29551 .30898 L
.2963 .30898 L
Mistroke
.29707 .30898 L
.29779 .30898 L
.29943 .30899 L
.30093 .309 L
.30414 .30902 L
.30724 .30906 L
.31053 .3091 L
.3137 .30914 L
.3153 .30916 L
.31675 .30917 L
.3175 .30918 L
.31832 .30918 L
.31876 .30918 L
.31918 .30919 L
.31958 .30919 L
.31978 .30919 L
.31989 .30919 L
.32 .30919 L
.32009 .30919 L
.32018 .30919 L
.32028 .30919 L
.32034 .30919 L
.32039 .30919 L
.32049 .30919 L
.32059 .30919 L
.3207 .30919 L
.32075 .30919 L
.32081 .30919 L
.32099 .30919 L
.3211 .30919 L
.32119 .30919 L
.32155 .30919 L
.32176 .30918 L
.32196 .30918 L
.32241 .30918 L
.32322 .30918 L
.32407 .30917 L
.32487 .30916 L
.32637 .30913 L
.32798 .30909 L
.32947 .30905 L
.33264 .30893 L
.3357 .30879 L
.33894 .30864 L
.34044 .30857 L
.34207 .30852 L
.34296 .30849 L
.34335 .30849 L
.34378 .30848 L
.34416 .30847 L
Mistroke
.34457 .30847 L
.34479 .30847 L
.34499 .30846 L
.34509 .30846 L
.3452 .30846 L
.3453 .30846 L
.3454 .30846 L
.3455 .30846 L
.34555 .30846 L
.34561 .30846 L
.34571 .30846 L
.3458 .30846 L
.34586 .30846 L
.34592 .30846 L
.34602 .30846 L
.34613 .30846 L
.34624 .30846 L
.34645 .30847 L
.34666 .30847 L
.34704 .30847 L
.34741 .30848 L
.34775 .30849 L
.34854 .30851 L
.34932 .30854 L
.35015 .30858 L
.35164 .30868 L
.35322 .30881 L
.3547 .30896 L
.35783 .30936 L
.36116 .30983 L
.36283 .31006 L
.36436 .31024 L
.36586 .31038 L
.36662 .31044 L
.36705 .31047 L
.36745 .31049 L
.36784 .3105 L
.36805 .31051 L
.36827 .31051 L
.36847 .31052 L
.36856 .31052 L
.36865 .31052 L
.36874 .31052 L
.36884 .31052 L
.36892 .31052 L
.36901 .31052 L
.36911 .31052 L
.36921 .31052 L
.36926 .31052 L
.36932 .31052 L
Mistroke
.36942 .31052 L
.36952 .31052 L
.36962 .31052 L
.36981 .31051 L
.37002 .31051 L
.37023 .3105 L
.37069 .31048 L
.37106 .31045 L
.37148 .31042 L
.37231 .31034 L
.37308 .31024 L
.37379 .31013 L
.37544 .3098 L
.37693 .30942 L
.38014 .30839 L
.38323 .30726 L
.3848 .30671 L
.38652 .30618 L
.38731 .30597 L
.38815 .30579 L
.38895 .30565 L
.38934 .3056 L
.38968 .30556 L
.39007 .30552 L
.39028 .30551 L
.39037 .30551 L
.39048 .3055 L
.39056 .3055 L
.39066 .3055 L
.39075 .30549 L
.39083 .30549 L
.39093 .30549 L
.39101 .30549 L
.39112 .30549 L
.39121 .30549 L
.39131 .30549 L
.39141 .3055 L
.39152 .3055 L
.39163 .30551 L
.39181 .30552 L
.39201 .30553 L
.39246 .30558 L
.39288 .30564 L
.39367 .30579 L
.3944 .30599 L
.39606 .30661 L
.39771 .30747 L
.3992 .30844 L
.40242 .31094 L
.40551 .31347 L
Mistroke
.40708 .3146 L
.40791 .31512 L
.4088 .31558 L
.40966 .31594 L
.41007 .31607 L
.41044 .31617 L
.41082 .31624 L
.41102 .31627 L
.41123 .3163 L
.41132 .3163 L
.41141 .31631 L
.4115 .31632 L
.41158 .31632 L
.41167 .31632 L
.41177 .31632 L
.41188 .31632 L
.41197 .31632 L
.41208 .31632 L
.41213 .31631 L
.41218 .31631 L
.41238 .31629 L
.41249 .31628 L
.41261 .31626 L
.41282 .31622 L
.41324 .31613 L
.41362 .31601 L
.41438 .31568 L
.41511 .31526 L
.4167 .31397 L
.41818 .31234 L
.42132 .30778 L
.42466 .3022 L
.42634 .29961 L
.42788 .29761 L
.42866 .2968 L
.42939 .29619 L
.42979 .29593 L
.43015 .29573 L
.43055 .29556 L
.43077 .29549 L
.43098 .29544 L
.43107 .29542 L
.43117 .2954 L
.43127 .29539 L
.43135 .29538 L
.43145 .29538 L
.43155 .29538 L
.4316 .29538 L
.43166 .29538 L
.43176 .29538 L
Mistroke
.43181 .29539 L
.43186 .29539 L
.43198 .29541 L
.43208 .29543 L
.43219 .29545 L
.43238 .2955 L
.43258 .29557 L
.43295 .29574 L
.43335 .29599 L
.43406 .29659 L
.43488 .29752 L
.43576 .29883 L
.43738 .30197 L
.44065 .3107 L
.4438 .32037 L
.44538 .32483 L
.44683 .32826 L
.44757 .32968 L
.44838 .33091 L
.4488 .33141 L
.44919 .33178 L
.4494 .33194 L
.44961 .33206 L
.44972 .33212 L
.44984 .33217 L
.44995 .33221 L
.45005 .33224 L
.45015 .33227 L
.45024 .33228 L
.45034 .33229 L
.45044 .33229 L
.45053 .33229 L
.45063 .33228 L
.45072 .33227 L
.45081 .33225 L
.45092 .33222 L
.45101 .33218 L
.45124 .33207 L
.45143 .33195 L
.45164 .33179 L
.45206 .33137 L
.45245 .33087 L
.45333 .32933 L
.45417 .32734 L
.45497 .32501 L
.45646 .31957 L
.45953 .30501 L
.46281 .28819 L
.46443 .28105 L
.46523 .27816 L
Mistroke
.46596 .27595 L
.46667 .27426 L
.46703 .2736 L
.46742 .27302 L
.46762 .27279 L
.46781 .27261 L
.46792 .27253 L
.46803 .27246 L
.46813 .27241 L
.46823 .27236 L
.46833 .27233 L
.46843 .27231 L
.46852 .27231 L
.46863 .27231 L
.46873 .27232 L
.46882 .27235 L
.4689 .27238 L
.46899 .27242 L
.4692 .27256 L
.46942 .27276 L
.46982 .27327 L
.47022 .27396 L
.47058 .27476 L
.4714 .27717 L
.47226 .28056 L
.47384 .28889 L
.47531 .29876 L
.47844 .32363 L
.48004 .33641 L
.48177 .34864 L
.48258 .35337 L
.48343 .35749 L
.48416 .36017 L
.48458 .36132 L
.48497 .36214 L
.48518 .36247 L
.48537 .3627 L
.48548 .36281 L
.48558 .36289 L
.48564 .36293 L
.4857 .36296 L
.48575 .36298 L
.4858 .363 L
.4859 .36302 L
.486 .36302 L
.48611 .363 L
.48616 .36299 L
.48622 .36296 L
.48631 .36291 L
.48641 .36284 L
Mistroke
.4866 .36265 L
.48677 .36241 L
.48697 .36208 L
.48737 .36118 L
.48774 .36008 L
.48808 .35881 L
.48887 .35509 L
.4897 .34995 L
.49119 .33792 L
.49424 .30471 L
.4975 .26648 L
.499 .25178 L
.49979 .24551 L
.50063 .24024 L
.50105 .23817 L
.50152 .23639 L
.50173 .23578 L
.50195 .23524 L
.50215 .23485 L
.50234 .23459 L
.50244 .23449 L
.50255 .23441 L
.50265 .23437 L
.50274 .23435 L
.5028 .23436 L
.50285 .23436 L
.5029 .23438 L
.50296 .23441 L
.50306 .23448 L
.50317 .23459 L
.50328 .23472 L
.50337 .23486 L
.50358 .23527 L
.50396 .23633 L
.50435 .23782 L
.50476 .23985 L
.50549 .24464 L
.50629 .25139 L
.50716 .26063 L
.51039 .30715 L
.5135 .35809 L
.51508 .38025 L
.51591 .3898 L
.51637 .39426 L
.5168 .39789 L
.51722 .40082 L
.51767 .40335 L
.51787 .40424 L
.51808 .40504 L
.51827 .40564 L
Mistroke
.51845 .40607 L
.51854 .40623 L
.51864 .40638 L
.51874 .4065 L
.51883 .40657 L
.51892 .40662 L
.51901 .40663 L
.5191 .40661 L
.51918 .40656 L
.51929 .40647 L
.51938 .40635 L
.51949 .40618 L
.5196 .40595 L
.51978 .40546 L
.51999 .40478 L
.52041 .40284 L
.52081 .40039 L
.52156 .39417 L
.52236 .38522 L
.52324 .37303 L
.52652 .31038 L
.52968 .24316 L
.53126 .21552 L
.53196 .20591 L
.53272 .19754 L
.53313 .19398 L
.53351 .19136 L
.53388 .18951 L
.53409 .18875 L
.53427 .18824 L
.53438 .18802 L
.53444 .18793 L
.53449 .18785 L
.53458 .18776 L
.53469 .18771 L
.53475 .1877 L
.5348 .18771 L
.5349 .18777 L
.53496 .18783 L
.53502 .18789 L
.53514 .1881 L
.53523 .18831 L
.53532 .18856 L
.53553 .18928 L
.53573 .19018 L
.53595 .19138 L
.53635 .1942 L
.53672 .19753 L
.53756 .20752 L
.53838 .22036 L
Mistroke
.53925 .23713 L
.54258 .32041 L
.54425 .36539 L
.54579 .40261 L
.54729 .43097 L
.54805 .44129 L
.54848 .44578 L
.54888 .44904 L
.54907 .45027 L
.54928 .45133 L
.5494 .45182 L
.54951 .4522 L
.54962 .4525 L
.54972 .45272 L
.54981 .45287 L
.54991 .45297 L
.55001 .453 L
.55007 .45299 L
.55012 .45296 L
.55022 .45286 L
.55031 .45272 L
.55041 .4525 L
.55051 .45223 L
.55069 .45157 L
.55088 .45064 L
.55122 .44841 L
.55159 .44519 L
.552 .44067 L
.55281 .42869 L
.55355 .41447 L
.55523 .37278 L
.55841 .27268 L
.56002 .2232 L
.56148 .18555 L
.56229 .16911 L
.56305 .15724 L
.56347 .15236 L
.56386 .14895 L
.56406 .1476 L
.56429 .14646 L
.5644 .14602 L
.56452 .14566 L
.56458 .14552 L
.56463 .14541 L
.56474 .14527 L
.56483 .14521 L
.56493 .14522 L
.56502 .14529 L
.5651 .14542 L
.5652 .14562 L
Mistroke
.5653 .14592 L
.56551 .14677 L
.56572 .14793 L
.56594 .14952 L
.56633 .15329 L
.56673 .15825 L
.56711 .16397 L
.56781 .17731 L
.56942 .21905 L
.5709 .26819 L
.57406 .38373 L
.57564 .43372 L
.57634 .45152 L
.5771 .46737 L
.57751 .47429 L
.5779 .47952 L
.57826 .48341 L
.57847 .4851 L
.57865 .48632 L
.57876 .48688 L
.57887 .48737 L
.57897 .48771 L
.57907 .48799 L
.57913 .4881 L
.57918 .48818 L
.57924 .48825 L
.5793 .48828 L
.57941 .48825 L
.57946 .4882 L
.57952 .48812 L
.57961 .48793 L
.57971 .48767 L
.57981 .4873 L
.57991 .48681 L
.58013 .4855 L
.58033 .48393 L
.58071 .48001 L
.58112 .47448 L
.58185 .46112 L
.58272 .43995 L
.58351 .41633 L
.58672 .29347 L
.5882 .23456 L
.58981 .17838 L
.59058 .15697 L
.59141 .13889 L
.59187 .13133 L
.59228 .12603 L
.59248 .12405 L
.5927 .12231 L
Mistroke
.5928 .12166 L
.59291 .12108 L
.59301 .12063 L
.5931 .1203 L
.5932 .12003 L
.59325 .11993 L
.59331 .11985 L
.59337 .11979 L
.59343 .11978 L
.59353 .11983 L
.59363 .11997 L
.59372 .12018 L
.59382 .12051 L
.59393 .12097 L
.59415 .12225 L
.59435 .12387 L
.59482 .12904 L
.59523 .1352 L
.5956 .14214 L
.59644 .16209 L
.59797 .21146 L
.59963 .27883 L
.60134 .35305 L
.60289 .41539 L
.60367 .44218 L
.60451 .46649 L
.60489 .47576 L
.6053 .48415 L
.60568 .49052 L
.60603 .49532 L
.60622 .49738 L
.60643 .49922 L
.60662 .50051 L
.60679 .50139 L
.60689 .50174 L
.60698 .50199 L
.60708 .50216 L
.60714 .50221 L
.60719 .50223 L
.60729 .50219 L
.60734 .50213 L
.60739 .50204 L
.6075 .50177 L
.60756 .50158 L
.60761 .50137 L
.6078 .50039 L
.60797 .49916 L
.60837 .49526 L
.60871 .49055 L
.60908 .48427 L
Mistroke
.60984 .46741 L
.61065 .44387 L
.61212 .38982 L
.61543 .24488 L
.61709 .1813 L
.61789 .15677 L
.61862 .13923 L
.61899 .13224 L
.61939 .12619 L
.61957 .12395 L
.61976 .12195 L
.61995 .12043 L
.62011 .11934 L
.6202 .11887 L
.6203 .11845 L
.6204 .11812 L
.6205 .11791 L
.62059 .1178 L
.62069 .11779 L
.62077 .11786 L
.62086 .11802 L
.62092 .11816 L
.62097 .11833 L
.62107 .11871 L
.62118 .11924 L
.62129 .11996 L
.6215 .12159 L
.62169 .12351 L
.6221 .12881 L
.62254 .13641 L
.62334 .15487 L
.62483 .20333 L
.62812 .34444 L
.62975 .4114 L
.63055 .43885 L
.63128 .45968 L
.63164 .46828 L
.63204 .47626 L
.63238 .48195 L
.63275 .48689 L
.63296 .48896 L
.63315 .49052 L
.63335 .49173 L
.63347 .49222 L
.63357 .49255 L
.63366 .49275 L
.63375 .49284 L
.63384 .49286 L
.63394 .49278 L
.63404 .49258 L
Mistroke
.63414 .49229 L
.63423 .49193 L
.63433 .49145 L
.63452 .49023 L
.63472 .4885 L
.63509 .4843 L
.63552 .47753 L
.63592 .46972 L
.63679 .44783 L
.63761 .42154 L
.64068 .2961 L
.64239 .22602 L
.64394 .17546 L
.64472 .1572 L
.64515 .14935 L
.64556 .14379 L
.64591 .14026 L
.64611 .13882 L
.6463 .13785 L
.6464 .13748 L
.6465 .13723 L
.64658 .13708 L
.64668 .13701 L
.64678 .13704 L
.64683 .1371 L
.64689 .13719 L
.64699 .13744 L
.64708 .13776 L
.64718 .13818 L
.64728 .13873 L
.64746 .13998 L
.64767 .14191 L
.64787 .14407 L
.6483 .15007 L
.6487 .15733 L
.64941 .17368 L
.65019 .19594 L
.65347 .32155 L
.65511 .38437 L
.65591 .41069 L
.65664 .43099 L
.657 .43947 L
.65739 .44747 L
.65776 .45383 L
.6581 .45845 L
.6585 .46246 L
.65872 .46401 L
.65882 .46457 L
.65892 .46505 L
.65901 .46537 L
Mistroke
.65911 .46564 L
.6592 .46579 L
.65928 .46587 L
.65938 .46586 L
.65947 .46577 L
.65958 .46557 L
.65968 .46528 L
.65977 .46492 L
.65987 .46445 L
.66005 .46335 L
.66026 .46163 L
.66046 .45969 L
.66088 .45426 L
.66128 .4476 L
.66199 .43262 L
.66276 .41202 L
.66602 .297 L
.66753 .24385 L
.66832 .21977 L
.66916 .19863 L
.66959 .18987 L
.67005 .18195 L
.67048 .17637 L
.67088 .1726 L
.67109 .17119 L
.67119 .17065 L
.67129 .17023 L
.67137 .16993 L
.67146 .16967 L
.67156 .16949 L
.67166 .16939 L
.67171 .16938 L
.67177 .16939 L
.67187 .16948 L
.67192 .16957 L
.67197 .16967 L
.67209 .17001 L
.67219 .17041 L
.67229 .17085 L
.6725 .17213 L
.67268 .17358 L
.67288 .17552 L
.6733 .18053 L
.67403 .19293 L
.6749 .21236 L
.6757 .23452 L
.67882 .33627 L
.6804 .38294 L
.6813 .40367 L
.68173 .4117 L
Mistroke
.68213 .41802 L
.68252 .42295 L
.68272 .42506 L
.68294 .42692 L
.68312 .42819 L
.68332 .42927 L
.68341 .42964 L
.6835 .42997 L
.68359 .43021 L
.68367 .43037 L
.68378 .43049 L
.68383 .43052 L
.68388 .43053 L
.68398 .43048 L
.68408 .43036 L
.68413 .43026 L
.68419 .43012 L
.68429 .42982 L
.6844 .4294 L
.68452 .42883 L
.68472 .42761 L
.68493 .42596 L
.68532 .42209 L
.68575 .41649 L
.68614 .4102 L
.68703 .39238 L
.68865 .35045 L
.69029 .30244 L
.69182 .26024 L
.69257 .24253 L
.69329 .22845 L
.69368 .22198 L
.69411 .21609 L
.6945 .21183 L
.69486 .20884 L
.69507 .20752 L
.69527 .2066 L
.69537 .20623 L
.69549 .20592 L
.69554 .20579 L
.6956 .20569 L
.69566 .20561 L
.69571 .20556 L
.69582 .20553 L
.69591 .20556 L
.69601 .20567 L
.69607 .20576 L
.69612 .20588 L
.69622 .20613 L
.69633 .20648 L
Mistroke
.69651 .2073 L
.6967 .20839 L
.69691 .20987 L
.69729 .21333 L
.69801 .22231 L
.69884 .23636 L
.69959 .25185 L
.70127 .29251 L
.70295 .33423 L
.70368 .35079 L
.70449 .36668 L
.70521 .37839 L
.70561 .38363 L
.70599 .38774 L
.7062 .38962 L
.70642 .39137 L
.70661 .39258 L
.70681 .39367 L
.70701 .39445 L
.70711 .39478 L
.70721 .39502 L
.7073 .39519 L
.70739 .3953 L
.70748 .39536 L
.70758 .39537 L
.70768 .39532 L
.70774 .39526 L
.70779 .39519 L
.70788 .39502 L
.70798 .39478 L
.70816 .39422 L
.70835 .39338 L
.70877 .39076 L
.70917 .38737 L
.70988 .37918 L
.71064 .36775 L
.71395 .30104 L
.71561 .26935 L
.71641 .25706 L
.71714 .24836 L
.71751 .24495 L
.71791 .24204 L
.71809 .24098 L
.71829 .24005 L
.71845 .23942 L
.71863 .23889 L
.71874 .23866 L
.71884 .2385 L
.71893 .2384 L
.71903 .23835 L
Mistroke
.71908 .23834 L
.71913 .23834 L
.71919 .23837 L
.71925 .23841 L
.71934 .23852 L
.71945 .23869 L
.71954 .23889 L
.71964 .23917 L
.71985 .23988 L
.72021 .24167 L
.72064 .24459 L
.72104 .2481 L
.72179 .25647 L
.72347 .28175 L
.72657 .33428 L
.72739 .34575 L
.72816 .35443 L
.72858 .35821 L
.72897 .36102 L
.7294 .36339 L
.72963 .36436 L
.72974 .36472 L
.72985 .36505 L
.72995 .36529 L
.73004 .36546 L
.73013 .3656 L
.73022 .3657 L
.73032 .36578 L
.73042 .36581 L
.73052 .36579 L
.73058 .36576 L
.73063 .36573 L
.73073 .36561 L
.73083 .36547 L
.73094 .36526 L
.73105 .36498 L
.73124 .36439 L
.73145 .36357 L
.73182 .3617 L
.73221 .35909 L
.73293 .35298 L
.73463 .33283 L
.73624 .31007 L
.73785 .28861 L
.73855 .28075 L
.73931 .27373 L
.73973 .27058 L
.74012 .26822 L
.74049 .26646 L
.7407 .2657 L
Mistroke
.74089 .26514 L
.74109 .26468 L
.7412 .26449 L
.7413 .26436 L
.7414 .26426 L
.74149 .26421 L
.74158 .26418 L
.74169 .26419 L
.74179 .26424 L
.74185 .26429 L
.7419 .26434 L
.742 .26446 L
.74211 .26462 L
.74233 .2651 L
.74257 .26581 L
.74299 .26754 L
.74339 .26968 L
.74414 .27493 L
.74583 .29113 L
.74892 .32485 L
.74974 .33206 L
.75051 .33743 L
.7509 .33955 L
.75132 .34137 L
.75155 .34219 L
.75178 .34281 L
.75198 .34324 L
.7521 .34343 L
.7522 .34358 L
.7523 .34368 L
.75241 .34376 L
.75251 .34381 L
.75257 .34382 L
.75263 .34383 L
.75273 .34381 L
.75282 .34376 L
.75288 .34373 L
.75293 .34368 L
.75303 .34357 L
.75322 .3433 L
.75342 .34289 L
.75378 .34189 L
.7542 .34034 L
.75459 .3385 L
.75547 .33312 L
.75858 .30701 L
.76016 .29447 L
.76106 .28896 L
.76148 .28687 L
.76189 .28524 L
Mistroke
.76228 .28402 L
.76248 .28352 L
.7627 .28309 L
.76288 .28281 L
.76298 .28269 L
.76308 .28259 L
.76317 .28251 L
.76326 .28247 L
.76335 .28244 L
.76343 .28242 L
.76352 .28243 L
.76363 .28246 L
.76368 .28248 L
.76374 .28251 L
.76384 .28259 L
.76394 .28268 L
.76404 .2828 L
.76422 .28307 L
.76463 .28394 L
.76507 .28528 L
.7659 .28869 L
.76665 .29269 L
.76833 .30357 L
.77 .31471 L
.77073 .31904 L
.77154 .32307 L
.77191 .32462 L
.77231 .32604 L
.77266 .32706 L
.77304 .32793 L
.77326 .32833 L
.77346 .32861 L
.77366 .32882 L
.77377 .3289 L
.77387 .32896 L
.77396 .329 L
.77405 .32902 L
.77415 .32903 L
.77426 .32902 L
.77435 .32899 L
.77443 .32895 L
.77452 .3289 L
.77462 .32882 L
.77483 .32862 L
.77505 .32832 L
.77544 .32759 L
.77586 .32654 L
.77633 .32509 L
.77795 .31825 L
.77963 .30962 L
Mistroke
.78118 .30221 L
.78196 .29913 L
.78269 .29686 L
.78306 .29597 L
.78345 .29521 L
.78368 .29487 L
.78389 .29461 L
.78408 .29443 L
.78419 .29435 L
.78429 .29429 L
.78438 .29424 L
.78447 .29421 L
.78457 .29419 L
.78463 .29418 L
.78468 .29418 L
.78476 .29419 L
.78486 .2942 L
.78495 .29423 L
.78505 .29427 L
.78515 .29433 L
.78526 .2944 L
.78545 .29457 L
.78566 .29481 L
.78588 .29512 L
.78631 .29587 L
.78676 .29689 L
.78757 .2992 L
.78917 .30492 L
.7909 .31152 L
.79171 .31426 L
.79257 .31667 L
.7933 .31825 L
.79372 .31891 L
.79411 .31938 L
.79431 .31956 L
.7945 .31969 L
.79461 .31975 L
.79471 .3198 L
.79477 .31981 L
.79483 .31983 L
.79489 .31984 L
.79494 .31985 L
.79503 .31986 L
.79512 .31986 L
.79522 .31985 L
.79532 .31983 L
.79538 .31982 L
.79543 .3198 L
.79554 .31976 L
.79573 .31965 L
Mistroke
.79591 .31952 L
.79611 .31934 L
.7965 .31888 L
.79722 .31771 L
.79803 .31597 L
.79877 .31407 L
.80045 .30934 L
.80124 .30716 L
.80209 .30507 L
.80283 .30355 L
.80363 .3023 L
.80406 .30182 L
.80424 .30165 L
.80445 .30149 L
.80465 .30138 L
.80483 .30129 L
.80493 .30126 L
.80502 .30123 L
.80507 .30122 L
.80513 .30121 L
.80523 .3012 L
.80533 .3012 L
.80542 .3012 L
.80551 .30121 L
.8056 .30122 L
.80569 .30124 L
.8058 .30127 L
.80599 .30135 L
.80616 .30144 L
.80632 .30155 L
.80669 .30185 L
.80709 .30228 L
.80753 .30285 L
.80832 .30413 L
.80981 .30705 L
.81137 .31023 L
.8122 .31172 L
.81309 .31304 L
.81351 .31352 L
.81394 .31394 L
.81431 .31422 L
.81453 .31434 L
.81472 .31443 L
.81482 .31447 L
.81492 .3145 L
.81501 .31453 L
.8151 .31455 L
.81521 .31457 L
.81526 .31457 L
.81532 .31458 L
Mistroke
.81541 .31458 L
.81551 .31458 L
.81561 .31458 L
.81571 .31457 L
.81581 .31455 L
.8159 .31453 L
.81607 .31449 L
.81625 .31442 L
.81664 .31422 L
.817 .31397 L
.81781 .31321 L
.81928 .31132 L
.82092 .30889 L
.82172 .30777 L
.82245 .30688 L
.82316 .30616 L
.82354 .30585 L
.82393 .30557 L
.82413 .30546 L
.82435 .30535 L
.82456 .30527 L
.82474 .30521 L
.82494 .30516 L
.82504 .30514 L
.82514 .30512 L
.82523 .30511 L
.82532 .30511 L
.82541 .3051 L
.82551 .3051 L
.82561 .30511 L
.82567 .30511 L
.82572 .30512 L
.82583 .30513 L
.82594 .30515 L
.82615 .30519 L
.82634 .30525 L
.8268 .30544 L
.82723 .30568 L
.82801 .30625 L
.82885 .30702 L
.83041 .30863 L
.83124 .30948 L
.83213 .3103 L
.83298 .31094 L
.83335 .31117 L
.83375 .31138 L
.83414 .31153 L
.8345 .31163 L
.8347 .31168 L
.83488 .31171 L
Mistroke
.83498 .31172 L
.83503 .31172 L
.83508 .31173 L
.83519 .31173 L
.83528 .31174 L
.83538 .31174 L
.83548 .31173 L
.83558 .31173 L
.83568 .31172 L
.83577 .31171 L
.83585 .3117 L
.83604 .31167 L
.83624 .31162 L
.83646 .31157 L
.83685 .31143 L
.83762 .31107 L
.83832 .31065 L
.83997 .30948 L
.8415 .3084 L
.84226 .30795 L
.84297 .3076 L
.84337 .30745 L
.8438 .30732 L
.84399 .30727 L
.84419 .30723 L
.84437 .3072 L
.84455 .30718 L
.84466 .30717 L
.84476 .30716 L
.84485 .30716 L
.84495 .30715 L
.84505 .30715 L
.84514 .30715 L
.84522 .30715 L
.84531 .30715 L
.84541 .30716 L
.84551 .30717 L
.84563 .30718 L
.84573 .30719 L
.84612 .30725 L
.84649 .30733 L
.84683 .30743 L
.84759 .3077 L
.84925 .30848 L
.85079 .30925 L
.85156 .30959 L
.85228 .30986 L
.85303 .31008 L
.85343 .31016 L
.85364 .3102 L
Mistroke
.85386 .31023 L
.85407 .31025 L
.85426 .31027 L
.85435 .31027 L
.85445 .31028 L
.85455 .31028 L
.85463 .31028 L
.85473 .31028 L
.85483 .31028 L
.85493 .31028 L
.85499 .31028 L
.85504 .31028 L
.85515 .31027 L
.85526 .31027 L
.85547 .31025 L
.8557 .31022 L
.8559 .3102 L
.85635 .31012 L
.85717 .30992 L
.85884 .30939 L
.86039 .30886 L
.86117 .30862 L
.86189 .30844 L
.86265 .30829 L
.86305 .30824 L
.86326 .30822 L
.86348 .3082 L
.86369 .30818 L
.8638 .30818 L
.86391 .30817 L
.86401 .30817 L
.8641 .30817 L
.8642 .30817 L
.8643 .30817 L
.86436 .30817 L
.86441 .30817 L
.86447 .30817 L
.86452 .30817 L
.86462 .30817 L
.86473 .30818 L
.86484 .30818 L
.86497 .30819 L
.86519 .3082 L
.86559 .30824 L
.86596 .30829 L
.86681 .30843 L
.86993 .30914 L
.87074 .3093 L
.87117 .30937 L
.87163 .30944 L
Mistroke
.87203 .30949 L
.87247 .30953 L
.87266 .30955 L
.87287 .30956 L
.87306 .30957 L
.87324 .30958 L
.87335 .30958 L
.87344 .30958 L
.87353 .30958 L
.87362 .30958 L
.87373 .30958 L
.87378 .30958 L
.87383 .30958 L
.87393 .30958 L
.87403 .30958 L
.87412 .30958 L
.87421 .30957 L
.87438 .30957 L
.87456 .30956 L
.87476 .30955 L
.87518 .30952 L
.87562 .30947 L
.87642 .30938 L
.87803 .30914 L
.87887 .309 L
.87976 .30888 L
.88056 .30878 L
.88098 .30874 L
.88144 .3087 L
.88185 .30868 L
.88223 .30866 L
.88242 .30865 L
.88251 .30865 L
.88262 .30865 L
.8827 .30865 L
.8828 .30865 L
.88289 .30865 L
.88298 .30864 L
.88307 .30864 L
.88317 .30865 L
.88327 .30865 L
.88335 .30865 L
.88346 .30865 L
.88357 .30865 L
.88377 .30866 L
.88398 .30866 L
.8842 .30867 L
.8846 .30869 L
.88531 .30874 L
.88608 .30881 L
Mistroke
.88778 .30899 L
.88932 .30913 L
.89009 .30919 L
.89049 .30921 L
.89092 .30923 L
.89114 .30924 L
.89134 .30925 L
.89153 .30925 L
.89171 .30925 L
.89188 .30926 L
.89197 .30926 L
.89206 .30926 L
.89216 .30926 L
.89226 .30926 L
.89235 .30926 L
.89244 .30926 L
.89254 .30926 L
.89262 .30926 L
.89272 .30926 L
.89283 .30925 L
.89304 .30925 L
.89324 .30925 L
.89362 .30923 L
.89398 .30922 L
.89477 .30918 L
.89564 .30913 L
.89735 .30901 L
.89816 .30896 L
.8989 .30892 L
.89968 .30889 L
.90009 .30888 L
.9003 .30887 L
.90052 .30887 L
.90072 .30887 L
.9009 .30886 L
.90098 .30886 L
.90108 .30886 L
.90116 .30886 L
.90125 .30886 L
.90134 .30886 L
.90143 .30886 L
.90153 .30886 L
.90163 .30886 L
.90174 .30886 L
.90185 .30886 L
.90204 .30886 L
.90225 .30887 L
.90244 .30887 L
.90281 .30888 L
.90363 .3089 L
Mistroke
.9051 .30896 L
.90657 .30903 L
.90741 .30906 L
.90819 .30908 L
.90858 .3091 L
.90896 .3091 L
.90916 .30911 L
.90939 .30911 L
.90959 .30911 L
.90978 .30911 L
.90989 .30912 L
.91 .30912 L
.91011 .30912 L
.91021 .30912 L
.91031 .30912 L
.91037 .30912 L
.91043 .30912 L
.91048 .30912 L
.91054 .30912 L
.9106 .30912 L
.91066 .30912 L
.91076 .30912 L
.91086 .30912 L
.91105 .30911 L
.91125 .30911 L
.91147 .30911 L
.91187 .30911 L
.91228 .3091 L
.91303 .30908 L
.9147 .30903 L
.91553 .30901 L
.9163 .30899 L
.91706 .30898 L
.91776 .30896 L
.91813 .30896 L
.91852 .30896 L
.91872 .30896 L
.91891 .30895 L
.91902 .30895 L
.91912 .30895 L
.91917 .30895 L
.91923 .30895 L
.91929 .30895 L
.91934 .30895 L
.91943 .30895 L
.91954 .30895 L
.91963 .30895 L
.91972 .30895 L
.91982 .30895 L
.91993 .30895 L
Mistroke
.92015 .30896 L
.92037 .30896 L
.9206 .30896 L
.92102 .30896 L
.92184 .30897 L
.92273 .30899 L
.92435 .30902 L
.92517 .30903 L
.92594 .30904 L
.92636 .30905 L
.92674 .30905 L
.92717 .30905 L
.9274 .30905 L
.92751 .30906 L
.92763 .30906 L
.92774 .30906 L
.92783 .30906 L
.92793 .30906 L
.92803 .30906 L
.92812 .30906 L
.92821 .30906 L
.9283 .30906 L
.9284 .30906 L
.9285 .30906 L
.92856 .30906 L
.92862 .30906 L
.92883 .30906 L
.92902 .30906 L
.92922 .30905 L
.92958 .30905 L
.92992 .30905 L
.93069 .30904 L
.9338 .30901 L
.93463 .309 L
.93541 .309 L
.9358 .30899 L
.936 .30899 L
.93622 .30899 L
.93634 .30899 L
.93645 .30899 L
.93656 .30899 L
.93668 .30899 L
.93679 .30899 L
.93688 .30899 L
.93699 .30899 L
.93705 .30899 L
.9371 .30899 L
.9372 .30899 L
.9373 .30899 L
.93739 .30899 L
Mistroke
.93748 .30899 L
.9377 .30899 L
.93789 .30899 L
.93825 .30899 L
.93863 .309 L
.93942 .309 L
.94029 .30901 L
.94199 .30902 L
.9428 .30902 L
.94354 .30903 L
.94391 .30903 L
.94431 .30903 L
.94472 .30903 L
.94494 .30903 L
.94504 .30903 L
.94515 .30903 L
.94524 .30903 L
.94533 .30903 L
.94544 .30903 L
.94553 .30903 L
.94562 .30903 L
.94571 .30903 L
.94579 .30903 L
.94588 .30903 L
.94598 .30903 L
.94608 .30903 L
.94619 .30903 L
.94629 .30903 L
.94667 .30903 L
.94688 .30903 L
.94707 .30903 L
.94751 .30903 L
.9483 .30903 L
.94979 .30902 L
.95057 .30902 L
.95141 .30901 L
.95221 .30901 L
.95259 .30901 L
.95294 .30901 L
.95328 .30901 L
.95345 .30901 L
.95364 .30901 L
.95375 .30901 L
.95385 .30901 L
.95394 .30901 L
.95405 .30901 L
.95414 .30901 L
.95422 .30901 L
.95431 .30901 L
.95441 .30901 L
Mistroke
.95452 .30901 L
.95461 .30901 L
.95472 .30901 L
.95483 .30901 L
.95504 .30901 L
.95522 .30901 L
.95561 .30901 L
.95597 .30901 L
.95758 .30901 L
.95906 .30902 L
.95979 .30902 L
.96057 .30902 L
.96102 .30902 L
.96143 .30902 L
.96163 .30902 L
.96184 .30902 L
.96205 .30902 L
.96223 .30902 L
.96242 .30902 L
.96252 .30902 L
.96262 .30902 L
.96271 .30902 L
.9628 .30902 L
.96289 .30902 L
.96299 .30902 L
.96304 .30902 L
.9631 .30902 L
.96321 .30902 L
.96332 .30902 L
.96343 .30902 L
.96361 .30902 L
.96382 .30902 L
.96424 .30902 L
.96469 .30902 L
.96551 .30902 L
.96709 .30902 L
.96793 .30902 L
.96882 .30902 L
.96927 .30901 L
.96969 .30901 L
.97007 .30901 L
.97027 .30901 L
.97048 .30901 L
.97068 .30901 L
.97087 .30901 L
.97097 .30901 L
.97107 .30901 L
.97112 .30901 L
.97118 .30901 L
.97128 .30901 L
Mistroke
.97137 .30901 L
.97147 .30901 L
.97157 .30901 L
.97166 .30901 L
.97183 .30901 L
.97202 .30901 L
.97222 .30901 L
.97244 .30901 L
.97283 .30901 L
.97371 .30901 L
.97532 .30902 L
.97619 .30902 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{421.375, 260.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008>0001AB000`400?l00000o`00003ooooooooo
oooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo
003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooo
oooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool0
0?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooooooo
ool@ooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooo
ooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo0ol0003o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0
003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo
00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`
ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLoooo
o`00<?ooool3o`000?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?oo
ool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0
033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomco
oooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooo
oooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool3o`000?oooooo
g?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0013ooooo0_o^k^h3ooooo`;ok^k^6Oooool00ol0003oooooooooo`3o
ooooomcooooo000;ooooo`;o000000[o410@ooooooooooook^k^oeEEEOo^k^koooooonk^k_mEEEGo
k^k^0oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h:ooooo`03o`000?oo
oooooooo0?oooooog?ooool000cooooo00?o0000ooooooooool00_ooool01Oo^k^koEEEEomgMgOmE
EEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00[ooooo
00?o0000ooooooooool0oooooooLooooo`0000?oooooo`000?l000001?l00002ooooo`Go00001?oo
ool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooo
oa0@400:ooooo`03o`000?oooooooooo0?oooooog?ooool000Wooooo00CoA4A4omgMgOoooooo0000
1?ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000000[ooooo00?o0000ooooooooool0oooooooLooooo`002Oooool01?oMgMgo
EEEEooooool00003ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000:ooooo`Co0000oooooooKooooo`002_oo
ool00omgMgOoc<c<o`000003ooooo`;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@00[ooooo00?o0000ooooooooool0oooooooLooooo`002_oo
ool00oo^k^koA4A4o`00000?ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`;o00001Oooool00ol0003oooooooooo`3oooooomcooooo000;ooooo`03ogMgMol0
003ooooo00cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`3oooooomcooooo000Xooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool0oooooooLooooo`00:?ooool3o`0000Gooooo
00?o0000ooooooooool0oooooooLooooo`00:Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo0?oooooog?ooool002[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0=_ooooo00?o0000ooooooooool0oOooool0033ooooo0ol0003?ooooo`03o`000?oooooo
oooo00Sooooo0_l0003oooooo`00<?ooool00ol0003oooooooooo`3>ooooo`;o00002_ooool2o`00
0?oooooo000`ooooo`03o`000?oooooooooo0<kooooo0_l0000:ooooo`;o0000ooooool0033ooooo
00?o0000ooooooooool0c_ooool2o`0000[ooooo0_l0003oooooo`00<?ooool00ol0003ooooooooo
o`3>ooooo`;o00002_ooool2o`000?oooooo000`ooooo`03o`000?oooooooooo0<kooooo0_l0000:
ooooo`;o0000ooooool0033ooooo00?o0000ooooooooool0c_ooool00ol0003oooooo`000009oooo
o`;o0000ooooool0033ooooo00?o0000ooooooooool0c_ooool00ol0003oooooo`000009ooooo`;o
00002_ooool00ol0003oooooooooo`3booooo`00<?ooool00ol0003oooooooooo`3>ooooo`03o`00
0?oooooo000000Wooooo0_l0000:ooooo`03o`000?oooooooooo0?;ooooo000`ooooo`03o`000?oo
oooooooo0<kooooo00?o0000ooooool000002Oooool2o`0000[ooooo00?o0000ooooooooool0l_oo
ool0033ooooo00?o0000ooooooooool0c_ooool00ol0003oooooo`000009ooooo`;o00002_ooool0
0ol0003oooooooooo`3booooo`00<?ooool00ol0003oooooooooo`32ooooo`;o00002_ooool00ol0
003oooooo`000009ooooo`;o00002Oooool2o`000?Cooooo000`ooooo`?o0000`_ooool2o`0000[o
oooo00?o0000ooooool000002Oooool00ol0003oooooo`000008ooooo`;o0000m?ooool0033ooooo
00?o0000ooooooooool0`_ooool2o`0000[ooooo00?o0000ooooool000002?ooool01?l0003ooooo
ooooool00008ooooo`03o`000?oooooo00000??ooooo000`ooooo`03o`000?oooooooooo0<;ooooo
0_l0000:ooooo`03o`000?oooooo000000Sooooo00Co0000oooooooooooo00002?ooool00ol0003o
ooooo`00003cooooo`00<?ooool00ol0003oooooooooo`32ooooo`;o00002_ooool00ol0003ooooo
o`000008ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000loooool0033ooooo
00?o0000ooooooooool0`_ooool2o`0000[ooooo00?o0000ooooool000002?ooool01?l0003ooooo
ooooool00008ooooo`03o`000?oooooo00000??ooooo000`ooooo`03o`000?oooooooooo0<;ooooo
0_l0000:ooooo`03o`000?oooooo000000Sooooo00Co0000oooooooooooo00002?ooool00ol0003o
ooooo`00003cooooo`00<?ooool00ol0003oooooooooo`32ooooo`;o00002_ooool00ol0003ooooo
o`000008ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000loooool0033ooooo
00?o0000ooooooooool0`_ooool2o`0000[ooooo00?o0000ooooool000002?ooool01?l0003ooooo
ooooool00008ooooo`03o`000?oooooo00000??ooooo000`ooooo`03o`000?oooooooooo0<7ooooo
00?o0000ooooool000002_ooool00ol0003oooooo`000008ooooo`04o`000?ooooooooooo`0000So
oooo00?o0000ooooool00000loooool0033ooooo00?o0000ooooooooool0`Oooool00ol0003ooooo
o`00000:ooooo`03o`000?oooooo000000Sooooo00Co0000oooooooooooo00002?ooool00ol0003o
ooooo`00003cooooo`00<?ooool00ol0003oooooooooo`31ooooo`03o`000?oooooo000000Wooooo
00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo0000
00Wooooo00?o0000ooooooooool0ioooool0033ooooo0ol00031ooooo`04o`000?ooooooooooo`00
00Sooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00008ooooo`03o`000?oo
oooo000000Sooooo0_l0003Yooooo`00<?ooool00ol0003oooooooooo`31ooooo`04o`000?oooooo
ooooo`0000Sooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00008ooooo`03
o`000?oooooo000000Sooooo0_l0003Yooooo`00<?ooool00ol0003oooooooooo`31ooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00008
ooooo`03o`000?oooooo000000Sooooo0_l0003Yooooo`00<?ooool00ol0003oooooooooo`31oooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002?ooool01?l0003ooooooooo
ool00008ooooo`03o`000?oooooo000000Sooooo0_l0003Yooooo`00<?ooool00ol0003ooooooooo
o`31ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002?ooool01?l0003o
ooooooooool00008ooooo`03o`000?oooooo000000Sooooo0_l0003Yooooo`00<?ooool00ol0003o
ooooooooo`31ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002?ooool0
1?l0003oooooooooool00008ooooo`03o`000?oooooo000000Sooooo0_l0003Yooooo`00<?ooool0
0ol0003oooooooooo`2fooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooo00002?oo
ool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool0
00002?ooool2o`000>Wooooo000@ooooo`;ok^k^0oooool2onk^kQWooooo00?o0000ooooooooool0
]Oooool2o`0000[ooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo0000
00Oooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`000008ooooo`03o`000?oooooo
00000>Sooooo0009ooooo`Go00000_ooool01oo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00ooo
ool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h:ooooo`03o`000?oooooooooo
0;Gooooo0_l0000:ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`00
0007ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool000002?ooool00ol0003ooooo
o`00003Xooooo`002Oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00Gok^k^oeEEEOoMgMgo
EEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0:oooo
o`03o`000?oooooooooo0;Gooooo0_l0000:ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000
ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000
2?ooool00ol0003oooooo`00003Xooooo`0000?oooooo`000?l000001?l00003ooooo`03oiRHV?lQ
8B7ok^k^00Gooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?oo
ooooooooooooool@41002_ooool00ol0003oooooooooo`2eooooo`;o00002_ooool01?l0003ooooo
ooooool00008ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool00008
ooooo`03o`000?oooooo000000Sooooo00?o0000ooooool00000j?ooool000_ooooo00?oV9RHob4Q
8Oo^k^h00oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000000[ooooo00?o0000ooooooooool0]?ooool00ol0003oooooo`00
000:ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000007ooooo`04
o`000?ooooooooooo`0000Sooooo00?o0000ooooool000002?ooool00ol0003oooooo`00003Xoooo
o`003?ooool02omgMgOoIVIVooooooooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000[ooooo1?l0002cooooo`03
o`000?oooooo000000[ooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo
000000Oooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`000008ooooo`03o`000?oo
oooo00000>Sooooo000=ooooo`03o`000?oooooooooo00;ok^k^0oooool2onk^kPGooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00[ooooo00?o0000ooooooooool0]?oo
ool00ol0003oooooo`00000:ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooooooo
ooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00002?ooool0
0ol0003oooooo`00003Xooooo`002Oooool01Ol0003o^[ZjoooooonHV9So410@00kooooo00?o0000
ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo0_l00005ooooo`03o`000?oo
oooooooo0;Cooooo00Co0000oooooooooooo00002Oooool01?l0003oooooooooool00008ooooo`05
o`000?ooooooooooooooool000001oooool01?l0003oooooooooool00007ooooo`04o`000?oooooo
ooooo`0000Sooooo00?o0000ooooool000002?ooool2o`000=kooooo0009ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`03?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
0_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooooooo0;Cooooo00Co0000oooooooo
oooo00002?ooool01Ol0003ooooooooooooooooo000000Sooooo00Go0000ooooooooooooooooo`00
0007ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00002?ooool00ol0003o
ooooo`000008ooooo`;o0000g_ooool002Sooooo00Co0000oooooooooooo00001?ooool00ol0003o
ooooooooo`2dooooo`04o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000008
ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool00007ooooo`04o`00
0?ooooooooooo`0000Sooooo00?o0000ooooool000002?ooool2o`000=kooooo000Xooooo`?o0000
1Oooool00ol0003oooooooooo`2dooooo`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooo
ooooooooo`000008ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool0
0007ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00002?ooool2o`000=ko
oooo000Yooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0]?ooool01?l0003ooooo
ooooool00008ooooo`05o`000?ooooooooooooooool000002?ooool01Ol0003ooooooooooooooooo
000000Kooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo
00Co0000oooooooooooo00002?ooool2o`000=kooooo000Zooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0]?ooool01?l0003oooooooooool00008ooooo`05o`000?oooooooooooooo
ool000002?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`00
0007ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00002?ooool2o`000=ko
oooo000`ooooo`03o`000?oooooooooo0;Cooooo00Co0000oooooooooooo00002?ooool01Ol0003o
oooooooooooooooo000000Sooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?oooooo
ooooooooool000001oooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000So
oooo0_l0003Nooooo`00<?ooool00ol0003oooooooooo`2dooooo`04o`000?ooooooooooo`0000So
oooo00Go0000ooooooooooooooooo`000008ooooo`05o`000?ooooooooooooooool000001_ooool0
1Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo00001oooool01?l0003ooooo
ooooool00007ooooo`03o`000?oooooo00000=kooooo000`ooooo`03o`000?oooooooooo0;Cooooo
00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Sooooo00Go0000oooo
ooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001oooool01?l0003ooooooooo
ool00007ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool00000g_ooool0033ooooo
00?o0000ooooooooool0]?ooool01?l0003oooooooooool00008ooooo`05o`000?oooooooooooooo
ool000002?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`00
0007ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooo00000=kooooo000`ooooo`?o0000]?ooool01?l0003oooooooooool00008ooooo`05
o`000?ooooooooooooooool000002?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000
ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000oooooooooooo
ooooo`000006ooooo`03o`000?oooooo00000=kooooo000`ooooo`03o`000?oooooooooo0;Cooooo
00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Sooooo00Go0000oooo
ooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooo
oooooooo000000Kooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo00000=ko
oooo000`ooooo`03o`000?oooooooooo0;?ooooo00Go0000ooooooooooooooooo`000008ooooo`05
o`000?ooooooooooooooool000002?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000
ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooo
oooooooooooo000000Kooooo00Co0000oooooooooooo0000gOooool0033ooooo00?o0000oooooooo
ool0Yoooool2o`0000[ooooo00Go0000ooooooooooooooooo`000008ooooo`05o`000?oooooooooo
ooooool000002?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000oooooooooooooooo
o`000007ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo0000
00Kooooo00Co0000oooooooooooo0000gOooool0033ooooo00?o0000ooooooooool0Yoooool2o`00
00[ooooo00Go0000ooooooooooooooooo`000008ooooo`05o`000?ooooooooooooooool000002?oo
ool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000007ooooo`05
o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000
oooooooooooo00002?ooool00ol0003oooooooooo`3Booooo`00<?ooool00ol0003oooooooooo`2W
ooooo`;o00002_ooool01Ol0003ooooooooooooooooo000000Sooooo00Go0000oooooooooooooooo
o`000008ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?oooooooooo
ooooool000001_ooool01?l0003oooooooooool00007ooooo`;o0000e?ooool0033ooooo00?o0000
ooooooooool0Yoooool2o`0000[ooooo00Go0000ooooooooooooooooo`000008ooooo`05o`000?oo
ooooooooooooool000002?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0
003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo00001oooool2o`000=Cooooo000`
ooooo`03o`000?oooooooooo0:Kooooo00Co0000oooooooooooo00002Oooool01Ol0003ooooooooo
oooooooo000000Sooooo00Go0000ooooooooooooooooo`000008ooooo`05o`000?oooooooooooooo
ool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooo
ooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003ooooooooo
ool00007ooooo`;o0000e?ooool0033ooooo00?o0000ooooooooool0Y_ooool01?l0003ooooooooo
ool00009ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000
ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Oooooo0_l0003Dooooo`00<?oo
ool00ol0003oooooooooo`2Vooooo`04o`000?ooooooooooo`0000Wooooo00Go0000oooooooooooo
ooooo`000008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool01Ol0003o
oooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04oooo
o`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Kooooo00Co
0000oooooooooooo00001oooool2o`000=Cooooo000`ooooo`03o`000?oooooooooo0:Kooooo00Co
0000oooooooooooo00002Oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000001_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006
ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool00007ooooo`;o0000
e?ooool0033ooooo00?o0000ooooooooool0Y_ooool01?l0003oooooooooool00009ooooo`05o`00
0?ooooooooooooooool000002?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Go
oooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`00
0006ooooo`04o`000?ooooooooooo`0000Oooooo0_l0003Dooooo`00<?ooool3o`000:Kooooo00Co
0000oooooooooooo00002Oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000001_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006
ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool00006ooooo`04o`00
0?ooooooooooo`000=?ooooo000`ooooo`03o`000?oooooooooo0:Kooooo00Co0000oooooooooooo
00002Oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`05ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?oo
ooooooooooooool000001_ooool01?l0003oooooooooool00006ooooo`04o`000?ooooooooooo`00
0=?ooooo000`ooooo`03o`000?oooooooooo0:Gooooo00Go0000ooooooooooooooooo`000009oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go
0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Kooooo00Co0000oooooooo
oooo0000doooool0033ooooo00?o0000ooooooooool0YOooool01Ol0003ooooooooooooooooo0000
00Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo0000
1_ooool01?l0003oooooooooool0003Cooooo`00<?ooool00ol0003oooooooooo`2Uooooo`05o`00
0?ooooooooooooooool000002Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`05o`000?oooooooooooooo
ool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool0
1?l0003oooooooooool00006ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool0
bOooool0033ooooo00?o0000ooooooooool0C_ooool2onk^kP?ooooo0_o^k^i@ooooo`05o`000?oo
ooooooooooooool000000_ooool2onk^kP?ooooo0_o^k^h00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`00
0?ooooooooooooooool000001_ooool01?l0003oooooooooool00006ooooo`04o`000?oooooooooo
o`0000Oooooo0_l00002ooooo`;ok^k^0oooool2onk^kTkooooo0_o^k^h3ooooo`;ok^k^K?ooool0
033ooooo00?o0000ooooooooool0B?ooool03Om4A4Co0000o`000?lb<S;ogMgMooooooo^k^koEEEE
onk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b
<_o^k^i1ooooo`Go000000[o410@ooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^ko00000_oo
ool4o`000005oa0@4?ooooooooooonk^k_lb<S800_l000001Oo^k^kooooooooooooooooo000000Ko
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00Co000000Oo410@oooo
oooooooo0000oooooolQ8B7o000000Gooooo00goA4A4o`000?l0003o0000omgMgOooooook^k^oeEE
EOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb
<S;ok^k^>?ooool5o`0000;ooooo00Ook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l0
00002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^GOooool0033ooooo00?o0000oooooooo
ool0Boooool02OmgMgOo<S8booooooooooook^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0dooooo`;o00002oooool00ol0003ooooo
ooooo`02o`0000?ooooo00Ook^k^oeEEEOoMgMgoEEEEonk^k_oooooo000000Cooooo00?o0000oooo
ooooool00_ooool01OmgMgOoV9RHooooool0003oMgMg00?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Ko0000oooooooooooo0000oooo
ool00004ooooo`04o`000?oooooo8B4Qo`0000Kooooo00Co0000ooooool0003o<S8b0_ooool01Oo^
k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg03Sooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05onk^k_mEEEGogMgMoeEEEOo^
k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0GOooool0033o
oooo00?o0000ooooooooool0C?ooool01ol0003ooooooooooooooooogMgMo`000?oMgMd01oooool0
0ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100=?ooool2o`0000_ooooo00Ko
0000oooooooooooo0000ooooool00003ooooo`03omgMgOl0003ogMgM00;ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooo`000?l@41000oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01?l0
003oooooooooooooool2o`0000Cooooo00Co0000oooooooooooo00001_ooool01?l0003oooooo`00
0?l00003ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@413ooooo
oooooooooooo410@03Wooooo00?oV9RHob4Q8Oo^k^h01Oooool00ooMgMgo0000omgMg@07ooooo`03
o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@401Mooooo`00<?ooool00ol0003o
ooooooooo`1;ooooo`09ogMgMolb<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000003?ooooo00Co0000oooooooooooo
00002_ooool01_l0003oooooooooool0003oooooo`0000;ooooo00Ook^k^oeEEEOoMgMgoEEEEonk^
k_oooooo000000Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02o`0000?ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo
00Co0000oooooooooooooooo0_l00004ooooo`04o`000?ooooooooooo`0000Kooooo00Co0000oooo
ool0003o<S8b0_ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000003[ooooo00?oV9RHob4Q8Oo^k^h00oooool01Oo^k^koEEEE
omgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
05gooooo000`ooooo`03o`000?oooooooooo04Sooooo00go0000ob4Q8Ol0003o<S8bolc<c?oooooo
k^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000003?ooooo00Co0000oooooooooooo00002_ooool03_l0003oooooooooool0
003oooooo`000?ooooook^k^oeEEEOo^k^koooooonk^k_mEEEGo00001Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00;o00000oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooooooool2o`0000Cooooo
00Co0000oooooooooooo00001Oooool4o`000009olc<c?ooooook^k^oeEEEOo^k^koooooonk^k_mE
EEGok^k^00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000003_ooooo
00_oMgMgofIVI_ooooooooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00001Mooooo`00<?ooool00ol0003ooooooooo
o`18ooooo`03o`000?oooooooooo00?ooooo0_o^k^h3ooooo`;ok^k^1Oooool00ol0003ooooooooo
o`02ooooo`05oa0@4?ooooooooooooooool@4100<oooool01?l0003oooooooooool0000:ooooo`07
o`000?ooooooooooo`000?oooooo0000ooooo`02onk^kP?ooooo00?ok^k^o`000?ooool01?ooool0
0ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooo`000?l@41000oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01?l0003ooooooooo
ooooool2o`0000Cooooo00Co0000oooooooooooo00001Oooool2o`000004ooooool0003ooooooooo
o`;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@03cooooo00?o0000ooooooooool00_o^k^h3ooooo`;ok^k^1Oooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@4100GOooool0033ooooo0ol00018ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00?o
0000ooooooooool0:?ooool01?l0003oooooooooool0000:ooooo`06o`000?ooooooooooo`000?oo
oooo00001oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRH
V?oooooo0000ogMgM`03ooooo`03o`000?oooooooooo00;ooooo0ol00004ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool2o`0000Cooooo00Co0000oooooooooooo00001Ooo
ool2o`000003ooooool0003ooooo00Kooooo0_l00005ooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`08ooooo`;o0000;_ooool01Ol0003o^[ZjoooooonHV9So410@00ko
oooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo0_l0001Coooo
o`00<?ooool00ol0003oooooooooo`18ooooo`Co00003?ooool00omEEEGoIVIVo`000004ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`0Wooooo`05o`000?oooooooooo
ooooool000002_ooool01_l0003oEEEEofIVI_l0003oooooo`0000Oooooo00Oo0000oooooooooooo
oooooeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o0000onk^kP03ooooo`05o`000?oooooo
ooooooooool000000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go
0000oooooooooooooooooeEEE@02o`0000Cooooo00Co0000oooooooooooo00001Oooool5o`0000Ko
oooo0_l00003ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP07oooo
o`04o`000?ooooooooooo`0002gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00<ooooo`03oeEEEOmV
IVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP07ooooo`04o`000?ooooooooooo`0005;o
oooo000`ooooo`03o`000?oooooooooo06Kooooo1?l00003ooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo
00Co0000oooooooooooooooo1?l000001Ooooooo0000oooooooooooo000000Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooool000004?oo
ool4o`000005ooooool0003oooooooooool00000C?ooool4o`000005ooooool0003oooooooooool0
0000D_ooool0033ooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooooooo1?l00004ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000001_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooo000001Gooooo0ol0001B
ooooo`?o0000Doooool0033ooooo00?o0000ooooooooool0Joooool01?l0003oooooooooool0000W
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooo`000004
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool00006ooooo`03o`00
0?oooooo000001Kooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`1Booooo`00<?oo
ool00ol0003oooooooooo`1[ooooo`Co00006Oooool2o`0000cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`;o00001?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo
00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00006ooooo`;o00003oooool00ol0
003oooooooooo`1Booooo`03o`000?oooooooooo057ooooo000`ooooo`03o`000?oooooooooo08Oo
oooo1?l0000;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01?l0003o
ooooooooool00005ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooool00000]oooool0
033ooooo00?o0000ooooooooool0Q_ooool01Ol0003ooooooooooooooooo000000[ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Gooooo00Go
0000ooooooooooooooooo`000005ooooo`03o`000?oooooo000007gooooo00?oMgMgofIVI_ooool0
;Oooool00omVIVKoMgMgooooo`07ooooo`00<?ooool00ol0003oooooooooo`26ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`000005ooooo`05o`000?ooooooooooooooool0
00001?ooool01?l0003oooooooooool00006ooooo`?o0000Loooool00ooMgMgo410@onk^kP0^oooo
o`03onk^k_l@413ogMgM00Oooooo000`ooooo`03o`000?oooooooooo08Kooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00_ooool01Ol0003ooooooooooooooooo000000Gooooo00Go0000ooooooooooooooooo`000004
ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooo`000007ooooo`03o`000?oo
oooooooo05Oooooo0_l00002ooooo`;o00003?ooool00omEEEGoV9RHooooo`02o`0000;ooooo00Oo
0000oooooooooooo0000oa0@4?o^k^koEEEE00;o000000?oA4A4okZj^_ooool00_ooool01OnHV9So
0000o`000?m4A4Co^[Zj00;ooooo00Sok^k^oeEEEOl0003o0000odA4A?nj^[[ooooooa0@40Go0000
0oooool02?l@413o<S8bo`000?l0003o410@ojVYZOn7QhOoIVIV1oooool0033ooooo00?o0000oooo
ooooool0M?ooool6o`0000_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo
000000Gooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool00000
1?ooool01Ol0003ooooooooooooooooo000000Cooooo1?l00006ooooo`03o`000?oooooooooo04oo
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd<ooooo`05o`000?ooooooooooooooool000000_oo
ool02ol0003oooooooooool0003ooooooeEEEOmgMgOoooooonk^k_mgMgOo410@00?ooooo00Go410@
okZj^_o^k^koMgMgoa0@4002ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo410@0oooool00ol0003o
ooooooooo`04ooooo`08o`000?nYZJWooooooooooonj^[[o0000onk^k_l00007ooooo`00ool0002d
o`0000oooooo00CogMgMo`000?l@413oc<c<3Oooool01Olb<S;ooooooooooooooooo000000;ooooo
00Ko0000oooooooooooo0000ooooool00008ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`07okZj^_n7QhOoIVIVofIVI_l@413oooooo`00
0007ooooo`002_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00cooooo1ol0000;
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001oooool00ol0003ooooooooo
o`04ooooo`;o00001oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`;o00000oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool2o`0000?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo
00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooooooo0_l00002ooooo`;o00000_ooool00ol0003oooooooooo`02ooooo`Go00000_ooool00ol0
003oooooo`000002o`0000Kooooo0_l00005ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0Gooooo`04onk^k_lQ8B7o410@onk^kPgooooo00Go<S8b
ooooooooooooooooo`000002ooooo`05o`000?ooooooooooo`000?ooool01_l00003ooooo`03o`00
0?oooooooooo00Cooooo1_l00003ooooo`03o`000?oooooooooo00Cooooo00So<S8bob4Q8OmgMgOo
MgMgohN7Qoo^k^koooooo`0000Oooooo000:ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0<ooooo`04o`000?ooooooooooooooo`?o00002?ooool0
0ol0003oooooooooo`04ooooo`;o00002?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
000000Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`;o00000oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_oo
ool2o`0000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo
00Ko0000oooooooooooo0000ooooool00003ooooo`?o00001oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo01Oooooo00Co8B4QogMgMomgMgOo<S8b3Oooool01Ol0003ok^k^oooooooo
oooo000000;oc<c<00_o0000ojVYZOoMgMgo8B4QoooooomEEEGoQhN7onk^k_ooooooQhN7oc8b<P03
ooooo`03o`000?oooooooooo00Cooooo00KoEEEEohN7Qoo^k^koooooohN7Qolb<S83ooooo`03o`00
0?lb<S;ogMgM00Cooooo00So0000okZj^_ooooook^k^ogMgMol0003ok^k^o`0000Oooooo000`oooo
o`03o`000?oooooooooo05_ooooo00?o0000ooooooooool08?ooool4o`0000_ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00_ooool01?l0003oooooooooooooool2o`0000?ooooo00Go0000ooooooooooooooooo`00
0005ooooo`04o`000?ooooooooooo`0000Kooooo0_l00014ooooo`03o`000?oooooooooo01Kooooo
0_l00002ooooo`;o00003?ooool03_mEEEGoMgMgooooool@413o0000ob4Q8Ol0003oMgMgoa0@4?l0
003oZJVYooooooo^k^koEEEE0_l000001?m4A4Cok^k^ooooool@4105o`0000?ooooo00Kok^k^oeEE
EOl0003o0000odA4A?o^k^h2ooooo`;o000000CoZJVYob4Q8Ol0003o8B4Q0_ooool02?nYZJWo8B4Q
o`000?l0003o<S8bo`000?mgMgOoEEEE1oooool0033ooooo00?o0000ooooooooool0SOooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooo
oooo000000Gooooo0ol0001hooooo`03omgMgOl@413ok^k^01;ooooo00?o0000ooooooooool06Ooo
ool00oo^k^ko410@omgMg@07ooooo`00<?ooool00ol0003oooooooooo`2>ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000005ooooo`04o`000?ooooooooooo`0000Kooooo
0_l0001iooooo`03ogMgMomVIVKooooo017ooooo00?o0000ooooooooool06Oooool00omVIVKoMgMg
ooooo`07ooooo`00<?ooool00ol0003oooooooooo`2>ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooooooo
ooooo`000005ooooo`03o`000?oooooo00000;cooooo000`ooooo`03o`000?oooooooooo08oooooo
00Go0000ooooooooooooooooo`000009ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Gooooo00Go0000oooo
ooooooooooooo`000005ooooo`03o`000?oooooo00000;cooooo000`ooooo`03o`000?oooooooooo
08oooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool01?l0003oooooooooool00005ooooo`05o`000?ooooooooooooooool0
00001Oooool3o`000;cooooo000`ooooo`03o`000?oooooooooo08oooooo00Co0000oooooooooooo
00002_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooo
ooooooooo`000005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01?l0
003oooooooooool00006ooooo`03o`000?oooooo000000Oooooo0_l0002looooo`00<?ooool00ol0
003oooooooooo`2@ooooo`?o00002oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000
ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooo
ool01?l0003oooooooooool00006ooooo`03o`000?oooooo00000<Gooooo000`ooooo`03o`000?oo
oooooooo09kooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool0
00001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooo
oooo00001_ooool00ol0003oooooo`000035ooooo`00<?ooool3o`0009kooooo00Go0000oooooooo
ooooooooo`000009ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0003ooooooooooooo
oooo000000Kooooo00Co0000oooooooooooo00001_ooool00ol0003oooooo`000035ooooo`00<?oo
ool00ol0003oooooooooo`2Nooooo`05o`000?ooooooooooooooool000002Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooo
oooooooooooo000000Gooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?oooooooooo
o`0000Kooooo00?o0000ooooool00000aOooool0033ooooo00?o0000ooooooooool0W_ooool01Ol0
003ooooooooooooooooo000000Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000005ooooo`05o`000?oo
ooooooooooooool000001_ooool01?l0003oooooooooool00006ooooo`03o`000?oooooo00000<Go
oooo000`ooooo`03o`000?oooooooooo09kooooo00Go0000ooooooooooooooooo`000009ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05
o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool00006ooooo`04o`000?oooooo
ooooo`0000Kooooo0_l00036ooooo`00<?ooool00ol0003oooooooooo`2Nooooo`05o`000?oooooo
ooooooooool000002Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo
00001_ooool00ol0003oooooo`00003?ooooo`00<?ooool00ol0003oooooooooo`2Nooooo`05o`00
0?ooooooooooooooool000002Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooo
oooooooo00001_ooool00ol0003oooooo`00003?ooooo`00<?ooool00ol0003oooooooooo`2Noooo
o`05o`000?ooooooooooooooool000002Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Kooooo00Co
0000oooooooooooo00001_ooool00ol0003oooooo`00003?ooooo`00<?ooool00ol0003ooooooooo
o`2Nooooo`05o`000?ooooooooooooooool000002Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Ko
oooo00Co0000oooooooooooo00001_ooool00ol0003oooooo`00003?ooooo`00<?ooool00ol0003o
ooooooooo`2Oooooo`03o`000?oooooo000000[ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003o
oooooooooooooooo000000Gooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?oooooo
ooooo`0000Kooooo00?o0000ooooool00000coooool0033ooooo00?o0000ooooooooool0Woooool0
0ol0003oooooo`00000:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00001_oo
ool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo00001_ooool00ol0003o
ooooo`00003?ooooo`00<?ooool00ol0003oooooooooo`2Oooooo`03o`000?oooooo000000[ooooo
00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool01?l0003oooooooooool00006ooooo`05o`000?ooooooooooooooool000001_ooool0
1?l0003oooooooooool00006ooooo`03o`000?oooooo00000<oooooo000`ooooo`03o`000?oooooo
oooo09oooooo0ol0000:ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo000000Oooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool00006oooo
o`04o`000?ooooooooooo`0000Oooooo0_l0003?ooooo`00<?ooool3o`000:3ooooo00?o0000oooo
ooooool02Oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00
0007ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00001_ooool01?l0003o
ooooooooool00007ooooo`;o0000coooool0033ooooo00?o0000ooooooooool0[?ooool01Ol0003o
oooooooooooooooo000000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?oooooo
ooooo`0000Oooooo00Co0000oooooooooooo00001_ooool01?l0003oooooooooool00007ooooo`;o
0000coooool0033ooooo00?o0000ooooooooool0[?ooool01Ol0003ooooooooooooooooo000000So
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000
oooooooooooo00001_ooool01?l0003oooooooooool0003Hooooo`00<?ooool00ol0003ooooooooo
o`2]ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000007ooooo`04
o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00001_ooool01?l0003oooooooooool0
003Hooooo`00<?ooool00ol0003oooooooooo`2]ooooo`04o`000?ooooooooooo`0000Sooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go
0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool0
00001oooool01?l0003oooooooooool0003Hooooo`00<?ooool00ol0003oooooooooo`2]ooooo`04
o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?oooooo
ooooo`0000Oooooo00?o0000ooooool000001oooool00ol0003oooooo`00003Iooooo`00<?ooool0
0ol0003oooooooooo`2]ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooooooo
o`000007ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool000001oooool00ol0003o
ooooo`00003Iooooo`00<?ooool00ol0003oooooooooo`2]ooooo`04o`000?ooooooooooo`0000So
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Go
oooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool00007ooooo`03o`000?oooooo
000000Oooooo00?o0000ooooool00000fOooool0033ooooo00?o0000ooooooooool0[Oooool01?l0
003oooooooooool00008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo0000
1oooool00ol0003oooooo`000008ooooo`;o0000fOooool0033ooooo00?o0000ooooooooool0[Ooo
ool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooo
oooo00001oooool00ol0003oooooo`000008ooooo`;o0000fOooool0033ooooo00?o0000oooooooo
ool0[Oooool01?l0003oooooooooool00009ooooo`05o`000?ooooooooooooooool000001oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`00
0007ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00001oooool00ol0003o
ooooo`000008ooooo`;o0000fOooool0033ooooo00?o0000ooooooooool0[Oooool01?l0003ooooo
ooooool00009ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo
000000Sooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo
00Co0000oooooooooooo00001oooool00ol0003oooooo`000008ooooo`;o0000fOooool0033ooooo
0ol0002]ooooo`04o`000?ooooooooooo`0000Wooooo00Go0000ooooooooooooooooo`000007oooo
o`05o`000?ooooooooooooooool000002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Co
0000oooooooooooo00001oooool01?l0003oooooooooool00007ooooo`03o`000?oooooo000000So
oooo0_l0003Iooooo`00<?ooool00ol0003oooooooooo`2]ooooo`04o`000?ooooooooooo`0000Wo
oooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000002?ooool0
1Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo00001oooool01?l0003ooooo
ooooool00007ooooo`03o`000?oooooo000000Sooooo0_l0003Iooooo`00<?ooool00ol0003ooooo
ooooo`2]ooooo`04o`000?ooooooooooo`0000Wooooo00Co0000oooooooooooo00002?ooool01Ol0
003ooooooooooooooooo000000Sooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?oo
ooooooooo`0000Oooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`000008ooooo`;o
0000fOooool0033ooooo00?o0000ooooooooool0[_ooool2o`0000[ooooo00Co0000oooooooooooo
00002?ooool01Ol0003ooooooooooooooooo000000Sooooo00Go0000ooooooooooooooooo`000007
ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00001oooool00ol0003ooooo
o`00003Sooooo`00<?ooool00ol0003oooooooooo`2^ooooo`;o00002_ooool01?l0003ooooooooo
ool00008ooooo`05o`000?ooooooooooooooool000002?ooool01Ol0003ooooooooooooooooo0000
00Oooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool00007ooooo`03o`000?oo
oooo00000>?ooooo000`ooooo`03o`000?oooooooooo0:kooooo0_l0000:ooooo`04o`000?oooooo
ooooo`0000Sooooo00Go0000ooooooooooooooooo`000008ooooo`05o`000?ooooooooooooooool0
00001oooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000
ooooool00000hoooool000oooooo0_o^k^h3ooooo`;ok^k^6_ooool00ol0003oooooooooo`2^oooo
o`;o00002_ooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool000002?oo
ool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo00001oooool01?l0003o
ooooooooool00007ooooo`03o`000?oooooo00000>?ooooo0008ooooo`Go00000_ooool01oo^k^ko
EEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000
oc8b<_o^k^h;ooooo`03o`000?oooooooooo0:kooooo0_l0000:ooooo`04o`000?ooooooooooo`00
00Sooooo00Go0000ooooooooooooooooo`000008ooooo`05o`000?ooooooooooooooool000001ooo
ool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool0
0000hoooool000Sooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05onk^k_mEEEGogMgMoeEE
EOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
0ol0003oooooooooo`2jooooo`04o`000?ooooooooooo`0000Wooooo00Co0000oooooooooooo0000
2?ooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo00001oooool01?l0
003oooooooooool00007ooooo`03o`000?oooooo00000>?ooooo0009ooooo`03oiRHV?lQ8B7ok^k^
00Gooooo00?ogMgMo`000?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@41002oooool00ol0003oooooooooo`2jooooo`04o`000?ooooooooooo`0000Wooooo00Co
0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooo
oooo00001oooool01?l0003oooooooooool00007ooooo`03o`000?oooooo00000>?ooooo000:oooo
o`03oiRHV?lQ8B7ok^k^00?ooooo00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`00000;ooooo`03o`000?oooooooooo0;[ooooo00Co
0000oooooooooooo00002Oooool01?l0003oooooooooool00008ooooo`05o`000?oooooooooooooo
ool000001oooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Oooooo00?o
0000ooooool00000hoooool000_ooooo00_oMgMgofIVI_ooooooooooonk^k_mEEEGok^k^ooooooo^
k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000;
ooooo`Co0000^Oooool01?l0003oooooooooool00009ooooo`04o`000?ooooooooooo`0000Sooooo
00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooo
oooooooo00001oooool00ol0003oooooo`00003Sooooo`003?ooool00ol0003oooooooooo`02onk^
kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400;
ooooo`03o`000?oooooooooo0;_ooooo00?o0000ooooool000002Oooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001oooool01?l0003o
ooooooooool00007ooooo`03o`000?oooooo00000>?ooooo0008ooooo`05o`000?nj^[[ooooooiRH
V?l@41003_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
0ol0003oooooooooo`2kooooo`03o`000?oooooo000000Wooooo00Co0000oooooooooooo00002?oo
ool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooo
oooo00001oooool00ol0003oooooo`00003Sooooo`002?ooool01OnHV9So410@o`000?lQ8B7oc<c<
00cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo0_l00006
ooooo`03o`000?oooooooooo0;_ooooo00?o0000ooooool000002Oooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001oooool01?l0003o
ooooooooool00007ooooo`03o`000?oooooo00000>?ooooo000Wooooo`04o`000?ooooooooooo`00
00Gooooo00?o0000ooooooooool0^oooool00ol0003oooooo`000009ooooo`04o`000?oooooooooo
o`0000Sooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00007ooooo`04o`00
0?ooooooooooo`0000Sooooo0_l0003Sooooo`009oooool01?l0003oooooooooool00005ooooo`03
o`000?oooooooooo0;_ooooo00?o0000ooooool000002Oooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001oooool01?l0003ooooooooo
ool00008ooooo`03o`000?oooooooooo0>;ooooo000Wooooo`?o00001_ooool00ol0003ooooooooo
o`2kooooo`03o`000?oooooo000000Wooooo00Co0000oooooooooooo00002?ooool01?l0003ooooo
ooooool00008ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00002?ooool0
0ol0003oooooooooo`3Rooooo`00:?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0;_ooooo00?o0000ooooool000002Oooool01?l0003oooooooooool00008ooooo`04o`000?oooooo
ooooo`0000Sooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool0003]ooooo`00
:Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0;_ooooo00?o0000ooooool00000
2Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooo
oooooooo00001oooool01?l0003oooooooooool0003]ooooo`00<?ooool00ol0003oooooooooo`2k
ooooo`03o`000?oooooo000000Wooooo00Co0000oooooooooooo00002?ooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo0000kOooool0033o
oooo00?o0000ooooooooool0^oooool00ol0003oooooo`000009ooooo`04o`000?ooooooooooo`00
00Sooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00007ooooo`04o`000?oo
ooooooooo`000>gooooo000`ooooo`03o`000?oooooooooo0;_ooooo00?o0000ooooool000002Ooo
ool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooo
oooo00001oooool00ol0003oooooo`00003^ooooo`00<?ooool3o`000;_ooooo00?o0000ooooool0
00002Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000
oooooooooooo00002?ooool2o`000>kooooo000`ooooo`03o`000?oooooooooo0;_ooooo00?o0000
ooooool000002Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00002?ooool2o`000>kooooo000`ooooo`03o`000?oooooooooo0;_ooooo
0_l0000:ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002?ooool01?l0
003oooooooooool00008ooooo`;o0000k_ooool0033ooooo00?o0000ooooooooool0_?ooool00ol0
003oooooooooo`08ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002?oo
ool01?l0003oooooooooool00008ooooo`;o0000k_ooool0033ooooo00?o0000ooooooooool0_?oo
ool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo
00002?ooool01?l0003oooooooooool00008ooooo`;o0000k_ooool0033ooooo00?o0000oooooooo
ool0aoooool01?l0003oooooooooool00009ooooo`03o`000?oooooo000000Sooooo00Co0000oooo
oooooooo00002?ooool2o`000>kooooo000`ooooo`03o`000?oooooooooo0<Oooooo00Co0000oooo
oooooooo00002Oooool00ol0003oooooo`000008ooooo`04o`000?ooooooooooo`0000Sooooo0_l0
003^ooooo`00<?ooool00ol0003oooooooooo`38ooooo`03o`000?oooooo000000Wooooo00?o0000
ooooool000002?ooool00ol0003oooooo`000009ooooo`;o0000k_ooool0033ooooo00?o0000oooo
ooooool0b?ooool00ol0003oooooo`000009ooooo`03o`000?oooooo000000Sooooo00?o0000oooo
ool000002Oooool2o`000>kooooo000`ooooo`03o`000?oooooooooo0<Sooooo00?o0000ooooool0
00002Oooool00ol0003oooooo`000008ooooo`03o`000?oooooo000000Wooooo0_l0003^ooooo`00
<?ooool00ol0003oooooooooo`38ooooo`03o`000?oooooo000000Wooooo00?o0000ooooool00000
2?ooool00ol0003oooooo`00003iooooo`00<?ooool00ol0003oooooooooo`38ooooo`;o00002_oo
ool00ol0003oooooo`000008ooooo`03o`000?oooooo00000?Wooooo000`ooooo`?o0000b?ooool2
o`0000[ooooo00?o0000ooooool000002?ooool00ol0003oooooo`00003iooooo`00<?ooool00ol0
003oooooooooo`38ooooo`;o00002_ooool00ol0003oooooo`000009ooooo`;o0000nOooool0033o
oooo00?o0000ooooooooool0b?ooool2o`0000[ooooo00?o0000ooooool000002Oooool2o`000?Wo
oooo000`ooooo`03o`000?oooooooooo0<Sooooo0_l0000:ooooo`03o`000?oooooo000000Wooooo
0_l0003iooooo`00<?ooool00ol0003oooooooooo`38ooooo`;o00002_ooool00ol0003oooooo`00
0009ooooo`;o0000nOooool0033ooooo00?o0000ooooooooool0b?ooool2o`0000[ooooo00?o0000
ooooool000002Oooool2o`000?Wooooo000`ooooo`03o`000?oooooooooo0<Sooooo0_l0000:oooo
o`03o`000?oooooo000000Wooooo0_l0003iooooo`00<?ooool00ol0003oooooooooo`38ooooo`;o
00002_ooool2o`0000[ooooo0_l0003iooooo`00<?ooool00ol0003oooooooooo`3Dooooo`;o0000
2_ooool2o`000?Wooooo000`ooooo`03o`000?oooooooooo0=Cooooo0_l0000:ooooo`;o0000nOoo
ool0033ooooo00?o0000ooooooooool0e?ooool2o`000?oooooo1_ooool0033ooooo00?o0000oooo
ooooool0e?ooool2o`000?oooooo1_ooool0033ooooo0ol0003Dooooo`;o0000ooooool6ooooo`00
<?ooool00ol0003oooooooooo`3Eooooo`03o`000?oooooooooo0?oooooo1?ooool0033ooooo00?o
0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`oooo
o`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00
3oooool2onk^kP?ooooo0_o^k^hJooooo`03o`000?oooooooooo0?oooooog?ooool000[ooooo0_l0
00002_l@413oooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h3ooooo`Co000000So410@
ooooooooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00?o0000ooooooooool0oooooooLooooo`00
2oooool00ol0003oooooooooo`02ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ol0003oooooooooo`3ooooo
omcooooo0008ooooo`Go00001?ooool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;o
oooo00Go410@oooooooooooooooooa0@400;ooooo`03o`000?oooooooooo0?oooooog?ooool000So
oooo00CoA4A4omgMgOoooooo00001?ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000000_ooooo00?o0000ooooooooool0oooo
oooLooooo`002?ooool01?oMgMgoEEEEooooool00003ooooo`07onk^k_mEEEGok^k^ooooooo^k^ko
EEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000;oooo
o`Co0000oooooooKooooo`002Oooool00omgMgOoc<c<o`000003ooooo`;ok^k^0oooool2onk^kPGo
oooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00_ooooo00?o0000oooo
ooooool0oooooooLooooo`002Oooool00oo^k^koA4A4o`00000?ooooo`03o`000?oooooooooo00;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03o`000?oooooooooo0?oooooog?ooool000[o
oooo00?oMgMgo`000?ooool03?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h00oooool2o`0000Kooooo00?o0000ooooooooool0oooooooLooooo`009oooool01?l0003o
ooooooooool00005ooooo`03o`000?oooooooooo0?oooooog?ooool002Oooooo00Co0000oooooooo
oooo00001Oooool00ol0003oooooooooo`3oooooomcooooo000Wooooo`?o00001_ooool00ol0003o
ooooooooo`3oooooomcooooo000Xooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
oooooooLooooo`00:Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooog?oo
ool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3ooooo
omcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo0ol0003oooooomcooooo
000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooL
ooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oo
oooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooooooo
o`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooo
ooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`00
0?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool3
o`000?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003o
ooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o
0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`oooo
o`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00
<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?oo
ool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3ooooo
omcooooo000`ooooo`?o0000oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo
000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooL
ooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo003ooooooooooooo4?ooool00?oooooo
ooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@oooo
o`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00X?ooool2
o`0000Cooooo00?o^[Zjoc8b<_ooool01?ooool2o`0000Kooooo00?o0000okZj^_ooool0oooooomG
ooooo`00X?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool2oc8b<_ooooooF?ooool008gooooo0ol00002ooooo`06oc8b<_l@413ooooooooo
ooo^k^koEEEE0_l000000om4A4Co^[Zjooooo`03ooooo`03o`000?oooooooooo00;ooooo00GoV9RH
oa0@4?l0003o0000ojVYZ@04ooooo`03o`000?oooooooooo00Cooooo00?oQhN7o`000?nj^[X03?oo
ool01OnHV9So0000o`000?m4A4Co^[Zj00[ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`00
0?lb<S;ok^k^1Oooool2ob4Q8@;ooooo00Goc<c<onk^k_ooooook^k^olc<c004ooooo`Co000000So
410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kQ?ooooo00Ko410@oc8b<_l0003o0000oa0@4?nY
ZJT2ooooo`06onk^k_mEEEGo0000o`000?m4A4Co^[Zj0oooool01OmVIVKo0000o`000?m4A4Coc<c<
0>Sooooo002>ooooo`05o`000?ooooooooooolc<c?l@41000oooool01_mEEEGoMgMgooooooo^k^ko
MgMgoa0@40Cooooo00?o0000ooooooooool00_ooool01_l0003oZJVYoeEEEOnHV9SoEEEEokZj^P?o
oooo00?o0000ooooooooool01?ooool00oo<c<co0000oa0@400<ooooo`06oa0@4?nj^[[ok^k^ogMg
Mol@413ooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q0_ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01?ooooo00Ko0000ojVYZOoooooooooookZj^_l00002
ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo410@0_ooool01_mVIVKoMgMgooooooooooooQhN7oa0@
4>Sooooo002>ooooo`05o`000?oooooooooooeEEEOn7QhL00oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00;ooooo00Ko<S8bonk^k_nHV9SoEEEEomgMgOl@4103ooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`05oa0@4?oo
ooooooooooooool@41002_ooool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo
00Go410@oooooooooooooooooa0@400Dooooo`05okZj^_n7QhOoIVIVofIVI_l@41000_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo0>_ooooo002>ooooo`05o`000?oooooogMgMo`00
0?o^k^h00oooool6o`0000Cooooo00?o0000ooooooooool00_ooool01onj^[[oA4A4olc<c?lQ8B7o
oooooa0@4?o<c<`00_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00?ooooo1_l0
0005ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000009ooooo`05onk^
k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000004oooool01_lb<S;o8B4QogMgMomgMgOoQhN7onk^kP;ooooo1_l00002ooooo`03o`000?oo
oooooooo0>_ooooo002>ooooo`?o000000?o410@oiRHV?ooool00_ooool01_mEEEGoQhN7onk^k_oo
ooooQhN7oc8b<PCooooo00?o0000ooooooooool00_ooool01oo^k^ko0000ooooool0003oooooofIV
I_n7QhL00_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000000Wooooo00Goc<c<onk^k_ooooook^k^olc<
c006ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Cooooo`06o`00
0?nj^[[oooooonk^k_mgMgOo00000_ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<P;ooooo00Ko
IVIVogMgMoooooooooooohN7Qol0003Xooooo`00S_ooool01Ol0003oooooooooooo<c<co000000?o
oooo00Kok^k^oeEEEOl0003o0000odA4A?o^k^h4ooooo`03o`000?oooooooooo00;ooooo00CoIVIV
oiRHV?oooooo<S8b0_nj^[X01?l0003oooooooooool0000Cooooo`03oa0@4?l0003o000000?o0000
3Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41005?ooool00ol0003o
ooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41001oooool3o`0000;ooooo0ol00004oooo
o`06ojVYZOlQ8B7o0000o`000?lb<S;o00000_ooool01_o^k^koEEEEo`000?l0003oA4A4onk^kP;o
oooo00Kok^k^ofIVI_l0003o0000odA4A?l0003Xooooo`00S_ooool01Ol0003oooooooooooo<c<co
000000gooooo00?o0000ooooooooool01Oooool00omVIVKoQhN7ooooo`03ooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL05?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo0_ooool008gooooo1?l0
00000ol@413oZJVYooooo`0<ooooo`;o00001_ooool00onYZJWoA4A4ooooo`02ooooo`;o00005Ooo
ool00ol0003oooooooooo`0<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0Booooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`Co
00000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo0_ooool00?oooooo
1_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo0_ooool00?oooooo1_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo0_ooool00?oooooo1Oooool2
o`0000?ooooo0_l0003oooooo`Cooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00
oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooo
oa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003o
oooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo
4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oo
ooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@
ooooo`00\
\>"],
  ImageRangeCache->{{{0, 525.688}, {324.5, 0}} -> {-2.58312*^-7, -6.34248*^6, \
6.65005*^-9, 53093.5}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0.309017 5.42214e-08 [
[.32684 .29652 -16.5 -12.5 ]
[.32684 .29652 16.5 0 ]
[.54329 .29652 -16.5 -12.5 ]
[.54329 .29652 16.5 0 ]
[.75974 .29652 -22.5 -12.5 ]
[.75974 .29652 22.5 0 ]
[.97619 .29652 -16.5 -12.5 ]
[.97619 .29652 16.5 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 64 6 ]
[.09789 .09213 -34.5 -6.25 ]
[.09789 .09213 0 6.25 ]
[.09789 .20057 -34.5 -6.25 ]
[.09789 .20057 0 6.25 ]
[.09789 .41746 -28.5 -6.25 ]
[.09789 .41746 0 6.25 ]
[.09789 .5259 -28.5 -6.25 ]
[.09789 .5259 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -65.8125 0 ]
[.5 .63053 65.8125 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 .30902 m
.32684 .31527 L
s
gsave
.32684 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 .30902 m
.54329 .31527 L
s
gsave
.54329 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 .30902 m
.75974 .31527 L
s
gsave
.75974 .29652 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 .30902 m
.15368 .31277 L
s
.19697 .30902 m
.19697 .31277 L
s
.24026 .30902 m
.24026 .31277 L
s
.28355 .30902 m
.28355 .31277 L
s
.37013 .30902 m
.37013 .31277 L
s
.41342 .30902 m
.41342 .31277 L
s
.45671 .30902 m
.45671 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.58658 .30902 m
.58658 .31277 L
s
.62987 .30902 m
.62987 .31277 L
s
.67316 .30902 m
.67316 .31277 L
s
.71645 .30902 m
.71645 .31277 L
s
.80303 .30902 m
.80303 .31277 L
s
.84632 .30902 m
.84632 .31277 L
s
.88961 .30902 m
.88961 .31277 L
s
.9329 .30902 m
.9329 .31277 L
s
.0671 .30902 m
.0671 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09213 m
.11664 .09213 L
s
gsave
.09789 .09213 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .20057 m
.11664 .20057 L
s
gsave
.09789 .20057 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .41746 m
.11664 .41746 L
s
gsave
.09789 .41746 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .5259 m
.11664 .5259 L
s
gsave
.09789 .5259 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.11039 .11924 m
.11414 .11924 L
s
.11039 .14635 m
.11414 .14635 L
s
.11039 .17346 m
.11414 .17346 L
s
.11039 .22768 m
.11414 .22768 L
s
.11039 .2548 m
.11414 .2548 L
s
.11039 .28191 m
.11414 .28191 L
s
.11039 .33613 m
.11414 .33613 L
s
.11039 .36324 m
.11414 .36324 L
s
.11039 .39035 m
.11414 .39035 L
s
.11039 .44457 m
.11414 .44457 L
s
.11039 .47168 m
.11414 .47168 L
s
.11039 .49879 m
.11414 .49879 L
s
.11039 .06502 m
.11414 .06502 L
s
.11039 .03791 m
.11414 .03791 L
s
.11039 .0108 m
.11414 .0108 L
s
.11039 .55301 m
.11414 .55301 L
s
.11039 .58012 m
.11414 .58012 L
s
.11039 .60723 m
.11414 .60723 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -126.812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.812 moveto
(@) show
81.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.812 moveto
(D) show
93.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10.2) show
141.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
147.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
159.000 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
163.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
172.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
190.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02532 .30902 L
.02691 .30902 L
.02866 .30902 L
.03029 .30902 L
.03335 .30902 L
.03499 .30902 L
.03648 .30902 L
.03814 .30902 L
.03968 .30902 L
.04277 .30902 L
.04427 .30902 L
.04592 .30902 L
.04761 .30902 L
.04916 .30902 L
.05227 .30902 L
.05379 .30902 L
.05546 .30902 L
.05717 .30902 L
.05872 .30902 L
.06186 .30902 L
.06341 .30902 L
.06508 .30902 L
.06665 .30902 L
.06837 .30902 L
.07154 .30902 L
.07478 .30902 L
.07791 .30902 L
.08123 .30902 L
.08442 .30902 L
.0875 .30902 L
.09077 .30902 L
.09393 .30902 L
.09696 .30902 L
.10018 .30902 L
.10329 .30902 L
.10659 .30902 L
.10977 .30902 L
.11283 .30902 L
.11609 .30902 L
.11922 .30902 L
.12255 .30902 L
.12576 .30902 L
.12885 .30902 L
.13041 .30902 L
.13124 .30902 L
.13213 .30902 L
.13257 .30902 L
.13299 .30902 L
.13336 .30902 L
Mistroke
.13357 .30902 L
.13377 .30902 L
.13386 .30902 L
.13397 .30902 L
.13406 .30902 L
.13415 .30902 L
.13424 .30902 L
.13433 .30902 L
.13442 .30902 L
.13451 .30902 L
.13461 .30902 L
.13471 .30902 L
.13489 .30902 L
.13508 .30902 L
.13529 .30902 L
.13569 .30902 L
.13605 .30902 L
.13645 .30902 L
.13689 .30902 L
.13777 .30902 L
.13857 .30902 L
.13936 .30902 L
.14009 .30902 L
.14176 .30902 L
.1434 .30902 L
.1449 .30902 L
.14644 .30902 L
.14811 .30902 L
.14968 .30902 L
.1514 .30902 L
.15456 .30902 L
.15781 .30902 L
.16093 .30902 L
.16424 .30902 L
.16744 .30902 L
.17051 .30902 L
.17379 .30902 L
.17693 .30902 L
.17996 .30902 L
.18164 .30902 L
.18319 .30902 L
.18479 .30902 L
.18558 .30902 L
.18629 .30902 L
.18664 .30902 L
.18702 .30902 L
.18723 .30902 L
.18743 .30902 L
.18761 .30902 L
.18771 .30902 L
Mistroke
.18781 .30902 L
.18791 .30902 L
.188 .30902 L
.1881 .30902 L
.18816 .30902 L
.18821 .30902 L
.18831 .30902 L
.1884 .30902 L
.1885 .30902 L
.1886 .30902 L
.1887 .30902 L
.18881 .30902 L
.18901 .30902 L
.18923 .30902 L
.18947 .30902 L
.18989 .30902 L
.19029 .30902 L
.19103 .30902 L
.19184 .30902 L
.19271 .30902 L
.1943 .30902 L
.1951 .30902 L
.19599 .30902 L
.19754 .30902 L
.19922 .30902 L
.2008 .30902 L
.20252 .30902 L
.2057 .30902 L
.20896 .30902 L
.2121 .30902 L
.21543 .30902 L
.21864 .30902 L
.22173 .30902 L
.22329 .30902 L
.22501 .30902 L
.2258 .30902 L
.22665 .30902 L
.22745 .30902 L
.22783 .30902 L
.22818 .30902 L
.22856 .30902 L
.22877 .30902 L
.22887 .30902 L
.22897 .30902 L
.22906 .30902 L
.22916 .30902 L
.22924 .30902 L
.22933 .30902 L
.22942 .30902 L
.22951 .30902 L
Mistroke
.22961 .30902 L
.22971 .30902 L
.2298 .30902 L
.22991 .30902 L
.23012 .30902 L
.23032 .30902 L
.23051 .30902 L
.23092 .30902 L
.23137 .30902 L
.23179 .30902 L
.23218 .30902 L
.23307 .30902 L
.23385 .30902 L
.23468 .30902 L
.2364 .30902 L
.23802 .30902 L
.23963 .30902 L
.24111 .30902 L
.24428 .30902 L
.24733 .30902 L
.25057 .30902 L
.25369 .30902 L
.25701 .30902 L
.25867 .30902 L
.26021 .30902 L
.2617 .30902 L
.26245 .30902 L
.26288 .30902 L
.26309 .30902 L
.26328 .30902 L
.26348 .30902 L
.26366 .30902 L
.26376 .30902 L
.26386 .30902 L
.26392 .30902 L
.26397 .30902 L
.26407 .30902 L
.26417 .30902 L
.26426 .30902 L
.26437 .30902 L
.26442 .30902 L
.26448 .30902 L
.26458 .30902 L
.26469 .30902 L
.2649 .30902 L
.2651 .30902 L
.26528 .30902 L
.26567 .30902 L
.26604 .30902 L
.26639 .30902 L
Mistroke
.26717 .30902 L
.268 .30902 L
.26871 .30902 L
.26949 .30902 L
.27105 .30902 L
.27273 .30902 L
.27444 .30902 L
.27606 .30902 L
.27914 .30901 L
.28241 .309 L
.28557 .309 L
.2886 .30899 L
.29029 .30899 L
.29103 .30898 L
.29183 .30898 L
.29256 .30898 L
.29335 .30898 L
.29378 .30898 L
.29398 .30898 L
.29417 .30898 L
.29436 .30898 L
.29446 .30898 L
.29457 .30898 L
.29466 .30898 L
.29474 .30898 L
.29484 .30898 L
.29494 .30898 L
.29504 .30898 L
.29509 .30898 L
.29515 .30898 L
.29525 .30898 L
.29536 .30898 L
.29557 .30898 L
.29575 .30898 L
.29596 .30898 L
.29619 .30898 L
.29664 .30898 L
.29705 .30898 L
.29748 .30898 L
.29826 .30898 L
.29908 .30899 L
.29997 .30899 L
.30158 .309 L
.30318 .309 L
.30486 .30901 L
.3079 .30904 L
.31114 .30907 L
.31425 .30911 L
.31583 .30912 L
.31756 .30914 L
Mistroke
.31836 .30915 L
.31921 .30915 L
.32001 .30916 L
.32075 .30916 L
.32115 .30916 L
.32157 .30916 L
.32179 .30916 L
.322 .30916 L
.32212 .30916 L
.32222 .30916 L
.32228 .30916 L
.32235 .30916 L
.32241 .30916 L
.32247 .30916 L
.32256 .30916 L
.32266 .30916 L
.32275 .30916 L
.32284 .30916 L
.32294 .30916 L
.32304 .30916 L
.32325 .30916 L
.32346 .30916 L
.32368 .30916 L
.32409 .30916 L
.32451 .30916 L
.32491 .30916 L
.3258 .30915 L
.32658 .30914 L
.32742 .30913 L
.32899 .30911 L
.33046 .30907 L
.33358 .30899 L
.33689 .30886 L
.34008 .30873 L
.34315 .30862 L
.34473 .30858 L
.34562 .30856 L
.34642 .30855 L
.34681 .30854 L
.34703 .30854 L
.34723 .30854 L
.34741 .30854 L
.34758 .30854 L
.34768 .30854 L
.34777 .30854 L
.34786 .30854 L
.34797 .30854 L
.34807 .30854 L
.34817 .30854 L
.34822 .30854 L
Mistroke
.34827 .30854 L
.34839 .30854 L
.3485 .30854 L
.34862 .30854 L
.34884 .30854 L
.34904 .30854 L
.34925 .30854 L
.34964 .30855 L
.35007 .30855 L
.35046 .30856 L
.35136 .30859 L
.35214 .30862 L
.35298 .30866 L
.35455 .30875 L
.35602 .30886 L
.35914 .30917 L
.36246 .30956 L
.36566 .30994 L
.36712 .31009 L
.36795 .31017 L
.36873 .31022 L
.36949 .31027 L
.36989 .31029 L
.37032 .31031 L
.37075 .31032 L
.37098 .31032 L
.37109 .31033 L
.3712 .31033 L
.37129 .31033 L
.3714 .31033 L
.3715 .31033 L
.37159 .31033 L
.37168 .31033 L
.37179 .31033 L
.37184 .31033 L
.3719 .31033 L
.372 .31033 L
.37206 .31033 L
.37211 .31033 L
.37221 .31033 L
.37242 .31033 L
.37261 .31032 L
.37282 .31032 L
.37328 .3103 L
.3737 .31028 L
.37449 .31022 L
.37531 .31015 L
.37689 .30994 L
.37836 .30967 L
.38149 .30891 L
Mistroke
.38481 .30789 L
.38801 .3069 L
.38948 .30651 L
.39031 .30632 L
.39109 .30618 L
.39186 .30606 L
.39225 .30601 L
.39268 .30597 L
.39289 .30595 L
.39311 .30594 L
.39323 .30593 L
.39334 .30593 L
.39346 .30592 L
.39356 .30592 L
.39366 .30592 L
.39376 .30592 L
.39386 .30592 L
.39392 .30592 L
.39398 .30592 L
.39407 .30592 L
.39416 .30592 L
.39427 .30592 L
.39437 .30592 L
.39447 .30592 L
.39458 .30593 L
.39477 .30594 L
.39514 .30597 L
.39557 .30601 L
.39596 .30606 L
.39668 .30619 L
.39744 .30636 L
.39902 .30688 L
.40049 .30754 L
.40362 .3094 L
.40695 .31178 L
.40862 .31295 L
.41015 .31393 L
.41165 .3147 L
.41241 .31501 L
.41283 .31515 L
.41324 .31526 L
.41363 .31535 L
.41383 .31539 L
.41405 .31542 L
.41425 .31545 L
.41444 .31547 L
.41452 .31547 L
.41462 .31548 L
.41471 .31548 L
.41479 .31549 L
Mistroke
.41489 .31549 L
.415 .31549 L
.41509 .31549 L
.41518 .31549 L
.41529 .31548 L
.4154 .31547 L
.41551 .31547 L
.41561 .31546 L
.41581 .31543 L
.41603 .3154 L
.41647 .3153 L
.41686 .31519 L
.41728 .31505 L
.41802 .31471 L
.41882 .31424 L
.4197 .3136 L
.42127 .31212 L
.42295 .31014 L
.42628 .30543 L
.42949 .30085 L
.43096 .29912 L
.4318 .29831 L
.43258 .29769 L
.43335 .29724 L
.43378 .29706 L
.43397 .297 L
.43417 .29694 L
.43429 .29691 L
.43439 .2969 L
.43449 .29688 L
.43459 .29687 L
.4347 .29686 L
.43476 .29685 L
.43482 .29685 L
.43493 .29685 L
.43498 .29685 L
.43504 .29685 L
.43509 .29685 L
.43515 .29685 L
.43525 .29686 L
.43535 .29687 L
.43544 .29689 L
.43564 .29693 L
.43586 .29699 L
.43626 .29713 L
.43662 .29732 L
.43743 .29789 L
.43814 .29859 L
.4389 .29952 L
.44048 .30209 L
Mistroke
.44196 .30516 L
.4451 .31321 L
.44843 .32212 L
.4501 .32583 L
.45084 .32716 L
.45165 .32835 L
.45202 .3288 L
.45242 .32921 L
.4528 .32951 L
.45315 .32972 L
.45335 .32981 L
.45354 .32987 L
.45364 .3299 L
.45374 .32992 L
.4538 .32993 L
.45386 .32993 L
.45396 .32994 L
.45406 .32994 L
.45416 .32993 L
.45421 .32993 L
.45427 .32992 L
.45437 .3299 L
.45447 .32988 L
.45456 .32985 L
.45474 .32978 L
.45493 .32968 L
.45511 .32957 L
.45552 .32924 L
.45591 .32882 L
.45634 .32825 L
.45711 .32692 L
.45782 .32538 L
.45935 .32104 L
.46101 .31491 L
.46427 .30027 L
.46742 .28636 L
.46824 .28332 L
.46914 .2805 L
.46998 .27837 L
.47075 .27694 L
.47113 .27643 L
.47134 .27621 L
.47154 .27605 L
.47172 .27592 L
.47182 .27587 L
.47192 .27583 L
.472 .2758 L
.4721 .27577 L
.47219 .27576 L
.47227 .27576 L
Mistroke
.47236 .27576 L
.47247 .27577 L
.47252 .27578 L
.47258 .2758 L
.47268 .27584 L
.47279 .27588 L
.47288 .27594 L
.47306 .27607 L
.47328 .27627 L
.47348 .2765 L
.47393 .27717 L
.4743 .2779 L
.4747 .27885 L
.47543 .28102 L
.47709 .28796 L
.47879 .29765 L
.4804 .30861 L
.48347 .33115 L
.48519 .34259 L
.48674 .35089 L
.48752 .35405 L
.48793 .35538 L
.48836 .35654 L
.48874 .35733 L
.48894 .35766 L
.48916 .35794 L
.48926 .35805 L
.48936 .35814 L
.48945 .35821 L
.48954 .35826 L
.48962 .3583 L
.48971 .35833 L
.48979 .35835 L
.48989 .35835 L
.48999 .35834 L
.49009 .35832 L
.49019 .35827 L
.49031 .3582 L
.49041 .35811 L
.49051 .35801 L
.4907 .35778 L
.49106 .35717 L
.49145 .35627 L
.49187 .35499 L
.49232 .35331 L
.49312 .34946 L
.4947 .33898 L
.49617 .32618 L
.49929 .29327 L
.50088 .27619 L
Mistroke
.50261 .25973 L
.50341 .25337 L
.50427 .2478 L
.505 .24416 L
.50541 .24259 L
.50562 .24197 L
.50581 .24147 L
.506 .24103 L
.50618 .24072 L
.50638 .24046 L
.50649 .24035 L
.50659 .24028 L
.50669 .24024 L
.50674 .24022 L
.5068 .24022 L
.5069 .24022 L
.50699 .24025 L
.50705 .24028 L
.5071 .24031 L
.5072 .24039 L
.50731 .2405 L
.50742 .24066 L
.50762 .241 L
.5078 .24139 L
.50819 .24255 L
.50856 .24398 L
.50891 .24564 L
.50969 .25048 L
.51052 .25718 L
.51201 .27285 L
.51506 .31558 L
.51676 .34151 L
.5183 .3635 L
.51907 .37316 L
.51991 .38232 L
.52069 .38938 L
.52143 .39446 L
.52179 .39638 L
.52219 .39798 L
.5224 .39864 L
.52262 .39918 L
.52271 .39935 L
.52281 .3995 L
.52287 .39957 L
.52292 .39963 L
.52302 .39971 L
.52313 .39976 L
.52318 .39977 L
.52324 .39978 L
.52334 .39975 L
Mistroke
.52344 .39969 L
.52349 .39964 L
.52355 .39958 L
.52365 .39944 L
.52377 .39925 L
.52389 .39899 L
.52409 .39843 L
.52431 .39767 L
.52471 .39589 L
.5251 .39358 L
.52546 .391 L
.52627 .38359 L
.52773 .36496 L
.53091 .30779 L
.53396 .24753 L
.53554 .22197 L
.53642 .21077 L
.5368 .20669 L
.53722 .20299 L
.5376 .20018 L
.5378 .19893 L
.53802 .19778 L
.53821 .19691 L
.5384 .19626 L
.53858 .19576 L
.53867 .19557 L
.53875 .19542 L
.53886 .19528 L
.53895 .1952 L
.53906 .19516 L
.53911 .19516 L
.53917 .19517 L
.53926 .19522 L
.53935 .19532 L
.53946 .19546 L
.53955 .19565 L
.53977 .19622 L
.53997 .19695 L
.54042 .19925 L
.54081 .20197 L
.54122 .20561 L
.54195 .214 L
.54275 .22558 L
.54362 .24115 L
.54685 .31608 L
.54995 .39165 L
.55156 .42165 L
.55237 .43267 L
.55283 .4375 L
.55326 .441 L
Mistroke
.55345 .44229 L
.55366 .44341 L
.55377 .44391 L
.55389 .44437 L
.554 .44472 L
.5541 .44499 L
.5542 .4452 L
.5543 .44534 L
.5544 .44543 L
.55446 .44545 L
.55451 .44546 L
.55461 .44543 L
.5547 .44535 L
.5548 .4452 L
.5549 .445 L
.55508 .44449 L
.55527 .44373 L
.55561 .44184 L
.55598 .43903 L
.55639 .43505 L
.55721 .42415 L
.55796 .41112 L
.55964 .37253 L
.56284 .27804 L
.56431 .23472 L
.56592 .1939 L
.56669 .17853 L
.56751 .16558 L
.56797 .16021 L
.56817 .15827 L
.56838 .15646 L
.56858 .15512 L
.56878 .15396 L
.5689 .15345 L
.569 .15306 L
.5691 .15274 L
.5692 .15251 L
.56929 .15236 L
.56939 .15226 L
.56944 .15223 L
.56949 .15223 L
.56959 .15227 L
.56969 .15238 L
.56979 .15255 L
.56989 .15282 L
.57 .15318 L
.57019 .15396 L
.57036 .15491 L
.57074 .15784 L
.57116 .16218 L
Mistroke
.57155 .16723 L
.57241 .18217 L
.57393 .219 L
.57559 .27114 L
.57885 .38447 L
.58035 .42946 L
.58114 .44871 L
.58198 .46482 L
.5824 .4711 L
.58263 .47389 L
.58287 .47646 L
.58309 .47842 L
.58329 .47987 L
.5835 .481 L
.5836 .48143 L
.58369 .48176 L
.58379 .48204 L
.58388 .48222 L
.58398 .48233 L
.58404 .48236 L
.58409 .48236 L
.58418 .48232 L
.58427 .4822 L
.58437 .482 L
.58446 .48174 L
.58457 .48134 L
.58468 .48087 L
.58487 .47975 L
.58508 .4782 L
.58531 .47611 L
.5857 .47156 L
.58606 .46619 L
.58689 .45016 L
.58771 .42986 L
.58858 .40349 L
.59189 .27934 L
.59353 .2173 L
.59434 .19063 L
.59507 .16947 L
.59578 .15224 L
.59655 .13788 L
.59697 .13206 L
.59716 .13 L
.59736 .12807 L
.59754 .12669 L
.59773 .12553 L
.59784 .12503 L
.59794 .12467 L
.59804 .12439 L
.59813 .12421 L
Mistroke
.59823 .1241 L
.59829 .12408 L
.59834 .12408 L
.59843 .12416 L
.59853 .12434 L
.59862 .12458 L
.59871 .12486 L
.5989 .12577 L
.59911 .12712 L
.5993 .1287 L
.59972 .13344 L
.60009 .13877 L
.60048 .14586 L
.6012 .16203 L
.60279 .21107 L
.60448 .27716 L
.60752 .40248 L
.60907 .45413 L
.60995 .47574 L
.61034 .48328 L
.61075 .48982 L
.61096 .49258 L
.61116 .49479 L
.61136 .49656 L
.61154 .49786 L
.61171 .4988 L
.6118 .49917 L
.61189 .49948 L
.61199 .49971 L
.61209 .49986 L
.61218 .4999 L
.61227 .49985 L
.61238 .49971 L
.61243 .49959 L
.61248 .49943 L
.61259 .49907 L
.61268 .49864 L
.6129 .49734 L
.61313 .49543 L
.61355 .49059 L
.61394 .48466 L
.61472 .46837 L
.61545 .4485 L
.61712 .38966 L
.62025 .25447 L
.62185 .19176 L
.62269 .16464 L
.62315 .15208 L
.62358 .14195 L
.62399 .13377 L
Mistroke
.62437 .12773 L
.62479 .12269 L
.62503 .12068 L
.62514 .11988 L
.62525 .11928 L
.62534 .11886 L
.62543 .1185 L
.62553 .11822 L
.62563 .11806 L
.62572 .11799 L
.62581 .11801 L
.6259 .1181 L
.62598 .11828 L
.62609 .1186 L
.62618 .11899 L
.6264 .12021 L
.6266 .12177 L
.62679 .12362 L
.62716 .12829 L
.62756 .13501 L
.62839 .15336 L
.62915 .17554 L
.62987 .20023 L
.63298 .33217 L
.63456 .39865 L
.63539 .42917 L
.63628 .45642 L
.63673 .4676 L
.63715 .4765 L
.63756 .48354 L
.63793 .48855 L
.63829 .49197 L
.63847 .49318 L
.63857 .49372 L
.63867 .49412 L
.63877 .49445 L
.63887 .49465 L
.63897 .49476 L
.63903 .49477 L
.63908 .49475 L
.63917 .49465 L
.63927 .49444 L
.63937 .49411 L
.63947 .49371 L
.63966 .49259 L
.63984 .49118 L
.64025 .48674 L
.64065 .48076 L
.64108 .47263 L
.64186 .45361 L
Mistroke
.64257 .43201 L
.64577 .30235 L
.64724 .24037 L
.64808 .20877 L
.64886 .18304 L
.64969 .1608 L
.65045 .14584 L
.65087 .14003 L
.65106 .13794 L
.65126 .13613 L
.65138 .13531 L
.65148 .13468 L
.65159 .13415 L
.65168 .13377 L
.65174 .1336 L
.6518 .13345 L
.65185 .13333 L
.65192 .13325 L
.65197 .13321 L
.65203 .13321 L
.65209 .13324 L
.65214 .13329 L
.65223 .13346 L
.65232 .13371 L
.65242 .13408 L
.65252 .13458 L
.65274 .13596 L
.65293 .13764 L
.65329 .14172 L
.65367 .14738 L
.65447 .16368 L
.65534 .18762 L
.65859 .31237 L
.6601 .37284 L
.66173 .42721 L
.66216 .43859 L
.66262 .44894 L
.66305 .45687 L
.66344 .46277 L
.66381 .46691 L
.66402 .46863 L
.66421 .46983 L
.66432 .47035 L
.66442 .47073 L
.66448 .4709 L
.66453 .47102 L
.66459 .47114 L
.66465 .47121 L
.66475 .47125 L
.66485 .4712 L
Mistroke
.66495 .47104 L
.665 .47092 L
.66506 .47075 L
.66517 .47036 L
.66526 .46991 L
.66548 .46853 L
.66568 .46692 L
.66588 .46481 L
.66624 .46022 L
.66663 .45381 L
.6675 .43496 L
.66831 .41216 L
.67142 .29858 L
.673 .24084 L
.67384 .21466 L
.67473 .19173 L
.67517 .18254 L
.67559 .1754 L
.67597 .17031 L
.67617 .16819 L
.67638 .16627 L
.67658 .16485 L
.67677 .16386 L
.67687 .16346 L
.67697 .16318 L
.67702 .16306 L
.67708 .16296 L
.67718 .16286 L
.67727 .16285 L
.67736 .16292 L
.67747 .16309 L
.67756 .16335 L
.67765 .16365 L
.67773 .164 L
.67791 .16501 L
.67811 .16646 L
.67829 .16808 L
.6787 .17279 L
.67943 .18479 L
.68029 .20398 L
.68109 .22637 L
.68418 .331 L
.68574 .38064 L
.68657 .4022 L
.68703 .41218 L
.68746 .42027 L
.68787 .42654 L
.68808 .42932 L
.68831 .43185 L
.68853 .43379 L
Mistroke
.68872 .43523 L
.68891 .43635 L
.68909 .43711 L
.68918 .43738 L
.68928 .4376 L
.68938 .43774 L
.68948 .43779 L
.68957 .43776 L
.68965 .43768 L
.68974 .43752 L
.68983 .43729 L
.68992 .43697 L
.69003 .43655 L
.69021 .43557 L
.69041 .4342 L
.69062 .43233 L
.69102 .42794 L
.69143 .42202 L
.69218 .40838 L
.69385 .36609 L
.69691 .27274 L
.69849 .23237 L
.69894 .22315 L
.69937 .21565 L
.69975 .21002 L
.70017 .20503 L
.70037 .20315 L
.70058 .20146 L
.70076 .20026 L
.70095 .19924 L
.70107 .19878 L
.70117 .19845 L
.70128 .19821 L
.70133 .19812 L
.70139 .19805 L
.70148 .19798 L
.70159 .19799 L
.70169 .19808 L
.70178 .19822 L
.70187 .19842 L
.70196 .19869 L
.70212 .19935 L
.70232 .20039 L
.7025 .2016 L
.70289 .20502 L
.70326 .20924 L
.70404 .22102 L
.70486 .23724 L
.70634 .2733 L
.70938 .35286 L
Mistroke
.71018 .37003 L
.71094 .38349 L
.71136 .38952 L
.71181 .39488 L
.71202 .39682 L
.71223 .39859 L
.71241 .39987 L
.71262 .40101 L
.71282 .40191 L
.71294 .40227 L
.71305 .40254 L
.71314 .40271 L
.71324 .40281 L
.71334 .40286 L
.71344 .40283 L
.71349 .40279 L
.71355 .40273 L
.71361 .40264 L
.71366 .40253 L
.71376 .4023 L
.71387 .40197 L
.71411 .40094 L
.71433 .39966 L
.71471 .39679 L
.71512 .39266 L
.71595 .38147 L
.71753 .35189 L
.71921 .31376 L
.72081 .27833 L
.72165 .26223 L
.72254 .24828 L
.72333 .23909 L
.72355 .23716 L
.72379 .23538 L
.72399 .2341 L
.72421 .23297 L
.72431 .23253 L
.72442 .23214 L
.72452 .23185 L
.72462 .2316 L
.72473 .23141 L
.72483 .23129 L
.72492 .23123 L
.72501 .23123 L
.7251 .23126 L
.72518 .23134 L
.72527 .23147 L
.72537 .23166 L
.72547 .23191 L
.72557 .2322 L
Mistroke
.72575 .2329 L
.72612 .23487 L
.72653 .23789 L
.72735 .24649 L
.72811 .25705 L
.72883 .26875 L
.73194 .32719 L
.73355 .35265 L
.73436 .36201 L
.73482 .36605 L
.73524 .36893 L
.73544 .36998 L
.73565 .37088 L
.73576 .37126 L
.73588 .37161 L
.73599 .37188 L
.73609 .37207 L
.73619 .37221 L
.73629 .3723 L
.73639 .37234 L
.73645 .37234 L
.7365 .37233 L
.73659 .37227 L
.73669 .37217 L
.73679 .37201 L
.73689 .37182 L
.73707 .37133 L
.73726 .37065 L
.73761 .36902 L
.73798 .36667 L
.73838 .36345 L
.73921 .355 L
.73995 .34546 L
.74164 .3201 L
.7433 .29419 L
.74404 .284 L
.74484 .27433 L
.74562 .26696 L
.74599 .26418 L
.74634 .26203 L
.74653 .26106 L
.74674 .26018 L
.74693 .25952 L
.7471 .25905 L
.7472 .25883 L
.74731 .25865 L
.74737 .25856 L
.74742 .2585 L
.74748 .25845 L
.74753 .25841 L
Mistroke
.74762 .25837 L
.74772 .25836 L
.74782 .2584 L
.74793 .25847 L
.74802 .25859 L
.74813 .25875 L
.74835 .25923 L
.74855 .25984 L
.74874 .26056 L
.74917 .26264 L
.74963 .26559 L
.75048 .27269 L
.75125 .28076 L
.7529 .30099 L
.75443 .32019 L
.75591 .33569 L
.75634 .33922 L
.75674 .34209 L
.75713 .34441 L
.75749 .34615 L
.75786 .34749 L
.75806 .34802 L
.75827 .34845 L
.75838 .34861 L
.75843 .34868 L
.75849 .34874 L
.75855 .34879 L
.7586 .34882 L
.7587 .34886 L
.7588 .34887 L
.75891 .34885 L
.75901 .34879 L
.7591 .34871 L
.75918 .34861 L
.75928 .34847 L
.75944 .34817 L
.75964 .34769 L
.75982 .34715 L
.76021 .34565 L
.76058 .34383 L
.76136 .33887 L
.76218 .33222 L
.76366 .31799 L
.76525 .30212 L
.7667 .2897 L
.7675 .2845 L
.76786 .28259 L
.76825 .28091 L
.76847 .28015 L
.76867 .27956 L
Mistroke
.76887 .27907 L
.76906 .27871 L
.76916 .27854 L
.76927 .2784 L
.76939 .27829 L
.76945 .27824 L
.76951 .2782 L
.76956 .27818 L
.76961 .27816 L
.76971 .27815 L
.76982 .27817 L
.76988 .27819 L
.76993 .27822 L
.77002 .27828 L
.77012 .27838 L
.7703 .27861 L
.77049 .27894 L
.7707 .27941 L
.77108 .28052 L
.77143 .28183 L
.77223 .28577 L
.77308 .29116 L
.77468 .30325 L
.77641 .31659 L
.77722 .32199 L
.77808 .3267 L
.77881 .32971 L
.77923 .33095 L
.77962 .3318 L
.77983 .33212 L
.78002 .33234 L
.78013 .33243 L
.78023 .3325 L
.78028 .33252 L
.78034 .33254 L
.7804 .33255 L
.78045 .33256 L
.78055 .33255 L
.78064 .33253 L
.78074 .33249 L
.78084 .33243 L
.78095 .33233 L
.78105 .33223 L
.78125 .33197 L
.78162 .33127 L
.78196 .3304 L
.78273 .32772 L
.78351 .32419 L
.78423 .32029 L
.78589 .31037 L
Mistroke
.78737 .30184 L
.78822 .29781 L
.789 .29482 L
.7894 .29362 L
.78978 .29271 L
.78999 .29231 L
.79021 .29195 L
.79042 .29169 L
.79061 .29151 L
.79071 .29144 L
.79081 .29138 L
.79091 .29135 L
.791 .29133 L
.79111 .29132 L
.79117 .29132 L
.79122 .29133 L
.79132 .29136 L
.79138 .29138 L
.79143 .29141 L
.79154 .29148 L
.79165 .29156 L
.79188 .29179 L
.79209 .29207 L
.7923 .29243 L
.79307 .2942 L
.79388 .29684 L
.79536 .30297 L
.79695 .31029 L
.79779 .31387 L
.79869 .31716 L
.79948 .31947 L
.79993 .32049 L
.80035 .32122 L
.80055 .3215 L
.80074 .32171 L
.80091 .32187 L
.80109 .322 L
.8012 .32205 L
.80129 .32209 L
.80139 .32211 L
.80147 .32213 L
.80158 .32214 L
.80167 .32213 L
.80178 .32211 L
.80183 .3221 L
.80189 .32208 L
.802 .32203 L
.80209 .32198 L
.80231 .32182 L
.8025 .32163 L
Mistroke
.80271 .32138 L
.80346 .32013 L
.80426 .31823 L
.80514 .31564 L
.80682 .30993 L
.80836 .30495 L
.80915 .30286 L
.80988 .30131 L
.81027 .30065 L
.81064 .30017 L
.81104 .29977 L
.81126 .29962 L
.81136 .29956 L
.81147 .29951 L
.81157 .29947 L
.81166 .29945 L
.81175 .29943 L
.81184 .29942 L
.81194 .29942 L
.81204 .29943 L
.81214 .29944 L
.8122 .29946 L
.81225 .29947 L
.81245 .29955 L
.81257 .29961 L
.81268 .29968 L
.81308 .30001 L
.81342 .3004 L
.8138 .30093 L
.81456 .30227 L
.81781 .31009 L
.81931 .31331 L
.81972 .314 L
.82015 .31464 L
.82053 .31509 L
.82093 .31547 L
.82115 .31563 L
.82135 .31575 L
.82155 .31584 L
.82165 .31587 L
.82175 .3159 L
.82185 .31592 L
.82191 .31593 L
.82197 .31594 L
.82207 .31595 L
.82212 .31595 L
.82218 .31595 L
.82223 .31594 L
.82228 .31594 L
.82234 .31593 L
Mistroke
.8224 .31592 L
.82253 .31589 L
.82264 .31586 L
.82285 .31577 L
.82304 .31567 L
.82347 .31536 L
.82385 .31499 L
.82426 .31453 L
.82582 .31212 L
.82729 .30944 L
.82877 .30689 L
.82961 .30572 L
.83002 .30525 L
.83039 .30489 L
.83076 .30459 L
.83117 .30434 L
.83139 .30424 L
.83159 .30416 L
.83179 .30412 L
.83189 .3041 L
.83194 .30409 L
.832 .30408 L
.83205 .30408 L
.83211 .30408 L
.83216 .30408 L
.83222 .30407 L
.83232 .30408 L
.83242 .30409 L
.83248 .30409 L
.83253 .3041 L
.83265 .30413 L
.83287 .30419 L
.83306 .30425 L
.83327 .30435 L
.83369 .3046 L
.83451 .30527 L
.83526 .30607 L
.83694 .30822 L
.8386 .31032 L
.83933 .31109 L
.83972 .31145 L
.84014 .31177 L
.84054 .31203 L
.84091 .31222 L
.84126 .31236 L
.84144 .31241 L
.84163 .31245 L
.84174 .31247 L
.84184 .31248 L
.84193 .31249 L
Mistroke
.84203 .3125 L
.84208 .3125 L
.84214 .3125 L
.84219 .3125 L
.84225 .3125 L
.84235 .31249 L
.84245 .31248 L
.84255 .31247 L
.84266 .31245 L
.84285 .31241 L
.84304 .31236 L
.84322 .3123 L
.84363 .31213 L
.84407 .31189 L
.84487 .31134 L
.84636 .31003 L
.84794 .30857 L
.84877 .30788 L
.84966 .30728 L
.8501 .30705 L
.85052 .30687 L
.8509 .30674 L
.85111 .30669 L
.8513 .30665 L
.85139 .30664 L
.85149 .30662 L
.85157 .30661 L
.85166 .3066 L
.85176 .3066 L
.85186 .30659 L
.85196 .30659 L
.85205 .30659 L
.85215 .30659 L
.85225 .3066 L
.85234 .30661 L
.85243 .30662 L
.85264 .30664 L
.85284 .30668 L
.85321 .30677 L
.85362 .30691 L
.85435 .30723 L
.85601 .30821 L
.8576 .30925 L
.85843 .30975 L
.85933 .31018 L
.8597 .31033 L
.86011 .31046 L
.86035 .31052 L
.86056 .31057 L
.86078 .31061 L
Mistroke
.86099 .31064 L
.86116 .31066 L
.86125 .31067 L
.86134 .31068 L
.86145 .31068 L
.86155 .31069 L
.86165 .31069 L
.86173 .31069 L
.86183 .31069 L
.86192 .31068 L
.86201 .31068 L
.86212 .31067 L
.86223 .31066 L
.86233 .31065 L
.86252 .31063 L
.86293 .31056 L
.86329 .31048 L
.86412 .31022 L
.86559 .30961 L
.86727 .30885 L
.86801 .30855 L
.86881 .30827 L
.86919 .30816 L
.86959 .30807 L
.86994 .308 L
.87032 .30794 L
.87054 .30792 L
.87064 .30791 L
.87075 .3079 L
.87084 .30789 L
.87094 .30789 L
.871 .30788 L
.87105 .30788 L
.87115 .30788 L
.87124 .30788 L
.87133 .30788 L
.87142 .30788 L
.87152 .30788 L
.87163 .30788 L
.87172 .30789 L
.87191 .3079 L
.8721 .30792 L
.87228 .30793 L
.87269 .30799 L
.87309 .30806 L
.87352 .30815 L
.875 .30856 L
.87659 .30906 L
.87743 .3093 L
.87832 .30951 L
Mistroke
.87911 .30966 L
.87956 .30972 L
.87976 .30974 L
.87998 .30975 L
.88016 .30977 L
.88026 .30977 L
.88036 .30978 L
.88046 .30978 L
.88055 .30978 L
.88063 .30978 L
.88072 .30979 L
.88081 .30979 L
.88091 .30979 L
.881 .30978 L
.8811 .30978 L
.8812 .30978 L
.88131 .30978 L
.88151 .30977 L
.88172 .30975 L
.88193 .30973 L
.88232 .30969 L
.88321 .30957 L
.88482 .30925 L
.88643 .30891 L
.88727 .30876 L
.88773 .30869 L
.88816 .30863 L
.88858 .30858 L
.88896 .30855 L
.88916 .30854 L
.88938 .30852 L
.88951 .30852 L
.88962 .30851 L
.88972 .30851 L
.88984 .30851 L
.88993 .30851 L
.89002 .3085 L
.8901 .3085 L
.89019 .3085 L
.89029 .3085 L
.89038 .3085 L
.89048 .30851 L
.89059 .30851 L
.89069 .30851 L
.8908 .30851 L
.891 .30852 L
.89138 .30854 L
.89177 .30857 L
.89214 .3086 L
.89298 .3087 L
Mistroke
.89466 .30893 L
.89616 .30914 L
.89694 .30922 L
.89778 .3093 L
.89825 .30932 L
.89866 .30934 L
.89887 .30935 L
.89897 .30935 L
.89909 .30935 L
.89918 .30935 L
.89924 .30936 L
.89929 .30936 L
.89939 .30936 L
.89948 .30936 L
.89954 .30936 L
.89959 .30936 L
.89969 .30936 L
.89975 .30936 L
.8998 .30935 L
.89992 .30935 L
.90002 .30935 L
.90011 .30935 L
.90033 .30934 L
.90072 .30933 L
.9011 .30931 L
.90187 .30926 L
.90268 .30919 L
.90416 .30905 L
.90576 .30891 L
.9062 .30888 L
.90667 .30885 L
.90707 .30883 L
.9075 .30881 L
.90771 .30881 L
.90791 .3088 L
.90809 .3088 L
.90819 .3088 L
.90829 .3088 L
.90838 .3088 L
.90848 .3088 L
.90857 .30879 L
.90867 .30879 L
.90876 .30879 L
.90886 .30879 L
.90894 .3088 L
.90903 .3088 L
.90914 .3088 L
.90925 .3088 L
.90945 .3088 L
.90967 .30881 L
Mistroke
.9099 .30881 L
.91071 .30884 L
.91147 .30888 L
.91231 .30893 L
.91399 .30904 L
.91479 .30908 L
.91555 .30912 L
.91597 .30913 L
.91643 .30914 L
.91663 .30915 L
.91685 .30915 L
.91703 .30916 L
.91723 .30916 L
.91734 .30916 L
.91744 .30916 L
.91755 .30916 L
.91761 .30916 L
.91766 .30916 L
.91776 .30916 L
.91786 .30916 L
.91796 .30916 L
.91806 .30916 L
.91811 .30916 L
.91816 .30916 L
.91826 .30916 L
.91849 .30916 L
.91873 .30915 L
.91895 .30915 L
.91974 .30913 L
.92057 .3091 L
.92218 .30904 L
.92363 .30898 L
.92439 .30896 L
.92479 .30895 L
.92521 .30894 L
.92542 .30894 L
.92566 .30893 L
.92588 .30893 L
.92607 .30893 L
.92628 .30893 L
.92639 .30893 L
.9265 .30892 L
.92659 .30892 L
.92669 .30892 L
.92678 .30892 L
.92689 .30892 L
.92698 .30892 L
.92708 .30892 L
.92719 .30892 L
.92728 .30893 L
Mistroke
.92746 .30893 L
.92764 .30893 L
.92806 .30893 L
.92845 .30894 L
.9292 .30895 L
.92992 .30897 L
.93138 .30901 L
.93222 .30903 L
.933 .30905 L
.93377 .30906 L
.9342 .30907 L
.93459 .30907 L
.93479 .30907 L
.93501 .30907 L
.93513 .30907 L
.93524 .30908 L
.93535 .30908 L
.93546 .30908 L
.93556 .30908 L
.93566 .30908 L
.93577 .30908 L
.93583 .30908 L
.93588 .30908 L
.93598 .30908 L
.93607 .30908 L
.93618 .30908 L
.93628 .30908 L
.93647 .30907 L
.93665 .30907 L
.93706 .30907 L
.93745 .30907 L
.93788 .30906 L
.93936 .30904 L
.94093 .30901 L
.94177 .309 L
.94223 .30899 L
.94266 .30899 L
.94307 .30899 L
.94329 .30898 L
.94352 .30898 L
.94372 .30898 L
.94393 .30898 L
.94402 .30898 L
.94413 .30898 L
.94421 .30898 L
.94431 .30898 L
.94441 .30898 L
.9445 .30898 L
.94456 .30898 L
.94462 .30898 L
Mistroke
.94472 .30898 L
.94482 .30898 L
.94491 .30898 L
.945 .30898 L
.94511 .30898 L
.94529 .30898 L
.94546 .30898 L
.94584 .30898 L
.94624 .30899 L
.94668 .30899 L
.94748 .309 L
.94897 .30901 L
.95053 .30903 L
.95095 .30903 L
.95141 .30903 L
.95181 .30904 L
.95202 .30904 L
.95225 .30904 L
.95246 .30904 L
.95266 .30904 L
.95276 .30904 L
.95286 .30904 L
.95296 .30904 L
.95305 .30904 L
.95315 .30904 L
.9532 .30904 L
.95326 .30904 L
.95332 .30904 L
.95338 .30904 L
.95343 .30904 L
.95349 .30904 L
.95359 .30904 L
.95364 .30904 L
.9537 .30904 L
.95389 .30904 L
.95399 .30904 L
.95409 .30904 L
.95427 .30904 L
.95467 .30904 L
.9554 .30903 L
.95698 .30902 L
.95846 .30901 L
.9593 .30901 L
.95972 .30901 L
.9601 .30901 L
.96044 .309 L
.96081 .309 L
.96119 .309 L
.9614 .309 L
.96159 .309 L
Mistroke
.96169 .309 L
.96174 .309 L
.9618 .309 L
.9619 .309 L
.96199 .309 L
.96204 .309 L
.9621 .309 L
.9622 .309 L
.96225 .309 L
.96231 .309 L
.96242 .309 L
.96253 .309 L
.96262 .309 L
.96281 .309 L
.96322 .309 L
.96359 .309 L
.96393 .30901 L
.9647 .30901 L
.96633 .30902 L
.96713 .30902 L
.96786 .30902 L
.96857 .30902 L
.96893 .30902 L
.96932 .30902 L
.96952 .30903 L
.96971 .30903 L
.96989 .30903 L
.97007 .30903 L
.97016 .30903 L
.97027 .30903 L
.97038 .30903 L
.97044 .30903 L
.97049 .30903 L
.97059 .30903 L
.97068 .30903 L
.97079 .30903 L
.97089 .30903 L
.97099 .30903 L
.9711 .30903 L
.97129 .30903 L
.97149 .30903 L
.97166 .30903 L
.97206 .30902 L
.97248 .30902 L
.97396 .30902 L
.97619 .30901 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{421.375, 260.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40008>0001AB000`400?l00000o`00003ooooooooo
oooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo
003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooo
oooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool0
0?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooooooo
ool@ooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003ooooo
ooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo0ol0003o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0
003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo
00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`
ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLoooo
o`00<?ooool3o`000?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?oo
ool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0
033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomco
oooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooo
oooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo
0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool3o`000?oooooo
g?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0?oooooog?ooool0013ooooo0_o^k^h3ooooo`;ok^k^6Oooool00ol0003oooooooooo`3o
ooooomcooooo000;ooooo`;o000000[o410@ooooooooooook^k^oeEEEOo^k^koooooonk^k_mEEEGo
k^k^0oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h:ooooo`03o`000?oo
oooooooo0?oooooog?ooool000cooooo00?o0000ooooooooool00_ooool01Oo^k^koEEEEomgMgOmE
EEGok^k^00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00[ooooo
00?o0000ooooooooool0oooooooLooooo`0000?oooooo`000?l000001?l00002ooooo`Go00001?oo
ool00ooMgMgo0000omgMg@07ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooo
oa0@400:ooooo`03o`000?oooooooooo0?oooooog?ooool000Wooooo00CoA4A4omgMgOoooooo0000
1?ooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000000[ooooo00?o0000ooooooooool0oooooooLooooo`002Oooool01?oMgMgo
EEEEooooool00003ooooo`07onk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000:ooooo`Co0000oooooooKooooo`002_oo
ool00omgMgOoc<c<o`000003ooooo`;ok^k^0oooool2onk^kPGooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@00[ooooo00?o0000ooooooooool0oooooooLooooo`002_oo
ool00oo^k^koA4A4o`00000?ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`03ooooo`;o00001Oooool00ol0003oooooooooo`3oooooomcooooo000;ooooo`03ogMgMol0
003ooooo00cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`3oooooomcooooo000Xooooo`04o`00
0?ooooooooooo`0000Cooooo00?o0000ooooooooool0oooooooLooooo`00:?ooool3o`0000Gooooo
00?o0000ooooooooool0oooooooLooooo`00:Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo0?oooooog?ooool002[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3o
ooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooooooo
ool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oo
oooooooo0=gooooo00?o0000ooooooooool0noooool0033ooooo0ol0003Mooooo`03o`000?oooooo
oooo0?_ooooo000`ooooo`03o`000?oooooooooo0=cooooo0_l0003mooooo`00<?ooool00ol0003o
ooooooooo`3Aooooo`03o`000?oooooooooo00Sooooo0_l0003mooooo`00<?ooool00ol0003ooooo
ooooo`3Aooooo`03o`000?oooooooooo00Sooooo0_l0003mooooo`00<?ooool00ol0003ooooooooo
o`3Aooooo`03o`000?oooooooooo00Sooooo0_l0003mooooo`00<?ooool00ol0003oooooooooo`3@
ooooo`;o00002_ooool2o`000?gooooo000`ooooo`03o`000?oooooooooo0=3ooooo00?o0000oooo
ool000002Oooool00ol0003oooooo`000009ooooo`03o`000?oooooooooo0?3ooooo000`ooooo`03
o`000?oooooooooo0=3ooooo00?o0000ooooool000002Oooool00ol0003oooooo`000009ooooo`;o
0000lOooool0033ooooo00?o0000ooooooooool0d?ooool00ol0003oooooo`000009ooooo`03o`00
0?oooooo000000Wooooo0_l0003aooooo`00<?ooool00ol0003oooooooooo`3@ooooo`03o`000?oo
oooo000000Wooooo00?o0000ooooool000002Oooool2o`000?7ooooo000`ooooo`03o`000?oooooo
oooo0=3ooooo00?o0000ooooool000002Oooool00ol0003oooooo`000009ooooo`;o0000lOooool0
033ooooo00?o0000ooooooooool0d?ooool00ol0003oooooo`000009ooooo`03o`000?oooooo0000
00Wooooo0_l0003aooooo`00<?ooool3o`000=3ooooo00?o0000ooooool000002Oooool00ol0003o
ooooo`000009ooooo`;o0000lOooool0033ooooo00?o0000ooooooooool0d?ooool00ol0003ooooo
o`000009ooooo`03o`000?oooooo000000Wooooo0_l0003aooooo`00<?ooool00ol0003ooooooooo
o`34ooooo`;o00002_ooool00ol0003oooooo`000009ooooo`03o`000?oooooo000000Wooooo0_l0
003aooooo`00<?ooool00ol0003oooooooooo`34ooooo`;o00002_ooool00ol0003oooooo`000009
ooooo`03o`000?oooooo000000Sooooo00?o0000ooooool00000lOooool0033ooooo00?o0000oooo
ooooool0a?ooool2o`0000[ooooo00?o0000ooooool000002Oooool00ol0003oooooo`000008oooo
o`03o`000?oooooo00000?7ooooo000`ooooo`03o`000?oooooooooo0<Cooooo0_l0000:ooooo`03
o`000?oooooo000000Wooooo00?o0000ooooool000002?ooool00ol0003oooooo`00003aooooo`00
<?ooool00ol0003oooooooooo`34ooooo`;o00002_ooool00ol0003oooooo`000009ooooo`03o`00
0?oooooo000000Sooooo00?o0000ooooool00000lOooool0033ooooo00?o0000ooooooooool0a?oo
ool2o`0000[ooooo00?o0000ooooool000002Oooool00ol0003oooooo`000008ooooo`03o`000?oo
oooo000000Wooooo00?o0000ooooooooool0iOooool0033ooooo00?o0000ooooooooool0a?ooool2
o`0000[ooooo00?o0000ooooool000002Oooool00ol0003oooooo`000008ooooo`03o`000?oooooo
000000Wooooo0_l0003Vooooo`00<?ooool00ol0003oooooooooo`34ooooo`;o00002_ooool00ol0
003oooooo`000009ooooo`03o`000?oooooo000000Sooooo00?o0000ooooool000002Oooool2o`00
0>Kooooo000`ooooo`03o`000?oooooooooo0<Cooooo0_l0000:ooooo`03o`000?oooooo000000Wo
oooo00?o0000ooooool000002?ooool00ol0003oooooo`000009ooooo`;o0000i_ooool0033ooooo
0ol00034ooooo`;o00002_ooool00ol0003oooooo`000009ooooo`03o`000?oooooo000000Sooooo
00?o0000ooooool000002Oooool2o`000>Kooooo000`ooooo`03o`000?oooooooooo0<?ooooo00?o
0000ooooool000002_ooool00ol0003oooooo`000009ooooo`03o`000?oooooo000000Sooooo00?o
0000ooooool000002?ooool00ol0003oooooo`00003Vooooo`00<?ooool00ol0003oooooooooo`33
ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooool000002Oooool00ol0003oooooo`00
0008ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool00000i_ooool0033ooooo00?o
0000ooooooooool0`oooool01?l0003oooooooooool00009ooooo`03o`000?oooooo000000Sooooo
00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00007ooooo`03o`000?oooooo0000
0>Kooooo000`ooooo`03o`000?oooooooooo0<?ooooo00Co0000oooooooooooo00002?ooool01?l0
003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000
1oooool00ol0003oooooo`00003Vooooo`00<?ooool00ol0003oooooooooo`33ooooo`04o`000?oo
ooooooooo`0000Sooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool00000i_ooool0033ooooo00?o0000oooo
ooooool0`oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo00Co
0000oooooooooooo00002?ooool01?l0003oooooooooool00007ooooo`03o`000?oooooo00000>Ko
oooo000@ooooo`;ok^k^0oooool2onk^kQWooooo00?o0000ooooooooool0`oooool01?l0003ooooo
ooooool00008ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo
000000Oooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00003Vooooo`002Oooool5
o`0000;ooooo00Ook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00?ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^2_ooool00ol0003oooooooooo`33ooooo`04o`000?oooooo
ooooo`0000Sooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool0
00001oooool01?l0003oooooooooool00007ooooo`03o`000?oooooo00000>Kooooo0009ooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000
ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00[ooooo00?o0000ooooooooool0`ooo
ool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003o
oooooooooooooooo000000Oooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00003V
ooooo`0000?oooooo`000?l000001?l00003ooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?ogMgMo`00
0?oMgMd01oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41002_ooool0
0ol0003oooooooooo`2gooooo`03o`000?oooooooooo00Wooooo00Co0000oooooooooooo00002?oo
ool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04
o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo0000iOooool000_ooooo00?oV9RHob4Q
8Oo^k^h00oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000000[ooooo00?o0000ooooooooool0]oooool2o`0000[ooooo00Co
0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooooooo
ooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00002?oo
ool00ol0003oooooooooo`3Jooooo`003?ooool02omgMgOoIVIVooooooooooook^k^oeEEEOo^k^ko
ooooonk^k_mEEEGok^k^00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo
000000[ooooo1?l0002fooooo`;o00002_ooool01?l0003oooooooooool00008ooooo`05o`000?oo
ooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooo
oooo00001oooool01?l0003oooooooooool00007ooooo`;o0000g?ooool000gooooo00?o0000oooo
ooooool00_o^k^h3ooooo`;ok^k^1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@41002_ooool00ol0003oooooooooo`2fooooo`03o`000?oooooo000000[ooooo00Co0000
oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooooooooooo
ooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00001oooool2
o`000=cooooo0009ooooo`05o`000?nj^[[ooooooiRHV?l@41003_ooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool2o`0000Gooooo00?o0000ooooooooool0]_oo
ool00ol0003oooooo`00000:ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooooooo
ooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool00007
ooooo`04o`000?ooooooooooo`0000Oooooo0_l0003Looooo`002Oooool01OnHV9So410@o`000?lQ
8B7oc<c<00cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`2fooooo`03o`000?oooooo000000[o
oooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000
ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo
00001oooool2o`000=cooooo000Xooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool0]_ooool00ol0003oooooo`00000:ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000oooo
ooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool01?l0003ooooooooo
ool00007ooooo`04o`000?ooooooooooo`0000Oooooo0_l0003Looooo`00:?ooool3o`0000Gooooo
00?o0000ooooooooool0]_ooool00ol0003oooooo`00000:ooooo`04o`000?ooooooooooo`0000So
oooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001oooool0
1?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Oooooo0_l0003Looooo`00:Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0;Kooooo00?o0000ooooool000002_oo
ool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003o
oooooooooooooooo000000Oooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool0
0007ooooo`;o0000g?ooool002[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2f
ooooo`03o`000?oooooo000000Wooooo00Go0000ooooooooooooooooo`000008ooooo`05o`000?oo
ooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooo
oooo00001oooool01?l0003oooooooooool00007ooooo`03o`000?oooooo00000=_ooooo000`oooo
o`03o`000?oooooooooo0;Kooooo00?o0000ooooool000002Oooool01Ol0003ooooooooooooooooo
000000Sooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool00000
1oooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000oooo
ool00000foooool0033ooooo00?o0000ooooooooool0]_ooool01?l0003oooooooooool00008oooo
o`05o`000?ooooooooooooooool000002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go
0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooo
oooo00001oooool00ol0003oooooo`00003Kooooo`00<?ooool00ol0003oooooooooo`2fooooo`04
o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`000008ooooo`05o`000?oooooo
ooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo
00001oooool01?l0003oooooooooool00007ooooo`03o`000?oooooo00000=_ooooo000`ooooo`03
o`000?oooooooooo0;Kooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo
000000Sooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01Oooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Oo
oooo00?o0000ooooool00000foooool0033ooooo0ol0002fooooo`04o`000?ooooooooooo`0000So
oooo00Go0000ooooooooooooooooo`000008ooooo`05o`000?ooooooooooooooool000001_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00
0007ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool00000foooool0033ooooo00?o
0000ooooooooool0]_ooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool0
00002?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooo
oooo000000Kooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`3@ooooo`00<?oo
ool00ol0003oooooooooo`2fooooo`04o`000?ooooooooooo`0000Sooooo00Go0000oooooooooooo
ooooo`000008ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?oooooo
ooooooooool000001_ooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo0=3ooooo
000`ooooo`03o`000?oooooooooo0;Kooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooo
oooooooooooo000000Sooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000
ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Oooooo0_l0003Booooo`00<?oo
ool00ol0003oooooooooo`2eooooo`05o`000?ooooooooooooooool000002?ooool01Ol0003ooooo
oooooooooooo000000Sooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000
ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool00000
dOooool0033ooooo00?o0000ooooooooool0ZOooool00ol0003oooooooooo`09ooooo`05o`000?oo
ooooooooooooool000002?ooool01Ol0003ooooooooooooooooo000000Sooooo00Go0000oooooooo
ooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0
003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?oo
ooooooooo`0000Oooooo00?o0000ooooool00000dOooool0033ooooo00?o0000ooooooooool0ZOoo
ool2o`0000[ooooo00Go0000ooooooooooooooooo`000008ooooo`05o`000?ooooooooooooooool0
00002?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooo
oooo000000Kooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00003Aooooo`00<?oo
ool00ol0003oooooooooo`2Xooooo`03o`000?oooooo000000[ooooo00Go0000oooooooooooooooo
o`000008ooooo`05o`000?ooooooooooooooool000002?ooool01Ol0003ooooooooooooooooo0000
00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooo
ooooool000001_ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo0000
1oooool00ol0003oooooo`00003Aooooo`00<?ooool00ol0003oooooooooo`2Xooooo`03o`000?oo
oooo000000[ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool0
00001_ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo00001oooool0
0ol0003oooooo`00003Aooooo`00<?ooool00ol0003oooooooooo`2Xooooo`03o`000?oooooo0000
00[ooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_oo
ool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo00001oooool00ol0003o
ooooo`00003Aooooo`00<?ooool00ol0003oooooooooo`2Xooooo`03o`000?oooooo000000[ooooo
00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0
003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00
003Aooooo`00<?ooool00ol0003oooooooooo`2Xooooo`03o`000?oooooo000000[ooooo00Go0000
ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooo
ool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo00001oooool00ol0003o
ooooo`00003Aooooo`00<?ooool3o`000:Sooooo00Co0000oooooooooooo00002Oooool01Ol0003o
oooooooooooooooo000000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool00007ooooo`03o`000?oo
oooo00000=7ooooo000`ooooo`03o`000?oooooooooo0:Oooooo00Go0000ooooooooooooooooo`00
0009ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?oooooooooooooo
ool000001Oooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo0<Kooooo000`oooo
o`03o`000?oooooooooo0:Oooooo00Go0000ooooooooooooooooo`000009ooooo`05o`000?oooooo
ooooooooool000002?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go
0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001Oooool01?l0003o
ooooooooool00007ooooo`;o0000b?ooool0033ooooo00?o0000ooooooooool0Yoooool01Ol0003o
oooooooooooooooo000000Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo
000000Kooooo00Go0000ooooooooooooooooo`000005ooooo`04o`000?ooooooooooo`0000Oooooo
0_l00038ooooo`00<?ooool00ol0003oooooooooo`2Wooooo`05o`000?ooooooooooooooool00000
2Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003o
oooooooooooooooo000000Gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
00000<Oooooo000`ooooo`03o`000?oooooooooo04kooooo0_o^k^h3ooooo`;ok^k^D_ooool01Ol0
003ooooooooooooooooo000000;ok^k^0oooool2onk^kP;ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool0
1Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000005ooooo`05o`00
0?ooooooooooooooool000001_ooool01?l0003oooooo`000?o^k^h3ooooo`;ok^k^C_ooool2onk^
kP?ooooo0_o^k^i/ooooo`00<?ooool00ol0003oooooooooo`18ooooo`0=odA4A?l0003o0000oc8b
<_oMgMgoooooonk^k_mEEEGok^k^ooooooo^k^koEEEEonk^kP03ooooo`Co000000So410@oooooooo
ooook^k^oc8b<_l0003o<S8bonk^kT;ooooo1?l000002Ol@413o0000onk^k_mEEEGok^k^ooooooo^
k^koEEEEonk^kP02ooooo`Ko00000_ooool01_o^k^ko<S8bo`000?lb<S;ok^k^o`0000Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Kooooo1Ol000000ol@413ooooo
ooooo`02ooooo`05o`000?lQ8B7oooooooooool000000_ooool03Om4A4Co0000o`000?lb<S;o0000
ooooool0003oEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?ooooooooooonk^
k_lb<S;o0000oc8b<_o^k^hhooooo`Go00000_ooool01oo^k^koEEEEonk^k_ooooook^k^oeEEEOo^
k^h00oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^iMooooo`00<?ooool0
0ol0003oooooooooo`1;ooooo`09ogMgMolb<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Ko
oooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg04?ooooo0_l00002oooo
o`07o`000?ooooook^k^oeEEEOoMgMgoEEEEonk^kP03ooooo`06o`000?ooooooooooo`000?oooooo
00000_ooool01_mgMgOoV9RHoooooonHV9SoMgMgo`0000Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool0
1Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_l00005ooooo`05o`000?lQ
8B7oooooooooool000001Oooool02OmgMgOo0000ooooool0003ok^k^oeEEEOoMgMgoEEEEonk^kP06
ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0hooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@00oooool01Oo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg05gooooo000`ooooo`03o`000?oooooooooo04co
oooo00Oo0000ooooooooooooooooomgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@04?ooooo0_l00002ooooo`06o`000?ooooooooooomgMgOl0003o
gMgM1?ooool01_l0003oooooooooool0003oooooo`0000;ooooo00Ko410@oooooooooooooooooa0@
4?l00004ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00;o00001Oooool01Ol0003ooooooooooooooooo000000Kooooo00Oo0000oooo
ool0003oooooomgMgOl0003ogMgM00Oooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@03Wooooo00?oV9RHob4Q8Oo^k^h01Oooool00ooMgMgo0000omgMg@07ooooo`03o`00
0?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@401Mooooo`00<?ooool00ol0003ooooo
ooooo`1;ooooo`09ogMgMolb<S;oooooooooooo^k^koEEEEomgMgOmEEEGok^k^00Kooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000003Kooooo0_l0000;ooooo`;o00000_oo
ool01ol0003oooooonk^k_mEEEGogMgMoeEEEOo^k^h00oooool01_l0003oooooooooool0003ooooo
o`0000;ooooo00Co0000oooooooooooooooo0_l00004ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;o00001Oooool01Ol0003ooooo
oooooooooooo000000Gooooo00WoMgMgo`000?oooooo0000onk^k_mEEEGogMgMoeEEEOo^k^h01_oo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000>_ooool00onHV9So8B4Q
onk^kP03ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h01_ooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool00000GOooool0033ooooo00?o0000ooooooooool0B?ooool03Ol0003o
8B4Qo`000?lb<S;oc<c<ooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h01Oooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool00000=Oooool00ol0003oooooo`00000;oooo
o`;o00000_ooool02?l0003ok^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^0_ooool01_l0003ooooo
ooooool0003oooooo`0000;ooooo00Co0000oooooooooooooooo0_l00004ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;o00001Ooo
ool01Ol0003ooooooooooooooooo000000;ooooo00ko0000ob4Q8Ol0003o<S8bo`000?oooooo0000
oeEEEOo^k^koooooonk^k_mEEEGok^k^ooooo`;o00000_ooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool00000>oooool02omgMgOoIVIVooooooooooook^k^oeEEEOo^k^kooooo
onk^k_mEEEGok^k^00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
05gooooo000`ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool00oooool2onk^kP?o
oooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400eoooo
o`04o`000?ooooooooooo`0000[ooooo0_l00002ooooo`03o`000?o^k^kok^k^00?ooooo0_o^k^h0
0ooooooo0000ooooo`02ooooo`03o`000?oooooo000000;ooooo00Ko410@oooooooooooooooooa0@
4?l00004ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;o00001Oooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo00000_ooool00ol0003ok^k^ooooo`02ooooo`;ok^k^00?oooooo`00
0?l000000_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100??ooool0
0ol0003oooooooooo`02onk^kP?ooooo0_o^k^h5ooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@401Mooooo`00<?ooool3o`0004Sooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool00ol0003ooooooooo
o`0Yooooo`05o`000?ooooooooooooooool000002_ooool2o`0000;ooooo00?o0000ooooooooool0
1_ooool01ol0003ooooooooooooooooo0000ooooool000000_ooool01_mgMgOoV9RHoooooonHV9So
MgMgo`0000Cooooo00?o0000ooooooooool00_l00002ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02o`0000Gooooo00Go0000oooooooooooooooo
o`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01Oooool2o`0000;o
oooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo0_l0000^oooo
o`05o`000?nj^[[ooooooiRHV?l@41003_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02?ooool2o`0005?ooooo000`ooooo`03o`000?oooooooooo04Sooooo1?l0000<
ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oo
oooooooo02Wooooo00Go0000ooooooooooooooooo`000009ooooo`03o`000?mVIVKo000000?ooooo
00?o0000ooooooooool01Oooool01ol0003ooooooeEEEOmVIVKo0000ooooool000000_ooool01_o^
k^ko<S8bo`000?lb<S;ok^k^o`0000Cooooo00?o0000ooooool000000_ooool00ol0003oooooo`00
0005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oeEEEOmVIVH00_l00005ooooo`05o`000?oo
ooooooooooooool000000_ooool4o`0000;ooooo00?o0000ooooooooool01?ooool01_l0003ooooo
o`000?mEEEGoIVIVo`0000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP07ooooo`04o`000?oooooo
ooooo`0002gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00<ooooo`03oeEEEOmVIVKo000000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP07ooooo`04o`000?ooooooooooo`0005;ooooo000`ooooo`03
o`000?oooooooooo06Kooooo1?l00003ooooo`03o`000?oooooooooo02Sooooo00Go0000oooooooo
ooooooooo`000009ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000000ol000001ooo
oooo0000oooooooooooo0000ooooool000001Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oo
ooooooooooooool000001Oooool01Ol0003ooooooooooooooooo000000Gooooo00Co0000oooooooo
oooo00001_ooool00ol0003oooooo`00000>ooooo`Co000000Goooooo`000?ooooooooooo`00001<
ooooo`Co000000Goooooo`000?ooooooooooo`00001Booooo`00<?ooool00ol0003oooooooooo`1]
ooooo`03o`000?oooooooooo02Sooooo00Go0000ooooooooooooooooo`000009ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooo`000002o`0000;ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool00000
1Oooool01Ol0003ooooooooooooooooo000000Gooooo00Co0000oooooooooooo00001_ooool01?l0
003oooooooooool00007ooooo`03o`000?oooooooooo00Sooooo0ol0001Booooo`?o0000Doooool0
033ooooo00?o0000ooooooooool0Joooool01?l0003oooooooooool0000Yooooo`05o`000?oooooo
ooooooooool000002Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
00Go0000ooooooooooooooooo`000005ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0
003ooooooooooooooooo000000Gooooo00Co0000oooooooooooo00001_ooool2o`0000_ooooo00?o
0000ooooooooool0D_ooool00ol0003oooooooooo`1Booooo`00<?ooool00ol0003oooooooooo`1[
ooooo`Co0000:?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooooooo
o`000005ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0003ooooooooooooooooo0000
00Gooooo00Co0000oooooooooooo00001_ooool2o`0000cooooo00?o0000ooooooooool0D_ooool0
0ol0003oooooooooo`1Aooooo`00<?ooool00ol0003oooooooooo`29ooooo`?o00002oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oo
ooooooooooooool000001Oooool01?l0003oooooooooool0002dooooo`00<?ooool00ol0003ooooo
ooooo`28ooooo`;o000000?oooooo`000?l000002_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oooooooooooooo
ool000001Oooool01?l0003oooooooooool00006ooooo`;o0000L_ooool00omgMgOoIVIVooooo`0]
ooooo`03ofIVI_mgMgOooooo00Oooooo000`ooooo`03o`000?oooooooooo08Sooooo00Go0000oooo
ooooooooooooo`00000:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000005ooooo`04o`00
0?ooooooooooo`0000Kooooo0ol0001`ooooo`03omgMgOl@413ok^k^02kooooo00?ok^k^oa0@4?oM
gMd01oooool0033ooooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Gooooo00Co0000oooo
oooooooo00001Oooool01?l0003oooooooooool00006ooooo`;o0000E_ooool2o`0000;ooooo0_l0
000<ooooo`03oeEEEOnHV9Sooooo00;o00000_ooool01ol0003oooooooooool0003o410@onk^k_mE
EED00_l000000om4A4Co^[Zjooooo`02ooooo`05oiRHV?l0003o0000odA4A?nj^[X00_ooool02?o^
k^koEEEEo`000?l0003oA4A4okZj^_oooooo410@1Ol00003ooooo`08oa0@4?lb<S;o0000o`000?l@
413oZJVYohN7QomVIVH7ooooo`00<?ooool00ol0003oooooooooo`1eooooo`Ko00002oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooo
oooo000000Gooooo00Co0000oooooooooooo00001Oooool01?l0003oooooooooool00005ooooo`Co
00001Oooool3o`0004gooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd<ooooo`05o`000?oooooo
ooooooooool000000_ooool02ol0003oooooooooool0003ooooooeEEEOmgMgOoooooonk^k_mgMgOo
410@00?ooooo00Go410@okZj^_o^k^koMgMgoa0@4002ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo
410@0oooool00ol0003oooooooooo`04ooooo`08o`000?nYZJWooooooooooonj^[[o0000onk^k_l0
0007ooooo`00ool0002do`0000oooooo00CogMgMo`000?l@413oc<c<3Oooool01Olb<S;ooooooooo
oooooooo000000;ooooo00Ko0000oooooooooooo0000ooooool00008ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`07okZj^_n7QhOoIVIV
ofIVI_l@413oooooo`000007ooooo`002_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo00gooooo1ol0000;ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001oooool00ol0003ooooo
ooooo`04ooooo`;o00001_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooool000001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooool000001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
0_l00005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooooooool2o`0000Gooooo00Go0000ooooooooooooooooo`000004ooooo`06o`000?oooooooooo
o`000?oooooo00000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00_l00004ooooo`05o`000?ooooooooooooooool000001?ooool2o`000003oooo
ool0003o000000Cooooo1?l00004ooooo`Co000000?oooooo`000?ooool04Oooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo01Oooooo00Cok^k^ob4Q8Ol@413ok^k^3Oooool01Olb<S;o
oooooooooooooooo000000;ooooo00Go0000oooooooooooo0000ooooo`06o`0000?ooooo00?o0000
ooooooooool01?ooool6o`0000?ooooo00?o0000ooooooooool01?ooool02?lb<S;o8B4QogMgMomg
MgOoQhN7onk^k_oooooo00001oooool000[ooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo00gooooo0_l000000ooooooo0000ooooo`02o`0000Wooooo
00?o0000ooooooooool00_ooool00ol0003oooooo`000008ooooo`03o`000?oooooooooo00Cooooo
0_l00006ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
o`000005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
o`000005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool2o`0000Gooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooooooo`;o
00001Oooool01Ol0003ooooooooooooooooo000000Gooooo00Go0000ooooool0003oooooo`000004
ooooo`05o`000?ooooooooooooooool000001Oooool01?l0003oooooo`000?l00005ooooo`04o`00
0?ooooooooooo`0000Gooooo1?l0000Aooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0Gooooo`04ob4Q8OmgMgOoMgMgoc8b<Pgooooo00Go0000onk^
k_ooooooooooo`000002olc<c00;o`000?nYZJWogMgMob4Q8OooooooEEEEohN7Qoo^k^koooooohN7
Qolb<S800oooool00ol0003oooooooooo`04ooooo`06oeEEEOn7QhOok^k^oooooon7QhOo<S8b0ooo
ool00ol0003o<S8bomgMg@04ooooo`08o`000?nj^[[oooooonk^k_mgMgOo0000onk^k_l00007oooo
o`00<?ooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo02;ooooo1?l0000:ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooo000000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05
o`000?ooooooooooooooool000001Oooool01Ol0003ooooooooooooooooo000000Gooooo00Go0000
ooooool0003oooooo`000004ooooo`05o`000?ooooooooooooooool000001Oooool01?l0003ooooo
ooooool00005ooooo`?o0000@Oooool00ol0003oooooooooo`0Fooooo`;o00000_ooool2o`0000co
oooo00koEEEEogMgMooooooo410@o`000?lQ8B7o0000ogMgMol@413o0000ojVYZOooooook^k^oeEE
E@;o000000CoA4A4onk^k_oooooo410@1Ol00003ooooo`06onk^k_mEEEGo0000o`000?m4A4Cok^k^
0_ooool2o`000004ojVYZOlQ8B7o0000ob4Q8@;ooooo00SoZJVYob4Q8Ol0003o0000oc8b<_l0003o
MgMgoeEEE@Oooooo000`ooooo`03o`000?oooooooooo08oooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00
0005ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0003ooooooooooooooooo000000Co
oooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooo000007Gooooo00?ogMgMoa0@
4?o^k^h04_ooool00ol0003oooooooooo`0Iooooo`03onk^k_l@413ogMgM00Oooooo000`ooooo`03
o`000?oooooooooo08oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000005ooooo`05o`000?oooooooooo
ooooool000001Oooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooooooooooo
o`000005ooooo`03o`000?oooooo000007Kooooo00?oMgMgofIVI_ooool04Oooool00ol0003ooooo
ooooo`0Iooooo`03ofIVI_mgMgOooooo00Oooooo000`ooooo`03o`000?oooooooooo093ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go
0000ooooooooooooooooo`000005ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0003o
oooooooooooooooo000000Gooooo00Co0000oooooooooooo00001_ooool2o`000;3ooooo000`oooo
o`03o`000?oooooooooo093ooooo00Go0000ooooooooooooooooo`00000:ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00Go0000ooooooooooooooooo`000005ooooo`05o`000?ooooooooooooooool00000
1Oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooool00000^Oooool0033ooooo
00?o0000ooooooooool0TOooool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00Go0000ooooooooooooooooo`000005ooooo`05o`000?ooooooooooooooool000001Oooool0
1?l0003oooooooooool00006ooooo`03o`000?oooooo00000;Wooooo000`ooooo`03o`000?oooooo
oooo097ooooo0ol0000;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00
0005ooooo`05o`000?ooooooooooooooool000001Oooool01?l0003oooooooooool00006ooooo`03
o`000?oooooo00000;Wooooo000`ooooo`03o`000?oooooooooo09oooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool01Ol0003ooooooooooooooooo000000Gooooo00Go0000ooooooooooooooooo`000005oooo
o`04o`000?ooooooooooo`0000Kooooo0ol0002iooooo`00<?ooool00ol0003oooooooooo`2Ooooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000005ooooo`04o`000?oooooo
ooooo`0000Kooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`2hooooo`00<?oo
ool3o`0009oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Gooooo
00Co0000oooooooooooo00001_ooool01?l0003oooooooooool00032ooooo`00<?ooool00ol0003o
ooooooooo`2Pooooo`05o`000?ooooooooooooooool000002Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000005ooooo`04o`000?oooooo
ooooo`0000Oooooo00?o0000ooooool00000`_ooool0033ooooo00?o0000ooooooooool0X?ooool0
1Ol0003ooooooooooooooooo000000Wooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooo`000007ooooo`03o`000?oooooo00000<;o
oooo000`ooooo`03o`000?oooooooooo0:3ooooo00Go0000ooooooooooooooooo`000009ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`05
o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000
ooooool000001oooool2o`000<?ooooo000`ooooo`03o`000?oooooooooo0:3ooooo00Co0000oooo
oooooooo00002_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0003ooooo
oooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo0000
00Oooooo0_l00033ooooo`00<?ooool00ol0003oooooooooo`2Pooooo`04o`000?ooooooooooo`00
00[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Gooooo00Go0000oooooooooooooooo
o`000006ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooo`000007ooooo`;o
0000`oooool0033ooooo00?o0000ooooooooool0X?ooool01?l0003oooooooooool0000:ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`05
o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00Go0000ooooooooooooooooo`000005ooooo`05o`000?ooooooooooooooool000001_oo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooool000001oooool2o`000<?ooooo
000`ooooo`03o`000?oooooooooo0:3ooooo00Co0000oooooooooooo00002_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05
o`000?ooooooooooooooool000001Oooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooo00000<cooooo000`ooooo`03o`000?oooooo
oooo0:7ooooo00?o0000ooooool000002_ooool01Ol0003ooooooooooooooooo000000Wooooo00Go
0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0003ooooooooooooooooo
000000Kooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo00000<cooooo000`
ooooo`03o`000?oooooooooo0:7ooooo0ol0000:ooooo`05o`000?ooooooooooooooool000002Ooo
ool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`05ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?oooooooooo
o`0000Kooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo00000<cooooo000`
ooooo`03o`000?oooooooooo0:;ooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooooooo
oooo000000Wooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01?l0
003oooooooooool00006ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooo`00
003<ooooo`00<?ooool00ol0003oooooooooo`2^ooooo`05o`000?ooooooooooooooool000002Ooo
ool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`05ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?oooooooooo
o`0000Kooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo00000<cooooo000`
ooooo`?o0000[_ooool01Ol0003ooooooooooooooooo000000Wooooo00Go0000oooooooooooooooo
o`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05
o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool00006ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooo`00003<ooooo`00<?ooool00ol0003oooooooooo`2^
ooooo`05o`000?ooooooooooooooool000002Oooool01Ol0003ooooooooooooooooo000000Oooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool0
00001oooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000006
ooooo`04o`000?ooooooooooo`0000Kooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooo00000<cooooo000`ooooo`03o`000?oooooooooo0:kooooo00Go0000oooooooooooooooo
o`000009ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooooooo
ooooool000001_ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo0000
1_ooool01?l0003oooooooooool00007ooooo`;o0000cOooool0033ooooo00?o0000ooooooooool0
[oooool01?l0003oooooooooool00009ooooo`05o`000?ooooooooooooooool000001oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000007
ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Kooooo
00Co0000oooooooooooo00001_ooool01?l0003oooooooooool00007ooooo`;o0000cOooool0033o
oooo00?o0000ooooooooool0[oooool01?l0003oooooooooool00009ooooo`05o`000?oooooooooo
ooooool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00Go0000
ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooo
oooooooooooo000000Kooooo00Co0000oooooooooooo00001_ooool01?l0003oooooooooool00008
ooooo`03o`000?oooooooooo0<_ooooo000`ooooo`03o`000?oooooooooo0:oooooo00Co0000oooo
oooooooo00002Oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooo
oooooooooooo000000Kooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?oooooooooo
o`0000Kooooo00Co0000oooooooooooo0000e_ooool0033ooooo00?o0000ooooooooool0[oooool0
1?l0003oooooooooool00009ooooo`05o`000?ooooooooooooooool000001oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000007ooooo`05
o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000
oooooooooooo00001_ooool01?l0003oooooooooool0003Fooooo`00<?ooool00ol0003ooooooooo
o`2_ooooo`04o`000?ooooooooooo`0000Wooooo00Go0000ooooooooooooooooo`000007ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo0000
00Oooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?ooooooooooooooool000001_oo
ool01?l0003oooooooooool00007ooooo`03o`000?oooooo00000=Kooooo000`ooooo`03o`000?oo
oooooooo0:oooooo00Co0000oooooooooooo00002Oooool01Ol0003ooooooooooooooooo000000Oo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`05o`000?oooooooooooooo
ool000001oooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000ooooooooooooooooo`00
0006ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool00000e_ooool0033ooooo00?o
0000ooooooooool0[oooool01?l0003oooooooooool00009ooooo`05o`000?ooooooooooooooool0
00001oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00Go0000oooooooo
ooooooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooo
oooo000000Kooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00003Fooooo`00<?oo
ool00ol0003oooooooooo`2_ooooo`04o`000?ooooooooooo`0000Wooooo00Go0000oooooooooooo
ooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool01Ol0003o
oooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?oooooo
ooooo`0000Oooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00003Fooooo`00<?oo
ool00ol0003oooooooooo`2_ooooo`03o`000?oooooo000000[ooooo00Go0000oooooooooooooooo
o`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool01Ol0003ooooo
oooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?oooooooooo
o`0000Oooooo00Co0000oooooooooooo00001oooool00ol0003oooooo`00003Fooooo`00<?ooool3
o`000:oooooo00?o0000ooooool000002_ooool01Ol0003ooooooooooooooooo000000Oooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool00000
1oooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo00001oooool01?l0
003oooooooooool00007ooooo`03o`000?oooooo00000=Kooooo000`ooooo`03o`000?oooooooooo
0;3ooooo0_l0000:ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooo
oooooooo000000Kooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool00007oooo
o`03o`000?oooooo00000=Kooooo000`ooooo`03o`000?oooooooooo0;3ooooo0_l0000:ooooo`04
o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05oooo
o`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Kooooo00Co
0000oooooooooooo00001oooool01?l0003oooooooooool00007ooooo`;o0000eoooool0033ooooo
00?o0000ooooooooool0/?ooool2o`0000[ooooo00Co0000oooooooooooo00002?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000007oooo
o`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool00007ooooo`04o`000?oo
ooooooooo`0000Oooooo0_l0003Gooooo`00<?ooool00ol0003oooooooooo`2`ooooo`;o00002_oo
ool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1Oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000006oooo
o`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00001oooool2o`000=Oooooo000`
ooooo`03o`000?oooooooooo0;cooooo00Co0000oooooooooooo00002?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000007ooooo`04o`00
0?ooooooooooo`0000Oooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool00008
ooooo`03o`000?oooooooooo0=Gooooo000?ooooo`;ok^k^0oooool2onk^kQ[ooooo00?o0000oooo
ooooool0_?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01Oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000
1oooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`000>3ooooo0008ooooo`Go
00000_ooool01oo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h00oooool4o`000008oa0@4?oooooo
ooooonk^k_lb<S;o0000oc8b<_o^k^h;ooooo`03o`000?oooooooooo0;gooooo00?o0000ooooool0
00002?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00Go0000oooooooo
ooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo00001ooo
ool01?l0003oooooooooool0003Pooooo`002?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo
00Gok^k^oeEEEOoMgMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`03o`000?oooooooooo0;gooooo00?o0000ooooool000002Oooool01Ol0
003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?oo
ooooooooo`0000Oooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool0003Poooo
o`002Oooool00onHV9So8B4Qonk^kP05ooooo`03omgMgOl0003ogMgM00Oooooo00?o0000oooooooo
ool00_ooool01Ol@413ooooooooooooooooo410@00_ooooo00?o0000ooooooooool0_Oooool00ol0
003oooooo`000009ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooo
oooo000000Oooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool00007ooooo`04
o`000?ooooooooooo`000>3ooooo000:ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Gok^k^oeEEEOoM
gMgoEEEEonk^kP06ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000;
ooooo`03o`000?oooooooooo0;gooooo00?o0000ooooool000002Oooool01Ol0003ooooooooooooo
oooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Oo
oooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool0003Pooooo`002oooool02omg
MgOoIVIVooooooooooook^k^oeEEEOo^k^koooooonk^k_mEEEGok^k^00Gooooo00?o0000oooooooo
ool00_ooool01Ol0003ooooooooooooooooo000000_ooooo1?l0002looooo`03o`000?oooooo0000
00Wooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001ooo
ool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooool0
0000hOooool000cooooo00?o0000ooooooooool00_o^k^h3ooooo`;ok^k^1Oooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41002oooool00ol0003oooooooooo`2mooooo`03
o`000?oooooo000000Wooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo
000000Oooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool00008ooooo`;o0000
hOooool000Sooooo00Go0000okZj^_ooooooV9RHoa0@400>ooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03o`000?oooooooooo0;gooooo00?o0000ooooool0
00002Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000
oooooooooooo00001oooool01?l0003oooooooooool00008ooooo`;o0000hOooool000Sooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c00<ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP03ooooo`;o00001_ooool00ol0003oooooooooo`2mooooo`03o`000?oooooo000000Wo
oooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00008ooooo`04o`000?oooooo
ooooo`0000Oooooo00Co0000oooooooooooo00002?ooool2o`000>7ooooo000Wooooo`04o`000?oo
ooooooooo`0000Gooooo00?o0000ooooooooool0_Oooool00ol0003oooooo`000009ooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00007
ooooo`04o`000?ooooooooooo`0000Sooooo0_l0003Qooooo`009oooool01?l0003oooooooooool0
0005ooooo`03o`000?oooooooooo0;gooooo00?o0000ooooool000002Oooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001oooool01?l0
003oooooooooool00008ooooo`;o0000hOooool002Oooooo0ol00006ooooo`03o`000?oooooooooo
0;gooooo00?o0000ooooool000002Oooool01?l0003oooooooooool00009ooooo`03o`000?oooooo
000000Sooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool00008ooooo`;o0000
hOooool002Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2mooooo`03o`000?oo
oooo000000Wooooo00Co0000oooooooooooo00002Oooool00ol0003oooooo`000008ooooo`04o`00
0?ooooooooooo`0000Oooooo00Co0000oooooooooooo00002?ooool2o`000>7ooooo000Yooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0_Oooool00ol0003oooooo`000009ooooo`04
o`000?ooooooooooo`0000Wooooo00?o0000ooooool000002?ooool01?l0003oooooooooool00008
ooooo`03o`000?oooooo000000Sooooo0_l0003Qooooo`00<?ooool00ol0003oooooooooo`2moooo
o`03o`000?oooooo000000Wooooo00Co0000oooooooooooo00002Oooool00ol0003oooooo`000008
ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool000002?ooool2o`000>7ooooo000`
ooooo`03o`000?oooooooooo0;gooooo00?o0000ooooool000002Oooool01?l0003oooooooooool0
0009ooooo`03o`000?oooooo000000Sooooo00Co0000oooooooooooo00002?ooool00ol0003ooooo
o`00003[ooooo`00<?ooool00ol0003oooooooooo`2mooooo`;o00002_ooool01?l0003ooooooooo
ool00009ooooo`03o`000?oooooo000000Sooooo00Co0000oooooooooooo00002?ooool00ol0003o
ooooo`00003[ooooo`00<?ooool3o`000;kooooo00?o0000ooooooooool02?ooool01?l0003ooooo
ooooool00009ooooo`03o`000?oooooo000000Sooooo00Co0000oooooooooooo00002?ooool00ol0
003oooooo`00003[ooooo`00<?ooool00ol0003oooooooooo`2nooooo`03o`000?oooooooooo00So
oooo00Co0000oooooooooooo00002Oooool00ol0003oooooo`000008ooooo`04o`000?oooooooooo
o`0000Sooooo00?o0000ooooool00000joooool0033ooooo00?o0000ooooooooool0bOooool01?l0
003oooooooooool00009ooooo`03o`000?oooooo000000Sooooo00Co0000oooooooooooo00002?oo
ool00ol0003oooooo`00003[ooooo`00<?ooool00ol0003oooooooooo`39ooooo`04o`000?oooooo
ooooo`0000Wooooo00?o0000ooooool000002?ooool01?l0003oooooooooool00008ooooo`03o`00
0?oooooo00000>_ooooo000`ooooo`03o`000?oooooooooo0<Wooooo00Co0000oooooooooooo0000
2Oooool00ol0003oooooo`000008ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool0
0000joooool0033ooooo00?o0000ooooooooool0bOooool01?l0003oooooooooool00009ooooo`03
o`000?oooooo000000Sooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00003[oooo
o`00<?ooool00ol0003oooooooooo`3:ooooo`03o`000?oooooo000000Wooooo00?o0000ooooool0
00002?ooool01?l0003oooooooooool00008ooooo`;o0000k?ooool0033ooooo00?o0000oooooooo
ool0b_ooool00ol0003oooooo`000009ooooo`03o`000?oooooo000000Sooooo00Co0000oooooooo
oooo00002?ooool2o`000>cooooo000`ooooo`03o`000?oooooooooo0<[ooooo00?o0000ooooool0
00002Oooool00ol0003oooooo`000009ooooo`03o`000?oooooo000000Sooooo0_l0003/ooooo`00
<?ooool00ol0003oooooooooo`3:ooooo`03o`000?oooooo000000Wooooo00?o0000ooooool00000
2Oooool2o`0000Wooooo0_l0003/ooooo`00<?ooool00ol0003oooooooooo`3:ooooo`03o`000?oo
oooo000000Wooooo00?o0000ooooool000002Oooool2o`0000Wooooo0_l0003/ooooo`00<?ooool0
0ol0003oooooooooo`3:ooooo`03o`000?oooooo000000Wooooo00?o0000ooooool000002Oooool2
o`0000Wooooo0_l0003/ooooo`00<?ooool3o`000<[ooooo0_l0000:ooooo`03o`000?oooooo0000
00Wooooo0_l0000:ooooo`03o`000?oooooooooo0>[ooooo000`ooooo`03o`000?oooooooooo0<[o
oooo0_l0000:ooooo`03o`000?oooooo000000Wooooo0_l0003gooooo`00<?ooool00ol0003ooooo
ooooo`3:ooooo`;o00002_ooool00ol0003oooooo`000009ooooo`;o0000moooool0033ooooo00?o
0000ooooooooool0b_ooool2o`0000[ooooo00?o0000ooooool000002Oooool2o`000?Oooooo000`
ooooo`03o`000?oooooooooo0<[ooooo0_l0000:ooooo`03o`000?oooooo000000Wooooo0_l0003g
ooooo`00<?ooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ool000002Oooool2o`000?Oooooo000`ooooo`03o`000?oooooooooo0=Kooooo00?o0000ooooool0
00002Oooool2o`000?Oooooo000`ooooo`03o`000?oooooooooo0=Kooooo00?o0000ooooool00000
2Oooool2o`000?Oooooo000`ooooo`03o`000?oooooooooo0=Kooooo00?o0000ooooool000002Ooo
ool2o`000?Oooooo000`ooooo`03o`000?oooooooooo0=Kooooo00?o0000ooooool000002Oooool2
o`000?Oooooo000`ooooo`03o`000?oooooooooo0=Kooooo0_l0000:ooooo`;o0000moooool0033o
oooo00?o0000ooooooooool0eoooool00ol0003oooooooooo`3oooooo`;ooooo000`ooooo`?o0000
eoooool00ol0003oooooooooo`3oooooo`;ooooo000`ooooo`03o`000?oooooooooo0?oooooog?oo
ool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3ooooo
omcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0
oooooooLooooo`003oooool2onk^kP?ooooo0_o^k^hJooooo`03o`000?oooooooooo0?oooooog?oo
ool000[ooooo0_l000002_l@413oooooooooooo^k^koEEEEonk^k_ooooook^k^oeEEEOo^k^h3oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kP_ooooo00?o0000ooooooooool0
oooooooLooooo`002oooool00ol0003oooooooooo`02ooooo`05onk^k_mEEEGogMgMoeEEEOo^k^h0
1_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ol0003o
ooooooooo`3oooooomcooooo0008ooooo`Go00001?ooool00ooMgMgo0000omgMg@07ooooo`03o`00
0?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400;ooooo`03o`000?oooooooooo0?oo
oooog?ooool000Sooooo00CoA4A4omgMgOoooooo00001?ooool01Oo^k^koEEEEomgMgOmEEEGok^k^
00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000_ooooo00?o0000
ooooooooool0oooooooLooooo`002?ooool01?oMgMgoEEEEooooool00003ooooo`07onk^k_mEEEGo
k^k^ooooooo^k^koEEEEonk^kP05ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`00000;ooooo`Co0000oooooooKooooo`002Oooool00omgMgOoc<c<o`000003ooooo`;ok^k^
0oooool2onk^kPGooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00_o
oooo00?o0000ooooooooool0oooooooLooooo`002Oooool00oo^k^koA4A4o`00000?ooooo`03o`00
0?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03o`000?oooooooooo0?oo
oooog?ooool000[ooooo00?oMgMgo`000?ooool03?ooool00omEEEGoIVIVo`000004ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h00oooool2o`0000Kooooo00?o0000ooooooooool0oooooooLooooo`00
9oooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo0?oooooog?ooool002Oooooo
00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`3oooooomcooooo000Wooooo`?o0000
1_ooool00ol0003oooooooooo`3oooooomcooooo000Xooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0oooooooLooooo`00:Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003o
ooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo0ol0
003oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooo
ooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`00
0?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool0
0ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033o
oooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo
000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooL
ooooo`00<?ooool3o`000?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00
<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?oo
ool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3ooooo
omcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0
oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo000`ooooo`03o`000?oooooo
oooo0?oooooog?ooool0033ooooo00?o0000ooooooooool0oooooooLooooo`00<?ooool00ol0003o
ooooooooo`3oooooomcooooo000`ooooo`?o0000oooooooLooooo`00<?ooool00ol0003ooooooooo
o`3oooooomcooooo000`ooooo`03o`000?oooooooooo0?oooooog?ooool0033ooooo00?o0000oooo
ooooool0oooooooLooooo`00<?ooool00ol0003oooooooooo`3oooooomcooooo003ooooooooooooo
4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oo
ooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@
ooooo`00W?ooool2o`0000Cooooo00?o^[Zjoc8b<_ooool01?ooool2o`0000Kooooo00?o0000okZj
^_ooool0oooooomKooooo`00W?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01?ooool2oc8b<_ooooooG?ooool008Wooooo0ol00002ooooo`06oc8b
<_l@413oooooooooooo^k^koEEEE0_l000000om4A4Co^[Zjooooo`03ooooo`03o`000?oooooooooo
00;ooooo00GoV9RHoa0@4?l0003o0000ojVYZ@04ooooo`03o`000?oooooooooo00Cooooo00?oQhN7
o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj00[ooooo1?l000002?l@413ooooooooo
ooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Cooooo1Ol000001_ooooooc<c<onk^k_oooooo
k^k^olc<c0?ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^4oooool01_l@
413o<S8bo`000?l0003o410@ojVYZ@;ooooo00Kok^k^oeEEEOl0003o0000odA4A?nj^[X3ooooo`05
ofIVI_l0003o0000odA4A?o<c<`0iOooool008[ooooo00Go0000ooooooooooooc<c<oa0@4003oooo
o`06oeEEEOmgMgOoooooonk^k_mgMgOo410@1?ooool00ol0003oooooooooo`02ooooo`06o`000?nY
ZJWoEEEEoiRHV?mEEEGo^[Zj0oooool00ol0003oooooooooo`04ooooo`03olc<c?l0003o410@00co
oooo00Ko410@okZj^_o^k^koMgMgoa0@4?ooool6o`0000Gooooo00?o0000ooooooooool00_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`0;oiRHV?lQ8B7ok^k^oooooom4A4Co
ooooonk^k_mEEEGogMgMoeEEEOo^k^h01Oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL04oooool01_l0003oZJVYoooooooooooo^[Zjo`0000;ooooo00KoEEEEogMgMooo
ooook^k^ogMgMol@4102ooooo`06ofIVI_mgMgOooooooooooon7QhOo410@iOooool008[ooooo00Go
0000ooooooooooooEEEEohN7Q`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
0_ooool01_lb<S;ok^k^oiRHV?mEEEGogMgMoa0@40?ooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00?ogMgMo`000?oMgMd01_ooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@41005?ooool01Onj^[[oQhN7ofIVI_mVIVKo410@00;ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3Xooooo`00R_ooool01Ol0003oooooomgM
gOl0003ok^k^00?ooooo1_l00004ooooo`03o`000?oooooooooo00;ooooo00Oo^[ZjodA4A?o<c<co
8B4Qooooool@413oc<c<00;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`03oooo
o`Ko00001Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000003Oooool0
2OnHV9So8B4Qonk^k_ooooook^k^oeEEEOoMgMgoEEEEonk^kP05ooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`00000Cooooo`06oc8b<_lQ8B7oMgMgogMgMon7QhOok^k^0_oo
ool6o`0000;ooooo00?o0000ooooooooool0j?ooool008[ooooo0ol000000ol@413oV9RHooooo`02
ooooo`06oeEEEOn7QhOok^k^oooooon7QhOo<S8b1?ooool00ol0003oooooooooo`02ooooo`07onk^
k_l0003oooooo`000?ooooooIVIVohN7Q`02ooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000003_ooool0
2?mgMgOoIVIVooooooo<c<cok^k^ooooooo^k^koc<c<1Oooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000004oooool01_l0003o^[Zjooooooo^k^koMgMgo`0000;ooooo00Ko
EEEEohN7Qoo^k^koooooohN7Qolb<S82ooooo`06ofIVI_mgMgOooooooooooon7QhOo0000iOooool0
08[ooooo00Go0000ooooooooooooc<c<o`000003ooooo`06onk^k_mEEEGo0000o`000?m4A4Cok^k^
1?ooool00ol0003oooooooooo`02ooooo`04ofIVI_nHV9Sooooooc8b<P;o^[Zj00Co0000oooooooo
oooo00004oooool00ol@413o0000o`000003o`0000gooooo00?o0000ooooooooool00_ooool01Ol@
413ooooooooooooooooo410@00oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@41002?ooool3o`0000;ooooo0ol00003ooooo`06ojVYZOlQ
8B7o0000o`000?lb<S;o00000_ooool01_o^k^koEEEEo`000?l0003oA4A4onk^kP;ooooo00Kok^k^
ofIVI_l0003o0000odA4A?l0003Uooooo`00R_ooool01Ol0003oooooooooooo<c<co000000gooooo
00?o0000ooooooooool01Oooool00omVIVKoQhN7ooooo`03ooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool01Ol0003o^[ZjoooooonHV9So410@00_ooooo00?o0000ooooooooool00_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3m
ooooo`00ROooool4o`000003oa0@4?nYZJWooooo00cooooo0_l00006ooooo`03ojVYZOm4A4Cooooo
00;ooooo0_l0000Eooooo`03o`000?oooooooooo00cooooo00?oEEEEofIVI_l000001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c009ooooo`03oeEEEOmV
IVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP02ooooo`Co00000oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo0?gooooo003oooooo`[ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`3mooooo`00ooooool:ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0oOooool00?oooooo2Oooool2o`0000?ooooo0_l0003oooooo`00oooooooooooooa3o
oooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooo
oooooooo4?ooool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?oo
ool00?ooooooooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?oooooo
ooooool@ooooo`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@oooo
o`00oooooooooooooa3ooooo003ooooooooooooo4?ooool00?ooooooooooool@ooooo`00oooooooo
oooooa3ooooo003ooooooooooooo4?ooool00001\
\>"],
  ImageRangeCache->{{{0, 525.688}, {324.5, 0}} -> {-2.58312*^-7, -6.34248*^6, \
6.65005*^-9, 53093.5}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0.309017 5.42214e-08 [
[.32684 .29652 -16.5 -12.5 ]
[.32684 .29652 16.5 0 ]
[.54329 .29652 -16.5 -12.5 ]
[.54329 .29652 16.5 0 ]
[.75974 .29652 -22.5 -12.5 ]
[.75974 .29652 22.5 0 ]
[.97619 .29652 -16.5 -12.5 ]
[.97619 .29652 16.5 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 64 6 ]
[.09789 .09213 -34.5 -6.25 ]
[.09789 .09213 0 6.25 ]
[.09789 .20057 -34.5 -6.25 ]
[.09789 .20057 0 6.25 ]
[.09789 .41746 -28.5 -6.25 ]
[.09789 .41746 0 6.25 ]
[.09789 .5259 -28.5 -6.25 ]
[.09789 .5259 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -65.8125 0 ]
[.5 .63053 65.8125 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 .30902 m
.32684 .31527 L
s
gsave
.32684 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 .30902 m
.54329 .31527 L
s
gsave
.54329 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 .30902 m
.75974 .31527 L
s
gsave
.75974 .29652 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 .30902 m
.15368 .31277 L
s
.19697 .30902 m
.19697 .31277 L
s
.24026 .30902 m
.24026 .31277 L
s
.28355 .30902 m
.28355 .31277 L
s
.37013 .30902 m
.37013 .31277 L
s
.41342 .30902 m
.41342 .31277 L
s
.45671 .30902 m
.45671 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.58658 .30902 m
.58658 .31277 L
s
.62987 .30902 m
.62987 .31277 L
s
.67316 .30902 m
.67316 .31277 L
s
.71645 .30902 m
.71645 .31277 L
s
.80303 .30902 m
.80303 .31277 L
s
.84632 .30902 m
.84632 .31277 L
s
.88961 .30902 m
.88961 .31277 L
s
.9329 .30902 m
.9329 .31277 L
s
.0671 .30902 m
.0671 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09213 m
.11664 .09213 L
s
gsave
.09789 .09213 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .20057 m
.11664 .20057 L
s
gsave
.09789 .20057 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .41746 m
.11664 .41746 L
s
gsave
.09789 .41746 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .5259 m
.11664 .5259 L
s
gsave
.09789 .5259 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.11039 .11924 m
.11414 .11924 L
s
.11039 .14635 m
.11414 .14635 L
s
.11039 .17346 m
.11414 .17346 L
s
.11039 .22768 m
.11414 .22768 L
s
.11039 .2548 m
.11414 .2548 L
s
.11039 .28191 m
.11414 .28191 L
s
.11039 .33613 m
.11414 .33613 L
s
.11039 .36324 m
.11414 .36324 L
s
.11039 .39035 m
.11414 .39035 L
s
.11039 .44457 m
.11414 .44457 L
s
.11039 .47168 m
.11414 .47168 L
s
.11039 .49879 m
.11414 .49879 L
s
.11039 .06502 m
.11414 .06502 L
s
.11039 .03791 m
.11414 .03791 L
s
.11039 .0108 m
.11414 .0108 L
s
.11039 .55301 m
.11414 .55301 L
s
.11039 .58012 m
.11414 .58012 L
s
.11039 .60723 m
.11414 .60723 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -126.812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.812 moveto
(@) show
81.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.812 moveto
(D) show
93.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10.4) show
141.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
147.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
159.000 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
163.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
172.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
190.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02691 .30902 L
.03029 .30902 L
.03347 .30902 L
.03652 .30902 L
.03978 .30902 L
.04291 .30902 L
.04462 .30902 L
.04623 .30902 L
.04932 .30902 L
.0526 .30902 L
.05575 .30902 L
.05879 .30902 L
.06202 .30902 L
.06514 .30902 L
.06845 .30902 L
.07163 .30902 L
.0747 .30902 L
.07796 .30902 L
.0811 .30902 L
.08444 .30902 L
.08766 .30902 L
.09075 .30902 L
.09404 .30902 L
.09721 .30902 L
.10026 .30902 L
.1035 .30902 L
.10663 .30902 L
.10995 .30902 L
.11315 .30902 L
.11622 .30902 L
.1195 .30902 L
.12265 .30902 L
.12568 .30902 L
.12736 .30902 L
.1289 .30902 L
.12969 .30902 L
.13042 .30902 L
.13082 .30902 L
.13118 .30902 L
.13158 .30902 L
.1318 .30902 L
.1319 .30902 L
.13201 .30902 L
.13211 .30902 L
.1322 .30902 L
.13229 .30902 L
.13238 .30902 L
.13248 .30902 L
.13258 .30902 L
Mistroke
.13268 .30902 L
.13274 .30902 L
.13279 .30902 L
.1329 .30902 L
.13299 .30902 L
.13322 .30902 L
.13341 .30902 L
.13362 .30902 L
.13398 .30902 L
.13432 .30902 L
.1351 .30902 L
.1355 .30902 L
.13594 .30902 L
.13673 .30902 L
.13751 .30902 L
.13822 .30902 L
.13973 .30902 L
.14138 .30902 L
.14294 .30902 L
.14461 .30902 L
.14622 .30902 L
.14792 .30902 L
.15098 .30902 L
.15256 .30902 L
.15424 .30902 L
.15758 .30902 L
.16079 .30902 L
.16388 .30902 L
.16717 .30902 L
.17034 .30902 L
.17338 .30902 L
.17662 .30902 L
.17975 .30902 L
.18133 .30902 L
.18306 .30902 L
.18387 .30902 L
.18472 .30902 L
.18552 .30902 L
.18626 .30902 L
.18662 .30902 L
.18701 .30902 L
.1872 .30902 L
.1874 .30902 L
.18751 .30902 L
.18761 .30902 L
.18771 .30902 L
.18782 .30902 L
.18791 .30902 L
.18801 .30902 L
.1881 .30902 L
Mistroke
.18818 .30902 L
.18828 .30902 L
.18837 .30902 L
.18847 .30902 L
.18857 .30902 L
.18875 .30902 L
.18891 .30902 L
.18929 .30902 L
.1895 .30902 L
.18969 .30902 L
.19013 .30902 L
.19093 .30902 L
.19166 .30902 L
.19243 .30902 L
.19319 .30902 L
.19401 .30902 L
.19548 .30902 L
.19718 .30902 L
.1988 .30902 L
.20188 .30902 L
.20347 .30902 L
.20515 .30902 L
.20818 .30902 L
.21141 .30902 L
.21452 .30902 L
.21782 .30902 L
.22101 .30902 L
.22407 .30902 L
.22577 .30902 L
.22732 .30902 L
.2281 .30902 L
.22851 .30902 L
.22894 .30902 L
.22931 .30902 L
.22953 .30902 L
.22963 .30902 L
.22973 .30902 L
.22982 .30902 L
.22991 .30902 L
.23 .30902 L
.23008 .30902 L
.23018 .30902 L
.23026 .30902 L
.23036 .30902 L
.23046 .30902 L
.23055 .30902 L
.23065 .30902 L
.23083 .30902 L
.23105 .30902 L
.23125 .30902 L
Mistroke
.23167 .30902 L
.23208 .30902 L
.23279 .30902 L
.23356 .30902 L
.23432 .30902 L
.23515 .30902 L
.23684 .30902 L
.2384 .30902 L
.24007 .30902 L
.24338 .30902 L
.24657 .30902 L
.24963 .30902 L
.25289 .30902 L
.25603 .30902 L
.25937 .30902 L
.26104 .30902 L
.26178 .30902 L
.26258 .30902 L
.26331 .30902 L
.26371 .30902 L
.26409 .30902 L
.26429 .30902 L
.26452 .30902 L
.2647 .30902 L
.26491 .30902 L
.2651 .30902 L
.26521 .30902 L
.26531 .30902 L
.2654 .30902 L
.26549 .30902 L
.26558 .30902 L
.26568 .30902 L
.26578 .30902 L
.26583 .30902 L
.26588 .30902 L
.26598 .30902 L
.26608 .30902 L
.26626 .30902 L
.26644 .30902 L
.26687 .30902 L
.26726 .30902 L
.26797 .30902 L
.26873 .30902 L
.26955 .30902 L
.27043 .30902 L
.27205 .30902 L
.27363 .30902 L
.27531 .30902 L
.27865 .30901 L
.28187 .30901 L
Mistroke
.28497 .309 L
.28826 .309 L
.28991 .30899 L
.29144 .30899 L
.29301 .30899 L
.29378 .30899 L
.29449 .30899 L
.29486 .30899 L
.29527 .30899 L
.29569 .30899 L
.29591 .30899 L
.29601 .30899 L
.29612 .30899 L
.29621 .30899 L
.29631 .30899 L
.29641 .30899 L
.2965 .30899 L
.29659 .30899 L
.29668 .30899 L
.29676 .30899 L
.29684 .30899 L
.29694 .30899 L
.29704 .30899 L
.29714 .30899 L
.29724 .30899 L
.29742 .30899 L
.29761 .30899 L
.29804 .30899 L
.29843 .30899 L
.29886 .30899 L
.29932 .30899 L
.30008 .30899 L
.30093 .30899 L
.30248 .309 L
.30415 .309 L
.30576 .30901 L
.30745 .30902 L
.31051 .30904 L
.31376 .30907 L
.31689 .3091 L
.31849 .30911 L
.32022 .30913 L
.32103 .30913 L
.32189 .30914 L
.32262 .30914 L
.323 .30914 L
.32342 .30914 L
.32364 .30914 L
.32384 .30914 L
.32403 .30914 L
Mistroke
.32413 .30914 L
.32424 .30914 L
.32434 .30914 L
.32444 .30914 L
.32453 .30914 L
.32463 .30914 L
.32472 .30914 L
.3248 .30914 L
.32489 .30914 L
.32498 .30914 L
.32504 .30914 L
.32509 .30914 L
.3252 .30914 L
.32543 .30914 L
.32564 .30914 L
.32586 .30914 L
.32627 .30914 L
.32666 .30914 L
.32745 .30914 L
.32828 .30913 L
.32976 .30911 L
.33135 .30909 L
.33282 .30906 L
.33596 .30899 L
.33929 .30888 L
.3425 .30877 L
.34559 .30867 L
.34718 .30863 L
.34799 .30862 L
.34844 .30861 L
.34887 .30861 L
.34926 .3086 L
.34947 .3086 L
.34969 .3086 L
.34989 .3086 L
.35008 .3086 L
.35017 .3086 L
.35026 .3086 L
.35035 .3086 L
.35043 .3086 L
.35053 .3086 L
.35064 .3086 L
.35073 .3086 L
.35082 .3086 L
.35093 .3086 L
.35104 .3086 L
.35125 .3086 L
.35147 .3086 L
.3517 .3086 L
.35211 .30861 L
Mistroke
.35251 .30861 L
.35287 .30862 L
.35368 .30864 L
.35443 .30866 L
.35515 .30869 L
.35674 .30877 L
.35821 .30886 L
.36135 .30912 L
.36469 .30946 L
.3679 .30979 L
.36937 .30993 L
.37021 .30999 L
.37099 .31005 L
.37183 .3101 L
.37259 .31013 L
.37301 .31015 L
.37341 .31016 L
.37362 .31016 L
.37383 .31016 L
.37393 .31017 L
.37405 .31017 L
.3741 .31017 L
.37417 .31017 L
.37423 .31017 L
.37428 .31017 L
.37438 .31017 L
.37448 .31017 L
.37457 .31017 L
.37466 .31017 L
.37476 .31017 L
.37487 .31017 L
.37507 .31016 L
.37525 .31016 L
.37542 .31016 L
.3758 .31015 L
.37622 .31013 L
.3766 .31011 L
.37746 .31006 L
.37825 .30999 L
.37899 .30991 L
.38065 .30967 L
.3823 .30937 L
.38379 .30904 L
.38701 .3082 L
.39011 .30735 L
.39168 .30696 L
.39251 .30678 L
.3934 .30661 L
.39426 .30648 L
.39504 .30638 L
Mistroke
.39542 .30635 L
.39562 .30633 L
.39583 .30632 L
.39601 .30631 L
.39621 .3063 L
.3963 .30629 L
.3964 .30629 L
.39649 .30629 L
.39657 .30629 L
.39667 .30629 L
.39677 .30629 L
.39686 .30628 L
.39692 .30628 L
.39697 .30629 L
.39706 .30629 L
.39715 .30629 L
.39725 .30629 L
.39734 .30629 L
.39755 .3063 L
.39775 .30631 L
.39797 .30632 L
.39818 .30634 L
.3986 .30638 L
.39899 .30642 L
.39988 .30657 L
.40073 .30676 L
.40153 .30698 L
.40302 .30752 L
.40612 .30905 L
.40942 .31109 L
.4126 .31302 L
.4142 .31382 L
.4149 .31411 L
.41565 .31437 L
.41607 .31448 L
.41646 .31458 L
.41685 .31465 L
.41722 .3147 L
.41741 .31472 L
.41761 .31474 L
.41773 .31475 L
.41778 .31475 L
.41783 .31475 L
.41793 .31475 L
.41798 .31475 L
.41804 .31476 L
.4181 .31476 L
.41815 .31476 L
.41821 .31475 L
.41827 .31475 L
Mistroke
.41838 .31475 L
.41844 .31475 L
.41849 .31475 L
.41869 .31473 L
.4188 .31472 L
.4189 .31471 L
.41929 .31466 L
.41948 .31462 L
.4197 .31458 L
.42044 .31437 L
.42085 .31422 L
.42129 .31402 L
.4221 .31359 L
.42371 .31244 L
.4254 .31085 L
.42846 .30722 L
.43172 .303 L
.43322 .30124 L
.43485 .29967 L
.43574 .29901 L
.43613 .29877 L
.43656 .29855 L
.43694 .2984 L
.43735 .29827 L
.43757 .29822 L
.43778 .29819 L
.43788 .29817 L
.43799 .29816 L
.43809 .29816 L
.43818 .29815 L
.43829 .29815 L
.43834 .29815 L
.43839 .29815 L
.4385 .29816 L
.43859 .29816 L
.4387 .29818 L
.4388 .29819 L
.43903 .29823 L
.43923 .29828 L
.43944 .29834 L
.43983 .2985 L
.44021 .29869 L
.44061 .29895 L
.44133 .29952 L
.44208 .3003 L
.44289 .30133 L
.44436 .30366 L
.44767 .31069 L
.45085 .3184 L
.45246 .32196 L
Mistroke
.45391 .32466 L
.45467 .3258 L
.45549 .32677 L
.45594 .32717 L
.45636 .32747 L
.45675 .32767 L
.45695 .32774 L
.45707 .32777 L
.45717 .3278 L
.45727 .32781 L
.45732 .32782 L
.45738 .32783 L
.45748 .32783 L
.45757 .32783 L
.45763 .32783 L
.45768 .32783 L
.45778 .32782 L
.45784 .32781 L
.45789 .3278 L
.45801 .32777 L
.45821 .32771 L
.45839 .32764 L
.4588 .3274 L
.45917 .32711 L
.45957 .32671 L
.46029 .32574 L
.46105 .32442 L
.46189 .3226 L
.46357 .31783 L
.46681 .30565 L
.46992 .29278 L
.47151 .28703 L
.47234 .28445 L
.47323 .28216 L
.47368 .28122 L
.4741 .28047 L
.47451 .27987 L
.47489 .27943 L
.47525 .27914 L
.47543 .27903 L
.47553 .27898 L
.47562 .27894 L
.47573 .27891 L
.47582 .27889 L
.47593 .27888 L
.47598 .27888 L
.47604 .27888 L
.47613 .27889 L
.47622 .2789 L
.47633 .27893 L
Mistroke
.47642 .27896 L
.47662 .27906 L
.4768 .27918 L
.477 .27935 L
.47721 .27957 L
.47765 .28016 L
.47804 .28085 L
.47881 .28262 L
.47953 .2848 L
.48114 .29132 L
.48262 .29911 L
.48578 .3193 L
.48882 .33861 L
.49039 .34643 L
.49126 .34978 L
.49165 .35099 L
.49206 .35206 L
.49248 .35293 L
.49286 .35351 L
.49304 .35371 L
.49313 .35381 L
.49323 .35389 L
.49332 .35395 L
.49342 .354 L
.49351 .35404 L
.49359 .35406 L
.49369 .35407 L
.49375 .35408 L
.49381 .35407 L
.49391 .35406 L
.49401 .35402 L
.49411 .35398 L
.49419 .35392 L
.49439 .35376 L
.49461 .35351 L
.49481 .35322 L
.49526 .35235 L
.49564 .35136 L
.49604 .35007 L
.49678 .3471 L
.49765 .34256 L
.49844 .33753 L
.50166 .31022 L
.50475 .2797 L
.50632 .26582 L
.50715 .25954 L
.50804 .2539 L
.50848 .2516 L
.5089 .24974 L
.5093 .24825 L
Mistroke
.50968 .24716 L
.51003 .2464 L
.51021 .24611 L
.51031 .24598 L
.51041 .24588 L
.51051 .24579 L
.51061 .24573 L
.51071 .24568 L
.51077 .24567 L
.51082 .24566 L
.51092 .24567 L
.51101 .24569 L
.51111 .24574 L
.51121 .2458 L
.5113 .24589 L
.5114 .246 L
.51158 .24626 L
.51179 .24666 L
.51199 .24711 L
.51241 .24841 L
.51281 .25001 L
.51352 .25372 L
.51429 .25901 L
.51587 .27357 L
.51756 .29359 L
.5209 .33967 L
.52258 .36138 L
.52331 .36971 L
.52412 .37769 L
.52485 .38366 L
.52562 .38858 L
.52606 .39058 L
.52645 .39195 L
.52664 .39244 L
.52674 .39265 L
.52684 .39285 L
.52693 .39299 L
.52704 .39312 L
.52713 .39321 L
.52721 .39327 L
.52731 .39331 L
.52741 .39331 L
.52751 .39329 L
.52759 .39325 L
.52769 .39316 L
.52781 .39304 L
.52791 .39288 L
.52801 .39271 L
.5282 .39227 L
.52841 .39165 L
Mistroke
.52884 .38996 L
.52921 .38803 L
.52961 .38547 L
.53032 .37961 L
.53114 .37112 L
.53202 .35982 L
.53364 .33472 L
.53691 .27474 L
.53853 .24641 L
.53933 .2342 L
.54006 .22437 L
.54075 .21647 L
.54151 .20966 L
.54191 .20695 L
.54228 .20497 L
.54248 .20412 L
.54267 .20346 L
.54277 .20316 L
.54288 .20289 L
.54299 .20268 L
.54308 .20254 L
.54318 .20242 L
.54327 .20236 L
.54337 .20232 L
.54347 .20233 L
.54357 .20237 L
.54366 .20246 L
.54376 .20258 L
.54384 .20272 L
.54405 .20319 L
.54427 .20391 L
.54468 .20576 L
.5451 .20847 L
.54555 .21216 L
.54636 .22087 L
.54794 .2449 L
.54941 .27422 L
.55253 .34705 L
.55412 .38244 L
.55496 .3988 L
.55585 .41366 L
.55664 .42422 L
.55706 .42871 L
.55752 .43261 L
.55772 .43402 L
.55793 .43528 L
.55813 .43625 L
.55831 .43696 L
.55848 .43747 L
.55858 .43769 L
Mistroke
.55866 .43785 L
.55876 .43797 L
.55886 .43805 L
.55896 .43807 L
.55905 .43804 L
.55915 .43796 L
.55925 .43783 L
.55934 .43767 L
.55943 .43745 L
.55964 .43679 L
.55983 .43596 L
.56018 .43392 L
.56056 .43102 L
.56101 .42657 L
.56143 .42142 L
.56222 .40943 L
.56383 .37618 L
.56532 .33782 L
.56849 .24735 L
.57009 .20729 L
.57078 .19273 L
.57154 .17951 L
.57196 .17349 L
.57235 .16882 L
.57274 .16499 L
.57311 .16227 L
.5733 .16122 L
.5735 .16035 L
.57361 .15998 L
.57372 .15968 L
.57382 .15949 L
.57387 .15941 L
.57393 .15936 L
.57398 .15932 L
.57404 .1593 L
.57409 .1593 L
.57415 .15932 L
.57424 .1594 L
.57434 .15956 L
.5744 .15967 L
.57445 .15981 L
.57456 .16011 L
.57479 .16106 L
.575 .1622 L
.57521 .16371 L
.57561 .16722 L
.57603 .17211 L
.57649 .17882 L
.57811 .21189 L
.57966 .25539 L
Mistroke
.58133 .31005 L
.58291 .36293 L
.58463 .41513 L
.58543 .43519 L
.58628 .45281 L
.58669 .45974 L
.58708 .46523 L
.58746 .46952 L
.58781 .47259 L
.58799 .4738 L
.58818 .47482 L
.58829 .47528 L
.58839 .47563 L
.58849 .47587 L
.58859 .47605 L
.58865 .47612 L
.5887 .47617 L
.5888 .47619 L
.5889 .47612 L
.58896 .47605 L
.58902 .47596 L
.58911 .47575 L
.58921 .47545 L
.58942 .47459 L
.58961 .47347 L
.58979 .4722 L
.59018 .46847 L
.59055 .46395 L
.5909 .45874 L
.59167 .44399 L
.5925 .42396 L
.59397 .37866 L
.59701 .26641 L
.59869 .20713 L
.59943 .18476 L
.60024 .16387 L
.60102 .14777 L
.6014 .14171 L
.60175 .13701 L
.60194 .13488 L
.60215 .13293 L
.60233 .1316 L
.60252 .13043 L
.60262 .12994 L
.60273 .12952 L
.60279 .12934 L
.60284 .12919 L
.6029 .12907 L
.60295 .12898 L
.60304 .12888 L
Mistroke
.60315 .12886 L
.60324 .12892 L
.60334 .12908 L
.60344 .12932 L
.60355 .12969 L
.60367 .13019 L
.60377 .13076 L
.60417 .13375 L
.6044 .13607 L
.6046 .13857 L
.60507 .14549 L
.6059 .16232 L
.60669 .18301 L
.60977 .29537 L
.61133 .3594 L
.61305 .42336 L
.61383 .44768 L
.61468 .46911 L
.61509 .47747 L
.61548 .48411 L
.61585 .48925 L
.61621 .49292 L
.6164 .49443 L
.6165 .49508 L
.61661 .49567 L
.6167 .49607 L
.6168 .49642 L
.61689 .49666 L
.61698 .49681 L
.61703 .49687 L
.61708 .4969 L
.61718 .49689 L
.61728 .49678 L
.61737 .4966 L
.61747 .49632 L
.61758 .49589 L
.6178 .49469 L
.61799 .49327 L
.61816 .49166 L
.61856 .48697 L
.6189 .48163 L
.61927 .47483 L
.62004 .45693 L
.62086 .43278 L
.62233 .37884 L
.62566 .23772 L
.62647 .20632 L
.62733 .17691 L
.62812 .15421 L
.62851 .14494 L
Mistroke
.62887 .13763 L
.62921 .13172 L
.62958 .12653 L
.62978 .12424 L
.62997 .12248 L
.63015 .12113 L
.63034 .12005 L
.63045 .11959 L
.63055 .11928 L
.6306 .11916 L
.63066 .11906 L
.63072 .119 L
.63077 .11897 L
.63088 .119 L
.63097 .11912 L
.63103 .11923 L
.63108 .11938 L
.63119 .11973 L
.63128 .12014 L
.63138 .12069 L
.63159 .12213 L
.63195 .12577 L
.63235 .13118 L
.63277 .13848 L
.63351 .15546 L
.63519 .20958 L
.63825 .33984 L
.63996 .40988 L
.64151 .45962 L
.64228 .47728 L
.64272 .48477 L
.64312 .49 L
.64329 .49172 L
.64347 .49324 L
.64358 .49395 L
.64367 .49451 L
.64377 .49494 L
.64386 .49531 L
.64396 .49559 L
.64405 .49576 L
.64415 .49584 L
.64421 .49584 L
.64426 .4958 L
.64436 .49567 L
.64445 .49547 L
.64454 .49515 L
.64464 .49471 L
.64485 .49348 L
.64504 .49192 L
.64541 .48796 L
Mistroke
.6458 .48221 L
.64623 .47428 L
.64699 .45584 L
.6477 .43453 L
.65086 .30738 L
.65245 .23988 L
.6539 .1871 L
.6547 .16415 L
.65546 .1474 L
.65587 .14052 L
.65626 .13567 L
.65648 .13356 L
.65668 .13209 L
.65679 .13146 L
.65691 .13092 L
.65697 .13072 L
.65703 .13055 L
.65713 .13033 L
.65723 .13023 L
.65728 .13021 L
.65734 .13023 L
.65743 .13033 L
.65753 .13054 L
.65762 .13082 L
.6577 .13115 L
.65789 .13218 L
.6581 .1337 L
.65829 .13548 L
.65871 .14078 L
.65905 .14635 L
.65943 .15372 L
.66018 .17231 L
.66176 .22454 L
.66344 .2928 L
.66504 .35939 L
.66588 .39159 L
.66677 .42156 L
.66756 .44361 L
.66799 .45319 L
.66844 .46171 L
.66885 .46783 L
.66923 .47194 L
.66942 .47341 L
.66951 .47404 L
.66962 .47462 L
.66972 .47507 L
.6698 .4754 L
.66989 .47564 L
.66998 .4758 L
.67007 .47588 L
Mistroke
.67017 .47588 L
.67027 .47578 L
.67035 .47561 L
.67046 .47531 L
.67057 .47487 L
.67076 .47377 L
.67097 .47218 L
.6712 .47002 L
.67159 .46496 L
.6723 .45237 L
.67308 .43359 L
.67463 .38362 L
.67631 .31897 L
.67789 .25751 L
.67873 .22819 L
.67962 .20116 L
.68048 .18032 L
.68089 .17261 L
.68127 .16682 L
.68165 .1623 L
.68185 .16046 L
.68206 .15893 L
.68215 .15842 L
.68224 .15795 L
.68232 .15762 L
.68241 .15732 L
.68252 .15708 L
.68262 .15695 L
.68271 .15691 L
.6828 .15696 L
.6829 .15709 L
.683 .15732 L
.68308 .15759 L
.68317 .15797 L
.68338 .1591 L
.68357 .16053 L
.68393 .16399 L
.6843 .16892 L
.68517 .18488 L
.68595 .20433 L
.68916 .31283 L
.69063 .36421 L
.69146 .38986 L
.69225 .41027 L
.69301 .42615 L
.69345 .43303 L
.69384 .43796 L
.69404 .43996 L
.69425 .44169 L
.69438 .44251 L
Mistroke
.69449 .44314 L
.6946 .44366 L
.69471 .44403 L
.69481 .4443 L
.69491 .44449 L
.69502 .44459 L
.69507 .44459 L
.69513 .44457 L
.69523 .44446 L
.69532 .44429 L
.69543 .44399 L
.69553 .44362 L
.69572 .44267 L
.6959 .44149 L
.69631 .43779 L
.6967 .43285 L
.69713 .42615 L
.69861 .39321 L
.70191 .28982 L
.70356 .24123 L
.70437 .22211 L
.7051 .20826 L
.70546 .20274 L
.70586 .19789 L
.70604 .19607 L
.70623 .19443 L
.70641 .19317 L
.70658 .19224 L
.70676 .19144 L
.70687 .19113 L
.70697 .19091 L
.70706 .19077 L
.70714 .19071 L
.70723 .1907 L
.70733 .19077 L
.70739 .19085 L
.70744 .19094 L
.70755 .19122 L
.70766 .19156 L
.70776 .19201 L
.70795 .193 L
.70816 .19441 L
.70858 .19831 L
.70898 .2032 L
.70973 .21529 L
.71141 .25367 L
.71449 .34047 L
.71608 .37835 L
.71689 .39267 L
.71734 .39905 L
Mistroke
.71777 .40377 L
.71817 .40702 L
.7184 .40837 L
.7185 .40888 L
.71861 .40929 L
.7187 .40961 L
.71881 .40988 L
.7189 .41006 L
.71899 .41017 L
.71908 .41022 L
.71919 .41021 L
.71924 .41017 L
.7193 .41011 L
.7194 .40994 L
.7195 .40971 L
.71959 .40943 L
.7198 .40858 L
.71998 .40758 L
.72017 .40627 L
.72051 .40341 L
.72088 .3994 L
.72169 .38783 L
.72244 .37423 L
.72411 .33633 L
.72576 .29555 L
.72729 .26142 L
.72805 .24766 L
.72877 .23726 L
.72917 .23273 L
.7296 .22886 L
.72979 .22751 L
.72999 .22632 L
.73016 .2255 L
.73035 .22482 L
.73046 .22453 L
.73055 .22433 L
.73065 .22419 L
.73075 .2241 L
.73084 .22407 L
.73094 .2241 L
.73102 .22417 L
.73111 .2243 L
.73121 .22449 L
.73131 .22477 L
.73153 .22555 L
.73173 .22653 L
.73192 .22765 L
.73263 .2337 L
.73303 .23826 L
.73339 .24307 L
Mistroke
.73659 .30353 L
.73806 .33337 L
.73889 .34831 L
.73967 .36014 L
.74044 .3692 L
.74087 .37306 L
.74107 .37457 L
.74126 .37578 L
.74147 .37688 L
.74166 .37768 L
.74186 .37835 L
.74198 .37862 L
.74203 .37872 L
.74209 .37882 L
.74219 .37895 L
.74225 .37899 L
.7423 .37902 L
.7424 .37903 L
.7425 .37899 L
.74256 .37894 L
.74262 .37886 L
.74274 .37868 L
.74285 .37843 L
.74295 .37815 L
.74314 .37746 L
.74332 .37667 L
.74372 .37432 L
.74408 .37161 L
.74445 .36816 L
.7461 .34661 L
.74916 .29464 L
.75073 .27165 L
.75118 .2664 L
.75161 .26213 L
.75199 .25894 L
.75241 .25612 L
.7526 .25508 L
.75281 .25414 L
.75299 .25348 L
.75319 .25293 L
.7533 .25268 L
.75341 .25251 L
.75351 .25239 L
.75357 .25235 L
.75362 .25232 L
.75372 .25229 L
.75382 .25232 L
.75392 .25238 L
.75401 .25248 L
.7541 .25261 L
Mistroke
.75419 .25278 L
.75436 .25318 L
.75455 .25381 L
.75473 .25452 L
.75512 .25653 L
.75549 .25897 L
.75627 .26567 L
.75709 .27477 L
.75857 .29449 L
.76015 .31692 L
.7616 .33507 L
.76236 .34263 L
.76316 .34869 L
.76357 .351 L
.76396 .3526 L
.76418 .35327 L
.76438 .35373 L
.76449 .35392 L
.76455 .354 L
.76461 .35407 L
.76467 .35412 L
.76473 .35417 L
.76483 .35421 L
.76494 .35422 L
.76503 .35419 L
.76514 .35412 L
.7652 .35406 L
.76525 .354 L
.76535 .35386 L
.76546 .35366 L
.76565 .35321 L
.76584 .35265 L
.76604 .35192 L
.76639 .35029 L
.7672 .34524 L
.76807 .33779 L
.77132 .30203 L
.77282 .28728 L
.77367 .28093 L
.77407 .27855 L
.77445 .27671 L
.77485 .27524 L
.77506 .27464 L
.77528 .27414 L
.77539 .27395 L
.77552 .27379 L
.77557 .27372 L
.77563 .27367 L
.77569 .27363 L
.77574 .2736 L
Mistroke
.77579 .27357 L
.77585 .27356 L
.77591 .27355 L
.77596 .27356 L
.77606 .27358 L
.77616 .27364 L
.77621 .27368 L
.77627 .27374 L
.77637 .27386 L
.77656 .27417 L
.77679 .27466 L
.777 .27524 L
.77737 .27659 L
.77778 .27841 L
.77853 .28281 L
.77934 .28873 L
.78081 .30141 L
.78238 .31551 L
.78322 .3222 L
.78411 .32822 L
.78455 .33068 L
.78497 .33262 L
.78538 .33414 L
.78556 .33469 L
.78575 .33521 L
.78593 .33559 L
.78611 .33592 L
.78621 .33606 L
.78631 .33617 L
.78639 .33626 L
.78649 .33633 L
.78659 .33639 L
.78668 .33642 L
.78674 .33642 L
.7868 .33642 L
.7869 .3364 L
.787 .33636 L
.78708 .33631 L
.78718 .33622 L
.78729 .33611 L
.78749 .33582 L
.78769 .33546 L
.78805 .33456 L
.78844 .3333 L
.78886 .33159 L
.79034 .32351 L
.7919 .31281 L
.79361 .30115 L
.7944 .29663 L
.79524 .2927 L
Mistroke
.79563 .29126 L
.79604 .29004 L
.79639 .28923 L
.79659 .28886 L
.79677 .28859 L
.79697 .28837 L
.79708 .28828 L
.79714 .28824 L
.79719 .28821 L
.79729 .28817 L
.79738 .28815 L
.79744 .28814 L
.79749 .28814 L
.79759 .28815 L
.79769 .28818 L
.79778 .28823 L
.79786 .28828 L
.79795 .28835 L
.79816 .28856 L
.79834 .28883 L
.79877 .28963 L
.79915 .29062 L
.80003 .29363 L
.80154 .30076 L
.8032 .30972 L
.80408 .3142 L
.80491 .31793 L
.80571 .3209 L
.80607 .32196 L
.80646 .32294 L
.80683 .32368 L
.80718 .32419 L
.80738 .3244 L
.80756 .32454 L
.80766 .3246 L
.80771 .32463 L
.80776 .32465 L
.80786 .32468 L
.80796 .3247 L
.80801 .3247 L
.80807 .3247 L
.80817 .32469 L
.80823 .32468 L
.80828 .32466 L
.8084 .32461 L
.8085 .32455 L
.8086 .32448 L
.80881 .32428 L
.809 .32405 L
.80921 .32374 L
Mistroke
.80959 .32306 L
.81034 .3212 L
.81117 .31853 L
.81286 .31193 L
.81454 .30523 L
.81528 .30269 L
.81609 .30039 L
.81647 .29952 L
.81687 .29874 L
.81725 .29816 L
.8176 .29778 L
.81781 .29761 L
.81799 .2975 L
.81809 .29745 L
.8182 .29742 L
.81826 .29741 L
.81831 .2974 L
.81842 .29739 L
.81852 .29739 L
.81858 .2974 L
.81863 .2974 L
.81872 .29743 L
.81882 .29746 L
.81892 .29751 L
.81902 .29756 L
.81919 .29768 L
.81957 .29805 L
.81998 .2986 L
.82081 .30015 L
.82229 .30403 L
.82399 .30921 L
.82554 .31348 L
.82631 .31516 L
.82672 .31588 L
.82715 .3165 L
.82753 .31693 L
.82773 .31712 L
.82794 .31727 L
.82814 .31739 L
.82822 .31743 L
.82832 .31746 L
.8284 .31749 L
.82849 .31751 L
.82858 .31752 L
.82867 .31753 L
.82877 .31753 L
.82883 .31753 L
.82888 .31752 L
.82893 .31751 L
.82899 .3175 L
Mistroke
.8291 .31748 L
.8292 .31744 L
.8293 .3174 L
.82949 .3173 L
.82972 .31714 L
.82996 .31694 L
.83039 .31648 L
.83116 .31536 L
.83201 .31378 L
.83369 .31007 L
.83523 .30674 L
.83601 .30532 L
.83674 .30425 L
.83714 .30379 L
.8375 .30344 L
.8379 .30315 L
.83812 .30304 L
.83823 .30299 L
.83833 .30295 L
.83843 .30292 L
.83853 .3029 L
.83862 .30288 L
.8387 .30287 L
.83881 .30286 L
.8389 .30286 L
.839 .30286 L
.83906 .30287 L
.83911 .30288 L
.83922 .30289 L
.83932 .30292 L
.83954 .30299 L
.83973 .30307 L
.83994 .30318 L
.8403 .30344 L
.84064 .30374 L
.84142 .3046 L
.84454 .30948 L
.84614 .31172 L
.84657 .3122 L
.84704 .31263 L
.84744 .31293 L
.84765 .31306 L
.84787 .31317 L
.84806 .31325 L
.84828 .31333 L
.84837 .31335 L
.84847 .31337 L
.84856 .31339 L
.84865 .3134 L
.84875 .31341 L
Mistroke
.84885 .31342 L
.84894 .31342 L
.84904 .31341 L
.84912 .31341 L
.8492 .3134 L
.84929 .31339 L
.84939 .31337 L
.8496 .31331 L
.84984 .31323 L
.85027 .31303 L
.85068 .31277 L
.85107 .31248 L
.85272 .31081 L
.85421 .30904 L
.85503 .30812 L
.85589 .30727 L
.85663 .30669 L
.85705 .30642 L
.85744 .30622 L
.85763 .30614 L
.85783 .30607 L
.85801 .30602 L
.85821 .30597 L
.85831 .30595 L
.85842 .30593 L
.85848 .30593 L
.85854 .30592 L
.85859 .30592 L
.85864 .30591 L
.85874 .30591 L
.85879 .30591 L
.85885 .30591 L
.85895 .30591 L
.85904 .30592 L
.85913 .30592 L
.85923 .30593 L
.85941 .30596 L
.8596 .306 L
.85981 .30606 L
.86019 .30619 L
.86054 .30635 L
.86138 .30684 L
.86217 .30742 L
.86366 .30865 L
.86512 .30982 L
.86595 .31038 L
.86636 .3106 L
.86674 .31078 L
.8671 .31092 L
.8675 .31104 L
Mistroke
.86771 .31109 L
.8679 .31113 L
.8681 .31116 L
.86822 .31117 L
.86832 .31118 L
.86843 .31118 L
.86848 .31119 L
.86854 .31119 L
.86864 .31119 L
.86874 .31119 L
.8688 .31119 L
.86885 .31118 L
.86896 .31118 L
.86907 .31117 L
.86919 .31115 L
.8694 .31112 L
.86961 .31108 L
.87001 .31098 L
.87044 .31084 L
.87084 .31068 L
.87173 .31024 L
.87335 .3093 L
.87499 .30839 L
.87579 .30803 L
.87652 .30778 L
.87689 .30768 L
.87708 .30764 L
.87728 .3076 L
.87746 .30757 L
.87765 .30755 L
.87774 .30754 L
.87783 .30753 L
.87791 .30753 L
.878 .30752 L
.8781 .30752 L
.87819 .30752 L
.87824 .30752 L
.8783 .30752 L
.8784 .30752 L
.8785 .30752 L
.8786 .30752 L
.87871 .30753 L
.87882 .30754 L
.87901 .30755 L
.87918 .30758 L
.87957 .30764 L
.87998 .30773 L
.88041 .30784 L
.88121 .30811 L
.88269 .3087 L
Mistroke
.88425 .30932 L
.88507 .3096 L
.88551 .30972 L
.88596 .30983 L
.88637 .30991 L
.88658 .30995 L
.88681 .30998 L
.88702 .31 L
.88721 .31002 L
.88731 .31003 L
.88741 .31003 L
.88749 .31004 L
.88759 .31004 L
.88768 .31004 L
.88777 .31004 L
.88788 .31004 L
.88797 .31004 L
.88807 .31004 L
.88813 .31004 L
.88818 .31004 L
.88828 .31004 L
.88838 .31003 L
.88858 .31002 L
.88877 .31 L
.88911 .30996 L
.88949 .30991 L
.8899 .30983 L
.89073 .30965 L
.89221 .30924 L
.89391 .30878 L
.89471 .30859 L
.89545 .30846 L
.89583 .30841 L
.89622 .30837 L
.89643 .30835 L
.89662 .30834 L
.89683 .30833 L
.89695 .30833 L
.89706 .30832 L
.89715 .30832 L
.89724 .30832 L
.89733 .30832 L
.89741 .30832 L
.89751 .30832 L
.89761 .30832 L
.89771 .30833 L
.8978 .30833 L
.89798 .30834 L
.89818 .30835 L
.89858 .30838 L
Mistroke
.899 .30842 L
.8994 .30847 L
.90014 .30859 L
.90182 .3089 L
.90343 .3092 L
.90413 .3093 L
.90489 .30939 L
.90531 .30943 L
.9055 .30944 L
.9057 .30946 L
.90589 .30947 L
.90608 .30947 L
.90618 .30948 L
.90628 .30948 L
.90638 .30948 L
.90647 .30948 L
.90657 .30948 L
.90662 .30948 L
.90668 .30948 L
.90678 .30948 L
.90684 .30948 L
.90689 .30948 L
.90699 .30948 L
.90709 .30948 L
.90719 .30948 L
.90728 .30948 L
.9075 .30947 L
.9077 .30946 L
.90816 .30943 L
.90896 .30936 L
.9097 .30928 L
.91137 .30907 L
.91216 .30896 L
.91301 .30887 L
.91374 .3088 L
.91413 .30877 L
.91454 .30875 L
.91474 .30874 L
.91496 .30873 L
.91517 .30872 L
.91536 .30871 L
.91555 .30871 L
.91565 .30871 L
.9157 .30871 L
.91576 .30871 L
.91585 .30871 L
.91594 .30871 L
.91604 .30871 L
.91613 .30871 L
.91622 .30871 L
Mistroke
.91632 .30871 L
.9164 .30871 L
.91649 .30871 L
.91669 .30872 L
.91688 .30872 L
.91722 .30873 L
.91759 .30875 L
.9184 .3088 L
.91928 .30887 L
.9209 .30901 L
.92248 .30913 L
.92293 .30916 L
.92336 .30918 L
.92374 .3092 L
.92395 .3092 L
.92416 .30921 L
.92438 .30921 L
.92457 .30922 L
.92466 .30922 L
.92476 .30922 L
.92486 .30922 L
.92495 .30922 L
.92505 .30922 L
.92514 .30922 L
.92524 .30922 L
.9253 .30922 L
.92535 .30922 L
.92545 .30922 L
.92551 .30922 L
.92556 .30922 L
.92578 .30922 L
.92597 .30921 L
.92615 .30921 L
.92649 .3092 L
.92726 .30917 L
.92887 .30909 L
.93035 .309 L
.93108 .30897 L
.93186 .30893 L
.93231 .30891 L
.93271 .3089 L
.93291 .3089 L
.93313 .30889 L
.93331 .30889 L
.93352 .30889 L
.93361 .30889 L
.93372 .30889 L
.93381 .30888 L
.9339 .30888 L
.93399 .30888 L
Mistroke
.93408 .30888 L
.93418 .30888 L
.93427 .30888 L
.93432 .30888 L
.93437 .30888 L
.93447 .30888 L
.93458 .30888 L
.9347 .30888 L
.9349 .30889 L
.9351 .30889 L
.93552 .3089 L
.93591 .3089 L
.93678 .30893 L
.93844 .30899 L
.93997 .30905 L
.94074 .30907 L
.94146 .30909 L
.94185 .30909 L
.94206 .3091 L
.94229 .3091 L
.94247 .3091 L
.94257 .3091 L
.94268 .3091 L
.94277 .3091 L
.94286 .3091 L
.94295 .3091 L
.94304 .3091 L
.94313 .3091 L
.94323 .3091 L
.94332 .3091 L
.94341 .3091 L
.9435 .3091 L
.9436 .3091 L
.94371 .3091 L
.94381 .3091 L
.94402 .3091 L
.94421 .3091 L
.94464 .30909 L
.9454 .30908 L
.94611 .30907 L
.94758 .30903 L
.94842 .30901 L
.9492 .30899 L
.94997 .30898 L
.95037 .30897 L
.9508 .30897 L
.95103 .30897 L
.95125 .30896 L
.95146 .30896 L
.95157 .30896 L
Mistroke
.95168 .30896 L
.95179 .30896 L
.9519 .30896 L
.952 .30896 L
.9521 .30896 L
.9522 .30896 L
.95229 .30896 L
.95238 .30896 L
.95249 .30896 L
.95259 .30896 L
.95269 .30896 L
.95291 .30896 L
.95312 .30896 L
.95331 .30897 L
.9542 .30897 L
.95497 .30899 L
.95581 .309 L
.95739 .30902 L
.95823 .30903 L
.95869 .30904 L
.95912 .30904 L
.95953 .30905 L
.95975 .30905 L
.95998 .30905 L
.96018 .30905 L
.96028 .30905 L
.96039 .30905 L
.96049 .30905 L
.96059 .30905 L
.96068 .30905 L
.96077 .30905 L
.96086 .30905 L
.96095 .30905 L
.96105 .30905 L
.96115 .30905 L
.96124 .30905 L
.96132 .30905 L
.9615 .30905 L
.96169 .30905 L
.96189 .30905 L
.9623 .30905 L
.96273 .30905 L
.96313 .30904 L
.96387 .30904 L
.96556 .30902 L
.96702 .30901 L
.96743 .309 L
.96786 .309 L
.96823 .309 L
.96864 .309 L
Mistroke
.96886 .309 L
.96907 .309 L
.96926 .30899 L
.96937 .30899 L
.96947 .30899 L
.96957 .30899 L
.96966 .30899 L
.96976 .30899 L
.96987 .30899 L
.96996 .30899 L
.97004 .30899 L
.97013 .30899 L
.97023 .30899 L
.97045 .309 L
.97069 .309 L
.97112 .309 L
.97192 .309 L
.9752 .30902 L
.97619 .30903 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{421.375, 260.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 525.688}, {324.5, 0}} -> {-2.58312*^-7, -6.34248*^6, \
6.65005*^-9, 53093.5}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0.309017 5.42214e-08 [
[.32684 .29652 -16.5 -12.5 ]
[.32684 .29652 16.5 0 ]
[.54329 .29652 -16.5 -12.5 ]
[.54329 .29652 16.5 0 ]
[.75974 .29652 -22.5 -12.5 ]
[.75974 .29652 22.5 0 ]
[.97619 .29652 -16.5 -12.5 ]
[.97619 .29652 16.5 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 64 6 ]
[.09789 .09213 -34.5 -6.25 ]
[.09789 .09213 0 6.25 ]
[.09789 .20057 -34.5 -6.25 ]
[.09789 .20057 0 6.25 ]
[.09789 .41746 -28.5 -6.25 ]
[.09789 .41746 0 6.25 ]
[.09789 .5259 -28.5 -6.25 ]
[.09789 .5259 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -65.8125 0 ]
[.5 .63053 65.8125 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 .30902 m
.32684 .31527 L
s
gsave
.32684 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 .30902 m
.54329 .31527 L
s
gsave
.54329 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 .30902 m
.75974 .31527 L
s
gsave
.75974 .29652 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 .30902 m
.15368 .31277 L
s
.19697 .30902 m
.19697 .31277 L
s
.24026 .30902 m
.24026 .31277 L
s
.28355 .30902 m
.28355 .31277 L
s
.37013 .30902 m
.37013 .31277 L
s
.41342 .30902 m
.41342 .31277 L
s
.45671 .30902 m
.45671 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.58658 .30902 m
.58658 .31277 L
s
.62987 .30902 m
.62987 .31277 L
s
.67316 .30902 m
.67316 .31277 L
s
.71645 .30902 m
.71645 .31277 L
s
.80303 .30902 m
.80303 .31277 L
s
.84632 .30902 m
.84632 .31277 L
s
.88961 .30902 m
.88961 .31277 L
s
.9329 .30902 m
.9329 .31277 L
s
.0671 .30902 m
.0671 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09213 m
.11664 .09213 L
s
gsave
.09789 .09213 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .20057 m
.11664 .20057 L
s
gsave
.09789 .20057 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .41746 m
.11664 .41746 L
s
gsave
.09789 .41746 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .5259 m
.11664 .5259 L
s
gsave
.09789 .5259 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.11039 .11924 m
.11414 .11924 L
s
.11039 .14635 m
.11414 .14635 L
s
.11039 .17346 m
.11414 .17346 L
s
.11039 .22768 m
.11414 .22768 L
s
.11039 .2548 m
.11414 .2548 L
s
.11039 .28191 m
.11414 .28191 L
s
.11039 .33613 m
.11414 .33613 L
s
.11039 .36324 m
.11414 .36324 L
s
.11039 .39035 m
.11414 .39035 L
s
.11039 .44457 m
.11414 .44457 L
s
.11039 .47168 m
.11414 .47168 L
s
.11039 .49879 m
.11414 .49879 L
s
.11039 .06502 m
.11414 .06502 L
s
.11039 .03791 m
.11414 .03791 L
s
.11039 .0108 m
.11414 .0108 L
s
.11039 .55301 m
.11414 .55301 L
s
.11039 .58012 m
.11414 .58012 L
s
.11039 .60723 m
.11414 .60723 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -126.812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.812 moveto
(@) show
81.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.812 moveto
(D) show
93.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10.6) show
141.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
147.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
159.000 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
163.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
172.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
190.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02691 .30902 L
.03029 .30902 L
.03347 .30902 L
.03652 .30902 L
.03978 .30902 L
.04291 .30902 L
.04623 .30902 L
.04944 .30902 L
.05252 .30902 L
.0558 .30902 L
.05896 .30902 L
.062 .30902 L
.06523 .30902 L
.06834 .30902 L
.07165 .30902 L
.07484 .30902 L
.0779 .30902 L
.08117 .30902 L
.08431 .30902 L
.08765 .30902 L
.09086 .30902 L
.09396 .30902 L
.09725 .30902 L
.10042 .30902 L
.10346 .30902 L
.10671 .30902 L
.10983 .30902 L
.11315 .30902 L
.11635 .30902 L
.11943 .30902 L
.1227 .30902 L
.12433 .30902 L
.12585 .30902 L
.12733 .30902 L
.12813 .30902 L
.12888 .30902 L
.12926 .30902 L
.12966 .30902 L
.12988 .30902 L
.1301 .30902 L
.13029 .30902 L
.1304 .30902 L
.1305 .30902 L
.13059 .30902 L
.13068 .30902 L
.13077 .30902 L
.13085 .30902 L
.13094 .30902 L
.13104 .30902 L
Mistroke
.13114 .30902 L
.13122 .30902 L
.13142 .30902 L
.13159 .30902 L
.13199 .30902 L
.13238 .30902 L
.13279 .30902 L
.13354 .30902 L
.13433 .30902 L
.13521 .30902 L
.13603 .30902 L
.13678 .30902 L
.13846 .30902 L
.13999 .30902 L
.14166 .30902 L
.14325 .30902 L
.14494 .30902 L
.14797 .30902 L
.14953 .30902 L
.1512 .30902 L
.15451 .30902 L
.15769 .30902 L
.16076 .30902 L
.16402 .30902 L
.16715 .30902 L
.17049 .30902 L
.1737 .30902 L
.1768 .30902 L
.18008 .30902 L
.18172 .30902 L
.18325 .30902 L
.18472 .30902 L
.18554 .30902 L
.1863 .30902 L
.18668 .30902 L
.18689 .30902 L
.18709 .30902 L
.18727 .30902 L
.18744 .30902 L
.18753 .30902 L
.18763 .30902 L
.18772 .30902 L
.18783 .30902 L
.18788 .30902 L
.18794 .30902 L
.18804 .30902 L
.18815 .30902 L
.18824 .30902 L
.18835 .30902 L
.18846 .30902 L
Mistroke
.18869 .30902 L
.18889 .30902 L
.1891 .30902 L
.18949 .30902 L
.18991 .30902 L
.1903 .30902 L
.19119 .30902 L
.19197 .30902 L
.1928 .30902 L
.19363 .30902 L
.19452 .30902 L
.19614 .30902 L
.19774 .30902 L
.19943 .30902 L
.20248 .30902 L
.20405 .30902 L
.20573 .30902 L
.20905 .30902 L
.21225 .30902 L
.21533 .30902 L
.21861 .30902 L
.22176 .30902 L
.22479 .30902 L
.22648 .30902 L
.22721 .30902 L
.22802 .30902 L
.2288 .30902 L
.22918 .30902 L
.22953 .30902 L
.22973 .30902 L
.22994 .30902 L
.23011 .30902 L
.2303 .30902 L
.2304 .30902 L
.23051 .30902 L
.23057 .30902 L
.23063 .30902 L
.23068 .30902 L
.23073 .30902 L
.23083 .30902 L
.23093 .30902 L
.23103 .30902 L
.23113 .30902 L
.23123 .30902 L
.23134 .30902 L
.23145 .30902 L
.23156 .30902 L
.23175 .30902 L
.23195 .30902 L
.23242 .30902 L
Mistroke
.23285 .30902 L
.23368 .30902 L
.23447 .30902 L
.23525 .30902 L
.23607 .30902 L
.23755 .30902 L
.23912 .30902 L
.24059 .30902 L
.2437 .30902 L
.24701 .30902 L
.25019 .30902 L
.25326 .30902 L
.25652 .30902 L
.25966 .30902 L
.26126 .30902 L
.263 .30902 L
.26381 .30902 L
.26467 .30902 L
.2654 .30902 L
.26561 .30902 L
.26582 .30902 L
.26601 .30902 L
.26621 .30902 L
.26642 .30902 L
.26653 .30902 L
.26663 .30902 L
.26673 .30902 L
.26682 .30902 L
.26692 .30902 L
.26703 .30902 L
.26713 .30902 L
.26719 .30902 L
.26725 .30902 L
.26745 .30902 L
.26757 .30902 L
.26769 .30902 L
.26792 .30902 L
.26832 .30902 L
.26876 .30902 L
.26953 .30902 L
.27029 .30902 L
.2711 .30902 L
.27257 .30902 L
.27427 .30902 L
.27588 .30902 L
.27895 .30902 L
.28222 .30901 L
.28536 .30901 L
.2887 .309 L
.29192 .309 L
Mistroke
.2934 .30899 L
.29424 .30899 L
.29502 .30899 L
.29586 .30899 L
.29662 .30899 L
.29704 .30899 L
.29744 .30899 L
.29766 .30899 L
.29786 .30899 L
.29796 .30899 L
.29808 .30899 L
.29814 .30899 L
.2982 .30899 L
.29826 .30899 L
.29831 .30899 L
.29842 .30899 L
.29851 .30899 L
.2986 .30899 L
.29869 .30899 L
.2988 .30899 L
.29891 .30899 L
.2991 .30899 L
.29928 .30899 L
.29945 .30899 L
.29983 .30899 L
.30025 .30899 L
.30064 .30899 L
.3015 .30899 L
.30229 .30899 L
.30303 .309 L
.30469 .309 L
.30619 .309 L
.30784 .30901 L
.31106 .30903 L
.31416 .30905 L
.31746 .30908 L
.32064 .3091 L
.32224 .30911 L
.3237 .30912 L
.3245 .30912 L
.32527 .30913 L
.32569 .30913 L
.32589 .30913 L
.32607 .30913 L
.32628 .30913 L
.32638 .30913 L
.3265 .30913 L
.32656 .30913 L
.32662 .30913 L
.32668 .30913 L
Mistroke
.32673 .30913 L
.32684 .30913 L
.3269 .30913 L
.32695 .30913 L
.32704 .30913 L
.32713 .30913 L
.32723 .30913 L
.32734 .30913 L
.32756 .30913 L
.32775 .30913 L
.32813 .30913 L
.32849 .30912 L
.32929 .30912 L
.32975 .30912 L
.33016 .30912 L
.33166 .3091 L
.33252 .30909 L
.33332 .30908 L
.33642 .30903 L
.33973 .30895 L
.34291 .30886 L
.34597 .30877 L
.34767 .30872 L
.34922 .30869 L
.35 .30868 L
.3504 .30867 L
.35084 .30866 L
.35121 .30866 L
.35163 .30866 L
.35181 .30866 L
.352 .30865 L
.35219 .30865 L
.35236 .30865 L
.35246 .30865 L
.35256 .30865 L
.35267 .30865 L
.35273 .30865 L
.35278 .30865 L
.35287 .30865 L
.35297 .30865 L
.35307 .30865 L
.35317 .30865 L
.35329 .30865 L
.3534 .30865 L
.3536 .30865 L
.35382 .30866 L
.35406 .30866 L
.35446 .30866 L
.3549 .30867 L
.35567 .30868 L
Mistroke
.35643 .3087 L
.35724 .30872 L
.35871 .30878 L
.3604 .30886 L
.36201 .30897 L
.36508 .30921 L
.36834 .30951 L
.37148 .30978 L
.37319 .3099 L
.37398 .30994 L
.37481 .30998 L
.37518 .30999 L
.37558 .31001 L
.37581 .31001 L
.37601 .31002 L
.37623 .31002 L
.37642 .31002 L
.3766 .31002 L
.37669 .31002 L
.37679 .31003 L
.37688 .31003 L
.37699 .31003 L
.37709 .31003 L
.37718 .31003 L
.37727 .31003 L
.37735 .31003 L
.37744 .31003 L
.37753 .31002 L
.37773 .31002 L
.3779 .31002 L
.37829 .31001 L
.3787 .31 L
.37906 .30999 L
.37944 .30997 L
.3803 .30992 L
.38111 .30985 L
.38274 .30968 L
.38423 .30946 L
.38742 .30885 L
.39048 .30813 L
.39375 .30736 L
.39526 .30706 L
.39689 .3068 L
.39733 .30675 L
.39779 .3067 L
.39821 .30667 L
.39861 .30664 L
.39898 .30662 L
.39919 .30662 L
.39929 .30661 L
Mistroke
.39938 .30661 L
.39944 .30661 L
.39949 .30661 L
.39959 .30661 L
.39965 .30661 L
.39971 .30661 L
.39977 .30661 L
.39982 .30661 L
.39991 .30661 L
.40002 .30661 L
.40007 .30661 L
.40013 .30661 L
.40023 .30661 L
.40044 .30662 L
.40066 .30663 L
.40105 .30665 L
.40148 .30668 L
.40195 .30673 L
.40278 .30685 L
.40356 .307 L
.40519 .30743 L
.40668 .30796 L
.40988 .30945 L
.41295 .31114 L
.41466 .31208 L
.41622 .31284 L
.417 .31317 L
.41784 .31349 L
.41863 .31374 L
.41936 .31391 L
.41973 .31398 L
.42013 .31404 L
.42036 .31407 L
.42057 .31409 L
.42076 .3141 L
.42087 .3141 L
.42097 .31411 L
.42107 .31411 L
.42117 .31411 L
.42127 .31411 L
.42136 .31411 L
.42147 .31411 L
.42153 .31411 L
.42158 .3141 L
.42179 .31409 L
.42191 .31408 L
.42201 .31407 L
.42221 .31405 L
.42266 .31398 L
.42304 .31391 L
Mistroke
.42345 .3138 L
.42427 .31352 L
.42504 .31318 L
.42576 .3128 L
.42739 .31167 L
.42888 .31036 L
.43208 .30694 L
.43515 .30343 L
.43671 .30185 L
.43754 .30112 L
.43843 .30045 L
.43927 .29994 L
.43965 .29976 L
.44005 .29959 L
.44044 .29947 L
.44079 .29939 L
.44099 .29935 L
.44117 .29933 L
.44127 .29932 L
.44133 .29932 L
.44138 .29931 L
.44148 .29931 L
.44158 .29931 L
.44167 .29931 L
.44178 .29931 L
.44188 .29932 L
.44197 .29932 L
.44215 .29935 L
.44233 .29938 L
.44255 .29942 L
.44276 .29948 L
.44315 .29961 L
.44386 .29997 L
.44462 .3005 L
.44538 .30119 L
.44622 .30212 L
.44791 .30454 L
.45116 .31074 L
.45429 .31748 L
.45588 .32062 L
.45672 .32208 L
.45761 .32343 L
.4584 .32442 L
.45882 .32485 L
.45928 .32524 L
.45969 .32553 L
.45987 .32563 L
.46007 .32573 L
.46025 .3258 L
.46043 .32586 L
Mistroke
.46054 .32589 L
.46063 .32591 L
.46073 .32592 L
.46081 .32593 L
.46091 .32594 L
.46101 .32595 L
.4611 .32595 L
.46119 .32594 L
.46129 .32593 L
.46134 .32592 L
.4614 .32592 L
.4615 .3259 L
.4616 .32587 L
.46179 .32581 L
.462 .32573 L
.46242 .32548 L
.4628 .3252 L
.46314 .32488 L
.46391 .32394 L
.46469 .32267 L
.46542 .32123 L
.46708 .31705 L
.47021 .30658 L
.47354 .29426 L
.47521 .28886 L
.47594 .28684 L
.47675 .28495 L
.47752 .2835 L
.47789 .28294 L
.47825 .28251 L
.47844 .28231 L
.47865 .28212 L
.47884 .28198 L
.47901 .28188 L
.47922 .28179 L
.47933 .28175 L
.47938 .28174 L
.47944 .28173 L
.47954 .28171 L
.47963 .28171 L
.47973 .28171 L
.47978 .28171 L
.47983 .28172 L
.47994 .28173 L
.47999 .28175 L
.48004 .28176 L
.48024 .28184 L
.48034 .2819 L
.48046 .28197 L
.48067 .28213 L
Mistroke
.48109 .28255 L
.48147 .28307 L
.48219 .2844 L
.48296 .28629 L
.48454 .29172 L
.48602 .2984 L
.48915 .31612 L
.49075 .32573 L
.49249 .3354 L
.4933 .33938 L
.49416 .34306 L
.49496 .3459 L
.4957 .34791 L
.49608 .34873 L
.49645 .34935 L
.49664 .3496 L
.49684 .34981 L
.49696 .34991 L
.49706 .34999 L
.49716 .35005 L
.49727 .3501 L
.49736 .35013 L
.49746 .35015 L
.49755 .35016 L
.49763 .35016 L
.49773 .35014 L
.49782 .35012 L
.49793 .35008 L
.49803 .35002 L
.4982 .34989 L
.49837 .34974 L
.49874 .34925 L
.49911 .34856 L
.49951 .34761 L
.50024 .34533 L
.5011 .3417 L
.5019 .33754 L
.50508 .31416 L
.50815 .28668 L
.50986 .27233 L
.51141 .26159 L
.51218 .25738 L
.51259 .25554 L
.51302 .2539 L
.5134 .25273 L
.5136 .25221 L
.51382 .25174 L
.51401 .25138 L
.51419 .25112 L
.51428 .25102 L
Mistroke
.51437 .25092 L
.51446 .25085 L
.51455 .25079 L
.51464 .25075 L
.51473 .25072 L
.51483 .25071 L
.51494 .25072 L
.51503 .25075 L
.51512 .25079 L
.51522 .25086 L
.5153 .25093 L
.51551 .25116 L
.51573 .25152 L
.51613 .25242 L
.51656 .25374 L
.51701 .25554 L
.51782 .2598 L
.51858 .26494 L
.51939 .27162 L
.52086 .28637 L
.52417 .32727 L
.52583 .34798 L
.52736 .36488 L
.52885 .37753 L
.52927 .3803 L
.52968 .38252 L
.53007 .38427 L
.53043 .38556 L
.53062 .3861 L
.5308 .38651 L
.531 .38685 L
.53111 .387 L
.53121 .3871 L
.53131 .38718 L
.53136 .3872 L
.53142 .38722 L
.53152 .38724 L
.53161 .38723 L
.53166 .38721 L
.53172 .38718 L
.53182 .38711 L
.53193 .387 L
.53204 .38685 L
.53224 .3865 L
.53241 .38608 L
.53281 .38482 L
.53318 .38324 L
.53353 .38139 L
.53431 .37596 L
.53513 .36839 L
Mistroke
.53662 .35059 L
.53966 .30215 L
.54135 .27294 L
.5429 .24831 L
.54367 .23761 L
.5445 .22752 L
.54528 .21983 L
.54602 .21437 L
.54638 .21237 L
.54677 .21074 L
.54698 .21009 L
.5471 .20981 L
.54721 .20959 L
.54731 .20943 L
.5474 .20931 L
.5475 .20922 L
.54755 .20919 L
.5476 .20917 L
.5477 .20916 L
.54776 .20917 L
.54781 .20919 L
.54791 .20926 L
.54797 .20932 L
.54802 .20939 L
.54812 .20954 L
.54822 .20974 L
.54841 .21021 L
.54863 .21094 L
.54887 .21193 L
.54929 .21425 L
.54972 .21734 L
.55012 .2208 L
.55101 .23074 L
.55263 .25554 L
.5558 .32096 L
.55885 .3851 L
.56041 .41025 L
.56086 .41589 L
.56129 .42047 L
.56167 .42388 L
.56209 .42689 L
.56228 .428 L
.56249 .42899 L
.56267 .42968 L
.56287 .43026 L
.56297 .4305 L
.56307 .43067 L
.56313 .43074 L
.56318 .43079 L
.56324 .43083 L
Mistroke
.5633 .43086 L
.56339 .43087 L
.56348 .43083 L
.56358 .43074 L
.56369 .4306 L
.56378 .43042 L
.56386 .43023 L
.56405 .42965 L
.56423 .42896 L
.56439 .42816 L
.56476 .42588 L
.56517 .4226 L
.566 .41335 L
.56675 .4022 L
.56843 .36886 L
.57165 .28537 L
.57313 .24615 L
.57475 .20863 L
.57553 .19401 L
.57636 .18143 L
.57682 .176 L
.57723 .17206 L
.57743 .17052 L
.57765 .16911 L
.57784 .16811 L
.57794 .16768 L
.57805 .16729 L
.57815 .16698 L
.57825 .16672 L
.57835 .16654 L
.57844 .16643 L
.57853 .16636 L
.57862 .16635 L
.57871 .16639 L
.57881 .16648 L
.57891 .16664 L
.57901 .16688 L
.57921 .16749 L
.57941 .16841 L
.57964 .16972 L
.58006 .17301 L
.58051 .17773 L
.58133 .18933 L
.58214 .20464 L
.58303 .22506 L
.58464 .27009 L
.58792 .37326 L
.58954 .41825 L
.59034 .43628 L
.59107 .44982 L
Mistroke
.59177 .45984 L
.59213 .46363 L
.59252 .46676 L
.59273 .46798 L
.59292 .46883 L
.59302 .46918 L
.59307 .46934 L
.59313 .46948 L
.59318 .46959 L
.59324 .46968 L
.59334 .46979 L
.59343 .46983 L
.59352 .4698 L
.59363 .46969 L
.59373 .46951 L
.59382 .46929 L
.5939 .46903 L
.59409 .46823 L
.59431 .46703 L
.5945 .46563 L
.59494 .46145 L
.59533 .45661 L
.59574 .45034 L
.59724 .41827 L
.59881 .3714 L
.60029 .32005 L
.60341 .2107 L
.60423 .18693 L
.60512 .16527 L
.60552 .15703 L
.60596 .14957 L
.60636 .14384 L
.60673 .13971 L
.6071 .13671 L
.60728 .13561 L
.60739 .13512 L
.60749 .13474 L
.60759 .13442 L
.60769 .13421 L
.60779 .13407 L
.60785 .13403 L
.60791 .13402 L
.608 .13406 L
.6081 .13418 L
.6082 .1344 L
.6083 .13468 L
.60849 .13547 L
.60867 .1365 L
.609 .13917 L
.60937 .1431 L
Mistroke
.60976 .14861 L
.6106 .16418 L
.61135 .1826 L
.61303 .23618 L
.61625 .36174 L
.61773 .41549 L
.61857 .44146 L
.61936 .46163 L
.62013 .47714 L
.62056 .48368 L
.62096 .4882 L
.62118 .49009 L
.62138 .49146 L
.62149 .49207 L
.6216 .49253 L
.62171 .49291 L
.62177 .49306 L
.62183 .49319 L
.62194 .49332 L
.62199 .49335 L
.62205 .49334 L
.62215 .49326 L
.62221 .49318 L
.62226 .49307 L
.62236 .49281 L
.62246 .49242 L
.62265 .49146 L
.62284 .49016 L
.62305 .4884 L
.62342 .48426 L
.62385 .47775 L
.62425 .47035 L
.62512 .44979 L
.62594 .4252 L
.62902 .30485 L
.63057 .24017 L
.6314 .20865 L
.63229 .17857 L
.63314 .15486 L
.63351 .14623 L
.63392 .13813 L
.63428 .13219 L
.63466 .12717 L
.63487 .12499 L
.63507 .12339 L
.63526 .12215 L
.63536 .12167 L
.63544 .12132 L
.63554 .12102 L
.63563 .1208 L
Mistroke
.63573 .12068 L
.63581 .12065 L
.63592 .12071 L
.63601 .12085 L
.63611 .12111 L
.63617 .12131 L
.63622 .12151 L
.63643 .12256 L
.63665 .12416 L
.63705 .12828 L
.63742 .13355 L
.63782 .14054 L
.63853 .15654 L
.64011 .20613 L
.64158 .2649 L
.64471 .39763 L
.64553 .42741 L
.64641 .45484 L
.64682 .46536 L
.64725 .47497 L
.64766 .48243 L
.64803 .48789 L
.6484 .49195 L
.64858 .49349 L
.64878 .49476 L
.64889 .49527 L
.64899 .49563 L
.64904 .49579 L
.6491 .49592 L
.64921 .49608 L
.6493 .49613 L
.64941 .49606 L
.6495 .49592 L
.6496 .49567 L
.64969 .49532 L
.64979 .49489 L
.64996 .49385 L
.65015 .49239 L
.65036 .49038 L
.65072 .48572 L
.65106 .48022 L
.65184 .46379 L
.65256 .4437 L
.65421 .38443 L
.65731 .2517 L
.65889 .19219 L
.65978 .16541 L
.66021 .15486 L
.66061 .14639 L
.661 .13974 L
Mistroke
.6612 .13681 L
.66142 .13416 L
.6616 .13229 L
.6618 .13062 L
.66198 .12946 L
.66207 .12902 L
.66215 .12868 L
.66225 .12836 L
.6623 .12823 L
.66236 .12813 L
.66247 .12803 L
.66256 .12804 L
.66266 .12814 L
.66276 .12835 L
.66285 .12865 L
.66294 .129 L
.66314 .1301 L
.66335 .13176 L
.66358 .134 L
.66379 .13656 L
.66419 .14265 L
.66463 .15102 L
.66543 .17057 L
.66691 .21986 L
.67019 .35543 L
.67182 .41613 L
.67261 .44003 L
.67334 .45751 L
.67405 .46991 L
.67441 .47431 L
.67461 .47624 L
.6748 .47766 L
.6749 .47826 L
.67501 .4788 L
.67511 .4792 L
.6752 .47948 L
.67528 .47966 L
.67537 .47977 L
.67547 .47979 L
.67556 .47973 L
.67567 .47955 L
.67577 .47927 L
.67585 .47894 L
.67595 .47848 L
.67617 .47712 L
.67637 .47542 L
.67678 .47076 L
.67722 .46392 L
.67802 .44705 L
.67952 .40238 L
Mistroke
.68281 .27343 L
.68446 .21425 L
.68526 .1909 L
.68599 .17387 L
.68635 .16707 L
.68675 .16104 L
.68712 .15668 L
.68729 .15517 L
.68746 .15384 L
.68756 .15324 L
.68765 .15277 L
.68774 .15238 L
.68783 .15209 L
.68793 .15184 L
.68798 .15174 L
.68803 .15167 L
.68814 .15162 L
.68823 .15167 L
.68833 .15182 L
.68843 .15205 L
.68854 .15241 L
.68865 .15291 L
.68884 .15402 L
.68904 .15563 L
.68946 .16014 L
.68986 .16591 L
.69061 .18041 L
.69141 .20082 L
.69229 .2277 L
.69556 .34728 L
.69634 .37421 L
.69718 .40002 L
.69791 .41878 L
.69832 .42771 L
.69871 .4348 L
.69911 .4409 L
.69948 .44522 L
.69966 .44697 L
.69987 .44851 L
.69998 .4492 L
.70008 .44973 L
.70018 .45014 L
.70029 .45048 L
.70038 .4507 L
.70046 .45083 L
.70054 .45089 L
.70062 .4509 L
.70071 .45083 L
.7008 .4507 L
.70089 .45048 L
Mistroke
.70099 .45017 L
.70109 .44977 L
.70119 .44924 L
.70138 .44804 L
.70174 .44494 L
.70213 .4402 L
.7025 .4346 L
.70334 .41801 L
.70503 .37129 L
.70815 .26683 L
.70897 .24227 L
.70986 .21937 L
.7107 .20238 L
.71107 .19646 L
.71148 .19131 L
.71167 .18927 L
.71188 .18746 L
.71207 .1861 L
.71225 .18512 L
.71242 .18443 L
.71251 .18416 L
.7126 .18397 L
.71269 .18383 L
.71279 .18377 L
.71289 .18378 L
.71298 .18387 L
.71307 .18403 L
.71318 .1843 L
.71327 .18463 L
.71336 .18499 L
.71358 .18616 L
.71378 .18762 L
.71419 .19151 L
.71463 .1972 L
.71546 .21161 L
.71622 .22833 L
.7179 .27473 L
.71958 .32567 L
.72112 .36823 L
.7219 .38599 L
.72263 .39937 L
.72303 .40522 L
.72339 .40959 L
.72379 .41333 L
.72402 .41488 L
.72422 .41601 L
.72432 .4164 L
.72442 .41675 L
.72451 .41702 L
.72459 .4172 L
Mistroke
.72469 .41734 L
.72475 .41739 L
.7248 .41741 L
.7249 .4174 L
.725 .41731 L
.72506 .41723 L
.72511 .41713 L
.72523 .41684 L
.72533 .41651 L
.72544 .41606 L
.72562 .4151 L
.72583 .41375 L
.7262 .41056 L
.72659 .40611 L
.72731 .39556 L
.72901 .35978 L
.73063 .31793 L
.73209 .27997 L
.73292 .26059 L
.7337 .24491 L
.73447 .23256 L
.73486 .22751 L
.73529 .22307 L
.73572 .21983 L
.73595 .21857 L
.73607 .21809 L
.73617 .21772 L
.73627 .21744 L
.73632 .21732 L
.73637 .21721 L
.73647 .21706 L
.73656 .21698 L
.73666 .21696 L
.73676 .217 L
.73686 .21711 L
.73692 .2172 L
.73698 .21731 L
.73708 .21757 L
.73718 .21788 L
.73736 .21862 L
.73756 .21965 L
.73777 .22104 L
.73815 .22425 L
.7385 .22795 L
.73931 .239 L
.74017 .25392 L
.74322 .32076 L
.74409 .33934 L
.74492 .35495 L
.74573 .36759 L
Mistroke
.74608 .37221 L
.74647 .37656 L
.74682 .37978 L
.7472 .3825 L
.7474 .38366 L
.74759 .3845 L
.74778 .38511 L
.74787 .38535 L
.74797 .38555 L
.74802 .38563 L
.74808 .38571 L
.74818 .38579 L
.74828 .38581 L
.74838 .38578 L
.74848 .38569 L
.74853 .38562 L
.74859 .38553 L
.7487 .3853 L
.74881 .38499 L
.74902 .38422 L
.74922 .38327 L
.7496 .38092 L
.74996 .37791 L
.75037 .37382 L
.75119 .36335 L
.75267 .33888 L
.75435 .30697 L
.75589 .27943 L
.75668 .26772 L
.75741 .25878 L
.75817 .25183 L
.75857 .24922 L
.75879 .24809 L
.759 .24728 L
.75918 .24672 L
.75929 .24647 L
.75939 .2463 L
.75949 .24616 L
.75958 .24608 L
.75964 .24605 L
.75969 .24604 L
.7598 .24605 L
.75989 .24612 L
.75998 .24621 L
.76008 .24637 L
.76018 .24656 L
.76035 .24702 L
.76054 .24766 L
.76096 .24971 L
.7614 .25272 L
Mistroke
.7622 .26009 L
.76378 .28049 L
.76525 .30336 L
.76675 .3263 L
.76754 .33694 L
.76838 .34642 L
.7688 .35034 L
.76926 .35392 L
.76969 .35647 L
.77008 .35822 L
.77028 .35885 L
.77039 .35913 L
.77049 .35935 L
.77058 .35952 L
.77067 .35964 L
.77076 .35974 L
.77086 .3598 L
.77091 .35982 L
.77097 .35983 L
.77107 .35981 L
.77112 .35979 L
.77117 .35975 L
.77123 .3597 L
.77129 .35963 L
.7714 .35947 L
.7715 .35927 L
.7717 .35879 L
.77191 .35811 L
.7721 .35733 L
.77247 .35548 L
.77329 .34969 L
.774 .34309 L
.77477 .33466 L
.77634 .31496 L
.77807 .29361 L
.77886 .28518 L
.77971 .27779 L
.78012 .27493 L
.78051 .27269 L
.78086 .27109 L
.78124 .2698 L
.78143 .26934 L
.78153 .26914 L
.78163 .26897 L
.78172 .26885 L
.78182 .26876 L
.78192 .26869 L
.782 .26866 L
.78205 .26865 L
.78211 .26865 L
Mistroke
.78221 .26868 L
.78231 .26874 L
.7824 .26883 L
.7825 .26895 L
.78261 .26912 L
.78283 .26959 L
.78305 .2702 L
.78325 .27089 L
.78371 .27287 L
.78452 .27783 L
.78605 .29087 L
.78772 .30782 L
.78927 .32288 L
.7901 .32955 L
.79053 .33251 L
.79099 .33518 L
.7914 .33712 L
.79161 .33798 L
.79184 .33876 L
.79205 .33937 L
.79224 .33981 L
.79243 .34016 L
.79262 .3404 L
.7927 .34048 L
.7928 .34055 L
.7929 .34059 L
.793 .34061 L
.79309 .3406 L
.79317 .34058 L
.79326 .34053 L
.79335 .34046 L
.79344 .34036 L
.79354 .34024 L
.79373 .33994 L
.79394 .33948 L
.79414 .33896 L
.79453 .33765 L
.79495 .3359 L
.79569 .3319 L
.79736 .31994 L
.79896 .30702 L
.80041 .29636 L
.80116 .29189 L
.80198 .28814 L
.80243 .28664 L
.80263 .28611 L
.80284 .28561 L
.80303 .28526 L
.80324 .28498 L
.80335 .28485 L
Mistroke
.80346 .28477 L
.80356 .28471 L
.80366 .28466 L
.80376 .28464 L
.80382 .28464 L
.80387 .28465 L
.80396 .28467 L
.80406 .28472 L
.80415 .28477 L
.80424 .28484 L
.80443 .28505 L
.80463 .28536 L
.80482 .28572 L
.80525 .28677 L
.806 .28943 L
.80672 .29274 L
.80979 .31127 L
.81135 .31985 L
.81177 .32177 L
.81223 .32356 L
.81263 .32486 L
.81306 .326 L
.81326 .32642 L
.81348 .3268 L
.81366 .32707 L
.81386 .32729 L
.81398 .32739 L
.81409 .32747 L
.81419 .32752 L
.81425 .32754 L
.8143 .32755 L
.8144 .32757 L
.81446 .32757 L
.81451 .32756 L
.81461 .32754 L
.81471 .32751 L
.8148 .32746 L
.81489 .3274 L
.81508 .32723 L
.81526 .32702 L
.81543 .32678 L
.8158 .32608 L
.81621 .3251 L
.81698 .32271 L
.81781 .31939 L
.8195 .31146 L
.8212 .30359 L
.82201 .30047 L
.82275 .29813 L
.82311 .29721 L
Mistroke
.82352 .29637 L
.82392 .29574 L
.82414 .29548 L
.82435 .2953 L
.82454 .29518 L
.82463 .29514 L
.82473 .29511 L
.82482 .29509 L
.82492 .29508 L
.825 .29509 L
.82508 .2951 L
.82519 .29512 L
.82528 .29516 L
.82538 .29521 L
.82549 .29528 L
.82567 .29542 L
.82587 .29563 L
.82629 .29621 L
.82669 .29694 L
.82743 .29871 L
.82911 .30413 L
.83072 .31001 L
.83218 .31473 L
.833 .31678 L
.83337 .31754 L
.83376 .3182 L
.83397 .31848 L
.83419 .31875 L
.83439 .31895 L
.83457 .3191 L
.83479 .31923 L
.83491 .31928 L
.83497 .3193 L
.83503 .31932 L
.83513 .31934 L
.83523 .31935 L
.83533 .31935 L
.83539 .31935 L
.83545 .31934 L
.83554 .31932 L
.83564 .31929 L
.83574 .31926 L
.83583 .31922 L
.83604 .31909 L
.83624 .31893 L
.83664 .31851 L
.83707 .31791 L
.83785 .31649 L
.83856 .31488 L
.8402 .31054 L
Mistroke
.84173 .30649 L
.84248 .30478 L
.8432 .30343 L
.84359 .30283 L
.84402 .30228 L
.84441 .30191 L
.84477 .30165 L
.84497 .30156 L
.84514 .3015 L
.84524 .30147 L
.84534 .30146 L
.84539 .30145 L
.84544 .30145 L
.84554 .30144 L
.84564 .30145 L
.84574 .30146 L
.84583 .30148 L
.84592 .3015 L
.84609 .30156 L
.84627 .30164 L
.84646 .30175 L
.84667 .30191 L
.84706 .30225 L
.84792 .30335 L
.84962 .30637 L
.85123 .30962 L
.85206 .31116 L
.85284 .3124 L
.85354 .31331 L
.8539 .31368 L
.8543 .31401 L
.8547 .31426 L
.85492 .31436 L
.85502 .3144 L
.85512 .31443 L
.85522 .31445 L
.85532 .31447 L
.85541 .31449 L
.85549 .3145 L
.85558 .3145 L
.85568 .3145 L
.85578 .3145 L
.85588 .31449 L
.85598 .31447 L
.85609 .31445 L
.8563 .31438 L
.8565 .3143 L
.85669 .31421 L
.85711 .31394 L
.85756 .31356 L
Mistroke
.85839 .31268 L
.85928 .31151 L
.8609 .30914 L
.86246 .30704 L
.86335 .30612 L
.86378 .30577 L
.86418 .3055 L
.86457 .30531 L
.86478 .30523 L
.86498 .30517 L
.86508 .30515 L
.86517 .30513 L
.86525 .30512 L
.86534 .30511 L
.86543 .3051 L
.86552 .30509 L
.86561 .30509 L
.86571 .30509 L
.86576 .30509 L
.86582 .3051 L
.86593 .30511 L
.86603 .30512 L
.86612 .30514 L
.86633 .30519 L
.86656 .30526 L
.86694 .30542 L
.86735 .30565 L
.86816 .30624 L
.86891 .30692 L
.87058 .30867 L
.87138 .3095 L
.87224 .3103 L
.87297 .31088 L
.87377 .31137 L
.8742 .31156 L
.87439 .31162 L
.8746 .31168 L
.87478 .31173 L
.87498 .31176 L
.87508 .31178 L
.87518 .31179 L
.87528 .31179 L
.87538 .3118 L
.87546 .3118 L
.87555 .3118 L
.87565 .3118 L
.87574 .31179 L
.87582 .31178 L
.8759 .31178 L
.87607 .31175 L
Mistroke
.87625 .31172 L
.87644 .31167 L
.87683 .31155 L
.87726 .31138 L
.87766 .31118 L
.87841 .31073 L
.88009 .3095 L
.88156 .30842 L
.8824 .3079 L
.88318 .30751 L
.88357 .30736 L
.88395 .30724 L
.88415 .30719 L
.88438 .30715 L
.88458 .30711 L
.88477 .30709 L
.88488 .30708 L
.88493 .30708 L
.88499 .30707 L
.88504 .30707 L
.8851 .30707 L
.8852 .30707 L
.8853 .30707 L
.8854 .30707 L
.8855 .30707 L
.88559 .30708 L
.8857 .30709 L
.8858 .3071 L
.88604 .30713 L
.88624 .30717 L
.88646 .30721 L
.88721 .30744 L
.88803 .30777 L
.88949 .30851 L
.89107 .30934 L
.89191 .30972 L
.89237 .3099 L
.8928 .31005 L
.89322 .31016 L
.89367 .31026 L
.89386 .31029 L
.89407 .31032 L
.89425 .31034 L
.89445 .31036 L
.89455 .31036 L
.89465 .31037 L
.89474 .31037 L
.89483 .31037 L
.89494 .31037 L
.89499 .31037 L
Mistroke
.89505 .31037 L
.89515 .31037 L
.89524 .31036 L
.89533 .31036 L
.89543 .31035 L
.8956 .31033 L
.89598 .31029 L
.89639 .31022 L
.89675 .31014 L
.89757 .30991 L
.89904 .30939 L
.90071 .30878 L
.90144 .30855 L
.90225 .30834 L
.90262 .30826 L
.90302 .30819 L
.90321 .30816 L
.9034 .30814 L
.90358 .30812 L
.90374 .30811 L
.90393 .3081 L
.90404 .30809 L
.90414 .30809 L
.90423 .30809 L
.90431 .30809 L
.90441 .30809 L
.9045 .30809 L
.9046 .30809 L
.90471 .30809 L
.90481 .30809 L
.9049 .3081 L
.90512 .30811 L
.90533 .30813 L
.9057 .30817 L
.90611 .30822 L
.90693 .30837 L
.90841 .30873 L
.91009 .30916 L
.91083 .30932 L
.91164 .30947 L
.91202 .30952 L
.91242 .30957 L
.9128 .30961 L
.91297 .30962 L
.91315 .30963 L
.91325 .30964 L
.91335 .30964 L
.91345 .30964 L
.91354 .30965 L
.91359 .30965 L
Mistroke
.91365 .30965 L
.91371 .30965 L
.91376 .30965 L
.91382 .30965 L
.91387 .30965 L
.91397 .30965 L
.91407 .30965 L
.91413 .30965 L
.91418 .30965 L
.91427 .30964 L
.91438 .30964 L
.91455 .30963 L
.91474 .30962 L
.91517 .30959 L
.91556 .30955 L
.91631 .30946 L
.91799 .30918 L
.91946 .30893 L
.92029 .3088 L
.92108 .3087 L
.92147 .30867 L
.92184 .30864 L
.92205 .30862 L
.92227 .30861 L
.92248 .3086 L
.92267 .3086 L
.92277 .30859 L
.92289 .30859 L
.92294 .30859 L
.92299 .30859 L
.92309 .30859 L
.92319 .30859 L
.92328 .30859 L
.92338 .30859 L
.92348 .30859 L
.92354 .30859 L
.92359 .30859 L
.92372 .3086 L
.92394 .3086 L
.92414 .30861 L
.92435 .30862 L
.92511 .30867 L
.92592 .30875 L
.92738 .30892 L
.92896 .3091 L
.92979 .30918 L
.93025 .30922 L
.93068 .30925 L
.9311 .30927 L
.93131 .30928 L
Mistroke
.93155 .30929 L
.93174 .30929 L
.93184 .3093 L
.93195 .3093 L
.93205 .3093 L
.93215 .3093 L
.93224 .3093 L
.93233 .3093 L
.93243 .3093 L
.93251 .3093 L
.93261 .3093 L
.93271 .3093 L
.9328 .3093 L
.93288 .3093 L
.93306 .3093 L
.93325 .30929 L
.93345 .30929 L
.93386 .30927 L
.93468 .30923 L
.93543 .30918 L
.93711 .30904 L
.93792 .30898 L
.93877 .30892 L
.9395 .30888 L
.93993 .30886 L
.94031 .30885 L
.94068 .30884 L
.94087 .30883 L
.94108 .30883 L
.94118 .30883 L
.94128 .30883 L
.94134 .30883 L
.9414 .30883 L
.94145 .30883 L
.9415 .30883 L
.94159 .30883 L
.9417 .30883 L
.9418 .30883 L
.9419 .30883 L
.94199 .30883 L
.94209 .30883 L
.94228 .30883 L
.94245 .30884 L
.94262 .30884 L
.94299 .30885 L
.94339 .30886 L
.94495 .30893 L
.94642 .30901 L
.9479 .30908 L
.9483 .3091 L
Mistroke
.94874 .30911 L
.94911 .30912 L
.94952 .30913 L
.94974 .30913 L
.94995 .30914 L
.95015 .30914 L
.95025 .30914 L
.95036 .30914 L
.95046 .30914 L
.95055 .30914 L
.95065 .30914 L
.95075 .30914 L
.95084 .30914 L
.95093 .30914 L
.95102 .30914 L
.95112 .30914 L
.95134 .30914 L
.95158 .30914 L
.95201 .30913 L
.95243 .30912 L
.95282 .30911 L
.95445 .30906 L
.95598 .309 L
.95674 .30898 L
.95746 .30896 L
.95785 .30895 L
.95828 .30895 L
.95847 .30894 L
.95867 .30894 L
.95884 .30894 L
.95903 .30894 L
.95922 .30894 L
.95933 .30894 L
.95943 .30894 L
.95952 .30894 L
.9596 .30894 L
.95969 .30894 L
.95979 .30894 L
.95988 .30894 L
.95999 .30894 L
.96008 .30894 L
.96017 .30894 L
.96039 .30894 L
.9606 .30894 L
.96097 .30894 L
.9613 .30895 L
.96206 .30896 L
.96372 .309 L
.96525 .30903 L
.96602 .30905 L
Mistroke
.96674 .30906 L
.96714 .30906 L
.96735 .30906 L
.96757 .30907 L
.96776 .30907 L
.96786 .30907 L
.96796 .30907 L
.96806 .30907 L
.96815 .30907 L
.96824 .30907 L
.96832 .30907 L
.96842 .30907 L
.96852 .30907 L
.96861 .30907 L
.96869 .30907 L
.96879 .30907 L
.96889 .30907 L
.969 .30907 L
.9691 .30907 L
.96931 .30907 L
.9695 .30907 L
.96993 .30906 L
.97069 .30906 L
.97141 .30905 L
.97291 .30902 L
.9745 .309 L
.9753 .30899 L
.97576 .30899 L
.97619 .30899 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{421.375, 260.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 525.688}, {324.5, 0}} -> {-2.58312*^-7, -6.34248*^6, \
6.65005*^-9, 53093.5}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0.309017 5.42214e-08 [
[.32684 .29652 -16.5 -12.5 ]
[.32684 .29652 16.5 0 ]
[.54329 .29652 -16.5 -12.5 ]
[.54329 .29652 16.5 0 ]
[.75974 .29652 -22.5 -12.5 ]
[.75974 .29652 22.5 0 ]
[.97619 .29652 -16.5 -12.5 ]
[.97619 .29652 16.5 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 64 6 ]
[.09789 .09213 -34.5 -6.25 ]
[.09789 .09213 0 6.25 ]
[.09789 .20057 -34.5 -6.25 ]
[.09789 .20057 0 6.25 ]
[.09789 .41746 -28.5 -6.25 ]
[.09789 .41746 0 6.25 ]
[.09789 .5259 -28.5 -6.25 ]
[.09789 .5259 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -65.8125 0 ]
[.5 .63053 65.8125 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 .30902 m
.32684 .31527 L
s
gsave
.32684 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 .30902 m
.54329 .31527 L
s
gsave
.54329 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 .30902 m
.75974 .31527 L
s
gsave
.75974 .29652 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 .30902 m
.15368 .31277 L
s
.19697 .30902 m
.19697 .31277 L
s
.24026 .30902 m
.24026 .31277 L
s
.28355 .30902 m
.28355 .31277 L
s
.37013 .30902 m
.37013 .31277 L
s
.41342 .30902 m
.41342 .31277 L
s
.45671 .30902 m
.45671 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.58658 .30902 m
.58658 .31277 L
s
.62987 .30902 m
.62987 .31277 L
s
.67316 .30902 m
.67316 .31277 L
s
.71645 .30902 m
.71645 .31277 L
s
.80303 .30902 m
.80303 .31277 L
s
.84632 .30902 m
.84632 .31277 L
s
.88961 .30902 m
.88961 .31277 L
s
.9329 .30902 m
.9329 .31277 L
s
.0671 .30902 m
.0671 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09213 m
.11664 .09213 L
s
gsave
.09789 .09213 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .20057 m
.11664 .20057 L
s
gsave
.09789 .20057 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .41746 m
.11664 .41746 L
s
gsave
.09789 .41746 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .5259 m
.11664 .5259 L
s
gsave
.09789 .5259 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.11039 .11924 m
.11414 .11924 L
s
.11039 .14635 m
.11414 .14635 L
s
.11039 .17346 m
.11414 .17346 L
s
.11039 .22768 m
.11414 .22768 L
s
.11039 .2548 m
.11414 .2548 L
s
.11039 .28191 m
.11414 .28191 L
s
.11039 .33613 m
.11414 .33613 L
s
.11039 .36324 m
.11414 .36324 L
s
.11039 .39035 m
.11414 .39035 L
s
.11039 .44457 m
.11414 .44457 L
s
.11039 .47168 m
.11414 .47168 L
s
.11039 .49879 m
.11414 .49879 L
s
.11039 .06502 m
.11414 .06502 L
s
.11039 .03791 m
.11414 .03791 L
s
.11039 .0108 m
.11414 .0108 L
s
.11039 .55301 m
.11414 .55301 L
s
.11039 .58012 m
.11414 .58012 L
s
.11039 .60723 m
.11414 .60723 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -126.812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.812 moveto
(@) show
81.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.812 moveto
(D) show
93.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10.8) show
141.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
147.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
159.000 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
163.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
172.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
190.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02691 .30902 L
.03029 .30902 L
.03347 .30902 L
.03652 .30902 L
.03978 .30902 L
.04291 .30902 L
.04623 .30902 L
.04944 .30902 L
.05252 .30902 L
.0558 .30902 L
.05896 .30902 L
.062 .30902 L
.06523 .30902 L
.06834 .30902 L
.07165 .30902 L
.07484 .30902 L
.0779 .30902 L
.08117 .30902 L
.08431 .30902 L
.08765 .30902 L
.09086 .30902 L
.09396 .30902 L
.09725 .30902 L
.10042 .30902 L
.10346 .30902 L
.10671 .30902 L
.10983 .30902 L
.11315 .30902 L
.11635 .30902 L
.11943 .30902 L
.1227 .30902 L
.12433 .30902 L
.12512 .30902 L
.12585 .30902 L
.12655 .30902 L
.12731 .30902 L
.12771 .30902 L
.1279 .30902 L
.12808 .30902 L
.12817 .30902 L
.12828 .30902 L
.12837 .30902 L
.12847 .30902 L
.12857 .30902 L
.12863 .30902 L
.12868 .30902 L
.12878 .30902 L
.12888 .30902 L
.12894 .30902 L
Mistroke
.12899 .30902 L
.12909 .30902 L
.12919 .30902 L
.1293 .30902 L
.12951 .30902 L
.1297 .30902 L
.13013 .30902 L
.13034 .30902 L
.13058 .30902 L
.13099 .30902 L
.13142 .30902 L
.1322 .30902 L
.13301 .30902 L
.1339 .30902 L
.13467 .30902 L
.13552 .30902 L
.13711 .30902 L
.1388 .30902 L
.14035 .30902 L
.14203 .30902 L
.14364 .30902 L
.14533 .30902 L
.1484 .30902 L
.14998 .30902 L
.15166 .30902 L
.15499 .30902 L
.15821 .30902 L
.1613 .30902 L
.16459 .30902 L
.16775 .30902 L
.1708 .30902 L
.17404 .30902 L
.17716 .30902 L
.18048 .30902 L
.18214 .30902 L
.18367 .30902 L
.18516 .30902 L
.18592 .30902 L
.18635 .30902 L
.18675 .30902 L
.18693 .30902 L
.18713 .30902 L
.18724 .30902 L
.18734 .30902 L
.18743 .30902 L
.18754 .30902 L
.18759 .30902 L
.18764 .30902 L
.18774 .30902 L
.1878 .30902 L
Mistroke
.18786 .30902 L
.18791 .30902 L
.18796 .30902 L
.18806 .30902 L
.18812 .30902 L
.18817 .30902 L
.18826 .30902 L
.18837 .30902 L
.18856 .30902 L
.18874 .30902 L
.18909 .30902 L
.18948 .30902 L
.18985 .30902 L
.19063 .30902 L
.19136 .30902 L
.19216 .30902 L
.19302 .30902 L
.19473 .30902 L
.19634 .30902 L
.19794 .30902 L
.19942 .30902 L
.20258 .30902 L
.20561 .30902 L
.20884 .30902 L
.21194 .30902 L
.21525 .30902 L
.21843 .30902 L
.22149 .30902 L
.22475 .30902 L
.22625 .30902 L
.22788 .30902 L
.22878 .30902 L
.2296 .30902 L
.23 .30902 L
.23038 .30902 L
.23078 .30902 L
.23099 .30902 L
.23111 .30902 L
.23122 .30902 L
.23132 .30902 L
.23142 .30902 L
.23152 .30902 L
.23158 .30902 L
.23164 .30902 L
.23173 .30902 L
.23183 .30902 L
.23193 .30902 L
.23203 .30902 L
.23214 .30902 L
.23225 .30902 L
Mistroke
.23246 .30902 L
.23268 .30902 L
.23292 .30902 L
.23332 .30902 L
.23376 .30902 L
.23453 .30902 L
.23528 .30902 L
.2361 .30902 L
.23757 .30902 L
.23926 .30902 L
.24087 .30902 L
.24394 .30902 L
.24552 .30902 L
.2472 .30902 L
.25054 .30902 L
.25375 .30902 L
.25685 .30902 L
.26014 .30902 L
.26177 .30902 L
.2633 .30902 L
.26477 .30902 L
.2656 .30902 L
.26635 .30902 L
.26674 .30902 L
.26695 .30902 L
.26715 .30902 L
.26733 .30902 L
.2675 .30902 L
.26768 .30902 L
.26778 .30902 L
.26788 .30902 L
.26799 .30902 L
.26808 .30902 L
.26813 .30902 L
.26819 .30902 L
.26829 .30902 L
.26839 .30902 L
.26849 .30902 L
.26858 .30902 L
.26868 .30902 L
.26889 .30902 L
.26913 .30902 L
.26955 .30902 L
.26997 .30902 L
.27036 .30902 L
.27125 .30902 L
.27203 .30902 L
.27286 .30902 L
.27458 .30902 L
.2762 .30902 L
Mistroke
.27782 .30902 L
.2793 .30902 L
.28247 .30901 L
.28552 .30901 L
.28877 .30901 L
.2919 .309 L
.29349 .309 L
.29522 .309 L
.29603 .309 L
.29688 .309 L
.29769 .309 L
.29842 .30899 L
.29879 .30899 L
.29918 .30899 L
.29938 .30899 L
.29956 .30899 L
.29967 .30899 L
.29977 .30899 L
.29982 .30899 L
.29988 .30899 L
.29994 .30899 L
.29999 .30899 L
.30007 .30899 L
.30016 .30899 L
.30025 .30899 L
.30033 .30899 L
.30042 .30899 L
.30052 .30899 L
.3007 .30899 L
.30089 .30899 L
.30109 .30899 L
.30146 .30899 L
.30185 .30899 L
.30221 .309 L
.30302 .309 L
.30373 .309 L
.30448 .309 L
.30606 .309 L
.30754 .309 L
.31067 .30902 L
.31399 .30903 L
.3172 .30905 L
.32028 .30908 L
.32185 .30909 L
.32357 .3091 L
.32522 .3091 L
.32594 .30911 L
.32672 .30911 L
.32714 .30911 L
.32752 .30911 L
Mistroke
.32789 .30911 L
.3281 .30911 L
.32828 .30911 L
.32839 .30911 L
.3285 .30911 L
.32859 .30911 L
.3287 .30911 L
.32876 .30911 L
.32881 .30911 L
.32887 .30911 L
.32893 .30911 L
.32903 .30911 L
.32909 .30911 L
.32915 .30911 L
.32924 .30911 L
.32933 .30911 L
.32954 .30911 L
.32974 .30911 L
.32996 .30911 L
.33036 .30911 L
.33073 .30911 L
.33157 .30911 L
.33239 .3091 L
.33326 .3091 L
.33498 .30908 L
.33659 .30906 L
.33968 .30901 L
.34297 .30893 L
.34613 .30885 L
.34917 .30878 L
.35086 .30874 L
.35241 .30872 L
.35318 .30871 L
.35361 .3087 L
.35401 .3087 L
.35421 .3087 L
.3544 .3087 L
.35457 .3087 L
.35474 .3087 L
.35484 .3087 L
.35494 .3087 L
.35503 .3087 L
.35512 .3087 L
.35522 .3087 L
.35532 .3087 L
.35537 .3087 L
.35543 .3087 L
.35553 .3087 L
.35563 .3087 L
.35572 .3087 L
Mistroke
.35592 .3087 L
.35611 .3087 L
.35628 .3087 L
.35668 .3087 L
.35712 .30871 L
.35754 .30871 L
.35799 .30872 L
.35881 .30874 L
.35963 .30876 L
.36052 .30878 L
.36214 .30885 L
.36543 .30903 L
.3686 .30926 L
.37164 .30951 L
.37334 .30964 L
.37489 .30974 L
.37565 .30978 L
.37649 .30983 L
.37727 .30986 L
.37801 .30988 L
.37837 .30989 L
.37876 .3099 L
.37897 .3099 L
.37909 .3099 L
.3792 .3099 L
.37929 .3099 L
.37939 .3099 L
.37949 .3099 L
.37954 .3099 L
.37959 .3099 L
.37969 .3099 L
.37975 .3099 L
.3798 .3099 L
.3799 .3099 L
.37996 .3099 L
.38001 .3099 L
.38011 .3099 L
.38021 .3099 L
.3804 .3099 L
.38062 .3099 L
.38086 .30989 L
.38128 .30988 L
.38171 .30987 L
.38211 .30985 L
.383 .30981 L
.38379 .30975 L
.38462 .30968 L
.3862 .3095 L
.38767 .3093 L
.39079 .30874 L
Mistroke
.39412 .30805 L
.39578 .3077 L
.39732 .30741 L
.39891 .30716 L
.39968 .30707 L
.4004 .30699 L
.40112 .30694 L
.4015 .30692 L
.40171 .30691 L
.4019 .3069 L
.40209 .30689 L
.4022 .30689 L
.40231 .30689 L
.4024 .30689 L
.40249 .30689 L
.40258 .30689 L
.40269 .30689 L
.40279 .30689 L
.40285 .30689 L
.4029 .30689 L
.403 .30689 L
.4031 .30689 L
.40331 .3069 L
.40355 .30691 L
.40376 .30692 L
.40398 .30693 L
.40438 .30696 L
.40513 .30703 L
.40601 .30716 L
.40682 .30731 L
.40833 .30768 L
.41 .30822 L
.41325 .30959 L
.41638 .31112 L
.41797 .31187 L
.4197 .31259 L
.42051 .31288 L
.42137 .31313 L
.4221 .31331 L
.42249 .31338 L
.42291 .31345 L
.42312 .31347 L
.42332 .3135 L
.42353 .31351 L
.42372 .31353 L
.42381 .31353 L
.42391 .31354 L
.424 .31354 L
.42408 .31354 L
.42417 .31354 L
Mistroke
.42427 .31355 L
.42437 .31355 L
.42446 .31354 L
.42457 .31354 L
.42463 .31354 L
.42468 .31354 L
.42478 .31353 L
.42489 .31353 L
.42507 .31351 L
.42527 .3135 L
.42572 .31344 L
.42614 .31336 L
.42693 .31317 L
.42776 .31288 L
.42925 .31218 L
.43083 .31115 L
.4323 .30998 L
.43544 .30698 L
.43877 .30364 L
.44044 .30221 L
.44117 .30168 L
.44198 .30118 L
.44275 .3008 L
.44312 .30065 L
.44348 .30054 L
.44367 .30049 L
.44388 .30044 L
.44407 .3004 L
.44424 .30038 L
.44434 .30036 L
.44445 .30035 L
.44456 .30034 L
.44461 .30034 L
.44467 .30034 L
.44477 .30033 L
.44487 .30033 L
.44497 .30033 L
.44506 .30034 L
.44517 .30034 L
.44522 .30035 L
.44527 .30035 L
.44547 .30037 L
.44558 .30039 L
.44569 .30041 L
.4459 .30045 L
.44632 .30057 L
.4467 .30071 L
.44743 .30108 L
.44819 .3016 L
.44978 .30312 L
Mistroke
.45125 .30502 L
.45439 .31033 L
.45773 .31671 L
.4594 .31964 L
.46094 .32187 L
.46172 .32276 L
.46244 .32342 L
.46284 .3237 L
.4632 .32391 L
.4636 .32409 L
.46382 .32416 L
.46392 .32419 L
.46403 .32421 L
.46413 .32423 L
.46422 .32424 L
.46431 .32425 L
.4644 .32426 L
.4645 .32426 L
.46459 .32426 L
.46469 .32425 L
.46475 .32424 L
.4648 .32424 L
.46491 .32422 L
.46501 .3242 L
.46523 .32415 L
.46542 .32408 L
.46563 .32399 L
.46599 .32378 L
.46633 .32354 L
.4671 .32279 L
.46794 .32169 L
.46873 .32037 L
.47022 .31719 L
.47328 .30834 L
.47655 .29746 L
.47806 .2928 L
.47969 .28858 L
.48059 .28678 L
.48098 .28612 L
.48141 .28551 L
.48179 .28507 L
.4822 .28469 L
.48242 .28454 L
.48263 .28442 L
.48273 .28438 L
.48283 .28434 L
.48294 .28431 L
.48303 .28429 L
.48312 .28427 L
.48322 .28426 L
Mistroke
.48331 .28426 L
.48342 .28427 L
.48351 .28428 L
.48361 .2843 L
.4837 .28432 L
.48378 .28435 L
.48399 .28444 L
.48421 .28457 L
.48462 .28491 L
.48504 .2854 L
.4855 .28607 L
.4863 .28766 L
.48706 .2896 L
.48788 .29214 L
.48935 .29783 L
.49266 .31439 L
.49585 .3313 L
.49747 .33841 L
.49817 .34094 L
.49892 .34322 L
.49935 .34426 L
.49974 .34505 L
.50011 .34566 L
.50051 .34615 L
.50071 .34632 L
.50082 .3464 L
.50092 .34646 L
.50102 .34651 L
.50113 .34655 L
.50122 .34657 L
.50131 .34658 L
.50142 .34658 L
.50151 .34657 L
.50157 .34656 L
.50162 .34654 L
.50174 .3465 L
.50185 .34644 L
.50197 .34636 L
.50219 .34617 L
.5024 .34594 L
.50262 .34564 L
.50302 .34493 L
.50377 .34307 L
.50465 .34003 L
.50545 .33644 L
.50696 .32785 L
.50862 .31612 L
.51187 .28981 L
.51336 .27814 L
.51499 .2673 L
Mistroke
.51587 .2626 L
.51669 .2592 L
.51709 .2579 L
.51747 .25691 L
.51787 .25613 L
.51808 .25583 L
.5182 .25569 L
.51831 .25559 L
.5184 .25552 L
.5185 .25546 L
.5186 .25541 L
.5187 .25539 L
.5188 .25538 L
.5189 .25539 L
.51898 .25541 L
.51907 .25546 L
.51913 .25549 L
.51918 .25552 L
.51928 .25561 L
.51951 .25586 L
.5197 .25615 L
.51991 .25655 L
.52034 .2576 L
.52079 .2591 L
.52161 .26274 L
.52243 .26765 L
.52333 .27424 L
.52495 .28914 L
.52824 .3265 L
.52988 .34531 L
.53141 .36077 L
.53289 .37233 L
.53331 .37489 L
.53371 .37696 L
.5341 .37861 L
.53446 .37984 L
.53483 .38075 L
.53503 .3811 L
.53513 .38124 L
.53524 .38136 L
.53529 .38141 L
.53535 .38145 L
.53545 .38151 L
.53551 .38153 L
.53557 .38154 L
.53567 .38154 L
.53577 .38151 L
.53586 .38146 L
.53596 .38139 L
.53606 .38128 L
Mistroke
.53624 .38103 L
.53643 .38067 L
.53677 .37978 L
.53717 .37832 L
.53754 .37661 L
.53834 .37173 L
.53907 .36577 L
.54074 .34772 L
.54389 .30146 L
.54691 .25475 L
.54846 .23542 L
.54933 .227 L
.54972 .22394 L
.55013 .22117 L
.55055 .21895 L
.55092 .21741 L
.5511 .21684 L
.5513 .21635 L
.55139 .21617 L
.55148 .216 L
.55157 .21588 L
.55165 .21579 L
.55175 .21571 L
.55185 .21568 L
.55195 .21567 L
.55201 .21568 L
.55206 .21571 L
.55216 .21577 L
.55224 .21586 L
.55235 .216 L
.55244 .21617 L
.55266 .21667 L
.55286 .21728 L
.55331 .2192 L
.55369 .22136 L
.55409 .22424 L
.55482 .23089 L
.55648 .25237 L
.55819 .28195 L
.5598 .31428 L
.56288 .37558 L
.56447 .4007 L
.56527 .41039 L
.5657 .41461 L
.56615 .41824 L
.56654 .42065 L
.56674 .42166 L
.56696 .42254 L
.56716 .42316 L
.56735 .42356 L
Mistroke
.56744 .4237 L
.56753 .42381 L
.56762 .42387 L
.56771 .42389 L
.5678 .42388 L
.56791 .42382 L
.568 .42372 L
.56809 .42359 L
.5682 .42338 L
.56831 .4231 L
.56852 .42243 L
.56873 .42152 L
.56897 .4203 L
.56938 .41749 L
.57021 .40952 L
.5711 .39753 L
.57272 .36795 L
.57602 .28824 L
.57766 .24731 L
.57919 .21403 L
.57995 .20046 L
.58067 .18984 L
.58106 .18502 L
.58149 .18067 L
.58188 .17756 L
.58224 .17543 L
.58244 .17458 L
.58262 .174 L
.58271 .17376 L
.58281 .17356 L
.58286 .17349 L
.58292 .17342 L
.58302 .17335 L
.58311 .17333 L
.58321 .17337 L
.58331 .17346 L
.5834 .17359 L
.58348 .17375 L
.58357 .17397 L
.58374 .17455 L
.58396 .1755 L
.58416 .17661 L
.5846 .17992 L
.58501 .184 L
.5854 .18874 L
.58617 .20059 L
.587 .21649 L
.58847 .25227 L
.5915 .34158 L
.59318 .3901 L
Mistroke
.59392 .40895 L
.59473 .42707 L
.59546 .44076 L
.59624 .45208 L
.59667 .45673 L
.59706 .45992 L
.59725 .4611 L
.59746 .46209 L
.59755 .46245 L
.59765 .46277 L
.59774 .46299 L
.59783 .46317 L
.59793 .46329 L
.59803 .46335 L
.59813 .46333 L
.59819 .46328 L
.59825 .46322 L
.59835 .46306 L
.5984 .46294 L
.59845 .46281 L
.59864 .46215 L
.59882 .46134 L
.59901 .46021 L
.59939 .45717 L
.59981 .45269 L
.60026 .44659 L
.60106 .43231 L
.60277 .39007 L
.60439 .33895 L
.60747 .23371 L
.60902 .18854 L
.60991 .16822 L
.61031 .16055 L
.61074 .15367 L
.61112 .14865 L
.61153 .14438 L
.61171 .14292 L
.61191 .14164 L
.61209 .1407 L
.61226 .14008 L
.61236 .13981 L
.61241 .13971 L
.61247 .13962 L
.61257 .13952 L
.61266 .1395 L
.61272 .13952 L
.61277 .13957 L
.61287 .13971 L
.61293 .13983 L
.61298 .13997 L
Mistroke
.6131 .14035 L
.6133 .14126 L
.61348 .14237 L
.61389 .14582 L
.61429 .15037 L
.6147 .15647 L
.61544 .17055 L
.61712 .2155 L
.62017 .32679 L
.62187 .39023 L
.62342 .43913 L
.62419 .45835 L
.6246 .4668 L
.62503 .47438 L
.62541 .47978 L
.62561 .48217 L
.62582 .48437 L
.62602 .48603 L
.6262 .48726 L
.62628 .48775 L
.62638 .4882 L
.62646 .48854 L
.62655 .48883 L
.6266 .48897 L
.62666 .48909 L
.62675 .48923 L
.62681 .48928 L
.62687 .4893 L
.62693 .48928 L
.62698 .48925 L
.62707 .48911 L
.62713 .489 L
.62718 .48887 L
.62728 .48856 L
.62738 .48815 L
.62756 .48716 L
.62773 .48596 L
.62813 .48223 L
.62855 .47673 L
.62894 .47035 L
.62981 .45152 L
.63133 .40602 L
.63299 .34303 L
.6347 .27286 L
.63625 .21283 L
.63702 .18667 L
.63786 .16246 L
.63865 .14436 L
.63903 .13749 L
.63938 .13232 L
Mistroke
.63975 .12801 L
.63996 .12619 L
.64016 .12483 L
.64024 .12435 L
.64034 .12391 L
.64042 .1236 L
.64051 .12334 L
.64061 .12312 L
.6407 .123 L
.6408 .12298 L
.64089 .12303 L
.64098 .12318 L
.64108 .12343 L
.64118 .12377 L
.64127 .12415 L
.64149 .12541 L
.64169 .12702 L
.6421 .1314 L
.64254 .13792 L
.6433 .15308 L
.64413 .17525 L
.64582 .2342 L
.64905 .36999 L
.65053 .42596 L
.65138 .45197 L
.65216 .47131 L
.65256 .4792 L
.65294 .48528 L
.65315 .48807 L
.65337 .4906 L
.65358 .49246 L
.65377 .49381 L
.65388 .49441 L
.65397 .49486 L
.65408 .49524 L
.65414 .4954 L
.6542 .49552 L
.65425 .4956 L
.65431 .49566 L
.65441 .49567 L
.65447 .49563 L
.65453 .49556 L
.65459 .49546 L
.65465 .4953 L
.65475 .49497 L
.65486 .49451 L
.65507 .49321 L
.65528 .49158 L
.65546 .48971 L
.65587 .48449 L
Mistroke
.65631 .47706 L
.6571 .45911 L
.65859 .41216 L
.66188 .27539 L
.66351 .2099 L
.6643 .18274 L
.66503 .16186 L
.66539 .1532 L
.66579 .14504 L
.66616 .13857 L
.6665 .13388 L
.66669 .13175 L
.66689 .12986 L
.66701 .129 L
.66711 .12832 L
.66722 .12775 L
.66731 .12732 L
.6674 .12703 L
.66749 .1268 L
.66759 .12664 L
.66768 .12659 L
.66778 .12663 L
.66788 .12679 L
.66798 .12703 L
.66807 .12735 L
.66827 .12831 L
.66844 .12953 L
.66864 .13124 L
.66885 .13346 L
.66919 .13815 L
.66957 .1446 L
.67043 .164 L
.67123 .18743 L
.67436 .31129 L
.67596 .37773 L
.6768 .40898 L
.67769 .43737 L
.67849 .4576 L
.67891 .46609 L
.67936 .47336 L
.67958 .4761 L
.67978 .47828 L
.67998 .48 L
.68016 .48125 L
.68033 .48212 L
.68043 .48247 L
.68051 .4827 L
.68061 .48287 L
.68071 .48295 L
.68081 .48292 L
Mistroke
.6809 .4828 L
.681 .48257 L
.6811 .48226 L
.68119 .4819 L
.68128 .48142 L
.68149 .48001 L
.68169 .47832 L
.68204 .47427 L
.68242 .46864 L
.68321 .4526 L
.68408 .42895 L
.68731 .30667 L
.6888 .24732 L
.69042 .19301 L
.6913 .17117 L
.69173 .16289 L
.69211 .15682 L
.69231 .15433 L
.69252 .15204 L
.6927 .1504 L
.69289 .14897 L
.693 .14838 L
.6931 .14787 L
.69317 .14764 L
.69322 .14745 L
.69328 .1473 L
.69333 .14719 L
.69343 .14704 L
.69348 .147 L
.69353 .14699 L
.69362 .14704 L
.69373 .1472 L
.69382 .14744 L
.69391 .14775 L
.69401 .14819 L
.69412 .14876 L
.69434 .15027 L
.69454 .15204 L
.69492 .15652 L
.69528 .16198 L
.69608 .1782 L
.69695 .20144 L
.70023 .3201 L
.70187 .37961 L
.70267 .40455 L
.7034 .42379 L
.70375 .43181 L
.70415 .43937 L
.70452 .44537 L
.70486 .44974 L
Mistroke
.70505 .45173 L
.70526 .45351 L
.70547 .45496 L
.70557 .45547 L
.70568 .45592 L
.70578 .45625 L
.70587 .45647 L
.70597 .45661 L
.70607 .45667 L
.70617 .45663 L
.70626 .45651 L
.70634 .45633 L
.70643 .45606 L
.70653 .45569 L
.70662 .45527 L
.70682 .45404 L
.707 .45265 L
.70719 .45088 L
.70759 .44609 L
.70802 .4393 L
.7089 .42115 L
.70971 .3996 L
.71285 .29348 L
.71445 .24092 L
.71529 .21783 L
.71618 .19836 L
.71656 .19178 L
.71698 .18602 L
.71721 .18336 L
.71743 .18133 L
.71765 .17969 L
.71776 .17904 L
.71785 .17854 L
.71794 .17815 L
.71804 .17781 L
.71814 .17753 L
.71823 .17735 L
.71833 .17725 L
.71839 .17723 L
.71845 .17724 L
.71855 .17732 L
.71864 .17748 L
.71874 .17773 L
.71883 .17804 L
.719 .17881 L
.71919 .17993 L
.71939 .18147 L
.71978 .18541 L
.72015 .19022 L
.72098 .20487 L
Mistroke
.7218 .22353 L
.72267 .2474 L
.72425 .29648 L
.72598 .3503 L
.72678 .37244 L
.72763 .39261 L
.72844 .40759 L
.72879 .41269 L
.72917 .41725 L
.72956 .42078 L
.72977 .42221 L
.72988 .42276 L
.72997 .42321 L
.73006 .42356 L
.73016 .42387 L
.73025 .42409 L
.73033 .42423 L
.73042 .42432 L
.73052 .42436 L
.73062 .42431 L
.73071 .4242 L
.73081 .424 L
.73092 .42371 L
.73103 .4233 L
.73113 .42284 L
.73152 .42041 L
.73174 .41852 L
.73194 .4165 L
.73238 .41094 L
.73319 .39772 L
.73392 .38228 L
.73559 .33942 L
.73723 .29353 L
.73876 .25459 L
.73951 .23882 L
.74022 .22665 L
.74062 .22127 L
.74104 .21654 L
.74123 .21486 L
.74144 .21333 L
.74161 .21224 L
.7418 .21129 L
.7419 .21089 L
.74201 .21053 L
.74207 .21037 L
.74212 .21025 L
.74218 .21014 L
.74223 .21006 L
.74233 .20997 L
.74243 .20994 L
Mistroke
.74253 .20998 L
.74262 .21009 L
.74273 .21028 L
.74284 .21057 L
.74295 .21093 L
.74305 .21133 L
.74328 .21251 L
.74352 .21413 L
.74392 .21767 L
.74429 .22186 L
.74514 .2343 L
.74678 .26767 L
.74828 .30359 L
.74995 .34283 L
.75068 .3578 L
.75149 .37171 L
.75186 .3771 L
.75227 .38205 L
.75261 .3856 L
.75299 .38866 L
.75321 .39005 L
.75342 .39108 L
.75362 .39181 L
.75371 .3921 L
.75382 .39234 L
.75392 .39249 L
.75401 .39258 L
.75411 .39263 L
.75421 .39261 L
.75431 .39253 L
.75439 .39242 L
.75448 .39225 L
.75458 .39201 L
.75479 .39131 L
.75501 .39029 L
.7554 .38778 L
.75583 .3841 L
.75629 .37898 L
.75791 .35389 L
.7596 .32016 L
.76115 .28865 L
.76191 .27462 L
.76274 .26139 L
.76353 .25144 L
.76391 .24765 L
.76426 .24479 L
.76467 .24223 L
.76488 .24123 L
.76499 .24082 L
.76511 .24044 L
Mistroke
.76521 .24017 L
.7653 .23997 L
.7654 .23982 L
.76549 .23972 L
.76559 .23965 L
.76569 .23965 L
.76579 .23969 L
.76585 .23974 L
.76591 .2398 L
.766 .23995 L
.7661 .24015 L
.76628 .24064 L
.76647 .24135 L
.76668 .24232 L
.76705 .24461 L
.7674 .24732 L
.76825 .25605 L
.76904 .26667 L
.77054 .29072 L
.77201 .31621 L
.77284 .32987 L
.77363 .3413 L
.77446 .3515 L
.77522 .35861 L
.77564 .3615 L
.77604 .36356 L
.77625 .36439 L
.77646 .36498 L
.77657 .36523 L
.77668 .36541 L
.77673 .36549 L
.7768 .36556 L
.77686 .36561 L
.77691 .36564 L
.77701 .36566 L
.77711 .36564 L
.7772 .36558 L
.77729 .36548 L
.77739 .36534 L
.7775 .36513 L
.7777 .36463 L
.77788 .36403 L
.77804 .36334 L
.77843 .36135 L
.77884 .35853 L
.77923 .3554 L
.78009 .34666 L
.78327 .30332 L
.78488 .2829 L
.78558 .2758 L
Mistroke
.78634 .26978 L
.78676 .26725 L
.78695 .26634 L
.78715 .26548 L
.78733 .26485 L
.78752 .26431 L
.78763 .26407 L
.78773 .26388 L
.78782 .26374 L
.78792 .26362 L
.78802 .26354 L
.78808 .2635 L
.78813 .26349 L
.78823 .26348 L
.78833 .26351 L
.78838 .26355 L
.78844 .2636 L
.78856 .26373 L
.78868 .2639 L
.78878 .2641 L
.78899 .26462 L
.78918 .26522 L
.7896 .26699 L
.78999 .26912 L
.7904 .27187 L
.79114 .27793 L
.79281 .29538 L
.7944 .31371 L
.79585 .32873 L
.79659 .33496 L
.79741 .3402 L
.79785 .34231 L
.79807 .34312 L
.79827 .34374 L
.79846 .34423 L
.79866 .34463 L
.79878 .3448 L
.79888 .34492 L
.79898 .34501 L
.79908 .34507 L
.79918 .34509 L
.79924 .34509 L
.79929 .34508 L
.79938 .34505 L
.79948 .34498 L
.79957 .3449 L
.79966 .3448 L
.79985 .3445 L
.80005 .34406 L
.80024 .34356 L
Mistroke
.80066 .34207 L
.80138 .33851 L
.80213 .33355 L
.8052 .30667 L
.80608 .29901 L
.8069 .29264 L
.80771 .28754 L
.80807 .28572 L
.80846 .28403 L
.80883 .28273 L
.80919 .28181 L
.80938 .28143 L
.80956 .28117 L
.80966 .28106 L
.80977 .28096 L
.80987 .2809 L
.80996 .28086 L
.81005 .28084 L
.81016 .28085 L
.81025 .28087 L
.81034 .28092 L
.81043 .28099 L
.81054 .28109 L
.81075 .28137 L
.81096 .28175 L
.81119 .28227 L
.81159 .28347 L
.81241 .2869 L
.8133 .29188 L
.81492 .303 L
.81648 .31422 L
.81731 .31955 L
.8182 .32436 L
.81864 .32628 L
.81905 .3278 L
.81946 .32899 L
.81965 .32946 L
.81983 .32983 L
.82 .33011 L
.82019 .33036 L
.82029 .33047 L
.82038 .33056 L
.82047 .33062 L
.82056 .33067 L
.82066 .33071 L
.82075 .33073 L
.82085 .33073 L
.82095 .33071 L
.82105 .33067 L
.82111 .33064 L
Mistroke
.82116 .33061 L
.82136 .33044 L
.82155 .3302 L
.82173 .32992 L
.82213 .3291 L
.82249 .32816 L
.82286 .32695 L
.82451 .31955 L
.82757 .30278 L
.82838 .29906 L
.82915 .29621 L
.82957 .29495 L
.83003 .29387 L
.83023 .29349 L
.83044 .29316 L
.83063 .29293 L
.83083 .29273 L
.83093 .29265 L
.83103 .29259 L
.83112 .29255 L
.83122 .29252 L
.83132 .2925 L
.83141 .2925 L
.8315 .29251 L
.83158 .29253 L
.83168 .29257 L
.83179 .29263 L
.8319 .2927 L
.83201 .29279 L
.83221 .293 L
.8324 .29326 L
.83277 .29389 L
.83311 .29461 L
.83387 .29672 L
.83547 .30276 L
.83695 .30915 L
.83773 .31241 L
.83858 .31555 L
.83931 .31783 L
.83972 .31889 L
.84011 .31973 L
.84051 .32043 L
.84088 .32091 L
.84108 .32111 L
.84127 .32125 L
.84138 .32131 L
.84147 .32135 L
.84158 .32139 L
.84163 .3214 L
.84169 .32141 L
Mistroke
.84179 .32142 L
.84188 .32142 L
.84196 .32141 L
.84205 .32139 L
.84215 .32136 L
.84225 .32132 L
.84244 .3212 L
.84261 .32107 L
.84277 .32091 L
.84314 .32046 L
.84352 .31985 L
.84393 .31905 L
.84476 .31702 L
.84624 .31249 L
.84795 .30697 L
.8495 .30281 L
.85027 .30133 L
.85071 .3007 L
.85091 .30046 L
.85111 .30027 L
.85129 .30012 L
.85146 .30001 L
.85165 .29991 L
.85175 .29987 L
.85185 .29984 L
.85194 .29983 L
.85204 .29981 L
.85214 .29981 L
.85222 .29981 L
.85232 .29983 L
.85238 .29984 L
.85243 .29985 L
.85253 .29988 L
.85263 .29992 L
.85283 .30002 L
.85303 .30016 L
.85339 .30048 L
.85378 .30094 L
.85421 .30157 L
.85568 .30448 L
.85724 .30824 L
.85806 .31023 L
.85896 .31217 L
.8598 .31371 L
.86018 .31427 L
.86058 .31478 L
.86094 .31515 L
.86133 .31545 L
.86154 .31557 L
.86173 .31566 L
Mistroke
.86183 .31569 L
.86193 .31572 L
.86202 .31574 L
.86211 .31576 L
.86221 .31577 L
.86231 .31577 L
.86239 .31577 L
.86249 .31576 L
.86259 .31575 L
.86264 .31574 L
.86269 .31572 L
.86289 .31566 L
.86307 .31559 L
.86326 .31548 L
.86362 .31523 L
.86404 .31485 L
.86448 .31434 L
.86527 .31324 L
.86833 .30789 L
.86914 .30662 L
.8699 .30561 L
.87032 .30515 L
.87078 .30474 L
.8712 .30446 L
.8714 .30435 L
.87158 .30427 L
.87177 .30421 L
.87195 .30416 L
.87205 .30414 L
.87215 .30413 L
.87225 .30412 L
.8723 .30412 L
.87236 .30412 L
.87245 .30412 L
.87254 .30412 L
.87263 .30413 L
.87273 .30415 L
.87282 .30416 L
.8729 .30418 L
.87308 .30424 L
.8733 .30432 L
.8735 .30442 L
.87388 .30465 L
.87474 .30536 L
.87634 .30722 L
.87781 .30918 L
.8786 .31015 L
.87944 .31106 L
.88024 .31175 L
.88061 .31201 L
Mistroke
.88097 .3122 L
.88131 .31235 L
.8815 .31241 L
.88167 .31246 L
.88186 .3125 L
.88197 .31251 L
.88207 .31252 L
.88215 .31253 L
.88225 .31253 L
.88235 .31253 L
.88244 .31253 L
.88254 .31253 L
.88264 .31252 L
.88274 .3125 L
.88283 .31249 L
.88301 .31245 L
.88319 .3124 L
.88361 .31224 L
.88399 .31206 L
.8848 .31153 L
.88554 .31093 L
.88721 .30937 L
.88886 .3079 L
.88966 .30733 L
.89039 .30693 L
.89075 .30677 L
.89094 .30671 L
.89114 .30665 L
.89132 .30661 L
.89152 .30657 L
.8916 .30656 L
.89169 .30654 L
.89178 .30654 L
.89186 .30653 L
.89196 .30652 L
.89205 .30652 L
.89211 .30652 L
.89216 .30652 L
.89226 .30652 L
.89237 .30653 L
.89247 .30653 L
.89257 .30654 L
.89268 .30656 L
.89287 .30659 L
.89304 .30662 L
.89344 .30673 L
.89384 .30687 L
.89428 .30706 L
.89507 .30749 L
.89656 .30847 L
Mistroke
.89811 .30951 L
.89894 .30998 L
.89937 .31019 L
.89983 .31038 L
.90023 .31052 L
.90045 .31058 L
.90068 .31064 L
.90089 .31068 L
.90108 .31072 L
.90127 .31074 L
.90145 .31076 L
.90154 .31076 L
.90164 .31077 L
.90174 .31077 L
.90183 .31077 L
.90192 .31077 L
.902 .31077 L
.9021 .31077 L
.90218 .31076 L
.90228 .31076 L
.90238 .31075 L
.90256 .31073 L
.90278 .3107 L
.90298 .31066 L
.90337 .31057 L
.90378 .31045 L
.90452 .31019 L
.9062 .30942 L
.90779 .30867 L
.90849 .30838 L
.90924 .30813 L
.90966 .30802 L
.91005 .30793 L
.91042 .30787 L
.91061 .30784 L
.91081 .30782 L
.91092 .30781 L
.91103 .30781 L
.91112 .3078 L
.91123 .3078 L
.91129 .3078 L
.91134 .30779 L
.9114 .30779 L
.91146 .30779 L
.91156 .30779 L
.91162 .3078 L
.91168 .3078 L
.91177 .3078 L
.91187 .3078 L
.91207 .30782 L
Mistroke
.91227 .30784 L
.91249 .30786 L
.91291 .30793 L
.9133 .308 L
.91419 .30823 L
.9158 .30875 L
.91732 .30925 L
.91811 .30947 L
.91895 .30966 L
.91938 .30974 L
.91961 .30977 L
.91985 .3098 L
.92007 .30982 L
.92028 .30984 L
.92037 .30984 L
.92048 .30985 L
.92057 .30985 L
.92067 .30986 L
.92077 .30986 L
.92087 .30986 L
.92093 .30986 L
.92098 .30986 L
.92108 .30986 L
.92113 .30986 L
.92119 .30986 L
.92129 .30986 L
.92141 .30985 L
.92152 .30985 L
.92171 .30984 L
.92192 .30982 L
.92229 .30978 L
.92269 .30973 L
.92306 .30968 L
.92389 .30952 L
.92558 .30913 L
.92708 .30879 L
.92787 .30865 L
.9287 .30854 L
.92913 .30849 L
.92936 .30848 L
.92959 .30846 L
.9298 .30845 L
.92998 .30845 L
.93008 .30844 L
.93014 .30844 L
.93019 .30844 L
.93025 .30844 L
.9303 .30844 L
.93041 .30844 L
.93051 .30844 L
Mistroke
.93056 .30844 L
.93062 .30844 L
.93071 .30844 L
.93081 .30845 L
.93102 .30845 L
.93124 .30846 L
.93165 .30849 L
.93202 .30852 L
.93281 .30861 L
.93355 .30872 L
.93521 .30898 L
.93672 .30921 L
.93757 .3093 L
.93798 .30934 L
.93836 .30937 L
.93876 .30939 L
.93897 .3094 L
.93919 .3094 L
.93931 .3094 L
.93937 .30941 L
.93943 .30941 L
.93949 .30941 L
.93955 .30941 L
.9396 .30941 L
.93966 .30941 L
.93976 .30941 L
.93986 .30941 L
.93991 .30941 L
.93997 .30941 L
.94008 .3094 L
.94019 .3094 L
.94029 .3094 L
.94048 .30939 L
.94092 .30938 L
.94129 .30935 L
.9417 .30933 L
.94329 .30917 L
.94498 .30899 L
.94574 .30891 L
.94656 .30884 L
.94695 .30882 L
.94733 .30879 L
.94769 .30878 L
.94803 .30877 L
.9482 .30876 L
.9484 .30876 L
.9485 .30876 L
.94861 .30876 L
.9487 .30876 L
.9488 .30875 L
Mistroke
.94886 .30875 L
.94891 .30875 L
.94901 .30875 L
.94911 .30875 L
.94917 .30876 L
.94923 .30876 L
.94932 .30876 L
.94942 .30876 L
.94962 .30876 L
.94982 .30877 L
.94999 .30877 L
.95039 .30879 L
.9511 .30882 L
.95262 .30892 L
.95429 .30905 L
.9551 .3091 L
.95587 .30914 L
.95629 .30916 L
.95675 .30917 L
.95695 .30918 L
.95717 .30918 L
.95735 .30919 L
.95755 .30919 L
.95766 .30919 L
.95775 .30919 L
.9578 .30919 L
.95786 .30919 L
.95792 .30919 L
.95797 .30919 L
.95807 .30919 L
.95816 .30919 L
.95826 .30919 L
.95837 .30919 L
.95846 .30919 L
.95855 .30919 L
.95873 .30919 L
.95893 .30918 L
.95912 .30918 L
.95953 .30917 L
.95998 .30916 L
.9608 .30912 L
.96236 .30905 L
.96319 .30901 L
.96408 .30897 L
.96493 .30894 L
.96534 .30892 L
.96571 .30892 L
.96609 .30891 L
.96629 .30891 L
.96639 .3089 L
Mistroke
.9665 .3089 L
.9666 .3089 L
.9667 .3089 L
.96679 .3089 L
.96689 .3089 L
.96698 .3089 L
.96706 .3089 L
.96715 .3089 L
.96724 .3089 L
.96734 .3089 L
.9674 .3089 L
.96745 .3089 L
.96767 .3089 L
.96786 .30891 L
.96806 .30891 L
.96853 .30892 L
.96895 .30892 L
.97057 .30897 L
.97222 .30903 L
.97302 .30905 L
.97375 .30907 L
.97436 .30908 L
.97464 .30908 L
.97493 .30909 L
.97508 .30909 L
.97525 .30909 L
.9754 .30909 L
.97554 .30909 L
.97561 .30909 L
.9757 .30909 L
.97579 .30909 L
.97587 .30909 L
.97595 .30909 L
.97604 .30909 L
.97611 .30909 L
.97619 .30909 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{421.375, 260.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 525.688}, {324.5, 0}} -> {-2.58312*^-7, -6.34248*^6, \
6.65005*^-9, 53093.5}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0.309017 5.42214e-08 [
[.32684 .29652 -16.5 -12.5 ]
[.32684 .29652 16.5 0 ]
[.54329 .29652 -16.5 -12.5 ]
[.54329 .29652 16.5 0 ]
[.75974 .29652 -22.5 -12.5 ]
[.75974 .29652 22.5 0 ]
[.97619 .29652 -16.5 -12.5 ]
[.97619 .29652 16.5 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 64 6 ]
[.09789 .09213 -34.5 -6.25 ]
[.09789 .09213 0 6.25 ]
[.09789 .20057 -34.5 -6.25 ]
[.09789 .20057 0 6.25 ]
[.09789 .41746 -28.5 -6.25 ]
[.09789 .41746 0 6.25 ]
[.09789 .5259 -28.5 -6.25 ]
[.09789 .5259 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -62.8125 0 ]
[.5 .63053 62.8125 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 .30902 m
.32684 .31527 L
s
gsave
.32684 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 .30902 m
.54329 .31527 L
s
gsave
.54329 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 .30902 m
.75974 .31527 L
s
gsave
.75974 .29652 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 .30902 m
.15368 .31277 L
s
.19697 .30902 m
.19697 .31277 L
s
.24026 .30902 m
.24026 .31277 L
s
.28355 .30902 m
.28355 .31277 L
s
.37013 .30902 m
.37013 .31277 L
s
.41342 .30902 m
.41342 .31277 L
s
.45671 .30902 m
.45671 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.58658 .30902 m
.58658 .31277 L
s
.62987 .30902 m
.62987 .31277 L
s
.67316 .30902 m
.67316 .31277 L
s
.71645 .30902 m
.71645 .31277 L
s
.80303 .30902 m
.80303 .31277 L
s
.84632 .30902 m
.84632 .31277 L
s
.88961 .30902 m
.88961 .31277 L
s
.9329 .30902 m
.9329 .31277 L
s
.0671 .30902 m
.0671 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09213 m
.11664 .09213 L
s
gsave
.09789 .09213 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .20057 m
.11664 .20057 L
s
gsave
.09789 .20057 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .41746 m
.11664 .41746 L
s
gsave
.09789 .41746 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .5259 m
.11664 .5259 L
s
gsave
.09789 .5259 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.11039 .11924 m
.11414 .11924 L
s
.11039 .14635 m
.11414 .14635 L
s
.11039 .17346 m
.11414 .17346 L
s
.11039 .22768 m
.11414 .22768 L
s
.11039 .2548 m
.11414 .2548 L
s
.11039 .28191 m
.11414 .28191 L
s
.11039 .33613 m
.11414 .33613 L
s
.11039 .36324 m
.11414 .36324 L
s
.11039 .39035 m
.11414 .39035 L
s
.11039 .44457 m
.11414 .44457 L
s
.11039 .47168 m
.11414 .47168 L
s
.11039 .49879 m
.11414 .49879 L
s
.11039 .06502 m
.11414 .06502 L
s
.11039 .03791 m
.11414 .03791 L
s
.11039 .0108 m
.11414 .0108 L
s
.11039 .55301 m
.11414 .55301 L
s
.11039 .58012 m
.11414 .58012 L
s
.11039 .60723 m
.11414 .60723 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -123.812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.812 moveto
(@) show
81.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.812 moveto
(D) show
93.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11.) show
135.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
141.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
153.000 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
157.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
166.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
184.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02691 .30902 L
.03029 .30902 L
.03347 .30902 L
.03652 .30902 L
.03978 .30902 L
.04291 .30902 L
.04623 .30902 L
.04944 .30902 L
.05252 .30902 L
.0558 .30902 L
.05896 .30902 L
.062 .30902 L
.06523 .30902 L
.06834 .30902 L
.07165 .30902 L
.07484 .30902 L
.0779 .30902 L
.08117 .30902 L
.08431 .30902 L
.08765 .30902 L
.09086 .30902 L
.09396 .30902 L
.09725 .30902 L
.10042 .30902 L
.10346 .30902 L
.10671 .30902 L
.10983 .30902 L
.11315 .30902 L
.11635 .30902 L
.11943 .30902 L
.12098 .30902 L
.1227 .30902 L
.12348 .30902 L
.12433 .30902 L
.12471 .30902 L
.12512 .30902 L
.1255 .30902 L
.12585 .30902 L
.12604 .30902 L
.12615 .30902 L
.12625 .30902 L
.12634 .30902 L
.12644 .30902 L
.12653 .30902 L
.12662 .30902 L
.12672 .30902 L
.12682 .30902 L
.12691 .30902 L
.12701 .30902 L
Mistroke
.12707 .30902 L
.12712 .30902 L
.12723 .30902 L
.12744 .30902 L
.12763 .30902 L
.1278 .30902 L
.1282 .30902 L
.12854 .30902 L
.12891 .30902 L
.12967 .30902 L
.13049 .30902 L
.13126 .30902 L
.13196 .30902 L
.1335 .30902 L
.13436 .30902 L
.13517 .30902 L
.13667 .30902 L
.13832 .30902 L
.13988 .30902 L
.14155 .30902 L
.14313 .30902 L
.14486 .30902 L
.14804 .30902 L
.1513 .30902 L
.15444 .30902 L
.15778 .30902 L
.16099 .30902 L
.16408 .30902 L
.16737 .30902 L
.17054 .30902 L
.17358 .30902 L
.17683 .30902 L
.17995 .30902 L
.18153 .30902 L
.18326 .30902 L
.18407 .30902 L
.18492 .30902 L
.18565 .30902 L
.18604 .30902 L
.18646 .30902 L
.18665 .30902 L
.18685 .30902 L
.18697 .30902 L
.18707 .30902 L
.18717 .30902 L
.18727 .30902 L
.18736 .30902 L
.18745 .30902 L
.18755 .30902 L
.18765 .30902 L
Mistroke
.18774 .30902 L
.18784 .30902 L
.18793 .30902 L
.18801 .30902 L
.18822 .30902 L
.18842 .30902 L
.18864 .30902 L
.18887 .30902 L
.1893 .30902 L
.18968 .30902 L
.19049 .30902 L
.19123 .30902 L
.19204 .30902 L
.1929 .30902 L
.19448 .30902 L
.19595 .30902 L
.19759 .30902 L
.19908 .30902 L
.20074 .30902 L
.20228 .30902 L
.20535 .30902 L
.20851 .30902 L
.21154 .30902 L
.21477 .30902 L
.21787 .30902 L
.22118 .30902 L
.22436 .30902 L
.22742 .30902 L
.229 .30902 L
.22988 .30902 L
.23068 .30902 L
.23107 .30902 L
.23128 .30902 L
.23148 .30902 L
.23165 .30902 L
.23183 .30902 L
.23194 .30902 L
.23203 .30902 L
.23212 .30902 L
.23222 .30902 L
.23227 .30902 L
.23233 .30902 L
.23239 .30902 L
.23244 .30902 L
.23254 .30902 L
.23264 .30902 L
.23275 .30902 L
.23285 .30902 L
.23309 .30902 L
.23329 .30902 L
Mistroke
.23347 .30902 L
.23389 .30902 L
.23428 .30902 L
.23469 .30902 L
.23542 .30902 L
.23622 .30902 L
.23709 .30902 L
.23865 .30902 L
.24033 .30902 L
.24202 .30902 L
.24363 .30902 L
.2467 .30902 L
.24996 .30902 L
.2531 .30902 L
.25644 .30902 L
.25965 .30902 L
.26274 .30902 L
.26431 .30902 L
.26514 .30902 L
.26604 .30902 L
.26689 .30902 L
.26767 .30902 L
.26805 .30902 L
.26825 .30902 L
.26846 .30902 L
.26864 .30902 L
.26874 .30902 L
.26885 .30902 L
.26894 .30902 L
.26903 .30902 L
.26911 .30902 L
.2692 .30902 L
.2693 .30902 L
.26936 .30902 L
.26941 .30902 L
.2695 .30902 L
.2696 .30902 L
.26969 .30902 L
.26978 .30902 L
.26997 .30902 L
.27018 .30902 L
.27036 .30902 L
.27079 .30902 L
.27115 .30902 L
.27154 .30902 L
.27226 .30902 L
.27309 .30902 L
.27384 .30902 L
.27553 .30902 L
.27707 .30902 L
Mistroke
.27875 .30902 L
.28204 .30902 L
.28521 .30901 L
.28826 .30901 L
.29151 .30901 L
.29464 .309 L
.29623 .309 L
.29796 .309 L
.29877 .309 L
.29963 .309 L
.29998 .309 L
.30036 .309 L
.30057 .309 L
.30077 .309 L
.30098 .309 L
.30116 .309 L
.30126 .309 L
.30136 .309 L
.30146 .309 L
.30155 .309 L
.30164 .309 L
.30174 .309 L
.3018 .309 L
.30185 .309 L
.30195 .309 L
.30205 .309 L
.30215 .309 L
.30225 .309 L
.30234 .309 L
.30268 .309 L
.30288 .309 L
.30307 .309 L
.30349 .309 L
.3039 .309 L
.30435 .309 L
.30511 .309 L
.30595 .309 L
.30765 .309 L
.30922 .30901 L
.3109 .30901 L
.31423 .30902 L
.31743 .30904 L
.32052 .30906 L
.3238 .30908 L
.32543 .30909 L
.32696 .30909 L
.32771 .30909 L
.32842 .3091 L
.32881 .3091 L
.32924 .3091 L
Mistroke
.32963 .3091 L
.32999 .3091 L
.33021 .3091 L
.3304 .3091 L
.3305 .3091 L
.33061 .3091 L
.33067 .3091 L
.33073 .3091 L
.33079 .3091 L
.33084 .3091 L
.33094 .3091 L
.33104 .3091 L
.33114 .3091 L
.33119 .3091 L
.33125 .3091 L
.33145 .3091 L
.33164 .3091 L
.33182 .3091 L
.33202 .3091 L
.33236 .3091 L
.33273 .3091 L
.33313 .3091 L
.33396 .30909 L
.33471 .30909 L
.33639 .30908 L
.33793 .30906 L
.3396 .30904 L
.34289 .30899 L
.34605 .30892 L
.34909 .30886 L
.35078 .30882 L
.35233 .30879 L
.35395 .30876 L
.35473 .30875 L
.35545 .30875 L
.3558 .30874 L
.35619 .30874 L
.3564 .30874 L
.35659 .30874 L
.35678 .30874 L
.35697 .30874 L
.35708 .30874 L
.35717 .30874 L
.35727 .30874 L
.35736 .30874 L
.35747 .30874 L
.35756 .30874 L
.35761 .30874 L
.35767 .30874 L
.35773 .30874 L
Mistroke
.35778 .30874 L
.35789 .30874 L
.358 .30874 L
.3582 .30874 L
.35841 .30874 L
.35864 .30874 L
.35906 .30874 L
.35947 .30875 L
.36022 .30876 L
.36102 .30877 L
.3619 .30879 L
.3635 .30883 L
.36519 .3089 L
.36823 .30905 L
.37148 .30926 L
.3746 .30948 L
.37619 .30958 L
.37792 .30968 L
.37872 .30972 L
.37958 .30975 L
.38031 .30977 L
.38072 .30978 L
.38111 .30979 L
.38149 .30979 L
.3817 .3098 L
.3818 .3098 L
.3819 .3098 L
.38196 .3098 L
.38201 .3098 L
.38211 .3098 L
.3822 .3098 L
.3823 .3098 L
.38241 .3098 L
.38251 .3098 L
.38256 .3098 L
.38261 .3098 L
.38273 .3098 L
.38292 .30979 L
.38309 .30979 L
.38349 .30979 L
.38384 .30978 L
.38422 .30977 L
.38504 .30974 L
.38594 .30969 L
.38678 .30964 L
.38756 .30957 L
.39073 .30921 L
.39378 .30872 L
.39702 .30813 L
.40015 .30759 L
Mistroke
.40097 .30747 L
.40186 .30736 L
.40262 .30728 L
.40303 .30724 L
.40347 .30721 L
.4039 .30718 L
.40429 .30716 L
.40467 .30714 L
.40485 .30714 L
.40495 .30714 L
.40506 .30714 L
.40512 .30713 L
.40517 .30713 L
.40523 .30713 L
.40528 .30713 L
.40538 .30713 L
.40548 .30713 L
.40554 .30713 L
.4056 .30713 L
.40566 .30713 L
.40572 .30713 L
.40582 .30713 L
.40593 .30714 L
.40614 .30714 L
.40636 .30715 L
.40675 .30716 L
.40718 .30719 L
.40758 .30722 L
.40847 .30732 L
.40926 .30743 L
.41009 .30758 L
.41167 .30795 L
.41315 .30839 L
.41628 .30957 L
.4196 .311 L
.42127 .31168 L
.42281 .31223 L
.4243 .31266 L
.42506 .31282 L
.42548 .3129 L
.42589 .31295 L
.42628 .313 L
.4265 .31301 L
.4267 .31303 L
.4268 .31303 L
.42689 .31304 L
.42698 .31304 L
.42706 .31304 L
.42716 .31305 L
.42725 .31305 L
Mistroke
.42734 .31305 L
.42745 .31305 L
.4275 .31305 L
.42756 .31304 L
.42761 .31304 L
.42767 .31304 L
.42776 .31304 L
.42787 .31303 L
.42808 .31302 L
.42831 .313 L
.42873 .31296 L
.42912 .3129 L
.42991 .31273 L
.43074 .31249 L
.43223 .31188 L
.43381 .31099 L
.43529 .30997 L
.43842 .30734 L
.44175 .30437 L
.44342 .30307 L
.44415 .30259 L
.44496 .30212 L
.44568 .30178 L
.44646 .3015 L
.44689 .30138 L
.44728 .30131 L
.44747 .30128 L
.44757 .30127 L
.44767 .30126 L
.44777 .30125 L
.44787 .30125 L
.44796 .30125 L
.44805 .30124 L
.44814 .30124 L
.44824 .30124 L
.44834 .30125 L
.44842 .30125 L
.44852 .30126 L
.44863 .30127 L
.44883 .30129 L
.44904 .30133 L
.44926 .30137 L
.44966 .30148 L
.45003 .3016 L
.45037 .30175 L
.45114 .30217 L
.45194 .30272 L
.45277 .30344 L
.45425 .30507 L
.45732 .30954 L
Mistroke
.46058 .31509 L
.46208 .31755 L
.46371 .31985 L
.46461 .32089 L
.46543 .32167 L
.46622 .32223 L
.46661 .32244 L
.46682 .32253 L
.46705 .32261 L
.46727 .32267 L
.46736 .32269 L
.46747 .32271 L
.46756 .32272 L
.46766 .32273 L
.46777 .32274 L
.46787 .32274 L
.46796 .32274 L
.46806 .32274 L
.46816 .32274 L
.46826 .32273 L
.46835 .32271 L
.46843 .3227 L
.46861 .32266 L
.46883 .32259 L
.46903 .32252 L
.46948 .32229 L
.46987 .32203 L
.47029 .32168 L
.47105 .32088 L
.47186 .31977 L
.47333 .31714 L
.47664 .30881 L
.47983 .29928 L
.48144 .29476 L
.48289 .29124 L
.48365 .28972 L
.48447 .28837 L
.48493 .28778 L
.48534 .28733 L
.48574 .287 L
.48595 .28685 L
.48616 .28675 L
.48635 .28667 L
.48646 .28663 L
.48656 .28661 L
.48664 .28659 L
.48673 .28658 L
.48683 .28657 L
.48692 .28657 L
.48702 .28658 L
Mistroke
.48712 .28659 L
.48721 .2866 L
.48731 .28663 L
.48742 .28666 L
.48753 .2867 L
.48774 .2868 L
.48813 .28708 L
.48851 .28743 L
.48921 .28836 L
.48999 .28978 L
.49081 .29173 L
.4923 .2963 L
.49534 .30911 L
.49858 .32486 L
.50007 .33153 L
.5017 .33754 L
.50258 .34003 L
.50301 .34102 L
.5034 .34176 L
.50377 .34235 L
.50418 .34284 L
.5044 .34303 L
.5045 .3431 L
.50461 .34317 L
.5047 .34321 L
.5048 .34325 L
.50486 .34327 L
.50491 .34328 L
.50501 .3433 L
.5051 .34331 L
.50519 .34331 L
.50529 .3433 L
.5054 .34327 L
.50545 .34326 L
.50551 .34323 L
.50561 .34319 L
.50581 .34306 L
.50599 .34291 L
.50619 .3427 L
.50655 .34222 L
.507 .34141 L
.50742 .34044 L
.50821 .3381 L
.509 .33513 L
.50982 .33132 L
.51131 .32295 L
.51435 .30153 L
.51605 .28887 L
.5176 .27816 L
.51838 .27334 L
Mistroke
.51922 .26884 L
.51999 .26536 L
.52072 .26279 L
.5211 .26174 L
.52145 .26096 L
.52183 .2603 L
.52203 .26005 L
.52215 .25994 L
.52225 .25986 L
.52235 .25979 L
.52245 .25975 L
.52255 .25971 L
.52261 .2597 L
.52266 .2597 L
.52275 .2597 L
.52285 .25971 L
.52295 .25975 L
.52304 .25979 L
.52316 .25987 L
.52326 .25996 L
.52346 .26018 L
.52368 .26049 L
.52391 .26093 L
.52434 .26195 L
.52474 .2632 L
.5255 .26625 L
.52631 .27056 L
.52718 .27634 L
.53047 .30638 L
.53365 .34021 L
.53524 .35535 L
.5367 .36631 L
.5375 .37082 L
.53787 .37247 L
.53827 .3739 L
.53846 .3745 L
.53868 .37506 L
.53889 .37548 L
.53907 .37578 L
.53917 .37592 L
.53929 .37604 L
.5394 .37613 L
.53946 .37616 L
.53952 .37619 L
.53958 .3762 L
.53963 .37621 L
.53973 .37621 L
.53983 .37618 L
.53989 .37616 L
.53994 .37613 L
Mistroke
.54005 .37605 L
.54014 .37595 L
.54032 .37571 L
.54051 .37537 L
.54072 .37488 L
.5411 .37375 L
.54145 .37239 L
.54226 .36815 L
.54311 .36199 L
.54467 .34675 L
.54614 .32854 L
.54924 .28373 L
.55081 .26162 L
.55165 .25111 L
.55254 .24122 L
.5534 .23332 L
.55418 .22777 L
.55456 .22571 L
.55497 .22396 L
.55516 .22333 L
.55536 .22278 L
.55553 .22241 L
.55571 .22211 L
.55582 .22199 L
.55591 .22191 L
.55602 .22186 L
.55608 .22185 L
.55613 .22185 L
.55623 .22187 L
.55633 .22193 L
.55643 .22202 L
.55653 .22213 L
.5567 .22242 L
.55689 .22285 L
.55709 .22342 L
.55727 .22408 L
.55769 .22601 L
.55808 .22828 L
.55895 .23516 L
.55974 .24351 L
.56048 .25285 L
.56215 .27881 L
.5653 .33791 L
.56688 .36683 L
.56833 .38952 L
.56907 .39899 L
.56988 .4073 L
.57028 .41049 L
.5707 .41324 L
.57093 .41446 L
Mistroke
.57114 .41537 L
.57135 .41611 L
.57145 .41638 L
.57156 .41663 L
.57166 .41682 L
.57175 .41696 L
.57184 .41707 L
.57193 .41713 L
.57203 .41717 L
.57212 .41716 L
.57223 .41711 L
.57228 .41706 L
.57234 .417 L
.57244 .41685 L
.57254 .41667 L
.57276 .4161 L
.57296 .41542 L
.57316 .41452 L
.57353 .41247 L
.57387 .41005 L
.57464 .4027 L
.57548 .39197 L
.57628 .37939 L
.57777 .35052 L
.58085 .27864 L
.58241 .24292 L
.58324 .22592 L
.58413 .20993 L
.58498 .19743 L
.58535 .19293 L
.58576 .18874 L
.58612 .1857 L
.5865 .18317 L
.58672 .18209 L
.58691 .18132 L
.587 .18102 L
.5871 .18075 L
.5872 .18054 L
.58729 .18039 L
.58738 .18027 L
.58748 .18021 L
.58757 .18019 L
.58763 .18021 L
.58768 .18023 L
.58776 .18031 L
.58786 .18044 L
.58796 .18063 L
.58805 .18085 L
.58826 .18153 L
.58845 .18237 L
Mistroke
.58888 .18501 L
.58928 .18827 L
.58971 .19279 L
.59057 .20477 L
.59215 .23535 L
.59383 .27777 L
.59716 .37188 L
.59882 .41272 L
.59956 .42733 L
.60036 .44038 L
.60074 .44523 L
.60114 .44954 L
.60152 .45271 L
.60186 .45484 L
.60206 .45573 L
.60216 .45606 L
.60225 .45632 L
.6023 .45644 L
.60236 .45656 L
.60246 .45671 L
.60251 .45676 L
.60257 .4568 L
.60268 .45681 L
.60277 .45677 L
.60287 .45665 L
.60296 .45648 L
.60304 .45628 L
.60325 .45559 L
.60345 .45467 L
.60382 .45226 L
.60422 .44857 L
.60465 .44358 L
.60505 .43788 L
.60653 .40868 L
.60815 .36465 L
.60963 .3173 L
.61128 .26268 L
.61282 .21568 L
.6143 .17884 L
.61513 .16342 L
.61588 .15328 L
.61627 .14959 L
.61646 .14814 L
.61668 .14688 L
.61686 .14608 L
.61697 .14575 L
.61706 .14551 L
.61715 .14535 L
.61724 .14525 L
.61733 .14521 L
Mistroke
.61742 .14523 L
.61752 .14534 L
.61758 .14543 L
.61764 .14554 L
.61774 .14581 L
.61784 .14617 L
.61803 .14701 L
.61823 .14821 L
.61867 .15199 L
.61909 .15684 L
.61993 .17052 L
.62073 .18787 L
.62222 .23013 L
.6253 .34038 L
.62686 .39551 L
.62769 .42141 L
.62858 .44535 L
.62943 .46353 L
.63021 .47555 L
.63058 .47962 L
.6308 .48142 L
.63099 .48275 L
.63109 .48329 L
.63118 .48372 L
.63127 .48405 L
.63135 .48434 L
.63145 .48458 L
.63154 .48473 L
.63163 .48481 L
.63174 .48482 L
.63184 .48473 L
.63194 .48456 L
.63199 .48444 L
.63205 .48428 L
.63216 .48388 L
.63236 .48287 L
.63256 .48159 L
.63292 .47836 L
.6333 .47366 L
.63373 .46707 L
.63418 .45856 L
.63498 .43961 L
.63657 .3903 L
.63804 .33462 L
.64117 .21296 L
.64199 .18613 L
.64289 .16165 L
.64329 .15231 L
.64373 .14384 L
.64413 .13732 L
Mistroke
.6445 .1326 L
.64469 .13069 L
.64489 .12897 L
.64508 .12769 L
.64526 .1268 L
.64537 .12641 L
.64547 .12614 L
.64556 .12598 L
.64565 .12589 L
.6457 .12587 L
.64576 .12589 L
.64582 .12593 L
.64587 .126 L
.64597 .1262 L
.64607 .12651 L
.64617 .12689 L
.64626 .12733 L
.64647 .1286 L
.64665 .13005 L
.64684 .13192 L
.64754 .14157 L
.64794 .14888 L
.6483 .1567 L
.64911 .17804 L
.65058 .2276 L
.65376 .35846 L
.65537 .41947 L
.65607 .4419 L
.65682 .46235 L
.65725 .47177 L
.65763 .4791 L
.65803 .48515 L
.6584 .48948 L
.65859 .49118 L
.65879 .49262 L
.6589 .49327 L
.65901 .49376 L
.65911 .4941 L
.65917 .49425 L
.65922 .49436 L
.65932 .49451 L
.65938 .49455 L
.65944 .49455 L
.65949 .49452 L
.65956 .49445 L
.65961 .49437 L
.65967 .49424 L
.65977 .49392 L
.65988 .49347 L
.66008 .49234 L
Mistroke
.66029 .49075 L
.66051 .48862 L
.6609 .48363 L
.66133 .47663 L
.66179 .46705 L
.66341 .42037 L
.66664 .28883 L
.66813 .22748 L
.66976 .17209 L
.67018 .16057 L
.67064 .14995 L
.67103 .14224 L
.67145 .13551 L
.67168 .13262 L
.67189 .13041 L
.67209 .12874 L
.67219 .128 L
.6723 .12734 L
.6724 .12684 L
.67249 .12648 L
.67259 .12621 L
.67267 .12602 L
.67277 .12591 L
.67286 .1259 L
.67296 .12598 L
.67307 .12618 L
.67316 .12644 L
.67326 .12682 L
.67346 .12791 L
.67365 .12927 L
.67382 .13086 L
.67421 .13554 L
.67463 .14219 L
.6754 .15858 L
.6761 .17777 L
.67931 .30125 L
.68078 .36343 L
.6824 .42338 L
.68317 .44625 L
.68399 .4655 L
.68445 .47349 L
.68487 .47905 L
.68507 .48112 L
.68528 .48291 L
.68538 .48357 L
.68549 .48416 L
.68559 .4846 L
.68568 .48493 L
.68578 .48518 L
.68584 .48527 L
Mistroke
.68589 .48534 L
.68595 .48537 L
.68601 .48537 L
.68611 .48529 L
.68621 .4851 L
.6863 .48484 L
.6864 .48445 L
.68651 .48394 L
.68673 .4825 L
.68694 .48071 L
.6874 .47508 L
.68781 .46847 L
.68819 .46108 L
.68903 .44009 L
.69055 .38937 L
.69221 .32257 L
.69392 .25265 L
.69547 .1981 L
.69625 .17656 L
.69666 .16716 L
.69709 .1588 L
.69747 .15288 L
.69767 .15029 L
.69788 .14794 L
.69808 .14619 L
.69826 .14492 L
.69834 .14443 L
.69844 .14397 L
.69852 .14365 L
.69861 .14338 L
.69871 .14317 L
.6988 .14307 L
.69889 .14304 L
.699 .14312 L
.69909 .14328 L
.69919 .14355 L
.69928 .14388 L
.69936 .14426 L
.69957 .14548 L
.69979 .14727 L
.7002 .15176 L
.70062 .15814 L
.70107 .16667 L
.70188 .18618 L
.70345 .23658 L
.70492 .29283 L
.70641 .35101 L
.70804 .40662 L
.70892 .43023 L
.70935 .43959 L
Mistroke
.70973 .44673 L
.71011 .45238 L
.71052 .45703 L
.71074 .45893 L
.71094 .46027 L
.71105 .46078 L
.71114 .46117 L
.71124 .46148 L
.71129 .46161 L
.71135 .46172 L
.71145 .46183 L
.7115 .46186 L
.71155 .46185 L
.71166 .46176 L
.71172 .46167 L
.71177 .46155 L
.71186 .46129 L
.71196 .46091 L
.71217 .45987 L
.71239 .45827 L
.71263 .45605 L
.71305 .45076 L
.71349 .44374 L
.7139 .43568 L
.71467 .41719 L
.71776 .31371 L
.71933 .25793 L
.72016 .23159 L
.72105 .2075 L
.72149 .1976 L
.7219 .18954 L
.72231 .18302 L
.72268 .17822 L
.72304 .1748 L
.72324 .17337 L
.72341 .17238 L
.72352 .17194 L
.72361 .17162 L
.72372 .17136 L
.72377 .17127 L
.72383 .1712 L
.72392 .17114 L
.72403 .17117 L
.72412 .17129 L
.72421 .17147 L
.72431 .17174 L
.7244 .17207 L
.7246 .17308 L
.7248 .17441 L
.72501 .17623 L
Mistroke
.7254 .18048 L
.72575 .18543 L
.7266 .20138 L
.72742 .22107 L
.73048 .31774 L
.73219 .37092 L
.733 .39189 L
.73374 .40776 L
.73452 .42023 L
.73493 .42494 L
.73514 .42684 L
.73536 .42848 L
.73556 .42958 L
.73574 .43031 L
.73582 .43057 L
.73592 .43078 L
.73601 .43092 L
.73609 .43098 L
.73618 .43099 L
.73627 .43093 L
.73637 .43079 L
.73647 .43055 L
.73658 .43022 L
.73669 .42978 L
.73689 .42875 L
.73709 .42734 L
.73729 .4257 L
.73765 .42185 L
.73847 .40972 L
.73918 .39573 L
.73994 .37752 L
.74323 .28308 L
.74402 .26163 L
.74486 .24126 L
.74559 .2266 L
.74639 .21435 L
.74681 .2096 L
.74702 .20774 L
.74721 .20633 L
.74739 .2052 L
.74758 .20425 L
.74769 .20385 L
.74779 .20355 L
.74788 .20334 L
.74798 .20318 L
.74807 .2031 L
.74815 .20309 L
.74825 .20313 L
.74834 .20323 L
.74842 .20337 L
Mistroke
.7485 .20355 L
.74867 .20412 L
.74885 .20491 L
.74904 .20604 L
.74943 .20911 L
.74983 .21328 L
.75024 .21875 L
.75099 .23105 L
.75266 .26792 L
.75573 .34558 L
.75654 .36318 L
.7573 .37714 L
.75773 .38356 L
.75819 .38936 L
.7586 .39353 L
.7588 .39515 L
.75899 .39641 L
.75917 .39743 L
.75936 .3983 L
.75947 .39867 L
.75957 .39895 L
.75966 .39915 L
.75977 .39931 L
.75985 .39938 L
.75994 .39941 L
.76003 .39939 L
.76011 .39932 L
.7602 .3992 L
.7603 .399 L
.7604 .39874 L
.7605 .39843 L
.76071 .39752 L
.76091 .39639 L
.7613 .39359 L
.76171 .38963 L
.76215 .38427 L
.76375 .3576 L
.76543 .32133 L
.76702 .28642 L
.76847 .25926 L
.76927 .24779 L
.77003 .23977 L
.77023 .23815 L
.77045 .23668 L
.77063 .23561 L
.77083 .23467 L
.77096 .2342 L
.77107 .23385 L
.77118 .23358 L
.77123 .23347 L
Mistroke
.77129 .23337 L
.77139 .23324 L
.77149 .23318 L
.77155 .23317 L
.7716 .23317 L
.77171 .23323 L
.7718 .23333 L
.7719 .23349 L
.77199 .23369 L
.77208 .23391 L
.77228 .23459 L
.77248 .23554 L
.77288 .23794 L
.77331 .24147 L
.77407 .2499 L
.77479 .25987 L
.77792 .31647 L
.77952 .34377 L
.78042 .35595 L
.78085 .36065 L
.78125 .36434 L
.78164 .36722 L
.782 .36923 L
.7822 .37011 L
.78239 .37076 L
.78249 .37103 L
.78259 .37126 L
.78265 .37137 L
.78271 .37145 L
.78281 .37157 L
.78292 .37164 L
.78297 .37165 L
.78303 .37165 L
.78313 .37162 L
.78322 .37154 L
.78328 .37147 L
.78333 .37139 L
.78344 .3712 L
.78366 .3706 L
.78386 .36988 L
.78405 .36906 L
.78446 .36664 L
.78484 .36385 L
.78524 .36023 L
.78597 .35225 L
.78762 .32899 L
.7892 .30412 L
.79004 .29162 L
.79093 .27973 L
.7918 .27023 L
Mistroke
.79258 .2638 L
.79296 .26152 L
.79316 .26055 L
.79337 .2597 L
.79356 .2591 L
.79365 .25883 L
.79376 .2586 L
.79386 .25842 L
.79394 .25829 L
.79403 .25819 L
.79412 .25812 L
.79421 .25808 L
.79431 .25808 L
.7944 .25811 L
.79448 .25817 L
.79458 .25827 L
.79468 .25842 L
.79479 .25862 L
.79489 .25885 L
.79529 .26014 L
.79551 .26112 L
.79571 .26216 L
.79647 .26734 L
.79719 .27383 L
.80028 .31144 L
.80184 .32995 L
.80267 .33789 L
.80313 .34151 L
.80356 .34439 L
.80397 .34656 L
.80419 .34749 L
.80441 .34831 L
.80463 .34892 L
.80482 .34934 L
.80491 .34949 L
.80501 .34963 L
.80511 .34973 L
.80519 .34979 L
.80528 .34983 L
.80538 .34985 L
.80547 .34983 L
.80555 .3498 L
.80565 .34973 L
.80575 .34961 L
.80585 .34948 L
.80594 .34932 L
.80612 .34893 L
.80632 .34839 L
.80672 .3469 L
.80712 .34499 L
Mistroke
.80753 .34252 L
.80828 .33706 L
.80995 .32129 L
.81156 .30459 L
.81302 .29107 L
.81383 .28509 L
.81459 .28081 L
.81501 .27908 L
.8154 .27791 L
.8156 .27745 L
.81582 .27708 L
.81594 .27695 L
.816 .27689 L
.81606 .27684 L
.81611 .27681 L
.81617 .27678 L
.81627 .27675 L
.81637 .27675 L
.81646 .27677 L
.81656 .27682 L
.81666 .2769 L
.81675 .27699 L
.81684 .2771 L
.81703 .27741 L
.81724 .27786 L
.81743 .27836 L
.81786 .27982 L
.81827 .28163 L
.81872 .28401 L
.81954 .28924 L
.82111 .30144 L
.82282 .31555 L
.82361 .32131 L
.82446 .32656 L
.82486 .32867 L
.82525 .33038 L
.82563 .33175 L
.82598 .33276 L
.82618 .33321 L
.82639 .33359 L
.82658 .33386 L
.82666 .33395 L
.82675 .33403 L
.82685 .3341 L
.82694 .33415 L
.827 .33417 L
.82705 .33418 L
.82715 .33418 L
.82726 .33416 L
.82735 .33413 L
Mistroke
.8274 .3341 L
.82746 .33406 L
.82757 .33396 L
.82776 .33374 L
.82794 .33347 L
.82834 .33263 L
.82868 .33165 L
.82905 .33037 L
.83063 .32255 L
.83211 .31322 L
.83361 .30359 L
.83441 .2991 L
.83524 .29512 L
.83567 .29347 L
.83614 .29198 L
.83656 .29093 L
.83696 .29023 L
.83717 .28997 L
.83727 .28987 L
.83736 .28979 L
.83745 .28974 L
.83754 .28969 L
.83764 .28966 L
.83774 .28964 L
.83779 .28964 L
.83785 .28965 L
.83794 .28967 L
.838 .28968 L
.83805 .28971 L
.83817 .28977 L
.83827 .28985 L
.83837 .28993 L
.83857 .29018 L
.83896 .29081 L
.83937 .29173 L
.84011 .29396 L
.84178 .3011 L
.84481 .31589 L
.84557 .31882 L
.84637 .32125 L
.84679 .32221 L
.84701 .32262 L
.84724 .323 L
.84746 .32328 L
.84766 .32347 L
.84775 .32355 L
.84786 .32362 L
.84795 .32367 L
.84804 .3237 L
.84814 .32373 L
Mistroke
.84823 .32375 L
.84833 .32375 L
.84839 .32374 L
.84844 .32374 L
.84852 .32371 L
.84862 .32368 L
.84871 .32363 L
.84881 .32358 L
.84902 .32341 L
.84921 .3232 L
.84964 .32258 L
.85004 .32183 L
.85047 .32082 L
.85133 .31827 L
.85304 .31202 L
.85459 .30611 L
.85536 .3035 L
.8562 .30113 L
.85658 .30024 L
.85699 .29944 L
.85736 .29886 L
.85772 .29843 L
.85791 .29826 L
.85811 .29812 L
.8582 .29807 L
.8583 .29802 L
.85839 .29799 L
.85848 .29797 L
.85858 .29795 L
.85868 .29795 L
.85878 .29795 L
.85884 .29796 L
.85889 .29797 L
.85899 .298 L
.8591 .29804 L
.85929 .29813 L
.85948 .29827 L
.85968 .29845 L
.86006 .29889 L
.86076 .30002 L
.86151 .30165 L
.86235 .30381 L
.86403 .30872 L
.86485 .31105 L
.86572 .31325 L
.86652 .31493 L
.86691 .3156 L
.86726 .31612 L
.86761 .31653 L
.86798 .31687 L
Mistroke
.86819 .31701 L
.86838 .31711 L
.86856 .31718 L
.86865 .3172 L
.86875 .31722 L
.8688 .31723 L
.86886 .31724 L
.86896 .31724 L
.86906 .31723 L
.86915 .31722 L
.86921 .31721 L
.86926 .3172 L
.86936 .31717 L
.86947 .31713 L
.86959 .31708 L
.86978 .31696 L
.86999 .31681 L
.87037 .31647 L
.87113 .31549 L
.87195 .3141 L
.87342 .31104 L
.87502 .30758 L
.87586 .30597 L
.87675 .30458 L
.87713 .3041 L
.87754 .30368 L
.87778 .30348 L
.87799 .30333 L
.87821 .3032 L
.87842 .30311 L
.8786 .30305 L
.8787 .30302 L
.87879 .303 L
.8789 .30299 L
.87895 .30298 L
.87901 .30298 L
.8791 .30298 L
.87921 .30298 L
.87929 .30299 L
.87939 .30301 L
.87948 .30302 L
.87956 .30305 L
.87976 .30311 L
.87995 .3032 L
.88032 .30342 L
.88073 .30374 L
.88155 .30462 L
.88303 .30675 L
.88471 .30948 L
.88545 .31059 L
Mistroke
.88626 .31165 L
.88704 .31247 L
.88742 .31278 L
.88777 .31302 L
.88796 .31312 L
.88817 .31322 L
.88835 .31328 L
.88854 .31334 L
.88865 .31336 L
.88875 .31338 L
.88885 .31339 L
.88891 .3134 L
.88897 .3134 L
.88906 .31341 L
.88917 .31341 L
.88927 .3134 L
.88936 .31339 L
.88947 .31338 L
.88958 .31336 L
.88977 .31331 L
.88998 .31324 L
.89021 .31314 L
.89063 .31291 L
.89101 .31265 L
.89251 .31123 L
.89401 .30947 L
.89563 .30765 L
.89652 .30685 L
.89691 .30657 L
.89734 .30631 L
.89775 .30611 L
.89813 .30598 L
.89833 .30593 L
.89853 .30589 L
.89863 .30588 L
.89874 .30587 L
.89879 .30587 L
.89885 .30586 L
.89891 .30586 L
.89896 .30586 L
.89905 .30586 L
.89914 .30586 L
.89924 .30587 L
.89935 .30588 L
.89946 .30589 L
.89956 .30591 L
.89976 .30595 L
.90011 .30606 L
.9005 .30621 L
.90137 .30669 L
Mistroke
.90217 .30727 L
.90379 .30863 L
.90532 .30989 L
.90603 .31037 L
.90677 .31078 L
.90717 .31095 L
.90759 .3111 L
.90778 .31115 L
.90798 .31119 L
.90817 .31122 L
.90835 .31124 L
.90844 .31125 L
.90853 .31126 L
.90863 .31126 L
.90873 .31127 L
.90879 .31127 L
.90884 .31127 L
.90895 .31126 L
.90905 .31126 L
.90915 .31125 L
.90924 .31124 L
.90933 .31123 L
.9095 .31121 L
.90988 .31113 L
.9103 .31101 L
.91069 .31087 L
.91155 .31047 L
.91319 .3095 L
.91472 .30858 L
.91548 .30818 L
.91619 .30787 L
.91659 .30773 L
.91702 .30761 L
.91721 .30757 L
.91741 .30753 L
.91758 .3075 L
.91777 .30747 L
.91796 .30745 L
.91807 .30744 L
.91816 .30744 L
.91826 .30743 L
.91834 .30743 L
.91843 .30743 L
.91852 .30743 L
.91862 .30743 L
.91873 .30744 L
.91882 .30744 L
.91891 .30745 L
.91913 .30747 L
.91934 .30749 L
Mistroke
.91971 .30756 L
.92004 .30763 L
.9208 .30785 L
.92233 .30845 L
.924 .30918 L
.92481 .3095 L
.92558 .30975 L
.926 .30987 L
.92646 .30997 L
.92688 .31004 L
.92708 .31007 L
.92726 .31009 L
.92746 .3101 L
.92764 .31012 L
.92774 .31012 L
.92784 .31012 L
.92794 .31013 L
.92799 .31013 L
.92805 .31013 L
.92814 .31013 L
.92823 .31012 L
.92833 .31012 L
.92842 .31012 L
.92859 .31011 L
.92878 .31009 L
.929 .31007 L
.92919 .31005 L
.92964 .30998 L
.93044 .30981 L
.93211 .30934 L
.93365 .30887 L
.93443 .30866 L
.93516 .30849 L
.93591 .30836 L
.93632 .30831 L
.93652 .30829 L
.93675 .30828 L
.93695 .30826 L
.93706 .30826 L
.93717 .30825 L
.93727 .30825 L
.93736 .30825 L
.93746 .30825 L
.93756 .30825 L
.93767 .30825 L
.93773 .30825 L
.93778 .30825 L
.93789 .30825 L
.93799 .30826 L
.93821 .30827 L
Mistroke
.93845 .30828 L
.93886 .30832 L
.93929 .30837 L
.94006 .3085 L
.9431 .30912 L
.9439 .30927 L
.94466 .30939 L
.94508 .30944 L
.94554 .30949 L
.94574 .3095 L
.94595 .30952 L
.94614 .30953 L
.94634 .30953 L
.94645 .30954 L
.94655 .30954 L
.94666 .30954 L
.94672 .30954 L
.94677 .30954 L
.94687 .30954 L
.94697 .30954 L
.94707 .30954 L
.94717 .30954 L
.94722 .30954 L
.94727 .30954 L
.94737 .30954 L
.9476 .30953 L
.94784 .30952 L
.94806 .30951 L
.94885 .30944 L
.94968 .30934 L
.95274 .3089 L
.95355 .3088 L
.95432 .30873 L
.95474 .3087 L
.95496 .30869 L
.9552 .30868 L
.9554 .30867 L
.9555 .30867 L
.95562 .30866 L
.95572 .30866 L
.95581 .30866 L
.95591 .30866 L
.956 .30866 L
.95609 .30866 L
.95619 .30866 L
.95628 .30866 L
.95637 .30866 L
.95646 .30866 L
.95657 .30866 L
.95667 .30866 L
Mistroke
.95677 .30866 L
.95698 .30867 L
.95717 .30868 L
.9576 .3087 L
.95835 .30875 L
.95907 .30881 L
.96054 .30895 L
.96216 .30911 L
.96292 .30917 L
.96335 .3092 L
.96375 .30922 L
.96397 .30923 L
.9642 .30924 L
.96442 .30925 L
.96462 .30925 L
.96483 .30925 L
.96494 .30926 L
.96504 .30926 L
.96514 .30926 L
.96523 .30926 L
.96533 .30926 L
.96544 .30926 L
.96553 .30926 L
.96559 .30926 L
.96564 .30926 L
.96573 .30926 L
.96583 .30926 L
.96601 .30925 L
.9662 .30925 L
.96662 .30924 L
.96701 .30922 L
.96772 .30919 L
.96848 .30914 L
.97006 .30903 L
.9709 .30898 L
.97179 .30893 L
.97223 .30891 L
.97265 .30889 L
.97306 .30888 L
.97343 .30887 L
.97362 .30886 L
.97379 .30886 L
.97397 .30886 L
.97407 .30886 L
.97417 .30886 L
.97427 .30886 L
.97433 .30885 L
.97438 .30885 L
.97448 .30885 L
.97459 .30885 L
Mistroke
.97469 .30885 L
.97479 .30886 L
.97487 .30886 L
.97497 .30886 L
.97525 .30886 L
.97541 .30886 L
.97556 .30887 L
.97619 .30888 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{421.375, 260.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 525.688}, {324.5, 0}} -> {-2.58312*^-7, -6.34248*^6, \
6.65005*^-9, 53093.5}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0.309017 5.42214e-08 [
[.32684 .29652 -16.5 -12.5 ]
[.32684 .29652 16.5 0 ]
[.54329 .29652 -16.5 -12.5 ]
[.54329 .29652 16.5 0 ]
[.75974 .29652 -22.5 -12.5 ]
[.75974 .29652 22.5 0 ]
[.97619 .29652 -16.5 -12.5 ]
[.97619 .29652 16.5 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 64 6 ]
[.09789 .09213 -34.5 -6.25 ]
[.09789 .09213 0 6.25 ]
[.09789 .20057 -34.5 -6.25 ]
[.09789 .20057 0 6.25 ]
[.09789 .41746 -28.5 -6.25 ]
[.09789 .41746 0 6.25 ]
[.09789 .5259 -28.5 -6.25 ]
[.09789 .5259 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -65.8125 0 ]
[.5 .63053 65.8125 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 .30902 m
.32684 .31527 L
s
gsave
.32684 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 .30902 m
.54329 .31527 L
s
gsave
.54329 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 .30902 m
.75974 .31527 L
s
gsave
.75974 .29652 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 .30902 m
.15368 .31277 L
s
.19697 .30902 m
.19697 .31277 L
s
.24026 .30902 m
.24026 .31277 L
s
.28355 .30902 m
.28355 .31277 L
s
.37013 .30902 m
.37013 .31277 L
s
.41342 .30902 m
.41342 .31277 L
s
.45671 .30902 m
.45671 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.58658 .30902 m
.58658 .31277 L
s
.62987 .30902 m
.62987 .31277 L
s
.67316 .30902 m
.67316 .31277 L
s
.71645 .30902 m
.71645 .31277 L
s
.80303 .30902 m
.80303 .31277 L
s
.84632 .30902 m
.84632 .31277 L
s
.88961 .30902 m
.88961 .31277 L
s
.9329 .30902 m
.9329 .31277 L
s
.0671 .30902 m
.0671 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09213 m
.11664 .09213 L
s
gsave
.09789 .09213 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .20057 m
.11664 .20057 L
s
gsave
.09789 .20057 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .41746 m
.11664 .41746 L
s
gsave
.09789 .41746 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .5259 m
.11664 .5259 L
s
gsave
.09789 .5259 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.11039 .11924 m
.11414 .11924 L
s
.11039 .14635 m
.11414 .14635 L
s
.11039 .17346 m
.11414 .17346 L
s
.11039 .22768 m
.11414 .22768 L
s
.11039 .2548 m
.11414 .2548 L
s
.11039 .28191 m
.11414 .28191 L
s
.11039 .33613 m
.11414 .33613 L
s
.11039 .36324 m
.11414 .36324 L
s
.11039 .39035 m
.11414 .39035 L
s
.11039 .44457 m
.11414 .44457 L
s
.11039 .47168 m
.11414 .47168 L
s
.11039 .49879 m
.11414 .49879 L
s
.11039 .06502 m
.11414 .06502 L
s
.11039 .03791 m
.11414 .03791 L
s
.11039 .0108 m
.11414 .0108 L
s
.11039 .55301 m
.11414 .55301 L
s
.11039 .58012 m
.11414 .58012 L
s
.11039 .60723 m
.11414 .60723 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -126.812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.812 moveto
(@) show
81.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.812 moveto
(D) show
93.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11.2) show
141.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
147.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
159.000 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
163.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
172.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
190.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02691 .30902 L
.03029 .30902 L
.03347 .30902 L
.03652 .30902 L
.03978 .30902 L
.04291 .30902 L
.04623 .30902 L
.04944 .30902 L
.05252 .30902 L
.0558 .30902 L
.05896 .30902 L
.062 .30902 L
.06523 .30902 L
.06834 .30902 L
.07165 .30902 L
.07484 .30902 L
.0779 .30902 L
.08117 .30902 L
.08431 .30902 L
.08765 .30902 L
.09086 .30902 L
.09396 .30902 L
.09725 .30902 L
.10042 .30902 L
.10346 .30902 L
.10671 .30902 L
.10983 .30902 L
.11315 .30902 L
.11635 .30902 L
.11943 .30902 L
.12101 .30902 L
.12183 .30902 L
.12225 .30902 L
.1227 .30902 L
.12309 .30902 L
.1233 .30902 L
.12352 .30902 L
.12372 .30902 L
.1239 .30902 L
.12399 .30902 L
.12409 .30902 L
.12417 .30902 L
.12426 .30902 L
.12435 .30902 L
.12444 .30902 L
.12454 .30902 L
.12463 .30902 L
.12473 .30902 L
.12484 .30902 L
Mistroke
.12493 .30902 L
.12503 .30902 L
.12521 .30902 L
.12537 .30902 L
.12573 .30902 L
.12592 .30902 L
.12612 .30902 L
.12654 .30902 L
.12728 .30902 L
.1277 .30902 L
.12814 .30902 L
.12895 .30902 L
.12977 .30902 L
.13066 .30902 L
.13227 .30902 L
.13387 .30902 L
.13555 .30902 L
.13712 .30902 L
.13859 .30902 L
.1417 .30902 L
.14331 .30902 L
.145 .30902 L
.14807 .30902 L
.15133 .30902 L
.15446 .30902 L
.1578 .30902 L
.16101 .30902 L
.1641 .30902 L
.16739 .30902 L
.17056 .30902 L
.17361 .30902 L
.17685 .30902 L
.17997 .30902 L
.18156 .30902 L
.18329 .30902 L
.18409 .30902 L
.18494 .30902 L
.18567 .30902 L
.18609 .30902 L
.18629 .30902 L
.18648 .30902 L
.18668 .30902 L
.18686 .30902 L
.18696 .30902 L
.18706 .30902 L
.18716 .30902 L
.18722 .30902 L
.18727 .30902 L
.18737 .30902 L
.18746 .30902 L
Mistroke
.18756 .30902 L
.18762 .30902 L
.18767 .30902 L
.18778 .30902 L
.18789 .30902 L
.1881 .30902 L
.18829 .30902 L
.18847 .30902 L
.18887 .30902 L
.18924 .30902 L
.18958 .30902 L
.19037 .30902 L
.1912 .30902 L
.1919 .30902 L
.19268 .30902 L
.19425 .30902 L
.19593 .30902 L
.19763 .30902 L
.19925 .30902 L
.20233 .30902 L
.20391 .30902 L
.2056 .30902 L
.20863 .30902 L
.21186 .30902 L
.21497 .30902 L
.21827 .30902 L
.22145 .30902 L
.22451 .30902 L
.22622 .30902 L
.22777 .30902 L
.2294 .30902 L
.23012 .30902 L
.23091 .30902 L
.23127 .30902 L
.23166 .30902 L
.23187 .30902 L
.23207 .30902 L
.23226 .30902 L
.23245 .30902 L
.23255 .30902 L
.23265 .30902 L
.2327 .30902 L
.23276 .30902 L
.23286 .30902 L
.23296 .30902 L
.23306 .30902 L
.23315 .30902 L
.23325 .30902 L
.23336 .30902 L
.23347 .30902 L
Mistroke
.2337 .30902 L
.23391 .30902 L
.23412 .30902 L
.23449 .30902 L
.2349 .30902 L
.23572 .30902 L
.23649 .30902 L
.2372 .30902 L
.23883 .30902 L
.24031 .30902 L
.24184 .30902 L
.2435 .30902 L
.24676 .30902 L
.2499 .30902 L
.25324 .30902 L
.25645 .30902 L
.25954 .30902 L
.26284 .30902 L
.26447 .30902 L
.266 .30902 L
.26747 .30902 L
.2683 .30902 L
.26905 .30902 L
.26944 .30902 L
.26965 .30902 L
.26985 .30902 L
.27001 .30902 L
.2701 .30902 L
.2702 .30902 L
.27029 .30902 L
.2704 .30902 L
.27049 .30902 L
.27058 .30902 L
.27069 .30902 L
.27074 .30902 L
.2708 .30902 L
.2709 .30902 L
.271 .30902 L
.27119 .30902 L
.27139 .30902 L
.2716 .30902 L
.27183 .30902 L
.27225 .30902 L
.27267 .30902 L
.27306 .30902 L
.27395 .30902 L
.27473 .30902 L
.27556 .30902 L
.27728 .30902 L
.2789 .30902 L
Mistroke
.282 .30902 L
.28529 .30901 L
.28847 .30901 L
.29152 .30901 L
.29476 .30901 L
.29789 .309 L
.2996 .309 L
.30038 .309 L
.30121 .309 L
.30158 .309 L
.30198 .309 L
.3022 .309 L
.30241 .309 L
.30262 .309 L
.30281 .309 L
.30298 .309 L
.30307 .309 L
.30316 .309 L
.30325 .309 L
.30335 .309 L
.30345 .309 L
.30354 .309 L
.30363 .309 L
.30371 .309 L
.3038 .309 L
.3039 .309 L
.30411 .309 L
.30429 .309 L
.30468 .309 L
.30509 .309 L
.30544 .309 L
.30582 .309 L
.30668 .309 L
.30749 .309 L
.30911 .309 L
.31059 .30901 L
.31211 .30901 L
.31377 .30902 L
.31702 .30903 L
.32015 .30904 L
.32348 .30906 L
.32668 .30907 L
.32815 .30908 L
.32899 .30908 L
.32977 .30909 L
.3306 .30909 L
.33136 .30909 L
.33156 .30909 L
.33178 .30909 L
.33198 .30909 L
Mistroke
.33217 .30909 L
.33239 .30909 L
.33251 .30909 L
.33257 .30909 L
.33263 .30909 L
.33273 .30909 L
.33283 .30909 L
.33293 .30909 L
.33299 .30909 L
.33305 .30909 L
.33315 .30909 L
.3332 .30909 L
.33326 .30909 L
.33345 .30909 L
.33356 .30909 L
.33368 .30909 L
.33389 .30909 L
.3343 .30909 L
.33468 .30909 L
.33541 .30909 L
.33617 .30908 L
.33694 .30908 L
.33776 .30908 L
.33923 .30906 L
.34095 .30905 L
.34256 .30903 L
.34565 .30898 L
.34894 .30892 L
.3521 .30886 L
.35514 .30881 L
.3567 .30879 L
.35758 .30878 L
.35797 .30878 L
.35838 .30878 L
.35859 .30878 L
.3588 .30877 L
.35899 .30877 L
.35917 .30877 L
.35934 .30877 L
.35943 .30877 L
.35953 .30877 L
.35962 .30877 L
.35971 .30877 L
.35981 .30877 L
.35991 .30877 L
.36001 .30877 L
.36006 .30877 L
.36012 .30877 L
.36022 .30877 L
.36032 .30877 L
Mistroke
.36053 .30877 L
.36076 .30877 L
.36098 .30877 L
.36119 .30878 L
.36157 .30878 L
.36234 .30879 L
.36316 .3088 L
.36393 .30881 L
.36464 .30882 L
.36618 .30886 L
.36785 .30892 L
.37114 .30908 L
.37431 .30926 L
.37735 .30944 L
.37905 .30953 L
.3806 .30961 L
.38136 .30964 L
.3822 .30966 L
.38258 .30967 L
.38299 .30968 L
.38334 .30969 L
.38372 .3097 L
.3839 .3097 L
.38411 .3097 L
.38429 .3097 L
.38447 .3097 L
.38457 .3097 L
.38467 .30971 L
.38476 .30971 L
.38486 .30971 L
.38496 .30971 L
.38502 .30971 L
.38508 .3097 L
.38518 .3097 L
.38528 .3097 L
.38547 .3097 L
.38565 .3097 L
.38598 .3097 L
.38635 .30969 L
.38674 .30968 L
.38757 .30966 L
.38833 .30962 L
.38919 .30958 L
.39001 .30952 L
.39162 .30938 L
.39311 .30922 L
.39628 .30878 L
.39933 .30829 L
.40257 .3078 L
.40407 .30761 L
Mistroke
.40486 .30752 L
.4057 .30745 L
.40612 .30742 L
.40659 .30739 L
.40701 .30737 L
.40741 .30736 L
.4076 .30735 L
.40771 .30735 L
.40781 .30735 L
.40791 .30735 L
.40799 .30735 L
.40808 .30735 L
.40818 .30735 L
.40824 .30735 L
.40829 .30735 L
.40839 .30735 L
.40845 .30735 L
.4085 .30735 L
.40855 .30735 L
.40862 .30735 L
.40872 .30735 L
.40883 .30735 L
.40902 .30736 L
.40923 .30736 L
.40943 .30737 L
.40979 .30739 L
.41019 .30741 L
.41062 .30744 L
.41139 .30752 L
.41209 .30761 L
.41361 .30787 L
.41527 .30826 L
.41852 .30928 L
.42165 .31045 L
.42325 .31104 L
.42498 .31164 L
.4265 .31208 L
.42737 .31228 L
.42818 .31243 L
.42858 .31249 L
.42895 .31253 L
.42915 .31255 L
.42938 .31257 L
.42958 .31258 L
.42977 .31259 L
.42988 .3126 L
.43 .3126 L
.4301 .3126 L
.4302 .31261 L
.4303 .31261 L
Mistroke
.43036 .31261 L
.43042 .31261 L
.43048 .31261 L
.43053 .31261 L
.43059 .31261 L
.43065 .3126 L
.43075 .3126 L
.43085 .3126 L
.43104 .31259 L
.43124 .31258 L
.43146 .31256 L
.43186 .31252 L
.43227 .31246 L
.43301 .31231 L
.43381 .3121 L
.43469 .31181 L
.43626 .31111 L
.43794 .31014 L
.44127 .30772 L
.44448 .30517 L
.44595 .3041 L
.44757 .30312 L
.44834 .30275 L
.44917 .30243 L
.44962 .30229 L
.45004 .30219 L
.45024 .30215 L
.45046 .30211 L
.45066 .30209 L
.45085 .30207 L
.45096 .30206 L
.45101 .30206 L
.45107 .30206 L
.45116 .30205 L
.45126 .30205 L
.45132 .30205 L
.45137 .30205 L
.45148 .30205 L
.45153 .30205 L
.45159 .30206 L
.4517 .30206 L
.4518 .30207 L
.45189 .30208 L
.45209 .3021 L
.45229 .30213 L
.4525 .30217 L
.45288 .30226 L
.45328 .30239 L
.454 .30268 L
.45477 .30311 L
Mistroke
.45559 .30368 L
.45706 .305 L
.4604 .30919 L
.46361 .31406 L
.4667 .31836 L
.4683 .32002 L
.4691 .32063 L
.46956 .32091 L
.46999 .32111 L
.47038 .32125 L
.4706 .32131 L
.47071 .32133 L
.47081 .32135 L
.4709 .32136 L
.47098 .32137 L
.47107 .32138 L
.47117 .32139 L
.47126 .32139 L
.47136 .32139 L
.47146 .32139 L
.47155 .32138 L
.47166 .32137 L
.47177 .32136 L
.47198 .32132 L
.47218 .32127 L
.47236 .32121 L
.47278 .32103 L
.47323 .32078 L
.47399 .32018 L
.4748 .31933 L
.47627 .31721 L
.47797 .31393 L
.47958 .31015 L
.48265 .302 L
.48436 .29752 L
.48591 .29392 L
.48669 .29239 L
.48753 .29097 L
.48832 .28992 L
.48905 .28922 L
.48943 .28896 L
.48964 .28885 L
.48983 .28877 L
.49001 .28872 L
.49012 .28869 L
.49021 .28868 L
.49029 .28867 L
.49038 .28866 L
.49048 .28866 L
.49056 .28866 L
Mistroke
.49066 .28867 L
.49077 .28868 L
.49082 .2887 L
.49088 .28871 L
.49098 .28874 L
.49118 .28881 L
.49136 .2889 L
.49181 .28919 L
.49222 .28958 L
.493 .29059 L
.49383 .29206 L
.49531 .2957 L
.49688 .30082 L
.49835 .30654 L
.50147 .32015 L
.50306 .32688 L
.50479 .33322 L
.50559 .33562 L
.50644 .33769 L
.50686 .3385 L
.50725 .33913 L
.5076 .33959 L
.50798 .33997 L
.50817 .34011 L
.50828 .34017 L
.50837 .34022 L
.50847 .34026 L
.50857 .34029 L
.50866 .34031 L
.50874 .34032 L
.50884 .34033 L
.50894 .34032 L
.50904 .34031 L
.5091 .3403 L
.50915 .34028 L
.50926 .34025 L
.50937 .3402 L
.50958 .34007 L
.50981 .33989 L
.51001 .33968 L
.51046 .33906 L
.51088 .33831 L
.51128 .33744 L
.51206 .33527 L
.51289 .33234 L
.51437 .32558 L
.51741 .3071 L
.52066 .28534 L
.52215 .27657 L
.52294 .27264 L
Mistroke
.52378 .26912 L
.5242 .26766 L
.52466 .26628 L
.52509 .26526 L
.52548 .26454 L
.52568 .26426 L
.52588 .26402 L
.52609 .26385 L
.52621 .26377 L
.52626 .26375 L
.52632 .26372 L
.52642 .26369 L
.52651 .26368 L
.52661 .26367 L
.52669 .26368 L
.52679 .26371 L
.52689 .26375 L
.527 .26381 L
.5271 .26388 L
.52731 .26407 L
.5275 .26431 L
.52793 .26506 L
.52832 .26597 L
.52873 .26718 L
.52951 .27018 L
.53021 .27368 L
.53176 .28368 L
.53343 .29751 L
.53673 .32941 L
.53837 .34476 L
.5399 .35695 L
.54066 .36185 L
.54137 .36564 L
.54177 .36734 L
.5422 .36886 L
.54259 .36993 L
.54295 .37064 L
.54314 .37091 L
.54332 .37109 L
.54342 .37116 L
.54352 .37121 L
.54357 .37122 L
.54362 .37124 L
.54372 .37124 L
.54382 .37122 L
.54392 .37119 L
.54402 .37113 L
.5441 .37106 L
.54427 .37088 L
.54445 .37062 L
Mistroke
.54465 .37025 L
.54486 .36976 L
.54524 .36862 L
.54569 .36685 L
.5461 .36484 L
.54763 .35429 L
.5485 .34631 L
.5493 .3378 L
.55245 .2975 L
.55547 .25829 L
.55702 .24253 L
.55789 .23584 L
.55828 .23346 L
.5587 .23134 L
.55911 .2297 L
.55948 .22862 L
.55966 .22825 L
.55976 .22809 L
.55986 .22795 L
.55994 .22785 L
.56004 .22777 L
.56013 .22772 L
.56021 .22769 L
.56031 .22769 L
.56037 .2277 L
.56043 .22772 L
.56052 .22779 L
.56063 .22788 L
.56073 .22801 L
.56083 .22816 L
.56101 .22852 L
.56123 .22908 L
.56143 .22971 L
.56187 .2316 L
.56225 .23366 L
.56265 .23634 L
.56338 .24239 L
.56504 .26147 L
.56836 .31536 L
.57002 .34492 L
.57156 .3702 L
.57305 .39042 L
.57381 .39836 L
.57421 .40189 L
.57464 .405 L
.57502 .40726 L
.57523 .40823 L
.57545 .4091 L
.57565 .40973 L
.57583 .41018 L
Mistroke
.57592 .41034 L
.57602 .41049 L
.57611 .41059 L
.57619 .41066 L
.57629 .4107 L
.57639 .41071 L
.57649 .41067 L
.57658 .41061 L
.57668 .41049 L
.5768 .41031 L
.577 .40986 L
.57722 .40919 L
.57745 .40828 L
.57786 .4061 L
.5783 .4031 L
.57869 .3997 L
.57959 .38983 L
.58121 .36499 L
.58438 .29885 L
.58743 .23371 L
.589 .20809 L
.58945 .20234 L
.58988 .19766 L
.59026 .19417 L
.59068 .19108 L
.59088 .18994 L
.59108 .18891 L
.59126 .18819 L
.59146 .18758 L
.59157 .18733 L
.59167 .18714 L
.59172 .18707 L
.59178 .18701 L
.59184 .18695 L
.59189 .18692 L
.59199 .1869 L
.59208 .18693 L
.59218 .18701 L
.59228 .18714 L
.59238 .18731 L
.59246 .1875 L
.59265 .18805 L
.59282 .18873 L
.59299 .18951 L
.59336 .19178 L
.59376 .19503 L
.59452 .20325 L
.59535 .21542 L
.59703 .24876 L
.60026 .33225 L
Mistroke
.60174 .3714 L
.60336 .4087 L
.60414 .42321 L
.60497 .43564 L
.60543 .44099 L
.60585 .44485 L
.60605 .44635 L
.60627 .44771 L
.60646 .44867 L
.60656 .4491 L
.60666 .44945 L
.60676 .44974 L
.60687 .44998 L
.60696 .45014 L
.60705 .45024 L
.60715 .45029 L
.60723 .45029 L
.60733 .45023 L
.60742 .45012 L
.60752 .44994 L
.60763 .44968 L
.60782 .44903 L
.60803 .44808 L
.60826 .44673 L
.60868 .44339 L
.60913 .4386 L
.60994 .42695 L
.61076 .4116 L
.61165 .39121 L
.61327 .34645 L
.61654 .24453 L
.61817 .20042 L
.61896 .18288 L
.61969 .16981 L
.62041 .16019 L
.62076 .15661 L
.62115 .1537 L
.62136 .15259 L
.62155 .15185 L
.62165 .15154 L
.62171 .15142 L
.62176 .1513 L
.62182 .15122 L
.62187 .15116 L
.62197 .1511 L
.62207 .15111 L
.62216 .15118 L
.62226 .15133 L
.62236 .15155 L
.62245 .15182 L
Mistroke
.62254 .15212 L
.62273 .15299 L
.62294 .15428 L
.62314 .15575 L
.62358 .16008 L
.62397 .16503 L
.62438 .17139 L
.62587 .20351 L
.62745 .25006 L
.62893 .30065 L
.63206 .40743 L
.63288 .43042 L
.63377 .4512 L
.63417 .45903 L
.63461 .46607 L
.63501 .47142 L
.63538 .47522 L
.63557 .47671 L
.63577 .47802 L
.63586 .47851 L
.63596 .47896 L
.63605 .47931 L
.63614 .47957 L
.63624 .47981 L
.6363 .4799 L
.63636 .47996 L
.63646 .48001 L
.63651 .48001 L
.63656 .47998 L
.63666 .47986 L
.63675 .47968 L
.63685 .4794 L
.63695 .47905 L
.63713 .47822 L
.63732 .47704 L
.63765 .47421 L
.63802 .47014 L
.63842 .46442 L
.63923 .44916 L
.63997 .43111 L
.64165 .37876 L
.64482 .25779 L
.64643 .20143 L
.64788 .1613 L
.64827 .15301 L
.64869 .14533 L
.64906 .13984 L
.64946 .13509 L
.64968 .13307 L
.64988 .13157 L
Mistroke
.6501 .13038 L
.65022 .1299 L
.65027 .12973 L
.65033 .12958 L
.65043 .12939 L
.65053 .12929 L
.65059 .12927 L
.65064 .12928 L
.65075 .12937 L
.65084 .12955 L
.65093 .12979 L
.65103 .13014 L
.65114 .1306 L
.65134 .1318 L
.65154 .13329 L
.6519 .13697 L
.65229 .14223 L
.65272 .14943 L
.65348 .16608 L
.65419 .18533 L
.65734 .30219 L
.66038 .42011 L
.66114 .4436 L
.66193 .46402 L
.66235 .47273 L
.66281 .48054 L
.66322 .48603 L
.66361 .4897 L
.66382 .49112 L
.66392 .49165 L
.66402 .49205 L
.66412 .49239 L
.66417 .49253 L
.66423 .49265 L
.66429 .49274 L
.66435 .49279 L
.6644 .49281 L
.66446 .4928 L
.66455 .49272 L
.66466 .49252 L
.66471 .49238 L
.66477 .4922 L
.66487 .49179 L
.66507 .49071 L
.66525 .48938 L
.6656 .48599 L
.66598 .48098 L
.66675 .46692 L
.66757 .44633 L
.66832 .42326 L
Mistroke
.67 .36013 L
.67167 .28978 L
.6732 .22705 L
.6747 .17591 L
.67546 .15588 L
.67588 .14664 L
.67629 .13935 L
.67668 .13378 L
.67688 .13143 L
.6771 .12937 L
.67731 .12788 L
.67749 .12689 L
.67758 .12653 L
.67767 .12624 L
.67776 .12604 L
.67785 .12593 L
.67794 .12589 L
.67805 .12595 L
.67815 .12611 L
.67824 .12634 L
.67834 .12672 L
.67845 .12725 L
.67866 .12855 L
.67888 .13036 L
.67911 .13279 L
.67952 .13845 L
.68028 .15281 L
.68109 .17372 L
.68255 .22335 L
.68586 .36073 L
.68751 .42236 L
.68831 .44654 L
.68904 .46412 L
.6894 .47117 L
.6898 .4774 L
.69017 .48191 L
.69034 .48347 L
.69052 .48484 L
.69062 .48546 L
.69071 .48593 L
.6908 .48634 L
.69088 .48663 L
.69098 .48689 L
.69103 .48698 L
.69109 .48705 L
.69119 .4871 L
.69129 .48704 L
.69139 .48688 L
.69149 .48663 L
.69159 .48625 L
Mistroke
.6917 .48572 L
.69189 .48455 L
.6921 .48286 L
.69252 .47809 L
.69292 .47199 L
.69367 .45663 L
.69447 .43489 L
.69535 .40609 L
.69863 .27374 L
.70026 .21187 L
.70105 .18676 L
.70178 .16788 L
.70214 .16024 L
.70253 .15321 L
.70291 .14783 L
.70325 .14411 L
.70345 .14242 L
.70364 .14121 L
.70375 .1407 L
.70384 .14032 L
.70395 .14002 L
.704 .13991 L
.70406 .13983 L
.70416 .13976 L
.70425 .13979 L
.70435 .13992 L
.70445 .14015 L
.70454 .14044 L
.70463 .14079 L
.70482 .14184 L
.70501 .14327 L
.70519 .14491 L
.70559 .14972 L
.70594 .15521 L
.70632 .16222 L
.7071 .18094 L
.70797 .2067 L
.71122 .33103 L
.71273 .38733 L
.71352 .4128 L
.71436 .43523 L
.71478 .44449 L
.71525 .4529 L
.71567 .45885 L
.71607 .46289 L
.71628 .46441 L
.71638 .46501 L
.71647 .46547 L
.71657 .46583 L
.71665 .46609 L
Mistroke
.71675 .4663 L
.71685 .46642 L
.7169 .46645 L
.71695 .46644 L
.71705 .46636 L
.71711 .46628 L
.71716 .46617 L
.71728 .46584 L
.71738 .46543 L
.71747 .46497 L
.71768 .46364 L
.71787 .46213 L
.71807 .4601 L
.71848 .45484 L
.71922 .44168 L
.72008 .4209 L
.72089 .39693 L
.72399 .28412 L
.72557 .22995 L
.72641 .20627 L
.72686 .19524 L
.7273 .18629 L
.72771 .17912 L
.72816 .17301 L
.72836 .17088 L
.72857 .16901 L
.72875 .16772 L
.72895 .16665 L
.72905 .16624 L
.72915 .16593 L
.72923 .16573 L
.72933 .1656 L
.72943 .16554 L
.72949 .16555 L
.72954 .16559 L
.72964 .16573 L
.72974 .16596 L
.72983 .16624 L
.72993 .16662 L
.7301 .16751 L
.73028 .16876 L
.73048 .17048 L
.7309 .17523 L
.7313 .1811 L
.73205 .19546 L
.73373 .24085 L
.73682 .34501 L
.73838 .39135 L
.73926 .41179 L
.73969 .41967 L
Mistroke
.7401 .42588 L
.74048 .43052 L
.74068 .43249 L
.74089 .43422 L
.74109 .43548 L
.74127 .43633 L
.74135 .43665 L
.74145 .43691 L
.74154 .4371 L
.74162 .43721 L
.74171 .43727 L
.74181 .43725 L
.74191 .43715 L
.742 .43698 L
.7421 .43671 L
.74221 .43632 L
.74241 .43534 L
.74262 .43394 L
.74285 .43206 L
.74325 .42767 L
.74401 .41622 L
.74482 .39959 L
.74628 .36077 L
.74786 .31233 L
.74959 .26076 L
.75038 .2402 L
.75123 .22186 L
.75165 .21457 L
.75204 .20875 L
.75241 .20415 L
.75277 .2008 L
.75296 .19936 L
.75314 .19829 L
.75333 .19739 L
.75344 .19702 L
.75355 .19676 L
.75365 .19658 L
.75375 .19648 L
.75385 .19646 L
.75394 .19651 L
.754 .19657 L
.75405 .19664 L
.75416 .19689 L
.75427 .1972 L
.75437 .1976 L
.75455 .19846 L
.75474 .19963 L
.75508 .20242 L
.75548 .20681 L
.75585 .21177 L
Mistroke
.75739 .24101 L
.75906 .28363 L
.76061 .32647 L
.76144 .34784 L
.76233 .3683 L
.76318 .38439 L
.76356 .39017 L
.76396 .39553 L
.76432 .39939 L
.76471 .40257 L
.76492 .4039 L
.76511 .40483 L
.76521 .40519 L
.76531 .40551 L
.7654 .40575 L
.76549 .40592 L
.76559 .40604 L
.76569 .4061 L
.76577 .40609 L
.76587 .40603 L
.76597 .40589 L
.76602 .40579 L
.76608 .40566 L
.76627 .40506 L
.76645 .40427 L
.76665 .40318 L
.767 .40056 L
.76742 .39643 L
.76786 .39093 L
.76866 .37847 L
.77171 .31085 L
.77342 .27204 L
.77422 .25649 L
.77497 .24459 L
.77574 .23521 L
.77614 .2316 L
.77635 .23013 L
.77658 .22884 L
.77677 .22795 L
.77695 .22734 L
.77704 .22712 L
.77713 .22693 L
.77722 .22679 L
.7773 .22671 L
.7774 .22667 L
.7775 .22668 L
.77759 .22675 L
.77769 .22687 L
.77779 .22707 L
.7779 .22735 L
Mistroke
.7781 .22803 L
.7783 .22897 L
.7785 .23008 L
.77886 .23273 L
.77925 .23638 L
.77967 .24121 L
.78115 .26388 L
.7827 .29432 L
.78442 .32903 L
.7852 .34326 L
.78605 .35648 L
.78684 .36637 L
.78723 .3701 L
.78757 .37287 L
.78796 .37521 L
.78816 .37618 L
.78836 .37688 L
.78845 .37713 L
.78854 .37735 L
.78863 .37751 L
.78871 .37763 L
.78881 .37772 L
.78889 .37777 L
.789 .37777 L
.78909 .37772 L
.7892 .37761 L
.78925 .37753 L
.78931 .37744 L
.7895 .37698 L
.78961 .37663 L
.78973 .37619 L
.78995 .37522 L
.79037 .37266 L
.79076 .36958 L
.79154 .36143 L
.79227 .35183 L
.79393 .32525 L
.79543 .29946 L
.79706 .27481 L
.79795 .26451 L
.79834 .2609 L
.79877 .25764 L
.79917 .25527 L
.79937 .25439 L
.79955 .2537 L
.79965 .25339 L
.79976 .25311 L
.79986 .25289 L
.79995 .25273 L
.80006 .2526 L
Mistroke
.80012 .25254 L
.80018 .2525 L
.80028 .25247 L
.80033 .25247 L
.80039 .25249 L
.80049 .25255 L
.80058 .25265 L
.80067 .25277 L
.80076 .25294 L
.80097 .25346 L
.80117 .2541 L
.80152 .25568 L
.8019 .2579 L
.80268 .26424 L
.80355 .27351 L
.80678 .31783 L
.80826 .33633 L
.8091 .34449 L
.80951 .34769 L
.80988 .35011 L
.81028 .35217 L
.81066 .35359 L
.81087 .35414 L
.81106 .35451 L
.81116 .35465 L
.81122 .35471 L
.81127 .35476 L
.81133 .3548 L
.81138 .35483 L
.81144 .35485 L
.81149 .35485 L
.81155 .35484 L
.8116 .35483 L
.8117 .35477 L
.8118 .35467 L
.81191 .35452 L
.81201 .35435 L
.81212 .35413 L
.8123 .35365 L
.81272 .35211 L
.81319 .34976 L
.81401 .344 L
.81475 .33728 L
.81643 .31887 L
.8181 .29967 L
.81883 .29202 L
.81963 .28471 L
.82041 .27911 L
.82076 .27708 L
.82113 .27532 L
Mistroke
.82132 .27457 L
.82153 .27388 L
.82172 .27335 L
.82189 .27298 L
.82199 .2728 L
.8221 .27265 L
.82216 .27258 L
.82221 .27252 L
.82227 .27248 L
.82232 .27244 L
.82241 .2724 L
.82251 .27238 L
.82261 .27239 L
.82271 .27244 L
.82281 .27251 L
.82292 .27262 L
.82303 .27277 L
.82314 .27295 L
.82333 .27335 L
.82353 .27389 L
.82399 .27555 L
.82442 .27756 L
.8252 .28239 L
.82603 .28875 L
.82909 .31673 L
.83066 .32883 L
.83111 .33152 L
.83154 .33366 L
.83192 .33521 L
.83212 .3359 L
.83234 .33652 L
.83255 .33702 L
.83274 .33738 L
.83283 .33752 L
.83293 .33765 L
.83303 .33775 L
.83312 .33782 L
.83317 .33785 L
.83322 .33788 L
.83332 .33791 L
.83338 .33792 L
.83344 .33792 L
.83354 .33789 L
.83364 .33785 L
.83373 .33778 L
.83383 .33769 L
.83394 .33756 L
.83413 .33727 L
.83434 .33686 L
.83472 .33586 L
Mistroke
.83508 .33459 L
.83542 .33318 L
.83692 .32465 L
.83857 .31265 L
.84026 .3005 L
.84099 .29594 L
.8418 .29183 L
.84218 .29027 L
.84259 .28888 L
.84297 .28786 L
.84331 .28717 L
.84352 .28688 L
.84371 .28669 L
.84381 .28661 L
.84386 .28658 L
.84391 .28656 L
.84397 .28653 L
.84403 .28652 L
.84413 .28651 L
.84423 .28652 L
.84432 .28654 L
.84442 .28659 L
.84448 .28662 L
.84453 .28666 L
.84472 .28684 L
.84491 .28708 L
.84528 .28776 L
.84569 .28879 L
.84652 .29169 L
.84801 .29896 L
.84971 .30887 L
.85126 .3173 L
.85203 .32072 L
.85243 .32224 L
.85286 .32361 L
.85324 .32459 L
.85344 .32503 L
.85365 .32542 L
.85385 .32573 L
.85403 .32595 L
.8542 .32612 L
.8543 .32619 L
.85438 .32624 L
.85448 .32629 L
.85454 .3263 L
.85459 .32632 L
.85468 .32633 L
.85479 .32633 L
.85488 .32632 L
.85498 .32629 L
Mistroke
.85507 .32625 L
.85515 .3262 L
.85535 .32604 L
.85557 .3258 L
.85597 .32518 L
.85634 .32441 L
.85674 .3234 L
.85745 .32115 L
.86047 .3081 L
.86129 .30458 L
.86216 .30132 L
.86296 .29888 L
.86335 .29793 L
.8637 .29721 L
.86407 .29663 L
.86442 .29622 L
.86461 .29606 L
.86478 .29595 L
.86487 .29591 L
.86498 .29588 L
.86508 .29586 L
.86518 .29585 L
.86528 .29585 L
.86534 .29586 L
.86539 .29587 L
.86549 .2959 L
.86559 .29594 L
.86569 .296 L
.86579 .29606 L
.86596 .2962 L
.86637 .29666 L
.8668 .29734 L
.86757 .29898 L
.8684 .30131 L
.8701 .30699 L
.87179 .3127 L
.8726 .31498 L
.87334 .31668 L
.87371 .31736 L
.87411 .31797 L
.87452 .31843 L
.87474 .31862 L
.87495 .31876 L
.87513 .31884 L
.87523 .31887 L
.87533 .3189 L
.87542 .31891 L
.87551 .31891 L
.8756 .31891 L
.87568 .3189 L
Mistroke
.87578 .31889 L
.87587 .31886 L
.87598 .31882 L
.87609 .31877 L
.87627 .31866 L
.87647 .31851 L
.87689 .31809 L
.87728 .31755 L
.87803 .31625 L
.87971 .31231 L
.88132 .30807 L
.88278 .30472 L
.8836 .30329 L
.88397 .30278 L
.88436 .30234 L
.88457 .30215 L
.88479 .30198 L
.88499 .30186 L
.88517 .30177 L
.88529 .30173 L
.88539 .3017 L
.88545 .30169 L
.88551 .30168 L
.88557 .30167 L
.88563 .30166 L
.88573 .30166 L
.88583 .30166 L
.88588 .30167 L
.88593 .30167 L
.88599 .30168 L
.88605 .30169 L
.88615 .30172 L
.88626 .30175 L
.88645 .30184 L
.88664 .30194 L
.88682 .30206 L
.88722 .3024 L
.88764 .30286 L
.88911 .30513 L
.89216 .31098 L
.89297 .31226 L
.89373 .31324 L
.89415 .31367 L
.89437 .31386 L
.8946 .31403 L
.8948 .31415 L
.89502 .31426 L
.89522 .31433 L
.89541 .31438 L
.8955 .3144 L
Mistroke
.8956 .31442 L
.8957 .31443 L
.89578 .31443 L
.89588 .31443 L
.89594 .31443 L
.89599 .31442 L
.89609 .31441 L
.89619 .3144 L
.89629 .31437 L
.8964 .31435 L
.89659 .31428 L
.89682 .31418 L
.89703 .31406 L
.89779 .31347 L
.89851 .31271 L
.90158 .3084 L
.90239 .30732 L
.90316 .30646 L
.90359 .30606 L
.90405 .3057 L
.90446 .30544 L
.90466 .30534 L
.90485 .30526 L
.90503 .30519 L
.90522 .30514 L
.90533 .30512 L
.90543 .3051 L
.90553 .30509 L
.90563 .30508 L
.90572 .30508 L
.90581 .30507 L
.9059 .30508 L
.90598 .30508 L
.90607 .30509 L
.90616 .3051 L
.90626 .30512 L
.90636 .30514 L
.90658 .30519 L
.90678 .30526 L
.90716 .30543 L
.90757 .30566 L
.90802 .30598 L
.90962 .30746 L
.91131 .30927 L
.91212 .31008 L
.9129 .31074 L
.91359 .31123 L
.91395 .31143 L
.91435 .3116 L
.91475 .31174 L
Mistroke
.91496 .31179 L
.91506 .31181 L
.91516 .31182 L
.91525 .31184 L
.91535 .31185 L
.91544 .31185 L
.91553 .31186 L
.91562 .31186 L
.91571 .31186 L
.91582 .31186 L
.91592 .31185 L
.91601 .31184 L
.91612 .31183 L
.91633 .3118 L
.91653 .31175 L
.91672 .3117 L
.91714 .31155 L
.91759 .31135 L
.91841 .31088 L
.91929 .31026 L
.9209 .309 L
.92179 .30835 L
.92262 .30782 L
.92336 .30744 L
.92378 .30728 L
.92417 .30716 L
.92435 .30711 L
.92454 .30707 L
.92471 .30704 L
.9249 .30702 L
.92501 .307 L
.92511 .307 L
.92521 .30699 L
.92531 .30699 L
.92541 .30699 L
.9255 .30699 L
.92559 .30699 L
.9257 .30699 L
.9258 .307 L
.92589 .30701 L
.92611 .30704 L
.92631 .30707 L
.92654 .30712 L
.92694 .30722 L
.92731 .30734 L
.92885 .30805 L
.93052 .30898 L
.93208 .30977 L
.93251 .30995 L
.93297 .31011 L
Mistroke
.93341 .31024 L
.93381 .31033 L
.93421 .3104 L
.93443 .31042 L
.93455 .31043 L
.93465 .31044 L
.93476 .31045 L
.93485 .31045 L
.93496 .31045 L
.93501 .31045 L
.93507 .31045 L
.93517 .31045 L
.93527 .31045 L
.93537 .31045 L
.93546 .31044 L
.93565 .31043 L
.93583 .31041 L
.93623 .31035 L
.93659 .31028 L
.93697 .31019 L
.93854 .30968 L
.94 .30909 L
.94149 .30854 L
.94233 .3083 L
.94274 .30821 L
.94311 .30814 L
.94332 .3081 L
.94355 .30807 L
.94373 .30805 L
.94394 .30803 L
.94404 .30803 L
.94416 .30802 L
.94422 .30802 L
.94428 .30802 L
.94434 .30801 L
.94439 .30801 L
.94449 .30801 L
.94455 .30801 L
.94461 .30801 L
.9447 .30801 L
.94476 .30801 L
.94481 .30801 L
.9449 .30801 L
.94501 .30802 L
.94511 .30802 L
.94521 .30803 L
.94559 .30806 L
.9458 .30808 L
.94599 .30811 L
.94642 .30818 L
Mistroke
.94722 .30835 L
.94796 .30853 L
.94963 .309 L
.95042 .30921 L
.95126 .30941 L
.95167 .30949 L
.95206 .30956 L
.95244 .30961 L
.95279 .30965 L
.95316 .30969 L
.95336 .3097 L
.95345 .3097 L
.95355 .30971 L
.95363 .30971 L
.95372 .30971 L
.9538 .30972 L
.95388 .30972 L
.95397 .30972 L
.95406 .30972 L
.95415 .30972 L
.95425 .30972 L
.95434 .30972 L
.95444 .30971 L
.95454 .30971 L
.95464 .3097 L
.95501 .30968 L
.95521 .30967 L
.9554 .30965 L
.95583 .3096 L
.95662 .30949 L
.95735 .30936 L
.95901 .30903 L
.96052 .30877 L
.96093 .30871 L
.96137 .30865 L
.96175 .30861 L
.96215 .30858 L
.96237 .30856 L
.96257 .30855 L
.96278 .30855 L
.96297 .30854 L
.96308 .30854 L
.96314 .30854 L
.96319 .30853 L
.96329 .30853 L
.96334 .30853 L
.9634 .30853 L
.96345 .30853 L
.96352 .30853 L
.96358 .30853 L
Mistroke
.96364 .30854 L
.96375 .30854 L
.96387 .30854 L
.96408 .30855 L
.9643 .30855 L
.96471 .30858 L
.96511 .30861 L
.96548 .30864 L
.96864 .30905 L
.96946 .30915 L
.97023 .30923 L
.97092 .30929 L
.97132 .30931 L
.97168 .30933 L
.97188 .30934 L
.97208 .30934 L
.97225 .30934 L
.97235 .30935 L
.97243 .30935 L
.97253 .30935 L
.97262 .30935 L
.97272 .30935 L
.97283 .30935 L
.97288 .30935 L
.97294 .30935 L
.97304 .30935 L
.97314 .30934 L
.97324 .30934 L
.97344 .30934 L
.97362 .30933 L
.97405 .30931 L
.97447 .30929 L
.97491 .30926 L
.97619 .30915 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{421.375, 260.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 525.688}, {324.5, 0}} -> {-2.58312*^-7, -6.34248*^6, \
6.65005*^-9, 53093.5}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0.309017 5.42214e-08 [
[.32684 .29652 -16.5 -12.5 ]
[.32684 .29652 16.5 0 ]
[.54329 .29652 -16.5 -12.5 ]
[.54329 .29652 16.5 0 ]
[.75974 .29652 -22.5 -12.5 ]
[.75974 .29652 22.5 0 ]
[.97619 .29652 -16.5 -12.5 ]
[.97619 .29652 16.5 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 64 6 ]
[.09789 .09213 -34.5 -6.25 ]
[.09789 .09213 0 6.25 ]
[.09789 .20057 -34.5 -6.25 ]
[.09789 .20057 0 6.25 ]
[.09789 .41746 -28.5 -6.25 ]
[.09789 .41746 0 6.25 ]
[.09789 .5259 -28.5 -6.25 ]
[.09789 .5259 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -65.8125 0 ]
[.5 .63053 65.8125 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 .30902 m
.32684 .31527 L
s
gsave
.32684 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 .30902 m
.54329 .31527 L
s
gsave
.54329 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 .30902 m
.75974 .31527 L
s
gsave
.75974 .29652 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 .30902 m
.15368 .31277 L
s
.19697 .30902 m
.19697 .31277 L
s
.24026 .30902 m
.24026 .31277 L
s
.28355 .30902 m
.28355 .31277 L
s
.37013 .30902 m
.37013 .31277 L
s
.41342 .30902 m
.41342 .31277 L
s
.45671 .30902 m
.45671 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.58658 .30902 m
.58658 .31277 L
s
.62987 .30902 m
.62987 .31277 L
s
.67316 .30902 m
.67316 .31277 L
s
.71645 .30902 m
.71645 .31277 L
s
.80303 .30902 m
.80303 .31277 L
s
.84632 .30902 m
.84632 .31277 L
s
.88961 .30902 m
.88961 .31277 L
s
.9329 .30902 m
.9329 .31277 L
s
.0671 .30902 m
.0671 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09213 m
.11664 .09213 L
s
gsave
.09789 .09213 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .20057 m
.11664 .20057 L
s
gsave
.09789 .20057 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .41746 m
.11664 .41746 L
s
gsave
.09789 .41746 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .5259 m
.11664 .5259 L
s
gsave
.09789 .5259 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.11039 .11924 m
.11414 .11924 L
s
.11039 .14635 m
.11414 .14635 L
s
.11039 .17346 m
.11414 .17346 L
s
.11039 .22768 m
.11414 .22768 L
s
.11039 .2548 m
.11414 .2548 L
s
.11039 .28191 m
.11414 .28191 L
s
.11039 .33613 m
.11414 .33613 L
s
.11039 .36324 m
.11414 .36324 L
s
.11039 .39035 m
.11414 .39035 L
s
.11039 .44457 m
.11414 .44457 L
s
.11039 .47168 m
.11414 .47168 L
s
.11039 .49879 m
.11414 .49879 L
s
.11039 .06502 m
.11414 .06502 L
s
.11039 .03791 m
.11414 .03791 L
s
.11039 .0108 m
.11414 .0108 L
s
.11039 .55301 m
.11414 .55301 L
s
.11039 .58012 m
.11414 .58012 L
s
.11039 .60723 m
.11414 .60723 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -126.812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.812 moveto
(@) show
81.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.812 moveto
(D) show
93.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11.4) show
141.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
147.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
159.000 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
163.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
172.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
190.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02691 .30902 L
.03029 .30902 L
.03347 .30902 L
.03652 .30902 L
.03978 .30902 L
.04291 .30902 L
.04623 .30902 L
.04944 .30902 L
.05252 .30902 L
.0558 .30902 L
.05896 .30902 L
.062 .30902 L
.06523 .30902 L
.06834 .30902 L
.07165 .30902 L
.07484 .30902 L
.0779 .30902 L
.08117 .30902 L
.08431 .30902 L
.08765 .30902 L
.09086 .30902 L
.09396 .30902 L
.09725 .30902 L
.10042 .30902 L
.10346 .30902 L
.10671 .30902 L
.10983 .30902 L
.11315 .30902 L
.11635 .30902 L
.11781 .30902 L
.11865 .30902 L
.11943 .30902 L
.12019 .30902 L
.12058 .30902 L
.12101 .30902 L
.12144 .30902 L
.12168 .30902 L
.12179 .30902 L
.12189 .30902 L
.12199 .30902 L
.12204 .30902 L
.1221 .30902 L
.12219 .30902 L
.12228 .30902 L
.12239 .30902 L
.12248 .30902 L
.12259 .30902 L
.12265 .30902 L
.1227 .30902 L
Mistroke
.1229 .30902 L
.12308 .30902 L
.12329 .30902 L
.12349 .30902 L
.12385 .30902 L
.12423 .30902 L
.12465 .30902 L
.12509 .30902 L
.12589 .30902 L
.12665 .30902 L
.12747 .30902 L
.12894 .30902 L
.12976 .30902 L
.13065 .30902 L
.13227 .30902 L
.13386 .30902 L
.13555 .30902 L
.13858 .30902 L
.14014 .30902 L
.14181 .30902 L
.14512 .30902 L
.1483 .30902 L
.15137 .30902 L
.15463 .30902 L
.15776 .30902 L
.1611 .30902 L
.16431 .30902 L
.1674 .30902 L
.17069 .30902 L
.17386 .30902 L
.1769 .30902 L
.18015 .30902 L
.18164 .30902 L
.18327 .30902 L
.18415 .30902 L
.18497 .30902 L
.18537 .30902 L
.18575 .30902 L
.18615 .30902 L
.18636 .30902 L
.18648 .30902 L
.18658 .30902 L
.18668 .30902 L
.18678 .30902 L
.18688 .30902 L
.18698 .30902 L
.18708 .30902 L
.18717 .30902 L
.18726 .30902 L
.18735 .30902 L
Mistroke
.18741 .30902 L
.18746 .30902 L
.18756 .30902 L
.18779 .30902 L
.18798 .30902 L
.18819 .30902 L
.18862 .30902 L
.18907 .30902 L
.1895 .30902 L
.18988 .30902 L
.19069 .30902 L
.19143 .30902 L
.1923 .30902 L
.1931 .30902 L
.19461 .30902 L
.19627 .30902 L
.19791 .30902 L
.1994 .30902 L
.2026 .30902 L
.20568 .30902 L
.20895 .30902 L
.2121 .30902 L
.21514 .30902 L
.21837 .30902 L
.22147 .30902 L
.22478 .30902 L
.22796 .30902 L
.22956 .30902 L
.23026 .30902 L
.23102 .30902 L
.23144 .30902 L
.23183 .30902 L
.23222 .30902 L
.23259 .30902 L
.23278 .30902 L
.23298 .30902 L
.2331 .30902 L
.23321 .30902 L
.2333 .30902 L
.23336 .30902 L
.23341 .30902 L
.23347 .30902 L
.23352 .30902 L
.23358 .30902 L
.23363 .30902 L
.23373 .30902 L
.23383 .30902 L
.23394 .30902 L
.23404 .30902 L
.23428 .30902 L
Mistroke
.23449 .30902 L
.23468 .30902 L
.23512 .30902 L
.2355 .30902 L
.23591 .30902 L
.23662 .30902 L
.2374 .30902 L
.23822 .30902 L
.23896 .30902 L
.24064 .30902 L
.24216 .30902 L
.24382 .30902 L
.24709 .30902 L
.25023 .30902 L
.25356 .30902 L
.25678 .30902 L
.25987 .30902 L
.26316 .30902 L
.2648 .30902 L
.26633 .30902 L
.26789 .30902 L
.26866 .30902 L
.26938 .30902 L
.27016 .30902 L
.27057 .30902 L
.27078 .30902 L
.27101 .30902 L
.2712 .30902 L
.27128 .30902 L
.27137 .30902 L
.27146 .30902 L
.27154 .30902 L
.27163 .30902 L
.27172 .30902 L
.27182 .30902 L
.27187 .30902 L
.27193 .30902 L
.27202 .30902 L
.27213 .30902 L
.27222 .30902 L
.2723 .30902 L
.2725 .30902 L
.27271 .30902 L
.2729 .30902 L
.27333 .30902 L
.27372 .30902 L
.27413 .30902 L
.27491 .30902 L
.27561 .30902 L
.27716 .30902 L
Mistroke
.27803 .30902 L
.27883 .30902 L
.28047 .30902 L
.28201 .30902 L
.28506 .30902 L
.28818 .30901 L
.29151 .30901 L
.29471 .30901 L
.29779 .30901 L
.29935 .309 L
.30106 .309 L
.30185 .309 L
.30269 .309 L
.30308 .309 L
.30349 .309 L
.30384 .309 L
.30422 .309 L
.30442 .309 L
.30454 .309 L
.30464 .309 L
.30474 .309 L
.30484 .309 L
.30489 .309 L
.30495 .309 L
.30505 .309 L
.30514 .309 L
.30525 .309 L
.30535 .309 L
.30544 .309 L
.30561 .309 L
.3058 .309 L
.30599 .309 L
.30621 .309 L
.30659 .309 L
.30706 .309 L
.30748 .309 L
.30826 .309 L
.30899 .309 L
.31065 .30901 L
.31229 .30901 L
.31379 .30901 L
.31699 .30902 L
.32008 .30903 L
.32336 .30904 L
.32652 .30906 L
.32955 .30907 L
.33111 .30908 L
.33198 .30908 L
.33279 .30908 L
.33318 .30908 L
Mistroke
.3336 .30908 L
.33384 .30908 L
.33406 .30908 L
.33427 .30908 L
.33438 .30908 L
.33448 .30908 L
.33458 .30908 L
.33468 .30908 L
.33477 .30908 L
.33486 .30908 L
.33496 .30908 L
.33502 .30908 L
.33507 .30908 L
.33517 .30908 L
.33527 .30908 L
.33537 .30908 L
.33547 .30908 L
.33566 .30908 L
.33589 .30908 L
.3361 .30908 L
.33648 .30908 L
.33688 .30908 L
.33762 .30908 L
.33849 .30907 L
.33928 .30907 L
.34082 .30906 L
.34249 .30905 L
.34577 .30901 L
.34894 .30897 L
.35198 .30892 L
.35522 .30886 L
.35671 .30884 L
.35833 .30882 L
.35922 .30881 L
.36003 .30881 L
.36044 .30881 L
.36082 .3088 L
.36103 .3088 L
.36125 .3088 L
.36146 .3088 L
.36165 .3088 L
.36175 .3088 L
.36185 .3088 L
.36193 .3088 L
.36203 .3088 L
.36213 .3088 L
.36218 .3088 L
.36224 .3088 L
.36234 .3088 L
.36243 .3088 L
Mistroke
.36253 .3088 L
.36261 .3088 L
.36278 .3088 L
.36296 .3088 L
.36316 .3088 L
.36358 .30881 L
.36402 .30881 L
.36482 .30882 L
.36565 .30883 L
.36654 .30884 L
.36816 .30887 L
.36976 .30892 L
.37145 .30898 L
.37449 .30911 L
.37774 .30928 L
.38086 .30944 L
.38245 .30951 L
.38328 .30955 L
.38417 .30957 L
.38496 .3096 L
.38538 .3096 L
.38583 .30961 L
.38625 .30962 L
.38643 .30962 L
.38663 .30962 L
.38681 .30962 L
.38699 .30962 L
.38709 .30962 L
.38717 .30962 L
.38727 .30962 L
.38737 .30962 L
.38746 .30962 L
.38756 .30962 L
.38766 .30962 L
.38774 .30962 L
.38784 .30962 L
.38795 .30962 L
.38815 .30962 L
.38836 .30962 L
.38858 .30962 L
.38898 .30961 L
.38938 .3096 L
.38975 .30959 L
.39046 .30957 L
.39124 .30954 L
.39207 .30949 L
.39355 .30939 L
.3966 .3091 L
.39985 .30868 L
.40298 .30824 L
Mistroke
.40457 .30802 L
.4063 .30782 L
.4071 .30774 L
.40796 .30766 L
.40869 .30761 L
.4095 .30757 L
.40989 .30755 L
.41011 .30755 L
.41031 .30754 L
.41048 .30754 L
.41057 .30754 L
.41066 .30754 L
.41077 .30754 L
.41087 .30753 L
.41096 .30753 L
.41105 .30753 L
.41115 .30753 L
.41125 .30753 L
.41135 .30754 L
.41144 .30754 L
.41154 .30754 L
.41166 .30754 L
.41187 .30754 L
.41208 .30755 L
.41231 .30756 L
.41273 .30758 L
.41316 .3076 L
.41356 .30763 L
.41445 .30772 L
.41524 .30781 L
.41607 .30794 L
.41913 .3086 L
.42238 .30957 L
.42551 .31061 L
.4271 .31112 L
.42883 .3116 L
.42964 .31179 L
.4305 .31196 L
.43123 .31207 L
.43162 .31212 L
.43204 .31216 L
.43225 .31218 L
.43245 .31219 L
.43266 .3122 L
.43275 .31221 L
.43285 .31221 L
.43295 .31221 L
.43304 .31222 L
.43312 .31222 L
.43321 .31222 L
Mistroke
.43331 .31222 L
.43339 .31222 L
.43349 .31222 L
.43359 .31222 L
.43365 .31222 L
.43371 .31222 L
.43381 .31221 L
.43404 .3122 L
.43425 .31219 L
.43447 .31218 L
.43488 .31214 L
.43527 .31209 L
.43606 .31195 L
.43689 .31175 L
.43838 .31127 L
.43996 .31057 L
.44143 .30976 L
.44457 .3077 L
.4479 .30536 L
.44957 .30433 L
.4503 .30393 L
.45111 .30355 L
.45183 .30327 L
.45261 .30303 L
.45304 .30292 L
.45343 .30285 L
.45362 .30283 L
.45382 .3028 L
.45391 .3028 L
.45401 .30279 L
.45411 .30278 L
.45419 .30278 L
.45429 .30277 L
.45435 .30277 L
.4544 .30277 L
.45446 .30277 L
.45452 .30277 L
.45463 .30277 L
.45472 .30277 L
.45482 .30278 L
.45492 .30278 L
.45502 .30279 L
.45524 .30281 L
.45545 .30284 L
.45592 .30292 L
.45632 .30302 L
.4567 .30314 L
.45754 .30349 L
.45832 .30392 L
.45906 .30441 L
Mistroke
.46072 .30582 L
.46386 .30945 L
.46719 .31397 L
.46887 .31612 L
.47041 .31785 L
.47191 .31915 L
.47267 .31962 L
.4731 .31983 L
.4735 .31998 L
.47369 .32004 L
.4739 .32009 L
.47401 .32011 L
.47412 .32013 L
.47423 .32015 L
.47433 .32016 L
.47443 .32017 L
.47453 .32017 L
.47463 .32018 L
.47469 .32018 L
.47474 .32018 L
.47484 .32017 L
.47493 .32017 L
.47503 .32016 L
.47513 .32015 L
.47531 .32012 L
.4755 .32008 L
.47584 .31998 L
.47621 .31983 L
.47662 .31962 L
.47743 .31904 L
.47818 .31833 L
.47985 .31612 L
.48138 .31345 L
.48304 .30995 L
.4863 .30216 L
.48945 .29523 L
.49027 .29378 L
.49117 .29247 L
.49158 .29197 L
.49201 .29151 L
.49242 .29116 L
.49279 .29091 L
.49297 .29081 L
.49318 .29071 L
.49337 .29064 L
.49355 .29059 L
.49364 .29057 L
.49374 .29056 L
.49384 .29055 L
.49389 .29055 L
Mistroke
.49394 .29054 L
.49404 .29054 L
.4941 .29055 L
.49415 .29055 L
.49425 .29056 L
.49431 .29057 L
.49436 .29058 L
.49455 .29063 L
.49473 .29069 L
.49492 .29077 L
.49512 .29088 L
.49546 .29111 L
.49583 .29145 L
.49665 .29243 L
.4974 .29365 L
.49907 .29745 L
.5006 .30204 L
.50227 .30799 L
.50553 .32093 L
.50705 .3266 L
.50868 .33181 L
.50958 .33409 L
.5104 .33573 L
.51081 .33636 L
.51119 .33684 L
.51159 .33722 L
.5118 .33737 L
.51191 .33743 L
.51202 .33749 L
.51212 .33753 L
.51223 .33757 L
.51229 .33758 L
.51234 .33759 L
.51245 .3376 L
.51255 .33761 L
.51265 .3376 L
.51275 .33759 L
.51284 .33757 L
.51296 .33753 L
.51307 .33749 L
.51327 .33737 L
.51349 .33721 L
.51373 .33699 L
.51414 .33648 L
.51457 .33579 L
.51535 .33412 L
.51611 .33198 L
.51692 .32914 L
.5184 .32272 L
.52171 .30389 L
Mistroke
.52491 .28463 L
.52637 .27723 L
.52721 .27376 L
.52799 .2711 L
.52875 .26914 L
.52918 .26834 L
.52938 .26804 L
.52957 .26781 L
.52976 .26762 L
.52996 .26747 L
.53008 .26741 L
.53014 .26739 L
.53019 .26737 L
.53029 .26735 L
.53034 .26734 L
.53039 .26734 L
.5305 .26734 L
.53055 .26735 L
.53061 .26736 L
.53071 .2674 L
.53081 .26744 L
.53092 .26751 L
.53102 .26759 L
.53126 .26782 L
.53147 .2681 L
.53167 .2684 L
.53211 .2693 L
.5325 .2703 L
.53291 .2716 L
.5344 .27819 L
.53516 .28262 L
.53598 .28809 L
.53745 .29952 L
.54078 .32904 L
.54244 .34317 L
.54398 .35418 L
.54475 .35862 L
.54547 .36198 L
.54586 .36345 L
.54622 .36456 L
.54663 .36552 L
.54684 .36591 L
.54706 .36622 L
.54716 .36634 L
.54726 .36644 L
.54737 .36651 L
.54746 .36656 L
.54754 .36659 L
.54764 .36661 L
.54773 .3666 L
Mistroke
.54782 .36659 L
.54793 .36655 L
.54803 .36649 L
.54812 .36642 L
.54822 .36632 L
.54844 .36603 L
.54864 .36568 L
.54898 .36491 L
.54936 .36379 L
.55012 .36064 L
.55093 .35605 L
.55167 .35077 L
.55334 .3355 L
.55652 .29801 L
.55957 .26153 L
.56114 .24684 L
.56202 .24064 L
.56241 .23846 L
.56282 .23653 L
.5632 .23513 L
.56341 .23454 L
.56362 .23402 L
.56382 .23365 L
.564 .23341 L
.56409 .23333 L
.56419 .23326 L
.56428 .23322 L
.56436 .2332 L
.56447 .23321 L
.56453 .23322 L
.56458 .23325 L
.56468 .23331 L
.56479 .23341 L
.56488 .23353 L
.56497 .23366 L
.56517 .23403 L
.56539 .23457 L
.56558 .23518 L
.56603 .23694 L
.56642 .23891 L
.56683 .24146 L
.56756 .24717 L
.56923 .26504 L
.57226 .31028 L
.57394 .33819 L
.57549 .36232 L
.57709 .38341 L
.57788 .39148 L
.57859 .39727 L
.57894 .39955 L
Mistroke
.57933 .40155 L
.57954 .40244 L
.57973 .40312 L
.57991 .40365 L
.58011 .40408 L
.58021 .40425 L
.58031 .40437 L
.5804 .40446 L
.5805 .40451 L
.5806 .40453 L
.5807 .40452 L
.58075 .40449 L
.5808 .40446 L
.58086 .40441 L
.58092 .40435 L
.58102 .40421 L
.58113 .40402 L
.58133 .40357 L
.58154 .40291 L
.58177 .40201 L
.58219 .39984 L
.58259 .39719 L
.58334 .39067 L
.58415 .38149 L
.58502 .3692 L
.5883 .30765 L
.58993 .27346 L
.59146 .24349 L
.59293 .21924 L
.59368 .20961 L
.59449 .20146 L
.5949 .19838 L
.59512 .197 L
.59533 .1959 L
.59553 .19505 L
.59574 .19433 L
.59584 .19408 L
.59594 .19386 L
.59603 .19369 L
.59611 .19358 L
.5962 .19349 L
.59629 .19344 L
.59638 .19343 L
.59648 .19347 L
.59657 .19353 L
.59666 .19364 L
.59674 .19377 L
.59682 .19394 L
.59701 .19445 L
.59722 .1952 L
Mistroke
.5976 .19708 L
.598 .19979 L
.59837 .20298 L
.59921 .21252 L
.60003 .22472 L
.6009 .2406 L
.60423 .31906 L
.6059 .36127 L
.60744 .39618 L
.60893 .42281 L
.60969 .43253 L
.61012 .43679 L
.61052 .4399 L
.61071 .44108 L
.61092 .4421 L
.61104 .44259 L
.61115 .44296 L
.61125 .44327 L
.61135 .44349 L
.61145 .44365 L
.61155 .44376 L
.61165 .44381 L
.61171 .44381 L
.61176 .4438 L
.61186 .44373 L
.61195 .44362 L
.61205 .44344 L
.61215 .44321 L
.61233 .44263 L
.61252 .44182 L
.61286 .43983 L
.61323 .43693 L
.61363 .43283 L
.61445 .42193 L
.61519 .40894 L
.61686 .37066 L
.62005 .27827 L
.62165 .23226 L
.62311 .19689 L
.62386 .1822 L
.62468 .16978 L
.62513 .16465 L
.62533 .16281 L
.62555 .16107 L
.62574 .15979 L
.62594 .15869 L
.62606 .15821 L
.62616 .15784 L
.62627 .15754 L
.62636 .15733 L
Mistroke
.62646 .15718 L
.62657 .1571 L
.62666 .15709 L
.62675 .15714 L
.62684 .15724 L
.62695 .15744 L
.62706 .15771 L
.62716 .15805 L
.62734 .15884 L
.62751 .15977 L
.62789 .16258 L
.6283 .16671 L
.62875 .17246 L
.62956 .18613 L
.63115 .22382 L
.63284 .27548 L
.63587 .37761 L
.63756 .42622 L
.63836 .44453 L
.63911 .45805 L
.63951 .46377 L
.63987 .46798 L
.64027 .47152 L
.64049 .47293 L
.64059 .47345 L
.6407 .47393 L
.64079 .47425 L
.64089 .47452 L
.64099 .47474 L
.64108 .47486 L
.64117 .47492 L
.64126 .47491 L
.64134 .47485 L
.64143 .47473 L
.64152 .47453 L
.64163 .47423 L
.64174 .47382 L
.64184 .47335 L
.64203 .47222 L
.64222 .4709 L
.64259 .46735 L
.64301 .46222 L
.64384 .44808 L
.64455 .43203 L
.64532 .41138 L
.64865 .29504 L
.65032 .23394 L
.65186 .1856 L
.65264 .16613 L
.65336 .15161 L
Mistroke
.65375 .14535 L
.65412 .14072 L
.65452 .13683 L
.65474 .13527 L
.65484 .1347 L
.65495 .13417 L
.65506 .13375 L
.65516 .13346 L
.65525 .13326 L
.65535 .13313 L
.65544 .13309 L
.65553 .13312 L
.65562 .13323 L
.65572 .13342 L
.65582 .13372 L
.65594 .13416 L
.65615 .13525 L
.65635 .13668 L
.65654 .13832 L
.65688 .14206 L
.65726 .14732 L
.65802 .16145 L
.65883 .18133 L
.65957 .20337 L
.66125 .26313 L
.66443 .38852 L
.66526 .41728 L
.66604 .44107 L
.66679 .46037 L
.66749 .47426 L
.66786 .47994 L
.66825 .48466 L
.66844 .48645 L
.66864 .48802 L
.66876 .48875 L
.66886 .4893 L
.66896 .48973 L
.66902 .48993 L
.66907 .49009 L
.66917 .49033 L
.66923 .49041 L
.66928 .49048 L
.66939 .49051 L
.66948 .49045 L
.66959 .49029 L
.66965 .49015 L
.6697 .48999 L
.66981 .48958 L
.66993 .48901 L
.67015 .48761 L
Mistroke
.67036 .48588 L
.67075 .48155 L
.67112 .47616 L
.67153 .46884 L
.67236 .44983 L
.67384 .40357 L
.67707 .27316 L
.67856 .21498 L
.68018 .16413 L
.68061 .15389 L
.68106 .14465 L
.68146 .13812 L
.68188 .13265 L
.68211 .13042 L
.68232 .12882 L
.68252 .12767 L
.68262 .12725 L
.68267 .12705 L
.68273 .12689 L
.68283 .12667 L
.68292 .12656 L
.68302 .12653 L
.68307 .12656 L
.68312 .12661 L
.68321 .12675 L
.6833 .12699 L
.6834 .12733 L
.68349 .12774 L
.68369 .12888 L
.68387 .13028 L
.68428 .13464 L
.68469 .14043 L
.68511 .14825 L
.68589 .16648 L
.6866 .18714 L
.68981 .3123 L
.69128 .37339 L
.69212 .40507 L
.6929 .43131 L
.69373 .45466 L
.69449 .47104 L
.69491 .4778 L
.69531 .48269 L
.69553 .48472 L
.69573 .48618 L
.69584 .48683 L
.69595 .48732 L
.69601 .48754 L
.69607 .48774 L
.69613 .48789 L
Mistroke
.69618 .488 L
.69628 .48811 L
.69638 .48813 L
.69647 .48806 L
.69653 .48797 L
.69658 .48787 L
.69667 .48763 L
.69676 .48729 L
.69695 .48633 L
.69716 .48485 L
.69738 .48278 L
.69779 .4778 L
.69824 .47039 L
.69867 .46162 L
.69948 .44095 L
.70107 .38719 L
.70254 .32746 L
.70405 .26457 L
.70568 .20377 L
.70658 .17695 L
.70697 .16708 L
.7074 .15774 L
.70778 .15088 L
.70819 .14502 L
.70841 .14246 L
.70862 .14056 L
.70882 .13907 L
.70892 .13853 L
.70902 .13805 L
.70912 .13768 L
.70921 .13743 L
.7093 .13726 L
.70939 .13717 L
.70949 .13716 L
.70958 .13725 L
.70968 .13745 L
.70974 .13761 L
.70979 .13778 L
.71 .1387 L
.71011 .13941 L
.71022 .14017 L
.71062 .14405 L
.71096 .14859 L
.71133 .15484 L
.71209 .17128 L
.71365 .21855 L
.71533 .28279 L
.71691 .34681 L
.71864 .409 L
.71944 .4321 L
Mistroke
.71988 .44274 L
.7203 .4513 L
.72068 .45794 L
.7211 .46358 L
.72129 .46554 L
.72148 .46726 L
.72165 .46844 L
.72183 .46942 L
.72194 .46983 L
.72203 .47011 L
.72208 .47023 L
.72214 .47032 L
.7222 .47039 L
.72225 .47042 L
.72235 .4704 L
.72245 .4703 L
.72255 .47009 L
.72265 .46977 L
.72274 .46941 L
.72284 .46894 L
.72301 .46787 L
.72321 .46622 L
.7234 .46439 L
.72381 .45912 L
.72426 .45168 L
.72508 .43385 L
.72668 .38563 L
.72837 .32292 L
.72996 .2626 L
.73141 .21456 L
.73216 .19459 L
.73297 .1776 L
.73342 .17063 L
.73364 .16788 L
.73383 .16575 L
.73402 .16404 L
.73423 .16255 L
.73434 .16191 L
.73445 .16142 L
.73455 .16104 L
.73465 .16075 L
.73475 .16057 L
.7348 .1605 L
.73486 .16047 L
.73495 .16048 L
.73505 .16057 L
.73514 .16074 L
.73522 .16096 L
.73531 .16128 L
.73541 .16171 L
Mistroke
.73563 .16299 L
.73584 .1646 L
.73623 .16869 L
.7366 .17372 L
.73694 .17938 L
.7377 .19554 L
.73935 .24279 L
.74084 .29459 L
.74252 .35334 L
.74325 .37675 L
.74406 .3994 L
.74479 .41636 L
.74557 .43025 L
.746 .43585 L
.74639 .4396 L
.74658 .44093 L
.74668 .4415 L
.74678 .44202 L
.74687 .44239 L
.74698 .44272 L
.74707 .44293 L
.74716 .44307 L
.74725 .44314 L
.74735 .44313 L
.74745 .44303 L
.74753 .44288 L
.74763 .44262 L
.74774 .44223 L
.74794 .44126 L
.74815 .43988 L
.74838 .438 L
.74877 .43363 L
.74948 .42278 L
.75026 .40675 L
.75182 .36441 L
.7535 .31078 L
.75508 .26112 L
.75592 .23818 L
.75681 .21779 L
.75726 .20944 L
.75768 .20286 L
.75809 .19771 L
.75827 .19587 L
.75847 .19413 L
.75864 .19286 L
.75883 .19176 L
.75893 .19127 L
.75902 .1909 L
.75911 .19061 L
.75921 .19038 L
Mistroke
.75931 .1902 L
.7594 .19012 L
.7595 .1901 L
.75956 .19013 L
.75961 .19019 L
.75971 .19034 L
.7598 .19055 L
.7599 .19084 L
.76 .19124 L
.76021 .19229 L
.76041 .19359 L
.76077 .1968 L
.76116 .20137 L
.76159 .20754 L
.76307 .23744 L
.76635 .32921 L
.76799 .3713 L
.76879 .38763 L
.76952 .39928 L
.76988 .40377 L
.77027 .40764 L
.77045 .40905 L
.77065 .4103 L
.77083 .41123 L
.77099 .41187 L
.77108 .41215 L
.77118 .41237 L
.77127 .41253 L
.77138 .41262 L
.77147 .41264 L
.77156 .41259 L
.77166 .41249 L
.77174 .41234 L
.77184 .41208 L
.77194 .41177 L
.77216 .41081 L
.77236 .40968 L
.77257 .4082 L
.77296 .40456 L
.77332 .40036 L
.77414 .38806 L
.7756 .35776 L
.77726 .31657 L
.77879 .27839 L
.78028 .24751 L
.78111 .23463 L
.78147 .23024 L
.78186 .22631 L
.78225 .22334 L
.78247 .22213 L
Mistroke
.78267 .22126 L
.78276 .22093 L
.78285 .22068 L
.78293 .2205 L
.78302 .22035 L
.78312 .22024 L
.78322 .2202 L
.78331 .22021 L
.78341 .22028 L
.78351 .22043 L
.78356 .22053 L
.78362 .22066 L
.78382 .22127 L
.78393 .22172 L
.78405 .22228 L
.78427 .22353 L
.78469 .22678 L
.78508 .23063 L
.78588 .24115 L
.78662 .25342 L
.78829 .28735 L
.78992 .32326 L
.79145 .35306 L
.79221 .36482 L
.79292 .37361 L
.79331 .37737 L
.79352 .37903 L
.79374 .38053 L
.79395 .38168 L
.79413 .38252 L
.79432 .38317 L
.79441 .38342 L
.7945 .38361 L
.79459 .38377 L
.79469 .38389 L
.79478 .38395 L
.79487 .38396 L
.79497 .38392 L
.79507 .38384 L
.79517 .38368 L
.79528 .38345 L
.79549 .38285 L
.79568 .38209 L
.79611 .37963 L
.79648 .37676 L
.79683 .37354 L
.7976 .36441 L
.79912 .34034 L
.80078 .30947 L
.80249 .27932 L
Mistroke
.8033 .26749 L
.80404 .25866 L
.80441 .2551 L
.80482 .25189 L
.80523 .24942 L
.80545 .2484 L
.80566 .24767 L
.80575 .2474 L
.80586 .24717 L
.80595 .24699 L
.80604 .24686 L
.80612 .24678 L
.80621 .24673 L
.80631 .24672 L
.80639 .24674 L
.80649 .24681 L
.80659 .24694 L
.80668 .24708 L
.80677 .24728 L
.80699 .24787 L
.80718 .2486 L
.80759 .25065 L
.80803 .25368 L
.80882 .26109 L
.81032 .28026 L
.81188 .30439 L
.8136 .33029 L
.81439 .34038 L
.81523 .34924 L
.81564 .35266 L
.81603 .35534 L
.81638 .35724 L
.81676 .35877 L
.81697 .35935 L
.81708 .3596 L
.81719 .35978 L
.81728 .35991 L
.81738 .36 L
.81744 .36003 L
.81749 .36005 L
.81759 .36006 L
.81769 .36003 L
.81779 .35996 L
.81789 .35984 L
.81798 .35971 L
.81816 .35935 L
.81834 .35885 L
.81876 .35725 L
.81914 .35518 L
.82003 .3486 L
Mistroke
.82082 .34083 L
.82165 .33122 L
.82313 .31216 L
.82474 .29223 L
.82544 .28474 L
.8262 .27793 L
.82662 .27482 L
.82701 .27242 L
.82738 .27058 L
.82777 .26913 L
.82797 .26859 L
.82808 .26835 L
.82819 .26816 L
.82828 .26802 L
.82839 .2679 L
.82849 .26782 L
.82857 .26778 L
.82868 .26776 L
.82878 .26778 L
.82883 .2678 L
.82888 .26783 L
.82894 .26788 L
.829 .26794 L
.82911 .26808 L
.82922 .26825 L
.82946 .26877 L
.82967 .26938 L
.82986 .27006 L
.8303 .27202 L
.83109 .27694 L
.83259 .28983 L
.83422 .30683 L
.83574 .32225 L
.83649 .32875 L
.83721 .3339 L
.8376 .33625 L
.83803 .33837 L
.83842 .33988 L
.83878 .34092 L
.83899 .34136 L
.83919 .34165 L
.83929 .34176 L
.8394 .34185 L
.83946 .34188 L
.83952 .34191 L
.83958 .34192 L
.83963 .34192 L
.83973 .34191 L
.83983 .34187 L
.83993 .3418 L
Mistroke
.83998 .34176 L
.84004 .3417 L
.84024 .34142 L
.84043 .34107 L
.8408 .34009 L
.84115 .33888 L
.84192 .33518 L
.84271 .33021 L
.84344 .32476 L
.8451 .31086 L
.84661 .29866 L
.8474 .2932 L
.84824 .28852 L
.84866 .28666 L
.84913 .28505 L
.84934 .28449 L
.84956 .284 L
.84976 .28363 L
.84995 .28338 L
.85005 .28328 L
.85011 .28323 L
.85016 .28319 L
.85026 .28314 L
.85035 .28311 L
.8504 .2831 L
.85046 .2831 L
.85056 .28311 L
.85061 .28313 L
.85066 .28315 L
.85072 .28318 L
.85078 .28322 L
.85088 .28331 L
.85099 .28343 L
.85119 .28371 L
.85139 .28407 L
.85157 .28446 L
.85235 .2869 L
.85307 .29013 L
.85473 .29993 L
.85621 .30994 L
.85705 .31536 L
.85784 .31987 L
.85868 .32392 L
.85945 .32668 L
.85987 .32778 L
.86027 .32853 L
.86049 .32882 L
.86069 .32901 L
.86079 .32909 L
.86085 .32912 L
Mistroke
.86091 .32914 L
.86097 .32916 L
.86103 .32918 L
.86109 .32918 L
.86114 .32918 L
.86123 .32917 L
.86133 .32914 L
.86143 .3291 L
.86151 .32905 L
.86171 .32888 L
.86192 .32863 L
.86231 .32796 L
.86274 .32696 L
.86351 .32451 L
.86422 .3216 L
.86735 .30562 L
.86817 .30175 L
.86906 .29821 L
.86947 .29688 L
.8699 .29569 L
.87031 .29481 L
.87068 .29419 L
.87086 .29396 L
.87107 .29376 L
.87116 .29369 L
.87126 .29362 L
.87135 .29358 L
.87144 .29355 L
.87154 .29352 L
.87164 .29351 L
.87174 .29351 L
.8718 .29352 L
.87185 .29353 L
.87195 .29357 L
.87206 .29362 L
.87216 .29368 L
.87225 .29375 L
.87261 .29413 L
.87281 .29441 L
.873 .29473 L
.87372 .29629 L
.87449 .29857 L
.87522 .30113 L
.87687 .30779 L
.87836 .31359 L
.8792 .31636 L
.87998 .31841 L
.88038 .31923 L
.88076 .31986 L
.88097 .32014 L
Mistroke
.88119 .32038 L
.8814 .32056 L
.88159 .32068 L
.88169 .32073 L
.88179 .32077 L
.88189 .32079 L
.88198 .32081 L
.88209 .32081 L
.88215 .32081 L
.8822 .3208 L
.8823 .32078 L
.88236 .32076 L
.88241 .32075 L
.88263 .32064 L
.88275 .32056 L
.88286 .32047 L
.88328 .32003 L
.88366 .31949 L
.88407 .31876 L
.8848 .31714 L
.88646 .31237 L
.88805 .3074 L
.88889 .30503 L
.88979 .30291 L
.89058 .30149 L
.89103 .3009 L
.89125 .30067 L
.89145 .30049 L
.89164 .30037 L
.89173 .30031 L
.89184 .30026 L
.89193 .30022 L
.89202 .30019 L
.89211 .30017 L
.89219 .30016 L
.89229 .30015 L
.89239 .30015 L
.89248 .30015 L
.89258 .30017 L
.89268 .30019 L
.89279 .30023 L
.89299 .30031 L
.8932 .30044 L
.89341 .30061 L
.89381 .301 L
.89423 .30154 L
.89469 .30227 L
.89631 .30558 L
.89799 .30957 L
.89873 .31122 L
Mistroke
.89954 .31281 L
.90027 .31399 L
.90067 .31451 L
.90105 .31492 L
.90126 .3151 L
.90148 .31527 L
.90167 .31538 L
.90187 .31549 L
.90207 .31555 L
.90217 .31558 L
.90227 .3156 L
.90237 .31561 L
.90245 .31562 L
.90255 .31562 L
.90264 .31562 L
.90274 .3156 L
.9028 .3156 L
.90285 .31559 L
.90294 .31556 L
.90305 .31553 L
.90322 .31546 L
.90341 .31537 L
.90384 .31508 L
.90423 .31473 L
.90495 .31389 L
.90571 .31277 L
.9073 .31002 L
.90903 .30707 L
.90984 .30594 L
.91028 .30542 L
.9107 .305 L
.91108 .30469 L
.91143 .30447 L
.91161 .30437 L
.91182 .30429 L
.91202 .30422 L
.91213 .3042 L
.91224 .30418 L
.91234 .30416 L
.91239 .30416 L
.91245 .30415 L
.91255 .30415 L
.91264 .30415 L
.9127 .30416 L
.91275 .30416 L
.91285 .30417 L
.91291 .30418 L
.91296 .30419 L
.91308 .30422 L
.91327 .30427 L
Mistroke
.91347 .30435 L
.91388 .30456 L
.91425 .3048 L
.91465 .30513 L
.91537 .30585 L
.91695 .3078 L
.91867 .31004 L
.91947 .31093 L
.92032 .3117 L
.92073 .312 L
.92112 .31222 L
.92147 .31237 L
.92167 .31244 L
.92185 .31249 L
.92195 .31251 L
.92205 .31253 L
.92213 .31254 L
.92222 .31255 L
.92232 .31256 L
.92242 .31257 L
.92247 .31257 L
.92253 .31257 L
.92263 .31256 L
.92271 .31256 L
.92281 .31255 L
.92289 .31254 L
.92298 .31253 L
.92317 .31249 L
.92335 .31244 L
.92377 .31228 L
.92415 .3121 L
.92501 .31154 L
.92667 .31006 L
.92821 .30858 L
.9297 .30737 L
.93045 .30692 L
.93088 .30673 L
.93109 .30666 L
.93129 .3066 L
.93148 .30655 L
.93166 .30651 L
.93186 .30648 L
.93197 .30647 L
.93208 .30646 L
.93218 .30645 L
.93223 .30645 L
.93228 .30645 L
.93238 .30645 L
.93247 .30645 L
.93253 .30646 L
Mistroke
.93258 .30646 L
.93268 .30647 L
.93279 .30648 L
.93291 .3065 L
.9331 .30653 L
.93328 .30657 L
.93368 .30669 L
.93439 .30698 L
.9352 .30742 L
.93594 .3079 L
.93761 .30908 L
.93841 .30961 L
.93926 .3101 L
.93967 .3103 L
.94006 .31047 L
.94041 .31059 L
.94079 .3107 L
.94116 .31078 L
.94136 .31081 L
.94146 .31082 L
.94155 .31083 L
.94163 .31084 L
.94173 .31085 L
.94181 .31085 L
.94189 .31085 L
.94198 .31086 L
.94206 .31086 L
.94216 .31085 L
.94225 .31085 L
.94234 .31085 L
.94245 .31084 L
.94265 .31082 L
.94284 .31079 L
.94302 .31076 L
.94341 .31068 L
.94384 .31056 L
.94466 .31026 L
.94555 .30985 L
.94716 .30903 L
.94872 .30832 L
.94914 .30816 L
.9496 .30801 L
.95 .30791 L
.95043 .30782 L
.95063 .30779 L
.95085 .30776 L
.95105 .30774 L
.95123 .30772 L
.95134 .30772 L
.95144 .30771 L
Mistroke
.95149 .30771 L
.95155 .30771 L
.95161 .30771 L
.95167 .30771 L
.95177 .30771 L
.95186 .30771 L
.95192 .30772 L
.95197 .30772 L
.95208 .30772 L
.95227 .30774 L
.95245 .30776 L
.95286 .30781 L
.95323 .30788 L
.95358 .30796 L
.9552 .30845 L
.95668 .30899 L
.95747 .30926 L
.95832 .30952 L
.95912 .30972 L
.95948 .30979 L
.95985 .30985 L
.96004 .30987 L
.96024 .30989 L
.96043 .30991 L
.9606 .30992 L
.9607 .30992 L
.96081 .30993 L
.96091 .30993 L
.96097 .30993 L
.96102 .30993 L
.96112 .30994 L
.96122 .30994 L
.96132 .30993 L
.96142 .30993 L
.96151 .30993 L
.9616 .30993 L
.96179 .30992 L
.96197 .3099 L
.96213 .30989 L
.9625 .30985 L
.9629 .30979 L
.96372 .30964 L
.9646 .30944 L
.96622 .30902 L
.96777 .30866 L
.9682 .30859 L
.96866 .30851 L
.96905 .30846 L
.96926 .30844 L
.96949 .30842 L
Mistroke
.9697 .3084 L
.9699 .30839 L
.97 .30839 L
.9701 .30838 L
.9702 .30838 L
.97029 .30838 L
.97039 .30838 L
.97044 .30838 L
.9705 .30838 L
.97056 .30838 L
.97062 .30838 L
.97067 .30838 L
.97072 .30838 L
.97083 .30838 L
.97088 .30838 L
.97093 .30838 L
.97103 .30838 L
.97113 .30839 L
.97132 .30839 L
.9715 .3084 L
.9719 .30844 L
.97225 .30847 L
.97264 .30851 L
.9742 .30876 L
.97588 .30906 L
.97619 .30912 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{421.375, 260.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 525.688}, {324.5, 0}} -> {-2.58312*^-7, -6.34248*^6, \
6.65005*^-9, 53093.5}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0.309017 5.42214e-08 [
[.32684 .29652 -16.5 -12.5 ]
[.32684 .29652 16.5 0 ]
[.54329 .29652 -16.5 -12.5 ]
[.54329 .29652 16.5 0 ]
[.75974 .29652 -22.5 -12.5 ]
[.75974 .29652 22.5 0 ]
[.97619 .29652 -16.5 -12.5 ]
[.97619 .29652 16.5 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 64 6 ]
[.09789 .09213 -34.5 -6.25 ]
[.09789 .09213 0 6.25 ]
[.09789 .20057 -34.5 -6.25 ]
[.09789 .20057 0 6.25 ]
[.09789 .41746 -28.5 -6.25 ]
[.09789 .41746 0 6.25 ]
[.09789 .5259 -28.5 -6.25 ]
[.09789 .5259 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -65.8125 0 ]
[.5 .63053 65.8125 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 .30902 m
.32684 .31527 L
s
gsave
.32684 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 .30902 m
.54329 .31527 L
s
gsave
.54329 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 .30902 m
.75974 .31527 L
s
gsave
.75974 .29652 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 .30902 m
.15368 .31277 L
s
.19697 .30902 m
.19697 .31277 L
s
.24026 .30902 m
.24026 .31277 L
s
.28355 .30902 m
.28355 .31277 L
s
.37013 .30902 m
.37013 .31277 L
s
.41342 .30902 m
.41342 .31277 L
s
.45671 .30902 m
.45671 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.58658 .30902 m
.58658 .31277 L
s
.62987 .30902 m
.62987 .31277 L
s
.67316 .30902 m
.67316 .31277 L
s
.71645 .30902 m
.71645 .31277 L
s
.80303 .30902 m
.80303 .31277 L
s
.84632 .30902 m
.84632 .31277 L
s
.88961 .30902 m
.88961 .31277 L
s
.9329 .30902 m
.9329 .31277 L
s
.0671 .30902 m
.0671 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09213 m
.11664 .09213 L
s
gsave
.09789 .09213 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .20057 m
.11664 .20057 L
s
gsave
.09789 .20057 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .41746 m
.11664 .41746 L
s
gsave
.09789 .41746 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .5259 m
.11664 .5259 L
s
gsave
.09789 .5259 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.11039 .11924 m
.11414 .11924 L
s
.11039 .14635 m
.11414 .14635 L
s
.11039 .17346 m
.11414 .17346 L
s
.11039 .22768 m
.11414 .22768 L
s
.11039 .2548 m
.11414 .2548 L
s
.11039 .28191 m
.11414 .28191 L
s
.11039 .33613 m
.11414 .33613 L
s
.11039 .36324 m
.11414 .36324 L
s
.11039 .39035 m
.11414 .39035 L
s
.11039 .44457 m
.11414 .44457 L
s
.11039 .47168 m
.11414 .47168 L
s
.11039 .49879 m
.11414 .49879 L
s
.11039 .06502 m
.11414 .06502 L
s
.11039 .03791 m
.11414 .03791 L
s
.11039 .0108 m
.11414 .0108 L
s
.11039 .55301 m
.11414 .55301 L
s
.11039 .58012 m
.11414 .58012 L
s
.11039 .60723 m
.11414 .60723 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -126.812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.812 moveto
(@) show
81.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.812 moveto
(D) show
93.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11.6) show
141.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
147.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
159.000 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
163.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
172.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
190.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02691 .30902 L
.03029 .30902 L
.03347 .30902 L
.03652 .30902 L
.03978 .30902 L
.04291 .30902 L
.04623 .30902 L
.04944 .30902 L
.05252 .30902 L
.0558 .30902 L
.05896 .30902 L
.062 .30902 L
.06523 .30902 L
.06834 .30902 L
.07165 .30902 L
.07484 .30902 L
.0779 .30902 L
.08117 .30902 L
.08431 .30902 L
.08765 .30902 L
.09086 .30902 L
.09396 .30902 L
.09725 .30902 L
.10042 .30902 L
.10346 .30902 L
.10671 .30902 L
.10983 .30902 L
.11315 .30902 L
.11481 .30902 L
.11635 .30902 L
.11712 .30902 L
.11784 .30902 L
.11824 .30902 L
.1186 .30902 L
.119 .30902 L
.11921 .30902 L
.11931 .30902 L
.11943 .30902 L
.11953 .30902 L
.11963 .30902 L
.11973 .30902 L
.11983 .30902 L
.11992 .30902 L
.12 .30902 L
.12009 .30902 L
.12019 .30902 L
.1203 .30902 L
.12041 .30902 L
.12062 .30902 L
Mistroke
.12082 .30902 L
.12101 .30902 L
.12139 .30902 L
.12173 .30902 L
.12249 .30902 L
.12288 .30902 L
.12329 .30902 L
.12403 .30902 L
.12483 .30902 L
.12571 .30902 L
.12728 .30902 L
.12895 .30902 L
.13066 .30902 L
.13228 .30902 L
.13388 .30902 L
.13536 .30902 L
.13699 .30902 L
.13852 .30902 L
.14155 .30902 L
.14466 .30902 L
.14797 .30902 L
.15115 .30902 L
.15421 .30902 L
.15747 .30902 L
.16061 .30902 L
.16395 .30902 L
.16716 .30902 L
.17025 .30902 L
.17354 .30902 L
.17671 .30902 L
.17975 .30902 L
.18145 .30902 L
.183 .30902 L
.18376 .30902 L
.1846 .30902 L
.18498 .30902 L
.18539 .30902 L
.18573 .30902 L
.18593 .30902 L
.18612 .30902 L
.1863 .30902 L
.1864 .30902 L
.18651 .30902 L
.18656 .30902 L
.18662 .30902 L
.18673 .30902 L
.18683 .30902 L
.18692 .30902 L
.18701 .30902 L
.1871 .30902 L
Mistroke
.18719 .30902 L
.18729 .30902 L
.18748 .30902 L
.18767 .30902 L
.18808 .30902 L
.18831 .30902 L
.18853 .30902 L
.18934 .30902 L
.18975 .30902 L
.19019 .30902 L
.19099 .30902 L
.19248 .30902 L
.19325 .30902 L
.19408 .30902 L
.19578 .30902 L
.19734 .30902 L
.19902 .30902 L
.20061 .30902 L
.20234 .30902 L
.20554 .30902 L
.20882 .30902 L
.21197 .30902 L
.215 .30902 L
.21823 .30902 L
.22134 .30902 L
.22464 .30902 L
.22783 .30902 L
.22943 .30902 L
.23089 .30902 L
.2317 .30902 L
.23246 .30902 L
.23288 .30902 L
.23327 .30902 L
.23347 .30902 L
.23359 .30902 L
.23369 .30902 L
.23381 .30902 L
.23387 .30902 L
.23393 .30902 L
.23403 .30902 L
.23409 .30902 L
.23414 .30902 L
.23425 .30902 L
.2343 .30902 L
.23436 .30902 L
.23446 .30902 L
.23455 .30902 L
.23477 .30902 L
.23499 .30902 L
.23521 .30902 L
Mistroke
.23541 .30902 L
.23579 .30902 L
.23651 .30902 L
.23692 .30902 L
.23729 .30902 L
.23879 .30902 L
.23965 .30902 L
.24045 .30902 L
.24207 .30902 L
.24356 .30902 L
.24521 .30902 L
.24674 .30902 L
.24981 .30902 L
.25295 .30902 L
.25629 .30902 L
.2595 .30902 L
.26259 .30902 L
.26588 .30902 L
.26752 .30902 L
.26905 .30902 L
.26981 .30902 L
.27052 .30902 L
.27092 .30902 L
.27135 .30902 L
.27174 .30902 L
.2721 .30902 L
.27229 .30902 L
.27247 .30902 L
.27256 .30902 L
.27267 .30902 L
.27272 .30902 L
.27277 .30902 L
.27287 .30902 L
.27297 .30902 L
.27307 .30902 L
.27316 .30902 L
.27325 .30902 L
.27333 .30902 L
.27342 .30902 L
.2736 .30902 L
.27381 .30902 L
.27401 .30902 L
.27445 .30902 L
.27486 .30902 L
.27525 .30902 L
.27602 .30902 L
.27684 .30902 L
.27832 .30902 L
.27915 .30902 L
.28004 .30902 L
Mistroke
.28166 .30902 L
.28496 .30902 L
.28813 .30902 L
.29118 .30901 L
.29443 .30901 L
.29755 .30901 L
.30088 .30901 L
.30254 .30901 L
.30327 .309 L
.30408 .309 L
.30445 .309 L
.30485 .309 L
.30519 .309 L
.30557 .309 L
.30578 .309 L
.30598 .309 L
.30608 .309 L
.30618 .309 L
.3063 .309 L
.3064 .309 L
.30649 .309 L
.30659 .309 L
.30667 .309 L
.30676 .309 L
.30686 .309 L
.30697 .309 L
.30707 .309 L
.30716 .309 L
.30734 .309 L
.30754 .309 L
.30795 .309 L
.30833 .309 L
.30869 .309 L
.30949 .309 L
.31035 .30901 L
.31112 .30901 L
.31196 .30901 L
.31365 .30901 L
.31522 .30901 L
.3169 .30901 L
.32023 .30902 L
.32344 .30903 L
.32652 .30905 L
.3298 .30906 L
.33143 .30906 L
.33296 .30907 L
.33371 .30907 L
.33442 .30907 L
.33482 .30907 L
.33525 .30907 L
Mistroke
.33564 .30907 L
.336 .30907 L
.33621 .30907 L
.33631 .30907 L
.33641 .30907 L
.33651 .30907 L
.33656 .30907 L
.33662 .30907 L
.33668 .30907 L
.33674 .30907 L
.33679 .30907 L
.33685 .30907 L
.33694 .30907 L
.33705 .30907 L
.3371 .30907 L
.33716 .30907 L
.33726 .30907 L
.33746 .30907 L
.33765 .30907 L
.33799 .30907 L
.33837 .30907 L
.33877 .30907 L
.33914 .30907 L
.33998 .30907 L
.34078 .30907 L
.34227 .30906 L
.34388 .30905 L
.34536 .30904 L
.34853 .30901 L
.35157 .30897 L
.35481 .30892 L
.35792 .30888 L
.35951 .30886 L
.36035 .30885 L
.36124 .30884 L
.36211 .30883 L
.36289 .30883 L
.36327 .30883 L
.36347 .30883 L
.36368 .30883 L
.36387 .30883 L
.36397 .30883 L
.36407 .30883 L
.36416 .30883 L
.36424 .30883 L
.36434 .30883 L
.36443 .30883 L
.36452 .30883 L
.36462 .30883 L
.36471 .30883 L
Mistroke
.3648 .30883 L
.36501 .30883 L
.36521 .30883 L
.3656 .30883 L
.36603 .30883 L
.3664 .30883 L
.3668 .30884 L
.36751 .30884 L
.36833 .30885 L
.36923 .30887 L
.37085 .3089 L
.37244 .30894 L
.37414 .309 L
.37718 .30912 L
.38042 .30927 L
.38354 .3094 L
.38513 .30946 L
.38597 .30949 L
.38686 .30952 L
.38765 .30953 L
.38807 .30954 L
.38852 .30955 L
.38872 .30955 L
.38894 .30955 L
.38913 .30955 L
.38932 .30955 L
.38949 .30955 L
.38958 .30955 L
.38967 .30955 L
.38977 .30955 L
.38987 .30956 L
.38997 .30955 L
.39006 .30955 L
.39016 .30955 L
.39025 .30955 L
.39034 .30955 L
.39043 .30955 L
.39064 .30955 L
.39084 .30955 L
.39119 .30955 L
.39156 .30954 L
.39201 .30953 L
.39243 .30952 L
.39322 .3095 L
.394 .30947 L
.39483 .30943 L
.39632 .30934 L
.39937 .30907 L
.40261 .3087 L
.40574 .30831 L
Mistroke
.40733 .30812 L
.40906 .30794 L
.40987 .30787 L
.41072 .30781 L
.41146 .30776 L
.41226 .30773 L
.41266 .30771 L
.41287 .30771 L
.41307 .30771 L
.41324 .3077 L
.41333 .3077 L
.41343 .3077 L
.41353 .3077 L
.41363 .3077 L
.41373 .3077 L
.41382 .3077 L
.41391 .3077 L
.41402 .3077 L
.41411 .3077 L
.4142 .3077 L
.41442 .3077 L
.41463 .30771 L
.41484 .30771 L
.41504 .30772 L
.41549 .30774 L
.4159 .30776 L
.41634 .30779 L
.41714 .30785 L
.41864 .30803 L
.42024 .30829 L
.42194 .30864 L
.42499 .30944 L
.42824 .3104 L
.43137 .31124 L
.43219 .31142 L
.43308 .31159 L
.43392 .31172 L
.43429 .31176 L
.4347 .3118 L
.4351 .31184 L
.43547 .31186 L
.43565 .31187 L
.43575 .31187 L
.43585 .31187 L
.43594 .31187 L
.43603 .31188 L
.43612 .31188 L
.4362 .31188 L
.4363 .31188 L
.4364 .31188 L
Mistroke
.43645 .31188 L
.43651 .31188 L
.43661 .31188 L
.43672 .31187 L
.43681 .31187 L
.437 .31186 L
.43721 .31185 L
.43741 .31184 L
.43786 .3118 L
.43823 .31176 L
.43863 .3117 L
.43935 .31158 L
.44022 .31137 L
.44101 .31115 L
.44253 .31059 L
.44419 .30982 L
.44744 .30794 L
.45058 .30598 L
.45217 .30506 L
.45302 .30463 L
.45391 .30424 L
.4547 .30394 L
.45512 .3038 L
.45558 .30368 L
.45599 .30358 L
.45637 .30351 L
.45655 .30349 L
.45675 .30346 L
.45694 .30344 L
.45712 .30343 L
.45722 .30342 L
.45732 .30342 L
.45743 .30341 L
.45749 .30341 L
.45754 .30341 L
.45764 .30341 L
.45774 .30341 L
.45779 .30341 L
.45784 .30341 L
.45795 .30341 L
.45804 .30342 L
.45814 .30342 L
.45834 .30344 L
.45852 .30346 L
.4587 .30348 L
.45912 .30355 L
.45951 .30364 L
.46038 .30392 L
.46117 .30427 L
.4619 .30467 L
Mistroke
.46357 .30585 L
.4667 .30898 L
.47004 .31299 L
.47171 .31496 L
.47325 .31658 L
.47475 .31785 L
.47551 .31834 L
.47594 .31857 L
.47634 .31875 L
.47673 .31889 L
.47694 .31895 L
.47716 .319 L
.47734 .31904 L
.47744 .31905 L
.47755 .31906 L
.47764 .31907 L
.47773 .31908 L
.47782 .31909 L
.47791 .31909 L
.47801 .31909 L
.47811 .31909 L
.47816 .31909 L
.47822 .31909 L
.47832 .31908 L
.47842 .31907 L
.47852 .31906 L
.47871 .31903 L
.47892 .31898 L
.47913 .31893 L
.47958 .31876 L
.47998 .31857 L
.48042 .31832 L
.48121 .31771 L
.4827 .31613 L
.48428 .31383 L
.48596 .31079 L
.4893 .30373 L
.49098 .30015 L
.49252 .29717 L
.49402 .29478 L
.49478 .29383 L
.49521 .29338 L
.49561 .29302 L
.49601 .29274 L
.49621 .29261 L
.49643 .2925 L
.49662 .29242 L
.49682 .29235 L
.49691 .29232 L
.49701 .2923 L
Mistroke
.49709 .29228 L
.49718 .29227 L
.49729 .29226 L
.49738 .29225 L
.49744 .29225 L
.4975 .29225 L
.49761 .29225 L
.49766 .29225 L
.49772 .29226 L
.49782 .29227 L
.49793 .29229 L
.49806 .29232 L
.49826 .29239 L
.49847 .29247 L
.49886 .29269 L
.49928 .29301 L
.49967 .29338 L
.50056 .29451 L
.50134 .29581 L
.50217 .2975 L
.50552 .30704 L
.50874 .31852 L
.51184 .3286 L
.51344 .33238 L
.51425 .33372 L
.51471 .33429 L
.51493 .33452 L
.51514 .3347 L
.51533 .33484 L
.51554 .33496 L
.51575 .33505 L
.51587 .33509 L
.51592 .3351 L
.51598 .33511 L
.51608 .33512 L
.51618 .33513 L
.51627 .33513 L
.51636 .33512 L
.51647 .3351 L
.51656 .33508 L
.51667 .33504 L
.51677 .335 L
.51695 .3349 L
.51715 .33478 L
.51749 .33447 L
.51786 .33404 L
.51826 .33344 L
.51908 .33182 L
.51983 .32989 L
.52151 .32403 L
Mistroke
.5247 .3084 L
.52778 .29125 L
.52933 .28338 L
.53016 .27974 L
.53105 .27639 L
.5319 .27384 L
.53227 .27294 L
.53268 .27212 L
.53306 .27152 L
.53342 .2711 L
.53362 .27093 L
.5338 .27082 L
.5339 .27078 L
.53395 .27076 L
.53401 .27074 L
.53411 .27072 L
.5342 .27071 L
.5343 .27071 L
.5344 .27073 L
.5345 .27076 L
.5346 .2708 L
.53477 .2709 L
.53496 .27104 L
.53518 .27127 L
.53539 .27154 L
.53577 .27219 L
.53648 .27386 L
.53724 .27636 L
.53801 .27957 L
.53884 .28384 L
.54054 .29459 L
.54378 .32027 L
.54691 .34459 L
.54773 .34981 L
.54862 .35463 L
.54946 .35821 L
.54983 .35946 L
.55023 .36057 L
.55043 .36102 L
.55064 .36142 L
.55083 .36172 L
.55101 .36195 L
.55117 .36211 L
.55127 .36218 L
.55135 .36223 L
.55145 .36227 L
.55155 .36229 L
.55164 .3623 L
.55173 .36229 L
.55183 .36226 L
Mistroke
.55193 .36222 L
.55203 .36216 L
.55212 .36209 L
.55233 .36186 L
.55254 .36156 L
.55294 .36073 L
.55339 .35948 L
.55414 .35655 L
.55497 .35212 L
.55666 .33967 L
.55988 .30632 L
.56298 .27125 L
.56455 .25623 L
.56539 .24978 L
.56585 .24677 L
.56628 .24431 L
.56669 .24234 L
.56714 .24063 L
.56734 .24003 L
.56755 .23949 L
.56774 .23908 L
.56792 .23878 L
.56801 .23867 L
.5681 .23857 L
.5682 .23849 L
.5683 .23843 L
.56839 .2384 L
.56848 .23839 L
.56857 .2384 L
.56865 .23842 L
.56876 .23848 L
.56885 .23856 L
.56896 .23867 L
.56907 .23882 L
.56925 .23914 L
.56946 .23959 L
.56988 .24087 L
.57027 .24251 L
.57102 .24665 L
.57183 .25265 L
.5727 .26087 L
.57597 .30374 L
.57913 .35155 L
.58071 .37236 L
.58216 .38707 L
.58291 .39258 L
.58329 .39471 L
.58371 .39654 L
.58393 .39728 L
.58413 .39781 L
Mistroke
.58424 .39805 L
.58436 .39827 L
.58447 .39842 L
.58458 .39853 L
.58467 .3986 L
.58476 .39863 L
.58486 .39864 L
.58492 .39862 L
.58497 .3986 L
.58507 .39854 L
.58513 .39848 L
.58518 .39842 L
.58538 .39811 L
.58549 .39789 L
.5856 .39762 L
.58579 .39704 L
.58623 .39524 L
.58662 .39314 L
.58703 .39027 L
.58781 .38344 L
.58853 .37538 L
.59017 .35176 L
.59166 .32532 L
.59486 .26322 L
.59632 .23775 L
.59716 .22542 L
.59794 .21574 L
.59871 .20828 L
.59914 .20505 L
.59953 .20275 L
.59972 .20187 L
.59992 .20109 L
.60004 .20072 L
.60015 .20044 L
.60025 .20022 L
.60035 .20003 L
.60041 .19995 L
.60046 .19988 L
.60057 .1998 L
.60062 .19977 L
.60069 .19975 L
.60075 .19976 L
.6008 .19977 L
.6009 .19984 L
.60096 .19989 L
.60101 .19996 L
.60111 .20012 L
.60122 .20033 L
.60141 .20084 L
.60161 .20155 L
Mistroke
.60197 .20327 L
.60236 .20576 L
.60278 .20923 L
.60354 .21735 L
.60425 .227 L
.60589 .25612 L
.60738 .28877 L
.61058 .36496 L
.61205 .39559 L
.61289 .41011 L
.61367 .42125 L
.61444 .42955 L
.61487 .43297 L
.61526 .43526 L
.61548 .43617 L
.61568 .4368 L
.61579 .43706 L
.6159 .43724 L
.61595 .43731 L
.61602 .43737 L
.61608 .43741 L
.61613 .43742 L
.61623 .43741 L
.61632 .43736 L
.61642 .43724 L
.61648 .43715 L
.61653 .43705 L
.61663 .43681 L
.61675 .43648 L
.61695 .43571 L
.61714 .4348 L
.61734 .43361 L
.61771 .43088 L
.61814 .42671 L
.61854 .42202 L
.61936 .40983 L
.62023 .39362 L
.62329 .3162 L
.625 .26756 L
.62655 .2265 L
.62732 .20857 L
.62816 .19188 L
.62895 .17925 L
.62968 .17065 L
.63006 .16745 L
.63026 .16605 L
.63046 .16498 L
.63064 .1642 L
.63074 .16387 L
.63084 .16359 L
Mistroke
.63094 .16339 L
.63102 .16326 L
.63111 .16317 L
.63119 .16314 L
.63129 .16315 L
.63139 .16324 L
.63144 .16331 L
.6315 .1634 L
.6316 .16363 L
.63171 .16392 L
.6318 .16426 L
.63199 .16506 L
.6322 .16629 L
.6324 .16769 L
.63285 .17177 L
.63362 .18183 L
.63435 .1945 L
.636 .23356 L
.63912 .33042 L
.6407 .38056 L
.64153 .40454 L
.64242 .427 L
.64329 .44495 L
.64408 .45732 L
.64446 .46184 L
.64465 .46381 L
.64487 .46559 L
.64505 .46689 L
.64525 .46803 L
.64534 .46843 L
.64544 .4688 L
.64553 .46908 L
.64561 .46929 L
.64571 .46948 L
.64576 .46954 L
.64582 .46959 L
.64587 .46962 L
.64593 .46962 L
.64603 .46956 L
.64613 .46944 L
.64622 .46925 L
.64632 .46898 L
.64643 .46861 L
.64667 .46746 L
.64689 .46598 L
.64731 .4622 L
.64772 .45737 L
.64809 .45189 L
.64893 .43604 L
.65043 .39704 L
Mistroke
.65209 .3426 L
.65378 .2815 L
.65533 .22777 L
.65611 .20343 L
.65694 .18074 L
.65772 .1634 L
.65844 .15081 L
.65883 .14573 L
.65903 .14352 L
.65924 .14155 L
.65943 .14017 L
.65962 .13897 L
.65971 .13854 L
.6598 .13815 L
.65988 .13787 L
.65997 .13763 L
.66002 .13751 L
.66008 .13741 L
.66018 .13731 L
.66024 .13728 L
.66031 .13729 L
.66036 .13733 L
.66042 .13739 L
.66052 .13757 L
.66057 .1377 L
.66062 .13785 L
.66074 .13825 L
.66084 .13872 L
.66104 .13988 L
.66123 .14122 L
.66163 .14524 L
.66201 .15008 L
.66242 .15666 L
.66324 .17382 L
.66473 .21583 L
.66797 .33692 L
.66946 .39274 L
.67109 .44332 L
.67197 .46389 L
.67236 .47107 L
.67279 .47758 L
.67319 .48227 L
.67338 .48394 L
.67357 .48537 L
.67367 .48597 L
.67378 .48653 L
.67388 .48695 L
.67397 .48725 L
.67402 .48739 L
.67408 .48751 L
Mistroke
.67414 .48761 L
.6742 .48767 L
.67425 .4877 L
.6743 .48771 L
.6744 .48765 L
.6745 .48751 L
.67461 .48725 L
.67471 .48692 L
.6748 .48653 L
.67497 .48558 L
.67516 .48426 L
.67559 .48006 L
.67597 .47487 L
.67673 .46104 L
.67744 .44387 L
.67905 .39259 L
.68054 .33508 L
.68218 .26794 L
.68371 .20994 L
.68518 .16527 L
.6856 .15522 L
.686 .14703 L
.68639 .14043 L
.68676 .13544 L
.68712 .13164 L
.68732 .13014 L
.68742 .12951 L
.68753 .12893 L
.68763 .1285 L
.68774 .12814 L
.6878 .128 L
.68785 .1279 L
.68796 .12778 L
.68806 .12777 L
.68816 .12786 L
.68826 .12804 L
.68835 .12829 L
.68844 .1286 L
.68853 .12901 L
.6887 .12995 L
.68889 .13141 L
.68907 .13307 L
.68946 .13771 L
.68983 .14341 L
.69061 .15915 L
.69143 .18117 L
.6929 .23181 L
.69625 .36896 L
.69793 .42939 L
.69866 .45052 L
Mistroke
.69905 .46004 L
.69947 .46881 L
.69988 .47593 L
.70025 .48107 L
.70043 .48308 L
.70062 .4849 L
.7008 .48628 L
.70098 .48728 L
.70107 .48769 L
.70117 .48805 L
.70122 .48821 L
.70128 .48833 L
.70138 .48848 L
.70148 .48853 L
.70158 .48847 L
.70164 .4884 L
.70169 .4883 L
.70175 .48816 L
.7018 .48799 L
.7019 .48765 L
.70199 .48719 L
.70217 .48613 L
.70236 .48466 L
.70257 .48263 L
.70299 .47727 L
.70339 .47066 L
.70413 .4545 L
.70494 .4321 L
.70581 .40276 L
.70908 .27004 L
.71071 .20831 L
.7115 .18316 L
.71223 .16414 L
.71294 .14993 L
.7133 .14452 L
.71369 .13998 L
.71389 .13818 L
.71408 .13691 L
.71419 .13636 L
.7143 .13588 L
.71435 .1357 L
.7144 .13554 L
.7145 .13533 L
.71459 .13523 L
.71469 .1352 L
.71478 .13526 L
.71486 .13539 L
.71496 .13563 L
.71507 .136 L
.71517 .13645 L
Mistroke
.71526 .13696 L
.71547 .13845 L
.71567 .14021 L
.71611 .14553 L
.7165 .15174 L
.71691 .15978 L
.7184 .20044 L
.72145 .31789 L
.72315 .38442 L
.7247 .43358 L
.72547 .45165 L
.72588 .45915 L
.72631 .46548 L
.72668 .46957 L
.7269 .47129 L
.72699 .47193 L
.7271 .4725 L
.72718 .4729 L
.72728 .47326 L
.72737 .4735 L
.72745 .47366 L
.72754 .47377 L
.72763 .47379 L
.72773 .47371 L
.72783 .47355 L
.72792 .47331 L
.72802 .47296 L
.7282 .47207 L
.72841 .4706 L
.72861 .46888 L
.72903 .4639 L
.72943 .45764 L
.73014 .44319 L
.73092 .42297 L
.73419 .30505 L
.7357 .24777 L
.73733 .19665 L
.73777 .18591 L
.73823 .17622 L
.73866 .16884 L
.73906 .16341 L
.73943 .15964 L
.73964 .15809 L
.73983 .15704 L
.73994 .1566 L
.74004 .15629 L
.74009 .15616 L
.74015 .15606 L
.74021 .15598 L
.74027 .15594 L
Mistroke
.74037 .15594 L
.74046 .15603 L
.74052 .15612 L
.74057 .15625 L
.74068 .15655 L
.74078 .15698 L
.74088 .15746 L
.7411 .15888 L
.7413 .16051 L
.74151 .16261 L
.74226 .17342 L
.74267 .18143 L
.74306 .1901 L
.74394 .21367 L
.74706 .3223 L
.74865 .37709 L
.74949 .40167 L
.75038 .42293 L
.75117 .4368 L
.75139 .4397 L
.75162 .44238 L
.75182 .44432 L
.75204 .44602 L
.75214 .44664 L
.75225 .44721 L
.75234 .44762 L
.75243 .44798 L
.75249 .44816 L
.75255 .44829 L
.75265 .44848 L
.75274 .44856 L
.75285 .44856 L
.75293 .44849 L
.75303 .44834 L
.75311 .44812 L
.7532 .44787 L
.75339 .44699 L
.75358 .44584 L
.75399 .44231 L
.75435 .43793 L
.75517 .42421 L
.75593 .4072 L
.75665 .38802 L
.75975 .2872 L
.76132 .23916 L
.76215 .21833 L
.76261 .2087 L
.76304 .20093 L
.76346 .19483 L
.76367 .19215 L
Mistroke
.7639 .18972 L
.7641 .188 L
.76431 .18647 L
.7645 .1854 L
.76469 .18468 L
.76478 .18443 L
.76487 .18423 L
.76498 .18411 L
.76507 .18407 L
.76516 .1841 L
.76524 .18419 L
.76534 .18436 L
.76542 .18459 L
.76552 .18491 L
.76562 .18534 L
.76581 .18631 L
.766 .18765 L
.76622 .18949 L
.76664 .19408 L
.76704 .19966 L
.76778 .21304 L
.76946 .25442 L
.77253 .34595 L
.77412 .38559 L
.77492 .40059 L
.77538 .40728 L
.7758 .41224 L
.77618 .41549 L
.77639 .41687 L
.77659 .41784 L
.7767 .41825 L
.7768 .41855 L
.77689 .41875 L
.77699 .4189 L
.77705 .41895 L
.7771 .41898 L
.77716 .41898 L
.77722 .41896 L
.77732 .41886 L
.77737 .41878 L
.77742 .41868 L
.77751 .41845 L
.77761 .41814 L
.77779 .41741 L
.77799 .41624 L
.77818 .41491 L
.77856 .41154 L
.77891 .4075 L
.77969 .39562 L
.78052 .37935 L
Mistroke
.782 .34332 L
.78505 .26367 L
.78586 .24642 L
.78662 .23297 L
.78704 .22694 L
.7875 .22162 L
.7877 .2197 L
.78791 .21795 L
.7881 .21669 L
.7883 .21557 L
.78849 .21476 L
.78859 .21442 L
.78869 .21417 L
.78878 .214 L
.78887 .21389 L
.78896 .21382 L
.78905 .21381 L
.78915 .21387 L
.78925 .21399 L
.78934 .21416 L
.78944 .21441 L
.78966 .21518 L
.78986 .21619 L
.79023 .2187 L
.79057 .22175 L
.79133 .23103 L
.79212 .24391 L
.79286 .25823 L
.79452 .29586 L
.79604 .33108 L
.79767 .36344 L
.79811 .37033 L
.79857 .3766 L
.79899 .3814 L
.79939 .38497 L
.79977 .38749 L
.79998 .38854 L
.80017 .38928 L
.80027 .3896 L
.80037 .38983 L
.80048 .39002 L
.80054 .39009 L
.8006 .39014 L
.8007 .39018 L
.80076 .39017 L
.80081 .39015 L
.80092 .39006 L
.80101 .38991 L
.80111 .38971 L
.80122 .38942 L
Mistroke
.80142 .38873 L
.80161 .38784 L
.80178 .38684 L
.80218 .38395 L
.8026 .37997 L
.80331 .37142 L
.80408 .35965 L
.80732 .29663 L
.80882 .26973 L
.8096 .25835 L
.81044 .24911 L
.81086 .24572 L
.81109 .24427 L
.81133 .24299 L
.81155 .24208 L
.81164 .24176 L
.81175 .24147 L
.81184 .24125 L
.81194 .24108 L
.81205 .24095 L
.81215 .24088 L
.8122 .24086 L
.81226 .24086 L
.81236 .24089 L
.81241 .24093 L
.81246 .24099 L
.81252 .24106 L
.81258 .24116 L
.81269 .24139 L
.8128 .24166 L
.81299 .24231 L
.81336 .24405 L
.81376 .24668 L
.81459 .25435 L
.81534 .26358 L
.81703 .28972 L
.8187 .31838 L
.82025 .34182 L
.82103 .35124 L
.82175 .35806 L
.82212 .36069 L
.82251 .36289 L
.82274 .36384 L
.82295 .36454 L
.82314 .365 L
.82324 .36519 L
.82334 .36532 L
.82344 .3654 L
.82354 .36545 L
.82362 .36545 L
Mistroke
.82372 .36542 L
.82382 .36534 L
.82387 .36528 L
.82392 .36521 L
.82403 .36504 L
.82412 .36485 L
.8243 .36437 L
.82449 .3637 L
.82484 .36208 L
.82523 .35977 L
.82565 .3566 L
.8265 .34839 L
.82974 .30472 L
.83123 .28519 L
.83202 .27675 L
.83286 .26975 L
.83328 .26712 L
.8335 .26597 L
.83374 .26494 L
.83396 .26418 L
.83416 .26363 L
.83436 .26326 L
.83445 .26312 L
.83456 .26301 L
.83461 .26298 L
.83467 .26295 L
.83477 .26292 L
.83487 .26293 L
.83497 .26298 L
.83506 .26306 L
.83512 .26313 L
.83517 .2632 L
.8354 .2636 L
.83559 .26411 L
.83577 .26469 L
.83618 .26639 L
.83656 .26849 L
.83697 .27122 L
.8377 .27726 L
.83936 .29484 L
.84097 .31369 L
.84181 .32301 L
.8427 .33167 L
.8435 .33797 L
.84392 .34065 L
.84438 .34295 L
.84459 .34383 L
.84479 .34454 L
.84499 .34511 L
.84517 .34552 L
Mistroke
.84535 .34583 L
.84543 .34594 L
.84553 .34604 L
.84563 .34612 L
.84573 .34616 L
.84583 .34618 L
.84592 .34617 L
.84602 .34612 L
.84612 .34605 L
.8462 .34596 L
.8463 .34584 L
.84651 .34547 L
.84671 .34502 L
.84706 .3439 L
.84744 .34235 L
.84823 .33793 L
.8491 .33155 L
.85079 .31624 L
.85234 .30162 L
.8531 .29508 L
.85394 .28895 L
.85432 .28659 L
.85472 .28441 L
.85508 .28281 L
.85545 .28145 L
.85566 .28085 L
.85589 .28031 L
.85609 .27993 L
.85628 .27967 L
.85634 .27961 L
.8564 .27956 L
.85645 .27952 L
.85651 .27949 L
.85656 .27946 L
.85662 .27944 L
.85671 .27943 L
.85677 .27943 L
.85683 .27945 L
.85689 .27947 L
.85695 .2795 L
.85706 .27957 L
.85718 .27969 L
.85739 .27999 L
.85758 .28035 L
.85802 .28148 L
.85842 .28289 L
.8588 .28453 L
.86041 .29416 L
.86189 .30528 L
.86353 .31745 L
Mistroke
.86433 .32256 L
.86506 .32644 L
.86542 .32803 L
.86581 .32949 L
.86615 .33051 L
.86653 .33138 L
.86673 .33173 L
.86692 .33198 L
.86703 .33209 L
.86713 .33217 L
.86723 .33223 L
.86729 .33225 L
.86734 .33227 L
.86744 .33229 L
.86753 .33229 L
.86764 .33226 L
.86774 .33222 L
.86783 .33216 L
.86791 .33209 L
.8681 .33189 L
.8683 .33161 L
.86848 .33129 L
.86888 .33035 L
.86961 .32796 L
.87046 .32419 L
.87126 .31987 L
.87433 .30175 L
.87514 .29777 L
.87591 .29473 L
.87634 .29341 L
.87679 .29228 L
.877 .29189 L
.87721 .29155 L
.87739 .29131 L
.87759 .29112 L
.8777 .29104 L
.8778 .29099 L
.87785 .29097 L
.8779 .29095 L
.87796 .29093 L
.87802 .29093 L
.87812 .29092 L
.87821 .29093 L
.87831 .29096 L
.87842 .29101 L
.8785 .29106 L
.8786 .29113 L
.87877 .2913 L
.87898 .29155 L
.87916 .29183 L
Mistroke
.87958 .29265 L
.88003 .29379 L
.88084 .29648 L
.88413 .31137 L
.88492 .31481 L
.88576 .31799 L
.88617 .31929 L
.88656 .32036 L
.88695 .32124 L
.88729 .32188 L
.88766 .3224 L
.88786 .32261 L
.88795 .32268 L
.88805 .32276 L
.88813 .32281 L
.88822 .32285 L
.88831 .32289 L
.88839 .32291 L
.88848 .32292 L
.88856 .32293 L
.88866 .32293 L
.88875 .32291 L
.88884 .32288 L
.88894 .32284 L
.88905 .32279 L
.88915 .32272 L
.88932 .32258 L
.88951 .32238 L
.88994 .32178 L
.89034 .32105 L
.89113 .31914 L
.89186 .31692 L
.89352 .31098 L
.89503 .30557 L
.89582 .3031 L
.89666 .30098 L
.89709 .30012 L
.89756 .29937 L
.89776 .29911 L
.89798 .29888 L
.89819 .29871 L
.89838 .29858 L
.89848 .29853 L
.89859 .29849 L
.89864 .29847 L
.8987 .29846 L
.89876 .29845 L
.89882 .29844 L
.89892 .29843 L
.89897 .29843 L
Mistroke
.89903 .29844 L
.89913 .29845 L
.89923 .29848 L
.89933 .29851 L
.89942 .29855 L
.8996 .29865 L
.89979 .2988 L
.9 .29899 L
.90039 .29945 L
.90076 .3 L
.9016 .30162 L
.90328 .30597 L
.90478 .31018 L
.9064 .3141 L
.90683 .3149 L
.90728 .31562 L
.90767 .31613 L
.9081 .31655 L
.90833 .31671 L
.90854 .31683 L
.90874 .31691 L
.90884 .31694 L
.90889 .31696 L
.90895 .31697 L
.90905 .31698 L
.90914 .31698 L
.90924 .31698 L
.90929 .31698 L
.90934 .31697 L
.90943 .31696 L
.90952 .31694 L
.90962 .31691 L
.90971 .31687 L
.90991 .31678 L
.91009 .31666 L
.9105 .31632 L
.91091 .31589 L
.91134 .31531 L
.91282 .31268 L
.91442 .30927 L
.91527 .30752 L
.91616 .30587 L
.91695 .30466 L
.91738 .30415 L
.91783 .3037 L
.91804 .30353 L
.91825 .3034 L
.91844 .30329 L
.91863 .30321 L
.9188 .30315 L
Mistroke
.91889 .30312 L
.91898 .30311 L
.91908 .30309 L
.91918 .30308 L
.91928 .30308 L
.91937 .30308 L
.91947 .30309 L
.91957 .3031 L
.91965 .30312 L
.91975 .30314 L
.91996 .30321 L
.92015 .3033 L
.92051 .3035 L
.92089 .30379 L
.92168 .3046 L
.92255 .30576 L
.92424 .30842 L
.92578 .31079 L
.92655 .31176 L
.92695 .31219 L
.92738 .31259 L
.92779 .3129 L
.92816 .31312 L
.92835 .3132 L
.92854 .31328 L
.92873 .31333 L
.92889 .31337 L
.929 .31338 L
.92909 .31339 L
.92918 .3134 L
.92927 .3134 L
.92937 .3134 L
.92943 .3134 L
.92948 .31339 L
.92958 .31338 L
.92968 .31337 L
.92986 .31333 L
.93003 .31328 L
.93041 .31313 L
.93079 .31292 L
.93121 .31264 L
.93207 .31189 L
.93377 .30997 L
.93532 .30814 L
.9361 .30735 L
.93694 .30665 L
.93732 .30639 L
.93773 .30616 L
.93808 .30602 L
.93827 .30595 L
Mistroke
.93846 .3059 L
.93866 .30586 L
.93876 .30584 L
.93882 .30583 L
.93888 .30583 L
.93893 .30582 L
.93898 .30582 L
.93908 .30581 L
.93918 .30581 L
.93927 .30581 L
.93936 .30582 L
.93946 .30582 L
.93955 .30583 L
.93963 .30584 L
.93983 .30588 L
.94002 .30592 L
.94044 .30606 L
.94082 .30623 L
.9417 .30675 L
.94485 .3094 L
.94567 .31004 L
.94644 .31056 L
.94713 .31092 L
.94752 .31108 L
.94789 .3112 L
.94809 .31124 L
.94828 .31128 L
.94846 .31131 L
.94855 .31132 L
.94864 .31133 L
.94874 .31133 L
.94883 .31134 L
.94893 .31134 L
.94903 .31134 L
.94909 .31134 L
.94914 .31134 L
.94925 .31133 L
.94935 .31132 L
.94945 .31131 L
.94964 .31129 L
.94983 .31125 L
.95026 .31115 L
.95067 .31101 L
.95112 .31082 L
.95273 .30993 L
.95442 .30884 L
.95519 .30839 L
.95601 .30797 L
.9564 .3078 L
.95678 .30767 L
Mistroke
.95714 .30756 L
.95748 .30747 L
.95785 .30741 L
.95805 .30738 L
.95816 .30737 L
.95826 .30736 L
.95836 .30736 L
.95842 .30735 L
.95848 .30735 L
.95854 .30735 L
.95859 .30735 L
.95869 .30735 L
.95879 .30735 L
.95888 .30735 L
.95898 .30736 L
.95908 .30736 L
.95926 .30738 L
.95945 .3074 L
.95979 .30746 L
.9602 .30755 L
.96057 .30765 L
.9621 .30824 L
.96377 .30901 L
.96532 .30966 L
.96575 .3098 L
.96621 .30994 L
.96661 .31003 L
.96682 .31007 L
.96704 .31011 L
.96726 .31014 L
.96746 .31017 L
.96766 .31018 L
.96775 .31019 L
.96784 .3102 L
.96795 .3102 L
.968 .3102 L
.96806 .3102 L
.96815 .31021 L
.96825 .31021 L
.96831 .31021 L
.96837 .3102 L
.96843 .3102 L
.96848 .3102 L
.96858 .3102 L
.96869 .31019 L
.96887 .31018 L
.96906 .31016 L
.96941 .31012 L
.96982 .31005 L
.9702 .30997 L
Mistroke
.97171 .30955 L
.97337 .309 L
.97619 .30829 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{421.375, 260.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 525.688}, {324.5, 0}} -> {-2.58312*^-7, -6.34248*^6, \
6.65005*^-9, 53093.5}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0.309017 5.42214e-08 [
[.32684 .29652 -16.5 -12.5 ]
[.32684 .29652 16.5 0 ]
[.54329 .29652 -16.5 -12.5 ]
[.54329 .29652 16.5 0 ]
[.75974 .29652 -22.5 -12.5 ]
[.75974 .29652 22.5 0 ]
[.97619 .29652 -16.5 -12.5 ]
[.97619 .29652 16.5 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 64 6 ]
[.09789 .09213 -34.5 -6.25 ]
[.09789 .09213 0 6.25 ]
[.09789 .20057 -34.5 -6.25 ]
[.09789 .20057 0 6.25 ]
[.09789 .41746 -28.5 -6.25 ]
[.09789 .41746 0 6.25 ]
[.09789 .5259 -28.5 -6.25 ]
[.09789 .5259 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -65.8125 0 ]
[.5 .63053 65.8125 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 .30902 m
.32684 .31527 L
s
gsave
.32684 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 .30902 m
.54329 .31527 L
s
gsave
.54329 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 .30902 m
.75974 .31527 L
s
gsave
.75974 .29652 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 .30902 m
.15368 .31277 L
s
.19697 .30902 m
.19697 .31277 L
s
.24026 .30902 m
.24026 .31277 L
s
.28355 .30902 m
.28355 .31277 L
s
.37013 .30902 m
.37013 .31277 L
s
.41342 .30902 m
.41342 .31277 L
s
.45671 .30902 m
.45671 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.58658 .30902 m
.58658 .31277 L
s
.62987 .30902 m
.62987 .31277 L
s
.67316 .30902 m
.67316 .31277 L
s
.71645 .30902 m
.71645 .31277 L
s
.80303 .30902 m
.80303 .31277 L
s
.84632 .30902 m
.84632 .31277 L
s
.88961 .30902 m
.88961 .31277 L
s
.9329 .30902 m
.9329 .31277 L
s
.0671 .30902 m
.0671 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09213 m
.11664 .09213 L
s
gsave
.09789 .09213 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .20057 m
.11664 .20057 L
s
gsave
.09789 .20057 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .41746 m
.11664 .41746 L
s
gsave
.09789 .41746 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .5259 m
.11664 .5259 L
s
gsave
.09789 .5259 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.11039 .11924 m
.11414 .11924 L
s
.11039 .14635 m
.11414 .14635 L
s
.11039 .17346 m
.11414 .17346 L
s
.11039 .22768 m
.11414 .22768 L
s
.11039 .2548 m
.11414 .2548 L
s
.11039 .28191 m
.11414 .28191 L
s
.11039 .33613 m
.11414 .33613 L
s
.11039 .36324 m
.11414 .36324 L
s
.11039 .39035 m
.11414 .39035 L
s
.11039 .44457 m
.11414 .44457 L
s
.11039 .47168 m
.11414 .47168 L
s
.11039 .49879 m
.11414 .49879 L
s
.11039 .06502 m
.11414 .06502 L
s
.11039 .03791 m
.11414 .03791 L
s
.11039 .0108 m
.11414 .0108 L
s
.11039 .55301 m
.11414 .55301 L
s
.11039 .58012 m
.11414 .58012 L
s
.11039 .60723 m
.11414 .60723 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -126.812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.812 moveto
(@) show
81.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.812 moveto
(D) show
93.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11.8) show
141.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
147.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
159.000 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
163.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
172.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
190.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02691 .30902 L
.03029 .30902 L
.03347 .30902 L
.03652 .30902 L
.03978 .30902 L
.04291 .30902 L
.04623 .30902 L
.04944 .30902 L
.05252 .30902 L
.0558 .30902 L
.05896 .30902 L
.062 .30902 L
.06523 .30902 L
.06834 .30902 L
.07165 .30902 L
.07484 .30902 L
.0779 .30902 L
.08117 .30902 L
.08431 .30902 L
.08765 .30902 L
.09086 .30902 L
.09396 .30902 L
.09725 .30902 L
.10042 .30902 L
.10346 .30902 L
.10671 .30902 L
.10983 .30902 L
.11142 .30902 L
.11315 .30902 L
.11396 .30902 L
.11481 .30902 L
.11554 .30902 L
.11596 .30902 L
.11616 .30902 L
.11635 .30902 L
.11655 .30902 L
.11673 .30902 L
.11693 .30902 L
.11704 .30902 L
.11714 .30902 L
.11724 .30902 L
.11729 .30902 L
.11735 .30902 L
.11745 .30902 L
.11754 .30902 L
.11759 .30902 L
.11765 .30902 L
.11775 .30902 L
.11785 .30902 L
Mistroke
.11797 .30902 L
.11817 .30902 L
.11834 .30902 L
.11874 .30902 L
.11911 .30902 L
.11946 .30902 L
.12024 .30902 L
.12107 .30902 L
.12178 .30902 L
.12255 .30902 L
.12412 .30902 L
.125 .30902 L
.1258 .30902 L
.12734 .30902 L
.12901 .30902 L
.1306 .30902 L
.13228 .30902 L
.13532 .30902 L
.13687 .30902 L
.13855 .30902 L
.14186 .30902 L
.14504 .30902 L
.1481 .30902 L
.15136 .30902 L
.1545 .30902 L
.15784 .30902 L
.16105 .30902 L
.16414 .30902 L
.16743 .30902 L
.1706 .30902 L
.17364 .30902 L
.17688 .30902 L
.18001 .30902 L
.18159 .30902 L
.18243 .30902 L
.18332 .30902 L
.18411 .30902 L
.18453 .30902 L
.18498 .30902 L
.18518 .30902 L
.18539 .30902 L
.18559 .30902 L
.18577 .30902 L
.18595 .30902 L
.18603 .30902 L
.18613 .30902 L
.18623 .30902 L
.18633 .30902 L
.18643 .30902 L
.18652 .30902 L
Mistroke
.18662 .30902 L
.18671 .30902 L
.1868 .30902 L
.18689 .30902 L
.1871 .30902 L
.18729 .30902 L
.18765 .30902 L
.18802 .30902 L
.18847 .30902 L
.18889 .30902 L
.18968 .30902 L
.19046 .30902 L
.19129 .30902 L
.19277 .30902 L
.19435 .30902 L
.19582 .30902 L
.19746 .30902 L
.19895 .30902 L
.20215 .30902 L
.20523 .30902 L
.2085 .30902 L
.21166 .30902 L
.21469 .30902 L
.21792 .30902 L
.22102 .30902 L
.22433 .30902 L
.22751 .30902 L
.22911 .30902 L
.23057 .30902 L
.23132 .30902 L
.23214 .30902 L
.23259 .30902 L
.23301 .30902 L
.23341 .30902 L
.23362 .30902 L
.23383 .30902 L
.23402 .30902 L
.23412 .30902 L
.23422 .30902 L
.23432 .30902 L
.23441 .30902 L
.2345 .30902 L
.23458 .30902 L
.23468 .30902 L
.23479 .30902 L
.23488 .30902 L
.23498 .30902 L
.23508 .30902 L
.23519 .30902 L
.2354 .30902 L
Mistroke
.23559 .30902 L
.23579 .30902 L
.23617 .30902 L
.23653 .30902 L
.23687 .30902 L
.23764 .30902 L
.23837 .30902 L
.23917 .30902 L
.24003 .30902 L
.24172 .30902 L
.24333 .30902 L
.24492 .30902 L
.2464 .30902 L
.24954 .30902 L
.25288 .30902 L
.25609 .30902 L
.25918 .30902 L
.26247 .30902 L
.26564 .30902 L
.26869 .30902 L
.27026 .30902 L
.27113 .30902 L
.27193 .30902 L
.27232 .30902 L
.27275 .30902 L
.27296 .30902 L
.27318 .30902 L
.2733 .30902 L
.27342 .30902 L
.27352 .30902 L
.27364 .30902 L
.27374 .30902 L
.27383 .30902 L
.27393 .30902 L
.27401 .30902 L
.27412 .30902 L
.27421 .30902 L
.27431 .30902 L
.27437 .30902 L
.27442 .30902 L
.27463 .30902 L
.27475 .30902 L
.27485 .30902 L
.27525 .30902 L
.27564 .30902 L
.27604 .30902 L
.27678 .30902 L
.27765 .30902 L
.27844 .30902 L
.27999 .30902 L
Mistroke
.28166 .30902 L
.28327 .30902 L
.28496 .30902 L
.28801 .30902 L
.29126 .30901 L
.29438 .30901 L
.29771 .30901 L
.30091 .30901 L
.30237 .30901 L
.30399 .30901 L
.30475 .30901 L
.30558 .30901 L
.30603 .30901 L
.30645 .30901 L
.30684 .30901 L
.30706 .30901 L
.30726 .30901 L
.30746 .30901 L
.30757 .30901 L
.30768 .30901 L
.30777 .30901 L
.30787 .30901 L
.30796 .30901 L
.30805 .30901 L
.30815 .30901 L
.30824 .30901 L
.30832 .30901 L
.30841 .30901 L
.3085 .30901 L
.3086 .30901 L
.30878 .30901 L
.30898 .30901 L
.30919 .30901 L
.30957 .30901 L
.31003 .30901 L
.31045 .30901 L
.31123 .30901 L
.31196 .30901 L
.31282 .30901 L
.31362 .30901 L
.31526 .30901 L
.31675 .30901 L
.31984 .30902 L
.32312 .30903 L
.32628 .30904 L
.32932 .30905 L
.33255 .30906 L
.33404 .30906 L
.33566 .30906 L
.33654 .30906 L
Mistroke
.33697 .30906 L
.33736 .30907 L
.33755 .30907 L
.33776 .30907 L
.33794 .30907 L
.33814 .30907 L
.33825 .30907 L
.33835 .30907 L
.33846 .30907 L
.33852 .30907 L
.33857 .30907 L
.33867 .30907 L
.33873 .30907 L
.33878 .30907 L
.33887 .30907 L
.33897 .30907 L
.33906 .30907 L
.33916 .30907 L
.33937 .30907 L
.33955 .30907 L
.33973 .30907 L
.34012 .30907 L
.34054 .30906 L
.34131 .30906 L
.342 .30906 L
.34281 .30906 L
.34354 .30906 L
.34521 .30905 L
.34672 .30904 L
.34838 .30903 L
.35162 .309 L
.35473 .30896 L
.35805 .30892 L
.3597 .3089 L
.36124 .30888 L
.36282 .30887 L
.3636 .30886 L
.36431 .30886 L
.36469 .30885 L
.3651 .30885 L
.36552 .30885 L
.36575 .30885 L
.36596 .30885 L
.36605 .30885 L
.36615 .30885 L
.36624 .30885 L
.36634 .30885 L
.36642 .30885 L
.36652 .30885 L
.3666 .30885 L
Mistroke
.36668 .30885 L
.36678 .30885 L
.36688 .30885 L
.36696 .30885 L
.36705 .30885 L
.36726 .30885 L
.36745 .30885 L
.36786 .30885 L
.3683 .30885 L
.36872 .30886 L
.3691 .30886 L
.36983 .30886 L
.37059 .30887 L
.37217 .3089 L
.37364 .30892 L
.37676 .30901 L
.38008 .30913 L
.38327 .30926 L
.38635 .30937 L
.3879 .30942 L
.38873 .30945 L
.38962 .30947 L
.39003 .30947 L
.39047 .30948 L
.39087 .30949 L
.39124 .30949 L
.3916 .30949 L
.39179 .30949 L
.39197 .30949 L
.39208 .30949 L
.39217 .30949 L
.39227 .30949 L
.39233 .30949 L
.39238 .30949 L
.39248 .30949 L
.39258 .30949 L
.39268 .30949 L
.39277 .30949 L
.39287 .30949 L
.39297 .30949 L
.39315 .30949 L
.39335 .30949 L
.39356 .30949 L
.39394 .30948 L
.3943 .30948 L
.39511 .30946 L
.39596 .30944 L
.39754 .30937 L
.39901 .30929 L
.40214 .30905 L
Mistroke
.40546 .30871 L
.40866 .30836 L
.41174 .30806 L
.41333 .30795 L
.41413 .3079 L
.41456 .30788 L
.41501 .30787 L
.4154 .30786 L
.41562 .30785 L
.41582 .30785 L
.41592 .30785 L
.41601 .30785 L
.4161 .30785 L
.41618 .30784 L
.41628 .30784 L
.41637 .30784 L
.41646 .30784 L
.41657 .30784 L
.41662 .30784 L
.41668 .30784 L
.41673 .30784 L
.41679 .30784 L
.41688 .30785 L
.41698 .30785 L
.41722 .30785 L
.41743 .30785 L
.41785 .30786 L
.41824 .30788 L
.41903 .30792 L
.41986 .30798 L
.42134 .30813 L
.42292 .30836 L
.4244 .30862 L
.42753 .30933 L
.43085 .3102 L
.43252 .31062 L
.43406 .31097 L
.43565 .31127 L
.43643 .31138 L
.43714 .31147 L
.43749 .3115 L
.43786 .31153 L
.43807 .31154 L
.43826 .31155 L
.43845 .31156 L
.43864 .31157 L
.43876 .31157 L
.43886 .31157 L
.43896 .31157 L
.43906 .31158 L
Mistroke
.43916 .31158 L
.43925 .31158 L
.43934 .31158 L
.43944 .31157 L
.4395 .31157 L
.43955 .31157 L
.43967 .31157 L
.43978 .31157 L
.43989 .31156 L
.44008 .31156 L
.4403 .31154 L
.44069 .31152 L
.44111 .31148 L
.44185 .31138 L
.44265 .31124 L
.44353 .31104 L
.4451 .31057 L
.44678 .30991 L
.45011 .30824 L
.45332 .30645 L
.45641 .30495 L
.458 .30439 L
.45881 .30419 L
.45926 .3041 L
.45949 .30407 L
.45969 .30404 L
.4599 .30402 L
.46009 .304 L
.4603 .30399 L
.46042 .30398 L
.46047 .30398 L
.46053 .30398 L
.46062 .30398 L
.46073 .30398 L
.46082 .30398 L
.46091 .30398 L
.46101 .30398 L
.46111 .30398 L
.46122 .30399 L
.46132 .30399 L
.4615 .30401 L
.46169 .30403 L
.46203 .30407 L
.4624 .30414 L
.46281 .30423 L
.46362 .30447 L
.46436 .30477 L
.46604 .30569 L
.46756 .30682 L
.46922 .30832 L
Mistroke
.47248 .31175 L
.47562 .31504 L
.47722 .31643 L
.47806 .31702 L
.47895 .31753 L
.47934 .3177 L
.47975 .31785 L
.47999 .31793 L
.4802 .31798 L
.48042 .31803 L
.48063 .31807 L
.48081 .31809 L
.4809 .3181 L
.48101 .31811 L
.48111 .31811 L
.48117 .31812 L
.48122 .31812 L
.48132 .31812 L
.48142 .31812 L
.48151 .31811 L
.4816 .31811 L
.48169 .3181 L
.48178 .31809 L
.48198 .31806 L
.48217 .31803 L
.48254 .31794 L
.48295 .3178 L
.48337 .31761 L
.48377 .31739 L
.48525 .31625 L
.48609 .31538 L
.48688 .3144 L
.48837 .31222 L
.49143 .30668 L
.4947 .30039 L
.49621 .29784 L
.49784 .29563 L
.49873 .29475 L
.49913 .29444 L
.49956 .29417 L
.49975 .29407 L
.49997 .29398 L
.50015 .29392 L
.50035 .29386 L
.50046 .29383 L
.50057 .29382 L
.50067 .2938 L
.50072 .2938 L
.50078 .29379 L
.50088 .29379 L
Mistroke
.50099 .29379 L
.50109 .29379 L
.50118 .2938 L
.50128 .29381 L
.50138 .29382 L
.50156 .29386 L
.50175 .29392 L
.50196 .294 L
.50235 .2942 L
.5027 .29443 L
.5035 .29518 L
.50436 .29627 L
.50593 .29909 L
.5074 .30257 L
.51052 .31189 L
.51383 .32252 L
.51549 .32707 L
.5163 .32892 L
.51703 .33033 L
.51779 .3315 L
.51814 .33192 L
.51851 .33229 L
.5187 .33244 L
.51891 .33258 L
.5191 .33269 L
.51928 .33277 L
.51937 .3328 L
.51948 .33283 L
.51954 .33284 L
.51959 .33285 L
.51965 .33286 L
.5197 .33286 L
.5198 .33287 L
.51989 .33287 L
.51999 .33286 L
.52005 .33285 L
.5201 .33284 L
.5202 .33282 L
.5203 .33279 L
.52048 .33272 L
.52067 .33261 L
.52089 .33247 L
.52127 .33213 L
.52162 .33172 L
.52243 .33044 L
.52328 .32858 L
.52486 .32385 L
.52633 .3181 L
.52945 .30305 L
.53104 .29494 L
Mistroke
.53277 .28673 L
.53429 .2807 L
.53515 .27798 L
.53558 .27686 L
.53597 .27599 L
.53633 .27529 L
.53673 .27467 L
.53713 .27422 L
.53735 .27404 L
.53755 .27392 L
.53766 .27388 L
.53771 .27386 L
.53777 .27384 L
.53782 .27383 L
.53788 .27382 L
.53798 .27381 L
.53808 .27382 L
.53818 .27383 L
.53828 .27386 L
.53837 .27389 L
.53848 .27394 L
.53858 .274 L
.53881 .27418 L
.53902 .2744 L
.53924 .27467 L
.53967 .27538 L
.54007 .27621 L
.54096 .27874 L
.54175 .2817 L
.54258 .28551 L
.54563 .3045 L
.54888 .32881 L
.55038 .3393 L
.552 .34881 L
.55289 .35281 L
.55328 .35426 L
.55371 .35562 L
.55409 .35659 L
.55449 .3574 L
.55472 .35774 L
.55492 .35798 L
.55512 .35815 L
.55522 .35821 L
.55527 .35823 L
.55533 .35825 L
.55538 .35827 L
.55543 .35828 L
.55553 .3583 L
.55559 .35829 L
.55564 .35829 L
Mistroke
.5557 .35828 L
.55575 .35826 L
.55585 .35822 L
.55596 .35816 L
.55606 .35808 L
.55615 .358 L
.55652 .35752 L
.5567 .3572 L
.5569 .35677 L
.55732 .35568 L
.55777 .35418 L
.55859 .35062 L
.55935 .3463 L
.56019 .34058 L
.56188 .32631 L
.56514 .29284 L
.56827 .26236 L
.56909 .25609 L
.56998 .25052 L
.57038 .24845 L
.57082 .24661 L
.57119 .24534 L
.57159 .24428 L
.57179 .2439 L
.5719 .24373 L
.57201 .24358 L
.57212 .24346 L
.57221 .24338 L
.57231 .24332 L
.57241 .24328 L
.5725 .24326 L
.57259 .24326 L
.57267 .24328 L
.57276 .24332 L
.57286 .24338 L
.57296 .24347 L
.57315 .2437 L
.57337 .24406 L
.5736 .24458 L
.57403 .24587 L
.57444 .24753 L
.57483 .24943 L
.5756 .25427 L
.57632 .26 L
.57798 .27691 L
.58108 .31837 L
.58266 .34074 L
.58439 .36305 L
.58518 .37187 L
.58603 .37987 L
Mistroke
.58684 .38586 L
.58757 .38981 L
.58796 .3913 L
.58815 .39188 L
.58837 .39239 L
.58855 .3927 L
.58866 .39283 L
.58875 .39293 L
.58884 .39299 L
.58893 .39302 L
.58902 .39303 L
.58911 .39302 L
.58921 .39297 L
.58927 .39293 L
.58933 .39288 L
.58943 .39276 L
.58953 .39261 L
.58971 .39225 L
.58992 .39174 L
.59036 .39015 L
.59078 .38809 L
.59162 .38228 L
.59241 .37482 L
.5939 .35624 L
.59699 .3045 L
.59854 .27595 L
.60026 .24683 L
.60105 .2353 L
.60189 .22462 L
.60268 .21655 L
.60342 .21095 L
.60379 .20887 L
.60398 .20801 L
.60419 .20724 L
.60431 .20687 L
.60442 .20659 L
.60452 .20636 L
.60463 .20616 L
.60473 .20602 L
.60483 .20593 L
.60492 .20587 L
.60498 .20585 L
.60503 .20585 L
.60514 .20588 L
.60519 .20591 L
.60525 .20596 L
.60535 .20608 L
.60545 .20623 L
.60567 .20671 L
.60579 .20707 L
Mistroke
.6059 .20745 L
.6063 .20924 L
.60673 .21185 L
.60749 .21838 L
.60831 .22786 L
.60978 .25077 L
.61311 .32085 L
.61478 .35817 L
.61632 .38898 L
.61782 .41247 L
.61857 .42107 L
.619 .42485 L
.6194 .42761 L
.6196 .42866 L
.6198 .42958 L
.61992 .43002 L
.62003 .43035 L
.62014 .43063 L
.62024 .43084 L
.62033 .43099 L
.62043 .4311 L
.62053 .43115 L
.62059 .43116 L
.62065 .43115 L
.62074 .4311 L
.62083 .43101 L
.62093 .43086 L
.62103 .43067 L
.62121 .43018 L
.6214 .42949 L
.62174 .42777 L
.62211 .42525 L
.62252 .42169 L
.62333 .41215 L
.62407 .40074 L
.62575 .36695 L
.62893 .28435 L
.63053 .24248 L
.63199 .20966 L
.63275 .19571 L
.63356 .18358 L
.63401 .17839 L
.63443 .17459 L
.63483 .17188 L
.63503 .17086 L
.63514 .17039 L
.63525 .17002 L
.63535 .16972 L
.63545 .16951 L
.63555 .16933 L
Mistroke
.63561 .16927 L
.63567 .16922 L
.63577 .16919 L
.63586 .16922 L
.63596 .1693 L
.63606 .16946 L
.63615 .16965 L
.63625 .1699 L
.63642 .1705 L
.63662 .17145 L
.63681 .17254 L
.63722 .17571 L
.63767 .18032 L
.63849 .19169 L
.63924 .2055 L
.64008 .22398 L
.64177 .26956 L
.645 .3689 L
.64649 .40958 L
.64727 .4276 L
.64811 .44334 L
.64857 .45027 L
.64899 .4554 L
.64941 .45941 L
.6496 .46082 L
.64981 .46209 L
.65 .46302 L
.65011 .46341 L
.65021 .4637 L
.6503 .46391 L
.65039 .46405 L
.65049 .46414 L
.65058 .46417 L
.65068 .46412 L
.65073 .46407 L
.65079 .464 L
.65089 .46381 L
.65098 .46356 L
.65119 .46279 L
.65131 .46221 L
.65142 .4616 L
.6518 .45878 L
.6522 .45465 L
.65294 .44435 L
.65381 .42762 L
.6546 .4086 L
.65781 .30643 L
.66089 .20497 L
.66172 .18349 L
.66249 .16688 L
Mistroke
.66329 .15372 L
.66372 .14863 L
.66394 .14652 L
.66418 .1447 L
.6644 .14338 L
.6646 .14253 L
.6647 .14223 L
.6648 .14199 L
.6649 .14185 L
.66499 .14178 L
.66504 .14178 L
.6651 .14179 L
.6652 .14189 L
.66526 .14198 L
.66531 .1421 L
.66542 .14239 L
.66553 .1428 L
.66564 .14327 L
.66588 .14465 L
.66625 .14774 L
.66666 .15241 L
.66749 .16579 L
.6683 .18361 L
.66905 .2036 L
.67072 .25863 L
.6739 .37742 L
.67551 .4292 L
.67621 .44751 L
.67697 .46361 L
.67739 .47072 L
.67778 .47602 L
.67815 .47991 L
.67834 .48143 L
.67854 .48274 L
.67866 .48331 L
.67876 .48374 L
.67886 .48405 L
.67896 .48429 L
.67902 .48437 L
.67908 .48444 L
.67914 .48447 L
.6792 .48447 L
.6793 .4844 L
.67936 .48432 L
.67941 .48422 L
.67951 .48397 L
.6796 .48366 L
.67981 .48268 L
.68001 .48137 L
.68023 .47957 L
Mistroke
.68065 .47483 L
.68105 .46908 L
.68194 .45149 L
.68272 .43112 L
.68355 .40528 L
.68659 .28901 L
.68828 .22404 L
.68983 .17489 L
.69059 .15629 L
.69099 .14828 L
.69142 .14123 L
.69183 .13597 L
.69221 .13254 L
.69239 .13134 L
.69248 .13083 L
.69258 .13038 L
.69267 .13007 L
.69277 .1298 L
.69286 .12964 L
.69294 .12956 L
.69304 .12954 L
.69309 .12957 L
.69315 .12962 L
.69325 .1298 L
.69334 .13005 L
.69345 .13045 L
.69355 .13092 L
.69378 .13232 L
.69396 .13382 L
.69417 .13581 L
.69457 .14098 L
.69534 .15475 L
.69606 .17195 L
.69771 .22457 L
.6992 .28314 L
.70087 .35213 L
.70241 .41039 L
.70391 .45491 L
.70466 .47094 L
.70509 .47783 L
.7053 .48057 L
.7055 .48275 L
.70571 .48471 L
.7059 .48613 L
.70611 .48729 L
.70622 .48774 L
.70627 .4879 L
.70633 .48804 L
.70643 .48822 L
.70653 .4883 L
Mistroke
.70662 .48829 L
.70671 .4882 L
.70682 .48799 L
.70691 .48771 L
.70702 .48728 L
.70712 .48677 L
.7073 .48562 L
.7075 .48406 L
.70784 .4804 L
.70821 .47522 L
.70861 .46808 L
.70943 .44956 L
.71017 .42812 L
.71185 .3678 L
.71503 .23756 L
.71586 .20759 L
.71664 .18293 L
.7174 .1631 L
.71809 .14906 L
.71846 .14341 L
.71885 .13884 L
.71905 .13704 L
.71924 .13573 L
.71935 .13514 L
.71945 .13468 L
.71951 .13448 L
.71957 .13429 L
.71967 .13404 L
.71978 .13391 L
.71987 .13388 L
.71993 .13391 L
.71998 .13396 L
.72004 .13404 L
.7201 .13417 L
.72021 .1345 L
.72031 .13492 L
.72055 .13626 L
.72075 .13788 L
.72094 .1397 L
.72136 .14499 L
.72174 .15137 L
.72216 .1596 L
.72289 .17788 L
.72456 .23293 L
.7276 .35538 L
.72929 .41619 L
.73009 .43918 L
.73084 .45607 L
.73124 .46319 L
.7316 .46837 L
Mistroke
.73201 .47267 L
.73223 .47436 L
.73233 .47496 L
.73244 .47551 L
.73252 .47587 L
.73262 .47617 L
.73272 .47639 L
.73282 .47651 L
.73291 .47653 L
.733 .47648 L
.73308 .47636 L
.73316 .47617 L
.73326 .47587 L
.73336 .47543 L
.73357 .47424 L
.73377 .47274 L
.73395 .471 L
.73433 .46641 L
.73474 .4599 L
.73557 .4423 L
.73706 .39819 L
.74032 .27304 L
.74182 .21918 L
.74262 .19559 L
.74346 .17553 L
.74388 .16753 L
.74435 .16058 L
.74455 .15816 L
.74477 .156 L
.74498 .15438 L
.74517 .15326 L
.74527 .1528 L
.74538 .15243 L
.74548 .15217 L
.74557 .15202 L
.74562 .15197 L
.74568 .15195 L
.74573 .15196 L
.74579 .152 L
.74589 .15214 L
.74595 .15226 L
.746 .15241 L
.7461 .15276 L
.7462 .15319 L
.74638 .15423 L
.74658 .15569 L
.74679 .15768 L
.74718 .16244 L
.74755 .16812 L
.74838 .18522 L
Mistroke
.74919 .20682 L
.75007 .23444 L
.75338 .35546 L
.75418 .3824 L
.75503 .40758 L
.75577 .42557 L
.75656 .44036 L
.757 .44615 L
.75719 .44817 L
.75739 .45003 L
.75759 .45142 L
.75777 .45241 L
.75787 .45282 L
.75797 .45312 L
.75802 .45324 L
.75807 .45336 L
.75817 .45349 L
.75826 .45354 L
.75835 .45351 L
.75844 .4534 L
.75854 .4532 L
.75864 .45291 L
.75874 .4525 L
.75893 .45154 L
.7591 .45036 L
.75926 .44902 L
.75963 .44515 L
.76004 .43954 L
.76047 .43195 L
.76127 .41453 L
.76276 .37174 L
.76433 .3186 L
.76605 .26018 L
.76684 .23638 L
.76768 .21439 L
.76848 .1979 L
.76886 .19165 L
.76921 .187 L
.7696 .183 L
.76981 .18132 L
.77 .18009 L
.77009 .17964 L
.77019 .17925 L
.77027 .17896 L
.77036 .17873 L
.77045 .17854 L
.77054 .17844 L
.77064 .17841 L
.77074 .17845 L
.77084 .1786 L
Mistroke
.77089 .1787 L
.77095 .17884 L
.77105 .17917 L
.77115 .17955 L
.77136 .18069 L
.77159 .18234 L
.77202 .18649 L
.7724 .19153 L
.77319 .2052 L
.77392 .22155 L
.77559 .26816 L
.77873 .36454 L
.77955 .38543 L
.78044 .40376 L
.78085 .41043 L
.78128 .41619 L
.78165 .42 L
.78187 .4217 L
.78206 .42297 L
.78226 .42397 L
.78237 .42437 L
.78248 .42469 L
.78258 .42489 L
.78267 .42501 L
.78277 .42507 L
.78283 .42506 L
.78288 .42504 L
.78297 .42495 L
.78305 .4248 L
.78314 .42458 L
.78324 .42427 L
.78344 .42341 L
.78362 .42235 L
.78404 .41903 L
.78449 .41402 L
.7853 .40144 L
.78606 .38618 L
.7869 .3662 L
.78858 .31974 L
.79027 .27283 L
.79182 .23726 L
.79258 .22412 L
.79299 .21862 L
.79342 .21393 L
.79363 .21208 L
.79383 .21062 L
.79402 .20947 L
.7942 .20865 L
.79437 .20808 L
.79446 .20787 L
Mistroke
.79455 .2077 L
.79465 .2076 L
.79475 .20756 L
.79485 .20759 L
.79493 .20767 L
.79503 .20782 L
.79512 .20802 L
.79521 .2083 L
.79532 .20868 L
.79553 .20969 L
.79573 .21088 L
.79609 .21374 L
.79647 .21766 L
.79726 .22871 L
.79813 .2446 L
.80139 .32247 L
.80289 .35664 L
.80369 .37141 L
.80453 .3837 L
.80495 .38843 L
.80518 .39051 L
.80542 .3924 L
.80564 .39381 L
.80584 .39483 L
.80594 .39523 L
.80605 .39559 L
.80614 .39586 L
.80624 .39608 L
.8063 .39618 L
.80635 .39625 L
.80645 .39634 L
.80655 .39636 L
.80665 .39632 L
.8067 .39628 L
.80675 .39621 L
.80685 .39604 L
.80697 .39577 L
.80708 .39544 L
.80727 .39467 L
.80748 .39359 L
.80786 .39097 L
.80825 .3874 L
.80861 .3833 L
.80945 .3715 L
.81114 .33972 L
.81425 .27428 L
.81506 .26033 L
.81549 .25399 L
.81594 .24813 L
.81638 .24345 L
Mistroke
.81678 .24006 L
.81697 .23872 L
.81718 .2375 L
.81738 .23656 L
.81756 .23589 L
.81765 .23561 L
.81775 .23537 L
.81785 .23517 L
.81795 .23503 L
.81804 .23496 L
.81814 .23493 L
.81823 .23495 L
.81832 .23502 L
.81837 .23507 L
.81843 .23515 L
.81853 .23533 L
.81863 .23559 L
.81875 .23594 L
.81896 .23675 L
.81916 .23772 L
.81958 .24051 L
.81997 .24383 L
.82085 .25374 L
.82238 .27768 L
.82405 .30836 L
.82562 .33597 L
.82645 .34841 L
.8269 .3543 L
.82734 .35916 L
.82775 .36301 L
.82819 .36639 L
.82839 .36759 L
.8286 .36867 L
.82879 .36949 L
.82897 .37009 L
.82907 .37035 L
.82917 .37058 L
.82927 .37076 L
.82933 .37083 L
.82938 .37089 L
.82948 .37096 L
.82957 .37098 L
.82967 .37096 L
.82977 .37089 L
.82986 .37079 L
.82995 .37065 L
.83012 .37029 L
.8303 .36976 L
.8305 .369 L
.83089 .36697 L
Mistroke
.83131 .36411 L
.83205 .35732 L
.83373 .3358 L
.83679 .28905 L
.8376 .27849 L
.83837 .2702 L
.83879 .26644 L
.83925 .26309 L
.83967 .26075 L
.83987 .25987 L
.84005 .2592 L
.84024 .25865 L
.84043 .25826 L
.84053 .25811 L
.84062 .258 L
.84072 .25793 L
.84077 .2579 L
.84083 .25789 L
.84092 .2579 L
.84101 .25794 L
.8411 .25801 L
.8412 .25813 L
.84129 .25827 L
.84137 .25843 L
.84156 .25888 L
.84177 .25957 L
.84198 .26038 L
.84236 .26231 L
.84322 .26846 L
.84399 .27591 L
.84482 .28529 L
.8463 .30423 L
.84789 .32425 L
.84934 .33909 L
.84972 .34213 L
.85014 .34495 L
.85053 .34714 L
.85089 .34868 L
.85111 .34939 L
.85132 .34992 L
.85142 .35014 L
.85153 .35033 L
.85159 .35041 L
.85165 .35048 L
.85171 .35054 L
.85176 .35059 L
.85187 .35064 L
.85197 .35066 L
.85207 .35065 L
.85213 .35062 L
Mistroke
.85218 .35059 L
.85227 .35051 L
.85237 .3504 L
.85247 .35025 L
.85257 .35007 L
.85295 .34909 L
.85316 .34834 L
.85336 .34751 L
.85419 .34284 L
.85491 .3374 L
.85568 .33045 L
.85728 .31381 L
.85901 .29592 L
.85982 .28879 L
.86068 .28266 L
.86141 .27882 L
.86161 .27802 L
.86183 .27728 L
.86203 .27669 L
.86222 .27626 L
.86242 .2759 L
.86253 .27576 L
.86264 .27565 L
.86274 .27558 L
.86283 .27554 L
.86293 .27552 L
.86303 .27553 L
.86314 .27557 L
.8632 .2756 L
.86325 .27564 L
.86336 .27575 L
.86345 .27587 L
.86368 .27625 L
.86392 .27681 L
.86432 .27809 L
.86476 .27988 L
.86553 .28414 L
.8671 .29578 L
.86857 .30845 L
.87005 .32061 L
.87089 .32637 L
.87168 .33063 L
.87208 .33235 L
.87246 .33365 L
.87267 .33423 L
.87289 .33475 L
.8731 .33512 L
.87329 .33537 L
.87339 .33547 L
.87349 .33555 L
Mistroke
.87359 .33561 L
.87368 .33564 L
.87379 .33565 L
.87385 .33564 L
.8739 .33563 L
.874 .33559 L
.87406 .33556 L
.87411 .33552 L
.87422 .33542 L
.87433 .3353 L
.87456 .33496 L
.87477 .33455 L
.87498 .33403 L
.87575 .33145 L
.87657 .32756 L
.87804 .31846 L
.87964 .30739 L
.88048 .30186 L
.88137 .29669 L
.88216 .29295 L
.88258 .29136 L
.88304 .28999 L
.88325 .28947 L
.88345 .28905 L
.88365 .28871 L
.88383 .28847 L
.884 .28829 L
.8841 .28822 L
.88419 .28816 L
.88428 .28812 L
.88439 .2881 L
.88449 .28809 L
.88458 .2881 L
.88468 .28813 L
.88477 .28818 L
.88486 .28823 L
.88495 .2883 L
.88516 .28853 L
.88536 .2888 L
.88571 .28947 L
.88609 .2904 L
.88688 .29303 L
.88775 .29681 L
.88943 .30569 L
.89098 .314 L
.89249 .32061 L
.89325 .32296 L
.89368 .32395 L
.89408 .32462 L
.8943 .32488 L
Mistroke
.89449 .32507 L
.89459 .32514 L
.8947 .3252 L
.89476 .32523 L
.89482 .32525 L
.89488 .32526 L
.89493 .32527 L
.89503 .32528 L
.89513 .32527 L
.89523 .32525 L
.89529 .32523 L
.89534 .32521 L
.89544 .32516 L
.89554 .32509 L
.89573 .32493 L
.89591 .32472 L
.89611 .32445 L
.89651 .32374 L
.89722 .322 L
.89804 .31934 L
.89879 .31647 L
.90047 .3093 L
.90214 .30268 L
.90287 .30035 L
.90326 .29931 L
.90368 .29836 L
.90408 .29762 L
.90445 .29711 L
.90463 .29692 L
.90482 .29675 L
.90491 .29669 L
.905 .29663 L
.90508 .29659 L
.90517 .29656 L
.90522 .29654 L
.90528 .29653 L
.90538 .29651 L
.90543 .29651 L
.90549 .29651 L
.90555 .29652 L
.9056 .29652 L
.9057 .29654 L
.90576 .29656 L
.90581 .29658 L
.906 .29668 L
.90618 .2968 L
.90637 .29698 L
.90676 .29745 L
.90715 .29809 L
.90757 .29891 L
Mistroke
.90831 .30072 L
.90999 .3059 L
.91159 .31119 L
.91304 .31523 L
.91343 .31608 L
.91385 .31688 L
.91422 .31744 L
.91462 .31793 L
.91484 .31814 L
.91504 .31829 L
.91526 .31842 L
.91538 .31847 L
.91543 .31848 L
.91549 .3185 L
.91559 .31852 L
.91569 .31853 L
.91575 .31853 L
.9158 .31853 L
.91591 .31853 L
.916 .31851 L
.91609 .31849 L
.91619 .31845 L
.9163 .31841 L
.9165 .3183 L
.9167 .31816 L
.91706 .31781 L
.91745 .31732 L
.91788 .31667 L
.91935 .31362 L
.92091 .30969 L
.92174 .30761 L
.92263 .30558 L
.92348 .30397 L
.92385 .30339 L
.92426 .30286 L
.92462 .30248 L
.925 .30217 L
.92521 .30204 L
.92541 .30195 L
.9255 .30192 L
.9256 .30189 L
.9257 .30187 L
.92578 .30186 L
.92588 .30185 L
.92598 .30184 L
.92607 .30185 L
.92616 .30186 L
.92626 .30188 L
.92637 .3019 L
.92656 .30197 L
Mistroke
.92674 .30205 L
.92691 .30215 L
.92729 .30244 L
.92771 .30285 L
.92809 .30331 L
.92895 .30459 L
.93059 .30762 L
.93213 .31054 L
.93289 .3118 L
.9336 .31281 L
.934 .31327 L
.93443 .31368 L
.93482 .31398 L
.93518 .31418 L
.93538 .31425 L
.93556 .31431 L
.93566 .31433 L
.93571 .31434 L
.93576 .31435 L
.93586 .31436 L
.93596 .31437 L
.93605 .31437 L
.93616 .31437 L
.93625 .31436 L
.93634 .31435 L
.93642 .31433 L
.93651 .31431 L
.93669 .31426 L
.9369 .31417 L
.9371 .31408 L
.93754 .31379 L
.93834 .31308 L
.93987 .31114 L
.94154 .30872 L
.9431 .30672 L
.94352 .30628 L
.94398 .30588 L
.94438 .30559 L
.94459 .30546 L
.94482 .30534 L
.94503 .30525 L
.94523 .30518 L
.94543 .30512 L
.94552 .3051 L
.94562 .30509 L
.94572 .30507 L
.94578 .30507 L
.94583 .30506 L
.94592 .30506 L
.94602 .30506 L
Mistroke
.94608 .30506 L
.94614 .30506 L
.9462 .30507 L
.94625 .30507 L
.94635 .30508 L
.94646 .3051 L
.94666 .30514 L
.94687 .30521 L
.94725 .30536 L
.94763 .30556 L
.94797 .30578 L
.94948 .30711 L
.95114 .3089 L
.95202 .30981 L
.95285 .31058 L
.95365 .31118 L
.954 .3114 L
.95439 .31159 L
.95477 .31174 L
.95495 .31179 L
.95512 .31184 L
.95532 .31187 L
.9554 .31189 L
.95549 .3119 L
.95559 .31191 L
.95568 .31191 L
.95574 .31192 L
.95579 .31192 L
.95589 .31192 L
.95599 .31192 L
.95609 .31191 L
.95614 .31191 L
.9562 .3119 L
.9563 .31189 L
.9565 .31186 L
.95668 .31182 L
.95711 .31169 L
.95752 .31152 L
.9583 .31111 L
.95912 .31055 L
.9606 .30939 L
.96218 .30818 L
.96287 .30774 L
.96326 .30753 L
.96363 .30735 L
.96402 .30719 L
.96438 .30708 L
.96477 .30699 L
.96498 .30695 L
.96518 .30693 L
Mistroke
.96527 .30692 L
.96538 .30692 L
.96543 .30691 L
.96549 .30691 L
.9656 .30691 L
.9657 .30691 L
.9658 .30691 L
.96588 .30692 L
.96598 .30692 L
.9661 .30694 L
.9662 .30695 L
.96643 .30698 L
.96665 .30703 L
.96685 .30707 L
.96764 .30733 L
.96847 .30771 L
.96995 .30853 L
.97154 .30945 L
.97224 .3098 L
.973 .31011 L
.97341 .31025 L
.97379 .31036 L
.97415 .31043 L
.97436 .31047 L
.97454 .31049 L
.97473 .31051 L
.97484 .31052 L
.97494 .31053 L
.97504 .31053 L
.97513 .31053 L
.97522 .31054 L
.97532 .31054 L
.97538 .31053 L
.97544 .31053 L
.9755 .31053 L
.97556 .31053 L
.97566 .31052 L
.97578 .31051 L
.97599 .31049 L
.97619 .31047 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{421.375, 260.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 525.688}, {324.5, 0}} -> {-2.58312*^-7, -6.34248*^6, \
6.65005*^-9, 53093.5}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0.309017 5.42214e-08 [
[.32684 .29652 -16.5 -12.5 ]
[.32684 .29652 16.5 0 ]
[.54329 .29652 -16.5 -12.5 ]
[.54329 .29652 16.5 0 ]
[.75974 .29652 -22.5 -12.5 ]
[.75974 .29652 22.5 0 ]
[.97619 .29652 -16.5 -12.5 ]
[.97619 .29652 16.5 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 64 6 ]
[.09789 .09213 -34.5 -6.25 ]
[.09789 .09213 0 6.25 ]
[.09789 .20057 -34.5 -6.25 ]
[.09789 .20057 0 6.25 ]
[.09789 .41746 -28.5 -6.25 ]
[.09789 .41746 0 6.25 ]
[.09789 .5259 -28.5 -6.25 ]
[.09789 .5259 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -62.8125 0 ]
[.5 .63053 62.8125 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 .30902 m
.32684 .31527 L
s
gsave
.32684 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 .30902 m
.54329 .31527 L
s
gsave
.54329 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 .30902 m
.75974 .31527 L
s
gsave
.75974 .29652 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 .30902 m
.15368 .31277 L
s
.19697 .30902 m
.19697 .31277 L
s
.24026 .30902 m
.24026 .31277 L
s
.28355 .30902 m
.28355 .31277 L
s
.37013 .30902 m
.37013 .31277 L
s
.41342 .30902 m
.41342 .31277 L
s
.45671 .30902 m
.45671 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.58658 .30902 m
.58658 .31277 L
s
.62987 .30902 m
.62987 .31277 L
s
.67316 .30902 m
.67316 .31277 L
s
.71645 .30902 m
.71645 .31277 L
s
.80303 .30902 m
.80303 .31277 L
s
.84632 .30902 m
.84632 .31277 L
s
.88961 .30902 m
.88961 .31277 L
s
.9329 .30902 m
.9329 .31277 L
s
.0671 .30902 m
.0671 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09213 m
.11664 .09213 L
s
gsave
.09789 .09213 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .20057 m
.11664 .20057 L
s
gsave
.09789 .20057 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .41746 m
.11664 .41746 L
s
gsave
.09789 .41746 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .5259 m
.11664 .5259 L
s
gsave
.09789 .5259 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.11039 .11924 m
.11414 .11924 L
s
.11039 .14635 m
.11414 .14635 L
s
.11039 .17346 m
.11414 .17346 L
s
.11039 .22768 m
.11414 .22768 L
s
.11039 .2548 m
.11414 .2548 L
s
.11039 .28191 m
.11414 .28191 L
s
.11039 .33613 m
.11414 .33613 L
s
.11039 .36324 m
.11414 .36324 L
s
.11039 .39035 m
.11414 .39035 L
s
.11039 .44457 m
.11414 .44457 L
s
.11039 .47168 m
.11414 .47168 L
s
.11039 .49879 m
.11414 .49879 L
s
.11039 .06502 m
.11414 .06502 L
s
.11039 .03791 m
.11414 .03791 L
s
.11039 .0108 m
.11414 .0108 L
s
.11039 .55301 m
.11414 .55301 L
s
.11039 .58012 m
.11414 .58012 L
s
.11039 .60723 m
.11414 .60723 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -123.812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.812 moveto
(@) show
81.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.812 moveto
(D) show
93.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12.) show
135.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
141.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
153.000 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
157.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
166.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
184.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02691 .30902 L
.03029 .30902 L
.03347 .30902 L
.03652 .30902 L
.03978 .30902 L
.04291 .30902 L
.04623 .30902 L
.04944 .30902 L
.05252 .30902 L
.0558 .30902 L
.05896 .30902 L
.062 .30902 L
.06523 .30902 L
.06834 .30902 L
.07165 .30902 L
.07484 .30902 L
.0779 .30902 L
.08117 .30902 L
.08431 .30902 L
.08765 .30902 L
.09086 .30902 L
.09396 .30902 L
.09725 .30902 L
.10042 .30902 L
.10346 .30902 L
.10671 .30902 L
.10983 .30902 L
.11065 .30902 L
.11154 .30902 L
.1123 .30902 L
.11271 .30902 L
.11315 .30902 L
.11336 .30902 L
.11358 .30902 L
.11378 .30902 L
.11397 .30902 L
.11415 .30902 L
.11425 .30902 L
.11434 .30902 L
.11444 .30902 L
.11449 .30902 L
.11454 .30902 L
.11464 .30902 L
.11474 .30902 L
.11484 .30902 L
.11494 .30902 L
.11505 .30902 L
.11515 .30902 L
.11534 .30902 L
Mistroke
.11554 .30902 L
.11576 .30902 L
.116 .30902 L
.11643 .30902 L
.11686 .30902 L
.11725 .30902 L
.11815 .30902 L
.11894 .30902 L
.11977 .30902 L
.12135 .30902 L
.12282 .30902 L
.12446 .30902 L
.12595 .30902 L
.12748 .30902 L
.12915 .30902 L
.13071 .30902 L
.13243 .30902 L
.13558 .30902 L
.13714 .30902 L
.13881 .30902 L
.14212 .30902 L
.14531 .30902 L
.14837 .30902 L
.15163 .30902 L
.15477 .30902 L
.1581 .30902 L
.16131 .30902 L
.16441 .30902 L
.1677 .30902 L
.17086 .30902 L
.17391 .30902 L
.17715 .30902 L
.18027 .30902 L
.18186 .30902 L
.1827 .30902 L
.18359 .30902 L
.18438 .30902 L
.18483 .30902 L
.18503 .30902 L
.18525 .30902 L
.18543 .30902 L
.18553 .30902 L
.18563 .30902 L
.18573 .30902 L
.18582 .30902 L
.1859 .30902 L
.18599 .30902 L
.18608 .30902 L
.18618 .30902 L
.18627 .30902 L
Mistroke
.18637 .30902 L
.18647 .30902 L
.18658 .30902 L
.18678 .30902 L
.18699 .30902 L
.1872 .30902 L
.1876 .30902 L
.18806 .30902 L
.18848 .30902 L
.18931 .30902 L
.19009 .30902 L
.19088 .30902 L
.19171 .30902 L
.19319 .30902 L
.19477 .30902 L
.19624 .30902 L
.19936 .30902 L
.20107 .30902 L
.20269 .30902 L
.20576 .30902 L
.20904 .30902 L
.21219 .30902 L
.21522 .30902 L
.21845 .30902 L
.22156 .30902 L
.22486 .30902 L
.22805 .30902 L
.22965 .30902 L
.23111 .30902 L
.23186 .30902 L
.23268 .30902 L
.23313 .30902 L
.23355 .30902 L
.23394 .30902 L
.23416 .30902 L
.23436 .30902 L
.23455 .30902 L
.23465 .30902 L
.23476 .30902 L
.23486 .30902 L
.23495 .30902 L
.23504 .30902 L
.23512 .30902 L
.23522 .30902 L
.23533 .30902 L
.23542 .30902 L
.23551 .30902 L
.23562 .30902 L
.23573 .30902 L
.23594 .30902 L
Mistroke
.23613 .30902 L
.23633 .30902 L
.23671 .30902 L
.23707 .30902 L
.23741 .30902 L
.23818 .30902 L
.23891 .30902 L
.23971 .30902 L
.24056 .30902 L
.24226 .30902 L
.24387 .30902 L
.24546 .30902 L
.24694 .30902 L
.25008 .30902 L
.25341 .30902 L
.25663 .30902 L
.25972 .30902 L
.26301 .30902 L
.26618 .30902 L
.26923 .30902 L
.27092 .30902 L
.27247 .30902 L
.27324 .30902 L
.27367 .30902 L
.27407 .30902 L
.27442 .30902 L
.27452 .30902 L
.27462 .30902 L
.27472 .30902 L
.27481 .30902 L
.27491 .30902 L
.27501 .30902 L
.27511 .30902 L
.27517 .30902 L
.27522 .30902 L
.27531 .30902 L
.27541 .30902 L
.27551 .30902 L
.27559 .30902 L
.27579 .30902 L
.27597 .30902 L
.27617 .30902 L
.27637 .30902 L
.27672 .30902 L
.2771 .30902 L
.27796 .30902 L
.27875 .30902 L
.2796 .30902 L
.2804 .30902 L
.2819 .30902 L
Mistroke
.28351 .30902 L
.285 .30902 L
.28817 .30902 L
.29122 .30902 L
.29447 .30901 L
.29759 .30901 L
.30092 .30901 L
.30258 .30901 L
.30412 .30901 L
.30571 .30901 L
.3072 .30901 L
.30792 .30901 L
.30833 .30901 L
.3087 .30901 L
.3089 .30901 L
.30908 .30901 L
.30929 .30901 L
.3094 .30901 L
.30951 .30901 L
.30956 .30901 L
.30962 .30901 L
.30972 .30901 L
.30977 .30901 L
.30982 .30901 L
.30988 .30901 L
.30994 .30901 L
.31 .30901 L
.31005 .30901 L
.31016 .30901 L
.31035 .30901 L
.31054 .30901 L
.31074 .30901 L
.31111 .30901 L
.31154 .30901 L
.31194 .30901 L
.31276 .30901 L
.31362 .30901 L
.31521 .30901 L
.31668 .30901 L
.31832 .30901 L
.31981 .30901 L
.32302 .30902 L
.3261 .30903 L
.32938 .30904 L
.33254 .30905 L
.33558 .30905 L
.33714 .30906 L
.33801 .30906 L
.3384 .30906 L
.33881 .30906 L
Mistroke
.33923 .30906 L
.3396 .30906 L
.33978 .30906 L
.33998 .30906 L
.34007 .30906 L
.34017 .30906 L
.34025 .30906 L
.34034 .30906 L
.34044 .30906 L
.34053 .30906 L
.34064 .30906 L
.34069 .30906 L
.34075 .30906 L
.34083 .30906 L
.34093 .30906 L
.34103 .30906 L
.34113 .30906 L
.34135 .30906 L
.34155 .30906 L
.342 .30906 L
.34238 .30906 L
.34279 .30906 L
.34352 .30906 L
.34439 .30906 L
.34518 .30905 L
.34672 .30905 L
.34839 .30904 L
.35168 .30902 L
.35484 .30899 L
.35788 .30895 L
.36112 .30892 L
.36424 .30889 L
.36505 .30888 L
.36594 .30888 L
.36634 .30888 L
.36677 .30887 L
.36715 .30887 L
.36755 .30887 L
.36776 .30887 L
.36798 .30887 L
.36819 .30887 L
.36828 .30887 L
.36838 .30887 L
.36844 .30887 L
.36849 .30887 L
.36855 .30887 L
.3686 .30887 L
.3687 .30887 L
.36881 .30887 L
.36887 .30887 L
Mistroke
.36892 .30887 L
.36899 .30887 L
.36905 .30887 L
.36916 .30887 L
.36927 .30887 L
.36949 .30887 L
.36968 .30887 L
.37011 .30887 L
.37051 .30887 L
.37089 .30887 L
.37168 .30888 L
.3725 .30889 L
.37398 .3089 L
.37556 .30893 L
.37703 .30896 L
.38015 .30904 L
.38347 .30915 L
.38667 .30927 L
.38974 .30936 L
.39133 .3094 L
.39213 .30942 L
.39256 .30942 L
.39301 .30943 L
.3934 .30943 L
.3936 .30944 L
.39382 .30944 L
.39402 .30944 L
.39421 .30944 L
.39429 .30944 L
.39439 .30944 L
.39447 .30944 L
.39456 .30944 L
.39467 .30944 L
.39476 .30944 L
.39482 .30944 L
.39488 .30944 L
.39499 .30944 L
.39504 .30944 L
.3951 .30944 L
.3952 .30944 L
.39532 .30944 L
.39543 .30944 L
.39563 .30944 L
.39585 .30944 L
.39624 .30943 L
.39663 .30943 L
.397 .30942 L
.39784 .30941 L
.39866 .30938 L
.39953 .30935 L
Mistroke
.40124 .30927 L
.40285 .30918 L
.40593 .30894 L
.40921 .30863 L
.41236 .30833 L
.41394 .3082 L
.41539 .3081 L
.41614 .30805 L
.41695 .30802 L
.41734 .308 L
.41776 .30799 L
.418 .30798 L
.41821 .30798 L
.41841 .30798 L
.41851 .30797 L
.41862 .30797 L
.41873 .30797 L
.41882 .30797 L
.41892 .30797 L
.41901 .30797 L
.41912 .30797 L
.41921 .30797 L
.41931 .30797 L
.41937 .30797 L
.41943 .30797 L
.41952 .30797 L
.41961 .30797 L
.41981 .30797 L
.41998 .30798 L
.42016 .30798 L
.42058 .30799 L
.42096 .308 L
.42183 .30804 L
.42268 .3081 L
.42347 .30817 L
.42496 .30833 L
.42657 .30857 L
.42805 .30883 L
.43121 .3095 L
.43424 .3102 L
.43593 .31057 L
.43748 .31087 L
.43824 .31099 L
.43907 .31111 L
.43986 .3112 L
.44059 .31126 L
.44099 .31128 L
.44122 .31129 L
.44143 .3113 L
.44162 .3113 L
Mistroke
.44173 .31131 L
.44182 .31131 L
.44193 .31131 L
.44202 .31131 L
.44207 .31131 L
.44213 .31131 L
.44223 .31131 L
.44233 .31131 L
.44241 .31131 L
.44251 .3113 L
.44261 .3113 L
.44282 .3113 L
.44301 .31129 L
.44336 .31127 L
.44373 .31124 L
.44449 .31117 L
.44531 .31105 L
.44608 .31091 L
.44679 .31075 L
.44833 .31031 L
.44999 .30971 L
.45328 .30823 L
.45644 .30666 L
.45948 .30534 L
.46104 .30486 L
.46149 .30475 L
.46192 .30467 L
.46234 .3046 L
.46272 .30455 L
.46291 .30453 L
.46312 .30451 L
.46331 .3045 L
.4634 .30449 L
.46349 .30449 L
.46359 .30449 L
.46368 .30448 L
.46374 .30448 L
.46379 .30448 L
.46389 .30448 L
.464 .30448 L
.46409 .30449 L
.46414 .30449 L
.4642 .30449 L
.46431 .30449 L
.4645 .3045 L
.46468 .30452 L
.46507 .30456 L
.46542 .30461 L
.46579 .30468 L
.46656 .30488 L
Mistroke
.46738 .30516 L
.46885 .30585 L
.47057 .30695 L
.47219 .30823 L
.47528 .31111 L
.47857 .31423 L
.4802 .31554 L
.481 .31608 L
.48173 .31649 L
.48249 .31683 L
.48283 .31695 L
.4832 .31706 L
.48339 .31711 L
.48359 .31715 L
.48378 .31718 L
.48396 .31721 L
.48405 .31722 L
.48416 .31723 L
.48427 .31723 L
.48433 .31724 L
.48438 .31724 L
.48448 .31724 L
.48457 .31724 L
.48468 .31724 L
.48478 .31724 L
.48487 .31723 L
.48497 .31723 L
.48515 .31721 L
.48536 .31718 L
.48556 .31714 L
.48598 .31704 L
.48638 .3169 L
.48709 .31657 L
.48786 .31609 L
.48944 .31471 L
.49113 .31269 L
.49446 .30743 L
.49768 .30182 L
.49916 .29949 L
.5 .29832 L
.50078 .29736 L
.50162 .2965 L
.50238 .29588 L
.5028 .29562 L
.5032 .29543 L
.5034 .29535 L
.50361 .29528 L
.50373 .29525 L
.50385 .29523 L
.50396 .29521 L
Mistroke
.50407 .29519 L
.50416 .29518 L
.50426 .29518 L
.50431 .29518 L
.50437 .29518 L
.50447 .29518 L
.50457 .29518 L
.50466 .29519 L
.50477 .2952 L
.50488 .29522 L
.50506 .29526 L
.50523 .29531 L
.50562 .29547 L
.50605 .2957 L
.50643 .29597 L
.5073 .2968 L
.50809 .29781 L
.50883 .29896 L
.51049 .30225 L
.51364 .31051 L
.51698 .32028 L
.51866 .32463 L
.5194 .32628 L
.5202 .32783 L
.52093 .32899 L
.52171 .32994 L
.52214 .33032 L
.52253 .33057 L
.52272 .33066 L
.52282 .3307 L
.52293 .33074 L
.52302 .33076 L
.52312 .33078 L
.52322 .3308 L
.5233 .33081 L
.5234 .33081 L
.52346 .33081 L
.52351 .33081 L
.52361 .3308 L
.5237 .33078 L
.52375 .33077 L
.52381 .33076 L
.52391 .33073 L
.52413 .33065 L
.52433 .33054 L
.52451 .33043 L
.52493 .33008 L
.5253 .32967 L
.52564 .32921 L
.52641 .32791 L
Mistroke
.52721 .32617 L
.52794 .32422 L
.52961 .31868 L
.53276 .30518 L
.53579 .29135 L
.53747 .28475 L
.53821 .28234 L
.53901 .28013 L
.53939 .27926 L
.5398 .27846 L
.54015 .27788 L
.54053 .27738 L
.54075 .27714 L
.54096 .27696 L
.54115 .27683 L
.54125 .27678 L
.54136 .27673 L
.54146 .2767 L
.54155 .27668 L
.54164 .27667 L
.54172 .27666 L
.54182 .27667 L
.54191 .27668 L
.54201 .2767 L
.54207 .27672 L
.54212 .27673 L
.54231 .27682 L
.54251 .27696 L
.54272 .27715 L
.54292 .27737 L
.54328 .27787 L
.54367 .27855 L
.54454 .28066 L
.54534 .28324 L
.54687 .28989 L
.54854 .29923 L
.55181 .32124 L
.55344 .3322 L
.55497 .34134 L
.55643 .34828 L
.55725 .35118 L
.55764 .35227 L
.558 .35309 L
.55838 .35378 L
.55859 .35406 L
.55879 .35428 L
.55888 .35436 L
.55897 .35443 L
.55905 .35448 L
.55914 .35452 L
Mistroke
.55924 .35455 L
.55932 .35457 L
.55943 .35458 L
.55952 .35458 L
.55963 .35456 L
.55968 .35454 L
.55974 .35451 L
.55984 .35446 L
.55993 .3544 L
.56015 .3542 L
.56038 .35391 L
.5608 .35317 L
.56119 .35225 L
.56197 .34969 L
.5627 .34648 L
.56436 .33643 L
.56749 .30958 L
.57082 .27754 L
.57249 .26383 L
.57322 .25886 L
.57402 .25433 L
.5744 .2526 L
.5748 .25103 L
.57514 .24991 L
.57552 .24895 L
.57574 .24853 L
.57595 .24822 L
.57614 .24801 L
.57625 .24792 L
.57635 .24787 L
.57645 .24784 L
.57654 .24783 L
.57664 .24783 L
.57674 .24786 L
.57683 .2479 L
.57692 .24796 L
.57701 .24804 L
.57711 .24815 L
.57731 .24844 L
.57753 .24885 L
.57792 .24984 L
.57835 .25128 L
.57881 .25332 L
.57965 .2581 L
.58043 .26386 L
.58205 .27927 L
.58353 .29666 L
.58671 .33821 L
.58832 .35764 L
.58977 .3722 L
Mistroke
.59058 .37852 L
.59135 .38308 L
.59177 .38495 L
.59216 .38626 L
.59236 .38679 L
.59258 .38723 L
.59269 .3874 L
.59281 .38754 L
.59287 .3876 L
.59293 .38764 L
.59303 .38769 L
.59313 .38772 L
.59319 .38772 L
.59324 .38771 L
.59333 .38768 L
.59343 .38761 L
.59353 .38753 L
.59361 .38743 L
.5938 .38712 L
.59401 .38667 L
.5942 .38615 L
.59462 .38459 L
.59499 .38284 L
.59538 .3805 L
.5961 .37512 L
.59769 .35837 L
.59938 .33459 L
.60241 .28377 L
.6041 .25631 L
.60564 .23508 L
.60643 .22646 L
.60716 .22006 L
.60756 .21727 L
.60792 .21522 L
.60832 .21347 L
.60855 .21277 L
.60865 .2125 L
.60875 .21226 L
.60885 .21208 L
.60895 .21194 L
.60904 .21183 L
.60913 .21176 L
.60923 .21172 L
.60932 .21171 L
.60943 .21174 L
.60948 .21177 L
.60954 .21182 L
.60964 .21194 L
.60974 .21209 L
.60996 .21256 L
Mistroke
.61016 .21313 L
.61036 .21389 L
.61073 .21565 L
.61107 .21774 L
.61185 .22411 L
.61269 .23347 L
.61349 .24447 L
.61498 .26982 L
.61806 .33355 L
.61962 .36563 L
.62045 .38105 L
.62134 .3957 L
.6222 .40737 L
.62298 .41568 L
.62335 .4188 L
.62376 .4215 L
.62395 .42249 L
.62415 .42337 L
.62432 .42398 L
.62451 .42449 L
.62461 .42471 L
.62471 .42486 L
.62477 .42493 L
.62482 .42498 L
.62488 .42501 L
.62494 .42504 L
.62503 .42504 L
.62513 .425 L
.62523 .42491 L
.62528 .42485 L
.62533 .42476 L
.62545 .42454 L
.62555 .42428 L
.62579 .4235 L
.626 .42258 L
.62623 .42138 L
.62663 .41862 L
.627 .41538 L
.62784 .40568 L
.62869 .39291 L
.62949 .37835 L
.63098 .34578 L
.63407 .26796 L
.63564 .23103 L
.63647 .21407 L
.63736 .19869 L
.63779 .19238 L
.63821 .18723 L
.63862 .18305 L
.63899 .17995 L
Mistroke
.63935 .17772 L
.63954 .17677 L
.63972 .17611 L
.63982 .17583 L
.63992 .17559 L
.63997 .17549 L
.64003 .1754 L
.64013 .17528 L
.64023 .17523 L
.64033 .17523 L
.64043 .17528 L
.64052 .17539 L
.64062 .17554 L
.64071 .17574 L
.64091 .17636 L
.64111 .1772 L
.64132 .17835 L
.6417 .1811 L
.64206 .18435 L
.64291 .19511 L
.64373 .20888 L
.64531 .24435 L
.64679 .28471 L
.64993 .37653 L
.65153 .41625 L
.65244 .43388 L
.65287 .44078 L
.65327 .44628 L
.65366 .45069 L
.65401 .45389 L
.6542 .45527 L
.65441 .4565 L
.65452 .45705 L
.65462 .45749 L
.65472 .45784 L
.65483 .45815 L
.65493 .45837 L
.65503 .45851 L
.65512 .45858 L
.65521 .45861 L
.65531 .45856 L
.65541 .45845 L
.65552 .45826 L
.65563 .45797 L
.65574 .45761 L
.65586 .45712 L
.65608 .45598 L
.65648 .45301 L
.65687 .44909 L
.65724 .44451 L
Mistroke
.65808 .43092 L
.65889 .41377 L
.65977 .39158 L
.66308 .2863 L
.66473 .23279 L
.66627 .19076 L
.66703 .17413 L
.66776 .16175 L
.66815 .15639 L
.66859 .15185 L
.66878 .15028 L
.66898 .14891 L
.66915 .14799 L
.66934 .14723 L
.66944 .14693 L
.66954 .14672 L
.66959 .14664 L
.66965 .14658 L
.66971 .14653 L
.66976 .14652 L
.66986 .14655 L
.66995 .14665 L
.67005 .14683 L
.67016 .14711 L
.67025 .14741 L
.67034 .1478 L
.67052 .14868 L
.67072 .15002 L
.67091 .15151 L
.67132 .1558 L
.67177 .16188 L
.67259 .17657 L
.67418 .21745 L
.67587 .27348 L
.67892 .38337 L
.67979 .41128 L
.68061 .43446 L
.68142 .45316 L
.68177 .46 L
.68216 .46651 L
.68251 .47134 L
.68288 .47547 L
.68309 .47725 L
.68328 .47858 L
.68346 .47957 L
.68356 .47999 L
.68365 .48031 L
.68376 .48058 L
.68385 .48074 L
.68395 .48084 L
Mistroke
.684 .48086 L
.68406 .48086 L
.68414 .48079 L
.68424 .48065 L
.68434 .48042 L
.68443 .48013 L
.68464 .47917 L
.68484 .47796 L
.68507 .47616 L
.68528 .47405 L
.68605 .46339 L
.68648 .45539 L
.68687 .44694 L
.68835 .40587 L
.69156 .28604 L
.69304 .23037 L
.69388 .20206 L
.69466 .17897 L
.6955 .15866 L
.69626 .14478 L
.69668 .1392 L
.69708 .13533 L
.69729 .1338 L
.69749 .13277 L
.6976 .13238 L
.69772 .13206 L
.69777 .13195 L
.69784 .13186 L
.6979 .13181 L
.69795 .1318 L
.69805 .13184 L
.69815 .13197 L
.69824 .13216 L
.69833 .13244 L
.69843 .13284 L
.69854 .13337 L
.69874 .13459 L
.69909 .13764 L
.69947 .14223 L
.69988 .14864 L
.70033 .15711 L
.70113 .17636 L
.70283 .23103 L
.70445 .29417 L
.70752 .41314 L
.70833 .43844 L
.7091 .4581 L
.70952 .46702 L
.70998 .47494 L
.7104 .48052 L
Mistroke
.7106 .48263 L
.71078 .48423 L
.71098 .48559 L
.71116 .48655 L
.71126 .48694 L
.71136 .48721 L
.71146 .48741 L
.71151 .48747 L
.71157 .48751 L
.71166 .48751 L
.71175 .48743 L
.71185 .48725 L
.71195 .48699 L
.71203 .48668 L
.71211 .48632 L
.7123 .48526 L
.71252 .48361 L
.71272 .48165 L
.7131 .47695 L
.71351 .4704 L
.71396 .46164 L
.71556 .41749 L
.71725 .35476 L
.72029 .23135 L
.72186 .17955 L
.72274 .1578 L
.72313 .15021 L
.72354 .1436 L
.72392 .13893 L
.72413 .13688 L
.72433 .13536 L
.72442 .13481 L
.72452 .13431 L
.7246 .13396 L
.72469 .13365 L
.72478 .1334 L
.72487 .13325 L
.72497 .13316 L
.72507 .13318 L
.72517 .1333 L
.72522 .1334 L
.72528 .13355 L
.72538 .13388 L
.72548 .13428 L
.72569 .13552 L
.72592 .13735 L
.72635 .14202 L
.72673 .14775 L
.72753 .16363 L
.72826 .18293 L
Mistroke
.72992 .23954 L
.73307 .36643 L
.73467 .42268 L
.73558 .44729 L
.73601 .45674 L
.73641 .46412 L
.7368 .46991 L
.73715 .47394 L
.73736 .47569 L
.73755 .47699 L
.73765 .47751 L
.73775 .47795 L
.73781 .47815 L
.73787 .47832 L
.73797 .47855 L
.73808 .47866 L
.73813 .47868 L
.73819 .47867 L
.73829 .47856 L
.73838 .47838 L
.73844 .47822 L
.7385 .47804 L
.7386 .47763 L
.73883 .47634 L
.73903 .47479 L
.73921 .47302 L
.73963 .46786 L
.74 .46182 L
.74041 .45395 L
.74113 .43636 L
.74279 .38303 L
.74611 .25328 L
.74691 .22457 L
.74776 .19779 L
.7485 .17863 L
.7493 .16286 L
.74973 .15663 L
.74992 .15444 L
.75013 .15244 L
.75032 .15101 L
.75051 .14983 L
.75062 .14935 L
.75072 .149 L
.75082 .14875 L
.75091 .1486 L
.751 .14854 L
.75109 .14855 L
.75119 .14865 L
.75128 .14883 L
.75136 .14906 L
Mistroke
.75144 .14934 L
.75161 .15017 L
.7518 .15138 L
.752 .15308 L
.75237 .15715 L
.7528 .16338 L
.7532 .1707 L
.75395 .18786 L
.75564 .23975 L
.75873 .35558 L
.7603 .40681 L
.76119 .4294 L
.76162 .43813 L
.76202 .44501 L
.7624 .45023 L
.76261 .45245 L
.76282 .45441 L
.763 .45573 L
.7631 .45631 L
.7632 .45684 L
.76329 .45724 L
.76338 .45753 L
.76346 .45774 L
.76355 .4579 L
.76365 .45799 L
.76375 .45799 L
.7638 .45796 L
.76385 .45789 L
.76396 .4577 L
.76405 .45743 L
.76415 .45705 L
.76433 .45614 L
.76454 .4547 L
.76474 .45299 L
.76519 .44782 L
.76559 .44176 L
.76603 .43369 L
.76682 .41537 L
.76831 .37094 L
.77002 .31073 L
.77157 .25682 L
.77235 .2327 L
.77319 .21026 L
.77399 .19338 L
.77437 .18696 L
.77472 .18213 L
.7751 .17803 L
.7753 .1763 L
.7755 .175 L
.77559 .17453 L
Mistroke
.77568 .17411 L
.77576 .1738 L
.77585 .17354 L
.77594 .17333 L
.77603 .1732 L
.77614 .17314 L
.77623 .17317 L
.77633 .17328 L
.77643 .17348 L
.77653 .17377 L
.77662 .17409 L
.77684 .17518 L
.77704 .17658 L
.77745 .18043 L
.77789 .18613 L
.77865 .19944 L
.77949 .21858 L
.78118 .26784 L
.78287 .32341 L
.78442 .37072 L
.78519 .39058 L
.78602 .40831 L
.78641 .41486 L
.78681 .42066 L
.78716 .42461 L
.78754 .42787 L
.78773 .42904 L
.78794 .42999 L
.78804 .43034 L
.7881 .43049 L
.78815 .43061 L
.78826 .43078 L
.78835 .43086 L
.78844 .43086 L
.78854 .43079 L
.78862 .43067 L
.78871 .43048 L
.7888 .43021 L
.78891 .42982 L
.78909 .42892 L
.78931 .42754 L
.78954 .42563 L
.78997 .42108 L
.79077 .40902 L
.7916 .39223 L
.79235 .37392 L
.79403 .32613 L
.79571 .2769 L
.79644 .25719 L
.79725 .23811 L
Mistroke
.79797 .22382 L
.79875 .21214 L
.79918 .20746 L
.79958 .20434 L
.79976 .20325 L
.79986 .20278 L
.79997 .20236 L
.80006 .20206 L
.80016 .2018 L
.80026 .20163 L
.80034 .20154 L
.80044 .20149 L
.80054 .20152 L
.80063 .20161 L
.80072 .20176 L
.80082 .202 L
.80093 .20234 L
.80113 .2032 L
.80134 .20441 L
.80157 .20603 L
.80196 .20979 L
.80267 .21903 L
.80345 .23258 L
.80669 .31199 L
.80818 .34956 L
.80897 .36672 L
.80981 .38189 L
.81027 .38865 L
.81069 .39367 L
.81111 .39761 L
.81151 .40027 L
.81171 .4012 L
.81181 .40161 L
.81191 .40191 L
.812 .40212 L
.81209 .40229 L
.81219 .40241 L
.81228 .40246 L
.81234 .40246 L
.81239 .40244 L
.81249 .40236 L
.81255 .40229 L
.8126 .4022 L
.81272 .40194 L
.81282 .40164 L
.81291 .4013 L
.81312 .40034 L
.8135 .39787 L
.81391 .39424 L
.81465 .38532 L
Mistroke
.81552 .37117 L
.81631 .35567 L
.81798 .31803 L
.81952 .28302 L
.82103 .2543 L
.82178 .24333 L
.82221 .23842 L
.82262 .23468 L
.82301 .23193 L
.82323 .23077 L
.82344 .22996 L
.82361 .22946 L
.82371 .22926 L
.8238 .22912 L
.82389 .22903 L
.82398 .22899 L
.82408 .229 L
.82418 .22908 L
.82429 .22922 L
.82438 .2294 L
.82449 .22967 L
.8246 .23 L
.82478 .23073 L
.82498 .23174 L
.82544 .23486 L
.82586 .23871 L
.82664 .24804 L
.82737 .25905 L
.82902 .28965 L
.83051 .31944 L
.83214 .34847 L
.83302 .3608 L
.83345 .36564 L
.83384 .36931 L
.83424 .37235 L
.83462 .37448 L
.83483 .37534 L
.83502 .37593 L
.83512 .37617 L
.83523 .37637 L
.83528 .37645 L
.83534 .37651 L
.8354 .37656 L
.83545 .37659 L
.83554 .3766 L
.83563 .37657 L
.83573 .3765 L
.83584 .37636 L
.83594 .37617 L
.83605 .37591 L
Mistroke
.83625 .37529 L
.83643 .37455 L
.8366 .37372 L
.83698 .37133 L
.83741 .36793 L
.83779 .3642 L
.83865 .35383 L
.84186 .3018 L
.84334 .279 L
.84417 .26847 L
.84458 .26419 L
.84495 .26082 L
.84532 .25804 L
.84572 .25566 L
.84594 .25464 L
.84615 .25389 L
.84634 .25334 L
.84644 .25313 L
.84655 .25294 L
.84666 .25281 L
.84671 .25277 L
.84677 .25273 L
.84687 .2527 L
.84697 .25272 L
.84703 .25275 L
.84708 .25279 L
.84719 .2529 L
.84725 .25299 L
.8473 .25308 L
.84742 .25333 L
.84761 .25385 L
.84782 .25459 L
.84824 .25663 L
.84866 .25934 L
.84905 .2625 L
.8498 .26981 L
.85148 .29113 L
.85308 .31411 L
.85454 .33315 L
.8553 .3413 L
.85612 .34824 L
.85657 .35111 L
.85677 .35214 L
.85699 .35311 L
.85718 .35382 L
.85738 .35444 L
.8575 .35471 L
.8576 .35491 L
.85771 .35508 L
.8578 .3552 L
Mistroke
.85789 .35528 L
.85799 .35533 L
.85809 .35535 L
.85819 .35532 L
.85829 .35527 L
.85839 .35517 L
.8585 .35503 L
.8586 .35486 L
.85879 .35444 L
.85896 .35396 L
.85934 .35251 L
.85975 .3504 L
.86019 .34752 L
.861 .3409 L
.86429 .304 L
.86508 .2952 L
.86592 .2868 L
.86665 .28076 L
.86745 .27576 L
.86787 .27384 L
.86808 .2731 L
.86827 .27254 L
.86845 .27211 L
.86864 .27175 L
.86875 .2716 L
.86885 .2715 L
.86894 .27143 L
.86904 .27139 L
.86913 .27137 L
.86921 .27138 L
.86931 .27142 L
.8694 .27148 L
.86948 .27156 L
.86956 .27165 L
.86973 .27192 L
.86991 .27229 L
.8701 .27279 L
.87049 .27415 L
.87089 .27594 L
.87131 .27825 L
.87205 .28335 L
.87372 .29808 L
.87533 .31364 L
.87679 .3262 L
.8776 .33173 L
.87837 .33566 L
.87879 .33723 L
.87917 .33828 L
.87938 .33868 L
.87949 .33886 L
Mistroke
.8796 .339 L
.87971 .33911 L
.87977 .33915 L
.87983 .33919 L
.87994 .33923 L
.87999 .33924 L
.88005 .33925 L
.88014 .33923 L
.88024 .33919 L
.88033 .33914 L
.88042 .33906 L
.88052 .33896 L
.88063 .33881 L
.88082 .33848 L
.8812 .33757 L
.88154 .33646 L
.88239 .33265 L
.8832 .32786 L
.88628 .30447 L
.88785 .29392 L
.88827 .29161 L
.88873 .28947 L
.88917 .28783 L
.88957 .28663 L
.88997 .28575 L
.89018 .28542 L
.8903 .28528 L
.89041 .28518 L
.89052 .28511 L
.89061 .28506 L
.89072 .28503 L
.89077 .28502 L
.89083 .28502 L
.89092 .28503 L
.89103 .28507 L
.89113 .28512 L
.89122 .28519 L
.89141 .28539 L
.89159 .28564 L
.89199 .28644 L
.89235 .28739 L
.89273 .28865 L
.89429 .29603 L
.89576 .30495 L
.89724 .31414 L
.89808 .31876 L
.89887 .32238 L
.89964 .32515 L
.90008 .3263 L
.90048 .32708 L
Mistroke
.90069 .32739 L
.90089 .32761 L
.901 .3277 L
.90111 .32777 L
.90117 .3278 L
.90124 .32783 L
.90129 .32784 L
.90135 .32785 L
.90145 .32786 L
.90155 .32785 L
.90161 .32784 L
.90166 .32782 L
.90172 .3278 L
.90177 .32777 L
.90196 .32764 L
.90207 .32754 L
.90217 .32743 L
.90255 .32686 L
.90295 .32602 L
.90369 .32393 L
.90456 .32065 L
.90535 .3171 L
.90701 .30886 L
.90855 .30179 L
.90932 .29891 L
.91005 .29679 L
.91041 .29596 L
.9108 .29526 L
.91102 .29495 L
.91124 .29471 L
.91143 .29456 L
.91153 .29449 L
.91163 .29444 L
.91174 .2944 L
.91179 .29439 L
.91185 .29438 L
.91195 .29437 L
.91204 .29438 L
.9121 .29439 L
.91215 .2944 L
.91225 .29444 L
.91236 .29449 L
.91248 .29456 L
.91268 .29473 L
.9129 .29496 L
.91328 .29552 L
.91365 .29621 L
.91399 .29698 L
.91477 .29917 L
.91788 .31073 L
Mistroke
.91946 .31602 L
.91989 .31717 L
.92035 .31822 L
.92078 .31901 L
.92118 .31958 L
.92138 .3198 L
.92159 .31999 L
.9218 .32013 L
.92192 .32019 L
.92198 .32021 L
.92204 .32023 L
.92214 .32026 L
.92224 .32027 L
.92234 .32028 L
.92243 .32027 L
.92248 .32027 L
.92253 .32026 L
.92263 .32023 L
.92273 .32019 L
.92285 .32014 L
.92303 .32003 L
.92323 .31986 L
.92364 .31941 L
.92401 .31887 L
.92436 .31825 L
.926 .31428 L
.92749 .30984 L
.92915 .30511 L
.92988 .30341 L
.93027 .30264 L
.93069 .30193 L
.93109 .30137 L
.93146 .30097 L
.93181 .30069 L
.93199 .30059 L
.93208 .30055 L
.93218 .30051 L
.93229 .30048 L
.93239 .30046 L
.93249 .30044 L
.93258 .30044 L
.93268 .30044 L
.93274 .30045 L
.93279 .30046 L
.93289 .30048 L
.93295 .30049 L
.93301 .30051 L
.93319 .30059 L
.9334 .3007 L
.93377 .30099 L
Mistroke
.93416 .3014 L
.93452 .30187 L
.93535 .30325 L
.93704 .30686 L
.93852 .31026 L
.93936 .312 L
.94014 .31338 L
.94092 .31443 L
.94135 .31488 L
.94175 .31517 L
.94197 .3153 L
.94217 .31538 L
.94227 .31542 L
.94239 .31545 L
.94244 .31546 L
.94251 .31547 L
.94256 .31548 L
.94262 .31548 L
.94272 .31549 L
.94282 .31549 L
.94288 .31548 L
.94293 .31548 L
.94299 .31547 L
.94304 .31546 L
.94314 .31544 L
.94323 .31541 L
.94344 .31533 L
.94364 .31524 L
.94382 .31513 L
.94422 .31482 L
.94495 .31406 L
.9458 .31288 L
.94661 .31157 L
.94807 .309 L
.94891 .3076 L
.94969 .30643 L
.95052 .30541 L
.95088 .30505 L
.95128 .30473 L
.95167 .30448 L
.95189 .30437 L
.95209 .30429 L
.9522 .30426 L
.95231 .30423 L
.95241 .30421 L
.95251 .3042 L
.95257 .30419 L
.95263 .30419 L
.95269 .30418 L
.95275 .30418 L
Mistroke
.95285 .30418 L
.95291 .30419 L
.95296 .30419 L
.95307 .3042 L
.95317 .30422 L
.95335 .30426 L
.95354 .30432 L
.95376 .30441 L
.95414 .30461 L
.95449 .30485 L
.9553 .30558 L
.95616 .30654 L
.95921 .31045 L
.96002 .3113 L
.96078 .31192 L
.9612 .31219 L
.96142 .3123 L
.96166 .3124 L
.96186 .31247 L
.96208 .31253 L
.96217 .31255 L
.96227 .31257 L
.96237 .31258 L
.96246 .31259 L
.96256 .3126 L
.96266 .3126 L
.96275 .3126 L
.96284 .3126 L
.96295 .31259 L
.963 .31258 L
.96305 .31258 L
.96325 .31255 L
.96343 .3125 L
.96363 .31245 L
.96398 .31231 L
.96443 .31208 L
.96485 .31182 L
.96565 .31121 L
.96872 .30827 L
.96954 .30758 L
.97031 .30706 L
.97072 .30683 L
.97111 .30666 L
.97153 .30652 L
.97176 .30647 L
.97187 .30644 L
.97199 .30642 L
.9721 .30641 L
.9722 .3064 L
.97229 .30639 L
Mistroke
.97239 .30639 L
.97248 .30639 L
.97257 .30639 L
.97266 .30639 L
.97276 .30639 L
.97286 .3064 L
.97298 .30641 L
.97319 .30644 L
.97339 .30649 L
.97358 .30653 L
.97429 .30679 L
.97505 .30718 L
.97619 .30791 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{421.375, 260.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 525.688}, {324.5, 0}} -> {-2.58312*^-7, -6.34248*^6, \
6.65005*^-9, 53093.5}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0.309017 5.42214e-08 [
[.32684 .29652 -16.5 -12.5 ]
[.32684 .29652 16.5 0 ]
[.54329 .29652 -16.5 -12.5 ]
[.54329 .29652 16.5 0 ]
[.75974 .29652 -22.5 -12.5 ]
[.75974 .29652 22.5 0 ]
[.97619 .29652 -16.5 -12.5 ]
[.97619 .29652 16.5 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 64 6 ]
[.09789 .09213 -34.5 -6.25 ]
[.09789 .09213 0 6.25 ]
[.09789 .20057 -34.5 -6.25 ]
[.09789 .20057 0 6.25 ]
[.09789 .41746 -28.5 -6.25 ]
[.09789 .41746 0 6.25 ]
[.09789 .5259 -28.5 -6.25 ]
[.09789 .5259 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -65.8125 0 ]
[.5 .63053 65.8125 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 .30902 m
.32684 .31527 L
s
gsave
.32684 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 .30902 m
.54329 .31527 L
s
gsave
.54329 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 .30902 m
.75974 .31527 L
s
gsave
.75974 .29652 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 .30902 m
.15368 .31277 L
s
.19697 .30902 m
.19697 .31277 L
s
.24026 .30902 m
.24026 .31277 L
s
.28355 .30902 m
.28355 .31277 L
s
.37013 .30902 m
.37013 .31277 L
s
.41342 .30902 m
.41342 .31277 L
s
.45671 .30902 m
.45671 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.58658 .30902 m
.58658 .31277 L
s
.62987 .30902 m
.62987 .31277 L
s
.67316 .30902 m
.67316 .31277 L
s
.71645 .30902 m
.71645 .31277 L
s
.80303 .30902 m
.80303 .31277 L
s
.84632 .30902 m
.84632 .31277 L
s
.88961 .30902 m
.88961 .31277 L
s
.9329 .30902 m
.9329 .31277 L
s
.0671 .30902 m
.0671 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09213 m
.11664 .09213 L
s
gsave
.09789 .09213 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .20057 m
.11664 .20057 L
s
gsave
.09789 .20057 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .41746 m
.11664 .41746 L
s
gsave
.09789 .41746 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .5259 m
.11664 .5259 L
s
gsave
.09789 .5259 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.11039 .11924 m
.11414 .11924 L
s
.11039 .14635 m
.11414 .14635 L
s
.11039 .17346 m
.11414 .17346 L
s
.11039 .22768 m
.11414 .22768 L
s
.11039 .2548 m
.11414 .2548 L
s
.11039 .28191 m
.11414 .28191 L
s
.11039 .33613 m
.11414 .33613 L
s
.11039 .36324 m
.11414 .36324 L
s
.11039 .39035 m
.11414 .39035 L
s
.11039 .44457 m
.11414 .44457 L
s
.11039 .47168 m
.11414 .47168 L
s
.11039 .49879 m
.11414 .49879 L
s
.11039 .06502 m
.11414 .06502 L
s
.11039 .03791 m
.11414 .03791 L
s
.11039 .0108 m
.11414 .0108 L
s
.11039 .55301 m
.11414 .55301 L
s
.11039 .58012 m
.11414 .58012 L
s
.11039 .60723 m
.11414 .60723 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -126.812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.812 moveto
(@) show
81.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.812 moveto
(D) show
93.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12.2) show
141.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
147.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
159.000 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
163.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
172.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
190.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02691 .30902 L
.03029 .30902 L
.03347 .30902 L
.03652 .30902 L
.03978 .30902 L
.04291 .30902 L
.04623 .30902 L
.04944 .30902 L
.05252 .30902 L
.0558 .30902 L
.05896 .30902 L
.062 .30902 L
.06523 .30902 L
.06834 .30902 L
.07165 .30902 L
.07484 .30902 L
.0779 .30902 L
.08117 .30902 L
.08431 .30902 L
.08765 .30902 L
.09086 .30902 L
.09396 .30902 L
.09725 .30902 L
.10042 .30902 L
.10346 .30902 L
.10516 .30902 L
.10671 .30902 L
.10833 .30902 L
.10904 .30902 L
.10983 .30902 L
.11019 .30902 L
.11057 .30902 L
.11079 .30902 L
.11098 .30902 L
.11117 .30902 L
.11136 .30902 L
.11147 .30902 L
.11156 .30902 L
.11162 .30902 L
.11167 .30902 L
.11178 .30902 L
.11187 .30902 L
.11198 .30902 L
.11206 .30902 L
.11216 .30902 L
.11227 .30902 L
.11238 .30902 L
.11261 .30902 L
.11283 .30902 L
Mistroke
.11303 .30902 L
.11344 .30902 L
.1138 .30902 L
.11462 .30902 L
.11538 .30902 L
.1161 .30902 L
.11689 .30902 L
.11771 .30902 L
.1192 .30902 L
.12078 .30902 L
.12225 .30902 L
.12389 .30902 L
.12538 .30902 L
.12704 .30902 L
.12858 .30902 L
.13166 .30902 L
.13316 .30902 L
.13482 .30902 L
.13805 .30902 L
.14116 .30902 L
.14446 .30902 L
.14765 .30902 L
.15071 .30902 L
.15397 .30902 L
.15711 .30902 L
.16045 .30902 L
.16366 .30902 L
.16675 .30902 L
.17004 .30902 L
.17321 .30902 L
.17625 .30902 L
.17949 .30902 L
.18099 .30902 L
.18261 .30902 L
.1835 .30902 L
.18389 .30902 L
.18432 .30902 L
.18451 .30902 L
.18472 .30902 L
.1849 .30902 L
.1851 .30902 L
.1852 .30902 L
.18531 .30902 L
.18537 .30902 L
.18543 .30902 L
.18548 .30902 L
.18553 .30902 L
.18563 .30902 L
.18568 .30902 L
.18574 .30902 L
Mistroke
.18583 .30902 L
.18593 .30902 L
.18604 .30902 L
.18613 .30902 L
.18635 .30902 L
.18654 .30902 L
.18675 .30902 L
.18714 .30902 L
.18749 .30902 L
.18791 .30902 L
.18835 .30902 L
.18917 .30902 L
.18993 .30902 L
.19077 .30902 L
.19246 .30902 L
.19403 .30902 L
.19571 .30902 L
.19741 .30902 L
.19903 .30902 L
.20211 .30902 L
.20538 .30902 L
.20853 .30902 L
.21157 .30902 L
.21479 .30902 L
.2179 .30902 L
.22121 .30902 L
.22439 .30902 L
.22745 .30902 L
.22916 .30902 L
.23071 .30902 L
.23148 .30902 L
.23232 .30902 L
.23311 .30902 L
.23384 .30902 L
.23421 .30902 L
.2346 .30902 L
.23483 .30902 L
.23504 .30902 L
.23523 .30902 L
.23534 .30902 L
.23544 .30902 L
.23549 .30902 L
.23554 .30902 L
.2356 .30902 L
.23566 .30902 L
.23576 .30902 L
.23582 .30902 L
.23587 .30902 L
.23597 .30902 L
.23606 .30902 L
Mistroke
.23616 .30902 L
.23626 .30902 L
.23647 .30902 L
.23667 .30902 L
.23713 .30902 L
.2375 .30902 L
.2379 .30902 L
.23863 .30902 L
.23949 .30902 L
.24028 .30902 L
.24181 .30902 L
.24347 .30902 L
.24505 .30902 L
.24673 .30902 L
.25007 .30902 L
.25328 .30902 L
.25638 .30902 L
.25967 .30902 L
.26284 .30902 L
.26588 .30902 L
.26913 .30902 L
.27062 .30902 L
.27225 .30902 L
.27313 .30902 L
.27395 .30902 L
.27474 .30902 L
.27513 .30902 L
.27536 .30902 L
.27557 .30902 L
.27566 .30902 L
.27576 .30902 L
.27585 .30902 L
.27595 .30902 L
.276 .30902 L
.27606 .30902 L
.27616 .30902 L
.27626 .30902 L
.27636 .30902 L
.27646 .30902 L
.27656 .30902 L
.27666 .30902 L
.27675 .30902 L
.27698 .30902 L
.27719 .30902 L
.27756 .30902 L
.2779 .30902 L
.27867 .30902 L
.27908 .30902 L
.27952 .30902 L
.28032 .30902 L
Mistroke
.28182 .30902 L
.28342 .30902 L
.28511 .30902 L
.28816 .30902 L
.29141 .30902 L
.29454 .30901 L
.29786 .30901 L
.30106 .30901 L
.30414 .30901 L
.3057 .30901 L
.30742 .30901 L
.3082 .30901 L
.30905 .30901 L
.30943 .30901 L
.30984 .30901 L
.31019 .30901 L
.31039 .30901 L
.31057 .30901 L
.31078 .30901 L
.31088 .30901 L
.31094 .30901 L
.311 .30901 L
.3111 .30901 L
.31119 .30901 L
.31125 .30901 L
.3113 .30901 L
.3114 .30901 L
.31149 .30901 L
.31159 .30901 L
.31167 .30901 L
.31176 .30901 L
.31196 .30901 L
.31215 .30901 L
.31257 .30901 L
.31296 .30901 L
.31338 .30901 L
.31383 .30901 L
.3146 .30901 L
.31541 .30901 L
.31689 .30901 L
.3186 .30901 L
.32021 .30901 L
.3233 .30902 L
.32658 .30902 L
.32974 .30903 L
.33278 .30904 L
.33601 .30905 L
.3375 .30905 L
.33912 .30905 L
.34 .30905 L
Mistroke
.34043 .30905 L
.34082 .30905 L
.3412 .30905 L
.3416 .30905 L
.34182 .30905 L
.34192 .30905 L
.34203 .30905 L
.34213 .30905 L
.34223 .30905 L
.34233 .30905 L
.34238 .30905 L
.34243 .30905 L
.34253 .30905 L
.34262 .30905 L
.34271 .30905 L
.34282 .30905 L
.34292 .30905 L
.34303 .30905 L
.34323 .30905 L
.34341 .30905 L
.34358 .30905 L
.34397 .30905 L
.34439 .30905 L
.34477 .30905 L
.34563 .30905 L
.34643 .30905 L
.34717 .30905 L
.34884 .30904 L
.35035 .30904 L
.352 .30903 L
.35524 .309 L
.35836 .30898 L
.36167 .30894 L
.36487 .30891 L
.36648 .3089 L
.36794 .30889 L
.36875 .30889 L
.36913 .30889 L
.36952 .30889 L
.36972 .30889 L
.36994 .30889 L
.37014 .30889 L
.37033 .30889 L
.37043 .30889 L
.37055 .30889 L
.37061 .30889 L
.37067 .30889 L
.37073 .30889 L
.37078 .30889 L
.37088 .30889 L
Mistroke
.37093 .30889 L
.37099 .30889 L
.37105 .30889 L
.3711 .30889 L
.3712 .30889 L
.3713 .30889 L
.37141 .30889 L
.37161 .30889 L
.3718 .30889 L
.37197 .30889 L
.37237 .30889 L
.37279 .30889 L
.3735 .30889 L
.37427 .3089 L
.37509 .3089 L
.37583 .30891 L
.37751 .30893 L
.37904 .30896 L
.38071 .309 L
.38398 .30908 L
.38713 .30918 L
.39016 .30927 L
.39184 .30932 L
.39338 .30935 L
.39416 .30937 L
.39489 .30938 L
.39565 .30939 L
.39605 .30939 L
.39626 .30939 L
.39648 .30939 L
.39669 .30939 L
.3968 .30939 L
.39691 .30939 L
.39701 .30939 L
.3971 .30939 L
.39721 .30939 L
.39731 .30939 L
.39736 .30939 L
.39741 .30939 L
.39747 .30939 L
.39753 .30939 L
.39763 .30939 L
.39773 .30939 L
.39797 .30939 L
.3982 .30939 L
.39857 .30939 L
.39898 .30938 L
.39941 .30938 L
.39981 .30937 L
.40065 .30935 L
Mistroke
.40145 .30933 L
.40294 .30928 L
.40454 .3092 L
.40602 .30912 L
.40917 .30889 L
.4122 .30863 L
.41543 .30837 L
.41692 .30826 L
.41776 .30821 L
.41854 .30817 L
.41939 .30813 L
.42015 .30811 L
.42057 .3081 L
.42097 .30809 L
.42119 .30809 L
.42139 .30808 L
.4215 .30808 L
.42156 .30808 L
.42161 .30808 L
.42167 .30808 L
.42173 .30808 L
.42179 .30808 L
.42185 .30808 L
.42195 .30808 L
.422 .30808 L
.42205 .30808 L
.42215 .30808 L
.42225 .30808 L
.42243 .30809 L
.42262 .30809 L
.42282 .30809 L
.42304 .3081 L
.42344 .30811 L
.42384 .30812 L
.42421 .30813 L
.42492 .30817 L
.4257 .30822 L
.42652 .30829 L
.428 .30845 L
.43104 .30889 L
.43427 .30951 L
.43738 .31015 L
.43896 .31045 L
.44069 .31074 L
.44149 .31084 L
.44234 .31094 L
.44276 .31097 L
.44315 .31101 L
.44353 .31103 L
.44388 .31105 L
Mistroke
.44407 .31106 L
.44425 .31106 L
.44445 .31107 L
.44456 .31107 L
.44466 .31107 L
.44476 .31107 L
.44487 .31107 L
.44496 .31107 L
.44506 .31107 L
.44511 .31107 L
.44516 .31107 L
.44522 .31107 L
.44528 .31107 L
.44538 .31107 L
.44549 .31107 L
.44568 .31106 L
.44586 .31105 L
.44626 .31104 L
.44662 .31101 L
.44697 .31098 L
.44775 .3109 L
.44858 .31078 L
.45006 .31049 L
.45163 .31007 L
.4531 .30958 L
.45622 .30832 L
.45953 .30685 L
.46118 .30617 L
.46272 .30564 L
.46421 .30524 L
.46463 .30516 L
.46504 .30509 L
.46543 .30503 L
.46579 .30499 L
.46599 .30497 L
.46616 .30496 L
.46636 .30495 L
.46647 .30494 L
.46657 .30494 L
.46667 .30494 L
.46673 .30493 L
.46678 .30493 L
.46688 .30493 L
.46697 .30493 L
.46702 .30493 L
.46708 .30493 L
.46718 .30494 L
.46724 .30494 L
.46729 .30494 L
.4674 .30494 L
Mistroke
.4676 .30496 L
.46778 .30497 L
.46812 .305 L
.46849 .30505 L
.46889 .30512 L
.46965 .30529 L
.47049 .30555 L
.47218 .30628 L
.47374 .30719 L
.47542 .30839 L
.47873 .31118 L
.48193 .31388 L
.48339 .31491 L
.48422 .31541 L
.485 .3158 L
.48577 .3161 L
.48619 .31624 L
.48659 .31633 L
.48698 .3164 L
.48709 .31642 L
.4872 .31643 L
.48731 .31644 L
.48741 .31645 L
.48752 .31645 L
.48758 .31646 L
.48764 .31646 L
.48775 .31646 L
.48781 .31646 L
.48786 .31646 L
.48797 .31646 L
.48806 .31645 L
.48811 .31645 L
.48817 .31645 L
.48827 .31644 L
.48848 .31642 L
.4887 .31639 L
.4891 .3163 L
.48949 .31619 L
.48985 .31607 L
.49067 .31568 L
.49154 .31514 L
.49311 .31378 L
.49459 .31213 L
.49771 .30768 L
.50103 .30246 L
.50269 .30012 L
.50423 .29833 L
.505 .29763 L
.50572 .2971 L
.50612 .29687 L
Mistroke
.50648 .29671 L
.50688 .29657 L
.50709 .29651 L
.50719 .29649 L
.50731 .29647 L
.50742 .29645 L
.50752 .29644 L
.50761 .29644 L
.50771 .29643 L
.5078 .29643 L
.50789 .29643 L
.50798 .29644 L
.50808 .29645 L
.50818 .29646 L
.5083 .29648 L
.5085 .29652 L
.50871 .29657 L
.50889 .29664 L
.50927 .2968 L
.50961 .297 L
.51037 .29757 L
.51118 .2984 L
.51192 .29936 L
.51359 .30218 L
.51677 .3095 L
.51982 .31761 L
.52152 .32183 L
.52307 .32507 L
.52384 .32638 L
.52468 .32753 L
.52506 .32795 L
.52547 .32832 L
.52582 .32857 L
.5262 .32877 L
.5264 .32885 L
.52651 .32888 L
.52661 .3289 L
.52672 .32892 L
.52681 .32893 L
.52691 .32894 L
.52701 .32894 L
.5271 .32893 L
.5272 .32892 L
.52728 .32891 L
.52737 .32889 L
.52757 .32884 L
.52775 .32876 L
.52797 .32865 L
.52818 .32852 L
.52856 .32821 L
Mistroke
.52898 .32778 L
.52943 .32719 L
.53018 .32595 L
.53102 .3242 L
.5327 .31953 L
.53593 .30742 L
.53903 .29441 L
.54061 .28849 L
.54144 .28579 L
.54233 .28333 L
.5432 .28145 L
.54398 .28022 L
.54436 .2798 L
.54457 .27962 L
.54477 .27948 L
.54494 .27939 L
.54504 .27935 L
.54513 .27932 L
.54523 .2793 L
.54531 .27929 L
.54542 .27928 L
.54551 .27928 L
.54561 .27929 L
.54567 .2793 L
.54572 .27931 L
.54582 .27934 L
.54592 .27938 L
.54609 .27947 L
.54628 .2796 L
.54649 .27977 L
.54671 .28001 L
.5471 .28054 L
.54788 .282 L
.54858 .2838 L
.55011 .28924 L
.55178 .29721 L
.55506 .31688 L
.55669 .32711 L
.55821 .33594 L
.55969 .34308 L
.5605 .34617 L
.56125 .34843 L
.56165 .34939 L
.56202 .35008 L
.56243 .35066 L
.56266 .35088 L
.56276 .35096 L
.56287 .35103 L
.56296 .35107 L
.56305 .35111 L
Mistroke
.56314 .35113 L
.56324 .35114 L
.56333 .35114 L
.56342 .35113 L
.5635 .35111 L
.56358 .35108 L
.56367 .35104 L
.56378 .35098 L
.56398 .35081 L
.56417 .3506 L
.56435 .35036 L
.56473 .3497 L
.56514 .34876 L
.56597 .34614 L
.56674 .34289 L
.56746 .33918 L
.57059 .31658 L
.57391 .28696 L
.57558 .27318 L
.57631 .26786 L
.57712 .26271 L
.57784 .25886 L
.57861 .25561 L
.57904 .25424 L
.57943 .25328 L
.57962 .25292 L
.57983 .25259 L
.57992 .25247 L
.58002 .25236 L
.58011 .25228 L
.5802 .25221 L
.5803 .25216 L
.58035 .25213 L
.58041 .25212 L
.58047 .2521 L
.58053 .2521 L
.58063 .25211 L
.58073 .25213 L
.58082 .25217 L
.58092 .25224 L
.58103 .25233 L
.58125 .25258 L
.58145 .25291 L
.58168 .25337 L
.58192 .25397 L
.58233 .25526 L
.58276 .25698 L
.58354 .26096 L
.58512 .27251 L
.5866 .28676 L
Mistroke
.58973 .32368 L
.59133 .34285 L
.59306 .36118 L
.59387 .36826 L
.59473 .37442 L
.59547 .37842 L
.59588 .38014 L
.59627 .38135 L
.59648 .38185 L
.59667 .3822 L
.59678 .38236 L
.59688 .38248 L
.59694 .38254 L
.597 .38259 L
.59706 .38262 L
.59711 .38265 L
.5972 .38268 L
.59731 .38269 L
.59741 .38267 L
.59747 .38264 L
.59752 .38261 L
.59762 .38254 L
.59772 .38243 L
.5979 .38217 L
.59808 .38183 L
.59828 .38135 L
.59868 .38006 L
.59904 .37848 L
.59939 .37667 L
.60018 .37134 L
.60101 .36404 L
.6025 .34714 L
.60556 .30171 L
.60727 .2746 L
.60882 .2521 L
.6096 .24231 L
.61044 .23322 L
.61123 .22635 L
.61196 .22159 L
.61233 .21985 L
.61252 .21913 L
.61272 .21848 L
.61284 .21817 L
.61295 .21793 L
.61305 .21774 L
.61316 .21757 L
.61326 .21746 L
.61335 .21738 L
.61345 .21734 L
.61351 .21733 L
Mistroke
.61356 .21733 L
.61366 .21735 L
.61376 .21742 L
.61386 .21751 L
.61395 .21763 L
.61417 .21805 L
.61438 .2186 L
.6146 .21933 L
.6148 .22016 L
.61525 .22254 L
.61603 .22831 L
.61675 .23555 L
.61841 .25796 L
.62152 .31545 L
.62311 .34697 L
.62484 .37831 L
.62564 .39068 L
.62649 .40178 L
.62729 .40997 L
.62764 .41275 L
.62802 .41524 L
.62842 .41717 L
.62863 .41795 L
.62873 .41825 L
.62883 .4185 L
.62892 .41869 L
.62902 .41885 L
.62911 .41896 L
.62919 .41904 L
.62928 .41909 L
.62937 .4191 L
.62948 .41906 L
.62957 .41899 L
.62967 .41887 L
.62978 .4187 L
.62989 .41846 L
.62999 .41818 L
.63038 .41675 L
.6306 .41563 L
.63079 .41443 L
.63124 .41109 L
.63204 .40295 L
.63278 .39311 L
.63445 .36369 L
.63762 .29086 L
.64066 .22293 L
.64146 .20894 L
.64222 .19796 L
.64264 .19298 L
.6431 .1885 L
Mistroke
.64352 .18532 L
.6439 .18316 L
.64411 .1823 L
.64431 .18172 L
.64441 .1815 L
.64453 .18132 L
.64458 .18126 L
.64464 .18121 L
.6447 .18118 L
.64475 .18118 L
.64485 .1812 L
.64495 .18127 L
.64505 .18141 L
.64511 .1815 L
.64516 .18162 L
.64536 .18218 L
.64555 .1829 L
.64593 .18491 L
.64627 .18743 L
.64705 .1954 L
.64784 .20668 L
.64857 .21977 L
.65023 .25731 L
.65337 .34403 L
.65498 .38672 L
.65582 .40639 L
.65671 .42413 L
.65751 .43682 L
.65793 .44216 L
.65839 .44675 L
.6586 .44849 L
.6588 .44988 L
.659 .451 L
.65918 .45181 L
.65936 .45238 L
.65944 .4526 L
.65954 .45279 L
.65964 .45291 L
.65974 .45298 L
.65984 .45298 L
.65993 .45293 L
.66003 .4528 L
.66013 .45263 L
.66021 .45241 L
.66031 .45213 L
.66052 .45128 L
.66071 .45024 L
.66107 .44772 L
.66145 .44418 L
.66224 .43389 L
Mistroke
.66311 .41836 L
.66467 .38102 L
.66634 .33121 L
.66793 .28031 L
.66966 .22752 L
.67046 .20601 L
.67131 .18623 L
.67211 .17126 L
.67285 .16098 L
.67325 .15687 L
.67345 .15521 L
.67367 .15377 L
.67379 .15315 L
.67389 .15266 L
.674 .15226 L
.6741 .15195 L
.67422 .15169 L
.67428 .15159 L
.67434 .15151 L
.6744 .15147 L
.67445 .15145 L
.67451 .15146 L
.67457 .15149 L
.67467 .1516 L
.67477 .15177 L
.67487 .15204 L
.67498 .15241 L
.67521 .15346 L
.67541 .15474 L
.67581 .15809 L
.67619 .16229 L
.67697 .1742 L
.6778 .19114 L
.67928 .23102 L
.68232 .33502 L
.68402 .39242 L
.68557 .43578 L
.68633 .45236 L
.68674 .45953 L
.68717 .46588 L
.68754 .47027 L
.68774 .47216 L
.68795 .47386 L
.68815 .47509 L
.68824 .47553 L
.68833 .47594 L
.68841 .47624 L
.6885 .47651 L
.6886 .47672 L
.68868 .47685 L
Mistroke
.68878 .47692 L
.68884 .47692 L
.68889 .47691 L
.689 .4768 L
.68906 .4767 L
.68911 .47658 L
.68921 .47631 L
.68931 .47593 L
.68951 .47501 L
.68973 .47355 L
.68997 .47155 L
.6904 .46681 L
.69083 .46049 L
.69124 .45322 L
.69201 .4364 L
.69362 .38939 L
.69511 .33638 L
.69675 .27389 L
.69828 .21901 L
.69975 .17562 L
.70057 .15722 L
.70133 .1449 L
.70171 .14037 L
.70192 .13843 L
.70212 .13695 L
.70229 .13597 L
.70247 .13519 L
.70257 .13489 L
.70267 .13466 L
.70276 .13454 L
.70286 .1345 L
.70291 .1345 L
.70297 .13454 L
.70303 .13461 L
.70308 .13469 L
.70317 .13491 L
.70328 .13524 L
.70339 .13569 L
.70349 .13621 L
.70372 .13775 L
.70411 .14134 L
.70453 .14664 L
.70534 .16115 L
.70623 .18273 L
.70784 .23458 L
.71111 .36244 L
.71262 .41645 L
.71341 .44017 L
.71425 .46052 L
.71468 .46881 L
Mistroke
.71515 .47612 L
.71536 .47873 L
.71558 .48109 L
.71578 .48291 L
.71598 .48424 L
.71618 .48531 L
.71629 .4857 L
.71635 .48586 L
.71641 .486 L
.71651 .48616 L
.71661 .48622 L
.71667 .48621 L
.71672 .48617 L
.71682 .48603 L
.71692 .48582 L
.71702 .4855 L
.71719 .4847 L
.7174 .48336 L
.7176 .48179 L
.71799 .47755 L
.7184 .47156 L
.71914 .45718 L
.71994 .43687 L
.72081 .40957 L
.72405 .28265 L
.72555 .2246 L
.72717 .17321 L
.7276 .16265 L
.72806 .15306 L
.72848 .14575 L
.72888 .14035 L
.72925 .13663 L
.72945 .1351 L
.72965 .13407 L
.72975 .13366 L
.72984 .13337 L
.72995 .13315 L
.73001 .13307 L
.73006 .13303 L
.73011 .13302 L
.73017 .13303 L
.73022 .13307 L
.73028 .13316 L
.73038 .13337 L
.73044 .13354 L
.73049 .13372 L
.7307 .1347 L
.73089 .13597 L
.7311 .13777 L
.73133 .14015 L
Mistroke
.73174 .14581 L
.73212 .15227 L
.73289 .16916 L
.73361 .18921 L
.7367 .30528 L
.73828 .36869 L
.73911 .39934 L
.74 .42814 L
.74086 .45077 L
.74164 .46619 L
.74202 .47167 L
.74221 .47403 L
.74243 .47613 L
.74261 .47761 L
.74271 .47826 L
.74281 .47886 L
.74291 .47932 L
.743 .47965 L
.74308 .4799 L
.74317 .48009 L
.74327 .48021 L
.74333 .48024 L
.74338 .48023 L
.74347 .48016 L
.74357 .47998 L
.74366 .47974 L
.74375 .47944 L
.74394 .4785 L
.74414 .47709 L
.74433 .47545 L
.74476 .47052 L
.74512 .46499 L
.74551 .45764 L
.74623 .44095 L
.74782 .39136 L
.7495 .32632 L
.75111 .26206 L
.75195 .23077 L
.75284 .20153 L
.75365 .17959 L
.75407 .16995 L
.75452 .16132 L
.75494 .15497 L
.75532 .1506 L
.75551 .14898 L
.75571 .14758 L
.7558 .14707 L
.75589 .14661 L
.75598 .14627 L
.75607 .14602 L
Mistroke
.75616 .14582 L
.75627 .1457 L
.75636 .14569 L
.75646 .14577 L
.75656 .14593 L
.75665 .14618 L
.75673 .14647 L
.75682 .14685 L
.75703 .14804 L
.75725 .14972 L
.75764 .15386 L
.758 .15895 L
.75834 .16475 L
.7591 .18146 L
.76074 .23059 L
.76223 .28579 L
.76389 .34977 L
.76543 .40236 L
.76619 .42383 L
.76692 .44011 L
.76731 .44719 L
.76767 .45251 L
.76807 .45707 L
.76828 .45887 L
.76839 .45963 L
.7685 .46033 L
.76861 .46087 L
.76871 .46127 L
.7688 .46157 L
.7689 .4618 L
.76899 .46192 L
.76908 .46196 L
.76917 .46193 L
.76927 .46182 L
.76937 .46159 L
.76943 .46142 L
.76949 .46122 L
.7697 .46025 L
.76988 .45901 L
.77009 .45733 L
.77048 .45294 L
.77086 .44753 L
.77156 .43431 L
.77235 .41512 L
.77318 .39069 L
.77466 .33968 L
.77771 .23274 L
.77852 .21012 L
.77928 .19264 L
.7797 .18484 L
Mistroke
.78016 .178 L
.78036 .17554 L
.78058 .17332 L
.78076 .17173 L
.78096 .17034 L
.78115 .16935 L
.78126 .16894 L
.78135 .16866 L
.78144 .16846 L
.78153 .16835 L
.78162 .1683 L
.78171 .16833 L
.78181 .16844 L
.78192 .16866 L
.78201 .16892 L
.7821 .16929 L
.78232 .17041 L
.78253 .17184 L
.7829 .17535 L
.78323 .17956 L
.78399 .19234 L
.78479 .21012 L
.78552 .22998 L
.78719 .28302 L
.78881 .33793 L
.79034 .38406 L
.79105 .4017 L
.79179 .4168 L
.79219 .4231 L
.79261 .42865 L
.7928 .43062 L
.793 .43241 L
.79318 .43368 L
.79337 .4348 L
.79347 .43526 L
.79357 .43567 L
.79363 .43585 L
.79369 .43599 L
.79374 .43611 L
.79379 .4362 L
.79389 .4363 L
.79399 .43633 L
.79409 .43627 L
.79419 .43613 L
.79425 .43601 L
.7943 .43587 L
.79443 .43546 L
.79454 .43499 L
.79465 .43438 L
.79486 .43305 L
Mistroke
.79508 .43125 L
.79548 .427 L
.79585 .42195 L
.79669 .40683 L
.7984 .36404 L
.80002 .31497 L
.80148 .27062 L
.80231 .24794 L
.80309 .22951 L
.80386 .21488 L
.80425 .20884 L
.80468 .20348 L
.80511 .1995 L
.80534 .19791 L
.80546 .1973 L
.80556 .19681 L
.80566 .19643 L
.80577 .19611 L
.80586 .19589 L
.80595 .19575 L
.80605 .19567 L
.80615 .19566 L
.80621 .19569 L
.80627 .19574 L
.80637 .19591 L
.80642 .19603 L
.80648 .19617 L
.80657 .19648 L
.80679 .19743 L
.80698 .19854 L
.80718 .20004 L
.80764 .20454 L
.80807 .20998 L
.80885 .22307 L
.80968 .24053 L
.81274 .32201 L
.81444 .36506 L
.81524 .38152 L
.81599 .39361 L
.81635 .39833 L
.81676 .40252 L
.81716 .40563 L
.81739 .40685 L
.81749 .40729 L
.8176 .40768 L
.8177 .40798 L
.81779 .40819 L
.81788 .40833 L
.81798 .40842 L
.81807 .40844 L
Mistroke
.81816 .40841 L
.81824 .40833 L
.81833 .40819 L
.81842 .40799 L
.81853 .40769 L
.81874 .40685 L
.81893 .40581 L
.81912 .40461 L
.81952 .4012 L
.81995 .39635 L
.82075 .38471 L
.82224 .35502 L
.82379 .31768 L
.82551 .27659 L
.82629 .26017 L
.82713 .24518 L
.82752 .23943 L
.82793 .23425 L
.82831 .23031 L
.82866 .22736 L
.82885 .22607 L
.82906 .22493 L
.82925 .22413 L
.82943 .22359 L
.82952 .22338 L
.82962 .22323 L
.82972 .22312 L
.82977 .22309 L
.82982 .22308 L
.82993 .2231 L
.82999 .22315 L
.83004 .22321 L
.83014 .22337 L
.83024 .2236 L
.83044 .2242 L
.83064 .22509 L
.83102 .22736 L
.83138 .23035 L
.83172 .23373 L
.8325 .24385 L
.83323 .2557 L
.83489 .28855 L
.83639 .32062 L
.83802 .3518 L
.8389 .36513 L
.83929 .36991 L
.83972 .37433 L
.84013 .37762 L
.84051 .37993 L
.84072 .38087 L
Mistroke
.84091 .38152 L
.84101 .38178 L
.84112 .38201 L
.84117 .38209 L
.84123 .38217 L
.84129 .38222 L
.84134 .38225 L
.84144 .38228 L
.84153 .38225 L
.84162 .38218 L
.84173 .38204 L
.84178 .38195 L
.84184 .38183 L
.84195 .38157 L
.84214 .38092 L
.84233 .38012 L
.84253 .37908 L
.84288 .3767 L
.84368 .36924 L
.84455 .35795 L
.84778 .30166 L
.84926 .27673 L
.8501 .26517 L
.85051 .26044 L
.85088 .25672 L
.85125 .25359 L
.85165 .2509 L
.85188 .24974 L
.85208 .24887 L
.85228 .24823 L
.85238 .24795 L
.85248 .24775 L
.85259 .24758 L
.85268 .24747 L
.85279 .24741 L
.85285 .24739 L
.8529 .24739 L
.853 .24743 L
.85309 .2475 L
.85319 .24763 L
.85329 .2478 L
.8534 .24804 L
.85351 .24835 L
.85372 .24905 L
.85393 .25001 L
.85418 .25132 L
.855 .25754 L
.85574 .26537 L
.85742 .2884 L
.85908 .31429 L
Mistroke
.86062 .3362 L
.86139 .34516 L
.86211 .35187 L
.86251 .35474 L
.86287 .35686 L
.86327 .35861 L
.86348 .35928 L
.86358 .35955 L
.8637 .35979 L
.8638 .35996 L
.8639 .36008 L
.864 .36016 L
.8641 .3602 L
.86419 .3602 L
.86427 .36017 L
.86436 .36011 L
.86446 .36001 L
.86457 .35985 L
.86468 .35964 L
.86489 .35911 L
.86509 .35844 L
.86528 .35767 L
.866 .35361 L
.8664 .3506 L
.86676 .34745 L
.86998 .30875 L
.87146 .29049 L
.87229 .28176 L
.87308 .27521 L
.87347 .27255 L
.87385 .2705 L
.87406 .26956 L
.87428 .26871 L
.87449 .26809 L
.87468 .26763 L
.87479 .26744 L
.87488 .26729 L
.87499 .26716 L
.87505 .26711 L
.87511 .26707 L
.87516 .26704 L
.87522 .26703 L
.87532 .26702 L
.87539 .26704 L
.87545 .26707 L
.8755 .2671 L
.87556 .26715 L
.87566 .26726 L
.87577 .26742 L
.87598 .26785 L
Mistroke
.87618 .26839 L
.87637 .26901 L
.87677 .2707 L
.87721 .27307 L
.878 .27867 L
.87949 .29257 L
.88105 .30929 L
.88276 .32649 L
.88355 .33281 L
.88396 .33561 L
.88439 .33811 L
.88477 .3399 L
.88497 .34069 L
.88518 .34142 L
.88538 .34197 L
.88556 .34237 L
.88574 .34269 L
.88583 .34281 L
.88591 .3429 L
.88601 .34298 L
.88611 .34304 L
.8862 .34307 L
.88629 .34307 L
.88639 .34305 L
.88648 .34301 L
.88658 .34293 L
.88669 .34281 L
.8868 .34267 L
.88692 .34247 L
.88713 .34203 L
.88752 .3409 L
.88789 .33944 L
.88829 .33755 L
.889 .33333 L
.89205 .30809 L
.89375 .29436 L
.89455 .28921 L
.8953 .28553 L
.89567 .28413 L
.89607 .28298 L
.89627 .28253 L
.89646 .2822 L
.89657 .28205 L
.89667 .28193 L
.89673 .28188 L
.89679 .28183 L
.89685 .28179 L
.8969 .28176 L
.897 .28172 L
.8971 .28171 L
Mistroke
.8972 .28172 L
.89728 .28175 L
.89738 .2818 L
.89748 .28187 L
.89759 .28198 L
.89769 .2821 L
.89804 .28271 L
.89824 .28318 L
.89842 .28367 L
.89921 .2866 L
.89995 .29029 L
.90162 .30105 L
.90313 .31183 L
.90476 .32207 L
.9052 .32428 L
.90566 .32629 L
.90609 .32784 L
.90649 .32899 L
.90686 .3298 L
.90707 .33014 L
.90726 .33038 L
.90737 .33048 L
.90747 .33056 L
.90758 .33062 L
.90763 .33064 L
.90769 .33066 L
.9078 .33067 L
.90785 .33067 L
.90791 .33067 L
.90801 .33064 L
.90811 .33059 L
.90821 .33053 L
.90831 .33044 L
.90851 .33022 L
.9087 .32994 L
.90888 .32963 L
.90927 .32873 L
.9097 .32749 L
.9104 .32486 L
.91117 .32128 L
.91287 .31195 L
.91442 .30336 L
.91518 .29964 L
.91602 .29629 L
.9164 .29505 L
.91681 .29395 L
.91715 .2932 L
.91754 .29258 L
.91773 .29236 L
.91793 .29218 L
Mistroke
.91804 .29212 L
.91809 .29209 L
.91815 .29207 L
.91825 .29204 L
.91835 .29202 L
.91844 .29202 L
.91853 .29203 L
.91861 .29206 L
.9187 .29209 L
.9188 .29214 L
.9189 .29222 L
.91909 .29238 L
.91931 .29264 L
.91954 .29299 L
.91997 .29382 L
.92076 .29599 L
.92235 .30202 L
.92403 .30958 L
.92564 .31615 L
.92654 .31901 L
.92697 .32008 L
.92737 .32089 L
.92773 .32146 L
.92792 .32169 L
.92812 .3219 L
.92823 .32199 L
.92834 .32206 L
.92844 .32212 L
.92855 .32217 L
.92865 .3222 L
.92874 .32222 L
.92883 .32222 L
.92894 .32222 L
.92904 .3222 L
.92914 .32217 L
.92925 .32213 L
.92936 .32207 L
.92959 .32189 L
.9298 .32168 L
.93021 .32114 L
.93059 .32047 L
.93137 .31868 L
.9322 .31628 L
.93368 .31122 L
.93527 .30574 L
.93597 .30364 L
.93673 .30171 L
.93714 .30084 L
.93753 .30017 L
.9379 .29965 L
Mistroke
.93829 .29924 L
.93849 .29909 L
.93859 .29902 L
.9387 .29897 L
.9388 .29893 L
.9389 .29889 L
.939 .29887 L
.93909 .29886 L
.93914 .29886 L
.9392 .29886 L
.93926 .29886 L
.93931 .29886 L
.93941 .29888 L
.93951 .29891 L
.93963 .29895 L
.93973 .299 L
.93997 .29915 L
.94018 .29932 L
.94037 .29951 L
.9408 .30005 L
.9416 .30141 L
.94308 .30492 L
.94459 .30903 L
.94622 .31311 L
.94712 .31483 L
.94751 .31543 L
.94794 .31597 L
.94814 .31617 L
.94835 .31635 L
.94853 .31648 L
.94873 .31659 L
.94885 .31665 L
.94896 .31669 L
.94906 .31672 L
.94911 .31673 L
.94917 .31674 L
.94926 .31675 L
.94936 .31676 L
.94941 .31676 L
.94946 .31676 L
.94956 .31675 L
.94966 .31674 L
.94972 .31672 L
.94977 .31671 L
.94997 .31664 L
.95014 .31656 L
.95033 .31645 L
.95072 .31614 L
.95115 .31568 L
.95191 .31462 L
Mistroke
.95262 .31339 L
.95574 .30704 L
.95655 .30562 L
.95698 .30498 L
.95744 .3044 L
.95788 .30393 L
.95828 .3036 L
.95847 .30348 L
.95868 .30337 L
.95887 .30328 L
.95906 .30323 L
.95916 .3032 L
.95925 .30319 L
.95934 .30318 L
.95943 .30317 L
.95954 .30317 L
.95959 .30317 L
.95964 .30317 L
.95974 .30318 L
.95984 .3032 L
.95993 .30322 L
.96002 .30324 L
.96019 .3033 L
.96037 .30338 L
.96057 .30349 L
.96099 .30377 L
.96143 .30417 L
.96223 .30509 L
.96383 .30745 L
.96557 .31018 L
.96638 .3113 L
.96724 .31227 L
.96797 .31288 L
.96818 .31301 L
.96839 .31312 L
.96858 .31321 L
.96878 .31328 L
.96899 .31334 L
.9691 .31336 L
.9692 .31338 L
.9693 .31339 L
.96939 .31339 L
.96949 .3134 L
.9696 .31339 L
.9697 .31339 L
.96976 .31338 L
.96982 .31337 L
.96992 .31336 L
.97002 .31334 L
.97024 .31328 L
Mistroke
.97048 .31319 L
.97089 .31299 L
.97132 .31271 L
.9721 .31205 L
.97514 .30857 L
.97619 .30743 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{421.375, 260.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 525.688}, {324.5, 0}} -> {-2.58312*^-7, -6.34248*^6, \
6.65005*^-9, 53093.5}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0.309017 5.42214e-08 [
[.32684 .29652 -16.5 -12.5 ]
[.32684 .29652 16.5 0 ]
[.54329 .29652 -16.5 -12.5 ]
[.54329 .29652 16.5 0 ]
[.75974 .29652 -22.5 -12.5 ]
[.75974 .29652 22.5 0 ]
[.97619 .29652 -16.5 -12.5 ]
[.97619 .29652 16.5 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 64 6 ]
[.09789 .09213 -34.5 -6.25 ]
[.09789 .09213 0 6.25 ]
[.09789 .20057 -34.5 -6.25 ]
[.09789 .20057 0 6.25 ]
[.09789 .41746 -28.5 -6.25 ]
[.09789 .41746 0 6.25 ]
[.09789 .5259 -28.5 -6.25 ]
[.09789 .5259 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -65.8125 0 ]
[.5 .63053 65.8125 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 .30902 m
.32684 .31527 L
s
gsave
.32684 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 .30902 m
.54329 .31527 L
s
gsave
.54329 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 .30902 m
.75974 .31527 L
s
gsave
.75974 .29652 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 .30902 m
.15368 .31277 L
s
.19697 .30902 m
.19697 .31277 L
s
.24026 .30902 m
.24026 .31277 L
s
.28355 .30902 m
.28355 .31277 L
s
.37013 .30902 m
.37013 .31277 L
s
.41342 .30902 m
.41342 .31277 L
s
.45671 .30902 m
.45671 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.58658 .30902 m
.58658 .31277 L
s
.62987 .30902 m
.62987 .31277 L
s
.67316 .30902 m
.67316 .31277 L
s
.71645 .30902 m
.71645 .31277 L
s
.80303 .30902 m
.80303 .31277 L
s
.84632 .30902 m
.84632 .31277 L
s
.88961 .30902 m
.88961 .31277 L
s
.9329 .30902 m
.9329 .31277 L
s
.0671 .30902 m
.0671 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09213 m
.11664 .09213 L
s
gsave
.09789 .09213 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .20057 m
.11664 .20057 L
s
gsave
.09789 .20057 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .41746 m
.11664 .41746 L
s
gsave
.09789 .41746 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .5259 m
.11664 .5259 L
s
gsave
.09789 .5259 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.11039 .11924 m
.11414 .11924 L
s
.11039 .14635 m
.11414 .14635 L
s
.11039 .17346 m
.11414 .17346 L
s
.11039 .22768 m
.11414 .22768 L
s
.11039 .2548 m
.11414 .2548 L
s
.11039 .28191 m
.11414 .28191 L
s
.11039 .33613 m
.11414 .33613 L
s
.11039 .36324 m
.11414 .36324 L
s
.11039 .39035 m
.11414 .39035 L
s
.11039 .44457 m
.11414 .44457 L
s
.11039 .47168 m
.11414 .47168 L
s
.11039 .49879 m
.11414 .49879 L
s
.11039 .06502 m
.11414 .06502 L
s
.11039 .03791 m
.11414 .03791 L
s
.11039 .0108 m
.11414 .0108 L
s
.11039 .55301 m
.11414 .55301 L
s
.11039 .58012 m
.11414 .58012 L
s
.11039 .60723 m
.11414 .60723 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -126.812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.812 moveto
(@) show
81.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.812 moveto
(D) show
93.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12.4) show
141.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
147.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
159.000 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
163.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
172.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
190.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02691 .30902 L
.03029 .30902 L
.03347 .30902 L
.03652 .30902 L
.03978 .30902 L
.04291 .30902 L
.04623 .30902 L
.04944 .30902 L
.05252 .30902 L
.0558 .30902 L
.05896 .30902 L
.062 .30902 L
.06523 .30902 L
.06834 .30902 L
.07165 .30902 L
.07484 .30902 L
.0779 .30902 L
.08117 .30902 L
.08431 .30902 L
.08765 .30902 L
.09086 .30902 L
.09396 .30902 L
.09725 .30902 L
.10042 .30902 L
.10346 .30902 L
.10503 .30902 L
.1059 .30902 L
.10671 .30902 L
.1071 .30902 L
.10753 .30902 L
.10773 .30902 L
.10796 .30902 L
.10808 .30902 L
.10819 .30902 L
.1083 .30902 L
.10841 .30902 L
.10852 .30902 L
.10861 .30902 L
.1087 .30902 L
.10879 .30902 L
.10889 .30902 L
.10899 .30902 L
.10909 .30902 L
.1092 .30902 L
.1094 .30902 L
.1096 .30902 L
.1098 .30902 L
.11003 .30902 L
.11045 .30902 L
Mistroke
.11084 .30902 L
.11173 .30902 L
.11251 .30902 L
.11334 .30902 L
.11417 .30902 L
.11506 .30902 L
.11668 .30902 L
.11829 .30902 L
.11998 .30902 L
.12156 .30902 L
.12303 .30902 L
.12616 .30902 L
.12787 .30902 L
.12948 .30902 L
.13256 .30902 L
.13584 .30902 L
.139 .30902 L
.14203 .30902 L
.14526 .30902 L
.14837 .30902 L
.15168 .30902 L
.15486 .30902 L
.15793 .30902 L
.16119 .30902 L
.16432 .30902 L
.16766 .30902 L
.17087 .30902 L
.17397 .30902 L
.17725 .30902 L
.17889 .30902 L
.18042 .30902 L
.18189 .30902 L
.18271 .30902 L
.18347 .30902 L
.18385 .30902 L
.18406 .30902 L
.18426 .30902 L
.18444 .30902 L
.18461 .30902 L
.1848 .30902 L
.18489 .30902 L
.185 .30902 L
.1851 .30902 L
.1852 .30902 L
.18525 .30902 L
.1853 .30902 L
.18541 .30902 L
.1855 .30902 L
.18561 .30902 L
.18569 .30902 L
Mistroke
.18579 .30902 L
.18601 .30902 L
.18624 .30902 L
.18666 .30902 L
.18708 .30902 L
.18747 .30902 L
.18836 .30902 L
.18914 .30902 L
.18997 .30902 L
.1908 .30902 L
.19169 .30902 L
.19331 .30902 L
.19491 .30902 L
.1966 .30902 L
.19965 .30902 L
.20122 .30902 L
.2029 .30902 L
.20622 .30902 L
.20942 .30902 L
.2125 .30902 L
.21578 .30902 L
.21893 .30902 L
.22196 .30902 L
.22519 .30902 L
.2283 .30902 L
.22987 .30902 L
.2316 .30902 L
.2324 .30902 L
.23325 .30902 L
.23405 .30902 L
.23478 .30902 L
.23517 .30902 L
.23537 .30902 L
.23558 .30902 L
.23577 .30902 L
.23587 .30902 L
.23597 .30902 L
.23605 .30902 L
.23615 .30902 L
.23624 .30902 L
.23632 .30902 L
.23643 .30902 L
.23649 .30902 L
.23654 .30902 L
.23664 .30902 L
.23675 .30902 L
.23693 .30902 L
.23713 .30902 L
.23758 .30902 L
.23799 .30902 L
Mistroke
.2384 .30902 L
.23883 .30902 L
.23963 .30902 L
.24041 .30902 L
.24112 .30902 L
.24262 .30902 L
.24428 .30902 L
.24584 .30902 L
.24751 .30902 L
.25082 .30902 L
.25401 .30902 L
.25707 .30902 L
.26033 .30902 L
.26347 .30902 L
.26681 .30902 L
.27002 .30902 L
.2715 .30902 L
.27312 .30902 L
.27389 .30902 L
.27472 .30902 L
.27517 .30902 L
.27559 .30902 L
.27599 .30902 L
.2762 .30902 L
.27641 .30902 L
.2766 .30902 L
.27679 .30902 L
.27688 .30902 L
.27699 .30902 L
.27709 .30902 L
.27715 .30902 L
.2772 .30902 L
.2773 .30902 L
.27739 .30902 L
.27747 .30902 L
.27756 .30902 L
.27765 .30902 L
.27776 .30902 L
.27794 .30902 L
.27814 .30902 L
.27835 .30902 L
.27873 .30902 L
.27919 .30902 L
.2796 .30902 L
.2804 .30902 L
.28113 .30902 L
.28194 .30902 L
.2828 .30902 L
.28452 .30902 L
.28614 .30902 L
Mistroke
.28923 .30902 L
.29253 .30902 L
.2957 .30902 L
.29875 .30901 L
.302 .30901 L
.30513 .30901 L
.30672 .30901 L
.30845 .30901 L
.30926 .30901 L
.31011 .30901 L
.31084 .30901 L
.31126 .30901 L
.31165 .30901 L
.31183 .30901 L
.31203 .30901 L
.31214 .30901 L
.31224 .30901 L
.31234 .30901 L
.31244 .30901 L
.31249 .30901 L
.31255 .30901 L
.31265 .30901 L
.3127 .30901 L
.31276 .30901 L
.31282 .30901 L
.31287 .30901 L
.31297 .30901 L
.31303 .30901 L
.31308 .30901 L
.31317 .30901 L
.31327 .30901 L
.31345 .30901 L
.31362 .30901 L
.31399 .30901 L
.31439 .30901 L
.31476 .30901 L
.31554 .30901 L
.31628 .30901 L
.31708 .30901 L
.31794 .30901 L
.31965 .30901 L
.32126 .30901 L
.32435 .30902 L
.32763 .30902 L
.33079 .30903 L
.33383 .30904 L
.33706 .30904 L
.33855 .30904 L
.34017 .30905 L
.34105 .30905 L
Mistroke
.34187 .30905 L
.34265 .30905 L
.34309 .30905 L
.34328 .30905 L
.34348 .30905 L
.34368 .30905 L
.34387 .30905 L
.34398 .30905 L
.34407 .30905 L
.34413 .30905 L
.34418 .30905 L
.34429 .30905 L
.34438 .30905 L
.34447 .30905 L
.34458 .30905 L
.34467 .30905 L
.34476 .30905 L
.34484 .30905 L
.34503 .30905 L
.34523 .30905 L
.34542 .30905 L
.34584 .30905 L
.34626 .30905 L
.3467 .30905 L
.34752 .30905 L
.34841 .30905 L
.35003 .30904 L
.35163 .30904 L
.35332 .30903 L
.35636 .30901 L
.3596 .30899 L
.36271 .30896 L
.36603 .30893 L
.36768 .30892 L
.36922 .30891 L
.36999 .30891 L
.37071 .3089 L
.37111 .3089 L
.37154 .3089 L
.37193 .3089 L
.37229 .3089 L
.37249 .3089 L
.37267 .3089 L
.37277 .3089 L
.37282 .3089 L
.37288 .3089 L
.37298 .3089 L
.37307 .3089 L
.37316 .3089 L
.37325 .3089 L
Mistroke
.37334 .3089 L
.37342 .3089 L
.37351 .3089 L
.37362 .3089 L
.3738 .3089 L
.37402 .3089 L
.37422 .3089 L
.37466 .3089 L
.37508 .3089 L
.37546 .30891 L
.37625 .30891 L
.37707 .30892 L
.37856 .30893 L
.38013 .30895 L
.3816 .30897 L
.38472 .30904 L
.38804 .30912 L
.39124 .30921 L
.39431 .30929 L
.3959 .30932 L
.39671 .30933 L
.39713 .30934 L
.39758 .30934 L
.39797 .30935 L
.3984 .30935 L
.39858 .30935 L
.39878 .30935 L
.39897 .30935 L
.39914 .30935 L
.39924 .30935 L
.39933 .30935 L
.39943 .30935 L
.39949 .30935 L
.39954 .30935 L
.39963 .30935 L
.39972 .30935 L
.39982 .30935 L
.39991 .30935 L
.4 .30935 L
.40009 .30935 L
.40025 .30935 L
.40044 .30935 L
.40061 .30935 L
.401 .30935 L
.40142 .30934 L
.40216 .30933 L
.40296 .30932 L
.40383 .3093 L
.4054 .30925 L
.40708 .30918 L
Mistroke
.4104 .30899 L
.4136 .30876 L
.41668 .30853 L
.41824 .30842 L
.41995 .30831 L
.42074 .30827 L
.42158 .30824 L
.42238 .30821 L
.42276 .3082 L
.42311 .30819 L
.42349 .30819 L
.4237 .30819 L
.4239 .30818 L
.42398 .30818 L
.42408 .30818 L
.42416 .30818 L
.42425 .30818 L
.42434 .30818 L
.42444 .30818 L
.42454 .30818 L
.42463 .30818 L
.42473 .30818 L
.42479 .30818 L
.42484 .30818 L
.42504 .30818 L
.42515 .30819 L
.42527 .30819 L
.42548 .30819 L
.4259 .3082 L
.42629 .30821 L
.42708 .30824 L
.42781 .30827 L
.42861 .30832 L
.42947 .30839 L
.43118 .30856 L
.43279 .30877 L
.43588 .30926 L
.43916 .30986 L
.44079 .31015 L
.44231 .31039 L
.44387 .31061 L
.44464 .31069 L
.44535 .31076 L
.44613 .31081 L
.44654 .31083 L
.44675 .31084 L
.44698 .31085 L
.44718 .31085 L
.44728 .31086 L
.44738 .31086 L
Mistroke
.44747 .31086 L
.44756 .31086 L
.44766 .31086 L
.44776 .31086 L
.44785 .31086 L
.44795 .31086 L
.44804 .31086 L
.44813 .31086 L
.4482 .31086 L
.44829 .31086 L
.44846 .31085 L
.44865 .31085 L
.44886 .31084 L
.44927 .31082 L
.44966 .3108 L
.45002 .31077 L
.45082 .31068 L
.45169 .31056 L
.4534 .31024 L
.45502 .30982 L
.45811 .30878 L
.46139 .30749 L
.46302 .30686 L
.46455 .30632 L
.46611 .30586 L
.46688 .30568 L
.46759 .30554 L
.46837 .30543 L
.46878 .30539 L
.46901 .30537 L
.46922 .30536 L
.46941 .30535 L
.46951 .30534 L
.46959 .30534 L
.46968 .30534 L
.46978 .30534 L
.46988 .30534 L
.46999 .30534 L
.47008 .30534 L
.47018 .30534 L
.47028 .30534 L
.47037 .30534 L
.47053 .30535 L
.47071 .30536 L
.4709 .30537 L
.4711 .30539 L
.47146 .30543 L
.47185 .30549 L
.47228 .30557 L
.47304 .30574 L
Mistroke
.47374 .30596 L
.47539 .30662 L
.47688 .30741 L
.48009 .3096 L
.48319 .31202 L
.48475 .31318 L
.48647 .31431 L
.48726 .31474 L
.48811 .31513 L
.48891 .31542 L
.48926 .31552 L
.48964 .31561 L
.49003 .31568 L
.49024 .31571 L
.49044 .31573 L
.49053 .31574 L
.49062 .31574 L
.4907 .31575 L
.49079 .31575 L
.49088 .31576 L
.49099 .31576 L
.49108 .31576 L
.49117 .31575 L
.49127 .31575 L
.49133 .31575 L
.49138 .31574 L
.49158 .31573 L
.49169 .31572 L
.49181 .3157 L
.49203 .31567 L
.49245 .31558 L
.49284 .31548 L
.49363 .31518 L
.49436 .31481 L
.49603 .31362 L
.49767 .31202 L
.49917 .31025 L
.50238 .30582 L
.50548 .30158 L
.50705 .2998 L
.50788 .29903 L
.50877 .29836 L
.50921 .2981 L
.50963 .2979 L
.51001 .29776 L
.5102 .2977 L
.51041 .29765 L
.51061 .29761 L
.5107 .2976 L
.5108 .29759 L
Mistroke
.5109 .29758 L
.511 .29757 L
.5111 .29757 L
.51115 .29757 L
.51121 .29757 L
.5113 .29757 L
.51139 .29758 L
.51148 .29758 L
.51156 .29759 L
.51176 .29762 L
.51194 .29766 L
.51232 .29777 L
.51272 .29794 L
.5131 .29814 L
.51345 .29837 L
.5143 .29908 L
.51511 .29997 L
.5167 .30228 L
.51818 .30501 L
.52132 .31213 L
.52467 .32001 L
.52635 .32332 L
.52708 .32452 L
.52789 .32561 L
.52827 .32603 L
.52867 .32642 L
.52902 .32669 L
.5294 .32693 L
.52962 .32704 L
.52983 .32712 L
.53002 .32717 L
.53012 .3272 L
.53018 .32721 L
.53023 .32721 L
.53033 .32722 L
.53042 .32723 L
.53052 .32723 L
.53062 .32723 L
.53071 .32722 L
.53081 .32721 L
.5309 .32719 L
.53099 .32717 L
.53118 .32711 L
.53138 .32703 L
.53179 .3268 L
.53218 .3265 L
.53253 .32616 L
.53334 .32513 L
.5342 .32365 L
.53591 .31966 L
Mistroke
.53752 .31473 L
.5406 .30341 L
.54215 .29745 L
.54387 .29136 L
.54551 .28654 L
.54623 .28487 L
.54702 .2834 L
.54739 .28287 L
.54778 .2824 L
.54799 .28219 L
.54819 .28203 L
.54837 .28191 L
.54857 .2818 L
.54867 .28176 L
.54879 .28173 L
.54889 .2817 L
.54898 .28169 L
.54904 .28168 L
.5491 .28168 L
.5492 .28168 L
.54926 .28169 L
.54931 .28169 L
.54937 .28171 L
.54943 .28172 L
.54954 .28175 L
.54965 .2818 L
.54986 .2819 L
.55006 .28204 L
.55025 .2822 L
.55062 .28261 L
.55103 .28319 L
.55176 .28458 L
.55263 .2868 L
.55342 .28934 L
.55662 .3039 L
.5597 .32148 L
.56126 .33016 L
.56297 .33845 L
.56376 .34155 L
.5646 .34429 L
.56499 .34532 L
.5654 .34622 L
.56578 .3469 L
.56613 .34738 L
.56632 .34759 L
.56653 .34776 L
.56662 .34782 L
.56672 .34787 L
.56681 .34791 L
.5669 .34793 L
Mistroke
.56695 .34795 L
.567 .34795 L
.5671 .34796 L
.56721 .34795 L
.56727 .34794 L
.56732 .34793 L
.56741 .3479 L
.56751 .34785 L
.56762 .34779 L
.56772 .34772 L
.5679 .34756 L
.56809 .34735 L
.56843 .34686 L
.56879 .34616 L
.56919 .34521 L
.57001 .34261 L
.57076 .33954 L
.57244 .33034 L
.57565 .30638 L
.57873 .28126 L
.58029 .27035 L
.58112 .26555 L
.58201 .26135 L
.58245 .2597 L
.58286 .25841 L
.58324 .25748 L
.58345 .25706 L
.58364 .25673 L
.58384 .25647 L
.58403 .25629 L
.58413 .25621 L
.58422 .25616 L
.58433 .25612 L
.58438 .2561 L
.58444 .25609 L
.58453 .25609 L
.58462 .2561 L
.58472 .25614 L
.58482 .25618 L
.5849 .25624 L
.58499 .25631 L
.58517 .2565 L
.58537 .25677 L
.58554 .25708 L
.58594 .25799 L
.5863 .25903 L
.58667 .26037 L
.58746 .26404 L
.58832 .26927 L
.5899 .28177 L
Mistroke
.59158 .29846 L
.59491 .33576 L
.59658 .35297 L
.59731 .35954 L
.59812 .36582 L
.59884 .37047 L
.59962 .3743 L
.60005 .37585 L
.60044 .37691 L
.60063 .37728 L
.60073 .37745 L
.60083 .3776 L
.60094 .37772 L
.60103 .3778 L
.60112 .37787 L
.60121 .37791 L
.6013 .37794 L
.6014 .37794 L
.6015 .37792 L
.60158 .37788 L
.60168 .37781 L
.60179 .37771 L
.60199 .37745 L
.6022 .37706 L
.60242 .37654 L
.60282 .37528 L
.60319 .37379 L
.60353 .37209 L
.60431 .36716 L
.6051 .36071 L
.60593 .35249 L
.60742 .33466 L
.61048 .29051 L
.61219 .26593 L
.61374 .2466 L
.61452 .23863 L
.61536 .23162 L
.61574 .22903 L
.61615 .22675 L
.6165 .22519 L
.61688 .2239 L
.61708 .2234 L
.61719 .22319 L
.6173 .22301 L
.6174 .22288 L
.61745 .22283 L
.6175 .22278 L
.6176 .22272 L
.6177 .22269 L
.61779 .22269 L
Mistroke
.61789 .22272 L
.61799 .22279 L
.61809 .22288 L
.61818 .223 L
.61826 .22312 L
.61844 .22349 L
.61866 .22406 L
.61886 .22473 L
.61931 .22671 L
.6197 .229 L
.62012 .23198 L
.62088 .23874 L
.62169 .24788 L
.62316 .26871 L
.62647 .32804 L
.62812 .35819 L
.62966 .3826 L
.63042 .39267 L
.63114 .40055 L
.63154 .40417 L
.63197 .40745 L
.63234 .40967 L
.63273 .41148 L
.63293 .4122 L
.63312 .4127 L
.63321 .41289 L
.63331 .41306 L
.6334 .41319 L
.63349 .41327 L
.63359 .41333 L
.63368 .41334 L
.63379 .41332 L
.63384 .41329 L
.6339 .41324 L
.634 .41313 L
.63411 .41296 L
.63422 .41273 L
.63433 .41246 L
.63455 .41176 L
.63476 .41091 L
.63515 .40883 L
.63557 .4059 L
.63602 .40191 L
.63678 .39342 L
.63762 .38163 L
.63931 .3512 L
.64255 .27925 L
.64404 .24678 L
.64566 .21688 L
.64655 .20429 L
Mistroke
.64698 .19929 L
.64737 .19546 L
.64774 .1924 L
.64815 .18985 L
.64837 .18879 L
.64858 .18804 L
.64877 .18751 L
.64887 .18732 L
.64892 .18723 L
.64898 .18716 L
.64908 .18707 L
.64918 .18704 L
.64929 .18705 L
.64935 .18709 L
.6494 .18714 L
.6495 .18726 L
.64959 .18743 L
.6497 .18767 L
.6498 .18795 L
.65016 .18938 L
.65036 .19048 L
.65055 .19169 L
.65136 .19897 L
.65182 .20445 L
.65223 .21026 L
.65377 .23841 L
.65545 .27782 L
.65874 .36508 L
.66037 .40318 L
.66117 .41844 L
.6619 .42987 L
.66227 .43456 L
.66266 .43887 L
.663 .44191 L
.66337 .44451 L
.66358 .44558 L
.66377 .44635 L
.66387 .44667 L
.66397 .44693 L
.66403 .44705 L
.66409 .44715 L
.66419 .44728 L
.66429 .44734 L
.66438 .44735 L
.66449 .44729 L
.66459 .44718 L
.66468 .44702 L
.66476 .44683 L
.66495 .44624 L
.66515 .44539 L
Mistroke
.66533 .44442 L
.66573 .44152 L
.6661 .43796 L
.66646 .43383 L
.66725 .42202 L
.66811 .40537 L
.67138 .31696 L
.67452 .22368 L
.67535 .20318 L
.67625 .18451 L
.67666 .17734 L
.67709 .17084 L
.6775 .1658 L
.67786 .16212 L
.67805 .1606 L
.67826 .15922 L
.67843 .15825 L
.67863 .15743 L
.67873 .15709 L
.67883 .15685 L
.67894 .15666 L
.679 .15659 L
.67905 .15655 L
.67914 .15653 L
.67924 .15657 L
.67935 .15668 L
.67944 .15686 L
.67954 .15709 L
.67964 .15741 L
.67982 .15816 L
.67999 .15912 L
.68016 .16019 L
.68053 .16332 L
.68092 .16764 L
.68168 .17893 L
.68249 .19505 L
.68396 .2331 L
.68728 .3425 L
.68894 .39592 L
.68967 .41653 L
.69047 .43628 L
.69119 .45067 L
.69196 .46241 L
.69239 .46705 L
.69257 .46866 L
.69278 .47011 L
.69297 .4712 L
.69315 .47195 L
.69325 .47226 L
.69334 .47247 L
Mistroke
.69345 .47263 L
.69355 .47271 L
.69364 .47271 L
.69374 .47264 L
.69383 .4725 L
.69392 .47231 L
.69402 .47201 L
.69413 .4716 L
.69432 .47061 L
.69453 .46925 L
.69475 .46743 L
.69515 .46321 L
.69593 .45153 L
.69663 .43727 L
.69818 .39534 L
.69985 .33825 L
.70142 .28014 L
.70314 .21983 L
.70393 .19573 L
.70478 .17369 L
.70558 .1572 L
.70593 .1515 L
.70631 .14631 L
.7067 .14226 L
.70691 .14057 L
.70711 .13932 L
.7072 .13886 L
.70729 .13846 L
.70737 .13817 L
.70746 .13792 L
.70755 .13773 L
.70764 .13762 L
.70775 .13758 L
.70784 .13762 L
.70795 .13776 L
.708 .13786 L
.70806 .138 L
.70816 .13832 L
.70825 .13871 L
.70847 .13985 L
.7087 .14152 L
.70912 .14575 L
.70951 .15091 L
.7103 .16523 L
.71104 .18265 L
.7127 .23431 L
.71585 .35472 L
.71745 .41189 L
.7183 .43706 L
.71919 .45856 L
Mistroke
.71958 .46605 L
.71999 .47271 L
.72023 .47589 L
.72044 .47836 L
.72066 .48044 L
.72087 .48198 L
.72105 .48306 L
.72115 .48349 L
.72125 .48387 L
.72135 .48415 L
.72144 .48432 L
.7215 .48439 L
.72156 .48442 L
.72166 .48442 L
.72175 .48433 L
.72185 .48415 L
.72194 .48391 L
.72202 .48363 L
.72222 .48267 L
.72241 .48142 L
.72278 .47803 L
.72319 .47288 L
.72402 .4581 L
.72479 .43958 L
.7255 .41858 L
.72862 .30088 L
.73021 .23831 L
.73105 .20858 L
.73194 .18112 L
.73273 .16132 L
.73315 .15277 L
.7336 .14521 L
.73402 .13989 L
.7342 .13805 L
.73439 .13638 L
.73458 .13514 L
.73476 .13428 L
.73485 .13393 L
.73494 .13369 L
.73504 .13351 L
.73514 .13342 L
.73523 .13342 L
.73533 .13351 L
.73542 .13369 L
.73551 .13392 L
.73561 .13428 L
.73572 .13478 L
.73592 .13598 L
.73613 .13763 L
.73635 .13983 L
Mistroke
.73674 .14492 L
.73752 .15891 L
.73823 .17587 L
.73977 .225 L
.74144 .2901 L
.74301 .35394 L
.74474 .41645 L
.74553 .43975 L
.74597 .45065 L
.74638 .45956 L
.74676 .46656 L
.74718 .47267 L
.74736 .47486 L
.74756 .47684 L
.74773 .47824 L
.74791 .47947 L
.7481 .48041 L
.74821 .48078 L
.7483 .48102 L
.74839 .48116 L
.74848 .48122 L
.74857 .48121 L
.74866 .48112 L
.74876 .48093 L
.74887 .48062 L
.74895 .48028 L
.74905 .47981 L
.74927 .47843 L
.74947 .47674 L
.74984 .47266 L
.75018 .46783 L
.75094 .45328 L
.75174 .4331 L
.75247 .41049 L
.75414 .34922 L
.75728 .22605 L
.75811 .19902 L
.75901 .1749 L
.75942 .16588 L
.75985 .15792 L
.76022 .15245 L
.76063 .1479 L
.76083 .14621 L
.76094 .14548 L
.76105 .14482 L
.76115 .14435 L
.76126 .14393 L
.76136 .14366 L
.76145 .14349 L
.76155 .1434 L
Mistroke
.76164 .1434 L
.76172 .14347 L
.76181 .14362 L
.76191 .14387 L
.76201 .14423 L
.7622 .14516 L
.76242 .14666 L
.76265 .14879 L
.76308 .15398 L
.7635 .16061 L
.76388 .16803 L
.76539 .20824 L
.76705 .26705 L
.76875 .33338 L
.77029 .3898 L
.77106 .41375 L
.7719 .43541 L
.77228 .44356 L
.77269 .45088 L
.77304 .45611 L
.77342 .46039 L
.7736 .46205 L
.77381 .46348 L
.7739 .46399 L
.77399 .46444 L
.77408 .46479 L
.77417 .46504 L
.77427 .46526 L
.77433 .46534 L
.77439 .46539 L
.77448 .4654 L
.77454 .46536 L
.77459 .4653 L
.77469 .46512 L
.77478 .46488 L
.77488 .4645 L
.77498 .46406 L
.77516 .46302 L
.77534 .4616 L
.77568 .45823 L
.77608 .4529 L
.77645 .44686 L
.77725 .42968 L
.77799 .40978 L
.77967 .35426 L
.78131 .29319 L
.78284 .23933 L
.78431 .19766 L
.78474 .18834 L
.78514 .18081 L
Mistroke
.78553 .17478 L
.78589 .1703 L
.78626 .16695 L
.78646 .16567 L
.78656 .16514 L
.78667 .16468 L
.78678 .16433 L
.78688 .16409 L
.78693 .16401 L
.78698 .16395 L
.78704 .16392 L
.7871 .16392 L
.7872 .16398 L
.78729 .16411 L
.78739 .16435 L
.78749 .1647 L
.78767 .1655 L
.78786 .16667 L
.7882 .16957 L
.7886 .17434 L
.78897 .17987 L
.78977 .19537 L
.7905 .21362 L
.79217 .26513 L
.79379 .32162 L
.79532 .37185 L
.79677 .41035 L
.79717 .41856 L
.79759 .42594 L
.79798 .43152 L
.79834 .43568 L
.79854 .43743 L
.79874 .43897 L
.79893 .44005 L
.79911 .44077 L
.79921 .44106 L
.7993 .44125 L
.7994 .44139 L
.79945 .44142 L
.79951 .44143 L
.79961 .44138 L
.79967 .44131 L
.79972 .44122 L
.79982 .44099 L
.79993 .44066 L
.80012 .43981 L
.80032 .43854 L
.8007 .43534 L
.80106 .43113 L
.8014 .42635 L
Mistroke
.80218 .41204 L
.80291 .39514 L
.80457 .34749 L
.8077 .25041 L
.80851 .22958 L
.8094 .21125 L
.80981 .2046 L
.81024 .19884 L
.81061 .19505 L
.8108 .19347 L
.81102 .19209 L
.81112 .19157 L
.81122 .1911 L
.81131 .19076 L
.81141 .19047 L
.81147 .19034 L
.81152 .19024 L
.81163 .19012 L
.81173 .19008 L
.81183 .19012 L
.81192 .19022 L
.81201 .1904 L
.8121 .19063 L
.81218 .1909 L
.81238 .19178 L
.81257 .1929 L
.81299 .19631 L
.81337 .20062 L
.81425 .21418 L
.8151 .23184 L
.8159 .25162 L
.81739 .29364 L
.81887 .33631 L
.81971 .35859 L
.82049 .37692 L
.82133 .39315 L
.8221 .4042 L
.82252 .4086 L
.82291 .41162 L
.82313 .4128 L
.82333 .41358 L
.82344 .41387 L
.8235 .414 L
.82355 .41409 L
.82361 .41417 L
.82368 .41422 L
.82373 .41425 L
.82379 .41425 L
.82389 .4142 L
.82395 .41413 L
Mistroke
.824 .41406 L
.82409 .41386 L
.82419 .41359 L
.82437 .41294 L
.82456 .41197 L
.82476 .41066 L
.82498 .40893 L
.82538 .405 L
.82615 .39448 L
.82685 .38197 L
.83005 .30453 L
.83151 .26852 L
.83234 .25089 L
.83313 .23717 L
.83389 .22697 L
.83432 .22277 L
.83452 .22117 L
.83471 .21993 L
.83492 .21885 L
.8351 .21811 L
.83521 .21778 L
.83531 .21755 L
.83536 .21745 L
.83542 .21737 L
.83548 .2173 L
.83553 .21726 L
.83564 .21724 L
.83569 .21726 L
.83575 .21729 L
.83585 .21741 L
.83595 .21758 L
.83606 .21786 L
.83616 .2182 L
.8364 .21921 L
.83661 .22042 L
.83681 .22178 L
.83725 .22569 L
.83805 .23557 L
.83878 .24729 L
.83954 .26194 L
.84259 .3299 L
.84347 .34786 L
.84429 .36256 L
.84504 .37327 L
.84542 .37775 L
.84584 .38179 L
.84604 .38333 L
.84625 .38474 L
.84643 .38576 L
.84663 .38665 L
Mistroke
.84684 .38735 L
.84696 .38762 L
.84701 .38773 L
.84707 .3878 L
.84717 .38791 L
.84726 .38796 L
.84736 .38796 L
.84741 .38793 L
.84747 .38789 L
.84755 .38779 L
.84765 .38763 L
.84773 .38743 L
.84781 .38721 L
.84801 .38653 L
.8482 .38568 L
.84857 .38343 L
.84897 .38016 L
.84972 .37192 L
.85055 .35999 L
.85224 .32955 L
.85392 .29639 L
.85546 .26937 L
.85624 .25848 L
.85697 .2506 L
.85734 .24755 L
.85773 .245 L
.85795 .24389 L
.85817 .24308 L
.85836 .24254 L
.85846 .24231 L
.85856 .24216 L
.85866 .24206 L
.85876 .242 L
.85884 .24199 L
.85894 .24203 L
.85904 .24211 L
.85909 .24218 L
.85914 .24226 L
.85925 .24245 L
.85934 .24267 L
.85952 .24322 L
.85971 .24399 L
.86007 .24585 L
.86045 .24852 L
.86087 .25219 L
.86172 .26171 L
.86497 .31316 L
.86646 .33668 L
.86725 .34703 L
.86809 .35576 L
Mistroke
.86851 .35915 L
.86873 .36065 L
.86898 .36204 L
.8692 .36309 L
.8694 .36387 L
.86959 .36445 L
.8697 .3647 L
.8698 .36488 L
.86989 .36503 L
.86999 .36512 L
.87009 .36518 L
.87014 .3652 L
.8702 .3652 L
.87028 .36518 L
.87038 .36512 L
.87047 .36501 L
.87057 .36487 L
.87068 .36467 L
.87078 .36442 L
.87097 .36384 L
.87118 .36303 L
.87141 .36196 L
.87184 .35938 L
.87224 .35634 L
.87299 .34921 L
.87468 .32811 L
.87778 .28548 L
.87861 .27649 L
.87938 .2699 L
.87977 .26732 L
.88019 .26515 L
.88043 .2642 L
.88065 .26349 L
.88085 .26301 L
.88097 .26281 L
.88107 .26267 L
.88117 .26257 L
.88127 .26251 L
.88135 .26249 L
.88145 .26249 L
.88155 .26253 L
.8816 .26257 L
.88165 .26262 L
.88175 .26274 L
.88185 .26288 L
.88203 .26325 L
.8822 .26369 L
.88257 .26506 L
.88296 .26693 L
.88338 .26953 L
Mistroke
.88423 .27631 L
.88747 .31276 L
.88897 .32904 L
.88975 .33603 L
.89059 .34177 L
.89101 .3439 L
.89124 .34482 L
.89148 .34564 L
.8917 .34623 L
.89179 .34644 L
.8919 .34664 L
.89199 .34679 L
.89209 .34691 L
.8922 .34701 L
.8923 .34707 L
.89235 .34709 L
.8924 .34711 L
.8925 .3471 L
.89256 .34709 L
.89261 .34706 L
.89267 .34703 L
.89273 .34698 L
.89284 .34686 L
.89295 .34672 L
.89314 .34636 L
.89333 .34589 L
.89351 .34537 L
.89391 .34385 L
.89432 .34186 L
.89476 .33924 L
.89556 .33342 L
.89705 .3199 L
.89862 .30445 L
.89946 .29681 L
.90035 .28966 L
.90121 .28418 L
.90161 .28216 L
.90199 .28065 L
.90236 .27948 L
.90256 .27902 L
.90277 .27864 L
.90286 .27851 L
.90296 .2784 L
.90304 .27832 L
.90313 .27826 L
.90323 .27821 L
.90333 .27818 L
.90343 .27819 L
.90352 .27821 L
.90362 .27827 L
Mistroke
.90367 .27831 L
.90373 .27836 L
.90392 .27859 L
.90403 .27876 L
.90415 .27898 L
.90436 .27946 L
.90478 .28071 L
.90516 .2822 L
.90593 .28608 L
.90665 .2907 L
.90973 .31461 L
.91131 .32532 L
.91177 .32773 L
.91219 .32966 L
.91258 .33108 L
.91278 .33171 L
.913 .33229 L
.91321 .33277 L
.9134 .33312 L
.9136 .33339 L
.91369 .33348 L
.91378 .33357 L
.91388 .33363 L
.91394 .33366 L
.91399 .33368 L
.91408 .3337 L
.91418 .33371 L
.91423 .3337 L
.9143 .33368 L
.91435 .33366 L
.91441 .33364 L
.91451 .33357 L
.91461 .33348 L
.9148 .33325 L
.91501 .33292 L
.91539 .33211 L
.91576 .33105 L
.9161 .32987 L
.91761 .32252 L
.91926 .31211 L
.92096 .30148 L
.92177 .2972 L
.92251 .29395 L
.92328 .29146 L
.92368 .29054 L
.92389 .29017 L
.92411 .28986 L
.92421 .28975 L
.92431 .28966 L
.9244 .28959 L
Mistroke
.92449 .28953 L
.92459 .28949 L
.92468 .28946 L
.92474 .28945 L
.92479 .28945 L
.9249 .28946 L
.92499 .28948 L
.92508 .28952 L
.92516 .28956 L
.92525 .28962 L
.92545 .28981 L
.92563 .29004 L
.92603 .29073 L
.92647 .29175 L
.92726 .29429 L
.92875 .30083 L
.93046 .30966 L
.93201 .31701 L
.93279 .31996 L
.9332 .32124 L
.93363 .32237 L
.93401 .32316 L
.93421 .3235 L
.93443 .32381 L
.93463 .32403 L
.93481 .32418 L
.93489 .32424 L
.93499 .32429 L
.93508 .32433 L
.93516 .32435 L
.93525 .32437 L
.93535 .32437 L
.93544 .32436 L
.93553 .32434 L
.93563 .32431 L
.93574 .32425 L
.93593 .32412 L
.93613 .32393 L
.93631 .32371 L
.93666 .32317 L
.93707 .32235 L
.93745 .32142 L
.93831 .31881 L
.94148 .30634 L
.9423 .30336 L
.94307 .30094 L
.94377 .29922 L
.94413 .29852 L
.94452 .2979 L
.94471 .29766 L
Mistroke
.94492 .29745 L
.94503 .29736 L
.94513 .29728 L
.94524 .29722 L
.94534 .29717 L
.94542 .29714 L
.94551 .29711 L
.94561 .29709 L
.9457 .29709 L
.9458 .29709 L
.9459 .2971 L
.946 .29713 L
.94609 .29716 L
.94619 .2972 L
.94629 .29726 L
.94648 .29739 L
.9467 .29759 L
.9469 .29783 L
.94735 .29847 L
.94777 .29924 L
.94936 .3033 L
.95083 .30796 L
.95234 .31259 L
.95314 .31465 L
.95398 .31638 L
.9544 .31706 L
.95463 .31735 L
.95487 .31762 L
.95509 .31783 L
.9553 .31797 L
.95539 .31803 L
.9555 .31808 L
.95559 .31812 L
.95569 .31816 L
.95579 .31818 L
.95589 .31819 L
.95594 .3182 L
.956 .3182 L
.9561 .3182 L
.95615 .31819 L
.95621 .31819 L
.95631 .31816 L
.95637 .31815 L
.95643 .31813 L
.95654 .31809 L
.95673 .31798 L
.95691 .31786 L
.95731 .31749 L
.95769 .31704 L
.95809 .31645 L
Mistroke
.95882 .31513 L
.96048 .31131 L
.96206 .30741 L
.9629 .30558 L
.96379 .30396 L
.96424 .30331 L
.96466 .30281 L
.96504 .30247 L
.96524 .30232 L
.96545 .3022 L
.96555 .30215 L
.96565 .30211 L
.96574 .30208 L
.96584 .30205 L
.9659 .30204 L
.96595 .30203 L
.96605 .30202 L
.96615 .30201 L
.96625 .30201 L
.96634 .30202 L
.96643 .30203 L
.96652 .30205 L
.9666 .30207 L
.9668 .30213 L
.96698 .30222 L
.96739 .30248 L
.96775 .3028 L
.96857 .30378 L
.97005 .30621 L
.97172 .30939 L
.97246 .31072 L
.97326 .31201 L
.97395 .31292 L
.97469 .31366 L
.97509 .31396 L
.97546 .31415 L
.97564 .31422 L
.97574 .31424 L
.97584 .31427 L
.97592 .31429 L
.97602 .3143 L
.97611 .31431 L
.97619 .31431 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{421.375, 260.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 525.688}, {324.5, 0}} -> {-2.58312*^-7, -6.34248*^6, \
6.65005*^-9, 53093.5}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0.309017 5.42214e-08 [
[.32684 .29652 -16.5 -12.5 ]
[.32684 .29652 16.5 0 ]
[.54329 .29652 -16.5 -12.5 ]
[.54329 .29652 16.5 0 ]
[.75974 .29652 -22.5 -12.5 ]
[.75974 .29652 22.5 0 ]
[.97619 .29652 -16.5 -12.5 ]
[.97619 .29652 16.5 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 64 6 ]
[.09789 .09213 -34.5 -6.25 ]
[.09789 .09213 0 6.25 ]
[.09789 .20057 -34.5 -6.25 ]
[.09789 .20057 0 6.25 ]
[.09789 .41746 -28.5 -6.25 ]
[.09789 .41746 0 6.25 ]
[.09789 .5259 -28.5 -6.25 ]
[.09789 .5259 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -65.8125 0 ]
[.5 .63053 65.8125 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 .30902 m
.32684 .31527 L
s
gsave
.32684 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 .30902 m
.54329 .31527 L
s
gsave
.54329 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 .30902 m
.75974 .31527 L
s
gsave
.75974 .29652 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 .30902 m
.15368 .31277 L
s
.19697 .30902 m
.19697 .31277 L
s
.24026 .30902 m
.24026 .31277 L
s
.28355 .30902 m
.28355 .31277 L
s
.37013 .30902 m
.37013 .31277 L
s
.41342 .30902 m
.41342 .31277 L
s
.45671 .30902 m
.45671 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.58658 .30902 m
.58658 .31277 L
s
.62987 .30902 m
.62987 .31277 L
s
.67316 .30902 m
.67316 .31277 L
s
.71645 .30902 m
.71645 .31277 L
s
.80303 .30902 m
.80303 .31277 L
s
.84632 .30902 m
.84632 .31277 L
s
.88961 .30902 m
.88961 .31277 L
s
.9329 .30902 m
.9329 .31277 L
s
.0671 .30902 m
.0671 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09213 m
.11664 .09213 L
s
gsave
.09789 .09213 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .20057 m
.11664 .20057 L
s
gsave
.09789 .20057 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .41746 m
.11664 .41746 L
s
gsave
.09789 .41746 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .5259 m
.11664 .5259 L
s
gsave
.09789 .5259 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.11039 .11924 m
.11414 .11924 L
s
.11039 .14635 m
.11414 .14635 L
s
.11039 .17346 m
.11414 .17346 L
s
.11039 .22768 m
.11414 .22768 L
s
.11039 .2548 m
.11414 .2548 L
s
.11039 .28191 m
.11414 .28191 L
s
.11039 .33613 m
.11414 .33613 L
s
.11039 .36324 m
.11414 .36324 L
s
.11039 .39035 m
.11414 .39035 L
s
.11039 .44457 m
.11414 .44457 L
s
.11039 .47168 m
.11414 .47168 L
s
.11039 .49879 m
.11414 .49879 L
s
.11039 .06502 m
.11414 .06502 L
s
.11039 .03791 m
.11414 .03791 L
s
.11039 .0108 m
.11414 .0108 L
s
.11039 .55301 m
.11414 .55301 L
s
.11039 .58012 m
.11414 .58012 L
s
.11039 .60723 m
.11414 .60723 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -126.812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.812 moveto
(@) show
81.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.812 moveto
(D) show
93.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12.6) show
141.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
147.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
159.000 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
163.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
172.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
190.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02691 .30902 L
.03029 .30902 L
.03347 .30902 L
.03652 .30902 L
.03978 .30902 L
.04291 .30902 L
.04623 .30902 L
.04944 .30902 L
.05252 .30902 L
.0558 .30902 L
.05896 .30902 L
.062 .30902 L
.06523 .30902 L
.06834 .30902 L
.07165 .30902 L
.07484 .30902 L
.0779 .30902 L
.08117 .30902 L
.08431 .30902 L
.08765 .30902 L
.09086 .30902 L
.09396 .30902 L
.09725 .30902 L
.09889 .30902 L
.10042 .30902 L
.10198 .30902 L
.10275 .30902 L
.10346 .30902 L
.10384 .30902 L
.10425 .30902 L
.10466 .30902 L
.10477 .30902 L
.10489 .30902 L
.105 .30902 L
.1051 .30902 L
.10519 .30902 L
.10528 .30902 L
.10538 .30902 L
.10548 .30902 L
.10557 .30902 L
.10563 .30902 L
.10568 .30902 L
.10578 .30902 L
.10587 .30902 L
.10605 .30902 L
.10621 .30902 L
.10639 .30902 L
.10659 .30902 L
.10701 .30902 L
Mistroke
.1074 .30902 L
.10783 .30902 L
.10829 .30902 L
.10913 .30902 L
.1099 .30902 L
.11145 .30902 L
.11232 .30902 L
.11312 .30902 L
.11463 .30902 L
.11629 .30902 L
.11786 .30902 L
.11954 .30902 L
.12125 .30902 L
.12287 .30902 L
.12595 .30902 L
.12754 .30902 L
.12923 .30902 L
.13226 .30902 L
.13549 .30902 L
.1386 .30902 L
.14191 .30902 L
.14509 .30902 L
.14816 .30902 L
.15142 .30902 L
.15455 .30902 L
.15789 .30902 L
.1611 .30902 L
.16419 .30902 L
.16748 .30902 L
.17065 .30902 L
.17369 .30902 L
.17694 .30902 L
.18006 .30902 L
.18087 .30902 L
.18176 .30902 L
.1826 .30902 L
.18297 .30902 L
.18337 .30902 L
.18357 .30902 L
.18378 .30902 L
.18397 .30902 L
.18415 .30902 L
.18431 .30902 L
.18441 .30902 L
.18449 .30902 L
.18459 .30902 L
.18469 .30902 L
.18478 .30902 L
.18487 .30902 L
.18497 .30902 L
Mistroke
.18507 .30902 L
.18516 .30902 L
.18525 .30902 L
.18547 .30902 L
.18567 .30902 L
.18608 .30902 L
.18631 .30902 L
.18652 .30902 L
.18693 .30902 L
.18737 .30902 L
.18817 .30902 L
.18895 .30902 L
.18967 .30902 L
.19118 .30902 L
.19284 .30902 L
.1944 .30902 L
.19608 .30902 L
.19768 .30902 L
.19941 .30902 L
.20261 .30902 L
.20588 .30902 L
.20903 .30902 L
.21207 .30902 L
.21529 .30902 L
.2184 .30902 L
.2217 .30902 L
.22489 .30902 L
.22795 .30902 L
.22965 .30902 L
.2312 .30902 L
.23284 .30902 L
.23355 .30902 L
.23434 .30902 L
.23509 .30902 L
.2355 .30902 L
.23588 .30902 L
.23599 .30902 L
.2361 .30902 L
.2362 .30902 L
.2363 .30902 L
.23641 .30902 L
.2365 .30902 L
.2366 .30902 L
.23669 .30902 L
.23679 .30902 L
.23685 .30902 L
.2369 .30902 L
.23701 .30902 L
.2371 .30902 L
.23732 .30902 L
Mistroke
.23744 .30902 L
.23755 .30902 L
.23794 .30902 L
.23835 .30902 L
.2387 .30902 L
.23909 .30902 L
.23995 .30902 L
.24076 .30902 L
.24159 .30902 L
.24238 .30902 L
.24387 .30902 L
.24546 .30902 L
.24693 .30902 L
.25007 .30902 L
.25341 .30902 L
.25662 .30902 L
.25972 .30902 L
.26301 .30902 L
.26618 .30902 L
.26922 .30902 L
.27247 .30902 L
.27396 .30902 L
.27559 .30902 L
.27602 .30902 L
.27647 .30902 L
.2769 .30902 L
.27729 .30902 L
.27747 .30902 L
.27766 .30902 L
.27776 .30902 L
.27787 .30902 L
.27797 .30902 L
.27806 .30902 L
.27811 .30902 L
.27817 .30902 L
.27827 .30902 L
.27833 .30902 L
.27839 .30902 L
.27844 .30902 L
.2785 .30902 L
.2786 .30902 L
.27866 .30902 L
.27871 .30902 L
.27891 .30902 L
.27901 .30902 L
.27911 .30902 L
.27929 .30902 L
.2797 .30902 L
.28005 .30902 L
.28043 .30902 L
Mistroke
.2813 .30902 L
.2821 .30902 L
.28288 .30902 L
.28361 .30902 L
.28527 .30902 L
.28691 .30902 L
.2884 .30902 L
.2916 .30902 L
.29468 .30902 L
.29795 .30901 L
.30111 .30901 L
.30414 .30901 L
.30737 .30901 L
.30886 .30901 L
.31048 .30901 L
.31126 .30901 L
.31209 .30901 L
.31255 .30901 L
.31297 .30901 L
.31317 .30901 L
.31339 .30901 L
.3136 .30901 L
.31379 .30901 L
.31389 .30901 L
.31398 .30901 L
.31407 .30901 L
.31416 .30901 L
.31426 .30901 L
.31432 .30901 L
.31437 .30901 L
.31447 .30901 L
.31457 .30901 L
.31466 .30901 L
.31475 .30901 L
.31492 .30901 L
.3151 .30901 L
.3153 .30901 L
.31571 .30901 L
.31615 .30901 L
.31695 .30901 L
.31777 .30901 L
.31866 .30901 L
.32028 .30901 L
.32187 .30901 L
.32356 .30901 L
.3266 .30902 L
.32983 .30902 L
.33295 .30903 L
.33626 .30903 L
.33944 .30904 L
Mistroke
.34105 .30904 L
.34251 .30904 L
.34327 .30905 L
.34409 .30905 L
.34454 .30905 L
.34496 .30905 L
.34535 .30905 L
.34555 .30905 L
.34567 .30905 L
.34577 .30905 L
.34587 .30905 L
.34597 .30905 L
.34608 .30905 L
.34614 .30905 L
.34619 .30905 L
.34629 .30905 L
.34639 .30905 L
.34649 .30905 L
.34659 .30905 L
.34678 .30905 L
.34695 .30905 L
.34734 .30905 L
.34756 .30905 L
.34776 .30905 L
.34815 .30905 L
.34902 .30905 L
.3498 .30904 L
.35062 .30904 L
.35211 .30904 L
.35368 .30903 L
.35515 .30903 L
.35826 .30901 L
.36158 .30899 L
.36477 .30897 L
.36784 .30894 L
.36956 .30893 L
.37111 .30892 L
.37189 .30892 L
.37273 .30892 L
.37312 .30892 L
.37352 .30892 L
.3739 .30891 L
.37425 .30891 L
.37445 .30891 L
.37455 .30891 L
.37465 .30891 L
.37474 .30891 L
.37484 .30891 L
.37493 .30891 L
.37502 .30891 L
Mistroke
.37512 .30891 L
.37522 .30891 L
.37531 .30891 L
.37541 .30891 L
.37547 .30891 L
.37552 .30891 L
.37563 .30891 L
.37574 .30891 L
.37583 .30891 L
.37601 .30891 L
.3762 .30891 L
.37654 .30891 L
.37691 .30892 L
.37731 .30892 L
.37813 .30892 L
.37887 .30892 L
.38055 .30894 L
.38208 .30895 L
.38375 .30898 L
.38702 .30904 L
.39017 .30911 L
.3932 .30918 L
.39488 .30922 L
.39642 .30925 L
.39803 .30928 L
.39881 .30929 L
.39952 .3093 L
.40026 .30931 L
.40066 .30931 L
.40104 .30931 L
.40124 .30932 L
.40146 .30932 L
.40164 .30932 L
.40174 .30932 L
.40184 .30932 L
.40189 .30932 L
.40195 .30932 L
.40206 .30932 L
.40216 .30932 L
.40225 .30932 L
.40231 .30932 L
.40237 .30932 L
.40247 .30932 L
.40258 .30932 L
.4027 .30932 L
.40289 .30931 L
.4031 .30931 L
.40347 .30931 L
.40391 .30931 L
.4043 .3093 L
Mistroke
.40517 .30929 L
.406 .30928 L
.4076 .30923 L
.40907 .30918 L
.41223 .30903 L
.41526 .30884 L
.41849 .30863 L
.4216 .30844 L
.42321 .30836 L
.42403 .30832 L
.42448 .30831 L
.4249 .3083 L
.4253 .30829 L
.42573 .30828 L
.42592 .30828 L
.42613 .30827 L
.42632 .30827 L
.42649 .30827 L
.42666 .30827 L
.42676 .30827 L
.42685 .30827 L
.42694 .30827 L
.42701 .30827 L
.4271 .30827 L
.42719 .30827 L
.42729 .30827 L
.42735 .30827 L
.4274 .30827 L
.42749 .30827 L
.4276 .30827 L
.42778 .30827 L
.42796 .30827 L
.42839 .30828 L
.42879 .30829 L
.42953 .30831 L
.43034 .30835 L
.43121 .30839 L
.43281 .30851 L
.43449 .30868 L
.43753 .30908 L
.44076 .30959 L
.44388 .31008 L
.44546 .31031 L
.44629 .31041 L
.44718 .3105 L
.44805 .31057 L
.44884 .31063 L
.44922 .31064 L
.44942 .31065 L
.44963 .31066 L
Mistroke
.44981 .31066 L
.45002 .31067 L
.4501 .31067 L
.4502 .31067 L
.45029 .31067 L
.45037 .31067 L
.45047 .31067 L
.45052 .31067 L
.45058 .31067 L
.45063 .31067 L
.45069 .31067 L
.4508 .31067 L
.45089 .31067 L
.45098 .31067 L
.45108 .31067 L
.45119 .31067 L
.45143 .31066 L
.45165 .31066 L
.45208 .31064 L
.45248 .31062 L
.45285 .31059 L
.45369 .31051 L
.45447 .31042 L
.4552 .31031 L
.45685 .30999 L
.45997 .30914 L
.46328 .30801 L
.46647 .30691 L
.46808 .30642 L
.46954 .30607 L
.47036 .30592 L
.47112 .30581 L
.47155 .30576 L
.47193 .30573 L
.47214 .30572 L
.47236 .30571 L
.47247 .3057 L
.47259 .3057 L
.47265 .3057 L
.47271 .3057 L
.47281 .3057 L
.4729 .3057 L
.473 .3057 L
.47309 .3057 L
.47318 .3057 L
.47327 .3057 L
.47338 .3057 L
.47359 .30571 L
.47379 .30572 L
.47401 .30574 L
Mistroke
.47441 .30578 L
.47481 .30583 L
.47519 .30588 L
.47589 .30602 L
.47667 .30622 L
.4775 .30649 L
.47898 .30709 L
.48203 .30879 L
.48527 .31101 L
.48839 .31311 L
.48998 .314 L
.49081 .31438 L
.49171 .31471 L
.49249 .31493 L
.49294 .31502 L
.49315 .31505 L
.49336 .31508 L
.49355 .3151 L
.49365 .3151 L
.49375 .31511 L
.49385 .31512 L
.49393 .31512 L
.49402 .31512 L
.4941 .31512 L
.4942 .31512 L
.4943 .31512 L
.49439 .31512 L
.49449 .31512 L
.49459 .31511 L
.4947 .31511 L
.4949 .31509 L
.4951 .31506 L
.49532 .31503 L
.49571 .31495 L
.49618 .31483 L
.4966 .31469 L
.49743 .31433 L
.49821 .3139 L
.49982 .31272 L
.50131 .31133 L
.50448 .30761 L
.50753 .30372 L
.50922 .30175 L
.51077 .30026 L
.51154 .29967 L
.51238 .29916 L
.51276 .29898 L
.51317 .29882 L
.51351 .29872 L
.51371 .29867 L
Mistroke
.5139 .29864 L
.51399 .29863 L
.51409 .29862 L
.51419 .29861 L
.51427 .2986 L
.51438 .2986 L
.51443 .29859 L
.51449 .29859 L
.51458 .29859 L
.51469 .2986 L
.51478 .2986 L
.51489 .29861 L
.51499 .29863 L
.51508 .29864 L
.51531 .29868 L
.51552 .29873 L
.51589 .29885 L
.51623 .299 L
.517 .29945 L
.51785 .30014 L
.51865 .30098 L
.52015 .30298 L
.52325 .30866 L
.52655 .31582 L
.52819 .31922 L
.52972 .32196 L
.5312 .324 L
.53162 .32446 L
.53202 .32483 L
.53241 .32512 L
.53277 .32535 L
.53314 .32552 L
.53334 .32558 L
.53355 .32563 L
.53366 .32565 L
.53371 .32566 L
.53377 .32567 L
.53383 .32567 L
.53388 .32568 L
.53398 .32568 L
.53408 .32568 L
.53418 .32567 L
.53428 .32566 L
.53438 .32565 L
.53455 .32561 L
.53472 .32556 L
.5349 .32549 L
.5351 .3254 L
.53549 .32516 L
.53586 .32487 L
Mistroke
.53665 .32403 L
.53739 .32298 L
.53905 .31969 L
.54055 .31578 L
.5422 .31064 L
.54543 .29945 L
.54853 .28981 L
.54937 .28782 L
.55014 .28629 L
.55095 .28506 L
.55138 .28458 L
.5516 .28438 L
.55183 .2842 L
.55204 .28408 L
.55215 .28403 L
.55226 .28398 L
.55237 .28394 L
.55246 .28392 L
.55256 .2839 L
.55266 .28389 L
.55271 .28388 L
.55276 .28388 L
.55282 .28388 L
.55288 .28389 L
.55297 .2839 L
.55303 .28391 L
.55308 .28392 L
.55319 .28395 L
.55331 .28399 L
.55355 .28411 L
.55376 .28425 L
.55395 .2844 L
.55438 .28486 L
.55478 .28541 L
.55516 .28605 L
.55594 .28768 L
.55676 .2899 L
.55824 .29504 L
.56128 .30917 L
.56451 .32614 L
.56599 .33316 L
.56683 .33663 L
.56761 .33941 L
.56846 .34185 L
.56922 .3435 L
.56965 .34416 L
.57004 .34462 L
.57026 .3448 L
.57046 .34491 L
.57057 .34496 L
Mistroke
.57063 .34498 L
.57068 .34499 L
.57074 .345 L
.57081 .34501 L
.57086 .34501 L
.57092 .34501 L
.57101 .34501 L
.57111 .34499 L
.5712 .34496 L
.57129 .34492 L
.57148 .34481 L
.57169 .34465 L
.57189 .34444 L
.57208 .3442 L
.57251 .3435 L
.57323 .34187 L
.57399 .33949 L
.57481 .33621 L
.5757 .33187 L
.57732 .32219 L
.5806 .29811 L
.58223 .28589 L
.58376 .2756 L
.58522 .26763 L
.58604 .26423 L
.58679 .26192 L
.58718 .26105 L
.58739 .26067 L
.58759 .26038 L
.58777 .26016 L
.58787 .26006 L
.58797 .25998 L
.58806 .25992 L
.58815 .25988 L
.58824 .25984 L
.58832 .25983 L
.58842 .25982 L
.58848 .25982 L
.58853 .25983 L
.58863 .25986 L
.58874 .2599 L
.58883 .25996 L
.58892 .26003 L
.58912 .26023 L
.58934 .26052 L
.58954 .26085 L
.58998 .26185 L
.59036 .26296 L
.59077 .26441 L
.5915 .2677 L
Mistroke
.59316 .2782 L
.59488 .29274 L
.59649 .30881 L
.59958 .34075 L
.60115 .35478 L
.60198 .36099 L
.60287 .36644 L
.6033 .3686 L
.60372 .3703 L
.60409 .37153 L
.60431 .3721 L
.6045 .37253 L
.60469 .37287 L
.60489 .37315 L
.605 .37327 L
.6051 .37335 L
.60519 .37341 L
.60529 .37345 L
.60538 .37347 L
.60548 .37346 L
.60556 .37344 L
.60565 .3734 L
.60574 .37334 L
.60584 .37326 L
.60603 .37303 L
.60622 .37272 L
.60642 .3723 L
.60679 .3713 L
.60722 .3697 L
.60762 .36786 L
.60844 .36294 L
.60931 .35622 L
.6109 .34021 L
.61237 .32202 L
.61551 .27906 L
.61711 .2588 L
.61795 .24956 L
.61884 .24126 L
.61964 .23534 L
.62006 .23285 L
.62052 .23071 L
.62073 .2299 L
.62093 .22925 L
.62113 .22873 L
.62131 .22835 L
.62149 .22808 L
.62157 .22798 L
.62167 .22789 L
.62177 .22783 L
.62187 .2278 L
Mistroke
.62197 .2278 L
.62206 .22783 L
.62216 .22789 L
.62226 .22798 L
.62234 .22808 L
.62244 .22821 L
.62265 .22862 L
.62284 .22911 L
.6232 .23031 L
.62358 .232 L
.62437 .23694 L
.62524 .24448 L
.6268 .26293 L
.62847 .2884 L
.63178 .34577 L
.63344 .37196 L
.63424 .38283 L
.63497 .39127 L
.63569 .39801 L
.63606 .4009 L
.63646 .40342 L
.63666 .4045 L
.63688 .40551 L
.63709 .40628 L
.63727 .40684 L
.63746 .40729 L
.63757 .40747 L
.63767 .40761 L
.63776 .4077 L
.63785 .40776 L
.63794 .40779 L
.63804 .40778 L
.63813 .40774 L
.63823 .40766 L
.63834 .40753 L
.63843 .40738 L
.63861 .407 L
.63879 .40648 L
.63922 .40476 L
.6396 .40259 L
.64036 .3967 L
.64107 .38921 L
.64268 .36611 L
.64416 .33873 L
.64733 .27161 L
.64892 .2401 L
.65037 .21654 L
.65117 .20655 L
.65193 .19942 L
.65235 .19656 L
Mistroke
.65273 .19461 L
.65296 .1938 L
.65316 .19327 L
.65327 .19306 L
.65333 .19297 L
.65339 .19289 L
.65344 .19284 L
.6535 .1928 L
.65361 .19277 L
.65371 .1928 L
.65381 .19287 L
.65386 .19292 L
.65392 .193 L
.65403 .19319 L
.65413 .19342 L
.65424 .19371 L
.65443 .19439 L
.65482 .1963 L
.65518 .19869 L
.65559 .20219 L
.65604 .20691 L
.65686 .21782 L
.65844 .24629 L
.66012 .28484 L
.66346 .36869 L
.66513 .4045 L
.66587 .41714 L
.66667 .42831 L
.66705 .43243 L
.66745 .43605 L
.66783 .43867 L
.668 .43958 L
.66818 .44037 L
.66827 .44073 L
.66838 .44105 L
.66848 .4413 L
.66857 .44148 L
.66867 .44163 L
.66873 .44168 L
.66879 .44172 L
.66889 .44174 L
.66894 .44172 L
.66899 .44169 L
.66909 .44159 L
.66919 .44144 L
.66927 .44126 L
.66937 .44102 L
.66958 .44029 L
.66977 .4394 L
.67014 .43705 L
Mistroke
.67054 .43364 L
.67127 .42518 L
.67214 .41149 L
.67293 .39584 L
.67612 .31146 L
.67919 .22477 L
.68077 .19023 L
.68123 .18247 L
.68165 .17619 L
.68204 .1715 L
.68245 .16737 L
.68265 .16581 L
.68286 .16442 L
.68304 .16344 L
.68324 .16262 L
.68336 .16226 L
.68346 .16201 L
.68357 .16184 L
.68362 .16178 L
.68367 .16173 L
.68377 .1617 L
.68388 .16174 L
.68398 .16185 L
.68407 .16201 L
.68416 .16221 L
.68425 .16248 L
.68441 .16311 L
.68461 .1641 L
.68479 .16523 L
.68518 .16843 L
.68555 .17236 L
.68633 .18354 L
.68716 .19931 L
.68864 .23628 L
.69169 .33267 L
.69338 .38624 L
.69493 .42719 L
.6957 .44309 L
.6961 .45006 L
.69653 .45631 L
.69691 .46073 L
.6971 .46268 L
.69732 .46446 L
.69752 .4658 L
.6977 .46678 L
.69787 .46749 L
.69795 .46776 L
.69805 .46799 L
.69815 .46818 L
.69825 .46827 L
Mistroke
.6983 .46829 L
.69836 .46829 L
.69842 .46826 L
.69847 .46821 L
.69857 .46807 L
.69867 .46786 L
.69877 .46755 L
.69887 .46718 L
.69906 .46628 L
.69923 .46522 L
.69962 .46199 L
.70005 .45718 L
.70043 .45168 L
.7013 .43563 L
.70285 .39581 L
.70452 .34104 L
.70609 .28478 L
.70781 .22571 L
.7086 .20182 L
.70945 .17972 L
.71025 .163 L
.71098 .15148 L
.71138 .14696 L
.71158 .14514 L
.7118 .14353 L
.71191 .14285 L
.71202 .14232 L
.71212 .14187 L
.71222 .14154 L
.71233 .14126 L
.71239 .14116 L
.71245 .14107 L
.71251 .14102 L
.71257 .141 L
.71263 .14101 L
.71269 .14105 L
.71279 .14118 L
.71288 .14137 L
.71298 .14168 L
.71309 .1421 L
.71332 .14328 L
.71353 .14472 L
.71392 .14849 L
.7143 .15324 L
.71507 .16641 L
.7159 .18514 L
.71737 .2291 L
.72072 .35333 L
.72239 .41169 L
.72313 .43325 L
Mistroke
.72394 .45302 L
.72431 .46068 L
.72472 .46767 L
.72507 .47265 L
.72544 .47691 L
.72567 .47884 L
.72587 .48024 L
.72607 .48123 L
.72617 .48161 L
.72622 .48178 L
.72628 .48191 L
.72638 .4821 L
.72647 .48219 L
.72656 .48222 L
.72667 .48214 L
.72676 .482 L
.72686 .48176 L
.72695 .48146 L
.72704 .48112 L
.72722 .48013 L
.72743 .4787 L
.72784 .47469 L
.72822 .46967 L
.72858 .46386 L
.72939 .44704 L
.73025 .42379 L
.73357 .30235 L
.73523 .23797 L
.73676 .18711 L
.73753 .16696 L
.73826 .15205 L
.73862 .14619 L
.73901 .14114 L
.73922 .13898 L
.73944 .13714 L
.73963 .13593 L
.73974 .13539 L
.73984 .13499 L
.73994 .13468 L
.74004 .13445 L
.74015 .13433 L
.74021 .13431 L
.74026 .13431 L
.74036 .1344 L
.74046 .13456 L
.74051 .13469 L
.74056 .13485 L
.74066 .13522 L
.74085 .13617 L
.74105 .13754 L
Mistroke
.74141 .14093 L
.74187 .14687 L
.74229 .15412 L
.74309 .1717 L
.74471 .22084 L
.74619 .27709 L
.74783 .34343 L
.74936 .40093 L
.75084 .44517 L
.75126 .45509 L
.75166 .46314 L
.75205 .46961 L
.75241 .47446 L
.75278 .47813 L
.75298 .47956 L
.75308 .48016 L
.75319 .48069 L
.7533 .48111 L
.7534 .4814 L
.75345 .48151 L
.75351 .48159 L
.75356 .48165 L
.75362 .48168 L
.75372 .48166 L
.75381 .48155 L
.75391 .48135 L
.75401 .48103 L
.7541 .48066 L
.75419 .48025 L
.75438 .4791 L
.75472 .47616 L
.75511 .47136 L
.75549 .46549 L
.75626 .44965 L
.75709 .42769 L
.75856 .37771 L
.76191 .24564 L
.76273 .2165 L
.76359 .18971 L
.76439 .16947 L
.76478 .16143 L
.76513 .15524 L
.76547 .15031 L
.76585 .14619 L
.76605 .14448 L
.76624 .14326 L
.76642 .14241 L
.76651 .14209 L
.76661 .14184 L
.76666 .14175 L
Mistroke
.76672 .14168 L
.76682 .14164 L
.76692 .14169 L
.76701 .14182 L
.76707 .14194 L
.76712 .14209 L
.76722 .14243 L
.76733 .14291 L
.76745 .14355 L
.76765 .14494 L
.76786 .14681 L
.76823 .1512 L
.76863 .15723 L
.76899 .16394 L
.76981 .18293 L
.77128 .22865 L
.77448 .35176 L
.77594 .40323 L
.77677 .4274 L
.77755 .44558 L
.77793 .45249 L
.77832 .45848 L
.77852 .46106 L
.77875 .46345 L
.77895 .4652 L
.77914 .4665 L
.77925 .46707 L
.77936 .46757 L
.77947 .46792 L
.77956 .46815 L
.77967 .46829 L
.77973 .46833 L
.77978 .46833 L
.77984 .4683 L
.7799 .46825 L
.77996 .46815 L
.78002 .46803 L
.78011 .46774 L
.78022 .46735 L
.7804 .46637 L
.78063 .46478 L
.78083 .46295 L
.78122 .45832 L
.78163 .45195 L
.78238 .43699 L
.78405 .3891 L
.7871 .2765 L
.7888 .2189 L
.78961 .1969 L
.79035 .18065 L
Mistroke
.79072 .17426 L
.79112 .16853 L
.79152 .16422 L
.79175 .16249 L
.79185 .16186 L
.79196 .16127 L
.79205 .16087 L
.79214 .16053 L
.79224 .16025 L
.79234 .16009 L
.79243 .16 L
.79252 .15999 L
.7926 .16005 L
.79269 .16018 L
.79278 .1604 L
.79289 .16074 L
.793 .1612 L
.7931 .16172 L
.79348 .1645 L
.79368 .16657 L
.79388 .16883 L
.79431 .1751 L
.79511 .19044 L
.7966 .23066 L
.79975 .34 L
.80132 .39039 L
.80202 .40859 L
.80277 .42486 L
.80314 .43117 L
.80353 .43675 L
.80374 .43929 L
.80394 .44127 L
.80413 .44283 L
.80432 .44416 L
.80443 .44472 L
.80454 .44523 L
.80464 .44559 L
.80474 .44585 L
.80479 .44597 L
.80485 .44605 L
.80495 .44614 L
.80501 .44614 L
.80506 .44612 L
.80512 .44607 L
.80518 .44599 L
.80529 .44576 L
.80535 .4456 L
.8054 .44541 L
.80561 .44449 L
.8058 .44333 L
Mistroke
.806 .44178 L
.8064 .43767 L
.80676 .4328 L
.80757 .41823 L
.80905 .38117 L
.81225 .278 L
.81371 .23506 L
.81454 .21526 L
.81495 .20715 L
.81532 .20074 L
.81569 .19547 L
.81609 .19088 L
.81628 .18911 L
.81649 .18755 L
.8166 .18683 L
.81671 .18627 L
.81681 .18584 L
.81691 .18544 L
.81702 .18515 L
.81708 .18503 L
.81713 .18494 L
.81723 .18483 L
.81733 .18481 L
.81739 .18483 L
.81745 .18489 L
.81751 .18497 L
.81756 .18508 L
.81767 .18534 L
.81778 .18572 L
.818 .18678 L
.81821 .18813 L
.8186 .19156 L
.81897 .19597 L
.81939 .20197 L
.82022 .21751 L
.8217 .25453 L
.8234 .30507 L
.82495 .35068 L
.82572 .37088 L
.82656 .38969 L
.82735 .40373 L
.82773 .40903 L
.82808 .413 L
.82845 .41626 L
.82866 .41762 L
.82885 .41861 L
.82894 .41896 L
.82903 .41927 L
.82911 .41949 L
.8292 .41966 L
Mistroke
.8293 .4198 L
.8294 .41985 L
.82949 .41984 L
.82958 .41977 L
.82968 .41962 L
.82978 .41939 L
.82988 .4191 L
.82996 .41877 L
.83018 .41773 L
.83039 .41643 L
.83079 .41294 L
.83124 .40784 L
.83199 .39628 L
.83282 .37983 L
.83451 .33811 L
.83619 .29234 L
.83773 .2543 L
.83852 .23852 L
.83925 .22672 L
.83964 .22161 L
.84001 .21784 L
.84041 .21466 L
.84063 .21337 L
.84073 .2129 L
.84084 .21247 L
.84094 .21214 L
.84103 .2119 L
.84112 .21172 L
.84121 .2116 L
.84131 .21152 L
.8414 .21152 L
.84151 .21158 L
.84157 .21165 L
.84162 .21173 L
.84172 .21195 L
.84182 .21222 L
.84204 .21307 L
.84224 .21409 L
.84244 .21544 L
.84281 .2185 L
.84315 .2221 L
.84392 .23276 L
.84556 .26442 L
.84705 .29959 L
.84871 .33891 L
.84945 .35432 L
.85025 .36899 L
.85102 .38018 L
.85138 .38425 L
.85175 .38777 L
Mistroke
.85194 .38926 L
.85214 .39065 L
.85234 .39169 L
.85251 .39245 L
.85261 .39279 L
.85272 .3931 L
.85277 .39324 L
.85283 .39335 L
.85288 .39344 L
.85294 .39351 L
.85303 .3936 L
.85313 .39363 L
.85323 .3936 L
.85333 .3935 L
.85343 .39335 L
.85354 .39312 L
.85365 .39281 L
.85375 .39244 L
.85394 .39162 L
.85415 .39051 L
.85461 .38709 L
.85503 .38292 L
.85582 .37283 L
.85665 .35935 L
.8597 .29703 L
.86058 .27967 L
.86141 .2651 L
.86221 .25331 L
.86257 .24902 L
.86296 .24499 L
.86331 .242 L
.86368 .23949 L
.86389 .23844 L
.86408 .23767 L
.86417 .23738 L
.86427 .2371 L
.86436 .23691 L
.86446 .23675 L
.86451 .23667 L
.86457 .23662 L
.86467 .23656 L
.86477 .23655 L
.86487 .2366 L
.86492 .23665 L
.86497 .23671 L
.86507 .23687 L
.86519 .23713 L
.8653 .23743 L
.86549 .23812 L
.8657 .23909 L
Mistroke
.86609 .24142 L
.86647 .24452 L
.86684 .24807 L
.86767 .25822 L
.86936 .28531 L
.87247 .3399 L
.8733 .35154 L
.87407 .36014 L
.87447 .36355 L
.87488 .36645 L
.87512 .36775 L
.87535 .36874 L
.87555 .36942 L
.87566 .36972 L
.87577 .36994 L
.87587 .3701 L
.87596 .37021 L
.87605 .37028 L
.87616 .37031 L
.87625 .37029 L
.87635 .37023 L
.87644 .37013 L
.87653 .37 L
.87664 .36979 L
.87673 .36955 L
.87696 .36885 L
.87716 .36804 L
.87736 .367 L
.87778 .36437 L
.87817 .36128 L
.87905 .35222 L
.88218 .30669 L
.88377 .28359 L
.88461 .27359 L
.88507 .269 L
.88551 .26536 L
.88592 .26251 L
.8863 .26047 L
.8865 .25962 L
.88672 .25887 L
.88694 .25832 L
.88706 .2581 L
.88712 .25802 L
.88717 .25795 L
.88727 .25786 L
.88737 .2578 L
.88746 .25779 L
.88756 .25782 L
.88765 .25787 L
.88773 .25795 L
Mistroke
.88782 .25807 L
.88791 .25823 L
.88813 .25871 L
.88833 .25934 L
.88871 .26092 L
.88908 .26296 L
.88948 .26575 L
.8903 .27295 L
.89178 .28985 L
.89346 .31182 L
.89501 .3305 L
.89579 .33828 L
.89652 .34408 L
.89692 .34658 L
.89728 .34841 L
.89768 .34993 L
.8979 .35053 L
.898 .35075 L
.89811 .35095 L
.89821 .35109 L
.8983 .3512 L
.89839 .35127 L
.89848 .35132 L
.89858 .35133 L
.89868 .35132 L
.89878 .35127 L
.89884 .35122 L
.89889 .35117 L
.899 .35104 L
.89909 .35089 L
.89932 .35043 L
.89951 .34989 L
.89972 .34919 L
.90042 .3458 L
.90082 .34325 L
.9012 .3405 L
.90432 .30905 L
.90591 .29274 L
.90675 .28564 L
.90721 .28238 L
.90764 .2798 L
.90806 .27778 L
.90843 .27633 L
.90863 .27573 L
.90885 .2752 L
.90907 .27481 L
.90919 .27466 L
.90925 .2746 L
.90931 .27455 L
.9094 .27449 L
Mistroke
.90951 .27445 L
.9096 .27445 L
.9097 .27447 L
.90978 .27451 L
.90986 .27456 L
.90995 .27465 L
.91005 .27476 L
.91026 .27511 L
.91046 .27555 L
.91084 .27668 L
.91125 .2783 L
.91162 .2801 L
.91244 .28517 L
.91392 .29696 L
.9156 .31202 L
.91714 .3245 L
.91792 .32953 L
.91865 .33316 L
.91901 .33455 L
.91941 .33569 L
.91963 .33618 L
.91984 .33654 L
.91993 .33666 L
.92003 .33677 L
.92014 .33686 L
.92024 .33691 L
.92034 .33695 L
.92044 .33696 L
.92054 .33695 L
.92063 .33691 L
.92072 .33686 L
.92081 .3368 L
.92099 .33659 L
.92119 .33629 L
.92141 .33585 L
.92181 .3348 L
.92218 .33351 L
.92257 .33185 L
.92328 .32823 L
.92632 .3071 L
.92719 .30106 L
.92802 .29599 L
.92882 .29195 L
.92918 .2905 L
.92957 .28915 L
.92994 .28813 L
.93029 .28741 L
.93049 .28711 L
.93066 .28691 L
.93076 .28682 L
Mistroke
.93086 .28675 L
.93091 .28673 L
.93096 .2867 L
.93106 .28667 L
.93112 .28666 L
.93117 .28666 L
.93127 .28667 L
.93133 .28669 L
.93138 .28671 L
.93144 .28674 L
.9315 .28677 L
.93161 .28686 L
.93172 .28696 L
.93191 .28721 L
.93229 .28786 L
.93269 .28885 L
.93352 .2917 L
.93427 .29509 L
.93596 .30444 L
.93763 .31418 L
.93837 .31797 L
.93918 .32151 L
.93955 .32289 L
.93996 .32414 L
.9403 .32504 L
.94068 .3258 L
.9409 .32614 L
.94111 .32639 L
.94131 .32656 L
.94141 .32662 L
.94146 .32665 L
.94151 .32668 L
.94161 .32671 L
.9417 .32672 L
.9418 .32672 L
.94191 .32671 L
.942 .32668 L
.9421 .32664 L
.94219 .32658 L
.94227 .32652 L
.94246 .32634 L
.94266 .32609 L
.94308 .3254 L
.94346 .32455 L
.94382 .32358 L
.94549 .31733 L
.94861 .30311 L
.94942 .30007 L
.94985 .29871 L
.95031 .29749 L
Mistroke
.95071 .29662 L
.95092 .29624 L
.95115 .29589 L
.95136 .29562 L
.95155 .29543 L
.95173 .29529 L
.95182 .29524 L
.95192 .29519 L
.95203 .29515 L
.95213 .29513 L
.95218 .29513 L
.95223 .29513 L
.95229 .29513 L
.95235 .29513 L
.95245 .29515 L
.95254 .29518 L
.95265 .29523 L
.95275 .29529 L
.95293 .29543 L
.9531 .29559 L
.95349 .2961 L
.95392 .29685 L
.95431 .29768 L
.95518 .30004 L
.95685 .30586 L
.95839 .31154 L
.9599 .3162 L
.96066 .31791 L
.96109 .31866 L
.96149 .31919 L
.9617 .3194 L
.96189 .31956 L
.9621 .31969 L
.96221 .31974 L
.96227 .31976 L
.96233 .31978 L
.96243 .3198 L
.96252 .31981 L
.96263 .31981 L
.96268 .31981 L
.96274 .3198 L
.96284 .31979 L
.96292 .31976 L
.96303 .31972 L
.96312 .31968 L
.9633 .31956 L
.96349 .31941 L
.96384 .31906 L
.96421 .31856 L
.96461 .31788 L
Mistroke
.96617 .31427 L
.96785 .30945 L
.96944 .30513 L
.97033 .30317 L
.97076 .30241 L
.97117 .30182 L
.97156 .30136 L
.97176 .30117 L
.97198 .301 L
.97216 .30088 L
.97226 .30084 L
.97236 .30079 L
.97246 .30076 L
.97254 .30073 L
.97263 .30072 L
.97271 .30071 L
.97281 .3007 L
.97291 .3007 L
.97296 .30071 L
.97302 .30071 L
.97312 .30073 L
.97322 .30076 L
.97332 .30079 L
.9735 .30087 L
.97371 .301 L
.97391 .30114 L
.97436 .30158 L
.97485 .30221 L
.97532 .30294 L
.97619 .30457 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{421.375, 260.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 525.688}, {324.5, 0}} -> {-2.58312*^-7, -6.34248*^6, \
6.65005*^-9, 53093.5}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0.309017 5.42214e-08 [
[.32684 .29652 -16.5 -12.5 ]
[.32684 .29652 16.5 0 ]
[.54329 .29652 -16.5 -12.5 ]
[.54329 .29652 16.5 0 ]
[.75974 .29652 -22.5 -12.5 ]
[.75974 .29652 22.5 0 ]
[.97619 .29652 -16.5 -12.5 ]
[.97619 .29652 16.5 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 64 6 ]
[.09789 .09213 -34.5 -6.25 ]
[.09789 .09213 0 6.25 ]
[.09789 .20057 -34.5 -6.25 ]
[.09789 .20057 0 6.25 ]
[.09789 .41746 -28.5 -6.25 ]
[.09789 .41746 0 6.25 ]
[.09789 .5259 -28.5 -6.25 ]
[.09789 .5259 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -65.8125 0 ]
[.5 .63053 65.8125 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 .30902 m
.32684 .31527 L
s
gsave
.32684 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 .30902 m
.54329 .31527 L
s
gsave
.54329 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 .30902 m
.75974 .31527 L
s
gsave
.75974 .29652 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 .30902 m
.15368 .31277 L
s
.19697 .30902 m
.19697 .31277 L
s
.24026 .30902 m
.24026 .31277 L
s
.28355 .30902 m
.28355 .31277 L
s
.37013 .30902 m
.37013 .31277 L
s
.41342 .30902 m
.41342 .31277 L
s
.45671 .30902 m
.45671 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.58658 .30902 m
.58658 .31277 L
s
.62987 .30902 m
.62987 .31277 L
s
.67316 .30902 m
.67316 .31277 L
s
.71645 .30902 m
.71645 .31277 L
s
.80303 .30902 m
.80303 .31277 L
s
.84632 .30902 m
.84632 .31277 L
s
.88961 .30902 m
.88961 .31277 L
s
.9329 .30902 m
.9329 .31277 L
s
.0671 .30902 m
.0671 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09213 m
.11664 .09213 L
s
gsave
.09789 .09213 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .20057 m
.11664 .20057 L
s
gsave
.09789 .20057 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .41746 m
.11664 .41746 L
s
gsave
.09789 .41746 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .5259 m
.11664 .5259 L
s
gsave
.09789 .5259 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.11039 .11924 m
.11414 .11924 L
s
.11039 .14635 m
.11414 .14635 L
s
.11039 .17346 m
.11414 .17346 L
s
.11039 .22768 m
.11414 .22768 L
s
.11039 .2548 m
.11414 .2548 L
s
.11039 .28191 m
.11414 .28191 L
s
.11039 .33613 m
.11414 .33613 L
s
.11039 .36324 m
.11414 .36324 L
s
.11039 .39035 m
.11414 .39035 L
s
.11039 .44457 m
.11414 .44457 L
s
.11039 .47168 m
.11414 .47168 L
s
.11039 .49879 m
.11414 .49879 L
s
.11039 .06502 m
.11414 .06502 L
s
.11039 .03791 m
.11414 .03791 L
s
.11039 .0108 m
.11414 .0108 L
s
.11039 .55301 m
.11414 .55301 L
s
.11039 .58012 m
.11414 .58012 L
s
.11039 .60723 m
.11414 .60723 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -126.812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.812 moveto
(@) show
81.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.812 moveto
(D) show
93.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12.8) show
141.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
147.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
159.000 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
163.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
172.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
190.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02691 .30902 L
.03029 .30902 L
.03347 .30902 L
.03652 .30902 L
.03978 .30902 L
.04291 .30902 L
.04623 .30902 L
.04944 .30902 L
.05252 .30902 L
.0558 .30902 L
.05896 .30902 L
.062 .30902 L
.06523 .30902 L
.06834 .30902 L
.07165 .30902 L
.07484 .30902 L
.0779 .30902 L
.08117 .30902 L
.08431 .30902 L
.08765 .30902 L
.09086 .30902 L
.09396 .30902 L
.09552 .30902 L
.09725 .30902 L
.09804 .30902 L
.09889 .30902 L
.09968 .30902 L
.10042 .30902 L
.10081 .30902 L
.10101 .30902 L
.10123 .30902 L
.10135 .30902 L
.10145 .30902 L
.10156 .30902 L
.10166 .30902 L
.10176 .30902 L
.10182 .30902 L
.10188 .30902 L
.10195 .30902 L
.10201 .30902 L
.10206 .30902 L
.10212 .30902 L
.10222 .30902 L
.10232 .30902 L
.10242 .30902 L
.10253 .30902 L
.10276 .30902 L
.10296 .30902 L
.10336 .30902 L
Mistroke
.10374 .30902 L
.10414 .30902 L
.10451 .30902 L
.10533 .30902 L
.10609 .30902 L
.10681 .30902 L
.10759 .30902 L
.10842 .30902 L
.1099 .30902 L
.11148 .30902 L
.11296 .30902 L
.11459 .30902 L
.11608 .30902 L
.11775 .30902 L
.11929 .30902 L
.12237 .30902 L
.12387 .30902 L
.12552 .30902 L
.12875 .30902 L
.13186 .30902 L
.13517 .30902 L
.13836 .30902 L
.14142 .30902 L
.14468 .30902 L
.14782 .30902 L
.15115 .30902 L
.15436 .30902 L
.15746 .30902 L
.16075 .30902 L
.16391 .30902 L
.16696 .30902 L
.1702 .30902 L
.17332 .30902 L
.17664 .30902 L
.1783 .30902 L
.17983 .30902 L
.18132 .30902 L
.18208 .30902 L
.18248 .30902 L
.18291 .30902 L
.18329 .30902 L
.18351 .30902 L
.18372 .30902 L
.18381 .30902 L
.1839 .30902 L
.18399 .30902 L
.18407 .30902 L
.18417 .30902 L
.18427 .30902 L
.18436 .30902 L
Mistroke
.18446 .30902 L
.18451 .30902 L
.18457 .30902 L
.18468 .30902 L
.18478 .30902 L
.18487 .30902 L
.18509 .30902 L
.18532 .30902 L
.18575 .30902 L
.18613 .30902 L
.18694 .30902 L
.18768 .30902 L
.18849 .30902 L
.18935 .30902 L
.19093 .30902 L
.1924 .30902 L
.19403 .30902 L
.19552 .30902 L
.19719 .30902 L
.19872 .30902 L
.2018 .30902 L
.20496 .30902 L
.20799 .30902 L
.21122 .30902 L
.21432 .30902 L
.21763 .30902 L
.22081 .30902 L
.22387 .30902 L
.22713 .30902 L
.23026 .30902 L
.23186 .30902 L
.2327 .30902 L
.23359 .30902 L
.23439 .30902 L
.23481 .30902 L
.23527 .30902 L
.23568 .30902 L
.23606 .30902 L
.23624 .30902 L
.23644 .30902 L
.23653 .30902 L
.23663 .30902 L
.23672 .30902 L
.23681 .30902 L
.23691 .30902 L
.23696 .30902 L
.23702 .30902 L
.23708 .30902 L
.23713 .30902 L
.23724 .30902 L
Mistroke
.23734 .30902 L
.23743 .30902 L
.23753 .30902 L
.23763 .30902 L
.23785 .30902 L
.23806 .30902 L
.23829 .30902 L
.23853 .30902 L
.23896 .30902 L
.23937 .30902 L
.24015 .30902 L
.24092 .30902 L
.24174 .30902 L
.24321 .30902 L
.24493 .30902 L
.24655 .30902 L
.24964 .30902 L
.25124 .30902 L
.25293 .30902 L
.25598 .30902 L
.25922 .30902 L
.26235 .30902 L
.26567 .30902 L
.26886 .30902 L
.27194 .30902 L
.27349 .30902 L
.27521 .30902 L
.27599 .30902 L
.27684 .30902 L
.27722 .30902 L
.27763 .30902 L
.27801 .30902 L
.27836 .30902 L
.27855 .30902 L
.27876 .30902 L
.27885 .30902 L
.27895 .30902 L
.27904 .30902 L
.27913 .30902 L
.27922 .30902 L
.27933 .30902 L
.27943 .30902 L
.27952 .30902 L
.27957 .30902 L
.27962 .30902 L
.27972 .30902 L
.27984 .30902 L
.27995 .30902 L
.28014 .30902 L
.28031 .30902 L
Mistroke
.2807 .30902 L
.28105 .30902 L
.28142 .30902 L
.28218 .30902 L
.283 .30902 L
.28377 .30902 L
.28447 .30902 L
.286 .30902 L
.28767 .30902 L
.28926 .30902 L
.29095 .30902 L
.29398 .30902 L
.29721 .30902 L
.30032 .30901 L
.30363 .30901 L
.30681 .30901 L
.30987 .30901 L
.31145 .30901 L
.31232 .30901 L
.31313 .30901 L
.31395 .30901 L
.31439 .30901 L
.31461 .30901 L
.31485 .30901 L
.31506 .30901 L
.31525 .30901 L
.31534 .30901 L
.31544 .30901 L
.31553 .30901 L
.31562 .30901 L
.31572 .30901 L
.31581 .30901 L
.31592 .30901 L
.31598 .30901 L
.31603 .30901 L
.31613 .30901 L
.31624 .30901 L
.31647 .30901 L
.31667 .30901 L
.31689 .30901 L
.31729 .30901 L
.31768 .30901 L
.31804 .30901 L
.31885 .30901 L
.31972 .30901 L
.32129 .30901 L
.32275 .30901 L
.32438 .30901 L
.32587 .30902 L
.32906 .30902 L
Mistroke
.33212 .30902 L
.33539 .30903 L
.33853 .30903 L
.34186 .30904 L
.34354 .30904 L
.34428 .30904 L
.34508 .30904 L
.34586 .30904 L
.34623 .30904 L
.34659 .30904 L
.34678 .30904 L
.34699 .30904 L
.34716 .30904 L
.34735 .30904 L
.34745 .30904 L
.34756 .30904 L
.34762 .30904 L
.34767 .30904 L
.34773 .30904 L
.34778 .30904 L
.34787 .30904 L
.34797 .30904 L
.34807 .30904 L
.34818 .30904 L
.34828 .30904 L
.34838 .30904 L
.3485 .30904 L
.3486 .30904 L
.34879 .30904 L
.349 .30904 L
.34946 .30904 L
.34989 .30904 L
.35072 .30904 L
.35151 .30904 L
.35228 .30904 L
.3531 .30904 L
.35458 .30904 L
.3563 .30903 L
.35792 .30902 L
.36102 .30901 L
.36432 .30899 L
.36749 .30897 L
.37054 .30895 L
.37224 .30894 L
.37379 .30893 L
.37456 .30893 L
.37497 .30893 L
.3754 .30893 L
.37578 .30893 L
.37619 .30893 L
Mistroke
.37637 .30893 L
.37657 .30893 L
.37675 .30892 L
.37692 .30892 L
.37702 .30892 L
.37712 .30892 L
.37721 .30892 L
.3773 .30892 L
.37741 .30892 L
.37746 .30892 L
.37751 .30892 L
.37762 .30892 L
.37771 .30892 L
.37789 .30892 L
.37806 .30893 L
.37844 .30893 L
.37866 .30893 L
.37885 .30893 L
.3793 .30893 L
.38011 .30893 L
.38088 .30893 L
.3816 .30894 L
.38326 .30895 L
.38487 .30897 L
.38636 .30899 L
.38954 .30904 L
.39259 .3091 L
.39585 .30917 L
.39898 .30923 L
.3998 .30925 L
.40069 .30926 L
.40146 .30927 L
.40187 .30927 L
.40231 .30928 L
.40274 .30928 L
.40313 .30928 L
.40332 .30928 L
.40353 .30928 L
.40372 .30928 L
.4039 .30928 L
.40401 .30928 L
.40407 .30928 L
.40412 .30928 L
.40418 .30928 L
.40423 .30928 L
.40433 .30928 L
.40443 .30928 L
.40453 .30928 L
.40463 .30928 L
.40472 .30928 L
Mistroke
.40483 .30928 L
.40494 .30928 L
.40517 .30928 L
.40537 .30928 L
.40559 .30928 L
.40598 .30928 L
.40635 .30928 L
.40716 .30927 L
.40787 .30926 L
.40862 .30924 L
.41021 .3092 L
.41169 .30916 L
.41482 .30902 L
.41815 .30884 L
.42137 .30864 L
.42446 .30848 L
.42605 .30841 L
.42686 .30839 L
.42731 .30838 L
.42774 .30837 L
.42813 .30836 L
.42834 .30836 L
.42856 .30835 L
.42876 .30835 L
.42895 .30835 L
.42913 .30835 L
.42922 .30835 L
.42931 .30835 L
.4294 .30835 L
.42945 .30835 L
.42951 .30835 L
.42957 .30835 L
.42962 .30835 L
.42973 .30835 L
.42982 .30835 L
.42991 .30835 L
.43001 .30835 L
.43011 .30835 L
.43033 .30835 L
.43053 .30835 L
.43075 .30835 L
.43098 .30836 L
.4314 .30836 L
.43179 .30837 L
.43268 .3084 L
.43346 .30844 L
.43429 .30848 L
.43601 .30861 L
.43763 .30876 L
.44072 .30914 L
Mistroke
.44401 .30961 L
.44718 .31005 L
.44878 .31024 L
.45023 .31038 L
.45103 .31043 L
.4518 .31047 L
.45221 .31049 L
.4526 .3105 L
.4528 .3105 L
.45292 .31051 L
.45302 .31051 L
.45308 .31051 L
.45314 .31051 L
.45324 .31051 L
.4533 .31051 L
.45335 .31051 L
.45341 .31051 L
.45347 .31051 L
.45357 .31051 L
.45363 .31051 L
.45368 .31051 L
.45379 .31051 L
.4539 .31051 L
.45411 .3105 L
.4543 .3105 L
.45475 .31048 L
.45519 .31046 L
.45596 .31041 L
.45681 .31033 L
.45764 .31023 L
.45839 .31012 L
.46007 .30981 L
.46329 .309 L
.46639 .30804 L
.46968 .30703 L
.47133 .3066 L
.47213 .30643 L
.47286 .30629 L
.47356 .30618 L
.47433 .30609 L
.47475 .30606 L
.47494 .30605 L
.47514 .30603 L
.47533 .30603 L
.47551 .30602 L
.47561 .30602 L
.4757 .30602 L
.4758 .30602 L
.47591 .30602 L
.47601 .30602 L
Mistroke
.47607 .30602 L
.47612 .30602 L
.47621 .30602 L
.47631 .30602 L
.47649 .30603 L
.47668 .30604 L
.47688 .30605 L
.4771 .30606 L
.4775 .3061 L
.47789 .30615 L
.47827 .3062 L
.47897 .30633 L
.47975 .30651 L
.48057 .30675 L
.48205 .3073 L
.48507 .30882 L
.4883 .3108 L
.4914 .31268 L
.49297 .31348 L
.49381 .31383 L
.4947 .31414 L
.49514 .31427 L
.49556 .31436 L
.49597 .31444 L
.49615 .31447 L
.49634 .3145 L
.49652 .31451 L
.4967 .31453 L
.4968 .31454 L
.4969 .31454 L
.49698 .31455 L
.49708 .31455 L
.49718 .31456 L
.49727 .31456 L
.49733 .31456 L
.49739 .31456 L
.49749 .31456 L
.49759 .31455 L
.49767 .31455 L
.49777 .31454 L
.49788 .31454 L
.49808 .31452 L
.49827 .3145 L
.49864 .31444 L
.49903 .31437 L
.49945 .31426 L
.50022 .314 L
.50093 .31369 L
.50242 .31281 L
.50408 .3115 L
Mistroke
.50731 .30819 L
.51041 .3046 L
.51199 .3029 L
.51372 .30131 L
.51451 .30071 L
.51537 .30019 L
.51578 .29999 L
.51617 .29983 L
.51655 .29971 L
.5169 .29962 L
.51708 .29959 L
.51727 .29956 L
.51738 .29954 L
.51748 .29953 L
.51758 .29953 L
.51768 .29952 L
.51774 .29952 L
.51779 .29952 L
.51789 .29952 L
.51794 .29952 L
.51799 .29953 L
.51805 .29953 L
.51811 .29953 L
.51821 .29954 L
.5183 .29955 L
.51851 .29958 L
.5187 .29962 L
.51888 .29966 L
.51922 .29976 L
.51959 .29991 L
.51999 .3001 L
.52074 .30058 L
.52158 .30128 L
.52327 .30319 L
.52482 .30551 L
.5265 .30846 L
.52981 .31496 L
.53146 .31808 L
.53299 .32062 L
.53448 .32255 L
.5353 .32335 L
.53566 .32362 L
.53606 .32387 L
.53645 .32406 L
.53666 .32413 L
.53686 .32419 L
.53696 .32421 L
.53705 .32423 L
.53713 .32424 L
.53722 .32425 L
Mistroke
.53731 .32426 L
.5374 .32426 L
.5375 .32426 L
.5376 .32426 L
.53771 .32425 L
.53776 .32425 L
.53782 .32424 L
.53802 .3242 L
.53813 .32417 L
.53825 .32414 L
.53846 .32406 L
.53889 .32384 L
.53927 .32358 L
.54007 .32283 L
.54081 .32189 L
.54248 .31895 L
.54398 .31542 L
.54564 .31077 L
.54888 .30056 L
.55199 .29165 L
.5528 .28983 L
.55369 .28819 L
.5541 .28757 L
.55453 .28701 L
.55491 .28661 L
.5553 .28629 L
.55551 .28616 L
.55573 .28604 L
.55583 .286 L
.55594 .28597 L
.55604 .28594 L
.55613 .28592 L
.55619 .28592 L
.55625 .28591 L
.55631 .28591 L
.55637 .2859 L
.55643 .2859 L
.55649 .28591 L
.55655 .28591 L
.5566 .28592 L
.5567 .28594 L
.55681 .28596 L
.55692 .286 L
.55702 .28604 L
.55724 .28615 L
.55744 .28628 L
.55781 .28659 L
.55821 .28704 L
.55864 .28765 L
.55941 .28903 L
Mistroke
.56024 .29099 L
.56193 .29629 L
.56517 .31023 L
.56829 .32522 L
.56988 .33202 L
.57072 .3351 L
.57161 .33787 L
.5724 .33981 L
.57281 .34063 L
.57327 .34134 L
.57347 .34159 L
.57368 .34182 L
.57387 .34199 L
.57406 .34212 L
.57423 .3422 L
.57433 .34224 L
.57441 .34226 L
.57451 .34228 L
.57461 .34229 L
.57471 .34229 L
.5748 .34228 L
.5749 .34226 L
.575 .34223 L
.57508 .34219 L
.57518 .34215 L
.57538 .34201 L
.57558 .34184 L
.57593 .34143 L
.57631 .34085 L
.57675 .33997 L
.57717 .33895 L
.57796 .33654 L
.57957 .32975 L
.58106 .32157 L
.58423 .30028 L
.58727 .27992 L
.58884 .27164 L
.58972 .26807 L
.59011 .26678 L
.59052 .26562 L
.5909 .26475 L
.5911 .26437 L
.59131 .26402 L
.59151 .26376 L
.59169 .26357 L
.59187 .26344 L
.59195 .26338 L
.59205 .26334 L
.5921 .26332 L
.59216 .26331 L
Mistroke
.59222 .2633 L
.59227 .26329 L
.59237 .26329 L
.59247 .26331 L
.59252 .26333 L
.59258 .26335 L
.59268 .2634 L
.5928 .26348 L
.59291 .26357 L
.59311 .26378 L
.59333 .26408 L
.59372 .2648 L
.59414 .26586 L
.59455 .26711 L
.5953 .2701 L
.59611 .27423 L
.59698 .27968 L
.60028 .30733 L
.60345 .33777 L
.60505 .35119 L
.60651 .3608 L
.60731 .36472 L
.60768 .36614 L
.60808 .36737 L
.60827 .36788 L
.60849 .36835 L
.6087 .36869 L
.60888 .36894 L
.60899 .36905 L
.6091 .36914 L
.60915 .36917 L
.60921 .3692 L
.60927 .36923 L
.60933 .36924 L
.60939 .36925 L
.60945 .36925 L
.6095 .36925 L
.60955 .36924 L
.60965 .3692 L
.60975 .36914 L
.60985 .36907 L
.60996 .36896 L
.61015 .36871 L
.61034 .36838 L
.61051 .36801 L
.61091 .36694 L
.61133 .36544 L
.61203 .36211 L
.6128 .35729 L
.61435 .34426 L
Mistroke
.61603 .32609 L
.61932 .28431 L
.62097 .2645 L
.6225 .24912 L
.62326 .24307 L
.62398 .23852 L
.62438 .23653 L
.62481 .23482 L
.625 .23422 L
.6252 .23369 L
.62537 .23332 L
.62556 .23301 L
.62566 .23288 L
.62576 .23278 L
.62586 .23272 L
.62595 .23268 L
.62605 .23266 L
.62614 .23267 L
.62623 .2327 L
.62632 .23275 L
.62641 .23284 L
.62652 .23296 L
.62674 .23331 L
.62694 .23376 L
.62713 .23428 L
.6275 .2356 L
.62784 .23714 L
.6286 .24176 L
.6294 .24828 L
.63013 .25572 L
.6318 .27689 L
.63495 .32686 L
.63798 .37279 L
.63874 .38189 L
.63954 .38991 L
.63996 .3934 L
.64041 .3966 L
.6408 .39878 L
.64121 .40058 L
.64143 .4013 L
.64164 .4018 L
.64183 .40215 L
.64193 .40228 L
.64199 .40233 L
.64204 .40237 L
.64214 .40243 L
.64223 .40244 L
.64232 .40243 L
.64243 .40238 L
.64252 .4023 L
Mistroke
.64261 .40218 L
.64279 .40189 L
.6429 .40163 L
.64301 .40136 L
.64324 .40059 L
.64367 .39868 L
.64406 .39637 L
.64447 .39335 L
.64523 .38618 L
.64605 .37639 L
.64752 .35396 L
.65085 .2895 L
.65252 .25671 L
.65405 .23044 L
.65483 .21961 L
.65555 .21125 L
.65631 .20461 L
.65671 .20202 L
.65692 .20094 L
.65714 .19999 L
.65736 .19926 L
.65756 .19879 L
.65765 .19862 L
.65776 .19849 L
.65786 .19841 L
.65795 .19837 L
.65805 .19838 L
.65815 .19843 L
.65821 .19848 L
.65826 .19854 L
.65838 .19871 L
.65849 .19894 L
.65861 .19924 L
.65883 .19998 L
.65903 .2008 L
.65924 .20191 L
.65967 .20477 L
.66045 .21196 L
.66126 .22217 L
.662 .23377 L
.66367 .26645 L
.66685 .34173 L
.66845 .37823 L
.66991 .40596 L
.67072 .41806 L
.67148 .42688 L
.6719 .43053 L
.67229 .43312 L
.67249 .43416 L
.67271 .43506 L
Mistroke
.67283 .43541 L
.67295 .43572 L
.67301 .43584 L
.67306 .43593 L
.67316 .43607 L
.67327 .43615 L
.67332 .43617 L
.67337 .43617 L
.67347 .43614 L
.67357 .43605 L
.67366 .43592 L
.67374 .43576 L
.67394 .43525 L
.67414 .43448 L
.67433 .43357 L
.67476 .43082 L
.67512 .4277 L
.67552 .42351 L
.67623 .41388 L
.67782 .38413 L
.67951 .34271 L
.68254 .25855 L
.68423 .21664 L
.68497 .20133 L
.68577 .18739 L
.68615 .18196 L
.68656 .17703 L
.68691 .17353 L
.68729 .17055 L
.68751 .16921 L
.68772 .16824 L
.68792 .16756 L
.68802 .16731 L
.68807 .1672 L
.68813 .16711 L
.68822 .16699 L
.68831 .16694 L
.68841 .16694 L
.68852 .16701 L
.68861 .16713 L
.68871 .16731 L
.68879 .16752 L
.68888 .1678 L
.68907 .16854 L
.68928 .1696 L
.68969 .17257 L
.69008 .17627 L
.69043 .18054 L
.69124 .19295 L
.69211 .21018 L
Mistroke
.69543 .30344 L
.6971 .35602 L
.69864 .40037 L
.70014 .43478 L
.70089 .44761 L
.70132 .4533 L
.70173 .4576 L
.70211 .46067 L
.70233 .46194 L
.70244 .46243 L
.70254 .46282 L
.70263 .46311 L
.70273 .46336 L
.70282 .46352 L
.7029 .46363 L
.70299 .46368 L
.70309 .46368 L
.70319 .4636 L
.70328 .46346 L
.70339 .46323 L
.7035 .46289 L
.70371 .46203 L
.70391 .46091 L
.70409 .45961 L
.70451 .45575 L
.70496 .4503 L
.70571 .43807 L
.70652 .42093 L
.70799 .38108 L
.71129 .26956 L
.71294 .21651 L
.71375 .19434 L
.71448 .17715 L
.71524 .16273 L
.71559 .15743 L
.71595 .15279 L
.71614 .15082 L
.71635 .14897 L
.71654 .14755 L
.71671 .14651 L
.71692 .14558 L
.71703 .14521 L
.71708 .14507 L
.71714 .14495 L
.71724 .14479 L
.71733 .14472 L
.71738 .1447 L
.71744 .14472 L
.71753 .1448 L
.71763 .14494 L
Mistroke
.71773 .14518 L
.71782 .14548 L
.71791 .14581 L
.71812 .14688 L
.71832 .14822 L
.71872 .15183 L
.71915 .15713 L
.71992 .17009 L
.72063 .18575 L
.72214 .2286 L
.72379 .2865 L
.72548 .3493 L
.72702 .40261 L
.72779 .42536 L
.72862 .44641 L
.7294 .462 L
.72978 .46787 L
.73013 .47227 L
.73054 .47611 L
.73075 .47757 L
.73086 .47817 L
.73098 .4787 L
.73108 .47906 L
.73118 .47931 L
.73127 .47949 L
.73136 .47959 L
.73147 .47962 L
.73156 .47956 L
.73167 .4794 L
.73172 .47928 L
.73178 .47912 L
.73187 .47881 L
.73197 .4784 L
.73215 .47745 L
.73234 .47612 L
.73255 .47431 L
.73292 .47015 L
.73327 .46522 L
.73412 .44932 L
.73491 .42953 L
.7364 .38234 L
.73949 .26443 L
.74105 .20887 L
.74188 .18404 L
.74277 .16231 L
.74321 .15381 L
.74363 .14717 L
.744 .14245 L
.74421 .1403 L
.74441 .1387 L
Mistroke
.7446 .13741 L
.74479 .13652 L
.74489 .13616 L
.74499 .13592 L
.74509 .13574 L
.74514 .13569 L
.7452 .13567 L
.7453 .13569 L
.74538 .13578 L
.74548 .13598 L
.74558 .13625 L
.74567 .13658 L
.74575 .13694 L
.74593 .13799 L
.74613 .13943 L
.74631 .14105 L
.74671 .14572 L
.74743 .15771 L
.74824 .17598 L
.74909 .20018 L
.75215 .31433 L
.75386 .38083 L
.75541 .43178 L
.75618 .45163 L
.75659 .46025 L
.75702 .46786 L
.7574 .47321 L
.7576 .47552 L
.75781 .4776 L
.75801 .47913 L
.75819 .48021 L
.75828 .48063 L
.75837 .48099 L
.75846 .48127 L
.75854 .48145 L
.75865 .48159 L
.7587 .48162 L
.75876 .48163 L
.75886 .48156 L
.75895 .48141 L
.75901 .48127 L
.75907 .48112 L
.75917 .48075 L
.75928 .48025 L
.7594 .47958 L
.7596 .47813 L
.75981 .47618 L
.7602 .47163 L
.76091 .45975 L
.76169 .44183 L
Mistroke
.76325 .39363 L
.76493 .32955 L
.76651 .26617 L
.76823 .20434 L
.76903 .18114 L
.76947 .17034 L
.76989 .16156 L
.77027 .15465 L
.77069 .14866 L
.77088 .14651 L
.77107 .1446 L
.77124 .14324 L
.77142 .14206 L
.77153 .14151 L
.77163 .14111 L
.77172 .14081 L
.77182 .14058 L
.77191 .14046 L
.77199 .14041 L
.77208 .14044 L
.77218 .14056 L
.77228 .14077 L
.77234 .14094 L
.77239 .14111 L
.77261 .14214 L
.7728 .14339 L
.773 .1451 L
.77339 .14957 L
.77377 .15509 L
.77447 .16868 L
.77525 .18838 L
.77608 .21372 L
.77756 .26751 L
.7806 .38486 L
.78216 .43255 L
.78261 .44323 L
.78304 .45187 L
.78346 .45887 L
.78384 .46385 L
.78403 .46585 L
.78423 .46764 L
.78443 .46895 L
.78461 .46985 L
.78471 .47021 L
.7848 .47046 L
.7849 .47065 L
.78496 .47071 L
.78501 .47074 L
.78511 .47072 L
.78517 .47067 L
Mistroke
.78522 .47059 L
.78532 .47037 L
.78543 .47003 L
.7856 .46924 L
.78579 .46807 L
.78613 .46512 L
.78654 .46022 L
.78691 .45447 L
.78769 .43841 L
.78843 .41927 L
.79009 .36439 L
.79323 .24661 L
.79405 .21948 L
.79494 .19447 L
.79535 .18483 L
.79579 .17605 L
.79619 .16922 L
.79656 .16423 L
.79675 .16217 L
.79695 .16029 L
.79713 .15897 L
.79732 .15784 L
.79743 .15737 L
.79753 .15702 L
.79763 .15676 L
.79769 .15665 L
.79775 .15659 L
.79784 .15654 L
.79794 .15657 L
.79804 .1567 L
.79814 .15691 L
.79823 .1572 L
.79833 .15759 L
.79851 .15854 L
.79869 .15975 L
.79885 .16112 L
.79922 .16511 L
.79961 .17062 L
.80036 .18484 L
.80118 .20483 L
.80265 .25055 L
.80423 .30742 L
.80596 .36835 L
.80676 .39315 L
.80761 .41564 L
.80842 .43225 L
.80876 .43787 L
.80915 .44288 L
.80954 .44673 L
.80975 .44827 L
Mistroke
.80985 .44886 L
.80995 .44933 L
.81004 .4497 L
.81014 .45001 L
.81023 .45022 L
.81031 .45036 L
.8104 .45044 L
.81049 .45044 L
.8106 .45035 L
.81069 .45019 L
.81079 .44994 L
.8109 .44956 L
.81111 .44851 L
.81131 .44717 L
.8115 .44561 L
.81192 .44102 L
.81236 .43453 L
.81319 .41861 L
.81408 .39631 L
.8157 .34624 L
.81726 .29292 L
.81898 .23876 L
.81977 .21821 L
.82062 .20045 L
.82103 .19368 L
.82142 .18845 L
.82177 .18479 L
.82196 .18316 L
.82215 .18194 L
.82235 .1809 L
.82246 .1805 L
.82252 .18033 L
.82257 .18018 L
.82267 .17999 L
.82277 .17989 L
.82282 .17987 L
.82288 .17987 L
.82298 .17993 L
.82307 .18007 L
.82316 .18028 L
.82325 .18053 L
.82334 .18087 L
.82354 .18187 L
.82373 .18311 L
.82415 .18693 L
.82454 .19166 L
.82541 .20633 L
.8262 .22383 L
.82694 .24301 L
.8286 .29309 L
Mistroke
.83011 .34005 L
.83174 .38424 L
.83263 .40284 L
.83303 .40938 L
.83346 .41534 L
.83386 .41971 L
.83424 .42267 L
.83445 .42382 L
.83465 .42457 L
.83475 .42486 L
.83481 .42499 L
.83487 .42508 L
.83497 .42519 L
.83502 .42521 L
.83508 .42522 L
.83517 .42516 L
.83526 .42504 L
.83536 .42484 L
.83547 .42454 L
.83558 .42413 L
.83569 .42365 L
.83589 .42253 L
.83624 .41977 L
.83663 .41572 L
.8375 .40288 L
.8383 .38696 L
.84146 .3024 L
.84305 .25976 L
.8445 .22899 L
.84489 .22278 L
.8453 .21704 L
.8457 .21264 L
.84606 .20958 L
.84628 .20819 L
.84649 .20718 L
.8466 .20675 L
.8467 .20644 L
.84681 .20618 L
.84687 .20609 L
.84693 .20601 L
.84704 .20594 L
.84714 .20595 L
.84719 .20599 L
.84725 .20605 L
.84735 .20621 L
.84745 .20644 L
.84755 .20676 L
.84774 .20752 L
.84793 .20855 L
.84813 .20991 L
Mistroke
.84849 .21301 L
.84888 .21729 L
.84931 .22301 L
.85077 .25014 L
.85403 .33048 L
.85554 .36408 L
.85639 .37902 L
.85717 .38943 L
.85757 .39335 L
.858 .39652 L
.85822 .39766 L
.85834 .39816 L
.85846 .39854 L
.85857 .39882 L
.85862 .39894 L
.85868 .39904 L
.85879 .39917 L
.85889 .39922 L
.85899 .39921 L
.85908 .39914 L
.85918 .39901 L
.85928 .3988 L
.85937 .39856 L
.85946 .39829 L
.85965 .3975 L
.85987 .39635 L
.86007 .39506 L
.8605 .39134 L
.8613 .38181 L
.86204 .37023 L
.86371 .33691 L
.86534 .3003 L
.86687 .26864 L
.86762 .25567 L
.86833 .24556 L
.86873 .24105 L
.86915 .23704 L
.86934 .23559 L
.86954 .23427 L
.86972 .23332 L
.86991 .23246 L
.87012 .23176 L
.87023 .23148 L
.87028 .23137 L
.87034 .23129 L
.87044 .23117 L
.87053 .23111 L
.87063 .2311 L
.87068 .23112 L
.87073 .23115 L
Mistroke
.87078 .23119 L
.87084 .23126 L
.87094 .23143 L
.87106 .2317 L
.87116 .23201 L
.87139 .23288 L
.87163 .23408 L
.87203 .23681 L
.8724 .24008 L
.87324 .24994 L
.87489 .27662 L
.87638 .30546 L
.87805 .33689 L
.87878 .3488 L
.87959 .3598 L
.87996 .36401 L
.88036 .36785 L
.88071 .37056 L
.88109 .37286 L
.88131 .37387 L
.88151 .3746 L
.88162 .37487 L
.88171 .37509 L
.88176 .37519 L
.88182 .37528 L
.88192 .3754 L
.88201 .37547 L
.88211 .3755 L
.88222 .37547 L
.88231 .37539 L
.88241 .37528 L
.88249 .37514 L
.88268 .3747 L
.88286 .3741 L
.88306 .37325 L
.88347 .37094 L
.88386 .36812 L
.88421 .36492 L
.88588 .34394 L
.88899 .2929 L
.8906 .27043 L
.89141 .26214 L
.89187 .25855 L
.8923 .25599 L
.89249 .25506 L
.8927 .25427 L
.89281 .25393 L
.89293 .25361 L
.89304 .25338 L
.89314 .25321 L
Mistroke
.89325 .25309 L
.89334 .25301 L
.89344 .25297 L
.8935 .25297 L
.89356 .25299 L
.89365 .25304 L
.89374 .25313 L
.89385 .25327 L
.89394 .25345 L
.89412 .25389 L
.89432 .2545 L
.89466 .25598 L
.89503 .25809 L
.89544 .26099 L
.89626 .26862 L
.89701 .27722 L
.89869 .30016 L
.90036 .32362 L
.90109 .33284 L
.9019 .34158 L
.90267 .34821 L
.90304 .3507 L
.90339 .35261 L
.90359 .35346 L
.90379 .35424 L
.90399 .35481 L
.90416 .35521 L
.90427 .3554 L
.90437 .35553 L
.90447 .35564 L
.90453 .35568 L
.90459 .35571 L
.90468 .35573 L
.90478 .35571 L
.90488 .35565 L
.90498 .35556 L
.90508 .35543 L
.90519 .35525 L
.90538 .35483 L
.90559 .35422 L
.90582 .35337 L
.90623 .35141 L
.90662 .34908 L
.90811 .33625 L
.91121 .30008 L
.91279 .28395 L
.91322 .28043 L
.91369 .27721 L
.91412 .27473 L
.91452 .27293 L
Mistroke
.91471 .27223 L
.91493 .27159 L
.91515 .2711 L
.91527 .27089 L
.91538 .27074 L
.91548 .27063 L
.91558 .27056 L
.91567 .27053 L
.91577 .27052 L
.91587 .27054 L
.91593 .27056 L
.91598 .2706 L
.91609 .27069 L
.91619 .27081 L
.91637 .27111 L
.91657 .27154 L
.91691 .27259 L
.91729 .27411 L
.9177 .27621 L
.91852 .28163 L
.91927 .28774 L
.92095 .30389 L
.92262 .32009 L
.92335 .32633 L
.92416 .33212 L
.92453 .33433 L
.92493 .33635 L
.92527 .33779 L
.92565 .339 L
.92587 .33954 L
.92608 .33993 L
.92618 .34008 L
.92627 .34019 L
.92638 .3403 L
.92648 .34036 L
.92657 .3404 L
.92667 .34042 L
.92675 .34041 L
.92685 .34038 L
.92694 .34033 L
.92705 .34025 L
.92715 .34014 L
.92724 .34002 L
.92742 .33971 L
.92762 .33928 L
.92803 .33809 L
.92841 .33664 L
.92877 .335 L
.93044 .32435 L
.93354 .29956 L
Mistroke
.93437 .29389 L
.93515 .28955 L
.93557 .28764 L
.93596 .28621 L
.93639 .28499 L
.93662 .28448 L
.93684 .28412 L
.93694 .284 L
.93704 .28389 L
.93712 .28381 L
.93721 .28375 L
.93727 .28372 L
.93732 .2837 L
.93743 .28367 L
.93752 .28367 L
.93762 .28369 L
.93768 .28371 L
.93773 .28373 L
.93785 .28381 L
.93795 .2839 L
.93806 .28402 L
.93824 .28429 L
.93845 .28466 L
.93882 .28555 L
.93922 .28679 L
.93993 .28972 L
.94164 .29944 L
.94325 .31018 L
.94472 .31918 L
.94555 .32333 L
.94596 .32501 L
.94633 .32632 L
.9467 .32738 L
.9471 .32828 L
.94731 .32864 L
.9475 .3289 L
.94771 .3291 L
.94782 .32918 L
.94792 .32923 L
.94803 .32927 L
.94808 .32928 L
.94814 .32928 L
.94824 .32927 L
.94834 .32925 L
.9484 .32923 L
.94846 .3292 L
.94856 .32914 L
.94867 .32905 L
.94879 .32892 L
.949 .32866 L
Mistroke
.94922 .3283 L
.94961 .32745 L
.95036 .32521 L
.95117 .32198 L
.95264 .31471 L
.95421 .30628 L
.95505 .30217 L
.95594 .2984 L
.95638 .29684 L
.9568 .29559 L
.95721 .2946 L
.95758 .29389 L
.95794 .2934 L
.95812 .29322 L
.95822 .29314 L
.95832 .29308 L
.95842 .29303 L
.95852 .293 L
.95862 .29298 L
.95868 .29297 L
.95873 .29297 L
.95883 .29298 L
.95892 .29301 L
.95902 .29304 L
.95912 .29309 L
.95931 .29323 L
.95949 .29341 L
.9599 .29398 L
.9603 .29474 L
.96073 .29577 L
.96221 .3007 L
.9638 .30736 L
.96553 .31443 L
.96634 .31716 L
.96678 .31842 L
.96719 .31943 L
.96758 .32019 L
.96792 .32075 L
.96831 .32121 L
.96852 .32138 L
.96862 .32145 L
.96873 .32151 L
.96878 .32153 L
.96884 .32155 L
.96894 .32158 L
.96903 .3216 L
.96913 .3216 L
.96922 .3216 L
.96932 .32158 L
.96941 .32156 L
Mistroke
.9695 .32153 L
.9696 .32148 L
.9697 .32142 L
.96992 .32125 L
.97011 .32106 L
.97032 .32081 L
.97109 .3195 L
.97179 .31786 L
.97501 .30753 L
.97619 .30395 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{421.375, 260.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 525.688}, {324.5, 0}} -> {-2.58312*^-7, -6.34248*^6, \
6.65005*^-9, 53093.5}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0.309017 5.42214e-08 [
[.32684 .29652 -16.5 -12.5 ]
[.32684 .29652 16.5 0 ]
[.54329 .29652 -16.5 -12.5 ]
[.54329 .29652 16.5 0 ]
[.75974 .29652 -22.5 -12.5 ]
[.75974 .29652 22.5 0 ]
[.97619 .29652 -16.5 -12.5 ]
[.97619 .29652 16.5 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 64 6 ]
[.09789 .09213 -34.5 -6.25 ]
[.09789 .09213 0 6.25 ]
[.09789 .20057 -34.5 -6.25 ]
[.09789 .20057 0 6.25 ]
[.09789 .41746 -28.5 -6.25 ]
[.09789 .41746 0 6.25 ]
[.09789 .5259 -28.5 -6.25 ]
[.09789 .5259 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -62.8125 0 ]
[.5 .63053 62.8125 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 .30902 m
.32684 .31527 L
s
gsave
.32684 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 .30902 m
.54329 .31527 L
s
gsave
.54329 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 .30902 m
.75974 .31527 L
s
gsave
.75974 .29652 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 .30902 m
.15368 .31277 L
s
.19697 .30902 m
.19697 .31277 L
s
.24026 .30902 m
.24026 .31277 L
s
.28355 .30902 m
.28355 .31277 L
s
.37013 .30902 m
.37013 .31277 L
s
.41342 .30902 m
.41342 .31277 L
s
.45671 .30902 m
.45671 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.58658 .30902 m
.58658 .31277 L
s
.62987 .30902 m
.62987 .31277 L
s
.67316 .30902 m
.67316 .31277 L
s
.71645 .30902 m
.71645 .31277 L
s
.80303 .30902 m
.80303 .31277 L
s
.84632 .30902 m
.84632 .31277 L
s
.88961 .30902 m
.88961 .31277 L
s
.9329 .30902 m
.9329 .31277 L
s
.0671 .30902 m
.0671 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09213 m
.11664 .09213 L
s
gsave
.09789 .09213 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .20057 m
.11664 .20057 L
s
gsave
.09789 .20057 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .41746 m
.11664 .41746 L
s
gsave
.09789 .41746 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .5259 m
.11664 .5259 L
s
gsave
.09789 .5259 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.11039 .11924 m
.11414 .11924 L
s
.11039 .14635 m
.11414 .14635 L
s
.11039 .17346 m
.11414 .17346 L
s
.11039 .22768 m
.11414 .22768 L
s
.11039 .2548 m
.11414 .2548 L
s
.11039 .28191 m
.11414 .28191 L
s
.11039 .33613 m
.11414 .33613 L
s
.11039 .36324 m
.11414 .36324 L
s
.11039 .39035 m
.11414 .39035 L
s
.11039 .44457 m
.11414 .44457 L
s
.11039 .47168 m
.11414 .47168 L
s
.11039 .49879 m
.11414 .49879 L
s
.11039 .06502 m
.11414 .06502 L
s
.11039 .03791 m
.11414 .03791 L
s
.11039 .0108 m
.11414 .0108 L
s
.11039 .55301 m
.11414 .55301 L
s
.11039 .58012 m
.11414 .58012 L
s
.11039 .60723 m
.11414 .60723 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -123.812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.812 moveto
(@) show
81.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.812 moveto
(D) show
93.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13.) show
135.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
141.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
153.000 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
157.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
166.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
184.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02691 .30902 L
.03029 .30902 L
.03347 .30902 L
.03652 .30902 L
.03978 .30902 L
.04291 .30902 L
.04623 .30902 L
.04944 .30902 L
.05252 .30902 L
.0558 .30902 L
.05896 .30902 L
.062 .30902 L
.06523 .30902 L
.06834 .30902 L
.07165 .30902 L
.07484 .30902 L
.0779 .30902 L
.08117 .30902 L
.08431 .30902 L
.08765 .30902 L
.09086 .30902 L
.09396 .30902 L
.09556 .30902 L
.09636 .30902 L
.09682 .30902 L
.09704 .30902 L
.09725 .30902 L
.09744 .30902 L
.09765 .30902 L
.09775 .30902 L
.09786 .30902 L
.09792 .30902 L
.09798 .30902 L
.09803 .30902 L
.09809 .30902 L
.09818 .30902 L
.09827 .30902 L
.09838 .30902 L
.09847 .30902 L
.09857 .30902 L
.09868 .30902 L
.09888 .30902 L
.09906 .30902 L
.09926 .30902 L
.09966 .30902 L
.10002 .30902 L
.10037 .30902 L
.10121 .30902 L
.102 .30902 L
Mistroke
.10271 .30902 L
.10349 .30902 L
.10507 .30902 L
.10595 .30902 L
.10675 .30902 L
.1083 .30902 L
.10997 .30902 L
.11158 .30902 L
.11327 .30902 L
.11632 .30902 L
.11789 .30902 L
.11957 .30902 L
.12289 .30902 L
.1261 .30902 L
.12918 .30902 L
.13245 .30902 L
.13561 .30902 L
.13864 .30902 L
.14188 .30902 L
.14499 .30902 L
.14829 .30902 L
.15148 .30902 L
.15454 .30902 L
.1578 .30902 L
.16094 .30902 L
.16427 .30902 L
.16749 .30902 L
.17058 .30902 L
.17387 .30902 L
.17703 .30902 L
.17863 .30902 L
.18008 .30902 L
.18083 .30902 L
.18164 .30902 L
.18209 .30902 L
.1825 .30902 L
.1829 .30902 L
.1831 .30902 L
.18321 .30902 L
.18332 .30902 L
.18342 .30902 L
.18351 .30902 L
.18361 .30902 L
.18366 .30902 L
.18372 .30902 L
.18382 .30902 L
.18391 .30902 L
.18402 .30902 L
.18407 .30902 L
.18413 .30902 L
Mistroke
.18432 .30902 L
.18442 .30902 L
.18451 .30902 L
.18487 .30902 L
.18509 .30902 L
.18528 .30902 L
.18573 .30902 L
.18655 .30902 L
.18695 .30902 L
.18739 .30902 L
.18819 .30902 L
.18969 .30902 L
.19045 .30902 L
.19129 .30902 L
.19298 .30902 L
.19455 .30902 L
.19623 .30902 L
.19782 .30902 L
.19955 .30902 L
.20275 .30902 L
.20602 .30902 L
.20918 .30902 L
.21221 .30902 L
.21544 .30902 L
.21854 .30902 L
.22185 .30902 L
.22503 .30902 L
.22809 .30902 L
.23135 .30902 L
.23285 .30902 L
.23448 .30902 L
.23538 .30902 L
.23577 .30902 L
.2362 .30902 L
.23639 .30902 L
.23661 .30902 L
.23679 .30902 L
.23698 .30902 L
.2371 .30902 L
.23721 .30902 L
.23731 .30902 L
.23737 .30902 L
.23742 .30902 L
.23752 .30902 L
.23757 .30902 L
.23762 .30902 L
.23772 .30902 L
.23782 .30902 L
.23792 .30902 L
.23802 .30902 L
Mistroke
.23822 .30902 L
.23841 .30902 L
.23858 .30902 L
.23898 .30902 L
.2394 .30902 L
.2401 .30902 L
.24087 .30902 L
.24168 .30902 L
.24243 .30902 L
.2441 .30902 L
.24563 .30902 L
.24729 .30902 L
.249 .30902 L
.25055 .30902 L
.25369 .30902 L
.25691 .30902 L
.26 .30902 L
.26329 .30902 L
.26646 .30902 L
.26951 .30902 L
.27275 .30902 L
.27587 .30902 L
.27669 .30902 L
.27758 .30902 L
.27798 .30902 L
.27841 .30902 L
.27882 .30902 L
.27919 .30902 L
.27956 .30902 L
.27974 .30902 L
.27994 .30902 L
.28005 .30902 L
.28014 .30902 L
.2802 .30902 L
.28026 .30902 L
.28036 .30902 L
.28046 .30902 L
.28056 .30902 L
.28065 .30902 L
.28075 .30902 L
.28085 .30902 L
.28094 .30902 L
.28112 .30902 L
.28131 .30902 L
.28151 .30902 L
.28188 .30902 L
.28222 .30902 L
.28263 .30902 L
.28307 .30902 L
.28387 .30902 L
Mistroke
.28465 .30902 L
.28536 .30902 L
.28688 .30902 L
.28854 .30902 L
.2901 .30902 L
.29178 .30902 L
.29511 .30902 L
.29831 .30902 L
.30139 .30902 L
.30466 .30901 L
.30782 .30901 L
.31085 .30901 L
.31254 .30901 L
.31328 .30901 L
.31408 .30901 L
.31482 .30901 L
.3156 .30901 L
.31582 .30901 L
.31603 .30901 L
.31624 .30901 L
.31642 .30901 L
.3166 .30901 L
.31669 .30901 L
.31679 .30901 L
.31689 .30901 L
.31698 .30901 L
.31704 .30901 L
.31709 .30901 L
.31719 .30901 L
.31728 .30901 L
.31738 .30901 L
.31747 .30901 L
.31756 .30901 L
.31776 .30901 L
.31797 .30901 L
.31817 .30901 L
.31836 .30901 L
.31879 .30901 L
.31916 .30901 L
.3195 .30901 L
.32027 .30901 L
.32106 .30901 L
.3218 .30901 L
.32347 .30901 L
.32497 .30901 L
.32663 .30901 L
.32986 .30902 L
.33298 .30902 L
.33629 .30903 L
.33947 .30903 L
Mistroke
.34254 .30903 L
.34425 .30904 L
.3458 .30904 L
.34658 .30904 L
.34742 .30904 L
.34781 .30904 L
.34822 .30904 L
.34856 .30904 L
.34895 .30904 L
.34915 .30904 L
.34925 .30904 L
.34937 .30904 L
.34946 .30904 L
.34952 .30904 L
.34957 .30904 L
.34967 .30904 L
.34976 .30904 L
.34986 .30904 L
.34995 .30904 L
.35006 .30904 L
.35015 .30904 L
.35033 .30904 L
.35051 .30904 L
.35073 .30904 L
.35096 .30904 L
.35139 .30904 L
.35181 .30904 L
.35219 .30904 L
.35297 .30904 L
.3537 .30904 L
.35535 .30904 L
.35698 .30903 L
.35847 .30903 L
.36166 .30902 L
.36473 .309 L
.368 .30898 L
.37115 .30896 L
.37275 .30895 L
.37449 .30895 L
.37531 .30894 L
.37617 .30894 L
.37698 .30894 L
.37771 .30894 L
.3781 .30894 L
.37847 .30894 L
.37868 .30893 L
.37886 .30893 L
.37896 .30893 L
.37907 .30893 L
.37913 .30893 L
Mistroke
.37918 .30893 L
.37929 .30893 L
.37939 .30893 L
.37948 .30893 L
.37958 .30893 L
.37963 .30893 L
.37968 .30893 L
.37978 .30893 L
.37988 .30893 L
.38006 .30893 L
.38024 .30894 L
.38043 .30894 L
.38076 .30894 L
.38116 .30894 L
.38152 .30894 L
.38234 .30894 L
.38309 .30894 L
.38381 .30895 L
.38541 .30896 L
.38688 .30897 L
.39003 .30901 L
.39306 .30906 L
.39629 .30912 L
.39939 .30918 L
.40097 .30921 L
.40269 .30923 L
.40349 .30924 L
.40434 .30925 L
.40475 .30925 L
.40514 .30925 L
.40549 .30925 L
.40587 .30926 L
.40606 .30926 L
.40616 .30926 L
.40626 .30926 L
.40635 .30926 L
.40645 .30926 L
.40654 .30926 L
.40663 .30926 L
.40668 .30926 L
.40674 .30926 L
.40684 .30926 L
.40694 .30926 L
.40703 .30926 L
.40713 .30926 L
.40724 .30926 L
.40746 .30926 L
.40768 .30925 L
.40788 .30925 L
.40834 .30925 L
Mistroke
.40875 .30925 L
.40915 .30924 L
.40993 .30924 L
.41075 .30922 L
.41223 .30919 L
.41379 .30915 L
.41526 .3091 L
.41837 .30897 L
.42167 .3088 L
.42486 .30863 L
.42646 .30856 L
.42792 .3085 L
.42867 .30847 L
.42949 .30845 L
.42994 .30844 L
.43036 .30843 L
.43075 .30842 L
.43097 .30842 L
.43118 .30842 L
.43137 .30842 L
.43158 .30842 L
.43168 .30842 L
.43178 .30842 L
.43187 .30841 L
.43196 .30841 L
.43205 .30841 L
.43215 .30841 L
.43224 .30841 L
.43234 .30841 L
.43242 .30841 L
.4325 .30841 L
.43259 .30842 L
.43268 .30842 L
.4329 .30842 L
.43313 .30842 L
.43355 .30842 L
.43396 .30843 L
.43434 .30844 L
.43512 .30846 L
.43584 .30849 L
.4375 .30857 L
.43912 .30869 L
.44061 .30882 L
.4438 .30918 L
.44686 .30958 L
.45013 .30998 L
.45163 .31013 L
.45327 .31026 L
.4537 .31029 L
.45416 .31031 L
Mistroke
.45459 .31033 L
.45498 .31034 L
.45536 .31035 L
.45557 .31036 L
.45576 .31036 L
.45586 .31036 L
.45596 .31036 L
.45602 .31036 L
.45607 .31036 L
.45613 .31036 L
.45619 .31036 L
.45629 .31036 L
.45639 .31036 L
.45649 .31036 L
.4566 .31036 L
.45681 .31036 L
.457 .31035 L
.45737 .31034 L
.45776 .31033 L
.45819 .31031 L
.45895 .31026 L
.45966 .31019 L
.46117 .31001 L
.46282 .30974 L
.46606 .30901 L
.46918 .30815 L
.47249 .30724 L
.47415 .30685 L
.47495 .30669 L
.47568 .30657 L
.4764 .30646 L
.47717 .30638 L
.47759 .30635 L
.47778 .30634 L
.47798 .30632 L
.47816 .30632 L
.47836 .30631 L
.47846 .30631 L
.47856 .30631 L
.47866 .3063 L
.47875 .3063 L
.47884 .3063 L
.47894 .3063 L
.47903 .3063 L
.47912 .30631 L
.47922 .30631 L
.47932 .30631 L
.47953 .30632 L
.47973 .30633 L
.47995 .30634 L
Mistroke
.48035 .30637 L
.48075 .30641 L
.48113 .30646 L
.48183 .30657 L
.48261 .30673 L
.48344 .30694 L
.48492 .30742 L
.48797 .30877 L
.49121 .31056 L
.49433 .31227 L
.49592 .31301 L
.49676 .31334 L
.49765 .31363 L
.49843 .31382 L
.49888 .31391 L
.49931 .31397 L
.49949 .31399 L
.49969 .31401 L
.49986 .31403 L
.50004 .31404 L
.50015 .31404 L
.50024 .31404 L
.5003 .31404 L
.50035 .31405 L
.50046 .31405 L
.50055 .31405 L
.50066 .31404 L
.50075 .31404 L
.50084 .31404 L
.50095 .31403 L
.50104 .31403 L
.50126 .31401 L
.50145 .31399 L
.50166 .31396 L
.50205 .3139 L
.5024 .31382 L
.50326 .31357 L
.50408 .31326 L
.50569 .31239 L
.50717 .31133 L
.51034 .30843 L
.51339 .30524 L
.51509 .30357 L
.51664 .30224 L
.51741 .30168 L
.51824 .30117 L
.51903 .3008 L
.51941 .30065 L
.51976 .30055 L
.52013 .30046 L
Mistroke
.52033 .30042 L
.52054 .3004 L
.52062 .30039 L
.52072 .30038 L
.5208 .30037 L
.52088 .30037 L
.52098 .30036 L
.52108 .30036 L
.52117 .30036 L
.52126 .30037 L
.52136 .30037 L
.52146 .30038 L
.52156 .30038 L
.52164 .30039 L
.52186 .30043 L
.52207 .30046 L
.52247 .30057 L
.52292 .30072 L
.52375 .30114 L
.5245 .30165 L
.52618 .30324 L
.52773 .3052 L
.52941 .30777 L
.5327 .31359 L
.53435 .31648 L
.53588 .31891 L
.53735 .32083 L
.53818 .32168 L
.53893 .32228 L
.53932 .32252 L
.53973 .32273 L
.54008 .32285 L
.54028 .32291 L
.54047 .32294 L
.54057 .32296 L
.54062 .32296 L
.54068 .32297 L
.54079 .32297 L
.54089 .32298 L
.54099 .32298 L
.54109 .32297 L
.54117 .32296 L
.54127 .32295 L
.54137 .32294 L
.54149 .32291 L
.54172 .32285 L
.54193 .32278 L
.54213 .32269 L
.54254 .32248 L
.54297 .32217 L
Mistroke
.54377 .32141 L
.54454 .32045 L
.54526 .31936 L
.54841 .31256 L
.55143 .30405 L
.55312 .2992 L
.55466 .29511 L
.55627 .29155 L
.55705 .29017 L
.55776 .28916 L
.5585 .28839 L
.55869 .28824 L
.5589 .2881 L
.5591 .28798 L
.55928 .2879 L
.55948 .28783 L
.55959 .2878 L
.5597 .28778 L
.55976 .28777 L
.55982 .28776 L
.55988 .28776 L
.55993 .28776 L
.56004 .28776 L
.56009 .28776 L
.56015 .28776 L
.56025 .28778 L
.56034 .2878 L
.56045 .28782 L
.56056 .28786 L
.56074 .28794 L
.56094 .28804 L
.56136 .28835 L
.56176 .28875 L
.56251 .28976 L
.56332 .29123 L
.56419 .29327 L
.56578 .29806 L
.56747 .30441 L
.5705 .31761 L
.57219 .32491 L
.57373 .33086 L
.57524 .33552 L
.57601 .33729 L
.57643 .33809 L
.57684 .33871 L
.57723 .33919 L
.57746 .33939 L
.57766 .33955 L
.57784 .33965 L
.57794 .33969 L
Mistroke
.57803 .33972 L
.57813 .33975 L
.57823 .33977 L
.57832 .33978 L
.57841 .33978 L
.57851 .33977 L
.57857 .33976 L
.57862 .33975 L
.57872 .33972 L
.57883 .33968 L
.57903 .33957 L
.57922 .33944 L
.57965 .33901 L
.5801 .33836 L
.58086 .33682 L
.58168 .33456 L
.58315 .32899 L
.58486 .32041 L
.58648 .31078 L
.58956 .291 L
.59112 .28181 L
.59195 .27754 L
.59284 .27358 L
.59369 .27053 L
.59447 .26844 L
.59485 .2677 L
.59505 .26738 L
.59526 .26709 L
.59546 .26687 L
.59564 .26671 L
.59573 .26666 L
.59583 .26661 L
.59592 .26657 L
.596 .26655 L
.5961 .26653 L
.5962 .26653 L
.59629 .26654 L
.59638 .26656 L
.59648 .26659 L
.59659 .26665 L
.59678 .26679 L
.59696 .26696 L
.59713 .26717 L
.59751 .26778 L
.59793 .26869 L
.59831 .26973 L
.59917 .27282 L
.59996 .2765 L
.60069 .28062 L
.60235 .29213 L
Mistroke
.60549 .31907 L
.60708 .33326 L
.60882 .34709 L
.60963 .35258 L
.61049 .35749 L
.61122 .36082 L
.61161 .36223 L
.61203 .36347 L
.61224 .36399 L
.61245 .3644 L
.61265 .36474 L
.61284 .36498 L
.61293 .36507 L
.61303 .36515 L
.61312 .36521 L
.6132 .36525 L
.61329 .36528 L
.61339 .3653 L
.61349 .36529 L
.61359 .36527 L
.61369 .36522 L
.61375 .36519 L
.61381 .36515 L
.61401 .36496 L
.6142 .3647 L
.6144 .36436 L
.61481 .36341 L
.61527 .36197 L
.61608 .3584 L
.61682 .35405 L
.6185 .3408 L
.62168 .30616 L
.62475 .27032 L
.62645 .25382 L
.62726 .24767 L
.62801 .24314 L
.62837 .24134 L
.62878 .23973 L
.62919 .23851 L
.62941 .23801 L
.62951 .23783 L
.62962 .23766 L
.62972 .23753 L
.62982 .23743 L
.62991 .23736 L
.63 .23731 L
.63009 .23728 L
.63017 .23727 L
.63026 .23728 L
.63036 .23732 L
Mistroke
.63045 .23738 L
.63056 .23747 L
.63066 .23759 L
.63077 .23774 L
.63095 .23807 L
.63114 .23851 L
.63157 .23984 L
.63196 .2415 L
.63286 .24671 L
.63364 .25293 L
.63447 .26106 L
.63751 .30116 L
.64075 .35026 L
.64224 .36996 L
.64302 .3787 L
.64386 .38641 L
.64432 .38985 L
.64474 .39244 L
.64516 .39451 L
.64556 .39595 L
.64575 .39648 L
.64586 .39671 L
.64596 .3969 L
.64605 .39704 L
.64614 .39714 L
.64623 .39723 L
.64633 .39729 L
.64639 .39731 L
.64644 .39732 L
.64654 .39731 L
.64659 .39729 L
.64665 .39726 L
.6467 .39722 L
.64676 .39716 L
.64687 .39704 L
.64698 .39687 L
.64717 .39647 L
.64738 .3959 L
.64757 .39522 L
.64794 .39362 L
.64833 .39139 L
.64876 .3884 L
.64952 .38153 L
.65023 .37361 L
.6534 .3235 L
.65644 .26601 L
.65813 .23774 L
.65968 .21802 L
.66045 .21113 L
.66088 .20819 L
Mistroke
.66109 .20704 L
.66128 .20612 L
.66147 .20538 L
.66167 .20474 L
.66175 .20451 L
.66185 .2043 L
.66194 .20414 L
.66202 .20402 L
.66211 .20391 L
.66221 .20384 L
.6623 .20381 L
.66239 .20381 L
.66249 .20386 L
.66258 .20394 L
.66269 .20407 L
.6628 .20426 L
.663 .20475 L
.66319 .20537 L
.66355 .20696 L
.66394 .2093 L
.66437 .21256 L
.66513 .22025 L
.66583 .22938 L
.66748 .25716 L
.66897 .28829 L
.67219 .36106 L
.67366 .39039 L
.6745 .40429 L
.67528 .41494 L
.67605 .42296 L
.67649 .42626 L
.67688 .42849 L
.6771 .42939 L
.6773 .43001 L
.6774 .43026 L
.67752 .43046 L
.67758 .43054 L
.67764 .43061 L
.6777 .43065 L
.67775 .43067 L
.67785 .43068 L
.67794 .43064 L
.67804 .43054 L
.6781 .43047 L
.67815 .43038 L
.67826 .43017 L
.67837 .42988 L
.67857 .42919 L
.67876 .42835 L
.67897 .42725 L
Mistroke
.67933 .42473 L
.67977 .42084 L
.68017 .41647 L
.68103 .4044 L
.68186 .38992 L
.68493 .31718 L
.68664 .27135 L
.68819 .23268 L
.68897 .21569 L
.68981 .19989 L
.6906 .18795 L
.69134 .17966 L
.69171 .17662 L
.69189 .17536 L
.6921 .17422 L
.69222 .17369 L
.69233 .17326 L
.69243 .17293 L
.69254 .17264 L
.69264 .17243 L
.69273 .1723 L
.69283 .17222 L
.69289 .17219 L
.69294 .17219 L
.69304 .17223 L
.69314 .17233 L
.69324 .1725 L
.69333 .1727 L
.69344 .17299 L
.69355 .17339 L
.69376 .17432 L
.69398 .17558 L
.69422 .17723 L
.69463 .18098 L
.69539 .19041 L
.6962 .20404 L
.69768 .23665 L
.70099 .3327 L
.70265 .38113 L
.70419 .41901 L
.70495 .43402 L
.70568 .44518 L
.70607 .44994 L
.70643 .45345 L
.70683 .45636 L
.70704 .45746 L
.70715 .4579 L
.70726 .45829 L
.70737 .45858 L
.70747 .45877 L
Mistroke
.70756 .45889 L
.70766 .45895 L
.70775 .45895 L
.70783 .45889 L
.70793 .45877 L
.70802 .45858 L
.70813 .45831 L
.70824 .45792 L
.70845 .45699 L
.70865 .45579 L
.70884 .45442 L
.70956 .44706 L
.70995 .44149 L
.71032 .43556 L
.71186 .40175 L
.71353 .353 L
.71682 .24429 L
.71846 .19764 L
.71927 .17943 L
.72 .16615 L
.72036 .16086 L
.72075 .15614 L
.72112 .15272 L
.72129 .15152 L
.72147 .15046 L
.72156 .14999 L
.72165 .14961 L
.72175 .14929 L
.72183 .14905 L
.72192 .14886 L
.72203 .14871 L
.72213 .14866 L
.72218 .14865 L
.72223 .14868 L
.72234 .14878 L
.72243 .14895 L
.72254 .14922 L
.72265 .1496 L
.72284 .15046 L
.72304 .15171 L
.72346 .15526 L
.72386 .15984 L
.72461 .17153 L
.72541 .18833 L
.72628 .21106 L
.72955 .32161 L
.73106 .37523 L
.7327 .42526 L
.73359 .44684 L
.73399 .45465 L
Mistroke
.73442 .46194 L
.7348 .46721 L
.73521 .4716 L
.73543 .47345 L
.73564 .47478 L
.73574 .47529 L
.73584 .47576 L
.73595 .47612 L
.73604 .47637 L
.73614 .47655 L
.73623 .47665 L
.73632 .47668 L
.73643 .47662 L
.73652 .47649 L
.73662 .47627 L
.73671 .476 L
.7368 .47569 L
.737 .47467 L
.73723 .47316 L
.73763 .46938 L
.73806 .46395 L
.73851 .45664 L
.73932 .43976 L
.74089 .39488 L
.74236 .34278 L
.74548 .22637 L
.7463 .2002 L
.74719 .17589 L
.74803 .15781 L
.7484 .15148 L
.7488 .14592 L
.749 .1437 L
.74921 .14172 L
.7494 .14022 L
.74958 .13911 L
.74974 .13833 L
.74984 .13799 L
.74992 .13776 L
.75001 .13758 L
.75012 .13747 L
.75021 .13745 L
.7503 .1375 L
.7504 .13764 L
.7505 .13787 L
.75059 .13818 L
.75068 .13854 L
.7509 .1397 L
.7511 .14119 L
.75151 .14523 L
.75195 .15126 L
Mistroke
.75278 .16687 L
.75353 .18548 L
.75522 .23965 L
.75844 .36427 L
.75991 .41569 L
.76075 .43974 L
.76153 .45779 L
.76193 .46512 L
.76231 .47085 L
.76251 .47348 L
.76274 .47591 L
.76294 .47771 L
.76314 .47905 L
.76334 .48011 L
.76345 .48051 L
.7635 .48068 L
.76356 .48083 L
.76362 .48095 L
.76368 .48102 L
.76374 .48107 L
.7638 .48109 L
.76386 .48108 L
.76391 .48103 L
.76401 .48088 L
.76411 .48063 L
.76422 .48027 L
.7644 .47938 L
.76461 .47806 L
.76483 .47618 L
.76525 .4714 L
.76564 .46543 L
.76639 .45065 L
.76719 .42997 L
.76807 .40264 L
.77134 .27689 L
.77285 .22058 L
.77365 .1951 L
.77448 .17261 L
.77491 .16314 L
.77538 .15449 L
.77581 .14829 L
.77621 .14399 L
.77642 .1423 L
.77662 .14109 L
.7767 .14068 L
.7768 .14032 L
.7769 .14002 L
.77699 .13983 L
.77709 .13972 L
.77715 .13969 L
Mistroke
.7772 .1397 L
.7773 .13978 L
.77739 .13994 L
.77744 .14007 L
.7775 .14024 L
.7776 .14061 L
.77772 .14118 L
.77783 .14182 L
.77822 .14501 L
.77842 .14716 L
.77863 .14992 L
.77937 .16247 L
.78024 .18279 L
.78104 .20652 L
.78417 .32378 L
.78576 .38405 L
.7866 .41185 L
.78749 .4367 L
.78828 .4538 L
.78873 .46121 L
.78915 .46654 L
.78934 .46839 L
.78953 .46998 L
.7897 .47105 L
.78989 .47191 L
.78999 .47225 L
.79009 .47247 L
.79014 .47256 L
.7902 .47262 L
.7903 .47265 L
.7904 .47259 L
.7905 .47243 L
.79059 .47221 L
.79069 .47189 L
.79089 .47094 L
.7911 .46947 L
.79131 .46767 L
.7915 .46566 L
.79225 .45469 L
.79267 .44629 L
.79306 .43744 L
.79392 .41375 L
.79714 .29681 L
.79862 .24195 L
.79946 .21449 L
.80024 .19256 L
.80102 .17513 L
.80141 .16805 L
.80185 .16189 L
.80208 .15922 L
Mistroke
.8023 .15721 L
.80251 .15569 L
.80262 .15507 L
.80273 .15452 L
.80283 .15413 L
.80293 .15386 L
.80302 .15368 L
.80311 .15358 L
.80322 .15356 L
.80332 .15364 L
.80337 .15372 L
.80342 .15382 L
.80354 .15414 L
.80363 .1545 L
.80372 .15492 L
.80393 .15614 L
.80413 .15769 L
.80434 .15976 L
.80473 .16454 L
.80508 .17003 L
.80594 .18755 L
.80675 .20903 L
.80982 .31588 L
.81138 .37124 L
.8122 .3971 L
.81309 .42061 L
.81351 .42964 L
.81394 .43774 L
.81434 .44388 L
.81472 .44835 L
.81507 .45144 L
.81527 .45269 L
.81545 .45352 L
.81555 .45386 L
.81564 .4541 L
.81575 .45426 L
.8158 .45431 L
.81586 .45433 L
.81595 .4543 L
.81606 .45417 L
.81615 .45396 L
.81624 .4537 L
.81635 .4533 L
.81644 .45284 L
.81663 .45175 L
.81682 .45025 L
.81703 .44825 L
.81742 .44367 L
.81777 .43839 L
.81858 .42262 L
Mistroke
.81943 .40111 L
.82248 .30057 L
.82418 .24439 L
.82573 .20407 L
.8265 .1899 L
.82693 .18391 L
.82714 .18159 L
.82733 .17973 L
.82752 .17828 L
.82768 .1772 L
.82787 .17628 L
.82797 .17591 L
.82807 .17562 L
.82816 .17543 L
.82826 .17531 L
.82836 .17528 L
.82844 .17531 L
.82855 .17544 L
.8286 .17554 L
.82865 .17567 L
.82875 .17596 L
.82885 .17635 L
.82906 .1774 L
.82925 .17871 L
.82961 .182 L
.83 .18672 L
.83043 .1932 L
.8319 .22507 L
.83348 .27138 L
.83516 .32589 L
.83677 .37394 L
.83762 .39485 L
.83808 .40452 L
.83851 .41228 L
.83893 .41859 L
.83931 .42319 L
.83973 .42699 L
.83997 .42847 L
.84007 .429 L
.84019 .42948 L
.84028 .42977 L
.84037 .43002 L
.84047 .4302 L
.84057 .43029 L
.84067 .4303 L
.84076 .43025 L
.84084 .43015 L
.84093 .42998 L
.84103 .42969 L
.84113 .42936 L
Mistroke
.84134 .42834 L
.84154 .42707 L
.84173 .4256 L
.8421 .42187 L
.84251 .41661 L
.84334 .40251 L
.84482 .36772 L
.84807 .27387 L
.84956 .23662 L
.85041 .22046 L
.85119 .20949 L
.85158 .20557 L
.8518 .20383 L
.85201 .20254 L
.85212 .202 L
.85223 .20152 L
.85233 .20119 L
.85244 .20091 L
.85249 .20079 L
.85255 .2007 L
.85265 .20059 L
.85271 .20056 L
.85278 .20056 L
.85284 .20059 L
.85289 .20064 L
.85298 .20077 L
.85308 .20098 L
.85318 .20125 L
.85326 .20156 L
.85348 .20253 L
.85368 .20374 L
.85407 .20699 L
.85451 .21176 L
.85534 .2242 L
.85609 .23875 L
.85777 .27938 L
.85945 .32414 L
.86099 .36165 L
.86177 .37727 L
.8625 .38904 L
.86289 .39417 L
.86326 .398 L
.86366 .40126 L
.86388 .4026 L
.86409 .40357 L
.86418 .4039 L
.86428 .40419 L
.86437 .40441 L
.86446 .40456 L
.86455 .40466 L
Mistroke
.86466 .40471 L
.86471 .40471 L
.86476 .40468 L
.86486 .40458 L
.86492 .4045 L
.86497 .40441 L
.86509 .40413 L
.86519 .40381 L
.8653 .4034 L
.86548 .4025 L
.86569 .40126 L
.86606 .39835 L
.86645 .39431 L
.86717 .38476 L
.86887 .35256 L
.87048 .31498 L
.87194 .28103 L
.87278 .26375 L
.87356 .24981 L
.87432 .23892 L
.87471 .2345 L
.87514 .23065 L
.87535 .22918 L
.87557 .22789 L
.87569 .2273 L
.8758 .22685 L
.87592 .22646 L
.87602 .22617 L
.87612 .22596 L
.87622 .2258 L
.87632 .2257 L
.87638 .22567 L
.87643 .22567 L
.87653 .2257 L
.87662 .22579 L
.87673 .22594 L
.87683 .22615 L
.87693 .22642 L
.87703 .22678 L
.87723 .2276 L
.8776 .22973 L
.87802 .23317 L
.87842 .23719 L
.87989 .25859 L
.88306 .32229 L
.88466 .35182 L
.88535 .36216 L
.88611 .37106 L
.88653 .37479 L
.88692 .37746 L
Mistroke
.88711 .37848 L
.88729 .37927 L
.88747 .37992 L
.88757 .38018 L
.88768 .38041 L
.88778 .38057 L
.88788 .38067 L
.88794 .3807 L
.88799 .38072 L
.88805 .38072 L
.8881 .3807 L
.88816 .38067 L
.88822 .38062 L
.88832 .38048 L
.88838 .38038 L
.88843 .38027 L
.88855 .37997 L
.88876 .37929 L
.88894 .37849 L
.88936 .37606 L
.88974 .37307 L
.89015 .36915 L
.89088 .36037 L
.89255 .33425 L
.89416 .30525 L
.89589 .27628 L
.89671 .26529 L
.89715 .26028 L
.89757 .25633 L
.89795 .25333 L
.89831 .25116 L
.89849 .25024 L
.89869 .24942 L
.89881 .24905 L
.89891 .24876 L
.89901 .24853 L
.89911 .24834 L
.8992 .2482 L
.89931 .24811 L
.8994 .24806 L
.89948 .24806 L
.89959 .24809 L
.89968 .24817 L
.89973 .24823 L
.89979 .2483 L
.89989 .24848 L
.90007 .24892 L
.90026 .24955 L
.90061 .25111 L
.90102 .25359 L
Mistroke
.9014 .25651 L
.90227 .26515 L
.9039 .28707 L
.90539 .31009 L
.90705 .3342 L
.90778 .34304 L
.90859 .35094 L
.90895 .35382 L
.90935 .35635 L
.90954 .35731 L
.90973 .35817 L
.90991 .35885 L
.91008 .35935 L
.91026 .35979 L
.91037 .35997 L
.91047 .3601 L
.91056 .36019 L
.91064 .36024 L
.91073 .36026 L
.91083 .36025 L
.91093 .36019 L
.91104 .36009 L
.91113 .35996 L
.91123 .3598 L
.91145 .35928 L
.91166 .3586 L
.91206 .35685 L
.91243 .35475 L
.91325 .34842 L
.91473 .33257 L
.9164 .31087 L
.91795 .29147 L
.91872 .28304 L
.91945 .27648 L
.92021 .27126 L
.92061 .26923 L
.92082 .26839 L
.92104 .26766 L
.92124 .26713 L
.92135 .26691 L
.92147 .26672 L
.92157 .26659 L
.92167 .2665 L
.92176 .26644 L
.92186 .26641 L
.92192 .26641 L
.92197 .26642 L
.92202 .26644 L
.92208 .26647 L
.92218 .26655 L
Mistroke
.92223 .26661 L
.92228 .26668 L
.92251 .26707 L
.92262 .26732 L
.92275 .26766 L
.92315 .26908 L
.92358 .27116 L
.92436 .27625 L
.92607 .29191 L
.92768 .30958 L
.92929 .32616 L
.92999 .33217 L
.93075 .33745 L
.93118 .33979 L
.93157 .3415 L
.93194 .34274 L
.93213 .34321 L
.93233 .34361 L
.93245 .34378 L
.93256 .3439 L
.93265 .34398 L
.93276 .34404 L
.93281 .34406 L
.93287 .34407 L
.93293 .34407 L
.93299 .34406 L
.9331 .34401 L
.93315 .34397 L
.93321 .34393 L
.93331 .34382 L
.93341 .34369 L
.93362 .34331 L
.93382 .34286 L
.93402 .34227 L
.93445 .34068 L
.93485 .33881 L
.93574 .33333 L
.93736 .32014 L
.939 .30521 L
.94053 .29273 L
.94128 .28785 L
.942 .28426 L
.94239 .28277 L
.9426 .28213 L
.94282 .28156 L
.94301 .28117 L
.94311 .281 L
.94321 .28085 L
.94331 .28073 L
.9434 .28064 L
Mistroke
.94348 .28057 L
.94357 .28052 L
.94367 .28048 L
.94373 .28047 L
.94378 .28047 L
.94387 .28048 L
.94397 .28052 L
.94406 .28058 L
.94415 .28065 L
.94434 .28086 L
.94455 .28119 L
.94473 .28158 L
.94516 .28274 L
.94552 .28403 L
.94591 .28573 L
.94663 .28953 L
.9499 .31278 L
.95141 .32272 L
.95226 .32702 L
.95267 .32864 L
.95304 .32988 L
.95344 .33089 L
.95365 .3313 L
.95388 .33164 L
.95399 .33177 L
.95412 .33188 L
.95417 .33193 L
.95423 .33196 L
.95429 .33199 L
.95434 .33201 L
.95445 .33203 L
.95454 .33204 L
.9546 .33203 L
.95466 .33202 L
.95476 .33197 L
.95487 .33191 L
.95496 .33184 L
.95517 .33161 L
.95536 .33133 L
.95554 .331 L
.95594 .33005 L
.95638 .32869 L
.95715 .32565 L
.95798 .32146 L
.95967 .31148 L
.96137 .30156 L
.96217 .2976 L
.96291 .29461 L
.96328 .29342 L
.96368 .29235 L
Mistroke
.96408 .29152 L
.96431 .29118 L
.96452 .29093 L
.9647 .29077 L
.96479 .29072 L
.9649 .29067 L
.96498 .29064 L
.96508 .29063 L
.96517 .29063 L
.96525 .29064 L
.96535 .29066 L
.96544 .2907 L
.96554 .29076 L
.96565 .29085 L
.96583 .29103 L
.96603 .29128 L
.96645 .29201 L
.96685 .29294 L
.96759 .29522 L
.96927 .30231 L
.97088 .31017 L
.97234 .31666 L
.97309 .31939 L
.97392 .32164 L
.97437 .32252 L
.97456 .32283 L
.97478 .3231 L
.97499 .32331 L
.97518 .32344 L
.97529 .3235 L
.97538 .32354 L
.97544 .32355 L
.97549 .32357 L
.9756 .32358 L
.97567 .32358 L
.97574 .32357 L
.97581 .32356 L
.97589 .32353 L
.97596 .3235 L
.97604 .32346 L
.97619 .32337 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{421.375, 260.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 525.688}, {324.5, 0}} -> {-2.58312*^-7, -6.34248*^6, \
6.65005*^-9, 53093.5}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0.309017 5.42214e-08 [
[.32684 .29652 -16.5 -12.5 ]
[.32684 .29652 16.5 0 ]
[.54329 .29652 -16.5 -12.5 ]
[.54329 .29652 16.5 0 ]
[.75974 .29652 -22.5 -12.5 ]
[.75974 .29652 22.5 0 ]
[.97619 .29652 -16.5 -12.5 ]
[.97619 .29652 16.5 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 64 6 ]
[.09789 .09213 -34.5 -6.25 ]
[.09789 .09213 0 6.25 ]
[.09789 .20057 -34.5 -6.25 ]
[.09789 .20057 0 6.25 ]
[.09789 .41746 -28.5 -6.25 ]
[.09789 .41746 0 6.25 ]
[.09789 .5259 -28.5 -6.25 ]
[.09789 .5259 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -65.8125 0 ]
[.5 .63053 65.8125 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 .30902 m
.32684 .31527 L
s
gsave
.32684 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 .30902 m
.54329 .31527 L
s
gsave
.54329 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 .30902 m
.75974 .31527 L
s
gsave
.75974 .29652 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 .30902 m
.15368 .31277 L
s
.19697 .30902 m
.19697 .31277 L
s
.24026 .30902 m
.24026 .31277 L
s
.28355 .30902 m
.28355 .31277 L
s
.37013 .30902 m
.37013 .31277 L
s
.41342 .30902 m
.41342 .31277 L
s
.45671 .30902 m
.45671 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.58658 .30902 m
.58658 .31277 L
s
.62987 .30902 m
.62987 .31277 L
s
.67316 .30902 m
.67316 .31277 L
s
.71645 .30902 m
.71645 .31277 L
s
.80303 .30902 m
.80303 .31277 L
s
.84632 .30902 m
.84632 .31277 L
s
.88961 .30902 m
.88961 .31277 L
s
.9329 .30902 m
.9329 .31277 L
s
.0671 .30902 m
.0671 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09213 m
.11664 .09213 L
s
gsave
.09789 .09213 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .20057 m
.11664 .20057 L
s
gsave
.09789 .20057 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .41746 m
.11664 .41746 L
s
gsave
.09789 .41746 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .5259 m
.11664 .5259 L
s
gsave
.09789 .5259 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.11039 .11924 m
.11414 .11924 L
s
.11039 .14635 m
.11414 .14635 L
s
.11039 .17346 m
.11414 .17346 L
s
.11039 .22768 m
.11414 .22768 L
s
.11039 .2548 m
.11414 .2548 L
s
.11039 .28191 m
.11414 .28191 L
s
.11039 .33613 m
.11414 .33613 L
s
.11039 .36324 m
.11414 .36324 L
s
.11039 .39035 m
.11414 .39035 L
s
.11039 .44457 m
.11414 .44457 L
s
.11039 .47168 m
.11414 .47168 L
s
.11039 .49879 m
.11414 .49879 L
s
.11039 .06502 m
.11414 .06502 L
s
.11039 .03791 m
.11414 .03791 L
s
.11039 .0108 m
.11414 .0108 L
s
.11039 .55301 m
.11414 .55301 L
s
.11039 .58012 m
.11414 .58012 L
s
.11039 .60723 m
.11414 .60723 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -126.812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.812 moveto
(@) show
81.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.812 moveto
(D) show
93.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13.2) show
141.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
147.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
159.000 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
163.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
172.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
190.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02691 .30902 L
.03029 .30902 L
.03347 .30902 L
.03652 .30902 L
.03978 .30902 L
.04291 .30902 L
.04623 .30902 L
.04944 .30902 L
.05252 .30902 L
.0558 .30902 L
.05896 .30902 L
.062 .30902 L
.06523 .30902 L
.06834 .30902 L
.07165 .30902 L
.07484 .30902 L
.0779 .30902 L
.08117 .30902 L
.08431 .30902 L
.08765 .30902 L
.08932 .30902 L
.09005 .30902 L
.09086 .30902 L
.09159 .30902 L
.09237 .30902 L
.0928 .30902 L
.09319 .30902 L
.09338 .30902 L
.09358 .30902 L
.09368 .30902 L
.09378 .30902 L
.09386 .30902 L
.09396 .30902 L
.09405 .30902 L
.09414 .30902 L
.09424 .30902 L
.0943 .30902 L
.09435 .30902 L
.09445 .30902 L
.09451 .30902 L
.09456 .30902 L
.09477 .30902 L
.09494 .30902 L
.09513 .30902 L
.09551 .30902 L
.09593 .30902 L
.09637 .30902 L
.09718 .30902 L
.098 .30902 L
Mistroke
.09888 .30902 L
.09972 .30902 L
.1005 .30902 L
.10215 .30902 L
.10364 .30902 L
.10519 .30902 L
.10686 .30902 L
.10846 .30902 L
.11016 .30902 L
.11321 .30902 L
.11478 .30902 L
.11646 .30902 L
.11978 .30902 L
.12298 .30902 L
.12606 .30902 L
.12934 .30902 L
.1325 .30902 L
.13553 .30902 L
.13876 .30902 L
.14187 .30902 L
.14518 .30902 L
.14836 .30902 L
.15143 .30902 L
.15469 .30902 L
.15783 .30902 L
.16116 .30902 L
.16437 .30902 L
.16747 .30902 L
.17075 .30902 L
.17392 .30902 L
.17697 .30902 L
.17866 .30902 L
.18021 .30902 L
.18098 .30902 L
.18138 .30902 L
.18181 .30902 L
.18219 .30902 L
.1824 .30902 L
.1826 .30902 L
.18269 .30902 L
.18278 .30902 L
.18286 .30902 L
.18295 .30902 L
.18304 .30902 L
.18313 .30902 L
.18324 .30902 L
.18333 .30902 L
.18343 .30902 L
.18351 .30902 L
.18361 .30902 L
Mistroke
.18372 .30902 L
.18393 .30902 L
.18413 .30902 L
.18451 .30902 L
.18487 .30902 L
.18528 .30902 L
.18567 .30902 L
.18654 .30902 L
.18739 .30902 L
.18819 .30902 L
.18968 .30902 L
.19129 .30902 L
.19277 .30902 L
.19429 .30902 L
.19595 .30902 L
.19919 .30902 L
.20232 .30902 L
.20564 .30902 L
.20884 .30902 L
.21192 .30902 L
.21519 .30902 L
.21835 .30902 L
.22138 .30902 L
.22461 .30902 L
.22771 .30902 L
.23102 .30902 L
.23267 .30902 L
.2342 .30902 L
.23496 .30902 L
.23568 .30902 L
.23608 .30902 L
.23651 .30902 L
.2369 .30902 L
.23708 .30902 L
.23726 .30902 L
.23735 .30902 L
.23746 .30902 L
.23755 .30902 L
.23763 .30902 L
.23774 .30902 L
.23779 .30902 L
.23784 .30902 L
.23794 .30902 L
.23804 .30902 L
.23813 .30902 L
.23822 .30902 L
.23832 .30902 L
.23842 .30902 L
.23859 .30902 L
.23877 .30902 L
Mistroke
.23898 .30902 L
.23921 .30902 L
.23963 .30902 L
.24004 .30902 L
.24042 .30902 L
.2412 .30902 L
.24193 .30902 L
.24277 .30902 L
.24358 .30902 L
.24521 .30902 L
.24669 .30902 L
.24976 .30902 L
.25134 .30902 L
.25302 .30902 L
.25636 .30902 L
.25957 .30902 L
.26266 .30902 L
.26595 .30902 L
.26912 .30902 L
.27217 .30902 L
.27541 .30902 L
.27691 .30902 L
.27854 .30902 L
.27896 .30902 L
.27942 .30902 L
.27984 .30902 L
.28024 .30902 L
.28061 .30902 L
.28082 .30902 L
.28101 .30902 L
.28111 .30902 L
.2812 .30902 L
.28131 .30902 L
.28137 .30902 L
.28142 .30902 L
.28148 .30902 L
.28153 .30902 L
.28158 .30902 L
.28164 .30902 L
.28174 .30902 L
.28185 .30902 L
.28205 .30902 L
.28227 .30902 L
.28248 .30902 L
.28267 .30902 L
.28303 .30902 L
.28341 .30902 L
.28429 .30902 L
.28509 .30902 L
.2859 .30902 L
Mistroke
.28664 .30902 L
.28831 .30902 L
.28982 .30902 L
.29148 .30902 L
.29473 .30902 L
.29786 .30902 L
.30118 .30902 L
.30438 .30901 L
.30746 .30901 L
.31074 .30901 L
.31237 .30901 L
.31389 .30901 L
.31535 .30901 L
.31617 .30901 L
.31693 .30901 L
.31731 .30901 L
.31752 .30901 L
.31772 .30901 L
.3179 .30901 L
.318 .30901 L
.3181 .30901 L
.31819 .30901 L
.31828 .30901 L
.31837 .30901 L
.31845 .30901 L
.31855 .30901 L
.31861 .30901 L
.31866 .30901 L
.31876 .30901 L
.31887 .30901 L
.31896 .30901 L
.31905 .30901 L
.31925 .30901 L
.31947 .30901 L
.31966 .30901 L
.32011 .30901 L
.32049 .30901 L
.3209 .30901 L
.32163 .30901 L
.3225 .30901 L
.32329 .30901 L
.32482 .30901 L
.32649 .30901 L
.32809 .30902 L
.32977 .30902 L
.33281 .30902 L
.33605 .30902 L
.33916 .30903 L
.34247 .30903 L
.34566 .30903 L
Mistroke
.34726 .30904 L
.34872 .30904 L
.34911 .30904 L
.34954 .30904 L
.3499 .30904 L
.3503 .30904 L
.35051 .30904 L
.35073 .30904 L
.35085 .30904 L
.35096 .30904 L
.35107 .30904 L
.35118 .30904 L
.35128 .30904 L
.35138 .30904 L
.35148 .30904 L
.35154 .30904 L
.35159 .30904 L
.35169 .30904 L
.35178 .30904 L
.35188 .30904 L
.35199 .30904 L
.35219 .30904 L
.35239 .30904 L
.35275 .30904 L
.35314 .30904 L
.35357 .30904 L
.35434 .30904 L
.35505 .30904 L
.35655 .30903 L
.35741 .30903 L
.35821 .30903 L
.36133 .30902 L
.36303 .30902 L
.36464 .30901 L
.36771 .309 L
.37098 .30898 L
.37412 .30896 L
.37573 .30896 L
.37747 .30895 L
.37828 .30895 L
.37914 .30895 L
.37988 .30894 L
.3803 .30894 L
.38049 .30894 L
.38069 .30894 L
.38079 .30894 L
.3809 .30894 L
.381 .30894 L
.38109 .30894 L
.3812 .30894 L
Mistroke
.38126 .30894 L
.38132 .30894 L
.38142 .30894 L
.38147 .30894 L
.38153 .30894 L
.38163 .30894 L
.38173 .30894 L
.38182 .30894 L
.38191 .30894 L
.38213 .30894 L
.38232 .30894 L
.38267 .30894 L
.38305 .30894 L
.38344 .30895 L
.38381 .30895 L
.38465 .30895 L
.38545 .30895 L
.38693 .30896 L
.38853 .30897 L
.39001 .30899 L
.39316 .30903 L
.39619 .30907 L
.39941 .30913 L
.40252 .30918 L
.40409 .3092 L
.40493 .30921 L
.40582 .30922 L
.40668 .30922 L
.40746 .30923 L
.40784 .30923 L
.40804 .30923 L
.40825 .30923 L
.40843 .30923 L
.40853 .30923 L
.40864 .30923 L
.40873 .30923 L
.40882 .30923 L
.40891 .30923 L
.40899 .30923 L
.40909 .30923 L
.40915 .30923 L
.4092 .30923 L
.4093 .30923 L
.4094 .30923 L
.40957 .30923 L
.40977 .30923 L
.40997 .30923 L
.41019 .30923 L
.41059 .30923 L
.41098 .30923 L
Mistroke
.41136 .30922 L
.41206 .30922 L
.41284 .30921 L
.41366 .30919 L
.41514 .30916 L
.41671 .30912 L
.41817 .30907 L
.42128 .30895 L
.42459 .3088 L
.42777 .30865 L
.42937 .30859 L
.43083 .30854 L
.43159 .30852 L
.43241 .3085 L
.43286 .30849 L
.43327 .30848 L
.43367 .30848 L
.43387 .30848 L
.43409 .30848 L
.43429 .30848 L
.4344 .30848 L
.43451 .30848 L
.43461 .30848 L
.4347 .30847 L
.43481 .30847 L
.4349 .30848 L
.435 .30848 L
.43509 .30848 L
.43526 .30848 L
.43545 .30848 L
.43565 .30848 L
.43607 .30848 L
.43652 .30849 L
.43694 .3085 L
.43733 .30851 L
.43813 .30853 L
.43886 .30856 L
.44053 .30865 L
.44204 .30875 L
.44369 .30889 L
.44692 .30922 L
.45004 .30958 L
.45162 .30976 L
.45334 .30994 L
.45502 .31008 L
.45574 .31013 L
.45653 .31017 L
.45695 .31019 L
.45734 .3102 L
.45772 .31021 L
Mistroke
.45811 .31022 L
.45831 .31023 L
.45842 .31023 L
.45853 .31023 L
.45862 .31023 L
.45872 .31023 L
.45882 .31023 L
.45891 .31023 L
.45902 .31023 L
.45912 .31023 L
.45917 .31023 L
.45922 .31023 L
.45934 .31023 L
.45945 .31023 L
.45956 .31022 L
.45979 .31022 L
.46 .31022 L
.46022 .31021 L
.46062 .31019 L
.46137 .31016 L
.46224 .31009 L
.46305 .31002 L
.46455 .30983 L
.46621 .30957 L
.46945 .30888 L
.47256 .30809 L
.47588 .30729 L
.47753 .30696 L
.47834 .30683 L
.47907 .30673 L
.47944 .30669 L
.47983 .30665 L
.48018 .30662 L
.48056 .3066 L
.48096 .30658 L
.48118 .30657 L
.48128 .30657 L
.48138 .30656 L
.48147 .30656 L
.48157 .30656 L
.48166 .30656 L
.48175 .30656 L
.48184 .30656 L
.48194 .30656 L
.48204 .30656 L
.48214 .30656 L
.48223 .30657 L
.48233 .30657 L
.48252 .30657 L
.48273 .30658 L
Mistroke
.48293 .30659 L
.48336 .30663 L
.48376 .30666 L
.48447 .30675 L
.48525 .30688 L
.48685 .30725 L
.48854 .3078 L
.49158 .30909 L
.49482 .31073 L
.49794 .31223 L
.49965 .31288 L
.50043 .31313 L
.50126 .31333 L
.50202 .31347 L
.50223 .3135 L
.50245 .31353 L
.50264 .31354 L
.50286 .31356 L
.50295 .31357 L
.50305 .31357 L
.50314 .31358 L
.50323 .31358 L
.50329 .31358 L
.50334 .31358 L
.50344 .31359 L
.50353 .31359 L
.50363 .31359 L
.50371 .31358 L
.5038 .31358 L
.50388 .31358 L
.50396 .31358 L
.50415 .31357 L
.50433 .31355 L
.50454 .31353 L
.50474 .31351 L
.5051 .31346 L
.5055 .31338 L
.50592 .31329 L
.50669 .31306 L
.5074 .31279 L
.50891 .31203 L
.51057 .31094 L
.51382 .30819 L
.51694 .30525 L
.51853 .30385 L
.52026 .30256 L
.52107 .30208 L
.52192 .30166 L
.52266 .30139 L
.52307 .30128 L
Mistroke
.52327 .30123 L
.52346 .3012 L
.52366 .30117 L
.52384 .30115 L
.52394 .30114 L
.52404 .30113 L
.52414 .30113 L
.5242 .30112 L
.52425 .30112 L
.52435 .30112 L
.52444 .30112 L
.52455 .30113 L
.5246 .30113 L
.52466 .30113 L
.52476 .30114 L
.52487 .30115 L
.52508 .30117 L
.52528 .30121 L
.52546 .30124 L
.52585 .30134 L
.52622 .30147 L
.52657 .30161 L
.52735 .30202 L
.52818 .30259 L
.52967 .30394 L
.53272 .30788 L
.53597 .31308 L
.5391 .31788 L
.53992 .31893 L
.54081 .31992 L
.54158 .32063 L
.54199 .32094 L
.54243 .32123 L
.54285 .32146 L
.54325 .32162 L
.54344 .32168 L
.54364 .32173 L
.54374 .32175 L
.54384 .32177 L
.54392 .32178 L
.54402 .32179 L
.54407 .32179 L
.54413 .3218 L
.54424 .3218 L
.54429 .32181 L
.54436 .3218 L
.54442 .3218 L
.54447 .3218 L
.54458 .32179 L
.54464 .32179 L
Mistroke
.54469 .32178 L
.5449 .32175 L
.54509 .32171 L
.54529 .32164 L
.5457 .32148 L
.5461 .32126 L
.54651 .32098 L
.54726 .32032 L
.54806 .31939 L
.54893 .31813 L
.55218 .31151 L
.55532 .3034 L
.55691 .29924 L
.55865 .29519 L
.55946 .29356 L
.56032 .29208 L
.56112 .29097 L
.56185 .2902 L
.56224 .2899 L
.56261 .28968 L
.56281 .28959 L
.563 .28953 L
.56311 .2895 L
.56321 .28948 L
.56326 .28947 L
.56332 .28947 L
.56342 .28946 L
.56352 .28945 L
.5636 .28945 L
.5637 .28946 L
.5638 .28947 L
.5639 .28949 L
.564 .28951 L
.56419 .28957 L
.56437 .28965 L
.56453 .28973 L
.56489 .28997 L
.56527 .2903 L
.56567 .29074 L
.56639 .29176 L
.56726 .29337 L
.56805 .29519 L
.57123 .30536 L
.57429 .31762 L
.576 .32435 L
.57755 .32972 L
.57833 .33201 L
.57917 .33409 L
.57996 .33564 L
.58034 .33623 L
Mistroke
.58069 .33667 L
.58107 .33704 L
.58127 .33719 L
.58147 .3373 L
.58156 .33735 L
.58165 .33738 L
.58173 .33741 L
.58182 .33743 L
.58191 .33745 L
.582 .33745 L
.5821 .33746 L
.5822 .33745 L
.58229 .33743 L
.5824 .33741 L
.58249 .33738 L
.58258 .33734 L
.5828 .33723 L
.583 .33708 L
.58341 .33667 L
.58385 .33607 L
.58461 .33464 L
.58545 .33249 L
.58714 .32643 L
.58869 .31908 L
.59037 .30982 L
.59368 .29034 L
.59533 .28169 L
.59614 .2781 L
.59687 .2753 L
.59758 .27304 L
.59835 .27119 L
.59877 .27046 L
.59896 .2702 L
.59916 .26997 L
.59936 .26979 L
.59954 .26967 L
.59964 .26962 L
.59973 .26958 L
.59983 .26955 L
.59993 .26954 L
.60002 .26954 L
.60012 .26955 L
.60022 .26957 L
.6003 .2696 L
.6004 .26964 L
.6005 .2697 L
.60071 .26986 L
.60091 .27007 L
.60113 .27036 L
.60153 .27104 L
Mistroke
.60193 .27192 L
.60231 .27294 L
.60301 .27533 L
.60462 .283 L
.6061 .29244 L
.60926 .31742 L
.6123 .34156 L
.61386 .35143 L
.61474 .35572 L
.61513 .35727 L
.61554 .35868 L
.61596 .35983 L
.61633 .36063 L
.61651 .36093 L
.61671 .36119 L
.6168 .36129 L
.6169 .36138 L
.61698 .36145 L
.61707 .3615 L
.61717 .36155 L
.61727 .36157 L
.61737 .36158 L
.61742 .36158 L
.61748 .36157 L
.61757 .36155 L
.61766 .36151 L
.61777 .36145 L
.61786 .36137 L
.61808 .36114 L
.61828 .36085 L
.61873 .35993 L
.61911 .35887 L
.61952 .35745 L
.62025 .35415 L
.62113 .34904 L
.62192 .34336 L
.62513 .31251 L
.62822 .27843 L
.62979 .26315 L
.63062 .2563 L
.63151 .25021 L
.63195 .24775 L
.63237 .24578 L
.63277 .24421 L
.63315 .24308 L
.6335 .24231 L
.63368 .24203 L
.63379 .2419 L
.63388 .2418 L
.63398 .24173 L
Mistroke
.63408 .24168 L
.63418 .24165 L
.63424 .24164 L
.63429 .24164 L
.63439 .24166 L
.63448 .2417 L
.63458 .24177 L
.63468 .24186 L
.63487 .24211 L
.63505 .24242 L
.63546 .24341 L
.63585 .24477 L
.63628 .24666 L
.63706 .25118 L
.63776 .25651 L
.63929 .2715 L
.64095 .29222 L
.64422 .3386 L
.64573 .35863 L
.64736 .37639 L
.64826 .38369 L
.64865 .38625 L
.64908 .38857 L
.64949 .39028 L
.64987 .39143 L
.65008 .39188 L
.65018 .39204 L
.65027 .39217 L
.65037 .39228 L
.65043 .39233 L
.65049 .39236 L
.65059 .3924 L
.65065 .39241 L
.6507 .39241 L
.65079 .39238 L
.65089 .39232 L
.65099 .39224 L
.65108 .39214 L
.65129 .39179 L
.65149 .39133 L
.65189 .39003 L
.65232 .38805 L
.65309 .38307 L
.65381 .37689 L
.65531 .35924 L
.65697 .33403 L
.66021 .27673 L
.6617 .25183 L
.66333 .22947 L
.66421 .22032 L
Mistroke
.66464 .21678 L
.66503 .21412 L
.66543 .21193 L
.66581 .21043 L
.66602 .20984 L
.66621 .20944 L
.66631 .20929 L
.66637 .20922 L
.66642 .20917 L
.66648 .20912 L
.66654 .20909 L
.66659 .20907 L
.66664 .20907 L
.66674 .20909 L
.66683 .20914 L
.66693 .20923 L
.66701 .20934 L
.66711 .20951 L
.66722 .20973 L
.66742 .21027 L
.66763 .211 L
.66785 .21196 L
.66825 .21418 L
.66902 .22028 L
.66973 .22777 L
.67127 .25007 L
.67294 .28138 L
.67623 .35185 L
.67787 .38361 L
.67867 .39672 L
.6794 .40683 L
.68016 .41518 L
.6805 .41822 L
.68087 .42088 L
.68106 .422 L
.68126 .42304 L
.68145 .42383 L
.68163 .42441 L
.68172 .42467 L
.68183 .4249 L
.68194 .42508 L
.682 .42516 L
.68205 .42521 L
.68215 .42528 L
.68224 .42529 L
.68235 .42526 L
.68245 .42518 L
.68254 .42506 L
.68264 .42489 L
.68282 .42446 L
Mistroke
.68303 .42374 L
.68323 .42289 L
.68365 .42041 L
.68405 .41726 L
.68476 .40988 L
.68553 .3993 L
.68712 .37038 L
.6888 .33157 L
.69214 .24793 L
.69382 .21267 L
.69455 .20035 L
.69536 .18962 L
.69574 .18569 L
.69614 .1823 L
.69634 .18097 L
.69652 .1799 L
.69669 .17911 L
.69687 .17841 L
.69696 .17813 L
.69706 .17788 L
.69717 .17767 L
.69726 .17754 L
.69736 .17746 L
.69746 .17744 L
.69754 .17746 L
.69763 .17753 L
.69769 .17759 L
.69774 .17767 L
.69784 .17786 L
.69794 .17813 L
.69806 .17849 L
.69827 .17934 L
.69846 .18034 L
.69884 .18291 L
.69924 .18656 L
.69997 .19541 L
.70083 .2095 L
.70163 .22543 L
.70482 .31001 L
.70789 .39521 L
.70948 .42846 L
.71028 .44059 L
.71074 .44586 L
.71116 .44967 L
.71154 .45207 L
.71164 .45257 L
.71175 .45303 L
.71186 .45338 L
.71195 .45365 L
.71206 .45388 L
Mistroke
.71211 .45397 L
.71217 .45405 L
.71228 .45412 L
.71233 .45413 L
.71239 .45412 L
.71249 .45405 L
.71258 .45393 L
.71268 .45372 L
.71278 .45346 L
.71296 .45282 L
.71315 .45191 L
.71349 .44968 L
.7139 .44604 L
.71427 .44182 L
.71507 .4297 L
.71581 .41526 L
.71748 .37294 L
.72065 .27296 L
.72225 .22465 L
.7237 .18848 L
.72451 .17317 L
.72527 .16237 L
.72569 .1581 L
.72607 .15525 L
.72627 .15419 L
.72639 .15372 L
.7265 .15337 L
.72661 .15309 L
.72667 .15298 L
.72673 .15289 L
.72683 .15281 L
.72689 .1528 L
.72695 .15281 L
.72705 .15289 L
.7271 .15297 L
.72716 .15307 L
.72726 .15331 L
.72735 .1536 L
.72756 .1545 L
.72779 .15583 L
.72821 .15926 L
.72859 .16349 L
.72936 .17506 L
.73008 .18961 L
.73168 .23186 L
.73315 .28009 L
.7363 .38822 L
.73713 .41287 L
.73802 .43574 L
.73887 .45293 L
Mistroke
.73964 .46438 L
.74002 .46834 L
.74023 .47005 L
.74043 .47134 L
.74061 .47227 L
.74071 .47268 L
.74081 .47298 L
.74089 .47317 L
.74098 .47332 L
.74107 .47341 L
.74116 .47344 L
.74126 .47338 L
.74132 .47332 L
.74137 .47323 L
.74147 .47301 L
.74157 .47269 L
.74177 .47183 L
.74196 .47076 L
.74217 .46918 L
.7424 .46706 L
.74282 .46214 L
.74358 .44975 L
.74442 .43139 L
.74611 .38176 L
.74935 .26343 L
.75084 .21243 L
.75163 .18943 L
.75247 .16905 L
.75289 .16065 L
.75335 .15291 L
.75378 .14735 L
.75417 .14346 L
.75437 .14202 L
.75448 .14138 L
.75458 .14087 L
.75467 .14047 L
.75476 .14017 L
.75485 .13992 L
.75495 .13973 L
.755 .13966 L
.75506 .13962 L
.75516 .13961 L
.75521 .13964 L
.75526 .1397 L
.75532 .13978 L
.75538 .13991 L
.75549 .14021 L
.75559 .14059 L
.75579 .14156 L
.756 .14297 L
Mistroke
.75619 .14463 L
.75656 .14861 L
.75695 .15414 L
.75738 .16154 L
.75886 .19742 L
.76046 .25061 L
.76215 .3153 L
.76375 .37594 L
.7652 .42383 L
.76595 .44393 L
.76677 .46122 L
.76722 .46847 L
.76763 .47367 L
.76803 .47723 L
.76823 .47849 L
.76834 .47905 L
.76845 .47947 L
.76854 .47975 L
.76864 .47997 L
.76874 .48008 L
.76883 .48011 L
.76893 .48006 L
.76898 .47999 L
.76904 .4799 L
.76913 .47967 L
.76924 .47933 L
.76934 .47891 L
.76944 .47836 L
.76963 .47711 L
.76986 .4752 L
.77007 .47305 L
.77083 .46195 L
.77156 .447 L
.77315 .40105 L
.77463 .34711 L
.77778 .22591 L
.7786 .19888 L
.7795 .1744 L
.77991 .16507 L
.78034 .1567 L
.78075 .15029 L
.78112 .14571 L
.78131 .14385 L
.78151 .1422 L
.78171 .14099 L
.78188 .14018 L
.78198 .13987 L
.78207 .13965 L
.78217 .13951 L
.78223 .13947 L
Mistroke
.78228 .13946 L
.78238 .13951 L
.78244 .13959 L
.7825 .13968 L
.78259 .13993 L
.7827 .1403 L
.78289 .14123 L
.7831 .14262 L
.78347 .14615 L
.78384 .15079 L
.78417 .1561 L
.78496 .1721 L
.78568 .19122 L
.78734 .24652 L
.79047 .36795 L
.79206 .42116 L
.79295 .44447 L
.79338 .45344 L
.79379 .46047 L
.79417 .46587 L
.79452 .46965 L
.79471 .47121 L
.79491 .4725 L
.79501 .47298 L
.79512 .4734 L
.79518 .4736 L
.79523 .47375 L
.79528 .47386 L
.79534 .47396 L
.79544 .47406 L
.7955 .47407 L
.79555 .47406 L
.79564 .47396 L
.79574 .47377 L
.7958 .47362 L
.79586 .47342 L
.79597 .47297 L
.79618 .4718 L
.79639 .4703 L
.7966 .46829 L
.79698 .46363 L
.79742 .45685 L
.79781 .44923 L
.79871 .42756 L
.80033 .3755 L
.8035 .25451 L
.8051 .202 L
.80579 .18382 L
.80655 .16822 L
.80697 .16164 L
Mistroke
.80736 .15693 L
.80773 .1537 L
.80791 .15255 L
.80802 .15204 L
.80812 .15166 L
.80822 .15137 L
.80827 .15125 L
.80833 .15116 L
.80843 .15106 L
.80849 .15105 L
.80854 .15107 L
.80864 .15117 L
.80874 .15138 L
.80884 .15166 L
.80893 .152 L
.80913 .15304 L
.80935 .15462 L
.80958 .15674 L
.8098 .15916 L
.81064 .17236 L
.81143 .19006 L
.81292 .23435 L
.81599 .34711 L
.81755 .39891 L
.81837 .42129 L
.81881 .43117 L
.81927 .44003 L
.81967 .44644 L
.81988 .44927 L
.82011 .45186 L
.82032 .45384 L
.82051 .45529 L
.82071 .45642 L
.8208 .45685 L
.82089 .45717 L
.82098 .45743 L
.82107 .45763 L
.82117 .45774 L
.82127 .45777 L
.82136 .45772 L
.82145 .45759 L
.82153 .45741 L
.82162 .45715 L
.82173 .45675 L
.82182 .4563 L
.82203 .455 L
.82223 .45344 L
.82241 .45166 L
.82279 .44715 L
.8232 .44086 L
Mistroke
.82403 .42417 L
.82551 .38311 L
.82876 .27035 L
.83025 .22364 L
.83104 .20372 L
.83188 .18728 L
.8323 .18106 L
.83253 .17834 L
.83277 .17589 L
.83299 .17408 L
.83319 .17279 L
.83338 .17189 L
.83348 .17156 L
.83359 .1713 L
.83364 .1712 L
.8337 .17113 L
.8338 .17106 L
.8339 .17109 L
.83399 .17119 L
.83409 .17139 L
.83415 .17154 L
.8342 .1717 L
.83442 .17266 L
.83462 .17385 L
.8348 .17523 L
.8352 .17931 L
.83559 .18443 L
.836 .19113 L
.83673 .20618 L
.8384 .25175 L
.84 .30435 L
.84174 .36048 L
.84256 .38366 L
.84342 .40434 L
.84415 .41822 L
.84457 .42435 L
.84496 .42886 L
.84516 .43068 L
.84536 .43227 L
.84547 .43296 L
.84559 .43361 L
.8457 .4341 L
.8458 .43447 L
.8459 .43475 L
.846 .43494 L
.8461 .43506 L
.84616 .43509 L
.84621 .43509 L
.84631 .43503 L
.8464 .43492 L
Mistroke
.8465 .4347 L
.8466 .43441 L
.84678 .43367 L
.84697 .4326 L
.84731 .42995 L
.84768 .42607 L
.84809 .42063 L
.84891 .40618 L
.84965 .38942 L
.85133 .34287 L
.85299 .29193 L
.85453 .2485 L
.8553 .23031 L
.85602 .21624 L
.85677 .20517 L
.85717 .20092 L
.85738 .19918 L
.85761 .19767 L
.85771 .19708 L
.85781 .19661 L
.85791 .19622 L
.858 .19593 L
.85809 .19571 L
.85818 .19554 L
.85827 .19543 L
.85837 .19539 L
.85843 .1954 L
.85848 .19544 L
.85858 .19556 L
.85864 .19565 L
.85869 .19577 L
.85881 .1961 L
.859 .19689 L
.85921 .19805 L
.85943 .19962 L
.85967 .20171 L
.8601 .20652 L
.86091 .21876 L
.86167 .23388 L
.86251 .2536 L
.8642 .29936 L
.8659 .34577 L
.86745 .38083 L
.86822 .39385 L
.86862 .39928 L
.86905 .40388 L
.86943 .40687 L
.86964 .40814 L
.86974 .40861 L
.86984 .40904 L
Mistroke
.86993 .40934 L
.87003 .40962 L
.87012 .40981 L
.8702 .40994 L
.87029 .41003 L
.87038 .41006 L
.87048 .41003 L
.87057 .40993 L
.87067 .40978 L
.87077 .40954 L
.87095 .40895 L
.87116 .40795 L
.87136 .40677 L
.87178 .40333 L
.87218 .39901 L
.87289 .38905 L
.87367 .37521 L
.87694 .29762 L
.87856 .26046 L
.87935 .24556 L
.88008 .23458 L
.88079 .22674 L
.88115 .22394 L
.88135 .22271 L
.88154 .22177 L
.88164 .22138 L
.88174 .22102 L
.88183 .22078 L
.88193 .22057 L
.88204 .22041 L
.8821 .22035 L
.88215 .22032 L
.88225 .22031 L
.88235 .22036 L
.88245 .22047 L
.88255 .22066 L
.88265 .2209 L
.88275 .22119 L
.88292 .22186 L
.88311 .22279 L
.88354 .22573 L
.88394 .22938 L
.88483 .24069 L
.88562 .2537 L
.88645 .26983 L
.8895 .33594 L
.89106 .36397 L
.89151 .37025 L
.89194 .3753 L
.89232 .37901 L
Mistroke
.89252 .38068 L
.89274 .38222 L
.89295 .38345 L
.89314 .38436 L
.89332 .38505 L
.89342 .38534 L
.89352 .38556 L
.89362 .38574 L
.89372 .38587 L
.89382 .38594 L
.89391 .38596 L
.89396 .38594 L
.89402 .38591 L
.89412 .38581 L
.89417 .38574 L
.89422 .38565 L
.89434 .38539 L
.89453 .38481 L
.89471 .38407 L
.89505 .3822 L
.89542 .37952 L
.89582 .37583 L
.89665 .36584 L
.8974 .35448 L
.89909 .32385 L
.90076 .2916 L
.9015 .27865 L
.90231 .26615 L
.90303 .25684 L
.90381 .24936 L
.90425 .24642 L
.90445 .24535 L
.90464 .24454 L
.90483 .2439 L
.90492 .24365 L
.90503 .24342 L
.90513 .24326 L
.90521 .24316 L
.90531 .24309 L
.90541 .24307 L
.90551 .24309 L
.9056 .24316 L
.9057 .24329 L
.9058 .24346 L
.90598 .24389 L
.90618 .24453 L
.90639 .24544 L
.90661 .24664 L
.90702 .24935 L
.90783 .25685 L
Mistroke
.90871 .26781 L
.91195 .3199 L
.91345 .34201 L
.91429 .35186 L
.91508 .35871 L
.91547 .36124 L
.91569 .3624 L
.9159 .36327 L
.91612 .36399 L
.91623 .36429 L
.91635 .36454 L
.91646 .3647 L
.91656 .36481 L
.91661 .36486 L
.91666 .36489 L
.91672 .36491 L
.91678 .36491 L
.91687 .36489 L
.91697 .36482 L
.91703 .36477 L
.91708 .3647 L
.91718 .36454 L
.91738 .36412 L
.91755 .36359 L
.91798 .36178 L
.91839 .35937 L
.91916 .35319 L
.91999 .34454 L
.92146 .32528 L
.92307 .30236 L
.92391 .291 L
.9248 .28041 L
.9256 .27263 L
.92602 .2693 L
.92648 .26641 L
.92669 .26529 L
.9269 .26439 L
.92709 .26366 L
.92728 .26311 L
.92745 .2627 L
.92754 .26254 L
.92763 .26239 L
.92773 .26228 L
.92782 .26221 L
.92792 .26216 L
.92802 .26216 L
.92812 .26219 L
.92822 .26226 L
.92831 .26234 L
.9284 .26247 L
Mistroke
.92861 .26288 L
.92881 .26339 L
.92916 .26468 L
.92954 .26651 L
.93033 .27181 L
.9312 .27959 L
.93444 .31719 L
.93593 .33286 L
.93678 .33969 L
.93718 .34228 L
.93756 .34429 L
.93777 .34522 L
.93799 .34606 L
.93818 .34664 L
.93838 .34715 L
.93849 .34737 L
.93861 .34756 L
.93873 .34771 L
.93878 .34777 L
.93884 .34782 L
.9389 .34785 L
.93895 .34788 L
.93901 .34789 L
.93906 .3479 L
.93916 .34788 L
.93926 .34784 L
.93931 .3478 L
.93937 .34775 L
.93947 .34764 L
.93966 .34734 L
.93989 .34684 L
.94009 .34625 L
.94047 .34484 L
.94088 .34291 L
.9417 .33768 L
.94259 .33042 L
.94421 .31471 L
.94578 .29915 L
.94661 .29185 L
.9475 .28535 L
.94794 .28275 L
.94836 .28072 L
.94873 .27926 L
.94893 .27865 L
.94914 .2781 L
.94934 .27769 L
.94953 .2774 L
.94963 .27728 L
.94972 .27719 L
.94983 .27713 L
Mistroke
.94988 .27711 L
.94994 .27709 L
.95003 .27708 L
.95012 .2771 L
.95022 .27714 L
.95032 .27721 L
.95041 .27729 L
.95049 .27739 L
.95067 .27766 L
.95087 .27805 L
.95105 .27849 L
.95145 .27977 L
.95218 .28301 L
.95303 .28812 L
.95383 .29398 L
.9569 .31896 L
.95772 .3246 L
.95849 .32897 L
.95891 .33093 L
.95937 .33263 L
.95957 .33324 L
.95979 .33379 L
.95997 .33418 L
.96017 .33451 L
.96028 .33466 L
.96038 .33477 L
.96047 .33485 L
.96057 .33492 L
.96066 .33496 L
.96075 .33499 L
.96084 .33499 L
.96093 .33498 L
.96103 .33494 L
.96109 .33491 L
.96114 .33488 L
.96125 .33479 L
.96136 .33468 L
.96156 .33439 L
.96175 .33406 L
.96211 .33319 L
.96251 .33196 L
.96322 .32902 L
.96482 .31988 L
.96651 .30838 L
.9681 .29832 L
.9688 .29472 L
.96955 .29159 L
.96997 .29027 L
.97036 .28932 L
.97073 .28866 L
Mistroke
.97091 .28842 L
.97101 .28832 L
.97112 .28823 L
.97122 .28816 L
.97128 .28813 L
.97134 .28811 L
.97143 .28809 L
.97153 .28809 L
.97159 .28809 L
.97166 .2881 L
.97171 .28812 L
.97177 .28815 L
.97187 .2882 L
.97198 .28829 L
.97218 .28849 L
.97237 .28875 L
.9728 .28956 L
.9732 .29058 L
.97363 .29196 L
.97442 .29513 L
.97591 .30265 L
.97619 .30421 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{421.375, 260.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 525.688}, {324.5, 0}} -> {-2.58312*^-7, -6.34248*^6, \
6.65005*^-9, 53093.5}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0.309017 5.42214e-08 [
[.32684 .29652 -16.5 -12.5 ]
[.32684 .29652 16.5 0 ]
[.54329 .29652 -16.5 -12.5 ]
[.54329 .29652 16.5 0 ]
[.75974 .29652 -22.5 -12.5 ]
[.75974 .29652 22.5 0 ]
[.97619 .29652 -16.5 -12.5 ]
[.97619 .29652 16.5 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 64 6 ]
[.09789 .09213 -34.5 -6.25 ]
[.09789 .09213 0 6.25 ]
[.09789 .20057 -34.5 -6.25 ]
[.09789 .20057 0 6.25 ]
[.09789 .41746 -28.5 -6.25 ]
[.09789 .41746 0 6.25 ]
[.09789 .5259 -28.5 -6.25 ]
[.09789 .5259 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -65.8125 0 ]
[.5 .63053 65.8125 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 .30902 m
.32684 .31527 L
s
gsave
.32684 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 .30902 m
.54329 .31527 L
s
gsave
.54329 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 .30902 m
.75974 .31527 L
s
gsave
.75974 .29652 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 .30902 m
.15368 .31277 L
s
.19697 .30902 m
.19697 .31277 L
s
.24026 .30902 m
.24026 .31277 L
s
.28355 .30902 m
.28355 .31277 L
s
.37013 .30902 m
.37013 .31277 L
s
.41342 .30902 m
.41342 .31277 L
s
.45671 .30902 m
.45671 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.58658 .30902 m
.58658 .31277 L
s
.62987 .30902 m
.62987 .31277 L
s
.67316 .30902 m
.67316 .31277 L
s
.71645 .30902 m
.71645 .31277 L
s
.80303 .30902 m
.80303 .31277 L
s
.84632 .30902 m
.84632 .31277 L
s
.88961 .30902 m
.88961 .31277 L
s
.9329 .30902 m
.9329 .31277 L
s
.0671 .30902 m
.0671 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09213 m
.11664 .09213 L
s
gsave
.09789 .09213 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .20057 m
.11664 .20057 L
s
gsave
.09789 .20057 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .41746 m
.11664 .41746 L
s
gsave
.09789 .41746 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .5259 m
.11664 .5259 L
s
gsave
.09789 .5259 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.11039 .11924 m
.11414 .11924 L
s
.11039 .14635 m
.11414 .14635 L
s
.11039 .17346 m
.11414 .17346 L
s
.11039 .22768 m
.11414 .22768 L
s
.11039 .2548 m
.11414 .2548 L
s
.11039 .28191 m
.11414 .28191 L
s
.11039 .33613 m
.11414 .33613 L
s
.11039 .36324 m
.11414 .36324 L
s
.11039 .39035 m
.11414 .39035 L
s
.11039 .44457 m
.11414 .44457 L
s
.11039 .47168 m
.11414 .47168 L
s
.11039 .49879 m
.11414 .49879 L
s
.11039 .06502 m
.11414 .06502 L
s
.11039 .03791 m
.11414 .03791 L
s
.11039 .0108 m
.11414 .0108 L
s
.11039 .55301 m
.11414 .55301 L
s
.11039 .58012 m
.11414 .58012 L
s
.11039 .60723 m
.11414 .60723 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -126.812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.812 moveto
(@) show
81.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.812 moveto
(D) show
93.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13.4) show
141.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
147.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
159.000 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
163.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
172.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
190.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02691 .30902 L
.03029 .30902 L
.03347 .30902 L
.03652 .30902 L
.03978 .30902 L
.04291 .30902 L
.04623 .30902 L
.04944 .30902 L
.05252 .30902 L
.0558 .30902 L
.05896 .30902 L
.062 .30902 L
.06523 .30902 L
.06834 .30902 L
.07165 .30902 L
.07484 .30902 L
.0779 .30902 L
.08117 .30902 L
.08431 .30902 L
.08603 .30902 L
.08681 .30902 L
.08765 .30902 L
.08802 .30902 L
.08841 .30902 L
.08864 .30902 L
.08885 .30902 L
.08906 .30902 L
.08915 .30902 L
.08926 .30902 L
.08934 .30902 L
.08944 .30902 L
.08953 .30902 L
.08963 .30902 L
.08971 .30902 L
.0898 .30902 L
.08988 .30902 L
.08997 .30902 L
.09007 .30902 L
.09016 .30902 L
.09037 .30902 L
.09056 .30902 L
.09074 .30902 L
.09111 .30902 L
.09152 .30902 L
.09195 .30902 L
.09235 .30902 L
.09306 .30902 L
.09383 .30902 L
.09464 .30902 L
Mistroke
.09553 .30902 L
.09714 .30902 L
.09872 .30902 L
.10041 .30902 L
.10213 .30902 L
.10375 .30902 L
.10685 .30902 L
.10845 .30902 L
.11014 .30902 L
.11319 .30902 L
.11644 .30902 L
.11957 .30902 L
.1229 .30902 L
.1261 .30902 L
.12918 .30902 L
.13246 .30902 L
.13561 .30902 L
.13865 .30902 L
.14188 .30902 L
.14499 .30902 L
.14829 .30902 L
.15148 .30902 L
.15454 .30902 L
.1578 .30902 L
.16094 .30902 L
.16427 .30902 L
.16749 .30902 L
.17058 .30902 L
.17387 .30902 L
.17551 .30902 L
.17704 .30902 L
.1786 .30902 L
.18008 .30902 L
.18086 .30902 L
.1813 .30902 L
.18151 .30902 L
.18171 .30902 L
.18189 .30902 L
.18206 .30902 L
.18224 .30902 L
.18233 .30902 L
.18243 .30902 L
.18253 .30902 L
.18262 .30902 L
.18272 .30902 L
.1828 .30902 L
.1829 .30902 L
.18296 .30902 L
.18301 .30902 L
.1832 .30902 L
Mistroke
.1833 .30902 L
.1834 .30902 L
.18358 .30902 L
.18398 .30902 L
.18433 .30902 L
.18471 .30902 L
.18556 .30902 L
.18636 .30902 L
.18721 .30902 L
.18801 .30902 L
.1895 .30902 L
.19112 .30902 L
.1926 .30902 L
.19411 .30902 L
.19577 .30902 L
.19902 .30902 L
.20214 .30902 L
.20546 .30902 L
.20866 .30902 L
.21174 .30902 L
.21502 .30902 L
.21817 .30902 L
.2212 .30902 L
.22443 .30902 L
.22754 .30902 L
.23084 .30902 L
.23249 .30902 L
.23402 .30902 L
.2355 .30902 L
.23633 .30902 L
.23669 .30902 L
.23708 .30902 L
.23747 .30902 L
.23769 .30902 L
.23779 .30902 L
.23789 .30902 L
.23798 .30902 L
.23807 .30902 L
.23816 .30902 L
.23824 .30902 L
.23834 .30902 L
.23843 .30902 L
.23853 .30902 L
.23863 .30902 L
.23872 .30902 L
.23883 .30902 L
.23904 .30902 L
.23924 .30902 L
.23943 .30902 L
.23985 .30902 L
Mistroke
.24029 .30902 L
.24111 .30902 L
.24158 .30902 L
.242 .30902 L
.24284 .30902 L
.24362 .30902 L
.24512 .30902 L
.24678 .30902 L
.2484 .30902 L
.24989 .30902 L
.25308 .30902 L
.25614 .30902 L
.2594 .30902 L
.26254 .30902 L
.26588 .30902 L
.26909 .30902 L
.27219 .30902 L
.27548 .30902 L
.27712 .30902 L
.27865 .30902 L
.2794 .30902 L
.28012 .30902 L
.28051 .30902 L
.28094 .30902 L
.28133 .30902 L
.28151 .30902 L
.28169 .30902 L
.28179 .30902 L
.28189 .30902 L
.28198 .30902 L
.28206 .30902 L
.28216 .30902 L
.28222 .30902 L
.28227 .30902 L
.28236 .30902 L
.28246 .30902 L
.28255 .30902 L
.28265 .30902 L
.28275 .30902 L
.28284 .30902 L
.28301 .30902 L
.28319 .30902 L
.2834 .30902 L
.28363 .30902 L
.28405 .30902 L
.28446 .30902 L
.28484 .30902 L
.28569 .30902 L
.28649 .30902 L
.28799 .30902 L
Mistroke
.2896 .30902 L
.29109 .30902 L
.29426 .30902 L
.29731 .30902 L
.30056 .30902 L
.30368 .30902 L
.30701 .30901 L
.31021 .30901 L
.31329 .30901 L
.31485 .30901 L
.31567 .30901 L
.31656 .30901 L
.31741 .30901 L
.31779 .30901 L
.31819 .30901 L
.31855 .30901 L
.31894 .30901 L
.31915 .30901 L
.31934 .30901 L
.31944 .30901 L
.31954 .30901 L
.31963 .30901 L
.31972 .30901 L
.31982 .30901 L
.31992 .30901 L
.32 .30901 L
.3201 .30901 L
.3202 .30901 L
.32025 .30901 L
.32031 .30901 L
.32041 .30901 L
.3205 .30901 L
.32068 .30901 L
.32087 .30901 L
.32123 .30901 L
.32161 .30901 L
.32203 .30901 L
.32289 .30901 L
.32371 .30901 L
.32446 .30901 L
.32614 .30901 L
.32767 .30901 L
.32934 .30902 L
.33262 .30902 L
.33578 .30902 L
.33882 .30902 L
.34206 .30903 L
.34517 .30903 L
.34675 .30903 L
.34848 .30903 L
Mistroke
.34928 .30903 L
.35013 .30903 L
.35093 .30904 L
.35167 .30904 L
.35207 .30904 L
.35227 .30904 L
.35249 .30904 L
.35261 .30904 L
.35271 .30904 L
.35282 .30904 L
.35292 .30904 L
.35297 .30904 L
.35303 .30904 L
.35309 .30904 L
.35316 .30904 L
.35321 .30904 L
.35327 .30904 L
.35333 .30904 L
.35338 .30904 L
.35348 .30904 L
.35358 .30904 L
.35367 .30904 L
.35376 .30904 L
.35397 .30904 L
.35417 .30904 L
.35457 .30904 L
.355 .30904 L
.3554 .30904 L
.35576 .30904 L
.3566 .30903 L
.35741 .30903 L
.35829 .30903 L
.35999 .30903 L
.3616 .30903 L
.36467 .30902 L
.36794 .30901 L
.37109 .30899 L
.37443 .30898 L
.37765 .30896 L
.37913 .30896 L
.37997 .30896 L
.38075 .30895 L
.38152 .30895 L
.38196 .30895 L
.38235 .30895 L
.38257 .30895 L
.38277 .30895 L
.38299 .30895 L
.3831 .30895 L
.38316 .30895 L
Mistroke
.38322 .30895 L
.38327 .30895 L
.38333 .30895 L
.38343 .30895 L
.38348 .30895 L
.38354 .30895 L
.38365 .30895 L
.3837 .30895 L
.38375 .30895 L
.38386 .30895 L
.38395 .30895 L
.38404 .30895 L
.38424 .30895 L
.38442 .30895 L
.38483 .30895 L
.3852 .30895 L
.38555 .30895 L
.38635 .30895 L
.38721 .30896 L
.3888 .30897 L
.39048 .30898 L
.39351 .309 L
.39674 .30904 L
.39984 .30909 L
.40314 .30914 L
.40479 .30916 L
.40632 .30918 L
.4078 .30919 L
.40862 .3092 L
.40938 .30921 L
.40976 .30921 L
.41018 .30921 L
.41053 .30921 L
.41073 .30921 L
.41082 .30921 L
.41091 .30921 L
.41102 .30921 L
.41107 .30921 L
.41113 .30921 L
.41119 .30921 L
.41124 .30921 L
.41133 .30921 L
.41143 .30921 L
.41152 .30921 L
.41162 .30921 L
.41172 .30921 L
.41182 .30921 L
.41193 .30921 L
.41213 .30921 L
.41237 .30921 L
Mistroke
.41258 .30921 L
.41297 .30921 L
.41338 .3092 L
.41412 .3092 L
.41491 .30919 L
.41578 .30918 L
.41734 .30915 L
.41901 .30911 L
.42232 .30901 L
.4255 .30888 L
.42856 .30875 L
.43027 .30868 L
.43182 .30863 L
.43345 .30858 L
.43417 .30856 L
.43496 .30855 L
.4357 .30854 L
.43611 .30853 L
.4363 .30853 L
.4365 .30853 L
.43661 .30853 L
.43671 .30853 L
.43682 .30853 L
.43692 .30853 L
.43701 .30853 L
.4371 .30853 L
.4372 .30853 L
.4373 .30853 L
.43741 .30853 L
.43747 .30853 L
.43752 .30853 L
.43763 .30853 L
.43775 .30853 L
.43797 .30853 L
.43817 .30853 L
.43855 .30854 L
.43897 .30854 L
.4397 .30856 L
.4405 .30858 L
.44137 .3086 L
.44293 .30867 L
.4446 .30878 L
.44791 .30904 L
.4511 .30936 L
.45417 .30968 L
.45588 .30984 L
.45743 .30996 L
.4582 .31001 L
.45904 .31005 L
.45943 .31007 L
Mistroke
.45984 .31008 L
.46021 .31009 L
.46057 .3101 L
.46076 .31011 L
.46097 .31011 L
.46106 .31011 L
.46115 .31011 L
.46125 .31011 L
.46133 .31011 L
.46143 .31011 L
.46153 .31011 L
.46162 .31011 L
.46172 .31011 L
.46182 .31011 L
.46192 .31011 L
.46203 .31011 L
.46214 .31011 L
.46233 .31011 L
.46254 .3101 L
.46292 .31009 L
.46328 .31008 L
.46362 .31007 L
.46439 .31003 L
.46512 .30998 L
.46678 .30982 L
.46841 .3096 L
.46989 .30936 L
.47309 .30871 L
.47615 .308 L
.47787 .30763 L
.47942 .30732 L
.48104 .30706 L
.48177 .30697 L
.48257 .30689 L
.48295 .30686 L
.48335 .30683 L
.48358 .30682 L
.48378 .30681 L
.48399 .3068 L
.48408 .3068 L
.48418 .3068 L
.48427 .30679 L
.48436 .30679 L
.48446 .30679 L
.48455 .30679 L
.48464 .30679 L
.48473 .30679 L
.48481 .30679 L
.48489 .30679 L
.48499 .30679 L
Mistroke
.48509 .30679 L
.48529 .3068 L
.48548 .30681 L
.48566 .30681 L
.48604 .30683 L
.48645 .30686 L
.48727 .30695 L
.48804 .30706 L
.48876 .30719 L
.49039 .30758 L
.49188 .30804 L
.49507 .30931 L
.49814 .31072 L
.4997 .31142 L
.50141 .31211 L
.5022 .31238 L
.50304 .31264 L
.50383 .31284 L
.50456 .31299 L
.50497 .31305 L
.50533 .3131 L
.50574 .31314 L
.50596 .31315 L
.50606 .31316 L
.50617 .31316 L
.50628 .31317 L
.50638 .31317 L
.50648 .31317 L
.50654 .31317 L
.50659 .31317 L
.50669 .31317 L
.50679 .31317 L
.50689 .31317 L
.50698 .31317 L
.5071 .31316 L
.50721 .31316 L
.50741 .31314 L
.50763 .31312 L
.50786 .3131 L
.50826 .31304 L
.50863 .31298 L
.50946 .31278 L
.51028 .31252 L
.51116 .31218 L
.51286 .31129 L
.51448 .31022 L
.51755 .30776 L
.52083 .30499 L
.52246 .30377 L
.52398 .30283 L
Mistroke
.52469 .30248 L
.52544 .30219 L
.52583 .30207 L
.52626 .30196 L
.52645 .30192 L
.52665 .30188 L
.52682 .30186 L
.52701 .30184 L
.52711 .30183 L
.52722 .30182 L
.52728 .30182 L
.52734 .30182 L
.52739 .30181 L
.52744 .30181 L
.52754 .30181 L
.52764 .30181 L
.52774 .30181 L
.52784 .30182 L
.5279 .30182 L
.52795 .30182 L
.52808 .30183 L
.5283 .30186 L
.52851 .30189 L
.52873 .30193 L
.52913 .30202 L
.5295 .30214 L
.53035 .30249 L
.53119 .30297 L
.53198 .30355 L
.53347 .30492 L
.53656 .30874 L
.53984 .31355 L
.54147 .31587 L
.54299 .31779 L
.54445 .31926 L
.54528 .3199 L
.54603 .32033 L
.54641 .32049 L
.54662 .32056 L
.54682 .32062 L
.547 .32066 L
.5471 .32068 L
.5472 .3207 L
.54729 .32071 L
.54738 .32072 L
.54747 .32073 L
.54755 .32073 L
.54765 .32074 L
.54771 .32074 L
.54777 .32074 L
Mistroke
.54787 .32073 L
.54797 .32073 L
.54806 .32072 L
.54815 .32071 L
.54835 .32067 L
.54857 .32062 L
.54877 .32056 L
.54921 .32038 L
.54959 .32018 L
.55 .31992 L
.55073 .31931 L
.5516 .31836 L
.55239 .3173 L
.5556 .31135 L
.55869 .30407 L
.56025 .30034 L
.56197 .29662 L
.56276 .29513 L
.5636 .29375 L
.5644 .29267 L
.56513 .2919 L
.56553 .29158 L
.56594 .29131 L
.56618 .2912 L
.56641 .29111 L
.56661 .29106 L
.56673 .29104 L
.56683 .29102 L
.56692 .29101 L
.56702 .29101 L
.56712 .29101 L
.5672 .29101 L
.56731 .29102 L
.56736 .29103 L
.56742 .29104 L
.56752 .29106 L
.56762 .29109 L
.56781 .29115 L
.56802 .29124 L
.56844 .29149 L
.56882 .2918 L
.56923 .29221 L
.57007 .29332 L
.57084 .29466 L
.57155 .29615 L
.57469 .30523 L
.57802 .31743 L
.57969 .32344 L
.58123 .3283 L
.58274 .33204 L
Mistroke
.58349 .33345 L
.58392 .33408 L
.58432 .33456 L
.58472 .33492 L
.58494 .33507 L
.58514 .33518 L
.58531 .33524 L
.58541 .33527 L
.5855 .33529 L
.5856 .33531 L
.58569 .33531 L
.58579 .33531 L
.58589 .3353 L
.58599 .33529 L
.58609 .33526 L
.5862 .33523 L
.5863 .33519 L
.58649 .33509 L
.58669 .33496 L
.58714 .33453 L
.58757 .33399 L
.58834 .33262 L
.58907 .33091 L
.59072 .32555 L
.59235 .31858 L
.59384 .31111 L
.59702 .29379 L
.59863 .28573 L
.60009 .27961 L
.60085 .27704 L
.60167 .27484 L
.60212 .27391 L
.60254 .27323 L
.60293 .27276 L
.60313 .27259 L
.60325 .27251 L
.60335 .27245 L
.60345 .2724 L
.60355 .27237 L
.60366 .27235 L
.60372 .27234 L
.60377 .27234 L
.60387 .27234 L
.60397 .27235 L
.60407 .27238 L
.60417 .27242 L
.60426 .27246 L
.60436 .27252 L
.60453 .27265 L
.60473 .27285 L
Mistroke
.60492 .27307 L
.60533 .27372 L
.60578 .27464 L
.6066 .27693 L
.60736 .27974 L
.60819 .28355 L
.60988 .29327 L
.61312 .31686 L
.61624 .33972 L
.61705 .34475 L
.61794 .34949 L
.61878 .35316 L
.61955 .35567 L
.61994 .35662 L
.62015 .35703 L
.62037 .3574 L
.62056 .35765 L
.62066 .35777 L
.62077 .35787 L
.62087 .35795 L
.62096 .35801 L
.62105 .35805 L
.62113 .35808 L
.62123 .3581 L
.62129 .3581 L
.62134 .3581 L
.62144 .35809 L
.6215 .35807 L
.62155 .35805 L
.62164 .35801 L
.62174 .35794 L
.62194 .35777 L
.62216 .35749 L
.6224 .35712 L
.62282 .3562 L
.62325 .35497 L
.62364 .35357 L
.62453 .34947 L
.62615 .33902 L
.62932 .31008 L
.63237 .27892 L
.63406 .26388 L
.63561 .25343 L
.63638 .24976 L
.63681 .24819 L
.63721 .24707 L
.63756 .24637 L
.63766 .24623 L
.63776 .24609 L
.63786 .24599 L
Mistroke
.63795 .24591 L
.63804 .24585 L
.63815 .2458 L
.63825 .24578 L
.6383 .24577 L
.63835 .24578 L
.63845 .2458 L
.63855 .24584 L
.63864 .2459 L
.63873 .24598 L
.63892 .24621 L
.6391 .2465 L
.63951 .24741 L
.63988 .24859 L
.64023 .24999 L
.64103 .25412 L
.64189 .26015 L
.64347 .27486 L
.64515 .29466 L
.64849 .33904 L
.65017 .3594 L
.6509 .3671 L
.65171 .37437 L
.65244 .37972 L
.65322 .38403 L
.65365 .38572 L
.65404 .38683 L
.65423 .3872 L
.65433 .38736 L
.65443 .3875 L
.65453 .38759 L
.65463 .38767 L
.65472 .38771 L
.65481 .38772 L
.6549 .38772 L
.655 .38768 L
.6551 .38762 L
.65518 .38754 L
.65529 .38741 L
.6554 .38725 L
.6556 .38685 L
.65581 .38631 L
.65603 .38559 L
.65643 .38394 L
.65714 .37988 L
.65791 .37378 L
.65948 .35683 L
.66115 .33296 L
.66447 .27788 L
.66613 .2521 L
Mistroke
.66693 .24122 L
.66766 .23266 L
.66838 .22565 L
.66915 .21983 L
.66958 .21746 L
.66976 .21662 L
.66997 .21583 L
.67015 .21526 L
.67034 .21478 L
.67045 .21457 L
.67054 .21442 L
.67064 .2143 L
.67073 .21422 L
.67083 .21417 L
.67093 .21415 L
.67102 .21417 L
.6711 .21421 L
.6712 .2143 L
.67126 .21436 L
.67131 .21443 L
.67151 .2148 L
.67172 .21534 L
.67191 .21597 L
.67234 .21787 L
.6727 .22005 L
.6731 .22295 L
.67382 .22962 L
.67542 .25052 L
.67711 .27988 L
.68015 .34151 L
.68185 .37381 L
.6834 .39775 L
.68417 .40682 L
.68457 .41073 L
.685 .41417 L
.68538 .41654 L
.68558 .41756 L
.68579 .41846 L
.68599 .41911 L
.68607 .41934 L
.68617 .41955 L
.68625 .41971 L
.68634 .41984 L
.68643 .41994 L
.68652 .42 L
.68662 .42002 L
.68668 .42002 L
.68673 .42 L
.68683 .41992 L
.68689 .41985 L
Mistroke
.68695 .41978 L
.68705 .41961 L
.68715 .41939 L
.68734 .41884 L
.68757 .41799 L
.68781 .41683 L
.68823 .41409 L
.68867 .41046 L
.68908 .40628 L
.68985 .39657 L
.69147 .36901 L
.69295 .33708 L
.69612 .26114 L
.69772 .22695 L
.69917 .20263 L
.69956 .1976 L
.69998 .19291 L
.70034 .18953 L
.70074 .18656 L
.70095 .18536 L
.70117 .18431 L
.70129 .18384 L
.7014 .18347 L
.70151 .18317 L
.70161 .18295 L
.70171 .18281 L
.7018 .18271 L
.70186 .18267 L
.70191 .18265 L
.70201 .18266 L
.70211 .18272 L
.70221 .18283 L
.70231 .183 L
.70242 .18325 L
.70263 .18389 L
.70282 .1847 L
.70318 .18676 L
.70357 .18978 L
.704 .19397 L
.70476 .20383 L
.70547 .21546 L
.70696 .24686 L
.70861 .28937 L
.71184 .37725 L
.71332 .4109 L
.71416 .42608 L
.71457 .43224 L
.71494 .43707 L
.71531 .44114 L
.71572 .44465 L
Mistroke
.71594 .44616 L
.71614 .44729 L
.71634 .44814 L
.71645 .4485 L
.71655 .44877 L
.71665 .44899 L
.71675 .44913 L
.71685 .44922 L
.71691 .44924 L
.71696 .44924 L
.71706 .44919 L
.71715 .44909 L
.71725 .44891 L
.71735 .44869 L
.71746 .44836 L
.71757 .44794 L
.71778 .44698 L
.718 .44566 L
.71824 .44386 L
.71866 .43986 L
.71906 .43508 L
.71981 .42365 L
.72148 .38745 L
.72456 .29709 L
.72612 .24943 L
.72784 .20373 L
.72862 .18703 L
.72903 .17956 L
.72946 .17277 L
.72984 .16775 L
.73026 .16332 L
.73044 .16174 L
.73064 .16031 L
.7308 .15928 L
.73099 .15838 L
.73109 .15799 L
.7312 .15765 L
.73126 .1575 L
.73131 .15738 L
.73137 .15728 L
.73142 .15721 L
.73151 .15712 L
.73162 .15711 L
.73171 .15716 L
.73181 .15728 L
.73187 .15739 L
.73193 .15751 L
.73205 .15787 L
.73216 .15827 L
.73228 .1588 L
Mistroke
.73248 .15993 L
.7327 .16151 L
.73311 .16528 L
.73354 .17055 L
.73432 .18318 L
.73514 .20044 L
.73603 .22324 L
.73765 .27276 L
.74092 .38231 L
.74171 .40549 L
.74255 .4274 L
.74328 .4432 L
.74408 .45659 L
.7445 .46188 L
.74471 .46399 L
.74489 .46564 L
.74507 .46698 L
.74527 .46815 L
.74537 .46867 L
.74547 .46907 L
.74557 .46938 L
.74567 .46964 L
.74576 .4698 L
.74584 .4699 L
.74592 .46994 L
.746 .46993 L
.74609 .46985 L
.74618 .46973 L
.74627 .46952 L
.74637 .46923 L
.74655 .46848 L
.74673 .46755 L
.74712 .46456 L
.74749 .46057 L
.7479 .45499 L
.74874 .44004 L
.75022 .40241 L
.75347 .29027 L
.75498 .23725 L
.75661 .18849 L
.7575 .16805 L
.75789 .16078 L
.75832 .15408 L
.75872 .14908 L
.7591 .14559 L
.75931 .14418 L
.7595 .1432 L
.75961 .1428 L
.75967 .14262 L
.75973 .14246 L
Mistroke
.75978 .14233 L
.75983 .14224 L
.75994 .14213 L
.76003 .14211 L
.76012 .14216 L
.76022 .14229 L
.76033 .14253 L
.76044 .14287 L
.76054 .1433 L
.76074 .14435 L
.76093 .14563 L
.7611 .14706 L
.76148 .15119 L
.76187 .15653 L
.76229 .16376 L
.76315 .18247 L
.76471 .22802 L
.76638 .28841 L
.76796 .34856 L
.76969 .40863 L
.77049 .43183 L
.77134 .45215 L
.77175 .46012 L
.77214 .46641 L
.77252 .4713 L
.77287 .47477 L
.77305 .47613 L
.77324 .47727 L
.77335 .47778 L
.77346 .47816 L
.77355 .47842 L
.77365 .47861 L
.77371 .47868 L
.77376 .47871 L
.77386 .47871 L
.77392 .47868 L
.77397 .47862 L
.77402 .47853 L
.77408 .4784 L
.77418 .47812 L
.77427 .47779 L
.77448 .47674 L
.77467 .47543 L
.77485 .47389 L
.7752 .47023 L
.77556 .46518 L
.77596 .45844 L
.77672 .44218 L
.77755 .41958 L
.77924 .3623 L
Mistroke
.78247 .23823 L
.78396 .19018 L
.7848 .16892 L
.78559 .15398 L
.78602 .14793 L
.78641 .14384 L
.78662 .14217 L
.78674 .14146 L
.78686 .14083 L
.78696 .1404 L
.78702 .14021 L
.78708 .14004 L
.78718 .13982 L
.78728 .1397 L
.78734 .13968 L
.78739 .13968 L
.78749 .13976 L
.78755 .13984 L
.7876 .13994 L
.78772 .14027 L
.78782 .14066 L
.78791 .1411 L
.78813 .1424 L
.78831 .14381 L
.7885 .14569 L
.7889 .15051 L
.78932 .1572 L
.78972 .16489 L
.79047 .18263 L
.79215 .23557 L
.79524 .35478 L
.7968 .40971 L
.79763 .43364 L
.79809 .44481 L
.79852 .45393 L
.79893 .46111 L
.79938 .46729 L
.79957 .46945 L
.79978 .47137 L
.79998 .47281 L
.80016 .47381 L
.80025 .47423 L
.80036 .47457 L
.80046 .47482 L
.80052 .47491 L
.80057 .47497 L
.80067 .47501 L
.80076 .47497 L
.80086 .47483 L
.80096 .4746 L
Mistroke
.80105 .47432 L
.80114 .47395 L
.80131 .47307 L
.80149 .47183 L
.80169 .47012 L
.80208 .46565 L
.8025 .45944 L
.80324 .44474 L
.80404 .42421 L
.80492 .39708 L
.80818 .27416 L
.80968 .22044 L
.81048 .19656 L
.81131 .17587 L
.81174 .16743 L
.81221 .1599 L
.81241 .1572 L
.81263 .15472 L
.81284 .1528 L
.81303 .15137 L
.81324 .15019 L
.81335 .14973 L
.8134 .14954 L
.81347 .14937 L
.81357 .14916 L
.81366 .14905 L
.81372 .14902 L
.81377 .14902 L
.81388 .14911 L
.81397 .14927 L
.81407 .14953 L
.81416 .14985 L
.81425 .15022 L
.81445 .1514 L
.81465 .15289 L
.81502 .15664 L
.81543 .16219 L
.81625 .17769 L
.81702 .19668 L
.81773 .21789 L
.82085 .33114 L
.82243 .38714 L
.82327 .41227 L
.82416 .43411 L
.82461 .44282 L
.82503 .44953 L
.8254 .45426 L
.8256 .4562 L
.82581 .45795 L
.82601 .45921 L
Mistroke
.8262 .46006 L
.8263 .46039 L
.8264 .4606 L
.82645 .46068 L
.82651 .46075 L
.82661 .46078 L
.8267 .46074 L
.8268 .4606 L
.8269 .46037 L
.82699 .46006 L
.82716 .45931 L
.82735 .45821 L
.82754 .45673 L
.82775 .45478 L
.82812 .45034 L
.82896 .43602 L
.82984 .41513 L
.83065 .39188 L
.83386 .27929 L
.83533 .2307 L
.83617 .20765 L
.83695 .1902 L
.83735 .18311 L
.83772 .17754 L
.83793 .17496 L
.83815 .17257 L
.83836 .17078 L
.83855 .16943 L
.83865 .16881 L
.83877 .16826 L
.83887 .16789 L
.83897 .16758 L
.83903 .16745 L
.83909 .16736 L
.83914 .16729 L
.83921 .16725 L
.83927 .16724 L
.83932 .16726 L
.83942 .16737 L
.83952 .16757 L
.83963 .16786 L
.83972 .1682 L
.83981 .16864 L
.84003 .16993 L
.84024 .17152 L
.84063 .17562 L
.84107 .18159 L
.84186 .1962 L
.84335 .23462 L
.84661 .34286 L
Mistroke
.84812 .38831 L
.84891 .40768 L
.84975 .42364 L
.85017 .42976 L
.8504 .43242 L
.85064 .43481 L
.85087 .43659 L
.85107 .43785 L
.85117 .43833 L
.85127 .43877 L
.85137 .43909 L
.85147 .43932 L
.85156 .43947 L
.85166 .43955 L
.85175 .43955 L
.85184 .43948 L
.85194 .43933 L
.85204 .43909 L
.85215 .43873 L
.85225 .4383 L
.85246 .43715 L
.85265 .43579 L
.85309 .43165 L
.85347 .42667 L
.85389 .42018 L
.85462 .40563 L
.85629 .36179 L
.85933 .26723 L
.86089 .22642 L
.86177 .20929 L
.86216 .20334 L
.86257 .1982 L
.86278 .19603 L
.86299 .19432 L
.86318 .19295 L
.86336 .19195 L
.86353 .19124 L
.86362 .19097 L
.86371 .19074 L
.86381 .19058 L
.86391 .1905 L
.86401 .19049 L
.8641 .19054 L
.8642 .19069 L
.86425 .19079 L
.86431 .19093 L
.86451 .1916 L
.86462 .19211 L
.86474 .19277 L
.86495 .19423 L
Mistroke
.86537 .1981 L
.86576 .20278 L
.86655 .21543 L
.86728 .23053 L
.86894 .27345 L
.87208 .36157 L
.8729 .38047 L
.8738 .39693 L
.87421 .40286 L
.87464 .40793 L
.87501 .41122 L
.87522 .41266 L
.87542 .41372 L
.87552 .41416 L
.87562 .41454 L
.87571 .4148 L
.87582 .41502 L
.87587 .41511 L
.87592 .41517 L
.87598 .41521 L
.87604 .41523 L
.87614 .41521 L
.8762 .41516 L
.87625 .4151 L
.87636 .41492 L
.87645 .41467 L
.87664 .41403 L
.87683 .41307 L
.87705 .41173 L
.87742 .40859 L
.87782 .40425 L
.87853 .39397 L
.8801 .36221 L
.88157 .3252 L
.88306 .28637 L
.88468 .24934 L
.88556 .2339 L
.88599 .2279 L
.88638 .2234 L
.88678 .21973 L
.88716 .21722 L
.88737 .21625 L
.88756 .2156 L
.88766 .21536 L
.88772 .21525 L
.88777 .21517 L
.88783 .21511 L
.88789 .21506 L
.88794 .21504 L
.88799 .21504 L
Mistroke
.88809 .21508 L
.88818 .21518 L
.88828 .21534 L
.88836 .21554 L
.88856 .21617 L
.88877 .21712 L
.88897 .21831 L
.88916 .21965 L
.88959 .22351 L
.89031 .23227 L
.89107 .24452 L
.8944 .31774 L
.89607 .35364 L
.89681 .3666 L
.89761 .37805 L
.89799 .38223 L
.89839 .38585 L
.89858 .38728 L
.89877 .38843 L
.89895 .38937 L
.89911 .39005 L
.8993 .39064 L
.89941 .39087 L
.89951 .39102 L
.8996 .39112 L
.89968 .39116 L
.89977 .39116 L
.89987 .3911 L
.89997 .39098 L
.90008 .39079 L
.90018 .39056 L
.90027 .39029 L
.90049 .38943 L
.9007 .38836 L
.90107 .38587 L
.90148 .38227 L
.9023 .37247 L
.90378 .34801 L
.90547 .31402 L
.90701 .28304 L
.90853 .25801 L
.90929 .24877 L
.90972 .24473 L
.91012 .2418 L
.91032 .24066 L
.91053 .23968 L
.91064 .23925 L
.91076 .23886 L
.91087 .23857 L
.91097 .23836 L
Mistroke
.91107 .2382 L
.91117 .2381 L
.91127 .23805 L
.91133 .23805 L
.91138 .23806 L
.91147 .23811 L
.91157 .23822 L
.91167 .23838 L
.91177 .23859 L
.91195 .23911 L
.91214 .23984 L
.91249 .24162 L
.91286 .24417 L
.91326 .2477 L
.91409 .257 L
.91483 .26757 L
.91652 .29602 L
.91818 .32569 L
.91892 .33757 L
.91972 .34904 L
.92044 .35746 L
.92084 .36124 L
.92122 .36421 L
.92143 .36556 L
.92165 .36682 L
.92185 .36777 L
.92204 .36847 L
.92223 .36902 L
.92234 .36925 L
.92244 .36942 L
.92253 .36954 L
.92262 .36961 L
.92271 .36965 L
.92281 .36964 L
.92291 .3696 L
.92296 .36955 L
.92301 .36949 L
.92311 .36936 L
.92321 .36918 L
.92338 .36875 L
.92357 .36812 L
.92399 .36617 L
.92439 .36365 L
.92509 .35761 L
.92586 .34917 L
.92916 .30057 L
.92996 .28899 L
.93081 .27801 L
.93155 .27011 L
.93234 .26358 L
Mistroke
.93277 .26103 L
.93296 .26014 L
.93317 .25932 L
.93337 .25871 L
.93355 .25827 L
.93365 .25809 L
.93374 .25796 L
.93379 .2579 L
.93385 .25785 L
.93395 .25779 L
.93405 .25777 L
.93414 .25779 L
.93423 .25784 L
.93432 .25792 L
.93441 .25804 L
.93452 .25822 L
.93471 .25864 L
.93488 .25915 L
.93504 .25973 L
.93541 .2614 L
.93581 .26381 L
.93625 .26703 L
.93704 .27436 L
.93854 .29184 L
.9401 .31236 L
.94092 .32284 L
.94181 .33298 L
.94267 .34102 L
.94345 .3466 L
.94382 .3486 L
.94402 .34947 L
.94423 .35025 L
.94443 .35086 L
.94461 .35129 L
.9447 .35146 L
.9448 .35161 L
.94489 .35172 L
.94497 .35179 L
.94507 .35185 L
.94517 .35188 L
.94526 .35188 L
.94535 .35184 L
.94545 .35177 L
.9455 .35172 L
.94556 .35166 L
.94575 .35135 L
.94594 .35095 L
.94613 .3504 L
.94648 .34909 L
.94691 .34703 L
Mistroke
.94735 .3443 L
.94814 .33817 L
.9512 .30606 L
.95208 .29676 L
.95291 .28891 L
.95371 .28254 L
.95407 .28022 L
.95446 .27804 L
.95481 .27642 L
.95519 .27507 L
.95539 .27451 L
.95559 .2741 L
.95568 .27394 L
.95578 .2738 L
.95586 .2737 L
.95596 .27361 L
.95602 .27358 L
.95607 .27355 L
.95617 .27352 L
.95627 .27352 L
.95637 .27355 L
.95642 .27358 L
.95648 .27362 L
.95658 .27371 L
.9567 .27386 L
.9568 .27403 L
.957 .27441 L
.95721 .27494 L
.95759 .27622 L
.95798 .27791 L
.95835 .27983 L
.95918 .28527 L
.96087 .29949 L
.96235 .31324 L
.96319 .32053 L
.96398 .32652 L
.96482 .33181 L
.96519 .33366 L
.96559 .33531 L
.96581 .33607 L
.96601 .33666 L
.96621 .33716 L
.96641 .33754 L
.96661 .33784 L
.96672 .33795 L
.96683 .33804 L
.96689 .33808 L
.96695 .33811 L
.96701 .33812 L
.96707 .33813 L
Mistroke
.96717 .33813 L
.96722 .33811 L
.96728 .33809 L
.96738 .33804 L
.96747 .33796 L
.96757 .33786 L
.96767 .33773 L
.96789 .33737 L
.96809 .33694 L
.96847 .33588 L
.96883 .33458 L
.96963 .33078 L
.97051 .32547 L
.97379 .30115 L
.97619 .2882 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{421.375, 260.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 525.688}, {324.5, 0}} -> {-2.58312*^-7, -6.34248*^6, \
6.65005*^-9, 53093.5}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0.309017 5.42214e-08 [
[.32684 .29652 -16.5 -12.5 ]
[.32684 .29652 16.5 0 ]
[.54329 .29652 -16.5 -12.5 ]
[.54329 .29652 16.5 0 ]
[.75974 .29652 -22.5 -12.5 ]
[.75974 .29652 22.5 0 ]
[.97619 .29652 -16.5 -12.5 ]
[.97619 .29652 16.5 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 64 6 ]
[.09789 .09213 -34.5 -6.25 ]
[.09789 .09213 0 6.25 ]
[.09789 .20057 -34.5 -6.25 ]
[.09789 .20057 0 6.25 ]
[.09789 .41746 -28.5 -6.25 ]
[.09789 .41746 0 6.25 ]
[.09789 .5259 -28.5 -6.25 ]
[.09789 .5259 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -65.8125 0 ]
[.5 .63053 65.8125 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 .30902 m
.32684 .31527 L
s
gsave
.32684 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 .30902 m
.54329 .31527 L
s
gsave
.54329 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 .30902 m
.75974 .31527 L
s
gsave
.75974 .29652 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 .30902 m
.15368 .31277 L
s
.19697 .30902 m
.19697 .31277 L
s
.24026 .30902 m
.24026 .31277 L
s
.28355 .30902 m
.28355 .31277 L
s
.37013 .30902 m
.37013 .31277 L
s
.41342 .30902 m
.41342 .31277 L
s
.45671 .30902 m
.45671 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.58658 .30902 m
.58658 .31277 L
s
.62987 .30902 m
.62987 .31277 L
s
.67316 .30902 m
.67316 .31277 L
s
.71645 .30902 m
.71645 .31277 L
s
.80303 .30902 m
.80303 .31277 L
s
.84632 .30902 m
.84632 .31277 L
s
.88961 .30902 m
.88961 .31277 L
s
.9329 .30902 m
.9329 .31277 L
s
.0671 .30902 m
.0671 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09213 m
.11664 .09213 L
s
gsave
.09789 .09213 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .20057 m
.11664 .20057 L
s
gsave
.09789 .20057 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .41746 m
.11664 .41746 L
s
gsave
.09789 .41746 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .5259 m
.11664 .5259 L
s
gsave
.09789 .5259 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.11039 .11924 m
.11414 .11924 L
s
.11039 .14635 m
.11414 .14635 L
s
.11039 .17346 m
.11414 .17346 L
s
.11039 .22768 m
.11414 .22768 L
s
.11039 .2548 m
.11414 .2548 L
s
.11039 .28191 m
.11414 .28191 L
s
.11039 .33613 m
.11414 .33613 L
s
.11039 .36324 m
.11414 .36324 L
s
.11039 .39035 m
.11414 .39035 L
s
.11039 .44457 m
.11414 .44457 L
s
.11039 .47168 m
.11414 .47168 L
s
.11039 .49879 m
.11414 .49879 L
s
.11039 .06502 m
.11414 .06502 L
s
.11039 .03791 m
.11414 .03791 L
s
.11039 .0108 m
.11414 .0108 L
s
.11039 .55301 m
.11414 .55301 L
s
.11039 .58012 m
.11414 .58012 L
s
.11039 .60723 m
.11414 .60723 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -126.812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.812 moveto
(@) show
81.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.812 moveto
(D) show
93.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13.6) show
141.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
147.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
159.000 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
163.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
172.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
190.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02691 .30902 L
.03029 .30902 L
.03347 .30902 L
.03652 .30902 L
.03978 .30902 L
.04291 .30902 L
.04623 .30902 L
.04944 .30902 L
.05252 .30902 L
.0558 .30902 L
.05896 .30902 L
.062 .30902 L
.06523 .30902 L
.06834 .30902 L
.07165 .30902 L
.07484 .30902 L
.0779 .30902 L
.07962 .30902 L
.08117 .30902 L
.08194 .30902 L
.08235 .30902 L
.08278 .30902 L
.08316 .30902 L
.08358 .30902 L
.08376 .30902 L
.08395 .30902 L
.08414 .30902 L
.08431 .30902 L
.0844 .30902 L
.08449 .30902 L
.08459 .30902 L
.08469 .30902 L
.0848 .30902 L
.08485 .30902 L
.08491 .30902 L
.08501 .30902 L
.0851 .30902 L
.0852 .30902 L
.08529 .30902 L
.08546 .30902 L
.08564 .30902 L
.08584 .30902 L
.08626 .30902 L
.08671 .30902 L
.08751 .30902 L
.08826 .30902 L
.08908 .30902 L
.09055 .30902 L
.09136 .30902 L
Mistroke
.09225 .30902 L
.09386 .30902 L
.09544 .30902 L
.09713 .30902 L
.09885 .30902 L
.10047 .30902 L
.10357 .30902 L
.10517 .30902 L
.10686 .30902 L
.10991 .30902 L
.11316 .30902 L
.11629 .30902 L
.11962 .30902 L
.12282 .30902 L
.1259 .30902 L
.12918 .30902 L
.13233 .30902 L
.13537 .30902 L
.1386 .30902 L
.14171 .30902 L
.14501 .30902 L
.1482 .30902 L
.15126 .30902 L
.15452 .30902 L
.15766 .30902 L
.16099 .30902 L
.16421 .30902 L
.1673 .30902 L
.17059 .30902 L
.17376 .30902 L
.1768 .30902 L
.17836 .30902 L
.17924 .30902 L
.18004 .30902 L
.18044 .30902 L
.18086 .30902 L
.18106 .30902 L
.18128 .30902 L
.18141 .30902 L
.18152 .30902 L
.18163 .30902 L
.18169 .30902 L
.18175 .30902 L
.18185 .30902 L
.18194 .30902 L
.18203 .30902 L
.18212 .30902 L
.18222 .30902 L
.18228 .30902 L
.18233 .30902 L
Mistroke
.18244 .30902 L
.18253 .30902 L
.18274 .30902 L
.18293 .30902 L
.18336 .30902 L
.18374 .30902 L
.18415 .30902 L
.18489 .30902 L
.18576 .30902 L
.18655 .30902 L
.1881 .30902 L
.18897 .30902 L
.18977 .30902 L
.19128 .30902 L
.19294 .30902 L
.19464 .30902 L
.19618 .30902 L
.19931 .30902 L
.20251 .30902 L
.20559 .30902 L
.20886 .30902 L
.21202 .30902 L
.21505 .30902 L
.21828 .30902 L
.22138 .30902 L
.22469 .30902 L
.22787 .30902 L
.23093 .30902 L
.23264 .30902 L
.23419 .30902 L
.23496 .30902 L
.2358 .30902 L
.23659 .30902 L
.23732 .30902 L
.2377 .30902 L
.23791 .30902 L
.2381 .30902 L
.23828 .30902 L
.23838 .30902 L
.23847 .30902 L
.23857 .30902 L
.23865 .30902 L
.23874 .30902 L
.23883 .30902 L
.23893 .30902 L
.23903 .30902 L
.23908 .30902 L
.23914 .30902 L
.23924 .30902 L
.23944 .30902 L
Mistroke
.23963 .30902 L
.24007 .30902 L
.24049 .30902 L
.24086 .30902 L
.24126 .30902 L
.24209 .30902 L
.24285 .30902 L
.24357 .30902 L
.24519 .30902 L
.24668 .30902 L
.2482 .30902 L
.24987 .30902 L
.25313 .30902 L
.25627 .30902 L
.2596 .30902 L
.26282 .30902 L
.26591 .30902 L
.2692 .30902 L
.27237 .30902 L
.27542 .30902 L
.27712 .30902 L
.27866 .30902 L
.27943 .30902 L
.28027 .30902 L
.28105 .30902 L
.28178 .30902 L
.28215 .30902 L
.28254 .30902 L
.28275 .30902 L
.28286 .30902 L
.28297 .30902 L
.28307 .30902 L
.28313 .30902 L
.28318 .30902 L
.28328 .30902 L
.28337 .30902 L
.28347 .30902 L
.28352 .30902 L
.28358 .30902 L
.28368 .30902 L
.28379 .30902 L
.28399 .30902 L
.28418 .30902 L
.2844 .30902 L
.28463 .30902 L
.28506 .30902 L
.28548 .30902 L
.28589 .30902 L
.28664 .30902 L
.28745 .30902 L
Mistroke
.28832 .30902 L
.28993 .30902 L
.29162 .30902 L
.2932 .30902 L
.29467 .30902 L
.29779 .30902 L
.30112 .30902 L
.30432 .30902 L
.3074 .30902 L
.31068 .30901 L
.31383 .30901 L
.31686 .30901 L
.31842 .30901 L
.31885 .30901 L
.31929 .30901 L
.31971 .30901 L
.32009 .30901 L
.32028 .30901 L
.32049 .30901 L
.32067 .30901 L
.32086 .30901 L
.32097 .30901 L
.32107 .30901 L
.32118 .30901 L
.32123 .30901 L
.32129 .30901 L
.32139 .30901 L
.32149 .30901 L
.32159 .30901 L
.32168 .30901 L
.32177 .30901 L
.32186 .30901 L
.32202 .30901 L
.32222 .30901 L
.3224 .30901 L
.32277 .30901 L
.32316 .30901 L
.32392 .30901 L
.32474 .30901 L
.32551 .30901 L
.32621 .30901 L
.32775 .30901 L
.32942 .30901 L
.33101 .30902 L
.3327 .30902 L
.33574 .30902 L
.33897 .30902 L
.34208 .30902 L
.34539 .30903 L
.34858 .30903 L
Mistroke
.35019 .30903 L
.35165 .30903 L
.35246 .30903 L
.35323 .30903 L
.35365 .30903 L
.35404 .30903 L
.35424 .30903 L
.35446 .30903 L
.35457 .30903 L
.35463 .30903 L
.35469 .30903 L
.35475 .30903 L
.35481 .30903 L
.35491 .30903 L
.35501 .30903 L
.3551 .30903 L
.3552 .30903 L
.3553 .30903 L
.35539 .30903 L
.35547 .30903 L
.35566 .30903 L
.35588 .30903 L
.35607 .30903 L
.3565 .30903 L
.35691 .30903 L
.35737 .30903 L
.35818 .30903 L
.35894 .30903 L
.35978 .30903 L
.36147 .30903 L
.36303 .30903 L
.36471 .30902 L
.36802 .30901 L
.37121 .309 L
.37428 .30899 L
.37755 .30898 L
.3807 .30897 L
.38152 .30896 L
.38242 .30896 L
.38326 .30896 L
.38367 .30896 L
.38404 .30896 L
.38442 .30896 L
.38463 .30896 L
.38482 .30896 L
.38491 .30896 L
.38501 .30896 L
.38509 .30896 L
.38517 .30896 L
.38527 .30896 L
Mistroke
.38535 .30896 L
.38546 .30896 L
.38555 .30896 L
.38566 .30896 L
.38571 .30896 L
.38576 .30896 L
.38587 .30896 L
.38596 .30896 L
.38617 .30896 L
.3864 .30896 L
.38683 .30896 L
.38721 .30896 L
.38799 .30896 L
.38872 .30896 L
.38952 .30896 L
.39038 .30897 L
.39208 .30898 L
.3937 .30899 L
.39677 .30902 L
.40005 .30906 L
.4032 .3091 L
.40622 .30914 L
.40791 .30916 L
.40945 .30917 L
.41023 .30918 L
.41096 .30918 L
.41172 .30919 L
.41212 .30919 L
.41233 .30919 L
.41255 .30919 L
.41276 .30919 L
.41286 .30919 L
.41298 .30919 L
.41309 .30919 L
.41318 .30919 L
.41328 .30919 L
.41337 .30919 L
.41343 .30919 L
.41348 .30919 L
.41354 .30919 L
.41359 .30919 L
.41369 .30919 L
.41375 .30919 L
.4138 .30919 L
.41391 .30919 L
.41403 .30919 L
.41415 .30919 L
.41426 .30919 L
.41447 .30919 L
.41467 .30919 L
Mistroke
.41504 .30919 L
.41545 .30919 L
.41588 .30918 L
.41664 .30918 L
.41747 .30917 L
.41916 .30915 L
.42071 .30912 L
.42239 .30908 L
.42569 .30897 L
.42887 .30886 L
.43193 .30874 L
.43364 .30869 L
.43519 .30864 L
.43597 .30862 L
.43681 .3086 L
.4376 .30859 L
.43798 .30859 L
.43833 .30858 L
.4387 .30858 L
.43891 .30858 L
.43911 .30858 L
.4392 .30858 L
.43929 .30858 L
.43937 .30858 L
.43946 .30858 L
.43956 .30858 L
.43966 .30858 L
.43975 .30858 L
.43984 .30858 L
.43993 .30858 L
.44004 .30858 L
.44013 .30858 L
.44022 .30858 L
.44044 .30858 L
.44064 .30858 L
.44105 .30858 L
.44149 .30859 L
.44225 .3086 L
.44309 .30862 L
.44396 .30865 L
.44477 .30868 L
.4464 .30876 L
.44788 .30885 L
.45107 .30909 L
.45414 .30937 L
.4574 .30967 L
.45891 .30979 L
.46054 .30989 L
.46143 .30994 L
.46183 .30996 L
Mistroke
.46226 .30997 L
.46264 .30998 L
.46305 .30999 L
.46327 .31 L
.46348 .31 L
.46368 .31 L
.46378 .31001 L
.46388 .31001 L
.46398 .31001 L
.46407 .31001 L
.46415 .31001 L
.46425 .31001 L
.46435 .31001 L
.46444 .31001 L
.46454 .31001 L
.4646 .31001 L
.46465 .31001 L
.46485 .31 L
.46497 .31 L
.46508 .31 L
.46547 .30999 L
.46582 .30999 L
.46619 .30997 L
.46695 .30994 L
.46777 .30989 L
.46851 .30984 L
.47019 .30967 L
.47172 .30947 L
.47338 .3092 L
.47665 .30857 L
.47979 .30793 L
.4814 .30762 L
.48313 .30734 L
.48395 .30723 L
.48481 .30714 L
.48555 .30707 L
.48597 .30705 L
.48635 .30703 L
.48655 .30702 L
.48676 .30701 L
.48687 .30701 L
.48698 .307 L
.48709 .307 L
.4872 .307 L
.48729 .307 L
.48739 .307 L
.48749 .307 L
.48755 .307 L
.48761 .307 L
.4877 .307 L
Mistroke
.48779 .307 L
.48789 .307 L
.48799 .307 L
.48817 .30701 L
.48836 .30701 L
.48871 .30703 L
.48908 .30705 L
.48948 .30708 L
.4903 .30716 L
.49104 .30726 L
.49272 .30758 L
.49425 .30797 L
.49592 .3085 L
.49919 .30976 L
.50234 .31106 L
.50536 .31213 L
.50612 .31233 L
.50692 .31251 L
.50733 .31259 L
.50779 .31266 L
.50817 .31271 L
.50859 .31275 L
.50881 .31277 L
.50901 .31278 L
.50921 .31279 L
.5093 .31279 L
.50936 .31279 L
.50941 .3128 L
.50951 .3128 L
.5096 .3128 L
.50969 .3128 L
.5098 .3128 L
.50989 .3128 L
.50999 .31279 L
.51008 .31279 L
.51016 .31279 L
.51038 .31278 L
.51058 .31276 L
.51103 .31272 L
.51142 .31267 L
.51184 .3126 L
.5126 .31243 L
.51342 .31219 L
.51489 .31161 L
.5166 .31072 L
.51821 .30969 L
.52129 .30739 L
.52456 .30492 L
.52619 .30388 L
.52699 .30345 L
Mistroke
.52772 .30311 L
.52841 .30285 L
.52918 .30263 L
.52957 .30255 L
.52994 .30249 L
.53015 .30247 L
.53033 .30245 L
.53044 .30244 L
.53049 .30244 L
.53055 .30244 L
.53065 .30244 L
.53075 .30243 L
.53085 .30244 L
.53095 .30244 L
.53105 .30244 L
.53115 .30244 L
.53124 .30245 L
.53132 .30246 L
.53151 .30247 L
.53171 .3025 L
.53193 .30254 L
.53232 .30262 L
.53269 .30272 L
.53309 .30286 L
.53379 .30316 L
.53455 .30358 L
.53537 .30413 L
.53684 .30539 L
.54017 .30921 L
.54337 .3135 L
.54646 .31721 L
.54805 .31861 L
.54885 .31913 L
.54931 .31936 L
.54973 .31953 L
.55013 .31965 L
.55036 .3197 L
.55047 .31972 L
.55057 .31973 L
.55066 .31974 L
.55077 .31975 L
.55086 .31976 L
.55095 .31976 L
.55104 .31976 L
.55115 .31976 L
.5512 .31976 L
.55126 .31976 L
.55136 .31975 L
.55146 .31974 L
.55155 .31973 L
Mistroke
.55176 .3197 L
.55194 .31966 L
.55214 .3196 L
.55247 .31949 L
.55285 .31932 L
.55365 .31882 L
.5544 .31819 L
.55607 .31623 L
.55759 .31383 L
.55925 .31067 L
.5625 .30362 L
.56564 .29723 L
.56646 .29587 L
.56735 .2946 L
.56819 .29364 L
.56897 .29299 L
.56934 .29276 L
.56955 .29266 L
.56974 .29258 L
.56993 .29253 L
.57002 .2925 L
.57012 .29248 L
.57022 .29246 L
.5703 .29245 L
.57039 .29244 L
.57047 .29244 L
.57057 .29244 L
.57067 .29244 L
.57073 .29244 L
.57078 .29245 L
.57089 .29246 L
.57099 .29248 L
.57109 .2925 L
.57127 .29255 L
.57148 .29263 L
.57168 .29272 L
.57213 .293 L
.5725 .29331 L
.5729 .29371 L
.57363 .29462 L
.57449 .29602 L
.57528 .29759 L
.57847 .30624 L
.58153 .31655 L
.58324 .32219 L
.58479 .32671 L
.58556 .32864 L
.5864 .3304 L
.58719 .33172 L
.58792 .33261 L
Mistroke
.5883 .33293 L
.58851 .33308 L
.5887 .33318 L
.58888 .33325 L
.58898 .33328 L
.58908 .33331 L
.58916 .33332 L
.58925 .33333 L
.58934 .33334 L
.58943 .33334 L
.58953 .33333 L
.58963 .33331 L
.58969 .3333 L
.58974 .33329 L
.58985 .33326 L
.59005 .33317 L
.59023 .33308 L
.59067 .33273 L
.59109 .33228 L
.59187 .33109 L
.59269 .32935 L
.59417 .32508 L
.59574 .31911 L
.59721 .31248 L
.60032 .29694 L
.6019 .2894 L
.60363 .28239 L
.60443 .27979 L
.60528 .27757 L
.6057 .27672 L
.60609 .27606 L
.60644 .2756 L
.60664 .27539 L
.60682 .27523 L
.60701 .2751 L
.60711 .27504 L
.60721 .275 L
.60731 .27497 L
.60739 .27495 L
.60748 .27494 L
.60758 .27494 L
.60768 .27494 L
.60774 .27495 L
.60779 .27496 L
.60788 .27499 L
.60798 .27503 L
.60809 .27508 L
.60819 .27514 L
.60842 .27532 L
.60864 .27555 L
Mistroke
.60885 .27581 L
.60924 .27643 L
.60966 .27728 L
.61011 .27841 L
.61087 .28078 L
.61171 .28407 L
.61339 .29264 L
.61663 .31406 L
.61975 .33555 L
.62145 .34511 L
.62223 .3486 L
.62306 .35154 L
.62349 .35272 L
.6239 .3536 L
.62426 .35419 L
.62447 .35445 L
.62466 .35462 L
.62474 .35469 L
.62483 .35474 L
.62492 .35479 L
.625 .35481 L
.62509 .35483 L
.62519 .35484 L
.62529 .35484 L
.62537 .35482 L
.62547 .35479 L
.62555 .35475 L
.62564 .35469 L
.62574 .35462 L
.62595 .35442 L
.62613 .35418 L
.62651 .35352 L
.62692 .35258 L
.62766 .35024 L
.62853 .34642 L
.62932 .34203 L
.63253 .31688 L
.63562 .28736 L
.63719 .27339 L
.63802 .26686 L
.63891 .26079 L
.63977 .25606 L
.64055 .2528 L
.64093 .25162 L
.64112 .25111 L
.64134 .25065 L
.64152 .25032 L
.64172 .25003 L
.64181 .24994 L
.64191 .24985 L
Mistroke
.642 .24978 L
.64208 .24973 L
.64218 .24969 L
.64227 .24968 L
.64237 .24968 L
.64243 .24969 L
.64248 .2497 L
.64256 .24974 L
.64266 .24979 L
.64276 .24987 L
.64285 .24997 L
.64306 .25024 L
.64325 .25058 L
.64369 .25163 L
.6441 .253 L
.64455 .25489 L
.64538 .25941 L
.64696 .27163 L
.64864 .28893 L
.65198 .32999 L
.65366 .34997 L
.6552 .36551 L
.65598 .37184 L
.65671 .3766 L
.65747 .38028 L
.65787 .38165 L
.65809 .38224 L
.6583 .38266 L
.65848 .38294 L
.65859 .38307 L
.65868 .38315 L
.65879 .38322 L
.65888 .38325 L
.65899 .38326 L
.65904 .38325 L
.65909 .38323 L
.65919 .38319 L
.65928 .38312 L
.65938 .38302 L
.65948 .3829 L
.65965 .38262 L
.65983 .38222 L
.66025 .38097 L
.6607 .37912 L
.6615 .37446 L
.66226 .36851 L
.66307 .36057 L
.66454 .34269 L
.66786 .29227 L
.66951 .26669 L
Mistroke
.67105 .24596 L
.67182 .23733 L
.67254 .23055 L
.67294 .22741 L
.67337 .22454 L
.67373 .22258 L
.67412 .22094 L
.67433 .22027 L
.67452 .21979 L
.67461 .2196 L
.67471 .21942 L
.6748 .21929 L
.67489 .21919 L
.67499 .21911 L
.67504 .21908 L
.6751 .21906 L
.67516 .21905 L
.67522 .21905 L
.67527 .21906 L
.67532 .21909 L
.67542 .21916 L
.67548 .21921 L
.67553 .21927 L
.67573 .21958 L
.67583 .2198 L
.67594 .22008 L
.67614 .22069 L
.6766 .22259 L
.67699 .22479 L
.67742 .22782 L
.67824 .23527 L
.67898 .24388 L
.68066 .26869 L
.68386 .32839 L
.68532 .35601 L
.68694 .38276 L
.6877 .39321 L
.68852 .40244 L
.68898 .40652 L
.68939 .40959 L
.68979 .41189 L
.69 .41287 L
.69021 .41362 L
.6904 .41417 L
.6905 .4144 L
.69061 .41459 L
.6907 .41472 L
.6908 .41481 L
.69089 .41487 L
.69097 .41488 L
Mistroke
.69108 .41486 L
.69118 .4148 L
.69127 .41471 L
.69137 .41456 L
.69147 .41436 L
.69159 .41409 L
.69179 .41347 L
.69198 .41272 L
.69219 .41174 L
.69257 .40949 L
.69327 .4037 L
.69403 .39513 L
.69487 .38321 L
.69656 .35239 L
.69981 .27954 L
.70131 .24678 L
.70294 .21688 L
.70382 .20435 L
.70421 .19985 L
.70464 .19567 L
.70502 .19271 L
.70543 .19028 L
.70565 .18928 L
.70575 .18893 L
.70586 .18859 L
.70595 .18835 L
.70605 .18813 L
.70611 .18804 L
.70616 .18796 L
.70626 .18786 L
.70636 .18781 L
.70644 .1878 L
.70654 .18784 L
.70665 .18794 L
.7067 .18801 L
.70676 .1881 L
.70687 .18832 L
.70706 .18887 L
.70725 .18958 L
.70745 .19053 L
.7078 .19274 L
.70821 .19608 L
.70859 .19997 L
.70947 .21148 L
.71109 .2413 L
.71257 .27619 L
.71575 .35962 L
.71735 .39709 L
.71881 .42349 L
.71919 .42891 L
Mistroke
.71961 .43393 L
.71998 .4375 L
.72038 .4406 L
.7206 .4419 L
.7208 .44288 L
.72102 .44364 L
.72114 .44394 L
.72119 .44405 L
.72125 .44414 L
.72135 .44426 L
.72145 .44432 L
.72151 .44433 L
.72156 .44432 L
.72167 .44425 L
.72176 .44412 L
.72185 .44395 L
.72195 .44371 L
.72206 .44339 L
.72226 .44258 L
.72246 .44158 L
.72282 .4391 L
.72321 .43557 L
.72364 .43073 L
.7244 .4195 L
.72511 .40642 L
.72826 .32486 L
.73129 .23614 L
.73284 .19888 L
.73372 .18272 L
.73411 .17689 L
.73452 .17164 L
.73493 .16745 L
.73531 .1646 L
.73549 .16355 L
.73568 .16266 L
.73577 .16233 L
.73587 .16205 L
.73595 .16186 L
.73604 .1617 L
.73609 .16163 L
.73615 .16157 L
.73626 .16153 L
.73636 .16156 L
.73645 .16166 L
.73651 .16175 L
.73657 .16185 L
.73667 .1621 L
.73678 .16245 L
.7369 .16292 L
.7371 .16395 L
Mistroke
.73732 .16534 L
.7377 .1686 L
.7381 .17303 L
.73846 .17796 L
.73928 .19199 L
.74075 .22648 L
.74396 .3265 L
.74542 .37363 L
.74704 .41856 L
.7478 .43567 L
.74863 .45024 L
.74908 .45638 L
.7495 .46074 L
.7497 .46239 L
.74992 .46387 L
.75013 .46493 L
.75022 .46531 L
.75032 .46564 L
.75042 .46591 L
.75048 .46602 L
.75053 .4661 L
.75062 .4662 L
.75072 .46623 L
.75078 .46621 L
.75084 .46617 L
.7509 .46609 L
.75095 .46601 L
.75106 .46578 L
.75116 .46545 L
.75136 .46464 L
.75154 .46361 L
.75196 .46031 L
.75234 .45627 L
.75268 .45167 L
.75346 .4383 L
.75497 .40137 L
.75663 .34878 L
.75989 .23561 L
.76139 .19185 L
.76224 .17245 L
.76302 .15878 L
.76342 .15355 L
.76385 .14919 L
.76407 .14756 L
.76419 .14683 L
.76431 .14624 L
.76441 .14579 L
.76453 .14541 L
.76464 .14515 L
.76473 .145 L
Mistroke
.76483 .14492 L
.76489 .14492 L
.76494 .14493 L
.76504 .14503 L
.76514 .14521 L
.76524 .14545 L
.76532 .14573 L
.76552 .1466 L
.76573 .14789 L
.76592 .14937 L
.76635 .1538 L
.76674 .15901 L
.76715 .16578 L
.76788 .181 L
.76955 .22782 L
.77258 .33748 L
.77427 .39673 L
.77501 .41927 L
.77581 .44043 L
.7766 .45687 L
.77697 .46312 L
.77733 .46799 L
.77752 .47022 L
.77773 .47229 L
.77791 .47372 L
.7781 .475 L
.77831 .47602 L
.77842 .47643 L
.77847 .47658 L
.77853 .4767 L
.77863 .47687 L
.77872 .47695 L
.77881 .47695 L
.77887 .47692 L
.77892 .47686 L
.77902 .47667 L
.77908 .47655 L
.77913 .47638 L
.77933 .47559 L
.77944 .47499 L
.77956 .47424 L
.77977 .47258 L
.78019 .46818 L
.78057 .4629 L
.78134 .44875 L
.78207 .43136 L
.78515 .32687 L
.78671 .26677 L
.78843 .20694 L
.78922 .18436 L
Mistroke
.79006 .16465 L
.79047 .15704 L
.79086 .15106 L
.79121 .14679 L
.79159 .14334 L
.79179 .14202 L
.79191 .14144 L
.79202 .14101 L
.79211 .14072 L
.79221 .14049 L
.79226 .14041 L
.79232 .14036 L
.79242 .14032 L
.79251 .14038 L
.79262 .14053 L
.79272 .14077 L
.79281 .14107 L
.79298 .14184 L
.79317 .14296 L
.79337 .14451 L
.79358 .14658 L
.79397 .15133 L
.79443 .15866 L
.79485 .16689 L
.79637 .20719 L
.79803 .26554 L
.79974 .33205 L
.80129 .38953 L
.80206 .41466 L
.8029 .43791 L
.80369 .45526 L
.80407 .46183 L
.80442 .46675 L
.8048 .47085 L
.805 .47256 L
.8052 .47383 L
.80529 .47428 L
.80538 .47469 L
.80546 .47497 L
.80555 .47521 L
.80565 .4754 L
.80575 .47549 L
.80584 .47549 L
.80593 .47543 L
.80602 .47527 L
.80613 .475 L
.80622 .47467 L
.80631 .47428 L
.80653 .47303 L
.80673 .47146 L
Mistroke
.80714 .46719 L
.80759 .4609 L
.80834 .44634 L
.80918 .42524 L
.81086 .36987 L
.81409 .24647 L
.81558 .19818 L
.81642 .17677 L
.81683 .16827 L
.8172 .16173 L
.81758 .15635 L
.81798 .15192 L
.81821 .15012 L
.8183 .14948 L
.81841 .14887 L
.81851 .14842 L
.81861 .14804 L
.81866 .14786 L
.81871 .14773 L
.81881 .14755 L
.81892 .14745 L
.81897 .14744 L
.81903 .14746 L
.81913 .14758 L
.81923 .14777 L
.81929 .14793 L
.81934 .14812 L
.81945 .14854 L
.81968 .14986 L
.81989 .15142 L
.82008 .1532 L
.82051 .15846 L
.82091 .16486 L
.82135 .17333 L
.82215 .19247 L
.82364 .23894 L
.82692 .36141 L
.82771 .38841 L
.82855 .41404 L
.82929 .43254 L
.83008 .44817 L
.8305 .45432 L
.83071 .45676 L
.8309 .45864 L
.83108 .46016 L
.83127 .46148 L
.83138 .46205 L
.83148 .46249 L
.83157 .46282 L
.83167 .46309 L
Mistroke
.83176 .46325 L
.83184 .46333 L
.83194 .46335 L
.83203 .46329 L
.83211 .46317 L
.83219 .463 L
.83227 .46275 L
.83236 .46241 L
.83255 .46148 L
.83272 .46031 L
.83312 .45664 L
.8335 .45187 L
.83391 .44528 L
.83474 .42793 L
.83623 .38556 L
.83948 .26894 L
.84099 .22019 L
.84178 .19928 L
.84262 .18189 L
.84305 .17518 L
.84327 .17223 L
.84351 .16954 L
.84373 .16752 L
.84394 .16605 L
.84403 .16548 L
.84414 .16495 L
.84423 .16457 L
.84433 .16424 L
.84439 .1641 L
.84444 .16399 L
.84455 .16385 L
.84464 .16381 L
.84474 .16385 L
.84479 .16391 L
.84485 .164 L
.84495 .16422 L
.84501 .1644 L
.84507 .16461 L
.84517 .16506 L
.84537 .16615 L
.84555 .16744 L
.84595 .17138 L
.84633 .17625 L
.84673 .18274 L
.84745 .19756 L
.84911 .24349 L
.85242 .35618 L
.85322 .38089 L
.85407 .40381 L
.85481 .42 L
Mistroke
.8556 .43307 L
.85581 .43568 L
.85603 .43804 L
.85624 .43987 L
.85643 .44126 L
.85661 .44227 L
.8567 .44269 L
.8568 .44306 L
.85686 .44323 L
.85691 .44336 L
.85702 .44356 L
.85711 .44365 L
.85721 .44367 L
.8573 .44362 L
.85738 .44351 L
.85747 .44332 L
.85757 .44304 L
.85773 .44241 L
.8579 .44146 L
.8581 .44013 L
.8583 .43838 L
.85867 .43436 L
.85949 .42165 L
.86038 .40257 L
.862 .35726 L
.86356 .30674 L
.86528 .25305 L
.86607 .23185 L
.86691 .21279 L
.86732 .20519 L
.86771 .19906 L
.86809 .1942 L
.86844 .19062 L
.86864 .18907 L
.86885 .18773 L
.86894 .18726 L
.86904 .18683 L
.86913 .18649 L
.86921 .18625 L
.86931 .18604 L
.86942 .1859 L
.86951 .18585 L
.86961 .18587 L
.86966 .18591 L
.86971 .18598 L
.86981 .18616 L
.86987 .1863 L
.86992 .18645 L
.87004 .18687 L
.87022 .18773 L
Mistroke
.87041 .18892 L
.87075 .19174 L
.87111 .19575 L
.87151 .20125 L
.87234 .21602 L
.87309 .23289 L
.87477 .27913 L
.87644 .32935 L
.87798 .37138 L
.87876 .38885 L
.87949 .40211 L
.87988 .40791 L
.88024 .41227 L
.88064 .41603 L
.88086 .41759 L
.88107 .41874 L
.88116 .41914 L
.88126 .4195 L
.88135 .41975 L
.88144 .41996 L
.88154 .42012 L
.8816 .42017 L
.88165 .4202 L
.88175 .4202 L
.88185 .42012 L
.88195 .41996 L
.88201 .41984 L
.88207 .41969 L
.88228 .41895 L
.88247 .418 L
.88267 .4167 L
.88303 .41362 L
.88337 .40992 L
.88415 .39867 L
.88498 .3827 L
.88577 .36453 L
.88726 .32544 L
.88887 .28178 L
.89033 .24717 L
.89114 .23185 L
.8919 .22082 L
.89233 .21631 L
.89271 .2132 L
.89292 .21197 L
.89314 .21095 L
.89325 .21057 L
.89331 .21039 L
.89337 .21025 L
.89343 .21014 L
.89348 .21005 L
Mistroke
.89359 .20994 L
.89369 .2099 L
.89378 .20992 L
.89387 .21001 L
.89398 .21018 L
.89407 .21039 L
.89415 .21063 L
.89434 .21135 L
.89455 .21244 L
.89475 .21369 L
.89518 .21734 L
.89559 .22197 L
.89604 .22814 L
.89686 .24203 L
.90015 .3181 L
.90178 .35525 L
.90258 .37023 L
.90331 .38131 L
.90367 .38574 L
.90406 .38972 L
.90443 .39264 L
.9046 .39367 L
.90478 .39459 L
.90488 .39506 L
.90498 .39542 L
.90508 .3957 L
.90518 .39595 L
.90527 .39612 L
.90535 .39623 L
.90544 .3963 L
.90554 .39631 L
.90564 .39626 L
.9057 .39621 L
.90576 .39613 L
.90586 .39595 L
.90597 .39569 L
.90615 .39508 L
.90635 .39416 L
.90675 .39167 L
.90716 .38807 L
.90791 .37933 L
.90871 .367 L
.90958 .35077 L
.91129 .31434 L
.91284 .28134 L
.91362 .26671 L
.91446 .25324 L
.91485 .24807 L
.91525 .24336 L
.91563 .23978 L
Mistroke
.91598 .23706 L
.91617 .23589 L
.91638 .23484 L
.91657 .23409 L
.91674 .23357 L
.91684 .23335 L
.91693 .2332 L
.91703 .23309 L
.91709 .23305 L
.91714 .23302 L
.91724 .23302 L
.91729 .23305 L
.91734 .23309 L
.91745 .23321 L
.9175 .2333 L
.91756 .2334 L
.91775 .23389 L
.91792 .23451 L
.91811 .23538 L
.91831 .23652 L
.91903 .24219 L
.91942 .24638 L
.91979 .2508 L
.9206 .26258 L
.92207 .28849 L
.92372 .32015 L
.92526 .34654 L
.92602 .35716 L
.92674 .36506 L
.92714 .36847 L
.92735 .36996 L
.92757 .37131 L
.92776 .37226 L
.92796 .37311 L
.92815 .3737 L
.92823 .37391 L
.92832 .3741 L
.92843 .37426 L
.92848 .37433 L
.92853 .37438 L
.92863 .37444 L
.92873 .37445 L
.92878 .37443 L
.92884 .3744 L
.9289 .37435 L
.92896 .37429 L
.92906 .37414 L
.92916 .37392 L
.92938 .37332 L
.92958 .37255 L
Mistroke
.92996 .3706 L
.93033 .36806 L
.93068 .36519 L
.93145 .35702 L
.93296 .33585 L
.93461 .30854 L
.93631 .28201 L
.93711 .27156 L
.93785 .26371 L
.93826 .26031 L
.93862 .25779 L
.93902 .25563 L
.93925 .25474 L
.93946 .25409 L
.93964 .25368 L
.93973 .25352 L
.93984 .2534 L
.93992 .25333 L
.94002 .25329 L
.9401 .25329 L
.94019 .25331 L
.94029 .25339 L
.94038 .25349 L
.94048 .25365 L
.94059 .25387 L
.94077 .25435 L
.94097 .25503 L
.94139 .25698 L
.94179 .25946 L
.94253 .26563 L
.94421 .28523 L
.94727 .32791 L
.94808 .33754 L
.94885 .34507 L
.94927 .34847 L
.94973 .35148 L
.95015 .35357 L
.95035 .35435 L
.95053 .35493 L
.95073 .35541 L
.95082 .35558 L
.95091 .35573 L
.95101 .35586 L
.9511 .35594 L
.9512 .35599 L
.95126 .356 L
.95131 .356 L
.9514 .35598 L
.9515 .35593 L
.95158 .35585 L
Mistroke
.95167 .35574 L
.95176 .3556 L
.95186 .3554 L
.95204 .35496 L
.95226 .35428 L
.95249 .35337 L
.95291 .35125 L
.9537 .34579 L
.95446 .33896 L
.9553 .33007 L
.95699 .30984 L
.95868 .29046 L
.95948 .28284 L
.96022 .27714 L
.96063 .27469 L
.96099 .27288 L
.96139 .27135 L
.96161 .27073 L
.96171 .2705 L
.96182 .27029 L
.96191 .27014 L
.96201 .27001 L
.96211 .26991 L
.9622 .26984 L
.9623 .2698 L
.96239 .26979 L
.96247 .2698 L
.96255 .26984 L
.96265 .26991 L
.96275 .27001 L
.96286 .27016 L
.96296 .27033 L
.96314 .27072 L
.96334 .27124 L
.96374 .27267 L
.96411 .2744 L
.96495 .27964 L
.96665 .29439 L
.96815 .30971 L
.96978 .32522 L
.97068 .33209 L
.97107 .33458 L
.9715 .33691 L
.97188 .33858 L
.97229 .33996 L
.97251 .34053 L
.97272 .34093 L
.97281 .34108 L
.97292 .34122 L
.97302 .34132 L
Mistroke
.97312 .34138 L
.97321 .34143 L
.97331 .34145 L
.97339 .34144 L
.97348 .34142 L
.97358 .34137 L
.97368 .34129 L
.97378 .34118 L
.97387 .34106 L
.97404 .34077 L
.97423 .34037 L
.97458 .33941 L
.97498 .3379 L
.97542 .33589 L
.97619 .33134 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{421.375, 260.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 525.688}, {324.5, 0}} -> {-2.58312*^-7, -6.34248*^6, \
6.65005*^-9, 53093.5}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0.309017 5.42214e-08 [
[.32684 .29652 -16.5 -12.5 ]
[.32684 .29652 16.5 0 ]
[.54329 .29652 -16.5 -12.5 ]
[.54329 .29652 16.5 0 ]
[.75974 .29652 -22.5 -12.5 ]
[.75974 .29652 22.5 0 ]
[.97619 .29652 -16.5 -12.5 ]
[.97619 .29652 16.5 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 64 6 ]
[.09789 .09213 -34.5 -6.25 ]
[.09789 .09213 0 6.25 ]
[.09789 .20057 -34.5 -6.25 ]
[.09789 .20057 0 6.25 ]
[.09789 .41746 -28.5 -6.25 ]
[.09789 .41746 0 6.25 ]
[.09789 .5259 -28.5 -6.25 ]
[.09789 .5259 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -65.8125 0 ]
[.5 .63053 65.8125 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 .30902 m
.32684 .31527 L
s
gsave
.32684 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 .30902 m
.54329 .31527 L
s
gsave
.54329 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 .30902 m
.75974 .31527 L
s
gsave
.75974 .29652 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 .30902 m
.15368 .31277 L
s
.19697 .30902 m
.19697 .31277 L
s
.24026 .30902 m
.24026 .31277 L
s
.28355 .30902 m
.28355 .31277 L
s
.37013 .30902 m
.37013 .31277 L
s
.41342 .30902 m
.41342 .31277 L
s
.45671 .30902 m
.45671 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.58658 .30902 m
.58658 .31277 L
s
.62987 .30902 m
.62987 .31277 L
s
.67316 .30902 m
.67316 .31277 L
s
.71645 .30902 m
.71645 .31277 L
s
.80303 .30902 m
.80303 .31277 L
s
.84632 .30902 m
.84632 .31277 L
s
.88961 .30902 m
.88961 .31277 L
s
.9329 .30902 m
.9329 .31277 L
s
.0671 .30902 m
.0671 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09213 m
.11664 .09213 L
s
gsave
.09789 .09213 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .20057 m
.11664 .20057 L
s
gsave
.09789 .20057 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .41746 m
.11664 .41746 L
s
gsave
.09789 .41746 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .5259 m
.11664 .5259 L
s
gsave
.09789 .5259 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.11039 .11924 m
.11414 .11924 L
s
.11039 .14635 m
.11414 .14635 L
s
.11039 .17346 m
.11414 .17346 L
s
.11039 .22768 m
.11414 .22768 L
s
.11039 .2548 m
.11414 .2548 L
s
.11039 .28191 m
.11414 .28191 L
s
.11039 .33613 m
.11414 .33613 L
s
.11039 .36324 m
.11414 .36324 L
s
.11039 .39035 m
.11414 .39035 L
s
.11039 .44457 m
.11414 .44457 L
s
.11039 .47168 m
.11414 .47168 L
s
.11039 .49879 m
.11414 .49879 L
s
.11039 .06502 m
.11414 .06502 L
s
.11039 .03791 m
.11414 .03791 L
s
.11039 .0108 m
.11414 .0108 L
s
.11039 .55301 m
.11414 .55301 L
s
.11039 .58012 m
.11414 .58012 L
s
.11039 .60723 m
.11414 .60723 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -126.812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.812 moveto
(@) show
81.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.812 moveto
(D) show
93.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13.8) show
141.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
147.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
159.000 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
163.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
172.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
190.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02691 .30902 L
.03029 .30902 L
.03347 .30902 L
.03652 .30902 L
.03978 .30902 L
.04291 .30902 L
.04623 .30902 L
.04944 .30902 L
.05252 .30902 L
.0558 .30902 L
.05896 .30902 L
.062 .30902 L
.06523 .30902 L
.06834 .30902 L
.07165 .30902 L
.0733 .30902 L
.07484 .30902 L
.07632 .30902 L
.07675 .30902 L
.07715 .30902 L
.07754 .30902 L
.0779 .30902 L
.07828 .30902 L
.07848 .30902 L
.07859 .30902 L
.07869 .30902 L
.07879 .30902 L
.07885 .30902 L
.07891 .30902 L
.07901 .30902 L
.07907 .30902 L
.07912 .30902 L
.07922 .30902 L
.07931 .30902 L
.07941 .30902 L
.07952 .30902 L
.07969 .30902 L
.07988 .30902 L
.08022 .30902 L
.08043 .30902 L
.08063 .30902 L
.081 .30902 L
.08178 .30902 L
.08217 .30902 L
.0826 .30902 L
.08409 .30902 L
.0849 .30902 L
.08565 .30902 L
.08732 .30902 L
Mistroke
.08885 .30902 L
.09052 .30902 L
.0921 .30902 L
.09378 .30902 L
.0955 .30902 L
.09712 .30902 L
.10022 .30902 L
.10183 .30902 L
.10352 .30902 L
.10657 .30902 L
.10982 .30902 L
.11295 .30902 L
.11627 .30902 L
.11947 .30902 L
.12255 .30902 L
.12583 .30902 L
.12899 .30902 L
.13202 .30902 L
.13525 .30902 L
.13836 .30902 L
.14167 .30902 L
.14485 .30902 L
.14792 .30902 L
.15118 .30902 L
.15431 .30902 L
.15765 .30902 L
.16086 .30902 L
.16396 .30902 L
.16724 .30902 L
.17041 .30902 L
.17346 .30902 L
.17515 .30902 L
.1767 .30902 L
.17747 .30902 L
.1783 .30902 L
.17908 .30902 L
.17982 .30902 L
.18018 .30902 L
.18057 .30902 L
.18078 .30902 L
.1809 .30902 L
.18101 .30902 L
.1811 .30902 L
.1812 .30902 L
.18125 .30902 L
.18131 .30902 L
.1814 .30902 L
.1815 .30902 L
.18156 .30902 L
.18161 .30902 L
Mistroke
.18171 .30902 L
.18177 .30902 L
.18182 .30902 L
.18202 .30902 L
.18221 .30902 L
.18243 .30902 L
.18263 .30902 L
.18309 .30902 L
.1835 .30902 L
.18394 .30902 L
.18474 .30902 L
.18552 .30902 L
.18623 .30902 L
.18774 .30902 L
.1894 .30902 L
.19097 .30902 L
.19265 .30902 L
.19424 .30902 L
.19597 .30902 L
.19917 .30902 L
.20245 .30902 L
.2056 .30902 L
.20863 .30902 L
.21186 .30902 L
.21497 .30902 L
.21827 .30902 L
.22145 .30902 L
.22451 .30902 L
.22777 .30902 L
.23091 .30902 L
.23251 .30902 L
.23424 .30902 L
.23505 .30902 L
.23591 .30902 L
.23671 .30902 L
.23745 .30902 L
.23784 .30902 L
.23821 .30902 L
.23841 .30902 L
.2386 .30902 L
.23871 .30902 L
.2388 .30902 L
.23886 .30902 L
.23892 .30902 L
.23902 .30902 L
.23911 .30902 L
.2392 .30902 L
.23929 .30902 L
.2394 .30902 L
.2395 .30902 L
Mistroke
.2396 .30902 L
.23979 .30902 L
.23996 .30902 L
.24013 .30902 L
.24049 .30902 L
.24087 .30902 L
.24127 .30902 L
.24199 .30902 L
.24286 .30902 L
.24365 .30902 L
.24517 .30902 L
.24684 .30902 L
.24841 .30902 L
.2501 .30902 L
.25343 .30902 L
.25665 .30902 L
.25974 .30902 L
.26303 .30902 L
.2662 .30902 L
.26925 .30902 L
.27249 .30902 L
.27561 .30902 L
.2772 .30902 L
.27893 .30902 L
.28059 .30902 L
.28139 .30902 L
.28213 .30902 L
.28285 .30902 L
.28305 .30902 L
.28326 .30902 L
.28345 .30902 L
.28363 .30902 L
.28383 .30902 L
.28393 .30902 L
.28404 .30902 L
.28413 .30902 L
.28422 .30902 L
.28432 .30902 L
.28442 .30902 L
.28452 .30902 L
.28458 .30902 L
.28463 .30902 L
.28483 .30902 L
.28494 .30902 L
.28506 .30902 L
.28528 .30902 L
.28571 .30902 L
.28611 .30902 L
.28686 .30902 L
.28767 .30902 L
Mistroke
.28855 .30902 L
.29015 .30902 L
.29184 .30902 L
.29342 .30902 L
.29489 .30902 L
.29802 .30902 L
.30134 .30902 L
.30454 .30902 L
.30762 .30902 L
.3109 .30902 L
.31406 .30901 L
.31709 .30901 L
.31864 .30901 L
.31944 .30901 L
.32032 .30901 L
.32072 .30901 L
.32115 .30901 L
.32156 .30901 L
.32193 .30901 L
.32204 .30901 L
.32215 .30901 L
.32224 .30901 L
.32235 .30901 L
.32241 .30901 L
.32246 .30901 L
.32256 .30901 L
.32262 .30901 L
.32269 .30901 L
.32275 .30901 L
.3228 .30901 L
.3229 .30901 L
.32299 .30901 L
.32309 .30901 L
.3232 .30901 L
.32342 .30901 L
.32362 .30901 L
.324 .30901 L
.32441 .30901 L
.32514 .30901 L
.32559 .30901 L
.32601 .30901 L
.3268 .30901 L
.32841 .30901 L
.32989 .30901 L
.33139 .30902 L
.33304 .30902 L
.33628 .30902 L
.33939 .30902 L
.3427 .30902 L
.34589 .30903 L
Mistroke
.34896 .30903 L
.35067 .30903 L
.35222 .30903 L
.353 .30903 L
.35384 .30903 L
.35463 .30903 L
.35501 .30903 L
.35536 .30903 L
.35574 .30903 L
.35595 .30903 L
.35614 .30903 L
.35623 .30903 L
.35632 .30903 L
.3564 .30903 L
.35649 .30903 L
.35659 .30903 L
.35669 .30903 L
.35678 .30903 L
.35687 .30903 L
.35697 .30903 L
.35707 .30903 L
.35717 .30903 L
.35726 .30903 L
.35747 .30903 L
.35768 .30903 L
.35809 .30903 L
.35853 .30903 L
.35929 .30903 L
.36013 .30903 L
.361 .30903 L
.36182 .30903 L
.36344 .30903 L
.36493 .30903 L
.36812 .30902 L
.37119 .30901 L
.37446 .309 L
.37761 .30899 L
.38095 .30898 L
.38263 .30897 L
.38336 .30897 L
.38417 .30897 L
.3849 .30897 L
.38568 .30896 L
.38611 .30896 L
.3865 .30896 L
.38669 .30896 L
.3869 .30896 L
.38699 .30896 L
.38709 .30896 L
.38718 .30896 L
Mistroke
.38727 .30896 L
.38737 .30896 L
.38747 .30896 L
.38757 .30896 L
.38763 .30896 L
.38769 .30896 L
.38778 .30896 L
.38789 .30896 L
.38808 .30896 L
.38827 .30896 L
.38847 .30896 L
.38883 .30896 L
.38924 .30896 L
.38963 .30897 L
.3905 .30897 L
.39134 .30897 L
.39213 .30897 L
.39362 .30898 L
.39522 .30899 L
.3967 .309 L
.39985 .30903 L
.40288 .30906 L
.4061 .3091 L
.4092 .30913 L
.41078 .30915 L
.41161 .30916 L
.4125 .30916 L
.41337 .30917 L
.41415 .30917 L
.41453 .30917 L
.41473 .30917 L
.41494 .30917 L
.41512 .30917 L
.41522 .30917 L
.41533 .30917 L
.41542 .30917 L
.41551 .30917 L
.4156 .30917 L
.41568 .30917 L
.41578 .30917 L
.41584 .30917 L
.41589 .30917 L
.41599 .30917 L
.41609 .30917 L
.41618 .30917 L
.41626 .30917 L
.41645 .30917 L
.41666 .30917 L
.41685 .30917 L
.41727 .30917 L
Mistroke
.41764 .30917 L
.41803 .30917 L
.41875 .30916 L
.41951 .30916 L
.42034 .30915 L
.42203 .30912 L
.42358 .3091 L
.42526 .30906 L
.42856 .30896 L
.43174 .30886 L
.4348 .30876 L
.43651 .30871 L
.43806 .30867 L
.43884 .30865 L
.43968 .30864 L
.44006 .30863 L
.44047 .30863 L
.44084 .30862 L
.4412 .30862 L
.44139 .30862 L
.44159 .30862 L
.44169 .30862 L
.44178 .30862 L
.44187 .30862 L
.44196 .30862 L
.44206 .30862 L
.44216 .30862 L
.44226 .30862 L
.44232 .30862 L
.44238 .30862 L
.44248 .30862 L
.44258 .30862 L
.44277 .30862 L
.44296 .30862 L
.44317 .30862 L
.44354 .30863 L
.44391 .30863 L
.44424 .30863 L
.44502 .30865 L
.44574 .30866 L
.4474 .30872 L
.44902 .30879 L
.45051 .30887 L
.4537 .30909 L
.45676 .30934 L
.46003 .30961 L
.46153 .30971 L
.46317 .30981 L
.46406 .30985 L
.46445 .30987 L
Mistroke
.46488 .30988 L
.46526 .30989 L
.46567 .3099 L
.4659 .30991 L
.4661 .30991 L
.46631 .30991 L
.4664 .30991 L
.4665 .30991 L
.4666 .30991 L
.46669 .30991 L
.46678 .30991 L
.46687 .30991 L
.46697 .30991 L
.46707 .30991 L
.46717 .30991 L
.46723 .30991 L
.46728 .30991 L
.46738 .30991 L
.46748 .30991 L
.4677 .30991 L
.4679 .30991 L
.4681 .3099 L
.46847 .3099 L
.46881 .30989 L
.46958 .30986 L
.47042 .30981 L
.47121 .30976 L
.4727 .30963 L
.47429 .30944 L
.47577 .30924 L
.47891 .30871 L
.48225 .30809 L
.48393 .3078 L
.48547 .30756 L
.48698 .30737 L
.48774 .3073 L
.48817 .30727 L
.48857 .30724 L
.48896 .30722 L
.48917 .30721 L
.48939 .3072 L
.48958 .3072 L
.48978 .30719 L
.48987 .30719 L
.48996 .30719 L
.49005 .30719 L
.49014 .30718 L
.49024 .30718 L
.49034 .30718 L
.4904 .30718 L
Mistroke
.49046 .30718 L
.49057 .30718 L
.49062 .30718 L
.49068 .30718 L
.49078 .30719 L
.49089 .30719 L
.49102 .30719 L
.49122 .3072 L
.49143 .3072 L
.49182 .30722 L
.49224 .30725 L
.49263 .30728 L
.49352 .30737 L
.4943 .30748 L
.49514 .30762 L
.4967 .30795 L
.49816 .30835 L
.50126 .30938 L
.50456 .31061 L
.50621 .3112 L
.50774 .31168 L
.50922 .31206 L
.51005 .31222 L
.5108 .31234 L
.51119 .31238 L
.5116 .31242 L
.51177 .31243 L
.51195 .31244 L
.51205 .31245 L
.51215 .31245 L
.51225 .31245 L
.51234 .31246 L
.51244 .31246 L
.51249 .31246 L
.51255 .31246 L
.51264 .31246 L
.51274 .31246 L
.5128 .31246 L
.51286 .31246 L
.51292 .31246 L
.51298 .31246 L
.51308 .31246 L
.51319 .31245 L
.51341 .31244 L
.51362 .31243 L
.514 .3124 L
.51437 .31235 L
.51478 .31229 L
.5156 .31213 L
.51637 .31193 L
Mistroke
.51708 .31171 L
.5187 .31105 L
.52019 .31028 L
.52337 .30825 L
.52643 .30611 L
.52814 .305 L
.52969 .30414 L
.53046 .30379 L
.5313 .30347 L
.53168 .30335 L
.53209 .30324 L
.53247 .30315 L
.53282 .30309 L
.53301 .30306 L
.53322 .30304 L
.53341 .30302 L
.53358 .30301 L
.53363 .30301 L
.53369 .30301 L
.53379 .303 L
.53388 .303 L
.53397 .303 L
.53407 .303 L
.53413 .303 L
.53418 .303 L
.53428 .30301 L
.53439 .30301 L
.53458 .30303 L
.53479 .30305 L
.53516 .3031 L
.53553 .30317 L
.53586 .30326 L
.53664 .30352 L
.53737 .30384 L
.53902 .30486 L
.54065 .30623 L
.54213 .30774 L
.54532 .31151 L
.54838 .31514 L
.55009 .31684 L
.55164 .318 L
.55242 .31842 L
.55286 .3186 L
.55326 .31872 L
.55361 .3188 L
.55381 .31884 L
.554 .31886 L
.5541 .31887 L
.5542 .31887 L
.55428 .31888 L
Mistroke
.55438 .31888 L
.55448 .31888 L
.55453 .31887 L
.55459 .31887 L
.55469 .31887 L
.55478 .31886 L
.55488 .31885 L
.55498 .31883 L
.55516 .3188 L
.55538 .31876 L
.55557 .3187 L
.556 .31855 L
.5564 .31836 L
.55711 .31793 L
.55789 .31732 L
.55948 .31557 L
.56117 .3131 L
.56421 .30749 L
.56745 .30104 L
.56894 .29839 L
.57056 .29602 L
.57144 .29505 L
.57187 .29466 L
.57226 .29437 L
.57264 .29413 L
.57304 .29394 L
.57326 .29386 L
.57336 .29384 L
.57347 .29381 L
.57356 .29379 L
.57367 .29377 L
.57372 .29376 L
.57377 .29376 L
.57387 .29375 L
.57397 .29374 L
.57406 .29374 L
.57415 .29375 L
.57426 .29375 L
.57436 .29377 L
.57447 .29378 L
.57467 .29383 L
.57485 .29388 L
.57502 .29395 L
.57541 .29414 L
.57583 .29442 L
.57621 .29474 L
.57707 .29569 L
.57788 .29686 L
.57862 .29816 L
.58029 .30184 L
Mistroke
.58345 .31088 L
.5865 .32031 L
.58819 .32496 L
.58974 .32834 L
.5905 .32962 L
.59091 .33017 L
.59134 .33066 L
.59171 .331 L
.59191 .33115 L
.59213 .33128 L
.59232 .33137 L
.59241 .33141 L
.5925 .33144 L
.59259 .33146 L
.59267 .33148 L
.59277 .3315 L
.59286 .33151 L
.59295 .33151 L
.59301 .33151 L
.59306 .33151 L
.59317 .3315 L
.59323 .33149 L
.59328 .33148 L
.59338 .33146 L
.59348 .33143 L
.59368 .33136 L
.5939 .33124 L
.59414 .33108 L
.59457 .33069 L
.595 .33017 L
.59541 .32957 L
.59618 .32814 L
.59779 .32394 L
.59928 .3188 L
.60245 .30505 L
.6055 .29124 L
.60719 .28478 L
.608 .28229 L
.60874 .28039 L
.60951 .27887 L
.60991 .27827 L
.61012 .27802 L
.61034 .2778 L
.61054 .27764 L
.61072 .27752 L
.61089 .27744 L
.61097 .27741 L
.61107 .27738 L
.61117 .27736 L
.61127 .27735 L
Mistroke
.61132 .27735 L
.61138 .27735 L
.61148 .27737 L
.61158 .27739 L
.61168 .27742 L
.61177 .27745 L
.61186 .2775 L
.61206 .27763 L
.61228 .27781 L
.61268 .27827 L
.61307 .27887 L
.61343 .27955 L
.61424 .28157 L
.6151 .2844 L
.61682 .29198 L
.61844 .30103 L
.62154 .32105 L
.62312 .33104 L
.62484 .34058 L
.62563 .3442 L
.62648 .34739 L
.62689 .34865 L
.62728 .34965 L
.62766 .35045 L
.62801 .35104 L
.62821 .35129 L
.62838 .35147 L
.62858 .35163 L
.62868 .35169 L
.62874 .35172 L
.62879 .35174 L
.62889 .35177 L
.62899 .35179 L
.62909 .35179 L
.62918 .35178 L
.62924 .35177 L
.62929 .35176 L
.62939 .35172 L
.6295 .35167 L
.62961 .35159 L
.62981 .35141 L
.62998 .35121 L
.63038 .35059 L
.63075 .34981 L
.63109 .34891 L
.63187 .34629 L
.63269 .34262 L
.63417 .33393 L
.6372 .30983 L
.64042 .28138 L
Mistroke
.6419 .27001 L
.64274 .26458 L
.64352 .26035 L
.6443 .25706 L
.64473 .25565 L
.64513 .25465 L
.64533 .25424 L
.64555 .25389 L
.64566 .25375 L
.64578 .25361 L
.6459 .25351 L
.646 .25344 L
.64611 .25339 L
.64621 .25336 L
.64631 .25335 L
.64637 .25336 L
.64643 .25337 L
.64653 .2534 L
.64662 .25345 L
.64672 .25352 L
.64682 .25361 L
.64702 .25384 L
.6472 .25412 L
.64761 .25499 L
.64801 .25615 L
.64844 .25773 L
.64921 .26148 L
.64992 .26584 L
.65145 .27812 L
.65312 .29499 L
.65639 .33295 L
.65802 .35066 L
.65955 .36445 L
.66026 .36954 L
.66101 .37382 L
.6614 .37558 L
.66183 .3771 L
.66202 .37763 L
.66222 .37811 L
.66239 .37843 L
.66258 .37871 L
.66269 .37883 L
.66279 .37891 L
.66284 .37894 L
.66289 .37897 L
.66295 .37899 L
.66301 .379 L
.66311 .37901 L
.6632 .37899 L
.6633 .37894 L
Mistroke
.6634 .37886 L
.66352 .37875 L
.66364 .37858 L
.66387 .37818 L
.66409 .37767 L
.6643 .37709 L
.66467 .37573 L
.66508 .37383 L
.66591 .36872 L
.66674 .36206 L
.66748 .35472 L
.66916 .33448 L
.67237 .28792 L
.67384 .2669 L
.67545 .24687 L
.67622 .23911 L
.67704 .23235 L
.6775 .2294 L
.67791 .22722 L
.67811 .22635 L
.67833 .22554 L
.67854 .22492 L
.67873 .22445 L
.67894 .22409 L
.67904 .22395 L
.6791 .22389 L
.67916 .22384 L
.67926 .22378 L
.67935 .22376 L
.6794 .22375 L
.67946 .22376 L
.67956 .2238 L
.67965 .22386 L
.67975 .22396 L
.67983 .22406 L
.67992 .2242 L
.68012 .22462 L
.68031 .22513 L
.68073 .22668 L
.68112 .22862 L
.68199 .23474 L
.68278 .24224 L
.68351 .25078 L
.68517 .27492 L
.68831 .33066 L
.6899 .3588 L
.69074 .37219 L
.69164 .38469 L
.69243 .39405 L
.69285 .39822 L
Mistroke
.6933 .40205 L
.69372 .40492 L
.6941 .407 L
.69428 .4078 L
.69448 .40853 L
.69467 .40908 L
.69484 .40946 L
.69495 .40963 L
.695 .40971 L
.69506 .40977 L
.69515 .40984 L
.69525 .40989 L
.69531 .40989 L
.69536 .40989 L
.69547 .40984 L
.69552 .4098 L
.69558 .40975 L
.69569 .40959 L
.69579 .40943 L
.69588 .40924 L
.69608 .40868 L
.69628 .40798 L
.69649 .40705 L
.69687 .40494 L
.69727 .4021 L
.69799 .39548 L
.69876 .38627 L
.69958 .37425 L
.70105 .34785 L
.70439 .27659 L
.70606 .24259 L
.70679 .22953 L
.7076 .21703 L
.70832 .20775 L
.7091 .20012 L
.70953 .19702 L
.70992 .19493 L
.71011 .19418 L
.71021 .19385 L
.71032 .19355 L
.71041 .19334 L
.71051 .19314 L
.7106 .19301 L
.71069 .19293 L
.71078 .19288 L
.71088 .19287 L
.71098 .19291 L
.71106 .19298 L
.71117 .19311 L
.71128 .19331 L
Mistroke
.71148 .19382 L
.71169 .19457 L
.71191 .1956 L
.71231 .19804 L
.71267 .20094 L
.71301 .20422 L
.71379 .21367 L
.71542 .24141 L
.7169 .27422 L
.72009 .35408 L
.7217 .3907 L
.72316 .41692 L
.72355 .42244 L
.72397 .42761 L
.72434 .43136 L
.72474 .43468 L
.72494 .43605 L
.72516 .43727 L
.7254 .43826 L
.7255 .4386 L
.72562 .43891 L
.72573 .43914 L
.72583 .4393 L
.72593 .43938 L
.72604 .43942 L
.72613 .43939 L
.72622 .43932 L
.72632 .43919 L
.72642 .43899 L
.72652 .43874 L
.72661 .43846 L
.72682 .43766 L
.72701 .43671 L
.72719 .43562 L
.72759 .4325 L
.72803 .42811 L
.72891 .41617 L
.72972 .40175 L
.73289 .32277 L
.73593 .23735 L
.73749 .20155 L
.73837 .1861 L
.73876 .18054 L
.73917 .17557 L
.73959 .17157 L
.73996 .16886 L
.74014 .16788 L
.74034 .16704 L
.74043 .16675 L
.74053 .16649 L
Mistroke
.74061 .16631 L
.7407 .16617 L
.74075 .16611 L
.74081 .16607 L
.74091 .16605 L
.74102 .16609 L
.74111 .1662 L
.74122 .16638 L
.74133 .16666 L
.74145 .16704 L
.74156 .16748 L
.74195 .16964 L
.74216 .17128 L
.74236 .17304 L
.74315 .18249 L
.74388 .1946 L
.74555 .23241 L
.74869 .32761 L
.75029 .37707 L
.75113 .40051 L
.75202 .42217 L
.75282 .43817 L
.75324 .44516 L
.7537 .4514 L
.75411 .45594 L
.75449 .45905 L
.75468 .46019 L
.75487 .46115 L
.75497 .4615 L
.75506 .4618 L
.75515 .46201 L
.75524 .46218 L
.75533 .46229 L
.75542 .46234 L
.75552 .46232 L
.75558 .46227 L
.75563 .46221 L
.75573 .46204 L
.75579 .4619 L
.75584 .46176 L
.75605 .46103 L
.75622 .46017 L
.75641 .45898 L
.75679 .45579 L
.7572 .45113 L
.75765 .44479 L
.75846 .43001 L
.76016 .38695 L
.76177 .33537 L
.76484 .23199 L
Mistroke
.76642 .18858 L
.76731 .17019 L
.76811 .15801 L
.7685 .15373 L
.76871 .15189 L
.76891 .15048 L
.76908 .14953 L
.76927 .14876 L
.76937 .14844 L
.76947 .14821 L
.76956 .14808 L
.76965 .148 L
.76976 .148 L
.76985 .14807 L
.76991 .14815 L
.76996 .14824 L
.77007 .14853 L
.77018 .14888 L
.77029 .14936 L
.77052 .15063 L
.77072 .1521 L
.77094 .15401 L
.77132 .15835 L
.77215 .17131 L
.77304 .19065 L
.77466 .23735 L
.77794 .35463 L
.77958 .40861 L
.78038 .43067 L
.78111 .44745 L
.78147 .4544 L
.78186 .46088 L
.78224 .46597 L
.78258 .46961 L
.78277 .47125 L
.78297 .47267 L
.78309 .4733 L
.78319 .47379 L
.7833 .47419 L
.7834 .47448 L
.78348 .47467 L
.78357 .47479 L
.78367 .47485 L
.78376 .47483 L
.78386 .47473 L
.78396 .47454 L
.78406 .47427 L
.78415 .47395 L
.78435 .47302 L
.78453 .47189 L
Mistroke
.78493 .46836 L
.7853 .46391 L
.78566 .45863 L
.78645 .44338 L
.78731 .42174 L
.79057 .30894 L
.79208 .25237 L
.79372 .19867 L
.79461 .17524 L
.795 .16668 L
.79543 .15862 L
.79581 .15272 L
.79622 .14773 L
.79645 .14557 L
.79665 .14399 L
.79675 .14336 L
.79686 .14277 L
.79696 .14231 L
.79705 .14196 L
.79714 .1417 L
.79724 .14151 L
.79734 .14139 L
.79744 .14137 L
.79753 .14142 L
.79763 .14156 L
.79772 .14177 L
.79781 .14203 L
.79801 .14293 L
.79813 .1436 L
.79824 .14433 L
.79864 .14797 L
.79903 .15282 L
.79946 .15962 L
.80033 .1778 L
.80189 .22323 L
.80356 .28431 L
.80515 .34566 L
.80688 .40665 L
.80768 .43013 L
.80853 .45045 L
.80895 .45833 L
.80934 .46445 L
.80969 .46884 L
.81007 .47237 L
.81026 .47366 L
.81036 .47423 L
.81046 .47467 L
.81056 .47501 L
.81066 .47528 L
.81075 .47545 L
Mistroke
.81083 .47554 L
.81093 .47556 L
.81103 .47549 L
.81113 .47532 L
.81119 .47519 L
.81124 .47504 L
.81145 .47418 L
.81156 .4736 L
.81167 .47285 L
.8121 .46906 L
.81233 .46625 L
.81255 .46327 L
.81336 .44849 L
.81417 .42892 L
.81491 .40712 L
.81658 .34817 L
.81821 .28469 L
.81974 .22869 L
.82121 .18489 L
.82204 .1667 L
.82239 .16049 L
.82279 .15489 L
.82317 .15075 L
.82338 .14905 L
.82358 .14782 L
.82367 .14738 L
.82377 .147 L
.82385 .14674 L
.82394 .14653 L
.82403 .14638 L
.82413 .14631 L
.82423 .14634 L
.82432 .14643 L
.82442 .14664 L
.82447 .14679 L
.82453 .14697 L
.82473 .14784 L
.82484 .14849 L
.82496 .14931 L
.82518 .15112 L
.8256 .15589 L
.82598 .16161 L
.82678 .17715 L
.82751 .19577 L
.82917 .24964 L
.83232 .36769 L
.83314 .3956 L
.83404 .42174 L
.83488 .44152 L
.83565 .45479 L
Mistroke
.83603 .45939 L
.83624 .46138 L
.83644 .46291 L
.83662 .46402 L
.83672 .46448 L
.83682 .46487 L
.8369 .46513 L
.837 .46533 L
.83709 .46544 L
.83717 .46549 L
.83726 .46546 L
.83737 .46533 L
.83742 .46523 L
.83748 .46509 L
.83758 .46476 L
.83769 .46433 L
.83778 .46384 L
.83797 .46269 L
.83818 .46094 L
.83838 .45897 L
.83883 .45324 L
.8396 .4393 L
.84033 .42209 L
.84199 .37107 L
.84511 .25745 L
.84669 .20791 L
.84759 .18646 L
.84802 .17831 L
.84842 .17199 L
.84881 .16718 L
.84902 .16517 L
.84923 .16347 L
.84942 .16235 L
.84951 .16188 L
.84962 .16147 L
.84971 .16117 L
.8498 .16098 L
.84989 .16085 L
.84997 .16079 L
.85006 .1608 L
.85017 .16091 L
.85022 .161 L
.85028 .16112 L
.85038 .16142 L
.85048 .16181 L
.85058 .16226 L
.85076 .16334 L
.85097 .16497 L
.85117 .16684 L
.85162 .17231 L
Mistroke
.85202 .17872 L
.85246 .18711 L
.85326 .20586 L
.85476 .25061 L
.85632 .3053 L
.85805 .36473 L
.85884 .38891 L
.85968 .41116 L
.86048 .42784 L
.86083 .43359 L
.86121 .43882 L
.8616 .44287 L
.86181 .44455 L
.86201 .44579 L
.8621 .44623 L
.86219 .44663 L
.86228 .44691 L
.86236 .44714 L
.86246 .44732 L
.86255 .44741 L
.86265 .44744 L
.86274 .44738 L
.86285 .44722 L
.8629 .44711 L
.86296 .44696 L
.86316 .44622 L
.86327 .44566 L
.86339 .44494 L
.8636 .44333 L
.86402 .43904 L
.86441 .43387 L
.8652 .41973 L
.86594 .40283 L
.8676 .35435 L
.87075 .25191 L
.87157 .229 L
.87247 .20845 L
.87288 .20076 L
.87331 .19395 L
.87372 .18887 L
.87409 .18538 L
.87427 .18403 L
.87448 .18288 L
.87457 .18247 L
.87467 .18212 L
.87475 .18188 L
.87485 .18168 L
.87495 .18155 L
.87505 .18151 L
.8751 .18151 L
Mistroke
.87516 .18155 L
.87522 .18161 L
.87527 .1817 L
.87537 .18191 L
.87546 .18218 L
.87566 .18304 L
.87585 .18413 L
.87603 .18539 L
.87642 .18912 L
.87677 .19339 L
.87714 .19887 L
.87871 .23217 L
.88018 .27375 L
.8833 .36736 L
.88411 .38733 L
.885 .4049 L
.88541 .41125 L
.88584 .41674 L
.88621 .42034 L
.88642 .42194 L
.88662 .42314 L
.88671 .4236 L
.88681 .42402 L
.8869 .42432 L
.88699 .42458 L
.88705 .42471 L
.8871 .4248 L
.88721 .42492 L
.8873 .42495 L
.8874 .42491 L
.8875 .42479 L
.88761 .42459 L
.88771 .42431 L
.8878 .424 L
.88802 .42295 L
.88823 .42162 L
.8886 .4185 L
.88894 .41474 L
.88972 .4033 L
.89057 .38664 L
.89137 .36773 L
.89286 .32706 L
.89433 .28523 L
.89517 .2631 L
.89595 .24467 L
.89679 .22815 L
.89756 .21662 L
.89797 .21189 L
.89837 .2085 L
.89859 .20712 L
Mistroke
.89879 .20613 L
.8989 .20574 L
.89901 .20539 L
.89907 .20525 L
.89913 .20513 L
.89919 .20504 L
.89925 .20498 L
.89935 .20492 L
.89945 .20494 L
.89953 .20501 L
.89963 .20515 L
.89973 .20537 L
.89984 .20569 L
.90003 .20647 L
.90021 .20742 L
.90038 .20852 L
.90077 .21173 L
.90118 .21632 L
.90157 .22147 L
.90243 .23603 L
.90562 .31235 L
.90723 .35176 L
.90869 .38006 L
.90908 .38589 L
.9095 .39121 L
.90987 .39494 L
.91027 .39808 L
.91049 .39937 L
.9107 .40028 L
.91081 .40067 L
.91092 .40095 L
.91097 .40107 L
.91104 .40118 L
.9111 .40127 L
.91115 .40132 L
.91125 .40137 L
.91134 .40136 L
.91143 .40129 L
.91149 .40122 L
.91154 .40115 L
.91164 .40095 L
.91174 .40066 L
.91196 .39988 L
.91216 .39885 L
.91238 .39744 L
.91278 .39413 L
.91353 .38546 L
.91441 .37171 L
.91522 .35627 L
.91838 .2851 L
Mistroke
.9192 .26822 L
.91998 .25427 L
.92073 .24316 L
.92143 .23541 L
.92179 .23244 L
.92218 .2301 L
.92238 .22923 L
.92257 .22862 L
.92267 .22837 L
.92277 .2282 L
.92282 .22813 L
.92288 .22807 L
.92294 .22803 L
.92299 .22802 L
.9231 .22803 L
.92316 .22807 L
.92321 .22812 L
.92331 .22827 L
.92342 .22848 L
.9236 .22901 L
.92381 .22981 L
.92402 .23093 L
.92425 .23241 L
.92467 .23583 L
.92548 .24495 L
.92637 .25816 L
.92798 .28825 L
.9297 .32304 L
.93125 .35104 L
.93203 .3622 L
.93244 .36707 L
.93287 .37138 L
.93325 .37442 L
.93345 .37574 L
.93366 .37692 L
.93386 .3778 L
.93404 .37843 L
.93413 .37867 L
.93422 .37888 L
.93431 .37904 L
.93439 .37916 L
.93449 .37924 L
.93459 .37928 L
.93467 .37927 L
.93476 .37922 L
.93486 .37911 L
.93492 .37903 L
.93497 .37894 L
.93516 .37848 L
.93534 .37788 L
Mistroke
.93554 .37704 L
.93589 .37506 L
.93631 .37194 L
.93675 .36778 L
.93755 .35835 L
.94059 .30788 L
.94228 .2795 L
.94308 .26833 L
.94383 .25993 L
.94423 .25629 L
.94459 .25359 L
.945 .25126 L
.94522 .2503 L
.94543 .2496 L
.94561 .24915 L
.94571 .24898 L
.94581 .24885 L
.9459 .24877 L
.94599 .24872 L
.94608 .24871 L
.94616 .24874 L
.94626 .24881 L
.94635 .24892 L
.94646 .24909 L
.94656 .24932 L
.94675 .24982 L
.94695 .25055 L
.94736 .25261 L
.94776 .25525 L
.9485 .26182 L
.95018 .28281 L
.95325 .32891 L
.95406 .33942 L
.95482 .34771 L
.95525 .35149 L
.95571 .35486 L
.95612 .35724 L
.95632 .35814 L
.95651 .35883 L
.9567 .35941 L
.95688 .35982 L
.95698 .35998 L
.95708 .3601 L
.95718 .36019 L
.95723 .36022 L
.95729 .36024 L
.95738 .36025 L
.95747 .36022 L
.95756 .36015 L
.95766 .36005 L
Mistroke
.95775 .35992 L
.95783 .35977 L
.95802 .35935 L
.95823 .35869 L
.95844 .3579 L
.95882 .356 L
.95923 .35339 L
.95968 .34994 L
.96127 .33324 L
.96296 .31138 L
.96455 .29125 L
.96524 .28362 L
.966 .27659 L
.96642 .27341 L
.9668 .27094 L
.96719 .26891 L
.96756 .26747 L
.96777 .26687 L
.96787 .26661 L
.96799 .26639 L
.96808 .26623 L
.96819 .26609 L
.96828 .26601 L
.96837 .26595 L
.96843 .26593 L
.96849 .26592 L
.96854 .26592 L
.96859 .26593 L
.96869 .26598 L
.96879 .26606 L
.96884 .26612 L
.9689 .26619 L
.969 .26635 L
.96924 .26684 L
.96943 .26738 L
.96964 .2681 L
.97001 .26972 L
.97085 .27489 L
.97174 .28228 L
.97254 .29027 L
.97576 .32509 L
.97619 .32911 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{421.375, 260.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 525.688}, {324.5, 0}} -> {-2.58312*^-7, -6.34248*^6, \
6.65005*^-9, 53093.5}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0.309017 5.42214e-08 [
[.32684 .29652 -16.5 -12.5 ]
[.32684 .29652 16.5 0 ]
[.54329 .29652 -16.5 -12.5 ]
[.54329 .29652 16.5 0 ]
[.75974 .29652 -22.5 -12.5 ]
[.75974 .29652 22.5 0 ]
[.97619 .29652 -16.5 -12.5 ]
[.97619 .29652 16.5 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 64 6 ]
[.09789 .09213 -34.5 -6.25 ]
[.09789 .09213 0 6.25 ]
[.09789 .20057 -34.5 -6.25 ]
[.09789 .20057 0 6.25 ]
[.09789 .41746 -28.5 -6.25 ]
[.09789 .41746 0 6.25 ]
[.09789 .5259 -28.5 -6.25 ]
[.09789 .5259 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -62.8125 0 ]
[.5 .63053 62.8125 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 .30902 m
.32684 .31527 L
s
gsave
.32684 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 .30902 m
.54329 .31527 L
s
gsave
.54329 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 .30902 m
.75974 .31527 L
s
gsave
.75974 .29652 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 .30902 m
.15368 .31277 L
s
.19697 .30902 m
.19697 .31277 L
s
.24026 .30902 m
.24026 .31277 L
s
.28355 .30902 m
.28355 .31277 L
s
.37013 .30902 m
.37013 .31277 L
s
.41342 .30902 m
.41342 .31277 L
s
.45671 .30902 m
.45671 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.58658 .30902 m
.58658 .31277 L
s
.62987 .30902 m
.62987 .31277 L
s
.67316 .30902 m
.67316 .31277 L
s
.71645 .30902 m
.71645 .31277 L
s
.80303 .30902 m
.80303 .31277 L
s
.84632 .30902 m
.84632 .31277 L
s
.88961 .30902 m
.88961 .31277 L
s
.9329 .30902 m
.9329 .31277 L
s
.0671 .30902 m
.0671 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09213 m
.11664 .09213 L
s
gsave
.09789 .09213 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .20057 m
.11664 .20057 L
s
gsave
.09789 .20057 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .41746 m
.11664 .41746 L
s
gsave
.09789 .41746 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .5259 m
.11664 .5259 L
s
gsave
.09789 .5259 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.11039 .11924 m
.11414 .11924 L
s
.11039 .14635 m
.11414 .14635 L
s
.11039 .17346 m
.11414 .17346 L
s
.11039 .22768 m
.11414 .22768 L
s
.11039 .2548 m
.11414 .2548 L
s
.11039 .28191 m
.11414 .28191 L
s
.11039 .33613 m
.11414 .33613 L
s
.11039 .36324 m
.11414 .36324 L
s
.11039 .39035 m
.11414 .39035 L
s
.11039 .44457 m
.11414 .44457 L
s
.11039 .47168 m
.11414 .47168 L
s
.11039 .49879 m
.11414 .49879 L
s
.11039 .06502 m
.11414 .06502 L
s
.11039 .03791 m
.11414 .03791 L
s
.11039 .0108 m
.11414 .0108 L
s
.11039 .55301 m
.11414 .55301 L
s
.11039 .58012 m
.11414 .58012 L
s
.11039 .60723 m
.11414 .60723 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -123.812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.812 moveto
(@) show
81.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.812 moveto
(D) show
93.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(14.) show
135.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
141.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
153.000 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
157.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
166.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
184.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02691 .30902 L
.03029 .30902 L
.03347 .30902 L
.03652 .30902 L
.03978 .30902 L
.04291 .30902 L
.04623 .30902 L
.04944 .30902 L
.05252 .30902 L
.0558 .30902 L
.05896 .30902 L
.062 .30902 L
.06523 .30902 L
.06672 .30902 L
.06834 .30902 L
.06922 .30902 L
.07004 .30902 L
.07082 .30902 L
.07126 .30902 L
.07144 .30902 L
.07165 .30902 L
.07185 .30902 L
.07204 .30902 L
.07215 .30902 L
.07224 .30902 L
.07229 .30902 L
.07235 .30902 L
.07246 .30902 L
.07254 .30902 L
.07264 .30902 L
.07274 .30902 L
.07284 .30902 L
.07301 .30902 L
.0732 .30902 L
.0734 .30902 L
.07362 .30902 L
.07407 .30902 L
.07448 .30902 L
.07487 .30902 L
.07571 .30902 L
.07651 .30902 L
.07723 .30902 L
.078 .30902 L
.0796 .30902 L
.0804 .30902 L
.08129 .30902 L
.08285 .30902 L
.08452 .30902 L
.08622 .30902 L
Mistroke
.08784 .30902 L
.09091 .30902 L
.09249 .30902 L
.09417 .30902 L
.09578 .30902 L
.09752 .30902 L
.10074 .30902 L
.10403 .30902 L
.1072 .30902 L
.11026 .30902 L
.11351 .30902 L
.11663 .30902 L
.11996 .30902 L
.12316 .30902 L
.12624 .30902 L
.12952 .30902 L
.13267 .30902 L
.13571 .30902 L
.13894 .30902 L
.14205 .30902 L
.14536 .30902 L
.14854 .30902 L
.1516 .30902 L
.15486 .30902 L
.158 .30902 L
.16134 .30902 L
.16455 .30902 L
.16764 .30902 L
.17093 .30902 L
.1741 .30902 L
.17569 .30902 L
.17714 .30902 L
.17789 .30902 L
.17871 .30902 L
.17915 .30902 L
.17957 .30902 L
.17996 .30902 L
.18016 .30902 L
.18028 .30902 L
.18038 .30902 L
.18048 .30902 L
.18057 .30902 L
.18063 .30902 L
.18068 .30902 L
.18078 .30902 L
.18088 .30902 L
.18098 .30902 L
.18108 .30902 L
.18119 .30902 L
.18138 .30902 L
Mistroke
.18155 .30902 L
.18173 .30902 L
.18194 .30902 L
.18238 .30902 L
.18281 .30902 L
.18361 .30902 L
.18438 .30902 L
.1852 .30902 L
.18668 .30902 L
.1875 .30902 L
.1884 .30902 L
.19002 .30902 L
.19162 .30902 L
.19331 .30902 L
.19636 .30902 L
.19793 .30902 L
.1996 .30902 L
.20293 .30902 L
.20613 .30902 L
.2092 .30902 L
.21248 .30902 L
.21563 .30902 L
.21866 .30902 L
.22189 .30902 L
.225 .30902 L
.2283 .30902 L
.23149 .30902 L
.23455 .30902 L
.23612 .30902 L
.237 .30902 L
.2378 .30902 L
.23819 .30902 L
.23841 .30902 L
.23861 .30902 L
.23879 .30902 L
.23896 .30902 L
.23905 .30902 L
.23914 .30902 L
.23924 .30902 L
.23934 .30902 L
.2394 .30902 L
.23946 .30902 L
.23951 .30902 L
.23957 .30902 L
.23966 .30902 L
.23976 .30902 L
.23988 .30902 L
.23998 .30902 L
.24021 .30902 L
.24041 .30902 L
Mistroke
.2406 .30902 L
.24101 .30902 L
.2414 .30902 L
.24181 .30902 L
.24255 .30902 L
.24334 .30902 L
.24422 .30902 L
.24578 .30902 L
.24745 .30902 L
.24915 .30902 L
.25076 .30902 L
.25382 .30902 L
.25709 .30902 L
.26023 .30902 L
.26356 .30902 L
.26678 .30902 L
.26987 .30902 L
.27316 .30902 L
.27633 .30902 L
.27938 .30902 L
.28094 .30902 L
.28181 .30902 L
.28262 .30902 L
.28344 .30902 L
.28387 .30902 L
.28409 .30902 L
.28432 .30902 L
.28453 .30902 L
.28462 .30902 L
.28472 .30902 L
.28481 .30902 L
.2849 .30902 L
.285 .30902 L
.28509 .30902 L
.28515 .30902 L
.2852 .30902 L
.28526 .30902 L
.28532 .30902 L
.28542 .30902 L
.28548 .30902 L
.28554 .30902 L
.28564 .30902 L
.28573 .30902 L
.28594 .30902 L
.28614 .30902 L
.28632 .30902 L
.28673 .30902 L
.28711 .30902 L
.28747 .30902 L
.28827 .30902 L
Mistroke
.28913 .30902 L
.28989 .30902 L
.29073 .30902 L
.29242 .30902 L
.29399 .30902 L
.29567 .30902 L
.299 .30902 L
.3022 .30902 L
.30528 .30902 L
.30855 .30902 L
.31171 .30902 L
.31474 .30901 L
.31797 .30901 L
.31946 .30901 L
.3203 .30901 L
.32108 .30901 L
.32186 .30901 L
.32226 .30901 L
.32269 .30901 L
.32293 .30901 L
.32315 .30901 L
.32336 .30901 L
.32346 .30901 L
.32358 .30901 L
.32368 .30901 L
.32378 .30901 L
.32387 .30901 L
.32396 .30901 L
.32407 .30901 L
.32417 .30901 L
.32422 .30901 L
.32427 .30901 L
.32433 .30901 L
.32439 .30901 L
.32448 .30901 L
.32458 .30901 L
.32476 .30901 L
.32498 .30901 L
.32517 .30901 L
.3256 .30901 L
.326 .30901 L
.32671 .30901 L
.32749 .30901 L
.32825 .30901 L
.32908 .30901 L
.33077 .30901 L
.33233 .30902 L
.334 .30902 L
.33731 .30902 L
.3405 .30902 L
Mistroke
.34357 .30902 L
.34683 .30902 L
.34997 .30903 L
.35157 .30903 L
.35331 .30903 L
.35412 .30903 L
.35498 .30903 L
.35579 .30903 L
.35653 .30903 L
.35692 .30903 L
.35729 .30903 L
.35748 .30903 L
.35768 .30903 L
.35778 .30903 L
.3579 .30903 L
.358 .30903 L
.3581 .30903 L
.35819 .30903 L
.35828 .30903 L
.35838 .30903 L
.35847 .30903 L
.35856 .30903 L
.35864 .30903 L
.35873 .30903 L
.35881 .30903 L
.359 .30903 L
.35918 .30903 L
.35957 .30903 L
.35995 .30903 L
.36035 .30903 L
.36108 .30903 L
.36195 .30903 L
.36274 .30903 L
.36427 .30903 L
.36593 .30903 L
.36751 .30902 L
.3692 .30902 L
.37254 .30901 L
.37576 .309 L
.37886 .30899 L
.38216 .30898 L
.3838 .30898 L
.38533 .30897 L
.38609 .30897 L
.3868 .30897 L
.3872 .30897 L
.38763 .30897 L
.38799 .30897 L
.38838 .30897 L
.38859 .30897 L
Mistroke
.38877 .30897 L
.38886 .30897 L
.38896 .30897 L
.38905 .30897 L
.38914 .30897 L
.38919 .30897 L
.38925 .30897 L
.38935 .30897 L
.38941 .30897 L
.38947 .30897 L
.38952 .30897 L
.38957 .30897 L
.38967 .30897 L
.38973 .30897 L
.38978 .30897 L
.38997 .30897 L
.39008 .30897 L
.39019 .30897 L
.39039 .30897 L
.39084 .30897 L
.39123 .30897 L
.39166 .30897 L
.39247 .30897 L
.39321 .30897 L
.39489 .30898 L
.3964 .30899 L
.39806 .309 L
.40132 .30902 L
.40445 .30905 L
.40778 .30909 L
.41099 .30912 L
.41246 .30913 L
.41407 .30914 L
.41484 .30915 L
.41567 .30915 L
.41612 .30915 L
.41654 .30916 L
.41674 .30916 L
.41696 .30916 L
.41716 .30916 L
.41735 .30916 L
.41756 .30916 L
.41767 .30916 L
.41772 .30916 L
.41778 .30916 L
.41788 .30916 L
.41797 .30916 L
.41803 .30916 L
.41808 .30916 L
.41818 .30916 L
Mistroke
.41828 .30916 L
.41837 .30916 L
.41845 .30916 L
.41854 .30916 L
.41875 .30916 L
.41894 .30916 L
.41936 .30916 L
.41975 .30915 L
.42017 .30915 L
.42062 .30915 L
.42139 .30915 L
.42221 .30914 L
.42368 .30912 L
.4254 .3091 L
.42701 .30906 L
.4301 .30899 L
.43339 .30889 L
.43656 .3088 L
.4396 .30872 L
.44116 .30869 L
.44204 .30868 L
.44243 .30867 L
.44284 .30867 L
.44326 .30866 L
.44363 .30866 L
.44381 .30866 L
.44401 .30866 L
.4441 .30866 L
.4442 .30866 L
.44428 .30866 L
.44437 .30866 L
.44447 .30866 L
.44457 .30866 L
.44467 .30866 L
.44473 .30866 L
.44478 .30866 L
.44487 .30866 L
.44496 .30866 L
.44507 .30866 L
.44516 .30866 L
.44538 .30866 L
.44558 .30866 L
.44603 .30866 L
.44642 .30867 L
.44682 .30867 L
.44756 .30868 L
.44843 .3087 L
.44922 .30872 L
.45076 .30878 L
.45244 .30885 L
Mistroke
.45573 .30905 L
.4589 .30928 L
.46194 .30951 L
.46364 .30962 L
.46519 .30971 L
.46596 .30974 L
.46679 .30978 L
.46758 .3098 L
.46796 .30981 L
.46831 .30982 L
.46868 .30982 L
.46888 .30983 L
.46898 .30983 L
.46908 .30983 L
.46918 .30983 L
.46926 .30983 L
.46935 .30983 L
.46943 .30983 L
.46952 .30983 L
.46961 .30983 L
.46971 .30983 L
.46981 .30983 L
.46991 .30983 L
.47 .30983 L
.47021 .30983 L
.47041 .30983 L
.4706 .30982 L
.47101 .30982 L
.47146 .3098 L
.47229 .30978 L
.47304 .30974 L
.47473 .30963 L
.47628 .30948 L
.47795 .30928 L
.48124 .3088 L
.48442 .30827 L
.48747 .3078 L
.48904 .3076 L
.48991 .30751 L
.49072 .30744 L
.49153 .30739 L
.49197 .30737 L
.49219 .30737 L
.49242 .30736 L
.49263 .30736 L
.49272 .30735 L
.49282 .30735 L
.49291 .30735 L
.493 .30735 L
.49309 .30735 L
Mistroke
.49319 .30735 L
.49325 .30735 L
.4933 .30735 L
.49336 .30735 L
.49342 .30735 L
.49352 .30735 L
.49364 .30735 L
.49374 .30735 L
.49385 .30736 L
.49404 .30736 L
.49425 .30737 L
.49446 .30738 L
.49486 .3074 L
.49528 .30742 L
.49574 .30746 L
.49657 .30754 L
.49736 .30764 L
.49897 .30792 L
.50046 .30826 L
.50364 .30917 L
.50669 .3102 L
.50995 .31124 L
.51145 .31163 L
.51224 .3118 L
.51308 .31195 L
.5135 .31201 L
.51397 .31207 L
.51439 .3121 L
.51479 .31213 L
.515 .31214 L
.5151 .31215 L
.51519 .31215 L
.51529 .31215 L
.51537 .31215 L
.51547 .31216 L
.51557 .31216 L
.51562 .31216 L
.51567 .31216 L
.51577 .31216 L
.51583 .31216 L
.51588 .31216 L
.51594 .31216 L
.516 .31215 L
.51611 .31215 L
.51621 .31215 L
.5164 .31214 L
.51659 .31213 L
.51677 .31212 L
.51718 .31208 L
.51758 .31203 L
Mistroke
.518 .31197 L
.51878 .31182 L
.51948 .31165 L
.521 .31116 L
.52266 .31045 L
.52592 .30864 L
.52906 .30665 L
.53066 .30568 L
.53239 .30475 L
.5332 .30439 L
.53406 .30406 L
.53479 .30384 L
.53518 .30374 L
.5356 .30366 L
.53582 .30362 L
.53602 .30359 L
.53623 .30356 L
.53642 .30354 L
.5366 .30353 L
.53669 .30353 L
.53678 .30352 L
.53687 .30352 L
.53696 .30351 L
.53706 .30351 L
.53716 .30351 L
.53722 .30351 L
.53727 .30351 L
.53733 .30352 L
.53738 .30352 L
.53748 .30352 L
.53758 .30353 L
.53779 .30354 L
.53803 .30357 L
.53823 .30359 L
.53845 .30363 L
.53884 .3037 L
.53965 .30393 L
.54053 .30428 L
.54215 .30517 L
.54372 .30636 L
.54541 .30791 L
.54874 .31152 L
.55196 .31495 L
.55343 .31625 L
.55427 .31686 L
.55505 .31733 L
.55582 .31769 L
.55626 .31784 L
.55665 .31795 L
.55687 .31799 L
Mistroke
.55707 .31803 L
.55718 .31804 L
.55729 .31805 L
.5574 .31806 L
.55745 .31806 L
.55752 .31807 L
.55762 .31807 L
.55767 .31807 L
.55773 .31807 L
.55778 .31807 L
.55783 .31807 L
.55789 .31806 L
.55795 .31806 L
.55805 .31806 L
.55814 .31805 L
.55834 .31802 L
.55854 .31799 L
.55872 .31795 L
.55912 .31784 L
.55949 .3177 L
.55985 .31754 L
.56064 .31707 L
.5615 .31639 L
.56308 .31472 L
.56477 .31239 L
.56811 .30664 L
.57133 .30084 L
.5728 .29855 L
.57364 .29745 L
.57442 .29657 L
.5752 .29587 L
.5756 .29558 L
.57603 .29533 L
.57626 .29521 L
.57648 .29513 L
.57669 .29506 L
.57679 .29503 L
.57691 .295 L
.57702 .29498 L
.57711 .29497 L
.57721 .29496 L
.5773 .29495 L
.57741 .29494 L
.5775 .29494 L
.57761 .29495 L
.57767 .29495 L
.57772 .29495 L
.57781 .29496 L
.5779 .29498 L
.57811 .29502 L
Mistroke
.57831 .29507 L
.57852 .29515 L
.57891 .29533 L
.57926 .29554 L
.58012 .29627 L
.58093 .29722 L
.58253 .29979 L
.584 .30292 L
.58715 .31128 L
.59018 .31986 L
.59186 .32403 L
.59259 .3256 L
.5934 .32707 L
.59413 .32816 L
.59491 .32904 L
.59534 .3294 L
.59573 .32963 L
.59592 .32971 L
.59602 .32974 L
.59613 .32977 L
.59622 .3298 L
.59632 .32981 L
.59641 .32982 L
.5965 .32983 L
.5966 .32983 L
.59666 .32983 L
.59671 .32983 L
.59681 .32981 L
.5969 .3298 L
.59701 .32977 L
.59711 .32974 L
.59733 .32966 L
.59752 .32956 L
.59772 .32944 L
.59813 .3291 L
.5985 .32871 L
.5989 .3282 L
.59961 .32704 L
.60043 .32535 L
.60132 .32308 L
.60293 .31796 L
.60621 .30484 L
.60936 .29176 L
.61094 .28631 L
.61239 .28251 L
.61315 .28111 L
.61353 .28056 L
.61394 .2801 L
.61416 .27992 L
.61436 .27979 L
Mistroke
.61447 .27973 L
.61459 .27968 L
.61471 .27964 L
.61481 .27961 L
.61491 .2796 L
.615 .27959 L
.6151 .2796 L
.61515 .2796 L
.6152 .27961 L
.6153 .27963 L
.61536 .27964 L
.61542 .27966 L
.61562 .27975 L
.61572 .27981 L
.61583 .27988 L
.61603 .28004 L
.61647 .28053 L
.61685 .28109 L
.61727 .28186 L
.61804 .2837 L
.61876 .28588 L
.6204 .29238 L
.62189 .29987 L
.62509 .31883 L
.62817 .33624 L
.62976 .34304 L
.63057 .3456 L
.631 .3467 L
.63145 .34762 L
.63184 .34823 L
.63206 .34849 L
.63226 .34868 L
.63236 .34876 L
.63245 .34881 L
.63254 .34886 L
.63262 .34889 L
.63272 .34892 L
.63281 .34894 L
.6329 .34894 L
.63301 .34894 L
.63306 .34893 L
.63312 .34891 L
.63318 .3489 L
.63323 .34888 L
.63332 .34883 L
.63343 .34877 L
.63364 .3486 L
.63387 .34834 L
.63429 .34771 L
.63468 .3469 L
Mistroke
.63547 .34469 L
.6363 .34151 L
.63779 .33382 L
.64084 .31175 L
.6441 .28497 L
.6456 .27397 L
.64723 .26448 L
.64766 .26252 L
.64812 .26074 L
.64854 .25936 L
.64894 .25834 L
.64931 .25761 L
.64952 .2573 L
.64971 .25709 L
.64982 .25699 L
.64992 .25692 L
.65003 .25687 L
.65009 .25685 L
.65014 .25683 L
.65025 .25682 L
.6503 .25682 L
.65036 .25682 L
.65045 .25685 L
.65056 .25689 L
.65065 .25695 L
.65076 .25704 L
.65095 .25724 L
.65114 .2575 L
.65132 .2578 L
.65171 .25869 L
.65213 .25993 L
.65283 .2627 L
.65361 .26672 L
.65516 .27767 L
.65684 .29297 L
.66014 .32853 L
.66179 .34565 L
.66332 .35915 L
.66408 .36459 L
.6648 .36878 L
.6652 .37066 L
.66563 .37234 L
.66602 .37351 L
.66638 .3743 L
.66658 .3746 L
.66676 .3748 L
.66686 .37487 L
.66691 .37491 L
.66696 .37493 L
.66706 .37496 L
Mistroke
.66716 .37497 L
.66726 .37496 L
.66736 .37492 L
.66745 .37486 L
.66754 .37478 L
.66771 .37459 L
.66789 .37431 L
.66809 .37392 L
.6683 .37339 L
.66868 .37217 L
.66913 .37027 L
.66955 .36813 L
.67108 .35685 L
.67195 .34838 L
.67275 .33941 L
.67591 .29736 L
.67895 .25741 L
.6805 .2418 L
.68138 .23535 L
.68176 .23312 L
.68218 .23118 L
.68239 .23037 L
.68259 .22972 L
.68279 .2292 L
.68297 .22883 L
.68314 .22856 L
.68323 .22845 L
.68332 .22836 L
.68342 .2283 L
.68352 .22827 L
.68361 .22827 L
.6837 .22829 L
.6838 .22834 L
.68386 .22838 L
.68391 .22843 L
.68411 .22869 L
.68422 .22889 L
.68434 .22914 L
.68456 .22971 L
.68498 .23124 L
.68536 .23312 L
.68615 .23831 L
.68688 .24472 L
.68854 .26437 L
.69168 .31452 L
.69328 .342 L
.69501 .36915 L
.69582 .37998 L
.69668 .38967 L
.69741 .39625 L
Mistroke
.6978 .39902 L
.69822 .40147 L
.69843 .4025 L
.69863 .4033 L
.69884 .40397 L
.69903 .40444 L
.69912 .40462 L
.69922 .40477 L
.69931 .40489 L
.69939 .40497 L
.69948 .40503 L
.69958 .40506 L
.69968 .40505 L
.69978 .405 L
.69988 .40491 L
.69994 .40485 L
.69999 .40477 L
.7002 .40439 L
.70039 .4039 L
.70059 .40323 L
.701 .40137 L
.70145 .39858 L
.70227 .3917 L
.70301 .38339 L
.70468 .35846 L
.70787 .29598 L
.71093 .23674 L
.71174 .22422 L
.71251 .21433 L
.71293 .20975 L
.71339 .20558 L
.7138 .20256 L
.71419 .20039 L
.71438 .19957 L
.71456 .19893 L
.71466 .19864 L
.71476 .19838 L
.71486 .19819 L
.71495 .19804 L
.71505 .19793 L
.7151 .19789 L
.71516 .19785 L
.71522 .19784 L
.71528 .19784 L
.71533 .19785 L
.71539 .19788 L
.71549 .19796 L
.71554 .19803 L
.71559 .19811 L
.71579 .1985 L
Mistroke
.71589 .19878 L
.716 .19914 L
.7162 .19993 L
.71666 .20238 L
.71705 .20524 L
.71748 .20919 L
.71829 .21881 L
.71904 .22993 L
.72071 .26182 L
.7239 .33691 L
.72551 .37391 L
.72697 .40224 L
.72773 .41404 L
.72855 .42404 L
.729 .4282 L
.7292 .4297 L
.72941 .43113 L
.72961 .43218 L
.72981 .43309 L
.72992 .4335 L
.73003 .43382 L
.73013 .43408 L
.73023 .43427 L
.73032 .43439 L
.73041 .43448 L
.73052 .43453 L
.73062 .43451 L
.73071 .43445 L
.73082 .43433 L
.73087 .43424 L
.73092 .43413 L
.73103 .43389 L
.73122 .43326 L
.73141 .43247 L
.73176 .43049 L
.73218 .42727 L
.73256 .4235 L
.73343 .41225 L
.73494 .38451 L
.73659 .34474 L
.73983 .25662 L
.74132 .22037 L
.74211 .20427 L
.74295 .19013 L
.74341 .18383 L
.74383 .17913 L
.74425 .17541 L
.74465 .17286 L
.74485 .17195 L
.74495 .17155 L
Mistroke
.74505 .17124 L
.74515 .17101 L
.74523 .17084 L
.74532 .17071 L
.74542 .17064 L
.74548 .17062 L
.74553 .17062 L
.74563 .17067 L
.74569 .17073 L
.74574 .17079 L
.74586 .17101 L
.74596 .17127 L
.74605 .17157 L
.74626 .17243 L
.74646 .17351 L
.74664 .1747 L
.74705 .17811 L
.74779 .18675 L
.74864 .2007 L
.74945 .2173 L
.75254 .3026 L
.75411 .35067 L
.75583 .39882 L
.75662 .41748 L
.75747 .43416 L
.75788 .44082 L
.75827 .44621 L
.75864 .45052 L
.759 .45372 L
.75937 .45617 L
.75956 .4571 L
.75966 .45748 L
.75977 .45781 L
.75982 .45794 L
.75988 .45805 L
.75998 .4582 L
.76004 .45826 L
.7601 .45829 L
.7602 .45829 L
.7603 .45822 L
.76039 .4581 L
.76049 .45789 L
.7606 .4576 L
.76077 .45695 L
.76096 .456 L
.7613 .45367 L
.7617 .44986 L
.76207 .44541 L
.76286 .43292 L
.7636 .41796 L
Mistroke
.76526 .37403 L
.76841 .27141 L
.77001 .22161 L
.77086 .19913 L
.77175 .17935 L
.77255 .16569 L
.773 .15985 L
.77322 .15757 L
.77342 .15573 L
.77361 .15434 L
.77381 .15311 L
.774 .15227 L
.77408 .15198 L
.77417 .15172 L
.77426 .15151 L
.77435 .15138 L
.77446 .1513 L
.77455 .1513 L
.77465 .15137 L
.77475 .15153 L
.77481 .15165 L
.77486 .15179 L
.77496 .15211 L
.77517 .15302 L
.77539 .15434 L
.77579 .15763 L
.77621 .16247 L
.77668 .1693 L
.77752 .18528 L
.7783 .20416 L
.78142 .30514 L
.783 .3613 L
.78473 .41543 L
.78554 .43581 L
.78639 .45308 L
.78681 .45962 L
.7872 .4646 L
.78755 .46805 L
.78775 .46956 L
.78793 .47067 L
.78803 .47118 L
.78813 .47158 L
.78821 .47188 L
.78831 .47213 L
.78841 .47232 L
.7885 .47242 L
.7886 .47244 L
.78866 .47242 L
.78871 .47238 L
.78881 .47224 L
Mistroke
.7889 .47204 L
.78898 .4718 L
.78906 .47149 L
.78926 .47054 L
.78944 .46939 L
.78986 .46567 L
.79025 .46107 L
.7911 .44669 L
.79191 .42843 L
.79265 .40807 L
.79432 .35265 L
.79749 .23671 L
.79831 .21028 L
.79908 .18833 L
.79984 .17053 L
.80054 .15768 L
.8009 .15249 L
.80129 .14816 L
.80147 .14651 L
.80167 .14507 L
.80179 .1444 L
.80189 .14389 L
.80199 .14349 L
.80205 .14331 L
.8021 .14316 L
.80221 .14293 L
.8023 .14281 L
.80239 .14277 L
.80249 .14281 L
.80254 .14286 L
.8026 .14294 L
.80266 .14306 L
.80271 .1432 L
.80281 .14351 L
.80292 .14395 L
.80315 .14522 L
.80337 .14686 L
.80378 .15104 L
.80419 .15653 L
.80455 .16265 L
.80537 .18007 L
.80685 .22252 L
.81007 .34166 L
.81155 .39456 L
.81239 .42053 L
.81317 .44098 L
.81394 .45695 L
.81438 .46384 L
.81477 .46874 L
.81497 .47072 L
Mistroke
.81519 .47244 L
.8153 .47317 L
.81542 .47385 L
.81554 .47435 L
.81564 .47471 L
.81574 .47497 L
.81585 .47514 L
.81595 .47521 L
.81601 .4752 L
.81607 .47517 L
.81617 .47504 L
.81626 .47484 L
.81636 .47452 L
.81646 .47412 L
.81666 .4731 L
.81684 .47184 L
.81725 .46792 L
.81765 .46269 L
.81807 .45561 L
.81885 .4391 L
.81956 .4203 L
.82275 .30676 L
.82421 .25135 L
.82504 .22248 L
.82583 .1984 L
.82665 .17708 L
.82741 .16195 L
.8278 .15593 L
.82822 .15104 L
.82844 .1491 L
.82864 .14768 L
.82875 .14704 L
.82886 .14654 L
.82892 .14631 L
.82898 .14609 L
.82904 .14594 L
.8291 .14581 L
.82919 .14566 L
.82928 .14561 L
.82938 .14563 L
.82949 .14575 L
.82958 .14593 L
.82968 .14622 L
.82977 .14657 L
.82985 .14696 L
.83006 .14819 L
.83028 .14995 L
.83069 .15427 L
.83112 .16039 L
.83157 .16852 L
Mistroke
.83238 .18701 L
.83395 .23515 L
.83543 .28932 L
.83692 .34654 L
.83855 .40274 L
.83944 .42772 L
.84026 .44599 L
.84066 .45305 L
.84104 .45843 L
.84144 .4627 L
.84165 .4644 L
.84177 .46519 L
.84187 .46579 L
.84197 .46622 L
.84207 .4666 L
.84217 .4669 L
.84227 .46709 L
.84236 .46718 L
.84246 .46719 L
.84255 .46713 L
.84264 .46699 L
.8427 .46686 L
.84275 .46671 L
.84285 .46637 L
.84296 .46589 L
.84308 .46526 L
.84329 .4638 L
.84348 .46209 L
.84391 .45713 L
.8443 .45127 L
.84518 .4337 L
.84673 .38975 L
.8484 .33036 L
.84997 .2717 L
.85169 .21458 L
.85249 .1935 L
.85293 .18375 L
.85334 .17587 L
.85372 .16977 L
.85414 .16456 L
.85432 .16274 L
.85452 .16114 L
.85469 .16005 L
.85487 .15913 L
.85497 .15875 L
.85507 .15848 L
.85517 .15828 L
.85523 .15821 L
.85529 .15818 L
.85538 .15818 L
Mistroke
.85549 .15829 L
.85559 .15848 L
.85568 .15873 L
.85577 .15905 L
.85586 .15942 L
.85604 .16048 L
.85623 .16182 L
.85643 .16359 L
.85688 .16887 L
.8573 .17544 L
.8581 .19156 L
.8597 .23621 L
.86118 .28707 L
.8628 .34529 L
.86433 .39414 L
.86504 .41292 L
.86579 .42909 L
.86618 .4359 L
.86661 .44195 L
.86679 .44412 L
.867 .44612 L
.86717 .44755 L
.86736 .44884 L
.86757 .44988 L
.86768 .45029 L
.86773 .45044 L
.86779 .45057 L
.86788 .45074 L
.86798 .45082 L
.86807 .45083 L
.86813 .4508 L
.86818 .45074 L
.86824 .45066 L
.8683 .45053 L
.86841 .45023 L
.86851 .44983 L
.86861 .44937 L
.86883 .44802 L
.86907 .44614 L
.86947 .44188 L
.86984 .43674 L
.87069 .42113 L
.87153 .40082 L
.87232 .37804 L
.87381 .32934 L
.87528 .27949 L
.87689 .23024 L
.87766 .21125 L
.87848 .19504 L
.87894 .18823 L
Mistroke
.87935 .18341 L
.87956 .18154 L
.87975 .18011 L
.87995 .17895 L
.88006 .17847 L
.88017 .17806 L
.88027 .17779 L
.88033 .17768 L
.88038 .17759 L
.88043 .17753 L
.88048 .17749 L
.88054 .17748 L
.8806 .17749 L
.8807 .17758 L
.88079 .17773 L
.88089 .17798 L
.88099 .17833 L
.88121 .17936 L
.88142 .18068 L
.88164 .18252 L
.88189 .18497 L
.88273 .19696 L
.8835 .21235 L
.88502 .25208 L
.88668 .30396 L
.88838 .35683 L
.88993 .39647 L
.8907 .41118 L
.89111 .41731 L
.89154 .42249 L
.89192 .42587 L
.89213 .42729 L
.89224 .42785 L
.89233 .4283 L
.89242 .42865 L
.89252 .42895 L
.8926 .42916 L
.89268 .42931 L
.89278 .42941 L
.89287 .42944 L
.89297 .4294 L
.89306 .42929 L
.89316 .42911 L
.89326 .42885 L
.89344 .42816 L
.89365 .42702 L
.89385 .42568 L
.89427 .42175 L
.89468 .41681 L
.89539 .40541 L
Mistroke
.89616 .38953 L
.89943 .2989 L
.90106 .25405 L
.90185 .23555 L
.90258 .22151 L
.90329 .21099 L
.90365 .20699 L
.90404 .20364 L
.90425 .20231 L
.90444 .20138 L
.90454 .20097 L
.90465 .20062 L
.9047 .20049 L
.90476 .20037 L
.90486 .20022 L
.90495 .20015 L
.90504 .20013 L
.90513 .20018 L
.90522 .20027 L
.90532 .20045 L
.90542 .20073 L
.90552 .20106 L
.90562 .20144 L
.90583 .20253 L
.90602 .20382 L
.90647 .20772 L
.90686 .21224 L
.90727 .21806 L
.90876 .24702 L
.91181 .32629 L
.91351 .36721 L
.91432 .3826 L
.91506 .39373 L
.91544 .39808 L
.91583 .40171 L
.91602 .40309 L
.91623 .40431 L
.91635 .40488 L
.91646 .40532 L
.91656 .40566 L
.91667 .40594 L
.91677 .40613 L
.91685 .40624 L
.91694 .4063 L
.91702 .40631 L
.91712 .40626 L
.91721 .40616 L
.91731 .40599 L
.91741 .40574 L
.9176 .40508 L
Mistroke
.91778 .40425 L
.91819 .40157 L
.91859 .39791 L
.91903 .39283 L
.91982 .3809 L
.92131 .3511 L
.92287 .31416 L
.92458 .27393 L
.92536 .25799 L
.92621 .24355 L
.92659 .23806 L
.927 .23313 L
.92738 .22943 L
.92773 .2267 L
.92792 .22553 L
.92813 .22451 L
.92823 .22415 L
.92832 .22382 L
.92841 .22357 L
.9285 .22338 L
.92859 .22322 L
.9287 .22311 L
.92879 .22307 L
.92889 .22308 L
.92894 .22311 L
.92899 .22316 L
.92909 .2233 L
.92915 .22341 L
.92921 .22354 L
.92932 .22383 L
.92949 .22447 L
.92968 .22536 L
.93002 .22747 L
.93039 .23048 L
.93079 .23461 L
.93161 .24557 L
.93236 .25805 L
.93404 .29186 L
.9357 .3275 L
.93643 .34201 L
.93724 .35624 L
.93796 .36687 L
.93873 .3757 L
.93916 .37927 L
.93934 .38054 L
.93955 .3817 L
.93973 .38255 L
.93992 .38325 L
.94003 .38355 L
.94013 .38376 L
Mistroke
.94022 .38393 L
.94031 .38404 L
.94041 .3841 L
.94051 .38411 L
.9406 .38407 L
.94069 .384 L
.94079 .38386 L
.9409 .38364 L
.941 .38337 L
.9411 .38308 L
.94131 .38225 L
.9415 .3813 L
.94192 .3785 L
.94229 .37536 L
.94269 .37127 L
.9434 .36217 L
.9467 .30378 L
.94835 .27491 L
.94915 .26337 L
.94988 .25494 L
.95024 .25158 L
.95064 .24861 L
.95082 .24749 L
.95101 .24647 L
.95119 .24568 L
.95135 .2451 L
.95154 .2446 L
.95164 .24439 L
.95174 .24425 L
.95183 .24415 L
.95191 .2441 L
.95201 .24409 L
.9521 .24412 L
.95216 .24416 L
.95221 .2442 L
.95227 .24427 L
.95233 .24436 L
.95243 .24455 L
.95254 .24481 L
.95274 .24545 L
.95293 .24622 L
.95333 .24839 L
.95377 .25157 L
.95457 .25932 L
.95605 .27936 L
.95761 .30459 L
.95933 .332 L
.96011 .34273 L
.96095 .3523 L
.96134 .35586 L
Mistroke
.96175 .35899 L
.9621 .36113 L
.96248 .3629 L
.96268 .36358 L
.96279 .36387 L
.9629 .36413 L
.963 .3643 L
.96305 .36438 L
.96311 .36445 L
.96321 .36453 L
.9633 .36458 L
.9634 .36458 L
.9635 .36454 L
.9636 .36446 L
.96369 .36435 L
.96379 .36421 L
.96387 .36404 L
.96405 .36357 L
.96427 .36284 L
.96447 .362 L
.96492 .35953 L
.96532 .35672 L
.96573 .35316 L
.96731 .33526 L
.96879 .31474 L
.97028 .29379 L
.97107 .28393 L
.97191 .27505 L
.97233 .27134 L
.9728 .26791 L
.97322 .26544 L
.97362 .2637 L
.97382 .26305 L
.97403 .26253 L
.9742 .26221 L
.9743 .26208 L
.9744 .26199 L
.97445 .26196 L
.97451 .26194 L
.97461 .26192 L
.97471 .26195 L
.9748 .262 L
.9749 .2621 L
.97501 .26225 L
.97513 .26245 L
.97524 .26268 L
.97549 .26341 L
.97574 .2643 L
.97619 .26653 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{421.375, 260.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 525.688}, {324.5, 0}} -> {-2.58312*^-7, -6.34248*^6, \
6.65005*^-9, 53093.5}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0.309017 5.42214e-08 [
[.32684 .29652 -16.5 -12.5 ]
[.32684 .29652 16.5 0 ]
[.54329 .29652 -16.5 -12.5 ]
[.54329 .29652 16.5 0 ]
[.75974 .29652 -22.5 -12.5 ]
[.75974 .29652 22.5 0 ]
[.97619 .29652 -16.5 -12.5 ]
[.97619 .29652 16.5 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 64 6 ]
[.09789 .09213 -34.5 -6.25 ]
[.09789 .09213 0 6.25 ]
[.09789 .20057 -34.5 -6.25 ]
[.09789 .20057 0 6.25 ]
[.09789 .41746 -28.5 -6.25 ]
[.09789 .41746 0 6.25 ]
[.09789 .5259 -28.5 -6.25 ]
[.09789 .5259 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -65.8125 0 ]
[.5 .63053 65.8125 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 .30902 m
.32684 .31527 L
s
gsave
.32684 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 .30902 m
.54329 .31527 L
s
gsave
.54329 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 .30902 m
.75974 .31527 L
s
gsave
.75974 .29652 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 .30902 m
.15368 .31277 L
s
.19697 .30902 m
.19697 .31277 L
s
.24026 .30902 m
.24026 .31277 L
s
.28355 .30902 m
.28355 .31277 L
s
.37013 .30902 m
.37013 .31277 L
s
.41342 .30902 m
.41342 .31277 L
s
.45671 .30902 m
.45671 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.58658 .30902 m
.58658 .31277 L
s
.62987 .30902 m
.62987 .31277 L
s
.67316 .30902 m
.67316 .31277 L
s
.71645 .30902 m
.71645 .31277 L
s
.80303 .30902 m
.80303 .31277 L
s
.84632 .30902 m
.84632 .31277 L
s
.88961 .30902 m
.88961 .31277 L
s
.9329 .30902 m
.9329 .31277 L
s
.0671 .30902 m
.0671 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09213 m
.11664 .09213 L
s
gsave
.09789 .09213 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .20057 m
.11664 .20057 L
s
gsave
.09789 .20057 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .41746 m
.11664 .41746 L
s
gsave
.09789 .41746 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .5259 m
.11664 .5259 L
s
gsave
.09789 .5259 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.11039 .11924 m
.11414 .11924 L
s
.11039 .14635 m
.11414 .14635 L
s
.11039 .17346 m
.11414 .17346 L
s
.11039 .22768 m
.11414 .22768 L
s
.11039 .2548 m
.11414 .2548 L
s
.11039 .28191 m
.11414 .28191 L
s
.11039 .33613 m
.11414 .33613 L
s
.11039 .36324 m
.11414 .36324 L
s
.11039 .39035 m
.11414 .39035 L
s
.11039 .44457 m
.11414 .44457 L
s
.11039 .47168 m
.11414 .47168 L
s
.11039 .49879 m
.11414 .49879 L
s
.11039 .06502 m
.11414 .06502 L
s
.11039 .03791 m
.11414 .03791 L
s
.11039 .0108 m
.11414 .0108 L
s
.11039 .55301 m
.11414 .55301 L
s
.11039 .58012 m
.11414 .58012 L
s
.11039 .60723 m
.11414 .60723 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -126.812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.812 moveto
(@) show
81.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.812 moveto
(D) show
93.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(14.2) show
141.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
147.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
159.000 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
163.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
172.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
190.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02691 .30902 L
.03029 .30902 L
.03347 .30902 L
.03652 .30902 L
.03978 .30902 L
.04291 .30902 L
.04623 .30902 L
.04944 .30902 L
.05252 .30902 L
.0558 .30902 L
.05743 .30902 L
.05896 .30902 L
.06052 .30902 L
.06128 .30902 L
.062 .30902 L
.0624 .30902 L
.06277 .30902 L
.06318 .30902 L
.06341 .30902 L
.06362 .30902 L
.0638 .30902 L
.06389 .30902 L
.06399 .30902 L
.06408 .30902 L
.06417 .30902 L
.06426 .30902 L
.06434 .30902 L
.06443 .30902 L
.06453 .30902 L
.06463 .30902 L
.06473 .30902 L
.06491 .30902 L
.06511 .30902 L
.0655 .30902 L
.06592 .30902 L
.06627 .30902 L
.06666 .30902 L
.06753 .30902 L
.06834 .30902 L
.06918 .30902 L
.06998 .30902 L
.07147 .30902 L
.07308 .30902 L
.07456 .30902 L
.07606 .30902 L
.07772 .30902 L
.07928 .30902 L
.08096 .30902 L
.08254 .30902 L
Mistroke
.08427 .30902 L
.08746 .30902 L
.08904 .30902 L
.09073 .30902 L
.09407 .30902 L
.09729 .30902 L
.10039 .30902 L
.10369 .30902 L
.10686 .30902 L
.10991 .30902 L
.11316 .30902 L
.11629 .30902 L
.11961 .30902 L
.12281 .30902 L
.12589 .30902 L
.12917 .30902 L
.13233 .30902 L
.13536 .30902 L
.13859 .30902 L
.1417 .30902 L
.14501 .30902 L
.14819 .30902 L
.15126 .30902 L
.15452 .30902 L
.15766 .30902 L
.16099 .30902 L
.1642 .30902 L
.1673 .30902 L
.17058 .30902 L
.17375 .30902 L
.17534 .30902 L
.1768 .30902 L
.1776 .30902 L
.17836 .30902 L
.17878 .30902 L
.17916 .30902 L
.17937 .30902 L
.17959 .30902 L
.1797 .30902 L
.17976 .30902 L
.17982 .30902 L
.17988 .30902 L
.17993 .30902 L
.18004 .30902 L
.18014 .30902 L
.18024 .30902 L
.18029 .30902 L
.18035 .30902 L
.18046 .30902 L
.18056 .30902 L
Mistroke
.18067 .30902 L
.18086 .30902 L
.18106 .30902 L
.18125 .30902 L
.18161 .30902 L
.18203 .30902 L
.18242 .30902 L
.18329 .30902 L
.18414 .30902 L
.18494 .30902 L
.18643 .30902 L
.18805 .30902 L
.18953 .30902 L
.19104 .30902 L
.1927 .30902 L
.1944 .30902 L
.19595 .30902 L
.19907 .30902 L
.20227 .30902 L
.20535 .30902 L
.20863 .30902 L
.21178 .30902 L
.21481 .30902 L
.21804 .30902 L
.22115 .30902 L
.22445 .30902 L
.22763 .30902 L
.23069 .30902 L
.2324 .30902 L
.23395 .30902 L
.23558 .30902 L
.23709 .30902 L
.23784 .30902 L
.23821 .30902 L
.23863 .30902 L
.23884 .30902 L
.23904 .30902 L
.23916 .30902 L
.23928 .30902 L
.23939 .30902 L
.23949 .30902 L
.2396 .30902 L
.2397 .30902 L
.23978 .30902 L
.23988 .30902 L
.23999 .30902 L
.24004 .30902 L
.2401 .30902 L
.2402 .30902 L
.2403 .30902 L
Mistroke
.24051 .30902 L
.2407 .30902 L
.24114 .30902 L
.24153 .30902 L
.24194 .30902 L
.24264 .30902 L
.24343 .30902 L
.24424 .30902 L
.24498 .30902 L
.24666 .30902 L
.24818 .30902 L
.24985 .30902 L
.25156 .30902 L
.25311 .30902 L
.25625 .30902 L
.25946 .30902 L
.26255 .30902 L
.26585 .30902 L
.26901 .30902 L
.27206 .30902 L
.2753 .30902 L
.27843 .30902 L
.28002 .30902 L
.28175 .30902 L
.28255 .30902 L
.28341 .30902 L
.28414 .30902 L
.28455 .30902 L
.28494 .30902 L
.28532 .30902 L
.28553 .30902 L
.28563 .30902 L
.28573 .30902 L
.28579 .30902 L
.28584 .30902 L
.28594 .30902 L
.28603 .30902 L
.28613 .30902 L
.28624 .30902 L
.28634 .30902 L
.28639 .30902 L
.28645 .30902 L
.28656 .30902 L
.28675 .30902 L
.28693 .30902 L
.28732 .30902 L
.28767 .30902 L
.28805 .30902 L
.28887 .30902 L
.28934 .30902 L
Mistroke
.28977 .30902 L
.29061 .30902 L
.29139 .30902 L
.2929 .30902 L
.29456 .30902 L
.2962 .30902 L
.29769 .30902 L
.30089 .30902 L
.30397 .30902 L
.30725 .30902 L
.3104 .30902 L
.31343 .30902 L
.31666 .30901 L
.31977 .30901 L
.32138 .30901 L
.3222 .30901 L
.32308 .30901 L
.32351 .30901 L
.32391 .30901 L
.32427 .30901 L
.32446 .30901 L
.32466 .30901 L
.32486 .30901 L
.32495 .30901 L
.32504 .30901 L
.32514 .30901 L
.32523 .30901 L
.32533 .30901 L
.32538 .30901 L
.32543 .30901 L
.32552 .30901 L
.3256 .30901 L
.32568 .30901 L
.32578 .30901 L
.32587 .30901 L
.32597 .30901 L
.32614 .30901 L
.32635 .30901 L
.32654 .30901 L
.3269 .30901 L
.3273 .30901 L
.32772 .30901 L
.32849 .30901 L
.3292 .30901 L
.3307 .30901 L
.33155 .30901 L
.33235 .30902 L
.33547 .30902 L
.33716 .30902 L
.33878 .30902 L
Mistroke
.34184 .30902 L
.34511 .30902 L
.34825 .30902 L
.35159 .30903 L
.35326 .30903 L
.3548 .30903 L
.35631 .30903 L
.35707 .30903 L
.3579 .30903 L
.35832 .30903 L
.35872 .30903 L
.35908 .30903 L
.35929 .30903 L
.35947 .30903 L
.35956 .30903 L
.35965 .30903 L
.35973 .30903 L
.35981 .30903 L
.35991 .30903 L
.36001 .30903 L
.3601 .30903 L
.36019 .30903 L
.36029 .30903 L
.36038 .30903 L
.36046 .30903 L
.36055 .30903 L
.36076 .30903 L
.36095 .30903 L
.36132 .30903 L
.36172 .30903 L
.36245 .30903 L
.3629 .30903 L
.36332 .30903 L
.36411 .30903 L
.3657 .30903 L
.36718 .30903 L
.36883 .30902 L
.37033 .30902 L
.37355 .30901 L
.37665 .30901 L
.37994 .309 L
.38312 .30899 L
.38617 .30898 L
.38774 .30898 L
.38862 .30898 L
.38901 .30898 L
.38942 .30897 L
.3898 .30897 L
.39022 .30897 L
.3904 .30897 L
Mistroke
.3906 .30897 L
.39078 .30897 L
.39095 .30897 L
.39106 .30897 L
.39111 .30897 L
.39117 .30897 L
.39127 .30897 L
.39136 .30897 L
.39142 .30897 L
.39147 .30897 L
.39158 .30897 L
.39163 .30897 L
.39169 .30897 L
.39181 .30897 L
.39191 .30897 L
.39201 .30897 L
.3922 .30897 L
.3924 .30897 L
.39262 .30897 L
.39301 .30897 L
.39337 .30897 L
.39421 .30898 L
.39502 .30898 L
.39589 .30898 L
.3975 .30899 L
.39919 .30899 L
.40225 .30901 L
.4055 .30904 L
.40864 .30907 L
.41196 .3091 L
.41363 .30911 L
.41517 .30913 L
.41667 .30913 L
.41743 .30914 L
.41785 .30914 L
.41826 .30914 L
.41865 .30914 L
.41907 .30914 L
.41926 .30914 L
.41946 .30914 L
.41965 .30914 L
.41982 .30914 L
.41992 .30914 L
.41998 .30914 L
.42003 .30914 L
.42014 .30914 L
.42023 .30914 L
.42029 .30914 L
.42035 .30914 L
.42045 .30914 L
Mistroke
.42051 .30914 L
.42056 .30914 L
.42068 .30914 L
.42087 .30914 L
.42107 .30914 L
.42129 .30914 L
.42149 .30914 L
.42187 .30914 L
.42228 .30914 L
.42312 .30914 L
.42389 .30913 L
.4246 .30913 L
.42624 .30911 L
.42774 .30909 L
.43095 .30903 L
.43404 .30895 L
.43733 .30886 L
.44049 .30878 L
.44208 .30875 L
.44353 .30872 L
.44434 .30871 L
.4451 .3087 L
.44551 .3087 L
.4459 .30869 L
.44612 .30869 L
.44632 .30869 L
.44644 .30869 L
.44656 .30869 L
.44667 .30869 L
.44677 .30869 L
.44688 .30869 L
.44697 .30869 L
.44706 .30869 L
.44715 .30869 L
.44726 .30869 L
.44731 .30869 L
.44736 .30869 L
.44747 .30869 L
.44756 .30869 L
.44774 .30869 L
.44794 .30869 L
.44829 .3087 L
.4487 .3087 L
.44914 .3087 L
.44995 .30871 L
.45078 .30873 L
.45153 .30875 L
.45321 .3088 L
.45476 .30886 L
.45643 .30894 L
Mistroke
.45972 .30914 L
.46289 .30935 L
.46594 .30955 L
.46763 .30964 L
.46918 .3097 L
.46995 .30972 L
.47035 .30973 L
.47078 .30974 L
.47116 .30975 L
.47137 .30975 L
.47157 .30975 L
.47166 .30975 L
.47176 .30975 L
.47184 .30975 L
.47192 .30975 L
.47202 .30975 L
.4721 .30975 L
.47221 .30975 L
.4723 .30975 L
.4724 .30975 L
.47249 .30975 L
.47259 .30975 L
.47269 .30975 L
.47291 .30975 L
.4731 .30975 L
.47348 .30974 L
.47384 .30974 L
.47464 .30972 L
.47509 .3097 L
.47551 .30968 L
.47716 .30959 L
.47866 .30946 L
.48188 .30911 L
.48497 .30867 L
.48827 .30817 L
.48991 .30795 L
.49144 .30777 L
.49292 .30763 L
.49374 .30757 L
.49449 .30753 L
.49488 .30752 L
.49509 .30751 L
.49529 .30751 L
.49546 .3075 L
.49555 .3075 L
.49564 .3075 L
.49574 .3075 L
.49584 .3075 L
.49594 .3075 L
.49603 .3075 L
Mistroke
.49613 .3075 L
.49619 .3075 L
.49625 .3075 L
.49635 .3075 L
.49645 .3075 L
.49663 .30751 L
.49684 .30751 L
.49705 .30752 L
.49728 .30752 L
.4977 .30754 L
.49812 .30757 L
.49851 .30759 L
.4994 .30768 L
.50018 .30777 L
.50101 .30789 L
.50404 .3085 L
.50726 .30938 L
.51037 .31033 L
.51194 .3108 L
.51367 .31124 L
.51446 .31142 L
.51531 .31158 L
.51611 .3117 L
.51684 .31179 L
.51724 .31183 L
.51766 .31186 L
.51788 .31187 L
.51809 .31187 L
.51821 .31188 L
.51831 .31188 L
.51837 .31188 L
.51844 .31188 L
.5185 .31188 L
.51855 .31188 L
.51866 .31188 L
.51871 .31188 L
.51877 .31188 L
.51886 .31188 L
.51896 .31188 L
.51906 .31188 L
.51914 .31188 L
.51934 .31187 L
.51955 .31186 L
.51974 .31185 L
.52017 .31181 L
.52056 .31177 L
.52097 .31172 L
.5217 .31159 L
.5225 .31142 L
.52337 .31118 L
Mistroke
.52492 .31064 L
.5266 .30991 L
.5299 .30814 L
.53308 .30631 L
.53469 .30548 L
.53614 .30484 L
.5369 .30457 L
.53772 .30432 L
.53817 .30421 L
.53858 .30413 L
.53898 .30407 L
.5392 .30404 L
.5394 .30402 L
.53959 .304 L
.53969 .304 L
.5398 .30399 L
.5399 .30399 L
.53999 .30398 L
.54007 .30398 L
.54016 .30398 L
.54026 .30398 L
.54036 .30398 L
.54045 .30398 L
.54055 .30398 L
.54066 .30399 L
.54077 .30399 L
.54097 .30401 L
.54116 .30403 L
.54137 .30405 L
.54174 .30411 L
.54211 .30418 L
.54244 .30426 L
.54322 .3045 L
.54395 .30479 L
.5456 .30568 L
.54722 .30684 L
.54871 .30811 L
.5519 .31126 L
.55496 .31426 L
.55667 .31565 L
.55822 .31661 L
.559 .31695 L
.55944 .3171 L
.55984 .3172 L
.56019 .31727 L
.56039 .3173 L
.56058 .31732 L
.56068 .31732 L
.56078 .31733 L
.56086 .31733 L
Mistroke
.56096 .31733 L
.56106 .31733 L
.56111 .31733 L
.56117 .31733 L
.56127 .31732 L
.56136 .31732 L
.56146 .31731 L
.56156 .3173 L
.56174 .31727 L
.56195 .31723 L
.56215 .31719 L
.56258 .31707 L
.56298 .31691 L
.56369 .31656 L
.56447 .31605 L
.56606 .31462 L
.56775 .31259 L
.57079 .30794 L
.57403 .30254 L
.57552 .30029 L
.57714 .29824 L
.57802 .29736 L
.57845 .29701 L
.57884 .29674 L
.57921 .29651 L
.57962 .29631 L
.57984 .29623 L
.58005 .29616 L
.58025 .29611 L
.58034 .29609 L
.58045 .29608 L
.58056 .29606 L
.58066 .29605 L
.58075 .29605 L
.58085 .29604 L
.58094 .29604 L
.58102 .29604 L
.58112 .29605 L
.58121 .29606 L
.58131 .29607 L
.58142 .29609 L
.58164 .29613 L
.58184 .29619 L
.58203 .29626 L
.5824 .29643 L
.58274 .29663 L
.5835 .29722 L
.58431 .29806 L
.58505 .29903 L
.58672 .30186 L
Mistroke
.58988 .30914 L
.59292 .31713 L
.59462 .32126 L
.59617 .32444 L
.59693 .32572 L
.59777 .32685 L
.59815 .32727 L
.59855 .32763 L
.5989 .32788 L
.59928 .32809 L
.59947 .32817 L
.59968 .32823 L
.59978 .32825 L
.59984 .32826 L
.59989 .32827 L
.6 .32828 L
.60009 .32828 L
.60018 .32828 L
.60028 .32827 L
.60036 .32827 L
.60045 .32825 L
.60054 .32823 L
.60065 .32821 L
.60083 .32814 L
.60105 .32805 L
.60128 .32792 L
.60171 .3276 L
.60212 .32719 L
.60251 .32672 L
.60336 .32541 L
.60416 .32383 L
.60565 .32001 L
.60874 .30937 L
.61204 .29652 L
.61367 .29072 L
.6152 .2863 L
.61596 .28458 L
.61668 .2833 L
.61707 .28274 L
.6175 .28226 L
.61769 .28209 L
.61789 .28194 L
.61806 .28184 L
.61816 .2818 L
.61825 .28176 L
.61835 .28173 L
.61844 .2817 L
.61854 .28169 L
.6186 .28168 L
.61865 .28168 L
Mistroke
.61875 .28168 L
.61885 .28168 L
.61895 .2817 L
.61901 .28171 L
.61906 .28172 L
.61925 .28179 L
.61935 .28184 L
.61945 .2819 L
.61981 .28217 L
.62002 .28238 L
.62022 .28261 L
.62066 .28325 L
.62148 .28485 L
.62233 .28708 L
.62313 .28969 L
.62463 .29576 L
.62772 .31184 L
.63102 .32995 L
.63266 .33748 L
.63346 .34047 L
.63419 .34271 L
.63456 .34364 L
.63495 .3445 L
.63529 .34511 L
.63567 .34564 L
.63587 .34587 L
.63607 .34603 L
.63627 .34616 L
.63638 .34622 L
.63649 .34625 L
.63658 .34627 L
.63666 .34628 L
.63676 .34628 L
.63686 .34627 L
.63696 .34625 L
.63706 .34621 L
.63715 .34617 L
.63725 .34612 L
.63744 .34598 L
.63764 .34578 L
.63801 .34529 L
.63845 .3445 L
.63884 .34359 L
.63971 .34094 L
.64054 .33765 L
.64213 .32926 L
.64361 .31957 L
.64676 .29569 L
.64979 .27438 L
.65134 .26639 L
Mistroke
.65176 .2647 L
.65221 .26319 L
.65263 .26203 L
.65301 .26121 L
.6532 .26088 L
.6534 .26059 L
.6536 .26037 L
.65378 .26022 L
.65387 .26016 L
.65397 .26012 L
.65407 .26009 L
.65412 .26008 L
.65417 .26008 L
.65428 .26008 L
.65433 .26009 L
.65439 .26011 L
.65449 .26015 L
.65459 .26021 L
.65469 .26028 L
.65479 .26036 L
.65499 .2606 L
.65517 .26087 L
.65537 .26121 L
.65607 .26297 L
.65647 .26433 L
.65683 .26579 L
.65765 .26984 L
.65912 .27959 L
.66232 .30878 L
.6654 .33981 L
.66695 .35332 L
.66778 .35928 L
.66867 .36451 L
.66909 .36646 L
.66952 .36817 L
.66989 .36933 L
.67011 .36987 L
.6703 .37028 L
.67048 .3706 L
.67068 .37086 L
.67079 .37097 L
.67089 .37104 L
.67099 .3711 L
.67109 .37113 L
.67118 .37114 L
.67127 .37114 L
.67136 .37111 L
.67144 .37107 L
.67153 .37101 L
.67164 .37092 L
Mistroke
.67183 .3707 L
.67203 .37037 L
.67225 .3699 L
.67266 .36877 L
.67305 .36734 L
.67341 .36572 L
.67423 .36102 L
.67509 .35458 L
.67667 .33938 L
.67815 .32211 L
.68128 .28148 L
.68287 .26235 L
.68371 .25359 L
.6846 .24568 L
.6854 .24005 L
.68582 .23766 L
.68627 .23557 L
.68648 .23478 L
.68668 .23413 L
.68688 .23361 L
.68706 .23322 L
.68723 .23294 L
.68733 .23281 L
.68742 .23272 L
.68751 .23265 L
.68762 .2326 L
.68772 .23258 L
.68781 .23259 L
.68791 .23262 L
.688 .23268 L
.68809 .23275 L
.68818 .23286 L
.68839 .23319 L
.68859 .23361 L
.68894 .23464 L
.68932 .23613 L
.69011 .24054 L
.69098 .24737 L
.69253 .26414 L
.6942 .2875 L
.6975 .34052 L
.69915 .36498 L
.69995 .37528 L
.70068 .38337 L
.70139 .3899 L
.70216 .39531 L
.70258 .39749 L
.70277 .39826 L
.70297 .39897 L
.70315 .39947 L
Mistroke
.70335 .3999 L
.70345 .40007 L
.70355 .4002 L
.70365 .4003 L
.70374 .40035 L
.70384 .40038 L
.7039 .40038 L
.70395 .40037 L
.70405 .40033 L
.70415 .40025 L
.70424 .40015 L
.70432 .40003 L
.70451 .39966 L
.70472 .3991 L
.70491 .39847 L
.70533 .39658 L
.7057 .39445 L
.70609 .39162 L
.70681 .38512 L
.7084 .36508 L
.71009 .33695 L
.71312 .2782 L
.71481 .24746 L
.71555 .23569 L
.71635 .22449 L
.71708 .21608 L
.71787 .20921 L
.7183 .20642 L
.71869 .20455 L
.71888 .20387 L
.71898 .20358 L
.71909 .20331 L
.71918 .20312 L
.71928 .20295 L
.71937 .20283 L
.71946 .20275 L
.71956 .2027 L
.71961 .20269 L
.71967 .2027 L
.71977 .20274 L
.71986 .20282 L
.71991 .20288 L
.71997 .20296 L
.72007 .20313 L
.7203 .20368 L
.72049 .20434 L
.72068 .2051 L
.72109 .20737 L
.72147 .21007 L
.72181 .21304 L
Mistroke
.72258 .22145 L
.72412 .24481 L
.72579 .27795 L
.72907 .3526 L
.7307 .38613 L
.7315 .39994 L
.73223 .4106 L
.73298 .41931 L
.73332 .42248 L
.73369 .42524 L
.73389 .4265 L
.73408 .42746 L
.73427 .42827 L
.73444 .42885 L
.73454 .42911 L
.73465 .42934 L
.73475 .42951 L
.73481 .42958 L
.73487 .42963 L
.73497 .42968 L
.73506 .42968 L
.73516 .42963 L
.73526 .42953 L
.73536 .42939 L
.73545 .42919 L
.73563 .42871 L
.73584 .42792 L
.73604 .42699 L
.73644 .42447 L
.73686 .42093 L
.73757 .41307 L
.73834 .40181 L
.73992 .37139 L
.7416 .33076 L
.7432 .28859 L
.74493 .24447 L
.74646 .21148 L
.74733 .19668 L
.74775 .19072 L
.74814 .18606 L
.74851 .18238 L
.74891 .1792 L
.74913 .17785 L
.74933 .17684 L
.74953 .1761 L
.74964 .17579 L
.74974 .17556 L
.74984 .17538 L
.7499 .17532 L
.74995 .17526 L
Mistroke
.75006 .17522 L
.75015 .17524 L
.75021 .17528 L
.75027 .17533 L
.75037 .17549 L
.75043 .1756 L
.75048 .17572 L
.75061 .17606 L
.7508 .17677 L
.751 .17779 L
.75143 .18065 L
.75184 .18449 L
.75224 .18905 L
.75298 .19995 L
.75466 .23432 L
.75772 .31968 L
.75943 .36922 L
.76098 .40829 L
.76176 .42425 L
.7626 .43808 L
.76298 .44309 L
.76339 .44741 L
.76374 .45028 L
.76394 .45156 L
.76412 .45253 L
.76432 .45333 L
.76443 .45364 L
.76448 .45377 L
.76454 .45389 L
.76464 .45404 L
.76473 .45413 L
.76478 .45415 L
.76484 .45415 L
.76494 .4541 L
.76503 .454 L
.76512 .45384 L
.76521 .45363 L
.7653 .45339 L
.7655 .45261 L
.76569 .45162 L
.7661 .4486 L
.76649 .44479 L
.76736 .43269 L
.76814 .41811 L
.76887 .40154 L
.77053 .35554 L
.77364 .25606 L
.77522 .21077 L
.77606 .19099 L
.77695 .17412 L
Mistroke
.7774 .16749 L
.77782 .16247 L
.7782 .15901 L
.77841 .1575 L
.77861 .15641 L
.77869 .156 L
.77879 .15563 L
.77887 .15537 L
.77896 .15513 L
.77907 .15494 L
.77917 .15483 L
.77926 .15479 L
.77935 .15481 L
.77945 .15491 L
.77953 .15505 L
.77963 .15528 L
.77974 .1556 L
.77995 .1565 L
.78014 .15762 L
.78052 .16061 L
.78093 .16498 L
.78166 .17575 L
.78253 .19313 L
.78332 .21273 L
.78654 .31627 L
.78801 .36666 L
.78963 .41537 L
.7904 .43427 L
.79122 .45054 L
.79168 .45754 L
.7921 .4626 L
.7923 .46456 L
.79252 .46635 L
.79272 .46771 L
.79291 .46865 L
.79301 .46904 L
.79312 .46935 L
.79317 .46947 L
.79322 .46958 L
.79329 .46967 L
.79334 .46973 L
.79339 .46976 L
.79345 .46976 L
.79355 .46971 L
.79365 .46958 L
.79374 .46939 L
.79383 .46914 L
.79392 .46885 L
.79411 .46796 L
.7943 .46682 L
Mistroke
.7945 .46528 L
.79495 .46067 L
.79538 .45484 L
.79618 .44026 L
.79695 .42227 L
.79777 .39929 L
.79925 .35055 L
.80085 .29223 L
.80258 .23136 L
.8034 .20619 L
.80426 .18332 L
.80499 .16748 L
.80538 .16069 L
.8058 .1546 L
.80602 .15197 L
.80622 .14989 L
.80641 .14824 L
.80662 .14677 L
.80681 .14576 L
.80689 .1454 L
.80698 .14508 L
.80708 .14482 L
.80717 .14465 L
.80726 .14454 L
.80737 .14451 L
.80742 .14453 L
.80748 .14459 L
.80754 .14466 L
.80759 .14475 L
.80768 .14499 L
.80779 .14533 L
.808 .14633 L
.80824 .14787 L
.80865 .15175 L
.80905 .15668 L
.80988 .17124 L
.81067 .18974 L
.81216 .23457 L
.81523 .3478 L
.81695 .40667 L
.81775 .42975 L
.8185 .44731 L
.81928 .46134 L
.81969 .46677 L
.81989 .469 L
.82012 .47097 L
.82032 .47234 L
.82049 .4733 L
.82058 .47366 L
.82067 .47398 L
Mistroke
.82076 .47421 L
.82085 .47436 L
.82094 .47446 L
.82103 .47448 L
.82113 .47442 L
.82123 .47426 L
.82134 .474 L
.82145 .47363 L
.82164 .47269 L
.82185 .47134 L
.82205 .46972 L
.82241 .4658 L
.8228 .46032 L
.82323 .45297 L
.82471 .41714 L
.8263 .36421 L
.82799 .30017 L
.82959 .24095 L
.83104 .19495 L
.83184 .17491 L
.8326 .16031 L
.83302 .15431 L
.83341 .15008 L
.83361 .1484 L
.83383 .14696 L
.83394 .1464 L
.83406 .14593 L
.83412 .14576 L
.83418 .1456 L
.83428 .14541 L
.83438 .14532 L
.83444 .14531 L
.83449 .14532 L
.83458 .14541 L
.83468 .14559 L
.83477 .14582 L
.83486 .14611 L
.83505 .14701 L
.83525 .14835 L
.83544 .1499 L
.83586 .15454 L
.83623 .15971 L
.83662 .1666 L
.83734 .18224 L
.83892 .22867 L
.8406 .29001 L
.84221 .35114 L
.84394 .40984 L
.84476 .43195 L
.8452 .44209 L
Mistroke
.84562 .45018 L
.846 .45642 L
.84635 .46101 L
.84674 .46485 L
.84696 .46638 L
.84705 .46695 L
.84716 .46746 L
.84726 .46784 L
.84735 .46812 L
.84744 .46831 L
.84753 .46844 L
.84763 .46849 L
.84772 .46846 L
.84782 .46833 L
.84788 .46821 L
.84793 .46808 L
.84804 .46774 L
.84814 .46734 L
.84836 .4661 L
.84855 .46465 L
.84876 .46275 L
.84912 .45847 L
.84946 .45344 L
.85024 .43849 L
.85107 .4174 L
.85187 .39341 L
.85335 .34114 L
.85643 .22962 L
.85724 .20521 L
.85801 .18604 L
.85843 .17725 L
.85889 .16936 L
.85931 .16371 L
.85951 .16153 L
.85969 .15986 L
.85987 .15848 L
.86007 .15732 L
.86018 .15684 L
.86028 .15648 L
.86038 .15623 L
.86048 .15605 L
.86056 .15597 L
.86066 .15596 L
.86074 .15602 L
.86083 .15614 L
.86092 .15636 L
.86102 .15668 L
.86121 .15752 L
.86143 .15889 L
.86162 .1605 L
Mistroke
.86207 .16536 L
.86248 .17136 L
.86287 .17827 L
.86448 .21841 L
.86596 .26737 L
.8676 .32688 L
.86913 .37942 L
.8706 .42014 L
.87102 .42929 L
.87142 .43673 L
.87181 .44271 L
.87218 .4472 L
.87254 .45058 L
.87274 .4519 L
.87284 .45245 L
.87295 .45295 L
.87306 .45333 L
.87316 .4536 L
.87322 .4537 L
.87327 .45378 L
.87333 .45384 L
.87338 .45386 L
.87348 .45384 L
.87357 .45375 L
.87367 .45356 L
.87377 .45326 L
.87387 .45293 L
.87395 .45256 L
.87414 .4515 L
.87448 .4488 L
.87488 .44442 L
.87525 .43905 L
.87602 .42467 L
.87684 .40485 L
.87832 .36028 L
.87993 .30502 L
.88166 .24724 L
.88248 .22376 L
.88334 .20303 L
.88407 .18933 L
.88449 .18337 L
.88488 .17907 L
.88509 .17728 L
.88528 .17595 L
.8855 .17485 L
.8856 .17444 L
.88566 .17426 L
.88572 .1741 L
.88582 .17391 L
.88592 .17381 L
Mistroke
.88602 .17378 L
.88608 .17381 L
.88613 .17386 L
.88623 .17402 L
.88632 .17423 L
.88642 .17455 L
.88652 .17494 L
.8867 .17588 L
.88689 .17717 L
.88723 .18024 L
.8876 .18459 L
.88801 .19059 L
.88882 .20626 L
.88957 .22424 L
.89125 .27386 L
.89291 .32805 L
.89444 .37455 L
.89521 .39418 L
.89593 .40954 L
.89668 .42183 L
.89708 .42666 L
.89729 .42869 L
.89752 .43049 L
.89772 .4318 L
.89791 .43269 L
.898 .43302 L
.8981 .4333 L
.8982 .43349 L
.89828 .4336 L
.89838 .43366 L
.89848 .43364 L
.89858 .43353 L
.89864 .43344 L
.89869 .43332 L
.8988 .43303 L
.89891 .43261 L
.89912 .43157 L
.89934 .43008 L
.89955 .4284 L
.9 .4235 L
.90081 .41099 L
.90162 .39445 L
.90236 .3762 L
.90403 .32803 L
.90567 .2785 L
.9072 .23793 L
.90796 .22189 L
.90867 .20989 L
.90907 .20474 L
.90928 .20246 L
Mistroke
.9095 .20039 L
.90968 .19894 L
.90989 .19763 L
.91007 .19671 L
.91025 .19609 L
.91034 .19585 L
.91044 .19567 L
.91054 .19557 L
.91063 .19554 L
.91073 .19558 L
.91079 .19564 L
.91084 .19571 L
.91094 .1959 L
.91104 .19618 L
.91114 .19652 L
.91124 .19697 L
.91143 .19799 L
.91166 .19956 L
.91187 .20131 L
.91263 .21032 L
.91335 .22231 L
.91495 .25814 L
.91643 .29829 L
.91794 .33997 L
.91957 .37837 L
.92047 .39413 L
.92086 .39953 L
.92129 .40432 L
.92149 .4061 L
.9217 .4077 L
.92188 .40884 L
.92208 .40982 L
.9222 .41027 L
.9223 .4106 L
.92241 .41084 L
.92246 .41093 L
.92252 .41101 L
.92262 .41109 L
.92272 .4111 L
.92282 .41104 L
.92291 .41093 L
.92302 .41072 L
.92311 .41047 L
.92329 .40981 L
.92349 .40885 L
.9237 .40752 L
.92408 .40436 L
.92444 .40063 L
.92524 .38925 L
.9261 .37351 L
Mistroke
.92914 .30015 L
.93084 .26044 L
.93164 .24497 L
.93239 .23341 L
.93275 .22884 L
.93315 .22471 L
.93356 .22155 L
.93378 .22026 L
.93399 .21933 L
.93417 .21873 L
.93427 .21852 L
.93437 .21835 L
.93446 .21825 L
.93455 .21821 L
.93464 .21822 L
.93472 .21827 L
.93482 .21839 L
.93491 .21856 L
.93502 .21881 L
.93512 .21915 L
.93531 .21989 L
.93551 .22094 L
.93593 .22391 L
.93632 .22769 L
.93707 .23709 L
.93787 .25017 L
.93874 .26722 L
.94046 .30528 L
.94201 .33949 L
.94279 .35462 L
.94363 .36848 L
.94401 .37379 L
.94442 .37859 L
.9448 .38224 L
.94515 .38498 L
.94534 .38616 L
.94555 .38721 L
.94574 .38795 L
.94591 .38845 L
.94601 .38865 L
.9461 .38879 L
.9462 .38889 L
.94626 .38891 L
.94631 .38892 L
.94641 .3889 L
.94646 .38886 L
.94651 .38881 L
.94662 .38866 L
.94668 .38855 L
.94673 .38843 L
Mistroke
.94692 .38788 L
.94709 .38719 L
.94749 .38502 L
.94783 .38241 L
.9482 .37897 L
.94896 .36984 L
.94977 .3574 L
.95124 .33015 L
.95283 .29822 L
.95367 .28226 L
.95456 .26713 L
.95543 .25499 L
.95622 .24677 L
.9566 .24386 L
.9568 .24261 L
.95701 .24152 L
.95719 .24075 L
.95729 .24041 L
.9574 .24011 L
.95749 .23988 L
.95758 .23971 L
.95767 .23958 L
.95775 .2395 L
.95784 .23945 L
.95794 .23944 L
.95804 .23948 L
.95812 .23956 L
.95822 .2397 L
.95833 .23991 L
.95853 .24045 L
.95874 .24122 L
.95896 .24228 L
.95936 .24478 L
.95976 .24803 L
.96013 .25172 L
.96084 .26013 L
.96393 .31106 L
.9655 .33721 L
.96633 .34886 L
.96679 .35431 L
.96722 .35877 L
.96763 .36229 L
.96808 .36531 L
.96827 .36636 L
.96848 .36729 L
.96866 .36792 L
.96886 .36845 L
.96896 .36865 L
.96906 .3688 L
.96914 .3689 L
Mistroke
.96924 .36897 L
.96934 .36899 L
.9694 .36899 L
.96945 .36897 L
.96955 .3689 L
.96965 .36878 L
.96974 .36864 L
.96983 .36845 L
.97 .36801 L
.97019 .36739 L
.97039 .36653 L
.97081 .36421 L
.9712 .36135 L
.97195 .3544 L
.97363 .33289 L
.97619 .29408 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{421.375, 260.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 525.688}, {324.5, 0}} -> {-2.58312*^-7, -6.34248*^6, \
6.65005*^-9, 53093.5}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0.309017 5.42214e-08 [
[.32684 .29652 -16.5 -12.5 ]
[.32684 .29652 16.5 0 ]
[.54329 .29652 -16.5 -12.5 ]
[.54329 .29652 16.5 0 ]
[.75974 .29652 -22.5 -12.5 ]
[.75974 .29652 22.5 0 ]
[.97619 .29652 -16.5 -12.5 ]
[.97619 .29652 16.5 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 64 6 ]
[.09789 .09213 -34.5 -6.25 ]
[.09789 .09213 0 6.25 ]
[.09789 .20057 -34.5 -6.25 ]
[.09789 .20057 0 6.25 ]
[.09789 .41746 -28.5 -6.25 ]
[.09789 .41746 0 6.25 ]
[.09789 .5259 -28.5 -6.25 ]
[.09789 .5259 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -65.8125 0 ]
[.5 .63053 65.8125 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 .30902 m
.32684 .31527 L
s
gsave
.32684 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 .30902 m
.54329 .31527 L
s
gsave
.54329 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 .30902 m
.75974 .31527 L
s
gsave
.75974 .29652 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 .30902 m
.15368 .31277 L
s
.19697 .30902 m
.19697 .31277 L
s
.24026 .30902 m
.24026 .31277 L
s
.28355 .30902 m
.28355 .31277 L
s
.37013 .30902 m
.37013 .31277 L
s
.41342 .30902 m
.41342 .31277 L
s
.45671 .30902 m
.45671 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.58658 .30902 m
.58658 .31277 L
s
.62987 .30902 m
.62987 .31277 L
s
.67316 .30902 m
.67316 .31277 L
s
.71645 .30902 m
.71645 .31277 L
s
.80303 .30902 m
.80303 .31277 L
s
.84632 .30902 m
.84632 .31277 L
s
.88961 .30902 m
.88961 .31277 L
s
.9329 .30902 m
.9329 .31277 L
s
.0671 .30902 m
.0671 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09213 m
.11664 .09213 L
s
gsave
.09789 .09213 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .20057 m
.11664 .20057 L
s
gsave
.09789 .20057 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .41746 m
.11664 .41746 L
s
gsave
.09789 .41746 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .5259 m
.11664 .5259 L
s
gsave
.09789 .5259 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.11039 .11924 m
.11414 .11924 L
s
.11039 .14635 m
.11414 .14635 L
s
.11039 .17346 m
.11414 .17346 L
s
.11039 .22768 m
.11414 .22768 L
s
.11039 .2548 m
.11414 .2548 L
s
.11039 .28191 m
.11414 .28191 L
s
.11039 .33613 m
.11414 .33613 L
s
.11039 .36324 m
.11414 .36324 L
s
.11039 .39035 m
.11414 .39035 L
s
.11039 .44457 m
.11414 .44457 L
s
.11039 .47168 m
.11414 .47168 L
s
.11039 .49879 m
.11414 .49879 L
s
.11039 .06502 m
.11414 .06502 L
s
.11039 .03791 m
.11414 .03791 L
s
.11039 .0108 m
.11414 .0108 L
s
.11039 .55301 m
.11414 .55301 L
s
.11039 .58012 m
.11414 .58012 L
s
.11039 .60723 m
.11414 .60723 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -126.812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.812 moveto
(@) show
81.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.812 moveto
(D) show
93.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(14.4) show
141.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
147.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
159.000 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
163.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
172.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
190.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02532 .30902 L
.02691 .30902 L
.03029 .30902 L
.03335 .30902 L
.0366 .30902 L
.03973 .30902 L
.04306 .30902 L
.04626 .30902 L
.04773 .30902 L
.04856 .30902 L
.04934 .30902 L
.05011 .30902 L
.05054 .30902 L
.05094 .30902 L
.05115 .30902 L
.05135 .30902 L
.05146 .30902 L
.05157 .30902 L
.05163 .30902 L
.05169 .30902 L
.05175 .30902 L
.0518 .30902 L
.0519 .30902 L
.05195 .30902 L
.05201 .30902 L
.05207 .30902 L
.05213 .30902 L
.05223 .30902 L
.05233 .30902 L
.05242 .30902 L
.05262 .30902 L
.05282 .30902 L
.053 .30902 L
.0534 .30902 L
.05375 .30902 L
.05412 .30902 L
.05491 .30902 L
.05536 .30902 L
.05578 .30902 L
.05662 .30902 L
.05742 .30902 L
.05891 .30902 L
.05969 .30902 L
.06052 .30902 L
.062 .30902 L
.06357 .30902 L
.06504 .30902 L
.06667 .30902 L
.06816 .30902 L
Mistroke
.06981 .30902 L
.07135 .30902 L
.07442 .30902 L
.07607 .30902 L
.07756 .30902 L
.07924 .30902 L
.08078 .30902 L
.08388 .30902 L
.08705 .30902 L
.09011 .30902 L
.09336 .30902 L
.09648 .30902 L
.09981 .30902 L
.10301 .30902 L
.10609 .30902 L
.10937 .30902 L
.11252 .30902 L
.11556 .30902 L
.11879 .30902 L
.1219 .30902 L
.12521 .30902 L
.12839 .30902 L
.13145 .30902 L
.13471 .30902 L
.13785 .30902 L
.14119 .30902 L
.1444 .30902 L
.14749 .30902 L
.15078 .30902 L
.15395 .30902 L
.15699 .30902 L
.16023 .30902 L
.16335 .30902 L
.16667 .30902 L
.16987 .30902 L
.17294 .30902 L
.1745 .30902 L
.17532 .30902 L
.17621 .30902 L
.17706 .30902 L
.17743 .30902 L
.17784 .30902 L
.17822 .30902 L
.17858 .30902 L
.17878 .30902 L
.17896 .30902 L
.17906 .30902 L
.17911 .30902 L
.17917 .30902 L
.17927 .30902 L
Mistroke
.17936 .30902 L
.17946 .30902 L
.17956 .30902 L
.17966 .30902 L
.17976 .30902 L
.17993 .30902 L
.18012 .30902 L
.18034 .30902 L
.18054 .30902 L
.18093 .30902 L
.1813 .30902 L
.18164 .30902 L
.1824 .30902 L
.18318 .30902 L
.18391 .30902 L
.18476 .30902 L
.18557 .30902 L
.18721 .30902 L
.1887 .30902 L
.1903 .30902 L
.19177 .30902 L
.19493 .30902 L
.19796 .30902 L
.20119 .30902 L
.2043 .30902 L
.2076 .30902 L
.21078 .30902 L
.21384 .30902 L
.2171 .30902 L
.22023 .30902 L
.22357 .30902 L
.22678 .30902 L
.22987 .30902 L
.23315 .30902 L
.23479 .30902 L
.23632 .30902 L
.23707 .30902 L
.23779 .30902 L
.23818 .30902 L
.23861 .30902 L
.239 .30902 L
.23917 .30902 L
.23936 .30902 L
.23946 .30902 L
.23957 .30902 L
.23968 .30902 L
.23977 .30902 L
.23982 .30902 L
.23988 .30902 L
.23994 .30902 L
Mistroke
.24 .30902 L
.24005 .30902 L
.24011 .30902 L
.24021 .30902 L
.24031 .30902 L
.24041 .30902 L
.2405 .30902 L
.24059 .30902 L
.24081 .30902 L
.24101 .30902 L
.24138 .30902 L
.24173 .30902 L
.2421 .30902 L
.24251 .30902 L
.24333 .30902 L
.24423 .30902 L
.24507 .30902 L
.24584 .30902 L
.24735 .30902 L
.24901 .30902 L
.25058 .30902 L
.25226 .30902 L
.25558 .30902 L
.25877 .30902 L
.26185 .30902 L
.26512 .30902 L
.26827 .30902 L
.2713 .30902 L
.27453 .30902 L
.27763 .30902 L
.28093 .30902 L
.28258 .30902 L
.28338 .30902 L
.28411 .30902 L
.28487 .30902 L
.28559 .30902 L
.28598 .30902 L
.28617 .30902 L
.28635 .30902 L
.28654 .30902 L
.28664 .30902 L
.28675 .30902 L
.2868 .30902 L
.28686 .30902 L
.28692 .30902 L
.28697 .30902 L
.28707 .30902 L
.28717 .30902 L
.28727 .30902 L
.28733 .30902 L
Mistroke
.28738 .30902 L
.28749 .30902 L
.2876 .30902 L
.28781 .30902 L
.288 .30902 L
.28846 .30902 L
.28889 .30902 L
.28967 .30902 L
.29051 .30902 L
.29127 .30902 L
.2921 .30902 L
.29379 .30902 L
.29534 .30902 L
.29702 .30902 L
.30032 .30902 L
.30351 .30902 L
.30657 .30902 L
.30983 .30902 L
.31296 .30902 L
.3163 .30902 L
.31951 .30902 L
.32098 .30901 L
.3226 .30901 L
.32337 .30901 L
.3242 .30901 L
.32466 .30901 L
.32507 .30901 L
.32549 .30901 L
.3257 .30901 L
.32589 .30901 L
.32607 .30901 L
.32626 .30901 L
.32636 .30901 L
.32642 .30901 L
.32647 .30901 L
.32656 .30901 L
.32666 .30901 L
.32671 .30901 L
.32677 .30901 L
.32687 .30901 L
.32697 .30901 L
.32706 .30901 L
.32716 .30901 L
.32727 .30901 L
.32749 .30901 L
.32768 .30901 L
.32785 .30901 L
.32825 .30901 L
.32861 .30901 L
.32896 .30901 L
Mistroke
.32973 .30901 L
.33055 .30901 L
.33203 .30901 L
.33286 .30902 L
.33375 .30902 L
.33537 .30902 L
.33866 .30902 L
.34183 .30902 L
.34488 .30902 L
.34812 .30902 L
.35125 .30902 L
.35457 .30903 L
.35623 .30903 L
.35777 .30903 L
.35854 .30903 L
.35926 .30903 L
.36001 .30903 L
.36041 .30903 L
.36062 .30903 L
.36084 .30903 L
.36105 .30903 L
.36124 .30903 L
.36133 .30903 L
.36143 .30903 L
.36153 .30903 L
.36161 .30903 L
.36171 .30903 L
.36181 .30903 L
.36191 .30903 L
.36197 .30903 L
.36202 .30903 L
.36213 .30903 L
.36224 .30903 L
.36245 .30903 L
.36268 .30903 L
.36288 .30903 L
.36333 .30903 L
.36375 .30903 L
.36415 .30903 L
.36493 .30903 L
.36576 .30903 L
.36725 .30903 L
.36883 .30902 L
.3703 .30902 L
.37343 .30902 L
.37675 .30901 L
.37995 .309 L
.38304 .309 L
.38631 .30899 L
.38794 .30898 L
Mistroke
.38947 .30898 L
.39022 .30898 L
.39093 .30898 L
.39132 .30898 L
.39175 .30898 L
.39214 .30898 L
.39251 .30898 L
.39272 .30898 L
.39291 .30898 L
.39301 .30898 L
.39307 .30898 L
.39313 .30898 L
.39318 .30898 L
.39324 .30898 L
.3933 .30898 L
.39335 .30898 L
.39345 .30898 L
.39355 .30898 L
.39364 .30898 L
.39374 .30898 L
.39384 .30898 L
.39395 .30898 L
.39415 .30898 L
.39453 .30898 L
.39493 .30898 L
.39527 .30898 L
.39564 .30898 L
.39647 .30898 L
.39722 .30898 L
.3989 .30899 L
.40044 .30899 L
.40211 .309 L
.40539 .30902 L
.40855 .30904 L
.41159 .30907 L
.41482 .3091 L
.41631 .30911 L
.41794 .30912 L
.41882 .30912 L
.41964 .30913 L
.42042 .30913 L
.42085 .30913 L
.42125 .30913 L
.42145 .30913 L
.42164 .30913 L
.42184 .30913 L
.42194 .30913 L
.42206 .30913 L
.42215 .30913 L
.42225 .30913 L
Mistroke
.42235 .30913 L
.42244 .30913 L
.42252 .30913 L
.42261 .30913 L
.42271 .30913 L
.4228 .30913 L
.423 .30913 L
.42322 .30913 L
.4234 .30913 L
.4236 .30913 L
.42405 .30913 L
.42447 .30913 L
.42531 .30913 L
.42611 .30912 L
.4276 .30911 L
.42921 .30909 L
.43069 .30907 L
.43386 .30901 L
.4369 .30894 L
.44014 .30886 L
.44326 .30879 L
.44485 .30876 L
.44569 .30875 L
.44658 .30874 L
.44702 .30873 L
.44745 .30873 L
.44786 .30873 L
.44823 .30873 L
.44859 .30872 L
.44877 .30872 L
.44897 .30872 L
.44908 .30872 L
.44917 .30872 L
.44922 .30872 L
.44928 .30872 L
.44939 .30872 L
.44948 .30872 L
.44959 .30872 L
.44967 .30872 L
.44977 .30872 L
.44987 .30872 L
.44997 .30872 L
.45019 .30872 L
.45038 .30872 L
.45058 .30873 L
.45097 .30873 L
.45133 .30873 L
.45219 .30874 L
.453 .30875 L
.45461 .30879 L
Mistroke
.4561 .30883 L
.45927 .30897 L
.46231 .30914 L
.46556 .30933 L
.46868 .30951 L
.47027 .30958 L
.47111 .30962 L
.472 .30965 L
.47279 .30967 L
.47324 .30967 L
.47366 .30968 L
.47385 .30968 L
.47405 .30968 L
.47422 .30969 L
.4744 .30969 L
.47451 .30969 L
.4746 .30969 L
.47465 .30969 L
.47471 .30969 L
.47481 .30969 L
.47491 .30969 L
.47501 .30969 L
.4751 .30969 L
.4752 .30969 L
.4753 .30969 L
.4754 .30969 L
.47562 .30968 L
.47581 .30968 L
.47601 .30968 L
.47641 .30967 L
.47676 .30966 L
.47762 .30964 L
.47844 .30961 L
.48005 .30952 L
.48153 .3094 L
.48471 .30908 L
.48776 .30868 L
.49101 .30825 L
.49413 .30788 L
.49495 .30781 L
.49584 .30774 L
.49668 .30769 L
.49706 .30767 L
.49746 .30766 L
.49766 .30765 L
.49786 .30765 L
.49805 .30764 L
.49823 .30764 L
.4984 .30764 L
.4985 .30764 L
Mistroke
.49858 .30764 L
.49867 .30764 L
.49878 .30764 L
.49887 .30764 L
.49896 .30764 L
.49906 .30764 L
.49916 .30764 L
.49925 .30764 L
.49934 .30764 L
.49956 .30764 L
.49976 .30765 L
.50017 .30766 L
.50061 .30768 L
.50137 .30773 L
.5022 .3078 L
.50307 .30789 L
.50388 .308 L
.50699 .30857 L
.51029 .3094 L
.51346 .31028 L
.51652 .31104 L
.51809 .31133 L
.51897 .31146 L
.51936 .31151 L
.51977 .31155 L
.52015 .31158 L
.52036 .31159 L
.52057 .31161 L
.52077 .31162 L
.52095 .31162 L
.52104 .31163 L
.52114 .31163 L
.52122 .31163 L
.52131 .31163 L
.52137 .31163 L
.52142 .31163 L
.52148 .31163 L
.52153 .31163 L
.52163 .31163 L
.52173 .31163 L
.52179 .31163 L
.52184 .31163 L
.52196 .31163 L
.52207 .31163 L
.52218 .31163 L
.52238 .31162 L
.52256 .31161 L
.52298 .31158 L
.52335 .31155 L
.52375 .3115 L
Mistroke
.52448 .3114 L
.52534 .31124 L
.52613 .31105 L
.52765 .31059 L
.52931 .30995 L
.53257 .3084 L
.53571 .30676 L
.53731 .30598 L
.53904 .30526 L
.53985 .30498 L
.54071 .30474 L
.54144 .30458 L
.54186 .30451 L
.54225 .30446 L
.54244 .30444 L
.54265 .30443 L
.54277 .30442 L
.54287 .30441 L
.54298 .30441 L
.54308 .30441 L
.54318 .3044 L
.54328 .3044 L
.54338 .3044 L
.54344 .3044 L
.54349 .3044 L
.54359 .3044 L
.54368 .30441 L
.54378 .30441 L
.54388 .30442 L
.54406 .30443 L
.54425 .30444 L
.54459 .30448 L
.54496 .30454 L
.54537 .30461 L
.54618 .30483 L
.54692 .30508 L
.5486 .30588 L
.55012 .30684 L
.55178 .30812 L
.55505 .31104 L
.55819 .31384 L
.55979 .31505 L
.56063 .31557 L
.56152 .31603 L
.56232 .31634 L
.56277 .31647 L
.56299 .31652 L
.5632 .31656 L
.56338 .31659 L
.56358 .31662 L
Mistroke
.56367 .31663 L
.56377 .31664 L
.56386 .31665 L
.56394 .31665 L
.56403 .31666 L
.56413 .31666 L
.56422 .31666 L
.56432 .31666 L
.56442 .31666 L
.56452 .31665 L
.56462 .31664 L
.56474 .31664 L
.56494 .31661 L
.56516 .31658 L
.56556 .31649 L
.56598 .31637 L
.56645 .31619 L
.56728 .31577 L
.56807 .31526 L
.56969 .31383 L
.57118 .31214 L
.57437 .30763 L
.57744 .30295 L
.57915 .30061 L
.5807 .29888 L
.58148 .2982 L
.58189 .2979 L
.58232 .29763 L
.5827 .29743 L
.58312 .29726 L
.5833 .2972 L
.5835 .29715 L
.58368 .29711 L
.58385 .29708 L
.58394 .29707 L
.58403 .29706 L
.58413 .29705 L
.58423 .29705 L
.58434 .29705 L
.58439 .29705 L
.58445 .29705 L
.58455 .29706 L
.58465 .29707 L
.58474 .29708 L
.58483 .29709 L
.585 .29713 L
.58518 .29717 L
.58538 .29723 L
.5858 .2974 L
.58625 .29765 L
Mistroke
.58705 .29825 L
.58781 .299 L
.58862 .30001 L
.59009 .30232 L
.59341 .30931 L
.5966 .317 L
.59806 .32025 L
.59968 .32331 L
.60044 .32448 L
.60126 .3255 L
.60171 .32595 L
.60213 .32629 L
.60253 .32654 L
.60273 .32664 L
.60295 .32673 L
.60315 .32679 L
.60326 .32681 L
.60337 .32683 L
.60346 .32684 L
.60356 .32685 L
.60361 .32685 L
.60367 .32685 L
.60377 .32685 L
.60386 .32684 L
.60397 .32683 L
.60407 .32681 L
.60416 .32679 L
.60433 .32674 L
.60452 .32667 L
.60473 .32656 L
.60497 .32642 L
.6054 .32609 L
.6062 .32523 L
.60696 .32411 L
.6078 .32255 L
.60949 .31845 L
.61273 .3079 L
.61586 .29667 L
.61745 .29158 L
.61829 .28926 L
.61918 .28716 L
.61997 .28566 L
.62039 .28502 L
.62084 .28446 L
.62125 .28406 L
.62143 .28393 L
.62163 .28381 L
.62182 .28372 L
.62199 .28366 L
.62209 .28363 L
Mistroke
.62218 .28362 L
.62228 .28361 L
.62238 .2836 L
.62247 .28361 L
.62257 .28362 L
.62266 .28364 L
.62275 .28366 L
.62285 .28369 L
.62296 .28373 L
.62316 .28383 L
.62336 .28397 L
.62359 .28416 L
.62398 .28458 L
.62476 .28577 L
.62546 .28723 L
.62701 .2917 L
.62868 .29823 L
.63198 .31447 L
.63362 .32298 L
.63515 .33034 L
.63672 .33669 L
.63749 .33919 L
.63821 .34106 L
.63858 .34186 L
.63899 .34259 L
.6394 .34315 L
.63963 .34339 L
.63984 .34356 L
.64003 .34367 L
.64012 .34372 L
.64022 .34375 L
.6403 .34377 L
.6404 .34379 L
.64048 .3438 L
.64056 .34379 L
.64066 .34378 L
.64075 .34376 L
.64085 .34373 L
.64096 .34368 L
.64114 .34358 L
.64133 .34342 L
.64153 .34321 L
.64175 .34294 L
.64215 .34231 L
.6429 .34065 L
.64377 .33795 L
.64458 .33475 L
.64607 .32723 L
.64773 .31695 L
.65095 .29408 L
Mistroke
.65243 .28397 L
.65405 .27443 L
.65483 .2707 L
.65566 .26745 L
.65612 .26601 L
.65654 .26494 L
.65696 .26412 L
.65716 .2638 L
.65735 .26356 L
.65753 .26339 L
.65762 .26331 L
.65772 .26325 L
.65778 .26322 L
.65783 .2632 L
.65794 .26316 L
.65803 .26315 L
.65813 .26314 L
.65819 .26315 L
.65824 .26316 L
.6583 .26317 L
.65836 .26319 L
.65846 .26324 L
.65857 .26331 L
.65877 .26348 L
.65896 .2637 L
.65933 .2643 L
.65967 .26503 L
.66044 .26732 L
.66123 .27062 L
.66197 .27449 L
.66364 .28577 L
.66679 .31379 L
.66982 .34191 L
.67138 .35379 L
.67218 .35871 L
.6726 .36092 L
.67305 .36296 L
.67349 .36459 L
.67389 .36577 L
.67408 .36624 L
.67429 .36666 L
.67448 .36698 L
.67466 .36721 L
.67476 .36731 L
.67487 .3674 L
.67493 .36743 L
.67498 .36746 L
.67504 .36749 L
.67509 .3675 L
.67515 .36751 L
Mistroke
.67521 .36752 L
.67527 .36751 L
.67533 .3675 L
.67543 .36747 L
.67549 .36744 L
.67554 .3674 L
.67573 .36724 L
.67584 .36711 L
.67594 .36697 L
.67616 .3666 L
.67636 .36617 L
.67676 .36505 L
.6772 .36346 L
.678 .35959 L
.67872 .355 L
.67949 .34911 L
.68252 .31763 L
.68576 .27829 L
.68724 .26205 L
.68887 .24796 L
.68929 .24509 L
.68975 .24245 L
.69014 .24056 L
.69056 .23891 L
.69079 .23822 L
.691 .23769 L
.6912 .23729 L
.6913 .23713 L
.69141 .23698 L
.69151 .23687 L
.6916 .2368 L
.69169 .23674 L
.69177 .23671 L
.69187 .2367 L
.69197 .23671 L
.69207 .23675 L
.69212 .23678 L
.69217 .23683 L
.69227 .23692 L
.69236 .23703 L
.69257 .23735 L
.69277 .23778 L
.69298 .23836 L
.69337 .23972 L
.69373 .2413 L
.69459 .2465 L
.6954 .2531 L
.69701 .27042 L
.69849 .29036 L
.70165 .33829 L
Mistroke
.70324 .36072 L
.70469 .37765 L
.70549 .38494 L
.70625 .39027 L
.70667 .39247 L
.70705 .39404 L
.70728 .39473 L
.70748 .39521 L
.70759 .39543 L
.70771 .39561 L
.70776 .39568 L
.70782 .39574 L
.70793 .39582 L
.70803 .39587 L
.70808 .39588 L
.70813 .39588 L
.70823 .39586 L
.70833 .3958 L
.70842 .39572 L
.7085 .39563 L
.70869 .39532 L
.7089 .39485 L
.70908 .3943 L
.70951 .39262 L
.70985 .39082 L
.71022 .38841 L
.71098 .38221 L
.71256 .36384 L
.71424 .33769 L
.71757 .27671 L
.71924 .24815 L
.71998 .23727 L
.72079 .22691 L
.72151 .21927 L
.72229 .21305 L
.72272 .21056 L
.72311 .20891 L
.7233 .20833 L
.7234 .20808 L
.7235 .20786 L
.72359 .20771 L
.7237 .20757 L
.72379 .20749 L
.72388 .20744 L
.72397 .20743 L
.72407 .20745 L
.72417 .20751 L
.72425 .20759 L
.72435 .20774 L
.72446 .20793 L
Mistroke
.72466 .20843 L
.72487 .20912 L
.7251 .21004 L
.72549 .21221 L
.7262 .21762 L
.72698 .2258 L
.72854 .24851 L
.73021 .28035 L
.73352 .35203 L
.73518 .38421 L
.73598 .39733 L
.73671 .40732 L
.73748 .41558 L
.73783 .41854 L
.7382 .42108 L
.73838 .42213 L
.73859 .42309 L
.73878 .4238 L
.73896 .4243 L
.73906 .42453 L
.73916 .4247 L
.73927 .42482 L
.73933 .42487 L
.73938 .4249 L
.73947 .42491 L
.73957 .42488 L
.73968 .4248 L
.73978 .42467 L
.73987 .4245 L
.73997 .42427 L
.74015 .42374 L
.74037 .42289 L
.74057 .42192 L
.74099 .41917 L
.7414 .41578 L
.74211 .40794 L
.74288 .39693 L
.74448 .36701 L
.74617 .32769 L
.74921 .25191 L
.7509 .21618 L
.75171 .20271 L
.75245 .19274 L
.75285 .18847 L
.75321 .18531 L
.75362 .18262 L
.75384 .18153 L
.75405 .18074 L
.75423 .18024 L
.75433 .18007 L
Mistroke
.75443 .17993 L
.75452 .17986 L
.75461 .17983 L
.7547 .17985 L
.75478 .1799 L
.75488 .18002 L
.75497 .18019 L
.75508 .18042 L
.75518 .18074 L
.75537 .18142 L
.75557 .18239 L
.75598 .18512 L
.75638 .18861 L
.75712 .19746 L
.75792 .21013 L
.7588 .22733 L
.76206 .31228 L
.7652 .39656 L
.76602 .41423 L
.76692 .42988 L
.76733 .43569 L
.76776 .4408 L
.76813 .44431 L
.76853 .4472 L
.76874 .44825 L
.76884 .4487 L
.76895 .44911 L
.76905 .44939 L
.76916 .44964 L
.76926 .44979 L
.76935 .44988 L
.76944 .44992 L
.76954 .4499 L
.76962 .44983 L
.76971 .44971 L
.76981 .44952 L
.76991 .44925 L
.7701 .44859 L
.77032 .44755 L
.77055 .44607 L
.77098 .44249 L
.77139 .43792 L
.77178 .43277 L
.77328 .40463 L
.77494 .3617 L
.77817 .26207 L
.77966 .21981 L
.78045 .20073 L
.78129 .18373 L
.78175 .17604 L
Mistroke
.78217 .1702 L
.7826 .16542 L
.78299 .1621 L
.78318 .16084 L
.78339 .15979 L
.78349 .1594 L
.78359 .15905 L
.78365 .15888 L
.78371 .15875 L
.78376 .15865 L
.78382 .15857 L
.78392 .15847 L
.78401 .15845 L
.78411 .15849 L
.78417 .15855 L
.78422 .15862 L
.78432 .1588 L
.7844 .15903 L
.7846 .15973 L
.7848 .16073 L
.78498 .16189 L
.78539 .16532 L
.78577 .16952 L
.78612 .17437 L
.78692 .18822 L
.78778 .20747 L
.79107 .30805 L
.79271 .36281 L
.79424 .40846 L
.79499 .42727 L
.7957 .44217 L
.7961 .44903 L
.79653 .45529 L
.79689 .45956 L
.79728 .46309 L
.7975 .46459 L
.7976 .46513 L
.79771 .46564 L
.7978 .46602 L
.7979 .46634 L
.79796 .46649 L
.79801 .4666 L
.79811 .46675 L
.79821 .46683 L
.7983 .46684 L
.79839 .46678 L
.7985 .46664 L
.79859 .46644 L
.79867 .4662 L
.79886 .46545 L
Mistroke
.79908 .46426 L
.79929 .46278 L
.79968 .45913 L
.80009 .45394 L
.80055 .44683 L
.80138 .43028 L
.80213 .4116 L
.80381 .35985 L
.80703 .24672 L
.8085 .20148 L
.80934 .18063 L
.81012 .16519 L
.81052 .15903 L
.81089 .15428 L
.8111 .15214 L
.81133 .15019 L
.81153 .14879 L
.81172 .14778 L
.81182 .14738 L
.81192 .14704 L
.81198 .14689 L
.81204 .14676 L
.81209 .14668 L
.81215 .14661 L
.81221 .14657 L
.81226 .14656 L
.81232 .14657 L
.81238 .14661 L
.81249 .14676 L
.81255 .14689 L
.8126 .14703 L
.81279 .1477 L
.81289 .14821 L
.81299 .14877 L
.81321 .15028 L
.81341 .15202 L
.81381 .15645 L
.81425 .16272 L
.81504 .17777 L
.81653 .21711 L
.81967 .32844 L
.82128 .38562 L
.82212 .4121 L
.82302 .43591 L
.82382 .45286 L
.82427 .46036 L
.82469 .46587 L
.82489 .46797 L
.82508 .46964 L
.82526 .4709 L
Mistroke
.82544 .47195 L
.82553 .47239 L
.82564 .47278 L
.82573 .47305 L
.82582 .47323 L
.82592 .47336 L
.82602 .47339 L
.82612 .47334 L
.82618 .47327 L
.82624 .47318 L
.82629 .47306 L
.82634 .47292 L
.82644 .4726 L
.82666 .47156 L
.82685 .47032 L
.82706 .4686 L
.82745 .46445 L
.82781 .45943 L
.82862 .44444 L
.82949 .42306 L
.83281 .30867 L
.83447 .24694 L
.83601 .19772 L
.83678 .17809 L
.8375 .16346 L
.83789 .15722 L
.83825 .15262 L
.83865 .14881 L
.83886 .14737 L
.83897 .14679 L
.83908 .14627 L
.83919 .1459 L
.83929 .14565 L
.83938 .14549 L
.83948 .1454 L
.83957 .14541 L
.83966 .14547 L
.83975 .14562 L
.83985 .14586 L
.83995 .14622 L
.84007 .14671 L
.84027 .14792 L
.84048 .14946 L
.84066 .15121 L
.84138 .16062 L
.84178 .1677 L
.84214 .1752 L
.84368 .21732 L
.84536 .27606 L
.84693 .33588 L
Mistroke
.84865 .3968 L
.84944 .42042 L
.85029 .44132 L
.8507 .44956 L
.85109 .45611 L
.85147 .46125 L
.85182 .46495 L
.852 .46639 L
.85219 .46763 L
.85229 .46817 L
.8524 .46863 L
.85249 .46893 L
.85259 .46918 L
.85265 .46927 L
.8527 .46933 L
.8528 .46939 L
.85291 .46934 L
.85297 .46927 L
.85302 .46918 L
.85311 .46896 L
.85321 .46864 L
.85332 .4682 L
.85342 .4677 L
.85361 .46647 L
.85379 .46501 L
.85413 .46149 L
.8545 .45658 L
.8549 .44995 L
.85573 .43215 L
.85648 .4119 L
.85817 .35583 L
.85984 .29283 L
.86139 .2374 L
.8629 .19292 L
.86365 .1761 L
.86408 .16858 L
.86449 .16286 L
.86488 .15864 L
.8651 .15686 L
.86531 .15561 L
.86548 .15485 L
.86558 .15454 L
.86567 .15433 L
.86577 .15419 L
.86586 .15414 L
.86596 .15417 L
.86606 .15428 L
.86616 .1545 L
.86626 .15479 L
.86637 .15523 L
Mistroke
.86647 .15574 L
.86666 .15689 L
.86686 .15848 L
.86732 .16342 L
.86774 .16952 L
.86852 .18462 L
.86925 .20269 L
.87091 .25479 L
.87403 .36721 L
.87484 .39327 L
.87573 .41764 L
.87657 .43585 L
.87694 .44224 L
.87735 .44786 L
.87754 .4501 L
.87775 .45211 L
.87794 .45363 L
.87812 .45477 L
.87829 .45558 L
.87838 .45592 L
.87846 .45616 L
.87856 .45636 L
.87866 .45648 L
.87876 .45651 L
.87884 .45647 L
.87894 .45635 L
.87904 .45612 L
.87914 .45583 L
.87923 .45548 L
.87944 .45435 L
.87965 .4529 L
.88005 .44895 L
.8805 .44306 L
.88133 .42788 L
.88208 .40993 L
.88376 .35867 L
.88544 .29994 L
.88698 .24783 L
.88849 .20606 L
.88925 .19034 L
.88967 .18336 L
.89008 .17809 L
.89047 .17425 L
.89069 .17266 L
.8908 .17205 L
.8909 .17157 L
.89099 .1712 L
.89107 .17093 L
.89116 .17069 L
.89126 .17052 L
Mistroke
.89135 .17044 L
.89145 .17043 L
.89155 .1705 L
.89165 .17066 L
.89175 .17091 L
.89187 .1713 L
.89207 .17229 L
.89227 .1736 L
.89246 .1751 L
.89288 .17958 L
.89333 .18585 L
.89409 .19992 L
.8949 .21925 L
.89637 .26249 L
.89796 .31519 L
.89969 .37018 L
.90049 .39208 L
.90135 .4114 L
.90208 .42403 L
.90249 .42946 L
.90269 .43162 L
.90288 .43333 L
.90308 .43482 L
.90326 .4359 L
.90346 .43678 L
.90357 .43713 L
.90367 .43737 L
.90377 .43752 L
.90382 .43757 L
.90388 .43759 L
.90397 .43757 L
.90407 .43747 L
.90412 .43738 L
.90418 .43727 L
.90428 .43701 L
.90438 .43663 L
.9045 .43611 L
.90469 .43499 L
.90487 .43371 L
.90527 .42995 L
.90564 .42538 L
.90598 .42017 L
.9076 .3858 L
.90908 .34348 L
.91072 .29228 L
.91225 .24788 L
.913 .22932 L
.91372 .21463 L
.91411 .20791 L
.91454 .20181 L
Mistroke
.91494 .19743 L
.9153 .19439 L
.91549 .19317 L
.91567 .19231 L
.91576 .19195 L
.91586 .19164 L
.91592 .19152 L
.91597 .1914 L
.91607 .19126 L
.91616 .1912 L
.91627 .19121 L
.91636 .19129 L
.91645 .19143 L
.91653 .19161 L
.91662 .19186 L
.9168 .19255 L
.91701 .19371 L
.91721 .19508 L
.91765 .1992 L
.91806 .20427 L
.91845 .21012 L
.92004 .24326 L
.92152 .28313 L
.92303 .32682 L
.92466 .36969 L
.92556 .38867 L
.92596 .39561 L
.92639 .40212 L
.92677 .40686 L
.92718 .41085 L
.9274 .41256 L
.92761 .41379 L
.9277 .41428 L
.92781 .41473 L
.92791 .41508 L
.92801 .41534 L
.9281 .41552 L
.9282 .41566 L
.92829 .41572 L
.9284 .41572 L
.92849 .41565 L
.92859 .4155 L
.92868 .4153 L
.92876 .41507 L
.92897 .41428 L
.92919 .41309 L
.9296 .41005 L
.93003 .40564 L
.93048 .39971 L
.93129 .38614 L
Mistroke
.93286 .35114 L
.93433 .31284 L
.93583 .27439 L
.93745 .23976 L
.93788 .23266 L
.93834 .22624 L
.93876 .22139 L
.93916 .21786 L
.93952 .21549 L
.93973 .21455 L
.93982 .21422 L
.93992 .21394 L
.94002 .21371 L
.94012 .21357 L
.94018 .2135 L
.94023 .21347 L
.94034 .21345 L
.94039 .21347 L
.94044 .21351 L
.94054 .21364 L
.9406 .21374 L
.94065 .21385 L
.94077 .21417 L
.94098 .21494 L
.94117 .21591 L
.9416 .21898 L
.94199 .22265 L
.9424 .22751 L
.94388 .25233 L
.94722 .32896 L
.94804 .3469 L
.9489 .36359 L
.9497 .37628 L
.95009 .38133 L
.95044 .38522 L
.95078 .3883 L
.95115 .39087 L
.95136 .39193 L
.95155 .3927 L
.95173 .39322 L
.95182 .39341 L
.95192 .39356 L
.95202 .39365 L
.95207 .39368 L
.95213 .39368 L
.95223 .39364 L
.95232 .39356 L
.95238 .39348 L
.95243 .39338 L
.95253 .39317 L
Mistroke
.95264 .39286 L
.95275 .39246 L
.95295 .39158 L
.95316 .39041 L
.95354 .38767 L
.9543 .37985 L
.95511 .36836 L
.95658 .34148 L
.95817 .308 L
.9599 .27322 L
.9607 .25968 L
.96155 .24806 L
.96197 .24363 L
.96236 .24024 L
.96271 .23788 L
.96291 .23684 L
.96309 .23607 L
.96328 .23545 L
.96339 .2352 L
.96349 .23501 L
.96358 .23489 L
.96366 .23482 L
.96376 .23479 L
.96386 .2348 L
.96396 .23487 L
.96401 .23494 L
.96406 .23501 L
.96416 .23519 L
.96426 .23541 L
.96447 .23607 L
.9647 .23707 L
.96512 .23962 L
.96557 .24333 L
.96639 .25234 L
.96811 .27906 L
.96973 .30919 L
.9712 .33577 L
.97204 .34881 L
.97282 .35891 L
.97359 .36647 L
.97402 .36956 L
.97442 .37161 L
.97464 .37241 L
.97483 .37295 L
.97494 .37315 L
.97505 .37332 L
.97511 .37338 L
.97517 .37342 L
.97523 .37344 L
.97529 .37345 L
Mistroke
.97539 .37343 L
.97548 .37337 L
.97558 .37325 L
.97564 .37316 L
.97569 .37307 L
.9759 .37254 L
.97611 .37183 L
.97619 .3715 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{421.375, 260.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 525.688}, {324.5, 0}} -> {-2.58312*^-7, -6.34248*^6, \
6.65005*^-9, 53093.5}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0.309017 5.42214e-08 [
[.32684 .29652 -16.5 -12.5 ]
[.32684 .29652 16.5 0 ]
[.54329 .29652 -16.5 -12.5 ]
[.54329 .29652 16.5 0 ]
[.75974 .29652 -22.5 -12.5 ]
[.75974 .29652 22.5 0 ]
[.97619 .29652 -16.5 -12.5 ]
[.97619 .29652 16.5 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 64 6 ]
[.09789 .09213 -34.5 -6.25 ]
[.09789 .09213 0 6.25 ]
[.09789 .20057 -34.5 -6.25 ]
[.09789 .20057 0 6.25 ]
[.09789 .41746 -28.5 -6.25 ]
[.09789 .41746 0 6.25 ]
[.09789 .5259 -28.5 -6.25 ]
[.09789 .5259 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -65.8125 0 ]
[.5 .63053 65.8125 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 .30902 m
.32684 .31527 L
s
gsave
.32684 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 .30902 m
.54329 .31527 L
s
gsave
.54329 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 .30902 m
.75974 .31527 L
s
gsave
.75974 .29652 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 .30902 m
.15368 .31277 L
s
.19697 .30902 m
.19697 .31277 L
s
.24026 .30902 m
.24026 .31277 L
s
.28355 .30902 m
.28355 .31277 L
s
.37013 .30902 m
.37013 .31277 L
s
.41342 .30902 m
.41342 .31277 L
s
.45671 .30902 m
.45671 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.58658 .30902 m
.58658 .31277 L
s
.62987 .30902 m
.62987 .31277 L
s
.67316 .30902 m
.67316 .31277 L
s
.71645 .30902 m
.71645 .31277 L
s
.80303 .30902 m
.80303 .31277 L
s
.84632 .30902 m
.84632 .31277 L
s
.88961 .30902 m
.88961 .31277 L
s
.9329 .30902 m
.9329 .31277 L
s
.0671 .30902 m
.0671 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09213 m
.11664 .09213 L
s
gsave
.09789 .09213 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .20057 m
.11664 .20057 L
s
gsave
.09789 .20057 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .41746 m
.11664 .41746 L
s
gsave
.09789 .41746 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .5259 m
.11664 .5259 L
s
gsave
.09789 .5259 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.11039 .11924 m
.11414 .11924 L
s
.11039 .14635 m
.11414 .14635 L
s
.11039 .17346 m
.11414 .17346 L
s
.11039 .22768 m
.11414 .22768 L
s
.11039 .2548 m
.11414 .2548 L
s
.11039 .28191 m
.11414 .28191 L
s
.11039 .33613 m
.11414 .33613 L
s
.11039 .36324 m
.11414 .36324 L
s
.11039 .39035 m
.11414 .39035 L
s
.11039 .44457 m
.11414 .44457 L
s
.11039 .47168 m
.11414 .47168 L
s
.11039 .49879 m
.11414 .49879 L
s
.11039 .06502 m
.11414 .06502 L
s
.11039 .03791 m
.11414 .03791 L
s
.11039 .0108 m
.11414 .0108 L
s
.11039 .55301 m
.11414 .55301 L
s
.11039 .58012 m
.11414 .58012 L
s
.11039 .60723 m
.11414 .60723 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -126.812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.812 moveto
(@) show
81.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.812 moveto
(D) show
93.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(14.6) show
141.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
147.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
159.000 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
163.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
172.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
190.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02691 .30902 L
.03029 .30902 L
.03347 .30902 L
.03652 .30902 L
.03978 .30902 L
.04291 .30902 L
.04462 .30902 L
.04623 .30902 L
.04932 .30902 L
.05091 .30902 L
.0526 .30902 L
.05563 .30902 L
.05719 .30902 L
.05887 .30902 L
.06045 .30902 L
.06218 .30902 L
.06536 .30902 L
.06694 .30902 L
.06863 .30902 L
.07023 .30902 L
.07196 .30902 L
.07518 .30902 L
.07847 .30902 L
.08164 .30902 L
.08469 .30902 L
.08793 .30902 L
.09106 .30902 L
.09438 .30902 L
.09757 .30902 L
.10065 .30902 L
.10392 .30902 L
.10708 .30902 L
.11011 .30902 L
.11333 .30902 L
.11644 .30902 L
.11974 .30902 L
.12292 .30902 L
.12598 .30902 L
.12924 .30902 L
.13237 .30902 L
.1357 .30902 L
.13891 .30902 L
.142 .30902 L
.14528 .30902 L
.14844 .30902 L
.15149 .30902 L
.15472 .30902 L
.15784 .30902 L
.16115 .30902 L
Mistroke
.16434 .30902 L
.16741 .30902 L
.17068 .30902 L
.17383 .30902 L
.17465 .30902 L
.17555 .30902 L
.17639 .30902 L
.17717 .30902 L
.17755 .30902 L
.17775 .30902 L
.17795 .30902 L
.17813 .30902 L
.17824 .30902 L
.17833 .30902 L
.17841 .30902 L
.1785 .30902 L
.1786 .30902 L
.17868 .30902 L
.17878 .30902 L
.17883 .30902 L
.17889 .30902 L
.17899 .30902 L
.1791 .30902 L
.1793 .30902 L
.17948 .30902 L
.17969 .30902 L
.17992 .30902 L
.18034 .30902 L
.18074 .30902 L
.1811 .30902 L
.18194 .30902 L
.18276 .30902 L
.18363 .30902 L
.18533 .30902 L
.18695 .30902 L
.18854 .30902 L
.19002 .30902 L
.19165 .30902 L
.19317 .30902 L
.1962 .30902 L
.1993 .30902 L
.2026 .30902 L
.20578 .30902 L
.20884 .30902 L
.21209 .30902 L
.21522 .30902 L
.21855 .30902 L
.22175 .30902 L
.22484 .30902 L
.22812 .30902 L
Mistroke
.23128 .30902 L
.23432 .30902 L
.23601 .30902 L
.23756 .30902 L
.23832 .30902 L
.23875 .30902 L
.23915 .30902 L
.23935 .30902 L
.23954 .30902 L
.23971 .30902 L
.23989 .30902 L
.23998 .30902 L
.24008 .30902 L
.24018 .30902 L
.24026 .30902 L
.24037 .30902 L
.24046 .30902 L
.24051 .30902 L
.24057 .30902 L
.24067 .30902 L
.24077 .30902 L
.24086 .30902 L
.24106 .30902 L
.24124 .30902 L
.24142 .30902 L
.24182 .30902 L
.24226 .30902 L
.24268 .30902 L
.24313 .30902 L
.24394 .30902 L
.24477 .30902 L
.24566 .30902 L
.24728 .30902 L
.24887 .30902 L
.25056 .30902 L
.25361 .30902 L
.25685 .30902 L
.25996 .30902 L
.26328 .30902 L
.26647 .30902 L
.26954 .30902 L
.27281 .30902 L
.27596 .30902 L
.2793 .30902 L
.28098 .30902 L
.28252 .30902 L
.28413 .30902 L
.28491 .30902 L
.28562 .30902 L
.28636 .30902 L
Mistroke
.28676 .30902 L
.28714 .30902 L
.28734 .30902 L
.28744 .30902 L
.28755 .30902 L
.28765 .30902 L
.28775 .30902 L
.28785 .30902 L
.28793 .30902 L
.28799 .30902 L
.28804 .30902 L
.28815 .30902 L
.28821 .30902 L
.28827 .30902 L
.28838 .30902 L
.28858 .30902 L
.2888 .30902 L
.28919 .30902 L
.28956 .30902 L
.28996 .30902 L
.2904 .30902 L
.29128 .30902 L
.29209 .30902 L
.29362 .30902 L
.29529 .30902 L
.29687 .30902 L
.29856 .30902 L
.30159 .30902 L
.30481 .30902 L
.30792 .30902 L
.31122 .30902 L
.3144 .30902 L
.31746 .30902 L
.32071 .30902 L
.32221 .30902 L
.32384 .30901 L
.32474 .30901 L
.32556 .30901 L
.32634 .30901 L
.32674 .30901 L
.32695 .30901 L
.32717 .30901 L
.32739 .30901 L
.3275 .30901 L
.32759 .30901 L
.32769 .30901 L
.32778 .30901 L
.32788 .30901 L
.32794 .30901 L
.32799 .30901 L
Mistroke
.32808 .30901 L
.32816 .30901 L
.32825 .30901 L
.32835 .30901 L
.32845 .30901 L
.32855 .30901 L
.32873 .30901 L
.32894 .30901 L
.32915 .30901 L
.32954 .30901 L
.32995 .30901 L
.33041 .30901 L
.33122 .30901 L
.33197 .30901 L
.33364 .30902 L
.33516 .30902 L
.33683 .30902 L
.34008 .30902 L
.34322 .30902 L
.34656 .30902 L
.34977 .30902 L
.35286 .30902 L
.35615 .30902 L
.35778 .30903 L
.35931 .30903 L
.36007 .30903 L
.36078 .30903 L
.36118 .30903 L
.3616 .30903 L
.36197 .30903 L
.36217 .30903 L
.36236 .30903 L
.36255 .30903 L
.36274 .30903 L
.36292 .30903 L
.36302 .30903 L
.36311 .30903 L
.36316 .30903 L
.36322 .30903 L
.36332 .30903 L
.36342 .30903 L
.36351 .30903 L
.36361 .30903 L
.36367 .30903 L
.36372 .30903 L
.36383 .30903 L
.36394 .30903 L
.36416 .30903 L
.36437 .30903 L
.36475 .30903 L
Mistroke
.36521 .30903 L
.36563 .30903 L
.36648 .30903 L
.36727 .30903 L
.36877 .30903 L
.37038 .30902 L
.37186 .30902 L
.37503 .30902 L
.37808 .30901 L
.38133 .30901 L
.38445 .309 L
.38777 .30899 L
.38943 .30899 L
.39097 .30899 L
.39246 .30898 L
.39322 .30898 L
.39365 .30898 L
.39405 .30898 L
.39442 .30898 L
.39464 .30898 L
.39473 .30898 L
.39484 .30898 L
.39489 .30898 L
.39495 .30898 L
.39505 .30898 L
.39514 .30898 L
.39524 .30898 L
.39534 .30898 L
.39544 .30898 L
.3955 .30898 L
.39555 .30898 L
.39567 .30898 L
.39586 .30898 L
.39603 .30898 L
.39643 .30898 L
.39678 .30898 L
.39715 .30898 L
.39798 .30898 L
.39888 .30898 L
.39972 .30899 L
.4005 .30899 L
.40201 .30899 L
.40367 .309 L
.40692 .30902 L
.41005 .30904 L
.41337 .30906 L
.41658 .30909 L
.41966 .30911 L
.42125 .30911 L
.42205 .30912 L
Mistroke
.4225 .30912 L
.42294 .30912 L
.42332 .30912 L
.42353 .30912 L
.42375 .30912 L
.42395 .30912 L
.42413 .30912 L
.42422 .30912 L
.42432 .30912 L
.42441 .30912 L
.42449 .30912 L
.42459 .30912 L
.42469 .30912 L
.42479 .30912 L
.42488 .30912 L
.42498 .30912 L
.4251 .30912 L
.42531 .30912 L
.42552 .30912 L
.42575 .30912 L
.42617 .30912 L
.42656 .30912 L
.42692 .30912 L
.42773 .30911 L
.42844 .30911 L
.4292 .3091 L
.43078 .30909 L
.43225 .30907 L
.43538 .30903 L
.43871 .30896 L
.44192 .30889 L
.44501 .30882 L
.44657 .3088 L
.4474 .30878 L
.44829 .30877 L
.44914 .30876 L
.44992 .30876 L
.4503 .30875 L
.45071 .30875 L
.45089 .30875 L
.45109 .30875 L
.45128 .30875 L
.45136 .30875 L
.45145 .30875 L
.45155 .30875 L
.45164 .30875 L
.45169 .30875 L
.45174 .30875 L
.45184 .30875 L
.45194 .30875 L
Mistroke
.45204 .30875 L
.45214 .30875 L
.45226 .30875 L
.45244 .30875 L
.45261 .30875 L
.453 .30875 L
.4532 .30875 L
.45342 .30875 L
.4538 .30876 L
.45467 .30877 L
.45543 .30878 L
.45625 .30879 L
.45773 .30883 L
.45944 .30888 L
.46106 .30894 L
.46415 .30909 L
.46744 .30927 L
.4706 .30944 L
.47219 .30951 L
.47365 .30956 L
.47439 .30958 L
.47521 .3096 L
.47566 .30961 L
.47607 .30962 L
.47647 .30962 L
.47669 .30962 L
.47679 .30963 L
.47689 .30963 L
.47699 .30963 L
.47707 .30963 L
.47717 .30963 L
.47723 .30963 L
.47728 .30963 L
.47738 .30963 L
.47748 .30963 L
.47758 .30963 L
.47764 .30963 L
.47769 .30963 L
.47788 .30963 L
.47798 .30962 L
.47808 .30962 L
.47844 .30962 L
.47865 .30962 L
.47885 .30962 L
.47929 .30961 L
.48011 .30959 L
.48096 .30956 L
.48176 .30952 L
.48325 .30943 L
.48486 .30931 L
Mistroke
.48634 .30918 L
.48951 .30883 L
.49256 .30845 L
.49426 .30825 L
.4958 .30808 L
.49743 .30793 L
.49893 .30783 L
.49967 .3078 L
.50005 .30778 L
.50026 .30778 L
.50046 .30777 L
.50066 .30777 L
.50087 .30776 L
.50109 .30776 L
.50121 .30776 L
.50126 .30776 L
.50132 .30776 L
.50142 .30776 L
.50152 .30776 L
.50162 .30776 L
.50171 .30776 L
.50181 .30776 L
.50191 .30776 L
.50202 .30776 L
.50213 .30776 L
.50233 .30776 L
.50253 .30777 L
.50296 .30778 L
.50334 .3078 L
.50375 .30782 L
.50453 .30787 L
.50524 .30793 L
.50679 .3081 L
.50846 .30836 L
.51176 .30903 L
.51493 .30982 L
.51798 .31056 L
.51968 .31092 L
.52123 .31117 L
.522 .31127 L
.52241 .31131 L
.52284 .31134 L
.52321 .31137 L
.52341 .31138 L
.52363 .31139 L
.52382 .3114 L
.524 .3114 L
.52409 .31141 L
.52418 .31141 L
.52426 .31141 L
Mistroke
.52436 .31141 L
.52446 .31141 L
.52451 .31141 L
.52457 .31141 L
.52467 .31141 L
.52476 .31141 L
.52482 .31141 L
.52487 .31141 L
.52498 .3114 L
.5252 .3114 L
.5254 .31139 L
.52559 .31138 L
.526 .31135 L
.52635 .31133 L
.52673 .31129 L
.52749 .31118 L
.5283 .31104 L
.52905 .31088 L
.53072 .31042 L
.5339 .30921 L
.53695 .30779 L
.54021 .30629 L
.54171 .3057 L
.54334 .3052 L
.54423 .305 L
.54462 .30493 L
.54505 .30487 L
.54524 .30485 L
.54545 .30483 L
.54563 .30482 L
.54583 .3048 L
.54595 .3048 L
.54606 .30479 L
.54616 .30479 L
.54621 .30479 L
.54627 .30479 L
.54637 .30479 L
.54642 .30479 L
.54647 .30479 L
.54657 .30479 L
.54666 .30479 L
.54676 .30479 L
.54687 .30479 L
.54706 .3048 L
.54725 .30482 L
.54743 .30483 L
.54782 .30488 L
.54824 .30494 L
.54894 .30509 L
.54971 .3053 L
Mistroke
.55127 .30592 L
.55294 .30683 L
.55624 .30923 L
.55943 .31191 L
.56249 .31424 L
.56406 .31516 L
.56494 .31555 L
.56574 .31581 L
.56613 .3159 L
.56635 .31594 L
.56655 .31598 L
.56673 .316 L
.5669 .31602 L
.56699 .31603 L
.56708 .31603 L
.56719 .31604 L
.56728 .31604 L
.56734 .31604 L
.5674 .31604 L
.56745 .31604 L
.5675 .31604 L
.5676 .31604 L
.5677 .31604 L
.56776 .31604 L
.56781 .31603 L
.56792 .31603 L
.56815 .316 L
.56837 .31598 L
.56857 .31594 L
.56895 .31586 L
.56932 .31575 L
.56973 .3156 L
.57056 .31522 L
.57132 .31476 L
.57204 .31424 L
.57515 .31107 L
.57845 .30663 L
.58164 .30228 L
.58325 .30043 L
.5847 .29913 L
.58552 .2986 L
.58589 .29841 L
.58628 .29824 L
.58648 .29817 L
.5867 .2981 L
.58691 .29806 L
.58709 .29802 L
.5872 .29801 L
.58731 .29799 L
.58737 .29799 L
Mistroke
.58743 .29798 L
.58748 .29798 L
.58754 .29798 L
.58765 .29797 L
.58774 .29798 L
.5878 .29798 L
.58785 .29798 L
.58791 .29798 L
.58797 .29799 L
.58806 .298 L
.58817 .29801 L
.58837 .29804 L
.58856 .29809 L
.58873 .29813 L
.58913 .29828 L
.58955 .29848 L
.59025 .29893 L
.59102 .2996 L
.59258 .30145 L
.59426 .30413 L
.59757 .3109 L
.60076 .31789 L
.60237 .32097 L
.60383 .32322 L
.60465 .32418 L
.60541 .32486 L
.60583 .32514 L
.60622 .32533 L
.60642 .32541 L
.60665 .32547 L
.60676 .32549 L
.60682 .3255 L
.60688 .32551 L
.60693 .32552 L
.60699 .32552 L
.6071 .32553 L
.60719 .32553 L
.60728 .32553 L
.60738 .32552 L
.60749 .32551 L
.60758 .32549 L
.60766 .32548 L
.60785 .32542 L
.60806 .32535 L
.60825 .32526 L
.60869 .325 L
.6091 .32467 L
.60955 .32422 L
.61037 .32317 L
.61197 .32026 L
Mistroke
.61366 .31609 L
.6167 .30662 L
.61994 .29599 L
.62144 .29177 L
.62306 .28818 L
.62349 .28745 L
.62395 .28679 L
.62437 .28629 L
.62477 .28591 L
.62513 .28565 L
.62534 .28554 L
.62553 .28547 L
.62563 .28544 L
.62573 .28542 L
.62583 .2854 L
.62589 .2854 L
.62594 .2854 L
.626 .28539 L
.62605 .28539 L
.62611 .2854 L
.62617 .2854 L
.62627 .28542 L
.62633 .28543 L
.62638 .28544 L
.62648 .28547 L
.62659 .28551 L
.62678 .2856 L
.62701 .28574 L
.62721 .2859 L
.62762 .2863 L
.628 .28678 L
.62872 .28795 L
.62949 .28962 L
.63109 .29428 L
.63278 .30075 L
.63583 .31486 L
.63753 .32297 L
.63908 .32975 L
.63986 .33279 L
.6407 .33562 L
.64147 .33781 L
.6422 .33943 L
.64258 .34011 L
.64293 .34061 L
.64331 .34104 L
.64352 .3412 L
.64363 .34128 L
.64373 .34134 L
.64383 .34138 L
.64393 .34142 L
Mistroke
.64399 .34144 L
.64404 .34145 L
.64414 .34147 L
.64423 .34148 L
.64433 .34147 L
.64443 .34146 L
.64453 .34144 L
.64458 .34142 L
.64464 .3414 L
.64475 .34136 L
.64495 .34124 L
.64518 .34105 L
.6454 .34082 L
.64581 .34027 L
.64625 .33948 L
.64705 .33754 L
.64783 .33506 L
.64854 .33228 L
.65172 .31523 L
.65477 .29505 L
.65647 .28434 L
.65802 .27604 L
.65879 .27268 L
.65963 .26972 L
.66001 .26864 L
.66042 .26768 L
.66076 .26703 L
.66115 .2665 L
.66134 .26631 L
.66154 .26615 L
.66165 .2661 L
.6617 .26607 L
.66176 .26606 L
.66186 .26603 L
.66196 .26602 L
.66205 .26603 L
.66214 .26604 L
.66223 .26607 L
.66232 .2661 L
.66241 .26616 L
.66252 .26623 L
.6627 .26639 L
.66292 .26665 L
.66315 .267 L
.66358 .26783 L
.66399 .2689 L
.66438 .2701 L
.66587 .27666 L
.66673 .28166 L
.66753 .28708 L
Mistroke
.67063 .3127 L
.67221 .32677 L
.67393 .34118 L
.67559 .3527 L
.67632 .35667 L
.67711 .36009 L
.67753 .36151 L
.67792 .36256 L
.67829 .36331 L
.67847 .36359 L
.67868 .36383 L
.67879 .36393 L
.6789 .364 L
.67899 .36404 L
.6791 .36407 L
.67916 .36408 L
.67921 .36408 L
.67927 .36408 L
.67933 .36407 L
.67944 .36403 L
.67949 .364 L
.67955 .36397 L
.67974 .36381 L
.67984 .36369 L
.67994 .36356 L
.68016 .36321 L
.68036 .3628 L
.68076 .36176 L
.6812 .36027 L
.682 .35666 L
.68272 .35239 L
.68349 .34689 L
.68652 .31754 L
.68975 .28068 L
.69123 .26536 L
.69207 .25787 L
.69285 .25191 L
.69363 .24711 L
.69403 .24513 L
.69446 .24337 L
.6947 .24258 L
.69492 .24197 L
.69513 .2415 L
.69535 .2411 L
.69545 .24096 L
.69555 .24084 L
.69565 .24076 L
.69574 .2407 L
.69585 .24065 L
.6959 .24064 L
Mistroke
.69596 .24063 L
.69605 .24064 L
.69616 .24068 L
.69626 .24074 L
.69632 .24078 L
.69637 .24083 L
.69659 .24111 L
.69678 .24145 L
.69699 .24192 L
.69746 .24337 L
.69788 .24517 L
.69871 .24995 L
.6995 .25595 L
.70111 .27212 L
.70259 .29079 L
.70574 .33585 L
.70733 .35709 L
.70878 .37329 L
.70952 .37992 L
.71034 .38558 L
.71078 .38793 L
.711 .38887 L
.7112 .3896 L
.71139 .3902 L
.71159 .39072 L
.7117 .39096 L
.71181 .39114 L
.71191 .39129 L
.71201 .3914 L
.71211 .39147 L
.71221 .39153 L
.7123 .39154 L
.71239 .39154 L
.71248 .3915 L
.71258 .39143 L
.71264 .39139 L
.71269 .39133 L
.71279 .39119 L
.71298 .39086 L
.71317 .3904 L
.71352 .38927 L
.71393 .38746 L
.71431 .3853 L
.71518 .37877 L
.71603 .37035 L
.71682 .3607 L
.71831 .33896 L
.7214 .28579 L
.72296 .25951 L
.72379 .24699 L
Mistroke
.72468 .23518 L
.72554 .22582 L
.72632 .21922 L
.72669 .21676 L
.7271 .21465 L
.72729 .21389 L
.72749 .21322 L
.72768 .21272 L
.72785 .21238 L
.72794 .21224 L
.72803 .21214 L
.72813 .21207 L
.72824 .21203 L
.72829 .21203 L
.72835 .21204 L
.72846 .21209 L
.72856 .21218 L
.72865 .2123 L
.72882 .2126 L
.72901 .21307 L
.72921 .2137 L
.72939 .21443 L
.72981 .21658 L
.7302 .21914 L
.73107 .2269 L
.73185 .23625 L
.73259 .2467 L
.73425 .2756 L
.73739 .34001 L
.73899 .37121 L
.73983 .38557 L
.74072 .39856 L
.74152 .40787 L
.74194 .41183 L
.74239 .41526 L
.74261 .41658 L
.74281 .41764 L
.74301 .41851 L
.74319 .41915 L
.74336 .41962 L
.74345 .41981 L
.74355 .41998 L
.74364 .4201 L
.74375 .42019 L
.74384 .42022 L
.74393 .42021 L
.74404 .42016 L
.74413 .42007 L
.74422 .41995 L
.74431 .41978 L
Mistroke
.74453 .41924 L
.74472 .41857 L
.74507 .41689 L
.74545 .41448 L
.74624 .40735 L
.74711 .39641 L
.74867 .36972 L
.75035 .33337 L
.75366 .25458 L
.75531 .22091 L
.75611 .20772 L
.75684 .19805 L
.75721 .1941 L
.75761 .19055 L
.75798 .18792 L
.75833 .18614 L
.75852 .18542 L
.7587 .18493 L
.7588 .18472 L
.75889 .18458 L
.75894 .18452 L
.759 .18447 L
.7591 .18442 L
.7592 .18443 L
.75925 .18446 L
.7593 .1845 L
.75941 .18463 L
.75947 .18473 L
.75952 .18483 L
.75971 .18533 L
.75991 .18607 L
.76012 .18706 L
.76031 .1882 L
.76068 .19088 L
.7615 .19942 L
.7622 .20948 L
.76297 .22296 L
.76626 .3024 L
.76789 .34706 L
.76942 .38574 L
.77089 .41611 L
.77171 .42907 L
.77246 .43783 L
.77285 .44109 L
.77306 .44251 L
.77325 .44361 L
.77344 .44442 L
.77354 .44477 L
.77364 .44507 L
.77373 .44527 L
Mistroke
.77382 .44544 L
.77391 .44555 L
.77399 .44561 L
.77409 .44563 L
.77415 .44561 L
.77421 .44557 L
.7743 .44546 L
.77441 .44527 L
.7745 .44504 L
.77459 .44478 L
.77479 .444 L
.77501 .44289 L
.77521 .44162 L
.77565 .43788 L
.77604 .43375 L
.77644 .4284 L
.77718 .41647 L
.77884 .3798 L
.78218 .2829 L
.78385 .23472 L
.78458 .216 L
.78539 .19797 L
.78612 .18448 L
.78689 .17331 L
.78732 .16873 L
.78771 .16559 L
.7879 .16444 L
.78811 .16346 L
.7882 .16311 L
.7883 .1628 L
.78839 .16259 L
.78848 .16241 L
.78858 .1623 L
.78867 .16225 L
.78877 .16226 L
.78883 .16229 L
.78888 .16234 L
.78898 .1625 L
.78904 .16262 L
.78909 .16275 L
.78929 .16343 L
.78946 .16423 L
.78965 .16534 L
.79003 .16832 L
.79045 .17269 L
.7909 .17865 L
.79171 .19258 L
.79341 .23328 L
.79502 .28219 L
.79809 .38088 L
Mistroke
.79967 .42282 L
.80055 .44081 L
.80135 .45292 L
.80174 .45727 L
.80196 .45919 L
.80216 .46068 L
.80234 .46179 L
.80251 .46259 L
.8026 .46293 L
.8027 .46323 L
.8028 .46347 L
.8029 .46362 L
.803 .46371 L
.8031 .46371 L
.80315 .46369 L
.80321 .46364 L
.80326 .46357 L
.80332 .46346 L
.80343 .4632 L
.80353 .46287 L
.80377 .46183 L
.80397 .46059 L
.80416 .45919 L
.80457 .45515 L
.80496 .45021 L
.80537 .44383 L
.80611 .42957 L
.80778 .38587 L
.81083 .28312 L
.81252 .22713 L
.81407 .18552 L
.81483 .16997 L
.81524 .16337 L
.81567 .15764 L
.81588 .15532 L
.81608 .15345 L
.81628 .15194 L
.81645 .15081 L
.81663 .14998 L
.81671 .14964 L
.81681 .14935 L
.8169 .14912 L
.81699 .14898 L
.81709 .14889 L
.81719 .14888 L
.81728 .14895 L
.81737 .14907 L
.81747 .14929 L
.81757 .14961 L
.81768 .15003 L
Mistroke
.81779 .15053 L
.81798 .1517 L
.81834 .15458 L
.81872 .15884 L
.81914 .16476 L
.81959 .1725 L
.82039 .18989 L
.82211 .23958 L
.82373 .29639 L
.82682 .40395 L
.82765 .42704 L
.82842 .44488 L
.82923 .45903 L
.82966 .46452 L
.82988 .46679 L
.83011 .46875 L
.83031 .47007 L
.83042 .47063 L
.83054 .47113 L
.83064 .47148 L
.83074 .47172 L
.83083 .47188 L
.83093 .47197 L
.83099 .47198 L
.83104 .47197 L
.83109 .47193 L
.83115 .47186 L
.83125 .47168 L
.8313 .47154 L
.83135 .47139 L
.83158 .47047 L
.83169 .46984 L
.83182 .46902 L
.83222 .46549 L
.83265 .46021 L
.83343 .44695 L
.83425 .42841 L
.83513 .40345 L
.83675 .34869 L
.83846 .28459 L
.84001 .22943 L
.84079 .20515 L
.84163 .18271 L
.84243 .1659 L
.84281 .15952 L
.84316 .15472 L
.84354 .15066 L
.84374 .14894 L
.84394 .14766 L
.84403 .1472 L
Mistroke
.84412 .14678 L
.8442 .14648 L
.84429 .14622 L
.84438 .14602 L
.84447 .1459 L
.84458 .14585 L
.84467 .14589 L
.84477 .14601 L
.84487 .14623 L
.84497 .14652 L
.84506 .14686 L
.84528 .14798 L
.84548 .14942 L
.84589 .15337 L
.84633 .15923 L
.84709 .17303 L
.84793 .19311 L
.84962 .24617 L
.85286 .36667 L
.85436 .41509 L
.85514 .43568 L
.85598 .45274 L
.8564 .4592 L
.85662 .46204 L
.85687 .46462 L
.85709 .46653 L
.85729 .46792 L
.85748 .4689 L
.85758 .46927 L
.85768 .46957 L
.85774 .46969 L
.85779 .46978 L
.8579 .46988 L
.858 .46988 L
.85809 .4698 L
.85819 .46964 L
.85825 .4695 L
.8583 .46935 L
.85841 .46896 L
.85852 .46843 L
.85873 .46716 L
.85893 .46561 L
.8593 .46176 L
.8597 .45623 L
.86007 .45007 L
.86089 .43247 L
.86237 .38971 L
.86558 .27184 L
.86706 .22119 L
.8679 .19703 L
Mistroke
.86868 .17858 L
.86945 .16489 L
.86989 .15937 L
.87028 .15576 L
.8705 .15437 L
.8706 .15385 L
.8707 .15345 L
.8708 .15312 L
.87086 .15298 L
.87092 .15286 L
.87098 .15278 L
.87104 .15273 L
.87109 .15271 L
.87115 .15272 L
.87121 .15275 L
.87126 .15281 L
.87136 .15299 L
.87146 .15329 L
.87158 .15372 L
.87178 .15479 L
.87197 .15611 L
.87235 .15965 L
.87275 .16482 L
.87348 .17752 L
.87435 .19779 L
.87514 .22049 L
.87833 .33379 L
.87994 .38903 L
.8814 .42836 L
.88179 .4365 L
.88222 .44396 L
.88258 .44924 L
.88298 .45372 L
.88321 .4556 L
.88341 .45697 L
.88352 .45755 L
.88363 .458 L
.88369 .4582 L
.88375 .45839 L
.88381 .45853 L
.88386 .45863 L
.88396 .45875 L
.88401 .45878 L
.88407 .45879 L
.88412 .45877 L
.88418 .45872 L
.88428 .45855 L
.88438 .45831 L
.88447 .45802 L
.88467 .45708 L
Mistroke
.88488 .45572 L
.88508 .45412 L
.88552 .4493 L
.8859 .44371 L
.88632 .4365 L
.88781 .40026 L
.89086 .29708 L
.89255 .23971 L
.8941 .19822 L
.89487 .18346 L
.8953 .17713 L
.8957 .17265 L
.89605 .16985 L
.89615 .16926 L
.89625 .16872 L
.89635 .1683 L
.89644 .16798 L
.89653 .16772 L
.89664 .16752 L
.89674 .16742 L
.89679 .16741 L
.89685 .16742 L
.89694 .16749 L
.89704 .16765 L
.89713 .16789 L
.89722 .16818 L
.89742 .16906 L
.8976 .17015 L
.898 .1736 L
.89837 .178 L
.89873 .1832 L
.89952 .19823 L
.90038 .21935 L
.90365 .32456 L
.90516 .37303 L
.90595 .39499 L
.90679 .41428 L
.90722 .42232 L
.90769 .4296 L
.90812 .43473 L
.90851 .4382 L
.90872 .43951 L
.90883 .44002 L
.90892 .44041 L
.90901 .44069 L
.9091 .44093 L
.9092 .4411 L
.90929 .4412 L
.90935 .44122 L
.9094 .44121 L
Mistroke
.9095 .44114 L
.90956 .44106 L
.90961 .44096 L
.90973 .44066 L
.90983 .4403 L
.90992 .4399 L
.91013 .43874 L
.91032 .43741 L
.91052 .43563 L
.91094 .43102 L
.91167 .41957 L
.91254 .40151 L
.91334 .38083 L
.91646 .28393 L
.91805 .23809 L
.91889 .21841 L
.91935 .2094 L
.91978 .20222 L
.92019 .19661 L
.92057 .19257 L
.92077 .19088 L
.92099 .18937 L
.92121 .18824 L
.92133 .18779 L
.92144 .18746 L
.92153 .18727 L
.92164 .18714 L
.92174 .18709 L
.92183 .18712 L
.92191 .1872 L
.922 .18735 L
.92209 .18758 L
.92218 .18785 L
.92238 .1887 L
.92256 .18975 L
.92298 .19305 L
.92336 .19725 L
.92377 .20288 L
.9245 .21578 L
.92616 .25575 L
.92777 .30248 L
.9295 .35282 L
.93032 .37365 L
.93118 .39229 L
.93191 .40483 L
.93233 .41039 L
.93272 .41448 L
.93291 .41612 L
.93312 .41757 L
.93323 .41819 L
Mistroke
.93335 .41879 L
.93346 .41924 L
.93356 .41957 L
.93365 .41982 L
.93375 .42001 L
.93386 .42012 L
.93391 .42015 L
.93397 .42016 L
.93406 .42011 L
.93415 .42001 L
.93425 .41982 L
.93435 .41957 L
.93453 .41892 L
.93472 .41796 L
.93507 .41559 L
.93544 .41212 L
.93584 .40724 L
.93666 .3943 L
.9374 .37928 L
.93908 .3376 L
.94074 .29228 L
.94227 .25389 L
.94304 .23801 L
.94376 .22584 L
.94416 .22039 L
.94459 .21565 L
.94478 .21393 L
.94498 .21239 L
.94515 .21129 L
.94534 .21032 L
.94545 .20987 L
.94555 .20953 L
.94564 .20927 L
.94574 .20906 L
.94583 .20892 L
.94592 .20885 L
.94601 .20883 L
.9461 .20887 L
.9462 .20898 L
.94626 .20907 L
.94631 .20917 L
.94642 .20944 L
.94653 .20981 L
.94674 .2107 L
.94692 .21175 L
.94729 .21448 L
.94768 .21837 L
.94839 .22781 L
.94916 .24087 L
.94999 .25812 L
Mistroke
.95168 .29866 L
.95338 .3401 L
.95493 .37168 L
.95569 .38345 L
.9561 .38838 L
.95653 .39258 L
.9569 .39533 L
.95712 .39651 L
.95732 .39735 L
.95741 .39765 L
.9575 .3979 L
.95758 .39807 L
.95767 .39822 L
.95776 .39832 L
.95786 .39836 L
.95796 .39834 L
.95805 .39828 L
.95814 .39815 L
.95823 .39798 L
.95833 .39773 L
.95844 .3974 L
.95865 .39651 L
.95885 .39545 L
.95923 .39275 L
.95959 .38943 L
.96038 .37955 L
.96125 .36537 L
.96452 .2956 L
.96603 .26498 L
.96682 .25182 L
.96766 .24096 L
.96809 .23679 L
.96832 .23498 L
.96856 .23335 L
.96878 .23215 L
.96898 .23129 L
.96908 .23097 L
.96919 .23068 L
.96929 .23046 L
.96938 .23031 L
.96947 .23021 L
.96957 .23016 L
.96967 .23017 L
.96976 .23021 L
.96985 .23032 L
.96996 .23049 L
.97007 .23074 L
.97017 .23103 L
.97038 .23182 L
.97057 .23275 L
Mistroke
.971 .23556 L
.97139 .23894 L
.9718 .24332 L
.97254 .25306 L
.97421 .28186 L
.97619 .32103 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{421.375, 260.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 525.688}, {324.5, 0}} -> {-2.58312*^-7, -6.34248*^6, \
6.65005*^-9, 53093.5}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0.309017 5.42214e-08 [
[.32684 .29652 -16.5 -12.5 ]
[.32684 .29652 16.5 0 ]
[.54329 .29652 -16.5 -12.5 ]
[.54329 .29652 16.5 0 ]
[.75974 .29652 -22.5 -12.5 ]
[.75974 .29652 22.5 0 ]
[.97619 .29652 -16.5 -12.5 ]
[.97619 .29652 16.5 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 64 6 ]
[.09789 .09213 -34.5 -6.25 ]
[.09789 .09213 0 6.25 ]
[.09789 .20057 -34.5 -6.25 ]
[.09789 .20057 0 6.25 ]
[.09789 .41746 -28.5 -6.25 ]
[.09789 .41746 0 6.25 ]
[.09789 .5259 -28.5 -6.25 ]
[.09789 .5259 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -65.8125 0 ]
[.5 .63053 65.8125 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 .30902 m
.32684 .31527 L
s
gsave
.32684 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 .30902 m
.54329 .31527 L
s
gsave
.54329 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 .30902 m
.75974 .31527 L
s
gsave
.75974 .29652 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 .30902 m
.15368 .31277 L
s
.19697 .30902 m
.19697 .31277 L
s
.24026 .30902 m
.24026 .31277 L
s
.28355 .30902 m
.28355 .31277 L
s
.37013 .30902 m
.37013 .31277 L
s
.41342 .30902 m
.41342 .31277 L
s
.45671 .30902 m
.45671 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.58658 .30902 m
.58658 .31277 L
s
.62987 .30902 m
.62987 .31277 L
s
.67316 .30902 m
.67316 .31277 L
s
.71645 .30902 m
.71645 .31277 L
s
.80303 .30902 m
.80303 .31277 L
s
.84632 .30902 m
.84632 .31277 L
s
.88961 .30902 m
.88961 .31277 L
s
.9329 .30902 m
.9329 .31277 L
s
.0671 .30902 m
.0671 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09213 m
.11664 .09213 L
s
gsave
.09789 .09213 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .20057 m
.11664 .20057 L
s
gsave
.09789 .20057 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .41746 m
.11664 .41746 L
s
gsave
.09789 .41746 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .5259 m
.11664 .5259 L
s
gsave
.09789 .5259 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.11039 .11924 m
.11414 .11924 L
s
.11039 .14635 m
.11414 .14635 L
s
.11039 .17346 m
.11414 .17346 L
s
.11039 .22768 m
.11414 .22768 L
s
.11039 .2548 m
.11414 .2548 L
s
.11039 .28191 m
.11414 .28191 L
s
.11039 .33613 m
.11414 .33613 L
s
.11039 .36324 m
.11414 .36324 L
s
.11039 .39035 m
.11414 .39035 L
s
.11039 .44457 m
.11414 .44457 L
s
.11039 .47168 m
.11414 .47168 L
s
.11039 .49879 m
.11414 .49879 L
s
.11039 .06502 m
.11414 .06502 L
s
.11039 .03791 m
.11414 .03791 L
s
.11039 .0108 m
.11414 .0108 L
s
.11039 .55301 m
.11414 .55301 L
s
.11039 .58012 m
.11414 .58012 L
s
.11039 .60723 m
.11414 .60723 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -126.812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.812 moveto
(@) show
81.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.812 moveto
(D) show
93.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(14.8) show
141.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
147.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
159.000 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
163.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
172.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
190.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02691 .30902 L
.03029 .30902 L
.03347 .30902 L
.03652 .30902 L
.03978 .30902 L
.04291 .30902 L
.04623 .30902 L
.04944 .30902 L
.05252 .30902 L
.0558 .30902 L
.05896 .30902 L
.062 .30902 L
.06523 .30902 L
.06834 .30902 L
.07165 .30902 L
.07484 .30902 L
.0779 .30902 L
.08117 .30902 L
.08431 .30902 L
.08765 .30902 L
.09086 .30902 L
.09396 .30902 L
.09725 .30902 L
.10042 .30902 L
.10346 .30902 L
.10671 .30902 L
.10983 .30902 L
.11315 .30902 L
.11635 .30902 L
.11943 .30902 L
.1227 .30902 L
.12585 .30902 L
.12888 .30902 L
.13211 .30902 L
.13521 .30902 L
.13852 .30902 L
.1417 .30902 L
.14476 .30902 L
.14801 .30902 L
.15115 .30902 L
.15448 .30902 L
.15769 .30902 L
.16077 .30902 L
.16406 .30902 L
.16722 .30902 L
.17026 .30902 L
.17195 .30902 L
.1735 .30902 L
.17427 .30902 L
Mistroke
.1751 .30902 L
.17589 .30902 L
.17627 .30902 L
.17662 .30902 L
.17703 .30902 L
.17724 .30902 L
.17735 .30902 L
.17747 .30902 L
.17757 .30902 L
.17766 .30902 L
.17776 .30902 L
.17785 .30902 L
.17795 .30902 L
.17805 .30902 L
.17815 .30902 L
.17821 .30902 L
.17827 .30902 L
.17846 .30902 L
.17864 .30902 L
.17883 .30902 L
.17904 .30902 L
.17938 .30902 L
.17976 .30902 L
.18059 .30902 L
.18134 .30902 L
.1822 .30902 L
.18302 .30902 L
.18463 .30902 L
.18611 .30902 L
.18762 .30902 L
.18928 .30902 L
.19098 .30902 L
.19252 .30902 L
.19564 .30902 L
.19884 .30902 L
.20191 .30902 L
.20518 .30902 L
.20833 .30902 L
.21136 .30902 L
.21458 .30902 L
.21769 .30902 L
.22099 .30902 L
.22417 .30902 L
.22722 .30902 L
.23047 .30902 L
.23361 .30902 L
.2352 .30902 L
.23604 .30902 L
.23693 .30902 L
.23773 .30902 L
Mistroke
.23815 .30902 L
.2386 .30902 L
.23902 .30902 L
.2394 .30902 L
.23958 .30902 L
.23978 .30902 L
.23997 .30902 L
.24014 .30902 L
.24024 .30902 L
.24035 .30902 L
.24045 .30902 L
.24051 .30902 L
.24057 .30902 L
.24067 .30902 L
.24076 .30902 L
.24081 .30902 L
.24087 .30902 L
.24097 .30902 L
.24106 .30902 L
.24116 .30902 L
.24136 .30902 L
.24155 .30902 L
.24172 .30902 L
.24214 .30902 L
.24253 .30902 L
.24296 .30902 L
.24341 .30902 L
.24417 .30902 L
.24499 .30902 L
.24647 .30902 L
.24818 .30902 L
.2498 .30902 L
.25289 .30902 L
.25448 .30902 L
.25617 .30902 L
.25922 .30902 L
.26246 .30902 L
.26557 .30902 L
.26889 .30902 L
.27208 .30902 L
.27515 .30902 L
.27842 .30902 L
.28157 .30902 L
.28318 .30902 L
.28491 .30902 L
.28573 .30902 L
.28659 .30902 L
.28733 .30902 L
.28753 .30902 L
.28774 .30902 L
Mistroke
.28793 .30902 L
.28813 .30902 L
.28834 .30902 L
.28845 .30902 L
.28856 .30902 L
.28866 .30902 L
.28875 .30902 L
.28885 .30902 L
.28895 .30902 L
.28901 .30902 L
.28906 .30902 L
.28917 .30902 L
.28928 .30902 L
.28938 .30902 L
.2896 .30902 L
.28984 .30902 L
.29025 .30902 L
.29068 .30902 L
.29146 .30902 L
.29222 .30902 L
.29303 .30902 L
.29451 .30902 L
.29621 .30902 L
.29782 .30902 L
.3009 .30902 L
.30417 .30902 L
.30732 .30902 L
.31035 .30902 L
.31358 .30902 L
.31668 .30902 L
.31998 .30902 L
.32316 .30902 L
.32477 .30902 L
.32622 .30902 L
.32703 .30902 L
.3278 .30902 L
.328 .30902 L
.32821 .30902 L
.3284 .30902 L
.3286 .30902 L
.32871 .30902 L
.32882 .30902 L
.32892 .30902 L
.32902 .30902 L
.32907 .30902 L
.32913 .30902 L
.3292 .30902 L
.32925 .30902 L
.32931 .30902 L
.32937 .30902 L
Mistroke
.32942 .30902 L
.32948 .30902 L
.32958 .30902 L
.32967 .30902 L
.32976 .30902 L
.32985 .30902 L
.33007 .30902 L
.33026 .30902 L
.33061 .30902 L
.33099 .30902 L
.3314 .30902 L
.33178 .30902 L
.33265 .30902 L
.33344 .30902 L
.33427 .30902 L
.33576 .30902 L
.33734 .30902 L
.33882 .30902 L
.34196 .30902 L
.34529 .30902 L
.3485 .30902 L
.35159 .30902 L
.35488 .30902 L
.35805 .30902 L
.35964 .30902 L
.36109 .30903 L
.36184 .30903 L
.36266 .30903 L
.3631 .30903 L
.36352 .30903 L
.36391 .30903 L
.36411 .30903 L
.36433 .30903 L
.36452 .30903 L
.36463 .30903 L
.36473 .30903 L
.36483 .30903 L
.36493 .30903 L
.36498 .30903 L
.36504 .30903 L
.36514 .30903 L
.36523 .30903 L
.36533 .30903 L
.36543 .30903 L
.36553 .30903 L
.3657 .30903 L
.36588 .30903 L
.36633 .30903 L
.36676 .30903 L
.36756 .30903 L
Mistroke
.36833 .30903 L
.36915 .30903 L
.37062 .30902 L
.37234 .30902 L
.37396 .30902 L
.37706 .30902 L
.38035 .30901 L
.38352 .30901 L
.38657 .309 L
.38981 .30899 L
.39131 .30899 L
.39294 .30899 L
.39382 .30899 L
.39464 .30899 L
.39542 .30899 L
.39582 .30899 L
.39603 .30899 L
.39626 .30899 L
.39646 .30899 L
.39665 .30899 L
.39676 .30899 L
.39685 .30899 L
.39691 .30899 L
.39696 .30899 L
.39707 .30899 L
.39716 .30899 L
.39726 .30899 L
.39736 .30899 L
.39745 .30899 L
.39754 .30899 L
.39763 .30899 L
.39781 .30899 L
.39802 .30899 L
.39822 .30899 L
.39867 .30899 L
.39906 .30899 L
.39948 .30899 L
.40031 .30899 L
.40121 .30899 L
.40283 .30899 L
.40443 .309 L
.40612 .309 L
.40918 .30902 L
.41243 .30904 L
.41555 .30906 L
.41888 .30908 L
.42054 .30909 L
.42208 .3091 L
.42358 .30911 L
.42433 .30911 L
Mistroke
.42476 .30911 L
.42516 .30911 L
.42555 .30911 L
.42576 .30911 L
.42597 .30911 L
.42608 .30911 L
.42618 .30911 L
.42627 .30911 L
.42636 .30911 L
.42644 .30911 L
.42653 .30911 L
.42662 .30911 L
.42672 .30911 L
.42677 .30911 L
.42683 .30911 L
.42689 .30911 L
.42694 .30911 L
.42703 .30911 L
.42714 .30911 L
.42735 .30911 L
.42759 .30911 L
.42779 .30911 L
.428 .30911 L
.42839 .30911 L
.42916 .30911 L
.43 .3091 L
.43088 .3091 L
.43169 .30909 L
.43333 .30908 L
.43483 .30906 L
.43803 .30902 L
.44112 .30896 L
.4444 .3089 L
.44756 .30884 L
.44915 .30881 L
.4506 .30879 L
.4514 .30879 L
.45216 .30878 L
.45258 .30878 L
.45296 .30878 L
.45318 .30878 L
.45339 .30877 L
.4535 .30877 L
.45362 .30877 L
.45374 .30877 L
.45384 .30877 L
.45394 .30877 L
.45403 .30877 L
.45413 .30877 L
.45418 .30877 L
Mistroke
.45423 .30877 L
.45432 .30877 L
.45441 .30877 L
.45451 .30877 L
.4546 .30877 L
.45481 .30877 L
.45501 .30877 L
.45522 .30878 L
.45544 .30878 L
.45586 .30878 L
.45625 .30878 L
.45713 .30879 L
.45798 .3088 L
.45878 .30882 L
.46027 .30885 L
.46188 .30889 L
.46336 .30895 L
.46652 .30908 L
.46957 .30923 L
.47281 .30939 L
.4743 .30945 L
.47592 .30951 L
.47681 .30953 L
.47763 .30955 L
.47803 .30956 L
.47841 .30956 L
.47862 .30956 L
.47884 .30957 L
.47905 .30957 L
.47924 .30957 L
.47943 .30957 L
.47954 .30957 L
.47964 .30957 L
.47973 .30957 L
.47981 .30957 L
.47991 .30957 L
.48001 .30957 L
.48011 .30957 L
.48016 .30957 L
.48021 .30957 L
.48031 .30957 L
.48041 .30957 L
.48062 .30957 L
.48084 .30957 L
.48107 .30957 L
.48127 .30956 L
.48172 .30956 L
.48214 .30955 L
.48254 .30954 L
.48332 .30952 L
Mistroke
.48415 .30948 L
.48563 .30941 L
.48721 .30931 L
.48868 .30919 L
.4918 .30888 L
.49512 .30851 L
.49832 .30818 L
.49978 .30805 L
.50061 .308 L
.5014 .30795 L
.50216 .30791 L
.50255 .3079 L
.50298 .30788 L
.50319 .30788 L
.50341 .30788 L
.50364 .30787 L
.50375 .30787 L
.50386 .30787 L
.50392 .30787 L
.50397 .30787 L
.50408 .30787 L
.50418 .30787 L
.50423 .30787 L
.50428 .30787 L
.50438 .30787 L
.50447 .30787 L
.50457 .30787 L
.50467 .30787 L
.50477 .30787 L
.50488 .30787 L
.50507 .30787 L
.50544 .30788 L
.50587 .30789 L
.50626 .30791 L
.50698 .30795 L
.50774 .308 L
.50932 .30815 L
.51079 .30835 L
.51392 .3089 L
.51724 .30963 L
.52044 .31035 L
.52191 .31064 L
.52352 .31091 L
.52429 .31101 L
.52511 .3111 L
.52557 .31114 L
.52598 .31116 L
.52638 .31118 L
.52658 .31119 L
.5268 .3112 L
Mistroke
.5269 .3112 L
.527 .3112 L
.52706 .3112 L
.52712 .3112 L
.52723 .31121 L
.52733 .31121 L
.52738 .31121 L
.52743 .31121 L
.52753 .31121 L
.52763 .31121 L
.52772 .3112 L
.52781 .3112 L
.52799 .3112 L
.52817 .31119 L
.52838 .31119 L
.52879 .31116 L
.52924 .31113 L
.53006 .31105 L
.53083 .31094 L
.53167 .31079 L
.53336 .31039 L
.53493 .30991 L
.53661 .30929 L
.53994 .30789 L
.54315 .30654 L
.54461 .30601 L
.54545 .30576 L
.54623 .30555 L
.54706 .30537 L
.54782 .30525 L
.54824 .3052 L
.54864 .30517 L
.54885 .30515 L
.54906 .30514 L
.54917 .30514 L
.54928 .30514 L
.54933 .30514 L
.5494 .30514 L
.54946 .30513 L
.54951 .30513 L
.54961 .30514 L
.54971 .30514 L
.5498 .30514 L
.54989 .30514 L
.54999 .30515 L
.5501 .30515 L
.55029 .30516 L
.55064 .30519 L
.55102 .30523 L
.55144 .3053 L
Mistroke
.55188 .30538 L
.55268 .30558 L
.55345 .30582 L
.55429 .30615 L
.55599 .30698 L
.55924 .30912 L
.56238 .31153 L
.56398 .31271 L
.56571 .31386 L
.56652 .31431 L
.56738 .31473 L
.56819 .31504 L
.56892 .31526 L
.56931 .31535 L
.56968 .31541 L
.56988 .31544 L
.57007 .31546 L
.57017 .31547 L
.57027 .31547 L
.57033 .31548 L
.57039 .31548 L
.57049 .31548 L
.57059 .31548 L
.57067 .31548 L
.57077 .31548 L
.57087 .31548 L
.57097 .31548 L
.57107 .31547 L
.57126 .31546 L
.57143 .31544 L
.5716 .31542 L
.57196 .31535 L
.57234 .31527 L
.57274 .31515 L
.57347 .31487 L
.57433 .31443 L
.57512 .31393 L
.57664 .3127 L
.57831 .31102 L
.58157 .30702 L
.58471 .30307 L
.58631 .30134 L
.58715 .30057 L
.58804 .29988 L
.58884 .2994 L
.58929 .29919 L
.58972 .29903 L
.58992 .29898 L
.59011 .29893 L
.59028 .29889 L
Mistroke
.59046 .29886 L
.59056 .29885 L
.59066 .29884 L
.59075 .29883 L
.59084 .29883 L
.59095 .29882 L
.59104 .29882 L
.59115 .29882 L
.5912 .29883 L
.59126 .29883 L
.59136 .29884 L
.59146 .29885 L
.59168 .29888 L
.59188 .29892 L
.59208 .29897 L
.59244 .29908 L
.59283 .29925 L
.5937 .29977 L
.59451 .30043 L
.59614 .30226 L
.59763 .30447 L
.60082 .31043 L
.60389 .31664 L
.6056 .31973 L
.60715 .322 L
.60793 .32289 L
.60834 .32327 L
.60877 .32362 L
.60915 .32387 L
.60935 .32398 L
.60957 .32408 L
.60976 .32416 L
.60994 .32421 L
.61012 .32426 L
.61021 .32428 L
.6103 .32429 L
.61039 .3243 L
.61049 .32431 L
.61057 .32431 L
.61066 .32432 L
.61077 .32431 L
.61086 .32431 L
.61096 .32429 L
.61107 .32428 L
.61118 .32426 L
.61129 .32423 L
.6115 .32416 L
.6119 .32399 L
.61227 .32376 L
.61267 .32346 L
Mistroke
.61337 .32275 L
.61413 .32176 L
.61495 .32044 L
.61642 .31742 L
.61973 .30835 L
.62293 .29858 L
.62439 .29453 L
.62522 .29251 L
.626 .29083 L
.62683 .28936 L
.62759 .2883 L
.62798 .28787 L
.6284 .28751 L
.6286 .28737 L
.62881 .28725 L
.62894 .2872 L
.62905 .28715 L
.62916 .28712 L
.62927 .28709 L
.62936 .28707 L
.62946 .28706 L
.62951 .28706 L
.62956 .28705 L
.62966 .28705 L
.62976 .28706 L
.62986 .28707 L
.62996 .28709 L
.63007 .28712 L
.63027 .28719 L
.63046 .28728 L
.63081 .2875 L
.63123 .28788 L
.63161 .28832 L
.63248 .28967 L
.63326 .29129 L
.63399 .29313 L
.63565 .29838 L
.63877 .3112 L
.64209 .32571 L
.64375 .33183 L
.64448 .33407 L
.64529 .33613 L
.64566 .33692 L
.64606 .33765 L
.6464 .33818 L
.64678 .33865 L
.64697 .33884 L
.64718 .33902 L
.6473 .33909 L
.6474 .33915 L
Mistroke
.64751 .33921 L
.64761 .33924 L
.6477 .33927 L
.64779 .33929 L
.64789 .33931 L
.64795 .33931 L
.648 .33931 L
.64809 .33931 L
.64817 .3393 L
.64827 .33928 L
.64837 .33925 L
.64847 .33921 L
.64857 .33916 L
.64877 .33903 L
.64914 .33871 L
.64956 .33816 L
.64996 .33751 L
.65068 .33595 L
.65144 .3338 L
.65301 .32775 L
.65449 .32048 L
.65761 .30184 L
.65921 .29205 L
.66094 .28241 L
.66175 .27853 L
.6626 .27501 L
.66341 .27235 L
.66414 .27051 L
.66451 .26982 L
.6649 .26928 L
.6651 .26907 L
.66528 .26891 L
.66539 .26885 L
.66549 .2688 L
.66554 .26878 L
.6656 .26876 L
.66566 .26874 L
.66571 .26873 L
.66579 .26873 L
.66588 .26873 L
.66597 .26874 L
.66605 .26876 L
.66614 .26879 L
.66624 .26884 L
.66642 .26896 L
.66661 .26913 L
.66681 .26936 L
.66718 .26991 L
.66757 .27071 L
.66793 .27161 L
Mistroke
.66874 .27426 L
.66945 .27727 L
.6702 .28109 L
.67326 .3021 L
.67651 .32894 L
.67802 .34043 L
.67965 .35075 L
.68054 .35507 L
.68093 .35662 L
.68136 .35806 L
.68174 .35909 L
.68214 .35994 L
.68237 .36029 L
.68257 .36054 L
.68267 .36063 L
.68278 .36071 L
.68288 .36077 L
.68297 .36081 L
.68308 .36083 L
.68313 .36084 L
.68319 .36084 L
.68329 .36083 L
.68338 .3608 L
.68344 .36077 L
.68349 .36075 L
.6836 .36068 L
.6837 .36058 L
.68382 .36046 L
.68403 .36019 L
.68424 .35982 L
.68462 .35896 L
.68499 .35789 L
.68533 .35668 L
.68612 .35315 L
.68691 .34856 L
.68774 .34271 L
.68922 .32998 L
.69229 .29814 L
.69399 .28003 L
.69554 .26539 L
.69632 .25917 L
.69716 .25348 L
.69795 .24926 L
.69833 .24767 L
.69868 .24648 L
.69905 .24549 L
.69926 .24508 L
.69946 .24477 L
.69955 .24466 L
.69964 .24457 L
Mistroke
.69972 .2445 L
.69981 .24444 L
.69991 .2444 L
.70001 .24438 L
.7001 .24438 L
.70019 .2444 L
.70028 .24444 L
.70039 .24451 L
.70048 .2446 L
.70057 .2447 L
.70079 .24502 L
.70099 .24542 L
.7014 .24651 L
.70184 .24813 L
.7026 .25194 L
.70343 .25758 L
.70512 .2732 L
.70836 .31384 L
.71147 .35458 L
.71228 .36358 L
.71316 .37208 L
.71401 .37866 L
.71478 .38313 L
.71517 .38482 L
.71537 .38554 L
.71559 .38618 L
.71578 .38662 L
.71588 .38682 L
.71599 .387 L
.71609 .38713 L
.71618 .38723 L
.71627 .3873 L
.71635 .38735 L
.71645 .38738 L
.71651 .38738 L
.71656 .38738 L
.71666 .38734 L
.71672 .38731 L
.71677 .38727 L
.71686 .38719 L
.71696 .38707 L
.71716 .38674 L
.71738 .38624 L
.71761 .38555 L
.71804 .3839 L
.71846 .3817 L
.71886 .37921 L
.71975 .37199 L
.72137 .35382 L
.72453 .30533 L
Mistroke
.72757 .25652 L
.72913 .23648 L
.73001 .22785 L
.73039 .22474 L
.73081 .22194 L
.73122 .21969 L
.7316 .21815 L
.73178 .21759 L
.73198 .2171 L
.73207 .21693 L
.73216 .21678 L
.73225 .21666 L
.73233 .21658 L
.73244 .21651 L
.73253 .21649 L
.73263 .21649 L
.73269 .21652 L
.73274 .21655 L
.73283 .21662 L
.73293 .21673 L
.73303 .21688 L
.73313 .21706 L
.73335 .2176 L
.73355 .21825 L
.734 .22023 L
.73438 .22248 L
.73479 .22545 L
.73552 .23223 L
.73718 .2538 L
.74052 .31471 L
.74219 .34766 L
.74373 .37516 L
.74523 .39663 L
.74599 .40473 L
.74641 .40838 L
.74682 .41118 L
.74721 .41325 L
.74743 .41414 L
.74764 .41478 L
.74781 .41518 L
.74791 .41535 L
.748 .41548 L
.7481 .41557 L
.74818 .41561 L
.74828 .41562 L
.74838 .41559 L
.74849 .41551 L
.74858 .4154 L
.74869 .41521 L
.7488 .41499 L
Mistroke
.74898 .41448 L
.74918 .41375 L
.74964 .41145 L
.75006 .40853 L
.75084 .40119 L
.75156 .39214 L
.75322 .36462 L
.75633 .29648 L
.75792 .26057 L
.75964 .22627 L
.76044 .21336 L
.7613 .20229 L
.76171 .19803 L
.7621 .19474 L
.76245 .19239 L
.76283 .19053 L
.76302 .18987 L
.76313 .18958 L
.76323 .18936 L
.76332 .1892 L
.76342 .18907 L
.76351 .189 L
.76359 .18898 L
.76369 .18899 L
.76379 .18905 L
.76389 .18917 L
.76395 .18926 L
.764 .18936 L
.76421 .1899 L
.76432 .19025 L
.76443 .1907 L
.76486 .19295 L
.76531 .19635 L
.76612 .20502 L
.76695 .2169 L
.76784 .23298 L
.76946 .26899 L
.77274 .35389 L
.77438 .39223 L
.77517 .40798 L
.7759 .42009 L
.77666 .42994 L
.777 .4335 L
.77737 .43658 L
.77758 .43797 L
.77776 .43902 L
.77795 .43989 L
.77812 .44051 L
.77822 .44078 L
.77833 .44101 L
Mistroke
.77843 .44117 L
.77849 .44124 L
.77855 .44128 L
.77865 .44131 L
.77874 .44128 L
.77885 .44119 L
.77895 .44104 L
.77904 .44085 L
.77914 .4406 L
.77932 .43998 L
.77953 .43901 L
.77972 .43788 L
.78015 .43468 L
.78055 .43069 L
.78126 .42149 L
.78203 .40847 L
.78361 .3736 L
.78529 .32778 L
.78689 .28097 L
.78862 .23318 L
.78944 .21365 L
.7903 .19596 L
.79103 .18376 L
.79142 .17853 L
.79184 .17384 L
.79206 .17183 L
.79226 .17024 L
.79245 .16897 L
.79266 .16785 L
.79284 .16708 L
.79293 .1668 L
.79302 .16656 L
.79312 .16637 L
.7932 .16624 L
.7933 .16616 L
.7934 .16614 L
.79346 .16616 L
.79352 .16621 L
.79357 .16627 L
.79362 .16634 L
.79372 .16653 L
.79382 .1668 L
.79404 .16759 L
.79427 .1688 L
.79469 .17185 L
.79508 .17573 L
.79592 .18719 L
.79671 .20184 L
.7982 .23777 L
.80126 .33188 L
Mistroke
.80298 .38396 L
.80453 .42304 L
.80531 .43815 L
.80572 .44466 L
.80615 .45038 L
.80653 .45437 L
.80673 .45609 L
.80694 .45761 L
.80714 .45873 L
.80732 .4595 L
.80741 .45979 L
.8075 .46004 L
.80759 .46022 L
.80767 .46034 L
.80777 .46041 L
.80787 .46041 L
.80795 .46036 L
.80805 .46024 L
.80815 .46004 L
.80825 .45974 L
.80845 .459 L
.80864 .45797 L
.80883 .45675 L
.80917 .4538 L
.80959 .44917 L
.80997 .44386 L
.81083 .42839 L
.81233 .39109 L
.81399 .33935 L
.81569 .28172 L
.81723 .23166 L
.818 .2097 L
.81883 .18895 L
.81962 .17314 L
.82035 .16197 L
.82075 .15752 L
.82096 .15565 L
.82118 .15405 L
.82137 .15299 L
.82147 .15254 L
.82158 .15215 L
.82167 .15186 L
.82176 .15166 L
.82185 .15153 L
.82194 .15145 L
.82203 .15144 L
.82209 .15147 L
.82214 .15151 L
.82224 .15167 L
.8223 .15179 L
Mistroke
.82236 .15193 L
.82245 .15223 L
.82255 .15264 L
.82274 .15361 L
.82296 .15508 L
.8232 .15706 L
.82362 .16169 L
.82445 .17453 L
.82534 .19365 L
.82696 .23971 L
.83025 .35486 L
.83189 .40748 L
.83269 .42881 L
.83342 .44491 L
.83378 .45156 L
.83417 .4577 L
.83451 .46207 L
.83489 .46583 L
.83509 .46741 L
.83529 .46858 L
.83549 .46948 L
.8356 .46984 L
.83571 .47007 L
.8358 .4702 L
.83588 .47026 L
.83598 .47025 L
.83608 .47017 L
.83618 .46999 L
.83628 .46973 L
.83637 .46943 L
.83647 .46904 L
.83666 .46803 L
.83686 .46663 L
.83723 .46323 L
.83766 .45778 L
.83806 .4515 L
.83893 .43386 L
.83975 .41255 L
.84282 .3077 L
.84453 .2456 L
.84609 .19736 L
.84687 .17811 L
.84728 .16964 L
.84771 .16204 L
.84809 .15657 L
.84829 .15415 L
.8485 .15192 L
.8487 .15021 L
.84888 .14894 L
.84906 .14794 L
Mistroke
.84923 .14726 L
.84932 .147 L
.84942 .1468 L
.84952 .14669 L
.8496 .14665 L
.8497 .14669 L
.8498 .14681 L
.84985 .14691 L
.84991 .14705 L
.85001 .14735 L
.85012 .14778 L
.85023 .14835 L
.85044 .14967 L
.85083 .15316 L
.85121 .15769 L
.8516 .16372 L
.85231 .17755 L
.85389 .22031 L
.85536 .27105 L
.85848 .38537 L
.85929 .41094 L
.86018 .43453 L
.86059 .44357 L
.86102 .45184 L
.86142 .45826 L
.8618 .46296 L
.86216 .46644 L
.86234 .46776 L
.86255 .46885 L
.86265 .46929 L
.86275 .4696 L
.8628 .46973 L
.86286 .46985 L
.86297 .46999 L
.86306 .47003 L
.86317 .46997 L
.86326 .46985 L
.86336 .46964 L
.86345 .46934 L
.86355 .46897 L
.86372 .46808 L
.86391 .46682 L
.86411 .4651 L
.86448 .4611 L
.86482 .45636 L
.86567 .44054 L
.86647 .42084 L
.86797 .37409 L
.87106 .2598 L
.87263 .20834 L
Mistroke
.87346 .18642 L
.87392 .17637 L
.87435 .16832 L
.87476 .16208 L
.87498 .15936 L
.87521 .15691 L
.8754 .15521 L
.87562 .15371 L
.87571 .15319 L
.87581 .1527 L
.8759 .15236 L
.87599 .15206 L
.87609 .15184 L
.87618 .15172 L
.87623 .15167 L
.87629 .15166 L
.87638 .15169 L
.87649 .15182 L
.87658 .15202 L
.87668 .15233 L
.87679 .15277 L
.87697 .15372 L
.87714 .15486 L
.87752 .1584 L
.87792 .16345 L
.87836 .17045 L
.87915 .18697 L
.88064 .22912 L
.88391 .34683 L
.88542 .39736 L
.88622 .41946 L
.88706 .43825 L
.88749 .44581 L
.88796 .45239 L
.88816 .45469 L
.88838 .45675 L
.88859 .45829 L
.88878 .45938 L
.88888 .45982 L
.88899 .4602 L
.88904 .46034 L
.8891 .46047 L
.88916 .46057 L
.88922 .46064 L
.88927 .46068 L
.88933 .46069 L
.88943 .46064 L
.88953 .4605 L
.88963 .46028 L
.88973 .45996 L
Mistroke
.88982 .45957 L
.89 .45864 L
.89019 .45732 L
.8904 .45554 L
.89079 .45112 L
.89116 .44583 L
.892 .42984 L
.89282 .40952 L
.89369 .38347 L
.89701 .26694 L
.89867 .21506 L
.8994 .19687 L
.89979 .18867 L
.90021 .18109 L
.90061 .17511 L
.90098 .17079 L
.90133 .16772 L
.9015 .16658 L
.9017 .16565 L
.9018 .16527 L
.90191 .16501 L
.902 .16485 L
.90209 .16475 L
.90215 .16474 L
.9022 .16475 L
.90226 .16479 L
.90231 .16485 L
.90241 .16504 L
.90252 .16532 L
.90262 .16568 L
.90272 .16616 L
.90292 .16729 L
.90328 .17029 L
.90371 .17521 L
.90411 .1812 L
.90486 .19564 L
.90655 .24086 L
.90964 .34557 L
.91122 .39334 L
.91211 .41489 L
.91253 .42336 L
.91294 .43015 L
.91332 .43545 L
.91353 .43776 L
.91374 .43986 L
.91392 .44132 L
.91412 .44262 L
.91421 .44308 L
.9143 .44351 L
.91438 .44383 L
Mistroke
.91447 .4441 L
.91457 .44433 L
.91467 .44447 L
.91473 .44452 L
.91478 .44453 L
.91489 .4445 L
.91494 .44444 L
.915 .44435 L
.9151 .44414 L
.91521 .4438 L
.91533 .44332 L
.91552 .44228 L
.91573 .44081 L
.91611 .43724 L
.91653 .43191 L
.91693 .42576 L
.91781 .40789 L
.91943 .3641 L
.92258 .26307 L
.92334 .24091 L
.92415 .22053 L
.9249 .20509 L
.9256 .19417 L
.92596 .18998 L
.92634 .1866 L
.92656 .18519 L
.92667 .18464 L
.92677 .18421 L
.92685 .18389 L
.92695 .18362 L
.92705 .18342 L
.92715 .1833 L
.92721 .18327 L
.92726 .18326 L
.92737 .18332 L
.92747 .18346 L
.92757 .18367 L
.92768 .18401 L
.92779 .18441 L
.92802 .18562 L
.92822 .18701 L
.92843 .18886 L
.92883 .19313 L
.92959 .20461 L
.93043 .22157 L
.93212 .26629 L
.93382 .31801 L
.93536 .36299 L
.93613 .38228 L
.93697 .39981 L
Mistroke
.93735 .40643 L
.93776 .41239 L
.93811 .41667 L
.93849 .42017 L
.93867 .42154 L
.93888 .42272 L
.93897 .42315 L
.93907 .42353 L
.93916 .42382 L
.93924 .42404 L
.93934 .42423 L
.9394 .4243 L
.93946 .42435 L
.93956 .42437 L
.93961 .42435 L
.93966 .42431 L
.93976 .42418 L
.93985 .424 L
.93995 .42371 L
.94005 .42337 L
.94023 .42256 L
.94041 .42145 L
.94075 .4188 L
.94115 .41458 L
.94152 .40981 L
.94232 .39622 L
.94307 .38056 L
.94474 .33732 L
.94638 .29081 L
.94791 .25122 L
.94867 .23495 L
.94939 .22235 L
.94978 .21672 L
.95021 .21174 L
.9504 .20994 L
.9506 .2083 L
.95078 .20712 L
.95096 .20606 L
.95116 .20525 L
.95126 .20492 L
.95136 .20468 L
.95145 .20452 L
.95153 .20442 L
.95163 .20437 L
.95172 .20438 L
.95182 .20446 L
.95192 .20462 L
.95201 .20482 L
.95211 .2051 L
.95233 .20597 L
Mistroke
.95253 .20709 L
.9529 .20983 L
.95324 .21313 L
.954 .22316 L
.95479 .2371 L
.95553 .25261 L
.9572 .29368 L
.95882 .33542 L
.95962 .35417 L
.96035 .36944 L
.96104 .38176 L
.9618 .39228 L
.9622 .3964 L
.96257 .39936 L
.96277 .40062 L
.96296 .40153 L
.96306 .40194 L
.96317 .4023 L
.96328 .40257 L
.96337 .40275 L
.96347 .40288 L
.96357 .40294 L
.96365 .40294 L
.96375 .40288 L
.96385 .40276 L
.96391 .40266 L
.96396 .40255 L
.96415 .402 L
.96433 .40126 L
.96452 .40023 L
.96488 .39777 L
.9653 .39385 L
.96574 .38861 L
.96653 .37668 L
.96811 .34532 L
.96958 .31116 L
.97108 .27709 L
.97187 .26121 L
.97271 .24692 L
.97313 .24095 L
.9736 .23541 L
.97402 .23141 L
.97442 .22858 L
.97461 .22751 L
.97482 .22664 L
.975 .2261 L
.9751 .22588 L
.97519 .22573 L
.97525 .22566 L
.9753 .22562 L
Mistroke
.97541 .22558 L
.97551 .2256 L
.9756 .22568 L
.9757 .22581 L
.97576 .22592 L
.97581 .22604 L
.97603 .2267 L
.97619 .22736 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{421.375, 260.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 525.688}, {324.5, 0}} -> {-2.58312*^-7, -6.34248*^6, \
6.65005*^-9, 53093.5}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.11039 432900 0.309017 5.42214e-08 [
[.32684 .29652 -16.5 -12.5 ]
[.32684 .29652 16.5 0 ]
[.54329 .29652 -16.5 -12.5 ]
[.54329 .29652 16.5 0 ]
[.75974 .29652 -22.5 -12.5 ]
[.75974 .29652 22.5 0 ]
[.97619 .29652 -16.5 -12.5 ]
[.97619 .29652 16.5 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 64 6 ]
[.09789 .09213 -34.5 -6.25 ]
[.09789 .09213 0 6.25 ]
[.09789 .20057 -34.5 -6.25 ]
[.09789 .20057 0 6.25 ]
[.09789 .41746 -28.5 -6.25 ]
[.09789 .41746 0 6.25 ]
[.09789 .5259 -28.5 -6.25 ]
[.09789 .5259 0 6.25 ]
[.11039 .64303 -5 0 ]
[.11039 .64303 5 12 ]
[.5 .63053 -62.8125 0 ]
[.5 .63053 62.8125 12.8125 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.32684 .30902 m
.32684 .31527 L
s
gsave
.32684 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-7) show
grestore
.54329 .30902 m
.54329 .31527 L
s
gsave
.54329 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.75974 .30902 m
.75974 .31527 L
s
gsave
.75974 .29652 -22.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(1.5) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.97619 .30902 m
.97619 .31527 L
s
gsave
.97619 .29652 -16.5 -10.5 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(-6) show
grestore
.125 Mabswid
.15368 .30902 m
.15368 .31277 L
s
.19697 .30902 m
.19697 .31277 L
s
.24026 .30902 m
.24026 .31277 L
s
.28355 .30902 m
.28355 .31277 L
s
.37013 .30902 m
.37013 .31277 L
s
.41342 .30902 m
.41342 .31277 L
s
.45671 .30902 m
.45671 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.58658 .30902 m
.58658 .31277 L
s
.62987 .30902 m
.62987 .31277 L
s
.67316 .30902 m
.67316 .31277 L
s
.71645 .30902 m
.71645 .31277 L
s
.80303 .30902 m
.80303 .31277 L
s
.84632 .30902 m
.84632 .31277 L
s
.88961 .30902 m
.88961 .31277 L
s
.9329 .30902 m
.9329 .31277 L
s
.0671 .30902 m
.0671 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.000 moveto
(H) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(meters) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
117.000 13.000 moveto
(L) show
123.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.11039 .09213 m
.11664 .09213 L
s
gsave
.09789 .09213 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .20057 m
.11664 .20057 L
s
gsave
.09789 .20057 -34.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(-2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .41746 m
.11664 .41746 L
s
gsave
.09789 .41746 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(2) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.11039 .5259 m
.11664 .5259 L
s
gsave
.09789 .5259 -28.5 -4.25 Mabsadd m
1 1 Mabs scale
/Courier findfont 10 scalefont setfont
(4) show
/Math1Mono findfont 10 scalefont setfont
(\\264) show
/Courier findfont 10 scalefont setfont
(10) show
0 5.25 rmoveto
/Courier findfont 7.5 scalefont setfont
(6) show
grestore
.125 Mabswid
.11039 .11924 m
.11414 .11924 L
s
.11039 .14635 m
.11414 .14635 L
s
.11039 .17346 m
.11414 .17346 L
s
.11039 .22768 m
.11414 .22768 L
s
.11039 .2548 m
.11414 .2548 L
s
.11039 .28191 m
.11414 .28191 L
s
.11039 .33613 m
.11414 .33613 L
s
.11039 .36324 m
.11414 .36324 L
s
.11039 .39035 m
.11414 .39035 L
s
.11039 .44457 m
.11414 .44457 L
s
.11039 .47168 m
.11414 .47168 L
s
.11039 .49879 m
.11414 .49879 L
s
.11039 .06502 m
.11414 .06502 L
s
.11039 .03791 m
.11414 .03791 L
s
.11039 .0108 m
.11414 .0108 L
s
.11039 .55301 m
.11414 .55301 L
s
.11039 .58012 m
.11414 .58012 L
s
.11039 .60723 m
.11414 .60723 L
s
.25 Mabswid
.11039 0 m
.11039 .61803 L
s
gsave
.11039 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
69.000 13.000 moveto
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -123.812 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.812 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Re) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.812 moveto
(@) show
81.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.812 moveto
(D) show
93.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
105.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
111.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
117.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15.) show
135.000 13.812 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(\\211) show
141.000 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
153.000 9.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
157.188 9.438 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
166.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sec) show
184.625 13.812 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .30902 m
.02691 .30902 L
.03029 .30902 L
.03347 .30902 L
.03652 .30902 L
.03978 .30902 L
.04291 .30902 L
.04623 .30902 L
.04944 .30902 L
.05252 .30902 L
.0558 .30902 L
.05896 .30902 L
.062 .30902 L
.06523 .30902 L
.06834 .30902 L
.07165 .30902 L
.07484 .30902 L
.0779 .30902 L
.08117 .30902 L
.08431 .30902 L
.08765 .30902 L
.09086 .30902 L
.09396 .30902 L
.09725 .30902 L
.10042 .30902 L
.10346 .30902 L
.10671 .30902 L
.10983 .30902 L
.11315 .30902 L
.11635 .30902 L
.11943 .30902 L
.1227 .30902 L
.12585 .30902 L
.12888 .30902 L
.13211 .30902 L
.13521 .30902 L
.13852 .30902 L
.1417 .30902 L
.14476 .30902 L
.14801 .30902 L
.15115 .30902 L
.15448 .30902 L
.15769 .30902 L
.16077 .30902 L
.16406 .30902 L
.16722 .30902 L
.17026 .30902 L
.17195 .30902 L
.1735 .30902 L
.17427 .30902 L
Mistroke
.17467 .30902 L
.1751 .30902 L
.17551 .30902 L
.17589 .30902 L
.17607 .30902 L
.17626 .30902 L
.17645 .30902 L
.17662 .30902 L
.17671 .30902 L
.17681 .30902 L
.17691 .30902 L
.17696 .30902 L
.17701 .30902 L
.1771 .30902 L
.17719 .30902 L
.17729 .30902 L
.17738 .30902 L
.17748 .30902 L
.17759 .30902 L
.17779 .30902 L
.17799 .30902 L
.17822 .30902 L
.17864 .30902 L
.1791 .30902 L
.17991 .30902 L
.18074 .30902 L
.18163 .30902 L
.1824 .30902 L
.18325 .30902 L
.18485 .30902 L
.18654 .30902 L
.1881 .30902 L
.18978 .30902 L
.19137 .30902 L
.1931 .30902 L
.19629 .30902 L
.19956 .30902 L
.20271 .30902 L
.20574 .30902 L
.20896 .30902 L
.21207 .30902 L
.21537 .30902 L
.21854 .30902 L
.2216 .30902 L
.22485 .30902 L
.22798 .30902 L
.23131 .30902 L
.23452 .30902 L
.23599 .30902 L
.23682 .30902 L
Mistroke
.2376 .30902 L
.23844 .30902 L
.2392 .30902 L
.23961 .30902 L
.24001 .30902 L
.24023 .30902 L
.24043 .30902 L
.24055 .30902 L
.24065 .30902 L
.24071 .30902 L
.24077 .30902 L
.24083 .30902 L
.24089 .30902 L
.24099 .30902 L
.24108 .30902 L
.24117 .30902 L
.24126 .30902 L
.24137 .30902 L
.24147 .30902 L
.24167 .30902 L
.24185 .30902 L
.24202 .30902 L
.2424 .30902 L
.24281 .30902 L
.2432 .30902 L
.24406 .30902 L
.24484 .30902 L
.24558 .30902 L
.24724 .30902 L
.24888 .30902 L
.25038 .30902 L
.25205 .30902 L
.25359 .30902 L
.25668 .30902 L
.25984 .30902 L
.26288 .30902 L
.26612 .30902 L
.26924 .30902 L
.27255 .30902 L
.27575 .30902 L
.27882 .30902 L
.28209 .30902 L
.2836 .30902 L
.28523 .30902 L
.28613 .30902 L
.28696 .30902 L
.28775 .30902 L
.28814 .30902 L
.28835 .30902 L
.28858 .30902 L
Mistroke
.2888 .30902 L
.289 .30902 L
.28919 .30902 L
.28929 .30902 L
.28935 .30902 L
.2894 .30902 L
.2895 .30902 L
.28959 .30902 L
.28968 .30902 L
.28979 .30902 L
.28988 .30902 L
.28997 .30902 L
.29006 .30902 L
.29015 .30902 L
.29036 .30902 L
.29056 .30902 L
.29101 .30902 L
.29141 .30902 L
.29183 .30902 L
.29259 .30902 L
.2934 .30902 L
.29487 .30902 L
.29569 .30902 L
.29658 .30902 L
.29819 .30902 L
.29978 .30902 L
.30147 .30902 L
.3045 .30902 L
.30772 .30902 L
.31083 .30902 L
.31413 .30902 L
.31731 .30902 L
.32036 .30902 L
.32362 .30902 L
.32512 .30902 L
.32675 .30902 L
.32764 .30902 L
.32846 .30902 L
.32887 .30902 L
.32925 .30902 L
.32965 .30902 L
.32986 .30902 L
.32997 .30902 L
.33008 .30902 L
.33018 .30902 L
.33029 .30902 L
.33034 .30902 L
.3304 .30902 L
.3305 .30902 L
.33059 .30902 L
Mistroke
.33069 .30902 L
.3308 .30902 L
.33089 .30902 L
.33101 .30902 L
.33112 .30902 L
.33132 .30902 L
.33154 .30902 L
.33178 .30902 L
.33219 .30902 L
.33262 .30902 L
.33339 .30902 L
.33415 .30902 L
.33496 .30902 L
.33643 .30902 L
.33804 .30902 L
.33973 .30902 L
.3428 .30902 L
.34605 .30902 L
.34919 .30902 L
.35253 .30902 L
.35574 .30902 L
.35883 .30902 L
.3604 .30902 L
.36212 .30902 L
.36291 .30902 L
.36375 .30902 L
.36455 .30902 L
.3649 .30902 L
.36528 .30903 L
.36567 .30903 L
.36588 .30903 L
.36597 .30903 L
.36608 .30903 L
.36616 .30903 L
.36626 .30903 L
.36635 .30903 L
.36643 .30903 L
.36653 .30903 L
.36661 .30903 L
.36672 .30903 L
.36681 .30903 L
.36691 .30903 L
.36701 .30903 L
.36723 .30903 L
.36743 .30903 L
.36761 .30903 L
.36803 .30903 L
.36848 .30902 L
.36929 .30902 L
.37017 .30902 L
Mistroke
.37101 .30902 L
.37179 .30902 L
.37343 .30902 L
.37493 .30902 L
.37814 .30902 L
.38124 .30901 L
.38453 .30901 L
.3877 .309 L
.39075 .309 L
.39245 .30899 L
.394 .30899 L
.39476 .30899 L
.3956 .30899 L
.39638 .30899 L
.39712 .30899 L
.39748 .30899 L
.39787 .30899 L
.39809 .30899 L
.39831 .30899 L
.3985 .30899 L
.39861 .30899 L
.39871 .30899 L
.39881 .30899 L
.39887 .30899 L
.39893 .30899 L
.39903 .30899 L
.39908 .30899 L
.39913 .30899 L
.39923 .30899 L
.39933 .30899 L
.39943 .30899 L
.39952 .30899 L
.39974 .30899 L
.39997 .30899 L
.40039 .30899 L
.40082 .30899 L
.40122 .30899 L
.40198 .30899 L
.40279 .30899 L
.40366 .30899 L
.40526 .309 L
.40696 .309 L
.41001 .30901 L
.41326 .30903 L
.41639 .30905 L
.41971 .30907 L
.42291 .30909 L
.42438 .30909 L
.42521 .3091 L
.426 .3091 L
Mistroke
.42676 .3091 L
.42719 .3091 L
.42759 .3091 L
.42779 .3091 L
.428 .3091 L
.42812 .3091 L
.42823 .3091 L
.42835 .3091 L
.42845 .3091 L
.42855 .3091 L
.42866 .3091 L
.42876 .3091 L
.42882 .3091 L
.42888 .3091 L
.42898 .3091 L
.42907 .3091 L
.42917 .3091 L
.42927 .3091 L
.42946 .3091 L
.42964 .3091 L
.43005 .3091 L
.43044 .3091 L
.43087 .3091 L
.43164 .3091 L
.43235 .3091 L
.43387 .30909 L
.43553 .30907 L
.4371 .30906 L
.43878 .30904 L
.44211 .30899 L
.44532 .30893 L
.4484 .30888 L
.44997 .30885 L
.45169 .30883 L
.45247 .30882 L
.45332 .30881 L
.45411 .3088 L
.45485 .3088 L
.45524 .3088 L
.45544 .3088 L
.45566 .3088 L
.45578 .3088 L
.4559 .3088 L
.45601 .3088 L
.45612 .3088 L
.45623 .3088 L
.45633 .3088 L
.45643 .3088 L
.45649 .3088 L
.45654 .3088 L
Mistroke
.45664 .3088 L
.4567 .3088 L
.45675 .3088 L
.45685 .3088 L
.45694 .3088 L
.45715 .3088 L
.45737 .3088 L
.45757 .3088 L
.45778 .3088 L
.45816 .3088 L
.45893 .30881 L
.45974 .30881 L
.46052 .30882 L
.46122 .30884 L
.46276 .30887 L
.46443 .30891 L
.46772 .30902 L
.47088 .30916 L
.47393 .3093 L
.47562 .30937 L
.47717 .30942 L
.47877 .30947 L
.47956 .30949 L
.48028 .3095 L
.48066 .30951 L
.48106 .30952 L
.48128 .30952 L
.48148 .30952 L
.48169 .30952 L
.48188 .30952 L
.48204 .30952 L
.48214 .30952 L
.48222 .30952 L
.48231 .30952 L
.48242 .30952 L
.48251 .30952 L
.4826 .30952 L
.48269 .30952 L
.48277 .30952 L
.48287 .30952 L
.48297 .30952 L
.48317 .30952 L
.48336 .30952 L
.48374 .30952 L
.48415 .30951 L
.48488 .3095 L
.48575 .30948 L
.48654 .30945 L
.48809 .30938 L
.48976 .30928 L
Mistroke
.49305 .30902 L
.49622 .30871 L
.49927 .30841 L
.50096 .30825 L
.50251 .30813 L
.50328 .30808 L
.50411 .30804 L
.5049 .30801 L
.50528 .30799 L
.50563 .30798 L
.50601 .30798 L
.5062 .30797 L
.50641 .30797 L
.50649 .30797 L
.50659 .30797 L
.50667 .30797 L
.50675 .30797 L
.50685 .30797 L
.50695 .30797 L
.50704 .30797 L
.50713 .30797 L
.50723 .30797 L
.50733 .30797 L
.50743 .30797 L
.50751 .30797 L
.50773 .30797 L
.50793 .30798 L
.50834 .30798 L
.50878 .308 L
.50921 .30802 L
.50961 .30803 L
.51037 .30808 L
.51118 .30814 L
.51205 .30823 L
.51365 .30842 L
.51535 .30867 L
.5184 .30924 L
.52165 .30991 L
.52477 .31051 L
.52648 .31076 L
.52727 .31085 L
.5281 .31093 L
.52846 .31096 L
.52886 .31098 L
.52908 .31099 L
.52929 .311 L
.5295 .31101 L
.5297 .31101 L
.52986 .31102 L
.52996 .31102 L
Mistroke
.53004 .31102 L
.53014 .31102 L
.53024 .31102 L
.53033 .31102 L
.53042 .31102 L
.53051 .31102 L
.53059 .31102 L
.53069 .31102 L
.53079 .31102 L
.53099 .31101 L
.53118 .31101 L
.53156 .31099 L
.53197 .31096 L
.53271 .3109 L
.5335 .31081 L
.53437 .31068 L
.53592 .31036 L
.5376 .30991 L
.5409 .30877 L
.54407 .30752 L
.54713 .30641 L
.5487 .30596 L
.54958 .30576 L
.55038 .30562 L
.55077 .30557 L
.5512 .30552 L
.55164 .30548 L
.55187 .30547 L
.55198 .30546 L
.55209 .30546 L
.5522 .30546 L
.5523 .30545 L
.5524 .30545 L
.5525 .30545 L
.5526 .30545 L
.5527 .30545 L
.55278 .30545 L
.55287 .30546 L
.55297 .30546 L
.55308 .30546 L
.55331 .30548 L
.55352 .30549 L
.55371 .30551 L
.55411 .30555 L
.55455 .30561 L
.55534 .30576 L
.55612 .30596 L
.55683 .30619 L
.55833 .30679 L
.55999 .30764 L
Mistroke
.56322 .30971 L
.56632 .31189 L
.5679 .31292 L
.56963 .31387 L
.57042 .31423 L
.57127 .31454 L
.57169 .31467 L
.57208 .31476 L
.57246 .31484 L
.57281 .3149 L
.573 .31492 L
.57318 .31494 L
.57338 .31496 L
.57349 .31496 L
.57359 .31497 L
.57369 .31497 L
.57379 .31497 L
.57389 .31497 L
.57398 .31497 L
.57404 .31497 L
.57409 .31497 L
.57421 .31496 L
.57431 .31496 L
.57442 .31495 L
.57459 .31493 L
.57478 .31491 L
.57512 .31486 L
.57553 .31477 L
.5759 .31468 L
.57669 .3144 L
.57743 .31406 L
.5791 .31301 L
.5806 .31176 L
.58226 .31011 L
.58549 .30638 L
.5886 .30288 L
.59018 .30142 L
.59102 .3008 L
.59191 .30026 L
.59235 .30004 L
.59277 .29988 L
.59315 .29976 L
.59335 .29972 L
.59356 .29967 L
.59376 .29964 L
.59395 .29962 L
.59405 .29961 L
.59415 .29961 L
.5942 .2996 L
.59426 .2996 L
Mistroke
.59436 .2996 L
.59445 .2996 L
.59454 .29961 L
.59465 .29961 L
.59474 .29962 L
.59491 .29964 L
.59509 .29967 L
.59529 .29971 L
.59549 .29976 L
.59586 .29987 L
.5963 .30006 L
.5967 .30027 L
.59757 .30085 L
.5984 .30157 L
.6 .30342 L
.60148 .30557 L
.60464 .31115 L
.60768 .31676 L
.60937 .31947 L
.61092 .32142 L
.61168 .32215 L
.61209 .32246 L
.61252 .32274 L
.61293 .32294 L
.6133 .32308 L
.61348 .32312 L
.61358 .32314 L
.61368 .32316 L
.61377 .32317 L
.61386 .32318 L
.61395 .32319 L
.61403 .32319 L
.61414 .32319 L
.61419 .32319 L
.61424 .32319 L
.61434 .32318 L
.61444 .32317 L
.61455 .32316 L
.61465 .32314 L
.61487 .32308 L
.61506 .32302 L
.61526 .32294 L
.61567 .32272 L
.61604 .32247 L
.61644 .32214 L
.61716 .3214 L
.61798 .3203 L
.61888 .31884 L
.62049 .31551 L
.62378 .30688 L
Mistroke
.62695 .29803 L
.62854 .29417 L
.62999 .29136 L
.63079 .29018 L
.63155 .28935 L
.63197 .28902 L
.63236 .28879 L
.63256 .28871 L
.63267 .28867 L
.63278 .28864 L
.63289 .28862 L
.63295 .28861 L
.63301 .2886 L
.63312 .28859 L
.63318 .28859 L
.63323 .28859 L
.63333 .2886 L
.63338 .2886 L
.63344 .28861 L
.63354 .28862 L
.63364 .28865 L
.63385 .28871 L
.63407 .28881 L
.63429 .28894 L
.63449 .28908 L
.63487 .28941 L
.63558 .29026 L
.63636 .29153 L
.63794 .29514 L
.63962 .30034 L
.64296 .31334 L
.64618 .32615 L
.64765 .33098 L
.64849 .33322 L
.64927 .33492 L
.65005 .33617 L
.65048 .33668 L
.65087 .33701 L
.65109 .33714 L
.65129 .33723 L
.65139 .33726 L
.65145 .33727 L
.65151 .33728 L
.65157 .33729 L
.65162 .33729 L
.65168 .3373 L
.65174 .3373 L
.65184 .33729 L
.65195 .33727 L
.65204 .33725 L
Mistroke
.65213 .33722 L
.65236 .33711 L
.65256 .33698 L
.65294 .33664 L
.65334 .33613 L
.65377 .33545 L
.65417 .33467 L
.65565 .33061 L
.65649 .32757 L
.65728 .32423 L
.65877 .31696 L
.66184 .29963 L
.66355 .29003 L
.66511 .28235 L
.66588 .27907 L
.66673 .27609 L
.66752 .27387 L
.6679 .27303 L
.66825 .27241 L
.66863 .27187 L
.66884 .27165 L
.66903 .27149 L
.66912 .27143 L
.66922 .27137 L
.6693 .27133 L
.66938 .2713 L
.66948 .27128 L
.66957 .27126 L
.66967 .27126 L
.66977 .27127 L
.66986 .27129 L
.66997 .27132 L
.67006 .27136 L
.67015 .27141 L
.67037 .27157 L
.67057 .27177 L
.67098 .27233 L
.67143 .27317 L
.67219 .27515 L
.67302 .27812 L
.67471 .28643 L
.67796 .30881 L
.68108 .33273 L
.68267 .34331 L
.6835 .348 L
.68439 .3521 L
.68518 .35487 L
.68563 .35606 L
.68584 .3565 L
.68605 .3569 L
Mistroke
.68624 .35718 L
.68644 .35743 L
.68653 .35751 L
.68662 .35759 L
.68671 .35766 L
.68679 .3577 L
.6869 .35774 L
.68695 .35776 L
.68701 .35777 L
.6871 .35778 L
.68716 .35778 L
.68721 .35777 L
.68731 .35774 L
.68739 .35771 L
.68749 .35765 L
.68759 .35758 L
.6878 .35738 L
.68799 .35712 L
.68836 .35648 L
.68876 .35553 L
.68918 .35422 L
.68995 .35112 L
.69066 .34745 L
.69217 .33724 L
.69383 .323 L
.69708 .29065 L
.69857 .27626 L
.7002 .26289 L
.70109 .25709 L
.70191 .25288 L
.70231 .25125 L
.70269 .25 L
.70309 .24901 L
.7033 .24861 L
.70342 .24842 L
.70352 .24828 L
.70362 .24818 L
.70372 .24809 L
.70382 .24802 L
.70392 .24797 L
.70402 .24794 L
.70411 .24794 L
.7042 .24795 L
.70429 .24798 L
.70435 .24801 L
.7044 .24804 L
.7045 .24812 L
.70461 .24823 L
.70473 .24837 L
.70494 .24871 L
Mistroke
.70513 .24911 L
.70556 .25029 L
.70595 .25169 L
.70683 .25601 L
.70763 .26138 L
.70838 .2674 L
.71005 .28423 L
.71322 .32356 L
.71628 .35957 L
.71709 .36712 L
.71785 .37312 L
.71827 .3759 L
.71873 .37845 L
.71914 .38032 L
.71953 .38168 L
.71972 .3822 L
.71989 .38261 L
.71999 .38279 L
.7201 .38297 L
.7202 .3831 L
.72029 .38321 L
.72034 .38326 L
.7204 .3833 L
.7205 .38336 L
.72055 .38338 L
.72061 .38339 L
.72066 .38339 L
.72072 .38338 L
.72082 .38335 L
.72088 .38332 L
.72093 .38329 L
.72103 .3832 L
.72112 .38309 L
.72132 .38277 L
.72154 .3823 L
.72193 .38114 L
.72235 .37943 L
.72281 .37698 L
.72362 .37134 L
.72436 .36471 L
.72603 .34534 L
.72921 .29779 L
.73227 .2526 L
.73385 .2351 L
.7343 .2312 L
.73473 .22804 L
.73511 .22568 L
.73553 .2236 L
.73572 .22283 L
.73593 .22213 L
Mistroke
.73611 .22165 L
.73631 .22124 L
.73642 .22107 L
.73648 .221 L
.73653 .22094 L
.73663 .22086 L
.73669 .22083 L
.73674 .22081 L
.73684 .2208 L
.73693 .22082 L
.73703 .22087 L
.73713 .22097 L
.73723 .22108 L
.73731 .22121 L
.7375 .22159 L
.73767 .22205 L
.73784 .22258 L
.73821 .22412 L
.73861 .22632 L
.73937 .23189 L
.7402 .24014 L
.74189 .26277 L
.74512 .32026 L
.74823 .37507 L
.74984 .39596 L
.75065 .40338 L
.75111 .40654 L
.75133 .40778 L
.75154 .40876 L
.75173 .40953 L
.75194 .4102 L
.75216 .4107 L
.75227 .41089 L
.75233 .41096 L
.75238 .41102 L
.75249 .4111 L
.75258 .41113 L
.75268 .41113 L
.75277 .41109 L
.75286 .41101 L
.75297 .41088 L
.75308 .41069 L
.75318 .41047 L
.75336 .40998 L
.75356 .4093 L
.7539 .40772 L
.75427 .40548 L
.75467 .40239 L
.7555 .39413 L
.75625 .38446 L
Mistroke
.75793 .3563 L
.76113 .28817 L
.7626 .25685 L
.76422 .22697 L
.76498 .21547 L
.76581 .20552 L
.76626 .20122 L
.76668 .19809 L
.76688 .19687 L
.7671 .19574 L
.76731 .19488 L
.7675 .19427 L
.7676 .19402 L
.7677 .1938 L
.76781 .19364 L
.76787 .19357 L
.76792 .19353 L
.76803 .19348 L
.76812 .19349 L
.76817 .1935 L
.76823 .19354 L
.76833 .19364 L
.76842 .19378 L
.76852 .19397 L
.76872 .19451 L
.7689 .19518 L
.76908 .19597 L
.7695 .19849 L
.76989 .20155 L
.77076 .21101 L
.77155 .22238 L
.77228 .23516 L
.77394 .27049 L
.77708 .34824 L
.77868 .38497 L
.77952 .40149 L
.78041 .41607 L
.7812 .4261 L
.78166 .43043 L
.78187 .43213 L
.78208 .43351 L
.78226 .43456 L
.78247 .43549 L
.78265 .43615 L
.78273 .43638 L
.78282 .43658 L
.78293 .43677 L
.78302 .43689 L
.78312 .43696 L
.78321 .43698 L
Mistroke
.7833 .43694 L
.78341 .43685 L
.78346 .43678 L
.78352 .43668 L
.78362 .43647 L
.78383 .43586 L
.78404 .43494 L
.78444 .43263 L
.78486 .42918 L
.78533 .42425 L
.78616 .41262 L
.78694 .39869 L
.79005 .32213 L
.79164 .27761 L
.79336 .23219 L
.79416 .21401 L
.79501 .19747 L
.79582 .18508 L
.79655 .1769 L
.79694 .1738 L
.79713 .17259 L
.79735 .17153 L
.79754 .17086 L
.79764 .17058 L
.79773 .17038 L
.79782 .17024 L
.79792 .17015 L
.79801 .17012 L
.79809 .17013 L
.79819 .17021 L
.79829 .17035 L
.79839 .17055 L
.79848 .17078 L
.79868 .17152 L
.7989 .17259 L
.79931 .17542 L
.79976 .17973 L
.80059 .19076 L
.80133 .2041 L
.80302 .24373 L
.80622 .33972 L
.80769 .38266 L
.80853 .40428 L
.80931 .42185 L
.81014 .43712 L
.8109 .44752 L
.81132 .45165 L
.81172 .4545 L
.81193 .45561 L
.81204 .45602 L
Mistroke
.81214 .45635 L
.81219 .4565 L
.81225 .45664 L
.81236 .45683 L
.81242 .4569 L
.81248 .45695 L
.81253 .45697 L
.81259 .45696 L
.8127 .4569 L
.81279 .45677 L
.81284 .45668 L
.8129 .45655 L
.81301 .45623 L
.81322 .45542 L
.81341 .45439 L
.81377 .45178 L
.81416 .44797 L
.81459 .4426 L
.81504 .43568 L
.81584 .42024 L
.81743 .37985 L
.8189 .33405 L
.82204 .23259 L
.82286 .20972 L
.82375 .18851 L
.82459 .17266 L
.825 .16666 L
.82537 .16216 L
.82575 .1586 L
.82595 .15708 L
.82615 .15594 L
.82624 .15552 L
.82633 .15514 L
.82641 .15486 L
.8265 .15462 L
.8266 .1544 L
.8267 .15427 L
.82679 .15422 L
.82688 .15422 L
.82697 .1543 L
.82708 .15446 L
.82717 .15469 L
.82726 .15495 L
.82748 .15586 L
.82768 .15705 L
.82809 .16035 L
.82854 .16533 L
.82929 .17709 L
.83013 .19444 L
.83182 .24117 L
Mistroke
.83505 .35194 L
.83654 .39956 L
.83732 .42109 L
.83816 .44027 L
.83862 .4489 L
.83904 .45544 L
.83947 .46076 L
.83986 .46443 L
.84005 .4658 L
.84026 .46693 L
.84036 .46738 L
.84046 .46772 L
.84057 .468 L
.84063 .46811 L
.84069 .46819 L
.84079 .46827 L
.84088 .46827 L
.84098 .46819 L
.84103 .46812 L
.84109 .46801 L
.84118 .46778 L
.84129 .46745 L
.84147 .46663 L
.84166 .46549 L
.84187 .46393 L
.84224 .46029 L
.84268 .45457 L
.84308 .44811 L
.84395 .43012 L
.84477 .40874 L
.84786 .30426 L
.84942 .24843 L
.85025 .22141 L
.85114 .19585 L
.852 .1757 L
.85278 .1617 L
.85315 .15661 L
.85335 .15437 L
.85356 .15234 L
.85376 .15074 L
.85395 .14958 L
.85404 .14912 L
.85413 .1487 L
.85422 .14838 L
.85431 .14814 L
.85441 .14793 L
.8545 .14781 L
.8546 .14777 L
.85465 .14778 L
.8547 .14781 L
Mistroke
.85479 .14792 L
.85488 .1481 L
.85498 .14838 L
.85507 .14871 L
.85528 .14975 L
.85547 .15102 L
.85591 .15503 L
.8563 .16001 L
.85673 .16685 L
.8576 .18482 L
.85918 .22964 L
.86086 .2889 L
.86246 .34832 L
.8642 .40641 L
.86501 .42878 L
.86587 .44776 L
.8666 .45959 L
.8668 .46207 L
.86702 .46436 L
.86721 .46601 L
.86741 .46749 L
.86761 .46862 L
.86773 .46908 L
.86783 .46941 L
.86793 .46963 L
.86802 .46976 L
.86812 .46981 L
.86822 .46978 L
.86833 .46965 L
.86839 .46953 L
.86844 .4694 L
.86855 .46907 L
.86865 .46867 L
.86887 .46745 L
.86911 .46565 L
.86952 .46148 L
.86995 .45554 L
.87073 .44118 L
.87148 .42298 L
.8723 .39945 L
.87377 .34928 L
.87535 .29018 L
.87708 .2291 L
.87788 .20475 L
.87873 .18297 L
.87914 .1742 L
.87953 .16714 L
.87991 .16147 L
.88026 .15725 L
.88064 .15393 L
Mistroke
.88084 .15267 L
.88095 .15212 L
.88105 .1517 L
.88116 .15137 L
.88121 .15123 L
.88127 .15112 L
.88137 .151 L
.88143 .15097 L
.88148 .15097 L
.88158 .15104 L
.88167 .15118 L
.88177 .15142 L
.88188 .15176 L
.88205 .15257 L
.88224 .15374 L
.88259 .15664 L
.88299 .16139 L
.88336 .16689 L
.88416 .18256 L
.8849 .20105 L
.88657 .25394 L
.88974 .36913 L
.89055 .39564 L
.89133 .41768 L
.89208 .43546 L
.89278 .44821 L
.89314 .45327 L
.89353 .45745 L
.89375 .45926 L
.89395 .46058 L
.89414 .46143 L
.89424 .46178 L
.89434 .46201 L
.89444 .46217 L
.89454 .46223 L
.89464 .46221 L
.89473 .46211 L
.89483 .46191 L
.89489 .46175 L
.89495 .46157 L
.89516 .46067 L
.89535 .45945 L
.89557 .4577 L
.89602 .4529 L
.89643 .4469 L
.89683 .4399 L
.89757 .42361 L
.89925 .37459 L
.90231 .26549 L
.90319 .23629 L
Mistroke
.90402 .21194 L
.90483 .19214 L
.90519 .18488 L
.90558 .178 L
.90593 .17279 L
.90631 .16834 L
.90652 .16641 L
.90671 .16497 L
.9069 .16385 L
.90708 .16308 L
.90718 .1628 L
.90728 .16258 L
.90733 .1625 L
.90739 .16245 L
.90749 .16242 L
.90758 .16247 L
.90769 .16262 L
.90777 .16281 L
.90787 .1631 L
.90798 .16354 L
.90808 .16403 L
.90831 .16547 L
.90852 .16719 L
.90872 .16916 L
.9095 .18003 L
.90989 .1873 L
.91032 .19659 L
.9118 .23699 L
.91504 .3475 L
.91653 .39356 L
.91732 .41343 L
.91815 .43008 L
.91862 .43703 L
.91904 .44185 L
.91924 .44366 L
.91946 .44523 L
.91956 .44582 L
.91966 .44635 L
.91976 .44674 L
.91985 .44705 L
.91995 .44729 L
.92004 .44744 L
.92014 .44752 L
.9202 .44753 L
.92025 .44752 L
.92034 .44744 L
.92043 .44728 L
.92053 .44704 L
.92062 .44673 L
.92083 .44576 L
Mistroke
.92103 .44453 L
.92147 .44063 L
.92185 .43596 L
.92225 .42974 L
.92299 .41553 L
.92465 .37147 L
.92625 .31964 L
.92798 .2628 L
.9288 .23884 L
.92966 .21689 L
.93039 .20165 L
.93078 .19511 L
.9312 .18925 L
.93141 .18674 L
.93162 .18475 L
.9318 .18318 L
.93201 .18178 L
.9322 .18084 L
.93228 .1805 L
.93237 .18021 L
.93247 .17997 L
.93256 .17981 L
.93265 .17972 L
.93276 .17971 L
.93281 .17974 L
.93287 .17979 L
.93293 .17987 L
.93298 .17997 L
.93308 .18021 L
.93318 .18055 L
.93339 .18153 L
.93363 .18304 L
.93405 .18679 L
.93444 .19153 L
.93527 .20529 L
.93606 .2225 L
.93755 .26306 L
.94062 .35738 L
.94219 .39688 L
.94265 .40574 L
.94308 .41286 L
.94346 .41813 L
.94388 .4227 L
.94407 .42438 L
.94428 .42586 L
.94448 .42694 L
.94466 .42766 L
.94477 .42797 L
.94487 .42817 L
.94492 .42825 L
Mistroke
.94497 .42831 L
.94503 .42835 L
.94509 .42836 L
.94519 .42832 L
.94528 .42821 L
.94538 .42801 L
.94549 .42772 L
.94567 .42704 L
.94586 .42604 L
.9462 .42356 L
.9466 .41949 L
.94697 .41478 L
.94777 .40144 L
.94851 .38582 L
.95018 .34204 L
.95182 .29432 L
.95335 .25282 L
.9541 .23552 L
.95481 .22181 L
.95521 .21555 L
.95564 .20987 L
.95603 .2058 L
.95639 .20298 L
.9566 .20176 L
.9568 .20093 L
.9569 .20061 L
.95701 .20034 L
.95707 .20025 L
.95713 .20017 L
.95719 .20012 L
.95724 .20009 L
.95734 .2001 L
.95744 .20018 L
.95754 .20034 L
.95759 .20045 L
.95765 .20059 L
.95785 .20129 L
.95804 .2022 L
.95841 .20477 L
.95876 .20798 L
.95953 .21805 L
.96032 .23193 L
.96106 .24758 L
.96272 .28962 L
.96423 .33007 L
.96586 .369 L
.96675 .38574 L
.96714 .39174 L
.96757 .39727 L
.96798 .40143 L
Mistroke
.96836 .40435 L
.96857 .40555 L
.96876 .40638 L
.96887 .40674 L
.96898 .40704 L
.96904 .40714 L
.96909 .40724 L
.96919 .40735 L
.96928 .40739 L
.96938 .40738 L
.96949 .40729 L
.96958 .40714 L
.96968 .40694 L
.96976 .40671 L
.96994 .40603 L
.97014 .40504 L
.97036 .40367 L
.97075 .40042 L
.97112 .39649 L
.97152 .39145 L
.97222 .38033 L
.97526 .31247 L
.97619 .28985 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{421.375, 260.438},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13026,
  ImageCacheValid->False,
  ImageRangeCache->{{{0, 525.688}, {324.5, 0}} -> {-2.58312*^-7, -6.34248*^6, \
6.65005*^-9, 53093.5}}]
}, Closed]]
}, Open  ]],

Cell["\<\
In the animation one can clearly observe the peaks and troughs \
falling behind in the packet, which is what we should expect given that  the \
phase velocity is half the group velocity. \
\>", "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Dispersion", "Section",
  CellTags->{"i:15", "c:10"}],

Cell[TextData[{
  "\tWe now consider the spreading of the wave packet.  This spreading is a \
consequence of the dispersion in phase velocities of the separate waves \
making up this wave function. Each wave, with form ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\[ImaginaryI]\ [k\ x - \
\(\[Omega](k)\) t]\)]],
  ", travels with its own distinct phase velocity, and as a result, the \
initial condition ",
  StyleBox["disperses",
    FontSlant->"Italic"],
  " as slow waves fall behind and fast waves outpace the packet."
}], "Text"],

Cell[TextData[{
  " \t In order to understand this dispersion, it is necessary to go beyond \
the first-order Taylor expansion in Eq. ",
  ButtonBox["(5.1.26)",
    ButtonData:>"(5.1.26)",
    ButtonStyle->"Hyperlink"],
  ", and keep second",
  "-order",
  " terms as well, writing ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega](
          k) \[TildeEqual] \[Omega](
            k\_o) + \ \((k - k\_o)\) \(\(v\_g\)(
              k\_o)\) + \(\(\[Alpha]\)\(\ \)\(\((k - 
                    k\_o)\)\^2\)\(\ \)\)\)]],
  ", where the constant ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] = \(1\/2\) \(\[PartialD]\/\[PartialD]k\_o\) \
\(\(v\_g\)(k\_o)\)\)]],
  ".  [For the free-particle group velocity given by  Eq. ",
  ButtonBox["(5.1.29)",
    ButtonData:>"(5.1.29)",
    ButtonStyle->"Hyperlink"],
  ", this constant is independent of ",
  Cell[BoxData[
      \(TraditionalForm\`k\_o\)]],
  ": ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] = \[HBar]/2  m\)]],
  ".] Then  Eq. ",
  ButtonBox["(5.1.20)",
    ButtonData:>"(5.1.20)",
    ButtonStyle->"Hyperlink"],
  " becomes"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Psi](x, t)\), "\[TildeEqual]", 
          RowBox[{\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\), 
            RowBox[{\(\[DifferentialD]k\/\(2  \[Pi]\)\), 
              
              FormBox[\(\(C(
                    k)\)\ \[ExponentialE]\^\[ImaginaryI]\ [k\ x - \
\((\[Omega](k\_o) + \ \((k - k\_o)\) \(\(v\_g\)(k\_o)\) + \[Alpha]\ \((k - \
k\_o)\)\^2)\)\ t]\),
                "TraditionalForm"]}]}]}], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  "\t The wavenumber integration in this equation cannot be performed \
analytically in general, but can be for various special cases, including the \
Gaussian wave packet given by the spectrum of Eq. ",
  ButtonBox["(5.1.24)",
    ButtonData:>"(5.1.24)",
    ButtonStyle->"Hyperlink"],
  ".  The result  for this case is "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Psi](x, 
          t) \[TildeEqual] \ \ \(\[ExponentialE]\^\(\[ImaginaryI](\(k\_o\) 
                    x\  - \ \(\[Omega](
                      k\_o)\)\ t)\)\) \[ExponentialE]\^\(\(-\((x - \ \(\(v\_g\
\)(k\_o)\)\ t\ )\)\^2\)/\((2  a\^2 + 4\ I\ \[Alpha]\ t)\)\)/\@\(2 \( \
\[Pi](a\^2 + 2\ I\ \[Alpha]\ t)\)\)\)]],
  "."
}], "NumberedEquation",
  CellTags->"(5.1.30)"],

Cell["\<\
This shows that the envelope of the wave packet remains a Gaussian \
during its evolution, but the width of the Gaussian increases with time. This \
is what we observed in the previous animations.\
\>", "Text"],

Cell[TextData[{
  "\tWe define the width in the following (somewhat arbitrary) way. For a \
Gaussian of the form  ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(\(-x\^2\)/2  a\^2\)\)]],
  ", the width is defined as ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  "  (the value of ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " where the Gaussian falls to 1/2\[ExponentialE] = 0.606... of its \
maximum).  For a Gaussian of the form ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(\(-x\^2\)/2 \((A\  + \ i\ \
B)\)\)\)]],
  ", the width is defined as the  width of the envelope function. Writing the \
Gaussian as ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(\(-\(\(x\^2\)(A - \[ImaginaryI]\ \
B)\)\)/2 \((A\^2\  + \ B\^2)\)\)\)]],
  ", the envelope is the nonoscillatory part of the exponential,  ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(\(-x\^2\) A/\ 2 \((A\^2\  + \ \
B\^2)\)\)\)]],
  ". Thus, the  width ",
  Cell[BoxData[
      \(TraditionalForm\`w\)]],
  " is ",
  Cell[BoxData[
      \(TraditionalForm\`w = \@\(\((A\^2\  + \ B\^2)\)/A\)\)]],
  ". Applying this definition to Eq. ",
  ButtonBox["(5.1.30)",
    ButtonData:>"(5.1.30)",
    ButtonStyle->"Hyperlink"],
  ", we find that the width of the wave packet increases with time according \
to"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`w(
          t) = \@\(a\^2 + 4\ \(\[Alpha]\^2\) t\^2/a\^2\)\)]],
  ". "
}], "NumberedEquation",
  CellTags->{"i:16", "(5.1.31)"}],

Cell[TextData[{
  "\tThis result applies to Gaussian wave packets traveling through any \
dispersive medium, not just to solutions of Schr\[ODoubleDot]dinger's \
equation.  We will see other examples in the exercises and in future \
sections. Note that for times ",
  Cell[BoxData[
      \(TraditionalForm\`t << \ \(a\^2\)/2  \[Alpha]\)]],
  ", no spreading occurs. For these early times we can neglect dispersion and \
use Eq. ",
  ButtonBox["(5.1.27)",
    ButtonData:>"(5.1.27)",
    ButtonStyle->"Hyperlink"],
  " to describe the wave packet. "
}], "Text"],

Cell[TextData[{
  "\tThe rate of increase in the width is controlled by the parameter ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  ". For a nondispersive system, where ",
  Cell[BoxData[
      \(TraditionalForm\`v\_g = \(c = constant\)\)]],
  ", we have ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] = 0\)]],
  " and packets do not disperse. This is in line with our previous \
understanding of solutions to the wave equation on a uniform string."
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["5.1.3 Waves in Two and Three Dimensions", "Subsubtitle",
  CellTags->"c:11"],

Cell[CellGroupData[{

Cell["Schr\[ODoubleDot]dinger's Equation in Three dimensions", "Section",
  CellTags->{"i:17", "c:12"}],

Cell[TextData[{
  "When a free particle of mass ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " propagates in three dimensions, the wave function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Psi]", "(", 
          RowBox[{
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[",",
              FontWeight->"Plain"], 
            StyleBox["t",
              FontWeight->"Plain"]}], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  " of the particle is described by the Schr\[ODoubleDot]dinger equation,"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
          "\[ImaginaryI]", " ", "\[HBar]", \(\[PartialD]\/\[PartialD]t\), 
            RowBox[{"\[Psi]", "(", 
              RowBox[{
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], ",", "t"}], ")"}]}], "=", 
          RowBox[{\(-\(\[HBar]\^2\/\(2\ m\)\)\), 
            RowBox[{\(\[Del]\^2\), 
              RowBox[{"\[Psi]", "(", 
                RowBox[{
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], ",", "t"}], ")"}]}]}]}], 
        TraditionalForm]]],
  "."
}], "NumberedEquation",
  CellTags->"(5.1.32)"],

Cell["\<\
As in the previous 1-dimensional case, this equation is first \
-order in time, and must therefore be supplemented with an initial condition,\
\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"\[Psi]", "(", 
            RowBox[{
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], ",", "0"}], ")"}], "=", 
          RowBox[{\(\[Psi]\_o\), "(", 
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[")",
              FontWeight->"Plain"]}]}], TraditionalForm]]],
  "."
}], "NumberedEquation",
  CellTags->"(5.1.33)"],

Cell[TextData[{
  "The evolution of ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"\[Psi]", "(", 
            RowBox[{
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[",",
                FontWeight->"Plain"], 
              StyleBox["t",
                FontWeight->"Plain"]}], 
            StyleBox[")",
              FontWeight->"Plain"]}], " "}], TraditionalForm]]],
  "from this initial condition can again be obtained using Fourier transform \
methods. We apply three separate transforms consecutively, in ",
  Cell[BoxData[
      \(TraditionalForm\`x, y, \)]],
  "  and ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  ", defining "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\&~\)(k\_x, k\_y, k\_z, 
          t)\  = \ \
\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\[DifferentialD]x\ \
\(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \(k\_x\) 
                  x\)\) \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\
\[DifferentialD]y\ \(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \(k\_y\) 
                      y\)\) \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\
\[DifferentialD]z\ \(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \(k\_z\) 
                          z\)\) \(\[Psi](x, y, z, t)\)\)\)\)]],
  "."
}], "NumberedEquation",
  CellTags->"(5.1.34)"],

Cell["This Fourier transform can be written more compactly, as", "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          FormBox[
            RowBox[{
              RowBox[{\(\[Psi]\&~\), "(", 
                RowBox[{
                  StyleBox["k",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], ",", "t"}], ")"}], " ", 
              "=", \(\[Integral]\[DifferentialD]\^3 r\)}],
            "TraditionalForm"], " ", 
          FormBox[
            RowBox[{
              SuperscriptBox["\[ExponentialE]", 
                RowBox[{\(-\[ImaginaryI]\), " ", 
                  RowBox[{
                    StyleBox["k",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], "\[CenterDot]", 
                    StyleBox["r",
                      FontWeight->"Bold",
                      FontSlant->"Plain"]}]}]], 
              RowBox[{"\[Psi]", "(", 
                RowBox[{
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], ",", "t"}], ")"}]}],
            "TraditionalForm"]}], ","}], 
      TraditionalForm]]]], "NumberedEquation",
  CellTags->"(5.1.35)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["k",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{
            StyleBox["(",
              FontWeight->"Plain"], \(k\_x, k\_y, k\_z\), ")"}]}], 
        TraditionalForm]]],
  "is called the ",
  StyleBox["wave vector",
    FontSlant->"Italic"],
  ". Then by Fourier transforming  Eq. ",
  ButtonBox["(5.1.32)",
    ButtonData:>"(5.1.32)",
    ButtonStyle->"Hyperlink"],
  " in ",
  Cell[BoxData[
      \(TraditionalForm\`x, y\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  " we find that"
}], "Text",
  CellTags->"i:18"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
          "\[ImaginaryI]", " ", "\[HBar]", \(\[PartialD]\/\[PartialD]t\), 
            RowBox[{\(\[Psi]\&~\), "(", 
              RowBox[{
                StyleBox["k",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], ",", "t"}], ")"}]}], " ", "=", 
          RowBox[{\(\(\(\[HBar]\^2\) k\^2\)\/\(2\ m\)\), 
            RowBox[{\(\[Psi]\&~\), "(", 
              RowBox[{
                StyleBox["k",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], ",", "t"}], ")"}]}]}], 
        TraditionalForm]]],
  ","
}], "NumberedEquation",
  CellTags->"(5.1.36)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`k = \@\(k\_x\%2 + k\_y\%2 + k\_z\%2\)\)]],
  "is the magnitude of the wave vector. This equation is identical to that \
for propagation in one-dimension, and has the solution"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(\[Psi]\&~\), "(", 
            RowBox[{
              StyleBox["k",
                FontWeight->"Bold",
                FontSlant->"Plain"], ",", "t"}], ")"}], "=", 
          RowBox[{
            RowBox[{"C", "(", 
              StyleBox["k",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              ")"}], \(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \(\[Omega](
                    k)\)\ t\)\)}]}], TraditionalForm]]],
  ","
}], "NumberedEquation",
  CellTags->"(5.1.37)"],

Cell[TextData[{
  "where the constant of integration ",
  Cell[BoxData[
      FormBox[
        RowBox[{"C", "(", 
          StyleBox["k",
            FontWeight->"Bold",
            FontSlant->"Plain"], ")"}], TraditionalForm]]],
  " can depend on all three components of the wave vector, and where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega](k)\)]],
  " depends only on the magnitude of ",
  Cell[BoxData[
      FormBox[
        StyleBox["k",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  ", and is given by Eq. ",
  ButtonBox["(5.1.19)",
    ButtonData:>{"Chapter5.nb", "(5.1.19)"},
    ButtonStyle->"Hyperlink"],
  ". Taking an inverse transform in all three dimensions then yields the \
solution for ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Psi]", "(", 
          RowBox[{
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], ",", "t"}], ")"}], TraditionalForm]]],
  ":"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"\[Psi]", "(", 
          RowBox[{
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[",",
              FontWeight->"Plain"], 
            StyleBox["t",
              FontWeight->"Plain"]}], 
          StyleBox[")",
            FontWeight->"Plain"]}], "=", 
        RowBox[{"\[Integral]", 
          RowBox[{\(\[DifferentialD]\^3 k\/\((2  \[Pi])\)\^3\), " ", 
            FormBox[
              RowBox[{
                RowBox[{"C", "(", 
                  StyleBox["k",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], 
                  StyleBox[")",
                    FontWeight->"Plain"]}], " ", 
                SuperscriptBox["\[ExponentialE]", 
                  RowBox[{
                    RowBox[{"\[ImaginaryI]", " ", 
                      RowBox[{
                        StyleBox["k",
                          FontWeight->"Bold",
                          FontSlant->"Plain"], "\[CenterDot]", 
                        StyleBox["r",
                          FontWeight->"Bold",
                          FontSlant->"Plain"]}]}], 
                    "-", \(\[ImaginaryI]\ \(\[Omega](k)\)\ t\)}]]}],
              "TraditionalForm"]}]}]}], 
      TraditionalForm]]]], "NumberedEquation",
  CellTags->"(5.1.38)"],

Cell[TextData[{
  "This is a ",
  "wave packet",
  " consisting of a superposition of traveling waves, each of the form ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox["\[ExponentialE]", 
          RowBox[{
            RowBox[{"\[ImaginaryI]", " ", 
              RowBox[{
                StyleBox["k",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "\[CenterDot]", 
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"]}]}], "-", 
            RowBox[{"\[ImaginaryI]", " ", 
              RowBox[{"\[Omega]", "(", 
                StyleBox["k",
                  FontSlant->"Italic"], ")"}], " ", "t"}]}]], 
        TraditionalForm]]],
  ". A given phase \[Phi] of this wave satisfies "
}], "Text",
  CellTags->"i:19"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Phi]", "=", " ", 
          RowBox[{
            RowBox[{
              StyleBox["k",
                FontWeight->"Bold",
                FontSlant->"Plain"], "\[CenterDot]", 
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"]}], "-", " ", \(\(\[Omega](k)\)\ t\)}]}], 
        TraditionalForm]]],
  "."
}], "NumberedEquation",
  CellTags->"(5.1.39)"],

Cell[TextData[{
  "\tThe meaning of Eq. ",
  ButtonBox["(5.1.39)",
    ButtonData:>"(5.1.39)",
    ButtonStyle->"Hyperlink"],
  " can be understood by defining coordinates ",
  Cell[BoxData[
      \(TraditionalForm\`\((x\&_, y\&_, z\&_)\)\)]],
  " with the ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(z\&_\)\(\ \)\)\)]],
  "axis aligned along ",
  Cell[BoxData[
      FormBox[
        StyleBox["k",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  ".  (See Fig. ",
  ButtonBox["5.2",
    ButtonData:>"Fig. 5.2",
    ButtonStyle->"Hyperlink"],
  "). Then Eq. ",
  ButtonBox["(5.1.39)",
    ButtonData:>"(5.1.39)",
    ButtonStyle->"Hyperlink"],
  " becomes"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] = 
        k\ z\&_\  - \(\(\[Omega](k)\)\(\ \)\(t\)\(\ \)\)\)]],
  ","
}], "NumberedEquation",
  CellTags->"(5.1.40)"],

Cell[TextData[{
  "or in other words, ",
  Cell[BoxData[
      \(TraditionalForm\`z\&_ = \[Phi]/k\  + \ \(\[Omega](k)\) t/k\)]],
  ". But ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(x\&_\)\(\ \)\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y\&_\)]],
  " are not determined, and can take on any values. This implies that Eq. ",
  ButtonBox["(5.1.39)",
    ButtonData:>"(5.1.39)",
    ButtonStyle->"Hyperlink"],
  " defines a plane of constant phase that moves with speed ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\(\[Omega](k)\)/k\)\)\)]],
  " in the direction of ",
  Cell[BoxData[
      FormBox[
        StyleBox["k",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " . Therefore, the phase velocity of a wave with ",
  "wave vector",
  " ",
  Cell[BoxData[
      FormBox[
        StyleBox["k",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " is "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            SubscriptBox[
              StyleBox["v",
                FontWeight->"Bold",
                FontSlant->"Plain"], "\[Phi]"], "(", 
            StyleBox["k",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{\(\(\[Omega](k)\)\/k\), 
            StyleBox[
              OverscriptBox[
                StyleBox["k",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "^"],
              FontWeight->"Bold"]}]}], TraditionalForm]]],
  ","
}], "NumberedEquation",
  CellTags->{"i:21", "(5.1.41)"}],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          OverscriptBox[
            StyleBox["k",
              FontWeight->"Bold",
              FontSlant->"Plain"], "^"],
          FontWeight->"Bold"], TraditionalForm]]],
  " is a unit vector in the direction of ",
  Cell[BoxData[
      FormBox[
        StyleBox["k",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  ". This generalizes our previous one-dimensional result, Eq. ",
  ButtonBox["(5.1.21)",
    ButtonData:>"(5.1.21)",
    ButtonStyle->"Hyperlink"],
  ". On the other hand, a ",
  "wave packet",
  " centered at wavenumber ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["k",
            FontWeight->"Bold",
            FontSlant->"Plain"], " "}], TraditionalForm]]],
  " will move at the group velocity,"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox["v",
              FontWeight->"Bold",
              FontSlant->"Plain"], "g"], "(", 
          StyleBox["k",
            FontWeight->"Bold",
            FontSlant->"Plain"], ")"}], "=", 
        RowBox[{
          RowBox[{"(", 
            RowBox[{\(\[PartialD]\[Omega]\/\[PartialD]k\_x\), ",", 
              FormBox[\(\[PartialD]\[Omega]\/\[PartialD]k\_y\),
                "TraditionalForm"], ",", 
              FormBox[\(\[PartialD]\[Omega]\/\[PartialD]k\_z\),
                "TraditionalForm"]}], ")"}], "."}]}], 
      TraditionalForm]]]], "NumberedEquation",
  CellTags->"(5.1.42)"],

Cell[TextData[{
  "This follows from an argument that is analogous to that given previously \
for the one-dimensional case. One can write Eq. ",
  ButtonBox["(5.1.42)",
    ButtonData:>"(5.1.42)",
    ButtonStyle->"Hyperlink"],
  " more compactly as ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            SubscriptBox[
              StyleBox["v",
                FontWeight->"Bold",
                FontSlant->"Plain"], "g"], "(", 
            StyleBox["k",
              FontWeight->"Bold",
              FontSlant->"Plain"], ")"}], "=", 
          RowBox[{\(\[PartialD]\[Omega]\), "/", 
            RowBox[{"\[PartialD]", 
              StyleBox["k",
                FontWeight->"Bold",
                FontSlant->"Plain"]}]}]}], TraditionalForm]]],
  ", where ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"\[PartialD]", 
            RowBox[{"/", 
              RowBox[{"\[PartialD]", 
                StyleBox["k",
                  FontWeight->"Bold",
                  FontSlant->"Plain"]}]}]}], 
          "\[Congruent]", \((\[PartialD]\(\(/\)\(\[PartialD]k\_x\)\), \
\[PartialD]\(\(/\)\(\[PartialD]k\_y\)\), \
\[PartialD]\(\(/\)\(\[PartialD]k\_z\)\))\)}], TraditionalForm]]],
  "."
}], "Text",
  CellTags->"i:139"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000:>0003Gb000`400?l00000o`00003oo`3ooooo
0?oooi00oooo003o0?ooool0ooooT03oool00?l0ooooo`3ooon@0?ooo`00o`3ooooo0?oooi00oooo
003o0?ooool0ooooT03oool00?l0ooooo`3ooon@0?ooo`00o`3ooooo0?oooi00oooo003o0?ooool0
ooooT03oool00?l0ooooo`3ooon@0?ooo`00o`3ooooo0?oooi00oooo003o0?ooool0ooooT03oool0
0?l0ooooo`3ooon@0?ooo`00o`3ooooo0?oooi00oooo003o0?ooool0ooooT03oool00?l0ooooo`3o
oon@0?ooo`00o`3ooooo0?oooi00oooo003o0?ooool0ooooT03oool00?l0ooooo`3ooon@0?ooo`00
o`3ooooo0?oooi00oooo003o0?ooool0ooooT03oool00?l0ooooo`3ooon@0?ooo`00o`3ooooo0?oo
oi00oooo003o0?ooool0ooooT03oool00?l0ooooo`3ooon@0?ooo`00o`3ooooo0?oooi00oooo003o
0?ooool0ooooT03oool00?l0ooooo`3ooon@0?ooo`00o`3ooooo0?oooi00oooo003o0?ooool0oooo
T03oool00?l0ooooo`3ooon@0?ooo`00:@3oool20820P0L0oooo00<0`<300820P020P800o`3ooooo
0?oooe/0oooo000X0?ooo`@000001P3oool3000000030820P03oool0oooo0?l0ooooo`3ooomH0?oo
o`00:03oool00`20P80000000410@0020820P0030<30`03oool0oooo0080oooo0`0000000`30`<00
P8200?ooo`3o0?ooool0ooooF03oool002d0oooo00<000000?ooo`3oool00P3oool200000080oooo
00<000000?ooo`3oool0o`3ooooo0?oooeL0oooo000]0?ooo`040820P03oool0oooo0?ooo`<00000
0`3oool00`20P800oooo0?ooo`3o0?ooool0ooooEP3oool002h0oooo00<000000<30`03oool00`00
003o0?ooool0ooooG03oool002l0oooo00<0P8200?ooo`0000000P00003o0?ooool0ooooG03oool0
02l0oooo00@0P8200?ooo`0000000000o`3ooooo0?oooed0oooo000?0?ooo`0300000020P800oooo
01d0oooo00@0`<300000000000000000o`3ooooo0?oooed0oooo000?0?ooo`<000007P3oool30000
0?l0ooooo`3ooomM0?ooo`00403oool2000000030410@020P800oooo01/0oooo0`00003o0?ooool0
ooooG@3oool00100oooo1@00000J0?ooo`040820P0000000000000000?l0ooooo`3ooomM0?ooo`00
403oool5000000030820P03oool0oooo01L0oooo00<0P8200000000000000P00003o0?ooool0oooo
G03oool00100oooo00<0P8200000000000000`0000020820P1L0oooo00<0P8200000000000000P20
P8000`000000oooo0?ooo`3o0?ooool0ooooF@3oool00100oooo00<0P8200000000000001@000000
0`20P800oooo0?ooo`0D0?ooo`080820P000000000000820P03oool000000820P03oool200000?l0
ooooo`3ooomG0?ooo`004@3oool8000001H0oooo0`0000030?ooo`@00000o`3ooooo0?oooeL0oooo
000A0?ooo`T0000000<0@4100?ooo`3oool03`3oool30820P080000000D0P8200?ooo`3oool0oooo
0<30`002000000030820P03oool0oooo0?l0ooooo`3ooomE0?ooo`004P3oool:00000?l0ooooo`3o
oomd0?ooo`004P3oool;000000030410@03oool0oooo0?l0ooooo`3ooom`0?ooo`004P3oool=0000
0?l0ooooo`3oooma0?ooo`004P3oool00`20P80000000000000;00000?l0ooooo`3ooom`0?ooo`00
4P3oool00`20P80000000000000<000000030820P03oool0oooo0?l0ooooo`3ooom/0?ooo`004P3o
ool00`20P80000000000000=000000030820P03oool0oooo0?l0ooooo`3ooom[0?ooo`004`3ooolA
000000030820P03oool0oooo0?l0ooooo`3ooomY0?ooo`004`3ooolB000000030820P03oool0oooo
0?l0ooooo`3ooomX0?ooo`004`3ooolD00000?l0ooooo`3ooomY0?ooo`00503ooolC000000030410
@03oool0oooo0?l0ooooo`3ooomV0?ooo`00503ooolE00000?l0ooooo`3ooomW0?ooo`00503ooolF
000000030820P03oool0oooo0?l0ooooo`3ooomS0?ooo`005@3ooolE000000030410@03oool0oooo
0?l0ooooo`3ooomS0?ooo`005@3ooolE00000?l0ooooo`3ooomV0?ooo`005@3oool00`10@4000000
0000000A000000030820P03oool0oooo0?l0ooooo`3ooomT0?ooo`005@3oool00`20P80000000000
000@00000?l0ooooo`3ooomX0?ooo`005@3oool00`20P80000000000000?000000030820P03oool0
oooo0?l0ooooo`3ooomV0?ooo`005@3oool00`30`<0000000000000>000000030820P03oool0oooo
0?l0ooooo`3ooomW0?ooo`005P3oool?000000030820P03oool0oooo0?l0ooooo`3ooomX0?ooo`00
5P3oool?00000?l0ooooo`3ooom[0?ooo`005P3oool00`20P80000000000000<000000030<30`03o
ool0oooo0?l0ooooo`3ooomX0?ooo`005`3oool>000000030820P03oool0oooo0?l0ooooo`3ooomX
0?ooo`005`3oool00`20P80000000000000400000080P82000<0`<300?ooo`20P8000`0000000`20
P800oooo0?ooo`3o0?ooool0ooooI`3oool001P0oooo100000070?ooo`@00000o`3ooooo0?ooofT0
oooo000T0?ooo`<0000000<0P8200?ooo`3oool0o`3ooooo0?ooofH0oooo000T0?ooo`040820P000
0000000000000?l0ooooo`3ooomX0?ooo`009@3oool01020P800000000000000003o0?ooool0oooo
I`3oool002D0oooo00<0P8200000000000000P00003o0?ooool0ooooIP3oool002H0oooo00D0P820
00000000000000000<30`03o0?ooool0ooooI@3oool002L0oooo0`0000000`20P800oooo0?ooo`3o
0?ooool0ooooH`3oool002L0oooo00D0P82000000000000000000820P03o0?ooool0ooooI03oool0
02P0oooo1000003o0?ooool0ooooI03oool002T0oooo1000003o0?ooool0ooooH`3oool002T0oooo
00D0P82000000000000000000820P03o0?ooool0ooooHP3oool002X0oooo00@0P820000000000000
0000o`3ooooo0?ooof80oooo000Z0?ooo`030<30`0000000000000800000o`3ooooo0?ooof40oooo
000/0?ooo`<0000000<0P8200?ooo`3oool0o`3ooooo0?oooeh0oooo000/0?ooo`@00000o`3ooooo
0?ooof00oooo000]0?ooo`040410@000000000000820P?l0ooooo`3ooomO0?ooo`00;@3oool00`20
P800000000000002000008H0oooo0P00003o0?ooomD0oooo000^0?ooo`@00000Q@3oool400000?l0
ooooe03oool002l0oooo0`0000000`10@400oooo0?ooo`220?ooo`<0P82000<0oooo0820P020P800
o`3ooooB0?ooo`00;`3oool01020P800000000000000002:0?ooo`030820P03oool0oooo0?l0oooo
c`3oool00300oooo100000000`20P800oooo0?ooo`260?ooo`80P820o`3oooo@0?ooo`00<@3oool4
000008T0oooo00<000000?ooo`3oool0o`3oooo>0?ooo`00<P3oool3000000030820P03oool0oooo
08L0oooo00<000000?ooo`3oool0o`3oooo=0?ooo`00<P3oool01010@40000000000000000290?oo
o`0300000020P800oooo0?l0ooooc@3oool003<0oooo100000280?ooo`800000o`3oooo>0?ooo`00
<`3oool4000000030820P03oool0oooo08D0oooo0`00003o0?ooold0oooo000d0?ooo`040820P000
000000000410@5H0oooo00<0`<300820P030`<00;P3oool3000000030<30`03oool0oooo0?l0oooo
bP3oool003D0oooo1000001E0?ooo`@00000;03oool3000000030?ooo`20P800oooo0?l0oooob`3o
ool003D0oooo00D0`<3000000000000000000820P01D0?ooo`H000000P20P8000`30`<00oooo0?oo
o`0U0?ooo`<0000000<0oooo0820P03oool0o`3oooo;0?ooo`00=P3oool4000000030820P03oool0
oooo0500oooo2`0000000`20P800oooo0?ooo`0S0?ooo`<0000000<0oooo0820P0000000o`3oooo;
0?ooo`00=`3oool3000000030820P03oool0oooo0500oooo3@00000T0?ooo`<000000P3oool00`00
0000oooo0?ooo`3o0?ooolT0oooo000g0?ooo`050820P0000000000000000020P800D@3oool?0000
0080P82000<0`<300?ooo`3oool0703oool01020P800000000000010@4020?ooo`030820P0000000
oooo0?l0oooob@3oool003P0oooo1000001A0?oooa<000007@3oool01020P800000000000020P803
0?ooo`0300000020P800oooo0?l0oooob03oool003T0oooo0`0000000`10@400oooo0?ooo`1=0?oo
oaH000000`20P80H0?ooo`040410@000000000000<30`0@0oooo00<0P8200?ooo`3oool0o`3oooo7
0?ooo`00>P3oool3000004l0oooo6`00000F0?ooo`<000001@3oool00`000000oooo0?ooo`3o0?oo
olL0oooo000j0?ooo`040820P00000000000000004h0oooo700000000`20P800oooo0?ooo`0B0?oo
o`<000001@3oool00`20P800oooo0?ooo`3o0?ooolL0oooo000j0?ooo`030<30`000000000000080
000000<0`<300820P020P800BP20P80O000000030820P03oool0oooo00h0oooo00@0P82000000000
0000P8201@3oool20820P?l0oooob03oool003`0ooooL`00000=0?ooo`<000001P3oool200000?l0
oooob03oool003`0ooooM000000;0?ooo`@000001@3oool300000?l0oooob03oool003`0oooo00<0
`<30000000000000K00000000`10@400P8200<30`00:0?ooo`030<30`020P800P82000<000001@3o
ool400000?l0oooob03oool003d0oooo1000001;0?oooad000004@3oool01020P800000000000000
00060?ooo`800000o`3oooo90?ooo`00?P3oool3000004/0oooo6@0000000`10@400P8200820P03o
0?ooonL0oooo000n0?ooo`<00000B`3ooolG000000030820P03oool0oooo0?l0ooooj@3oool003h0
oooo0`00001;0?oooaD00000o`3oooo^0?ooo`00?P3oool3000004`0oooo400000020820P?l0oooo
l03oool003h0oooo0`00001<0?ooo`h00000o`3ooood0?ooo`00?P3oool3000004`0oooo2`000000
0`20P800oooo0?ooo`3o0?oooo@0oooo000n0?ooo`<00000C@3oool700000080P820o`3ooooh0?oo
o`00?P3oool3000004d0oooo00<0P8200000000000000P00003o0?oooo`0oooo000n0?ooo`<00000
C@3oool00`30`<00P8200<30`03o0?ooooh0oooo000n0?ooo`<00000o`3ooooo0?ooodl0oooo000n
0?ooo`<00000o`3ooooo0?ooodl0oooo000n0?ooo`<00000o`3ooooo0?ooodl0oooo000n0?ooo`<0
0000o`3ooooo0?ooodl0oooo000n0?ooo`<00000o`3ooooo0?ooodl0oooo000n0?ooo`<00000o`3o
oooo0?ooodl0oooo000n0?ooo`<00000o`3ooooo0?ooodl0oooo000n0?ooo`<00000o`3ooooo0?oo
odl0oooo000n0?ooo`<00000o`3ooooo0?ooodl0oooo000n0?ooo`<00000o`3ooooo0?ooodl0oooo
000n0?ooo`<00000o`3ooooo0?ooodl0oooo000n0?ooo`<00000o`3ooooo0?ooodl0oooo000n0?oo
o`<00000o`3ooooo0?ooodl0oooo000n0?ooo`<00000o`3ooooo0?ooodl0oooo000n0?ooo`<00000
o`3ooooo0?ooodl0oooo000n0?ooo`<00000o`3ooooo0?ooodl0oooo000n0?ooo`<00000o`3ooooo
0?ooodl0oooo000n0?ooo`<00000o`3ooooo0?ooodl0oooo000n0?ooo`<00000o`3ooooo0?ooodl0
oooo000n0?ooo`<00000o`3ooooo0?ooodl0oooo000n0?ooo`<00000o`3ooooo0?ooodl0oooo000n
0?ooo`<00000o`3ooooo0?ooodl0oooo000n0?ooo`<00000o`3ooooo0?ooodl0oooo000n0?ooo`<0
0000o`3ooooo0?ooodl0oooo000n0?ooo`<00000o`3ooooo0?ooodl0oooo000n0?ooo`<00000o`3o
oooo0?ooodl0oooo000n0?ooo`<00000o`3ooooo0?ooodl0oooo000n0?ooo`<00000o`3ooooo0?oo
odl0oooo000n0?ooo`<00000o`3ooooo0?ooodl0oooo000n0?ooo`<00000o`3ooooo0?ooodl0oooo
000n0?ooo`<00000o`3ooooo0?ooodl0oooo000n0?ooo`<00000o`3ooooo0?ooodl0oooo000n0?oo
o`<00000o`3ooooo0?ooodl0oooo000n0?ooo`<00000o`3ooooo0?ooodl0oooo000n0?ooo`<00000
o`3ooooo0?ooodl0oooo000n0?ooo`<00000o`3ooooo0?ooodl0oooo000n0?ooo`<00000o`3ooooo
0?ooodl0oooo000n0?ooo`<00000o`3ooooo0?ooodl0oooo000n0?ooo`<00000o`3ooooo0?ooodl0
oooo000n0?ooo`<00000o`3ooooo0?ooodl0oooo000n0?ooo`<00000o`3ooooo0?ooodl0oooo000n
0?ooo`<00000o`3ooooo0?ooodl0oooo000n0?ooo`<00000o`3ooooo0?ooodl0oooo000n0?ooo`<0
0000o`3ooooo0?ooodl0oooo000n0?ooo`<00000o`3ooooo0?ooodl0oooo000n0?ooo`<00000o`3o
oooo0?ooodl0oooo000n0?ooo`<00000o`3ooooo0?ooodl0oooo000n0?ooo`<00000o`3ooooo0?oo
odl0oooo000n0?ooo`<00000o`3ooooo0?ooodl0oooo000n0?ooo`<00000o`3ooooo0?ooodl0oooo
000n0?ooo`<00000o`3ooooo0?ooodl0oooo000n0?ooo`<00000o`3ooooo0?ooodl0oooo000n0?oo
o`<00000o`3ooooo0?ooodl0oooo000n0?ooo`<00000o`3oooo;0?ooo`030000003oool0oooo0800
oooo000n0?ooo`<00000o`3oooo:0?ooo`030820P0000000oooo0840oooo000n0?ooo`<00000o`3o
ooo:0?ooo`<00000P@3oool003h0oooo0`00003o0?ooolT0oooo100000000`20P800oooo0?ooo`1n
0?ooo`00?P3oool300000?l0oooob03oool00`20P800000000000002000000030820P03oool0oooo
07h0oooo000n0?ooo`<00000o`3oooo80?ooo`H00000P03oool003h0oooo0`00003o0?ooolL0oooo
1`0000200?ooo`00?P3oool300000?l0ooooaP3oool01P20P8000000000000000000`<300820P080
000000<0P8200?ooo`3oool0O@3oool003h0oooo0`00003o0?ooolH0oooo0`0000030?ooo`@00000
OP3oool003h0oooo0`00003o0?ooolD0oooo00@0P8200000000000000000103oool3000007h0oooo
000n0?ooo`<00000o`3oooo50?ooo`<0000000<0`<300?ooo`3oool00P3oool01010@40000000000
0020P81m0?ooo`00?P3oool300000?l0ooooa03oool3000000H0oooo00@0P8200000000000000000
O@3oool003H0oooo0P20P80?00000080P820o`3ooonj0?ooo`050<30`0000000000000000020P800
1P3oool01030`<00000000000000001m0?ooo`00=@3ooolF00000?l0oooo^03oool01020P8000000
0000000000080?ooo`@00000O03oool003@0oooo5`00003o0?oookP0oooo0`0000000`20P800oooo
0?ooo`060?ooo`@00000O03oool003D0oooo5P00003o0?oookL0oooo1000000:0?ooo`<0000000<0
`<300?ooo`3oool0N@3oool003D0oooo5@0000000`20P800oooo0?ooo`3o0?oook@0oooo00@0P820
0000000000000000303oool2000000030820P03oool0oooo07T0oooo000e0?ooo`030820P0000000
00000180000000<0P8200?ooo`3oool0o`3ooonc0?ooo`040820P00000000000000000d0oooo00<0
@410000000000000N`3oool003D0oooo00<0P8200000000000004P0000000`20P800oooo0?ooo`3o
0?oook<0oooo0`0000000`20P800oooo0?ooo`0;0?ooo`040820P00000000000000007X0oooo000f
0?oooa@00000o`3ooone0?ooo`@000003`3oool3000007X0oooo000f0?oooa@00000o`3ooond0?oo
o`050820P0000000000000000020P8003`3oool01020P800000000000000001i0?ooo`00=`3ooolB
00000?l0oooo]@3oool3000000030820P03oool0oooo00l0oooo0`0000000`20P800oooo0?ooo`1f
0?ooo`00=`3ooolB00000?l0oooo]03oool400000180oooo00@0P820000000000000P820N03oool0
03L0oooo00<0@4100000000000003P0000000`20P800oooo0?ooo`3o0?oook40oooo00D0`<300000
0000000000000820P00B0?ooo`040<30`00000000000000007P0oooo000g0?ooo`030820P0000000
000000h00000o`3ooond0?ooo`<000005@3oool4000007L0oooo000g0?ooo`030<30`00000000000
00d0000000<0P8200?ooo`3oool0o`3ooona0?ooo`040820P000000000000820P1H0oooo0`000000
0`30`<00oooo0?ooo`1d0?ooo`00>03oool?000000030820P03oool0oooo0?l0oooo/03oool40000
01P0oooo0P0000000`20P800oooo0?ooo`1d0?ooo`00>03oool?00000?l0oooo/`3oool3000001T0
oooo0`00001f0?ooo`00>@3oool=000000030820P03oool0oooo0?l0oooo/03oool01010@4000000
00000010@40I0?ooo`030820P0000000000007H0oooo000i0?ooo`d00000o`3ooonc0?ooo`<00000
6`3oool3000007D0oooo000j0?ooo``00000o`3ooonb0?ooo`<00000703oool3000007D0oooo000j
0?ooo`030410@0000000000000P00000o`3ooonb0?ooo`<0000000<0P8200?ooo`3oool06`3oool3
000007@0oooo000j0?ooo`030820P0000000000000L0000000<0P8200?ooo`3oool0o`3ooon_0?oo
o`040820P00000000000000001h0oooo0`0000000`20P800oooo0?ooo`1a0?ooo`00:03oool40820
P0h0oooo00<0`<300000000000001`0000000`20P800oooo0?ooo`3o0?ooojl0oooo0`0000000`30
`<00oooo0?ooo`0L0?ooo`040820P000000000000410@7<0oooo000W0?ooo`8000000`3oool00`00
0000oooo0?ooo`0<0?ooo`T00000o`3ooona0?ooo`@00000803oool3000007<0oooo000U0?ooo`03
0820P0000000000000<0oooo0P0000000`20P800oooo0?ooo`0;0?ooo`T00000o`3ooon`0?ooo`04
0820P0000000000000000240oooo1000001b0?ooo`008@3oool30820P0<0000000@0`<300?ooo`3o
ool0P8200P0000000`20P800oooo0?ooo`0<0?ooo`L0000000<0P8200?ooo`3oool0o`3ooon^0?oo
o`030410@0000000000002<0oooo0`0000000`20P800oooo0?ooo`1_0?ooo`008P3oool4000001H0
oooo1`00003o0?oook00oooo0`0000000`20P800oooo0?ooo`0R0?ooo`<00000L@3oool00280oooo
00@0P820000000000000P8205P3oool00`20P800000000000003000000030820P03oool0oooo0?l0
oooo[@3oool4000002D0oooo0`0000000`20P800oooo0?ooo`1^0?ooo`008`3oool20820P1L0oooo
00<0P8200000000000000`0000000`20P800oooo0?ooo`3o0?oooj`0oooo00D0`<30000000000000
00000820P00U0?ooo`040410@000000000000410@700oooo000T0?ooo`030000003oool0oooo01H0
oooo1@00003o0?ooojl0oooo1000000V0?ooo`040820P0000000000000000700oooo000U0?ooo`03
0820P03oool0oooo01D0oooo1@00003o0?ooojh0oooo00D0P82000000000000000000<30`00W0?oo
o`<0000000<0P8200?ooo`3oool0K@3oool002H0oooo00<000000?ooo`3oool05@3oool300000?l0
oooo[P3oool5000002P0oooo1000001_0?ooo`009P3oool00`000000oooo0?ooo`0E0?ooo`<00000
o`3ooon^0?ooo`@00000:P3oool3000000030820P03oool0oooo06`0oooo000W0?ooo`030820P03o
ool0oooo01@0oooo00<0P820000000000000o`3ooon]0?ooo`040410@00000000000000002/0oooo
00@0P820000000000000@410KP3oool002P0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`3o0?oooj`0oooo0`0000000`20P800oooo0?ooo`0Z0?ooo`<00000KP3oool002T0oooo00<0
00000?ooo`3oool04`3oool00`10@400oooo0?ooo`1L0?ooo`030820P03oool0oooo0?l0ooooB`3o
ool00`30`<00000000000002000002d0oooo00@0P8200000000000000000K@3oool002X0oooo00<0
P8200?ooo`3oool0L03oool00`000000P8200?ooo`3o0?oood`0oooo00@0P8200000000000000000
;`3oool4000006`0oooo000S0?ooo`8000001@3oool00`20P800oooo0?ooo`1_0?ooo`80000000<0
P8200?ooo`3oool0o`3ooom;0?ooo`<00000<03oool4000006`0oooo000S0?ooo`030820P0000000
`<3000D0oooo00<000000?ooo`3oool0K03oool01@20P8000000000000000000`<300?l0ooooC03o
ool3000000030410@03oool0oooo02l0oooo0`0000000`20P800oooo0?ooo`1Y0?ooo`00903oool9
000006/0oooo00<0P8200000000000000`0000040?ooo`800000o`3ooom60?ooo`@00000<P3oool0
1020P800000000000000001[0?ooo`00903oool9000000030820P03oool0oooo06L0oooo1`000003
0?ooo`@0000000<0P8200?ooo`3oool0o`3ooom10?ooo`030820P0000000000000800000<P3oool0
1020P800000000000000001[0?ooo`00903oool:0820P6L0oooo00<0P8200410@00000001@000004
0?ooo`<0P82000<0oooo0<30`020P800o`3ooom20?ooo`<0000000<0@4100?ooo`3oool0<P3oool3
000000030820P03oool0oooo06P0oooo002D0?ooo`T000002P3oool00`000000oooo0?ooo`3o0?oo
och0oooo1000000e0?ooo`@00000JP3oool00980oooo00<0P8200410@00000001`00000<0?ooo`03
0410@03oool0oooo0?l0oooo?03oool01@20P8000000000000000000P82003H0oooo1000001Y0?oo
o`00T03oool00`20P800000000000009000000`0oooo00<0P8200?ooo`3oool0o`3oooll0?ooo`<0
0000>@3oool3000000030820P03oool0oooo06H0oooo002@0?ooo`/0000000<0P8200?ooo`3oool0
2`3oool00`000000oooo0?ooo`3o0?ooocX0oooo1000000i0?ooo`<0000000<0P8200?ooo`3oool0
IP3oool008d0oooo00<0P8200410@00000002`0000000`20P800oooo0?ooo`0;0?ooo`800000o`3o
oolj0?ooo`050820P0000000000000000030`<00>@3oool01020P800000000000000001X0?ooo`00
R`3oool00`20P80000000000000=000000h0oooo0P0000000`20P800oooo0?ooo`3o0?ooocH0oooo
00<0P8200000000000000P00000k0?ooo`@00000I`3oool008/0oooo4000000>0?ooo`<00000o`3o
oolh0?ooo`040820P00000000000000003`0oooo1000001W0?ooo`00R03oool00`20P800@4100000
000?000000030820P03oool0oooo00`0oooo0`0000000`20P800oooo0?ooo`3o0?oooc@0oooo00D0
P82000000000000000000820P00m0?ooo`<0000000<0`<300?ooo`3oool0I03oool008L0oooo4`00
000>0?ooo`050820P000000000000820P0000000o`3ooolf0?ooo`@00000?P3oool3000000030820
P03oool0oooo06@0oooo00250?ooo`030820P000000000000140000000<0P8200?ooo`3oool0303o
ool01P20P800000000000020P800oooo0820P?l0oooo<`3oool00`30`<0000000000000200000400
oooo0`00001V0?ooo`00P`3oool00`20P80000000000000C000000l0oooo00H0P820000000000000
P8200?ooo`00003o0?oooc<0oooo00@0P8200000000000000000@@3oool01020P800000000000000
001U0?ooo`00P`3ooolF000000l0oooo00H0P820000000000000P8200?ooo`20P83o0?oooc<0oooo
0`0000000`20P800oooo0?ooo`0o0?ooo`040820P00000000000000006D0oooo00210?ooo`030820
P0000000000001@0000000<0P8200?ooo`3oool03@3oool3000000040<30`03oool0`<3000000?l0
oooo<@3oool4000000030<30`03oool0oooo0400oooo1000001T0?ooo`00P@3oool00`20P8000000
0000000D00000100oooo0`0000030?ooo`800000o`3oool_0?ooo`040820P00000000000000004D0
oooo0`0000000`20P800oooo0?ooo`1Q0?ooo`00P@3oool00`30`<0000000000000D000000l0oooo
00@0P820000000000000P820103oool00`000000oooo0?ooo`3o0?ooobd0oooo0`0000000`20P800
oooo0?ooo`130?ooo`040410@000000000000820P6<0oooo00230?oooa@00000403oool3000000D0
oooo00<000000820P03oool0o`3oool/0?ooo`<0000000<0P8200?ooo`3oool0A03oool01020P800
000000000000001S0?ooo`00P`3ooolD00000100oooo0`0000060?ooo`030820P03oool0oooo0?l0
oooo:P3oool4000000030820P03oool0oooo04@0oooo00@0P8200000000000000000H`3oool008<0
oooo00<0`<30000000000000400000000`10@400oooo0?ooo`0=0?ooo`040820P000000000000820
P0H0oooo00<0@4100?ooo`3oool0o`3ooolY0?ooo`050820P0000000000000000020P800B03oool4
00000680oooo00250?oooa40000000<0P8200?ooo`3oool03@3oool3000000H0oooo0P00003o0?oo
ob/0oooo0`0000000`20P800oooo0?ooo`180?ooo`<0000000<0P8200?ooo`3oool0G`3oool008H0
oooo400000000`20P800oooo0?ooo`0<0?ooo`040820P00000000000000000D0oooo0`00003o0?oo
obX0oooo100000000`20P800oooo0?ooo`180?ooo`<0000000<0P8200?ooo`3oool0G`3oool008H0
oooo00<0`<300000000000003@00000=0?ooo`80P82000@0@410000000000000P820103oool01020
P800000000000000003o0?ooobT0oooo00D0P82000000000000000000820P01<0?ooo`<00000H@3o
ool008L0oooo3`00000?0?ooo`<0000000<0P8200?ooo`3oool00`3oool2000000030820P03oool0
oooo0?l0oooo9P3oool00`20P800000000000002000004d0oooo00@0P8200000000000000000H03o
ool008H0oooo00<0@4100000000000003000003o0?oood@0oooo00@0@410000000000000@410CP3o
ool01030`<00000000000000001P0?ooo`00QP3oool3000000030820P03oool0P82000T00000o`3o
oom30?ooo`@0000000<0P8200?ooo`3oool0C@3oool4000005l0oooo00250?ooo`@000000`3oool8
00000?l0ooooA03oool400000540oooo0`00001O0?ooo`00P`3oool01@30`<000000000000000000
P82000H0oooo00<0P8200000000000000`00000@0?ooo`d00000o`3ooolV0?ooo`040410@0000000
000000000580oooo00@0@410000000000000P820GP3oool008<0oooo1000000:0?ooo`80000000<0
P8200?ooo`3oool03P3oool=00000?l0oooo9P3oool3000005<0oooo00@0P8200000000000000000
GP3oool008<0oooo0`0000000`20P800oooo0?ooo`0:0?ooo`030820P03oool0oooo00h0oooo3@00
003o0?ooobD0oooo0`0000000`20P800oooo0?ooo`1B0?ooo`<00000GP3oool00840oooo00D0`<30
00000000000000000820P03o0?ooodl0oooo100000000`30`<00oooo0?ooo`1B0?ooo`040820P000
000000000820P5d0oooo00210?ooo`@00000o`3ooom?0?ooo`040820P00000000000000005L0oooo
0`00001M0?ooo`00P03oool01020P800000000000010@43o0?oooe00oooo0`0000000`10@400oooo
0?ooo`1F0?ooo`<00000G03oool007l0oooo1000003o0?oooe00oooo1000001I0?ooo`040820P000
000000000820P5/0oooo001n0?ooo`040820P0000000000000000?l0ooooD03oool00`20P8000000
00000002000005T0oooo00@0P820000000000000P820F`3oool007h0oooo00@0@410000000000000
@410o`3ooom@0?ooo`040410@000000000000820P5X0oooo00@0`<300000000000000000F`3oool0
07d0oooo1000003o0?oooe00oooo1000001L0?ooo`@00000FP3oool007`0oooo1000003o0?oooe00
oooo100000000`20P800oooo0?ooo`1K0?ooo`<00000FP3oool007/0oooo00D0P820000000000000
00000820P03o0?ooodl0oooo00D0`<3000000000000000000820P01N0?ooo`040820P00000000000
0820P5T0oooo001k0?ooo`<0000000<0P8200?ooo`3oool0o`3ooom>0?ooo`@00000H03oool30000
05T0oooo001i0?ooo`050<30`0000000000000000020P800o`3ooom@0?ooo`050820P00000000000
00000030`<00H03oool01020P800000000000020P81H0?ooo`00N@3oool01020P800000000000000
003o0?oooe00oooo1@00001R0?ooo`<00000F03oool007T0oooo0`00003o0?oooe40oooo1000001S
0?ooo`<00000F03oool007L0oooo00D0P82000000000000000000<30`03o0?oooe00oooo00@0@410
0000000000000000I03oool01020P800000000000000001G0?ooo`00M`3oool400000?l0ooooD@3o
ool3000000030820P03oool0oooo06<0oooo0`0000000`20P800oooo0?ooo`1D0?ooo`00MP3oool0
1010@400000000000010@43o0?oooe00oooo00<0`<300000000000000P00001V0?ooo`040820P000
000000000410@5H0oooo001e0?ooo`@00000o`3ooomA0?ooo`040820P00000000000000006P0oooo
0`00001F0?ooo`00M03oool01020P800000000000000003o0?oooe80oooo0`00001Y0?ooo`@00000
E@3oool007@0oooo00@0@410000000000000P820o`3ooomA0?ooo`<0000000<0@4100?ooo`3oool0
I`3oool01@20P8000000000000000000P82005@0oooo001c0?ooo`<0000000<0P8200?ooo`3oool0
o`3ooom?0?ooo`@00000J`3oool4000005@0oooo001b0?ooo`@00000o`3ooomA0?ooo`030820P000
0000000000800000K03oool3000005@0oooo001a0?ooo`050<30`0000000000000000020P800o`3o
oomA0?ooo`040410@000000000000410@6d0oooo0`0000000`20P800oooo0?ooo`1A0?ooo`00L@3o
ool3000000030820P03oool0oooo0?l0ooooC`3oool4000000030820P03oool0oooo06/0oooo00@0
P8200000000000000000D`3oool00700oooo0`0000000`20P800oooo0?ooo`3o0?ooodl0oooo00D0
P82000000000000000000820P01^0?ooo`050<30`0000000000000000020P800DP3oool006l0oooo
1000003o0?oooe40oooo00<0P8200000000000000P00001`0?ooo`@00000DP3oool006h0oooo00@0
P8200000000000000000o`3ooomB0?ooo`040820P0000000000000000780oooo0`00001B0?ooo`00
K@3oool01@20P8000000000000000000`<300?l0ooooD@3oool01@20P8000000000000000000P820
0780oooo00@0P820000000000000P820D@3oool006d0oooo1000003o0?oooe80oooo1000001d0?oo
o`<00000D@3oool006`0oooo00@0P8200000000000000000o`3ooomB0?ooo`040820P00000000000
000007D0oooo00<0P820000000000000D@3oool006/0oooo00@0P820000000000000@410o`3ooomC
0?ooo`<0000000<0P8200?ooo`3oool0L`3oool01030`<00000000000020P81@0?ooo`00J`3oool3
00000?l0ooooD`3oool3000000030820P03oool0oooo07D0oooo0`00001@0?ooo`004@3ooolT0820
P3@0oooo00D0`<3000000000000000000820P03o0?oooe80oooo1000001i0?ooo`<00000C`3oool0
0180oooo8`00000d0?ooo`<0000000<0P8200?ooo`3oool0o`3ooom@0?ooo`040820P00000000000
000007X0oooo00@0P820000000000000P820CP3oool00180oooo00<0P8200000000000008000000d
0?ooo`<00000o`3ooomC0?ooo`<0000000<0P8200?ooo`3oool0N03oool01020P800000000000020
P81>0?ooo`00503oool00`20P80000000000000N00000380oooo00D0P82000000000000000000820
P03o0?oooe80oooo00D0P82000000000000000000<30`01k0?ooo`<00000CP3oool001D0oooo00<0
P8200000000000007@00000a0?ooo`040820P0000000000000000?l0ooooD`3oool01020P8000000
00000000001n0?ooo`<00000C@3oool001L0oooo7P00000a0?ooo`<0000000<0P8200?ooo`3oool0
o`3ooomA0?ooo`040820P00000000000000007h0oooo0`00001=0?ooo`00603oool00`10@4000000
0000000I000000030820P03oool0oooo02h0oooo00@0P8200000000000000000o`3ooomC0?ooo`04
0820P000000000000410@800oooo0P0000000`20P800oooo0?ooo`1:0?ooo`006@3ooolK00000300
oooo00@0P8200000000000000000o`3ooomD0?ooo`<0000000<0P8200?ooo`3oool0OP3oool30000
04`0oooo000J0?ooo`030820P0000000000001L00000<03oool2000000030410@03oool0oooo0?l0
ooooD@3oool01@30`<000000000000000000P8200840oooo00@0P820000000000000P820B`3oool0
01`0oooo6000000_0?ooo`<0000000<0P8200?ooo`3oool0o`3ooomA0?ooo`040820P00000000000
000008<0oooo0`00001;0?ooo`007@3ooolF000002l0oooo1000003o0?oooe@0oooo0`0000000`20
P800oooo0?ooo`210?ooo`@00000BP3oool001d0oooo00<0`<300820P00000005@0000020820P2X0
oooo00@0P820000000000000@410o`3ooomD0?ooo`@00000Q@3oool3000000030<30`03oool0oooo
04L0oooo000P0?oooaX000009`3oool300000?l0ooooE03oool4000008H0oooo00@0P82000000000
0000P820B@3oool00240oooo00<0P8200000000000003P0000000`10@400P8200000000700000080
P8208@3oool01@30`<000000000000000000P8200?l0ooooD`3oool01020P8000000000000000027
0?ooo`040<30`00000000000000004T0oooo000R0?ooo`030820P0000000000000d0000000@0P820
0?ooo`3oool0oooo2P00000O0?ooo`<00000o`3ooomE0?ooo`<0000000<0P8200?ooo`3oool0QP3o
ool4000004P0oooo000S0?ooo`l0000000<0P8200?ooo`3oool0103oool9000000030820P03oool0
oooo01X0oooo0P0000000`20P800oooo0?ooo`3o0?oooe80oooo1000002:0?ooo`<00000B03oool0
02D0oooo00<0@4100000000000002P0000000`30`<00oooo0?ooo`060?ooo`80P820200000020820
P0030<30`03oool0oooo01<0oooo00D0P82000000000000000000<30`03o0?oooe<0oooo00@0`<30
0000000000000000R`3oool01020P800000000000020P8170?ooo`009P3oool;000000h0oooo00<0
P8200000000000002000000B0?ooo`040820P0000000000000000?l0ooooE@3oool3000008d0oooo
0`0000170?ooo`009`3oool00`20P80000000000000700000140oooo2P00000@0?ooo`040820P000
000000000820P?l0ooooE@3oool2000000030820P03oool0oooo08/0oooo00@0P820000000000000
P820AP3oool002P0oooo0P20P805000000030410@03oool0oooo0180oooo00<0`<300820P020P800
200000020820P0X0oooo00@0P8200000000000000000o`3ooomD0?ooo`050820P000000000000000
0030`<00S@3oool01030`<00000000000020P8160?ooo`00:P3oool00`20P8000000000000020000
00030820P03oool0oooo01L0oooo2P0000070?ooo`@00000o`3ooomE0?ooo`<00000T03oool30000
04H0oooo000[0?ooo`80P82000<000000820P03oool06`3oool30820P0L000000`20P8001@3oool0
`<30000000000000@4100?l0ooooE@3oool01010@400000000000010@42A0?ooo`80000000<0P820
0?ooo`3oool0@`3oool00500oooo300000000`20P800oooo0?ooo`3o0?oooe<0oooo0`00002B0?oo
o`<00000A@3oool00100oooo0P0000070?ooo`800000=`3oool;00000?l0ooooE03oool4000009<0
oooo0P0000000`20P800oooo0?ooo`120?ooo`003`3oool3000000030410@03oool0oooo00<0oooo
00<0P8200000000000000P20P80g0?ooo`040<30`020P800P8200410@0H0000000<0P8200?ooo`3o
ool0o`3ooom?0?ooo`<0000000<0P8200?ooo`3oool0TP3oool2000000030410@03oool0oooo0480
oooo000@0?ooo`040000003oool0oooo000000@0oooo00<0P8200000000000000P3oool00`20P800
oooo0?ooo`0i0?ooo`030820P0000000000000<0000000<0P8200?ooo`3oool0o`3ooom=0?ooo`04
0820P00000000000000009D0oooo00<0P820000000000000A03oool001<0oooo0P0000030?ooo`03
0820P0000000P8200080oooo00<0P8200?ooo`3oool0>`3oool600000?l0ooooCP3oool300000003
0820P03oool0oooo09<0oooo00@0P8200000000000000000@`3oool001@0oooo00@0P8200<30`03o
ool0oooo0P0000001020P800oooo0?ooo`30`<0n0?ooo`030410@000000000000080000000<0@410
0?ooo`3oool0o`3ooom:0?ooo`040820P000000000000820P9L0oooo0`0000000`20P800oooo0?oo
o`100?ooo`005@3oool00`000000oooo0?ooo`02000000030820P03oool0oooo0440oooo1P00003o
0?ooodT0oooo00@0P8200000000000000000V03oool400000480oooo000E0?ooo`030<30`020P800
oooo0080000000<0`<300?ooo`3oool0@P3oool00`10@400000000000002000000030410@03oool0
oooo0?l0ooooAP3oool00`10@40000000410@02J0?ooo`<0000000<0P8200?ooo`3oool0?`3oool0
01H0oooo100000160?ooo`H00000o`3ooom60?ooo`<0000000<0P8200?ooo`3oool0V03oool01020
P80000000000000000110?ooo`005`3oool3000004L0oooo00<0P8200000000000000`00003o0?oo
odD0oooo0`00002K0?ooo`040820P0000000000000000440oooo000G0?ooo`<00000B03oool00`20
P800000000000003000000030820P03oool0oooo0?l0oooo?`3oool01030`<00000000000000002M
0?ooo`@00000@03oool001L0oooo0`00001:0?ooo`030820P0000000000000<00000o`3ooom00?oo
o`040820P000000000000820P9h0oooo1000000o0?ooo`005P3oool4000004/0oooo1P00003o0?oo
ocl0oooo0`00002O0?ooo`@00000?`3oool001H0oooo0`0000000`20P800@4100?ooo`1:0?ooo`03
0820P0000000000000<0000000<0`<300?ooo`3oool0o`3ooolj0?ooo`<0000000<0P8200?ooo`3o
ool0WP3oool3000000030820P03oool0oooo03`0oooo000F0?ooo`<0000000<0oooo0820P03oool0
C03oool600000?l0oooo>P3oool00`20P80000000000002R0?ooo`040820P000000000000820P3h0
oooo000E0?ooo`090<30`000000000000410@03oool0`<3000000020P800@41000800000B@3oool0
0`10@400000000000002000000030410@03oool0oooo0?l0oooo=`3oool2000000030410@03oool0
oooo0:00oooo00@0`<300000000000000000?P3oool00180oooo00@0P8200000003oool0P8200P00
00001020P800oooo0?ooo`3oool4000004/0oooo1P00003o0?ooocH0oooo0`00002T0?ooo`@00000
?@3oool001@0oooo100000050?ooo`800000C@3oool5000000030820P03oool0oooo0?l0oooo<P3o
ool400000:D0oooo0`00000m0?ooo`00K03oool00`30`<00P82000000003000000030820P03oool0
oooo0?l0oooo<03oool01030`<00000000000010@42V0?ooo`040820P000000000000820P3`0oooo
001^0?ooo`030820P0000000000000<0000000<0P8200?ooo`3oool0o`3oool^0?ooo`<0000000<0
P8200?ooo`3oool0Y@3oool3000003`0oooo001_0?ooo`80P820100000000`20P800oooo0?ooo`3o
0?ooob`0oooo00@0P820000000000000P820Z03oool01020P800000000000020P80k0?ooo`00L@3o
ool00`20P80000000000000300000?l0oooo;03oool400000:T0oooo00@0P8200000000000000000
>`3oool00180oooo00<0P8200000000000002`00001B0?ooo`H00000o`3ooolZ0?ooo`040820P000
0000000000000:/0oooo1000000j0?ooo`004P3oool00`20P80000000000000;000005<0oooo00<0
P8200410@00000000`0000000`30`<00oooo0?ooo`3o0?ooobH0oooo00@0@410000000000000`<30
Z`3oool01@20P8000000000000000000`<3003T0oooo000B0?ooo`030820P0000000000000/00000
E@3oool600000?l0oooo9P3oool400000:d0oooo0`0000000`20P800oooo0?ooo`0g0?ooo`00MP3o
ool5000000030820P03oool0oooo0?l0oooo8`3oool300000:h0oooo00@0P8200000000000000000
>@3oool007L0oooo00<0P8200000000000000P0000020820P?l0oooo8P3oool00`10@40000000000
002_0?ooo`040<30`00000000000000003T0oooo001i0?ooo`D0000000<0P8200?ooo`3oool0o`3o
oolO0?ooo`80000000<0P8200?ooo`3oool0[P3oool4000003P0oooo001j0?ooo`030820P0000000
00000080000000<0P8200?ooo`3oool0o`3ooolL0?ooo`040820P0000000000000000;40oooo00D0
P82000000000000000000<30`00g0?ooo`00N`3oool00`20P800000000000003000000030820P03o
ool0oooo0?l0oooo6P3oool300000;<0oooo0`0000000`20P800oooo0?ooo`0e0?ooo`00O03oool6
00000?l0oooo6`3oool01020P800000000000020P82d0?ooo`<00000=`3oool007h0oooo00<0@410
0000000000000P0000000`20P800oooo0?ooo`3o0?oooaL0oooo0`0000000`30`<00oooo0?ooo`2b
0?ooo`030410@0000000000003L0oooo001o0?ooo`H00000o`3ooolG0?ooo`<00000]P3oool01020
P800000000000000000f0?ooo`00P@3oool500000?l0oooo5@3oool400000;H0oooo00@0P8200000
000000000000=P3oool00840oooo00<0`<300000000000000P0000000`10@400P8200?ooo`3o0?oo
oa40oooo00@0`<30000000000000@410^03oool4000003D0oooo00230?ooo`030820P00000000000
00<00000o`3ooolA0?ooo`<0000000<0P8200?ooo`3oool0]`3oool3000000030820P03oool0oooo
0380oooo00240?ooo`030820P000000000000080000000<0@4100820P03oool0o`3oool=0?ooo`04
0820P000000000000820P;X0oooo00@0@410000000000000@410=03oool008H0oooo1@0000000`20
P800oooo0?ooo`3o0?ooo`X0oooo00@0P8200000000000000000^`3oool01020P800000000000000
000d0?ooo`00Q`3oool500000?l0oooo303oool00`20P80000000000002m0?ooo`@00000<`3oool0
08P0oooo00<0P8200000000000000P0000000`20P800`<300?ooo`3o0?ooo`L0oooo00@0P8200000
00000000P820_@3oool01@20P8000000000000000000P8200380oooo002:0?ooo`D00000o`3oool8
0?ooo`<00000_`3oool400000380oooo002;0?ooo`D000003P3oool00`20P80000000820P03d0?oo
o`<00000`@3oool3000000030820P03oool0oooo02l0oooo002;0?ooo`030<30`020P800000000<0
000000<0P8200?ooo`3oool01`3oool00`30`<00P82000000002000000030410@03oool0oooo0?40
oooo00@0P820000000000000@410`@3oool01010@400000000000010@40a0?ooo`00SP3oool50000
00P0oooo1P00003c0?ooo`<00000`P3oool01020P800000000000000000a0?ooo`00SP3oool00`30
`<00000000000002000000030410@020P800oooo00<0oooo00<0P8200000000000001P00003a0?oo
o`<0000000<0P8200?ooo`3oool0`@3oool3000000030820P03oool0oooo02h0oooo002@0?ooo`03
0820P0000000000000<000000P3oool00`20P80000000000000800000>l0oooo00<0P82000000000
0000aP3oool300000300oooo002A0?ooo`D0000000<0P8200?ooo`0000002P0000000`20P800oooo
0?ooo`3/0?ooo`<00000aP3oool300000300oooo002B0?ooo`030820P010@400000000h0000000<0
@4100?ooo`3oool0j`3oool01020P800000000000030`<370?ooo`030410@0000000P82002l0oooo
002D0?oooa400000j`3oool400000<P0oooo00<0P820000000000000;`3oool009D0oooo40000000
0`10@400oooo0?ooo`3W0?ooo`040<30`000000000000410@<P0oooo00@0P820000000000000P820
;`3oool009D0oooo4@00003Y0?ooo`<0000000<0P8200?ooo`3oool0aP3oool300000300oooo002E
0?oooa800000j03oool300000<P0oooo0`00000a0?ooo`00U03ooolD000000030<30`03oool0oooo
0>80oooo00@0P8200000000000000000b03oool01020P800000000000010@40a0?ooo`00T`3oool0
0`20P80000000000000B000000030820P03oool0oooo0>80oooo0`0000390?ooo`<00000<P3oool0
09<0oooo5P00003S0?ooo`040820P000000000000820P<P0oooo1000000b0?ooo`00TP3oool00`20
P80000000000000D000000030820P03oool0oooo0>00oooo0`0000000`30`<00oooo0?ooo`350?oo
o`040820P000000000000820P3<0oooo002B0?oooaP00000h@3oool300000<P0oooo00@0P8200000
000000000000=03oool00940oooo6P00003O0?ooo`040820P000000000000820P<P0oooo00@0@410
000000000000`<30=03oool00940oooo6P0000000`20P800oooo0?ooo`3L0?ooo`80000000<0P820
0?ooo`3oool0aP3oool4000003D0oooo002C0?ooo`030820P0000000000001D0000000<0P8200?oo
o`3oool0f`3oool3000000030820P03oool0oooo0<H0oooo0`00000f0?ooo`00UP3oool20820P1@0
000000<0P8200?ooo`3oool0f@3oool01020P800000000000020P8380?ooo`030410@00000000000
03L0oooo002J0?oooa<00000fP3oool01020P80000000000000000390?ooo`80000000<0P8200?oo
o`3oool0=@3oool009/0oooo00<0P8200000000000003`0000000`20P800oooo0?ooo`3G0?ooo`04
0820P000000000000820P<P0oooo0`00000h0?ooo`00WP3oool20820P0h00000f03oool01020P800
00000000000000380?ooo`<0000000<0P8200?ooo`3oool0=P3oool00:80oooo3@00003G0?ooo`<0
0000b03oool01020P800000000000020P80i0?ooo`00Y03oool20820P0X00000e03oool01030`<00
00000000000000390?ooo`<0000000<0`<300?ooo`3oool0=`3oool00:P0oooo00<0P82000000000
00001@0000000`20P800oooo0?ooo`3A0?ooo`040820P000000000000820P<P0oooo0`00000k0?oo
o`00Z`3oool600000080oooo00<0P8200000003oool0cP3oool300000<P0oooo00@0P82000000000
00000000>`3oool00:`0oooo0P20P803000000030820P03oool000000080000000<0P8200?ooo`3o
ool0bP3oool3000000030820P03oool0oooo0<H0oooo00<0@41000000010@400?03oool00;00oooo
00<0P8200000000000001@00003:0?ooo`030820P000000000000<T0oooo0`0000000`20P800oooo
0?ooo`0j0?ooo`00/03oool00`30`<00000000000006000000030820P03oool0oooo0<H0oooo0P00
00000`10@400oooo0?ooo`360?ooo`040820P000000000000820P3d0oooo002a0?ooo`T0000000<0
P8200?ooo`3oool0a03oool300000<P0oooo00@0P8200000000000000000?P3oool00;<0oooo2@00
00340?ooo`@00000b03oool3000000030820P03oool0oooo03`0oooo002c0?ooo`030<30`0000000
000000L0000000<0`<300?ooo`3oool0_`3oool01030`<00000000000010@4380?ooo`040820P000
00000000000003l0oooo002e0?ooo`030820P0000000000000L00000`03oool3000000030820P03o
ool0oooo0<D0oooo100000100?ooo`00]P3oool:00000;h0oooo100000370?ooo`040820P0000000
000000000440oooo002g0?ooo`030820P0000000000000H0000000<0@4100?ooo`3oool0^P3oool0
1030`<00000000000020P8380?ooo`040410@000000000000410@440oooo002i0?ooo`T0000000<0
P8200?ooo`3oool0^03oool300000<P0oooo100000120?ooo`00SP3oool01030`<00P8200820P020
P80X0?ooo`030410@0000000000000H0000000<0P8200?ooo`3oool0]P3oool01020P80000000000
0030`<370?ooo`050<30`0000000000000000020P800@P3oool008d0oooo0P0000030?ooo`030000
003oool0oooo02L0oooo2@0000000`20P800oooo0?ooo`2c0?ooo`@00000b03oool3000004@0oooo
002;0?ooo`040820P000000000000820P080oooo0P0000000`20P800oooo0?ooo`0W0?ooo`T00000
]@3oool300000<P0oooo100000140?ooo`00Q`3oool30820P0<0000000@0P8200?ooo`3oool0P820
0P0000000`20P800oooo0?ooo`0W0?ooo`030<30`020P800000000L0000000<0P8200<30`03oool0
/03oool01010@400000000000020P8370?ooo`050820P0000000000000000030`<00A03oool008P0
oooo1000000d0?ooo`T00000/@3oool300000<L0oooo00<0P8200000000000000P0000150?ooo`00
R@3oool2000000030820P03oool0oooo0380oooo00<0P8200000000000001`00002_0?ooo`<00000
b03oool01020P80000000000000000160?ooo`00R@3oool00`30`<00P8200?ooo`0f0?ooo`030410
@0000000000000H0000000<0P8200?ooo`3oool0ZP3oool3000000030820P03oool0oooo0<D0oooo
00D0P82000000000000000000820P0160?ooo`00RP3oool00`000000oooo0?ooo`0f0?ooo`X00000
ZP3oool01020P800000000000020P8380?ooo`@00000A`3oool008/0oooo00<0P8200?ooo`3oool0
=`3oool00`10@400000000000006000000030820P03oool0oooo0:H0oooo0`0000000`30`<00oooo
0?ooo`340?ooo`030<30`0000000000000800000B03oool008`0oooo00<000000?ooo`3oool0=`3o
ool9000000030820P03oool0oooo0:@0oooo0`0000380?ooo`040820P00000000000000004T0oooo
002<0?ooo`030000003oool0oooo03P0oooo2P00002T0?ooo`040820P0000000000000000<P0oooo
0`0000000`20P800oooo0?ooo`170?ooo`00S@3oool00`20P800`<300?ooo`0h0?ooo`030<30`000
0000000000L0000000<0`<300?ooo`3oool0X03oool00`10@40000000410@0380?ooo`@0000000<0
`<300?ooo`3oool0A`3oool008h0oooo00<0P8200?ooo`3oool0>@3oool:00000:00oooo0`000000
0`20P800oooo0?ooo`350?ooo`040820P00000000000000004/0oooo002?0?ooo`030000003oool0
oooo03T0oooo2P00002O0?ooo`<00000b03oool4000004/0oooo002?0?ooo`030820P030`<00oooo
03X0oooo00<0P8200000000000001P0000000`10@400P8200?ooo`2J0?ooo`040<30`00000000000
00000<P0oooo00@0P820000000000000@410C03oool008T0oooo00<0P8200000003oool0103oool0
0`20P800oooo0?ooo`0k0?ooo`T0000000<0P8200?ooo`3oool0V03oool3000000030820P03oool0
oooo0<D0oooo100000000`20P800oooo0?ooo`1:0?ooo`00R@3oool00`30`<0000000<30`0050?oo
o`030000003oool0oooo03/0oooo00<0@4100000000000001P0000000`20P800oooo0?ooo`2F0?oo
o`040820P000000000000820P<L0oooo00D0`<3000000000000000000820P01=0?ooo`00RP3oool9
000003h0oooo2@0000000`20P800oooo0?ooo`2C0?ooo`@00000b03oool4000004h0oooo002:0?oo
o`T0000000<0P8200?ooo`3oool0?03oool9000009D0oooo0`0000390?ooo`<0000000<0P8200?oo
o`3oool0C03oool008X0oooo2P20P80n0?ooo`030<30`020P800000000L0000000<0P8200<30`03o
ool0T03oool01010@400000000000020P8370?ooo`030<30`0000000000000800000C`3oool00=D0
oooo2@00002A0?ooo`<00000b03oool01020P800000000000000001@0?ooo`00e@3oool00`30`<00
000000000007000000030820P03oool0oooo08/0oooo00@0`<300000000000000000b@3oool20000
00030410@03oool0oooo04l0oooo003G0?ooo`030820P0000000000000L00000S03oool00`20P800
0000000000390?ooo`<0000000<0P8200?ooo`3oool0C`3oool00=P0oooo2P00002;0?ooo`800000
00<0P8200?ooo`3oool0aP3oool400000580oooo00290?ooo`d00000@`3oool00`20P800@4100000
0007000000030820P03oool0oooo08H0oooo0`0000000`30`<00oooo0?ooo`350?ooo`040<30`000
00000000000005<0oooo00290?ooo`d00000A@3oool9000000030820P03oool0oooo08@0oooo0`00
00390?ooo`<0000000<0P8200?ooo`3oool0D@3oool008T0oooo3@0000160?ooo`X00000Q03oool0
1020P80000000000000000390?ooo`<00000E03oool00=d0oooo00<0`<300000000000001`000000
0`30`<00oooo0?ooo`200?ooo`040410@000000000000<30`<L0oooo00D0P8200000000000000000
0820P01D0?ooo`00g`3oool:00000800oooo100000380?ooo`<00000EP3oool00>00oooo00<0P820
0000000000001`0000000`30`<00oooo0?ooo`1k0?ooo`040820P000000000000820P<P0oooo00@0
@410000000000000P820EP3oool00>80oooo2P00001l0?ooo`80000000<0P8200?ooo`3oool0a`3o
ool3000005L0oooo003R0?ooo`030820P0000000000000L0000000<0P8200?ooo`3oool0N03oool3
000000030820P03oool0oooo0<H0oooo0`00001H0?ooo`00i03oool00`10@4000000000000060000
0080P820M`3oool01020P800000000000020P8380?ooo`040820P000000000000820P5P0oooo003U
0?ooo`X0000000<0P8200?ooo`3oool0L`3oool01020P80000000000000000390?ooo`80000000<0
P8200?ooo`3oool0E`3oool00>L0oooo2@00001e0?ooo`040820P000000000000820P<P0oooo0`00
00000`20P800oooo0?ooo`1G0?ooo`00i`3oool00`30`<00000000000007000000030820P030`<00
oooo0700oooo00@0P8200000000000000000b03oool3000000030820P03oool0oooo05P0oooo003Z
0?ooo`T00000L@3oool300000<P0oooo00@0P8200000000000000000F`3oool00>X0oooo00<0`<30
0000000000001`0000000`20P800oooo0?ooo`1[0?ooo`040<30`0000000000000000<T0oooo0`00
00000`20P800oooo0?ooo`1I0?ooo`00k03oool00`20P800000000000007000006`0oooo00@0P820
000000000000P820b03oool4000005`0oooo003]0?ooo`X00000J`3oool300000<P0oooo1000001M
0?ooo`00kP3oool00`20P800@41000000007000000030820P03oool0oooo06H0oooo0`0000000`20
P800oooo0?ooo`350?ooo`050<30`0000000000000000020P800G@3oool00?00oooo2@0000000`20
P800oooo0?ooo`1T0?ooo`030820P000000000000<T0oooo0`0000000`20P800oooo0?ooo`1L0?oo
o`00l@3oool:000006D0oooo0`0000390?ooo`<0000000<0P8200?ooo`3oool0G03oool00?80oooo
00<0P8200000000000001`0000000`30`<00oooo0?ooo`1P0?ooo`<0000000<0`<300?ooo`3oool0
a@3oool01@30`<000000000000000000P82005l0oooo003d0?ooo`X00000H03oool400000<P0oooo
1000001P0?ooo`00m03oool00`30`<00P82000000008000000030<30`03oool0oooo05/0oooo00@0
P820000000000000@410b03oool01020P800000000000010@41Q0?ooo`00m`3oool:000005`0oooo
0`0000000`20P800oooo0?ooo`350?ooo`@0000000<0P8200?ooo`3oool0G`3oool00?L0oooo00<0
P8200000000000001`0000000`20P800oooo0?ooo`1H0?ooo`@00000b03oool400000680oooo003i
0?ooo`030410@0000000000000H000000P20P81G0?ooo`040820P0000000000000000<P0oooo00@0
@4100000000000000000H`3oool00?X0oooo2P0000000`20P800oooo0?ooo`1C0?ooo`040820P000
0000000000000<T0oooo0`0000000`20P800oooo0?ooo`1Q0?ooo`00o03oool00`10@40000000000
0006000000030820P03oool0oooo0580oooo00@0@410000000000000P820a`3oool01@30`<000000
000000000000P82006@0oooo003m0?ooo`X0000000<0P8200?ooo`3oool0C`3oool400000<P0oooo
00@0P8200000000000000000I@3oool00?h0oooo2P00001A0?ooo`<00000b@3oool3000006H0oooo
003o0?ooo`030<30`0000000000000L0000000<0P8200?ooo`3oool0C03oool01010@40000000000
0020P8380?ooo`<0000000<0P8200?ooo`3oool0I03oool00?l0oooo0P3oool:000004d0oooo0P00
00000`20P800oooo0?ooo`360?ooo`@00000I`3oool00?l0oooo0`3oool:000004/0oooo0`000000
0`20P800oooo0?ooo`350?ooo`040820P00000000000000006P0oooo003o0?ooo`@0oooo00<0P820
0000000000001`0000000`20P800oooo0?ooo`150?ooo`050<30`0000000000000000020P800b03o
ool01010@400000000000010@41X0?ooo`00o`3oool60?ooo`T0000000<0P8200?ooo`3oool0A03o
ool01020P80000000000000000380?ooo`@00000J@3oool00?l0oooo1`3oool00`20P80000000000
0007000000030820P03oool0oooo0440oooo00D0P82000000000000000000<30`0370?ooo`040820
P00000000000000006X0oooo003o0?ooo`T0oooo2@0000000`20P800oooo0?ooo`100?ooo`@00000
a`3oool01020P800000000000000001[0?ooo`00o`3oool:0?ooo`X00000@03oool01020P8000000
0000000000380?ooo`040820P000000000000820P6/0oooo003o0?ooo`X0oooo00<0`<300820P000
0000200000000`30`<00oooo0?ooo`0l0?ooo`<00000b03oool01@20P8000000000000000000`<30
06/0oooo003o0?ooo`d0oooo2P00000l0?ooo`<0000000<0P8200?ooo`3oool0aP3oool3000006d0
oooo003o0?ooo`d0oooo00<0P8200000000000001`0000000`20P800oooo0?ooo`0h0?ooo`@00000
b03oool00`20P80000000000001^0?ooo`00o`3oool>0?ooo`030820P010@400000000L000000P20
P80g0?ooo`050<30`0000000000000000020P800b03oool2000000030410@03oool0oooo06`0oooo
003o0?oooa00oooo2P0000000`20P800oooo0?ooo`0d0?ooo`<0000000<0P8200?ooo`3oool0aP3o
ool3000006l0oooo003o0?oooa40oooo00<0P8200410@00000001`0000020820P3<0oooo00D0P820
00000000000000000<30`0370?ooo`<0000000<0P8200?ooo`3oool0K@3oool00?l0oooo4`3oool:
000000030820P03oool0oooo02l0oooo100000380?ooo`040820P0000000000000000700oooo003o
0?oooa@0oooo2P00000a0?ooo`@00000b03oool3000000030820P03oool0oooo06h0oooo003o0?oo
oaD0oooo00<0`<300000000000001`0000000`20P800oooo0?ooo`0/0?ooo`040410@00000000000
0410@<P0oooo1000001a0?ooo`00o`3ooolG0?ooo`X00000;@3oool3000000030820P03oool0oooo
0<D0oooo1000001b0?ooo`00o`3ooolH0?ooo`X00000:`3oool400000<L0oooo00@0P82000000000
00000000L`3oool00?l0oooo6@3oool00`20P800000000000007000000030820P03oool0oooo02H0
oooo00@0P820000000000000P820b03oool01010@400000000000010@41c0?ooo`00o`3ooolK0?oo
o`T0000000<0P8200?ooo`3oool09@3oool300000<P0oooo1000001d0?ooo`00o`3ooolL0?ooo`03
0820P0000000000000L0000000<0P8200?ooo`3oool08P3oool3000000030<30`03oool0oooo0<D0
oooo00D0`<3000000000000000000820P01d0?ooo`00o`3ooolM0?ooo`030820P0000000000000L0
000000<0P8200?ooo`3oool0803oool400000<P0oooo1000001e0?ooo`00o`3ooolO0?ooo`X00000
803oool01020P80000000000000000390?ooo`<00000MP3oool00?l0oooo7`3oool00`30`<000000
00000008000000030<30`03oool0oooo01`0oooo00@0@410000000000000P820a`3oool01@20P800
0000000000000000P82007H0oooo003o0?ooob80oooo2P00000L0?ooo`@00000a`3oool00`20P800
000000000002000007L0oooo003o0?ooob80oooo00<0`<300000000000001`0000000`10@400oooo
0?ooo`0H0?ooo`040820P0000000000000000<P0oooo00@0@4100000000000000000N03oool00?l0
oooo903oool00`20P800000000000008000001L0oooo00@0P8200000000000000000b03oool40000
00030820P03oool0oooo07H0oooo003o0?ooobD0oooo2P0000000`20P800oooo0?ooo`0D0?ooo`04
0820P000000000000820P<P0oooo100000000`20P800oooo0?ooo`1f0?ooo`00o`3ooolV0?ooo`03
0820P010@400000000L000000P20P80C0?ooo`050820P0000000000000000030`<00a`3oool01@10
@4000000000000000000P82007T0oooo003o0?ooobP0oooo2P0000000`20P800oooo0?ooo`0@0?oo
o`<00000b@3oool4000007X0oooo003o0?ooobT0oooo2P00000A0?ooo`040820P000000000000000
0<P0oooo1000001k0?ooo`00o`3ooolZ0?ooo`030820P0000000000000L0000000<0@4100?ooo`3o
ool03@3oool2000000030410@03oool0oooo0<H0oooo100000000`20P800oooo0?ooo`1i0?ooo`00
o`3oool/0?ooo`X000003@3oool300000<P0oooo00<0P8200000000000000P00001l0?ooo`00o`3o
ool/0?ooo`030<30`020P800000000P0000000<0P8200?ooo`3oool0203oool3000000030820P03o
ool0oooo0<H0oooo00@0@4100000000000000000O@3oool00?l0oooo;`3oool:000000P0oooo00@0
P820000000000000P820b03oool4000000030820P03oool0oooo07/0oooo003o0?ooobl0oooo00<0
P8200000000000001`0000000`20P800oooo0?ooo`050?ooo`<0000000<0P8200?ooo`3oool0aP3o
ool4000007h0oooo003o0?oooc40oooo00<0P8200000000000001`0000000`20P800oooo0?ooo`02
0?ooo`040820P000000000000820P<L0oooo00<0`<300000000000000P00001o0?ooo`00o`3ooolb
0?ooo`030820P0000000000000L0000000@0P8200?ooo`3oool0P8200`0000380?ooo`040820P000
0000000000000800oooo003o0?oooc@0oooo2P000000103oool0P8200000000000390?ooo`<00000
00<0P8200?ooo`3oool0OP3oool00?l0oooo=03oool00`30`<0000000000000:000000030820P03o
ool0oooo0<H0oooo100000000`30`<00oooo0?ooo`1n0?ooo`00o`3ooolg0?ooo`X00000b03oool0
1020P80000000000000000220?ooo`00o`3ooolg0?ooo`030<30`0000000000000L0000000<0`<30
0?ooo`3oool0a@3oool3000008<0oooo003o0?ooocT0oooo200000370?ooo`<0000000<0P8200?oo
o`3oool0P@3oool00?l0oooo>P3oool600000<P0oooo0`0000240?ooo`00o`3ooolj0?ooo`030820
P000000000000080000000<0P8200?ooo`3oool0a03oool01@30`<000000000000000000P82008@0
oooo003o0?ooocX0oooo1@0000370?ooo`040820P000000000000820P8D0oooo003o0?ooocT0oooo
00@0P8200000000000000000b@3oool3000000030820P03oool0oooo08<0oooo003o0?ooocT0oooo
0`0000000`30`<00oooo0?ooo`360?ooo`<0000000<0P8200?ooo`3oool0Q03oool00?l0oooo>03o
ool400000<P0oooo0`0000280?ooo`00o`3ooolg0?ooo`040820P000000000000820P<P0oooo00@0
P820000000000000@410R03oool00?l0oooo=`3oool300000<T0oooo0`0000290?ooo`00o`3ooolf
0?ooo`<0000000<0P8200?ooo`3oool0aP3oool4000008T0oooo003o0?ooocD0oooo1000000C0?oo
o`030820P03oool0oooo0;80oooo00@0`<30000000000000P820RP3oool00?l0oooo=03oool01020
P800000000000000000C0?ooo`<0000000<0P8200?ooo`3oool0/03oool3000008/0oooo003o0?oo
oc@0oooo0`0000000`20P800oooo0?ooo`0@0?ooo`030820P00000000000008000000P20P82_0?oo
o`040820P000000000000<30`8/0oooo003o0?oooc<0oooo1000000E0?ooo`030820P00000000000
0080000000<0P8200?ooo`3oool0Z`3oool4000008`0oooo003o0?oooc80oooo00@0P82000000000
000000005`3oool600000:/0oooo00@0P8200000000000000000S@3oool00?l0oooo<P3oool01010
@400000000000020P80H0?ooo`030<30`000000000000080000000<0P8200?ooo`3oool0Z03oool0
1010@400000000000020P82=0?ooo`00o`3ooola0?ooo`<0000000<0P8200?ooo`3oool06P3oool0
0`000000oooo0?ooo`2Y0?ooo`@00000SP3oool00?l0oooo<@3oool3000000030820P03oool0oooo
0<H0oooo1000002>0?ooo`00o`3oool_0?ooo`050<30`0000000000000000020P800b03oool01010
@400000000000020P82?0?ooo`00o`3oool_0?ooo`@00000b@3oool300000900oooo003o0?ooobh0
oooo00D0P82000000000000000000<30`0370?ooo`050820P0000000000000000030`<00T03oool0
0?l0oooo;@3oool500000<P0oooo1000002A0?ooo`00o`3oool]0?ooo`@00000b03oool01020P800
000000000000002B0?ooo`00o`3oool/0?ooo`040410@0000000000000000<P0oooo00D0P8200000
0000000000000820P02B0?ooo`00o`3oool/0?ooo`<0000000<0P8200?ooo`3oool0aP3oool40000
09<0oooo003o0?ooob/0oooo1000000`0?ooo`030000003oool0oooo09D0oooo1000002D0?ooo`00
o`3ooolZ0?ooo`050820P0000000000000000020P800;`3oool01010@400000000000010@42D0?oo
o`050820P0000000000000000020P800U03oool00?l0oooo:P3oool300000340oooo00<0P8200000
000000000P0000000`20P800oooo0?ooo`2@0?ooo`<0000000<0P8200?ooo`3oool0T`3oool00?l0
oooo:@3oool3000000030410@03oool0oooo0340oooo00@0P82000000000000000000P20P82?0?oo
o`@0000000<0`<300?ooo`3oool0T`3oool00?l0oooo:03oool4000003D0oooo00<0P82000000000
00000P0000000`20P800oooo0?ooo`2;0?ooo`040820P00000000000000009L0oooo003o0?ooobL0
oooo00<0P8200000000000000P00000f0?ooo`@0000000<0P8200?ooo`3oool0R`3oool4000009L0
oooo003o0?ooobL0oooo0`0000000`10@400oooo0?ooo`0f0?ooo`030<30`0000000000008h0oooo
0`20P82H0?ooo`00o`3ooolV0?ooo`@0000000<0P8200?ooo`3oool0o`3ooomS0?ooo`00o`3ooolU
0?ooo`@0000000<0P8200?ooo`3oool0o`3ooolT0?ooo`03092=S038a/H0oooo03d0oooo003o0?oo
ob@0oooo00<0P8200000000000000P00003o0?ooobL0oooo00<081/H092=S03oool0?@3oool00?l0
oooo903oool400000?l0oooo:03oool00`0P6aP0T8f<0?ooo`0m0?ooo`00o`3ooolS0?ooo`050820
P0000000000000000020P800^03oool3020K66`0oooo00<0T8f<05QDDP3oool0?@3oool00?l0oooo
8P3oool00`20P80000000000000200000;T0oooo0`0P6aQ]0?ooo`03020K603oool0oooo03`0oooo
003o0?ooob80oooo00@0P8200000000000000000^P3oool3020K66/0oooo100P6aP00`2@SH`0oooo
0?ooo`0j0?ooo`00o`3ooolQ0?ooo`050820P0000000000000000020P800C03oool00`20P800`<30
0?ooo`1/0?ooo`<081/HJ@3oool0200P6aP0T8f<0?ooo`1HE580oooo092=S00P6aP0T8f<>P3oool0
0?l0oooo8@3oool3000000030820P03oool0oooo04X0oooo1000001/0?ooo`<081/H3@3oool0102@
SH`081/H020K600P6aQG0?ooo`8081/H0P3oool00`2@SH`081/H0?ooo`02020K6003092=S03oool0
oooo03L0oooo003o0?oooal0oooo00<0`<300000000000000P0000000`30`<00oooo0?ooo`190?oo
o`030<30`0000000000000<0000000<0`<300?ooo`3oool0;P3oool00`2@SH`0F5AB092=S003092=
S3@0oooo0`0P6aP>0?ooo`<081/H00<0T8f<0?ooo`3oool0E03oool2020K6080oooo00@0T8f<020K
603oool0oooo0P0P6aPi0?ooo`00o`3ooolO0?ooo`040820P0000000000000000500oooo1000000^
0?ooo`04092=S00P6aP081/H092=S080oooo0P0P6aP00`2@SH`0oooo0?ooo`0a0?ooo`04092=S00P
6aP081/H092=S0h0oooo0`0P6aQF0?ooo`8081/H0P3oool0102@SH`081/H0?ooo`3oool2020K63T0
oooo003o0?oooal0oooo1000001@0?ooo`030820P000000000000080000000<0P8200?ooo`3oool0
9P3oool00`0P6aP0oooo0?ooo`04020K6080oooo00@0T8f<020K600P6aP0T8f<<`3oool0102@SH`0
81/H020K602@SH`>0?ooo`<081/H3@3oool0102@SH`081/H020K602@SH`70?ooo`8081/H703oool2
020K61H0oooo00<081/H0?ooo`3oool01P3oool2020K6080oooo00<081/H0?ooo`3oool00P0P6aP9
0?ooo`<081/H;@3oool00?l0oooo7@3oool00`30`<00000000000002000000030<30`03oool0oooo
04l0oooo00<0P8200000000000000P0000000`20P800oooo0?ooo`0V0?ooo`@081/H00D0T8f<0?oo
o`3oool0oooo0<S6aP02092=S0030<S6aP3oool0oooo02h0oooo00@0T8f<05QDDP0P6aP0F5AB0P0P
6aP0101HE580T8f<020K602@SH`<0?ooo`8081/H00<0T8f<0?ooo`3oool02P3oool01038a/H081/H
020K601HE5850?ooo`03092=S00P6aP081/H00<0T8f<6P3oool2020K61H0oooo00<081/H05QDDP3o
ool01P3oool01`1HE58081/H0?ooo`3oool081/H092=S03oool00P0P6aP90?ooo`<081/H0P2@SH`[
0?ooo`00o`3ooolM0?ooo`030820P0000000000000800000E03oool00`20P80000000000000Y0?oo
o`04092=S00P6aP081/H092=S3L0oooo0`0P6aP20?ooo`8081/H00<0T8f<0?ooo`3oool00P0P6aP0
0`2@SH`0oooo0?ooo`080?ooo`03092=S00P6aP081/H00d0oooo0`0P6aP50?ooo`<081/H0P3oool0
0`2@SH`0oooo0?ooo`0H0?ooo`8081/H5P3oool3020K60H0oooo00L0T8f<020K600P6aP0oooo020K
602@SH`0oooo008081/H2@3oool3020K6080oooo00<081/H0?ooo`3oool0:03oool00?l0oooo7@3o
ool4000005H0oooo00<000000820P03oool0:@3oool00`0P6aP0oooo0?ooo`0f0?ooo`04092=S00P
6aP081/H020K6080oooo0`0P6aP20?ooo`03092=S00P6aP081/H00X0oooo00<0T8f<020K600P6aP0
3@3oool3020K60@0oooo00@0T8f<020K600P6aP0T8f<0`3oool00`0P6aP0oooo0?ooo`0G0?ooo`80
81/H5P3oool4020K60H0oooo0P0P6aP00`2@SH`0oooo092=S002020K6003092=S03oool0oooo00L0
oooo0`0P6aP30?ooo`03092=S03oool0oooo02L0oooo003o0?oooa`0oooo100000240?ooo`03020K
603oool0oooo03D0oooo00@0F5AB020K600P6aP0T8f<0P3oool3020K60<0oooo0`0P6aP00`2@SH`0
oooo0?ooo`070?ooo`<081/H303oool0102@SH`081/H020K600P6aP30?ooo`0405QDDP0P6aP081/H
0<S6aP<0oooo00<0T8f<0?ooo`3oool05`3oool2020K61H0oooo0`0P6aP00`2@SH`0F5AB0?ooo`06
0?ooo`80T8f<00<0F5AB092=S02@SH`02P3oool0102@SH`081/H020K602@SH`20?ooo`030<S6aP3o
ool0oooo02L0oooo003o0?oooa/0oooo100000000`20P800oooo0?ooo`230?ooo`03092=S03oool0
oooo01D0oooo00<0T8f<020K600P6aP03P0P6aP>0?ooo`<081/H00<0T8f<0?ooo`3oool00`0P6aP4
0?ooo`<081/H00<0T8f<0?ooo`3oool01`3oool3020K60`0oooo0`0P6aP30?ooo`<081/H7P3oool2
020K61D0oooo100P6aP00`3oool0T8f<0?ooo`080?ooo`03020K603oool0oooo00X0oooo00@0T8f<
020K600P6aP0T8f<;03oool00?l0oooo6P3oool00`20P800000000000002000008H0oooo00<0b<K6
092=S03oool05@3oool00`2@SH`081/H020K600>020K60h0oooo0`0P6aP0102@SH`0oooo0?ooo`3o
ool2020K60@0oooo00@0F5AB020K600P6aP0T8f<2@3oool3020K60030<S6aP3oool0oooo00T0oooo
0`0P6aP00`2@SH`0oooo020K6002020K61l0oooo0P0P6aPE0?ooo`<081/H0`3oool00`0P6aP0b<K6
0?ooo`060?ooo`0305QDDP3oool0oooo00X0oooo00@0b<K6020K600P6aP0F5AB;03oool00?l0oooo
6P3oool4000008P0oooo00<081/H0?ooo`3oool0<`3oool3020K6004092=S03oool0oooo0?ooo`<0
81/H0`3oool0102@SH`081/H020K600P6aP90?ooo`04092=S00P6aP081/H092=S0`0oooo1`0P6aPH
0?oooa0081/H00<0T8f<0?ooo`3oool02`3oool3020K60@0oooo00<081/H0?ooo`3oool01@3oool0
0`2@SH`0oooo0?ooo`0;0?ooo`<081/H;03oool00?l0oooo6@3oool4000000030820P03oool0oooo
08L0oooo00<081/H0?ooo`3oool0<P3oool3020K6004092=S03oool0oooo0?ooo`<081/H0`3oool0
102@SH`081/H020K600P6aP90?ooo`04092=S00P6aP081/H020K60`0oooo0`0P6aP00`2@SH`081/H
020K600I0?oooa0081/H00<0T8f<0?ooo`3oool02`3oool3020K60@0oooo00<0T8f<0?ooo`3oool0
1@3oool00`2@SH`0oooo0?ooo`0;0?ooo`<081/H;03oool00?l0oooo603oool00`20P80000000000
0002000000030<30`03oool0oooo08P0oooo00<0T8f<0?ooo`3oool04P3oool00`38a/H0T8f<092=
S00>092=S0h0oooo00@0F5AB020K600P6aP0F5AB103oool2020K60<0oooo00@0T8f<020K600P6aP0
81/H2P3oool3020K6003092=S03oool0oooo00T0oooo00H0F5AB020K600P6aP0b<K6092=S01HE58I
0?ooo`L0T8f<0P0P6aP7092=S0030<S6aP3oool0oooo00/0oooo0`0P6aP40?ooo`030<S6aP0P6aP0
T8f<01<0oooo00@0T8f<020K600P6aP081/H:`3oool00?l0oooo5`3oool00`20P800000000000002
000008d0oooo00<081/H0?ooo`3oool04@3oool00`2@SH`081/H020K600>020K60h0oooo00@0T8f<
020K600P6aP081/H103oool2020K60@0oooo0`0P6aP;0?ooo`<081/H2`3oool01`2@SH`081/H020K
602@SH`0oooo092=S00P6aP07`3oool2020K61D0oooo0`0P6aP50?ooo`8081/H503oool3020K62/0
oooo003o0?oooaL0oooo00<0P8200000000000000P00001Y0?ooo`030000003oool0oooo0240oooo
00<081/H0?ooo`3oool04@3oool00`2@SH`081/H020K600>020K60h0oooo00@0T8f<020K600P6aP0
81/H103oool3020K60<0oooo0`0P6aP;0?ooo`@081/H2P3oool0102@SH`081/H020K602@SH`20?oo
o`8081/H7P3oool2020K61D0oooo0`0P6aP60?ooo`03020K602@SH`0oooo0180oooo0`0P6aP[0?oo
o`00o`3ooolF0?ooo`050820P0000000000000000010@400J@3oool01@20P8000000000000000000
`<3001X0oooo0P2@SH`50?ooo`03092=S03oool0oooo0300oooo00@0T8f<020K600P6aP081/H0`3o
ool00`1HE58081/H020K60020?ooo`040<S6aP0P6aP081/H020K60`0oooo0`0P6aP00`38a/H0oooo
0?ooo`070?ooo`040<S6aP0P6aP081/H020K60<0oooo00<0T8f<05QDDP3oool0703oool2020K61@0
oooo00@0T8f<020K600P6aP0F5AB1P3oool00`0P6aP0F5AB0?ooo`0C0?ooo`<081/H:P3oool00?l0
oooo5P3oool4000000030820P03oool0oooo06H0oooo00<0P8200000000000000`00000J0?ooo`80
81/H1P3oool00`0P6aP0oooo0?ooo`0`0?ooo`<081/H00@0T8f<0?ooo`3oool0T8f<0P0P6aP20?oo
o`04092=S00P6aP081/H020K60`0oooo00@0T8f<020K600P6aP0T8f<2P3oool3020K60@0oooo00<0
T8f<020K603oool06`3oool2020K61@0oooo00@0T8f<020K600P6aP0T8f<1P3oool2020K61@0oooo
0`0P6aPZ0?ooo`00o`3ooolE0?ooo`050410@0000000000000000020P800JP3oool00`20P800@410
00000003000000<0P820100000020820P140oooo00<081/H05QDDP2@SH`0102@SH`00`0P6aP0T8f<
0?ooo`0a0?ooo`06092=S00P6aP081/H092=S03oool0T8f<0P0P6aP20?ooo`0405QDDP0P6aP081/H
0<S6aP`0oooo00@0b<K6020K600P6aP081/H2P3oool0102@SH`081/H020K602@SH`40?ooo`03092=
S00P6aP0b<K601X0oooo0P0P6aPD0?ooo`0405QDDP0P6aP081/H092=S0@0oooo00@0b<K6020K600P
6aP081/H503oool0101HE58081/H020K6038a/HY0?ooo`00o`3ooolE0?ooo`@00000K@3oool=0000
00030820P03oool0oooo00h0oooo2@0P6aP00`2@SH`0oooo0?ooo`0a0?ooo`<081/H00@0oooo020K
600P6aP0T8f<0`0P6aP?0?ooo`@081/H2P3oool3020K60D0oooo0`0P6aPI0?ooo`8081/H4P3oool5
020K6003092=S03oool0oooo0080oooo00@0T8f<020K600P6aP081/H503oool0102@SH`081/H020K
602@SH`Y0?ooo`00o`3ooolD0?ooo`@00000L03oool;000000030820P03oool0oooo00h0oooo2P0P
6aPe0?ooo`H081/H00<0T8f<0?ooo`3oool03`3oool3020K60X0oooo0`0P6aP30?ooo`H081/H603o
ool2020K61@0oooo00<0T8f<020K600P6aP01P3oool2020K6003092=S03oool0oooo00l0oooo00<0
T8f<020K600P6aP01P0P6aPW0?ooo`00o`3ooolC0?ooo`@0000000<0`<300?ooo`3oool0KP3oool0
0`30`<00000000000008000000030410@03oool0oooo04l0oooo0P0P6aP00`2@SH`0oooo0?ooo`0A
0?ooo`04092=S00P6aP081/H092=S0T0oooo00@0T8f<020K600P6aP0b<K6E@3oool01@2@SH`0F5AB
020K600P6aP0F5AB02T0oooo003o0?oooa80oooo00<0P8200000000000000P00001b0?ooo`/00000
DP3oool00`0P6aP0T8f<0?ooo`0C0?ooo`8081/H00<0T8f<0?ooo`3oool0203oool2020K6003092=
S03oool0oooo05D0oooo0`0P6aPY0?ooo`00o`3ooolB0?ooo`<0000000<0@4100?ooo`3oool0L03o
ool00`20P80000000000000900000580oooo00<081/H05QDDP3oool04`3oool00`2@SH`081/H020K
600:0?ooo`8081/H00<0F5AB0?ooo`3oool0E`3oool00`1HE580oooo0?ooo`0W0?ooo`00o`3ooolA
0?ooo`@0000000<0P8200?ooo`3oool0L03oool00`20P80000000000000900000580oooo0P0P6aPE
0?ooo`<081/H2@3oool00`2@SH`081/H020K601I0?ooo`03092=S03oool0oooo02L0oooo003o0?oo
oa40oooo1000001d0?ooo`/00000DP3oool2020K61D0oooo0`0P6aP90?ooo`03092=S00P6aP081/H
08<0oooo003o0?ooo`l0oooo00<0`<300000000000000P00001e0?ooo`030820P0000000000000L0
000000<0@4100?ooo`3oool02`3oool=0820P2h0oooo0`20P8000`30`<00oooo0?ooo`050?ooo`03
020K603oool0oooo01@0oooo0`0P6aP80?ooo`04092=S00P6aP081/H092=S880oooo003o0?ooo`l0
oooo00@0P8200000000000000000M`3oool9000000030820P03oool0oooo00/0oooo3@00000]0?oo
o`@0000000<0P8200?ooo`3oool01@3oool00`0P6aP0oooo0?ooo`0D0?ooo`04092=S00P6aP081/H
092=S0D0oooo1P0P6aR20?ooo`00o`3oool?0?ooo`<0000000<0P8200?ooo`3oool0MP3oool80000
00h0oooo3@00000]0?ooo`@00000203oool2020K61D0oooo00@0T8f<020K600P6aP0T8f<2@3oool2
020K6880oooo003o0?ooo`h0oooo100000000`30`<00oooo0?ooo`1i0?ooo`030820P03oool0oooo
0100oooo3@20P80[0?ooo`030<30`000000000000080000000<0P8200?ooo`3oool07@3oool01038
a/H081/H020K600P6aR=0?ooo`00o`3oool=0?ooo`040820P0000000000000000<P0oooo1000000R
0?ooo`@081/HS03oool00?l0oooo3@3oool3000000030820P03oool0oooo0<D0oooo00D0P8200000
0000000000000410@02b0?ooo`00o`3oool<0?ooo`<0000000<0P8200?ooo`3oool0a@3oool00`20
P80000000000000200000;<0oooo003o0?ooo`/0oooo100000000`20P800oooo0?ooo`290?ooo`03
0000003oool0oooo03T0oooo00<0P8200000000000000P00002c0?ooo`00o`3oool:0?ooo`050<30
`0000000000000000020P800R`3oool01010@400000000000010@40h0?ooo`050820P00000000000
00000020P800]03oool00?l0oooo2P3oool3000000030820P03oool0oooo08X0oooo00<0P8200000
000000000P00000g0?ooo`@00000]@3oool00?l0oooo2P3oool3000000030820P03oool0oooo08`0
oooo100000000`20P800oooo0?ooo`0b0?ooo`@0000000<0P8200?ooo`3oool0/`3oool00?l0oooo
203oool01@30`<000000000000000000P8200900oooo00D0@41000000000000000000820P00b0?oo
o`030820P0000000000000800000]P3oool00?l0oooo203oool01020P800000000000000002C0?oo
o`<0000000<0P8200?ooo`3oool0;`3oool400000;L0oooo003o0?ooo`L0oooo00@0P82000000000
0000@410U@3oool01@10@4000000000000000000P82002h0oooo100000000`20P800oooo0?ooo`2e
0?ooo`00o`3oool70?ooo`<0000000<0P8200?ooo`3oool0U03oool4000000030820P03oool0oooo
02X0oooo00<0P8200000000000000P00002h0?ooo`00o`3oool60?ooo`@00000V03oool00`20P800
000000000002000002/0oooo1000002i0?ooo`00o`3oool50?ooo`040820P00000000000000009X0
oooo00<0P8200000000000000P0000000`30`<00oooo0?ooo`0V0?ooo`050820P000000000000000
0020P800^@3oool00?l0oooo1@3oool3000000030820P03oool0oooo09X0oooo00<0P82000000000
00000P00000V0?ooo`@0000000<0P8200?ooo`3oool0^03oool00?l0oooo103oool4000009h0oooo
100000000`20P800oooo0?ooo`0S0?ooo`@0000000<0P8200?ooo`3oool0^03oool00?l0oooo0`3o
ool01@20P8000000000000000000P82009l0oooo00D0P8200410@000000000000820P00S0?ooo`05
0410@0000000000000000020P800^`3oool00?l0oooo0P3oool01020P800000000000000002S0?oo
o`@0000000<0P8200?ooo`3oool07P3oool500000;`0oooo003o0?ooo`80oooo00@0@41000000000
0000@410Y03oool01@10@4000000000000000000P82001h0oooo00<0P8200000000000000P000000
0`30`<00oooo0?ooo`2j0?ooo`00o`3oool10?ooo`@00000Y`3oool4000001`0oooo00<0P8200000
000000000P00002n0?ooo`00o`3oool10?ooo`@00000Z03oool4000001/0oooo00<0P82000000000
00000P00002n0?ooo`00o`3oool01010@400000000000020P82Y0?ooo`030<30`020P80000000080
000000<0P8200?ooo`3oool05P3oool01@20P8000000000000000000@4100;l0oooo003o0?ooo`<0
0000[03oool00`20P800000000000002000001L0oooo100000000`20P800oooo0?ooo`2m0?ooo`00
o@3oool01@20P8000000000000000000`<300:d0oooo0P20P803000000030<30`03oool0oooo0180
oooo00D0@41000000000000000000820P0300?ooo`00o@3oool400000;00oooo00<0P82000000000
00000P00000C0?ooo`@00000`@3oool00?`0oooo00@0P8200000000000000000/P3oool400000003
0820P03oool0oooo00l0oooo100000320?ooo`00n`3oool01@20P8000000000000000000P8200;<0
oooo00@0P8200410@000000000000P20P80>0?ooo`@0000000<0P8200?ooo`3oool0`03oool00?/0
oooo1000002f0?ooo`@0000000<0P8200?ooo`3oool02P3oool00`20P80000000000000200000<<0
oooo003j0?ooo`@00000^03oool4000000`0oooo100000340?ooo`00n@3oool01020P80000000000
0000002j0?ooo`030820P000000000000080000000<0`<300?ooo`3oool01P3oool01@20P8000000
000000000000@4100<@0oooo003i0?ooo`<0000000<0P8200?ooo`3oool0^P3oool4000000L0oooo
1@0000350?ooo`00n03oool400000;h0oooo00D0P82000000000000000000820P0040?ooo`030<30
`000000000000080000000<0P8200?ooo`3oool0``3oool00?L0oooo00@0P8200000000000000000
`@3oool4000000<0oooo100000370?ooo`00m`3oool300000<80oooo00<0P8200000000000000P00
00020?ooo`@00000a`3oool00?H0oooo00@0P820000000000000@410a03oool00`10@40000000000
0005000000030<30`03oool0oooo0<D0oooo003e0?ooo`@00000aP3oool700000<P0oooo003e0?oo
o`@00000b03oool400000<T0oooo003d0?ooo`040410@000000000000410@<P0oooo00<0P8200000
000000000`0000000`30`<00oooo0?ooo`350?ooo`00m03oool3000000030820P03oool0oooo0<D0
oooo200000370?ooo`00lP3oool01@30`<000000000000000000P8200<L0oooo00<0`<3000000000
00000P0000000`3oool0P82000000003000000030<30`03oool0oooo0<80oooo003b0?ooo`040820
P0000000000000000<P0oooo100000040?ooo`@00000a03oool00?80oooo0`0000390?ooo`<00000
00<0P8200?ooo`3oool00`3oool4000000030820P03oool0oooo0<00oooo003a0?ooo`<0000000<0
P8200?ooo`3oool0a@3oool00`30`<00000000000002000000L0oooo00D0P8200000000000000000
0820P0310?ooo`00l03oool400000<P0oooo00@0P82000000000000000002P3oool4000000030820
P03oool0oooo0;d0oooo003_0?ooo`040820P0000000000000000<T0oooo0`00000<0?ooo`@00000
3`3oool00`20P80000000?ooo`2]0?ooo`00k`3oool01010@400000000000010@4380?ooo`<00000
00<0@4100?ooo`3oool02P3oool00`30`<00P82000000002000000030820P03oool0oooo00P0oooo
00<0`<300820P00000000P0000000`20P800oooo0?ooo`2[0?ooo`00kP3oool400000<P0oooo1000
000@0?ooo`@000002@3oool600000:d0oooo003]0?ooo`050820P0000000000000000020P800a`3o
ool01@20P8000000000000000000P8200100oooo00<0`<300000000000000P0000000`30`<00oooo
0?ooo`020?ooo`030<30`020P800000000L00000[03oool00>`0oooo00@0P8200000000000000000
b@3oool3000000030820P03oool0oooo0180oooo100000030?ooo`/00000Z`3oool00>`0oooo00@0
P8200000000000000000b03oool4000000030820P03oool0oooo0180oooo00<0P820000000000000
0P0000020?ooo`/0000000<0P8200?ooo`3oool0Z03oool00>/0oooo00D0P8200000000000000000
0<30`0370?ooo`050820P0000000000000000020P8005P3oool01@20P800@410000000000000@410
00`0000000<0@4100?ooo`3oool0Z03oool00>/0oooo100000370?ooo`030820P000000000000080
00006@3ooolA00000:T0oooo003Z0?ooo`040410@000000000000820P<P0oooo00@0@41000000000
0000@4106`3oool@000000030820P03oool0oooo0:H0oooo003Z0?ooo`<00000b03oool400000003
0820P03oool0oooo01T0oooo4@00002X0?ooo`00j@3oool3000000030820P03oool0oooo0<H0oooo
1000000K0?oooa80000000<0P8200?ooo`3oool0Y@3oool00>P0oooo100000380?ooo`040410@000
00000000000001/0oooo00<0P820000000000000400000000`10@400oooo0?ooo`2U0?ooo`00i`3o
ool01020P80000000000000000390?ooo`<00000703ooolE00000:H0oooo003W0?ooo`<0000000<0
P8200?ooo`3oool0aP3oool3000000030820P03oool0oooo01X0oooo5@00002V0?ooo`00iP3oool0
1@20P8000000000000000000`<300<L0oooo100000000`30`<00oooo0?ooo`0I0?oooaH0000000<0
@4100?ooo`3oool0X`3oool00>D0oooo100000380?ooo`040820P00000000000000001d0oooo6000
002T0?ooo`00i03oool01@30`<000000000000000000P8200<P0oooo0`0000000`10@400oooo0?oo
o`0J0?ooo`030820P0000000000001H0000000<0P8200?ooo`3oool0X@3oool00>@0oooo0`000000
0`20P800oooo0?ooo`360?ooo`@000007@3ooolJ000000030820P03oool0oooo0:00oooo003T0?oo
o`<0000000<0P8200?ooo`3oool0a@3oool5000001l0oooo600000000`20P800oooo0?ooo`2P0?oo
o`00hP3oool01@30`<000000000000000000P8200<L0oooo00D0P82000000000000000000820P00R
0?ooo`80P8205@0000000`20P800oooo0?ooo`2O0?ooo`00hP3oool01020P8000000000000000038
0?ooo`<0000000<0P8200?ooo`3oool09@3ooolD00000:40oooo003R0?ooo`<00000b03oool40000
00030820P03oool0oooo02L0oooo00<0P8200000000000003`0000000`20P800oooo0?ooo`2N0?oo
o`00h03oool01@20P8000000000000000000P8200<L0oooo00D0`<3000000000000000000820P00]
0?ooo`80P8203P00002P0?ooo`00h03oool400000<P0oooo1000000b0?ooo`d00000W`3oool00=l0
oooo00@0@4100000000000000000b03oool01020P800000000000010@40d0?ooo`030<30`020P800
P82000T0000000<0P8200?ooo`3oool0W03oool00=l0oooo0`0000000`20P800oooo0?ooo`350?oo
o`@0000000<0P8200?ooo`3oool0=`3oool8000009h0oooo003N0?ooo`@00000b03oool4000003`0
oooo1P0000000`20P800oooo0?ooo`2K0?ooo`00g@3oool01@20P8000000000000000000P8200<L0
oooo00@0@4100000000000000000?`3oool20820P0<00000W@3oool00=d0oooo0`0000390?ooo`<0
000000<0P8200?ooo`3oool0@@3oool00`20P80000000?ooo`2K0?ooo`00g03oool400000<P0oooo
1000003R0?ooo`00f`3oool4000000030<30`03oool0oooo0<D0oooo00D0P8200000000000000000
0820P03R0?ooo`00fP3oool00`20P80000000000000200000<P0oooo0`00003T0?ooo`00fP3oool3
000000030410@03oool0oooo0<H0oooo0`0000000`10@400oooo0?ooo`1<0?ooo`030820P0000000
0000008000001@3oool01010@40000000000000000020820P8H0oooo003I0?ooo`@0000000<0P820
0?ooo`3oool0a@3oool4000004l0oooo00<0P8200000000000000P0000040?ooo`L0000000<0P820
0?ooo`3oool0P`3oool00=P0oooo1@0000370?ooo`030820P0000000000000800000C`3oool00`20
P800000000000002000000040820P03oool0oooo0?ooo`D000000P3oool00`20P800oooo0?ooo`23
0?ooo`00e`3oool01@20P8000000000000000000P8200<P0oooo00@0@410000000000000@410D@3o
ool4000000040820P03oool0oooo0820P0@0000000<0P8200?ooo`3oool00P20P8240?ooo`00e`3o
ool400000<P0oooo100000000`20P800oooo0?ooo`1?0?ooo`@0000000@0P8200?ooo`3oool0P820
100000290?ooo`00eP3oool4000000030<30`03oool0oooo0<D0oooo00D0P8200000000000000000
0820P01B0?ooo`030820P00000000000008000000P3oool00`20P800000000000002000008T0oooo
003E0?ooo`030820P0000000000000800000a`3oool00`20P800000000000002000005@0oooo1000
00020?ooo`D00000R@3oool00=D0oooo100000380?ooo`040820P00000000000000005D0oooo1@00
00000`3oool0000000000002000008X0oooo003D0?ooo`040820P0000000000000000<P0oooo00D0
P82000000000000000000820P01F0?ooo`T00000RP3oool00=<0oooo100000000`20P800oooo0?oo
o`350?ooo`030820P0000000000000800000E`3oool4000000030?ooo`000000000000800000RP3o
ool00=80oooo00<0P8200000000000000P0000380?ooo`040820P00000000000000005P0oooo1000
00020?ooo`<00000RP3oool00=80oooo00D0@41000000000000000000820P0370?ooo`040820P000
00000000000005T0oooo00<0P8200000000000000P0000020?ooo`030410@020P800oooo08T0oooo
003A0?ooo`@0000000<0P8200?ooo`3oool0aP3oool3000000030820P03oool0oooo05L0oooo00<0
P8200000000000000P0000030?ooo`800000R@3oool00=00oooo00<0P8200000000000000P000000
0`30`<00oooo0?ooo`340?ooo`030<30`0000000000000800000FP3oool00`30`<00000000000002
000000070820P03oool0oooo0?ooo`20P80000000820P0270?ooo`00c`3oool00`20P80000000000
000200000<P0oooo00@0P8200000000000000000G03oool4000000030820P03oool0oooo0080oooo
0`0000260?ooo`00c`3oool00`20P80000000000000200000<P0oooo0`0000000`20P800oooo0?oo
o`1J0?ooo`@0000000<0P8200?ooo`3oool00P3oool4000008D0oooo003>0?ooo`050820P0000000
000000000010@400b03oool4000000030<30`03oool0oooo05X0oooo00<0P8200000000000000P00
00000`3oool0`<300820P0060820P0030<30`03oool0oooo0840oooo003>0?ooo`@0000000<0P820
0?ooo`3oool0a@3oool4000005l0oooo1000002=0?ooo`00c@3oool00`20P8000000000000020000
0<L0oooo00<0P8200000000000000P00001O0?ooo`@00000S@3oool00<d0oooo100000380?ooo`04
0410@000000000000410@600oooo00<0P8200000000000000P00002<0?ooo`00c03oool400000<P0
oooo100000000`20P800oooo0?ooo`1N0?ooo`030820P0000000000000800000S03oool00</0oooo
100000000`30`<00oooo0?ooo`350?ooo`050<30`0000000000000000020P800H@3oool00`20P800
000000000002000000030<30`03oool0oooo08T0oooo003:0?ooo`030820P0000000000000800000
b03oool400000680oooo00<0P8200000000000000P0000000`20P800oooo0?ooo`290?ooo`00bP3o
ool400000<T0oooo0`00001Q0?ooo`030820P0000000000000@0000000<0P8200?ooo`3oool0R@3o
ool00<T0oooo00D0P82000000000000000000820P0370?ooo`050820P0000000000000000020P800
IP3oool30820P8/0oooo00380?ooo`030820P0000000000000800000b03oool400000?D0oooo0038
0?ooo`040410@0000000000000000<P0oooo00@0@4100000000000000000mP3oool00<L0oooo1000
00390?ooo`<0000000<0P8200?ooo`3oool0m03oool00<L0oooo0`0000000`20P800oooo0?ooo`36
0?ooo`@00000m`3oool00<D0oooo00<0`<300000000000000P0000000`30`<00oooo0?ooo`350?oo
o`050820P0000000000000000020P800m`3oool00<D0oooo00@0P8200000000000000000b@3oool3
00000?T0oooo00350?ooo`@00000b03oool400000?T0oooo00340?ooo`@0000000<0`<300?ooo`3o
ool0a@3oool4000000030<30`03oool0oooo0640oooo00@0@410000000000000@4102P3oool01@20
P8000000000000000000`<3008<0oooo00330?ooo`@00000b03oool01020P800000000000000001V
0?ooo`@00000203oool01020P80000000000000000250?ooo`00`P3oool01@20P800000000000000
0000P8200<P0oooo0`0000000`10@400oooo0?ooo`1U0?ooo`040820P000000000000410@0H0oooo
00D0P82000000000000000000<30`0250?ooo`00`P3oool3000000030820P03oool0oooo0<H0oooo
1000001Y0?ooo`040820P00000000000000000@0oooo100000270?ooo`00`@3oool4000000030820
P03oool0oooo0<D0oooo1@00001Z0?ooo`@000000P3oool01020P80000000000000000280?ooo`00
`03oool01@30`<000000000000000000P8200<L0oooo00D0`<3000000000000000000820P01/0?oo
o`050410@000000000000410@020P8000`0000000`30`<00oooo0?ooo`260?ooo`00`03oool40000
0<P0oooo1000001^0?ooo`H00000RP3oool00<00oooo0`0000390?ooo`<0000000<0P8200?ooo`3o
ool0K@3oool4000008/0oooo002n0?ooo`050820P0000000000000000020P800a`3oool00`30`<00
00000000000200000740oooo00<0@41000000030`<00R`3oool00;h0oooo100000380?ooo`040820
P0000000000000000?l0oooo0@3oool00;d0oooo00@0@4100000000000000000b03oool01020P800
000000000000003o0?ooo`80oooo002m0?ooo`<0000000<0P8200?ooo`3oool0aP3oool300000003
0820P03oool0oooo0?l0oooo002l0?ooo`@00000b03oool400000?l0oooo0`3oool00;/0oooo1000
00000`20P800oooo0?ooo`350?ooo`050820P0000000000000000020P800o`3oool30?ooo`00^P3o
ool01020P80000000000000000390?ooo`<0000000<0P8200?ooo`3oool0o`3oool20?ooo`00^P3o
ool400000<P0oooo100000000`20P800oooo0?ooo`3o0?ooo`80oooo002i0?ooo`050820P0000000
000000000030`<00a`3oool01@20P8000000000000000000P8200?l0oooo1@3oool00;P0oooo00<0
P8200000000000000P0000370?ooo`030820P0000000000000800000o`3oool60?ooo`00^03oool0
1010@400000000000020P8380?ooo`040410@000000000000410@?l0oooo1`3oool00;L0oooo0`00
00000`20P800oooo0?ooo`360?ooo`@0000000<0P8200?ooo`3oool0o`3oool50?ooo`00]`3oool3
000000030820P03oool0oooo0<H0oooo1000003o0?ooo`P0oooo002e0?ooo`050<30`00000000000
00000020P800b03oool01010@400000000000000003o0?ooo`T0oooo002e0?ooo`040820P0000000
000000000<T0oooo0`00003o0?ooo`X0oooo002d0?ooo`050820P0000000000000000030`<00a`3o
ool01@20P8000000000000000000P8200?l0oooo2P3oool00;@0oooo100000380?ooo`@00000o`3o
ool;0?ooo`00/`3oool01020P80000000000000000380?ooo`040820P0000000000000000?l0oooo
303oool00;<0oooo0`0000390?ooo`<0000000<0@4100?ooo`3oool0o`3oool:0?ooo`00/P3oool3
000000030820P03oool0oooo0<H0oooo1000003o0?ooo`d0oooo002a0?ooo`@00000b03oool00`20
P80000000000000200000?l0oooo3@3oool00;00oooo00D0`<3000000000000000000820P0380?oo
o`040410@000000000000820P?l0oooo3P3oool00;00oooo0`0000000`20P800oooo0?ooo`360?oo
o`@00000o`3oool?0?ooo`00[`3oool01@20P8000000000000000000`<300<L0oooo00D0P8200000
0000000000000<30`03o0?ooo`l0oooo002^0?ooo`@00000b03oool00`20P8000000000000020000
0?l0oooo403oool00:h0oooo100000380?ooo`040820P0000000000000000?l0oooo4@3oool00:d0
oooo00@0@410000000000000@410b03oool01@20P8000000000000000000P8200?l0oooo4@3oool0
0:d0oooo0`0000000`20P800oooo0?ooo`360?ooo`@00000o`3ooolB0?ooo`00[03oool400000<P0
oooo1000003o0?oooa<0oooo002[0?ooo`040410@0000000000000000<P0oooo00D0P82000000000
000000000820P03o0?oooa<0oooo002[0?ooo`<00000b@3oool3000000030820P03oool0oooo0?l0
oooo4P3oool00:T0oooo00D0P82000000000000000000820P0380?ooo`@00000o`3ooolE0?ooo`00
Z@3oool400000<P0oooo00@0P8200000000000000000o`3ooolF0?ooo`00Z03oool01020P8000000
0000000000390?ooo`<00000o`3ooolG0?ooo`00Z03oool3000000030410@03oool0oooo0<H0oooo
0`0000000`10@400oooo0?ooo`3o0?oooaD0oooo002W0?ooo`@00000b03oool400000?l0oooo603o
ool00:H0oooo1@0000370?ooo`030820P0000000000000800000o`3ooolH0?ooo`00Y@3oool01@30
`<000000000000000000P8200<P0oooo00@0@410000000000000@410o`3ooolI0?ooo`00Y@3oool4
00000<P0oooo100000000`20P800oooo0?ooo`3o0?oooaL0oooo002T0?ooo`050820P00000000000
00000030`<00a`3oool01@20P8000000000000000000P8200?l0oooo6P3oool00:<0oooo00<0P820
0000000000000P0000370?ooo`040820P0000000000000000?l0oooo703oool00:<0oooo00@0P820
0000000000000000b03oool01020P800000000000000003o0?oooa`0oooo002R0?ooo`040820P000
0000000000000<P0oooo00D0P82000000000000000000<30`03o0?oooa`0oooo002R0?ooo`<00000
00<0P8200?ooo`3oool0aP3oool400000?l0oooo7@3oool00:00oooo00<0`<300000000000000P00
00380?ooo`040410@000000000000820P?l0oooo7P3oool00:00oooo00@0P8200000000000000000
b@3oool300000?l0oooo7`3oool00:00oooo0`0000000`20P800oooo0?ooo`360?ooo`<0000000<0
P8200?ooo`3oool0o`3ooolM0?ooo`00W`3oool4000000030<30`03oool0oooo0<D0oooo1000003o
0?ooob00oooo002N0?ooo`030820P0000000000000800000a`3oool01020P800000000000000003o
0?ooob40oooo002N0?ooo`@00000b03oool3000000030820P03oool0oooo0?l0oooo7`3oool009d0
oooo100000380?ooo`050820P0000000000000000030`<00o`3ooolQ0?ooo`00W03oool400000003
0820P03oool0oooo0<D0oooo00@0P8200000000000000000o`3ooolS0?ooo`00V`3oool00`20P800
00000000000200000<P0oooo00@0@410000000000000P820o`3ooolS0?ooo`00V`3oool400000<P0
oooo0`0000000`20P800oooo0?ooo`3o0?ooob80oooo002J0?ooo`@0000000<0P8200?ooo`3oool0
a@3oool4000000030820P03oool0oooo0?l0oooo8P3oool009T0oooo00<0P8200000000000000P00
00000`30`<00oooo0?ooo`340?ooo`050<30`0000000000000000020P800o`3ooolU0?ooo`00V03o
ool00`20P80000000000000200000<P0oooo1000003o0?ooobH0oooo002H0?ooo`030820P0000000
000000800000b03oool3000000030820P03oool0oooo0?l0oooo903oool009L0oooo00D0P8200000
0000000000000410@0370?ooo`030820P0000000000000800000o`3ooolW0?ooo`00U`3oool40000
00030820P03oool0oooo0<D0oooo1000003o0?ooobP0oooo002F0?ooo`050410@000000000000000
0020P800a`3oool01010@400000000000000003o0?ooobT0oooo002F0?ooo`@00000b03oool30000
00030820P03oool0oooo0?l0oooo9`3oool009D0oooo100000380?ooo`@00000o`3ooolZ0?ooo`00
U03oool4000000030820P03oool0oooo0<D0oooo00D0P82000000000000000000820P03o0?ooobX0
oooo002C0?ooo`030820P0000000000000800000b03oool300000?l0oooo;03oool009<0oooo1000
00380?ooo`@00000o`3oool/0?ooo`00TP3oool4000000030410@03oool0oooo0<D0oooo00D0P820
00000000000000000<30`03o0?ooob`0oooo002A0?ooo`D00000a`3oool00`20P800000000000002
00000?l0oooo;@3oool00900oooo00<0P8200000000000000P0000380?ooo`<0000000<0@4100?oo
o`3oool0o`3oool/0?ooo`00T03oool400000<P0oooo100000000`20P800oooo0?ooo`3o0?ooob`0
oooo002?0?ooo`@0000000<0P8200?ooo`3oool0a@3oool500000?l0oooo;`3oool008h0oooo00<0
`<300000000000000P0000000`30`<00oooo0?ooo`340?ooo`030<30`0000000000000800000o`3o
ool`0?ooo`00SP3oool400000<P0oooo1000003o0?oooc40oooo002=0?ooo`050820P00000000000
00000020P800a`3oool01@20P8000000000000000000P8200?l0oooo<@3oool008`0oooo10000000
0`20P800oooo0?ooo`350?ooo`030820P0000000000000800000o`3ooolb0?ooo`00S03oool40000
00030820P03oool0oooo0<D0oooo00@0P8200000000000000000o`3ooolc0?ooo`00R`3oool01@10
@4000000000000000000P8200<L0oooo00D0P82000000000000000000820P03o0?oooc<0oooo002;
0?ooo`@00000a`3oool4000000030820P03oool0oooo0?l0oooo<P3oool008X0oooo100000000`20
P800oooo0?ooo`350?ooo`@0000000<0P8200?ooo`3oool0o`3ooolb0?ooo`00R@3oool00`20P800
00000000000200000<L0oooo00D0@41000000000000000000820P03o0?ooocD0oooo00290?ooo`@0
0000b03oool400000?l0oooo=P3oool008L0oooo00<0P8200000000000000P0000370?ooo`030<30
`000000000000080000000<0`<300?ooo`3oool0o`3ooold0?ooo`00Q`3oool4000000030820P03o
ool0oooo0<D0oooo00<0P8200000000000000P00003o0?ooocL0oooo00260?ooo`030820P0000000
000000800000b03oool400000?l0oooo>03oool008H0oooo100000380?ooo`@00000o`3oooli0?oo
o`00Q@3oool4000000030820P03oool0oooo0<D0oooo100000000`20P800oooo0?ooo`3o0?ooocL0
oooo00240?ooo`D00000b03oool400000?l0oooo>P3oool008<0oooo00<0`<300000000000000P00
00000`20P800oooo0?ooo`350?ooo`040410@0000000000000000?l0oooo>`3oool008<0oooo1000
00390?ooo`<0000000<0P8200?ooo`3oool0o`3oooli0?ooo`00PP3oool01@20P800000000000000
0000@4100<L0oooo00<0P8200000000000000P00003o0?oooc`0oooo00210?ooo`030820P0000000
000000800000b03oool400000?l0oooo?@3oool00840oooo00<0P8200000000000000P0000370?oo
o`040820P0000000000000000?l0oooo?P3oool00800oooo00D0P82000000000000000000820P038
0?ooo`<0000000<0@4100?ooo`3oool0o`3oooll0?ooo`00P03oool400000<P0oooo1000003o0?oo
ocl0oooo001o0?ooo`@0000000<0P8200?ooo`3oool0aP3oool300000?l0oooo@03oool007h0oooo
00<0P8200000000000000P0000380?ooo`040410@000000000000820P?l0oooo@03oool007h0oooo
100000390?ooo`80000000<0P8200?ooo`3oool0o`3ooolo0?ooo`00O@3oool4000000030820P03o
ool0oooo0<D0oooo00D0P82000000000000000000<30`03o0?oood40oooo001l0?ooo`D00000b03o
ool300000?l0oooo@`3oool007`0oooo100000380?ooo`040820P000000000000820P?l0oooo@`3o
ool007/0oooo00D0@41000000000000000000820P0380?ooo`<0000000<0`<300?ooo`3oool0o`3o
oom10?ooo`00N`3oool3000000030820P03oool0oooo0<H0oooo0`00003o0?ooodD0oooo001i0?oo
o`030<30`0000000000000800000b03oool3000000030820P03oool0oooo0?l0oooo@`3oool007T0
oooo00@0P8200000000000000000b03oool01020P800000000000020P83o0?ooodH0oooo001i0?oo
o`<00000b@3oool3000000030820P03oool0oooo0?l0ooooA03oool007P0oooo00@0P82000000000
0000@410b03oool01020P800000000000020P83o0?ooodL0oooo001g0?ooo`@00000b03oool01020
P800000000000000003o0?ooodP0oooo001g0?ooo`<00000b@3oool00`20P80000000000003o0?oo
odT0oooo001f0?ooo`040410@000000000000410@<P0oooo00@0P820000000000000@410o`3ooom9
0?ooo`00M@3oool400000<P0oooo1000003o0?ooodX0oooo001d0?ooo`050<30`000000000000000
0020P800a`3oool01@30`<000000000000000000P8200?l0ooooBP3oool007@0oooo0`0000390?oo
o`<0000000<0P8200?ooo`3oool0o`3ooom90?ooo`00M03oool5000000030820P03oool0oooo0<@0
oooo0`0000000`20P800oooo0?ooo`3o0?ooodT0oooo001c0?ooo`030820P010@400000000D00000
00<0P8200?ooo`3oool0`03oool01@30`<000000000000000000P8200?l0ooooC03oool007H0oooo
00<0P8200000000000001@0000000`20P800oooo0?ooo`2m0?ooo`040820P0000000000000000?l0
ooooC@3oool007T0oooo1`00002n0?ooo`<00000o`3ooom>0?ooo`00NP3oool00`20P800@4100000
000500000080P820^@3oool3000000030820P03oool0oooo0?l0ooooC03oool007h0oooo2000002f
0?ooo`@00000o`3ooom?0?ooo`00O`3oool20820P0030410@0000000000000@0000000<0P8200<30
`03oool0/03oool01020P800000000000000003o0?oooe00oooo00230?ooo`030820P00000000000
00D0000000<0P8200?ooo`3oool0[@3oool3000000030820P03oool0oooo0?l0ooooCP3oool008D0
oooo2000002]0?ooo`@00000o`3ooomA0?ooo`00Q`3oool20820P0H000000P20P82X0?ooo`050820
P0000000000000000020P800o`3ooomA0?ooo`00RP3oool900000:D0oooo00@0P820000000000000
0000o`3ooomC0?ooo`00S03oool20820P0L000000P20P82Q0?ooo`040410@000000000000410@?l0
ooooD`3oool00900oooo2@00002N0?ooo`@0000000<0P8200?ooo`3oool0o`3ooomA0?ooo`00T@3o
ool:000000030820P03oool0oooo09T0oooo1000003o0?oooe@0oooo002C0?ooo`030<30`020P800
P82000L000000P20P82G0?ooo`040410@0000000000000000?l0ooooE@3oool009P0oooo20000000
0`20P800oooo0?ooo`2C0?ooo`<00000o`3ooomF0?ooo`00VP3oool8000009<0oooo0`0000000`20
P800oooo0?ooo`3o0?oooe@0oooo002K0?ooo`030<30`020P800P82000D0000000<0@4100820P030
`<00SP3oool4000000030<30`03oool0oooo0?l0ooooE03oool009l0oooo2000002<0?ooo`040820
P0000000000000000?l0ooooF03oool00:00oooo00<0`<300820P020P8001@0000000`10@400P820
0820P0280?ooo`<0000000<0@4100?ooo`3oool0o`3ooomF0?ooo`00Y03oool8000008H0oooo1000
003o0?oooeT0oooo002V0?ooo`P00000P`3oool00`20P80000000000000200000?l0ooooF@3oool0
0:P0oooo0P20P80600000080P820O`3oool01010@400000000000020P83o0?oooeX0oooo002]0?oo
o`L00000O03oool3000000030820P03oool0oooo0?l0ooooF@3oool00:l0oooo1P0000000`20P800
oooo0?ooo`1g0?ooo`@0000000<0P8200?ooo`3oool0o`3ooomI0?ooo`00/@3oool20820P0D00000
0P20P81d0?ooo`050<30`0000000000000000020P800o`3ooomL0?ooo`00]@3oool6000007<0oooo
1000003o0?oooed0oooo002f0?ooo`80P8201@0000000`10@400P8200?ooo`1]0?ooo`050820P000
0000000000000030`<00o`3ooomM0?ooo`00^@3oool8000006/0oooo1000003o0?oooel0oooo002j
0?ooo`030820P0000000000000D0000000<0P8200?ooo`3oool0IP3oool00`20P800000000000002
00000?l0ooooG`3oool00;`0oooo00<0P8200410@00000001P0000000`20P800oooo0?ooo`1S0?oo
o`040410@000000000000410@?l0ooooH03oool00<00oooo200000000`20P800oooo0?ooo`1O0?oo
o`@00000o`3ooomQ0?ooo`00`P3oool8000000030820P03oool0oooo05d0oooo1000003o0?ooof40
oooo00330?ooo`80P82000<0@410000000000000100000020820P5/0oooo00@0P820000000000000
P820o`3ooomR0?ooo`00b03oool8000005T0oooo0`00003o0?ooof<0oooo00390?ooo`80P8201`00
00020820P5@0oooo0`0000000`30`<00oooo0?ooo`3o0?ooof40oooo003=0?ooo`P0000000<0P820
0?ooo`3oool0C`3oool400000?l0ooooI03oool00<l0oooo200000000`20P800oooo0?ooo`1<0?oo
o`040820P0000000000000000?l0ooooI@3oool00=40oooo00<0P8200410@00000001@0000020820
P4/0oooo00@0@410000000000000P820o`3ooomU0?ooo`00e@3oool8000004T0oooo0`00003o0?oo
ofH0oooo003G0?ooo`030820P0000000000000D0000000<0P8200?ooo`3oool0@P3oool01020P800
000000000000003o0?ooofL0oooo003J0?ooo`030820P0000000000000D0000000<0P8200?ooo`3o
ool0?`3oool300000?l0ooooJ03oool00=`0oooo2000000o0?ooo`040820P000000000000820P?l0
ooooJ03oool00=h0oooo00<0P8200410@00000001@0000000`20P800`<300?ooo`0j0?ooo`<00000
00<0`<300?ooo`3oool0o`3ooomV0?ooo`00hP3oool8000003P0oooo0`00003o0?ooofX0oooo003S
0?ooo`P00000=P3oool01020P800000000000000003o0?ooofX0oooo003U0?ooo`80P82000<0@410
0000000000000`0000020820P0030<30`03oool0oooo02l0oooo00<0@41000000010@400o`3ooom[
0?ooo`00jP3oool8000002h0oooo0`0000000`20P800oooo0?ooo`3o0?ooofT0oooo003/0?ooo`03
0820P0000000000000@000000P20P80Z0?ooo`040820P000000000000820P?l0ooooK03oool00>l0
oooo00<0P8200000000000001@00000W0?ooo`040820P0000000000000000?l0ooooK@3oool00?40
oooo1`00000V0?ooo`040820P000000000000820P?l0ooooK@3oool00?80oooo00<0`<300820P000
00001@0000020820P240oooo00@0P8200000000000000000o`3ooom^0?ooo`00m@3oool9000001l0
oooo0`00003o0?ooofl0oooo003g0?ooo`T00000703oool00`20P80000000000003o0?ooog00oooo
003i0?ooo`80P8201P0000000`10@400P8200820P00G0?ooo`040820P000000000000410@?l0oooo
L03oool00?d0oooo2@00000D0?ooo`@00000o`3oooma0?ooo`00o`3oool20820P0L0000000<0P820
0<30`03oool03P3oool01@30`<000000000000000000P8200?l0ooooL@3oool00?l0oooo0`3oool9
000000h0oooo0`0000000`20P800oooo0?ooo`3o0?ooog00oooo003o0?ooo`H0oooo1`0000000`20
P800oooo0?ooo`0:0?ooo`<0000000<0P8200?ooo`3oool0o`3ooom`0?ooo`00o`3oool80?ooo`03
0<30`020P800000000@0000000<0@4100820P03oool01P3oool01@20P8000000000000000000P820
0?l0ooooL`3oool00?l0oooo2`3oool9000000@0oooo1000003o0?ooog@0oooo003o0?ooo`d0oooo
200000000`20P800oooo0820P00300000?l0ooooM@3oool00?l0oooo3`3oool00`20P80000000000
0004000000050820P0000000000000000020P800o`3ooome0?ooo`00o`3ooolC0?ooo`L00000o`3o
oomf0?ooo`00o`3ooolE0?ooo`050<30`020P800000000000020P800o`3ooomf0?ooo`00o`3ooooo
0?oooi00oooo003o0?ooool0ooooT03oool00?l0ooooo`3ooon@0?ooo`00o`3ooooo0?oooi00oooo
003o0?ooool0ooooT03oool00?l0ooooo`3ooon@0?ooo`00o`3ooooo0?oooi00oooo003o0?ooool0
ooooT03oool00?l0ooooo`3ooon@0?ooo`00o`3ooooo0?oooi00oooo003o0?ooool0ooooT03oool0
0?l0ooooo`3ooon@0?ooo`00o`3ooooo0?oooi00oooo003o0?ooool0ooooT03oool00?l0ooooo`3o
oon@0?ooo`00o`3ooooo0?oooi00oooo003o0?ooool0ooooT03oool00?l0ooooo`3ooon@0?ooo`00
o`3ooooo0?oooi00oooo003o0?ooool0ooooT03oool00?l0ooooo`3ooon@0?ooo`00\
\>"], "Picture",
  Evaluatable->False,
  ImageSize->{180.438, 238.188},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Fig. 5.2 Location of a plane of constant phase ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " at time ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  "."
}], "Caption",
  CellTags->"Fig. 5.2"]
}, Closed]],

Cell[CellGroupData[{

Cell["Group Velocity in an Isotropic Medium", "Section",
  CellTags->"c:13"],

Cell[TextData[{
  "\tIf a system is isotropic, so that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\)]],
  " depends only on the magnitude of ",
  Cell[BoxData[
      FormBox[
        StyleBox["k",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " and not its direction, then the group velocity simplifies somewhat.  The \
definition of the group velocity, Equation ",
  ButtonBox["(5.1.42)",
    ButtonData:>"(5.1.42)",
    ButtonStyle->"Hyperlink"],
  ",  implies that"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            SubscriptBox[
              StyleBox["v",
                FontWeight->"Bold",
                FontSlant->"Plain"], "g"], "(", 
            StyleBox["k",
              FontWeight->"Bold",
              FontSlant->"Plain"], ")"}], "=", 
          RowBox[{
            RowBox[{
              FractionBox["\[PartialD]", 
                RowBox[{"\[PartialD]", 
                  StyleBox["k",
                    FontWeight->"Bold",
                    FontSlant->"Plain"]}]], \(\[Omega](k)\)}], "=", 
            RowBox[{
              FractionBox[\(\[PartialD]k\), 
                RowBox[{"\[PartialD]", 
                  StyleBox["k",
                    
                    FontWeight->
                      "Bold"]}]], \(\[PartialD]\[Omega]\/\[PartialD]k\)}]}]}],
         TraditionalForm]]],
  ", "
}], "Text"],

Cell["\<\
where the second equality follows from the chain rule. \
However,\
\>", "Text"],

Cell[TextData[{
  "\t\t ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FractionBox[\(\[PartialD]k\), 
            RowBox[{"\[PartialD]", 
              StyleBox["k",
                FontWeight->"Bold",
                FontSlant->"Plain"]}]], "=", 
          
          RowBox[{\(\((\[PartialD]\/\[PartialD]k\_x, \
\[PartialD]\/\[PartialD]k\_y, \[PartialD]\/\[PartialD]k\_z)\) \@\(k\_x\^2 + k\
\_y\^2 + k\_z\^2\)\), "=", 
            RowBox[{\((k\_x\/k, k\_y\/k, k\_z\/k)\), "=", 
              OverscriptBox[
                StyleBox["k",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "^"]}]}]}], TraditionalForm]]],
  ", \nwhere ",
  Cell[BoxData[
      FormBox[
        OverscriptBox[
          StyleBox["k",
            FontWeight->"Bold",
            FontSlant->"Plain"], "^"], TraditionalForm]]],
  " is a unit vector in the direction of ",
  Cell[BoxData[
      FormBox[
        StyleBox["k",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  ". Thus, the group velocity is"
}], "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox[
            StyleBox["v",
              FontWeight->"Bold",
              FontSlant->"Plain"], "g"], "(", 
          StyleBox["k",
            FontWeight->"Bold",
            FontSlant->"Plain"], ")"}], TraditionalForm]]],
  "=",
  Cell[BoxData[
      FormBox[
        OverscriptBox[
          StyleBox["k",
            FontWeight->"Bold",
            FontSlant->"Plain"], "^"], TraditionalForm]]],
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\[Omega]\/\[PartialD]k\)]],
  "."
}], "NumberedEquation",
  CellTags->{"i:20", "(5.1.43)"}],

Cell[TextData[{
  "In an isotropic system, the group and phase velocities are both along ",
  Cell[BoxData[
      FormBox[
        StyleBox["k",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  ", although they are generally of different magnitudes."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["The Wave Equation  in Three Dimensions", "Section",
  CellTags->"c:14"],

Cell[CellGroupData[{

Cell["The Initial-Value Problem", "Subsubsection"],

Cell["\<\
Let's now consider the wave equation for propagation in two or \
three dimensions, \
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(\[PartialD]\^2\/\[PartialD]t\^2\), 
            RowBox[{"p", "(", 
              RowBox[{
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox[",",
                  FontWeight->"Plain"], 
                StyleBox["t",
                  FontWeight->"Plain"]}], 
              StyleBox[")",
                FontWeight->"Plain"]}]}], "=", " ", 
          RowBox[{\(c\^2\), 
            RowBox[{\(\[Del]\^2\), 
              RowBox[{"p", 
                StyleBox["(",
                  FontWeight->"Plain"], 
                RowBox[{
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], ",", "t"}], ")"}], " "}]}]}], 
        TraditionalForm]]],
  "."
}], "NumberedEquation",
  CellTags->"(5.1.44)"],

Cell[TextData[{
  "Here we are thinking of ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  " as the pressure in a compressional sound wave, and ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  " as the speed of sound. However, this same  equation applies to the \
propagation of light waves, and in two dimensions it applies to waves on a \
drumhead, or on the surface of water (with a suitable reinterpretation of the \
meaning of the symbols ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  ") .  "
}], "Text"],

Cell[TextData[{
  "\tEquation ",
  ButtonBox["(5.1.44)",
    ButtonData:>"(5.1.44)",
    ButtonStyle->"Hyperlink"],
  " must be supplemented by two initial conditions,"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"p", "(", 
            RowBox[{
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[",",
                FontWeight->"Plain"], 
              StyleBox["0",
                FontWeight->"Plain"]}], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{
            StyleBox[\(p\_o\),
              FontWeight->"Plain"], "(", 
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[")",
              FontWeight->"Plain"]}]}], ",", "\[IndentingNewLine]", 
        RowBox[{
          RowBox[{\(\[PartialD]p\/\[PartialD]t\), 
            RowBox[{"(", 
              RowBox[{
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox[",",
                  FontWeight->"Plain"], 
                StyleBox["0",
                  FontWeight->"Plain"]}], ")"}]}], "=", 
          RowBox[{
            RowBox[{\(v\_o\), "(", 
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], ")"}], ".", Cell[""]}]}]}], 
      TraditionalForm]]]], "NumberedEquation",
  CellTags->"(5.1.45)"],

Cell[TextData[{
  "\tThe solution for ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  " follows from Fourier transformation with respect to ",
  Cell[BoxData[
      FormBox[
        StyleBox["r",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  ". The Fourier transform of ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(p\&~\), "(", 
          RowBox[{
            StyleBox["k",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[",",
              FontWeight->"Plain"], 
            StyleBox["t",
              FontWeight->"Plain"]}], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  ", satisfies the second-order ODE"
}], "Text",
  CellTags->"i:59"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(\[PartialD]\^2\/\[PartialD]t\^2\), 
            RowBox[{\(p\&~\), "(", 
              RowBox[{
                StyleBox["k",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox[",",
                  FontWeight->"Plain"], 
                StyleBox["t",
                  FontWeight->"Plain"]}], 
              StyleBox[")",
                FontWeight->"Plain"]}]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{
            StyleBox[\(-c\^\(\(2\)\(\ \)\)\),
              FontWeight->"Plain"], 
            StyleBox[\(k\^2\),
              FontWeight->"Plain"], 
            RowBox[{\(p\&~\), "(", 
              RowBox[{
                StyleBox["k",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox[",",
                  FontWeight->"Plain"], 
                StyleBox["t",
                  FontWeight->"Plain"]}], 
              StyleBox[")",
                FontWeight->"Plain"]}]}]}], TraditionalForm]]],
  "."
}], "NumberedEquation",
  CellTags->"(5.1.46)"],

Cell["Therefore, ", "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"p", "(", 
            RowBox[{
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[",",
                FontWeight->"Plain"], 
              StyleBox["t",
                FontWeight->"Plain"]}], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{
            RowBox[{"\[Integral]", 
              
              RowBox[{\(\(\(\[DifferentialD]\^3 
                      k\)\(\ \)\)\/\((2  \[Pi])\)\^3\), 
                RowBox[{"C", "(", 
                  StyleBox["k",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], 
                  StyleBox[")",
                    FontWeight->"Plain"]}], 
                StyleBox[" ",
                  FontWeight->"Plain"], 
                StyleBox[
                  SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"\[ImaginaryI]", " ", 
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{
                            StyleBox["k",
                              FontWeight->"Bold",
                              FontSlant->"Plain"], "\[CenterDot]", 
                            StyleBox["r",
                              FontWeight->"Bold",
                              FontSlant->"Plain"]}], 
                          StyleBox["-",
                            FontWeight->"Bold"], 
                          RowBox[{
                            RowBox[{
                              StyleBox["\[Omega]",
                                FontWeight->"Plain"], "(", "k", 
                              StyleBox[")",
                                FontWeight->"Plain"]}], 
                            StyleBox["t",
                              FontWeight->"Plain"]}]}], 
                        StyleBox[")",
                          FontWeight->"Plain"]}]}]],
                  FontWeight->"Plain"]}]}], 
            StyleBox["+",
              FontWeight->"Plain"], 
            RowBox[{"\[Integral]", 
              
              RowBox[{\(\(\(\[DifferentialD]\^3 
                      k\)\(\ \)\)\/\((2  \[Pi])\)\^3\), " ", 
                RowBox[{"D", "(", 
                  StyleBox["k",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], 
                  StyleBox[")",
                    FontWeight->"Plain"]}], 
                StyleBox[" ",
                  FontWeight->"Plain"], 
                StyleBox[
                  SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"\[ImaginaryI]", " ", 
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{
                            StyleBox["k",
                              FontWeight->"Bold",
                              FontSlant->"Plain"], "\[CenterDot]", 
                            StyleBox["r",
                              FontWeight->"Bold",
                              FontSlant->"Plain"]}], 
                          StyleBox["+",
                            FontWeight->"Bold"], 
                          RowBox[{
                            RowBox[{
                              StyleBox["\[Omega]",
                                FontWeight->"Plain"], "(", "k", 
                              StyleBox[")",
                                FontWeight->"Plain"]}], 
                            StyleBox["t",
                              FontWeight->"Plain"]}]}], 
                        StyleBox[")",
                          FontWeight->"Plain"]}]}]],
                  FontWeight->"Plain"]}]}]}]}], TraditionalForm]]],
  ","
}], "NumberedEquation",
  CellTags->"(5.1.47)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        RowBox[{"C", "(", 
          StyleBox["k",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{"D", "(", 
          StyleBox["k",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  " are undetermined coefficients, and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega](k) = c\ k\)]],
  " is the dispersion relation for the waves, ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  " being the magnitude of the wave vector ",
  Cell[BoxData[
      FormBox[
        StyleBox["k",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  ". The functions ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{
            FormBox[
              RowBox[{"C", "(", 
                StyleBox["k",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox[")",
                  FontWeight->"Plain"]}],
              "TraditionalForm"], "and", 
            FormBox[
              RowBox[{"D", "(", 
                StyleBox["k",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox[")",
                  FontWeight->"Plain"]}],
              "TraditionalForm"]}]}], TraditionalForm]]],
  " are found by matching to the two initial conditions ",
  ButtonBox["(5.1.45)",
    ButtonData:>"(5.1.45)",
    ButtonStyle->"Hyperlink"],
  ". Evaluation of Eq. ",
  ButtonBox["(5.1.47)",
    ButtonData:>"(5.1.47)",
    ButtonStyle->"Hyperlink"],
  " and its time derivative at time ",
  Cell[BoxData[
      \(TraditionalForm\`t = 0\)]],
  " yields, after Fourier transformation,  two equations for ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{
            FormBox[
              RowBox[{"C", "(", 
                StyleBox["k",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox[")",
                  FontWeight->"Plain"]}],
              "TraditionalForm"], "and", 
            FormBox[
              RowBox[{"D", "(", 
                StyleBox["k",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox[")",
                  FontWeight->"Plain"]}],
              "TraditionalForm"]}]}], TraditionalForm]]],
  ". Following the same approach as in the 1D case studied in Sec. ",
  ButtonBox["5.1.1",
    ButtonData:>"c:4",
    ButtonStyle->"Hyperlink"],
  ", we obtain"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"C", "(", 
            StyleBox["k",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox[" ",
            FontWeight->"Plain"], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{\(1\/2\), "[", 
            RowBox[{
              RowBox[{
                StyleBox[\(p\&~\_o\),
                  FontWeight->"Plain"], "(", 
                StyleBox["k",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox[")",
                  FontWeight->"Plain"]}], 
              StyleBox["+",
                FontWeight->"Plain"], 
              StyleBox[" ",
                FontWeight->"Plain"], 
              RowBox[{
                StyleBox["\[ImaginaryI]",
                  FontWeight->"Plain"], 
                StyleBox[" ",
                  FontWeight->"Plain"], 
                RowBox[{
                  RowBox[{
                    StyleBox[\(v\&~\_o\),
                      FontWeight->"Plain"], "(", 
                    StyleBox["k",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], 
                    StyleBox[")",
                      FontWeight->"Plain"]}], 
                  StyleBox["/",
                    FontWeight->"Plain"], 
                  StyleBox[\(\[Omega](k)\),
                    FontWeight->"Plain"]}]}]}], 
            StyleBox["]",
              FontWeight->"Plain"]}]}], 
        StyleBox[",",
          FontWeight->"Plain"], "\[IndentingNewLine]", 
        RowBox[{
          RowBox[{"D", "(", 
            StyleBox["k",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox[" ",
            FontWeight->"Plain"], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{\(1\/2\), "[", 
            RowBox[{
              RowBox[{
                StyleBox[\(p\&~\_o\),
                  FontWeight->"Plain"], "(", 
                StyleBox["k",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox[")",
                  FontWeight->"Plain"]}], 
              StyleBox["-",
                FontWeight->"Plain"], 
              StyleBox[" ",
                FontWeight->"Plain"], 
              RowBox[{
                StyleBox["\[ImaginaryI]",
                  FontWeight->"Plain"], 
                StyleBox[" ",
                  FontWeight->"Plain"], 
                RowBox[{
                  RowBox[{
                    StyleBox[\(v\&~\_o\),
                      FontWeight->"Plain"], "(", 
                    StyleBox["k",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], 
                    StyleBox[")",
                      FontWeight->"Plain"]}], 
                  StyleBox["/",
                    FontWeight->"Plain"], 
                  StyleBox[\(\[Omega](k)\),
                    FontWeight->"Plain"]}]}]}], 
            StyleBox["]",
              FontWeight->"Plain"]}]}], 
        StyleBox[",",
          FontWeight->"Plain"], 
        StyleBox[" ",
          FontWeight->"Plain"]}], TraditionalForm]]]], "NumberedEquation",
  CellTags->"(5.1.48)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(p\&~\_o\),
          FontWeight->"Plain"], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        StyleBox[\(v\&~\_o\),
          FontWeight->"Plain"], TraditionalForm]]],
  " are the Fourier transforms of the initial conditions. Equations ",
  ButtonBox["(5.1.47)",
    ButtonData:>"(5.1.47)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(5.1.48)",
    ButtonData:>"(5.1.48)",
    ButtonStyle->"Hyperlink"],
  " are the solution to the problem. "
}], "Text"],

Cell[TextData[{
  "\t However, the form of  Eq. ",
  ButtonBox["(5.1.47)",
    ButtonData:>"(5.1.47)",
    ButtonStyle->"Hyperlink"],
  " can be inconvenient in some applications, for the following reason: for \
given wavenumber ",
  Cell[BoxData[
      FormBox[
        StyleBox["k",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  ", there are ",
  StyleBox["two",
    FontSlant->"Italic"],
  " possible frequencies appearing in Eq. ",
  ButtonBox["(5.1.47)",
    ButtonData:>"(5.1.47)",
    ButtonStyle->"Hyperlink"],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`\(\[PlusMinus]\(\[Omega](k)\)\)\)]],
  ". These two choices merely correspond to wave propagation with and against \
the direction of ",
  Cell[BoxData[
      FormBox[
        StyleBox["k",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  ". However,  this implies that there are now ",
  StyleBox["two",
    FontSlant->"Italic"],
  " group velocities and",
  StyleBox[" two",
    FontSlant->"Italic"],
  " phase velocities for every value of ",
  Cell[BoxData[
      FormBox[
        StyleBox["k",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  ", each pair with equal magnitude but opposite direction. This occurs \
because the wave equation is second-order in time, so the dispersion relation \
is a polynomial in ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\)]],
  " of order 2, with two solutions. This was not the case for the solution to \
 Schr\[ODoubleDot]dinger's equation,  Eq. ",
  ButtonBox["(5.1.38)",
    ButtonData:>"(5.1.38)",
    ButtonStyle->"Hyperlink"],
  ", because that equation is first-order in time."
}], "Text"],

Cell[TextData[{
  "\t In fact, for more general wave equations (such as vector wave \
equations, or scalar wave equations of order 3 or higher in time), there can \
be multiple roots to the dispersion relation,  ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Omega]\_i\), "(", 
          StyleBox["k",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`i = 1, 2,  ... , \)]],
  ".  Each of the roots gets its own Fourier integral in Eq. ",
  ButtonBox["(5.1.47)",
    ButtonData:>"(5.1.47)",
    ButtonStyle->"Hyperlink"],
  ". Such equations describe wave propagation through media such as plasmas \
or solids.  The multiple dispersion relations correspond to physically \
different modes of propagation, such as shear and compressional waves in the \
case of a solid. "
}], "Text"],

Cell[TextData[{
  "\t However,  Eq. ",
  ButtonBox["(5.1.44)",
    ButtonData:>"(5.1.44)",
    ButtonStyle->"Hyperlink"],
  " describes only one type of wave, and it should be possible to simplify \
the solution to reflect this fact.  Indeed, we will now show that Eq. ",
  ButtonBox["(5.1.47)",
    ButtonData:>"(5.1.47)",
    ButtonStyle->"Hyperlink"],
  "  can be simplified, because our system is isotropic. Recall that an \
isotropic system is one that looks the same in all directions, and in \
particular, the dispersion relation depends only on the magnitude of ",
  Cell[BoxData[
      FormBox[
        StyleBox["k",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega] = \[Omega](k)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\tBecause of isotropy, we can write Eq. ",
  ButtonBox["(5.1.47)",
    ButtonData:>"(5.1.47)",
    ButtonStyle->"Hyperlink"],
  " in a form where there is only one frequency for each value of ",
  Cell[BoxData[
      FormBox[
        StyleBox["k",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  ". First, we transform the integral involving ",
  Cell[BoxData[
      FormBox[
        RowBox[{"D", "(", 
          StyleBox["k",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  " in Eq. ",
  ButtonBox["(5.1.47)",
    ButtonData:>"(5.1.47)",
    ButtonStyle->"Hyperlink"],
  ", taking ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["k",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox[" ",
            FontWeight->"Bold"], 
          StyleBox["\[Rule]",
            FontWeight->"Plain"], 
          RowBox[{
            StyleBox["-",
              FontWeight->"Plain"], 
            StyleBox["k",
              FontWeight->"Bold",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  ":"
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"p", "(", 
            RowBox[{
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[",",
                FontWeight->"Plain"], 
              StyleBox["t",
                FontWeight->"Plain"]}], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{
            RowBox[{"\[Integral]", 
              
              RowBox[{\(\(\(\[DifferentialD]\^3 
                      k\)\(\ \)\)\/\((2  \[Pi])\)\^3\), 
                RowBox[{"C", "(", 
                  StyleBox["k",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], 
                  StyleBox[")",
                    FontWeight->"Plain"]}], 
                StyleBox[" ",
                  FontWeight->"Plain"], 
                StyleBox[
                  SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"\[ImaginaryI]", " ", 
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{
                            StyleBox["k",
                              FontWeight->"Bold",
                              FontSlant->"Plain"], "\[CenterDot]", 
                            StyleBox["r",
                              FontWeight->"Bold",
                              FontSlant->"Plain"]}], 
                          StyleBox["-",
                            FontWeight->"Bold"], 
                          RowBox[{
                            RowBox[{
                              StyleBox["\[Omega]",
                                FontWeight->"Plain"], "(", "k", 
                              StyleBox[")",
                                FontWeight->"Plain"]}], 
                            StyleBox["t",
                              FontWeight->"Plain"]}]}], 
                        StyleBox[")",
                          FontWeight->"Plain"]}]}]],
                  FontWeight->"Plain"]}]}], 
            StyleBox["+",
              FontWeight->"Plain"], 
            RowBox[{"\[Integral]", 
              
              RowBox[{\(\(\(\[DifferentialD]\^3 
                      k\)\(\ \)\)\/\((2  \[Pi])\)\^3\), " ", 
                RowBox[{"D", "(", 
                  RowBox[{"-", 
                    StyleBox["k",
                      FontWeight->"Bold",
                      FontSlant->"Plain"]}], 
                  StyleBox[")",
                    FontWeight->"Plain"]}], 
                StyleBox[" ",
                  FontWeight->"Plain"], 
                StyleBox[
                  SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"\[ImaginaryI]", " ", 
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{
                            RowBox[{"-", 
                              StyleBox["k",
                                FontWeight->"Bold",
                                FontSlant->"Plain"]}], "\[CenterDot]", 
                            StyleBox["r",
                              FontWeight->"Bold",
                              FontSlant->"Plain"]}], 
                          StyleBox["+",
                            FontWeight->"Bold"], 
                          RowBox[{
                            RowBox[{
                              StyleBox["\[Omega]",
                                FontWeight->"Plain"], "(", "k", 
                              StyleBox[")",
                                FontWeight->"Plain"]}], 
                            StyleBox["t",
                              FontWeight->"Plain"]}]}], 
                        StyleBox[")",
                          FontWeight->"Plain"]}]}]],
                  FontWeight->"Plain"]}]}]}]}], TraditionalForm]]],
  "."
}], "NumberedEquation",
  CellTags->"(5.1.49)"],

Cell[TextData[{
  "Note that the frequency ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega](k)\)]],
  " remains the same in this transformation, since ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\)]],
  " depends only on the magnitude of ",
  Cell[BoxData[
      FormBox[
        StyleBox["k",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  ". Next, we observe that  Eq. ",
  ButtonBox["(5.1.48)",
    ButtonData:>"(5.1.48)",
    ButtonStyle->"Hyperlink"],
  " implies that ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"D", "(", 
            RowBox[{"-", 
              StyleBox["k",
                FontWeight->"Bold",
                FontSlant->"Plain"]}], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox[" ",
            FontWeight->"Plain"], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{
            RowBox[{\(1\/2\), "[", 
              RowBox[{
                RowBox[{
                  StyleBox[\(p\&~\_o\),
                    FontWeight->"Plain"], "(", 
                  RowBox[{"-", 
                    StyleBox["k",
                      FontWeight->"Bold",
                      FontSlant->"Plain"]}], 
                  StyleBox[")",
                    FontWeight->"Plain"]}], 
                StyleBox["-",
                  FontWeight->"Plain"], 
                StyleBox[" ",
                  FontWeight->"Plain"], 
                RowBox[{
                  StyleBox["\[ImaginaryI]",
                    FontWeight->"Plain"], 
                  StyleBox[" ",
                    FontWeight->"Plain"], 
                  RowBox[{
                    RowBox[{
                      StyleBox[\(v\&~\_o\),
                        FontWeight->"Plain"], "(", 
                      RowBox[{"-", 
                        StyleBox["k",
                          FontWeight->"Bold",
                          FontSlant->"Plain"]}], 
                      StyleBox[")",
                        FontWeight->"Plain"]}], 
                    StyleBox["/",
                      FontWeight->"Plain"], 
                    StyleBox[\(\[Omega](k)\),
                      FontWeight->"Plain"]}]}]}], 
              StyleBox["]",
                FontWeight->"Plain"]}], 
            StyleBox[".",
              FontWeight->"Plain"], 
            StyleBox[\(\(\ \)\(\ \)\),
              FontWeight->"Plain"]}]}], TraditionalForm]]],
  "However, the functions ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[\(p\_o\),
            FontWeight->"Plain"], "(", 
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[\(v\_o\),
            FontWeight->"Plain"], "(", 
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  " are real, so according to Eq. ",
  ButtonBox["(2.1.7)",
    ButtonData:>{"Chapter2.nb", "(2.1.7)"},
    ButtonStyle->"Hyperlink"],
  ", their Fourier transforms have the property that ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox[\(p\&~\_o\),
              FontWeight->"Plain"], "(", 
            RowBox[{"-", 
              StyleBox["k",
                FontWeight->"Bold",
                FontSlant->"Plain"]}], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          SuperscriptBox[
            RowBox[{
              StyleBox[\(p\&~\_o\),
                FontWeight->"Plain"], "(", 
              StyleBox["k",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[")",
                FontWeight->"Plain"]}], "*"]}], TraditionalForm]]],
  ", and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox[\(v\&~\_o\),
              FontWeight->"Plain"], "(", 
            RowBox[{"-", 
              StyleBox["k",
                FontWeight->"Bold",
                FontSlant->"Plain"]}], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          SuperscriptBox[
            RowBox[{
              StyleBox[\(v\&~\_o\),
                FontWeight->"Plain"], "(", 
              StyleBox["k",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[")",
                FontWeight->"Plain"]}], "*"]}], TraditionalForm]]],
  ". Therefore, we find that ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"D", "(", 
            RowBox[{"-", 
              StyleBox["k",
                FontWeight->"Bold",
                FontSlant->"Plain"]}], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          SuperscriptBox[
            RowBox[{
              StyleBox["C",
                FontWeight->"Plain"], 
              StyleBox["(",
                FontWeight->"Plain"], 
              StyleBox["k",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[")",
                FontWeight->"Plain"]}], "*"]}], TraditionalForm]]],
  ",",
  " from which it follows that "
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"p", "(", 
            RowBox[{
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[",",
                FontWeight->"Plain"], 
              StyleBox["t",
                FontWeight->"Plain"]}], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{"\[Integral]", 
            
            RowBox[{\(\(\(\[DifferentialD]\^3 
                    k\)\(\ \)\)\/\((2  \[Pi])\)\^3\), "[", 
              RowBox[{
                RowBox[{
                  RowBox[{"C", "(", 
                    StyleBox["k",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], 
                    StyleBox[")",
                      FontWeight->"Plain"]}], 
                  StyleBox[" ",
                    FontWeight->"Plain"], 
                  StyleBox[
                    SuperscriptBox["\[ExponentialE]", 
                      RowBox[{"\[ImaginaryI]", " ", 
                        RowBox[{"(", 
                          RowBox[{
                            RowBox[{
                              StyleBox["k",
                                FontWeight->"Bold",
                                FontSlant->"Plain"], "\[CenterDot]", 
                              StyleBox["r",
                                FontWeight->"Bold",
                                FontSlant->"Plain"]}], 
                            StyleBox["-",
                              FontWeight->"Bold"], 
                            RowBox[{
                              RowBox[{
                                StyleBox["\[Omega]",
                                  FontWeight->"Plain"], "(", "k", 
                                StyleBox[")",
                                  FontWeight->"Plain"]}], 
                              StyleBox["t",
                                FontWeight->"Plain"]}]}], 
                          StyleBox[")",
                            FontWeight->"Plain"]}]}]],
                    FontWeight->"Plain"]}], 
                StyleBox[" ",
                  FontWeight->"Plain"], 
                StyleBox["+",
                  FontWeight->"Plain"], 
                SuperscriptBox[
                  RowBox[{
                    StyleBox["(",
                      FontWeight->"Plain"], 
                    RowBox[{
                      RowBox[{"C", "(", 
                        StyleBox["k",
                          FontWeight->"Bold",
                          FontSlant->"Plain"], 
                        StyleBox[")",
                          FontWeight->"Plain"]}], 
                      StyleBox[" ",
                        FontWeight->"Plain"], 
                      StyleBox[
                        SuperscriptBox["\[ExponentialE]", 
                          RowBox[{"\[ImaginaryI]", " ", 
                            RowBox[{"(", 
                              RowBox[{
                                RowBox[{
                                  StyleBox["k",
                                    FontWeight->"Bold",
                                    FontSlant->"Plain"], "\[CenterDot]", 
                                  StyleBox["r",
                                    FontWeight->"Bold",
                                    FontSlant->"Plain"]}], 
                                StyleBox["-",
                                  FontWeight->"Bold"], 
                                StyleBox[" ",
                                  FontWeight->"Bold"], 
                                RowBox[{
                                  RowBox[{
                                    StyleBox["\[Omega]",
                                      FontWeight->"Plain"], "(", "k", 
                                    StyleBox[")",
                                      FontWeight->"Plain"]}], 
                                  StyleBox["t",
                                    FontWeight->"Plain"]}]}], 
                              StyleBox[")",
                                FontWeight->"Plain"]}]}]],
                        FontWeight->"Plain"]}], 
                    StyleBox[")",
                      FontWeight->"Plain"]}], "*"]}], "]"}]}]}], 
        TraditionalForm]]],
  "."
}], "Text"],

Cell["\<\
Since the second term is the complex conjugate of the first, we \
arrive at\
\>", "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"p", "(", 
            RowBox[{
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[",",
                FontWeight->"Plain"], 
              StyleBox["t",
                FontWeight->"Plain"]}], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{"2", " ", "Re", 
            RowBox[{"\[Integral]", 
              
              RowBox[{\(\(\(\[DifferentialD]\^3 
                      k\)\(\ \)\)\/\((2  \[Pi])\)\^3\), 
                RowBox[{"C", "(", 
                  StyleBox["k",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], 
                  StyleBox[")",
                    FontWeight->"Plain"]}], 
                StyleBox[" ",
                  FontWeight->"Plain"], 
                StyleBox[
                  SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"\[ImaginaryI]", " ", 
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{
                            StyleBox["k",
                              FontWeight->"Bold",
                              FontSlant->"Plain"], "\[CenterDot]", 
                            StyleBox["r",
                              FontWeight->"Bold",
                              FontSlant->"Plain"]}], 
                          StyleBox["-",
                            FontWeight->"Bold"], 
                          RowBox[{
                            RowBox[{
                              StyleBox["\[Omega]",
                                FontWeight->"Plain"], "(", "k", 
                              StyleBox[")",
                                FontWeight->"Plain"]}], 
                            StyleBox["t",
                              FontWeight->"Plain"]}]}], 
                        StyleBox[")",
                          FontWeight->"Plain"]}]}]],
                  FontWeight->"Plain"]}]}]}]}], TraditionalForm]]],
  "."
}], "NumberedEquation",
  CellTags->"(5.1.50)"],

Cell[TextData[{
  " For a given value of ",
  Cell[BoxData[
      FormBox[
        StyleBox["k",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  ", the argument of  the integral in Eq. ",
  ButtonBox["(5.1.50)",
    ButtonData:>"(5.1.50)",
    ButtonStyle->"Hyperlink"],
  " describes a wave that propagates only in one direction, along ",
  Cell[BoxData[
      FormBox[
        StyleBox["k",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  ". Furthermore, these waves only have positive frequencies. This is as \
opposed to the solution of Eq. ",
  ButtonBox["(5.1.47)",
    ButtonData:>"(5.1.47)",
    ButtonStyle->"Hyperlink"],
  ", where for given ",
  Cell[BoxData[
      FormBox[
        StyleBox["k",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " waves propagate both with and against ",
  Cell[BoxData[
      FormBox[
        StyleBox["k",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  ", with both positive and negative frequencies. Thanks to isotropy, we do \
not lose anything in Eq. ",
  ButtonBox["(5.1.50)",
    ButtonData:>"(5.1.50)",
    ButtonStyle->"Hyperlink"],
  ": a wave with negative frequency and wave vector ",
  Cell[BoxData[
      FormBox[
        StyleBox["k",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  ", propagating in the ",
  Cell[BoxData[
      FormBox[
        RowBox[{"-", 
          StyleBox["k",
            FontWeight->"Bold",
            FontSlant->"Plain"]}], TraditionalForm]]],
  " direction, can equally well be described by a wave with positive \
frequency but with the ",
  "wave vector",
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{"-", 
          StyleBox["k",
            FontWeight->"Bold",
            FontSlant->"Plain"]}], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  "\tHow can we match the two initial conditions of Eq. ",
  ButtonBox["(5.1.45)",
    ButtonData:>"(5.1.45)",
    ButtonStyle->"Hyperlink"],
  " when there is only a single function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"C", "(", 
          StyleBox["k",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  " in Eq. ",
  ButtonBox["(5.1.50)",
    ButtonData:>"(5.1.50)",
    ButtonStyle->"Hyperlink"],
  ", rather than the two functions in Eq. ",
  ButtonBox["(5.1.47)",
    ButtonData:>"(5.1.47)",
    ButtonStyle->"Hyperlink"],
  "? The answer is that ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox["C",
            "TraditionalForm"], "(", 
          StyleBox["k",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  " has both a real and an imaginary part, and this gives us the two \
functions we need: see Eq. ",
  ButtonBox["(5.1.48)",
    ButtonData:>"(5.1.48)",
    ButtonStyle->"Hyperlink"],
  ". The fact that we take the real part in Eq. ",
  ButtonBox["(5.1.50)",
    ButtonData:>"(5.1.50)",
    ButtonStyle->"Hyperlink"],
  " allows us latitude in choosing these functions that is absent in Eq. ",
  ButtonBox["(5.1.47)",
    ButtonData:>"(5.1.47)",
    ButtonStyle->"Hyperlink"],
  ", where the integrals must by themselves provide a real result. In fact, \
one can regard the function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"D", "(", 
          StyleBox["k",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  " as merely a way to obtain a real result in Eq. ",
  ButtonBox["(5.1.47)",
    ButtonData:>"(5.1.47)",
    ButtonStyle->"Hyperlink"],
  ", which is obviated in Eq. ",
  ButtonBox["(5.1.50)",
    ButtonData:>"(5.1.50)",
    ButtonStyle->"Hyperlink"],
  " by our directly taking the real part."
}], "Text"],

Cell[TextData[{
  "\tAlso, it is important to realize that no part of the argument leading to \
Eq. ",
  ButtonBox["(5.1.50)",
    ButtonData:>"(5.1.50)",
    ButtonStyle->"Hyperlink"],
  " relied on the specific form of the dispersion relation, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega] = c\ k\)]],
  "; rather, only the isotropy of the dispersion was required. In fact, Eq. \
",
  ButtonBox["(5.1.50)",
    ButtonData:>"(5.1.50)",
    ButtonStyle->"Hyperlink"],
  " also applies to more general dispersive isotropic systems where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega] = \[Omega](k)\)]],
  " for some general function ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega](k)\)]],
  ". Examples of such systems include electromagnetic waves propagating in \
isotropic dispersive media with an index of refraction that depends on \
frequency, ",
  Cell[BoxData[
      \(TraditionalForm\`n = n(\[Omega])\)]],
  ";  phonons propagating though amorphous materials such as rubber or glass; \
waves in unmagnetized plasmas;  water waves in deep water; and sound waves in \
air. These examples, and others, will be taken up in the exercises."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Wave Packets", "Subsubsection"],

Cell[TextData[{
  "\tOne advantage of Eq. ",
  ButtonBox["(5.1.50)",
    ButtonData:>"(5.1.50)",
    ButtonStyle->"Hyperlink"],
  " over Eq. ",
  ButtonBox["(5.1.47)",
    ButtonData:>"(5.1.47)",
    ButtonStyle->"Hyperlink"],
  ", aside from its compact form, is the ease with which it can be applied to \
describe the evolution of wave packets. If we consider an initial condition \
for which ",
  Cell[BoxData[
      FormBox[
        RowBox[{"C", "(", 
          StyleBox["k",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  " is sharply peaked around a wave vector ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          SubscriptBox[
            StyleBox["k",
              FontSlant->"Plain"], 
            StyleBox["o",
              FontWeight->"Plain"]],
          FontWeight->"Bold"], TraditionalForm]]],
  ", then we can Taylor expand ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Omega]", "(", 
          StyleBox["k",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  " about ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          SubscriptBox[
            StyleBox["k",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox["o",
              FontWeight->"Plain"]],
          FontWeight->"Bold"], TraditionalForm]]],
  ", obtaining ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"\[Omega]", "(", 
            StyleBox["k",
              FontWeight->"Bold",
              FontSlant->"Plain"], ")"}], "\[TildeEqual]", 
          RowBox[{
            RowBox[{"\[Omega]", "(", 
              StyleBox[
                SubscriptBox[
                  StyleBox["k",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], 
                  StyleBox["o",
                    FontWeight->"Plain"]],
                FontWeight->"Bold"], ")"}], "+", 
            RowBox[{
              RowBox[{
                StyleBox[
                  SubscriptBox[
                    StyleBox["v",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], 
                    StyleBox["g",
                      FontWeight->"Plain"]],
                  FontWeight->"Bold"], "(", 
                StyleBox[
                  SubscriptBox[
                    StyleBox["k",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], 
                    StyleBox["o",
                      FontWeight->"Plain"]],
                  FontWeight->"Bold"], ")"}], "\[CenterDot]", 
              RowBox[{"(", 
                RowBox[{
                  StyleBox["k",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "-", 
                  StyleBox[
                    SubscriptBox[
                      StyleBox["k",
                        FontWeight->"Bold",
                        FontSlant->"Plain"], 
                      StyleBox["o",
                        FontWeight->"Plain"]],
                    FontWeight->"Bold"]}], ")"}]}]}]}], TraditionalForm]]],
  ", where the group velocity ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          SubscriptBox[
            StyleBox["v",
              FontSlant->"Plain"], 
            StyleBox["g",
              FontWeight->"Plain"]],
          FontWeight->"Bold"], TraditionalForm]]],
  " is given by Eq. ",
  ButtonBox["(5.1.42)",
    ButtonData:>"(5.1.42)",
    ButtonStyle->"Hyperlink"],
  ".  Using this approximation in Eq. ",
  ButtonBox["(5.1.49)",
    ButtonData:>"(5.1.49)",
    ButtonStyle->"Hyperlink"],
  " allows us to write"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"p", "(", 
            RowBox[{
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[",",
                FontWeight->"Plain"], 
              StyleBox["t",
                FontWeight->"Plain"]}], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox["=",
            FontWeight->"Plain"], " ", 
          RowBox[{"Re", "(", " ", 
            RowBox[{
              SuperscriptBox["\[ExponentialE]", 
                RowBox[{"\[ImaginaryI]", "[", 
                  RowBox[{
                    RowBox[{
                      SubscriptBox[
                        StyleBox["k",
                          FontWeight->"Bold",
                          FontSlant->"Plain"], "o"], "\[CenterDot]", 
                      StyleBox["r",
                        FontWeight->"Bold",
                        FontSlant->"Plain"]}], 
                    StyleBox[" ",
                      FontWeight->"Plain"], 
                    StyleBox["-",
                      FontWeight->"Plain"], 
                    StyleBox[" ",
                      FontWeight->"Plain"], 
                    StyleBox[\(\(\[Omega](k\_o)\) t\),
                      FontWeight->"Plain"]}], "]"}]], 
              RowBox[{"\[Integral]", 
                
                RowBox[{\(\(\(\[DifferentialD]\^3 
                        k\)\(\ \)\)\/\((2  \[Pi])\)\^3\), "2", " ", 
                  RowBox[{"C", "(", 
                    StyleBox["k",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], 
                    StyleBox[")",
                      FontWeight->"Plain"]}], 
                  StyleBox[" ",
                    FontWeight->"Plain"], 
                  StyleBox[
                    SuperscriptBox["\[ExponentialE]", 
                      RowBox[{"\[ImaginaryI]", " ", 
                        RowBox[{
                          RowBox[{"(", 
                            RowBox[{
                              StyleBox["k",
                                FontWeight->"Bold",
                                FontSlant->"Plain"], "-", 
                              SubscriptBox[
                                StyleBox["k",
                                  FontWeight->"Bold",
                                  FontSlant->"Plain"], "o"]}], ")"}], 
                          "\[CenterDot]", 
                          RowBox[{"(", 
                            RowBox[{
                              StyleBox["r",
                                FontWeight->"Bold",
                                FontSlant->"Plain"], "-", 
                              RowBox[{
                                RowBox[{
                                  StyleBox[
                                    SubscriptBox[
                                      StyleBox["v",
                                        FontWeight->"Bold",
                                        FontSlant->"Plain"], "g"],
                                    FontWeight->"Plain"], "(", 
                                  SubscriptBox[
                                    StyleBox["k",
                                      FontWeight->"Bold",
                                      FontSlant->"Plain"], "o"], 
                                  StyleBox[")",
                                    FontWeight->"Plain"]}], 
                                StyleBox["t",
                                  FontWeight->"Plain"]}]}], 
                            StyleBox[")",
                              FontWeight->"Plain"]}], " "}]}]],
                    FontWeight->"Plain"]}]}]}], 
            StyleBox[")",
              FontWeight->"Plain"]}]}], TraditionalForm]]],
  ". "
}], "Text"],

Cell[TextData[{
  "The integral over ",
  Cell[BoxData[
      FormBox[
        StyleBox["k",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " results in a function only of  ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], "-", 
          RowBox[{
            RowBox[{
              StyleBox[
                SubscriptBox[
                  StyleBox["v",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "g"],
                FontWeight->"Plain"], "(", 
              SubscriptBox[
                StyleBox["k",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "o"], 
              StyleBox[")",
                FontWeight->"Plain"]}], 
            StyleBox["t",
              FontWeight->"Plain"]}]}], TraditionalForm]]],
  ",  which we write as ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"A", "(", 
            RowBox[{
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], "-", 
              RowBox[{
                RowBox[{
                  StyleBox[
                    SubscriptBox[
                      StyleBox["v",
                        FontWeight->"Bold",
                        FontSlant->"Plain"], "g"],
                    FontWeight->"Plain"], "(", 
                  SubscriptBox[
                    StyleBox["k",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], "o"], 
                  StyleBox[")",
                    FontWeight->"Plain"]}], 
                StyleBox["t",
                  FontWeight->"Plain"]}]}], 
            StyleBox[")",
              FontWeight->"Plain"]}], " "}], TraditionalForm]]],
  ". Furthermore, since ",
  Cell[BoxData[
      FormBox[
        RowBox[{"C", "(", 
          StyleBox["k",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  " is peaked around ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["k",
            FontWeight->"Bold",
            FontSlant->"Plain"], "=", 
          SubscriptBox[
            StyleBox["k",
              FontWeight->"Bold",
              FontSlant->"Plain"], "o"]}], TraditionalForm]]],
  " the Fourier components ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["k",
            FontWeight->"Bold",
            FontSlant->"Plain"], "-", 
          SubscriptBox[
            StyleBox["k",
              FontWeight->"Bold",
              FontSlant->"Plain"], "o"]}], TraditionalForm]]],
  " that contribute to ",
  Cell[BoxData[
      \(TraditionalForm\`A\)]],
  " are small, so ",
  Cell[BoxData[
      FormBox[
        RowBox[{"A", "(", 
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  " is slowly varying in space. The function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"A", "(", 
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  " can be recognized as the slowly",
  " varying",
  " amplitude function that is superimposed on the wave train ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[ImaginaryI]", "[", 
            RowBox[{
              RowBox[{
                SubscriptBox[
                  StyleBox["k",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "o"], "\[CenterDot]", 
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"]}], 
              StyleBox[" ",
                FontWeight->"Plain"], 
              StyleBox["-",
                FontWeight->"Plain"], 
              StyleBox[" ",
                FontWeight->"Plain"], 
              StyleBox[\(\(\[Omega](k\_o)\) t\),
                FontWeight->"Plain"]}], "]"}]], TraditionalForm]]],
  "in order to create a finite wave packet:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"p", "(", 
            RowBox[{
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[",",
                FontWeight->"Bold"], 
              StyleBox["t",
                FontWeight->"Plain"]}], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox[" ",
            FontWeight->"Plain"], 
          RowBox[{
            StyleBox["Re",
              FontWeight->"Plain"], 
            StyleBox["[",
              FontWeight->"Plain"], 
            StyleBox[" ",
              FontWeight->"Plain"], 
            RowBox[{
              RowBox[{
                StyleBox["A",
                  FontWeight->"Plain"], 
                StyleBox["(",
                  FontWeight->"Plain"], 
                RowBox[{
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "-", 
                  RowBox[{
                    RowBox[{
                      StyleBox[
                        SubscriptBox[
                          StyleBox["v",
                            FontWeight->"Bold",
                            FontSlant->"Plain"], "g"],
                        FontWeight->"Plain"], "(", 
                      SubscriptBox[
                        StyleBox["k",
                          FontWeight->"Bold",
                          FontSlant->"Plain"], "o"], 
                      StyleBox[")",
                        FontWeight->"Plain"]}], 
                    StyleBox["t",
                      FontWeight->"Plain"]}]}], 
                StyleBox[")",
                  FontWeight->"Plain"]}], 
              SuperscriptBox["\[ExponentialE]", 
                RowBox[{"\[ImaginaryI]", "[", 
                  RowBox[{
                    RowBox[{
                      SubscriptBox[
                        StyleBox["k",
                          FontWeight->"Bold",
                          FontSlant->"Plain"], "o"], "\[CenterDot]", 
                      StyleBox["r",
                        FontWeight->"Bold",
                        FontSlant->"Plain"]}], 
                    StyleBox[" ",
                      FontWeight->"Plain"], 
                    StyleBox["-",
                      FontWeight->"Plain"], 
                    StyleBox[" ",
                      FontWeight->"Plain"], 
                    StyleBox[\(\(\[Omega](k\_o)\) t\),
                      FontWeight->"Plain"]}], "]"}]]}], "]"}]}], 
        TraditionalForm]]],
  " ."
}], "NumberedEquation",
  CellTags->{"i:23", "(5.1.51)"}],

Cell[TextData[{
  StyleBox["The amplitude function travels with the group velocity of the ", 
    "NumberedEquation"],
  "wave packet",
  StyleBox[", while planes of constant  ", "NumberedEquation"],
  "phase within the packet move with the average phase velocity of the \
packet. The packet travels without changing shape, because in deriving Eq. ",
  ButtonBox["(5.1.51)",
    ButtonData:>"(5.1.51)",
    ButtonStyle->"Hyperlink"],
  " we neglected dispersion."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Dispersion and Diffraction", "Subsubsection",
  CellTags->"i:24"],

Cell[TextData[{
  "We can take account of dispersion in much the same manner as was used to \
analyze the 1D wave equation. Keeping the next-order term in the \
Taylor-expansion of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega](k)\)]],
  " about the central wave vector ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["k",
            FontWeight->"Bold",
            FontSlant->"Plain"], "o"], TraditionalForm]]],
  " of the wave packet, we obtain"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Omega](k)\), " ", "=", " ", 
          RowBox[{
            RowBox[{"\[Omega]", "(", 
              StyleBox[
                SubscriptBox[
                  StyleBox["k",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], 
                  StyleBox["o",
                    FontWeight->"Plain"]],
                FontWeight->"Bold"], ")"}], "+", " ", 
            RowBox[{
              RowBox[{
                SubscriptBox[
                  StyleBox["v",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "g"], "(", 
                SubscriptBox[
                  StyleBox["k",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "o"], ")"}], "\[CenterDot]", 
              RowBox[{"(", 
                RowBox[{
                  StyleBox["k",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "-", 
                  SubscriptBox[
                    StyleBox["k",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], "o"]}], ")"}]}], " ", "+", " ", 
            RowBox[{\(1\/2\), 
              RowBox[{
                RowBox[{"(", 
                  RowBox[{
                    StyleBox["k",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], "-", 
                    SubscriptBox[
                      StyleBox["k",
                        FontWeight->"Bold",
                        FontSlant->"Plain"], "o"]}], ")"}], "\[CenterDot]", 
                StyleBox["\[Gamma]",
                  FontWeight->"Bold"], "\[CenterDot]", 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox["k",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], "-", 
                    SubscriptBox[
                      StyleBox["k",
                        FontWeight->"Bold",
                        FontSlant->"Plain"], "o"]}], ")"}]}]}]}]}], 
        TraditionalForm]]],
  ","
}], "NumberedEquation",
  CellTags->"(5.1.52)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        StyleBox["\[Gamma]",
          FontWeight->"Bold"], TraditionalForm]]],
  " is a symmetric tensor, given in component form by ",
  Cell[BoxData[
      \(TraditionalForm\`\[Gamma]\_\(i\ j\) = \[PartialD]\^2 \[Omega]/\
\[PartialD]k\_i \[PartialD]k\_j\)]],
  Cell[BoxData[
      FormBox[
        SubscriptBox["|", 
          RowBox[{
            StyleBox["k",
              FontWeight->"Bold",
              FontSlant->"Plain"], "=", 
            SubscriptBox[
              StyleBox["k",
                FontWeight->"Bold",
                FontSlant->"Plain"], "o"]}]], TraditionalForm]]],
  ". Here the indices ",
  Cell[BoxData[
      \(TraditionalForm\`i\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  " each run over the ",
  Cell[BoxData[
      \(TraditionalForm\`x, y, \)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  " components of the vector ",
  Cell[BoxData[
      FormBox[
        StyleBox["k",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  ".  The tensor ",
  Cell[BoxData[
      FormBox[
        StyleBox["\[Gamma]",
          FontWeight->"Bold"], TraditionalForm]]],
  " describes the  spreading of the ",
  "wave packet",
  ".  For an isotropic system where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\  = \ \[Omega](k)\)]],
  ", we can write this tensor as "
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Gamma]\_\(i\ j\)\), " ", "=", " ", 
          RowBox[{
            
            RowBox[{\(\(\[PartialD]\/\[PartialD]k\_j\) \(\(\(v\_g\)\_i\)(
                  k)\)\), 
              SubscriptBox[
                StyleBox["|",
                  FontSize->10], 
                RowBox[{
                  StyleBox["k",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "=", 
                  SubscriptBox[
                    StyleBox["k",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], "o"]}]]}], "=", 
            
            RowBox[{\(\(\[PartialD]\/\[PartialD]k\_j\) \((\(\(v\_g\)(k)\) 
                    k\_i\/k)\)\), 
              SubscriptBox[
                StyleBox["|",
                  FontSize->10], 
                RowBox[{
                  StyleBox["k",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "=", 
                  SubscriptBox[
                    StyleBox["k",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], "o"]}]]}]}]}], TraditionalForm]]],
  ", "
}], "Text"],

Cell[TextData[{
  "where we have used Eq. ",
  ButtonBox["(5.1.43)",
    ButtonData:>"(5.1.43)",
    ButtonStyle->"Hyperlink"],
  ".  Then applying the identities ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]k\_i\/\[PartialD]k\_j = \[Delta]\_\(i\ \
j\)\)]],
  ",  ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]k\/\[PartialD]k\_j = k\_j\/k\)]],
  ", and using the chain rule, we obtain"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Gamma]\_\(i\ j\)\), " ", "=", " ", 
          RowBox[{
            RowBox[{
              RowBox[{\(\(\(v\_g\)(k)\)\/k\), 
                RowBox[{"(", 
                  RowBox[{\(\[Delta]\_\(i\ j\)\), 
                    StyleBox[" ",
                      FontWeight->"Plain"], 
                    StyleBox["-",
                      FontWeight->"Plain"], 
                    FractionBox[
                      RowBox[{
                        StyleBox[\(k\_i\),
                          FontWeight->"Plain"], 
                        StyleBox[" ",
                          FontWeight->"Bold"], 
                        StyleBox[\(k\_j\),
                          FontWeight->"Plain"]}], \(k\^2\)]}], ")"}]}], " ", 
              "+", 
              RowBox[{\(\[PartialD]v\_g\/\[PartialD]k\), 
                FractionBox[
                  RowBox[{
                    StyleBox[\(k\_i\),
                      FontWeight->"Plain"], 
                    StyleBox[" ",
                      FontWeight->"Bold"], 
                    StyleBox[\(k\_j\),
                      FontWeight->"Plain"]}], \(k\^2\)]}]}], 
            StyleBox[
              RowBox[{
                StyleBox["  ",
                  FontWeight->"Bold"], 
                StyleBox[" ",
                  FontWeight->"Plain"]}]], 
            SubscriptBox[
              StyleBox["|",
                FontSize->10], 
              RowBox[{
                StyleBox["k",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "=", 
                SubscriptBox[
                  StyleBox["k",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "o"]}]]}]}], TraditionalForm]]],
  ","
}], "NumberedEquation",
  CellTags->"(5.1.53)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]\_\(i\ j\)\)]],
  " is a Kronecker delta function (the component form of the unit tensor)."
}], "Text"],

Cell[TextData[{
  "The tensor ",
  StyleBox["\[Gamma]",
    FontWeight->"Bold"],
  " has a simple diagonal form when written in components with the ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  "-axis chosen along the direction of ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["k",
            FontWeight->"Bold",
            FontSlant->"Plain"], "o"], TraditionalForm]]],
  ":"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        StyleBox["\[Gamma]",
          FontWeight->"Bold"], " ", "=", " ", 
        RowBox[{"(", GridBox[{
              {\(\(\(v\_g\)(k\_o)\)\/k\_o\), "0", "0"},
              {"0", \(\(\(v\_g\)(k\_o)\)\/k\_o\), "0"},
              {"0", "0", \(\[PartialD]v\_g\/\[PartialD]k\_o\)}
              }], ")"}]}], TraditionalForm]]]], "NumberedEquation",
  CellTags->"(5.1.54)"],

Cell[TextData[{
  "The ",
  Cell[BoxData[
      FormBox[
        StyleBox["zz",
          FontSlant->"Italic"], TraditionalForm]]],
  " component of the tensor, ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]v\_g\/\[PartialD]k\_o\)]],
  ", causes dispersion along the direction of propagation (",
  StyleBox["longitudinal",
    FontSlant->"Italic"],
  " dispersion). The ",
  Cell[BoxData[
      FormBox[
        StyleBox["xx",
          FontSlant->"Italic"], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        StyleBox["yy",
          FontSlant->"Italic"], TraditionalForm]]],
  " components, ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(v\_g\)(k\_o)\)/k\_o\)]],
  ", cause spreading of the wave packet ",
  StyleBox["transverse",
    FontSlant->"Italic"],
  " to the direction of propagation (",
  StyleBox["transverse ",
    FontSlant->"Italic"],
  "dispersion). The fact that these latter two components are identical \
implies that the wave packet spreads isotropically in the transverse \
directions, as  expected for a homogeneous isotropic medium. However, the \
transverse dispersion is not the same as the longitudinal dispersion. \
Transverse dispersion is also known as ",
  StyleBox["diffraction",
    FontSlant->"Italic"],
  ". "
}], "Text",
  CellTags->"i:133"],

Cell[TextData[{
  "\tWe can work out the dispersion quantitatively for a Gaussian wave packet \
with central wave vector ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(k\_o\), " ", 
          StyleBox[
            OverscriptBox[
              StyleBox["z",
                FontWeight->"Bold",
                FontSlant->"Plain"], "^"],
            FontWeight->"Bold"]}], TraditionalForm]]],
  ".  When Eqs. ",
  ButtonBox["(5.1.52)",
    ButtonData:>"(5.1.52)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(5.1.54)",
    ButtonData:>"(5.1.54)",
    ButtonStyle->"Hyperlink"],
  " are employed in Eq. ",
  ButtonBox["(5.1.50)",
    ButtonData:>"(5.1.50)",
    ButtonStyle->"Hyperlink"],
  ", the result is"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"p", "(", 
            RowBox[{
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[",",
                FontWeight->"Plain"], 
              StyleBox["t",
                FontWeight->"Plain"]}], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{"2", " ", 
            RowBox[{"Re", "[", " ", 
              RowBox[{
                SuperscriptBox["\[ExponentialE]", 
                  RowBox[{
                    RowBox[{"\[ImaginaryI]", "[", 
                      RowBox[{
                        RowBox[{
                          SubscriptBox[
                            StyleBox["k",
                              FontWeight->"Bold",
                              FontSlant->"Plain"], "o"], "\[CenterDot]", 
                          RowBox[{
                            StyleBox[
                              SubscriptBox[
                                StyleBox["v",
                                  FontWeight->"Bold",
                                  FontSlant->"Plain"], "g"],
                              FontWeight->"Plain"], "(", 
                            StyleBox[\(k\_o\),
                              FontWeight->"Bold"], 
                            StyleBox[")",
                              FontWeight->"Plain"]}]}], 
                        StyleBox[" ",
                          FontWeight->"Plain"], 
                        StyleBox["-",
                          FontWeight->"Plain"], 
                        StyleBox[" ",
                          FontWeight->"Plain"], 
                        StyleBox[\(\[Omega](k\_o)\),
                          FontWeight->"Plain"]}], "]"}], "t"}]], 
                RowBox[{"\[Integral]", 
                  
                  RowBox[{\(\(\(\[DifferentialD]\^3 
                          k\)\(\ \)\)\/\((2  \[Pi])\)\^3\), 
                    RowBox[{"C", "(", 
                      StyleBox["k",
                        FontWeight->"Bold",
                        FontSlant->"Plain"], 
                      StyleBox[")",
                        FontWeight->"Plain"]}], 
                    StyleBox[" ",
                      FontWeight->"Plain"], 
                    StyleBox[
                      SuperscriptBox["\[ExponentialE]", 
                        RowBox[{
                          RowBox[{"\[ImaginaryI]", " ", 
                            RowBox[{
                              StyleBox["k",
                                FontWeight->"Bold",
                                FontSlant->"Plain"], "\[CenterDot]", 
                              RowBox[{"(", 
                                RowBox[{
                                  StyleBox["r",
                                    FontWeight->"Bold",
                                    FontSlant->"Plain"], 
                                  StyleBox["-",
                                    FontWeight->"Bold"], 
                                  RowBox[{
                                    RowBox[{
                                      StyleBox[
                                        SubscriptBox[
                                        StyleBox["v",
                                        FontWeight->"Bold",
                                        FontSlant->"Plain"], "g"],
                                        FontWeight->"Plain"], "(", 
                                      SubscriptBox[
                                        StyleBox["k",
                                        FontWeight->"Bold",
                                        FontSlant->"Plain"], "o"], 
                                      StyleBox[")",
                                        FontWeight->"Plain"]}], " ", "t"}]}], 
                                ")"}]}]}], "-", " ", 
                          RowBox[{"\[ImaginaryI]", " ", 
                            RowBox[{
                            "(", \(\(\(\(v\_g\)(k\_o)\)\/\(2 
                                         k\_o\)\) \((k\_x\^\(\(2\)\(\ \)\) + \
\ k\_y\^2)\)\  + 
                                1\/2\ \(\[PartialD]v\_g\/\[PartialD]k\_o\) \
\((k\_z - k\_o)\)\^2\), " ", 
                              StyleBox[")",
                                FontWeight->"Plain"]}], 
                            StyleBox["t",
                              FontWeight->"Plain"]}]}]],
                      FontWeight->"Plain"]}]}]}], 
              StyleBox["]",
                FontWeight->"Plain"]}]}]}], TraditionalForm]]],
  ".\t"
}], "Text"],

Cell["Taking  a packet with a spectrum of the form", "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"C", "(", 
            StyleBox["k",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox[" ",
            FontWeight->"Plain"], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{"A", 
            StyleBox[" ",
              FontWeight->"Plain"], 
            
            StyleBox[\(\[ExponentialE]\^\(\(-\((k\_x\%2 + k\_y\%2)\)\) 
                    b\^2/2\)\),
              FontWeight->"Plain"], 
            
            StyleBox[\(\[ExponentialE]\^\(\(-\((k\_z - k\_o)\)\^2\) 
                    a\^2/2\)\),
              FontWeight->"Plain"]}]}], TraditionalForm]]]
}], "Text"],

Cell[TextData[{
  "allows us to perform the required integrations over ",
  Cell[BoxData[
      \(TraditionalForm\`k\_x, \ k\_y\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`k\_z\)]],
  " analytically.  The result is given below, defining ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] = \(1\/2\) \[PartialD]v\_g\/\[PartialD]k\_o\
\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta]\  = \(\(\(\(v\_g\)(k\_o)\)/
            2\) \(k\_o\)\(\ \)\)\)]],
  ":"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{"p", "(", 
          RowBox[{
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[",",
              FontWeight->"Plain"], 
            StyleBox["t",
              FontWeight->"Plain"]}], 
          StyleBox[")",
            FontWeight->"Plain"]}], 
        StyleBox[" ",
          FontWeight->"Plain"], 
        StyleBox["=",
          
          FontWeight->
            "Plain"], \(2\ Re[\(\(4\ \(\[Pi]\^\(\(3/2\)\(\ \)\)\) 
                    A\)\/\(\((b\^2\  + \ 
                        2\ \[ImaginaryI]\ \[Beta]\ t)\) \@\(2  a\^2 + 4\ \
\[ImaginaryI]\ \[Alpha]\ t\)\)\) \(\[ExponentialE]\^\(\[ImaginaryI](\(k\_o\) 
                        z\  - \ \(\[Omega](
                          k\_o)\)\ t)\)\) \
\[ExponentialE]\^\(\(-\(\(x\^\(\(2\)\(\ \)\) + y\^2\)\/\(2  b\^2\  + \ 4\ \
\[ImaginaryI]\ \[Beta]\ \ t\)\)\) - \((z - \(\(v\_g\)(k\_o)\) t)\)\^2\/\(2  a\
\^2 + 4\ \[ImaginaryI]\ \[Alpha]\ t\)\)\ ]\)}], 
      TraditionalForm]]]], "NumberedEquation",
  CellTags->"(5.1.55)"],

Cell[TextData[{
  "This packet has an initial transverse width of ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  " and an initial length of ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  ", but spreads over time.  The rate of longitudinal spreading is the same \
as for a 1D packet, Eq. ",
  ButtonBox["(5.1.31)",
    ButtonData:>"(5.1.31)",
    ButtonStyle->"Hyperlink"],
  ",  and is controlled by the same parameter ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\  = \(\(1\/2\) \(\[PartialD]v\_g\/\
\[PartialD]k\_o\)\(\ \)\)\)]],
  "as for the 1D case. "
}], "Text"],

Cell[TextData[{
  "\tHowever, the transverse spreading (diffraction)  is controlled by the \
parameter ",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta]\  = \ \(\(v\_g\)(k\_o)\)/2  k\_o\)]],
  ". This parameter is nonzero even if the medium is dispersionless. This \
implies that diffraction occurs even in vacuum. "
}], "Text"],

Cell[TextData[{
  "\tThe transverse width ",
  Cell[BoxData[
      \(TraditionalForm\`w(t)\)]],
  " of the Gaussian wave packet, defined in the same way as in Eq. ",
  ButtonBox["(5.1.31)",
    ButtonData:>"(5.1.31)",
    ButtonStyle->"Hyperlink"],
  ", is ",
  Cell[BoxData[
      \(TraditionalForm\`w(t) = \@\(b\^2 + 4\ \(\[Beta]\^2\) t\^2/b\^2\)\)]],
  ".  Thus, the width of the packet increases by a factor ",
  Cell[BoxData[
      \(TraditionalForm\`\@2\)]],
  " in a time ",
  Cell[BoxData[
      \(TraditionalForm\`t\_2 = \(b\^2/2\ \[Beta] = 
          b\^2\ \(\(k\_o/\(\(v\_g\)(k\_o)\)\)\(\ \)\)\)\)]],
  "  In this time, the packet has moved a distance "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`d = \(\(\(v\_g\)(k\_o)\)\ t\_2 = \ b\^2\ k\_o\)\)]],
  "."
}], "NumberedEquation",
  CellTags->"(5.1.56)"],

Cell[TextData[{
  "This distance is called the ",
  StyleBox["Rayleigh",
    FontSlant->"Italic"],
  " ",
  StyleBox["length. ",
    FontSlant->"Italic"],
  " It is the distance over which a Gaussian wave packet increases in \
transverse width from ",
  Cell[BoxData[
      \(TraditionalForm\`b\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`\@2\ b\)]],
  "."
}], "Text",
  CellTags->"i:25"],

Cell["\<\
\tThis diffraction is simply a consequence of the uncertainty \
principle of Fourier analysis. According to the uncertainty principle, any \
packet with finite transverse extent must contain a finite range of \
transverse wavenumbers. This necessarily implies a range of directions for \
the phase velocities of the different waves making up the packet. These waves \
then propagate off in separate directions, causing the packet to \
spread.\
\>", "Text",
  CellTags->"i:26"],

Cell[TextData[{
  "\t Even tightly focused laser beams must eventually diffract.  In fact, \
Eq. ",
  ButtonBox["(5.1.56)",
    ButtonData:>"(5.1.56)",
    ButtonStyle->"Hyperlink"],
  "  shows that the narrower the beam, the faster it spreads. However, the \
higher the wavenumber ",
  Cell[BoxData[
      \(TraditionalForm\`k\_o\)]],
  " of the beam, the further it can propagate before diffracting appreciably. \
"
}], "Text"],

Cell[TextData[{
  "\tFor example, for a Gaussian light beam with a wavelength in the visible, \
",
  Cell[BoxData[
      \(TraditionalForm\`2  \[Pi]/k\_o = 5000\ \[Angstrom]\)]],
  ", and an initial radius of ",
  Cell[BoxData[
      FormBox[
        RowBox[{"b", "=", 
          RowBox[{\(1\ cm\), "=", 
            RowBox[{"0.01", " ", 
              StyleBox["m",
                FontSlant->"Plain"]}]}]}], TraditionalForm]]],
  ",  Eq. ",
  ButtonBox["(5.1.56)",
    ButtonData:>"(5.1.56)",
    ButtonStyle->"Hyperlink"],
  " implies that the beam will propagate  ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{
            
            RowBox[{\(0.01\^2\), " ", "\[Times]", " ", 
              "2", \(\[Pi]\ \ /\((5000\ \[Times]\ 10\^\(-10\))\)\), " ", 
              StyleBox["m",
                FontSlant->"Plain"]}], "=", \(1.2\ \ km\)}]}], 
        TraditionalForm]]],
  " before spreading by a factor of ",
  Cell[BoxData[
      \(TraditionalForm\`\@2\)]],
  ".  However, for a 1-cm-radius ultraviolet beam,  with a wavelength of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(40\ \[Angstrom]\)\(,\)\)\)]],
  " the beam propagates ",
  Cell[BoxData[
      \(TraditionalForm\`160\)]],
  " km before spreading by the same factor. "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Wave-Packet Energy and Momentum ", "Subsubsection",
  CellTags->"i:34"],

Cell[TextData[{
  "In this section we derive general expressions for the energy and momentum \
of a wave packet for the wave equation, and for a more general class of wave \
equations that we term ",
  StyleBox["classical",
    FontSlant->"Italic"],
  " wave equations. Quantum wave equations, such as Schr\[ODoubleDot]dinger's \
equation, are considered in the exercises. We begin with energy conservation \
relation for the simple nondispersive wave equation, ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\^2 
            z/\[PartialD]t\^2 = \(c\^2\) \[Del]\^2 z\)]],
  ". Multiplying both sides of this equation by ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\ \[PartialD]z/\[PartialD]t\)]],
  ", and differentiating by parts using, for example, ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]z/\[PartialD]t\ \[PartialD]\^2 
              z/\[PartialD]t\^2 = \(1\/2\) \(\[PartialD]\/\[PartialD]t\) \((\
\[PartialD]z\/\[PartialD]t)\)\^2\)]],
  ", we obtain"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(\(\[PartialD]\/\[PartialD]t\) \[Epsilon]\), " ", "+", 
            RowBox[{"\[Del]", 
              RowBox[{"\[CenterDot]", 
                StyleBox["\[CapitalGamma]",
                  FontWeight->"Bold"]}]}]}], "=", "0"}], TraditionalForm]]],
  ", "
}], "NumberedEquation",
  CellTags->"(5.1.57)"],

Cell["where the  energy density \[Epsilon] is", "Text",
  CellTags->"i:28"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon] = \(\[Rho]\/2\) \((\[PartialD]z\/\
\[PartialD]t)\)\^2 + \(\(\[Rho]\ c\^2\)\/2\) \[Del]z\[CenterDot]\[Del]z\)]],
  ","
}], "NumberedEquation",
  CellTags->"(5.1.58)"],

Cell[TextData[{
  "and the energy flux ",
  Cell[BoxData[
      FormBox[
        StyleBox["\[CapitalGamma]",
          FontWeight->"Bold"], TraditionalForm]]],
  " is"
}], "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["\[CapitalGamma]",
            FontWeight->"Bold"], 
          "=", \(\(-\[Rho]\)\ \(c\^\(\(2\)\(\ \)\)\) \(\[PartialD]z\/\
\[PartialD]t\) \[Del]z\)}], TraditionalForm]]],
  "."
}], "NumberedEquation",
  CellTags->{"i:29", "(5.1.59)"}],

Cell[TextData[{
  "Recall that Eq. ",
  ButtonBox["(5.1.57)",
    ButtonData:>"(5.1.57)",
    ButtonStyle->"Hyperlink"],
  " also described energy conservation for the heat equation, although the \
form of the energy density and flux differed:  see Eq. ",
  ButtonBox["(3.1.38)",
    ButtonData:>{"Chapter3.nb", "(3.1.38)"},
    ButtonStyle->"Hyperlink"],
  ". By integrating Eq. ",
  ButtonBox["(5.1.57)",
    ButtonData:>"(5.1.57)",
    ButtonStyle->"Hyperlink"],
  " over all space, applying the divergence theorem, and assuming that the \
energy flux vanishes at infinity, we can regain the integral form of energy \
conservation, "
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(\[DifferentialD]\/\[DifferentialD]t\), 
            RowBox[{"\[Integral]", 
              RowBox[{
                RowBox[{"\[Epsilon]", "(", 
                  RowBox[{
                    StyleBox["r",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], 
                    StyleBox[",",
                      FontWeight->"Plain"], 
                    StyleBox["t",
                      FontWeight->"Plain"]}], 
                  StyleBox[")",
                    FontWeight->"Plain"]}], \(\[DifferentialD]\^3 r\)}]}]}], 
          "=", "0"}], TraditionalForm]]],
  ","
}], "Text"],

Cell[TextData[{
  "as previously discussed for  1D  or 2D wave propagation [see Eqs. ",
  ButtonBox["(4.2.29)",
    ButtonData:>{"Chapter4.nb", "(4.2.29)"},
    ButtonStyle->"Hyperlink"],
  "   and ",
  ButtonBox["(4.4.33)",
    ButtonData:>{"Chapter4.nb", "(4.4.33)"},
    ButtonStyle->"Hyperlink"],
  "]. [Note: The interpretation of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalGamma]\)]],
  " as energy density and energy flux is easiest to understand when ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  " is the wave displacement (with units of distance). Then ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\)]],
  " is mass density, and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\)]],
  " is the sum of kinetic and potential energies. If ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  " is some other quantity such as wave pressure or potential, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\)]],
  " must be reinterpreted.]"
}], "Text"],

Cell[TextData[{
  "\tNow consider the energy density and energy flux for a wave packet. \
According to Eq. ",
  ButtonBox["(5.1.51)",
    ButtonData:>"(5.1.51)",
    ButtonStyle->"Hyperlink"],
  ", such packets can be described as traveling waves with a slowly",
  " varying",
  " amplitude ",
  Cell[BoxData[
      \(TraditionalForm\`A\)]],
  " and phase ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"z", "(", 
            RowBox[{
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[",",
                FontWeight->"Plain"], 
              StyleBox["t",
                FontWeight->"Plain"]}], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{
            RowBox[{
              StyleBox["A",
                FontWeight->"Plain"], 
              StyleBox["(",
                FontWeight->"Plain"], 
              RowBox[{
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox["-",
                  FontWeight->"Plain"], 
                StyleBox[
                  RowBox[{
                    SubscriptBox[
                      StyleBox["v",
                        FontWeight->"Bold",
                        FontSlant->"Plain"], "g"], "t"}],
                  FontWeight->"Plain"]}], 
              StyleBox[")",
                FontWeight->"Plain"]}], 
            StyleBox[" ",
              FontWeight->"Plain"], 
            RowBox[{
              StyleBox["cos",
                FontWeight->"Plain"], 
              StyleBox["(",
                FontWeight->"Plain"], 
              RowBox[{
                RowBox[{
                  StyleBox[
                    SubscriptBox[
                      StyleBox["k",
                        FontSlant->"Plain"], 
                      StyleBox["o",
                        FontWeight->"Plain"]],
                    FontWeight->"Bold"], "\[CenterDot]", 
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"]}], 
                StyleBox["-",
                  FontWeight->"Plain"], 
                StyleBox[\(\(\[Omega]\_o\) t\),
                  FontWeight->"Plain"], 
                StyleBox["+",
                  FontWeight->"Plain"], 
                RowBox[{
                  StyleBox["\[Phi]",
                    FontWeight->"Plain"], 
                  StyleBox["(",
                    FontWeight->"Plain"], 
                  RowBox[{
                    StyleBox["r",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], 
                    StyleBox["-",
                      FontWeight->"Plain"], 
                    StyleBox[
                      RowBox[{
                        SubscriptBox[
                          StyleBox["v",
                            FontWeight->"Bold",
                            FontSlant->"Plain"], "g"], "t"}],
                      FontWeight->"Plain"]}], 
                  StyleBox[")",
                    FontWeight->"Plain"]}]}], 
              StyleBox[" ",
                FontWeight->"Plain"], 
              StyleBox[")",
                FontWeight->"Plain"]}]}]}], TraditionalForm]]],
  Cell[BoxData[
      FormBox[Cell[""], TraditionalForm]]],
  ","
}], "NumberedEquation",
  CellTags->"(5.1.60)"],

Cell[TextData[{
  "where for our simple wave equation ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_o = c\ k\_o\)]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox[
            StyleBox["v",
              FontWeight->"Bold",
              FontSlant->"Plain"], "g"], "=", 
          RowBox[{"c", " ", 
            SubscriptBox[
              StyleBox[
                OverscriptBox[
                  StyleBox["k",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "^"],
                FontWeight->"Bold"], "o"]}]}], TraditionalForm]]],
  ". We will now substitute this expression into Eq. ",
  ButtonBox["(5.1.58)",
    ButtonData:>"(5.1.58)",
    ButtonStyle->"Hyperlink"],
  ", and note that derivatives of the amplitude and phase are small compared \
to derivatives of the cosine function, since by assumption the packet has \
slowly",
  " varying",
  " amplitude and phase. Then ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[PartialD]z/\[PartialD]t\), " ", "\[TildeEqual]", 
          RowBox[{\(\[Omega]\_o\), "A", " ", 
            RowBox[{"sin", 
              StyleBox["(",
                FontWeight->"Plain"], 
              RowBox[{
                RowBox[{
                  StyleBox[
                    SubscriptBox[
                      StyleBox["k",
                        FontSlant->"Plain"], 
                      StyleBox["o",
                        FontWeight->"Plain"]],
                    FontWeight->"Bold"], "\[CenterDot]", 
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"]}], 
                StyleBox["-",
                  FontWeight->"Plain"], 
                StyleBox[\(\(\[Omega]\_o\) t\),
                  FontWeight->"Plain"], 
                StyleBox["+",
                  FontWeight->"Plain"], 
                StyleBox["\[Phi]",
                  FontWeight->"Plain"]}], 
              StyleBox[" ",
                FontWeight->"Plain"], 
              StyleBox[")",
                FontWeight->"Plain"]}]}]}], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Del]z\), " ", "\[TildeEqual]", 
          RowBox[{
            RowBox[{"-", 
              SubscriptBox[
                StyleBox["k",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "o"]}], "A", " ", 
            RowBox[{"sin", 
              StyleBox["(",
                FontWeight->"Plain"], 
              RowBox[{
                RowBox[{
                  StyleBox[
                    SubscriptBox[
                      StyleBox["k",
                        FontSlant->"Plain"], 
                      StyleBox["o",
                        FontWeight->"Plain"]],
                    FontWeight->"Bold"], "\[CenterDot]", 
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"]}], 
                StyleBox["-",
                  FontWeight->"Plain"], 
                StyleBox[\(\(\[Omega]\_o\) t\),
                  FontWeight->"Plain"], 
                StyleBox["+",
                  FontWeight->"Plain"], 
                StyleBox["\[Phi]",
                  FontWeight->"Plain"]}], 
              StyleBox[" ",
                FontWeight->"Plain"], 
              StyleBox[")",
                FontWeight->"Plain"]}]}]}], TraditionalForm]]],
  ", and the energy density and flux become"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Epsilon]", "=", 
          
          RowBox[{\(\[Rho]\/2\), \((\[Omega]\_o\^2 + \(c\^2\) k\_o\^2)\), 
            " ", \(A\^2\), 
            RowBox[{\(sin\^2\), "(", 
              RowBox[{
                RowBox[{
                  StyleBox[
                    SubscriptBox[
                      StyleBox["k",
                        FontSlant->"Plain"], 
                      StyleBox["o",
                        FontWeight->"Plain"]],
                    FontWeight->"Bold"], "\[CenterDot]", 
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"]}], 
                StyleBox["-",
                  FontWeight->"Plain"], 
                StyleBox[\(\(\[Omega]\_o\) t\),
                  FontWeight->"Plain"], 
                StyleBox["+",
                  FontWeight->"Plain"], 
                StyleBox["\[Phi]",
                  FontWeight->"Plain"]}], 
              StyleBox[" ",
                FontWeight->"Plain"], 
              StyleBox[")",
                FontWeight->"Plain"]}]}]}], TraditionalForm]]],
  ",\n",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["\[CapitalGamma]",
            FontWeight->"Bold"], "=", 
          RowBox[{"\[Rho]", " ", \(c\^\(\(2\)\(\ \)\)\), \(\[Omega]\_o\), 
            SubscriptBox[
              StyleBox["k",
                FontWeight->"Bold",
                FontSlant->"Plain"], "o"], \(A\^2\), 
            RowBox[{\(sin\^2\), "(", 
              RowBox[{
                RowBox[{
                  StyleBox[
                    SubscriptBox[
                      StyleBox["k",
                        FontSlant->"Plain"], 
                      StyleBox["o",
                        FontWeight->"Plain"]],
                    FontWeight->"Bold"], "\[CenterDot]", 
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"]}], 
                StyleBox["-",
                  FontWeight->"Plain"], 
                StyleBox[\(\(\[Omega]\_o\) t\),
                  FontWeight->"Plain"], 
                StyleBox["+",
                  FontWeight->"Plain"], 
                StyleBox["\[Phi]",
                  FontWeight->"Plain"]}], 
              StyleBox[" ",
                FontWeight->"Plain"], 
              StyleBox[")",
                FontWeight->"Plain"]}]}]}], TraditionalForm]]],
  "."
}], "NumberedEquation",
  CellTags->"(5.1.61)"],

Cell[TextData[{
  "The energy density varies in time because energy is traded back and forth \
between different parts of the packet as the wave oscillates, and also \
because the packet moves at the group velocity. However, if we take a time \
average over the oscillations, using ",
  Cell[BoxData[
      \(TraditionalForm\`\[LeftAngleBracket]sin\^2\ x\[RightAngleBracket]\  = 
        1/2\)]],
  ", we arrive at an expression for the average energy and flux associated \
with the packet :"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(\[Epsilon]\&_\), "(", 
            RowBox[{
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], ",", "t"}], ")"}], "=", 
          RowBox[{\(\[Rho]\/2\), 
            StyleBox[
              SuperscriptBox[
                RowBox[{\(\[Omega]\_o\^2\), " ", "[", 
                  RowBox[{"A", "(", 
                    RowBox[{
                      StyleBox["r",
                        FontWeight->"Bold",
                        FontSlant->"Plain"], 
                      StyleBox["-",
                        FontWeight->"Plain"], 
                      StyleBox[
                        RowBox[{"c", " ", 
                          SubscriptBox[
                            StyleBox[
                              OverscriptBox[
                                StyleBox["k",
                                  FontWeight->"Bold",
                                  FontSlant->"Plain"], "^"],
                              FontWeight->"Bold"], "o"], "t"}],
                        FontWeight->"Plain"]}], 
                    StyleBox[")",
                      FontWeight->"Plain"]}], 
                  StyleBox["]",
                    FontWeight->"Plain"]}], "2"],
              FontWeight->"Plain"]}]}], TraditionalForm]]],
  ",\n",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox[
              OverscriptBox[
                StyleBox["\[CapitalGamma]",
                  FontWeight->"Bold"], 
                StyleBox["_",
                  FontWeight->"Plain"]],
              FontWeight->"Bold"], "(", 
            RowBox[{
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], ",", "t"}], ")"}], "=", 
          RowBox[{
            RowBox[{\(\[Epsilon]\&_\), "(", 
              RowBox[{
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], ",", "t"}], ")"}], " ", "c", " ", 
            SubscriptBox[
              StyleBox[
                OverscriptBox[
                  StyleBox["k",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "^"],
                FontWeight->"Bold"], "o"]}]}], TraditionalForm]]],
  ","
}], "NumberedEquation",
  CellTags->{"i:30", "(5.1.62)"}],

Cell[TextData[{
  "where we have used the dispersion relation ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_o = c\ k\_o\)]],
  ".   Both energy density and flux are proportional to amplitude squared, \
and propagate at the wave velocity ",
  Cell[BoxData[
      FormBox[
        RowBox[{"c", " ", 
          SubscriptBox[
            StyleBox[
              OverscriptBox[
                StyleBox["k",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "^"],
              FontWeight->"Bold"], "o"]}], TraditionalForm]]],
  ". "
}], "Text"],

Cell[TextData[{
  "\t Also, we see that the energy flux consists of the energy density \
transported at the wave velocity ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{"c", " ", 
            StyleBox[
              SubscriptBox[
                StyleBox[
                  OverscriptBox[
                    StyleBox["k",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], "^"],
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox["o",
                  FontWeight->"Plain"]],
              FontWeight->"Bold"]}]}], TraditionalForm]]],
  ". This is to be expected, since energy is neither created nor destroyed in \
this wave system, but is simply moved from place to place by the waves. The \
Poynting flux ",
  Cell[BoxData[
      FormBox[
        StyleBox["S",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " for electromagnetic waves traveling in a dispersionless medium has the \
same form, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["S",
            FontWeight->"Bold",
            FontSlant->"Plain"], "=", 
          RowBox[{"\[Epsilon]", " ", "c", " ", 
            StyleBox[
              OverscriptBox[
                StyleBox["k",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "^"],
              FontWeight->"Bold"]}]}], TraditionalForm]]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\)]],
  " is the wave energy density."
}], "Text"],

Cell[TextData[{
  "\t However, for more general wave equations, we might expect the average \
energy flux to involve the group velocity ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["v",
            FontWeight->"Bold",
            FontSlant->"Plain"], "g"], TraditionalForm]]],
  ". We will now show that this is in fact the case. We will also find a \
simple expression for the energy density in terms of the dispersion relation \
for the waves."
}], "Text"],

Cell["\tConsider a wave equation of the form", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Sum]\+\(n\  = 0, 2, 4, 6,  ... \)\(a\_n\) \(\
\[PartialD]\^n\/\[PartialD]t\^n\) 
            z\  = \ \[Sum]\+\(n = 2, 4, 6,  ... \)\(\[Sum]\+\(j = 1, 2, \
3\)\(b\_\(n\ j\)\) \(\[PartialD]\^n\/\[PartialD]r\_j\^n\) z\)\)]],
  ","
}], "NumberedEquation",
  CellTags->"(5.1.63)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`r\_j\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`j = 1, 2, 3\)]],
  ", are the ",
  Cell[BoxData[
      \(TraditionalForm\`x, y\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  " components of ",
  Cell[BoxData[
      FormBox[
        StyleBox["r",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`a\_n\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`b\_\(n\ j\)\)]],
  " are constant coefficients. Even more general wave equations could be \
constructed, involving cross-derivatives between different components of  ",
  Cell[BoxData[
      \(TraditionalForm\`r\_j\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  ", but Eq. ",
  ButtonBox["(5.1.63)",
    ButtonData:>"(5.1.63)",
    ButtonStyle->"Hyperlink"],
  " is sufficient for our purposes. We refer to wave equations of the form of \
Eq. ",
  ButtonBox["(5.1.63)",
    ButtonData:>"(5.1.63)",
    ButtonStyle->"Hyperlink"],
  " as ",
  StyleBox["classical wave equations",
    FontSlant->"Italic"],
  ".  Note that wave equations such as Schr\[ODoubleDot]dinger's equation, \
with odd powers of the time derivative, are not included in this form.  \
Conservation laws for Schr\[ODoubleDot]dinger's equation and its cousins will \
be considered in the exercises."
}], "Text",
  CellTags->"i:35"],

Cell[TextData[{
  "\tThe dispersion relation associated with this wave equation takes the \
form of a polynomial, found by replacing ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\/\[PartialD]t\)]],
  " by ",
  Cell[BoxData[
      \(TraditionalForm\`\(-\[ImaginaryI]\)\ \[Omega]\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\/\[PartialD]r\_j\ by\ \[ImaginaryI]\ \
k\_j\)]],
  " . We write this dispersion relation in the compact form ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"D", "(", 
            RowBox[{
              StyleBox["k",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[",",
                FontWeight->"Plain"], 
              StyleBox["\[Omega]",
                FontWeight->"Plain"]}], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox["0",
            FontWeight->"Plain"]}], TraditionalForm]]],
  ", where the ",
  StyleBox["dispersion function",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`D\)]],
  " is given by"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"D", "(", 
            RowBox[{
              StyleBox["k",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[",",
                FontWeight->"Plain"], 
              StyleBox["\[Omega]",
                FontWeight->"Plain"]}], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox["=",
            
            FontWeight->
              "Plain"], \(\[Sum]\+n\ \(\((\(-1\))\)\^\(n/2 - 1\)\) 
                a\_n\ \[Omega]\^n\  + \ \[Sum]\+\(\(\ \)\(n\ \
j\)\)\(\((\(-1\))\)\^\(n/2\)\) \(b\_\(n\ j\)\) k\_j\^n\)}], 
        TraditionalForm]]],
  ","
}], "NumberedEquation",
  CellTags->{"i:36", "(5.1.64)"}],

Cell[TextData[{
  "and we have used the fact that ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " is even. For example, for  electromagnetic waves traveling through a \
medium with refractive index ",
  Cell[BoxData[
      FormBox[
        RowBox[{"n", "(", 
          StyleBox["\[Omega]",
            FontWeight->"Plain"], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  ", the dispersion function is ",
  Cell[BoxData[
      \(TraditionalForm\`D = \(\(\[Omega]\^2\) \(\(n\^2\)(\[Omega])\) - 
            c\^2\ k\^2 = 0\)\)]],
  ",",
  " and we can think of Eq. ",
  ButtonBox["(5.1.64)",
    ButtonData:>"(5.1.64)",
    ButtonStyle->"Hyperlink"],
  " as a polynomial expansion of this equation. "
}], "Text",
  CellTags->"i:112"],

Cell[TextData[{
  "\tWe now construct an energy conservation law for Eq. ",
  ButtonBox["(5.1.63)",
    ButtonData:>"(5.1.63)",
    ButtonStyle->"Hyperlink"],
  " by following the same approach as for the wave equation. We multiply both \
sides of the equation by ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\ \[PartialD]z/\[PartialD]t\)]],
  ", and differentiate by parts repeatedly. For example,\n\t\t",
  Cell[BoxData[{
      \(TraditionalForm\`\(\[PartialD]z\/\[PartialD]t\) \[PartialD]\^n z\/\
\[PartialD]t\^n = \(\[PartialD]\/\[PartialD]t\) \
\((\(\[PartialD]z\/\[PartialD]t\) \[PartialD]\^\(n - 1\)z\/\[PartialD]t\^\(n \
- 1\))\) - \(\[PartialD]\^2 
                  z\/\[PartialD]t\^2\) \[PartialD]\^\(n - \
1\)z\/\[PartialD]t\^\(n - 1\)\), "\[IndentingNewLine]", 
      \(TraditionalForm\`\(\(=\)\(\(\[PartialD]\/\[PartialD]t\) \((\(\
\[PartialD]z\/\[PartialD]t\) \[PartialD]\^\(n - 1\)z\/\[PartialD]t\^\(n - 1\) \
- \(\[PartialD]\^2 
                          z\/\[PartialD]t\^2\) \[PartialD]\^\(n - 2\)z\/\
\[PartialD]t\^\(n - 2\))\)\  + \(\[PartialD]\^3 
                    z\/\[PartialD]t\^3\) \[PartialD]\^\(n - \
2\)z\/\[PartialD]t\^\(n - 2\) = \ \(\(...\)\(\ \)\(\[IndentingNewLine]\)
            \(\(=\)\(\(\[PartialD]\/\[PartialD]t\) \((\[Sum]\+\(m = 1\)\%\(n \
- 1\)\(\((\(-1\))\)\^\(m - 1\)\) \(\[PartialD]\^m 
                              z\/\[PartialD]t\^m\) \[PartialD]\^\(n - m\)z\/\
\[PartialD]t\^\(n - m\))\)\  + \ \(\((\(-1\))\)\^\(n - 
                        1\)\) \(\[PartialD]z\/\[PartialD]t\) \
\(\(\[PartialD]\^n z\/\[PartialD]t\^n\)\(.\)\)\)\)\)\)\)\)}]]
}], "Text"],

Cell[TextData[{
  "However, if ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " is even,",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\(\((\(-1\))\)\^\(n - 
                1\)\) \(\[PartialD]z\/\[PartialD]t\) \[PartialD]\^n z\/\
\[PartialD]t\^n = \ \(-\(\[PartialD]z\/\[PartialD]t\)\) \[PartialD]\^n z\/\
\[PartialD]t\^n\)\)\)]],
  ". This allows us to bring this term over to the ",
  "left-hand",
  " side of the equation, and so obtain"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox["", TraditionalForm]]],
  Cell[BoxData[
      \(TraditionalForm\`\(\[PartialD]z\/\[PartialD]t\) \[PartialD]\^n z\/\
\[PartialD]t\^n = \(1\/2\) \(\[PartialD]\/\[PartialD]t\) \((\[Sum]\+\(m = 1\)\
\%\(n - 1\)\(\((\(-1\))\)\^\(m - 1\)\) \(\[PartialD]\^m 
                      z\/\[PartialD]t\^m\) \[PartialD]\^\(n - m\)z\/\
\[PartialD]t\^\(n - m\))\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`n = 2, 4, 6,  ... \)]]
}], "NumberedEquation",
  CellTags->"(5.1.65)"],

Cell[TextData[{
  "For the ",
  Cell[BoxData[
      \(TraditionalForm\`n = 0\)]],
  "case, we can simply write"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\[PartialD]z\/\[PartialD]t\) 
          z\  = \(\(1\/2\) \(\[PartialD]z\^2\/\[PartialD]t\)\(\ \)\)\)]],
  ". "
}], "NumberedEquation",
  CellTags->"(5.1.66)"],

Cell[TextData[{
  "Similarly, we require terms of the form ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[PartialD]z\/\[PartialD]t\) \[PartialD]\^n z\/\
\[PartialD]r\_j\^n\)]],
  " on the ",
  "right-hand",
  " side of the energy equation. These terms can also be rewritten via \
differentiation by parts: "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\[PartialD]z\/\[PartialD]t\) \[PartialD]\^n z\/\
\[PartialD]r\_j\^n = \(\[PartialD]\/\[PartialD]r\_j\) \((\[Sum]\+\(m = \
1\)\%\(n/2\)\(\((\(-1\))\)\^\(m - 
                        1\)\) \(\[PartialD]\^m\/\[PartialD]r\_j\^m\) \((\
\[PartialD]z\/\[PartialD]t)\) \[PartialD]\^\(n - m - \
1\)z\/\[PartialD]r\_j\^\(n - m - 1\))\) - \(1\/2\) \
\(\[PartialD]\/\[PartialD]t\) \
\((\[PartialD]\^\(n/2\)z\/\[PartialD]r\_j\^\(n/2\))\)\^2\)]],
  ","
}], "NumberedEquation",
  CellTags->"(5.1.67)"],

Cell[TextData[{
  "where again we have used the fact that ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " is even.  Combining Eqs. ",
  ButtonBox["(5.1.65)",
    ButtonData:>"(5.1.65)",
    ButtonStyle->"Hyperlink"],
  "-",
  ButtonBox["(5.1.67)",
    ButtonData:>"(5.1.67)",
    ButtonStyle->"Hyperlink"],
  "",
  ",",
  " we obtain the general energy conservation relation in the form of Eq. ",
  ButtonBox["(5.1.57)",
    ButtonData:>"(5.1.57)",
    ButtonStyle->"Hyperlink"],
  ", with "
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{"\[Epsilon]", " ", "=", 
        RowBox[{\(\(\[Rho]\/2\) \(a\_o\) z\^2\), "+", 
          RowBox[{\(\[Rho]\/2\), 
            RowBox[{\(\[Sum]\+\(n = 2, 4,  ... \)\), 
              RowBox[{"(", 
                
                RowBox[{\(\(a\_n\) \(\[Sum]\+\(m = 1\)\%\(n - 1\)\(\((\(-1\))\
\)\^\(m - 1\)\) \(\[PartialD]\^m 
                              z\/\[PartialD]t\^m\) \[PartialD]\^\(n - m\)z\/\
\[PartialD]t\^\(n - m\)\)\), " ", "+", " ", 
                  RowBox[{
                    UnderscriptBox[
                      StyleBox["\[Sum]",
                        FontSize->8], \(\(\ \ \)\(j\)\)], 
                    " ", \(\(\(b\_\(n\ j\)\)(\[PartialD]\^\(n/2\)z\/\
\[PartialD]r\_j\^\(n/2\))\)\^2\)}]}], ")"}]}]}]}]}], 
      TraditionalForm]]]], "NumberedEquation",
  CellTags->"(5.1.68)"],

Cell["and ", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalGamma]\_j = \(-\[Rho]\) \(\[Sum]\+\(n = 2, \
4,  ... \)\(b\_\(n\ j\)\) \(\[Sum]\+\(m = 1\)\%\(n/2\)\(\((\(-1\))\)\^\(m - 
                        1\)\) \(\[PartialD]\^m\/\[PartialD]r\_j\^m\) \((\
\[PartialD]z\/\[PartialD]t)\) \[PartialD]\^\(n - m - \
1\)z\/\[PartialD]r\_j\^\(n - m - 1\)\)\)\)]],
  "."
}], "NumberedEquation",
  CellTags->"(5.1.69)"],

Cell[TextData[{
  "\tIn their present form, these expressions for energy density and flux are \
of such complexity as to be of limited usefulness. However, when applied to \
wave packets, the expressions simplify considerably. On substituting Eq. ",
  ButtonBox["(5.1.60)",
    ButtonData:>"(5.1.60)",
    ButtonStyle->"Hyperlink"],
  " into Eqs. ",
  ButtonBox["(5.1.68)",
    ButtonData:>"(5.1.68)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(5.1.69)",
    ButtonData:>"(5.1.69)",
    ButtonStyle->"Hyperlink"],
  ", again dropping derivatives of the slowing",
  " varying",
  " amplitude and phase, and averaging over a cycle, each term in the sum \
over ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " in Eq. ",
  ButtonBox["(5.1.68)",
    ButtonData:>"(5.1.68)",
    ButtonStyle->"Hyperlink"],
  " yields the same result, ",
  Cell[BoxData[
      \(TraditionalForm\`\(\((\(-1\))\)\^\(n/2 - 1\)\) \(\[Omega]\_o\^n\) 
        A\^2/2\)]],
  "; the same is true for each term in the sum over ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " in Eq. ",
  ButtonBox["(5.1.69)",
    ButtonData:>"(5.1.69)",
    ButtonStyle->"Hyperlink"],
  ", which becomes ",
  Cell[BoxData[
      \(TraditionalForm\`\(\((\(-1\))\)\^\(n/2\)\) \(\(\(\[Omega]\_o\)(
              k\_\(o\ j\))\)\^n\) A\^2/2\)]],
  ".  We then obtain the following expressions for the averaged energy \
density and flux:"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Epsilon]\&_\), " ", "=", 
          RowBox[{\(\[Rho]\/4\), 
            RowBox[{\(A\^2\), "(", 
              RowBox[{\(a\_o\), "+", 
                RowBox[{\(\[Sum]\+\(n = 2, 4,  ... \)\), 
                  RowBox[{\(\((\(-1\))\)\^\(n/2 - 1\)\), 
                    RowBox[{"(", 
                      
                      RowBox[{\(\(a\_n\) \[Omega]\_o\^n\ \((n - 1)\)\), " ", 
                        "+", 
                        RowBox[{
                          UnderscriptBox[
                            StyleBox["\[Sum]",
                              
                              FontSize->
                                8], \(\(\ \)\(j\)\)], \(b\_\(n\ j\)\ \ \((k\_\
\(o\ j\))\)\^n\)}]}], ")"}]}]}]}], ")"}]}]}], TraditionalForm]]],
  ","
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalGamma]\&_\_j = \(\[Rho]\/4\) \(\[Sum]\+\(n \
= 2, 4,  ... \)\(\((\(-1\))\)\^\(n/2 - 1\)\) \(b\_\(n\ j\)\) 
              A\^2\ \ \[Omega]\_o\ n\ \((k\_\(o\ j\))\)\^\(n - 1\)\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "These sums collapse into amazingly simple and general expressions if they \
are written in terms of the dispersion function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"D", "(", 
          RowBox[{
            StyleBox["k",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[",",
              FontWeight->"Plain"], 
            StyleBox["\[Omega]",
              FontWeight->"Plain"]}], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  ", defined in Eq. ",
  ButtonBox["(5.1.64)",
    ButtonData:>"(5.1.64)",
    ButtonStyle->"Hyperlink"],
  ". By applying differentiation formulae such as ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\[Omega]\_o\^n/\[PartialD]\[Omega]\_o = 
        n\ \[Omega]\_o\^\(n - 1\)\)]],
  ", we obtain"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{\(\[Epsilon]\&_\), " ", "=", 
          
          RowBox[{\(\[Rho]\/4\), \(A\^2\), \(\[Omega]\_o\^2\), \
\(\[PartialD]\/\[PartialD]\[Omega]\_o\), 
            RowBox[{"(", 
              RowBox[{
                RowBox[{"D", "(", 
                  RowBox[{
                    StyleBox[
                      SubscriptBox[
                        StyleBox["k",
                          FontSlant->"Plain"], 
                        StyleBox["o",
                          FontWeight->"Plain"]],
                      FontWeight->"Bold"], ",", \(\[Omega]\_o\)}], ")"}], 
                "/", \(\[Omega]\_o\)}], ")"}]}]}], ","}], 
      TraditionalForm]]]], "NumberedEquation",
  CellTags->"(5.1.70)"],

Cell["and", "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[CapitalGamma]\&_\_j\), "=", 
          
          RowBox[{\(-\(\[Rho]\/4\)\), \(A\^2\), \(\[Omega]\_o\), \
\(\[PartialD]\/\[PartialD]k\_\(o\ j\)\), 
            RowBox[{"D", "(", 
              RowBox[{
                StyleBox[
                  SubscriptBox[
                    StyleBox["k",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], 
                    StyleBox["o",
                      FontWeight->"Plain"]],
                  FontWeight->"Bold"], ",", \(\[Omega]\_o\)}], ")"}]}]}], 
        TraditionalForm]]],
  "."
}], "NumberedEquation",
  CellTags->"(5.1.71)"],

Cell[TextData[{
  "\tTwo more simplifications can be made. First, since ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"D", "(", 
            RowBox[{
              StyleBox[
                SubscriptBox[
                  StyleBox["k",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], 
                  StyleBox["o",
                    FontWeight->"Plain"]],
                FontWeight->"Bold"], ",", \(\[Omega]\_o\)}], ")"}], "=", 
          "0"}], TraditionalForm]]],
  ", Eq. ",
  ButtonBox["(5.1.70)",
    ButtonData:>"(5.1.70)",
    ButtonStyle->"Hyperlink"],
  " can also be written as "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Epsilon]\&_\), " ", "=", 
          
          RowBox[{\(\[Rho]\/4\), \(A\^2\), \(\[Omega]\_o\), \(\[PartialD]\/\
\[PartialD]\[Omega]\_o\), 
            RowBox[{"D", "(", 
              RowBox[{
                StyleBox[
                  SubscriptBox[
                    StyleBox["k",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], 
                    StyleBox["o",
                      FontWeight->"Plain"]],
                  FontWeight->"Bold"], ",", \(\[Omega]\_o\)}], ")"}]}]}], 
        TraditionalForm]]],
  "."
}], "NumberedEquation",
  CellTags->{"i:32", "(5.1.72)"}],

Cell[TextData[{
  "Second, we note that the group velocity ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["v",
            FontWeight->"Bold",
            FontSlant->"Plain"], "g"], TraditionalForm]]],
  " can be written as"
}], "Text"],

Cell[TextData[{
  "\t\t ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox[
            StyleBox["v",
              FontWeight->"Bold",
              FontSlant->"Plain"], "g"], "=", 
          RowBox[{
            RowBox[{\(\[PartialD]\[Omega]\_o\), "/", 
              RowBox[{"\[PartialD]", 
                StyleBox[
                  SubscriptBox[
                    StyleBox["k",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], 
                    StyleBox["o",
                      FontWeight->"Plain"]],
                  FontWeight->"Bold"]}]}], 
            StyleBox[" ",
              FontWeight->"Bold"], 
            StyleBox["=",
              FontWeight->"Plain"], 
            RowBox[{
              StyleBox["-",
                FontWeight->"Plain"], 
              FractionBox[
                RowBox[{\(\[PartialD]D\), "/", 
                  RowBox[{"\[PartialD]", 
                    StyleBox[
                      SubscriptBox[
                        StyleBox["k",
                          FontWeight->"Bold",
                          FontSlant->"Plain"], 
                        StyleBox["o",
                          FontWeight->"Plain"]],
                      
                      FontWeight->
                        "Bold"]}]}], \
\(\[PartialD]D/\[PartialD]\[Omega]\_o\)]}]}]}], TraditionalForm]]],
  "."
}], "Text"],

Cell["\<\
 This allows us to write the energy flux in terms of the energy \
density as \
\>", "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            OverscriptBox["\[CapitalGamma]", 
              StyleBox["_",
                FontWeight->"Plain"]],
            FontWeight->"Bold"], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox[
            RowBox[{
              SubscriptBox[
                StyleBox["v",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "g"], " ", \(\[Epsilon]\&_\)}],
            FontWeight->"Plain"]}], TraditionalForm]]],
  "."
}], "NumberedEquation",
  CellTags->"(5.1.73)"],

Cell["\<\
Thus, the energy density propagates in the direction of the group \
velocity, as we expected.  \
\>", "Text",
  CellTags->"i:116"],

Cell[TextData[{
  "\tEquations ",
  ButtonBox["(5.1.72)",
    ButtonData:>"(5.1.72)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(5.1.73)",
    ButtonData:>"(5.1.73)",
    ButtonStyle->"Hyperlink"],
  " provide simple general expressions for the energy density and flux \
associated with a ",
  "wave packet",
  ". Similar expressions can also be obtained for the momentum density and \
momentum flux. Here, the conservation law is obtained by multiplying the wave \
equation by ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho] \[Del]z\)]],
  " rather than by ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho] \[PartialD]z/\[PartialD]t\)]],
  ", and then applying the same differentiation by parts regimen. The \
resulting conservation law is written as follows:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{\(\[PartialD]\/\[PartialD]t\), 
              StyleBox["p",
                FontWeight->"Bold",
                FontSlant->"Plain"]}], " ", "+", 
            RowBox[{"\[Del]", 
              RowBox[{"\[CenterDot]", 
                StyleBox["T",
                  FontWeight->"Bold",
                  FontSlant->"Plain"]}]}]}], "=", "0"}], TraditionalForm]]],
  ","
}], "NumberedEquation",
  CellTags->"(5.1.74)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        StyleBox["p",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " is the momentum density, and ",
  Cell[BoxData[
      FormBox[
        StyleBox["T",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " is a tensor (the stress tensor), which is the flux of momentum. (Since \
momentum is a vector, the flux of momentum is a tensor. The components of ",
  Cell[BoxData[
      FormBox[
        StyleBox["T",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`T\_\(i\ j\)\)]],
  ", provide the flux of ",
  Cell[BoxData[
      \(TraditionalForm\`p\_i\)]],
  " in direction ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  ".) The units of ",
  Cell[BoxData[
      FormBox[
        StyleBox["T",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " are pressure, and in fact ",
  Cell[BoxData[
      FormBox[
        StyleBox["T",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " is the pressure created by the waves. For a ",
  "wave packet",
  ", the expressions for  ",
  Cell[BoxData[
      FormBox[
        StyleBox["p",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        StyleBox["T",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  ", averaged over a cycle, are"
}], "Text",
  CellTags->"i:117"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        StyleBox[
          OverscriptBox[
            StyleBox["p",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox["_",
              FontWeight->"Plain"]],
          FontWeight->"Bold"], 
        StyleBox["=",
          FontWeight->"Plain"], 
        RowBox[{
          StyleBox[
            SubscriptBox[
              StyleBox["k",
                FontSlant->"Plain"], 
              StyleBox["o",
                FontWeight->"Plain"]],
            FontWeight->"Bold"], 
          StyleBox[" ",
            FontWeight->"Plain"], 
          StyleBox[
            RowBox[{
              OverscriptBox[
                StyleBox["\[Epsilon]",
                  FontWeight->"Plain"], "_"], "/", \(\[Omega]\_o\)}],
            FontWeight->"Plain"]}]}], TraditionalForm]]]], "NumberedEquation",\

  CellTags->{"i:33", "(5.1.75)"}],

Cell["and", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`T\_\(i\ j\) = \ p\&_\_i\ v\_\(g\ j\)\)]],
  "."
}], "NumberedEquation",
  CellTags->"(5.1.76)"],

Cell[TextData[{
  "The proof of Eqs. ",
  ButtonBox["(5.1.75)",
    ButtonData:>"(5.1.75)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(5.1.76)",
    ButtonData:>"(5.1.76)",
    ButtonStyle->"Hyperlink"],
  " is left as an exercise."
}], "Text"],

Cell[TextData[{
  "\t Thus, just as with energy density, the flux of momentum is given by the \
momentum density, transported at the group velocity. The wave momentum itself \
is in the direction of the wave vector ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          SubscriptBox[
            StyleBox["k",
              FontSlant->"Plain"], 
            StyleBox["o",
              FontWeight->"Plain"]],
          FontWeight->"Bold"], TraditionalForm]]],
  "(rather than the group velocity), since the phase fronts responsible for \
pushing on an object in the path of the wave travel in this direction. For \
waves traveling in the ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  "-direction though a nondispersive medium, the only nonzero component of ",
  Cell[BoxData[
      FormBox[
        StyleBox["T",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " is ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(T\_\(x\ x\)\), "=", 
          OverscriptBox[
            StyleBox["\[Epsilon]",
              FontWeight->"Plain"], "_"]}], TraditionalForm]]],
  ", indicating that a pressure equal to the wave energy density will be \
exerted on an absorbing barrier placed in the path of the wave packet.  "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Spherically-Symmetric Disturbance", "Subsubsection"],

Cell[TextData[{
  "We now consider the evolution of waves in a dispersionless medium, \
starting from a spherically symmetric initial condition, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(p\_o\), "(", 
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox[" ",
            FontWeight->"Plain"], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{"P", 
            StyleBox[" ",
              
              FontWeight->
                "Plain"], \(\[ExponentialE]\^\(\(-r\^2\)/a\^2\)\)}]}], 
        TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(u\_o\), "(", 
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox["0",
            FontWeight->"Plain"]}], TraditionalForm]]],
  ". The Fourier transform of ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(p\_o\), "(", 
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  " is  ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(p\&~\_o\), "(", 
            StyleBox["k",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox["=",
            FontWeight->"Plain"], \(\(\((\[Pi]\ a\^2)\)\^\(3/2\)\) 
            P\ \[ExponentialE]\^\(\(-a\^2\) k\^2/4\)\)}], TraditionalForm]]],
  ". Then according to Eq. ",
  ButtonBox["(5.1.48)",
    ButtonData:>"(5.1.48)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(5.1.50)",
    ButtonData:>"(5.1.50)",
    ButtonStyle->"Hyperlink"],
  ", the response to this initial condition is"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"p", "(", 
            RowBox[{
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[",",
                FontWeight->"Plain"], 
              StyleBox["t",
                FontWeight->"Plain"]}], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{
            RowBox[{
              StyleBox["2",
                FontWeight->"Plain"], " ", "Re", " ", 
              RowBox[{"\[Integral]", 
                
                RowBox[{\(\(\(\[DifferentialD]\^3 
                        k\)\(\ \)\)\/\((2  \[Pi])\)\^3\), 
                  RowBox[{\(p\&~\_o\), "(", 
                    StyleBox["k",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], 
                    StyleBox[")",
                      FontWeight->"Plain"]}], 
                  StyleBox[
                    SuperscriptBox["\[ExponentialE]", 
                      RowBox[{"\[ImaginaryI]", " ", 
                        RowBox[{"(", 
                          RowBox[{
                            RowBox[{
                              StyleBox["k",
                                FontWeight->"Bold",
                                FontSlant->"Plain"], "\[CenterDot]", 
                              StyleBox["r",
                                FontWeight->"Bold",
                                FontSlant->"Plain"]}], 
                            StyleBox["-",
                              FontWeight->"Bold"], 
                            RowBox[{"c", " ", "k", " ", 
                              StyleBox["t",
                                FontWeight->"Plain"]}]}], 
                          StyleBox[")",
                            FontWeight->"Plain"]}]}]],
                    FontWeight->"Plain"]}]}]}], " ", "=", 
            RowBox[{\(\((\[Pi]\ a\^2)\)\^\(3/2\)\), 
              StyleBox["P",
                FontWeight->"Plain"], 
              StyleBox[" ",
                FontWeight->"Plain"], "Re", 
              RowBox[{"\[Integral]", 
                
                RowBox[{\(\(\(\[DifferentialD]\^3 
                        k\)\(\ \)\)\/\((2  \[Pi])\)\^3\), 
                  StyleBox[
                    SuperscriptBox["\[ExponentialE]", 
                      RowBox[{
                        RowBox[{"\[ImaginaryI]", " ", 
                          RowBox[{"(", 
                            RowBox[{
                              RowBox[{
                                StyleBox["k",
                                  FontWeight->"Bold",
                                  FontSlant->"Plain"], "\[CenterDot]", 
                                StyleBox["r",
                                  FontWeight->"Bold",
                                  FontSlant->"Plain"]}], 
                              StyleBox["-",
                                FontWeight->"Bold"], 
                              RowBox[{"c", " ", "k", " ", 
                                StyleBox["t",
                                  FontWeight->"Plain"]}]}], 
                            StyleBox[")",
                              FontWeight->"Plain"]}]}], 
                        "-", \(\(a\^2\) k\^2/4\)}]],
                    FontWeight->"Plain"]}]}]}]}]}], TraditionalForm]]],
  "."
}], "NumberedEquation",
  CellTags->"(5.1.77)"],

Cell[TextData[{
  "It is best to perform this integration using spherical  coordinates in ",
  Cell[BoxData[
      FormBox[
        StyleBox["k",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  "-space, ",
  Cell[BoxData[
      \(TraditionalForm\`\((k, \[Theta], \[Phi])\)\)]],
  ". Here ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " are polar angles used to determine the direction of ",
  Cell[BoxData[
      FormBox[
        StyleBox["k",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " with respect to fixed axes. We choose the vector ",
  Cell[BoxData[
      FormBox[
        StyleBox["r",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " to be along the ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(k\_z\)\(-\)\)\)]],
  " axis of this coordinate system, so that ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["k",
              FontWeight->"Bold",
              FontSlant->"Plain"], "\[CenterDot]", 
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox[\(k\ r\ cos\[Theta]\),
            FontWeight->"Plain"]}], TraditionalForm]]],
  ", where ",
  Cell[BoxData[
      FormBox[
        RowBox[{"r", "=", 
          RowBox[{"|", 
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], "|"}]}], TraditionalForm]]],
  ".  Also, ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]\^3 
          k\  = \(k\^2\) \[DifferentialD]k\ sin\[Theta]\ \[DifferentialD]\
\[Theta]\ \[DifferentialD]\[Phi]\)]],
  ". Equation ",
  ButtonBox["(5.1.77)",
    ButtonData:>"(5.1.77)",
    ButtonStyle->"Hyperlink"],
  " then becomes"
}], "Text",
  CellTags->"i:40"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"p", "(", 
            RowBox[{
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[",",
                FontWeight->"Plain"], 
              StyleBox["t",
                FontWeight->"Plain"]}], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          
          RowBox[{\(\(\(\((\[Pi]\ a\^2)\)\^\(3/2\)\) P\)\/\((2  \[Pi])\)\^3\),
             "Re", 
            RowBox[{\(\[Integral]\_0\%\[Infinity]\), 
              RowBox[{\(k\^2\), \(\[DifferentialD]k\), 
                RowBox[{\(\[Integral]\_0\%\(2  \[Pi]\)\), 
                  RowBox[{\(\[DifferentialD]\[Phi]\), 
                    RowBox[{\(\[Integral]\_0\%\[Pi]\), 
                      RowBox[{
                      "sin\[Theta]", \(\[DifferentialD]\[Theta]\), 
                        " ", \(\[ExponentialE]\^\(\(-a\^2\) k\^2/4\)\), 
                        StyleBox[
                          SuperscriptBox["\[ExponentialE]", 
                            RowBox[{"\[ImaginaryI]", " ", "k", " ", 
                              RowBox[{"(", 
                                RowBox[{\(r\ cos\[Theta]\), "-", 
                                  RowBox[{"c", "  ", 
                                    StyleBox["t",
                                      FontWeight->"Plain"]}]}], 
                                StyleBox[")",
                                  FontWeight->"Plain"]}]}]],
                          FontWeight->"Plain"]}]}]}]}]}]}]}]}], 
        TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  "The  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  "-integral is trivial, and the \[Theta]-integral can be calculated by \
changing variables to ",
  Cell[BoxData[
      \(TraditionalForm\`x = cos\[Theta]\)]],
  ". This implies that ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[DifferentialD]x\  = \ \(-sin\[Theta]\)\ \
\[DifferentialD]\[Theta]\)\(,\)\)\)]],
  " and the range of integration runs from ",
  Cell[BoxData[
      \(TraditionalForm\`x = 1\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`x = \(-1\)\)]],
  ". The result is"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"p", "(", 
            RowBox[{
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[",",
                FontWeight->"Plain"], 
              StyleBox["t",
                FontWeight->"Plain"]}], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          
          RowBox[{\(\(\(\((\[Pi]\ a\^2)\)\^\(3/2\)\) P\)\/\((2  \[Pi])\)\^2\),
             "Re", 
            RowBox[{\(\[Integral]\_0\%\[Infinity]\), 
              RowBox[{\(k\^2\), \(\[DifferentialD]k\), " ", 
                StyleBox[
                  SuperscriptBox["\[ExponentialE]", 
                    RowBox[{\(-\[ImaginaryI]\), " ", "k", " ", "c", "  ", 
                      StyleBox["t",
                        FontWeight->"Plain"]}]],
                  
                  FontWeight->
                    "Plain"], \(\[ExponentialE]\^\(\(-a\^2\) k\^2/4\)\), " ", 
                
                FractionBox[
                  RowBox[{"2", 
                    StyleBox["sin",
                      FontWeight->"Plain"], 
                    StyleBox[" ",
                      FontWeight->"Plain"], 
                    StyleBox["k",
                      FontWeight->"Plain"], 
                    StyleBox[" ",
                      FontWeight->"Plain"], 
                    StyleBox["r",
                      FontWeight->"Plain"]}], \(k\ r\)]}]}]}]}], 
        TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  "The ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  "-integral can also be calculated analytically, yielding "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`p(r, 
          t) = \(P\/\(\(2\)  \(r\)\(\ \)\)\) \((\[ExponentialE]\^\(-\(\((r + \
c\ t)\)\^2\/a\^2\)\)\ \((r + 
                    c\ t)\)\  + \[ExponentialE]\^\(-\(\((r - c\ t)\)\^2\/a\^2\
\)\)\ \((r - c\ t)\))\)\)]],
  ". "
}], "NumberedEquation",
  CellTags->"(5.1.78)"],

Cell[TextData[{
  "This solution is displayed in Cell ",
  ButtonBox["5.9",
    ButtonData:>"Cell 5.9",
    ButtonStyle->"Hyperlink"],
  ", taking ",
  Cell[BoxData[
      \(TraditionalForm\`P = \(c = 1\), \ a = 0.02\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(p[r_, 
          t_]\  = \ \(P\/\(\(2\)  \(r\)\(\ \)\)\) \
\((\[ExponentialE]\^\(-\(\((r + c\ t)\)\^2\/a\^2\)\)\ \((r + 
                      c\ t)\)\  + \[ExponentialE]\^\(-\(\((r - c\ \
t)\)\^2\/a\^2\)\)\ \((r - c\ t)\))\) /. {P \[Rule] 1, a \[Rule] 0.02, 
            c \[Rule] 1};\)\), "\n", 
    \(\(Table[
        Plot[p[r, t], {r, 0,  .3}, 
          PlotRange \[Rule] {{0,  .3}, {\(- .5\), 1}}, 
          AxesLabel \[Rule] {"\<r\>", "\<p\>"}, 
          PlotLabel -> "\<t = \>" <> ToString[t]], {t, 
          0,  .3,  .01}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 5.9"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 3.33333 0.206011 0.412023 [
[.16667 .19351 -12 -9 ]
[.16667 .19351 12 0 ]
[.33333 .19351 -9 -9 ]
[.33333 .19351 9 0 ]
[.5 .19351 -12 -9 ]
[.5 .19351 12 0 ]
[.66667 .19351 -9 -9 ]
[.66667 .19351 9 0 ]
[.83333 .19351 -12 -9 ]
[.83333 .19351 12 0 ]
[1.025 .20601 0 -6 ]
[1.025 .20601 10 6 ]
[-0.0125 .0412 -24 -4.5 ]
[-0.0125 .0412 0 4.5 ]
[-0.0125 .12361 -24 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .28842 -18 -4.5 ]
[-0.0125 .28842 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .45322 -18 -4.5 ]
[-0.0125 .45322 0 4.5 ]
[-0.0125 .53563 -18 -4.5 ]
[-0.0125 .53563 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -17 0 ]
[.5 .63053 17 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 .20601 m
.16667 .21226 L
s
[(0.05)] .16667 .19351 0 1 Mshowa
.33333 .20601 m
.33333 .21226 L
s
[(0.1)] .33333 .19351 0 1 Mshowa
.5 .20601 m
.5 .21226 L
s
[(0.15)] .5 .19351 0 1 Mshowa
.66667 .20601 m
.66667 .21226 L
s
[(0.2)] .66667 .19351 0 1 Mshowa
.83333 .20601 m
.83333 .21226 L
s
[(0.25)] .83333 .19351 0 1 Mshowa
.125 Mabswid
.03333 .20601 m
.03333 .20976 L
s
.06667 .20601 m
.06667 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.13333 .20601 m
.13333 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.23333 .20601 m
.23333 .20976 L
s
.26667 .20601 m
.26667 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.36667 .20601 m
.36667 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.43333 .20601 m
.43333 .20976 L
s
.46667 .20601 m
.46667 .20976 L
s
.53333 .20601 m
.53333 .20976 L
s
.56667 .20601 m
.56667 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.63333 .20601 m
.63333 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.73333 .20601 m
.73333 .20976 L
s
.76667 .20601 m
.76667 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.86667 .20601 m
.86667 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.93333 .20601 m
.93333 .20976 L
s
.96667 .20601 m
.96667 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
gsave
1.025 .20601 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .0412 m
.00625 .0412 L
s
[(-0.4)] -0.0125 .0412 1 0 Mshowa
0 .12361 m
.00625 .12361 L
s
[(-0.2)] -0.0125 .12361 1 0 Mshowa
0 .28842 m
.00625 .28842 L
s
[(0.2)] -0.0125 .28842 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.4)] -0.0125 .37082 1 0 Mshowa
0 .45322 m
.00625 .45322 L
s
[(0.6)] -0.0125 .45322 1 0 Mshowa
0 .53563 m
.00625 .53563 L
s
[(0.8)] -0.0125 .53563 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .10301 m
.00375 .10301 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .30902 m
.00375 .30902 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .39142 m
.00375 .39142 L
s
0 .41202 m
.00375 .41202 L
s
0 .43262 m
.00375 .43262 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .51503 m
.00375 .51503 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
0 .0206 m
.00375 .0206 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -78 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .61803 m
.00123 .61789 L
.00236 .61752 L
.00365 .6168 L
.00488 .61583 L
.00706 .61344 L
.00942 .60988 L
.01203 .60483 L
.01479 .59824 L
.01975 .58342 L
.02966 .54407 L
.04057 .49053 L
.06188 .38009 L
.07364 .32765 L
.08481 .28769 L
.09537 .25924 L
.10135 .24686 L
.1069 .23751 L
.11668 .22527 L
.12215 .22036 L
.12711 .21688 L
.13223 .21407 L
.13764 .21182 L
.14225 .21035 L
.14732 .20913 L
.15278 .20817 L
.15578 .20776 L
.15863 .20744 L
.16127 .2072 L
.16415 .20697 L
.16918 .20667 L
.17163 .20656 L
.17427 .20646 L
.17905 .20631 L
.18182 .20625 L
.18473 .2062 L
.18994 .20613 L
.19258 .20611 L
.1954 .20609 L
.19784 .20607 L
.20048 .20606 L
.20358 .20605 L
.20652 .20604 L
.20937 .20603 L
.212 .20603 L
.21452 .20602 L
.21691 .20602 L
.21966 .20602 L
.22218 .20602 L
.22439 .20602 L
Mistroke
.22674 .20602 L
.22931 .20601 L
.2317 .20601 L
.23452 .20601 L
.23756 .20601 L
.24044 .20601 L
.24308 .20601 L
.24547 .20601 L
.24809 .20601 L
.25082 .20601 L
.25337 .20601 L
.25612 .20601 L
.25865 .20601 L
.26143 .20601 L
.26438 .20601 L
.26693 .20601 L
.26933 .20601 L
.27196 .20601 L
.27479 .20601 L
.27716 .20601 L
.27975 .20601 L
.28245 .20601 L
.28496 .20601 L
.28733 .20601 L
.28947 .20601 L
.29195 .20601 L
.29428 .20601 L
.2968 .20601 L
.29916 .20601 L
.30175 .20601 L
.3032 .20601 L
.30452 .20601 L
.30718 .20601 L
.30868 .20601 L
.31007 .20601 L
.31263 .20601 L
.31392 .20601 L
.31534 .20601 L
.31785 .20601 L
.32015 .20601 L
.32267 .20601 L
.32394 .20601 L
.32534 .20601 L
.32769 .20601 L
.32898 .20601 L
.3302 .20601 L
.33257 .20601 L
.33473 .20601 L
.33594 .20601 L
.33723 .20601 L
Mistroke
.33958 .20601 L
.34101 .20601 L
.34237 .20601 L
.34492 .20601 L
.34622 .20601 L
.3476 .20601 L
.35008 .20601 L
.3516 .20601 L
.35304 .20601 L
.35432 .20601 L
.35572 .20601 L
.35807 .20601 L
.35936 .20601 L
.36056 .20601 L
.36272 .20601 L
.36392 .20601 L
.36502 .20601 L
.3675 .20601 L
.3689 .20601 L
.37019 .20601 L
.37256 .20601 L
.37376 .20601 L
.37508 .20601 L
.37755 .20601 L
.37895 .20601 L
.38025 .20601 L
.38161 .20601 L
.38288 .20601 L
.38436 .20601 L
.38569 .20601 L
.38687 .20601 L
.38812 .20601 L
.39036 .20601 L
.3916 .20601 L
.39277 .20601 L
.39414 .20601 L
.39541 .20601 L
.39677 .20601 L
.39825 .20601 L
.39955 .20601 L
.40093 .20601 L
.4023 .20601 L
.40358 .20601 L
.40598 .20601 L
.40736 .20601 L
.40882 .20601 L
.41006 .20601 L
.41143 .20601 L
.4129 .20601 L
.41448 .20601 L
Mistroke
.41596 .20601 L
.41732 .20601 L
.41848 .20601 L
.41973 .20601 L
.4211 .20601 L
.42239 .20601 L
.42383 .20601 L
.4252 .20601 L
.42642 .20601 L
.42776 .20601 L
.42903 .20601 L
.43019 .20601 L
.43143 .20601 L
.43277 .20601 L
.43401 .20601 L
.43516 .20601 L
.43741 .20601 L
.43867 .20601 L
.44003 .20601 L
.4413 .20601 L
.44247 .20601 L
.44383 .20601 L
.44532 .20601 L
.44672 .20601 L
.44802 .20601 L
.44935 .20601 L
.4506 .20601 L
.45198 .20601 L
.45346 .20601 L
.45492 .20601 L
.45647 .20601 L
.45779 .20601 L
.45923 .20601 L
.46062 .20601 L
.46189 .20601 L
.46329 .20601 L
.46478 .20601 L
.46606 .20601 L
.46727 .20601 L
.46859 .20601 L
.47001 .20601 L
.47127 .20601 L
.47264 .20601 L
.47393 .20601 L
.47513 .20601 L
.47632 .20601 L
.4774 .20601 L
.47864 .20601 L
.47981 .20601 L
.48109 .20601 L
Mistroke
.48249 .20601 L
.48396 .20601 L
.48532 .20601 L
.4866 .20601 L
.48777 .20601 L
.48911 .20601 L
.49038 .20601 L
.49176 .20601 L
.49323 .20601 L
.49448 .20601 L
.49586 .20601 L
.49734 .20601 L
.49893 .20601 L
.50043 .20601 L
.50181 .20601 L
.50315 .20601 L
.50442 .20601 L
.50556 .20601 L
.5068 .20601 L
.50814 .20601 L
.50957 .20601 L
.51078 .20601 L
.51212 .20601 L
.51337 .20601 L
.51451 .20601 L
.51583 .20601 L
.51708 .20601 L
.51823 .20601 L
.51929 .20601 L
.52046 .20601 L
.52171 .20601 L
.52304 .20601 L
.52427 .20601 L
.52561 .20601 L
.52703 .20601 L
.52827 .20601 L
.52942 .20601 L
.53069 .20601 L
.53204 .20601 L
.53351 .20601 L
.53434 .20601 L
.53511 .20601 L
.53652 .20601 L
.53802 .20601 L
.53935 .20601 L
.5406 .20601 L
.54198 .20601 L
.54345 .20601 L
.54485 .20601 L
.54612 .20601 L
Mistroke
.54758 .20601 L
.54896 .20601 L
.55024 .20601 L
.55141 .20601 L
.5527 .20601 L
.55407 .20601 L
.55545 .20601 L
.55622 .20601 L
.55692 .20601 L
.55829 .20601 L
.55959 .20601 L
.56032 .20601 L
.5611 .20601 L
.56249 .20601 L
.56327 .20601 L
.564 .20601 L
.56485 .20601 L
.56565 .20601 L
.56688 .20601 L
.56823 .20601 L
.56955 .20601 L
.57095 .20601 L
.57226 .20601 L
.57349 .20601 L
.5746 .20601 L
.57581 .20601 L
.57712 .20601 L
.57787 .20601 L
.57857 .20601 L
.57998 .20601 L
.58078 .20601 L
.5815 .20601 L
.58279 .20601 L
.58347 .20601 L
.58419 .20601 L
.58552 .20601 L
.58675 .20601 L
.58806 .20601 L
.5888 .20601 L
.5895 .20601 L
.5909 .20601 L
.59168 .20601 L
.59239 .20601 L
.59367 .20601 L
.59506 .20601 L
.59637 .20601 L
.59758 .20601 L
.59825 .20601 L
.59897 .20601 L
.60028 .20601 L
Mistroke
.60108 .20601 L
.60183 .20601 L
.60326 .20601 L
.60398 .20601 L
.60475 .20601 L
.60614 .20601 L
.60698 .20601 L
.60778 .20601 L
.60856 .20601 L
.60928 .20601 L
.61051 .20601 L
.61186 .20601 L
.61317 .20601 L
.61391 .20601 L
.61458 .20601 L
.61578 .20601 L
.61708 .20601 L
.61832 .20601 L
.61946 .20601 L
.62076 .20601 L
.62199 .20601 L
.62334 .20601 L
.6241 .20601 L
.6248 .20601 L
.62612 .20601 L
.62686 .20601 L
.62756 .20601 L
.62897 .20601 L
.62976 .20601 L
.63047 .20601 L
.63172 .20601 L
.63289 .20601 L
.63418 .20601 L
.63556 .20601 L
.63625 .20601 L
.637 .20601 L
.63837 .20601 L
.6397 .20601 L
.64094 .20601 L
.6422 .20601 L
.64339 .20601 L
.64446 .20601 L
.64562 .20601 L
.64688 .20601 L
.64821 .20601 L
.64935 .20601 L
.6506 .20601 L
.6513 .20601 L
.65206 .20601 L
.65345 .20601 L
Mistroke
.6548 .20601 L
.65605 .20601 L
.6574 .20601 L
.65816 .20601 L
.65888 .20601 L
.66033 .20601 L
.66115 .20601 L
.66189 .20601 L
.66316 .20601 L
.66434 .20601 L
.66564 .20601 L
.66703 .20601 L
.66772 .20601 L
.66848 .20601 L
.66986 .20601 L
.67119 .20601 L
.67243 .20601 L
.67375 .20601 L
.675 .20601 L
.67612 .20601 L
.67734 .20601 L
.67867 .20601 L
.67941 .20601 L
.68008 .20601 L
.68139 .20601 L
.68262 .20601 L
.68378 .20601 L
.68501 .20601 L
.68606 .20601 L
.6872 .20601 L
.68844 .20601 L
.68976 .20601 L
.69101 .20601 L
.69215 .20601 L
.6935 .20601 L
.69418 .20601 L
.69493 .20601 L
.69625 .20601 L
.69749 .20601 L
.69824 .20601 L
.69895 .20601 L
.70029 .20601 L
.70103 .20601 L
.70172 .20601 L
.70248 .20601 L
.70329 .20601 L
.70467 .20601 L
.70597 .20601 L
.70723 .20601 L
.70839 .20601 L
Mistroke
.70965 .20601 L
.71104 .20601 L
.71173 .20601 L
.71248 .20601 L
.71383 .20601 L
.71511 .20601 L
.71584 .20601 L
.71652 .20601 L
.71789 .20601 L
.71867 .20601 L
.71938 .20601 L
.72057 .20601 L
.72188 .20601 L
.72324 .20601 L
.72451 .20601 L
.72524 .20601 L
.72602 .20601 L
.72677 .20601 L
.72745 .20601 L
.72875 .20601 L
.73013 .20601 L
.73084 .20601 L
.7316 .20601 L
.73298 .20601 L
.73383 .20601 L
.73463 .20601 L
.73534 .20601 L
.73613 .20601 L
.73682 .20601 L
.73756 .20601 L
.73891 .20601 L
.74023 .20601 L
.74144 .20601 L
.74275 .20601 L
.74349 .20601 L
.74419 .20601 L
.74491 .20601 L
.74559 .20601 L
.74637 .20601 L
.74709 .20601 L
.74832 .20601 L
.74962 .20601 L
.75073 .20601 L
.75196 .20601 L
.75328 .20601 L
.75402 .20601 L
.75469 .20601 L
.75594 .20601 L
.75725 .20601 L
.75856 .20601 L
Mistroke
.75929 .20601 L
.75996 .20601 L
.76121 .20601 L
.76252 .20601 L
.7637 .20601 L
.7648 .20601 L
.76601 .20601 L
.7673 .20601 L
.76868 .20601 L
.76946 .20601 L
.77018 .20601 L
.7715 .20601 L
.77217 .20601 L
.77291 .20601 L
.77417 .20601 L
.77554 .20601 L
.77683 .20601 L
.77802 .20601 L
.77914 .20601 L
.78034 .20601 L
.78148 .20601 L
.78251 .20601 L
.78372 .20601 L
.78503 .20601 L
.78627 .20601 L
.78742 .20601 L
.7886 .20601 L
.7897 .20601 L
.79092 .20601 L
.79222 .20601 L
.79359 .20601 L
.79488 .20601 L
.79605 .20601 L
.79732 .20601 L
.798 .20601 L
.79872 .20601 L
.8 .20601 L
.80138 .20601 L
.80217 .20601 L
.8029 .20601 L
.80423 .20601 L
.80544 .20601 L
.80611 .20601 L
.80684 .20601 L
.80816 .20601 L
.80934 .20601 L
.81064 .20601 L
.81199 .20601 L
.81326 .20601 L
.81445 .20601 L
Mistroke
.81554 .20601 L
.81673 .20601 L
.81799 .20601 L
.81937 .20601 L
.82062 .20601 L
.82132 .20601 L
.82207 .20601 L
.82344 .20601 L
.82472 .20601 L
.82608 .20601 L
.82723 .20601 L
.82851 .20601 L
.82928 .20601 L
.83001 .20601 L
.83137 .20601 L
.83214 .20601 L
.83285 .20601 L
.83362 .20601 L
.83445 .20601 L
.83517 .20601 L
.83596 .20601 L
.83669 .20601 L
.83737 .20601 L
.83866 .20601 L
.84001 .20601 L
.8413 .20601 L
.84203 .20601 L
.8427 .20601 L
.84393 .20601 L
.84524 .20601 L
.84641 .20601 L
.8475 .20601 L
.8487 .20601 L
.85 .20601 L
.85136 .20601 L
.85214 .20601 L
.85286 .20601 L
.85417 .20601 L
.85491 .20601 L
.85558 .20601 L
.85684 .20601 L
.85821 .20601 L
.8595 .20601 L
.86068 .20601 L
.8618 .20601 L
.86299 .20601 L
.86412 .20601 L
.86515 .20601 L
.86635 .20601 L
.86767 .20601 L
Mistroke
.86891 .20601 L
.87005 .20601 L
.87123 .20601 L
.87233 .20601 L
.87354 .20601 L
.87485 .20601 L
.87615 .20601 L
.87751 .20601 L
.87868 .20601 L
.87995 .20601 L
.88134 .20601 L
.88261 .20601 L
.88328 .20601 L
.88401 .20601 L
.88478 .20601 L
.8855 .20601 L
.88681 .20601 L
.88802 .20601 L
.88868 .20601 L
.88941 .20601 L
.89073 .20601 L
.89202 .20601 L
.89319 .20601 L
.89454 .20601 L
.89582 .20601 L
.897 .20601 L
.89808 .20601 L
.89927 .20601 L
.90053 .20601 L
.9019 .20601 L
.90315 .20601 L
.90384 .20601 L
.90459 .20601 L
.90596 .20601 L
.90723 .20601 L
.90859 .20601 L
.90974 .20601 L
.91102 .20601 L
.91175 .20601 L
.91251 .20601 L
.91388 .20601 L
.91464 .20601 L
.91535 .20601 L
.91613 .20601 L
.91696 .20601 L
.91768 .20601 L
.91846 .20601 L
.91919 .20601 L
.91987 .20601 L
.92116 .20601 L
Mistroke
.92252 .20601 L
.9238 .20601 L
.92519 .20601 L
.9265 .20601 L
.92771 .20601 L
.9288 .20601 L
.93001 .20601 L
.93127 .20601 L
.93245 .20601 L
.93375 .20601 L
.93512 .20601 L
.93629 .20601 L
.93757 .20601 L
.93896 .20601 L
.93973 .20601 L
.94044 .20601 L
.94181 .20601 L
.9431 .20601 L
.94421 .20601 L
.94543 .20601 L
.94671 .20601 L
.9479 .20601 L
.94902 .20601 L
.95003 .20601 L
.95121 .20601 L
.95233 .20601 L
.95353 .20601 L
.95481 .20601 L
.95602 .20601 L
.95712 .20601 L
.95841 .20601 L
.95914 .20601 L
.95981 .20601 L
.96104 .20601 L
.96234 .20601 L
.96355 .20601 L
.96487 .20601 L
.96611 .20601 L
.96726 .20601 L
.96829 .20601 L
.96943 .20601 L
.97062 .20601 L
.97174 .20601 L
.97297 .20601 L
.97427 .20601 L
.97538 .20601 L
.97659 .20601 L
.9779 .20601 L
.97863 .20601 L
.9793 .20601 L
Mistroke
.9806 .20601 L
.98182 .20601 L
.98287 .20601 L
.98402 .20601 L
.98523 .20601 L
.98636 .20601 L
.98741 .20601 L
.98838 .20601 L
.98949 .20601 L
.99054 .20601 L
.99168 .20601 L
.99289 .20601 L
.99403 .20601 L
.99507 .20601 L
.99629 .20601 L
.99761 .20601 L
.99886 .20601 L
1 .20601 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13039,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo00?ooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooo
oom5ooooo`001Ol00002ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Gooooo00?o
0000ooooooooool0oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo00Co
A4A4omgMgOoooooo00001_ooool3o`000?ooooooAOooool000Oooooo00Go0000oooooooooooooooo
o`00000;ooooo`04omgMgOmEEEGoooooo`0000Kooooo00?o0000ooooooooool0oooooom5ooooo`00
1oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001_ooool00ol0003o
ooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^ko
A4A4o`000006ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Gooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool5o`0000Gooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool00ol0003oooooooooo`3oooooodGooooo0005o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0oooooom5ooooo`001ooo
ool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01Oooool3o`000?oooooo
AOooool000Oooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Cooooo
00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Gooooo00?o0000oooooooo
ool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c005ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo027ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@0Iooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l00000
0ol@413oooooooooo`0Gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l0
00001Ol@413oooooooooooooooooA4A400;o000000?o<S8bomgMgOooool06?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM03Wooooo000Qoooo
o`;o00008_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01oooool00omgMgOo<S8booooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B47ooooo`03o`000?oooooooooo00Kooooo00?oMgMgoc8b<_ooool06?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@06_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1oooool00omgMgOo<S8booooo`0hooooo`008Oooool00ol0003oooooooooo`0Qooooo`05oa0@4?oo
ooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000oooooooo
ool05oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool06Oooool01Ol@
413ooooooooooooooooo410@00kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0G
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Kooooo`05oa0@4?oo
ooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo03Oooooo
000Qooooo`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`00
0?ooooooooooooooool000001oooool00omgMgOo<S8booooo`0Hooooo`05o`000?oooooooooooooo
ool000003_ooool00ol0003oooooooooo`0Iooooo`05o`000?ooooooooooooooool000003_ooool0
0ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo01Sooooo00Go0000ooooooooooooooooo`00
000=ooooo`03oiRHV?lQ8B7ok^k^01[ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool0>?ooool0027ooooo00?o0000ooooooooool08Ooo
ool01Ol0003ooooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000004ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`06Oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000
ooooooooool06Oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<01Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo01Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00iooooo`008Oooool00ol0003oooooooooo`0Qoooo
o`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00Cooooo00?o
0000ooooooooool06oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool0
6Oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Kooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`0Hoooo
o`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo03_ooooo000Qooooo`03o`000?oooooooooo027ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00ol0003oooooooooo`0Kooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`0Iooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01_ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41006_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo03_ooooo
000Qooooo`;o00008_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP04ooooo`Co00006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIV
I_l000006oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l000001Oooool4
o`0001[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
6_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004oooo
o`Co0000>_ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo>_ooool00ol@413o0000o`00
0003o`0000Gooooo000Qooooo`03o`000?oooooooooo0?oooooo??ooool00ol0003oooooooooo`06
ooooo`008Oooool00ol0003oooooooooo`3ooooooccooooo00?o0000ooooooooool01_ooool0027o
ooooool0000co`0000cooooo00?o0000ooooooooool01_ooool0027ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooo`000006o`000003ooooool0003ooooo00Sooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Cooooo00?o0000oc8b<_oMgMd0
1_ooool0027ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo033ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0`ooooo`03o`000?oo
oooooooo033ooooo00?o0000ooooooooool0>oooool2o`000004ojVYZOlQ8B7o0000ob4Q8@Cooooo
000Qooooo`03o`000?oooooooooo02Cooooo0ol0003ooooooakooooo000Qooooo`03o`000?oooooo
oooo02?ooooo00?o0000ooooooooool0oooooolOooooo`008Oooool00ol0003oooooooooo`0Roooo
o`03o`000?oooooooooo0?oooooo8?ooool0027ooooo0_l0000Rooooo`03o`000?oooooooooo0?oo
oooo8Oooool0027ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`3oooooob7ooooo
000Qooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0oooooolRooooo`008Oooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo0?oooooo8oooool0027ooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`3oooooobCooooo000Qooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool0oooooolTooooo`008Oooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo0?oooooo9Oooool0027ooooo0_l0000Mooooo`03o`000?oooooooooo0?oooooo9_oo
ool0027ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`3oooooobKooooo000Qoooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0oooooolWooooo`008Oooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo0?oooooo:?ooool0027ooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`3oooooobSooooo000Qooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool0oooooolYooooo`008Oooool2o`0001[ooooo00?o0000ooooooooool0oooooolY
ooooo`008Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo0?oooooo:Oooool0027o
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`3oooooob[ooooo000Qooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool0oooooolZooooo`001oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001Oooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo0?oooooo:_ooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`3oooooob_ooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP06ooooo`?o00005oooool00ol0003oooooooooo`3oooooob_ooooo0007ooooo`05o`00
0?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP05ooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool0ooooool[ooooo`001oooool01Ol0003ooooooooooooooooo000000ko
oooo00?oMgMgofIVI_ooool01?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo0?oo
oooo:oooool000Oooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`3oooooobcooooo0007ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Gooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`3oooooobcooooo0007ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Gooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`3oooooobcooooo000Qooooo`;o00005oooool00ol0003oooooooooo`3ooooo
obcooooo000Qooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0ooooool]ooooo`00
8Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0?oooooo;Oooool0027ooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`3oooooobgooooo000Qooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool0ooooool]ooooo`008Oooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo0?oooooo;_ooool0027ooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`3oooooobkooooo000Qooooo`;o00005Oooool00ol0003oooooooooo`3oooooobkooooo
000Qooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0ooooool^ooooo`008Oooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo0?oooooo;oooool0027ooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`3ooooooboooooo000Qooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool0ooooool_ooooo`008Oooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo0?oooooo;oooool0027ooooo0_l0000Cooooo`03o`000?oooooooooo0?oooooo<?oo
ool0027ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`3ooooooc3ooooo000Qoooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0ooooool`ooooo`008Oooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo0?oooooo<?ooool000Oooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00?ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`3ooooooc7ooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo0?oooooo<Oooool000Oooooo00Go410@oooooooooooooooooa0@400;ooooo`Go
00001Oooool3o`00017ooooo00?o0000ooooooooool0oooooolaooooo`001oooool01Ol0003ooooo
oooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00001_ooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo0?oooooo<Oooool000Oooooo00Go0000ooooooooooooooooo`00000;oooo
o`04omgMgOmEEEGoooooo`0000Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`3o
oooooc;ooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000006
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0oooooolbooooo`001oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001_ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo0?oooooo<_ooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=
ooooo`03ogMgMol0003ooooo00Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`3o
oooooc;ooooo000Qooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0oooooolboooo
o`008Oooool2o`00013ooooo00?o0000ooooooooool0oooooolcooooo`008Oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo0?oooooo<oooool0027ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`3ooooooc?ooooo000Qooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool0oooooolcooooo`008Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
0?oooooo<oooool0027ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`3oooooocCo
oooo000Qooooo`;o00003oooool00ol0003oooooooooo`3oooooocCooooo000Qooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool0ooooooldooooo`008Oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo0?oooooo=?ooool0027ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`3oooooocCooooo000Qooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool0ooooooldooooo`008Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo0?oooooo
=Oooool0027ooooo0_l0000>ooooo`03o`000?oooooooooo0?oooooo=Oooool0027ooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`3oooooocGooooo000Qooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool0ooooooleooooo`008Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo0?oooooo=Oooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`3oooooocGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@05ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool0oooooolfooooo`001oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`000005ooooo`?o00003?ooool00ol0003oooooooooo`3oooooocKooooo0007
ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Gooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`3oooooocKooooo0007ooooo`05o`000?oo
ooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Gooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`3oooooocKooooo0007ooooo`05oa0@4?ooooooooooooooool@
41002oooool00omEEEGoQhN7ooooo`07ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool0oooooolfooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nH
V9P01oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0?oooooo=oooool000Oooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Gooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`3oooooocOooooo000Qooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool0oooooolgooooo`008Oooool2o`0000cooooo00?o0000ooooooooool0
oooooolgooooo`008Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0?oooooo=ooo
ool0027ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`3oooooocOooooo000Qoooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0oooooolhooooo`008Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo0?oooooo>?ooool0027ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`3oooooocSooooo000Qooooo`;o00002oooool00ol0003ooooooooo
o`3oooooocSooooo000Qooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0oooooolh
ooooo`008Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0?oooooo>Oooool0027o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`3oooooocWooooo000Qooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool0ooooooliooooo`008Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo0?oooooo>Oooool0027ooooo0_l00009ooooo`03o`000?oooooo
oooo0?oooooo>_ooool0027ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`3ooooo
oc[ooooo000Qooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0ooooooljooooo`00
8Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0?oooooo>_ooool000Oooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Go
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3ooooooc_ooooo0007ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@05oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooolkooooo`001oooool01Ol@413o
oooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0oooooolkooooo`001oooool01Ol0003ooooooooooooooooo
000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P05ooooo`?o00001oooool00ol0003ooooooooo
o`3ooooooc_ooooo0007ooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`00
0?l0003oc<c<00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3ooooooccooooo
0007ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Go
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3ooooooccooooo0007ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`3ooooooccooooo0007ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`3ooooooccooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0oooooolmooooo`008Oooool2o`0000Kooooo00?o0000ooooooooool0oooooolmooooo`00
8Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo?Oooool0027ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`3oooooocgooooo000Qooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0oooooolnooooo`008Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo0?oooooo?_ooool0027ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3oooooockooooo000Qooooo`;o00001Oooool00ol0003oooooooooo`3oooooockooooo
000Qooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0ooooooloooooo`008Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo?oooool0027ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`3oooooocoooooo000Qooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0ooooooloooooo`008Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo0?oooooo@?ooool0027ooooo0_l00003ooooo`03o`000?oooooooooo0?oooooo@?oo
ool0027ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3ooooood3ooooo000Qoooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0oooooom0ooooo`008Oooool01Ol0003o
oooooooooooooooo00000?oooooo@oooool001Sooooo1?l000000ol@413oooooooooo`02ooooo`04
o`000?ooooooooooo`000?ooooooA?ooool001[ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooo`00003oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo0ol0003oooooodGooooo
000Jooooo`03o`000?oooooooooo00Cooooo0ol0003oooooodGooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Hooooo`03oeEEEOmVIVKo00000?ooooooC_ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00:Wooooo00GoV9RHo`000?l0003oA4A4okZj^P0Hoooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h0WOooool001oooooo00Co410@o`000?l0003o0000Q_ooool0
1Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l00009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
WOooool0023ooooo00?o0000ooooooooool0Q_ooool00ol0003oooooooooo`0Jooooo`05oa0@4?oo
ooooooooooooool@4100WOooool0023ooooo00?o0000ooooooooool0Q_ooool00ol0003ooooooooo
o`0;ooooo`Ko00002Oooool01Ol0003ooooooooooooooooo000009gooooo000Pooooo`06o`000?mg
MgOo0000o`000?mEEEGok^k^Poooool00ol0003oooooooooo`0Jooooo`05o`000?oooooooooooooo
ool00000WOooool0023ooooo00Ko0000oeEEEOo^k^koooooogMgMomEEEF1ooooo`03oa0@4?l0003o
000000?o00006Oooool01Ol@413ooooooooooooooooo410@09gooooo000Pooooo`03o`000?o^k^ko
oooo00;ooooo00?o0000ooooooooool0POooool00ol0003oooooooooo`0Jooooo`05ogMgMonHV9So
oooooiRHV?mgMgL0WOooool0023ooooo00?o0000onk^k_ooool00_ooool00ol0003oooooooooo`21
ooooo`03o`000?oooooooooo01[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP2Mooooo`008?ooool0
1_l0003oEEEEonk^k_ooooooMgMgofIVI_oooooo@oooool001oooooo00?o410@o`000?mgMgL00_l0
00000omVIVKok^k^ooooo`3ooooood;ooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.0332543, -0.540631, \
0.00122928, 0.00994506}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 3.33333 0.206011 0.412023 [
[.16667 .19351 -12 -9 ]
[.16667 .19351 12 0 ]
[.33333 .19351 -9 -9 ]
[.33333 .19351 9 0 ]
[.5 .19351 -12 -9 ]
[.5 .19351 12 0 ]
[.66667 .19351 -9 -9 ]
[.66667 .19351 9 0 ]
[.83333 .19351 -12 -9 ]
[.83333 .19351 12 0 ]
[1.025 .20601 0 -6 ]
[1.025 .20601 10 6 ]
[-0.0125 .0412 -24 -4.5 ]
[-0.0125 .0412 0 4.5 ]
[-0.0125 .12361 -24 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .28842 -18 -4.5 ]
[-0.0125 .28842 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .45322 -18 -4.5 ]
[-0.0125 .45322 0 4.5 ]
[-0.0125 .53563 -18 -4.5 ]
[-0.0125 .53563 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 .20601 m
.16667 .21226 L
s
[(0.05)] .16667 .19351 0 1 Mshowa
.33333 .20601 m
.33333 .21226 L
s
[(0.1)] .33333 .19351 0 1 Mshowa
.5 .20601 m
.5 .21226 L
s
[(0.15)] .5 .19351 0 1 Mshowa
.66667 .20601 m
.66667 .21226 L
s
[(0.2)] .66667 .19351 0 1 Mshowa
.83333 .20601 m
.83333 .21226 L
s
[(0.25)] .83333 .19351 0 1 Mshowa
.125 Mabswid
.03333 .20601 m
.03333 .20976 L
s
.06667 .20601 m
.06667 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.13333 .20601 m
.13333 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.23333 .20601 m
.23333 .20976 L
s
.26667 .20601 m
.26667 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.36667 .20601 m
.36667 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.43333 .20601 m
.43333 .20976 L
s
.46667 .20601 m
.46667 .20976 L
s
.53333 .20601 m
.53333 .20976 L
s
.56667 .20601 m
.56667 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.63333 .20601 m
.63333 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.73333 .20601 m
.73333 .20976 L
s
.76667 .20601 m
.76667 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.86667 .20601 m
.86667 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.93333 .20601 m
.93333 .20976 L
s
.96667 .20601 m
.96667 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
gsave
1.025 .20601 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .0412 m
.00625 .0412 L
s
[(-0.4)] -0.0125 .0412 1 0 Mshowa
0 .12361 m
.00625 .12361 L
s
[(-0.2)] -0.0125 .12361 1 0 Mshowa
0 .28842 m
.00625 .28842 L
s
[(0.2)] -0.0125 .28842 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.4)] -0.0125 .37082 1 0 Mshowa
0 .45322 m
.00625 .45322 L
s
[(0.6)] -0.0125 .45322 1 0 Mshowa
0 .53563 m
.00625 .53563 L
s
[(0.8)] -0.0125 .53563 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .10301 m
.00375 .10301 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .30902 m
.00375 .30902 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .39142 m
.00375 .39142 L
s
0 .41202 m
.00375 .41202 L
s
0 .43262 m
.00375 .43262 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .51503 m
.00375 .51503 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
0 .0206 m
.00375 .0206 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.01) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .36645 m
.00123 .36644 L
.00236 .36642 L
.00365 .36637 L
.00488 .36631 L
.00706 .36615 L
.00942 .3659 L
.01203 .36554 L
.01479 .36504 L
.01975 .36381 L
.02486 .36201 L
.02966 .35975 L
.03491 .35654 L
.04057 .35214 L
.05241 .33956 L
.06367 .32359 L
.08481 .28731 L
.10584 .25272 L
.115 .24051 L
.12491 .22983 L
.13555 .22123 L
.14557 .21553 L
.15115 .2132 L
.15704 .21127 L
.16207 .20999 L
.16759 .2089 L
.17309 .20808 L
.1783 .2075 L
.18298 .20711 L
.18807 .20679 L
.19361 .20654 L
.1964 .20644 L
.19948 .20636 L
.2021 .2063 L
.20492 .20624 L
.21003 .20617 L
.21255 .20614 L
.21524 .20611 L
.22008 .20608 L
.22305 .20606 L
.22584 .20605 L
.23108 .20604 L
.23376 .20603 L
.23661 .20603 L
.23907 .20602 L
.24171 .20602 L
.24454 .20602 L
.2472 .20602 L
.25035 .20602 L
.25323 .20601 L
Mistroke
.25587 .20601 L
.25825 .20601 L
.26101 .20601 L
.2636 .20601 L
.26584 .20601 L
.26822 .20601 L
.27082 .20601 L
.27321 .20601 L
.2758 .20601 L
.27858 .20601 L
.2812 .20601 L
.28359 .20601 L
.2864 .20601 L
.28944 .20601 L
.29232 .20601 L
.29498 .20601 L
.29753 .20601 L
.29986 .20601 L
.30242 .20601 L
.30512 .20601 L
.30747 .20601 L
.30966 .20601 L
.31206 .20601 L
.31462 .20601 L
.31742 .20601 L
.319 .20601 L
.32046 .20601 L
.32314 .20601 L
.32597 .20601 L
.3285 .20601 L
.33087 .20601 L
.33347 .20601 L
.33493 .20601 L
.33626 .20601 L
.33866 .20601 L
.3413 .20601 L
.34263 .20601 L
.34406 .20601 L
.34666 .20601 L
.3491 .20601 L
.35167 .20601 L
.35387 .20601 L
.35628 .20601 L
.35775 .20601 L
.35914 .20601 L
.36173 .20601 L
.36319 .20601 L
.36453 .20601 L
.3661 .20601 L
.36756 .20601 L
Mistroke
.36999 .20601 L
.37128 .20601 L
.37266 .20601 L
.37411 .20601 L
.37549 .20601 L
.37807 .20601 L
.37938 .20601 L
.38079 .20601 L
.38204 .20601 L
.38335 .20601 L
.38454 .20601 L
.38585 .20601 L
.38814 .20601 L
.38955 .20601 L
.39083 .20601 L
.3922 .20601 L
.3937 .20601 L
.39508 .20601 L
.39636 .20601 L
.39757 .20601 L
.39888 .20601 L
.40008 .20601 L
.40118 .20601 L
.40333 .20601 L
.40448 .20601 L
.40573 .20601 L
.40705 .20601 L
.40825 .20601 L
.41074 .20601 L
.41211 .20601 L
.4134 .20601 L
.4157 .20601 L
.417 .20601 L
.41819 .20601 L
.41951 .20601 L
.42076 .20601 L
.42311 .20601 L
.42442 .20601 L
.42563 .20601 L
.42705 .20601 L
.42838 .20601 L
.42955 .20601 L
.4308 .20601 L
.433 .20601 L
.43424 .20601 L
.43556 .20601 L
.43791 .20601 L
.43926 .20601 L
.4405 .20601 L
.44192 .20601 L
Mistroke
.44326 .20601 L
.44566 .20601 L
.44701 .20601 L
.44825 .20601 L
.44951 .20601 L
.45087 .20601 L
.45236 .20601 L
.45375 .20601 L
.45531 .20601 L
.4568 .20601 L
.45813 .20601 L
.45959 .20601 L
.46098 .20601 L
.46226 .20601 L
.46367 .20601 L
.46516 .20601 L
.46646 .20601 L
.46766 .20601 L
.46899 .20601 L
.47041 .20601 L
.47168 .20601 L
.47305 .20601 L
.47435 .20601 L
.47555 .20601 L
.47782 .20601 L
.47897 .20601 L
.48023 .20601 L
.48162 .20601 L
.48308 .20601 L
.48433 .20601 L
.4857 .20601 L
.48717 .20601 L
.48875 .20601 L
.49024 .20601 L
.49159 .20601 L
.49296 .20601 L
.49422 .20601 L
.4956 .20601 L
.49707 .20601 L
.49835 .20601 L
.49954 .20601 L
.50085 .20601 L
.50225 .20601 L
.50365 .20601 L
.50492 .20601 L
.50639 .20601 L
.50777 .20601 L
.50905 .20601 L
.51022 .20601 L
.51152 .20601 L
Mistroke
.51288 .20601 L
.51426 .20601 L
.51574 .20601 L
.51714 .20601 L
.51841 .20601 L
.5199 .20601 L
.52153 .20601 L
.52306 .20601 L
.52447 .20601 L
.52568 .20601 L
.52699 .20601 L
.52822 .20601 L
.52934 .20601 L
.53059 .20601 L
.53196 .20601 L
.53339 .20601 L
.53471 .20601 L
.53613 .20601 L
.53747 .20601 L
.53867 .20601 L
.53997 .20601 L
.54139 .20601 L
.54289 .20601 L
.54417 .20601 L
.54558 .20601 L
.54694 .20601 L
.54821 .20601 L
.54959 .20601 L
.55107 .20601 L
.55234 .20601 L
.55354 .20601 L
.55485 .20601 L
.55627 .20601 L
.55745 .20601 L
.55875 .20601 L
.5601 .20601 L
.56136 .20601 L
.56254 .20601 L
.56362 .20601 L
.56486 .20601 L
.56603 .20601 L
.56729 .20601 L
.56869 .20601 L
.57014 .20601 L
.5715 .20601 L
.57277 .20601 L
.57394 .20601 L
.57528 .20601 L
.57655 .20601 L
.57793 .20601 L
Mistroke
.57939 .20601 L
.58077 .20601 L
.58202 .20601 L
.58349 .20601 L
.58432 .20601 L
.58509 .20601 L
.58649 .20601 L
.5872 .20601 L
.58798 .20601 L
.58935 .20601 L
.59061 .20601 L
.592 .20601 L
.59271 .20601 L
.59348 .20601 L
.59478 .20601 L
.59617 .20601 L
.59749 .20601 L
.5987 .20601 L
.59987 .20601 L
.60097 .20601 L
.60217 .20601 L
.60346 .20601 L
.60481 .20601 L
.60608 .20601 L
.60723 .20601 L
.60847 .20601 L
.60983 .20601 L
.61111 .20601 L
.61251 .20601 L
.6133 .20601 L
.61402 .20601 L
.61546 .20601 L
.61628 .20601 L
.61703 .20601 L
.61842 .20601 L
.61919 .20601 L
.6199 .20601 L
.62126 .20601 L
.62251 .20601 L
.62388 .20601 L
.62457 .20601 L
.62532 .20601 L
.6266 .20601 L
.62797 .20601 L
.62926 .20601 L
.63043 .20601 L
.63167 .20601 L
.63284 .20601 L
.63412 .20601 L
.6355 .20601 L
Mistroke
.63618 .20601 L
.63693 .20601 L
.6383 .20601 L
.63963 .20601 L
.64087 .20601 L
.64213 .20601 L
.64332 .20601 L
.64438 .20601 L
.64554 .20601 L
.6468 .20601 L
.64813 .20601 L
.64927 .20601 L
.65052 .20601 L
.65122 .20601 L
.65198 .20601 L
.65336 .20601 L
.65471 .20601 L
.65596 .20601 L
.6573 .20601 L
.65807 .20601 L
.65879 .20601 L
.66023 .20601 L
.66105 .20601 L
.66179 .20601 L
.66306 .20601 L
.66424 .20601 L
.66554 .20601 L
.66693 .20601 L
.66762 .20601 L
.66838 .20601 L
.66976 .20601 L
.6711 .20601 L
.67233 .20601 L
.67364 .20601 L
.67489 .20601 L
.67601 .20601 L
.67723 .20601 L
.67855 .20601 L
.67929 .20601 L
.67996 .20601 L
.68127 .20601 L
.6825 .20601 L
.68366 .20601 L
.68488 .20601 L
.68592 .20601 L
.68707 .20601 L
.6883 .20601 L
.68963 .20601 L
.69088 .20601 L
.69201 .20601 L
Mistroke
.69336 .20601 L
.69404 .20601 L
.69478 .20601 L
.69611 .20601 L
.69735 .20601 L
.69806 .20601 L
.6988 .20601 L
.70014 .20601 L
.70088 .20601 L
.70157 .20601 L
.70233 .20601 L
.70314 .20601 L
.70452 .20601 L
.70581 .20601 L
.70708 .20601 L
.70824 .20601 L
.7095 .20601 L
.71088 .20601 L
.71158 .20601 L
.71233 .20601 L
.71368 .20601 L
.7144 .20601 L
.71508 .20601 L
.71636 .20601 L
.71773 .20601 L
.7185 .20601 L
.71921 .20601 L
.7204 .20601 L
.7217 .20601 L
.72306 .20601 L
.72433 .20601 L
.72505 .20601 L
.72584 .20601 L
.72653 .20601 L
.72727 .20601 L
.72865 .20601 L
.72994 .20601 L
.73065 .20601 L
.73141 .20601 L
.73279 .20601 L
.73363 .20601 L
.73443 .20601 L
.73515 .20601 L
.73593 .20601 L
.73662 .20601 L
.73736 .20601 L
.73871 .20601 L
.74003 .20601 L
.74123 .20601 L
.74254 .20601 L
Mistroke
.74329 .20601 L
.74398 .20601 L
.7447 .20601 L
.74538 .20601 L
.74617 .20601 L
.74688 .20601 L
.74811 .20601 L
.74941 .20601 L
.75052 .20601 L
.75175 .20601 L
.75307 .20601 L
.7538 .20601 L
.75448 .20601 L
.75573 .20601 L
.75705 .20601 L
.75834 .20601 L
.75907 .20601 L
.75975 .20601 L
.76099 .20601 L
.7623 .20601 L
.76347 .20601 L
.76457 .20601 L
.76577 .20601 L
.76707 .20601 L
.76844 .20601 L
.76922 .20601 L
.76994 .20601 L
.77126 .20601 L
.77199 .20601 L
.77266 .20601 L
.77393 .20601 L
.77529 .20601 L
.77659 .20601 L
.77777 .20601 L
.77889 .20601 L
.78009 .20601 L
.78122 .20601 L
.78225 .20601 L
.78346 .20601 L
.78477 .20601 L
.78601 .20601 L
.78716 .20601 L
.78833 .20601 L
.78944 .20601 L
.79065 .20601 L
.79196 .20601 L
.79326 .20601 L
.79462 .20601 L
.79578 .20601 L
.79706 .20601 L
Mistroke
.79773 .20601 L
.79845 .20601 L
.79973 .20601 L
.80111 .20601 L
.80189 .20601 L
.80262 .20601 L
.80395 .20601 L
.80515 .20601 L
.80582 .20601 L
.80655 .20601 L
.80787 .20601 L
.80904 .20601 L
.81034 .20601 L
.81169 .20601 L
.81297 .20601 L
.81415 .20601 L
.81524 .20601 L
.81643 .20601 L
.81768 .20601 L
.81906 .20601 L
.82031 .20601 L
.82101 .20601 L
.82176 .20601 L
.82312 .20601 L
.8244 .20601 L
.82576 .20601 L
.82692 .20601 L
.82819 .20601 L
.82896 .20601 L
.82969 .20601 L
.83105 .20601 L
.83182 .20601 L
.83253 .20601 L
.8333 .20601 L
.83413 .20601 L
.83485 .20601 L
.83564 .20601 L
.83637 .20601 L
.83705 .20601 L
.83834 .20601 L
.8397 .20601 L
.84098 .20601 L
.8417 .20601 L
.84237 .20601 L
.8436 .20601 L
.84491 .20601 L
.84607 .20601 L
.84716 .20601 L
.84836 .20601 L
.84965 .20601 L
Mistroke
.85095 .20601 L
.85169 .20601 L
.85237 .20601 L
.85375 .20601 L
.85452 .20601 L
.85522 .20601 L
.85648 .20601 L
.85785 .20601 L
.85914 .20601 L
.86033 .20601 L
.86144 .20601 L
.86263 .20601 L
.86375 .20601 L
.86478 .20601 L
.86599 .20601 L
.8673 .20601 L
.86853 .20601 L
.86968 .20601 L
.87098 .20601 L
.8722 .20601 L
.87329 .20601 L
.87448 .20601 L
.87577 .20601 L
.87714 .20601 L
.8783 .20601 L
.87958 .20601 L
.88096 .20601 L
.88223 .20601 L
.88289 .20601 L
.88363 .20601 L
.88439 .20601 L
.88511 .20601 L
.88642 .20601 L
.88762 .20601 L
.88901 .20601 L
.89033 .20601 L
.89151 .20601 L
.89276 .20601 L
.89394 .20601 L
.89501 .20601 L
.89627 .20601 L
.89764 .20601 L
.89893 .20601 L
.90012 .20601 L
.90139 .20601 L
.90275 .20601 L
.90404 .20601 L
.90521 .20601 L
.90659 .20601 L
.90736 .20601 L
Mistroke
.90808 .20601 L
.9094 .20601 L
.91007 .20601 L
.9108 .20601 L
.91152 .20601 L
.91227 .20601 L
.91361 .20601 L
.91435 .20601 L
.91505 .20601 L
.91581 .20601 L
.91663 .20601 L
.91734 .20601 L
.9181 .20601 L
.91883 .20601 L
.91949 .20601 L
.92076 .20601 L
.9221 .20601 L
.92337 .20601 L
.92475 .20601 L
.92606 .20601 L
.92727 .20601 L
.92847 .20601 L
.92956 .20601 L
.93082 .20601 L
.932 .20601 L
.93329 .20601 L
.93466 .20601 L
.93583 .20601 L
.93711 .20601 L
.93849 .20601 L
.93927 .20601 L
.93997 .20601 L
.94134 .20601 L
.94264 .20601 L
.94374 .20601 L
.94496 .20601 L
.94623 .20601 L
.94742 .20601 L
.94854 .20601 L
.94955 .20601 L
.95067 .20601 L
.95185 .20601 L
.95305 .20601 L
.95433 .20601 L
.95554 .20601 L
.95663 .20601 L
.95793 .20601 L
.95865 .20601 L
.95932 .20601 L
.96056 .20601 L
Mistroke
.96186 .20601 L
.96308 .20601 L
.96441 .20601 L
.96567 .20601 L
.96683 .20601 L
.96788 .20601 L
.96903 .20601 L
.97024 .20601 L
.97137 .20601 L
.97261 .20601 L
.97393 .20601 L
.97505 .20601 L
.97628 .20601 L
.9776 .20601 L
.97834 .20601 L
.97902 .20601 L
.98033 .20601 L
.98157 .20601 L
.98264 .20601 L
.9838 .20601 L
.98502 .20601 L
.98617 .20601 L
.98724 .20601 L
.98821 .20601 L
.98934 .20601 L
.99041 .20601 L
.99156 .20601 L
.99279 .20601 L
.99395 .20601 L
.995 .20601 L
.99623 .20601 L
.99757 .20601 L
.99884 .20601 L
1 .20601 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13039,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo00?ooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooo
oom5ooooo`001Ol00002ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Gooooo00?o
0000ooooooooool0oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo00Co
A4A4omgMgOoooooo00001_ooool3o`000?ooooooAOooool000Oooooo00Go0000oooooooooooooooo
o`00000;ooooo`04omgMgOmEEEGoooooo`0000Kooooo00?o0000ooooooooool0oooooom5ooooo`00
1oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001_ooool00ol0003o
ooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^ko
A4A4o`000006ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Gooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool5o`0000Gooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool00ol0003oooooooooo`3oooooodGooooo0005o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0oooooom5ooooo`001ooo
ool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01Oooool3o`000?oooooo
AOooool000Oooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Cooooo
00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Gooooo00?o0000oooooooo
ool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c005ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo027ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@0Iooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l00000
0ol@413oooooooooo`0Gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l0
00001Ol@413oooooooooooooooooA4A400;o000000?o<S8bomgMgOooool06?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM03Wooooo000Qoooo
o`;o00008_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01oooool00omgMgOo<S8booooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B47ooooo`03o`000?oooooooooo00Kooooo00?oMgMgoc8b<_ooool06?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@06_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1oooool00omgMgOo<S8booooo`0hooooo`008Oooool00ol0003oooooooooo`0Qooooo`05oa0@4?oo
ooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000oooooooo
ool05oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool06Oooool01Ol@
413ooooooooooooooooo410@00kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0G
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Kooooo`05oa0@4?oo
ooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo03Oooooo
000Qooooo`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`00
0?ooooooooooooooool000001oooool00omgMgOo<S8booooo`0Hooooo`05o`000?oooooooooooooo
ool000003_ooool00ol0003oooooooooo`0Iooooo`05o`000?ooooooooooooooool000003_ooool0
0ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo01Sooooo00Go0000ooooooooooooooooo`00
000=ooooo`03oiRHV?lQ8B7ok^k^01[ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool0>?ooool0027ooooo00?o0000ooooooooool08Ooo
ool01Ol0003ooooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000004ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`06Oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000
ooooooooool06Oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<01Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo01Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00iooooo`008Oooool00ol0003oooooooooo`0Qoooo
o`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00Cooooo00?o
0000ooooooooool06oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool0
6Oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Kooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`0Hoooo
o`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo03_ooooo000Qooooo`03o`000?oooooooooo027ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00ol0003oooooooooo`0Kooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`0Iooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01_ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41006_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo03_ooooo
000Qooooo`;o00008_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP04ooooo`Co00006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIV
I_l000006oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l000001Oooool4
o`0001[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
6_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004oooo
o`Co0000>_ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo>_ooool00ol@413o0000o`00
0003o`0000Gooooo000Qooooo`03o`000?oooooooooo0?oooooo??ooool00ol0003oooooooooo`06
ooooo`008Oooool00ol0003oooooooooo`3ooooooccooooo00?o0000ooooooooool01_ooool0027o
ooooool0000co`0000cooooo00?o0000ooooooooool01_ooool0027ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`05ooooo`Oo00001Oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool05?ooool00ol0003o<S8bomgMg@06ooooo`008Ooo
ool00ol0003oooooooooo`0[ooooo`?o00000_ooool00ol0003oooooooooo`0`ooooo`03o`000?oo
oooooooo033ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0`ooooo`03o`000?oo
oooooooo03_ooooo0_l000001?nYZJWo8B4Qo`000?lQ8B44ooooo`008Oooool00ol0003ooooooooo
o`0Yooooo`;o0000oooooolJooooo`008Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo0?oooooo6_ooool0027ooooo00?o0000ooooooooool09_ooool2o`000?oooooo7Oooool0027o
oooo0_l0000Uooooo`;o0000oooooolOooooo`008Oooool00ol0003oooooooooo`0Sooooo`03o`00
0?oooooooooo0?oooooo7oooool0027ooooo00?o0000ooooooooool08oooool00ol0003ooooooooo
o`3ooooooaoooooo000Qooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0oooooolP
ooooo`008Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo0?oooooo8Oooool0027o
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`3oooooob;ooooo000Qooooo`03o`00
0?oooooooooo023ooooo00?o0000ooooooooool0oooooolRooooo`008Oooool2o`00023ooooo00?o
0000ooooooooool0oooooolSooooo`008Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo0?oooooo9?ooool0027ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`3ooooo
obCooooo000Qooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0oooooolUooooo`00
8Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo0?oooooo9_ooool0027ooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`3oooooobKooooo000Qooooo`;o00007?ooool0
0ol0003oooooooooo`3oooooobOooooo000Qooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool0oooooolXooooo`008Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo0?oo
oooo:?ooool0027ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`3oooooobWooooo
0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00005ooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool0oooooolYooooo`001oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo0?oooooo:_ooool000Oooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0000Gooooo`03o`000?oooooooooo0?oo
oooo:oooool000Oooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Go
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`3oooooob_ooooo0007ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`04ooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool0ooooool/ooooo`001oooool01Ol@413ooooooooooooooooo410@00oo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo0?oo
oooo;?ooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRH
V?l@41001Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0?oooooo;Oooool000Oo
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01Oooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0?oooooo;Oooool0027ooooo0_l0000Eoooo
o`03o`000?oooooooooo0?oooooo;_ooool0027ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`3ooooooboooooo000Qooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
ooooool_ooooo`008Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo0?oooooo<?oo
ool0027ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`3ooooooc3ooooo000Qoooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool0oooooolaooooo`008Oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo0?oooooo<Oooool0027ooooo0_l0000Aooooo`03o`00
0?oooooooooo0?oooooo<_ooool0027ooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`3ooooooc?ooooo000Qooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0oooooold
ooooo`008Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo0?oooooo=Oooool0027o
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`3oooooocGooooo000Qooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool0oooooolfooooo`008Oooool2o`0000cooooo00?o
0000ooooooooool0oooooolgooooo`008Oooool00ol0003oooooooooo`09ooooo`;o0000oooooolj
ooooo`008Oooool00ol0003oooooooooo`07ooooo`;o0000oooooollooooo`008Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo0?oooooo??ooool000Oooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool3o`000?oooooo?oooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1oooool00ol0003oooooooooo`04ooooo`Ko0000oooooom2ooooo`001oooool01Ol@413ooooo
oooooooooooo410@00_ooooo1Ol00005ooooo`?o0000oooooom5ooooo`001oooool01Ol0003ooooo
oooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00001_ooool00ol0003oooooooooo`3ooooo
odGooooo0007ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00006
ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go410@oooooooooooooooooa0@400<
ooooo`03ogMgMoo<c<co000000Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001_ooool00ol0003oooooooooo`3o
ooooodGooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`05
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo0_l0003oooooodKooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0
003o410@olc<c005ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Gooooo00?o0000
ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`000005ooooo`?o0000oooooom5ooooo`001oooool01Ol0003ooooooooooooo
oooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@05ooooo`03o`000?oooooooooo0?oooooo
AOooool000Oooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`01Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@
41002oooool00omEEEGoQhN7ooooo`07ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Oooooo00?o0000oooooooo
ool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0
003o410@1Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo0_l0003oooooodKooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<
c?lQ8B7o0000ob4Q8Oo<c<`01Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@05oooo
o`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go410@oooooooooooooooooa0@400;oooo
o`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`3oooooodGooooo0007oooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Gooooo0ol0
003oooooodGooooo0007ooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`00
0?l0003oc<c<00Gooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooooooo
oooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4005ooooo`03o`000?oooooooooo0?oo
ooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj
^_l000001Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Gooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool2o`000?ooooooA_oo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool001Sooooo1?l000000ol@413ooooo
ooooo`02ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`?o0000oooooom5oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006?ooool00omEEEGoIVIVo`00003o
ooooodkooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Nooooo`05oiRHV?l0
003o0000odA4A?nj^[X06?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01?ooool4o`000003oa0@4?oooooooooo08gooooo000Oooooo`04
oa0@4?l0003o0000o`0007_ooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00002Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1_ooool00ol0003oooooooooo`2?ooooo`008?ooool00ol0003oooooooooo`1kooooo`03o`000?oo
oooooooo01[ooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?ooooooooooooooool@
41001_ooool00ol0003oooooooooo`2?ooooo`008?ooool00ol0003oooooooooo`1kooooo`03o`00
0?oooooooooo00_ooooo1_l00009ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003o
oooooooooooooooo000000Kooooo00?o0000ooooooooool0Soooool0023ooooo00Ko0000ogMgMol0
003o0000oeEEEOo^k^ihooooo`03o`000?oooooooooo01[ooooo00Go0000ooooooooooooooooo`00
000;ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`2?ooooo`008?oo
ool01_l0003oEEEEonk^k_ooooooMgMgoeEEEGKooooo00?o410@o`000?l000000ol0000Iooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000
ooooooooool0Soooool0023ooooo00?o0000onk^k_ooool00_ooool00ol0003oooooooooo`1foooo
o`03o`000?oooooooooo01[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01_ooool00ol0003oooooooooo`2?ooooo`008?ooool00ol0003ok^k^ooooo`02
ooooo`03o`000?oooooooooo07Kooooo00?o0000ooooooooool06_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`03oeEEEOmVIVKo0000097ooooo
000Pooooo`06o`000?mEEEGok^k^oooooomgMgOoIVIVoooooom3ooooo`007oooool00ol@413o0000
ogMgM`02o`000003ofIVI_o^k^kooooo0?oooooo@_ooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.0332543, -0.540631, \
0.00122928, 0.00994506}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 3.33333 0.206011 0.412023 [
[.16667 .19351 -12 -9 ]
[.16667 .19351 12 0 ]
[.33333 .19351 -9 -9 ]
[.33333 .19351 9 0 ]
[.5 .19351 -12 -9 ]
[.5 .19351 12 0 ]
[.66667 .19351 -9 -9 ]
[.66667 .19351 9 0 ]
[.83333 .19351 -12 -9 ]
[.83333 .19351 12 0 ]
[1.025 .20601 0 -6 ]
[1.025 .20601 10 6 ]
[-0.0125 .0412 -24 -4.5 ]
[-0.0125 .0412 0 4.5 ]
[-0.0125 .12361 -24 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .28842 -18 -4.5 ]
[-0.0125 .28842 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .45322 -18 -4.5 ]
[-0.0125 .45322 0 4.5 ]
[-0.0125 .53563 -18 -4.5 ]
[-0.0125 .53563 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 .20601 m
.16667 .21226 L
s
[(0.05)] .16667 .19351 0 1 Mshowa
.33333 .20601 m
.33333 .21226 L
s
[(0.1)] .33333 .19351 0 1 Mshowa
.5 .20601 m
.5 .21226 L
s
[(0.15)] .5 .19351 0 1 Mshowa
.66667 .20601 m
.66667 .21226 L
s
[(0.2)] .66667 .19351 0 1 Mshowa
.83333 .20601 m
.83333 .21226 L
s
[(0.25)] .83333 .19351 0 1 Mshowa
.125 Mabswid
.03333 .20601 m
.03333 .20976 L
s
.06667 .20601 m
.06667 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.13333 .20601 m
.13333 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.23333 .20601 m
.23333 .20976 L
s
.26667 .20601 m
.26667 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.36667 .20601 m
.36667 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.43333 .20601 m
.43333 .20976 L
s
.46667 .20601 m
.46667 .20976 L
s
.53333 .20601 m
.53333 .20976 L
s
.56667 .20601 m
.56667 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.63333 .20601 m
.63333 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.73333 .20601 m
.73333 .20976 L
s
.76667 .20601 m
.76667 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.86667 .20601 m
.86667 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.93333 .20601 m
.93333 .20976 L
s
.96667 .20601 m
.96667 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
gsave
1.025 .20601 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .0412 m
.00625 .0412 L
s
[(-0.4)] -0.0125 .0412 1 0 Mshowa
0 .12361 m
.00625 .12361 L
s
[(-0.2)] -0.0125 .12361 1 0 Mshowa
0 .28842 m
.00625 .28842 L
s
[(0.2)] -0.0125 .28842 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.4)] -0.0125 .37082 1 0 Mshowa
0 .45322 m
.00625 .45322 L
s
[(0.6)] -0.0125 .45322 1 0 Mshowa
0 .53563 m
.00625 .53563 L
s
[(0.8)] -0.0125 .53563 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .10301 m
.00375 .10301 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .30902 m
.00375 .30902 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .39142 m
.00375 .39142 L
s
0 .41202 m
.00375 .41202 L
s
0 .43262 m
.00375 .43262 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .51503 m
.00375 .51503 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
0 .0206 m
.00375 .0206 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.02) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .05444 m
.04057 .13327 L
.06168 .19998 L
.06747 .2156 L
.07365 .23002 L
.07945 .24108 L
.08481 .24904 L
.09017 .25485 L
.093 .25706 L
.09444 .25797 L
.09599 .25878 L
.09735 .25936 L
.09859 .25979 L
.09984 .26012 L
.10102 .26034 L
.1024 .2605 L
.10367 .26054 L
.10441 .26053 L
.10507 .26049 L
.10584 .26041 L
.10656 .26031 L
.10771 .2601 L
.10897 .2598 L
.11152 .25896 L
.11387 .25795 L
.11607 .25682 L
.12636 .24974 L
.14593 .23325 L
.15625 .22543 L
.16721 .21875 L
.17272 .21608 L
.1788 .21364 L
.18952 .21049 L
.19476 .20939 L
.20041 .20847 L
.20575 .2078 L
.21064 .20734 L
.21562 .20698 L
.22094 .20669 L
.22595 .20649 L
.23051 .20636 L
.23588 .20625 L
.2389 .2062 L
.24169 .20616 L
.24682 .20611 L
.2494 .20609 L
.25225 .20608 L
.25487 .20606 L
.25772 .20605 L
.26024 .20604 L
Mistroke
.26292 .20604 L
.26557 .20603 L
.26798 .20603 L
.27267 .20602 L
.2755 .20602 L
.2781 .20602 L
.28096 .20602 L
.28397 .20602 L
.2866 .20601 L
.28904 .20601 L
.29173 .20601 L
.2946 .20601 L
.29731 .20601 L
.30017 .20601 L
.30262 .20601 L
.30531 .20601 L
.30821 .20601 L
.31132 .20601 L
.31426 .20601 L
.31695 .20601 L
.3195 .20601 L
.32187 .20601 L
.32448 .20601 L
.32725 .20601 L
.33018 .20601 L
.33293 .20601 L
.33541 .20601 L
.33809 .20601 L
.34057 .20601 L
.34324 .20601 L
.34576 .20601 L
.34805 .20601 L
.35074 .20601 L
.35216 .20601 L
.35367 .20601 L
.35644 .20601 L
.359 .20601 L
.3616 .20601 L
.36297 .20601 L
.36441 .20601 L
.36707 .20601 L
.3695 .20601 L
.37089 .20601 L
.37237 .20601 L
.37504 .20601 L
.37668 .20601 L
.37822 .20601 L
.37961 .20601 L
.38111 .20601 L
.38361 .20601 L
Mistroke
.38596 .20601 L
.38739 .20601 L
.38875 .20601 L
.3913 .20601 L
.3926 .20601 L
.39398 .20601 L
.39646 .20601 L
.39798 .20601 L
.39942 .20601 L
.4007 .20601 L
.4021 .20601 L
.40445 .20601 L
.40574 .20601 L
.40694 .20601 L
.4091 .20601 L
.4114 .20601 L
.4127 .20601 L
.41411 .20601 L
.41535 .20601 L
.41667 .20601 L
.41785 .20601 L
.41916 .20601 L
.42146 .20601 L
.42274 .20601 L
.42393 .20601 L
.42535 .20601 L
.42663 .20601 L
.42926 .20601 L
.43071 .20601 L
.43207 .20601 L
.43325 .20601 L
.4345 .20601 L
.43674 .20601 L
.43798 .20601 L
.43915 .20601 L
.44179 .20601 L
.44315 .20601 L
.44463 .20601 L
.44593 .20601 L
.44731 .20601 L
.44869 .20601 L
.44993 .20601 L
.45236 .20601 L
.45382 .20601 L
.45517 .20601 L
.45664 .20601 L
.4582 .20601 L
.45956 .20601 L
.46082 .20601 L
.46221 .20601 L
Mistroke
.4637 .20601 L
.46498 .20601 L
.4664 .20601 L
.46788 .20601 L
.46927 .20601 L
.47054 .20601 L
.47175 .20601 L
.47314 .20601 L
.47442 .20601 L
.47581 .20601 L
.4773 .20601 L
.47871 .20601 L
.47998 .20601 L
.48149 .20601 L
.48311 .20601 L
.48465 .20601 L
.48606 .20601 L
.48728 .20601 L
.48859 .20601 L
.48973 .20601 L
.49096 .20601 L
.4924 .20601 L
.49377 .20601 L
.49511 .20601 L
.49634 .20601 L
.49754 .20601 L
.49884 .20601 L
.50027 .20601 L
.50161 .20601 L
.50303 .20601 L
.50453 .20601 L
.5058 .20601 L
.5072 .20601 L
.50859 .20601 L
.50986 .20601 L
.51126 .20601 L
.51275 .20601 L
.51404 .20601 L
.51524 .20601 L
.51656 .20601 L
.51798 .20601 L
.51924 .20601 L
.52061 .20601 L
.5219 .20601 L
.5231 .20601 L
.52427 .20601 L
.52537 .20601 L
.52664 .20601 L
.52778 .20601 L
.52906 .20601 L
Mistroke
.53046 .20601 L
.53193 .20601 L
.53329 .20601 L
.53457 .20601 L
.53574 .20601 L
.53708 .20601 L
.53836 .20601 L
.53974 .20601 L
.5412 .20601 L
.54245 .20601 L
.54383 .20601 L
.54531 .20601 L
.5469 .20601 L
.5484 .20601 L
.54978 .20601 L
.55112 .20601 L
.55239 .20601 L
.55353 .20601 L
.55477 .20601 L
.55612 .20601 L
.55754 .20601 L
.55876 .20601 L
.56009 .20601 L
.56134 .20601 L
.56248 .20601 L
.5638 .20601 L
.56505 .20601 L
.5662 .20601 L
.56727 .20601 L
.56844 .20601 L
.56968 .20601 L
.57101 .20601 L
.57224 .20601 L
.57359 .20601 L
.575 .20601 L
.57624 .20601 L
.57739 .20601 L
.57866 .20601 L
.58001 .20601 L
.58148 .20601 L
.58232 .20601 L
.58308 .20601 L
.58449 .20601 L
.58599 .20601 L
.58732 .20601 L
.58858 .20601 L
.58995 .20601 L
.59143 .20601 L
.59282 .20601 L
.59409 .20601 L
Mistroke
.59555 .20601 L
.59693 .20601 L
.59821 .20601 L
.59939 .20601 L
.60068 .20601 L
.60204 .20601 L
.60342 .20601 L
.6049 .20601 L
.60629 .20601 L
.60756 .20601 L
.60905 .20601 L
.6099 .20601 L
.61068 .20601 L
.6121 .20601 L
.61283 .20601 L
.61362 .20601 L
.61495 .20601 L
.61636 .20601 L
.61755 .20601 L
.61886 .20601 L
.62027 .20601 L
.62107 .20601 L
.62179 .20601 L
.62318 .20601 L
.62451 .20601 L
.62574 .20601 L
.62706 .20601 L
.62818 .20601 L
.62941 .20601 L
.63073 .20601 L
.63215 .20601 L
.63349 .20601 L
.63472 .20601 L
.63608 .20601 L
.63736 .20601 L
.6385 .20601 L
.63974 .20601 L
.6411 .20601 L
.64178 .20601 L
.64253 .20601 L
.64385 .20601 L
.64509 .20601 L
.64634 .20601 L
.64752 .20601 L
.64858 .20601 L
.64973 .20601 L
.65098 .20601 L
.65231 .20601 L
.65345 .20601 L
.6547 .20601 L
Mistroke
.65539 .20601 L
.65615 .20601 L
.65753 .20601 L
.65887 .20601 L
.66011 .20601 L
.66087 .20601 L
.66159 .20601 L
.66293 .20601 L
.66368 .20601 L
.66438 .20601 L
.66513 .20601 L
.66594 .20601 L
.6672 .20601 L
.66838 .20601 L
.6691 .20601 L
.66978 .20601 L
.67106 .20601 L
.67241 .20601 L
.67365 .20601 L
.67502 .20601 L
.67571 .20601 L
.67648 .20601 L
.67775 .20601 L
.67894 .20601 L
.68024 .20601 L
.68097 .20601 L
.68163 .20601 L
.68297 .20601 L
.68373 .20601 L
.68442 .20601 L
.6857 .20601 L
.68706 .20601 L
.68821 .20601 L
.68945 .20601 L
.69062 .20601 L
.69168 .20601 L
.69293 .20601 L
.69429 .20601 L
.69558 .20601 L
.69677 .20601 L
.69815 .20601 L
.69892 .20601 L
.69964 .20601 L
.70095 .20601 L
.70233 .20601 L
.70358 .20601 L
.70474 .20601 L
.70601 .20601 L
.70737 .20601 L
.70813 .20601 L
Mistroke
.70883 .20601 L
.70958 .20601 L
.71041 .20601 L
.7118 .20601 L
.71256 .20601 L
.71328 .20601 L
.71463 .20601 L
.71587 .20601 L
.71723 .20601 L
.71792 .20601 L
.71866 .20601 L
.72005 .20601 L
.72133 .20601 L
.722 .20601 L
.72274 .20601 L
.72351 .20601 L
.72422 .20601 L
.72553 .20601 L
.72625 .20601 L
.72693 .20601 L
.72815 .20601 L
.72947 .20601 L
.73076 .20601 L
.73193 .20601 L
.73329 .20601 L
.73456 .20601 L
.73574 .20601 L
.73683 .20601 L
.73802 .20601 L
.73928 .20601 L
.74065 .20601 L
.7419 .20601 L
.7426 .20601 L
.74335 .20601 L
.74471 .20601 L
.74599 .20601 L
.74735 .20601 L
.7485 .20601 L
.74978 .20601 L
.75054 .20601 L
.75127 .20601 L
.75264 .20601 L
.7534 .20601 L
.75411 .20601 L
.75494 .20601 L
.75572 .20601 L
.7564 .20601 L
.75713 .20601 L
.75841 .20601 L
.75914 .20601 L
Mistroke
.75991 .20601 L
.76128 .20601 L
.76256 .20601 L
.76328 .20601 L
.76395 .20601 L
.76518 .20601 L
.76649 .20601 L
.76765 .20601 L
.76874 .20601 L
.76994 .20601 L
.77123 .20601 L
.77253 .20601 L
.77326 .20601 L
.77394 .20601 L
.77532 .20601 L
.77609 .20601 L
.7768 .20601 L
.77805 .20601 L
.77942 .20601 L
.78071 .20601 L
.7819 .20601 L
.78301 .20601 L
.7842 .20601 L
.78532 .20601 L
.78635 .20601 L
.78755 .20601 L
.78886 .20601 L
.7901 .20601 L
.79125 .20601 L
.79254 .20601 L
.79376 .20601 L
.79486 .20601 L
.79604 .20601 L
.79734 .20601 L
.7987 .20601 L
.79987 .20601 L
.80115 .20601 L
.80252 .20601 L
.80379 .20601 L
.80446 .20601 L
.80519 .20601 L
.80595 .20601 L
.80667 .20601 L
.80798 .20601 L
.80918 .20601 L
.8105 .20601 L
.81189 .20601 L
.81306 .20601 L
.81431 .20601 L
.81549 .20601 L
Mistroke
.81656 .20601 L
.81782 .20601 L
.81919 .20601 L
.82048 .20601 L
.82167 .20601 L
.82294 .20601 L
.8243 .20601 L
.82559 .20601 L
.82676 .20601 L
.82813 .20601 L
.82891 .20601 L
.82963 .20601 L
.83095 .20601 L
.83161 .20601 L
.83235 .20601 L
.83306 .20601 L
.83381 .20601 L
.83515 .20601 L
.8359 .20601 L
.83659 .20601 L
.83736 .20601 L
.83817 .20601 L
.83888 .20601 L
.83964 .20601 L
.84037 .20601 L
.84104 .20601 L
.8423 .20601 L
.84364 .20601 L
.84491 .20601 L
.84629 .20601 L
.8476 .20601 L
.84881 .20601 L
.85001 .20601 L
.8511 .20601 L
.85235 .20601 L
.85353 .20601 L
.85483 .20601 L
.85619 .20601 L
.85736 .20601 L
.85864 .20601 L
.86002 .20601 L
.86079 .20601 L
.8615 .20601 L
.86287 .20601 L
.86417 .20601 L
.86527 .20601 L
.86649 .20601 L
.86776 .20601 L
.86895 .20601 L
.87006 .20601 L
Mistroke
.87108 .20601 L
.8722 .20601 L
.87337 .20601 L
.87457 .20601 L
.87585 .20601 L
.87706 .20601 L
.87816 .20601 L
.87945 .20601 L
.88018 .20601 L
.88085 .20601 L
.88208 .20601 L
.88339 .20601 L
.88466 .20601 L
.88604 .20601 L
.88735 .20601 L
.88857 .20601 L
.88977 .20601 L
.89086 .20601 L
.89212 .20601 L
.8933 .20601 L
.8946 .20601 L
.89597 .20601 L
.89714 .20601 L
.89842 .20601 L
.8998 .20601 L
.90058 .20601 L
.90128 .20601 L
.90265 .20601 L
.90395 .20601 L
.90506 .20601 L
.90628 .20601 L
.90755 .20601 L
.90874 .20601 L
.90986 .20601 L
.91088 .20601 L
.91205 .20601 L
.91317 .20601 L
.91437 .20601 L
.91565 .20601 L
.91686 .20601 L
.91796 .20601 L
.91925 .20601 L
.91998 .20601 L
.92065 .20601 L
.92188 .20601 L
.92318 .20601 L
.92446 .20601 L
.92518 .20601 L
.92585 .20601 L
.92708 .20601 L
Mistroke
.92838 .20601 L
.92955 .20601 L
.93064 .20601 L
.93183 .20601 L
.93313 .20601 L
.93442 .20601 L
.93515 .20601 L
.93583 .20601 L
.93721 .20601 L
.93799 .20601 L
.93869 .20601 L
.93995 .20601 L
.94131 .20601 L
.9426 .20601 L
.94379 .20601 L
.9449 .20601 L
.94609 .20601 L
.94721 .20601 L
.94824 .20601 L
.94944 .20601 L
.95075 .20601 L
.95199 .20601 L
.95314 .20601 L
.95443 .20601 L
.95565 .20601 L
.95675 .20601 L
.95793 .20601 L
.95922 .20601 L
.96059 .20601 L
.96176 .20601 L
.96304 .20601 L
.96423 .20601 L
.96534 .20601 L
.96655 .20601 L
.96783 .20601 L
.96895 .20601 L
.96999 .20601 L
.97114 .20601 L
.97238 .20601 L
.97341 .20601 L
.97454 .20601 L
.97572 .20601 L
.97682 .20601 L
.97785 .20601 L
.97878 .20601 L
.97986 .20601 L
.98088 .20601 L
.98199 .20601 L
.9832 .20601 L
.98447 .20601 L
Mistroke
.98566 .20601 L
.98677 .20601 L
.98778 .20601 L
.98895 .20601 L
.99006 .20601 L
.99126 .20601 L
.99253 .20601 L
.99362 .20601 L
.99482 .20601 L
.9961 .20601 L
.99749 .20601 L
.9988 .20601 L
1 .20601 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13039,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo00?ooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooo
oom5ooooo`001Ol00002ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Gooooo00?o
0000ooooooooool0oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo00Co
A4A4omgMgOoooooo00001_ooool3o`000?ooooooAOooool000Oooooo00Go0000oooooooooooooooo
o`00000;ooooo`04omgMgOmEEEGoooooo`0000Kooooo00?o0000ooooooooool0oooooom5ooooo`00
1oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001_ooool00ol0003o
ooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^ko
A4A4o`000006ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Gooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool2
o`000?ooooooA_ooool0027ooooo00?o0000ooooool00000oooooom5ooooo`008Oooool00ol0003o
ooooo`00003oooooodGooooo000Qooooo`04o`000?ooooooooooo`000?ooooooA?ooool0027ooooo
00Go0000ooooooooooooooooo`00003ooooood?ooooo000Qooooo`;o00000_ooool00ol0003ooooo
ooooo`3ooooood7ooooo000Qooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0oooo
oom0ooooo`008Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo@?ooool0
027ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooocoooooo000Qooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0ooooooloooooo`008Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo0?oooooo?_ooool0027ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`3oooooockooooo000Qooooo`;o00001_ooool00ol0003oooooooooo`3o
ooooocgooooo000Qooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooolmoooo
o`008Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo??ooool000Oooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Gooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`3ooooooccooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0oooooolkooooo`001Ol00002ooooo`05oa0@4?oooooooooooooo
ool@41003?ooool00onHV9So8B4Qonk^kP06ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool0ooooooljooooo`001oooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q
8Oo^k^h01Oooool3o`0000Sooooo00?o0000ooooooooool0ooooooljooooo`001oooool01Ol0003o
oooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01?ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo0?oooooo>Oooool000Oooooo00Go410@oooooooooooooooooa0@400?oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`3ooooo
ocWooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So
410@00Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`3oooooocSooooo0007oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Gooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`3oooooocSooooo000Qooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool0oooooolhooooo`008Oooool2o`0000cooooo00?o0000oooo
ooooool0oooooolgooooo`008Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0?oo
oooo=oooool0027ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`3oooooocOooooo
000Qooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0oooooolfooooo`008Oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo0?oooooo=_ooool0027ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`3oooooocKooooo000Qooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool04Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool01Om4A4Co0000o`000?lb<S;ogMgM01Wooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool4o`000003oa0@4?oooooooooo01Oooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool4o`000005oa0@4?oooooooooooooo
oom4A4@00_l000000olb<S;ogMgMooooo`0Hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Cooooo1Ol0000Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol0
0004ooooo`05odA4A?l0003o0000oc8b<_oMgMd0>Oooool0027ooooo0_l0000>ooooo`03o`000?oo
oooooooo017ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Oooooo00?oMgMgoc8b<_ooool06?ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo01Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1oooool00ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo01Sooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A401[ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A4
00Oooooo00?oMgMgoc8b<_ooool0>?ooool0027ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0Aooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo
410@00Sooooo00?o0000ooooooooool05oooool01Ol@413ooooooooooooooooo410@00kooooo00?o
0000ooooooooool06Oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Gooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP0Kooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09oooo
o`03o`000?oooooooooo03Oooooo000Qooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool04Oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000007
ooooo`03ogMgMolb<S;ooooo01Sooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oo
oooooooo01Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo00Kooooo
00?oMgMgoc8b<_ooool06?ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^
k^h06_ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omg
MgOo<S8booooo`0hooooo`008Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo013o
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?ooooooooooooooool000001?ooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<01Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`00
0?oooooooooo01Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo00?o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c00Iooooo`05o`000?ooooooooooooooool000003_ooool0
0omgMgOoIVIVooooo`0Iooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0>Oooool0027ooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0@ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooo
oooooooooooo410@00Cooooo00?o0000ooooooooool06oooool01Ol@413ooooooooooooooooo410@
00kooooo00?o0000ooooooooool06Oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0Kooooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`0Hooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo03_ooooo000Qooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool04?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`04ooooo`03o`000?oooooooooo01_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>oooo
o`03o`000?oooooooooo01Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool06oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go
0000okZj^_ooooooV9RHoa0@400Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o
^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool0>oooool0027ooooo0_l0000@ooooo`03
o`000?oooooooooo00oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01?ooool4o`0001[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`03oeEEEOmV
IVKo000001_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`03oeEEEOmVIVKo000000Gooooo
1?l0000Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<
01[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?oo
ool4o`0003[ooooo000Qooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0oooooolc
ooooo`008Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0?oooooo<oooool0027o
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`3oooooobOooooo00?o410@o`000?l0
00000ol00005ooooo`008Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo0?oooooo
:Oooool00ol0003oooooooooo`06ooooo`008Oooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo0?oooooo:Oooool00ol0003oooooooooo`06ooooo`008Oooooooo`0003?o00003?ooool0
0ol0003oooooooooo`06ooooo`008Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo0_l00009ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`03ooooo`Oo00001oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
01Cooooo00?o0000oc8b<_oMgMd01_ooool0027ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo00?o0000;Oooool00ol0003oooooooooo`0`ooooo`03
o`000?oooooooooo033ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0kooooo`;o
000000CoZJVYob4Q8Ol0003o8B4Q1?ooool0027ooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0Looooo`;o0000oooooolBooooo`008Oooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo01[ooooo0_l0003ooooooaCooooo000Qooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`3ooooooaCooooo000Qooooo`;o00005?ooool0
0ol0003oooooooooo`0Fooooo`;o0000oooooolGooooo`008Oooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0oooooolGooooo`008Oooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo01;ooooo0_l0003ooooooa[ooooo000Qooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`3ooooooa[ooooo
000Qooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`3ooooooa_ooooo000Qooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`3ooooooacooooo000Qooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`3ooooooagooooo000Qooooo`;o00006?ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo0?oooooo7_ooool0027ooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0?oooooo7oooool0027ooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo8?oo
ool0027ooooo00?o0000ooooooooool06_ooool2o`0000?ooooo0ol0003oooooob?ooooo000Qoooo
o`03o`000?oooooooooo01cooooo0ol0003oooooobKooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo0_l0003oooooodKooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00005oooo
o`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo00?o0000ooooooooool0oooooom5
ooooo`001oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01_ooool3
o`000?ooooooAOooool000Oooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^00Gooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo
000000kooooo00?oMgMgofIVI_ooool01?ooool00ol0003oooooooooo`3oooooodGooooo0007oooo
o`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@41001Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Gooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003ooooo
odKooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool2o`000?oo
ooooA_ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00?ooooo00?o0000
ooooooooool0oooooom5ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@
413ooooooooooooooooo410@00_ooooo1Ol00005ooooo`?o0000oooooom5ooooo`001oooool01Ol0
003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00001_ooool00ol0003ooooooooo
o`3oooooodGooooo0007ooooo`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEoooo
ool00006ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03ogMgMoo<c<co000000Kooooo00?o0000ooooooooool0oooooom5ooooo`001ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001_ooool00ol0003ooooo
ooooo`3oooooodGooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000
ooooo`05ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^
oc8b<_l0003o410@olc<c005ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Gooooo
00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00_ooooo
00Go0000ooooooooooooooooo`000005ooooo`?o0000oooooom5ooooo`001oooool01Ol0003ooooo
oooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@05ooooo`03o`000?oooooooooo
0?ooooooAOooool000Oooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000
oa0@4?o<c<`01Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05oa0@4?oooooooooo
ooooool@41002oooool00omEEEGoQhN7ooooo`07ooooo`03o`000?oooooooooo0?ooooooAOooool0
00Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Oooooo00?o0000
ooooooooool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<
odA4A?l0003o410@1Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01Oooool00ol0003oooooooooo`3oooooodGooooo0007oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q
8@05ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go410@oooooooooooooooooa0@
400;ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`3oooooodGooooo
0007ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Go
oooo0ol0003oooooodGooooo0007ooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co
0000o`000?l0003oc<c<00Gooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413o
oooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4005ooooo`03o`000?oooooo
oooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooookZj^_l000001Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Gooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003ooooo
odKooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool2o`000?oo
ooooA_ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool001Sooooo1?l000000ol@
413oooooooooo`02ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`?o0000oooo
oom5ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006?ooool00omEEEGoIVIV
o`00003oooooodkooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo002Nooooo`05
oiRHV?l0003o0000odA4A?nj^[X06?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool5o`00093ooooo000Oooooo`04oa0@4?l0003o
0000o`0007_ooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00002Oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OnH
V9So8B4Qonk^k_ooooooA4A4093ooooo000Pooooo`03o`000?oooooooooo07_ooooo00?o0000oooo
ooooool06_ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooooooooooooooooa0@
4004ooooo`03oiRHV?lQ8B7ok^k^097ooooo000Pooooo`03o`000?oooooooooo07_ooooo00?o0000
ooooooooool02oooool6o`0000Wooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?oo
ooooooooooooool000001Oooool00onHV9So8B4Qonk^kP2@ooooo`008?ooool01_l0003oMgMgo`00
0?l0003oEEEEonk^kWSooooo00?o0000ooooooooool06_ooool01Ol0003ooooooooooooooooo0000
00_ooooo00Go0000ooooooooooooooooo`000006ooooo`03ogMgMomVIVKooooo08oooooo000Poooo
o`06o`000?mEEEGok^k^oooooomgMgOoEEEEM_ooool00ol@413o0000o`000003o`0001Wooooo00Go
410@oooooooooooooooooa0@400;ooooo`05oa0@4?ooooooooooooooool@41001oooool00ol0003o
ooooooooo`2>ooooo`008?ooool00ol0003ok^k^ooooo`02ooooo`03o`000?oooooooooo07Kooooo
00?o0000ooooooooool06_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`03ooooo`05o`000?nj^[[ooooooiRHV?l@4100T?ooool0023ooooo00?o0000onk^
k_ooool00_ooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo01[ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01OnHV9So410@o`00
0?lQ8B7oc<c<093ooooo000Pooooo`06o`000?mEEEGok^k^oooooomgMgOoIVIVoooooom3ooooo`00
7oooool00ol@413o0000ogMgM`02o`000003ofIVI_o^k^kooooo0?oooooo@_ooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.0332543, -0.540631, \
0.00122928, 0.00994506}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 3.33333 0.206011 0.412023 [
[.16667 .19351 -12 -9 ]
[.16667 .19351 12 0 ]
[.33333 .19351 -9 -9 ]
[.33333 .19351 9 0 ]
[.5 .19351 -12 -9 ]
[.5 .19351 12 0 ]
[.66667 .19351 -9 -9 ]
[.66667 .19351 9 0 ]
[.83333 .19351 -12 -9 ]
[.83333 .19351 12 0 ]
[1.025 .20601 0 -6 ]
[1.025 .20601 10 6 ]
[-0.0125 .0412 -24 -4.5 ]
[-0.0125 .0412 0 4.5 ]
[-0.0125 .12361 -24 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .28842 -18 -4.5 ]
[-0.0125 .28842 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .45322 -18 -4.5 ]
[-0.0125 .45322 0 4.5 ]
[-0.0125 .53563 -18 -4.5 ]
[-0.0125 .53563 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 .20601 m
.16667 .21226 L
s
[(0.05)] .16667 .19351 0 1 Mshowa
.33333 .20601 m
.33333 .21226 L
s
[(0.1)] .33333 .19351 0 1 Mshowa
.5 .20601 m
.5 .21226 L
s
[(0.15)] .5 .19351 0 1 Mshowa
.66667 .20601 m
.66667 .21226 L
s
[(0.2)] .66667 .19351 0 1 Mshowa
.83333 .20601 m
.83333 .21226 L
s
[(0.25)] .83333 .19351 0 1 Mshowa
.125 Mabswid
.03333 .20601 m
.03333 .20976 L
s
.06667 .20601 m
.06667 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.13333 .20601 m
.13333 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.23333 .20601 m
.23333 .20976 L
s
.26667 .20601 m
.26667 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.36667 .20601 m
.36667 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.43333 .20601 m
.43333 .20976 L
s
.46667 .20601 m
.46667 .20976 L
s
.53333 .20601 m
.53333 .20976 L
s
.56667 .20601 m
.56667 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.63333 .20601 m
.63333 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.73333 .20601 m
.73333 .20976 L
s
.76667 .20601 m
.76667 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.86667 .20601 m
.86667 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.93333 .20601 m
.93333 .20976 L
s
.96667 .20601 m
.96667 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
gsave
1.025 .20601 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .0412 m
.00625 .0412 L
s
[(-0.4)] -0.0125 .0412 1 0 Mshowa
0 .12361 m
.00625 .12361 L
s
[(-0.2)] -0.0125 .12361 1 0 Mshowa
0 .28842 m
.00625 .28842 L
s
[(0.2)] -0.0125 .28842 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.4)] -0.0125 .37082 1 0 Mshowa
0 .45322 m
.00625 .45322 L
s
[(0.6)] -0.0125 .45322 1 0 Mshowa
0 .53563 m
.00625 .53563 L
s
[(0.8)] -0.0125 .53563 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .10301 m
.00375 .10301 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .30902 m
.00375 .30902 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .39142 m
.00375 .39142 L
s
0 .41202 m
.00375 .41202 L
s
0 .43262 m
.00375 .43262 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .51503 m
.00375 .51503 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
0 .0206 m
.00375 .0206 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.03) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .05402 m
.00123 .05404 L
.00236 .05409 L
.00365 .05418 L
.00488 .05431 L
.00706 .05463 L
.00942 .05512 L
.01203 .05582 L
.01479 .05678 L
.01975 .05905 L
.02486 .06221 L
.02966 .06602 L
.04057 .07806 L
.04627 .08636 L
.0517 .09555 L
.06188 .11598 L
.08481 .17118 L
.09564 .19673 L
.10584 .21732 L
.115 .23157 L
.12016 .23756 L
.12491 .24175 L
.12739 .24343 L
.1297 .2447 L
.13224 .24576 L
.13366 .24622 L
.13496 .24655 L
.13631 .2468 L
.13757 .24696 L
.13894 .24706 L
.13964 .24708 L
.14041 .24707 L
.14169 .24701 L
.14307 .24687 L
.14437 .24667 L
.14557 .24643 L
.14822 .24573 L
.15069 .24488 L
.1563 .24238 L
.16759 .23574 L
.18726 .22332 L
.19762 .21793 L
.20859 .21357 L
.21414 .21187 L
.22025 .21036 L
.22587 .20926 L
.231 .20847 L
.23627 .20783 L
.24193 .20731 L
.24718 .20695 L
Mistroke
.25216 .20669 L
.25746 .20649 L
.26225 .20635 L
.26491 .20629 L
.26779 .20624 L
.27027 .2062 L
.273 .20617 L
.2779 .20612 L
.28057 .2061 L
.28307 .20608 L
.28753 .20606 L
.29004 .20605 L
.29232 .20604 L
.29738 .20603 L
.29994 .20603 L
.30275 .20602 L
.30515 .20602 L
.30773 .20602 L
.3124 .20602 L
.31505 .20602 L
.31795 .20601 L
.32097 .20601 L
.32378 .20601 L
.32643 .20601 L
.32883 .20601 L
.3316 .20601 L
.33421 .20601 L
.33673 .20601 L
.33909 .20601 L
.34167 .20601 L
.34444 .20601 L
.34735 .20601 L
.3501 .20601 L
.35257 .20601 L
.35526 .20601 L
.35758 .20601 L
.36014 .20601 L
.36282 .20601 L
.36533 .20601 L
.36767 .20601 L
.36982 .20601 L
.37217 .20601 L
.37465 .20601 L
.37735 .20601 L
.37989 .20601 L
.38218 .20601 L
.38466 .20601 L
.38736 .20601 L
.39022 .20601 L
.39267 .20601 L
Mistroke
.39536 .20601 L
.39786 .20601 L
.40015 .20601 L
.4028 .20601 L
.40531 .20601 L
.40762 .20601 L
.40977 .20601 L
.41212 .20601 L
.41463 .20601 L
.41594 .20601 L
.41737 .20601 L
.41877 .20601 L
.42026 .20601 L
.42167 .20601 L
.42294 .20601 L
.42544 .20601 L
.42694 .20601 L
.42832 .20601 L
.42981 .20601 L
.43145 .20601 L
.4342 .20601 L
.43571 .20601 L
.43713 .20601 L
.43972 .20601 L
.44103 .20601 L
.44245 .20601 L
.44367 .20601 L
.44498 .20601 L
.44733 .20601 L
.44875 .20601 L
.45029 .20601 L
.45165 .20601 L
.45309 .20601 L
.45438 .20601 L
.45581 .20601 L
.45832 .20601 L
.45968 .20601 L
.46094 .20601 L
.46244 .20601 L
.4638 .20601 L
.46632 .20601 L
.4677 .20601 L
.469 .20601 L
.47019 .20601 L
.47144 .20601 L
.47369 .20601 L
.47494 .20601 L
.4761 .20601 L
.47875 .20601 L
.48012 .20601 L
Mistroke
.4816 .20601 L
.48291 .20601 L
.4843 .20601 L
.48555 .20601 L
.48693 .20601 L
.48935 .20601 L
.49082 .20601 L
.49217 .20601 L
.49373 .20601 L
.49521 .20601 L
.49657 .20601 L
.49783 .20601 L
.49922 .20601 L
.50069 .20601 L
.502 .20601 L
.50343 .20601 L
.50492 .20601 L
.50631 .20601 L
.5076 .20601 L
.50881 .20601 L
.51021 .20601 L
.51149 .20601 L
.51289 .20601 L
.51439 .20601 L
.51567 .20601 L
.51708 .20601 L
.51859 .20601 L
.52022 .20601 L
.52176 .20601 L
.52317 .20601 L
.5244 .20601 L
.52572 .20601 L
.52686 .20601 L
.52809 .20601 L
.52954 .20601 L
.53091 .20601 L
.53225 .20601 L
.53348 .20601 L
.53478 .20601 L
.53599 .20601 L
.53732 .20601 L
.53875 .20601 L
.54025 .20601 L
.54167 .20601 L
.54295 .20601 L
.54434 .20601 L
.54574 .20601 L
.54703 .20601 L
.54844 .20601 L
.54993 .20601 L
Mistroke
.55123 .20601 L
.55244 .20601 L
.55377 .20601 L
.5552 .20601 L
.55646 .20601 L
.55784 .20601 L
.55914 .20601 L
.56034 .20601 L
.56152 .20601 L
.56262 .20601 L
.56376 .20601 L
.56503 .20601 L
.56632 .20601 L
.56773 .20601 L
.5692 .20601 L
.57057 .20601 L
.57185 .20601 L
.57302 .20601 L
.57437 .20601 L
.57564 .20601 L
.57702 .20601 L
.57849 .20601 L
.57974 .20601 L
.58112 .20601 L
.5826 .20601 L
.58419 .20601 L
.58569 .20601 L
.58706 .20601 L
.58829 .20601 L
.58945 .20601 L
.59072 .20601 L
.59209 .20601 L
.59345 .20601 L
.59488 .20601 L
.59611 .20601 L
.59745 .20601 L
.59871 .20601 L
.59985 .20601 L
.60118 .20601 L
.60243 .20601 L
.60358 .20601 L
.60465 .20601 L
.60582 .20601 L
.60707 .20601 L
.60841 .20601 L
.60965 .20601 L
.61107 .20601 L
.61242 .20601 L
.61366 .20601 L
.61482 .20601 L
Mistroke
.61608 .20601 L
.61743 .20601 L
.61892 .20601 L
.61975 .20601 L
.62052 .20601 L
.62193 .20601 L
.62342 .20601 L
.62476 .20601 L
.62601 .20601 L
.62738 .20601 L
.62885 .20601 L
.63013 .20601 L
.63154 .20601 L
.63302 .20601 L
.6344 .20601 L
.63569 .20601 L
.63687 .20601 L
.63817 .20601 L
.63954 .20601 L
.64093 .20601 L
.64241 .20601 L
.64382 .20601 L
.64509 .20601 L
.64659 .20601 L
.64743 .20601 L
.64821 .20601 L
.64964 .20601 L
.65037 .20601 L
.65116 .20601 L
.65257 .20601 L
.65391 .20601 L
.65511 .20601 L
.65642 .20601 L
.65784 .20601 L
.65864 .20601 L
.65936 .20601 L
.66076 .20601 L
.66208 .20601 L
.66332 .20601 L
.66464 .20601 L
.66576 .20601 L
.66699 .20601 L
.66831 .20601 L
.66904 .20601 L
.66973 .20601 L
.67107 .20601 L
.67229 .20601 L
.67349 .20601 L
.67479 .20601 L
.67601 .20601 L
Mistroke
.67713 .20601 L
.67843 .20601 L
.67917 .20601 L
.67986 .20601 L
.68112 .20601 L
.68246 .20601 L
.68318 .20601 L
.68385 .20601 L
.68458 .20601 L
.68537 .20601 L
.6867 .20601 L
.68743 .20601 L
.68811 .20601 L
.68941 .20601 L
.69059 .20601 L
.69195 .20601 L
.69324 .20601 L
.69435 .20601 L
.69557 .20601 L
.69685 .20601 L
.69805 .20601 L
.69917 .20601 L
.7002 .20601 L
.70132 .20601 L
.70251 .20601 L
.70372 .20601 L
.705 .20601 L
.70622 .20601 L
.70733 .20601 L
.70863 .20601 L
.70936 .20601 L
.71004 .20601 L
.71128 .20601 L
.7126 .20601 L
.71387 .20601 L
.71525 .20601 L
.71656 .20601 L
.71777 .20601 L
.71897 .20601 L
.72006 .20601 L
.72131 .20601 L
.72249 .20601 L
.72379 .20601 L
.72516 .20601 L
.72632 .20601 L
.72761 .20601 L
.72899 .20601 L
.72976 .20601 L
.73046 .20601 L
.73183 .20601 L
Mistroke
.73313 .20601 L
.73423 .20601 L
.73545 .20601 L
.73672 .20601 L
.73792 .20601 L
.73903 .20601 L
.74005 .20601 L
.74117 .20601 L
.74234 .20601 L
.74354 .20601 L
.74482 .20601 L
.74603 .20601 L
.74712 .20601 L
.74842 .20601 L
.74914 .20601 L
.74982 .20601 L
.75105 .20601 L
.75235 .20601 L
.75363 .20601 L
.75502 .20601 L
.75633 .20601 L
.75754 .20601 L
.75874 .20601 L
.75983 .20601 L
.76109 .20601 L
.76228 .20601 L
.76358 .20601 L
.76495 .20601 L
.76612 .20601 L
.7674 .20601 L
.76878 .20601 L
.76956 .20601 L
.77026 .20601 L
.77163 .20601 L
.77293 .20601 L
.77404 .20601 L
.77526 .20601 L
.77653 .20601 L
.77772 .20601 L
.77884 .20601 L
.77986 .20601 L
.78103 .20601 L
.78215 .20601 L
.78335 .20601 L
.78463 .20601 L
.78584 .20601 L
.78694 .20601 L
.78823 .20601 L
.78896 .20601 L
.78963 .20601 L
Mistroke
.79086 .20601 L
.79216 .20601 L
.79344 .20601 L
.79417 .20601 L
.79484 .20601 L
.79606 .20601 L
.79737 .20601 L
.79853 .20601 L
.79962 .20601 L
.80082 .20601 L
.80211 .20601 L
.80341 .20601 L
.80414 .20601 L
.80482 .20601 L
.8062 .20601 L
.80698 .20601 L
.80768 .20601 L
.80894 .20601 L
.8103 .20601 L
.81159 .20601 L
.81278 .20601 L
.81389 .20601 L
.81508 .20601 L
.8162 .20601 L
.81723 .20601 L
.81843 .20601 L
.81974 .20601 L
.82098 .20601 L
.82213 .20601 L
.82343 .20601 L
.82465 .20601 L
.82574 .20601 L
.82692 .20601 L
.82822 .20601 L
.82958 .20601 L
.83075 .20601 L
.83203 .20601 L
.8334 .20601 L
.83467 .20601 L
.83534 .20601 L
.83607 .20601 L
.83683 .20601 L
.83755 .20601 L
.83886 .20601 L
.84006 .20601 L
.84138 .20601 L
.84277 .20601 L
.84394 .20601 L
.84519 .20601 L
.84637 .20601 L
Mistroke
.84744 .20601 L
.84871 .20601 L
.85007 .20601 L
.85136 .20601 L
.85255 .20601 L
.85382 .20601 L
.85518 .20601 L
.85647 .20601 L
.85764 .20601 L
.85901 .20601 L
.85979 .20601 L
.86051 .20601 L
.86183 .20601 L
.8625 .20601 L
.86323 .20601 L
.86394 .20601 L
.86469 .20601 L
.86603 .20601 L
.86678 .20601 L
.86747 .20601 L
.86824 .20601 L
.86905 .20601 L
.86976 .20601 L
.87053 .20601 L
.87125 .20601 L
.87192 .20601 L
.87318 .20601 L
.87453 .20601 L
.87579 .20601 L
.87717 .20601 L
.87848 .20601 L
.87969 .20601 L
.88089 .20601 L
.88198 .20601 L
.88323 .20601 L
.88441 .20601 L
.88571 .20601 L
.88708 .20601 L
.88824 .20601 L
.88952 .20601 L
.8909 .20601 L
.89168 .20601 L
.89238 .20601 L
.89375 .20601 L
.89505 .20601 L
.89615 .20601 L
.89737 .20601 L
.89864 .20601 L
.89983 .20601 L
.90094 .20601 L
Mistroke
.90196 .20601 L
.90308 .20601 L
.90426 .20601 L
.90545 .20601 L
.90673 .20601 L
.90794 .20601 L
.90904 .20601 L
.91033 .20601 L
.91106 .20601 L
.91173 .20601 L
.91296 .20601 L
.91427 .20601 L
.91554 .20601 L
.91693 .20601 L
.91824 .20601 L
.91945 .20601 L
.92065 .20601 L
.92174 .20601 L
.923 .20601 L
.92418 .20601 L
.92548 .20601 L
.92685 .20601 L
.92802 .20601 L
.9293 .20601 L
.93069 .20601 L
.93146 .20601 L
.93217 .20601 L
.93354 .20601 L
.93483 .20601 L
.93594 .20601 L
.93716 .20601 L
.93843 .20601 L
.93963 .20601 L
.94074 .20601 L
.94176 .20601 L
.94293 .20601 L
.94405 .20601 L
.94525 .20601 L
.94653 .20601 L
.94774 .20601 L
.94884 .20601 L
.95013 .20601 L
.95086 .20601 L
.95153 .20601 L
.95276 .20601 L
.95407 .20601 L
.95534 .20601 L
.95607 .20601 L
.95674 .20601 L
.95796 .20601 L
Mistroke
.95927 .20601 L
.96043 .20601 L
.96152 .20601 L
.96272 .20601 L
.96401 .20601 L
.9653 .20601 L
.96603 .20601 L
.96672 .20601 L
.9681 .20601 L
.96887 .20601 L
.96957 .20601 L
.97083 .20601 L
.97219 .20601 L
.97348 .20601 L
.97467 .20601 L
.97578 .20601 L
.97697 .20601 L
.97809 .20601 L
.97912 .20601 L
.98032 .20601 L
.98163 .20601 L
.98287 .20601 L
.98402 .20601 L
.98531 .20601 L
.98653 .20601 L
.98763 .20601 L
.98881 .20601 L
.99011 .20601 L
.99147 .20601 L
.99264 .20601 L
.99392 .20601 L
.99471 .20601 L
.99545 .20601 L
.99613 .20601 L
.99685 .20601 L
.99765 .20601 L
.99849 .20601 L
.99921 .20601 L
1 .20601 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13039,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo00?ooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooo
oom5ooooo`001Ol00002ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Gooooo00?o
0000ooooooooool0oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo00Co
A4A4omgMgOoooooo00001_ooool3o`000?ooooooAOooool000Oooooo00Go0000oooooooooooooooo
o`00000;ooooo`04omgMgOmEEEGoooooo`0000Kooooo00?o0000ooooooooool0oooooom5ooooo`00
1oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001_ooool00ol0003o
ooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^ko
A4A4o`000006ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Gooooo1Ol0003ooooood?ooooo000Qooooo`03o`00
0?oooooooooo00;ooooo0ol0003ooooood3ooooo000Qooooo`;o00001_ooool00ol0003ooooooooo
o`3oooooocgooooo000Qooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0ooooooll
ooooo`008Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo>oooool0027o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`3ooooooc[ooooo000Qooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool0ooooooliooooo`008Oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo0?oooooo>?ooool0027ooooo0_l0000;ooooo`03o`000?oooooo
oooo0?oooooo>?ooool0027ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`3ooooo
ocOooooo000Qooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0oooooolgooooo`00
8Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo0?oooooo=_ooool0027ooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`3oooooocGooooo000Qooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool0ooooooleooooo`008Oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo0?oooooo=?ooool0027ooooo0_l0000?ooooo`03o`000?oooooooooo0?oo
oooo=?ooool0027ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`3ooooooc?ooooo
000Qooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0oooooolcooooo`001oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001Oooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo0?oooooo<oooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`3ooooooc;ooooo0005o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`3ooooooc;ooooo0007ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Q
onk^kP05ooooo`?o00004Oooool00ol0003oooooooooo`3ooooooc7ooooo0007ooooo`05o`000?oo
ooooooooooooool000003_ooool00omgMgOoIVIVooooo`04ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool0oooooolaooooo`001oooool01Ol@413ooooooooooooooooo410@00oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo0?oooooo
<?ooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@
41001Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo0?oooooo<?ooool000Oooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01Oooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo0?oooooo<?ooool0027ooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`3ooooooboooooo000Qooooo`;o00005?ooool00ol0003ooooo
ooooo`3ooooooboooooo000Qooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0oooo
ool^ooooo`008Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo0?oooooo;_ooool0
027ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`3oooooobgooooo000Qooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool0ooooool]ooooo`008Oooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo0?oooooo;Oooool0027ooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`08ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`05odA4A?l0003o0000oc8b<_oMgMd06Oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`Co000000?o410@ooooooooool05oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`Co000000Go410@oooooooooooooooo
odA4A002o`000003oc8b<_oMgMgooooo01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1?ooool5o`0001[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`00
00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0iooooo`008Oooool2o`0001Oooooo00?o0000oooo
ooooool02?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01oooool00omgMgOo<S8booooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B47ooooo`03o`000?oooooooooo00Kooooo00?oMgMgoc8b<_ooool06?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@06_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1oooool00omgMgOo<S8booooo`0hooooo`008Oooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo00Oooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?ooooooooooooooool@
41002?ooool00ol0003oooooooooo`0Gooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0
003oooooooooo`0Iooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo01Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ
8B7ok^k^01_ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo
00?o0000ooooooooool0=oooool0027ooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`07ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooooooooooo000000Oo
oooo00?oMgMgoc8b<_ooool06?ooool01Ol0003ooooooooooooooooo000000kooooo00?o0000oooo
ooooool06Oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool01_ooool0
0omgMgOo<S8booooo`0Hooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^
kP0Jooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMg
Molb<S;ooooo03Sooooo000Qooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01_oo
ool01Ol0003ooooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000004ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`06Oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000
ooooooooool06Oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<01Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo01Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00iooooo`008Oooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo00Kooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?oooooo
ooooooooool@41001?ooool00ol0003oooooooooo`0Kooooo`05oa0@4?ooooooooooooooool@4100
3_ooool00ol0003oooooooooo`0Iooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo01_ooooo00Go410@oooooooooooooooooa0@400?oooo
o`03o`000?oooooooooo01Sooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0>oooool0027ooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`06ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Cooooo00?o0000ooooooooool06oooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo
00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Kooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@01[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj
^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`0kooooo`008Oooool2o`0001[ooooo00?o
0000ooooooooool01Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP04ooooo`Co00006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIV
I_l000006oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l000001Oooool4
o`0001[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
6_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004oooo
o`Co0000>_ooool0027ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`3oooooobWo
oooo000Qooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0oooooolYooooo`008Ooo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo0?oooooo7Oooool00ol@413o0000o`00
0003o`0000Gooooo000Qooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0oooooolO
ooooo`03o`000?oooooooooo00Kooooo000Qooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool0oooooolNooooo`03o`000?oooooooooo00Kooooo000Qoooooooo0000<ol0000<ooooo`03
o`000?oooooooooo00Kooooo000Qooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo1_l00009ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo01Cooooo00?o0000oc8b<_oMgMd01_ooool0027ooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Wooooo1?l0000Sooooo`03o`000?oo
oooooooo033ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0`ooooo`03o`000?oo
oooooooo03_ooooo0_l000001?nYZJWo8B4Qo`000?lQ8B44ooooo`008Oooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0ooooool7ooooo`008Oooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01Oooooo0ol0003oooooo`[ooooo000Qoooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool05?ooool3o`000?oooooo3Oooool0027o
oooo0_l0000Pooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0ooooool>ooooo`00
8Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo013ooooo0_l0003ooooooa7ooooo
000Qooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`3ooooooa7ooooo000Qooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool02oooool2
o`000?oooooo5?ooool0027ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo0?oooooo5?ooool0027ooooo00?o0000ooooooooool08oooool2o`0000Oo
oooo0_l0003ooooooaOooooo000Qooooo`03o`000?oooooooooo02Gooooo0_l00002ooooo`?o0000
oooooolIooooo`008Oooool2o`0002Sooooo0ol0003ooooooa_ooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Gooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool00ol0003o
ooooooooo`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP06ooooo`?o0000oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h01Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`04ooooo`03o`000?oooooooooo0?oo
ooooAOooool000Oooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0oooooom5ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4005ooooo`03o`000?oooooooooo0?ooooooAOooool000Oo
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
1oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@oooooooo
ool00oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGo
oooo0007ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Gooooo0ol0003oooooodGo
oooo0007ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool00006oooo
o`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go0000ooooooooooooooooo`00000;oooo
o`04omgMgOmEEEGoooooo`0000Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@
413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001_ooool00ol0003oooooooooo`3o
ooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`000006
ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=
ooooo`03ogMgMol0003ooooo00Gooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Gooooo00?o0000ooooooooool0oooooom5oooo
o`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooo
oiRHV?lQ8B401Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol0003ooooooooooooooooo000000Gooooo0ol0003oooooodGooooo0007
ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Gooooo
00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo
00Go0000oeEEEOl0003o410@olc<c005ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo
00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo00Oooooo00?o0000oooooooo
ool0oooooom5ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nH
V9P01oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h03?ooool01?o<c<coA4A4o`000?l@4105ooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c005ooooo`03o`000?oooooooooo0?oo
ooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7o
V9RHoooooonHV9So8B4Q00Gooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413o
oooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooo
oooo0?ooooooAOooool000Oooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9So
oooooiRHV?lb<S801Oooool3o`000?ooooooAOooool000Oooooo00Go0000ooooooooooooooooo`00
000;ooooo`05olc<c?l0003o0000o`000?o<c<`01Oooool00ol0003oooooooooo`3oooooodGooooo
0007ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Go
oooo00?o0000ooooooooool0oooooom5ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_oooooo^[Zjo`000005ooooo`03o`000?oooooooooo0?ooooooAOooool000Oo
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo0_l0003oooooodKooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
6?ooool4o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool0oooooom5ooooo`006_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo
00Cooooo0ol0003oooooodGooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000H
ooooo`03oeEEEOmVIVKo00000?ooooooC_ooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool009kooooo00GoV9RHo`000?l0003oA4A4okZj^P0Hooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05oiRHV?l@413o0000
oc8b<_o<c<`0T?ooool001oooooo00Co410@o`000?l0003o0000Noooool01Ol@413o^[Zjonk^k_mg
MgOo410@00Wooooo1_l00009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05oa0@4?nj^[[oooooogMgMolb<S80T?ooool0023o
oooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`0Jooooo`05oa0@4?oooooooooooooo
ool@41002oooool01Ol@413ooooooooooooooooo410@00Oooooo00?o0000ooooooooool0S_ooool0
023ooooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`0;ooooo`Ko00002Oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000006ooooo`03ojVYZOl@
413ooooo08oooooo000Pooooo`06o`000?mgMgOo0000o`000?mEEEGok^k^N?ooool00ol0003ooooo
ooooo`0Jooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooooooooooo0000
00Gooooo00?o410@o`000?nj^[X0T?ooool0023ooooo00Ko0000oeEEEOo^k^koooooogMgMomEEEEf
ooooo`03oa0@4?l0003o000000?o00006Oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go
410@oooooooooooooooooa0@4006ooooo`03okZj^_lQ8B7ooooo08oooooo000Pooooo`03o`000?o^
k^kooooo00;ooooo00?o0000ooooooooool0M_ooool00ol0003oooooooooo`0Jooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Go410@oiRHV?oo
oooo^[Zjo`00002@ooooo`008?ooool00ol0003ok^k^ooooo`02ooooo`03o`000?oooooooooo07Ko
oooo00?o0000ooooooooool06_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP03ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0T?ooool0023ooooo00Ko0000
oeEEEOo^k^koooooogMgMomVIVKooooood?ooooo000Oooooo`03oa0@4?l0003oMgMg00;o000000?o
IVIVonk^k_ooool0oooooom2ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.0332543, -0.540631, \
0.00122928, 0.00994506}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 3.33333 0.206011 0.412023 [
[.16667 .19351 -12 -9 ]
[.16667 .19351 12 0 ]
[.33333 .19351 -9 -9 ]
[.33333 .19351 9 0 ]
[.5 .19351 -12 -9 ]
[.5 .19351 12 0 ]
[.66667 .19351 -9 -9 ]
[.66667 .19351 9 0 ]
[.83333 .19351 -12 -9 ]
[.83333 .19351 12 0 ]
[1.025 .20601 0 -6 ]
[1.025 .20601 10 6 ]
[-0.0125 .0412 -24 -4.5 ]
[-0.0125 .0412 0 4.5 ]
[-0.0125 .12361 -24 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .28842 -18 -4.5 ]
[-0.0125 .28842 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .45322 -18 -4.5 ]
[-0.0125 .45322 0 4.5 ]
[-0.0125 .53563 -18 -4.5 ]
[-0.0125 .53563 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 .20601 m
.16667 .21226 L
s
[(0.05)] .16667 .19351 0 1 Mshowa
.33333 .20601 m
.33333 .21226 L
s
[(0.1)] .33333 .19351 0 1 Mshowa
.5 .20601 m
.5 .21226 L
s
[(0.15)] .5 .19351 0 1 Mshowa
.66667 .20601 m
.66667 .21226 L
s
[(0.2)] .66667 .19351 0 1 Mshowa
.83333 .20601 m
.83333 .21226 L
s
[(0.25)] .83333 .19351 0 1 Mshowa
.125 Mabswid
.03333 .20601 m
.03333 .20976 L
s
.06667 .20601 m
.06667 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.13333 .20601 m
.13333 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.23333 .20601 m
.23333 .20976 L
s
.26667 .20601 m
.26667 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.36667 .20601 m
.36667 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.43333 .20601 m
.43333 .20976 L
s
.46667 .20601 m
.46667 .20976 L
s
.53333 .20601 m
.53333 .20976 L
s
.56667 .20601 m
.56667 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.63333 .20601 m
.63333 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.73333 .20601 m
.73333 .20976 L
s
.76667 .20601 m
.76667 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.86667 .20601 m
.86667 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.93333 .20601 m
.93333 .20976 L
s
.96667 .20601 m
.96667 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
gsave
1.025 .20601 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .0412 m
.00625 .0412 L
s
[(-0.4)] -0.0125 .0412 1 0 Mshowa
0 .12361 m
.00625 .12361 L
s
[(-0.2)] -0.0125 .12361 1 0 Mshowa
0 .28842 m
.00625 .28842 L
s
[(0.2)] -0.0125 .28842 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.4)] -0.0125 .37082 1 0 Mshowa
0 .45322 m
.00625 .45322 L
s
[(0.6)] -0.0125 .45322 1 0 Mshowa
0 .53563 m
.00625 .53563 L
s
[(0.8)] -0.0125 .53563 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .10301 m
.00375 .10301 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .30902 m
.00375 .30902 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .39142 m
.00375 .39142 L
s
0 .41202 m
.00375 .41202 L
s
0 .43262 m
.00375 .43262 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .51503 m
.00375 .51503 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
0 .0206 m
.00375 .0206 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.04) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .15319 m
.00123 .15317 L
.00236 .15313 L
.00365 .15304 L
.00488 .15293 L
.00706 .15265 L
.00942 .15224 L
.01203 .15166 L
.01479 .1509 L
.01975 .14919 L
.04057 .13904 L
.05071 .13413 L
.05363 .13297 L
.05641 .13203 L
.05893 .13132 L
.06162 .13076 L
.06242 .13063 L
.06318 .13053 L
.06391 .13045 L
.06459 .13039 L
.06591 .13032 L
.06661 .1303 L
.06734 .1303 L
.06809 .13033 L
.06888 .13037 L
.06964 .13044 L
.07032 .13051 L
.072 .13078 L
.07359 .13113 L
.07638 .132 L
.07896 .13309 L
.0818 .13462 L
.08481 .13663 L
.09465 .14589 L
.10525 .15999 L
.12445 .19156 L
.13535 .20907 L
.14549 .22266 L
.15103 .22851 L
.15607 .23273 L
.15876 .23454 L
.16167 .23615 L
.16474 .23747 L
.16626 .23798 L
.16764 .23836 L
.16883 .23863 L
.17012 .23887 L
.17148 .23904 L
.17278 .23915 L
.17399 .2392 L
Mistroke
.17527 .2392 L
.17648 .23914 L
.17758 .23905 L
.17827 .23898 L
.17899 .23889 L
.18029 .23868 L
.18321 .23805 L
.18574 .23734 L
.18851 .23641 L
.19995 .2313 L
.21061 .22573 L
.23022 .2165 L
.24129 .21271 L
.25152 .21019 L
.25667 .20924 L
.26236 .2084 L
.2683 .20773 L
.27386 .20725 L
.27918 .20691 L
.28404 .20667 L
.28938 .20647 L
.295 .20633 L
.30027 .20623 L
.30505 .20616 L
.3077 .20614 L
.31057 .20611 L
.31305 .20609 L
.31577 .20608 L
.32065 .20606 L
.32332 .20605 L
.32582 .20604 L
.33028 .20603 L
.33279 .20603 L
.33507 .20602 L
.34011 .20602 L
.34265 .20602 L
.34546 .20602 L
.34785 .20602 L
.35042 .20601 L
.35508 .20601 L
.35773 .20601 L
.36062 .20601 L
.36364 .20601 L
.36645 .20601 L
.36909 .20601 L
.37149 .20601 L
.37426 .20601 L
.37687 .20601 L
.37938 .20601 L
.38172 .20601 L
Mistroke
.3843 .20601 L
.38706 .20601 L
.38996 .20601 L
.3927 .20601 L
.39517 .20601 L
.39786 .20601 L
.40041 .20601 L
.40273 .20601 L
.40539 .20601 L
.40791 .20601 L
.41024 .20601 L
.41239 .20601 L
.41474 .20601 L
.41723 .20601 L
.41991 .20601 L
.42244 .20601 L
.42472 .20601 L
.42719 .20601 L
.42988 .20601 L
.43124 .20601 L
.43274 .20601 L
.43538 .20601 L
.43787 .20601 L
.44022 .20601 L
.4427 .20601 L
.44482 .20601 L
.44713 .20601 L
.44964 .20601 L
.45104 .20601 L
.45231 .20601 L
.45478 .20601 L
.45712 .20601 L
.45964 .20601 L
.46199 .20601 L
.46334 .20601 L
.46457 .20601 L
.46601 .20601 L
.46734 .20601 L
.46999 .20601 L
.4714 .20601 L
.47289 .20601 L
.47431 .20601 L
.47565 .20601 L
.47684 .20601 L
.47815 .20601 L
.48052 .20601 L
.48181 .20601 L
.48301 .20601 L
.48516 .20601 L
.48747 .20601 L
Mistroke
.48877 .20601 L
.49018 .20601 L
.49142 .20601 L
.49274 .20601 L
.49392 .20601 L
.49523 .20601 L
.49753 .20601 L
.49888 .20601 L
.50014 .20601 L
.50163 .20601 L
.50298 .20601 L
.50549 .20601 L
.50687 .20601 L
.50817 .20601 L
.50935 .20601 L
.5106 .20601 L
.51284 .20601 L
.51409 .20601 L
.51525 .20601 L
.5179 .20601 L
.51926 .20601 L
.52074 .20601 L
.52205 .20601 L
.52343 .20601 L
.52468 .20601 L
.52605 .20601 L
.52848 .20601 L
.52995 .20601 L
.53129 .20601 L
.53277 .20601 L
.53433 .20601 L
.53569 .20601 L
.53695 .20601 L
.53834 .20601 L
.53982 .20601 L
.54111 .20601 L
.54254 .20601 L
.54402 .20601 L
.54541 .20601 L
.54669 .20601 L
.5479 .20601 L
.54929 .20601 L
.55057 .20601 L
.55197 .20601 L
.55346 .20601 L
.55487 .20601 L
.55614 .20601 L
.55765 .20601 L
.55928 .20601 L
.56081 .20601 L
Mistroke
.56222 .20601 L
.56345 .20601 L
.56476 .20601 L
.5659 .20601 L
.56713 .20601 L
.56858 .20601 L
.56995 .20601 L
.57128 .20601 L
.57252 .20601 L
.57381 .20601 L
.57502 .20601 L
.57635 .20601 L
.57779 .20601 L
.57921 .20601 L
.58071 .20601 L
.58198 .20601 L
.58338 .20601 L
.58477 .20601 L
.58605 .20601 L
.58746 .20601 L
.58894 .20601 L
.59024 .20601 L
.59144 .20601 L
.59277 .20601 L
.59419 .20601 L
.59545 .20601 L
.59682 .20601 L
.59812 .20601 L
.59932 .20601 L
.6004 .20601 L
.60159 .20601 L
.60283 .20601 L
.604 .20601 L
.60528 .20601 L
.60669 .20601 L
.60816 .20601 L
.60952 .20601 L
.6108 .20601 L
.61197 .20601 L
.61331 .20601 L
.61459 .20601 L
.61597 .20601 L
.61744 .20601 L
.61869 .20601 L
.62007 .20601 L
.62154 .20601 L
.62314 .20601 L
.62464 .20601 L
.62601 .20601 L
.62736 .20601 L
Mistroke
.62864 .20601 L
.62978 .20601 L
.63102 .20601 L
.63237 .20601 L
.6338 .20601 L
.63501 .20601 L
.63635 .20601 L
.63761 .20601 L
.63875 .20601 L
.64007 .20601 L
.64132 .20601 L
.64247 .20601 L
.64354 .20601 L
.64471 .20601 L
.64595 .20601 L
.64729 .20601 L
.64852 .20601 L
.64987 .20601 L
.65129 .20601 L
.65253 .20601 L
.65368 .20601 L
.65494 .20601 L
.6563 .20601 L
.65777 .20601 L
.65861 .20601 L
.65937 .20601 L
.66078 .20601 L
.66228 .20601 L
.66362 .20601 L
.66487 .20601 L
.66624 .20601 L
.66771 .20601 L
.66912 .20601 L
.67039 .20601 L
.67185 .20601 L
.67324 .20601 L
.67452 .20601 L
.6757 .20601 L
.67699 .20601 L
.67835 .20601 L
.67974 .20601 L
.6805 .20601 L
.68122 .20601 L
.68262 .20601 L
.68389 .20601 L
.68462 .20601 L
.6854 .20601 L
.68679 .20601 L
.68757 .20601 L
.6883 .20601 L
Mistroke
.68916 .20601 L
.68995 .20601 L
.69125 .20601 L
.69267 .20601 L
.69392 .20601 L
.69526 .20601 L
.69657 .20601 L
.69781 .20601 L
.69892 .20601 L
.70012 .20601 L
.70144 .20601 L
.70289 .20601 L
.70362 .20601 L
.7044 .20601 L
.70508 .20601 L
.70582 .20601 L
.70655 .20601 L
.70722 .20601 L
.70856 .20601 L
.70977 .20601 L
.71106 .20601 L
.71225 .20601 L
.71356 .20601 L
.71492 .20601 L
.71619 .20601 L
.71738 .20601 L
.71846 .20601 L
.71971 .20601 L
.72089 .20601 L
.72217 .20601 L
.72353 .20601 L
.72469 .20601 L
.72597 .20601 L
.72734 .20601 L
.72811 .20601 L
.72882 .20601 L
.73019 .20601 L
.73149 .20601 L
.7327 .20601 L
.73379 .20601 L
.73506 .20601 L
.73625 .20601 L
.73735 .20601 L
.73837 .20601 L
.73949 .20601 L
.74066 .20601 L
.74186 .20601 L
.74313 .20601 L
.74434 .20601 L
.74544 .20601 L
Mistroke
.74673 .20601 L
.74745 .20601 L
.74813 .20601 L
.74936 .20601 L
.75067 .20601 L
.75187 .20601 L
.75318 .20601 L
.75455 .20601 L
.75582 .20601 L
.75701 .20601 L
.75809 .20601 L
.75935 .20601 L
.76053 .20601 L
.76181 .20601 L
.76318 .20601 L
.76434 .20601 L
.76562 .20601 L
.767 .20601 L
.76777 .20601 L
.76847 .20601 L
.76984 .20601 L
.77114 .20601 L
.77235 .20601 L
.77345 .20601 L
.77472 .20601 L
.77591 .20601 L
.77702 .20601 L
.77804 .20601 L
.77915 .20601 L
.78033 .20601 L
.78152 .20601 L
.7828 .20601 L
.78401 .20601 L
.78511 .20601 L
.7864 .20601 L
.78712 .20601 L
.7878 .20601 L
.78903 .20601 L
.79034 .20601 L
.7916 .20601 L
.79299 .20601 L
.79429 .20601 L
.7955 .20601 L
.7967 .20601 L
.79778 .20601 L
.79904 .20601 L
.80022 .20601 L
.80151 .20601 L
.80288 .20601 L
.80404 .20601 L
Mistroke
.80533 .20601 L
.8067 .20601 L
.80748 .20601 L
.80818 .20601 L
.80955 .20601 L
.81085 .20601 L
.81195 .20601 L
.81317 .20601 L
.81444 .20601 L
.81563 .20601 L
.81674 .20601 L
.81776 .20601 L
.81887 .20601 L
.82005 .20601 L
.82125 .20601 L
.82253 .20601 L
.82373 .20601 L
.82483 .20601 L
.82612 .20601 L
.82685 .20601 L
.82752 .20601 L
.82876 .20601 L
.83006 .20601 L
.83133 .20601 L
.83272 .20601 L
.83403 .20601 L
.83524 .20601 L
.83644 .20601 L
.83753 .20601 L
.83879 .20601 L
.83997 .20601 L
.84127 .20601 L
.84263 .20601 L
.8438 .20601 L
.84508 .20601 L
.84647 .20601 L
.84724 .20601 L
.84794 .20601 L
.84931 .20601 L
.85061 .20601 L
.85172 .20601 L
.85294 .20601 L
.85421 .20601 L
.8554 .20601 L
.85651 .20601 L
.85753 .20601 L
.85865 .20601 L
.85983 .20601 L
.86103 .20601 L
.86231 .20601 L
Mistroke
.86352 .20601 L
.86461 .20601 L
.8659 .20601 L
.86663 .20601 L
.8673 .20601 L
.86854 .20601 L
.86984 .20601 L
.87112 .20601 L
.87184 .20601 L
.8725 .20601 L
.87373 .20601 L
.87503 .20601 L
.87619 .20601 L
.87728 .20601 L
.87848 .20601 L
.87977 .20601 L
.88106 .20601 L
.8818 .20601 L
.88248 .20601 L
.88386 .20601 L
.88463 .20601 L
.88533 .20601 L
.88659 .20601 L
.88795 .20601 L
.88924 .20601 L
.89043 .20601 L
.89154 .20601 L
.89273 .20601 L
.89385 .20601 L
.89488 .20601 L
.89608 .20601 L
.89739 .20601 L
.89862 .20601 L
.89977 .20601 L
.90107 .20601 L
.90229 .20601 L
.90338 .20601 L
.90456 .20601 L
.90586 .20601 L
.90722 .20601 L
.90839 .20601 L
.90967 .20601 L
.91104 .20601 L
.91231 .20601 L
.91297 .20601 L
.9137 .20601 L
.91446 .20601 L
.91518 .20601 L
.91649 .20601 L
.91769 .20601 L
Mistroke
.91901 .20601 L
.92039 .20601 L
.92156 .20601 L
.92281 .20601 L
.92399 .20601 L
.92506 .20601 L
.92632 .20601 L
.92769 .20601 L
.92898 .20601 L
.93017 .20601 L
.93143 .20601 L
.93279 .20601 L
.93408 .20601 L
.93525 .20601 L
.93662 .20601 L
.9374 .20601 L
.93812 .20601 L
.93944 .20601 L
.94017 .20601 L
.94084 .20601 L
.94155 .20601 L
.9423 .20601 L
.94364 .20601 L
.94438 .20601 L
.94508 .20601 L
.94584 .20601 L
.94666 .20601 L
.94736 .20601 L
.94813 .20601 L
.94886 .20601 L
.94952 .20601 L
.95079 .20601 L
.95213 .20601 L
.9534 .20601 L
.95477 .20601 L
.95608 .20601 L
.95729 .20601 L
.95848 .20601 L
.95957 .20601 L
.96082 .20601 L
.96201 .20601 L
.9633 .20601 L
.96466 .20601 L
.96583 .20601 L
.96711 .20601 L
.96849 .20601 L
.96926 .20601 L
.96996 .20601 L
.97133 .20601 L
.97263 .20601 L
Mistroke
.97373 .20601 L
.97495 .20601 L
.97622 .20601 L
.97741 .20601 L
.97852 .20601 L
.97954 .20601 L
.98065 .20601 L
.98183 .20601 L
.98303 .20601 L
.98431 .20601 L
.98551 .20601 L
.98661 .20601 L
.9879 .20601 L
.98863 .20601 L
.9893 .20601 L
.99053 .20601 L
.99184 .20601 L
.9929 .20601 L
.99387 .20601 L
.99499 .20601 L
.99606 .20601 L
.99703 .20601 L
.99794 .20601 L
.99894 .20601 L
1 .20601 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13039,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo00?ooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooo
oom5ooooo`001Ol00002ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Gooooo00?o
0000ooooooooool0oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo00Co
A4A4omgMgOoooooo00001_ooool3o`000?ooooooAOooool000Oooooo00Go0000oooooooooooooooo
o`00000;ooooo`04omgMgOmEEEGoooooo`0000Kooooo00?o0000ooooooooool0oooooom5ooooo`00
1oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001_ooool00ol0003o
ooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^ko
A4A4o`000006ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Gooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool5o`0000Gooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool00ol0003oooooooooo`3oooooodGooooo0005o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0oooooom5ooooo`001ooo
ool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01Oooool3o`000?oooooo
AOooool000Oooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Cooooo
00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0?ooooo`Oo0000ooooool_ooooo`001ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4005ooooo`03
o`000?oooooooooo00cooooo1?l00005ooooo`;o0000ooooool^ooooo`001oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c005ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`3oooooob_ooooo000Qooooo`03
o`000?oooooooooo00Wooooo0_l0000=ooooo`03o`000?oooooooooo0?oooooo:_ooool0027ooooo
0_l00007ooooo`?o00004?ooool00ol0003oooooooooo`3oooooobWooooo000Qooooo`03o`000?oo
oooooooo00Cooooo0_l0000Dooooo`03o`000?oooooooooo0?oooooo:?ooool0027ooooo00Co0000
oooooooooooooooo0ol0000Fooooo`03o`000?oooooooooo0?oooooo:?ooool0027ooooo1?l0000J
ooooo`03o`000?oooooooooo0?oooooo9oooool0027ooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`3oooooobKooooo000Qooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool0oooooolUooooo`008Oooool00ol0003oooooooooo`0Mooooo`09o`000?ooooooooooooooooo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?oo
ool01Om4A4Co0000o`000?lb<S;ogMgM01Wooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1Oooool4o`000003oa0@4?oooooooooo01Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1Oooool4o`000005oa0@4?oooooooooooooooom4A4@00_l000000olb<S;ogMgMooooo`0H
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol0000Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oM
gMd0>Oooool0027ooooo0_l0000Oooooo`08o`000?ooooooooooogMgMonHV9SooooooiRHV?mgMgL5
ooooo`;o8B4Q1?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Oooooo00?oMgMgoc8b<_ooool06?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo01Wooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`06ooooo`03
ogMgMolb<S;ooooo01Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnH
V9So8B4Qonk^k_ooooooA4A401[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?oo
ool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool0>?ooool0027ooooo00?o
0000ooooooooool07oooool00ol0003ooooooa0@4003ooooo`03oa0@4?oooooooooo00Wooooo00Go
410@oooooooooooooooooa0@4008ooooo`03o`000?oooooooooo01Oooooo00Go410@oooooooooooo
oooooa0@400>ooooo`03o`000?oooooooooo01Wooooo00Go410@oooooooooooooooooa0@400>oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05oooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h06oooool01Ol@413ooooooooooooooooo410@00cooooo00?o
V9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`0gooooo`008Oooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooooooo
oooo000000Oooooo00?oMgMgoc8b<_ooool06?ooool01Ol0003ooooooooooooooooo000000kooooo
00?o0000ooooooooool06Oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000oooooooo
ool01_ooool00omgMgOo<S8booooo`0Hooooo`05o`000?ooooooooooooooool000003Oooool00onH
V9So8B4Qonk^kP0Jooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP07
ooooo`03ogMgMolb<S;ooooo03Sooooo000Qooooo`03o`000?oooooooooo023ooooo0_l00003oooo
o`03o`000?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`06Oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool0
6Oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool00oooool01Ol0003o
8B4Qo`000?lb<S;oc<c<01Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKo
oooo01Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c00iooooo`008Oooool00ol0003oooooooooo`0Pooooo`03o`000?l@
413ooooo00;ooooo00?o410@ooooooooool02Oooool01Ol@413ooooooooooooooooo410@00Cooooo
00?o0000ooooooooool06oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000oooooooo
ool06Oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Kooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`0H
ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo03_ooooo000Qooooo`03o`000?oooooooooo027ooooo00Go0000oiRHV?ooooooV9RHogMg
M`0;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00ol0003oooooooooo`0Kooooo`05ogMg
MonHV9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`0Iooooo`05ogMgMonHV9SooooooiRH
V?mgMgL03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01_ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41006_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo03_o
oooo000Qooooo`;o00008_ooool01Oo^k^ko0000o`000?lb<S;ok^k^00_ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP04ooooo`Co00006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEE
ofIVI_l000006oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l000001Ooo
ool4o`0001[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`06_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004
ooooo`Co0000>_ooool0027ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`3ooooo
ob3ooooo000Qooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0oooooolOooooo`00
8Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo0?oooooo5?ooool00ol@413o0000
o`000003o`0000Gooooo000Qooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0oooo
oolEooooo`03o`000?oooooooooo00Kooooo000Qooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0oooooolDooooo`03o`000?oooooooooo00Kooooo000Qoooooooo0000<ol0000<oooo
o`03o`000?oooooooooo00Kooooo000Qooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo0_l00008ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`Oo
00002Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool05?ooool00ol0003o<S8bomgMg@06ooooo`008Oooool00ol0003oooooooooo`0Wooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool04oooool3o`0001[ooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
>oooool2o`000004ojVYZOlQ8B7o0000ob4Q8@Cooooo000Qooooo`03o`000?oooooooooo02Sooooo
00?o0000ooooooooool06?ooool3o`000?kooooo000Qooooo`03o`000?oooooooooo02Wooooo00?o
0000ooooooooool05Oooool2o`000?oooooo0_ooool0027ooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`0Booooo`;o0000ooooool4ooooo`008Oooool2o`0002_ooooo00?o0000oooo
ooooool04?ooool2o`000?oooooo1_ooool0027ooooo00?o0000ooooooooool0:oooool2o`0000ko
oooo0_l0003oooooo`Sooooo000Qooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0
2Oooool2o`000?oooooo2_ooool0027ooooo00?o0000ooooooooool0;_ooool2o`0000Oooooo0_l0
003oooooo`cooooo000Qooooo`03o`000?oooooooooo033ooooo1ol0003oooooo`kooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
1oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001Oooool00ol0003o
ooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`03o`000?oooooooooo0?ooooooAOooool000Oo
oooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003ooooo
odGooooo0007ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP05oooo
o`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413o
oooooooooooooooo410@00oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3ooooo
odGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So
410@00Gooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c005ooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo0_l0003oooooodKooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go00001Oooool3o`000?ooooooAOooool000Oooooo00Go0000oooooooo
ooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Kooooo00?o0000ooooooooool0oooooom5
ooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001_oo
ool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00omgMgOoc<c<o`000006ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Kooooo00?o0000ooooooooool0oooo
oom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo0_l0003oooooodKooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000
oa0@4?o<c<`01Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@05ooooo`03o`000?oo
oooooooo0?ooooooAOooool000Oooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oo
ooooooooooooool000001Oooool3o`000?ooooooAOooool000Oooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401Oooool00ol0003oooooooooo`3oooooodGo
oooo0007ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<
00Gooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@
00_ooooo00?oEEEEohN7Qoooool01oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV007ooooo`03o`000?oooooooooo
0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000
oa0@40Gooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo0_l0003oooooodKooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co
8B4Qo`000?lQ8B7oc<c<00Gooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401Oooool0
0ol0003oooooooooo`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41002oooool0
1Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P05ooooo`?o0000
oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o
0000olc<c005ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go410@oooooooooooo
oooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@41001Oooool00ol0003oooooooooo`3ooooo
odGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o
000000Gooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@05ooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Hooooo`Co000000?o410@oooooooo
ool00_ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool0
01[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001Sooooo00?oEEEEofIVI_l00000oooo
oom>ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00W_ooool01OnHV9So0000
o`000?m4A4Co^[Zj01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_l000000ol@413oooooooooo`2>ooooo`007oooool01?l@
413o0000o`000?l0001kooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000Wooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Ko
oooo00?o0000ooooooooool0Soooool0023ooooo00?o0000ooooooooool0Noooool00ol0003ooooo
ooooo`0Jooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@
00?ooooo1Ol0002@ooooo`008?ooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo00_o
oooo1_l00009ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooooooooooo
000000?ooooo00CoA4A4omgMgOoooooo0000TOooool0023ooooo00Ko0000ogMgMol0003o0000oeEE
EOo^k^ihooooo`03o`000?oooooooooo01[ooooo00Go0000ooooooooooooooooo`00000;ooooo`05
o`000?ooooooooooooooool000000oooool01?oMgMgoEEEEooooool0002Aooooo`008?ooool01_l0
003oEEEEonk^k_ooooooMgMgoeEEEGKooooo00?o410@o`000?l000000ol0000Iooooo`05oa0@4?oo
ooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00Cooooo00?oMgMgolc<c?l0
0000TOooool0023ooooo00?o0000onk^k_ooool00_ooool00ol0003oooooooooo`1fooooo`03o`00
0?oooooooooo01[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01?ooool00oo^k^koA4A4o`00002Aooooo`008?ooool00ol0003ok^k^ooooo`02ooooo`03
o`000?oooooooooo07Kooooo00?o0000ooooooooool06_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03ogMgMol0003ooooo093ooooo000Poooo
o`06o`000?mEEEGok^k^oooooomgMgOoIVIVoooooom3ooooo`007oooool00ol@413o0000ogMgM`02
o`000003ofIVI_o^k^kooooo0?oooooo@_ooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.0332543, -0.540631, \
0.00122928, 0.00994506}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 3.33333 0.206011 0.412023 [
[.16667 .19351 -12 -9 ]
[.16667 .19351 12 0 ]
[.33333 .19351 -9 -9 ]
[.33333 .19351 9 0 ]
[.5 .19351 -12 -9 ]
[.5 .19351 12 0 ]
[.66667 .19351 -9 -9 ]
[.66667 .19351 9 0 ]
[.83333 .19351 -12 -9 ]
[.83333 .19351 12 0 ]
[1.025 .20601 0 -6 ]
[1.025 .20601 10 6 ]
[-0.0125 .0412 -24 -4.5 ]
[-0.0125 .0412 0 4.5 ]
[-0.0125 .12361 -24 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .28842 -18 -4.5 ]
[-0.0125 .28842 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .45322 -18 -4.5 ]
[-0.0125 .45322 0 4.5 ]
[-0.0125 .53563 -18 -4.5 ]
[-0.0125 .53563 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 .20601 m
.16667 .21226 L
s
[(0.05)] .16667 .19351 0 1 Mshowa
.33333 .20601 m
.33333 .21226 L
s
[(0.1)] .33333 .19351 0 1 Mshowa
.5 .20601 m
.5 .21226 L
s
[(0.15)] .5 .19351 0 1 Mshowa
.66667 .20601 m
.66667 .21226 L
s
[(0.2)] .66667 .19351 0 1 Mshowa
.83333 .20601 m
.83333 .21226 L
s
[(0.25)] .83333 .19351 0 1 Mshowa
.125 Mabswid
.03333 .20601 m
.03333 .20976 L
s
.06667 .20601 m
.06667 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.13333 .20601 m
.13333 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.23333 .20601 m
.23333 .20976 L
s
.26667 .20601 m
.26667 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.36667 .20601 m
.36667 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.43333 .20601 m
.43333 .20976 L
s
.46667 .20601 m
.46667 .20976 L
s
.53333 .20601 m
.53333 .20976 L
s
.56667 .20601 m
.56667 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.63333 .20601 m
.63333 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.73333 .20601 m
.73333 .20976 L
s
.76667 .20601 m
.76667 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.86667 .20601 m
.86667 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.93333 .20601 m
.93333 .20976 L
s
.96667 .20601 m
.96667 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
gsave
1.025 .20601 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .0412 m
.00625 .0412 L
s
[(-0.4)] -0.0125 .0412 1 0 Mshowa
0 .12361 m
.00625 .12361 L
s
[(-0.2)] -0.0125 .12361 1 0 Mshowa
0 .28842 m
.00625 .28842 L
s
[(0.2)] -0.0125 .28842 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.4)] -0.0125 .37082 1 0 Mshowa
0 .45322 m
.00625 .45322 L
s
[(0.6)] -0.0125 .45322 1 0 Mshowa
0 .53563 m
.00625 .53563 L
s
[(0.8)] -0.0125 .53563 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .10301 m
.00375 .10301 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .30902 m
.00375 .30902 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .39142 m
.00375 .39142 L
s
0 .41202 m
.00375 .41202 L
s
0 .43262 m
.00375 .43262 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .51503 m
.00375 .51503 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
0 .0206 m
.00375 .0206 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.05) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .19686 m
.00123 .19686 L
.00236 .19684 L
.00365 .1968 L
.00488 .19674 L
.00706 .19661 L
.00942 .19642 L
.01203 .19613 L
.01479 .19575 L
.01975 .19487 L
.02486 .19369 L
.02966 .19231 L
.04057 .18819 L
.0517 .18262 L
.06188 .17653 L
.07377 .1688 L
.08481 .16198 L
.08978 .15936 L
.09446 .15729 L
.09705 .15635 L
.09985 .15552 L
.10109 .15523 L
.1024 .15496 L
.1036 .15476 L
.10474 .15462 L
.1061 .15449 L
.10733 .15444 L
.10866 .15443 L
.10941 .15445 L
.11011 .15449 L
.11126 .15459 L
.11254 .15476 L
.11387 .15499 L
.11512 .15528 L
.11798 .15614 L
.1206 .15719 L
.1265 .16051 L
.13148 .16428 L
.1368 .16921 L
.14637 .17998 L
.16811 .20778 L
.17886 .2196 L
.18453 .22457 L
.19052 .22871 L
.19576 .23132 L
.19874 .23239 L
.20017 .2328 L
.20153 .23312 L
.20275 .23337 L
.20409 .23358 L
Mistroke
.2053 .23372 L
.20642 .23381 L
.20776 .23388 L
.20897 .23389 L
.20964 .23388 L
.21037 .23386 L
.21168 .23378 L
.21299 .23366 L
.21418 .23351 L
.21686 .23306 L
.21934 .23251 L
.22169 .23189 L
.23266 .22795 L
.25479 .21843 L
.26495 .21471 L
.27574 .21162 L
.28494 .20968 L
.29018 .20884 L
.29509 .2082 L
.30046 .20765 L
.30544 .20724 L
.31064 .20691 L
.31632 .20664 L
.32126 .20647 L
.32573 .20635 L
.3309 .20625 L
.33577 .20618 L
.34064 .20613 L
.34341 .20611 L
.346 .20609 L
.35122 .20606 L
.35415 .20605 L
.35682 .20604 L
.36159 .20603 L
.36428 .20603 L
.36678 .20603 L
.37135 .20602 L
.37366 .20602 L
.37621 .20602 L
.37888 .20602 L
.38136 .20601 L
.38395 .20601 L
.38679 .20601 L
.39148 .20601 L
.39411 .20601 L
.3965 .20601 L
.39931 .20601 L
.4019 .20601 L
.40474 .20601 L
.40776 .20601 L
Mistroke
.41037 .20601 L
.41282 .20601 L
.4155 .20601 L
.41839 .20601 L
.42106 .20601 L
.4239 .20601 L
.42658 .20601 L
.42901 .20601 L
.43188 .20601 L
.43498 .20601 L
.43791 .20601 L
.4406 .20601 L
.44313 .20601 L
.44549 .20601 L
.44808 .20601 L
.45086 .20601 L
.45226 .20601 L
.45377 .20601 L
.45653 .20601 L
.45921 .20601 L
.4617 .20601 L
.46424 .20601 L
.46657 .20601 L
.46912 .20601 L
.47182 .20601 L
.47417 .20601 L
.47635 .20601 L
.47875 .20601 L
.48131 .20601 L
.48277 .20601 L
.48411 .20601 L
.48556 .20601 L
.48714 .20601 L
.48982 .20601 L
.49128 .20601 L
.49265 .20601 L
.49398 .20601 L
.49524 .20601 L
.49762 .20601 L
.49894 .20601 L
.50017 .20601 L
.50295 .20601 L
.50431 .20601 L
.50574 .20601 L
.5083 .20601 L
.50973 .20601 L
.51106 .20601 L
.51261 .20601 L
.51408 .20601 L
.51535 .20601 L
Mistroke
.51673 .20601 L
.51914 .20601 L
.52051 .20601 L
.52196 .20601 L
.52331 .20601 L
.52455 .20601 L
.52687 .20601 L
.52814 .20601 L
.52936 .20601 L
.53151 .20601 L
.53273 .20601 L
.53386 .20601 L
.5352 .20601 L
.53646 .20601 L
.53882 .20601 L
.54014 .20601 L
.54136 .20601 L
.54277 .20601 L
.54411 .20601 L
.54534 .20601 L
.54669 .20601 L
.54904 .20601 L
.55037 .20601 L
.55178 .20601 L
.55301 .20601 L
.55433 .20601 L
.55554 .20601 L
.55666 .20601 L
.55886 .20601 L
.56002 .20601 L
.5613 .20601 L
.56253 .20601 L
.56387 .20601 L
.56533 .20601 L
.56671 .20601 L
.56794 .20601 L
.5693 .20601 L
.57076 .20601 L
.57232 .20601 L
.57376 .20601 L
.5751 .20601 L
.57645 .20601 L
.57773 .20601 L
.58014 .20601 L
.58149 .20601 L
.58273 .20601 L
.5841 .20601 L
.58556 .20601 L
.58687 .20601 L
.5883 .20601 L
Mistroke
.5898 .20601 L
.5912 .20601 L
.59251 .20601 L
.5937 .20601 L
.59508 .20601 L
.59638 .20601 L
.59779 .20601 L
.59929 .20601 L
.60057 .20601 L
.60198 .20601 L
.6035 .20601 L
.60513 .20601 L
.60666 .20601 L
.60807 .20601 L
.60931 .20601 L
.61063 .20601 L
.61188 .20601 L
.61301 .20601 L
.61434 .20601 L
.61578 .20601 L
.61715 .20601 L
.6184 .20601 L
.6197 .20601 L
.62091 .20601 L
.62225 .20601 L
.62368 .20601 L
.62518 .20601 L
.6266 .20601 L
.62787 .20601 L
.62926 .20601 L
.63053 .20601 L
.6317 .20601 L
.63299 .20601 L
.63434 .20601 L
.63552 .20601 L
.63661 .20601 L
.63782 .20601 L
.63911 .20601 L
.64051 .20601 L
.64204 .20601 L
.64348 .20601 L
.64481 .20601 L
.646 .20601 L
.64732 .20601 L
.6487 .20601 L
.64999 .20601 L
.65135 .20601 L
.65283 .20601 L
.65424 .20601 L
.65554 .20601 L
Mistroke
.65683 .20601 L
.65799 .20601 L
.65934 .20601 L
.66061 .20601 L
.662 .20601 L
.66347 .20601 L
.66472 .20601 L
.6661 .20601 L
.66758 .20601 L
.66917 .20601 L
.67067 .20601 L
.67204 .20601 L
.67327 .20601 L
.67444 .20601 L
.67571 .20601 L
.67709 .20601 L
.67845 .20601 L
.67988 .20601 L
.68111 .20601 L
.68245 .20601 L
.68371 .20601 L
.68486 .20601 L
.68619 .20601 L
.68744 .20601 L
.6886 .20601 L
.68967 .20601 L
.69084 .20601 L
.69208 .20601 L
.69343 .20601 L
.69467 .20601 L
.69609 .20601 L
.69745 .20601 L
.69869 .20601 L
.69985 .20601 L
.70111 .20601 L
.70246 .20601 L
.70395 .20601 L
.70478 .20601 L
.70555 .20601 L
.70696 .20601 L
.70846 .20601 L
.7098 .20601 L
.71104 .20601 L
.71241 .20601 L
.71388 .20601 L
.71517 .20601 L
.71658 .20601 L
.7173 .20601 L
.71806 .20601 L
.71945 .20601 L
Mistroke
.72083 .20601 L
.72214 .20601 L
.72331 .20601 L
.7246 .20601 L
.72538 .20601 L
.72613 .20601 L
.72751 .20601 L
.72829 .20601 L
.72901 .20601 L
.72985 .20601 L
.73063 .20601 L
.73193 .20601 L
.73267 .20601 L
.73335 .20601 L
.73474 .20601 L
.73551 .20601 L
.73623 .20601 L
.73744 .20601 L
.73878 .20601 L
.74018 .20601 L
.74149 .20601 L
.74271 .20601 L
.74383 .20601 L
.74506 .20601 L
.74635 .20601 L
.74767 .20601 L
.74841 .20601 L
.74908 .20601 L
.75038 .20601 L
.75162 .20601 L
.75231 .20601 L
.75305 .20601 L
.75438 .20601 L
.75511 .20601 L
.7558 .20601 L
.75663 .20601 L
.75737 .20601 L
.75868 .20601 L
.7594 .20601 L
.76008 .20601 L
.76129 .20601 L
.76259 .20601 L
.76328 .20601 L
.76404 .20601 L
.76477 .20601 L
.76556 .20601 L
.7663 .20601 L
.76697 .20601 L
.76829 .20601 L
.76961 .20601 L
Mistroke
.77084 .20601 L
.77218 .20601 L
.77286 .20601 L
.77361 .20601 L
.77487 .20601 L
.77621 .20601 L
.77749 .20601 L
.77866 .20601 L
.77979 .20601 L
.781 .20601 L
.78215 .20601 L
.78319 .20601 L
.78441 .20601 L
.78573 .20601 L
.78698 .20601 L
.78814 .20601 L
.78933 .20601 L
.79045 .20601 L
.79167 .20601 L
.79298 .20601 L
.79436 .20601 L
.79567 .20601 L
.79684 .20601 L
.79811 .20601 L
.7988 .20601 L
.79952 .20601 L
.80081 .20601 L
.8022 .20601 L
.80299 .20601 L
.80372 .20601 L
.80505 .20601 L
.80627 .20601 L
.80694 .20601 L
.80767 .20601 L
.80899 .20601 L
.81017 .20601 L
.81147 .20601 L
.81283 .20601 L
.81411 .20601 L
.8153 .20601 L
.81638 .20601 L
.81764 .20601 L
.81883 .20601 L
.82022 .20601 L
.82148 .20601 L
.82217 .20601 L
.82293 .20601 L
.8243 .20601 L
.82558 .20601 L
.82694 .20601 L
Mistroke
.8281 .20601 L
.82937 .20601 L
.83014 .20601 L
.83087 .20601 L
.83224 .20601 L
.83301 .20601 L
.83372 .20601 L
.83454 .20601 L
.83532 .20601 L
.8366 .20601 L
.83728 .20601 L
.83801 .20601 L
.83874 .20601 L
.83951 .20601 L
.84087 .20601 L
.84217 .20601 L
.8429 .20601 L
.84357 .20601 L
.84481 .20601 L
.84612 .20601 L
.8473 .20601 L
.84839 .20601 L
.8496 .20601 L
.85089 .20601 L
.85227 .20601 L
.85304 .20601 L
.85376 .20601 L
.85508 .20601 L
.85582 .20601 L
.85649 .20601 L
.85775 .20601 L
.85912 .20601 L
.86041 .20601 L
.8616 .20601 L
.86272 .20601 L
.86392 .20601 L
.86505 .20601 L
.86607 .20601 L
.86728 .20601 L
.8686 .20601 L
.86984 .20601 L
.87098 .20601 L
.87216 .20601 L
.87327 .20601 L
.87448 .20601 L
.87579 .20601 L
.87708 .20601 L
.87845 .20601 L
.87961 .20601 L
.88088 .20601 L
Mistroke
.88156 .20601 L
.88227 .20601 L
.88356 .20601 L
.88493 .20601 L
.88572 .20601 L
.88645 .20601 L
.88777 .20601 L
.88898 .20601 L
.88965 .20601 L
.89037 .20601 L
.8917 .20601 L
.89287 .20601 L
.89417 .20601 L
.89552 .20601 L
.89679 .20601 L
.89798 .20601 L
.89906 .20601 L
.90025 .20601 L
.90151 .20601 L
.90289 .20601 L
.90414 .20601 L
.90483 .20601 L
.90559 .20601 L
.90695 .20601 L
.90823 .20601 L
.90959 .20601 L
.91074 .20601 L
.91202 .20601 L
.91278 .20601 L
.91351 .20601 L
.91488 .20601 L
.91564 .20601 L
.91635 .20601 L
.91713 .20601 L
.91796 .20601 L
.91868 .20601 L
.91946 .20601 L
.9202 .20601 L
.92088 .20601 L
.92216 .20601 L
.92352 .20601 L
.9248 .20601 L
.92553 .20601 L
.9262 .20601 L
.92743 .20601 L
.92873 .20601 L
.9299 .20601 L
.93099 .20601 L
.93219 .20601 L
.93348 .20601 L
Mistroke
.93478 .20601 L
.93551 .20601 L
.93619 .20601 L
.93758 .20601 L
.93835 .20601 L
.93905 .20601 L
.94031 .20601 L
.94168 .20601 L
.94297 .20601 L
.94415 .20601 L
.94526 .20601 L
.94646 .20601 L
.94758 .20601 L
.94861 .20601 L
.94981 .20601 L
.95112 .20601 L
.95236 .20601 L
.95351 .20601 L
.95481 .20601 L
.95603 .20601 L
.95712 .20601 L
.9583 .20601 L
.9596 .20601 L
.96096 .20601 L
.96213 .20601 L
.96341 .20601 L
.96459 .20601 L
.96569 .20601 L
.96689 .20601 L
.96816 .20601 L
.96927 .20601 L
.9703 .20601 L
.97144 .20601 L
.97266 .20601 L
.97374 .20601 L
.97492 .20601 L
.97603 .20601 L
.97706 .20601 L
.97808 .20601 L
.97901 .20601 L
.98008 .20601 L
.98108 .20601 L
.98218 .20601 L
.98338 .20601 L
.98464 .20601 L
.98581 .20601 L
.98691 .20601 L
.98792 .20601 L
.98907 .20601 L
.99017 .20601 L
Mistroke
.99135 .20601 L
.99261 .20601 L
.99369 .20601 L
.99488 .20601 L
.99615 .20601 L
.99752 .20601 L
.99881 .20601 L
1 .20601 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13039,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo00?ooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooo
oom5ooooo`001Ol00002ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Gooooo00?o
0000ooooooooool0oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo00Co
A4A4omgMgOoooooo00001_ooool3o`000?ooooooAOooool000Oooooo00Go0000oooooooooooooooo
o`00000;ooooo`04omgMgOmEEEGoooooo`0000Kooooo00?o0000ooooooooool0oooooom5ooooo`00
1oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001_ooool00ol0003o
ooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^ko
A4A4o`000006ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Gooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool5o`0000Gooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool00ol0003oooooooooo`3oooooodGooooo0005o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0oooooom5ooooo`001ooo
ool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01Oooool3o`000?oooooo
AOooool000Oooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Cooooo
00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Gooooo00?o0000oooooooo
ool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c005ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
01gooooo1?l0003oooooobCooooo000Qooooo`03o`000?oooooooooo01[ooooo1?l00002ooooo`Co
0000oooooolQooooo`008Oooool00ol0003oooooooooo`0Hooooo`;o00002_ooool00ol0003ooooo
ooooo`3ooooooakooooo000Qooooo`03o`000?oooooooooo01Kooooo0_l00009ooooo`05onk^k_lb
<S;o0000oc8b<_l000001Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`05
odA4A?l0003o0000oc8b<_oMgMd06Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45
ooooo`Co000000?o410@ooooooooool05oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B45ooooo`Co000000Go410@ooooooooooooooooodA4A002o`000003oc8b<_oMgMgooooo01Sooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0001[ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@0i
ooooo`008Oooool2o`0001Kooooo00?o0000ooooooooool02Oooool01_mgMgOoV9RHoooooonHV9So
MgMgo`0000Cooooo0_lQ8B44ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01oooool00omgMgOo<S8b
ooooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooooooo
ool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo
00Kooooo00?oMgMgoc8b<_ooool06?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@06_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8booooo`0hooooo`00
8Oooool00ol0003oooooooooo`0Cooooo`;o00003?ooool01ol@413ooooooooooooooooo410@oooo
ool000002Oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool05oooool0
1Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool06Oooool01Ol@413ooooooooo
oooooooo410@00kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Gooooo`05oa0@
4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Kooooo`05oa0@4?oooooooooooooo
ool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo03Oooooo000Qooooo`03
o`000?oooooooooo017ooooo0_l0000>ooooo`05o`000?ooooooooooooooool000000_ooool00ol0
003oooooooooo`06ooooo`05o`000?ooooooooooooooool000001oooool00omgMgOo<S8booooo`0H
ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003oooooooooo`0Iooooo`05o`000?oo
ooooooooooooool000003_ooool00ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo01Sooooo
00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01[ooooo00Go0000oooooooo
ooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool0>?ooool0027o
oooo00?o0000ooooooooool03oooool2o`00013ooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`06Oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool0
6Oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool00oooool01Ol0003o
8B4Qo`000?lb<S;oc<c<01Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKo
oooo01Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c00iooooo`008Oooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo013ooooo00Go410@oooooooooooooooooa0@4004ooooo`03o`000?oooooooooo00Cooooo
00Go410@oooooooooooooooooa0@4004ooooo`03o`000?oooooooooo01_ooooo00Go410@oooooooo
oooooooooa0@400>ooooo`03o`000?oooooooooo01Wooooo00Go410@oooooooooooooooooa0@400>
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool06oooool01Ol@413ooooooooooooo
oooo410@00oooooo00?o0000ooooooooool06?ooool01Ol@413ooooooooooooooooo410@00oooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0kooooo`008Oooool00ol0003ooooooooo
o`0<ooooo`;o00004oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo00?o0000ooooooooool0
1?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo00?o0000ooooooooool06oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00kooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9So
MgMg00kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Kooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@01[ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`0koooo
o`008Oooool2o`0000cooooo00?o0000ooooooooool04oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo00?o0000ooooooooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo1?l0000J
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool00omEEEGoIVIVo`00000Kooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool00omEEEGoIVIVo`000005ooooo`Co00006_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Jooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l0000jooooo`008Oooool0
0ol0003oooooooooo`08ooooo`?o00008Oooool00ol0003oooooooooo`3ooooooaKooooo000Qoooo
o`03o`000?oooooooooo00Cooooo1?l0000Uooooo`03o`000?oooooooooo0?oooooo5Oooool0027o
oooo1ol0000Zooooo`03o`000?oooooooooo0?oooooo2Oooool00ol@413o0000o`000003o`0000Go
oooo000Qooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0ooooool;ooooo`03o`00
0?oooooooooo00Kooooo000Qooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0oooo
ool:ooooo`03o`000?oooooooooo00Kooooo000Qoooooooo0000<ol0000<ooooo`03o`000?oooooo
oooo00Kooooo000Qooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool2o`00
00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`04o`000?oooooooooo
ooooo`Oo00002Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Cooooo00?o0000
oc8b<_oMgMd01_ooool0027ooooo00?o0000ooooooooool0<?ooool00ol0003oooooo`00000Moooo
o`?o00004?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo033ooooo00?o0000oooo
ooooool0<?ooool00ol0003oooooooooo`0kooooo`;o000000CoZJVYob4Q8Ol0003o8B4Q1?ooool0
027ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Gooooo`?o0000m?ooool0027o
oooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Cooooo`?o0000moooool0027ooooo
00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0?ooooo`?o0000n_ooool0027ooooo0_l0
000gooooo`03o`000?oooooooooo00cooooo0_l0003mooooo`008Oooool00ol0003oooooooooo`0g
ooooo`;o00002_ooool2o`000?oooooo000Qooooo`03o`000?oooooooooo03Wooooo1?l00002oooo
o`Co0000ooooool2ooooo`008Oooool00ol0003oooooooooo`0looooo`?o0000ooooool6ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B44ooooo`Go00001Oooool00ol0003oooooooooo`3oooooodGooooo0007oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4
A005ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go410@oooooooooooooooooa0@
400<ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003oooooodGooooo0007ooooo`05o`000?oooooo
ooooooooool000003Oooool00onHV9So8B4Qonk^kP05ooooo`03o`000?oooooooooo0?ooooooAOoo
ool000Oooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Cooooo00?o
0000ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00oooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Gooooo00?o0000ooooooooool0
oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c005ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l0
00000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo0?ooooooAOooool000Oooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00001Ooo
ool3o`000?ooooooAOooool000Oooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oM
gMgoooooo`0000Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol0003ooooooooo
oooooooo000000_ooooo00CogMgMoeEEEOoooooo00001_ooool00ol0003oooooooooo`3oooooodGo
oooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000006ooooo`03
o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03
onk^k_m4A4Co000000Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01Oooool00ol0003ooooo
ooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo
00GoEEEEogMgMoooooooV9RHob4Q8@05ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo
00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001Oooool3o`00
0?ooooooAOooool000Oooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9Sooooo
oiRHV?lQ8B401Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05o`000?oooooooooo
ooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Gooooo00?o0000ooooooooool0oooo
oom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool01ooo
ool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool00ooMgMgo410@oiRHV007ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Gooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003ooooo
odKooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool2o`000?oo
ooooA_ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Gooooo00?o
0000ooooooooool0oooooom5ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401Oooool00ol0003oooooooooo`3oooooodGooooo
0007ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Go
oooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000_o
oooo00Go<S8boiRHV?ooooooV9RHoc8b<P05ooooo`?o0000oooooom5ooooo`001oooool01Ol0003o
oooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c005ooooo`03o`000?oooooo
oooo0?ooooooAOooool000Oooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[o
oooookZj^_l@41001Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Gooooo00?o0000ooooooooool0
oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@05ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3o
ooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo
00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo
0?ooooooC?ooool001Sooooo00?oEEEEofIVI_l00000oooooom>ooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00W_ooool01OnHV9So0000o`000?m4A4Co^[Zj01Sooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo
00GoA4A4o`000?l0003o<S8bomgMg@2?ooooo`007oooool01?l@413o0000o`000?l0001kooooo`05
oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Oooooo00?oMgMgoc8b<_ooool0S_oo
ool0023ooooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`0Jooooo`05oa0@4?oooooo
ooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool0
SOooool0023ooooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`0;ooooo`Ko00002Ooo
ool01Ol0003ooooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000007ooooo`03
ogMgMolb<S;ooooo08kooooo000Pooooo`06o`000?mgMgOo0000o`000?mEEEGok^k^N?ooool00ol0
003oooooooooo`0Jooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooooooo
oooo000000Cooooo00Go0000ob4Q8Ol0003o<S8bolc<c02?ooooo`008?ooool01_l0003oEEEEonk^
k_ooooooMgMgoeEEEGKooooo00?o410@o`000?l000000ol0000Iooooo`05oa0@4?oooooooooooooo
ool@41002oooool01Ol@413ooooooooooooooooo410@00Cooooo00?o0000ooooooooool0TOooool0
023ooooo00?o0000onk^k_ooool00_ooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo
01[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?oo
ool00ol0003oooooooooo`2Aooooo`008?ooool00ol0003ok^k^ooooo`02ooooo`03o`000?oooooo
oooo07Kooooo00?o0000ooooooooool06_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP04ooooo`Co0000T?ooool0023ooooo00Ko0000oeEEEOo^k^kooooo
ogMgMomVIVKooooood?ooooo000Oooooo`03oa0@4?l0003oMgMg00;o000000?oIVIVonk^k_ooool0
oooooom2ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.0332543, -0.540631, \
0.00122928, 0.00994506}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 3.33333 0.206011 0.412023 [
[.16667 .19351 -12 -9 ]
[.16667 .19351 12 0 ]
[.33333 .19351 -9 -9 ]
[.33333 .19351 9 0 ]
[.5 .19351 -12 -9 ]
[.5 .19351 12 0 ]
[.66667 .19351 -9 -9 ]
[.66667 .19351 9 0 ]
[.83333 .19351 -12 -9 ]
[.83333 .19351 12 0 ]
[1.025 .20601 0 -6 ]
[1.025 .20601 10 6 ]
[-0.0125 .0412 -24 -4.5 ]
[-0.0125 .0412 0 4.5 ]
[-0.0125 .12361 -24 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .28842 -18 -4.5 ]
[-0.0125 .28842 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .45322 -18 -4.5 ]
[-0.0125 .45322 0 4.5 ]
[-0.0125 .53563 -18 -4.5 ]
[-0.0125 .53563 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 .20601 m
.16667 .21226 L
s
[(0.05)] .16667 .19351 0 1 Mshowa
.33333 .20601 m
.33333 .21226 L
s
[(0.1)] .33333 .19351 0 1 Mshowa
.5 .20601 m
.5 .21226 L
s
[(0.15)] .5 .19351 0 1 Mshowa
.66667 .20601 m
.66667 .21226 L
s
[(0.2)] .66667 .19351 0 1 Mshowa
.83333 .20601 m
.83333 .21226 L
s
[(0.25)] .83333 .19351 0 1 Mshowa
.125 Mabswid
.03333 .20601 m
.03333 .20976 L
s
.06667 .20601 m
.06667 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.13333 .20601 m
.13333 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.23333 .20601 m
.23333 .20976 L
s
.26667 .20601 m
.26667 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.36667 .20601 m
.36667 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.43333 .20601 m
.43333 .20976 L
s
.46667 .20601 m
.46667 .20976 L
s
.53333 .20601 m
.53333 .20976 L
s
.56667 .20601 m
.56667 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.63333 .20601 m
.63333 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.73333 .20601 m
.73333 .20976 L
s
.76667 .20601 m
.76667 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.86667 .20601 m
.86667 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.93333 .20601 m
.93333 .20976 L
s
.96667 .20601 m
.96667 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
gsave
1.025 .20601 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .0412 m
.00625 .0412 L
s
[(-0.4)] -0.0125 .0412 1 0 Mshowa
0 .12361 m
.00625 .12361 L
s
[(-0.2)] -0.0125 .12361 1 0 Mshowa
0 .28842 m
.00625 .28842 L
s
[(0.2)] -0.0125 .28842 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.4)] -0.0125 .37082 1 0 Mshowa
0 .45322 m
.00625 .45322 L
s
[(0.6)] -0.0125 .45322 1 0 Mshowa
0 .53563 m
.00625 .53563 L
s
[(0.8)] -0.0125 .53563 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .10301 m
.00375 .10301 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .30902 m
.00375 .30902 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .39142 m
.00375 .39142 L
s
0 .41202 m
.00375 .41202 L
s
0 .43262 m
.00375 .43262 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .51503 m
.00375 .51503 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
0 .0206 m
.00375 .0206 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.06) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .20515 m
.00123 .20515 L
.00236 .20514 L
.00365 .20514 L
.00488 .20513 L
.00706 .2051 L
.00942 .20507 L
.01203 .20502 L
.01479 .20496 L
.01975 .2048 L
.02486 .20457 L
.02966 .20429 L
.03491 .2039 L
.04057 .20336 L
.04623 .20266 L
.05241 .2017 L
.06367 .19928 L
.07463 .19593 L
.08481 .19188 L
.10455 .1818 L
.11493 .17609 L
.12589 .17076 L
.13148 .16868 L
.13465 .16776 L
.13616 .1674 L
.1376 .16711 L
.13891 .16689 L
.14032 .1667 L
.14161 .16657 L
.1428 .16649 L
.14409 .16645 L
.14482 .16645 L
.14551 .16646 L
.14689 .16652 L
.14766 .16659 L
.14838 .16666 L
.14961 .16682 L
.15093 .16705 L
.1533 .16759 L
.15613 .16847 L
.15869 .16948 L
.16428 .1724 L
.16956 .17598 L
.19057 .19602 L
.20995 .21556 L
.21485 .21956 L
.22012 .22321 L
.2251 .22595 L
.22965 .22783 L
.23241 .22869 L
Mistroke
.23497 .2293 L
.23644 .22956 L
.23777 .22975 L
.23852 .22984 L
.23932 .22991 L
.24007 .22997 L
.24076 .23001 L
.24203 .23005 L
.24321 .23006 L
.24451 .23003 L
.2459 .22995 L
.2466 .22989 L
.24736 .22982 L
.24874 .22967 L
.25132 .22927 L
.25378 .22879 L
.25643 .22816 L
.26121 .22679 L
.27212 .22295 L
.28267 .21896 L
.2942 .21497 L
.3044 .2121 L
.31528 .2098 L
.3213 .20885 L
.32677 .20816 L
.33196 .20764 L
.33745 .20721 L
.34245 .2069 L
.34796 .20665 L
.35296 .20647 L
.35763 .20635 L
.36314 .20624 L
.36817 .20617 L
.37095 .20614 L
.37398 .20612 L
.37663 .2061 L
.37948 .20608 L
.38213 .20607 L
.38456 .20606 L
.38934 .20604 L
.39187 .20604 L
.39464 .20603 L
.39756 .20603 L
.40022 .20602 L
.40287 .20602 L
.40574 .20602 L
.40877 .20602 L
.41164 .20602 L
.41432 .20601 L
.41717 .20601 L
Mistroke
.4196 .20601 L
.42227 .20601 L
.42488 .20601 L
.42773 .20601 L
.43042 .20601 L
.43292 .20601 L
.43535 .20601 L
.43764 .20601 L
.44028 .20601 L
.44266 .20601 L
.44533 .20601 L
.44815 .20601 L
.45056 .20601 L
.4532 .20601 L
.45605 .20601 L
.45909 .20601 L
.46197 .20601 L
.46459 .20601 L
.467 .20601 L
.46965 .20601 L
.47241 .20601 L
.47501 .20601 L
.47743 .20601 L
.47965 .20601 L
.48209 .20601 L
.48465 .20601 L
.48726 .20601 L
.49004 .20601 L
.49267 .20601 L
.49506 .20601 L
.49788 .20601 L
.49946 .20601 L
.50092 .20601 L
.50361 .20601 L
.50496 .20601 L
.50645 .20601 L
.50907 .20601 L
.51056 .20601 L
.51193 .20601 L
.51445 .20601 L
.51586 .20601 L
.51713 .20601 L
.51955 .20601 L
.52082 .20601 L
.52216 .20601 L
.52462 .20601 L
.52689 .20601 L
.5295 .20601 L
.53097 .20601 L
.53231 .20601 L
Mistroke
.53355 .20601 L
.5349 .20601 L
.53736 .20601 L
.53873 .20601 L
.54025 .20601 L
.54173 .20601 L
.54332 .20601 L
.54481 .20601 L
.54616 .20601 L
.54754 .20601 L
.54883 .20601 L
.55009 .20601 L
.55145 .20601 L
.55383 .20601 L
.55518 .20601 L
.55661 .20601 L
.55784 .20601 L
.55916 .20601 L
.5604 .20601 L
.56152 .20601 L
.56373 .20601 L
.56497 .20601 L
.56631 .20601 L
.56875 .20601 L
.5701 .20601 L
.57136 .20601 L
.57286 .20601 L
.57423 .20601 L
.57557 .20601 L
.57703 .20601 L
.5785 .20601 L
.58005 .20601 L
.58267 .20601 L
.58414 .20601 L
.58547 .20601 L
.58671 .20601 L
.58806 .20601 L
.59051 .20601 L
.5918 .20601 L
.59298 .20601 L
.59425 .20601 L
.59564 .20601 L
.59692 .20601 L
.5981 .20601 L
.60044 .20601 L
.60187 .20601 L
.60322 .20601 L
.60444 .20601 L
.60573 .20601 L
.60715 .20601 L
Mistroke
.60844 .20601 L
.60984 .20601 L
.61137 .20601 L
.61285 .20601 L
.61426 .20601 L
.61552 .20601 L
.61689 .20601 L
.61838 .20601 L
.61996 .20601 L
.62131 .20601 L
.6228 .20601 L
.62418 .20601 L
.62545 .20601 L
.62684 .20601 L
.6283 .20601 L
.62958 .20601 L
.63077 .20601 L
.63207 .20601 L
.63346 .20601 L
.63476 .20601 L
.63619 .20601 L
.63768 .20601 L
.63907 .20601 L
.64037 .20601 L
.64156 .20601 L
.64294 .20601 L
.64424 .20601 L
.64564 .20601 L
.64714 .20601 L
.64841 .20601 L
.64982 .20601 L
.65133 .20601 L
.65296 .20601 L
.6545 .20601 L
.65591 .20601 L
.65714 .20601 L
.65845 .20601 L
.6597 .20601 L
.66083 .20601 L
.66215 .20601 L
.6636 .20601 L
.66496 .20601 L
.66621 .20601 L
.66751 .20601 L
.66872 .20601 L
.67006 .20601 L
.67149 .20601 L
.67298 .20601 L
.67441 .20601 L
.67568 .20601 L
Mistroke
.67708 .20601 L
.67847 .20601 L
.67976 .20601 L
.68117 .20601 L
.68266 .20601 L
.68395 .20601 L
.68516 .20601 L
.68649 .20601 L
.68791 .20601 L
.68918 .20601 L
.69055 .20601 L
.69185 .20601 L
.69305 .20601 L
.69413 .20601 L
.69533 .20601 L
.69657 .20601 L
.69774 .20601 L
.69903 .20601 L
.70043 .20601 L
.7019 .20601 L
.70327 .20601 L
.70455 .20601 L
.70572 .20601 L
.70707 .20601 L
.70834 .20601 L
.70972 .20601 L
.71119 .20601 L
.71244 .20601 L
.71382 .20601 L
.7153 .20601 L
.71613 .20601 L
.71689 .20601 L
.71836 .20601 L
.71976 .20601 L
.72107 .20601 L
.72249 .20601 L
.72383 .20601 L
.72506 .20601 L
.72618 .20601 L
.7274 .20601 L
.72867 .20601 L
.72986 .20601 L
.73126 .20601 L
.73258 .20601 L
.73376 .20601 L
.73505 .20601 L
.73645 .20601 L
.73794 .20601 L
.73921 .20601 L
.74061 .20601 L
Mistroke
.74189 .20601 L
.74311 .20601 L
.74421 .20601 L
.74541 .20601 L
.74671 .20601 L
.74809 .20601 L
.74939 .20601 L
.75058 .20601 L
.75178 .20601 L
.75289 .20601 L
.75411 .20601 L
.75539 .20601 L
.75651 .20601 L
.75755 .20601 L
.7587 .20601 L
.75993 .20601 L
.7612 .20601 L
.76261 .20601 L
.76332 .20601 L
.76408 .20601 L
.76547 .20601 L
.76677 .20601 L
.76814 .20601 L
.76931 .20601 L
.7706 .20601 L
.77138 .20601 L
.77212 .20601 L
.7735 .20601 L
.77428 .20601 L
.77499 .20601 L
.77583 .20601 L
.77661 .20601 L
.7779 .20601 L
.77865 .20601 L
.77933 .20601 L
.78072 .20601 L
.78148 .20601 L
.78221 .20601 L
.78354 .20601 L
.78475 .20601 L
.78542 .20601 L
.78614 .20601 L
.78745 .20601 L
.78868 .20601 L
.78998 .20601 L
.79109 .20601 L
.79231 .20601 L
.79305 .20601 L
.79375 .20601 L
.79506 .20601 L
Mistroke
.7958 .20601 L
.79648 .20601 L
.79727 .20601 L
.79801 .20601 L
.79924 .20601 L
.80059 .20601 L
.80191 .20601 L
.80265 .20601 L
.80333 .20601 L
.80468 .20601 L
.80594 .20601 L
.80708 .20601 L
.80832 .20601 L
.80966 .20601 L
.81034 .20601 L
.81109 .20601 L
.81241 .20601 L
.81364 .20601 L
.81488 .20601 L
.81605 .20601 L
.81711 .20601 L
.81826 .20601 L
.81951 .20601 L
.82084 .20601 L
.82209 .20601 L
.82322 .20601 L
.82459 .20601 L
.82528 .20601 L
.82603 .20601 L
.82737 .20601 L
.82861 .20601 L
.82937 .20601 L
.83008 .20601 L
.83142 .20601 L
.83217 .20601 L
.83286 .20601 L
.83362 .20601 L
.83443 .20601 L
.83569 .20601 L
.83686 .20601 L
.83758 .20601 L
.83826 .20601 L
.83954 .20601 L
.84089 .20601 L
.84214 .20601 L
.8435 .20601 L
.84427 .20601 L
.84497 .20601 L
.84623 .20601 L
.8474 .20601 L
Mistroke
.8487 .20601 L
.85008 .20601 L
.85078 .20601 L
.85153 .20601 L
.85291 .20601 L
.85425 .20601 L
.85549 .20601 L
.85664 .20601 L
.85772 .20601 L
.8589 .20601 L
.86018 .20601 L
.86145 .20601 L
.86278 .20601 L
.86392 .20601 L
.86517 .20601 L
.86588 .20601 L
.86665 .20601 L
.86732 .20601 L
.86804 .20601 L
.86939 .20601 L
.87064 .20601 L
.87134 .20601 L
.87208 .20601 L
.87343 .20601 L
.87425 .20601 L
.87503 .20601 L
.8758 .20601 L
.87649 .20601 L
.87776 .20601 L
.87911 .20601 L
.88036 .20601 L
.88153 .20601 L
.88291 .20601 L
.88418 .20601 L
.88556 .20601 L
.88626 .20601 L
.88703 .20601 L
.8884 .20601 L
.88968 .20601 L
.89034 .20601 L
.89107 .20601 L
.89184 .20601 L
.89255 .20601 L
.89385 .20601 L
.89453 .20601 L
.89524 .20601 L
.89645 .20601 L
.89777 .20601 L
.89906 .20601 L
.90022 .20601 L
Mistroke
.90157 .20601 L
.90284 .20601 L
.90402 .20601 L
.9051 .20601 L
.90629 .20601 L
.90755 .20601 L
.90892 .20601 L
.91016 .20601 L
.91085 .20601 L
.9116 .20601 L
.91296 .20601 L
.91424 .20601 L
.91559 .20601 L
.91675 .20601 L
.91802 .20601 L
.91875 .20601 L
.91951 .20601 L
.92087 .20601 L
.92164 .20601 L
.92234 .20601 L
.92312 .20601 L
.92395 .20601 L
.92467 .20601 L
.92545 .20601 L
.92614 .20601 L
.92687 .20601 L
.92825 .20601 L
.92953 .20601 L
.93079 .20601 L
.93217 .20601 L
.93348 .20601 L
.93469 .20601 L
.93589 .20601 L
.93698 .20601 L
.93823 .20601 L
.93941 .20601 L
.94071 .20601 L
.94208 .20601 L
.94324 .20601 L
.94452 .20601 L
.9459 .20601 L
.94668 .20601 L
.94738 .20601 L
.94875 .20601 L
.95005 .20601 L
.95115 .20601 L
.95237 .20601 L
.95364 .20601 L
.95483 .20601 L
.95594 .20601 L
Mistroke
.95696 .20601 L
.95808 .20601 L
.95926 .20601 L
.96045 .20601 L
.96173 .20601 L
.96294 .20601 L
.96404 .20601 L
.96533 .20601 L
.96606 .20601 L
.96673 .20601 L
.96796 .20601 L
.96927 .20601 L
.97025 .20601 L
.97132 .20601 L
.97233 .20601 L
.97327 .20601 L
.9742 .20601 L
.97504 .20601 L
.97601 .20601 L
.97693 .20601 L
.97793 .20601 L
.97899 .20601 L
.97989 .20601 L
.98088 .20601 L
.98195 .20601 L
.98309 .20601 L
.98417 .20601 L
.98515 .20601 L
.98607 .20601 L
.98705 .20601 L
.98789 .20601 L
.98881 .20601 L
.9898 .20601 L
.99086 .20601 L
.99186 .20601 L
.99278 .20601 L
.9937 .20601 L
.99455 .20601 L
.99548 .20601 L
.99648 .20601 L
.99743 .20601 L
.99833 .20601 L
.99913 .20601 L
1 .20601 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13039,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo00?ooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooo
oom5ooooo`001Ol00002ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Gooooo00?o
0000ooooooooool0oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo00Co
A4A4omgMgOoooooo00001_ooool3o`000?ooooooAOooool000Oooooo00Go0000oooooooooooooooo
o`00000;ooooo`04omgMgOmEEEGoooooo`0000Kooooo00?o0000ooooooooool0oooooom5ooooo`00
1oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001_ooool00ol0003o
ooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^ko
A4A4o`000006ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Gooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool5o`0000Gooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool00ol0003oooooooooo`3oooooodGooooo0005o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0oooooom5ooooo`001ooo
ool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01Oooool3o`000?oooooo
AOooool000Oooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Cooooo
00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Gooooo00?o0000oooooooo
ool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c005ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo027ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@0Iooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l00000
0ol@413oooooooooo`0Gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l0
00001Ol@413oooooooooooooooooA4A400;o000000?o<S8bomgMgOooool06?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM03Wooooo000Qoooo
o`;o00008_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Oo00001?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Oooooo00?oMgMgoc8b<_ooool06?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B47ooooo`03o`000?oooooooooo01Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1oooool00ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo01Sooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A401[ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo
00?oMgMgoc8b<_ooool0>?ooool0027ooooo00?o0000ooooooooool08Oooool00ol@413oooooo`00
0002o`0000Oooooo0_l00002ooooo`05oa0@4?ooooooooooooooool@41002?ooool00ol0003ooooo
ooooo`0Gooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`0Iooooo`05
oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
01Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^01_ooooo00Go410@
oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool0=ooo
ool0027ooooo00?o0000ooooooooool08Oooool2o`0000;ooooo00?o0000ooooooooool01oooool3
o`0000?ooooo00?o0000ooooooooool01Oooool00omgMgOo<S8booooo`0Hooooo`05o`000?oooooo
ooooooooool000003_ooool00ol0003oooooooooo`0Iooooo`05o`000?ooooooooooooooool00000
3_ooool00ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo01Sooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^01[ooooo00Go0000ooooooooooooooooo`00000=oooo
o`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool0>?ooool0027ooooo00?o0000oooooooo
ool07oooool3o`0000?ooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooooooooooo0000
00Cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00Iooooo`05o`000?ooooooooooooooool000003_oo
ool00ol0003oooooooooo`0Iooooo`05o`000?ooooooooooooooool000003_ooool00ol0003ooooo
ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`06Oooool01Ol0003ooooooooooooooooo0000
00kooooo00?oMgMgofIVI_ooool06Oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMg
ofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<03Wooooo000Qooooo`03o`000?oooooo
oooo01kooooo00Co0000oooooooooooo410@0oooool00ol@413oooooooooo`09ooooo`05oa0@4?l0
003oooooooooool@41001?ooool00ol0003oooooooooo`0Kooooo`05oa0@4?ooooooooooooooool@
41003_ooool00ol0003oooooooooo`0Iooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo01_ooooo00Go410@oooooooooooooooooa0@400?
ooooo`03o`000?oooooooooo01Sooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0>oooool0027ooooo00?o0000ooooooooool07?ooool2
o`0000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05ogMgMonHV9So0000oiRHV?mgMgL0
1?ooool00ol0003oooooooooo`0Kooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool00ol0003o
ooooooooo`0Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo01_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooooiRHV?l@41006_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo
V9RHoa0@4004ooooo`03o`000?oooooooooo03_ooooo000Qooooo`;o00006oooool2o`0000Gooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05onk^k_lb<S;o0000o`000?o^k^h01?ooool4o`00
01[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`03oeEEEOmVIVKo000001_ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`03oeEEEOmVIVKo000000Gooooo1?l0000Jooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<01[ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0003[ooooo000Qoooo
o`03o`000?oooooooooo01Sooooo0_l0000Kooooo`03o`000?oooooooooo0?oooooo3Oooool0027o
oooo00?o0000ooooooooool05_ooool2o`0001kooooo00?o0000ooooooooool0ooooool<ooooo`00
8Oooool00ol0003oooooooooo`0Cooooo`?o00008Oooool00ol0003oooooooooo`3oooooo`03oa0@
4?l0003o000000?o00001Oooool0027ooooo00?o0000ooooooooool03oooool4o`0002Gooooo00?o
0000ooooooooool0ooooool1ooooo`03o`000?oooooooooo00Kooooo000Qooooo`03o`000?oooooo
oooo00Oooooo2?l0000Zooooo`03o`000?oooooooooo0?oooooo00?o0000ooooooooool01_ooool0
027oooooool0000co`0000cooooo00?o0000ooooooooool01_ooool0027ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo0_l00008ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08o`0000Wo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool05?ooool00ol0003o<S8bomgMg@06ooooo`008Oooool00ol0003ooooo
ooooo`0`ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool06_ooool3o`0000Oooooo
00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool0>oooool2o`000004ojVYZOlQ8B7o0000ob4Q8@Cooooo000Qooooo`03o`00
0?oooooooooo03gooooo0_l0000Gooooo`?o0000joooool0027ooooo00?o0000ooooooooool0?ooo
ool00ol0003oooooooooo`0@ooooo`Co0000k_ooool0027ooooo00?o0000ooooooooool0@?ooool2
o`0000gooooo0ol0003booooo`008Oooool2o`0004?ooooo00?o0000ooooooooool02?ooool2o`00
0?Gooooo000Qooooo`03o`000?oooooooooo04?ooooo2_l0003gooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1?ooool5o`0000Gooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool00ol0
003oooooooooo`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onH
V9So8B4Qonk^kP06ooooo`?o0000oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo0000
00gooooo00?oV9RHob4Q8Oo^k^h01Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05
o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`04ooooo`03o`000?oooooooooo
0?ooooooAOooool000Oooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00_ooooo00Go0000okZj^_ooooooV9RHoa0@4005ooooo`03o`000?oooooooooo0?ooooooAOooool0
00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@oooo
ooooool00oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3ooooo
odGooooo0007ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Gooooo0ol0003ooooo
odGooooo0007ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool00006
ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go0000ooooooooooooooooo`00000;
ooooo`04omgMgOmEEEGoooooo`0000Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001_ooool00ol0003ooooooooo
o`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`00
0006ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0=ooooo`03ogMgMol0003ooooo00Gooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Gooooo00?o0000ooooooooool0oooooom5
ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOo
oooooiRHV?lQ8B401Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05oa0@4?oooooo
ooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Gooooo0ol0003oooooodGooooo
0007ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Go
oooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000_o
oooo00Go0000oeEEEOl0003o410@olc<c005ooooo`03o`000?oooooooooo0?ooooooAOooool000Oo
oooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo00Oooooo00?o0000oooo
ooooool0oooooom5ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@
4?nHV9P01oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4105ooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c005ooooo`03o`000?oooooooooo
0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ
8B7oV9RHoooooonHV9So8B4Q00Gooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@
413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oo
oooooooo0?ooooooAOooool000Oooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nH
V9SooooooiRHV?lb<S801Oooool3o`000?ooooooAOooool000Oooooo00Go0000oooooooooooooooo
o`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`01Oooool00ol0003oooooooooo`3oooooodGo
oooo0007ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@
00Gooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00_ooooo00Go0000okZj^_oooooo^[Zjo`000005ooooo`03o`000?oooooooooo0?ooooooAOooool0
00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo0_l0003oooooodKooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`006?ooool4o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool0oooooom5ooooo`00
6_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooo
oooo00Cooooo0ol0003oooooodGooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Hooooo`03oeEEEOmVIVKo00000?ooooooC_ooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool009kooooo00GoV9RHo`000?l0003oA4A4okZj^P0Hooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o
0000oa0@4?o<c<`0T?ooool001oooooo00Co410@o`000?l0003o0000Noooool01Ol@413o^[Zjonk^
k_mgMgOo410@00Wooooo1_l00009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40T?ooool0
023ooooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`0Jooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go0000oooooooooooooooo
o`00002@ooooo`008?ooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo00_ooooo1_l0
0009ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooooooooooo000000?o
oooo00Go0000oiRHV?ooooooV9RHob4Q8@2@ooooo`008?ooool01_l0003oMgMgo`000?l0003oEEEE
onk^kWSooooo00?o0000ooooooooool06_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0T?ooool0023ooooo
00Ko0000oeEEEOo^k^koooooogMgMomEEEEfooooo`03oa0@4?l0003o000000?o00006Oooool01Ol@
413ooooooooooooooooo410@00_ooooo00Go410@oooooooooooooooooa0@4003ooooo`03oeEEEOn7
QhOooooo09;ooooo000Pooooo`03o`000?o^k^kooooo00;ooooo00?o0000ooooooooool0M_ooool0
0ol0003oooooooooo`0Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00?ooooo00?ogMgMoa0@4?nHV9P0T_ooool0023ooooo00?o0000onk^k_ooool00_oo
ool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo01[ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool01?o<c<coA4A4o`000?l@412@oooo
o`008?ooool01_l0003oEEEEonk^k_ooooooMgMgofIVI_oooooo@oooool001oooooo00?o410@o`00
0?mgMgL00_l000000omVIVKok^k^ooooo`3ooooood;ooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.0332543, -0.540631, \
0.00122928, 0.00994506}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 3.33333 0.206011 0.412023 [
[.16667 .19351 -12 -9 ]
[.16667 .19351 12 0 ]
[.33333 .19351 -9 -9 ]
[.33333 .19351 9 0 ]
[.5 .19351 -12 -9 ]
[.5 .19351 12 0 ]
[.66667 .19351 -9 -9 ]
[.66667 .19351 9 0 ]
[.83333 .19351 -12 -9 ]
[.83333 .19351 12 0 ]
[1.025 .20601 0 -6 ]
[1.025 .20601 10 6 ]
[-0.0125 .0412 -24 -4.5 ]
[-0.0125 .0412 0 4.5 ]
[-0.0125 .12361 -24 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .28842 -18 -4.5 ]
[-0.0125 .28842 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .45322 -18 -4.5 ]
[-0.0125 .45322 0 4.5 ]
[-0.0125 .53563 -18 -4.5 ]
[-0.0125 .53563 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 .20601 m
.16667 .21226 L
s
[(0.05)] .16667 .19351 0 1 Mshowa
.33333 .20601 m
.33333 .21226 L
s
[(0.1)] .33333 .19351 0 1 Mshowa
.5 .20601 m
.5 .21226 L
s
[(0.15)] .5 .19351 0 1 Mshowa
.66667 .20601 m
.66667 .21226 L
s
[(0.2)] .66667 .19351 0 1 Mshowa
.83333 .20601 m
.83333 .21226 L
s
[(0.25)] .83333 .19351 0 1 Mshowa
.125 Mabswid
.03333 .20601 m
.03333 .20976 L
s
.06667 .20601 m
.06667 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.13333 .20601 m
.13333 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.23333 .20601 m
.23333 .20976 L
s
.26667 .20601 m
.26667 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.36667 .20601 m
.36667 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.43333 .20601 m
.43333 .20976 L
s
.46667 .20601 m
.46667 .20976 L
s
.53333 .20601 m
.53333 .20976 L
s
.56667 .20601 m
.56667 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.63333 .20601 m
.63333 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.73333 .20601 m
.73333 .20976 L
s
.76667 .20601 m
.76667 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.86667 .20601 m
.86667 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.93333 .20601 m
.93333 .20976 L
s
.96667 .20601 m
.96667 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
gsave
1.025 .20601 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .0412 m
.00625 .0412 L
s
[(-0.4)] -0.0125 .0412 1 0 Mshowa
0 .12361 m
.00625 .12361 L
s
[(-0.2)] -0.0125 .12361 1 0 Mshowa
0 .28842 m
.00625 .28842 L
s
[(0.2)] -0.0125 .28842 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.4)] -0.0125 .37082 1 0 Mshowa
0 .45322 m
.00625 .45322 L
s
[(0.6)] -0.0125 .45322 1 0 Mshowa
0 .53563 m
.00625 .53563 L
s
[(0.8)] -0.0125 .53563 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .10301 m
.00375 .10301 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .30902 m
.00375 .30902 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .39142 m
.00375 .39142 L
s
0 .41202 m
.00375 .41202 L
s
0 .43262 m
.00375 .43262 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .51503 m
.00375 .51503 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
0 .0206 m
.00375 .0206 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.07) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .20596 m
.00123 .20596 L
.00236 .20596 L
.00365 .20596 L
.00488 .20596 L
.00706 .20596 L
.00942 .20596 L
.01203 .20595 L
.01479 .20595 L
.01975 .20594 L
.02221 .20593 L
.02486 .20591 L
.02966 .20589 L
.03535 .20584 L
.04057 .20578 L
.04619 .2057 L
.05141 .20559 L
.05714 .20542 L
.06325 .20519 L
.06907 .20488 L
.07456 .2045 L
.07948 .20407 L
.08481 .20349 L
.09479 .202 L
.10045 .20088 L
.10574 .19963 L
.11642 .19646 L
.12786 .1921 L
.14866 .18263 L
.15964 .17799 L
.16518 .17612 L
.16837 .17526 L
.17129 .17463 L
.17392 .17421 L
.17524 .17405 L
.17669 .17393 L
.17745 .17388 L
.17814 .17385 L
.17894 .17383 L
.1797 .17382 L
.18104 .17385 L
.1818 .17388 L
.1825 .17393 L
.18376 .17404 L
.18493 .17418 L
.18761 .17464 L
.19022 .17528 L
.19302 .17616 L
.19841 .17845 L
.20353 .18131 L
Mistroke
.21313 .1882 L
.2342 .20678 L
.24338 .21432 L
.25329 .22085 L
.25884 .22355 L
.26128 .2245 L
.26395 .22536 L
.26631 .22598 L
.26883 .2265 L
.27023 .22672 L
.2715 .22688 L
.27278 .227 L
.27398 .22709 L
.27525 .22714 L
.27597 .22715 L
.27665 .22716 L
.27801 .22714 L
.27877 .22711 L
.27947 .22708 L
.28065 .227 L
.28195 .22688 L
.28455 .22656 L
.28742 .22608 L
.29049 .22545 L
.29602 .22403 L
.31697 .21728 L
.32799 .21393 L
.33965 .21108 L
.35007 .20921 L
.356 .20842 L
.36153 .20782 L
.36652 .20739 L
.37125 .20707 L
.37671 .20678 L
.38168 .20658 L
.38649 .20643 L
.3918 .2063 L
.39735 .20621 L
.40256 .20615 L
.40741 .20611 L
.41186 .20608 L
.41675 .20606 L
.4192 .20605 L
.42189 .20604 L
.42455 .20604 L
.42743 .20603 L
.42997 .20603 L
.43267 .20602 L
.43509 .20602 L
.43776 .20602 L
Mistroke
.44246 .20602 L
.44532 .20602 L
.44793 .20601 L
.45095 .20601 L
.45382 .20601 L
.45645 .20601 L
.4589 .20601 L
.46159 .20601 L
.46445 .20601 L
.46719 .20601 L
.47008 .20601 L
.47255 .20601 L
.47526 .20601 L
.47818 .20601 L
.48131 .20601 L
.48426 .20601 L
.48695 .20601 L
.48966 .20601 L
.49216 .20601 L
.49491 .20601 L
.49783 .20601 L
.50036 .20601 L
.50273 .20601 L
.50533 .20601 L
.50813 .20601 L
.51065 .20601 L
.51334 .20601 L
.51588 .20601 L
.51819 .20601 L
.52091 .20601 L
.52234 .20601 L
.52385 .20601 L
.52663 .20601 L
.52919 .20601 L
.53182 .20601 L
.5333 .20601 L
.53464 .20601 L
.53726 .20601 L
.53974 .20601 L
.54114 .20601 L
.54263 .20601 L
.5453 .20601 L
.54694 .20601 L
.54847 .20601 L
.54986 .20601 L
.55135 .20601 L
.55389 .20601 L
.55626 .20601 L
.55771 .20601 L
.55908 .20601 L
Mistroke
.56164 .20601 L
.56295 .20601 L
.56434 .20601 L
.56684 .20601 L
.56823 .20601 L
.56953 .20601 L
.57094 .20601 L
.57249 .20601 L
.57379 .20601 L
.57499 .20601 L
.57737 .20601 L
.57953 .20601 L
.58184 .20601 L
.58315 .20601 L
.58456 .20601 L
.5858 .20601 L
.58712 .20601 L
.58831 .20601 L
.58961 .20601 L
.5919 .20601 L
.59327 .20601 L
.59454 .20601 L
.5959 .20601 L
.5974 .20601 L
.59993 .20601 L
.60131 .20601 L
.60261 .20601 L
.60381 .20601 L
.60506 .20601 L
.60731 .20601 L
.60856 .20601 L
.60973 .20601 L
.61238 .20601 L
.61375 .20601 L
.61524 .20601 L
.61655 .20601 L
.61794 .20601 L
.61919 .20601 L
.62057 .20601 L
.62299 .20601 L
.62447 .20601 L
.62582 .20601 L
.62737 .20601 L
.62885 .20601 L
.63021 .20601 L
.63148 .20601 L
.63286 .20601 L
.63434 .20601 L
.63564 .20601 L
.63708 .20601 L
Mistroke
.63858 .20601 L
.63997 .20601 L
.64126 .20601 L
.64248 .20601 L
.64388 .20601 L
.64516 .20601 L
.64657 .20601 L
.64807 .20601 L
.64935 .20601 L
.65076 .20601 L
.65227 .20601 L
.6539 .20601 L
.65544 .20601 L
.65685 .20601 L
.65809 .20601 L
.65941 .20601 L
.66055 .20601 L
.66179 .20601 L
.66324 .20601 L
.66461 .20601 L
.66595 .20601 L
.66718 .20601 L
.66848 .20601 L
.66969 .20601 L
.67103 .20601 L
.67246 .20601 L
.67395 .20601 L
.67537 .20601 L
.67665 .20601 L
.67804 .20601 L
.67931 .20601 L
.68048 .20601 L
.68176 .20601 L
.68312 .20601 L
.68429 .20601 L
.68539 .20601 L
.6866 .20601 L
.68789 .20601 L
.68929 .20601 L
.69082 .20601 L
.69226 .20601 L
.69358 .20601 L
.69478 .20601 L
.6961 .20601 L
.69748 .20601 L
.69877 .20601 L
.70013 .20601 L
.70161 .20601 L
.70301 .20601 L
.70432 .20601 L
Mistroke
.7056 .20601 L
.70677 .20601 L
.70812 .20601 L
.70939 .20601 L
.71078 .20601 L
.71225 .20601 L
.7135 .20601 L
.71488 .20601 L
.71636 .20601 L
.71795 .20601 L
.71945 .20601 L
.72081 .20601 L
.72205 .20601 L
.72321 .20601 L
.72449 .20601 L
.72586 .20601 L
.72723 .20601 L
.72866 .20601 L
.72989 .20601 L
.73123 .20601 L
.73249 .20601 L
.73364 .20601 L
.73497 .20601 L
.73622 .20601 L
.73738 .20601 L
.73844 .20601 L
.73962 .20601 L
.74086 .20601 L
.74221 .20601 L
.74345 .20601 L
.74487 .20601 L
.74622 .20601 L
.74747 .20601 L
.74862 .20601 L
.74989 .20601 L
.75124 .20601 L
.75273 .20601 L
.75356 .20601 L
.75433 .20601 L
.75574 .20601 L
.75723 .20601 L
.75857 .20601 L
.75982 .20601 L
.76119 .20601 L
.76266 .20601 L
.76394 .20601 L
.76536 .20601 L
.76684 .20601 L
.76823 .20601 L
.76952 .20601 L
Mistroke
.77071 .20601 L
.77207 .20601 L
.77337 .20601 L
.77477 .20601 L
.77626 .20601 L
.77766 .20601 L
.77893 .20601 L
.78044 .20601 L
.78128 .20601 L
.78206 .20601 L
.78349 .20601 L
.78422 .20601 L
.78501 .20601 L
.78643 .20601 L
.78777 .20601 L
.78897 .20601 L
.79028 .20601 L
.79171 .20601 L
.79243 .20601 L
.79322 .20601 L
.79462 .20601 L
.79594 .20601 L
.79719 .20601 L
.7985 .20601 L
.79962 .20601 L
.80085 .20601 L
.80218 .20601 L
.80291 .20601 L
.8036 .20601 L
.80493 .20601 L
.80615 .20601 L
.80736 .20601 L
.80866 .20601 L
.80988 .20601 L
.811 .20601 L
.81231 .20601 L
.81306 .20601 L
.81374 .20601 L
.815 .20601 L
.81635 .20601 L
.81708 .20601 L
.81775 .20601 L
.81847 .20601 L
.81926 .20601 L
.8206 .20601 L
.82133 .20601 L
.82201 .20601 L
.82331 .20601 L
.82449 .20601 L
.82585 .20601 L
Mistroke
.82715 .20601 L
.82826 .20601 L
.82948 .20601 L
.83077 .20601 L
.83197 .20601 L
.83309 .20601 L
.83411 .20601 L
.83524 .20601 L
.83643 .20601 L
.83763 .20601 L
.83892 .20601 L
.84014 .20601 L
.84125 .20601 L
.84255 .20601 L
.84328 .20601 L
.84396 .20601 L
.8452 .20601 L
.84651 .20601 L
.84779 .20601 L
.84918 .20601 L
.85049 .20601 L
.8517 .20601 L
.85291 .20601 L
.854 .20601 L
.85525 .20601 L
.85644 .20601 L
.85774 .20601 L
.85911 .20601 L
.86028 .20601 L
.86156 .20601 L
.86294 .20601 L
.86372 .20601 L
.86442 .20601 L
.86579 .20601 L
.86709 .20601 L
.8682 .20601 L
.86942 .20601 L
.87069 .20601 L
.87188 .20601 L
.873 .20601 L
.87402 .20601 L
.87519 .20601 L
.87631 .20601 L
.87751 .20601 L
.87879 .20601 L
.88 .20601 L
.8811 .20601 L
.88239 .20601 L
.88312 .20601 L
.88379 .20601 L
Mistroke
.88502 .20601 L
.88633 .20601 L
.88761 .20601 L
.88833 .20601 L
.889 .20601 L
.89023 .20601 L
.89153 .20601 L
.89269 .20601 L
.89378 .20601 L
.89498 .20601 L
.89627 .20601 L
.89757 .20601 L
.8983 .20601 L
.89899 .20601 L
.90036 .20601 L
.90114 .20601 L
.90184 .20601 L
.9031 .20601 L
.90446 .20601 L
.90575 .20601 L
.90694 .20601 L
.90805 .20601 L
.90924 .20601 L
.91037 .20601 L
.91139 .20601 L
.9126 .20601 L
.91391 .20601 L
.91514 .20601 L
.91629 .20601 L
.91759 .20601 L
.91881 .20601 L
.9199 .20601 L
.92109 .20601 L
.92238 .20601 L
.92375 .20601 L
.92491 .20601 L
.92619 .20601 L
.92757 .20601 L
.92884 .20601 L
.9295 .20601 L
.93023 .20601 L
.931 .20601 L
.93171 .20601 L
.93301 .20601 L
.93369 .20601 L
.9344 .20601 L
.93561 .20601 L
.93693 .20601 L
.93822 .20601 L
.93938 .20601 L
Mistroke
.94073 .20601 L
.942 .20601 L
.94318 .20601 L
.94426 .20601 L
.94545 .20601 L
.94671 .20601 L
.94808 .20601 L
.94932 .20601 L
.95001 .20601 L
.95076 .20601 L
.95213 .20601 L
.9534 .20601 L
.95475 .20601 L
.95591 .20601 L
.95718 .20601 L
.95791 .20601 L
.95867 .20601 L
.96004 .20601 L
.9608 .20601 L
.9615 .20601 L
.96228 .20601 L
.96311 .20601 L
.96383 .20601 L
.96461 .20601 L
.96535 .20601 L
.96603 .20601 L
.96732 .20601 L
.96869 .20601 L
.96968 .20601 L
.97077 .20601 L
.9718 .20601 L
.97276 .20601 L
.9737 .20601 L
.97456 .20601 L
.97555 .20601 L
.97648 .20601 L
.9775 .20601 L
.97858 .20601 L
.97949 .20601 L
.9805 .20601 L
.98159 .20601 L
.98276 .20601 L
.98385 .20601 L
.98486 .20601 L
.9858 .20601 L
.98679 .20601 L
.98764 .20601 L
.98858 .20601 L
.98959 .20601 L
.99067 .20601 L
Mistroke
.9917 .20601 L
.99263 .20601 L
.99352 .20601 L
.99435 .20601 L
.99526 .20601 L
.99622 .20601 L
.99724 .20601 L
.9982 .20601 L
.99907 .20601 L
1 .20601 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13039,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo00?ooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooo
oom5ooooo`001Ol00002ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Gooooo00?o
0000ooooooooool0oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo00Co
A4A4omgMgOoooooo00001_ooool3o`000?ooooooAOooool000Oooooo00Go0000oooooooooooooooo
o`00000;ooooo`04omgMgOmEEEGoooooo`0000Kooooo00?o0000ooooooooool0oooooom5ooooo`00
1oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001_ooool00ol0003o
ooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^ko
A4A4o`000006ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Gooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool5o`0000Gooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool00ol0003oooooooooo`3oooooodGooooo0005o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0oooooom5ooooo`001ooo
ool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01Oooool3o`000?oooooo
AOooool000Oooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Cooooo
00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Gooooo00?o0000oooooooo
ool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c005ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo027ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@0Iooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l00000
0ol@413oooooooooo`0Gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l0
00001Ol@413oooooooooooooooooA4A400;o000000?o<S8bomgMgOooool06?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM03Wooooo000Qoooo
o`;o00008_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01oooool00omgMgOo<S8booooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B47ooooo`03o`000?oooooooooo00Kooooo00?oMgMgoc8b<_ooool06?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@06_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1oooool00omgMgOo<S8booooo`0hooooo`008Oooool00ol0003oooooooooo`0Qooooo`05oa0@4?oo
ooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000oooooooo
ool05oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool06Oooool01Ol@
413ooooooooooooooooo410@00kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0G
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Kooooo`05oa0@4?oo
ooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo03Oooooo
000Qooooo`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`00000;ooooo`Ko0000
1_ooool00omgMgOo<S8booooo`0Hooooo`05o`000?ooooooooooooooool000003_ooool00ol0003o
ooooooooo`0Iooooo`05o`000?ooooooooooooooool000003_ooool00ol0003oooooooooo`06oooo
o`03ogMgMolb<S;ooooo01Sooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7o
k^k^01[ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o
MgMgoc8b<_ooool0>?ooool0027ooooo00?o0000ooooooooool08Oooool01Ol0003ooooooooooooo
oooo000000Wooooo1?l00002ooooo`03o`000?oooooo000000?o000000Co8B4Qo`000?lb<S;oc<c<
6Oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool06Oooool01Ol0003o
oooooooooooooooo000000kooooo00?o0000ooooooooool00oooool01Ol0003o8B4Qo`000?lb<S;o
c<c<01Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo01Wooooo00Go
0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c00iooooo`008Oooool00ol0003oooooooooo`0Qooooo`05oa0@4?ooooooooooooooool@
41001oooool2o`0000;ooooo00Go410@oooooooooooooooooa0@4004ooooo`03o`000?oooooooooo
01_ooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo01Wooooo00Go410@
oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool06ooo
ool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool06?ooool01Ol@413ooooo
oooooooooooo410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0kooooo`00
8Oooool00ol0003oooooooooo`0Qooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool3o`0000Co
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`?o00006oooool01OmgMgOoV9RHoooooonHV9So
MgMg00kooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Kooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2oooool01Ol0003o^[ZjoooooonHV9So410@01[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;oooo
o`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`0kooooo`008Oooool2o`00
02;ooooo00Kok^k^oc8b<_l0003o<S8bonk^k_ooool3o`0000Oooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP04ooooo`Co00006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l0
00006oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l000001Oooool4o`00
01[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`06_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co
0000>_ooool0027ooooo00?o0000ooooooooool09Oooool2o`0001Oooooo0_l0003oooooo`Gooooo
000Qooooo`03o`000?oooooooooo02?ooooo0_l0000Kooooo`03o`000?oooooooooo0?oooooo0_oo
ool0027ooooo00?o0000ooooooooool08?ooool3o`0001kooooo0_l0003fooooo`03oa0@4?l0003o
000000?o00001Oooool0027ooooo00?o0000ooooooooool07Oooool3o`0002?ooooo00?o0000oooo
ooooool0mOooool00ol0003oooooooooo`06ooooo`008Oooool00ol0003oooooooooo`0Eooooo`So
00009oooool00ol0003oooooooooo`3dooooo`03o`000?oooooooooo00Kooooo000Qoooooooo0000
<ol0000<ooooo`03o`000?oooooooooo00Kooooo000Qooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooool000002?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00Co
0000oooooooooooooooo1ol00009ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Dooooo`03o`000?lb<S;ogMgM00Kooooo000Qooooo`03o`000?oo
oooooooo033ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Fooooo`Oo0000;ooo
ool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0>ooo
ool2o`000004ojVYZOlQ8B7o0000ob4Q8@Cooooo000Qooooo`03o`000?oooooooooo04Sooooo0_l0
000Eooooo`03o`000?oooooooooo0>;ooooo000Qooooo`03o`000?oooooooooo04[ooooo00?o0000
ooooooooool04?ooool2o`000>Gooooo000Qooooo`03o`000?oooooooooo04_ooooo0_l0000=oooo
o`?o0000ioooool0027ooooo0_l0001>ooooo`Go000000?oooooo`000?l000001Ol0003Zooooo`00
8Oooool00ol0003oooooooooo`1Aooooo`?o0000l?ooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
1Ol00005ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo00?o0000oooooooo
ool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^
k^h01_ooool3o`000?ooooooAOooool000Oooooo00Go0000ooooooooooooooooo`00000=ooooo`03
oiRHV?lQ8B7ok^k^00Gooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol0003ooooo
oooooooooooo000000kooooo00?oMgMgofIVI_ooool01?ooool00ol0003oooooooooo`3oooooodGo
oooo0007ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41001Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Gooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
0_l0003oooooodKooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00?o
oooo00?o0000ooooooooool0oooooom5ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B47ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`00
1oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00005ooooo`?o0000oooooom5ooooo`00
1oooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00001_ooool00ol0
003oooooooooo`3oooooodGooooo0007ooooo`05o`000?ooooooooooooooool000002oooool01?oM
gMgoEEEEooooool00006ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Kooooo00?o0000ooooooooool0oooooom5
ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001_ooool0
0ol0003oooooooooo`3oooooodGooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool0
0omgMgOo0000ooooo`05ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Co
oooo00Gok^k^oc8b<_l0003o410@olc<c005ooooo`03o`000?oooooooooo0?ooooooAOooool000Oo
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So
8B4Q00Gooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go0000ooooooooooooooooo`000005ooooo`?o0000oooooom5ooooo`001oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@05ooooo`03o`00
0?oooooooooo0?ooooooAOooool000Oooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`00
0?mEEEGo0000oa0@4?o<c<`01Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05oa0@
4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`07ooooo`03o`000?oooooooooo0?oo
ooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Oo
oooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00co
oooo00Coc<c<odA4A?l0003o410@1Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01Oooool00ol0003oooooooooo`3oooooodGo
oooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?oo
ooooV9RHob4Q8@05ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go410@oooooooo
oooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`3o
ooooodGooooo0007ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonH
V9So<S8b00Gooooo0ol0003oooooodGooooo0007ooooo`05o`000?ooooooooooooooool000002ooo
ool01Oo<c<co0000o`000?l0003oc<c<00Gooooo00?o0000ooooooooool0oooooom5ooooo`001ooo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4005ooooo`03
o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooookZj^_l000001Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Gooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o
0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
0_l0003oooooodKooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool001Sooooo
1?l000000ol@413oooooooooo`02ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04oooo
o`?o0000oooooom5ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006?ooool0
0omEEEGoIVIVo`00003oooooodkooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
002Nooooo`05oiRHV?l0003o0000odA4A?nj^[X06?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003ok^k^ooooo`2@oooo
o`007oooool01?l@413o0000o`000?l0001kooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6
o`0000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo00?oEEEEojVYZOooool0T?ooool0023ooooo00?o0000ooooooooool0Nooo
ool00ol0003oooooooooo`0Jooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooo
oooooooooooo410@00Gooooo00?oZJVYoeEEEOooool0T?ooool0023ooooo00?o0000ooooooooool0
Noooool00ol0003oooooooooo`0;ooooo`Ko00002Oooool01Ol0003ooooooooooooooooo000000_o
oooo00Go0000ooooooooooooooooo`000006ooooo`03ob4Q8Ooooooooooo08oooooo000Pooooo`06
o`000?mgMgOo0000o`000?mEEEGok^k^N?ooool00ol0003oooooooooo`0Jooooo`05o`000?oooooo
ooooooooool000002oooool01Ol0003ooooooooooooooooo000000Kooooo00?oEEEEolc<c?ooool0
Soooool0023ooooo00Ko0000oeEEEOo^k^koooooogMgMomEEEEfooooo`03oa0@4?l0003o000000?o
00006Oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@oooooooooooooooooa0@4006
ooooo`03ojVYZOmgMgOooooo08oooooo000Pooooo`03o`000?o^k^kooooo00;ooooo00?o0000oooo
ooooool0M_ooool00ol0003oooooooooo`0Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Go410@oooooooooooooooooc8b<P2@ooooo`008?oo
ool00ol0003ok^k^ooooo`02ooooo`03o`000?oooooooooo07Kooooo00?o0000ooooooooool06_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`Go
0000T?ooool0023ooooo00Ko0000oeEEEOo^k^koooooogMgMomVIVKooooood?ooooo000Oooooo`03
oa0@4?l0003oMgMg00;o000000?oIVIVonk^k_ooool0oooooom2ooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.0332543, -0.540631, \
0.00122928, 0.00994506}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 3.33333 0.206011 0.412023 [
[.16667 .19351 -12 -9 ]
[.16667 .19351 12 0 ]
[.33333 .19351 -9 -9 ]
[.33333 .19351 9 0 ]
[.5 .19351 -12 -9 ]
[.5 .19351 12 0 ]
[.66667 .19351 -9 -9 ]
[.66667 .19351 9 0 ]
[.83333 .19351 -12 -9 ]
[.83333 .19351 12 0 ]
[1.025 .20601 0 -6 ]
[1.025 .20601 10 6 ]
[-0.0125 .0412 -24 -4.5 ]
[-0.0125 .0412 0 4.5 ]
[-0.0125 .12361 -24 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .28842 -18 -4.5 ]
[-0.0125 .28842 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .45322 -18 -4.5 ]
[-0.0125 .45322 0 4.5 ]
[-0.0125 .53563 -18 -4.5 ]
[-0.0125 .53563 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 .20601 m
.16667 .21226 L
s
[(0.05)] .16667 .19351 0 1 Mshowa
.33333 .20601 m
.33333 .21226 L
s
[(0.1)] .33333 .19351 0 1 Mshowa
.5 .20601 m
.5 .21226 L
s
[(0.15)] .5 .19351 0 1 Mshowa
.66667 .20601 m
.66667 .21226 L
s
[(0.2)] .66667 .19351 0 1 Mshowa
.83333 .20601 m
.83333 .21226 L
s
[(0.25)] .83333 .19351 0 1 Mshowa
.125 Mabswid
.03333 .20601 m
.03333 .20976 L
s
.06667 .20601 m
.06667 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.13333 .20601 m
.13333 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.23333 .20601 m
.23333 .20976 L
s
.26667 .20601 m
.26667 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.36667 .20601 m
.36667 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.43333 .20601 m
.43333 .20976 L
s
.46667 .20601 m
.46667 .20976 L
s
.53333 .20601 m
.53333 .20976 L
s
.56667 .20601 m
.56667 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.63333 .20601 m
.63333 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.73333 .20601 m
.73333 .20976 L
s
.76667 .20601 m
.76667 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.86667 .20601 m
.86667 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.93333 .20601 m
.93333 .20976 L
s
.96667 .20601 m
.96667 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
gsave
1.025 .20601 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .0412 m
.00625 .0412 L
s
[(-0.4)] -0.0125 .0412 1 0 Mshowa
0 .12361 m
.00625 .12361 L
s
[(-0.2)] -0.0125 .12361 1 0 Mshowa
0 .28842 m
.00625 .28842 L
s
[(0.2)] -0.0125 .28842 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.4)] -0.0125 .37082 1 0 Mshowa
0 .45322 m
.00625 .45322 L
s
[(0.6)] -0.0125 .45322 1 0 Mshowa
0 .53563 m
.00625 .53563 L
s
[(0.8)] -0.0125 .53563 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .10301 m
.00375 .10301 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .30902 m
.00375 .30902 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .39142 m
.00375 .39142 L
s
0 .41202 m
.00375 .41202 L
s
0 .43262 m
.00375 .43262 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .51503 m
.00375 .51503 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
0 .0206 m
.00375 .0206 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.08) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .20601 m
.00123 .20601 L
.00236 .20601 L
.00365 .20601 L
.00488 .20601 L
.00601 .20601 L
.00706 .20601 L
.00942 .20601 L
.01181 .20601 L
.01444 .20601 L
.01718 .20601 L
.01975 .20601 L
.02243 .20601 L
.02499 .20601 L
.02978 .20601 L
.03245 .206 L
.03494 .206 L
.04057 .206 L
.04334 .206 L
.04635 .20599 L
.049 .20599 L
.0518 .20599 L
.05433 .20598 L
.0571 .20597 L
.06198 .20596 L
.06496 .20594 L
.06768 .20593 L
.0706 .20591 L
.07379 .20589 L
.07945 .20583 L
.08481 .20575 L
.0899 .20565 L
.09468 .20553 L
.09992 .20535 L
.10557 .2051 L
.11118 .20476 L
.11708 .2043 L
.12212 .2038 L
.12763 .20311 L
.13842 .2013 L
.14822 .199 L
.15954 .19555 L
.17022 .19162 L
.18945 .18406 L
.19472 .18226 L
.20038 .18065 L
.20312 .18003 L
.20573 .17955 L
.20806 .17922 L
.20938 .17908 L
Mistroke
.21061 .17897 L
.21192 .1789 L
.21266 .17887 L
.21334 .17885 L
.21459 .17885 L
.21591 .17889 L
.2171 .17895 L
.2182 .17904 L
.21942 .17917 L
.22072 .17934 L
.22361 .17987 L
.22635 .18056 L
.23148 .18231 L
.23698 .18485 L
.24207 .18774 L
.25357 .19578 L
.26383 .2038 L
.27488 .21207 L
.27996 .21541 L
.28531 .21846 L
.29032 .22081 L
.29486 .22248 L
.29714 .22316 L
.29962 .22376 L
.30223 .22425 L
.3034 .22442 L
.30469 .22458 L
.30589 .2247 L
.307 .22478 L
.30818 .22484 L
.30945 .22488 L
.31062 .22489 L
.31174 .22487 L
.31274 .22484 L
.31383 .22478 L
.31511 .22469 L
.31631 .22458 L
.31904 .22426 L
.32171 .22384 L
.32459 .22329 L
.33455 .22083 L
.35516 .21483 L
.36606 .21207 L
.37205 .21081 L
.37771 .20979 L
.38312 .20897 L
.38899 .20825 L
.39924 .20732 L
.4043 .207 L
.40967 .20673 L
Mistroke
.41424 .20656 L
.41929 .20641 L
.42475 .20629 L
.42994 .20621 L
.4346 .20615 L
.43968 .20611 L
.44257 .20609 L
.44519 .20607 L
.44801 .20606 L
.45105 .20605 L
.45389 .20604 L
.45649 .20604 L
.45917 .20603 L
.46161 .20603 L
.46655 .20602 L
.46927 .20602 L
.47184 .20602 L
.47642 .20602 L
.479 .20601 L
.48139 .20601 L
.4838 .20601 L
.48639 .20601 L
.48924 .20601 L
.49191 .20601 L
.49476 .20601 L
.49775 .20601 L
.5003 .20601 L
.50309 .20601 L
.50576 .20601 L
.50865 .20601 L
.51138 .20601 L
.51389 .20601 L
.51616 .20601 L
.51866 .20601 L
.52126 .20601 L
.5237 .20601 L
.52654 .20601 L
.52924 .20601 L
.53167 .20601 L
.53431 .20601 L
.53717 .20601 L
.54022 .20601 L
.5431 .20601 L
.5457 .20601 L
.54815 .20601 L
.55084 .20601 L
.55365 .20601 L
.55626 .20601 L
.55872 .20601 L
.56095 .20601 L
Mistroke
.56353 .20601 L
.56597 .20601 L
.56861 .20601 L
.56995 .20601 L
.57142 .20601 L
.57402 .20601 L
.57646 .20601 L
.57792 .20601 L
.57932 .20601 L
.58194 .20601 L
.58341 .20601 L
.58476 .20601 L
.58626 .20601 L
.58785 .20601 L
.58917 .20601 L
.59062 .20601 L
.59317 .20601 L
.59461 .20601 L
.59615 .20601 L
.59894 .20601 L
.60028 .20601 L
.60174 .20601 L
.60303 .20601 L
.6044 .20601 L
.60563 .20601 L
.60699 .20601 L
.60938 .20601 L
.61062 .20601 L
.61191 .20601 L
.61423 .20601 L
.61552 .20601 L
.61673 .20601 L
.61813 .20601 L
.61946 .20601 L
.62061 .20601 L
.62185 .20601 L
.62403 .20601 L
.62527 .20601 L
.62657 .20601 L
.62892 .20601 L
.63019 .20601 L
.63157 .20601 L
.63279 .20601 L
.63409 .20601 L
.63538 .20601 L
.63655 .20601 L
.63882 .20601 L
.64019 .20601 L
.64146 .20601 L
.64281 .20601 L
Mistroke
.6443 .20601 L
.64681 .20601 L
.64818 .20601 L
.64946 .20601 L
.65066 .20601 L
.65196 .20601 L
.6531 .20601 L
.65432 .20601 L
.65541 .20601 L
.65662 .20601 L
.65875 .20601 L
.66004 .20601 L
.66122 .20601 L
.66249 .20601 L
.66388 .20601 L
.66622 .20601 L
.6675 .20601 L
.66869 .20601 L
.67003 .20601 L
.67146 .20601 L
.67268 .20601 L
.674 .20601 L
.67542 .20601 L
.67675 .20601 L
.67832 .20601 L
.67976 .20601 L
.68109 .20601 L
.68232 .20601 L
.68368 .20601 L
.68512 .20601 L
.68636 .20601 L
.68753 .20601 L
.68881 .20601 L
.6902 .20601 L
.69135 .20601 L
.69258 .20601 L
.69389 .20601 L
.6951 .20601 L
.69631 .20601 L
.69745 .20601 L
.69959 .20601 L
.70082 .20601 L
.70212 .20601 L
.70324 .20601 L
.70445 .20601 L
.70575 .20601 L
.70696 .20601 L
.70841 .20601 L
.70973 .20601 L
.71108 .20601 L
Mistroke
.71235 .20601 L
.7135 .20601 L
.71473 .20601 L
.71609 .20601 L
.71751 .20601 L
.71873 .20601 L
.72007 .20601 L
.72132 .20601 L
.72247 .20601 L
.72378 .20601 L
.72503 .20601 L
.72611 .20601 L
.72725 .20601 L
.72851 .20601 L
.72967 .20601 L
.73101 .20601 L
.73224 .20601 L
.73358 .20601 L
.735 .20601 L
.73624 .20601 L
.7374 .20601 L
.73866 .20601 L
.74001 .20601 L
.74149 .20601 L
.74309 .20601 L
.7446 .20601 L
.746 .20601 L
.74725 .20601 L
.74864 .20601 L
.75008 .20601 L
.75143 .20601 L
.75274 .20601 L
.75414 .20601 L
.75546 .20601 L
.75666 .20601 L
.75807 .20601 L
.7596 .20601 L
.76104 .20601 L
.76236 .20601 L
.76361 .20601 L
.76477 .20601 L
.76605 .20601 L
.76741 .20601 L
.76884 .20601 L
.7702 .20601 L
.77142 .20601 L
.77274 .20601 L
.77394 .20601 L
.77507 .20601 L
.77631 .20601 L
Mistroke
.77765 .20601 L
.77904 .20601 L
.78037 .20601 L
.78156 .20601 L
.78286 .20601 L
.78409 .20601 L
.7852 .20601 L
.78649 .20601 L
.7877 .20601 L
.78883 .20601 L
.78986 .20601 L
.791 .20601 L
.7922 .20601 L
.79348 .20601 L
.79487 .20601 L
.79618 .20601 L
.7974 .20601 L
.79849 .20601 L
.7997 .20601 L
.80096 .20601 L
.80214 .20601 L
.80344 .20601 L
.80482 .20601 L
.80599 .20601 L
.80727 .20601 L
.80866 .20601 L
.81014 .20601 L
.81153 .20601 L
.8128 .20601 L
.814 .20601 L
.81527 .20601 L
.81636 .20601 L
.81755 .20601 L
.81883 .20601 L
.82021 .20601 L
.82151 .20601 L
.8227 .20601 L
.82389 .20601 L
.82499 .20601 L
.8262 .20601 L
.82749 .20601 L
.82872 .20601 L
.82988 .20601 L
.83092 .20601 L
.83205 .20601 L
.83335 .20601 L
.83454 .20601 L
.83592 .20601 L
.83722 .20601 L
.83842 .20601 L
Mistroke
.83953 .20601 L
.84075 .20601 L
.84204 .20601 L
.84334 .20601 L
.84473 .20601 L
.84605 .20601 L
.84725 .20601 L
.84859 .20601 L
.84935 .20601 L
.85006 .20601 L
.85148 .20601 L
.85228 .20601 L
.853 .20601 L
.85439 .20601 L
.85508 .20601 L
.85585 .20601 L
.8572 .20601 L
.85847 .20601 L
.85924 .20601 L
.85996 .20601 L
.86132 .20601 L
.86209 .20601 L
.86279 .20601 L
.86356 .20601 L
.86439 .20601 L
.86512 .20601 L
.8658 .20601 L
.86712 .20601 L
.86832 .20601 L
.86959 .20601 L
.87096 .20601 L
.87224 .20601 L
.87297 .20601 L
.87363 .20601 L
.87435 .20601 L
.87513 .20601 L
.87638 .20601 L
.87754 .20601 L
.87893 .20601 L
.8802 .20601 L
.88152 .20601 L
.88227 .20601 L
.88296 .20601 L
.88423 .20601 L
.88558 .20601 L
.88683 .20601 L
.88819 .20601 L
.88946 .20601 L
.89064 .20601 L
.8917 .20601 L
Mistroke
.89287 .20601 L
.89409 .20601 L
.89523 .20601 L
.89658 .20601 L
.89735 .20601 L
.89806 .20601 L
.89936 .20601 L
.90074 .20601 L
.90197 .20601 L
.90313 .20601 L
.90439 .20601 L
.90576 .20601 L
.90713 .20601 L
.90791 .20601 L
.90863 .20601 L
.91009 .20601 L
.91091 .20601 L
.91165 .20601 L
.91298 .20601 L
.91374 .20601 L
.91443 .20601 L
.9157 .20601 L
.91705 .20601 L
.91832 .20601 L
.91971 .20601 L
.92101 .20601 L
.92223 .20601 L
.92343 .20601 L
.92452 .20601 L
.92577 .20601 L
.92696 .20601 L
.92825 .20601 L
.92962 .20601 L
.93079 .20601 L
.93207 .20601 L
.93345 .20601 L
.93423 .20601 L
.93493 .20601 L
.9363 .20601 L
.9376 .20601 L
.93871 .20601 L
.93992 .20601 L
.9412 .20601 L
.94239 .20601 L
.9435 .20601 L
.94452 .20601 L
.94564 .20601 L
.94682 .20601 L
.94802 .20601 L
.9493 .20601 L
Mistroke
.9505 .20601 L
.9516 .20601 L
.95289 .20601 L
.95362 .20601 L
.95429 .20601 L
.95552 .20601 L
.95683 .20601 L
.9581 .20601 L
.95883 .20601 L
.95949 .20601 L
.96072 .20601 L
.96202 .20601 L
.96318 .20601 L
.96427 .20601 L
.96547 .20601 L
.96676 .20601 L
.96805 .20601 L
.96878 .20601 L
.96947 .20601 L
.97084 .20601 L
.97162 .20601 L
.97232 .20601 L
.97358 .20601 L
.97494 .20601 L
.97623 .20601 L
.97742 .20601 L
.97852 .20601 L
.97971 .20601 L
.98084 .20601 L
.98186 .20601 L
.98307 .20601 L
.98437 .20601 L
.98561 .20601 L
.98676 .20601 L
.98805 .20601 L
.98927 .20601 L
.99037 .20601 L
.99155 .20601 L
.99285 .20601 L
.99421 .20601 L
.99538 .20601 L
.99666 .20601 L
.9975 .20601 L
.99827 .20601 L
.99916 .20601 L
1 .20601 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13039,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo00?ooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooo
oom5ooooo`001Ol00002ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Gooooo00?o
0000ooooooooool0oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo00Co
A4A4omgMgOoooooo00001_ooool3o`000?ooooooAOooool000Oooooo00Go0000oooooooooooooooo
o`00000;ooooo`04omgMgOmEEEGoooooo`0000Kooooo00?o0000ooooooooool0oooooom5ooooo`00
1oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001_ooool00ol0003o
ooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^ko
A4A4o`000006ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Gooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool5o`0000Gooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool00ol0003oooooooooo`3oooooodGooooo0005o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0oooooom5ooooo`001ooo
ool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01Oooool3o`000?oooooo
AOooool000Oooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Cooooo
00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Gooooo00?o0000oooooooo
ool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c005ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo027ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@0Iooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l00000
0ol@413oooooooooo`0Gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l0
00001Ol@413oooooooooooooooooA4A400;o000000?o<S8bomgMgOooool06?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM03Wooooo000Qoooo
o`;o00008_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01oooool00omgMgOo<S8booooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B47ooooo`03o`000?oooooooooo00Kooooo00?oMgMgoc8b<_ooool06?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@06_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1oooool00omgMgOo<S8booooo`0hooooo`008Oooool00ol0003oooooooooo`0Qooooo`05oa0@4?oo
ooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000oooooooo
ool05oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool06Oooool01Ol@
413ooooooooooooooooo410@00kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0G
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Kooooo`05oa0@4?oo
ooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo03Oooooo
000Qooooo`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`00
0?ooooooooooooooool000001oooool00omgMgOo<S8booooo`0Hooooo`05o`000?oooooooooooooo
ool000003_ooool00ol0003oooooooooo`0Iooooo`05o`000?ooooooooooooooool000003_ooool0
0ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo01Sooooo00Go0000ooooooooooooooooo`00
000=ooooo`03oiRHV?lQ8B7ok^k^01[ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool0>?ooool0027ooooo00?o0000ooooooooool08Ooo
ool01Ol0003ooooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000004ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`06Oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000
ooooooooool06Oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<01Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo01Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00iooooo`008Oooool00ol0003oooooooooo`0Qoooo
o`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00Cooooo2_l0
000Dooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`0Iooooo`05oa0@
4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01_o
oooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo01Sooooo00Go410@oooo
oooooooooooooa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0>oooool0
027ooooo00?o0000ooooooooool08Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05o`0000Wooooo0_l0000Booooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3_ooool00ol0003oooooooooo`0Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo01_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;oooo
o`05o`000?nj^[[ooooooiRHV?l@41006_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go
0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo03_ooooo000Qooooo`;o00008_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00?ok^k^oc8b<_l000000_l00004ooooo`Co0000
2?ooool00ol0003oooooooooo`0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool00omEEEGo
IVIVo`00000Kooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool00omEEEGoIVIVo`000005oooo
o`Co00006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Co
oooo1?l0000jooooo`008Oooool00ol0003oooooooooo`0booooo`;o00004oooool2o`000?_ooooo
000Qooooo`03o`000?oooooooooo033ooooo0_l0000Gooooo`;o0000nOooool0027ooooo00?o0000
ooooooooool0;Oooool3o`0001_ooooo0_l0003/ooooo`03oa0@4?l0003o000000?o00001Oooool0
027ooooo00?o0000ooooooooool0:_ooool3o`00023ooooo00?o0000ooooooooool0joooool00ol0
003oooooooooo`06ooooo`008Oooool00ol0003oooooooooo`0Rooooo`So00009?ooool00ol0003o
ooooooooo`3Zooooo`03o`000?oooooooooo00Kooooo000Qoooooooo0000<ol0000<ooooo`03o`00
0?oooooooooo00Kooooo000Qooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool2o`0000Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Ko000000?oooooo`000?ooool02Oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo01Cooooo00?o0000oc8b<_oMgMd01_ooool0027ooooo00?o0000ooooooooool0<?ooool0
0ol0003oooooooooo`0Nooooo`;o00004?ooool00ol0003oooooooooo`06ooooo`Co00009_ooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0>oooool2
o`000004ojVYZOlQ8B7o0000ob4Q8@Cooooo000Qooooo`03o`000?oooooooooo05?ooooo00?o0000
ooooooooool04_ooool4o`000=Sooooo000Qooooo`03o`000?oooooooooo05Cooooo0_l0000?oooo
o`?o0000g?ooool0027ooooo00?o0000ooooooooool0E_ooool4o`0000Kooooo1Ol0003Oooooo`00
8Oooool2o`0005_ooooo1_l0003Tooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001Oooool00ol0003oooooooooo`3oooooodGooooo0007
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A005ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003oooooodGooooo0007ooooo`05o`000?oo
ooooooooooooool000003Oooool00onHV9So8B4Qonk^kP05ooooo`03o`000?oooooooooo0?oooooo
AOooool000Oooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Cooooo
00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Gooooo00?o0000oooooooo
ool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c005ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo
0_l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo0?ooooooAOooool000Oooooo00Go410@oooooooooooooooooa0@400;ooooo`Go0000
1Oooool3o`000?ooooooAOooool000Oooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4
A?oMgMgoooooo`0000Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol0003ooooo
oooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001_ooool00ol0003oooooooooo`3ooooo
odGooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000006oooo
o`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<oooo
o`03onk^k_m4A4Co000000Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool2o`000?ooooooA_oo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01Oooool00ol0003o
ooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoEEEEogMgMoooooooV9RHob4Q8@05ooooo`03o`000?oooooooooo0?ooooooAOooool000Oo
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001Oooool3
o`000?ooooooAOooool000Oooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9So
oooooiRHV?lQ8B401Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05o`000?oooooo
ooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Gooooo00?o0000ooooooooool0
oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool0
1oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2oooool00ooMgMgo410@oiRHV007ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Gooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooo
oom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003o
ooooodKooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool2o`00
0?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Gooooo
00?o0000ooooooooool0oooooom5ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401Oooool00ol0003oooooooooo`3oooooodGo
oooo0007ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo0000
00Gooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo0000
00_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P05ooooo`?o0000oooooom5ooooo`001oooool01Ol0
003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c005ooooo`03o`000?oo
oooooooo0?ooooooAOooool000Oooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj
^[[ooooookZj^_l@41001Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Gooooo00?o0000oooooooo
ool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0
003o410@ojVYZ@05ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003ooooooooo
o`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5
ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[o
oooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooo
oooo0?ooooooC?ooool001Sooooo00?oEEEEofIVI_l00000oooooom>ooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00W_ooool01OnHV9So0000o`000?m4A4Co^[Zj01Sooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?o
oooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c02@ooooo`007oooool01?l@413o0000o`000?l0001koooo
o`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000Wooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Go8B4QoiRHV?oooooo
V9RHob4Q8@2@ooooo`008?ooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo01[ooooo
00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol0
003ooooooooooooooooo0000093ooooo000Pooooo`03o`000?oooooooooo07_ooooo00?o0000oooo
ooooool02oooool6o`0000Wooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?oooooo
ooooooooool000000oooool01Olb<S;oV9RHoooooonHV9So<S8b093ooooo000Pooooo`06o`000?mg
MgOo0000o`000?mEEEGok^k^N?ooool00ol0003oooooooooo`0Jooooo`05o`000?oooooooooooooo
ool000002oooool01Ol0003ooooooooooooooooo000000?ooooo00Goc<c<o`000?l0003o0000olc<
c02@ooooo`008?ooool01_l0003oEEEEonk^k_ooooooMgMgoeEEEGKooooo00?o410@o`000?l00000
0ol0000Iooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@
00?ooooo00Go410@okZj^_oooooo^[Zjoa0@402@ooooo`008?ooool00ol0003ok^k^ooooo`02oooo
o`03o`000?oooooooooo07Kooooo00?o0000ooooooooool06_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05o`000?nj^[[ooooookZj^_l00000
T?ooool0023ooooo00?o0000onk^k_ooool00_ooool00ol0003oooooooooo`1fooooo`03o`000?oo
oooooooo01[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00oooool01OnYZJWo410@o`000?l@413oZJVY093ooooo000Pooooo`06o`000?mEEEGok^k^oooo
oomgMgOoIVIVoooooom3ooooo`007oooool00ol@413o0000ogMgM`02o`000003ofIVI_o^k^kooooo
0?oooooo@_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.0332543, -0.540631, \
0.00122928, 0.00994506}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 3.33333 0.206011 0.412023 [
[.16667 .19351 -12 -9 ]
[.16667 .19351 12 0 ]
[.33333 .19351 -9 -9 ]
[.33333 .19351 9 0 ]
[.5 .19351 -12 -9 ]
[.5 .19351 12 0 ]
[.66667 .19351 -9 -9 ]
[.66667 .19351 9 0 ]
[.83333 .19351 -12 -9 ]
[.83333 .19351 12 0 ]
[1.025 .20601 0 -6 ]
[1.025 .20601 10 6 ]
[-0.0125 .0412 -24 -4.5 ]
[-0.0125 .0412 0 4.5 ]
[-0.0125 .12361 -24 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .28842 -18 -4.5 ]
[-0.0125 .28842 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .45322 -18 -4.5 ]
[-0.0125 .45322 0 4.5 ]
[-0.0125 .53563 -18 -4.5 ]
[-0.0125 .53563 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 .20601 m
.16667 .21226 L
s
[(0.05)] .16667 .19351 0 1 Mshowa
.33333 .20601 m
.33333 .21226 L
s
[(0.1)] .33333 .19351 0 1 Mshowa
.5 .20601 m
.5 .21226 L
s
[(0.15)] .5 .19351 0 1 Mshowa
.66667 .20601 m
.66667 .21226 L
s
[(0.2)] .66667 .19351 0 1 Mshowa
.83333 .20601 m
.83333 .21226 L
s
[(0.25)] .83333 .19351 0 1 Mshowa
.125 Mabswid
.03333 .20601 m
.03333 .20976 L
s
.06667 .20601 m
.06667 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.13333 .20601 m
.13333 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.23333 .20601 m
.23333 .20976 L
s
.26667 .20601 m
.26667 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.36667 .20601 m
.36667 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.43333 .20601 m
.43333 .20976 L
s
.46667 .20601 m
.46667 .20976 L
s
.53333 .20601 m
.53333 .20976 L
s
.56667 .20601 m
.56667 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.63333 .20601 m
.63333 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.73333 .20601 m
.73333 .20976 L
s
.76667 .20601 m
.76667 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.86667 .20601 m
.86667 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.93333 .20601 m
.93333 .20976 L
s
.96667 .20601 m
.96667 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
gsave
1.025 .20601 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .0412 m
.00625 .0412 L
s
[(-0.4)] -0.0125 .0412 1 0 Mshowa
0 .12361 m
.00625 .12361 L
s
[(-0.2)] -0.0125 .12361 1 0 Mshowa
0 .28842 m
.00625 .28842 L
s
[(0.2)] -0.0125 .28842 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.4)] -0.0125 .37082 1 0 Mshowa
0 .45322 m
.00625 .45322 L
s
[(0.6)] -0.0125 .45322 1 0 Mshowa
0 .53563 m
.00625 .53563 L
s
[(0.8)] -0.0125 .53563 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .10301 m
.00375 .10301 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .30902 m
.00375 .30902 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .39142 m
.00375 .39142 L
s
0 .41202 m
.00375 .41202 L
s
0 .43262 m
.00375 .43262 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .51503 m
.00375 .51503 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
0 .0206 m
.00375 .0206 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.09) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .20601 m
.00123 .20601 L
.00236 .20601 L
.00365 .20601 L
.00488 .20601 L
.00601 .20601 L
.00706 .20601 L
.00942 .20601 L
.01181 .20601 L
.01444 .20601 L
.01718 .20601 L
.01975 .20601 L
.02243 .20601 L
.02499 .20601 L
.02978 .20601 L
.03245 .20601 L
.03494 .20601 L
.03766 .20601 L
.04057 .20601 L
.04356 .20601 L
.04631 .20601 L
.04933 .20601 L
.05251 .20601 L
.05529 .20601 L
.05788 .20601 L
.06072 .20601 L
.06377 .20601 L
.06648 .20601 L
.06942 .20601 L
.07202 .20601 L
.07478 .206 L
.07725 .206 L
.07999 .206 L
.08481 .206 L
.08727 .20599 L
.08997 .20599 L
.0926 .20598 L
.09541 .20598 L
.10044 .20596 L
.10512 .20594 L
.10796 .20592 L
.11103 .2059 L
.1166 .20584 L
.12202 .20577 L
.12702 .20568 L
.13193 .20556 L
.1372 .20538 L
.14218 .20517 L
.14672 .20492 L
.15204 .20456 L
Mistroke
.15784 .20404 L
.1684 .20274 L
.17399 .20182 L
.17926 .20079 L
.18909 .19842 L
.21113 .19134 L
.22141 .18779 L
.22702 .18603 L
.23225 .18462 L
.23672 .18364 L
.23902 .18325 L
.24151 .1829 L
.24293 .18275 L
.24424 .18265 L
.24549 .18257 L
.24682 .18252 L
.24801 .1825 L
.24912 .18251 L
.25035 .18255 L
.25166 .18262 L
.25299 .18273 L
.25419 .18286 L
.25688 .18325 L
.25938 .18375 L
.26174 .18435 L
.26702 .18609 L
.27274 .18859 L
.28429 .19524 L
.29491 .20248 L
.30524 .20953 L
.31633 .21603 L
.3217 .21851 L
.32679 .22038 L
.33136 .22164 L
.33395 .22217 L
.33634 .22255 L
.33862 .22281 L
.3399 .22291 L
.34107 .22298 L
.3421 .22303 L
.34323 .22305 L
.34441 .22306 L
.34551 .22304 L
.34683 .22299 L
.34808 .22293 L
.3492 .22285 L
.35041 .22274 L
.35314 .22243 L
.35565 .22207 L
.36562 .22004 L
Mistroke
.37618 .21732 L
.38682 .21449 L
.39694 .21208 L
.40679 .21017 L
.41592 .2088 L
.42568 .20775 L
.43083 .20734 L
.43632 .20699 L
.44224 .20671 L
.44782 .20651 L
.45283 .20637 L
.45825 .20627 L
.46342 .20619 L
.46824 .20614 L
.47353 .2061 L
.4765 .20608 L
.4792 .20607 L
.48464 .20605 L
.48772 .20604 L
.49056 .20603 L
.49578 .20603 L
.49842 .20602 L
.50132 .20602 L
.50649 .20602 L
.50909 .20602 L
.51193 .20601 L
.51437 .20601 L
.51697 .20601 L
.52165 .20601 L
.52449 .20601 L
.52756 .20601 L
.53046 .20601 L
.53313 .20601 L
.53554 .20601 L
.5382 .20601 L
.54097 .20601 L
.54356 .20601 L
.54627 .20601 L
.54879 .20601 L
.55155 .20601 L
.55449 .20601 L
.5573 .20601 L
.55994 .20601 L
.56231 .20601 L
.56487 .20601 L
.56723 .20601 L
.56981 .20601 L
.57251 .20601 L
.57502 .20601 L
.57738 .20601 L
Mistroke
.57952 .20601 L
.582 .20601 L
.58434 .20601 L
.58684 .20601 L
.58918 .20601 L
.59175 .20601 L
.59452 .20601 L
.5959 .20601 L
.5974 .20601 L
.59873 .20601 L
.60015 .20601 L
.60282 .20601 L
.60531 .20601 L
.60782 .20601 L
.60914 .20601 L
.61053 .20601 L
.6131 .20601 L
.61546 .20601 L
.61773 .20601 L
.61985 .20601 L
.62217 .20601 L
.62466 .20601 L
.62594 .20601 L
.62735 .20601 L
.62873 .20601 L
.63021 .20601 L
.63159 .20601 L
.63285 .20601 L
.63534 .20601 L
.63674 .20601 L
.63804 .20601 L
.63959 .20601 L
.641 .20601 L
.64388 .20601 L
.64546 .20601 L
.64696 .20601 L
.64952 .20601 L
.65081 .20601 L
.65223 .20601 L
.65344 .20601 L
.65474 .20601 L
.65709 .20601 L
.6585 .20601 L
.66004 .20601 L
.66139 .20601 L
.66283 .20601 L
.66426 .20601 L
.66556 .20601 L
.66686 .20601 L
.66808 .20601 L
Mistroke
.67053 .20601 L
.67182 .20601 L
.67321 .20601 L
.67467 .20601 L
.67605 .20601 L
.6773 .20601 L
.67863 .20601 L
.67977 .20601 L
.68104 .20601 L
.68327 .20601 L
.68453 .20601 L
.68588 .20601 L
.68832 .20601 L
.6897 .20601 L
.69098 .20601 L
.69238 .20601 L
.69388 .20601 L
.69546 .20601 L
.69695 .20601 L
.69829 .20601 L
.69974 .20601 L
.701 .20601 L
.70238 .20601 L
.70383 .20601 L
.70518 .20601 L
.7076 .20601 L
.70895 .20601 L
.71019 .20601 L
.71258 .20601 L
.71394 .20601 L
.71522 .20601 L
.71648 .20601 L
.7178 .20601 L
.71925 .20601 L
.72058 .20601 L
.72173 .20601 L
.72295 .20601 L
.72517 .20601 L
.72652 .20601 L
.7278 .20601 L
.72904 .20601 L
.7302 .20601 L
.73145 .20601 L
.73283 .20601 L
.73418 .20601 L
.73563 .20601 L
.73697 .20601 L
.73825 .20601 L
.73951 .20601 L
.74064 .20601 L
Mistroke
.74201 .20601 L
.74346 .20601 L
.7448 .20601 L
.74607 .20601 L
.74755 .20601 L
.74891 .20601 L
.7504 .20601 L
.75198 .20601 L
.75326 .20601 L
.75466 .20601 L
.75597 .20601 L
.75719 .20601 L
.75838 .20601 L
.75949 .20601 L
.76066 .20601 L
.76194 .20601 L
.76324 .20601 L
.76462 .20601 L
.76579 .20601 L
.76707 .20601 L
.76846 .20601 L
.76994 .20601 L
.77134 .20601 L
.77261 .20601 L
.77381 .20601 L
.77508 .20601 L
.77617 .20601 L
.77736 .20601 L
.77864 .20601 L
.78002 .20601 L
.78132 .20601 L
.78251 .20601 L
.7837 .20601 L
.78481 .20601 L
.78602 .20601 L
.78731 .20601 L
.78854 .20601 L
.7897 .20601 L
.79074 .20601 L
.79186 .20601 L
.79317 .20601 L
.79436 .20601 L
.79574 .20601 L
.79704 .20601 L
.79825 .20601 L
.79936 .20601 L
.80058 .20601 L
.80187 .20601 L
.80317 .20601 L
.80457 .20601 L
Mistroke
.80588 .20601 L
.80709 .20601 L
.8085 .20601 L
.81004 .20601 L
.81149 .20601 L
.81284 .20601 L
.81423 .20601 L
.81573 .20601 L
.81715 .20601 L
.81846 .20601 L
.81964 .20601 L
.82094 .20601 L
.82229 .20601 L
.82355 .20601 L
.82503 .20601 L
.82644 .20601 L
.82769 .20601 L
.82907 .20601 L
.83055 .20601 L
.8313 .20601 L
.83214 .20601 L
.8336 .20601 L
.83498 .20601 L
.83621 .20601 L
.83753 .20601 L
.83877 .20601 L
.8399 .20601 L
.84123 .20601 L
.84267 .20601 L
.84403 .20601 L
.84529 .20601 L
.84658 .20601 L
.8478 .20601 L
.84913 .20601 L
.85056 .20601 L
.85128 .20601 L
.85206 .20601 L
.85348 .20601 L
.85486 .20601 L
.85615 .20601 L
.85737 .20601 L
.85869 .20601 L
.85994 .20601 L
.86108 .20601 L
.86212 .20601 L
.86326 .20601 L
.86445 .20601 L
.86555 .20601 L
.86685 .20601 L
.86809 .20601 L
Mistroke
.86919 .20601 L
.87039 .20601 L
.8717 .20601 L
.87308 .20601 L
.87427 .20601 L
.87557 .20601 L
.87685 .20601 L
.87804 .20601 L
.87935 .20601 L
.88074 .20601 L
.88145 .20601 L
.88221 .20601 L
.8836 .20601 L
.88494 .20601 L
.88619 .20601 L
.88735 .20601 L
.88844 .20601 L
.88963 .20601 L
.89091 .20601 L
.89225 .20601 L
.89352 .20601 L
.89467 .20601 L
.89591 .20601 L
.89663 .20601 L
.8974 .20601 L
.89808 .20601 L
.8988 .20601 L
.90017 .20601 L
.90142 .20601 L
.90212 .20601 L
.90287 .20601 L
.90422 .20601 L
.90504 .20601 L
.90582 .20601 L
.90651 .20601 L
.90728 .20601 L
.90855 .20601 L
.90991 .20601 L
.91116 .20601 L
.91233 .20601 L
.91371 .20601 L
.91497 .20601 L
.91567 .20601 L
.91643 .20601 L
.91782 .20601 L
.91849 .20601 L
.91921 .20601 L
.92049 .20601 L
.92188 .20601 L
.92266 .20601 L
Mistroke
.92339 .20601 L
.92472 .20601 L
.92593 .20601 L
.9266 .20601 L
.92732 .20601 L
.92865 .20601 L
.92982 .20601 L
.93112 .20601 L
.93248 .20601 L
.93375 .20601 L
.93493 .20601 L
.93602 .20601 L
.93721 .20601 L
.93847 .20601 L
.93985 .20601 L
.9411 .20601 L
.9418 .20601 L
.94255 .20601 L
.94392 .20601 L
.9452 .20601 L
.94655 .20601 L
.94771 .20601 L
.94898 .20601 L
.94975 .20601 L
.95048 .20601 L
.95185 .20601 L
.95261 .20601 L
.95332 .20601 L
.95415 .20601 L
.95493 .20601 L
.95561 .20601 L
.95634 .20601 L
.95762 .20601 L
.95835 .20601 L
.95912 .20601 L
.96049 .20601 L
.96176 .20601 L
.96314 .20601 L
.96445 .20601 L
.96566 .20601 L
.96674 .20601 L
.96794 .20601 L
.96919 .20601 L
.97036 .20601 L
.97166 .20601 L
.97302 .20601 L
.97418 .20601 L
.97545 .20601 L
.97683 .20601 L
.9776 .20601 L
Mistroke
.97829 .20601 L
.97965 .20601 L
.98093 .20601 L
.98204 .20601 L
.98325 .20601 L
.98452 .20601 L
.9857 .20601 L
.98681 .20601 L
.98782 .20601 L
.98898 .20601 L
.99009 .20601 L
.99128 .20601 L
.99255 .20601 L
.99364 .20601 L
.99483 .20601 L
.99611 .20601 L
.9975 .20601 L
.9988 .20601 L
1 .20601 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13039,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo00?ooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooo
oom5ooooo`001Ol00002ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Gooooo00?o
0000ooooooooool0oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo00Co
A4A4omgMgOoooooo00001_ooool3o`000?ooooooAOooool000Oooooo00Go0000oooooooooooooooo
o`00000;ooooo`04omgMgOmEEEGoooooo`0000Kooooo00?o0000ooooooooool0oooooom5ooooo`00
1oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001_ooool00ol0003o
ooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^ko
A4A4o`000006ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Gooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool5o`0000Gooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool00ol0003oooooooooo`3oooooodGooooo0005o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0oooooom5ooooo`001ooo
ool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01Oooool3o`000?oooooo
AOooool000Oooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Cooooo
00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Gooooo00?o0000oooooooo
ool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c005ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo027ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@0Iooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l00000
0ol@413oooooooooo`0Gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l0
00001Ol@413oooooooooooooooooA4A400;o000000?o<S8bomgMgOooool06?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM03Wooooo000Qoooo
o`;o00008_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01oooool00omgMgOo<S8booooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B47ooooo`03o`000?oooooooooo00Kooooo00?oMgMgoc8b<_ooool06?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@06_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1oooool00omgMgOo<S8booooo`0hooooo`008Oooool00ol0003oooooooooo`0Qooooo`05oa0@4?oo
ooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000oooooooo
ool05oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool06Oooool01Ol@
413ooooooooooooooooo410@00kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0G
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Kooooo`05oa0@4?oo
ooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo03Oooooo
000Qooooo`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`00
0?ooooooooooooooool000001oooool00omgMgOo<S8booooo`0Hooooo`05o`000?oooooooooooooo
ool000003_ooool00ol0003oooooooooo`0Iooooo`05o`000?ooooooooooooooool000003_ooool0
0ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo01Sooooo00Go0000ooooooooooooooooo`00
000=ooooo`03oiRHV?lQ8B7ok^k^01[ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool0>?ooool0027ooooo00?o0000ooooooooool08Ooo
ool01Ol0003ooooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000004ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`06Oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000
ooooooooool06Oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<01Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo01Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00iooooo`008Oooool00ol0003oooooooooo`0Qoooo
o`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00Cooooo00?o
0000ooooooooool06oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool0
6Oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Kooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`0Hoooo
o`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo03_ooooo000Qooooo`03o`000?oooooooooo027ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00ol0003oooooooooo`08ooooo`[o00002Ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Kooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@01[ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003ooooo
ooooo`0kooooo`008Oooool2o`0002;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01?ooool4o`0000Cooooo0ol0000:ooooo`;o00001oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l000006oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00cooooo00?oEEEEofIVI_l000001Oooool4o`0001[ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`06_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co0000>_ooool0027ooooo00?o0000oooooooo
ool0@?ooool2o`0000oooooo0_l0003aooooo`008Oooool00ol0003oooooooooo`0looooo`Co0000
4oooool00ol0003oooooooooo`3^ooooo`008Oooool00ol0003oooooooooo`0iooooo`?o00006?oo
ool2o`000>?ooooo00?o410@o`000?l000000ol00005ooooo`008Oooool00ol0003oooooooooo`0c
ooooo`Ko00007Oooool00ol0003oooooooooo`3Rooooo`03o`000?oooooooooo00Kooooo000Qoooo
o`03o`000?oooooooooo02gooooo1_l0000Tooooo`;o0000h_ooool00ol0003oooooooooo`06oooo
o`008Oooooooo`0003?o00003?ooool00ol0003oooooooooo`06ooooo`008Oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool3o`0000Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`Wo00000_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo01Cooooo00?o0000oc8b<_oMgMd01_ooool0027ooooo00?o
0000ooooooooool0<?ooool00ol0003oooooooooo`0Yooooo`;o00001Oooool00ol0003ooooooooo
o`0?ooooo`?o00007_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo033ooooo00?o
0000ooooooooool0>oooool2o`000004ojVYZOlQ8B7o0000ob4Q8@Cooooo000Qooooo`03o`000?oo
oooooooo05kooooo00?o0000ooooooooool04Oooool3o`000<oooooo000Qooooo`03o`000?oooooo
oooo05oooooo0ol0000:ooooo`Ko0000d_ooool0027ooooo00?o0000ooooooooool0H_ooool:o`00
0=Sooooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool2o`000?ooooooA_oo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001Oooool00ol0003oooooooooo`3oooooodGooooo
0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A005ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003oooooodGooooo0007ooooo`05o`00
0?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP05ooooo`03o`000?oooooooooo0?oo
ooooAOooool000Oooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Co
oooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00oo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Gooooo00?o0000oooo
ooooool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c005ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003ooooo
odKooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Ko
oooo0_l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo0?ooooooAOooool000Oooooo00Go410@oooooooooooooooooa0@400;ooooo`Go
00001Oooool3o`000?ooooooAOooool000Oooooo00Go0000ooooooooooooooooo`00000;ooooo`04
odA4A?oMgMgoooooo`0000Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol0003o
oooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001_ooool00ol0003oooooooooo`3o
ooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000006
ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<
ooooo`03onk^k_m4A4Co000000Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool2o`000?oooooo
A_ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooo
oom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01Oooool00ol0
003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@05ooooo`03o`000?oooooooooo0?ooooooAOooool0
00Oooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001Ooo
ool3o`000?ooooooAOooool000Oooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B401Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05o`000?oo
ooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Gooooo00?o0000oooooooo
ool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qooo
ool01oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool00ooMgMgo410@oiRHV007ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Gooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000
oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0
003oooooodKooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool2
o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Go
oooo00?o0000ooooooooool0oooooom5ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401Oooool00ol0003oooooooooo`3ooooo
odGooooo0007ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo
000000Gooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo
000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P05ooooo`?o0000oooooom5ooooo`001oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c005ooooo`03o`00
0?oooooooooo0?ooooooAOooool000Oooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@
4?nj^[[ooooookZj^_l@41001Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Gooooo00?o0000oooo
ooooool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@
4?l0003o410@ojVYZ@05ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003ooooo
ooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooo
oom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool0
01[ooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo00?o0000oooooooo
ool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oo
oooooooo0?ooooooC?ooool001Sooooo00?oEEEEofIVI_l00000oooooom>ooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00W_ooool01OnHV9So0000o`000?m4A4Co^[Zj01Sooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00?ooooo00Co410@o`000?m4A4Coc<c<TOooool001oooooo00Co410@o`000?l0003o0000Noooool0
1Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l00009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03oiRHV?l@413ogMgM093o
oooo000Pooooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool06_ooool01Ol@413ooooo
oooooooooooo410@00_ooooo00Go410@oooooooooooooooooa0@4006ooooo`03ohN7QomEEEGooooo
08oooooo000Pooooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool02oooool6o`0000Wo
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?ooooooooooooooool000000oooool0
1Oo<c<co8B4Qo`000?mEEEGo0000093ooooo000Pooooo`06o`000?mgMgOo0000o`000?mEEEGok^k^
N?ooool00ol0003oooooooooo`0Jooooo`05o`000?ooooooooooooooool000002oooool01Ol0003o
oooooooooooooooo000000?ooooo00Go8B4QohN7QoooooooV9RHo`00002@ooooo`008?ooool01_l0
003oEEEEonk^k_ooooooMgMgoeEEEGKooooo00?o410@o`000?l000000ol0000Iooooo`05oa0@4?oo
ooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00?ooooo00Go0000oooooooo
ooooooooo`00002@ooooo`008?ooool00ol0003ok^k^ooooo`02ooooo`03o`000?oooooooooo07Ko
oooo00?o0000ooooooooool06_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`03ooooo`05ob4Q8OnHV9SoooooogMgMomEEED0T?ooool0023ooooo00?o0000
onk^k_ooool00_ooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo01[ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool01Oo<c<co410@
o`000?lb<S;ok^k^093ooooo000Pooooo`06o`000?mEEEGok^k^oooooomgMgOoIVIVoooooom3oooo
o`007oooool00ol@413o0000ogMgM`02o`000003ofIVI_o^k^kooooo0?oooooo@_ooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.0332543, -0.540631, \
0.00122928, 0.00994506}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 3.33333 0.206011 0.412023 [
[.16667 .19351 -12 -9 ]
[.16667 .19351 12 0 ]
[.33333 .19351 -9 -9 ]
[.33333 .19351 9 0 ]
[.5 .19351 -12 -9 ]
[.5 .19351 12 0 ]
[.66667 .19351 -9 -9 ]
[.66667 .19351 9 0 ]
[.83333 .19351 -12 -9 ]
[.83333 .19351 12 0 ]
[1.025 .20601 0 -6 ]
[1.025 .20601 10 6 ]
[-0.0125 .0412 -24 -4.5 ]
[-0.0125 .0412 0 4.5 ]
[-0.0125 .12361 -24 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .28842 -18 -4.5 ]
[-0.0125 .28842 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .45322 -18 -4.5 ]
[-0.0125 .45322 0 4.5 ]
[-0.0125 .53563 -18 -4.5 ]
[-0.0125 .53563 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 .20601 m
.16667 .21226 L
s
[(0.05)] .16667 .19351 0 1 Mshowa
.33333 .20601 m
.33333 .21226 L
s
[(0.1)] .33333 .19351 0 1 Mshowa
.5 .20601 m
.5 .21226 L
s
[(0.15)] .5 .19351 0 1 Mshowa
.66667 .20601 m
.66667 .21226 L
s
[(0.2)] .66667 .19351 0 1 Mshowa
.83333 .20601 m
.83333 .21226 L
s
[(0.25)] .83333 .19351 0 1 Mshowa
.125 Mabswid
.03333 .20601 m
.03333 .20976 L
s
.06667 .20601 m
.06667 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.13333 .20601 m
.13333 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.23333 .20601 m
.23333 .20976 L
s
.26667 .20601 m
.26667 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.36667 .20601 m
.36667 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.43333 .20601 m
.43333 .20976 L
s
.46667 .20601 m
.46667 .20976 L
s
.53333 .20601 m
.53333 .20976 L
s
.56667 .20601 m
.56667 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.63333 .20601 m
.63333 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.73333 .20601 m
.73333 .20976 L
s
.76667 .20601 m
.76667 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.86667 .20601 m
.86667 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.93333 .20601 m
.93333 .20976 L
s
.96667 .20601 m
.96667 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
gsave
1.025 .20601 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .0412 m
.00625 .0412 L
s
[(-0.4)] -0.0125 .0412 1 0 Mshowa
0 .12361 m
.00625 .12361 L
s
[(-0.2)] -0.0125 .12361 1 0 Mshowa
0 .28842 m
.00625 .28842 L
s
[(0.2)] -0.0125 .28842 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.4)] -0.0125 .37082 1 0 Mshowa
0 .45322 m
.00625 .45322 L
s
[(0.6)] -0.0125 .45322 1 0 Mshowa
0 .53563 m
.00625 .53563 L
s
[(0.8)] -0.0125 .53563 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .10301 m
.00375 .10301 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .30902 m
.00375 .30902 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .39142 m
.00375 .39142 L
s
0 .41202 m
.00375 .41202 L
s
0 .43262 m
.00375 .43262 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .51503 m
.00375 .51503 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
0 .0206 m
.00375 .0206 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.1) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .20601 m
.00123 .20601 L
.00236 .20601 L
.00365 .20601 L
.00488 .20601 L
.00601 .20601 L
.00706 .20601 L
.00942 .20601 L
.01181 .20601 L
.01444 .20601 L
.01718 .20601 L
.01975 .20601 L
.02243 .20601 L
.02499 .20601 L
.02728 .20601 L
.02978 .20601 L
.03249 .20601 L
.03537 .20601 L
.0381 .20601 L
.04057 .20601 L
.04334 .20601 L
.04627 .20601 L
.04877 .20601 L
.05151 .20601 L
.05446 .20601 L
.05763 .20601 L
.06062 .20601 L
.06335 .20601 L
.06609 .20601 L
.06863 .20601 L
.07141 .20601 L
.07437 .20601 L
.07693 .20601 L
.07933 .20601 L
.08197 .20601 L
.08481 .20601 L
.08733 .20601 L
.09001 .20601 L
.09486 .20601 L
.09782 .20601 L
.10062 .20601 L
.10585 .20601 L
.10854 .20601 L
.11138 .20601 L
.11648 .206 L
.11932 .206 L
.12197 .206 L
.1251 .20599 L
.12801 .20599 L
.13323 .20597 L
Mistroke
.13599 .20596 L
.13893 .20595 L
.14438 .20592 L
.14931 .20589 L
.15413 .20584 L
.15934 .20576 L
.16425 .20567 L
.16877 .20556 L
.17372 .2054 L
.17902 .20517 L
.18402 .2049 L
.18858 .20459 L
.19392 .20414 L
.19973 .20353 L
.21029 .20201 L
.22018 .20007 L
.23109 .19734 L
.25316 .19065 L
.26309 .18789 L
.26807 .18678 L
.27093 .18625 L
.27352 .18587 L
.27639 .18555 L
.27714 .18548 L
.27796 .18542 L
.27867 .18538 L
.27945 .18534 L
.28017 .18531 L
.28084 .1853 L
.28155 .18529 L
.28232 .18528 L
.2837 .18531 L
.28496 .18535 L
.28629 .18544 L
.28753 .18554 L
.28889 .18569 L
.29033 .18588 L
.29276 .1863 L
.29543 .18688 L
.30058 .18838 L
.30601 .19046 L
.31572 .19529 L
.33761 .20861 L
.34762 .2141 L
.35312 .21658 L
.35831 .21849 L
.36316 .21986 L
.36589 .22045 L
.36841 .22088 L
.37053 .22116 L
Mistroke
.37175 .22129 L
.37287 .22138 L
.37404 .22145 L
.37531 .22151 L
.37648 .22154 L
.37759 .22155 L
.3789 .22154 L
.37964 .22152 L
.38031 .2215 L
.38156 .22144 L
.38288 .22136 L
.38516 .22116 L
.38767 .22087 L
.39322 .22001 L
.3984 .21899 L
.41771 .2144 L
.4287 .21193 L
.4391 .21002 L
.44844 .20869 L
.45368 .20811 L
.45859 .20766 L
.46847 .20699 L
.47372 .20674 L
.47937 .20653 L
.48498 .20638 L
.49088 .20626 L
.49592 .20619 L
.50143 .20613 L
.5041 .20611 L
.50699 .20609 L
.50954 .20608 L
.51223 .20606 L
.51466 .20606 L
.51733 .20605 L
.52204 .20604 L
.5249 .20603 L
.52752 .20603 L
.53034 .20602 L
.53341 .20602 L
.53624 .20602 L
.53886 .20602 L
.54404 .20601 L
.54683 .20601 L
.5494 .20601 L
.55221 .20601 L
.55518 .20601 L
.55776 .20601 L
.56017 .20601 L
.56282 .20601 L
.56565 .20601 L
Mistroke
.56817 .20601 L
.57091 .20601 L
.5735 .20601 L
.57589 .20601 L
.57822 .20601 L
.58041 .20601 L
.58269 .20601 L
.5852 .20601 L
.5879 .20601 L
.59041 .20601 L
.59316 .20601 L
.5961 .20601 L
.59889 .20601 L
.60153 .20601 L
.60389 .20601 L
.60645 .20601 L
.6088 .20601 L
.61138 .20601 L
.61407 .20601 L
.61658 .20601 L
.61893 .20601 L
.62108 .20601 L
.62355 .20601 L
.6259 .20601 L
.62838 .20601 L
.63072 .20601 L
.63327 .20601 L
.63459 .20601 L
.63603 .20601 L
.63877 .20601 L
.64026 .20601 L
.64165 .20601 L
.64414 .20601 L
.64552 .20601 L
.6468 .20601 L
.6493 .20601 L
.65061 .20601 L
.65201 .20601 L
.65435 .20601 L
.65693 .20601 L
.65922 .20601 L
.66168 .20601 L
.66401 .20601 L
.66613 .20601 L
.66749 .20601 L
.66877 .20601 L
.67115 .20601 L
.67249 .20601 L
.67372 .20601 L
.67515 .20601 L
Mistroke
.67649 .20601 L
.67872 .20601 L
.6799 .20601 L
.68117 .20601 L
.68249 .20601 L
.68375 .20601 L
.6861 .20601 L
.68735 .20601 L
.68873 .20601 L
.69007 .20601 L
.69152 .20601 L
.69287 .20601 L
.69411 .20601 L
.69653 .20601 L
.6979 .20601 L
.69917 .20601 L
.70069 .20601 L
.70206 .20601 L
.70341 .20601 L
.70487 .20601 L
.70641 .20601 L
.70787 .20601 L
.71035 .20601 L
.71175 .20601 L
.71302 .20601 L
.7142 .20601 L
.71549 .20601 L
.71783 .20601 L
.71914 .20601 L
.72058 .20601 L
.72209 .20601 L
.72351 .20601 L
.72604 .20601 L
.72746 .20601 L
.72877 .20601 L
.73006 .20601 L
.73143 .20601 L
.73262 .20601 L
.73391 .20601 L
.73542 .20601 L
.73685 .20601 L
.73825 .20601 L
.73953 .20601 L
.7408 .20601 L
.74215 .20601 L
.74364 .20601 L
.74504 .20601 L
.7466 .20601 L
.74809 .20601 L
.74942 .20601 L
Mistroke
.75088 .20601 L
.75227 .20601 L
.75356 .20601 L
.75497 .20601 L
.75646 .20601 L
.75775 .20601 L
.75896 .20601 L
.76029 .20601 L
.76171 .20601 L
.76298 .20601 L
.76435 .20601 L
.76565 .20601 L
.76685 .20601 L
.76913 .20601 L
.77027 .20601 L
.77154 .20601 L
.77293 .20601 L
.77439 .20601 L
.77564 .20601 L
.77701 .20601 L
.77848 .20601 L
.78006 .20601 L
.78155 .20601 L
.7829 .20601 L
.78427 .20601 L
.78553 .20601 L
.78692 .20601 L
.78838 .20601 L
.78966 .20601 L
.79085 .20601 L
.79216 .20601 L
.79356 .20601 L
.79497 .20601 L
.79624 .20601 L
.7977 .20601 L
.79908 .20601 L
.80037 .20601 L
.80155 .20601 L
.80284 .20601 L
.8042 .20601 L
.80559 .20601 L
.80707 .20601 L
.80847 .20601 L
.80974 .20601 L
.81123 .20601 L
.81285 .20601 L
.81439 .20601 L
.8158 .20601 L
.81701 .20601 L
.81832 .20601 L
Mistroke
.81955 .20601 L
.82067 .20601 L
.82199 .20601 L
.82343 .20601 L
.82478 .20601 L
.82605 .20601 L
.82746 .20601 L
.8288 .20601 L
.83 .20601 L
.8313 .20601 L
.83272 .20601 L
.83422 .20601 L
.8355 .20601 L
.83691 .20601 L
.83828 .20601 L
.83954 .20601 L
.84093 .20601 L
.8424 .20601 L
.84368 .20601 L
.84488 .20601 L
.84619 .20601 L
.84761 .20601 L
.8488 .20601 L
.85009 .20601 L
.85145 .20601 L
.85271 .20601 L
.85389 .20601 L
.85496 .20601 L
.8562 .20601 L
.85738 .20601 L
.85864 .20601 L
.86004 .20601 L
.86149 .20601 L
.86285 .20601 L
.86413 .20601 L
.86529 .20601 L
.86663 .20601 L
.86791 .20601 L
.86928 .20601 L
.87074 .20601 L
.87212 .20601 L
.87337 .20601 L
.87485 .20601 L
.87568 .20601 L
.87644 .20601 L
.87785 .20601 L
.87933 .20601 L
.88061 .20601 L
.88201 .20601 L
.88333 .20601 L
Mistroke
.88455 .20601 L
.88564 .20601 L
.88685 .20601 L
.88811 .20601 L
.8893 .20601 L
.8906 .20601 L
.89198 .20601 L
.89315 .20601 L
.89444 .20601 L
.89582 .20601 L
.8966 .20601 L
.8973 .20601 L
.89868 .20601 L
.89997 .20601 L
.90109 .20601 L
.90231 .20601 L
.90359 .20601 L
.90478 .20601 L
.9059 .20601 L
.90692 .20601 L
.9081 .20601 L
.90922 .20601 L
.91042 .20601 L
.9117 .20601 L
.91291 .20601 L
.91401 .20601 L
.9153 .20601 L
.91598 .20601 L
.9167 .20601 L
.91802 .20601 L
.91923 .20601 L
.92052 .20601 L
.92125 .20601 L
.92192 .20601 L
.92315 .20601 L
.92446 .20601 L
.92563 .20601 L
.92673 .20601 L
.92793 .20601 L
.92922 .20601 L
.93059 .20601 L
.93136 .20601 L
.93208 .20601 L
.9334 .20601 L
.93414 .20601 L
.9348 .20601 L
.93607 .20601 L
.93743 .20601 L
.93873 .20601 L
.93991 .20601 L
Mistroke
.94103 .20601 L
.94222 .20601 L
.94335 .20601 L
.94438 .20601 L
.94559 .20601 L
.9469 .20601 L
.94814 .20601 L
.94928 .20601 L
.95046 .20601 L
.95156 .20601 L
.95278 .20601 L
.95408 .20601 L
.95538 .20601 L
.95674 .20601 L
.95791 .20601 L
.95918 .20601 L
.96051 .20601 L
.96174 .20601 L
.96308 .20601 L
.96376 .20601 L
.9645 .20601 L
.96575 .20601 L
.9671 .20601 L
.96836 .20601 L
.96952 .20601 L
.97072 .20601 L
.97183 .20601 L
.97304 .20601 L
.97434 .20601 L
.97558 .20601 L
.97674 .20601 L
.97779 .20601 L
.97892 .20601 L
.98024 .20601 L
.98147 .20601 L
.98282 .20601 L
.98357 .20601 L
.98426 .20601 L
.98565 .20601 L
.98644 .20601 L
.98716 .20601 L
.98849 .20601 L
.98916 .20601 L
.9899 .20601 L
.99121 .20601 L
.99241 .20601 L
.99373 .20601 L
.99511 .20601 L
.99632 .20601 L
.99745 .20601 L
Mistroke
.99868 .20601 L
1 .20601 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13039,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo00?ooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooo
oom5ooooo`001Ol00002ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Gooooo00?o
0000ooooooooool0oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo00Co
A4A4omgMgOoooooo00001_ooool3o`000?ooooooAOooool000Oooooo00Go0000oooooooooooooooo
o`00000;ooooo`04omgMgOmEEEGoooooo`0000Kooooo00?o0000ooooooooool0oooooom5ooooo`00
1oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001_ooool00ol0003o
ooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^ko
A4A4o`000006ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Gooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool5o`0000Gooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool00ol0003oooooooooo`3oooooodGooooo0005o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0oooooom5ooooo`001ooo
ool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01Oooool3o`000?oooooo
AOooool000Oooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Cooooo
00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Gooooo00?o0000oooooooo
ool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c005ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo027ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@0Iooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l00000
0ol@413oooooooooo`0Gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l0
00001Ol@413oooooooooooooooooA4A400;o000000?o<S8bomgMgOooool06?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM03Wooooo000Qoooo
o`;o00008_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01oooool00omgMgOo<S8booooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B47ooooo`03o`000?oooooooooo00Kooooo00?oMgMgoc8b<_ooool06?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@06_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1oooool00omgMgOo<S8booooo`0hooooo`008Oooool00ol0003oooooooooo`0Qooooo`05oa0@4?oo
ooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000oooooooo
ool05oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool06Oooool01Ol@
413ooooooooooooooooo410@00kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0G
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Kooooo`05oa0@4?oo
ooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo03Oooooo
000Qooooo`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`00
0?ooooooooooooooool000001oooool00omgMgOo<S8booooo`0Hooooo`05o`000?oooooooooooooo
ool000003_ooool00ol0003oooooooooo`0Iooooo`05o`000?ooooooooooooooool000003_ooool0
0ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo01Sooooo00Go0000ooooooooooooooooo`00
000=ooooo`03oiRHV?lQ8B7ok^k^01[ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool0>?ooool0027ooooo00?o0000ooooooooool08Ooo
ool01Ol0003ooooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000004ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`06Oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000
ooooooooool06Oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<01Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo01Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00iooooo`008Oooool00ol0003oooooooooo`0Qoooo
o`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00Cooooo00?o
0000ooooooooool06oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool0
6Oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Kooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`0Hoooo
o`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo03_ooooo000Qooooo`03o`000?oooooooooo027ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00ol0003oooooooooo`0Kooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`0Iooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01_ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41006_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo03_ooooo
000Qooooo`;o00008_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP04ooooo`Co00004Oooool:o`000004oc8b<_l0003o<S8bonk^kPcooooo00?oEEEEofIV
I_l000006oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l000001Oooool4
o`0001[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
6_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004oooo
o`Co0000>_ooool0027ooooo00?o0000ooooooooool0BOooool6o`0000[ooooo1?l0003Wooooo`00
8Oooool00ol0003oooooooooo`16ooooo`?o00005?ooool00ol0003oooooooooo`3Tooooo`008Ooo
ool00ol0003oooooooooo`12ooooo`Co00006?ooool2o`000=Wooooo00?o410@o`000?l000000ol0
0005ooooo`008Oooool00ol0003oooooooooo`0oooooo`?o00007_ooool00ol0003oooooooooo`3H
ooooo`03o`000?oooooooooo00Kooooo000Qooooo`03o`000?oooooooooo03Wooooo1_l0000Roooo
o`;o0000f?ooool00ol0003oooooooooo`06ooooo`008Oooooooo`0003?o00003?ooool00ol0003o
ooooooooo`06ooooo`008Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`?o00001oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Sooooo2Ol000000ooooooo0000ooooo`08ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Dooooo`03o`00
0?lb<S;ogMgM00Kooooo000Qooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0<?oo
ool01?l0003oooooooooool0000Hooooo`?o00005?ooool00ol0003oooooooooo`0`ooooo`03o`00
0?oooooooooo033ooooo00?o0000ooooooooool0>oooool2o`000004ojVYZOlQ8B7o0000ob4Q8@Co
oooo000Qooooo`03o`000?oooooooooo06Oooooo1?l0000?ooooo`Go0000aOooool0027ooooo00?o
0000ooooooooool0Joooool3o`0000Oooooo1Ol0003:ooooo`008Oooool00ol0003oooooooooo`1^
ooooo`Oo0000coooool0027ooooo0_l0003oooooodKooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000
oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0
003oooooodKooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00005ooooo`03o`000?oooooooooo0?oo
ooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Gooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000?ooooooAOooool000Oo
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?o0000oooo
ooooool0oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIV
I_ooool01?ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05oa0@4?oooooooooooooo
ool@41003oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?ooooooAOooool000Oo
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001Oooool0
0ol0003oooooooooo`3oooooodGooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool0
1OnHV9So410@o`000?lQ8B7oc<c<00Gooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool2
o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom5oooo
o`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@
00_ooooo1Ol00005ooooo`?o0000oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo0000
00_ooooo00CoA4A4omgMgOoooooo00001_ooool00ol0003oooooooooo`3oooooodGooooo0007oooo
o`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00006ooooo`03o`000?oo
oooooooo0?ooooooAOooool000Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<
c<co000000Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00cooooo00?ok^k^odA4A?l000001_ooool00ol0003oooooooooo`3oooooodGooooo0007
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`05ooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool2o`00
0?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o
0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
0_l0003oooooodKooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c005
ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Gooooo00?o0000ooooooooool0oooo
oom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000oooooooooooooooo
o`000005ooooo`?o0000oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo
00Go0000oiRHV?ooooooV9RHob4Q8@05ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01Oooool00ol0
003oooooooooo`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41002oooool00omE
EEGoQhN7ooooo`07ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Oooooo00?o0000ooooooooool0oooooom5oooo
o`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@1Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo0_l0003oooooodKooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
1oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q
8Oo<c<`01Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@05ooooo`03o`000?oooooo
oooo0?ooooooAOooool000Oooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooo
ooooooooool000001Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05o`000?oooooo
ooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Gooooo0ol0003oooooodGooooo
0007ooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<00Go
oooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00_o
oooo00Go410@okZj^_oooooo^[Zjoa0@4005ooooo`03o`000?oooooooooo0?ooooooAOooool000Oo
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000001Oooool0
0ol0003oooooooooo`3oooooodGooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool0
1OnYZJWo410@o`000?l@413oZJVY00Gooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool001Sooooo1?l000000ol@413oooooooooo`02ooooo`03
o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooo
oom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`?o0000oooooom5ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006?ooool00omEEEGoIVIVo`00003oooooodkooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo002Rooooo`05oiRHV?l0003o0000odA4A?nj
^[X06?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`Co000000?o410@oooo
ooooool0TOooool001oooooo00Co410@o`000?l0003o0000Ooooool01Ol@413o^[Zjonk^k_mgMgOo
410@00Wooooo1_l00009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o
0000ooooooooool0Toooool0023ooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`0J
ooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`2Cooooo`008?ooool0
0ol0003oooooooooo`1oooooo`03o`000?oooooooooo00_ooooo1_l00009ooooo`05o`000?oooooo
ooooooooool000003_ooool00ol0003oooooooooo`2Cooooo`008?ooool01_l0003oMgMgo`000?l0
003oEEEEonk^kWcooooo00?o0000ooooooooool06_ooool01Ol0003ooooooooooooooooo000000ko
oooo00?o0000ooooooooool0Toooool0023ooooo00Ko0000oeEEEOo^k^koooooogMgMomEEEEjoooo
o`03oa0@4?l0003o000000?o00006Oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000
ooooooooool0Toooool0023ooooo00?o0000onk^k_ooool00_ooool00ol0003oooooooooo`1joooo
o`03o`000?oooooooooo01[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oooooo
oooo09?ooooo000Pooooo`03o`000?o^k^kooooo00;ooooo00?o0000ooooooooool0N_ooool00ol0
003oooooooooo`0Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool00omEEEGoIVIVo`00002E
ooooo`008?ooool01_l0003oEEEEonk^k_ooooooMgMgofIVI_oooooo@oooool001oooooo00?o410@
o`000?mgMgL00_l000000omVIVKok^k^ooooo`3ooooood;ooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.0332543, -0.540631, \
0.00122928, 0.00994506}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 3.33333 0.206011 0.412023 [
[.16667 .19351 -12 -9 ]
[.16667 .19351 12 0 ]
[.33333 .19351 -9 -9 ]
[.33333 .19351 9 0 ]
[.5 .19351 -12 -9 ]
[.5 .19351 12 0 ]
[.66667 .19351 -9 -9 ]
[.66667 .19351 9 0 ]
[.83333 .19351 -12 -9 ]
[.83333 .19351 12 0 ]
[1.025 .20601 0 -6 ]
[1.025 .20601 10 6 ]
[-0.0125 .0412 -24 -4.5 ]
[-0.0125 .0412 0 4.5 ]
[-0.0125 .12361 -24 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .28842 -18 -4.5 ]
[-0.0125 .28842 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .45322 -18 -4.5 ]
[-0.0125 .45322 0 4.5 ]
[-0.0125 .53563 -18 -4.5 ]
[-0.0125 .53563 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 .20601 m
.16667 .21226 L
s
[(0.05)] .16667 .19351 0 1 Mshowa
.33333 .20601 m
.33333 .21226 L
s
[(0.1)] .33333 .19351 0 1 Mshowa
.5 .20601 m
.5 .21226 L
s
[(0.15)] .5 .19351 0 1 Mshowa
.66667 .20601 m
.66667 .21226 L
s
[(0.2)] .66667 .19351 0 1 Mshowa
.83333 .20601 m
.83333 .21226 L
s
[(0.25)] .83333 .19351 0 1 Mshowa
.125 Mabswid
.03333 .20601 m
.03333 .20976 L
s
.06667 .20601 m
.06667 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.13333 .20601 m
.13333 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.23333 .20601 m
.23333 .20976 L
s
.26667 .20601 m
.26667 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.36667 .20601 m
.36667 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.43333 .20601 m
.43333 .20976 L
s
.46667 .20601 m
.46667 .20976 L
s
.53333 .20601 m
.53333 .20976 L
s
.56667 .20601 m
.56667 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.63333 .20601 m
.63333 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.73333 .20601 m
.73333 .20976 L
s
.76667 .20601 m
.76667 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.86667 .20601 m
.86667 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.93333 .20601 m
.93333 .20976 L
s
.96667 .20601 m
.96667 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
gsave
1.025 .20601 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .0412 m
.00625 .0412 L
s
[(-0.4)] -0.0125 .0412 1 0 Mshowa
0 .12361 m
.00625 .12361 L
s
[(-0.2)] -0.0125 .12361 1 0 Mshowa
0 .28842 m
.00625 .28842 L
s
[(0.2)] -0.0125 .28842 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.4)] -0.0125 .37082 1 0 Mshowa
0 .45322 m
.00625 .45322 L
s
[(0.6)] -0.0125 .45322 1 0 Mshowa
0 .53563 m
.00625 .53563 L
s
[(0.8)] -0.0125 .53563 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .10301 m
.00375 .10301 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .30902 m
.00375 .30902 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .39142 m
.00375 .39142 L
s
0 .41202 m
.00375 .41202 L
s
0 .43262 m
.00375 .43262 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .51503 m
.00375 .51503 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
0 .0206 m
.00375 .0206 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.11) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .20601 m
.00123 .20601 L
.00236 .20601 L
.00365 .20601 L
.00488 .20601 L
.00601 .20601 L
.00706 .20601 L
.00942 .20601 L
.01181 .20601 L
.01444 .20601 L
.01718 .20601 L
.01975 .20601 L
.02243 .20601 L
.02499 .20601 L
.02728 .20601 L
.02978 .20601 L
.03249 .20601 L
.03537 .20601 L
.0381 .20601 L
.04057 .20601 L
.04334 .20601 L
.04627 .20601 L
.04877 .20601 L
.05151 .20601 L
.05446 .20601 L
.05612 .20601 L
.05763 .20601 L
.06057 .20601 L
.06335 .20601 L
.06594 .20601 L
.06869 .20601 L
.07104 .20601 L
.07363 .20601 L
.0764 .20601 L
.07939 .20601 L
.08222 .20601 L
.08481 .20601 L
.08742 .20601 L
.08979 .20601 L
.09252 .20601 L
.0951 .20601 L
.09749 .20601 L
.0997 .20601 L
.10212 .20601 L
.10468 .20601 L
.10726 .20601 L
.11003 .20601 L
.11264 .20601 L
.11503 .20601 L
.11782 .20601 L
Mistroke
.12087 .20601 L
.12375 .20601 L
.12641 .20601 L
.1292 .20601 L
.13176 .20601 L
.13457 .20601 L
.13754 .20601 L
.14253 .20601 L
.14536 .20601 L
.148 .206 L
.15054 .206 L
.15295 .206 L
.15745 .206 L
.15996 .20599 L
.16229 .20599 L
.16504 .20598 L
.16756 .20598 L
.17244 .20596 L
.175 .20595 L
.17769 .20594 L
.18223 .20591 L
.18719 .20587 L
.19262 .20581 L
.19841 .20571 L
.20388 .20559 L
.20884 .20544 L
.21395 .20524 L
.21935 .20496 L
.22902 .20427 L
.23441 .20374 L
.23944 .20314 L
.25088 .20136 L
.26183 .19905 L
.27222 .19641 L
.2917 .19106 L
.29691 .18982 L
.30182 .18883 L
.30448 .18839 L
.30693 .18805 L
.30964 .18776 L
.31107 .18764 L
.31184 .18759 L
.31257 .18755 L
.31378 .18751 L
.31488 .18748 L
.31607 .18747 L
.31735 .18749 L
.31848 .18753 L
.31967 .18759 L
.32068 .18765 L
Mistroke
.3218 .18775 L
.32432 .18804 L
.32702 .18848 L
.33191 .18957 L
.33742 .19128 L
.34253 .19328 L
.35411 .19896 L
.37521 .21063 L
.38055 .21321 L
.38632 .21562 L
.39141 .21736 L
.39419 .21814 L
.39678 .21876 L
.39932 .21926 L
.40163 .21963 L
.4042 .21995 L
.40562 .22007 L
.40696 .22017 L
.40809 .22023 L
.40929 .22027 L
.41031 .22029 L
.41144 .22029 L
.41266 .22028 L
.41396 .22024 L
.41519 .22019 L
.41632 .22012 L
.41893 .21991 L
.4213 .21966 L
.42663 .21891 L
.43621 .21707 L
.45795 .21231 L
.46774 .21048 L
.47811 .20895 L
.48352 .20832 L
.48947 .20775 L
.49449 .20736 L
.49995 .20702 L
.50543 .20675 L
.51063 .20656 L
.51569 .20641 L
.52039 .20631 L
.52597 .20622 L
.53102 .20616 L
.53382 .20613 L
.53685 .20611 L
.53949 .20609 L
.54233 .20608 L
.54504 .20606 L
.54751 .20605 L
.55234 .20604 L
Mistroke
.55505 .20604 L
.55799 .20603 L
.56332 .20602 L
.56598 .20602 L
.56891 .20602 L
.57196 .20602 L
.57483 .20602 L
.57745 .20601 L
.57995 .20601 L
.58282 .20601 L
.58546 .20601 L
.58817 .20601 L
.59073 .20601 L
.59306 .20601 L
.59552 .20601 L
.5982 .20601 L
.60067 .20601 L
.60333 .20601 L
.60624 .20601 L
.60876 .20601 L
.61106 .20601 L
.61371 .20601 L
.61622 .20601 L
.61854 .20601 L
.62069 .20601 L
.62304 .20601 L
.62555 .20601 L
.62804 .20601 L
.63067 .20601 L
.63292 .20601 L
.63538 .20601 L
.63803 .20601 L
.64087 .20601 L
.64355 .20601 L
.64598 .20601 L
.64844 .20601 L
.65072 .20601 L
.65321 .20601 L
.65585 .20601 L
.65814 .20601 L
.66029 .20601 L
.66264 .20601 L
.66517 .20601 L
.66784 .20601 L
.66934 .20601 L
.67069 .20601 L
.67332 .20601 L
.6758 .20601 L
.67721 .20601 L
.67871 .20601 L
Mistroke
.68137 .20601 L
.68286 .20601 L
.68425 .20601 L
.68575 .20601 L
.68739 .20601 L
.68882 .20601 L
.69013 .20601 L
.69137 .20601 L
.69273 .20601 L
.69508 .20601 L
.69759 .20601 L
.699 .20601 L
.7003 .20601 L
.70169 .20601 L
.70322 .20601 L
.70579 .20601 L
.70719 .20601 L
.7085 .20601 L
.70984 .20601 L
.71127 .20601 L
.71381 .20601 L
.71523 .20601 L
.71656 .20601 L
.7181 .20601 L
.71957 .20601 L
.72083 .20601 L
.7222 .20601 L
.72461 .20601 L
.72597 .20601 L
.72741 .20601 L
.72877 .20601 L
.73001 .20601 L
.73231 .20601 L
.73352 .20601 L
.73479 .20601 L
.73694 .20601 L
.73815 .20601 L
.73929 .20601 L
.74062 .20601 L
.74188 .20601 L
.74424 .20601 L
.74556 .20601 L
.74678 .20601 L
.74819 .20601 L
.74954 .20601 L
.75076 .20601 L
.75209 .20601 L
.75443 .20601 L
.75575 .20601 L
.75716 .20601 L
Mistroke
.75969 .20601 L
.76093 .20601 L
.76226 .20601 L
.76344 .20601 L
.76468 .20601 L
.76581 .20601 L
.76704 .20601 L
.76921 .20601 L
.77066 .20601 L
.77203 .20601 L
.77328 .20601 L
.77461 .20601 L
.77606 .20601 L
.77739 .20601 L
.77882 .20601 L
.78041 .20601 L
.78176 .20601 L
.783 .20601 L
.78437 .20601 L
.7858 .20601 L
.78705 .20601 L
.78822 .20601 L
.78948 .20601 L
.79086 .20601 L
.79221 .20601 L
.79362 .20601 L
.79494 .20601 L
.79617 .20601 L
.79762 .20601 L
.79894 .20601 L
.80047 .20601 L
.80192 .20601 L
.80317 .20601 L
.80451 .20601 L
.80577 .20601 L
.80691 .20601 L
.80826 .20601 L
.80971 .20601 L
.81109 .20601 L
.81235 .20601 L
.81348 .20601 L
.8147 .20601 L
.81574 .20601 L
.81688 .20601 L
.81822 .20601 L
.81948 .20601 L
.82071 .20601 L
.82185 .20601 L
.82296 .20601 L
.82416 .20601 L
Mistroke
.82548 .20601 L
.82671 .20601 L
.82809 .20601 L
.82941 .20601 L
.83058 .20601 L
.83187 .20601 L
.83326 .20601 L
.83454 .20601 L
.83595 .20601 L
.83744 .20601 L
.83873 .20601 L
.83994 .20601 L
.84127 .20601 L
.84269 .20601 L
.84395 .20601 L
.84533 .20601 L
.84662 .20601 L
.84782 .20601 L
.8489 .20601 L
.85009 .20601 L
.85134 .20601 L
.85251 .20601 L
.85379 .20601 L
.8552 .20601 L
.85666 .20601 L
.85803 .20601 L
.85931 .20601 L
.86048 .20601 L
.86183 .20601 L
.8631 .20601 L
.86448 .20601 L
.86595 .20601 L
.8672 .20601 L
.86858 .20601 L
.87006 .20601 L
.87165 .20601 L
.87315 .20601 L
.87452 .20601 L
.87588 .20601 L
.87715 .20601 L
.8783 .20601 L
.87953 .20601 L
.88089 .20601 L
.88232 .20601 L
.88354 .20601 L
.88487 .20601 L
.88613 .20601 L
.88727 .20601 L
.88859 .20601 L
.88984 .20601 L
Mistroke
.891 .20601 L
.89206 .20601 L
.89323 .20601 L
.89448 .20601 L
.89582 .20601 L
.89705 .20601 L
.8984 .20601 L
.89982 .20601 L
.90106 .20601 L
.90221 .20601 L
.90348 .20601 L
.90483 .20601 L
.90631 .20601 L
.90714 .20601 L
.90791 .20601 L
.90932 .20601 L
.91081 .20601 L
.91215 .20601 L
.9134 .20601 L
.91477 .20601 L
.91553 .20601 L
.91624 .20601 L
.91765 .20601 L
.91892 .20601 L
.92029 .20601 L
.92177 .20601 L
.92307 .20601 L
.92444 .20601 L
.92562 .20601 L
.9269 .20601 L
.92768 .20601 L
.92842 .20601 L
.9298 .20601 L
.93057 .20601 L
.93129 .20601 L
.93212 .20601 L
.9329 .20601 L
.9342 .20601 L
.93494 .20601 L
.93562 .20601 L
.93701 .20601 L
.93777 .20601 L
.9385 .20601 L
.93983 .20601 L
.94103 .20601 L
.94242 .20601 L
.94373 .20601 L
.94495 .20601 L
.94607 .20601 L
.9473 .20601 L
Mistroke
.94859 .20601 L
.94991 .20601 L
.95064 .20601 L
.95131 .20601 L
.95261 .20601 L
.95385 .20601 L
.95454 .20601 L
.95528 .20601 L
.95661 .20601 L
.95735 .20601 L
.95804 .20601 L
.95886 .20601 L
.95961 .20601 L
.96084 .20601 L
.96215 .20601 L
.96337 .20601 L
.96451 .20601 L
.96585 .20601 L
.96709 .20601 L
.96844 .20601 L
.96912 .20601 L
.96988 .20601 L
.9706 .20601 L
.97128 .20601 L
.97257 .20601 L
.97395 .20601 L
.97473 .20601 L
.97546 .20601 L
.97679 .20601 L
.97799 .20601 L
.97938 .20601 L
.98068 .20601 L
.9818 .20601 L
.98304 .20601 L
.98432 .20601 L
.98552 .20601 L
.98664 .20601 L
.98767 .20601 L
.98885 .20601 L
.98997 .20601 L
.99118 .20601 L
.99247 .20601 L
.99356 .20601 L
.99478 .20601 L
.99607 .20601 L
.9968 .20601 L
.99747 .20601 L
.9987 .20601 L
1 .20601 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13039,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo00?ooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooo
oom5ooooo`001Ol00002ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Gooooo00?o
0000ooooooooool0oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo00Co
A4A4omgMgOoooooo00001_ooool3o`000?ooooooAOooool000Oooooo00Go0000oooooooooooooooo
o`00000;ooooo`04omgMgOmEEEGoooooo`0000Kooooo00?o0000ooooooooool0oooooom5ooooo`00
1oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001_ooool00ol0003o
ooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^ko
A4A4o`000006ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Gooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool5o`0000Gooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool00ol0003oooooooooo`3oooooodGooooo0005o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0oooooom5ooooo`001ooo
ool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01Oooool3o`000?oooooo
AOooool000Oooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Cooooo
00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Gooooo00?o0000oooooooo
ool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c005ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo027ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@0Iooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l00000
0ol@413oooooooooo`0Gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l0
00001Ol@413oooooooooooooooooA4A400;o000000?o<S8bomgMgOooool06?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM03Wooooo000Qoooo
o`;o00008_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01oooool00omgMgOo<S8booooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B47ooooo`03o`000?oooooooooo00Kooooo00?oMgMgoc8b<_ooool06?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@06_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1oooool00omgMgOo<S8booooo`0hooooo`008Oooool00ol0003oooooooooo`0Qooooo`05oa0@4?oo
ooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000oooooooo
ool05oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool06Oooool01Ol@
413ooooooooooooooooo410@00kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0G
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Kooooo`05oa0@4?oo
ooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo03Oooooo
000Qooooo`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`00
0?ooooooooooooooool000001oooool00omgMgOo<S8booooo`0Hooooo`05o`000?oooooooooooooo
ool000003_ooool00ol0003oooooooooo`0Iooooo`05o`000?ooooooooooooooool000003_ooool0
0ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo01Sooooo00Go0000ooooooooooooooooo`00
000=ooooo`03oiRHV?lQ8B7ok^k^01[ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool0>?ooool0027ooooo00?o0000ooooooooool08Ooo
ool01Ol0003ooooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000004ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`06Oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000
ooooooooool06Oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<01Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo01Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00iooooo`008Oooool00ol0003oooooooooo`0Qoooo
o`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00Cooooo00?o
0000ooooooooool06oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool0
6Oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Kooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`0Hoooo
o`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo03_ooooo000Qooooo`03o`000?oooooooooo027ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00ol0003oooooooooo`0Kooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`0Iooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01_ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41006_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo03_ooooo
000Qooooo`;o00008_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP04ooooo`Co00006_ooool01?o^k^ko<S8bo`000?lb<S84o`0000Wooooo00?oEEEEofIV
I_l000006oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l000001Oooool4
o`0001[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
6_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004oooo
o`Co0000>_ooool0027ooooo00?o0000ooooooooool0Eoooool6o`0000;ooooo1Ol0003Pooooo`00
8Oooool00ol0003oooooooooo`1Cooooo`Co00003Oooool4o`000=cooooo000Qooooo`03o`000?oo
oooooooo04oooooo1?l0000Eooooo`03o`000?oooooooooo0<kooooo00?o410@o`000?l000000ol0
0005ooooo`008Oooool00ol0003oooooooooo`1<ooooo`?o00006_ooool2o`000=3ooooo00?o0000
ooooooooool01_ooool0027ooooo00?o0000ooooooooool0A?ooool8o`0001oooooo0ol0003=oooo
o`03o`000?oooooooooo00Kooooo000Qoooooooo0000<ol0000<ooooo`03o`000?oooooooooo00Ko
oooo000Qooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool01?l0003ooooo
ooooool00006ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool9o`0000;o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Co
oooo00?o0000oc8b<_oMgMd01_ooool0027ooooo00?o0000ooooooooool0<?ooool00ol0003ooooo
ooooo`0`ooooo`03o`000?oooooooooo00_ooooo0_l0000Cooooo`Go00002oooool00ol0003ooooo
ooooo`0`ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0>oooool2o`000004ojVY
ZOlQ8B7o0000ob4Q8@Cooooo000Qooooo`03o`000?oooooooooo07?ooooo0_l0000<ooooo`Go0000
__ooool0027ooooo00?o0000ooooooooool0MOooool<o`000<?ooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000
oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0
003oooooodKooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00005ooooo`03o`000?oooooooooo0?oo
ooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Gooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413o
oooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000?ooooooAOooool000Oo
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?o0000oooo
ooooool0oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIV
I_ooool01?ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05oa0@4?oooooooooooooo
ool@41003oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?ooooooAOooool000Oo
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001Oooool0
0ol0003oooooooooo`3oooooodGooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool0
1OnHV9So410@o`000?lQ8B7oc<c<00Gooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool2
o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom5oooo
o`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@
00_ooooo1Ol00005ooooo`?o0000oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo0000
00_ooooo00CoA4A4omgMgOoooooo00001_ooool00ol0003oooooooooo`3oooooodGooooo0007oooo
o`05o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00006ooooo`03o`000?oo
oooooooo0?ooooooAOooool000Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<
c<co000000Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00cooooo00?ok^k^odA4A?l000001_ooool00ol0003oooooooooo`3oooooodGooooo0007
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`05ooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool2o`00
0?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o
0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
0_l0003oooooodKooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c005
ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Gooooo00?o0000ooooooooool0oooo
oom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000oooooooooooooooo
o`000005ooooo`?o0000oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo
00Go0000oiRHV?ooooooV9RHob4Q8@05ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01Oooool00ol0
003oooooooooo`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41002oooool00omE
EEGoQhN7ooooo`07ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Oooooo00?o0000ooooooooool0oooooom5oooo
o`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@1Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo0_l0003oooooodKooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
1oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q
8Oo<c<`01Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@05ooooo`03o`000?oooooo
oooo0?ooooooAOooool000Oooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooo
ooooooooool000001Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05o`000?oooooo
ooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Gooooo0ol0003oooooodGooooo
0007ooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<00Go
oooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00_o
oooo00Go410@okZj^_oooooo^[Zjoa0@4005ooooo`03o`000?oooooooooo0?ooooooAOooool000Oo
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000001Oooool0
0ol0003oooooooooo`3oooooodGooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool0
1OnYZJWo410@o`000?l@413oZJVY00Gooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool001Sooooo1?l000000ol@413oooooooooo`02ooooo`03
o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooo
oom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`?o0000oooooom5ooooo`006_ooool00ol0
003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006?ooool00omEEEGoIVIVo`00003oooooodkooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo002Nooooo`05oiRHV?l0003o0000odA4A?nj
^[X06?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`Co000000Co410@oooo
oooooooooooo1?l000000ol@413oooooooooo`2=ooooo`007oooool01?l@413o0000o`000?l0001k
ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000Wooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo08oooooo
000Pooooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool06_ooool01Ol@413ooooooooo
oooooooo410@00kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2?ooooo`008?oo
ool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo00_ooooo1_l00009ooooo`05o`000?oo
ooooooooooooool000003_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo08oooooo
000Pooooo`06o`000?mgMgOo0000o`000?mEEEGok^k^N?ooool00ol0003oooooooooo`0Jooooo`05
o`000?ooooooooooooooool000003_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
08oooooo000Pooooo`06o`000?mEEEGok^k^oooooomgMgOoEEEEM_ooool00ol@413o0000o`000003
o`0001Wooooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0Soooool0023ooooo00?o0000onk^k_ooool00_ooool00ol0003oooooooooo`1f
ooooo`03o`000?oooooooooo01[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0Soooool0023ooooo00?o0000onk^k_ooool00_ooool0
0ol0003oooooooooo`1fooooo`03o`000?oooooooooo01[ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0<ooooo`03oeEEEOmVIVKo000000Gooooo00?oEEEEofIVI_l00000TOooool0023ooooo00Ko0000
oeEEEOo^k^koooooogMgMomVIVKooooood?ooooo000Oooooo`03oa0@4?l0003oMgMg00;o000000?o
IVIVonk^k_ooool0oooooom2ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.0332543, -0.540631, \
0.00122928, 0.00994506}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 3.33333 0.206011 0.412023 [
[.16667 .19351 -12 -9 ]
[.16667 .19351 12 0 ]
[.33333 .19351 -9 -9 ]
[.33333 .19351 9 0 ]
[.5 .19351 -12 -9 ]
[.5 .19351 12 0 ]
[.66667 .19351 -9 -9 ]
[.66667 .19351 9 0 ]
[.83333 .19351 -12 -9 ]
[.83333 .19351 12 0 ]
[1.025 .20601 0 -6 ]
[1.025 .20601 10 6 ]
[-0.0125 .0412 -24 -4.5 ]
[-0.0125 .0412 0 4.5 ]
[-0.0125 .12361 -24 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .28842 -18 -4.5 ]
[-0.0125 .28842 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .45322 -18 -4.5 ]
[-0.0125 .45322 0 4.5 ]
[-0.0125 .53563 -18 -4.5 ]
[-0.0125 .53563 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 .20601 m
.16667 .21226 L
s
[(0.05)] .16667 .19351 0 1 Mshowa
.33333 .20601 m
.33333 .21226 L
s
[(0.1)] .33333 .19351 0 1 Mshowa
.5 .20601 m
.5 .21226 L
s
[(0.15)] .5 .19351 0 1 Mshowa
.66667 .20601 m
.66667 .21226 L
s
[(0.2)] .66667 .19351 0 1 Mshowa
.83333 .20601 m
.83333 .21226 L
s
[(0.25)] .83333 .19351 0 1 Mshowa
.125 Mabswid
.03333 .20601 m
.03333 .20976 L
s
.06667 .20601 m
.06667 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.13333 .20601 m
.13333 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.23333 .20601 m
.23333 .20976 L
s
.26667 .20601 m
.26667 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.36667 .20601 m
.36667 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.43333 .20601 m
.43333 .20976 L
s
.46667 .20601 m
.46667 .20976 L
s
.53333 .20601 m
.53333 .20976 L
s
.56667 .20601 m
.56667 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.63333 .20601 m
.63333 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.73333 .20601 m
.73333 .20976 L
s
.76667 .20601 m
.76667 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.86667 .20601 m
.86667 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.93333 .20601 m
.93333 .20976 L
s
.96667 .20601 m
.96667 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
gsave
1.025 .20601 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .0412 m
.00625 .0412 L
s
[(-0.4)] -0.0125 .0412 1 0 Mshowa
0 .12361 m
.00625 .12361 L
s
[(-0.2)] -0.0125 .12361 1 0 Mshowa
0 .28842 m
.00625 .28842 L
s
[(0.2)] -0.0125 .28842 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.4)] -0.0125 .37082 1 0 Mshowa
0 .45322 m
.00625 .45322 L
s
[(0.6)] -0.0125 .45322 1 0 Mshowa
0 .53563 m
.00625 .53563 L
s
[(0.8)] -0.0125 .53563 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .10301 m
.00375 .10301 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .30902 m
.00375 .30902 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .39142 m
.00375 .39142 L
s
0 .41202 m
.00375 .41202 L
s
0 .43262 m
.00375 .43262 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .51503 m
.00375 .51503 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
0 .0206 m
.00375 .0206 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.12) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .20601 m
.00123 .20601 L
.00236 .20601 L
.00365 .20601 L
.00488 .20601 L
.00601 .20601 L
.00706 .20601 L
.00942 .20601 L
.01066 .20601 L
.01181 .20601 L
.01318 .20601 L
.01444 .20601 L
.017 .20601 L
.01841 .20601 L
.01975 .20601 L
.02225 .20601 L
.02491 .20601 L
.02742 .20601 L
.0297 .20601 L
.03239 .20601 L
.0339 .20601 L
.0353 .20601 L
.03786 .20601 L
.03915 .20601 L
.04057 .20601 L
.04199 .20601 L
.04353 .20601 L
.0449 .20601 L
.04634 .20601 L
.04764 .20601 L
.04908 .20601 L
.05161 .20601 L
.05314 .20601 L
.05455 .20601 L
.05606 .20601 L
.05772 .20601 L
.06051 .20601 L
.06203 .20601 L
.06345 .20601 L
.06478 .20601 L
.06623 .20601 L
.06886 .20601 L
.07142 .20601 L
.07378 .20601 L
.07633 .20601 L
.07913 .20601 L
.08055 .20601 L
.08207 .20601 L
.08481 .20601 L
.08748 .20601 L
Mistroke
.09033 .20601 L
.09301 .20601 L
.09545 .20601 L
.09832 .20601 L
.09994 .20601 L
.10142 .20601 L
.10416 .20601 L
.10704 .20601 L
.10956 .20601 L
.11225 .20601 L
.1148 .20601 L
.11711 .20601 L
.11983 .20601 L
.12278 .20601 L
.12557 .20601 L
.12815 .20601 L
.1307 .20601 L
.13303 .20601 L
.13559 .20601 L
.13828 .20601 L
.14064 .20601 L
.14283 .20601 L
.14523 .20601 L
.14779 .20601 L
.15059 .20601 L
.15363 .20601 L
.1565 .20601 L
.15914 .20601 L
.16152 .20601 L
.16414 .20601 L
.16688 .20601 L
.16943 .20601 L
.17468 .20601 L
.17764 .20601 L
.18039 .20601 L
.18542 .206 L
.18797 .206 L
.19078 .206 L
.19561 .20599 L
.19833 .20599 L
.20082 .20598 L
.20541 .20597 L
.21025 .20595 L
.21549 .20593 L
.22026 .20589 L
.22576 .20584 L
.23096 .20577 L
.23577 .20568 L
.2402 .20557 L
.24507 .20542 L
Mistroke
.25023 .20522 L
.2554 .20496 L
.26013 .20465 L
.26521 .20425 L
.27076 .20372 L
.28062 .20246 L
.28998 .20088 L
.31238 .19574 L
.32296 .19309 L
.33268 .19097 L
.33763 .19015 L
.34012 .18982 L
.34285 .18954 L
.34429 .18943 L
.3456 .18935 L
.34632 .18931 L
.34711 .18928 L
.34786 .18926 L
.34854 .18925 L
.34977 .18924 L
.35112 .18926 L
.3518 .18928 L
.35253 .1893 L
.35385 .18937 L
.35511 .18946 L
.35627 .18957 L
.35892 .18988 L
.3615 .19029 L
.36425 .19085 L
.36925 .19214 L
.37379 .19363 L
.39395 .20287 L
.40435 .20822 L
.41579 .21341 L
.42099 .21531 L
.42658 .21696 L
.42929 .2176 L
.43186 .21811 L
.43439 .21851 L
.43667 .2188 L
.43795 .21892 L
.43933 .21903 L
.44009 .21908 L
.44079 .21912 L
.44216 .21918 L
.44335 .21921 L
.44464 .21922 L
.44599 .21921 L
.44725 .21918 L
.44797 .21916 L
Mistroke
.44875 .21912 L
.45017 .21904 L
.45282 .21884 L
.45591 .21851 L
.45877 .21814 L
.46892 .21641 L
.47843 .21447 L
.48953 .21222 L
.50008 .21034 L
.51024 .2089 L
.51561 .20829 L
.52133 .20776 L
.52662 .20736 L
.53141 .20706 L
.53588 .20683 L
.54078 .20663 L
.54589 .20647 L
.5513 .20634 L
.5563 .20625 L
.56098 .20618 L
.56649 .20613 L
.57152 .20609 L
.57431 .20608 L
.57733 .20606 L
.57998 .20606 L
.58283 .20605 L
.58549 .20604 L
.58792 .20603 L
.5927 .20603 L
.59523 .20602 L
.598 .20602 L
.60093 .20602 L
.60359 .20602 L
.60624 .20602 L
.60911 .20602 L
.61215 .20601 L
.61501 .20601 L
.6177 .20601 L
.62054 .20601 L
.62297 .20601 L
.62564 .20601 L
.62826 .20601 L
.63111 .20601 L
.63381 .20601 L
.63631 .20601 L
.63878 .20601 L
.64103 .20601 L
.64362 .20601 L
.64605 .20601 L
.64873 .20601 L
Mistroke
.65155 .20601 L
.65395 .20601 L
.6566 .20601 L
.65944 .20601 L
.66249 .20601 L
.66537 .20601 L
.66799 .20601 L
.67039 .20601 L
.67305 .20601 L
.67582 .20601 L
.67842 .20601 L
.68084 .20601 L
.68306 .20601 L
.68549 .20601 L
.68806 .20601 L
.69067 .20601 L
.69346 .20601 L
.69609 .20601 L
.69848 .20601 L
.70129 .20601 L
.70288 .20601 L
.70434 .20601 L
.70703 .20601 L
.70838 .20601 L
.70987 .20601 L
.71249 .20601 L
.71398 .20601 L
.71535 .20601 L
.71788 .20601 L
.71915 .20601 L
.72056 .20601 L
.72298 .20601 L
.72434 .20601 L
.72559 .20601 L
.72789 .20601 L
.73032 .20601 L
.73169 .20601 L
.73294 .20601 L
.73428 .20601 L
.73574 .20601 L
.73709 .20601 L
.73834 .20601 L
.74079 .20601 L
.74216 .20601 L
.74344 .20601 L
.74497 .20601 L
.74636 .20601 L
.74921 .20601 L
.75077 .20601 L
.75226 .20601 L
Mistroke
.75357 .20601 L
.75498 .20601 L
.75623 .20601 L
.75755 .20601 L
.75874 .20601 L
.76004 .20601 L
.76233 .20601 L
.76374 .20601 L
.76501 .20601 L
.76639 .20601 L
.76789 .20601 L
.76927 .20601 L
.77055 .20601 L
.77176 .20601 L
.77307 .20601 L
.77426 .20601 L
.77536 .20601 L
.77752 .20601 L
.77866 .20601 L
.77991 .20601 L
.78123 .20601 L
.78243 .20601 L
.78492 .20601 L
.78629 .20601 L
.78758 .20601 L
.78988 .20601 L
.79118 .20601 L
.79238 .20601 L
.79369 .20601 L
.79494 .20601 L
.79728 .20601 L
.79859 .20601 L
.79981 .20601 L
.80123 .20601 L
.80256 .20601 L
.80372 .20601 L
.80498 .20601 L
.80717 .20601 L
.80842 .20601 L
.80973 .20601 L
.81208 .20601 L
.81344 .20601 L
.81467 .20601 L
.81609 .20601 L
.81743 .20601 L
.8186 .20601 L
.81983 .20601 L
.82118 .20601 L
.82242 .20601 L
.82376 .20601 L
Mistroke
.82521 .20601 L
.82657 .20601 L
.82781 .20601 L
.82927 .20601 L
.83086 .20601 L
.83236 .20601 L
.83376 .20601 L
.8351 .20601 L
.83653 .20601 L
.83774 .20601 L
.83908 .20601 L
.84052 .20601 L
.84206 .20601 L
.84351 .20601 L
.84484 .20601 L
.84617 .20601 L
.84741 .20601 L
.84876 .20601 L
.8502 .20601 L
.85145 .20601 L
.85262 .20601 L
.8539 .20601 L
.85529 .20601 L
.85651 .20601 L
.85765 .20601 L
.85891 .20601 L
.86025 .20601 L
.86165 .20601 L
.86298 .20601 L
.86418 .20601 L
.86547 .20601 L
.8666 .20601 L
.86783 .20601 L
.86912 .20601 L
.87033 .20601 L
.87144 .20601 L
.87249 .20601 L
.87371 .20601 L
.87482 .20601 L
.87613 .20601 L
.87754 .20601 L
.87888 .20601 L
.88011 .20601 L
.88122 .20601 L
.88244 .20601 L
.88371 .20601 L
.8849 .20601 L
.88629 .20601 L
.88761 .20601 L
.88879 .20601 L
Mistroke
.89008 .20601 L
.89148 .20601 L
.89297 .20601 L
.89424 .20601 L
.89563 .20601 L
.89685 .20601 L
.89814 .20601 L
.89923 .20601 L
.90043 .20601 L
.90173 .20601 L
.90311 .20601 L
.90441 .20601 L
.9056 .20601 L
.9068 .20601 L
.90791 .20601 L
.90912 .20601 L
.91041 .20601 L
.91153 .20601 L
.91257 .20601 L
.91372 .20601 L
.91495 .20601 L
.91635 .20601 L
.91763 .20601 L
.9191 .20601 L
.92048 .20601 L
.92176 .20601 L
.92294 .20601 L
.92424 .20601 L
.9256 .20601 L
.92699 .20601 L
.92847 .20601 L
.92987 .20601 L
.93114 .20601 L
.93263 .20601 L
.93348 .20601 L
.93426 .20601 L
.93569 .20601 L
.9372 .20601 L
.93851 .20601 L
.9397 .20601 L
.94108 .20601 L
.94239 .20601 L
.9436 .20601 L
.94471 .20601 L
.94594 .20601 L
.94725 .20601 L
.94869 .20601 L
.94949 .20601 L
.95024 .20601 L
.95161 .20601 L
Mistroke
.95305 .20601 L
.95435 .20601 L
.95556 .20601 L
.95689 .20601 L
.95832 .20601 L
.95954 .20601 L
.9609 .20601 L
.96231 .20601 L
.96364 .20601 L
.96488 .20601 L
.96601 .20601 L
.96726 .20601 L
.96857 .20601 L
.9699 .20601 L
.97064 .20601 L
.97133 .20601 L
.97267 .20601 L
.97389 .20601 L
.9746 .20601 L
.97535 .20601 L
.97669 .20601 L
.97744 .20601 L
.97813 .20601 L
.97896 .20601 L
.97972 .20601 L
.98097 .20601 L
.98234 .20601 L
.98355 .20601 L
.98483 .20601 L
.98609 .20601 L
.98728 .20601 L
.98834 .20601 L
.9895 .20601 L
.99077 .20601 L
.99216 .20601 L
.99286 .20601 L
.99361 .20601 L
.99497 .20601 L
.99632 .20601 L
.9976 .20601 L
.99875 .20601 L
1 .20601 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13039,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo00?ooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooo
oom5ooooo`001Ol00002ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Gooooo00?o
0000ooooooooool0oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo00Co
A4A4omgMgOoooooo00001_ooool3o`000?ooooooAOooool000Oooooo00Go0000oooooooooooooooo
o`00000;ooooo`04omgMgOmEEEGoooooo`0000Kooooo00?o0000ooooooooool0oooooom5ooooo`00
1oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001_ooool00ol0003o
ooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^ko
A4A4o`000006ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Gooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool5o`0000Gooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool00ol0003oooooooooo`3oooooodGooooo0005o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0oooooom5ooooo`001ooo
ool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01Oooool3o`000?oooooo
AOooool000Oooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Cooooo
00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Gooooo00?o0000oooooooo
ool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c005ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo027ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@0Iooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l00000
0ol@413oooooooooo`0Gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l0
00001Ol@413oooooooooooooooooA4A400;o000000?o<S8bomgMgOooool06?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM03Wooooo000Qoooo
o`;o00008_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01oooool00omgMgOo<S8booooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B47ooooo`03o`000?oooooooooo00Kooooo00?oMgMgoc8b<_ooool06?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@06_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1oooool00omgMgOo<S8booooo`0hooooo`008Oooool00ol0003oooooooooo`0Qooooo`05oa0@4?oo
ooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000oooooooo
ool05oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool06Oooool01Ol@
413ooooooooooooooooo410@00kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0G
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Kooooo`05oa0@4?oo
ooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo03Oooooo
000Qooooo`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`00
0?ooooooooooooooool000001oooool00omgMgOo<S8booooo`0Hooooo`05o`000?oooooooooooooo
ool000003_ooool00ol0003oooooooooo`0Iooooo`05o`000?ooooooooooooooool000003_ooool0
0ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo01Sooooo00Go0000ooooooooooooooooo`00
000=ooooo`03oiRHV?lQ8B7ok^k^01[ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool0>?ooool0027ooooo00?o0000ooooooooool08Ooo
ool01Ol0003ooooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000004ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`06Oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000
ooooooooool06Oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<01Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo01Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00iooooo`008Oooool00ol0003oooooooooo`0Qoooo
o`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00Cooooo00?o
0000ooooooooool06oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool0
6Oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Kooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`0Hoooo
o`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo03_ooooo000Qooooo`03o`000?oooooooooo027ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00ol0003oooooooooo`0Kooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`0Iooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01_ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41006_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo03_ooooo
000Qooooo`;o00008_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP04ooooo`Co00006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIV
I_l000006oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l000001Oooool4
o`0001[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
6_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004oooo
o`Co0000>_ooool0027ooooo00?o0000ooooooooool0H_ooool<o`000=Kooooo000Qooooo`03o`00
0?oooooooooo05oooooo0ol0000<ooooo`?o0000doooool0027ooooo00?o0000ooooooooool0Fooo
ool4o`0001;ooooo0_l00036ooooo`03oa0@4?l0003o000000?o00001Oooool0027ooooo00?o0000
ooooooooool0F?ooool3o`0001Sooooo0_l00036ooooo`03o`000?oooooooooo00Kooooo000Qoooo
o`03o`000?oooooooooo04oooooo2Ol0000Mooooo`;o0000a?ooool00ol0003oooooooooo`06oooo
o`008Oooooooo`0003?o00003?ooool00ol0003oooooooooo`06ooooo`008Oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
o`000002o`0000Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`So0000
0oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Cooooo00?o0000oc8b<_oMgMd0
1_ooool0027ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0`ooooo`03o`000?oo
oooooooo01Kooooo0_l0000Cooooo`Co000000?oooooo`000?ooool0<Oooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo03_ooooo0_l000001?nYZJWo8B4Qo`000?lQ8B44ooooo`008Ooo
ool00ol0003oooooooooo`1nooooo`;o00002oooool6o`000;?ooooo000Qooooo`03o`000?oooooo
oooo083ooooo2ol0002iooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o
0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`Go00001Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`03
o`000?oooooooooo0?ooooooAOooool000Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03
oiRHV?lQ8B7ok^k^00Kooooo0ol0003oooooodGooooo0007ooooo`05o`000?ooooooooooooooool0
00003Oooool00onHV9So8B4Qonk^kP05ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo
00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Cooooo00?o0000oooooooo
ool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Gooooo00?o0000ooooooooool0oooooom5oooo
o`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c005
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo0_l0003oooooodKooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413o
ooooooooo`03ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oo
ooooAOooool000Oooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00001Oooool3o`000?oo
ooooAOooool000Oooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`00
00Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo0000
00_ooooo00CogMgMoeEEEOoooooo00001_ooool00ol0003oooooooooo`3oooooodGooooo0007oooo
o`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000006ooooo`03o`000?oooooo
oooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co
000000Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00gooooo00?oMgMgo`000?ooool01Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01Oooool00ol0003oooooooooo`3ooooo
odGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMg
MoooooooV9RHob4Q8@05ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go410@oooo
oooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001Oooool3o`000?ooooooAOoo
ool000Oooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40
1Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05o`000?ooooooooooooooool00000
2oooool01Ol0003oEEEEo`000?l@413oc<c<00Gooooo00?o0000ooooooooool0oooooom5ooooo`00
1oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool01oooool00ol0003o
ooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo
410@oiRHV007ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Gooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Gooooo00?o0000oooooooo
ool0oooooom5ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B401Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000
ooooooooool0oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8b
oiRHV?ooooooV9RHoc8b<P05ooooo`?o0000oooooom5ooooo`001oooool01Ol0003ooooooooooooo
oooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c005ooooo`03o`000?oooooooooo0?oooooo
AOooool000Oooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@
41001Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Gooooo00?o0000ooooooooool0oooooom5oooo
o`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@05
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo0_l0003oooooodKooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodGooooo
000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000oooo
ooooool01?ooool3o`000?ooooooAOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001Sooooo00?oEEEEofIVI_l00000oooooom>ooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00W_ooool01OnHV9So0000o`000?m4A4Co^[Zj01Sooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool4o`000003oa0@4?oooooooooo00Go0000T?ooool001oooooo
00Co410@o`000?l0003o0000Noooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l00009oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool00_ooool0
1OnHV9So8B4Qonk^k_ooooooA4A4093ooooo000Pooooo`03o`000?oooooooooo07_ooooo00?o0000
ooooooooool06_ooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool00ooo
ool00onHV9So8B4Qonk^kP2Aooooo`008?ooool00ol0003oooooooooo`1kooooo`03o`000?oooooo
oooo00_ooooo1_l00009ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003ooooooooo
o`04ooooo`03oiRHV?lQ8B7ok^k^093ooooo000Pooooo`06o`000?mgMgOo0000o`000?mEEEGok^k^
N?ooool00ol0003oooooooooo`0Jooooo`05o`000?ooooooooooooooool000003_ooool00ol0003o
ooooooooo`05ooooo`03ogMgMomVIVKooooo08oooooo000Pooooo`06o`000?mEEEGok^k^oooooomg
MgOoEEEEM_ooool00ol@413o0000o`000003o`0001Wooooo00Go410@oooooooooooooooooa0@400>
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0S_ooool0023ooooo00?o0000onk^
k_ooool00_ooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo01[ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0>ooooo`03o`000?oooooooooo00;ooooo00Go0000okZj^_ooooooV9RHoa0@
402@ooooo`008?ooool00ol0003ok^k^ooooo`02ooooo`03o`000?oooooooooo07Kooooo00?o0000
ooooooooool06_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l000001?oo
ool01OnHV9So410@o`000?lQ8B7oc<c<093ooooo000Pooooo`06o`000?mEEEGok^k^oooooomgMgOo
IVIVoooooom3ooooo`007oooool00ol@413o0000ogMgM`02o`000003ofIVI_o^k^kooooo0?oooooo
@_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.0332543, -0.540631, \
0.00122928, 0.00994506}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 3.33333 0.206011 0.412023 [
[.16667 .19351 -12 -9 ]
[.16667 .19351 12 0 ]
[.33333 .19351 -9 -9 ]
[.33333 .19351 9 0 ]
[.5 .19351 -12 -9 ]
[.5 .19351 12 0 ]
[.66667 .19351 -9 -9 ]
[.66667 .19351 9 0 ]
[.83333 .19351 -12 -9 ]
[.83333 .19351 12 0 ]
[1.025 .20601 0 -6 ]
[1.025 .20601 10 6 ]
[-0.0125 .0412 -24 -4.5 ]
[-0.0125 .0412 0 4.5 ]
[-0.0125 .12361 -24 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .28842 -18 -4.5 ]
[-0.0125 .28842 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .45322 -18 -4.5 ]
[-0.0125 .45322 0 4.5 ]
[-0.0125 .53563 -18 -4.5 ]
[-0.0125 .53563 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 .20601 m
.16667 .21226 L
s
[(0.05)] .16667 .19351 0 1 Mshowa
.33333 .20601 m
.33333 .21226 L
s
[(0.1)] .33333 .19351 0 1 Mshowa
.5 .20601 m
.5 .21226 L
s
[(0.15)] .5 .19351 0 1 Mshowa
.66667 .20601 m
.66667 .21226 L
s
[(0.2)] .66667 .19351 0 1 Mshowa
.83333 .20601 m
.83333 .21226 L
s
[(0.25)] .83333 .19351 0 1 Mshowa
.125 Mabswid
.03333 .20601 m
.03333 .20976 L
s
.06667 .20601 m
.06667 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.13333 .20601 m
.13333 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.23333 .20601 m
.23333 .20976 L
s
.26667 .20601 m
.26667 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.36667 .20601 m
.36667 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.43333 .20601 m
.43333 .20976 L
s
.46667 .20601 m
.46667 .20976 L
s
.53333 .20601 m
.53333 .20976 L
s
.56667 .20601 m
.56667 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.63333 .20601 m
.63333 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.73333 .20601 m
.73333 .20976 L
s
.76667 .20601 m
.76667 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.86667 .20601 m
.86667 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.93333 .20601 m
.93333 .20976 L
s
.96667 .20601 m
.96667 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
gsave
1.025 .20601 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .0412 m
.00625 .0412 L
s
[(-0.4)] -0.0125 .0412 1 0 Mshowa
0 .12361 m
.00625 .12361 L
s
[(-0.2)] -0.0125 .12361 1 0 Mshowa
0 .28842 m
.00625 .28842 L
s
[(0.2)] -0.0125 .28842 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.4)] -0.0125 .37082 1 0 Mshowa
0 .45322 m
.00625 .45322 L
s
[(0.6)] -0.0125 .45322 1 0 Mshowa
0 .53563 m
.00625 .53563 L
s
[(0.8)] -0.0125 .53563 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .10301 m
.00375 .10301 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .30902 m
.00375 .30902 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .39142 m
.00375 .39142 L
s
0 .41202 m
.00375 .41202 L
s
0 .43262 m
.00375 .43262 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .51503 m
.00375 .51503 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
0 .0206 m
.00375 .0206 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.13) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .20601 m
.00123 .20601 L
.00236 .20601 L
.00365 .20601 L
.00488 .20601 L
.00601 .20601 L
.00706 .20601 L
.00942 .20601 L
.01066 .20601 L
.01181 .20601 L
.01318 .20601 L
.01444 .20601 L
.017 .20601 L
.01841 .20601 L
.01975 .20601 L
.02225 .20601 L
.02364 .20601 L
.02491 .20601 L
.0261 .20601 L
.02738 .20601 L
.0297 .20601 L
.03101 .20601 L
.03245 .20601 L
.03386 .20601 L
.03536 .20601 L
.03677 .20601 L
.03805 .20601 L
.04057 .20601 L
.04187 .20601 L
.04331 .20601 L
.04471 .20601 L
.04622 .20601 L
.04763 .20601 L
.04892 .20601 L
.05145 .20601 L
.05288 .20601 L
.0542 .20601 L
.05578 .20601 L
.05722 .20601 L
.06015 .20601 L
.06176 .20601 L
.06329 .20601 L
.0659 .20601 L
.06721 .20601 L
.06866 .20601 L
.06989 .20601 L
.07122 .20601 L
.07361 .20601 L
.07505 .20601 L
.07661 .20601 L
Mistroke
.07799 .20601 L
.07946 .20601 L
.08092 .20601 L
.08224 .20601 L
.08481 .20601 L
.08726 .20601 L
.08865 .20601 L
.08994 .20601 L
.09256 .20601 L
.09403 .20601 L
.09536 .20601 L
.09775 .20601 L
.10034 .20601 L
.10279 .20601 L
.10506 .20601 L
.10766 .20601 L
.11011 .20601 L
.11279 .20601 L
.11429 .20601 L
.11567 .20601 L
.1183 .20601 L
.12116 .20601 L
.12261 .20601 L
.12415 .20601 L
.12693 .20601 L
.12966 .20601 L
.13255 .20601 L
.13501 .20601 L
.13772 .20601 L
.14063 .20601 L
.14226 .20601 L
.14375 .20601 L
.14664 .20601 L
.14939 .20601 L
.15194 .20601 L
.15465 .20601 L
.15697 .20601 L
.15953 .20601 L
.16226 .20601 L
.16522 .20601 L
.168 .20601 L
.17056 .20601 L
.17316 .20601 L
.17553 .20601 L
.17826 .20601 L
.18084 .20601 L
.18322 .20601 L
.18543 .20601 L
.18784 .20601 L
.19041 .20601 L
Mistroke
.19298 .20601 L
.19575 .20601 L
.19836 .20601 L
.20075 .20601 L
.20354 .20601 L
.20659 .20601 L
.20946 .20601 L
.21213 .20601 L
.21747 .20601 L
.22047 .206 L
.22324 .206 L
.22833 .206 L
.23089 .20599 L
.2337 .20599 L
.23858 .20598 L
.24131 .20597 L
.24381 .20596 L
.24865 .20594 L
.25324 .20591 L
.25806 .20587 L
.26339 .20581 L
.26894 .20572 L
.27416 .20561 L
.27902 .20547 L
.28347 .20532 L
.28836 .2051 L
.29351 .20481 L
.30354 .20402 L
.30915 .20344 L
.31425 .2028 L
.33354 .19945 L
.3554 .19449 L
.36499 .19252 L
.37045 .19165 L
.37306 .19131 L
.37554 .19106 L
.37791 .19087 L
.37925 .1908 L
.38049 .19075 L
.38164 .19072 L
.38268 .1907 L
.38388 .1907 L
.38501 .19072 L
.38625 .19076 L
.38756 .19083 L
.38868 .1909 L
.3899 .191 L
.39263 .1913 L
.39518 .19168 L
.40043 .19274 L
Mistroke
.40521 .19405 L
.41595 .19797 L
.43774 .20808 L
.44732 .21217 L
.4524 .21401 L
.45787 .21565 L
.46314 .21687 L
.46797 .21765 L
.47029 .21792 L
.47152 .21803 L
.47282 .21813 L
.47408 .2182 L
.47521 .21825 L
.47636 .21828 L
.47744 .2183 L
.47864 .2183 L
.47996 .21828 L
.48134 .21824 L
.48263 .21819 L
.48383 .21813 L
.48493 .21805 L
.4874 .21785 L
.49294 .21721 L
.49819 .21642 L
.51731 .21285 L
.5282 .2109 L
.53842 .20936 L
.54841 .20821 L
.55918 .20733 L
.56478 .20699 L
.57068 .20672 L
.57572 .20654 L
.58123 .20639 L
.58678 .20628 L
.59201 .2062 L
.59671 .20615 L
.60181 .20611 L
.60737 .20608 L
.61017 .20606 L
.61325 .20605 L
.61588 .20605 L
.6187 .20604 L
.62381 .20603 L
.62648 .20603 L
.62932 .20602 L
.63444 .20602 L
.63757 .20602 L
.64052 .20602 L
.64317 .20601 L
.64603 .20601 L
Mistroke
.64858 .20601 L
.65138 .20601 L
.6543 .20601 L
.65703 .20601 L
.65953 .20601 L
.66191 .20601 L
.66464 .20601 L
.66713 .20601 L
.66963 .20601 L
.67196 .20601 L
.67453 .20601 L
.67729 .20601 L
.68003 .20601 L
.68292 .20601 L
.68538 .20601 L
.68807 .20601 L
.69061 .20601 L
.69292 .20601 L
.69559 .20601 L
.6981 .20601 L
.70043 .20601 L
.70258 .20601 L
.70493 .20601 L
.70742 .20601 L
.71009 .20601 L
.71261 .20601 L
.71488 .20601 L
.71735 .20601 L
.72003 .20601 L
.72288 .20601 L
.72532 .20601 L
.72801 .20601 L
.73049 .20601 L
.73278 .20601 L
.73528 .20601 L
.73792 .20601 L
.74023 .20601 L
.74237 .20601 L
.74473 .20601 L
.74725 .20601 L
.74853 .20601 L
.74995 .20601 L
.75134 .20601 L
.75283 .20601 L
.75421 .20601 L
.75549 .20601 L
.75798 .20601 L
.75946 .20601 L
.76083 .20601 L
.76247 .20601 L
Mistroke
.76395 .20601 L
.76669 .20601 L
.7682 .20601 L
.76962 .20601 L
.7722 .20601 L
.77349 .20601 L
.77491 .20601 L
.77613 .20601 L
.77743 .20601 L
.77978 .20601 L
.7812 .20601 L
.78273 .20601 L
.78409 .20601 L
.78553 .20601 L
.78682 .20601 L
.78825 .20601 L
.78956 .20601 L
.79077 .20601 L
.79324 .20601 L
.79454 .20601 L
.79594 .20601 L
.7974 .20601 L
.79878 .20601 L
.80004 .20601 L
.80137 .20601 L
.80253 .20601 L
.8038 .20601 L
.80604 .20601 L
.8073 .20601 L
.80865 .20601 L
.81109 .20601 L
.81255 .20601 L
.8139 .20601 L
.81538 .20601 L
.81696 .20601 L
.81847 .20601 L
.81989 .20601 L
.82118 .20601 L
.82254 .20601 L
.82379 .20601 L
.82516 .20601 L
.82756 .20601 L
.82892 .20601 L
.83037 .20601 L
.83299 .20601 L
.83428 .20601 L
.83569 .20601 L
.83717 .20601 L
.83856 .20601 L
.83983 .20601 L
Mistroke
.84104 .20601 L
.84243 .20601 L
.84371 .20601 L
.8451 .20601 L
.84659 .20601 L
.84799 .20601 L
.84927 .20601 L
.85077 .20601 L
.8524 .20601 L
.85393 .20601 L
.85534 .20601 L
.85656 .20601 L
.85788 .20601 L
.85901 .20601 L
.86024 .20601 L
.86168 .20601 L
.86305 .20601 L
.86439 .20601 L
.86562 .20601 L
.86682 .20601 L
.86812 .20601 L
.86955 .20601 L
.87089 .20601 L
.87231 .20601 L
.87381 .20601 L
.87508 .20601 L
.87648 .20601 L
.87787 .20601 L
.87914 .20601 L
.88054 .20601 L
.88203 .20601 L
.88331 .20601 L
.88452 .20601 L
.88584 .20601 L
.88726 .20601 L
.88851 .20601 L
.88988 .20601 L
.89118 .20601 L
.89238 .20601 L
.89354 .20601 L
.89464 .20601 L
.89591 .20601 L
.89706 .20601 L
.89833 .20601 L
.89973 .20601 L
.9012 .20601 L
.90256 .20601 L
.90384 .20601 L
.90501 .20601 L
.90635 .20601 L
Mistroke
.90762 .20601 L
.909 .20601 L
.91047 .20601 L
.91172 .20601 L
.9131 .20601 L
.91458 .20601 L
.91617 .20601 L
.91767 .20601 L
.91905 .20601 L
.92039 .20601 L
.92166 .20601 L
.9228 .20601 L
.92403 .20601 L
.92538 .20601 L
.9268 .20601 L
.92802 .20601 L
.92936 .20601 L
.9306 .20601 L
.93174 .20601 L
.93306 .20601 L
.93431 .20601 L
.93546 .20601 L
.93652 .20601 L
.93769 .20601 L
.93894 .20601 L
.94041 .20601 L
.94177 .20601 L
.94325 .20601 L
.94482 .20601 L
.94619 .20601 L
.94746 .20601 L
.94886 .20601 L
.95035 .20601 L
.95169 .20601 L
.95313 .20601 L
.9545 .20601 L
.95576 .20601 L
.9569 .20601 L
.95815 .20601 L
.95946 .20601 L
.96068 .20601 L
.96194 .20601 L
.96329 .20601 L
.96456 .20601 L
.96571 .20601 L
.96707 .20601 L
.96854 .20601 L
.96993 .20601 L
.97121 .20601 L
.97241 .20601 L
Mistroke
.97353 .20601 L
.97475 .20601 L
.97607 .20601 L
.97745 .20601 L
.97876 .20601 L
.97994 .20601 L
.98121 .20601 L
.98237 .20601 L
.98346 .20601 L
.98466 .20601 L
.98594 .20601 L
.98722 .20601 L
.98857 .20601 L
.98971 .20601 L
.99097 .20601 L
.99216 .20601 L
.99323 .20601 L
.99447 .20601 L
.99565 .20601 L
.99673 .20601 L
.99774 .20601 L
.99884 .20601 L
1 .20601 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13039,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo00?ooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooo
oom5ooooo`001Ol00002ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Gooooo00?o
0000ooooooooool0oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo00Co
A4A4omgMgOoooooo00001_ooool3o`000?ooooooAOooool000Oooooo00Go0000oooooooooooooooo
o`00000;ooooo`04omgMgOmEEEGoooooo`0000Kooooo00?o0000ooooooooool0oooooom5ooooo`00
1oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001_ooool00ol0003o
ooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^ko
A4A4o`000006ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Gooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool5o`0000Gooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool00ol0003oooooooooo`3oooooodGooooo0005o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0oooooom5ooooo`001ooo
ool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01Oooool3o`000?oooooo
AOooool000Oooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Cooooo
00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Gooooo00?o0000oooooooo
ool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c005ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo027ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@0Iooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l00000
0ol@413oooooooooo`0Gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l0
00001Ol@413oooooooooooooooooA4A400;o000000?o<S8bomgMgOooool06?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM03Wooooo000Qoooo
o`;o00008_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01oooool00omgMgOo<S8booooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B47ooooo`03o`000?oooooooooo00Kooooo00?oMgMgoc8b<_ooool06?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@06_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1oooool00omgMgOo<S8booooo`0hooooo`008Oooool00ol0003oooooooooo`0Qooooo`05oa0@4?oo
ooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000oooooooo
ool05oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool06Oooool01Ol@
413ooooooooooooooooo410@00kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0G
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Kooooo`05oa0@4?oo
ooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo03Oooooo
000Qooooo`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`00
0?ooooooooooooooool000001oooool00omgMgOo<S8booooo`0Hooooo`05o`000?oooooooooooooo
ool000003_ooool00ol0003oooooooooo`0Iooooo`05o`000?ooooooooooooooool000003_ooool0
0ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo01Sooooo00Go0000ooooooooooooooooo`00
000=ooooo`03oiRHV?lQ8B7ok^k^01[ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool0>?ooool0027ooooo00?o0000ooooooooool08Ooo
ool01Ol0003ooooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000004ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`06Oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000
ooooooooool06Oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<01Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo01Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00iooooo`008Oooool00ol0003oooooooooo`0Qoooo
o`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00Cooooo00?o
0000ooooooooool06oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool0
6Oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Kooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`0Hoooo
o`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo03_ooooo000Qooooo`03o`000?oooooooooo027ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00ol0003oooooooooo`0Kooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`0Iooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01_ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41006_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo03_ooooo
000Qooooo`;o00008_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP04ooooo`Co00006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIV
I_l000006oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l000001Oooool4
o`0001[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
6_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004oooo
o`Co0000>_ooool0027ooooo00?o0000ooooooooool0LOooool4o`000<oooooo000Qooooo`03o`00
0?oooooooooo06cooooo1Ol00004ooooo`Ko0000bOooool0027ooooo00?o0000ooooooooool0Iooo
ool5o`0000oooooo00?o0000ooooooooool0^oooool00ol@413o0000o`000003o`0000Gooooo000Q
ooooo`03o`000?oooooooooo063ooooo1ol0000Eooooo`;o0000_Oooool00ol0003oooooooooo`06
ooooo`008Oooool00ol0003oooooooooo`1Iooooo`Oo00007_ooool3o`000;[ooooo00?o0000oooo
ooooool01_ooool0027oooooool0000co`0000cooooo00?o0000ooooooooool01_ooool0027ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool02?ooool4o`0000Kooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`Oo00000oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Dooooo`03o`000?lb<S;ogMgM00Kooooo
000Qooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0<?ooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo00gooooo00?o0000ooooool000001ol0000Yooooo`03o`000?oo
oooooooo033ooooo00?o0000ooooooooool0>oooool2o`000004ojVYZOlQ8B7o0000ob4Q8@Cooooo
000Qooooo`03o`000?oooooooooo08Oooooo1Ol00007ooooo`Go0000[?ooool0027ooooo00?o0000
ooooooooool0S?ooool7o`000;7ooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo0_l0003oooooodKooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo1Ol00005ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Go
oooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00co
oooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000?ooooooAOooool000Oooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?o0000ooooooooool0oooooom5ooooo`00
1oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01?ooool00ol0003o
ooooooooo`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001Oooool00ol0003oooooooooo`3ooooo
odGooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7o
c<c<00Gooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo0_l0003oooooodKooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003
oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00005ooooo`?o
0000oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoo
oooo00001_ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05o`000?oooooooooooooo
ool000002oooool01?oMgMgoEEEEooooool00006ooooo`03o`000?oooooooooo0?ooooooAOooool0
00Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Kooooo00?o0000
ooooooooool0oooooom5ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000001_ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`05ooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c005ooooo`03o`000?oooooooooo
0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmE
EEGoMgMgoooooonHV9So8B4Q00Gooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@
413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000005ooooo`?o0000oooo
oom5ooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RH
ob4Q8@05ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01Oooool00ol0003oooooooooo`3oooooodGo
oooo0007ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`07ooooo`03
o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03
omgMgOl@413oV9RH00Oooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@1Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool2o`000?ooooooA_oo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01Oooool00ol0003o
ooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00Go8B4QoiRHV?ooooooV9RHob4Q8@05ooooo`03o`000?oooooooooo0?ooooooAOooool000Oo
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001Oooool0
0ol0003oooooooooo`3oooooodGooooo0007ooooo`05o`000?ooooooooooooooool000002oooool0
1Olb<S;oV9RHoooooonHV9So<S8b00Gooooo0ol0003oooooodGooooo0007ooooo`05o`000?oooooo
ooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<00Gooooo00?o0000ooooooooool0
oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo
^[Zjoa0@4005ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000001Oooool00ol0003oooooooooo`3ooooo
odGooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413o
ZJVY00Gooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo0_l0003oooooodKooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool001Sooooo1?l000000ol@413oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo
AOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000J
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0
003oooooooooo`04ooooo`?o0000oooooom5ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006?ooool00omEEEGoIVIVo`00003oooooodkooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo002Nooooo`05oiRHV?l0003o0000odA4A?nj^[X06?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`Co000000So410@ooooooooooooV9RHoa0@4?l0003o
<S8bolc<c93ooooo000Oooooo`04oa0@4?l0003o0000o`0007_ooooo00Go410@okZj^_o^k^koMgMg
oa0@4009ooooo`Ko00002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03
o`000?oooooooooo00;ooooo00Go410@okZj^_ooooooMgMgoc8b<P2@ooooo`008?ooool00ol0003o
ooooooooo`1kooooo`03o`000?oooooooooo01[ooooo00Go410@oooooooooooooooooa0@400>oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0S_ooool0023ooooo00?o0000oooooooo
ool0Noooool00ol0003oooooooooo`0;ooooo`Ko00002Oooool01Ol0003ooooooooooooooooo0000
00kooooo00?o0000ooooooooool01Oooool00onYZJWo410@ooooo`2?ooooo`008?ooool01_l0003o
MgMgo`000?l0003oEEEEonk^kWSooooo00?o0000ooooooooool06_ooool01Ol0003ooooooooooooo
oooo000000kooooo00?o0000ooooooooool01?ooool00ol@413o0000okZj^P2@ooooo`008?ooool0
1_l0003oEEEEonk^k_ooooooMgMgoeEEEGKooooo00?o410@o`000?l000000ol0000Iooooo`05oa0@
4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`05ooooo`03okZj^_lQ8B7ooooo08oo
oooo000Pooooo`03o`000?o^k^kooooo00;ooooo00?o0000ooooooooool0M_ooool00ol0003ooooo
ooooo`0Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`02ooooo`05
oa0@4?nHV9SooooookZj^_l00000T?ooool0023ooooo00?o0000onk^k_ooool00_ooool00ol0003o
ooooooooo`1fooooo`03o`000?oooooooooo01[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<oooo
o`03oeEEEOmVIVKo000000Cooooo00GoZJVYoa0@4?l0003o410@ojVYZ@2@ooooo`008?ooool01_l0
003oEEEEonk^k_ooooooMgMgofIVI_oooooo@oooool001oooooo00?o410@o`000?mgMgL00_l00000
0omVIVKok^k^ooooo`3ooooood;ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.0332543, -0.540631, \
0.00122928, 0.00994506}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 3.33333 0.206011 0.412023 [
[.16667 .19351 -12 -9 ]
[.16667 .19351 12 0 ]
[.33333 .19351 -9 -9 ]
[.33333 .19351 9 0 ]
[.5 .19351 -12 -9 ]
[.5 .19351 12 0 ]
[.66667 .19351 -9 -9 ]
[.66667 .19351 9 0 ]
[.83333 .19351 -12 -9 ]
[.83333 .19351 12 0 ]
[1.025 .20601 0 -6 ]
[1.025 .20601 10 6 ]
[-0.0125 .0412 -24 -4.5 ]
[-0.0125 .0412 0 4.5 ]
[-0.0125 .12361 -24 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .28842 -18 -4.5 ]
[-0.0125 .28842 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .45322 -18 -4.5 ]
[-0.0125 .45322 0 4.5 ]
[-0.0125 .53563 -18 -4.5 ]
[-0.0125 .53563 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 .20601 m
.16667 .21226 L
s
[(0.05)] .16667 .19351 0 1 Mshowa
.33333 .20601 m
.33333 .21226 L
s
[(0.1)] .33333 .19351 0 1 Mshowa
.5 .20601 m
.5 .21226 L
s
[(0.15)] .5 .19351 0 1 Mshowa
.66667 .20601 m
.66667 .21226 L
s
[(0.2)] .66667 .19351 0 1 Mshowa
.83333 .20601 m
.83333 .21226 L
s
[(0.25)] .83333 .19351 0 1 Mshowa
.125 Mabswid
.03333 .20601 m
.03333 .20976 L
s
.06667 .20601 m
.06667 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.13333 .20601 m
.13333 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.23333 .20601 m
.23333 .20976 L
s
.26667 .20601 m
.26667 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.36667 .20601 m
.36667 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.43333 .20601 m
.43333 .20976 L
s
.46667 .20601 m
.46667 .20976 L
s
.53333 .20601 m
.53333 .20976 L
s
.56667 .20601 m
.56667 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.63333 .20601 m
.63333 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.73333 .20601 m
.73333 .20976 L
s
.76667 .20601 m
.76667 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.86667 .20601 m
.86667 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.93333 .20601 m
.93333 .20976 L
s
.96667 .20601 m
.96667 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
gsave
1.025 .20601 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .0412 m
.00625 .0412 L
s
[(-0.4)] -0.0125 .0412 1 0 Mshowa
0 .12361 m
.00625 .12361 L
s
[(-0.2)] -0.0125 .12361 1 0 Mshowa
0 .28842 m
.00625 .28842 L
s
[(0.2)] -0.0125 .28842 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.4)] -0.0125 .37082 1 0 Mshowa
0 .45322 m
.00625 .45322 L
s
[(0.6)] -0.0125 .45322 1 0 Mshowa
0 .53563 m
.00625 .53563 L
s
[(0.8)] -0.0125 .53563 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .10301 m
.00375 .10301 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .30902 m
.00375 .30902 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .39142 m
.00375 .39142 L
s
0 .41202 m
.00375 .41202 L
s
0 .43262 m
.00375 .43262 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .51503 m
.00375 .51503 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
0 .0206 m
.00375 .0206 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.14) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .20601 m
.00123 .20601 L
.00236 .20601 L
.00365 .20601 L
.00488 .20601 L
.00601 .20601 L
.00706 .20601 L
.00942 .20601 L
.01066 .20601 L
.01181 .20601 L
.01318 .20601 L
.01444 .20601 L
.017 .20601 L
.01841 .20601 L
.01975 .20601 L
.02225 .20601 L
.02364 .20601 L
.02491 .20601 L
.0261 .20601 L
.02738 .20601 L
.0297 .20601 L
.03101 .20601 L
.03245 .20601 L
.03396 .20601 L
.03536 .20601 L
.03787 .20601 L
.03928 .20601 L
.04057 .20601 L
.04331 .20601 L
.04469 .20601 L
.04622 .20601 L
.04752 .20601 L
.04892 .20601 L
.05145 .20601 L
.05289 .20601 L
.05446 .20601 L
.0561 .20601 L
.05762 .20601 L
.05906 .20601 L
.06036 .20601 L
.06178 .20601 L
.06329 .20601 L
.0646 .20601 L
.06605 .20601 L
.0686 .20601 L
.07003 .20601 L
.07157 .20601 L
.07436 .20601 L
.0757 .20601 L
.07716 .20601 L
Mistroke
.07845 .20601 L
.07982 .20601 L
.08118 .20601 L
.08241 .20601 L
.08481 .20601 L
.08608 .20601 L
.08726 .20601 L
.08866 .20601 L
.08994 .20601 L
.09256 .20601 L
.094 .20601 L
.09536 .20601 L
.09778 .20601 L
.10001 .20601 L
.10117 .20601 L
.10246 .20601 L
.10506 .20601 L
.10644 .20601 L
.1079 .20601 L
.11049 .20601 L
.11194 .20601 L
.11329 .20601 L
.11487 .20601 L
.11635 .20601 L
.11764 .20601 L
.11903 .20601 L
.12147 .20601 L
.12285 .20601 L
.12431 .20601 L
.12693 .20601 L
.12821 .20601 L
.1296 .20601 L
.13213 .20601 L
.13459 .20601 L
.13687 .20601 L
.13932 .20601 L
.14203 .20601 L
.1434 .20601 L
.14487 .20601 L
.14753 .20601 L
.14986 .20601 L
.15241 .20601 L
.15508 .20601 L
.15756 .20601 L
.15989 .20601 L
.16201 .20601 L
.16446 .20601 L
.16677 .20601 L
.16927 .20601 L
.17162 .20601 L
Mistroke
.17419 .20601 L
.17696 .20601 L
.17985 .20601 L
.1826 .20601 L
.18507 .20601 L
.18776 .20601 L
.19031 .20601 L
.19262 .20601 L
.19529 .20601 L
.1978 .20601 L
.20014 .20601 L
.20228 .20601 L
.20464 .20601 L
.20713 .20601 L
.2098 .20601 L
.21234 .20601 L
.21461 .20601 L
.21709 .20601 L
.21978 .20601 L
.22263 .20601 L
.22507 .20601 L
.22776 .20601 L
.23026 .20601 L
.23254 .20601 L
.235 .20601 L
.2377 .20601 L
.24224 .20601 L
.24471 .20601 L
.24702 .20601 L
.25233 .20601 L
.25532 .206 L
.25808 .206 L
.26315 .206 L
.2657 .20599 L
.26851 .20599 L
.27338 .20598 L
.27611 .20597 L
.2786 .20596 L
.28344 .20594 L
.28804 .20591 L
.29334 .20587 L
.29814 .20582 L
.30368 .20573 L
.30889 .20562 L
.31373 .20549 L
.31818 .20534 L
.32821 .20485 L
.33317 .20451 L
.33847 .20408 L
.34803 .20305 L
Mistroke
.3594 .20139 L
.36975 .19949 L
.38033 .19727 L
.39154 .19491 L
.40112 .19321 L
.40374 .19284 L
.40656 .1925 L
.40923 .19225 L
.41166 .19208 L
.41296 .19201 L
.41414 .19197 L
.4155 .19194 L
.41679 .19193 L
.41798 .19193 L
.41907 .19196 L
.42027 .192 L
.42154 .19206 L
.42283 .19215 L
.4242 .19227 L
.42669 .19254 L
.42964 .19297 L
.43233 .19346 L
.43717 .19458 L
.44242 .19612 L
.45199 .19964 L
.47233 .20846 L
.48314 .21262 L
.48882 .21437 L
.49479 .21581 L
.49735 .2163 L
.50009 .21672 L
.50166 .21692 L
.50309 .21708 L
.50454 .21721 L
.50588 .21731 L
.5071 .21738 L
.50839 .21744 L
.50969 .21748 L
.51042 .21749 L
.51111 .2175 L
.51236 .2175 L
.51349 .21748 L
.5148 .21745 L
.51605 .2174 L
.51731 .21734 L
.51845 .21727 L
.521 .21707 L
.5256 .21658 L
.53601 .21504 L
.55795 .21118 L
Mistroke
.56757 .20972 L
.57812 .20844 L
.58305 .20796 L
.58832 .20754 L
.59784 .20695 L
.60343 .20671 L
.60873 .20652 L
.61348 .2064 L
.61864 .20629 L
.62375 .20621 L
.62853 .20616 L
.63378 .20611 L
.63648 .20609 L
.63944 .20608 L
.64505 .20606 L
.64811 .20605 L
.65096 .20604 L
.65606 .20603 L
.65891 .20603 L
.66151 .20602 L
.66661 .20602 L
.66918 .20602 L
.67201 .20602 L
.67442 .20602 L
.67701 .20601 L
.68168 .20601 L
.68449 .20601 L
.68754 .20601 L
.69043 .20601 L
.6931 .20601 L
.6955 .20601 L
.69816 .20601 L
.70093 .20601 L
.70353 .20601 L
.70607 .20601 L
.70845 .20601 L
.71105 .20601 L
.71383 .20601 L
.71675 .20601 L
.71951 .20601 L
.72199 .20601 L
.72468 .20601 L
.72702 .20601 L
.72959 .20601 L
.73227 .20601 L
.73478 .20601 L
.73713 .20601 L
.73927 .20601 L
.74175 .20601 L
.7441 .20601 L
Mistroke
.74682 .20601 L
.74939 .20601 L
.75169 .20601 L
.75417 .20601 L
.75689 .20601 L
.75976 .20601 L
.76222 .20601 L
.76491 .20601 L
.76743 .20601 L
.76973 .20601 L
.77238 .20601 L
.77489 .20601 L
.77721 .20601 L
.77936 .20601 L
.78171 .20601 L
.78421 .20601 L
.78672 .20601 L
.78797 .20601 L
.78935 .20601 L
.79179 .20601 L
.79406 .20601 L
.79544 .20601 L
.79674 .20601 L
.79919 .20601 L
.80055 .20601 L
.80182 .20601 L
.80319 .20601 L
.80467 .20601 L
.80696 .20601 L
.80911 .20601 L
.81042 .20601 L
.81166 .20601 L
.81399 .20601 L
.81518 .20601 L
.81644 .20601 L
.81871 .20601 L
.82011 .20601 L
.82141 .20601 L
.82386 .20601 L
.82509 .20601 L
.8264 .20601 L
.82877 .20601 L
.83021 .20601 L
.83158 .20601 L
.83414 .20601 L
.83546 .20601 L
.83685 .20601 L
.83934 .20601 L
.84073 .20601 L
.84203 .20601 L
Mistroke
.84344 .20601 L
.84499 .20601 L
.84629 .20601 L
.84749 .20601 L
.84874 .20601 L
.84987 .20601 L
.85203 .20601 L
.85322 .20601 L
.85434 .20601 L
.85556 .20601 L
.85686 .20601 L
.85917 .20601 L
.86046 .20601 L
.86166 .20601 L
.86299 .20601 L
.8644 .20601 L
.8657 .20601 L
.86713 .20601 L
.86844 .20601 L
.86965 .20601 L
.87107 .20601 L
.8726 .20601 L
.87394 .20601 L
.87536 .20601 L
.8766 .20601 L
.87793 .20601 L
.87908 .20601 L
.88032 .20601 L
.88178 .20601 L
.88317 .20601 L
.88451 .20601 L
.88575 .20601 L
.88687 .20601 L
.88808 .20601 L
.89025 .20601 L
.89158 .20601 L
.89284 .20601 L
.89521 .20601 L
.89641 .20601 L
.8977 .20601 L
.8988 .20601 L
.9 .20601 L
.90142 .20601 L
.90274 .20601 L
.90404 .20601 L
.90523 .20601 L
.90656 .20601 L
.90782 .20601 L
.90896 .20601 L
.91017 .20601 L
Mistroke
.91149 .20601 L
.91271 .20601 L
.91402 .20601 L
.91547 .20601 L
.9167 .20601 L
.91784 .20601 L
.91908 .20601 L
.92039 .20601 L
.92146 .20601 L
.9226 .20601 L
.92385 .20601 L
.92502 .20601 L
.92648 .20601 L
.92783 .20601 L
.92931 .20601 L
.93087 .20601 L
.93223 .20601 L
.9335 .20601 L
.93489 .20601 L
.93639 .20601 L
.93772 .20601 L
.93916 .20601 L
.94053 .20601 L
.94179 .20601 L
.94304 .20601 L
.94418 .20601 L
.94549 .20601 L
.94672 .20601 L
.94795 .20601 L
.94926 .20601 L
.9505 .20601 L
.95163 .20601 L
.95296 .20601 L
.9544 .20601 L
.95576 .20601 L
.95701 .20601 L
.95831 .20601 L
.95952 .20601 L
.96085 .20601 L
.96228 .20601 L
.96378 .20601 L
.9652 .20601 L
.96647 .20601 L
.96787 .20601 L
.96918 .20601 L
.97042 .20601 L
.97154 .20601 L
.97274 .20601 L
.97405 .20601 L
.97545 .20601 L
Mistroke
.97663 .20601 L
.97793 .20601 L
.97915 .20601 L
.98027 .20601 L
.98155 .20601 L
.98277 .20601 L
.98389 .20601 L
.98493 .20601 L
.98607 .20601 L
.98728 .20601 L
.98808 .20601 L
.98893 .20601 L
.99044 .20601 L
.99128 .20601 L
.99206 .20601 L
.99298 .20601 L
.99384 .20601 L
.9954 .20601 L
.99682 .20601 L
.99835 .20601 L
.99921 .20601 L
1 .20601 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13039,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo00?ooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooo
oom5ooooo`001Ol00002ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Gooooo00?o
0000ooooooooool0oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo00Co
A4A4omgMgOoooooo00001_ooool3o`000?ooooooAOooool000Oooooo00Go0000oooooooooooooooo
o`00000;ooooo`04omgMgOmEEEGoooooo`0000Kooooo00?o0000ooooooooool0oooooom5ooooo`00
1oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001_ooool00ol0003o
ooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^ko
A4A4o`000006ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Gooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool5o`0000Gooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool00ol0003oooooooooo`3oooooodGooooo0005o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0oooooom5ooooo`001ooo
ool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01Oooool3o`000?oooooo
AOooool000Oooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Cooooo
00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Gooooo00?o0000oooooooo
ool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c005ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo027ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@0Iooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l00000
0ol@413oooooooooo`0Gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l0
00001Ol@413oooooooooooooooooA4A400;o000000?o<S8bomgMgOooool06?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM03Wooooo000Qoooo
o`;o00008_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01oooool00omgMgOo<S8booooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B47ooooo`03o`000?oooooooooo00Kooooo00?oMgMgoc8b<_ooool06?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@06_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1oooool00omgMgOo<S8booooo`0hooooo`008Oooool00ol0003oooooooooo`0Qooooo`05oa0@4?oo
ooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000oooooooo
ool05oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool06Oooool01Ol@
413ooooooooooooooooo410@00kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0G
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Kooooo`05oa0@4?oo
ooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo03Oooooo
000Qooooo`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`00
0?ooooooooooooooool000001oooool00omgMgOo<S8booooo`0Hooooo`05o`000?oooooooooooooo
ool000003_ooool00ol0003oooooooooo`0Iooooo`05o`000?ooooooooooooooool000003_ooool0
0ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo01Sooooo00Go0000ooooooooooooooooo`00
000=ooooo`03oiRHV?lQ8B7ok^k^01[ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool0>?ooool0027ooooo00?o0000ooooooooool08Ooo
ool01Ol0003ooooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000004ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`06Oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000
ooooooooool06Oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<01Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo01Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00iooooo`008Oooool00ol0003oooooooooo`0Qoooo
o`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00Cooooo00?o
0000ooooooooool06oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool0
6Oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Kooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`0Hoooo
o`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo03_ooooo000Qooooo`03o`000?oooooooooo027ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00ol0003oooooooooo`0Kooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`0Iooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01_ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41006_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo03_ooooo
000Qooooo`;o00008_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP04ooooo`Co00006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIV
I_l000006oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l000001Oooool4
o`0001[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
6_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004oooo
o`Co0000>_ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`1gooooo`co0000`Oooool0027ooooo00?o0000ooooooooool0L?ooool7o`0000cooooo1?l0
002booooo`03oa0@4?l0003o000000?o00001Oooool0027ooooo00?o0000ooooooooool0KOooool3
o`0001Oooooo0_l0002booooo`03o`000?oooooooooo00Kooooo000Qooooo`03o`000?oooooooooo
06Cooooo2Ol0000Looooo`;o0000/?ooool00ol0003oooooooooo`06ooooo`008Oooooooo`0003?o
00003?ooool00ol0003oooooooooo`06ooooo`008Oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Oooooo1?l00006ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1_ooool:o`000003ooooool0003ooooo00Wooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0Dooooo`03o`000?lb<S;ogMgM00Kooooo000Qooooo`03o`000?oooooooooo033ooooo00?o
0000ooooooooool0<?ooool00ol0003oooooooooo`0Zooooo`;o00001?ooool00ol0003ooooooooo
o`0<ooooo`Co00008?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo03_ooooo0_l0
00001?nYZJWo8B4Qo`000?lQ8B44ooooo`008Oooool00ol0003oooooooooo`2Booooo`Ko00001?oo
ool9o`0009oooooo000Qooooo`03o`000?oooooooooo09Sooooo1?l0002Xooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`001ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001Oooool00ol0003ooooo
ooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo
00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003oooooodGo
oooo0007ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP05ooooo`03
o`000?oooooooooo0?ooooooAOooool000Oooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooo
oooooooooooo410@00oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooodGo
oooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@
00Gooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c005ooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo0_l0003oooooodKooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?oo
ooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go410@oooooooooooo
oooooa0@400;ooooo`Go00001Oooool3o`000?ooooooAOooool000Oooooo00Go0000oooooooooooo
ooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Kooooo00?o0000ooooooooool0oooooom5oooo
o`001oooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001_ooool0
0ol0003oooooooooo`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0omgMgOoc<c<o`000006ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Kooooo00?o0000ooooooooool0oooooom5
ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo0_l0003oooooodKooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
1oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@
4?o<c<`01Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@05ooooo`03o`000?oooooo
oooo0?ooooooAOooool000Oooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooo
ooooooooool000001Oooool3o`000?ooooooAOooool000Oooooo00Go0000ooooooooooooooooo`00
000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401Oooool00ol0003oooooooooo`3oooooodGooooo
0007ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Go
oooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00_o
oooo00?oEEEEohN7Qoooool01oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV007ooooo`03o`000?oooooooooo0?oo
ooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@
40Gooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo0_l0003oooooodKooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Q
o`000?lQ8B7oc<c<00Gooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401Oooool00ol0
003oooooooooo`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0
003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P05ooooo`?o0000oooo
oom5ooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000
olc<c005ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go410@oooooooooooooooo
oa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@41001Oooool00ol0003oooooooooo`3oooooodGo
oooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o0000
00Gooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@05ooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool0
0_ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001Sooooo00?oEEEEofIVI_l00000oooooom>
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00W_ooool01OnHV9So0000o`00
0?m4A4Co^[Zj01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool4o`000003
oa0@4?oooooooooo00;ooooo0_l000000ol@413oooooooooo`2>ooooo`007oooool01?l@413o0000
o`000?l0001kooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000Wooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo08oooooo000Pooooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool06_ooool01Ol@
413ooooooooooooooooo410@00kooooo00?o0000ooooooooool00_ooool5o`00093ooooo000Poooo
o`03o`000?oooooooooo07_ooooo00?o0000ooooooooool02oooool6o`0000Wooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03o`000?oooooooooo00;ooooo00CoA4A4omgMgOoooooo0000TOoo
ool0023ooooo00Ko0000ogMgMol0003o0000oeEEEOo^k^ihooooo`03o`000?oooooooooo01[ooooo
00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo00;ooooo00CogMgMoeEEEOoo
oooo0000TOooool0023ooooo00Ko0000oeEEEOo^k^koooooogMgMomEEEEfooooo`03oa0@4?l0003o
000000?o00006Oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool00ooo
ool00omgMgOoc<c<o`00002Aooooo`008?ooool00ol0003ok^k^ooooo`02ooooo`03o`000?oooooo
oooo07Kooooo00?o0000ooooooooool06_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00?o
0000ooooooooool00oooool00oo^k^koA4A4o`00002Aooooo`008?ooool00ol0003ok^k^ooooo`02
ooooo`03o`000?oooooooooo07Kooooo00?o0000ooooooooool06_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00cooooo00?oEEEEofIVI_l000001_ooool00omgMgOo0000ooooo`2@ooooo`008?ooool0
1_l0003oEEEEonk^k_ooooooMgMgofIVI_oooooo@oooool001oooooo00?o410@o`000?mgMgL00_l0
00000omVIVKok^k^ooooo`3ooooood;ooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.0332543, -0.540631, \
0.00122928, 0.00994506}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 3.33333 0.206011 0.412023 [
[.16667 .19351 -12 -9 ]
[.16667 .19351 12 0 ]
[.33333 .19351 -9 -9 ]
[.33333 .19351 9 0 ]
[.5 .19351 -12 -9 ]
[.5 .19351 12 0 ]
[.66667 .19351 -9 -9 ]
[.66667 .19351 9 0 ]
[.83333 .19351 -12 -9 ]
[.83333 .19351 12 0 ]
[1.025 .20601 0 -6 ]
[1.025 .20601 10 6 ]
[-0.0125 .0412 -24 -4.5 ]
[-0.0125 .0412 0 4.5 ]
[-0.0125 .12361 -24 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .28842 -18 -4.5 ]
[-0.0125 .28842 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .45322 -18 -4.5 ]
[-0.0125 .45322 0 4.5 ]
[-0.0125 .53563 -18 -4.5 ]
[-0.0125 .53563 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 .20601 m
.16667 .21226 L
s
[(0.05)] .16667 .19351 0 1 Mshowa
.33333 .20601 m
.33333 .21226 L
s
[(0.1)] .33333 .19351 0 1 Mshowa
.5 .20601 m
.5 .21226 L
s
[(0.15)] .5 .19351 0 1 Mshowa
.66667 .20601 m
.66667 .21226 L
s
[(0.2)] .66667 .19351 0 1 Mshowa
.83333 .20601 m
.83333 .21226 L
s
[(0.25)] .83333 .19351 0 1 Mshowa
.125 Mabswid
.03333 .20601 m
.03333 .20976 L
s
.06667 .20601 m
.06667 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.13333 .20601 m
.13333 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.23333 .20601 m
.23333 .20976 L
s
.26667 .20601 m
.26667 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.36667 .20601 m
.36667 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.43333 .20601 m
.43333 .20976 L
s
.46667 .20601 m
.46667 .20976 L
s
.53333 .20601 m
.53333 .20976 L
s
.56667 .20601 m
.56667 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.63333 .20601 m
.63333 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.73333 .20601 m
.73333 .20976 L
s
.76667 .20601 m
.76667 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.86667 .20601 m
.86667 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.93333 .20601 m
.93333 .20976 L
s
.96667 .20601 m
.96667 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
gsave
1.025 .20601 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .0412 m
.00625 .0412 L
s
[(-0.4)] -0.0125 .0412 1 0 Mshowa
0 .12361 m
.00625 .12361 L
s
[(-0.2)] -0.0125 .12361 1 0 Mshowa
0 .28842 m
.00625 .28842 L
s
[(0.2)] -0.0125 .28842 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.4)] -0.0125 .37082 1 0 Mshowa
0 .45322 m
.00625 .45322 L
s
[(0.6)] -0.0125 .45322 1 0 Mshowa
0 .53563 m
.00625 .53563 L
s
[(0.8)] -0.0125 .53563 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .10301 m
.00375 .10301 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .30902 m
.00375 .30902 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .39142 m
.00375 .39142 L
s
0 .41202 m
.00375 .41202 L
s
0 .43262 m
.00375 .43262 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .51503 m
.00375 .51503 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
0 .0206 m
.00375 .0206 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.15) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .20601 m
.00123 .20601 L
.00236 .20601 L
.00365 .20601 L
.00488 .20601 L
.00601 .20601 L
.00706 .20601 L
.00942 .20601 L
.01066 .20601 L
.01181 .20601 L
.01318 .20601 L
.01444 .20601 L
.017 .20601 L
.01841 .20601 L
.01975 .20601 L
.02225 .20601 L
.02364 .20601 L
.02491 .20601 L
.0261 .20601 L
.02738 .20601 L
.0297 .20601 L
.03101 .20601 L
.03245 .20601 L
.03396 .20601 L
.03536 .20601 L
.03668 .20601 L
.03787 .20601 L
.03926 .20601 L
.04057 .20601 L
.04188 .20601 L
.0431 .20601 L
.04445 .20601 L
.0459 .20601 L
.04734 .20601 L
.04886 .20601 L
.05016 .20601 L
.05157 .20601 L
.05291 .20601 L
.05412 .20601 L
.05553 .20601 L
.05685 .20601 L
.0592 .20601 L
.06053 .20601 L
.06176 .20601 L
.06309 .20601 L
.06451 .20601 L
.06586 .20601 L
.06709 .20601 L
.06853 .20601 L
.0701 .20601 L
Mistroke
.07158 .20601 L
.07295 .20601 L
.07451 .20601 L
.07597 .20601 L
.07728 .20601 L
.0787 .20601 L
.08025 .20601 L
.08188 .20601 L
.08328 .20601 L
.08481 .20601 L
.08618 .20601 L
.08745 .20601 L
.08885 .20601 L
.09033 .20601 L
.09281 .20601 L
.09423 .20601 L
.09555 .20601 L
.09675 .20601 L
.09801 .20601 L
.10026 .20601 L
.10152 .20601 L
.10269 .20601 L
.10533 .20601 L
.10671 .20601 L
.1082 .20601 L
.10952 .20601 L
.11091 .20601 L
.11216 .20601 L
.11354 .20601 L
.11597 .20601 L
.11745 .20601 L
.11879 .20601 L
.12035 .20601 L
.12183 .20601 L
.12445 .20601 L
.12594 .20601 L
.12731 .20601 L
.12854 .20601 L
.12984 .20601 L
.13216 .20601 L
.13346 .20601 L
.13466 .20601 L
.13607 .20601 L
.1374 .20601 L
.1398 .20601 L
.14198 .20601 L
.14433 .20601 L
.14566 .20601 L
.14688 .20601 L
.14813 .20601 L
Mistroke
.14946 .20601 L
.15188 .20601 L
.15335 .20601 L
.15475 .20601 L
.15738 .20601 L
.15872 .20601 L
.16014 .20601 L
.1627 .20601 L
.16427 .20601 L
.16575 .20601 L
.16708 .20601 L
.1685 .20601 L
.17104 .20601 L
.1734 .20601 L
.17484 .20601 L
.17621 .20601 L
.17877 .20601 L
.18146 .20601 L
.18396 .20601 L
.1867 .20601 L
.18808 .20601 L
.1896 .20601 L
.19212 .20601 L
.19442 .20601 L
.19695 .20601 L
.19961 .20601 L
.20194 .20601 L
.2041 .20601 L
.20647 .20601 L
.209 .20601 L
.21173 .20601 L
.21461 .20601 L
.21707 .20601 L
.21977 .20601 L
.22268 .20601 L
.2258 .20601 L
.22874 .20601 L
.23143 .20601 L
.23413 .20601 L
.23663 .20601 L
.23937 .20601 L
.24229 .20601 L
.24508 .20601 L
.2477 .20601 L
.25006 .20601 L
.2526 .20601 L
.2551 .20601 L
.25778 .20601 L
.26031 .20601 L
.26261 .20601 L
Mistroke
.26532 .20601 L
.26826 .20601 L
.27103 .20601 L
.27359 .20601 L
.2787 .20601 L
.28161 .20601 L
.28433 .20601 L
.28982 .206 L
.2929 .206 L
.29573 .206 L
.30073 .20599 L
.30352 .20599 L
.30606 .20598 L
.311 .20597 L
.31565 .20595 L
.32109 .20593 L
.3261 .20589 L
.3316 .20583 L
.33741 .20575 L
.34261 .20565 L
.34735 .20553 L
.35283 .20535 L
.35802 .20514 L
.36724 .2046 L
.37244 .2042 L
.37727 .20375 L
.38737 .20256 L
.39685 .20112 L
.41848 .19701 L
.4288 .19508 L
.43443 .19419 L
.43717 .19383 L
.43966 .19355 L
.44182 .19335 L
.44415 .19317 L
.44543 .1931 L
.44661 .19304 L
.44774 .193 L
.44894 .19298 L
.45014 .19297 L
.45144 .19298 L
.45266 .193 L
.45377 .19304 L
.45508 .1931 L
.4565 .19319 L
.45909 .19341 L
.46178 .19374 L
.46468 .19419 L
.46995 .19526 L
.47978 .19809 L
Mistroke
.50181 .20675 L
.51266 .21092 L
.52278 .214 L
.52787 .21514 L
.53049 .21562 L
.53333 .21604 L
.53495 .21624 L
.53644 .21639 L
.53784 .21651 L
.53939 .21662 L
.54077 .2167 L
.54207 .21675 L
.54343 .21678 L
.5442 .21679 L
.54491 .2168 L
.54625 .21679 L
.54752 .21677 L
.54866 .21674 L
.5499 .21669 L
.55124 .21662 L
.55267 .21653 L
.55522 .21633 L
.55979 .21586 L
.56481 .2152 L
.58655 .21165 L
.59705 .21003 L
.607 .20877 L
.6125 .20821 L
.61848 .20769 L
.62388 .20731 L
.62895 .20701 L
.63409 .20677 L
.6388 .2066 L
.64403 .20644 L
.64968 .20632 L
.6548 .20623 L
.66041 .20616 L
.66324 .20614 L
.66627 .20611 L
.67173 .20608 L
.67443 .20607 L
.67731 .20606 L
.68246 .20604 L
.68532 .20604 L
.688 .20603 L
.69113 .20603 L
.6941 .20602 L
.69665 .20602 L
.69942 .20602 L
.70429 .20602 L
Mistroke
.70704 .20602 L
.70998 .20601 L
.71249 .20601 L
.71525 .20601 L
.71799 .20601 L
.72088 .20601 L
.72356 .20601 L
.72606 .20601 L
.72901 .20601 L
.7317 .20601 L
.7348 .20601 L
.73774 .20601 L
.7403 .20601 L
.74301 .20601 L
.74533 .20601 L
.74789 .20601 L
.75063 .20601 L
.75358 .20601 L
.75637 .20601 L
.75892 .20601 L
.76153 .20601 L
.7639 .20601 L
.76664 .20601 L
.76922 .20601 L
.77161 .20601 L
.77382 .20601 L
.77624 .20601 L
.7788 .20601 L
.78138 .20601 L
.78415 .20601 L
.78676 .20601 L
.78915 .20601 L
.79194 .20601 L
.79352 .20601 L
.79499 .20601 L
.79768 .20601 L
.79918 .20601 L
.80053 .20601 L
.80299 .20601 L
.80567 .20601 L
.80703 .20601 L
.80848 .20601 L
.80973 .20601 L
.81109 .20601 L
.8137 .20601 L
.81617 .20601 L
.81857 .20601 L
.82079 .20601 L
.82205 .20601 L
.8234 .20601 L
Mistroke
.82584 .20601 L
.82733 .20601 L
.82875 .20601 L
.83141 .20601 L
.83276 .20601 L
.8342 .20601 L
.83679 .20601 L
.83837 .20601 L
.83987 .20601 L
.84122 .20601 L
.84267 .20601 L
.84399 .20601 L
.84519 .20601 L
.84755 .20601 L
.84886 .20601 L
.8503 .20601 L
.85291 .20601 L
.8542 .20601 L
.85563 .20601 L
.85702 .20601 L
.85853 .20601 L
.85993 .20601 L
.86121 .20601 L
.86243 .20601 L
.86373 .20601 L
.86495 .20601 L
.86606 .20601 L
.86824 .20601 L
.86945 .20601 L
.87077 .20601 L
.87317 .20601 L
.87437 .20601 L
.87568 .20601 L
.87697 .20601 L
.87835 .20601 L
.87963 .20601 L
.88081 .20601 L
.88312 .20601 L
.88447 .20601 L
.88575 .20601 L
.88813 .20601 L
.88947 .20601 L
.8907 .20601 L
.89213 .20601 L
.89347 .20601 L
.8957 .20601 L
.89688 .20601 L
.89814 .20601 L
.89947 .20601 L
.90072 .20601 L
Mistroke
.90308 .20601 L
.90433 .20601 L
.9057 .20601 L
.90714 .20601 L
.90849 .20601 L
.91091 .20601 L
.91226 .20601 L
.9135 .20601 L
.91478 .20601 L
.91614 .20601 L
.91764 .20601 L
.91903 .20601 L
.9206 .20601 L
.92208 .20601 L
.9234 .20601 L
.92484 .20601 L
.92614 .20601 L
.92732 .20601 L
.92869 .20601 L
.92999 .20601 L
.93229 .20601 L
.93359 .20601 L
.93479 .20601 L
.93623 .20601 L
.93758 .20601 L
.93879 .20601 L
.94009 .20601 L
.94153 .20601 L
.94303 .20601 L
.94432 .20601 L
.94573 .20601 L
.94722 .20601 L
.94863 .20601 L
.94989 .20601 L
.95126 .20601 L
.95275 .20601 L
.95434 .20601 L
.95569 .20601 L
.95718 .20601 L
.95856 .20601 L
.95983 .20601 L
.96129 .20601 L
.96268 .20601 L
.96396 .20601 L
.96514 .20601 L
.96645 .20601 L
.96784 .20601 L
.96985 .20601 L
.97087 .20601 L
.97198 .20601 L
Mistroke
.97293 .20601 L
.97395 .20601 L
.97579 .20601 L
.9769 .20601 L
.9781 .20601 L
.97924 .20601 L
.98029 .20601 L
.98228 .20601 L
.98329 .20601 L
.9844 .20601 L
.98538 .20601 L
.98642 .20601 L
.98827 .20601 L
.9893 .20601 L
.99026 .20601 L
.99138 .20601 L
.99244 .20601 L
.99336 .20601 L
.99436 .20601 L
.9961 .20601 L
.99708 .20601 L
.99813 .20601 L
1 .20601 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13039,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo00?ooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooo
oom5ooooo`001Ol00002ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Gooooo00?o
0000ooooooooool0oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo00Co
A4A4omgMgOoooooo00001_ooool3o`000?ooooooAOooool000Oooooo00Go0000oooooooooooooooo
o`00000;ooooo`04omgMgOmEEEGoooooo`0000Kooooo00?o0000ooooooooool0oooooom5ooooo`00
1oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001_ooool00ol0003o
ooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^ko
A4A4o`000006ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Gooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool5o`0000Gooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool00ol0003oooooooooo`3oooooodGooooo0005o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0oooooom5ooooo`001ooo
ool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01Oooool3o`000?oooooo
AOooool000Oooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Cooooo
00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Gooooo00?o0000oooooooo
ool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c005ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo027ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@0Iooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l00000
0ol@413oooooooooo`0Gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l0
00001Ol@413oooooooooooooooooA4A400;o000000?o<S8bomgMgOooool06?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM03Wooooo000Qoooo
o`;o00008_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01oooool00omgMgOo<S8booooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B47ooooo`03o`000?oooooooooo00Kooooo00?oMgMgoc8b<_ooool06?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@06_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1oooool00omgMgOo<S8booooo`0hooooo`008Oooool00ol0003oooooooooo`0Qooooo`05oa0@4?oo
ooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000oooooooo
ool05oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool06Oooool01Ol@
413ooooooooooooooooo410@00kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0G
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Kooooo`05oa0@4?oo
ooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo03Oooooo
000Qooooo`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`00
0?ooooooooooooooool000001oooool00omgMgOo<S8booooo`0Hooooo`05o`000?oooooooooooooo
ool000003_ooool00ol0003oooooooooo`0Iooooo`05o`000?ooooooooooooooool000003_ooool0
0ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo01Sooooo00Go0000ooooooooooooooooo`00
000=ooooo`03oiRHV?lQ8B7ok^k^01[ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool0>?ooool0027ooooo00?o0000ooooooooool08Ooo
ool01Ol0003ooooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000004ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`06Oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000
ooooooooool06Oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<01Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo01Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00iooooo`008Oooool00ol0003oooooooooo`0Qoooo
o`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00Cooooo00?o
0000ooooooooool06oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool0
6Oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Kooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`0Hoooo
o`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo03_ooooo000Qooooo`03o`000?oooooooooo027ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00ol0003oooooooooo`0Kooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`0Iooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01_ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41006_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo03_ooooo
000Qooooo`;o00008_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP04ooooo`Co00006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIV
I_l000006oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l000001Oooool4
o`0001[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
6_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004oooo
o`Co0000>_ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`21ooooo`co0000]oooool0027ooooo00?o0000ooooooooool0Noooool6o`0000cooooo0ol0
002Yooooo`03oa0@4?l0003o000000?o00001Oooool0027ooooo00?o0000ooooooooool0N?ooool3
o`0001Gooooo0ol0002Xooooo`03o`000?oooooooooo00Kooooo000Qooooo`03o`000?oooooooooo
073ooooo2?l0000Kooooo`?o0000YOooool00ol0003oooooooooo`06ooooo`008Oooooooo`0003?o
00003?ooool00ol0003oooooooooo`06ooooo`008Oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01oooool01?l0003oooooo`000?l00006ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool9o`0000Cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Dooooo`03o`000?lb<S;ogMgM00Kooooo000Qooooo`03o`00
0?oooooooooo033ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0`ooooo`04o`00
0?ooooooooooooooo`?o00004?ooool5o`0001Oooooo00?o0000ooooooooool0<?ooool00ol0003o
ooooooooo`0kooooo`;o000000CoZJVYob4Q8Ol0003o8B4Q1?ooool0027ooooo00?o0000oooooooo
ool0WOooool@o`0009Oooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo0_l0003oooooodKooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool000Oo
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Gooooo00?o0000oooo
ooooool0oooooom5ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44oooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool00ol0003oooooooooo`3oooooodGooooo0007oooo
o`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP06ooooo`?o0000oooooom5
ooooo`001oooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01Oooool0
0ol0003oooooooooo`3oooooodGooooo0007ooooo`05o`000?ooooooooooooooool000003_ooool0
0omgMgOoIVIVooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go410@oooo
oooooooooooooa0@400?ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0oooooom5
ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@
4005ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool00oooool00ol0003oooooooooo`3o
ooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05oa0@4?oooooooooo
ooooool@41002oooool5o`0000Gooooo0ol0003oooooodGooooo0007ooooo`05o`000?oooooooooo
ooooool000002oooool01?m4A4CogMgMooooool00006ooooo`03o`000?oooooooooo0?ooooooAOoo
ool000Oooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Kooooo
00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00cooooo
00?oMgMgolc<c?l000001_ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`000006ooooo`03o`000?oooooooooo0?oooooo
AOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Gooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo0_l0003oooooodKooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@
413oc<c<00Gooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401Oooool00ol0003ooooo
ooooo`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000000Gooooo0ol0003oooooodGooooo0007ooooo`05o`000?ooooooooooooooool0
00002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Gooooo00?o0000ooooooooool0oooooom5oooo
o`001oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c005
ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go410@oooooooooooooooooa0@400;
ooooo`03oeEEEOn7QhOooooo00Oooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P01oooool00ol0003oooooooooo`3o
ooooodGooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@
4105ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo0_l0003oooooodKooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q
8Ol0003o8B4Qolc<c005ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Gooooo00?o
0000ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go
0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go
0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801Oooool3o`000?oo
ooooAOooool000Oooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`00
0?o<c<`01Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05oa0@4?oooooooooooooo
ool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Gooooo00?o0000ooooooooool0oooooom5
ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00
0005ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`006?ooool4o`000003oa0@4?oooooooooo
00;ooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo0ol0003oooooodGooooo000J
ooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Hooooo`03oeEEEOmVIVKo00000?oooooo
C_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool009kooooo00GoV9RHo`000?l0
003oA4A4okZj^P0Hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l00000
1Ol@413oooooooooooooooooA4A400;o000000?o<S8bomgMgOooool0S_ooool001oooooo00Co410@
o`000?l0003o0000Noooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l00009ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01_ooool00omgMgOo
<S8booooo`2>ooooo`008?ooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo01[ooooo
00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0SOooool0023ooooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`0;ooooo`Ko0000
2Oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool01_ooool00omgMgOo
<S8booooo`2>ooooo`008?ooool01_l0003oMgMgo`000?l0003oEEEEonk^kWSooooo00?o0000oooo
ooooool06_ooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<08oooooo000Pooooo`06o`000?mEEEGok^k^oooooomgMgOoEEEE
M_ooool00ol@413o0000o`000003o`0001Wooooo00Go410@oooooooooooooooooa0@400>ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0TOooool0023ooooo00?o0000onk^k_ooool0
0_ooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo01[ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0TOooool0023ooooo
00?o0000onk^k_ooool00_ooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo01[ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`03oeEEEOmVIVKo000000Gooooo1?l0002@ooooo`00
8?ooool01_l0003oEEEEonk^k_ooooooMgMgofIVI_oooooo@oooool001oooooo00?o410@o`000?mg
MgL00_l000000omVIVKok^k^ooooo`3ooooood;ooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.0332543, -0.540631, \
0.00122928, 0.00994506}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 3.33333 0.206011 0.412023 [
[.16667 .19351 -12 -9 ]
[.16667 .19351 12 0 ]
[.33333 .19351 -9 -9 ]
[.33333 .19351 9 0 ]
[.5 .19351 -12 -9 ]
[.5 .19351 12 0 ]
[.66667 .19351 -9 -9 ]
[.66667 .19351 9 0 ]
[.83333 .19351 -12 -9 ]
[.83333 .19351 12 0 ]
[1.025 .20601 0 -6 ]
[1.025 .20601 10 6 ]
[-0.0125 .0412 -24 -4.5 ]
[-0.0125 .0412 0 4.5 ]
[-0.0125 .12361 -24 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .28842 -18 -4.5 ]
[-0.0125 .28842 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .45322 -18 -4.5 ]
[-0.0125 .45322 0 4.5 ]
[-0.0125 .53563 -18 -4.5 ]
[-0.0125 .53563 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 .20601 m
.16667 .21226 L
s
[(0.05)] .16667 .19351 0 1 Mshowa
.33333 .20601 m
.33333 .21226 L
s
[(0.1)] .33333 .19351 0 1 Mshowa
.5 .20601 m
.5 .21226 L
s
[(0.15)] .5 .19351 0 1 Mshowa
.66667 .20601 m
.66667 .21226 L
s
[(0.2)] .66667 .19351 0 1 Mshowa
.83333 .20601 m
.83333 .21226 L
s
[(0.25)] .83333 .19351 0 1 Mshowa
.125 Mabswid
.03333 .20601 m
.03333 .20976 L
s
.06667 .20601 m
.06667 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.13333 .20601 m
.13333 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.23333 .20601 m
.23333 .20976 L
s
.26667 .20601 m
.26667 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.36667 .20601 m
.36667 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.43333 .20601 m
.43333 .20976 L
s
.46667 .20601 m
.46667 .20976 L
s
.53333 .20601 m
.53333 .20976 L
s
.56667 .20601 m
.56667 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.63333 .20601 m
.63333 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.73333 .20601 m
.73333 .20976 L
s
.76667 .20601 m
.76667 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.86667 .20601 m
.86667 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.93333 .20601 m
.93333 .20976 L
s
.96667 .20601 m
.96667 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
gsave
1.025 .20601 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .0412 m
.00625 .0412 L
s
[(-0.4)] -0.0125 .0412 1 0 Mshowa
0 .12361 m
.00625 .12361 L
s
[(-0.2)] -0.0125 .12361 1 0 Mshowa
0 .28842 m
.00625 .28842 L
s
[(0.2)] -0.0125 .28842 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.4)] -0.0125 .37082 1 0 Mshowa
0 .45322 m
.00625 .45322 L
s
[(0.6)] -0.0125 .45322 1 0 Mshowa
0 .53563 m
.00625 .53563 L
s
[(0.8)] -0.0125 .53563 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .10301 m
.00375 .10301 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .30902 m
.00375 .30902 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .39142 m
.00375 .39142 L
s
0 .41202 m
.00375 .41202 L
s
0 .43262 m
.00375 .43262 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .51503 m
.00375 .51503 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
0 .0206 m
.00375 .0206 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.16) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .20601 m
.00123 .20601 L
.00236 .20601 L
.00365 .20601 L
.00488 .20601 L
.00601 .20601 L
.00706 .20601 L
.00821 .20601 L
.00942 .20601 L
.01065 .20601 L
.01196 .20601 L
.0132 .20601 L
.01434 .20601 L
.01566 .20601 L
.01711 .20601 L
.01848 .20601 L
.01975 .20601 L
.02106 .20601 L
.02247 .20601 L
.0238 .20601 L
.02503 .20601 L
.02736 .20601 L
.02854 .20601 L
.02982 .20601 L
.03123 .20601 L
.03251 .20601 L
.03398 .20601 L
.03538 .20601 L
.03667 .20601 L
.03786 .20601 L
.03917 .20601 L
.04057 .20601 L
.04189 .20601 L
.04329 .20601 L
.04448 .20601 L
.04579 .20601 L
.0472 .20601 L
.0487 .20601 L
.05012 .20601 L
.05141 .20601 L
.05272 .20601 L
.05393 .20601 L
.05525 .20601 L
.05665 .20601 L
.05787 .20601 L
.05901 .20601 L
.06025 .20601 L
.0616 .20601 L
.06314 .20601 L
.06457 .20601 L
Mistroke
.06615 .20601 L
.06782 .20601 L
.06942 .20601 L
.07092 .20601 L
.07227 .20601 L
.07373 .20601 L
.07507 .20601 L
.07654 .20601 L
.07807 .20601 L
.0795 .20601 L
.08084 .20601 L
.08206 .20601 L
.08347 .20601 L
.08481 .20601 L
.08601 .20601 L
.0873 .20601 L
.08964 .20601 L
.091 .20601 L
.09242 .20601 L
.09364 .20601 L
.09497 .20601 L
.09639 .20601 L
.09768 .20601 L
.09916 .20601 L
.10056 .20601 L
.10186 .20601 L
.10306 .20601 L
.10437 .20601 L
.10576 .20601 L
.10806 .20601 L
.10935 .20601 L
.11052 .20601 L
.11162 .20601 L
.11281 .20601 L
.11498 .20601 L
.11619 .20601 L
.11753 .20601 L
.11893 .20601 L
.12024 .20601 L
.12258 .20601 L
.1239 .20601 L
.12511 .20601 L
.12645 .20601 L
.12771 .20601 L
.13008 .20601 L
.1314 .20601 L
.13262 .20601 L
.13405 .20601 L
.13539 .20601 L
.1376 .20601 L
Mistroke
.13877 .20601 L
.14003 .20601 L
.14135 .20601 L
.1426 .20601 L
.14496 .20601 L
.14632 .20601 L
.14756 .20601 L
.1489 .20601 L
.15034 .20601 L
.15169 .20601 L
.15292 .20601 L
.15535 .20601 L
.15671 .20601 L
.15797 .20601 L
.15948 .20601 L
.16086 .20601 L
.16367 .20601 L
.16522 .20601 L
.16668 .20601 L
.16788 .20601 L
.16917 .20601 L
.17151 .20601 L
.17286 .20601 L
.17428 .20601 L
.17683 .20601 L
.17812 .20601 L
.17949 .20601 L
.18197 .20601 L
.18349 .20601 L
.18492 .20601 L
.1862 .20601 L
.1876 .20601 L
.18995 .20601 L
.19243 .20601 L
.19474 .20601 L
.19689 .20601 L
.19942 .20601 L
.20174 .20601 L
.20302 .20601 L
.20441 .20601 L
.20695 .20601 L
.20835 .20601 L
.20964 .20601 L
.21103 .20601 L
.21255 .20601 L
.21512 .20601 L
.21782 .20601 L
.22028 .20601 L
.22291 .20601 L
.2254 .20601 L
Mistroke
.22766 .20601 L
.23048 .20601 L
.23309 .20601 L
.23595 .20601 L
.2374 .20601 L
.23899 .20601 L
.24165 .20601 L
.24452 .20601 L
.24723 .20601 L
.2497 .20601 L
.25232 .20601 L
.2547 .20601 L
.25745 .20601 L
.26003 .20601 L
.26243 .20601 L
.26464 .20601 L
.26706 .20601 L
.26963 .20601 L
.27221 .20601 L
.27499 .20601 L
.27761 .20601 L
.28 .20601 L
.2828 .20601 L
.28584 .20601 L
.28872 .20601 L
.29138 .20601 L
.29392 .20601 L
.29624 .20601 L
.2988 .20601 L
.30148 .20601 L
.30601 .20601 L
.30858 .20601 L
.31097 .20601 L
.31379 .20601 L
.31645 .20601 L
.32143 .20601 L
.32421 .206 L
.32679 .206 L
.32982 .206 L
.3326 .206 L
.3375 .20599 L
.34021 .20598 L
.34277 .20598 L
.34733 .20597 L
.35229 .20594 L
.35774 .20591 L
.36078 .20589 L
.36353 .20586 L
.3689 .2058 L
.37396 .20572 L
Mistroke
.37886 .20562 L
.38423 .20547 L
.38984 .20527 L
.39507 .20503 L
.40444 .20445 L
.4097 .20402 L
.41448 .20355 L
.43455 .2008 L
.45636 .19685 L
.46153 .19596 L
.46709 .19513 L
.46965 .1948 L
.47234 .19449 L
.47467 .19427 L
.47715 .19409 L
.47852 .19401 L
.47975 .19395 L
.481 .19391 L
.48217 .19388 L
.48354 .19387 L
.4848 .19387 L
.48618 .1939 L
.48688 .19392 L
.48765 .19394 L
.48916 .19402 L
.49053 .19411 L
.49363 .19439 L
.4965 .19475 L
.49922 .19518 L
.50403 .19614 L
.50934 .19748 L
.52009 .20097 L
.53942 .20832 L
.54929 .21166 L
.55468 .21317 L
.5597 .21431 L
.56515 .21525 L
.56803 .21561 L
.56951 .21576 L
.57111 .2159 L
.57258 .216 L
.57393 .21607 L
.57523 .21612 L
.5766 .21616 L
.57782 .21617 L
.57897 .21617 L
.58023 .21616 L
.58159 .21613 L
.58231 .21611 L
.58299 .21609 L
Mistroke
.58425 .21603 L
.58709 .21586 L
.58955 .21566 L
.5922 .2154 L
.60379 .21388 L
.62488 .21059 L
.63571 .20915 L
.64582 .20809 L
.65637 .20729 L
.66196 .20698 L
.66794 .20672 L
.67349 .20653 L
.67863 .20639 L
.68427 .20628 L
.69025 .2062 L
.69543 .20614 L
.7003 .2061 L
.70563 .20607 L
.70863 .20606 L
.71138 .20605 L
.71636 .20604 L
.71915 .20603 L
.72168 .20603 L
.72404 .20603 L
.72661 .20602 L
.73126 .20602 L
.73387 .20602 L
.73675 .20602 L
.73976 .20602 L
.74257 .20601 L
.74759 .20601 L
.75042 .20601 L
.75299 .20601 L
.75558 .20601 L
.75802 .20601 L
.76082 .20601 L
.76336 .20601 L
.76561 .20601 L
.76798 .20601 L
.77058 .20601 L
.77297 .20601 L
.77557 .20601 L
.77835 .20601 L
.78097 .20601 L
.78336 .20601 L
.78617 .20601 L
.78922 .20601 L
.79209 .20601 L
.79475 .20601 L
.7973 .20601 L
Mistroke
.79963 .20601 L
.80233 .20601 L
.80489 .20601 L
.80724 .20601 L
.80943 .20601 L
.81183 .20601 L
.81439 .20601 L
.8172 .20601 L
.81878 .20601 L
.82024 .20601 L
.82291 .20601 L
.82574 .20601 L
.82828 .20601 L
.83065 .20601 L
.83325 .20601 L
.83458 .20601 L
.83604 .20601 L
.83873 .20601 L
.8402 .20601 L
.84158 .20601 L
.84405 .20601 L
.84671 .20601 L
.84812 .20601 L
.84966 .20601 L
.85116 .20601 L
.85277 .20601 L
.85428 .20601 L
.85565 .20601 L
.85832 .20601 L
.85964 .20601 L
.86103 .20601 L
.86353 .20601 L
.86492 .20601 L
.86623 .20601 L
.86774 .20601 L
.86919 .20601 L
.87042 .20601 L
.87177 .20601 L
.87413 .20601 L
.87547 .20601 L
.87689 .20601 L
.87945 .20601 L
.88075 .20601 L
.88219 .20601 L
.88358 .20601 L
.88508 .20601 L
.88648 .20601 L
.88776 .20601 L
.89026 .20601 L
.89176 .20601 L
Mistroke
.89314 .20601 L
.89463 .20601 L
.89627 .20601 L
.89902 .20601 L
.90053 .20601 L
.90195 .20601 L
.90454 .20601 L
.90585 .20601 L
.90727 .20601 L
.9085 .20601 L
.9098 .20601 L
.91215 .20601 L
.91357 .20601 L
.91511 .20601 L
.91657 .20601 L
.91791 .20601 L
.92045 .20601 L
.92173 .20601 L
.92314 .20601 L
.92441 .20601 L
.92576 .20601 L
.92724 .20601 L
.92862 .20601 L
.93003 .20601 L
.93135 .20601 L
.93255 .20601 L
.93382 .20601 L
.93499 .20601 L
.93627 .20601 L
.93851 .20601 L
.93978 .20601 L
.94113 .20601 L
.94232 .20601 L
.94358 .20601 L
.94505 .20601 L
.94641 .20601 L
.94787 .20601 L
.94948 .20601 L
.95087 .20601 L
.95237 .20601 L
.95378 .20601 L
.95507 .20601 L
.9564 .20601 L
.95763 .20601 L
.95898 .20601 L
.96043 .20601 L
.9618 .20601 L
.9631 .20601 L
.96427 .20601 L
.96552 .20601 L
Mistroke
.96665 .20601 L
.96767 .20601 L
.96968 .20601 L
.97081 .20601 L
.97203 .20601 L
.97425 .20601 L
.97536 .20601 L
.97658 .20601 L
.97785 .20601 L
.97904 .20601 L
.98118 .20601 L
.98238 .20601 L
.98348 .20601 L
.98444 .20601 L
.98547 .20601 L
.98732 .20601 L
.98845 .20601 L
.98952 .20601 L
.99153 .20601 L
.99255 .20601 L
.99364 .20601 L
.99559 .20601 L
.99668 .20601 L
.99769 .20601 L
1 .20601 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13039,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo00?ooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooo
oom5ooooo`001Ol00002ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Gooooo00?o
0000ooooooooool0oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo00Co
A4A4omgMgOoooooo00001_ooool3o`000?ooooooAOooool000Oooooo00Go0000oooooooooooooooo
o`00000;ooooo`04omgMgOmEEEGoooooo`0000Kooooo00?o0000ooooooooool0oooooom5ooooo`00
1oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001_ooool00ol0003o
ooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^ko
A4A4o`000006ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Gooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool5o`0000Gooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool00ol0003oooooooooo`3oooooodGooooo0005o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0oooooom5ooooo`001ooo
ool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01Oooool3o`000?oooooo
AOooool000Oooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Cooooo
00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Gooooo00?o0000oooooooo
ool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c005ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo027ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@0Iooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l00000
0ol@413oooooooooo`0Gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l0
00001Ol@413oooooooooooooooooA4A400;o000000?o<S8bomgMgOooool06?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM03Wooooo000Qoooo
o`;o00008_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01oooool00omgMgOo<S8booooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B47ooooo`03o`000?oooooooooo00Kooooo00?oMgMgoc8b<_ooool06?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@06_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1oooool00omgMgOo<S8booooo`0hooooo`008Oooool00ol0003oooooooooo`0Qooooo`05oa0@4?oo
ooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000oooooooo
ool05oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool06Oooool01Ol@
413ooooooooooooooooo410@00kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0G
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Kooooo`05oa0@4?oo
ooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo03Oooooo
000Qooooo`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`00
0?ooooooooooooooool000001oooool00omgMgOo<S8booooo`0Hooooo`05o`000?oooooooooooooo
ool000003_ooool00ol0003oooooooooo`0Iooooo`05o`000?ooooooooooooooool000003_ooool0
0ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo01Sooooo00Go0000ooooooooooooooooo`00
000=ooooo`03oiRHV?lQ8B7ok^k^01[ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool0>?ooool0027ooooo00?o0000ooooooooool08Ooo
ool01Ol0003ooooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000004ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`06Oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000
ooooooooool06Oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<01Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo01Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00iooooo`008Oooool00ol0003oooooooooo`0Qoooo
o`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00Cooooo00?o
0000ooooooooool06oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool0
6Oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Kooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`0Hoooo
o`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo03_ooooo000Qooooo`03o`000?oooooooooo027ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00ol0003oooooooooo`0Kooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`0Iooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01_ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41006_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo03_ooooo
000Qooooo`;o00008_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP04ooooo`Co00006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIV
I_l000006oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l000001Oooool4
o`0001[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
6_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004oooo
o`Co0000>_ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`2>ooooo`Ko0000/?ooool0027ooooo00?o0000ooooooooool0Q_ooool8o`0000Kooooo1ol0
002Nooooo`03oa0@4?l0003o000000?o00001Oooool0027ooooo00?o0000ooooooooool0Ooooool7
o`0001Gooooo00?o0000ooooooooool0WOooool00ol0003oooooooooo`06ooooo`008Oooool00ol0
003oooooooooo`1jooooo`Go00007Oooool3o`0009cooooo00?o0000ooooooooool01_ooool0027o
ooooool0000co`0000cooooo00?o0000ooooooooool01_ooool0027ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooo`000002o`0000Gooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`02ooooo`_o00001Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Dooooo`03o`000?lb<S;ogMgM00Kooooo
000Qooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0<?ooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo00cooooo0ol0000<ooooo`Go00004?ooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo03_ooooo0_l000001?nYZJWo8B4Qo`000?lQ8B44ooooo`008Ooo
ool00ol0003oooooooooo`2Xooooo`co0000T?ooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000
1Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`03o`000?oooooooooo0?oo
ooooAOooool000Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Ko
oooo0ol0003oooooodGooooo0007ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So
8B4Qonk^kP05ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`00
1oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o
^[ZjoooooonHV9So410@00Gooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c005ooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000
oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0
003oooooodKooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`03ooooo`03
o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo
00Go410@oooooooooooooooooa0@400;ooooo`Go00001Oooool3o`000?ooooooAOooool000Oooooo
00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Kooooo00?o0000oooo
ooooool0oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEE
EOoooooo00001_ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00omgMgOoc<c<o`000006ooooo`03o`000?oooooooooo0?ooooooAOooool0
00Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Kooooo00?o0000
ooooooooool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMg
o`000?ooool01Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
onk^k_lb<S;o0000oa0@4?o<c<`01Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@05
ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go410@oooooooooooooooooa0@400;
ooooo`05o`000?ooooooooooooooool000001Oooool3o`000?ooooooAOooool000Oooooo00Go0000
ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401Oooool00ol0003ooooo
ooooo`3oooooodGooooo0007ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEE
o`000?l@413oc<c<00Gooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooo
oooooooooooo410@00_ooooo00?oEEEEohN7Qoooool01oooool00ol0003oooooooooo`3oooooodGo
oooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV007ooooo`03
o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04
olc<c?m4A4Co0000oa0@40Gooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Gooooo00?o0000ooooooooool0oooooom5ooooo`00
1oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRH
V?lQ8B401Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05oa0@4?oooooooooooooo
ool@41002oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0oooooom5
ooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b
<P05ooooo`?o0000oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo00Go
c<c<o`000?l0003o0000olc<c005ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go
410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@41001Oooool00ol0003o
ooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o
^[Zjoooooonj^[[o000000Gooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@05ooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool2o`000?oo
ooooA_ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000
oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0
003oooooodKooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Hooooo`Co0000
00?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool3o`00
0?ooooooAOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooo
ooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001Sooooo00?oEEEE
ofIVI_l00000oooooom>ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00W_oo
ool01OnHV9So0000o`000?m4A4Co^[Zj01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1Oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oa0@4?o<c<b@ooooo`007oooool0
1?l@413o0000o`000?l0001kooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000Wooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`02ooooo`05
oeEEEOmgMgOooooooiRHV?lQ8B40T?ooool0023ooooo00?o0000ooooooooool0Noooool00ol0003o
ooooooooo`0Jooooo`05oa0@4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool00000T?ooool0023ooooo00?o0000ooooooooool0Noooool00ol0
003oooooooooo`0;ooooo`Ko00002Oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000
ooooooooool00_ooool01Ol0003oV9RHoooooonHV9So8B4Q093ooooo000Pooooo`06o`000?mgMgOo
0000o`000?mEEEGok^k^N?ooool00ol0003oooooooooo`0Jooooo`05o`000?ooooooooooooooool0
00003_ooool00ol0003oooooooooo`02ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0T?ooool0023o
oooo00Ko0000oeEEEOo^k^koooooogMgMomEEEEfooooo`03oa0@4?l0003o000000?o00006Oooool0
1Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool00_ooool00omEEEGoQhN7oooo
o`2Booooo`008?ooool00ol0003ok^k^ooooo`02ooooo`03o`000?oooooooooo07Kooooo00?o0000
ooooooooool06_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00kooooo00?o0000ooooooooool00_oo
ool00ooMgMgo410@oiRHV02Booooo`008?ooool00ol0003ok^k^ooooo`02ooooo`03o`000?oooooo
oooo07Kooooo00?o0000ooooooooool06_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?o
EEEEofIVI_l000001Oooool01?o<c<coA4A4o`000?l@412@ooooo`008?ooool01_l0003oEEEEonk^
k_ooooooMgMgofIVI_oooooo@oooool001oooooo00?o410@o`000?mgMgL00_l000000omVIVKok^k^
ooooo`3ooooood;ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.0332543, -0.540631, \
0.00122928, 0.00994506}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 3.33333 0.206011 0.412023 [
[.16667 .19351 -12 -9 ]
[.16667 .19351 12 0 ]
[.33333 .19351 -9 -9 ]
[.33333 .19351 9 0 ]
[.5 .19351 -12 -9 ]
[.5 .19351 12 0 ]
[.66667 .19351 -9 -9 ]
[.66667 .19351 9 0 ]
[.83333 .19351 -12 -9 ]
[.83333 .19351 12 0 ]
[1.025 .20601 0 -6 ]
[1.025 .20601 10 6 ]
[-0.0125 .0412 -24 -4.5 ]
[-0.0125 .0412 0 4.5 ]
[-0.0125 .12361 -24 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .28842 -18 -4.5 ]
[-0.0125 .28842 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .45322 -18 -4.5 ]
[-0.0125 .45322 0 4.5 ]
[-0.0125 .53563 -18 -4.5 ]
[-0.0125 .53563 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 .20601 m
.16667 .21226 L
s
[(0.05)] .16667 .19351 0 1 Mshowa
.33333 .20601 m
.33333 .21226 L
s
[(0.1)] .33333 .19351 0 1 Mshowa
.5 .20601 m
.5 .21226 L
s
[(0.15)] .5 .19351 0 1 Mshowa
.66667 .20601 m
.66667 .21226 L
s
[(0.2)] .66667 .19351 0 1 Mshowa
.83333 .20601 m
.83333 .21226 L
s
[(0.25)] .83333 .19351 0 1 Mshowa
.125 Mabswid
.03333 .20601 m
.03333 .20976 L
s
.06667 .20601 m
.06667 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.13333 .20601 m
.13333 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.23333 .20601 m
.23333 .20976 L
s
.26667 .20601 m
.26667 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.36667 .20601 m
.36667 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.43333 .20601 m
.43333 .20976 L
s
.46667 .20601 m
.46667 .20976 L
s
.53333 .20601 m
.53333 .20976 L
s
.56667 .20601 m
.56667 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.63333 .20601 m
.63333 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.73333 .20601 m
.73333 .20976 L
s
.76667 .20601 m
.76667 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.86667 .20601 m
.86667 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.93333 .20601 m
.93333 .20976 L
s
.96667 .20601 m
.96667 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
gsave
1.025 .20601 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .0412 m
.00625 .0412 L
s
[(-0.4)] -0.0125 .0412 1 0 Mshowa
0 .12361 m
.00625 .12361 L
s
[(-0.2)] -0.0125 .12361 1 0 Mshowa
0 .28842 m
.00625 .28842 L
s
[(0.2)] -0.0125 .28842 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.4)] -0.0125 .37082 1 0 Mshowa
0 .45322 m
.00625 .45322 L
s
[(0.6)] -0.0125 .45322 1 0 Mshowa
0 .53563 m
.00625 .53563 L
s
[(0.8)] -0.0125 .53563 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .10301 m
.00375 .10301 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .30902 m
.00375 .30902 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .39142 m
.00375 .39142 L
s
0 .41202 m
.00375 .41202 L
s
0 .43262 m
.00375 .43262 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .51503 m
.00375 .51503 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
0 .0206 m
.00375 .0206 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.17) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .20601 m
.00123 .20601 L
.00236 .20601 L
.00365 .20601 L
.00488 .20601 L
.00601 .20601 L
.00706 .20601 L
.00821 .20601 L
.00942 .20601 L
.01065 .20601 L
.01196 .20601 L
.0132 .20601 L
.01434 .20601 L
.01566 .20601 L
.01711 .20601 L
.01848 .20601 L
.01975 .20601 L
.02106 .20601 L
.02247 .20601 L
.0238 .20601 L
.02503 .20601 L
.02614 .20601 L
.02736 .20601 L
.02864 .20601 L
.02982 .20601 L
.03122 .20601 L
.03254 .20601 L
.03372 .20601 L
.03501 .20601 L
.03641 .20601 L
.0379 .20601 L
.03917 .20601 L
.04057 .20601 L
.0419 .20601 L
.04336 .20601 L
.04488 .20601 L
.0463 .20601 L
.04763 .20601 L
.04884 .20601 L
.05023 .20601 L
.05155 .20601 L
.05298 .20601 L
.0545 .20601 L
.0558 .20601 L
.05723 .20601 L
.05876 .20601 L
.06041 .20601 L
.06196 .20601 L
.06339 .20601 L
.06471 .20601 L
Mistroke
.06611 .20601 L
.06744 .20601 L
.06864 .20601 L
.07006 .20601 L
.0716 .20601 L
.07305 .20601 L
.07438 .20601 L
.07563 .20601 L
.0768 .20601 L
.07808 .20601 L
.07945 .20601 L
.08089 .20601 L
.08226 .20601 L
.08348 .20601 L
.08481 .20601 L
.08609 .20601 L
.08727 .20601 L
.08856 .20601 L
.08992 .20601 L
.0911 .20601 L
.0922 .20601 L
.09341 .20601 L
.0947 .20601 L
.09612 .20601 L
.09765 .20601 L
.09909 .20601 L
.10042 .20601 L
.10163 .20601 L
.10295 .20601 L
.10432 .20601 L
.10561 .20601 L
.10698 .20601 L
.10847 .20601 L
.10988 .20601 L
.11118 .20601 L
.11235 .20601 L
.11364 .20601 L
.11499 .20601 L
.11626 .20601 L
.11766 .20601 L
.11913 .20601 L
.12038 .20601 L
.12176 .20601 L
.12324 .20601 L
.12483 .20601 L
.12632 .20601 L
.12768 .20601 L
.12893 .20601 L
.1301 .20601 L
.13139 .20601 L
Mistroke
.13277 .20601 L
.13421 .20601 L
.13558 .20601 L
.13681 .20601 L
.13815 .20601 L
.14057 .20601 L
.14193 .20601 L
.14316 .20601 L
.14431 .20601 L
.14555 .20601 L
.1478 .20601 L
.14917 .20601 L
.15044 .20601 L
.15184 .20601 L
.15334 .20601 L
.1549 .20601 L
.15639 .20601 L
.15772 .20601 L
.15918 .20601 L
.16043 .20601 L
.16181 .20601 L
.16325 .20601 L
.16461 .20601 L
.16703 .20601 L
.16839 .20601 L
.16963 .20601 L
.17098 .20601 L
.17224 .20601 L
.17462 .20601 L
.17594 .20601 L
.17717 .20601 L
.1786 .20601 L
.17994 .20601 L
.18215 .20601 L
.18333 .20601 L
.18459 .20601 L
.18591 .20601 L
.18717 .20601 L
.18952 .20601 L
.19089 .20601 L
.19213 .20601 L
.19347 .20601 L
.19492 .20601 L
.19626 .20601 L
.1975 .20601 L
.19992 .20601 L
.20128 .20601 L
.20255 .20601 L
.20407 .20601 L
.20544 .20601 L
Mistroke
.20825 .20601 L
.2098 .20601 L
.21126 .20601 L
.21246 .20601 L
.21376 .20601 L
.2161 .20601 L
.21753 .20601 L
.21888 .20601 L
.22143 .20601 L
.22273 .20601 L
.22411 .20601 L
.22659 .20601 L
.22811 .20601 L
.22954 .20601 L
.23082 .20601 L
.23222 .20601 L
.23458 .20601 L
.23706 .20601 L
.23937 .20601 L
.24152 .20601 L
.24406 .20601 L
.24637 .20601 L
.24905 .20601 L
.25158 .20601 L
.25406 .20601 L
.25639 .20601 L
.25895 .20601 L
.26171 .20601 L
.26444 .20601 L
.26582 .20601 L
.26733 .20601 L
.26999 .20601 L
.27248 .20601 L
.27499 .20601 L
.27737 .20601 L
.27951 .20601 L
.28182 .20601 L
.28435 .20601 L
.28702 .20601 L
.2893 .20601 L
.29181 .20601 L
.29443 .20601 L
.29728 .20601 L
.29998 .20601 L
.30248 .20601 L
.30495 .20601 L
.3072 .20601 L
.30979 .20601 L
.31222 .20601 L
.3149 .20601 L
Mistroke
.31772 .20601 L
.32012 .20601 L
.32277 .20601 L
.32561 .20601 L
.32866 .20601 L
.33154 .20601 L
.33416 .20601 L
.33656 .20601 L
.33922 .20601 L
.34199 .20601 L
.34459 .20601 L
.34923 .20601 L
.35184 .20601 L
.35423 .20601 L
.35931 .206 L
.36218 .206 L
.36486 .206 L
.37026 .20599 L
.37329 .20599 L
.37604 .20598 L
.38114 .20597 L
.38371 .20596 L
.38654 .20595 L
.39154 .20592 L
.39621 .20588 L
.40172 .20583 L
.40675 .20575 L
.41255 .20564 L
.41806 .2055 L
.42286 .20534 L
.42817 .20512 L
.43335 .20485 L
.43893 .20449 L
.44889 .20363 L
.45826 .20255 L
.47885 .19935 L
.48975 .19746 L
.49575 .19651 L
.50141 .19573 L
.50681 .19515 L
.50829 .19502 L
.50986 .19491 L
.51122 .19482 L
.51268 .19475 L
.51399 .1947 L
.5152 .19467 L
.5164 .19465 L
.51755 .19465 L
.51889 .19466 L
.52012 .19469 L
Mistroke
.52148 .19474 L
.52293 .19481 L
.52428 .19489 L
.52553 .19499 L
.52834 .19527 L
.53082 .19559 L
.53344 .196 L
.54297 .19809 L
.55292 .2011 L
.56359 .20489 L
.57359 .20847 L
.58285 .2114 L
.58793 .21274 L
.59353 .21394 L
.59917 .21482 L
.60226 .21517 L
.60364 .21529 L
.60515 .2154 L
.6064 .21547 L
.60774 .21554 L
.60848 .21556 L
.60915 .21558 L
.61046 .21561 L
.61166 .21562 L
.61296 .21562 L
.61419 .2156 L
.61532 .21557 L
.61663 .21553 L
.61786 .21548 L
.62065 .21531 L
.62336 .2151 L
.62628 .21483 L
.63692 .2135 L
.64852 .21177 L
.6596 .21017 L
.66963 .20893 L
.6803 .20789 L
.69033 .20719 L
.69586 .20691 L
.70093 .20669 L
.7065 .20651 L
.71237 .20637 L
.7176 .20627 L
.72235 .2062 L
.72785 .20614 L
.73304 .2061 L
.73784 .20608 L
.74227 .20606 L
.74714 .20604 L
.7496 .20604 L
Mistroke
.7523 .20603 L
.75491 .20603 L
.75775 .20603 L
.76026 .20602 L
.76293 .20602 L
.76558 .20602 L
.76798 .20602 L
.77267 .20602 L
.77549 .20601 L
.77808 .20601 L
.78093 .20601 L
.78395 .20601 L
.78657 .20601 L
.78901 .20601 L
.7917 .20601 L
.79458 .20601 L
.79727 .20601 L
.80012 .20601 L
.80256 .20601 L
.80525 .20601 L
.80813 .20601 L
.81124 .20601 L
.81417 .20601 L
.81686 .20601 L
.81941 .20601 L
.82177 .20601 L
.82437 .20601 L
.82715 .20601 L
.83007 .20601 L
.83282 .20601 L
.8353 .20601 L
.83798 .20601 L
.84045 .20601 L
.84311 .20601 L
.84562 .20601 L
.84791 .20601 L
.85059 .20601 L
.85351 .20601 L
.85627 .20601 L
.85883 .20601 L
.86022 .20601 L
.86172 .20601 L
.86445 .20601 L
.86709 .20601 L
.86953 .20601 L
.87217 .20601 L
.87367 .20601 L
.87507 .20601 L
.8779 .20601 L
.87948 .20601 L
Mistroke
.88092 .20601 L
.88333 .20601 L
.88598 .20601 L
.88731 .20601 L
.88875 .20601 L
.88999 .20601 L
.89135 .20601 L
.8938 .20601 L
.89513 .20601 L
.89638 .20601 L
.8986 .20601 L
.90098 .20601 L
.90245 .20601 L
.90381 .20601 L
.90526 .20601 L
.90686 .20601 L
.90956 .20601 L
.91103 .20601 L
.91241 .20601 L
.91375 .20601 L
.91503 .20601 L
.91742 .20601 L
.91875 .20601 L
.91999 .20601 L
.92135 .20601 L
.92279 .20601 L
.92412 .20601 L
.92558 .20601 L
.92815 .20601 L
.92959 .20601 L
.93114 .20601 L
.93393 .20601 L
.93528 .20601 L
.93675 .20601 L
.93804 .20601 L
.93941 .20601 L
.94065 .20601 L
.94201 .20601 L
.9444 .20601 L
.9457 .20601 L
.94694 .20601 L
.94927 .20601 L
.95056 .20601 L
.95177 .20601 L
.95317 .20601 L
.9545 .20601 L
.95565 .20601 L
.9569 .20601 L
.95908 .20601 L
.96031 .20601 L
Mistroke
.96162 .20601 L
.96396 .20601 L
.96512 .20601 L
.96638 .20601 L
.96749 .20601 L
.96866 .20601 L
.96972 .20601 L
.97089 .20601 L
.97295 .20601 L
.9742 .20601 L
.97535 .20601 L
.97658 .20601 L
.97793 .20601 L
.9802 .20601 L
.98144 .20601 L
.9826 .20601 L
.98369 .20601 L
.98486 .20601 L
.9859 .20601 L
.98701 .20601 L
.988 .20601 L
.98909 .20601 L
.99101 .20601 L
.99218 .20601 L
.99325 .20601 L
.9944 .20601 L
.99565 .20601 L
.99681 .20601 L
.99788 .20601 L
1 .20601 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13039,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo00?ooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooo
oom5ooooo`001Ol00002ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Gooooo00?o
0000ooooooooool0oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo00Co
A4A4omgMgOoooooo00001_ooool3o`000?ooooooAOooool000Oooooo00Go0000oooooooooooooooo
o`00000;ooooo`04omgMgOmEEEGoooooo`0000Kooooo00?o0000ooooooooool0oooooom5ooooo`00
1oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001_ooool00ol0003o
ooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^ko
A4A4o`000006ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Gooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool5o`0000Gooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool00ol0003oooooooooo`3oooooodGooooo0005o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0oooooom5ooooo`001ooo
ool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01Oooool3o`000?oooooo
AOooool000Oooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Cooooo
00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Gooooo00?o0000oooooooo
ool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c005ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo027ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@0Iooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l00000
0ol@413oooooooooo`0Gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l0
00001Ol@413oooooooooooooooooA4A400;o000000?o<S8bomgMgOooool06?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM03Wooooo000Qoooo
o`;o00008_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01oooool00omgMgOo<S8booooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B47ooooo`03o`000?oooooooooo00Kooooo00?oMgMgoc8b<_ooool06?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@06_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1oooool00omgMgOo<S8booooo`0hooooo`008Oooool00ol0003oooooooooo`0Qooooo`05oa0@4?oo
ooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000oooooooo
ool05oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool06Oooool01Ol@
413ooooooooooooooooo410@00kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0G
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Kooooo`05oa0@4?oo
ooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo03Oooooo
000Qooooo`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`00
0?ooooooooooooooool000001oooool00omgMgOo<S8booooo`0Hooooo`05o`000?oooooooooooooo
ool000003_ooool00ol0003oooooooooo`0Iooooo`05o`000?ooooooooooooooool000003_ooool0
0ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo01Sooooo00Go0000ooooooooooooooooo`00
000=ooooo`03oiRHV?lQ8B7ok^k^01[ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool0>?ooool0027ooooo00?o0000ooooooooool08Ooo
ool01Ol0003ooooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000004ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`06Oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000
ooooooooool06Oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<01Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo01Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00iooooo`008Oooool00ol0003oooooooooo`0Qoooo
o`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00Cooooo00?o
0000ooooooooool06oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool0
6Oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Kooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`0Hoooo
o`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo03_ooooo000Qooooo`03o`000?oooooooooo027ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00ol0003oooooooooo`0Kooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`0Iooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01_ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41006_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo03_ooooo
000Qooooo`;o00008_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP04ooooo`Co00006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIV
I_l000006oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l000001Oooool4
o`0001[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
6_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004oooo
o`Co0000>_ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo097ooooo4_l0002Fooooo`03oa0@4?l0
003o000000?o00001Oooool0027ooooo00?o0000ooooooooool0S?ooool5o`0001;ooooo0ol0002E
ooooo`03o`000?oooooooooo00Kooooo000Qooooo`03o`000?oooooooooo08Gooooo1ol0000Joooo
o`?o0000T_ooool00ol0003oooooooooo`06ooooo`008Oooooooo`0003?o00003?ooool00ol0003o
ooooooooo`06ooooo`008Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooool000000_l00005ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
0oooool:o`0000Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo01Cooooo00?o0000oc8b<_oMgMd01_ooool0027ooooo00?o0000ooooooooool0<?oo
ool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool05_oo
ool5o`0000[ooooo1ol00004ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0>ooo
ool2o`000004ojVYZOlQ8B7o0000ob4Q8@Cooooo000Qooooo`03o`000?oooooooooo0;Cooooo2_l0
0026ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooo
oom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003o
ooooodKooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00005ooooo`03o`000?oooooooooo0?oooooo
AOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Q
onk^k_ooooooA4A400Gooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooo
oooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000?ooooooAOooool000Oooooo
00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?o0000oooooooo
ool0oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_oo
ool01?ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@
41003oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001Oooool00ol0
003oooooooooo`3oooooodGooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnH
V9So410@o`000?lQ8B7oc<c<00Gooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool2o`00
0?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1_ooool2o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom5ooooo`00
1oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00_o
oooo1Ol00005ooooo`?o0000oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000_o
oooo00CoA4A4omgMgOoooooo00001_ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05
o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00006ooooo`03o`000?oooooo
oooo0?ooooooAOooool000Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co
000000Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01OmgMgOoV9RHoooooonHV9So
MgMg00cooooo00?ok^k^odA4A?l000001_ooool00ol0003oooooooooo`3oooooodGooooo0007oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`05ooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool2o`000?oo
ooooA_ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000
oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0
003oooooodKooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c005oooo
o`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Gooooo00?o0000ooooooooool0oooooom5
ooooo`001oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00
0005ooooo`?o0000oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo00Go
0000oiRHV?ooooooV9RHob4Q8@05ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go
0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01Oooool00ol0003o
ooooooooo`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGo
QhN7ooooo`07ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Oooooo00?o0000ooooooooool0oooooom5ooooo`00
1oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@1Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
0_l0003oooooodKooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`001ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<
c<`01Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@05ooooo`03o`000?oooooooooo
0?ooooooAOooool000Oooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooo
ooooool000001Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05o`000?oooooooooo
ooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Gooooo0ol0003oooooodGooooo0007
ooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<00Gooooo
00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00_ooooo
00Go410@okZj^_oooooo^[Zjoa0@4005ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000001Oooool00ol0
003oooooooooo`3oooooodGooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnY
ZJWo410@o`000?l@413oZJVY00Gooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool001Sooooo1?l000000ol@413oooooooooo`02ooooo`03o`00
0?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5
ooooo`006_ooool00ol0003oooooooooo`04ooooo`?o0000oooooom5ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006?ooool00omEEEGoIVIVo`00003oooooodkooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo002Nooooo`05oiRHV?l0003o0000odA4A?nj^[X0
6?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`Co000000?o410@oooooooo
ool00_ooool00ol0003ok^k^ooooo`2@ooooo`007oooool01?l@413o0000o`000?l0001kooooo`05
oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1oooool00ol0003oooooooooo`04ooooo`03oeEEEOnYZJWooooo093ooooo000Poooo
o`03o`000?oooooooooo07_ooooo00?o0000ooooooooool06_ooool01Ol@413ooooooooooooooooo
410@00kooooo00?o0000ooooooooool01?ooool00onYZJWoEEEEooooo`2@ooooo`008?ooool00ol0
003oooooooooo`1kooooo`03o`000?oooooooooo00_ooooo1_l00009ooooo`05o`000?oooooooooo
ooooool000003_ooool00ol0003oooooooooo`05ooooo`03ob4Q8Ooooooooooo08oooooo000Poooo
o`06o`000?mgMgOo0000o`000?mEEEGok^k^N?ooool00ol0003oooooooooo`0Jooooo`05o`000?oo
ooooooooooooool000003_ooool00ol0003oooooooooo`05ooooo`03oeEEEOo<c<cooooo08oooooo
000Pooooo`06o`000?mEEEGok^k^oooooomgMgOoEEEEM_ooool00ol@413o0000o`000003o`0001Wo
oooo00Go410@oooooooooooooooooa0@400>ooooo`03o`000?oooooooooo00Gooooo00?oZJVYogMg
Moooool0Soooool0023ooooo00?o0000onk^k_ooool00_ooool00ol0003oooooooooo`1fooooo`03
o`000?oooooooooo01[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oooooooooo
00;ooooo00Go410@oooooooooooooooooc8b<P2@ooooo`008?ooool00ol0003ok^k^ooooo`02oooo
o`03o`000?oooooooooo07Kooooo00?o0000ooooooooool06_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00cooooo00?oEEEEofIVI_l000001?ooool5o`00093ooooo000Pooooo`06o`000?mEEEGok^k^
oooooomgMgOoIVIVoooooom3ooooo`007oooool00ol@413o0000ogMgM`02o`000003ofIVI_o^k^ko
oooo0?oooooo@_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.0332543, -0.540631, \
0.00122928, 0.00994506}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 3.33333 0.206011 0.412023 [
[.16667 .19351 -12 -9 ]
[.16667 .19351 12 0 ]
[.33333 .19351 -9 -9 ]
[.33333 .19351 9 0 ]
[.5 .19351 -12 -9 ]
[.5 .19351 12 0 ]
[.66667 .19351 -9 -9 ]
[.66667 .19351 9 0 ]
[.83333 .19351 -12 -9 ]
[.83333 .19351 12 0 ]
[1.025 .20601 0 -6 ]
[1.025 .20601 10 6 ]
[-0.0125 .0412 -24 -4.5 ]
[-0.0125 .0412 0 4.5 ]
[-0.0125 .12361 -24 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .28842 -18 -4.5 ]
[-0.0125 .28842 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .45322 -18 -4.5 ]
[-0.0125 .45322 0 4.5 ]
[-0.0125 .53563 -18 -4.5 ]
[-0.0125 .53563 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 .20601 m
.16667 .21226 L
s
[(0.05)] .16667 .19351 0 1 Mshowa
.33333 .20601 m
.33333 .21226 L
s
[(0.1)] .33333 .19351 0 1 Mshowa
.5 .20601 m
.5 .21226 L
s
[(0.15)] .5 .19351 0 1 Mshowa
.66667 .20601 m
.66667 .21226 L
s
[(0.2)] .66667 .19351 0 1 Mshowa
.83333 .20601 m
.83333 .21226 L
s
[(0.25)] .83333 .19351 0 1 Mshowa
.125 Mabswid
.03333 .20601 m
.03333 .20976 L
s
.06667 .20601 m
.06667 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.13333 .20601 m
.13333 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.23333 .20601 m
.23333 .20976 L
s
.26667 .20601 m
.26667 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.36667 .20601 m
.36667 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.43333 .20601 m
.43333 .20976 L
s
.46667 .20601 m
.46667 .20976 L
s
.53333 .20601 m
.53333 .20976 L
s
.56667 .20601 m
.56667 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.63333 .20601 m
.63333 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.73333 .20601 m
.73333 .20976 L
s
.76667 .20601 m
.76667 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.86667 .20601 m
.86667 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.93333 .20601 m
.93333 .20976 L
s
.96667 .20601 m
.96667 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
gsave
1.025 .20601 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .0412 m
.00625 .0412 L
s
[(-0.4)] -0.0125 .0412 1 0 Mshowa
0 .12361 m
.00625 .12361 L
s
[(-0.2)] -0.0125 .12361 1 0 Mshowa
0 .28842 m
.00625 .28842 L
s
[(0.2)] -0.0125 .28842 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.4)] -0.0125 .37082 1 0 Mshowa
0 .45322 m
.00625 .45322 L
s
[(0.6)] -0.0125 .45322 1 0 Mshowa
0 .53563 m
.00625 .53563 L
s
[(0.8)] -0.0125 .53563 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .10301 m
.00375 .10301 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .30902 m
.00375 .30902 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .39142 m
.00375 .39142 L
s
0 .41202 m
.00375 .41202 L
s
0 .43262 m
.00375 .43262 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .51503 m
.00375 .51503 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
0 .0206 m
.00375 .0206 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.18) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .20601 m
.00123 .20601 L
.00236 .20601 L
.00365 .20601 L
.00488 .20601 L
.00601 .20601 L
.00706 .20601 L
.00821 .20601 L
.00942 .20601 L
.01065 .20601 L
.01196 .20601 L
.0132 .20601 L
.01434 .20601 L
.01566 .20601 L
.01711 .20601 L
.01848 .20601 L
.01975 .20601 L
.02106 .20601 L
.02247 .20601 L
.0238 .20601 L
.02503 .20601 L
.02614 .20601 L
.02736 .20601 L
.02864 .20601 L
.02982 .20601 L
.03122 .20601 L
.03254 .20601 L
.03372 .20601 L
.03501 .20601 L
.03641 .20601 L
.0379 .20601 L
.03917 .20601 L
.04057 .20601 L
.0419 .20601 L
.04336 .20601 L
.04488 .20601 L
.0463 .20601 L
.04763 .20601 L
.04884 .20601 L
.05023 .20601 L
.05155 .20601 L
.05298 .20601 L
.0545 .20601 L
.0558 .20601 L
.05723 .20601 L
.05876 .20601 L
.05962 .20601 L
.06041 .20601 L
.06194 .20601 L
.06339 .20601 L
Mistroke
.06474 .20601 L
.06596 .20601 L
.06738 .20601 L
.0687 .20601 L
.06994 .20601 L
.07107 .20601 L
.07232 .20601 L
.07364 .20601 L
.07497 .20601 L
.07639 .20601 L
.07774 .20601 L
.07897 .20601 L
.0804 .20601 L
.08197 .20601 L
.08344 .20601 L
.08481 .20601 L
.08605 .20601 L
.08736 .20601 L
.08847 .20601 L
.08969 .20601 L
.09101 .20601 L
.09241 .20601 L
.09374 .20601 L
.09494 .20601 L
.09617 .20601 L
.09729 .20601 L
.09853 .20601 L
.09983 .20601 L
.10097 .20601 L
.10203 .20601 L
.1032 .20601 L
.10445 .20601 L
.10589 .20601 L
.10723 .20601 L
.1087 .20601 L
.11026 .20601 L
.11161 .20601 L
.11287 .20601 L
.11426 .20601 L
.11576 .20601 L
.11702 .20601 L
.11839 .20601 L
.11982 .20601 L
.12115 .20601 L
.1224 .20601 L
.12354 .20601 L
.12485 .20601 L
.12609 .20601 L
.1273 .20601 L
.1286 .20601 L
Mistroke
.12982 .20601 L
.13094 .20601 L
.13225 .20601 L
.13368 .20601 L
.13503 .20601 L
.13628 .20601 L
.1377 .20601 L
.13903 .20601 L
.14022 .20601 L
.14151 .20601 L
.14292 .20601 L
.14441 .20601 L
.14569 .20601 L
.14708 .20601 L
.14838 .20601 L
.14961 .20601 L
.15192 .20601 L
.15321 .20601 L
.1544 .20601 L
.15571 .20601 L
.1571 .20601 L
.1582 .20601 L
.15939 .20601 L
.16155 .20601 L
.16279 .20601 L
.1641 .20601 L
.16645 .20601 L
.16775 .20601 L
.16915 .20601 L
.17048 .20601 L
.17171 .20601 L
.17403 .20601 L
.1752 .20601 L
.17648 .20601 L
.17788 .20601 L
.17915 .20601 L
.18062 .20601 L
.18202 .20601 L
.18449 .20601 L
.1859 .20601 L
.18719 .20601 L
.18841 .20601 L
.18972 .20601 L
.19088 .20601 L
.1921 .20601 L
.1932 .20601 L
.19441 .20601 L
.19654 .20601 L
.19784 .20601 L
.19903 .20601 L
Mistroke
.2003 .20601 L
.20169 .20601 L
.20297 .20601 L
.20415 .20601 L
.20648 .20601 L
.20779 .20601 L
.20904 .20601 L
.21137 .20601 L
.21267 .20601 L
.21388 .20601 L
.2153 .20601 L
.21663 .20601 L
.21779 .20601 L
.21904 .20601 L
.22123 .20601 L
.22247 .20601 L
.22378 .20601 L
.22614 .20601 L
.22748 .20601 L
.22871 .20601 L
.23003 .20601 L
.23147 .20601 L
.2328 .20601 L
.23403 .20601 L
.23646 .20601 L
.2378 .20601 L
.23907 .20601 L
.24057 .20601 L
.24195 .20601 L
.24476 .20601 L
.24624 .20601 L
.24779 .20601 L
.24908 .20601 L
.25049 .20601 L
.25173 .20601 L
.25304 .20601 L
.25552 .20601 L
.2578 .20601 L
.25907 .20601 L
.26044 .20601 L
.2629 .20601 L
.2644 .20601 L
.26583 .20601 L
.26851 .20601 L
.27083 .20601 L
.27329 .20601 L
.27562 .20601 L
.27773 .20601 L
.28022 .20601 L
.28291 .20601 L
Mistroke
.28545 .20601 L
.28779 .20601 L
.29038 .20601 L
.29274 .20601 L
.29546 .20601 L
.29803 .20601 L
.30041 .20601 L
.30261 .20601 L
.30502 .20601 L
.30759 .20601 L
.31015 .20601 L
.31291 .20601 L
.31552 .20601 L
.31791 .20601 L
.32056 .20601 L
.32346 .20601 L
.32648 .20601 L
.32929 .20601 L
.33206 .20601 L
.33461 .20601 L
.33741 .20601 L
.34036 .20601 L
.34294 .20601 L
.34534 .20601 L
.34798 .20601 L
.35081 .20601 L
.35331 .20601 L
.35605 .20601 L
.35863 .20601 L
.36101 .20601 L
.36553 .20601 L
.36781 .20601 L
.37033 .20601 L
.37279 .20601 L
.37548 .20601 L
.37829 .20601 L
.38091 .20601 L
.3856 .20601 L
.38822 .20601 L
.39061 .20601 L
.39601 .206 L
.39905 .206 L
.40187 .206 L
.40703 .20599 L
.40963 .20598 L
.4125 .20598 L
.41511 .20597 L
.41796 .20596 L
.42315 .20594 L
.4282 .2059 L
Mistroke
.43289 .20586 L
.43845 .2058 L
.4435 .20572 L
.44932 .20559 L
.45481 .20544 L
.4597 .20526 L
.46507 .20502 L
.47029 .20472 L
.4759 .20433 L
.48593 .20342 L
.4953 .20232 L
.5161 .19914 L
.52708 .1974 L
.53309 .19657 L
.53603 .19622 L
.53873 .19594 L
.54111 .19574 L
.54371 .19556 L
.54497 .19549 L
.54632 .19543 L
.54706 .1954 L
.54774 .19538 L
.54907 .19535 L
.54978 .19534 L
.55053 .19534 L
.55188 .19534 L
.55263 .19535 L
.55334 .19537 L
.55411 .19539 L
.55493 .19542 L
.55642 .19549 L
.55783 .19557 L
.56047 .19579 L
.56289 .19605 L
.56546 .19639 L
.57009 .19717 L
.58058 .19968 L
.6016 .20656 L
.61265 .21011 L
.61868 .21176 L
.6243 .21303 L
.62936 .21393 L
.63196 .21429 L
.63478 .21461 L
.63639 .21476 L
.63787 .21487 L
.63926 .21496 L
.64079 .21503 L
.64216 .21508 L
.64345 .21511 L
Mistroke
.6448 .21512 L
.64556 .21513 L
.64626 .21512 L
.6475 .21511 L
.64882 .21508 L
.65007 .21504 L
.6512 .21499 L
.65398 .21484 L
.6566 .21465 L
.66132 .21421 L
.66644 .21362 L
.68694 .21077 L
.69781 .20937 L
.70946 .20816 L
.71521 .20769 L
.72067 .20731 L
.72597 .20702 L
.73089 .20679 L
.73544 .20662 L
.74047 .20647 L
.74552 .20635 L
.7509 .20626 L
.75605 .20619 L
.76148 .20613 L
.76612 .2061 L
.77119 .20607 L
.77667 .20605 L
.77974 .20604 L
.78253 .20604 L
.78514 .20603 L
.78796 .20603 L
.79043 .20603 L
.79309 .20602 L
.79576 .20602 L
.79821 .20602 L
.80301 .20602 L
.80569 .20602 L
.80861 .20601 L
.81136 .20601 L
.81394 .20601 L
.81685 .20601 L
.81948 .20601 L
.82232 .20601 L
.82539 .20601 L
.82809 .20601 L
.83093 .20601 L
.83336 .20601 L
.83603 .20601 L
.83867 .20601 L
.84154 .20601 L
Mistroke
.84425 .20601 L
.84676 .20601 L
.84901 .20601 L
.8515 .20601 L
.85409 .20601 L
.85653 .20601 L
.85922 .20601 L
.86205 .20601 L
.86447 .20601 L
.86711 .20601 L
.86996 .20601 L
.87301 .20601 L
.87589 .20601 L
.8785 .20601 L
.88093 .20601 L
.8836 .20601 L
.88639 .20601 L
.88899 .20601 L
.89143 .20601 L
.89366 .20601 L
.89623 .20601 L
.89866 .20601 L
.90129 .20601 L
.90276 .20601 L
.90409 .20601 L
.90668 .20601 L
.90912 .20601 L
.91051 .20601 L
.91198 .20601 L
.9146 .20601 L
.91606 .20601 L
.91742 .20601 L
.91892 .20601 L
.92051 .20601 L
.92182 .20601 L
.92326 .20601 L
.92579 .20601 L
.92722 .20601 L
.92875 .20601 L
.93153 .20601 L
.93286 .20601 L
.93432 .20601 L
.9356 .20601 L
.93697 .20601 L
.93832 .20601 L
.93955 .20601 L
.94194 .20601 L
.94317 .20601 L
.94446 .20601 L
.94677 .20601 L
Mistroke
.94805 .20601 L
.94925 .20601 L
.95066 .20601 L
.95199 .20601 L
.95313 .20601 L
.95437 .20601 L
.95655 .20601 L
.95778 .20601 L
.95909 .20601 L
.96145 .20601 L
.96261 .20601 L
.96388 .20601 L
.96512 .20601 L
.96644 .20601 L
.96768 .20601 L
.96881 .20601 L
.97102 .20601 L
.97234 .20601 L
.97356 .20601 L
.97488 .20601 L
.97632 .20601 L
.97875 .20601 L
.98009 .20601 L
.98133 .20601 L
.98248 .20601 L
.98374 .20601 L
.98485 .20601 L
.98603 .20601 L
.9872 .20601 L
.98826 .20601 L
.99033 .20601 L
.99158 .20601 L
.99273 .20601 L
.99396 .20601 L
.99531 .20601 L
.99759 .20601 L
.99884 .20601 L
1 .20601 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13039,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo00?ooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooo
oom5ooooo`001Ol00002ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Gooooo00?o
0000ooooooooool0oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo00Co
A4A4omgMgOoooooo00001_ooool3o`000?ooooooAOooool000Oooooo00Go0000oooooooooooooooo
o`00000;ooooo`04omgMgOmEEEGoooooo`0000Kooooo00?o0000ooooooooool0oooooom5ooooo`00
1oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001_ooool00ol0003o
ooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^ko
A4A4o`000006ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Gooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool5o`0000Gooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool00ol0003oooooooooo`3oooooodGooooo0005o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0oooooom5ooooo`001ooo
ool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01Oooool3o`000?oooooo
AOooool000Oooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Cooooo
00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Gooooo00?o0000oooooooo
ool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c005ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo027ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@0Iooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l00000
0ol@413oooooooooo`0Gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l0
00001Ol@413oooooooooooooooooA4A400;o000000?o<S8bomgMgOooool06?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM03Wooooo000Qoooo
o`;o00008_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01oooool00omgMgOo<S8booooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B47ooooo`03o`000?oooooooooo00Kooooo00?oMgMgoc8b<_ooool06?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@06_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1oooool00omgMgOo<S8booooo`0hooooo`008Oooool00ol0003oooooooooo`0Qooooo`05oa0@4?oo
ooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000oooooooo
ool05oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool06Oooool01Ol@
413ooooooooooooooooo410@00kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0G
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Kooooo`05oa0@4?oo
ooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo03Oooooo
000Qooooo`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`00
0?ooooooooooooooool000001oooool00omgMgOo<S8booooo`0Hooooo`05o`000?oooooooooooooo
ool000003_ooool00ol0003oooooooooo`0Iooooo`05o`000?ooooooooooooooool000003_ooool0
0ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo01Sooooo00Go0000ooooooooooooooooo`00
000=ooooo`03oiRHV?lQ8B7ok^k^01[ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool0>?ooool0027ooooo00?o0000ooooooooool08Ooo
ool01Ol0003ooooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000004ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`06Oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000
ooooooooool06Oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<01Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo01Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00iooooo`008Oooool00ol0003oooooooooo`0Qoooo
o`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00Cooooo00?o
0000ooooooooool06oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool0
6Oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Kooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`0Hoooo
o`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo03_ooooo000Qooooo`03o`000?oooooooooo027ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00ol0003oooooooooo`0Kooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`0Iooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01_ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41006_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo03_ooooo
000Qooooo`;o00008_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP04ooooo`Co00006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIV
I_l000006oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l000001Oooool4
o`0001[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
6_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004oooo
o`Co0000>_ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo09gooooo4Ol0002;ooooo`03oa0@4?l0
003o000000?o00001Oooool0027ooooo00?o0000ooooooooool0V?ooool5o`00017ooooo0ol0002:
ooooo`03o`000?oooooooooo00Kooooo000Qooooo`03o`000?oooooooooo093ooooo2?l0000Ioooo
o`?o0000Qoooool00ol0003oooooooooo`06ooooo`008Oooooooo`0003?o00003?ooool00ol0003o
ooooooooo`06ooooo`008Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool01?l0003oooooooooooooool2o`0000Gooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`05ooooo`Oo00001Oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo01Cooooo00?o0000oc8b<_oMgMd01_ooool0027ooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
8Oooool4o`0000[ooooo2Ol0000[ooooo`03o`000?oooooooooo03_ooooo0_l000001?nYZJWo8B4Q
o`000?lQ8B44ooooo`008Oooool00ol0003oooooooooo`2nooooo`[o0000O?ooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go00001Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A005oooo
o`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go410@oooooooooooooooooa0@400<oooo
o`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003oooooodGooooo0007ooooo`05o`000?oooooooooooooo
ool000003Oooool00onHV9So8B4Qonk^kP05ooooo`03o`000?oooooooooo0?ooooooAOooool000Oo
oooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Cooooo00?o0000oooo
ooooool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Gooooo00?o0000ooooooooool0oooooom5
ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c005ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo0_l0003oooooodKooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@
413oooooooooo`03ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
0?ooooooAOooool000Oooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00001Oooool3o`00
0?ooooooAOooool000Oooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgooooo
o`0000Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo
000000_ooooo00CogMgMoeEEEOoooooo00001_ooool00ol0003oooooooooo`3oooooodGooooo0007
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000006ooooo`03o`000?oo
oooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000000Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00gooooo00?oMgMgo`000?ooool01Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01Oooool00ol0003oooooooooo`3o
ooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEE
ogMgMoooooooV9RHob4Q8@05ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go410@
oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001Oooool3o`000?oooooo
AOooool000Oooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ
8B401Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05o`000?ooooooooooooooool0
00002oooool01Ol0003oEEEEo`000?l@413oc<c<00Gooooo00?o0000ooooooooool0oooooom5oooo
o`001oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool01oooool00ol0
003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooM
gMgo410@oiRHV007ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Gooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool2o`000?ooooooA_oo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Gooooo00?o0000oooo
ooooool0oooooom5ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44oooo
o`05ob4Q8OnHV9SooooooiRHV?lQ8B401Oooool00ol0003oooooooooo`3oooooodGooooo0007oooo
o`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Gooooo00?o
0000ooooooooool0oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo00Go
<S8boiRHV?ooooooV9RHoc8b<P05ooooo`?o0000oooooom5ooooo`001oooool01Ol0003ooooooooo
oooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c005ooooo`03o`000?oooooooooo0?oo
ooooAOooool000Oooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj
^_l@41001Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Gooooo00?o0000ooooooooool0oooooom5
ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVY
Z@05ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo0_l0003oooooodKooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodGo
oooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000
ooooooooool01?ooool3o`000?ooooooAOooool001[ooooo00?o0000ooooooooool0oooooom<oooo
o`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?oooooo
C?ooool001Sooooo00?oEEEEofIVI_l00000oooooom>ooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00W_ooool01OnHV9So0000o`000?m4A4Co^[Zj01Sooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1Oooool4o`000008oa0@4?ooooooooooolc<c?lQ8B7o0000ob4Q
8Oo<c<b@ooooo`007oooool01?l@413o0000o`000?l0001kooooo`05oa0@4?nj^[[ok^k^ogMgMol@
41002Oooool6o`0000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0
003oooooooooo`02ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40T?ooool0023ooooo00?o0000oooo
ooooool0Noooool00ol0003oooooooooo`0Jooooo`05oa0@4?ooooooooooooooool@41003_ooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000T?ooool0023ooooo00?o0000
ooooooooool0Noooool00ol0003oooooooooo`0;ooooo`Ko00002Oooool01Ol0003ooooooooooooo
oooo000000kooooo00?o0000ooooooooool00_ooool01Olb<S;oV9RHoooooonHV9So<S8b093ooooo
000Pooooo`06o`000?mgMgOo0000o`000?mEEEGok^k^N?ooool00ol0003oooooooooo`0Jooooo`05
o`000?ooooooooooooooool000003_ooool00ol0003oooooooooo`02ooooo`05olc<c?l0003o0000
o`000?o<c<`0T?ooool0023ooooo00Ko0000oeEEEOo^k^koooooogMgMomEEEEfooooo`03oa0@4?l0
003o000000?o00006Oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool0
0_ooool01Ol@413o^[Zjoooooonj^[[o410@093ooooo000Pooooo`03o`000?o^k^kooooo00;ooooo
00?o0000ooooooooool0M_ooool00ol0003oooooooooo`0Jooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03_ooool00ol0003oooooooooo`02ooooo`05o`000?nj^[[ooooookZj^_l00000T?ooool0023o
oooo00?o0000onk^k_ooool00_ooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo01[o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`03oeEEEOmVIVKo000000Cooooo00GoZJVYoa0@
4?l0003o410@ojVYZ@2@ooooo`008?ooool01_l0003oEEEEonk^k_ooooooMgMgofIVI_oooooo@ooo
ool001oooooo00?o410@o`000?mgMgL00_l000000omVIVKok^k^ooooo`3ooooood;ooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.0332543, -0.540631, \
0.00122928, 0.00994506}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 3.33333 0.206011 0.412023 [
[.16667 .19351 -12 -9 ]
[.16667 .19351 12 0 ]
[.33333 .19351 -9 -9 ]
[.33333 .19351 9 0 ]
[.5 .19351 -12 -9 ]
[.5 .19351 12 0 ]
[.66667 .19351 -9 -9 ]
[.66667 .19351 9 0 ]
[.83333 .19351 -12 -9 ]
[.83333 .19351 12 0 ]
[1.025 .20601 0 -6 ]
[1.025 .20601 10 6 ]
[-0.0125 .0412 -24 -4.5 ]
[-0.0125 .0412 0 4.5 ]
[-0.0125 .12361 -24 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .28842 -18 -4.5 ]
[-0.0125 .28842 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .45322 -18 -4.5 ]
[-0.0125 .45322 0 4.5 ]
[-0.0125 .53563 -18 -4.5 ]
[-0.0125 .53563 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 .20601 m
.16667 .21226 L
s
[(0.05)] .16667 .19351 0 1 Mshowa
.33333 .20601 m
.33333 .21226 L
s
[(0.1)] .33333 .19351 0 1 Mshowa
.5 .20601 m
.5 .21226 L
s
[(0.15)] .5 .19351 0 1 Mshowa
.66667 .20601 m
.66667 .21226 L
s
[(0.2)] .66667 .19351 0 1 Mshowa
.83333 .20601 m
.83333 .21226 L
s
[(0.25)] .83333 .19351 0 1 Mshowa
.125 Mabswid
.03333 .20601 m
.03333 .20976 L
s
.06667 .20601 m
.06667 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.13333 .20601 m
.13333 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.23333 .20601 m
.23333 .20976 L
s
.26667 .20601 m
.26667 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.36667 .20601 m
.36667 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.43333 .20601 m
.43333 .20976 L
s
.46667 .20601 m
.46667 .20976 L
s
.53333 .20601 m
.53333 .20976 L
s
.56667 .20601 m
.56667 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.63333 .20601 m
.63333 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.73333 .20601 m
.73333 .20976 L
s
.76667 .20601 m
.76667 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.86667 .20601 m
.86667 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.93333 .20601 m
.93333 .20976 L
s
.96667 .20601 m
.96667 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
gsave
1.025 .20601 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .0412 m
.00625 .0412 L
s
[(-0.4)] -0.0125 .0412 1 0 Mshowa
0 .12361 m
.00625 .12361 L
s
[(-0.2)] -0.0125 .12361 1 0 Mshowa
0 .28842 m
.00625 .28842 L
s
[(0.2)] -0.0125 .28842 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.4)] -0.0125 .37082 1 0 Mshowa
0 .45322 m
.00625 .45322 L
s
[(0.6)] -0.0125 .45322 1 0 Mshowa
0 .53563 m
.00625 .53563 L
s
[(0.8)] -0.0125 .53563 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .10301 m
.00375 .10301 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .30902 m
.00375 .30902 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .39142 m
.00375 .39142 L
s
0 .41202 m
.00375 .41202 L
s
0 .43262 m
.00375 .43262 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .51503 m
.00375 .51503 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
0 .0206 m
.00375 .0206 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.19) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .20601 m
.00123 .20601 L
.00236 .20601 L
.00365 .20601 L
.00488 .20601 L
.00601 .20601 L
.00706 .20601 L
.00821 .20601 L
.00942 .20601 L
.01065 .20601 L
.01196 .20601 L
.0132 .20601 L
.01434 .20601 L
.01566 .20601 L
.01711 .20601 L
.01848 .20601 L
.01975 .20601 L
.02106 .20601 L
.02247 .20601 L
.0238 .20601 L
.02503 .20601 L
.02614 .20601 L
.02736 .20601 L
.02864 .20601 L
.02982 .20601 L
.03122 .20601 L
.03254 .20601 L
.03372 .20601 L
.03501 .20601 L
.03641 .20601 L
.0379 .20601 L
.03917 .20601 L
.04057 .20601 L
.0419 .20601 L
.04336 .20601 L
.04409 .20601 L
.04488 .20601 L
.0463 .20601 L
.04771 .20601 L
.04905 .20601 L
.05025 .20601 L
.05155 .20601 L
.05297 .20601 L
.05378 .20601 L
.05454 .20601 L
.05607 .20601 L
.05692 .20601 L
.05771 .20601 L
.0591 .20601 L
.05984 .20601 L
Mistroke
.06062 .20601 L
.06206 .20601 L
.06339 .20601 L
.06484 .20601 L
.06617 .20601 L
.06763 .20601 L
.06837 .20601 L
.06918 .20601 L
.07054 .20601 L
.072 .20601 L
.07338 .20601 L
.07463 .20601 L
.07593 .20601 L
.07714 .20601 L
.07846 .20601 L
.07986 .20601 L
.08107 .20601 L
.08221 .20601 L
.08346 .20601 L
.08481 .20601 L
.08613 .20601 L
.08734 .20601 L
.08872 .20601 L
.09003 .20601 L
.09125 .20601 L
.09236 .20601 L
.09359 .20601 L
.09488 .20601 L
.09619 .20601 L
.0976 .20601 L
.09892 .20601 L
.10013 .20601 L
.10155 .20601 L
.10309 .20601 L
.10454 .20601 L
.10589 .20601 L
.10716 .20601 L
.10852 .20601 L
.10981 .20601 L
.111 .20601 L
.11231 .20601 L
.11374 .20601 L
.11524 .20601 L
.11664 .20601 L
.11812 .20601 L
.11953 .20601 L
.12079 .20601 L
.12216 .20601 L
.12365 .20601 L
.12523 .20601 L
Mistroke
.12658 .20601 L
.12806 .20601 L
.12942 .20601 L
.13067 .20601 L
.13205 .20601 L
.13352 .20601 L
.13493 .20601 L
.13625 .20601 L
.13743 .20601 L
.13871 .20601 L
.13989 .20601 L
.14118 .20601 L
.14253 .20601 L
.14379 .20601 L
.14497 .20601 L
.14604 .20601 L
.14728 .20601 L
.14846 .20601 L
.14971 .20601 L
.1511 .20601 L
.15255 .20601 L
.15391 .20601 L
.15518 .20601 L
.15634 .20601 L
.15762 .20601 L
.15896 .20601 L
.16033 .20601 L
.16179 .20601 L
.16317 .20601 L
.16442 .20601 L
.16589 .20601 L
.16749 .20601 L
.16899 .20601 L
.17038 .20601 L
.1717 .20601 L
.17295 .20601 L
.17407 .20601 L
.1753 .20601 L
.17662 .20601 L
.17803 .20601 L
.17937 .20601 L
.18057 .20601 L
.1818 .20601 L
.18293 .20601 L
.18417 .20601 L
.18548 .20601 L
.18769 .20601 L
.18894 .20601 L
.1901 .20601 L
.19145 .20601 L
Mistroke
.19292 .20601 L
.1943 .20601 L
.19558 .20601 L
.19673 .20601 L
.198 .20601 L
.19933 .20601 L
.20057 .20601 L
.20202 .20601 L
.20339 .20601 L
.20462 .20601 L
.20597 .20601 L
.20743 .20601 L
.20898 .20601 L
.21045 .20601 L
.21178 .20601 L
.21422 .20601 L
.2156 .20601 L
.21689 .20601 L
.21826 .20601 L
.2195 .20601 L
.22094 .20601 L
.2223 .20601 L
.22346 .20601 L
.2247 .20601 L
.22693 .20601 L
.22817 .20601 L
.22933 .20601 L
.23198 .20601 L
.23325 .20601 L
.23465 .20601 L
.23611 .20601 L
.23746 .20601 L
.23989 .20601 L
.24126 .20601 L
.24249 .20601 L
.24385 .20601 L
.24529 .20601 L
.24687 .20601 L
.24833 .20601 L
.25095 .20601 L
.25244 .20601 L
.25383 .20601 L
.25515 .20601 L
.25654 .20601 L
.25906 .20601 L
.2606 .20601 L
.26205 .20601 L
.26336 .20601 L
.26476 .20601 L
.26599 .20601 L
Mistroke
.26735 .20601 L
.26974 .20601 L
.27109 .20601 L
.27253 .20601 L
.27388 .20601 L
.27513 .20601 L
.27763 .20601 L
.27896 .20601 L
.28036 .20601 L
.28271 .20601 L
.28405 .20601 L
.28531 .20601 L
.28764 .20601 L
.28978 .20601 L
.29212 .20601 L
.29459 .20601 L
.29589 .20601 L
.2973 .20601 L
.29854 .20601 L
.29985 .20601 L
.30234 .20601 L
.30463 .20601 L
.30727 .20601 L
.30974 .20601 L
.31115 .20601 L
.31244 .20601 L
.31385 .20601 L
.31535 .20601 L
.31781 .20601 L
.32009 .20601 L
.32254 .20601 L
.32525 .20601 L
.32758 .20601 L
.33009 .20601 L
.33246 .20601 L
.33464 .20601 L
.33724 .20601 L
.33961 .20601 L
.34233 .20601 L
.34491 .20601 L
.3473 .20601 L
.3495 .20601 L
.35192 .20601 L
.35448 .20601 L
.35705 .20601 L
.35982 .20601 L
.36243 .20601 L
.36482 .20601 L
.36761 .20601 L
.37065 .20601 L
Mistroke
.37353 .20601 L
.3762 .20601 L
.37898 .20601 L
.38153 .20601 L
.38434 .20601 L
.3873 .20601 L
.38988 .20601 L
.39229 .20601 L
.39493 .20601 L
.39776 .20601 L
.40027 .20601 L
.40301 .20601 L
.40559 .20601 L
.40798 .20601 L
.4125 .20601 L
.41478 .20601 L
.4173 .20601 L
.42246 .20601 L
.42506 .20601 L
.4279 .206 L
.43033 .206 L
.43293 .206 L
.43762 .20599 L
.44045 .20599 L
.44352 .20598 L
.44623 .20598 L
.44909 .20597 L
.45452 .20595 L
.45952 .20592 L
.4647 .20589 L
.46943 .20584 L
.47489 .20577 L
.48008 .20568 L
.48485 .20557 L
.48928 .20544 L
.49931 .20504 L
.50466 .20475 L
.51043 .20435 L
.5209 .20342 L
.53109 .20224 L
.54046 .20093 L
.55084 .19934 L
.56195 .1977 L
.56734 .19702 L
.57243 .1965 L
.57465 .19632 L
.57701 .19616 L
.57824 .1961 L
.57959 .19604 L
.58082 .196 L
Mistroke
.58198 .19597 L
.58325 .19595 L
.58444 .19595 L
.58574 .19596 L
.58713 .19598 L
.58845 .19602 L
.58969 .19608 L
.59202 .19622 L
.59432 .19641 L
.59643 .19663 L
.60121 .19728 L
.60601 .19816 L
.61128 .19935 L
.62191 .20234 L
.6333 .206 L
.64409 .20936 L
.65379 .21188 L
.65926 .21298 L
.6617 .21338 L
.66433 .21376 L
.66686 .21405 L
.66918 .21428 L
.6714 .21444 L
.67374 .21457 L
.67498 .21462 L
.6763 .21465 L
.67756 .21467 L
.6787 .21468 L
.68003 .21467 L
.68079 .21466 L
.68149 .21465 L
.68277 .21462 L
.68412 .21457 L
.68662 .21445 L
.6893 .21428 L
.69414 .21387 L
.70516 .21258 L
.72588 .20984 L
.73682 .20861 L
.74282 .20806 L
.74848 .20762 L
.75393 .20726 L
.75983 .20695 L
.76474 .20674 L
.77012 .20655 L
.77521 .20642 L
.78058 .20631 L
.78556 .20623 L
.7902 .20617 L
.79546 .20612 L
Mistroke
.79824 .20611 L
.80119 .20609 L
.80659 .20606 L
.81159 .20605 L
.81637 .20604 L
.82086 .20603 L
.82578 .20602 L
.82855 .20602 L
.83108 .20602 L
.83607 .20602 L
.83886 .20602 L
.84139 .20601 L
.84376 .20601 L
.84632 .20601 L
.85097 .20601 L
.85359 .20601 L
.85647 .20601 L
.85948 .20601 L
.86229 .20601 L
.86492 .20601 L
.86732 .20601 L
.87009 .20601 L
.87272 .20601 L
.87545 .20601 L
.87802 .20601 L
.88033 .20601 L
.88282 .20601 L
.88555 .20601 L
.88843 .20601 L
.89088 .20601 L
.89357 .20601 L
.89611 .20601 L
.89841 .20601 L
.90107 .20601 L
.90358 .20601 L
.9059 .20601 L
.90805 .20601 L
.9104 .20601 L
.9129 .20601 L
.91555 .20601 L
.91806 .20601 L
.92032 .20601 L
.92278 .20601 L
.92545 .20601 L
.92691 .20601 L
.92829 .20601 L
.93098 .20601 L
.93341 .20601 L
.93575 .20601 L
.93822 .20601 L
Mistroke
.94032 .20601 L
.94264 .20601 L
.94513 .20601 L
.9465 .20601 L
.9478 .20601 L
.95032 .20601 L
.95262 .20601 L
.95511 .20601 L
.95744 .20601 L
.96 .20601 L
.96144 .20601 L
.96276 .20601 L
.96526 .20601 L
.96668 .20601 L
.968 .20601 L
.97067 .20601 L
.97217 .20601 L
.97352 .20601 L
.97473 .20601 L
.97601 .20601 L
.9783 .20601 L
.97957 .20601 L
.98076 .20601 L
.98215 .20601 L
.98347 .20601 L
.98584 .20601 L
.988 .20601 L
.99033 .20601 L
.99164 .20601 L
.99286 .20601 L
.99479 .20601 L
.99661 .20601 L
.99824 .20601 L
1 .20601 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13039,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo00?ooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooo
oom5ooooo`001Ol00002ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Gooooo00?o
0000ooooooooool0oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo00Co
A4A4omgMgOoooooo00001_ooool3o`000?ooooooAOooool000Oooooo00Go0000oooooooooooooooo
o`00000;ooooo`04omgMgOmEEEGoooooo`0000Kooooo00?o0000ooooooooool0oooooom5ooooo`00
1oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001_ooool00ol0003o
ooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^ko
A4A4o`000006ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Gooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool5o`0000Gooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool00ol0003oooooooooo`3oooooodGooooo0005o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0oooooom5ooooo`001ooo
ool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01Oooool3o`000?oooooo
AOooool000Oooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Cooooo
00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Gooooo00?o0000oooooooo
ool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c005ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo027ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@0Iooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l00000
0ol@413oooooooooo`0Gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l0
00001Ol@413oooooooooooooooooA4A400;o000000?o<S8bomgMgOooool06?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM03Wooooo000Qoooo
o`;o00008_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01oooool00omgMgOo<S8booooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B47ooooo`03o`000?oooooooooo00Kooooo00?oMgMgoc8b<_ooool06?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@06_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1oooool00omgMgOo<S8booooo`0hooooo`008Oooool00ol0003oooooooooo`0Qooooo`05oa0@4?oo
ooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000oooooooo
ool05oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool06Oooool01Ol@
413ooooooooooooooooo410@00kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0G
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Kooooo`05oa0@4?oo
ooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo03Oooooo
000Qooooo`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`00
0?ooooooooooooooool000001oooool00omgMgOo<S8booooo`0Hooooo`05o`000?oooooooooooooo
ool000003_ooool00ol0003oooooooooo`0Iooooo`05o`000?ooooooooooooooool000003_ooool0
0ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo01Sooooo00Go0000ooooooooooooooooo`00
000=ooooo`03oiRHV?lQ8B7ok^k^01[ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool0>?ooool0027ooooo00?o0000ooooooooool08Ooo
ool01Ol0003ooooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000004ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`06Oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000
ooooooooool06Oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<01Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo01Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00iooooo`008Oooool00ol0003oooooooooo`0Qoooo
o`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00Cooooo00?o
0000ooooooooool06oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool0
6Oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Kooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`0Hoooo
o`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo03_ooooo000Qooooo`03o`000?oooooooooo027ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00ol0003oooooooooo`0Kooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`0Iooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01_ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41006_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo03_ooooo
000Qooooo`;o00008_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP04ooooo`Co00006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIV
I_l000006oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l000001Oooool4
o`0001[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
6_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004oooo
o`Co0000>_ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0:[ooooo3?l00023ooooo`03oa0@4?l0
003o000000?o00001Oooool0027ooooo00?o0000ooooooooool0Y?ooool6o`0000cooooo1Ol00020
ooooo`03o`000?oooooooooo00Kooooo000Qooooo`03o`000?oooooooooo09_ooooo2Ol0000Goooo
o`?o0000OOooool00ol0003oooooooooo`06ooooo`008Oooooooo`0003?o00003?ooool00ol0003o
ooooooooo`06ooooo`008Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00?o0000
1?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo2ol00004ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo01Cooooo00?o0000oc8b<_oMgMd01_ooool0027ooooo00?o0000ooooooooool0<?oo
ool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0;?oo
ool5o`0000Oooooo1ol0000Tooooo`03o`000?oooooooooo03_ooooo0_l000001?nYZJWo8B4Qo`00
0?lQ8B44ooooo`008Oooool00ol0003oooooooooo`39ooooo`So0000Loooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o
0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`Go00001Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`03
o`000?oooooooooo0?ooooooAOooool000Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03
oiRHV?lQ8B7ok^k^00Kooooo0ol0003oooooodGooooo0007ooooo`05o`000?ooooooooooooooool0
00003Oooool00onHV9So8B4Qonk^kP05ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo
00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Cooooo00?o0000oooooooo
ool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Gooooo00?o0000ooooooooool0oooooom5oooo
o`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c005
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo0_l0003oooooodKooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413o
ooooooooo`03ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oo
ooooAOooool000Oooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00001Oooool3o`000?oo
ooooAOooool000Oooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`00
00Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo0000
00_ooooo00CogMgMoeEEEOoooooo00001_ooool00ol0003oooooooooo`3oooooodGooooo0007oooo
o`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000006ooooo`03o`000?oooooo
oooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co
000000Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00gooooo00?oMgMgo`000?ooool01Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01Oooool00ol0003oooooooooo`3ooooo
odGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMg
MoooooooV9RHob4Q8@05ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go410@oooo
oooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001Oooool3o`000?ooooooAOoo
ool000Oooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40
1Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05o`000?ooooooooooooooool00000
2oooool01Ol0003oEEEEo`000?l@413oc<c<00Gooooo00?o0000ooooooooool0oooooom5ooooo`00
1oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool01oooool00ol0003o
ooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo
410@oiRHV007ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Gooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Gooooo00?o0000oooooooo
ool0oooooom5ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B401Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000
ooooooooool0oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8b
oiRHV?ooooooV9RHoc8b<P05ooooo`?o0000oooooom5ooooo`001oooool01Ol0003ooooooooooooo
oooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c005ooooo`03o`000?oooooooooo0?oooooo
AOooool000Oooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@
41001Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Gooooo00?o0000ooooooooool0oooooom5oooo
o`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@05
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo0_l0003oooooodKooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodGooooo
000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000oooo
ooooool01?ooool3o`000?ooooooAOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001Sooooo00?oEEEEofIVI_l00000oooooom>ooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00W_ooool01OnHV9So0000o`000?m4A4Co^[Zj01Sooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1Oooool4o`000007oa0@4?oooooooooooa0@4?l0003oA4A4olc<c02A
ooooo`007oooool01?l@413o0000o`000?l0001kooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Ooo
ool6o`0000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003ooooo
ooooo`04ooooo`03oiRHV?l@413ogMgM093ooooo000Pooooo`03o`000?oooooooooo07_ooooo00?o
0000ooooooooool06_ooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool0
1Oooool00on7QhOoEEEEooooo`2?ooooo`008?ooool00ol0003oooooooooo`1kooooo`03o`000?oo
oooooooo00_ooooo1_l00009ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003ooooo
ooooo`02ooooo`05olc<c?lQ8B7o0000oeEEEOl00000T?ooool0023ooooo00Ko0000ogMgMol0003o
0000oeEEEOo^k^ihooooo`03o`000?oooooooooo01[ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03o`000?oooooooooo00;ooooo00Go8B4QohN7QoooooooV9RHo`00002@ooooo`008?ooool0
1_l0003oEEEEonk^k_ooooooMgMgoeEEEGKooooo00?o410@o`000?l000000ol0000Iooooo`05oa0@
4?ooooooooooooooool@41003_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool00000T?ooool0023ooooo00?o0000onk^k_ooool00_ooool00ol0003oooooooooo`1fooooo`03
o`000?oooooooooo01[ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0>ooooo`03o`000?oooooooooo
00;ooooo00Go8B4QoiRHV?ooooooMgMgoeEEE@2@ooooo`008?ooool00ol0003ok^k^ooooo`02oooo
o`03o`000?oooooooooo07Kooooo00?o0000ooooooooool06_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00cooooo00?oEEEEofIVI_l000001?ooool01Oo<c<co410@o`000?lb<S;ok^k^093ooooo000P
ooooo`06o`000?mEEEGok^k^oooooomgMgOoIVIVoooooom3ooooo`007oooool00ol@413o0000ogMg
M`02o`000003ofIVI_o^k^kooooo0?oooooo@_ooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.0332543, -0.540631, \
0.00122928, 0.00994506}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 3.33333 0.206011 0.412023 [
[.16667 .19351 -12 -9 ]
[.16667 .19351 12 0 ]
[.33333 .19351 -9 -9 ]
[.33333 .19351 9 0 ]
[.5 .19351 -12 -9 ]
[.5 .19351 12 0 ]
[.66667 .19351 -9 -9 ]
[.66667 .19351 9 0 ]
[.83333 .19351 -12 -9 ]
[.83333 .19351 12 0 ]
[1.025 .20601 0 -6 ]
[1.025 .20601 10 6 ]
[-0.0125 .0412 -24 -4.5 ]
[-0.0125 .0412 0 4.5 ]
[-0.0125 .12361 -24 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .28842 -18 -4.5 ]
[-0.0125 .28842 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .45322 -18 -4.5 ]
[-0.0125 .45322 0 4.5 ]
[-0.0125 .53563 -18 -4.5 ]
[-0.0125 .53563 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 .20601 m
.16667 .21226 L
s
[(0.05)] .16667 .19351 0 1 Mshowa
.33333 .20601 m
.33333 .21226 L
s
[(0.1)] .33333 .19351 0 1 Mshowa
.5 .20601 m
.5 .21226 L
s
[(0.15)] .5 .19351 0 1 Mshowa
.66667 .20601 m
.66667 .21226 L
s
[(0.2)] .66667 .19351 0 1 Mshowa
.83333 .20601 m
.83333 .21226 L
s
[(0.25)] .83333 .19351 0 1 Mshowa
.125 Mabswid
.03333 .20601 m
.03333 .20976 L
s
.06667 .20601 m
.06667 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.13333 .20601 m
.13333 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.23333 .20601 m
.23333 .20976 L
s
.26667 .20601 m
.26667 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.36667 .20601 m
.36667 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.43333 .20601 m
.43333 .20976 L
s
.46667 .20601 m
.46667 .20976 L
s
.53333 .20601 m
.53333 .20976 L
s
.56667 .20601 m
.56667 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.63333 .20601 m
.63333 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.73333 .20601 m
.73333 .20976 L
s
.76667 .20601 m
.76667 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.86667 .20601 m
.86667 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.93333 .20601 m
.93333 .20976 L
s
.96667 .20601 m
.96667 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
gsave
1.025 .20601 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .0412 m
.00625 .0412 L
s
[(-0.4)] -0.0125 .0412 1 0 Mshowa
0 .12361 m
.00625 .12361 L
s
[(-0.2)] -0.0125 .12361 1 0 Mshowa
0 .28842 m
.00625 .28842 L
s
[(0.2)] -0.0125 .28842 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.4)] -0.0125 .37082 1 0 Mshowa
0 .45322 m
.00625 .45322 L
s
[(0.6)] -0.0125 .45322 1 0 Mshowa
0 .53563 m
.00625 .53563 L
s
[(0.8)] -0.0125 .53563 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .10301 m
.00375 .10301 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .30902 m
.00375 .30902 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .39142 m
.00375 .39142 L
s
0 .41202 m
.00375 .41202 L
s
0 .43262 m
.00375 .43262 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .51503 m
.00375 .51503 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
0 .0206 m
.00375 .0206 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.2) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .20601 m
.00123 .20601 L
.00236 .20601 L
.00365 .20601 L
.00488 .20601 L
.00601 .20601 L
.00706 .20601 L
.00821 .20601 L
.00942 .20601 L
.01065 .20601 L
.01196 .20601 L
.0132 .20601 L
.01434 .20601 L
.01566 .20601 L
.01711 .20601 L
.01848 .20601 L
.01975 .20601 L
.02106 .20601 L
.02247 .20601 L
.0238 .20601 L
.02503 .20601 L
.02614 .20601 L
.02736 .20601 L
.02864 .20601 L
.02982 .20601 L
.03122 .20601 L
.03254 .20601 L
.03372 .20601 L
.03501 .20601 L
.03641 .20601 L
.03712 .20601 L
.0379 .20601 L
.03927 .20601 L
.04057 .20601 L
.04191 .20601 L
.04315 .20601 L
.04452 .20601 L
.04528 .20601 L
.04598 .20601 L
.04738 .20601 L
.04818 .20601 L
.04891 .20601 L
.05025 .20601 L
.05093 .20601 L
.05167 .20601 L
.053 .20601 L
.05421 .20601 L
.05561 .20601 L
.05694 .20601 L
.05816 .20601 L
Mistroke
.05929 .20601 L
.06053 .20601 L
.06186 .20601 L
.06261 .20601 L
.06341 .20601 L
.06484 .20601 L
.06564 .20601 L
.06638 .20601 L
.06724 .20601 L
.06806 .20601 L
.06877 .20601 L
.06954 .20601 L
.07088 .20601 L
.07164 .20601 L
.07245 .20601 L
.0739 .20601 L
.07519 .20601 L
.07658 .20601 L
.07789 .20601 L
.07909 .20601 L
.08042 .20601 L
.08188 .20601 L
.08261 .20601 L
.0834 .20601 L
.08481 .20601 L
.08611 .20601 L
.08754 .20601 L
.08826 .20601 L
.08903 .20601 L
.09042 .20601 L
.09181 .20601 L
.09313 .20601 L
.09431 .20601 L
.09559 .20601 L
.09699 .20601 L
.09778 .20601 L
.09853 .20601 L
.10003 .20601 L
.10088 .20601 L
.10165 .20601 L
.10296 .20601 L
.10439 .20601 L
.10511 .20601 L
.10588 .20601 L
.10726 .20601 L
.10869 .20601 L
.11 .20601 L
.11144 .20601 L
.11217 .20601 L
.11297 .20601 L
Mistroke
.11431 .20601 L
.11575 .20601 L
.11711 .20601 L
.11835 .20601 L
.11964 .20601 L
.12083 .20601 L
.12213 .20601 L
.12352 .20601 L
.12485 .20601 L
.1261 .20601 L
.12722 .20601 L
.12844 .20601 L
.12974 .20601 L
.13093 .20601 L
.1323 .20601 L
.1336 .20601 L
.1348 .20601 L
.13591 .20601 L
.13713 .20601 L
.13843 .20601 L
.13972 .20601 L
.14112 .20601 L
.14243 .20601 L
.14364 .20601 L
.14498 .20601 L
.14644 .20601 L
.14797 .20601 L
.14939 .20601 L
.15077 .20601 L
.15227 .20601 L
.15369 .20601 L
.15499 .20601 L
.15617 .20601 L
.15747 .20601 L
.15882 .20601 L
.16009 .20601 L
.16156 .20601 L
.16297 .20601 L
.16422 .20601 L
.1656 .20601 L
.16708 .20601 L
.16867 .20601 L
.17016 .20601 L
.17151 .20601 L
.17278 .20601 L
.17396 .20601 L
.17526 .20601 L
.17665 .20601 L
.17811 .20601 L
.17949 .20601 L
Mistroke
.18073 .20601 L
.18207 .20601 L
.18324 .20601 L
.18452 .20601 L
.18586 .20601 L
.18712 .20601 L
.18829 .20601 L
.18936 .20601 L
.1906 .20601 L
.19178 .20601 L
.19315 .20601 L
.1944 .20601 L
.19584 .20601 L
.1972 .20601 L
.19846 .20601 L
.19962 .20601 L
.20089 .20601 L
.20224 .20601 L
.20359 .20601 L
.20505 .20601 L
.20642 .20601 L
.20768 .20601 L
.20915 .20601 L
.21075 .20601 L
.21226 .20601 L
.21366 .20601 L
.21489 .20601 L
.21619 .20601 L
.2173 .20601 L
.21852 .20601 L
.21983 .20601 L
.22123 .20601 L
.22255 .20601 L
.22376 .20601 L
.2261 .20601 L
.22742 .20601 L
.22864 .20601 L
.23087 .20601 L
.232 .20601 L
.23324 .20601 L
.23469 .20601 L
.23606 .20601 L
.23729 .20601 L
.23863 .20601 L
.24008 .20601 L
.24163 .20601 L
.24309 .20601 L
.24442 .20601 L
.24577 .20601 L
.24701 .20601 L
Mistroke
.24837 .20601 L
.2498 .20601 L
.25222 .20601 L
.25359 .20601 L
.25487 .20601 L
.2562 .20601 L
.25761 .20601 L
.26014 .20601 L
.26155 .20601 L
.26287 .20601 L
.26431 .20601 L
.26587 .20601 L
.26713 .20601 L
.26852 .20601 L
.26996 .20601 L
.2713 .20601 L
.27371 .20601 L
.27505 .20601 L
.27627 .20601 L
.27749 .20601 L
.27878 .20601 L
.28109 .20601 L
.28238 .20601 L
.28358 .20601 L
.28498 .20601 L
.28631 .20601 L
.28745 .20601 L
.28869 .20601 L
.29087 .20601 L
.2921 .20601 L
.29341 .20601 L
.29577 .20601 L
.29696 .20601 L
.29826 .20601 L
.29953 .20601 L
.30089 .20601 L
.30216 .20601 L
.30332 .20601 L
.30558 .20601 L
.30694 .20601 L
.3082 .20601 L
.30955 .20601 L
.31103 .20601 L
.31353 .20601 L
.3149 .20601 L
.31618 .20601 L
.31736 .20601 L
.31865 .20601 L
.321 .20601 L
.32329 .20601 L
Mistroke
.32542 .20601 L
.32794 .20601 L
.33023 .20601 L
.3315 .20601 L
.33287 .20601 L
.33536 .20601 L
.33785 .20601 L
.33925 .20601 L
.34052 .20601 L
.343 .20601 L
.34534 .20601 L
.34667 .20601 L
.34807 .20601 L
.35059 .20601 L
.35331 .20601 L
.35485 .20601 L
.3563 .20601 L
.35901 .20601 L
.36037 .20601 L
.36186 .20601 L
.36449 .20601 L
.36695 .20601 L
.36985 .20601 L
.3725 .20601 L
.37396 .20601 L
.37554 .20601 L
.37842 .20601 L
.3809 .20601 L
.38356 .20601 L
.38607 .20601 L
.38836 .20601 L
.39105 .20601 L
.39397 .20601 L
.39674 .20601 L
.3993 .20601 L
.40219 .20601 L
.40491 .20601 L
.40736 .20601 L
.41 .20601 L
.41289 .20601 L
.41594 .20601 L
.41854 .20601 L
.42139 .20601 L
.42404 .20601 L
.42692 .20601 L
.42963 .20601 L
.43214 .20601 L
.43689 .20601 L
.43929 .20601 L
.44193 .20601 L
Mistroke
.44478 .20601 L
.44739 .20601 L
.4504 .20601 L
.45327 .20601 L
.45835 .20601 L
.46123 .206 L
.4639 .206 L
.46922 .206 L
.47222 .20599 L
.47498 .20599 L
.48006 .20598 L
.48262 .20597 L
.48543 .20596 L
.4903 .20594 L
.49553 .20591 L
.50046 .20587 L
.50496 .20583 L
.51 .20576 L
.51536 .20566 L
.51993 .20555 L
.52498 .2054 L
.53039 .2052 L
.53622 .20492 L
.54677 .20423 L
.55681 .20332 L
.5678 .20203 L
.58995 .19889 L
.59502 .1982 L
.60052 .19753 L
.60572 .19702 L
.6082 .19683 L
.61052 .19669 L
.61191 .19662 L
.61318 .19657 L
.61459 .19653 L
.61537 .19651 L
.61611 .1965 L
.61682 .19649 L
.61758 .19649 L
.61894 .1965 L
.61978 .19651 L
.62057 .19652 L
.62127 .19654 L
.62204 .19657 L
.6233 .19662 L
.62469 .1967 L
.62749 .19691 L
.63009 .19716 L
.63251 .19745 L
.63777 .19828 L
Mistroke
.6435 .19944 L
.6539 .20213 L
.67339 .20805 L
.68412 .21092 L
.68937 .21205 L
.69418 .2129 L
.69923 .21357 L
.70188 .21383 L
.70467 .21404 L
.70605 .21412 L
.70753 .21418 L
.70825 .21421 L
.70893 .21423 L
.7102 .21426 L
.71093 .21427 L
.71171 .21427 L
.71237 .21427 L
.7131 .21427 L
.71388 .21426 L
.71472 .21425 L
.71552 .21423 L
.71624 .21421 L
.7176 .21417 L
.71888 .21411 L
.72127 .21399 L
.72662 .21358 L
.73624 .21256 L
.75802 .20981 L
.76831 .20868 L
.77917 .20774 L
.78843 .20714 L
.79369 .20689 L
.79858 .20669 L
.80386 .20652 L
.8096 .20638 L
.81501 .20628 L
.82002 .20621 L
.82452 .20616 L
.82948 .20612 L
.83466 .20608 L
.83952 .20606 L
.84473 .20605 L
.84768 .20604 L
.85042 .20603 L
.85543 .20603 L
.85823 .20602 L
.86077 .20602 L
.86559 .20602 L
.8683 .20602 L
.87079 .20602 L
Mistroke
.87538 .20601 L
.87769 .20601 L
.88022 .20601 L
.88286 .20601 L
.88573 .20601 L
.88843 .20601 L
.89094 .20601 L
.89567 .20601 L
.89807 .20601 L
.90071 .20601 L
.90355 .20601 L
.90616 .20601 L
.90902 .20601 L
.91203 .20601 L
.91466 .20601 L
.91711 .20601 L
.9198 .20601 L
.92267 .20601 L
.92538 .20601 L
.92826 .20601 L
.93072 .20601 L
.93342 .20601 L
.93632 .20601 L
.93792 .20601 L
.93944 .20601 L
.94238 .20601 L
.94507 .20601 L
.94762 .20601 L
.95033 .20601 L
.95288 .20601 L
.9552 .20601 L
.95793 .20601 L
.95947 .20601 L
.96088 .20601 L
.96349 .20601 L
.96623 .20601 L
.9685 .20601 L
.97065 .20601 L
.97258 .20601 L
.97467 .20601 L
.97695 .20601 L
.97937 .20601 L
.98143 .20601 L
.98371 .20601 L
.98582 .20601 L
.98776 .20601 L
.98988 .20601 L
.99212 .20601 L
.99407 .20601 L
.99588 .20601 L
Mistroke
.99787 .20601 L
1 .20601 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13039,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo00?ooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooo
oom5ooooo`001Ol00002ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Gooooo00?o
0000ooooooooool0oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo00Co
A4A4omgMgOoooooo00001_ooool3o`000?ooooooAOooool000Oooooo00Go0000oooooooooooooooo
o`00000;ooooo`04omgMgOmEEEGoooooo`0000Kooooo00?o0000ooooooooool0oooooom5ooooo`00
1oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001_ooool00ol0003o
ooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^ko
A4A4o`000006ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Gooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool5o`0000Gooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool00ol0003oooooooooo`3oooooodGooooo0005o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0oooooom5ooooo`001ooo
ool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01Oooool3o`000?oooooo
AOooool000Oooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Cooooo
00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Gooooo00?o0000oooooooo
ool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c005ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo027ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@0Iooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l00000
0ol@413oooooooooo`0Gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l0
00001Ol@413oooooooooooooooooA4A400;o000000?o<S8bomgMgOooool06?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM03Wooooo000Qoooo
o`;o00008_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01oooool00omgMgOo<S8booooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B47ooooo`03o`000?oooooooooo00Kooooo00?oMgMgoc8b<_ooool06?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@06_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1oooool00omgMgOo<S8booooo`0hooooo`008Oooool00ol0003oooooooooo`0Qooooo`05oa0@4?oo
ooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000oooooooo
ool05oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool06Oooool01Ol@
413ooooooooooooooooo410@00kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0G
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Kooooo`05oa0@4?oo
ooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo03Oooooo
000Qooooo`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`00
0?ooooooooooooooool000001oooool00omgMgOo<S8booooo`0Hooooo`05o`000?oooooooooooooo
ool000003_ooool00ol0003oooooooooo`0Iooooo`05o`000?ooooooooooooooool000003_ooool0
0ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo01Sooooo00Go0000ooooooooooooooooo`00
000=ooooo`03oiRHV?lQ8B7ok^k^01[ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool0>?ooool0027ooooo00?o0000ooooooooool08Ooo
ool01Ol0003ooooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000004ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`06Oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000
ooooooooool06Oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<01Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo01Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00iooooo`008Oooool00ol0003oooooooooo`0Qoooo
o`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00Cooooo00?o
0000ooooooooool06oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool0
6Oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Kooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`0Hoooo
o`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo03_ooooo000Qooooo`03o`000?oooooooooo027ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00ol0003oooooooooo`0Kooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`0Iooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01_ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41006_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo03_ooooo
000Qooooo`;o00008_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP04ooooo`Co00006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIV
I_l000006oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l000001Oooool4
o`0001[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
6_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004oooo
o`Co0000>_ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0;Cooooo3?l0001iooooo`03oa0@4?l0
003o000000?o00001Oooool0027ooooo00?o0000ooooooooool0[_ooool6o`0000cooooo1Ol0001f
ooooo`03o`000?oooooooooo00Kooooo000Qooooo`03o`000?oooooooooo0:Kooooo2?l0000Goooo
o`?o0000Loooool00ol0003oooooooooo`06ooooo`008Oooooooo`0003?o00003?ooool00ol0003o
ooooooooo`06ooooo`008Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooool000000_l00005ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
0_ooool;o`0000Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo01Cooooo00?o0000oc8b<_oMgMd01_ooool0027ooooo00?o0000ooooooooool0<?oo
ool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0<?oo
ool00ol0003oooooooooo`02ooooo`Ko00001_ooool8o`0001[ooooo00?o0000ooooooooool0>ooo
ool2o`000004ojVYZOlQ8B7o0000ob4Q8@Cooooo000Qooooo`03o`000?oooooooooo0=Cooooo1_l0
001Zooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooo
oom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003o
ooooodKooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00005ooooo`03o`000?oooooooooo0?oooooo
AOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Q
onk^k_ooooooA4A400Gooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooo
oooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000?ooooooAOooool000Oooooo
00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?o0000oooooooo
ool0oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_oo
ool01?ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@
41003oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001Oooool00ol0
003oooooooooo`3oooooodGooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnH
V9So410@o`000?lQ8B7oc<c<00Gooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool2o`00
0?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1_ooool2o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom5ooooo`00
1oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00_o
oooo1Ol00005ooooo`?o0000oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000_o
oooo00CoA4A4omgMgOoooooo00001_ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05
o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00006ooooo`03o`000?oooooo
oooo0?ooooooAOooool000Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co
000000Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01OmgMgOoV9RHoooooonHV9So
MgMg00cooooo00?ok^k^odA4A?l000001_ooool00ol0003oooooooooo`3oooooodGooooo0007oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`05ooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool2o`000?oo
ooooA_ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000
oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0
003oooooodKooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c005oooo
o`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Gooooo00?o0000ooooooooool0oooooom5
ooooo`001oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00
0005ooooo`?o0000oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo00Go
0000oiRHV?ooooooV9RHob4Q8@05ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go
0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01Oooool00ol0003o
ooooooooo`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGo
QhN7ooooo`07ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Oooooo00?o0000ooooooooool0oooooom5ooooo`00
1oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@1Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
0_l0003oooooodKooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`001ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<
c<`01Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@05ooooo`03o`000?oooooooooo
0?ooooooAOooool000Oooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooo
ooooool000001Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05o`000?oooooooooo
ooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Gooooo0ol0003oooooodGooooo0007
ooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<00Gooooo
00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00_ooooo
00Go410@okZj^_oooooo^[Zjoa0@4005ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000001Oooool00ol0
003oooooooooo`3oooooodGooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnY
ZJWo410@o`000?l@413oZJVY00Gooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool001Sooooo1?l000000ol@413oooooooooo`02ooooo`03o`00
0?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5
ooooo`006_ooool00ol0003oooooooooo`04ooooo`?o0000oooooom5ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o
0000ooooooooool0oooooom<ooooo`006?ooool00omEEEGoIVIVo`00003oooooodkooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo002Rooooo`05oiRHV?l0003o0000odA4A?nj^[X0
6?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000U?ooool001oooooo
00Co410@o`000?l0003o0000Ooooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l00009oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4
A02Dooooo`008?ooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo01[ooooo00Go410@
oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^09Gooooo000Pooooo`03o`000?oooooo
oooo07oooooo00?o0000ooooooooool02oooool6o`0000Wooooo00Go0000ooooooooooooooooo`00
000=ooooo`03oiRHV?lQ8B7ok^k^09Cooooo000Pooooo`06o`000?mgMgOo0000o`000?mEEEGok^k^
O?ooool00ol0003oooooooooo`0Jooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOo
IVIVooooo`2Cooooo`008?ooool01_l0003oEEEEonk^k_ooooooMgMgoeEEEG[ooooo00?o410@o`00
0?l000000ol0000Iooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`2B
ooooo`008?ooool00ol0003ok^k^ooooo`02ooooo`03o`000?oooooooooo07[ooooo00?o0000oooo
ooooool06_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@
402Dooooo`008?ooool00ol0003ok^k^ooooo`02ooooo`03o`000?oooooooooo07[ooooo00?o0000
ooooooooool06_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c02Dooooo`008?ooool01_l0003oEEEEonk^k_ooooooMgMgofIVI_oooooo@oooool001oooooo
00?o410@o`000?mgMgL00_l000000omVIVKok^k^ooooo`3ooooood;ooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.0332543, -0.540631, \
0.00122928, 0.00994506}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 3.33333 0.206011 0.412023 [
[.16667 .19351 -12 -9 ]
[.16667 .19351 12 0 ]
[.33333 .19351 -9 -9 ]
[.33333 .19351 9 0 ]
[.5 .19351 -12 -9 ]
[.5 .19351 12 0 ]
[.66667 .19351 -9 -9 ]
[.66667 .19351 9 0 ]
[.83333 .19351 -12 -9 ]
[.83333 .19351 12 0 ]
[1.025 .20601 0 -6 ]
[1.025 .20601 10 6 ]
[-0.0125 .0412 -24 -4.5 ]
[-0.0125 .0412 0 4.5 ]
[-0.0125 .12361 -24 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .28842 -18 -4.5 ]
[-0.0125 .28842 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .45322 -18 -4.5 ]
[-0.0125 .45322 0 4.5 ]
[-0.0125 .53563 -18 -4.5 ]
[-0.0125 .53563 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 .20601 m
.16667 .21226 L
s
[(0.05)] .16667 .19351 0 1 Mshowa
.33333 .20601 m
.33333 .21226 L
s
[(0.1)] .33333 .19351 0 1 Mshowa
.5 .20601 m
.5 .21226 L
s
[(0.15)] .5 .19351 0 1 Mshowa
.66667 .20601 m
.66667 .21226 L
s
[(0.2)] .66667 .19351 0 1 Mshowa
.83333 .20601 m
.83333 .21226 L
s
[(0.25)] .83333 .19351 0 1 Mshowa
.125 Mabswid
.03333 .20601 m
.03333 .20976 L
s
.06667 .20601 m
.06667 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.13333 .20601 m
.13333 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.23333 .20601 m
.23333 .20976 L
s
.26667 .20601 m
.26667 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.36667 .20601 m
.36667 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.43333 .20601 m
.43333 .20976 L
s
.46667 .20601 m
.46667 .20976 L
s
.53333 .20601 m
.53333 .20976 L
s
.56667 .20601 m
.56667 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.63333 .20601 m
.63333 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.73333 .20601 m
.73333 .20976 L
s
.76667 .20601 m
.76667 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.86667 .20601 m
.86667 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.93333 .20601 m
.93333 .20976 L
s
.96667 .20601 m
.96667 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
gsave
1.025 .20601 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .0412 m
.00625 .0412 L
s
[(-0.4)] -0.0125 .0412 1 0 Mshowa
0 .12361 m
.00625 .12361 L
s
[(-0.2)] -0.0125 .12361 1 0 Mshowa
0 .28842 m
.00625 .28842 L
s
[(0.2)] -0.0125 .28842 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.4)] -0.0125 .37082 1 0 Mshowa
0 .45322 m
.00625 .45322 L
s
[(0.6)] -0.0125 .45322 1 0 Mshowa
0 .53563 m
.00625 .53563 L
s
[(0.8)] -0.0125 .53563 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .10301 m
.00375 .10301 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .30902 m
.00375 .30902 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .39142 m
.00375 .39142 L
s
0 .41202 m
.00375 .41202 L
s
0 .43262 m
.00375 .43262 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .51503 m
.00375 .51503 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
0 .0206 m
.00375 .0206 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.21) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .20601 m
.00123 .20601 L
.00236 .20601 L
.00365 .20601 L
.00488 .20601 L
.00601 .20601 L
.00706 .20601 L
.00821 .20601 L
.00942 .20601 L
.01065 .20601 L
.01196 .20601 L
.0132 .20601 L
.01434 .20601 L
.01566 .20601 L
.01641 .20601 L
.01711 .20601 L
.01839 .20601 L
.01975 .20601 L
.02043 .20601 L
.02115 .20601 L
.02245 .20601 L
.02317 .20601 L
.02384 .20601 L
.02463 .20601 L
.02537 .20601 L
.02671 .20601 L
.02793 .20601 L
.02924 .20601 L
.02998 .20601 L
.03067 .20601 L
.03184 .20601 L
.03295 .20601 L
.03416 .20601 L
.03547 .20601 L
.03676 .20601 L
.03813 .20601 L
.03929 .20601 L
.04057 .20601 L
.04131 .20601 L
.042 .20601 L
.04274 .20601 L
.04355 .20601 L
.04492 .20601 L
.04567 .20601 L
.04637 .20601 L
.0477 .20601 L
.04892 .20601 L
.04959 .20601 L
.05032 .20601 L
.05165 .20601 L
Mistroke
.05245 .20601 L
.05321 .20601 L
.05462 .20601 L
.05542 .20601 L
.05615 .20601 L
.057 .20601 L
.05779 .20601 L
.05911 .20601 L
.05981 .20601 L
.06056 .20601 L
.06135 .20601 L
.06209 .20601 L
.06349 .20601 L
.06471 .20601 L
.06606 .20601 L
.06674 .20601 L
.06747 .20601 L
.0688 .20601 L
.07005 .20601 L
.07136 .20601 L
.07248 .20601 L
.07371 .20601 L
.07446 .20601 L
.07517 .20601 L
.07649 .20601 L
.07723 .20601 L
.07792 .20601 L
.07872 .20601 L
.07946 .20601 L
.0807 .20601 L
.08206 .20601 L
.08339 .20601 L
.08413 .20601 L
.08481 .20601 L
.08604 .20601 L
.0872 .20601 L
.08847 .20601 L
.08985 .20601 L
.09121 .20601 L
.09189 .20601 L
.09264 .20601 L
.09397 .20601 L
.0952 .20601 L
.09645 .20601 L
.09764 .20601 L
.0987 .20601 L
.09985 .20601 L
.10111 .20601 L
.10244 .20601 L
.10357 .20601 L
Mistroke
.10482 .20601 L
.10552 .20601 L
.10628 .20601 L
.10766 .20601 L
.109 .20601 L
.11025 .20601 L
.11101 .20601 L
.11173 .20601 L
.11307 .20601 L
.11382 .20601 L
.11451 .20601 L
.11527 .20601 L
.11608 .20601 L
.11734 .20601 L
.11852 .20601 L
.11992 .20601 L
.1212 .20601 L
.12253 .20601 L
.12398 .20601 L
.12535 .20601 L
.12661 .20601 L
.12785 .20601 L
.12915 .20601 L
.13027 .20601 L
.13148 .20601 L
.1328 .20601 L
.1342 .20601 L
.13553 .20601 L
.13673 .20601 L
.13795 .20601 L
.13908 .20601 L
.14031 .20601 L
.14162 .20601 L
.14275 .20601 L
.14381 .20601 L
.14498 .20601 L
.14623 .20601 L
.14767 .20601 L
.149 .20601 L
.15047 .20601 L
.15129 .20601 L
.15203 .20601 L
.15339 .20601 L
.15487 .20601 L
.15626 .20601 L
.15753 .20601 L
.15878 .20601 L
.15993 .20601 L
.1612 .20601 L
.16256 .20601 L
Mistroke
.16399 .20601 L
.16534 .20601 L
.16655 .20601 L
.16786 .20601 L
.16915 .20601 L
.17033 .20601 L
.17168 .20601 L
.17298 .20601 L
.17416 .20601 L
.17527 .20601 L
.17648 .20601 L
.17777 .20601 L
.17918 .20601 L
.18072 .20601 L
.18216 .20601 L
.18349 .20601 L
.18469 .20601 L
.18602 .20601 L
.18739 .20601 L
.18868 .20601 L
.19005 .20601 L
.19154 .20601 L
.19295 .20601 L
.19425 .20601 L
.19542 .20601 L
.19672 .20601 L
.19807 .20601 L
.19934 .20601 L
.20073 .20601 L
.2022 .20601 L
.20346 .20601 L
.20483 .20601 L
.20632 .20601 L
.2079 .20601 L
.2094 .20601 L
.21076 .20601 L
.21201 .20601 L
.21318 .20601 L
.21447 .20601 L
.21585 .20601 L
.21729 .20601 L
.21866 .20601 L
.21989 .20601 L
.22123 .20601 L
.22251 .20601 L
.22366 .20601 L
.22499 .20601 L
.22625 .20601 L
.22741 .20601 L
.22848 .20601 L
Mistroke
.22966 .20601 L
.23089 .20601 L
.23226 .20601 L
.2335 .20601 L
.23493 .20601 L
.23628 .20601 L
.23753 .20601 L
.23869 .20601 L
.23996 .20601 L
.24131 .20601 L
.24266 .20601 L
.24411 .20601 L
.24548 .20601 L
.24674 .20601 L
.24813 .20601 L
.24966 .20601 L
.25125 .20601 L
.25273 .20601 L
.25407 .20601 L
.25549 .20601 L
.25671 .20601 L
.25804 .20601 L
.25948 .20601 L
.26102 .20601 L
.26247 .20601 L
.2638 .20601 L
.26513 .20601 L
.26636 .20601 L
.26772 .20601 L
.26916 .20601 L
.2704 .20601 L
.27157 .20601 L
.27286 .20601 L
.27424 .20601 L
.27661 .20601 L
.27795 .20601 L
.2792 .20601 L
.28172 .20601 L
.28314 .20601 L
.28442 .20601 L
.28673 .20601 L
.28803 .20601 L
.28923 .20601 L
.29143 .20601 L
.29254 .20601 L
.29377 .20601 L
.29638 .20601 L
.29785 .20601 L
.29923 .20601 L
.30174 .20601 L
Mistroke
.30314 .20601 L
.30441 .20601 L
.30682 .20601 L
.30818 .20601 L
.30943 .20601 L
.31173 .20601 L
.31288 .20601 L
.31415 .20601 L
.31562 .20601 L
.31702 .20601 L
.31963 .20601 L
.32109 .20601 L
.32244 .20601 L
.32392 .20601 L
.32549 .20601 L
.32674 .20601 L
.32809 .20601 L
.33052 .20601 L
.33194 .20601 L
.33342 .20601 L
.33608 .20601 L
.33737 .20601 L
.33878 .20601 L
.34002 .20601 L
.34133 .20601 L
.34251 .20601 L
.34381 .20601 L
.3461 .20601 L
.3475 .20601 L
.34877 .20601 L
.35014 .20601 L
.35164 .20601 L
.35301 .20601 L
.35429 .20601 L
.35681 .20601 L
.35803 .20601 L
.35934 .20601 L
.36172 .20601 L
.36403 .20601 L
.36615 .20601 L
.36846 .20601 L
.37099 .20601 L
.37227 .20601 L
.37364 .20601 L
.3761 .20601 L
.37738 .20601 L
.3788 .20601 L
.38018 .20601 L
.38167 .20601 L
.38432 .20601 L
Mistroke
.38681 .20601 L
.3883 .20601 L
.38993 .20601 L
.39136 .20601 L
.39289 .20601 L
.3944 .20601 L
.39577 .20601 L
.39845 .20601 L
.40117 .20601 L
.40368 .20601 L
.40643 .20601 L
.40933 .20601 L
.41186 .20601 L
.41422 .20601 L
.41681 .20601 L
.41959 .20601 L
.42228 .20601 L
.42513 .20601 L
.42757 .20601 L
.43026 .20601 L
.43314 .20601 L
.43625 .20601 L
.43918 .20601 L
.44187 .20601 L
.44442 .20601 L
.44678 .20601 L
.44938 .20601 L
.45216 .20601 L
.45508 .20601 L
.45783 .20601 L
.46031 .20601 L
.46299 .20601 L
.46547 .20601 L
.46812 .20601 L
.47292 .20601 L
.47585 .20601 L
.47863 .20601 L
.48112 .20601 L
.48384 .20601 L
.48676 .20601 L
.48939 .20601 L
.49244 .20601 L
.4953 .206 L
.50041 .206 L
.50329 .206 L
.50593 .20599 L
.51088 .20599 L
.51365 .20598 L
.51617 .20597 L
.52108 .20596 L
Mistroke
.52572 .20594 L
.53112 .2059 L
.53612 .20586 L
.5416 .2058 L
.54742 .20571 L
.55257 .2056 L
.55728 .20547 L
.56245 .2053 L
.56789 .20507 L
.57706 .20455 L
.58709 .20376 L
.59789 .20264 L
.6077 .20141 L
.61916 .19983 L
.62971 .19845 L
.63477 .19788 L
.63951 .19746 L
.64209 .19727 L
.64445 .19714 L
.6457 .19709 L
.64706 .19704 L
.64781 .19702 L
.64851 .197 L
.64987 .19698 L
.65125 .19698 L
.65203 .19698 L
.65274 .19699 L
.65405 .19701 L
.65543 .19705 L
.65667 .1971 L
.65783 .19716 L
.66046 .19734 L
.66331 .19759 L
.6659 .19789 L
.67172 .19877 L
.68217 .201 L
.69182 .20361 L
.70309 .20691 L
.71364 .20979 L
.72311 .21185 L
.72843 .21271 L
.7333 .2133 L
.73605 .21354 L
.73861 .21371 L
.74008 .21378 L
.74141 .21383 L
.74215 .21386 L
.74295 .21388 L
.7437 .21389 L
.7444 .2139 L
Mistroke
.74567 .2139 L
.74685 .2139 L
.74814 .21388 L
.74887 .21387 L
.74953 .21385 L
.75087 .21381 L
.75232 .21375 L
.75495 .21361 L
.76004 .21324 L
.76482 .2128 L
.77571 .21155 L
.78646 .21022 L
.79777 .20895 L
.80789 .20802 L
.81324 .20761 L
.81896 .20725 L
.82423 .20698 L
.82902 .20677 L
.83839 .20647 L
.84348 .20635 L
.84887 .20626 L
.85347 .2062 L
.85853 .20614 L
.86397 .2061 L
.86696 .20609 L
.86981 .20607 L
.87245 .20606 L
.87532 .20605 L
.88036 .20604 L
.88305 .20603 L
.88596 .20603 L
.88852 .20603 L
.89122 .20602 L
.89367 .20602 L
.89635 .20602 L
.90106 .20602 L
.90394 .20602 L
.90656 .20601 L
.90939 .20601 L
.91246 .20601 L
.9153 .20601 L
.91792 .20601 L
.92062 .20601 L
.92309 .20601 L
.92542 .20601 L
.92797 .20601 L
.93053 .20601 L
.93322 .20601 L
.93561 .20601 L
.93815 .20601 L
Mistroke
.94053 .20601 L
.94272 .20601 L
.94553 .20601 L
.94856 .20601 L
.95124 .20601 L
.95407 .20601 L
.95661 .20601 L
.95898 .20601 L
.96158 .20601 L
.96437 .20601 L
.96657 .20601 L
.96892 .20601 L
.97092 .20601 L
.97313 .20601 L
.97549 .20601 L
.97804 .20601 L
.98045 .20601 L
.98266 .20601 L
.98475 .20601 L
.98669 .20601 L
.98882 .20601 L
.9911 .20601 L
.9935 .20601 L
.99576 .20601 L
.99779 .20601 L
1 .20601 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13039,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo00?ooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooo
oom5ooooo`001Ol00002ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Gooooo00?o
0000ooooooooool0oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo00Co
A4A4omgMgOoooooo00001_ooool3o`000?ooooooAOooool000Oooooo00Go0000oooooooooooooooo
o`00000;ooooo`04omgMgOmEEEGoooooo`0000Kooooo00?o0000ooooooooool0oooooom5ooooo`00
1oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001_ooool00ol0003o
ooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^ko
A4A4o`000006ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Gooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool5o`0000Gooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool00ol0003oooooooooo`3oooooodGooooo0005o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0oooooom5ooooo`001ooo
ool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01Oooool3o`000?oooooo
AOooool000Oooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Cooooo
00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Gooooo00?o0000oooooooo
ool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c005ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo027ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@0Iooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l00000
0ol@413oooooooooo`0Gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l0
00001Ol@413oooooooooooooooooA4A400;o000000?o<S8bomgMgOooool06?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM03Wooooo000Qoooo
o`;o00008_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01oooool00omgMgOo<S8booooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B47ooooo`03o`000?oooooooooo00Kooooo00?oMgMgoc8b<_ooool06?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@06_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1oooool00omgMgOo<S8booooo`0hooooo`008Oooool00ol0003oooooooooo`0Qooooo`05oa0@4?oo
ooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000oooooooo
ool05oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool06Oooool01Ol@
413ooooooooooooooooo410@00kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0G
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Kooooo`05oa0@4?oo
ooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo03Oooooo
000Qooooo`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`00
0?ooooooooooooooool000001oooool00omgMgOo<S8booooo`0Hooooo`05o`000?oooooooooooooo
ool000003_ooool00ol0003oooooooooo`0Iooooo`05o`000?ooooooooooooooool000003_ooool0
0ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo01Sooooo00Go0000ooooooooooooooooo`00
000=ooooo`03oiRHV?lQ8B7ok^k^01[ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool0>?ooool0027ooooo00?o0000ooooooooool08Ooo
ool01Ol0003ooooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000004ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`06Oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000
ooooooooool06Oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<01Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo01Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00iooooo`008Oooool00ol0003oooooooooo`0Qoooo
o`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00Cooooo00?o
0000ooooooooool06oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool0
6Oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Kooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`0Hoooo
o`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo03_ooooo000Qooooo`03o`000?oooooooooo027ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00ol0003oooooooooo`0Kooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`0Iooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01_ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41006_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo03_ooooo
000Qooooo`;o00008_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP04ooooo`Co00006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIV
I_l000006oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l000001Oooool4
o`0001[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
6_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004oooo
o`Co0000>_ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0<3ooooo2?l0001aooooo`03oa0@4?l0
003o000000?o00001Oooool0027ooooo00?o0000ooooooooool0^Oooool7o`0000Sooooo1Ol0001^
ooooo`03o`000?oooooooooo00Kooooo000Qooooo`03o`000?oooooooooo0:oooooo2_l0000Doooo
o`Ko0000J?ooool00ol0003oooooooooo`06ooooo`008Oooooooo`0003?o00003?ooool00ol0003o
ooooooooo`06ooooo`008Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool01?l0003oooooooooooooool3o`0000?ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`02ooooo`[o00001_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo01Cooooo00?o0000oc8b<_oMgMd01_ooool0027ooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`0>oooooa;o00004?ooool00ol0003oooooooooo`0kooooo`;o0000
00CoZJVYob4Q8Ol0003o8B4Q1?ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo0_l0003oooooodKooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Cooooo1Ol00005ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A4
00Gooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@
00cooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000?ooooooAOooool000Oooooo00Go0000oooooooo
ooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?o0000ooooooooool0oooooom5oooo
o`001oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01?ooool00ol0
003oooooooooo`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001Oooool00ol0003oooooooooo`3o
ooooodGooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<00Gooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`00
0003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00005oooo
o`?o0000oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgM
gOoooooo00001_ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05o`000?oooooooooo
ooooool000002oooool01?oMgMgoEEEEooooool00006ooooo`03o`000?oooooooooo0?ooooooAOoo
ool000Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Kooooo00?o
0000ooooooooool0oooooom5ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o
k^k^odA4A?l000001_ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`05ooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c005ooooo`03o`000?oooooo
oooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q00Gooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000005ooooo`?o0000
oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@05ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go0000oooooooooooo
ooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01Oooool00ol0003oooooooooo`3ooooo
odGooooo0007ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`07oooo
o`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;oooo
o`03omgMgOl@413oV9RH00Oooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@1Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool2o`000?oooooo
A_ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooo
oom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01Oooool00ol0
003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@05ooooo`03o`000?oooooooooo0?ooooooAOooool0
00Oooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001Ooo
ool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05o`000?ooooooooooooooool000002ooo
ool01Olb<S;oV9RHoooooonHV9So<S8b00Gooooo0ol0003oooooodGooooo0007ooooo`05o`000?oo
ooooooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<00Gooooo00?o0000oooooooo
ool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oo
oooo^[Zjoa0@4005ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000001Oooool00ol0003oooooooooo`3o
ooooodGooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@
413oZJVY00Gooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool001Sooooo1?l000000ol@413oooooooooo`02ooooo`03o`000?oooooooooo0?oo
ooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo
000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool0
0ol0003oooooooooo`04ooooo`?o0000oooooom5ooooo`006_ooool00ol0003oooooooooo`3ooooo
odcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0
oooooom<ooooo`006?ooool00omEEEGoIVIVo`00003oooooodkooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo002Nooooo`05oiRHV?l0003o0000odA4A?nj^[X06?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool4o`000003oa0@4?oooooooooo
08gooooo000Oooooo`04oa0@4?l0003o0000o`0007_ooooo00Go410@okZj^_o^k^koMgMgoa0@4009
ooooo`Ko00002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`2?ooooo`008?ooool00ol0003ooooooooo
o`1kooooo`03o`000?oooooooooo01[ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0Soooool0023ooooo00?o0000ooooooooool0Nooo
ool00ol0003oooooooooo`0;ooooo`Ko00002Oooool01Ol0003ooooooooooooooooo000000gooooo
00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`2?ooooo`008?ooool01_l0003oMgMgo`00
0?l0003oEEEEonk^kWSooooo00?o0000ooooooooool06_ooool01Ol0003ooooooooooooooooo0000
00kooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`2?ooooo`008?ooool01_l0003o
EEEEonk^k_ooooooMgMgoeEEEGKooooo00?o410@o`000?l000000ol0000Iooooo`05oa0@4?oooooo
ooooooooool@41003oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo08oooooo000P
ooooo`03o`000?o^k^kooooo00;ooooo00?o0000ooooooooool0M_ooool00ol0003oooooooooo`0J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo
00?o0000ooooooooool0Soooool0023ooooo00?o0000onk^k_ooool00_ooool00ol0003ooooooooo
o`1fooooo`03o`000?oooooooooo01[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRH
V?l@413o0000ob4Q8Oo<c<`01?ooool00omEEEGoIVIVo`00002Aooooo`008?ooool01_l0003oEEEE
onk^k_ooooooMgMgofIVI_oooooo@oooool001oooooo00?o410@o`000?mgMgL00_l000000omVIVKo
k^k^ooooo`3ooooood;ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.0332543, -0.540631, \
0.00122928, 0.00994506}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 3.33333 0.206011 0.412023 [
[.16667 .19351 -12 -9 ]
[.16667 .19351 12 0 ]
[.33333 .19351 -9 -9 ]
[.33333 .19351 9 0 ]
[.5 .19351 -12 -9 ]
[.5 .19351 12 0 ]
[.66667 .19351 -9 -9 ]
[.66667 .19351 9 0 ]
[.83333 .19351 -12 -9 ]
[.83333 .19351 12 0 ]
[1.025 .20601 0 -6 ]
[1.025 .20601 10 6 ]
[-0.0125 .0412 -24 -4.5 ]
[-0.0125 .0412 0 4.5 ]
[-0.0125 .12361 -24 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .28842 -18 -4.5 ]
[-0.0125 .28842 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .45322 -18 -4.5 ]
[-0.0125 .45322 0 4.5 ]
[-0.0125 .53563 -18 -4.5 ]
[-0.0125 .53563 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 .20601 m
.16667 .21226 L
s
[(0.05)] .16667 .19351 0 1 Mshowa
.33333 .20601 m
.33333 .21226 L
s
[(0.1)] .33333 .19351 0 1 Mshowa
.5 .20601 m
.5 .21226 L
s
[(0.15)] .5 .19351 0 1 Mshowa
.66667 .20601 m
.66667 .21226 L
s
[(0.2)] .66667 .19351 0 1 Mshowa
.83333 .20601 m
.83333 .21226 L
s
[(0.25)] .83333 .19351 0 1 Mshowa
.125 Mabswid
.03333 .20601 m
.03333 .20976 L
s
.06667 .20601 m
.06667 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.13333 .20601 m
.13333 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.23333 .20601 m
.23333 .20976 L
s
.26667 .20601 m
.26667 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.36667 .20601 m
.36667 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.43333 .20601 m
.43333 .20976 L
s
.46667 .20601 m
.46667 .20976 L
s
.53333 .20601 m
.53333 .20976 L
s
.56667 .20601 m
.56667 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.63333 .20601 m
.63333 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.73333 .20601 m
.73333 .20976 L
s
.76667 .20601 m
.76667 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.86667 .20601 m
.86667 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.93333 .20601 m
.93333 .20976 L
s
.96667 .20601 m
.96667 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
gsave
1.025 .20601 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .0412 m
.00625 .0412 L
s
[(-0.4)] -0.0125 .0412 1 0 Mshowa
0 .12361 m
.00625 .12361 L
s
[(-0.2)] -0.0125 .12361 1 0 Mshowa
0 .28842 m
.00625 .28842 L
s
[(0.2)] -0.0125 .28842 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.4)] -0.0125 .37082 1 0 Mshowa
0 .45322 m
.00625 .45322 L
s
[(0.6)] -0.0125 .45322 1 0 Mshowa
0 .53563 m
.00625 .53563 L
s
[(0.8)] -0.0125 .53563 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .10301 m
.00375 .10301 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .30902 m
.00375 .30902 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .39142 m
.00375 .39142 L
s
0 .41202 m
.00375 .41202 L
s
0 .43262 m
.00375 .43262 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .51503 m
.00375 .51503 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
0 .0206 m
.00375 .0206 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.22) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .20601 m
.00123 .20601 L
.00236 .20601 L
.00365 .20601 L
.00488 .20601 L
.00601 .20601 L
.00706 .20601 L
.00821 .20601 L
.00942 .20601 L
.01065 .20601 L
.01196 .20601 L
.0132 .20601 L
.01434 .20601 L
.01566 .20601 L
.01641 .20601 L
.01711 .20601 L
.01839 .20601 L
.01975 .20601 L
.02043 .20601 L
.02115 .20601 L
.02245 .20601 L
.02317 .20601 L
.02384 .20601 L
.02463 .20601 L
.02537 .20601 L
.02671 .20601 L
.02793 .20601 L
.02924 .20601 L
.02998 .20601 L
.03067 .20601 L
.03184 .20601 L
.03295 .20601 L
.03416 .20601 L
.03547 .20601 L
.03676 .20601 L
.03813 .20601 L
.03929 .20601 L
.04057 .20601 L
.04131 .20601 L
.042 .20601 L
.04274 .20601 L
.04355 .20601 L
.04492 .20601 L
.04567 .20601 L
.04637 .20601 L
.0477 .20601 L
.04892 .20601 L
.04959 .20601 L
.05032 .20601 L
.05165 .20601 L
Mistroke
.05245 .20601 L
.05321 .20601 L
.05462 .20601 L
.05542 .20601 L
.05615 .20601 L
.057 .20601 L
.05779 .20601 L
.05911 .20601 L
.05981 .20601 L
.06056 .20601 L
.06135 .20601 L
.06209 .20601 L
.06281 .20601 L
.06349 .20601 L
.06471 .20601 L
.06606 .20601 L
.06738 .20601 L
.06812 .20601 L
.0688 .20601 L
.06994 .20601 L
.07119 .20601 L
.07249 .20601 L
.07371 .20601 L
.0744 .20601 L
.07516 .20601 L
.07652 .20601 L
.07785 .20601 L
.07908 .20601 L
.08041 .20601 L
.08116 .20601 L
.08186 .20601 L
.08328 .20601 L
.08408 .20601 L
.08481 .20601 L
.08604 .20601 L
.0872 .20601 L
.08847 .20601 L
.08985 .20601 L
.09121 .20601 L
.09189 .20601 L
.09264 .20601 L
.09397 .20601 L
.0952 .20601 L
.09645 .20601 L
.09764 .20601 L
.0987 .20601 L
.09985 .20601 L
.10111 .20601 L
.10244 .20601 L
.10357 .20601 L
Mistroke
.10482 .20601 L
.10552 .20601 L
.10628 .20601 L
.10766 .20601 L
.109 .20601 L
.11025 .20601 L
.11101 .20601 L
.11173 .20601 L
.11307 .20601 L
.11382 .20601 L
.11451 .20601 L
.11527 .20601 L
.11608 .20601 L
.11734 .20601 L
.11852 .20601 L
.11924 .20601 L
.11992 .20601 L
.1212 .20601 L
.12255 .20601 L
.12379 .20601 L
.12516 .20601 L
.12585 .20601 L
.12661 .20601 L
.12789 .20601 L
.12908 .20601 L
.13039 .20601 L
.13112 .20601 L
.13178 .20601 L
.13312 .20601 L
.13388 .20601 L
.13458 .20601 L
.13586 .20601 L
.13722 .20601 L
.13837 .20601 L
.13961 .20601 L
.14078 .20601 L
.14185 .20601 L
.1431 .20601 L
.14446 .20601 L
.14575 .20601 L
.14694 .20601 L
.14832 .20601 L
.1491 .20601 L
.14981 .20601 L
.15113 .20601 L
.15251 .20601 L
.15376 .20601 L
.15492 .20601 L
.15619 .20601 L
.15755 .20601 L
Mistroke
.15831 .20601 L
.15901 .20601 L
.15976 .20601 L
.16059 .20601 L
.16199 .20601 L
.16275 .20601 L
.16347 .20601 L
.16482 .20601 L
.16606 .20601 L
.16749 .20601 L
.16885 .20601 L
.17015 .20601 L
.17156 .20601 L
.1729 .20601 L
.17412 .20601 L
.17523 .20601 L
.17645 .20601 L
.17772 .20601 L
.17891 .20601 L
.1803 .20601 L
.18161 .20601 L
.1828 .20601 L
.18408 .20601 L
.18548 .20601 L
.18696 .20601 L
.18823 .20601 L
.18963 .20601 L
.19085 .20601 L
.19213 .20601 L
.19323 .20601 L
.19442 .20601 L
.19572 .20601 L
.1971 .20601 L
.1984 .20601 L
.19959 .20601 L
.20079 .20601 L
.20189 .20601 L
.20311 .20601 L
.2044 .20601 L
.20551 .20601 L
.20656 .20601 L
.2077 .20601 L
.20894 .20601 L
.21034 .20601 L
.21161 .20601 L
.21307 .20601 L
.21445 .20601 L
.21573 .20601 L
.21691 .20601 L
.2182 .20601 L
Mistroke
.21957 .20601 L
.22095 .20601 L
.22243 .20601 L
.22382 .20601 L
.2251 .20601 L
.22659 .20601 L
.22821 .20601 L
.22974 .20601 L
.23116 .20601 L
.23237 .20601 L
.23367 .20601 L
.2349 .20601 L
.23603 .20601 L
.23728 .20601 L
.23865 .20601 L
.24007 .20601 L
.2414 .20601 L
.24282 .20601 L
.24415 .20601 L
.24535 .20601 L
.24665 .20601 L
.24807 .20601 L
.24957 .20601 L
.25086 .20601 L
.25226 .20601 L
.25363 .20601 L
.25489 .20601 L
.25628 .20601 L
.25775 .20601 L
.25903 .20601 L
.26022 .20601 L
.26154 .20601 L
.26296 .20601 L
.26414 .20601 L
.26543 .20601 L
.26678 .20601 L
.26804 .20601 L
.26923 .20601 L
.2703 .20601 L
.27154 .20601 L
.27271 .20601 L
.27398 .20601 L
.27537 .20601 L
.27683 .20601 L
.27819 .20601 L
.27946 .20601 L
.28062 .20601 L
.28196 .20601 L
.28324 .20601 L
.28461 .20601 L
Mistroke
.28607 .20601 L
.28745 .20601 L
.2887 .20601 L
.29018 .20601 L
.29177 .20601 L
.29328 .20601 L
.29466 .20601 L
.29599 .20601 L
.29724 .20601 L
.2996 .20601 L
.30091 .20601 L
.30213 .20601 L
.30347 .20601 L
.30489 .20601 L
.30602 .20601 L
.30723 .20601 L
.30943 .20601 L
.3107 .20601 L
.31204 .20601 L
.31443 .20601 L
.31579 .20601 L
.31703 .20601 L
.31846 .20601 L
.3198 .20601 L
.3222 .20601 L
.32355 .20601 L
.3248 .20601 L
.32606 .20601 L
.32742 .20601 L
.32891 .20601 L
.3303 .20601 L
.33187 .20601 L
.33335 .20601 L
.33468 .20601 L
.33613 .20601 L
.33754 .20601 L
.33882 .20601 L
.34024 .20601 L
.34173 .20601 L
.34424 .20601 L
.34567 .20601 L
.347 .20601 L
.34828 .20601 L
.34949 .20601 L
.35175 .20601 L
.35302 .20601 L
.35419 .20601 L
.35546 .20601 L
.35684 .20601 L
.35821 .20601 L
Mistroke
.35946 .20601 L
.36192 .20601 L
.3633 .20601 L
.3648 .20601 L
.36753 .20601 L
.36902 .20601 L
.37037 .20601 L
.37183 .20601 L
.37341 .20601 L
.37487 .20601 L
.37622 .20601 L
.37758 .20601 L
.37887 .20601 L
.38011 .20601 L
.38145 .20601 L
.3838 .20601 L
.38513 .20601 L
.38654 .20601 L
.38776 .20601 L
.38908 .20601 L
.39142 .20601 L
.39361 .20601 L
.39489 .20601 L
.39622 .20601 L
.39862 .20601 L
.39998 .20601 L
.40121 .20601 L
.40254 .20601 L
.40398 .20601 L
.40655 .20601 L
.40897 .20601 L
.41034 .20601 L
.41184 .20601 L
.4133 .20601 L
.41487 .20601 L
.41634 .20601 L
.41768 .20601 L
.42031 .20601 L
.42294 .20601 L
.42532 .20601 L
.42807 .20601 L
.43066 .20601 L
.43307 .20601 L
.43528 .20601 L
.4377 .20601 L
.44026 .20601 L
.44286 .20601 L
.44563 .20601 L
.44826 .20601 L
.45065 .20601 L
Mistroke
.45345 .20601 L
.45649 .20601 L
.45937 .20601 L
.46203 .20601 L
.46457 .20601 L
.4669 .20601 L
.46946 .20601 L
.47215 .20601 L
.47451 .20601 L
.47669 .20601 L
.47909 .20601 L
.48165 .20601 L
.48445 .20601 L
.48749 .20601 L
.49035 .20601 L
.49299 .20601 L
.49538 .20601 L
.498 .20601 L
.50073 .20601 L
.50329 .20601 L
.50601 .20601 L
.50853 .20601 L
.51129 .20601 L
.51423 .20601 L
.51704 .20601 L
.51968 .20601 L
.52208 .20601 L
.52461 .20601 L
.52694 .20601 L
.5295 .206 L
.53398 .206 L
.5365 .206 L
.53921 .206 L
.54408 .20599 L
.54679 .20598 L
.54966 .20598 L
.55481 .20596 L
.55767 .20595 L
.56035 .20594 L
.56645 .2059 L
.57177 .20585 L
.57664 .20579 L
.58226 .2057 L
.5876 .20558 L
.59288 .20543 L
.59766 .20527 L
.60281 .20505 L
.60839 .20475 L
.61833 .20406 L
.6277 .2032 L
Mistroke
.64822 .20071 L
.65909 .1993 L
.66507 .1986 L
.67074 .19805 L
.67335 .19784 L
.67611 .19767 L
.67756 .19759 L
.67915 .19752 L
.6806 .19747 L
.68196 .19744 L
.68321 .19742 L
.68452 .19742 L
.68565 .19742 L
.68688 .19744 L
.68821 .19747 L
.68895 .19749 L
.68963 .19752 L
.69218 .19764 L
.69343 .19773 L
.69475 .19783 L
.69712 .19804 L
.70248 .19871 L
.70711 .19947 L
.7122 .20048 L
.73433 .20629 L
.74482 .2091 L
.75455 .21125 L
.7594 .21208 L
.76456 .21277 L
.7675 .21306 L
.77028 .21328 L
.77277 .21342 L
.77417 .21348 L
.77546 .21352 L
.77661 .21354 L
.77785 .21356 L
.77901 .21357 L
.78007 .21356 L
.78131 .21355 L
.78266 .21352 L
.78394 .21349 L
.78512 .21344 L
.78747 .21334 L
.79007 .21318 L
.79531 .21278 L
.81737 .21033 L
.82703 .20925 L
.83758 .20824 L
.84785 .20747 L
.8574 .20695 L
Mistroke
.86269 .20673 L
.86749 .20657 L
.87272 .20643 L
.87825 .20631 L
.88325 .20623 L
.88875 .20617 L
.89375 .20612 L
.89843 .20609 L
.90394 .20607 L
.90897 .20605 L
.91175 .20604 L
.91477 .20604 L
.91742 .20603 L
.92028 .20603 L
.92293 .20602 L
.92536 .20602 L
.93013 .20602 L
.93266 .20602 L
.93543 .20602 L
.93835 .20601 L
.94101 .20601 L
.94366 .20601 L
.94653 .20601 L
.94956 .20601 L
.95243 .20601 L
.95511 .20601 L
.95796 .20601 L
.96039 .20601 L
.96306 .20601 L
.96534 .20601 L
.96783 .20601 L
.97002 .20601 L
.97236 .20601 L
.97467 .20601 L
.97677 .20601 L
.98086 .20601 L
.98333 .20601 L
.9856 .20601 L
.98809 .20601 L
.99072 .20601 L
.99301 .20601 L
.99514 .20601 L
.99749 .20601 L
1 .20601 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13039,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo00?ooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooo
oom5ooooo`001Ol00002ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Gooooo00?o
0000ooooooooool0oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo00Co
A4A4omgMgOoooooo00001_ooool3o`000?ooooooAOooool000Oooooo00Go0000oooooooooooooooo
o`00000;ooooo`04omgMgOmEEEGoooooo`0000Kooooo00?o0000ooooooooool0oooooom5ooooo`00
1oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001_ooool00ol0003o
ooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^ko
A4A4o`000006ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Gooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool5o`0000Gooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool00ol0003oooooooooo`3oooooodGooooo0005o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0oooooom5ooooo`001ooo
ool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01Oooool3o`000?oooooo
AOooool000Oooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Cooooo
00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Gooooo00?o0000oooooooo
ool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c005ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo027ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@0Iooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l00000
0ol@413oooooooooo`0Gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l0
00001Ol@413oooooooooooooooooA4A400;o000000?o<S8bomgMgOooool06?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM03Wooooo000Qoooo
o`;o00008_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01oooool00omgMgOo<S8booooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B47ooooo`03o`000?oooooooooo00Kooooo00?oMgMgoc8b<_ooool06?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@06_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1oooool00omgMgOo<S8booooo`0hooooo`008Oooool00ol0003oooooooooo`0Qooooo`05oa0@4?oo
ooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000oooooooo
ool05oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool06Oooool01Ol@
413ooooooooooooooooo410@00kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0G
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Kooooo`05oa0@4?oo
ooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo03Oooooo
000Qooooo`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`00
0?ooooooooooooooool000001oooool00omgMgOo<S8booooo`0Hooooo`05o`000?oooooooooooooo
ool000003_ooool00ol0003oooooooooo`0Iooooo`05o`000?ooooooooooooooool000003_ooool0
0ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo01Sooooo00Go0000ooooooooooooooooo`00
000=ooooo`03oiRHV?lQ8B7ok^k^01[ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool0>?ooool0027ooooo00?o0000ooooooooool08Ooo
ool01Ol0003ooooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000004ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`06Oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000
ooooooooool06Oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<01Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo01Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00iooooo`008Oooool00ol0003oooooooooo`0Qoooo
o`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00Cooooo00?o
0000ooooooooool06oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool0
6Oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Kooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`0Hoooo
o`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo03_ooooo000Qooooo`03o`000?oooooooooo027ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00ol0003oooooooooo`0Kooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`0Iooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01_ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41006_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo03_ooooo
000Qooooo`;o00008_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP04ooooo`Co00006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIV
I_l000006oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l000001Oooool4
o`0001[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
6_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004oooo
o`Co0000>_ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0<cooooo1Ol0001Xooooo`03oa0@4?l0
003o000000?o00001Oooool0027ooooo00?o0000ooooooooool0`?ooool=o`0000?ooooo2_l0001Q
ooooo`03o`000?oooooooooo00Kooooo000Qooooo`03o`000?oooooooooo0;Wooooo1ol0000Joooo
o`?o0000G_ooool00ol0003oooooooooo`06ooooo`008Oooooooo`0003?o00003?ooool00ol0003o
ooooooooo`06ooooo`008Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?o0000
1?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00ko00001?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0Dooooo`03o`000?lb<S;ogMgM00Kooooo000Qooooo`03o`000?oooooooooo033ooooo00?o
0000ooooooooool0<?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo033ooooo00?o
0000ooooooooool05ooooolAo`0000Sooooo00?o0000ooooooooool0>oooool2o`000004ojVYZOlQ
8B7o0000ob4Q8@Cooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o
0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`Go00001Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`03
o`000?oooooooooo0?ooooooAOooool000Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03
oiRHV?lQ8B7ok^k^00Kooooo0ol0003oooooodGooooo0007ooooo`05o`000?ooooooooooooooool0
00003Oooool00onHV9So8B4Qonk^kP05ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo
00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Cooooo00?o0000oooooooo
ool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Gooooo00?o0000ooooooooool0oooooom5oooo
o`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c005
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo0_l0003oooooodKooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413o
ooooooooo`03ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oo
ooooAOooool000Oooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00001Oooool3o`000?oo
ooooAOooool000Oooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`00
00Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo0000
00_ooooo00CogMgMoeEEEOoooooo00001_ooool00ol0003oooooooooo`3oooooodGooooo0007oooo
o`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000006ooooo`03o`000?oooooo
oooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co
000000Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00gooooo00?oMgMgo`000?ooool01Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01Oooool00ol0003oooooooooo`3ooooo
odGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMg
MoooooooV9RHob4Q8@05ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go410@oooo
oooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001Oooool3o`000?ooooooAOoo
ool000Oooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40
1Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05o`000?ooooooooooooooool00000
2oooool01Ol0003oEEEEo`000?l@413oc<c<00Gooooo00?o0000ooooooooool0oooooom5ooooo`00
1oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool01oooool00ol0003o
ooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo
410@oiRHV007ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Gooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Gooooo00?o0000oooooooo
ool0oooooom5ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B401Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000
ooooooooool0oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8b
oiRHV?ooooooV9RHoc8b<P05ooooo`?o0000oooooom5ooooo`001oooool01Ol0003ooooooooooooo
oooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c005ooooo`03o`000?oooooooooo0?oooooo
AOooool000Oooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@
41001Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Gooooo00?o0000ooooooooool0oooooom5oooo
o`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@05
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo0_l0003oooooodKooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodGooooo
000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000oooo
ooooool01?ooool3o`000?ooooooAOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001Sooooo00?oEEEEofIVI_l00000oooooom>ooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00W_ooool01OnHV9So0000o`000?m4A4Co^[Zj01Sooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000?ooooo1Ol0002@ooooo`007oooool01?l@413o0000
o`000?l0001kooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000Wooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00Go
V9RHob4Q8Oo^k^koooooodA4A02@ooooo`008?ooool00ol0003oooooooooo`1kooooo`03o`000?oo
oooooooo01[ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Gooooo
00?oV9RHob4Q8Oo^k^h0TOooool0023ooooo00?o0000ooooooooool0Noooool00ol0003ooooooooo
o`0;ooooo`Ko00002Oooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1Oooool00onHV9So8B4Qonk^kP2@ooooo`008?ooool01_l0003oMgMgo`000?l0003oEEEEonk^kWSo
oooo00?o0000ooooooooool06_ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIV
I_ooool01Oooool00omgMgOoIVIVooooo`2?ooooo`008?ooool01_l0003oEEEEonk^k_ooooooMgMg
oeEEEGKooooo00?o410@o`000?l000000ol0000Iooooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo08kooooo000Pooooo`03o`000?o^k^ko
oooo00;ooooo00?o0000ooooooooool0M_ooool00ol0003oooooooooo`0Jooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00Go0000okZj^_oooooo
V9RHoa0@402@ooooo`008?ooool00ol0003ok^k^ooooo`02ooooo`03o`000?oooooooooo07Kooooo
00?o0000ooooooooool06_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c003ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0T?ooool0023ooooo00Ko0000oeEE
EOo^k^koooooogMgMomVIVKooooood?ooooo000Oooooo`03oa0@4?l0003oMgMg00;o000000?oIVIV
onk^k_ooool0oooooom2ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.0332543, -0.540631, \
0.00122928, 0.00994506}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 3.33333 0.206011 0.412023 [
[.16667 .19351 -12 -9 ]
[.16667 .19351 12 0 ]
[.33333 .19351 -9 -9 ]
[.33333 .19351 9 0 ]
[.5 .19351 -12 -9 ]
[.5 .19351 12 0 ]
[.66667 .19351 -9 -9 ]
[.66667 .19351 9 0 ]
[.83333 .19351 -12 -9 ]
[.83333 .19351 12 0 ]
[1.025 .20601 0 -6 ]
[1.025 .20601 10 6 ]
[-0.0125 .0412 -24 -4.5 ]
[-0.0125 .0412 0 4.5 ]
[-0.0125 .12361 -24 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .28842 -18 -4.5 ]
[-0.0125 .28842 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .45322 -18 -4.5 ]
[-0.0125 .45322 0 4.5 ]
[-0.0125 .53563 -18 -4.5 ]
[-0.0125 .53563 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 .20601 m
.16667 .21226 L
s
[(0.05)] .16667 .19351 0 1 Mshowa
.33333 .20601 m
.33333 .21226 L
s
[(0.1)] .33333 .19351 0 1 Mshowa
.5 .20601 m
.5 .21226 L
s
[(0.15)] .5 .19351 0 1 Mshowa
.66667 .20601 m
.66667 .21226 L
s
[(0.2)] .66667 .19351 0 1 Mshowa
.83333 .20601 m
.83333 .21226 L
s
[(0.25)] .83333 .19351 0 1 Mshowa
.125 Mabswid
.03333 .20601 m
.03333 .20976 L
s
.06667 .20601 m
.06667 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.13333 .20601 m
.13333 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.23333 .20601 m
.23333 .20976 L
s
.26667 .20601 m
.26667 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.36667 .20601 m
.36667 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.43333 .20601 m
.43333 .20976 L
s
.46667 .20601 m
.46667 .20976 L
s
.53333 .20601 m
.53333 .20976 L
s
.56667 .20601 m
.56667 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.63333 .20601 m
.63333 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.73333 .20601 m
.73333 .20976 L
s
.76667 .20601 m
.76667 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.86667 .20601 m
.86667 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.93333 .20601 m
.93333 .20976 L
s
.96667 .20601 m
.96667 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
gsave
1.025 .20601 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .0412 m
.00625 .0412 L
s
[(-0.4)] -0.0125 .0412 1 0 Mshowa
0 .12361 m
.00625 .12361 L
s
[(-0.2)] -0.0125 .12361 1 0 Mshowa
0 .28842 m
.00625 .28842 L
s
[(0.2)] -0.0125 .28842 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.4)] -0.0125 .37082 1 0 Mshowa
0 .45322 m
.00625 .45322 L
s
[(0.6)] -0.0125 .45322 1 0 Mshowa
0 .53563 m
.00625 .53563 L
s
[(0.8)] -0.0125 .53563 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .10301 m
.00375 .10301 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .30902 m
.00375 .30902 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .39142 m
.00375 .39142 L
s
0 .41202 m
.00375 .41202 L
s
0 .43262 m
.00375 .43262 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .51503 m
.00375 .51503 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
0 .0206 m
.00375 .0206 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.23) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .20601 m
.00123 .20601 L
.00236 .20601 L
.00365 .20601 L
.00488 .20601 L
.00601 .20601 L
.00706 .20601 L
.00821 .20601 L
.00942 .20601 L
.01065 .20601 L
.01196 .20601 L
.0132 .20601 L
.01434 .20601 L
.01566 .20601 L
.01641 .20601 L
.01711 .20601 L
.01839 .20601 L
.01975 .20601 L
.02043 .20601 L
.02115 .20601 L
.02245 .20601 L
.02317 .20601 L
.02384 .20601 L
.02463 .20601 L
.02537 .20601 L
.02671 .20601 L
.02793 .20601 L
.02924 .20601 L
.02998 .20601 L
.03067 .20601 L
.03184 .20601 L
.03295 .20601 L
.03416 .20601 L
.03547 .20601 L
.03676 .20601 L
.03813 .20601 L
.03929 .20601 L
.04057 .20601 L
.04131 .20601 L
.042 .20601 L
.04274 .20601 L
.04355 .20601 L
.04492 .20601 L
.04567 .20601 L
.04637 .20601 L
.0477 .20601 L
.04892 .20601 L
.04959 .20601 L
.05032 .20601 L
.05165 .20601 L
Mistroke
.05245 .20601 L
.05321 .20601 L
.05462 .20601 L
.05542 .20601 L
.05615 .20601 L
.05695 .20601 L
.05779 .20601 L
.05847 .20601 L
.0592 .20601 L
.06051 .20601 L
.06131 .20601 L
.06207 .20601 L
.0628 .20601 L
.06349 .20601 L
.06471 .20601 L
.06606 .20601 L
.06738 .20601 L
.06812 .20601 L
.0688 .20601 L
.06994 .20601 L
.07119 .20601 L
.07249 .20601 L
.07371 .20601 L
.0744 .20601 L
.07516 .20601 L
.07652 .20601 L
.07785 .20601 L
.07908 .20601 L
.08041 .20601 L
.08116 .20601 L
.08186 .20601 L
.08328 .20601 L
.08408 .20601 L
.08481 .20601 L
.08604 .20601 L
.0872 .20601 L
.08847 .20601 L
.08985 .20601 L
.09121 .20601 L
.09189 .20601 L
.09264 .20601 L
.09397 .20601 L
.0952 .20601 L
.09645 .20601 L
.09764 .20601 L
.0987 .20601 L
.09985 .20601 L
.10111 .20601 L
.10244 .20601 L
.10357 .20601 L
Mistroke
.10482 .20601 L
.10552 .20601 L
.10628 .20601 L
.10766 .20601 L
.109 .20601 L
.11025 .20601 L
.11101 .20601 L
.11173 .20601 L
.11307 .20601 L
.11382 .20601 L
.11451 .20601 L
.11527 .20601 L
.11608 .20601 L
.11734 .20601 L
.11852 .20601 L
.11924 .20601 L
.11992 .20601 L
.1212 .20601 L
.12255 .20601 L
.12379 .20601 L
.12516 .20601 L
.12585 .20601 L
.12661 .20601 L
.12789 .20601 L
.12908 .20601 L
.13039 .20601 L
.13112 .20601 L
.13178 .20601 L
.13312 .20601 L
.13388 .20601 L
.13458 .20601 L
.13586 .20601 L
.13722 .20601 L
.13837 .20601 L
.13961 .20601 L
.14078 .20601 L
.14185 .20601 L
.1431 .20601 L
.14446 .20601 L
.14575 .20601 L
.14694 .20601 L
.14832 .20601 L
.1491 .20601 L
.14981 .20601 L
.15113 .20601 L
.15251 .20601 L
.15376 .20601 L
.15492 .20601 L
.15619 .20601 L
.15755 .20601 L
Mistroke
.15831 .20601 L
.15901 .20601 L
.15976 .20601 L
.16059 .20601 L
.16199 .20601 L
.16275 .20601 L
.16347 .20601 L
.16482 .20601 L
.16606 .20601 L
.16674 .20601 L
.16749 .20601 L
.16885 .20601 L
.16952 .20601 L
.17024 .20601 L
.17152 .20601 L
.1729 .20601 L
.17369 .20601 L
.17442 .20601 L
.17575 .20601 L
.17696 .20601 L
.17835 .20601 L
.17967 .20601 L
.18086 .20601 L
.18212 .20601 L
.18319 .20601 L
.18438 .20601 L
.18565 .20601 L
.18702 .20601 L
.18831 .20601 L
.18949 .20601 L
.19078 .20601 L
.19215 .20601 L
.19344 .20601 L
.19461 .20601 L
.196 .20601 L
.19678 .20601 L
.1975 .20601 L
.19882 .20601 L
.20022 .20601 L
.20156 .20601 L
.203 .20601 L
.20435 .20601 L
.20559 .20601 L
.20705 .20601 L
.20787 .20601 L
.20863 .20601 L
.21003 .20601 L
.21151 .20601 L
.21282 .20601 L
.21425 .20601 L
Mistroke
.21498 .20601 L
.21575 .20601 L
.21715 .20601 L
.21854 .20601 L
.21986 .20601 L
.22105 .20601 L
.22233 .20601 L
.22373 .20601 L
.22528 .20601 L
.22606 .20601 L
.2269 .20601 L
.22841 .20601 L
.22984 .20601 L
.23134 .20601 L
.23262 .20601 L
.23403 .20601 L
.23546 .20601 L
.23681 .20601 L
.23802 .20601 L
.23934 .20601 L
.24077 .20601 L
.24229 .20601 L
.24358 .20601 L
.24501 .20601 L
.24634 .20601 L
.24755 .20601 L
.24895 .20601 L
.25028 .20601 L
.25151 .20601 L
.25264 .20601 L
.25389 .20601 L
.25521 .20601 L
.2564 .20601 L
.25771 .20601 L
.25907 .20601 L
.26033 .20601 L
.26152 .20601 L
.2626 .20601 L
.26385 .20601 L
.26503 .20601 L
.26631 .20601 L
.26767 .20601 L
.26883 .20601 L
.27011 .20601 L
.27148 .20601 L
.27296 .20601 L
.27435 .20601 L
.27562 .20601 L
.2768 .20601 L
.27806 .20601 L
Mistroke
.27925 .20601 L
.28033 .20601 L
.2816 .20601 L
.28297 .20601 L
.28427 .20601 L
.28546 .20601 L
.28658 .20601 L
.28763 .20601 L
.28877 .20601 L
.29 .20601 L
.29129 .20601 L
.29252 .20601 L
.29361 .20601 L
.29481 .20601 L
.29608 .20601 L
.29726 .20601 L
.29854 .20601 L
.2999 .20601 L
.30108 .20601 L
.30218 .20601 L
.30339 .20601 L
.30468 .20601 L
.30609 .20601 L
.30762 .20601 L
.30906 .20601 L
.31039 .20601 L
.31159 .20601 L
.31291 .20601 L
.31429 .20601 L
.31557 .20601 L
.31694 .20601 L
.31843 .20601 L
.31983 .20601 L
.32113 .20601 L
.32242 .20601 L
.32359 .20601 L
.32494 .20601 L
.32621 .20601 L
.3276 .20601 L
.32907 .20601 L
.33033 .20601 L
.3317 .20601 L
.33319 .20601 L
.33477 .20601 L
.33627 .20601 L
.33764 .20601 L
.33888 .20601 L
.34005 .20601 L
.34132 .20601 L
.3427 .20601 L
Mistroke
.34414 .20601 L
.34551 .20601 L
.34673 .20601 L
.34808 .20601 L
.35049 .20601 L
.35185 .20601 L
.35308 .20601 L
.35422 .20601 L
.35547 .20601 L
.35772 .20601 L
.35908 .20601 L
.36035 .20601 L
.36175 .20601 L
.36324 .20601 L
.36481 .20601 L
.36629 .20601 L
.36763 .20601 L
.36908 .20601 L
.37033 .20601 L
.37171 .20601 L
.37315 .20601 L
.37451 .20601 L
.37693 .20601 L
.37829 .20601 L
.37954 .20601 L
.38087 .20601 L
.38214 .20601 L
.3845 .20601 L
.38583 .20601 L
.38705 .20601 L
.38848 .20601 L
.38982 .20601 L
.39203 .20601 L
.3932 .20601 L
.39446 .20601 L
.39578 .20601 L
.39704 .20601 L
.39939 .20601 L
.40076 .20601 L
.402 .20601 L
.40333 .20601 L
.40478 .20601 L
.40612 .20601 L
.40735 .20601 L
.40978 .20601 L
.41114 .20601 L
.41241 .20601 L
.41392 .20601 L
.41529 .20601 L
.4181 .20601 L
Mistroke
.41965 .20601 L
.42112 .20601 L
.42231 .20601 L
.42361 .20601 L
.42594 .20601 L
.4273 .20601 L
.42872 .20601 L
.43127 .20601 L
.43256 .20601 L
.43393 .20601 L
.43641 .20601 L
.43793 .20601 L
.43936 .20601 L
.44204 .20601 L
.44439 .20601 L
.44688 .20601 L
.449 .20601 L
.45133 .20601 L
.45384 .20601 L
.45653 .20601 L
.45907 .20601 L
.46139 .20601 L
.46403 .20601 L
.46642 .20601 L
.46918 .20601 L
.47177 .20601 L
.47418 .20601 L
.47639 .20601 L
.47882 .20601 L
.48139 .20601 L
.48399 .20601 L
.48677 .20601 L
.48939 .20601 L
.49178 .20601 L
.49459 .20601 L
.49763 .20601 L
.50051 .20601 L
.50317 .20601 L
.50572 .20601 L
.50806 .20601 L
.51075 .20601 L
.51332 .20601 L
.51567 .20601 L
.51786 .20601 L
.52027 .20601 L
.52283 .20601 L
.52563 .20601 L
.52867 .20601 L
.53154 .20601 L
.53418 .20601 L
Mistroke
.53657 .20601 L
.53919 .20601 L
.54193 .20601 L
.54448 .20601 L
.54974 .20601 L
.55271 .20601 L
.55545 .20601 L
.56049 .20601 L
.56304 .206 L
.56585 .206 L
.57068 .206 L
.5734 .206 L
.5759 .20599 L
.58049 .20598 L
.58533 .20597 L
.59058 .20595 L
.59535 .20593 L
.60086 .20589 L
.60606 .20585 L
.61087 .20579 L
.61531 .20572 L
.62018 .20562 L
.62534 .20549 L
.63525 .20514 L
.64081 .20487 L
.64589 .20456 L
.65575 .20382 L
.66512 .20292 L
.68619 .20038 L
.69536 .19928 L
.70018 .19878 L
.70527 .19833 L
.70792 .19815 L
.70932 .19806 L
.71082 .19799 L
.71221 .19793 L
.71347 .19789 L
.71473 .19785 L
.71593 .19783 L
.71714 .19782 L
.71843 .19782 L
.71953 .19782 L
.72074 .19784 L
.72204 .19788 L
.72343 .19793 L
.72475 .19799 L
.72596 .19805 L
.72862 .19824 L
.73109 .19847 L
.7367 .19916 L
Mistroke
.74217 .20007 L
.748 .20126 L
.76894 .20662 L
.77996 .20939 L
.78599 .21067 L
.79162 .21166 L
.79665 .21234 L
.79923 .21262 L
.80204 .21287 L
.80364 .21298 L
.80512 .21307 L
.8065 .21313 L
.80803 .21319 L
.8094 .21322 L
.81068 .21324 L
.81204 .21325 L
.8128 .21325 L
.8135 .21325 L
.81467 .21324 L
.81592 .21322 L
.81711 .21319 L
.81818 .21315 L
.82082 .21304 L
.82331 .2129 L
.82827 .21254 L
.83365 .21204 L
.85408 .20979 L
.86492 .20868 L
.87658 .20772 L
.88229 .20734 L
.88772 .20705 L
.89301 .20681 L
.89792 .20664 L
.90293 .20649 L
.90748 .20638 L
.91253 .20629 L
.91791 .20621 L
.92303 .20615 L
.92844 .20611 L
.93306 .20608 L
.93813 .20606 L
.94359 .20605 L
.94665 .20604 L
.94944 .20603 L
.95204 .20603 L
.95486 .20603 L
.95733 .20602 L
.96 .20602 L
.96248 .20602 L
.96475 .20602 L
Mistroke
.96922 .20602 L
.97159 .20601 L
.97418 .20601 L
.97691 .20601 L
.9794 .20601 L
.98187 .20601 L
.98456 .20601 L
.9874 .20601 L
.99007 .20601 L
.99258 .20601 L
.99524 .20601 L
1 .20601 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13039,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo00?ooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooo
oom5ooooo`001Ol00002ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Gooooo00?o
0000ooooooooool0oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo00Co
A4A4omgMgOoooooo00001_ooool3o`000?ooooooAOooool000Oooooo00Go0000oooooooooooooooo
o`00000;ooooo`04omgMgOmEEEGoooooo`0000Kooooo00?o0000ooooooooool0oooooom5ooooo`00
1oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001_ooool00ol0003o
ooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^ko
A4A4o`000006ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Gooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool5o`0000Gooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool00ol0003oooooooooo`3oooooodGooooo0005o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0oooooom5ooooo`001ooo
ool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01Oooool3o`000?oooooo
AOooool000Oooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Cooooo
00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Gooooo00?o0000oooooooo
ool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c005ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo027ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@0Iooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l00000
0ol@413oooooooooo`0Gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l0
00001Ol@413oooooooooooooooooA4A400;o000000?o<S8bomgMgOooool06?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM03Wooooo000Qoooo
o`;o00008_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01oooool00omgMgOo<S8booooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B47ooooo`03o`000?oooooooooo00Kooooo00?oMgMgoc8b<_ooool06?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@06_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1oooool00omgMgOo<S8booooo`0hooooo`008Oooool00ol0003oooooooooo`0Qooooo`05oa0@4?oo
ooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000oooooooo
ool05oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool06Oooool01Ol@
413ooooooooooooooooo410@00kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0G
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Kooooo`05oa0@4?oo
ooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo03Oooooo
000Qooooo`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`00
0?ooooooooooooooool000001oooool00omgMgOo<S8booooo`0Hooooo`05o`000?oooooooooooooo
ool000003_ooool00ol0003oooooooooo`0Iooooo`05o`000?ooooooooooooooool000003_ooool0
0ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo01Sooooo00Go0000ooooooooooooooooo`00
000=ooooo`03oiRHV?lQ8B7ok^k^01[ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool0>?ooool0027ooooo00?o0000ooooooooool08Ooo
ool01Ol0003ooooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000004ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`06Oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000
ooooooooool06Oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<01Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo01Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00iooooo`008Oooool00ol0003oooooooooo`0Qoooo
o`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00Cooooo00?o
0000ooooooooool06oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool0
6Oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Kooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`0Hoooo
o`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo03_ooooo000Qooooo`03o`000?oooooooooo027ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00ol0003oooooooooo`0Kooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`0Iooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01_ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41006_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo03_ooooo
000Qooooo`;o00008_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP04ooooo`Co00006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIV
I_l000006oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l000001Oooool4
o`0001[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
6_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004oooo
o`Co0000>_ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo>_ooool00ol@413o0000o`00
0003o`0000Gooooo000Qooooo`03o`000?oooooooooo0<cooooo5Ol0001Jooooo`03o`000?oooooo
oooo00Kooooo000Qooooo`03o`000?oooooooooo0<Cooooo2?l0000Eooooo`Go0000EOooool00ol0
003oooooooooo`06ooooo`008Oooooooo`0003?o00003?ooool00ol0003oooooooooo`06ooooo`00
8Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo
oooo1?l00002ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02ol00006ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Dooooo`03
o`000?lb<S;ogMgM00Kooooo000Qooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
8oooool@o`0003_ooooo0_l000001?nYZJWo8B4Qo`000?lQ8B44ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
0_l0003oooooodKooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Gooooo00?o0000oooooooo
ool0oooooom5ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP06ooooo`?o0000oooooom5oooo
o`001oooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01Oooool00ol0
003oooooooooo`3oooooodGooooo0007ooooo`05o`000?ooooooooooooooool000003_ooool00omg
MgOoIVIVooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go410@oooooooo
oooooooooa0@400?ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0oooooom5oooo
o`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4005
ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool00oooool00ol0003oooooooooo`3ooooo
odGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05oa0@4?oooooooooooooo
ool@41002oooool5o`0000Gooooo0ol0003oooooodGooooo0007ooooo`05o`000?oooooooooooooo
ool000002oooool01?m4A4CogMgMooooool00006ooooo`03o`000?oooooooooo0?ooooooAOooool0
00Oooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Kooooo00?o
0000ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00cooooo00?o
MgMgolc<c?l000001_ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`000006ooooo`03o`000?oooooooooo0?ooooooAOoo
ool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Gooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo0_l0003oooooodKooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool000Oo
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413o
c<c<00Gooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401Oooool00ol0003ooooooooo
o`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000000Gooooo0ol0003oooooodGooooo0007ooooo`05o`000?ooooooooooooooool00000
2oooool01Ol0003oV9RHoooooonHV9So8B4Q00Gooooo00?o0000ooooooooool0oooooom5ooooo`00
1oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c005oooo
o`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go410@oooooooooooooooooa0@400;oooo
o`03oeEEEOn7QhOooooo00Oooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P01oooool00ol0003oooooooooo`3ooooo
odGooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4105
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo0_l0003oooooodKooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0
003o8B4Qolc<c005ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Gooooo00?o0000
ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`000005ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go0000
ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801Oooool3o`000?oooooo
AOooool000Oooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<
c<`01Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@
41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Gooooo00?o0000ooooooooool0oooooom5oooo
o`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000005
ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;
ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`006?ooool4o`000003oa0@4?oooooooooo00;o
oooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo0ol0003oooooodGooooo000Joooo
o`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Hooooo`03oeEEEOmVIVKo00000?ooooooC_oo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool009kooooo00GoV9RHo`000?l0003o
A4A4okZj^P0Hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00003oooo
o`05oiRHV?l@413o0000oc8b<_o<c<`0T?ooool001oooooo00Co410@o`000?l0003o0000Noooool0
1Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l00009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05oa0@4?nj^[[oooooogMg
Molb<S80T?ooool0023ooooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`0Jooooo`05
oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP08ooooo`03o`000?oooooooooo
08kooooo000Pooooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool02oooool6o`0000Wo
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?oZJVYoa0@
4?ooool0Soooool0023ooooo00Ko0000ogMgMol0003o0000oeEEEOo^k^ihooooo`03o`000?oooooo
oooo01[ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Cooooo00?o
410@o`000?nj^[X0T?ooool0023ooooo00Ko0000oeEEEOo^k^koooooogMgMomEEEEfooooo`03oa0@
4?l0003o000000?o00006Oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooooooo
ool01?ooool00onj^[[o8B4Qooooo`2?ooooo`008?ooool00ol0003ok^k^ooooo`02ooooo`03o`00
0?oooooooooo07Kooooo00?o0000ooooooooool06_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05oa0@4?nHV9SooooookZj^_l00000T?ooool0
023ooooo00?o0000onk^k_ooool00_ooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo
01[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00ooo
ool01OnYZJWo410@o`000?l@413oZJVY093ooooo000Pooooo`06o`000?mEEEGok^k^oooooomgMgOo
IVIVoooooom3ooooo`007oooool00ol@413o0000ogMgM`02o`000003ofIVI_o^k^kooooo0?oooooo
@_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.0332543, -0.540631, \
0.00122928, 0.00994506}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 3.33333 0.206011 0.412023 [
[.16667 .19351 -12 -9 ]
[.16667 .19351 12 0 ]
[.33333 .19351 -9 -9 ]
[.33333 .19351 9 0 ]
[.5 .19351 -12 -9 ]
[.5 .19351 12 0 ]
[.66667 .19351 -9 -9 ]
[.66667 .19351 9 0 ]
[.83333 .19351 -12 -9 ]
[.83333 .19351 12 0 ]
[1.025 .20601 0 -6 ]
[1.025 .20601 10 6 ]
[-0.0125 .0412 -24 -4.5 ]
[-0.0125 .0412 0 4.5 ]
[-0.0125 .12361 -24 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .28842 -18 -4.5 ]
[-0.0125 .28842 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .45322 -18 -4.5 ]
[-0.0125 .45322 0 4.5 ]
[-0.0125 .53563 -18 -4.5 ]
[-0.0125 .53563 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 .20601 m
.16667 .21226 L
s
[(0.05)] .16667 .19351 0 1 Mshowa
.33333 .20601 m
.33333 .21226 L
s
[(0.1)] .33333 .19351 0 1 Mshowa
.5 .20601 m
.5 .21226 L
s
[(0.15)] .5 .19351 0 1 Mshowa
.66667 .20601 m
.66667 .21226 L
s
[(0.2)] .66667 .19351 0 1 Mshowa
.83333 .20601 m
.83333 .21226 L
s
[(0.25)] .83333 .19351 0 1 Mshowa
.125 Mabswid
.03333 .20601 m
.03333 .20976 L
s
.06667 .20601 m
.06667 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.13333 .20601 m
.13333 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.23333 .20601 m
.23333 .20976 L
s
.26667 .20601 m
.26667 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.36667 .20601 m
.36667 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.43333 .20601 m
.43333 .20976 L
s
.46667 .20601 m
.46667 .20976 L
s
.53333 .20601 m
.53333 .20976 L
s
.56667 .20601 m
.56667 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.63333 .20601 m
.63333 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.73333 .20601 m
.73333 .20976 L
s
.76667 .20601 m
.76667 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.86667 .20601 m
.86667 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.93333 .20601 m
.93333 .20976 L
s
.96667 .20601 m
.96667 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
gsave
1.025 .20601 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .0412 m
.00625 .0412 L
s
[(-0.4)] -0.0125 .0412 1 0 Mshowa
0 .12361 m
.00625 .12361 L
s
[(-0.2)] -0.0125 .12361 1 0 Mshowa
0 .28842 m
.00625 .28842 L
s
[(0.2)] -0.0125 .28842 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.4)] -0.0125 .37082 1 0 Mshowa
0 .45322 m
.00625 .45322 L
s
[(0.6)] -0.0125 .45322 1 0 Mshowa
0 .53563 m
.00625 .53563 L
s
[(0.8)] -0.0125 .53563 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .10301 m
.00375 .10301 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .30902 m
.00375 .30902 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .39142 m
.00375 .39142 L
s
0 .41202 m
.00375 .41202 L
s
0 .43262 m
.00375 .43262 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .51503 m
.00375 .51503 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
0 .0206 m
.00375 .0206 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.24) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .20601 m
.00123 .20601 L
.00236 .20601 L
.00365 .20601 L
.00488 .20601 L
.00601 .20601 L
.00706 .20601 L
.00821 .20601 L
.00942 .20601 L
.01065 .20601 L
.01196 .20601 L
.0132 .20601 L
.01434 .20601 L
.01566 .20601 L
.01641 .20601 L
.01711 .20601 L
.01839 .20601 L
.01975 .20601 L
.02043 .20601 L
.02115 .20601 L
.02245 .20601 L
.02317 .20601 L
.02384 .20601 L
.02463 .20601 L
.02537 .20601 L
.02671 .20601 L
.02793 .20601 L
.02924 .20601 L
.02998 .20601 L
.03067 .20601 L
.03184 .20601 L
.03295 .20601 L
.03416 .20601 L
.03547 .20601 L
.03676 .20601 L
.03813 .20601 L
.03929 .20601 L
.04057 .20601 L
.04131 .20601 L
.042 .20601 L
.04275 .20601 L
.04355 .20601 L
.0449 .20601 L
.04566 .20601 L
.04637 .20601 L
.0477 .20601 L
.04892 .20601 L
.04959 .20601 L
.05032 .20601 L
.05165 .20601 L
Mistroke
.05245 .20601 L
.05321 .20601 L
.05462 .20601 L
.05542 .20601 L
.05615 .20601 L
.05695 .20601 L
.05779 .20601 L
.05847 .20601 L
.0592 .20601 L
.06051 .20601 L
.06131 .20601 L
.06207 .20601 L
.0628 .20601 L
.06349 .20601 L
.06471 .20601 L
.06606 .20601 L
.06738 .20601 L
.06812 .20601 L
.0688 .20601 L
.06994 .20601 L
.07119 .20601 L
.07249 .20601 L
.07371 .20601 L
.0744 .20601 L
.07516 .20601 L
.07652 .20601 L
.07785 .20601 L
.07908 .20601 L
.08041 .20601 L
.08116 .20601 L
.08186 .20601 L
.08328 .20601 L
.08408 .20601 L
.08481 .20601 L
.08604 .20601 L
.0872 .20601 L
.08847 .20601 L
.08985 .20601 L
.09121 .20601 L
.09189 .20601 L
.09264 .20601 L
.09397 .20601 L
.0952 .20601 L
.09645 .20601 L
.09764 .20601 L
.0987 .20601 L
.09985 .20601 L
.10111 .20601 L
.10244 .20601 L
.10357 .20601 L
Mistroke
.10482 .20601 L
.10552 .20601 L
.10628 .20601 L
.10766 .20601 L
.109 .20601 L
.11025 .20601 L
.11101 .20601 L
.11173 .20601 L
.11307 .20601 L
.11382 .20601 L
.11451 .20601 L
.11527 .20601 L
.11608 .20601 L
.11734 .20601 L
.11852 .20601 L
.11924 .20601 L
.11992 .20601 L
.1212 .20601 L
.12255 .20601 L
.12379 .20601 L
.12516 .20601 L
.12585 .20601 L
.12661 .20601 L
.12789 .20601 L
.12908 .20601 L
.13039 .20601 L
.13112 .20601 L
.13178 .20601 L
.13312 .20601 L
.13388 .20601 L
.13458 .20601 L
.13586 .20601 L
.13722 .20601 L
.13837 .20601 L
.13961 .20601 L
.14078 .20601 L
.14185 .20601 L
.1431 .20601 L
.14446 .20601 L
.14575 .20601 L
.14694 .20601 L
.14832 .20601 L
.1491 .20601 L
.14981 .20601 L
.15113 .20601 L
.15251 .20601 L
.15376 .20601 L
.15492 .20601 L
.15619 .20601 L
.15755 .20601 L
Mistroke
.15831 .20601 L
.15901 .20601 L
.15976 .20601 L
.16059 .20601 L
.16199 .20601 L
.16275 .20601 L
.16347 .20601 L
.16482 .20601 L
.16606 .20601 L
.16674 .20601 L
.16749 .20601 L
.16885 .20601 L
.16952 .20601 L
.17024 .20601 L
.17152 .20601 L
.1729 .20601 L
.17369 .20601 L
.17442 .20601 L
.17575 .20601 L
.17696 .20601 L
.17762 .20601 L
.17835 .20601 L
.17967 .20601 L
.18085 .20601 L
.18215 .20601 L
.1835 .20601 L
.18477 .20601 L
.18596 .20601 L
.18704 .20601 L
.18824 .20601 L
.18949 .20601 L
.19087 .20601 L
.19213 .20601 L
.19282 .20601 L
.19357 .20601 L
.19494 .20601 L
.19622 .20601 L
.19758 .20601 L
.19873 .20601 L
.20001 .20601 L
.20078 .20601 L
.2015 .20601 L
.20287 .20601 L
.20364 .20601 L
.20434 .20601 L
.20517 .20601 L
.20595 .20601 L
.20736 .20601 L
.20864 .20601 L
.21002 .20601 L
Mistroke
.2108 .20601 L
.21151 .20601 L
.21284 .20601 L
.2141 .20601 L
.21523 .20601 L
.21646 .20601 L
.21779 .20601 L
.21921 .20601 L
.22042 .20601 L
.22175 .20601 L
.22299 .20601 L
.22413 .20601 L
.22537 .20601 L
.22668 .20601 L
.22783 .20601 L
.22889 .20601 L
.23006 .20601 L
.23131 .20601 L
.23277 .20601 L
.23412 .20601 L
.2356 .20601 L
.23634 .20601 L
.23716 .20601 L
.23854 .20601 L
.24002 .20601 L
.24141 .20601 L
.24269 .20601 L
.244 .20601 L
.24522 .20601 L
.24656 .20601 L
.24799 .20601 L
.24922 .20601 L
.25038 .20601 L
.25165 .20601 L
.25302 .20601 L
.25433 .20601 L
.25552 .20601 L
.2569 .20601 L
.25821 .20601 L
.25941 .20601 L
.26053 .20601 L
.26175 .20601 L
.26304 .20601 L
.26434 .20601 L
.26574 .20601 L
.26706 .20601 L
.26827 .20601 L
.26968 .20601 L
.27122 .20601 L
.27267 .20601 L
Mistroke
.27402 .20601 L
.27541 .20601 L
.27692 .20601 L
.27834 .20601 L
.27964 .20601 L
.28083 .20601 L
.28212 .20601 L
.28348 .20601 L
.28474 .20601 L
.28622 .20601 L
.28763 .20601 L
.28889 .20601 L
.29026 .20601 L
.29174 .20601 L
.29333 .20601 L
.29468 .20601 L
.29617 .20601 L
.29744 .20601 L
.29863 .20601 L
.29994 .20601 L
.30133 .20601 L
.3028 .20601 L
.30418 .20601 L
.30542 .20601 L
.30677 .20601 L
.30794 .20601 L
.30922 .20601 L
.31057 .20601 L
.31182 .20601 L
.313 .20601 L
.31407 .20601 L
.31531 .20601 L
.31649 .20601 L
.31787 .20601 L
.31912 .20601 L
.32056 .20601 L
.32192 .20601 L
.32319 .20601 L
.32435 .20601 L
.32562 .20601 L
.32697 .20601 L
.32833 .20601 L
.32979 .20601 L
.33116 .20601 L
.33241 .20601 L
.33389 .20601 L
.33548 .20601 L
.33699 .20601 L
.33839 .20601 L
.33969 .20601 L
Mistroke
.34094 .20601 L
.34205 .20601 L
.34327 .20601 L
.34459 .20601 L
.34599 .20601 L
.34732 .20601 L
.34853 .20601 L
.34975 .20601 L
.35087 .20601 L
.35211 .20601 L
.35342 .20601 L
.35562 .20601 L
.35686 .20601 L
.35803 .20601 L
.35937 .20601 L
.36083 .20601 L
.36221 .20601 L
.36349 .20601 L
.36464 .20601 L
.36591 .20601 L
.36723 .20601 L
.36847 .20601 L
.36984 .20601 L
.37129 .20601 L
.37252 .20601 L
.37386 .20601 L
.37532 .20601 L
.37688 .20601 L
.37834 .20601 L
.37968 .20601 L
.3821 .20601 L
.38347 .20601 L
.38476 .20601 L
.38612 .20601 L
.38736 .20601 L
.38879 .20601 L
.39015 .20601 L
.39131 .20601 L
.39254 .20601 L
.39477 .20601 L
.39613 .20601 L
.39741 .20601 L
.3998 .20601 L
.40107 .20601 L
.40246 .20601 L
.40391 .20601 L
.40527 .20601 L
.4077 .20601 L
.40906 .20601 L
.41029 .20601 L
Mistroke
.41165 .20601 L
.41309 .20601 L
.41466 .20601 L
.41612 .20601 L
.41874 .20601 L
.42023 .20601 L
.42163 .20601 L
.42287 .20601 L
.42419 .20601 L
.42657 .20601 L
.42803 .20601 L
.4294 .20601 L
.43197 .20601 L
.43329 .20601 L
.43469 .20601 L
.43719 .20601 L
.43858 .20601 L
.43989 .20601 L
.4413 .20601 L
.44285 .20601 L
.44415 .20601 L
.44536 .20601 L
.44775 .20601 L
.44992 .20601 L
.45222 .20601 L
.45353 .20601 L
.45494 .20601 L
.45619 .20601 L
.4575 .20601 L
.46 .20601 L
.46229 .20601 L
.46357 .20601 L
.46497 .20601 L
.46621 .20601 L
.46752 .20601 L
.46999 .20601 L
.47228 .20601 L
.4749 .20601 L
.47736 .20601 L
.47877 .20601 L
.48006 .20601 L
.48147 .20601 L
.48297 .20601 L
.48542 .20601 L
.48769 .20601 L
.4904 .20601 L
.49285 .20601 L
.49517 .20601 L
.49768 .20601 L
.50006 .20601 L
Mistroke
.50224 .20601 L
.50482 .20601 L
.50717 .20601 L
.50989 .20601 L
.51246 .20601 L
.51483 .20601 L
.51703 .20601 L
.51944 .20601 L
.522 .20601 L
.52456 .20601 L
.52732 .20601 L
.52992 .20601 L
.53231 .20601 L
.53496 .20601 L
.53786 .20601 L
.54088 .20601 L
.5437 .20601 L
.54645 .20601 L
.549 .20601 L
.55179 .20601 L
.55474 .20601 L
.55731 .20601 L
.55971 .20601 L
.56234 .20601 L
.56517 .20601 L
.56767 .20601 L
.5704 .20601 L
.57298 .20601 L
.57537 .20601 L
.57988 .20601 L
.5824 .20601 L
.58469 .20601 L
.58982 .20601 L
.59241 .20601 L
.59524 .20601 L
.59766 .206 L
.60026 .206 L
.60493 .206 L
.60775 .206 L
.61082 .20599 L
.61352 .20599 L
.61638 .20598 L
.6218 .20596 L
.62681 .20594 L
.63196 .20592 L
.63667 .20588 L
.64185 .20583 L
.64729 .20576 L
.65205 .20567 L
.65647 .20557 L
Mistroke
.6665 .20526 L
.67181 .20504 L
.67757 .20473 L
.68801 .20402 L
.69818 .2031 L
.70754 .20208 L
.71787 .20084 L
.72896 .19956 L
.73433 .19903 L
.73942 .19862 L
.74163 .19848 L
.74399 .19835 L
.74522 .1983 L
.74657 .19826 L
.74781 .19822 L
.74897 .1982 L
.75017 .19818 L
.75129 .19818 L
.75252 .19818 L
.75383 .1982 L
.75521 .19823 L
.75652 .19827 L
.75769 .19832 L
.75896 .19839 L
.76127 .19853 L
.76373 .19873 L
.76813 .19921 L
.77321 .19994 L
.77796 .20078 L
.7888 .20317 L
.80827 .20809 L
.81856 .21033 L
.82421 .21131 L
.82952 .21204 L
.83243 .21235 L
.83557 .21261 L
.83695 .2127 L
.83842 .21278 L
.83979 .21285 L
.84104 .21289 L
.84231 .21293 L
.84368 .21295 L
.84494 .21297 L
.84614 .21297 L
.84681 .21297 L
.84753 .21296 L
.84882 .21294 L
.8502 .21291 L
.85173 .21286 L
.85446 .21275 L
Mistroke
.85697 .21261 L
.86261 .2122 L
.87283 .21122 L
.89439 .20894 L
.9049 .20802 L
.91445 .20736 L
.91923 .2071 L
.92441 .20686 L
.93381 .20654 L
.93903 .20641 L
.94456 .2063 L
.94928 .20623 L
.95448 .20617 L
.95996 .20612 L
.96516 .20609 L
.96982 .20607 L
.97491 .20605 L
.9778 .20604 L
.98043 .20604 L
.98325 .20603 L
.9863 .20603 L
.98913 .20602 L
.99174 .20602 L
.99685 .20602 L
1 .20602 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13039,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo00?ooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooo
oom5ooooo`001Ol00002ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Gooooo00?o
0000ooooooooool0oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo00Co
A4A4omgMgOoooooo00001_ooool3o`000?ooooooAOooool000Oooooo00Go0000oooooooooooooooo
o`00000;ooooo`04omgMgOmEEEGoooooo`0000Kooooo00?o0000ooooooooool0oooooom5ooooo`00
1oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001_ooool00ol0003o
ooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^ko
A4A4o`000006ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Gooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool5o`0000Gooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool00ol0003oooooooooo`3oooooodGooooo0005o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0oooooom5ooooo`001ooo
ool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01Oooool3o`000?oooooo
AOooool000Oooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Cooooo
00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Gooooo00?o0000oooooooo
ool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c005ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo027ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@0Iooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l00000
0ol@413oooooooooo`0Gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l0
00001Ol@413oooooooooooooooooA4A400;o000000?o<S8bomgMgOooool06?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM03Wooooo000Qoooo
o`;o00008_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01oooool00omgMgOo<S8booooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B47ooooo`03o`000?oooooooooo00Kooooo00?oMgMgoc8b<_ooool06?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@06_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1oooool00omgMgOo<S8booooo`0hooooo`008Oooool00ol0003oooooooooo`0Qooooo`05oa0@4?oo
ooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000oooooooo
ool05oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool06Oooool01Ol@
413ooooooooooooooooo410@00kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0G
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Kooooo`05oa0@4?oo
ooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo03Oooooo
000Qooooo`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`00
0?ooooooooooooooool000001oooool00omgMgOo<S8booooo`0Hooooo`05o`000?oooooooooooooo
ool000003_ooool00ol0003oooooooooo`0Iooooo`05o`000?ooooooooooooooool000003_ooool0
0ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo01Sooooo00Go0000ooooooooooooooooo`00
000=ooooo`03oiRHV?lQ8B7ok^k^01[ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool0>?ooool0027ooooo00?o0000ooooooooool08Ooo
ool01Ol0003ooooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000004ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`06Oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000
ooooooooool06Oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<01Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo01Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00iooooo`008Oooool00ol0003oooooooooo`0Qoooo
o`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00Cooooo00?o
0000ooooooooool06oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool0
6Oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Kooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`0Hoooo
o`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo03_ooooo000Qooooo`03o`000?oooooooooo027ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00ol0003oooooooooo`0Kooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`0Iooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01_ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41006_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo03_ooooo
000Qooooo`;o00008_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP04ooooo`Co00006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIV
I_l000006oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l000001Oooool4
o`0001[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
6_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004oooo
o`Co0000>_ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo>_ooool00ol@413o0000o`00
0003o`0000Gooooo000Qooooo`03o`000?oooooooooo0=Oooooo5ol0001=ooooo`03o`000?oooooo
oooo00Kooooo000Qooooo`03o`000?oooooooooo0<kooooo2Ol0000Gooooo`?o0000B_ooool00ol0
003oooooooooo`06ooooo`008Oooooooo`0003?o00003?ooool00ol0003oooooooooo`06ooooo`00
8Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`05o`0000?ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`02ooooo`So00001oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Cooooo
00?o0000oc8b<_oMgMd01_ooool0027ooooo00?o0000ooooooooool0<?ooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0<?ooool00ol0003ooooooooo
o`0]oooooa;o0000;oooool2o`000004ojVYZOlQ8B7o0000ob4Q8@Cooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`001ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001Oooool00ol0003ooooo
ooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo
00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003oooooodGo
oooo0007ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP05ooooo`03
o`000?oooooooooo0?ooooooAOooool000Oooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooo
oooooooooooo410@00oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooodGo
oooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@
00Gooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c005ooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo0_l0003oooooodKooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?oo
ooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go410@oooooooooooo
oooooa0@400;ooooo`Go00001Oooool3o`000?ooooooAOooool000Oooooo00Go0000oooooooooooo
ooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Kooooo00?o0000ooooooooool0oooooom5oooo
o`001oooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001_ooool0
0ol0003oooooooooo`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0omgMgOoc<c<o`000006ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Kooooo00?o0000ooooooooool0oooooom5
ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo0_l0003oooooodKooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
1oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@
4?o<c<`01Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@05ooooo`03o`000?oooooo
oooo0?ooooooAOooool000Oooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooo
ooooooooool000001Oooool3o`000?ooooooAOooool000Oooooo00Go0000ooooooooooooooooo`00
000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401Oooool00ol0003oooooooooo`3oooooodGooooo
0007ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Go
oooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00_o
oooo00?oEEEEohN7Qoooool01oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV007ooooo`03o`000?oooooooooo0?oo
ooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@
40Gooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo0_l0003oooooodKooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Q
o`000?lQ8B7oc<c<00Gooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401Oooool00ol0
003oooooooooo`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0
003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol0
003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P05ooooo`?o0000oooo
oom5ooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000
olc<c005ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go410@oooooooooooooooo
oa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@41001Oooool00ol0003oooooooooo`3oooooodGo
oooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o0000
00Gooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@05ooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Hooooo`Co000000?o410@ooooooooool0
0_ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool3o`000?ooooooAOooool001[o
oooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo
000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001Sooooo00?oEEEEofIVI_l00000oooooom>
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00W_ooool01OnHV9So0000o`00
0?m4A4Co^[Zj01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Go
oooo0_l000000ol@413oooooooooo`2>ooooo`007oooool01?l@413o0000o`000?l0001kooooo`05
oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0Sooo
ool0023ooooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`0Jooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP04ooooo`Go0000T?ooool0023ooooo00?o0000
ooooooooool0Noooool00ol0003oooooooooo`0;ooooo`Ko00002Oooool01Ol0003ooooooooooooo
oooo000000gooooo00?oV9RHob4Q8Oo^k^h00oooool01?m4A4CogMgMooooool0002Aooooo`008?oo
ool01_l0003oMgMgo`000?l0003oEEEEonk^kWSooooo00?o0000ooooooooool06_ooool01Ol0003o
oooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00_ooool01?oMgMgoEEEEooooool0002A
ooooo`008?ooool01_l0003oEEEEonk^k_ooooooMgMgoeEEEGKooooo00?o410@o`000?l000000ol0
000Iooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03ogMg
Moo<c<co0000097ooooo000Pooooo`03o`000?o^k^kooooo00;ooooo00?o0000ooooooooool0M_oo
ool00ol0003oooooooooo`0Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zj
oooooonHV9So410@00Cooooo00?ok^k^odA4A?l00000TOooool0023ooooo00?o0000onk^k_ooool0
0_ooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo01[ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01Oooool00omgMgOo0000ooooo`2@oooo
o`008?ooool01_l0003oEEEEonk^k_ooooooMgMgofIVI_oooooo@oooool001oooooo00?o410@o`00
0?mgMgL00_l000000omVIVKok^k^ooooo`3ooooood;ooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.0332543, -0.540631, \
0.00122928, 0.00994506}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 3.33333 0.206011 0.412023 [
[.16667 .19351 -12 -9 ]
[.16667 .19351 12 0 ]
[.33333 .19351 -9 -9 ]
[.33333 .19351 9 0 ]
[.5 .19351 -12 -9 ]
[.5 .19351 12 0 ]
[.66667 .19351 -9 -9 ]
[.66667 .19351 9 0 ]
[.83333 .19351 -12 -9 ]
[.83333 .19351 12 0 ]
[1.025 .20601 0 -6 ]
[1.025 .20601 10 6 ]
[-0.0125 .0412 -24 -4.5 ]
[-0.0125 .0412 0 4.5 ]
[-0.0125 .12361 -24 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .28842 -18 -4.5 ]
[-0.0125 .28842 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .45322 -18 -4.5 ]
[-0.0125 .45322 0 4.5 ]
[-0.0125 .53563 -18 -4.5 ]
[-0.0125 .53563 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 .20601 m
.16667 .21226 L
s
[(0.05)] .16667 .19351 0 1 Mshowa
.33333 .20601 m
.33333 .21226 L
s
[(0.1)] .33333 .19351 0 1 Mshowa
.5 .20601 m
.5 .21226 L
s
[(0.15)] .5 .19351 0 1 Mshowa
.66667 .20601 m
.66667 .21226 L
s
[(0.2)] .66667 .19351 0 1 Mshowa
.83333 .20601 m
.83333 .21226 L
s
[(0.25)] .83333 .19351 0 1 Mshowa
.125 Mabswid
.03333 .20601 m
.03333 .20976 L
s
.06667 .20601 m
.06667 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.13333 .20601 m
.13333 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.23333 .20601 m
.23333 .20976 L
s
.26667 .20601 m
.26667 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.36667 .20601 m
.36667 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.43333 .20601 m
.43333 .20976 L
s
.46667 .20601 m
.46667 .20976 L
s
.53333 .20601 m
.53333 .20976 L
s
.56667 .20601 m
.56667 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.63333 .20601 m
.63333 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.73333 .20601 m
.73333 .20976 L
s
.76667 .20601 m
.76667 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.86667 .20601 m
.86667 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.93333 .20601 m
.93333 .20976 L
s
.96667 .20601 m
.96667 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
gsave
1.025 .20601 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .0412 m
.00625 .0412 L
s
[(-0.4)] -0.0125 .0412 1 0 Mshowa
0 .12361 m
.00625 .12361 L
s
[(-0.2)] -0.0125 .12361 1 0 Mshowa
0 .28842 m
.00625 .28842 L
s
[(0.2)] -0.0125 .28842 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.4)] -0.0125 .37082 1 0 Mshowa
0 .45322 m
.00625 .45322 L
s
[(0.6)] -0.0125 .45322 1 0 Mshowa
0 .53563 m
.00625 .53563 L
s
[(0.8)] -0.0125 .53563 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .10301 m
.00375 .10301 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .30902 m
.00375 .30902 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .39142 m
.00375 .39142 L
s
0 .41202 m
.00375 .41202 L
s
0 .43262 m
.00375 .43262 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .51503 m
.00375 .51503 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
0 .0206 m
.00375 .0206 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.25) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .20601 m
.00123 .20601 L
.00236 .20601 L
.00365 .20601 L
.00488 .20601 L
.00601 .20601 L
.00706 .20601 L
.00821 .20601 L
.00942 .20601 L
.01065 .20601 L
.01196 .20601 L
.0132 .20601 L
.01434 .20601 L
.01566 .20601 L
.01641 .20601 L
.01711 .20601 L
.01839 .20601 L
.01975 .20601 L
.02043 .20601 L
.02115 .20601 L
.02245 .20601 L
.02317 .20601 L
.02384 .20601 L
.02458 .20601 L
.02537 .20601 L
.02605 .20601 L
.02679 .20601 L
.02814 .20601 L
.02945 .20601 L
.03067 .20601 L
.03184 .20601 L
.03295 .20601 L
.03416 .20601 L
.03547 .20601 L
.03676 .20601 L
.03813 .20601 L
.03929 .20601 L
.04057 .20601 L
.04131 .20601 L
.042 .20601 L
.04275 .20601 L
.04355 .20601 L
.0449 .20601 L
.04566 .20601 L
.04637 .20601 L
.0477 .20601 L
.04892 .20601 L
.04959 .20601 L
.05032 .20601 L
.05165 .20601 L
Mistroke
.05245 .20601 L
.05321 .20601 L
.05389 .20601 L
.05462 .20601 L
.05543 .20601 L
.05627 .20601 L
.057 .20601 L
.05779 .20601 L
.05854 .20601 L
.05921 .20601 L
.06 .20601 L
.06074 .20601 L
.06205 .20601 L
.0628 .20601 L
.06349 .20601 L
.06471 .20601 L
.06603 .20601 L
.06727 .20601 L
.06841 .20601 L
.06967 .20601 L
.07105 .20601 L
.07175 .20601 L
.07249 .20601 L
.07383 .20601 L
.07457 .20601 L
.07525 .20601 L
.076 .20601 L
.07679 .20601 L
.07812 .20601 L
.07888 .20601 L
.07959 .20601 L
.0809 .20601 L
.08211 .20601 L
.08349 .20601 L
.08481 .20601 L
.086 .20601 L
.08729 .20601 L
.0885 .20601 L
.08962 .20601 L
.09085 .20601 L
.0922 .20601 L
.09289 .20601 L
.09361 .20601 L
.09493 .20601 L
.09565 .20601 L
.09632 .20601 L
.09705 .20601 L
.09783 .20601 L
.09913 .20601 L
.09987 .20601 L
Mistroke
.10056 .20601 L
.10185 .20601 L
.10303 .20601 L
.10439 .20601 L
.10569 .20601 L
.10691 .20601 L
.10801 .20601 L
.10928 .20601 L
.11048 .20601 L
.1116 .20601 L
.11262 .20601 L
.11375 .20601 L
.11493 .20601 L
.11613 .20601 L
.11742 .20601 L
.11864 .20601 L
.11974 .20601 L
.12104 .20601 L
.12178 .20601 L
.12245 .20601 L
.1237 .20601 L
.12502 .20601 L
.12622 .20601 L
.12753 .20601 L
.12889 .20601 L
.13016 .20601 L
.13135 .20601 L
.13244 .20601 L
.13369 .20601 L
.13487 .20601 L
.13616 .20601 L
.13752 .20601 L
.13868 .20601 L
.13996 .20601 L
.14134 .20601 L
.14211 .20601 L
.14281 .20601 L
.14418 .20601 L
.14548 .20601 L
.14669 .20601 L
.14779 .20601 L
.14906 .20601 L
.15025 .20601 L
.15136 .20601 L
.15237 .20601 L
.15349 .20601 L
.15467 .20601 L
.15586 .20601 L
.15714 .20601 L
.15835 .20601 L
Mistroke
.15945 .20601 L
.16074 .20601 L
.16146 .20601 L
.16214 .20601 L
.16337 .20601 L
.16468 .20601 L
.16594 .20601 L
.16732 .20601 L
.16863 .20601 L
.16984 .20601 L
.17103 .20601 L
.17212 .20601 L
.17337 .20601 L
.17456 .20601 L
.17585 .20601 L
.17721 .20601 L
.17838 .20601 L
.17966 .20601 L
.18104 .20601 L
.18181 .20601 L
.18251 .20601 L
.18388 .20601 L
.18518 .20601 L
.18628 .20601 L
.1875 .20601 L
.18877 .20601 L
.18996 .20601 L
.19107 .20601 L
.19209 .20601 L
.19321 .20601 L
.19438 .20601 L
.19558 .20601 L
.19686 .20601 L
.19807 .20601 L
.19916 .20601 L
.20045 .20601 L
.20118 .20601 L
.20185 .20601 L
.20309 .20601 L
.20439 .20601 L
.20566 .20601 L
.20705 .20601 L
.20835 .20601 L
.20957 .20601 L
.21077 .20601 L
.21186 .20601 L
.21311 .20601 L
.2143 .20601 L
.21559 .20601 L
.21696 .20601 L
Mistroke
.21813 .20601 L
.21941 .20601 L
.22079 .20601 L
.22157 .20601 L
.22227 .20601 L
.22364 .20601 L
.22494 .20601 L
.22604 .20601 L
.22726 .20601 L
.22853 .20601 L
.22973 .20601 L
.23084 .20601 L
.23186 .20601 L
.23297 .20601 L
.23415 .20601 L
.23535 .20601 L
.23663 .20601 L
.23784 .20601 L
.23893 .20601 L
.24023 .20601 L
.24091 .20601 L
.24163 .20601 L
.24295 .20601 L
.24416 .20601 L
.24544 .20601 L
.24683 .20601 L
.24814 .20601 L
.24935 .20601 L
.25044 .20601 L
.25165 .20601 L
.25291 .20601 L
.25409 .20601 L
.25539 .20601 L
.25676 .20601 L
.25793 .20601 L
.25922 .20601 L
.2606 .20601 L
.26137 .20601 L
.26208 .20601 L
.26345 .20601 L
.26475 .20601 L
.26586 .20601 L
.26708 .20601 L
.26835 .20601 L
.26954 .20601 L
.27066 .20601 L
.27168 .20601 L
.27286 .20601 L
.27397 .20601 L
.27518 .20601 L
Mistroke
.27646 .20601 L
.27767 .20601 L
.27876 .20601 L
.28005 .20601 L
.28145 .20601 L
.28277 .20601 L
.28399 .20601 L
.28531 .20601 L
.28657 .20601 L
.2877 .20601 L
.28892 .20601 L
.29025 .20601 L
.29167 .20601 L
.29288 .20601 L
.29421 .20601 L
.29545 .20601 L
.29658 .20601 L
.29783 .20601 L
.29914 .20601 L
.30028 .20601 L
.30134 .20601 L
.30251 .20601 L
.30376 .20601 L
.30522 .20601 L
.30656 .20601 L
.30804 .20601 L
.30961 .20601 L
.31097 .20601 L
.31224 .20601 L
.31363 .20601 L
.31513 .20601 L
.31645 .20601 L
.3179 .20601 L
.31926 .20601 L
.32053 .20601 L
.32178 .20601 L
.32291 .20601 L
.32422 .20601 L
.32546 .20601 L
.32668 .20601 L
.328 .20601 L
.32923 .20601 L
.33036 .20601 L
.33169 .20601 L
.33313 .20601 L
.33448 .20601 L
.33574 .20601 L
.33703 .20601 L
.33824 .20601 L
.33957 .20601 L
Mistroke
.341 .20601 L
.3425 .20601 L
.34392 .20601 L
.34519 .20601 L
.34659 .20601 L
.3479 .20601 L
.34914 .20601 L
.35025 .20601 L
.35146 .20601 L
.35277 .20601 L
.35416 .20601 L
.35535 .20601 L
.35665 .20601 L
.35787 .20601 L
.35898 .20601 L
.36026 .20601 L
.36148 .20601 L
.3626 .20601 L
.36364 .20601 L
.36478 .20601 L
.366 .20601 L
.36719 .20601 L
.36849 .20601 L
.36985 .20601 L
.37112 .20601 L
.37231 .20601 L
.37339 .20601 L
.37464 .20601 L
.37582 .20601 L
.37711 .20601 L
.37847 .20601 L
.37963 .20601 L
.38091 .20601 L
.38228 .20601 L
.38376 .20601 L
.38515 .20601 L
.38642 .20601 L
.3876 .20601 L
.38886 .20601 L
.39113 .20601 L
.39252 .20601 L
.39382 .20601 L
.39499 .20601 L
.39626 .20601 L
.39863 .20601 L
.39982 .20601 L
.40113 .20601 L
.40225 .20601 L
.40345 .20601 L
.40561 .20601 L
Mistroke
.40689 .20601 L
.40831 .20601 L
.40978 .20601 L
.41117 .20601 L
.41246 .20601 L
.41364 .20601 L
.41494 .20601 L
.41631 .20601 L
.4177 .20601 L
.41918 .20601 L
.42059 .20601 L
.42186 .20601 L
.42336 .20601 L
.42499 .20601 L
.42652 .20601 L
.42793 .20601 L
.42915 .20601 L
.43046 .20601 L
.43283 .20601 L
.43427 .20601 L
.43564 .20601 L
.4382 .20601 L
.43951 .20601 L
.4409 .20601 L
.4434 .20601 L
.44494 .20601 L
.44638 .20601 L
.44768 .20601 L
.44907 .20601 L
.4504 .20601 L
.45161 .20601 L
.45398 .20601 L
.45531 .20601 L
.45675 .20601 L
.45936 .20601 L
.46066 .20601 L
.4621 .20601 L
.4636 .20601 L
.465 .20601 L
.46751 .20601 L
.46892 .20601 L
.47021 .20601 L
.47141 .20601 L
.47268 .20601 L
.47497 .20601 L
.47637 .20601 L
.4777 .20601 L
.4789 .20601 L
.48017 .20601 L
.48253 .20601 L
Mistroke
.48471 .20601 L
.48706 .20601 L
.48839 .20601 L
.48963 .20601 L
.49095 .20601 L
.49236 .20601 L
.49488 .20601 L
.49629 .20601 L
.4976 .20601 L
.49906 .20601 L
.5006 .20601 L
.50321 .20601 L
.5056 .20601 L
.50818 .20601 L
.50964 .20601 L
.511 .20601 L
.51353 .20601 L
.51593 .20601 L
.51808 .20601 L
.52041 .20601 L
.52296 .20601 L
.52565 .20601 L
.52795 .20601 L
.53048 .20601 L
.5331 .20601 L
.53595 .20601 L
.53865 .20601 L
.54115 .20601 L
.54362 .20601 L
.54587 .20601 L
.54846 .20601 L
.55089 .20601 L
.55357 .20601 L
.55639 .20601 L
.5588 .20601 L
.56144 .20601 L
.56429 .20601 L
.56733 .20601 L
.57021 .20601 L
.57283 .20601 L
.57524 .20601 L
.57789 .20601 L
.58066 .20601 L
.58326 .20601 L
.58569 .20601 L
.58791 .20601 L
.59034 .20601 L
.59291 .20601 L
.59552 .20601 L
.59831 .20601 L
Mistroke
.60094 .20601 L
.60333 .20601 L
.60614 .20601 L
.60919 .20601 L
.61207 .20601 L
.61472 .20601 L
.61964 .20601 L
.6224 .20601 L
.62492 .20601 L
.62726 .20601 L
.62981 .20601 L
.63446 .206 L
.63705 .206 L
.63991 .206 L
.6427 .20599 L
.64571 .20599 L
.64852 .20598 L
.65109 .20598 L
.65614 .20596 L
.66111 .20594 L
.66641 .20591 L
.67143 .20587 L
.67598 .20583 L
.68134 .20576 L
.68715 .20565 L
.69264 .20552 L
.69771 .20537 L
.7026 .20519 L
.70787 .20495 L
.71738 .20439 L
.72869 .20349 L
.73904 .20246 L
.74951 .20127 L
.76068 .20001 L
.7661 .19947 L
.77121 .19905 L
.77579 .19876 L
.77705 .1987 L
.77838 .19864 L
.77951 .1986 L
.78075 .19856 L
.78204 .19854 L
.78325 .19852 L
.78443 .19851 L
.78553 .19851 L
.78671 .19852 L
.78801 .19855 L
.78937 .19858 L
.79065 .19863 L
.79297 .19874 L
Mistroke
.79509 .19888 L
.79988 .19931 L
.80477 .19993 L
.81011 .20078 L
.82087 .20299 L
.8432 .20837 L
.84832 .20947 L
.85375 .2105 L
.85878 .21129 L
.86348 .21187 L
.8683 .21231 L
.87086 .21248 L
.87228 .21255 L
.8736 .2126 L
.87501 .21265 L
.87575 .21267 L
.87655 .21268 L
.8773 .21269 L
.87801 .2127 L
.87934 .21271 L
.88065 .2127 L
.88186 .21269 L
.88318 .21266 L
.88458 .21262 L
.88695 .21253 L
.88949 .21241 L
.89408 .21211 L
.90449 .2112 L
.92534 .20906 L
.93633 .20809 L
.94799 .20731 L
.95835 .20681 L
.96425 .2066 L
.96977 .20645 L
.97474 .20634 L
.97947 .20626 L
.98491 .20619 L
.9899 .20614 L
.99514 .2061 L
1 .20608 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13039,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo00?ooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooo
oom5ooooo`001Ol00002ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Gooooo00?o
0000ooooooooool0oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo00Co
A4A4omgMgOoooooo00001_ooool3o`000?ooooooAOooool000Oooooo00Go0000oooooooooooooooo
o`00000;ooooo`04omgMgOmEEEGoooooo`0000Kooooo00?o0000ooooooooool0oooooom5ooooo`00
1oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001_ooool00ol0003o
ooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^ko
A4A4o`000006ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Gooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool5o`0000Gooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool00ol0003oooooooooo`3oooooodGooooo0005o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0oooooom5ooooo`001ooo
ool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01Oooool3o`000?oooooo
AOooool000Oooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Cooooo
00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Gooooo00?o0000oooooooo
ool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c005ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo027ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@0Iooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l00000
0ol@413oooooooooo`0Gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l0
00001Ol@413oooooooooooooooooA4A400;o000000?o<S8bomgMgOooool06?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM03Wooooo000Qoooo
o`;o00008_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01oooool00omgMgOo<S8booooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B47ooooo`03o`000?oooooooooo00Kooooo00?oMgMgoc8b<_ooool06?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@06_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1oooool00omgMgOo<S8booooo`0hooooo`008Oooool00ol0003oooooooooo`0Qooooo`05oa0@4?oo
ooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000oooooooo
ool05oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool06Oooool01Ol@
413ooooooooooooooooo410@00kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0G
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Kooooo`05oa0@4?oo
ooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo03Oooooo
000Qooooo`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`00
0?ooooooooooooooool000001oooool00omgMgOo<S8booooo`0Hooooo`05o`000?oooooooooooooo
ool000003_ooool00ol0003oooooooooo`0Iooooo`05o`000?ooooooooooooooool000003_ooool0
0ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo01Sooooo00Go0000ooooooooooooooooo`00
000=ooooo`03oiRHV?lQ8B7ok^k^01[ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool0>?ooool0027ooooo00?o0000ooooooooool08Ooo
ool01Ol0003ooooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000004ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`06Oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000
ooooooooool06Oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<01Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo01Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00iooooo`008Oooool00ol0003oooooooooo`0Qoooo
o`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00Cooooo00?o
0000ooooooooool06oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool0
6Oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Kooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`0Hoooo
o`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo03_ooooo000Qooooo`03o`000?oooooooooo027ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00ol0003oooooooooo`0Kooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`0Iooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01_ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41006_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo03_ooooo
000Qooooo`;o00008_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP04ooooo`Co00006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIV
I_l000006oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l000001Oooool4
o`0001[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
6_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004oooo
o`Co0000>_ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo>_ooool00ol@413o0000o`00
0003o`0000Gooooo000Qooooo`03o`000?oooooooooo0>Cooooo4ol00014ooooo`03o`000?oooooo
oooo00Kooooo000Qooooo`03o`000?oooooooooo0=[ooooo2_l0000Cooooo`Co0000@?ooool00ol0
003oooooooooo`06ooooo`008Oooooooo`0003?o00003?ooool00ol0003oooooooooo`06ooooo`00
8Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo000000Co00000oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00;ooooo2?l00007ooooo`03o`000?oooooooooo01Cooooo
00?o0000oc8b<_oMgMd01_ooool0027ooooo00?o0000ooooooooool0<?ooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0<?ooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo00Cooooo4_l0000Uooooo`;o000000CoZJVYob4Q8Ol0003o8B4Q
1?ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
1Ol00005ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo00?o0000oooooooo
ool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^
k^h01_ooool3o`000?ooooooAOooool000Oooooo00Go0000ooooooooooooooooo`00000=ooooo`03
oiRHV?lQ8B7ok^k^00Gooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol0003ooooo
oooooooooooo000000kooooo00?oMgMgofIVI_ooool01?ooool00ol0003oooooooooo`3oooooodGo
oooo0007ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41001Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Gooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
0_l0003oooooodKooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00?o
oooo00?o0000ooooooooool0oooooom5ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B47ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`00
1oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00005ooooo`?o0000oooooom5ooooo`00
1oooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00001_ooool00ol0
003oooooooooo`3oooooodGooooo0007ooooo`05o`000?ooooooooooooooool000002oooool01?oM
gMgoEEEEooooool00006ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Kooooo00?o0000ooooooooool0oooooom5
ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001_ooool0
0ol0003oooooooooo`3oooooodGooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool0
0omgMgOo0000ooooo`05ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Co
oooo00Gok^k^oc8b<_l0003o410@olc<c005ooooo`03o`000?oooooooooo0?ooooooAOooool000Oo
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So
8B4Q00Gooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go0000ooooooooooooooooo`000005ooooo`?o0000oooooom5ooooo`001oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@05ooooo`03o`00
0?oooooooooo0?ooooooAOooool000Oooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`00
0?mEEEGo0000oa0@4?o<c<`01Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05oa0@
4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`07ooooo`03o`000?oooooooooo0?oo
ooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Oo
oooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00co
oooo00Coc<c<odA4A?l0003o410@1Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01Oooool00ol0003oooooooooo`3oooooodGo
oooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?oo
ooooV9RHob4Q8@05ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go410@oooooooo
oooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`3o
ooooodGooooo0007ooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonH
V9So<S8b00Gooooo0ol0003oooooodGooooo0007ooooo`05o`000?ooooooooooooooool000002ooo
ool01Oo<c<co0000o`000?l0003oc<c<00Gooooo00?o0000ooooooooool0oooooom5ooooo`001ooo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4005ooooo`03
o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooookZj^_l000001Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Gooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o
0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
0_l0003oooooodKooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool001Sooooo
1?l000000ol@413oooooooooo`02ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003oooooooooo`04oooo
o`?o0000oooooom5ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`00
0?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006?ooool0
0omEEEGoIVIVo`00003oooooodkooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
002Nooooo`05oiRHV?l0003o0000odA4A?nj^[X06?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM08oooooo000Oooooo`04
oa0@4?l0003o0000o`0007_ooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00002Oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1oooool00omgMgOo<S8booooo`2>ooooo`008?ooool00ol0003oooooooooo`1kooooo`03o`000?oo
oooooooo01[ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo
00?o0000ooooooooool0SOooool0023ooooo00?o0000ooooooooool0Noooool00ol0003ooooooooo
o`0;ooooo`Ko00002Oooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`2>ooooo`008?ooool01_l0003oMgMgo`000?l0003oEEEEonk^kWSo
oooo00?o0000ooooooooool06_ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIV
I_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<08oooooo000Pooooo`06o`000?mEEEGok^k^
oooooomgMgOoEEEEM_ooool00ol@413o0000o`000003o`0001Wooooo00Go410@oooooooooooooooo
oa0@400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0TOooool0023ooooo00?o
0000onk^k_ooool00_ooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo01[ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003o
ooooooooo`2Aooooo`008?ooool00ol0003ok^k^ooooo`02ooooo`03o`000?oooooooooo07Kooooo
00?o0000ooooooooool06_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c004ooooo`Co0000T?ooool0023ooooo00Ko0000oeEEEOo^k^koooooogMgMomVIVKo
oooood?ooooo000Oooooo`03oa0@4?l0003oMgMg00;o000000?oIVIVonk^k_ooool0oooooom2oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.0332543, -0.540631, \
0.00122928, 0.00994506}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 3.33333 0.206011 0.412023 [
[.16667 .19351 -12 -9 ]
[.16667 .19351 12 0 ]
[.33333 .19351 -9 -9 ]
[.33333 .19351 9 0 ]
[.5 .19351 -12 -9 ]
[.5 .19351 12 0 ]
[.66667 .19351 -9 -9 ]
[.66667 .19351 9 0 ]
[.83333 .19351 -12 -9 ]
[.83333 .19351 12 0 ]
[1.025 .20601 0 -6 ]
[1.025 .20601 10 6 ]
[-0.0125 .0412 -24 -4.5 ]
[-0.0125 .0412 0 4.5 ]
[-0.0125 .12361 -24 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .28842 -18 -4.5 ]
[-0.0125 .28842 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .45322 -18 -4.5 ]
[-0.0125 .45322 0 4.5 ]
[-0.0125 .53563 -18 -4.5 ]
[-0.0125 .53563 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 .20601 m
.16667 .21226 L
s
[(0.05)] .16667 .19351 0 1 Mshowa
.33333 .20601 m
.33333 .21226 L
s
[(0.1)] .33333 .19351 0 1 Mshowa
.5 .20601 m
.5 .21226 L
s
[(0.15)] .5 .19351 0 1 Mshowa
.66667 .20601 m
.66667 .21226 L
s
[(0.2)] .66667 .19351 0 1 Mshowa
.83333 .20601 m
.83333 .21226 L
s
[(0.25)] .83333 .19351 0 1 Mshowa
.125 Mabswid
.03333 .20601 m
.03333 .20976 L
s
.06667 .20601 m
.06667 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.13333 .20601 m
.13333 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.23333 .20601 m
.23333 .20976 L
s
.26667 .20601 m
.26667 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.36667 .20601 m
.36667 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.43333 .20601 m
.43333 .20976 L
s
.46667 .20601 m
.46667 .20976 L
s
.53333 .20601 m
.53333 .20976 L
s
.56667 .20601 m
.56667 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.63333 .20601 m
.63333 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.73333 .20601 m
.73333 .20976 L
s
.76667 .20601 m
.76667 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.86667 .20601 m
.86667 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.93333 .20601 m
.93333 .20976 L
s
.96667 .20601 m
.96667 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
gsave
1.025 .20601 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .0412 m
.00625 .0412 L
s
[(-0.4)] -0.0125 .0412 1 0 Mshowa
0 .12361 m
.00625 .12361 L
s
[(-0.2)] -0.0125 .12361 1 0 Mshowa
0 .28842 m
.00625 .28842 L
s
[(0.2)] -0.0125 .28842 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.4)] -0.0125 .37082 1 0 Mshowa
0 .45322 m
.00625 .45322 L
s
[(0.6)] -0.0125 .45322 1 0 Mshowa
0 .53563 m
.00625 .53563 L
s
[(0.8)] -0.0125 .53563 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .10301 m
.00375 .10301 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .30902 m
.00375 .30902 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .39142 m
.00375 .39142 L
s
0 .41202 m
.00375 .41202 L
s
0 .43262 m
.00375 .43262 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .51503 m
.00375 .51503 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
0 .0206 m
.00375 .0206 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.26) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .20601 m
.00123 .20601 L
.00236 .20601 L
.00365 .20601 L
.00488 .20601 L
.00601 .20601 L
.00706 .20601 L
.00821 .20601 L
.00942 .20601 L
.01065 .20601 L
.01196 .20601 L
.0132 .20601 L
.01434 .20601 L
.01566 .20601 L
.01641 .20601 L
.01711 .20601 L
.01839 .20601 L
.01975 .20601 L
.02043 .20601 L
.02115 .20601 L
.02245 .20601 L
.02317 .20601 L
.02384 .20601 L
.02458 .20601 L
.02537 .20601 L
.02605 .20601 L
.02679 .20601 L
.02814 .20601 L
.02945 .20601 L
.03067 .20601 L
.03184 .20601 L
.03295 .20601 L
.03416 .20601 L
.03547 .20601 L
.03676 .20601 L
.03813 .20601 L
.03929 .20601 L
.04057 .20601 L
.04131 .20601 L
.042 .20601 L
.04275 .20601 L
.04355 .20601 L
.0449 .20601 L
.04566 .20601 L
.04637 .20601 L
.0477 .20601 L
.04892 .20601 L
.04959 .20601 L
.05032 .20601 L
.05165 .20601 L
Mistroke
.05245 .20601 L
.05321 .20601 L
.05389 .20601 L
.05462 .20601 L
.05543 .20601 L
.05627 .20601 L
.057 .20601 L
.05779 .20601 L
.05854 .20601 L
.05921 .20601 L
.06 .20601 L
.06074 .20601 L
.06205 .20601 L
.0628 .20601 L
.06349 .20601 L
.06471 .20601 L
.06603 .20601 L
.06727 .20601 L
.06841 .20601 L
.06967 .20601 L
.07105 .20601 L
.07175 .20601 L
.07249 .20601 L
.07383 .20601 L
.07457 .20601 L
.07525 .20601 L
.076 .20601 L
.07679 .20601 L
.07812 .20601 L
.07888 .20601 L
.07959 .20601 L
.0809 .20601 L
.08211 .20601 L
.08349 .20601 L
.08481 .20601 L
.086 .20601 L
.08729 .20601 L
.0885 .20601 L
.08962 .20601 L
.09085 .20601 L
.0922 .20601 L
.09289 .20601 L
.09361 .20601 L
.09493 .20601 L
.09565 .20601 L
.09632 .20601 L
.09705 .20601 L
.09783 .20601 L
.09913 .20601 L
.09987 .20601 L
Mistroke
.10056 .20601 L
.10185 .20601 L
.10303 .20601 L
.10439 .20601 L
.10569 .20601 L
.10691 .20601 L
.10801 .20601 L
.10928 .20601 L
.11048 .20601 L
.1116 .20601 L
.11262 .20601 L
.11375 .20601 L
.11493 .20601 L
.11613 .20601 L
.11742 .20601 L
.11864 .20601 L
.11974 .20601 L
.12104 .20601 L
.12178 .20601 L
.12245 .20601 L
.1237 .20601 L
.12502 .20601 L
.12622 .20601 L
.12753 .20601 L
.12889 .20601 L
.13016 .20601 L
.13135 .20601 L
.13244 .20601 L
.13369 .20601 L
.13487 .20601 L
.13616 .20601 L
.13752 .20601 L
.13868 .20601 L
.13996 .20601 L
.14134 .20601 L
.14211 .20601 L
.14281 .20601 L
.14418 .20601 L
.14548 .20601 L
.14669 .20601 L
.14779 .20601 L
.14906 .20601 L
.15025 .20601 L
.15136 .20601 L
.15237 .20601 L
.15349 .20601 L
.15467 .20601 L
.15586 .20601 L
.15714 .20601 L
.15835 .20601 L
Mistroke
.15945 .20601 L
.16074 .20601 L
.16146 .20601 L
.16214 .20601 L
.16337 .20601 L
.16468 .20601 L
.16594 .20601 L
.16732 .20601 L
.16863 .20601 L
.16984 .20601 L
.17103 .20601 L
.17212 .20601 L
.17337 .20601 L
.17456 .20601 L
.17585 .20601 L
.17721 .20601 L
.17838 .20601 L
.17966 .20601 L
.18104 .20601 L
.18181 .20601 L
.18251 .20601 L
.18388 .20601 L
.18518 .20601 L
.18628 .20601 L
.1875 .20601 L
.18877 .20601 L
.18996 .20601 L
.19107 .20601 L
.19209 .20601 L
.19321 .20601 L
.19438 .20601 L
.19558 .20601 L
.19686 .20601 L
.19807 .20601 L
.19916 .20601 L
.20045 .20601 L
.20118 .20601 L
.20185 .20601 L
.20309 .20601 L
.20439 .20601 L
.20566 .20601 L
.20705 .20601 L
.20835 .20601 L
.20957 .20601 L
.21077 .20601 L
.21186 .20601 L
.21311 .20601 L
.2143 .20601 L
.21559 .20601 L
.21696 .20601 L
Mistroke
.21813 .20601 L
.21941 .20601 L
.22079 .20601 L
.22157 .20601 L
.22227 .20601 L
.22364 .20601 L
.22494 .20601 L
.22604 .20601 L
.22726 .20601 L
.22853 .20601 L
.22973 .20601 L
.23084 .20601 L
.23186 .20601 L
.23297 .20601 L
.23415 .20601 L
.23535 .20601 L
.23663 .20601 L
.23784 .20601 L
.23893 .20601 L
.24023 .20601 L
.24095 .20601 L
.24163 .20601 L
.24286 .20601 L
.24416 .20601 L
.24544 .20601 L
.24683 .20601 L
.24814 .20601 L
.24935 .20601 L
.25044 .20601 L
.25165 .20601 L
.25291 .20601 L
.25409 .20601 L
.25539 .20601 L
.25676 .20601 L
.25793 .20601 L
.25922 .20601 L
.2606 .20601 L
.26137 .20601 L
.26208 .20601 L
.26345 .20601 L
.26475 .20601 L
.26586 .20601 L
.26708 .20601 L
.26835 .20601 L
.26954 .20601 L
.27066 .20601 L
.27168 .20601 L
.27286 .20601 L
.27397 .20601 L
.27518 .20601 L
Mistroke
.27646 .20601 L
.27767 .20601 L
.27876 .20601 L
.28005 .20601 L
.28145 .20601 L
.28277 .20601 L
.28399 .20601 L
.28531 .20601 L
.28657 .20601 L
.2877 .20601 L
.28892 .20601 L
.29025 .20601 L
.29167 .20601 L
.29288 .20601 L
.29421 .20601 L
.29545 .20601 L
.29658 .20601 L
.29783 .20601 L
.29914 .20601 L
.30028 .20601 L
.30134 .20601 L
.30251 .20601 L
.30376 .20601 L
.30522 .20601 L
.30656 .20601 L
.30804 .20601 L
.30879 .20601 L
.30961 .20601 L
.31098 .20601 L
.31246 .20601 L
.31385 .20601 L
.31513 .20601 L
.31644 .20601 L
.31766 .20601 L
.319 .20601 L
.32043 .20601 L
.32179 .20601 L
.32307 .20601 L
.32422 .20601 L
.32546 .20601 L
.32677 .20601 L
.32796 .20601 L
.32934 .20601 L
.33064 .20601 L
.33184 .20601 L
.33295 .20601 L
.33417 .20601 L
.33547 .20601 L
.33676 .20601 L
.33816 .20601 L
Mistroke
.33948 .20601 L
.34069 .20601 L
.3421 .20601 L
.34363 .20601 L
.34509 .20601 L
.34644 .20601 L
.34783 .20601 L
.34933 .20601 L
.35075 .20601 L
.35205 .20601 L
.35323 .20601 L
.35453 .20601 L
.35588 .20601 L
.35715 .20601 L
.35863 .20601 L
.36003 .20601 L
.36129 .20601 L
.36266 .20601 L
.36415 .20601 L
.36573 .20601 L
.36708 .20601 L
.36857 .20601 L
.36985 .20601 L
.37103 .20601 L
.37234 .20601 L
.37373 .20601 L
.37519 .20601 L
.37657 .20601 L
.37781 .20601 L
.37916 .20601 L
.38032 .20601 L
.38161 .20601 L
.38295 .20601 L
.38421 .20601 L
.38538 .20601 L
.38645 .20601 L
.38769 .20601 L
.38887 .20601 L
.39025 .20601 L
.3915 .20601 L
.39294 .20601 L
.3943 .20601 L
.39556 .20601 L
.39672 .20601 L
.39799 .20601 L
.39934 .20601 L
.4007 .20601 L
.40216 .20601 L
.40353 .20601 L
.40479 .20601 L
Mistroke
.40626 .20601 L
.40785 .20601 L
.40936 .20601 L
.41076 .20601 L
.412 .20601 L
.4133 .20601 L
.41442 .20601 L
.41563 .20601 L
.41695 .20601 L
.41835 .20601 L
.41968 .20601 L
.42088 .20601 L
.42323 .20601 L
.42455 .20601 L
.42577 .20601 L
.42801 .20601 L
.42914 .20601 L
.43038 .20601 L
.43183 .20601 L
.4332 .20601 L
.43443 .20601 L
.43577 .20601 L
.43723 .20601 L
.43878 .20601 L
.44024 .20601 L
.44156 .20601 L
.44291 .20601 L
.44415 .20601 L
.44552 .20601 L
.44695 .20601 L
.4482 .20601 L
.44937 .20601 L
.45202 .20601 L
.45335 .20601 L
.45476 .20601 L
.45597 .20601 L
.4573 .20601 L
.45873 .20601 L
.46026 .20601 L
.46171 .20601 L
.46304 .20601 L
.46559 .20601 L
.46703 .20601 L
.46838 .20601 L
.47083 .20601 L
.47221 .20601 L
.47345 .20601 L
.47467 .20601 L
.47596 .20601 L
.47828 .20601 L
Mistroke
.47956 .20601 L
.48076 .20601 L
.48217 .20601 L
.48349 .20601 L
.48464 .20601 L
.48588 .20601 L
.48806 .20601 L
.48929 .20601 L
.4906 .20601 L
.49296 .20601 L
.49415 .20601 L
.49546 .20601 L
.49673 .20601 L
.49809 .20601 L
.49936 .20601 L
.50052 .20601 L
.50279 .20601 L
.50415 .20601 L
.50541 .20601 L
.50676 .20601 L
.50825 .20601 L
.51075 .20601 L
.51212 .20601 L
.5134 .20601 L
.51458 .20601 L
.51588 .20601 L
.51823 .20601 L
.52052 .20601 L
.52265 .20601 L
.52518 .20601 L
.52746 .20601 L
.52873 .20601 L
.5301 .20601 L
.53259 .20601 L
.5339 .20601 L
.53509 .20601 L
.53637 .20601 L
.53777 .20601 L
.54025 .20601 L
.54259 .20601 L
.54391 .20601 L
.54536 .20601 L
.54677 .20601 L
.54829 .20601 L
.54971 .20601 L
.55101 .20601 L
.55356 .20601 L
.55623 .20601 L
.55872 .20601 L
.56144 .20601 L
Mistroke
.56297 .20601 L
.56435 .20601 L
.56715 .20601 L
.56873 .20601 L
.57019 .20601 L
.57286 .20601 L
.57569 .20601 L
.57836 .20601 L
.58089 .20601 L
.58315 .20601 L
.58563 .20601 L
.58831 .20601 L
.59116 .20601 L
.59359 .20601 L
.59628 .20601 L
.59877 .20601 L
.60105 .20601 L
.60356 .20601 L
.6062 .20601 L
.60851 .20601 L
.61065 .20601 L
.61301 .20601 L
.61552 .20601 L
.61823 .20601 L
.62111 .20601 L
.62356 .20601 L
.62626 .20601 L
.62916 .20601 L
.63227 .20601 L
.63522 .20601 L
.63791 .20601 L
.6406 .20601 L
.64309 .20601 L
.64583 .20601 L
.64875 .20601 L
.65154 .20601 L
.65416 .20601 L
.65669 .20601 L
.65906 .20601 L
.66395 .20601 L
.66654 .206 L
.66932 .206 L
.67223 .206 L
.67499 .206 L
.67749 .20599 L
.68015 .20599 L
.68498 .20598 L
.68945 .20597 L
.69425 .20595 L
.69955 .20592 L
Mistroke
.70472 .20588 L
.71016 .20583 L
.7148 .20577 L
.71988 .20568 L
.72537 .20556 L
.73123 .2054 L
.74178 .20497 L
.74738 .20467 L
.75254 .20434 L
.76421 .20341 L
.78537 .20119 L
.79488 .20018 L
.80011 .19969 L
.80508 .1993 L
.80788 .19912 L
.80936 .19904 L
.81094 .19897 L
.81239 .19892 L
.81371 .19888 L
.81504 .19885 L
.81628 .19883 L
.81756 .19882 L
.81891 .19882 L
.82006 .19883 L
.82132 .19885 L
.82268 .19888 L
.82414 .19893 L
.82676 .19906 L
.82946 .19924 L
.83233 .19949 L
.83748 .20008 L
.84301 .20091 L
.84912 .20204 L
.87026 .20686 L
.8807 .20915 L
.89063 .21088 L
.8961 .21158 L
.89919 .21188 L
.90207 .21211 L
.90473 .21227 L
.90714 .21237 L
.90847 .21241 L
.90923 .21243 L
.90992 .21244 L
.9112 .21246 L
.91254 .21246 L
.91382 .21246 L
.91454 .21245 L
.91521 .21244 L
.91644 .21242 L
Mistroke
.91774 .21239 L
.92 .21231 L
.92249 .2122 L
.92798 .21185 L
.93315 .21144 L
.9524 .20956 L
.97217 .20784 L
.98212 .20722 L
.993 .20673 L
1 .20651 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13039,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo00?ooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooo
oom5ooooo`001Ol00002ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Gooooo00?o
0000ooooooooool0oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo00Co
A4A4omgMgOoooooo00001_ooool3o`000?ooooooAOooool000Oooooo00Go0000oooooooooooooooo
o`00000;ooooo`04omgMgOmEEEGoooooo`0000Kooooo00?o0000ooooooooool0oooooom5ooooo`00
1oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001_ooool00ol0003o
ooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^ko
A4A4o`000006ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Gooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool5o`0000Gooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool00ol0003oooooooooo`3oooooodGooooo0005o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0oooooom5ooooo`001ooo
ool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01Oooool3o`000?oooooo
AOooool000Oooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Cooooo
00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Gooooo00?o0000oooooooo
ool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c005ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo027ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@0Iooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l00000
0ol@413oooooooooo`0Gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l0
00001Ol@413oooooooooooooooooA4A400;o000000?o<S8bomgMgOooool06?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM03Wooooo000Qoooo
o`;o00008_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01oooool00omgMgOo<S8booooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B47ooooo`03o`000?oooooooooo00Kooooo00?oMgMgoc8b<_ooool06?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@06_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1oooool00omgMgOo<S8booooo`0hooooo`008Oooool00ol0003oooooooooo`0Qooooo`05oa0@4?oo
ooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000oooooooo
ool05oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool06Oooool01Ol@
413ooooooooooooooooo410@00kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0G
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Kooooo`05oa0@4?oo
ooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo03Oooooo
000Qooooo`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`00
0?ooooooooooooooool000001oooool00omgMgOo<S8booooo`0Hooooo`05o`000?oooooooooooooo
ool000003_ooool00ol0003oooooooooo`0Iooooo`05o`000?ooooooooooooooool000003_ooool0
0ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo01Sooooo00Go0000ooooooooooooooooo`00
000=ooooo`03oiRHV?lQ8B7ok^k^01[ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool0>?ooool0027ooooo00?o0000ooooooooool08Ooo
ool01Ol0003ooooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000004ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`06Oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000
ooooooooool06Oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<01Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo01Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00iooooo`008Oooool00ol0003oooooooooo`0Qoooo
o`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00Cooooo00?o
0000ooooooooool06oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool0
6Oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Kooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`0Hoooo
o`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo03_ooooo000Qooooo`03o`000?oooooooooo027ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00ol0003oooooooooo`0Kooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`0Iooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01_ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41006_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo03_ooooo
000Qooooo`;o00008_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP04ooooo`Co00006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIV
I_l000006oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l000001Oooool4
o`0001[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
6_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004oooo
o`Co0000>_ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo>_ooool00ol@413o0000o`00
0003o`0000Gooooo000Qooooo`03o`000?oooooooooo0>oooooo3ol0000mooooo`03o`000?oooooo
oooo00Kooooo000Qooooo`03o`000?oooooooooo0>Gooooo2_l0000?ooooo`Oo0000=_ooool00ol0
003oooooooooo`06ooooo`008Oooooooo`0003?o00003?ooool00ol0003oooooooooo`06ooooo`00
8Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo
oooo0ol00003ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02ol0000Cooooo`03
o`000?lb<S;ogMgM00Kooooo000Qooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`0>oooooa3o00007Oooool2o`000004ojVYZOlQ8B7o0000ob4Q8@Co
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go
00001Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`03o`000?oooooooooo
0?ooooooAOooool000Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^
00Kooooo0ol0003oooooodGooooo0007ooooo`05o`000?ooooooooooooooool000003Oooool00onH
V9So8B4Qonk^kP05ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go0000oooooooo
ooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Cooooo00?o0000ooooooooool0oooooom5oooo
o`001oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@00Gooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c005ooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o
0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
0_l0003oooooodKooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`03oooo
o`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool000Oo
oooo00Go410@oooooooooooooooooa0@400;ooooo`Go00001Oooool3o`000?ooooooAOooool000Oo
oooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Kooooo00?o0000
ooooooooool0oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgM
oeEEEOoooooo00001_ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00omgMgOoc<c<o`000006ooooo`03o`000?oooooooooo0?ooooooAOoo
ool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Kooooo00?o
0000ooooooooool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?o
MgMgo`000?ooool01Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`05onk^k_lb<S;o0000oa0@4?o<c<`01Oooool00ol0003oooooooooo`3oooooodGooooo0007oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q
8@05ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go410@oooooooooooooooooa0@
400;ooooo`05o`000?ooooooooooooooool000001Oooool3o`000?ooooooAOooool000Oooooo00Go
0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401Oooool00ol0003o
ooooooooo`3oooooodGooooo0007ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003o
EEEEo`000?l@413oc<c<00Gooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413o
oooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool01oooool00ol0003oooooooooo`3ooooo
odGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV007oooo
o`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<oooo
o`04olc<c?m4A4Co0000oa0@40Gooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Gooooo00?o0000ooooooooool0oooooom5oooo
o`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B401Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0oooo
oom5ooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RH
oc8b<P05ooooo`?o0000oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo
00Goc<c<o`000?l0003o0000olc<c005ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo
00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@41001Oooool00ol0
003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[Zjoooooonj^[[o000000Gooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@05ooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool2o`00
0?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o
0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
0_l0003oooooodKooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Hooooo`Co
000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000ooooooooool01?ooool3
o`000?ooooooAOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003o
ooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001Sooooo00?o
EEEEofIVI_l00000oooooom>ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
W_ooool01OnHV9So0000o`000?m4A4Co^[Zj01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000?ooooo00Gok^k^oc8b<_l0003o410@olc<c02@ooooo`007oooool01?l@
413o0000o`000?l0001kooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000Wooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?o
oooo00GoEEEEogMgMoooooooV9RHob4Q8@2@ooooo`008?ooool00ol0003oooooooooo`1kooooo`03
o`000?oooooooooo01[ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^
00Cooooo00Go0000ooooooooooooooooo`00002@ooooo`008?ooool00ol0003oooooooooo`1koooo
o`03o`000?oooooooooo00_ooooo1_l00009ooooo`05o`000?ooooooooooooooool000003Oooool0
0onHV9So8B4Qonk^kP03ooooo`05o`000?nHV9SooooooiRHV?lQ8B40T?ooool0023ooooo00Ko0000
ogMgMol0003o0000oeEEEOo^k^ihooooo`03o`000?oooooooooo01[ooooo00Go0000oooooooooooo
ooooo`00000>ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000oeEEEOl0003o410@olc<c02@oooo
o`008?ooool01_l0003oEEEEonk^k_ooooooMgMgoeEEEGKooooo00?o410@o`000?l000000ol0000I
ooooo`05oa0@4?ooooooooooooooool@41003oooool01_l0003oooooooooooooooooEEEEohN7Qi?o
oooo000Pooooo`03o`000?o^k^kooooo00;ooooo00?o0000ooooooooool0M_ooool00ol0003ooooo
ooooo`0Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@
00?ooooo00?ogMgMoa0@4?nHV9P0T_ooool0023ooooo00?o0000onk^k_ooool00_ooool00ol0003o
ooooooooo`1fooooo`03o`000?oooooooooo01[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;oooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool01?o<c<coA4A4o`000?l@412@ooooo`008?ooool0
1_l0003oEEEEonk^k_ooooooMgMgofIVI_oooooo@oooool001oooooo00?o410@o`000?mgMgL00_l0
00000omVIVKok^k^ooooo`3ooooood;ooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.0332543, -0.540631, \
0.00122928, 0.00994506}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 3.33333 0.206011 0.412023 [
[.16667 .19351 -12 -9 ]
[.16667 .19351 12 0 ]
[.33333 .19351 -9 -9 ]
[.33333 .19351 9 0 ]
[.5 .19351 -12 -9 ]
[.5 .19351 12 0 ]
[.66667 .19351 -9 -9 ]
[.66667 .19351 9 0 ]
[.83333 .19351 -12 -9 ]
[.83333 .19351 12 0 ]
[1.025 .20601 0 -6 ]
[1.025 .20601 10 6 ]
[-0.0125 .0412 -24 -4.5 ]
[-0.0125 .0412 0 4.5 ]
[-0.0125 .12361 -24 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .28842 -18 -4.5 ]
[-0.0125 .28842 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .45322 -18 -4.5 ]
[-0.0125 .45322 0 4.5 ]
[-0.0125 .53563 -18 -4.5 ]
[-0.0125 .53563 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 .20601 m
.16667 .21226 L
s
[(0.05)] .16667 .19351 0 1 Mshowa
.33333 .20601 m
.33333 .21226 L
s
[(0.1)] .33333 .19351 0 1 Mshowa
.5 .20601 m
.5 .21226 L
s
[(0.15)] .5 .19351 0 1 Mshowa
.66667 .20601 m
.66667 .21226 L
s
[(0.2)] .66667 .19351 0 1 Mshowa
.83333 .20601 m
.83333 .21226 L
s
[(0.25)] .83333 .19351 0 1 Mshowa
.125 Mabswid
.03333 .20601 m
.03333 .20976 L
s
.06667 .20601 m
.06667 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.13333 .20601 m
.13333 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.23333 .20601 m
.23333 .20976 L
s
.26667 .20601 m
.26667 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.36667 .20601 m
.36667 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.43333 .20601 m
.43333 .20976 L
s
.46667 .20601 m
.46667 .20976 L
s
.53333 .20601 m
.53333 .20976 L
s
.56667 .20601 m
.56667 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.63333 .20601 m
.63333 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.73333 .20601 m
.73333 .20976 L
s
.76667 .20601 m
.76667 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.86667 .20601 m
.86667 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.93333 .20601 m
.93333 .20976 L
s
.96667 .20601 m
.96667 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
gsave
1.025 .20601 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .0412 m
.00625 .0412 L
s
[(-0.4)] -0.0125 .0412 1 0 Mshowa
0 .12361 m
.00625 .12361 L
s
[(-0.2)] -0.0125 .12361 1 0 Mshowa
0 .28842 m
.00625 .28842 L
s
[(0.2)] -0.0125 .28842 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.4)] -0.0125 .37082 1 0 Mshowa
0 .45322 m
.00625 .45322 L
s
[(0.6)] -0.0125 .45322 1 0 Mshowa
0 .53563 m
.00625 .53563 L
s
[(0.8)] -0.0125 .53563 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .10301 m
.00375 .10301 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .30902 m
.00375 .30902 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .39142 m
.00375 .39142 L
s
0 .41202 m
.00375 .41202 L
s
0 .43262 m
.00375 .43262 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .51503 m
.00375 .51503 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
0 .0206 m
.00375 .0206 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.27) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .20601 m
.00123 .20601 L
.00236 .20601 L
.00365 .20601 L
.00488 .20601 L
.00601 .20601 L
.00706 .20601 L
.00821 .20601 L
.00942 .20601 L
.01065 .20601 L
.01196 .20601 L
.0132 .20601 L
.01434 .20601 L
.01566 .20601 L
.01641 .20601 L
.01711 .20601 L
.01839 .20601 L
.01975 .20601 L
.02043 .20601 L
.02115 .20601 L
.02245 .20601 L
.02317 .20601 L
.02384 .20601 L
.02458 .20601 L
.02537 .20601 L
.02605 .20601 L
.02679 .20601 L
.02814 .20601 L
.02945 .20601 L
.03067 .20601 L
.03184 .20601 L
.03295 .20601 L
.03416 .20601 L
.03547 .20601 L
.03676 .20601 L
.03813 .20601 L
.03929 .20601 L
.04057 .20601 L
.04131 .20601 L
.042 .20601 L
.04275 .20601 L
.04355 .20601 L
.0449 .20601 L
.04566 .20601 L
.04637 .20601 L
.0477 .20601 L
.04892 .20601 L
.04959 .20601 L
.05032 .20601 L
.05165 .20601 L
Mistroke
.05245 .20601 L
.05321 .20601 L
.05389 .20601 L
.05462 .20601 L
.05543 .20601 L
.05627 .20601 L
.057 .20601 L
.05779 .20601 L
.05854 .20601 L
.05921 .20601 L
.06 .20601 L
.06074 .20601 L
.06205 .20601 L
.0628 .20601 L
.06349 .20601 L
.06471 .20601 L
.06603 .20601 L
.06727 .20601 L
.06841 .20601 L
.06967 .20601 L
.07105 .20601 L
.07175 .20601 L
.07249 .20601 L
.07383 .20601 L
.07457 .20601 L
.07525 .20601 L
.076 .20601 L
.07679 .20601 L
.07812 .20601 L
.07888 .20601 L
.07959 .20601 L
.0809 .20601 L
.08211 .20601 L
.08349 .20601 L
.08481 .20601 L
.086 .20601 L
.08729 .20601 L
.0885 .20601 L
.08962 .20601 L
.09085 .20601 L
.0922 .20601 L
.09289 .20601 L
.09361 .20601 L
.09493 .20601 L
.09565 .20601 L
.09632 .20601 L
.09705 .20601 L
.09783 .20601 L
.09913 .20601 L
.09987 .20601 L
Mistroke
.10056 .20601 L
.10185 .20601 L
.10303 .20601 L
.10439 .20601 L
.10569 .20601 L
.10691 .20601 L
.10801 .20601 L
.10928 .20601 L
.11048 .20601 L
.1116 .20601 L
.11262 .20601 L
.11375 .20601 L
.11493 .20601 L
.11613 .20601 L
.11742 .20601 L
.11864 .20601 L
.11974 .20601 L
.12104 .20601 L
.12178 .20601 L
.12245 .20601 L
.1237 .20601 L
.12502 .20601 L
.12622 .20601 L
.12753 .20601 L
.12889 .20601 L
.13016 .20601 L
.13135 .20601 L
.13244 .20601 L
.13369 .20601 L
.13487 .20601 L
.13616 .20601 L
.13752 .20601 L
.13868 .20601 L
.13996 .20601 L
.14134 .20601 L
.14211 .20601 L
.14281 .20601 L
.14418 .20601 L
.14548 .20601 L
.14669 .20601 L
.14779 .20601 L
.14906 .20601 L
.15025 .20601 L
.15136 .20601 L
.15237 .20601 L
.15349 .20601 L
.15467 .20601 L
.15586 .20601 L
.15714 .20601 L
.15835 .20601 L
Mistroke
.15945 .20601 L
.16074 .20601 L
.16146 .20601 L
.16214 .20601 L
.16337 .20601 L
.16468 .20601 L
.16594 .20601 L
.16732 .20601 L
.16863 .20601 L
.16984 .20601 L
.17103 .20601 L
.17212 .20601 L
.17337 .20601 L
.17456 .20601 L
.17585 .20601 L
.17721 .20601 L
.17838 .20601 L
.17966 .20601 L
.18104 .20601 L
.18181 .20601 L
.18251 .20601 L
.18388 .20601 L
.18518 .20601 L
.18628 .20601 L
.1875 .20601 L
.18877 .20601 L
.18996 .20601 L
.19107 .20601 L
.19209 .20601 L
.19321 .20601 L
.19438 .20601 L
.19558 .20601 L
.19686 .20601 L
.19807 .20601 L
.19916 .20601 L
.20045 .20601 L
.20118 .20601 L
.20185 .20601 L
.20309 .20601 L
.20439 .20601 L
.20566 .20601 L
.20705 .20601 L
.20835 .20601 L
.20957 .20601 L
.21077 .20601 L
.21186 .20601 L
.21311 .20601 L
.2143 .20601 L
.21559 .20601 L
.21696 .20601 L
Mistroke
.21813 .20601 L
.21941 .20601 L
.22079 .20601 L
.22157 .20601 L
.22227 .20601 L
.22364 .20601 L
.22494 .20601 L
.22604 .20601 L
.22726 .20601 L
.22853 .20601 L
.22973 .20601 L
.23084 .20601 L
.23186 .20601 L
.23297 .20601 L
.23415 .20601 L
.23535 .20601 L
.23663 .20601 L
.23784 .20601 L
.23893 .20601 L
.24023 .20601 L
.24095 .20601 L
.24163 .20601 L
.24286 .20601 L
.24416 .20601 L
.24544 .20601 L
.24683 .20601 L
.24814 .20601 L
.24935 .20601 L
.25044 .20601 L
.25165 .20601 L
.25291 .20601 L
.25409 .20601 L
.25539 .20601 L
.25676 .20601 L
.25793 .20601 L
.25922 .20601 L
.2606 .20601 L
.26137 .20601 L
.26208 .20601 L
.26345 .20601 L
.26475 .20601 L
.26586 .20601 L
.26708 .20601 L
.26835 .20601 L
.26954 .20601 L
.27066 .20601 L
.27168 .20601 L
.27286 .20601 L
.27397 .20601 L
.27518 .20601 L
Mistroke
.27646 .20601 L
.27767 .20601 L
.27876 .20601 L
.28005 .20601 L
.28078 .20601 L
.28145 .20601 L
.28268 .20601 L
.28399 .20601 L
.28527 .20601 L
.28599 .20601 L
.28666 .20601 L
.28789 .20601 L
.28919 .20601 L
.29036 .20601 L
.29145 .20601 L
.29265 .20601 L
.29394 .20601 L
.29524 .20601 L
.29597 .20601 L
.29665 .20601 L
.29803 .20601 L
.29881 .20601 L
.29951 .20601 L
.30077 .20601 L
.30213 .20601 L
.30342 .20601 L
.30461 .20601 L
.30572 .20601 L
.30691 .20601 L
.30804 .20601 L
.30907 .20601 L
.31027 .20601 L
.31158 .20601 L
.31282 .20601 L
.31396 .20601 L
.31526 .20601 L
.31648 .20601 L
.31758 .20601 L
.31876 .20601 L
.32005 .20601 L
.32142 .20601 L
.32259 .20601 L
.32386 .20601 L
.32524 .20601 L
.32651 .20601 L
.32791 .20601 L
.32861 .20601 L
.32939 .20601 L
.33069 .20601 L
.33208 .20601 L
Mistroke
.3334 .20601 L
.33461 .20601 L
.33585 .20601 L
.33701 .20601 L
.33828 .20601 L
.33963 .20601 L
.34091 .20601 L
.34213 .20601 L
.34322 .20601 L
.3444 .20601 L
.34577 .20601 L
.34705 .20601 L
.34845 .20601 L
.34924 .20601 L
.34996 .20601 L
.3514 .20601 L
.35222 .20601 L
.35298 .20601 L
.35436 .20601 L
.35584 .20601 L
.35708 .20601 L
.35842 .20601 L
.35968 .20601 L
.36084 .20601 L
.36213 .20601 L
.36354 .20601 L
.36501 .20601 L
.36637 .20601 L
.36771 .20601 L
.36913 .20601 L
.37034 .20601 L
.37167 .20601 L
.3731 .20601 L
.37463 .20601 L
.37608 .20601 L
.37741 .20601 L
.37873 .20601 L
.37997 .20601 L
.38132 .20601 L
.38275 .20601 L
.38413 .20601 L
.38542 .20601 L
.38658 .20601 L
.38783 .20601 L
.38905 .20601 L
.39019 .20601 L
.39144 .20601 L
.39278 .20601 L
.39418 .20601 L
.39551 .20601 L
Mistroke
.3967 .20601 L
.398 .20601 L
.39912 .20601 L
.40035 .20601 L
.40164 .20601 L
.40285 .20601 L
.40398 .20601 L
.40502 .20601 L
.40615 .20601 L
.40734 .20601 L
.40864 .20601 L
.41005 .20601 L
.41138 .20601 L
.4126 .20601 L
.41371 .20601 L
.41493 .20601 L
.41619 .20601 L
.41738 .20601 L
.41877 .20601 L
.42008 .20601 L
.42126 .20601 L
.42255 .20601 L
.42394 .20601 L
.42543 .20601 L
.42683 .20601 L
.42809 .20601 L
.42931 .20601 L
.43059 .20601 L
.43168 .20601 L
.43288 .20601 L
.43417 .20601 L
.43555 .20601 L
.43685 .20601 L
.43804 .20601 L
.43924 .20601 L
.44034 .20601 L
.44156 .20601 L
.44284 .20601 L
.44501 .20601 L
.44624 .20601 L
.44739 .20601 L
.44869 .20601 L
.45009 .20601 L
.4514 .20601 L
.4526 .20601 L
.454 .20601 L
.45552 .20601 L
.45696 .20601 L
.45828 .20601 L
.45953 .20601 L
Mistroke
.46068 .20601 L
.46196 .20601 L
.46332 .20601 L
.46475 .20601 L
.4661 .20601 L
.46732 .20601 L
.46864 .20601 L
.47097 .20601 L
.4723 .20601 L
.47354 .20601 L
.47485 .20601 L
.47605 .20601 L
.47736 .20601 L
.47875 .20601 L
.47986 .20601 L
.48106 .20601 L
.48321 .20601 L
.48453 .20601 L
.48577 .20601 L
.48809 .20601 L
.4893 .20601 L
.4906 .20601 L
.49295 .20601 L
.49438 .20601 L
.49575 .20601 L
.4983 .20601 L
.4996 .20601 L
.50098 .20601 L
.50347 .20601 L
.50499 .20601 L
.50642 .20601 L
.50771 .20601 L
.5091 .20601 L
.51145 .20601 L
.51278 .20601 L
.51402 .20601 L
.51652 .20601 L
.51792 .20601 L
.5192 .20601 L
.52148 .20601 L
.52277 .20601 L
.52397 .20601 L
.52616 .20601 L
.52726 .20601 L
.52848 .20601 L
.53095 .20601 L
.53235 .20601 L
.53366 .20601 L
.53629 .20601 L
.53776 .20601 L
Mistroke
.5391 .20601 L
.5415 .20601 L
.54286 .20601 L
.54411 .20601 L
.5464 .20601 L
.54756 .20601 L
.54883 .20601 L
.55029 .20601 L
.55169 .20601 L
.55429 .20601 L
.55575 .20601 L
.5571 .20601 L
.55868 .20601 L
.56016 .20601 L
.56259 .20601 L
.56389 .20601 L
.56529 .20601 L
.56667 .20601 L
.56813 .20601 L
.57074 .20601 L
.57203 .20601 L
.57343 .20601 L
.57598 .20601 L
.57846 .20601 L
.58074 .20601 L
.58322 .20601 L
.58594 .20601 L
.58731 .20601 L
.58878 .20601 L
.59144 .20601 L
.59391 .20601 L
.5966 .20601 L
.59915 .20601 L
.60151 .20601 L
.60385 .20601 L
.60597 .20601 L
.60841 .20601 L
.61072 .20601 L
.61325 .20601 L
.61561 .20601 L
.6182 .20601 L
.62098 .20601 L
.62389 .20601 L
.62664 .20601 L
.62912 .20601 L
.63181 .20601 L
.63413 .20601 L
.6367 .20601 L
.63938 .20601 L
.64189 .20601 L
Mistroke
.64423 .20601 L
.64638 .20601 L
.64873 .20601 L
.65121 .20601 L
.65391 .20601 L
.65647 .20601 L
.65876 .20601 L
.66124 .20601 L
.66395 .20601 L
.66681 .20601 L
.66926 .20601 L
.67195 .20601 L
.67676 .20601 L
.67945 .20601 L
.68192 .20601 L
.68421 .20601 L
.6867 .20601 L
.69124 .20601 L
.69393 .20601 L
.69684 .20601 L
.69941 .206 L
.70211 .206 L
.70456 .206 L
.70724 .206 L
.71195 .20599 L
.71483 .20599 L
.71746 .20598 L
.72029 .20598 L
.72336 .20597 L
.72882 .20595 L
.73399 .20592 L
.7391 .20588 L
.74389 .20583 L
.74915 .20576 L
.7548 .20567 L
.76071 .20553 L
.76633 .20537 L
.77186 .20516 L
.77688 .20493 L
.78694 .20434 L
.79766 .20351 L
.81696 .20157 L
.82678 .20055 L
.83215 .20005 L
.83716 .19965 L
.84 .19947 L
.84259 .19933 L
.84546 .19921 L
.84704 .19916 L
.84775 .19914 L
Mistroke
.84854 .19913 L
.8498 .19911 L
.85115 .1991 L
.85239 .1991 L
.85356 .19911 L
.85493 .19913 L
.85618 .19917 L
.85756 .19921 L
.85902 .19928 L
.86171 .19943 L
.86426 .19962 L
.86903 .20009 L
.87416 .20077 L
.87973 .20168 L
.89901 .20579 L
.90979 .20818 L
.91987 .21008 L
.92494 .21084 L
.93039 .21148 L
.93349 .21175 L
.93643 .21196 L
.93908 .21209 L
.94057 .21215 L
.94196 .21219 L
.94331 .21221 L
.944 .21222 L
.94474 .21223 L
.94607 .21223 L
.9473 .21223 L
.94805 .21222 L
.94876 .21221 L
.95009 .21219 L
.95152 .21215 L
.95307 .2121 L
.95571 .21198 L
.95851 .21183 L
.96354 .21149 L
.98308 .2097 L
1 .20818 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13039,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo00?ooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooo
oom5ooooo`001Ol00002ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Gooooo00?o
0000ooooooooool0oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo00Co
A4A4omgMgOoooooo00001_ooool3o`000?ooooooAOooool000Oooooo00Go0000oooooooooooooooo
o`00000;ooooo`04omgMgOmEEEGoooooo`0000Kooooo00?o0000ooooooooool0oooooom5ooooo`00
1oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001_ooool00ol0003o
ooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^ko
A4A4o`000006ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Gooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool5o`0000Gooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool00ol0003oooooooooo`3oooooodGooooo0005o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0oooooom5ooooo`001ooo
ool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01Oooool3o`000?oooooo
AOooool000Oooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Cooooo
00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Gooooo00?o0000oooooooo
ool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c005ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo027ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@0Iooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l00000
0ol@413oooooooooo`0Gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l0
00001Ol@413oooooooooooooooooA4A400;o000000?o<S8bomgMgOooool06?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM03Wooooo000Qoooo
o`;o00008_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01oooool00omgMgOo<S8booooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B47ooooo`03o`000?oooooooooo00Kooooo00?oMgMgoc8b<_ooool06?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@06_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1oooool00omgMgOo<S8booooo`0hooooo`008Oooool00ol0003oooooooooo`0Qooooo`05oa0@4?oo
ooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000oooooooo
ool05oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool06Oooool01Ol@
413ooooooooooooooooo410@00kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0G
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Kooooo`05oa0@4?oo
ooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo03Oooooo
000Qooooo`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`00
0?ooooooooooooooool000001oooool00omgMgOo<S8booooo`0Hooooo`05o`000?oooooooooooooo
ool000003_ooool00ol0003oooooooooo`0Iooooo`05o`000?ooooooooooooooool000003_ooool0
0ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo01Sooooo00Go0000ooooooooooooooooo`00
000=ooooo`03oiRHV?lQ8B7ok^k^01[ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool0>?ooool0027ooooo00?o0000ooooooooool08Ooo
ool01Ol0003ooooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000004ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`06Oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000
ooooooooool06Oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<01Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo01Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00iooooo`008Oooool00ol0003oooooooooo`0Qoooo
o`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00Cooooo00?o
0000ooooooooool06oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool0
6Oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Kooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`0Hoooo
o`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo03_ooooo000Qooooo`03o`000?oooooooooo027ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00ol0003oooooooooo`0Kooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`0Iooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01_ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41006_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo03_ooooo
000Qooooo`;o00008_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP04ooooo`Co00006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIV
I_l000006oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l000001Oooool4
o`0001[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
6_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004oooo
o`Co0000>_ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo>_ooool00ol@413o0000o`00
0003o`0000Gooooo000Qooooo`03o`000?oooooooooo0?Wooooo4Ol0000aooooo`03o`000?oooooo
oooo00Kooooo000Qooooo`03o`000?oooooooooo0>oooooo2_l0000Aooooo`Co0000;Oooool00ol0
003oooooooooo`06ooooo`008Oooooooo`0003?o00003?ooool00ol0003oooooooooo`06ooooo`00
8Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`04o`0000?ooooo00?o0000ooooooooool01oooool00ol0003ooooo
o`000008o`0000cooooo00?o0000oc8b<_oMgMd01_ooool0027ooooo00?o0000ooooooooool0<?oo
ool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0<?oo
ool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01Sooooo3ol0000Dooooo`;o000000Co
ZJVYob4Q8Ol0003o8B4Q1?ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo0_l0003oooooodKooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo1Ol00005ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Go
oooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00co
oooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000?ooooooAOooool000Oooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Gooooo00?o0000ooooooooool0oooooom5ooooo`00
1oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01?ooool00ol0003o
ooooooooo`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001Oooool00ol0003oooooooooo`3ooooo
odGooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7o
c<c<00Gooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo0_l0003oooooodKooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003
oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00005ooooo`?o
0000oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoo
oooo00001_ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05o`000?oooooooooooooo
ool000002oooool01?oMgMgoEEEEooooool00006ooooo`03o`000?oooooooooo0?ooooooAOooool0
00Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Kooooo00?o0000
ooooooooool0oooooom5ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^
odA4A?l000001_ooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`05ooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c005ooooo`03o`000?oooooooooo
0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmE
EEGoMgMgoooooonHV9So8B4Q00Gooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@
413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000005ooooo`?o0000oooo
oom5ooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RH
ob4Q8@05ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01Oooool00ol0003oooooooooo`3oooooodGo
oooo0007ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`07ooooo`03
o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03
omgMgOl@413oV9RH00Oooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@1Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool2o`000?ooooooA_oo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01Oooool00ol0003o
ooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00Go8B4QoiRHV?ooooooV9RHob4Q8@05ooooo`03o`000?oooooooooo0?ooooooAOooool000Oo
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001Oooool0
0ol0003oooooooooo`3oooooodGooooo0007ooooo`05o`000?ooooooooooooooool000002oooool0
1Olb<S;oV9RHoooooonHV9So<S8b00Gooooo0ol0003oooooodGooooo0007ooooo`05o`000?oooooo
ooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<00Gooooo00?o0000ooooooooool0
oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo
^[Zjoa0@4005ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000001Oooool00ol0003oooooooooo`3ooooo
odGooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413o
ZJVY00Gooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo0_l0003oooooodKooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0
oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool001Sooooo1?l000000ol@413oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo
AOooool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000J
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool00ol0
003oooooooooo`04ooooo`?o0000oooooom5ooooo`006_ooool00ol0003oooooooooo`3oooooodco
oooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo00?o0000ooooooooool0oooo
oom<ooooo`006?ooool00omEEEGoIVIVo`00003oooooodkooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo002Nooooo`05oiRHV?l0003o0000odA4A?nj^[X06?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001Oooool00ol0003ok^k^ooooo`2@ooooo`00
7oooool01?l@413o0000o`000?l0001kooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`00
00Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oo
ooooA4A400Gooooo00?oEEEEojVYZOooool0T?ooool0023ooooo00?o0000ooooooooool0Noooool0
0ol0003oooooooooo`0Jooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^
kP06ooooo`03ojVYZOmEEEGooooo093ooooo000Pooooo`03o`000?oooooooooo07_ooooo00?o0000
ooooooooool02oooool6o`0000Wooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ
8B7ok^k^00Kooooo00?o8B4Qooooooooool0Soooool0023ooooo00Ko0000ogMgMol0003o0000oeEE
EOo^k^ihooooo`03o`000?oooooooooo01[ooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo00Gooooo00?oEEEEolc<c?ooool0Soooool0023ooooo00Ko0000oeEEEOo^k^ko
ooooogMgMomEEEEfooooo`03oa0@4?l0003o000000?o00006Oooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool01?ooool00onYZJWoMgMgooooo`2?ooooo`008?ooool00ol0
003ok^k^ooooo`02ooooo`03o`000?oooooooooo07Kooooo00?o0000ooooooooool06_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05oa0@4?oo
oooooooooooooolb<S80T?ooool0023ooooo00?o0000onk^k_ooool00_ooool00ol0003ooooooooo
o`1fooooo`03o`000?oooooooooo01[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRH
V?l@413o0000ob4Q8Oo<c<`00oooool5o`00093ooooo000Pooooo`06o`000?mEEEGok^k^oooooomg
MgOoIVIVoooooom3ooooo`007oooool00ol@413o0000ogMgM`02o`000003ofIVI_o^k^kooooo0?oo
oooo@_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.0332543, -0.540631, \
0.00122928, 0.00994506}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 3.33333 0.206011 0.412023 [
[.16667 .19351 -12 -9 ]
[.16667 .19351 12 0 ]
[.33333 .19351 -9 -9 ]
[.33333 .19351 9 0 ]
[.5 .19351 -12 -9 ]
[.5 .19351 12 0 ]
[.66667 .19351 -9 -9 ]
[.66667 .19351 9 0 ]
[.83333 .19351 -12 -9 ]
[.83333 .19351 12 0 ]
[1.025 .20601 0 -6 ]
[1.025 .20601 10 6 ]
[-0.0125 .0412 -24 -4.5 ]
[-0.0125 .0412 0 4.5 ]
[-0.0125 .12361 -24 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .28842 -18 -4.5 ]
[-0.0125 .28842 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .45322 -18 -4.5 ]
[-0.0125 .45322 0 4.5 ]
[-0.0125 .53563 -18 -4.5 ]
[-0.0125 .53563 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 .20601 m
.16667 .21226 L
s
[(0.05)] .16667 .19351 0 1 Mshowa
.33333 .20601 m
.33333 .21226 L
s
[(0.1)] .33333 .19351 0 1 Mshowa
.5 .20601 m
.5 .21226 L
s
[(0.15)] .5 .19351 0 1 Mshowa
.66667 .20601 m
.66667 .21226 L
s
[(0.2)] .66667 .19351 0 1 Mshowa
.83333 .20601 m
.83333 .21226 L
s
[(0.25)] .83333 .19351 0 1 Mshowa
.125 Mabswid
.03333 .20601 m
.03333 .20976 L
s
.06667 .20601 m
.06667 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.13333 .20601 m
.13333 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.23333 .20601 m
.23333 .20976 L
s
.26667 .20601 m
.26667 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.36667 .20601 m
.36667 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.43333 .20601 m
.43333 .20976 L
s
.46667 .20601 m
.46667 .20976 L
s
.53333 .20601 m
.53333 .20976 L
s
.56667 .20601 m
.56667 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.63333 .20601 m
.63333 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.73333 .20601 m
.73333 .20976 L
s
.76667 .20601 m
.76667 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.86667 .20601 m
.86667 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.93333 .20601 m
.93333 .20976 L
s
.96667 .20601 m
.96667 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
gsave
1.025 .20601 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .0412 m
.00625 .0412 L
s
[(-0.4)] -0.0125 .0412 1 0 Mshowa
0 .12361 m
.00625 .12361 L
s
[(-0.2)] -0.0125 .12361 1 0 Mshowa
0 .28842 m
.00625 .28842 L
s
[(0.2)] -0.0125 .28842 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.4)] -0.0125 .37082 1 0 Mshowa
0 .45322 m
.00625 .45322 L
s
[(0.6)] -0.0125 .45322 1 0 Mshowa
0 .53563 m
.00625 .53563 L
s
[(0.8)] -0.0125 .53563 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .10301 m
.00375 .10301 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .30902 m
.00375 .30902 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .39142 m
.00375 .39142 L
s
0 .41202 m
.00375 .41202 L
s
0 .43262 m
.00375 .43262 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .51503 m
.00375 .51503 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
0 .0206 m
.00375 .0206 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.28) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .20601 m
.00123 .20601 L
.00236 .20601 L
.00365 .20601 L
.00488 .20601 L
.00601 .20601 L
.00706 .20601 L
.00821 .20601 L
.00942 .20601 L
.01065 .20601 L
.01196 .20601 L
.0132 .20601 L
.01434 .20601 L
.01566 .20601 L
.01641 .20601 L
.01711 .20601 L
.01839 .20601 L
.01975 .20601 L
.02043 .20601 L
.02115 .20601 L
.02245 .20601 L
.02317 .20601 L
.02384 .20601 L
.02458 .20601 L
.02537 .20601 L
.02605 .20601 L
.02679 .20601 L
.02814 .20601 L
.02945 .20601 L
.03067 .20601 L
.03184 .20601 L
.03295 .20601 L
.03416 .20601 L
.03547 .20601 L
.03676 .20601 L
.03813 .20601 L
.03929 .20601 L
.04057 .20601 L
.04131 .20601 L
.042 .20601 L
.04275 .20601 L
.04355 .20601 L
.0449 .20601 L
.04566 .20601 L
.04637 .20601 L
.0477 .20601 L
.04892 .20601 L
.04959 .20601 L
.05032 .20601 L
.05165 .20601 L
Mistroke
.05245 .20601 L
.05321 .20601 L
.05389 .20601 L
.05462 .20601 L
.05543 .20601 L
.05627 .20601 L
.057 .20601 L
.05779 .20601 L
.05854 .20601 L
.05921 .20601 L
.06 .20601 L
.06074 .20601 L
.06205 .20601 L
.0628 .20601 L
.06349 .20601 L
.06471 .20601 L
.06603 .20601 L
.06727 .20601 L
.06841 .20601 L
.06967 .20601 L
.07105 .20601 L
.07175 .20601 L
.07249 .20601 L
.07383 .20601 L
.07457 .20601 L
.07525 .20601 L
.076 .20601 L
.07679 .20601 L
.07812 .20601 L
.07888 .20601 L
.07959 .20601 L
.0809 .20601 L
.08211 .20601 L
.08349 .20601 L
.08481 .20601 L
.086 .20601 L
.08729 .20601 L
.0885 .20601 L
.08962 .20601 L
.09085 .20601 L
.0922 .20601 L
.09289 .20601 L
.09361 .20601 L
.09493 .20601 L
.09565 .20601 L
.09632 .20601 L
.09705 .20601 L
.09783 .20601 L
.09913 .20601 L
.09987 .20601 L
Mistroke
.10056 .20601 L
.10185 .20601 L
.10303 .20601 L
.10439 .20601 L
.10569 .20601 L
.10691 .20601 L
.10801 .20601 L
.10928 .20601 L
.11048 .20601 L
.1116 .20601 L
.11262 .20601 L
.11375 .20601 L
.11493 .20601 L
.11613 .20601 L
.11742 .20601 L
.11864 .20601 L
.11974 .20601 L
.12104 .20601 L
.12178 .20601 L
.12245 .20601 L
.1237 .20601 L
.12502 .20601 L
.12622 .20601 L
.12753 .20601 L
.12889 .20601 L
.13016 .20601 L
.13135 .20601 L
.13244 .20601 L
.13369 .20601 L
.13487 .20601 L
.13616 .20601 L
.13752 .20601 L
.13868 .20601 L
.13996 .20601 L
.14134 .20601 L
.14211 .20601 L
.14281 .20601 L
.14418 .20601 L
.14548 .20601 L
.14669 .20601 L
.14779 .20601 L
.14906 .20601 L
.15025 .20601 L
.15136 .20601 L
.15237 .20601 L
.15349 .20601 L
.15467 .20601 L
.15586 .20601 L
.15714 .20601 L
.15835 .20601 L
Mistroke
.15945 .20601 L
.16074 .20601 L
.16146 .20601 L
.16214 .20601 L
.16337 .20601 L
.16468 .20601 L
.16594 .20601 L
.16732 .20601 L
.16863 .20601 L
.16984 .20601 L
.17103 .20601 L
.17212 .20601 L
.17337 .20601 L
.17456 .20601 L
.17585 .20601 L
.17721 .20601 L
.17838 .20601 L
.17966 .20601 L
.18104 .20601 L
.18181 .20601 L
.18251 .20601 L
.18388 .20601 L
.18518 .20601 L
.18628 .20601 L
.1875 .20601 L
.18877 .20601 L
.18996 .20601 L
.19107 .20601 L
.19209 .20601 L
.19321 .20601 L
.19438 .20601 L
.19558 .20601 L
.19686 .20601 L
.19807 .20601 L
.19916 .20601 L
.20045 .20601 L
.20118 .20601 L
.20185 .20601 L
.20309 .20601 L
.20439 .20601 L
.20566 .20601 L
.20705 .20601 L
.20835 .20601 L
.20957 .20601 L
.21077 .20601 L
.21186 .20601 L
.21311 .20601 L
.2143 .20601 L
.21559 .20601 L
.21696 .20601 L
Mistroke
.21813 .20601 L
.21941 .20601 L
.22079 .20601 L
.22157 .20601 L
.22227 .20601 L
.22364 .20601 L
.22494 .20601 L
.22604 .20601 L
.22726 .20601 L
.22853 .20601 L
.22973 .20601 L
.23084 .20601 L
.23186 .20601 L
.23297 .20601 L
.23415 .20601 L
.23535 .20601 L
.23663 .20601 L
.23784 .20601 L
.23893 .20601 L
.24023 .20601 L
.24095 .20601 L
.24163 .20601 L
.24286 .20601 L
.24416 .20601 L
.24544 .20601 L
.24683 .20601 L
.24814 .20601 L
.24935 .20601 L
.25044 .20601 L
.25165 .20601 L
.25291 .20601 L
.25409 .20601 L
.25539 .20601 L
.25676 .20601 L
.25793 .20601 L
.25922 .20601 L
.2606 .20601 L
.26137 .20601 L
.26208 .20601 L
.26345 .20601 L
.26475 .20601 L
.26586 .20601 L
.26708 .20601 L
.26835 .20601 L
.26954 .20601 L
.27066 .20601 L
.27168 .20601 L
.27286 .20601 L
.27397 .20601 L
.27518 .20601 L
Mistroke
.27646 .20601 L
.27767 .20601 L
.27876 .20601 L
.28005 .20601 L
.28078 .20601 L
.28145 .20601 L
.28268 .20601 L
.28399 .20601 L
.28527 .20601 L
.28599 .20601 L
.28666 .20601 L
.28789 .20601 L
.28919 .20601 L
.29036 .20601 L
.29145 .20601 L
.29265 .20601 L
.29394 .20601 L
.29524 .20601 L
.29597 .20601 L
.29665 .20601 L
.29803 .20601 L
.29881 .20601 L
.29951 .20601 L
.30077 .20601 L
.30213 .20601 L
.30342 .20601 L
.30461 .20601 L
.30572 .20601 L
.30691 .20601 L
.30804 .20601 L
.30907 .20601 L
.31027 .20601 L
.31158 .20601 L
.31282 .20601 L
.31396 .20601 L
.31526 .20601 L
.31648 .20601 L
.31758 .20601 L
.31876 .20601 L
.32005 .20601 L
.32142 .20601 L
.32259 .20601 L
.32386 .20601 L
.32524 .20601 L
.32651 .20601 L
.32718 .20601 L
.32791 .20601 L
.32868 .20601 L
.32939 .20601 L
.33069 .20601 L
Mistroke
.3314 .20601 L
.33208 .20601 L
.33329 .20601 L
.33461 .20601 L
.3359 .20601 L
.33707 .20601 L
.33841 .20601 L
.33968 .20601 L
.34086 .20601 L
.34195 .20601 L
.34314 .20601 L
.3444 .20601 L
.34576 .20601 L
.34701 .20601 L
.3477 .20601 L
.34845 .20601 L
.34981 .20601 L
.35108 .20601 L
.35244 .20601 L
.35359 .20601 L
.35487 .20601 L
.35559 .20601 L
.35636 .20601 L
.35772 .20601 L
.35848 .20601 L
.35919 .20601 L
.36002 .20601 L
.3608 .20601 L
.36221 .20601 L
.36349 .20601 L
.36487 .20601 L
.36565 .20601 L
.36637 .20601 L
.36769 .20601 L
.36893 .20601 L
.37005 .20601 L
.37127 .20601 L
.37259 .20601 L
.374 .20601 L
.37533 .20601 L
.37654 .20601 L
.37777 .20601 L
.37889 .20601 L
.38013 .20601 L
.38144 .20601 L
.38258 .20601 L
.38364 .20601 L
.38481 .20601 L
.38606 .20601 L
.38751 .20601 L
Mistroke
.38885 .20601 L
.39032 .20601 L
.39106 .20601 L
.39188 .20601 L
.39325 .20601 L
.39472 .20601 L
.39612 .20601 L
.39739 .20601 L
.39864 .20601 L
.3998 .20601 L
.40107 .20601 L
.40242 .20601 L
.40385 .20601 L
.4052 .20601 L
.40641 .20601 L
.40772 .20601 L
.40902 .20601 L
.4102 .20601 L
.41157 .20601 L
.41286 .20601 L
.41406 .20601 L
.41516 .20601 L
.41638 .20601 L
.41767 .20601 L
.4191 .20601 L
.42063 .20601 L
.42208 .20601 L
.42341 .20601 L
.42462 .20601 L
.42594 .20601 L
.42732 .20601 L
.42861 .20601 L
.42999 .20601 L
.43149 .20601 L
.4329 .20601 L
.4342 .20601 L
.43538 .20601 L
.43667 .20601 L
.43802 .20601 L
.43929 .20601 L
.44076 .20601 L
.44216 .20601 L
.44342 .20601 L
.44479 .20601 L
.44628 .20601 L
.44786 .20601 L
.44936 .20601 L
.45071 .20601 L
.45198 .20601 L
.45315 .20601 L
Mistroke
.45445 .20601 L
.45583 .20601 L
.45728 .20601 L
.45866 .20601 L
.45989 .20601 L
.46124 .20601 L
.4624 .20601 L
.46367 .20601 L
.46501 .20601 L
.46627 .20601 L
.46743 .20601 L
.4685 .20601 L
.46968 .20601 L
.47092 .20601 L
.47229 .20601 L
.47353 .20601 L
.47497 .20601 L
.47633 .20601 L
.47758 .20601 L
.47874 .20601 L
.48001 .20601 L
.48136 .20601 L
.48271 .20601 L
.48417 .20601 L
.48554 .20601 L
.4868 .20601 L
.48826 .20601 L
.48986 .20601 L
.49138 .20601 L
.49278 .20601 L
.49413 .20601 L
.49556 .20601 L
.49679 .20601 L
.49812 .20601 L
.49957 .20601 L
.50111 .20601 L
.50257 .20601 L
.5039 .20601 L
.50524 .20601 L
.50648 .20601 L
.50784 .20601 L
.50928 .20601 L
.51053 .20601 L
.5117 .20601 L
.51298 .20601 L
.51437 .20601 L
.51674 .20601 L
.51809 .20601 L
.51934 .20601 L
.52187 .20601 L
Mistroke
.52329 .20601 L
.52457 .20601 L
.52688 .20601 L
.52818 .20601 L
.52938 .20601 L
.53158 .20601 L
.53269 .20601 L
.53391 .20601 L
.53654 .20601 L
.53803 .20601 L
.5394 .20601 L
.54193 .20601 L
.5432 .20601 L
.54461 .20601 L
.54703 .20601 L
.54839 .20601 L
.54964 .20601 L
.55194 .20601 L
.5531 .20601 L
.55437 .20601 L
.55585 .20601 L
.55725 .20601 L
.55986 .20601 L
.56133 .20601 L
.56268 .20601 L
.56416 .20601 L
.56574 .20601 L
.56699 .20601 L
.56834 .20601 L
.57077 .20601 L
.57226 .20601 L
.57367 .20601 L
.57632 .20601 L
.57763 .20601 L
.57904 .20601 L
.58029 .20601 L
.58161 .20601 L
.5828 .20601 L
.5841 .20601 L
.58639 .20601 L
.5878 .20601 L
.58908 .20601 L
.59045 .20601 L
.59195 .20601 L
.59333 .20601 L
.59461 .20601 L
.59713 .20601 L
.59943 .20601 L
.60158 .20601 L
.60395 .20601 L
Mistroke
.60516 .20601 L
.60649 .20601 L
.60902 .20601 L
.6104 .20601 L
.61168 .20601 L
.61398 .20601 L
.61644 .20601 L
.61916 .20601 L
.62053 .20601 L
.62204 .20601 L
.62471 .20601 L
.6272 .20601 L
.62871 .20601 L
.63014 .20601 L
.63283 .20601 L
.63433 .20601 L
.63572 .20601 L
.63723 .20601 L
.63887 .20601 L
.64164 .20601 L
.64425 .20601 L
.64679 .20601 L
.64912 .20601 L
.65165 .20601 L
.65443 .20601 L
.65733 .20601 L
.66003 .20601 L
.66277 .20601 L
.66531 .20601 L
.66809 .20601 L
.67104 .20601 L
.6736 .20601 L
.67599 .20601 L
.67862 .20601 L
.68145 .20601 L
.68395 .20601 L
.68667 .20601 L
.68924 .20601 L
.69163 .20601 L
.69614 .20601 L
.69867 .20601 L
.70095 .20601 L
.70339 .20601 L
.70607 .20601 L
.70886 .20601 L
.71147 .20601 L
.71614 .20601 L
.71876 .20601 L
.72115 .20601 L
.72652 .20601 L
Mistroke
.72956 .20601 L
.73237 .206 L
.73753 .206 L
.74013 .206 L
.74301 .206 L
.74816 .20599 L
.75076 .20598 L
.75359 .20598 L
.75862 .20596 L
.76331 .20594 L
.76885 .20591 L
.77389 .20587 L
.77971 .20581 L
.7852 .20573 L
.79006 .20564 L
.7954 .20552 L
.80098 .20535 L
.8062 .20516 L
.81554 .2047 L
.82557 .20404 L
.8463 .20216 L
.85724 .20104 L
.86324 .20047 L
.86889 .20001 L
.87435 .19966 L
.87585 .19958 L
.87743 .19951 L
.87879 .19946 L
.88025 .19942 L
.88158 .19939 L
.88279 .19937 L
.88401 .19936 L
.88516 .19936 L
.8865 .19937 L
.88774 .19938 L
.8891 .19941 L
.89054 .19946 L
.89292 .19955 L
.89547 .1997 L
.90009 .20008 L
.90559 .2007 L
.91063 .20144 L
.93221 .20576 L
.94272 .20802 L
.95227 .20979 L
.95705 .21051 L
.96224 .21114 L
.96462 .21137 L
.96713 .21158 L
.96949 .21174 L
Mistroke
.97164 .21185 L
.97282 .2119 L
.9741 .21194 L
.97545 .21198 L
.97673 .212 L
.97793 .21202 L
.9792 .21202 L
.98029 .21202 L
.98149 .21201 L
.98217 .212 L
.98289 .21199 L
.98418 .21196 L
.98556 .21192 L
.98707 .21187 L
.99232 .21161 L
.99603 .21137 L
1 .21106 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13039,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo00?ooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooo
oom5ooooo`001Ol00002ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Gooooo00?o
0000ooooooooool0oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo00Co
A4A4omgMgOoooooo00001_ooool3o`000?ooooooAOooool000Oooooo00Go0000oooooooooooooooo
o`00000;ooooo`04omgMgOmEEEGoooooo`0000Kooooo00?o0000ooooooooool0oooooom5ooooo`00
1oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001_ooool00ol0003o
ooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^ko
A4A4o`000006ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Gooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool5o`0000Gooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool00ol0003oooooooooo`3oooooodGooooo0005o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0oooooom5ooooo`001ooo
ool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01Oooool3o`000?oooooo
AOooool000Oooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Cooooo
00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Gooooo00?o0000oooooooo
ool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c005ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo027ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@0Iooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l00000
0ol@413oooooooooo`0Gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l0
00001Ol@413oooooooooooooooooA4A400;o000000?o<S8bomgMgOooool06?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM03Wooooo000Qoooo
o`;o00008_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01oooool00omgMgOo<S8booooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B47ooooo`03o`000?oooooooooo00Kooooo00?oMgMgoc8b<_ooool06?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@06_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1oooool00omgMgOo<S8booooo`0hooooo`008Oooool00ol0003oooooooooo`0Qooooo`05oa0@4?oo
ooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000oooooooo
ool05oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool06Oooool01Ol@
413ooooooooooooooooo410@00kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0G
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Kooooo`05oa0@4?oo
ooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo03Oooooo
000Qooooo`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`00
0?ooooooooooooooool000001oooool00omgMgOo<S8booooo`0Hooooo`05o`000?oooooooooooooo
ool000003_ooool00ol0003oooooooooo`0Iooooo`05o`000?ooooooooooooooool000003_ooool0
0ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo01Sooooo00Go0000ooooooooooooooooo`00
000=ooooo`03oiRHV?lQ8B7ok^k^01[ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool0>?ooool0027ooooo00?o0000ooooooooool08Ooo
ool01Ol0003ooooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000004ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`06Oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000
ooooooooool06Oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<01Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo01Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00iooooo`008Oooool00ol0003oooooooooo`0Qoooo
o`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00Cooooo00?o
0000ooooooooool06oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool0
6Oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Kooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`0Hoooo
o`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo03_ooooo000Qooooo`03o`000?oooooooooo027ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00ol0003oooooooooo`0Kooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`0Iooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01_ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41006_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo03_ooooo
000Qooooo`;o00008_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP04ooooo`Co00006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIV
I_l000006oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l000001Oooool4
o`0001[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
6_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004oooo
o`Co0000>_ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo>_ooool00ol@413o0000o`00
0003o`0000Gooooo000Qooooo`03o`000?oooooooooo0?oooooo1Oooool?o`0002Sooooo00?o0000
ooooooooool01_ooool0027ooooo00?o0000ooooooooool0n?ooool<o`0000oooooo1Ol0000Soooo
o`03o`000?oooooooooo00Kooooo000Qoooooooo0000<ol0000<ooooo`03o`000?oooooooooo00Ko
oooo000Qooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_l000000ooooooo0000
ooooo`0Eooooo`03o`000?lb<S;ogMgM00Kooooo000Qooooo`03o`000?oooooooooo033ooooo00?o
0000ooooooooool0<?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo033ooooo00?o
0000ooooooooool0<?ooool00ol0003oooooooooo`0Tooooo`co00002oooool2o`000004ojVYZOlQ
8B7o0000ob4Q8@Cooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o
0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`Go00001Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`03
o`000?oooooooooo0?ooooooAOooool000Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03
oiRHV?lQ8B7ok^k^00Kooooo0ol0003oooooodGooooo0007ooooo`05o`000?ooooooooooooooool0
00003Oooool00onHV9So8B4Qonk^kP05ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo
00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Cooooo00?o0000oooooooo
ool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Gooooo00?o0000ooooooooool0oooooom5oooo
o`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c005
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo0_l0003oooooodKooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413o
ooooooooo`03ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oo
ooooAOooool000Oooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00001Oooool3o`000?oo
ooooAOooool000Oooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`00
00Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo0000
00_ooooo00CogMgMoeEEEOoooooo00001_ooool00ol0003oooooooooo`3oooooodGooooo0007oooo
o`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000006ooooo`03o`000?oooooo
oooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co
000000Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00gooooo00?oMgMgo`000?ooool01Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01Oooool00ol0003oooooooooo`3ooooo
odGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMg
MoooooooV9RHob4Q8@05ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go410@oooo
oooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001Oooool3o`000?ooooooAOoo
ool000Oooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40
1Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05o`000?ooooooooooooooool00000
2oooool01Ol0003oEEEEo`000?l@413oc<c<00Gooooo00?o0000ooooooooool0oooooom5ooooo`00
1oooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool01oooool00ol0003o
ooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo
410@oiRHV007ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Gooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Gooooo00?o0000oooooooo
ool0oooooom5ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B401Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05
oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000
ooooooooool0oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8b
oiRHV?ooooooV9RHoc8b<P05ooooo`?o0000oooooom5ooooo`001oooool01Ol0003ooooooooooooo
oooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c005ooooo`03o`000?oooooooooo0?oooooo
AOooool000Oooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@
41001Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Gooooo00?o0000ooooooooool0oooooom5oooo
o`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@05
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo0_l0003oooooodKooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Hooooo`Co000000?o410@ooooooooool00_ooool00ol0003oooooooooo`3oooooodGooooo
000Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooom5ooooo`006_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000oooo
ooooool01?ooool3o`000?ooooooAOooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`00
6_ooool00ol0003oooooooooo`3oooooodcooooo000Jooooo`03o`000?oooooooooo0?ooooooC?oo
ool001Sooooo00?oEEEEofIVI_l00000oooooom>ooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00W_ooool01OnHV9So0000o`000?m4A4Co^[Zj01Sooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000?ooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c02@oooo
o`007oooool01?l@413o0000o`000?l0001kooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6
o`0000Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^
k_ooooooA4A400?ooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@2@ooooo`008?ooool00ol0003ooooo
ooooo`1kooooo`03o`000?oooooooooo01[ooooo00Go410@oooooooooooooooooa0@400<ooooo`03
oiRHV?lQ8B7ok^k^00Cooooo00Go0000ooooooooooooooooo`00002@ooooo`008?ooool00ol0003o
ooooooooo`1kooooo`03o`000?oooooooooo00_ooooo1_l00009ooooo`05o`000?oooooooooooooo
ool000003Oooool00onHV9So8B4Qonk^kP03ooooo`05oc8b<_nHV9SooooooiRHV?lb<S80T?ooool0
023ooooo00Ko0000ogMgMol0003o0000oeEEEOo^k^ihooooo`03o`000?oooooooooo01[ooooo00Go
0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00;ooooo00Goc<c<o`000?l0003o
0000olc<c02@ooooo`008?ooool01_l0003oEEEEonk^k_ooooooMgMgoeEEEGKooooo00?o410@o`00
0?l000000ol0000Iooooo`05oa0@4?ooooooooooooooool@41003oooool02Ol0003ooooooooooooo
oooo410@okZj^_oooooo^[Zjoa0@402@ooooo`008?ooool00ol0003ok^k^ooooo`02ooooo`03o`00
0?oooooooooo07Kooooo00?o0000ooooooooool06_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05o`000?nj^[[ooooookZj^_l00000T?ooool0
023ooooo00?o0000onk^k_ooool00_ooool00ol0003oooooooooo`1fooooo`03o`000?oooooooooo
01[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00ooo
ool01OnYZJWo410@o`000?l@413oZJVY093ooooo000Pooooo`06o`000?mEEEGok^k^oooooomgMgOo
IVIVoooooom3ooooo`007oooool00ol@413o0000ogMgM`02o`000003ofIVI_o^k^kooooo0?oooooo
@_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.0332543, -0.540631, \
0.00122928, 0.00994506}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 3.33333 0.206011 0.412023 [
[.16667 .19351 -12 -9 ]
[.16667 .19351 12 0 ]
[.33333 .19351 -9 -9 ]
[.33333 .19351 9 0 ]
[.5 .19351 -12 -9 ]
[.5 .19351 12 0 ]
[.66667 .19351 -9 -9 ]
[.66667 .19351 9 0 ]
[.83333 .19351 -12 -9 ]
[.83333 .19351 12 0 ]
[1.025 .20601 0 -6 ]
[1.025 .20601 10 6 ]
[-0.0125 .0412 -24 -4.5 ]
[-0.0125 .0412 0 4.5 ]
[-0.0125 .12361 -24 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .28842 -18 -4.5 ]
[-0.0125 .28842 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .45322 -18 -4.5 ]
[-0.0125 .45322 0 4.5 ]
[-0.0125 .53563 -18 -4.5 ]
[-0.0125 .53563 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -26 0 ]
[.5 .63053 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 .20601 m
.16667 .21226 L
s
[(0.05)] .16667 .19351 0 1 Mshowa
.33333 .20601 m
.33333 .21226 L
s
[(0.1)] .33333 .19351 0 1 Mshowa
.5 .20601 m
.5 .21226 L
s
[(0.15)] .5 .19351 0 1 Mshowa
.66667 .20601 m
.66667 .21226 L
s
[(0.2)] .66667 .19351 0 1 Mshowa
.83333 .20601 m
.83333 .21226 L
s
[(0.25)] .83333 .19351 0 1 Mshowa
.125 Mabswid
.03333 .20601 m
.03333 .20976 L
s
.06667 .20601 m
.06667 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.13333 .20601 m
.13333 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.23333 .20601 m
.23333 .20976 L
s
.26667 .20601 m
.26667 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.36667 .20601 m
.36667 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.43333 .20601 m
.43333 .20976 L
s
.46667 .20601 m
.46667 .20976 L
s
.53333 .20601 m
.53333 .20976 L
s
.56667 .20601 m
.56667 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.63333 .20601 m
.63333 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.73333 .20601 m
.73333 .20976 L
s
.76667 .20601 m
.76667 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.86667 .20601 m
.86667 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.93333 .20601 m
.93333 .20976 L
s
.96667 .20601 m
.96667 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
gsave
1.025 .20601 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .0412 m
.00625 .0412 L
s
[(-0.4)] -0.0125 .0412 1 0 Mshowa
0 .12361 m
.00625 .12361 L
s
[(-0.2)] -0.0125 .12361 1 0 Mshowa
0 .28842 m
.00625 .28842 L
s
[(0.2)] -0.0125 .28842 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.4)] -0.0125 .37082 1 0 Mshowa
0 .45322 m
.00625 .45322 L
s
[(0.6)] -0.0125 .45322 1 0 Mshowa
0 .53563 m
.00625 .53563 L
s
[(0.8)] -0.0125 .53563 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .10301 m
.00375 .10301 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .30902 m
.00375 .30902 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .39142 m
.00375 .39142 L
s
0 .41202 m
.00375 .41202 L
s
0 .43262 m
.00375 .43262 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .51503 m
.00375 .51503 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
0 .0206 m
.00375 .0206 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.29) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .20601 m
.00123 .20601 L
.00236 .20601 L
.00365 .20601 L
.00488 .20601 L
.00601 .20601 L
.00706 .20601 L
.00821 .20601 L
.00942 .20601 L
.01065 .20601 L
.01196 .20601 L
.0132 .20601 L
.01434 .20601 L
.01566 .20601 L
.01641 .20601 L
.01711 .20601 L
.01839 .20601 L
.01975 .20601 L
.02043 .20601 L
.02115 .20601 L
.02245 .20601 L
.02317 .20601 L
.02384 .20601 L
.02458 .20601 L
.02537 .20601 L
.02605 .20601 L
.02679 .20601 L
.02814 .20601 L
.02945 .20601 L
.03067 .20601 L
.03184 .20601 L
.03295 .20601 L
.03416 .20601 L
.03547 .20601 L
.03676 .20601 L
.03813 .20601 L
.03929 .20601 L
.04057 .20601 L
.04131 .20601 L
.042 .20601 L
.04275 .20601 L
.04355 .20601 L
.0449 .20601 L
.04566 .20601 L
.04637 .20601 L
.0477 .20601 L
.04892 .20601 L
.04959 .20601 L
.05032 .20601 L
.05165 .20601 L
Mistroke
.05245 .20601 L
.05321 .20601 L
.05389 .20601 L
.05462 .20601 L
.05543 .20601 L
.05627 .20601 L
.057 .20601 L
.05779 .20601 L
.05854 .20601 L
.05921 .20601 L
.06 .20601 L
.06074 .20601 L
.06205 .20601 L
.0628 .20601 L
.06349 .20601 L
.06471 .20601 L
.06603 .20601 L
.06727 .20601 L
.06841 .20601 L
.06967 .20601 L
.07105 .20601 L
.07175 .20601 L
.07249 .20601 L
.07383 .20601 L
.07457 .20601 L
.07525 .20601 L
.076 .20601 L
.07679 .20601 L
.07812 .20601 L
.07888 .20601 L
.07959 .20601 L
.0809 .20601 L
.08211 .20601 L
.08349 .20601 L
.08481 .20601 L
.086 .20601 L
.08729 .20601 L
.0885 .20601 L
.08962 .20601 L
.09085 .20601 L
.0922 .20601 L
.09289 .20601 L
.09361 .20601 L
.09493 .20601 L
.09565 .20601 L
.09632 .20601 L
.09705 .20601 L
.09783 .20601 L
.09913 .20601 L
.09987 .20601 L
Mistroke
.10056 .20601 L
.10185 .20601 L
.10303 .20601 L
.10439 .20601 L
.10569 .20601 L
.10691 .20601 L
.10801 .20601 L
.10928 .20601 L
.11048 .20601 L
.1116 .20601 L
.11262 .20601 L
.11375 .20601 L
.11493 .20601 L
.11613 .20601 L
.11742 .20601 L
.11864 .20601 L
.11974 .20601 L
.12104 .20601 L
.12178 .20601 L
.12245 .20601 L
.1237 .20601 L
.12502 .20601 L
.12622 .20601 L
.12753 .20601 L
.12889 .20601 L
.13016 .20601 L
.13135 .20601 L
.13244 .20601 L
.13369 .20601 L
.13487 .20601 L
.13616 .20601 L
.13752 .20601 L
.13868 .20601 L
.13996 .20601 L
.14134 .20601 L
.14211 .20601 L
.14281 .20601 L
.14418 .20601 L
.14548 .20601 L
.14669 .20601 L
.14779 .20601 L
.14906 .20601 L
.15025 .20601 L
.15136 .20601 L
.15237 .20601 L
.15349 .20601 L
.15467 .20601 L
.15586 .20601 L
.15714 .20601 L
.15835 .20601 L
Mistroke
.15945 .20601 L
.16074 .20601 L
.16146 .20601 L
.16214 .20601 L
.16337 .20601 L
.16468 .20601 L
.16594 .20601 L
.16732 .20601 L
.16863 .20601 L
.16984 .20601 L
.17103 .20601 L
.17212 .20601 L
.17337 .20601 L
.17456 .20601 L
.17585 .20601 L
.17721 .20601 L
.17838 .20601 L
.17966 .20601 L
.18104 .20601 L
.18181 .20601 L
.18251 .20601 L
.18388 .20601 L
.18518 .20601 L
.18628 .20601 L
.1875 .20601 L
.18877 .20601 L
.18996 .20601 L
.19107 .20601 L
.19209 .20601 L
.19321 .20601 L
.19438 .20601 L
.19558 .20601 L
.19686 .20601 L
.19807 .20601 L
.19916 .20601 L
.20045 .20601 L
.20118 .20601 L
.20185 .20601 L
.20309 .20601 L
.20439 .20601 L
.20566 .20601 L
.20705 .20601 L
.20835 .20601 L
.20957 .20601 L
.21077 .20601 L
.21186 .20601 L
.21311 .20601 L
.2143 .20601 L
.21559 .20601 L
.21696 .20601 L
Mistroke
.21813 .20601 L
.21941 .20601 L
.22079 .20601 L
.22157 .20601 L
.22227 .20601 L
.22364 .20601 L
.22494 .20601 L
.22604 .20601 L
.22726 .20601 L
.22853 .20601 L
.22973 .20601 L
.23084 .20601 L
.23186 .20601 L
.23297 .20601 L
.23415 .20601 L
.23535 .20601 L
.23663 .20601 L
.23784 .20601 L
.23893 .20601 L
.24023 .20601 L
.24095 .20601 L
.24163 .20601 L
.24286 .20601 L
.24416 .20601 L
.24544 .20601 L
.24683 .20601 L
.24814 .20601 L
.24935 .20601 L
.25044 .20601 L
.25165 .20601 L
.25291 .20601 L
.25409 .20601 L
.25539 .20601 L
.25676 .20601 L
.25793 .20601 L
.25922 .20601 L
.2606 .20601 L
.26137 .20601 L
.26208 .20601 L
.26345 .20601 L
.26475 .20601 L
.26586 .20601 L
.26708 .20601 L
.26835 .20601 L
.26954 .20601 L
.27066 .20601 L
.27168 .20601 L
.27286 .20601 L
.27397 .20601 L
.27518 .20601 L
Mistroke
.27646 .20601 L
.27767 .20601 L
.27876 .20601 L
.28005 .20601 L
.28078 .20601 L
.28145 .20601 L
.28268 .20601 L
.28399 .20601 L
.28527 .20601 L
.28599 .20601 L
.28666 .20601 L
.28789 .20601 L
.28919 .20601 L
.29036 .20601 L
.29145 .20601 L
.29265 .20601 L
.29394 .20601 L
.29524 .20601 L
.29597 .20601 L
.29665 .20601 L
.29803 .20601 L
.29881 .20601 L
.29951 .20601 L
.30077 .20601 L
.30213 .20601 L
.30342 .20601 L
.30461 .20601 L
.30572 .20601 L
.30691 .20601 L
.30804 .20601 L
.30907 .20601 L
.31027 .20601 L
.31158 .20601 L
.31282 .20601 L
.31396 .20601 L
.31526 .20601 L
.31648 .20601 L
.31758 .20601 L
.31876 .20601 L
.32005 .20601 L
.32142 .20601 L
.32259 .20601 L
.32386 .20601 L
.32524 .20601 L
.32651 .20601 L
.32718 .20601 L
.32791 .20601 L
.32868 .20601 L
.32939 .20601 L
.33069 .20601 L
Mistroke
.3314 .20601 L
.33208 .20601 L
.33329 .20601 L
.33461 .20601 L
.3359 .20601 L
.33707 .20601 L
.33841 .20601 L
.33968 .20601 L
.34086 .20601 L
.34195 .20601 L
.34314 .20601 L
.3444 .20601 L
.34576 .20601 L
.34701 .20601 L
.3477 .20601 L
.34845 .20601 L
.34981 .20601 L
.35108 .20601 L
.35244 .20601 L
.35359 .20601 L
.35487 .20601 L
.35559 .20601 L
.35636 .20601 L
.35772 .20601 L
.35848 .20601 L
.35919 .20601 L
.36002 .20601 L
.3608 .20601 L
.36148 .20601 L
.36221 .20601 L
.36349 .20601 L
.36422 .20601 L
.36499 .20601 L
.36637 .20601 L
.36764 .20601 L
.36902 .20601 L
.37033 .20601 L
.37154 .20601 L
.37274 .20601 L
.37383 .20601 L
.37509 .20601 L
.37627 .20601 L
.37756 .20601 L
.37893 .20601 L
.3801 .20601 L
.38138 .20601 L
.38276 .20601 L
.38353 .20601 L
.38424 .20601 L
.38561 .20601 L
Mistroke
.38691 .20601 L
.38801 .20601 L
.38923 .20601 L
.3905 .20601 L
.39169 .20601 L
.3928 .20601 L
.39382 .20601 L
.39494 .20601 L
.39612 .20601 L
.39732 .20601 L
.3986 .20601 L
.3998 .20601 L
.4009 .20601 L
.40219 .20601 L
.40359 .20601 L
.40491 .20601 L
.40613 .20601 L
.40745 .20601 L
.4087 .20601 L
.40982 .20601 L
.41104 .20601 L
.41237 .20601 L
.41378 .20601 L
.41512 .20601 L
.41632 .20601 L
.41755 .20601 L
.41868 .20601 L
.41992 .20601 L
.42123 .20601 L
.42237 .20601 L
.42344 .20601 L
.4246 .20601 L
.42585 .20601 L
.42731 .20601 L
.42865 .20601 L
.43012 .20601 L
.43087 .20601 L
.43169 .20601 L
.43306 .20601 L
.43453 .20601 L
.43593 .20601 L
.4372 .20601 L
.43851 .20601 L
.43973 .20601 L
.44107 .20601 L
.4425 .20601 L
.44386 .20601 L
.44514 .20601 L
.44629 .20601 L
.44753 .20601 L
Mistroke
.44883 .20601 L
.45002 .20601 L
.45139 .20601 L
.45269 .20601 L
.45389 .20601 L
.455 .20601 L
.45622 .20601 L
.45751 .20601 L
.4588 .20601 L
.46019 .20601 L
.46151 .20601 L
.46272 .20601 L
.46405 .20601 L
.46551 .20601 L
.46704 .20601 L
.46846 .20601 L
.46985 .20601 L
.47134 .20601 L
.47276 .20601 L
.47406 .20601 L
.47524 .20601 L
.47654 .20601 L
.47789 .20601 L
.47916 .20601 L
.48063 .20601 L
.48203 .20601 L
.48329 .20601 L
.48466 .20601 L
.48615 .20601 L
.48773 .20601 L
.48923 .20601 L
.49058 .20601 L
.49185 .20601 L
.49303 .20601 L
.49432 .20601 L
.49571 .20601 L
.49717 .20601 L
.49855 .20601 L
.49979 .20601 L
.50113 .20601 L
.50229 .20601 L
.50357 .20601 L
.50491 .20601 L
.50617 .20601 L
.50734 .20601 L
.50841 .20601 L
.50959 .20601 L
.51082 .20601 L
.5122 .20601 L
.51345 .20601 L
Mistroke
.51489 .20601 L
.51624 .20601 L
.5175 .20601 L
.51866 .20601 L
.51993 .20601 L
.52128 .20601 L
.52264 .20601 L
.52409 .20601 L
.52547 .20601 L
.52672 .20601 L
.52819 .20601 L
.52979 .20601 L
.5313 .20601 L
.5327 .20601 L
.53393 .20601 L
.53523 .20601 L
.53755 .20601 L
.53885 .20601 L
.54005 .20601 L
.54137 .20601 L
.54279 .20601 L
.54401 .20601 L
.54534 .20601 L
.54651 .20601 L
.54775 .20601 L
.54887 .20601 L
.5501 .20601 L
.55227 .20601 L
.55371 .20601 L
.55508 .20601 L
.55631 .20601 L
.55765 .20601 L
.5591 .20601 L
.56065 .20601 L
.56211 .20601 L
.56343 .20601 L
.56602 .20601 L
.56748 .20601 L
.56882 .20601 L
.57129 .20601 L
.57253 .20601 L
.57389 .20601 L
.57653 .20601 L
.57802 .20601 L
.5794 .20601 L
.58193 .20601 L
.5832 .20601 L
.58461 .20601 L
.58704 .20601 L
.5884 .20601 L
Mistroke
.58966 .20601 L
.59196 .20601 L
.59312 .20601 L
.59439 .20601 L
.59587 .20601 L
.59727 .20601 L
.59989 .20601 L
.60136 .20601 L
.60271 .20601 L
.6042 .20601 L
.60577 .20601 L
.60702 .20601 L
.60837 .20601 L
.61081 .20601 L
.61229 .20601 L
.61371 .20601 L
.61635 .20601 L
.61766 .20601 L
.61908 .20601 L
.62033 .20601 L
.62165 .20601 L
.62415 .20601 L
.62645 .20601 L
.62773 .20601 L
.62911 .20601 L
.63158 .20601 L
.63309 .20601 L
.63452 .20601 L
.6358 .20601 L
.6372 .20601 L
.63954 .20601 L
.64202 .20601 L
.64431 .20601 L
.64646 .20601 L
.64899 .20601 L
.65131 .20601 L
.65398 .20601 L
.65652 .20601 L
.65924 .20601 L
.6618 .20601 L
.6641 .20601 L
.66658 .20601 L
.6693 .20601 L
.67217 .20601 L
.67462 .20601 L
.67731 .20601 L
.67983 .20601 L
.68212 .20601 L
.68477 .20601 L
.68729 .20601 L
Mistroke
.68961 .20601 L
.69175 .20601 L
.69411 .20601 L
.69661 .20601 L
.69911 .20601 L
.70174 .20601 L
.70398 .20601 L
.70644 .20601 L
.70909 .20601 L
.71193 .20601 L
.71461 .20601 L
.71704 .20601 L
.7195 .20601 L
.72177 .20601 L
.72427 .20601 L
.72691 .20601 L
.73135 .20601 L
.73387 .20601 L
.73623 .20601 L
.73894 .20601 L
.74145 .20601 L
.74421 .20601 L
.74715 .20601 L
.74995 .20601 L
.75259 .20601 L
.75499 .20601 L
.75752 .20601 L
.75984 .20601 L
.76239 .20601 L
.76687 .206 L
.76939 .206 L
.7721 .206 L
.77698 .206 L
.77967 .20599 L
.78254 .20599 L
.78768 .20598 L
.79053 .20597 L
.79321 .20596 L
.79931 .20593 L
.80462 .2059 L
.80948 .20586 L
.81482 .2058 L
.82044 .20571 L
.82571 .20561 L
.83048 .20549 L
.83563 .20533 L
.8412 .20512 L
.85113 .20462 L
.86049 .204 L
.88098 .20217 L
Mistroke
.89184 .20111 L
.89782 .20057 L
.9035 .20014 L
.90609 .19998 L
.90885 .19983 L
.91029 .19977 L
.91188 .19971 L
.91334 .19967 L
.91468 .19964 L
.91592 .19962 L
.91722 .1996 L
.91852 .1996 L
.91926 .1996 L
.91995 .19961 L
.9212 .19963 L
.92234 .19965 L
.92366 .19968 L
.9249 .19973 L
.92732 .19984 L
.92989 .2 L
.93449 .20039 L
.93945 .20096 L
.94491 .20175 L
.967 .20608 L
.97736 .20821 L
.98721 .20991 L
.99333 .21072 L
1 .21136 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13039,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo00?ooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooo
oom5ooooo`001Ol00002ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Gooooo00?o
0000ooooooooool0oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo00Co
A4A4omgMgOoooooo00001_ooool3o`000?ooooooAOooool000Oooooo00Go0000oooooooooooooooo
o`00000;ooooo`04omgMgOmEEEGoooooo`0000Kooooo00?o0000ooooooooool0oooooom5ooooo`00
1oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001_ooool00ol0003o
ooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^ko
A4A4o`000006ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Gooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool5o`0000Gooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool00ol0003oooooooooo`3oooooodGooooo0005o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0oooooom5ooooo`001ooo
ool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01Oooool3o`000?oooooo
AOooool000Oooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Cooooo
00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Gooooo00?o0000oooooooo
ool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c005ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo027ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@0Iooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l00000
0ol@413oooooooooo`0Gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l0
00001Ol@413oooooooooooooooooA4A400;o000000?o<S8bomgMgOooool06?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM03Wooooo000Qoooo
o`;o00008_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01oooool00omgMgOo<S8booooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B47ooooo`03o`000?oooooooooo00Kooooo00?oMgMgoc8b<_ooool06?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@06_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1oooool00omgMgOo<S8booooo`0hooooo`008Oooool00ol0003oooooooooo`0Qooooo`05oa0@4?oo
ooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000oooooooo
ool05oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool06Oooool01Ol@
413ooooooooooooooooo410@00kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0G
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Kooooo`05oa0@4?oo
ooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo03Oooooo
000Qooooo`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`00
0?ooooooooooooooool000001oooool00omgMgOo<S8booooo`0Hooooo`05o`000?oooooooooooooo
ool000003_ooool00ol0003oooooooooo`0Iooooo`05o`000?ooooooooooooooool000003_ooool0
0ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo01Sooooo00Go0000ooooooooooooooooo`00
000=ooooo`03oiRHV?lQ8B7ok^k^01[ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool0>?ooool0027ooooo00?o0000ooooooooool08Ooo
ool01Ol0003ooooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000004ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`06Oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000
ooooooooool06Oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<01Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo01Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00iooooo`008Oooool00ol0003oooooooooo`0Qoooo
o`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00Cooooo00?o
0000ooooooooool06oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool0
6Oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Kooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`0Hoooo
o`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo03_ooooo000Qooooo`03o`000?oooooooooo027ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00ol0003oooooooooo`0Kooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`0Iooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01_ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41006_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo03_ooooo
000Qooooo`;o00008_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP04ooooo`Co00006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIV
I_l000006oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l000001Oooool4
o`0001[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
6_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004oooo
o`Co0000>_ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo>_ooool00ol@413o0000o`00
0003o`0000Gooooo000Qooooo`03o`000?oooooooooo0?oooooo3oooool>o`0001oooooo00?o0000
ooooooooool01_ooool0027ooooo00?o0000ooooooooool0ooooool4ooooo`_o00003_ooool6o`00
01Wooooo00?o0000ooooooooool01_ooool0027oooooool0000co`0000cooooo00?o0000oooooooo
ool01_ooool0027ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Go00003oooool00ol0003o<S8bomgMg@06ooooo`008Oooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0<?ooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0;Oooool3o`0000_ooooo0_l0
00001?nYZJWo8B4Qo`000?lQ8B44ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Ooo
ool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Q
ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0
027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGo
oooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1?ooool5o`0000Gooooo00?o0000ooooooooool0oooooom5ooooo`001ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@01Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@
41003?ooool00onHV9So8B4Qonk^kP06ooooo`?o0000oooooom5ooooo`001oooool01Ol0003ooooo
oooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01Oooool00ol0003oooooooooo`3oooooodGo
oooo0007ooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`04ooooo`03
o`000?oooooooooo0?ooooooAOooool000Oooooo00Go410@oooooooooooooooooa0@400?ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4005ooooo`03o`000?oooooooooo
0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`01Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6oooo
o`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o
000000?o410@ooooooooool00oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Go
oooo0ol0003oooooodGooooo0007ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4Co
gMgMooooool00006ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go0000oooooooo
ooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Kooooo00?o0000ooooooooool0oooooom5
ooooo`001oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001_ooool0
0ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool0
0oo^k^koA4A4o`000006ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Gooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oo
ooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool2o`000?ooooooA_oo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Gooooo00?o0000oooo
ooooool0oooooom5ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44oooo
o`05oeEEEOmgMgOooooooiRHV?lQ8B401Oooool00ol0003oooooooooo`3oooooodGooooo0007oooo
o`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Gooooo0ol0
003oooooodGooooo0007ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooo
oonHV9So8B4Q00Gooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol0003ooooooooo
oooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c005ooooo`03o`000?oooooooooo0?oo
ooooAOooool000Oooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo00Oo
oooo00?o0000ooooooooool0oooooom5ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00?ogMgMoa0@4?nHV9P01oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4105ooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool2o`000?oooooo
A_ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooo
oom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003o
ooooodKooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c005ooooo`03
o`000?oooooooooo0?ooooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Gooooo00?o0000ooooooooool0oooooom5oooo
o`001oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000005
ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go0000ooooooooooooooooo`00000;
ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801Oooool3o`000?ooooooAOooool000Oooooo00Go0000
ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`01Oooool00ol0003ooooo
ooooo`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zj
oooooonj^[[o410@00Gooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000005ooooo`03o`000?oooooooooo
0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000
oa0@4?nYZJT01Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qooooo`03o`000?oooooooooo0?oooooo
AOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3o
ooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`006?ooool4o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool0
oooooom5ooooo`006_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOoo
ool001[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Joooo
o`03o`000?oooooooooo00Cooooo0ol0003oooooodGooooo000Jooooo`03o`000?oooooooooo0?oo
ooooC?ooool001[ooooo00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003ooooooooo
o`3oooooodcooooo000Hooooo`03oeEEEOmVIVKo00000?ooooooC_ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool009kooooo00GoV9RHo`000?l0003oA4A4okZj^P0Hooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00003ooooo`04oa0@4?l0003oA4A4olc<
c97ooooo000Oooooo`04oa0@4?l0003o0000o`0007_ooooo00Go410@okZj^_o^k^koMgMgoa0@4009
ooooo`Ko00002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@01Oooool00onHV9So410@omgMg@2@ooooo`008?ooool00ol0003ooooooooo
o`1kooooo`03o`000?oooooooooo01[ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?oQhN7oeEEEOooool0Soooool0023ooooo00?o0000ooooooooool0Nooo
ool00ol0003oooooooooo`0;ooooo`Ko00002Oooool01Ol0003ooooooooooooooooo000000gooooo
00?oV9RHob4Q8Oo^k^h00oooool01Oo<c<co8B4Qo`000?mEEEGo0000093ooooo000Pooooo`06o`00
0?mgMgOo0000o`000?mEEEGok^k^N?ooool00ol0003oooooooooo`0Jooooo`05o`000?oooooooooo
ooooool000003_ooool00omgMgOoIVIVooooo`02ooooo`05ob4Q8On7QhOooooooiRHV?l00000T?oo
ool0023ooooo00Ko0000oeEEEOo^k^koooooogMgMomEEEEfooooo`03oa0@4?l0003o000000?o0000
6Oooool01Ol@413ooooooooooooooooo410@00oooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooooooo08kooooo000Pooooo`03o`000?o^k^kooooo00;ooooo00?o0000oooooooo
ool0M_ooool00ol0003oooooooooo`0Jooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[ZjoooooonHV9So410@00?ooooo00Go8B4QoiRHV?ooooooMgMgoeEEE@2@ooooo`008?ooool0
0ol0003ok^k^ooooo`02ooooo`03o`000?oooooooooo07Kooooo00?o0000ooooooooool06_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05olc<
c?l@413o0000oc8b<_o^k^h0T?ooool0023ooooo00Ko0000oeEEEOo^k^koooooogMgMomVIVKooooo
od?ooooo000Oooooo`03oa0@4?l0003oMgMg00;o000000?oIVIVonk^k_ooool0oooooom2ooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.0332543, -0.540631, \
0.00122928, 0.00994506}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0 3.33333 0.206011 0.412023 [
[.16667 .19351 -12 -9 ]
[.16667 .19351 12 0 ]
[.33333 .19351 -9 -9 ]
[.33333 .19351 9 0 ]
[.5 .19351 -12 -9 ]
[.5 .19351 12 0 ]
[.66667 .19351 -9 -9 ]
[.66667 .19351 9 0 ]
[.83333 .19351 -12 -9 ]
[.83333 .19351 12 0 ]
[1.025 .20601 0 -6 ]
[1.025 .20601 10 6 ]
[-0.0125 .0412 -24 -4.5 ]
[-0.0125 .0412 0 4.5 ]
[-0.0125 .12361 -24 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .28842 -18 -4.5 ]
[-0.0125 .28842 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .45322 -18 -4.5 ]
[-0.0125 .45322 0 4.5 ]
[-0.0125 .53563 -18 -4.5 ]
[-0.0125 .53563 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[0 .64303 -5 0 ]
[0 .64303 5 12 ]
[.5 .63053 -23 0 ]
[.5 .63053 23 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.16667 .20601 m
.16667 .21226 L
s
[(0.05)] .16667 .19351 0 1 Mshowa
.33333 .20601 m
.33333 .21226 L
s
[(0.1)] .33333 .19351 0 1 Mshowa
.5 .20601 m
.5 .21226 L
s
[(0.15)] .5 .19351 0 1 Mshowa
.66667 .20601 m
.66667 .21226 L
s
[(0.2)] .66667 .19351 0 1 Mshowa
.83333 .20601 m
.83333 .21226 L
s
[(0.25)] .83333 .19351 0 1 Mshowa
.125 Mabswid
.03333 .20601 m
.03333 .20976 L
s
.06667 .20601 m
.06667 .20976 L
s
.1 .20601 m
.1 .20976 L
s
.13333 .20601 m
.13333 .20976 L
s
.2 .20601 m
.2 .20976 L
s
.23333 .20601 m
.23333 .20976 L
s
.26667 .20601 m
.26667 .20976 L
s
.3 .20601 m
.3 .20976 L
s
.36667 .20601 m
.36667 .20976 L
s
.4 .20601 m
.4 .20976 L
s
.43333 .20601 m
.43333 .20976 L
s
.46667 .20601 m
.46667 .20976 L
s
.53333 .20601 m
.53333 .20976 L
s
.56667 .20601 m
.56667 .20976 L
s
.6 .20601 m
.6 .20976 L
s
.63333 .20601 m
.63333 .20976 L
s
.7 .20601 m
.7 .20976 L
s
.73333 .20601 m
.73333 .20976 L
s
.76667 .20601 m
.76667 .20976 L
s
.8 .20601 m
.8 .20976 L
s
.86667 .20601 m
.86667 .20976 L
s
.9 .20601 m
.9 .20976 L
s
.93333 .20601 m
.93333 .20976 L
s
.96667 .20601 m
.96667 .20976 L
s
.25 Mabswid
0 .20601 m
1 .20601 L
s
gsave
1.025 .20601 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .0412 m
.00625 .0412 L
s
[(-0.4)] -0.0125 .0412 1 0 Mshowa
0 .12361 m
.00625 .12361 L
s
[(-0.2)] -0.0125 .12361 1 0 Mshowa
0 .28842 m
.00625 .28842 L
s
[(0.2)] -0.0125 .28842 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.4)] -0.0125 .37082 1 0 Mshowa
0 .45322 m
.00625 .45322 L
s
[(0.6)] -0.0125 .45322 1 0 Mshowa
0 .53563 m
.00625 .53563 L
s
[(0.8)] -0.0125 .53563 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0618 m
.00375 .0618 L
s
0 .0824 m
.00375 .0824 L
s
0 .10301 m
.00375 .10301 L
s
0 .14421 m
.00375 .14421 L
s
0 .16481 m
.00375 .16481 L
s
0 .18541 m
.00375 .18541 L
s
0 .22661 m
.00375 .22661 L
s
0 .24721 m
.00375 .24721 L
s
0 .26781 m
.00375 .26781 L
s
0 .30902 m
.00375 .30902 L
s
0 .32962 m
.00375 .32962 L
s
0 .35022 m
.00375 .35022 L
s
0 .39142 m
.00375 .39142 L
s
0 .41202 m
.00375 .41202 L
s
0 .43262 m
.00375 .43262 L
s
0 .47383 m
.00375 .47383 L
s
0 .49443 m
.00375 .49443 L
s
0 .51503 m
.00375 .51503 L
s
0 .55623 m
.00375 .55623 L
s
0 .57683 m
.00375 .57683 L
s
0 .59743 m
.00375 .59743 L
s
0 .0206 m
.00375 .0206 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
gsave
0 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.5 .63053 -84 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
75.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0.3) show
105.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .20601 m
.00123 .20601 L
.00236 .20601 L
.00365 .20601 L
.00488 .20601 L
.00601 .20601 L
.00706 .20601 L
.00821 .20601 L
.00942 .20601 L
.01065 .20601 L
.01196 .20601 L
.0132 .20601 L
.01434 .20601 L
.01566 .20601 L
.01641 .20601 L
.01711 .20601 L
.01839 .20601 L
.01975 .20601 L
.02043 .20601 L
.02115 .20601 L
.02245 .20601 L
.02317 .20601 L
.02384 .20601 L
.02458 .20601 L
.02537 .20601 L
.02605 .20601 L
.02679 .20601 L
.02814 .20601 L
.02945 .20601 L
.03067 .20601 L
.03184 .20601 L
.03295 .20601 L
.03416 .20601 L
.03547 .20601 L
.03676 .20601 L
.03813 .20601 L
.03929 .20601 L
.04057 .20601 L
.04131 .20601 L
.042 .20601 L
.04275 .20601 L
.04355 .20601 L
.0449 .20601 L
.04566 .20601 L
.04637 .20601 L
.0477 .20601 L
.04892 .20601 L
.04959 .20601 L
.05032 .20601 L
.05165 .20601 L
Mistroke
.05245 .20601 L
.05321 .20601 L
.05389 .20601 L
.05462 .20601 L
.05543 .20601 L
.05627 .20601 L
.057 .20601 L
.05779 .20601 L
.05854 .20601 L
.05921 .20601 L
.06 .20601 L
.06074 .20601 L
.06205 .20601 L
.0628 .20601 L
.06349 .20601 L
.06471 .20601 L
.06603 .20601 L
.06727 .20601 L
.06841 .20601 L
.06967 .20601 L
.07105 .20601 L
.07175 .20601 L
.07249 .20601 L
.07383 .20601 L
.07457 .20601 L
.07525 .20601 L
.076 .20601 L
.07679 .20601 L
.07812 .20601 L
.07888 .20601 L
.07959 .20601 L
.0809 .20601 L
.08211 .20601 L
.08349 .20601 L
.08481 .20601 L
.086 .20601 L
.08729 .20601 L
.0885 .20601 L
.08962 .20601 L
.09085 .20601 L
.0922 .20601 L
.09289 .20601 L
.09361 .20601 L
.09493 .20601 L
.09565 .20601 L
.09632 .20601 L
.09705 .20601 L
.09783 .20601 L
.09913 .20601 L
.09987 .20601 L
Mistroke
.10056 .20601 L
.10185 .20601 L
.10303 .20601 L
.10439 .20601 L
.10569 .20601 L
.10691 .20601 L
.10801 .20601 L
.10928 .20601 L
.11048 .20601 L
.1116 .20601 L
.11262 .20601 L
.11375 .20601 L
.11493 .20601 L
.11613 .20601 L
.11742 .20601 L
.11864 .20601 L
.11974 .20601 L
.12104 .20601 L
.12178 .20601 L
.12245 .20601 L
.1237 .20601 L
.12502 .20601 L
.12622 .20601 L
.12753 .20601 L
.12889 .20601 L
.13016 .20601 L
.13135 .20601 L
.13244 .20601 L
.13369 .20601 L
.13487 .20601 L
.13616 .20601 L
.13752 .20601 L
.13868 .20601 L
.13996 .20601 L
.14134 .20601 L
.14211 .20601 L
.14281 .20601 L
.14418 .20601 L
.14548 .20601 L
.14669 .20601 L
.14779 .20601 L
.14906 .20601 L
.15025 .20601 L
.15136 .20601 L
.15237 .20601 L
.15349 .20601 L
.15467 .20601 L
.15586 .20601 L
.15714 .20601 L
.15835 .20601 L
Mistroke
.15945 .20601 L
.16074 .20601 L
.16146 .20601 L
.16214 .20601 L
.16337 .20601 L
.16468 .20601 L
.16594 .20601 L
.16732 .20601 L
.16863 .20601 L
.16984 .20601 L
.17103 .20601 L
.17212 .20601 L
.17337 .20601 L
.17456 .20601 L
.17585 .20601 L
.17721 .20601 L
.17838 .20601 L
.17966 .20601 L
.18104 .20601 L
.18181 .20601 L
.18251 .20601 L
.18388 .20601 L
.18518 .20601 L
.18628 .20601 L
.1875 .20601 L
.18877 .20601 L
.18996 .20601 L
.19107 .20601 L
.19209 .20601 L
.19321 .20601 L
.19438 .20601 L
.19558 .20601 L
.19686 .20601 L
.19807 .20601 L
.19916 .20601 L
.20045 .20601 L
.20118 .20601 L
.20185 .20601 L
.20309 .20601 L
.20439 .20601 L
.20566 .20601 L
.20705 .20601 L
.20835 .20601 L
.20957 .20601 L
.21077 .20601 L
.21186 .20601 L
.21311 .20601 L
.2143 .20601 L
.21559 .20601 L
.21696 .20601 L
Mistroke
.21813 .20601 L
.21941 .20601 L
.22079 .20601 L
.22157 .20601 L
.22227 .20601 L
.22364 .20601 L
.22494 .20601 L
.22604 .20601 L
.22726 .20601 L
.22853 .20601 L
.22973 .20601 L
.23084 .20601 L
.23186 .20601 L
.23297 .20601 L
.23415 .20601 L
.23535 .20601 L
.23663 .20601 L
.23784 .20601 L
.23893 .20601 L
.24023 .20601 L
.24095 .20601 L
.24163 .20601 L
.24286 .20601 L
.24416 .20601 L
.24544 .20601 L
.24683 .20601 L
.24814 .20601 L
.24935 .20601 L
.25044 .20601 L
.25165 .20601 L
.25291 .20601 L
.25409 .20601 L
.25539 .20601 L
.25676 .20601 L
.25793 .20601 L
.25922 .20601 L
.2606 .20601 L
.26137 .20601 L
.26208 .20601 L
.26345 .20601 L
.26475 .20601 L
.26586 .20601 L
.26708 .20601 L
.26835 .20601 L
.26954 .20601 L
.27066 .20601 L
.27168 .20601 L
.27286 .20601 L
.27397 .20601 L
.27518 .20601 L
Mistroke
.27646 .20601 L
.27767 .20601 L
.27876 .20601 L
.28005 .20601 L
.28078 .20601 L
.28145 .20601 L
.28268 .20601 L
.28399 .20601 L
.28527 .20601 L
.28599 .20601 L
.28666 .20601 L
.28789 .20601 L
.28919 .20601 L
.29036 .20601 L
.29145 .20601 L
.29265 .20601 L
.29394 .20601 L
.29524 .20601 L
.29597 .20601 L
.29665 .20601 L
.29803 .20601 L
.29881 .20601 L
.29951 .20601 L
.30077 .20601 L
.30213 .20601 L
.30342 .20601 L
.30461 .20601 L
.30572 .20601 L
.30691 .20601 L
.30804 .20601 L
.30907 .20601 L
.31027 .20601 L
.31158 .20601 L
.31282 .20601 L
.31396 .20601 L
.31526 .20601 L
.31648 .20601 L
.31758 .20601 L
.31876 .20601 L
.32005 .20601 L
.32142 .20601 L
.32259 .20601 L
.32386 .20601 L
.32524 .20601 L
.32651 .20601 L
.32718 .20601 L
.32791 .20601 L
.32868 .20601 L
.32939 .20601 L
.33069 .20601 L
Mistroke
.3314 .20601 L
.33208 .20601 L
.33329 .20601 L
.33461 .20601 L
.3359 .20601 L
.33707 .20601 L
.33841 .20601 L
.33968 .20601 L
.34086 .20601 L
.34195 .20601 L
.34314 .20601 L
.3444 .20601 L
.34576 .20601 L
.34701 .20601 L
.3477 .20601 L
.34845 .20601 L
.34981 .20601 L
.35108 .20601 L
.35244 .20601 L
.35359 .20601 L
.35487 .20601 L
.35559 .20601 L
.35636 .20601 L
.35772 .20601 L
.35848 .20601 L
.35919 .20601 L
.36002 .20601 L
.3608 .20601 L
.36148 .20601 L
.36221 .20601 L
.36349 .20601 L
.36422 .20601 L
.36499 .20601 L
.36637 .20601 L
.36764 .20601 L
.36902 .20601 L
.37033 .20601 L
.37154 .20601 L
.37274 .20601 L
.37383 .20601 L
.37509 .20601 L
.37627 .20601 L
.37756 .20601 L
.37893 .20601 L
.3801 .20601 L
.38138 .20601 L
.38276 .20601 L
.38353 .20601 L
.38424 .20601 L
.38561 .20601 L
Mistroke
.38691 .20601 L
.38801 .20601 L
.38923 .20601 L
.3905 .20601 L
.39169 .20601 L
.3928 .20601 L
.39382 .20601 L
.39494 .20601 L
.39612 .20601 L
.39732 .20601 L
.3986 .20601 L
.3998 .20601 L
.4009 .20601 L
.40219 .20601 L
.40292 .20601 L
.40359 .20601 L
.40482 .20601 L
.40613 .20601 L
.4074 .20601 L
.40879 .20601 L
.4101 .20601 L
.41132 .20601 L
.41252 .20601 L
.41361 .20601 L
.41487 .20601 L
.41605 .20601 L
.41735 .20601 L
.41872 .20601 L
.41989 .20601 L
.42117 .20601 L
.42256 .20601 L
.42333 .20601 L
.42404 .20601 L
.42541 .20601 L
.4267 .20601 L
.42781 .20601 L
.42903 .20601 L
.43031 .20601 L
.4315 .20601 L
.43261 .20601 L
.43363 .20601 L
.43481 .20601 L
.43593 .20601 L
.43713 .20601 L
.43841 .20601 L
.43962 .20601 L
.44071 .20601 L
.44201 .20601 L
.4434 .20601 L
.44472 .20601 L
Mistroke
.44594 .20601 L
.44726 .20601 L
.44852 .20601 L
.44965 .20601 L
.45087 .20601 L
.4522 .20601 L
.45362 .20601 L
.45483 .20601 L
.45616 .20601 L
.45739 .20601 L
.45853 .20601 L
.45977 .20601 L
.46108 .20601 L
.46222 .20601 L
.46329 .20601 L
.46445 .20601 L
.4657 .20601 L
.46716 .20601 L
.46851 .20601 L
.46998 .20601 L
.47073 .20601 L
.47155 .20601 L
.47292 .20601 L
.4744 .20601 L
.47579 .20601 L
.47707 .20601 L
.47838 .20601 L
.4796 .20601 L
.48094 .20601 L
.48237 .20601 L
.48373 .20601 L
.48501 .20601 L
.48615 .20601 L
.4874 .20601 L
.4887 .20601 L
.4899 .20601 L
.49127 .20601 L
.49257 .20601 L
.49378 .20601 L
.49489 .20601 L
.49611 .20601 L
.4974 .20601 L
.4987 .20601 L
.50009 .20601 L
.50141 .20601 L
.50262 .20601 L
.50396 .20601 L
.50542 .20601 L
.50695 .20601 L
.50837 .20601 L
Mistroke
.50976 .20601 L
.51126 .20601 L
.51268 .20601 L
.51398 .20601 L
.51516 .20601 L
.51646 .20601 L
.51781 .20601 L
.51908 .20601 L
.52055 .20601 L
.52196 .20601 L
.52322 .20601 L
.52459 .20601 L
.52607 .20601 L
.52766 .20601 L
.52901 .20601 L
.5305 .20601 L
.53177 .20601 L
.53296 .20601 L
.53426 .20601 L
.53565 .20601 L
.53711 .20601 L
.53849 .20601 L
.53973 .20601 L
.54108 .20601 L
.54224 .20601 L
.54353 .20601 L
.54487 .20601 L
.54613 .20601 L
.5473 .20601 L
.54837 .20601 L
.54964 .20601 L
.55079 .20601 L
.55213 .20601 L
.55357 .20601 L
.5549 .20601 L
.55615 .20601 L
.55762 .20601 L
.55897 .20601 L
.56045 .20601 L
.56201 .20601 L
.56328 .20601 L
.56464 .20601 L
.56592 .20601 L
.56709 .20601 L
.56847 .20601 L
.56996 .20601 L
.57137 .20601 L
.57267 .20601 L
.57391 .20601 L
.57521 .20601 L
Mistroke
.57754 .20601 L
.57884 .20601 L
.58005 .20601 L
.58137 .20601 L
.58279 .20601 L
.58402 .20601 L
.58535 .20601 L
.58652 .20601 L
.58776 .20601 L
.58888 .20601 L
.59012 .20601 L
.59228 .20601 L
.59373 .20601 L
.5951 .20601 L
.59633 .20601 L
.59767 .20601 L
.59913 .20601 L
.60068 .20601 L
.60214 .20601 L
.60346 .20601 L
.60605 .20601 L
.60751 .20601 L
.60885 .20601 L
.61132 .20601 L
.61256 .20601 L
.61392 .20601 L
.61657 .20601 L
.61806 .20601 L
.61945 .20601 L
.62198 .20601 L
.62326 .20601 L
.62467 .20601 L
.6271 .20601 L
.62847 .20601 L
.62972 .20601 L
.63088 .20601 L
.63215 .20601 L
.63446 .20601 L
.63595 .20601 L
.63735 .20601 L
.63997 .20601 L
.64144 .20601 L
.6428 .20601 L
.64438 .20601 L
.64585 .20601 L
.6483 .20601 L
.6496 .20601 L
.651 .20601 L
.65246 .20601 L
.65384 .20601 L
Mistroke
.65509 .20601 L
.65644 .20601 L
.65892 .20601 L
.66125 .20601 L
.6626 .20601 L
.66402 .20601 L
.66656 .20601 L
.66785 .20601 L
.66923 .20601 L
.6717 .20601 L
.67322 .20601 L
.67465 .20601 L
.67733 .20601 L
.67967 .20601 L
.68215 .20601 L
.68427 .20601 L
.6866 .20601 L
.68911 .20601 L
.6918 .20601 L
.69434 .20601 L
.69666 .20601 L
.6993 .20601 L
.70168 .20601 L
.70443 .20601 L
.70702 .20601 L
.70943 .20601 L
.71164 .20601 L
.71406 .20601 L
.71663 .20601 L
.71922 .20601 L
.722 .20601 L
.72462 .20601 L
.72701 .20601 L
.72981 .20601 L
.73286 .20601 L
.73574 .20601 L
.7384 .20601 L
.74094 .20601 L
.74327 .20601 L
.74583 .20601 L
.74852 .20601 L
.75087 .20601 L
.75306 .20601 L
.75546 .20601 L
.75802 .20601 L
.76082 .20601 L
.76386 .20601 L
.76672 .20601 L
.76936 .20601 L
.77175 .20601 L
Mistroke
.77437 .20601 L
.7771 .20601 L
.77966 .20601 L
.7849 .20601 L
.78786 .20601 L
.79061 .20601 L
.79564 .20601 L
.79818 .20601 L
.80099 .206 L
.80582 .206 L
.80854 .206 L
.81103 .206 L
.81562 .20599 L
.82046 .20598 L
.8257 .20596 L
.83046 .20595 L
.83596 .20592 L
.84115 .20588 L
.84596 .20583 L
.85039 .20578 L
.85526 .2057 L
.86043 .20559 L
.87031 .20531 L
.87586 .2051 L
.88094 .20486 L
.89079 .20429 L
.90016 .20359 L
.92119 .20165 L
.93035 .20083 L
.93517 .20046 L
.94026 .20015 L
.9429 .20002 L
.9443 .19997 L
.9458 .19992 L
.94718 .19988 L
.94844 .19985 L
.9497 .19984 L
.9509 .19983 L
.95211 .19983 L
.95339 .19983 L
.95449 .19985 L
.9557 .19987 L
.957 .19991 L
.95839 .19995 L
.96092 .20007 L
.96359 .20023 L
.96652 .20047 L
.97241 .20109 L
.97787 .20183 L
.98294 .20266 L
Mistroke
1 .20601 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  AnimationDisplayTime->0.13039,
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5
ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oo
oooooooo00?ooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooo
oom5ooooo`001Ol00002ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Gooooo00?o
0000ooooooooool0oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo00Co
A4A4omgMgOoooooo00001_ooool3o`000?ooooooAOooool000Oooooo00Go0000oooooooooooooooo
o`00000;ooooo`04omgMgOmEEEGoooooo`0000Kooooo00?o0000ooooooooool0oooooom5ooooo`00
1oooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001_ooool00ol0003o
ooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^ko
A4A4o`000006ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Gooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOoo
ool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3ooooo
odGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool5o`0000Gooooo00?o0000ooooooooool0oooooom5ooooo`001oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1Oooool00ol0003oooooooooo`3oooooodGooooo0005o`0000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0oooooom5ooooo`001ooo
ool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01Oooool3o`000?oooooo
AOooool000Oooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Cooooo
00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413ooooooooooooooooo410@00oooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Gooooo00?o0000oooooooo
ool0oooooom5ooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c005ooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooooooo
ool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooo
oom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo
0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo027ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo00GoA4A4o`000?l0
003o<S8bomgMg@0Iooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l00000
0ol@413oooooooooo`0Gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo1?l0
00001Ol@413oooooooooooooooooA4A400;o000000?o<S8bomgMgOooool06?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM03Wooooo000Qoooo
o`;o00008_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01oooool00omgMgOo<S8booooo`0Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Oooooo00?o0000ooooooooool06Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B47ooooo`03o`000?oooooooooo00Kooooo00?oMgMgoc8b<_ooool06?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@06_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1oooool00omgMgOo<S8booooo`0hooooo`008Oooool00ol0003oooooooooo`0Qooooo`05oa0@4?oo
ooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000oooooooo
ool05oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool06Oooool01Ol@
413ooooooooooooooooo410@00kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0G
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP0Kooooo`05oa0@4?oo
ooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo03Oooooo
000Qooooo`03o`000?oooooooooo027ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`00
0?ooooooooooooooool000001oooool00omgMgOo<S8booooo`0Hooooo`05o`000?oooooooooooooo
ool000003_ooool00ol0003oooooooooo`0Iooooo`05o`000?ooooooooooooooool000003_ooool0
0ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo01Sooooo00Go0000ooooooooooooooooo`00
000=ooooo`03oiRHV?lQ8B7ok^k^01[ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool0>?ooool0027ooooo00?o0000ooooooooool08Ooo
ool01Ol0003ooooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`000004ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`06Oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000
ooooooooool06Oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<01Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03
ogMgMomVIVKooooo01Wooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo
00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c00iooooo`008Oooool00ol0003oooooooooo`0Qoooo
o`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooooooo410@00Cooooo00?o
0000ooooooooool06oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool0
6Oooool01Ol@413ooooooooooooooooo410@00kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Kooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`0Hoooo
o`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo03_ooooo000Qooooo`03o`000?oooooooooo027ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00ol0003oooooooooo`0Kooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03_ooool00ol0003oooooooooo`0Iooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01_ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41006_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo03_ooooo
000Qooooo`;o00008_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP04ooooo`Co00006_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIV
I_l000006oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00?oEEEEofIVI_l000001Oooool4
o`0001[ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0
6_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004oooo
o`Co0000>_ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?oooooo>_ooool00ol@413o0000o`00
0003o`0000Gooooo000Qooooo`03o`000?oooooooooo0?oooooo6Oooool>o`0001Gooooo00?o0000
ooooooooool01_ooool0027ooooo00?o0000ooooooooool0ooooool@ooooo`Wo00003_ooool7o`00
00kooooo00?o0000ooooooooool01_ooool0027oooooool0000co`0000cooooo00?o0000oooooooo
ool01_ooool0027ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo01Cooooo00?o0000oc8b<_oMgMd01_ooool0027ooooo00?o0000ooooooooool0<?oo
ool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0<?oo
ool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo03_ooooo0_l000001?nYZJWo8B4Qo`00
0?lQ8B44ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool2o`000?oo
ooooA_ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003ooooooooo
o`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qooooo`03o`000?oooooo
oooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000oooo
ooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`00
0?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool5o`0000Gooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool00ol0003o
ooooooooo`3oooooodGooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP06ooooo`?o0000oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000go
oooo00?oV9RHob4Q8Oo^k^h01Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05o`00
0?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`04ooooo`03o`000?oooooooooo0?oo
ooooAOooool000Oooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0oooooom5ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_ooooooV9RHoa0@4005ooooo`03o`000?oooooooooo0?ooooooAOooool000Oo
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003o
ooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
1oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@oooooooo
ool00oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooodGo
oooo0007ooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Gooooo0ol0003oooooodGo
oooo0007ooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool00006oooo
o`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Go0000ooooooooooooooooo`00000;oooo
o`04omgMgOmEEEGoooooo`0000Kooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@
413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001_ooool00ol0003oooooooooo`3o
ooooodGooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`000006
ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=
ooooo`03ogMgMol0003ooooo00Gooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003ooooo
ooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qooooo`03o`000?oo
oooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0
003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo
00?o0000ooooooooool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o0000
ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`03
o`000?oooooooooo0?ooooooAOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Gooooo00?o0000ooooooooool0oooooom5oooo
o`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooo
oiRHV?lQ8B401Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol0003ooooooooooooooooo000000Gooooo0ol0003oooooodGooooo0007
ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Gooooo
00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol0003ooooooooooooooooo000000_ooooo
00Go0000oeEEEOl0003o410@olc<c005ooooo`03o`000?oooooooooo0?ooooooAOooool000Oooooo
00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo00Oooooo00?o0000oooooooo
ool0oooooom5ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nH
V9P01oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h03?ooool01?o<c<coA4A4o`000?l@4105ooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool2o`000?ooooooA_ooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo000Qooooo`;o0000oooooom6ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo0_l0003oooooodKooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool00ol0003oooooooooo`3oooooodGooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c005ooooo`03o`000?oooooooooo0?oo
ooooAOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7o
V9RHoooooonHV9So8B4Q00Gooooo00?o0000ooooooooool0oooooom5ooooo`001oooool01Ol@413o
oooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooo
oooo0?ooooooAOooool000Oooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9So
oooooiRHV?lb<S801Oooool3o`000?ooooooAOooool000Oooooo00Go0000ooooooooooooooooo`00
000;ooooo`05olc<c?l0003o0000o`000?o<c<`01Oooool00ol0003oooooooooo`3oooooodGooooo
0007ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Go
oooo00?o0000ooooooooool0oooooom5ooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_oooooo^[Zjo`000005ooooo`03o`000?oooooooooo0?ooooooAOooool000Oo
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo0_l0003oooooodKooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o
0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
8Oooool2o`000?ooooooA_ooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`008Oooool0
0ol0003oooooooooo`3oooooodGooooo000Qooooo`03o`000?oooooooooo0?ooooooAOooool0027o
oooo00?o0000ooooooooool0oooooom5ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo
000Qooooo`;o0000oooooom6ooooo`008Oooool00ol0003oooooooooo`3oooooodGooooo000Qoooo
o`03o`000?oooooooooo0?ooooooAOooool0027ooooo00?o0000ooooooooool0oooooom5ooooo`00
6?ooool4o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool0oooooom5ooooo`006_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?ooooooAOooool001[ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`3oooooodGooooo000Jooooo`03o`000?oooooooooo
00Cooooo0ol0003oooooodGooooo000Jooooo`03o`000?oooooooooo0?ooooooC?ooool001[ooooo
00?o0000ooooooooool0oooooom<ooooo`006_ooool00ol0003oooooooooo`3oooooodcooooo000H
ooooo`03oeEEEOmVIVKo00000?ooooooC_ooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00:;ooooo00GoV9RHo`000?l0003oA4A4okZj^P0Hooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Cooooo00GoV9RHoa0@4?l0003o<S8bolc<c02Dooooo`007oooool01?l@413o
0000o`000?l0001oooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000Wooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01Ol@413o^[ZjoooooomgMgOo<S8b09Cooooo
000Pooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool06_ooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool0T_ooool0023ooooo00?o0000ooooooooool0Oooo
ool00ol0003oooooooooo`0;ooooo`Ko00002Oooool01Ol0003ooooooooooooooooo000000kooooo
00?oZJVYoa0@4?ooool0Toooool0023ooooo00Ko0000ogMgMol0003o0000oeEEEOo^k^ilooooo`03
o`000?oooooooooo01[ooooo00Go0000ooooooooooooooooo`00000=ooooo`03oa0@4?l0003o^[Zj
09Cooooo000Pooooo`06o`000?mEEEGok^k^oooooomgMgOoEEEEN_ooool00ol@413o0000o`000003
o`0001Wooooo00Go410@oooooooooooooooooa0@400>ooooo`03okZj^_lQ8B7ooooo09?ooooo000P
ooooo`03o`000?o^k^kooooo00;ooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`0J
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413oV9RHoooooonj^[[o000009Cooooo
000Pooooo`03o`000?o^k^kooooo00;ooooo00?o0000ooooooooool0N_ooool00ol0003ooooooooo
o`0Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY09Co
oooo000Pooooo`06o`000?mEEEGok^k^oooooomgMgOoIVIVoooooom3ooooo`007oooool00ol@413o
0000ogMgM`02o`000003ofIVI_o^k^kooooo0?oooooo@_ooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.0332543, -0.540631, \
0.00122928, 0.00994506}}]
}, Closed]]
}, Open  ]],

Cell[TextData[{
  "\tThis spherical wave decreases in amplitude as it expands in ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  ". This is to be expected, given that the surface area of the pulse is \
increasing",
  ",",
  " yet the overall energy of the pulse is conserved. The general \
considerations of the previous section imply that the total wave energy \
should scale as ",
  Cell[BoxData[
      \(TraditionalForm\`\(p\^2\) V\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`V\)]],
  " is the volume occupied by the pulse. The radial width of the pulse is \
roughly constant, but the surface area of the pulse is proportional to ",
  Cell[BoxData[
      \(TraditionalForm\`r\^2\)]],
  ". We therefore expect ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  " to be proportional to ",
  Cell[BoxData[
      \(TraditionalForm\`1/r\)]],
  " at the peak of the pulse. This is in fact what Eq. ",
  ButtonBox["(5.1.78)",
    ButtonData:>"(5.1.78)",
    ButtonStyle->"Hyperlink"],
  " implies, for large ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  ".  Interestingly, there is also a negative section to the pulse (a \
pressure rarefaction), trailing the forward peak, even though the initial \
pulse was entirely positive. This does not occur in propagation in one \
dimension along a string, and is a consequence of the spherical geometry."
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Response to a Source", "Section",
  CellTags->"c:15"],

Cell[TextData[{
  "The wave equation with a source ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"S", "(", 
            RowBox[{
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[",",
                FontWeight->"Plain"], 
              StyleBox["t",
                FontWeight->"Plain"]}], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox[" ",
            FontWeight->"Plain"]}], TraditionalForm]]],
  "is "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(\[PartialD]\^2\/\[PartialD]t\^2\), 
            RowBox[{"p", "(", 
              RowBox[{
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox[",",
                  FontWeight->"Plain"], 
                StyleBox["t",
                  FontWeight->"Plain"]}], 
              StyleBox[")",
                FontWeight->"Plain"]}]}], "=", " ", 
          RowBox[{
            RowBox[{\(c\^2\), 
              RowBox[{\(\[Del]\^2\), 
                RowBox[{"p", 
                  StyleBox["(",
                    FontWeight->"Plain"], 
                  RowBox[{
                    StyleBox["r",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], ",", "t"}], ")"}]}]}], " ", "+", 
            RowBox[{"S", "(", 
              RowBox[{
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox[",",
                  FontWeight->"Plain"], 
                StyleBox["t",
                  FontWeight->"Plain"]}], 
              StyleBox[")",
                FontWeight->"Plain"]}]}]}], TraditionalForm]]],
  ","
}], "NumberedEquation",
  CellTags->"(5.1.79)"],

Cell[TextData[{
  "A particular solution for the response to the source can be obtained by \
Fourier transformation in both time and space. We denote the time-space \
Fourier transform of ",
  Cell[BoxData[
      FormBox[
        RowBox[{"p", "(", 
          RowBox[{
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[",",
              FontWeight->"Plain"], 
            StyleBox["t",
              FontWeight->"Plain"]}], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  " as ",
  Cell[BoxData[
      FormBox[Cell[TextData[Cell[BoxData[
            FormBox[
              RowBox[{\(p\&~\), "(", 
                RowBox[{
                  StyleBox["k",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], 
                  StyleBox[",",
                    FontWeight->"Plain"], 
                  StyleBox["\[Omega]",
                    FontWeight->"Plain"]}], 
                StyleBox[")",
                  FontWeight->"Plain"]}], TraditionalForm]]]]], 
        TraditionalForm]]],
  ", where"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(p\&~\), "(", 
            RowBox[{
              StyleBox["k",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[",",
                FontWeight->"Plain"], 
              StyleBox["\[Omega]",
                FontWeight->"Plain"]}], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{"\[Integral]", 
            RowBox[{\(\[DifferentialD]t\), 
              RowBox[{"\[Integral]", 
                RowBox[{
                  RowBox[{\(\[DifferentialD]\^3\), 
                    StyleBox["r",
                      FontWeight->"Bold",
                      FontSlant->"Plain"]}], 
                  StyleBox[" ",
                    FontWeight->"Plain"], 
                  RowBox[{
                    StyleBox["p",
                      FontWeight->"Plain"], 
                    StyleBox["(",
                      FontWeight->"Plain"], 
                    RowBox[{
                      StyleBox["r",
                        FontWeight->"Bold",
                        FontSlant->"Plain"], 
                      StyleBox[",",
                        FontWeight->"Plain"], 
                      StyleBox["t",
                        FontWeight->"Plain"]}], 
                    StyleBox[")",
                      FontWeight->"Plain"]}], 
                  StyleBox[" ",
                    FontWeight->"Plain"], 
                  StyleBox[
                    SuperscriptBox["\[ExponentialE]", 
                      RowBox[{"-", 
                        RowBox[{"\[ImaginaryI]", "(", " ", 
                          RowBox[{
                            RowBox[{
                              StyleBox["k",
                                FontWeight->"Bold",
                                FontSlant->"Plain"], "\[CenterDot]", 
                              StyleBox["r",
                                FontWeight->"Bold",
                                FontSlant->"Plain"]}], 
                            StyleBox["-",
                              FontWeight->"Plain"], 
                            StyleBox[\(\[Omega]\ t\),
                              FontWeight->"Plain"]}], 
                          StyleBox[")",
                            FontWeight->"Plain"]}]}]],
                    FontWeight->"Plain"]}]}]}]}]}], TraditionalForm]]],
  ","
}], "NumberedEquation",
  CellTags->"(5.1.80)"],

Cell[TextData[{
  "and similarly for the time-space transform of the source, ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(S\&~\), "(", 
          RowBox[{
            StyleBox["k",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[",",
              FontWeight->"Plain"], 
            StyleBox["\[Omega]",
              FontWeight->"Plain"]}], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  ". Note the use of differing transform conventions for the time and space \
parts of the transform, as discussed in Sec. ",
  ButtonBox["2.3.1",
    ButtonData:>{"Chapter2.nb", "c:20"},
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[TextData[{
  "\tApplication of the time-space transform to Eq. ",
  ButtonBox["(5.1.79)",
    ButtonData:>"(5.1.79)",
    ButtonStyle->"Hyperlink"],
  " yields the algebraic equation"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(-\[Omega]\^\(\(2\)\(\ \)\)\), 
            RowBox[{\(p\&~\), "(", 
              RowBox[{
                StyleBox["k",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox[",",
                  FontWeight->"Plain"], 
                StyleBox["\[Omega]",
                  FontWeight->"Plain"]}], 
              StyleBox[")",
                FontWeight->"Plain"]}]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{
            RowBox[{
              StyleBox[\(-c\^2\),
                FontWeight->"Plain"], 
              StyleBox[\(k\^2\),
                FontWeight->"Plain"], 
              RowBox[{\(p\&~\), "(", 
                RowBox[{
                  StyleBox["k",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], 
                  StyleBox[",",
                    FontWeight->"Plain"], 
                  StyleBox["\[Omega]",
                    FontWeight->"Plain"]}], 
                StyleBox[")",
                  FontWeight->"Plain"]}]}], 
            StyleBox["+",
              FontWeight->"Plain"], 
            RowBox[{\(S\&~\), "(", 
              RowBox[{
                StyleBox["k",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox[",",
                  FontWeight->"Plain"], 
                StyleBox["\[Omega]",
                  FontWeight->"Plain"]}], 
              StyleBox[")",
                FontWeight->"Plain"]}]}]}], TraditionalForm]]],
  ","
}], "Text"],

Cell[TextData[{
  "which has the solution ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(p\&~\), "(", 
            RowBox[{
              StyleBox["k",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[",",
                FontWeight->"Plain"], 
              StyleBox["\[Omega]",
                FontWeight->"Plain"]}], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{
            RowBox[{\(S\&~\), "(", 
              RowBox[{
                StyleBox["k",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox[",",
                  FontWeight->"Plain"], 
                StyleBox["\[Omega]",
                  FontWeight->"Plain"]}], 
              StyleBox[")",
                FontWeight->"Plain"]}], 
            StyleBox["/",
              FontWeight->"Plain"], 
            StyleBox[\((\(c\^2\) k\^2 - \[Omega]\^2)\),
              FontWeight->"Plain"]}]}], TraditionalForm]]],
  ". Taking an inverse time-space transform then yields the particular \
solution,"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"p", "(", 
            RowBox[{
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[",",
                FontWeight->"Plain"], 
              StyleBox["t",
                FontWeight->"Plain"]}], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{"\[Integral]", 
            
            RowBox[{\(\(\[DifferentialD]\[Omega] \[DifferentialD]\^3 
                      k\)\/\((2\ \[Pi])\)\^4\), 
              FractionBox[
                RowBox[{\(S\&~\), "(", 
                  RowBox[{
                    StyleBox["k",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], 
                    StyleBox[",",
                      FontWeight->"Plain"], 
                    StyleBox["\[Omega]",
                      FontWeight->"Plain"]}], 
                  StyleBox[")",
                    FontWeight->"Plain"]}], \(\(c\^2\) k\^2 - \[Omega]\^2\)], 
              
              StyleBox[
                SuperscriptBox["\[ExponentialE]", 
                  RowBox[{"\[ImaginaryI]", "(", " ", 
                    RowBox[{
                      RowBox[{
                        StyleBox["k",
                          FontWeight->"Bold",
                          FontSlant->"Plain"], "\[CenterDot]", 
                        StyleBox["r",
                          FontWeight->"Bold",
                          FontSlant->"Plain"]}], 
                      StyleBox["-",
                        FontWeight->"Plain"], 
                      StyleBox[\(\[Omega]\ t\),
                        FontWeight->"Plain"]}], 
                    StyleBox[")",
                      FontWeight->"Plain"]}]],
                FontWeight->"Plain"]}]}]}], TraditionalForm]]],
  "."
}], "NumberedEquation",
  CellTags->"(5.1.81)"],

Cell[TextData[{
  "\tAs an example, let us determine the response to a point source in time \
and space, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"S", "(", 
            RowBox[{
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[",",
                FontWeight->"Plain"], 
              StyleBox["t",
                FontWeight->"Plain"]}], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{
            RowBox[{
              StyleBox["\[Delta]",
                FontWeight->"Plain"], 
              StyleBox["(",
                FontWeight->"Plain"], 
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[")",
                FontWeight->"Plain"]}], 
            StyleBox[\(\[Delta](t)\),
              FontWeight->"Plain"]}]}], TraditionalForm]]],
  ". Then ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(S\&~\), "(", 
            RowBox[{
              StyleBox["k",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[",",
                FontWeight->"Plain"], 
              StyleBox["\[Omega]",
                FontWeight->"Plain"]}], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox["1",
            FontWeight->"Plain"]}], TraditionalForm]]],
  ".  ",
  "\n",
  "We first perform the inverse frequency transform. This is easily done with \
the ",
  StyleBox["InverseFourierTransform",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FullSimplify[
      InverseFourierTransform[1/\((c^2\ k^2\  - \[Omega]^2)\), \[Omega], t]\ /
        Sqrt[2\ Pi], 
      c > 0 && t \[Element] Reals && k \[Element] Reals]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 5.10"],

Cell[BoxData[
    \(\(Sign[t]\ Sin[c\ k\ t]\)\/\(2\ c\ k\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "(Note that different versions of ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " can give different results for this inverse transform, depending on how \
it treats the singularity at  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\^2 = \ \(c\^2\) k\^2\)]],
  ". )"
}], "Text"],

Cell["Thus, we obtain", "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"p", "(", 
            RowBox[{
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[",",
                FontWeight->"Plain"], 
              StyleBox["t",
                FontWeight->"Plain"]}], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{\(Sign(t)\), 
            RowBox[{"\[Integral]", 
              
              RowBox[{\(\[DifferentialD]\^3 k\/\((2\ \[Pi])\)\^3\), \(\(sin(
                      c\ k\ t)\)\/\(2\ c\ k\)\), 
                StyleBox[
                  SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"\[ImaginaryI]", "  ", 
                      RowBox[{
                        StyleBox["k",
                          FontWeight->"Bold",
                          FontSlant->"Plain"], "\[CenterDot]", 
                        StyleBox["r",
                          FontWeight->"Bold",
                          FontSlant->"Plain"]}]}]],
                  FontWeight->"Plain"]}]}]}]}], TraditionalForm]]]
}], "NumberedEquation",
  CellTags->"(5.1.82)"],

Cell[TextData[{
  "This solution is nonzero for ",
  Cell[BoxData[
      \(TraditionalForm\`t < 0\)]],
  ", which is inconvenient. But it is only one particular solution to the \
PDE. To obtain a solution that is zero for ",
  Cell[BoxData[
      \(TraditionalForm\`t < 0\)]],
  ", we must add an appropriate solution to the homogeneous equation: Eq. ",
  ButtonBox["(5.1.50)",
    ButtonData:>"(5.1.50)",
    ButtonStyle->"Hyperlink"],
  ", or equivalently, Eq. ",
  ButtonBox["(5.1.47)",
    ButtonData:>"(5.1.47)",
    ButtonStyle->"Hyperlink"],
  ". By choosing ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"C", "(", 
            StyleBox["k",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{\(1\/\(4\ c\ k\ \[ImaginaryI]\)\), "=", 
            RowBox[{"-", 
              RowBox[{"D", "(", 
                StyleBox["k",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], ")"}]}]}]}], TraditionalForm]]],
  ",  Eq. ",
  ButtonBox["(5.1.47)",
    ButtonData:>"(5.1.47)",
    ButtonStyle->"Hyperlink"],
  " becomes ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Integral]", 
          
          RowBox[{\(\[DifferentialD]\^3 k\/\((2\ \[Pi])\)\^3\), \(\(sin(
                  c\ k\ t)\)\/\(2\ c\ k\)\), 
            StyleBox[
              SuperscriptBox["\[ExponentialE]", 
                RowBox[{"\[ImaginaryI]", "  ", 
                  RowBox[{
                    StyleBox["k",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], "\[CenterDot]", 
                    StyleBox["r",
                      FontWeight->"Bold",
                      FontSlant->"Plain"]}]}]],
              FontWeight->"Plain"]}]}], TraditionalForm]]],
  ". Adding this homogeneous solution to Eq. ",
  ButtonBox["(5.1.82)",
    ButtonData:>"(5.1.82)",
    ButtonStyle->"Hyperlink"],
  ", we cancel out the solution for ",
  Cell[BoxData[
      \(TraditionalForm\`t < 0\)]],
  " and are left with"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"p", "(", 
            RowBox[{
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[",",
                FontWeight->"Plain"], 
              StyleBox["t",
                FontWeight->"Plain"]}], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{\(h(t)\), 
            RowBox[{"\[Integral]", 
              
              RowBox[{\(\[DifferentialD]\^3 k\/\((2\ \[Pi])\)\^3\), \(\(sin(
                      c\ k\ t)\)\/\(c\ k\)\), 
                StyleBox[
                  SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"\[ImaginaryI]", "  ", 
                      RowBox[{
                        StyleBox["k",
                          FontWeight->"Bold",
                          FontSlant->"Plain"], "\[CenterDot]", 
                        StyleBox["r",
                          FontWeight->"Bold",
                          FontSlant->"Plain"]}]}]],
                  FontWeight->"Plain"]}]}]}]}], TraditionalForm]]],
  ","
}], "Text"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`h(t)\)]],
  " is the Heaviside step function. [We could also have obtained this result \
directly from Eq. ",
  ButtonBox["(5.1.79)",
    ButtonData:>"(5.1.79)",
    ButtonStyle->"Hyperlink"],
  " by Fourier transforming only in space, and then using the Greens function \
for the harmonic oscillator equation, Eq. ",
  ButtonBox["(2.3.77)",
    ButtonData:>{"Chapter2.nb", "(2.3.77)"},
    ButtonStyle->"Hyperlink"],
  ".]"
}], "Text"],

Cell[TextData[{
  "\tThe  remaining Fourier integrals are best evaluated in spherical \
coordinates ",
  Cell[BoxData[
      \(TraditionalForm\`\((k, \[Theta], \[Phi])\)\)]],
  ". As in the derivation of Eq. ",
  ButtonBox["(5.1.78)",
    ButtonData:>"(5.1.78)",
    ButtonStyle->"Hyperlink"],
  ", we choose ",
  Cell[BoxData[
      FormBox[
        StyleBox["r",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " to lie along the ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(z\)\(\ \)\)\)]],
  "axis of the spherical coordinate system. Then ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox["\[ExponentialE]", 
            RowBox[{"\[ImaginaryI]", " ", 
              RowBox[{
                StyleBox["k",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "\[CenterDot]", 
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], " "}]}]], 
          "=", \(\[ExponentialE]\^\(\[ImaginaryI]\ k\ r\ cos\[Theta]\)\)}], 
        TraditionalForm]]],
  ", and the \[Theta] and \[Phi] integrals yield"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"p", "(", 
            RowBox[{
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[",",
                FontWeight->"Plain"], 
              StyleBox["t",
                FontWeight->"Plain"]}], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{
            RowBox[{\(\(h(t)\)\/\(r\ c\)\), 
              RowBox[{\(\[Integral]\_0\%\[Infinity]\), 
                
                RowBox[{\(\[DifferentialD]k\/\(2\ \[Pi]\^2\)\), "sin", 
                  " ", \((c\ k\ t)\), " ", 
                  StyleBox["sin",
                    FontWeight->"Plain"], 
                  StyleBox[" ",
                    FontWeight->"Plain"], 
                  StyleBox["k",
                    FontWeight->"Plain"], 
                  StyleBox[" ",
                    FontWeight->"Plain"], 
                  StyleBox["r",
                    FontWeight->"Plain"]}]}]}], 
            StyleBox["=",
              FontWeight->"Plain"], 
            RowBox[{\(\(h(t)\)\/\(\(\ \)\(r\ c\)\)\), 
              RowBox[{\(\[Integral]\_0\%\[Infinity]\), 
                RowBox[{\(\[DifferentialD]k\/\(4\ \[Pi]\^2\)\), 
                  StyleBox["[",
                    FontWeight->"Plain"], 
                  StyleBox[\(cos\ \(k(r - c\ t)\) - cos\ \(k(r + c\ t)\)\),
                    FontWeight->"Plain"], 
                  StyleBox["]",
                    FontWeight->"Plain"]}]}]}]}]}], TraditionalForm]]],
  "."
}], "NumberedEquation",
  CellTags->"(5.1.83)"],

Cell[TextData[{
  "The integral over ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  " can be recognized as  a generalized Fourier integral of the type \
considered in Sec. ",
  ButtonBox["2.3.4",
    ButtonData:>{"Chapter2.nb", "c:31"},
    ButtonStyle->"Hyperlink"],
  ". The result is \n",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"p", "(", 
            RowBox[{
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[",",
                FontWeight->"Plain"], 
              StyleBox["t",
                FontWeight->"Plain"]}], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox["=",
            
            FontWeight->
              "Plain"], \(\(\(h(t)\)\/\(4  \[Pi]\ c\ r\)\)[\[Delta](
                r - c\ t)\  - \[Delta](r + c\ t)]\)}], TraditionalForm]]],
  " (see the exercises). However, since ",
  Cell[BoxData[
      \(TraditionalForm\`r \[GreaterEqual] \ 0\)]],
  " and we only require the solution for ",
  Cell[BoxData[
      \(TraditionalForm\`t > 0\)]],
  " thanks to the Heaviside function, we can neglect ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta](r + c\ t)\)]],
  " and drop ",
  Cell[BoxData[
      \(TraditionalForm\`h(t)\)]],
  " (since the ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]\)]],
  "-function makes it redundant), and so we obtain"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"p", "(", 
            RowBox[{
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[",",
                FontWeight->"Plain"], 
              StyleBox["t",
                FontWeight->"Plain"]}], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox["=",
            
            FontWeight->"Plain"], \(\(1\/\(4  \[Pi]\ c\ r\)\) \(\[Delta](
              r - c\ t)\)\)}], TraditionalForm]]],
  "."
}], "NumberedEquation",
  CellTags->"(5.1.84)"],

Cell[TextData[{
  "This solution, the response to a \[Delta]-function impulse at the origin \
at time ",
  Cell[BoxData[
      \(TraditionalForm\`t = 0\)]],
  ", is a spherical \[Delta]-function wave that moves with speed ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  ", decreasing in amplitude like ",
  Cell[BoxData[
      \(TraditionalForm\`1/r\)]],
  " as it expands radially. This response function also arises in the theory \
of the retarded potentials for electromagnetic radiation from a point source. \
 [See, for example, ",
  ButtonBox["Griffiths (1999)",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  ".] "
}], "Text",
  CellTags->"i:37"],

Cell[TextData[{
  "\tEquation ",
  ButtonBox["(5.1.84)",
    ButtonData:>"(5.1.84)",
    ButtonStyle->"Hyperlink"],
  "  may be compared with the response to an initially localized spherically \
symmetric perturbation, derived in the previous section [see Eq. ",
  ButtonBox["(5.1.78)",
    ButtonData:>"(5.1.78)",
    ButtonStyle->"Hyperlink"],
  " and Cell ",
  ButtonBox["5.9",
    ButtonData:>"Cell 5.9",
    ButtonStyle->"Hyperlink"],
  "] .  In that solution, there was a negative portion to the response, \
trailing the forward wave. Here, there is no trailing negative response, \
merely an outward-propagating \[Delta]-function peak,  because here the \
source function creates an initial ",
  StyleBox["rate of change",
    FontSlant->"Italic"],
  " to the pressure, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(\[PartialD]\_t\), " ", 
            RowBox[{"p", "(", 
              RowBox[{
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox[",",
                  FontWeight->"Plain"], \(t = \(0\^+\)\)}], ")"}]}], "=", 
          RowBox[{"\[Delta]", "(", 
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[")",
              FontWeight->"Plain"]}]}], TraditionalForm]]],
  "; but the pressure itself is initially zero: ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"p", "(", 
            RowBox[{
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[",",
                FontWeight->"Plain"], 
              StyleBox[\(t = \(0\^+\)\),
                FontWeight->"Plain"]}], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox["0",
            FontWeight->"Plain"]}], TraditionalForm]]],
  ". In electromagnetism, this sort of initial condition is the most \
physically relevant: it describes the response to a source in the wave \
equation (in electromagnetism, a current or moving charge) rather than the \
evolution of an initial field distribution. "
}], "Text"],

Cell[TextData[{
  "\tEquation ",
  ButtonBox["(5.1.84)",
    ButtonData:>"(5.1.84)",
    ButtonStyle->"Hyperlink"],
  " can also be thought of as a Green's function for the response to a \
general source of the form ",
  Cell[BoxData[
      FormBox[
        RowBox[{"S", "(", 
          RowBox[{
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[",",
              FontWeight->"Plain"], 
            StyleBox["t",
              FontWeight->"Plain"]}], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  ". Since any such source can be constructed from a series of \
\[Delta]-function sources in space and time, the superposition of the \
response to each of these point sources is"
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"p", "(", 
            RowBox[{
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[",",
                FontWeight->"Plain"], 
              StyleBox["t",
                FontWeight->"Plain"]}], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox["=",
            FontWeight->"Plain"]}], TraditionalForm]]],
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Integral]", 
          RowBox[{\(\[DifferentialD]t\_o\), \(\[DifferentialD]\^3 r\_o\), 
            FractionBox["1", 
              RowBox[{\(4  \[Pi]\ c\), " ", "|", 
                RowBox[{
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "-", 
                  SubscriptBox[
                    StyleBox["r",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], "o"]}], "|"}]], 
            RowBox[{"\[Delta]", "(", 
              RowBox[{"|", 
                RowBox[{
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "-", 
                  SubscriptBox[
                    StyleBox["r",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], "o"]}], 
                "|", \(\(-c\)\ \((t - t\_o)\)\)}], ")"}], 
            RowBox[{"S", "(", 
              RowBox[{
                StyleBox[
                  SubscriptBox[
                    StyleBox["r",
                      FontSlant->"Plain"], 
                    StyleBox["o",
                      FontWeight->"Plain"]],
                  FontWeight->"Bold"], 
                StyleBox[",",
                  FontWeight->"Plain"], 
                StyleBox[\(t\_o\),
                  FontWeight->"Plain"]}], 
              StyleBox[")",
                FontWeight->"Plain"]}]}]}], TraditionalForm]]],
  "."
}], "NumberedEquation",
  CellTags->"(5.1.85)"],

Cell[TextData[{
  "In this equation, the time ",
  Cell[BoxData[
      \(TraditionalForm\`t\_o\)]],
  "is generally referred to as the ",
  StyleBox["retarded time",
    FontSlant->"Italic"],
  ", because it is the time at which a source at ",
  Cell[BoxData[
      FormBox[
        SubscriptBox[
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], "o"], TraditionalForm]]],
  " must emit a wave in order for the response to reach position ",
  Cell[BoxData[
      FormBox[
        StyleBox["r",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " at time ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  ". "
}], "Text",
  CellTags->"i:130"]
}, Closed]],

Cell[CellGroupData[{

Cell["Wave Propagation in an Anisotropic Medium", "Section",
  CellTags->{"i:38", "c:16"}],

Cell[TextData[{
  "When waves travel through some medium that is moving with velocity ",
  Cell[BoxData[
      FormBox[
        StyleBox["U",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " with respect to the observer, the dispersion relation is affected by the \
motion of the medium. This can be easily understood by making a Galilean \
transformation to the frame of reference of the medium, where the position of \
some point on the wave is ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          OverscriptBox[
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox["_",
              FontWeight->"Plain"]],
          FontWeight->"Bold"], TraditionalForm]]],
  " . The same point as observed in the lab frame has position ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox[" ",
            FontWeight->"Plain"]}], TraditionalForm]]],
  ", where"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[" ",
            FontWeight->"Plain"], 
          RowBox[{
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[" ",
              FontWeight->"Plain"], 
            StyleBox["=",
              FontWeight->"Plain"], 
            RowBox[{
              StyleBox[
                OverscriptBox[
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], 
                  StyleBox["_",
                    FontWeight->"Plain"]],
                FontWeight->"Bold"], 
              StyleBox[" ",
                FontWeight->"Plain"], 
              StyleBox["+",
                FontWeight->"Plain"], 
              StyleBox[" ",
                FontWeight->"Plain"], 
              RowBox[{
                StyleBox["U",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox[" ",
                  FontWeight->"Plain"], 
                StyleBox["t",
                  FontWeight->"Plain"]}]}]}]}], TraditionalForm]]],
  "."
}], "NumberedEquation",
  CellTags->"(5.1.86)"],

Cell[TextData[{
  "(Here we consider nonrelativistic wave propagation,  such as that of sound \
or water waves.) In the moving frame, the medium is stationary, and the waves \
obey the usual wave equation ",
  ButtonBox["(5.1.44)",
    ButtonData:>"(5.1.44)",
    ButtonStyle->"Hyperlink"],
  ". The solution is given by Eq. ",
  ButtonBox["(5.1.50)",
    ButtonData:>"(5.1.50)",
    ButtonStyle->"Hyperlink"],
  " with ",
  Cell[BoxData[
      FormBox[
        StyleBox["r",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " replaced by ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          OverscriptBox[
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox["_",
              FontWeight->"Plain"]],
          FontWeight->"Bold"], TraditionalForm]]],
  ". If we now substitute for ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          OverscriptBox[
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox["_",
              FontWeight->"Plain"]],
          FontWeight->"Bold"], TraditionalForm]]],
  "  using Eq. ",
  ButtonBox["(5.1.86)",
    ButtonData:>"(5.1.86)",
    ButtonStyle->"Hyperlink"],
  " we obtain"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"p", "(", 
            RowBox[{
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[",",
                FontWeight->"Plain"], 
              StyleBox["t",
                FontWeight->"Plain"]}], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{
            RowBox[{"2", " ", "Re", 
              RowBox[{"\[Integral]", 
                
                RowBox[{\(\(\(\[DifferentialD]\^3 
                        k\)\(\ \)\)\/\((2  \[Pi])\)\^3\), 
                  RowBox[{"C", "(", 
                    StyleBox["k",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], 
                    StyleBox[")",
                      FontWeight->"Plain"]}], 
                  StyleBox[" ",
                    FontWeight->"Plain"], 
                  StyleBox[
                    SuperscriptBox["\[ExponentialE]", 
                      RowBox[{"\[ImaginaryI]", " ", 
                        RowBox[{"(", 
                          RowBox[{
                            RowBox[{
                              StyleBox["k",
                                FontWeight->"Bold",
                                FontSlant->"Plain"], "\[CenterDot]", 
                              StyleBox[
                                OverscriptBox[
                                  StyleBox["r",
                                    FontWeight->"Bold",
                                    FontSlant->"Plain"], "_"],
                                FontWeight->"Bold"]}], 
                            StyleBox["-",
                              FontWeight->"Bold"], 
                            RowBox[{
                              RowBox[{
                                StyleBox[
                                  OverscriptBox[
                                    StyleBox["\[Omega]",
                                      FontWeight->"Plain"], "_"],
                                  FontWeight->"Plain"], "(", "k", 
                                StyleBox[")",
                                  FontWeight->"Plain"]}], 
                              StyleBox["t",
                                FontWeight->"Plain"]}]}], 
                          StyleBox[")",
                            FontWeight->"Plain"]}]}]],
                    FontWeight->"Plain"]}]}]}], 
            StyleBox["=",
              FontWeight->"Plain"], 
            RowBox[{
              RowBox[{"2", " ", "Re", 
                RowBox[{"\[Integral]", 
                  
                  RowBox[{\(\(\(\[DifferentialD]\^3 
                          k\)\(\ \)\)\/\((2  \[Pi])\)\^3\), 
                    RowBox[{"C", "(", 
                      StyleBox["k",
                        FontWeight->"Bold",
                        FontSlant->"Plain"], 
                      StyleBox[")",
                        FontWeight->"Plain"]}], 
                    StyleBox[" ",
                      FontWeight->"Plain"], 
                    StyleBox[
                      SuperscriptBox["\[ExponentialE]", 
                        RowBox[{"\[ImaginaryI]", " ", 
                          RowBox[{"(", 
                            RowBox[{
                              RowBox[{
                                StyleBox["k",
                                  FontWeight->"Bold",
                                  FontSlant->"Plain"], "\[CenterDot]", 
                                StyleBox["r",
                                  FontWeight->"Bold",
                                  FontSlant->"Plain"]}], 
                              StyleBox["-",
                                FontWeight->"Bold"], 
                              StyleBox[
                                RowBox[{
                                  StyleBox["U",
                                    FontWeight->"Plain"], "t"}]], 
                              StyleBox["-",
                                FontWeight->"Bold"], 
                              RowBox[{
                                RowBox[{
                                  StyleBox[
                                    OverscriptBox[
                                      StyleBox["\[Omega]",
                                        FontWeight->"Plain"], "_"],
                                    FontWeight->"Plain"], "(", "k", 
                                  StyleBox[")",
                                    FontWeight->"Plain"]}], 
                                StyleBox["t",
                                  FontWeight->"Plain"]}]}], 
                            StyleBox[")",
                              FontWeight->"Plain"]}]}]],
                      FontWeight->"Plain"]}]}]}], "=", " ", 
              RowBox[{"2", " ", "Re", 
                RowBox[{"\[Integral]", 
                  
                  RowBox[{\(\(\(\[DifferentialD]\^3 
                          k\)\(\ \)\)\/\((2  \[Pi])\)\^3\), 
                    RowBox[{"C", "(", 
                      StyleBox["k",
                        FontWeight->"Bold",
                        FontSlant->"Plain"], 
                      StyleBox[")",
                        FontWeight->"Plain"]}], 
                    StyleBox[" ",
                      FontWeight->"Plain"], 
                    StyleBox[
                      SuperscriptBox["\[ExponentialE]", 
                        RowBox[{"\[ImaginaryI]", " ", 
                          RowBox[{"(", 
                            RowBox[{
                              RowBox[{
                                StyleBox["k",
                                  FontWeight->"Bold",
                                  FontSlant->"Plain"], "\[CenterDot]", 
                                StyleBox["r",
                                  FontWeight->"Bold",
                                  FontSlant->"Plain"]}], 
                              StyleBox["-",
                                FontWeight->"Bold"], 
                              RowBox[{
                                RowBox[{
                                  StyleBox["\[Omega]",
                                    FontWeight->"Plain"], "(", 
                                  StyleBox["k",
                                    FontWeight->"Bold",
                                    FontSlant->"Plain"], 
                                  StyleBox[")",
                                    FontWeight->"Plain"]}], 
                                StyleBox["t",
                                  FontWeight->"Plain"]}]}], 
                            StyleBox[")",
                              FontWeight->"Plain"]}]}]],
                      FontWeight->"Plain"]}]}]}]}]}]}], 
        StyleBox[",",
          FontWeight->"Plain"]}], TraditionalForm]]]], "NumberedEquation",
  CellTags->"(5.1.87)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Omega]", "(", 
          StyleBox["k",
            FontWeight->"Bold",
            FontSlant->"Plain"], ")"}], TraditionalForm]]],
  " is the frequency as seen in the lab frame and  ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            OverscriptBox[
              StyleBox["\[Omega]",
                FontWeight->"Plain"], "_"],
            FontWeight->"Plain"], "(", 
          StyleBox["k",
            FontSlant->"Italic"], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  " is the wave frequency as seen in the  frame moving with the medium. \
According to Eq. ",
  ButtonBox["(5.1.87)",
    ButtonData:>"(5.1.87)",
    ButtonStyle->"Hyperlink"],
  " the frequencies in the lab and moving frames are related by the equation \
"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["\[Omega]",
              FontWeight->"Plain"], "(", 
            StyleBox["k",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{\(\(\[Omega]\&_\)(k)\), "+", " ", 
            RowBox[{
              StyleBox["k",
                FontWeight->"Bold",
                FontSlant->"Plain"], "\[CenterDot]", 
              StyleBox["U",
                FontWeight->"Bold",
                FontSlant->"Plain"]}]}]}], TraditionalForm]]],
  "."
}], "NumberedEquation",
  CellTags->"(5.1.88)"],

Cell[TextData[{
  " The term ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["k",
            FontWeight->"Bold",
            FontSlant->"Plain"], "\[CenterDot]", 
          StyleBox["U",
            FontWeight->"Bold",
            FontSlant->"Plain"]}], TraditionalForm]]],
  " is the ",
  StyleBox[ButtonBox["Doppler",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Doppler.\
html"], None},
    ButtonStyle->"Hyperlink"],
    FontSlant->"Italic"],
  StyleBox[" shift",
    FontSlant->"Italic"],
  " of the frequency, caused by the motion of the medium. Equation ",
  ButtonBox["(5.1.88)",
    ButtonData:>"(5.1.88)",
    ButtonStyle->"Hyperlink"],
  " is an example of ",
  StyleBox["anisotropic",
    FontSlant->"Italic"],
  " dispersion: the frequency depends on the direction of propagation as well \
as the magnitude of the ",
  "wave vector",
  ". As a result, we will now see that the group and phase velocities are no \
longer in the same directions. "
}], "Text",
  CellTags->"i:39"],

Cell["\tThe phase velocity is", "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          SubscriptBox[
            StyleBox["v",
              FontWeight->"Bold",
              FontSlant->"Plain"], "\[Phi]"], "=", 
          RowBox[{
            RowBox[{
              RowBox[{
                StyleBox["\[Omega]",
                  FontWeight->"Plain"], "(", 
                StyleBox["k",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox[")",
                  FontWeight->"Plain"]}], 
              RowBox[{
                StyleBox[
                  OverscriptBox[
                    StyleBox["k",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], "^"],
                  FontWeight->"Bold"], "/", "k"}]}], "=", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{\(\(\(\[Omega]\&_\)(k)\)/k\), " ", "+", 
                  RowBox[{
                    StyleBox[
                      OverscriptBox[
                        StyleBox["k",
                          FontWeight->"Bold",
                          FontSlant->"Plain"], "^"],
                      FontWeight->"Bold"], "\[CenterDot]", 
                    StyleBox["U",
                      FontWeight->"Bold",
                      FontSlant->"Plain"]}]}], ")"}], 
              StyleBox[
                OverscriptBox[
                  StyleBox["k",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "^"],
                FontWeight->"Bold"], Cell[""]}]}]}], ","}], 
      TraditionalForm]]]], "NumberedEquation",
  CellTags->"(5.1.89)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          OverscriptBox[
            StyleBox["k",
              FontWeight->"Bold",
              FontSlant->"Plain"], "^"],
          FontWeight->"Bold"], TraditionalForm]]],
  " is a unit vector in the direction of ",
  Cell[BoxData[
      FormBox[
        StyleBox["k",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  "; but the group velocity is"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox[
            StyleBox["v",
              FontWeight->"Bold",
              FontSlant->"Plain"], "g"], "=", 
          RowBox[{
            RowBox[{\(\[PartialD]\[Omega]\&_\/\[PartialD]k\), 
              StyleBox[
                OverscriptBox[
                  StyleBox["k",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "^"],
                FontWeight->"Bold"]}], " ", "+", " ", 
            StyleBox["U",
              FontWeight->"Bold",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  "."
}], "NumberedEquation",
  CellTags->"(5.1.90)"],

Cell[TextData[{
  "Consequently, the phase fronts within the packet propagate along ",
  Cell[BoxData[
      FormBox[
        StyleBox["k",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  ", but the packet itself propagates in an entirely different direction as \
it is carried along by the flowing medium."
}], "Text"],

Cell["\<\
\tWaves in a  moving medium are a particularly simple example of \
how anisotropy  can modify the character of wave propagation. In these \
systems, phase and group velocities are completely independent of one \
another; they not only differ in magnitude, as in an isotropic dispersive \
medium ; they also differ in direction. \
\>", "Text"],

Cell[TextData[{
  "\tAn example of the propagation of a wave packet in an anisotropic system \
is displayed in Fig. ",
  ButtonBox["5.3",
    ButtonData:>"Fig. 5.3",
    ButtonStyle->"Hyperlink"],
  " [This wave packet is the solution to Exercise (26)  at the end of this \
section, on the propagation of deep-water waves in moving water. The water is \
moving to the right, and carries the packet with it.] Note how the wavefronts \
travel in one direction (the ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  "-direction), but the packet as a whole propagates in a different \
direction.  Also note that phase velocity is faster than the group velocity \
for these waves, and that the wave packet disperses both in the axial and \
transverse directions as it propagates."
}], "Text"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0192308 0.211538 0.0192308 [
[.11538 -0.0125 -9 -9 ]
[.11538 -0.0125 9 0 ]
[.30769 -0.0125 -9 -9 ]
[.30769 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69231 -0.0125 -6 -9 ]
[.69231 -0.0125 6 0 ]
[.88462 -0.0125 -6 -9 ]
[.88462 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -18 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .21154 -6 -4.5 ]
[-0.0125 .21154 0 4.5 ]
[-0.0125 .40385 -12 -4.5 ]
[-0.0125 .40385 0 4.5 ]
[-0.0125 .59615 -12 -4.5 ]
[-0.0125 .59615 0 4.5 ]
[-0.0125 .78846 -12 -4.5 ]
[-0.0125 .78846 0 4.5 ]
[-0.0125 .98077 -12 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11538 0 m
.11538 .00625 L
s
[(-20)] .11538 -0.0125 0 1 Mshowa
.30769 0 m
.30769 .00625 L
s
[(-10)] .30769 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69231 0 m
.69231 .00625 L
s
[(10)] .69231 -0.0125 0 1 Mshowa
.88462 0 m
.88462 .00625 L
s
[(20)] .88462 -0.0125 0 1 Mshowa
.125 Mabswid
.15385 0 m
.15385 .00375 L
s
.19231 0 m
.19231 .00375 L
s
.23077 0 m
.23077 .00375 L
s
.26923 0 m
.26923 .00375 L
s
.34615 0 m
.34615 .00375 L
s
.38462 0 m
.38462 .00375 L
s
.42308 0 m
.42308 .00375 L
s
.46154 0 m
.46154 .00375 L
s
.53846 0 m
.53846 .00375 L
s
.57692 0 m
.57692 .00375 L
s
.61538 0 m
.61538 .00375 L
s
.65385 0 m
.65385 .00375 L
s
.73077 0 m
.73077 .00375 L
s
.76923 0 m
.76923 .00375 L
s
.80769 0 m
.80769 .00375 L
s
.84615 0 m
.84615 .00375 L
s
.07692 0 m
.07692 .00375 L
s
.03846 0 m
.03846 .00375 L
s
.92308 0 m
.92308 .00375 L
s
.96154 0 m
.96154 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(-10)] -0.0125 .01923 1 0 Mshowa
0 .21154 m
.00625 .21154 L
s
[(0)] -0.0125 .21154 1 0 Mshowa
0 .40385 m
.00625 .40385 L
s
[(10)] -0.0125 .40385 1 0 Mshowa
0 .59615 m
.00625 .59615 L
s
[(20)] -0.0125 .59615 1 0 Mshowa
0 .78846 m
.00625 .78846 L
s
[(30)] -0.0125 .78846 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(40)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .05769 m
.00375 .05769 L
s
0 .09615 m
.00375 .09615 L
s
0 .13462 m
.00375 .13462 L
s
0 .17308 m
.00375 .17308 L
s
0 .25 m
.00375 .25 L
s
0 .28846 m
.00375 .28846 L
s
0 .32692 m
.00375 .32692 L
s
0 .36538 m
.00375 .36538 L
s
0 .44231 m
.00375 .44231 L
s
0 .48077 m
.00375 .48077 L
s
0 .51923 m
.00375 .51923 L
s
0 .55769 m
.00375 .55769 L
s
0 .63462 m
.00375 .63462 L
s
0 .67308 m
.00375 .67308 L
s
0 .71154 m
.00375 .71154 L
s
0 .75 m
.00375 .75 L
s
0 .82692 m
.00375 .82692 L
s
0 .86538 m
.00375 .86538 L
s
0 .90385 m
.00375 .90385 L
s
0 .94231 m
.00375 .94231 L
s
.25 Mabswid
0 0 m
0 1 L
s
.11538 .99375 m
.11538 1 L
s
.30769 .99375 m
.30769 1 L
s
.5 .99375 m
.5 1 L
s
.69231 .99375 m
.69231 1 L
s
.88462 .99375 m
.88462 1 L
s
.125 Mabswid
.15385 .99625 m
.15385 1 L
s
.19231 .99625 m
.19231 1 L
s
.23077 .99625 m
.23077 1 L
s
.26923 .99625 m
.26923 1 L
s
.34615 .99625 m
.34615 1 L
s
.38462 .99625 m
.38462 1 L
s
.42308 .99625 m
.42308 1 L
s
.46154 .99625 m
.46154 1 L
s
.53846 .99625 m
.53846 1 L
s
.57692 .99625 m
.57692 1 L
s
.61538 .99625 m
.61538 1 L
s
.65385 .99625 m
.65385 1 L
s
.73077 .99625 m
.73077 1 L
s
.76923 .99625 m
.76923 1 L
s
.80769 .99625 m
.80769 1 L
s
.84615 .99625 m
.84615 1 L
s
.07692 .99625 m
.07692 1 L
s
.03846 .99625 m
.03846 1 L
s
.92308 .99625 m
.92308 1 L
s
.96154 .99625 m
.96154 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .21154 m
1 .21154 L
s
.99375 .40385 m
1 .40385 L
s
.99375 .59615 m
1 .59615 L
s
.99375 .78846 m
1 .78846 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .05769 m
1 .05769 L
s
.99625 .09615 m
1 .09615 L
s
.99625 .13462 m
1 .13462 L
s
.99625 .17308 m
1 .17308 L
s
.99625 .25 m
1 .25 L
s
.99625 .28846 m
1 .28846 L
s
.99625 .32692 m
1 .32692 L
s
.99625 .36538 m
1 .36538 L
s
.99625 .44231 m
1 .44231 L
s
.99625 .48077 m
1 .48077 L
s
.99625 .51923 m
1 .51923 L
s
.99625 .55769 m
1 .55769 L
s
.99625 .63462 m
1 .63462 L
s
.99625 .67308 m
1 .67308 L
s
.99625 .71154 m
1 .71154 L
s
.99625 .75 m
1 .75 L
s
.99625 .82692 m
1 .82692 L
s
.99625 .86538 m
1 .86538 L
s
.99625 .90385 m
1 .90385 L
s
.99625 .94231 m
1 .94231 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.6 g
.37245 .19061 m
.39207 .18544 L
.4117 .18354 L
.43132 .18263 L
.45094 .18214 L
.47057 .18188 L
.49019 .18177 L
.50981 .18177 L
.52943 .18188 L
.54906 .18214 L
.56868 .18263 L
.5883 .18354 L
.60793 .18544 L
.62755 .19061 L
.63536 .19584 L
.64717 .20748 L
.64805 .21546 L
.64717 .21722 L
.62755 .23026 L
.60793 .23507 L
.60782 .23509 L
.5883 .23746 L
.56868 .23876 L
.54906 .23948 L
.52943 .23988 L
.50981 .24005 L
.49019 .24005 L
.47057 .23988 L
.45094 .23948 L
.43132 .23876 L
.4117 .23746 L
.39218 .23509 L
.39207 .23507 L
.37245 .23026 L
.35283 .21722 L
.35195 .21546 L
.35283 .20748 L
.36464 .19584 L
F
0 g
.37245 .19061 m
.39207 .18544 L
.4117 .18354 L
.43132 .18263 L
.45094 .18214 L
.47057 .18188 L
.49019 .18177 L
.50981 .18177 L
.52943 .18188 L
.54906 .18214 L
.56868 .18263 L
.5883 .18354 L
.60793 .18544 L
.62755 .19061 L
.63536 .19584 L
.64717 .20748 L
.64805 .21546 L
.64717 .21722 L
.62755 .23026 L
.60793 .23507 L
.60782 .23509 L
.5883 .23746 L
.56868 .23876 L
.54906 .23948 L
.52943 .23988 L
.50981 .24005 L
.49019 .24005 L
.47057 .23988 L
.45094 .23948 L
.43132 .23876 L
.4117 .23746 L
.39218 .23509 L
.39207 .23507 L
.37245 .23026 L
.35283 .21722 L
.35195 .21546 L
.35283 .20748 L
.36464 .19584 L
.37245 .19061 L
s
.4 g
.39207 .13446 m
.4117 .1317 L
.43132 .12992 L
.45094 .12873 L
.47057 .12801 L
.49019 .12768 L
.50981 .12768 L
.52943 .12801 L
.54906 .12873 L
.56868 .12992 L
.5883 .1317 L
.60793 .13446 L
.61743 .13697 L
.62755 .1424 L
.63663 .15659 L
.62755 .16668 L
.60793 .17368 L
.59249 .17622 L
.5883 .17663 L
.56868 .17787 L
.54906 .1785 L
.52943 .17882 L
.50981 .17896 L
.49019 .17896 L
.47057 .17882 L
.45094 .1785 L
.43132 .17787 L
.4117 .17663 L
.40751 .17622 L
.39207 .17368 L
.37245 .16668 L
.36337 .15659 L
.37245 .1424 L
.38257 .13697 L
F
0 g
.39207 .13446 m
.4117 .1317 L
.43132 .12992 L
.45094 .12873 L
.47057 .12801 L
.49019 .12768 L
.50981 .12768 L
.52943 .12801 L
.54906 .12873 L
.56868 .12992 L
.5883 .1317 L
.60793 .13446 L
.61743 .13697 L
.62755 .1424 L
.63663 .15659 L
.62755 .16668 L
.60793 .17368 L
.59249 .17622 L
.5883 .17663 L
.56868 .17787 L
.54906 .1785 L
.52943 .17882 L
.50981 .17896 L
.49019 .17896 L
.47057 .17882 L
.45094 .1785 L
.43132 .17787 L
.4117 .17663 L
.40751 .17622 L
.39207 .17368 L
.37245 .16668 L
.36337 .15659 L
.37245 .1424 L
.38257 .13697 L
.39207 .13446 L
s
.4 g
.39207 .24946 m
.4117 .24682 L
.43132 .24544 L
.45094 .24467 L
.47057 .24427 L
.49019 .24409 L
.50981 .24409 L
.52943 .24427 L
.54906 .24467 L
.56868 .24544 L
.5883 .24682 L
.60793 .24946 L
.62625 .25471 L
.62755 .25549 L
.63438 .27433 L
.62755 .28099 L
.60793 .28941 L
.5883 .29348 L
.58496 .29396 L
.56868 .29597 L
.54906 .29743 L
.52943 .29823 L
.50981 .29858 L
.49019 .29858 L
.47057 .29823 L
.45094 .29743 L
.43132 .29597 L
.41504 .29396 L
.4117 .29348 L
.39207 .28941 L
.37245 .28099 L
.36562 .27433 L
.37245 .25549 L
.37375 .25471 L
F
0 g
.39207 .24946 m
.4117 .24682 L
.43132 .24544 L
.45094 .24467 L
.47057 .24427 L
.49019 .24409 L
.50981 .24409 L
.52943 .24427 L
.54906 .24467 L
.56868 .24544 L
.5883 .24682 L
.60793 .24946 L
.62625 .25471 L
.62755 .25549 L
.63438 .27433 L
.62755 .28099 L
.60793 .28941 L
.5883 .29348 L
.58496 .29396 L
.56868 .29597 L
.54906 .29743 L
.52943 .29823 L
.50981 .29858 L
.49019 .29858 L
.47057 .29823 L
.45094 .29743 L
.43132 .29597 L
.41504 .29396 L
.4117 .29348 L
.39207 .28941 L
.37245 .28099 L
.36562 .27433 L
.37245 .25549 L
.37375 .25471 L
.39207 .24946 L
s
.7 g
.4117 .19443 m
.43132 .18846 L
.45094 .18611 L
.47057 .18504 L
.49019 .18461 L
.50981 .18461 L
.52943 .18504 L
.54906 .18611 L
.56868 .18846 L
.5883 .19443 L
.59087 .19584 L
.60793 .20878 L
.60861 .21546 L
.60793 .21643 L
.5883 .22761 L
.56868 .23202 L
.54906 .23432 L
.53914 .23509 L
.52943 .23553 L
.50981 .23606 L
.49019 .23606 L
.47057 .23553 L
.46086 .23509 L
.45094 .23432 L
.43132 .23202 L
.4117 .22761 L
.39207 .21643 L
.39139 .21546 L
.39207 .20878 L
.40913 .19584 L
F
0 g
.4117 .19443 m
.43132 .18846 L
.45094 .18611 L
.47057 .18504 L
.49019 .18461 L
.50981 .18461 L
.52943 .18504 L
.54906 .18611 L
.56868 .18846 L
.5883 .19443 L
.59087 .19584 L
.60793 .20878 L
.60861 .21546 L
.60793 .21643 L
.5883 .22761 L
.56868 .23202 L
.54906 .23432 L
.53914 .23509 L
.52943 .23553 L
.50981 .23606 L
.49019 .23606 L
.47057 .23553 L
.46086 .23509 L
.45094 .23432 L
.43132 .23202 L
.4117 .22761 L
.39207 .21643 L
.39139 .21546 L
.39207 .20878 L
.40913 .19584 L
.4117 .19443 L
s
.3 g
.45094 .13536 m
.47057 .13393 L
.49019 .13334 L
.50981 .13334 L
.52943 .13393 L
.54906 .13536 L
.56079 .13697 L
.56868 .139 L
.5883 .14854 L
.59274 .15659 L
.5883 .16155 L
.56868 .16945 L
.54906 .17269 L
.52943 .17429 L
.50981 .17496 L
.49019 .17496 L
.47057 .17429 L
.45094 .17269 L
.43132 .16945 L
.4117 .16155 L
.40726 .15659 L
.4117 .14854 L
.43132 .139 L
.43921 .13697 L
F
0 g
.45094 .13536 m
.47057 .13393 L
.49019 .13334 L
.50981 .13334 L
.52943 .13393 L
.54906 .13536 L
.56079 .13697 L
.56868 .139 L
.5883 .14854 L
.59274 .15659 L
.5883 .16155 L
.56868 .16945 L
.54906 .17269 L
.52943 .17429 L
.50981 .17496 L
.49019 .17496 L
.47057 .17429 L
.45094 .17269 L
.43132 .16945 L
.4117 .16155 L
.40726 .15659 L
.4117 .14854 L
.43132 .139 L
.43921 .13697 L
.45094 .13536 L
s
.6 g
.47057 .07585 m
.49019 .07471 L
.50981 .07471 L
.52943 .07585 L
.54736 .0781 L
.54906 .07839 L
.56868 .0825 L
.5883 .09159 L
.59259 .09772 L
.5883 .10395 L
.56868 .11132 L
.54906 .11409 L
.52943 .11541 L
.50981 .11596 L
.49019 .11596 L
.47057 .11541 L
.45094 .11409 L
.43132 .11132 L
.4117 .10395 L
.40741 .09772 L
.4117 .09159 L
.43132 .0825 L
.45094 .07839 L
.45264 .0781 L
F
0 g
.47057 .07585 m
.49019 .07471 L
.50981 .07471 L
.52943 .07585 L
.54736 .0781 L
.54906 .07839 L
.56868 .0825 L
.5883 .09159 L
.59259 .09772 L
.5883 .10395 L
.56868 .11132 L
.54906 .11409 L
.52943 .11541 L
.50981 .11596 L
.49019 .11596 L
.47057 .11541 L
.45094 .11409 L
.43132 .11132 L
.4117 .10395 L
.40741 .09772 L
.4117 .09159 L
.43132 .0825 L
.45094 .07839 L
.45264 .0781 L
.47057 .07585 L
s
.3 g
.43132 .25304 m
.45094 .25031 L
.47057 .24894 L
.49019 .24836 L
.50981 .24836 L
.52943 .24894 L
.54906 .25031 L
.56868 .25304 L
.57608 .25471 L
.5883 .26176 L
.58941 .27433 L
.5883 .27531 L
.56868 .2842 L
.54906 .28815 L
.52943 .29019 L
.50981 .29108 L
.49019 .29108 L
.47057 .29019 L
.45094 .28815 L
.43132 .2842 L
.4117 .27531 L
.41059 .27433 L
.4117 .26176 L
.42392 .25471 L
F
0 g
.43132 .25304 m
.45094 .25031 L
.47057 .24894 L
.49019 .24836 L
.50981 .24836 L
.52943 .24894 L
.54906 .25031 L
.56868 .25304 L
.57608 .25471 L
.5883 .26176 L
.58941 .27433 L
.5883 .27531 L
.56868 .2842 L
.54906 .28815 L
.52943 .29019 L
.50981 .29108 L
.49019 .29108 L
.47057 .29019 L
.45094 .28815 L
.43132 .2842 L
.4117 .27531 L
.41059 .27433 L
.4117 .26176 L
.42392 .25471 L
.43132 .25304 L
s
.6 g
.43132 .31138 m
.45094 .30922 L
.47057 .30814 L
.49019 .30768 L
.50981 .30768 L
.52943 .30814 L
.54906 .30922 L
.56868 .31138 L
.5799 .31358 L
.58577 .3332 L
.56868 .34094 L
.54906 .34519 L
.52943 .34741 L
.50981 .34838 L
.49019 .34838 L
.47057 .34741 L
.45094 .34519 L
.43132 .34094 L
.41423 .3332 L
.4201 .31358 L
F
0 g
.43132 .31138 m
.45094 .30922 L
.47057 .30814 L
.49019 .30768 L
.50981 .30768 L
.52943 .30814 L
.54906 .30922 L
.56868 .31138 L
.5799 .31358 L
.58577 .3332 L
.56868 .34094 L
.54906 .34519 L
.52943 .34741 L
.50981 .34838 L
.49019 .34838 L
.47057 .34741 L
.45094 .34519 L
.43132 .34094 L
.41423 .3332 L
.4201 .31358 L
.43132 .31138 L
s
.8 g
.45094 .19271 m
.47057 .18972 L
.49019 .18859 L
.50981 .18859 L
.52943 .18972 L
.54906 .19271 L
.55964 .19584 L
.56868 .19868 L
.58413 .21546 L
.56868 .22419 L
.54906 .22874 L
.52943 .23095 L
.50981 .2319 L
.49019 .2319 L
.47057 .23095 L
.45094 .22874 L
.43132 .22419 L
.41587 .21546 L
.43132 .19868 L
.44036 .19584 L
F
0 g
.45094 .19271 m
.47057 .18972 L
.49019 .18859 L
.50981 .18859 L
.52943 .18972 L
.54906 .19271 L
.55964 .19584 L
.56868 .19868 L
.58413 .21546 L
.56868 .22419 L
.54906 .22874 L
.52943 .23095 L
.50981 .2319 L
.49019 .2319 L
.47057 .23095 L
.45094 .22874 L
.43132 .22419 L
.41587 .21546 L
.43132 .19868 L
.44036 .19584 L
.45094 .19271 L
s
.9 g
.49019 .19481 m
.50981 .19481 L
.52073 .19584 L
.52943 .1968 L
.54906 .20118 L
.56309 .21546 L
.54906 .22204 L
.52943 .22587 L
.50981 .22737 L
.49019 .22737 L
.47057 .22587 L
.45094 .22204 L
.43691 .21546 L
.45094 .20118 L
.47057 .1968 L
.47927 .19584 L
F
0 g
.49019 .19481 m
.50981 .19481 L
.52073 .19584 L
.52943 .1968 L
.54906 .20118 L
.56309 .21546 L
.54906 .22204 L
.52943 .22587 L
.50981 .22737 L
.49019 .22737 L
.47057 .22587 L
.45094 .22204 L
.43691 .21546 L
.45094 .20118 L
.47057 .1968 L
.47927 .19584 L
.49019 .19481 L
s
.2 g
.45094 .14567 m
.47057 .14102 L
.49019 .13922 L
.50981 .13922 L
.52943 .14102 L
.54906 .14567 L
.56247 .15659 L
.54906 .16395 L
.52943 .16782 L
.50981 .16927 L
.49019 .16927 L
.47057 .16782 L
.45094 .16395 L
.43753 .15659 L
F
0 g
.45094 .14567 m
.47057 .14102 L
.49019 .13922 L
.50981 .13922 L
.52943 .14102 L
.54906 .14567 L
.56247 .15659 L
.54906 .16395 L
.52943 .16782 L
.50981 .16927 L
.49019 .16927 L
.47057 .16782 L
.45094 .16395 L
.43753 .15659 L
.45094 .14567 L
s
.2 g
.47057 .25437 m
.49019 .25318 L
.50981 .25318 L
.52943 .25437 L
.53312 .25471 L
.54906 .25863 L
.55734 .27433 L
.54906 .27795 L
.52943 .28229 L
.50981 .28399 L
.49019 .28399 L
.47057 .28229 L
.45094 .27795 L
.44266 .27433 L
.45094 .25863 L
.46688 .25471 L
F
0 g
.47057 .25437 m
.49019 .25318 L
.50981 .25318 L
.52943 .25437 L
.53312 .25471 L
.54906 .25863 L
.55734 .27433 L
.54906 .27795 L
.52943 .28229 L
.50981 .28399 L
.49019 .28399 L
.47057 .28229 L
.45094 .27795 L
.44266 .27433 L
.45094 .25863 L
.46688 .25471 L
.47057 .25437 L
s
1 g
.47057 .20448 m
.49019 .20123 L
.50981 .20123 L
.52943 .20448 L
.54139 .21546 L
.52943 .21937 L
.50981 .222 L
.49019 .222 L
.47057 .21937 L
.45861 .21546 L
F
0 g
.47057 .20448 m
.49019 .20123 L
.50981 .20123 L
.52943 .20448 L
.54139 .21546 L
.52943 .21937 L
.50981 .222 L
.49019 .222 L
.47057 .21937 L
.45861 .21546 L
.47057 .20448 L
s
.1 g
.49019 .14925 m
.50981 .14925 L
.52792 .15659 L
.50981 .16097 L
.49019 .16097 L
.47208 .15659 L
F
0 g
.49019 .14925 m
.50981 .14925 L
.52792 .15659 L
.50981 .16097 L
.49019 .16097 L
.47208 .15659 L
.49019 .14925 L
s
.1 g
.49019 .26262 m
.50981 .26262 L
.51277 .27433 L
.50981 .27468 L
.49019 .27468 L
.48723 .27433 L
F
0 g
.49019 .26262 m
.50981 .26262 L
.51277 .27433 L
.50981 .27468 L
.49019 .27468 L
.48723 .27433 L
.49019 .26262 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00?Oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0dooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kS?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0hooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8b
onk^kS?ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08_ooool003gooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0=_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0<oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg03?ooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL08_ooool003Gooooo1_l0
0003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400[ooooo`Ko0000
1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100<oooool01Ol@413o
oooooooooooooooo410@03[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@03Cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@02;ooooo000o
ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000fooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000cooooo`05o`000?ooooooooooooooool0
0000>_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000=Oooool00onH
V9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000008_ooool0043ooooo00?oMgMgofIV
I_ooool00_ooool01Ol0003ooooooooooooooooo000003Kooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000003?ooooo00Go0000ooooooooooooooooo`00000jooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`03ogMgMomVIVKooooo00;o
oooo00Go0000ooooooooooooooooo`00000Rooooo`00@Oooool01Ol0003ooooooooooooooooo410@
00?ooooo00?o410@ooooooooool0=?ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@4100<oooool01Ol@413ooooooooooooooooo410@03[ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@03Oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo023ooooo000mooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg03Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg03?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0jooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0cooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02;ooooo000mooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^03Cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^03?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`03oeEEEOmVIVKo000000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0cooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02;ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo000Joooooooo0000C_l00001ooooo`00
6_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0?Ooo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool08ooo
ool1o`00007ooooo0008ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKo
oooo00?o0000ooooooooool0oooooom:ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooom:ooooo`7o
00000Oooool000Go00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41001_ooool00ol0003oooooooooo`3ooooood[ooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?ooooooB?ooool3o`00007o
oooo000:ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo0008ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Oooooooogmo
Od3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04oooooiWoOgmo3_l0002HogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04oooooi?oOgmo1_l0000>oiVIV@Ko0000T_moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?oooon<ogmoO`Oo00006_nIVIT7o`0008_oOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CoooooQomoOgl5o`0002SoVIVI1?l00027ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooohGoOgmo0_l0000aoiVIV@?o0000Q?moOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon3ogmoO`;o0000=_nIVIT2o`00
08;oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooP_moOgl00ol0003o
VIVIoiVIV@0hoiVIV@03o`000?moOgooOgmo07ooOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CoooooPOmoOgl00ol0003oVIVIoiVIV@0ioiVIV@03o`000?moOgooOgmo07ooOgmo
1_ooool1o`00007ooooo000Jooooo`;o00001Ooooon0ogmoO`03o`000?nIVIWoVIVI03_oVIVI00?o
0000ogmoOomoOgl0O_moOgl5ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool01?oooon1
ogmoO`03o`000?nIVIWoVIVI03[oVIVI00?o0000ogmoOomoOgl0O_moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?oooon2ogmoO`;o0000>?nIVIT2o`00087oOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CoooooQ?moOgl2o`0003?oVIVI0ol00023ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooohKoOgmo0_l0000_oiVIV@;o0000
Q_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon8ogmoO`Go00009_nI
VIT4o`0008SoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooSOmoOglV
o`0008coOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CoooooS?moOglXo`0008_oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CoooooOomoOgl=o`0002SoIVIV3Ol0001nogmoO`Kooooo0Ol00001
ooooo`006_ooool2o`0000GoooooN_moOgl5o`0001?oIVIV7?l0000CofIVIPGo0000NOmoOgl5oooo
o`;o00000Oooool001[ooooo00?o0000ooooooooool01?oooomgogmoO`?o00004?mVIVH8o`0001co
C4a<2?l0000@ofIVIP;o0000MomoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?oooomfogmoO`03o`000?mVIVKoIVIV00koIVIV0ol0000:oda<C1So00002_m<C4`2o`00013oIVIV
0_l0001eogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooogGoOgmo00?o
0000ofIVI_mVIVH03OmVIVH2o`0000[oC4a<0ol0000Hoc<c<`?o00002Om<C4`3o`0000ooIVIV00?o
0000ogmoOomoOgl0L_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooome
ogmoO`03o`000?mVIVKoIVIV00_oIVIV0_l00009oda<C0?o00007_lc<c<2o`0000[oC4a<0_l0000=
ofIVIP03o`000?moOgooOgmo07;oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CoooooM?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<00SoC4a<00?o0000oc<c
<olc<c<02olc<c<:o`0000co<c<c00?o0000oda<C?m<C4`02Om<C4`00ol0003oIVIVofIVIP0;ofIV
IP03o`000?moOgooOgmo077oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
ooooLomoOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<00OoC4a<00?o0000oc<c<olc
<c<02_lc<c<2o`0000[o6ATI0_l0000;oc<c<`03o`000?m<C4coC4a<00SoC4a<00?o0000ofIVI_mV
IVH03?mVIVH00ol0003oOgmoogmoO`1`ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooog?oOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C007oda<C003o`00
0?lc<c?o<c<c00Wo<c<c0_l0000>oaTI6@;o00002_lc<c<00ol0003oC4a<oda<C008oda<C003o`00
0?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl0L?moOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?oooombogmoO`03o`000?mVIVKoIVIV00_oIVIV0_l00008oda<C0;o00002_lc
<c<4o`0000co6ATI1?l00009oc<c<`;o00002Om<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?mo
OgooOgmo06ooOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooLomoOgl0
0ol0003oIVIVofIVIP0<ofIVIP;o00002?m<C4`3o`0000_o<c<c3?l0000;oc<c<`;o00002Om<C4`2
o`0000koIVIV00?o0000ogmoOomoOgl0L?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?oooomdogmoO`03o`000?mVIVKoIVIV00goIVIV0_l00009oda<C0Co00006_lc<c<4o`00
00SoC4a<0ol0000?ofIVIP03o`000?moOgooOgmo077oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CoooooMOmoOgl3o`0000koIVIV0_l0000;oda<C0Oo00003?lc<c<7o`0000[o
C4a<0_l0000?ofIVIP?o0000M?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?oooomhogmoO`?o00003OmVIVH5o`0000goC4a<3?l0000=oda<C0Co00003_mVIVH3o`0007OoOgmo
1_ooool1o`00007ooooo000Jooooo`;o00001OoooomkogmoO`Co00003_mVIVH6o`0001[oC4a<1_l0
000>ofIVIPCo0000N_moOgl5ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool01?oooomo
ogmoO`Oo00003OmVIVHJo`0000goIVIV1ol0001nogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooohKoOgmo=?l00025ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooohGoOgmo=_l00024ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooog[oOgmo2ol00007oiVIVBSo00001onIVIT;o`0007WoOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CoooooMomoOgl3o`0000goVIVI1Ol0000=ok>c/`ko00003Onc
/k<5o`0000goVIVI0ol0001fogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooogCoOgmo0ol0000=oiVIV@?o00002onc/k<7o`0000koc<c<1ol0000;ok>c/`?o00003OnIVIT2
o`0007CoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooLomoOgl00ol0
003oVIVIoiVIV@0<oiVIV@;o00002Onc/k<5o`0000Soc<c<3?l00008olc<c0Go00002Onc/k<2o`00
00goVIVI00?o0000ogmoOomoOgl0LOmoOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?oooombogmoO`03o`000?nIVIWoVIVI00_oVIVI0_l00008ok>c/`?o00001Oo<c<`8o`0000co
i^KV2?l00005olc<c0?o00001onc/k<2o`0000goVIVI00?o0000ogmoOomoOgl0L?moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?oooomaogmoO`03o`000?nIVIWoVIVI00_oVIVI
00?o0000ok>c/onc/k<01_nc/k<2o`0000Goc<c<0ol00008onKViPco00002?oVi^H3o`0000Goc<c<
00?o0000ok>c/onc/k<01_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo06ooOgmo
1_ooool1o`00007ooooo000?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003ooooo
ooooo`04ooooog3oOgmo00?o0000oiVIVOnIVIT02_nIVIT2o`0000So/k>c00?o0000olc<c?o<c<`0
1?o<c<`00ol0003oi^KVonKViP06onKViP?o00003?ooool3o`0000Ooi^KV00?o0000olc<c?o<c<`0
1?o<c<`00ol0003o/k>cok>c/`06ok>c/`;o00003?nIVIT00ol0003oOgmoogmoO`1^ogmoO`Kooooo
0Ol00001ooooo`003oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0
1?oooom_ogmoO`03o`000?nIVIWoVIVI00[oVIVI00?o0000ok>c/onc/k<01onc/k<00ol0003oc<c<
olc<c004olc<c003o`000?oVi^Koi^KV00Goi^KV0_l0000Booooo`;o00001_oVi^H00ol0003oc<c<
olc<c004olc<c003o`000?nc/k?o/k>c00Oo/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmo
ogmoO`1]ogmoO`Kooooo0Ol00001ooooo`003oooool01Ol@413ooooooooooooooooo410@00Kooooo
00?o0000ooooooooool01?oooom^ogmoO`03o`000?nIVIWoVIVI00[oVIVI00?o0000ok>c/onc/k<0
1onc/k<00ol0003oc<c<olc<c004olc<c003o`000?oVi^Koi^KV00Goi^KV00?o0000ooooooooool0
5?ooool00ol0003oi^KVonKViP04onKViP03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<0
1onc/k<00ol0003oVIVIoiVIV@0:oiVIV@03o`000?moOgooOgmo06coOgmo1_ooool1o`00007ooooo
000?ooooo`05o`000?ooooooooooooooool000001_ooool3o`0000CoooooK_moOgl00ol0003oVIVI
oiVIV@0:oiVIV@03o`000?nc/k?o/k>c00Ko/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003oi^KV
onKViP05onKViP03o`000?oooooooooo01Kooooo00?o0000onKVi_oVi^H01?oVi^H00ol0003oc<c<
olc<c004olc<c003o`000?nc/k?o/k>c00Ko/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmo
ogmoO`1/ogmoO`Cooooo0ol00001ooooo`003oooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool01?oooom^ogmoO`03o`000?nIVIWoVIVI00[oVIVI00?o0000ok>c/onc/k<0
1Onc/k<2o`0000Goc<c<0_l00006onKViP?o00005_ooool3o`0000Goi^KV0_l00005olc<c0;o0000
1onc/k<00ol0003oVIVIoiVIV@0:oiVIV@03o`000?moOgooOgmo06coOgmo1_ooool1o`00007ooooo
000?ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`04ooooofkoOgmo
0_l0000;oiVIV@;o00002?nc/k<2o`0000Goc<c<0ol00006onKViPGo00003?ooool5o`0000Koi^KV
0_l00005olc<c0;o00002?nc/k<2o`0000_oVIVI0_l0001^ogmoO`Kooooo0Ol00001ooooo`003ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?oooom`ogmoO`;o0000
2onIVIT3o`0000Oo/k>c00?o0000olc<c?o<c<`01Oo<c<`3o`0000Soi^KV3?l00008onKViP?o0000
1_o<c<`00ol0003o/k>cok>c/`06ok>c/`;o00003?nIVIT00ol0003oOgmoogmoO`1^ogmoO`Kooooo
0Ol00001ooooo`003oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0
1?oooombogmoO`03o`000?nIVIWoVIVI00_oVIVI0_l00006ok>c/`?o00001oo<c<`3o`0001Koi^KV
0ol00007olc<c0;o00001onc/k<2o`0000coVIVI0_l0001aogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooog?oOgmo0_l0000=oiVIV@?o00001_nc/k<3o`0000Ooc<c<5_l0
0007olc<c0?o00001_nc/k<3o`0000goVIVI00?o0000ogmoOomoOgl0LOmoOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?oooomeogmoO`?o00003OnIVIT3o`0000Ko/k>c3?l0000<
olc<c0co00001_nc/k<3o`0000goVIVI0ol0001dogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooogSoOgmo0ol0000=oiVIV@[o00002?nc/k<<o`0000So/k>c2_l0000=oiVI
V@?o0000MomoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooomkogmoO`_o
00003?nIVITLo`0000coVIVI2ol0001jogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooohKoOgmo=?l00025ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon5
ogmoOcKo0000Q?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooomjogmo
O`_o00003OmVIVHLo`0000goIVIV2ol0001iogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000Go
ooooMomoOgl3o`0001;oIVIV1_l0000Loda<C0Ko00004_mVIVH3o`0007KoOgmo1Oooool2o`00007o
oooo000Jooooo`03o`000?oooooooooo00CoooooMOmoOgl2o`0000koIVIV1ol00007oda<C1[o0000
1om<C4`7o`0000koIVIV0_l0001dogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooogGoOgmo00?o0000ofIVI_mVIVH03?mVIVH00ol0003oC4a<oda<C009oda<C0?o00006_lc
<c<3o`0000_oC4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmoO`1bogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooogGoOgmo00?o0000ofIVI_mVIVH02omVIVH0
0ol0003oC4a<oda<C009oda<C003o`000?lc<c?o<c<c01ko<c<c00?o0000oda<C?m<C4`02Om<C4`0
0ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo07;oOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CoooooM?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<
00[oC4a<00?o0000oc<c<olc<c<02_lc<c<8o`0000co<c<c00?o0000oda<C?m<C4`02_m<C4`00ol0
003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo077oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CoooooM?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<00Wo
C4a<00?o0000oc<c<olc<c<02olc<c<00ol0003o6ATIoaTI6@04oaTI6@03o`000?lc<c?o<c<c00_o
<c<c00?o0000oda<C?m<C4`02Om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo077o
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooM?moOgl00ol0003oIVIV
ofIVIP0;ofIVIP03o`000?m<C4coC4a<00SoC4a<00?o0000oc<c<olc<c<03?lc<c<00ol0003o6ATI
oaTI6@04oaTI6@03o`000?lc<c?o<c<c00_o<c<c00?o0000oda<C?m<C4`02Om<C4`00ol0003oIVIV
ofIVIP0;ofIVIP03o`000?moOgooOgmo077oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CoooooLomoOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<00SoC4a<00?o
0000oc<c<olc<c<02olc<c<00ol0003o6ATIoaTI6@05oaTI6@03o`000?lc<c?o<c<c00_o<c<c00?o
0000oda<C?m<C4`02Om<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?moOgooOgmo073oOgmo1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooLomoOgl00ol0003oIVIVofIVIP0<
ofIVIP;o00002?m<C4`3o`0000co<c<c2Ol0000=oc<c<`;o00002Om<C4`2o`0000koIVIV00?o0000
ogmoOomoOgl0L?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooomdogmo
O`03o`000?mVIVKoIVIV00goIVIV0_l00009oda<C0Co00006_lc<c<4o`0000SoC4a<0ol0000?ofIV
IP03o`000?moOgooOgmo077oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
ooooMOmoOgl2o`0000ooIVIV0_l0000;oda<C0Oo00003?lc<c<7o`0000[oC4a<0_l0000@ofIVIP;o
0000M?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooomgogmoO`;o0000
3omVIVH5o`0000goC4a<3?l0000=oda<C0Co00003omVIVH3o`0007KoOgmo1_ooool1o`00007ooooo
000Jooooo`;o00001OoooomiogmoO`;o00004_mVIVH6o`0001[oC4a<1_l0000AofIVIP;o0000NOmo
Ogl5ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool01?oooomkogmoO`Go00004omVIVHJ
o`0001?oIVIV1?l0001kogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
oh3oOgmo1ol0000bofIVIPOo0000OomoOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?oooon7ogmoO`co00006_mVIVH<o`0008KoOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CoooooTomoOglJo`0009;oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon<ogmo
ObSo0000RomoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon7ogmoO`Go
0000:?nIVIT5o`0008KoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
QOmoOgl2o`0003;oVIVI0_l00024ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooohGoOgmo00?o0000oiVIVOnIVIT0<_nIVIT00ol0003oOgmoogmoO`22ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooohCoOgmo00?o0000oiVIVOnIVIT0=?nIVIT0
0ol0003oOgmoogmoO`21ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
ohCoOgmo00?o0000oiVIVOnIVIT0=?nIVIT00ol0003oOgmoogmoO`21ogmoO`Kooooo0Ol00001oooo
o`006_ooool2o`0000GoooooQ?moOgl00ol0003oVIVIoiVIV@0doiVIV@03o`000?moOgooOgmo087o
Ogmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooPomoOgl00ol0003oVIVI
oiVIV@0foiVIV@03o`000?moOgooOgmo083oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CoooooPomoOgl2o`0003KoVIVI0_l00022ogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooohGoOgmo0_l0000boiVIV@;o0000Q?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?oooon7ogmoO`03o`000?nIVIWoVIVI02goVIVI0_l00026ogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooohSoOgmo1Ol0000VoiVIV@Co
0000R?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon=ogmoO`Ko0000
6_nIVIT6o`0008coOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooTomo
OglJo`0009;oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo0_l00005
ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool000Sooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;o
k^k^1_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000[ooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000:ooooo`03o`000?oooooooooo00;ooooo
00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`002_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
00001_ooool3o`0000CooooooomoOgm0ogmoO`Cooooo0ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooo
oooooooooooo410@00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000:ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002?ooool00omEEEGoIVIV
o`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo
1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Oooooooogmo
Od3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Ooo
ooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo0007ooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo0007ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo0008ooooo`03oiRHV?lQ8B7ok^k^00Cooooo
00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`002Oooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool0
00001_ooool3o`0000CooooooomoOgm0ogmoO`Cooooo0ol00001ooooo`002_ooool00omgMgOoIVIV
ooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool000_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo00Cooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo0007ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo0007ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000Gooooo
oomoOgm0ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`00
00GooooooomoOgm0ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`001oooool01OnHV9So410@o`000?lb<S;oc<c<
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`001oooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`002oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool01?oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000[ooooo00?oZJVY
oa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo0ol00004ooooooooOgmo@?mo
Ogl4ooooo`?o00000Oooool000Wooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooo
oooo000000Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000:
ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`001oooool01Ol@413oV9RHoooooonj
^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`001oooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo0_l00005ooooooooOgmo@?moOgl5oooo
o`;o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo0_l00005ooooooooOgmo@?mo
Ogl5ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool000Wooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP06oooo
o`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`04oooo
ooooOgmo@?moOgl6ooooo`7o00000Oooool000Oooooo1Ol00003ooooo`05oa0@4?oooooooooooooo
ool@41001_ooool3o`0000CooooooomoOgm0ogmoO`Cooooo0ol00001ooooo`001oooool01?m4A4Co
gMgMooooool00004ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3o
oooood[ooooo0Ol00001ooooo`001oooool01?oMgMgoEEEEooooool00004ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`3ooooood[ooooo0Ol00001ooooo`002?ooool0
0omgMgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003ooooooooo
o`3ooooood[ooooo0Ol00001ooooo`002?ooool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooood[ooooo0Ol00001ooooo`002Oooool0
0omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003ooooooooo
o`0Sooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0?Oooool00ol0003ooooooooo
o`0mooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool08oooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool1o`00007ooooo000Joooo
oooo0000C_l00001ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-30.1723, -14.304, 0.195672, \
0.195672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0192308 0.211538 0.0192308 [
[.11538 -0.0125 -9 -9 ]
[.11538 -0.0125 9 0 ]
[.30769 -0.0125 -9 -9 ]
[.30769 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69231 -0.0125 -6 -9 ]
[.69231 -0.0125 6 0 ]
[.88462 -0.0125 -6 -9 ]
[.88462 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -18 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .21154 -6 -4.5 ]
[-0.0125 .21154 0 4.5 ]
[-0.0125 .40385 -12 -4.5 ]
[-0.0125 .40385 0 4.5 ]
[-0.0125 .59615 -12 -4.5 ]
[-0.0125 .59615 0 4.5 ]
[-0.0125 .78846 -12 -4.5 ]
[-0.0125 .78846 0 4.5 ]
[-0.0125 .98077 -12 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11538 0 m
.11538 .00625 L
s
[(-20)] .11538 -0.0125 0 1 Mshowa
.30769 0 m
.30769 .00625 L
s
[(-10)] .30769 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69231 0 m
.69231 .00625 L
s
[(10)] .69231 -0.0125 0 1 Mshowa
.88462 0 m
.88462 .00625 L
s
[(20)] .88462 -0.0125 0 1 Mshowa
.125 Mabswid
.15385 0 m
.15385 .00375 L
s
.19231 0 m
.19231 .00375 L
s
.23077 0 m
.23077 .00375 L
s
.26923 0 m
.26923 .00375 L
s
.34615 0 m
.34615 .00375 L
s
.38462 0 m
.38462 .00375 L
s
.42308 0 m
.42308 .00375 L
s
.46154 0 m
.46154 .00375 L
s
.53846 0 m
.53846 .00375 L
s
.57692 0 m
.57692 .00375 L
s
.61538 0 m
.61538 .00375 L
s
.65385 0 m
.65385 .00375 L
s
.73077 0 m
.73077 .00375 L
s
.76923 0 m
.76923 .00375 L
s
.80769 0 m
.80769 .00375 L
s
.84615 0 m
.84615 .00375 L
s
.07692 0 m
.07692 .00375 L
s
.03846 0 m
.03846 .00375 L
s
.92308 0 m
.92308 .00375 L
s
.96154 0 m
.96154 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(-10)] -0.0125 .01923 1 0 Mshowa
0 .21154 m
.00625 .21154 L
s
[(0)] -0.0125 .21154 1 0 Mshowa
0 .40385 m
.00625 .40385 L
s
[(10)] -0.0125 .40385 1 0 Mshowa
0 .59615 m
.00625 .59615 L
s
[(20)] -0.0125 .59615 1 0 Mshowa
0 .78846 m
.00625 .78846 L
s
[(30)] -0.0125 .78846 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(40)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .05769 m
.00375 .05769 L
s
0 .09615 m
.00375 .09615 L
s
0 .13462 m
.00375 .13462 L
s
0 .17308 m
.00375 .17308 L
s
0 .25 m
.00375 .25 L
s
0 .28846 m
.00375 .28846 L
s
0 .32692 m
.00375 .32692 L
s
0 .36538 m
.00375 .36538 L
s
0 .44231 m
.00375 .44231 L
s
0 .48077 m
.00375 .48077 L
s
0 .51923 m
.00375 .51923 L
s
0 .55769 m
.00375 .55769 L
s
0 .63462 m
.00375 .63462 L
s
0 .67308 m
.00375 .67308 L
s
0 .71154 m
.00375 .71154 L
s
0 .75 m
.00375 .75 L
s
0 .82692 m
.00375 .82692 L
s
0 .86538 m
.00375 .86538 L
s
0 .90385 m
.00375 .90385 L
s
0 .94231 m
.00375 .94231 L
s
.25 Mabswid
0 0 m
0 1 L
s
.11538 .99375 m
.11538 1 L
s
.30769 .99375 m
.30769 1 L
s
.5 .99375 m
.5 1 L
s
.69231 .99375 m
.69231 1 L
s
.88462 .99375 m
.88462 1 L
s
.125 Mabswid
.15385 .99625 m
.15385 1 L
s
.19231 .99625 m
.19231 1 L
s
.23077 .99625 m
.23077 1 L
s
.26923 .99625 m
.26923 1 L
s
.34615 .99625 m
.34615 1 L
s
.38462 .99625 m
.38462 1 L
s
.42308 .99625 m
.42308 1 L
s
.46154 .99625 m
.46154 1 L
s
.53846 .99625 m
.53846 1 L
s
.57692 .99625 m
.57692 1 L
s
.61538 .99625 m
.61538 1 L
s
.65385 .99625 m
.65385 1 L
s
.73077 .99625 m
.73077 1 L
s
.76923 .99625 m
.76923 1 L
s
.80769 .99625 m
.80769 1 L
s
.84615 .99625 m
.84615 1 L
s
.07692 .99625 m
.07692 1 L
s
.03846 .99625 m
.03846 1 L
s
.92308 .99625 m
.92308 1 L
s
.96154 .99625 m
.96154 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .21154 m
1 .21154 L
s
.99375 .40385 m
1 .40385 L
s
.99375 .59615 m
1 .59615 L
s
.99375 .78846 m
1 .78846 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .05769 m
1 .05769 L
s
.99625 .09615 m
1 .09615 L
s
.99625 .13462 m
1 .13462 L
s
.99625 .17308 m
1 .17308 L
s
.99625 .25 m
1 .25 L
s
.99625 .28846 m
1 .28846 L
s
.99625 .32692 m
1 .32692 L
s
.99625 .36538 m
1 .36538 L
s
.99625 .44231 m
1 .44231 L
s
.99625 .48077 m
1 .48077 L
s
.99625 .51923 m
1 .51923 L
s
.99625 .55769 m
1 .55769 L
s
.99625 .63462 m
1 .63462 L
s
.99625 .67308 m
1 .67308 L
s
.99625 .71154 m
1 .71154 L
s
.99625 .75 m
1 .75 L
s
.99625 .82692 m
1 .82692 L
s
.99625 .86538 m
1 .86538 L
s
.99625 .90385 m
1 .90385 L
s
.99625 .94231 m
1 .94231 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.6 g
.43132 .21436 m
.45094 .21381 L
.47057 .21356 L
.49019 .21346 L
.50981 .21343 L
.52943 .21346 L
.54906 .21356 L
.56868 .21381 L
.5883 .21437 L
.60662 .21546 L
.60793 .21558 L
.62755 .21827 L
.64717 .22483 L
.6574 .23509 L
.64717 .25308 L
.64456 .25471 L
.62755 .26366 L
.60793 .2679 L
.5883 .27009 L
.56868 .27135 L
.54906 .27209 L
.52943 .27248 L
.50981 .27261 L
.49019 .27249 L
.47057 .2721 L
.45094 .27137 L
.43132 .27012 L
.4117 .26796 L
.39207 .26379 L
.37465 .25471 L
.37245 .25336 L
.36182 .23509 L
.37245 .22462 L
.39207 .21819 L
.4117 .21554 L
.41261 .21546 L
F
0 g
.43132 .21436 m
.45094 .21381 L
.47057 .21356 L
.49019 .21346 L
.50981 .21343 L
.52943 .21346 L
.54906 .21356 L
.56868 .21381 L
.5883 .21437 L
.60662 .21546 L
.60793 .21558 L
.62755 .21827 L
.64717 .22483 L
.6574 .23509 L
.64717 .25308 L
.64456 .25471 L
.62755 .26366 L
.60793 .2679 L
.5883 .27009 L
.56868 .27135 L
.54906 .27209 L
.52943 .27248 L
.50981 .27261 L
.49019 .27249 L
.47057 .2721 L
.45094 .27137 L
.43132 .27012 L
.4117 .26796 L
.39207 .26379 L
.37465 .25471 L
.37245 .25336 L
.36182 .23509 L
.37245 .22462 L
.39207 .21819 L
.4117 .21554 L
.41261 .21546 L
.43132 .21436 L
s
.4 g
.45094 .1555 m
.47057 .15489 L
.49019 .1546 L
.50981 .15452 L
.52943 .1546 L
.54906 .1549 L
.56868 .15552 L
.58681 .15659 L
.5883 .1567 L
.60793 .15877 L
.62755 .16295 L
.64717 .17335 L
.64937 .17622 L
.64717 .19052 L
.64107 .19584 L
.62755 .20098 L
.60793 .20489 L
.5883 .20706 L
.56868 .20836 L
.54906 .20913 L
.52943 .20955 L
.50981 .20968 L
.49019 .20955 L
.47057 .20914 L
.45094 .20838 L
.43132 .20709 L
.4117 .20495 L
.39207 .20109 L
.37814 .19584 L
.37245 .19101 L
.36989 .17622 L
.37245 .17297 L
.39207 .16283 L
.4117 .15871 L
.43132 .15667 L
.43243 .15659 L
F
0 g
.45094 .1555 m
.47057 .15489 L
.49019 .1546 L
.50981 .15452 L
.52943 .1546 L
.54906 .1549 L
.56868 .15552 L
.58681 .15659 L
.5883 .1567 L
.60793 .15877 L
.62755 .16295 L
.64717 .17335 L
.64937 .17622 L
.64717 .19052 L
.64107 .19584 L
.62755 .20098 L
.60793 .20489 L
.5883 .20706 L
.56868 .20836 L
.54906 .20913 L
.52943 .20955 L
.50981 .20968 L
.49019 .20955 L
.47057 .20914 L
.45094 .20838 L
.43132 .20709 L
.4117 .20495 L
.39207 .20109 L
.37814 .19584 L
.37245 .19101 L
.36989 .17622 L
.37245 .17297 L
.39207 .16283 L
.4117 .15871 L
.43132 .15667 L
.43243 .15659 L
.45094 .1555 L
s
.4 g
.39207 .28299 m
.4117 .27816 L
.43132 .27616 L
.45094 .27524 L
.47057 .27481 L
.49019 .27462 L
.50981 .27457 L
.52943 .27463 L
.54906 .27482 L
.56868 .27525 L
.5883 .27619 L
.60793 .27822 L
.62755 .28315 L
.64038 .29396 L
.62755 .31056 L
.62167 .31358 L
.60793 .31791 L
.5883 .32164 L
.56868 .32416 L
.54906 .32579 L
.52943 .3267 L
.50981 .327 L
.49019 .32671 L
.47057 .32581 L
.45094 .3242 L
.43132 .3217 L
.4117 .318 L
.39755 .31358 L
.39207 .3108 L
.37883 .29396 L
F
0 g
.39207 .28299 m
.4117 .27816 L
.43132 .27616 L
.45094 .27524 L
.47057 .27481 L
.49019 .27462 L
.50981 .27457 L
.52943 .27463 L
.54906 .27482 L
.56868 .27525 L
.5883 .27619 L
.60793 .27822 L
.62755 .28315 L
.64038 .29396 L
.62755 .31056 L
.62167 .31358 L
.60793 .31791 L
.5883 .32164 L
.56868 .32416 L
.54906 .32579 L
.52943 .3267 L
.50981 .327 L
.49019 .32671 L
.47057 .32581 L
.45094 .3242 L
.43132 .3217 L
.4117 .318 L
.39755 .31358 L
.39207 .3108 L
.37883 .29396 L
.39207 .28299 L
s
.7 g
.4117 .22797 m
.43132 .2221 L
.45094 .21942 L
.47057 .21806 L
.49019 .21741 L
.50981 .21722 L
.52943 .21742 L
.54906 .21808 L
.56868 .21945 L
.5883 .22218 L
.60793 .22816 L
.61723 .23509 L
.60793 .25168 L
.60235 .25471 L
.5883 .26253 L
.56868 .26744 L
.54906 .26967 L
.52943 .27069 L
.50981 .27099 L
.49019 .2707 L
.47057 .2697 L
.45094 .2675 L
.43132 .26267 L
.41687 .25471 L
.4117 .25193 L
.402 .23509 L
F
0 g
.4117 .22797 m
.43132 .2221 L
.45094 .21942 L
.47057 .21806 L
.49019 .21741 L
.50981 .21722 L
.52943 .21742 L
.54906 .21808 L
.56868 .21945 L
.5883 .22218 L
.60793 .22816 L
.61723 .23509 L
.60793 .25168 L
.60235 .25471 L
.5883 .26253 L
.56868 .26744 L
.54906 .26967 L
.52943 .27069 L
.50981 .27099 L
.49019 .2707 L
.47057 .2697 L
.45094 .2675 L
.43132 .26267 L
.41687 .25471 L
.4117 .25193 L
.402 .23509 L
.4117 .22797 L
s
.6 g
.4117 .11551 m
.43132 .10813 L
.45094 .10457 L
.47057 .10266 L
.49019 .10171 L
.50981 .10142 L
.52943 .10172 L
.54906 .10269 L
.56868 .10462 L
.5883 .10823 L
.60793 .11575 L
.61028 .11735 L
.61032 .13697 L
.60793 .13796 L
.5883 .14283 L
.56868 .14528 L
.54906 .14664 L
.52943 .14734 L
.50981 .14756 L
.49019 .14735 L
.47057 .14666 L
.45094 .14532 L
.43132 .1429 L
.4117 .1381 L
.40892 .13697 L
.40896 .11735 L
F
0 g
.4117 .11551 m
.43132 .10813 L
.45094 .10457 L
.47057 .10266 L
.49019 .10171 L
.50981 .10142 L
.52943 .10172 L
.54906 .10269 L
.56868 .10462 L
.5883 .10823 L
.60793 .11575 L
.61028 .11735 L
.61032 .13697 L
.60793 .13796 L
.5883 .14283 L
.56868 .14528 L
.54906 .14664 L
.52943 .14734 L
.50981 .14756 L
.49019 .14735 L
.47057 .14666 L
.45094 .14532 L
.43132 .1429 L
.4117 .1381 L
.40892 .13697 L
.40896 .11735 L
.4117 .11551 L
s
.3 g
.43132 .16769 m
.45094 .16367 L
.47057 .16161 L
.49019 .16061 L
.50981 .16031 L
.52943 .16062 L
.54906 .16164 L
.56868 .16372 L
.5883 .1678 L
.60589 .17622 L
.59788 .19584 L
.5883 .19889 L
.56868 .20255 L
.54906 .20451 L
.52943 .2055 L
.50981 .20581 L
.49019 .20551 L
.47057 .20453 L
.45094 .2026 L
.43132 .19899 L
.42135 .19584 L
.41334 .17622 L
F
0 g
.43132 .16769 m
.45094 .16367 L
.47057 .16161 L
.49019 .16061 L
.50981 .16031 L
.52943 .16062 L
.54906 .16164 L
.56868 .16372 L
.5883 .1678 L
.60589 .17622 L
.59788 .19584 L
.5883 .19889 L
.56868 .20255 L
.54906 .20451 L
.52943 .2055 L
.50981 .20581 L
.49019 .20551 L
.47057 .20453 L
.45094 .2026 L
.43132 .19899 L
.42135 .19584 L
.41334 .17622 L
.43132 .16769 L
s
.8 g
.43132 .23227 m
.45094 .2257 L
.47057 .22288 L
.49019 .22158 L
.50981 .2212 L
.52943 .2216 L
.54906 .22292 L
.56868 .22578 L
.5883 .2325 L
.59191 .23509 L
.5883 .24692 L
.57374 .25471 L
.56868 .25759 L
.54906 .26411 L
.52943 .26679 L
.50981 .26755 L
.49019 .26683 L
.47057 .26419 L
.45094 .25778 L
.44549 .25471 L
.43132 .24726 L
.42732 .23509 L
F
0 g
.43132 .23227 m
.45094 .2257 L
.47057 .22288 L
.49019 .22158 L
.50981 .2212 L
.52943 .2216 L
.54906 .22292 L
.56868 .22578 L
.5883 .2325 L
.59191 .23509 L
.5883 .24692 L
.57374 .25471 L
.56868 .25759 L
.54906 .26411 L
.52943 .26679 L
.50981 .26755 L
.49019 .26683 L
.47057 .26419 L
.45094 .25778 L
.44549 .25471 L
.43132 .24726 L
.42732 .23509 L
.43132 .23227 L
s
.3 g
.43132 .291 m
.45094 .28433 L
.47057 .28173 L
.49019 .28057 L
.50981 .28024 L
.52943 .28058 L
.54906 .28176 L
.56868 .28441 L
.5883 .29125 L
.59148 .29396 L
.5883 .302 L
.56868 .31196 L
.56294 .31358 L
.54906 .31645 L
.52943 .31849 L
.50981 .3191 L
.49019 .31852 L
.47057 .31651 L
.4563 .31358 L
.45094 .31208 L
.43132 .30238 L
.42775 .29396 L
F
0 g
.43132 .291 m
.45094 .28433 L
.47057 .28173 L
.49019 .28057 L
.50981 .28024 L
.52943 .28058 L
.54906 .28176 L
.56868 .28441 L
.5883 .29125 L
.59148 .29396 L
.5883 .302 L
.56868 .31196 L
.56294 .31358 L
.54906 .31645 L
.52943 .31849 L
.50981 .3191 L
.49019 .31852 L
.47057 .31651 L
.4563 .31358 L
.45094 .31208 L
.43132 .30238 L
.42775 .29396 L
.43132 .291 L
s
.6 g
.45094 .34707 m
.47057 .34351 L
.49019 .34211 L
.50981 .34173 L
.52943 .34213 L
.54906 .34355 L
.56868 .34719 L
.57927 .35283 L
.56868 .36353 L
.54906 .36916 L
.52943 .3717 L
.51327 .37245 L
.50981 .37247 L
.50599 .37245 L
.49019 .37173 L
.47057 .36923 L
.45094 .3637 L
.43996 .35283 L
F
0 g
.45094 .34707 m
.47057 .34351 L
.49019 .34211 L
.50981 .34173 L
.52943 .34213 L
.54906 .34355 L
.56868 .34719 L
.57927 .35283 L
.56868 .36353 L
.54906 .36916 L
.52943 .3717 L
.51327 .37245 L
.50981 .37247 L
.50599 .37245 L
.49019 .37173 L
.47057 .36923 L
.45094 .3637 L
.43996 .35283 L
.45094 .34707 L
s
.2 g
.45094 .17277 m
.47057 .16839 L
.49019 .16644 L
.50981 .16588 L
.52943 .16647 L
.54906 .16845 L
.56868 .1729 L
.57641 .17622 L
.56868 .19534 L
.56745 .19584 L
.54906 .19933 L
.52943 .2011 L
.50981 .20163 L
.49019 .20112 L
.47057 .19938 L
.45179 .19584 L
.45094 .1955 L
.44281 .17622 L
F
0 g
.45094 .17277 m
.47057 .16839 L
.49019 .16644 L
.50981 .16588 L
.52943 .16647 L
.54906 .16845 L
.56868 .1729 L
.57641 .17622 L
.56868 .19534 L
.56745 .19584 L
.54906 .19933 L
.52943 .2011 L
.50981 .20163 L
.49019 .20112 L
.47057 .19938 L
.45179 .19584 L
.45094 .1955 L
.44281 .17622 L
.45094 .17277 L
s
.9 g
.45094 .23439 m
.47057 .22847 L
.49019 .22619 L
.50981 .22556 L
.52943 .22622 L
.54906 .22854 L
.56868 .2346 L
.56953 .23509 L
.56868 .24426 L
.54906 .25347 L
.54598 .25471 L
.52943 .2585 L
.50981 .26022 L
.49019 .25857 L
.47317 .25471 L
.47057 .25357 L
.45094 .24467 L
.4497 .23509 L
F
0 g
.45094 .23439 m
.47057 .22847 L
.49019 .22619 L
.50981 .22556 L
.52943 .22622 L
.54906 .22854 L
.56868 .2346 L
.56953 .23509 L
.56868 .24426 L
.54906 .25347 L
.54598 .25471 L
.52943 .2585 L
.50981 .26022 L
.49019 .25857 L
.47317 .25471 L
.47057 .25357 L
.45094 .24467 L
.4497 .23509 L
.45094 .23439 L
s
.2 g
.47057 .29239 m
.49019 .28853 L
.50981 .2876 L
.52943 .28857 L
.54906 .29253 L
.55252 .29396 L
.54906 .30112 L
.52943 .3072 L
.50981 .30863 L
.49019 .30726 L
.47057 .30137 L
.46669 .29396 L
F
0 g
.47057 .29239 m
.49019 .28853 L
.50981 .2876 L
.52943 .28857 L
.54906 .29253 L
.55252 .29396 L
.54906 .30112 L
.52943 .3072 L
.50981 .30863 L
.49019 .30726 L
.47057 .30137 L
.46669 .29396 L
.47057 .29239 L
s
.1 g
.49019 .1732 m
.50981 .17217 L
.52943 .17324 L
.54736 .17622 L
.52943 .19583 L
.52934 .19584 L
.50981 .19674 L
.49019 .19587 L
.48973 .19584 L
.47191 .17622 L
F
0 g
.49019 .1732 m
.50981 .17217 L
.52943 .17324 L
.54736 .17622 L
.52943 .19583 L
.52934 .19584 L
.50981 .19674 L
.49019 .19587 L
.48973 .19584 L
.47191 .17622 L
.49019 .1732 L
s
1 g
.49019 .2319 m
.50981 .23077 L
.52943 .23194 L
.54669 .23509 L
.52943 .24931 L
.50981 .25103 L
.49019 .24939 L
.47252 .23509 L
F
0 g
.49019 .2319 m
.50981 .23077 L
.52943 .23194 L
.54669 .23509 L
.52943 .24931 L
.50981 .25103 L
.49019 .24939 L
.47252 .23509 L
.49019 .2319 L
s
.7 g
.49019 .11941 m
.50981 .11798 L
.52943 .11947 L
.53678 .13697 L
.52943 .13752 L
.50981 .13838 L
.49019 .13755 L
.48216 .13697 L
F
0 g
.49019 .11941 m
.50981 .11798 L
.52943 .11947 L
.53678 .13697 L
.52943 .13752 L
.50981 .13838 L
.49019 .13755 L
.48216 .13697 L
.49019 .11941 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00?Oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0dooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kS?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0hooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8b
onk^kS?ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08_ooool003gooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0=_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0<oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg03?ooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL08_ooool003Gooooo1_l0
0003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400[ooooo`Ko0000
1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100<oooool01Ol@413o
oooooooooooooooo410@03[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@03Cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@02;ooooo000o
ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000fooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000cooooo`05o`000?ooooooooooooooool0
0000>_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000=Oooool00onH
V9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000008_ooool0043ooooo00?oMgMgofIV
I_ooool00_ooool01Ol0003ooooooooooooooooo000003Kooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000003?ooooo00Go0000ooooooooooooooooo`00000jooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`03ogMgMomVIVKooooo00;o
oooo00Go0000ooooooooooooooooo`00000Rooooo`00@Oooool01Ol0003ooooooooooooooooo410@
00?ooooo00?o410@ooooooooool0=?ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@4100<oooool01Ol@413ooooooooooooooooo410@03[ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@03Oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo023ooooo000mooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg03Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg03?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0jooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0cooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02;ooooo000mooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^03Cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^03?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`03oeEEEOmVIVKo000000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0cooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02;ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo000Joooooooo0000C_l00001ooooo`00
6_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0?Ooo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool08ooo
ool1o`00007ooooo0008ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKo
oooo00?o0000ooooooooool0oooooom:ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooom:ooooo`7o
00000Oooool000Go00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41001_ooool00ol0003oooooooooo`3ooooood[ooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?ooooooB?ooool3o`00007o
oooo000:ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo0008ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Oooooooogmo
Od3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Ooo
ooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooVOmoOglE
o`00097oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooSOmoOgl<o`00
01GoVIVI2ol00026ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooh[o
Ogmo0ol0000/oiVIV@?o0000PomoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?oooon7ogmoO`?o0000<_nIVIT4o`0007ooOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CoooooQ?moOgl3o`0003WoVIVI0ol0001logmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04oooooh;oOgmo0_l0000ooiVIV@03o`000?moOgooOgmo07WoOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooPOmoOgl00ol0003oVIVIoiVIV@0HoiVI
V@ko00006_nIVIT00ol0003oOgmoogmoO`1hogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04oooooh7oOgmo00?o0000oiVIVOnIVIT06?nIVIT00ol0003o/k>cok>c/`0:ok>c/`03
o`000?nIVIWoVIVI01SoVIVI00?o0000ogmoOomoOgl0N?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?oooon1ogmoO`03o`000?nIVIWoVIVI01OoVIVI00?o0000ok>c/onc/k<0
3?nc/k<00ol0003oVIVIoiVIV@0GoiVIV@03o`000?moOgooOgmo07SoOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CoooooPOmoOgl00ol0003oVIVIoiVIV@0GoiVIV@03o`000?nc
/k?o/k>c00co/k>c00?o0000oiVIVOnIVIT05onIVIT00ol0003oOgmoogmoO`1hogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04oooooh7oOgmo00?o0000oiVIVOnIVIT05_nIVIT0
0ol0003o/k>cok>c/`0=ok>c/`03o`000?nIVIWoVIVI01OoVIVI00?o0000ogmoOomoOgl0N?moOgl6
ooooo`7o00000Oooool001[ooooo0_l00005oooooh7oOgmo00?o0000oiVIVOnIVIT05_nIVIT00ol0
003o/k>cok>c/`0>ok>c/`03o`000?nIVIWoVIVI01KoVIVI00?o0000ogmoOomoOgl0N?moOgl5oooo
o`;o00000Oooool001[ooooo00?o0000ooooooooool01?oooon1ogmoO`Co00005?nIVIT8o`0000Go
/k>c1_l0000FoiVIV@?o0000N_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?oooon5ogmoO`?o00006OnIVIT5o`0001WoVIVI0ol0001mogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooohSoOgmo1Ol0000]oiVIV@Go0000P?moOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?oooon=ogmoO`go00004onIVIT=o`0008GoOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooV_moOglCo`0009;oOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooohcoOgmo;_l00025ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04oooooh3oOgmo3?l0000^ofIVIPco0000NOmoOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?oooommogmoO`?o00004_mVIVHRo`0001;oIVIV0ol0001f
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooog[oOgmo0ol0000?ofIV
IPKo00008_m<C4`7o`0000koIVIV0ol0001cogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooogSoOgmo0_l0000=ofIVIPGo00003Om<C4`Eo`0000goC4a<1?l0000=ofIVIP;o
0000LOmoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooomfogmoO`;o0000
3OmVIVH2o`0000_oC4a<1ol0000Eoc<c<`Ko00002om<C4`2o`0000goIVIV0_l0001_ogmoO`Kooooo
0Ol00001ooooo`006_ooool2o`0000GoooooMOmoOgl00ol0003oIVIVofIVIP0;ofIVIP;o00002Om<
C4`4o`0000Oo<c<c5?l00007oc<c<`Go00002?m<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?mo
OgooOgmo06coOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooM?moOgl0
0ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<00OoC4a<0_l00008oc<c<`?o00005?lI6AT3
o`0000Wo<c<c00?o0000oda<C?m<C4`01_m<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?moOgoo
Ogmo06_oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooM?moOgl00ol0
003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<00OoC4a<00?o0000oc<c<olc<c<01olc<c<00ol0
003o6ATIoaTI6@0FoaTI6@03o`000?lc<c?o<c<c00Oo<c<c00?o0000oda<C?m<C4`01_m<C4`00ol0
003oIVIVofIVIP0<ofIVIP03o`000?moOgooOgmo06_oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CoooooM?moOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<00Oo
C4a<00?o0000oc<c<olc<c<01olc<c<00ol0003o6ATIoaTI6@0DoaTI6@03o`000?lc<c?o<c<c00Oo
<c<c00?o0000oda<C?m<C4`01om<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?moOgooOgmo06_o
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooMOmoOgl00ol0003oIVIV
ofIVIP0;ofIVIP03o`000?m<C4coC4a<00OoC4a<00?o0000oc<c<olc<c<02?lc<c<00ol0003o6ATI
oaTI6@0BoaTI6@03o`000?lc<c?o<c<c00So<c<c00?o0000oda<C?m<C4`01_m<C4`00ol0003oIVIV
ofIVIP0<ofIVIP03o`000?moOgooOgmo06coOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CoooooMOmoOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<00OoC4a<00?o
0000oc<c<olc<c<02?lc<c<00ol0003o6ATIoaTI6@0@oaTI6@03o`000?lc<c?o<c<c00So<c<c00?o
0000oda<C?m<C4`01om<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?moOgooOgmo06coOgmo1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooMOmoOgl00ol0003oIVIVofIVIP0<
ofIVIP03o`000?m<C4coC4a<00OoC4a<00?o0000oc<c<olc<c<02Olc<c<00ol0003o6ATIoaTI6@0>
oaTI6@03o`000?lc<c?o<c<c00Wo<c<c00?o0000oda<C?m<C4`01om<C4`00ol0003oIVIVofIVIP0<
ofIVIP03o`000?moOgooOgmo06coOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CoooooM_moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<00OoC4a<00?o0000oc<c
<olc<c<02_lc<c<00ol0003o6ATIoaTI6@0<oaTI6@03o`000?lc<c?o<c<c00Wo<c<c00?o0000oda<
C?m<C4`01om<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?moOgooOgmo06goOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CoooooMomoOgl3o`0000_oIVIV0ol00007oda<C0Co
00002Olc<c<>o`0000Wo<c<c1?l00008oda<C0;o00002omVIVH3o`00073oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CoooooN_moOgl4o`0000[oIVIV1Ol00006oda<C0ko0000
1Olc<c<=o`0000OoC4a<1Ol00009ofIVIPCo0000LomoOgl6ooooo`7o00000Oooool000oooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo00CoooooO_moOgl3o`0000coIVIV
1_l0000>oda<C0Go00003Om<C4`7o`0000_oIVIV0ol0001gogmoO`Kooooo0Ol00001ooooo`003ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?oooon1ogmoO`co0000
1_mVIVHPo`0000OoIVIV2ol0001jogmoO`Kooooo0Ol00001ooooo`003oooool01Ol@413ooooooooo
oooooooo410@00Kooooo00?o0000ooooooooool01?oooon=ogmoObgo0000QOmoOgl6ooooo`7o0000
0Oooool000oooooo00Go0000ooooooooooooooooo`000006ooooo`?o00001?ooooooogmoOd3oOgmo
1?ooool3o`00007ooooo000?ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooo
ooooo`04ooooogooOgmoBOl0001gogmoO`Kooooo0Ol00001ooooo`003oooool01Ol@413ooooooooo
oooooooo410@00Kooooo00?o0000ooooooooool01?oooomjogmoO`Go00003OnIVITXo`0001CoVIVI
1Ol0001bogmoO`Kooooo0Ol00001ooooo`003oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo
00?o0000ooooooooool01?oooomgogmoO`?o00003OnIVIT5o`0000go/k>c5Ol00006ok>c/`co0000
3OnIVIT3o`0006ooOgmo1_ooool1o`00007ooooo000?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1_ooool00ol0003oooooooooo`04ooooogGoOgmo0_l0000=oiVIV@?o00002onc/k<7o`0001Goc<c<
1_l0000<ok>c/`?o00003OnIVIT00ol0003oOgmoogmoO`1/ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooogCoOgmo00?o0000oiVIVOnIVIT02onIVIT2o`0000Wo/k>c1Ol0
0007olc<c1Go00001_o<c<`5o`0000[o/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmo
O`1[ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooog?oOgmo00?o0000
oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`06ok>c/`?o00001Oo<c<`7o`0000Ooi^KV1ol00007
onKViPGo00001_o<c<`3o`0000So/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`1Z
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooog;oOgmo00?o0000oiVI
VOnIVIT02onIVIT00ol0003o/k>cok>c/`05ok>c/`;o00001Oo<c<`3o`0000Ooi^KV1ol00007oooo
o`Ko00001_oVi^H3o`0000Koc<c<0_l00007ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmo
OomoOgl0JOmoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooomaogmoO`03
o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c005olc<c003
o`000?oVi^Koi^KV00Coi^KV0ol0000Dooooo`?o00001_oVi^H00ol0003oc<c<olc<c005olc<c003
o`000?nc/k?o/k>c00Go/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`1XogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooog7oOgmo00?o0000oiVIVOnIVIT0
2onIVIT00ol0003o/k>cok>c/`05ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000onKVi_oVi^H0
1_oVi^H00ol0003oooooooooo`0Booooo`03o`000?oVi^Koi^KV00Koi^KV00?o0000olc<c?o<c<`0
1Oo<c<`00ol0003o/k>cok>c/`05ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl0
J?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooombogmoO`03o`000?nI
VIWoVIVI00_oVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?oV
i^Koi^KV00Ooi^KV0_l0000@ooooo`;o00002OoVi^H00ol0003oc<c<olc<c005olc<c003o`000?nc
/k?o/k>c00Co/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`1YogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooog?oOgmo00?o0000oiVIVOnIVIT02onIVIT0
0ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00Coc<c<0_l0000:onKViP03o`000?oooooo
oooo00cooooo00?o0000onKVi_oVi^H02?oVi^H2o`0000Koc<c<00?o0000ok>c/onc/k<01?nc/k<0
0ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo06[oOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CoooooLomoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c
00Co/k>c0_l00007olc<c0;o00002OoVi^H5o`0000Gooooo1?l00009onKViP;o00001oo<c<`2o`00
00Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`1ZogmoO`Kooooo0Ol00001oooo
o`006_ooool2o`0000GoooooM?moOgl00ol0003oVIVIoiVIV@0;oiVIV@;o00001_nc/k<3o`0000Ko
c<c<0_l0000<onKViPGo00002ooVi^H2o`0000Koc<c<0ol00006ok>c/`;o00003OnIVIT00ol0003o
OgmoogmoO`1[ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04ooooogGoOgmo
0ol0000<oiVIV@;o00001onc/k<2o`0000Koc<c<1Ol0000BonKViPGo00001_o<c<`2o`0000Oo/k>c
0_l0000<oiVIV@?o0000K_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
oomhogmoO`;o00003?nIVIT00ol0003o/k>cok>c/`06ok>c/`?o00002?o<c<`7o`0000Goi^KV1_l0
0009olc<c0;o00002?nc/k<00ol0003oVIVIoiVIV@0:oiVIV@;o0000LOmoOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?oooomjogmoO`03o`000?nIVIWoVIVI00[oVIVI00?o0000
ok>c/onc/k<02?nc/k<3o`0000coc<c<1Ol0000<olc<c0?o00002Onc/k<00ol0003oVIVIoiVIV@0:
oiVIV@03o`000?moOgooOgmo077oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CoooooNomoOgl3o`0000[oVIVI1Ol00008ok>c/`Go00004oo<c<`5o`0000So/k>c1?l0000:oiVI
V@?o0000M?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooomnogmoO`?o
00003?nIVIT6o`0000Oo/k>c4ol00006ok>c/`Oo00002onIVIT3o`0007OoOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CoooooPOmoOgl<o`0000KoVIVI1ol0000Cok>c/`Ko0000
1onIVIT;o`0007[oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooSOmo
Ogl]o`0008GoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooQOmoOgll
o`0007koOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooP?moOgl5o`00
03coIVIV1Ol0001iogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooggo
Ogmo0ol0000BofIVIR;o00004_mVIVH3o`0007KoOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CoooooN_moOgl3o`00013oIVIV1Ol0000Roda<C0Go00004?mVIVH3o`0007?oOgmo
1_ooool1o`00007ooooo000Jooooo`;o00001OoooomiogmoO`03o`000?mVIVKoIVIV00koIVIV0ol0
000=oda<C1;o00003Om<C4`3o`00013oIVIV00?o0000ogmoOomoOgl0L?moOgl5ooooo`;o00000Ooo
ool001[ooooo00?o0000ooooooooool01?oooomhogmoO`03o`000?mVIVKoIVIV00goIVIV0_l0000=
oda<C0?o00004_lc<c<3o`0000goC4a<0_l0000?ofIVIP03o`000?moOgooOgmo06ooOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooMomoOgl00ol0003oIVIVofIVIP0=ofIV
IP03o`000?m<C4coC4a<00[oC4a<0ol0000Hoc<c<`?o00003?m<C4`00ol0003oIVIVofIVIP0=ofIV
IP03o`000?moOgooOgmo06koOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
ooooMomoOgl00ol0003oIVIVofIVIP0=ofIVIP03o`000?m<C4coC4a<00[oC4a<00?o0000oc<c<olc
<c<06_lc<c<00ol0003oC4a<oda<C00:oda<C003o`000?mVIVKoIVIV00goIVIV00?o0000ogmoOomo
Ogl0K_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooomhogmoO`03o`00
0?mVIVKoIVIV00goIVIV00?o0000oda<C?m<C4`02_m<C4`00ol0003o<c<coc<c<`0Hoc<c<`03o`00
0?m<C4coC4a<00[oC4a<00?o0000ofIVI_mVIVH03OmVIVH00ol0003oOgmoogmoO`1_ogmoO`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooogWoOgmo00?o0000ofIVI_mVIVH03?mV
IVH2o`0000_oC4a<0ol0000Foc<c<`?o00002om<C4`2o`0000koIVIV00?o0000ogmoOomoOgl0L?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooomiogmoO`03o`000?mVIVKo
IVIV00koIVIV0ol0000;oda<C0?o00004?lc<c<3o`0000_oC4a<0ol0000@ofIVIP03o`000?moOgoo
Ogmo073oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooN_moOgl00ol0
003oIVIVofIVIP0@ofIVIP;o00003?m<C4`@o`0000coC4a<0_l0000BofIVIP03o`000?moOgooOgmo
077oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooNomoOgl2o`0001;o
IVIV0_l0000Toda<C0;o00004_mVIVH2o`0007CoOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CoooooOOmoOgl4o`00013oIVIV0ol0000Noda<C0?o00004OmVIVH3o`0007KoOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooPOmoOgl5o`0000koIVIV3Ol0
0005oda<C0co00003_mVIVH6o`0007WoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CoooooQ_moOgl7o`0001CoIVIV1Ol0000DofIVIPKo0000OomoOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?oooon=ogmoO`Ko00008?mVIVH7o`0008GoOgmo1_ooool1o`00
007ooooo000Jooooo`;o00001OoooonCogmoOb3o0000S?moOgl5ooooo`;o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooVOmoOglEo`00097o
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooT_moOgl7o`0001GoVIVI
1_l0002;ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooohkoOgmo1?l0
000RoiVIV@Co0000QomoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon<
ogmoO`;o0000:_nIVIT2o`0008GoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CoooooRomoOgl2o`0002coVIVI0_l00024ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooohgoOgmo00?o0000oiVIVOnIVIT0:?nIVIT00ol0003oOgmoogmoO`24ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooohkoOgmo00?o0000oiVIVOnIVIT0
9_nIVIT00ol0003oOgmoogmoO`25ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooohooOgmo0ol0000SoiVIV@;o0000R?moOgl6ooooo`7o00000Oooool001[ooooo0_l00005
oooooi;oOgmo0ol0000MoiVIV@?o0000R_moOgl5ooooo`;o00000Oooool001[ooooo00?o0000oooo
ooooool01?oooonEogmoO`Go00004onIVIT5o`0008goOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CoooooV_moOglCo`0009;oOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooo
ogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002?ooool4
o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h6ooooo`03o`000?oooooooooo00Co
oooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool000[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Ko
oooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000:ooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`?o00001?ooooooogmoOd3o
Ogmo1?ooool3o`00007ooooo000:ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`000006ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`00
2_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003o
ooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3o
Ogmo1_ooool1o`00007ooooo0008ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
ooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3o
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Joooo
o`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo
@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooo
ogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool001[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o
0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
ooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3o
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooooomo
Ogm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6
ooooo`7o00000Oooool001[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[o
oooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooo
ogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo
@?moOgl6ooooo`7o00000Oooool001[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Ooo
ool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooooomo
Ogm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000Oooooo1Ol0
0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`04ooooooooOgmo
@?moOgl6ooooo`7o00000Oooool000Oooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool000Sooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00Ko
oooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo0009ooooo`03oiRH
V?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000006ooooo`?o00001?ooooooogmoOd3o
Ogmo1?ooool3o`00007ooooo000:ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000oooooooooooo
ooooo`000006ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`00
2oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool01?ooool00ol0003o
ooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000Oooooo00Go0000okZj^_oooooo
V9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`04oooo
ooooOgmo@?moOgl6ooooo`7o00000Oooool000Oooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
ooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3o
Ogmo1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007ooooo
000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo
@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooo
ogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00
007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
ooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3o
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Ooo
ool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooo
ogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3o
Ogmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooooomo
Ogm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00
007ooooo0007ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo0007oooo
o`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o
0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000;ooooo`05o`000?oooooo
ooooooooool@41000oooool00ol@413oooooooooo`04ooooo`03o`000?oooooooooo00Cooooooomo
Ogm0ogmoO`Kooooo0Ol00001ooooo`002_ooool00onYZJWo410@ooooo`02ooooo`05o`000?oooooo
ooooooooool000001_ooool3o`0000CooooooomoOgm0ogmoO`Cooooo0ol00001ooooo`002Oooool0
0ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooooooo
o`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000[ooooo00?o^[Zjob4Q8Oooool00_ooool0
1Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_oo
ool1o`00007ooooo0007ooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo
0007ooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Ko
oooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooo
ogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool2
o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04oooo
ooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3o
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooooomo
Ogm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`00
6_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooo
ogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo
@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001
ooooo`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooooomo
Ogm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
ooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3o
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo
0Ol00001ooooo`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo
@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002Oooool2o`000009oa0@4?oo
ooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000:ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`001oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@4006ooooo`?o00001?ooooooogmo
Od3oOgmo1?ooool3o`00007ooooo0007ooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo0?ooooooB_ooool1o`00007ooooo0007oooo
o`04omgMgOmEEEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oo
oooooooo0?ooooooB_ooool1o`00007ooooo0008ooooo`03ogMgMoo<c<co000000Cooooo00Go410@
oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo0?ooooooB_ooool1o`00007ooooo0008
ooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oo
oooooooo0?ooooooB_ooool1o`00007ooooo0009ooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0?Ooo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0?Ooo
ool00ol0003oooooooooo`0Sooooo`7o00000Oooool001[ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`09ooooo`7o00000Oooool001[oooooool0001>o`00007ooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-30.1723, -14.304, 0.195672, \
0.195672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0192308 0.211538 0.0192308 [
[.11538 -0.0125 -9 -9 ]
[.11538 -0.0125 9 0 ]
[.30769 -0.0125 -9 -9 ]
[.30769 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69231 -0.0125 -6 -9 ]
[.69231 -0.0125 6 0 ]
[.88462 -0.0125 -6 -9 ]
[.88462 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -18 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .21154 -6 -4.5 ]
[-0.0125 .21154 0 4.5 ]
[-0.0125 .40385 -12 -4.5 ]
[-0.0125 .40385 0 4.5 ]
[-0.0125 .59615 -12 -4.5 ]
[-0.0125 .59615 0 4.5 ]
[-0.0125 .78846 -12 -4.5 ]
[-0.0125 .78846 0 4.5 ]
[-0.0125 .98077 -12 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11538 0 m
.11538 .00625 L
s
[(-20)] .11538 -0.0125 0 1 Mshowa
.30769 0 m
.30769 .00625 L
s
[(-10)] .30769 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69231 0 m
.69231 .00625 L
s
[(10)] .69231 -0.0125 0 1 Mshowa
.88462 0 m
.88462 .00625 L
s
[(20)] .88462 -0.0125 0 1 Mshowa
.125 Mabswid
.15385 0 m
.15385 .00375 L
s
.19231 0 m
.19231 .00375 L
s
.23077 0 m
.23077 .00375 L
s
.26923 0 m
.26923 .00375 L
s
.34615 0 m
.34615 .00375 L
s
.38462 0 m
.38462 .00375 L
s
.42308 0 m
.42308 .00375 L
s
.46154 0 m
.46154 .00375 L
s
.53846 0 m
.53846 .00375 L
s
.57692 0 m
.57692 .00375 L
s
.61538 0 m
.61538 .00375 L
s
.65385 0 m
.65385 .00375 L
s
.73077 0 m
.73077 .00375 L
s
.76923 0 m
.76923 .00375 L
s
.80769 0 m
.80769 .00375 L
s
.84615 0 m
.84615 .00375 L
s
.07692 0 m
.07692 .00375 L
s
.03846 0 m
.03846 .00375 L
s
.92308 0 m
.92308 .00375 L
s
.96154 0 m
.96154 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(-10)] -0.0125 .01923 1 0 Mshowa
0 .21154 m
.00625 .21154 L
s
[(0)] -0.0125 .21154 1 0 Mshowa
0 .40385 m
.00625 .40385 L
s
[(10)] -0.0125 .40385 1 0 Mshowa
0 .59615 m
.00625 .59615 L
s
[(20)] -0.0125 .59615 1 0 Mshowa
0 .78846 m
.00625 .78846 L
s
[(30)] -0.0125 .78846 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(40)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .05769 m
.00375 .05769 L
s
0 .09615 m
.00375 .09615 L
s
0 .13462 m
.00375 .13462 L
s
0 .17308 m
.00375 .17308 L
s
0 .25 m
.00375 .25 L
s
0 .28846 m
.00375 .28846 L
s
0 .32692 m
.00375 .32692 L
s
0 .36538 m
.00375 .36538 L
s
0 .44231 m
.00375 .44231 L
s
0 .48077 m
.00375 .48077 L
s
0 .51923 m
.00375 .51923 L
s
0 .55769 m
.00375 .55769 L
s
0 .63462 m
.00375 .63462 L
s
0 .67308 m
.00375 .67308 L
s
0 .71154 m
.00375 .71154 L
s
0 .75 m
.00375 .75 L
s
0 .82692 m
.00375 .82692 L
s
0 .86538 m
.00375 .86538 L
s
0 .90385 m
.00375 .90385 L
s
0 .94231 m
.00375 .94231 L
s
.25 Mabswid
0 0 m
0 1 L
s
.11538 .99375 m
.11538 1 L
s
.30769 .99375 m
.30769 1 L
s
.5 .99375 m
.5 1 L
s
.69231 .99375 m
.69231 1 L
s
.88462 .99375 m
.88462 1 L
s
.125 Mabswid
.15385 .99625 m
.15385 1 L
s
.19231 .99625 m
.19231 1 L
s
.23077 .99625 m
.23077 1 L
s
.26923 .99625 m
.26923 1 L
s
.34615 .99625 m
.34615 1 L
s
.38462 .99625 m
.38462 1 L
s
.42308 .99625 m
.42308 1 L
s
.46154 .99625 m
.46154 1 L
s
.53846 .99625 m
.53846 1 L
s
.57692 .99625 m
.57692 1 L
s
.61538 .99625 m
.61538 1 L
s
.65385 .99625 m
.65385 1 L
s
.73077 .99625 m
.73077 1 L
s
.76923 .99625 m
.76923 1 L
s
.80769 .99625 m
.80769 1 L
s
.84615 .99625 m
.84615 1 L
s
.07692 .99625 m
.07692 1 L
s
.03846 .99625 m
.03846 1 L
s
.92308 .99625 m
.92308 1 L
s
.96154 .99625 m
.96154 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .21154 m
1 .21154 L
s
.99375 .40385 m
1 .40385 L
s
.99375 .59615 m
1 .59615 L
s
.99375 .78846 m
1 .78846 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .05769 m
1 .05769 L
s
.99625 .09615 m
1 .09615 L
s
.99625 .13462 m
1 .13462 L
s
.99625 .17308 m
1 .17308 L
s
.99625 .25 m
1 .25 L
s
.99625 .28846 m
1 .28846 L
s
.99625 .32692 m
1 .32692 L
s
.99625 .36538 m
1 .36538 L
s
.99625 .44231 m
1 .44231 L
s
.99625 .48077 m
1 .48077 L
s
.99625 .51923 m
1 .51923 L
s
.99625 .55769 m
1 .55769 L
s
.99625 .63462 m
1 .63462 L
s
.99625 .67308 m
1 .67308 L
s
.99625 .71154 m
1 .71154 L
s
.99625 .75 m
1 .75 L
s
.99625 .82692 m
1 .82692 L
s
.99625 .86538 m
1 .86538 L
s
.99625 .90385 m
1 .90385 L
s
.99625 .94231 m
1 .94231 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.4 g
.39207 .18894 m
.4117 .18595 L
.43132 .18573 L
.45094 .18596 L
.47057 .18632 L
.49019 .18665 L
.50981 .18684 L
.52943 .18683 L
.54906 .18664 L
.56868 .1863 L
.5883 .18594 L
.60793 .18572 L
.62755 .18598 L
.64717 .18927 L
.65508 .19584 L
.66313 .21546 L
.64717 .22654 L
.62755 .23264 L
.61444 .23509 L
.60793 .23603 L
.5883 .23602 L
.56868 .23709 L
.54906 .23789 L
.52943 .23831 L
.50981 .23832 L
.49019 .23791 L
.47057 .23713 L
.45094 .23606 L
.43132 .23613 L
.42402 .23509 L
.4117 .23281 L
.39207 .22687 L
.37529 .21546 L
.38338 .19584 L
F
0 g
.39207 .18894 m
.4117 .18595 L
.43132 .18573 L
.45094 .18596 L
.47057 .18632 L
.49019 .18665 L
.50981 .18684 L
.52943 .18683 L
.54906 .18664 L
.56868 .1863 L
.5883 .18594 L
.60793 .18572 L
.62755 .18598 L
.64717 .18927 L
.65508 .19584 L
.66313 .21546 L
.64717 .22654 L
.62755 .23264 L
.61444 .23509 L
.60793 .23603 L
.5883 .23602 L
.56868 .23709 L
.54906 .23789 L
.52943 .23831 L
.50981 .23832 L
.49019 .23791 L
.47057 .23713 L
.45094 .23606 L
.43132 .23613 L
.42402 .23509 L
.4117 .23281 L
.39207 .22687 L
.37529 .21546 L
.38338 .19584 L
.39207 .18894 L
s
.6 g
.39207 .24865 m
.4117 .24554 L
.43132 .24437 L
.45094 .23821 L
.47057 .23941 L
.49019 .24013 L
.50981 .24047 L
.52943 .24046 L
.54906 .24011 L
.56868 .23937 L
.5883 .23815 L
.60793 .2444 L
.62755 .24561 L
.64717 .24885 L
.66105 .25471 L
.66298 .27433 L
.64717 .2851 L
.62755 .29155 L
.61587 .29396 L
.60793 .2954 L
.5883 .29789 L
.56868 .29944 L
.54906 .30036 L
.52943 .3008 L
.50981 .30081 L
.49019 .30039 L
.47057 .29949 L
.45094 .29796 L
.43132 .29552 L
.42258 .29396 L
.4117 .29174 L
.39207 .28544 L
.37544 .27433 L
.37739 .25471 L
F
0 g
.39207 .24865 m
.4117 .24554 L
.43132 .24437 L
.45094 .23821 L
.47057 .23941 L
.49019 .24013 L
.50981 .24047 L
.52943 .24046 L
.54906 .24011 L
.56868 .23937 L
.5883 .23815 L
.60793 .2444 L
.62755 .24561 L
.64717 .24885 L
.66105 .25471 L
.66298 .27433 L
.64717 .2851 L
.62755 .29155 L
.61587 .29396 L
.60793 .2954 L
.5883 .29789 L
.56868 .29944 L
.54906 .30036 L
.52943 .3008 L
.50981 .30081 L
.49019 .30039 L
.47057 .29949 L
.45094 .29796 L
.43132 .29552 L
.42258 .29396 L
.4117 .29174 L
.39207 .28544 L
.37544 .27433 L
.37739 .25471 L
.39207 .24865 L
s
.6 g
.43132 .13685 m
.45094 .13217 L
.47057 .13045 L
.49019 .12957 L
.50981 .12921 L
.52943 .12921 L
.54906 .1296 L
.56868 .1305 L
.5883 .13226 L
.60793 .13685 L
.61282 .13697 L
.62755 .14241 L
.63881 .15659 L
.62755 .16646 L
.60793 .17304 L
.58969 .17622 L
.5883 .17644 L
.56868 .17887 L
.54906 .18034 L
.52943 .18104 L
.50981 .18106 L
.49019 .18038 L
.47057 .17894 L
.45094 .17656 L
.44878 .17622 L
.43132 .17322 L
.4117 .16685 L
.39964 .15659 L
.4117 .142 L
.42565 .13697 L
F
0 g
.43132 .13685 m
.45094 .13217 L
.47057 .13045 L
.49019 .12957 L
.50981 .12921 L
.52943 .12921 L
.54906 .1296 L
.56868 .1305 L
.5883 .13226 L
.60793 .13685 L
.61282 .13697 L
.62755 .14241 L
.63881 .15659 L
.62755 .16646 L
.60793 .17304 L
.58969 .17622 L
.5883 .17644 L
.56868 .17887 L
.54906 .18034 L
.52943 .18104 L
.50981 .18106 L
.49019 .18038 L
.47057 .17894 L
.45094 .17656 L
.44878 .17622 L
.43132 .17322 L
.4117 .16685 L
.39964 .15659 L
.4117 .142 L
.42565 .13697 L
.43132 .13685 L
s
.4 g
.4117 .31119 m
.43132 .3082 L
.45094 .30704 L
.47057 .30657 L
.49019 .30641 L
.50981 .30636 L
.52943 .30636 L
.54906 .30641 L
.56868 .30658 L
.5883 .30706 L
.60793 .30828 L
.62755 .31138 L
.63437 .31358 L
.63683 .3332 L
.62755 .33998 L
.60793 .3476 L
.5883 .35189 L
.5824 .35283 L
.56868 .35481 L
.54906 .35662 L
.52943 .35746 L
.50981 .35747 L
.49019 .35667 L
.47057 .35491 L
.45606 .35283 L
.45094 .35202 L
.43132 .34781 L
.4117 .3404 L
.40162 .3332 L
.40409 .31358 L
F
0 g
.4117 .31119 m
.43132 .3082 L
.45094 .30704 L
.47057 .30657 L
.49019 .30641 L
.50981 .30636 L
.52943 .30636 L
.54906 .30641 L
.56868 .30658 L
.5883 .30706 L
.60793 .30828 L
.62755 .31138 L
.63437 .31358 L
.63683 .3332 L
.62755 .33998 L
.60793 .3476 L
.5883 .35189 L
.5824 .35283 L
.56868 .35481 L
.54906 .35662 L
.52943 .35746 L
.50981 .35747 L
.49019 .35667 L
.47057 .35491 L
.45606 .35283 L
.45094 .35202 L
.43132 .34781 L
.4117 .3404 L
.40162 .3332 L
.40409 .31358 L
.4117 .31119 L
s
.3 g
.45094 .19243 m
.47057 .19106 L
.49019 .19065 L
.50981 .19054 L
.52943 .19054 L
.54906 .19066 L
.56868 .19109 L
.5883 .19253 L
.60315 .19584 L
.60793 .19743 L
.62383 .21546 L
.60793 .22582 L
.5883 .23138 L
.56868 .23441 L
.56286 .23509 L
.54906 .2357 L
.52943 .2362 L
.50981 .23621 L
.49019 .23573 L
.47559 .23509 L
.47057 .2345 L
.45094 .23153 L
.43132 .22612 L
.41461 .21546 L
.43132 .19714 L
.43531 .19584 L
F
0 g
.45094 .19243 m
.47057 .19106 L
.49019 .19065 L
.50981 .19054 L
.52943 .19054 L
.54906 .19066 L
.56868 .19109 L
.5883 .19253 L
.60315 .19584 L
.60793 .19743 L
.62383 .21546 L
.60793 .22582 L
.5883 .23138 L
.56868 .23441 L
.56286 .23509 L
.54906 .2357 L
.52943 .2362 L
.50981 .23621 L
.49019 .23573 L
.47559 .23509 L
.47057 .2345 L
.45094 .23153 L
.43132 .22612 L
.41461 .21546 L
.43132 .19714 L
.43531 .19584 L
.45094 .19243 L
s
.7 g
.43132 .25344 m
.45094 .24514 L
.47057 .24391 L
.49019 .24369 L
.50981 .24368 L
.52943 .24368 L
.54906 .24369 L
.56868 .24393 L
.5883 .24524 L
.60793 .25363 L
.61168 .25471 L
.62308 .27433 L
.60793 .28367 L
.5883 .2895 L
.56868 .29278 L
.5584 .29396 L
.54906 .29466 L
.52943 .29554 L
.50981 .29556 L
.49019 .29471 L
.47998 .29396 L
.47057 .29288 L
.45094 .28967 L
.43132 .28399 L
.41537 .27433 L
.42679 .25471 L
F
0 g
.43132 .25344 m
.45094 .24514 L
.47057 .24391 L
.49019 .24369 L
.50981 .24368 L
.52943 .24368 L
.54906 .24369 L
.56868 .24393 L
.5883 .24524 L
.60793 .25363 L
.61168 .25471 L
.62308 .27433 L
.60793 .28367 L
.5883 .2895 L
.56868 .29278 L
.5584 .29396 L
.54906 .29466 L
.52943 .29554 L
.50981 .29556 L
.49019 .29471 L
.47998 .29396 L
.47057 .29288 L
.45094 .28967 L
.43132 .28399 L
.41537 .27433 L
.42679 .25471 L
.43132 .25344 L
s
.2 g
.49019 .19492 m
.50981 .19418 L
.52943 .19419 L
.54906 .19498 L
.5594 .19584 L
.56868 .19732 L
.5883 .20294 L
.59879 .21546 L
.5883 .22259 L
.56868 .22846 L
.54906 .2313 L
.52943 .23254 L
.50981 .23256 L
.49019 .23138 L
.47057 .22861 L
.45094 .22293 L
.43967 .21546 L
.45094 .20259 L
.47057 .19718 L
.47898 .19584 L
F
0 g
.49019 .19492 m
.50981 .19418 L
.52943 .19419 L
.54906 .19498 L
.5594 .19584 L
.56868 .19732 L
.5883 .20294 L
.59879 .21546 L
.5883 .22259 L
.56868 .22846 L
.54906 .2313 L
.52943 .23254 L
.50981 .23256 L
.49019 .23138 L
.47057 .22861 L
.45094 .22293 L
.43967 .21546 L
.45094 .20259 L
.47057 .19718 L
.47898 .19584 L
.49019 .19492 L
s
.8 g
.47057 .25295 m
.49019 .24991 L
.50981 .24893 L
.52943 .24895 L
.54906 .24998 L
.56868 .25315 L
.57387 .25471 L
.5883 .25894 L
.59748 .27433 L
.5883 .28 L
.56868 .28605 L
.54906 .28906 L
.52943 .29039 L
.50981 .29041 L
.49019 .28914 L
.47057 .28621 L
.45094 .28035 L
.44098 .27433 L
.45094 .2586 L
.46457 .25471 L
F
0 g
.47057 .25295 m
.49019 .24991 L
.50981 .24893 L
.52943 .24895 L
.54906 .24998 L
.56868 .25315 L
.57387 .25471 L
.5883 .25894 L
.59748 .27433 L
.5883 .28 L
.56868 .28605 L
.54906 .28906 L
.52943 .29039 L
.50981 .29041 L
.49019 .28914 L
.47057 .28621 L
.45094 .28035 L
.44098 .27433 L
.45094 .2586 L
.46457 .25471 L
.47057 .25295 L
s
.7 g
.47057 .14598 m
.49019 .1425 L
.50981 .14114 L
.52943 .14117 L
.54906 .14259 L
.56868 .1462 L
.58617 .15659 L
.56868 .16737 L
.54906 .17111 L
.52943 .1726 L
.50981 .17262 L
.49019 .1712 L
.47057 .16759 L
.4523 .15659 L
F
0 g
.47057 .14598 m
.49019 .1425 L
.50981 .14114 L
.52943 .14117 L
.54906 .14259 L
.56868 .1462 L
.58617 .15659 L
.56868 .16737 L
.54906 .17111 L
.52943 .1726 L
.50981 .17262 L
.49019 .1712 L
.47057 .16759 L
.4523 .15659 L
.47057 .14598 L
s
.3 g
.50981 .31285 m
.52943 .31286 L
.54795 .31358 L
.54906 .31367 L
.56868 .31669 L
.57993 .3332 L
.56868 .33826 L
.54906 .34267 L
.52943 .3445 L
.50981 .34453 L
.49019 .34279 L
.47057 .33852 L
.45853 .3332 L
.47057 .3165 L
.49019 .31361 L
.4905 .31358 L
F
0 g
.50981 .31285 m
.52943 .31286 L
.54795 .31358 L
.54906 .31367 L
.56868 .31669 L
.57993 .3332 L
.56868 .33826 L
.54906 .34267 L
.52943 .3445 L
.50981 .34453 L
.49019 .34279 L
.47057 .33852 L
.45853 .3332 L
.47057 .3165 L
.49019 .31361 L
.4905 .31358 L
.50981 .31285 L
s
.1 g
.47057 .20644 m
.49019 .20134 L
.50981 .19959 L
.52943 .19963 L
.54906 .20146 L
.56868 .2068 L
.57651 .21546 L
.56868 .22031 L
.54906 .22557 L
.52943 .22755 L
.50981 .22758 L
.49019 .22569 L
.47057 .22064 L
.46194 .21546 L
F
0 g
.47057 .20644 m
.49019 .20134 L
.50981 .19959 L
.52943 .19963 L
.54906 .20146 L
.56868 .2068 L
.57651 .21546 L
.56868 .22031 L
.54906 .22557 L
.52943 .22755 L
.50981 .22758 L
.49019 .22569 L
.47057 .22064 L
.46194 .21546 L
.47057 .20644 L
s
.9 g
.47057 .26292 m
.49019 .25785 L
.50981 .25622 L
.52943 .25625 L
.54906 .25796 L
.56868 .26331 L
.57436 .27433 L
.56868 .27739 L
.54906 .28277 L
.52943 .28483 L
.50981 .28487 L
.49019 .2829 L
.47057 .27773 L
.46409 .27433 L
F
0 g
.47057 .26292 m
.49019 .25785 L
.50981 .25622 L
.52943 .25625 L
.54906 .25796 L
.56868 .26331 L
.57436 .27433 L
.56868 .27739 L
.54906 .28277 L
.52943 .28483 L
.50981 .28487 L
.49019 .2829 L
.47057 .27773 L
.46409 .27433 L
.47057 .26292 L
s
.4 g
.49019 .09526 m
.50981 .09239 L
.52943 .09244 L
.54906 .09547 L
.55571 .09772 L
.54906 .10779 L
.52943 .11083 L
.50981 .11088 L
.49019 .10802 L
.48263 .09772 L
F
0 g
.49019 .09526 m
.50981 .09239 L
.52943 .09244 L
.54906 .09547 L
.55571 .09772 L
.54906 .10779 L
.52943 .11083 L
.50981 .11088 L
.49019 .10802 L
.48263 .09772 L
.49019 .09526 L
s
.49019 .21236 m
.50981 .20716 L
.52943 .20723 L
.54906 .21301 L
.55056 .21546 L
.54906 .21623 L
.52943 .22085 L
.50981 .22091 L
.49019 .21661 L
.48778 .21546 L
F
.49019 .21236 m
.50981 .20716 L
.52943 .20723 L
.54906 .21301 L
.55056 .21546 L
.54906 .21623 L
.52943 .22085 L
.50981 .22091 L
.49019 .21661 L
.48778 .21546 L
.49019 .21236 L
s
1 g
.50981 .26411 m
.52943 .26419 L
.54574 .27433 L
.52943 .27766 L
.50981 .27773 L
.49272 .27433 L
F
0 g
.50981 .26411 m
.52943 .26419 L
.54574 .27433 L
.52943 .27766 L
.50981 .27773 L
.49272 .27433 L
.50981 .26411 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00?Oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0dooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kS?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0hooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8b
onk^kS?ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08_ooool003gooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0=_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0<oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg03?ooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL08_ooool003Gooooo1_l0
0003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400[ooooo`Ko0000
1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100<oooool01Ol@413o
oooooooooooooooo410@03[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@03Cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@02;ooooo000o
ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000fooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000cooooo`05o`000?ooooooooooooooool0
0000>_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000=Oooool00onH
V9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000008_ooool0043ooooo00?oMgMgofIV
I_ooool00_ooool01Ol0003ooooooooooooooooo000003Kooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000003?ooooo00Go0000ooooooooooooooooo`00000jooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`03ogMgMomVIVKooooo00;o
oooo00Go0000ooooooooooooooooo`00000Rooooo`00@Oooool01Ol0003ooooooooooooooooo410@
00?ooooo00?o410@ooooooooool0=?ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@4100<oooool01Ol@413ooooooooooooooooo410@03[ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@03Oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo023ooooo000mooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg03Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg03?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0jooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0cooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02;ooooo000mooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^03Cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^03?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`03oeEEEOmVIVKo000000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0cooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02;ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo000Joooooooo0000C_l00001ooooo`00
6_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0?Ooo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool08ooo
ool1o`00007ooooo0008ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKo
oooo00?o0000ooooooooool0oooooom:ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooom:ooooo`7o
00000Oooool000Go00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41001_ooool00ol0003oooooooooo`3ooooood[ooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?ooooooB?ooool3o`00007o
oooo000:ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo0008ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Oooooooogmo
Od3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04oooooj3oOgmo3_l0002AogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04oooooi_oOgmo1Ol0000>ofIVIPCo0000SOmoOgl6ooooo`7o0000
0Oooool001[ooooo0_l00005oooooiWoOgmo0_l0000GofIVIP03o`000?moOgooOgmo08[oOgmo1Ooo
ool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooV_moOgl00ol0003oIVIVofIVIP0E
ofIVIP03o`000?moOgooOgmo08[oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CoooooVomoOgl00ol0003oIVIVofIVIP0CofIVIP03o`000?moOgooOgmo08_oOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CoooooW?moOgl5o`0000coIVIV1?l0002>ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooj7oOgmo3?l0002BogmoO`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooooomo
Ogm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooi;oOgmo:Ol00024
ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000GoooooS?moOgl6o`0002WoVIVI1_l0001nogmo
O`Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04ooooohKoOgmo1_l0000eoiVIV@Ko
0000N?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon3ogmoO`?o0000
6_nIVIT7o`00023oVIVI0ol0001eogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04oooooh;oOgmo00?o0000oiVIVOnIVIT05?nIVIT7o`0000Oo/k>c3Ol0000FoiVIV@03o`000?mo
OgooOgmo07;oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooP_moOgl0
0ol0003oVIVIoiVIV@0?oiVIV@Go00006onc/k<4o`0001;oVIVI00?o0000ogmoOomoOgl0L_moOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon1ogmoO`03o`000?nIVIWoVIVI
00ooVIVI00?o0000ok>c/onc/k<08_nc/k<00ol0003oVIVIoiVIV@0@oiVIV@03o`000?moOgooOgmo
077oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooP?moOgl00ol0003o
VIVIoiVIV@0>oiVIV@;o00009_nc/k<2o`00017oVIVI00?o0000ogmoOomoOgl0L?moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?oooomoogmoO`03o`000?nIVIWoVIVI00koVIVI
00?o0000ok>c/onc/k<0:?nc/k<00ol0003oVIVIoiVIV@0>oiVIV@03o`000?moOgooOgmo073oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooO_moOgl2o`0000ooVIVI0_l0
000Zok>c/`;o00004?nIVIT00ol0003oOgmoogmoO`1_ogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04oooooh3oOgmo00?o0000oiVIVOnIVIT03_nIVIT2o`0002Ko/k>c0_l0000A
oiVIV@03o`000?moOgooOgmo073oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CoooooPOmoOgl00ol0003oVIVIoiVIV@0?oiVIV@;o00008_nc/k<2o`0001;oVIVI00?o0000ogmo
OomoOgl0LOmoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon2ogmoO`?o
00004?nIVIT5o`0001Wo/k>c1?l0000AoiVIV@?o0000M?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?oooon5ogmoO`?o00004_nIVIT7o`0000co/k>c1_l0000BoiVIV@?o0000
MomoOgl6ooooo`7o00000Oooool001[ooooo0_l00005ooooohSoOgmo1?l0000EoiVIV@co00004onI
VIT5o`0007[oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooS?moOgl7
o`0002OoVIVI1_l0001oogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
oi?oOgmo1ol0000IoiVIV@Oo0000QOmoOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?oooonJogmoOaWo0000S?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?oooomoogmoOa_o00006OmoOglKo`00077oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CoooooNomoOgl4o`0001_oIVIV6Ol0000KofIVIP?o0000K_moOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?oooomkogmoO`03o`000?mVIVKoIVIV01CoIVIV:Ol0000F
ofIVIP03o`000?moOgooOgmo06_oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CoooooN_moOgl00ol0003oIVIVofIVIP0@ofIVIPGo00002?m<C4`Io`0000SoC4a<1_l0000AofIV
IP03o`000?moOgooOgmo06[oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
ooooNOmoOgl00ol0003oIVIVofIVIP0<ofIVIPGo00001om<C4`6o`0001Wo<c<c1_l00008oda<C0?o
00003omVIVH00ol0003oOgmoogmoO`1YogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooogWoOgmo00?o0000ofIVI_mVIVH03?mVIVH00ol0003oC4a<oda<C006oda<C0?o0000
1_lc<c<Do`0000_o<c<c0ol00007oda<C003o`000?mVIVKoIVIV00goIVIV00?o0000ogmoOomoOgl0
JOmoOgl6ooooo`7o00000Oooool000oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`00
0?oooooooooo00CoooooN?moOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<00GoC4a<
0_l00006oc<c<`?o00005?lI6AT6o`0000So<c<c0_l00006oda<C003o`000?mVIVKoIVIV00goIVIV
00?o0000ogmoOomoOgl0J?moOgl6ooooo`7o00000Oooool000oooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`06ooooo`03o`000?oooooooooo00CoooooN?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`00
0?m<C4coC4a<00GoC4a<00?o0000oc<c<olc<c<01?lc<c<2o`0000[o6ATI2ol00008oaTI6@?o0000
1_lc<c<00ol0003oC4a<oda<C005oda<C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl0
J?moOgl6ooooo`7o00000Oooool000oooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`00
0?oooooooooo00CoooooMomoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<00GoC4a<
00?o0000oc<c<olc<c<01Olc<c<00ol0003o6ATIoaTI6@06oaTI6A7o00002?lI6AT00ol0003o<c<c
oc<c<`04oc<c<`03o`000?m<C4coC4a<00GoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmo
ogmoO`1XogmoO`Kooooo0Ol00001ooooo`003oooool01Ol0003ooooooooooooooooo000000Kooooo
0ol00004ooooogOoOgmo00?o0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<oda<C005oda<C003o`00
0?lc<c?o<c<c00Go<c<c00?o0000oaTI6OlI6AT01OlI6ATEo`0000Oo6ATI00?o0000oc<c<olc<c<0
1?lc<c<00ol0003oC4a<oda<C005oda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl0
IomoOgl4ooooo`?o00000Oooool000oooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo00CoooooM_moOgl2o`0000_oIVIV0_l00006oda<C0;o00001_lc<c<00ol0003o6ATI
oaTI6@05oaTI6AKo00001olI6AT2o`0000Ko<c<c00?o0000oda<C?m<C4`01?m<C4`2o`0000_oIVIV
0_l0001YogmoO`Kooooo0Ol00001ooooo`003oooool01Ol@413ooooooooooooooooo410@00Kooooo
00?o0000ooooooooool01?oooomhogmoO`03o`000?mVIVKoIVIV00[oIVIV00?o0000oda<C?m<C4`0
1Om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?lI6AWo6ATI00Go6ATI4_l00009oaTI6@03o`00
0?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`01?m<C4`00ol0003oIVIVofIVIP0:ofIVIP03o`00
0?moOgooOgmo06WoOgmo1_ooool1o`00007ooooo000?ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1_ooool00ol0003oooooooooo`04ooooogWoOgmo00?o0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<
oda<C005oda<C003o`000?lc<c?o<c<c00Co<c<c0ol00009oaTI6@[o00002_lI6AT2o`0000Oo<c<c
00?o0000oda<C?m<C4`01?m<C4`00ol0003oIVIVofIVIP0:ofIVIP03o`000?moOgooOgmo06[oOgmo
1_ooool1o`00007ooooo000?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003ooooo
ooooo`04ooooog[oOgmo00?o0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<oda<C005oda<C0?o0000
1_lc<c<3o`0001Oo6ATI0ol00005oc<c<`Co00001_m<C4`00ol0003oIVIVofIVIP0:ofIVIP03o`00
0?moOgooOgmo06_oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooNomo
Ogl3o`0000[oIVIV0ol00007oda<C0?o00001_lc<c<Go`000003oc<c<ol0003o000000Go00001_m<
C4`4o`0000_oIVIV0_l0001^ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooogkoOgmo0ol0000:ofIVIP?o00001om<C4`<o`0000co<c<c1_l00007oda<C0Ko00003?mVIVH3
o`00073oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooPOmoOgl4o`00
00WoIVIV1Ol0000>oda<C0co00002?m<C4`5o`0000koIVIV1?l0001cogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooohGoOgmo@ol0001gogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooohgoOgmo<ol0001oogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04oooooh[oOgmo0ol0000coiVIV@?o0000O?moOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?oooomoogmoO`_o00001?nIVITao`0000CoVIVI2ol0001a
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooog[oOgmo1Ol0000<oiVI
V@?o00004_nc/k<>o`00017o/k>c0_l0000=oiVIV@Co0000KOmoOgl6ooooo`7o00000Oooool001[o
oooo0_l00005ooooogSoOgmo0_l0000?oiVIV@;o00003_nc/k<7o`0000koc<c<1_l0000=ok>c/`;o
00003onIVIT3o`0006[oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
MomoOgl00ol0003oVIVIoiVIV@0=oiVIV@;o00002Onc/k<7o`0001_oc<c<1_l00009ok>c/`;o0000
4?nIVIT00ol0003oOgmoogmoO`1WogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooogOoOgmo00?o0000oiVIVOnIVIT03OnIVIT00ol0003o/k>cok>c/`06ok>c/`;o00002?o<
c<`Io`0000Ooc<c<0ol00007ok>c/`03o`000?nIVIWoVIVI00koVIVI00?o0000ogmoOomoOgl0Iomo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooomgogmoO`03o`000?nIVIWo
VIVI00coVIVI00?o0000ok>c/onc/k<01_nc/k<00ol0003oc<c<olc<c005olc<c0?o00006OoVi^H3
o`0000Ooc<c<00?o0000ok>c/onc/k<01Onc/k<00ol0003oVIVIoiVIV@0=oiVIV@03o`000?moOgoo
Ogmo06OoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooMomoOgl00ol0
003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c00Ko/k>c00?o0000olc<c?o<c<`00oo<c<`2o`00
00_oi^KV2Ol0000;onKViP03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01Onc/k<00ol0
003oVIVIoiVIV@0=oiVIV@03o`000?moOgooOgmo06OoOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CoooooM_moOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c00Ko
/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003oi^KVonKViP09onKViP03o`000?oooooooooo00Oo
oooo00?o0000onKVi_oVi^H02?oVi^H00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00Go
/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`1WogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooogKoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>c
ok>c/`06ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000onKVi_oVi^H02?oVi^H2o`0000_ooooo
00?o0000onKVi_oVi^H02?oVi^H00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00Go/k>c
00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`1WogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooogKoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c
/`06ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000onKVi_oVi^H01ooVi^H00ol0003ooooooooo
o`0<ooooo`03o`000?oVi^Koi^KV00Ooi^KV00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c
/`05ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl0IomoOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?oooomfogmoO`;o00002onIVIT2o`0000Oo/k>c0_l00005
olc<c0;o00002?oVi^H4o`0000_ooooo0ol00008onKViP;o00001_o<c<`2o`0000Ko/k>c0_l0000;
oiVIV@;o0000JOmoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooomhogmo
O`;o00002onIVIT2o`0000Oo/k>c00?o0000olc<c?o<c<`01?o<c<`3o`0000Woi^KV2ol00009onKV
iP;o00001oo<c<`00ol0003o/k>cok>c/`04ok>c/`;o00002onIVIT2o`0006_oOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CoooooN_moOgl00ol0003oVIVIoiVIV@0:oiVIV@03
o`000?nc/k?o/k>c00Go/k>c0ol00006olc<c0?o00005ooVi^H3o`0000Koc<c<0ol00006ok>c/`03
o`000?nIVIWoVIVI00[oVIVI00?o0000ogmoOomoOgl0JomoOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?oooomkogmoO`;o00002onIVIT3o`0000Oo/k>c0ol00006olc<c1Oo0000
1_o<c<`3o`0000Oo/k>c0_l0000;oiVIV@;o0000K_moOgl6ooooo`7o00000Oooool001[ooooo0_l0
0005oooooggoOgmo0ol0000;oiVIV@?o00001onc/k<5o`0001Woc<c<1Ol00007ok>c/`?o00002_nI
VIT3o`00073oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooP?moOgl2
o`0000coVIVI1Ol00007ok>c/aWo00001onc/k<5o`0000WoVIVI1?l0001cogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04oooooh;oOgmo1_l0000;oiVIV@Wo00004Onc/k<=o`00
00_oVIVI0ol0001gogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooohSo
Ogmo1Ol0000?oiVIVA7o00004onIVIT5o`0007[oOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CoooooSOmoOglDo`0000coVIVI4ol0001oogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04oooooj7oOgmo3?l0002BogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04oooooi;oOgmo:Ol00024ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooohGoOgmo3Ol0000YofIVIPgo0000MomoOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?oooon1ogmoO`Co0000@omVIVH4o`0007?oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CoooooOomoOgl2o`0001SoIVIV6ol0000HofIVIP03o`00
0?moOgooOgmo073oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooOomo
Ogl00ol0003oIVIVofIVIP0CofIVIPCo00006om<C4`3o`0001GoIVIV00?o0000ogmoOomoOgl0L?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooomoogmoO`03o`000?mVIVKo
IVIV01?oIVIV00?o0000oda<C?m<C4`07_m<C4`00ol0003oIVIVofIVIP0CofIVIP03o`000?moOgoo
Ogmo073oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooOomoOgl00ol0
003oIVIVofIVIP0BofIVIP03o`000?m<C4coC4a<023oC4a<00?o0000ofIVI_mVIVH04_mVIVH00ol0
003oOgmoogmoO`1`ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000GoooooOomoOgl00ol0003o
IVIVofIVIP0AofIVIP03o`000?m<C4coC4a<02;oC4a<00?o0000ofIVI_mVIVH04_mVIVH00ol0003o
OgmoogmoO`1_ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04ooooogooOgmo
00?o0000ofIVI_mVIVH04?mVIVH00ol0003oC4a<oda<C00Toda<C003o`000?mVIVKoIVIV017oIVIV
00?o0000ogmoOomoOgl0KomoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
oomoogmoO`03o`000?mVIVKoIVIV00ooIVIV0_l0000Voda<C0;o00004_mVIVH00ol0003oOgmoogmo
O`1_ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooh3oOgmo00?o0000
ofIVI_mVIVH04?mVIVH2o`0002;oC4a<0_l0000CofIVIP03o`000?moOgooOgmo073oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooPOmoOgl00ol0003oIVIVofIVIP0AofIV
IPGo00006Om<C4`4o`0001CoIVIV00?o0000ogmoOomoOgl0LOmoOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?oooon2ogmoO`?o00005OmVIVH7o`0000coC4a<1_l0000EofIVIP?o
0000M?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon5ogmoO`?o0000
6OmVIVH<o`0001SoIVIV0ol0001gogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooohSoOgmo0ol0000eofIVIPGo0000N_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?oooon;ogmoO`?o0000;_mVIVH4o`0007ooOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CoooooS_moOgl6o`0001ooIVIV2Ol00023ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04oooooiCoOgmo7ol0002<ogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Ooooooo
ogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo
@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_oo
ool1o`00007ooooo0008ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKo
oooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000:ooooo`03o`00
0?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00Co
oooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003oooooooooo`02ooooo`05oa0@
4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool000[ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Ko
oooo0ol00004ooooooooOgmo@?moOgl4ooooo`?o00000Oooool000[ooooo00?o0000ooooooooool0
0_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool01?ooooooogmoOd3o
Ogmo1_ooool1o`00007ooooo000:ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@4006ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`00
2_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003o
ooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000Sooooo00?oEEEEofIVI_l00000
1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool01?ooooooogmoOd3o
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooooomo
Ogm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6
ooooo`7o00000Oooool001[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[o
oooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooo
ogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo
0_l00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooooomo
Ogm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000GooooooomoOgm0ogmo
O`Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo
@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000Gooooooomo
Ogm0ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
ooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3o
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo
0Ol00001ooooo`001oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`00
0?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`001oooool01OnHV9So8B4Qonk^
k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00Co
oooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@
4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool000Wooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000Ko
oooo0ol00004ooooooooOgmo@?moOgl4ooooo`?o00000Oooool000[ooooo00?oMgMgofIVI_ooool0
0_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool01?ooooooogmoOd3o
Ogmo1_ooool1o`00007ooooo000;ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413o
ooooooooo`04ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`00
1oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06oooo
o`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`001oooool01OnHV9So
410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooo
oooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
ooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3o
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo0_l00005ooooooooOgmo
@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooo
ogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo0_l00005oooo
ooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3o
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooooomo
Ogm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo0_l0
0005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool01?oooooo
ogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo
@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[o
oooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool0
1?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooooomo
Ogm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
ooooOgmo@?moOgl6ooooo`7o00000Oooool000Oooooo00GoV9RHoa0@4?l0003o<S8bolc<c003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6
ooooo`7o00000Oooool000Oooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Ooo
ool000_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o
0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000:ooooo`03ojVYZOl@413o
oooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`?o00001?ooooooogmoOd3oOgmo1?oo
ool3o`00007ooooo0009ooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool0
0onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003ooooooooo
o`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000Oooooo00Go410@oiRHV?oooooo^[Zjo`00
0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`04ooooooooOgmo
@?moOgl6ooooo`7o00000Oooool000Oooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo
@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_oo
ool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007ooooo000Joooo
o`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooooomo
Ogm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
ooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3o
Ogmo1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007ooooo
000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo
@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooo
ogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00
007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
ooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3o
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Ooo
ool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooo
ogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo
0009ooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000[ooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo0007ooooo`Go00000oooool01Ol@413ooooooooooooooooo410@
00Kooooo0ol00004ooooooooOgmo@?moOgl4ooooo`?o00000Oooool000Oooooo00CoA4A4omgMgOoo
oooo00001?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0oooooom:
ooooo`7o00000Oooool000Oooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooo
oooo000000Kooooo00?o0000ooooooooool0oooooom:ooooo`7o00000Oooool000Sooooo00?oMgMg
olc<c?l000001?ooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool0oooo
oom:ooooo`7o00000Oooool000Sooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Kooooo00?o0000ooooooooool0oooooom:ooooo`7o00000Oooool000Wooooo00?oMgMg
o`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0?Ooo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo02?ooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo0Ol00001ooooo`006_ooooooo`00
04ko00000Oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-30.1723, -14.304, 0.195672, \
0.195672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0192308 0.211538 0.0192308 [
[.11538 -0.0125 -9 -9 ]
[.11538 -0.0125 9 0 ]
[.30769 -0.0125 -9 -9 ]
[.30769 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69231 -0.0125 -6 -9 ]
[.69231 -0.0125 6 0 ]
[.88462 -0.0125 -6 -9 ]
[.88462 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -18 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .21154 -6 -4.5 ]
[-0.0125 .21154 0 4.5 ]
[-0.0125 .40385 -12 -4.5 ]
[-0.0125 .40385 0 4.5 ]
[-0.0125 .59615 -12 -4.5 ]
[-0.0125 .59615 0 4.5 ]
[-0.0125 .78846 -12 -4.5 ]
[-0.0125 .78846 0 4.5 ]
[-0.0125 .98077 -12 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11538 0 m
.11538 .00625 L
s
[(-20)] .11538 -0.0125 0 1 Mshowa
.30769 0 m
.30769 .00625 L
s
[(-10)] .30769 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69231 0 m
.69231 .00625 L
s
[(10)] .69231 -0.0125 0 1 Mshowa
.88462 0 m
.88462 .00625 L
s
[(20)] .88462 -0.0125 0 1 Mshowa
.125 Mabswid
.15385 0 m
.15385 .00375 L
s
.19231 0 m
.19231 .00375 L
s
.23077 0 m
.23077 .00375 L
s
.26923 0 m
.26923 .00375 L
s
.34615 0 m
.34615 .00375 L
s
.38462 0 m
.38462 .00375 L
s
.42308 0 m
.42308 .00375 L
s
.46154 0 m
.46154 .00375 L
s
.53846 0 m
.53846 .00375 L
s
.57692 0 m
.57692 .00375 L
s
.61538 0 m
.61538 .00375 L
s
.65385 0 m
.65385 .00375 L
s
.73077 0 m
.73077 .00375 L
s
.76923 0 m
.76923 .00375 L
s
.80769 0 m
.80769 .00375 L
s
.84615 0 m
.84615 .00375 L
s
.07692 0 m
.07692 .00375 L
s
.03846 0 m
.03846 .00375 L
s
.92308 0 m
.92308 .00375 L
s
.96154 0 m
.96154 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(-10)] -0.0125 .01923 1 0 Mshowa
0 .21154 m
.00625 .21154 L
s
[(0)] -0.0125 .21154 1 0 Mshowa
0 .40385 m
.00625 .40385 L
s
[(10)] -0.0125 .40385 1 0 Mshowa
0 .59615 m
.00625 .59615 L
s
[(20)] -0.0125 .59615 1 0 Mshowa
0 .78846 m
.00625 .78846 L
s
[(30)] -0.0125 .78846 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(40)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .05769 m
.00375 .05769 L
s
0 .09615 m
.00375 .09615 L
s
0 .13462 m
.00375 .13462 L
s
0 .17308 m
.00375 .17308 L
s
0 .25 m
.00375 .25 L
s
0 .28846 m
.00375 .28846 L
s
0 .32692 m
.00375 .32692 L
s
0 .36538 m
.00375 .36538 L
s
0 .44231 m
.00375 .44231 L
s
0 .48077 m
.00375 .48077 L
s
0 .51923 m
.00375 .51923 L
s
0 .55769 m
.00375 .55769 L
s
0 .63462 m
.00375 .63462 L
s
0 .67308 m
.00375 .67308 L
s
0 .71154 m
.00375 .71154 L
s
0 .75 m
.00375 .75 L
s
0 .82692 m
.00375 .82692 L
s
0 .86538 m
.00375 .86538 L
s
0 .90385 m
.00375 .90385 L
s
0 .94231 m
.00375 .94231 L
s
.25 Mabswid
0 0 m
0 1 L
s
.11538 .99375 m
.11538 1 L
s
.30769 .99375 m
.30769 1 L
s
.5 .99375 m
.5 1 L
s
.69231 .99375 m
.69231 1 L
s
.88462 .99375 m
.88462 1 L
s
.125 Mabswid
.15385 .99625 m
.15385 1 L
s
.19231 .99625 m
.19231 1 L
s
.23077 .99625 m
.23077 1 L
s
.26923 .99625 m
.26923 1 L
s
.34615 .99625 m
.34615 1 L
s
.38462 .99625 m
.38462 1 L
s
.42308 .99625 m
.42308 1 L
s
.46154 .99625 m
.46154 1 L
s
.53846 .99625 m
.53846 1 L
s
.57692 .99625 m
.57692 1 L
s
.61538 .99625 m
.61538 1 L
s
.65385 .99625 m
.65385 1 L
s
.73077 .99625 m
.73077 1 L
s
.76923 .99625 m
.76923 1 L
s
.80769 .99625 m
.80769 1 L
s
.84615 .99625 m
.84615 1 L
s
.07692 .99625 m
.07692 1 L
s
.03846 .99625 m
.03846 1 L
s
.92308 .99625 m
.92308 1 L
s
.96154 .99625 m
.96154 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .21154 m
1 .21154 L
s
.99375 .40385 m
1 .40385 L
s
.99375 .59615 m
1 .59615 L
s
.99375 .78846 m
1 .78846 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .05769 m
1 .05769 L
s
.99625 .09615 m
1 .09615 L
s
.99625 .13462 m
1 .13462 L
s
.99625 .17308 m
1 .17308 L
s
.99625 .25 m
1 .25 L
s
.99625 .28846 m
1 .28846 L
s
.99625 .32692 m
1 .32692 L
s
.99625 .36538 m
1 .36538 L
s
.99625 .44231 m
1 .44231 L
s
.99625 .48077 m
1 .48077 L
s
.99625 .51923 m
1 .51923 L
s
.99625 .55769 m
1 .55769 L
s
.99625 .63462 m
1 .63462 L
s
.99625 .67308 m
1 .67308 L
s
.99625 .71154 m
1 .71154 L
s
.99625 .75 m
1 .75 L
s
.99625 .82692 m
1 .82692 L
s
.99625 .86538 m
1 .86538 L
s
.99625 .90385 m
1 .90385 L
s
.99625 .94231 m
1 .94231 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.4 g
.43132 .21466 m
.45094 .21413 L
.47057 .21414 L
.49019 .2143 L
.50981 .21445 L
.52943 .21451 L
.54906 .21444 L
.56868 .21429 L
.5883 .21413 L
.60793 .21415 L
.62755 .21472 L
.63785 .21546 L
.64717 .21664 L
.6668 .22237 L
.67796 .23509 L
.6668 .25063 L
.65961 .25471 L
.64717 .2615 L
.62755 .26854 L
.60793 .27364 L
.5883 .26852 L
.56868 .26974 L
.54906 .27044 L
.52943 .27067 L
.50981 .27047 L
.49019 .2698 L
.47057 .26861 L
.45094 .26678 L
.43132 .26889 L
.4117 .26201 L
.39802 .25471 L
.39207 .25144 L
.37969 .23509 L
.39207 .22179 L
.4117 .21646 L
.41983 .21546 L
F
0 g
.43132 .21466 m
.45094 .21413 L
.47057 .21414 L
.49019 .2143 L
.50981 .21445 L
.52943 .21451 L
.54906 .21444 L
.56868 .21429 L
.5883 .21413 L
.60793 .21415 L
.62755 .21472 L
.63785 .21546 L
.64717 .21664 L
.6668 .22237 L
.67796 .23509 L
.6668 .25063 L
.65961 .25471 L
.64717 .2615 L
.62755 .26854 L
.60793 .27364 L
.5883 .26852 L
.56868 .26974 L
.54906 .27044 L
.52943 .27067 L
.50981 .27047 L
.49019 .2698 L
.47057 .26861 L
.45094 .26678 L
.43132 .26889 L
.4117 .26201 L
.39802 .25471 L
.39207 .25144 L
.37969 .23509 L
.39207 .22179 L
.4117 .21646 L
.41983 .21546 L
.43132 .21466 L
s
.6 g
.43132 .27411 m
.45094 .27374 L
.47057 .2739 L
.49019 .27415 L
.50775 .27433 L
.50981 .27434 L
.52943 .27442 L
.54906 .27433 L
.54941 .27433 L
.56868 .27414 L
.5883 .27388 L
.60793 .27425 L
.62755 .27413 L
.63546 .27433 L
.64717 .27561 L
.6668 .28167 L
.67477 .29396 L
.6668 .30546 L
.65358 .31358 L
.64717 .31608 L
.62755 .32192 L
.60793 .32616 L
.5883 .32898 L
.56868 .33068 L
.54906 .33155 L
.52943 .33182 L
.50981 .33158 L
.49019 .33075 L
.47057 .32911 L
.45094 .32636 L
.43132 .32222 L
.4117 .31648 L
.40411 .31358 L
.39207 .30642 L
.38291 .29396 L
.39207 .28099 L
.4117 .27544 L
.42203 .27433 L
F
0 g
.43132 .27411 m
.45094 .27374 L
.47057 .2739 L
.49019 .27415 L
.50775 .27433 L
.50981 .27434 L
.52943 .27442 L
.54906 .27433 L
.54941 .27433 L
.56868 .27414 L
.5883 .27388 L
.60793 .27425 L
.62755 .27413 L
.63546 .27433 L
.64717 .27561 L
.6668 .28167 L
.67477 .29396 L
.6668 .30546 L
.65358 .31358 L
.64717 .31608 L
.62755 .32192 L
.60793 .32616 L
.5883 .32898 L
.56868 .33068 L
.54906 .33155 L
.52943 .33182 L
.50981 .33158 L
.49019 .33075 L
.47057 .32911 L
.45094 .32636 L
.43132 .32222 L
.4117 .31648 L
.40411 .31358 L
.39207 .30642 L
.38291 .29396 L
.39207 .28099 L
.4117 .27544 L
.42203 .27433 L
.43132 .27411 L
s
.6 g
.4117 .1687 m
.43132 .16285 L
.45094 .16035 L
.47057 .15921 L
.49019 .1587 L
.50981 .15849 L
.52943 .15844 L
.54906 .1585 L
.56868 .15872 L
.5883 .15925 L
.60793 .16046 L
.62755 .16308 L
.64717 .16928 L
.65586 .17622 L
.64717 .1952 L
.64609 .19584 L
.62755 .20162 L
.60793 .20514 L
.5883 .20738 L
.56868 .20879 L
.54906 .20958 L
.52943 .20985 L
.50981 .20961 L
.49019 .20885 L
.47057 .20748 L
.45094 .20531 L
.43132 .20188 L
.4117 .1959 L
.41157 .19584 L
.40183 .17622 L
F
0 g
.4117 .1687 m
.43132 .16285 L
.45094 .16035 L
.47057 .15921 L
.49019 .1587 L
.50981 .15849 L
.52943 .15844 L
.54906 .1585 L
.56868 .15872 L
.5883 .15925 L
.60793 .16046 L
.62755 .16308 L
.64717 .16928 L
.65586 .17622 L
.64717 .1952 L
.64609 .19584 L
.62755 .20162 L
.60793 .20514 L
.5883 .20738 L
.56868 .20879 L
.54906 .20958 L
.52943 .20985 L
.50981 .20961 L
.49019 .20885 L
.47057 .20748 L
.45094 .20531 L
.43132 .20188 L
.4117 .1959 L
.41157 .19584 L
.40183 .17622 L
.4117 .1687 L
s
.4 g
.43132 .34277 m
.45094 .33973 L
.47057 .33873 L
.49019 .33842 L
.50981 .33835 L
.52943 .33835 L
.54906 .33836 L
.56868 .33843 L
.5883 .33877 L
.60793 .33983 L
.62755 .3431 L
.64124 .35283 L
.62755 .36768 L
.61727 .37245 L
.60793 .3755 L
.5883 .38022 L
.56868 .38338 L
.54906 .38517 L
.52943 .38577 L
.50981 .38524 L
.49019 .38352 L
.47057 .38045 L
.45094 .37583 L
.44042 .37245 L
.43132 .36832 L
.41644 .35283 L
F
0 g
.43132 .34277 m
.45094 .33973 L
.47057 .33873 L
.49019 .33842 L
.50981 .33835 L
.52943 .33835 L
.54906 .33836 L
.56868 .33843 L
.5883 .33877 L
.60793 .33983 L
.62755 .3431 L
.64124 .35283 L
.62755 .36768 L
.61727 .37245 L
.60793 .3755 L
.5883 .38022 L
.56868 .38338 L
.54906 .38517 L
.52943 .38577 L
.50981 .38524 L
.49019 .38352 L
.47057 .38045 L
.45094 .37583 L
.44042 .37245 L
.43132 .36832 L
.41644 .35283 L
.43132 .34277 L
s
.3 g
.43132 .22756 m
.45094 .22245 L
.47057 .22029 L
.49019 .2193 L
.50981 .21888 L
.52943 .21876 L
.54906 .21889 L
.56868 .21934 L
.5883 .22037 L
.60793 .22264 L
.62755 .22807 L
.6371 .23509 L
.62755 .25161 L
.62211 .25471 L
.60793 .26586 L
.5883 .26311 L
.56868 .26535 L
.54906 .26655 L
.52943 .26695 L
.50981 .2666 L
.49019 .26544 L
.47057 .26328 L
.45094 .25958 L
.43557 .25471 L
.43132 .25237 L
.42058 .23509 L
F
0 g
.43132 .22756 m
.45094 .22245 L
.47057 .22029 L
.49019 .2193 L
.50981 .21888 L
.52943 .21876 L
.54906 .21889 L
.56868 .21934 L
.5883 .22037 L
.60793 .22264 L
.62755 .22807 L
.6371 .23509 L
.62755 .25161 L
.62211 .25471 L
.60793 .26586 L
.5883 .26311 L
.56868 .26535 L
.54906 .26655 L
.52943 .26695 L
.50981 .2666 L
.49019 .26544 L
.47057 .26328 L
.45094 .25958 L
.43557 .25471 L
.43132 .25237 L
.42058 .23509 L
.43132 .22756 L
s
.7 g
.43132 .28888 m
.45094 .28238 L
.47057 .28008 L
.49019 .2791 L
.50981 .27871 L
.52943 .27861 L
.54906 .27872 L
.56868 .27914 L
.5883 .28016 L
.60793 .2826 L
.62755 .28967 L
.6316 .29396 L
.62755 .30308 L
.61082 .31358 L
.60793 .31512 L
.5883 .32232 L
.56868 .32631 L
.54906 .3284 L
.52943 .32908 L
.50981 .32848 L
.49019 .32649 L
.47057 .32263 L
.45094 .3157 L
.44688 .31358 L
.43132 .30425 L
.4261 .29396 L
F
0 g
.43132 .28888 m
.45094 .28238 L
.47057 .28008 L
.49019 .2791 L
.50981 .27871 L
.52943 .27861 L
.54906 .27872 L
.56868 .27914 L
.5883 .28016 L
.60793 .2826 L
.62755 .28967 L
.6316 .29396 L
.62755 .30308 L
.61082 .31358 L
.60793 .31512 L
.5883 .32232 L
.56868 .32631 L
.54906 .3284 L
.52943 .32908 L
.50981 .32848 L
.49019 .32649 L
.47057 .32263 L
.45094 .3157 L
.44688 .31358 L
.43132 .30425 L
.4261 .29396 L
.43132 .28888 L
s
.2 g
.45094 .23277 m
.47057 .22683 L
.49019 .22439 L
.50981 .22331 L
.52943 .22301 L
.54906 .22335 L
.56868 .22449 L
.5883 .22705 L
.60793 .23341 L
.61045 .23509 L
.60793 .24767 L
.59656 .25471 L
.5883 .25709 L
.56868 .26069 L
.54906 .26251 L
.52943 .26309 L
.50981 .26257 L
.49019 .26084 L
.47057 .25738 L
.46113 .25471 L
.45094 .24873 L
.44724 .23509 L
F
0 g
.45094 .23277 m
.47057 .22683 L
.49019 .22439 L
.50981 .22331 L
.52943 .22301 L
.54906 .22335 L
.56868 .22449 L
.5883 .22705 L
.60793 .23341 L
.61045 .23509 L
.60793 .24767 L
.59656 .25471 L
.5883 .25709 L
.56868 .26069 L
.54906 .26251 L
.52943 .26309 L
.50981 .26257 L
.49019 .26084 L
.47057 .25738 L
.46113 .25471 L
.45094 .24873 L
.44724 .23509 L
.45094 .23277 L
s
.7 g
.47057 .17137 m
.49019 .16837 L
.50981 .16702 L
.52943 .16664 L
.54906 .16707 L
.56868 .1685 L
.5883 .17163 L
.60217 .17622 L
.6008 .19584 L
.5883 .19937 L
.56868 .20258 L
.54906 .20421 L
.52943 .20473 L
.50981 .20427 L
.49019 .20272 L
.47057 .19963 L
.45689 .19584 L
.45553 .17622 L
F
0 g
.47057 .17137 m
.49019 .16837 L
.50981 .16702 L
.52943 .16664 L
.54906 .16707 L
.56868 .1685 L
.5883 .17163 L
.60217 .17622 L
.6008 .19584 L
.5883 .19937 L
.56868 .20258 L
.54906 .20421 L
.52943 .20473 L
.50981 .20427 L
.49019 .20272 L
.47057 .19963 L
.45689 .19584 L
.45553 .17622 L
.47057 .17137 L
s
.8 g
.47057 .28779 m
.49019 .28478 L
.50981 .28355 L
.52943 .28322 L
.54906 .28359 L
.56868 .28489 L
.5883 .28807 L
.60213 .29396 L
.5883 .30994 L
.57828 .31358 L
.56868 .31744 L
.54906 .32217 L
.52943 .32364 L
.50981 .32234 L
.49019 .31784 L
.47938 .31358 L
.47057 .31044 L
.45556 .29396 L
F
0 g
.47057 .28779 m
.49019 .28478 L
.50981 .28355 L
.52943 .28322 L
.54906 .28359 L
.56868 .28489 L
.5883 .28807 L
.60213 .29396 L
.5883 .30994 L
.57828 .31358 L
.56868 .31744 L
.54906 .32217 L
.52943 .32364 L
.50981 .32234 L
.49019 .31784 L
.47938 .31358 L
.47057 .31044 L
.45556 .29396 L
.47057 .28779 L
s
.4 g
.49019 .11575 m
.50981 .11451 L
.52943 .11429 L
.54906 .11455 L
.56868 .1159 L
.57675 .11735 L
.5883 .12023 L
.59995 .13697 L
.5883 .14075 L
.56868 .14421 L
.54906 .14591 L
.52943 .14644 L
.50981 .14597 L
.49019 .14435 L
.47057 .14103 L
.45773 .13697 L
.47057 .11986 L
.4809 .11735 L
F
0 g
.49019 .11575 m
.50981 .11451 L
.52943 .11429 L
.54906 .11455 L
.56868 .1159 L
.57675 .11735 L
.5883 .12023 L
.59995 .13697 L
.5883 .14075 L
.56868 .14421 L
.54906 .14591 L
.52943 .14644 L
.50981 .14597 L
.49019 .14435 L
.47057 .14103 L
.45773 .13697 L
.47057 .11986 L
.4809 .11735 L
.49019 .11575 L
s
.1 g
.49019 .23018 m
.50981 .22814 L
.52943 .22759 L
.54906 .22821 L
.56868 .23037 L
.58602 .23509 L
.5715 .25471 L
.56868 .2553 L
.54906 .25804 L
.52943 .25888 L
.50981 .25814 L
.49019 .25553 L
.48613 .25471 L
.47172 .23509 L
F
0 g
.49019 .23018 m
.50981 .22814 L
.52943 .22759 L
.54906 .22821 L
.56868 .23037 L
.58602 .23509 L
.5715 .25471 L
.56868 .2553 L
.54906 .25804 L
.52943 .25888 L
.50981 .25814 L
.49019 .25553 L
.48613 .25471 L
.47172 .23509 L
.49019 .23018 L
s
.9 g
.49019 .29252 m
.50981 .28948 L
.52943 .28874 L
.54906 .28958 L
.56868 .29284 L
.57224 .29396 L
.56868 .30449 L
.54906 .31047 L
.52943 .312 L
.50981 .31065 L
.49019 .30512 L
.48538 .29396 L
F
0 g
.49019 .29252 m
.50981 .28948 L
.52943 .28874 L
.54906 .28958 L
.56868 .29284 L
.57224 .29396 L
.56868 .30449 L
.54906 .31047 L
.52943 .312 L
.50981 .31065 L
.49019 .30512 L
.48538 .29396 L
.49019 .29252 L
s
.8 g
.52943 .17575 m
.54189 .17622 L
.54906 .17698 L
.56355 .19584 L
.54906 .19749 L
.52943 .19849 L
.50981 .19761 L
.49367 .19584 L
.50981 .17682 L
.51579 .17622 L
F
0 g
.52943 .17575 m
.54189 .17622 L
.54906 .17698 L
.56355 .19584 L
.54906 .19749 L
.52943 .19849 L
.50981 .19761 L
.49367 .19584 L
.50981 .17682 L
.51579 .17622 L
.52943 .17575 L
s
.3 g
.50981 .35098 m
.52943 .35008 L
.54906 .35111 L
.56255 .35283 L
.54906 .36391 L
.52943 .3659 L
.50981 .36416 L
.4945 .35283 L
F
0 g
.50981 .35098 m
.52943 .35008 L
.54906 .35111 L
.56255 .35283 L
.54906 .36391 L
.52943 .3659 L
.50981 .36416 L
.4945 .35283 L
.50981 .35098 L
s
.50981 .23405 m
.52943 .23302 L
.54906 .2342 L
.55725 .23509 L
.54906 .25159 L
.52943 .25352 L
.50981 .25183 L
.49954 .23509 L
F
.50981 .23405 m
.52943 .23302 L
.54906 .2342 L
.55725 .23509 L
.54906 .25159 L
.52943 .25352 L
.50981 .25183 L
.49954 .23509 L
.50981 .23405 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00?Oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0dooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kS?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0hooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8b
onk^kS?ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08_ooool003gooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0=_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0<oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg03?ooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL08_ooool003Gooooo1_l0
0003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400[ooooo`Ko0000
1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100<oooool01Ol@413o
oooooooooooooooo410@03[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@03Cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@02;ooooo000o
ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000fooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000cooooo`05o`000?ooooooooooooooool0
0000>_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000=Oooool00onH
V9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000008_ooool0043ooooo00?oMgMgofIV
I_ooool00_ooool01Ol0003ooooooooooooooooo000003Kooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000003?ooooo00Go0000ooooooooooooooooo`00000jooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`03ogMgMomVIVKooooo00;o
oooo00Go0000ooooooooooooooooo`00000Rooooo`00@Oooool01Ol0003ooooooooooooooooo410@
00?ooooo00?o410@ooooooooool0=?ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@4100<oooool01Ol@413ooooooooooooooooo410@03[ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@03Oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo023ooooo000mooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg03Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg03?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0jooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0cooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02;ooooo000mooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^03Cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^03?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`03oeEEEOmVIVKo000000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0cooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02;ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo000Joooooooo0000C_l00001ooooo`00
6_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0?Ooo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool08ooo
ool1o`00007ooooo0008ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKo
oooo00?o0000ooooooooool0oooooom:ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooom:ooooo`7o
00000Oooool000Go00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41001_ooool00ol0003oooooooooo`3ooooood[ooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?ooooooB?ooool3o`00007o
oooo000:ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo0008ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Oooooooogmo
Od3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Ooo
ooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?oooonKogmoOako0000Q_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?oooonEogmoO`Ko00007_mVIVH3o`0008?oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CoooooUOmoOgl00ol0003oIVIVofIVIP0TofIVIP;o0000POmoOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?oooonDogmoO`03o`000?mVIVKoIVIV02KoIVIV
00?o0000ogmoOomoOgl0OomoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
oonCogmoO`03o`000?mVIVKoIVIV02SoIVIV00?o0000ogmoOomoOgl0O_moOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?oooonCogmoO`03o`000?mVIVKoIVIV02WoIVIV00?o0000
ogmoOomoOgl0OOmoOgl6ooooo`7o00000Oooool001[ooooo0_l00005oooooi;oOgmo00?o0000ofIV
I_mVIVH0:_mVIVH00ol0003oOgmoogmoO`1mogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003o
ooooooooo`04oooooi7oOgmo0ol0000[ofIVIP;o0000O_moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?oooonDogmoO`Co00008omVIVH4o`00083oOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CoooooV?moOgl3o`0001goIVIV0ol00024ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04oooooi_oOgmo7Ol00027ogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04oooooi;oOgmo:Ol00024ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooohcoOgmo1_l0000YoiVIV@go0000MomoOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?oooon7ogmoO`Go0000??nIVIT5o`0007;oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CoooooQ?moOgl3o`0001WoVIVI5?l0000IoiVIV@?o0000KomoOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?oooon1ogmoO`?o00005OnIVIT7o`0001Co/k>c
1ol0000EoiVIV@;o0000KOmoOgl6ooooo`7o00000Oooool001[ooooo0_l00005oooooh3oOgmo00?o
0000oiVIVOnIVIT04?nIVIT6o`0002;o/k>c1Ol0000BoiVIV@03o`000?moOgooOgmo06[oOgmo1Ooo
ool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooOomoOgl00ol0003oVIVIoiVIV@0>
oiVIV@?o00004?nc/k<>o`0000oo/k>c0_l0000AoiVIV@03o`000?moOgooOgmo06WoOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooOomoOgl00ol0003oVIVIoiVIV@0>oiVI
V@03o`000?nc/k?o/k>c013o/k>c00?o0000olc<c?o<c<`02_o<c<`00ol0003o/k>cok>c/`0>ok>c
/`03o`000?nIVIWoVIVI00ooVIVI00?o0000ogmoOomoOgl0JOmoOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?oooon0ogmoO`03o`000?nIVIWoVIVI00goVIVI00?o0000ok>c/onc
/k<03onc/k<00ol0003oc<c<olc<c00<olc<c003o`000?nc/k?o/k>c00go/k>c00?o0000oiVIVOnI
VIT03_nIVIT00ol0003oOgmoogmoO`1ZogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04oooooh3oOgmo00?o0000oiVIVOnIVIT03OnIVIT00ol0003o/k>cok>c/`0>ok>c/`03o`00
0?o<c<coc<c<00goc<c<00?o0000ok>c/onc/k<03Onc/k<00ol0003oVIVIoiVIV@0>oiVIV@03o`00
0?moOgooOgmo06[oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooPOmo
Ogl00ol0003oVIVIoiVIV@0=oiVIV@03o`000?nc/k?o/k>c00co/k>c00?o0000olc<c?o<c<`03oo<
c<`00ol0003o/k>cok>c/`0<ok>c/`03o`000?nIVIWoVIVI00goVIVI00?o0000ogmoOomoOgl0Jomo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon1ogmoO`03o`000?nIVIWo
VIVI00goVIVI00?o0000ok>c/onc/k<02onc/k<00ol0003oc<c<olc<c00Aolc<c003o`000?nc/k?o
/k>c00_o/k>c00?o0000oiVIVOnIVIT03OnIVIT00ol0003oOgmoogmoO`1[ogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04oooooh7oOgmo00?o0000oiVIVOnIVIT03OnIVIT00ol0
003o/k>cok>c/`0:ok>c/`03o`000?o<c<coc<c<01;oc<c<00?o0000ok>c/onc/k<02onc/k<00ol0
003oVIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo06coOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CoooooP_moOgl3o`0000coVIVI0ol00009ok>c/`[o00001_o<c<`8o`0000[o
/k>c0ol0000=oiVIV@;o0000K_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?oooon5ogmoO`?o00003?nIVIT6o`0000go/k>c1_l0000=ok>c/`Go00003OnIVIT3o`00073oOgmo
1_ooool1o`00007ooooo000?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003ooooo
ooooo`04ooooohSoOgmo1Ol0000=oiVIV@go00001_nc/k<=o`0000goVIVI1Ol0001cogmoO`Kooooo
0Ol00001ooooo`003oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0
1?oooon=ogmoO`Ko00005?nIVIT6o`0000goVIVI3Ol0001hogmoO`Kooooo0Ol00001ooooo`003ooo
ool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool01?oooonCogmoObOo0000
QOmoOgl6ooooo`7o00000Oooool000oooooo00Go0000ooooooooooooooooo`000006ooooo`?o0000
1?ooooooogmoOd3oOgmo1?ooool3o`00007ooooo000?ooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`04ooooohCoOgmoC?l0001_ogmoO`Kooooo0Ol00001ooooo`003ooo
ool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool01?oooomoogmoO`Go0000
5OmVIVHRo`0001GoIVIV1Ol0001ZogmoO`Kooooo0Ol00001ooooo`003oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Kooooo00?o0000ooooooooool01?oooomkogmoO`Co00004omVIVH7o`0002;oC4a<
1_l0000DofIVIP?o0000IomoOgl6ooooo`7o00000Oooool000oooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP06ooooo`03o`000?oooooooooo00CoooooNomoOgl00ol0003oIVIVofIVIP0>ofIVIPKo0000
1om<C4`Ro`0000KoC4a<1ol0000?ofIVIP03o`000?moOgooOgmo06GoOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CoooooN_moOgl00ol0003oIVIVofIVIP0;ofIVIPCo00002?m<
C4`5o`0000Oo<c<c5?l00007oc<c<`Go00002?m<C4`3o`0000goIVIV00?o0000ogmoOomoOgl0I?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooomiogmoO`03o`000?mVIVKo
IVIV00_oIVIV00?o0000oda<C?m<C4`01om<C4`3o`0000Oo<c<c1Ol0000DoaTI6@Go00001olc<c<3
o`0000SoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`1SogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooogSoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0
003oC4a<oda<C006oda<C0;o00001olc<c<3o`0000Ko6ATI4Ol00007oaTI6@?o00001olc<c<00ol0
003oC4a<oda<C006oda<C003o`000?mVIVKoIVIV00[oIVIV00?o0000ogmoOomoOgl0HomoOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooomgogmoO`03o`000?mVIVKoIVIV00_o
IVIV00?o0000oda<C?m<C4`01_m<C4`00ol0003o<c<coc<c<`05oc<c<`;o00001olI6ATDo`0000Wo
6ATI00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C006oda<C003o`000?mVIVKoIVIV00[o
IVIV00?o0000ogmoOomoOgl0H_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?oooomgogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`01_m<C4`00ol0003o<c<c
oc<c<`05oc<c<`03o`000?lI6AWo6ATI00Ko6ATI5?l00009oaTI6@03o`000?lc<c?o<c<c00Go<c<c
00?o0000oda<C?m<C4`01_m<C4`00ol0003oIVIVofIVIP0:ofIVIP03o`000?moOgooOgmo06;oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooN?moOgl00ol0003oIVIVofIV
IP0;ofIVIP03o`000?m<C4coC4a<00GoC4a<00?o0000oc<c<olc<c<01_lc<c<00ol0003o6ATIoaTI
6@06oaTI6A;o00002OlI6AT00ol0003o<c<coc<c<`06oc<c<`03o`000?m<C4coC4a<00GoC4a<00?o
0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`1SogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooogWoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C005
oda<C003o`000?lc<c?o<c<c00Ko<c<c00?o0000oaTI6OlI6AT01_lI6ATAo`0000So6ATI00?o0000
oc<c<olc<c<01_lc<c<00ol0003oC4a<oda<C005oda<C003o`000?mVIVKoIVIV00[oIVIV00?o0000
ogmoOomoOgl0I?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooomjogmo
O`03o`000?mVIVKoIVIV00[oIVIV00?o0000oda<C?m<C4`01Om<C4`2o`0000So<c<c00?o0000oaTI
6OlI6AT01_lI6AT@o`0000Oo6ATI00?o0000oc<c<olc<c<01_lc<c<2o`0000OoC4a<00?o0000ofIV
I_mVIVH02_mVIVH00ol0003oOgmoogmoO`1TogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000Go
ooooNomoOgl2o`0000_oIVIV0_l00007oda<C003o`000?lc<c?o<c<c00Ko<c<c00?o0000oaTI6OlI
6AT01_lI6AT>o`0000Oo6ATI00?o0000oc<c<olc<c<01Olc<c<2o`0000OoC4a<0_l0000;ofIVIP;o
0000IomoOgl5ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool01?oooommogmoO`;o0000
2omVIVH2o`0000KoC4a<0ol00006oc<c<`Ko00001_lI6AT6o`0000Ko6ATI1Ol00006oc<c<`;o0000
1om<C4`2o`0000[oIVIV0ol0001YogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooogooOgmo0_l0000;ofIVIP?o00001_m<C4`5o`0000Oo<c<c1_l00006oaTI6@Ko00001olc
<c<4o`0000SoC4a<00?o0000ofIVI_mVIVH02?mVIVH2o`0006coOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CoooooPOmoOgl00ol0003oIVIVofIVIP0;ofIVIPCo00001om<C4`7
o`0000Ko<c<c1_l00006oc<c<`Oo00002om<C4`00ol0003oIVIVofIVIP07ofIVIP;o0000K_moOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon2ogmoO`?o00003_mVIVH7o`00
00OoC4a<4_l00007oda<C0Oo00000om<C4`00ol0003oIVIVofIVIP06ofIVIP;o0000L?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon5ogmoO`?o00001?mVIVH7o`0000Oo
IVIV8?l00007ofIVIP?o00001omVIVH2o`0007;oOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CoooooR?moOgl4o`0000OoOgmo5?l00006ofIVIQ?o00002?mVIVH3o`0007CoOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooYomoOgl6o`0001?oOgmo0ol0
0002ofIVIP?o0000MomoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon0
ogmoOe?o0000K?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooommogmo
O`?o00006OnIVITRo`0001SoVIVI0ol0001YogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooog_oOgmo0_l0000AoiVIV@_o00008_nc/k<:o`00017oVIVI0_l0001WogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooog_oOgmo00?o0000oiVIVOnIVIT0
3OnIVIT3o`0000_o/k>c8_l0000:ok>c/`?o00003onIVIT00ol0003oOgmoogmoO`1UogmoO`Kooooo
0Ol00001ooooo`006_ooool2o`0000GoooooN_moOgl00ol0003oVIVIoiVIV@0<oiVIV@;o00002Onc
/k<5o`0002;oc<c<1?l00009ok>c/`;o00003_nIVIT00ol0003oOgmoogmoO`1TogmoO`Gooooo0_l0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooogWoOgmo00?o0000oiVIVOnIVIT03?nIVIT0
0ol0003o/k>cok>c/`06ok>c/`?o00003?o<c<`Do`0000_oc<c<0_l00009ok>c/`03o`000?nIVIWo
VIVI00_oVIVI00?o0000ogmoOomoOgl0I?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?oooomhogmoO`03o`000?nIVIWoVIVI00coVIVI00?o0000ok>c/onc/k<01_nc/k<00ol0
003oc<c<olc<c007olc<c0Ko00005?oVi^H4o`0000Woc<c<00?o0000ok>c/onc/k<01onc/k<00ol0
003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo06?oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CoooooN?moOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c00Ko
/k>c00?o0000olc<c?o<c<`01oo<c<`00ol0003oi^KVonKViP0JonKViP03o`000?o<c<coc<c<00Oo
c<c<00?o0000ok>c/onc/k<01onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo06?o
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooNOmoOgl00ol0003oVIVI
oiVIV@0;oiVIV@03o`000?nc/k?o/k>c00Oo/k>c00?o0000olc<c?o<c<`01oo<c<`00ol0003oi^KV
onKViP0IonKViP03o`000?o<c<coc<c<00Koc<c<00?o0000ok>c/onc/k<01onc/k<00ol0003oVIVI
oiVIV@0;oiVIV@03o`000?moOgooOgmo06CoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CoooooN_moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c00Oo/k>c00?o
0000olc<c?o<c<`01_o<c<`00ol0003oi^KVonKViP0HonKViP03o`000?o<c<coc<c<00Koc<c<00?o
0000ok>c/onc/k<01onc/k<2o`0000goVIVI00?o0000ogmoOomoOgl0I?moOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?oooomkogmoO`;o00002onIVIT2o`0000Wo/k>c00?o0000
olc<c?o<c<`01_o<c<`3o`0001Koi^KV0_l00008olc<c003o`000?nc/k?o/k>c00Ko/k>c00?o0000
oiVIVOnIVIT02onIVIT2o`0006OoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CoooooOOmoOgl00ol0003oVIVIoiVIV@0:oiVIV@;o00002?nc/k<00ol0003oc<c<olc<c008olc<
c0?o00004?oVi^H3o`0000Woc<c<00?o0000ok>c/onc/k<01Onc/k<2o`0000coVIVI0_l0001Yogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooogkoOgmo00?o0000oiVIVOnI
VIT02onIVIT2o`0000Oo/k>c0ol0000:olc<c13o00002Oo<c<`3o`0000Oo/k>c00?o0000oiVIVOnI
VIT02onIVIT00ol0003oOgmoogmoO`1YogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooogooOgmo0ol0000<oiVIV@?o00001onc/k<3o`0001goc<c<0ol00007ok>c/`?o0000
3?nIVIT2o`0006coOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooP_mo
Ogl3o`0000coVIVI0_l00008ok>c/`Co00005_o<c<`3o`0000So/k>c0_l0000=oiVIV@;o0000K_mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon5ogmoO`?o00002onIVIT2
o`0000[o/k>c0ol0000@olc<c0?o00002Onc/k<2o`0000coVIVI0ol0001`ogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooohSoOgmo1Ol00008oiVIV@Go00002?nc/k<@o`00
00So/k>c1?l00009oiVIV@Go0000LomoOgl6ooooo`7o00000Oooool001[ooooo0_l00005ooooohgo
Ogmo1_l00007oiVIV@Oo00004_nc/k<7o`0000KoVIVI1ol0001hogmoO`Gooooo0_l00001ooooo`00
6_ooool00ol0003oooooooooo`04oooooi?oOgmo;Ol0001oogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04oooooj7oOgmo4_l0002<ogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?oooon<ogmoOc[o0000NOmoOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?oooon7ogmoO`Go0000>_mVIVH3o`0007KoOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CoooooQ_moOgl00ol0003oIVIVofIVIP10ofIVIP?o0000LomoOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?oooon5ogmoO`03o`000?mVIVKoIVIV04CoIVIV00?o
0000ogmoOomoOgl0L?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon4
ogmoO`03o`000?mVIVKoIVIV01WoIVIV4ol0000JofIVIP03o`000?moOgooOgmo06ooOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooPomoOgl00ol0003oIVIVofIVIP0GofIV
IP?o00004om<C4`2o`0001WoIVIV00?o0000ogmoOomoOgl0K_moOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?oooon4ogmoO`03o`000?mVIVKoIVIV01SoIVIV00?o0000oda<C?m<
C4`04?m<C4`00ol0003oIVIVofIVIP0IofIVIP03o`000?moOgooOgmo06koOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CoooooQOmoOgl00ol0003oIVIVofIVIP0HofIVIP;o0000
3om<C4`00ol0003oIVIVofIVIP0IofIVIP03o`000?moOgooOgmo06ooOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CoooooQ_moOgl00ol0003oIVIVofIVIP0IofIVIP03o`000?m<
C4coC4a<00SoC4a<1?l0000KofIVIP03o`000?moOgooOgmo073oOgmo1_ooool1o`00007ooooo000J
ooooo`;o00001Ooooon7ogmoO`03o`000?mVIVKoIVIV01WoIVIV2_l0000NofIVIP03o`000?moOgoo
Ogmo077oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooR?moOgl3o`00
03goIVIV0ol0001dogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooh_o
Ogmo0ol0000gofIVIP?o0000MomoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?oooon>ogmoO`Co0000<?mVIVH3o`0007[oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CoooooT_moOgl3o`0002[oIVIV0ol0001mogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04oooooiGoOgmo1Ol0000PofIVIPGo0000P?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?oooonJogmoO`Oo00004_mVIVH7o`0008GoOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CoooooXOmoOglBo`0008coOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000Sooooo1?l00000
2?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^1_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000:ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool3o`0000CooooooomoOgm0ogmoO`Co
oooo0ol00001ooooo`002_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
00001_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000[ooooo
00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000:ooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`002?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`00
00GooooooomoOgm0ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo0007ooooo`Go00000ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo0007ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo0008ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4006ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002Oooool00onHV9So8B4Q
onk^kP03ooooo`05o`000?ooooooooooooooool000001_ooool3o`0000CooooooomoOgm0ogmoO`Co
oooo0ol00001ooooo`002_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool0
00001_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000_ooooo
00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo0007ooooo`05o`000?nj^[[ooooooiRHV?l@
41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo0007ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000GooooooomoOgm0ogmoO`Go
oooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`001oooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`001oooool01Ol@
413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002oooool01Ol0003ooooooooooooo
oooo410@00?ooooo00?o410@ooooooooool01?ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool000[ooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooo
oooo000000Kooooo0ol00004ooooooooOgmo@?moOgl4ooooo`?o00000Oooool000Wooooo00?o410@
o`000?nj^[X00oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000:ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@
oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`001oooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`001ooo
ool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo0_l00005
ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000Wooooo0_l000002Ol@413ooooooooo
ooooooook^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmo
O`Kooooo0Ol00001ooooo`002_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000Oo
oooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@41001_ooool3o`0000CooooooomoOgm0ogmo
O`Cooooo0ol00001ooooo`001oooool01?m4A4CogMgMooooool00004ooooo`05o`000?oooooooooo
ooooool000001_ooool00ol0003oooooooooo`3ooooood[ooooo0Ol00001ooooo`001oooool01?oM
gMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooooooo
o`3ooooood[ooooo0Ol00001ooooo`002?ooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooo
ooooooooool@41001_ooool00ol0003oooooooooo`3ooooood[ooooo0Ol00001ooooo`002?ooool0
0oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003ooooooooo
o`3ooooood[ooooo0Ol00001ooooo`002Oooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03gooooo00?o
0000ooooooooool0?Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03gooooo00?o
0000ooooooooool08oooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02Oooool1o`00007ooooo000Joooooooo0000C_l00001ooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-30.1723, -14.304, 0.195672, \
0.195672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0192308 0.211538 0.0192308 [
[.11538 -0.0125 -9 -9 ]
[.11538 -0.0125 9 0 ]
[.30769 -0.0125 -9 -9 ]
[.30769 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69231 -0.0125 -6 -9 ]
[.69231 -0.0125 6 0 ]
[.88462 -0.0125 -6 -9 ]
[.88462 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -18 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .21154 -6 -4.5 ]
[-0.0125 .21154 0 4.5 ]
[-0.0125 .40385 -12 -4.5 ]
[-0.0125 .40385 0 4.5 ]
[-0.0125 .59615 -12 -4.5 ]
[-0.0125 .59615 0 4.5 ]
[-0.0125 .78846 -12 -4.5 ]
[-0.0125 .78846 0 4.5 ]
[-0.0125 .98077 -12 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11538 0 m
.11538 .00625 L
s
[(-20)] .11538 -0.0125 0 1 Mshowa
.30769 0 m
.30769 .00625 L
s
[(-10)] .30769 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69231 0 m
.69231 .00625 L
s
[(10)] .69231 -0.0125 0 1 Mshowa
.88462 0 m
.88462 .00625 L
s
[(20)] .88462 -0.0125 0 1 Mshowa
.125 Mabswid
.15385 0 m
.15385 .00375 L
s
.19231 0 m
.19231 .00375 L
s
.23077 0 m
.23077 .00375 L
s
.26923 0 m
.26923 .00375 L
s
.34615 0 m
.34615 .00375 L
s
.38462 0 m
.38462 .00375 L
s
.42308 0 m
.42308 .00375 L
s
.46154 0 m
.46154 .00375 L
s
.53846 0 m
.53846 .00375 L
s
.57692 0 m
.57692 .00375 L
s
.61538 0 m
.61538 .00375 L
s
.65385 0 m
.65385 .00375 L
s
.73077 0 m
.73077 .00375 L
s
.76923 0 m
.76923 .00375 L
s
.80769 0 m
.80769 .00375 L
s
.84615 0 m
.84615 .00375 L
s
.07692 0 m
.07692 .00375 L
s
.03846 0 m
.03846 .00375 L
s
.92308 0 m
.92308 .00375 L
s
.96154 0 m
.96154 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(-10)] -0.0125 .01923 1 0 Mshowa
0 .21154 m
.00625 .21154 L
s
[(0)] -0.0125 .21154 1 0 Mshowa
0 .40385 m
.00625 .40385 L
s
[(10)] -0.0125 .40385 1 0 Mshowa
0 .59615 m
.00625 .59615 L
s
[(20)] -0.0125 .59615 1 0 Mshowa
0 .78846 m
.00625 .78846 L
s
[(30)] -0.0125 .78846 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(40)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .05769 m
.00375 .05769 L
s
0 .09615 m
.00375 .09615 L
s
0 .13462 m
.00375 .13462 L
s
0 .17308 m
.00375 .17308 L
s
0 .25 m
.00375 .25 L
s
0 .28846 m
.00375 .28846 L
s
0 .32692 m
.00375 .32692 L
s
0 .36538 m
.00375 .36538 L
s
0 .44231 m
.00375 .44231 L
s
0 .48077 m
.00375 .48077 L
s
0 .51923 m
.00375 .51923 L
s
0 .55769 m
.00375 .55769 L
s
0 .63462 m
.00375 .63462 L
s
0 .67308 m
.00375 .67308 L
s
0 .71154 m
.00375 .71154 L
s
0 .75 m
.00375 .75 L
s
0 .82692 m
.00375 .82692 L
s
0 .86538 m
.00375 .86538 L
s
0 .90385 m
.00375 .90385 L
s
0 .94231 m
.00375 .94231 L
s
.25 Mabswid
0 0 m
0 1 L
s
.11538 .99375 m
.11538 1 L
s
.30769 .99375 m
.30769 1 L
s
.5 .99375 m
.5 1 L
s
.69231 .99375 m
.69231 1 L
s
.88462 .99375 m
.88462 1 L
s
.125 Mabswid
.15385 .99625 m
.15385 1 L
s
.19231 .99625 m
.19231 1 L
s
.23077 .99625 m
.23077 1 L
s
.26923 .99625 m
.26923 1 L
s
.34615 .99625 m
.34615 1 L
s
.38462 .99625 m
.38462 1 L
s
.42308 .99625 m
.42308 1 L
s
.46154 .99625 m
.46154 1 L
s
.53846 .99625 m
.53846 1 L
s
.57692 .99625 m
.57692 1 L
s
.61538 .99625 m
.61538 1 L
s
.65385 .99625 m
.65385 1 L
s
.73077 .99625 m
.73077 1 L
s
.76923 .99625 m
.76923 1 L
s
.80769 .99625 m
.80769 1 L
s
.84615 .99625 m
.84615 1 L
s
.07692 .99625 m
.07692 1 L
s
.03846 .99625 m
.03846 1 L
s
.92308 .99625 m
.92308 1 L
s
.96154 .99625 m
.96154 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .21154 m
1 .21154 L
s
.99375 .40385 m
1 .40385 L
s
.99375 .59615 m
1 .59615 L
s
.99375 .78846 m
1 .78846 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .05769 m
1 .05769 L
s
.99625 .09615 m
1 .09615 L
s
.99625 .13462 m
1 .13462 L
s
.99625 .17308 m
1 .17308 L
s
.99625 .25 m
1 .25 L
s
.99625 .28846 m
1 .28846 L
s
.99625 .32692 m
1 .32692 L
s
.99625 .36538 m
1 .36538 L
s
.99625 .44231 m
1 .44231 L
s
.99625 .48077 m
1 .48077 L
s
.99625 .51923 m
1 .51923 L
s
.99625 .55769 m
1 .55769 L
s
.99625 .63462 m
1 .63462 L
s
.99625 .67308 m
1 .67308 L
s
.99625 .71154 m
1 .71154 L
s
.99625 .75 m
1 .75 L
s
.99625 .82692 m
1 .82692 L
s
.99625 .86538 m
1 .86538 L
s
.99625 .90385 m
1 .90385 L
s
.99625 .94231 m
1 .94231 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.4 g
.39207 .25205 m
.4117 .2453 L
.43132 .24347 L
.45094 .23928 L
.47057 .2419 L
.49019 .24358 L
.50981 .24467 L
.52943 .24522 L
.54906 .2452 L
.56868 .2446 L
.5883 .24346 L
.60793 .24174 L
.62755 .23899 L
.64717 .24354 L
.6668 .24557 L
.68642 .2532 L
.68797 .25471 L
.68642 .27171 L
.68422 .27433 L
.6668 .28445 L
.64717 .29079 L
.63248 .29396 L
.62755 .29493 L
.60793 .29774 L
.5883 .29485 L
.56868 .29655 L
.54906 .29744 L
.52943 .29747 L
.50981 .29666 L
.49019 .29501 L
.47057 .29792 L
.45094 .2952 L
.44446 .29396 L
.43132 .29118 L
.4117 .28509 L
.3926 .27433 L
.39207 .27376 L
.38903 .25471 L
F
0 g
.39207 .25205 m
.4117 .2453 L
.43132 .24347 L
.45094 .23928 L
.47057 .2419 L
.49019 .24358 L
.50981 .24467 L
.52943 .24522 L
.54906 .2452 L
.56868 .2446 L
.5883 .24346 L
.60793 .24174 L
.62755 .23899 L
.64717 .24354 L
.6668 .24557 L
.68642 .2532 L
.68797 .25471 L
.68642 .27171 L
.68422 .27433 L
.6668 .28445 L
.64717 .29079 L
.63248 .29396 L
.62755 .29493 L
.60793 .29774 L
.5883 .29485 L
.56868 .29655 L
.54906 .29744 L
.52943 .29747 L
.50981 .29666 L
.49019 .29501 L
.47057 .29792 L
.45094 .2952 L
.44446 .29396 L
.43132 .29118 L
.4117 .28509 L
.3926 .27433 L
.39207 .27376 L
.38903 .25471 L
.39207 .25205 L
s
.6 g
.4117 .3069 m
.43132 .30457 L
.45094 .3042 L
.47057 .30448 L
.49019 .29802 L
.50981 .29985 L
.52943 .30065 L
.54906 .30062 L
.56868 .29975 L
.5883 .29781 L
.60793 .30445 L
.62755 .3042 L
.64717 .30465 L
.6668 .30727 L
.68016 .31358 L
.67407 .3332 L
.6668 .33875 L
.64717 .34749 L
.62755 .3528 L
.62745 .35283 L
.60793 .35675 L
.5883 .35931 L
.56868 .36086 L
.54906 .36161 L
.52943 .36164 L
.50981 .36095 L
.49019 .35947 L
.47057 .357 L
.45094 .35318 L
.44955 .35283 L
.43132 .34801 L
.4117 .33967 L
.40284 .3332 L
.39673 .31358 L
F
0 g
.4117 .3069 m
.43132 .30457 L
.45094 .3042 L
.47057 .30448 L
.49019 .29802 L
.50981 .29985 L
.52943 .30065 L
.54906 .30062 L
.56868 .29975 L
.5883 .29781 L
.60793 .30445 L
.62755 .3042 L
.64717 .30465 L
.6668 .30727 L
.68016 .31358 L
.67407 .3332 L
.6668 .33875 L
.64717 .34749 L
.62755 .3528 L
.62745 .35283 L
.60793 .35675 L
.5883 .35931 L
.56868 .36086 L
.54906 .36161 L
.52943 .36164 L
.50981 .36095 L
.49019 .35947 L
.47057 .357 L
.45094 .35318 L
.44955 .35283 L
.43132 .34801 L
.4117 .33967 L
.40284 .3332 L
.39673 .31358 L
.4117 .3069 L
s
.6 g
.43132 .19033 m
.45094 .19104 L
.47057 .19278 L
.49019 .18705 L
.50981 .18707 L
.52943 .18711 L
.54906 .18711 L
.56868 .18706 L
.5883 .18706 L
.60793 .19262 L
.62755 .19093 L
.64717 .19038 L
.66461 .19584 L
.6668 .19708 L
.6731 .21546 L
.6668 .2207 L
.64717 .22923 L
.62755 .23416 L
.62252 .23509 L
.60793 .23698 L
.5883 .23927 L
.56868 .2409 L
.54906 .24176 L
.52943 .2418 L
.50981 .241 L
.49019 .23942 L
.47057 .23718 L
.45436 .23509 L
.45094 .23447 L
.43132 .22972 L
.4117 .22164 L
.40383 .21546 L
.4117 .19616 L
.41229 .19584 L
F
0 g
.43132 .19033 m
.45094 .19104 L
.47057 .19278 L
.49019 .18705 L
.50981 .18707 L
.52943 .18711 L
.54906 .18711 L
.56868 .18706 L
.5883 .18706 L
.60793 .19262 L
.62755 .19093 L
.64717 .19038 L
.66461 .19584 L
.6668 .19708 L
.6731 .21546 L
.6668 .2207 L
.64717 .22923 L
.62755 .23416 L
.62252 .23509 L
.60793 .23698 L
.5883 .23927 L
.56868 .2409 L
.54906 .24176 L
.52943 .2418 L
.50981 .241 L
.49019 .23942 L
.47057 .23718 L
.45436 .23509 L
.45094 .23447 L
.43132 .22972 L
.4117 .22164 L
.40383 .21546 L
.4117 .19616 L
.41229 .19584 L
.43132 .19033 L
s
.3 g
.45094 .24922 m
.47057 .24748 L
.49019 .24764 L
.50981 .24802 L
.52943 .24827 L
.54906 .24826 L
.56868 .248 L
.5883 .24761 L
.60793 .24751 L
.62755 .24964 L
.63699 .25471 L
.64717 .27433 L
.62755 .28537 L
.60793 .29097 L
.5914 .29396 L
.5883 .29404 L
.56868 .29488 L
.54906 .29552 L
.52943 .29554 L
.50981 .29495 L
.49019 .29409 L
.4855 .29396 L
.47057 .29131 L
.45094 .28594 L
.43132 .27573 L
.42982 .27433 L
.43132 .25998 L
.43992 .25471 L
F
0 g
.45094 .24922 m
.47057 .24748 L
.49019 .24764 L
.50981 .24802 L
.52943 .24827 L
.54906 .24826 L
.56868 .248 L
.5883 .24761 L
.60793 .24751 L
.62755 .24964 L
.63699 .25471 L
.64717 .27433 L
.62755 .28537 L
.60793 .29097 L
.5914 .29396 L
.5883 .29404 L
.56868 .29488 L
.54906 .29552 L
.52943 .29554 L
.50981 .29495 L
.49019 .29409 L
.4855 .29396 L
.47057 .29131 L
.45094 .28594 L
.43132 .27573 L
.42982 .27433 L
.43132 .25998 L
.43992 .25471 L
.45094 .24922 L
s
.4 g
.45094 .14933 m
.47057 .14313 L
.49019 .14048 L
.50981 .13921 L
.52943 .1387 L
.54906 .13872 L
.56868 .13928 L
.5883 .14062 L
.60793 .14344 L
.62755 .15023 L
.63351 .15659 L
.62755 .16504 L
.60793 .17338 L
.59483 .17622 L
.5883 .17697 L
.56868 .17855 L
.54906 .17929 L
.52943 .17932 L
.50981 .17863 L
.49019 .17713 L
.48208 .17622 L
.47057 .17379 L
.45094 .16611 L
.44342 .15659 L
F
0 g
.45094 .14933 m
.47057 .14313 L
.49019 .14048 L
.50981 .13921 L
.52943 .1387 L
.54906 .13872 L
.56868 .13928 L
.5883 .14062 L
.60793 .14344 L
.62755 .15023 L
.63351 .15659 L
.62755 .16504 L
.60793 .17338 L
.59483 .17622 L
.5883 .17697 L
.56868 .17855 L
.54906 .17929 L
.52943 .17932 L
.50981 .17863 L
.49019 .17713 L
.48208 .17622 L
.47057 .17379 L
.45094 .16611 L
.44342 .15659 L
.45094 .14933 L
s
.7 g
.50981 .1947 m
.52943 .19418 L
.54906 .1942 L
.56868 .19476 L
.58555 .19584 L
.5883 .19614 L
.60793 .19908 L
.62755 .20719 L
.6315 .21546 L
.62755 .21948 L
.60793 .2286 L
.5883 .23308 L
.5738 .23509 L
.56868 .2356 L
.54906 .23694 L
.52943 .23699 L
.50981 .23576 L
.50289 .23509 L
.49019 .23333 L
.47057 .22907 L
.45094 .22061 L
.44543 .21546 L
.45094 .20598 L
.47057 .19874 L
.49019 .19599 L
.49155 .19584 L
F
0 g
.50981 .1947 m
.52943 .19418 L
.54906 .1942 L
.56868 .19476 L
.58555 .19584 L
.5883 .19614 L
.60793 .19908 L
.62755 .20719 L
.6315 .21546 L
.62755 .21948 L
.60793 .2286 L
.5883 .23308 L
.5738 .23509 L
.56868 .2356 L
.54906 .23694 L
.52943 .23699 L
.50981 .23576 L
.50289 .23509 L
.49019 .23333 L
.47057 .22907 L
.45094 .22061 L
.44543 .21546 L
.45094 .20598 L
.47057 .19874 L
.49019 .19599 L
.49155 .19584 L
.50981 .1947 L
s
.7 g
.47057 .31188 m
.49019 .30661 L
.50981 .30642 L
.52943 .30648 L
.54906 .30648 L
.56868 .30642 L
.5883 .30666 L
.60793 .31205 L
.61826 .31358 L
.62755 .31716 L
.63051 .3332 L
.62755 .33554 L
.60793 .34451 L
.5883 .34927 L
.56868 .352 L
.5584 .35283 L
.54906 .35332 L
.52943 .35337 L
.51853 .35283 L
.50981 .35215 L
.49019 .34956 L
.47057 .34499 L
.45094 .33658 L
.44643 .3332 L
.45094 .31633 L
.45866 .31358 L
F
0 g
.47057 .31188 m
.49019 .30661 L
.50981 .30642 L
.52943 .30648 L
.54906 .30648 L
.56868 .30642 L
.5883 .30666 L
.60793 .31205 L
.61826 .31358 L
.62755 .31716 L
.63051 .3332 L
.62755 .33554 L
.60793 .34451 L
.5883 .34927 L
.56868 .352 L
.5584 .35283 L
.54906 .35332 L
.52943 .35337 L
.51853 .35283 L
.50981 .35215 L
.49019 .34956 L
.47057 .34499 L
.45094 .33658 L
.44643 .3332 L
.45094 .31633 L
.45866 .31358 L
.47057 .31188 L
s
.4 g
.47057 .37232 m
.49019 .3715 L
.50981 .37125 L
.52943 .37118 L
.54906 .37119 L
.56868 .37126 L
.5883 .37154 L
.60793 .37243 L
.60813 .37245 L
.62755 .37688 L
.62902 .39207 L
.62755 .39332 L
.60793 .40292 L
.5883 .40787 L
.56868 .41069 L
.55599 .4117 L
.54906 .41209 L
.52943 .41215 L
.52095 .4117 L
.50981 .41085 L
.49019 .40816 L
.47057 .40343 L
.45094 .39447 L
.44791 .39207 L
.45094 .37617 L
.46874 .37245 L
F
0 g
.47057 .37232 m
.49019 .3715 L
.50981 .37125 L
.52943 .37118 L
.54906 .37119 L
.56868 .37126 L
.5883 .37154 L
.60793 .37243 L
.60813 .37245 L
.62755 .37688 L
.62902 .39207 L
.62755 .39332 L
.60793 .40292 L
.5883 .40787 L
.56868 .41069 L
.55599 .4117 L
.54906 .41209 L
.52943 .41215 L
.52095 .4117 L
.50981 .41085 L
.49019 .40816 L
.47057 .40343 L
.45094 .39447 L
.44791 .39207 L
.45094 .37617 L
.46874 .37245 L
.47057 .37232 L
s
.2 g
.49019 .25366 m
.50981 .25231 L
.52943 .25194 L
.54906 .25195 L
.56868 .25237 L
.5883 .25386 L
.59381 .25471 L
.60793 .25761 L
.62326 .27433 L
.60793 .28313 L
.5883 .28863 L
.56868 .29162 L
.54906 .293 L
.52943 .29305 L
.50981 .29178 L
.49019 .28895 L
.47057 .28371 L
.45366 .27433 L
.47057 .25718 L
.48307 .25471 L
F
0 g
.49019 .25366 m
.50981 .25231 L
.52943 .25194 L
.54906 .25195 L
.56868 .25237 L
.5883 .25386 L
.59381 .25471 L
.60793 .25761 L
.62326 .27433 L
.60793 .28313 L
.5883 .28863 L
.56868 .29162 L
.54906 .293 L
.52943 .29305 L
.50981 .29178 L
.49019 .28895 L
.47057 .28371 L
.45366 .27433 L
.47057 .25718 L
.48307 .25471 L
.49019 .25366 L
s
.1 g
.49019 .26121 m
.50981 .258 L
.52943 .25688 L
.54906 .25692 L
.56868 .25815 L
.5883 .26164 L
.60234 .27433 L
.5883 .28163 L
.56868 .28624 L
.54906 .28819 L
.52943 .28826 L
.50981 .28647 L
.49019 .28214 L
.47459 .27433 L
F
0 g
.49019 .26121 m
.50981 .258 L
.52943 .25688 L
.54906 .25692 L
.56868 .25815 L
.5883 .26164 L
.60234 .27433 L
.5883 .28163 L
.56868 .28624 L
.54906 .28819 L
.52943 .28826 L
.50981 .28647 L
.49019 .28214 L
.47459 .27433 L
.49019 .26121 L
s
.8 g
.49019 .20598 m
.50981 .2025 L
.52943 .20124 L
.54906 .20129 L
.56868 .20267 L
.5883 .20645 L
.60175 .21546 L
.5883 .22416 L
.56868 .22896 L
.54906 .23091 L
.52943 .23098 L
.50981 .2292 L
.49019 .22472 L
.47518 .21546 L
F
0 g
.49019 .20598 m
.50981 .2025 L
.52943 .20124 L
.54906 .20129 L
.56868 .20267 L
.5883 .20645 L
.60175 .21546 L
.5883 .22416 L
.56868 .22896 L
.54906 .23091 L
.52943 .23098 L
.50981 .2292 L
.49019 .22472 L
.47518 .21546 L
.49019 .20598 L
s
.8 g
.49019 .31931 m
.50981 .31624 L
.52943 .31524 L
.54906 .31528 L
.56868 .31638 L
.5883 .31975 L
.59854 .3332 L
.5883 .3384 L
.56868 .34338 L
.54906 .34547 L
.52943 .34555 L
.50981 .34364 L
.49019 .33896 L
.47837 .3332 L
F
0 g
.49019 .31931 m
.50981 .31624 L
.52943 .31524 L
.54906 .31528 L
.56868 .31638 L
.5883 .31975 L
.59854 .3332 L
.5883 .3384 L
.56868 .34338 L
.54906 .34547 L
.52943 .34555 L
.50981 .34364 L
.49019 .33896 L
.47837 .3332 L
.49019 .31931 L
s
.50981 .26559 m
.52943 .263 L
.54906 .26309 L
.56868 .266 L
.58041 .27433 L
.56868 .2791 L
.54906 .28234 L
.52943 .28245 L
.50981 .27952 L
.49642 .27433 L
F
.50981 .26559 m
.52943 .263 L
.54906 .26309 L
.56868 .266 L
.58041 .27433 L
.56868 .2791 L
.54906 .28234 L
.52943 .28245 L
.50981 .27952 L
.49642 .27433 L
.50981 .26559 L
s
.9 g
.50981 .21526 m
.52943 .21035 L
.54906 .21049 L
.56736 .21546 L
.54906 .22212 L
.52943 .22229 L
.50981 .21589 L
.50951 .21546 L
F
0 g
.50981 .21526 m
.52943 .21035 L
.54906 .21049 L
.56736 .21546 L
.54906 .22212 L
.52943 .22229 L
.50981 .21589 L
.50951 .21546 L
.50981 .21526 L
s
.9 g
.52943 .32659 m
.54906 .32684 L
.55552 .3332 L
.54906 .3345 L
.52943 .33469 L
.52142 .3332 L
F
0 g
.52943 .32659 m
.54906 .32684 L
.55552 .3332 L
.54906 .3345 L
.52943 .33469 L
.52142 .3332 L
.52943 .32659 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00?Oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0dooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kS?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0hooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8b
onk^kS?ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08_ooool003gooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0=_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0<oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg03?ooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL08_ooool003Gooooo1_l0
0003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400[ooooo`Ko0000
1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100<oooool01Ol@413o
oooooooooooooooo410@03[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@03Cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@02;ooooo000o
ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000fooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000cooooo`05o`000?ooooooooooooooool0
0000>_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000=Oooool00onH
V9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000008_ooool0043ooooo00?oMgMgofIV
I_ooool00_ooool01Ol0003ooooooooooooooooo000003Kooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000003?ooooo00Go0000ooooooooooooooooo`00000jooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`03ogMgMomVIVKooooo00;o
oooo00Go0000ooooooooooooooooo`00000Rooooo`00@Oooool01Ol0003ooooooooooooooooo410@
00?ooooo00?o410@ooooooooool0=?ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@4100<oooool01Ol@413ooooooooooooooooo410@03[ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@03Oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo023ooooo000mooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg03Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg03?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0jooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0cooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02;ooooo000mooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^03Cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^03?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`03oeEEEOmVIVKo000000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0cooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02;ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo000Joooooooo0000C_l00001ooooo`00
6_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0?Ooo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool08ooo
ool1o`00007ooooo0008ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKo
oooo00?o0000ooooooooool0oooooom:ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooom:ooooo`7o
00000Oooool000Go00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41001_ooool00ol0003oooooooooo`3ooooood[ooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?ooooooB?ooool3o`00007o
oooo000:ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo0008ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Oooooooogmo
Od3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Ooo
ooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
VOmoOglXo`0007koOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooU?mo
Ogl5o`0002SoIVIV1?l0001jogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
oooooi7oOgmo0ol0000aofIVIP?o0000MomoOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?oooon?ogmoO`;o0000=omVIVH2o`0007GoOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CoooooS_moOgl00ol0003oIVIVofIVIP0iofIVIP03o`000?moOgooOgmo07;o
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooSOmoOgl00ol0003oIVIV
ofIVIP0kofIVIP03o`000?moOgooOgmo077oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CoooooS?moOgl00ol0003oIVIVofIVIP0mofIVIP03o`000?moOgooOgmo073oOgmo1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooSOmoOgl00ol0003oIVIVofIVIP0k
ofIVIP03o`000?moOgooOgmo077oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CoooooS_moOgl00ol0003oIVIVofIVIP0hofIVIP;o0000M?moOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?oooon?ogmoO`?o0000=?mVIVH3o`0007KoOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CoooooT_moOgl3o`0002ooIVIV0_l0001iogmoO`Kooooo
0Ol00001ooooo`006_ooool2o`0000GoooooUOmoOgl3o`0002WoIVIV0ol0001kogmoO`Gooooo0_l0
0001ooooo`006_ooool00ol0003oooooooooo`04oooooiSoOgmo2Ol0000IofIVIPOo0000O_moOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonQogmoOaWo0000QOmoOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04oooooi[oOgmo9_l0001oogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooohOoOgmo3?l00004ogmoO`?o00009_nIVIT3o`0000CoOgmo3?l0001/
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooohCoOgmo0ol0000<oiVI
V@Co00002OnIVITJo`0000WoVIVI1?l0000<oiVIV@?o0000JOmoOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?oooon2ogmoO`;o00005OnIVIT7o`0001[o/k>c1ol0000EoiVIV@;o
0000IomoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon2ogmoO`03o`00
0?nIVIWoVIVI00ooVIVI1Ol0000=ok>c/`ko00003Onc/k<5o`00017oVIVI00?o0000ogmoOomoOgl0
IOmoOgl6ooooo`7o00000Oooool000oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`00
0?oooooooooo00CoooooPOmoOgl00ol0003oVIVIoiVIV@0=oiVIV@?o00003?nc/k<6o`0000koc<c<
1ol0000;ok>c/`?o00003onIVIT00ol0003oOgmoogmoO`1TogmoO`Kooooo0Ol00001ooooo`003ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?oooon1ogmoO`03o`00
0?nIVIWoVIVI00_oVIVI0_l0000:ok>c/`Go00006oo<c<`4o`0000[o/k>c0_l0000=oiVIV@03o`00
0?moOgooOgmo06CoOgmo1_ooool1o`00007ooooo000?ooooo`05oa0@4?ooooooooooooooool@4100
1_ooool00ol0003oooooooooo`04oooooh3oOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>c
ok>c/`07ok>c/`;o00003Oo<c<`6o`00017oc<c<00?o0000ok>c/onc/k<02?nc/k<00ol0003oVIVI
oiVIV@0;oiVIV@03o`000?moOgooOgmo06CoOgmo1_ooool1o`00007ooooo000?ooooo`05o`000?oo
ooooooooooooool000001_ooool3o`0000CoooooP?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`00
0?nc/k?o/k>c00Oo/k>c00?o0000olc<c?o<c<`02_o<c<`3o`0000Koi^KV1_l0000<olc<c003o`00
0?nc/k?o/k>c00So/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`1SogmoO`Cooooo
0ol00001ooooo`003oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0
1?oooomoogmoO`;o00003?nIVIT00ol0003o/k>cok>c/`07ok>c/`;o00002Oo<c<`4o`0000koi^KV
0ol00009olc<c0;o00002Onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo06?oOgmo
1_ooool1o`00007ooooo000?ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003ooooo
ooooo`04oooooh7oOgmo00?o0000oiVIVOnIVIT02_nIVIT00ol0003o/k>cok>c/`08ok>c/`;o0000
2oo<c<`3o`0000Woi^KV0ol0000:olc<c003o`000?nc/k?o/k>c00Wo/k>c00?o0000oiVIVOnIVIT0
2_nIVIT00ol0003oOgmoogmoO`1TogmoO`Kooooo0Ol00001ooooo`003oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Kooooo00?o0000ooooooooool01?oooon2ogmoO`;o00002onIVIT2o`0000[o/k>c
00?o0000olc<c?o<c<`02oo<c<`9o`0000coc<c<00?o0000ok>c/onc/k<02?nc/k<2o`0000_oVIVI
0_l0001WogmoO`Kooooo0Ol00001ooooo`003oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo
00?o0000ooooooooool01?oooon4ogmoO`;o00002onIVIT2o`0000Wo/k>c0ol0000Lolc<c0?o0000
2?nc/k<3o`0000[oVIVI0ol0001YogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooohKoOgmo0_l0000;oiVIV@;o00002_nc/k<3o`0001Koc<c<0ol00009ok>c/`;o00002onI
VIT2o`0006coOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooR?moOgl5
o`0000SoVIVI1Ol00008ok>c/aKo00002?nc/k<4o`0000WoVIVI1?l0001^ogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooohgoOgmo0ol0000:oiVIV@Go00007?nc/k<5o`00
00WoVIVI1?l0001bogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooi3o
Ogmo2_l00005oiVIVAco00001OnIVIT9o`0007KoOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CoooooS?moOgl7o`0000OoOgmo1ol0000IoiVIV@Ko00001omoOgl6o`0007;oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooQOmoOgl7o`0000OoIVIV1ol0
0007ogmoObKo00001_mVIVH3o`0006ooOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CoooooP?moOgl5o`0001GoIVIV8?l0000FofIVIPWo0000I_moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?oooommogmoO`?o00003_mVIVHjo`00017oIVIV0_l0001Togmo
O`Kooooo0Ol00001ooooo`006_ooool2o`0000GoooooNomoOgl2o`0000ooIVIV0_l0000Boda<C1_o
00003Om<C4`5o`0000koIVIV0_l0001RogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooog[oOgmo00?o0000ofIVI_mVIVH03OmVIVH2o`0000coC4a<2?l0000Koc<c<`Oo0000
2om<C4`00ol0003oIVIVofIVIP0=ofIVIP;o0000H?moOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?oooomjogmoO`03o`000?mVIVKoIVIV00coIVIV00?o0000oda<C?m<C4`02Om<
C4`3o`0000So<c<c6Ol00009oc<c<`;o00002Om<C4`00ol0003oIVIVofIVIP0>ofIVIP03o`000?mo
OgooOgmo05koOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooN_moOgl0
0ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<00[oC4a<00?o0000oc<c<olc<c<01?lc<c<4
o`0001Wo6ATI0ol00007oc<c<`03o`000?m<C4coC4a<00SoC4a<00?o0000ofIVI_mVIVH03OmVIVH0
0ol0003oOgmoogmoO`1NogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
og[oOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C009oda<C003o`000?lc<c?o<c<c
00Co<c<c00?o0000oaTI6OlI6AT02?lI6AT>o`0000So6ATI0_l00006oc<c<`03o`000?m<C4coC4a<
00OoC4a<00?o0000ofIVI_mVIVH03OmVIVH00ol0003oOgmoogmoO`1NogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooog_oOgmo00?o0000ofIVI_mVIVH02_mVIVH00ol0003o
C4a<oda<C008oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oaTI6OlI6AT01OlI6ATFo`0000Ko
6ATI00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C007oda<C003o`000?mVIVKoIVIV00_o
IVIV00?o0000ogmoOomoOgl0GomoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?oooomkogmoO`03o`000?mVIVKoIVIV00[oIVIV00?o0000oda<C?m<C4`01om<C4`00ol0003o<c<c
oc<c<`04oc<c<`03o`000?lI6AWo6ATI00Co6ATI6Ol00006oaTI6@03o`000?lc<c?o<c<c00Co<c<c
00?o0000oda<C?m<C4`01_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo05ooOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooNomoOgl00ol0003oIVIVofIV
IP0:ofIVIP03o`000?m<C4coC4a<00KoC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003o6ATIoaTI
6@04oaTI6A_o00001_lI6AT00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00GoC4a<00?o
0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`1OogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooog_oOgmo0ol0000:ofIVIP;o00001_m<C4`2o`0000Go<c<c0_l00005
oaTI6Ago00001OlI6AT2o`0000Go<c<c0_l00006oda<C0;o00002_mVIVH2o`0006;oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooO_moOgl2o`0000[oIVIV0_l00006oda<
C0;o00001Olc<c<3o`0000Ko6ATI5_l00006oaTI6@;o00001Olc<c<2o`0000KoC4a<0_l0000:ofIV
IP;o0000I?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon0ogmoO`;o
00002_mVIVH00ol0003oC4a<oda<C005oda<C003o`000?lc<c?o<c<c00Go<c<c0ol00008oaTI6@co
00002?lI6AT3o`0000Ko<c<c00?o0000oda<C?m<C4`01?m<C4`2o`0000_oIVIV00?o0000ogmoOomo
Ogl0I?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon2ogmoO`?o0000
2?mVIVH2o`0000KoC4a<0ol00007oc<c<`?o00005_lI6AT3o`0000Go<c<c1?l00004oda<C0?o0000
2_mVIVH3o`0006OoOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Ooooon5ogmoO`?o00001omV
IVH4o`0000GoC4a<0ol00007oc<c<aKo00000_lc<c<6o`0000GoC4a<0ol0000:ofIVIP?o0000J_mo
Ogl5ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool01?oooon8ogmoO`Co00001omVIVH6
o`0000;oC4a<1_l0000Boc<c<`Oo00001om<C4`4o`0000WoIVIV1?l0001]ogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooohcoOgmo0ol0000:ofIVIQ[o00001om<C4`7o`00
00[oIVIV0ol0001aogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooohoo
Ogmo1?l00006ofIVIRSo00001_mVIVH4o`0007CoOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CoooooTomoOgl6o`000003ogmoOol0003o000002Co000000?oOgmoo`000?l00000
1?l0001hogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooiOoOgmo0ol0
000VoiVIV@?o0000O?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon5
ogmoOa;o00000onIVITVo`0000?oVIVI4_l0001ZogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04oooooh7oOgmo1?l0000BoiVIV@?o00009_nc/k<3o`0001;oVIVI1?l0001Vogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooogkoOgmo0ol0000CoiVIV@?o
0000;?nc/k<3o`0001?oVIVI0_l0001TogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04oooooggoOgmo00?o0000oiVIVOnIVIT04OnIVIT3o`0001;o/k>c3_l0000Bok>c/`Co0000
4OnIVIT00ol0003oOgmoogmoO`1QogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04oooooggoOgmo00?o0000oiVIVOnIVIT03onIVIT2o`0000oo/k>c1_l0000>olc<c0Oo00003onc
/k<00ol0003oVIVIoiVIV@0>oiVIV@03o`000?moOgooOgmo067oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CoooooO_moOgl00ol0003oVIVIoiVIV@0>oiVIV@03o`000?nc/k?o
/k>c00[o/k>c1?l0000Kolc<c0?o00003?nc/k<00ol0003oVIVIoiVIV@0=oiVIV@03o`000?moOgoo
Ogmo06;oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooO_moOgl00ol0
003oVIVIoiVIV@0=oiVIV@03o`000?nc/k?o/k>c00[o/k>c00?o0000olc<c?o<c<`07oo<c<`00ol0
003o/k>cok>c/`0:ok>c/`03o`000?nIVIWoVIVI00goVIVI00?o0000ogmoOomoOgl0H_moOgl6oooo
o`7o00000Oooool001[ooooo0_l00005ooooogkoOgmo00?o0000oiVIVOnIVIT03OnIVIT00ol0003o
/k>cok>c/`09ok>c/`03o`000?o<c<coc<c<00_oc<c<2Ol0000=olc<c003o`000?nc/k?o/k>c00[o
/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`1RogmoO`Gooooo0_l00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooogooOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>c
ok>c/`08ok>c/`03o`000?o<c<coc<c<00_oc<c<00?o0000onKVi_oVi^H01ooVi^H00ol0003oc<c<
olc<c00;olc<c003o`000?nc/k?o/k>c00Wo/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmo
ogmoO`1SogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooogooOgmo0_l0
000<oiVIV@;o00002Onc/k<2o`0000coc<c<0ol00008onKViP;o00003?o<c<`2o`0000[o/k>c00?o
0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`1SogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04oooooh7oOgmo00?o0000oiVIVOnIVIT02onIVIT2o`0000Wo/k>c0_l0000=
olc<c0So00003Oo<c<`00ol0003o/k>cok>c/`08ok>c/`;o00003OnIVIT00ol0003oOgmoogmoO`1T
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooh;oOgmo0_l0000=oiVI
V@;o00002Onc/k<3o`0001coc<c<0ol00008ok>c/`?o00003OnIVIT2o`0006OoOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CoooooQ?moOgl2o`0000goVIVI0_l0000:ok>c/`?o
00005_o<c<`3o`0000Wo/k>c0_l0000=oiVIV@?o0000JOmoOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?oooon6ogmoO`;o00003OnIVIT3o`0000[o/k>c5_l0000:ok>c/`;o0000
3OnIVIT2o`0006coOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooR?mo
Ogl3o`0000goVIVI0ol0000Tok>c/`?o00003OnIVIT2o`0006koOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CoooooRomoOgl3o`0000goVIVI1_l0000Iok>c/`Go00003OnIVIT3
o`00073oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooS_moOgl5o`00
00koVIVI6Ol0000=oiVIV@Go0000LomoOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?oooonCogmoO`Oo00009_nIVIT7o`0007SoOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CoooooV_moOgl7o`0001;oVIVI3Ol0001oogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04oooooj7oOgmo4_l0002<ogmoO`Kooooo0Ol00001ooooo`006_ooool2
o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04oooo
ooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonDogmoOc;o
0000NOmoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonAogmoO`?o0000
<_mVIVH3o`0007KoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooSomo
Ogl2o`0003SoIVIV0_l0001dogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooohooOgmo00?o0000ofIVI_mVIVH0>?mVIVH00ol0003oOgmoogmoO`1bogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooohooOgmo00?o0000ofIVI_mVIVH0>?mVIVH00ol0
003oOgmoogmoO`1bogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooohko
Ogmo00?o0000ofIVI_mVIVH0>OmVIVH00ol0003oOgmoogmoO`1bogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooohkoOgmo00?o0000ofIVI_mVIVH0>OmVIVH00ol0003oOgmo
ogmoO`1bogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooohkoOgmo00?o
0000ofIVI_mVIVH0>?mVIVH2o`0007CoOgmo1_ooool1o`00007ooooo0008ooooo`Co000000So410@
ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo00?o0000ooooooooool01?oooon?ogmoO`;o
0000=OmVIVH3o`0007KoOgmo1_ooool1o`00007ooooo000:ooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00CoooooTOmoOgl2o`00037o
IVIV0_l0001iogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003oooooooooo`02ooooo`05oa0@
4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`04oooooi?oOgmo0_l0000]ofIVIP;o
0000NomoOgl6ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000Kooooo0ol00004oooooiGoOgmo1Ol0000UofIVIP?o0000OOmoOgl4ooooo`?o
00000Oooool000[ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooooooool01?oooonJogmoO`Oo00006OmVIVH5o`00083oOgmo1_ooool1o`00007o
oooo000:ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03
o`000?oooooooooo00CoooooXOmoOgl8o`0000CoIVIV3Ol00025ogmoO`Kooooo0Ol00001ooooo`00
2_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003o
ooooooooo`04ooooojWoOgmo1?l0002BogmoO`Kooooo0Ol00001ooooo`002?ooool00omEEEGoIVIV
o`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo
1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Oooooooogmo
Od3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Ooo
ooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo0007ooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo0007ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo0008ooooo`03oiRHV?lQ8B7ok^k^00Cooooo
00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`002Oooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool0
00001_ooool3o`0000CooooooomoOgm0ogmoO`Cooooo0ol00001ooooo`002_ooool00omgMgOoIVIV
ooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool000_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo00Cooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo0007ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo0007ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000Gooooo
oomoOgm0ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`00
00GooooooomoOgm0ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`001oooool01OnHV9So410@o`000?lb<S;oc<c<
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`001oooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`002oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool01?oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000[ooooo00?oZJVY
oa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo0ol00004ooooooooOgmo@?mo
Ogl4ooooo`?o00000Oooool000Wooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooo
oooo000000Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000:
ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`001oooool01Ol@413oV9RHoooooonj
^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`001oooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo0_l00005ooooooooOgmo@?moOgl5oooo
o`;o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo0_l00005ooooooooOgmo@?mo
Ogl5ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool000Wooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP06oooo
o`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`04oooo
ooooOgmo@?moOgl6ooooo`7o00000Oooool000Oooooo1Ol00003ooooo`05oa0@4?oooooooooooooo
ool@41001_ooool3o`0000CooooooomoOgm0ogmoO`Cooooo0ol00001ooooo`001oooool01?m4A4Co
gMgMooooool00004ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3o
oooood[ooooo0Ol00001ooooo`001oooool01?oMgMgoEEEEooooool00004ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`3ooooood[ooooo0Ol00001ooooo`002?ooool0
0omgMgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003ooooooooo
o`3ooooood[ooooo0Ol00001ooooo`002?ooool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooood[ooooo0Ol00001ooooo`002Oooool0
0omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003ooooooooo
o`0Sooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0?Oooool00ol0003ooooooooo
o`0mooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool08oooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool1o`00007ooooo000Joooo
oooo0000C_l00001ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-30.1723, -14.304, 0.195672, \
0.195672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0192308 0.211538 0.0192308 [
[.11538 -0.0125 -9 -9 ]
[.11538 -0.0125 9 0 ]
[.30769 -0.0125 -9 -9 ]
[.30769 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69231 -0.0125 -6 -9 ]
[.69231 -0.0125 6 0 ]
[.88462 -0.0125 -6 -9 ]
[.88462 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -18 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .21154 -6 -4.5 ]
[-0.0125 .21154 0 4.5 ]
[-0.0125 .40385 -12 -4.5 ]
[-0.0125 .40385 0 4.5 ]
[-0.0125 .59615 -12 -4.5 ]
[-0.0125 .59615 0 4.5 ]
[-0.0125 .78846 -12 -4.5 ]
[-0.0125 .78846 0 4.5 ]
[-0.0125 .98077 -12 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11538 0 m
.11538 .00625 L
s
[(-20)] .11538 -0.0125 0 1 Mshowa
.30769 0 m
.30769 .00625 L
s
[(-10)] .30769 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69231 0 m
.69231 .00625 L
s
[(10)] .69231 -0.0125 0 1 Mshowa
.88462 0 m
.88462 .00625 L
s
[(20)] .88462 -0.0125 0 1 Mshowa
.125 Mabswid
.15385 0 m
.15385 .00375 L
s
.19231 0 m
.19231 .00375 L
s
.23077 0 m
.23077 .00375 L
s
.26923 0 m
.26923 .00375 L
s
.34615 0 m
.34615 .00375 L
s
.38462 0 m
.38462 .00375 L
s
.42308 0 m
.42308 .00375 L
s
.46154 0 m
.46154 .00375 L
s
.53846 0 m
.53846 .00375 L
s
.57692 0 m
.57692 .00375 L
s
.61538 0 m
.61538 .00375 L
s
.65385 0 m
.65385 .00375 L
s
.73077 0 m
.73077 .00375 L
s
.76923 0 m
.76923 .00375 L
s
.80769 0 m
.80769 .00375 L
s
.84615 0 m
.84615 .00375 L
s
.07692 0 m
.07692 .00375 L
s
.03846 0 m
.03846 .00375 L
s
.92308 0 m
.92308 .00375 L
s
.96154 0 m
.96154 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(-10)] -0.0125 .01923 1 0 Mshowa
0 .21154 m
.00625 .21154 L
s
[(0)] -0.0125 .21154 1 0 Mshowa
0 .40385 m
.00625 .40385 L
s
[(10)] -0.0125 .40385 1 0 Mshowa
0 .59615 m
.00625 .59615 L
s
[(20)] -0.0125 .59615 1 0 Mshowa
0 .78846 m
.00625 .78846 L
s
[(30)] -0.0125 .78846 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(40)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .05769 m
.00375 .05769 L
s
0 .09615 m
.00375 .09615 L
s
0 .13462 m
.00375 .13462 L
s
0 .17308 m
.00375 .17308 L
s
0 .25 m
.00375 .25 L
s
0 .28846 m
.00375 .28846 L
s
0 .32692 m
.00375 .32692 L
s
0 .36538 m
.00375 .36538 L
s
0 .44231 m
.00375 .44231 L
s
0 .48077 m
.00375 .48077 L
s
0 .51923 m
.00375 .51923 L
s
0 .55769 m
.00375 .55769 L
s
0 .63462 m
.00375 .63462 L
s
0 .67308 m
.00375 .67308 L
s
0 .71154 m
.00375 .71154 L
s
0 .75 m
.00375 .75 L
s
0 .82692 m
.00375 .82692 L
s
0 .86538 m
.00375 .86538 L
s
0 .90385 m
.00375 .90385 L
s
0 .94231 m
.00375 .94231 L
s
.25 Mabswid
0 0 m
0 1 L
s
.11538 .99375 m
.11538 1 L
s
.30769 .99375 m
.30769 1 L
s
.5 .99375 m
.5 1 L
s
.69231 .99375 m
.69231 1 L
s
.88462 .99375 m
.88462 1 L
s
.125 Mabswid
.15385 .99625 m
.15385 1 L
s
.19231 .99625 m
.19231 1 L
s
.23077 .99625 m
.23077 1 L
s
.26923 .99625 m
.26923 1 L
s
.34615 .99625 m
.34615 1 L
s
.38462 .99625 m
.38462 1 L
s
.42308 .99625 m
.42308 1 L
s
.46154 .99625 m
.46154 1 L
s
.53846 .99625 m
.53846 1 L
s
.57692 .99625 m
.57692 1 L
s
.61538 .99625 m
.61538 1 L
s
.65385 .99625 m
.65385 1 L
s
.73077 .99625 m
.73077 1 L
s
.76923 .99625 m
.76923 1 L
s
.80769 .99625 m
.80769 1 L
s
.84615 .99625 m
.84615 1 L
s
.07692 .99625 m
.07692 1 L
s
.03846 .99625 m
.03846 1 L
s
.92308 .99625 m
.92308 1 L
s
.96154 .99625 m
.96154 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .21154 m
1 .21154 L
s
.99375 .40385 m
1 .40385 L
s
.99375 .59615 m
1 .59615 L
s
.99375 .78846 m
1 .78846 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .05769 m
1 .05769 L
s
.99625 .09615 m
1 .09615 L
s
.99625 .13462 m
1 .13462 L
s
.99625 .17308 m
1 .17308 L
s
.99625 .25 m
1 .25 L
s
.99625 .28846 m
1 .28846 L
s
.99625 .32692 m
1 .32692 L
s
.99625 .36538 m
1 .36538 L
s
.99625 .44231 m
1 .44231 L
s
.99625 .48077 m
1 .48077 L
s
.99625 .51923 m
1 .51923 L
s
.99625 .55769 m
1 .55769 L
s
.99625 .63462 m
1 .63462 L
s
.99625 .67308 m
1 .67308 L
s
.99625 .71154 m
1 .71154 L
s
.99625 .75 m
1 .75 L
s
.99625 .82692 m
1 .82692 L
s
.99625 .86538 m
1 .86538 L
s
.99625 .90385 m
1 .90385 L
s
.99625 .94231 m
1 .94231 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.4 g
.4117 .27404 m
.43132 .27261 L
.45094 .27196 L
.47057 .27261 L
.49019 .27343 L
.50981 .27414 L
.514 .27433 L
.52943 .2746 L
.54906 .27474 L
.56868 .27456 L
.58141 .27433 L
.5883 .27407 L
.60793 .27335 L
.62755 .27254 L
.64717 .27419 L
.6668 .27254 L
.68551 .27433 L
.68642 .2746 L
.70165 .29396 L
.68642 .30814 L
.67537 .31358 L
.6668 .31663 L
.64717 .32307 L
.62755 .32827 L
.60793 .33205 L
.5883 .33035 L
.56868 .33134 L
.54906 .33168 L
.52943 .3314 L
.50981 .33048 L
.49019 .33235 L
.47057 .32871 L
.45094 .32365 L
.43132 .3173 L
.4207 .31358 L
.4117 .30929 L
.3944 .29396 L
.41071 .27433 L
F
0 g
.4117 .27404 m
.43132 .27261 L
.45094 .27196 L
.47057 .27261 L
.49019 .27343 L
.50981 .27414 L
.514 .27433 L
.52943 .2746 L
.54906 .27474 L
.56868 .27456 L
.58141 .27433 L
.5883 .27407 L
.60793 .27335 L
.62755 .27254 L
.64717 .27419 L
.6668 .27254 L
.68551 .27433 L
.68642 .2746 L
.70165 .29396 L
.68642 .30814 L
.67537 .31358 L
.6668 .31663 L
.64717 .32307 L
.62755 .32827 L
.60793 .33205 L
.5883 .33035 L
.56868 .33134 L
.54906 .33168 L
.52943 .3314 L
.50981 .33048 L
.49019 .33235 L
.47057 .32871 L
.45094 .32365 L
.43132 .3173 L
.4207 .31358 L
.4117 .30929 L
.3944 .29396 L
.41071 .27433 L
.4117 .27404 L
s
.6 g
.4117 .22423 m
.43132 .21808 L
.45094 .21634 L
.47057 .21605 L
.49019 .21627 L
.50981 .21661 L
.52943 .21687 L
.54906 .21696 L
.56868 .21685 L
.5883 .21658 L
.60793 .21624 L
.62755 .21605 L
.64717 .21643 L
.6668 .21841 L
.68642 .22551 L
.69246 .23509 L
.68642 .24491 L
.67109 .25471 L
.6668 .25788 L
.64717 .26989 L
.62755 .2654 L
.60793 .26788 L
.5883 .26955 L
.56868 .27053 L
.54906 .27087 L
.52943 .27059 L
.50981 .26968 L
.49019 .26808 L
.47057 .26569 L
.45094 .26226 L
.43132 .25911 L
.42511 .25471 L
.4117 .24667 L
.40369 .23509 L
F
0 g
.4117 .22423 m
.43132 .21808 L
.45094 .21634 L
.47057 .21605 L
.49019 .21627 L
.50981 .21661 L
.52943 .21687 L
.54906 .21696 L
.56868 .21685 L
.5883 .21658 L
.60793 .21624 L
.62755 .21605 L
.64717 .21643 L
.6668 .21841 L
.68642 .22551 L
.69246 .23509 L
.68642 .24491 L
.67109 .25471 L
.6668 .25788 L
.64717 .26989 L
.62755 .2654 L
.60793 .26788 L
.5883 .26955 L
.56868 .27053 L
.54906 .27087 L
.52943 .27059 L
.50981 .26968 L
.49019 .26808 L
.47057 .26569 L
.45094 .26226 L
.43132 .25911 L
.42511 .25471 L
.4117 .24667 L
.40369 .23509 L
.4117 .22423 L
s
.6 g
.4117 .34247 m
.43132 .33535 L
.45094 .33439 L
.47057 .33476 L
.49019 .33547 L
.50981 .33612 L
.52943 .33655 L
.54906 .3367 L
.56868 .33652 L
.5883 .33606 L
.60793 .33539 L
.62755 .3347 L
.64717 .3344 L
.6668 .33561 L
.68642 .34512 L
.68718 .35283 L
.68642 .35429 L
.6668 .37019 L
.66209 .37245 L
.64717 .37743 L
.62755 .38348 L
.60793 .38784 L
.5883 .39042 L
.56868 .39156 L
.54906 .39184 L
.52943 .39161 L
.50981 .39059 L
.49019 .38817 L
.47057 .384 L
.45094 .37809 L
.434 .37245 L
.43132 .3712 L
.4117 .35701 L
.40907 .35283 L
F
0 g
.4117 .34247 m
.43132 .33535 L
.45094 .33439 L
.47057 .33476 L
.49019 .33547 L
.50981 .33612 L
.52943 .33655 L
.54906 .3367 L
.56868 .33652 L
.5883 .33606 L
.60793 .33539 L
.62755 .3347 L
.64717 .3344 L
.6668 .33561 L
.68642 .34512 L
.68718 .35283 L
.68642 .35429 L
.6668 .37019 L
.66209 .37245 L
.64717 .37743 L
.62755 .38348 L
.60793 .38784 L
.5883 .39042 L
.56868 .39156 L
.54906 .39184 L
.52943 .39161 L
.50981 .39059 L
.49019 .38817 L
.47057 .384 L
.45094 .37809 L
.434 .37245 L
.43132 .3712 L
.4117 .35701 L
.40907 .35283 L
.4117 .34247 L
s
.3 g
.45094 .2832 m
.47057 .27999 L
.49019 .27894 L
.50981 .27864 L
.52943 .2786 L
.54906 .2786 L
.56868 .2786 L
.5883 .27865 L
.60793 .27899 L
.62755 .28017 L
.64717 .28379 L
.66116 .29396 L
.64717 .30988 L
.64009 .31358 L
.62755 .32072 L
.60793 .32929 L
.5883 .32521 L
.56868 .32673 L
.54906 .32725 L
.52943 .32683 L
.50981 .32541 L
.49019 .33003 L
.47057 .32169 L
.45604 .31358 L
.45094 .31102 L
.43497 .29396 L
F
0 g
.45094 .2832 m
.47057 .27999 L
.49019 .27894 L
.50981 .27864 L
.52943 .2786 L
.54906 .2786 L
.56868 .2786 L
.5883 .27865 L
.60793 .27899 L
.62755 .28017 L
.64717 .28379 L
.66116 .29396 L
.64717 .30988 L
.64009 .31358 L
.62755 .32072 L
.60793 .32929 L
.5883 .32521 L
.56868 .32673 L
.54906 .32725 L
.52943 .32683 L
.50981 .32541 L
.49019 .33003 L
.47057 .32169 L
.45604 .31358 L
.45094 .31102 L
.43497 .29396 L
.45094 .2832 L
s
.4 g
.45094 .17298 m
.47057 .16827 L
.49019 .16472 L
.50981 .16651 L
.52943 .1673 L
.54906 .16753 L
.56868 .16725 L
.5883 .1664 L
.60793 .16442 L
.62755 .16857 L
.64717 .17378 L
.6518 .17622 L
.65008 .19584 L
.64717 .19712 L
.62755 .2029 L
.60793 .20642 L
.5883 .20866 L
.56868 .20992 L
.54906 .21036 L
.52943 .21 L
.50981 .20882 L
.49019 .2067 L
.47057 .20333 L
.45094 .19787 L
.44612 .19584 L
.44436 .17622 L
F
0 g
.45094 .17298 m
.47057 .16827 L
.49019 .16472 L
.50981 .16651 L
.52943 .1673 L
.54906 .16753 L
.56868 .16725 L
.5883 .1664 L
.60793 .16442 L
.62755 .16857 L
.64717 .17378 L
.6518 .17622 L
.65008 .19584 L
.64717 .19712 L
.62755 .2029 L
.60793 .20642 L
.5883 .20866 L
.56868 .20992 L
.54906 .21036 L
.52943 .21 L
.50981 .20882 L
.49019 .2067 L
.47057 .20333 L
.45094 .19787 L
.44612 .19584 L
.44436 .17622 L
.45094 .17298 L
s
.7 g
.45094 .23309 m
.47057 .22634 L
.49019 .22389 L
.50981 .22284 L
.52943 .22241 L
.54906 .2223 L
.56868 .22244 L
.5883 .22291 L
.60793 .22405 L
.62755 .22672 L
.64717 .23455 L
.64776 .23509 L
.64717 .24479 L
.63525 .25471 L
.62755 .25743 L
.60793 .26205 L
.5883 .26482 L
.56868 .26635 L
.54906 .26687 L
.52943 .26644 L
.50981 .26502 L
.49019 .2624 L
.47057 .25801 L
.46089 .25471 L
.45094 .2474 L
.44841 .23509 L
F
0 g
.45094 .23309 m
.47057 .22634 L
.49019 .22389 L
.50981 .22284 L
.52943 .22241 L
.54906 .2223 L
.56868 .22244 L
.5883 .22291 L
.60793 .22405 L
.62755 .22672 L
.64717 .23455 L
.64776 .23509 L
.64717 .24479 L
.63525 .25471 L
.62755 .25743 L
.60793 .26205 L
.5883 .26482 L
.56868 .26635 L
.54906 .26687 L
.52943 .26644 L
.50981 .26502 L
.49019 .2624 L
.47057 .25801 L
.46089 .25471 L
.45094 .2474 L
.44841 .23509 L
.45094 .23309 L
s
.7 g
.47057 .34804 m
.49019 .34435 L
.50981 .34312 L
.52943 .34268 L
.54906 .34258 L
.56868 .34271 L
.5883 .34319 L
.60793 .34455 L
.62755 .34877 L
.63406 .35283 L
.62755 .36381 L
.61042 .37245 L
.60793 .3738 L
.5883 .38212 L
.56868 .38711 L
.54906 .38894 L
.52943 .38744 L
.50981 .38276 L
.49019 .37481 L
.48572 .37245 L
.47057 .36519 L
.46209 .35283 L
F
0 g
.47057 .34804 m
.49019 .34435 L
.50981 .34312 L
.52943 .34268 L
.54906 .34258 L
.56868 .34271 L
.5883 .34319 L
.60793 .34455 L
.62755 .34877 L
.63406 .35283 L
.62755 .36381 L
.61042 .37245 L
.60793 .3738 L
.5883 .38212 L
.56868 .38711 L
.54906 .38894 L
.52943 .38744 L
.50981 .38276 L
.49019 .37481 L
.48572 .37245 L
.47057 .36519 L
.46209 .35283 L
.47057 .34804 L
s
.2 g
.47057 .28934 m
.49019 .28505 L
.50981 .28343 L
.52943 .28278 L
.54906 .28262 L
.56868 .28282 L
.5883 .28353 L
.60793 .28531 L
.62755 .29013 L
.63371 .29396 L
.62755 .30645 L
.61475 .31358 L
.60793 .31881 L
.5883 .31987 L
.56868 .32204 L
.54906 .32276 L
.52943 .32217 L
.50981 .32016 L
.49019 .32021 L
.4814 .31358 L
.47057 .30789 L
.46244 .29396 L
F
0 g
.47057 .28934 m
.49019 .28505 L
.50981 .28343 L
.52943 .28278 L
.54906 .28262 L
.56868 .28282 L
.5883 .28353 L
.60793 .28531 L
.62755 .29013 L
.63371 .29396 L
.62755 .30645 L
.61475 .31358 L
.60793 .31881 L
.5883 .31987 L
.56868 .32204 L
.54906 .32276 L
.52943 .32217 L
.50981 .32016 L
.49019 .32021 L
.4814 .31358 L
.47057 .30789 L
.46244 .29396 L
.47057 .28934 L
s
.8 g
.49019 .2325 m
.50981 .22938 L
.52943 .22809 L
.54906 .22775 L
.56868 .22817 L
.5883 .22958 L
.60793 .233 L
.61424 .23509 L
.60867 .25471 L
.60793 .25495 L
.5883 .2595 L
.56868 .26178 L
.54906 .26252 L
.52943 .26191 L
.50981 .25981 L
.49019 .25556 L
.48748 .25471 L
.4819 .23509 L
F
0 g
.49019 .2325 m
.50981 .22938 L
.52943 .22809 L
.54906 .22775 L
.56868 .22817 L
.5883 .22958 L
.60793 .233 L
.61424 .23509 L
.60867 .25471 L
.60793 .25495 L
.5883 .2595 L
.56868 .26178 L
.54906 .26252 L
.52943 .26191 L
.50981 .25981 L
.49019 .25556 L
.48748 .25471 L
.4819 .23509 L
.49019 .2325 L
s
.4 g
.49019 .41051 m
.50981 .40838 L
.52943 .40769 L
.54906 .40753 L
.56868 .40773 L
.5883 .4085 L
.60793 .41091 L
.61111 .4117 L
.60793 .42433 L
.5883 .43131 L
.58828 .43132 L
.56868 .43494 L
.54906 .43609 L
.52943 .43516 L
.50981 .43266 L
.50778 .43132 L
.49019 .42535 L
.485 .4117 L
F
0 g
.49019 .41051 m
.50981 .40838 L
.52943 .40769 L
.54906 .40753 L
.56868 .40773 L
.5883 .4085 L
.60793 .41091 L
.61111 .4117 L
.60793 .42433 L
.5883 .43131 L
.58828 .43132 L
.56868 .43494 L
.54906 .43609 L
.52943 .43516 L
.50981 .43266 L
.50778 .43132 L
.49019 .42535 L
.485 .4117 L
.49019 .41051 L
s
.1 g
.49019 .29327 m
.50981 .28898 L
.52943 .28744 L
.54906 .28704 L
.56868 .28753 L
.5883 .28923 L
.60763 .29396 L
.58887 .31358 L
.5883 .31371 L
.56868 .31689 L
.54906 .31789 L
.52943 .31707 L
.50981 .31415 L
.50717 .31358 L
.49019 .30553 L
.48852 .29396 L
F
0 g
.49019 .29327 m
.50981 .28898 L
.52943 .28744 L
.54906 .28704 L
.56868 .28753 L
.5883 .28923 L
.60763 .29396 L
.58887 .31358 L
.5883 .31371 L
.56868 .31689 L
.54906 .31789 L
.52943 .31707 L
.50981 .31415 L
.50717 .31358 L
.49019 .30553 L
.48852 .29396 L
.49019 .29327 L
s
.3 g
.50981 .18451 m
.52943 .18066 L
.54906 .1798 L
.56868 .18087 L
.5883 .18529 L
.59144 .19584 L
.5883 .19675 L
.56868 .20027 L
.54906 .20132 L
.52943 .20046 L
.50981 .19726 L
.50461 .19584 L
F
0 g
.50981 .18451 m
.52943 .18066 L
.54906 .1798 L
.56868 .18087 L
.5883 .18529 L
.59144 .19584 L
.5883 .19675 L
.56868 .20027 L
.54906 .20132 L
.52943 .20046 L
.50981 .19726 L
.50461 .19584 L
.50981 .18451 L
s
.9 g
.52943 .23474 m
.54906 .23399 L
.56868 .23492 L
.57105 .23509 L
.58164 .25471 L
.56868 .25626 L
.54906 .25741 L
.52943 .25648 L
.51352 .25471 L
.52371 .23509 L
F
0 g
.52943 .23474 m
.54906 .23399 L
.56868 .23492 L
.57105 .23509 L
.58164 .25471 L
.56868 .25626 L
.54906 .25741 L
.52943 .25648 L
.51352 .25471 L
.52371 .23509 L
.52943 .23474 L
s
.8 g
.52943 .35093 m
.54906 .3503 L
.56868 .35108 L
.58476 .35283 L
.56868 .36789 L
.54906 .36977 L
.52943 .36825 L
.51415 .35283 L
F
0 g
.52943 .35093 m
.54906 .3503 L
.56868 .35108 L
.58476 .35283 L
.56868 .36789 L
.54906 .36977 L
.52943 .36825 L
.51415 .35283 L
.52943 .35093 L
s
.52943 .29328 m
.54906 .29244 L
.56868 .29349 L
.57398 .29396 L
.56868 .30927 L
.54906 .31149 L
.52943 .30971 L
.52064 .29396 L
F
.52943 .29328 m
.54906 .29244 L
.56868 .29349 L
.57398 .29396 L
.56868 .30927 L
.54906 .31149 L
.52943 .30971 L
.52064 .29396 L
.52943 .29328 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00?Oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0dooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kS?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0hooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8b
onk^kS?ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08_ooool003gooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0=_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0<oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg03?ooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL08_ooool003Gooooo1_l0
0003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400[ooooo`Ko0000
1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100<oooool01Ol@413o
oooooooooooooooo410@03[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@03Cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@02;ooooo000o
ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000fooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000cooooo`05o`000?ooooooooooooooool0
0000>_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000=Oooool00onH
V9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000008_ooool0043ooooo00?oMgMgofIV
I_ooool00_ooool01Ol0003ooooooooooooooooo000003Kooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000003?ooooo00Go0000ooooooooooooooooo`00000jooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`03ogMgMomVIVKooooo00;o
oooo00Go0000ooooooooooooooooo`00000Rooooo`00@Oooool01Ol0003ooooooooooooooooo410@
00?ooooo00?o410@ooooooooool0=?ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@4100<oooool01Ol@413ooooooooooooooooo410@03[ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@03Oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo023ooooo000mooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg03Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg03?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0jooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0cooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02;ooooo000mooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^03Cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^03?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`03oeEEEOmVIVKo000000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0cooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02;ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo000Joooooooo0000C_l00001ooooo`00
6_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0?Ooo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool08ooo
ool1o`00007ooooo0008ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKo
oooo00?o0000ooooooooool0oooooom:ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooom:ooooo`7o
00000Oooool000Go00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41001_ooool00ol0003oooooooooo`3ooooood[ooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?ooooooB?ooool3o`00007o
oooo000:ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo0008ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Oooooooogmo
Od3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Ooo
ooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonJogmo
O`Oo00007omoOgl6o`0007WoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
ooooUomoOgl3o`0000OoIVIV7ol00006ofIVIP?o0000M_moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?oooonBogmoO`Go0000<_mVIVH5o`00077oOgmo1_ooool1o`00007ooooo
000Jooooo`;o00001Ooooon>ogmoO`Co0000??mVIVH4o`0006goOgmo1Oooool2o`00007ooooo000J
ooooo`03o`000?oooooooooo00CoooooSOmoOgl00ol0003oIVIVofIVIP12ofIVIP03o`000?moOgoo
Ogmo06[oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooSOmoOgl00ol0
003oIVIVofIVIP0MofIVIPOo00007_mVIVH00ol0003oOgmoogmoO`1ZogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooohgoOgmo00?o0000ofIVI_mVIVH05_mVIVH7o`0000Oo
C4a<1ol0000GofIVIP03o`000?moOgooOgmo06[oOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CoooooSOmoOgl00ol0003oIVIVofIVIP0CofIVIP?o00005Om<C4`3o`0001CoIVIV
00?o0000ogmoOomoOgl0J_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
oon=ogmoO`03o`000?mVIVKoIVIV01?oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIV
IP0AofIVIP03o`000?moOgooOgmo06_oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CoooooSOmoOgl00ol0003oIVIVofIVIP0BofIVIP03o`000?m<C4coC4a<01SoC4a<00?o0000
ofIVI_mVIVH04OmVIVH00ol0003oOgmoogmoO`1[ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooohgoOgmo00?o0000ofIVI_mVIVH04_mVIVH00ol0003oC4a<oda<C00Ioda<
C003o`000?mVIVKoIVIV013oIVIV00?o0000ogmoOomoOgl0JomoOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?oooon=ogmoO`Go00003omVIVH6o`0001?oC4a<1Ol0000@ofIVIP?o
0000KOmoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonBogmoO`?o0000
4_mVIVHCo`0001;oIVIV0ol0001`ogmoO`Kooooo0Ol00001ooooo`003oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Kooooo00?o0000ooooooooool01?oooonEogmoO`Go0000;OmVIVH5o`0007?oOgmo
1_ooool1o`00007ooooo000?ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003ooooo
ooooo`04oooooi[oOgmo1ol0000OofIVIPOo0000N?moOgl6ooooo`7o00000Oooool000oooooo00Go
410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00CoooooXOmoOglOo`0007ooOgmo
1_ooool1o`00007ooooo000?ooooo`05o`000?ooooooooooooooool000001_ooool3o`0000Cooooo
oomoOgm0ogmoO`Cooooo0ol00001ooooo`003oooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool01?oooon<ogmoOaGo00007omoOgl>o`00077oOgmo1_ooool1o`00007ooooo
000?ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`04ooooohOoOgmo
1Ol0000EoiVIVAoo00003_nIVIT;o`0006KoOgmo1_ooool1o`00007ooooo000?ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`04ooooohCoOgmo0ol0000OoiVIVAGo0000
7_nIVIT2o`0006CoOgmo1_ooool1o`00007ooooo000?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1_ooool00ol0003oooooooooo`04oooooh;oOgmo0_l0000EoiVIV@go00005Onc/k<=o`0001?oVIVI
0_l0001RogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooh;oOgmo00?o
0000oiVIVOnIVIT03onIVIT5o`0000go/k>c5Ol0000=ok>c/`Co00004OnIVIT00ol0003oOgmoogmo
O`1OogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooh7oOgmo00?o0000
oiVIVOnIVIT03OnIVIT3o`0000co/k>c1_l0000Eolc<c0Ko00002onc/k<2o`0000ooVIVI00?o0000
ogmoOomoOgl0GomoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon0ogmo
O`03o`000?nIVIWoVIVI00coVIVI0_l0000:ok>c/`Go00003Oo<c<`7o`0000goc<c<1?l00009ok>c
/`;o00003_nIVIT00ol0003oOgmoogmoO`1NogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooogooOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`08ok>c/`;o
00003?o<c<`6o`0000Ooi^KV1?l0000=olc<c003o`000?nc/k?o/k>c00So/k>c00?o0000oiVIVOnI
VIT03?nIVIT00ol0003oOgmoogmoO`1MogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooogooOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`08ok>c/`03o`00
0?o<c<coc<c<00_oc<c<00?o0000onKVi_oVi^H03OoVi^H00ol0003oc<c<olc<c00;olc<c003o`00
0?nc/k?o/k>c00So/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`1MogmoO`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooh3oOgmo00?o0000oiVIVOnIVIT02onI
VIT00ol0003o/k>cok>c/`09ok>c/`03o`000?o<c<coc<c<00Woc<c<00?o0000onKVi_oVi^H03ooV
i^H00ol0003oc<c<olc<c009olc<c003o`000?nc/k?o/k>c00Wo/k>c00?o0000oiVIVOnIVIT02onI
VIT00ol0003oOgmoogmoO`1NogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
oooooh7oOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`08ok>c/`03o`000?o<c<co
c<c<00Woc<c<00?o0000onKVi_oVi^H03ooVi^H00ol0003oc<c<olc<c009olc<c003o`000?nc/k?o
/k>c00So/k>c0_l0000;oiVIV@;o0000HOmoOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?oooon2ogmoO`;o00002onIVIT2o`0000Wo/k>c00?o0000olc<c?o<c<`02?o<c<`00ol0
003oi^KVonKViP0AonKViP03o`000?o<c<coc<c<00Soc<c<00?o0000ok>c/onc/k<01onc/k<00ol0
003oVIVIoiVIV@09oiVIV@;o0000HomoOgl6ooooo`7o00000Oooool001[ooooo0_l00005ooooohCo
Ogmo0_l0000;oiVIV@03o`000?nc/k?o/k>c00Oo/k>c00?o0000olc<c?o<c<`01oo<c<`00ol0003o
i^KVonKViP0AonKViP03o`000?o<c<coc<c<00Ooc<c<00?o0000ok>c/onc/k<01onc/k<00ol0003o
VIVIoiVIV@09oiVIV@03o`000?moOgooOgmo06?oOgmo1Oooool2o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CoooooQ_moOgl00ol0003oVIVIoiVIV@09oiVIV@?o00001_nc/k<4o`0000Goc<c<
1?l0000@onKViP?o00001oo<c<`2o`0000Oo/k>c0_l0000;oiVIV@03o`000?moOgooOgmo06CoOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooQomoOgl00ol0003oVIVIoiVI
V@0;oiVIV@?o00001onc/k<3o`0000Koc<c<4?l00007olc<c0?o00001_nc/k<3o`0000_oVIVI0_l0
001WogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooohSoOgmo1Ol0000;
oiVIV@?o00001onc/k<5o`0001?oc<c<1Ol00006ok>c/`?o00003?nIVIT2o`0006WoOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooSOmoOgl6o`0000SoVIVI1_l00006ok>c
/a?o00001_nc/k<5o`0000koVIVI00?o0000ogmoOomoOgl0JOmoOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?oooonCogmoO`Oo00001onIVITOo`0000OoVIVI1ol00003oiVIV@;o
0000K?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonJogmoOaCo0000
1OnIVITDo`0000OoOgmo0ol0001^ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooohGoOgmo7?l0000=ogmoO`Go00003OmoOgl>o`0000KoOgmo1ol0001TogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04oooooh;oOgmo0ol0000LofIVIQoo00003_mVIVH6
o`0000OoIVIV0ol0001QogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
oh7oOgmo00?o0000ofIVI_mVIVH05OmVIVH_o`0001GoIVIV00?o0000ogmoOomoOgl0GomoOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon0ogmoO`03o`000?mVIVKoIVIV00oo
IVIV1ol0000Doda<C0Oo00005?m<C4`6o`00013oIVIV00?o0000ogmoOomoOgl0G_moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?oooomoogmoO`03o`000?mVIVKoIVIV00coIVIV
1?l00008oda<C1?o00001olc<c<Bo`0000SoC4a<1?l0000=ofIVIP03o`000?moOgooOgmo05goOgmo
1_ooool1o`00007ooooo000Jooooo`;o00001OoooomnogmoO`03o`000?mVIVKoIVIV00_oIVIV0_l0
0009oda<C0?o00003?lc<c<Eo`0000_o<c<c0ol00009oda<C0;o00003?mVIVH00ol0003oOgmoogmo
O`1LogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04oooooggoOgmo00?o0000
ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C006oda<C0?o00002Olc<c<6o`0001Go6ATI1_l00008
oc<c<`?o00002?m<C4`00ol0003oIVIVofIVIP0:ofIVIP03o`000?moOgooOgmo05_oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooO?moOgl2o`0000coIVIV00?o0000oda<
C?m<C4`01_m<C4`00ol0003o<c<coc<c<`05oc<c<`Go00001_lI6ATCo`0000So6ATI0ol00008oc<c
<`03o`000?m<C4coC4a<00KoC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`1Jogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooogkoOgmo00?o0000ofIVI_mV
IVH02OmVIVH00ol0003oC4a<oda<C006oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oaTI6OlI
6AT02?lI6ATCo`0000[o6ATI00?o0000oc<c<olc<c<01_lc<c<00ol0003oC4a<oda<C006oda<C003
o`000?mVIVKoIVIV00WoIVIV00?o0000ogmoOomoOgl0FomoOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?oooomoogmoO`03o`000?mVIVKoIVIV00WoIVIV00?o0000oda<C?m<C4`0
1_m<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?lI6AWo6ATI00Wo6ATI4Ol0000:oaTI6@03o`00
0?lc<c?o<c<c00Ko<c<c00?o0000oda<C?m<C4`01_m<C4`00ol0003oIVIVofIVIP09ofIVIP03o`00
0?moOgooOgmo05coOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooP?mo
Ogl00ol0003oIVIVofIVIP09ofIVIP03o`000?m<C4coC4a<00GoC4a<00?o0000oc<c<olc<c<01Olc
<c<00ol0003o6ATIoaTI6@09oaTI6A3o00002OlI6AT00ol0003o<c<coc<c<`07oc<c<`03o`000?m<
C4coC4a<00GoC4a<00?o0000ofIVI_mVIVH02OmVIVH00ol0003oOgmoogmoO`1MogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04oooooh7oOgmo00?o0000ofIVI_mVIVH02OmVIVH0
0ol0003oC4a<oda<C004oda<C003o`000?lc<c?o<c<c00Go<c<c0_l0000:oaTI6A3o00002?lI6AT0
0ol0003o<c<coc<c<`06oc<c<`;o00001om<C4`00ol0003oIVIVofIVIP09ofIVIP03o`000?moOgoo
Ogmo05koOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooP_moOgl2o`00
00[oIVIV00?o0000oda<C?m<C4`01?m<C4`2o`0000Oo<c<c0_l00009oaTI6@ko00002?lI6AT00ol0
003o<c<coc<c<`05oc<c<`;o00002?m<C4`00ol0003oIVIVofIVIP08ofIVIP;o0000HOmoOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon4ogmoO`03o`000?mVIVKoIVIV00So
IVIV0_l00006oda<C0;o00001olc<c<2o`0000co6ATI1Ol0000;oaTI6@03o`000?lc<c?o<c<c00Go
<c<c00?o0000oda<C?m<C4`01_m<C4`2o`0000[oIVIV00?o0000ogmoOomoOgl0HOmoOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?oooon5ogmoO`?o00002OmVIVH2o`0000KoC4a<
0_l00007oc<c<`Go00004olI6AT4o`0000Oo<c<c00?o0000oda<C?m<C4`01Om<C4`2o`0000[oIVIV
0_l0001TogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooohSoOgmo0ol0
0008ofIVIP;o00001_m<C4`00ol0003o<c<coc<c<`09oc<c<a?o00002_lc<c<00ol0003oC4a<oda<
C004oda<C0;o00002?mVIVH4o`0006KoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CoooooRomoOgl3o`0000OoIVIV0_l00005oda<C0_o00004olc<c<:o`0000GoC4a<0_l00007
ofIVIP?o0000J_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon>ogmo
O`Co00001OmVIVH3o`0000goC4a<4ol0000<oda<C0?o00001_mVIVH3o`0006goOgmo1_ooool1o`00
007ooooo000Jooooo`;o00001OoooonBogmoO`?o00001OmVIVH2o`0000CoC4a<8Ol00003oda<C0;o
00001_mVIVH3o`00073oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
UOmoOgl5o`0000;oIVIV2ol0000CofIVIP[o00000omVIVH5o`0007?oOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CoooooV_moOgl6o`0000OoOgmo4ol00007ogmoO`Ko0000N?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon7ogmoOe;o0000I_moOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon4ogmoO`?o0000D_nIVIT2o`00
06CoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooP_moOgl2o`0002;o
VIVI5Ol0000PoiVIV@;o0000H_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?oooon2ogmoO`03o`000?nIVIWoVIVI01CoVIVI3Ol0000Eok>c/`go00005OnIVIT00ol0003oOgmo
ogmoO`1OogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooh;oOgmo00?o
0000oiVIVOnIVIT04?nIVIT4o`0002oo/k>c0ol0000BoiVIV@03o`000?moOgooOgmo05ooOgmo1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooPOmoOgl00ol0003oVIVIoiVIV@0@
oiVIV@03o`000?nc/k?o/k>c013o/k>c4ol0000Aok>c/`03o`000?nIVIWoVIVI00ooVIVI00?o0000
ogmoOomoOgl0GomoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon1ogmo
O`03o`000?nIVIWoVIVI00ooVIVI00?o0000ok>c/onc/k<03_nc/k<3o`0001?oc<c<0_l0000@ok>c
/`03o`000?nIVIWoVIVI00koVIVI00?o0000ogmoOomoOgl0GomoOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?oooon2ogmoO`;o00003onIVIT00ol0003o/k>cok>c/`0?ok>c/`03
o`000?o<c<coc<c<01;oc<c<00?o0000ok>c/onc/k<03onc/k<00ol0003oVIVIoiVIV@0=oiVIV@03
o`000?moOgooOgmo063oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
Q?moOgl00ol0003oVIVIoiVIV@0=oiVIV@03o`000?nc/k?o/k>c00oo/k>c00?o0000olc<c?o<c<`0
4?o<c<`00ol0003o/k>cok>c/`0?ok>c/`03o`000?nIVIWoVIVI00goVIVI00?o0000ogmoOomoOgl0
HOmoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon5ogmoO`03o`000?nI
VIWoVIVI00coVIVI00?o0000ok>c/onc/k<04?nc/k<00ol0003oc<c<olc<c00>olc<c003o`000?nc
/k?o/k>c00ko/k>c0_l0000?oiVIV@03o`000?moOgooOgmo06;oOgmo1_ooool1o`00007ooooo000J
ooooo`;o00001Ooooon6ogmoO`03o`000?nIVIWoVIVI00coVIVI0ol0000@ok>c/`03o`000?o<c<co
c<c<00coc<c<00?o0000ok>c/onc/k<03Onc/k<2o`00013oVIVI00?o0000ogmoOomoOgl0HomoOgl5
ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool01?oooon7ogmoO`03o`000?nIVIWoVIVI
00koVIVI0ol0000>ok>c/`ko00003_nc/k<2o`00017oVIVI00?o0000ogmoOomoOgl0I?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon8ogmoO`Co00003onIVIT00ol0003o
/k>cok>c/`0Vok>c/`03o`000?nIVIWoVIVI00goVIVI1?l0001WogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooohcoOgmo0ol0000=oiVIV@;o00009?nc/k<2o`0000goVIVI
0ol0001[ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooohooOgmo0ol0
000<oiVIV@?o00007onc/k<2o`0000goVIVI0_l0001^ogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04oooooi;oOgmo0ol0000<oiVIV@;o00006onc/k<2o`0000coVIVI0ol0001`
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooiGoOgmo0ol0000;oiVI
V@Co00004onc/k<4o`0000WoVIVI1Ol0001cogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04oooooiSoOgmo0ol0000<oiVIV@Oo00001Onc/k<7o`0000KoVIVI1ol0001hogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooi_oOgmo3?l00007oiVIV@Go0000
1onIVIT6o`0007ooOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooYomo
OglCo`0008GoOgmo1_ooool1o`00007ooooo0008ooooo`Co000000So410@ooooooooooook^k^oc8b
<_l0003o<S8bonk^kPKooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000:ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000Kooooo0ol00004ooooooooOgmo@?moOgl4ooooo`?o00000Oooool000[ooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool01?oooonPogmoOb7o0000O_moOgl6ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool01?oooonJogmoO`Ko
00008OmVIVH4o`0007[oOgmo1_ooool1o`00007ooooo000:ooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00CoooooV_moOgl00ol0003o
IVIVofIVIP0WofIVIP03o`000?moOgooOgmo07SoOgmo1_ooool1o`00007ooooo0008ooooo`03oeEE
EOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo00Co
ooooVomoOgl00ol0003oIVIVofIVIP0VofIVIP03o`000?moOgooOgmo07SoOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CoooooVomoOgl00ol0003oIVIVofIVIP0UofIVIP03o`00
0?moOgooOgmo07WoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooVomo
Ogl00ol0003oIVIVofIVIP0UofIVIP03o`000?moOgooOgmo07WoOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CoooooW?moOgl3o`0002?oIVIV0_l0001kogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04oooooiooOgmo0ol0000MofIVIP?o0000OOmoOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonRogmoO`Go00004omVIVH5o`00083o
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooYomoOglCo`0008GoOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`001ooo
ool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`001oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`002?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@
41001_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000Wooooo
00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000Kooooo0ol00004oooooooo
Ogmo@?moOgl4ooooo`?o00000Oooool000[ooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000;ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`04ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`001oooool01Ol0003o^[Zj
oooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`001oooool01OnHV9So410@o`000?lQ8B7oc<c<
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo0_l00005ooooooooOgmo@?moOgl5oooo
o`;o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo0_l00005ooooooooOgmo@?mo
Ogl5ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo0_l00005oooooooo
Ogmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool000Oooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
00Oooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000_ooooo00Go0000
oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000:ooooo`03ojVYZOl@413ooooo00;ooooo00Go0000
ooooooooooooooooo`000006ooooo`?o00001?ooooooogmoOd3oOgmo1?ooool3o`00007ooooo0009
ooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool00onj^[[o8B4Qooooo`02
ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool000Oooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool000Oooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo0009ooooo`;o000000Wo
410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`04oooo
ooooOgmo@?moOgl6ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00
007ooooo0007ooooo`Go00000oooool01Ol@413ooooooooooooooooo410@00Kooooo0ol00004oooo
ooooOgmo@?moOgl4ooooo`?o00000Oooool000Oooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0oooooom:ooooo`7o00000Oooool0
00Oooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o
0000ooooooooool0oooooom:ooooo`7o00000Oooool000Sooooo00?oMgMgolc<c?l000001?ooool0
1Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool0oooooom:ooooo`7o00000Ooo
ool000Sooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o
0000ooooooooool0oooooom:ooooo`7o00000Oooool000Wooooo00?oMgMgo`000?ooool00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool08oooool00ol0003ooooooooo
o`0mooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0?Oooool00ol0003ooooooooo
o`0mooooo`03o`000?oooooooooo02?ooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00Wooooo0Ol00001ooooo`006_ooooooo`0004ko00000Oooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001
\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-30.1723, -14.304, 0.195672, \
0.195672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0192308 0.211538 0.0192308 [
[.11538 -0.0125 -9 -9 ]
[.11538 -0.0125 9 0 ]
[.30769 -0.0125 -9 -9 ]
[.30769 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69231 -0.0125 -6 -9 ]
[.69231 -0.0125 6 0 ]
[.88462 -0.0125 -6 -9 ]
[.88462 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -18 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .21154 -6 -4.5 ]
[-0.0125 .21154 0 4.5 ]
[-0.0125 .40385 -12 -4.5 ]
[-0.0125 .40385 0 4.5 ]
[-0.0125 .59615 -12 -4.5 ]
[-0.0125 .59615 0 4.5 ]
[-0.0125 .78846 -12 -4.5 ]
[-0.0125 .78846 0 4.5 ]
[-0.0125 .98077 -12 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11538 0 m
.11538 .00625 L
s
[(-20)] .11538 -0.0125 0 1 Mshowa
.30769 0 m
.30769 .00625 L
s
[(-10)] .30769 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69231 0 m
.69231 .00625 L
s
[(10)] .69231 -0.0125 0 1 Mshowa
.88462 0 m
.88462 .00625 L
s
[(20)] .88462 -0.0125 0 1 Mshowa
.125 Mabswid
.15385 0 m
.15385 .00375 L
s
.19231 0 m
.19231 .00375 L
s
.23077 0 m
.23077 .00375 L
s
.26923 0 m
.26923 .00375 L
s
.34615 0 m
.34615 .00375 L
s
.38462 0 m
.38462 .00375 L
s
.42308 0 m
.42308 .00375 L
s
.46154 0 m
.46154 .00375 L
s
.53846 0 m
.53846 .00375 L
s
.57692 0 m
.57692 .00375 L
s
.61538 0 m
.61538 .00375 L
s
.65385 0 m
.65385 .00375 L
s
.73077 0 m
.73077 .00375 L
s
.76923 0 m
.76923 .00375 L
s
.80769 0 m
.80769 .00375 L
s
.84615 0 m
.84615 .00375 L
s
.07692 0 m
.07692 .00375 L
s
.03846 0 m
.03846 .00375 L
s
.92308 0 m
.92308 .00375 L
s
.96154 0 m
.96154 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(-10)] -0.0125 .01923 1 0 Mshowa
0 .21154 m
.00625 .21154 L
s
[(0)] -0.0125 .21154 1 0 Mshowa
0 .40385 m
.00625 .40385 L
s
[(10)] -0.0125 .40385 1 0 Mshowa
0 .59615 m
.00625 .59615 L
s
[(20)] -0.0125 .59615 1 0 Mshowa
0 .78846 m
.00625 .78846 L
s
[(30)] -0.0125 .78846 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(40)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .05769 m
.00375 .05769 L
s
0 .09615 m
.00375 .09615 L
s
0 .13462 m
.00375 .13462 L
s
0 .17308 m
.00375 .17308 L
s
0 .25 m
.00375 .25 L
s
0 .28846 m
.00375 .28846 L
s
0 .32692 m
.00375 .32692 L
s
0 .36538 m
.00375 .36538 L
s
0 .44231 m
.00375 .44231 L
s
0 .48077 m
.00375 .48077 L
s
0 .51923 m
.00375 .51923 L
s
0 .55769 m
.00375 .55769 L
s
0 .63462 m
.00375 .63462 L
s
0 .67308 m
.00375 .67308 L
s
0 .71154 m
.00375 .71154 L
s
0 .75 m
.00375 .75 L
s
0 .82692 m
.00375 .82692 L
s
0 .86538 m
.00375 .86538 L
s
0 .90385 m
.00375 .90385 L
s
0 .94231 m
.00375 .94231 L
s
.25 Mabswid
0 0 m
0 1 L
s
.11538 .99375 m
.11538 1 L
s
.30769 .99375 m
.30769 1 L
s
.5 .99375 m
.5 1 L
s
.69231 .99375 m
.69231 1 L
s
.88462 .99375 m
.88462 1 L
s
.125 Mabswid
.15385 .99625 m
.15385 1 L
s
.19231 .99625 m
.19231 1 L
s
.23077 .99625 m
.23077 1 L
s
.26923 .99625 m
.26923 1 L
s
.34615 .99625 m
.34615 1 L
s
.38462 .99625 m
.38462 1 L
s
.42308 .99625 m
.42308 1 L
s
.46154 .99625 m
.46154 1 L
s
.53846 .99625 m
.53846 1 L
s
.57692 .99625 m
.57692 1 L
s
.61538 .99625 m
.61538 1 L
s
.65385 .99625 m
.65385 1 L
s
.73077 .99625 m
.73077 1 L
s
.76923 .99625 m
.76923 1 L
s
.80769 .99625 m
.80769 1 L
s
.84615 .99625 m
.84615 1 L
s
.07692 .99625 m
.07692 1 L
s
.03846 .99625 m
.03846 1 L
s
.92308 .99625 m
.92308 1 L
s
.96154 .99625 m
.96154 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .21154 m
1 .21154 L
s
.99375 .40385 m
1 .40385 L
s
.99375 .59615 m
1 .59615 L
s
.99375 .78846 m
1 .78846 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .05769 m
1 .05769 L
s
.99625 .09615 m
1 .09615 L
s
.99625 .13462 m
1 .13462 L
s
.99625 .17308 m
1 .17308 L
s
.99625 .25 m
1 .25 L
s
.99625 .28846 m
1 .28846 L
s
.99625 .32692 m
1 .32692 L
s
.99625 .36538 m
1 .36538 L
s
.99625 .44231 m
1 .44231 L
s
.99625 .48077 m
1 .48077 L
s
.99625 .51923 m
1 .51923 L
s
.99625 .55769 m
1 .55769 L
s
.99625 .63462 m
1 .63462 L
s
.99625 .67308 m
1 .67308 L
s
.99625 .71154 m
1 .71154 L
s
.99625 .75 m
1 .75 L
s
.99625 .82692 m
1 .82692 L
s
.99625 .86538 m
1 .86538 L
s
.99625 .90385 m
1 .90385 L
s
.99625 .94231 m
1 .94231 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.4 g
.4117 .30462 m
.43132 .3012 L
.45094 .30111 L
.47057 .30197 L
.49019 .29827 L
.50981 .30143 L
.52943 .3032 L
.54906 .30401 L
.56868 .30396 L
.5883 .30304 L
.60793 .30114 L
.62755 .29773 L
.64717 .30185 L
.6668 .30104 L
.68642 .30136 L
.70604 .30562 L
.71419 .31358 L
.70604 .32959 L
.70179 .3332 L
.68642 .34195 L
.6668 .34901 L
.65182 .35283 L
.64717 .354 L
.62755 .35772 L
.60793 .35449 L
.5883 .35713 L
.56868 .35846 L
.54906 .35854 L
.52943 .35736 L
.50981 .35488 L
.49019 .35807 L
.47057 .35453 L
.46359 .35283 L
.45094 .34969 L
.43132 .34296 L
.41345 .3332 L
.4117 .3318 L
.40117 .31358 L
F
0 g
.4117 .30462 m
.43132 .3012 L
.45094 .30111 L
.47057 .30197 L
.49019 .29827 L
.50981 .30143 L
.52943 .3032 L
.54906 .30401 L
.56868 .30396 L
.5883 .30304 L
.60793 .30114 L
.62755 .29773 L
.64717 .30185 L
.6668 .30104 L
.68642 .30136 L
.70604 .30562 L
.71419 .31358 L
.70604 .32959 L
.70179 .3332 L
.68642 .34195 L
.6668 .34901 L
.65182 .35283 L
.64717 .354 L
.62755 .35772 L
.60793 .35449 L
.5883 .35713 L
.56868 .35846 L
.54906 .35854 L
.52943 .35736 L
.50981 .35488 L
.49019 .35807 L
.47057 .35453 L
.46359 .35283 L
.45094 .34969 L
.43132 .34296 L
.41345 .3332 L
.4117 .3318 L
.40117 .31358 L
.4117 .30462 L
s
.6 g
.4117 .25208 m
.43132 .24541 L
.45094 .23834 L
.47057 .2437 L
.49019 .24681 L
.50981 .24951 L
.52943 .25174 L
.54906 .25302 L
.56868 .25293 L
.5883 .25151 L
.60793 .24921 L
.62755 .24646 L
.64717 .24327 L
.6668 .23709 L
.68642 .2458 L
.70604 .25406 L
.70662 .25471 L
.70604 .2671 L
.70019 .27433 L
.68642 .28207 L
.6668 .28897 L
.64717 .29377 L
.64624 .29396 L
.62755 .2952 L
.60793 .29786 L
.5883 .29988 L
.56868 .30096 L
.54906 .30102 L
.52943 .30006 L
.50981 .29815 L
.49019 .29552 L
.47057 .29423 L
.46927 .29396 L
.45094 .28963 L
.43132 .28306 L
.41505 .27433 L
.4117 .27081 L
.40887 .25471 L
F
0 g
.4117 .25208 m
.43132 .24541 L
.45094 .23834 L
.47057 .2437 L
.49019 .24681 L
.50981 .24951 L
.52943 .25174 L
.54906 .25302 L
.56868 .25293 L
.5883 .25151 L
.60793 .24921 L
.62755 .24646 L
.64717 .24327 L
.6668 .23709 L
.68642 .2458 L
.70604 .25406 L
.70662 .25471 L
.70604 .2671 L
.70019 .27433 L
.68642 .28207 L
.6668 .28897 L
.64717 .29377 L
.64624 .29396 L
.62755 .2952 L
.60793 .29786 L
.5883 .29988 L
.56868 .30096 L
.54906 .30102 L
.52943 .30006 L
.50981 .29815 L
.49019 .29552 L
.47057 .29423 L
.46927 .29396 L
.45094 .28963 L
.43132 .28306 L
.41505 .27433 L
.4117 .27081 L
.40887 .25471 L
.4117 .25208 L
s
.6 g
.43132 .36962 m
.45094 .36651 L
.47057 .36633 L
.49019 .3669 L
.50981 .36258 L
.52943 .36456 L
.54906 .3654 L
.56868 .36535 L
.5883 .36439 L
.60793 .36224 L
.62755 .36682 L
.64717 .36629 L
.6668 .36665 L
.68642 .37057 L
.68964 .37245 L
.68642 .38748 L
.68172 .39207 L
.6668 .4014 L
.64717 .4089 L
.63703 .4117 L
.62755 .41422 L
.60793 .41305 L
.5883 .41564 L
.56868 .41713 L
.54906 .41721 L
.52943 .41589 L
.50981 .41339 L
.49019 .41477 L
.47834 .4117 L
.47057 .4096 L
.45094 .4025 L
.43361 .39207 L
.43132 .39 L
.42575 .37245 L
F
0 g
.43132 .36962 m
.45094 .36651 L
.47057 .36633 L
.49019 .3669 L
.50981 .36258 L
.52943 .36456 L
.54906 .3654 L
.56868 .36535 L
.5883 .36439 L
.60793 .36224 L
.62755 .36682 L
.64717 .36629 L
.6668 .36665 L
.68642 .37057 L
.68964 .37245 L
.68642 .38748 L
.68172 .39207 L
.6668 .4014 L
.64717 .4089 L
.63703 .4117 L
.62755 .41422 L
.60793 .41305 L
.5883 .41564 L
.56868 .41713 L
.54906 .41721 L
.52943 .41589 L
.50981 .41339 L
.49019 .41477 L
.47834 .4117 L
.47057 .4096 L
.45094 .4025 L
.43361 .39207 L
.43132 .39 L
.42575 .37245 L
.43132 .36962 L
s
.4 g
.47057 .19479 m
.49019 .19336 L
.50981 .1929 L
.52943 .19282 L
.54906 .19283 L
.56868 .19283 L
.5883 .19282 L
.60793 .19293 L
.62755 .19346 L
.64717 .19507 L
.65243 .19584 L
.6668 .19921 L
.68008 .21546 L
.6668 .2248 L
.64717 .23215 L
.63538 .23509 L
.62755 .23722 L
.60793 .24194 L
.5883 .24565 L
.56868 .24783 L
.54906 .24796 L
.52943 .24601 L
.50981 .24245 L
.49019 .23783 L
.47999 .23509 L
.47057 .23281 L
.45094 .22591 L
.43524 .21546 L
.45094 .19844 L
.46294 .19584 L
F
0 g
.47057 .19479 m
.49019 .19336 L
.50981 .1929 L
.52943 .19282 L
.54906 .19283 L
.56868 .19283 L
.5883 .19282 L
.60793 .19293 L
.62755 .19346 L
.64717 .19507 L
.65243 .19584 L
.6668 .19921 L
.68008 .21546 L
.6668 .2248 L
.64717 .23215 L
.63538 .23509 L
.62755 .23722 L
.60793 .24194 L
.5883 .24565 L
.56868 .24783 L
.54906 .24796 L
.52943 .24601 L
.50981 .24245 L
.49019 .23783 L
.47999 .23509 L
.47057 .23281 L
.45094 .22591 L
.43524 .21546 L
.45094 .19844 L
.46294 .19584 L
.47057 .19479 L
s
.3 g
.47057 .3103 m
.49019 .3048 L
.50981 .30621 L
.52943 .30714 L
.54906 .3076 L
.56868 .30757 L
.5883 .30706 L
.60793 .30607 L
.62755 .30459 L
.64717 .31059 L
.6611 .31358 L
.66451 .3332 L
.64717 .34297 L
.62755 .34931 L
.61106 .35283 L
.60793 .35291 L
.5883 .35406 L
.56868 .35499 L
.54906 .35504 L
.52943 .3542 L
.50981 .353 L
.50429 .35283 L
.49019 .34989 L
.47057 .3439 L
.45094 .33328 L
.45085 .3332 L
.45094 .31552 L
.45429 .31358 L
F
0 g
.47057 .3103 m
.49019 .3048 L
.50981 .30621 L
.52943 .30714 L
.54906 .3076 L
.56868 .30757 L
.5883 .30706 L
.60793 .30607 L
.62755 .30459 L
.64717 .31059 L
.6611 .31358 L
.66451 .3332 L
.64717 .34297 L
.62755 .34931 L
.61106 .35283 L
.60793 .35291 L
.5883 .35406 L
.56868 .35499 L
.54906 .35504 L
.52943 .3542 L
.50981 .353 L
.50429 .35283 L
.49019 .34989 L
.47057 .3439 L
.45094 .33328 L
.45085 .3332 L
.45094 .31552 L
.45429 .31358 L
.47057 .3103 L
s
.7 g
.47057 .25424 m
.49019 .25226 L
.50981 .25273 L
.52943 .25363 L
.54906 .25424 L
.56868 .2542 L
.5883 .25352 L
.60793 .25263 L
.62755 .25229 L
.64641 .25471 L
.64717 .25489 L
.6639 .27433 L
.64717 .28412 L
.62755 .29043 L
.61054 .29396 L
.60793 .29429 L
.5883 .29648 L
.56868 .2977 L
.54906 .29778 L
.52943 .29668 L
.50981 .29459 L
.5048 .29396 L
.49019 .29101 L
.47057 .28506 L
.45144 .27433 L
.46898 .25471 L
F
0 g
.47057 .25424 m
.49019 .25226 L
.50981 .25273 L
.52943 .25363 L
.54906 .25424 L
.56868 .2542 L
.5883 .25352 L
.60793 .25263 L
.62755 .25229 L
.64641 .25471 L
.64717 .25489 L
.6639 .27433 L
.64717 .28412 L
.62755 .29043 L
.61054 .29396 L
.60793 .29429 L
.5883 .29648 L
.56868 .2977 L
.54906 .29778 L
.52943 .29668 L
.50981 .29459 L
.5048 .29396 L
.49019 .29101 L
.47057 .28506 L
.45144 .27433 L
.46898 .25471 L
.47057 .25424 L
s
.8 g
.49019 .26137 m
.50981 .25777 L
.52943 .25638 L
.54906 .25588 L
.56868 .25591 L
.5883 .25649 L
.60793 .25804 L
.62755 .26215 L
.63889 .27433 L
.62755 .28176 L
.60793 .28826 L
.5883 .29175 L
.56868 .29338 L
.54906 .29347 L
.52943 .29204 L
.50981 .2888 L
.49019 .2828 L
.47649 .27433 L
F
0 g
.49019 .26137 m
.50981 .25777 L
.52943 .25638 L
.54906 .25588 L
.56868 .25591 L
.5883 .25649 L
.60793 .25804 L
.62755 .26215 L
.63889 .27433 L
.62755 .28176 L
.60793 .28826 L
.5883 .29175 L
.56868 .29338 L
.54906 .29347 L
.52943 .29204 L
.50981 .2888 L
.49019 .2828 L
.47649 .27433 L
.49019 .26137 L
s
.2 g
.52943 .31296 m
.54906 .31262 L
.56868 .31263 L
.5883 .31305 L
.59933 .31358 L
.60793 .31427 L
.62755 .31749 L
.63876 .3332 L
.62755 .33989 L
.60793 .3463 L
.5883 .34984 L
.56868 .35151 L
.54906 .35161 L
.52943 .35013 L
.50981 .34684 L
.49019 .34089 L
.47662 .3332 L
.49019 .31687 L
.50981 .31407 L
.51577 .31358 L
F
0 g
.52943 .31296 m
.54906 .31262 L
.56868 .31263 L
.5883 .31305 L
.59933 .31358 L
.60793 .31427 L
.62755 .31749 L
.63876 .3332 L
.62755 .33989 L
.60793 .3463 L
.5883 .34984 L
.56868 .35151 L
.54906 .35161 L
.52943 .35013 L
.50981 .34684 L
.49019 .34089 L
.47662 .3332 L
.49019 .31687 L
.50981 .31407 L
.51577 .31358 L
.52943 .31296 L
s
.3 g
.49019 .21316 m
.50981 .20647 L
.52943 .20418 L
.54906 .20333 L
.56868 .20338 L
.5883 .20436 L
.60793 .20691 L
.62753 .21546 L
.60793 .22918 L
.5883 .23345 L
.57192 .23509 L
.56868 .23544 L
.54906 .23564 L
.54351 .23509 L
.52943 .23377 L
.50981 .22988 L
.49019 .22016 L
.48785 .21546 L
F
0 g
.49019 .21316 m
.50981 .20647 L
.52943 .20418 L
.54906 .20333 L
.56868 .20338 L
.5883 .20436 L
.60793 .20691 L
.62753 .21546 L
.60793 .22918 L
.5883 .23345 L
.57192 .23509 L
.56868 .23544 L
.54906 .23564 L
.54351 .23509 L
.52943 .23377 L
.50981 .22988 L
.49019 .22016 L
.48785 .21546 L
.49019 .21316 L
s
.7 g
.50981 .37856 m
.52943 .37688 L
.54906 .37637 L
.56868 .3764 L
.5883 .37699 L
.60793 .37893 L
.62292 .39207 L
.60793 .39964 L
.5883 .40439 L
.56868 .40649 L
.54906 .4066 L
.52943 .40475 L
.50981 .40041 L
.4925 .39207 L
F
0 g
.50981 .37856 m
.52943 .37688 L
.54906 .37637 L
.56868 .3764 L
.5883 .37699 L
.60793 .37893 L
.62292 .39207 L
.60793 .39964 L
.5883 .40439 L
.56868 .40649 L
.54906 .4066 L
.52943 .40475 L
.50981 .40041 L
.4925 .39207 L
.50981 .37856 L
s
.9 g
.50981 .26663 m
.52943 .26279 L
.54906 .26156 L
.56868 .26163 L
.5883 .26306 L
.60793 .26752 L
.61555 .27433 L
.60793 .27959 L
.5883 .2856 L
.56868 .28801 L
.54906 .28814 L
.52943 .28603 L
.50981 .28065 L
.4998 .27433 L
F
0 g
.50981 .26663 m
.52943 .26279 L
.54906 .26156 L
.56868 .26163 L
.5883 .26306 L
.60793 .26752 L
.61555 .27433 L
.60793 .27959 L
.5883 .2856 L
.56868 .28801 L
.54906 .28814 L
.52943 .28603 L
.50981 .28065 L
.4998 .27433 L
.50981 .26663 L
s
.1 g
.50981 .32315 m
.52943 .3195 L
.54906 .31841 L
.56868 .31847 L
.5883 .31974 L
.60793 .32405 L
.61444 .3332 L
.60793 .33703 L
.5883 .34293 L
.56868 .34535 L
.54906 .34548 L
.52943 .34336 L
.50981 .33805 L
.50091 .3332 L
F
0 g
.50981 .32315 m
.52943 .3195 L
.54906 .31841 L
.56868 .31847 L
.5883 .31974 L
.60793 .32405 L
.61444 .3332 L
.60793 .33703 L
.5883 .34293 L
.56868 .34535 L
.54906 .34548 L
.52943 .34336 L
.50981 .33805 L
.50091 .3332 L
.50981 .32315 L
s
.6 g
.52943 .15482 m
.54906 .15339 L
.56868 .15347 L
.5883 .15513 L
.59743 .15659 L
.59298 .17622 L
.5883 .17672 L
.56868 .17811 L
.54906 .17818 L
.52943 .17696 L
.52205 .17622 L
.51769 .15659 L
F
0 g
.52943 .15482 m
.54906 .15339 L
.56868 .15347 L
.5883 .15513 L
.59743 .15659 L
.59298 .17622 L
.5883 .17672 L
.56868 .17811 L
.54906 .17818 L
.52943 .17696 L
.52205 .17622 L
.51769 .15659 L
.52943 .15482 L
s
1 g
.52943 .27421 m
.54906 .26927 L
.56868 .26947 L
.58606 .27433 L
.56868 .28017 L
.54906 .28042 L
.52943 .27448 L
.52928 .27433 L
F
0 g
.52943 .27421 m
.54906 .26927 L
.56868 .26947 L
.58606 .27433 L
.56868 .28017 L
.54906 .28042 L
.52943 .27448 L
.52928 .27433 L
.52943 .27421 L
s
.54906 .3272 m
.56868 .32745 L
.58199 .3332 L
.56868 .33666 L
.54906 .33693 L
.53338 .3332 L
F
.54906 .3272 m
.56868 .32745 L
.58199 .3332 L
.56868 .33666 L
.54906 .33693 L
.53338 .3332 L
.54906 .3272 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00?Oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0dooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kS?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0hooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8b
onk^kS?ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08_ooool003gooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0=_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0<oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg03?ooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL08_ooool003Gooooo1_l0
0003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400[ooooo`Ko0000
1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100<oooool01Ol@413o
oooooooooooooooo410@03[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@03Cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@02;ooooo000o
ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000fooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000cooooo`05o`000?ooooooooooooooool0
0000>_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000=Oooool00onH
V9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000008_ooool0043ooooo00?oMgMgofIV
I_ooool00_ooool01Ol0003ooooooooooooooooo000003Kooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000003?ooooo00Go0000ooooooooooooooooo`00000jooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`03ogMgMomVIVKooooo00;o
oooo00Go0000ooooooooooooooooo`00000Rooooo`00@Oooool01Ol0003ooooooooooooooooo410@
00?ooooo00?o410@ooooooooool0=?ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@4100<oooool01Ol@413ooooooooooooooooo410@03[ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@03Oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo023ooooo000mooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg03Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg03?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0jooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0cooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02;ooooo000mooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^03Cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^03?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`03oeEEEOmVIVKo000000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0cooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02;ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo000Joooooooo0000C_l00001ooooo`00
6_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0?Ooo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool08ooo
ool1o`00007ooooo0008ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKo
oooo00?o0000ooooooooool0oooooom:ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooom:ooooo`7o
00000Oooool000Go00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41001_ooool00ol0003oooooooooo`3ooooood[ooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?ooooooB?ooool3o`00007o
oooo000:ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo0008ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Oooooooogmo
Od3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Ooo
ooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?oooonWogmoOaWo0000OomoOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?oooonUogmoO`;o00006OnIVIT00ol0003oOgmoogmoO`1logmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooojGoOgmo00?o0000oiVIVOnIVIT06?nIVIT0
0ol0003oOgmoogmoO`1logmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
ojKoOgmo00?o0000oiVIVOnIVIT05_nIVIT00ol0003oOgmoogmoO`1mogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooojKoOgmo00?o0000oiVIVOnIVIT05_nIVIT00ol0003o
OgmoogmoO`1mogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooojKoOgmo
00?o0000oiVIVOnIVIT05_nIVIT00ol0003oOgmoogmoO`1mogmoO`Kooooo0Ol00001ooooo`006_oo
ool2o`0000GoooooYomoOgl00ol0003oVIVIoiVIV@0DoiVIV@03o`000?moOgooOgmo07koOgmo1Ooo
ool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooYomoOgl7o`0000coVIVI1Ol00020
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooojkoOgmo3?l00025ogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?oooonDogmoOcko0000KOmoOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?oooonAogmoO`?o0000?_mVIVH4o`0006WoOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CoooooSomoOgl2o`0004GoIVIV0_l0001WogmoO`Kooooo0Ol00001ooooo`003ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool01?oooon>ogmoO`03o`00
0?mVIVKoIVIV01GoIVIV6ol0000FofIVIP03o`000?moOgooOgmo06GoOgmo1_ooool1o`00007ooooo
000?ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`04ooooohgoOgmo
00?o0000ofIVI_mVIVH04OmVIVH5o`0001_oC4a<1?l0000CofIVIP03o`000?moOgooOgmo06CoOgmo
1_ooool1o`00007ooooo000?ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003ooooo
ooooo`04ooooohcoOgmo00?o0000ofIVI_mVIVH03omVIVH3o`0002CoC4a<0ol0000AofIVIP03o`00
0?moOgooOgmo06?oOgmo1_ooool1o`00007ooooo000?ooooo`05o`000?ooooooooooooooool00000
1_ooool3o`0000CoooooRomoOgl00ol0003oIVIVofIVIP0>ofIVIP;o0000:_m<C4`2o`00013oIVIV
00?o0000ogmoOomoOgl0H_moOgl4ooooo`?o00000Oooool000oooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo00CoooooR_moOgl2o`0000ooIVIV00?o0000oda<C?m<C4`0
:om<C4`2o`0000ooIVIV0_l0001SogmoO`Kooooo0Ol00001ooooo`003oooool01Ol@413ooooooooo
oooooooo410@00Kooooo00?o0000ooooooooool01?oooon<ogmoO`03o`000?mVIVKoIVIV00coIVIV
00?o0000oda<C?m<C4`0:_m<C4`00ol0003oIVIVofIVIP0>ofIVIP03o`000?moOgooOgmo06?oOgmo
1_ooool1o`00007ooooo000?ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003ooooo
ooooo`04ooooohgoOgmo00?o0000ofIVI_mVIVH03?mVIVH2o`0002SoC4a<0_l0000@ofIVIP03o`00
0?moOgooOgmo06CoOgmo1_ooool1o`00007ooooo000?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1_ooool00ol0003oooooooooo`04ooooohkoOgmo00?o0000ofIVI_mVIVH03OmVIVH3o`0002CoC4a<
00?o0000ofIVI_mVIVH03_mVIVH2o`0006OoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CoooooSomoOgl3o`0000ooIVIV0_l0000Qoda<C003o`000?mVIVKoIVIV00coIVIV0ol0
001YogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooi;oOgmo0ol0000>
ofIVIPCo00006Om<C4`4o`0000goIVIV0_l0001/ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04oooooiGoOgmo0ol0000?ofIVIPKo00003Om<C4`6o`0000koIVIV0ol0001^ogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooiSoOgmo1?l0000AofIVIPgo
00003_mVIVH6o`0000OoOgmo1?l0001VogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooohgoOgmo1Ol0000:ogmoO`Go00009?mVIVH3o`0000[oOgmo0ol00004oiVIV@;o0000
I?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon:ogmoO`?o00001OnI
VIT3o`0000coOgmo1_l0000IofIVIPGo00002?moOgl5o`0000WoVIVI0_l0001RogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooohOoOgmo0ol0000;oiVIV@Go00003OmoOgl7
o`0000coIVIV1_l00007ogmoO`Ko00004?nIVIT2o`00063oOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CoooooQ?moOgl3o`0001?oVIVI3Ol00007ogmoO`co00001_moOgl7o`00
01SoVIVI0ol0001MogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000GoooooP_moOgl2o`0001Go
VIVI2?l00006oiVIV@Oo00003?moOgl6o`0000OoVIVI1ol0000DoiVIV@;o0000FomoOgl5ooooo`;o
00000Oooool001[ooooo00?o0000ooooooooool01?oooon1ogmoO`03o`000?nIVIWoVIVI017oVIVI
1?l00008ok>c/bKo00001onc/k<3o`0001?oVIVI00?o0000ogmoOomoOgl0F?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?oooon1ogmoO`03o`000?nIVIWoVIVI017oVIVI00?o
0000ok>c/onc/k<02?nc/k<Vo`0000[o/k>c00?o0000oiVIVOnIVIT04OnIVIT00ol0003oOgmoogmo
O`1HogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooh7oOgmo00?o0000
oiVIVOnIVIT04?nIVIT00ol0003o/k>cok>c/`05ok>c/`Co00003Oo<c<`7o`0001;oc<c<0ol00008
ok>c/`03o`000?nIVIWoVIVI013oVIVI00?o0000ogmoOomoOgl0F?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?oooon1ogmoO`03o`000?nIVIWoVIVI00ooVIVI00?o0000ok>c
/onc/k<01Onc/k<00ol0003oc<c<olc<c008olc<c0Oo00001ooVi^H=o`0000Soc<c<0_l00007ok>c
/`03o`000?nIVIWoVIVI00ooVIVI00?o0000ogmoOomoOgl0F?moOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?oooon2ogmoO`03o`000?nIVIWoVIVI00goVIVI00?o0000ok>c/onc
/k<01Onc/k<00ol0003oc<c<olc<c005olc<c0Co00006ooVi^H3o`0000Koc<c<00?o0000ok>c/onc
/k<01_nc/k<00ol0003oVIVIoiVIV@0>oiVIV@03o`000?moOgooOgmo05SoOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CoooooP_moOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`00
0?nc/k?o/k>c00Go/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003oi^KVonKViP0:onKViP_o0000
2ooVi^H00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00Ko/k>c00?o0000oiVIVOnIVIT0
3OnIVIT00ol0003oOgmoogmoO`1HogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04oooooh;oOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`05ok>c/`03o`000?o<
c<coc<c<00Goc<c<00?o0000onKVi_oVi^H02?oVi^H3o`0000_ooooo0ol00009onKViP03o`000?o<
c<coc<c<00Coc<c<00?o0000ok>c/onc/k<01_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?mo
OgooOgmo05WoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooPomoOgl2
o`0000[oVIVI0_l00006ok>c/`;o00001_o<c<`2o`0000Soi^KV0ol0000?ooooo`;o00002?oVi^H2
o`0000Goc<c<0_l00007ok>c/`;o00002_nIVIT2o`0005coOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CoooooQOmoOgl2o`0000[oVIVI0_l00006ok>c/`;o00001_o<c<`2o`00
00Woi^KV0ol00009ooooo`?o00001ooVi^H3o`0000Koc<c<00?o0000ok>c/onc/k<01Onc/k<2o`00
00WoVIVI0ol0001NogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooohOo
Ogmo00?o0000oiVIVOnIVIT02OnIVIT2o`0000Ko/k>c00?o0000olc<c?o<c<`01Oo<c<`3o`0000Wo
i^KV2Ol00007onKViP?o00001_o<c<`3o`0000Ko/k>c0_l00009oiVIV@;o0000HOmoOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?oooon8ogmoO`?o00002_nIVIT3o`0000Co/k>c
0ol00007olc<c0?o00004OoVi^H5o`0000Koc<c<0ol00007ok>c/`;o00002OnIVIT2o`0006?oOgmo
1_ooool1o`00007ooooo000Jooooo`;o00001Ooooon;ogmoO`?o00002_nIVIT3o`0000Co/k>c0ol0
0007olc<c17o00002?o<c<`3o`0000Oo/k>c0ol00009oiVIV@;o0000IOmoOgl5ooooo`;o00000Ooo
ool001[ooooo00?o0000ooooooooool01?oooon>ogmoO`Go00002?nIVIT5o`0000;o/k>c1Ol0000H
olc<c0?o00001Onc/k<5o`0000SoVIVI1?l0001WogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04oooooi?oOgmo1ol00006oiVIVAoo000000?o/k>co`000?l000001Ol00006oiVI
V@Oo0000JomoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonJogmoO`Oo
00001_nIVIT7o`0000Go/k>c3Ol00007oiVIV@Ko0000L_moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?oooonIogmoOa[o00001onIVITDo`00077oOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CoooooQOmoOglDo`0000SoIVIV9_l00007ofIVIQCo0000GOmo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon1ogmoO`Co00005OmVIVH=
o`0000OoIVIV3?l00006ofIVIPgo00005OmVIVH3o`0005[oOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CoooooP?moOgl00ol0003oIVIVofIVIP0DofIVIP?o00003Om<C4`Io`00
00goC4a<0ol0000DofIVIP03o`000?moOgooOgmo05SoOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CoooooOomoOgl00ol0003oIVIVofIVIP0AofIVIPCo00005_m<C4`>o`0001Go
C4a<1?l0000AofIVIP03o`000?moOgooOgmo05OoOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CoooooO_moOgl00ol0003oIVIVofIVIP0>ofIVIPCo00003Om<C4`=o`0000ko<c<c
3Ol0000<oda<C0;o00004?mVIVH00ol0003oOgmoogmoO`1FogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooogkoOgmo00?o0000ofIVI_mVIVH03_mVIVH00ol0003oC4a<oda<
C00:oda<C0Co00003Olc<c<>o`0000go<c<c0ol0000:oda<C003o`000?mVIVKoIVIV00koIVIV00?o
0000ogmoOomoOgl0E_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooomo
ogmoO`03o`000?mVIVKoIVIV00goIVIV00?o0000oda<C?m<C4`02Om<C4`00ol0003o<c<coc<c<`08
oc<c<`Oo00003_lI6AT6o`0000Wo<c<c00?o0000oda<C?m<C4`02?m<C4`00ol0003oIVIVofIVIP0=
ofIVIP03o`000?moOgooOgmo05OoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CoooooP?moOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<00SoC4a<00?o0000oc<c
<olc<c<01_lc<c<3o`0001_o6ATI0ol00007oc<c<`03o`000?m<C4coC4a<00OoC4a<00?o0000ofIV
I_mVIVH03OmVIVH00ol0003oOgmoogmoO`1GogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000Go
ooooP?moOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<00OoC4a<00?o0000oc<c<olc
<c<01_lc<c<00ol0003o6ATIoaTI6@0:oaTI6@Wo00002olI6AT00ol0003o<c<coc<c<`06oc<c<`03
o`000?m<C4coC4a<00OoC4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmoO`1GogmoO`Go
oooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04oooooh7oOgmo00?o0000ofIVI_mVIVH0
2omVIVH00ol0003oC4a<oda<C006oda<C003o`000?lc<c?o<c<c00Ko<c<c00?o0000oaTI6OlI6AT0
2?lI6AT>o`0000[o6ATI00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C007oda<C003o`00
0?mVIVKoIVIV00[oIVIV0_l0001JogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04oooooh;oOgmo0_l0000;ofIVIP;o00001_m<C4`2o`0000Oo<c<c0_l00008oaTI6A7o00002_lI
6AT00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00GoC4a<0_l0000:ofIVIP;o0000G?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon4ogmoO`03o`000?mVIVKo
IVIV00[oIVIV00?o0000oda<C?m<C4`01Om<C4`2o`0000Oo<c<c00?o0000oaTI6OlI6AT02?lI6AT;
o`0000co6ATI00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C005oda<C003o`000?mVIVKo
IVIV00SoIVIV0_l0001NogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
ohGoOgmo0_l0000;ofIVIP;o00001om<C4`00ol0003o<c<coc<c<`05oc<c<`?o00002_lI6AT3o`00
00oo6ATI0_l00007oc<c<`03o`000?m<C4coC4a<00CoC4a<0_l0000:ofIVIP03o`000?moOgooOgmo
05koOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooQomoOgl00ol0003o
IVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<00GoC4a<0ol00007oc<c<`?o00005_lI6AT3o`0000Ko
<c<c0ol00006oda<C003o`000?mVIVKoIVIV00SoIVIV0_l0001QogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooohSoOgmo0ol0000:ofIVIP?o00001om<C4`3o`0000Oo<c<c
5_l00006oc<c<`?o00001om<C4`2o`0000WoIVIV0_l0001SogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04oooooh_oOgmo0ol0000:ofIVIP?o00001om<C4`5o`0001Wo<c<c1Ol0
0007oda<C0?o00002OmVIVH2o`0006GoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CoooooS_moOgl4o`0000WoIVIV1Ol00007oda<C1Wo00001om<C4`5o`0000WoIVIV0ol0001W
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooi;oOgmo1_l00008ofIV
IPko00003?m<C4`>o`0000GoIVIV2?l0001ZogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04oooooiSoOgmo0ol00003ofIVIP?o00001_moOglIo`0000SoOgmo1Ol0001bogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooi_oOgmo0ol0000@ogmoO`co0000
QOmoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonPogmoO`Oo00006Omo
Ogl8o`0007OoOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Ooooon<ogmoOaCo00001onIVITI
o`0000SoVIVI4_l0001UogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04oooo
ohSoOgmo1?l0001>oiVIV@?o0000H_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?oooon7ogmoO`03o`000?nIVIWoVIVI05?oVIVI0_l0001PogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooohOoOgmo00?o0000oiVIVOnIVIT0E?nIVIT00ol0003oOgmo
ogmoO`1NogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooohOoOgmo00?o
0000oiVIVOnIVIT06?nIVITRo`0001[oVIVI00?o0000ogmoOomoOgl0G_moOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?oooon7ogmoO`03o`000?nIVIWoVIVI01OoVIVI00?o0000
ok>c/onc/k<08?nc/k<00ol0003oVIVIoiVIV@0FoiVIV@03o`000?moOgooOgmo05ooOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooR?moOgl00ol0003oVIVIoiVIV@0EoiVI
V@03o`000?nc/k?o/k>c02;o/k>c00?o0000oiVIVOnIVIT05OnIVIT00ol0003oOgmoogmoO`1Oogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooohSoOgmo00?o0000oiVIVOnI
VIT05?nIVIT00ol0003o/k>cok>c/`0Tok>c/`03o`000?nIVIWoVIVI01CoVIVI00?o0000ogmoOomo
Ogl0GomoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon8ogmoO`03o`00
0?nIVIWoVIVI01?oVIVI00?o0000ok>c/onc/k<09_nc/k<00ol0003oVIVIoiVIV@0CoiVIV@03o`00
0?moOgooOgmo05ooOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooROmo
Ogl2o`0001;oVIVI0_l0000Xok>c/`;o00004_nIVIT2o`0006;oOgmo1_ooool1o`00007ooooo0008
ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo00?o0000oooooooo
ool01?oooon;ogmoO`;o00004_nIVIT2o`0002?o/k>c0ol0000BoiVIV@;o0000I?moOgl6ooooo`7o
00000Oooool000[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Ko
oooo00?o0000ooooooooool01?oooon=ogmoO`;o00004_nIVIT2o`0001oo/k>c0_l0000DoiVIV@03
o`000?moOgooOgmo06CoOgmo1_ooool1o`00007ooooo000:ooooo`03o`000?oooooooooo00;ooooo
00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00CoooooSomoOgl2o`0001;o
VIVI1?l0000Hok>c/`?o00004onIVIT3o`0006OoOgmo1_ooool1o`00007ooooo000:ooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`?o00001?oooonAogmoO`;o
00005?nIVIT7o`0000co/k>c1Ol0000CoiVIV@?o0000J_moOgl4ooooo`?o00000Oooool000[ooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool01?oooonCogmoO`;o00006OnIVIT<o`0001GoVIVI0ol0001]ogmoO`Kooooo0Ol00001ooooo`00
2_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003o
ooooooooo`04oooooiGoOgmo1_l0000aoiVIV@?o0000L?moOgl6ooooo`7o00000Oooool000[ooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000oooooooo
ool01?oooonKogmoO`co00006OnIVIT<o`0007?oOgmo1_ooool1o`00007ooooo0008ooooo`03oeEE
EOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo00Co
ooooYomoOglIo`0007ooOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo0_l00005ooooooooOgmo@?moOgl5oooo
o`;o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000Gooooo
oomoOgm0ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`00
00GooooooomoOgm0ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`001oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`001ooo
ool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002?ooool00onHV9So8B4Q
onk^kP04ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool000Wooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooo
oooooooooooo000000Kooooo0ol00004ooooooooOgmo@?moOgl4ooooo`?o00000Oooool000[ooooo
00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000;ooooo`05o`000?ooooooooooooooool@
41000oooool00ol@413oooooooooo`04ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`001oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`001oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000Oooooo00GoV9RHoa0@4?l0
003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000Oooooo00Go410@okZj^_ooooooMgMgoc8b<P03
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool000_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000:
ooooo`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`?o00001?oo
ooooogmoOd3oOgmo1?ooool3o`00007ooooo0009ooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`002_ooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000Oooooo00Go410@
oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000Oooooo00GoZJVYoa0@4?l0003o410@
ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo
1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Oooooooogmo
Od3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Ooo
ooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo0009ooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b
<_o^k^h01_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000[o
oooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000oooo
ooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo0007ooooo`Go00000oooool01Ol@413o
oooooooooooooooo410@00Kooooo0ol00004ooooooooOgmo@?moOgl4ooooo`?o00000Oooool000Oo
oooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000
ooooooooool0oooooom:ooooo`7o00000Oooool000Oooooo00CogMgMoeEEEOoooooo00001?ooool0
1Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0oooooom:ooooo`7o00000Ooo
ool000Sooooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo410@00Kooooo00?o
0000ooooooooool0oooooom:ooooo`7o00000Oooool000Sooooo00?ok^k^odA4A?l000001?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooom:ooooo`7o00000Ooo
ool000Wooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03gooooo00?o
0000ooooooooool0?Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo02?ooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo0Ol00001
ooooo`006_ooooooo`0004ko00000Oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-30.1723, -14.304, 0.195672, \
0.195672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0192308 0.211538 0.0192308 [
[.11538 -0.0125 -9 -9 ]
[.11538 -0.0125 9 0 ]
[.30769 -0.0125 -9 -9 ]
[.30769 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69231 -0.0125 -6 -9 ]
[.69231 -0.0125 6 0 ]
[.88462 -0.0125 -6 -9 ]
[.88462 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -18 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .21154 -6 -4.5 ]
[-0.0125 .21154 0 4.5 ]
[-0.0125 .40385 -12 -4.5 ]
[-0.0125 .40385 0 4.5 ]
[-0.0125 .59615 -12 -4.5 ]
[-0.0125 .59615 0 4.5 ]
[-0.0125 .78846 -12 -4.5 ]
[-0.0125 .78846 0 4.5 ]
[-0.0125 .98077 -12 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11538 0 m
.11538 .00625 L
s
[(-20)] .11538 -0.0125 0 1 Mshowa
.30769 0 m
.30769 .00625 L
s
[(-10)] .30769 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69231 0 m
.69231 .00625 L
s
[(10)] .69231 -0.0125 0 1 Mshowa
.88462 0 m
.88462 .00625 L
s
[(20)] .88462 -0.0125 0 1 Mshowa
.125 Mabswid
.15385 0 m
.15385 .00375 L
s
.19231 0 m
.19231 .00375 L
s
.23077 0 m
.23077 .00375 L
s
.26923 0 m
.26923 .00375 L
s
.34615 0 m
.34615 .00375 L
s
.38462 0 m
.38462 .00375 L
s
.42308 0 m
.42308 .00375 L
s
.46154 0 m
.46154 .00375 L
s
.53846 0 m
.53846 .00375 L
s
.57692 0 m
.57692 .00375 L
s
.61538 0 m
.61538 .00375 L
s
.65385 0 m
.65385 .00375 L
s
.73077 0 m
.73077 .00375 L
s
.76923 0 m
.76923 .00375 L
s
.80769 0 m
.80769 .00375 L
s
.84615 0 m
.84615 .00375 L
s
.07692 0 m
.07692 .00375 L
s
.03846 0 m
.03846 .00375 L
s
.92308 0 m
.92308 .00375 L
s
.96154 0 m
.96154 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(-10)] -0.0125 .01923 1 0 Mshowa
0 .21154 m
.00625 .21154 L
s
[(0)] -0.0125 .21154 1 0 Mshowa
0 .40385 m
.00625 .40385 L
s
[(10)] -0.0125 .40385 1 0 Mshowa
0 .59615 m
.00625 .59615 L
s
[(20)] -0.0125 .59615 1 0 Mshowa
0 .78846 m
.00625 .78846 L
s
[(30)] -0.0125 .78846 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(40)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .05769 m
.00375 .05769 L
s
0 .09615 m
.00375 .09615 L
s
0 .13462 m
.00375 .13462 L
s
0 .17308 m
.00375 .17308 L
s
0 .25 m
.00375 .25 L
s
0 .28846 m
.00375 .28846 L
s
0 .32692 m
.00375 .32692 L
s
0 .36538 m
.00375 .36538 L
s
0 .44231 m
.00375 .44231 L
s
0 .48077 m
.00375 .48077 L
s
0 .51923 m
.00375 .51923 L
s
0 .55769 m
.00375 .55769 L
s
0 .63462 m
.00375 .63462 L
s
0 .67308 m
.00375 .67308 L
s
0 .71154 m
.00375 .71154 L
s
0 .75 m
.00375 .75 L
s
0 .82692 m
.00375 .82692 L
s
0 .86538 m
.00375 .86538 L
s
0 .90385 m
.00375 .90385 L
s
0 .94231 m
.00375 .94231 L
s
.25 Mabswid
0 0 m
0 1 L
s
.11538 .99375 m
.11538 1 L
s
.30769 .99375 m
.30769 1 L
s
.5 .99375 m
.5 1 L
s
.69231 .99375 m
.69231 1 L
s
.88462 .99375 m
.88462 1 L
s
.125 Mabswid
.15385 .99625 m
.15385 1 L
s
.19231 .99625 m
.19231 1 L
s
.23077 .99625 m
.23077 1 L
s
.26923 .99625 m
.26923 1 L
s
.34615 .99625 m
.34615 1 L
s
.38462 .99625 m
.38462 1 L
s
.42308 .99625 m
.42308 1 L
s
.46154 .99625 m
.46154 1 L
s
.53846 .99625 m
.53846 1 L
s
.57692 .99625 m
.57692 1 L
s
.61538 .99625 m
.61538 1 L
s
.65385 .99625 m
.65385 1 L
s
.73077 .99625 m
.73077 1 L
s
.76923 .99625 m
.76923 1 L
s
.80769 .99625 m
.80769 1 L
s
.84615 .99625 m
.84615 1 L
s
.07692 .99625 m
.07692 1 L
s
.03846 .99625 m
.03846 1 L
s
.92308 .99625 m
.92308 1 L
s
.96154 .99625 m
.96154 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .21154 m
1 .21154 L
s
.99375 .40385 m
1 .40385 L
s
.99375 .59615 m
1 .59615 L
s
.99375 .78846 m
1 .78846 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .05769 m
1 .05769 L
s
.99625 .09615 m
1 .09615 L
s
.99625 .13462 m
1 .13462 L
s
.99625 .17308 m
1 .17308 L
s
.99625 .25 m
1 .25 L
s
.99625 .28846 m
1 .28846 L
s
.99625 .32692 m
1 .32692 L
s
.99625 .36538 m
1 .36538 L
s
.99625 .44231 m
1 .44231 L
s
.99625 .48077 m
1 .48077 L
s
.99625 .51923 m
1 .51923 L
s
.99625 .55769 m
1 .55769 L
s
.99625 .63462 m
1 .63462 L
s
.99625 .67308 m
1 .67308 L
s
.99625 .71154 m
1 .71154 L
s
.99625 .75 m
1 .75 L
s
.99625 .82692 m
1 .82692 L
s
.99625 .86538 m
1 .86538 L
s
.99625 .90385 m
1 .90385 L
s
.99625 .94231 m
1 .94231 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.6 g
.43132 .2726 m
.45094 .27386 L
.47057 .27205 L
.49019 .27318 L
.50925 .27433 L
.50981 .27438 L
.52943 .2753 L
.54906 .27587 L
.56868 .27605 L
.5883 .27582 L
.60793 .27519 L
.62566 .27433 L
.62755 .27422 L
.64717 .27301 L
.6668 .27192 L
.68642 .2734 L
.70604 .273 L
.71051 .27433 L
.72213 .29396 L
.70604 .30697 L
.69196 .31358 L
.68642 .31588 L
.6668 .3237 L
.64717 .33161 L
.62755 .32811 L
.60793 .33007 L
.5883 .33125 L
.56868 .33167 L
.54906 .33135 L
.52943 .33028 L
.50981 .32843 L
.49019 .32573 L
.47057 .32479 L
.45094 .31694 L
.44262 .31358 L
.43132 .3085 L
.41234 .29396 L
.42401 .27433 L
F
0 g
.43132 .2726 m
.45094 .27386 L
.47057 .27205 L
.49019 .27318 L
.50925 .27433 L
.50981 .27438 L
.52943 .2753 L
.54906 .27587 L
.56868 .27605 L
.5883 .27582 L
.60793 .27519 L
.62566 .27433 L
.62755 .27422 L
.64717 .27301 L
.6668 .27192 L
.68642 .2734 L
.70604 .273 L
.71051 .27433 L
.72213 .29396 L
.70604 .30697 L
.69196 .31358 L
.68642 .31588 L
.6668 .3237 L
.64717 .33161 L
.62755 .32811 L
.60793 .33007 L
.5883 .33125 L
.56868 .33167 L
.54906 .33135 L
.52943 .33028 L
.50981 .32843 L
.49019 .32573 L
.47057 .32479 L
.45094 .31694 L
.44262 .31358 L
.43132 .3085 L
.41234 .29396 L
.42401 .27433 L
.43132 .2726 L
s
.4 g
.43132 .3264 m
.45094 .32879 L
.47057 .33128 L
.49019 .33234 L
.50333 .3332 L
.50981 .33373 L
.52943 .33487 L
.54906 .33556 L
.56868 .33577 L
.5883 .33549 L
.60793 .33473 L
.62755 .33354 L
.63117 .3332 L
.64717 .33295 L
.6668 .33095 L
.68642 .32842 L
.70604 .33051 L
.71792 .3332 L
.72098 .35283 L
.70604 .36512 L
.69137 .37245 L
.68642 .37368 L
.6668 .38038 L
.64717 .38643 L
.62755 .39054 L
.60793 .39129 L
.59996 .39207 L
.5883 .39265 L
.56868 .39318 L
.54906 .39278 L
.53322 .39207 L
.52943 .39152 L
.50981 .39094 L
.49019 .38714 L
.47057 .38132 L
.45094 .3745 L
.44327 .37245 L
.43132 .36673 L
.41351 .35283 L
.41666 .3332 L
F
0 g
.43132 .3264 m
.45094 .32879 L
.47057 .33128 L
.49019 .33234 L
.50333 .3332 L
.50981 .33373 L
.52943 .33487 L
.54906 .33556 L
.56868 .33577 L
.5883 .33549 L
.60793 .33473 L
.62755 .33354 L
.63117 .3332 L
.64717 .33295 L
.6668 .33095 L
.68642 .32842 L
.70604 .33051 L
.71792 .3332 L
.72098 .35283 L
.70604 .36512 L
.69137 .37245 L
.68642 .37368 L
.6668 .38038 L
.64717 .38643 L
.62755 .39054 L
.60793 .39129 L
.59996 .39207 L
.5883 .39265 L
.56868 .39318 L
.54906 .39278 L
.53322 .39207 L
.52943 .39152 L
.50981 .39094 L
.49019 .38714 L
.47057 .38132 L
.45094 .3745 L
.44327 .37245 L
.43132 .36673 L
.41351 .35283 L
.41666 .3332 L
.43132 .3264 L
s
.4 g
.45094 .22392 m
.47057 .22116 L
.49019 .22045 L
.50981 .22049 L
.52943 .21948 L
.54906 .22108 L
.56868 .22151 L
.5883 .22093 L
.60793 .21911 L
.62755 .22046 L
.64717 .22049 L
.6668 .22138 L
.68642 .22465 L
.7016 .23509 L
.68642 .25302 L
.68326 .25471 L
.6668 .26005 L
.64717 .26444 L
.62755 .26755 L
.60793 .26969 L
.5883 .27097 L
.56868 .27143 L
.54906 .27108 L
.52943 .26992 L
.50981 .26791 L
.49019 .26494 L
.47057 .26076 L
.45123 .25471 L
.45094 .25456 L
.43295 .23509 L
F
0 g
.45094 .22392 m
.47057 .22116 L
.49019 .22045 L
.50981 .22049 L
.52943 .21948 L
.54906 .22108 L
.56868 .22151 L
.5883 .22093 L
.60793 .21911 L
.62755 .22046 L
.64717 .22049 L
.6668 .22138 L
.68642 .22465 L
.7016 .23509 L
.68642 .25302 L
.68326 .25471 L
.6668 .26005 L
.64717 .26444 L
.62755 .26755 L
.60793 .26969 L
.5883 .27097 L
.56868 .27143 L
.54906 .27108 L
.52943 .26992 L
.50981 .26791 L
.49019 .26494 L
.47057 .26076 L
.45123 .25471 L
.45094 .25456 L
.43295 .23509 L
.45094 .22392 L
s
.6 g
.45094 .40243 m
.47057 .39938 L
.49019 .39946 L
.50981 .40018 L
.52943 .4009 L
.54906 .4014 L
.56868 .40155 L
.5883 .40135 L
.60793 .40081 L
.62755 .40007 L
.64717 .39938 L
.6668 .39951 L
.68642 .40378 L
.69078 .4117 L
.68642 .41798 L
.6668 .43084 L
.66577 .43132 L
.64717 .44004 L
.62755 .44795 L
.60793 .44735 L
.5883 .44922 L
.56868 .44988 L
.54906 .44938 L
.52943 .44769 L
.50981 .44895 L
.49019 .44123 L
.47057 .43218 L
.46887 .43132 L
.45094 .4205 L
.44384 .4117 L
F
0 g
.45094 .40243 m
.47057 .39938 L
.49019 .39946 L
.50981 .40018 L
.52943 .4009 L
.54906 .4014 L
.56868 .40155 L
.5883 .40135 L
.60793 .40081 L
.62755 .40007 L
.64717 .39938 L
.6668 .39951 L
.68642 .40378 L
.69078 .4117 L
.68642 .41798 L
.6668 .43084 L
.66577 .43132 L
.64717 .44004 L
.62755 .44795 L
.60793 .44735 L
.5883 .44922 L
.56868 .44988 L
.54906 .44938 L
.52943 .44769 L
.50981 .44895 L
.49019 .44123 L
.47057 .43218 L
.46887 .43132 L
.45094 .4205 L
.44384 .4117 L
.45094 .40243 L
s
.7 g
.47057 .2835 m
.49019 .28096 L
.50981 .28026 L
.52943 .28017 L
.54906 .28024 L
.56868 .28027 L
.5883 .28023 L
.60793 .28016 L
.62755 .2803 L
.64717 .28116 L
.6668 .28418 L
.68174 .29396 L
.6668 .31031 L
.66061 .31358 L
.64717 .32403 L
.62755 .32263 L
.60793 .32549 L
.5883 .32713 L
.56868 .32771 L
.54906 .32727 L
.52943 .32579 L
.50981 .32312 L
.49019 .31891 L
.47397 .31358 L
.47057 .31187 L
.45285 .29396 L
F
0 g
.47057 .2835 m
.49019 .28096 L
.50981 .28026 L
.52943 .28017 L
.54906 .28024 L
.56868 .28027 L
.5883 .28023 L
.60793 .28016 L
.62755 .2803 L
.64717 .28116 L
.6668 .28418 L
.68174 .29396 L
.6668 .31031 L
.66061 .31358 L
.64717 .32403 L
.62755 .32263 L
.60793 .32549 L
.5883 .32713 L
.56868 .32771 L
.54906 .32727 L
.52943 .32579 L
.50981 .32312 L
.49019 .31891 L
.47397 .31358 L
.47057 .31187 L
.45285 .29396 L
.47057 .2835 L
s
.3 g
.47057 .34305 m
.49019 .34038 L
.50981 .33984 L
.52943 .3399 L
.54906 .34007 L
.56868 .34013 L
.5883 .34005 L
.60793 .33988 L
.62755 .33986 L
.64717 .34056 L
.6668 .34387 L
.67757 .35283 L
.6668 .3651 L
.65344 .37245 L
.64717 .37599 L
.62755 .38567 L
.60793 .38401 L
.5883 .38596 L
.56868 .38664 L
.54906 .38613 L
.52943 .38437 L
.50981 .38692 L
.49019 .37745 L
.48117 .37245 L
.47057 .3669 L
.45703 .35283 L
F
0 g
.47057 .34305 m
.49019 .34038 L
.50981 .33984 L
.52943 .3399 L
.54906 .34007 L
.56868 .34013 L
.5883 .34005 L
.60793 .33988 L
.62755 .33986 L
.64717 .34056 L
.6668 .34387 L
.67757 .35283 L
.6668 .3651 L
.65344 .37245 L
.64717 .37599 L
.62755 .38567 L
.60793 .38401 L
.5883 .38596 L
.56868 .38664 L
.54906 .38613 L
.52943 .38437 L
.50981 .38692 L
.49019 .37745 L
.48117 .37245 L
.47057 .3669 L
.45703 .35283 L
.47057 .34305 L
s
.8 g
.49019 .29027 m
.50981 .28658 L
.52943 .28522 L
.54906 .28471 L
.56868 .28459 L
.5883 .28476 L
.60793 .28535 L
.62755 .28689 L
.64717 .29125 L
.65235 .29396 L
.64717 .30746 L
.637 .31358 L
.62755 .31655 L
.60793 .32062 L
.5883 .32282 L
.56868 .32358 L
.54906 .32301 L
.52943 .32103 L
.50981 .31726 L
.4976 .31358 L
.49019 .30947 L
.48226 .29396 L
F
0 g
.49019 .29027 m
.50981 .28658 L
.52943 .28522 L
.54906 .28471 L
.56868 .28459 L
.5883 .28476 L
.60793 .28535 L
.62755 .28689 L
.64717 .29125 L
.65235 .29396 L
.64717 .30746 L
.637 .31358 L
.62755 .31655 L
.60793 .32062 L
.5883 .32282 L
.56868 .32358 L
.54906 .32301 L
.52943 .32103 L
.50981 .31726 L
.4976 .31358 L
.49019 .30947 L
.48226 .29396 L
.49019 .29027 L
s
.6 g
.49019 .18513 m
.50981 .17969 L
.52943 .17767 L
.54906 .17683 L
.56868 .17661 L
.5883 .1769 L
.60793 .17786 L
.62755 .18015 L
.64717 .18682 L
.6496 .19584 L
.64717 .19726 L
.62755 .20432 L
.60793 .20816 L
.5883 .21023 L
.56868 .21094 L
.54906 .2104 L
.52943 .20854 L
.50981 .20499 L
.49019 .19861 L
.48503 .19584 L
F
0 g
.49019 .18513 m
.50981 .17969 L
.52943 .17767 L
.54906 .17683 L
.56868 .17661 L
.5883 .1769 L
.60793 .17786 L
.62755 .18015 L
.64717 .18682 L
.6496 .19584 L
.64717 .19726 L
.62755 .20432 L
.60793 .20816 L
.5883 .21023 L
.56868 .21094 L
.54906 .2104 L
.52943 .20854 L
.50981 .20499 L
.49019 .19861 L
.48503 .19584 L
.49019 .18513 L
s
.2 g
.50981 .34729 m
.52943 .34564 L
.54906 .34507 L
.56868 .34494 L
.5883 .34512 L
.60793 .34578 L
.62755 .34769 L
.64395 .35283 L
.62755 .37058 L
.62306 .37245 L
.60793 .37636 L
.5883 .37921 L
.56868 .38017 L
.54906 .37945 L
.52943 .37689 L
.51163 .37245 L
.50981 .37171 L
.49071 .35283 L
F
0 g
.50981 .34729 m
.52943 .34564 L
.54906 .34507 L
.56868 .34494 L
.5883 .34512 L
.60793 .34578 L
.62755 .34769 L
.64395 .35283 L
.62755 .37058 L
.62306 .37245 L
.60793 .37636 L
.5883 .37921 L
.56868 .38017 L
.54906 .37945 L
.52943 .37689 L
.51163 .37245 L
.50981 .37171 L
.49071 .35283 L
.50981 .34729 L
s
.3 g
.50981 .23167 m
.52943 .22578 L
.54906 .22687 L
.56868 .22718 L
.5883 .22677 L
.60793 .22555 L
.62755 .23207 L
.64114 .23509 L
.64342 .25471 L
.62755 .25969 L
.60793 .26339 L
.5883 .26542 L
.56868 .26613 L
.54906 .2656 L
.52943 .26376 L
.50981 .26033 L
.4912 .25471 L
.49349 .23509 L
F
0 g
.50981 .23167 m
.52943 .22578 L
.54906 .22687 L
.56868 .22718 L
.5883 .22677 L
.60793 .22555 L
.62755 .23207 L
.64114 .23509 L
.64342 .25471 L
.62755 .25969 L
.60793 .26339 L
.5883 .26542 L
.56868 .26613 L
.54906 .2656 L
.52943 .26376 L
.50981 .26033 L
.4912 .25471 L
.49349 .23509 L
.50981 .23167 L
s
.9 g
.52943 .29102 m
.54906 .28964 L
.56868 .2893 L
.5883 .28976 L
.60793 .29135 L
.62193 .29396 L
.61341 .31358 L
.60793 .3149 L
.5883 .31801 L
.56868 .31903 L
.54906 .31827 L
.52943 .3155 L
.52107 .31358 L
.51275 .29396 L
F
0 g
.52943 .29102 m
.54906 .28964 L
.56868 .2893 L
.5883 .28976 L
.60793 .29135 L
.62193 .29396 L
.61341 .31358 L
.60793 .3149 L
.5883 .31801 L
.56868 .31903 L
.54906 .31827 L
.52943 .3155 L
.52107 .31358 L
.51275 .29396 L
.52943 .29102 L
s
.2 g
.52943 .24259 m
.54906 .2389 L
.56868 .23814 L
.5883 .23917 L
.60779 .25471 L
.5883 .25841 L
.56868 .25958 L
.54906 .2587 L
.52943 .25538 L
.52683 .25471 L
F
0 g
.52943 .24259 m
.54906 .2389 L
.56868 .23814 L
.5883 .23917 L
.60779 .25471 L
.5883 .25841 L
.56868 .25958 L
.54906 .2587 L
.52943 .25538 L
.52683 .25471 L
.52943 .24259 L
s
.1 g
.54906 .35132 m
.56868 .35083 L
.5883 .35149 L
.60383 .35283 L
.5883 .37066 L
.57173 .37245 L
.56868 .37252 L
.56302 .37245 L
.54906 .37114 L
.53364 .35283 L
F
0 g
.54906 .35132 m
.56868 .35083 L
.5883 .35149 L
.60383 .35283 L
.5883 .37066 L
.57173 .37245 L
.56868 .37252 L
.56302 .37245 L
.54906 .37114 L
.53364 .35283 L
.54906 .35132 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00?Oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0dooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kS?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0hooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8b
onk^kS?ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08_ooool003gooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0=_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0<oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg03?ooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL08_ooool003Gooooo1_l0
0003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400[ooooo`Ko0000
1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100<oooool01Ol@413o
oooooooooooooooo410@03[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@03Cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@02;ooooo000o
ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000fooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000cooooo`05o`000?ooooooooooooooool0
0000>_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000=Oooool00onH
V9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000008_ooool0043ooooo00?oMgMgofIV
I_ooool00_ooool01Ol0003ooooooooooooooooo000003Kooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000003?ooooo00Go0000ooooooooooooooooo`00000jooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`03ogMgMomVIVKooooo00;o
oooo00Go0000ooooooooooooooooo`00000Rooooo`00@Oooool01Ol0003ooooooooooooooooo410@
00?ooooo00?o410@ooooooooool0=?ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@4100<oooool01Ol@413ooooooooooooooooo410@03[ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@03Oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo023ooooo000mooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg03Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg03?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0jooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0cooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02;ooooo000mooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^03Cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^03?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`03oeEEEOmVIVKo000000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0cooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02;ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo000Joooooooo0000C_l00001ooooo`00
6_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0?Ooo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool08ooo
ool1o`00007ooooo0008ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKo
oooo00?o0000ooooooooool0oooooom:ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooom:ooooo`7o
00000Oooool000Go00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41001_ooool00ol0003oooooooooo`3ooooood[ooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?ooooooB?ooool3o`00007o
oooo000:ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo0008ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Oooooooogmo
Od3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Ooo
ooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000
ooooooooool01?oooon]ogmoOaCo0000O_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?oooonQogmoO`co00005?nIVIT;o`0007?oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CoooooW_moOgl3o`0002_oVIVI0_l0001aogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04oooooicoOgmo0_l0000`oiVIV@;o0000KomoOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?oooonLogmoO`03o`000?nIVIWoVIVI037oVIVI00?o
0000ogmoOomoOgl0K?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonK
ogmoO`03o`000?nIVIWoVIVI03;oVIVI00?o0000ogmoOomoOgl0K?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?oooonKogmoO`03o`000?nIVIWoVIVI03?oVIVI00?o0000ogmo
OomoOgl0JomoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonJogmoO`;o
0000<onIVIT3o`0006goOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
W?moOgl3o`0002goVIVI0ol0001`ogmoO`Kooooo0Ol00001ooooo`003oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Kooooo00?o0000ooooooooool01?oooonOogmoO`?o00009_nIVIT4o`0007?oOgmo
1_ooool1o`00007ooooo000?ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003ooooo
ooooo`04oooooj;oOgmo1Ol0000NoiVIV@?o0000MomoOgl6ooooo`7o00000Oooool000oooooo00Go
410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00CoooooYomoOgl=o`0000KoVIVI
2ol0001jogmoO`Kooooo0Ol00001ooooo`003oooool01Ol0003ooooooooooooooooo000000Kooooo
0ol00004oooookCoOgmo1_l00025ogmoO`Cooooo0ol00001ooooo`003oooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo
000?ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`04oooool3oOgmo
2?l0001gogmoO`Kooooo0Ol00001ooooo`003oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo
00?o0000ooooooooool01?oooonBogmoObko00002?mVIVHCo`0006CoOgmo1_ooool1o`00007ooooo
000?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`04ooooohkoOgmo
1?l00019ofIVIPCo0000H?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
oon=ogmoO`03o`000?mVIVKoIVIV01SoIVIV7_l0000IofIVIP03o`000?moOgooOgmo05goOgmo1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooRomoOgl2o`0001SoIVIV0ol0000N
oda<C0?o00005omVIVH00ol0003oOgmoogmoO`1LogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04oooooh[oOgmo00?o0000ofIVI_mVIVH04omVIVH5o`0002CoC4a<1?l0000DofIV
IP03o`000?moOgooOgmo05_oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
ooooROmoOgl00ol0003oIVIVofIVIP0AofIVIP?o0000;Om<C4`2o`0001?oIVIV00?o0000ogmoOomo
Ogl0F_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon:ogmoO`03o`00
0?mVIVKoIVIV013oIVIV00?o0000oda<C?m<C4`03Om<C4`Bo`0000ooC4a<00?o0000ofIVI_mVIVH0
4OmVIVH00ol0003oOgmoogmoO`1JogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04oooooh_oOgmo00?o0000ofIVI_mVIVH03omVIVH00ol0003oC4a<oda<C009oda<C0Co00004_lc
<c<00ol0003oC4a<oda<C00<oda<C003o`000?mVIVKoIVIV013oIVIV00?o0000ogmoOomoOgl0Fomo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon<ogmoO`03o`000?mVIVKo
IVIV00koIVIV00?o0000oda<C?m<C4`02Om<C4`00ol0003o<c<coc<c<`0Doc<c<`03o`000?m<C4co
C4a<00_oC4a<00?o0000ofIVI_mVIVH03omVIVH00ol0003oOgmoogmoO`1LogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooohgoOgmo00?o0000ofIVI_mVIVH03?mVIVH00ol0
003oC4a<oda<C00:oda<C003o`000?lc<c?o<c<c01Go<c<c00?o0000oda<C?m<C4`02om<C4`00ol0
003oIVIVofIVIP0=ofIVIP03o`000?moOgooOgmo05goOgmo1_ooool1o`00007ooooo000Jooooo`;o
00001Ooooon>ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`02Om<C4`00ol0003o
<c<coc<c<`0Goc<c<`03o`000?m<C4coC4a<00[oC4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003o
OgmoogmoO`1NogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04ooooohooOgmo
0ol0000:ofIVIP?o00002Om<C4`4o`0001Co<c<c1?l0000:oda<C0;o00002omVIVH3o`00067oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooT_moOgl3o`0000[oIVIV0ol0
000:oda<C0?o00002olc<c<6o`0000_oC4a<0ol0000:ofIVIP?o0000I?moOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?oooonEogmoO`?o00002_mVIVH5o`0000SoC4a<2ol0000=
oda<C0Co00002OmVIVH4o`0006OoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CoooooV?moOgl3o`0000coIVIV1ol0000Boda<C0Oo00001_mVIVH7o`0006_oOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CoooooVomoOgl6o`0000goIVIV4_l00007ofIVIPKo
0000L_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonQogmoO`go0000
4_mVIVH7o`0007SoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooQomo
Ogl6o`0000GoOgmo3_l0000>ogmoOa;o00003OmoOglHo`0005[oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CoooooQ_moOgl00ol0003oVIVIoiVIV@04oiVIV@Go00003_nIVIT]
o`0001SoVIVI00?o0000ogmoOomoOgl0EomoOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?oooon6ogmoO`03o`000?nIVIWoVIVI05coVIVI00?o0000ogmoOomoOgl0EomoOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon5ogmoO`03o`000?nIVIWoVIVI017o
VIVI??l0000AoiVIV@03o`000?moOgooOgmo05KoOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CoooooQ?moOgl00ol0003oVIVIoiVIV@0=oiVIV@Go00003Onc/k<Ro`0000go/k>c
1?l0000>oiVIV@03o`000?moOgooOgmo05GoOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Ooo
oon4ogmoO`03o`000?nIVIWoVIVI00_oVIVI0_l0000<ok>c/`Ko00008_o<c<`6o`0000_o/k>c0_l0
000<oiVIV@03o`000?moOgooOgmo05GoOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CoooooPomoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c00Oo/k>c1Ol00006
olc<c27o00001oo<c<`4o`0000Wo/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`1D
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooh;oOgmo0_l0000<oiVI
V@03o`000?nc/k?o/k>c00Ko/k>c0_l00008olc<c0?o00008OoVi^H2o`0000Woc<c<00?o0000ok>c
/onc/k<01onc/k<00ol0003oVIVIoiVIV@0:oiVIV@03o`000?moOgooOgmo05?oOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CoooooQ?moOgl00ol0003oVIVIoiVIV@09oiVIV@03
o`000?nc/k?o/k>c00Ko/k>c00?o0000olc<c?o<c<`01oo<c<`00ol0003oi^KVonKViP0RonKViP03
o`000?o<c<coc<c<00Ooc<c<00?o0000ok>c/onc/k<01onc/k<00ol0003oVIVIoiVIV@09oiVIV@03
o`000?moOgooOgmo05CoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
QOmoOgl00ol0003oVIVIoiVIV@09oiVIV@03o`000?nc/k?o/k>c00Ko/k>c00?o0000olc<c?o<c<`0
1oo<c<`00ol0003oi^KVonKViP0PonKViP03o`000?o<c<coc<c<00Ooc<c<00?o0000ok>c/onc/k<0
1onc/k<00ol0003oVIVIoiVIV@09oiVIV@03o`000?moOgooOgmo05GoOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CoooooQ_moOgl00ol0003oVIVIoiVIV@09oiVIV@03o`000?nc
/k?o/k>c00Ko/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003oi^KVonKViP0PonKViP03o`000?o<
c<coc<c<00Ooc<c<00?o0000ok>c/onc/k<01_nc/k<00ol0003oVIVIoiVIV@09oiVIV@03o`000?mo
OgooOgmo05KoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooQomoOgl0
0ol0003oVIVIoiVIV@09oiVIV@03o`000?nc/k?o/k>c00Go/k>c00?o0000olc<c?o<c<`01oo<c<`0
0ol0003oi^KVonKViP0NonKViP03o`000?o<c<coc<c<00Soc<c<00?o0000ok>c/onc/k<01Onc/k<0
0ol0003oVIVIoiVIV@09oiVIV@03o`000?moOgooOgmo05OoOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CoooooR?moOgl2o`0000[oVIVI00?o0000ok>c/onc/k<01Onc/k<00ol0
003oc<c<olc<c006olc<c003o`000?oVi^Koi^KV01koi^KV00?o0000olc<c?o<c<`01_o<c<`2o`00
00Oo/k>c00?o0000oiVIVOnIVIT02?nIVIT2o`0005[oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CoooooR_moOgl2o`0000WoVIVI0_l00006ok>c/`03o`000?o<c<coc<c<00Go
c<c<00?o0000onKVi_oVi^H07_oVi^H00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00Go
/k>c0_l00008oiVIV@?o0000G?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?oooon<ogmoO`?o00002?nIVIT2o`0000Go/k>c1?l00004olc<c0So00004_oVi^H6o`0000Koc<c<
0_l00006ok>c/`;o00002?nIVIT2o`0005ooOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CoooooSomoOgl3o`0000OoVIVI0ol00006ok>c/`Go00001oo<c<`6o`0000Koi^KV1_l0
0007olc<c0Go00001_nc/k<2o`0000SoVIVI0_l0001QogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04oooooi;oOgmo0ol00007oiVIV@Go00001_nc/k<7o`0000Koc<c<1_l00006
olc<c0Oo00002_nc/k<00ol0003oVIVIoiVIV@05oiVIV@?o0000HomoOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?oooonEogmoO`Go00001onIVIT6o`0000Oo/k>c4_l00007ok>c
/`[o00001OnIVIT3o`0006KoOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Ooooon7ogmoO`Ko
00003OmoOgl7o`0000KoVIVI8?l0000<oiVIV@?o0000JOmoOgl5ooooo`;o00000Oooool001[ooooo
00?o0000ooooooooool01?oooon5ogmoO`;o00001_mVIVH6o`0000koOgmo3Ol0000BoiVIV@ko0000
0onIVIT2o`0000OoOgmo3Ol0001HogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooohCoOgmo00?o0000ofIVI_mVIVH03?mVIVHDo`0000OoOgmo4_l00007ogmoOa?o00003OmV
IVH2o`0005KoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooQ?moOgl0
0ol0003oIVIVofIVIP0PofIVIR3o00008OmVIVH00ol0003oOgmoogmoO`1DogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooohCoOgmo00?o0000ofIVI_mVIVH06OmVIVH7o`00
047oIVIV00?o0000ogmoOomoOgl0E?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?oooon4ogmoO`03o`000?mVIVKoIVIV01;oIVIV1ol00007oda<C2ko00004omVIVH00ol0003o
OgmoogmoO`1DogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooh?oOgmo
00?o0000ofIVI_mVIVH03_mVIVH5o`0000goC4a<8_l0000=oda<C0?o00004OmVIVH00ol0003oOgmo
ogmoO`1CogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooh?oOgmo00?o
0000ofIVI_mVIVH03OmVIVH00ol0003oC4a<oda<C00;oda<C0Go00008_lc<c<4o`0000coC4a<00?o
0000ofIVI_mVIVH03_mVIVH00ol0003oOgmoogmoO`1CogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04oooooh?oOgmo00?o0000ofIVI_mVIVH03?mVIVH00ol0003oC4a<oda<C009
oda<C0?o00003?lc<c<Do`0000_o<c<c0ol0000:oda<C003o`000?mVIVKoIVIV00goIVIV00?o0000
ogmoOomoOgl0DomoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon3ogmo
O`;o00003?mVIVH00ol0003oC4a<oda<C008oda<C0;o00003?lc<c<3o`0001Co6ATI0_l0000<oc<c
<`03o`000?m<C4coC4a<00SoC4a<00?o0000ofIVI_mVIVH02omVIVH2o`0005GoOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CoooooQOmoOgl00ol0003oIVIVofIVIP0:ofIVIP03
o`000?m<C4coC4a<00WoC4a<00?o0000oc<c<olc<c<02_lc<c<00ol0003o6ATIoaTI6@0DoaTI6@03
o`000?lc<c?o<c<c00[o<c<c00?o0000oda<C?m<C4`02?m<C4`00ol0003oIVIVofIVIP0:ofIVIP03
o`000?moOgooOgmo05GoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
Q_moOgl00ol0003oIVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<00WoC4a<00?o0000oc<c<olc<c<0
2_lc<c<00ol0003o6ATIoaTI6@0BoaTI6@03o`000?lc<c?o<c<c00[o<c<c00?o0000oda<C?m<C4`0
2?m<C4`00ol0003oIVIVofIVIP0:ofIVIP03o`000?moOgooOgmo05KoOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CoooooQomoOgl00ol0003oIVIVofIVIP0:ofIVIP03o`000?m<
C4coC4a<00WoC4a<00?o0000oc<c<olc<c<02_lc<c<00ol0003o6ATIoaTI6@0@oaTI6@03o`000?lc
<c?o<c<c00[o<c<c00?o0000oda<C?m<C4`02?m<C4`00ol0003oIVIVofIVIP0:ofIVIP03o`000?mo
OgooOgmo05OoOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Ooooon8ogmoO`;o00002omVIVH2
o`0000[oC4a<00?o0000oc<c<olc<c<02_lc<c<00ol0003o6ATIoaTI6@0>oaTI6@03o`000?lc<c?o
<c<c00[o<c<c00?o0000oda<C?m<C4`01om<C4`2o`0000_oIVIV0_l0001JogmoO`Gooooo0_l00001
ooooo`006_ooool00ol0003oooooooooo`04oooooh[oOgmo0_l0000;ofIVIP;o00002Om<C4`00ol0
003o<c<coc<c<`0:oc<c<`03o`000?lI6AWo6ATI00co6ATI00?o0000oc<c<olc<c<02_lc<c<00ol0
003oC4a<oda<C005oda<C0?o00002_mVIVH3o`0005coOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CoooooS?moOgl3o`0000[oIVIV0_l00008oda<C0?o00002_lc<c<>o`0000Wo
<c<c1?l00007oda<C003o`000?mVIVKoIVIV00WoIVIV0_l0001OogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooohooOgmo0ol00009ofIVIP03o`000?m<C4coC4a<00SoC4a<
0ol0000Koc<c<`?o00002_m<C4`00ol0003oIVIVofIVIP08ofIVIP;o0000HOmoOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?oooonBogmoO`?o00001omVIVH2o`0000_oC4a<1Ol0
000Boc<c<`Co00002om<C4`2o`0000SoIVIV0ol0001SogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04oooooiGoOgmo0ol00006ofIVIP?o00003Om<C4`Bo`0000goC4a<0_l00006
ofIVIPCo0000I_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonHogmo
O`?o00001_mVIVH2o`0000?oC4a<2?l0000Boda<C0So00000om<C4`2o`0000GoIVIV0ol0001Zogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooi_oOgmo1_l00002ofIVIP?o
00002?mVIVHBo`0000SoIVIV0ol00002ofIVIPGo0000KOmoOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?oooonQogmoO`Ko00008?mVIVH6o`0007;oOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CoooooYomoOglPo`0007SoOgmo1_ooool1o`00007ooooo0008
ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000:ooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00CoooooT_moOgl?o`0002co
Ogmo3Ol0001UogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003oooooooooo`02ooooo`05oa0@
4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`04ooooohooOgmo0ol0000?oiVIVBco
00003OnIVIT3o`0006;oOgmo1_ooool1o`00007ooooo000:ooooo`03o`000?oooooooooo00;ooooo
00Go0000ooooooooooooooooo`000006ooooo`?o00001?oooon?ogmoO`03o`000?nIVIWoVIVI04_o
VIVI00?o0000ogmoOomoOgl0GomoOgl4ooooo`?o00000Oooool000[ooooo00?o0000ooooooooool0
0_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool01?oooon>ogmoO`03
o`000?nIVIWoVIVI04goVIVI00?o0000ogmoOomoOgl0G_moOgl6ooooo`7o00000Oooool000[ooooo
00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000oooooooo
ool01?oooon=ogmoO`03o`000?nIVIWoVIVI04ooVIVI00?o0000ogmoOomoOgl0GOmoOgl6ooooo`7o
00000Oooool000[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Ko
oooo00?o0000ooooooooool01?oooon=ogmoO`03o`000?nIVIWoVIVI04koVIVI00?o0000ogmoOomo
Ogl0G_moOgl6ooooo`7o00000Oooool000Sooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool01?oooon>ogmoO`03o`000?nIVIWoVIVI04_o
VIVI0_l0001QogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooohooOgmo
0_l0001:oiVIV@03o`000?moOgooOgmo067oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CoooooTOmoOgl00ol0003oVIVIoiVIV@16oiVIV@03o`000?moOgooOgmo06;oOgmo1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooT_moOgl2o`0004GoVIVI00?o0000
ogmoOomoOgl0HomoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonDogmo
O`03o`000?nIVIWoVIVI047oVIVI00?o0000ogmoOomoOgl0I?moOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?oooonEogmoO`;o0000?_nIVIT3o`0006OoOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CoooooUomoOgl3o`0003WoVIVI0_l0001ZogmoO`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooi[oOgmo0_l0000eoiVIV@;o0000K?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonLogmoO`;o0000<OnIVIT2
o`0006koOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OoooonNogmoO`?o0000:onIVIT3o`00
073oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooXOmoOgl2o`0000?o
VIVI2?l0000BoiVIV@co0000LomoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?oooonSogmoO`?o00002?moOglBo`0007ooOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo
1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Oooooooogmo
Od3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Ooo
ooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo0007ooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo0007ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo0008ooooo`03oiRHV?lQ8B7ok^k^00Cooooo
00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`002Oooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool0
00001_ooool3o`0000CooooooomoOgm0ogmoO`Cooooo0ol00001ooooo`002_ooool00omgMgOoIVIV
ooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool000_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo00Cooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo0007ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo0007ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000Gooooo
oomoOgm0ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`00
00GooooooomoOgm0ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`001oooool01OnHV9So410@o`000?lb<S;oc<c<
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`001oooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`002oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool01?oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000[ooooo00?oZJVY
oa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo0ol00004ooooooooOgmo@?mo
Ogl4ooooo`?o00000Oooool000Wooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooo
oooo000000Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000:
ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`001oooool01Ol@413oV9RHoooooonj
^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`001oooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo0_l00005ooooooooOgmo@?moOgl5oooo
o`;o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo0_l00005ooooooooOgmo@?mo
Ogl5ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool000Wooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP06oooo
o`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`04oooo
ooooOgmo@?moOgl6ooooo`7o00000Oooool000Oooooo1Ol00003ooooo`05oa0@4?oooooooooooooo
ool@41001_ooool3o`0000CooooooomoOgm0ogmoO`Cooooo0ol00001ooooo`001oooool01?m4A4Co
gMgMooooool00004ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3o
oooood[ooooo0Ol00001ooooo`001oooool01?oMgMgoEEEEooooool00004ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`3ooooood[ooooo0Ol00001ooooo`002?ooool0
0omgMgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003ooooooooo
o`3ooooood[ooooo0Ol00001ooooo`002?ooool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooood[ooooo0Ol00001ooooo`002Oooool0
0omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003ooooooooo
o`0Sooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0?Oooool00ol0003ooooooooo
o`0mooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool08oooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool1o`00007ooooo000Joooo
oooo0000C_l00001ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-30.1723, -14.304, 0.195672, \
0.195672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0192308 0.211538 0.0192308 [
[.11538 -0.0125 -9 -9 ]
[.11538 -0.0125 9 0 ]
[.30769 -0.0125 -9 -9 ]
[.30769 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69231 -0.0125 -6 -9 ]
[.69231 -0.0125 6 0 ]
[.88462 -0.0125 -6 -9 ]
[.88462 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -18 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .21154 -6 -4.5 ]
[-0.0125 .21154 0 4.5 ]
[-0.0125 .40385 -12 -4.5 ]
[-0.0125 .40385 0 4.5 ]
[-0.0125 .59615 -12 -4.5 ]
[-0.0125 .59615 0 4.5 ]
[-0.0125 .78846 -12 -4.5 ]
[-0.0125 .78846 0 4.5 ]
[-0.0125 .98077 -12 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11538 0 m
.11538 .00625 L
s
[(-20)] .11538 -0.0125 0 1 Mshowa
.30769 0 m
.30769 .00625 L
s
[(-10)] .30769 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69231 0 m
.69231 .00625 L
s
[(10)] .69231 -0.0125 0 1 Mshowa
.88462 0 m
.88462 .00625 L
s
[(20)] .88462 -0.0125 0 1 Mshowa
.125 Mabswid
.15385 0 m
.15385 .00375 L
s
.19231 0 m
.19231 .00375 L
s
.23077 0 m
.23077 .00375 L
s
.26923 0 m
.26923 .00375 L
s
.34615 0 m
.34615 .00375 L
s
.38462 0 m
.38462 .00375 L
s
.42308 0 m
.42308 .00375 L
s
.46154 0 m
.46154 .00375 L
s
.53846 0 m
.53846 .00375 L
s
.57692 0 m
.57692 .00375 L
s
.61538 0 m
.61538 .00375 L
s
.65385 0 m
.65385 .00375 L
s
.73077 0 m
.73077 .00375 L
s
.76923 0 m
.76923 .00375 L
s
.80769 0 m
.80769 .00375 L
s
.84615 0 m
.84615 .00375 L
s
.07692 0 m
.07692 .00375 L
s
.03846 0 m
.03846 .00375 L
s
.92308 0 m
.92308 .00375 L
s
.96154 0 m
.96154 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(-10)] -0.0125 .01923 1 0 Mshowa
0 .21154 m
.00625 .21154 L
s
[(0)] -0.0125 .21154 1 0 Mshowa
0 .40385 m
.00625 .40385 L
s
[(10)] -0.0125 .40385 1 0 Mshowa
0 .59615 m
.00625 .59615 L
s
[(20)] -0.0125 .59615 1 0 Mshowa
0 .78846 m
.00625 .78846 L
s
[(30)] -0.0125 .78846 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(40)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .05769 m
.00375 .05769 L
s
0 .09615 m
.00375 .09615 L
s
0 .13462 m
.00375 .13462 L
s
0 .17308 m
.00375 .17308 L
s
0 .25 m
.00375 .25 L
s
0 .28846 m
.00375 .28846 L
s
0 .32692 m
.00375 .32692 L
s
0 .36538 m
.00375 .36538 L
s
0 .44231 m
.00375 .44231 L
s
0 .48077 m
.00375 .48077 L
s
0 .51923 m
.00375 .51923 L
s
0 .55769 m
.00375 .55769 L
s
0 .63462 m
.00375 .63462 L
s
0 .67308 m
.00375 .67308 L
s
0 .71154 m
.00375 .71154 L
s
0 .75 m
.00375 .75 L
s
0 .82692 m
.00375 .82692 L
s
0 .86538 m
.00375 .86538 L
s
0 .90385 m
.00375 .90385 L
s
0 .94231 m
.00375 .94231 L
s
.25 Mabswid
0 0 m
0 1 L
s
.11538 .99375 m
.11538 1 L
s
.30769 .99375 m
.30769 1 L
s
.5 .99375 m
.5 1 L
s
.69231 .99375 m
.69231 1 L
s
.88462 .99375 m
.88462 1 L
s
.125 Mabswid
.15385 .99625 m
.15385 1 L
s
.19231 .99625 m
.19231 1 L
s
.23077 .99625 m
.23077 1 L
s
.26923 .99625 m
.26923 1 L
s
.34615 .99625 m
.34615 1 L
s
.38462 .99625 m
.38462 1 L
s
.42308 .99625 m
.42308 1 L
s
.46154 .99625 m
.46154 1 L
s
.53846 .99625 m
.53846 1 L
s
.57692 .99625 m
.57692 1 L
s
.61538 .99625 m
.61538 1 L
s
.65385 .99625 m
.65385 1 L
s
.73077 .99625 m
.73077 1 L
s
.76923 .99625 m
.76923 1 L
s
.80769 .99625 m
.80769 1 L
s
.84615 .99625 m
.84615 1 L
s
.07692 .99625 m
.07692 1 L
s
.03846 .99625 m
.03846 1 L
s
.92308 .99625 m
.92308 1 L
s
.96154 .99625 m
.96154 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .21154 m
1 .21154 L
s
.99375 .40385 m
1 .40385 L
s
.99375 .59615 m
1 .59615 L
s
.99375 .78846 m
1 .78846 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .05769 m
1 .05769 L
s
.99625 .09615 m
1 .09615 L
s
.99625 .13462 m
1 .13462 L
s
.99625 .17308 m
1 .17308 L
s
.99625 .25 m
1 .25 L
s
.99625 .28846 m
1 .28846 L
s
.99625 .32692 m
1 .32692 L
s
.99625 .36538 m
1 .36538 L
s
.99625 .44231 m
1 .44231 L
s
.99625 .48077 m
1 .48077 L
s
.99625 .51923 m
1 .51923 L
s
.99625 .55769 m
1 .55769 L
s
.99625 .63462 m
1 .63462 L
s
.99625 .67308 m
1 .67308 L
s
.99625 .71154 m
1 .71154 L
s
.99625 .75 m
1 .75 L
s
.99625 .82692 m
1 .82692 L
s
.99625 .86538 m
1 .86538 L
s
.99625 .90385 m
1 .90385 L
s
.99625 .94231 m
1 .94231 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.6 g
.43132 .30092 m
.45094 .29944 L
.47057 .3002 L
.49019 .29718 L
.50981 .30221 L
.52943 .30535 L
.54906 .3075 L
.56868 .3086 L
.5883 .3085 L
.60793 .30722 L
.62755 .30492 L
.64717 .30159 L
.6668 .29591 L
.68642 .30001 L
.70604 .29946 L
.72567 .30165 L
.73941 .31358 L
.72567 .33126 L
.7229 .3332 L
.70604 .34161 L
.68642 .34833 L
.66894 .35283 L
.6668 .35337 L
.64717 .35324 L
.62755 .35686 L
.60793 .35944 L
.5883 .36078 L
.56868 .36088 L
.54906 .35974 L
.52943 .35736 L
.50981 .35386 L
.49019 .35407 L
.48503 .35283 L
.47057 .34923 L
.45094 .34284 L
.43132 .33377 L
.43089 .3332 L
.41434 .31358 L
F
0 g
.43132 .30092 m
.45094 .29944 L
.47057 .3002 L
.49019 .29718 L
.50981 .30221 L
.52943 .30535 L
.54906 .3075 L
.56868 .3086 L
.5883 .3085 L
.60793 .30722 L
.62755 .30492 L
.64717 .30159 L
.6668 .29591 L
.68642 .30001 L
.70604 .29946 L
.72567 .30165 L
.73941 .31358 L
.72567 .33126 L
.7229 .3332 L
.70604 .34161 L
.68642 .34833 L
.66894 .35283 L
.6668 .35337 L
.64717 .35324 L
.62755 .35686 L
.60793 .35944 L
.5883 .36078 L
.56868 .36088 L
.54906 .35974 L
.52943 .35736 L
.50981 .35386 L
.49019 .35407 L
.48503 .35283 L
.47057 .34923 L
.45094 .34284 L
.43132 .33377 L
.43089 .3332 L
.41434 .31358 L
.43132 .30092 L
s
.4 g
.43132 .36138 m
.45094 .35975 L
.47057 .36076 L
.49019 .36238 L
.50981 .35751 L
.52943 .36179 L
.54906 .36399 L
.56868 .36494 L
.5883 .36486 L
.60793 .36373 L
.62755 .36129 L
.64717 .35647 L
.6668 .36211 L
.68642 .36053 L
.70604 .35973 L
.72567 .36234 L
.73465 .37245 L
.72567 .38567 L
.71756 .39207 L
.70604 .40311 L
.68642 .4073 L
.672 .4117 L
.6668 .4133 L
.64717 .41798 L
.62755 .41689 L
.60793 .41998 L
.5883 .42153 L
.56868 .42165 L
.54906 .42033 L
.52943 .41749 L
.50981 .41321 L
.49019 .41417 L
.48185 .4117 L
.47057 .40836 L
.45094 .4063 L
.43616 .39207 L
.43132 .38846 L
.41915 .37245 L
F
0 g
.43132 .36138 m
.45094 .35975 L
.47057 .36076 L
.49019 .36238 L
.50981 .35751 L
.52943 .36179 L
.54906 .36399 L
.56868 .36494 L
.5883 .36486 L
.60793 .36373 L
.62755 .36129 L
.64717 .35647 L
.6668 .36211 L
.68642 .36053 L
.70604 .35973 L
.72567 .36234 L
.73465 .37245 L
.72567 .38567 L
.71756 .39207 L
.70604 .40311 L
.68642 .4073 L
.672 .4117 L
.6668 .4133 L
.64717 .41798 L
.62755 .41689 L
.60793 .41998 L
.5883 .42153 L
.56868 .42165 L
.54906 .42033 L
.52943 .41749 L
.50981 .41321 L
.49019 .41417 L
.48185 .4117 L
.47057 .40836 L
.45094 .4063 L
.43616 .39207 L
.43132 .38846 L
.41915 .37245 L
.43132 .36138 L
s
.4 g
.45094 .24965 m
.47057 .24726 L
.49019 .25205 L
.50981 .24791 L
.52943 .24863 L
.54906 .24922 L
.56868 .24953 L
.5883 .24951 L
.60793 .24914 L
.62755 .24851 L
.64717 .2478 L
.6668 .25122 L
.68642 .24641 L
.70604 .25038 L
.71635 .25471 L
.71398 .27433 L
.70604 .27921 L
.68642 .28721 L
.6668 .29287 L
.66208 .29396 L
.64717 .29668 L
.62755 .30049 L
.60793 .30352 L
.5883 .30527 L
.56868 .3054 L
.54906 .3039 L
.52943 .30105 L
.50981 .29731 L
.49168 .29396 L
.49019 .29362 L
.47057 .28824 L
.45094 .28073 L
.43979 .27433 L
.43747 .25471 L
F
0 g
.45094 .24965 m
.47057 .24726 L
.49019 .25205 L
.50981 .24791 L
.52943 .24863 L
.54906 .24922 L
.56868 .24953 L
.5883 .24951 L
.60793 .24914 L
.62755 .24851 L
.64717 .2478 L
.6668 .25122 L
.68642 .24641 L
.70604 .25038 L
.71635 .25471 L
.71398 .27433 L
.70604 .27921 L
.68642 .28721 L
.6668 .29287 L
.66208 .29396 L
.64717 .29668 L
.62755 .30049 L
.60793 .30352 L
.5883 .30527 L
.56868 .3054 L
.54906 .3039 L
.52943 .30105 L
.50981 .29731 L
.49168 .29396 L
.49019 .29362 L
.47057 .28824 L
.45094 .28073 L
.43979 .27433 L
.43747 .25471 L
.45094 .24965 L
s
.7 g
.47057 .3124 m
.49019 .3053 L
.50981 .30753 L
.52943 .30914 L
.54906 .31031 L
.56868 .31091 L
.5883 .31086 L
.60793 .31016 L
.62755 .30891 L
.64717 .30722 L
.6668 .30486 L
.68642 .31335 L
.68707 .31358 L
.68887 .3332 L
.68642 .33499 L
.6668 .34448 L
.64717 .35044 L
.6366 .35283 L
.62755 .35382 L
.60793 .35604 L
.5883 .35738 L
.56868 .35748 L
.54906 .35633 L
.52943 .3542 L
.51722 .35283 L
.50981 .3512 L
.49019 .3456 L
.47057 .33693 L
.46503 .3332 L
.46676 .31358 L
F
0 g
.47057 .3124 m
.49019 .3053 L
.50981 .30753 L
.52943 .30914 L
.54906 .31031 L
.56868 .31091 L
.5883 .31086 L
.60793 .31016 L
.62755 .30891 L
.64717 .30722 L
.6668 .30486 L
.68642 .31335 L
.68707 .31358 L
.68887 .3332 L
.68642 .33499 L
.6668 .34448 L
.64717 .35044 L
.6366 .35283 L
.62755 .35382 L
.60793 .35604 L
.5883 .35738 L
.56868 .35748 L
.54906 .35633 L
.52943 .3542 L
.51722 .35283 L
.50981 .3512 L
.49019 .3456 L
.47057 .33693 L
.46503 .3332 L
.46676 .31358 L
.47057 .3124 L
s
.6 g
.49019 .20642 m
.50981 .20336 L
.52943 .20215 L
.54906 .20167 L
.56868 .20151 L
.5883 .20152 L
.60793 .20172 L
.62755 .20228 L
.64717 .20367 L
.6668 .20728 L
.6797 .21546 L
.6668 .22861 L
.65037 .23509 L
.64717 .23575 L
.62755 .23885 L
.60793 .24078 L
.5883 .24174 L
.56868 .24181 L
.54906 .24099 L
.52943 .23923 L
.50981 .23634 L
.50349 .23509 L
.49019 .23017 L
.47413 .21546 L
F
0 g
.49019 .20642 m
.50981 .20336 L
.52943 .20215 L
.54906 .20167 L
.56868 .20151 L
.5883 .20152 L
.60793 .20172 L
.62755 .20228 L
.64717 .20367 L
.6668 .20728 L
.6797 .21546 L
.6668 .22861 L
.65037 .23509 L
.64717 .23575 L
.62755 .23885 L
.60793 .24078 L
.5883 .24174 L
.56868 .24181 L
.54906 .24099 L
.52943 .23923 L
.50981 .23634 L
.50349 .23509 L
.49019 .23017 L
.47413 .21546 L
.49019 .20642 L
s
.6 g
.49019 .43446 m
.50981 .4341 L
.52943 .43461 L
.54906 .43517 L
.56868 .43548 L
.5883 .43545 L
.60793 .43509 L
.62755 .43451 L
.64717 .43406 L
.6668 .43475 L
.6778 .45094 L
.6668 .45844 L
.64717 .46634 L
.63115 .47057 L
.62755 .47114 L
.60793 .47401 L
.5883 .47569 L
.56868 .47582 L
.54906 .47437 L
.52943 .47165 L
.52263 .47057 L
.50981 .46728 L
.49019 .46001 L
.47603 .45094 L
F
0 g
.49019 .43446 m
.50981 .4341 L
.52943 .43461 L
.54906 .43517 L
.56868 .43548 L
.5883 .43545 L
.60793 .43509 L
.62755 .43451 L
.64717 .43406 L
.6668 .43475 L
.6778 .45094 L
.6668 .45844 L
.64717 .46634 L
.63115 .47057 L
.62755 .47114 L
.60793 .47401 L
.5883 .47569 L
.56868 .47582 L
.54906 .47437 L
.52943 .47165 L
.52263 .47057 L
.50981 .46728 L
.49019 .46001 L
.47603 .45094 L
.49019 .43446 L
s
.3 g
.49019 .3723 m
.50981 .36936 L
.52943 .3699 L
.54906 .37051 L
.56868 .37083 L
.5883 .3708 L
.60793 .37043 L
.62755 .36979 L
.64717 .36936 L
.66548 .37245 L
.6668 .37283 L
.67514 .39207 L
.6668 .39752 L
.64717 .40557 L
.62755 .41059 L
.62226 .4117 L
.60793 .41303 L
.5883 .41432 L
.56868 .41442 L
.54906 .4133 L
.5317 .4117 L
.52943 .4112 L
.50981 .40653 L
.49019 .39912 L
.4787 .39207 L
.48892 .37245 L
F
0 g
.49019 .3723 m
.50981 .36936 L
.52943 .3699 L
.54906 .37051 L
.56868 .37083 L
.5883 .3708 L
.60793 .37043 L
.62755 .36979 L
.64717 .36936 L
.66548 .37245 L
.6668 .37283 L
.67514 .39207 L
.6668 .39752 L
.64717 .40557 L
.62755 .41059 L
.62226 .4117 L
.60793 .41303 L
.5883 .41432 L
.56868 .41442 L
.54906 .4133 L
.5317 .4117 L
.52943 .4112 L
.50981 .40653 L
.49019 .39912 L
.4787 .39207 L
.48892 .37245 L
.49019 .3723 L
s
.3 g
.49019 .26253 m
.50981 .25847 L
.52943 .25708 L
.54906 .25659 L
.56868 .25644 L
.5883 .25645 L
.60793 .25664 L
.62755 .25722 L
.64717 .25885 L
.6668 .26387 L
.67397 .27433 L
.6668 .28 L
.64717 .28853 L
.62755 .29351 L
.62543 .29396 L
.60793 .29745 L
.5883 .29976 L
.56868 .29994 L
.54906 .29795 L
.52943 .29413 L
.52866 .29396 L
.50981 .2895 L
.49019 .28178 L
.47987 .27433 L
F
0 g
.49019 .26253 m
.50981 .25847 L
.52943 .25708 L
.54906 .25659 L
.56868 .25644 L
.5883 .25645 L
.60793 .25664 L
.62755 .25722 L
.64717 .25885 L
.6668 .26387 L
.67397 .27433 L
.6668 .28 L
.64717 .28853 L
.62755 .29351 L
.62543 .29396 L
.60793 .29745 L
.5883 .29976 L
.56868 .29994 L
.54906 .29795 L
.52943 .29413 L
.52866 .29396 L
.50981 .2895 L
.49019 .28178 L
.47987 .27433 L
.49019 .26253 L
s
.8 g
.49019 .3231 m
.50981 .31615 L
.52943 .31445 L
.54906 .31392 L
.56868 .31378 L
.5883 .31379 L
.60793 .31397 L
.62755 .31461 L
.64717 .31666 L
.66478 .3332 L
.64717 .34268 L
.62755 .34847 L
.60793 .35189 L
.59914 .35283 L
.5883 .3535 L
.56868 .35362 L
.5547 .35283 L
.54906 .35227 L
.52943 .34915 L
.50981 .34382 L
.49019 .33411 L
.48907 .3332 L
F
0 g
.49019 .3231 m
.50981 .31615 L
.52943 .31445 L
.54906 .31392 L
.56868 .31378 L
.5883 .31379 L
.60793 .31397 L
.62755 .31461 L
.64717 .31666 L
.66478 .3332 L
.64717 .34268 L
.62755 .34847 L
.60793 .35189 L
.59914 .35283 L
.5883 .3535 L
.56868 .35362 L
.5547 .35283 L
.54906 .35227 L
.52943 .34915 L
.50981 .34382 L
.49019 .33411 L
.48907 .3332 L
.49019 .3231 L
s
.9 g
.52943 .32179 m
.54906 .31961 L
.56868 .31891 L
.5883 .31896 L
.60793 .31982 L
.62755 .32243 L
.64221 .3332 L
.62755 .34099 L
.60793 .34598 L
.5883 .34823 L
.56868 .34839 L
.54906 .3465 L
.52943 .34204 L
.51168 .3332 L
F
0 g
.52943 .32179 m
.54906 .31961 L
.56868 .31891 L
.5883 .31896 L
.60793 .31982 L
.62755 .32243 L
.64221 .3332 L
.62755 .34099 L
.60793 .34598 L
.5883 .34823 L
.56868 .34839 L
.54906 .3465 L
.52943 .34204 L
.51168 .3332 L
.52943 .32179 L
s
.2 g
.52943 .2664 m
.54906 .26404 L
.56868 .26324 L
.5883 .2633 L
.60793 .26428 L
.62755 .26706 L
.64218 .27433 L
.62755 .2844 L
.60793 .28961 L
.5883 .29186 L
.56868 .29202 L
.54906 .29013 L
.52943 .28553 L
.51171 .27433 L
F
0 g
.52943 .2664 m
.54906 .26404 L
.56868 .26324 L
.5883 .2633 L
.60793 .26428 L
.62755 .26706 L
.64218 .27433 L
.62755 .2844 L
.60793 .28961 L
.5883 .29186 L
.56868 .29202 L
.54906 .29013 L
.52943 .28553 L
.51171 .27433 L
.52943 .2664 L
s
.2 g
.52943 .38033 m
.54906 .3785 L
.56868 .37797 L
.5883 .37801 L
.60793 .37867 L
.62755 .3809 L
.6406 .39207 L
.62755 .39895 L
.60793 .4041 L
.5883 .40641 L
.56868 .40657 L
.54906 .40463 L
.52943 .40004 L
.51327 .39207 L
F
0 g
.52943 .38033 m
.54906 .3785 L
.56868 .37797 L
.5883 .37801 L
.60793 .37867 L
.62755 .3809 L
.6406 .39207 L
.62755 .39895 L
.60793 .4041 L
.5883 .40641 L
.56868 .40657 L
.54906 .40463 L
.52943 .40004 L
.51327 .39207 L
.52943 .38033 L
s
1 g
.54906 .32781 m
.56868 .32557 L
.5883 .32572 L
.60793 .32863 L
.61621 .3332 L
.60793 .33729 L
.5883 .34129 L
.56868 .34154 L
.54906 .33831 L
.53725 .3332 L
F
0 g
.54906 .32781 m
.56868 .32557 L
.5883 .32572 L
.60793 .32863 L
.61621 .3332 L
.60793 .33729 L
.5883 .34129 L
.56868 .34154 L
.54906 .33831 L
.53725 .3332 L
.54906 .32781 L
s
.1 g
.56868 .27236 m
.5883 .2726 L
.59917 .27433 L
.5883 .28152 L
.56868 .28195 L
.55466 .27433 L
F
0 g
.56868 .27236 m
.5883 .2726 L
.59917 .27433 L
.5883 .28152 L
.56868 .28195 L
.55466 .27433 L
.56868 .27236 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00?Oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0dooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kS?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0hooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8b
onk^kS?ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08_ooool003gooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0=_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0<oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg03?ooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL08_ooool003Gooooo1_l0
0003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400[ooooo`Ko0000
1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100<oooool01Ol@413o
oooooooooooooooo410@03[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@03Cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@02;ooooo000o
ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000fooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000cooooo`05o`000?ooooooooooooooool0
0000>_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000=Oooool00onH
V9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000008_ooool0043ooooo00?oMgMgofIV
I_ooool00_ooool01Ol0003ooooooooooooooooo000003Kooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000003?ooooo00Go0000ooooooooooooooooo`00000jooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`03ogMgMomVIVKooooo00;o
oooo00Go0000ooooooooooooooooo`00000Rooooo`00@Oooool01Ol0003ooooooooooooooooo410@
00?ooooo00?o410@ooooooooool0=?ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@4100<oooool01Ol@413ooooooooooooooooo410@03[ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@03Oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo023ooooo000mooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg03Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg03?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0jooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0cooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02;ooooo000mooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^03Cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^03?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`03oeEEEOmVIVKo000000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0cooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02;ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo000Joooooooo0000C_l00001ooooo`00
6_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0?Ooo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool08ooo
ool1o`00007ooooo0008ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKo
oooo00?o0000ooooooooool0oooooom:ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooom:ooooo`7o
00000Oooool000Go00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41001_ooool00ol0003oooooooooo`3ooooood[ooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?ooooooB?ooool3o`00007o
oooo000:ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo0008ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Oooooooogmo
Od3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Ooo
ooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000oooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP06ooooo`03o`000?oooooooooo00CoooooX?moOgleo`0006[oOgmo1_ooool1o`00007ooooo
000?ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`04oooooi_oOgmo
1Ol0000eoiVIV@Co0000I_moOgl6ooooo`7o00000Oooool000oooooo00Go410@oooooooooooooooo
oa0@4006ooooo`03o`000?oooooooooo00CoooooVOmoOgl2o`0003koVIVI00?o0000ogmoOomoOgl0
HomoOgl6ooooo`7o00000Oooool000oooooo00Go0000ooooooooooooooooo`000006ooooo`?o0000
1?oooonHogmoO`03o`000?nIVIWoVIVI03ooVIVI00?o0000ogmoOomoOgl0H_moOgl4ooooo`?o0000
0Oooool000oooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00Cooooo
UomoOgl00ol0003oVIVIoiVIV@11oiVIV@03o`000?moOgooOgmo067oOgmo1_ooool1o`00007ooooo
000?ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`04oooooiSoOgmo
00?o0000oiVIVOnIVIT0@?nIVIT00ol0003oOgmoogmoO`1QogmoO`Kooooo0Ol00001ooooo`003ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?oooonIogmoO`03o`00
0?nIVIWoVIVI03koVIVI00?o0000ogmoOomoOgl0H_moOgl6ooooo`7o00000Oooool000oooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo00CoooooV_moOgl00ol0003oVIVI
oiVIV@0loiVIV@03o`000?moOgooOgmo06?oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CoooooVomoOgl00ol0003oVIVIoiVIV@0joiVIV@03o`000?moOgooOgmo06CoOgmo1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooW?moOgl2o`0003SoVIVI0_l0001W
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooikoOgmo0_l0000coiVI
V@?o0000JOmoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonPogmoO`Oo
00009_nIVIT6o`0006coOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
YomoOgl7o`0001WoVIVI1_l0001bogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooojkoOgmo6Ol0001hogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooomcoOgmo1?l0001OogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
oi;oOgmo2?l00006ogmoOcGo00001?moOgl3o`0000CoIVIV0ol0001LogmoO`Kooooo0Ol00001oooo
o`006_ooool2o`0000GoooooSOmoOgl5o`0000SoIVIV1_l0000eofIVIPCo00002_mVIVH4o`0005So
Ogmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooR_moOgl3o`0005[oIVIV
00?o0000ogmoOomoOgl0EOmoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
oon:ogmoO`03o`000?mVIVKoIVIV01CoIVIV;Ol0000IofIVIP03o`000?moOgooOgmo05GoOgmo1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooR_moOgl00ol0003oIVIVofIVIP0A
ofIVIP?o0000;Om<C4`7o`0001;oIVIV00?o0000ogmoOomoOgl0EOmoOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?oooon:ogmoO`03o`000?mVIVKoIVIV00ooIVIV0_l0000?oda<
C1_o00003Om<C4`3o`0000ooIVIV00?o0000ogmoOomoOgl0EOmoOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?oooon;ogmoO`03o`000?mVIVKoIVIV00koIVIV00?o0000oda<C?m<
C4`02Om<C4`5o`0001_o<c<c1?l0000;oda<C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomo
Ogl0E_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon;ogmoO`03o`00
0?mVIVKoIVIV00goIVIV00?o0000oda<C?m<C4`02?m<C4`2o`0002Co<c<c00?o0000oda<C?m<C4`0
2Om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo05KoOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CoooooRomoOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<
C4coC4a<00OoC4a<0_l0000>oc<c<`co00003Olc<c<00ol0003oC4a<oda<C008oda<C003o`000?mV
IVKoIVIV00_oIVIV00?o0000ogmoOomoOgl0E_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?oooon;ogmoO`;o00003?mVIVH2o`0000SoC4a<0_l0000<oc<c<`?o00002olI6AT2
o`0000co<c<c0_l0000:oda<C003o`000?mVIVKoIVIV00WoIVIV0_l0001HogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooohgoOgmo0_l0000<ofIVIP03o`000?m<C4coC4a<
00OoC4a<0_l0000<oc<c<`?o00002?lI6AT00ol0003o<c<coc<c<`0;oc<c<`03o`000?m<C4coC4a<
00WoC4a<00?o0000ofIVI_mVIVH02?mVIVH2o`0005[oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CoooooSomoOgl3o`0000[oIVIV0_l00009oda<C0;o00003Olc<c<8o`0000go
<c<c00?o0000oda<C?m<C4`01om<C4`3o`0000SoIVIV0ol0001LogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04oooooi;oOgmo0ol00009ofIVIP?o00002?m<C4`3o`0001co<c<c
0ol00007oda<C0?o00002OmVIVH2o`0005ooOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Ooo
oonEogmoO`?o00002OmVIVH2o`0000WoC4a<0ol0000Foc<c<`?o00001om<C4`3o`0000[oIVIV0_l0
001QogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04oooooiSoOgmo0ol00008
ofIVIPCo00002?m<C4`5o`0000co<c<c1Ol00007oda<C0?o00002_mVIVH3o`0006?oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooVomoOgl6o`0000KoIVIV1Ol00008oda<
C0co00001_m<C4`6o`0000OoIVIV1_l0001VogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04oooooiWoOgmo1_l00002ogmoO`Go00001_mVIVH3o`00017oC4a<1_l00007ofIVIPKo
00000_moOgl6o`0006CoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
S?moOgl=o`0000KoVIVI0ol00004ogmoO`?o00001_mVIVHAo`0000OoIVIV1_l00005ogmoO`?o0000
1_nIVIT=o`0005OoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooQomo
Ogl5o`0001KoVIVI1Ol00002ogmoO`Go00004_mVIVH7o`0000KoOgmo1Ol0000FoiVIV@Co0000Domo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon6ogmoO`03o`000?nIVIWo
VIVI017oVIVI1ol00006oiVIVAWo00001omoOgl6o`0000OoVIVI1Ol0000CoiVIV@03o`000?moOgoo
Ogmo053oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooQOmoOgl00ol0
003oVIVIoiVIV@0?oiVIV@?o00001onc/k<co`0000Go/k>c0_l0000BoiVIV@03o`000?moOgooOgmo
04ooOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooQ?moOgl00ol0003o
VIVIoiVIV@0>oiVIV@;o00005onc/k<Io`0001Co/k>c0_l0000AoiVIV@03o`000?moOgooOgmo04ko
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooPomoOgl00ol0003oVIVI
oiVIV@0>oiVIV@03o`000?nc/k?o/k>c00oo/k>c:?l0000?ok>c/`03o`000?nIVIWoVIVI00ooVIVI
00?o0000ogmoOomoOgl0COmoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
oon3ogmoO`03o`000?nIVIWoVIVI00koVIVI00?o0000ok>c/onc/k<02_nc/k<5o`0002Soc<c<1?l0
000;ok>c/`03o`000?nIVIWoVIVI00ooVIVI00?o0000ogmoOomoOgl0COmoOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?oooon4ogmoO`03o`000?nIVIWoVIVI00goVIVI00?o0000
ok>c/onc/k<01onc/k<3o`0000Ooc<c<8?l0000:olc<c003o`000?nc/k?o/k>c00So/k>c00?o0000
oiVIVOnIVIT03_nIVIT00ol0003oOgmoogmoO`1>ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooohGoOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`05ok>c
/`;o00002Oo<c<`00ol0003oi^KVonKViP0NonKViPCo00001oo<c<`00ol0003o/k>cok>c/`07ok>c
/`03o`000?nIVIWoVIVI00goVIVI00?o0000ogmoOomoOgl0ComoOgl6ooooo`7o00000Oooool001[o
oooo0_l00005ooooohKoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`05ok>c/`03
o`000?o<c<coc<c<00Koc<c<0_l00008onKViQ;o00002ooVi^H00ol0003oc<c<olc<c005olc<c003
o`000?nc/k?o/k>c00Oo/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`1@ogmoO`Go
oooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04ooooohOoOgmo00?o0000oiVIVOnIVIT0
2_nIVIT00ol0003o/k>cok>c/`05ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000onKVi_oVi^H0
1_oVi^H2o`0001;ooooo1Ol00007onKViP03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<0
1_nc/k<00ol0003oVIVIoiVIV@0:oiVIV@03o`000?moOgooOgmo057oOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CoooooR?moOgl2o`0000[oVIVI00?o0000ok>c/onc/k<01Onc
/k<00ol0003oc<c<olc<c004olc<c0;o00001ooVi^H2o`0001Oooooo0_l00006onKViP;o00001_o<
c<`2o`0000Oo/k>c00?o0000oiVIVOnIVIT01onIVIT3o`0005CoOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CoooooR_moOgl3o`0000OoVIVI00?o0000ok>c/onc/k<01Onc/k<2
o`0000Ooc<c<0_l00007onKViP;o00005?ooool00ol0003oi^KVonKViP05onKViP03o`000?o<c<co
c<c<00Coc<c<0_l00007ok>c/`;o00002?nIVIT2o`0005OoOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CoooooSOmoOgl2o`0000KoVIVI0ol00006ok>c/`?o00001_o<c<`2o`00
00Ooi^KV1?l0000<ooooo`Co00001ooVi^H00ol0003oc<c<olc<c003olc<c0;o00001onc/k<2o`00
00WoVIVI00?o0000ogmoOomoOgl0EomoOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?oooon?ogmoO`;o00001onIVIT3o`0000Ko/k>c0_l00006olc<c0?o00002?oVi^H<o`0000So
i^KV0ol00004olc<c0;o00001onc/k<2o`0000SoVIVI0ol0001JogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04oooooi7oOgmo0_l00008oiVIV@Co00001?nc/k<3o`0000Koc<c<
0ol0000FonKViP?o00001?o<c<`3o`0000Ko/k>c0ol00007oiVIV@?o0000GOmoOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?oooonCogmoO`;o00002_nIVIT3o`0000Co/k>c0ol0
0006olc<c1Ko00000_o<c<`5o`0000Ko/k>c0ol00007oiVIV@?o0000H?moOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?oooonEogmoO`Co00002OnIVIT3o`0000Co/k>c1Ol0000D
olc<c0Go00002?nc/k<3o`0000OoVIVI0ol0001SogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04oooooiWoOgmo:Ol00005ok>c/a;o0000I_moOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?oooonQogmoO`Go000000?oOgmoo`000?l000009?l00002ogmoO`Co
0000K?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon<ogmoO`ko0000
1?moOgl3o`0000GoIVIV0ol00005ogmoOaWo00001OmoOgl3o`0000CoIVIV0ol00004ogmoO`ko0000
EomoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon7ogmoO`Go00003_mV
IVH4o`0000_oIVIV1Ol0000BogmoO`co00002_mVIVH4o`0000koIVIV0ol0001DogmoO`Kooooo0Ol0
0001ooooo`006_ooool2o`0000GoooooQ_moOgl00ol0003oIVIVofIVIP0UofIVIQ;o0000:omVIVH0
0ol0003oOgmoogmoO`1AogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04oooo
ohGoOgmo00?o0000ofIVI_mVIVH06?mVIVH>o`0001WoIVIV3Ol0000HofIVIP03o`000?moOgooOgmo
053oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooQ?moOgl00ol0003o
IVIVofIVIP0EofIVIPCo00003_m<C4`Io`0000goC4a<1?l0000EofIVIP03o`000?moOgooOgmo04oo
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooQ?moOgl00ol0003oIVIV
ofIVIP0EofIVIP03o`000?m<C4coC4a<03SoC4a<00?o0000ofIVI_mVIVH04omVIVH00ol0003oOgmo
ogmoO`1?ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooohGoOgmo00?o
0000ofIVI_mVIVH04omVIVH00ol0003oC4a<oda<C00?oda<C1_o00003om<C4`00ol0003oIVIVofIV
IP0BofIVIP03o`000?moOgooOgmo053oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CoooooQ_moOgl00ol0003oIVIVofIVIP0BofIVIP03o`000?m<C4coC4a<00[oC4a<1Ol0000K
oc<c<`?o00003Om<C4`00ol0003oIVIVofIVIP0@ofIVIP03o`000?moOgooOgmo057oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooQ_moOgl00ol0003oIVIVofIVIP0AofIV
IP03o`000?m<C4coC4a<00[oC4a<00?o0000oc<c<olc<c<08Olc<c<00ol0003oC4a<oda<C00:oda<
C003o`000?mVIVKoIVIV013oIVIV00?o0000ogmoOomoOgl0DOmoOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?oooon7ogmoO`03o`000?mVIVKoIVIV00ooIVIV00?o0000oda<C?m<
C4`02_m<C4`00ol0003o<c<coc<c<`0Soc<c<`03o`000?m<C4coC4a<00WoC4a<00?o0000ofIVI_mV
IVH03omVIVH00ol0003oOgmoogmoO`1BogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooohSoOgmo0_l0000?ofIVIP03o`000?m<C4coC4a<00WoC4a<00?o0000oc<c<olc<c<0
9Olc<c<00ol0003oC4a<oda<C009oda<C003o`000?mVIVKoIVIV00goIVIV00?o0000ogmoOomoOgl0
DomoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon:ogmoO`03o`000?mV
IVKoIVIV00_oIVIV0_l0000:oda<C0;o00009olc<c<2o`0000[oC4a<00?o0000ofIVI_mVIVH03?mV
IVH00ol0003oOgmoogmoO`1DogmoO`Kooooo0Ol00001ooooo`002?ooool4o`000008oa0@4?oooooo
ooooonk^k_lb<S;o0000oc8b<_o^k^h6ooooo`03o`000?oooooooooo00CoooooRomoOgl00ol0003o
IVIVofIVIP0<ofIVIP;o00002_m<C4`3o`0002;o<c<c0_l0000;oda<C003o`000?mVIVKoIVIV00co
IVIV00?o0000ogmoOomoOgl0EOmoOgl6ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?oooon<ogmoO`03
o`000?mVIVKoIVIV00goIVIV0_l0000;oda<C0?o00007?lc<c<3o`0000[oC4a<0ol0000>ofIVIP03
o`000?moOgooOgmo05KoOgmo1_ooool1o`00007ooooo000:ooooo`03o`000?oooooooooo00;ooooo
00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00CoooooSOmoOgl00ol0003o
IVIVofIVIP0>ofIVIP?o00002om<C4`3o`0001Ko<c<c0ol0000:oda<C0?o00004?mVIVH00ol0003o
OgmoogmoO`1GogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000001_ooool3o`0000CoooooS_moOgl00ol0003oIVIVofIVIP0@ofIVIP;o
00003?m<C4`5o`0000co<c<c1Ol0000:oda<C0?o00003omVIVH4o`0005[oOgmo1?ooool3o`00007o
oooo000:ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00CoooooSomoOgl9o`0000_oIVIV1?l0000=oda<C0co00003?m<C4`3o`0000co
IVIV1_l0001NogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003oooooooooo`02ooooo`05oa0@
4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`04oooooiSoOgmo1?l0000;ofIVIPOo
00006?m<C4`6o`0000coIVIV0ol0001TogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`04oooooico
Ogmo2ol00007ofIVIQSo00003_mVIVH4o`0006OoOgmo1_ooool1o`00007ooooo0008ooooo`03oeEE
EOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo00Co
ooooYomoOgl7o`0001WoIVIV3Ol0001[ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooojkoOgmo1_l0000<ofIVIPOo0000N?moOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?oooondogmoO`co0000OomoOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonLogmoOcco0000
IomoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonKogmoO`03o`000?nI
VIWoVIVI03WoVIVI00?o0000ogmoOomoOgl0IOmoOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?oooonJogmoO`03o`000?nIVIWoVIVI03_oVIVI00?o0000ogmoOomoOgl0I?moOgl6
ooooo`7o00000Oooool001[ooooo0_l00005oooooiWoOgmo00?o0000oiVIVOnIVIT0?OnIVIT00ol0
003oOgmoogmoO`1SogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04oooooiSo
Ogmo00?o0000oiVIVOnIVIT0?_nIVIT00ol0003oOgmoogmoO`1SogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04oooooiOoOgmo0_l00011oiVIV@03o`000?moOgooOgmo06;oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooVOmoOgl2o`0003koVIVI00?o
0000ogmoOomoOgl0HomoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonK
ogmoO`03o`000?nIVIWoVIVI03[oVIVI00?o0000ogmoOomoOgl0I?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?oooonLogmoO`;o0000>?nIVIT2o`0006OoOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CoooooW_moOgl3o`0003;oVIVI0ol0001YogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooj7oOgmo0_l0000^oiVIV@;o0000
K?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonSogmoO`?o0000:?nI
VIT3o`0006koOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooY_moOgl8
o`0001WoVIVI1ol0001aogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
ojkoOgmo1_l0000<oiVIV@Oo0000N?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?oooondogmoO`co0000OomoOgl6ooooo`7o00000Oooool001[ooooo0_l00005ooooooooOgmo
@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooo
ogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo0_l00005oooo
ooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3o
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooooomo
Ogm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo0_l0
0005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool01?oooooo
ogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo
@?moOgl6ooooo`7o00000Oooool000Oooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000Oooooo00Go
V9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003o
ooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000Sooooo00?oV9RHob4Q8Oo^k^h0
1?ooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool01?ooooooogmoOd3o
Ogmo1_ooool1o`00007ooooo0009ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooooooo
ooooo`000006ooooo`?o00001?ooooooogmoOd3oOgmo1?ooool3o`00007ooooo000:ooooo`03ogMg
MomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00Co
oooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002oooool01Ol0003ooooooooooooooooo410@00?o
oooo00?o410@ooooooooool01?ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool000Oooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000Oo
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool0
0ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo
@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o0000
1OooooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooooomo
Ogm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
ooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3o
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Joooo
o`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo
@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooo
ogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo
000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
ooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3o
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooooomo
Ogm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00
007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooo
ogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo0007ooooo`05oiRHV?l@413o0000oc8b
<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool01?oooooo
ogmoOd3oOgmo1_ooool1o`00007ooooo0007ooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_oo
ool1o`00007ooooo000;ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413ooooooooo
o`04ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool0
0onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool3o`0000Cooooooomo
Ogm0ogmoO`Cooooo0ol00001ooooo`002Oooool00ol@413o0000okZj^P03ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Ooo
ool000[ooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@00Kooooo00?o
0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo0007ooooo`05oa0@4?nHV9So
oooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0
1?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo0007ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool01?ooooooogmoOd3o
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooooomo
Ogm0ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001
ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooo
ogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo
0_l00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooooomo
Ogm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000GooooooomoOgm0ogmo
O`Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo
@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000Gooooooomo
Ogm0ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
ooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3o
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo
0Ol00001ooooo`002Oooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^
00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000:ooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`001oooool5o`0000?ooooo00Go410@oooooooo
oooooooooa0@4006ooooo`?o00001?ooooooogmoOd3oOgmo1?ooool3o`00007ooooo0007ooooo`04
odA4A?oMgMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
oooo0?ooooooB_ooool1o`00007ooooo0007ooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?ooooooB_ooool1o`00007ooooo0008
ooooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oo
oooooooo0?ooooooB_ooool1o`00007ooooo0008ooooo`03onk^k_m4A4Co000000Cooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?ooooooB_ooool1o`00007ooooo0009
ooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oo
oooooooo02?ooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0mooooo`03o`000?oo
oooooooo03gooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Sooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`7o00000Oooool0
01[oooooool0001>o`00007ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-30.1723, -14.304, 0.195672, \
0.195672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0192308 0.211538 0.0192308 [
[.11538 -0.0125 -9 -9 ]
[.11538 -0.0125 9 0 ]
[.30769 -0.0125 -9 -9 ]
[.30769 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69231 -0.0125 -6 -9 ]
[.69231 -0.0125 6 0 ]
[.88462 -0.0125 -6 -9 ]
[.88462 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -18 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .21154 -6 -4.5 ]
[-0.0125 .21154 0 4.5 ]
[-0.0125 .40385 -12 -4.5 ]
[-0.0125 .40385 0 4.5 ]
[-0.0125 .59615 -12 -4.5 ]
[-0.0125 .59615 0 4.5 ]
[-0.0125 .78846 -12 -4.5 ]
[-0.0125 .78846 0 4.5 ]
[-0.0125 .98077 -12 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11538 0 m
.11538 .00625 L
s
[(-20)] .11538 -0.0125 0 1 Mshowa
.30769 0 m
.30769 .00625 L
s
[(-10)] .30769 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69231 0 m
.69231 .00625 L
s
[(10)] .69231 -0.0125 0 1 Mshowa
.88462 0 m
.88462 .00625 L
s
[(20)] .88462 -0.0125 0 1 Mshowa
.125 Mabswid
.15385 0 m
.15385 .00375 L
s
.19231 0 m
.19231 .00375 L
s
.23077 0 m
.23077 .00375 L
s
.26923 0 m
.26923 .00375 L
s
.34615 0 m
.34615 .00375 L
s
.38462 0 m
.38462 .00375 L
s
.42308 0 m
.42308 .00375 L
s
.46154 0 m
.46154 .00375 L
s
.53846 0 m
.53846 .00375 L
s
.57692 0 m
.57692 .00375 L
s
.61538 0 m
.61538 .00375 L
s
.65385 0 m
.65385 .00375 L
s
.73077 0 m
.73077 .00375 L
s
.76923 0 m
.76923 .00375 L
s
.80769 0 m
.80769 .00375 L
s
.84615 0 m
.84615 .00375 L
s
.07692 0 m
.07692 .00375 L
s
.03846 0 m
.03846 .00375 L
s
.92308 0 m
.92308 .00375 L
s
.96154 0 m
.96154 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(-10)] -0.0125 .01923 1 0 Mshowa
0 .21154 m
.00625 .21154 L
s
[(0)] -0.0125 .21154 1 0 Mshowa
0 .40385 m
.00625 .40385 L
s
[(10)] -0.0125 .40385 1 0 Mshowa
0 .59615 m
.00625 .59615 L
s
[(20)] -0.0125 .59615 1 0 Mshowa
0 .78846 m
.00625 .78846 L
s
[(30)] -0.0125 .78846 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(40)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .05769 m
.00375 .05769 L
s
0 .09615 m
.00375 .09615 L
s
0 .13462 m
.00375 .13462 L
s
0 .17308 m
.00375 .17308 L
s
0 .25 m
.00375 .25 L
s
0 .28846 m
.00375 .28846 L
s
0 .32692 m
.00375 .32692 L
s
0 .36538 m
.00375 .36538 L
s
0 .44231 m
.00375 .44231 L
s
0 .48077 m
.00375 .48077 L
s
0 .51923 m
.00375 .51923 L
s
0 .55769 m
.00375 .55769 L
s
0 .63462 m
.00375 .63462 L
s
0 .67308 m
.00375 .67308 L
s
0 .71154 m
.00375 .71154 L
s
0 .75 m
.00375 .75 L
s
0 .82692 m
.00375 .82692 L
s
0 .86538 m
.00375 .86538 L
s
0 .90385 m
.00375 .90385 L
s
0 .94231 m
.00375 .94231 L
s
.25 Mabswid
0 0 m
0 1 L
s
.11538 .99375 m
.11538 1 L
s
.30769 .99375 m
.30769 1 L
s
.5 .99375 m
.5 1 L
s
.69231 .99375 m
.69231 1 L
s
.88462 .99375 m
.88462 1 L
s
.125 Mabswid
.15385 .99625 m
.15385 1 L
s
.19231 .99625 m
.19231 1 L
s
.23077 .99625 m
.23077 1 L
s
.26923 .99625 m
.26923 1 L
s
.34615 .99625 m
.34615 1 L
s
.38462 .99625 m
.38462 1 L
s
.42308 .99625 m
.42308 1 L
s
.46154 .99625 m
.46154 1 L
s
.53846 .99625 m
.53846 1 L
s
.57692 .99625 m
.57692 1 L
s
.61538 .99625 m
.61538 1 L
s
.65385 .99625 m
.65385 1 L
s
.73077 .99625 m
.73077 1 L
s
.76923 .99625 m
.76923 1 L
s
.80769 .99625 m
.80769 1 L
s
.84615 .99625 m
.84615 1 L
s
.07692 .99625 m
.07692 1 L
s
.03846 .99625 m
.03846 1 L
s
.92308 .99625 m
.92308 1 L
s
.96154 .99625 m
.96154 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .21154 m
1 .21154 L
s
.99375 .40385 m
1 .40385 L
s
.99375 .59615 m
1 .59615 L
s
.99375 .78846 m
1 .78846 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .05769 m
1 .05769 L
s
.99625 .09615 m
1 .09615 L
s
.99625 .13462 m
1 .13462 L
s
.99625 .17308 m
1 .17308 L
s
.99625 .25 m
1 .25 L
s
.99625 .28846 m
1 .28846 L
s
.99625 .32692 m
1 .32692 L
s
.99625 .36538 m
1 .36538 L
s
.99625 .44231 m
1 .44231 L
s
.99625 .48077 m
1 .48077 L
s
.99625 .51923 m
1 .51923 L
s
.99625 .55769 m
1 .55769 L
s
.99625 .63462 m
1 .63462 L
s
.99625 .67308 m
1 .67308 L
s
.99625 .71154 m
1 .71154 L
s
.99625 .75 m
1 .75 L
s
.99625 .82692 m
1 .82692 L
s
.99625 .86538 m
1 .86538 L
s
.99625 .90385 m
1 .90385 L
s
.99625 .94231 m
1 .94231 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.6 g
.43132 .3288 m
.45094 .32185 L
.47057 .32811 L
.49019 .33281 L
.50981 .33171 L
.52656 .3332 L
.52943 .33346 L
.54906 .33479 L
.56868 .33558 L
.5883 .33582 L
.60793 .33548 L
.62755 .33459 L
.64683 .3332 L
.64717 .33317 L
.6668 .33137 L
.68642 .33194 L
.70604 .32725 L
.72567 .31965 L
.74529 .32986 L
.75131 .3332 L
.74655 .35283 L
.74529 .35414 L
.72567 .36668 L
.7124 .37245 L
.70604 .37405 L
.68642 .38118 L
.6668 .38791 L
.64717 .38875 L
.62755 .39101 L
.61547 .39207 L
.60793 .39241 L
.5883 .39297 L
.56868 .39258 L
.5551 .39207 L
.54906 .39132 L
.52943 .38922 L
.50981 .38899 L
.49019 .38247 L
.47057 .37521 L
.46058 .37245 L
.45094 .36841 L
.43132 .35697 L
.42679 .35283 L
.42174 .3332 L
F
0 g
.43132 .3288 m
.45094 .32185 L
.47057 .32811 L
.49019 .33281 L
.50981 .33171 L
.52656 .3332 L
.52943 .33346 L
.54906 .33479 L
.56868 .33558 L
.5883 .33582 L
.60793 .33548 L
.62755 .33459 L
.64683 .3332 L
.64717 .33317 L
.6668 .33137 L
.68642 .33194 L
.70604 .32725 L
.72567 .31965 L
.74529 .32986 L
.75131 .3332 L
.74655 .35283 L
.74529 .35414 L
.72567 .36668 L
.7124 .37245 L
.70604 .37405 L
.68642 .38118 L
.6668 .38791 L
.64717 .38875 L
.62755 .39101 L
.61547 .39207 L
.60793 .39241 L
.5883 .39297 L
.56868 .39258 L
.5551 .39207 L
.54906 .39132 L
.52943 .38922 L
.50981 .38899 L
.49019 .38247 L
.47057 .37521 L
.46058 .37245 L
.45094 .36841 L
.43132 .35697 L
.42679 .35283 L
.42174 .3332 L
.43132 .3288 L
s
.4 g
.45094 .276 m
.47057 .27442 L
.49019 .2749 L
.50981 .27597 L
.52943 .27708 L
.54906 .27798 L
.56868 .27538 L
.5883 .27605 L
.60793 .27506 L
.62755 .27784 L
.64717 .27689 L
.6668 .27577 L
.68642 .27475 L
.70604 .27448 L
.72567 .27681 L
.73843 .29396 L
.72567 .3047 L
.7083 .31358 L
.70604 .3149 L
.68642 .32634 L
.6668 .32453 L
.64717 .32768 L
.62755 .32991 L
.60793 .33127 L
.5883 .33177 L
.56868 .33142 L
.54906 .33021 L
.52943 .32814 L
.50981 .32517 L
.49019 .32892 L
.47057 .31673 L
.46496 .31358 L
.45094 .30683 L
.43452 .29396 L
F
0 g
.45094 .276 m
.47057 .27442 L
.49019 .2749 L
.50981 .27597 L
.52943 .27708 L
.54906 .27798 L
.56868 .27538 L
.5883 .27605 L
.60793 .27506 L
.62755 .27784 L
.64717 .27689 L
.6668 .27577 L
.68642 .27475 L
.70604 .27448 L
.72567 .27681 L
.73843 .29396 L
.72567 .3047 L
.7083 .31358 L
.70604 .3149 L
.68642 .32634 L
.6668 .32453 L
.64717 .32768 L
.62755 .32991 L
.60793 .33127 L
.5883 .33177 L
.56868 .33142 L
.54906 .33021 L
.52943 .32814 L
.50981 .32517 L
.49019 .32892 L
.47057 .31673 L
.46496 .31358 L
.45094 .30683 L
.43452 .29396 L
.45094 .276 L
s
.4 g
.45094 .38993 m
.47057 .38924 L
.49019 .39203 L
.49072 .39207 L
.50981 .39417 L
.52943 .39602 L
.54906 .3974 L
.56868 .39822 L
.5883 .39847 L
.60793 .39812 L
.62755 .39719 L
.64717 .39572 L
.6668 .39379 L
.6807 .39207 L
.68642 .3916 L
.70604 .38862 L
.72567 .39014 L
.73935 .39207 L
.7366 .4117 L
.72567 .42106 L
.70717 .43132 L
.70604 .43165 L
.68642 .43906 L
.6668 .44623 L
.64717 .45071 L
.63776 .45094 L
.62755 .45239 L
.60793 .45427 L
.5883 .45495 L
.56868 .45447 L
.54906 .45282 L
.53527 .45094 L
.52943 .45005 L
.50981 .44728 L
.49019 .44048 L
.47057 .43275 L
.46606 .43132 L
.45094 .42336 L
.4364 .4117 L
.43682 .39207 L
F
0 g
.45094 .38993 m
.47057 .38924 L
.49019 .39203 L
.49072 .39207 L
.50981 .39417 L
.52943 .39602 L
.54906 .3974 L
.56868 .39822 L
.5883 .39847 L
.60793 .39812 L
.62755 .39719 L
.64717 .39572 L
.6668 .39379 L
.6807 .39207 L
.68642 .3916 L
.70604 .38862 L
.72567 .39014 L
.73935 .39207 L
.7366 .4117 L
.72567 .42106 L
.70717 .43132 L
.70604 .43165 L
.68642 .43906 L
.6668 .44623 L
.64717 .45071 L
.63776 .45094 L
.62755 .45239 L
.60793 .45427 L
.5883 .45495 L
.56868 .45447 L
.54906 .45282 L
.53527 .45094 L
.52943 .45005 L
.50981 .44728 L
.49019 .44048 L
.47057 .43275 L
.46606 .43132 L
.45094 .42336 L
.4364 .4117 L
.43682 .39207 L
.45094 .38993 L
s
.7 g
.47057 .34461 m
.49019 .33943 L
.50981 .33865 L
.52943 .3389 L
.54906 .33937 L
.56868 .33973 L
.5883 .33984 L
.60793 .33968 L
.62755 .33928 L
.64717 .33882 L
.6668 .33868 L
.68642 .33983 L
.70604 .34784 L
.70755 .35283 L
.70604 .3553 L
.68642 .37002 L
.68139 .37245 L
.6668 .38094 L
.64717 .38243 L
.62755 .38558 L
.60793 .38741 L
.5883 .38808 L
.56868 .38761 L
.54906 .386 L
.52943 .38311 L
.50981 .38304 L
.49165 .37245 L
.49019 .37177 L
.47057 .35921 L
.46556 .35283 L
F
0 g
.47057 .34461 m
.49019 .33943 L
.50981 .33865 L
.52943 .3389 L
.54906 .33937 L
.56868 .33973 L
.5883 .33984 L
.60793 .33968 L
.62755 .33928 L
.64717 .33882 L
.6668 .33868 L
.68642 .33983 L
.70604 .34784 L
.70755 .35283 L
.70604 .3553 L
.68642 .37002 L
.68139 .37245 L
.6668 .38094 L
.64717 .38243 L
.62755 .38558 L
.60793 .38741 L
.5883 .38808 L
.56868 .38761 L
.54906 .386 L
.52943 .38311 L
.50981 .38304 L
.49165 .37245 L
.49019 .37177 L
.47057 .35921 L
.46556 .35283 L
.47057 .34461 L
s
.6 g
.49019 .23029 m
.50981 .22793 L
.52943 .2323 L
.54906 .22772 L
.56868 .22781 L
.5883 .22784 L
.60793 .22779 L
.62755 .22771 L
.64717 .23159 L
.6668 .22687 L
.68642 .23094 L
.69898 .23509 L
.69494 .25471 L
.68642 .25814 L
.6668 .2638 L
.64717 .26778 L
.62755 .27051 L
.60793 .27213 L
.5883 .27272 L
.56868 .27231 L
.54906 .27088 L
.52943 .26836 L
.50981 .26463 L
.49019 .25933 L
.47809 .25471 L
.47409 .23509 L
F
0 g
.49019 .23029 m
.50981 .22793 L
.52943 .2323 L
.54906 .22772 L
.56868 .22781 L
.5883 .22784 L
.60793 .22779 L
.62755 .22771 L
.64717 .23159 L
.6668 .22687 L
.68642 .23094 L
.69898 .23509 L
.69494 .25471 L
.68642 .25814 L
.6668 .2638 L
.64717 .26778 L
.62755 .27051 L
.60793 .27213 L
.5883 .27272 L
.56868 .27231 L
.54906 .27088 L
.52943 .26836 L
.50981 .26463 L
.49019 .25933 L
.47809 .25471 L
.47409 .23509 L
.49019 .23029 L
s
.3 g
.49019 .28868 m
.50981 .28531 L
.52943 .2843 L
.54906 .28406 L
.56868 .27647 L
.5883 .27767 L
.60793 .27588 L
.62755 .28408 L
.64717 .2844 L
.6668 .28566 L
.68642 .28994 L
.69284 .29396 L
.68642 .30703 L
.6764 .31358 L
.6668 .31695 L
.64717 .32182 L
.62755 .32498 L
.60793 .32682 L
.5883 .32749 L
.56868 .32703 L
.54906 .3254 L
.52943 .3225 L
.50981 .31799 L
.49665 .31358 L
.49019 .30973 L
.48023 .29396 L
F
0 g
.49019 .28868 m
.50981 .28531 L
.52943 .2843 L
.54906 .28406 L
.56868 .27647 L
.5883 .27767 L
.60793 .27588 L
.62755 .28408 L
.64717 .2844 L
.6668 .28566 L
.68642 .28994 L
.69284 .29396 L
.68642 .30703 L
.6764 .31358 L
.6668 .31695 L
.64717 .32182 L
.62755 .32498 L
.60793 .32682 L
.5883 .32749 L
.56868 .32703 L
.54906 .3254 L
.52943 .3225 L
.50981 .31799 L
.49665 .31358 L
.49019 .30973 L
.48023 .29396 L
.49019 .28868 L
s
.3 g
.50981 .4059 m
.52943 .40467 L
.54906 .40454 L
.56868 .40465 L
.5883 .4047 L
.60793 .40463 L
.62755 .40454 L
.64717 .40477 L
.6668 .40641 L
.68041 .4117 L
.6668 .42693 L
.65789 .43132 L
.64717 .44095 L
.62755 .43987 L
.60793 .44247 L
.5883 .44339 L
.56868 .44276 L
.54906 .44048 L
.52943 .4362 L
.51518 .43132 L
.50981 .4288 L
.49269 .4117 L
F
0 g
.50981 .4059 m
.52943 .40467 L
.54906 .40454 L
.56868 .40465 L
.5883 .4047 L
.60793 .40463 L
.62755 .40454 L
.64717 .40477 L
.6668 .40641 L
.68041 .4117 L
.6668 .42693 L
.65789 .43132 L
.64717 .44095 L
.62755 .43987 L
.60793 .44247 L
.5883 .44339 L
.56868 .44276 L
.54906 .44048 L
.52943 .4362 L
.51518 .43132 L
.50981 .4288 L
.49269 .4117 L
.50981 .4059 L
s
.8 g
.50981 .34711 m
.52943 .3449 L
.54906 .34425 L
.56868 .34409 L
.5883 .34407 L
.60793 .3441 L
.62755 .34431 L
.64717 .34512 L
.6668 .34791 L
.67744 .35283 L
.6668 .36717 L
.65678 .37245 L
.64717 .37557 L
.62755 .37992 L
.60793 .38232 L
.5883 .38317 L
.56868 .38258 L
.54906 .38047 L
.52943 .37653 L
.51629 .37245 L
.50981 .36925 L
.49564 .35283 L
F
0 g
.50981 .34711 m
.52943 .3449 L
.54906 .34425 L
.56868 .34409 L
.5883 .34407 L
.60793 .3441 L
.62755 .34431 L
.64717 .34512 L
.6668 .34791 L
.67744 .35283 L
.6668 .36717 L
.65678 .37245 L
.64717 .37557 L
.62755 .37992 L
.60793 .38232 L
.5883 .38317 L
.56868 .38258 L
.54906 .38047 L
.52943 .37653 L
.51629 .37245 L
.50981 .36925 L
.49564 .35283 L
.50981 .34711 L
s
.2 g
.52943 .29247 m
.54906 .29054 L
.56868 .28341 L
.5883 .28396 L
.60793 .28315 L
.62755 .29076 L
.64717 .29308 L
.65134 .29396 L
.65048 .31358 L
.64717 .31469 L
.62755 .3194 L
.60793 .32191 L
.5883 .3228 L
.56868 .32219 L
.54906 .31998 L
.52943 .31576 L
.52256 .31358 L
.52166 .29396 L
F
0 g
.52943 .29247 m
.54906 .29054 L
.56868 .28341 L
.5883 .28396 L
.60793 .28315 L
.62755 .29076 L
.64717 .29308 L
.65134 .29396 L
.65048 .31358 L
.64717 .31469 L
.62755 .3194 L
.60793 .32191 L
.5883 .3228 L
.56868 .32219 L
.54906 .31998 L
.52943 .31576 L
.52256 .31358 L
.52166 .29396 L
.52943 .29247 L
s
.9 g
.54906 .34997 m
.56868 .34901 L
.5883 .34879 L
.60793 .34912 L
.62755 .35028 L
.64378 .35283 L
.63079 .37245 L
.62755 .37325 L
.60793 .37663 L
.5883 .37777 L
.56868 .37698 L
.54906 .37406 L
.54208 .37245 L
.52956 .35283 L
F
0 g
.54906 .34997 m
.56868 .34901 L
.5883 .34879 L
.60793 .34912 L
.62755 .35028 L
.64378 .35283 L
.63079 .37245 L
.62755 .37325 L
.60793 .37663 L
.5883 .37777 L
.56868 .37698 L
.54906 .37406 L
.54208 .37245 L
.52956 .35283 L
.54906 .34997 L
s
.6 g
.54906 .47331 m
.56868 .47314 L
.5883 .47314 L
.60793 .47315 L
.62755 .47341 L
.64121 .49019 L
.62755 .4946 L
.60793 .49808 L
.5883 .49926 L
.56868 .49845 L
.54906 .49543 L
.53196 .49019 L
F
0 g
.54906 .47331 m
.56868 .47314 L
.5883 .47314 L
.60793 .47315 L
.62755 .47341 L
.64121 .49019 L
.62755 .4946 L
.60793 .49808 L
.5883 .49926 L
.56868 .49845 L
.54906 .49543 L
.53196 .49019 L
.54906 .47331 L
s
.7 g
.54906 .2441 m
.56868 .24194 L
.5883 .24145 L
.60793 .24217 L
.62755 .24484 L
.6398 .25471 L
.62755 .25891 L
.60793 .26243 L
.5883 .2636 L
.56868 .26279 L
.54906 .25977 L
.5333 .25471 L
F
0 g
.54906 .2441 m
.56868 .24194 L
.5883 .24145 L
.60793 .24217 L
.62755 .24484 L
.6398 .25471 L
.62755 .25891 L
.60793 .26243 L
.5883 .2636 L
.56868 .26279 L
.54906 .25977 L
.5333 .25471 L
.54906 .2441 L
s
.1 g
.56868 .29739 m
.5883 .29669 L
.60793 .29774 L
.62292 .31358 L
.60793 .31581 L
.5883 .31712 L
.56868 .31622 L
.55258 .31358 L
F
0 g
.56868 .29739 m
.5883 .29669 L
.60793 .29774 L
.62292 .31358 L
.60793 .31581 L
.5883 .31712 L
.56868 .31622 L
.55258 .31358 L
.56868 .29739 L
s
.4 g
.5883 .19506 m
.60174 .19584 L
.5883 .20726 L
.5713 .19584 L
F
0 g
.5883 .19506 m
.60174 .19584 L
.5883 .20726 L
.5713 .19584 L
.5883 .19506 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00?Oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0dooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kS?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0hooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8b
onk^kS?ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08_ooool003gooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0=_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0<oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg03?ooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL08_ooool003Gooooo1_l0
0003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400[ooooo`Ko0000
1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100<oooool01Ol@413o
oooooooooooooooo410@03[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@03Cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@02;ooooo000o
ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000fooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000cooooo`05o`000?ooooooooooooooool0
0000>_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000=Oooool00onH
V9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000008_ooool0043ooooo00?oMgMgofIV
I_ooool00_ooool01Ol0003ooooooooooooooooo000003Kooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000003?ooooo00Go0000ooooooooooooooooo`00000jooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`03ogMgMomVIVKooooo00;o
oooo00Go0000ooooooooooooooooo`00000Rooooo`00@Oooool01Ol0003ooooooooooooooooo410@
00?ooooo00?o410@ooooooooool0=?ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@4100<oooool01Ol@413ooooooooooooooooo410@03[ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@03Oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo023ooooo000mooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg03Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg03?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0jooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0cooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02;ooooo000mooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^03Cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^03?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`03oeEEEOmVIVKo000000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0cooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02;ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo000Joooooooo0000C_l00001ooooo`00
6_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0?Ooo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool08ooo
ool1o`00007ooooo0008ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKo
oooo00?o0000ooooooooool0oooooom:ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooom:ooooo`7o
00000Oooool000Go00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41001_ooool00ol0003oooooooooo`3ooooood[ooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?ooooooB?ooool3o`00007o
oooo000:ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo0008ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Oooooooogmo
Od3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Ooo
ooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?oooonjogmoO`Ko0000OomoOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?oooongogmoO`?o00001_mVIVH2o`0007goOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00Cooooo^OmoOgl2o`0000CoIVIV00?o0000ogmoOomoOgl0
OOmoOgl6ooooo`7o00000Oooool000oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`00
0?oooooooooo00Cooooo^omoOgl2o`000003ofIVI_l0003oOgmo07ooOgmo1_ooool1o`00007ooooo
000?ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`04oooookgoOgmo
00?o0000ogmoOomoOgl0OomoOgl6ooooo`7o00000Oooool000oooooo00Go410@oooooooooooooooo
oa0@4006ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`003ooo
ool01Ol0003ooooooooooooooooo000000Kooooo0ol00004ooooooooOgmo@?moOgl4ooooo`?o0000
0Oooool000oooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`003oooool01Ol@413ooooooooooooooooo410@00Kooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000?ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool000oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooj3oOgmo1_l0
0008ogmoOaoo00002?moOgl6o`0006CoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CoooooVomoOgl5o`0000KoVIVI0ol00002ogmoO`?o00007onIVIT3o`0000;oOgmo0ol00006
oiVIV@Co0000H?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonHogmo
O`?o00003_nIVIT2o`0002GoVIVI0_l0000=oiVIV@;o0000G_moOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?oooonGogmoO`03o`000?nIVIWoVIVI04OoVIVI00?o0000ogmoOomo
Ogl0FomoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonGogmoO`03o`00
0?nIVIWoVIVI04OoVIVI00?o0000ogmoOomoOgl0FomoOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?oooonGogmoO`03o`000?nIVIWoVIVI01WoVIVI5Ol0000IoiVIV@03o`000?mo
OgooOgmo05_oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooUomoOgl0
0ol0003oVIVIoiVIV@0EoiVIV@Co00005Onc/k<4o`0001GoVIVI00?o0000ogmoOomoOgl0FomoOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonHogmoO`03o`000?nIVIWoVIVI
01;oVIVI0_l0000Mok>c/`03o`000?nIVIWoVIVI017oVIVI00?o0000ogmoOomoOgl0G?moOgl6oooo
o`7o00000Oooool001[ooooo0_l00005oooooiSoOgmo00?o0000oiVIVOnIVIT04?nIVIT2o`00023o
/k>c00?o0000oiVIVOnIVIT04?nIVIT00ol0003oOgmoogmoO`1LogmoO`Gooooo0_l00001ooooo`00
6_ooool00ol0003oooooooooo`04oooooiSoOgmo0_l0000@oiVIV@?o00008?nc/k<2o`00013oVIVI
0_l0001NogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooi[oOgmo0_l0
000AoiVIV@?o00006onc/k<2o`0000ooVIVI0ol0001PogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04oooooicoOgmo0ol0000AoiVIV@Co00004onc/k<4o`0000koVIVI0ol0001S
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooiooOgmo0ol0000BoiVI
VA?o00003_nIVIT4o`0006KoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
ooooX_moOgl5o`0002_oVIVI0ol0001ZogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooojOoOgmo1ol0000IoiVIV@_o0000KOmoOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?oooon^ogmoOaWo0000N?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?oooon?ogmoOaSo00003?moOglEo`0000coOgmo5?l0001GogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooohkoOgmo00?o0000ofIVI_mVIVH05_mVIVH>o`00
00KoC4a<1Ol00005oda<C0oo00005?mVIVH3o`0005CoOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CoooooSOmoOgl00ol0003oIVIVofIVIP0QofIVIP;o00005Om<C4`2o`00023o
IVIV00?o0000ogmoOomoOgl0D_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?oooon<ogmoO`03o`000?mVIVKoIVIV01;oIVIV4?l00004oda<C17o00001?m<C4`@o`00017oIVIV
00?o0000ogmoOomoOgl0DOmoOgl6ooooo`7o00000Oooool001[ooooo0_l00005oooooh_oOgmo00?o
0000ofIVI_mVIVH04?mVIVH3o`00017oC4a<0ol0000Aoc<c<`?o00004Om<C4`3o`0000ooIVIV00?o
0000ogmoOomoOgl0D?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool01?oooon:
ogmoO`03o`000?mVIVKoIVIV00koIVIV0ol0000?oda<C0Go00005olc<c<5o`0000ooC4a<0_l0000>
ofIVIP03o`000?moOgooOgmo04ooOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CoooooROmoOgl2o`0000koIVIV0_l0000;oda<C0Oo00008Olc<c<5o`0000coC4a<00?o0000ofIV
I_mVIVH03?mVIVH00ol0003oOgmoogmoO`1>ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04oooooh_oOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00:oda<C003
o`000?lc<c?o<c<c00go<c<c2ol0000Aoc<c<`03o`000?m<C4coC4a<00[oC4a<00?o0000ofIVI_mV
IVH02omVIVH00ol0003oOgmoogmoO`1?ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooohcoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C009oda<C003o`00
0?lc<c?o<c<c00go<c<c00?o0000oaTI6OlI6AT02?lI6AT3o`0000ko<c<c00?o0000oda<C?m<C4`0
2Om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo053oOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CoooooSOmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<
C4coC4a<00SoC4a<00?o0000oc<c<olc<c<03?lc<c<00ol0003o6ATIoaTI6@0<oaTI6@03o`000?lc
<c?o<c<c00_o<c<c00?o0000oda<C?m<C4`02Om<C4`00ol0003oIVIVofIVIP0:ofIVIP03o`000?mo
OgooOgmo057oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooS_moOgl0
0ol0003oIVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<00WoC4a<00?o0000oc<c<olc<c<02_lc<c<0
0ol0003o6ATIoaTI6@0>oaTI6@03o`000?lc<c?o<c<c00Wo<c<c00?o0000oda<C?m<C4`02_m<C4`0
0ol0003oIVIVofIVIP08ofIVIP;o0000E?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?oooon?ogmoO`;o00002omVIVH00ol0003oC4a<oda<C008oda<C003o`000?lc<c?o<c<c
00Wo<c<c00?o0000oaTI6OlI6AT04?lI6AT00ol0003o<c<coc<c<`08oc<c<`03o`000?m<C4coC4a<
00SoC4a<0_l00009ofIVIP;o0000E_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?oooonAogmoO`?o00002OmVIVH00ol0003oC4a<oda<C007oda<C003o`000?lc<c?o<c<c00So
<c<c00?o0000oaTI6OlI6AT04_lI6AT00ol0003o<c<coc<c<`07oc<c<`03o`000?m<C4coC4a<00Oo
C4a<00?o0000ofIVI_mVIVH01omVIVH2o`0005SoOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CoooooU?moOgl00ol0003oIVIVofIVIP07ofIVIPCo00001Om<C4`5o`0000Go<c<c
1?l0000AoaTI6@?o00001_lc<c<3o`0000OoC4a<0_l00008ofIVIP;o0000F_moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?oooonEogmoO`;o00002omVIVH4o`0000KoC4a<0ol0
0006oc<c<a7o00001_lc<c<3o`0000KoC4a<1?l00008ofIVIP;o0000G?moOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?oooonGogmoO`;o00003OmVIVH3o`0000KoC4a<1Ol0000C
oc<c<`Go00001_m<C4`3o`0000_oIVIV00?o0000ogmoOomoOgl01_moOgl3o`0005?oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooSOmoOgl5o`0000OoOgmo00?o0000ofIV
I_mVIVH03OmVIVH5o`0000KoC4a<4ol00006oda<C0Go00000_mVIVH7o`0000?oIVIV0_l00006ogmo
O`?o00000onIVIT3o`00053oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Ooooon:ogmoO`?o
00001OnIVIT3o`0000GoOgmo0_l00004ofIVIPOo00001omVIVHVo`0000OoOgmo0ol00004ogmoO`Co
00002OnIVIT2o`0004koOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
QomoOgl3o`0000_oVIVI1Ol00002ogmoO`Co00001omoOgl=o`0001?oIVIV1_l0000BogmoO`?o0000
3onIVIT2o`0004coOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooQOmo
Ogl2o`0001?oVIVI5?l00006ogmoOa?o00001_moOglBo`0001CoVIVI00?o0000ogmoOomoOgl0BOmo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon5ogmoO`03o`000?nIVIWo
VIVI02KoVIVI7ol0000VoiVIV@03o`000?moOgooOgmo04WoOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CoooooQOmoOgl00ol0003oVIVIoiVIV@0BoiVIVDGo00005?nIVIT00ol0
003oOgmoogmoO`19ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooohKo
Ogmo00?o0000oiVIVOnIVIT03_nIVIT3o`0004Go/k>c0ol0000@oiVIV@03o`000?moOgooOgmo04[o
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooQ_moOgl00ol0003oVIVI
oiVIV@0<oiVIV@;o00003onc/k<_o`0000go/k>c0_l0000>oiVIV@03o`000?moOgooOgmo04[oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooQ_moOgl00ol0003oVIVIoiVI
V@0<oiVIV@03o`000?nc/k?o/k>c00[o/k>c1?l0000Dolc<c0Oo00005?o<c<`4o`0000_o/k>c00?o
0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`1:ogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooohOoOgmo00?o0000oiVIVOnIVIT02_nIVIT00ol0003o/k>cok>c/`08
ok>c/`?o00002oo<c<`=o`0000Ooi^KV3Ol0000;olc<c003o`000?nc/k?o/k>c00So/k>c00?o0000
oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`1;ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooohOoOgmo00?o0000oiVIVOnIVIT02_nIVIT00ol0003o/k>cok>c/`07ok>c
/`03o`000?o<c<coc<c<00Soc<c<1?l0000QonKViP;o00002_o<c<`00ol0003o/k>cok>c/`07ok>c
/`03o`000?nIVIWoVIVI00WoVIVI0_l0001=ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooohSoOgmo0_l0000:oiVIV@03o`000?nc/k?o/k>c00So/k>c00?o0000olc<c?o<
c<`01oo<c<`00ol0003oi^KVonKViP0SonKViP03o`000?o<c<coc<c<00Soc<c<00?o0000ok>c/onc
/k<01_nc/k<2o`0000WoVIVI0_l0001?ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04oooooh[oOgmo0_l00009oiVIV@;o00002Onc/k<00ol0003oc<c<olc<c007olc<c003o`00
0?oVi^Koi^KV027oi^KV00?o0000olc<c?o<c<`02?o<c<`00ol0003o/k>cok>c/`06ok>c/`03o`00
0?nIVIWoVIVI00SoVIVI00?o0000ogmoOomoOgl0ComoOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?oooon<ogmoO`03o`000?nIVIWoVIVI00SoVIVI0_l00008ok>c/`03o`000?o<
c<coc<c<00Ooc<c<00?o0000onKVi_oVi^H07ooVi^H00ol0003oc<c<olc<c008olc<c003o`000?nc
/k?o/k>c00Go/k>c0_l00009oiVIV@;o0000D_moOgl6ooooo`7o00000Oooool001[ooooo0_l00005
ooooohgoOgmo0_l0000:oiVIV@03o`000?nc/k?o/k>c00Ko/k>c00?o0000olc<c?o<c<`01_o<c<`0
0ol0003oi^KVonKViP0OonKViP03o`000?o<c<coc<c<00Soc<c<00?o0000ok>c/onc/k<01?nc/k<0
0ol0003oVIVIoiVIV@07oiVIV@;o0000E?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000oooo
ooooool01?oooon?ogmoO`?o00002?nIVIT2o`0000Oo/k>c0_l00007olc<c003o`000?oVi^Koi^KV
01goi^KV00?o0000olc<c?o<c<`01_o<c<`3o`0000Ko/k>c00?o0000oiVIVOnIVIT01_nIVIT2o`00
05KoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooT_moOgl3o`0000Oo
VIVI0_l00007ok>c/`;o00001_o<c<`3o`0001_oi^KV00?o0000olc<c?o<c<`01?o<c<`3o`0000Ko
/k>c0ol00007oiVIV@;o0000F?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?oooonEogmoO`;o00001onIVIT2o`0000Oo/k>c0_l00007olc<c0Co00004ooVi^H4o`0000Coc<c<
0ol00007ok>c/`;o00001onIVIT3o`0005[oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CoooooUomoOgl3o`0000KoVIVI00?o0000ok>c/onc/k<01_nc/k<5o`0000Koc<c<4ol0
0005olc<c0?o00002Onc/k<00ol0003oVIVIoiVIV@04oiVIV@?o0000GOmoOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?oooonJogmoO`;o00001OnIVIT2o`0000_o/k>c1_l0000C
olc<c0Go00002?nc/k<4o`0000CoVIVI0ol0001PogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04oooooicoOgmo0ol00004oiVIV@_o00001_nc/k<Co`0000Ko/k>c1ol00005oiVI
V@?o0000HomoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonOogmoO`?o
00003?nIVIT=o`0000Go/k>c3Ol00007oiVIV@Go0000I_moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?oooon=ogmoO`go00002?moOgl<o`0000goVIVI1Ol00008oiVIV@co0000
3OmoOgl=o`00057oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooR_mo
Ogl3o`0000goIVIV1ol0000=ogmoOa[o00003?moOgl=o`0000goIVIV0_l0001?ogmoO`Kooooo0Ol0
0001ooooo`002?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h6ooooo`03
o`000?oooooooooo00CoooooR_moOgl00ol0003oIVIVofIVIP0DofIVIPgo00007omoOgl7o`0001_o
IVIV00?o0000ogmoOomoOgl0COmoOgl6ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?oooon:ogmoO`03
o`000?mVIVKoIVIV027oIVIV7ol0000RofIVIP03o`000?moOgooOgmo04goOgmo1_ooool1o`00007o
oooo000:ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03
o`000?oooooooooo00CoooooR_moOgl00ol0003oIVIVofIVIP1RofIVIP03o`000?moOgooOgmo04go
Ogmo1_ooool1o`00007ooooo000:ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`000006ooooo`?o00001?oooon:ogmoO`03o`000?mVIVKoIVIV01GoIVIV<ol0000IofIVIP03
o`000?moOgooOgmo04koOgmo1?ooool3o`00007ooooo000:ooooo`03o`000?oooooooooo00;ooooo
00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00CoooooR_moOgl00ol0003o
IVIVofIVIP0BofIVIP?o0000<om<C4`5o`0001CoIVIV00?o0000ogmoOomoOgl0C_moOgl6ooooo`7o
00000Oooool000[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Ko
oooo00?o0000ooooooooool01?oooon:ogmoO`;o00004OmVIVH2o`0003_oC4a<0_l0000AofIVIP;o
0000D?moOgl6ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?oooon<ogmoO`03o`000?mVIVKoIVIV00oo
IVIV00?o0000oda<C?m<C4`0>_m<C4`00ol0003oIVIVofIVIP0>ofIVIP03o`000?moOgooOgmo053o
Ogmo1_ooool1o`00007ooooo0008ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP06ooooo`03o`000?oooooooooo00CoooooSOmoOgl00ol0003oIVIVofIVIP0?ofIVIP03
o`000?m<C4coC4a<03SoC4a<00?o0000ofIVI_mVIVH03_mVIVH00ol0003oOgmoogmoO`1AogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooohkoOgmo00?o0000ofIVI_mVIVH0
3omVIVH00ol0003oC4a<oda<C00foda<C003o`000?mVIVKoIVIV00goIVIV0_l0001DogmoO`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooohooOgmo0_l0000@ofIVIP03o`000?m<
C4coC4a<03CoC4a<00?o0000ofIVI_mVIVH03OmVIVH00ol0003oOgmoogmoO`1DogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04oooooi7oOgmo0_l0000?ofIVIP03o`000?m<C4co
C4a<037oC4a<0_l0000>ofIVIP;o0000EomoOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?oooonCogmoO`03o`000?mVIVKoIVIV00goIVIV00?o0000oda<C?m<C4`0;om<C4`00ol0
003oIVIVofIVIP0=ofIVIP03o`000?moOgooOgmo05OoOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CoooooU?moOgl3o`0000goIVIV0_l0000]oda<C0;o00003OmVIVH3o`0005[o
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooUomoOgl3o`0000coIVIV
0ol0000Yoda<C003o`000?mVIVKoIVIV00[oIVIV0ol0001MogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04oooooi[oOgmo0_l0000=ofIVIPGo00008om<C4`00ol0003oIVIVofIV
IP08ofIVIP?o0000H?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonL
ogmoO`?o00003omVIVH6o`0001?oC4a<2_l00009ofIVIP;o0000HomoOgl6ooooo`7o00000Oooool0
01[ooooo0_l00005oooooiooOgmo0ol0000BofIVIQ?o00004OmVIVH2o`0006GoOgmo1Oooool2o`00
007ooooo000Jooooo`03o`000?oooooooooo00CoooooX_moOgl5o`0002goIVIV1?l0001WogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooojOoOgmo2?l0000MofIVIPSo0000
JomoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon_ogmoO`Go00004omV
IVH5o`0007?oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo]?moOglC
o`0007SoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?oooon_ogmoOaco0000M?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?oooon^ogmoO`03o`000?nIVIWoVIVI01WoVIVI00?o0000ogmoOomoOgl0L_moOgl6ooooo`7o
00000Oooool001[ooooo0_l00005ooooojgoOgmo00?o0000oiVIVOnIVIT06onIVIT00ol0003oOgmo
ogmoO`1aogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04ooooojcoOgmo00?o
0000oiVIVOnIVIT07OnIVIT00ol0003oOgmoogmoO`1`ogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04oooooj_oOgmo00?o0000oiVIVOnIVIT07onIVIT00ol0003oOgmoogmoO`1_
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooj[oOgmo0ol0000PoiVI
V@;o0000L?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon]ogmoO`?o
00006onIVIT2o`0007;oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
/?moOgl4o`0001?oVIVI1?l0001dogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04oooookCoOgmo4ol0001hogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`00
00GooooooomoOgm0ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`001oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`001ooo
ool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002?ooool00onHV9So8B4Q
onk^kP04ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool000Wooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooo
oooooooooooo000000Kooooo0ol00004ooooooooOgmo@?moOgl4ooooo`?o00000Oooool000[ooooo
00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000;ooooo`05o`000?ooooooooooooooool@
41000oooool00ol@413oooooooooo`04ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`001oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`001oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000Oooooo00GoV9RHoa0@4?l0
003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000Oooooo00Go410@okZj^_ooooooMgMgoc8b<P03
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool000_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000:
ooooo`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`?o00001?oo
ooooogmoOd3oOgmo1?ooool3o`00007ooooo0009ooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`002_ooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000Oooooo00Go410@
oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000Oooooo00GoZJVYoa0@4?l0003o410@
ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo
1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Oooooooogmo
Od3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Ooo
ooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo0009ooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b
<_o^k^h01_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000[o
oooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000oooo
ooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo0007ooooo`Go00000oooool01Ol@413o
oooooooooooooooo410@00Kooooo0ol00004ooooooooOgmo@?moOgl4ooooo`?o00000Oooool000Oo
oooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000
ooooooooool0oooooom:ooooo`7o00000Oooool000Oooooo00CogMgMoeEEEOoooooo00001?ooool0
1Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0oooooom:ooooo`7o00000Ooo
ool000Sooooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo410@00Kooooo00?o
0000ooooooooool0oooooom:ooooo`7o00000Oooool000Sooooo00?ok^k^odA4A?l000001?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooom:ooooo`7o00000Ooo
ool000Wooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03gooooo00?o
0000ooooooooool0?Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo02?ooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo0Ol00001
ooooo`006_ooooooo`0004ko00000Oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-30.1723, -14.304, 0.195672, \
0.195672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0192308 0.211538 0.0192308 [
[.11538 -0.0125 -9 -9 ]
[.11538 -0.0125 9 0 ]
[.30769 -0.0125 -9 -9 ]
[.30769 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69231 -0.0125 -6 -9 ]
[.69231 -0.0125 6 0 ]
[.88462 -0.0125 -6 -9 ]
[.88462 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -18 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .21154 -6 -4.5 ]
[-0.0125 .21154 0 4.5 ]
[-0.0125 .40385 -12 -4.5 ]
[-0.0125 .40385 0 4.5 ]
[-0.0125 .59615 -12 -4.5 ]
[-0.0125 .59615 0 4.5 ]
[-0.0125 .78846 -12 -4.5 ]
[-0.0125 .78846 0 4.5 ]
[-0.0125 .98077 -12 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11538 0 m
.11538 .00625 L
s
[(-20)] .11538 -0.0125 0 1 Mshowa
.30769 0 m
.30769 .00625 L
s
[(-10)] .30769 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69231 0 m
.69231 .00625 L
s
[(10)] .69231 -0.0125 0 1 Mshowa
.88462 0 m
.88462 .00625 L
s
[(20)] .88462 -0.0125 0 1 Mshowa
.125 Mabswid
.15385 0 m
.15385 .00375 L
s
.19231 0 m
.19231 .00375 L
s
.23077 0 m
.23077 .00375 L
s
.26923 0 m
.26923 .00375 L
s
.34615 0 m
.34615 .00375 L
s
.38462 0 m
.38462 .00375 L
s
.42308 0 m
.42308 .00375 L
s
.46154 0 m
.46154 .00375 L
s
.53846 0 m
.53846 .00375 L
s
.57692 0 m
.57692 .00375 L
s
.61538 0 m
.61538 .00375 L
s
.65385 0 m
.65385 .00375 L
s
.73077 0 m
.73077 .00375 L
s
.76923 0 m
.76923 .00375 L
s
.80769 0 m
.80769 .00375 L
s
.84615 0 m
.84615 .00375 L
s
.07692 0 m
.07692 .00375 L
s
.03846 0 m
.03846 .00375 L
s
.92308 0 m
.92308 .00375 L
s
.96154 0 m
.96154 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(-10)] -0.0125 .01923 1 0 Mshowa
0 .21154 m
.00625 .21154 L
s
[(0)] -0.0125 .21154 1 0 Mshowa
0 .40385 m
.00625 .40385 L
s
[(10)] -0.0125 .40385 1 0 Mshowa
0 .59615 m
.00625 .59615 L
s
[(20)] -0.0125 .59615 1 0 Mshowa
0 .78846 m
.00625 .78846 L
s
[(30)] -0.0125 .78846 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(40)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .05769 m
.00375 .05769 L
s
0 .09615 m
.00375 .09615 L
s
0 .13462 m
.00375 .13462 L
s
0 .17308 m
.00375 .17308 L
s
0 .25 m
.00375 .25 L
s
0 .28846 m
.00375 .28846 L
s
0 .32692 m
.00375 .32692 L
s
0 .36538 m
.00375 .36538 L
s
0 .44231 m
.00375 .44231 L
s
0 .48077 m
.00375 .48077 L
s
0 .51923 m
.00375 .51923 L
s
0 .55769 m
.00375 .55769 L
s
0 .63462 m
.00375 .63462 L
s
0 .67308 m
.00375 .67308 L
s
0 .71154 m
.00375 .71154 L
s
0 .75 m
.00375 .75 L
s
0 .82692 m
.00375 .82692 L
s
0 .86538 m
.00375 .86538 L
s
0 .90385 m
.00375 .90385 L
s
0 .94231 m
.00375 .94231 L
s
.25 Mabswid
0 0 m
0 1 L
s
.11538 .99375 m
.11538 1 L
s
.30769 .99375 m
.30769 1 L
s
.5 .99375 m
.5 1 L
s
.69231 .99375 m
.69231 1 L
s
.88462 .99375 m
.88462 1 L
s
.125 Mabswid
.15385 .99625 m
.15385 1 L
s
.19231 .99625 m
.19231 1 L
s
.23077 .99625 m
.23077 1 L
s
.26923 .99625 m
.26923 1 L
s
.34615 .99625 m
.34615 1 L
s
.38462 .99625 m
.38462 1 L
s
.42308 .99625 m
.42308 1 L
s
.46154 .99625 m
.46154 1 L
s
.53846 .99625 m
.53846 1 L
s
.57692 .99625 m
.57692 1 L
s
.61538 .99625 m
.61538 1 L
s
.65385 .99625 m
.65385 1 L
s
.73077 .99625 m
.73077 1 L
s
.76923 .99625 m
.76923 1 L
s
.80769 .99625 m
.80769 1 L
s
.84615 .99625 m
.84615 1 L
s
.07692 .99625 m
.07692 1 L
s
.03846 .99625 m
.03846 1 L
s
.92308 .99625 m
.92308 1 L
s
.96154 .99625 m
.96154 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .21154 m
1 .21154 L
s
.99375 .40385 m
1 .40385 L
s
.99375 .59615 m
1 .59615 L
s
.99375 .78846 m
1 .78846 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .05769 m
1 .05769 L
s
.99625 .09615 m
1 .09615 L
s
.99625 .13462 m
1 .13462 L
s
.99625 .17308 m
1 .17308 L
s
.99625 .25 m
1 .25 L
s
.99625 .28846 m
1 .28846 L
s
.99625 .32692 m
1 .32692 L
s
.99625 .36538 m
1 .36538 L
s
.99625 .44231 m
1 .44231 L
s
.99625 .48077 m
1 .48077 L
s
.99625 .51923 m
1 .51923 L
s
.99625 .55769 m
1 .55769 L
s
.99625 .63462 m
1 .63462 L
s
.99625 .67308 m
1 .67308 L
s
.99625 .71154 m
1 .71154 L
s
.99625 .75 m
1 .75 L
s
.99625 .82692 m
1 .82692 L
s
.99625 .86538 m
1 .86538 L
s
.99625 .90385 m
1 .90385 L
s
.99625 .94231 m
1 .94231 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.6 g
.43132 .3585 m
.45094 .35508 L
.47057 .35625 L
.49019 .35843 L
.50981 .3607 L
.52943 .35953 L
.54906 .36327 L
.56868 .36546 L
.5883 .36648 L
.60793 .36636 L
.62755 .36512 L
.64717 .36267 L
.6668 .35848 L
.68642 .36026 L
.70604 .35797 L
.72567 .35589 L
.74529 .35515 L
.76491 .36178 L
.76599 .37245 L
.76491 .37417 L
.74529 .39118 L
.74382 .39207 L
.72567 .40545 L
.70604 .40813 L
.69339 .4117 L
.68642 .41367 L
.6668 .41351 L
.64717 .41798 L
.62755 .42096 L
.60793 .42247 L
.5883 .4226 L
.56868 .42137 L
.54906 .4187 L
.52943 .4145 L
.50981 .41465 L
.49886 .4117 L
.49019 .40932 L
.47057 .40897 L
.45094 .39373 L
.44879 .39207 L
.43132 .37874 L
.42649 .37245 L
F
0 g
.43132 .3585 m
.45094 .35508 L
.47057 .35625 L
.49019 .35843 L
.50981 .3607 L
.52943 .35953 L
.54906 .36327 L
.56868 .36546 L
.5883 .36648 L
.60793 .36636 L
.62755 .36512 L
.64717 .36267 L
.6668 .35848 L
.68642 .36026 L
.70604 .35797 L
.72567 .35589 L
.74529 .35515 L
.76491 .36178 L
.76599 .37245 L
.76491 .37417 L
.74529 .39118 L
.74382 .39207 L
.72567 .40545 L
.70604 .40813 L
.69339 .4117 L
.68642 .41367 L
.6668 .41351 L
.64717 .41798 L
.62755 .42096 L
.60793 .42247 L
.5883 .4226 L
.56868 .42137 L
.54906 .4187 L
.52943 .4145 L
.50981 .41465 L
.49886 .4117 L
.49019 .40932 L
.47057 .40897 L
.45094 .39373 L
.44879 .39207 L
.43132 .37874 L
.42649 .37245 L
.43132 .3585 L
s
.4 g
.45094 .30232 m
.47057 .30104 L
.49019 .29493 L
.50981 .30375 L
.52943 .30901 L
.54906 .30612 L
.56868 .30705 L
.5883 .30751 L
.60793 .30746 L
.62755 .3069 L
.64717 .30588 L
.6668 .30798 L
.68642 .30257 L
.70604 .30161 L
.72567 .30105 L
.74529 .30317 L
.75836 .31358 L
.74529 .33027 L
.74113 .3332 L
.72567 .34056 L
.70604 .34737 L
.68642 .35267 L
.68576 .35283 L
.6668 .35504 L
.64717 .3588 L
.62755 .36165 L
.60793 .36323 L
.5883 .36337 L
.56868 .36207 L
.54906 .35946 L
.52943 .35583 L
.50981 .35355 L
.50675 .35283 L
.49019 .34853 L
.47057 .34208 L
.45095 .3332 L
.45094 .3332 L
.43387 .31358 L
F
0 g
.45094 .30232 m
.47057 .30104 L
.49019 .29493 L
.50981 .30375 L
.52943 .30901 L
.54906 .30612 L
.56868 .30705 L
.5883 .30751 L
.60793 .30746 L
.62755 .3069 L
.64717 .30588 L
.6668 .30798 L
.68642 .30257 L
.70604 .30161 L
.72567 .30105 L
.74529 .30317 L
.75836 .31358 L
.74529 .33027 L
.74113 .3332 L
.72567 .34056 L
.70604 .34737 L
.68642 .35267 L
.68576 .35283 L
.6668 .35504 L
.64717 .3588 L
.62755 .36165 L
.60793 .36323 L
.5883 .36337 L
.56868 .36207 L
.54906 .35946 L
.52943 .35583 L
.50981 .35355 L
.50675 .35283 L
.49019 .34853 L
.47057 .34208 L
.45095 .3332 L
.45094 .3332 L
.43387 .31358 L
.45094 .30232 L
s
.4 g
.45094 .4245 m
.47057 .42231 L
.49019 .42354 L
.50981 .42542 L
.52943 .42366 L
.54906 .42718 L
.56868 .42904 L
.5883 .42984 L
.60793 .42975 L
.62755 .42877 L
.64717 .42665 L
.6668 .42262 L
.68642 .42504 L
.70604 .42321 L
.72567 .42228 L
.74529 .42676 L
.74794 .43132 L
.74529 .43719 L
.73066 .45094 L
.72567 .45696 L
.70604 .46441 L
.68906 .47057 L
.68642 .47063 L
.6668 .47452 L
.64717 .47914 L
.62755 .48239 L
.60793 .48406 L
.5883 .48421 L
.56868 .48285 L
.54906 .47992 L
.52943 .47551 L
.50981 .47105 L
.50328 .47057 L
.49019 .46599 L
.47057 .4624 L
.46165 .45094 L
.45094 .44196 L
.44437 .43132 L
F
0 g
.45094 .4245 m
.47057 .42231 L
.49019 .42354 L
.50981 .42542 L
.52943 .42366 L
.54906 .42718 L
.56868 .42904 L
.5883 .42984 L
.60793 .42975 L
.62755 .42877 L
.64717 .42665 L
.6668 .42262 L
.68642 .42504 L
.70604 .42321 L
.72567 .42228 L
.74529 .42676 L
.74794 .43132 L
.74529 .43719 L
.73066 .45094 L
.72567 .45696 L
.70604 .46441 L
.68906 .47057 L
.68642 .47063 L
.6668 .47452 L
.64717 .47914 L
.62755 .48239 L
.60793 .48406 L
.5883 .48421 L
.56868 .48285 L
.54906 .47992 L
.52943 .47551 L
.50981 .47105 L
.50328 .47057 L
.49019 .46599 L
.47057 .4624 L
.46165 .45094 L
.45094 .44196 L
.44437 .43132 L
.45094 .4245 L
s
.6 g
.50981 .2545 m
.52943 .25467 L
.53115 .25471 L
.54906 .25512 L
.56868 .25554 L
.5883 .25576 L
.60793 .25573 L
.62755 .25546 L
.64717 .25503 L
.66124 .25471 L
.6668 .25459 L
.68642 .25457 L
.69054 .25471 L
.70604 .25593 L
.72567 .26342 L
.72623 .27433 L
.72567 .27481 L
.70604 .28561 L
.68642 .29262 L
.68167 .29396 L
.6668 .29934 L
.64717 .29954 L
.62755 .30132 L
.60793 .30224 L
.5883 .30232 L
.56868 .30157 L
.54906 .29996 L
.52943 .30085 L
.51058 .29396 L
.50981 .29375 L
.49019 .28721 L
.47057 .27756 L
.46623 .27433 L
.47057 .2604 L
.49019 .25546 L
.50184 .25471 L
F
0 g
.50981 .2545 m
.52943 .25467 L
.53115 .25471 L
.54906 .25512 L
.56868 .25554 L
.5883 .25576 L
.60793 .25573 L
.62755 .25546 L
.64717 .25503 L
.66124 .25471 L
.6668 .25459 L
.68642 .25457 L
.69054 .25471 L
.70604 .25593 L
.72567 .26342 L
.72623 .27433 L
.72567 .27481 L
.70604 .28561 L
.68642 .29262 L
.68167 .29396 L
.6668 .29934 L
.64717 .29954 L
.62755 .30132 L
.60793 .30224 L
.5883 .30232 L
.56868 .30157 L
.54906 .29996 L
.52943 .30085 L
.51058 .29396 L
.50981 .29375 L
.49019 .28721 L
.47057 .27756 L
.46623 .27433 L
.47057 .2604 L
.49019 .25546 L
.50184 .25471 L
.50981 .2545 L
s
.7 g
.49019 .36949 m
.50981 .36828 L
.52943 .36588 L
.54906 .3681 L
.56868 .36935 L
.5883 .36991 L
.60793 .36985 L
.62755 .36916 L
.64717 .36775 L
.6668 .36524 L
.68642 .36834 L
.70604 .37017 L
.71373 .37245 L
.70868 .39207 L
.70604 .39387 L
.68642 .40334 L
.6668 .40959 L
.6583 .4117 L
.64717 .41318 L
.62755 .41581 L
.60793 .41737 L
.5883 .41752 L
.56868 .41623 L
.54906 .41375 L
.534 .4117 L
.52943 .4106 L
.50981 .40478 L
.49019 .39619 L
.48366 .39207 L
.47852 .37245 L
F
0 g
.49019 .36949 m
.50981 .36828 L
.52943 .36588 L
.54906 .3681 L
.56868 .36935 L
.5883 .36991 L
.60793 .36985 L
.62755 .36916 L
.64717 .36775 L
.6668 .36524 L
.68642 .36834 L
.70604 .37017 L
.71373 .37245 L
.70868 .39207 L
.70604 .39387 L
.68642 .40334 L
.6668 .40959 L
.6583 .4117 L
.64717 .41318 L
.62755 .41581 L
.60793 .41737 L
.5883 .41752 L
.56868 .41623 L
.54906 .41375 L
.534 .4117 L
.52943 .4106 L
.50981 .40478 L
.49019 .39619 L
.48366 .39207 L
.47852 .37245 L
.49019 .36949 L
s
.3 g
.50981 .31226 m
.52943 .31255 L
.54906 .31208 L
.56868 .31235 L
.5883 .31254 L
.60793 .31251 L
.62755 .3123 L
.64717 .31203 L
.6668 .31237 L
.68642 .31256 L
.69254 .31358 L
.70604 .31822 L
.70703 .3332 L
.70604 .33393 L
.68642 .34379 L
.6668 .35008 L
.65528 .35283 L
.64717 .35433 L
.62755 .35752 L
.60793 .35939 L
.5883 .35957 L
.56868 .35802 L
.54906 .35504 L
.53699 .35283 L
.52943 .35108 L
.50981 .34525 L
.49019 .33643 L
.48534 .3332 L
.49019 .31617 L
.4994 .31358 L
F
0 g
.50981 .31226 m
.52943 .31255 L
.54906 .31208 L
.56868 .31235 L
.5883 .31254 L
.60793 .31251 L
.62755 .3123 L
.64717 .31203 L
.6668 .31237 L
.68642 .31256 L
.69254 .31358 L
.70604 .31822 L
.70703 .3332 L
.70604 .33393 L
.68642 .34379 L
.6668 .35008 L
.65528 .35283 L
.64717 .35433 L
.62755 .35752 L
.60793 .35939 L
.5883 .35957 L
.56868 .35802 L
.54906 .35504 L
.53699 .35283 L
.52943 .35108 L
.50981 .34525 L
.49019 .33643 L
.48534 .3332 L
.49019 .31617 L
.4994 .31358 L
.50981 .31226 L
s
.8 g
.52943 .3761 m
.54906 .37491 L
.56868 .37467 L
.5883 .37466 L
.60793 .37466 L
.62755 .37469 L
.64717 .37503 L
.6668 .37663 L
.68178 .39207 L
.6668 .40024 L
.64717 .40648 L
.62755 .41021 L
.61368 .4117 L
.60793 .41206 L
.5883 .41222 L
.57865 .4117 L
.56868 .41072 L
.54906 .40739 L
.52943 .40176 L
.51055 .39207 L
F
0 g
.52943 .3761 m
.54906 .37491 L
.56868 .37467 L
.5883 .37466 L
.60793 .37466 L
.62755 .37469 L
.64717 .37503 L
.6668 .37663 L
.68178 .39207 L
.6668 .40024 L
.64717 .40648 L
.62755 .41021 L
.61368 .4117 L
.60793 .41206 L
.5883 .41222 L
.57865 .4117 L
.56868 .41072 L
.54906 .40739 L
.52943 .40176 L
.51055 .39207 L
.52943 .3761 L
s
.2 g
.52943 .3207 m
.54906 .31864 L
.56868 .31795 L
.5883 .31775 L
.60793 .31776 L
.62755 .31803 L
.64717 .31889 L
.6668 .32151 L
.68082 .3332 L
.6668 .34155 L
.64717 .34799 L
.62755 .35175 L
.61831 .35283 L
.60793 .35381 L
.5883 .35403 L
.57399 .35283 L
.56868 .35226 L
.54906 .34892 L
.52943 .34314 L
.5115 .3332 L
F
0 g
.52943 .3207 m
.54906 .31864 L
.56868 .31795 L
.5883 .31775 L
.60793 .31776 L
.62755 .31803 L
.64717 .31889 L
.6668 .32151 L
.68082 .3332 L
.6668 .34155 L
.64717 .34799 L
.62755 .35175 L
.61831 .35283 L
.60793 .35381 L
.5883 .35403 L
.57399 .35283 L
.56868 .35226 L
.54906 .34892 L
.52943 .34314 L
.5115 .3332 L
.52943 .3207 L
s
.7 g
.52943 .2705 m
.54906 .26697 L
.56868 .26567 L
.5883 .26522 L
.60793 .26526 L
.62755 .26584 L
.64717 .2674 L
.6668 .27197 L
.67073 .27433 L
.6668 .28177 L
.64717 .29101 L
.63568 .29396 L
.62755 .29489 L
.60793 .29633 L
.5883 .29646 L
.56868 .29529 L
.55622 .29396 L
.54906 .2921 L
.52943 .28449 L
.52155 .27433 L
F
0 g
.52943 .2705 m
.54906 .26697 L
.56868 .26567 L
.5883 .26522 L
.60793 .26526 L
.62755 .26584 L
.64717 .2674 L
.6668 .27197 L
.67073 .27433 L
.6668 .28177 L
.64717 .29101 L
.63568 .29396 L
.62755 .29489 L
.60793 .29633 L
.5883 .29646 L
.56868 .29529 L
.55622 .29396 L
.54906 .2921 L
.52943 .28449 L
.52155 .27433 L
.52943 .2705 L
s
.3 g
.52943 .44379 m
.54906 .44055 L
.56868 .43992 L
.5883 .4398 L
.60793 .43981 L
.62755 .43998 L
.64717 .44084 L
.6668 .44623 L
.6677 .45094 L
.6668 .45182 L
.64717 .46144 L
.62755 .46606 L
.60793 .46826 L
.5883 .46845 L
.56868 .46667 L
.54906 .46261 L
.52943 .45469 L
.52456 .45094 L
F
0 g
.52943 .44379 m
.54906 .44055 L
.56868 .43992 L
.5883 .4398 L
.60793 .43981 L
.62755 .43998 L
.64717 .44084 L
.6668 .44623 L
.6677 .45094 L
.6668 .45182 L
.64717 .46144 L
.62755 .46606 L
.60793 .46826 L
.5883 .46845 L
.56868 .46667 L
.54906 .46261 L
.52943 .45469 L
.52456 .45094 L
.52943 .44379 L
s
.4 g
.5883 .21503 m
.60793 .21509 L
.61948 .21546 L
.62755 .21586 L
.64717 .2179 L
.6582 .23509 L
.64717 .23759 L
.62755 .24054 L
.60793 .24198 L
.5883 .24211 L
.56868 .24094 L
.54906 .23832 L
.53411 .23509 L
.54906 .21731 L
.56868 .21565 L
.57282 .21546 L
F
0 g
.5883 .21503 m
.60793 .21509 L
.61948 .21546 L
.62755 .21586 L
.64717 .2179 L
.6582 .23509 L
.64717 .23759 L
.62755 .24054 L
.60793 .24198 L
.5883 .24211 L
.56868 .24094 L
.54906 .23832 L
.53411 .23509 L
.54906 .21731 L
.56868 .21565 L
.57282 .21546 L
.5883 .21503 L
s
.1 g
.54906 .32743 m
.56868 .32455 L
.5883 .32368 L
.60793 .32377 L
.62755 .3249 L
.64717 .32865 L
.65395 .3332 L
.64717 .33836 L
.62755 .34484 L
.60793 .34753 L
.5883 .34776 L
.56868 .34561 L
.54906 .34017 L
.53828 .3332 L
F
0 g
.54906 .32743 m
.56868 .32455 L
.5883 .32368 L
.60793 .32377 L
.62755 .3249 L
.64717 .32865 L
.65395 .3332 L
.64717 .33836 L
.62755 .34484 L
.60793 .34753 L
.5883 .34776 L
.56868 .34561 L
.54906 .34017 L
.53828 .3332 L
.54906 .32743 L
s
.9 g
.54906 .38424 m
.56868 .38159 L
.5883 .38086 L
.60793 .38093 L
.62755 .38189 L
.64717 .38544 L
.6538 .39207 L
.64717 .39616 L
.62755 .40233 L
.60793 .40497 L
.5883 .40519 L
.56868 .40307 L
.54906 .39785 L
.53843 .39207 L
F
0 g
.54906 .38424 m
.56868 .38159 L
.5883 .38086 L
.60793 .38093 L
.62755 .38189 L
.64717 .38544 L
.6538 .39207 L
.64717 .39616 L
.62755 .40233 L
.60793 .40497 L
.5883 .40519 L
.56868 .40307 L
.54906 .39785 L
.53843 .39207 L
.54906 .38424 L
s
.5883 .33272 m
.60793 .33314 L
.60834 .3332 L
.60793 .33495 L
.5883 .33636 L
.58402 .3332 L
F
.5883 .33272 m
.60793 .33314 L
.60834 .3332 L
.60793 .33495 L
.5883 .33636 L
.58402 .3332 L
.5883 .33272 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00?Oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0dooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kS?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0hooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8b
onk^kS?ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08_ooool003gooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0=_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0<oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg03?ooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL08_ooool003Gooooo1_l0
0003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400[ooooo`Ko0000
1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100<oooool01Ol@413o
oooooooooooooooo410@03[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@03Cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@02;ooooo000o
ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000fooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000cooooo`05o`000?ooooooooooooooool0
0000>_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000=Oooool00onH
V9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000008_ooool0043ooooo00?oMgMgofIV
I_ooool00_ooool01Ol0003ooooooooooooooooo000003Kooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000003?ooooo00Go0000ooooooooooooooooo`00000jooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`03ogMgMomVIVKooooo00;o
oooo00Go0000ooooooooooooooooo`00000Rooooo`00@Oooool01Ol0003ooooooooooooooooo410@
00?ooooo00?o410@ooooooooool0=?ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@4100<oooool01Ol@413ooooooooooooooooo410@03[ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@03Oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo023ooooo000mooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg03Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg03?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0jooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0cooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02;ooooo000mooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^03Cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^03?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`03oeEEEOmVIVKo000000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0cooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02;ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo000Joooooooo0000C_l00001ooooo`00
6_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0?Ooo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool08ooo
ool1o`00007ooooo0008ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKo
oooo00?o0000ooooooooool0oooooom:ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooom:ooooo`7o
00000Oooool000Go00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41001_ooool00ol0003oooooooooo`3ooooood[ooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?ooooooB?ooool3o`00007o
oooo000:ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo0008ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Oooooooogmo
Od3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Ooo
ooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000oooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`003ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000?ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000oooooo00Go0000oooooooooooooooo
o`000006ooooo`?o00001?ooooooogmoOd3oOgmo1?ooool3o`00007ooooo000?ooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`04oooook?oOgmo6ol0001aogmoO`Kooooo
0Ol00001ooooo`003oooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool0
1?oooon`ogmoO`?o00006omVIVH3o`0006koOgmo1_ooool1o`00007ooooo000?ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`04oooook3oOgmo00?o0000ofIVI_mVIVH0
7OmVIVH00ol0003oOgmoogmoO`1/ogmoO`Kooooo0Ol00001ooooo`003oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Kooooo00?o0000ooooooooool01?oooon_ogmoO`03o`000?mVIVKoIVIV01ooIVIV
00?o0000ogmoOomoOgl0JomoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
oon^ogmoO`03o`000?mVIVKoIVIV027oIVIV00?o0000ogmoOomoOgl0J_moOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?oooon]ogmoO`03o`000?mVIVKoIVIV02;oIVIV00?o0000
ogmoOomoOgl0J_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon/ogmo
O`03o`000?mVIVKoIVIV02CoIVIV00?o0000ogmoOomoOgl0JOmoOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?oooon[ogmoO`Co00008omVIVH3o`0006[oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00Cooooo[omoOgl5o`0001WoIVIV1Ol0001]ogmoO`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooookCoOgmo6Ol0001bogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o
00001OooooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
V_moOglQo`0000coOgmo7?l0001LogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04oooooiOoOgmo0ol0000QoiVIV@co00007?nIVIT4o`0005SoOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CoooooUOmoOgl2o`00053oVIVI0ol0001EogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04oooooiGoOgmo00?o0000oiVIVOnIVIT0D_nIVIT00ol0
003oOgmoogmoO`1BogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooiGo
Ogmo00?o0000oiVIVOnIVIT05OnIVITVo`0001OoVIVI00?o0000ogmoOomoOgl0D_moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?oooonDogmoO`03o`000?nIVIWoVIVI017oVIVI
1Ol0000Vok>c/`?o00005?nIVIT00ol0003oOgmoogmoO`1BogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04oooooiCoOgmo00?o0000oiVIVOnIVIT04?nIVIT00ol0003o/k>cok>c
/`0/ok>c/`;o00004_nIVIT00ol0003oOgmoogmoO`1BogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04oooooiCoOgmo00?o0000oiVIVOnIVIT03onIVIT00ol0003o/k>cok>c/`0_
ok>c/`03o`000?nIVIWoVIVI00koVIVI0_l0001DogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04oooooiGoOgmo0_l0000@oiVIV@03o`000?nc/k?o/k>c02ko/k>c00?o0000oiVI
VOnIVIT03?nIVIT2o`0005KoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
ooooUomoOgl3o`0000koVIVI00?o0000ok>c/onc/k<0:onc/k<2o`0000goVIVI0_l0001HogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooi[oOgmo0_l0000=oiVIV@;o0000
:?nc/k<3o`0000goVIVI0_l0001JogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000GoooooW?mo
Ogl3o`0000coVIVI0ol0000Sok>c/`;o00003OnIVIT3o`0005coOgmo1Oooool2o`00007ooooo000J
ooooo`03o`000?oooooooooo00CoooooWomoOgl3o`0000coVIVI0_l0000Nok>c/`?o00003OnIVIT2
o`0005ooOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooX_moOgl3o`00
00_oVIVI1Ol0000Fok>c/`?o00003OnIVIT3o`00067oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CoooooV_moOgl4o`0000OoOgmo0_l0000>oiVIVAKo00003OnIVIT3o`0006Co
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooUomoOgl3o`0000CoIVIV
0ol00006ogmoO`;o00001?nIVIT7o`0001WoVIVI2ol0001WogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooohkoOgmo2Ol0000:ofIVIP;o00001_moOgl4o`0000OoOgmo6Ol0
000?ogmoOaKo0000COmoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon=
ogmoO`03o`000?mVIVKoIVIV01?oIVIV1?l00006ogmoO`Oo00006OmoOgl8o`0000CoOgmo0ol0000F
ofIVIP03o`000?moOgooOgmo04[oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CoooooRomoOgl2o`0001[oIVIV1_l00007ofIVIQWo00002?mVIVH4o`0001[oIVIV00?o0000ogmo
OomoOgl0BOmoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon:ogmoO`03
o`000?mVIVKoIVIV01CoIVIV?_l0000EofIVIP03o`000?moOgooOgmo04SoOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CoooooROmoOgl00ol0003oIVIVofIVIP0BofIVIP?o0000
?_m<C4`4o`0001;oIVIV00?o0000ogmoOomoOgl0AomoOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?oooon:ogmoO`03o`000?mVIVKoIVIV00ooIVIV0_l0000?oda<C27o00005Om<
C4`2o`00013oIVIV00?o0000ogmoOomoOgl0AomoOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?oooon;ogmoO`03o`000?mVIVKoIVIV00koIVIV00?o0000oda<C?m<C4`02Om<C4`5
o`00027o<c<c2_l0000<oda<C003o`000?mVIVKoIVIV00goIVIV00?o0000ogmoOomoOgl0B?moOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon<ogmoO`03o`000?mVIVKoIVIV
00coIVIV00?o0000oda<C?m<C4`02Om<C4`00ol0003o<c<coc<c<`09oc<c<aGo00004?lc<c<00ol0
003oC4a<oda<C009oda<C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl0BOmoOgl6oooo
o`7o00000Oooool001[ooooo0_l00005ooooohgoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003o
C4a<oda<C007oda<C0;o00002?lc<c<4o`0001Go6ATI1_l0000;oc<c<`03o`000?m<C4coC4a<00So
C4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`1:ogmoO`Gooooo0_l00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooohkoOgmo00?o0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<
oda<C006oda<C003o`000?lc<c?o<c<c00Ko<c<c0_l0000OoaTI6@Co00002?lc<c<00ol0003oC4a<
oda<C007oda<C003o`000?mVIVKoIVIV00WoIVIV0_l0001=ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooohooOgmo0_l00009ofIVIP;o00001om<C4`2o`0000Oo<c<c0_l0
000=oaTI6@Wo00003_lI6AT00ol0003o<c<coc<c<`05oc<c<`;o00002?m<C4`00ol0003oIVIVofIV
IP07ofIVIP;o0000ComoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonA
ogmoO`;o00002OmVIVH2o`0000OoC4a<00?o0000oc<c<olc<c<01_lc<c<00ol0003o6ATIoaTI6@0<
oaTI6@Oo00003OlI6AT00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00OoC4a<0_l00007
ofIVIP;o0000DOmoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonCogmo
O`;o00002OmVIVH3o`0000GoC4a<0_l00007oc<c<`03o`000?lI6AWo6ATI01go6ATI0_l00007oc<c
<`03o`000?m<C4coC4a<00GoC4a<0ol00008ofIVIP03o`000?moOgooOgmo057oOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CoooooUOmoOgl3o`0000WoIVIV0_l00005oda<C003
o`000?lc<c?o<c<c00Go<c<c1?l0000HoaTI6@?o00001_lc<c<3o`0000KoC4a<0_l00009ofIVIP;o
0000E?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonHogmoO`?o0000
2?mVIVH3o`0000?oC4a<0ol00008oc<c<`Oo00003?lI6AT5o`0000Ko<c<c0ol00007oda<C0;o0000
2?mVIVH3o`0005KoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooVomo
Ogl3o`0000SoIVIV0ol00003oda<C0?o00003?lc<c<<o`0000Ko<c<c1Ol00007oda<C0?o00001_mV
IVH4o`0005WoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooW_moOgl3
o`0000SoIVIV0ol00003oda<C0Go00005Olc<c<4o`0000SoC4a<1?l00006ofIVIP?o0000GOmoOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonQogmoO`Ko00001OmVIVH3o`00
00GoC4a<5Ol00004oda<C0So00001OmVIVH5o`00063oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CoooooS?moOgl>o`0000goOgmo1ol000000omVIVKo0000o`000003o`0001?o
C4a<1_l00007ofIVIPKo00003OmoOgl=o`0004_oOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CoooooR?moOgl4o`0000koVIVI;Ol00006ofIVIQ[o00003OnIVIT3o`0004SoOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooR?moOgl00ol0003oVIVIoiVI
V@0SoiVIVBKo00008onIVIT00ol0003oOgmoogmoO`15ogmoO`Kooooo0Ol00001ooooo`006_ooool2
o`0000GoooooR?moOgl00ol0003oVIVIoiVIV@0KoiVIV@So00001_nIVITIo`0000OoVIVI1ol0000L
oiVIV@03o`000?moOgooOgmo04GoOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo
00CoooooQomoOgl00ol0003oVIVIoiVIV@0@oiVIV@co00002?nc/k<Vo`0000Oo/k>c1ol0000FoiVI
V@03o`000?moOgooOgmo04CoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
ooooQomoOgl00ol0003oVIVIoiVIV@0>oiVIV@;o0000B?nc/k<5o`00017oVIVI00?o0000ogmoOomo
Ogl0A?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon7ogmoO`03o`00
0?nIVIWoVIVI00koVIVI00?o0000ok>c/onc/k<04_nc/k<Xo`00017o/k>c00?o0000oiVIVOnIVIT0
3_nIVIT00ol0003oOgmoogmoO`15ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooohSoOgmo0_l0000>oiVIV@03o`000?nc/k?o/k>c00go/k>c1Ol0000Xolc<c0?o00003_nc
/k<00ol0003oVIVIoiVIV@0=oiVIV@03o`000?moOgooOgmo04KoOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CoooooR_moOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o
/k>c00_o/k>c00?o0000olc<c?o<c<`02Oo<c<`Jo`0000_oc<c<00?o0000ok>c/onc/k<02onc/k<0
0ol0003oVIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo04OoOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CoooooRomoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c
00[o/k>c00?o0000olc<c?o<c<`01_o<c<`4o`0001[oi^KV0ol00009olc<c003o`000?nc/k?o/k>c
00Wo/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`18ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooohcoOgmo00?o0000oiVIVOnIVIT02_nIVIT00ol0003o
/k>cok>c/`09ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o0000onKVi_oVi^H07ooVi^H00ol0003o
c<c<olc<c007olc<c003o`000?nc/k?o/k>c00So/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003o
OgmoogmoO`19ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooohgoOgmo
00?o0000oiVIVOnIVIT02_nIVIT00ol0003o/k>cok>c/`07ok>c/`03o`000?o<c<coc<c<00Koc<c<
00?o0000onKVi_oVi^H08OoVi^H00ol0003oc<c<olc<c007olc<c003o`000?nc/k?o/k>c00Oo/k>c
00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`1:ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooohkoOgmo0ol00009oiVIV@;o00001onc/k<2o`0000Ooc<c<0_l0
000SonKViP;o00002?o<c<`2o`0000Ko/k>c0ol00009oiVIV@?o0000COmoOgl6ooooo`7o00000Ooo
ool000Sooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^1_ooool00ol0003o
ooooooooo`04oooooi7oOgmo00?o0000oiVIVOnIVIT02?nIVIT2o`0000Oo/k>c0_l00007olc<c0;o
00007ooVi^H2o`0000Soc<c<0_l00006ok>c/`;o00002onIVIT00ol0003oOgmoogmoO`1>ogmoO`Ko
oooo0Ol00001ooooo`002_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01_ooool00ol0003oooooooooo`04oooooi;oOgmo00?o0000oiVIVOnIVIT02OnIVIT3o`0000Ko
/k>c0_l00007olc<c0?o00006OoVi^H3o`0000Woc<c<00?o0000ok>c/onc/k<01Onc/k<00ol0003o
VIVIoiVIV@09oiVIV@;o0000DOmoOgl6ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool01?oooonCogmoO`03
o`000?nIVIWoVIVI00_oVIVI0_l00006ok>c/`?o00001oo<c<`3o`00017oi^KV1Ol00009olc<c0?o
00001_nc/k<2o`0000_oVIVI00?o0000ogmoOomoOgl0DOmoOgl6ooooo`7o00000Oooool000[ooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo0ol00004oooooiCo
Ogmo00?o0000oiVIVOnIVIT03?nIVIT3o`0000Ko/k>c0ol00007olc<c17o00002oo<c<`3o`0000Oo
/k>c0_l00009oiVIV@Co0000E?moOgl4ooooo`?o00000Oooool000[ooooo00?o0000ooooooooool0
0_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool01?oooonEogmoO`Go
00003?nIVIT3o`0000Ko/k>c1Ol0000Iolc<c0Go00001onc/k<3o`0000KoVIVI1Ol0001HogmoO`Ko
oooo0Ol00001ooooo`002_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41001_ooool00ol0003oooooooooo`04oooooi[oOgmo2?l00007oiVIV@Ko00001Onc/k<8o`0000Co
c<c<3Ol00005ok>c/`Oo00001OnIVIT4o`0005goOgmo1_ooool1o`00007ooooo000:ooooo`03o`00
0?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00Co
ooooX_moOgl:o`0000?oVIVI1Ol00008ok>c/`Co00003Onc/k<5o`0000;oVIVI2_l0001QogmoO`Ko
oooo0Ol00001ooooo`002?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01_ooool00ol0003oooooooooo`04ooooojcoOgmo0ol00005oiVIVB3o0000JomoOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?oooon_ogmoO`Go00004onIVIT6o`0007;oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooT_moOgl?o`0000GoOgmo1_l0
0008ogmoOa?o00003OmoOgl7o`0000KoOgmo3_l0001@ogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooohooOgmo0ol0000?ofIVIPGo00001_mVIVH3o`0001koOgmo1ol00007
ofIVIPKo00003_mVIVH3o`0004goOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CoooooS_moOgl00ol0003oIVIVofIVIP0NofIVIQko00009?mVIVH00ol0003oOgmoogmoO`1;ogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooohgoOgmo00?o0000ofIVI_mV
IVH0H_mVIVH00ol0003oOgmoogmoO`1:ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooohgoOgmo00?o0000ofIVI_mVIVH0H_mVIVH00ol0003oOgmoogmoO`1:ogmoO`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooohkoOgmo00?o0000ofIVI_mVIVH0GomV
IVH2o`0004goOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooSomoOgl2
o`0001coIVIV9_l0000LofIVIP03o`000?moOgooOgmo04goOgmo1_ooool1o`00007ooooo000Joooo
o`;o00001OoooonAogmoO`03o`000?mVIVKoIVIV01GoIVIV1?l0000Voda<C0?o00006?mVIVH00ol0
003oOgmoogmoO`1>ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04oooooi;o
Ogmo00?o0000ofIVI_mVIVH04omVIVH00ol0003oC4a<oda<C00[oda<C0;o00005OmVIVH00ol0003o
OgmoogmoO`1?ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooi?oOgmo
00?o0000ofIVI_mVIVH04OmVIVH00ol0003oC4a<oda<C00]oda<C003o`000?mVIVKoIVIV01;oIVIV
00?o0000ogmoOomoOgl0D?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
oonCogmoO`03o`000?mVIVKoIVIV01;oIVIV00?o0000oda<C?m<C4`0:om<C4`2o`0001?oIVIV00?o
0000ogmoOomoOgl0DOmoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonD
ogmoO`03o`000?mVIVKoIVIV01;oIVIV0ol0000Woda<C0?o00004omVIVH2o`0005CoOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooU?moOgl00ol0003oIVIVofIVIP0EofIV
IP?o00008_m<C4`2o`0001CoIVIV0_l0001FogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04oooooiGoOgmo1Ol0000EofIVIPCo00006_m<C4`4o`0001CoIVIV0_l0001HogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooi[oOgmo1?l0000EofIVIP?o0000
4Om<C4`6o`0001KoIVIV0_l0001JogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04oooooikoOgmo0_l0000FofIVIQ7o00006OmVIVH3o`0005coOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CoooooX?moOgl6o`0003CoIVIV1_l0001OogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooojKoOgmo0ol0000/ofIVIPGo0000IOmoOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonYogmoO`Go00009?mVIVH3o`0006[o
Ogmo1_ooool1o`00007ooooo000Jooooo`;o00001Ooooon^ogmoO`Ko00006OmVIVH5o`0006goOgmo
1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo]?moOglIo`0007;oOgmo1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooo
ogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo0_l00005oooo
ooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3o
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooooomo
Ogm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo0_l0
0005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool01?oooooo
ogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo
@?moOgl6ooooo`7o00000Oooool000Oooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000Oooooo00Go
V9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003o
ooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000Sooooo00?oV9RHob4Q8Oo^k^h0
1?ooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool01?ooooooogmoOd3o
Ogmo1_ooool1o`00007ooooo0009ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooooooo
ooooo`000006ooooo`?o00001?ooooooogmoOd3oOgmo1?ooool3o`00007ooooo000:ooooo`03ogMg
MomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00Co
oooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002oooool01Ol0003ooooooooooooooooo410@00?o
oooo00?o410@ooooooooool01?ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool000Oooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000Oo
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool0
0ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo
@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o0000
1OooooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooooomo
Ogm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
ooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3o
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Joooo
o`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo
@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooo
ogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo
000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
ooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3o
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooooomo
Ogm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00
007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooo
ogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo0007ooooo`05oiRHV?l@413o0000oc8b
<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool01?oooooo
ogmoOd3oOgmo1_ooool1o`00007ooooo0007ooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_oo
ool1o`00007ooooo000;ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413ooooooooo
o`04ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool0
0onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool3o`0000Cooooooomo
Ogm0ogmoO`Cooooo0ol00001ooooo`002Oooool00ol@413o0000okZj^P03ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Ooo
ool000[ooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@00Kooooo00?o
0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo0007ooooo`05oa0@4?nHV9So
oooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0
1?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo0007ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool01?ooooooogmoOd3o
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooooomo
Ogm0ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001
ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooo
ogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo
0_l00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooooomo
Ogm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000GooooooomoOgm0ogmo
O`Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo
@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000Gooooooomo
Ogm0ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
ooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3o
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo
0Ol00001ooooo`002Oooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^
00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000:ooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`001oooool5o`0000?ooooo00Go410@oooooooo
oooooooooa0@4006ooooo`?o00001?ooooooogmoOd3oOgmo1?ooool3o`00007ooooo0007ooooo`04
odA4A?oMgMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
oooo0?ooooooB_ooool1o`00007ooooo0007ooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?ooooooB_ooool1o`00007ooooo0008
ooooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oo
oooooooo0?ooooooB_ooool1o`00007ooooo0008ooooo`03onk^k_m4A4Co000000Cooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?ooooooB_ooool1o`00007ooooo0009
ooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oo
oooooooo02?ooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0mooooo`03o`000?oo
oooooooo03gooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Sooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`7o00000Oooool0
01[oooooool0001>o`00007ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-30.1723, -14.304, 0.195672, \
0.195672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0192308 0.211538 0.0192308 [
[.11538 -0.0125 -9 -9 ]
[.11538 -0.0125 9 0 ]
[.30769 -0.0125 -9 -9 ]
[.30769 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69231 -0.0125 -6 -9 ]
[.69231 -0.0125 6 0 ]
[.88462 -0.0125 -6 -9 ]
[.88462 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -18 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .21154 -6 -4.5 ]
[-0.0125 .21154 0 4.5 ]
[-0.0125 .40385 -12 -4.5 ]
[-0.0125 .40385 0 4.5 ]
[-0.0125 .59615 -12 -4.5 ]
[-0.0125 .59615 0 4.5 ]
[-0.0125 .78846 -12 -4.5 ]
[-0.0125 .78846 0 4.5 ]
[-0.0125 .98077 -12 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11538 0 m
.11538 .00625 L
s
[(-20)] .11538 -0.0125 0 1 Mshowa
.30769 0 m
.30769 .00625 L
s
[(-10)] .30769 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69231 0 m
.69231 .00625 L
s
[(10)] .69231 -0.0125 0 1 Mshowa
.88462 0 m
.88462 .00625 L
s
[(20)] .88462 -0.0125 0 1 Mshowa
.125 Mabswid
.15385 0 m
.15385 .00375 L
s
.19231 0 m
.19231 .00375 L
s
.23077 0 m
.23077 .00375 L
s
.26923 0 m
.26923 .00375 L
s
.34615 0 m
.34615 .00375 L
s
.38462 0 m
.38462 .00375 L
s
.42308 0 m
.42308 .00375 L
s
.46154 0 m
.46154 .00375 L
s
.53846 0 m
.53846 .00375 L
s
.57692 0 m
.57692 .00375 L
s
.61538 0 m
.61538 .00375 L
s
.65385 0 m
.65385 .00375 L
s
.73077 0 m
.73077 .00375 L
s
.76923 0 m
.76923 .00375 L
s
.80769 0 m
.80769 .00375 L
s
.84615 0 m
.84615 .00375 L
s
.07692 0 m
.07692 .00375 L
s
.03846 0 m
.03846 .00375 L
s
.92308 0 m
.92308 .00375 L
s
.96154 0 m
.96154 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(-10)] -0.0125 .01923 1 0 Mshowa
0 .21154 m
.00625 .21154 L
s
[(0)] -0.0125 .21154 1 0 Mshowa
0 .40385 m
.00625 .40385 L
s
[(10)] -0.0125 .40385 1 0 Mshowa
0 .59615 m
.00625 .59615 L
s
[(20)] -0.0125 .59615 1 0 Mshowa
0 .78846 m
.00625 .78846 L
s
[(30)] -0.0125 .78846 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(40)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .05769 m
.00375 .05769 L
s
0 .09615 m
.00375 .09615 L
s
0 .13462 m
.00375 .13462 L
s
0 .17308 m
.00375 .17308 L
s
0 .25 m
.00375 .25 L
s
0 .28846 m
.00375 .28846 L
s
0 .32692 m
.00375 .32692 L
s
0 .36538 m
.00375 .36538 L
s
0 .44231 m
.00375 .44231 L
s
0 .48077 m
.00375 .48077 L
s
0 .51923 m
.00375 .51923 L
s
0 .55769 m
.00375 .55769 L
s
0 .63462 m
.00375 .63462 L
s
0 .67308 m
.00375 .67308 L
s
0 .71154 m
.00375 .71154 L
s
0 .75 m
.00375 .75 L
s
0 .82692 m
.00375 .82692 L
s
0 .86538 m
.00375 .86538 L
s
0 .90385 m
.00375 .90385 L
s
0 .94231 m
.00375 .94231 L
s
.25 Mabswid
0 0 m
0 1 L
s
.11538 .99375 m
.11538 1 L
s
.30769 .99375 m
.30769 1 L
s
.5 .99375 m
.5 1 L
s
.69231 .99375 m
.69231 1 L
s
.88462 .99375 m
.88462 1 L
s
.125 Mabswid
.15385 .99625 m
.15385 1 L
s
.19231 .99625 m
.19231 1 L
s
.23077 .99625 m
.23077 1 L
s
.26923 .99625 m
.26923 1 L
s
.34615 .99625 m
.34615 1 L
s
.38462 .99625 m
.38462 1 L
s
.42308 .99625 m
.42308 1 L
s
.46154 .99625 m
.46154 1 L
s
.53846 .99625 m
.53846 1 L
s
.57692 .99625 m
.57692 1 L
s
.61538 .99625 m
.61538 1 L
s
.65385 .99625 m
.65385 1 L
s
.73077 .99625 m
.73077 1 L
s
.76923 .99625 m
.76923 1 L
s
.80769 .99625 m
.80769 1 L
s
.84615 .99625 m
.84615 1 L
s
.07692 .99625 m
.07692 1 L
s
.03846 .99625 m
.03846 1 L
s
.92308 .99625 m
.92308 1 L
s
.96154 .99625 m
.96154 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .21154 m
1 .21154 L
s
.99375 .40385 m
1 .40385 L
s
.99375 .59615 m
1 .59615 L
s
.99375 .78846 m
1 .78846 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .05769 m
1 .05769 L
s
.99625 .09615 m
1 .09615 L
s
.99625 .13462 m
1 .13462 L
s
.99625 .17308 m
1 .17308 L
s
.99625 .25 m
1 .25 L
s
.99625 .28846 m
1 .28846 L
s
.99625 .32692 m
1 .32692 L
s
.99625 .36538 m
1 .36538 L
s
.99625 .44231 m
1 .44231 L
s
.99625 .48077 m
1 .48077 L
s
.99625 .51923 m
1 .51923 L
s
.99625 .55769 m
1 .55769 L
s
.99625 .63462 m
1 .63462 L
s
.99625 .67308 m
1 .67308 L
s
.99625 .71154 m
1 .71154 L
s
.99625 .75 m
1 .75 L
s
.99625 .82692 m
1 .82692 L
s
.99625 .86538 m
1 .86538 L
s
.99625 .90385 m
1 .90385 L
s
.99625 .94231 m
1 .94231 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.6 g
.43132 .39146 m
.45094 .38386 L
.47057 .38462 L
.49019 .3851 L
.50981 .38994 L
.52943 .39181 L
.53176 .39207 L
.54906 .394 L
.56868 .39559 L
.5883 .39653 L
.60793 .39679 L
.62755 .39638 L
.64717 .3953 L
.6668 .39357 L
.67955 .39207 L
.68642 .3913 L
.70604 .38906 L
.72567 .38362 L
.74529 .38426 L
.76491 .38419 L
.78056 .39207 L
.7681 .4117 L
.76491 .41445 L
.74529 .42619 L
.73378 .43132 L
.72567 .43328 L
.70604 .44095 L
.68642 .44767 L
.6668 .45006 L
.66109 .45094 L
.64717 .45285 L
.62755 .4546 L
.60793 .45525 L
.5883 .45483 L
.56868 .45334 L
.55053 .45094 L
.54906 .45072 L
.52943 .44883 L
.50981 .44259 L
.49019 .43485 L
.47762 .43132 L
.47057 .42827 L
.45094 .41748 L
.44353 .4117 L
.43132 .39467 L
.43103 .39207 L
F
0 g
.43132 .39146 m
.45094 .38386 L
.47057 .38462 L
.49019 .3851 L
.50981 .38994 L
.52943 .39181 L
.53176 .39207 L
.54906 .394 L
.56868 .39559 L
.5883 .39653 L
.60793 .39679 L
.62755 .39638 L
.64717 .3953 L
.6668 .39357 L
.67955 .39207 L
.68642 .3913 L
.70604 .38906 L
.72567 .38362 L
.74529 .38426 L
.76491 .38419 L
.78056 .39207 L
.7681 .4117 L
.76491 .41445 L
.74529 .42619 L
.73378 .43132 L
.72567 .43328 L
.70604 .44095 L
.68642 .44767 L
.6668 .45006 L
.66109 .45094 L
.64717 .45285 L
.62755 .4546 L
.60793 .45525 L
.5883 .45483 L
.56868 .45334 L
.55053 .45094 L
.54906 .45072 L
.52943 .44883 L
.50981 .44259 L
.49019 .43485 L
.47762 .43132 L
.47057 .42827 L
.45094 .41748 L
.44353 .4117 L
.43132 .39467 L
.43103 .39207 L
.43132 .39146 L
s
.4 g
.45094 .32848 m
.47057 .32591 L
.49019 .33234 L
.50981 .3309 L
.52943 .33306 L
.53084 .3332 L
.54906 .33486 L
.56868 .33617 L
.5883 .33695 L
.60793 .33717 L
.62755 .33682 L
.64717 .33592 L
.6668 .3345 L
.68043 .3332 L
.68642 .3326 L
.70604 .33042 L
.72567 .33085 L
.74529 .32404 L
.76491 .3294 L
.77319 .3332 L
.76747 .35283 L
.76491 .35504 L
.74529 .36635 L
.73087 .37245 L
.72567 .37417 L
.70604 .38233 L
.68642 .38465 L
.6668 .38796 L
.64717 .39033 L
.62755 .39179 L
.62095 .39207 L
.60793 .39235 L
.5905 .39207 L
.5883 .39199 L
.56868 .39073 L
.54906 .38856 L
.52943 .38546 L
.50981 .38431 L
.49019 .37578 L
.4806 .37245 L
.47057 .36837 L
.45094 .35796 L
.44421 .35283 L
.43827 .3332 L
F
0 g
.45094 .32848 m
.47057 .32591 L
.49019 .33234 L
.50981 .3309 L
.52943 .33306 L
.53084 .3332 L
.54906 .33486 L
.56868 .33617 L
.5883 .33695 L
.60793 .33717 L
.62755 .33682 L
.64717 .33592 L
.6668 .3345 L
.68043 .3332 L
.68642 .3326 L
.70604 .33042 L
.72567 .33085 L
.74529 .32404 L
.76491 .3294 L
.77319 .3332 L
.76747 .35283 L
.76491 .35504 L
.74529 .36635 L
.73087 .37245 L
.72567 .37417 L
.70604 .38233 L
.68642 .38465 L
.6668 .38796 L
.64717 .39033 L
.62755 .39179 L
.62095 .39207 L
.60793 .39235 L
.5905 .39207 L
.5883 .39199 L
.56868 .39073 L
.54906 .38856 L
.52943 .38546 L
.50981 .38431 L
.49019 .37578 L
.4806 .37245 L
.47057 .36837 L
.45094 .35796 L
.44421 .35283 L
.43827 .3332 L
.45094 .32848 L
s
.6 g
.47057 .28392 m
.49019 .2806 L
.50981 .2803 L
.52943 .28091 L
.54906 .28134 L
.56868 .28524 L
.5883 .28752 L
.60793 .2882 L
.62755 .28714 L
.64717 .28455 L
.6668 .28006 L
.68642 .28074 L
.70604 .28025 L
.72567 .28093 L
.74529 .28588 L
.75087 .29396 L
.74529 .30093 L
.72599 .31358 L
.72567 .3139 L
.70604 .31989 L
.68642 .32448 L
.6668 .32797 L
.64717 .33047 L
.62755 .33201 L
.60793 .3326 L
.5883 .33222 L
.56868 .3309 L
.54906 .32861 L
.52943 .32534 L
.50981 .32101 L
.49019 .31791 L
.48583 .31358 L
.47057 .30451 L
.46067 .29396 L
F
0 g
.47057 .28392 m
.49019 .2806 L
.50981 .2803 L
.52943 .28091 L
.54906 .28134 L
.56868 .28524 L
.5883 .28752 L
.60793 .2882 L
.62755 .28714 L
.64717 .28455 L
.6668 .28006 L
.68642 .28074 L
.70604 .28025 L
.72567 .28093 L
.74529 .28588 L
.75087 .29396 L
.74529 .30093 L
.72599 .31358 L
.72567 .3139 L
.70604 .31989 L
.68642 .32448 L
.6668 .32797 L
.64717 .33047 L
.62755 .33201 L
.60793 .3326 L
.5883 .33222 L
.56868 .3309 L
.54906 .32861 L
.52943 .32534 L
.50981 .32101 L
.49019 .31791 L
.48583 .31358 L
.47057 .30451 L
.46067 .29396 L
.47057 .28392 L
s
.4 g
.47057 .45748 m
.49019 .45623 L
.50981 .45787 L
.52943 .4599 L
.54906 .46171 L
.56868 .46306 L
.5883 .46387 L
.60793 .4641 L
.62755 .46374 L
.64717 .46281 L
.6668 .46134 L
.68642 .45946 L
.70604 .45744 L
.72567 .45607 L
.74522 .47057 L
.72567 .48584 L
.71739 .49019 L
.70604 .49645 L
.68642 .50924 L
.6668 .50757 L
.65478 .50981 L
.64717 .51108 L
.62755 .51077 L
.60793 .51137 L
.5883 .51097 L
.56868 .50996 L
.55662 .50981 L
.54906 .50842 L
.52943 .50391 L
.50981 .49896 L
.49412 .49019 L
.49019 .4882 L
.47057 .47511 L
.46635 .47057 L
F
0 g
.47057 .45748 m
.49019 .45623 L
.50981 .45787 L
.52943 .4599 L
.54906 .46171 L
.56868 .46306 L
.5883 .46387 L
.60793 .4641 L
.62755 .46374 L
.64717 .46281 L
.6668 .46134 L
.68642 .45946 L
.70604 .45744 L
.72567 .45607 L
.74522 .47057 L
.72567 .48584 L
.71739 .49019 L
.70604 .49645 L
.68642 .50924 L
.6668 .50757 L
.65478 .50981 L
.64717 .51108 L
.62755 .51077 L
.60793 .51137 L
.5883 .51097 L
.56868 .50996 L
.55662 .50981 L
.54906 .50842 L
.52943 .50391 L
.50981 .49896 L
.49412 .49019 L
.49019 .4882 L
.47057 .47511 L
.46635 .47057 L
.47057 .45748 L
s
.3 g
.49019 .34482 m
.50981 .34085 L
.52943 .34029 L
.54906 .3406 L
.56868 .34109 L
.5883 .34145 L
.60793 .34156 L
.62755 .34139 L
.64717 .34098 L
.6668 .3405 L
.68642 .3403 L
.70604 .34124 L
.72567 .34755 L
.72844 .35283 L
.72567 .35688 L
.70604 .37067 L
.70234 .37245 L
.68642 .37777 L
.6668 .38237 L
.64717 .38547 L
.62755 .38733 L
.60793 .38802 L
.5883 .38758 L
.56868 .38598 L
.54906 .38317 L
.52943 .37893 L
.50981 .37291 L
.50918 .37245 L
.49019 .36098 L
.48311 .35283 L
F
0 g
.49019 .34482 m
.50981 .34085 L
.52943 .34029 L
.54906 .3406 L
.56868 .34109 L
.5883 .34145 L
.60793 .34156 L
.62755 .34139 L
.64717 .34098 L
.6668 .3405 L
.68642 .3403 L
.70604 .34124 L
.72567 .34755 L
.72844 .35283 L
.72567 .35688 L
.70604 .37067 L
.70234 .37245 L
.68642 .37777 L
.6668 .38237 L
.64717 .38547 L
.62755 .38733 L
.60793 .38802 L
.5883 .38758 L
.56868 .38598 L
.54906 .38317 L
.52943 .37893 L
.50981 .37291 L
.50918 .37245 L
.49019 .36098 L
.48311 .35283 L
.49019 .34482 L
s
.7 g
.49019 .40371 m
.50981 .39955 L
.52943 .39942 L
.54906 .40008 L
.56868 .40079 L
.5883 .40129 L
.60793 .40143 L
.62755 .4012 L
.64717 .40065 L
.6668 .39991 L
.68642 .39934 L
.70604 .39987 L
.72567 .4087 L
.72586 .4117 L
.72567 .41202 L
.70604 .42747 L
.69825 .43132 L
.68642 .43849 L
.6668 .44132 L
.64717 .4449 L
.62755 .447 L
.60793 .44778 L
.5883 .44728 L
.56868 .44548 L
.54906 .44225 L
.52943 .44128 L
.51327 .43132 L
.50981 .42969 L
.49019 .41705 L
.4857 .4117 L
F
0 g
.49019 .40371 m
.50981 .39955 L
.52943 .39942 L
.54906 .40008 L
.56868 .40079 L
.5883 .40129 L
.60793 .40143 L
.62755 .4012 L
.64717 .40065 L
.6668 .39991 L
.68642 .39934 L
.70604 .39987 L
.72567 .4087 L
.72586 .4117 L
.72567 .41202 L
.70604 .42747 L
.69825 .43132 L
.68642 .43849 L
.6668 .44132 L
.64717 .4449 L
.62755 .447 L
.60793 .44778 L
.5883 .44728 L
.56868 .44548 L
.54906 .44225 L
.52943 .44128 L
.51327 .43132 L
.50981 .42969 L
.49019 .41705 L
.4857 .4117 L
.49019 .40371 L
s
.4 g
.52943 .24189 m
.54906 .2398 L
.56868 .23903 L
.5883 .23876 L
.60793 .2387 L
.62755 .23879 L
.64717 .23914 L
.6668 .2401 L
.68642 .24275 L
.7007 .25471 L
.68642 .26186 L
.6668 .26789 L
.64717 .27168 L
.62755 .27383 L
.61875 .27433 L
.60793 .27481 L
.59274 .27433 L
.5883 .27411 L
.56868 .27229 L
.54906 .26889 L
.52943 .26344 L
.51083 .25471 L
F
0 g
.52943 .24189 m
.54906 .2398 L
.56868 .23903 L
.5883 .23876 L
.60793 .2387 L
.62755 .23879 L
.64717 .23914 L
.6668 .2401 L
.68642 .24275 L
.7007 .25471 L
.68642 .26186 L
.6668 .26789 L
.64717 .27168 L
.62755 .27383 L
.61875 .27433 L
.60793 .27481 L
.59274 .27433 L
.5883 .27411 L
.56868 .27229 L
.54906 .26889 L
.52943 .26344 L
.51083 .25471 L
.52943 .24189 L
s
.2 g
.52943 .34874 m
.54906 .34681 L
.56868 .34625 L
.5883 .34612 L
.60793 .34611 L
.62755 .34613 L
.64717 .34632 L
.6668 .34706 L
.68642 .34962 L
.69528 .35283 L
.68642 .36811 L
.67859 .37245 L
.6668 .37613 L
.64717 .38027 L
.62755 .38262 L
.60793 .38348 L
.5883 .38293 L
.56868 .38092 L
.54906 .37722 L
.53295 .37245 L
.52943 .37066 L
.51625 .35283 L
F
0 g
.52943 .34874 m
.54906 .34681 L
.56868 .34625 L
.5883 .34612 L
.60793 .34611 L
.62755 .34613 L
.64717 .34632 L
.6668 .34706 L
.68642 .34962 L
.69528 .35283 L
.68642 .36811 L
.67859 .37245 L
.6668 .37613 L
.64717 .38027 L
.62755 .38262 L
.60793 .38348 L
.5883 .38293 L
.56868 .38092 L
.54906 .37722 L
.53295 .37245 L
.52943 .37066 L
.51625 .35283 L
.52943 .34874 L
s
.7 g
.54906 .29071 m
.56868 .2912 L
.5883 .29187 L
.60793 .29211 L
.62755 .29175 L
.64717 .29104 L
.6668 .29083 L
.67961 .29396 L
.68642 .29578 L
.68785 .31358 L
.68642 .31417 L
.6668 .3202 L
.64717 .32398 L
.62755 .32618 L
.60793 .32699 L
.5883 .32647 L
.56868 .32459 L
.54906 .32119 L
.52943 .31577 L
.5237 .31358 L
.52943 .29455 L
.53202 .29396 L
F
0 g
.54906 .29071 m
.56868 .2912 L
.5883 .29187 L
.60793 .29211 L
.62755 .29175 L
.64717 .29104 L
.6668 .29083 L
.67961 .29396 L
.68642 .29578 L
.68785 .31358 L
.68642 .31417 L
.6668 .3202 L
.64717 .32398 L
.62755 .32618 L
.60793 .32699 L
.5883 .32647 L
.56868 .32459 L
.54906 .32119 L
.52943 .31577 L
.5237 .31358 L
.52943 .29455 L
.53202 .29396 L
.54906 .29071 L
s
.8 g
.52943 .41017 m
.54906 .40741 L
.56868 .40675 L
.5883 .40662 L
.60793 .40661 L
.62755 .40663 L
.64717 .40683 L
.6668 .40773 L
.68632 .4117 L
.66694 .43132 L
.6668 .43137 L
.64717 .4367 L
.62755 .43958 L
.60793 .44062 L
.5883 .43996 L
.56868 .43751 L
.54906 .43282 L
.54454 .43132 L
.52943 .42298 L
.52515 .4117 L
F
0 g
.52943 .41017 m
.54906 .40741 L
.56868 .40675 L
.5883 .40662 L
.60793 .40661 L
.62755 .40663 L
.64717 .40683 L
.6668 .40773 L
.68632 .4117 L
.66694 .43132 L
.6668 .43137 L
.64717 .4367 L
.62755 .43958 L
.60793 .44062 L
.5883 .43996 L
.56868 .43751 L
.54906 .43282 L
.54454 .43132 L
.52943 .42298 L
.52515 .4117 L
.52943 .41017 L
s
.1 g
.56868 .35231 m
.5883 .3514 L
.60793 .3512 L
.62755 .35152 L
.64717 .35268 L
.64873 .35283 L
.65338 .37245 L
.64717 .37399 L
.62755 .37722 L
.60793 .37835 L
.5883 .37764 L
.56868 .37492 L
.55797 .37245 L
.56237 .35283 L
F
0 g
.56868 .35231 m
.5883 .3514 L
.60793 .3512 L
.62755 .35152 L
.64717 .35268 L
.64873 .35283 L
.65338 .37245 L
.64717 .37399 L
.62755 .37722 L
.60793 .37835 L
.5883 .37764 L
.56868 .37492 L
.55797 .37245 L
.56237 .35283 L
.56868 .35231 L
s
.8 g
.56868 .30345 m
.5883 .30087 L
.60793 .30036 L
.62755 .30119 L
.64717 .30475 L
.65108 .31358 L
.64717 .31476 L
.62755 .31858 L
.60793 .31985 L
.5883 .31905 L
.56868 .31589 L
.56021 .31358 L
F
0 g
.56868 .30345 m
.5883 .30087 L
.60793 .30036 L
.62755 .30119 L
.64717 .30475 L
.65108 .31358 L
.64717 .31476 L
.62755 .31858 L
.60793 .31985 L
.5883 .31905 L
.56868 .31589 L
.56021 .31358 L
.56868 .30345 L
s
.9 g
.60793 .41403 m
.61544 .43132 L
.60793 .43165 L
.59611 .43132 L
F
0 g
.60793 .41403 m
.61544 .43132 L
.60793 .43165 L
.59611 .43132 L
.60793 .41403 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00?Oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0dooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kS?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0hooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8b
onk^kS?ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08_ooool003gooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0=_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0<oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg03?ooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL08_ooool003Gooooo1_l0
0003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400[ooooo`Ko0000
1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100<oooool01Ol@413o
oooooooooooooooo410@03[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@03Cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@02;ooooo000o
ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000fooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000cooooo`05o`000?ooooooooooooooool0
0000>_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000=Oooool00onH
V9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000008_ooool0043ooooo00?oMgMgofIV
I_ooool00_ooool01Ol0003ooooooooooooooooo000003Kooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000003?ooooo00Go0000ooooooooooooooooo`00000jooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`03ogMgMomVIVKooooo00;o
oooo00Go0000ooooooooooooooooo`00000Rooooo`00@Oooool01Ol0003ooooooooooooooooo410@
00?ooooo00?o410@ooooooooool0=?ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@4100<oooool01Ol@413ooooooooooooooooo410@03[ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@03Oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo023ooooo000mooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg03Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg03?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0jooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0cooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02;ooooo000mooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^03Cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^03?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`03oeEEEOmVIVKo000000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0cooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02;ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo000Joooooooo0000C_l00001ooooo`00
6_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0?Ooo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool08ooo
ool1o`00007ooooo0008ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKo
oooo00?o0000ooooooooool0oooooom:ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooom:ooooo`7o
00000Oooool000Go00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41001_ooool00ol0003oooooooooo`3ooooood[ooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?ooooooB?ooool3o`00007o
oooo000:ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo0008ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Oooooooogmo
Od3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Ooo
ooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000oooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`003ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000?ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000oooooo00Go0000oooooooooooooooo
o`000006ooooo`?o00001?ooooooogmoOd3oOgmo1?ooool3o`00007ooooo000?ooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool000oooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`003oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000?ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
[OmoOgl^o`0006CoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooZ?mo
Ogl5o`0002koIVIV1?l0001PogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooojOoOgmo00?o0000ofIVI_mVIVH0=OmVIVH00ol0003oOgmoogmoO`1MogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooojGoOgmo0_l0000iofIVIP03o`000?moOgooOgmo
05coOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OoooonTogmoO`03o`000?mVIVKoIVIV03[o
IVIV00?o0000ogmoOomoOgl0FomoOgl5ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool0
1?oooonSogmoO`;o0000??mVIVH2o`0005coOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CoooooYOmoOgl2o`0003SoIVIV0_l0001NogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooojOoOgmo0_l0000eofIVIP03o`000?moOgooOgmo05koOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooZOmoOgl3o`00033oIVIV0_l0001Qogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooojcoOgmo0ol0000ZofIVIP?o
0000HomoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon_ogmoO`Go0000
8?mVIVH5o`0006KoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo]?mo
Ogl7o`0001;oIVIV1ol0001[ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
oooook_oOgmo4_l0001bogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
ooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonIogmoOa_o
00008?moOglIo`0005;oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
UOmoOgl4o`0001_oVIVI1ol0000BogmoO`Oo00006OnIVIT3o`0004ooOgmo1_ooool1o`00007ooooo
000Jooooo`;o00001OoooonDogmoO`03o`000?nIVIWoVIVI02CoVIVI4_l0000SoiVIV@;o0000COmo
Ogl5ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool01?oooonCogmoO`03o`000?nIVIWo
VIVI01OoVIVI3_l0000BoiVIV@go00006?nIVIT00ol0003oOgmoogmoO`1:ogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04oooooi;oOgmo00?o0000oiVIVOnIVIT05?nIVIT4o`00
00ko/k>c4_l0000=ok>c/`?o00005_nIVIT00ol0003oOgmoogmoO`19ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04oooooi;oOgmo00?o0000oiVIVOnIVIT05?nIVIT00ol0003o
/k>cok>c/`0aok>c/`03o`000?nIVIWoVIVI01?oVIVI00?o0000ogmoOomoOgl0BOmoOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?oooonCogmoO`03o`000?nIVIWoVIVI01?oVIVI
00?o0000ok>c/onc/k<05?nc/k<8o`0001Go/k>c00?o0000oiVIVOnIVIT04_nIVIT00ol0003oOgmo
ogmoO`1:ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooiCoOgmo00?o
0000oiVIVOnIVIT04OnIVIT00ol0003o/k>cok>c/`0;ok>c/`[o00002?o<c<`6o`0000oo/k>c00?o
0000oiVIVOnIVIT04?nIVIT2o`0004goOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CoooooUOmoOgl2o`00017oVIVI00?o0000ok>c/onc/k<02onc/k<00ol0003oc<c<olc<c00E
olc<c0?o00003?nc/k<00ol0003oVIVIoiVIV@0>oiVIV@;o0000ComoOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?oooonGogmoO`;o00003onIVIT00ol0003o/k>cok>c/`0:ok>c
/`03o`000?o<c<coc<c<01Soc<c<00?o0000ok>c/onc/k<02onc/k<00ol0003oVIVIoiVIV@0<oiVI
V@03o`000?moOgooOgmo04ooOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
ooooVOmoOgl2o`0000coVIVI00?o0000ok>c/onc/k<02_nc/k<00ol0003oc<c<olc<c00Jolc<c003
o`000?nc/k?o/k>c00[o/k>c00?o0000oiVIVOnIVIT02_nIVIT2o`0005;oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CoooooVomoOgl00ol0003oVIVIoiVIV@09oiVIV@;o0000
2_nc/k<3o`0001Ooc<c<1Ol0000:ok>c/`?o00002_nIVIT2o`0005CoOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CoooooW?moOgl5o`0000SoVIVI1Ol00008ok>c/`Go00003?o<
c<`6o`0000co/k>c0ol0000:oiVIV@?o0000E_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?oooonQogmoO`Go00002?nIVIT6o`0000Oo/k>c3?l0000=ok>c/`Go00002?nIVIT5
o`0005WoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooY_moOgl3o`00
00_oVIVI1ol0000Bok>c/`Oo00002?nIVIT5o`0000ooOgmo1?l0001;ogmoO`Kooooo0Ol00001oooo
o`006_ooool2o`0000GoooooT_moOgl6o`00017oOgmo1Ol0000=oiVIVA;o00003?nIVIT3o`00017o
Ogmo0ol00004ofIVIP?o0000B?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool0
1?oooon=ogmoO`Go00001_mVIVH3o`0001?oOgmo1_l0000IoiVIV@co00002?moOgl7o`0000?oOgmo
0_l0000:ofIVIP?o0000AOmoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
oon;ogmoO`;o00003_mVIVHCo`0000KoOgmo6Ol0000<ogmoO`So00001omVIVH3o`0000ooIVIV00?o
0000ogmoOomoOgl0@_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon;
ogmoO`03o`000?mVIVKoIVIV023oIVIV3Ol0000<ogmoOa;o00008OmVIVH00ol0003oOgmoogmoO`12
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooh_oOgmo00?o0000ofIV
I_mVIVH0;OmVIVH<o`0003?oIVIV00?o0000ogmoOomoOgl0@_moOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?oooon<ogmoO`03o`000?mVIVKoIVIV017oIVIVAol0000BofIVIP03
o`000?moOgooOgmo04?oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
S?moOgl00ol0003oIVIVofIVIP0=ofIVIPCo0000Aom<C4`3o`0000ooIVIV00?o0000ogmoOomoOgl0
@omoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon<ogmoO`03o`000?mV
IVKoIVIV00goIVIV00?o0000oda<C?m<C4`02Om<C4`co`0000ooC4a<00?o0000ofIVI_mVIVH03?mV
IVH00ol0003oOgmoogmoO`13ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooohgoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C008oda<C0;o00004_lc<c<D
o`0000go<c<c1Ol0000:oda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl0A?moOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon=ogmoO`03o`000?mVIVKoIVIV
00[oIVIV00?o0000oda<C?m<C4`02?m<C4`00ol0003o<c<coc<c<`0<oc<c<`Ko00005?lI6AT4o`00
00ko<c<c00?o0000oda<C?m<C4`02?m<C4`00ol0003oIVIVofIVIP0:ofIVIP03o`000?moOgooOgmo
04CoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooS_moOgl00ol0003o
IVIVofIVIP09ofIVIP03o`000?m<C4coC4a<00SoC4a<00?o0000oc<c<olc<c<03?lc<c<00ol0003o
6ATIoaTI6@0JoaTI6@03o`000?lc<c?o<c<c00co<c<c00?o0000oda<C?m<C4`01_m<C4`2o`0000_o
IVIV0_l00017ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooohooOgmo
0_l0000:ofIVIP03o`000?m<C4coC4a<00SoC4a<00?o0000oc<c<olc<c<02olc<c<00ol0003o6ATI
oaTI6@0JoaTI6@03o`000?lc<c?o<c<c00_o<c<c00?o0000oda<C?m<C4`01_m<C4`00ol0003oIVIV
ofIVIP09ofIVIP;o0000BOmoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
oonAogmoO`;o00002OmVIVH2o`0000WoC4a<00?o0000oc<c<olc<c<02_lc<c<00ol0003o6ATIoaTI
6@0JoaTI6@03o`000?lc<c?o<c<c00[o<c<c00?o0000oda<C?m<C4`01_m<C4`00ol0003oIVIVofIV
IP08ofIVIP;o0000BomoOgl6ooooo`7o00000Oooool001[ooooo0_l00005oooooi?oOgmo0_l00009
ofIVIP;o00001om<C4`00ol0003o<c<coc<c<`09oc<c<`03o`000?lI6AWo6ATI01co6ATI00?o0000
oc<c<olc<c<02Olc<c<00ol0003oC4a<oda<C005oda<C003o`000?mVIVKoIVIV00OoIVIV0_l0001=
ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04oooooiGoOgmo0ol00008ofIV
IP;o00001_m<C4`00ol0003o<c<coc<c<`08oc<c<`03o`000?lI6AWo6ATI01co6ATI00?o0000oc<c
<olc<c<01olc<c<2o`0000OoC4a<00?o0000ofIVI_mVIVH01OmVIVH3o`0004ooOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CoooooV?moOgl4o`0000KoIVIV1?l00003oda<C0Co
00001_lc<c<3o`0001_o6ATI0_l00007oc<c<`;o00001Om<C4`4o`0000KoIVIV0_l0001BogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooicoOgmo0_l00008ofIVIP?o0000
1?m<C4`3o`0000Ko<c<c1Ol0000BoaTI6@Co00001olc<c<2o`0000CoC4a<0ol00008ofIVIP;o0000
E?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonNogmoO`?o00002?mV
IVH3o`0000CoC4a<1?l00007oc<c<a;o00001olc<c<4o`0000CoC4a<0_l00009ofIVIP;o0000E_mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonQogmoO`;o00002OmVIVH3
o`0000GoC4a<1ol0000Boc<c<`Oo00001Om<C4`3o`0000WoIVIV0_l0001HogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooohkoOgmo3?l00009ogmoO`Co00002?mVIVH5o`00
00OoC4a<4_l00007oda<C0Go000000?oIVIVo`000?l000002Ol00004ogmoOa3o0000A_moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon;ogmoO`?o00003?nIVIT7o`0000Ko
Ogmo1ol00006ofIVIPgo00001_m<C4`Co`0000coOgmo0ol0000@oiVIV@;o0000A?moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?oooon9ogmoO`;o00005_nIVIT6o`0000OoOgmo
3Ol00006ofIVIPKo00001_mVIVH7o`0000goOgmo1Ol0000EoiVIV@03o`000?moOgooOgmo047oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooR?moOgl00ol0003oVIVIoiVI
V@0LoiVIV@go00001omoOglBo`0000OoOgmo3Ol0000KoiVIV@03o`000?moOgooOgmo043oOgmo1_oo
ool1o`00007ooooo0008ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKo
oooo00?o0000ooooooooool01?oooon8ogmoO`03o`000?nIVIWoVIVI02WoVIVI8?l0000XoiVIV@03
o`000?moOgooOgmo043oOgmo1_ooool1o`00007ooooo000:ooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00CoooooR?moOgl00ol0003o
VIVIoiVIV@0FoiVIV@go00009_nIVITBo`0001GoVIVI00?o0000ogmoOomoOgl0@OmoOgl6ooooo`7o
00000Oooool000[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Ko
oooo00?o0000ooooooooool01?oooon9ogmoO`03o`000?nIVIWoVIVI01;oVIVI0ol0000=ok>c/bKo
00004_nc/k<2o`0001;oVIVI00?o0000ogmoOomoOgl0@_moOgl6ooooo`7o00000Oooool000[ooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo0ol00004oooooh[o
Ogmo00?o0000oiVIVOnIVIT03onIVIT2o`0004[o/k>c0_l0000@oiVIV@03o`000?moOgooOgmo04;o
Ogmo1?ooool3o`00007ooooo000:ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`000006ooooo`03o`000?oooooooooo00CoooooRomoOgl00ol0003oVIVIoiVIV@0=oiVIV@03
o`000?nc/k?o/k>c00oo/k>c;_l0000?ok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomo
Ogl0@omoOgl6ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooo
oooooooooooo410@00Kooooo00?o0000ooooooooool01?oooon<ogmoO`;o00003?nIVIT00ol0003o
/k>cok>c/`0;ok>c/`Go0000;_o<c<`3o`0000co/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003o
OgmoogmoO`14ogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`04ooooohkoOgmo00?o0000oiVIVOnI
VIT02_nIVIT00ol0003o/k>cok>c/`0:ok>c/`03o`000?o<c<coc<c<01Soc<c<00?o0000olc<c?o<
c<`05oo<c<`00ol0003o/k>cok>c/`09ok>c/`03o`000?nIVIWoVIVI00[oVIVI0_l00017ogmoO`Ko
oooo0Ol00001ooooo`002?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01_ooool00ol0003oooooooooo`04ooooohooOgmo0_l0000;oiVIV@;o00002_nc/k<00ol0003o
c<c<olc<c00Holc<c003o`000?o<c<coc<c<01Koc<c<00?o0000ok>c/onc/k<02Onc/k<00ol0003o
VIVIoiVIV@0:oiVIV@03o`000?moOgooOgmo04OoOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CoooooTOmoOgl00ol0003oVIVIoiVIV@0:oiVIV@;o00002Onc/k<00ol0003oc<c<
olc<c00Folc<c003o`000?oVi^Ko000001Koc<c<00?o0000ok>c/onc/k<02Onc/k<00ol0003oVIVI
oiVIV@09oiVIV@;o0000B_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
oonBogmoO`;o00003?nIVIT00ol0003o/k>cok>c/`06ok>c/`;o00005_o<c<`01?l0003oi^KVonKV
i_l0000Eolc<c003o`000?nc/k?o/k>c00Wo/k>c00?o0000oiVIVOnIVIT02OnIVIT00ol0003oOgmo
ogmoO`1:ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooiCoOgmo00?o
0000oiVIVOnIVIT02_nIVIT2o`0000So/k>c0_l0000Dolc<c005o`000?oVi^Koi^KVonKVi_l00000
4oo<c<`00ol0003o/k>cok>c/`09ok>c/`03o`000?nIVIWoVIVI00SoVIVI0_l0001=ogmoO`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooiGoOgmo0ol0000;oiVIV@03o`000?nc
/k?o/k>c00Oo/k>c00?o0000olc<c?o<c<`04?o<c<`00ol0003oi^KVonKViP02onKViP03o`000?o<
c<coc<c<013oc<c<00?o0000ok>c/onc/k<02?nc/k<2o`0000WoVIVI0_l0001?ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04oooooiSoOgmo0ol00009oiVIV@;o00002?nc/k<5
o`0000coc<c<2?l0000>olc<c0?o00002?nc/k<3o`0000WoVIVI0_l0001AogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04oooooi_oOgmo0ol00008oiVIV@;o00002onc/k<3o`00
01coc<c<0ol00009ok>c/`;o00002OnIVIT3o`0005?oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CoooooW_moOgl3o`0000OoVIVI00?o0000ok>c/onc/k<02onc/k<5o`0001;o
c<c<1Ol00008ok>c/`Co00002?nIVIT3o`0005KoOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CoooooXOmoOgl2o`0000KoVIVI1Ol0000=ok>c/a;o00001onc/k<6o`0000SoVIVI
1?l0001IogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000GoooooXomoOgl3o`0000SoVIVI1_l0
000Iok>c/`Oo00002onIVIT3o`0005goOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CoooooY_moOgl3o`0000_oVIVI6Ol0000=oiVIV@Go0000H?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?oooonYogmoO`_o00007onIVIT7o`0006GoOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00Cooooo]?moOgl7o`0001;oVIVI1_l0001/ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooiWoOgmo2?l0000JogmoOa;o0000
6_moOgl5o`0005?oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooUOmo
Ogl4o`0000SoIVIV3Ol0000/ogmoO`go00001OmVIVH00ol0003oOgmoogmoO`1@ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04oooooiGoOgmo00?o0000ofIVI_mVIVH05_mVIVH=
o`0001;oOgmo3Ol0000CofIVIP;o0000D?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?oooonEogmoO`03o`000?mVIVKoIVIV02?oIVIV4_l0000RofIVIP03o`000?moOgooOgmo
04goOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooU?moOgl00ol0003o
IVIVofIVIP1IofIVIP03o`000?moOgooOgmo04coOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CoooooU?moOgl00ol0003oIVIVofIVIP1IofIVIP;o0000COmoOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?oooonEogmoO`;o0000F?mVIVH00ol0003oOgmoogmo
O`1=ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooiOoOgmo00?o0000
ofIVI_mVIVH0DomVIVH2o`00053oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OoooonHogmo
O`;o0000D_mVIVH00ol0003oOgmoogmoO`1@ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003o
ooooooooo`04oooooi[oOgmo00?o0000ofIVI_mVIVH0C_mVIVH00ol0003oOgmoogmoO`1AogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooi_oOgmo00?o0000ofIVI_mVIVH0
BomVIVH2o`0005CoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooW?mo
Ogl3o`0004SoIVIV0_l0001FogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
oooooiooOgmo0_l00015ofIVIP03o`000?moOgooOgmo05KoOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CoooooXOmoOgl2o`0004;oIVIV00?o0000ogmoOomoOgl0EomoOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonSogmoO`?o0000?OmVIVH2o`0005[o
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooY_moOgl3o`0003SoIVIV
0_l0001LogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooojWoOgmo1Ol0
000bofIVIP03o`000?moOgooOgmo05coOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00Cooooo[_moOgl4o`0002?oIVIV1_l00003ofIVIP;o0000GomoOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?oooonbogmoOb?o00001_moOgl3o`00067oOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo0_l0
0005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool01?oooooo
ogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo
@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[o
oooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool0
1?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooooomo
Ogm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
ooooOgmo@?moOgl6ooooo`7o00000Oooool000Oooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000Oo
oooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool0
0ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000Sooooo00?oV9RHob4Q
8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool01?oooooo
ogmoOd3oOgmo1_ooool1o`00007ooooo0009ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooo
ooooooooooooo`000006ooooo`?o00001?ooooooogmoOd3oOgmo1?ooool3o`00007ooooo000:oooo
o`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
oooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002oooool01Ol0003ooooooooooooooooo
410@00?ooooo00?o410@ooooooooool01?ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6
ooooo`7o00000Oooool000Oooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Ooo
ool000Oooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
ooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3o
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Joooo
o`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo
@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooo
ogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo
000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
ooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3o
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooooomo
Ogm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00
007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooo
ogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo
@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_oo
ool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007ooooo000Joooo
o`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooooomo
Ogm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo0007ooooo`05oiRHV?l@413o
0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0
1?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo0007ooooo`05oa0@4?nj^[[oooooogMgMolb<S80
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3o
Ogmo1_ooool1o`00007ooooo000;ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413o
ooooooooo`04ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`00
2_ooool00onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool3o`0000Co
oooooomoOgm0ogmoO`Cooooo0ol00001ooooo`002Oooool00ol@413o0000okZj^P03ooooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool000[ooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@00Ko
oooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo0007ooooo`05oa0@
4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000oooo
ooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo0007ooooo`05ojVYZOl@413o0000oa0@
4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool01?oooooo
ogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo
0_l00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooooomo
Ogm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000GooooooomoOgm0ogmo
O`Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo
@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000Gooooooomo
Ogm0ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
ooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3o
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000Go
oooooomoOgm0ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo
@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooo
ogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmo
O`Kooooo0Ol00001ooooo`002Oooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb
<S;ok^k^00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000:
ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`001oooool5o`0000?ooooo00Go410@
oooooooooooooooooa0@4006ooooo`?o00001?ooooooogmoOd3oOgmo1?ooool3o`00007ooooo0007
ooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo0?ooooooB_ooool1o`00007ooooo0007ooooo`04omgMgOmEEEGoooooo`0000Cooooo
00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?ooooooB_ooool1o`00007o
oooo0008ooooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooooooooa0@4006ooooo`03
o`000?oooooooooo0?ooooooB_ooool1o`00007ooooo0008ooooo`03onk^k_m4A4Co000000Cooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?ooooooB_ooool1o`00007o
oooo0009ooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0mooooo`03
o`000?oooooooooo03gooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Sooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`7o0000
0Oooool001[oooooool0001>o`00007ooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-30.1723, -14.304, 0.195672, \
0.195672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0192308 0.211538 0.0192308 [
[.11538 -0.0125 -9 -9 ]
[.11538 -0.0125 9 0 ]
[.30769 -0.0125 -9 -9 ]
[.30769 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69231 -0.0125 -6 -9 ]
[.69231 -0.0125 6 0 ]
[.88462 -0.0125 -6 -9 ]
[.88462 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -18 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .21154 -6 -4.5 ]
[-0.0125 .21154 0 4.5 ]
[-0.0125 .40385 -12 -4.5 ]
[-0.0125 .40385 0 4.5 ]
[-0.0125 .59615 -12 -4.5 ]
[-0.0125 .59615 0 4.5 ]
[-0.0125 .78846 -12 -4.5 ]
[-0.0125 .78846 0 4.5 ]
[-0.0125 .98077 -12 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11538 0 m
.11538 .00625 L
s
[(-20)] .11538 -0.0125 0 1 Mshowa
.30769 0 m
.30769 .00625 L
s
[(-10)] .30769 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69231 0 m
.69231 .00625 L
s
[(10)] .69231 -0.0125 0 1 Mshowa
.88462 0 m
.88462 .00625 L
s
[(20)] .88462 -0.0125 0 1 Mshowa
.125 Mabswid
.15385 0 m
.15385 .00375 L
s
.19231 0 m
.19231 .00375 L
s
.23077 0 m
.23077 .00375 L
s
.26923 0 m
.26923 .00375 L
s
.34615 0 m
.34615 .00375 L
s
.38462 0 m
.38462 .00375 L
s
.42308 0 m
.42308 .00375 L
s
.46154 0 m
.46154 .00375 L
s
.53846 0 m
.53846 .00375 L
s
.57692 0 m
.57692 .00375 L
s
.61538 0 m
.61538 .00375 L
s
.65385 0 m
.65385 .00375 L
s
.73077 0 m
.73077 .00375 L
s
.76923 0 m
.76923 .00375 L
s
.80769 0 m
.80769 .00375 L
s
.84615 0 m
.84615 .00375 L
s
.07692 0 m
.07692 .00375 L
s
.03846 0 m
.03846 .00375 L
s
.92308 0 m
.92308 .00375 L
s
.96154 0 m
.96154 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(-10)] -0.0125 .01923 1 0 Mshowa
0 .21154 m
.00625 .21154 L
s
[(0)] -0.0125 .21154 1 0 Mshowa
0 .40385 m
.00625 .40385 L
s
[(10)] -0.0125 .40385 1 0 Mshowa
0 .59615 m
.00625 .59615 L
s
[(20)] -0.0125 .59615 1 0 Mshowa
0 .78846 m
.00625 .78846 L
s
[(30)] -0.0125 .78846 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(40)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .05769 m
.00375 .05769 L
s
0 .09615 m
.00375 .09615 L
s
0 .13462 m
.00375 .13462 L
s
0 .17308 m
.00375 .17308 L
s
0 .25 m
.00375 .25 L
s
0 .28846 m
.00375 .28846 L
s
0 .32692 m
.00375 .32692 L
s
0 .36538 m
.00375 .36538 L
s
0 .44231 m
.00375 .44231 L
s
0 .48077 m
.00375 .48077 L
s
0 .51923 m
.00375 .51923 L
s
0 .55769 m
.00375 .55769 L
s
0 .63462 m
.00375 .63462 L
s
0 .67308 m
.00375 .67308 L
s
0 .71154 m
.00375 .71154 L
s
0 .75 m
.00375 .75 L
s
0 .82692 m
.00375 .82692 L
s
0 .86538 m
.00375 .86538 L
s
0 .90385 m
.00375 .90385 L
s
0 .94231 m
.00375 .94231 L
s
.25 Mabswid
0 0 m
0 1 L
s
.11538 .99375 m
.11538 1 L
s
.30769 .99375 m
.30769 1 L
s
.5 .99375 m
.5 1 L
s
.69231 .99375 m
.69231 1 L
s
.88462 .99375 m
.88462 1 L
s
.125 Mabswid
.15385 .99625 m
.15385 1 L
s
.19231 .99625 m
.19231 1 L
s
.23077 .99625 m
.23077 1 L
s
.26923 .99625 m
.26923 1 L
s
.34615 .99625 m
.34615 1 L
s
.38462 .99625 m
.38462 1 L
s
.42308 .99625 m
.42308 1 L
s
.46154 .99625 m
.46154 1 L
s
.53846 .99625 m
.53846 1 L
s
.57692 .99625 m
.57692 1 L
s
.61538 .99625 m
.61538 1 L
s
.65385 .99625 m
.65385 1 L
s
.73077 .99625 m
.73077 1 L
s
.76923 .99625 m
.76923 1 L
s
.80769 .99625 m
.80769 1 L
s
.84615 .99625 m
.84615 1 L
s
.07692 .99625 m
.07692 1 L
s
.03846 .99625 m
.03846 1 L
s
.92308 .99625 m
.92308 1 L
s
.96154 .99625 m
.96154 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .21154 m
1 .21154 L
s
.99375 .40385 m
1 .40385 L
s
.99375 .59615 m
1 .59615 L
s
.99375 .78846 m
1 .78846 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .05769 m
1 .05769 L
s
.99625 .09615 m
1 .09615 L
s
.99625 .13462 m
1 .13462 L
s
.99625 .17308 m
1 .17308 L
s
.99625 .25 m
1 .25 L
s
.99625 .28846 m
1 .28846 L
s
.99625 .32692 m
1 .32692 L
s
.99625 .36538 m
1 .36538 L
s
.99625 .44231 m
1 .44231 L
s
.99625 .48077 m
1 .48077 L
s
.99625 .51923 m
1 .51923 L
s
.99625 .55769 m
1 .55769 L
s
.99625 .63462 m
1 .63462 L
s
.99625 .67308 m
1 .67308 L
s
.99625 .71154 m
1 .71154 L
s
.99625 .75 m
1 .75 L
s
.99625 .82692 m
1 .82692 L
s
.99625 .86538 m
1 .86538 L
s
.99625 .90385 m
1 .90385 L
s
.99625 .94231 m
1 .94231 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.4 g
.45094 .35539 m
.47057 .35455 L
.49019 .35631 L
.50981 .35869 L
.52943 .35784 L
.54906 .3635 L
.56868 .36747 L
.5883 .37044 L
.60793 .37205 L
.62755 .37182 L
.64717 .36983 L
.6668 .36661 L
.68642 .36237 L
.70604 .35579 L
.72567 .3581 L
.74529 .35579 L
.76491 .35437 L
.78454 .35681 L
.79001 .37245 L
.78454 .37839 L
.76511 .39207 L
.76491 .39223 L
.74529 .40863 L
.72567 .40752 L
.71043 .4117 L
.70604 .41286 L
.68642 .41425 L
.6668 .41845 L
.64717 .42139 L
.62755 .42295 L
.60793 .42312 L
.5883 .42189 L
.56868 .41928 L
.54906 .41534 L
.52943 .41397 L
.52034 .4117 L
.50981 .4089 L
.49019 .40265 L
.47057 .39538 L
.46616 .39207 L
.45094 .38227 L
.44073 .37245 L
F
0 g
.45094 .35539 m
.47057 .35455 L
.49019 .35631 L
.50981 .35869 L
.52943 .35784 L
.54906 .3635 L
.56868 .36747 L
.5883 .37044 L
.60793 .37205 L
.62755 .37182 L
.64717 .36983 L
.6668 .36661 L
.68642 .36237 L
.70604 .35579 L
.72567 .3581 L
.74529 .35579 L
.76491 .35437 L
.78454 .35681 L
.79001 .37245 L
.78454 .37839 L
.76511 .39207 L
.76491 .39223 L
.74529 .40863 L
.72567 .40752 L
.71043 .4117 L
.70604 .41286 L
.68642 .41425 L
.6668 .41845 L
.64717 .42139 L
.62755 .42295 L
.60793 .42312 L
.5883 .42189 L
.56868 .41928 L
.54906 .41534 L
.52943 .41397 L
.52034 .4117 L
.50981 .4089 L
.49019 .40265 L
.47057 .39538 L
.46616 .39207 L
.45094 .38227 L
.44073 .37245 L
.45094 .35539 L
s
.6 g
.45094 .41313 m
.47057 .41333 L
.49019 .41592 L
.50981 .41892 L
.52943 .4217 L
.54906 .42042 L
.56868 .4243 L
.5883 .42642 L
.60793 .42733 L
.62755 .42721 L
.64717 .42603 L
.6668 .42356 L
.68642 .41906 L
.70604 .42107 L
.72567 .4182 L
.74529 .41523 L
.76491 .41292 L
.78454 .4143 L
.78812 .43132 L
.78454 .4355 L
.76491 .45044 L
.76409 .45094 L
.74529 .46381 L
.72567 .46837 L
.71878 .47057 L
.70604 .47083 L
.68642 .47639 L
.6668 .48111 L
.64717 .48418 L
.62755 .48572 L
.60793 .48588 L
.5883 .48468 L
.56868 .482 L
.54906 .47766 L
.52943 .47206 L
.51189 .47057 L
.50981 .46992 L
.49019 .46768 L
.47057 .45332 L
.46695 .45094 L
.45094 .43979 L
.44269 .43132 L
F
0 g
.45094 .41313 m
.47057 .41333 L
.49019 .41592 L
.50981 .41892 L
.52943 .4217 L
.54906 .42042 L
.56868 .4243 L
.5883 .42642 L
.60793 .42733 L
.62755 .42721 L
.64717 .42603 L
.6668 .42356 L
.68642 .41906 L
.70604 .42107 L
.72567 .4182 L
.74529 .41523 L
.76491 .41292 L
.78454 .4143 L
.78812 .43132 L
.78454 .4355 L
.76491 .45044 L
.76409 .45094 L
.74529 .46381 L
.72567 .46837 L
.71878 .47057 L
.70604 .47083 L
.68642 .47639 L
.6668 .48111 L
.64717 .48418 L
.62755 .48572 L
.60793 .48588 L
.5883 .48468 L
.56868 .482 L
.54906 .47766 L
.52943 .47206 L
.51189 .47057 L
.50981 .46992 L
.49019 .46768 L
.47057 .45332 L
.46695 .45094 L
.45094 .43979 L
.44269 .43132 L
.45094 .41313 L
s
.6 g
.47057 .30806 m
.49019 .30584 L
.50981 .30771 L
.52943 .30743 L
.54906 .30885 L
.56868 .31014 L
.5883 .31108 L
.60793 .31154 L
.62755 .31147 L
.64717 .31089 L
.6668 .30986 L
.68642 .30852 L
.70604 .3071 L
.72567 .30575 L
.74529 .30602 L
.76491 .30964 L
.77066 .31358 L
.76491 .32789 L
.75886 .3332 L
.74529 .33979 L
.72567 .347 L
.70604 .35271 L
.7056 .35283 L
.68642 .35719 L
.6668 .36231 L
.64717 .36685 L
.62755 .36989 L
.60793 .37025 L
.5883 .36776 L
.56868 .36347 L
.54906 .35843 L
.52943 .35356 L
.52533 .35283 L
.50981 .34849 L
.49019 .34169 L
.47173 .3332 L
.47057 .3323 L
.46008 .31358 L
F
0 g
.47057 .30806 m
.49019 .30584 L
.50981 .30771 L
.52943 .30743 L
.54906 .30885 L
.56868 .31014 L
.5883 .31108 L
.60793 .31154 L
.62755 .31147 L
.64717 .31089 L
.6668 .30986 L
.68642 .30852 L
.70604 .3071 L
.72567 .30575 L
.74529 .30602 L
.76491 .30964 L
.77066 .31358 L
.76491 .32789 L
.75886 .3332 L
.74529 .33979 L
.72567 .347 L
.70604 .35271 L
.7056 .35283 L
.68642 .35719 L
.6668 .36231 L
.64717 .36685 L
.62755 .36989 L
.60793 .37025 L
.5883 .36776 L
.56868 .36347 L
.54906 .35843 L
.52943 .35356 L
.52533 .35283 L
.50981 .34849 L
.49019 .34169 L
.47173 .3332 L
.47057 .3323 L
.46008 .31358 L
.47057 .30806 L
s
.3 g
.50981 .36883 m
.52943 .36511 L
.54906 .36845 L
.56868 .37044 L
.5883 .3717 L
.60793 .37225 L
.62755 .37218 L
.64717 .37146 L
.6668 .37004 L
.68642 .36783 L
.70604 .36375 L
.72567 .36929 L
.73909 .37245 L
.733 .39207 L
.72567 .3963 L
.70604 .40449 L
.68642 .41033 L
.68085 .4117 L
.6668 .4141 L
.64717 .41714 L
.62755 .41893 L
.60793 .41913 L
.5883 .4177 L
.56868 .41491 L
.54997 .4117 L
.54906 .41148 L
.52943 .40606 L
.50981 .39857 L
.49775 .39207 L
.49182 .37245 L
F
0 g
.50981 .36883 m
.52943 .36511 L
.54906 .36845 L
.56868 .37044 L
.5883 .3717 L
.60793 .37225 L
.62755 .37218 L
.64717 .37146 L
.6668 .37004 L
.68642 .36783 L
.70604 .36375 L
.72567 .36929 L
.73909 .37245 L
.733 .39207 L
.72567 .3963 L
.70604 .40449 L
.68642 .41033 L
.68085 .4117 L
.6668 .4141 L
.64717 .41714 L
.62755 .41893 L
.60793 .41913 L
.5883 .4177 L
.56868 .41491 L
.54997 .4117 L
.54906 .41148 L
.52943 .40606 L
.50981 .39857 L
.49775 .39207 L
.49182 .37245 L
.50981 .36883 L
s
.4 g
.50981 .4933 m
.52943 .49437 L
.54906 .49611 L
.56868 .49768 L
.5883 .49878 L
.60793 .49932 L
.62755 .49924 L
.64717 .49857 L
.6668 .49734 L
.68642 .49569 L
.70604 .494 L
.72567 .4934 L
.73193 .50981 L
.72567 .51439 L
.70604 .52417 L
.69103 .52943 L
.68642 .53091 L
.6668 .53699 L
.64717 .54219 L
.62755 .54567 L
.60793 .5461 L
.5883 .54323 L
.56868 .53835 L
.54906 .53241 L
.53971 .52943 L
.52943 .52597 L
.50981 .5172 L
.49883 .50981 L
F
0 g
.50981 .4933 m
.52943 .49437 L
.54906 .49611 L
.56868 .49768 L
.5883 .49878 L
.60793 .49932 L
.62755 .49924 L
.64717 .49857 L
.6668 .49734 L
.68642 .49569 L
.70604 .494 L
.72567 .4934 L
.73193 .50981 L
.72567 .51439 L
.70604 .52417 L
.69103 .52943 L
.68642 .53091 L
.6668 .53699 L
.64717 .54219 L
.62755 .54567 L
.60793 .5461 L
.5883 .54323 L
.56868 .53835 L
.54906 .53241 L
.53971 .52943 L
.52943 .52597 L
.50981 .5172 L
.49883 .50981 L
.50981 .4933 L
s
.4 g
.50981 .26821 m
.52943 .26471 L
.54906 .26374 L
.56868 .26356 L
.5883 .26363 L
.60793 .26071 L
.62755 .26025 L
.64717 .26361 L
.6668 .26357 L
.68642 .26387 L
.70604 .2652 L
.72567 .27023 L
.73004 .27433 L
.72567 .28086 L
.70604 .29241 L
.702 .29396 L
.68642 .29738 L
.6668 .30049 L
.64717 .30255 L
.62755 .30363 L
.60793 .30374 L
.5883 .30289 L
.56868 .30108 L
.54906 .29823 L
.52943 .29413 L
.52876 .29396 L
.50981 .2846 L
.50073 .27433 L
F
0 g
.50981 .26821 m
.52943 .26471 L
.54906 .26374 L
.56868 .26356 L
.5883 .26363 L
.60793 .26071 L
.62755 .26025 L
.64717 .26361 L
.6668 .26357 L
.68642 .26387 L
.70604 .2652 L
.72567 .27023 L
.73004 .27433 L
.72567 .28086 L
.70604 .29241 L
.702 .29396 L
.68642 .29738 L
.6668 .30049 L
.64717 .30255 L
.62755 .30363 L
.60793 .30374 L
.5883 .30289 L
.56868 .30108 L
.54906 .29823 L
.52943 .29413 L
.52876 .29396 L
.50981 .2846 L
.50073 .27433 L
.50981 .26821 L
s
.7 g
.52943 .43063 m
.54906 .43078 L
.55685 .43132 L
.56868 .43186 L
.5883 .43261 L
.60793 .433 L
.62755 .43294 L
.64717 .43246 L
.6668 .43165 L
.67394 .43132 L
.68642 .43044 L
.70604 .43069 L
.71665 .43132 L
.72216 .45094 L
.70604 .45986 L
.68642 .467 L
.67313 .47057 L
.6668 .47179 L
.64717 .47511 L
.62755 .47705 L
.60793 .47726 L
.5883 .47572 L
.56868 .47268 L
.55757 .47057 L
.54906 .46835 L
.52943 .46183 L
.50981 .45179 L
.50862 .45094 L
.50981 .43212 L
.51406 .43132 L
F
0 g
.52943 .43063 m
.54906 .43078 L
.55685 .43132 L
.56868 .43186 L
.5883 .43261 L
.60793 .433 L
.62755 .43294 L
.64717 .43246 L
.6668 .43165 L
.67394 .43132 L
.68642 .43044 L
.70604 .43069 L
.71665 .43132 L
.72216 .45094 L
.70604 .45986 L
.68642 .467 L
.67313 .47057 L
.6668 .47179 L
.64717 .47511 L
.62755 .47705 L
.60793 .47726 L
.5883 .47572 L
.56868 .47268 L
.55757 .47057 L
.54906 .46835 L
.52943 .46183 L
.50981 .45179 L
.50862 .45094 L
.50981 .43212 L
.51406 .43132 L
.52943 .43063 L
s
.7 g
.52943 .32036 m
.54906 .31856 L
.56868 .31814 L
.5883 .31813 L
.60793 .31819 L
.62755 .31818 L
.64717 .31812 L
.6668 .31819 L
.68642 .3188 L
.70604 .3213 L
.71899 .3332 L
.70604 .34136 L
.68642 .34895 L
.67193 .35283 L
.6668 .35441 L
.64717 .36004 L
.62755 .36384 L
.60793 .3643 L
.5883 .36118 L
.56868 .35585 L
.55876 .35283 L
.54906 .35034 L
.52943 .3435 L
.51177 .3332 L
F
0 g
.52943 .32036 m
.54906 .31856 L
.56868 .31814 L
.5883 .31813 L
.60793 .31819 L
.62755 .31818 L
.64717 .31812 L
.6668 .31819 L
.68642 .3188 L
.70604 .3213 L
.71899 .3332 L
.70604 .34136 L
.68642 .34895 L
.67193 .35283 L
.6668 .35441 L
.64717 .36004 L
.62755 .36384 L
.60793 .3643 L
.5883 .36118 L
.56868 .35585 L
.55876 .35283 L
.54906 .35034 L
.52943 .3435 L
.51177 .3332 L
.52943 .32036 L
s
.2 g
.52943 .37915 m
.54906 .37604 L
.56868 .37542 L
.5883 .3754 L
.60793 .37546 L
.62755 .37545 L
.64717 .37539 L
.6668 .37548 L
.68642 .37641 L
.70604 .38138 L
.70764 .39207 L
.70604 .39321 L
.68642 .40252 L
.6668 .40817 L
.64726 .4117 L
.64717 .41171 L
.62755 .41379 L
.60793 .41402 L
.5883 .41236 L
.5827 .4117 L
.56868 .40919 L
.54906 .40411 L
.52943 .39604 L
.52313 .39207 L
F
0 g
.52943 .37915 m
.54906 .37604 L
.56868 .37542 L
.5883 .3754 L
.60793 .37546 L
.62755 .37545 L
.64717 .37539 L
.6668 .37548 L
.68642 .37641 L
.70604 .38138 L
.70764 .39207 L
.70604 .39321 L
.68642 .40252 L
.6668 .40817 L
.64726 .4117 L
.64717 .41171 L
.62755 .41379 L
.60793 .41402 L
.5883 .41236 L
.5827 .4117 L
.56868 .40919 L
.54906 .40411 L
.52943 .39604 L
.52313 .39207 L
.52943 .37915 L
s
.8 g
.54906 .44744 m
.56868 .44177 L
.5883 .44078 L
.60793 .44054 L
.62755 .44056 L
.64717 .44091 L
.6668 .4423 L
.68277 .45094 L
.6668 .45931 L
.64717 .46435 L
.62755 .46673 L
.60793 .46698 L
.5883 .46513 L
.56868 .46083 L
.54906 .45177 L
.54813 .45094 L
F
0 g
.54906 .44744 m
.56868 .44177 L
.5883 .44078 L
.60793 .44054 L
.62755 .44056 L
.64717 .44091 L
.6668 .4423 L
.68277 .45094 L
.6668 .45931 L
.64717 .46435 L
.62755 .46673 L
.60793 .46698 L
.5883 .46513 L
.56868 .46083 L
.54906 .45177 L
.54813 .45094 L
.54906 .44744 L
s
.8 g
.54906 .33257 m
.56868 .32708 L
.5883 .32555 L
.60793 .32506 L
.62755 .32512 L
.64717 .32579 L
.6668 .32776 L
.68261 .3332 L
.6668 .34444 L
.64717 .34968 L
.62755 .35205 L
.60793 .35229 L
.5883 .35047 L
.56868 .34605 L
.54906 .33523 L
.54827 .3332 L
F
0 g
.54906 .33257 m
.56868 .32708 L
.5883 .32555 L
.60793 .32506 L
.62755 .32512 L
.64717 .32579 L
.6668 .32776 L
.68261 .3332 L
.6668 .34444 L
.64717 .34968 L
.62755 .35205 L
.60793 .35229 L
.5883 .35047 L
.56868 .34605 L
.54906 .33523 L
.54827 .3332 L
.54906 .33257 L
s
.1 g
.56868 .38304 m
.5883 .38151 L
.60793 .38106 L
.62755 .38111 L
.64717 .38174 L
.6668 .38378 L
.68148 .39207 L
.6668 .39986 L
.64717 .40499 L
.62755 .40739 L
.60793 .40764 L
.5883 .40578 L
.56868 .40142 L
.54942 .39207 L
F
0 g
.56868 .38304 m
.5883 .38151 L
.60793 .38106 L
.62755 .38111 L
.64717 .38174 L
.6668 .38378 L
.68148 .39207 L
.6668 .39986 L
.64717 .40499 L
.62755 .40739 L
.60793 .40764 L
.5883 .40578 L
.56868 .40142 L
.54942 .39207 L
.56868 .38304 L
s
.5883 .39183 m
.60793 .38903 L
.62755 .3893 L
.64309 .39207 L
.62755 .39797 L
.60793 .39848 L
.5883 .39309 L
.58753 .39207 L
F
.5883 .39183 m
.60793 .38903 L
.62755 .3893 L
.64309 .39207 L
.62755 .39797 L
.60793 .39848 L
.5883 .39309 L
.58753 .39207 L
.5883 .39183 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00?Oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0dooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kS?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0hooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8b
onk^kS?ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08_ooool003gooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0=_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0<oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg03?ooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL08_ooool003Gooooo1_l0
0003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400[ooooo`Ko0000
1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100<oooool01Ol@413o
oooooooooooooooo410@03[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@03Cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@02;ooooo000o
ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000fooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000cooooo`05o`000?ooooooooooooooool0
0000>_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000=Oooool00onH
V9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000008_ooool0043ooooo00?oMgMgofIV
I_ooool00_ooool01Ol0003ooooooooooooooooo000003Kooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000003?ooooo00Go0000ooooooooooooooooo`00000jooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`03ogMgMomVIVKooooo00;o
oooo00Go0000ooooooooooooooooo`00000Rooooo`00@Oooool01Ol0003ooooooooooooooooo410@
00?ooooo00?o410@ooooooooool0=?ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@4100<oooool01Ol@413ooooooooooooooooo410@03[ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@03Oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo023ooooo000mooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg03Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg03?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0jooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0cooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02;ooooo000mooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^03Cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^03?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`03oeEEEOmVIVKo000000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0cooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02;ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo000Joooooooo0000C_l00001ooooo`00
6_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0?Ooo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool08ooo
ool1o`00007ooooo0008ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKo
oooo00?o0000ooooooooool0oooooom:ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooom:ooooo`7o
00000Oooool000Go00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41001_ooool00ol0003oooooooooo`3ooooood[ooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?ooooooB?ooool3o`00007o
oooo000:ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo0008ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Oooooooogmo
Od3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Ooo
ooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000oooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`003ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000?ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000oooooo00Go0000oooooooooooooooo
o`000006ooooo`?o00001?ooooooogmoOd3oOgmo1?ooool3o`00007ooooo000?ooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool000oooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`003oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000?ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo`?moOgl>
o`00077oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo[OmoOglCo`00
00koIVIV5?l0001MogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooojKo
Ogmo1ol0000eofIVIPKo0000EomoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?oooonRogmoO`Co0000@_mVIVH3o`0005CoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CoooooX?moOgl2o`0004WoIVIV00?o0000ogmoOomoOgl0DOmoOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?oooonOogmoO`;o0000BomVIVH00ol0003oOgmoogmoO`1@
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooj7oOgmo00?o0000ofIV
I_mVIVH0AomVIVH00ol0003oOgmoogmoO`1AogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04oooooj;oOgmo00?o0000ofIVI_mVIVH0A?mVIVH2o`0005CoOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CoooooXomoOgl2o`0004?oIVIV00?o0000ogmoOomoOgl0
E?moOgl6ooooo`7o00000Oooool001[ooooo0_l00005ooooojGoOgmo0_l0000oofIVIP;o0000Eomo
Ogl5ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool01?oooonWogmoO`;o0000??mVIVH0
0ol0003oOgmoogmoO`1GogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
ojWoOgmo0ol0000dofIVIPGo0000F_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?oooon/ogmoO`?o0000:omVIVH6o`0005ooOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00Cooooo[omoOgl5o`00023oIVIV1_l0001UogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04oooookCoOgmo3Ol00006ofIVIPgo0000JomoOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?oooonIogmoO`So00008?moOgl6o`00023oOgmo3_l0001:
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooiCoOgmo1Ol00008oiVI
VA?o00009_moOgl=o`0000koVIVI0ol00017ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04oooooi?oOgmo00?o0000oiVIVOnIVIT07_nIVITVo`0001koVIVI00?o0000ogmoOomo
Ogl0A?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonBogmoO`03o`00
0?nIVIWoVIVI06CoVIVI00?o0000ogmoOomoOgl0@omoOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?oooonBogmoO`03o`000?nIVIWoVIVI01SoVIVI;_l0000NoiVIV@03o`000?mo
OgooOgmo04?oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooTomoOgl0
0ol0003oVIVIoiVIV@0BoiVIV@Go0000;_nc/k<:o`0001?oVIVI00?o0000ogmoOomoOgl0A?moOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonCogmoO`03o`000?nIVIWoVIVI
017oVIVI00?o0000ok>c/onc/k<0>onc/k<00ol0003oVIVIoiVIV@0@oiVIV@03o`000?moOgooOgmo
04CoOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OoooonDogmoO`03o`000?nIVIWoVIVI00ko
VIVI0_l0000>ok>c/bCo00003Onc/k<00ol0003oVIVIoiVIV@0?oiVIV@03o`000?moOgooOgmo04Co
Ogmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooU?moOgl00ol0003oVIVI
oiVIV@0=oiVIV@03o`000?nc/k?o/k>c00_o/k>c0ol0000Tolc<c0?o00002onc/k<00ol0003oVIVI
oiVIV@0<oiVIV@;o0000AomoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
oonEogmoO`?o00002onIVIT2o`0000[o/k>c0ol0000Yolc<c0;o00002_nc/k<2o`0000_oVIVI0_l0
0019ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooiSoOgmo0_l0000;
oiVIV@03o`000?nc/k?o/k>c00So/k>c0_l0000Xolc<c003o`000?nc/k?o/k>c00Wo/k>c00?o0000
oiVIVOnIVIT02OnIVIT2o`0004_oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CoooooV_moOgl2o`0000[oVIVI0_l0000:ok>c/`03o`000?o<c<coc<c<02Coc<c<00?o0000ok>c
/onc/k<02Onc/k<00ol0003oVIVIoiVIV@08oiVIV@;o0000COmoOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?oooonLogmoO`?o00002OnIVIT00ol0003o/k>cok>c/`08ok>c/`;o
00008oo<c<`00ol0003o/k>cok>c/`08ok>c/`;o00002?nIVIT3o`0004ooOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CoooooWomoOgl3o`0000OoVIVI0ol00009ok>c/`03o`00
0?o<c<coc<c<01goc<c<0ol00008ok>c/`?o00002?nIVIT2o`0005;oOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CoooooX_moOgl3o`0000OoVIVI0ol00007ok>c/`Go00005oo<
c<`3o`0000Wo/k>c0_l00009oiVIV@;o0000E?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?oooonUogmoO`?o00001onIVIT4o`0000So/k>c1_l0000<olc<c0Go00002Onc/k<3
o`0000SoVIVI0ol0001FogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
oi;oOgmo2?l0000>ogmoO`Co00001onIVIT3o`0000_o/k>c3?l00008ok>c/`Ko00001_nIVIT5o`00
00koOgmo2?l00013ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooohoo
Ogmo0ol00008ofIVIPOo00001OmoOgl9o`0000OoVIVI0ol0000Iok>c/`?o00001onIVIT5o`000003
ogmoOol0003o000000Co00001_moOgl6o`0000SoIVIV0ol00010ogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooohooOgmo00?o0000ofIVI_mVIVH03omVIVH5o`0000KoIVIV
2?l00005oiVIV@?o00004Onc/k<5o`0000OoVIVI0ol00003ogmoO`?o00001_mVIVH6o`00013oIVIV
00?o0000ogmoOomoOgl0?_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
oon>ogmoO`03o`000?mVIVKoIVIV01koIVIV1?l000000omoOgoo0000o`000003o`0000?oVIVI1Ol0
0006ok>c/`Ko00001onIVIT5o`000003ogmoOol0003o000000?o00000omVIVH5o`0001SoIVIV00?o
0000ogmoOomoOgl0?OmoOgl6ooooo`7o00000Oooool001[ooooo0_l00005ooooohgoOgmo00?o0000
ofIVI_mVIVH05_mVIVH8o`0000GoIVIV0ol00003ogmoO`?o00001OnIVIT6o`0000KoVIVI3Ol00005
ofIVIP?o00001Om<C4`3o`0001GoIVIV00?o0000ogmoOomoOgl0?OmoOgl5ooooo`;o00000Oooool0
01[ooooo00?o0000ooooooooool01?oooon=ogmoO`03o`000?mVIVKoIVIV013oIVIV1_l00008oda<
C0Ko00000_mVIVH5o`000003ogmoOol0003o000000?o00001_nIVIT=o`0000KoIVIV1Ol0000;oda<
C0Co00004OmVIVH00ol0003oOgmoogmoO`0mogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooohcoOgmo00?o0000ofIVI_mVIVH03_mVIVH3o`0001CoC4a<9_l0000Doda<C0;o
00004?mVIVH00ol0003oOgmoogmoO`0logmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooohcoOgmo00?o0000ofIVI_mVIVH03_mVIVH00ol0003oC4a<oda<C00Coda<C2So0000
5?m<C4`00ol0003oIVIVofIVIP0=ofIVIP03o`000?moOgooOgmo03goOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CoooooSOmoOgl00ol0003oIVIVofIVIP0=ofIVIP03o`000?m<
C4coC4a<00goC4a<1_l0000Xoc<c<`Oo00003Om<C4`00ol0003oIVIVofIVIP0;ofIVIP;o0000@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon>ogmoO`03o`000?mVIVKo
IVIV00goIVIV00?o0000oda<C?m<C4`02?m<C4`4o`0000go<c<c6ol0000=oc<c<`?o00002Om<C4`0
0ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo043oOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CoooooSomoOgl2o`0000goIVIV00?o0000oda<C?m<C4`02?m<C4`00ol0
003o<c<coc<c<`09oc<c<`Go00006olI6AT4o`0000_o<c<c00?o0000oda<C?m<C4`01om<C4`00ol0
003oIVIVofIVIP09ofIVIP;o0000@omoOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?oooonAogmoO`;o00002omVIVH00ol0003oC4a<oda<C007oda<C003o`000?lc<c?o<c<c00So
<c<c0_l0000ToaTI6@;o00002Olc<c<00ol0003oC4a<oda<C007oda<C003o`000?mVIVKoIVIV00So
IVIV00?o0000ogmoOomoOgl0@omoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?oooonCogmoO`03o`000?mVIVKoIVIV00WoIVIV00?o0000oda<C?m<C4`01_m<C4`00ol0003o<c<c
oc<c<`06oc<c<`;o00003OlI6AT>o`0000go6ATI00?o0000oc<c<olc<c<01_lc<c<00ol0003oC4a<
oda<C006oda<C003o`000?mVIVKoIVIV00SoIVIV00?o0000ogmoOomoOgl0A?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?oooonDogmoO`03o`000?mVIVKoIVIV00SoIVIV0_l0
0006oda<C0;o00001olc<c<2o`0000[o6ATI5?l0000;oaTI6@;o00001_lc<c<2o`0000OoC4a<0_l0
0008ofIVIP;o0000AomoOgl6ooooo`7o00000Oooool000Sooooo1?l000002?l@413oooooooooooo^
k^ko<S8bo`000?lb<S;ok^k^1_ooool00ol0003oooooooooo`04oooooiGoOgmo0ol00009ofIVIP;o
00001_m<C4`2o`0000Oo<c<c0_l0000<oaTI6@ko00002_lI6AT3o`0000Go<c<c0ol00006oda<C0?o
00002OmVIVH00ol0003oOgmoogmoO`17ogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`04oooooiSo
Ogmo0ol00008ofIVIP?o00001Om<C4`3o`0000Ko<c<c0_l0000=oaTI6@So00002_lI6AT3o`0000Ko
<c<c0_l00007oda<C0;o00002omVIVH00ol0003oOgmoogmoO`18ogmoO`Kooooo0Ol00001ooooo`00
2_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003o
ooooooooo`04oooooi_oOgmo1?l00007ofIVIP?o00001Om<C4`2o`0000Ko<c<c1Ol0000GoaTI6@?o
00001olc<c<2o`0000OoC4a<0_l0000<ofIVIP03o`000?moOgooOgmo04WoOgmo1_ooool1o`00007o
oooo000:ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`?o
00001?oooonOogmoO`?o00001omVIVH3o`0000CoC4a<0ol00008oc<c<`Ko00003?lI6AT5o`0000Oo
<c<c0ol00006oda<C0?o00003OmVIVH00ol0003oOgmoogmoO`1:ogmoO`Cooooo0ol00001ooooo`00
2_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`04oooooj;oOgmo1?l00006ofIVIP?o00001?m<C4`3o`0000_o<c<c3?l00007oc<c<`Go
00001_m<C4`3o`0000KoIVIV2_l0001=ogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`04ooooojKo
Ogmo0ol00006ofIVIPGo00000_m<C4`7o`00013o<c<c1ol00005oda<C0Ko00001_mVIVH3o`0005Oo
Ogmo1_ooool1o`00007ooooo000:ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`06ooooo`03o`000?oooooooooo00CoooooSomoOgl;o`0000ooOgmo1Ol00006ofIVIPOo
00000_m<C4`@o`0000OoC4a<1Ol00003ofIVIPWo00003omoOgl;o`00043oOgmo1_ooool1o`00007o
oooo0008ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03
o`000?oooooooooo00CoooooSomoOgl00ol0003oVIVIoiVIV@08oiVIV@Oo00003OmoOgl6o`0000Oo
IVIV1_l0000<oda<C0Oo00001OmVIVH3o`0001;oOgmo1_l0000:oiVIV@03o`000?moOgooOgmo03ko
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooS_moOgl00ol0003oVIVI
oiVIV@0@oiVIV@Ko00001_moOgl6o`000003ogmoOol0003o000000Go00001_mVIVH<o`0000OoIVIV
1Ol000000omoOgoo0000o`00000Bo`00013oVIVI00?o0000ogmoOomoOgl0?_moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?oooon>ogmoO`03o`000?nIVIWoVIVI01KoVIVI1_l0
0006oiVIV@?o00001OmoOglOo`0002CoVIVI00?o0000ogmoOomoOgl0?_moOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?oooon=ogmoO`03o`000?nIVIWoVIVI02KoVIVI2ol0000<
ogmoO`Oo0000:onIVIT00ol0003oOgmoogmoO`0mogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooohgoOgmo00?o0000oiVIVOnIVIT0<OnIVIT<o`0003;oVIVI00?o0000ogmo
OomoOgl0?OmoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon<ogmoO`03
o`000?nIVIWoVIVI01CoVIVIAOl0000GoiVIV@03o`000?moOgooOgmo03goOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CoooooSOmoOgl00ol0003oVIVIoiVIV@0CoiVIV@03o`00
0?nc/k?o/k>c047o/k>c00?o0000oiVIVOnIVIT04onIVIT2o`00043oOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CoooooS_moOgl00ol0003oVIVIoiVIV@0BoiVIV@03o`000?nc
/k?o/k>c04;o/k>c00?o0000oiVIVOnIVIT04OnIVIT00ol0003oOgmoogmoO`10ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooohooOgmo0_l0000BoiVIV@03o`000?nc/k?o
/k>c00oo/k>c8?l0000Cok>c/`03o`000?nIVIWoVIVI00ooVIVI0_l00013ogmoO`Kooooo0Ol00001
ooooo`006_ooool2o`0000GoooooTOmoOgl2o`0000ooVIVI00?o0000ok>c/onc/k<03Onc/k<3o`00
023oc<c<1?l0000?ok>c/`03o`000?nIVIWoVIVI00koVIVI00?o0000ogmoOomoOgl0@omoOgl5oooo
o`;o00000Oooool001[ooooo00?o0000ooooooooool01?oooonCogmoO`03o`000?nIVIWoVIVI00co
VIVI00?o0000ok>c/onc/k<02onc/k<2o`0002Ooc<c<0ol0000=ok>c/`03o`000?nIVIWoVIVI00co
VIVI00?o0000ogmoOomoOgl0A?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?oooonDogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<02_nc/k<00ol0003oc<c<
olc<c00Yolc<c0;o00002onc/k<2o`0000coVIVI0_l00017ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04oooooiGoOgmo0_l0000<oiVIV@;o00002onc/k<2o`0002Ooc<c<0_l0
000;ok>c/`;o00003OnIVIT00ol0003oOgmoogmoO`17ogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04oooooiOoOgmo00?o0000oiVIVOnIVIT02onIVIT2o`0000_o/k>c0_l0000T
olc<c003o`000?nc/k?o/k>c00[o/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`18
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooiSoOgmo0_l0000=oiVI
V@;o00002onc/k<2o`0001ooc<c<0ol0000;ok>c/`;o00003_nIVIT00ol0003oOgmoogmoO`19ogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooi[oOgmo00?o0000oiVIVOnI
VIT03?nIVIT3o`0000[o/k>c1Ol0000Golc<c0?o00002onc/k<3o`0000ooVIVI00?o0000ogmoOomo
Ogl0B_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonKogmoO`03o`00
0?nIVIWoVIVI00koVIVI0ol0000<ok>c/`Ko00003?o<c<`5o`0000co/k>c0_l0000>oiVIV@Co0000
COmoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonLogmoO`Go00003_nI
VIT3o`0000oo/k>c3?l0000>ok>c/`?o00002onIVIT5o`00057oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CoooooXOmoOgl;o`0000KoVIVI0ol0000Ook>c/`Oo00001onIVIT7
o`0005KoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo[?moOgl3o`00
00KoVIVI1_l0000Bok>c/`Oo00002onIVIT3o`0005goOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00Cooooo[omoOgl4o`0000SoVIVI4_l0000=oiVIV@Go0000H?moOgl6ooooo`7o
00000Oooool001[ooooo0_l00005oooook?oOgmo0ol0000NoiVIV@Ko0000IOmoOgl5ooooo`;o0000
0Oooool001[ooooo00?o0000ooooooooool01?oooonfogmoO`Go00004_nIVIT7o`0006_oOgmo1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo^omoOglBo`0007;oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04oooooj?oOgmo1?l0002HogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04oooooj?oOgmo00Co0000ofIVI_mVIVKoIVIV3Ol0000VogmoOa7o
0000E?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonRogmoO`03o`00
0?mVIVKoIVIV00ooIVIV9_l0000@ofIVIP03o`000?moOgooOgmo05;oOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CoooooXOmoOgl00ol0003oIVIVofIVIP17ofIVIP03o`000?mo
OgooOgmo057oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooXOmoOgl0
0ol0003oIVIVofIVIP17ofIVIP03o`000?moOgooOgmo057oOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CoooooX?moOgl00ol0003oIVIVofIVIP18ofIVIP03o`000?moOgooOgmo
057oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooWomoOgl2o`0004[o
IVIV0_l0001BogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooj7oOgmo
0_l00016ofIVIP;o0000E?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
oonSogmoO`;o0000@omVIVH00ol0003oOgmoogmoO`1DogmoO`Kooooo0Ol00001ooooo`006_ooool2
o`0000GoooooYOmoOgl2o`0003ooIVIV0_l0001GogmoO`Gooooo0_l00001ooooo`006_ooool00ol0
003oooooooooo`04ooooojOoOgmo0_l0000lofIVIP03o`000?moOgooOgmo05OoOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CoooooZOmoOgl3o`0003KoIVIV0ol0001JogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooojcoOgmo0ol0000_ofIVIPCo0000
GOmoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon_ogmoO`Co0000:OmV
IVH2o`00067oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo/omoOgl3
o`0002?oIVIV0ol0001SogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
okKoOgmo0ol0000LofIVIPCo0000I_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooniogmoO`?o00005_mVIVH3o`0006[oOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00Cooooo_?moOgl5o`0000coIVIV1Ol0001]ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04oooool7oOgmo3?l0001bogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo
0_l00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooooomo
Ogm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`00
1oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo00Co
oooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`001oooool01OnHV9So8B4Qonk^k_ooooooA4A400?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmo
O`Kooooo0Ol00001ooooo`002?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?oooooooooooooo
ool@41001_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000Wo
oooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000Kooooo0ol00004oooo
ooooOgmo@?moOgl4ooooo`?o00000Oooool000[ooooo00?oMgMgofIVI_ooool00_ooool01Ol0003o
oooooooooooooooo000000Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00
007ooooo000;ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`04oooo
o`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`001oooool01Ol0003o
^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooo
oooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`001oooool01OnHV9So410@o`000?lQ8B7o
c<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo00Cooooooomo
Ogm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
ooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo
@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo0_l00005ooooooooOgmo@?moOgl5
ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
ooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3o
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo0_l00005ooooooooOgmo
@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooo
ogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo0_l00005oooo
ooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3o
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooooomo
Ogm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6
ooooo`7o00000Oooool000Oooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Ooo
ool000Oooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000_ooooo00Go
0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0
1?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000:ooooo`03ojVYZOl@413ooooo00;ooooo00Go
0000ooooooooooooooooo`000006ooooo`?o00001?ooooooogmoOd3oOgmo1?ooool3o`00007ooooo
0009ooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool00onj^[[o8B4Qoooo
o`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`04ooooooooOgmo
@?moOgl6ooooo`7o00000Oooool000Oooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool000Oooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooo
ogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo
000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
ooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3o
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooooomo
Ogm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00
007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooo
ogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo
@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_oo
ool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007ooooo000Joooo
o`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooooomo
Ogm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
ooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3o
Ogmo1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007ooooo
000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo
@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo0009ooooo`;o0000
00Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool00_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo0007ooooo`Go00000oooool01Ol@413ooooooooooooooooo410@00Kooooo0ol00004
ooooooooOgmo@?moOgl4ooooo`?o00000Oooool000Oooooo00CoA4A4omgMgOoooooo00001?ooool0
1Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0oooooom:ooooo`7o00000Ooo
ool000Oooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool0oooooom:ooooo`7o00000Oooool000Sooooo00?oMgMgolc<c?l000001?oo
ool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool0oooooom:ooooo`7o0000
0Oooool000Sooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo
00?o0000ooooooooool0oooooom:ooooo`7o00000Oooool000Wooooo00?oMgMgo`000?ooool00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool08oooool00ol0003ooooo
ooooo`0mooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0?Oooool00ol0003ooooo
ooooo`0mooooo`03o`000?oooooooooo02?ooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00Wooooo0Ol00001ooooo`006_ooooooo`0004ko00000Oooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-30.1723, -14.304, 0.195672, \
0.195672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0192308 0.211538 0.0192308 [
[.11538 -0.0125 -9 -9 ]
[.11538 -0.0125 9 0 ]
[.30769 -0.0125 -9 -9 ]
[.30769 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69231 -0.0125 -6 -9 ]
[.69231 -0.0125 6 0 ]
[.88462 -0.0125 -6 -9 ]
[.88462 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -18 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .21154 -6 -4.5 ]
[-0.0125 .21154 0 4.5 ]
[-0.0125 .40385 -12 -4.5 ]
[-0.0125 .40385 0 4.5 ]
[-0.0125 .59615 -12 -4.5 ]
[-0.0125 .59615 0 4.5 ]
[-0.0125 .78846 -12 -4.5 ]
[-0.0125 .78846 0 4.5 ]
[-0.0125 .98077 -12 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11538 0 m
.11538 .00625 L
s
[(-20)] .11538 -0.0125 0 1 Mshowa
.30769 0 m
.30769 .00625 L
s
[(-10)] .30769 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69231 0 m
.69231 .00625 L
s
[(10)] .69231 -0.0125 0 1 Mshowa
.88462 0 m
.88462 .00625 L
s
[(20)] .88462 -0.0125 0 1 Mshowa
.125 Mabswid
.15385 0 m
.15385 .00375 L
s
.19231 0 m
.19231 .00375 L
s
.23077 0 m
.23077 .00375 L
s
.26923 0 m
.26923 .00375 L
s
.34615 0 m
.34615 .00375 L
s
.38462 0 m
.38462 .00375 L
s
.42308 0 m
.42308 .00375 L
s
.46154 0 m
.46154 .00375 L
s
.53846 0 m
.53846 .00375 L
s
.57692 0 m
.57692 .00375 L
s
.61538 0 m
.61538 .00375 L
s
.65385 0 m
.65385 .00375 L
s
.73077 0 m
.73077 .00375 L
s
.76923 0 m
.76923 .00375 L
s
.80769 0 m
.80769 .00375 L
s
.84615 0 m
.84615 .00375 L
s
.07692 0 m
.07692 .00375 L
s
.03846 0 m
.03846 .00375 L
s
.92308 0 m
.92308 .00375 L
s
.96154 0 m
.96154 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(-10)] -0.0125 .01923 1 0 Mshowa
0 .21154 m
.00625 .21154 L
s
[(0)] -0.0125 .21154 1 0 Mshowa
0 .40385 m
.00625 .40385 L
s
[(10)] -0.0125 .40385 1 0 Mshowa
0 .59615 m
.00625 .59615 L
s
[(20)] -0.0125 .59615 1 0 Mshowa
0 .78846 m
.00625 .78846 L
s
[(30)] -0.0125 .78846 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(40)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .05769 m
.00375 .05769 L
s
0 .09615 m
.00375 .09615 L
s
0 .13462 m
.00375 .13462 L
s
0 .17308 m
.00375 .17308 L
s
0 .25 m
.00375 .25 L
s
0 .28846 m
.00375 .28846 L
s
0 .32692 m
.00375 .32692 L
s
0 .36538 m
.00375 .36538 L
s
0 .44231 m
.00375 .44231 L
s
0 .48077 m
.00375 .48077 L
s
0 .51923 m
.00375 .51923 L
s
0 .55769 m
.00375 .55769 L
s
0 .63462 m
.00375 .63462 L
s
0 .67308 m
.00375 .67308 L
s
0 .71154 m
.00375 .71154 L
s
0 .75 m
.00375 .75 L
s
0 .82692 m
.00375 .82692 L
s
0 .86538 m
.00375 .86538 L
s
0 .90385 m
.00375 .90385 L
s
0 .94231 m
.00375 .94231 L
s
.25 Mabswid
0 0 m
0 1 L
s
.11538 .99375 m
.11538 1 L
s
.30769 .99375 m
.30769 1 L
s
.5 .99375 m
.5 1 L
s
.69231 .99375 m
.69231 1 L
s
.88462 .99375 m
.88462 1 L
s
.125 Mabswid
.15385 .99625 m
.15385 1 L
s
.19231 .99625 m
.19231 1 L
s
.23077 .99625 m
.23077 1 L
s
.26923 .99625 m
.26923 1 L
s
.34615 .99625 m
.34615 1 L
s
.38462 .99625 m
.38462 1 L
s
.42308 .99625 m
.42308 1 L
s
.46154 .99625 m
.46154 1 L
s
.53846 .99625 m
.53846 1 L
s
.57692 .99625 m
.57692 1 L
s
.61538 .99625 m
.61538 1 L
s
.65385 .99625 m
.65385 1 L
s
.73077 .99625 m
.73077 1 L
s
.76923 .99625 m
.76923 1 L
s
.80769 .99625 m
.80769 1 L
s
.84615 .99625 m
.84615 1 L
s
.07692 .99625 m
.07692 1 L
s
.03846 .99625 m
.03846 1 L
s
.92308 .99625 m
.92308 1 L
s
.96154 .99625 m
.96154 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .21154 m
1 .21154 L
s
.99375 .40385 m
1 .40385 L
s
.99375 .59615 m
1 .59615 L
s
.99375 .78846 m
1 .78846 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .05769 m
1 .05769 L
s
.99625 .09615 m
1 .09615 L
s
.99625 .13462 m
1 .13462 L
s
.99625 .17308 m
1 .17308 L
s
.99625 .25 m
1 .25 L
s
.99625 .28846 m
1 .28846 L
s
.99625 .32692 m
1 .32692 L
s
.99625 .36538 m
1 .36538 L
s
.99625 .44231 m
1 .44231 L
s
.99625 .48077 m
1 .48077 L
s
.99625 .51923 m
1 .51923 L
s
.99625 .55769 m
1 .55769 L
s
.99625 .63462 m
1 .63462 L
s
.99625 .67308 m
1 .67308 L
s
.99625 .71154 m
1 .71154 L
s
.99625 .75 m
1 .75 L
s
.99625 .82692 m
1 .82692 L
s
.99625 .86538 m
1 .86538 L
s
.99625 .90385 m
1 .90385 L
s
.99625 .94231 m
1 .94231 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.4 g
.45094 .38294 m
.47057 .38169 L
.49019 .37715 L
.50981 .38669 L
.52943 .38899 L
.54906 .39162 L
.55284 .39207 L
.56868 .39383 L
.5883 .39541 L
.60793 .39632 L
.62755 .39657 L
.64717 .39615 L
.6668 .39506 L
.68642 .39331 L
.69701 .39207 L
.70604 .39096 L
.72567 .39137 L
.74529 .3849 L
.76491 .38292 L
.78454 .38154 L
.80416 .38498 L
.80904 .39207 L
.80416 .40063 L
.79257 .4117 L
.78454 .41713 L
.76491 .42701 L
.75429 .43132 L
.74529 .43358 L
.72567 .44136 L
.70604 .44889 L
.68642 .44899 L
.67224 .45094 L
.6668 .45158 L
.64717 .45326 L
.62755 .45389 L
.60793 .45352 L
.5883 .45212 L
.57756 .45094 L
.56868 .44974 L
.54906 .45074 L
.52943 .44338 L
.50981 .4355 L
.49551 .43132 L
.49019 .42922 L
.47057 .41998 L
.45725 .4117 L
.45094 .40624 L
.44093 .39207 L
F
0 g
.45094 .38294 m
.47057 .38169 L
.49019 .37715 L
.50981 .38669 L
.52943 .38899 L
.54906 .39162 L
.55284 .39207 L
.56868 .39383 L
.5883 .39541 L
.60793 .39632 L
.62755 .39657 L
.64717 .39615 L
.6668 .39506 L
.68642 .39331 L
.69701 .39207 L
.70604 .39096 L
.72567 .39137 L
.74529 .3849 L
.76491 .38292 L
.78454 .38154 L
.80416 .38498 L
.80904 .39207 L
.80416 .40063 L
.79257 .4117 L
.78454 .41713 L
.76491 .42701 L
.75429 .43132 L
.74529 .43358 L
.72567 .44136 L
.70604 .44889 L
.68642 .44899 L
.67224 .45094 L
.6668 .45158 L
.64717 .45326 L
.62755 .45389 L
.60793 .45352 L
.5883 .45212 L
.57756 .45094 L
.56868 .44974 L
.54906 .45074 L
.52943 .44338 L
.50981 .4355 L
.49551 .43132 L
.49019 .42922 L
.47057 .41998 L
.45725 .4117 L
.45094 .40624 L
.44093 .39207 L
.45094 .38294 L
s
.6 g
.45094 .44692 m
.47057 .44361 L
.49019 .44549 L
.50981 .44702 L
.52712 .45094 L
.52943 .45133 L
.54906 .45438 L
.56868 .4568 L
.5883 .4585 L
.60793 .45949 L
.62755 .45976 L
.64717 .45931 L
.6668 .45813 L
.68642 .45623 L
.70604 .45365 L
.72252 .45094 L
.72567 .45045 L
.74529 .44533 L
.76491 .44485 L
.78454 .44355 L
.80232 .45094 L
.78766 .47057 L
.78454 .47696 L
.76491 .48537 L
.75492 .49019 L
.74529 .4936 L
.72567 .50219 L
.70604 .50905 L
.69584 .50981 L
.68642 .51188 L
.6668 .51516 L
.64717 .51225 L
.62755 .51325 L
.60793 .51266 L
.5883 .5158 L
.56868 .51287 L
.55414 .50981 L
.54906 .50871 L
.52943 .50426 L
.50981 .49581 L
.49499 .49019 L
.49019 .48795 L
.47057 .47683 L
.46239 .47057 L
.45094 .45813 L
.44792 .45094 L
F
0 g
.45094 .44692 m
.47057 .44361 L
.49019 .44549 L
.50981 .44702 L
.52712 .45094 L
.52943 .45133 L
.54906 .45438 L
.56868 .4568 L
.5883 .4585 L
.60793 .45949 L
.62755 .45976 L
.64717 .45931 L
.6668 .45813 L
.68642 .45623 L
.70604 .45365 L
.72252 .45094 L
.72567 .45045 L
.74529 .44533 L
.76491 .44485 L
.78454 .44355 L
.80232 .45094 L
.78766 .47057 L
.78454 .47696 L
.76491 .48537 L
.75492 .49019 L
.74529 .4936 L
.72567 .50219 L
.70604 .50905 L
.69584 .50981 L
.68642 .51188 L
.6668 .51516 L
.64717 .51225 L
.62755 .51325 L
.60793 .51266 L
.5883 .5158 L
.56868 .51287 L
.55414 .50981 L
.54906 .50871 L
.52943 .50426 L
.50981 .49581 L
.49499 .49019 L
.49019 .48795 L
.47057 .47683 L
.46239 .47057 L
.45094 .45813 L
.44792 .45094 L
.45094 .44692 L
s
.6 g
.47057 .33235 m
.49019 .33284 L
.50981 .33274 L
.51467 .3332 L
.52943 .33459 L
.54906 .3364 L
.56868 .33796 L
.5883 .33674 L
.60793 .33915 L
.62755 .33975 L
.64717 .33872 L
.6668 .33569 L
.68642 .33759 L
.70604 .33595 L
.72567 .3341 L
.73537 .3332 L
.74529 .33232 L
.76491 .33199 L
.78082 .3332 L
.78454 .33452 L
.78647 .35283 L
.78454 .35444 L
.76491 .36598 L
.75033 .37245 L
.74529 .37488 L
.72567 .38724 L
.70604 .38432 L
.68642 .38771 L
.6668 .39018 L
.64717 .39171 L
.63901 .39207 L
.62755 .3923 L
.61091 .39207 L
.60793 .39196 L
.5883 .39067 L
.56868 .38844 L
.54906 .38529 L
.52943 .38119 L
.50981 .37752 L
.49961 .37245 L
.49019 .36844 L
.47057 .35791 L
.46367 .35283 L
.46877 .3332 L
F
0 g
.47057 .33235 m
.49019 .33284 L
.50981 .33274 L
.51467 .3332 L
.52943 .33459 L
.54906 .3364 L
.56868 .33796 L
.5883 .33674 L
.60793 .33915 L
.62755 .33975 L
.64717 .33872 L
.6668 .33569 L
.68642 .33759 L
.70604 .33595 L
.72567 .3341 L
.73537 .3332 L
.74529 .33232 L
.76491 .33199 L
.78082 .3332 L
.78454 .33452 L
.78647 .35283 L
.78454 .35444 L
.76491 .36598 L
.75033 .37245 L
.74529 .37488 L
.72567 .38724 L
.70604 .38432 L
.68642 .38771 L
.6668 .39018 L
.64717 .39171 L
.63901 .39207 L
.62755 .3923 L
.61091 .39207 L
.60793 .39196 L
.5883 .39067 L
.56868 .38844 L
.54906 .38529 L
.52943 .38119 L
.50981 .37752 L
.49961 .37245 L
.49019 .36844 L
.47057 .35791 L
.46367 .35283 L
.46877 .3332 L
.47057 .33235 L
s
.3 g
.50981 .39842 m
.52943 .39758 L
.54906 .39828 L
.56868 .39928 L
.5883 .40015 L
.60793 .40071 L
.62755 .40087 L
.64717 .40061 L
.6668 .39995 L
.68642 .39902 L
.70604 .39804 L
.72567 .39756 L
.74529 .39938 L
.75525 .4117 L
.74529 .42025 L
.72567 .43097 L
.72489 .43132 L
.70604 .44317 L
.68642 .44249 L
.6668 .44572 L
.64717 .44768 L
.62755 .44843 L
.60793 .44799 L
.5883 .44635 L
.56868 .44346 L
.54906 .44728 L
.52943 .43377 L
.52517 .43132 L
.50981 .42348 L
.49473 .4117 L
F
0 g
.50981 .39842 m
.52943 .39758 L
.54906 .39828 L
.56868 .39928 L
.5883 .40015 L
.60793 .40071 L
.62755 .40087 L
.64717 .40061 L
.6668 .39995 L
.68642 .39902 L
.70604 .39804 L
.72567 .39756 L
.74529 .39938 L
.75525 .4117 L
.74529 .42025 L
.72567 .43097 L
.72489 .43132 L
.70604 .44317 L
.68642 .44249 L
.6668 .44572 L
.64717 .44768 L
.62755 .44843 L
.60793 .44799 L
.5883 .44635 L
.56868 .44346 L
.54906 .44728 L
.52943 .43377 L
.52517 .43132 L
.50981 .42348 L
.49473 .4117 L
.50981 .39842 L
s
.4 g
.50981 .2907 m
.52943 .28635 L
.54906 .28877 L
.56868 .28923 L
.5883 .28977 L
.60793 .29017 L
.62755 .29028 L
.64717 .29009 L
.6668 .28964 L
.68642 .28908 L
.70604 .29208 L
.72567 .28274 L
.74529 .29185 L
.75098 .29396 L
.74529 .31214 L
.74319 .31358 L
.72567 .31986 L
.70604 .32515 L
.68642 .32919 L
.6668 .33206 L
.65752 .3332 L
.64717 .33377 L
.62755 .33451 L
.60793 .33407 L
.5946 .3332 L
.5883 .33262 L
.56868 .33004 L
.54906 .32632 L
.52943 .32137 L
.50981 .31482 L
.50689 .31358 L
.49897 .29396 L
F
0 g
.50981 .2907 m
.52943 .28635 L
.54906 .28877 L
.56868 .28923 L
.5883 .28977 L
.60793 .29017 L
.62755 .29028 L
.64717 .29009 L
.6668 .28964 L
.68642 .28908 L
.70604 .29208 L
.72567 .28274 L
.74529 .29185 L
.75098 .29396 L
.74529 .31214 L
.74319 .31358 L
.72567 .31986 L
.70604 .32515 L
.68642 .32919 L
.6668 .33206 L
.65752 .3332 L
.64717 .33377 L
.62755 .33451 L
.60793 .33407 L
.5946 .3332 L
.5883 .33262 L
.56868 .33004 L
.54906 .32632 L
.52943 .32137 L
.50981 .31482 L
.50689 .31358 L
.49897 .29396 L
.50981 .2907 L
s
.7 g
.52943 .34617 m
.54906 .34498 L
.56868 .34494 L
.5883 .34015 L
.60793 .34296 L
.62755 .34358 L
.64717 .3425 L
.6668 .33873 L
.68642 .3449 L
.70604 .34512 L
.72567 .34694 L
.73998 .35283 L
.72567 .36923 L
.71984 .37245 L
.70604 .37703 L
.68642 .38174 L
.6668 .38496 L
.64717 .38691 L
.62755 .38766 L
.60793 .38722 L
.5883 .38558 L
.56868 .3827 L
.54906 .37842 L
.53014 .37245 L
.52943 .37209 L
.51005 .35283 L
F
0 g
.52943 .34617 m
.54906 .34498 L
.56868 .34494 L
.5883 .34015 L
.60793 .34296 L
.62755 .34358 L
.64717 .3425 L
.6668 .33873 L
.68642 .3449 L
.70604 .34512 L
.72567 .34694 L
.73998 .35283 L
.72567 .36923 L
.71984 .37245 L
.70604 .37703 L
.68642 .38174 L
.6668 .38496 L
.64717 .38691 L
.62755 .38766 L
.60793 .38722 L
.5883 .38558 L
.56868 .3827 L
.54906 .37842 L
.53014 .37245 L
.52943 .37209 L
.51005 .35283 L
.52943 .34617 L
s
.7 g
.52943 .46664 m
.54906 .4651 L
.56868 .46535 L
.5883 .46589 L
.60793 .46631 L
.62755 .46643 L
.64717 .46622 L
.6668 .46575 L
.68642 .46523 L
.70604 .46521 L
.72567 .46813 L
.72955 .47057 L
.72567 .47785 L
.70604 .49018 L
.70602 .49019 L
.68642 .49707 L
.6668 .50143 L
.64717 .50396 L
.62755 .50491 L
.60793 .50435 L
.5883 .50225 L
.56868 .49841 L
.54906 .49229 L
.54396 .49019 L
.52943 .48203 L
.52033 .47057 L
F
0 g
.52943 .46664 m
.54906 .4651 L
.56868 .46535 L
.5883 .46589 L
.60793 .46631 L
.62755 .46643 L
.64717 .46622 L
.6668 .46575 L
.68642 .46523 L
.70604 .46521 L
.72567 .46813 L
.72955 .47057 L
.72567 .47785 L
.70604 .49018 L
.70602 .49019 L
.68642 .49707 L
.6668 .50143 L
.64717 .50396 L
.62755 .50491 L
.60793 .50435 L
.5883 .50225 L
.56868 .49841 L
.54906 .49229 L
.54396 .49019 L
.52943 .48203 L
.52033 .47057 L
.52943 .46664 L
s
.2 g
.52943 .41098 m
.54906 .40618 L
.56868 .40531 L
.5883 .40527 L
.60793 .40539 L
.62755 .40544 L
.64717 .40536 L
.6668 .40525 L
.68642 .40541 L
.70604 .40674 L
.72165 .4117 L
.70604 .42801 L
.69928 .43132 L
.68642 .43538 L
.6668 .43961 L
.64717 .44206 L
.62755 .44297 L
.60793 .44244 L
.5883 .4404 L
.56868 .43668 L
.55075 .43132 L
.54906 .43054 L
.52943 .41648 L
.52843 .4117 L
F
0 g
.52943 .41098 m
.54906 .40618 L
.56868 .40531 L
.5883 .40527 L
.60793 .40539 L
.62755 .40544 L
.64717 .40536 L
.6668 .40525 L
.68642 .40541 L
.70604 .40674 L
.72165 .4117 L
.70604 .42801 L
.69928 .43132 L
.68642 .43538 L
.6668 .43961 L
.64717 .44206 L
.62755 .44297 L
.60793 .44244 L
.5883 .4404 L
.56868 .43668 L
.55075 .43132 L
.54906 .43054 L
.52943 .41648 L
.52843 .4117 L
.52943 .41098 L
s
.4 g
.56868 .53828 m
.5883 .53851 L
.60793 .53891 L
.62755 .53903 L
.64717 .53882 L
.6668 .53841 L
.68642 .53841 L
.69511 .54906 L
.68642 .55301 L
.6668 .55855 L
.64717 .5615 L
.62755 .56258 L
.60793 .56195 L
.5883 .55952 L
.56868 .5548 L
.55486 .54906 L
F
0 g
.56868 .53828 m
.5883 .53851 L
.60793 .53891 L
.62755 .53903 L
.64717 .53882 L
.6668 .53841 L
.68642 .53841 L
.69511 .54906 L
.68642 .55301 L
.6668 .55855 L
.64717 .5615 L
.62755 .56258 L
.60793 .56195 L
.5883 .55952 L
.56868 .5548 L
.55486 .54906 L
.56868 .53828 L
s
.8 g
.5883 .35049 m
.60793 .35041 L
.62755 .35045 L
.64717 .35039 L
.6668 .35067 L
.68127 .35283 L
.68642 .35361 L
.69251 .37245 L
.68642 .37442 L
.6668 .37895 L
.64717 .38151 L
.62755 .38246 L
.60793 .3819 L
.5883 .37978 L
.56868 .37584 L
.55744 .37245 L
.56868 .35292 L
.56933 .35283 L
F
0 g
.5883 .35049 m
.60793 .35041 L
.62755 .35045 L
.64717 .35039 L
.6668 .35067 L
.68127 .35283 L
.68642 .35361 L
.69251 .37245 L
.68642 .37442 L
.6668 .37895 L
.64717 .38151 L
.62755 .38246 L
.60793 .3819 L
.5883 .37978 L
.56868 .37584 L
.55744 .37245 L
.56868 .35292 L
.56933 .35283 L
.5883 .35049 L
s
.3 g
.56868 .30819 m
.5883 .3042 L
.60793 .30299 L
.62755 .30274 L
.64717 .30319 L
.6668 .30479 L
.6863 .31358 L
.6668 .32063 L
.64717 .32399 L
.62755 .32519 L
.60793 .32449 L
.5883 .32175 L
.56868 .31606 L
.56361 .31358 L
F
0 g
.56868 .30819 m
.5883 .3042 L
.60793 .30299 L
.62755 .30274 L
.64717 .30319 L
.6668 .30479 L
.6863 .31358 L
.6668 .32063 L
.64717 .32399 L
.62755 .32519 L
.60793 .32449 L
.5883 .32175 L
.56868 .31606 L
.56361 .31358 L
.56868 .30819 L
s
.1 g
.5883 .41144 m
.60793 .41083 L
.62755 .41071 L
.64717 .41092 L
.66592 .4117 L
.6668 .41178 L
.67014 .43132 L
.6668 .43214 L
.64717 .43556 L
.62755 .43677 L
.60793 .43607 L
.5883 .43328 L
.57954 .43132 L
.58347 .4117 L
F
0 g
.5883 .41144 m
.60793 .41083 L
.62755 .41071 L
.64717 .41092 L
.66592 .4117 L
.6668 .41178 L
.67014 .43132 L
.6668 .43214 L
.64717 .43556 L
.62755 .43677 L
.60793 .43607 L
.5883 .43328 L
.57954 .43132 L
.58347 .4117 L
.5883 .41144 L
s
.9 g
.60793 .36051 m
.62755 .35988 L
.64717 .36103 L
.6603 .37245 L
.64717 .37438 L
.62755 .37583 L
.60793 .37499 L
.59215 .37245 L
F
0 g
.60793 .36051 m
.62755 .35988 L
.64717 .36103 L
.6603 .37245 L
.64717 .37438 L
.62755 .37583 L
.60793 .37499 L
.59215 .37245 L
.60793 .36051 L
s
.6 g
.60793 .25419 m
.62755 .25386 L
.64717 .25444 L
.65284 .25471 L
.64717 .27396 L
.64385 .27433 L
.62755 .27489 L
.60793 .27444 L
.60613 .27433 L
.59872 .25471 L
F
0 g
.60793 .25419 m
.62755 .25386 L
.64717 .25444 L
.65284 .25471 L
.64717 .27396 L
.64385 .27433 L
.62755 .27489 L
.60793 .27444 L
.60613 .27433 L
.59872 .25471 L
.60793 .25419 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00?Oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0dooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kS?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0hooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8b
onk^kS?ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08_ooool003gooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0=_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0<oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg03?ooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL08_ooool003Gooooo1_l0
0003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400[ooooo`Ko0000
1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100<oooool01Ol@413o
oooooooooooooooo410@03[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@03Cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@02;ooooo000o
ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000fooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000cooooo`05o`000?ooooooooooooooool0
0000>_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000=Oooool00onH
V9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000008_ooool0043ooooo00?oMgMgofIV
I_ooool00_ooool01Ol0003ooooooooooooooooo000003Kooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000003?ooooo00Go0000ooooooooooooooooo`00000jooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`03ogMgMomVIVKooooo00;o
oooo00Go0000ooooooooooooooooo`00000Rooooo`00@Oooool01Ol0003ooooooooooooooooo410@
00?ooooo00?o410@ooooooooool0=?ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@4100<oooool01Ol@413ooooooooooooooooo410@03[ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@03Oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo023ooooo000mooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg03Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg03?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0jooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0cooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02;ooooo000mooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^03Cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^03?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`03oeEEEOmVIVKo000000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0cooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02;ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo000Joooooooo0000C_l00001ooooo`00
6_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0?Ooo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool08ooo
ool1o`00007ooooo0008ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKo
oooo00?o0000ooooooooool0oooooom:ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooom:ooooo`7o
00000Oooool000Go00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41001_ooool00ol0003oooooooooo`3ooooood[ooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?ooooooB?ooool3o`00007o
oooo000:ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo0008ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Oooooooogmo
Od3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Ooo
ooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000oooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`003ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000?ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000oooooo00Go0000oooooooooooooooo
o`000006ooooo`?o00001?ooooooogmoOd3oOgmo1?ooool3o`00007ooooo000?ooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool000oooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`003oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000?ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003ooooo
ooooo`04oooool3oOgmo4ol0001/ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04oooool3oOgmo00?o0000oiVIVOnIVIT03onIVIT00ol0003oOgmoogmoO`1ZogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04oooool7oOgmo00?o0000oiVIVOnIVIT03_nIVIT0
0ol0003oOgmoogmoO`1ZogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
ol7oOgmo00?o0000oiVIVOnIVIT03OnIVIT00ol0003oOgmoogmoO`1[ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04oooool;oOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o
OgmoogmoO`1[ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooool;oOgmo
00?o0000oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`1[ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04oooool;oOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmo
O`1/ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooool?oOgmo3_l0001^
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooojOmoOgl3o`0005?oOgmo1_ooool1o`00007ooooo
000Jooooo`;o00001OoooonVogmoO`So0000>OmoOgl2o`0000?oIVIV0ol0001@ogmoO`Gooooo0_l0
0001ooooo`006_ooool00ol0003oooooooooo`04oooooj7oOgmo1Ol00008ofIVISCo00000omoOgl2
o`0000SoIVIV0_l0001>ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
oiooOgmo0_l00011ofIVIP?o00003?mVIVH3o`0004_oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CoooooWomoOgl00ol0003oIVIVofIVIP1AofIVIP03o`000?moOgooOgmo04Wo
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooX?moOgl00ol0003oIVIV
ofIVIP1?ofIVIP03o`000?moOgooOgmo04[oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CoooooX?moOgl00ol0003oIVIVofIVIP0MofIVIQGo00007OmVIVH00ol0003oOgmoogmo
O`1:ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooj7oOgmo00?o0000
ofIVI_mVIVH05_mVIVH6o`0001GoC4a<1?l0000IofIVIP03o`000?moOgooOgmo04[oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooXOmoOgl00ol0003oIVIVofIVIP0BofIV
IPCo00007om<C4`2o`0001KoIVIV00?o0000ogmoOomoOgl0BomoOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?oooonQogmoO`03o`000?mVIVKoIVIV017oIVIV00?o0000oda<C?m<
C4`08om<C4`2o`0001CoIVIV00?o0000ogmoOomoOgl0BomoOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?oooonRogmoO`Co00003_mVIVH2o`0002KoC4a<0_l0000AofIVIP;o0000
C_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonVogmoO`?o00003OmV
IVH5o`0001koC4a<0ol0000@ofIVIP?o0000D?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?oooonYogmoO`?o00003omVIVH6o`0001?oC4a<1Ol0000@ofIVIP?o0000DomoOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon/ogmoO`?o00004_mVIVH7o`00
00GoC4a<1ol0000BofIVIP?o0000E_moOgl6ooooo`7o00000Oooool001[ooooo0_l00005ooooojoo
Ogmo1Ol0000DofIVIPGo00005?mVIVH5o`0005WoOgmo1Oooool2o`00007ooooo000Jooooo`03o`00
0?oooooooooo00Cooooo]?moOgl7o`0001ooIVIV1ol0001NogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04oooooiGoOgmo4ol0000CogmoO`Oo00002omVIVH=o`0001;oOgmo4_l0
0011ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooiGoOgmo00?o0000
oiVIVOnIVIT04?nIVIT<o`0000KoOgmo1ol000000omoOgoo0000o`000009o`0000OoOgmo1ol00006
ogmoO`_o00004_nIVIT00ol0003oOgmoogmoO`0nogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04oooooiGoOgmo00?o0000oiVIVOnIVIT07?nIVIT6o`0000OoVIVI6Ol000000onI
VIWo0000o`000004o`0001goVIVI00?o0000ogmoOomoOgl0?_moOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?oooonDogmoO`03o`000?nIVIWoVIVI02?oVIVI1ol0000<oiVIV@Oo
00001_nc/k<3o`00027oVIVI00?o0000ogmoOomoOgl0?_moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?oooonDogmoO`03o`000?nIVIWoVIVI01KoVIVI3Ol00007ok>c/`co0000
4?nc/k<;o`0001KoVIVI00?o0000ogmoOomoOgl0?_moOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?oooonDogmoO`03o`000?nIVIWoVIVI017oVIVI1Ol0000kok>c/`Co00004_nI
VIT00ol0003oOgmoogmoO`0nogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
oooooi?oOgmo00?o0000oiVIVOnIVIT03onIVIT3o`0001;o/k>c8?l0000Bok>c/`?o00003onIVIT0
0ol0003oOgmoogmoO`0nogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
oi?oOgmo0_l0000>oiVIV@;o00004Onc/k<4o`00023oc<c<1?l0000Aok>c/`03o`000?nIVIWoVIVI
00_oVIVI0_l00010ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooiGo
Ogmo0_l0000=oiVIV@03o`000?nc/k?o/k>c00oo/k>c00?o0000olc<c?o<c<`09?o<c<`00ol0003o
/k>cok>c/`0>ok>c/`03o`000?nIVIWoVIVI00[oVIVI0_l00012ogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04oooooiOoOgmo0_l0000<oiVIV@03o`000?nc/k?o/k>c00go/k>c
00?o0000olc<c?o<c<`02_o<c<`<o`00013oc<c<00?o0000ok>c/onc/k<03?nc/k<00ol0003oVIVI
oiVIV@0:oiVIV@03o`000?moOgooOgmo04;oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CoooooVOmoOgl00ol0003oVIVIoiVIV@0:oiVIV@03o`000?nc/k?o/k>c00_o/k>c00?o
0000olc<c?o<c<`02_o<c<`00ol0003oi^KVonKViP0:onKViPCo00003?o<c<`00ol0003o/k>cok>c
/`0;ok>c/`03o`000?nIVIWoVIVI00WoVIVI0_l00015ogmoO`Kooooo0Ol00001ooooo`006_ooool2
o`0000GoooooV_moOgl2o`0000_oVIVI00?o0000ok>c/onc/k<02_nc/k<00ol0003oc<c<olc<c009
olc<c003o`000?oVi^Koi^KV00ooi^KV00?o0000olc<c?o<c<`02Oo<c<`00ol0003o/k>cok>c/`0:
ok>c/`03o`000?nIVIWoVIVI00SoVIVI0_l00017ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0
003oooooooooo`04oooooicoOgmo0ol00009oiVIV@03o`000?nc/k?o/k>c00So/k>c00?o0000olc<
c?o<c<`02Oo<c<`00ol0003oi^KVonKViP0AonKViP03o`000?o<c<coc<c<00Woc<c<00?o0000ok>c
/onc/k<01onc/k<2o`0000SoVIVI0ol00019ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04oooooiooOgmo0_l00008oiVIV@?o00001_nc/k<3o`0000Woc<c<1?l0000@onKViP?o
00002Oo<c<`2o`0000Oo/k>c0_l00009oiVIV@03o`000?moOgooOgmo04[oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CoooooXOmoOgl2o`0000WoVIVI0ol00006ok>c/`Co0000
2Oo<c<`@o`0000Soc<c<1?l00007ok>c/`;o00002OnIVIT2o`0004goOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CoooooVOmoOgl5o`0000GoOgmo1?l00008oiVIV@Co00001_nc
/k<3o`0001Soc<c<1_l00007ok>c/`Co00002OnIVIT2o`0004ooOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CoooooT_moOgl7o`0000GoIVIV0ol00006ogmoO`Go00001onIVIT3
o`0000Ko/k>c3?l00005olc<c0Oo00001_nc/k<7o`0000coVIVI00?o0000ogmoOomoOgl02omoOgl7
o`0003goOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooSomoOgl3o`00
00ooIVIV0_l00009ogmoO`?o00001onIVIT5o`0000go/k>c1Ol00007ok>c/`Ko00001onIVIT7o`00
00?oVIVI0_l00003ogmoO`_o00001omVIVH3o`0003[oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CoooooS_moOgl00ol0003oIVIVofIVIP0BofIVIPCo00002?moOgl5o`0000Oo
VIVI6Ol00006oiVIV@Oo00001omoOgl3o`0000;oOgmo0ol0000DofIVIP03o`000?moOgooOgmo03So
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooSOmoOgl00ol0003oIVIV
ofIVIP0GofIVIPOo00001_moOgl=o`0001?oVIVI1_l00009ogmoO`Go00000omoOgl2o`0001SoIVIV
00?o0000ogmoOomoOgl0=omoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
oon<ogmoO`03o`000?mVIVKoIVIV01ooIVIV3Ol00006ogmoOa?o00001_moOgl9o`0000GoIVIV0ol0
000KofIVIP03o`000?moOgooOgmo03KoOgmo1_ooool1o`00007ooooo0008ooooo`Co000000So410@
ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo00?o0000ooooooooool01?oooon<ogmoO`03
o`000?mVIVKoIVIV02coIVIV7ol0000/ofIVIP03o`000?moOgooOgmo03KoOgmo1_ooool1o`00007o
oooo000:ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03
o`000?oooooooooo00CoooooSOmoOgl00ol0003oIVIVofIVIP0BofIVIQWo00006OmVIVHNo`0001?o
IVIV00?o0000ogmoOomoOgl0=omoOgl6ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool01?oooon>ogmoO`03
o`000?mVIVKoIVIV013oIVIV00?o0000oda<C?m<C4`05om<C4`Io`0001goC4a<00?o0000ofIVI_mV
IVH03omVIVH2o`0003[oOgmo1_ooool1o`00007ooooo000:ooooo`03o`000?oooooooooo00;ooooo
00Go0000ooooooooooooooooo`000006ooooo`?o00001?oooon>ogmoO`03o`000?mVIVKoIVIV00ko
IVIV0_l0000Boda<C2oo00004?m<C4`00ol0003oIVIVofIVIP0=ofIVIP03o`000?moOgooOgmo03[o
Ogmo1?ooool3o`00007ooooo000:ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`000006ooooo`03o`000?oooooooooo00CoooooSomoOgl2o`0000goIVIV00?o0000oda<C?m<
C4`03?m<C4`6o`0002oo<c<c1_l0000;oda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomo
Ogl0>omoOgl6ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooo
oooooooooooo410@00Kooooo00?o0000ooooooooool01?oooonAogmoO`;o00002_mVIVH2o`0000[o
C4a<1?l0000>oc<c<ago00004?lc<c<2o`0000[oC4a<00?o0000ofIVI_mVIVH02OmVIVH00ol0003o
OgmoogmoO`0logmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`04oooooi?oOgmo00?o0000ofIVI_mV
IVH02OmVIVH00ol0003oC4a<oda<C007oda<C003o`000?lc<c?o<c<c00oo<c<c00?o0000oaTI6OlI
6AT06OlI6AT00ol0003o<c<coc<c<`0?oc<c<`03o`000?m<C4coC4a<00OoC4a<00?o0000ofIVI_mV
IVH02OmVIVH00ol0003oOgmoogmoO`0mogmoO`Kooooo0Ol00001ooooo`002?ooool00omEEEGoIVIV
o`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`04oooooiCo
Ogmo00?o0000ofIVI_mVIVH02OmVIVH2o`0000OoC4a<0_l0000@oc<c<`03o`000?lI6AWo6ATI01Wo
6ATI00?o0000oc<c<olc<c<03_lc<c<00ol0003oC4a<oda<C007oda<C003o`000?mVIVKoIVIV00So
IVIV0_l00010ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooiGoOgmo
0_l0000;ofIVIP03o`000?m<C4coC4a<00KoC4a<00?o0000oc<c<olc<c<03Olc<c<00ol0003o6ATI
oaTI6@0IoaTI6@03o`000?lc<c?o<c<c00go<c<c00?o0000oda<C?m<C4`01_m<C4`2o`0000SoIVIV
0ol00012ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooiOoOgmo0ol0
0009ofIVIP;o00001om<C4`2o`0000co<c<c00?o0000oaTI6OlI6AT06olI6AT00ol0003o<c<coc<c
<`0;oc<c<`03o`000?m<C4coC4a<00GoC4a<0_l00008ofIVIP;o0000AOmoOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?oooonJogmoO`;o00002OmVIVH2o`0000OoC4a<00?o0000
oc<c<olc<c<02Olc<c<00ol0003o6ATIoaTI6@0KoaTI6@03o`000?lc<c?o<c<c00[o<c<c00?o0000
oda<C?m<C4`01Om<C4`00ol0003oIVIVofIVIP06ofIVIP;o0000AomoOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?oooonLogmoO`;o00002OmVIVH00ol0003oC4a<oda<C005oda<
C003o`000?lc<c?o<c<c00So<c<c00?o0000oaTI6OlI6AT06olI6AT00ol0003o<c<coc<c<`08oc<c
<`;o00001_m<C4`2o`0000SoIVIV00?o0000ogmoOomoOgl0AomoOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?oooonNogmoO`Co00001_mVIVH00ol0003oC4a<oda<C005oda<C0?o
00001olc<c<3o`0001Oo6ATI1Ol00006oc<c<`Co00001_m<C4`2o`0000SoIVIV0_l0001:ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooj;oOgmo0ol00004ofIVIP;o0000
2?m<C4`3o`0000Oo<c<c2ol00005oaTI6@Oo00002?lc<c<3o`0000WoC4a<00?o0000ofIVI_mVIVH0
1?mVIVH4o`0004coOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooYOmo
Ogl2o`0000CoIVIV0_l00009oda<C0Go00003Olc<c<5o`0000co<c<c0ol0000:oda<C0;o00001?mV
IVH3o`00053oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooYomoOgl2
o`0000CoIVIV00?o0000oda<C?m<C4`02om<C4`6o`0000co<c<c3?l0000<oda<C004o`000?mVIVKo
IVIVofIVIP?o0000DomoOgl6ooooo`7o00000Oooool001[ooooo0_l00005oooooi;oOgmo2?l0000?
ogmoO`?o00000_mVIVH2o`0000?oC4a<2?l00006oda<C0co00003Om<C4`;o`0000;oIVIV0_l0000;
ogmoO`go0000?_moOgl5ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool01?oooon?ogmo
O`?o00002?nIVIT=o`0000GoOgmo0ol000001?mVIVKo0000o`000?l00008ofIVIPgo00001Om<C4`=
o`0000_oIVIV0_l00007ogmoO`Ko00003OnIVIT3o`0003_oOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CoooooS_moOgl00ol0003oVIVIoiVIV@0FoiVIV@;o00001_moOgl=o`00
00coIVIV1Ol0000;ofIVIPgo00000_moOgl7o`0001KoVIVI00?o0000ogmoOomoOgl0>?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon>ogmoO`03o`000?nIVIWoVIVI01So
VIVI1Ol0000>ogmoOaco00002OmoOgl6o`0001goVIVI00?o0000ogmoOomoOgl0>?moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?oooon?ogmoO`03o`000?nIVIWoVIVI01coVIVI
3Ol0000OogmoO`Oo00008_nIVIT00ol0003oOgmoogmoO`0iogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooohooOgmo00?o0000oiVIVOnIVIT0:OnIVITOo`0002SoVIVI00?o
0000ogmoOomoOgl0>_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon@
ogmoO`03o`000?nIVIWoVIVI06koVIVI00?o0000ogmoOomoOgl0>omoOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?oooonAogmoO`03o`000?nIVIWoVIVI01WoVIVI5?l0000<oiVI
VA_o00006OnIVIT00ol0003oOgmoogmoO`0kogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04oooooi;oOgmo00?o0000oiVIVOnIVIT04onIVIT5o`0001Co/k>c3?l0000Kok>c/`Co
00005?nIVIT00ol0003oOgmoogmoO`0logmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04oooooi?oOgmo00?o0000oiVIVOnIVIT04?nIVIT2o`0004Co/k>c00?o0000oiVIVOnIVIT0
4?nIVIT00ol0003oOgmoogmoO`0mogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04oooooiCoOgmo00?o0000oiVIVOnIVIT03onIVIT00ol0003o/k>cok>c/`12ok>c/`03o`000?nI
VIWoVIVI017oVIVI00?o0000ogmoOomoOgl0?OmoOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?oooonEogmoO`;o00004?nIVIT00ol0003o/k>cok>c/`0ook>c/`;o00004_nIVIT2
o`00043oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OoooonGogmoO`;o00003onIVIT00ol0
003o/k>cok>c/`0mok>c/`03o`000?nIVIWoVIVI00ooVIVI0ol00012ogmoO`Gooooo0_l00001oooo
o`006_ooool00ol0003oooooooooo`04oooooiWoOgmo00?o0000oiVIVOnIVIT03OnIVIT2o`0003_o
/k>c0_l0000@oiVIV@;o0000AOmoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?oooonJogmoO`;o00003onIVIT3o`0003Oo/k>c00?o0000oiVIVOnIVIT03_nIVIT2o`0004OoOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooW?moOgl4o`0000koVIVI0_l0
000cok>c/`;o00003_nIVIT3o`0004WoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CoooooX?moOgl3o`0000goVIVI0ol0000]ok>c/`?o00003onIVIT00ol0003oOgmoogmoO`1:
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooj?oOgmo0_l0000>oiVI
V@?o0000:?nc/k<2o`0000ooVIVI0ol0001=ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooojGoOgmo0_l0000?oiVIV@Go00007onc/k<4o`0000koVIVI0ol0001@ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooojOoOgmo0_l0000BoiVIV@Ko0000
4onc/k<6o`0000ooVIVI0ol0001CogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooojWoOgmo0ol0000EoiVIVA?o00004onIVIT2o`0005KoOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00Cooooo[?moOgl3o`0003KoVIVI0_l0001HogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooojooOgmo1_l0000ZoiVIV@Ko0000F_moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooneogmoO`Ko00001OnIVITEo`0000Go
VIVI1Ol0001PogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooook_oOgmo
1Ol0000EogmoO`Go0000IOmoOgl6ooooo`7o00000Oooool001[ooooo0_l00005ooooooooOgmo@?mo
Ogl5ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
oooookGoOgmo3?l0000CogmoO`[o0000HOmoOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?oooondogmoO`03o`000?mVIVKoIVIV00[oIVIV4ol00009ofIVIP03o`000?moOgooOgmo
05ooOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo/omoOgl00ol0003o
IVIVofIVIP0XofIVIP03o`000?moOgooOgmo05koOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00Cooooo/_moOgl00ol0003oIVIVofIVIP0ZofIVIP03o`000?moOgooOgmo05goOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo/OmoOgl2o`0002coIVIV0_l0
001NogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooook?oOgmo0ol0000V
ofIVIP?o0000H?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonfogmo
O`Go00007_mVIVH3o`0006?oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OoooonkogmoO`Ko
00004omVIVH5o`0006KoOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
`OmoOglCo`0006_oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooooomo
Ogm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
ooooOgmo@?moOgl6ooooo`7o00000Oooool000Oooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000Oo
oooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool0
0ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000Sooooo00?oV9RHob4Q
8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool01?oooooo
ogmoOd3oOgmo1_ooool1o`00007ooooo0009ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooo
ooooooooooooo`000006ooooo`?o00001?ooooooogmoOd3oOgmo1?ooool3o`00007ooooo000:oooo
o`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
oooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002oooool01Ol0003ooooooooooooooooo
410@00?ooooo00?o410@ooooooooool01?ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6
ooooo`7o00000Oooool000Oooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Ooo
ool000Oooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
ooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3o
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Joooo
o`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo
@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooo
ogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo
000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
ooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3o
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooooomo
Ogm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00
007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooo
ogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo
@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_oo
ool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007ooooo000Joooo
o`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooooomo
Ogm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo0007ooooo`05oiRHV?l@413o
0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0
1?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo0007ooooo`05oa0@4?nj^[[oooooogMgMolb<S80
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3o
Ogmo1_ooool1o`00007ooooo000;ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413o
ooooooooo`04ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`00
2_ooool00onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool3o`0000Co
oooooomoOgm0ogmoO`Cooooo0ol00001ooooo`002Oooool00ol@413o0000okZj^P03ooooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool000[ooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@00Ko
oooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo0007ooooo`05oa0@
4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000oooo
ooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo0007ooooo`05ojVYZOl@413o0000oa0@
4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool01?oooooo
ogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo
0_l00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooooomo
Ogm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000GooooooomoOgm0ogmo
O`Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo
@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000Gooooooomo
Ogm0ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
ooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3o
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000Go
oooooomoOgm0ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo
@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooo
ogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmo
O`Kooooo0Ol00001ooooo`002Oooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb
<S;ok^k^00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000:
ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`001oooool5o`0000?ooooo00Go410@
oooooooooooooooooa0@4006ooooo`?o00001?ooooooogmoOd3oOgmo1?ooool3o`00007ooooo0007
ooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo0?ooooooB_ooool1o`00007ooooo0007ooooo`04omgMgOmEEEGoooooo`0000Cooooo
00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?ooooooB_ooool1o`00007o
oooo0008ooooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooooooooa0@4006ooooo`03
o`000?oooooooooo0?ooooooB_ooool1o`00007ooooo0008ooooo`03onk^k_m4A4Co000000Cooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?ooooooB_ooool1o`00007o
oooo0009ooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0mooooo`03
o`000?oooooooooo03gooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Sooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`7o0000
0Oooool001[oooooool0001>o`00007ooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-30.1723, -14.304, 0.195672, \
0.195672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0192308 0.211538 0.0192308 [
[.11538 -0.0125 -9 -9 ]
[.11538 -0.0125 9 0 ]
[.30769 -0.0125 -9 -9 ]
[.30769 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69231 -0.0125 -6 -9 ]
[.69231 -0.0125 6 0 ]
[.88462 -0.0125 -6 -9 ]
[.88462 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -18 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .21154 -6 -4.5 ]
[-0.0125 .21154 0 4.5 ]
[-0.0125 .40385 -12 -4.5 ]
[-0.0125 .40385 0 4.5 ]
[-0.0125 .59615 -12 -4.5 ]
[-0.0125 .59615 0 4.5 ]
[-0.0125 .78846 -12 -4.5 ]
[-0.0125 .78846 0 4.5 ]
[-0.0125 .98077 -12 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11538 0 m
.11538 .00625 L
s
[(-20)] .11538 -0.0125 0 1 Mshowa
.30769 0 m
.30769 .00625 L
s
[(-10)] .30769 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69231 0 m
.69231 .00625 L
s
[(10)] .69231 -0.0125 0 1 Mshowa
.88462 0 m
.88462 .00625 L
s
[(20)] .88462 -0.0125 0 1 Mshowa
.125 Mabswid
.15385 0 m
.15385 .00375 L
s
.19231 0 m
.19231 .00375 L
s
.23077 0 m
.23077 .00375 L
s
.26923 0 m
.26923 .00375 L
s
.34615 0 m
.34615 .00375 L
s
.38462 0 m
.38462 .00375 L
s
.42308 0 m
.42308 .00375 L
s
.46154 0 m
.46154 .00375 L
s
.53846 0 m
.53846 .00375 L
s
.57692 0 m
.57692 .00375 L
s
.61538 0 m
.61538 .00375 L
s
.65385 0 m
.65385 .00375 L
s
.73077 0 m
.73077 .00375 L
s
.76923 0 m
.76923 .00375 L
s
.80769 0 m
.80769 .00375 L
s
.84615 0 m
.84615 .00375 L
s
.07692 0 m
.07692 .00375 L
s
.03846 0 m
.03846 .00375 L
s
.92308 0 m
.92308 .00375 L
s
.96154 0 m
.96154 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(-10)] -0.0125 .01923 1 0 Mshowa
0 .21154 m
.00625 .21154 L
s
[(0)] -0.0125 .21154 1 0 Mshowa
0 .40385 m
.00625 .40385 L
s
[(10)] -0.0125 .40385 1 0 Mshowa
0 .59615 m
.00625 .59615 L
s
[(20)] -0.0125 .59615 1 0 Mshowa
0 .78846 m
.00625 .78846 L
s
[(30)] -0.0125 .78846 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(40)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .05769 m
.00375 .05769 L
s
0 .09615 m
.00375 .09615 L
s
0 .13462 m
.00375 .13462 L
s
0 .17308 m
.00375 .17308 L
s
0 .25 m
.00375 .25 L
s
0 .28846 m
.00375 .28846 L
s
0 .32692 m
.00375 .32692 L
s
0 .36538 m
.00375 .36538 L
s
0 .44231 m
.00375 .44231 L
s
0 .48077 m
.00375 .48077 L
s
0 .51923 m
.00375 .51923 L
s
0 .55769 m
.00375 .55769 L
s
0 .63462 m
.00375 .63462 L
s
0 .67308 m
.00375 .67308 L
s
0 .71154 m
.00375 .71154 L
s
0 .75 m
.00375 .75 L
s
0 .82692 m
.00375 .82692 L
s
0 .86538 m
.00375 .86538 L
s
0 .90385 m
.00375 .90385 L
s
0 .94231 m
.00375 .94231 L
s
.25 Mabswid
0 0 m
0 1 L
s
.11538 .99375 m
.11538 1 L
s
.30769 .99375 m
.30769 1 L
s
.5 .99375 m
.5 1 L
s
.69231 .99375 m
.69231 1 L
s
.88462 .99375 m
.88462 1 L
s
.125 Mabswid
.15385 .99625 m
.15385 1 L
s
.19231 .99625 m
.19231 1 L
s
.23077 .99625 m
.23077 1 L
s
.26923 .99625 m
.26923 1 L
s
.34615 .99625 m
.34615 1 L
s
.38462 .99625 m
.38462 1 L
s
.42308 .99625 m
.42308 1 L
s
.46154 .99625 m
.46154 1 L
s
.53846 .99625 m
.53846 1 L
s
.57692 .99625 m
.57692 1 L
s
.61538 .99625 m
.61538 1 L
s
.65385 .99625 m
.65385 1 L
s
.73077 .99625 m
.73077 1 L
s
.76923 .99625 m
.76923 1 L
s
.80769 .99625 m
.80769 1 L
s
.84615 .99625 m
.84615 1 L
s
.07692 .99625 m
.07692 1 L
s
.03846 .99625 m
.03846 1 L
s
.92308 .99625 m
.92308 1 L
s
.96154 .99625 m
.96154 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .21154 m
1 .21154 L
s
.99375 .40385 m
1 .40385 L
s
.99375 .59615 m
1 .59615 L
s
.99375 .78846 m
1 .78846 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .05769 m
1 .05769 L
s
.99625 .09615 m
1 .09615 L
s
.99625 .13462 m
1 .13462 L
s
.99625 .17308 m
1 .17308 L
s
.99625 .25 m
1 .25 L
s
.99625 .28846 m
1 .28846 L
s
.99625 .32692 m
1 .32692 L
s
.99625 .36538 m
1 .36538 L
s
.99625 .44231 m
1 .44231 L
s
.99625 .48077 m
1 .48077 L
s
.99625 .51923 m
1 .51923 L
s
.99625 .55769 m
1 .55769 L
s
.99625 .63462 m
1 .63462 L
s
.99625 .67308 m
1 .67308 L
s
.99625 .71154 m
1 .71154 L
s
.99625 .75 m
1 .75 L
s
.99625 .82692 m
1 .82692 L
s
.99625 .86538 m
1 .86538 L
s
.99625 .90385 m
1 .90385 L
s
.99625 .94231 m
1 .94231 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.4 g
.45094 .41038 m
.47057 .40607 L
.49019 .41116 L
.49544 .4117 L
.50981 .41418 L
.52943 .41749 L
.54906 .41481 L
.56868 .42123 L
.5883 .42491 L
.60793 .42717 L
.62755 .4282 L
.64717 .42804 L
.6668 .42667 L
.68642 .42404 L
.70604 .41983 L
.72567 .41964 L
.74529 .41659 L
.76491 .41322 L
.77381 .4117 L
.78454 .41014 L
.80416 .40861 L
.82128 .4117 L
.81679 .43132 L
.80416 .44142 L
.78813 .45094 L
.78454 .45291 L
.76491 .46582 L
.74529 .46838 L
.73785 .47057 L
.72567 .47406 L
.70604 .47579 L
.68642 .4803 L
.6668 .48328 L
.64717 .4848 L
.62755 .48499 L
.60793 .48384 L
.5883 .48129 L
.56868 .4772 L
.54906 .47188 L
.53127 .47057 L
.52943 .47004 L
.50981 .46368 L
.49019 .45608 L
.48113 .45094 L
.47057 .44498 L
.45228 .43132 L
.45094 .42961 L
.44738 .4117 L
F
0 g
.45094 .41038 m
.47057 .40607 L
.49019 .41116 L
.49544 .4117 L
.50981 .41418 L
.52943 .41749 L
.54906 .41481 L
.56868 .42123 L
.5883 .42491 L
.60793 .42717 L
.62755 .4282 L
.64717 .42804 L
.6668 .42667 L
.68642 .42404 L
.70604 .41983 L
.72567 .41964 L
.74529 .41659 L
.76491 .41322 L
.77381 .4117 L
.78454 .41014 L
.80416 .40861 L
.82128 .4117 L
.81679 .43132 L
.80416 .44142 L
.78813 .45094 L
.78454 .45291 L
.76491 .46582 L
.74529 .46838 L
.73785 .47057 L
.72567 .47406 L
.70604 .47579 L
.68642 .4803 L
.6668 .48328 L
.64717 .4848 L
.62755 .48499 L
.60793 .48384 L
.5883 .48129 L
.56868 .4772 L
.54906 .47188 L
.53127 .47057 L
.52943 .47004 L
.50981 .46368 L
.49019 .45608 L
.48113 .45094 L
.47057 .44498 L
.45228 .43132 L
.45094 .42961 L
.44738 .4117 L
.45094 .41038 L
s
.6 g
.47057 .35863 m
.49019 .35767 L
.50981 .35913 L
.52943 .35709 L
.54906 .36561 L
.56868 .36539 L
.5883 .367 L
.60793 .36811 L
.62755 .36864 L
.64717 .36856 L
.6668 .36786 L
.68642 .3666 L
.70604 .37071 L
.72567 .36365 L
.74529 .36062 L
.76491 .35862 L
.78454 .35755 L
.80416 .36025 L
.81033 .37245 L
.80416 .37892 L
.78535 .39207 L
.78454 .39285 L
.76491 .4007 L
.74529 .40715 L
.7287 .4117 L
.72567 .41245 L
.70604 .41551 L
.68642 .41989 L
.6668 .42329 L
.64717 .42529 L
.62755 .42555 L
.60793 .42401 L
.5883 .42096 L
.56868 .4168 L
.54906 .41238 L
.54057 .4117 L
.52943 .40874 L
.50981 .40263 L
.49019 .39793 L
.48419 .39207 L
.47057 .38333 L
.45886 .37245 L
F
0 g
.47057 .35863 m
.49019 .35767 L
.50981 .35913 L
.52943 .35709 L
.54906 .36561 L
.56868 .36539 L
.5883 .367 L
.60793 .36811 L
.62755 .36864 L
.64717 .36856 L
.6668 .36786 L
.68642 .3666 L
.70604 .37071 L
.72567 .36365 L
.74529 .36062 L
.76491 .35862 L
.78454 .35755 L
.80416 .36025 L
.81033 .37245 L
.80416 .37892 L
.78535 .39207 L
.78454 .39285 L
.76491 .4007 L
.74529 .40715 L
.7287 .4117 L
.72567 .41245 L
.70604 .41551 L
.68642 .41989 L
.6668 .42329 L
.64717 .42529 L
.62755 .42555 L
.60793 .42401 L
.5883 .42096 L
.56868 .4168 L
.54906 .41238 L
.54057 .4117 L
.52943 .40874 L
.50981 .40263 L
.49019 .39793 L
.48419 .39207 L
.47057 .38333 L
.45886 .37245 L
.47057 .35863 L
s
.6 g
.47057 .47577 m
.49019 .4764 L
.50981 .47934 L
.52943 .48254 L
.54906 .48115 L
.56868 .48672 L
.5883 .4897 L
.5923 .49019 L
.60793 .49126 L
.62755 .49197 L
.64717 .49185 L
.6668 .49092 L
.67671 .49019 L
.68642 .48903 L
.70604 .48553 L
.72567 .48468 L
.74529 .48166 L
.76491 .47845 L
.78454 .47581 L
.80416 .47744 L
.8056 .49019 L
.80416 .49201 L
.78454 .50825 L
.78212 .50981 L
.76491 .52627 L
.74529 .52794 L
.74116 .52943 L
.72567 .53313 L
.70604 .53918 L
.68642 .54395 L
.6668 .54692 L
.64717 .54825 L
.62755 .54839 L
.60793 .54744 L
.5883 .54496 L
.56868 .54069 L
.54906 .53487 L
.52943 .5296 L
.52807 .52943 L
.50981 .52216 L
.49019 .51219 L
.48718 .50981 L
.47057 .49756 L
.46364 .49019 L
F
0 g
.47057 .47577 m
.49019 .4764 L
.50981 .47934 L
.52943 .48254 L
.54906 .48115 L
.56868 .48672 L
.5883 .4897 L
.5923 .49019 L
.60793 .49126 L
.62755 .49197 L
.64717 .49185 L
.6668 .49092 L
.67671 .49019 L
.68642 .48903 L
.70604 .48553 L
.72567 .48468 L
.74529 .48166 L
.76491 .47845 L
.78454 .47581 L
.80416 .47744 L
.8056 .49019 L
.80416 .49201 L
.78454 .50825 L
.78212 .50981 L
.76491 .52627 L
.74529 .52794 L
.74116 .52943 L
.72567 .53313 L
.70604 .53918 L
.68642 .54395 L
.6668 .54692 L
.64717 .54825 L
.62755 .54839 L
.60793 .54744 L
.5883 .54496 L
.56868 .54069 L
.54906 .53487 L
.52943 .5296 L
.52807 .52943 L
.50981 .52216 L
.49019 .51219 L
.48718 .50981 L
.47057 .49756 L
.46364 .49019 L
.47057 .47577 L
s
.4 g
.50981 .31475 m
.52943 .31411 L
.54906 .31474 L
.56868 .31568 L
.5883 .31656 L
.60793 .3172 L
.62755 .31751 L
.64717 .31746 L
.6668 .31705 L
.68642 .31633 L
.70604 .31541 L
.72567 .31451 L
.74529 .31409 L
.76491 .31552 L
.77522 .3332 L
.76491 .339 L
.74529 .34735 L
.7289 .35283 L
.72567 .35406 L
.70604 .36335 L
.68642 .3602 L
.6668 .36207 L
.64717 .36307 L
.62755 .36319 L
.60793 .36244 L
.5883 .36081 L
.56868 .35829 L
.54906 .35631 L
.54036 .35283 L
.52943 .34933 L
.50981 .34157 L
.49393 .3332 L
F
0 g
.50981 .31475 m
.52943 .31411 L
.54906 .31474 L
.56868 .31568 L
.5883 .31656 L
.60793 .3172 L
.62755 .31751 L
.64717 .31746 L
.6668 .31705 L
.68642 .31633 L
.70604 .31541 L
.72567 .31451 L
.74529 .31409 L
.76491 .31552 L
.77522 .3332 L
.76491 .339 L
.74529 .34735 L
.7289 .35283 L
.72567 .35406 L
.70604 .36335 L
.68642 .3602 L
.6668 .36207 L
.64717 .36307 L
.62755 .36319 L
.60793 .36244 L
.5883 .36081 L
.56868 .35829 L
.54906 .35631 L
.54036 .35283 L
.52943 .34933 L
.50981 .34157 L
.49393 .3332 L
.50981 .31475 L
s
.3 g
.50981 .42856 m
.52943 .42692 L
.54906 .4232 L
.56868 .42746 L
.5883 .42955 L
.60793 .43064 L
.62755 .43105 L
.64717 .43098 L
.6668 .43041 L
.68642 .42908 L
.70604 .4266 L
.72567 .42726 L
.74529 .42701 L
.76491 .4304 L
.76661 .43132 L
.76491 .44091 L
.75457 .45094 L
.74529 .45608 L
.72567 .46415 L
.70604 .47007 L
.70415 .47057 L
.68642 .47405 L
.6668 .47736 L
.64717 .47928 L
.62755 .47952 L
.60793 .47806 L
.5883 .47509 L
.56868 .47124 L
.5651 .47057 L
.54906 .46599 L
.52943 .45863 L
.51463 .45094 L
.50981 .44697 L
.50238 .43132 L
F
0 g
.50981 .42856 m
.52943 .42692 L
.54906 .4232 L
.56868 .42746 L
.5883 .42955 L
.60793 .43064 L
.62755 .43105 L
.64717 .43098 L
.6668 .43041 L
.68642 .42908 L
.70604 .4266 L
.72567 .42726 L
.74529 .42701 L
.76491 .4304 L
.76661 .43132 L
.76491 .44091 L
.75457 .45094 L
.74529 .45608 L
.72567 .46415 L
.70604 .47007 L
.70415 .47057 L
.68642 .47405 L
.6668 .47736 L
.64717 .47928 L
.62755 .47952 L
.60793 .47806 L
.5883 .47509 L
.56868 .47124 L
.5651 .47057 L
.54906 .46599 L
.52943 .45863 L
.51463 .45094 L
.50981 .44697 L
.50238 .43132 L
.50981 .42856 L
s
.7 g
.54906 .3719 m
.56868 .37236 L
.57275 .37245 L
.5883 .37306 L
.60793 .37364 L
.62755 .37393 L
.64717 .37388 L
.6668 .3735 L
.68642 .37286 L
.69784 .37245 L
.70604 .37235 L
.72567 .3718 L
.73771 .37245 L
.74529 .37348 L
.75205 .39207 L
.74529 .39591 L
.72567 .40411 L
.70604 .41005 L
.6994 .4117 L
.68642 .41466 L
.6668 .41864 L
.64717 .42115 L
.62755 .42148 L
.60793 .41953 L
.5883 .41587 L
.56989 .4117 L
.56868 .41141 L
.54906 .40596 L
.52943 .39852 L
.51717 .39207 L
.52943 .37264 L
.53142 .37245 L
F
0 g
.54906 .3719 m
.56868 .37236 L
.57275 .37245 L
.5883 .37306 L
.60793 .37364 L
.62755 .37393 L
.64717 .37388 L
.6668 .3735 L
.68642 .37286 L
.69784 .37245 L
.70604 .37235 L
.72567 .3718 L
.73771 .37245 L
.74529 .37348 L
.75205 .39207 L
.74529 .39591 L
.72567 .40411 L
.70604 .41005 L
.6994 .4117 L
.68642 .41466 L
.6668 .41864 L
.64717 .42115 L
.62755 .42148 L
.60793 .41953 L
.5883 .41587 L
.56989 .4117 L
.56868 .41141 L
.54906 .40596 L
.52943 .39852 L
.51717 .39207 L
.52943 .37264 L
.53142 .37245 L
.54906 .3719 L
s
.2 g
.54906 .43895 m
.56868 .4364 L
.5883 .43612 L
.60793 .43629 L
.62755 .43643 L
.64717 .43641 L
.6668 .43623 L
.68642 .43612 L
.70604 .43671 L
.72538 .45094 L
.70604 .46054 L
.68642 .4664 L
.6668 .4701 L
.66327 .47057 L
.64717 .47233 L
.62755 .47262 L
.60793 .47085 L
.60552 .47057 L
.5883 .46763 L
.56868 .46244 L
.54906 .45422 L
.54383 .45094 L
F
0 g
.54906 .43895 m
.56868 .4364 L
.5883 .43612 L
.60793 .43629 L
.62755 .43643 L
.64717 .43641 L
.6668 .43623 L
.68642 .43612 L
.70604 .43671 L
.72538 .45094 L
.70604 .46054 L
.68642 .4664 L
.6668 .4701 L
.66327 .47057 L
.64717 .47233 L
.62755 .47262 L
.60793 .47085 L
.60552 .47057 L
.5883 .46763 L
.56868 .46244 L
.54906 .45422 L
.54383 .45094 L
.54906 .43895 L
s
.8 g
.54906 .38571 m
.56868 .38082 L
.5883 .37972 L
.60793 .37946 L
.62755 .37941 L
.64717 .37942 L
.6668 .37949 L
.68642 .3799 L
.70604 .38149 L
.72338 .39207 L
.70604 .40142 L
.68642 .40753 L
.6668 .41128 L
.6637 .4117 L
.64717 .41403 L
.62755 .41442 L
.60793 .41213 L
.60502 .4117 L
.5883 .40879 L
.56868 .40343 L
.54906 .39445 L
.54587 .39207 L
F
0 g
.54906 .38571 m
.56868 .38082 L
.5883 .37972 L
.60793 .37946 L
.62755 .37941 L
.64717 .37942 L
.6668 .37949 L
.68642 .3799 L
.70604 .38149 L
.72338 .39207 L
.70604 .40142 L
.68642 .40753 L
.6668 .41128 L
.6637 .4117 L
.64717 .41403 L
.62755 .41442 L
.60793 .41213 L
.60502 .4117 L
.5883 .40879 L
.56868 .40343 L
.54906 .39445 L
.54587 .39207 L
.54906 .38571 L
s
.6 g
.56868 .27848 m
.5883 .27688 L
.60793 .27633 L
.62755 .27616 L
.64717 .27618 L
.6668 .27643 L
.68642 .27717 L
.70604 .27937 L
.71506 .29396 L
.70604 .29663 L
.68642 .30092 L
.6668 .30368 L
.64717 .30512 L
.62755 .3053 L
.60793 .30421 L
.5883 .30183 L
.56868 .29801 L
.55416 .29396 L
F
0 g
.56868 .27848 m
.5883 .27688 L
.60793 .27633 L
.62755 .27616 L
.64717 .27618 L
.6668 .27643 L
.68642 .27717 L
.70604 .27937 L
.71506 .29396 L
.70604 .29663 L
.68642 .30092 L
.6668 .30368 L
.64717 .30512 L
.62755 .3053 L
.60793 .30421 L
.5883 .30183 L
.56868 .29801 L
.55416 .29396 L
.56868 .27848 L
s
.3 g
.56868 .3293 m
.5883 .32753 L
.60793 .32691 L
.62755 .32672 L
.64717 .32674 L
.6668 .32702 L
.68642 .32785 L
.70604 .33029 L
.71492 .3332 L
.70604 .345 L
.68642 .3525 L
.68534 .35283 L
.6668 .35543 L
.64717 .35686 L
.62755 .35703 L
.60793 .35596 L
.5883 .35355 L
.58392 .35283 L
.56868 .34768 L
.5543 .3332 L
F
0 g
.56868 .3293 m
.5883 .32753 L
.60793 .32691 L
.62755 .32672 L
.64717 .32674 L
.6668 .32702 L
.68642 .32785 L
.70604 .33029 L
.71492 .3332 L
.70604 .345 L
.68642 .3525 L
.68534 .35283 L
.6668 .35543 L
.64717 .35686 L
.62755 .35703 L
.60793 .35596 L
.5883 .35355 L
.58392 .35283 L
.56868 .34768 L
.5543 .3332 L
.56868 .3293 L
s
.7 g
.56868 .50318 m
.5883 .50231 L
.60793 .50235 L
.62755 .50247 L
.64717 .50245 L
.6668 .50232 L
.68642 .50239 L
.70604 .50403 L
.71451 .50981 L
.70604 .51598 L
.68642 .52345 L
.6668 .52775 L
.65345 .52943 L
.64717 .5303 L
.62755 .53079 L
.61579 .52943 L
.60793 .52856 L
.5883 .5249 L
.56868 .51857 L
.5547 .50981 L
F
0 g
.56868 .50318 m
.5883 .50231 L
.60793 .50235 L
.62755 .50247 L
.64717 .50245 L
.6668 .50232 L
.68642 .50239 L
.70604 .50403 L
.71451 .50981 L
.70604 .51598 L
.68642 .52345 L
.6668 .52775 L
.65345 .52943 L
.64717 .5303 L
.62755 .53079 L
.61579 .52943 L
.60793 .52856 L
.5883 .5249 L
.56868 .51857 L
.5547 .50981 L
.56868 .50318 L
s
.1 g
.5883 .44629 m
.60793 .44405 L
.62755 .44347 L
.64717 .44355 L
.6668 .44441 L
.68642 .44798 L
.69035 .45094 L
.68642 .45391 L
.6668 .46071 L
.64717 .46353 L
.62755 .46386 L
.60793 .46179 L
.5883 .45653 L
.57869 .45094 L
F
0 g
.5883 .44629 m
.60793 .44405 L
.62755 .44347 L
.64717 .44355 L
.6668 .44441 L
.68642 .44798 L
.69035 .45094 L
.68642 .45391 L
.6668 .46071 L
.64717 .46353 L
.62755 .46386 L
.60793 .46179 L
.5883 .45653 L
.57869 .45094 L
.5883 .44629 L
s
.9 g
.5883 .38897 m
.60793 .38658 L
.62755 .3859 L
.64717 .386 L
.6668 .38698 L
.68642 .39059 L
.6894 .39207 L
.68642 .3956 L
.6668 .40311 L
.64717 .40603 L
.62755 .40637 L
.60793 .40423 L
.5883 .39863 L
.57963 .39207 L
F
0 g
.5883 .38897 m
.60793 .38658 L
.62755 .3859 L
.64717 .386 L
.6668 .38698 L
.68642 .39059 L
.6894 .39207 L
.68642 .3956 L
.6668 .40311 L
.64717 .40603 L
.62755 .40637 L
.60793 .40423 L
.5883 .39863 L
.57963 .39207 L
.5883 .38897 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00?Oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0dooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kS?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0hooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8b
onk^kS?ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08_ooool003gooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0=_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0<oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg03?ooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL08_ooool003Gooooo1_l0
0003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400[ooooo`Ko0000
1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100<oooool01Ol@413o
oooooooooooooooo410@03[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@03Cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@02;ooooo000o
ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000fooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000cooooo`05o`000?ooooooooooooooool0
0000>_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000=Oooool00onH
V9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000008_ooool0043ooooo00?oMgMgofIV
I_ooool00_ooool01Ol0003ooooooooooooooooo000003Kooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000003?ooooo00Go0000ooooooooooooooooo`00000jooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`03ogMgMomVIVKooooo00;o
oooo00Go0000ooooooooooooooooo`00000Rooooo`00@Oooool01Ol0003ooooooooooooooooo410@
00?ooooo00?o410@ooooooooool0=?ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@4100<oooool01Ol@413ooooooooooooooooo410@03[ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@03Oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo023ooooo000mooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg03Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg03?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0jooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0cooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02;ooooo000mooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^03Cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^03?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`03oeEEEOmVIVKo000000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0cooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02;ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo000Joooooooo0000C_l00001ooooo`00
6_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0?Ooo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool08ooo
ool1o`00007ooooo0008ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKo
oooo00?o0000ooooooooool0oooooom:ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooom:ooooo`7o
00000Oooool000Go00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41001_ooool00ol0003oooooooooo`3ooooood[ooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?ooooooB?ooool3o`00007o
oooo000:ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo0008ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Oooooooogmo
Od3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Ooo
ooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000oooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`003ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000?ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000oooooo00Go0000oooooooooooooooo
o`000006ooooo`?o00001?ooooooogmoOd3oOgmo1?ooool3o`00007ooooo000?ooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool000oooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`003oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000?ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooo0ogmoOa_o0000I?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?oooonfogmoO`[o00006onIVIT:o`0005[oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00Cooooo]OmoOgl00ol0003oVIVIoiVIV@0/oiVIV@03o`000?moOgooOgmo05So
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo]?moOgl00ol0003oVIVI
oiVIV@0^oiVIV@03o`000?moOgooOgmo05OoOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Ooo
ooncogmoO`03o`000?nIVIWoVIVI033oVIVI00?o0000ogmoOomoOgl0E_moOgl5ooooo`;o00000Ooo
ool001[ooooo00?o0000ooooooooool01?oooonbogmoO`03o`000?nIVIWoVIVI037oVIVI00?o0000
ogmoOomoOgl0E_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonaogmo
O`;o0000<onIVIT2o`0005OoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooo/omoOgl3o`0002coVIVI1?l0001IogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04oooookKoOgmo1Ol0000ToiVIV@?o0000GOmoOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?oooonkogmoO`Ko00004onIVIT;o`00063oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00Cooooo`OmoOglCo`0006_oOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?oooonSogmoOaSo00009_moOglGo`0004OoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CoooooX_moOgl00ol0003oIVIVofIVIP0FofIVIRKo00005_mVIVH00ol0003oOgmoogmo
O`15ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooj7oOgmo00?o0000
ofIVI_mVIVH0E?mVIVH00ol0003oOgmoogmoO`14ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04oooooj3oOgmo00?o0000ofIVI_mVIVH0E_mVIVH00ol0003oOgmoogmoO`13ogmo
O`Kooooo0Ol00001ooooo`006_ooool2o`0000GoooooWomoOgl00ol0003oIVIVofIVIP0HofIVIR7o
00007_mVIVH00ol0003oOgmoogmoO`13ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003ooooo
ooooo`04oooooikoOgmo00?o0000ofIVI_mVIVH04omVIVH6o`00027oC4a<3?l0000CofIVIP03o`00
0?moOgooOgmo04;oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooWOmo
Ogl2o`0001;oIVIV0ol0000coda<C003o`000?mVIVKoIVIV013oIVIV0_l00013ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04oooooiooOgmo0_l0000AofIVIP03o`000?m<C4co
C4a<03;oC4a<00?o0000ofIVI_mVIVH03_mVIVH2o`0004GoOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CoooooXOmoOgl2o`00013oIVIV00?o0000oda<C?m<C4`0<?m<C4`00ol0
003oIVIVofIVIP0=ofIVIP;o0000AomoOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?oooonSogmoO`;o00003omVIVH00ol0003oC4a<oda<C00^oda<C003o`000?mVIVKoIVIV00co
IVIV0_l00019ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooojGoOgmo
0_l0000>ofIVIP03o`000?m<C4coC4a<02_oC4a<0_l0000=ofIVIP;o0000BomoOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?oooonWogmoO`;o00003OmVIVH2o`0002SoC4a<0ol0
000=ofIVIP;o0000COmoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonY
ogmoO`?o00003?mVIVH3o`0002?oC4a<0_l0000=ofIVIP?o0000ComoOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?oooon/ogmoO`Co00002omVIVH6o`0001WoC4a<1?l0000;ofIV
IPCo0000D_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonIogmoO`So
00001OmoOgl5o`0000GoOgmo1?l0000=ofIVIQWo00003OmVIVH2o`0001;oOgmo1ol0000mogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooiGoOgmo1?l00008oiVIV@Go0000
1OnIVIT3o`0000KoOgmo3Ol0000IofIVIPSo00000omVIVH2o`0000OoOgmo3Ol00007oiVIV@?o0000
>_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonEogmoO`03o`000?nI
VIWoVIVI01KoVIVI0_l0000AogmoOaWo00002?moOgl3o`0000CoOgmo1Ol0000FoiVIV@03o`000?mo
OgooOgmo03SoOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OoooonDogmoO`03o`000?nIVIWo
VIVI01WoVIVI2ol0000OogmoO`Ko00001omoOgl2o`0001coVIVI00?o0000ogmoOomoOgl0=omoOgl5
ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool01?oooonCogmoO`03o`000?nIVIWoVIVI
02GoVIVI7ol00006oiVIV@?o00000_moOgl2o`0001koVIVI00?o0000ogmoOomoOgl0=omoOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonBogmoO`03o`000?nIVIWoVIVI01Co
VIVI4_l0000OoiVIVAOo00005OnIVIT00ol0003oOgmoogmoO`0fogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04oooooi;oOgmo00?o0000oiVIVOnIVIT05?nIVIT00ol0003o/k>c
ok>c/`0?ok>c/aoo00005onc/k<00ol0003oVIVIoiVIV@0AoiVIV@03o`000?moOgooOgmo03OoOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooTomoOgl00ol0003oVIVIoiVI
V@0BoiVIV@03o`000?nc/k?o/k>c04Ko/k>c00?o0000oiVIVOnIVIT03onIVIT2o`0003[oOgmo1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooU?moOgl00ol0003oVIVIoiVIV@0A
oiVIV@03o`000?nc/k?o/k>c00[o/k>c<Ol0000<ok>c/`03o`000?nIVIWoVIVI00goVIVI00?o0000
ogmoOomoOgl0>_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonEogmo
O`;o00004?nIVIT00ol0003o/k>cok>c/`08ok>c/`?o0000<Oo<c<`00ol0003o/k>cok>c/`09ok>c
/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl0>omoOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?oooonGogmoO`;o00003OnIVIT00ol0003o/k>cok>c/`07ok>c/`;o
00003_o<c<`Ko`0000coc<c<00?o0000ok>c/onc/k<02?nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03
o`000?moOgooOgmo03coOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
VOmoOgl00ol0003oVIVIoiVIV@0:oiVIV@03o`000?nc/k?o/k>c00Ko/k>c00?o0000olc<c?o<c<`0
2_o<c<`4o`0001_oi^KV0ol0000:olc<c003o`000?nc/k?o/k>c00So/k>c00?o0000oiVIVOnIVIT0
2OnIVIT00ol0003oOgmoogmoO`0mogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04oooooi[oOgmo00?o0000oiVIVOnIVIT02?nIVIT2o`0000Oo/k>c0_l0000:olc<c0;o00008_oV
i^H00ol0003oc<c<olc<c007olc<c0;o00002?nc/k<2o`0000WoVIVI0_l00010ogmoO`Kooooo0Ol0
0001ooooo`002?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h6ooooo`03
o`000?oooooooooo00CoooooVomoOgl00ol0003oVIVIoiVIV@09oiVIV@;o00001onc/k<2o`0000[o
c<c<00?o0000onKVi_oVi^H07OoVi^H2o`0000Soc<c<0_l00008ok>c/`;o00002?nIVIT3o`0004;o
Ogmo1_ooool1o`00007ooooo000:ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`06ooooo`03o`000?oooooooooo00CoooooW?moOgl5o`0000SoVIVI0ol00006ok>c/`;o
00002Oo<c<`3o`0001[oi^KV0_l00009olc<c003o`000?nc/k?o/k>c00Go/k>c0ol00008oiVIV@;o
0000AOmoOgl6ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooo
oooooooooooo410@00Kooooo00?o0000ooooooooool01?oooonQogmoO`Go00001_nIVIT3o`0000Go
/k>c0_l0000:olc<c0?o00005OoVi^H2o`0000Soc<c<0ol00006ok>c/`;o00002OnIVIT2o`0004Oo
Ogmo1_ooool1o`00007ooooo000:ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`000006ooooo`?o00001?oooonDogmoO`Co00003_moOgl3o`0000KoVIVI1?l00003ok>c/`Go
00002?o<c<`5o`0000Goi^KV2ol00007olc<c0?o00001onc/k<2o`0000SoVIVI0ol00019ogmoO`Co
oooo0ol00001ooooo`002_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
00001_ooool00ol0003oooooooooo`04oooooi7oOgmo0ol00004ofIVIP?o00003_moOgl3o`0000Oo
VIVI0ol00005ok>c/`Ko00001oo<c<`5o`0000goc<c<1Ol00007ok>c/`?o00001OnIVIT5o`0000ko
Ogmo1ol0000gogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003oooooooooo`02ooooo`05oa0@
4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`04ooooohkoOgmo0ol0000:ofIVIPOo
00002_moOgl4o`0000KoVIVI0ol00008ok>c/`;o00004?o<c<`7o`0000Go/k>c1ol00005oiVIV@?o
00002omoOgl8o`0000OoIVIV0ol0000dogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`04ooooohko
Ogmo00?o0000ofIVI_mVIVH04OmVIVH5o`0000KoOgmo1ol00005oiVIV@?o00001onc/k<@o`0000Wo
/k>c0ol00008oiVIV@Co00002OmoOgl5o`00017oIVIV00?o0000ogmoOomoOgl0<_moOgl6ooooo`7o
00000Oooool000Sooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Ko
oooo00?o0000ooooooooool01?oooon>ogmoO`03o`000?mVIVKoIVIV01KoIVIV1_l00005ofIVIPWo
000000?oVIVIo`000?l000000ol0000Hok>c/`?o00001OnIVIT6o`0000OoOgmo1_l0000FofIVIP03
o`000?moOgooOgmo03;oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
S_moOgl00ol0003oIVIVofIVIP0SofIVIP;o00001OmoOgl=o`0000co/k>c1Ol000000onIVIWo0000
o`00000Bo`0001_oIVIV00?o0000ogmoOomoOgl0<omoOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?oooon?ogmoO`03o`000?mVIVKoIVIV01_oIVIV1_l00003ofIVIPGo00001_mo
OglPo`0002SoIVIV00?o0000ogmoOomoOgl0<omoOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?oooon?ogmoO`03o`000?mVIVKoIVIV01CoIVIV1ol00006oda<C0?o00001OmVIVH6
o`0000OoOgmo4_l00007ofIVIPOo00001_mVIVH6o`0001GoIVIV00?o0000ogmoOomoOgl0<omoOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon?ogmoO`03o`000?mVIVKoIVIV
013oIVIV1?l0000@oda<C1ko00001_mVIVH7o`0000OoC4a<1_l00006oda<C0?o00004OmVIVH00ol0
003oOgmoogmoO`0dogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooohoo
Ogmo0_l0000?ofIVIP;o00007om<C4`Io`0001goC4a<0_l0000>ofIVIP;o0000=_moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?oooonAogmoO`03o`000?mVIVKoIVIV00coIVIV
00?o0000oda<C?m<C4`05om<C4`7o`0001WoC4a<2?l0000Foda<C003o`000?mVIVKoIVIV00_oIVIV
00?o0000ogmoOomoOgl0=_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
oonBogmoO`;o00003OmVIVH00ol0003oC4a<oda<C00<oda<C0[o00001olc<c<Io`0000So<c<c1?l0
000Aoda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl0=omoOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?oooonDogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000
oda<C?m<C4`02om<C4`00ol0003o<c<coc<c<`0coc<c<`03o`000?m<C4coC4a<00koC4a<00?o0000
ofIVI_mVIVH02OmVIVH2o`0003[oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OoooonEogmo
O`;o00002omVIVH00ol0003oC4a<oda<C00:oda<C003o`000?lc<c?o<c<c00ko<c<c6ol0000<oc<c
<`;o00003Om<C4`00ol0003oIVIVofIVIP08ofIVIP;o0000??moOgl5ooooo`;o00000Oooool001[o
oooo00?o0000ooooooooool01?oooonGogmoO`;o00002_mVIVH00ol0003oC4a<oda<C009oda<C003
o`000?lc<c?o<c<c00Wo<c<c1Ol0000KoaTI6@?o00002olc<c<00ol0003oC4a<oda<C009oda<C003
o`000?mVIVKoIVIV00SoIVIV00?o0000ogmoOomoOgl0??moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?oooonIogmoO`;o00002OmVIVH2o`0000SoC4a<0_l00009oc<c<`;o0000
8olI6AT00ol0003o<c<coc<c<`08oc<c<`;o00002?m<C4`2o`0000[oIVIV00?o0000ogmoOomoOgl0
?OmoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonKogmoO`03o`000?mV
IVKoIVIV00SoIVIV0_l00008oda<C0;o00002Olc<c<2o`0001oo6ATI0_l0000:oc<c<`03o`000?m<
C4coC4a<00OoC4a<00?o0000ofIVI_mVIVH02?mVIVH2o`00043oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CoooooW?moOgl2o`0000[oIVIV00?o0000oda<C?m<C4`01om<C4`2
o`0000Wo<c<c0ol0000JoaTI6@;o00002_lc<c<2o`0000SoC4a<0_l00009ofIVIP;o0000@_moOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonNogmoO`?o00002?mVIVH3o`00
00SoC4a<0_l0000:oc<c<`?o00005OlI6AT2o`0000_o<c<c00?o0000oda<C?m<C4`01Om<C4`3o`00
00[oIVIV00?o0000ogmoOomoOgl0@_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?oooonQogmoO`;o00002OmVIVH3o`0000OoC4a<0ol0000:oc<c<`Go00003?lI6AT4o`0000[o
<c<c0ol00006oda<C0;o00002omVIVH2o`0004GoOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CoooooXomoOgl3o`0000WoIVIV0ol00007oda<C0?o00003?lc<c<<o`0000_o<c<c
0ol00007oda<C0;o00002OmVIVH4o`0004OoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CoooooY_moOgl3o`0000WoIVIV0ol00007oda<C0Go00006Olc<c<5o`0000OoC4a<0ol0
0007ofIVIPCo0000BomoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonY
ogmoO`[o00000_mVIVH6o`0000KoC4a<1ol0000;oc<c<`Oo00001_m<C4`6o`0000KoIVIV1?l0001?
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooook?oOgmo0ol00005ofIV
IPKo00001om<C4`;o`0000OoC4a<1_l00007ofIVIPGo0000DomoOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?oooonEogmoO`co00005OmoOgl5o`0000KoIVIV1ol0000<oda<C0Ko
00001omVIVH6o`0001CoOgmo2_l0000jogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000Gooooo
UOmoOgl00ol0003oVIVIoiVIV@09oiVIV@Ko00001_moOgl6o`0000SoOgmo1_l00007ofIVIPco0000
1_mVIVH7o`0001?oOgmo1ol00009oiVIV@03o`000?moOgooOgmo03SoOgmo1Oooool2o`00007ooooo
000Jooooo`03o`000?oooooooooo00CoooooU?moOgl00ol0003oVIVIoiVIV@0@oiVIV@Ko00001_nI
VIT3o`0000_oOgmo1ol0000<ofIVIPKo00005?moOgl6o`00013oVIVI00?o0000ogmoOomoOgl0>?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonDogmoO`03o`000?nIVIWo
VIVI01ooVIVI1Ol0000=ogmoO`co00003OmoOgl=o`0001OoVIVI00?o0000ogmoOomoOgl0=omoOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonCogmoO`03o`000?nIVIWoVIVI
02GoVIVI1ol0000GogmoO`So00009?nIVIT00ol0003oOgmoogmoO`0gogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04oooooi?oOgmo00?o0000oiVIVOnIVIT0;?nIVITGo`0002[o
VIVI0_l0000jogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooiCoOgmo
00?o0000oiVIVOnIVIT0JonIVIT00ol0003oOgmoogmoO`0jogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04oooooiGoOgmo0_l0001ZoiVIV@03o`000?moOgooOgmo03_oOgmo1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooUomoOgl00ol0003oVIVIoiVIV@0P
oiVIV@ko00003?nIVIT>o`0001koVIVI00?o0000ogmoOomoOgl0??moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?oooonHogmoO`;o00006onIVIT5o`0000ko/k>c3?l0000>ok>c
/`Co00006OnIVIT00ol0003oOgmoogmoO`0mogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04oooooi[oOgmo00?o0000oiVIVOnIVIT05OnIVIT3o`00037o/k>c00?o0000oiVIVOnI
VIT05OnIVIT00ol0003oOgmoogmoO`0nogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04oooooi_oOgmo00?o0000oiVIVOnIVIT04onIVIT2o`0003?o/k>c0_l0000DoiVIV@;o0000
@OmoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonLogmoO`;o00005OnI
VIT2o`00033o/k>c00?o0000oiVIVOnIVIT04onIVIT00ol0003oOgmoogmoO`11ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04oooooikoOgmo0ol0000DoiVIV@03o`000?nc/k?o
/k>c02[o/k>c0ol0000EoiVIV@03o`000?moOgooOgmo04;oOgmo1_ooool1o`00007ooooo000Joooo
o`;o00001OoooonQogmoO`;o00004onIVIT3o`0002Ko/k>c0ol0000GoiVIV@03o`000?moOgooOgmo
04?oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooXomoOgl3o`0001?o
VIVI0ol0000Pok>c/`?o00006OnIVIT00ol0003oOgmoogmoO`14ogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooojKoOgmo0ol0000CoiVIV@Go00006?nc/k<3o`0001SoVIVI
1?l00017ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooojWoOgmo00?o
0000oiVIVOnIVIT05OnIVIT8o`0000So/k>c2?l0000EoiVIV@Ko0000BomoOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?oooonYogmoO`Go00006onIVIT8o`0001[oVIVI0ol0001A
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooojkoOgmo1Ol0000foiVI
V@;o0000E?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooncogmoO`?o
0000<?nIVIT3o`0005KoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
]_moOgl3o`0002SoVIVI1Ol0001IogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04oooookWoOgmo0ol0000NoiVIV@Oo0000G_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?oooonlogmoO`co00003?nIVIT6o`0006GoOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00Cooooob?moOgl<o`0006_oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo0_l00005ooooooooOgmo@?mo
Ogl5ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool000Oooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000Oooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool000Sooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooo
oooooooooooo410@00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo0009ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000006ooooo`?o
00001?ooooooogmoOd3oOgmo1?ooool3o`00007ooooo000:ooooo`03ogMgMomVIVKooooo00;ooooo
00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`002oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@oooooooo
ool01?ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000Oooooo
00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000Oooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo
1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Oooooooogmo
Od3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Ooo
ooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o
00001OooooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo0007ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo0007ooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000;
ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`04ooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool00onYZJWo410@ooooo`02
ooooo`05o`000?ooooooooooooooool000001_ooool3o`0000CooooooomoOgm0ogmoO`Cooooo0ol0
0001ooooo`002Oooool00ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool000001_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000[ooooo00?o^[Zj
ob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo0007ooooo`05oa0@4?nHV9SooooookZj^_l000000ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo0007ooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002Ooo
ool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooo
ooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000:ooooo`03o`000?oooooooooo00;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmo
O`Kooooo0Ol00001ooooo`001oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@4006oooo
o`?o00001?ooooooogmoOd3oOgmo1?ooool3o`00007ooooo0007ooooo`04odA4A?oMgMgoooooo`00
00Cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?ooooooB_ooool1
o`00007ooooo0007ooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo0?ooooooB_ooool1o`00007ooooo0008ooooo`03ogMgMoo<c<co
000000Cooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo0?ooooooB_oo
ool1o`00007ooooo0008ooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`06ooooo`03o`000?oooooooooo0?ooooooB_ooool1o`00007ooooo0009ooooo`03ogMgMol0003o
oooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool0?Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03gooooo00?o
0000ooooooooool0?Oooool00ol0003oooooooooo`0Sooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`09ooooo`7o00000Oooool001[oooooool0001>o`00
007ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-30.1723, -14.304, 0.195672, \
0.195672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0192308 0.211538 0.0192308 [
[.11538 -0.0125 -9 -9 ]
[.11538 -0.0125 9 0 ]
[.30769 -0.0125 -9 -9 ]
[.30769 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69231 -0.0125 -6 -9 ]
[.69231 -0.0125 6 0 ]
[.88462 -0.0125 -6 -9 ]
[.88462 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -18 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .21154 -6 -4.5 ]
[-0.0125 .21154 0 4.5 ]
[-0.0125 .40385 -12 -4.5 ]
[-0.0125 .40385 0 4.5 ]
[-0.0125 .59615 -12 -4.5 ]
[-0.0125 .59615 0 4.5 ]
[-0.0125 .78846 -12 -4.5 ]
[-0.0125 .78846 0 4.5 ]
[-0.0125 .98077 -12 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11538 0 m
.11538 .00625 L
s
[(-20)] .11538 -0.0125 0 1 Mshowa
.30769 0 m
.30769 .00625 L
s
[(-10)] .30769 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69231 0 m
.69231 .00625 L
s
[(10)] .69231 -0.0125 0 1 Mshowa
.88462 0 m
.88462 .00625 L
s
[(20)] .88462 -0.0125 0 1 Mshowa
.125 Mabswid
.15385 0 m
.15385 .00375 L
s
.19231 0 m
.19231 .00375 L
s
.23077 0 m
.23077 .00375 L
s
.26923 0 m
.26923 .00375 L
s
.34615 0 m
.34615 .00375 L
s
.38462 0 m
.38462 .00375 L
s
.42308 0 m
.42308 .00375 L
s
.46154 0 m
.46154 .00375 L
s
.53846 0 m
.53846 .00375 L
s
.57692 0 m
.57692 .00375 L
s
.61538 0 m
.61538 .00375 L
s
.65385 0 m
.65385 .00375 L
s
.73077 0 m
.73077 .00375 L
s
.76923 0 m
.76923 .00375 L
s
.80769 0 m
.80769 .00375 L
s
.84615 0 m
.84615 .00375 L
s
.07692 0 m
.07692 .00375 L
s
.03846 0 m
.03846 .00375 L
s
.92308 0 m
.92308 .00375 L
s
.96154 0 m
.96154 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(-10)] -0.0125 .01923 1 0 Mshowa
0 .21154 m
.00625 .21154 L
s
[(0)] -0.0125 .21154 1 0 Mshowa
0 .40385 m
.00625 .40385 L
s
[(10)] -0.0125 .40385 1 0 Mshowa
0 .59615 m
.00625 .59615 L
s
[(20)] -0.0125 .59615 1 0 Mshowa
0 .78846 m
.00625 .78846 L
s
[(30)] -0.0125 .78846 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(40)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .05769 m
.00375 .05769 L
s
0 .09615 m
.00375 .09615 L
s
0 .13462 m
.00375 .13462 L
s
0 .17308 m
.00375 .17308 L
s
0 .25 m
.00375 .25 L
s
0 .28846 m
.00375 .28846 L
s
0 .32692 m
.00375 .32692 L
s
0 .36538 m
.00375 .36538 L
s
0 .44231 m
.00375 .44231 L
s
0 .48077 m
.00375 .48077 L
s
0 .51923 m
.00375 .51923 L
s
0 .55769 m
.00375 .55769 L
s
0 .63462 m
.00375 .63462 L
s
0 .67308 m
.00375 .67308 L
s
0 .71154 m
.00375 .71154 L
s
0 .75 m
.00375 .75 L
s
0 .82692 m
.00375 .82692 L
s
0 .86538 m
.00375 .86538 L
s
0 .90385 m
.00375 .90385 L
s
0 .94231 m
.00375 .94231 L
s
.25 Mabswid
0 0 m
0 1 L
s
.11538 .99375 m
.11538 1 L
s
.30769 .99375 m
.30769 1 L
s
.5 .99375 m
.5 1 L
s
.69231 .99375 m
.69231 1 L
s
.88462 .99375 m
.88462 1 L
s
.125 Mabswid
.15385 .99625 m
.15385 1 L
s
.19231 .99625 m
.19231 1 L
s
.23077 .99625 m
.23077 1 L
s
.26923 .99625 m
.26923 1 L
s
.34615 .99625 m
.34615 1 L
s
.38462 .99625 m
.38462 1 L
s
.42308 .99625 m
.42308 1 L
s
.46154 .99625 m
.46154 1 L
s
.53846 .99625 m
.53846 1 L
s
.57692 .99625 m
.57692 1 L
s
.61538 .99625 m
.61538 1 L
s
.65385 .99625 m
.65385 1 L
s
.73077 .99625 m
.73077 1 L
s
.76923 .99625 m
.76923 1 L
s
.80769 .99625 m
.80769 1 L
s
.84615 .99625 m
.84615 1 L
s
.07692 .99625 m
.07692 1 L
s
.03846 .99625 m
.03846 1 L
s
.92308 .99625 m
.92308 1 L
s
.96154 .99625 m
.96154 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .21154 m
1 .21154 L
s
.99375 .40385 m
1 .40385 L
s
.99375 .59615 m
1 .59615 L
s
.99375 .78846 m
1 .78846 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .05769 m
1 .05769 L
s
.99625 .09615 m
1 .09615 L
s
.99625 .13462 m
1 .13462 L
s
.99625 .17308 m
1 .17308 L
s
.99625 .25 m
1 .25 L
s
.99625 .28846 m
1 .28846 L
s
.99625 .32692 m
1 .32692 L
s
.99625 .36538 m
1 .36538 L
s
.99625 .44231 m
1 .44231 L
s
.99625 .48077 m
1 .48077 L
s
.99625 .51923 m
1 .51923 L
s
.99625 .55769 m
1 .55769 L
s
.99625 .63462 m
1 .63462 L
s
.99625 .67308 m
1 .67308 L
s
.99625 .71154 m
1 .71154 L
s
.99625 .75 m
1 .75 L
s
.99625 .82692 m
1 .82692 L
s
.99625 .86538 m
1 .86538 L
s
.99625 .90385 m
1 .90385 L
s
.99625 .94231 m
1 .94231 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.4 g
.47057 .43706 m
.49019 .43913 L
.50981 .44236 L
.52943 .44484 L
.54906 .44993 L
.56195 .45094 L
.56868 .45202 L
.5883 .45449 L
.60793 .45622 L
.62755 .45721 L
.64717 .45747 L
.6668 .45699 L
.68642 .45578 L
.70604 .45382 L
.72567 .45113 L
.72672 .45094 L
.74529 .4487 L
.76491 .44266 L
.78454 .44135 L
.80416 .43831 L
.82378 .4371 L
.83734 .45094 L
.82378 .46504 L
.81654 .47057 L
.80416 .47835 L
.78454 .48798 L
.77927 .49019 L
.76491 .49457 L
.74529 .50271 L
.72567 .50917 L
.71294 .50981 L
.70604 .51115 L
.68642 .51413 L
.6668 .51594 L
.64717 .51159 L
.62755 .51104 L
.60793 .5148 L
.5883 .51218 L
.57548 .50981 L
.56868 .50849 L
.54906 .50492 L
.52943 .49705 L
.50981 .49025 L
.50911 .49019 L
.49019 .48148 L
.47173 .47057 L
.47057 .46972 L
.4511 .45094 L
F
0 g
.47057 .43706 m
.49019 .43913 L
.50981 .44236 L
.52943 .44484 L
.54906 .44993 L
.56195 .45094 L
.56868 .45202 L
.5883 .45449 L
.60793 .45622 L
.62755 .45721 L
.64717 .45747 L
.6668 .45699 L
.68642 .45578 L
.70604 .45382 L
.72567 .45113 L
.72672 .45094 L
.74529 .4487 L
.76491 .44266 L
.78454 .44135 L
.80416 .43831 L
.82378 .4371 L
.83734 .45094 L
.82378 .46504 L
.81654 .47057 L
.80416 .47835 L
.78454 .48798 L
.77927 .49019 L
.76491 .49457 L
.74529 .50271 L
.72567 .50917 L
.71294 .50981 L
.70604 .51115 L
.68642 .51413 L
.6668 .51594 L
.64717 .51159 L
.62755 .51104 L
.60793 .5148 L
.5883 .51218 L
.57548 .50981 L
.56868 .50849 L
.54906 .50492 L
.52943 .49705 L
.50981 .49025 L
.50911 .49019 L
.49019 .48148 L
.47173 .47057 L
.47057 .46972 L
.4511 .45094 L
.47057 .43706 L
s
.6 g
.47057 .38405 m
.49019 .38354 L
.50981 .38486 L
.52943 .38805 L
.54906 .39087 L
.55811 .39207 L
.56868 .39344 L
.5883 .39545 L
.60793 .39689 L
.62755 .3929 L
.64717 .39365 L
.6668 .39754 L
.68642 .39652 L
.70604 .39491 L
.72567 .39273 L
.73019 .39207 L
.74529 .39003 L
.76491 .39086 L
.78454 .38155 L
.80416 .3833 L
.82378 .38556 L
.83088 .39207 L
.82378 .40343 L
.81466 .4117 L
.80416 .41795 L
.78454 .42713 L
.77391 .43132 L
.76491 .43421 L
.74529 .44308 L
.72567 .44453 L
.70604 .44797 L
.68642 .45048 L
.68322 .45094 L
.6668 .45207 L
.64717 .45269 L
.62755 .45236 L
.60793 .45105 L
.60668 .45094 L
.5883 .44882 L
.56868 .44566 L
.54906 .4462 L
.52943 .43665 L
.51436 .43132 L
.50981 .42957 L
.49019 .42091 L
.47359 .4117 L
.47057 .40921 L
.4575 .39207 L
F
0 g
.47057 .38405 m
.49019 .38354 L
.50981 .38486 L
.52943 .38805 L
.54906 .39087 L
.55811 .39207 L
.56868 .39344 L
.5883 .39545 L
.60793 .39689 L
.62755 .3929 L
.64717 .39365 L
.6668 .39754 L
.68642 .39652 L
.70604 .39491 L
.72567 .39273 L
.73019 .39207 L
.74529 .39003 L
.76491 .39086 L
.78454 .38155 L
.80416 .3833 L
.82378 .38556 L
.83088 .39207 L
.82378 .40343 L
.81466 .4117 L
.80416 .41795 L
.78454 .42713 L
.77391 .43132 L
.76491 .43421 L
.74529 .44308 L
.72567 .44453 L
.70604 .44797 L
.68642 .45048 L
.68322 .45094 L
.6668 .45207 L
.64717 .45269 L
.62755 .45236 L
.60793 .45105 L
.60668 .45094 L
.5883 .44882 L
.56868 .44566 L
.54906 .4462 L
.52943 .43665 L
.51436 .43132 L
.50981 .42957 L
.49019 .42091 L
.47359 .4117 L
.47057 .40921 L
.4575 .39207 L
.47057 .38405 L
s
.6 g
.49019 .50936 m
.50012 .50981 L
.50981 .51109 L
.52943 .51448 L
.54906 .51788 L
.56868 .52081 L
.5883 .52311 L
.60793 .52475 L
.62755 .52183 L
.64717 .5225 L
.6668 .52549 L
.68642 .52433 L
.70604 .52249 L
.72567 .51999 L
.74529 .5169 L
.76491 .51343 L
.78454 .51024 L
.80169 .52943 L
.78454 .54179 L
.77106 .54906 L
.76491 .55234 L
.74529 .56491 L
.72567 .56661 L
.71761 .56868 L
.70604 .57021 L
.68642 .57341 L
.6668 .57576 L
.64717 .57673 L
.62755 .57621 L
.60793 .57424 L
.5883 .57118 L
.57088 .56868 L
.56868 .56814 L
.54906 .56251 L
.52943 .5557 L
.51738 .54906 L
.50981 .54514 L
.49019 .53237 L
.48681 .52943 L
.4841 .50981 L
F
0 g
.49019 .50936 m
.50012 .50981 L
.50981 .51109 L
.52943 .51448 L
.54906 .51788 L
.56868 .52081 L
.5883 .52311 L
.60793 .52475 L
.62755 .52183 L
.64717 .5225 L
.6668 .52549 L
.68642 .52433 L
.70604 .52249 L
.72567 .51999 L
.74529 .5169 L
.76491 .51343 L
.78454 .51024 L
.80169 .52943 L
.78454 .54179 L
.77106 .54906 L
.76491 .55234 L
.74529 .56491 L
.72567 .56661 L
.71761 .56868 L
.70604 .57021 L
.68642 .57341 L
.6668 .57576 L
.64717 .57673 L
.62755 .57621 L
.60793 .57424 L
.5883 .57118 L
.57088 .56868 L
.56868 .56814 L
.54906 .56251 L
.52943 .5557 L
.51738 .54906 L
.50981 .54514 L
.49019 .53237 L
.48681 .52943 L
.4841 .50981 L
.49019 .50936 L
s
.4 g
.49019 .34327 m
.50981 .33912 L
.52943 .33919 L
.54906 .34027 L
.56868 .33938 L
.5883 .34653 L
.60793 .34389 L
.62755 .34451 L
.64717 .34467 L
.6668 .34437 L
.68642 .35034 L
.70604 .34475 L
.72567 .33541 L
.74529 .3399 L
.76491 .339 L
.78454 .33958 L
.80254 .35283 L
.78454 .36585 L
.77163 .37245 L
.76491 .37839 L
.74529 .38046 L
.72567 .38494 L
.70604 .38848 L
.68642 .39107 L
.67786 .39207 L
.6668 .39263 L
.64717 .39254 L
.62755 .39232 L
.61268 .39207 L
.60793 .39166 L
.5883 .38935 L
.56868 .3861 L
.54906 .38191 L
.52943 .37668 L
.51675 .37245 L
.50981 .3691 L
.49019 .35669 L
.486 .35283 L
F
0 g
.49019 .34327 m
.50981 .33912 L
.52943 .33919 L
.54906 .34027 L
.56868 .33938 L
.5883 .34653 L
.60793 .34389 L
.62755 .34451 L
.64717 .34467 L
.6668 .34437 L
.68642 .35034 L
.70604 .34475 L
.72567 .33541 L
.74529 .3399 L
.76491 .339 L
.78454 .33958 L
.80254 .35283 L
.78454 .36585 L
.77163 .37245 L
.76491 .37839 L
.74529 .38046 L
.72567 .38494 L
.70604 .38848 L
.68642 .39107 L
.67786 .39207 L
.6668 .39263 L
.64717 .39254 L
.62755 .39232 L
.61268 .39207 L
.60793 .39166 L
.5883 .38935 L
.56868 .3861 L
.54906 .38191 L
.52943 .37668 L
.51675 .37245 L
.50981 .3691 L
.49019 .35669 L
.486 .35283 L
.49019 .34327 L
s
.7 g
.52943 .40055 m
.54906 .39977 L
.56868 .40034 L
.5883 .4012 L
.60793 .40197 L
.62755 .39461 L
.64717 .39571 L
.6668 .40236 L
.68642 .40176 L
.70604 .40094 L
.72567 .40011 L
.74529 .39977 L
.76491 .40152 L
.77623 .4117 L
.76491 .42116 L
.74587 .43132 L
.74529 .43172 L
.72567 .43773 L
.70604 .44216 L
.68642 .44526 L
.6668 .44717 L
.64717 .44792 L
.62755 .44751 L
.60793 .44596 L
.5883 .44322 L
.56868 .43921 L
.54906 .43605 L
.54264 .43132 L
.52943 .42472 L
.51222 .4117 L
F
0 g
.52943 .40055 m
.54906 .39977 L
.56868 .40034 L
.5883 .4012 L
.60793 .40197 L
.62755 .39461 L
.64717 .39571 L
.6668 .40236 L
.68642 .40176 L
.70604 .40094 L
.72567 .40011 L
.74529 .39977 L
.76491 .40152 L
.77623 .4117 L
.76491 .42116 L
.74587 .43132 L
.74529 .43172 L
.72567 .43773 L
.70604 .44216 L
.68642 .44526 L
.6668 .44717 L
.64717 .44792 L
.62755 .44751 L
.60793 .44596 L
.5883 .44322 L
.56868 .43921 L
.54906 .43605 L
.54264 .43132 L
.52943 .42472 L
.51222 .4117 L
.52943 .40055 L
s
.3 g
.52943 .4582 m
.54906 .45823 L
.56868 .45938 L
.5883 .46065 L
.60793 .46168 L
.62755 .46232 L
.64717 .46249 L
.6668 .46217 L
.68642 .46141 L
.70604 .46028 L
.72567 .459 L
.74529 .45802 L
.76491 .4589 L
.77511 .47057 L
.76491 .47901 L
.74529 .48969 L
.7442 .49019 L
.72567 .50331 L
.70604 .502 L
.68642 .50548 L
.6668 .50761 L
.64717 .50844 L
.62755 .50799 L
.60793 .50626 L
.5883 .5032 L
.56868 .49864 L
.54906 .49311 L
.54429 .49019 L
.52943 .48265 L
.51335 .47057 L
F
0 g
.52943 .4582 m
.54906 .45823 L
.56868 .45938 L
.5883 .46065 L
.60793 .46168 L
.62755 .46232 L
.64717 .46249 L
.6668 .46217 L
.68642 .46141 L
.70604 .46028 L
.72567 .459 L
.74529 .45802 L
.76491 .4589 L
.77511 .47057 L
.76491 .47901 L
.74529 .48969 L
.7442 .49019 L
.72567 .50331 L
.70604 .502 L
.68642 .50548 L
.6668 .50761 L
.64717 .50844 L
.62755 .50799 L
.60793 .50626 L
.5883 .5032 L
.56868 .49864 L
.54906 .49311 L
.54429 .49019 L
.52943 .48265 L
.51335 .47057 L
.52943 .4582 L
s
.6 g
.54906 .30264 m
.56868 .3006 L
.5883 .30008 L
.60793 .30003 L
.62755 .3001 L
.64717 .30012 L
.6668 .30008 L
.68642 .30002 L
.70604 .30016 L
.72567 .30096 L
.74529 .30408 L
.75357 .31358 L
.74529 .31813 L
.72567 .32573 L
.70604 .33098 L
.69483 .3332 L
.68642 .33572 L
.6668 .33559 L
.64717 .33616 L
.62755 .33585 L
.60793 .33465 L
.59353 .3332 L
.5883 .33219 L
.56868 .32751 L
.54906 .32074 L
.53488 .31358 L
F
0 g
.54906 .30264 m
.56868 .3006 L
.5883 .30008 L
.60793 .30003 L
.62755 .3001 L
.64717 .30012 L
.6668 .30008 L
.68642 .30002 L
.70604 .30016 L
.72567 .30096 L
.74529 .30408 L
.75357 .31358 L
.74529 .31813 L
.72567 .32573 L
.70604 .33098 L
.69483 .3332 L
.68642 .33572 L
.6668 .33559 L
.64717 .33616 L
.62755 .33585 L
.60793 .33465 L
.59353 .3332 L
.5883 .33219 L
.56868 .32751 L
.54906 .32074 L
.53488 .31358 L
.54906 .30264 L
s
.8 g
.56868 .40834 m
.5883 .40748 L
.60793 .40739 L
.62755 .40129 L
.64717 .40205 L
.6668 .40745 L
.68642 .40738 L
.70604 .40761 L
.72567 .40898 L
.73753 .4117 L
.72567 .42867 L
.72047 .43132 L
.70604 .43561 L
.68642 .43959 L
.6668 .44193 L
.64717 .44283 L
.62755 .44235 L
.60793 .44045 L
.5883 .437 L
.56868 .43154 L
.56805 .43132 L
.55104 .4117 L
F
0 g
.56868 .40834 m
.5883 .40748 L
.60793 .40739 L
.62755 .40129 L
.64717 .40205 L
.6668 .40745 L
.68642 .40738 L
.70604 .40761 L
.72567 .40898 L
.73753 .4117 L
.72567 .42867 L
.72047 .43132 L
.70604 .43561 L
.68642 .43959 L
.6668 .44193 L
.64717 .44283 L
.62755 .44235 L
.60793 .44045 L
.5883 .437 L
.56868 .43154 L
.56805 .43132 L
.55104 .4117 L
.56868 .40834 L
s
.3 g
.5883 .35277 m
.60793 .35262 L
.62755 .35267 L
.64717 .35269 L
.6668 .35265 L
.68642 .35272 L
.70252 .35283 L
.70604 .35293 L
.72567 .35454 L
.73337 .37245 L
.72567 .37528 L
.70604 .38066 L
.68642 .38429 L
.6668 .38648 L
.64717 .38734 L
.62755 .38688 L
.60793 .38509 L
.5883 .38191 L
.56868 .37712 L
.55508 .37245 L
.56868 .35379 L
.58597 .35283 L
F
0 g
.5883 .35277 m
.60793 .35262 L
.62755 .35267 L
.64717 .35269 L
.6668 .35265 L
.68642 .35272 L
.70252 .35283 L
.70604 .35293 L
.72567 .35454 L
.73337 .37245 L
.72567 .37528 L
.70604 .38066 L
.68642 .38429 L
.6668 .38648 L
.64717 .38734 L
.62755 .38688 L
.60793 .38509 L
.5883 .38191 L
.56868 .37712 L
.55508 .37245 L
.56868 .35379 L
.58597 .35283 L
.5883 .35277 L
s
.2 g
.56868 .4693 m
.5883 .46811 L
.60793 .46802 L
.62755 .46813 L
.64717 .46818 L
.6668 .4681 L
.68642 .46801 L
.70604 .46828 L
.72567 .47031 L
.72681 .47057 L
.72567 .48151 L
.71042 .49019 L
.70604 .49166 L
.68642 .49658 L
.6668 .49937 L
.64717 .50043 L
.62755 .49986 L
.60793 .49762 L
.5883 .49341 L
.57796 .49019 L
.56868 .48553 L
.56123 .47057 L
F
0 g
.56868 .4693 m
.5883 .46811 L
.60793 .46802 L
.62755 .46813 L
.64717 .46818 L
.6668 .4681 L
.68642 .46801 L
.70604 .46828 L
.72567 .47031 L
.72681 .47057 L
.72567 .48151 L
.71042 .49019 L
.70604 .49166 L
.68642 .49658 L
.6668 .49937 L
.64717 .50043 L
.62755 .49986 L
.60793 .49762 L
.5883 .49341 L
.57796 .49019 L
.56868 .48553 L
.56123 .47057 L
.56868 .4693 L
s
.2 g
.60793 .36459 m
.62755 .36266 L
.64717 .3623 L
.6668 .36301 L
.68642 .36598 L
.69225 .37245 L
.68642 .37425 L
.6668 .37803 L
.64717 .37936 L
.62755 .37865 L
.60793 .37571 L
.59593 .37245 L
F
0 g
.60793 .36459 m
.62755 .36266 L
.64717 .3623 L
.6668 .36301 L
.68642 .36598 L
.69225 .37245 L
.68642 .37425 L
.6668 .37803 L
.64717 .37936 L
.62755 .37865 L
.60793 .37571 L
.59593 .37245 L
.60793 .36459 L
s
.9 g
.60793 .41482 m
.62755 .41382 L
.64717 .41364 L
.6668 .414 L
.68642 .41548 L
.69093 .43132 L
.68642 .4324 L
.6668 .43567 L
.64717 .43686 L
.62755 .43622 L
.60793 .43364 L
.5972 .43132 L
F
0 g
.60793 .41482 m
.62755 .41382 L
.64717 .41364 L
.6668 .414 L
.68642 .41548 L
.69093 .43132 L
.68642 .4324 L
.6668 .43567 L
.64717 .43686 L
.62755 .43622 L
.60793 .43364 L
.5972 .43132 L
.60793 .41482 L
s
.6 g
.80416 .50976 m
.80449 .50981 L
.80416 .52678 L
.7882 .50981 L
F
0 g
.80416 .50976 m
.80449 .50981 L
.80416 .52678 L
.7882 .50981 L
.80416 .50976 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00?Oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0dooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kS?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0hooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8b
onk^kS?ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08_ooool003gooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0=_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0<oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg03?ooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL08_ooool003Gooooo1_l0
0003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400[ooooo`Ko0000
1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100<oooool01Ol@413o
oooooooooooooooo410@03[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@03Cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@02;ooooo000o
ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000fooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000cooooo`05o`000?ooooooooooooooool0
0000>_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000=Oooool00onH
V9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000008_ooool0043ooooo00?oMgMgofIV
I_ooool00_ooool01Ol0003ooooooooooooooooo000003Kooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000003?ooooo00Go0000ooooooooooooooooo`00000jooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`03ogMgMomVIVKooooo00;o
oooo00Go0000ooooooooooooooooo`00000Rooooo`00@Oooool01Ol0003ooooooooooooooooo410@
00?ooooo00?o410@ooooooooool0=?ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@4100<oooool01Ol@413ooooooooooooooooo410@03[ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@03Oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo023ooooo000mooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg03Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg03?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0jooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0cooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02;ooooo000mooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^03Cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^03?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`03oeEEEOmVIVKo000000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0cooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02;ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo000Joooooooo0000C_l00001ooooo`00
6_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0?Ooo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool08ooo
ool1o`00007ooooo0008ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKo
oooo00?o0000ooooooooool0oooooom:ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooom:ooooo`7o
00000Oooool000Go00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41001_ooool00ol0003oooooooooo`3ooooood[ooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?ooooooB?ooool3o`00007o
oooo000:ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo0008ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Oooooooogmo
Od3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Ooo
ooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000oooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`003ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000?ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000oooooo00Go0000oooooooooooooooo
o`000006ooooo`?o00001?ooooooogmoOd3oOgmo1?ooool3o`00007ooooo000?ooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool000oooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`003oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000?ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
/omoOgleo`0005OoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo[omo
Ogl4o`0003GoVIVI1ol0001@ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooojkoOgmo00?o0000oiVIVOnIVIT0?_nIVIT3o`0004goOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00Cooooo[OmoOgl00ol0003oVIVIoiVIV@11oiVIV@03o`000?moOgooOgmo
04_oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo[?moOgl00ol0003o
VIVIoiVIV@13oiVIV@03o`000?moOgooOgmo04[oOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CoooooZomoOgl2o`0004GoVIVI0_l0001;ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooojgoOgmo0ol00010oiVIV@;o0000COmoOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?oooon`ogmoO`?o0000>_nIVIT3o`0004ooOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo/omoOgl3o`0003GoVIVI0_l0001Bogmo
O`Kooooo0Ol00001ooooo`006_ooool2o`0000Gooooo]_moOgl3o`00033oVIVI0_l0001DogmoO`Go
oooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04oooookWoOgmo0ol0000ZoiVIV@?o0000
E_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonlogmoO`Ko00007OnI
VIT7o`0005WoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo`_moOglM
o`0000[oOgmo1?l0001BogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
oj7oOgmo3Ol00005ogmoO`Go0000;omoOgl2o`0000CoIVIV0ol00004ogmoO`co0000?omoOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonNogmoO`?o00003OmVIVH5o`0000Go
IVIV0ol0000ZogmoO`;o00002OmVIVH4o`0000coIVIV00?o0000ogmoOomoOgl0??moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?oooonLogmoO`;o00007OmVIVH2o`0000?oOgmo
6_l00008ogmoO`?o00007?mVIVH00ol0003oOgmoogmoO`0kogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04oooooicoOgmo00?o0000ofIVI_mVIVH07_mVIVH3o`0001[oIVIV0ol0
0002ogmoO`?o00008?mVIVH00ol0003oOgmoogmoO`0jogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04oooooi_oOgmo00?o0000ofIVI_mVIVH0?omVIVH2o`0002CoIVIV00?o0000
ogmoOomoOgl0>OmoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonKogmo
O`03o`000?mVIVKoIVIV01SoIVIV=Ol0000HofIVIP;o0000>_moOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?oooonLogmoO`;o00006?mVIVH00ol0003oC4a<oda<C00aoda<C003
o`000?mVIVKoIVIV01GoIVIV00?o0000ogmoOomoOgl0>_moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?oooonNogmoO`;o00005OmVIVH00ol0003oC4a<oda<C00coda<C003o`00
0?mVIVKoIVIV01;oIVIV0_l0000mogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04oooooj3oOgmo00?o0000ofIVI_mVIVH04OmVIVH00ol0003oC4a<oda<C00@oda<C1Co00004?m<
C4`00ol0003oIVIVofIVIP0AofIVIP03o`000?moOgooOgmo03goOgmo1_ooool1o`00007ooooo000J
ooooo`;o00001OoooonQogmoO`;o00004OmVIVH00ol0003oC4a<oda<C00;oda<C0Go00005?lc<c<3
o`0000koC4a<00?o0000ofIVI_mVIVH03_mVIVH2o`00043oOgmo1Oooool2o`00007ooooo000Joooo
o`03o`000?oooooooooo00CoooooXomoOgl2o`0000koIVIV00?o0000oda<C?m<C4`02_m<C4`2o`00
01co<c<c00?o0000oda<C?m<C4`02om<C4`00ol0003oIVIVofIVIP0;ofIVIP?o0000@_moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonUogmoO`;o00002omVIVH2o`0000_o
C4a<0ol0000Loc<c<`;o00003?m<C4`2o`0000_oIVIV00?o0000ogmoOomoOgl0@omoOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?oooonWogmoO`;o00002omVIVH2o`0000coC4a<
1_l0000Boc<c<`Co00002om<C4`3o`0000coIVIV00?o0000ogmoOomoOgl0A?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?oooonYogmoO`Go00002?mVIVH5o`0000goC4a<1_l0
0006oc<c<`Ko00003?m<C4`3o`0000_oIVIV1?l00017ogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooojkoOgmo1Ol00008ofIVIPGo00003_m<C4`6o`0000goC4a<1Ol00008
ofIVIPKo00002OmoOgl5o`0003goOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CoooooU?moOglBo`0000goOgmo0ol0000:ofIVIP?o00005om<C4`7o`0000SoIVIV1Ol0000<ogmo
O`?o00001OnIVIT7o`0003KoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
ooooTomoOgl00ol0003oVIVIoiVIV@0@oiVIV@?o00003OmoOgl5o`0000SoIVIV5ol0000<ofIVIP?o
00003omoOgl2o`0000ooVIVI0ol0000cogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04oooooi;oOgmo00?o0000oiVIVOnIVIT05?nIVIT:o`0000SoOgmo1_l0000PofIVIPGo0000
2OmoOgl9o`0001CoVIVI00?o0000ogmoOomoOgl0<?moOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?oooonAogmoO`03o`000?nIVIWoVIVI01ooVIVI2?l00006ogmoOb3o00001_mo
Ogl8o`0001koVIVI00?o0000ogmoOomoOgl0;omoOgl6ooooo`7o00000Oooool000Sooooo1?l00000
2?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^1_ooool00ol0003oooooooooo`04oooooi7o
Ogmo00?o0000oiVIVOnIVIT09onIVIT<o`000003oiVIVOl0003o000000co00001?moOgl=o`0002Ko
VIVI00?o0000ogmoOomoOgl0;omoOgl6ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?oooonBogmoO`03
o`000?nIVIWoVIVI01SoVIVI1ol0000AoiVIV@?o00002onc/k<7o`0001CoVIVI1ol0000GoiVIV@03
o`000?moOgooOgmo033oOgmo1_ooool1o`00007ooooo000:ooooo`03o`000?oooooooooo00;ooooo
00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00CoooooTomoOgl00ol0003o
VIVIoiVIV@0BoiVIV@Go00001onc/k<Ao`0000?o/k>c2ol00003ok>c/aSo00001onc/k<4o`0001?o
VIVI00?o0000ogmoOomoOgl0<?moOgl6ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool0
0_ooool01Ol0003ooooooooooooooooo000000Kooooo0ol00004oooooi?oOgmo00?o0000oiVIVOnI
VIT04?nIVIT2o`0001go/k>c0ol0000;olc<c0?o00008onc/k<00ol0003oVIVIoiVIV@0>oiVIV@;o
0000<omoOgl4ooooo`?o00000Oooool000[ooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool01?oooonDogmoO`03o`000?nIVIWoVIVI00go
VIVI0_l0000=ok>c/a;o00004Oo<c<`Go`0000go/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003o
OgmoogmoO`0cogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003oooooooooo`02ooooo`05oa0@
4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`04oooooiGoOgmo0ol0000;oiVIV@;o
00002onc/k<3o`0003[oc<c<0_l0000<ok>c/`03o`000?nIVIWoVIVI00WoVIVI0_l0000fogmoO`Ko
oooo0Ol00001ooooo`002_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01_ooool00ol0003oooooooooo`04oooooiSoOgmo0_l0000;oiVIV@03o`000?nc/k?o/k>c00So
/k>c00?o0000olc<c?o<c<`04?o<c<`Ho`0001?oc<c<00?o0000ok>c/onc/k<02Onc/k<00ol0003o
VIVIoiVIV@08oiVIV@;o0000>?moOgl6ooooo`7o00000Oooool000Sooooo00?oEEEEofIVI_l00000
1?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool01?oooonJogmoO`;o
00002_nIVIT00ol0003o/k>cok>c/`08ok>c/`03o`000?o<c<coc<c<00ooc<c<00?o0000onKVi_oV
i^H05OoVi^H3o`0000ooc<c<00?o0000ok>c/onc/k<02Onc/k<00ol0003oVIVIoiVIV@07oiVIV@;o
0000>_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonLogmoO`;o0000
2OnIVIT00ol0003o/k>cok>c/`08ok>c/`03o`000?o<c<coc<c<00goc<c<00?o0000onKVi_oVi^H0
6?oVi^H00ol0003oc<c<olc<c00<olc<c003o`000?nc/k?o/k>c00Wo/k>c00?o0000oiVIVOnIVIT0
1_nIVIT2o`0003coOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooW_mo
Ogl3o`0000OoVIVI00?o0000ok>c/onc/k<02?nc/k<00ol0003oc<c<olc<c00<olc<c003o`000?oV
i^Koi^KV01Woi^KV00?o0000olc<c?o<c<`02oo<c<`00ol0003o/k>cok>c/`07ok>c/`;o00001onI
VIT2o`0003koOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooXOmoOgl2
o`0000KoVIVI0_l00009ok>c/`03o`000?o<c<coc<c<00[oc<c<00?o0000onKVi_oVi^H06_oVi^H0
0ol0003oc<c<olc<c00:olc<c003o`000?nc/k?o/k>c00Ko/k>c0_l00007oiVIV@;o0000@?moOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonSogmoO`03o`000?nIVIWoVIVI
00GoVIVI0_l00008ok>c/`03o`000?o<c<coc<c<00Woc<c<00?o0000onKVi_oVi^H06_oVi^H00ol0
003oc<c<olc<c008olc<c0;o00001onc/k<2o`0000OoVIVI0_l00012ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooojCoOgmo0_l00007oiVIV@?o00001_nc/k<3o`0000Oo
c<c<0ol0000GonKViPKo00001_o<c<`3o`0000Ko/k>c0ol00007oiVIV@;o0000A?moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?oooonVogmoO`?o00001onIVIT3o`0000Ko/k>c
0ol00007olc<c0Go00003?oVi^H6o`0000Soc<c<1?l00006ok>c/`?o00001onIVIT3o`0004KoOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooU?moOgl;o`0000[oOgmo0_l0
0008oiVIV@?o00001_nc/k<5o`0000Ooc<c<3?l0000;olc<c0?o00001Onc/k<5o`0000SoVIVI0_l0
000;ogmoO`_o0000<omoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonC
ogmoO`03o`000?mVIVKoIVIV00WoIVIV0ol00009ogmoO`?o00002?nIVIT5o`0000Ko/k>c1ol0000<
olc<c0_o00000onc/k<5o`0000_oVIVI0_l00007ogmoO`Ko00002omVIVH00ol0003oOgmoogmoO`0`
ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000GoooooTOmoOgl2o`0000ooIVIV2_l00002ogmo
O`;o00002onIVIT6o`0000Oo/k>c3?l0000;ok>c/`?o00001OnIVIT;o`0000CoOgmo1Ol0000BofIV
IP03o`000?moOgooOgmo02ooOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
ooooT?moOgl00ol0003oIVIVofIVIP0IofIVIP?o000000?oOgmoo`000?l000002Ol00006oiVIVAko
00000_nIVIT6o`0000coOgmo0ol0000HofIVIP03o`000?moOgooOgmo02koOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CoooooSomoOgl00ol0003oIVIVofIVIP0MofIVIPOo0000
1OmoOgl=o`0001;oVIVI1ol00006ogmoO`co00007?mVIVH00ol0003oOgmoogmoO`0]ogmoO`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooohooOgmo00?o0000ofIVI_mVIVH09?mV
IVH5o`0000goOgmo4_l00007ogmoO`Ko0000:?mVIVH00ol0003oOgmoogmoO`0]ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04oooooi3oOgmo00?o0000ofIVI_mVIVH0:?mVIVHC
o`0000KoOgmo3Ol0000]ofIVIP03o`000?moOgooOgmo02koOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CoooooTOmoOgl00ol0003oIVIVofIVIP0DofIVIQ?o00004omVIVH6o`00
01?oIVIV4Ol0000EofIVIP03o`000?moOgooOgmo02ooOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CoooooT_moOgl00ol0003oIVIVofIVIP0BofIVIP03o`000?m<C4coC4a<017o
C4a<;?l0000Aoda<C003o`000?mVIVKoIVIV017oIVIV00?o0000ogmoOomoOgl0<?moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?oooonCogmoO`03o`000?mVIVKoIVIV013oIVIV
00?o0000oda<C?m<C4`0D?m<C4`00ol0003oIVIVofIVIP0>ofIVIP;o0000<omoOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?oooonDogmoO`03o`000?mVIVKoIVIV00koIVIV00?o
0000oda<C?m<C4`04_m<C4`^o`0001;oC4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmo
O`0cogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooiGoOgmo0ol0000<
ofIVIP;o00003_m<C4`6o`0002ko<c<c1?l0000>oda<C0;o00002omVIVH2o`0003KoOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooV?moOgl00ol0003oIVIVofIVIP0;ofIV
IP03o`000?m<C4coC4a<00_oC4a<00?o0000oc<c<olc<c<0=?lc<c<00ol0003oC4a<oda<C00;oda<
C003o`000?mVIVKoIVIV00[oIVIV00?o0000ogmoOomoOgl0=_moOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?oooonIogmoO`;o00003?mVIVH00ol0003oC4a<oda<C00;oda<C003
o`000?lc<c?o<c<c03?o<c<c00?o0000oda<C?m<C4`02_m<C4`00ol0003oIVIVofIVIP0:ofIVIP03
o`000?moOgooOgmo03OoOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OoooonKogmoO`03o`00
0?mVIVKoIVIV00[oIVIV00?o0000oda<C?m<C4`02_m<C4`00ol0003o<c<coc<c<`0boc<c<`03o`00
0?m<C4coC4a<00WoC4a<0_l0000;ofIVIP;o0000>_moOgl5ooooo`;o00000Oooool001[ooooo00?o
0000ooooooooool01?oooonLogmoO`?o00002_mVIVH2o`0000[oC4a<00?o0000oc<c<olc<c<0<Olc
<c<2o`0000WoC4a<0_l0000;ofIVIP;o0000??moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?oooonOogmoO`?o00002OmVIVH3o`0000SoC4a<0ol0000]oc<c<`?o00002Om<C4`2
o`0000_oIVIV0_l0000nogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
oj;oOgmo0ol00009ofIVIP;o00002Om<C4`2o`0002[o<c<c00?o0000oda<C?m<C4`01om<C4`3o`00
00WoIVIV1?l00010ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooojGo
Ogmo0_l00009ofIVIP?o00002?m<C4`2o`0002Go<c<c0ol00009oda<C003o`000?mVIVKoIVIV00Oo
IVIV0ol00014ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooojOoOgmo
0_l0000:ofIVIP?o00001om<C4`4o`0001ko<c<c0ol0000;oda<C003o`000?mVIVKoIVIV00KoIVIV
0_l00017ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooojWoOgmo0ol0
000:ofIVIP?o00002?m<C4`7o`0000co<c<c2ol0000=oda<C003o`000?mVIVKoIVIV00GoIVIV0_l0
0019ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooojcoOgmo0ol0000:
ofIVIP?o00003?m<C4`<o`0000koC4a<1_l00003oda<C003o`000?mVIVKoIVIV00CoIVIV0_l0001;
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooojooOgmo1?l00009ofIV
IPGo00007_m<C4`3o`0000KoIVIV0ol00004ofIVIP?o0000COmoOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?ooooncogmoO`?o00002omVIVH=o`0000KoC4a<2ol0000=ofIVIP?o
0000D?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonJogmoO`co0000
4?moOgl6o`0000coIVIV3?l0000=ofIVIP_o00003omoOgl:o`0003[oOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CoooooV_moOgl00ol0003oVIVIoiVIV@09oiVIV@?o00004omo
Ogl5o`0000CoIVIV0ol00006ogmoO`Oo00001OmVIVH7o`0001?oOgmo1ol00003oiVIV@;o00001?nI
VIT00ol0003oOgmoogmoO`0hogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
oooooi[oOgmo00?o0000oiVIVOnIVIT03?nIVIT5o`0001?oOgmo1?l0000@ogmoO`Go00005?moOgl6
o`0000_oVIVI0_l00003oiVIV@03o`000?moOgooOgmo03SoOgmo1_ooool1o`00007ooooo000Joooo
o`;o00001OoooonJogmoO`03o`000?nIVIWoVIVI017oVIVI1_l0000cogmoO`Oo00004_nIVIT2o`00
00;oVIVI00?o0000ogmoOomoOgl0>?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000oooooooo
ool01?oooonKogmoO`03o`000?nIVIWoVIVI01KoVIVI3Ol00006ogmoO`ko00003?moOgl6o`0001[o
VIVI0_l000000onIVIWo0000ogmoO`0iogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04oooooi_oOgmo00?o0000oiVIVOnIVIT08onIVIT6o`0000koVIVI3?l0000QoiVIV@?o0000
>_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonKogmoO`03o`000?nI
VIWoVIVI06GoVIVI0_l0000jogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
oooooicoOgmo0_l0001ToiVIV@03o`000?moOgooOgmo03[oOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CoooooW_moOgl00ol0003oVIVIoiVIV@1PoiVIV@03o`000?moOgooOgmo
03_oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooWomoOgl2o`0005oo
VIVI00?o0000ogmoOomoOgl0??moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?oooonQogmoO`03o`000?nIVIWoVIVI05_oVIVI00?o0000ogmoOomoOgl0?OmoOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?oooonRogmoO`03o`000?nIVIWoVIVI05SoVIVI0_l0
0010ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooj?oOgmo0_l0001E
oiVIV@?o0000@_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonUogmo
O`;o0000DOnIVIT2o`0004GoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
ooooYomoOgl2o`0004goVIVI0_l00017ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooojWoOgmo0ol00019oiVIV@03o`000?moOgooOgmo04OoOgmo1_ooool1o`00007ooooo
000Jooooo`;o00001Ooooon/ogmoO`?o0000A?nIVIT2o`0004[oOgmo1Oooool2o`00007ooooo000J
ooooo`03o`000?oooooooooo00Cooooo[omoOgl4o`0003ooVIVI00?o0000ogmoOomoOgl0B_moOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooncogmoO`?o0000>?nIVIT4o`00
04goOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo]_moOgl00ol0003o
VIVIoiVIV@0`oiVIV@Go0000DOmoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?oooongogmoO`[o00008?nIVIT8o`0005KoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00Cooooo`OmoOgl7o`0001;oVIVI1ol0001NogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooolSoOgmo4_l0001UogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`001oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`001ooo
ool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002?ooool00onHV9So8B4Q
onk^kP04ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool000Wooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooo
oooooooooooo000000Kooooo0ol00004ooooooooOgmo@?moOgl4ooooo`?o00000Oooool000[ooooo
00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000;ooooo`05o`000?ooooooooooooooool@
41000oooool00ol@413oooooooooo`04ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`001oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`001oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000Oooooo00GoV9RHoa0@4?l0
003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000Oooooo00Go410@okZj^_ooooooMgMgoc8b<P03
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool000_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000:
ooooo`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`?o00001?oo
ooooogmoOd3oOgmo1?ooool3o`00007ooooo0009ooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`002_ooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000Oooooo00Go410@
oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000Oooooo00GoZJVYoa0@4?l0003o410@
ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo
1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Oooooooogmo
Od3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Ooo
ooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo0009ooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b
<_o^k^h01_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000[o
oooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000oooo
ooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo0007ooooo`Go00000oooool01Ol@413o
oooooooooooooooo410@00Kooooo0ol00004ooooooooOgmo@?moOgl4ooooo`?o00000Oooool000Oo
oooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000
ooooooooool0oooooom:ooooo`7o00000Oooool000Oooooo00CogMgMoeEEEOoooooo00001?ooool0
1Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0oooooom:ooooo`7o00000Ooo
ool000Sooooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo410@00Kooooo00?o
0000ooooooooool0oooooom:ooooo`7o00000Oooool000Sooooo00?ok^k^odA4A?l000001?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooom:ooooo`7o00000Ooo
ool000Wooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03gooooo00?o
0000ooooooooool0?Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo02?ooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo0Ol00001
ooooo`006_ooooooo`0004ko00000Oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-30.1723, -14.304, 0.195672, \
0.195672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0192308 0.211538 0.0192308 [
[.11538 -0.0125 -9 -9 ]
[.11538 -0.0125 9 0 ]
[.30769 -0.0125 -9 -9 ]
[.30769 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69231 -0.0125 -6 -9 ]
[.69231 -0.0125 6 0 ]
[.88462 -0.0125 -6 -9 ]
[.88462 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -18 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .21154 -6 -4.5 ]
[-0.0125 .21154 0 4.5 ]
[-0.0125 .40385 -12 -4.5 ]
[-0.0125 .40385 0 4.5 ]
[-0.0125 .59615 -12 -4.5 ]
[-0.0125 .59615 0 4.5 ]
[-0.0125 .78846 -12 -4.5 ]
[-0.0125 .78846 0 4.5 ]
[-0.0125 .98077 -12 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11538 0 m
.11538 .00625 L
s
[(-20)] .11538 -0.0125 0 1 Mshowa
.30769 0 m
.30769 .00625 L
s
[(-10)] .30769 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69231 0 m
.69231 .00625 L
s
[(10)] .69231 -0.0125 0 1 Mshowa
.88462 0 m
.88462 .00625 L
s
[(20)] .88462 -0.0125 0 1 Mshowa
.125 Mabswid
.15385 0 m
.15385 .00375 L
s
.19231 0 m
.19231 .00375 L
s
.23077 0 m
.23077 .00375 L
s
.26923 0 m
.26923 .00375 L
s
.34615 0 m
.34615 .00375 L
s
.38462 0 m
.38462 .00375 L
s
.42308 0 m
.42308 .00375 L
s
.46154 0 m
.46154 .00375 L
s
.53846 0 m
.53846 .00375 L
s
.57692 0 m
.57692 .00375 L
s
.61538 0 m
.61538 .00375 L
s
.65385 0 m
.65385 .00375 L
s
.73077 0 m
.73077 .00375 L
s
.76923 0 m
.76923 .00375 L
s
.80769 0 m
.80769 .00375 L
s
.84615 0 m
.84615 .00375 L
s
.07692 0 m
.07692 .00375 L
s
.03846 0 m
.03846 .00375 L
s
.92308 0 m
.92308 .00375 L
s
.96154 0 m
.96154 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(-10)] -0.0125 .01923 1 0 Mshowa
0 .21154 m
.00625 .21154 L
s
[(0)] -0.0125 .21154 1 0 Mshowa
0 .40385 m
.00625 .40385 L
s
[(10)] -0.0125 .40385 1 0 Mshowa
0 .59615 m
.00625 .59615 L
s
[(20)] -0.0125 .59615 1 0 Mshowa
0 .78846 m
.00625 .78846 L
s
[(30)] -0.0125 .78846 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(40)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .05769 m
.00375 .05769 L
s
0 .09615 m
.00375 .09615 L
s
0 .13462 m
.00375 .13462 L
s
0 .17308 m
.00375 .17308 L
s
0 .25 m
.00375 .25 L
s
0 .28846 m
.00375 .28846 L
s
0 .32692 m
.00375 .32692 L
s
0 .36538 m
.00375 .36538 L
s
0 .44231 m
.00375 .44231 L
s
0 .48077 m
.00375 .48077 L
s
0 .51923 m
.00375 .51923 L
s
0 .55769 m
.00375 .55769 L
s
0 .63462 m
.00375 .63462 L
s
0 .67308 m
.00375 .67308 L
s
0 .71154 m
.00375 .71154 L
s
0 .75 m
.00375 .75 L
s
0 .82692 m
.00375 .82692 L
s
0 .86538 m
.00375 .86538 L
s
0 .90385 m
.00375 .90385 L
s
0 .94231 m
.00375 .94231 L
s
.25 Mabswid
0 0 m
0 1 L
s
.11538 .99375 m
.11538 1 L
s
.30769 .99375 m
.30769 1 L
s
.5 .99375 m
.5 1 L
s
.69231 .99375 m
.69231 1 L
s
.88462 .99375 m
.88462 1 L
s
.125 Mabswid
.15385 .99625 m
.15385 1 L
s
.19231 .99625 m
.19231 1 L
s
.23077 .99625 m
.23077 1 L
s
.26923 .99625 m
.26923 1 L
s
.34615 .99625 m
.34615 1 L
s
.38462 .99625 m
.38462 1 L
s
.42308 .99625 m
.42308 1 L
s
.46154 .99625 m
.46154 1 L
s
.53846 .99625 m
.53846 1 L
s
.57692 .99625 m
.57692 1 L
s
.61538 .99625 m
.61538 1 L
s
.65385 .99625 m
.65385 1 L
s
.73077 .99625 m
.73077 1 L
s
.76923 .99625 m
.76923 1 L
s
.80769 .99625 m
.80769 1 L
s
.84615 .99625 m
.84615 1 L
s
.07692 .99625 m
.07692 1 L
s
.03846 .99625 m
.03846 1 L
s
.92308 .99625 m
.92308 1 L
s
.96154 .99625 m
.96154 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .21154 m
1 .21154 L
s
.99375 .40385 m
1 .40385 L
s
.99375 .59615 m
1 .59615 L
s
.99375 .78846 m
1 .78846 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .05769 m
1 .05769 L
s
.99625 .09615 m
1 .09615 L
s
.99625 .13462 m
1 .13462 L
s
.99625 .17308 m
1 .17308 L
s
.99625 .25 m
1 .25 L
s
.99625 .28846 m
1 .28846 L
s
.99625 .32692 m
1 .32692 L
s
.99625 .36538 m
1 .36538 L
s
.99625 .44231 m
1 .44231 L
s
.99625 .48077 m
1 .48077 L
s
.99625 .51923 m
1 .51923 L
s
.99625 .55769 m
1 .55769 L
s
.99625 .63462 m
1 .63462 L
s
.99625 .67308 m
1 .67308 L
s
.99625 .71154 m
1 .71154 L
s
.99625 .75 m
1 .75 L
s
.99625 .82692 m
1 .82692 L
s
.99625 .86538 m
1 .86538 L
s
.99625 .90385 m
1 .90385 L
s
.99625 .94231 m
1 .94231 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.4 g
.47057 .46571 m
.49019 .46393 L
.50965 .47057 L
.50981 .4706 L
.52943 .47477 L
.54906 .47856 L
.56868 .47672 L
.5883 .48267 L
.60793 .48599 L
.62755 .48783 L
.64717 .48858 L
.6668 .48844 L
.68642 .48738 L
.70604 .48512 L
.72567 .48117 L
.74529 .47356 L
.76491 .47741 L
.78454 .47346 L
.79812 .47057 L
.80416 .46914 L
.82378 .46645 L
.84341 .46627 L
.85362 .47057 L
.84341 .48752 L
.84093 .49019 L
.82378 .50286 L
.81184 .50981 L
.80416 .51403 L
.78454 .52729 L
.76657 .52943 L
.76491 .53006 L
.74529 .53356 L
.72567 .53949 L
.70604 .54393 L
.68642 .54668 L
.6668 .54796 L
.64717 .54812 L
.62755 .54723 L
.60793 .54498 L
.5883 .54109 L
.56868 .53556 L
.54906 .52975 L
.5412 .52943 L
.52943 .52536 L
.50981 .51791 L
.49572 .50981 L
.49019 .5067 L
.47057 .49345 L
.46689 .49019 L
.45573 .47057 L
F
0 g
.47057 .46571 m
.49019 .46393 L
.50965 .47057 L
.50981 .4706 L
.52943 .47477 L
.54906 .47856 L
.56868 .47672 L
.5883 .48267 L
.60793 .48599 L
.62755 .48783 L
.64717 .48858 L
.6668 .48844 L
.68642 .48738 L
.70604 .48512 L
.72567 .48117 L
.74529 .47356 L
.76491 .47741 L
.78454 .47346 L
.79812 .47057 L
.80416 .46914 L
.82378 .46645 L
.84341 .46627 L
.85362 .47057 L
.84341 .48752 L
.84093 .49019 L
.82378 .50286 L
.81184 .50981 L
.80416 .51403 L
.78454 .52729 L
.76657 .52943 L
.76491 .53006 L
.74529 .53356 L
.72567 .53949 L
.70604 .54393 L
.68642 .54668 L
.6668 .54796 L
.64717 .54812 L
.62755 .54723 L
.60793 .54498 L
.5883 .54109 L
.56868 .53556 L
.54906 .52975 L
.5412 .52943 L
.52943 .52536 L
.50981 .51791 L
.49572 .50981 L
.49019 .5067 L
.47057 .49345 L
.46689 .49019 L
.45573 .47057 L
Mistroke
.47057 .46571 L
Mfstroke
.6 g
.47057 .40961 m
.49019 .40935 L
.50679 .4117 L
.50981 .41217 L
.52943 .41537 L
.54906 .41845 L
.56868 .41974 L
.5883 .42531 L
.60793 .42983 L
.62755 .4265 L
.64717 .42706 L
.6668 .42695 L
.68642 .42618 L
.70604 .42845 L
.72567 .4237 L
.74529 .41736 L
.76491 .4175 L
.78454 .41434 L
.80092 .4117 L
.80416 .41121 L
.82378 .40748 L
.84341 .41108 L
.84527 .4117 L
.84341 .42819 L
.84092 .43132 L
.82378 .44323 L
.80962 .45094 L
.80416 .45414 L
.78454 .46139 L
.76491 .46768 L
.75449 .47057 L
.74529 .4707 L
.72567 .4754 L
.70604 .47973 L
.68642 .48281 L
.6668 .48449 L
.64717 .48473 L
.62755 .4835 L
.60793 .48086 L
.5883 .4769 L
.56868 .47205 L
.55312 .47057 L
.54906 .46947 L
.52943 .46352 L
.50981 .45828 L
.49795 .45094 L
.49019 .44688 L
.47057 .43439 L
.46693 .43132 L
.45763 .4117 L
F
0 g
.47057 .40961 m
.49019 .40935 L
.50679 .4117 L
.50981 .41217 L
.52943 .41537 L
.54906 .41845 L
.56868 .41974 L
.5883 .42531 L
.60793 .42983 L
.62755 .4265 L
.64717 .42706 L
.6668 .42695 L
.68642 .42618 L
.70604 .42845 L
.72567 .4237 L
.74529 .41736 L
.76491 .4175 L
.78454 .41434 L
.80092 .4117 L
.80416 .41121 L
.82378 .40748 L
.84341 .41108 L
.84527 .4117 L
.84341 .42819 L
.84092 .43132 L
.82378 .44323 L
.80962 .45094 L
.80416 .45414 L
.78454 .46139 L
.76491 .46768 L
.75449 .47057 L
.74529 .4707 L
.72567 .4754 L
.70604 .47973 L
.68642 .48281 L
.6668 .48449 L
.64717 .48473 L
.62755 .4835 L
.60793 .48086 L
.5883 .4769 L
.56868 .47205 L
.55312 .47057 L
.54906 .46947 L
.52943 .46352 L
.50981 .45828 L
.49795 .45094 L
.49019 .44688 L
.47057 .43439 L
.46693 .43132 L
.45763 .4117 L
Mistroke
.47057 .40961 L
Mfstroke
.4 g
.49019 .36588 m
.50981 .3636 L
.52943 .35907 L
.54906 .37104 L
.56868 .36803 L
.5883 .36991 L
.60793 .37147 L
.62474 .37245 L
.62755 .37254 L
.64717 .37299 L
.6668 .37291 L
.68247 .37245 L
.68642 .37226 L
.70604 .37102 L
.72567 .36934 L
.74529 .3674 L
.76491 .36784 L
.78454 .36398 L
.80416 .36379 L
.82378 .36924 L
.82584 .37245 L
.82378 .37641 L
.80611 .39207 L
.80416 .39309 L
.78454 .40112 L
.76491 .40767 L
.75083 .4117 L
.74529 .41277 L
.72567 .41841 L
.70604 .42484 L
.68642 .4213 L
.6668 .42229 L
.64717 .42243 L
.62755 .42171 L
.60793 .42699 L
.5883 .42041 L
.56868 .4144 L
.55684 .4117 L
.54906 .40955 L
.52943 .40333 L
.50981 .39589 L
.50169 .39207 L
.49019 .38336 L
.48183 .37245 L
F
0 g
.49019 .36588 m
.50981 .3636 L
.52943 .35907 L
.54906 .37104 L
.56868 .36803 L
.5883 .36991 L
.60793 .37147 L
.62474 .37245 L
.62755 .37254 L
.64717 .37299 L
.6668 .37291 L
.68247 .37245 L
.68642 .37226 L
.70604 .37102 L
.72567 .36934 L
.74529 .3674 L
.76491 .36784 L
.78454 .36398 L
.80416 .36379 L
.82378 .36924 L
.82584 .37245 L
.82378 .37641 L
.80611 .39207 L
.80416 .39309 L
.78454 .40112 L
.76491 .40767 L
.75083 .4117 L
.74529 .41277 L
.72567 .41841 L
.70604 .42484 L
.68642 .4213 L
.6668 .42229 L
.64717 .42243 L
.62755 .42171 L
.60793 .42699 L
.5883 .42041 L
.56868 .4144 L
.55684 .4117 L
.54906 .40955 L
.52943 .40333 L
.50981 .39589 L
.50169 .39207 L
.49019 .38336 L
.48183 .37245 L
.49019 .36588 L
s
.6 g
.50981 .54869 m
.52891 .54906 L
.52943 .54912 L
.54906 .5521 L
.56868 .55523 L
.5883 .55793 L
.60793 .55999 L
.62755 .56133 L
.64717 .56195 L
.6668 .56183 L
.68642 .56098 L
.70604 .55941 L
.72567 .55713 L
.74529 .55426 L
.76491 .55108 L
.77895 .54906 L
.78454 .54859 L
.79984 .54906 L
.78972 .56868 L
.78454 .57219 L
.76491 .58242 L
.75008 .5883 L
.74529 .59023 L
.72567 .59911 L
.70604 .60071 L
.68642 .60354 L
.6668 .60503 L
.64717 .60523 L
.62755 .60416 L
.60793 .60177 L
.5883 .60264 L
.56868 .59288 L
.5576 .5883 L
.54906 .58505 L
.52943 .5759 L
.51792 .56868 L
.50981 .56176 L
.50777 .54906 L
F
0 g
.50981 .54869 m
.52891 .54906 L
.52943 .54912 L
.54906 .5521 L
.56868 .55523 L
.5883 .55793 L
.60793 .55999 L
.62755 .56133 L
.64717 .56195 L
.6668 .56183 L
.68642 .56098 L
.70604 .55941 L
.72567 .55713 L
.74529 .55426 L
.76491 .55108 L
.77895 .54906 L
.78454 .54859 L
.79984 .54906 L
.78972 .56868 L
.78454 .57219 L
.76491 .58242 L
.75008 .5883 L
.74529 .59023 L
.72567 .59911 L
.70604 .60071 L
.68642 .60354 L
.6668 .60503 L
.64717 .60523 L
.62755 .60416 L
.60793 .60177 L
.5883 .60264 L
.56868 .59288 L
.5576 .5883 L
.54906 .58505 L
.52943 .5759 L
.51792 .56868 L
.50981 .56176 L
.50777 .54906 L
.50981 .54869 L
s
.7 g
.52943 .42804 m
.54906 .42737 L
.56868 .42662 L
.5883 .42952 L
.60793 .43103 L
.62753 .43132 L
.62755 .43132 L
.64717 .43174 L
.6668 .43166 L
.68006 .43132 L
.68642 .4311 L
.70604 .43068 L
.72567 .42878 L
.74529 .42511 L
.76491 .42733 L
.78454 .42913 L
.79074 .43132 L
.78454 .44602 L
.77856 .45094 L
.76491 .45761 L
.74529 .46483 L
.72567 .47036 L
.72484 .47057 L
.70604 .47452 L
.68642 .47809 L
.6668 .48025 L
.64717 .48057 L
.62755 .47896 L
.60793 .47577 L
.5883 .47169 L
.58285 .47057 L
.56868 .46676 L
.54906 .46014 L
.52943 .45113 L
.52911 .45094 L
.51661 .43132 L
F
0 g
.52943 .42804 m
.54906 .42737 L
.56868 .42662 L
.5883 .42952 L
.60793 .43103 L
.62753 .43132 L
.62755 .43132 L
.64717 .43174 L
.6668 .43166 L
.68006 .43132 L
.68642 .4311 L
.70604 .43068 L
.72567 .42878 L
.74529 .42511 L
.76491 .42733 L
.78454 .42913 L
.79074 .43132 L
.78454 .44602 L
.77856 .45094 L
.76491 .45761 L
.74529 .46483 L
.72567 .47036 L
.72484 .47057 L
.70604 .47452 L
.68642 .47809 L
.6668 .48025 L
.64717 .48057 L
.62755 .47896 L
.60793 .47577 L
.5883 .47169 L
.58285 .47057 L
.56868 .46676 L
.54906 .46014 L
.52943 .45113 L
.52911 .45094 L
.51661 .43132 L
.52943 .42804 L
s
.6 g
.52943 .32868 m
.54906 .32474 L
.56868 .32406 L
.5883 .32426 L
.60793 .32404 L
.62755 .32926 L
.64717 .33151 L
.6668 .33107 L
.68642 .32799 L
.70604 .32105 L
.72567 .32415 L
.74529 .32413 L
.76491 .32538 L
.78338 .3332 L
.76491 .3475 L
.75299 .35283 L
.74529 .35479 L
.72567 .35882 L
.70604 .36181 L
.68642 .36386 L
.6668 .36497 L
.64717 .36512 L
.62755 .36432 L
.60793 .36257 L
.5883 .35988 L
.56868 .35621 L
.55467 .35283 L
.54906 .35051 L
.52943 .33896 L
.52433 .3332 L
F
0 g
.52943 .32868 m
.54906 .32474 L
.56868 .32406 L
.5883 .32426 L
.60793 .32404 L
.62755 .32926 L
.64717 .33151 L
.6668 .33107 L
.68642 .32799 L
.70604 .32105 L
.72567 .32415 L
.74529 .32413 L
.76491 .32538 L
.78338 .3332 L
.76491 .3475 L
.75299 .35283 L
.74529 .35479 L
.72567 .35882 L
.70604 .36181 L
.68642 .36386 L
.6668 .36497 L
.64717 .36512 L
.62755 .36432 L
.60793 .36257 L
.5883 .35988 L
.56868 .35621 L
.55467 .35283 L
.54906 .35051 L
.52943 .33896 L
.52433 .3332 L
.52943 .32868 L
s
.3 g
.54906 .4895 m
.56817 .49019 L
.56868 .49022 L
.5883 .49172 L
.60793 .49308 L
.62755 .49405 L
.64717 .49451 L
.6668 .49442 L
.68642 .49379 L
.70604 .49268 L
.72567 .49123 L
.73959 .49019 L
.74529 .48943 L
.76491 .48959 L
.77232 .49019 L
.77028 .50981 L
.76491 .51305 L
.74529 .52198 L
.72567 .5284 L
.72195 .52943 L
.70604 .53347 L
.68642 .5376 L
.6668 .54011 L
.64717 .54047 L
.62755 .53861 L
.60793 .53493 L
.5883 .53008 L
.58582 .52943 L
.56868 .52424 L
.54906 .51629 L
.53739 .50981 L
.53536 .49019 L
F
0 g
.54906 .4895 m
.56817 .49019 L
.56868 .49022 L
.5883 .49172 L
.60793 .49308 L
.62755 .49405 L
.64717 .49451 L
.6668 .49442 L
.68642 .49379 L
.70604 .49268 L
.72567 .49123 L
.73959 .49019 L
.74529 .48943 L
.76491 .48959 L
.77232 .49019 L
.77028 .50981 L
.76491 .51305 L
.74529 .52198 L
.72567 .5284 L
.72195 .52943 L
.70604 .53347 L
.68642 .5376 L
.6668 .54011 L
.64717 .54047 L
.62755 .53861 L
.60793 .53493 L
.5883 .53008 L
.58582 .52943 L
.56868 .52424 L
.54906 .51629 L
.53739 .50981 L
.53536 .49019 L
.54906 .4895 L
s
.3 g
.54906 .38261 m
.56868 .37948 L
.5883 .37897 L
.60793 .37911 L
.62755 .37937 L
.64717 .37952 L
.6668 .37949 L
.68642 .37929 L
.70604 .37904 L
.72567 .37902 L
.74529 .37998 L
.76491 .38669 L
.76532 .39207 L
.76491 .39239 L
.74529 .4027 L
.72567 .40945 L
.71734 .4117 L
.70604 .41599 L
.68642 .41609 L
.6668 .41736 L
.64717 .41753 L
.62755 .41662 L
.60793 .41853 L
.5904 .4117 L
.5883 .41115 L
.56868 .40512 L
.54906 .3964 L
.54237 .39207 L
F
0 g
.54906 .38261 m
.56868 .37948 L
.5883 .37897 L
.60793 .37911 L
.62755 .37937 L
.64717 .37952 L
.6668 .37949 L
.68642 .37929 L
.70604 .37904 L
.72567 .37902 L
.74529 .37998 L
.76491 .38669 L
.76532 .39207 L
.76491 .39239 L
.74529 .4027 L
.72567 .40945 L
.71734 .4117 L
.70604 .41599 L
.68642 .41609 L
.6668 .41736 L
.64717 .41753 L
.62755 .41662 L
.60793 .41853 L
.5904 .4117 L
.5883 .41115 L
.56868 .40512 L
.54906 .3964 L
.54237 .39207 L
.54906 .38261 L
s
.8 g
.56868 .43807 m
.5883 .43669 L
.60793 .43665 L
.62755 .43687 L
.64717 .43702 L
.6668 .43699 L
.68642 .4368 L
.70604 .43661 L
.72567 .43688 L
.74529 .43946 L
.75078 .45094 L
.74529 .45419 L
.72567 .46225 L
.70604 .4676 L
.69039 .47057 L
.68642 .47122 L
.6668 .47377 L
.64717 .47415 L
.62755 .47224 L
.61629 .47057 L
.60793 .4689 L
.5883 .4642 L
.56868 .4572 L
.55689 .45094 L
F
0 g
.56868 .43807 m
.5883 .43669 L
.60793 .43665 L
.62755 .43687 L
.64717 .43702 L
.6668 .43699 L
.68642 .4368 L
.70604 .43661 L
.72567 .43688 L
.74529 .43946 L
.75078 .45094 L
.74529 .45419 L
.72567 .46225 L
.70604 .4676 L
.69039 .47057 L
.68642 .47122 L
.6668 .47377 L
.64717 .47415 L
.62755 .47224 L
.61629 .47057 L
.60793 .4689 L
.5883 .4642 L
.56868 .4572 L
.55689 .45094 L
.56868 .43807 L
s
.2 g
.5883 .50649 m
.60793 .50348 L
.62755 .50294 L
.64717 .50285 L
.6668 .50286 L
.68642 .50303 L
.70604 .50393 L
.72364 .50981 L
.70604 .51916 L
.68642 .52404 L
.6668 .52643 L
.64717 .52675 L
.62755 .52504 L
.60793 .52105 L
.5883 .51328 L
.58408 .50981 L
F
0 g
.5883 .50649 m
.60793 .50348 L
.62755 .50294 L
.64717 .50285 L
.6668 .50286 L
.68642 .50303 L
.70604 .50393 L
.72364 .50981 L
.70604 .51916 L
.68642 .52404 L
.6668 .52643 L
.64717 .52675 L
.62755 .52504 L
.60793 .52105 L
.5883 .51328 L
.58408 .50981 L
.5883 .50649 L
s
.2 g
.5883 .39137 m
.60793 .38799 L
.62755 .38699 L
.64717 .38668 L
.6668 .38673 L
.68642 .3872 L
.70604 .38863 L
.72134 .39207 L
.70604 .404 L
.68642 .40915 L
.6668 .41154 L
.66403 .4117 L
.64717 .41181 L
.64367 .4117 L
.62755 .41016 L
.60793 .40604 L
.5883 .39687 L
.58652 .39207 L
F
0 g
.5883 .39137 m
.60793 .38799 L
.62755 .38699 L
.64717 .38668 L
.6668 .38673 L
.68642 .3872 L
.70604 .38863 L
.72134 .39207 L
.70604 .404 L
.68642 .40915 L
.6668 .41154 L
.66403 .4117 L
.64717 .41181 L
.64367 .4117 L
.62755 .41016 L
.60793 .40604 L
.5883 .39687 L
.58652 .39207 L
.5883 .39137 L
s
.9 g
.60793 .44494 m
.62755 .44367 L
.64717 .44332 L
.6668 .44338 L
.68642 .44393 L
.70604 .44584 L
.71817 .45094 L
.70604 .45779 L
.68642 .46313 L
.6668 .46564 L
.64717 .46598 L
.62755 .46419 L
.60793 .4599 L
.58967 .45094 L
F
0 g
.60793 .44494 m
.62755 .44367 L
.64717 .44332 L
.6668 .44338 L
.68642 .44393 L
.70604 .44584 L
.71817 .45094 L
.70604 .45779 L
.68642 .46313 L
.6668 .46564 L
.64717 .46598 L
.62755 .46419 L
.60793 .4599 L
.58967 .45094 L
.60793 .44494 L
s
.7 g
.64717 .34309 m
.6668 .34343 L
.67647 .35283 L
.6668 .35368 L
.64717 .35397 L
.6312 .35283 L
F
0 g
.64717 .34309 m
.6668 .34343 L
.67647 .35283 L
.6668 .35368 L
.64717 .35397 L
.6312 .35283 L
.64717 .34309 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00?Oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0dooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kS?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0hooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8b
onk^kS?ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08_ooool003gooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0=_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0<oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg03?ooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL08_ooool003Gooooo1_l0
0003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400[ooooo`Ko0000
1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100<oooool01Ol@413o
oooooooooooooooo410@03[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@03Cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@02;ooooo000o
ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000fooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000cooooo`05o`000?ooooooooooooooool0
0000>_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000=Oooool00onH
V9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000008_ooool0043ooooo00?oMgMgofIV
I_ooool00_ooool01Ol0003ooooooooooooooooo000003Kooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000003?ooooo00Go0000ooooooooooooooooo`00000jooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`03ogMgMomVIVKooooo00;o
oooo00Go0000ooooooooooooooooo`00000Rooooo`00@Oooool01Ol0003ooooooooooooooooo410@
00?ooooo00?o410@ooooooooool0=?ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@4100<oooool01Ol@413ooooooooooooooooo410@03[ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@03Oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo023ooooo000mooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg03Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg03?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0jooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0cooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02;ooooo000mooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^03Cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^03?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`03oeEEEOmVIVKo000000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0cooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02;ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo000Joooooooo0000C_l00001ooooo`00
6_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0?Ooo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool08ooo
ool1o`00007ooooo0008ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKo
oooo00?o0000ooooooooool0oooooom:ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooom:ooooo`7o
00000Oooool000Go00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41001_ooool00ol0003oooooooooo`3ooooood[ooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?ooooooB?ooool3o`00007o
oooo000:ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo0008ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Oooooooogmo
Od3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Ooo
ooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000oooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`003ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000?ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000oooooo00Go0000oooooooooooooooo
o`000006ooooo`?o00001?ooooooogmoOd3oOgmo1?ooool3o`00007ooooo000?ooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool000oooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`003oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000?ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooon?oOgmo1Ol0001GogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
ojkoOgmo6?l0000JogmoO`?o00001OnIVIT=o`0004[oOgmo1_ooool1o`00007ooooo000Jooooo`;o
00001Ooooon[ogmoO`?o00006?nIVIT3o`0001GoOgmo0_l0000EoiVIV@Go0000AOmoOgl5ooooo`;o
00000Oooool001[ooooo00?o0000ooooooooool01?oooonXogmoO`?o00007_nIVIT5o`0000coOgmo
1?l0000LoiVIV@?o0000@_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
oonWogmoO`03o`000?nIVIWoVIVI02CoVIVI3?l0000RoiVIV@;o0000@OmoOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?oooonXogmoO`03o`000?nIVIWoVIVI053oVIVI00?o0000
ogmoOomoOgl0@OmoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonYogmo
O`;o0000ConIVIT00ol0003oOgmoogmoO`12ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04oooooj_oOgmo0_l0001<oiVIV@03o`000?moOgooOgmo04?oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00Cooooo[OmoOgl00ol0003oVIVIoiVIV@0OoiVIV@Wo0000
8?nIVIT00ol0003oOgmoogmoO`14ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooojkoOgmo0_l0000MoiVIV@;o00002Onc/k<00ol0003oVIVIoiVIV@0KoiVIV@;o0000Aomo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon`ogmoO`03o`000?nIVIWo
VIVI01WoVIVI00?o0000ok>c/onc/k<02_nc/k<00ol0003oVIVIoiVIV@0HoiVIV@;o0000BOmoOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonaogmoO`Co00005_nIVIT@o`00
01CoVIVI1Ol0001;ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooookGo
Ogmo1_l0000aoiVIV@?o0000D?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?oooonVogmoO`Go00004?moOgl6o`0002KoVIVI1Ol0001CogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04oooooj3oOgmo1_l00005ofIVIP;o00005?moOgl7o`0001;oVIVI3Ol0
000JogmoO`Ko0000>?moOgl6ooooo`7o00000Oooool001[ooooo0_l00005oooooi_oOgmo1Ol0000=
ofIVIP03o`000?moOgooOgmo01SoOgmo4_l0000QogmoO`Ko00001_mVIVH3o`0003GoOgmo1Oooool2
o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooV_moOgl00ol0003oIVIVofIVIP0AofIV
IP;o00000omoOgl>o`0002KoOgmo5?l0000?ofIVIP;o0000<omoOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?oooonIogmoO`03o`000?mVIVKoIVIV01CoIVIV0ol0000>ofIVIPgo
00001_moOglCo`0002CoIVIV00?o0000ogmoOomoOgl0<OmoOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?oooonIogmoO`03o`000?mVIVKoIVIV03;oIVIV1_l0000gofIVIP03o`00
0?moOgooOgmo037oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooV_mo
Ogl00ol0003oIVIVofIVIP0MofIVIPOo0000BOmVIVH2o`0003?oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CoooooVomoOgl00ol0003oIVIVofIVIP0EofIVIPOo00001om<C4`c
o`0001GoIVIV00?o0000ogmoOomoOgl0<omoOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?oooonLogmoO`;o00004_mVIVH3o`00047oC4a<0ol0000AofIVIP03o`000?moOgooOgmo
03CoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooW_moOgl00ol0003o
IVIVofIVIP0>ofIVIP03o`000?m<C4coC4a<013oC4a<8?l0000Eoda<C003o`000?mVIVKoIVIV00go
IVIV00?o0000ogmoOomoOgl0=OmoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?oooonOogmoO`03o`000?mVIVKoIVIV00coIVIV00?o0000oda<C?m<C4`03_m<C4`3o`00023o<c<c
1_l0000?oda<C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl0=_moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?oooonPogmoO`?o00002_mVIVH3o`0000coC4a<0ol0
000Yoc<c<`;o00003?m<C4`2o`0000_oIVIV0ol0000iogmoO`Kooooo0Ol00001ooooo`002?ooool4
o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h6ooooo`03o`000?oooooooooo00Co
ooooXomoOgl2o`0000_oIVIV0_l0000;oda<C0;o0000:?lc<c<00ol0003oC4a<oda<C00:oda<C0;o
00002omVIVH2o`0003coOgmo1_ooool1o`00007ooooo000:ooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00CoooooYOmoOgl2o`0000_o
IVIV0_l0000;oda<C0;o00009Olc<c<00ol0003oC4a<oda<C009oda<C0;o00002omVIVH2o`0003ko
Ogmo1_ooool1o`00007ooooo000:ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@4006ooooo`03o`000?oooooooooo00CoooooYomoOgl2o`0000_oIVIV0_l0000;oda<C0;o
00008_lc<c<00ol0003oC4a<oda<C008oda<C0;o00002_mVIVH3o`00043oOgmo1_ooool1o`00007o
oooo000:ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`?o
00001?oooonYogmoO`?o00002_mVIVH3o`0000[oC4a<0ol0000Loc<c<`?o00002?m<C4`3o`0000Wo
IVIV0ol00013ogmoO`Cooooo0ol00001ooooo`002_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooooooo`04ooooojcoOgmo0ol0000:ofIVIP?o
00002_m<C4`3o`0001Ko<c<c0ol00009oda<C0;o00002?mVIVH4o`0000ooOgmo1ol0000`ogmoO`Ko
oooo0Ol00001ooooo`002_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41001_ooool00ol0003oooooooooo`04oooooi7oOgmo4_l0000<ogmoO`Ko00001omVIVH3o`0000[o
C4a<5_l00007oda<C0Go00001omVIVH3o`0000coOgmo1ol00007oiVIV@Co0000;?moOgl6ooooo`7o
00000Oooool000[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Ko
oooo00?o0000ooooooooool01?oooonAogmoO`03o`000?nIVIWoVIVI00ooVIVI1?l0000>ogmoO`Co
00001_mVIVH2o`0002CoC4a<00?o0000ofIVI_mVIVH01omVIVH3o`0000WoOgmo1_l0000AoiVIV@03
o`000?moOgooOgmo02[oOgmo1_ooool1o`00007ooooo0008ooooo`03oeEEEOmVIVKo000000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo00CoooooT_moOgl00ol0003o
VIVIoiVIV@0BoiVIV@Oo00002omoOgl3o`0000GoIVIV0_l00004oda<C1ko00001omVIVH?o`0001Oo
VIVI00?o0000ogmoOomoOgl0:_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?oooonBogmoO`03o`000?nIVIWoVIVI01WoVIVI2ol00003ogmoO`Co00000omVIVH4o`0002;oIVIV
1_l0000SoiVIV@03o`000?moOgooOgmo02[oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CoooooTomoOgl00ol0003oVIVIoiVIV@0SoiVIV@?o00001?moOgl3o`0000CoIVIV6ol0
0004ofIVIPKo00009OnIVIT00ol0003oOgmoogmoO`0[ogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04oooooi?oOgmo00?o0000oiVIVOnIVIT07OnIVIT8o`000003oiVIVOl0003o
000000?o00000_moOglVo`0000GoVIVI1ol0000LoiVIV@03o`000?moOgooOgmo02_oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooTomoOgl00ol0003oVIVIoiVIV@0AoiVI
V@co00002?nc/k<<o`0001_oVIVI1?l000000onIVIWo0000o`000005o`0000Oo/k>c2ol0000AoiVI
V@03o`000?moOgooOgmo02_oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
ooooU?moOgl00ol0003oVIVIoiVIV@0>oiVIV@;o00006_nc/k<Vo`0001Wo/k>c00?o0000oiVIVOnI
VIT03?nIVIT2o`0002koOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
UOmoOgl2o`0000koVIVI00?o0000ok>c/onc/k<0F?nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`00
0?moOgooOgmo02koOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooUomo
Ogl2o`0000goVIVI00?o0000ok>c/onc/k<03Onc/k<io`00013o/k>c00?o0000oiVIVOnIVIT02onI
VIT00ol0003oOgmoogmoO`0_ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
oooooiWoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0;ok>c/`03o`000?o<c<co
c<c<03Ooc<c<0ol0000=ok>c/`03o`000?nIVIWoVIVI00[oVIVI00?o0000ogmoOomoOgl0<?moOgl6
ooooo`7o00000Oooool001[ooooo0_l00005oooooi[oOgmo0_l0000;oiVIV@03o`000?nc/k?o/k>c
00[o/k>c00?o0000olc<c?o<c<`02oo<c<`Po`0000ooc<c<00?o0000ok>c/onc/k<02onc/k<00ol0
003oVIVIoiVIV@08oiVIV@;o0000<omoOgl5ooooo`;o00000Oooool001[ooooo00?o0000oooooooo
ool01?oooonLogmoO`?o00002OnIVIT00ol0003o/k>cok>c/`08ok>c/`03o`000?o<c<coc<c<00Wo
c<c<0ol0000PonKViPGo00002oo<c<`00ol0003o/k>cok>c/`08ok>c/`;o00002?nIVIT3o`0003Go
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooWomoOgl2o`0000SoVIVI
0_l00007ok>c/`;o00002Oo<c<`2o`0002Soi^KV0_l00009olc<c0;o00001onc/k<2o`0000SoVIVI
0_l0000hogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooj7oOgmo00?o
0000oiVIVOnIVIT01onIVIT3o`0000Ko/k>c0_l00009olc<c0;o00009OoVi^H00ol0003oc<c<olc<
c007olc<c0;o00001onc/k<2o`0000SoVIVI0_l0000jogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04oooooj;oOgmo00?o0000oiVIVOnIVIT02OnIVIT2o`0000Ko/k>c0_l00009
olc<c0;o00008_oVi^H00ol0003oc<c<olc<c005olc<c0?o00002?nc/k<00ol0003oVIVIoiVIV@06
oiVIV@;o0000??moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonSogmo
O`?o00002_nIVIT2o`0000Ko/k>c0ol00008olc<c0?o00006ooVi^H4o`0000Koc<c<0_l00009ok>c
/`;o00001onIVIT2o`0003koOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
ooooY_moOgl3o`0000WoVIVI0_l00007ok>c/`;o00002Oo<c<`3o`00017oi^KV1ol00008olc<c0;o
00002?nc/k<3o`0000KoVIVI0ol00010ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04oooooiCoOgmo2ol0000:ogmoO`?o00002?nIVIT2o`0000Oo/k>c1?l00008olc<c17o0000
3?o<c<`3o`0000Ko/k>c1?l00006oiVIV@?o00004_moOgl5o`0002coOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CoooooT_moOgl2o`0000_oIVIV0ol0000:ogmoO`?o00001onI
VIT4o`0000Oo/k>c1Ol0000Kolc<c0Go00001_nc/k<3o`0000OoVIVI0ol0000:ogmoO`_o00001OmV
IVH2o`0002[oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooTOmoOgl0
0ol0003oIVIVofIVIP0>ofIVIPGo00002?moOgl:o`000003oiVIVOl0003o000000Co00001_nc/k<8
o`0000coc<c<1ol00006ok>c/`Go00000onIVIT7o`0000[oOgmo0ol0000BofIVIP03o`000?moOgoo
Ogmo02OoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooTOmoOgl00ol0
003oIVIVofIVIP0CofIVIPGo00003OmoOgl3o`0000CoVIVI0ol0000;ok>c/`co00001onc/k<6o`00
00GoVIVI2Ol00006ogmoO`Go00005OmVIVH00ol0003oOgmoogmoO`0WogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04oooooi;oOgmo00?o0000ofIVI_mVIVH05omVIVH3o`0000Co
Ogmo1_l00003ogmoO`Go00000_nIVIT5o`0001;o/k>c1ol00006oiVIV@So00001_mVIVH6o`0001Wo
IVIV00?o0000ogmoOomoOgl0:?moOgl6ooooo`7o00000Oooool001[ooooo0_l00005oooooi;oOgmo
00?o0000ofIVI_mVIVH06_mVIVH4o`0000KoIVIV0ol00005ogmoOaWo00001onIVIT6o`0000;oOgmo
0ol0000WofIVIP03o`000?moOgooOgmo02WoOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CoooooTomoOgl00ol0003oIVIVofIVIP0VofIVIPGo00001omoOgl6o`0000coVIVI1ol0
0005ogmoO`?o0000:_mVIVH00ol0003oOgmoogmoO`0YogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04oooooi?oOgmo00?o0000ofIVI_mVIVH0:omVIVH7o`0000KoOgmo3?l00007
ogmoO`Go0000;?mVIVH00ol0003oOgmoogmoO`0ZogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04oooooiCoOgmo00?o0000ofIVI_mVIVH05?mVIVH@o`0000goIVIV6Ol0000<ofIV
IPko00005OmVIVH2o`0002goOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
ooooU?moOgl00ol0003oIVIVofIVIP0DofIVIP03o`000?m<C4coC4a<00goC4a<3Ol0000IofIVIPco
00003Om<C4`00ol0003oIVIVofIVIP0BofIVIP03o`000?moOgooOgmo02goOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CoooooUOmoOgl2o`0001CoIVIV00?o0000oda<C?m<C4`0
6_m<C4`Io`0001WoC4a<00?o0000ofIVI_mVIVH04OmVIVH00ol0003oOgmoogmoO`0^ogmoO`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooiOoOgmo0_l0000BofIVIP03o`000?m<
C4coC4a<04coC4a<00?o0000ofIVI_mVIVH04?mVIVH00ol0003oOgmoogmoO`0_ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04oooooiWoOgmo00?o0000ofIVI_mVIVH04?mVIVH0
0ol0003oC4a<oda<C01:oda<C003o`000?mVIVKoIVIV013oIVIV00?o0000ogmoOomoOgl0<?moOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonJogmoO`;o00004?mVIVH00ol0
003oC4a<oda<C00Aoda<C2Oo00004_m<C4`00ol0003oIVIVofIVIP0>ofIVIP;o0000<omoOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonLogmoO`;o00003_mVIVH00ol0003o
C4a<oda<C00=oda<C0Co00009olc<c<3o`0000ooC4a<00?o0000ofIVI_mVIVH03?mVIVH2o`0003Go
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooW_moOgl2o`0000coIVIV
0_l0000=oda<C0;o0000;?lc<c<2o`0000goC4a<0_l0000<ofIVIP;o0000=omoOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?oooonPogmoO`;o00003?mVIVH2o`0000goC4a<0_l0
000Xoc<c<`;o00003Om<C4`2o`0000_oIVIV0ol0000iogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04oooooj;oOgmo00?o0000ofIVI_mVIVH02omVIVH2o`0000goC4a<0_l0000T
oc<c<`;o00003Om<C4`2o`0000coIVIV00?o0000ogmoOomoOgl0>_moOgl6ooooo`7o00000Oooool0
01[ooooo0_l00005oooooj?oOgmo0ol0000<ofIVIP;o00003Om<C4`2o`0001oo<c<c0ol0000=oda<
C0;o00003OmVIVH00ol0003oOgmoogmoO`0kogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooojKoOgmo0ol0000;ofIVIP;o00003Om<C4`5o`0001Oo<c<c0ol0000=oda<C0?o
00003_mVIVH00ol0003oOgmoogmoO`0logmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooojWoOgmo0ol0000:ofIVIPCo00003_m<C4`6o`0000Ko<c<c2ol0000=oda<C0?o0000
4?mVIVH00ol0003oOgmoogmoO`0mogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooojcoOgmo1?l0000:ofIVIP?o00004Om<C4`6o`0001CoC4a<1?l0000<ofIVIPOo0000@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon`ogmoO`?o00002_mVIVH4
o`0002CoC4a<0ol0000<ofIVIPCo0000AomoOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?ooooncogmoO`?o00002omVIVH5o`0001_oC4a<1?l0000:ofIVIPGo0000BomoOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonfogmoO`Go00002omVIVH3o`00017o
C4a<1ol0000;ofIVIP?o0000D?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?oooonkogmoO`Go00002OmVIVHAo`0000goIVIV1Ol0001CogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04oooool3oOgmo0ol0000NofIVIPKo0000F?moOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?ooooo3ogmoO`_o00003?mVIVH7o`0005koOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooX_moOgl<o`00023oOgmo3?l0000Pogmo
O`[o0000>omoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonRogmoO`03
o`000?nIVIWoVIVI00WoVIVI1_l00010ogmoO`Ko00002OnIVIT00ol0003oOgmoogmoO`0iogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooj;oOgmo00?o0000oiVIVOnIVIT0
3onIVIT7o`0003?oOgmo1_l0000>oiVIV@03o`000?moOgooOgmo03[oOgmo1_ooool1o`00007ooooo
000Jooooo`;o00001OoooonSogmoO`03o`000?nIVIWoVIVI01GoVIVI1_l0000PogmoO`go00005?nI
VIT00ol0003oOgmoogmoO`0jogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04
oooooj?oOgmo00?o0000oiVIVOnIVIT06onIVITPo`00023oVIVI00?o0000ogmoOomoOgl0>omoOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonSogmoO`03o`000?nIVIWoVIVI
05[oVIVI00?o0000ogmoOomoOgl0??moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?oooonTogmoO`03o`000?nIVIWoVIVI05WoVIVI00?o0000ogmoOomoOgl0??moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?oooonUogmoO`;o0000F?nIVIT00ol0003oOgmo
ogmoO`0mogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooojOoOgmo0_l0
001DoiVIV@;o0000@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonY
ogmoO`;o0000ConIVIT3o`0004;oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CoooooZomoOgl3o`0004[oVIVI0_l00015ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooojkoOgmo0_l00016oiVIV@;o0000AomoOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?oooon`ogmoO`;o0000@OnIVIT3o`0004WoOgmo1_ooool1o`00007ooooo
0007ooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0
1?oooonbogmoO`;o0000?_nIVIT00ol0003oOgmoogmoO`1:ogmoO`Kooooo0Ol00001ooooo`001ooo
ool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03
o`000?oooooooooo00Cooooo]?moOgl2o`0003[oVIVI0_l0001=ogmoO`Kooooo0Ol00001ooooo`00
2?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003o
ooooooooo`04oooookKoOgmo0_l0000eoiVIV@?o0000ComoOgl6ooooo`7o00000Oooool000Wooooo
00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000Kooooo0ol00004oooookSo
Ogmo0ol0000`oiVIV@;o0000D_moOgl4ooooo`?o00000Oooool000[ooooo00?oMgMgofIVI_ooool0
0_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool01?oooonkogmoO`;o
00009?nIVIT:o`0005CoOgmo1_ooool1o`00007ooooo000;ooooo`05o`000?ooooooooooooooool@
41000oooool00ol@413oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo_OmoOglAo`0000co
VIVI1ol0001NogmoO`Kooooo0Ol00001ooooo`001oooool01Ol0003o^[ZjoooooonHV9So410@00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00Coooooc_moOgl<o`00
06GoOgmo1_ooool1o`00007ooooo0007ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000GooooooomoOgm0ogmoO`Go
oooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`001oooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`001oooool01Ol@
413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002oooool01Ol0003ooooooooooooo
oooo410@00?ooooo00?o410@ooooooooool01?ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool000[ooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooo
oooo000000Kooooo0ol00004ooooooooOgmo@?moOgl4ooooo`?o00000Oooool000Wooooo00?o410@
o`000?nj^[X00oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000:ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@
oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`001oooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`001ooo
ool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo0_l00005
ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000Wooooo0_l000002Ol@413ooooooooo
ooooooook^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmo
O`Kooooo0Ol00001ooooo`002_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000Oo
oooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@41001_ooool3o`0000CooooooomoOgm0ogmo
O`Cooooo0ol00001ooooo`001oooool01?m4A4CogMgMooooool00004ooooo`05o`000?oooooooooo
ooooool000001_ooool00ol0003oooooooooo`3ooooood[ooooo0Ol00001ooooo`001oooool01?oM
gMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooooooo
o`3ooooood[ooooo0Ol00001ooooo`002?ooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooo
ooooooooool@41001_ooool00ol0003oooooooooo`3ooooood[ooooo0Ol00001ooooo`002?ooool0
0oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003ooooooooo
o`3ooooood[ooooo0Ol00001ooooo`002Oooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03gooooo00?o
0000ooooooooool0?Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03gooooo00?o
0000ooooooooool08oooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02Oooool1o`00007ooooo000Joooooooo0000C_l00001ooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-30.1723, -14.304, 0.195672, \
0.195672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0192308 0.211538 0.0192308 [
[.11538 -0.0125 -9 -9 ]
[.11538 -0.0125 9 0 ]
[.30769 -0.0125 -9 -9 ]
[.30769 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69231 -0.0125 -6 -9 ]
[.69231 -0.0125 6 0 ]
[.88462 -0.0125 -6 -9 ]
[.88462 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -18 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .21154 -6 -4.5 ]
[-0.0125 .21154 0 4.5 ]
[-0.0125 .40385 -12 -4.5 ]
[-0.0125 .40385 0 4.5 ]
[-0.0125 .59615 -12 -4.5 ]
[-0.0125 .59615 0 4.5 ]
[-0.0125 .78846 -12 -4.5 ]
[-0.0125 .78846 0 4.5 ]
[-0.0125 .98077 -12 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11538 0 m
.11538 .00625 L
s
[(-20)] .11538 -0.0125 0 1 Mshowa
.30769 0 m
.30769 .00625 L
s
[(-10)] .30769 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69231 0 m
.69231 .00625 L
s
[(10)] .69231 -0.0125 0 1 Mshowa
.88462 0 m
.88462 .00625 L
s
[(20)] .88462 -0.0125 0 1 Mshowa
.125 Mabswid
.15385 0 m
.15385 .00375 L
s
.19231 0 m
.19231 .00375 L
s
.23077 0 m
.23077 .00375 L
s
.26923 0 m
.26923 .00375 L
s
.34615 0 m
.34615 .00375 L
s
.38462 0 m
.38462 .00375 L
s
.42308 0 m
.42308 .00375 L
s
.46154 0 m
.46154 .00375 L
s
.53846 0 m
.53846 .00375 L
s
.57692 0 m
.57692 .00375 L
s
.61538 0 m
.61538 .00375 L
s
.65385 0 m
.65385 .00375 L
s
.73077 0 m
.73077 .00375 L
s
.76923 0 m
.76923 .00375 L
s
.80769 0 m
.80769 .00375 L
s
.84615 0 m
.84615 .00375 L
s
.07692 0 m
.07692 .00375 L
s
.03846 0 m
.03846 .00375 L
s
.92308 0 m
.92308 .00375 L
s
.96154 0 m
.96154 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(-10)] -0.0125 .01923 1 0 Mshowa
0 .21154 m
.00625 .21154 L
s
[(0)] -0.0125 .21154 1 0 Mshowa
0 .40385 m
.00625 .40385 L
s
[(10)] -0.0125 .40385 1 0 Mshowa
0 .59615 m
.00625 .59615 L
s
[(20)] -0.0125 .59615 1 0 Mshowa
0 .78846 m
.00625 .78846 L
s
[(30)] -0.0125 .78846 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(40)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .05769 m
.00375 .05769 L
s
0 .09615 m
.00375 .09615 L
s
0 .13462 m
.00375 .13462 L
s
0 .17308 m
.00375 .17308 L
s
0 .25 m
.00375 .25 L
s
0 .28846 m
.00375 .28846 L
s
0 .32692 m
.00375 .32692 L
s
0 .36538 m
.00375 .36538 L
s
0 .44231 m
.00375 .44231 L
s
0 .48077 m
.00375 .48077 L
s
0 .51923 m
.00375 .51923 L
s
0 .55769 m
.00375 .55769 L
s
0 .63462 m
.00375 .63462 L
s
0 .67308 m
.00375 .67308 L
s
0 .71154 m
.00375 .71154 L
s
0 .75 m
.00375 .75 L
s
0 .82692 m
.00375 .82692 L
s
0 .86538 m
.00375 .86538 L
s
0 .90385 m
.00375 .90385 L
s
0 .94231 m
.00375 .94231 L
s
.25 Mabswid
0 0 m
0 1 L
s
.11538 .99375 m
.11538 1 L
s
.30769 .99375 m
.30769 1 L
s
.5 .99375 m
.5 1 L
s
.69231 .99375 m
.69231 1 L
s
.88462 .99375 m
.88462 1 L
s
.125 Mabswid
.15385 .99625 m
.15385 1 L
s
.19231 .99625 m
.19231 1 L
s
.23077 .99625 m
.23077 1 L
s
.26923 .99625 m
.26923 1 L
s
.34615 .99625 m
.34615 1 L
s
.38462 .99625 m
.38462 1 L
s
.42308 .99625 m
.42308 1 L
s
.46154 .99625 m
.46154 1 L
s
.53846 .99625 m
.53846 1 L
s
.57692 .99625 m
.57692 1 L
s
.61538 .99625 m
.61538 1 L
s
.65385 .99625 m
.65385 1 L
s
.73077 .99625 m
.73077 1 L
s
.76923 .99625 m
.76923 1 L
s
.80769 .99625 m
.80769 1 L
s
.84615 .99625 m
.84615 1 L
s
.07692 .99625 m
.07692 1 L
s
.03846 .99625 m
.03846 1 L
s
.92308 .99625 m
.92308 1 L
s
.96154 .99625 m
.96154 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .21154 m
1 .21154 L
s
.99375 .40385 m
1 .40385 L
s
.99375 .59615 m
1 .59615 L
s
.99375 .78846 m
1 .78846 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .05769 m
1 .05769 L
s
.99625 .09615 m
1 .09615 L
s
.99625 .13462 m
1 .13462 L
s
.99625 .17308 m
1 .17308 L
s
.99625 .25 m
1 .25 L
s
.99625 .28846 m
1 .28846 L
s
.99625 .32692 m
1 .32692 L
s
.99625 .36538 m
1 .36538 L
s
.99625 .44231 m
1 .44231 L
s
.99625 .48077 m
1 .48077 L
s
.99625 .51923 m
1 .51923 L
s
.99625 .55769 m
1 .55769 L
s
.99625 .63462 m
1 .63462 L
s
.99625 .67308 m
1 .67308 L
s
.99625 .71154 m
1 .71154 L
s
.99625 .75 m
1 .75 L
s
.99625 .82692 m
1 .82692 L
s
.99625 .86538 m
1 .86538 L
s
.99625 .90385 m
1 .90385 L
s
.99625 .94231 m
1 .94231 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.6 g
.47057 .43665 m
.49019 .43653 L
.50981 .43919 L
.52943 .439 L
.54906 .44757 L
.56868 .44911 L
.58101 .45094 L
.5883 .45201 L
.60793 .45431 L
.62755 .45592 L
.64717 .45684 L
.6668 .45706 L
.68642 .4566 L
.70604 .45545 L
.72567 .45361 L
.74529 .45107 L
.74607 .45094 L
.76491 .44804 L
.78454 .4451 L
.80416 .43332 L
.82378 .43816 L
.84341 .43602 L
.86303 .43963 L
.86401 .45094 L
.86303 .45213 L
.84341 .46867 L
.8406 .47057 L
.82378 .47963 L
.80416 .48822 L
.79907 .49019 L
.78454 .49454 L
.76491 .50272 L
.74529 .50571 L
.72567 .50926 L
.72218 .50981 L
.70604 .51199 L
.68642 .51368 L
.6668 .51435 L
.64717 .51402 L
.62755 .51268 L
.60793 .51028 L
.60485 .50981 L
.5883 .50702 L
.56868 .50551 L
.54906 .49729 L
.52943 .49037 L
.52785 .49019 L
.50981 .48271 L
.49019 .4743 L
.48655 .47057 L
.47057 .45862 L
.46299 .45094 L
F
0 g
.47057 .43665 m
.49019 .43653 L
.50981 .43919 L
.52943 .439 L
.54906 .44757 L
.56868 .44911 L
.58101 .45094 L
.5883 .45201 L
.60793 .45431 L
.62755 .45592 L
.64717 .45684 L
.6668 .45706 L
.68642 .4566 L
.70604 .45545 L
.72567 .45361 L
.74529 .45107 L
.74607 .45094 L
.76491 .44804 L
.78454 .4451 L
.80416 .43332 L
.82378 .43816 L
.84341 .43602 L
.86303 .43963 L
.86401 .45094 L
.86303 .45213 L
.84341 .46867 L
.8406 .47057 L
.82378 .47963 L
.80416 .48822 L
.79907 .49019 L
.78454 .49454 L
.76491 .50272 L
.74529 .50571 L
.72567 .50926 L
.72218 .50981 L
.70604 .51199 L
.68642 .51368 L
.6668 .51435 L
.64717 .51402 L
.62755 .51268 L
.60793 .51028 L
.60485 .50981 L
.5883 .50702 L
.56868 .50551 L
.54906 .49729 L
.52943 .49037 L
.52785 .49019 L
.50981 .48271 L
.49019 .4743 L
.48655 .47057 L
Mistroke
.47057 .45862 L
.46299 .45094 L
.47057 .43665 L
Mfstroke
.4 g
.47057 .49672 m
.49019 .4969 L
.50981 .50027 L
.52943 .49905 L
.54906 .50743 L
.56002 .50981 L
.56868 .51168 L
.5883 .51501 L
.60793 .51757 L
.62755 .51935 L
.64717 .52037 L
.6668 .52062 L
.68642 .52011 L
.70604 .51884 L
.72567 .51679 L
.74529 .51397 L
.76491 .51037 L
.76689 .50981 L
.78454 .50533 L
.80416 .50281 L
.82378 .49901 L
.84341 .49616 L
.86102 .50981 L
.84341 .52641 L
.83934 .52943 L
.82378 .53929 L
.80433 .54906 L
.80416 .5491 L
.78454 .55709 L
.76491 .56559 L
.74889 .56868 L
.74529 .56966 L
.72567 .57072 L
.70604 .57439 L
.68642 .57688 L
.6668 .57788 L
.64717 .57738 L
.62755 .5754 L
.60793 .57205 L
.5883 .57136 L
.57802 .56868 L
.56868 .56783 L
.54906 .56014 L
.52943 .55133 L
.52274 .54906 L
.50981 .54286 L
.49019 .53205 L
.48764 .52943 L
.47057 .51513 L
.46601 .50981 L
F
0 g
.47057 .49672 m
.49019 .4969 L
.50981 .50027 L
.52943 .49905 L
.54906 .50743 L
.56002 .50981 L
.56868 .51168 L
.5883 .51501 L
.60793 .51757 L
.62755 .51935 L
.64717 .52037 L
.6668 .52062 L
.68642 .52011 L
.70604 .51884 L
.72567 .51679 L
.74529 .51397 L
.76491 .51037 L
.76689 .50981 L
.78454 .50533 L
.80416 .50281 L
.82378 .49901 L
.84341 .49616 L
.86102 .50981 L
.84341 .52641 L
.83934 .52943 L
.82378 .53929 L
.80433 .54906 L
.80416 .5491 L
.78454 .55709 L
.76491 .56559 L
.74889 .56868 L
.74529 .56966 L
.72567 .57072 L
.70604 .57439 L
.68642 .57688 L
.6668 .57788 L
.64717 .57738 L
.62755 .5754 L
.60793 .57205 L
.5883 .57136 L
.57802 .56868 L
.56868 .56783 L
.54906 .56014 L
.52943 .55133 L
.52274 .54906 L
.50981 .54286 L
.49019 .53205 L
.48764 .52943 L
.47057 .51513 L
.46601 .50981 L
Mistroke
.47057 .49672 L
Mfstroke
.4 g
.49019 .38952 m
.50981 .38668 L
.52943 .3901 L
.54522 .39207 L
.54906 .39256 L
.56868 .39495 L
.5883 .39706 L
.60793 .39531 L
.62755 .39994 L
.64717 .40224 L
.6668 .40281 L
.68642 .40165 L
.70604 .39871 L
.72567 .39824 L
.74529 .39638 L
.76491 .39416 L
.78102 .39207 L
.78454 .39169 L
.80416 .38941 L
.82378 .3884 L
.84341 .39173 L
.84405 .39207 L
.84341 .40295 L
.8359 .4117 L
.82378 .41865 L
.80416 .4278 L
.79546 .43132 L
.78454 .4364 L
.76491 .4402 L
.74529 .44445 L
.72567 .44783 L
.70604 .45033 L
.70146 .45094 L
.68642 .45186 L
.6668 .45246 L
.64717 .45217 L
.62755 .45097 L
.62723 .45094 L
.60793 .44878 L
.5883 .44569 L
.56868 .44175 L
.54906 .44039 L
.53129 .43132 L
.52943 .43059 L
.50981 .42194 L
.49087 .4117 L
.49019 .41106 L
.48201 .39207 L
F
0 g
.49019 .38952 m
.50981 .38668 L
.52943 .3901 L
.54522 .39207 L
.54906 .39256 L
.56868 .39495 L
.5883 .39706 L
.60793 .39531 L
.62755 .39994 L
.64717 .40224 L
.6668 .40281 L
.68642 .40165 L
.70604 .39871 L
.72567 .39824 L
.74529 .39638 L
.76491 .39416 L
.78102 .39207 L
.78454 .39169 L
.80416 .38941 L
.82378 .3884 L
.84341 .39173 L
.84405 .39207 L
.84341 .40295 L
.8359 .4117 L
.82378 .41865 L
.80416 .4278 L
.79546 .43132 L
.78454 .4364 L
.76491 .4402 L
.74529 .44445 L
.72567 .44783 L
.70604 .45033 L
.70146 .45094 L
.68642 .45186 L
.6668 .45246 L
.64717 .45217 L
.62755 .45097 L
.62723 .45094 L
.60793 .44878 L
.5883 .44569 L
.56868 .44175 L
.54906 .44039 L
.53129 .43132 L
.52943 .43059 L
.50981 .42194 L
.49087 .4117 L
.49019 .41106 L
.48201 .39207 L
.49019 .38952 L
s
.6 g
.52943 .34984 m
.54906 .34822 L
.56868 .34853 L
.5883 .34946 L
.60793 .35051 L
.62755 .35139 L
.64717 .35194 L
.6668 .35209 L
.68642 .3518 L
.70604 .35112 L
.72567 .35016 L
.74529 .34911 L
.76491 .34886 L
.78454 .34843 L
.80416 .35169 L
.80659 .35283 L
.80416 .3635 L
.7929 .37245 L
.78454 .37559 L
.76491 .38163 L
.74529 .38653 L
.72567 .39041 L
.71526 .39207 L
.70604 .39322 L
.68642 .39556 L
.6668 .39668 L
.64717 .39612 L
.62755 .3941 L
.61162 .39207 L
.60793 .39149 L
.5883 .38797 L
.56868 .38341 L
.54906 .3778 L
.53397 .37245 L
.52943 .36946 L
.52015 .35283 L
F
0 g
.52943 .34984 m
.54906 .34822 L
.56868 .34853 L
.5883 .34946 L
.60793 .35051 L
.62755 .35139 L
.64717 .35194 L
.6668 .35209 L
.68642 .3518 L
.70604 .35112 L
.72567 .35016 L
.74529 .34911 L
.76491 .34886 L
.78454 .34843 L
.80416 .35169 L
.80659 .35283 L
.80416 .3635 L
.7929 .37245 L
.78454 .37559 L
.76491 .38163 L
.74529 .38653 L
.72567 .39041 L
.71526 .39207 L
.70604 .39322 L
.68642 .39556 L
.6668 .39668 L
.64717 .39612 L
.62755 .3941 L
.61162 .39207 L
.60793 .39149 L
.5883 .38797 L
.56868 .38341 L
.54906 .3778 L
.53397 .37245 L
.52943 .36946 L
.52015 .35283 L
.52943 .34984 L
s
.7 g
.52943 .45783 m
.54906 .45623 L
.56868 .45716 L
.5883 .45856 L
.60793 .4599 L
.62755 .46093 L
.64717 .46156 L
.6668 .46172 L
.68642 .4614 L
.70604 .46062 L
.72567 .45947 L
.74529 .45807 L
.76491 .45674 L
.78454 .45626 L
.8035 .47057 L
.78454 .48302 L
.76941 .49019 L
.76491 .49276 L
.74529 .498 L
.72567 .50246 L
.70604 .50561 L
.68642 .50757 L
.6668 .50835 L
.64717 .50796 L
.62755 .50641 L
.60793 .50367 L
.5883 .49968 L
.56868 .49699 L
.5575 .49019 L
.54906 .48638 L
.52943 .47529 L
.52343 .47057 L
F
0 g
.52943 .45783 m
.54906 .45623 L
.56868 .45716 L
.5883 .45856 L
.60793 .4599 L
.62755 .46093 L
.64717 .46156 L
.6668 .46172 L
.68642 .4614 L
.70604 .46062 L
.72567 .45947 L
.74529 .45807 L
.76491 .45674 L
.78454 .45626 L
.8035 .47057 L
.78454 .48302 L
.76941 .49019 L
.76491 .49276 L
.74529 .498 L
.72567 .50246 L
.70604 .50561 L
.68642 .50757 L
.6668 .50835 L
.64717 .50796 L
.62755 .50641 L
.60793 .50367 L
.5883 .49968 L
.56868 .49699 L
.5575 .49019 L
.54906 .48638 L
.52943 .47529 L
.52343 .47057 L
.52943 .45783 L
s
.3 g
.54906 .40711 m
.56868 .40518 L
.5883 .40517 L
.60793 .3999 L
.62755 .40452 L
.64717 .40632 L
.6668 .40673 L
.68642 .40589 L
.70604 .40344 L
.72567 .40549 L
.74529 .40508 L
.76491 .40548 L
.78454 .40928 L
.78794 .4117 L
.78454 .41784 L
.76491 .43107 L
.76439 .43132 L
.74529 .43722 L
.72567 .44161 L
.70604 .44473 L
.68642 .44666 L
.6668 .44744 L
.64717 .44706 L
.62755 .44552 L
.60793 .44281 L
.5883 .43887 L
.56868 .43344 L
.56255 .43132 L
.54906 .42349 L
.53891 .4117 L
F
0 g
.54906 .40711 m
.56868 .40518 L
.5883 .40517 L
.60793 .3999 L
.62755 .40452 L
.64717 .40632 L
.6668 .40673 L
.68642 .40589 L
.70604 .40344 L
.72567 .40549 L
.74529 .40508 L
.76491 .40548 L
.78454 .40928 L
.78794 .4117 L
.78454 .41784 L
.76491 .43107 L
.76439 .43132 L
.74529 .43722 L
.72567 .44161 L
.70604 .44473 L
.68642 .44666 L
.6668 .44744 L
.64717 .44706 L
.62755 .44552 L
.60793 .44281 L
.5883 .43887 L
.56868 .43344 L
.56255 .43132 L
.54906 .42349 L
.53891 .4117 L
.54906 .40711 L
s
.3 g
.54906 .52762 m
.56868 .5247 L
.5883 .5252 L
.60793 .52619 L
.62755 .52708 L
.64717 .52764 L
.6668 .52779 L
.68642 .52749 L
.70604 .5268 L
.72567 .52585 L
.74529 .52493 L
.76491 .52493 L
.78084 .52943 L
.76491 .54374 L
.75473 .54906 L
.74529 .55282 L
.72567 .55872 L
.70604 .56268 L
.68642 .56508 L
.6668 .56603 L
.64717 .56557 L
.62755 .56367 L
.60793 .56026 L
.5883 .55509 L
.5722 .54906 L
.56868 .54733 L
.54906 .53398 L
.54667 .52943 L
F
0 g
.54906 .52762 m
.56868 .5247 L
.5883 .5252 L
.60793 .52619 L
.62755 .52708 L
.64717 .52764 L
.6668 .52779 L
.68642 .52749 L
.70604 .5268 L
.72567 .52585 L
.74529 .52493 L
.76491 .52493 L
.78084 .52943 L
.76491 .54374 L
.75473 .54906 L
.74529 .55282 L
.72567 .55872 L
.70604 .56268 L
.68642 .56508 L
.6668 .56603 L
.64717 .56557 L
.62755 .56367 L
.60793 .56026 L
.5883 .55509 L
.5722 .54906 L
.56868 .54733 L
.54906 .53398 L
.54667 .52943 L
.54906 .52762 L
s
.8 g
.56868 .46829 m
.5883 .46628 L
.60793 .46614 L
.62755 .46641 L
.64717 .46667 L
.6668 .46674 L
.68642 .4666 L
.70604 .46631 L
.72567 .46611 L
.74529 .4666 L
.76462 .47057 L
.74529 .48847 L
.74155 .49019 L
.72567 .49493 L
.70604 .49892 L
.68642 .5013 L
.6668 .50224 L
.64717 .50178 L
.62755 .4999 L
.60793 .49649 L
.5883 .49118 L
.58541 .49019 L
.56868 .48092 L
.56212 .47057 L
F
0 g
.56868 .46829 m
.5883 .46628 L
.60793 .46614 L
.62755 .46641 L
.64717 .46667 L
.6668 .46674 L
.68642 .4666 L
.70604 .46631 L
.72567 .46611 L
.74529 .4666 L
.76462 .47057 L
.74529 .48847 L
.74155 .49019 L
.72567 .49493 L
.70604 .49892 L
.68642 .5013 L
.6668 .50224 L
.64717 .50178 L
.62755 .4999 L
.60793 .49649 L
.5883 .49118 L
.58541 .49019 L
.56868 .48092 L
.56212 .47057 L
.56868 .46829 L
s
.6 g
.5883 .59882 m
.60793 .60028 L
.62755 .60156 L
.64717 .60234 L
.6668 .60254 L
.68642 .60214 L
.70604 .60117 L
.72567 .59977 L
.74529 .59843 L
.75679 .60793 L
.74529 .61325 L
.72567 .61951 L
.70604 .62355 L
.68642 .62598 L
.6668 .62694 L
.64717 .62647 L
.62755 .62455 L
.60793 .62108 L
.5883 .61571 L
.57039 .60793 L
F
0 g
.5883 .59882 m
.60793 .60028 L
.62755 .60156 L
.64717 .60234 L
.6668 .60254 L
.68642 .60214 L
.70604 .60117 L
.72567 .59977 L
.74529 .59843 L
.75679 .60793 L
.74529 .61325 L
.72567 .61951 L
.70604 .62355 L
.68642 .62598 L
.6668 .62694 L
.64717 .62647 L
.62755 .62455 L
.60793 .62108 L
.5883 .61571 L
.57039 .60793 L
.5883 .59882 L
s
.2 g
.60793 .41418 m
.62755 .41339 L
.64717 .41321 L
.6668 .41318 L
.68642 .41324 L
.70604 .41355 L
.72567 .41481 L
.73411 .43132 L
.72567 .43388 L
.70604 .43814 L
.68642 .44062 L
.6668 .4416 L
.64717 .44112 L
.62755 .43916 L
.60793 .43556 L
.5928 .43132 L
F
0 g
.60793 .41418 m
.62755 .41339 L
.64717 .41321 L
.6668 .41318 L
.68642 .41324 L
.70604 .41355 L
.72567 .41481 L
.73411 .43132 L
.72567 .43388 L
.70604 .43814 L
.68642 .44062 L
.6668 .4416 L
.64717 .44112 L
.62755 .43916 L
.60793 .43556 L
.5928 .43132 L
.60793 .41418 L
s
.7 g
.60793 .36636 m
.62755 .36442 L
.64717 .36377 L
.6668 .36364 L
.68642 .36391 L
.70604 .36486 L
.72567 .36786 L
.73276 .37245 L
.72567 .37604 L
.70604 .38185 L
.68642 .38496 L
.6668 .38614 L
.64717 .38556 L
.62755 .38314 L
.60793 .37845 L
.59413 .37245 L
F
0 g
.60793 .36636 m
.62755 .36442 L
.64717 .36377 L
.6668 .36364 L
.68642 .36391 L
.70604 .36486 L
.72567 .36786 L
.73276 .37245 L
.72567 .37604 L
.70604 .38185 L
.68642 .38496 L
.6668 .38614 L
.64717 .38556 L
.62755 .38314 L
.60793 .37845 L
.59413 .37245 L
.60793 .36636 L
s
.4 g
.6668 .31358 m
.66736 .31358 L
.68642 .31376 L
.70604 .31444 L
.71869 .3332 L
.70604 .33496 L
.68642 .33677 L
.6668 .33748 L
.64717 .33713 L
.62755 .3357 L
.60846 .3332 L
.62755 .31412 L
.64717 .31366 L
.6588 .31358 L
F
0 g
.6668 .31358 m
.66736 .31358 L
.68642 .31376 L
.70604 .31444 L
.71869 .3332 L
.70604 .33496 L
.68642 .33677 L
.6668 .33748 L
.64717 .33713 L
.62755 .3357 L
.60846 .3332 L
.62755 .31412 L
.64717 .31366 L
.6588 .31358 L
.6668 .31358 L
s
.9 g
.62755 .4746 m
.64717 .47374 L
.6668 .4736 L
.68642 .47391 L
.70597 .49019 L
.68642 .49362 L
.6668 .4949 L
.64717 .49428 L
.62755 .49163 L
.6205 .49019 L
F
0 g
.62755 .4746 m
.64717 .47374 L
.6668 .4736 L
.68642 .47391 L
.70597 .49019 L
.68642 .49362 L
.6668 .4949 L
.64717 .49428 L
.62755 .49163 L
.6205 .49019 L
.62755 .4746 L
s
.1 g
.64717 .42456 m
.6668 .42373 L
.68642 .42579 L
.68927 .43132 L
.68642 .43168 L
.6668 .43337 L
.64717 .43256 L
.6384 .43132 L
F
0 g
.64717 .42456 m
.6668 .42373 L
.68642 .42579 L
.68927 .43132 L
.68642 .43168 L
.6668 .43337 L
.64717 .43256 L
.6384 .43132 L
.64717 .42456 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00?Oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0dooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kS?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0hooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8b
onk^kS?ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08_ooool003gooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0=_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0<oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg03?ooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL08_ooool003Gooooo1_l0
0003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400[ooooo`Ko0000
1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100<oooool01Ol@413o
oooooooooooooooo410@03[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@03Cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@02;ooooo000o
ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000fooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000cooooo`05o`000?ooooooooooooooool0
0000>_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000=Oooool00onH
V9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000008_ooool0043ooooo00?oMgMgofIV
I_ooool00_ooool01Ol0003ooooooooooooooooo000003Kooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000003?ooooo00Go0000ooooooooooooooooo`00000jooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`03ogMgMomVIVKooooo00;o
oooo00Go0000ooooooooooooooooo`00000Rooooo`00@Oooool01Ol0003ooooooooooooooooo410@
00?ooooo00?o410@ooooooooool0=?ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@4100<oooool01Ol@413ooooooooooooooooo410@03[ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@03Oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo023ooooo000mooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg03Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg03?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0jooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0cooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02;ooooo000mooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^03Cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^03?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`03oeEEEOmVIVKo000000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0cooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02;ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo000Joooooooo0000C_l00001ooooo`00
6_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0?Ooo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool08ooo
ool1o`00007ooooo0008ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKo
oooo00?o0000ooooooooool0oooooom:ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooom:ooooo`7o
00000Oooool000Go00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41001_ooool00ol0003oooooooooo`3ooooood[ooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?ooooooB?ooool3o`00007o
oooo000:ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo0008ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Oooooooogmo
Od3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Ooo
ooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000oooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`003ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000?ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000oooooo00Go0000oooooooooooooooo
o`000006ooooo`?o00001?ooooooogmoOd3oOgmo1?ooool3o`00007ooooo000?ooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool000oooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`003oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000?ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooo9ogmoOaco0000F_moOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?ooooo8ogmoO`03o`000?mVIVKoIVIV01WoIVIV00?o0000ogmoOomoOgl0F?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooo7ogmoO`03o`000?mVIVKo
IVIV01_oIVIV00?o0000ogmoOomoOgl0EomoOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?ooooo6ogmoO`03o`000?mVIVKoIVIV01goIVIV00?o0000ogmoOomoOgl0E_moOgl6oooo
o`7o00000Oooool001[ooooo0_l00005ooooolGoOgmo00?o0000ofIVI_mVIVH07_mVIVH00ol0003o
OgmoogmoO`1FogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04ooooolCoOgmo
00?o0000ofIVI_mVIVH08?mVIVH00ol0003oOgmoogmoO`1EogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04oooool?oOgmo1Ol0000NofIVIP?o0000E_moOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?ooooo8ogmoO`Ko00003?mVIVH<o`0005WoOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00Coooooc_moOgl<o`0006GoOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?oooon]ogmoO`ko0000>OmoOgl>o`0003goOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CoooooZ?moOgl5o`0000koVIVI4ol0000<ogmoOa[o00003_nIVIT3
o`0003[oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooY_moOgl2o`00
02KoVIVI3?l0000[oiVIV@03o`000?moOgooOgmo03OoOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CoooooY_moOgl00ol0003oVIVIoiVIV@1LoiVIV@03o`000?moOgooOgmo03Oo
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooYomoOgl00ol0003oVIVI
oiVIV@1JoiVIV@03o`000?moOgooOgmo03SoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CoooooZ?moOgl00ol0003oVIVIoiVIV@0RoiVIVAGo00008_nIVIT00ol0003oOgmoogmo
O`0hogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000GoooooZ?moOgl00ol0003oVIVIoiVIV@0G
oiVIV@_o00005Onc/k<6o`0001_oVIVI00?o0000ogmoOomoOgl0>OmoOgl5ooooo`;o00000Oooool0
01[ooooo00?o0000ooooooooool01?oooonYogmoO`;o00005OnIVIT2o`0002Ko/k>c1Ol0000EoiVI
V@03o`000?moOgooOgmo03[oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
ooooZomoOgl2o`0001;oVIVI0_l0000[ok>c/`;o00004_nIVIT2o`0003goOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00Cooooo[OmoOgl3o`00017oVIVI0_l0000Xok>c/`03o`00
0?nIVIWoVIVI00koVIVI1?l0000oogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04oooook3oOgmo0ol0000@oiVIV@?o00008Onc/k<4o`0000koVIVI0ol00013ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04oooook?oOgmo0ol0000@oiVIV@?o00006?nc/k<6
o`0000ooVIVI0ol00016ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
okKoOgmo1Ol0000>oiVIV@Go00003?nc/k<7o`0001;oVIVI0ol00019ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04oooooj3oOgmo1ol0000DogmoO`Go00003_nIVIT<o`0001Co
VIVI1Ol0001<ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooi_oOgmo
1Ol00007ofIVIPKo00004omoOgl3o`0002KoVIVI1Ol0000CogmoO`ko0000<?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?oooonIogmoO`;o00004_mVIVH7o`0000ooOgmo1Ol0
000IoiVIV@So00004OmoOgl7o`0000koIVIV1?l0000/ogmoO`Kooooo0Ol00001ooooo`002?ooool4
o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h6ooooo`03o`000?oooooooooo00Co
ooooVOmoOgl00ol0003oIVIVofIVIP0HofIVIPOo00001OmoOglQo`0000goOgmo3?l0000HofIVIP03
o`000?moOgooOgmo02[oOgmo1_ooool1o`00007ooooo000:ooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00CoooooV_moOgl00ol0003o
IVIVofIVIP0NofIVIPGo00000_mVIVH4o`0000;oIVIV1_l0000CogmoO`go00008omVIVH00ol0003o
OgmoogmoO`0[ogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003oooooooooo`02ooooo`05oa0@
4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`04oooooi[oOgmo00?o0000ofIVI_mV
IVH08_mVIVH3o`0000CoC4a<0ol00005ofIVIQ?o0000<?mVIVH00ol0003oOgmoogmoO`0[ogmoO`Ko
oooo0Ol00001ooooo`002_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
00001_ooool3o`0000CoooooVomoOgl00ol0003oIVIVofIVIP0EofIVIPco00002_m<C4`5o`0000co
IVIV8?l0000GofIVIP03o`000?moOgooOgmo02_oOgmo1?ooool3o`00007ooooo000:ooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00Co
ooooVomoOgl00ol0003oIVIVofIVIP0@ofIVIPGo00006om<C4`<o`00023oC4a<0ol0000CofIVIP03
o`000?moOgooOgmo02coOgmo1_ooool1o`00007ooooo000:ooooo`03o`000?oooooooooo00;ooooo
00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00CoooooW?moOgl2o`0000ko
IVIV0_l0001?oda<C0?o00003_mVIVH2o`0002ooOgmo1_ooool1o`00007ooooo000:ooooo`03o`00
0?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00Co
ooooW_moOgl2o`0000goIVIV00?o0000oda<C?m<C4`04om<C4`Xo`0001CoC4a<00?o0000ofIVI_mV
IVH02omVIVH00ol0003oOgmoogmoO`0_ogmoO`Kooooo0Ol00001ooooo`002?ooool00omEEEGoIVIV
o`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`04oooooj3o
Ogmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Boda<C003o`000?lc<c?o<c<c02Co
<c<c00?o0000oda<C?m<C4`04?m<C4`2o`0000goIVIV00?o0000ogmoOomoOgl0<?moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?oooonQogmoO`;o00003?mVIVH00ol0003oC4a<
oda<C00@oda<C003o`000?lc<c?o<c<c02Ko<c<c00?o0000oda<C?m<C4`03_m<C4`00ol0003oIVIV
ofIVIP0;ofIVIP;o0000<omoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
oonSogmoO`;o00002omVIVH2o`0000ooC4a<00?o0000oc<c<olc<c<04?lc<c<7o`00013o<c<c00?o
0000oda<C?m<C4`03?m<C4`2o`0000_oIVIV0ol0000eogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooojGoOgmo0_l0000;ofIVIP03o`000?m<C4coC4a<00_oC4a<00?o0000
oc<c<olc<c<03?lc<c<5o`0000Oo6ATI0ol0000>oc<c<`03o`000?m<C4coC4a<00[oC4a<00?o0000
ofIVI_mVIVH02OmVIVH2o`0003SoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CoooooYomoOgl2o`0000[oIVIV00?o0000oda<C?m<C4`02Om<C4`00ol0003o<c<coc<c<`0<oc<c
<`03o`000?lI6AWo6ATI00co6ATI00?o0000oc<c<olc<c<03?lc<c<00ol0003oC4a<oda<C009oda<
C003o`000?mVIVKoIVIV00SoIVIV0_l0000jogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooojWoOgmo0ol00008ofIVIP;o00002?m<C4`4o`0000_o<c<c2?l00005oaTI6@Go
00003Olc<c<2o`0000SoC4a<0_l00008ofIVIP?o0000??moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?oooon/ogmoO`;o00002?mVIVH5o`0000OoC4a<1_l0000=oc<c<`Go0000
3Olc<c<5o`0000OoC4a<0ol00009ofIVIP04o`000?moOgooOgmoogmoO`Ko00001OmoOgl6o`0002_o
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooUOmoOglFo`0000?oOgmo
0_l0000;ofIVIPGo00002?m<C4`6o`0001?o<c<c1_l00007oda<C0Go00002?mVIVH4o`0000;oOgmo
0_l00006oiVIV@Go00001_nIVIT3o`0002SoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CoooooUOmoOgl00ol0003oVIVIoiVIV@0CoiVIV@?o00000_moOgl9o`0000OoIVIV0ol0
000;oda<C1?o00001_m<C4`7o`0000KoIVIV1ol00004ogmoO`;o00005_nIVIT2o`0002KoOgmo1_oo
ool1o`00007ooooo000Jooooo`;o00001OoooonDogmoO`03o`000?nIVIWoVIVI01OoVIVI0_l00009
ogmoO`?o00001omVIVH5o`0001WoC4a<1_l00007ofIVIPKo00001omoOgl4o`0001WoVIVI00?o0000
ogmoOomoOgl09?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool01?oooonDogmo
O`03o`000?nIVIWoVIVI01WoVIVI1?l00008ogmoO`Go00001omVIVHIo`0000KoIVIV1ol00006ogmo
O`Oo00007OnIVIT00ol0003oOgmoogmoO`0TogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04oooooi?oOgmo00?o0000oiVIVOnIVIT07_nIVIT9o`0000CoOgmo3Ol0000BofIVIPOo
00001omoOgl6o`0002CoVIVI00?o0000ogmoOomoOgl09?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?oooonCogmoO`03o`000?nIVIWoVIVI02OoVIVI1?l0000=ogmoOa;o0000
1omoOgl7o`0002WoVIVI0_l0000VogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04oooooiCoOgmo00?o0000oiVIVOnIVIT05_nIVIT>o`0000KoVIVI9_l0000=oiVIV@co00005_nI
VIT00ol0003oOgmoogmoO`0VogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
oooooiGoOgmo0_l0000BoiVIV@Co00003_nc/k<=o`0001ooVIVI3Ol0000<ok>c/`03o`000?nIVIWo
VIVI017oVIVI0_l0000YogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
oiOoOgmo00?o0000oiVIVOnIVIT03onIVIT00ol0003o/k>cok>c/`0Lok>c/aoo00006_nc/k<00ol0
003oVIVIoiVIV@0?oiVIV@03o`000?moOgooOgmo02WoOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CoooooV?moOgl2o`0000koVIVI00?o0000ok>c/onc/k<03onc/k<>o`0001oo
/k>c2?l0000Cok>c/`03o`000?nIVIWoVIVI00goVIVI00?o0000ogmoOomoOgl0:_moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?oooonJogmoO`03o`000?nIVIWoVIVI00_oVIVI
00?o0000ok>c/onc/k<02_nc/k<5o`0000koc<c<7ol00008olc<c0Ko00003_nc/k<00ol0003oVIVI
oiVIV@0;oiVIV@03o`000?moOgooOgmo02_oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CoooooVomoOgl00ol0003oVIVIoiVIV@09oiVIV@;o00002onc/k<00ol0003oc<c<olc<
c00nolc<c0?o00002onc/k<2o`0000[oVIVI0_l0000^ogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04oooooicoOgmo0_l0000;oiVIV@;o00002Onc/k<00ol0003oc<c<olc<c00C
olc<c1Go00005oo<c<`00ol0003o/k>cok>c/`09ok>c/`03o`000?nIVIWoVIVI00SoVIVI0_l0000`
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooikoOgmo0ol0000:oiVI
V@;o00002?nc/k<00ol0003oc<c<olc<c00Bolc<c003o`000?oVi^Koi^KV01;oi^KV00?o0000olc<
c?o<c<`04oo<c<`00ol0003o/k>cok>c/`08ok>c/`;o00002_nIVIT00ol0003oOgmoogmoO`0`ogmo
O`Kooooo0Ol00001ooooo`006_ooool2o`0000GoooooXOmoOgl2o`0000[oVIVI00?o0000ok>c/onc
/k<01_nc/k<2o`00017oc<c<00?o0000onKVi_oVi^H05?oVi^H2o`0001;oc<c<00?o0000ok>c/onc
/k<02?nc/k<00ol0003oVIVIoiVIV@08oiVIV@;o0000<omoOgl5ooooo`;o00000Oooool001[ooooo
00?o0000ooooooooool01?oooonSogmoO`?o00002?nIVIT2o`0000So/k>c0_l0000>olc<c003o`00
0?oVi^Koi^KV01Ooi^KV00?o0000olc<c?o<c<`03_o<c<`00ol0003o/k>cok>c/`07ok>c/`;o0000
2?nIVIT3o`0003GoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooY_mo
Ogl3o`0000OoVIVI0_l00008ok>c/`;o00003?o<c<`00ol0003oi^KVonKViP0HonKViP03o`000?o<
c<coc<c<00coc<c<00?o0000ok>c/onc/k<01Onc/k<3o`0000SoVIVI0_l0000hogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooojWoOgmo00?o0000oiVIVOnIVIT01_nIVIT2
o`0000So/k>c00?o0000olc<c?o<c<`02?o<c<`3o`0001Soi^KV0ol00009olc<c0Co00001_nc/k<2
o`0000SoVIVI0ol0000jogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
ojWoOgmo0ol00008oiVIV@03o`000?nc/k?o/k>c00Ko/k>c0ol0000:olc<c0Co00004OoVi^H3o`00
00Woc<c<0ol00008ok>c/`;o00001onIVIT3o`0003goOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00Cooooo[?moOgl3o`0000KoVIVI00?o0000ok>c/onc/k<02?nc/k<3o`0000_o
c<c<4Ol00008olc<c0Co00002?nc/k<3o`0000OoVIVI0_l0000?ogmoO`Go0000;?moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?oooonEogmoO`co00001OmoOgl5o`0000CoOgmo
0ol00004oiVIV@Go00002?nc/k<5o`0001Woc<c<1_l00008ok>c/`Co00001onIVIT3o`0000coOgmo
1Ol00005ofIVIP03o`000?moOgooOgmo02WoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CoooooUOmoOgl00ol0003oIVIVofIVIP09ofIVIPGo00001OmVIVH3o`0000CoOgmo0_l0
0007oiVIV@Ko00001onc/k<Io`0000_o/k>c0ol00009oiVIV@;o00003?moOgl3o`0000_oIVIV00?o
0000ogmoOomoOgl0:?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonE
ogmoO`03o`000?mVIVKoIVIV01KoIVIV0_l00004ogmoO`;o00002onIVIT7o`0001oo/k>c1Ol00008
oiVIV@Co00001OmoOgl9o`0000ooIVIV00?o0000ogmoOomoOgl09omoOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?oooonDogmoO`03o`000?mVIVKoIVIV01WoIVIV0ol00003ogmo
O`_o00001onIVITOo`0000OoVIVI1_l00006ogmoO`?o00006OmVIVH00ol0003oOgmoogmoO`0Vogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooiCoOgmo00?o0000ofIVI_mV
IVH07?mVIVH3o`0000_oOgmo1ol0000OoiVIV@Oo00001_moOgl6o`0001coIVIV0_l0000WogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooiCoOgmo00?o0000ofIVI_mVIVH0
7omVIVH5o`0000goOgmo7ol00007ogmoO`Ko00008OmVIVH00ol0003oOgmoogmoO`0WogmoO`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooiGoOgmo0_l0000TofIVIPKo00009_mo
Ogl7o`0002KoIVIV00?o0000ogmoOomoOgl0:?moOgl6ooooo`7o00000Oooool001[ooooo0_l00005
oooooiOoOgmo00?o0000ofIVI_mVIVH09omVIVHDo`0000GoOgmo3Ol0000/ofIVIP03o`000?moOgoo
Ogmo02WoOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooV?moOgl2o`00
03_oIVIV1Ol0000hofIVIP03o`000?moOgooOgmo02[oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CoooooV_moOgl00ol0003oIVIVofIVIP0FofIVIQGo00007omVIVHDo`0001Ko
IVIV00?o0000ogmoOomoOgl0:omoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?oooonKogmoO`03o`000?mVIVKoIVIV017oIVIV1?l0000Eoda<C1oo00005?m<C4`3o`00017oIVIV
0_l0000^ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooicoOgmo0_l0
000AofIVIP03o`000?m<C4coC4a<04WoC4a<00?o0000ofIVI_mVIVH04?mVIVH00ol0003oOgmoogmo
O`0^ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooikoOgmo0_l0000@
ofIVIP;o0000B?m<C4`00ol0003oIVIVofIVIP0@ofIVIP03o`000?moOgooOgmo02ooOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooX?moOgl00ol0003oIVIVofIVIP0?ofIV
IP03o`000?m<C4coC4a<04CoC4a<00?o0000ofIVI_mVIVH04?mVIVH00ol0003oOgmoogmoO`0`ogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooj7oOgmo0_l0000@ofIVIP;o
0000@om<C4`00ol0003oIVIVofIVIP0?ofIVIP;o0000<omoOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?oooonSogmoO`;o00004?mVIVH00ol0003oC4a<oda<C00noda<C0;o0000
3omVIVH3o`0003GoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooYOmo
Ogl2o`0000ooIVIV00?o0000oda<C?m<C4`0??m<C4`00ol0003oIVIVofIVIP0=ofIVIP;o0000>?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonWogmoO`;o00003_mVIVH3
o`0003WoC4a<0_l0000>ofIVIP;o0000>_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?oooonYogmoO`;o00003omVIVH3o`0003;oC4a<1?l0000>ofIVIP;o0000??moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon[ogmoO`?o00003omVIVH3o`0002co
C4a<0ol0000@ofIVIP;o0000?_moOgl6ooooo`7o00000Oooool001[ooooo0_l00005ooooojkoOgmo
0_l0000@ofIVIP?o00009_m<C4`3o`00013oIVIV0ol00010ogmoO`Gooooo0_l00001ooooo`006_oo
ool00ol0003oooooooooo`04oooook3oOgmo0ol0000@ofIVIPGo00007_m<C4`3o`00013oIVIV0ol0
0013ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooook?oOgmo0ol0000B
ofIVIPgo00001Om<C4`<o`00013oIVIV0ol00016ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04oooookKoOgmo0ol0000LofIVIPGo00006OmVIVH3o`0004WoOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00Cooooo^OmoOgl8o`0002KoIVIV3?l0001<ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooool7oOgmo1ol0000IofIVIPKo0000
F?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooo8ogmoO`go00001OmV
IVH7o`0005koOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooeOmoOgl5
o`0006GoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool000Oooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003o
ooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000Oooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`04oooo
ooooOgmo@?moOgl6ooooo`7o00000Oooool000Sooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00
007ooooo0009ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000006oooo
o`?o00001?ooooo^ogmoO`Co0000COmoOgl4ooooo`?o00000Oooool000[ooooo00?oMgMgofIVI_oo
ool00_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool01?oooonlogmo
Oa;o00004omoOgl=o`0000CoVIVI00?o0000ogmoOomoOgl0B_moOgl6ooooo`7o00000Oooool000_o
oooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o0000oooo
ooooool01?oooonjogmoO`;o00004_nIVITCo`0001;oVIVI00?o0000ogmoOomoOgl0BOmoOgl6oooo
o`7o00000Oooool000Oooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01_ooool00ol0003oooooooooo`04oooookSoOgmo0_l0000joiVIV@03o`000?moOgoo
Ogmo04SoOgmo1_ooool1o`00007ooooo0007ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool01?oooongogmoO`?o0000>OnI
VIT3o`0004WoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo^_moOgl3
o`0003;oVIVI1?l0001<ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
okgoOgmo0ol0000/oiVIV@?o0000D?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooo0ogmoO`?o00009_nIVIT3o`0005?oOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00Cooooo`omoOgl5o`0001koVIVI0ol0001FogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooolSoOgmo1_l0000CoiVIV@Go0000FOmoOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?ooooo>ogmoOa?o0000G_moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o
00001OooooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo0007ooooo`05oiRHV?l@413o0000
oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo0007ooooo`05oa0@4?nj^[[oooooogMgMolb<S800ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000;ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413ooooo
ooooo`04ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_oo
ool00onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool3o`0000Cooooo
oomoOgm0ogmoO`Cooooo0ol00001ooooo`002Oooool00ol@413o0000okZj^P03ooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool000[ooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@00Kooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo0007ooooo`05oa0@4?nH
V9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo0007ooooo`05ojVYZOl@413o0000oa0@4?nY
ZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000GooooooomoOgm0ogmoO`Go
oooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000GooooooomoOgm0
ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000Gooooo
oomoOgm0ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`002Oooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;o
k^k^00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000:oooo
o`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooo
oooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`001oooool5o`0000?ooooo00Go410@oooo
oooooooooooooa0@4006ooooo`?o00001?ooooooogmoOd3oOgmo1?ooool3o`00007ooooo0007oooo
o`04odA4A?oMgMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oo
oooooooo0?ooooooB_ooool1o`00007ooooo0007ooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?ooooooB_ooool1o`00007ooooo
0008ooooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`00
0?oooooooooo0?ooooooB_ooool1o`00007ooooo0008ooooo`03onk^k_m4A4Co000000Cooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?ooooooB_ooool1o`00007ooooo
0009ooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`00
0?oooooooooo02?ooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0mooooo`03o`00
0?oooooooooo03gooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Sooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`7o00000Ooo
ool001[oooooool0001>o`00007ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-30.1723, -14.304, 0.195672, \
0.195672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0192308 0.211538 0.0192308 [
[.11538 -0.0125 -9 -9 ]
[.11538 -0.0125 9 0 ]
[.30769 -0.0125 -9 -9 ]
[.30769 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69231 -0.0125 -6 -9 ]
[.69231 -0.0125 6 0 ]
[.88462 -0.0125 -6 -9 ]
[.88462 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -18 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .21154 -6 -4.5 ]
[-0.0125 .21154 0 4.5 ]
[-0.0125 .40385 -12 -4.5 ]
[-0.0125 .40385 0 4.5 ]
[-0.0125 .59615 -12 -4.5 ]
[-0.0125 .59615 0 4.5 ]
[-0.0125 .78846 -12 -4.5 ]
[-0.0125 .78846 0 4.5 ]
[-0.0125 .98077 -12 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11538 0 m
.11538 .00625 L
s
[(-20)] .11538 -0.0125 0 1 Mshowa
.30769 0 m
.30769 .00625 L
s
[(-10)] .30769 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69231 0 m
.69231 .00625 L
s
[(10)] .69231 -0.0125 0 1 Mshowa
.88462 0 m
.88462 .00625 L
s
[(20)] .88462 -0.0125 0 1 Mshowa
.125 Mabswid
.15385 0 m
.15385 .00375 L
s
.19231 0 m
.19231 .00375 L
s
.23077 0 m
.23077 .00375 L
s
.26923 0 m
.26923 .00375 L
s
.34615 0 m
.34615 .00375 L
s
.38462 0 m
.38462 .00375 L
s
.42308 0 m
.42308 .00375 L
s
.46154 0 m
.46154 .00375 L
s
.53846 0 m
.53846 .00375 L
s
.57692 0 m
.57692 .00375 L
s
.61538 0 m
.61538 .00375 L
s
.65385 0 m
.65385 .00375 L
s
.73077 0 m
.73077 .00375 L
s
.76923 0 m
.76923 .00375 L
s
.80769 0 m
.80769 .00375 L
s
.84615 0 m
.84615 .00375 L
s
.07692 0 m
.07692 .00375 L
s
.03846 0 m
.03846 .00375 L
s
.92308 0 m
.92308 .00375 L
s
.96154 0 m
.96154 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(-10)] -0.0125 .01923 1 0 Mshowa
0 .21154 m
.00625 .21154 L
s
[(0)] -0.0125 .21154 1 0 Mshowa
0 .40385 m
.00625 .40385 L
s
[(10)] -0.0125 .40385 1 0 Mshowa
0 .59615 m
.00625 .59615 L
s
[(20)] -0.0125 .59615 1 0 Mshowa
0 .78846 m
.00625 .78846 L
s
[(30)] -0.0125 .78846 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(40)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .05769 m
.00375 .05769 L
s
0 .09615 m
.00375 .09615 L
s
0 .13462 m
.00375 .13462 L
s
0 .17308 m
.00375 .17308 L
s
0 .25 m
.00375 .25 L
s
0 .28846 m
.00375 .28846 L
s
0 .32692 m
.00375 .32692 L
s
0 .36538 m
.00375 .36538 L
s
0 .44231 m
.00375 .44231 L
s
0 .48077 m
.00375 .48077 L
s
0 .51923 m
.00375 .51923 L
s
0 .55769 m
.00375 .55769 L
s
0 .63462 m
.00375 .63462 L
s
0 .67308 m
.00375 .67308 L
s
0 .71154 m
.00375 .71154 L
s
0 .75 m
.00375 .75 L
s
0 .82692 m
.00375 .82692 L
s
0 .86538 m
.00375 .86538 L
s
0 .90385 m
.00375 .90385 L
s
0 .94231 m
.00375 .94231 L
s
.25 Mabswid
0 0 m
0 1 L
s
.11538 .99375 m
.11538 1 L
s
.30769 .99375 m
.30769 1 L
s
.5 .99375 m
.5 1 L
s
.69231 .99375 m
.69231 1 L
s
.88462 .99375 m
.88462 1 L
s
.125 Mabswid
.15385 .99625 m
.15385 1 L
s
.19231 .99625 m
.19231 1 L
s
.23077 .99625 m
.23077 1 L
s
.26923 .99625 m
.26923 1 L
s
.34615 .99625 m
.34615 1 L
s
.38462 .99625 m
.38462 1 L
s
.42308 .99625 m
.42308 1 L
s
.46154 .99625 m
.46154 1 L
s
.53846 .99625 m
.53846 1 L
s
.57692 .99625 m
.57692 1 L
s
.61538 .99625 m
.61538 1 L
s
.65385 .99625 m
.65385 1 L
s
.73077 .99625 m
.73077 1 L
s
.76923 .99625 m
.76923 1 L
s
.80769 .99625 m
.80769 1 L
s
.84615 .99625 m
.84615 1 L
s
.07692 .99625 m
.07692 1 L
s
.03846 .99625 m
.03846 1 L
s
.92308 .99625 m
.92308 1 L
s
.96154 .99625 m
.96154 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .21154 m
1 .21154 L
s
.99375 .40385 m
1 .40385 L
s
.99375 .59615 m
1 .59615 L
s
.99375 .78846 m
1 .78846 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .05769 m
1 .05769 L
s
.99625 .09615 m
1 .09615 L
s
.99625 .13462 m
1 .13462 L
s
.99625 .17308 m
1 .17308 L
s
.99625 .25 m
1 .25 L
s
.99625 .28846 m
1 .28846 L
s
.99625 .32692 m
1 .32692 L
s
.99625 .36538 m
1 .36538 L
s
.99625 .44231 m
1 .44231 L
s
.99625 .48077 m
1 .48077 L
s
.99625 .51923 m
1 .51923 L
s
.99625 .55769 m
1 .55769 L
s
.99625 .63462 m
1 .63462 L
s
.99625 .67308 m
1 .67308 L
s
.99625 .71154 m
1 .71154 L
s
.99625 .75 m
1 .75 L
s
.99625 .82692 m
1 .82692 L
s
.99625 .86538 m
1 .86538 L
s
.99625 .90385 m
1 .90385 L
s
.99625 .94231 m
1 .94231 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.6 g
.47057 .46382 m
.49019 .46334 L
.50981 .4643 L
.52943 .46984 L
.53375 .47057 L
.54906 .47392 L
.56868 .47758 L
.5883 .47759 L
.60793 .48288 L
.62755 .48629 L
.64717 .48839 L
.6668 .4893 L
.68642 .4891 L
.70604 .48777 L
.72567 .48522 L
.74529 .48127 L
.76491 .47473 L
.78454 .47633 L
.80416 .47248 L
.80971 .47057 L
.82378 .469 L
.84341 .45945 L
.86303 .46286 L
.88265 .46824 L
.88354 .47057 L
.88265 .47277 L
.86759 .49019 L
.86303 .49365 L
.84341 .50542 L
.83483 .50981 L
.82378 .5154 L
.80416 .5228 L
.78454 .52918 L
.78366 .52943 L
.76491 .53214 L
.74529 .53761 L
.72567 .54191 L
.70604 .54474 L
.68642 .54619 L
.6668 .5464 L
.64717 .54542 L
.62755 .5431 L
.60793 .53933 L
.5883 .53418 L
.56868 .53132 L
.56261 .52943 L
.54906 .52522 L
.52943 .51974 L
.51111 .50981 L
.50981 .50916 L
.49019 .49822 L
.47851 .49019 L
.47057 .48249 L
.46229 .47057 L
F
0 g
.47057 .46382 m
.49019 .46334 L
.50981 .4643 L
.52943 .46984 L
.53375 .47057 L
.54906 .47392 L
.56868 .47758 L
.5883 .47759 L
.60793 .48288 L
.62755 .48629 L
.64717 .48839 L
.6668 .4893 L
.68642 .4891 L
.70604 .48777 L
.72567 .48522 L
.74529 .48127 L
.76491 .47473 L
.78454 .47633 L
.80416 .47248 L
.80971 .47057 L
.82378 .469 L
.84341 .45945 L
.86303 .46286 L
.88265 .46824 L
.88354 .47057 L
.88265 .47277 L
.86759 .49019 L
.86303 .49365 L
.84341 .50542 L
.83483 .50981 L
.82378 .5154 L
.80416 .5228 L
.78454 .52918 L
.78366 .52943 L
.76491 .53214 L
.74529 .53761 L
.72567 .54191 L
.70604 .54474 L
.68642 .54619 L
.6668 .5464 L
.64717 .54542 L
.62755 .5431 L
.60793 .53933 L
.5883 .53418 L
.56868 .53132 L
.56261 .52943 L
.54906 .52522 L
.52943 .51974 L
.51111 .50981 L
.50981 .50916 L
Mistroke
.49019 .49822 L
.47851 .49019 L
.47057 .48249 L
.46229 .47057 L
.47057 .46382 L
Mfstroke
.4 g
.49019 .52733 m
.50721 .52943 L
.50981 .52997 L
.52943 .53444 L
.54906 .53881 L
.56868 .54269 L
.5883 .54434 L
.60793 .54859 L
.61087 .54906 L
.62755 .55104 L
.64717 .55259 L
.6668 .55329 L
.68642 .55313 L
.70604 .55213 L
.72567 .55027 L
.73525 .54906 L
.74529 .54732 L
.76491 .54205 L
.78454 .54136 L
.80416 .53728 L
.82378 .53281 L
.83899 .52943 L
.84341 .52771 L
.86303 .52733 L
.87105 .52943 L
.86303 .54786 L
.86193 .54906 L
.84341 .56306 L
.83423 .56868 L
.82378 .57581 L
.80416 .58394 L
.79309 .5883 L
.78454 .59047 L
.76491 .59725 L
.74529 .60324 L
.72567 .60715 L
.71786 .60793 L
.70604 .60935 L
.68642 .61084 L
.6668 .61107 L
.64717 .61003 L
.62858 .60793 L
.62755 .60785 L
.60793 .60494 L
.5883 .59959 L
.56868 .59284 L
.55302 .5883 L
.54906 .58679 L
.52943 .58167 L
.51185 .56868 L
.50981 .56747 L
.49019 .55416 L
.48428 .54906 L
.47512 .52943 L
F
0 g
.49019 .52733 m
.50721 .52943 L
.50981 .52997 L
.52943 .53444 L
.54906 .53881 L
.56868 .54269 L
.5883 .54434 L
.60793 .54859 L
.61087 .54906 L
.62755 .55104 L
.64717 .55259 L
.6668 .55329 L
.68642 .55313 L
.70604 .55213 L
.72567 .55027 L
.73525 .54906 L
.74529 .54732 L
.76491 .54205 L
.78454 .54136 L
.80416 .53728 L
.82378 .53281 L
.83899 .52943 L
.84341 .52771 L
.86303 .52733 L
.87105 .52943 L
.86303 .54786 L
.86193 .54906 L
.84341 .56306 L
.83423 .56868 L
.82378 .57581 L
.80416 .58394 L
.79309 .5883 L
.78454 .59047 L
.76491 .59725 L
.74529 .60324 L
.72567 .60715 L
.71786 .60793 L
.70604 .60935 L
.68642 .61084 L
.6668 .61107 L
.64717 .61003 L
.62858 .60793 L
.62755 .60785 L
.60793 .60494 L
.5883 .59959 L
.56868 .59284 L
.55302 .5883 L
.54906 .58679 L
.52943 .58167 L
.51185 .56868 L
Mistroke
.50981 .56747 L
.49019 .55416 L
.48428 .54906 L
.47512 .52943 L
.49019 .52733 L
Mfstroke
.4 g
.49019 .41441 m
.50981 .41411 L
.52943 .41619 L
.54906 .4188 L
.56868 .42042 L
.5883 .42867 L
.60793 .42609 L
.62755 .42779 L
.64717 .42894 L
.6668 .42948 L
.68642 .42936 L
.70604 .4286 L
.72567 .42724 L
.74529 .42536 L
.76491 .42576 L
.78454 .41629 L
.80416 .41784 L
.82378 .41533 L
.84341 .41374 L
.8627 .43132 L
.84341 .44447 L
.83158 .45094 L
.82378 .45709 L
.80416 .46156 L
.78454 .4676 L
.77356 .47057 L
.76491 .4715 L
.74529 .47634 L
.72567 .48109 L
.70604 .48498 L
.68642 .48748 L
.6668 .48789 L
.64717 .48608 L
.62755 .48261 L
.60793 .47812 L
.5883 .47313 L
.57253 .47057 L
.56868 .46956 L
.54906 .46384 L
.52943 .45716 L
.5144 .45094 L
.50981 .44852 L
.49019 .43647 L
.4836 .43132 L
F
0 g
.49019 .41441 m
.50981 .41411 L
.52943 .41619 L
.54906 .4188 L
.56868 .42042 L
.5883 .42867 L
.60793 .42609 L
.62755 .42779 L
.64717 .42894 L
.6668 .42948 L
.68642 .42936 L
.70604 .4286 L
.72567 .42724 L
.74529 .42536 L
.76491 .42576 L
.78454 .41629 L
.80416 .41784 L
.82378 .41533 L
.84341 .41374 L
.8627 .43132 L
.84341 .44447 L
.83158 .45094 L
.82378 .45709 L
.80416 .46156 L
.78454 .4676 L
.77356 .47057 L
.76491 .4715 L
.74529 .47634 L
.72567 .48109 L
.70604 .48498 L
.68642 .48748 L
.6668 .48789 L
.64717 .48608 L
.62755 .48261 L
.60793 .47812 L
.5883 .47313 L
.57253 .47057 L
.56868 .46956 L
.54906 .46384 L
.52943 .45716 L
.5144 .45094 L
.50981 .44852 L
.49019 .43647 L
.4836 .43132 L
.49019 .41441 L
s
.6 g
.52943 .37302 m
.54906 .37277 L
.56868 .37386 L
.5883 .37524 L
.60793 .37655 L
.62755 .37762 L
.64717 .37835 L
.6668 .37869 L
.68642 .37862 L
.70604 .37813 L
.72567 .37727 L
.74529 .3761 L
.76491 .37474 L
.78454 .3734 L
.80416 .3726 L
.82378 .37417 L
.82604 .39207 L
.82378 .39331 L
.80416 .40206 L
.78454 .40925 L
.77685 .4117 L
.76491 .4168 L
.74529 .418 L
.72567 .42068 L
.70604 .42253 L
.68642 .42353 L
.6668 .42369 L
.64717 .42299 L
.62755 .42144 L
.60793 .41906 L
.5883 .42074 L
.56925 .4117 L
.56868 .41152 L
.54906 .4048 L
.52943 .39673 L
.52015 .39207 L
F
0 g
.52943 .37302 m
.54906 .37277 L
.56868 .37386 L
.5883 .37524 L
.60793 .37655 L
.62755 .37762 L
.64717 .37835 L
.6668 .37869 L
.68642 .37862 L
.70604 .37813 L
.72567 .37727 L
.74529 .3761 L
.76491 .37474 L
.78454 .3734 L
.80416 .3726 L
.82378 .37417 L
.82604 .39207 L
.82378 .39331 L
.80416 .40206 L
.78454 .40925 L
.77685 .4117 L
.76491 .4168 L
.74529 .418 L
.72567 .42068 L
.70604 .42253 L
.68642 .42353 L
.6668 .42369 L
.64717 .42299 L
.62755 .42144 L
.60793 .41906 L
.5883 .42074 L
.56925 .4117 L
.56868 .41152 L
.54906 .4048 L
.52943 .39673 L
.52015 .39207 L
.52943 .37302 L
s
.7 g
.52943 .48878 m
.54906 .48548 L
.56868 .48614 L
.5883 .48575 L
.60793 .48889 L
.62309 .49019 L
.62755 .4905 L
.64717 .49152 L
.6668 .49199 L
.68642 .49189 L
.70604 .49121 L
.72326 .49019 L
.72567 .49002 L
.74529 .488 L
.76491 .48378 L
.78454 .48575 L
.80416 .48578 L
.81949 .49019 L
.80416 .5078 L
.80126 .50981 L
.78454 .51783 L
.76491 .52495 L
.74943 .52943 L
.74529 .53039 L
.72567 .53498 L
.70604 .53875 L
.68642 .54103 L
.6668 .5414 L
.64717 .53977 L
.62755 .53647 L
.60793 .53208 L
.59668 .52943 L
.5883 .5271 L
.56868 .52061 L
.54906 .51206 L
.54492 .50981 L
.52943 .49607 L
.52743 .49019 L
F
0 g
.52943 .48878 m
.54906 .48548 L
.56868 .48614 L
.5883 .48575 L
.60793 .48889 L
.62309 .49019 L
.62755 .4905 L
.64717 .49152 L
.6668 .49199 L
.68642 .49189 L
.70604 .49121 L
.72326 .49019 L
.72567 .49002 L
.74529 .488 L
.76491 .48378 L
.78454 .48575 L
.80416 .48578 L
.81949 .49019 L
.80416 .5078 L
.80126 .50981 L
.78454 .51783 L
.76491 .52495 L
.74943 .52943 L
.74529 .53039 L
.72567 .53498 L
.70604 .53875 L
.68642 .54103 L
.6668 .5414 L
.64717 .53977 L
.62755 .53647 L
.60793 .53208 L
.59668 .52943 L
.5883 .5271 L
.56868 .52061 L
.54906 .51206 L
.54492 .50981 L
.52943 .49607 L
.52743 .49019 L
.52943 .48878 L
s
.3 g
.54906 .43316 m
.56868 .43154 L
.5883 .4321 L
.60793 .4331 L
.62755 .43404 L
.64717 .43471 L
.6668 .43503 L
.68642 .43496 L
.70604 .4345 L
.72567 .43372 L
.74529 .43273 L
.76491 .43181 L
.78454 .43167 L
.79811 .45094 L
.78454 .45741 L
.76491 .46455 L
.74529 .47006 L
.74324 .47057 L
.72567 .47517 L
.70604 .47997 L
.68642 .48331 L
.6668 .48389 L
.64717 .48141 L
.62755 .47699 L
.60793 .47186 L
.60293 .47057 L
.5883 .4667 L
.56868 .4602 L
.54906 .4515 L
.54805 .45094 L
F
0 g
.54906 .43316 m
.56868 .43154 L
.5883 .4321 L
.60793 .4331 L
.62755 .43404 L
.64717 .43471 L
.6668 .43503 L
.68642 .43496 L
.70604 .4345 L
.72567 .43372 L
.74529 .43273 L
.76491 .43181 L
.78454 .43167 L
.79811 .45094 L
.78454 .45741 L
.76491 .46455 L
.74529 .47006 L
.74324 .47057 L
.72567 .47517 L
.70604 .47997 L
.68642 .48331 L
.6668 .48389 L
.64717 .48141 L
.62755 .47699 L
.60793 .47186 L
.60293 .47057 L
.5883 .4667 L
.56868 .4602 L
.54906 .4515 L
.54805 .45094 L
.54906 .43316 L
s
.4 g
.5883 .33843 m
.60793 .33706 L
.62755 .33674 L
.64717 .33672 L
.6668 .33675 L
.68642 .33674 L
.70604 .33671 L
.72567 .3368 L
.74529 .33735 L
.76491 .33966 L
.77041 .35283 L
.76491 .35462 L
.74529 .35977 L
.72567 .36355 L
.70604 .36612 L
.68642 .3675 L
.6668 .36771 L
.64717 .36675 L
.62755 .36461 L
.60793 .36128 L
.5883 .35667 L
.57573 .35283 L
F
0 g
.5883 .33843 m
.60793 .33706 L
.62755 .33674 L
.64717 .33672 L
.6668 .33675 L
.68642 .33674 L
.70604 .33671 L
.72567 .3368 L
.74529 .33735 L
.76491 .33966 L
.77041 .35283 L
.76491 .35462 L
.74529 .35977 L
.72567 .36355 L
.70604 .36612 L
.68642 .3675 L
.6668 .36771 L
.64717 .36675 L
.62755 .36461 L
.60793 .36128 L
.5883 .35667 L
.57573 .35283 L
.5883 .33843 L
s
.8 g
.5883 .49848 m
.60793 .49741 L
.62755 .49757 L
.64717 .4979 L
.6668 .49809 L
.68642 .49804 L
.70604 .49778 L
.72567 .49746 L
.74529 .49754 L
.76491 .50004 L
.76863 .50981 L
.76491 .51208 L
.74529 .52045 L
.72567 .52592 L
.7065 .52943 L
.70604 .52951 L
.68642 .53234 L
.6668 .53281 L
.64717 .53076 L
.63831 .52943 L
.62755 .52741 L
.60793 .52266 L
.5883 .5156 L
.57748 .50981 L
F
0 g
.5883 .49848 m
.60793 .49741 L
.62755 .49757 L
.64717 .4979 L
.6668 .49809 L
.68642 .49804 L
.70604 .49778 L
.72567 .49746 L
.74529 .49754 L
.76491 .50004 L
.76863 .50981 L
.76491 .51208 L
.74529 .52045 L
.72567 .52592 L
.7065 .52943 L
.70604 .52951 L
.68642 .53234 L
.6668 .53281 L
.64717 .53076 L
.63831 .52943 L
.62755 .52741 L
.60793 .52266 L
.5883 .5156 L
.57748 .50981 L
.5883 .49848 L
s
.2 g
.5883 .44419 m
.60793 .44151 L
.62755 .44094 L
.64717 .44088 L
.6668 .44091 L
.68642 .4409 L
.70604 .44088 L
.72567 .44105 L
.74529 .44204 L
.76491 .44837 L
.76547 .45094 L
.76491 .45138 L
.74529 .461 L
.72567 .46674 L
.70604 .47038 L
.70463 .47057 L
.68642 .47386 L
.6668 .4745 L
.64717 .4718 L
.64037 .47057 L
.62755 .46827 L
.60793 .46335 L
.5883 .4557 L
.58063 .45094 L
F
0 g
.5883 .44419 m
.60793 .44151 L
.62755 .44094 L
.64717 .44088 L
.6668 .44091 L
.68642 .4409 L
.70604 .44088 L
.72567 .44105 L
.74529 .44204 L
.76491 .44837 L
.76547 .45094 L
.76491 .45138 L
.74529 .461 L
.72567 .46674 L
.70604 .47038 L
.70463 .47057 L
.68642 .47386 L
.6668 .4745 L
.64717 .4718 L
.64037 .47057 L
.62755 .46827 L
.60793 .46335 L
.5883 .4557 L
.58063 .45094 L
.5883 .44419 L
s
.3 g
.5883 .56531 m
.60793 .56346 L
.62755 .56369 L
.64717 .56412 L
.6668 .56436 L
.68642 .5643 L
.70604 .56397 L
.72567 .56355 L
.74529 .56364 L
.76284 .56868 L
.74529 .57926 L
.72567 .58551 L
.71364 .5883 L
.70604 .58945 L
.68642 .59146 L
.6668 .59176 L
.64717 .59038 L
.6318 .5883 L
.62755 .58717 L
.60793 .58184 L
.5883 .57301 L
.58339 .56868 L
F
0 g
.5883 .56531 m
.60793 .56346 L
.62755 .56369 L
.64717 .56412 L
.6668 .56436 L
.68642 .5643 L
.70604 .56397 L
.72567 .56355 L
.74529 .56364 L
.76284 .56868 L
.74529 .57926 L
.72567 .58551 L
.71364 .5883 L
.70604 .58945 L
.68642 .59146 L
.6668 .59176 L
.64717 .59038 L
.6318 .5883 L
.62755 .58717 L
.60793 .58184 L
.5883 .57301 L
.58339 .56868 L
.5883 .56531 L
s
.7 g
.5883 .39173 m
.60793 .38886 L
.62755 .38808 L
.64717 .38788 L
.6668 .38784 L
.68642 .38785 L
.70604 .38792 L
.72567 .38826 L
.74529 .38948 L
.75916 .39207 L
.74529 .40723 L
.73272 .4117 L
.72567 .41296 L
.70604 .41556 L
.68642 .41692 L
.6668 .41713 L
.64717 .41619 L
.62755 .41405 L
.61337 .4117 L
.60793 .40993 L
.5883 .39985 L
.58719 .39207 L
F
0 g
.5883 .39173 m
.60793 .38886 L
.62755 .38808 L
.64717 .38788 L
.6668 .38784 L
.68642 .38785 L
.70604 .38792 L
.72567 .38826 L
.74529 .38948 L
.75916 .39207 L
.74529 .40723 L
.73272 .4117 L
.72567 .41296 L
.70604 .41556 L
.68642 .41692 L
.6668 .41713 L
.64717 .41619 L
.62755 .41405 L
.61337 .4117 L
.60793 .40993 L
.5883 .39985 L
.58719 .39207 L
.5883 .39173 L
s
.9 g
.62755 .50979 m
.64717 .50701 L
.6668 .5064 L
.68642 .50651 L
.70604 .50755 L
.7197 .50981 L
.70604 .51733 L
.68642 .52068 L
.6668 .52114 L
.64717 .51895 L
.62755 .51111 L
.62747 .50981 L
F
0 g
.62755 .50979 m
.64717 .50701 L
.6668 .5064 L
.68642 .50651 L
.70604 .50755 L
.7197 .50981 L
.70604 .51733 L
.68642 .52068 L
.6668 .52114 L
.64717 .51895 L
.62755 .51111 L
.62747 .50981 L
.62755 .50979 L
s
.1 g
.64717 .44897 m
.6668 .44832 L
.68642 .44845 L
.70604 .44952 L
.71709 .45094 L
.70604 .45975 L
.68642 .46326 L
.6668 .46373 L
.64717 .46145 L
.62914 .45094 L
F
0 g
.64717 .44897 m
.6668 .44832 L
.68642 .44845 L
.70604 .44952 L
.71709 .45094 L
.70604 .45975 L
.68642 .46326 L
.6668 .46373 L
.64717 .46145 L
.62914 .45094 L
.64717 .44897 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00?Oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0dooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kS?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0hooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8b
onk^kS?ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08_ooool003gooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0=_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0<oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg03?ooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL08_ooool003Gooooo1_l0
0003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400[ooooo`Ko0000
1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100<oooool01Ol@413o
oooooooooooooooo410@03[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@03Cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@02;ooooo000o
ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000fooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000cooooo`05o`000?ooooooooooooooool0
0000>_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000=Oooool00onH
V9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000008_ooool0043ooooo00?oMgMgofIV
I_ooool00_ooool01Ol0003ooooooooooooooooo000003Kooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000003?ooooo00Go0000ooooooooooooooooo`00000jooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`03ogMgMomVIVKooooo00;o
oooo00Go0000ooooooooooooooooo`00000Rooooo`00@Oooool01Ol0003ooooooooooooooooo410@
00?ooooo00?o410@ooooooooool0=?ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@4100<oooool01Ol@413ooooooooooooooooo410@03[ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@03Oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo023ooooo000mooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg03Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg03?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0jooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0cooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02;ooooo000mooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^03Cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^03?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`03oeEEEOmVIVKo000000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0cooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02;ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo000Joooooooo0000C_l00001ooooo`00
6_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0?Ooo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool08ooo
ool1o`00007ooooo0008ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKo
oooo00?o0000ooooooooool0oooooom:ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooom:ooooo`7o
00000Oooool000Go00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41001_ooool00ol0003oooooooooo`3ooooood[ooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?ooooooB?ooool3o`00007o
oooo000:ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo0008ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Oooooooogmo
Od3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Ooo
ooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000oooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`003ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000?ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000oooooo00Go0000oooooooooooooooo
o`000006ooooo`?o00001?ooooooogmoOd3oOgmo1?ooool3o`00007ooooo000?ooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool000oooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`003oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000?ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooo7ogmoObSo0000D?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?oooonmogmoO`[o0000:?mVIVH9o`0004OoOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00Cooooo_?moOgl00ol0003oIVIVofIVIP0hofIVIP03o`000?moOgooOgmo04Go
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo^omoOgl00ol0003oIVIV
ofIVIP0jofIVIP03o`000?moOgooOgmo04CoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00Cooooo^_moOgl00ol0003oIVIVofIVIP0kofIVIP03o`000?moOgooOgmo04CoOgmo1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo^OmoOgl00ol0003oIVIVofIVIP0l
ofIVIP03o`000?moOgooOgmo04CoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00Cooooo^?moOgl4o`0003[oIVIV1?l00015ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04oooookcoOgmo1?l0000cofIVIP?o0000BOmoOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooo0ogmoO`?o0000:omVIVH5o`0004coOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00Cooooo`omoOgl5o`0001ooIVIV1ol0001AogmoO`Kooooo0Ol0
0001ooooo`006_ooool2o`0000Gooooob?moOgl=o`0000coIVIV1_l0001HogmoO`Gooooo0_l00001
ooooo`006_ooool00ol0003oooooooooo`04ooooomGoOgmo3?l0001NogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooojgoOgmo1ol0001=ogmoO`So0000=_moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?oooonYogmoO`Co00001onIVIT=o`0003?oOgmo
3Ol00008oiVIV@?o0000<omoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
oonYogmoO`03o`000?nIVIWoVIVI01GoVIVI<ol0000GoiVIV@03o`000?moOgooOgmo037oOgmo1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooZ?moOgl00ol0003oVIVIoiVIV@1P
oiVIV@03o`000?moOgooOgmo037oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CoooooZ?moOgl00ol0003oVIVIoiVIV@1PoiVIV@03o`000?moOgooOgmo037oOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CoooooYomoOgl00ol0003oVIVIoiVIV@0SoiVIVA_o
00009?nIVIT00ol0003oOgmoogmoO`0`ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooojOoOgmo00?o0000oiVIVOnIVIT05_nIVIT=o`0001_o/k>c3?l0000HoiVIV@03o`00
0?moOgooOgmo033oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooY_mo
Ogl3o`0001?oVIVI1?l0000dok>c/`;o00005?nIVIT3o`0003;oOgmo1_ooool1o`00007ooooo0008
ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo00?o0000oooooooo
ool01?oooonYogmoO`;o00004OnIVIT00ol0003o/k>cok>c/`0fok>c/`03o`000?nIVIWoVIVI00oo
VIVI0ol0000eogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`04oooooj_oOgmo0ol0000?oiVIV@;o
0000=Onc/k<00ol0003oVIVIoiVIV@0>oiVIV@;o0000>?moOgl6ooooo`7o00000Oooool000[ooooo
00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000oooooooo
ool01?oooon^ogmoO`;o00003onIVIT00ol0003o/k>cok>c/`0aok>c/`03o`000?nIVIWoVIVI00go
VIVI0_l0000jogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000001_ooool3o`0000Cooooo/?moOgl3o`0000goVIVI0_l0000`ok>c/`03
o`000?nIVIWoVIVI00coVIVI0_l0000logmoO`Cooooo0ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`04oooook?o
Ogmo0ol0000<oiVIV@03o`000?nc/k?o/k>c02[o/k>c0ol0000=oiVIV@;o0000?_moOgl6ooooo`7o
00000Oooool000[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Ko
oooo00?o0000ooooooooool01?oooonfogmoO`;o00002onIVIT6o`0002?o/k>c0ol0000;oiVIV@Go
0000@?moOgl6ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?oooonLogmoO`_o00004OmoOgl3o`0000ko
VIVI1Ol0000Iok>c/`Go00003?nIVIT2o`0001CoOgmo1Ol0000/ogmoO`Kooooo0Ol00001ooooo`00
2?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003o
ooooooooo`04oooooicoOgmo00?o0000ofIVI_mVIVH02?mVIVH7o`0000goOgmo0_l0000AoiVIVAWo
00001onIVIT:o`0000GoOgmo4Ol00005ofIVIP03o`000?moOgooOgmo02WoOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CoooooVomoOgl00ol0003oIVIVofIVIP0@ofIVIP[o0000
1OmoOgl;o`0001ooVIVI1ol0000<ogmoO`?o00005omVIVH00ol0003oOgmoogmoO`0XogmoO`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooi_oOgmo00?o0000ofIVI_mVIVH06_mV
IVH3o`0000goOgmo7ol0000AogmoO`;o00006omVIVH00ol0003oOgmoogmoO`0WogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04oooooi_oOgmo00?o0000ofIVI_mVIVH07OmVIVH2
o`0000?oOgmo2?l0000VogmoO`[o00007_mVIVH00ol0003oOgmoogmoO`0VogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04oooooi[oOgmo00?o0000ofIVI_mVIVH08?mVIVH3o`00
00SoIVIV9_l0000YofIVIP03o`000?moOgooOgmo02GoOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CoooooV_moOgl00ol0003oIVIVofIVIP0CofIVIQSo00009_mVIVHAo`0001So
IVIV0_l0000VogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooi_oOgmo
00?o0000ofIVI_mVIVH04_mVIVH00ol0003oC4a<oda<C00Eoda<C2Ko00004?m<C4`00ol0003oIVIV
ofIVIP0DofIVIP;o0000:?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
oonLogmoO`;o00004_mVIVH00ol0003oC4a<oda<C01<oda<C003o`000?mVIVKoIVIV01;oIVIV00?o
0000ogmoOomoOgl0:?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonN
ogmoO`;o00004?mVIVH00ol0003oC4a<oda<C00=oda<C3?o00003Om<C4`00ol0003oIVIVofIVIP0?
ofIVIP;o0000:omoOgl6ooooo`7o00000Oooool001[ooooo0_l00005oooooj3oOgmo00?o0000ofIV
I_mVIVH03?mVIVH00ol0003oC4a<oda<C00:oda<C0Co0000<olc<c<2o`0000_oC4a<00?o0000ofIV
I_mVIVH03OmVIVH2o`0002goOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
ooooXOmoOgl2o`0000coIVIV00?o0000oda<C?m<C4`02Om<C4`00ol0003o<c<coc<c<`0goc<c<`;o
00002_m<C4`00ol0003oIVIVofIVIP0:ofIVIP;o0000;omoOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?oooonSogmoO`?o00002OmVIVH00ol0003oC4a<oda<C008oda<C0;o0000
3_lc<c<No`0000oo<c<c00?o0000oda<C?m<C4`01om<C4`2o`0000[oIVIV00?o0000ogmoOomoOgl0
;omoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonVogmoO`?o00001omV
IVH3o`0000WoC4a<00?o0000oc<c<olc<c<03Olc<c<00ol0003o6ATIoaTI6@0GoaTI6@03o`000?lc
<c?o<c<c00go<c<c0_l00008oda<C003o`000?mVIVKoIVIV00WoIVIV00?o0000ogmoOomoOgl0<?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonYogmoO`;o00002?mVIVH3
o`0000OoC4a<0_l0000>oc<c<`;o00005_lI6AT00ol0003o<c<coc<c<`0<oc<c<`;o00002Om<C4`0
0ol0003oIVIVofIVIP07ofIVIP?o0000<omoOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?oooon[ogmoO`?o00002?mVIVH2o`0000OoC4a<0_l0000>oc<c<`03o`000?lI6AWo6ATI
00oo6ATI1?l0000=oc<c<`;o00002?m<C4`3o`0000OoIVIV0ol00007ogmoO`Ko0000:OmoOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon^ogmoO`;o00002?mVIVH3o`0000Ko
C4a<0_l0000=oc<c<`Go00001OlI6AT7o`0000ko<c<c0ol00007oda<C0?o00001omVIVH3o`0000So
Ogmo0_l00006oiVIV@Go00009?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?oooonEogmoOa7o00002_moOgl3o`0000SoIVIV0_l00006oda<C0Go00003Olc<c<5o`0001;o<c<c
0ol00007oda<C0?o00001omVIVH3o`0000WoOgmo0_l0000=oiVIV@?o00008OmoOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?oooonDogmoO`03o`000?nIVIWoVIVI00ooVIVI0ol0
000:ogmoO`?o00001omVIVH3o`0000SoC4a<1Ol0000Joc<c<`Go00001om<C4`3o`0000KoIVIV1?l0
0009ogmoO`?o00004_nIVIT00ol0003oOgmoogmoO`0NogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04oooooi?oOgmo00?o0000oiVIVOnIVIT04onIVIT5o`0000SoOgmo1Ol00005
ofIVIPKo00001om<C4`8o`0000_o<c<c1ol00006oda<C0Ko00000omVIVH6o`0000WoOgmo1?l0000F
oiVIV@03o`000?moOgooOgmo01goOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CoooooTomoOgl00ol0003oVIVIoiVIV@0HoiVIV@Ko00001omoOgl6o`0000GoIVIV0ol0000<oda<
C0_o00002Om<C4`4o`0000KoIVIV2Ol00005ogmoO`Co00006OnIVIT00ol0003oOgmoogmoO`0Nogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooiCoOgmo00?o0000oiVIVOnI
VIT07OnIVIT<o`000003ogmoOol0003o000000?o00000omVIVH4o`0001WoC4a<0ol00005ofIVIPSo
00001_nIVIT5o`0001coVIVI00?o0000ogmoOomoOgl07omoOgl6ooooo`7o00000Oooool001[ooooo
0_l00005oooooiCoOgmo00?o0000oiVIVOnIVIT0:OnIVIT3o`0000?oOgmo0ol00004ofIVIP?o0000
4Om<C4`5o`0000?oIVIV1Ol000000omoOgoo0000o`000002o`0002WoVIVI00?o0000ogmoOomoOgl0
8?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool01?oooonEogmoO`;o0000;?nI
VIT5o`000003ogmoOol0003o000000?o00000_mVIVHAo`0000GoIVIV0ol00003ogmoO`?o00001onI
VIT6o`0001ooVIVI00?o0000ogmoOomoOgl08OmoOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?oooonGogmoO`03o`000?nIVIWoVIVI01?oVIVI5?l00007oiVIV@go00003?mVIVH5
o`000003ogmoOol0003o000000?o00001onIVIT3o`0000Ko/k>c3?l0000BoiVIV@03o`000?moOgoo
Ogmo02;oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooV?moOgl2o`00
00koVIVI1Ol0000Dok>c/`Wo00001?nIVITUo`0001Go/k>c0_l0000?oiVIV@03o`000?moOgooOgmo
02?oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooV_moOgl00ol0003o
VIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01oo/k>c7Ol0000Rok>c/`03o`000?nIVIWoVIVI00go
VIVI00?o0000ogmoOomoOgl08omoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?oooonKogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<0G?nc/k<00ol0003oVIVI
oiVIV@0<oiVIV@;o00009_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
oonLogmoO`;o00003?nIVIT00ol0003o/k>cok>c/`0@ok>c/cSo00004_nc/k<00ol0003oVIVIoiVI
V@0:oiVIV@?o0000:?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonN
ogmoO`;o00002onIVIT00ol0003o/k>cok>c/`0>ok>c/`03o`000?o<c<coc<c<03Koc<c<0ol0000>
ok>c/`03o`000?nIVIWoVIVI00WoVIVI0_l0000[ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04oooooj3oOgmo00?o0000oiVIVOnIVIT02OnIVIT00ol0003o/k>cok>c/`0<ok>c
/`03o`000?o<c<coc<c<03Woc<c<00?o0000ok>c/onc/k<02onc/k<00ol0003oVIVIoiVIV@08oiVI
V@;o0000;OmoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonQogmoO`;o
00002_nIVIT00ol0003o/k>cok>c/`0:ok>c/`03o`000?o<c<coc<c<013oc<c<6_l0000Aolc<c003
o`000?nc/k?o/k>c00Wo/k>c00?o0000oiVIVOnIVIT02?nIVIT00ol0003oOgmoogmoO`0]ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooj?oOgmo0_l00009oiVIV@;o0000
2Onc/k<2o`0000ooc<c<0ol0000JonKViP;o00003oo<c<`00ol0003o/k>cok>c/`07ok>c/`;o0000
2OnIVIT2o`00033oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooYOmo
Ogl2o`0000WoVIVI0_l00009ok>c/`;o00003oo<c<`2o`0001Ooi^KV0_l0000?olc<c0;o00002?nc
/k<2o`0000[oVIVI00?o0000ogmoOomoOgl0<?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?oooonWogmoO`;o00002OnIVIT2o`0000Wo/k>c0ol0000>olc<c0;o00004_oVi^H3
o`0000koc<c<0ol00009ok>c/`03o`000?nIVIWoVIVI00OoVIVI0ol0000cogmoO`Kooooo0Ol00001
ooooo`006_ooool2o`0000GoooooZOmoOgl3o`0000SoVIVI0_l0000:ok>c/`?o00003Oo<c<`5o`00
00[oi^KV0ol0000=olc<c0Co00002Onc/k<3o`0000OoVIVI0ol0000fogmoO`Gooooo0_l00001oooo
o`006_ooool00ol0003oooooooooo`04ooooojcoOgmo0ol00007oiVIV@?o00002_nc/k<3o`0000oo
c<c<2_l0000=olc<c0?o00002_nc/k<3o`0000OoVIVI0ol0000iogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooojooOgmo1?l00006oiVIV@?o00002_nc/k<3o`0001koc<c<
1Ol00009ok>c/`Co00001onIVIT3o`0003coOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CoooooUomoOgl<o`00013oOgmo0ol00006oiVIV@Ko00001onc/k<7o`0001Coc<c<0ol0
000;ok>c/`?o00001OnIVIT6o`0000ooOgmo3Ol0000SogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04oooooiOoOgmo00?o0000ofIVI_mVIVH02OmVIVH4o`0000ooOgmo1Ol00007
oiVIV@Co00002_nc/k<5o`0000Goc<c<2ol00009ok>c/`Co00001?nIVIT4o`0001;oOgmo0ol0000<
ofIVIP03o`000?moOgooOgmo027oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CoooooV?moOgl00ol0003oIVIVofIVIP0<ofIVIPGo00003omoOgl5o`0000KoVIVI0ol0000<ok>c
/`Go00003onc/k<5o`0000GoVIVI0ol0000BogmoO`Co00003_mVIVH00ol0003oOgmoogmoO`0Rogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooiSoOgmo00?o0000ofIVI_mV
IVH04OmVIVH3o`00017oOgmo0ol00006oiVIV@Go00006?nc/k<3o`0000KoVIVI1?l0000>ogmoO`Oo
00004_mVIVH00ol0003oOgmoogmoO`0RogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04oooooiWoOgmo00?o0000ofIVI_mVIVH04omVIVH5o`0000ooOgmo1Ol00006oiVIVASo0000
1_nIVIT3o`0000coOgmo1_l0000HofIVIP03o`000?moOgooOgmo02?oOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CoooooVOmoOgl00ol0003oIVIVofIVIP0HofIVIPco00002?mo
Ogl6o`0001WoVIVI1Ol00008ogmoO`Oo00007_mVIVH00ol0003oOgmoogmoO`0SogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04oooooiWoOgmo00?o0000ofIVI_mVIVH09?mVIVH3
o`0000_oOgmo6Ol00008ogmoO`Go00009OmVIVH00ol0003oOgmoogmoO`0SogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04oooooi[oOgmo00?o0000ofIVI_mVIVH09_mVIVH5o`00
01ooOgmo2?l0000WofIVIP?o00009_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?oooonKogmoO`03o`000?mVIVKoIVIV02[oIVIV7ol0000^ofIVIP03o`000?moOgooOgmo02Oo
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooW?moOgl2o`0007KoIVIV
00?o0000ogmoOomoOgl0:?moOgl6ooooo`7o00000Oooool001[ooooo0_l00005oooooikoOgmo0_l0
001cofIVIP03o`000?moOgooOgmo02WoOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CoooooX?moOgl00ol0003oIVIVofIVIP1_ofIVIP03o`000?moOgooOgmo02[oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooXOmoOgl2o`0001[oIVIV=ol0000LofIV
IP;o0000;OmoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonSogmoO`03
o`000?mVIVKoIVIV01KoIVIV00?o0000oda<C?m<C4`0=Om<C4`3o`0001SoIVIV00?o0000ogmoOomo
Ogl0;OmoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonSogmoO`;o0000
5_mVIVH2o`0003WoC4a<0_l0000EofIVIP;o0000<?moOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?oooonUogmoO`03o`000?mVIVKoIVIV01GoIVIV0_l0000eoda<C0;o00005_mV
IVH00ol0003oOgmoogmoO`0`ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooojKoOgmo0_l0000GofIVIP;o0000<Om<C4`2o`0001KoIVIV0_l0000cogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooojSoOgmo00?o0000ofIVI_mVIVH05_mVIVH2o`00
02coC4a<0ol0000EofIVIP?o0000=OmoOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?oooonYogmoO`?o00005omVIVH3o`0002KoC4a<0ol0000FofIVIP;o0000>?moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?oooon/ogmoO`?o00005omVIVH3o`0001ooC4a<
1?l0000GofIVIP;o0000>_moOgl6ooooo`7o00000Oooool000Oooooo1Ol00003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`04ooooojooOgmo1?l0000FofIVIPKo0000
4_m<C4`7o`0001SoIVIV0ol0000logmoO`Kooooo0Ol00001ooooo`001oooool01OnHV9So8B4Qonk^
k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00Co
oooo/omoOgl3o`0001WoIVIV4_l0000KofIVIPCo0000?omoOgl6ooooo`7o00000Oooool000Sooooo
00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000oooooooo
ool01?oooonfogmoO`?o0000@?mVIVH3o`0004?oOgmo1_ooool1o`00007ooooo0009ooooo`03oiRH
V?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000006ooooo`?o00001?ooooniogmoO`?o
0000>_mVIVH3o`0004KoOgmo1?ooool3o`00007ooooo000:ooooo`03ogMgMomVIVKooooo00;ooooo
00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00Cooooo_?moOgl4o`0003?o
IVIV0ol00019ogmoO`Kooooo0Ol00001ooooo`002oooool01Ol0003ooooooooooooooooo410@00?o
oooo00?o410@ooooooooool01?ooool00ol0003oooooooooo`04oooool3oOgmo0ol0000[ofIVIPGo
0000C?moOgl6ooooo`7o00000Oooool000Oooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`04oooool?oOgmo1Ol0000QofIV
IPGo0000DOmoOgl6ooooo`7o00000Oooool000Oooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`04ooooolSoOgmo3Ol0000<
ofIVIPSo0000E_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooEogmo
O`co0000G_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3o
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo0_l00005ooooooooOgmo
@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooo
ogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo0_l00005oooo
ooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3o
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooooomo
Ogm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo0_l0
0005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool01?oooooo
ogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo
@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[o
oooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool0
1?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooooomo
Ogm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
ooooOgmo@?moOgl6ooooo`7o00000Oooool000Oooooo00GoV9RHoa0@4?l0003o<S8bolc<c003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6
ooooo`7o00000Oooool000Oooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Ooo
ool000_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o
0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000:ooooo`03ojVYZOl@413o
oooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`?o00001?ooooooogmoOd3oOgmo1?oo
ool3o`00007ooooo0009ooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool0
0onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003ooooooooo
o`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000Oooooo00Go410@oiRHV?oooooo^[Zjo`00
0003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`04ooooooooOgmo
@?moOgl6ooooo`7o00000Oooool000Oooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo
@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_oo
ool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007ooooo000Joooo
o`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooooomo
Ogm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
ooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3o
Ogmo1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007ooooo
000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo
@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooo
ogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00
007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
ooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3o
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Ooo
ool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooo
ogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo
0009ooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000[ooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo0007ooooo`Go00000oooool01Ol@413ooooooooooooooooo410@
00Kooooo0ol00004ooooooooOgmo@?moOgl4ooooo`?o00000Oooool000Oooooo00CoA4A4omgMgOoo
oooo00001?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0oooooom:
ooooo`7o00000Oooool000Oooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooo
oooo000000Kooooo00?o0000ooooooooool0oooooom:ooooo`7o00000Oooool000Sooooo00?oMgMg
olc<c?l000001?ooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool0oooo
oom:ooooo`7o00000Oooool000Sooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Kooooo00?o0000ooooooooool0oooooom:ooooo`7o00000Oooool000Wooooo00?oMgMg
o`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0?Ooo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo02?ooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo0Ol00001ooooo`006_ooooooo`00
04ko00000Oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-30.1723, -14.304, 0.195672, \
0.195672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0192308 0.211538 0.0192308 [
[.11538 -0.0125 -9 -9 ]
[.11538 -0.0125 9 0 ]
[.30769 -0.0125 -9 -9 ]
[.30769 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69231 -0.0125 -6 -9 ]
[.69231 -0.0125 6 0 ]
[.88462 -0.0125 -6 -9 ]
[.88462 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -18 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .21154 -6 -4.5 ]
[-0.0125 .21154 0 4.5 ]
[-0.0125 .40385 -12 -4.5 ]
[-0.0125 .40385 0 4.5 ]
[-0.0125 .59615 -12 -4.5 ]
[-0.0125 .59615 0 4.5 ]
[-0.0125 .78846 -12 -4.5 ]
[-0.0125 .78846 0 4.5 ]
[-0.0125 .98077 -12 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11538 0 m
.11538 .00625 L
s
[(-20)] .11538 -0.0125 0 1 Mshowa
.30769 0 m
.30769 .00625 L
s
[(-10)] .30769 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69231 0 m
.69231 .00625 L
s
[(10)] .69231 -0.0125 0 1 Mshowa
.88462 0 m
.88462 .00625 L
s
[(20)] .88462 -0.0125 0 1 Mshowa
.125 Mabswid
.15385 0 m
.15385 .00375 L
s
.19231 0 m
.19231 .00375 L
s
.23077 0 m
.23077 .00375 L
s
.26923 0 m
.26923 .00375 L
s
.34615 0 m
.34615 .00375 L
s
.38462 0 m
.38462 .00375 L
s
.42308 0 m
.42308 .00375 L
s
.46154 0 m
.46154 .00375 L
s
.53846 0 m
.53846 .00375 L
s
.57692 0 m
.57692 .00375 L
s
.61538 0 m
.61538 .00375 L
s
.65385 0 m
.65385 .00375 L
s
.73077 0 m
.73077 .00375 L
s
.76923 0 m
.76923 .00375 L
s
.80769 0 m
.80769 .00375 L
s
.84615 0 m
.84615 .00375 L
s
.07692 0 m
.07692 .00375 L
s
.03846 0 m
.03846 .00375 L
s
.92308 0 m
.92308 .00375 L
s
.96154 0 m
.96154 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(-10)] -0.0125 .01923 1 0 Mshowa
0 .21154 m
.00625 .21154 L
s
[(0)] -0.0125 .21154 1 0 Mshowa
0 .40385 m
.00625 .40385 L
s
[(10)] -0.0125 .40385 1 0 Mshowa
0 .59615 m
.00625 .59615 L
s
[(20)] -0.0125 .59615 1 0 Mshowa
0 .78846 m
.00625 .78846 L
s
[(30)] -0.0125 .78846 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(40)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .05769 m
.00375 .05769 L
s
0 .09615 m
.00375 .09615 L
s
0 .13462 m
.00375 .13462 L
s
0 .17308 m
.00375 .17308 L
s
0 .25 m
.00375 .25 L
s
0 .28846 m
.00375 .28846 L
s
0 .32692 m
.00375 .32692 L
s
0 .36538 m
.00375 .36538 L
s
0 .44231 m
.00375 .44231 L
s
0 .48077 m
.00375 .48077 L
s
0 .51923 m
.00375 .51923 L
s
0 .55769 m
.00375 .55769 L
s
0 .63462 m
.00375 .63462 L
s
0 .67308 m
.00375 .67308 L
s
0 .71154 m
.00375 .71154 L
s
0 .75 m
.00375 .75 L
s
0 .82692 m
.00375 .82692 L
s
0 .86538 m
.00375 .86538 L
s
0 .90385 m
.00375 .90385 L
s
0 .94231 m
.00375 .94231 L
s
.25 Mabswid
0 0 m
0 1 L
s
.11538 .99375 m
.11538 1 L
s
.30769 .99375 m
.30769 1 L
s
.5 .99375 m
.5 1 L
s
.69231 .99375 m
.69231 1 L
s
.88462 .99375 m
.88462 1 L
s
.125 Mabswid
.15385 .99625 m
.15385 1 L
s
.19231 .99625 m
.19231 1 L
s
.23077 .99625 m
.23077 1 L
s
.26923 .99625 m
.26923 1 L
s
.34615 .99625 m
.34615 1 L
s
.38462 .99625 m
.38462 1 L
s
.42308 .99625 m
.42308 1 L
s
.46154 .99625 m
.46154 1 L
s
.53846 .99625 m
.53846 1 L
s
.57692 .99625 m
.57692 1 L
s
.61538 .99625 m
.61538 1 L
s
.65385 .99625 m
.65385 1 L
s
.73077 .99625 m
.73077 1 L
s
.76923 .99625 m
.76923 1 L
s
.80769 .99625 m
.80769 1 L
s
.84615 .99625 m
.84615 1 L
s
.07692 .99625 m
.07692 1 L
s
.03846 .99625 m
.03846 1 L
s
.92308 .99625 m
.92308 1 L
s
.96154 .99625 m
.96154 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .21154 m
1 .21154 L
s
.99375 .40385 m
1 .40385 L
s
.99375 .59615 m
1 .59615 L
s
.99375 .78846 m
1 .78846 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .05769 m
1 .05769 L
s
.99625 .09615 m
1 .09615 L
s
.99625 .13462 m
1 .13462 L
s
.99625 .17308 m
1 .17308 L
s
.99625 .25 m
1 .25 L
s
.99625 .28846 m
1 .28846 L
s
.99625 .32692 m
1 .32692 L
s
.99625 .36538 m
1 .36538 L
s
.99625 .44231 m
1 .44231 L
s
.99625 .48077 m
1 .48077 L
s
.99625 .51923 m
1 .51923 L
s
.99625 .55769 m
1 .55769 L
s
.99625 .63462 m
1 .63462 L
s
.99625 .67308 m
1 .67308 L
s
.99625 .71154 m
1 .71154 L
s
.99625 .75 m
1 .75 L
s
.99625 .82692 m
1 .82692 L
s
.99625 .86538 m
1 .86538 L
s
.99625 .90385 m
1 .90385 L
s
.99625 .94231 m
1 .94231 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.6 g
.88265 .48983 m
.89076 .49019 L
.89189 .50981 L
.88265 .51779 L
.86579 .52943 L
.86303 .53158 L
.84341 .5415 L
.82607 .54906 L
.82378 .54943 L
.80416 .55684 L
.78454 .56484 L
.76491 .56808 L
.76209 .56868 L
.74529 .57208 L
.72567 .57135 L
.70604 .57366 L
.68642 .57463 L
.6668 .5742 L
.64717 .57238 L
.62755 .56942 L
.60793 .5697 L
.60332 .56868 L
.5883 .5674 L
.56868 .56001 L
.54906 .55177 L
.53938 .54906 L
.52943 .54489 L
.50981 .53814 L
.49963 .52943 L
.49019 .52324 L
.47341 .50981 L
.49019 .49041 L
.50981 .49384 L
.52943 .49797 L
.54906 .498 L
.56868 .50601 L
.5883 .50937 L
.59099 .50981 L
.60793 .51255 L
.62755 .51501 L
.64717 .51671 L
.6668 .51767 L
.68642 .51097 L
.70604 .51739 L
.72567 .51615 L
.74529 .51417 L
.76491 .51142 L
.77422 .50981 L
.78454 .50898 L
.80416 .50357 L
.82378 .50052 L
.84341 .49639 L
.86303 .49238 L
.87728 .49019 L
F
0 g
.88265 .48983 m
.89076 .49019 L
.89189 .50981 L
.88265 .51779 L
.86579 .52943 L
.86303 .53158 L
.84341 .5415 L
.82607 .54906 L
.82378 .54943 L
.80416 .55684 L
.78454 .56484 L
.76491 .56808 L
.76209 .56868 L
.74529 .57208 L
.72567 .57135 L
.70604 .57366 L
.68642 .57463 L
.6668 .5742 L
.64717 .57238 L
.62755 .56942 L
.60793 .5697 L
.60332 .56868 L
.5883 .5674 L
.56868 .56001 L
.54906 .55177 L
.53938 .54906 L
.52943 .54489 L
.50981 .53814 L
.49963 .52943 L
.49019 .52324 L
.47341 .50981 L
.49019 .49041 L
.50981 .49384 L
.52943 .49797 L
.54906 .498 L
.56868 .50601 L
.5883 .50937 L
.59099 .50981 L
.60793 .51255 L
.62755 .51501 L
.64717 .51671 L
.6668 .51767 L
.68642 .51097 L
.70604 .51739 L
.72567 .51615 L
.74529 .51417 L
.76491 .51142 L
.77422 .50981 L
.78454 .50898 L
.80416 .50357 L
Mistroke
.82378 .50052 L
.84341 .49639 L
.86303 .49238 L
.87728 .49019 L
.88265 .48983 L
Mfstroke
.4 g
.49019 .43966 m
.50981 .43973 L
.52943 .44207 L
.54906 .44683 L
.56868 .4483 L
.58548 .45094 L
.5883 .45142 L
.60793 .45402 L
.62755 .45603 L
.64717 .45281 L
.6668 .45538 L
.68642 .45592 L
.70604 .45468 L
.72567 .45698 L
.74529 .45534 L
.76491 .4531 L
.78011 .45094 L
.78454 .45027 L
.80416 .44708 L
.82378 .4431 L
.84341 .44106 L
.86303 .43925 L
.88265 .44184 L
.88655 .45094 L
.88265 .45529 L
.86343 .47057 L
.86303 .47105 L
.84341 .48043 L
.82378 .48851 L
.81929 .49019 L
.80416 .49544 L
.78454 .50535 L
.76491 .50464 L
.74529 .50801 L
.73208 .50981 L
.72567 .51051 L
.70604 .51209 L
.68642 .50986 L
.6668 .51244 L
.64717 .51123 L
.6331 .50981 L
.62755 .50906 L
.60793 .50602 L
.5883 .50211 L
.56868 .49886 L
.54906 .49088 L
.54616 .49019 L
.52943 .48362 L
.50981 .47475 L
.50219 .47057 L
.49019 .46186 L
.47877 .45094 L
F
0 g
.49019 .43966 m
.50981 .43973 L
.52943 .44207 L
.54906 .44683 L
.56868 .4483 L
.58548 .45094 L
.5883 .45142 L
.60793 .45402 L
.62755 .45603 L
.64717 .45281 L
.6668 .45538 L
.68642 .45592 L
.70604 .45468 L
.72567 .45698 L
.74529 .45534 L
.76491 .4531 L
.78011 .45094 L
.78454 .45027 L
.80416 .44708 L
.82378 .4431 L
.84341 .44106 L
.86303 .43925 L
.88265 .44184 L
.88655 .45094 L
.88265 .45529 L
.86343 .47057 L
.86303 .47105 L
.84341 .48043 L
.82378 .48851 L
.81929 .49019 L
.80416 .49544 L
.78454 .50535 L
.76491 .50464 L
.74529 .50801 L
.73208 .50981 L
.72567 .51051 L
.70604 .51209 L
.68642 .50986 L
.6668 .51244 L
.64717 .51123 L
.6331 .50981 L
.62755 .50906 L
.60793 .50602 L
.5883 .50211 L
.56868 .49886 L
.54906 .49088 L
.54616 .49019 L
.52943 .48362 L
.50981 .47475 L
.50219 .47057 L
Mistroke
.49019 .46186 L
.47877 .45094 L
.49019 .43966 L
Mfstroke
.4 g
.49019 .56472 m
.50981 .56274 L
.52943 .56594 L
.54338 .56868 L
.54906 .57006 L
.56868 .57462 L
.5883 .57857 L
.60793 .58177 L
.62755 .58029 L
.64717 .58424 L
.6668 .58606 L
.68642 .58646 L
.70604 .58555 L
.72567 .58306 L
.74529 .58337 L
.76491 .58064 L
.78454 .57715 L
.80416 .57295 L
.82135 .56868 L
.82378 .56797 L
.84341 .56458 L
.86303 .56214 L
.87671 .56868 L
.86303 .58424 L
.85814 .5883 L
.84341 .5982 L
.82532 .60793 L
.82378 .60868 L
.80416 .61979 L
.78454 .62479 L
.77541 .62755 L
.76491 .62968 L
.74529 .63427 L
.72567 .63803 L
.70604 .64043 L
.68642 .6414 L
.6668 .64097 L
.64717 .63911 L
.62755 .63584 L
.60793 .63144 L
.58999 .62755 L
.5883 .62706 L
.56868 .62512 L
.54906 .61257 L
.54008 .60793 L
.52943 .60244 L
.50981 .59021 L
.5073 .5883 L
.49019 .57152 L
.48846 .56868 L
F
0 g
.49019 .56472 m
.50981 .56274 L
.52943 .56594 L
.54338 .56868 L
.54906 .57006 L
.56868 .57462 L
.5883 .57857 L
.60793 .58177 L
.62755 .58029 L
.64717 .58424 L
.6668 .58606 L
.68642 .58646 L
.70604 .58555 L
.72567 .58306 L
.74529 .58337 L
.76491 .58064 L
.78454 .57715 L
.80416 .57295 L
.82135 .56868 L
.82378 .56797 L
.84341 .56458 L
.86303 .56214 L
.87671 .56868 L
.86303 .58424 L
.85814 .5883 L
.84341 .5982 L
.82532 .60793 L
.82378 .60868 L
.80416 .61979 L
.78454 .62479 L
.77541 .62755 L
.76491 .62968 L
.74529 .63427 L
.72567 .63803 L
.70604 .64043 L
.68642 .6414 L
.6668 .64097 L
.64717 .63911 L
.62755 .63584 L
.60793 .63144 L
.58999 .62755 L
.5883 .62706 L
.56868 .62512 L
.54906 .61257 L
.54008 .60793 L
.52943 .60244 L
.50981 .59021 L
.5073 .5883 L
.49019 .57152 L
.48846 .56868 L
Mistroke
.49019 .56472 L
Mfstroke
.6 g
.52943 .39703 m
.54906 .39747 L
.56868 .39895 L
.5883 .40069 L
.60793 .40459 L
.62755 .40384 L
.64717 .40495 L
.6668 .4056 L
.68642 .40576 L
.70604 .40541 L
.72567 .40457 L
.74529 .40946 L
.76491 .4012 L
.78454 .40002 L
.80416 .39833 L
.82378 .3971 L
.84341 .39761 L
.85509 .4117 L
.84341 .41922 L
.82378 .42934 L
.81935 .43132 L
.80416 .43613 L
.78454 .44125 L
.76491 .4455 L
.74529 .44892 L
.73052 .45094 L
.72567 .45141 L
.70604 .4522 L
.68642 .45291 L
.6668 .45258 L
.64717 .45143 L
.63457 .45094 L
.62755 .45 L
.60793 .4469 L
.5883 .44296 L
.56868 .43819 L
.54906 .43343 L
.54608 .43132 L
.52943 .4233 L
.51025 .4117 L
F
0 g
.52943 .39703 m
.54906 .39747 L
.56868 .39895 L
.5883 .40069 L
.60793 .40459 L
.62755 .40384 L
.64717 .40495 L
.6668 .4056 L
.68642 .40576 L
.70604 .40541 L
.72567 .40457 L
.74529 .40946 L
.76491 .4012 L
.78454 .40002 L
.80416 .39833 L
.82378 .3971 L
.84341 .39761 L
.85509 .4117 L
.84341 .41922 L
.82378 .42934 L
.81935 .43132 L
.80416 .43613 L
.78454 .44125 L
.76491 .4455 L
.74529 .44892 L
.73052 .45094 L
.72567 .45141 L
.70604 .4522 L
.68642 .45291 L
.6668 .45258 L
.64717 .45143 L
.63457 .45094 L
.62755 .45 L
.60793 .4469 L
.5883 .44296 L
.56868 .43819 L
.54906 .43343 L
.54608 .43132 L
.52943 .4233 L
.51025 .4117 L
.52943 .39703 L
s
.7 g
.54906 .51702 m
.56868 .51674 L
.5883 .51819 L
.60793 .51988 L
.62755 .52138 L
.64717 .52252 L
.6668 .52319 L
.68642 .51651 L
.70604 .52299 L
.72567 .52214 L
.74529 .52085 L
.76491 .51924 L
.78454 .51757 L
.80416 .51646 L
.82378 .51939 L
.8244 .52943 L
.82378 .52998 L
.80416 .54255 L
.79048 .54906 L
.78454 .55283 L
.76491 .55775 L
.74529 .56242 L
.72567 .56573 L
.70604 .5678 L
.68642 .56864 L
.6668 .56826 L
.64717 .56666 L
.62755 .56383 L
.60793 .5597 L
.5883 .5586 L
.57489 .54906 L
.56868 .54624 L
.54906 .53553 L
.54093 .52943 L
F
0 g
.54906 .51702 m
.56868 .51674 L
.5883 .51819 L
.60793 .51988 L
.62755 .52138 L
.64717 .52252 L
.6668 .52319 L
.68642 .51651 L
.70604 .52299 L
.72567 .52214 L
.74529 .52085 L
.76491 .51924 L
.78454 .51757 L
.80416 .51646 L
.82378 .51939 L
.8244 .52943 L
.82378 .52998 L
.80416 .54255 L
.79048 .54906 L
.78454 .55283 L
.76491 .55775 L
.74529 .56242 L
.72567 .56573 L
.70604 .5678 L
.68642 .56864 L
.6668 .56826 L
.64717 .56666 L
.62755 .56383 L
.60793 .5597 L
.5883 .5586 L
.57489 .54906 L
.56868 .54624 L
.54906 .53553 L
.54093 .52943 L
.54906 .51702 L
s
.3 g
.54906 .46084 m
.56868 .4591 L
.5883 .4597 L
.60793 .4608 L
.62755 .46191 L
.64717 .45592 L
.6668 .45908 L
.68642 .45968 L
.70604 .45827 L
.72567 .46249 L
.74529 .46151 L
.76491 .46036 L
.78454 .45936 L
.80416 .45927 L
.82378 .465 L
.82431 .47057 L
.82378 .47106 L
.80416 .48368 L
.79023 .49019 L
.78454 .49436 L
.76491 .49772 L
.74529 .50187 L
.72567 .50485 L
.70604 .50672 L
.68642 .50748 L
.6668 .50714 L
.64717 .50569 L
.62755 .50314 L
.60793 .49945 L
.5883 .49447 L
.57514 .49019 L
.56868 .48733 L
.54906 .4767 L
.54104 .47057 L
F
0 g
.54906 .46084 m
.56868 .4591 L
.5883 .4597 L
.60793 .4608 L
.62755 .46191 L
.64717 .45592 L
.6668 .45908 L
.68642 .45968 L
.70604 .45827 L
.72567 .46249 L
.74529 .46151 L
.76491 .46036 L
.78454 .45936 L
.80416 .45927 L
.82378 .465 L
.82431 .47057 L
.82378 .47106 L
.80416 .48368 L
.79023 .49019 L
.78454 .49436 L
.76491 .49772 L
.74529 .50187 L
.72567 .50485 L
.70604 .50672 L
.68642 .50748 L
.6668 .50714 L
.64717 .50569 L
.62755 .50314 L
.60793 .49945 L
.5883 .49447 L
.57514 .49019 L
.56868 .48733 L
.54906 .4767 L
.54104 .47057 L
.54906 .46084 L
s
.4 g
.56868 .36221 m
.5883 .36029 L
.60793 .36007 L
.62755 .36033 L
.64717 .36068 L
.6668 .36092 L
.68642 .36098 L
.70604 .36085 L
.72567 .36055 L
.74529 .36021 L
.76491 .36007 L
.78454 .36068 L
.80416 .36456 L
.80763 .37245 L
.80416 .37431 L
.78454 .38254 L
.76491 .38877 L
.75146 .39207 L
.74529 .39465 L
.72567 .39524 L
.70604 .39663 L
.68642 .39719 L
.6668 .39694 L
.64717 .39586 L
.62755 .39394 L
.61389 .39207 L
.60793 .39069 L
.5883 .38511 L
.56868 .37776 L
.55775 .37245 L
F
0 g
.56868 .36221 m
.5883 .36029 L
.60793 .36007 L
.62755 .36033 L
.64717 .36068 L
.6668 .36092 L
.68642 .36098 L
.70604 .36085 L
.72567 .36055 L
.74529 .36021 L
.76491 .36007 L
.78454 .36068 L
.80416 .36456 L
.80763 .37245 L
.80416 .37431 L
.78454 .38254 L
.76491 .38877 L
.75146 .39207 L
.74529 .39465 L
.72567 .39524 L
.70604 .39663 L
.68642 .39719 L
.6668 .39694 L
.64717 .39586 L
.62755 .39394 L
.61389 .39207 L
.60793 .39069 L
.5883 .38511 L
.56868 .37776 L
.55775 .37245 L
.56868 .36221 L
s
.7 g
.5883 .41568 m
.60793 .41376 L
.62755 .41355 L
.64717 .41372 L
.6668 .4139 L
.68642 .41395 L
.70604 .41384 L
.72567 .41364 L
.74529 .41355 L
.76491 .41413 L
.7793 .43132 L
.76491 .43609 L
.74529 .4409 L
.72567 .4443 L
.70604 .44641 L
.68642 .44727 L
.6668 .44688 L
.64717 .44525 L
.62755 .44235 L
.60793 .43811 L
.5883 .43215 L
.58611 .43132 L
F
0 g
.5883 .41568 m
.60793 .41376 L
.62755 .41355 L
.64717 .41372 L
.6668 .4139 L
.68642 .41395 L
.70604 .41384 L
.72567 .41364 L
.74529 .41355 L
.76491 .41413 L
.7793 .43132 L
.76491 .43609 L
.74529 .4409 L
.72567 .4443 L
.70604 .44641 L
.68642 .44727 L
.6668 .44688 L
.64717 .44525 L
.62755 .44235 L
.60793 .43811 L
.5883 .43215 L
.58611 .43132 L
.5883 .41568 L
s
.2 g
.60793 .46873 m
.62755 .46845 L
.64717 .46568 L
.6668 .467 L
.68642 .46726 L
.70604 .46666 L
.72567 .46853 L
.74529 .46847 L
.76491 .46916 L
.77669 .47057 L
.76491 .48876 L
.76192 .49019 L
.74529 .49483 L
.72567 .49857 L
.70604 .50083 L
.68642 .50174 L
.6668 .50133 L
.64717 .49959 L
.62755 .49644 L
.60793 .49159 L
.60348 .49019 L
.58922 .47057 L
F
0 g
.60793 .46873 m
.62755 .46845 L
.64717 .46568 L
.6668 .467 L
.68642 .46726 L
.70604 .46666 L
.72567 .46853 L
.74529 .46847 L
.76491 .46916 L
.77669 .47057 L
.76491 .48876 L
.76192 .49019 L
.74529 .49483 L
.72567 .49857 L
.70604 .50083 L
.68642 .50174 L
.6668 .50133 L
.64717 .49959 L
.62755 .49644 L
.60793 .49159 L
.60348 .49019 L
.58922 .47057 L
.60793 .46873 L
s
.8 g
.62755 .52921 m
.64717 .5294 L
.64865 .52943 L
.6668 .52969 L
.68642 .52977 L
.70604 .52959 L
.7157 .52943 L
.72567 .52931 L
.74529 .52924 L
.75333 .52943 L
.75279 .54906 L
.74529 .55142 L
.72567 .55596 L
.70604 .55861 L
.68642 .55966 L
.6668 .55919 L
.64717 .55716 L
.62755 .5534 L
.61257 .54906 L
.61198 .52943 L
F
0 g
.62755 .52921 m
.64717 .5294 L
.64865 .52943 L
.6668 .52969 L
.68642 .52977 L
.70604 .52959 L
.7157 .52943 L
.72567 .52931 L
.74529 .52924 L
.75333 .52943 L
.75279 .54906 L
.74529 .55142 L
.72567 .55596 L
.70604 .55861 L
.68642 .55966 L
.6668 .55919 L
.64717 .55716 L
.62755 .5534 L
.61257 .54906 L
.61198 .52943 L
.62755 .52921 L
s
.8 g
.64717 .42597 m
.6668 .42435 L
.68642 .42407 L
.70604 .42473 L
.72567 .42762 L
.7306 .43132 L
.72567 .43289 L
.70604 .43676 L
.68642 .43814 L
.6668 .43753 L
.64717 .43474 L
.63439 .43132 L
F
0 g
.64717 .42597 m
.6668 .42435 L
.68642 .42407 L
.70604 .42473 L
.72567 .42762 L
.7306 .43132 L
.72567 .43289 L
.70604 .43676 L
.68642 .43814 L
.6668 .43753 L
.64717 .43474 L
.63439 .43132 L
.64717 .42597 L
s
.1 g
.64717 .47845 m
.6668 .47714 L
.68642 .47693 L
.70604 .47744 L
.72491 .49019 L
.70604 .49327 L
.68642 .49453 L
.6668 .49397 L
.64717 .49146 L
.64056 .49019 L
F
0 g
.64717 .47845 m
.6668 .47714 L
.68642 .47693 L
.70604 .47744 L
.72491 .49019 L
.70604 .49327 L
.68642 .49453 L
.6668 .49397 L
.64717 .49146 L
.64056 .49019 L
.64717 .47845 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00?Oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0dooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kS?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0hooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8b
onk^kS?ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08_ooool003gooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0=_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0<oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg03?ooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL08_ooool003Gooooo1_l0
0003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400[ooooo`Ko0000
1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100<oooool01Ol@413o
oooooooooooooooo410@03[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@03Cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@02;ooooo000o
ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000fooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000cooooo`05o`000?ooooooooooooooool0
0000>_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000=Oooool00onH
V9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000008_ooool0043ooooo00?oMgMgofIV
I_ooool00_ooool01Ol0003ooooooooooooooooo000003Kooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000003?ooooo00Go0000ooooooooooooooooo`00000jooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`03ogMgMomVIVKooooo00;o
oooo00Go0000ooooooooooooooooo`00000Rooooo`00@Oooool01Ol0003ooooooooooooooooo410@
00?ooooo00?o410@ooooooooool0=?ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@4100<oooool01Ol@413ooooooooooooooooo410@03[ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@03Oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo023ooooo000mooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg03Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg03?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0jooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0cooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02;ooooo000mooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^03Cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^03?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`03oeEEEOmVIVKo000000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0cooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02;ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo000Joooooooo0000C_l00001ooooo`00
6_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0?Ooo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool08ooo
ool1o`00007ooooo0008ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKo
oooo00?o0000ooooooooool0oooooom:ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooom:ooooo`7o
00000Oooool000Go00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41001_ooool00ol0003oooooooooo`3ooooood[ooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?ooooooB?ooool3o`00007o
oooo000:ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo0008ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Oooooooogmo
Od3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Ooo
ooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000oooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`003ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000?ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000oooooo00Go0000oooooooooooooooo
o`000006ooooo`?o00001?ooooooogmoOd3oOgmo1?ooool3o`00007ooooo000?ooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool000oooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`003oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000?ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04oooook[oOgmo8Ol00006ogmoOb3o0000?_moOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?ooooneogmoO`Go00008OmVIVH6o`00023oIVIV0ol0000kogmoO`Kooooo0Ol0
0001ooooo`006_ooool2o`0000Gooooo]?moOgl00ol0003oIVIVofIVIP1=ofIVIP03o`000?moOgoo
Ogmo03SoOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo/omoOgl00ol0
003oIVIVofIVIP1>ofIVIP03o`000?moOgooOgmo03SoOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00Cooooo/_moOgl2o`00057oIVIV00?o0000ogmoOomoOgl0=omoOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?oooondogmoO`;o0000COmVIVH2o`0003[oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo]_moOgl2o`0004WoIVIV0_l0
000logmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooookSoOgmo0ol00014
ofIVIP;o0000?_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonkogmo
O`;o0000?omVIVH3o`00043oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooo_OmoOgl4o`0003SoIVIV0ol00013ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04oooool7oOgmo1?l0000`ofIVIPCo0000A_moOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?ooooo5ogmoO`Wo00009?mVIVH3o`0004[oOgmo1_ooool1o`00007ooooo0008
ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo00?o0000oooooooo
ool01?oooonXogmoO`Ko00008?moOgl=o`0000KoIVIV4Ol0001=ogmoO`Kooooo0Ol00001ooooo`00
2_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003o
ooooooooo`04ooooojOoOgmo00?o0000oiVIVOnIVIT01?nIVIT=o`00023oOgmo1_l0000JogmoOaOo
0000;OmoOgl6ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooo
oooooooooooo410@00Kooooo00?o0000ooooooooool01?oooonVogmoO`03o`000?nIVIWoVIVI01;o
VIVI1_l0000eogmoO`Go00005onIVIT00ol0003oOgmoogmoO`0ZogmoO`Kooooo0Ol00001ooooo`00
2_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool3o`0000Co
ooooYOmoOgl00ol0003oVIVIoiVIV@0IoiVIVBco00001omoOgl2o`0001goVIVI00?o0000ogmoOomo
Ogl0:OmoOgl4ooooo`?o00000Oooool000[ooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool01?oooonTogmoO`03o`000?nIVIWoVIVI04Ko
VIVI0ol00002ogmoO`;o00008?nIVIT00ol0003oOgmoogmoO`0XogmoO`Kooooo0Ol00001ooooo`00
2_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003o
ooooooooo`04oooooj?oOgmo0_l0001;oiVIV@;o00008_nIVIT2o`0002WoOgmo1_ooool1o`00007o
oooo000:ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03
o`000?oooooooooo00CoooooYOmoOgl00ol0003oVIVIoiVIV@0HoiVIVCSo00006onIVIT00ol0003o
OgmoogmoO`0YogmoO`Kooooo0Ol00001ooooo`002?ooool00omEEEGoIVIVo`000004ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`04ooooojKoOgmo0_l0000EoiVIV@?o
0000=onc/k<00ol0003oVIVIoiVIV@0HoiVIV@03o`000?moOgooOgmo02[oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CoooooZ?moOgl00ol0003oVIVIoiVIV@0BoiVIV@03o`00
0?nc/k?o/k>c03So/k>c00?o0000oiVIVOnIVIT05OnIVIT2o`0002goOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CoooooZOmoOgl2o`0001;oVIVI00?o0000ok>c/onc/k<06_nc
/k<8o`0001Oo/k>c00?o0000oiVIVOnIVIT04_nIVIT2o`0002ooOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CoooooZomoOgl2o`0000ooVIVI00?o0000ok>c/onc/k<04?nc/k<;
o`0000Soc<c<1_l0000Bok>c/`03o`000?nIVIWoVIVI00ooVIVI0_l0000aogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooojgoOgmo0_l0000=oiVIV@03o`000?nc/k?o/k>c
00ko/k>c0_l0000Iolc<c0Co00003onc/k<00ol0003oVIVIoiVIV@0<oiVIV@;o0000<omoOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon_ogmoO`03o`000?nIVIWoVIVI00[o
VIVI1?l0000<ok>c/`?o00006_o<c<`4o`0000go/k>c0ol0000:oiVIV@?o0000=OmoOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?oooon`ogmoO`Co00003?nIVIT3o`0000co/k>c
1_l0000Aolc<c0?o00003Onc/k<4o`0000WoVIVI1?l0000hogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04oooookCoOgmo1Ol0000:oiVIV@?o00003onc/k<Ao`0000go/k>c0ol0
000:oiVIV@?o0000??moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonK
ogmoOa7o00003OmoOgl3o`0000[oVIVI0ol0000Uok>c/`Go00002OnIVIT4o`0000koOgmo4Ol0000P
ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000GoooooV_moOgl00ol0003oIVIVofIVIP0?ofIV
IP?o00003OmoOgl5o`0000SoVIVI1Ol0000Iok>c/`Oo00002onIVIT3o`0000coOgmo1_l0000@ofIV
IP03o`000?moOgooOgmo01koOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
ooooVOmoOgl00ol0003oIVIVofIVIP0CofIVIPGo00003OmoOgl7o`0000KoVIVI6Ol0000=oiVIV@Go
00002?moOgl7o`0001OoIVIV00?o0000ogmoOomoOgl07OmoOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?oooonHogmoO`03o`000?mVIVKoIVIV01WoIVIV2Ol0000;ogmoO`Oo0000
7?nIVIT9o`0000KoOgmo1ol0000OofIVIP03o`000?moOgooOgmo01coOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CoooooVOmoOgl00ol0003oIVIVofIVIP0QofIVIP_o00001Omo
OglNo`0000WoOgmo1_l0000UofIVIP03o`000?moOgooOgmo01goOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CoooooV_moOgl00ol0003oIVIVofIVIP0[ofIVIPGo00000_mVIVHU
o`0002WoIVIV0_l0000PogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
oi_oOgmo00?o0000ofIVI_mVIVH05OmVIVH>o`0000_oIVIV0ol00006oda<C1?o00004omVIVH<o`00
01GoIVIV00?o0000ogmoOomoOgl08?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?oooonLogmoO`;o00004_mVIVH3o`0000koC4a<2ol0000Loda<C1?o00003?m<C4`3o`00017o
IVIV00?o0000ogmoOomoOgl08OmoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?oooonNogmoO`03o`000?mVIVKoIVIV00koIVIV00?o0000oda<C?m<C4`06om<C4`8o`0003GoC4a<
0_l0000>ofIVIP03o`000?moOgooOgmo02;oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CoooooWomoOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<00ooC4a<3Ol0
0008oc<c<bGo00004Om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo02?oOgmo1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooX?moOgl3o`0000[oIVIV0_l0000>
oda<C0?o0000>_lc<c<2o`0000koC4a<0_l0000;ofIVIP;o00009_moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?oooonSogmoO`;o00002_mVIVH00ol0003oC4a<oda<C00;oda<
C003o`000?lc<c?o<c<c03_o<c<c00?o0000oda<C?m<C4`02_m<C4`2o`0000[oIVIV0ol0000Xogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooojGoOgmo0_l00009ofIVIP;o
00003?m<C4`00ol0003o<c<coc<c<`0Coc<c<a;o00005?lc<c<00ol0003oC4a<oda<C00:oda<C003
o`000?mVIVKoIVIV00SoIVIV0_l0000[ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000Gooooo
YomoOgl2o`0000WoIVIV0_l0000;oda<C003o`000?lc<c?o<c<c00ko<c<c1?l0000BoaTI6@03o`00
0?lc<c?o<c<c013o<c<c00?o0000oda<C?m<C4`02Om<C4`2o`0000WoIVIV0_l0000]ogmoO`Gooooo
0_l00001ooooo`006_ooool00ol0003oooooooooo`04ooooojWoOgmo0ol00008ofIVIP;o00002_m<
C4`00ol0003o<c<coc<c<`0=oc<c<`03o`000?lI6AWo6ATI01Co6ATI0_l0000@oc<c<`03o`000?m<
C4coC4a<00OoC4a<0_l00009ofIVIP;o0000;omoOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?oooon/ogmoO`?o00001omVIVH2o`0000WoC4a<00?o0000oc<c<olc<c<02olc<c<0
0ol0003o6ATIoaTI6@0GoaTI6@03o`000?lc<c?o<c<c00co<c<c00?o0000oda<C?m<C4`01_m<C4`2
o`0000WoIVIV0_l0000aogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
ojooOgmo00?o0000ofIVI_mVIVH01_mVIVH2o`0000SoC4a<00?o0000oc<c<olc<c<02Olc<c<2o`00
01Oo6ATI1?l0000:oc<c<`?o00002?m<C4`00ol0003oIVIVofIVIP05ofIVIPCo00003omoOgl7o`00
01goOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooW?moOgl5o`0000oo
Ogmo0ol00007ofIVIP?o00001_m<C4`3o`0000[o<c<c1Ol0000<oaTI6@Ko00002olc<c<3o`0000[o
C4a<00?o0000ofIVI_mVIVH00omVIVH3o`0000koOgmo1Ol00006oiVIV@03o`000?moOgooOgmo01_o
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooVomoOgl00ol0003oVIVI
oiVIV@03oiVIV@Ko00003?moOgl3o`0000OoIVIV0ol00006oda<C0?o00003?lc<c<<o`0000go<c<c
1?l00009oda<C0Co00001?mVIVH2o`0000koOgmo0ol0000;oiVIV@03o`000?moOgooOgmo01_oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooV_moOgl00ol0003oVIVIoiVI
V@0:oiVIV@_o00001?moOgl5o`0000GoIVIV0ol00006oda<C0Go00006Olc<c<7o`0000KoC4a<1ol0
0006ofIVIP;o00002omoOgl5o`0000koVIVI00?o0000ogmoOomoOgl06omoOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?oooonIogmoO`03o`000?nIVIWoVIVI01KoVIVI0_l00007
ogmoO`Go00000omVIVH5o`0000KoC4a<6Ol00007oda<C0Ko00002omVIVH2o`0000OoOgmo1_l0000C
oiVIV@03o`000?moOgooOgmo01_oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CoooooV?moOgl00ol0003oVIVIoiVIV@0IoiVIV@;o00002_moOgl3o`0000GoIVIV1_l0000Ioda<
C0Oo00001_mVIVH;o`0000CoOgmo1Ol0000IoiVIV@03o`000?moOgooOgmo01_oOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CoooooUomoOgl00ol0003oVIVIoiVIV@0LoiVIV@Go
00002?moOgl5o`0000KoIVIV6Ol00008ofIVIPGo00003?moOgl3o`0001koVIVI00?o0000ogmoOomo
Ogl06omoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonFogmoO`;o0000
8onIVIT6o`0000OoOgmo3Ol00005ofIVIPSo00001OmVIVH8o`0000GoOgmo3?l0000QoiVIV@03o`00
0?moOgooOgmo01_oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooV?mo
Ogl00ol0003oVIVIoiVIV@0VoiVIV@Oo00003OmoOgl7o`0000CoVIVI1ol00007ogmoO`Ko0000;?nI
VIT00ol0003oOgmoogmoO`0LogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
oooooiWoOgmo0_l0000EoiVIV@_o00003OnIVIT=o`0000?oOgmo0_l00002oiVIV@Co00000onIVIT;
o`0001?oVIVI2?l0000FoiVIV@03o`000?moOgooOgmo01goOgmo1_ooool1o`00007ooooo000Joooo
o`;o00001OoooonKogmoO`03o`000?nIVIWoVIVI01;oVIVI00?o0000ok>c/onc/k<02?nc/k<=o`00
00goVIVI0ol000001?nIVIWo0000o`000?l00004ok>c/`?o00004OnIVIT=o`0000So/k>c0ol0000A
oiVIV@;o00008?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool01?oooonLogmo
O`;o00004OnIVIT00ol0003o/k>cok>c/`0Fok>c/a7o00002_nc/k<Ao`0001Oo/k>c00?o0000oiVI
VOnIVIT03OnIVIT2o`0002;oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
ooooW_moOgl00ol0003oVIVIoiVIV@0=oiVIV@03o`000?nc/k?o/k>c05[o/k>c00?o0000oiVIVOnI
VIT03?nIVIT00ol0003oOgmoogmoO`0RogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04oooooiooOgmo0_l0000<oiVIV@03o`000?nc/k?o/k>c01Co/k>c4Ol0000Aok>c/`ko0000
5onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo02?oOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CoooooXOmoOgl00ol0003oVIVIoiVIV@0:oiVIV@03o`000?nc
/k?o/k>c01?o/k>c00?o0000olc<c?o<c<`03_o<c<`Ao`0000goc<c<00?o0000ok>c/onc/k<05?nc
/k<2o`0000_oVIVI0_l0000VogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
oooooj;oOgmo00?o0000oiVIVOnIVIT02_nIVIT00ol0003o/k>cok>c/`0Bok>c/`03o`000?o<c<co
c<c<02coc<c<00?o0000ok>c/onc/k<04_nc/k<2o`0000[oVIVI0ol0000XogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04oooooj?oOgmo0_l0000;oiVIV@;o00004_nc/k<00ol0
003oc<c<olc<c00/olc<c003o`000?nc/k?o/k>c017o/k>c00?o0000oiVIVOnIVIT02?nIVIT2o`00
02_oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooYOmoOgl2o`0000_o
VIVI0_l0000Aok>c/`03o`000?o<c<coc<c<02_oc<c<00?o0000ok>c/onc/k<03onc/k<2o`0000Wo
VIVI0_l0000]ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooojOoOgmo
0_l0000;oiVIV@;o00003onc/k<00ol0003oc<c<olc<c00[olc<c003o`000?nc/k?o/k>c00go/k>c
0_l00009oiVIV@;o0000;omoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
oonYogmoO`?o00002_nIVIT2o`0000go/k>c00?o0000olc<c?o<c<`0:oo<c<`00ol0003o/k>cok>c
/`0;ok>c/`;o00002_nIVIT00ol0003oOgmoogmoO`0_ogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooojcoOgmo0ol00009oiVIV@;o00002onc/k<4o`0002Woc<c<0_l0000;
ok>c/`;o00002OnIVIT3o`0003;oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00Cooooo[omoOgl3o`0000SoVIVI0_l0000=ok>c/`Co00008Oo<c<`4o`0000[o/k>c0ol00008oiVI
V@?o0000=OmoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonbogmoO`;o
00002?nIVIT00ol0003o/k>cok>c/`0>ok>c/`?o00005oo<c<`7o`0000_o/k>c0ol00009oiVIV@;o
0000>?moOgl6ooooo`7o00000Oooool001[ooooo0_l00005oooookCoOgmo0_l00007oiVIV@Co0000
3onc/k<;o`0000Koc<c<1_l0000=ok>c/`Go00002_nIVIT2o`0003[oOgmo1Oooool2o`00007ooooo
000Jooooo`03o`000?oooooooooo00Cooooo]_moOgl3o`0000SoVIVI1ol0000Cok>c/`Ko00003_nc
/k<5o`0000coVIVI0ol0000BogmoO`Go00009OmoOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?oooonLogmoO`_o00004_moOgl3o`0000coVIVI1_l0000Nok>c/`?o00003?nIVIT5
o`0000koOgmo1ol00005ofIVIP03o`000?moOgooOgmo02;oOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CoooooW?moOgl00ol0003oIVIVofIVIP08ofIVIPKo00003omoOgl5o`00
00goVIVI3Ol00006ok>c/`_o00002onIVIT4o`00013oOgmo0ol0000=ofIVIP03o`000?moOgooOgmo
027oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooVomoOgl2o`00013o
IVIV1ol0000=ogmoO`go00003OnIVIT6o`0000KoVIVI2?l00005oiVIV@?o00004?moOgl4o`00017o
IVIV00?o0000ogmoOomoOgl08?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?oooonMogmoO`03o`000?mVIVKoIVIV01CoIVIV1Ol0000EogmoOaWo00002?moOgl5o`0000goOgmo
1_l0000EofIVIP03o`000?moOgooOgmo023oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CoooooW_moOgl00ol0003oIVIVofIVIP0HofIVIP?o0000?omoOgl6o`0001[oIVIV00?o
0000ogmoOomoOgl08OmoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonO
ogmoO`03o`000?mVIVKoIVIV01[oIVIV1Ol00006ogmoO`Ko00009omoOgl7o`0001ooIVIV00?o0000
ogmoOomoOgl08_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonPogmo
O`03o`000?mVIVKoIVIV01koIVIV1_l00006ofIVIP?o00005omoOgl=o`0002GoIVIV00?o0000ogmo
OomoOgl08omoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonQogmoO`03
o`000?mVIVKoIVIV02coIVIV5ol0000`ofIVIP;o00009_moOgl6ooooo`7o00000Oooool000Oooooo
1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`04oooooj;o
Ogmo00?o0000ofIVI_mVIVH0L?mVIVH2o`0002SoOgmo1_ooool1o`00007ooooo0007ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000oooo
ooooool01?oooonSogmoO`;o0000K_mVIVH2o`0002[oOgmo1_ooool1o`00007ooooo0008ooooo`03
oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo
00CoooooYOmoOgl00ol0003oIVIVofIVIP1ZofIVIP03o`000?moOgooOgmo02[oOgmo1_ooool1o`00
007ooooo0009ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000006oooo
o`?o00001?oooonVogmoO`;o0000J?mVIVH2o`0002goOgmo1?ooool3o`00007ooooo000:ooooo`03
ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo
00CoooooZ?moOgl00ol0003oIVIVofIVIP1TofIVIP03o`000?moOgooOgmo02goOgmo1_ooool1o`00
007ooooo000;ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`04oooo
o`03o`000?oooooooooo00CoooooZOmoOgl2o`0006;oIVIV0_l0000`ogmoO`Kooooo0Ol00001oooo
o`001oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06
ooooo`03o`000?oooooooooo00CoooooZomoOgl2o`0005ooIVIV00?o0000ogmoOomoOgl0<?moOgl6
ooooo`7o00000Oooool000Oooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`04ooooojgoOgmo0ol0001JofIVIP;o0000<omo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon`ogmoO`;o0000EOmVIVH3
o`0003GoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo/_moOgl00ol0
003oIVIVofIVIP1@ofIVIP;o0000>?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooncogmoO`;o0000C_mVIVH2o`0003[oOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00Cooooo]OmoOgl00ol0003oIVIVofIVIP18ofIVIP?o0000??moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?oooonfogmoO`Go0000@_mVIVH3o`0003ooOgmo1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo^omoOgl6o`0003SoIVIV1?l00012
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooool7oOgmo1Ol0000^ofIV
IPGo0000A_moOgl6ooooo`7o00000Oooool001[ooooo0_l00005ooooolKoOgmo0ol0000VofIVIPGo
0000BomoOgl5ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool01?ooooo9ogmoO`Go0000
7_mVIVH3o`00053oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Coooooc_mo
Ogl7o`0000coIVIV2ol0001CogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooomGoOgmo3?l0001NogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
ooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3o
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooooomo
Ogm0ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001
ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooo
ogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo
0_l00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooooomo
Ogm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000GooooooomoOgm0ogmo
O`Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo
@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001
ooooo`001oooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`001oooool0
1Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`00
0?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002oooool01Ol0003ooooooooo
oooooooo410@00?ooooo00?o410@ooooooooool01?ooool00ol0003oooooooooo`04ooooooooOgmo
@?moOgl6ooooo`7o00000Oooool000[ooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooo
oooooooo000000Kooooo0ol00004ooooooooOgmo@?moOgl4ooooo`?o00000Oooool000Wooooo00?o
410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0
1?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000:ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go
410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo
0Ol00001ooooo`001oooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`00
1oooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06oooo
o`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooooomo
Ogm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo0_l0
0005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool01?oooooo
ogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo
@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[o
oooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool0
1?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooooomo
Ogm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
ooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3o
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Ooo
ool001[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000oooo
ooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo
@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooo
ogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool001[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o
0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
ooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3o
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000Wooooo0_l000002Ol@413ooooo
ooooooooooook^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
00Oooooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@41001_ooool3o`0000CooooooomoOgm0
ogmoO`Cooooo0ol00001ooooo`001oooool01?m4A4CogMgMooooool00004ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`3ooooood[ooooo0Ol00001ooooo`001oooool0
1?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooo
ooooo`3ooooood[ooooo0Ol00001ooooo`002?ooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oo
ooooooooooooool@41001_ooool00ol0003oooooooooo`3ooooood[ooooo0Ol00001ooooo`002?oo
ool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003ooooo
ooooo`3ooooood[ooooo0Ol00001ooooo`002Oooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03gooooo
00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03gooooo
00?o0000ooooooooool08oooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02Oooool1o`00007ooooo000Joooooooo0000C_l00001ooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-30.1723, -14.304, 0.195672, \
0.195672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0192308 0.211538 0.0192308 [
[.11538 -0.0125 -9 -9 ]
[.11538 -0.0125 9 0 ]
[.30769 -0.0125 -9 -9 ]
[.30769 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69231 -0.0125 -6 -9 ]
[.69231 -0.0125 6 0 ]
[.88462 -0.0125 -6 -9 ]
[.88462 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -18 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .21154 -6 -4.5 ]
[-0.0125 .21154 0 4.5 ]
[-0.0125 .40385 -12 -4.5 ]
[-0.0125 .40385 0 4.5 ]
[-0.0125 .59615 -12 -4.5 ]
[-0.0125 .59615 0 4.5 ]
[-0.0125 .78846 -12 -4.5 ]
[-0.0125 .78846 0 4.5 ]
[-0.0125 .98077 -12 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11538 0 m
.11538 .00625 L
s
[(-20)] .11538 -0.0125 0 1 Mshowa
.30769 0 m
.30769 .00625 L
s
[(-10)] .30769 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69231 0 m
.69231 .00625 L
s
[(10)] .69231 -0.0125 0 1 Mshowa
.88462 0 m
.88462 .00625 L
s
[(20)] .88462 -0.0125 0 1 Mshowa
.125 Mabswid
.15385 0 m
.15385 .00375 L
s
.19231 0 m
.19231 .00375 L
s
.23077 0 m
.23077 .00375 L
s
.26923 0 m
.26923 .00375 L
s
.34615 0 m
.34615 .00375 L
s
.38462 0 m
.38462 .00375 L
s
.42308 0 m
.42308 .00375 L
s
.46154 0 m
.46154 .00375 L
s
.53846 0 m
.53846 .00375 L
s
.57692 0 m
.57692 .00375 L
s
.61538 0 m
.61538 .00375 L
s
.65385 0 m
.65385 .00375 L
s
.73077 0 m
.73077 .00375 L
s
.76923 0 m
.76923 .00375 L
s
.80769 0 m
.80769 .00375 L
s
.84615 0 m
.84615 .00375 L
s
.07692 0 m
.07692 .00375 L
s
.03846 0 m
.03846 .00375 L
s
.92308 0 m
.92308 .00375 L
s
.96154 0 m
.96154 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(-10)] -0.0125 .01923 1 0 Mshowa
0 .21154 m
.00625 .21154 L
s
[(0)] -0.0125 .21154 1 0 Mshowa
0 .40385 m
.00625 .40385 L
s
[(10)] -0.0125 .40385 1 0 Mshowa
0 .59615 m
.00625 .59615 L
s
[(20)] -0.0125 .59615 1 0 Mshowa
0 .78846 m
.00625 .78846 L
s
[(30)] -0.0125 .78846 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(40)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .05769 m
.00375 .05769 L
s
0 .09615 m
.00375 .09615 L
s
0 .13462 m
.00375 .13462 L
s
0 .17308 m
.00375 .17308 L
s
0 .25 m
.00375 .25 L
s
0 .28846 m
.00375 .28846 L
s
0 .32692 m
.00375 .32692 L
s
0 .36538 m
.00375 .36538 L
s
0 .44231 m
.00375 .44231 L
s
0 .48077 m
.00375 .48077 L
s
0 .51923 m
.00375 .51923 L
s
0 .55769 m
.00375 .55769 L
s
0 .63462 m
.00375 .63462 L
s
0 .67308 m
.00375 .67308 L
s
0 .71154 m
.00375 .71154 L
s
0 .75 m
.00375 .75 L
s
0 .82692 m
.00375 .82692 L
s
0 .86538 m
.00375 .86538 L
s
0 .90385 m
.00375 .90385 L
s
0 .94231 m
.00375 .94231 L
s
.25 Mabswid
0 0 m
0 1 L
s
.11538 .99375 m
.11538 1 L
s
.30769 .99375 m
.30769 1 L
s
.5 .99375 m
.5 1 L
s
.69231 .99375 m
.69231 1 L
s
.88462 .99375 m
.88462 1 L
s
.125 Mabswid
.15385 .99625 m
.15385 1 L
s
.19231 .99625 m
.19231 1 L
s
.23077 .99625 m
.23077 1 L
s
.26923 .99625 m
.26923 1 L
s
.34615 .99625 m
.34615 1 L
s
.38462 .99625 m
.38462 1 L
s
.42308 .99625 m
.42308 1 L
s
.46154 .99625 m
.46154 1 L
s
.53846 .99625 m
.53846 1 L
s
.57692 .99625 m
.57692 1 L
s
.61538 .99625 m
.61538 1 L
s
.65385 .99625 m
.65385 1 L
s
.73077 .99625 m
.73077 1 L
s
.76923 .99625 m
.76923 1 L
s
.80769 .99625 m
.80769 1 L
s
.84615 .99625 m
.84615 1 L
s
.07692 .99625 m
.07692 1 L
s
.03846 .99625 m
.03846 1 L
s
.92308 .99625 m
.92308 1 L
s
.96154 .99625 m
.96154 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .21154 m
1 .21154 L
s
.99375 .40385 m
1 .40385 L
s
.99375 .59615 m
1 .59615 L
s
.99375 .78846 m
1 .78846 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .05769 m
1 .05769 L
s
.99625 .09615 m
1 .09615 L
s
.99625 .13462 m
1 .13462 L
s
.99625 .17308 m
1 .17308 L
s
.99625 .25 m
1 .25 L
s
.99625 .28846 m
1 .28846 L
s
.99625 .32692 m
1 .32692 L
s
.99625 .36538 m
1 .36538 L
s
.99625 .44231 m
1 .44231 L
s
.99625 .48077 m
1 .48077 L
s
.99625 .51923 m
1 .51923 L
s
.99625 .55769 m
1 .55769 L
s
.99625 .63462 m
1 .63462 L
s
.99625 .67308 m
1 .67308 L
s
.99625 .71154 m
1 .71154 L
s
.99625 .75 m
1 .75 L
s
.99625 .82692 m
1 .82692 L
s
.99625 .86538 m
1 .86538 L
s
.99625 .90385 m
1 .90385 L
s
.99625 .94231 m
1 .94231 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.6 g
.49019 .51918 m
.50981 .52196 L
.52943 .52442 L
.54498 .52943 L
.54906 .53045 L
.56868 .53503 L
.5883 .53897 L
.60793 .53971 L
.62755 .54432 L
.64717 .54706 L
.6668 .54845 L
.68642 .54891 L
.70604 .54881 L
.72567 .54803 L
.74529 .54614 L
.76491 .54276 L
.78454 .53697 L
.80416 .53747 L
.82378 .53327 L
.83891 .52943 L
.84341 .52857 L
.86303 .5196 L
.88265 .5206 L
.90228 .51911 L
.91299 .52943 L
.90228 .54113 L
.89312 .54906 L
.88265 .55635 L
.86303 .56763 L
.86101 .56868 L
.84341 .57823 L
.82378 .58511 L
.81461 .5883 L
.80416 .58992 L
.78454 .5962 L
.76491 .60178 L
.74529 .60568 L
.72567 .60771 L
.72084 .60793 L
.70604 .60885 L
.68642 .60908 L
.6668 .60817 L
.66304 .60793 L
.64717 .60672 L
.62755 .60356 L
.60793 .5986 L
.5883 .59234 L
.56994 .5883 L
.56868 .58788 L
.54906 .58337 L
.52943 .57142 L
.52376 .56868 L
.50981 .56109 L
.49138 .54906 L
.49019 .54808 L
.47167 .52943 L
F
0 g
.49019 .51918 m
.50981 .52196 L
.52943 .52442 L
.54498 .52943 L
.54906 .53045 L
.56868 .53503 L
.5883 .53897 L
.60793 .53971 L
.62755 .54432 L
.64717 .54706 L
.6668 .54845 L
.68642 .54891 L
.70604 .54881 L
.72567 .54803 L
.74529 .54614 L
.76491 .54276 L
.78454 .53697 L
.80416 .53747 L
.82378 .53327 L
.83891 .52943 L
.84341 .52857 L
.86303 .5196 L
.88265 .5206 L
.90228 .51911 L
.91299 .52943 L
.90228 .54113 L
.89312 .54906 L
.88265 .55635 L
.86303 .56763 L
.86101 .56868 L
.84341 .57823 L
.82378 .58511 L
.81461 .5883 L
.80416 .58992 L
.78454 .5962 L
.76491 .60178 L
.74529 .60568 L
.72567 .60771 L
.72084 .60793 L
.70604 .60885 L
.68642 .60908 L
.6668 .60817 L
.66304 .60793 L
.64717 .60672 L
.62755 .60356 L
.60793 .5986 L
.5883 .59234 L
.56994 .5883 L
.56868 .58788 L
.54906 .58337 L
Mistroke
.52943 .57142 L
.52376 .56868 L
.50981 .56109 L
.49138 .54906 L
.49019 .54808 L
.47167 .52943 L
.49019 .51918 L
Mfstroke
.4 g
.49019 .46475 m
.50981 .46537 L
.52943 .46936 L
.54193 .47057 L
.54906 .47196 L
.56868 .47561 L
.5883 .47394 L
.60793 .48189 L
.62755 .48733 L
.64717 .48578 L
.6668 .48697 L
.68642 .4875 L
.70604 .48737 L
.72567 .48657 L
.74529 .48514 L
.76491 .48525 L
.78454 .47929 L
.80416 .47761 L
.82378 .47419 L
.84247 .47057 L
.84341 .47041 L
.86303 .4664 L
.88265 .46469 L
.90228 .46651 L
.90732 .47057 L
.90228 .47942 L
.89172 .49019 L
.88265 .49608 L
.86303 .50668 L
.85655 .50981 L
.84341 .51716 L
.82378 .52233 L
.80416 .52825 L
.79984 .52943 L
.78454 .53146 L
.76491 .5365 L
.74529 .54082 L
.72567 .54397 L
.70604 .54577 L
.68642 .54607 L
.6668 .54486 L
.64717 .54223 L
.62755 .53835 L
.60793 .53349 L
.5883 .53039 L
.58481 .52943 L
.56868 .5248 L
.54906 .52331 L
.52943 .51046 L
.52802 .50981 L
.50981 .50051 L
.49274 .49019 L
.49019 .48789 L
.47629 .47057 L
F
0 g
.49019 .46475 m
.50981 .46537 L
.52943 .46936 L
.54193 .47057 L
.54906 .47196 L
.56868 .47561 L
.5883 .47394 L
.60793 .48189 L
.62755 .48733 L
.64717 .48578 L
.6668 .48697 L
.68642 .4875 L
.70604 .48737 L
.72567 .48657 L
.74529 .48514 L
.76491 .48525 L
.78454 .47929 L
.80416 .47761 L
.82378 .47419 L
.84247 .47057 L
.84341 .47041 L
.86303 .4664 L
.88265 .46469 L
.90228 .46651 L
.90732 .47057 L
.90228 .47942 L
.89172 .49019 L
.88265 .49608 L
.86303 .50668 L
.85655 .50981 L
.84341 .51716 L
.82378 .52233 L
.80416 .52825 L
.79984 .52943 L
.78454 .53146 L
.76491 .5365 L
.74529 .54082 L
.72567 .54397 L
.70604 .54577 L
.68642 .54607 L
.6668 .54486 L
.64717 .54223 L
.62755 .53835 L
.60793 .53349 L
.5883 .53039 L
.58481 .52943 L
.56868 .5248 L
.54906 .52331 L
.52943 .51046 L
.52802 .50981 L
Mistroke
.50981 .50051 L
.49274 .49019 L
.49019 .48789 L
.47629 .47057 L
.49019 .46475 L
Mfstroke
.6 g
.50981 .42332 m
.52943 .42109 L
.54906 .4222 L
.56868 .4247 L
.5883 .42654 L
.60793 .42884 L
.62755 .4309 L
.63196 .43132 L
.64717 .43242 L
.6668 .43337 L
.68642 .4338 L
.70604 .4337 L
.72567 .43305 L
.74529 .43188 L
.75259 .43132 L
.76491 .43012 L
.78454 .42794 L
.80416 .4256 L
.82378 .41855 L
.84341 .42159 L
.86303 .42125 L
.88106 .43132 L
.86303 .44587 L
.85475 .45094 L
.84341 .45569 L
.82378 .46261 L
.80416 .46865 L
.79724 .47057 L
.78454 .4736 L
.76491 .48023 L
.74529 .47952 L
.72567 .48132 L
.70604 .48231 L
.68642 .48247 L
.6668 .48182 L
.64717 .48034 L
.62755 .48329 L
.60793 .47609 L
.5883 .4707 L
.58735 .47057 L
.56868 .46512 L
.54906 .45859 L
.52973 .45094 L
.52943 .45077 L
.50981 .43726 L
.50359 .43132 L
F
0 g
.50981 .42332 m
.52943 .42109 L
.54906 .4222 L
.56868 .4247 L
.5883 .42654 L
.60793 .42884 L
.62755 .4309 L
.63196 .43132 L
.64717 .43242 L
.6668 .43337 L
.68642 .4338 L
.70604 .4337 L
.72567 .43305 L
.74529 .43188 L
.75259 .43132 L
.76491 .43012 L
.78454 .42794 L
.80416 .4256 L
.82378 .41855 L
.84341 .42159 L
.86303 .42125 L
.88106 .43132 L
.86303 .44587 L
.85475 .45094 L
.84341 .45569 L
.82378 .46261 L
.80416 .46865 L
.79724 .47057 L
.78454 .4736 L
.76491 .48023 L
.74529 .47952 L
.72567 .48132 L
.70604 .48231 L
.68642 .48247 L
.6668 .48182 L
.64717 .48034 L
.62755 .48329 L
.60793 .47609 L
.5883 .4707 L
.58735 .47057 L
.56868 .46512 L
.54906 .45859 L
.52973 .45094 L
.52943 .45077 L
.50981 .43726 L
.50359 .43132 L
.50981 .42332 L
s
.4 g
.52943 .60141 m
.54906 .60444 L
.56786 .60793 L
.56868 .60811 L
.5883 .6125 L
.60793 .61627 L
.62755 .61927 L
.64717 .62147 L
.6668 .62287 L
.68642 .62349 L
.70604 .62333 L
.72567 .6224 L
.74529 .62069 L
.76491 .61817 L
.78454 .61485 L
.80416 .6108 L
.8136 .60793 L
.82378 .60661 L
.84341 .60307 L
.86303 .60101 L
.8746 .60793 L
.86303 .61701 L
.84845 .62755 L
.84341 .6307 L
.82378 .6409 L
.80884 .64717 L
.80416 .64917 L
.78454 .659 L
.76491 .66123 L
.74529 .66503 L
.73347 .6668 L
.72567 .66748 L
.70604 .66879 L
.68642 .66902 L
.6668 .66812 L
.65055 .6668 L
.64717 .66619 L
.62755 .6629 L
.60793 .66469 L
.5883 .65275 L
.57576 .64717 L
.56868 .64431 L
.54906 .63513 L
.5361 .62755 L
.52943 .62296 L
.51291 .60793 L
F
0 g
.52943 .60141 m
.54906 .60444 L
.56786 .60793 L
.56868 .60811 L
.5883 .6125 L
.60793 .61627 L
.62755 .61927 L
.64717 .62147 L
.6668 .62287 L
.68642 .62349 L
.70604 .62333 L
.72567 .6224 L
.74529 .62069 L
.76491 .61817 L
.78454 .61485 L
.80416 .6108 L
.8136 .60793 L
.82378 .60661 L
.84341 .60307 L
.86303 .60101 L
.8746 .60793 L
.86303 .61701 L
.84845 .62755 L
.84341 .6307 L
.82378 .6409 L
.80884 .64717 L
.80416 .64917 L
.78454 .659 L
.76491 .66123 L
.74529 .66503 L
.73347 .6668 L
.72567 .66748 L
.70604 .66879 L
.68642 .66902 L
.6668 .66812 L
.65055 .6668 L
.64717 .66619 L
.62755 .6629 L
.60793 .66469 L
.5883 .65275 L
.57576 .64717 L
.56868 .64431 L
.54906 .63513 L
.5361 .62755 L
.52943 .62296 L
.51291 .60793 L
.52943 .60141 L
s
.3 g
.54906 .48791 m
.56868 .48633 L
.5883 .48349 L
.60793 .4882 L
.62755 .4901 L
.62955 .49019 L
.64717 .49138 L
.6668 .49228 L
.68642 .49269 L
.70604 .49259 L
.72567 .49198 L
.74529 .49089 L
.75488 .49019 L
.76491 .48956 L
.78454 .48686 L
.80416 .4867 L
.82378 .48645 L
.84219 .49019 L
.82468 .50981 L
.82378 .51027 L
.80416 .51868 L
.78454 .52517 L
.76869 .52943 L
.76491 .53031 L
.74529 .53498 L
.72567 .53904 L
.70604 .5417 L
.68642 .54219 L
.6668 .54032 L
.64717 .53672 L
.62755 .53219 L
.61588 .52943 L
.60793 .52738 L
.5883 .52145 L
.56868 .51395 L
.55995 .50981 L
.54906 .50133 L
.54295 .49019 L
F
0 g
.54906 .48791 m
.56868 .48633 L
.5883 .48349 L
.60793 .4882 L
.62755 .4901 L
.62955 .49019 L
.64717 .49138 L
.6668 .49228 L
.68642 .49269 L
.70604 .49259 L
.72567 .49198 L
.74529 .49089 L
.75488 .49019 L
.76491 .48956 L
.78454 .48686 L
.80416 .4867 L
.82378 .48645 L
.84219 .49019 L
.82468 .50981 L
.82378 .51027 L
.80416 .51868 L
.78454 .52517 L
.76869 .52943 L
.76491 .53031 L
.74529 .53498 L
.72567 .53904 L
.70604 .5417 L
.68642 .54219 L
.6668 .54032 L
.64717 .53672 L
.62755 .53219 L
.61588 .52943 L
.60793 .52738 L
.5883 .52145 L
.56868 .51395 L
.55995 .50981 L
.54906 .50133 L
.54295 .49019 L
.54906 .48791 L
s
.4 g
.54906 .38822 m
.56868 .38377 L
.5883 .38339 L
.60793 .38393 L
.62755 .38438 L
.64717 .38552 L
.6668 .3861 L
.68642 .38637 L
.70604 .3863 L
.72567 .3859 L
.74529 .38523 L
.76491 .38441 L
.78454 .38366 L
.80416 .38337 L
.82378 .38458 L
.8384 .39207 L
.82378 .40233 L
.80416 .41157 L
.80384 .4117 L
.78454 .4163 L
.76491 .41997 L
.74529 .42278 L
.72567 .42476 L
.70604 .42585 L
.68642 .42603 L
.6668 .4253 L
.64717 .42368 L
.62755 .42119 L
.60793 .41787 L
.5883 .41363 L
.58081 .4117 L
.56868 .40643 L
.54906 .39465 L
.54626 .39207 L
F
0 g
.54906 .38822 m
.56868 .38377 L
.5883 .38339 L
.60793 .38393 L
.62755 .38438 L
.64717 .38552 L
.6668 .3861 L
.68642 .38637 L
.70604 .3863 L
.72567 .3859 L
.74529 .38523 L
.76491 .38441 L
.78454 .38366 L
.80416 .38337 L
.82378 .38458 L
.8384 .39207 L
.82378 .40233 L
.80416 .41157 L
.80384 .4117 L
.78454 .4163 L
.76491 .41997 L
.74529 .42278 L
.72567 .42476 L
.70604 .42585 L
.68642 .42603 L
.6668 .4253 L
.64717 .42368 L
.62755 .42119 L
.60793 .41787 L
.5883 .41363 L
.58081 .4117 L
.56868 .40643 L
.54906 .39465 L
.54626 .39207 L
.54906 .38822 L
s
.7 g
.56868 .54818 m
.5883 .54896 L
.58965 .54906 L
.60793 .55086 L
.62755 .55273 L
.64717 .55424 L
.6668 .55525 L
.68642 .55571 L
.70604 .55559 L
.72567 .55491 L
.74529 .55369 L
.76491 .55201 L
.78454 .55006 L
.79506 .54906 L
.80416 .54848 L
.82378 .54857 L
.8272 .54906 L
.82378 .56473 L
.8187 .56868 L
.80416 .57609 L
.78454 .58367 L
.76947 .5883 L
.76491 .58968 L
.74529 .59559 L
.72567 .60093 L
.70604 .60481 L
.68642 .60557 L
.6668 .60274 L
.64717 .59782 L
.62755 .59208 L
.6151 .5883 L
.60793 .58619 L
.5883 .57937 L
.56868 .57026 L
.56594 .56868 L
.55748 .54906 L
F
0 g
.56868 .54818 m
.5883 .54896 L
.58965 .54906 L
.60793 .55086 L
.62755 .55273 L
.64717 .55424 L
.6668 .55525 L
.68642 .55571 L
.70604 .55559 L
.72567 .55491 L
.74529 .55369 L
.76491 .55201 L
.78454 .55006 L
.79506 .54906 L
.80416 .54848 L
.82378 .54857 L
.8272 .54906 L
.82378 .56473 L
.8187 .56868 L
.80416 .57609 L
.78454 .58367 L
.76947 .5883 L
.76491 .58968 L
.74529 .59559 L
.72567 .60093 L
.70604 .60481 L
.68642 .60557 L
.6668 .60274 L
.64717 .59782 L
.62755 .59208 L
.6151 .5883 L
.60793 .58619 L
.5883 .57937 L
.56868 .57026 L
.56594 .56868 L
.55748 .54906 L
.56868 .54818 L
s
.7 g
.5883 .44031 m
.60793 .43936 L
.62755 .43953 L
.64717 .43995 L
.6668 .44033 L
.68642 .44052 L
.70604 .44047 L
.72567 .4402 L
.74529 .43978 L
.76491 .4394 L
.78454 .43951 L
.80416 .44169 L
.81217 .45094 L
.80416 .45553 L
.78454 .46375 L
.76491 .4698 L
.76201 .47057 L
.74529 .47343 L
.72567 .47571 L
.70604 .47693 L
.68642 .47713 L
.6668 .47632 L
.64717 .47447 L
.62755 .47265 L
.62263 .47057 L
.60793 .46639 L
.5883 .45915 L
.57245 .45094 L
F
0 g
.5883 .44031 m
.60793 .43936 L
.62755 .43953 L
.64717 .43995 L
.6668 .44033 L
.68642 .44052 L
.70604 .44047 L
.72567 .4402 L
.74529 .43978 L
.76491 .4394 L
.78454 .43951 L
.80416 .44169 L
.81217 .45094 L
.80416 .45553 L
.78454 .46375 L
.76491 .4698 L
.76201 .47057 L
.74529 .47343 L
.72567 .47571 L
.70604 .47693 L
.68642 .47713 L
.6668 .47632 L
.64717 .47447 L
.62755 .47265 L
.62263 .47057 L
.60793 .46639 L
.5883 .45915 L
.57245 .45094 L
.5883 .44031 L
s
.2 g
.60793 .49843 m
.62755 .49782 L
.64717 .49802 L
.6668 .49832 L
.68642 .49849 L
.70604 .49845 L
.72567 .49821 L
.74529 .49791 L
.76491 .49789 L
.78454 .49942 L
.79333 .50981 L
.78454 .51441 L
.76491 .52165 L
.74529 .52669 L
.73034 .52943 L
.72567 .53032 L
.70604 .53339 L
.68642 .53396 L
.6668 .53179 L
.65315 .52943 L
.64717 .52821 L
.62755 .52389 L
.60793 .51765 L
.59131 .50981 L
F
0 g
.60793 .49843 m
.62755 .49782 L
.64717 .49802 L
.6668 .49832 L
.68642 .49849 L
.70604 .49845 L
.72567 .49821 L
.74529 .49791 L
.76491 .49789 L
.78454 .49942 L
.79333 .50981 L
.78454 .51441 L
.76491 .52165 L
.74529 .52669 L
.73034 .52943 L
.72567 .53032 L
.70604 .53339 L
.68642 .53396 L
.6668 .53179 L
.65315 .52943 L
.64717 .52821 L
.62755 .52389 L
.60793 .51765 L
.59131 .50981 L
.60793 .49843 L
s
.8 g
.62755 .5675 m
.64717 .56536 L
.6668 .565 L
.68642 .56496 L
.70604 .56497 L
.72567 .56507 L
.74529 .56579 L
.76084 .56868 L
.74529 .57815 L
.72567 .58304 L
.70604 .58546 L
.68642 .58585 L
.6668 .58426 L
.64717 .58047 L
.62755 .57288 L
.62411 .56868 L
F
0 g
.62755 .5675 m
.64717 .56536 L
.6668 .565 L
.68642 .56496 L
.70604 .56497 L
.72567 .56507 L
.74529 .56579 L
.76084 .56868 L
.74529 .57815 L
.72567 .58304 L
.70604 .58546 L
.68642 .58585 L
.6668 .58426 L
.64717 .58047 L
.62755 .57288 L
.62411 .56868 L
.62755 .5675 L
s
.8 g
.64717 .44908 m
.6668 .44837 L
.68642 .44817 L
.70604 .44821 L
.72567 .44857 L
.74529 .44969 L
.75493 .45094 L
.74529 .46284 L
.72567 .46802 L
.70604 .47041 L
.70353 .47057 L
.68642 .47073 L
.68111 .47057 L
.6668 .46924 L
.64717 .46536 L
.62981 .45094 L
F
0 g
.64717 .44908 m
.6668 .44837 L
.68642 .44817 L
.70604 .44821 L
.72567 .44857 L
.74529 .44969 L
.75493 .45094 L
.74529 .46284 L
.72567 .46802 L
.70604 .47041 L
.70353 .47057 L
.68642 .47073 L
.68111 .47057 L
.6668 .46924 L
.64717 .46536 L
.62981 .45094 L
.64717 .44908 L
s
.1 g
.64717 .50761 m
.6668 .50621 L
.68642 .50584 L
.70604 .50592 L
.72567 .50657 L
.74529 .50909 L
.74764 .50981 L
.74529 .51304 L
.72567 .51998 L
.70604 .52277 L
.68642 .5232 L
.6668 .52141 L
.64717 .51675 L
.63657 .50981 L
F
0 g
.64717 .50761 m
.6668 .50621 L
.68642 .50584 L
.70604 .50592 L
.72567 .50657 L
.74529 .50909 L
.74764 .50981 L
.74529 .51304 L
.72567 .51998 L
.70604 .52277 L
.68642 .5232 L
.6668 .52141 L
.64717 .51675 L
.63657 .50981 L
.64717 .50761 L
s
.6 g
.64717 .35272 m
.6668 .35149 L
.68642 .35112 L
.70604 .3512 L
.72567 .35183 L
.73943 .35283 L
.72567 .3665 L
.70604 .36895 L
.68642 .36933 L
.6668 .36778 L
.64717 .36352 L
.6461 .35283 L
F
0 g
.64717 .35272 m
.6668 .35149 L
.68642 .35112 L
.70604 .3512 L
.72567 .35183 L
.73943 .35283 L
.72567 .3665 L
.70604 .36895 L
.68642 .36933 L
.6668 .36778 L
.64717 .36352 L
.6461 .35283 L
.64717 .35272 L
s
.3 g
.6668 .40379 m
.68642 .4027 L
.70604 .40294 L
.72567 .40502 L
.72985 .4117 L
.72567 .41231 L
.70604 .4143 L
.68642 .41462 L
.6668 .41333 L
.65351 .4117 L
F
0 g
.6668 .40379 m
.68642 .4027 L
.70604 .40294 L
.72567 .40502 L
.72985 .4117 L
.72567 .41231 L
.70604 .4143 L
.68642 .41462 L
.6668 .41333 L
.65351 .4117 L
.6668 .40379 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00?Oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0dooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kS?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0hooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8b
onk^kS?ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08_ooool003gooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0=_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0<oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg03?ooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL08_ooool003Gooooo1_l0
0003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400[ooooo`Ko0000
1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100<oooool01Ol@413o
oooooooooooooooo410@03[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@03Cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@02;ooooo000o
ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000fooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000cooooo`05o`000?ooooooooooooooool0
0000>_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000=Oooool00onH
V9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000008_ooool0043ooooo00?oMgMgofIV
I_ooool00_ooool01Ol0003ooooooooooooooooo000003Kooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000003?ooooo00Go0000ooooooooooooooooo`00000jooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`03ogMgMomVIVKooooo00;o
oooo00Go0000ooooooooooooooooo`00000Rooooo`00@Oooool01Ol0003ooooooooooooooooo410@
00?ooooo00?o410@ooooooooool0=?ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@4100<oooool01Ol@413ooooooooooooooooo410@03[ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@03Oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo023ooooo000mooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg03Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg03?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0jooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0cooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02;ooooo000mooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^03Cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^03?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`03oeEEEOmVIVKo000000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0cooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02;ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo000Joooooooo0000C_l00001ooooo`00
6_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0?Ooo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool08ooo
ool1o`00007ooooo0008ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKo
oooo00?o0000ooooooooool0oooooom:ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooom:ooooo`7o
00000Oooool000Go00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41001_ooool00ol0003oooooooooo`3ooooood[ooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?ooooooB?ooool3o`00007o
oooo000:ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo0008ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Oooooooogmo
Od3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Ooo
ooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000oooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`003ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000?ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000oooooo00Go0000oooooooooooooooo
o`000006ooooo`?o00001?ooooooogmoOd3oOgmo1?ooool3o`00007ooooo000?ooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool000oooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`003oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000?ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooomCoOgmo6_l0001AogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooom3oOgmo1?l0000JoiVIV@;o0000ComoOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooo@ogmoO`03o`000?nIVIWoVIVI01[o
VIVI00?o0000ogmoOomoOgl0ComoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?ooooo@ogmoO`03o`000?nIVIWoVIVI01WoVIVI00?o0000ogmoOomoOgl0D?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooo@ogmoO`?o00006?nIVIT00ol0003oOgmoogmo
O`1AogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000GooooodomoOgl3o`00017oVIVI1?l0001D
ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04ooooomKoOgmo4Ol0001Hogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?ooooneogmoOaWo00009_moOglIo`0003;oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00Cooooo/_moOgl3o`0001WoIVIV9_l0000IofIVIP;o0000<?moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?oooon`ogmoO`;o0000GOmVIVH00ol0003oOgmo
ogmoO`0]ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooojooOgmo00?o
0000ofIVI_mVIVH0GOmVIVH2o`0002koOgmo1_ooool1o`00007ooooo0008ooooo`Co000000So410@
ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo00?o0000ooooooooool01?oooon`ogmoO`;o
0000FomVIVH2o`00033oOgmo1_ooool1o`00007ooooo000:ooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00Cooooo/_moOgl00ol0003o
IVIVofIVIP1GofIVIP03o`000?moOgooOgmo033oOgmo1_ooool1o`00007ooooo000:ooooo`03o`00
0?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00Co
oooo/omoOgl2o`0002GoIVIV3_l0000RofIVIP;o0000<omoOgl6ooooo`7o00000Oooool000[ooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo0ol00004oooookGo
Ogmo00?o0000ofIVI_mVIVH07_mVIVH4o`0000koC4a<0ol0000LofIVIP?o0000=OmoOgl4ooooo`?o
00000Oooool000[ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooooooool01?oooonfogmoO`?o00006_mVIVH3o`0001GoC4a<00?o0000ofIVI_mV
IVH05omVIVH2o`0003SoOgmo1_ooool1o`00007ooooo000:ooooo`03o`000?oooooooooo00;ooooo
00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00Cooooo^OmoOgl4o`0001Go
IVIV1?l0000Eoda<C0;o00005_mVIVH2o`0003[oOgmo1_ooool1o`00007ooooo000:ooooo`03o`00
0?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00Co
oooo_OmoOgl4o`0001GoIVIV5Ol0000EofIVIP?o0000??moOgl6ooooo`7o00000Oooool000Sooooo
00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooooooo
ool01?ooooo1ogmoO`Go0000=OmVIVH5o`0003ooOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CoooooY_moOgl8o`0001SoOgmo0ol0000[ofIVIPOo00003_moOgl6o`00033oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooXomoOgl3o`0000SoVIVI1_l0
000EogmoO`co00006OmVIVH6o`0001;oOgmo0ol00006oiVIV@_o00009OmoOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?oooonRogmoO`03o`000?nIVIWoVIVI00ooVIVI3Ol0000D
ogmoOaWo00004omoOgl5o`0001CoVIVI0_l0000SogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04oooooj7oOgmo00?o0000oiVIVOnIVIT07OnIVIT7o`0002goOgmo3?l0000KoiVI
V@;o00008OmoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonPogmoO`;o
00009_nIVIT=o`0001;oOgmo3_l0000XoiVIV@;o00008?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?oooonRogmoO`03o`000?nIVIWoVIVI033oVIVI4_l0000eoiVIV@03o`00
0?moOgooOgmo023oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooXomo
Ogl2o`0007KoVIVI00?o0000ogmoOomoOgl08OmoOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?oooonUogmoO`03o`000?nIVIWoVIVI01CoVIVIBOl0000EoiVIV@03o`000?moOgoo
Ogmo02;oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OoooonVogmoO`;o00004_nIVIT2o`00
04Wo/k>c00?o0000oiVIVOnIVIT04OnIVIT00ol0003oOgmoogmoO`0SogmoO`Gooooo0_l00001oooo
o`006_ooool00ol0003oooooooooo`04ooooojSoOgmo00?o0000oiVIVOnIVIT03OnIVIT2o`00023o
/k>c3_l0000Nok>c/`03o`000?nIVIWoVIVI00koVIVI0_l0000VogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooojWoOgmo0_l0000<oiVIV@;o00004Onc/k<@o`0000koc<c<
3Ol0000Aok>c/`;o00003?nIVIT3o`0002SoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CoooooZomoOgl3o`0000_oVIVI0_l0000Aok>c/`03o`000?o<c<coc<c<02Goc<c<00?o
0000ok>c/onc/k<03_nc/k<00ol0003oVIVIoiVIV@0:oiVIV@;o0000:omoOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?oooon^ogmoO`;o00002onIVIT2o`00013o/k>c00?o0000
olc<c?o<c<`08oo<c<`00ol0003o/k>cok>c/`0=ok>c/`;o00002onIVIT2o`0002goOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo/?moOgl3o`0000[oVIVI0_l0000?ok>c
/`03o`000?o<c<coc<c<027oc<c<00?o0000ok>c/onc/k<03?nc/k<2o`0000[oVIVI0ol0000_ogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooook?oOgmo0ol00009oiVIV@;o
00003_nc/k<00ol0003oc<c<olc<c00Molc<c0?o00003Onc/k<2o`0000SoVIVI1?l0000bogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooi_oOgmo2ol0000@ogmoO`?o0000
2?nIVIT2o`0000go/k>c1Ol0000Golc<c0?o00003Onc/k<3o`0000OoVIVI0ol0000BogmoO`So0000
7?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonHogmoO`?o00002omV
IVH3o`00013oOgmo0ol00007oiVIV@Co00003_nc/k<5o`0000goc<c<1Ol0000=ok>c/`?o00001onI
VIT3o`0000ooOgmo1_l00008ofIVIPCo00006?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?oooonGogmoO`03o`000?mVIVKoIVIV00ooIVIV2_l00009ogmoO`Co00001onIVIT3
o`00013o/k>c3Ol0000=ok>c/`Go00001onIVIT3o`0000_oOgmo1ol0000BofIVIP03o`000?moOgoo
Ogmo01GoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooUomoOgl00ol0
003oIVIVofIVIP0IofIVIP?o00001?moOgl5o`000004ogmoOol0003o0000o`0000OoVIVI2ol0000I
ok>c/`Ko00002?nIVIT4o`0000SoOgmo1_l0000IofIVIP03o`000?moOgooOgmo01GoOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooV?moOgl00ol0003oIVIVofIVIP0KofIV
IPCo00001OmVIVH2o`0000;oOgmo0ol0000?oiVIVAWo00002onIVIT3o`0000GoOgmo1ol0000NofIV
IP03o`000?moOgooOgmo01KoOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OoooonIogmoO`03
o`000?mVIVKoIVIV02GoIVIV0_l00003ogmoO`?o00001?nIVIT8o`0001;oVIVI4_l00003ogmoO`Go
00008omVIVH2o`0001WoOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
V_moOgl00ol0003oIVIVofIVIP0MofIVIPKo00000omVIVH5o`000003ogmoOol0003o000000;o0000
2?moOglBo`0001;oOgmo0ol0000WofIVIP03o`000?moOgooOgmo01WoOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CoooooVomoOgl00ol0003oIVIVofIVIP0EofIVIPOo00001_m<
C4`3o`0000GoIVIV4ol0000<ogmoOa;o00000_mVIVHDo`0001?oIVIV00?o0000ogmoOomoOgl06_mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonLogmoO`?o00003omVIVH5
o`00013oC4a<2ol0000=ofIVIPco00003?mVIVH8o`0001CoC4a<0ol0000>ofIVIP;o00007OmoOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonOogmoO`03o`000?mVIVKoIVIV
00coIVIV00?o0000oda<C?m<C4`07Om<C4`Uo`0001koC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0
003oOgmoogmoO`0MogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooj3o
Ogmo0_l0000=ofIVIP03o`000?m<C4coC4a<05koC4a<00?o0000ofIVI_mVIVH02_mVIVH2o`00023o
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooX_moOgl00ol0003oIVIV
ofIVIP0:ofIVIP03o`000?m<C4coC4a<013oC4a<>_l0000Coda<C003o`000?mVIVKoIVIV00[oIVIV
00?o0000ogmoOomoOgl08?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
oonSogmoO`;o00002omVIVH00ol0003oC4a<oda<C00>oda<C003o`000?lc<c?o<c<c03So<c<c0ol0
000?oda<C003o`000?mVIVKoIVIV00WoIVIV0_l0000SogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooojGoOgmo0_l0000:ofIVIP03o`000?m<C4coC4a<00coC4a<00?o0000
oc<c<olc<c<0??lc<c<00ol0003oC4a<oda<C00;oda<C003o`000?mVIVKoIVIV00WoIVIV00?o0000
ogmoOomoOgl08omoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonWogmo
O`;o00002OmVIVH00ol0003oC4a<oda<C00:oda<C003o`000?lc<c?o<c<c00go<c<c8?l0000Aoc<c
<`03o`000?m<C4coC4a<00WoC4a<00?o0000ofIVI_mVIVH02?mVIVH2o`0002KoOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CoooooZOmoOgl2o`0000SoIVIV0ol00008oda<C0;o
00003Olc<c<2o`00023o6ATI1?l0000=oc<c<`;o00002?m<C4`2o`0000WoIVIV0_l0000XogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooj_oOgmo0_l00009ofIVIP;o0000
2?m<C4`2o`0000go<c<c00?o0000oaTI6OlI6AT07OlI6AT3o`0000_o<c<c0ol00007oda<C0?o0000
2?mVIVH3o`0002[oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo[Omo
Ogl00ol0003oIVIVofIVIP08ofIVIP?o00001om<C4`00ol0003o<c<coc<c<`0;oc<c<`?o00006OlI
6AT3o`0000_o<c<c0ol00008oda<C0;o00002OmVIVH2o`0002goOgmo1_ooool1o`00007ooooo000J
ooooo`;o00001OoooonKogmoO`Ko00003OmoOgl2o`0000_oIVIV0_l00006oda<C0?o00003Olc<c<3
o`00017o6ATI1Ol0000<oc<c<`;o00002Om<C4`2o`0000SoIVIV0ol00007ogmoO`Go00001_moOgl4
o`0001WoOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooVOmoOgl2o`00
00KoVIVI1_l00009ogmoO`Co00002OmVIVH3o`0000KoC4a<0ol0000=oc<c<a7o00003olc<c<2o`00
00SoC4a<0ol00006ofIVIPCo00001omoOgl3o`0000GoVIVI1_l00004oiVIV@03o`000?moOgooOgmo
01KoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooUomoOgl2o`0000ko
VIVI1_l00007ogmoO`Ko00001_mVIVH3o`0000KoC4a<1Ol0000Uoc<c<`?o00001_m<C4`4o`0000Ko
IVIV0ol00009ogmoO`;o00004onIVIT00ol0003oOgmoogmoO`0EogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04oooooiKoOgmo00?o0000oiVIVOnIVIT05?nIVIT3o`0000[oOgmo
0ol00006ofIVIPKo00001Om<C4`8o`0001Go<c<c2?l00005oda<C0Co00001OmVIVH5o`0000WoOgmo
0ol0000FoiVIV@03o`000?moOgooOgmo01CoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CoooooU_moOgl00ol0003oVIVIoiVIV@0GoiVIV@Co00002OmoOgl4o`0000SoIVIV1?l0
0009oda<C0Go00003?lc<c<4o`0000WoC4a<1?l00004ofIVIPGo00002omoOgl3o`0001WoVIVI00?o
0000ogmoOomoOgl05?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonG
ogmoO`03o`000?nIVIWoVIVI01[oVIVI1Ol00008ogmoO`Oo00001OmVIVH3o`0000_oC4a<3?l00008
oda<C0Go00001OmVIVH3o`0000coOgmo1?l0000KoiVIV@03o`000?moOgooOgmo01GoOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooV?moOgl00ol0003oVIVIoiVIV@0NoiVI
V@?o00003?moOgl5o`0000?oIVIV1Ol0000Goda<C0?o00001OmVIVH5o`0000?oOgmo3?l0000NoiVI
V@03o`000?moOgooOgmo01KoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
ooooVOmoOgl00ol0003oVIVIoiVIV@0PoiVIV@co00001OmoOgl3o`0000GoIVIV1_l0000<oda<C0Go
00000_mVIVH6o`0000GoOgmo0ol0000YoiVIV@03o`000?moOgooOgmo01OoOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CoooooV_moOgl00ol0003oVIVIoiVIV@0[oiVIV@Ko0000
0_moOgl5o`0000KoIVIV4ol00006ogmoO`Go0000:onIVIT00ol0003oOgmoogmoO`0HogmoO`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooi_oOgmo00?o0000oiVIVOnIVIT0<?nI
VITIo`0000OoOgmo1_l0000_oiVIV@03o`000?moOgooOgmo01WoOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CoooooW?moOgl2o`0001CoVIVI3ol0000DoiVIVAWo00003OnIVITB
o`0001CoVIVI0_l0000LogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
oikoOgmo0_l0000BoiVIV@03o`000?nc/k?o/k>c00co/k>c3Ol0000VoiVIV@Oo00004Onc/k<00ol0
003oVIVIoiVIV@0@oiVIV@;o00007_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?oooonPogmoO`03o`000?nIVIWoVIVI013oVIVI00?o0000ok>c/onc/k<06?nc/k<Vo`0001So
/k>c00?o0000oiVIVOnIVIT03_nIVIT2o`00023oOgmo1_ooool1o`00007ooooo000Jooooo`;o0000
1OoooonQogmoO`;o00004?nIVIT00ol0003o/k>cok>c/`1Eok>c/`03o`000?nIVIWoVIVI00koVIVI
00?o0000ogmoOomoOgl08?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool01?oo
oonSogmoO`;o00003onIVIT00ol0003o/k>cok>c/`1Dok>c/`03o`000?nIVIWoVIVI00coVIVI0_l0
000SogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooojGoOgmo00?o0000
oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`0Fok>c/b;o00007?nc/k<00ol0003oVIVIoiVIV@0;
oiVIV@03o`000?moOgooOgmo02?oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CoooooY_moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01;o/k>c1?l0000Rolc<
c0Ko00005Onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo02CoOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CoooooYomoOgl4o`0000[oVIVI0ol0000@ok>c/`;o
0000:oo<c<`2o`00017o/k>c0_l0000<oiVIV@;o00009omoOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?oooon[ogmoO`;o00002onIVIT3o`0000oo/k>c0ol0000Volc<c0;o0000
4?nc/k<3o`0000coVIVI0_l0000YogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooojgoOgmo00?o0000oiVIVOnIVIT02onIVIT2o`00013o/k>c0ol0000Rolc<c003o`000?nc
/k?o/k>c00ko/k>c0_l0000=oiVIV@;o0000:omoOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?oooon^ogmoO`;o00003OnIVIT3o`00013o/k>c0ol0000Kolc<c0Co00003_nc/k<3
o`0000goVIVI0_l0000]ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
ok3oOgmo0ol0000=oiVIV@?o00004?nc/k<3o`00017oc<c<1ol0000?ok>c/`?o00003OnIVIT3o`00
02ooOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo/omoOgl3o`0000go
VIVI0_l0000Aok>c/a7o00004onc/k<3o`0000goVIVI0ol0000bogmoO`Kooooo0Ol00001ooooo`00
1oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo00Co
oooo]_moOgl5o`0000[oVIVI1?l0000]ok>c/`Co00003?nIVIT4o`0003GoOgmo1_ooool1o`00007o
oooo0007ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Kooooo00?o0000ooooooooool01?oooonkogmoO`Go00002OnIVIT4o`0002Ko/k>c0ol0000=oiVI
V@?o0000>OmoOgl6ooooo`7o00000Oooool000Sooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@00Kooooo00?o0000ooooooooool01?ooooo0ogmoO`?o00002_nIVIT3o`00
01oo/k>c1?l0000=oiVIV@?o0000??moOgl6ooooo`7o00000Oooool000Wooooo00?oV9RHob4Q8Oo^
k^h00oooool01Ol0003ooooooooooooooooo000000Kooooo0ol00004oooool?oOgmo0ol0000:oiVI
V@?o00006Onc/k<3o`0000goVIVI1?l0000oogmoO`Cooooo0ol00001ooooo`002_ooool00omgMgOo
IVIVooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`04oooo
ojSoOgmo1_l0000HogmoO`?o00002_nIVIT3o`0001?o/k>c0ol0000=oiVIV@?o00006OmoOgl5o`00
02GoOgmo1_ooool1o`00007ooooo000;ooooo`05o`000?ooooooooooooooool@41000oooool00ol@
413oooooooooo`04ooooo`03o`000?oooooooooo00CoooooY_moOgl2o`0000KoIVIV1Ol0000Fogmo
O`Go00002?nIVIT5o`0000_o/k>c0ol0000;oiVIV@Go00005OmoOgl7o`0000GoIVIV00?o0000ogmo
OomoOgl08_moOgl6ooooo`7o00000Oooool000Oooooo00Go0000okZj^_ooooooV9RHoa0@4003oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`04ooooojGoOgmo00?o0000
ofIVI_mVIVH02omVIVH3o`0001SoOgmo1_l00007oiVIV@_o00001?nIVIT:o`0001GoOgmo1Ol0000=
ofIVIP03o`000?moOgooOgmo027oOgmo1_ooool1o`00007ooooo0007ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool01?oo
oonTogmoO`03o`000?mVIVKoIVIV00ooIVIV1Ol0000IogmoOaKo00007?moOgl3o`0001;oIVIV0_l0
000RogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooojGoOgmo00?o0000
ofIVI_mVIVH04omVIVH6o`00043oOgmo1Ol0000DofIVIP03o`000?moOgooOgmo02;oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooY_moOgl00ol0003oIVIVofIVIP0HofIV
IPOo0000<omoOgl6o`0001SoIVIV00?o0000ogmoOomoOgl08omoOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?oooonWogmoO`03o`000?mVIVKoIVIV01koIVIV1_l0000VogmoO`Oo
00007?mVIVH2o`0002KoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
Z?moOgl00ol0003oIVIVofIVIP0SofIVIPOo00004_moOgl=o`00027oIVIV0_l0000XogmoO`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooojWoOgmo0_l0000ZofIVIQ;o0000;OmV
IVH00ol0003oOgmoogmoO`0XogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
oooooj_oOgmo0_l0001UofIVIP;o0000:omoOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?oooon]ogmoO`;o0000HOmVIVH2o`0002goOgmo1_ooool1o`00007ooooo000Jooooo`;o
00001Ooooon_ogmoO`03o`000?mVIVKoIVIV05goIVIV00?o0000ogmoOomoOgl0;OmoOgl5ooooo`;o
00000Oooool001[ooooo00?o0000ooooooooool01?oooon`ogmoO`;o0000FomVIVH2o`00033oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo/_moOgl2o`0005SoIVIV00?o
0000ogmoOomoOgl0<?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooond
ogmoO`;o0000E?mVIVH2o`0003?oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00Cooooo]_moOgl2o`0004ooIVIV0ol0000eogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04oooookSoOgmo1?l00017ofIVIPCo0000>?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?oooonlogmoO`?o0000@omVIVH00ol0003oOgmoogmoO`0jogmoO`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooookooOgmo00?o0000ofIVI_mVIVH0?_mV
IVH2o`0003goOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo`?moOgl2
o`0003goIVIV00?o0000ogmoOomoOgl0?OmoOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?ooooo2ogmoO`03o`000?mVIVKoIVIV037oIVIV2Ol00010ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04oooool?oOgmo2ol0000UofIVIP?o0000BOmoOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooo>ogmoO`Oo00004_mVIVH<o`0004coOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooeOmoOglBo`0005SoOgmo1_oo
ool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007ooooo000Joooo
o`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooooomo
Ogm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
ooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3o
Ogmo1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007ooooo
000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo
@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooo
ogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00
007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
ooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3o
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo0007oooo
o`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o
0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo0007ooooo`05oa0@4?nj^[[o
ooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0
1?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000;ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`04ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo
0Ol00001ooooo`002_ooool00onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool00000
1_ooool3o`0000CooooooomoOgm0ogmoO`Cooooo0ol00001ooooo`002Oooool00ol@413o0000okZj
^P03ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`04ooooooooOgmo
@?moOgl6ooooo`7o00000Oooool000[ooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooo
oooooooo410@00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo
0007ooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Ko
oooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo0007ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooo
ooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo
@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000Gooooooomo
Ogm0ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
ooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3o
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000Go
oooooomoOgm0ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo
@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooo
ogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool2
o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04oooo
ooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3o
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooooomo
Ogm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`00
6_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooo
ogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002Oooool2o`000009oa0@4?ooooooooooooooooo^
k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000:ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`001oooool5o`00
00?ooooo00Go410@oooooooooooooooooa0@4006ooooo`?o00001?ooooooogmoOd3oOgmo1?ooool3
o`00007ooooo0007ooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo0?ooooooB_ooool1o`00007ooooo0007ooooo`04omgMgOmEEEGo
ooooo`0000Cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo
B_ooool1o`00007ooooo0008ooooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooooooo
oa0@4006ooooo`03o`000?oooooooooo0?ooooooB_ooool1o`00007ooooo0008ooooo`03onk^k_m4
A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oooooo
B_ooool1o`00007ooooo0009ooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP06ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0?Oooool00ol0003ooooo
ooooo`0mooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0?Oooool00ol0003ooooo
ooooo`0Sooooo`7o00000Oooool001[ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`09ooooo`7o00000Oooool001[oooooool0001>o`00007ooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-30.1723, -14.304, 0.195672, \
0.195672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0192308 0.211538 0.0192308 [
[.11538 -0.0125 -9 -9 ]
[.11538 -0.0125 9 0 ]
[.30769 -0.0125 -9 -9 ]
[.30769 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69231 -0.0125 -6 -9 ]
[.69231 -0.0125 6 0 ]
[.88462 -0.0125 -6 -9 ]
[.88462 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -18 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .21154 -6 -4.5 ]
[-0.0125 .21154 0 4.5 ]
[-0.0125 .40385 -12 -4.5 ]
[-0.0125 .40385 0 4.5 ]
[-0.0125 .59615 -12 -4.5 ]
[-0.0125 .59615 0 4.5 ]
[-0.0125 .78846 -12 -4.5 ]
[-0.0125 .78846 0 4.5 ]
[-0.0125 .98077 -12 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11538 0 m
.11538 .00625 L
s
[(-20)] .11538 -0.0125 0 1 Mshowa
.30769 0 m
.30769 .00625 L
s
[(-10)] .30769 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69231 0 m
.69231 .00625 L
s
[(10)] .69231 -0.0125 0 1 Mshowa
.88462 0 m
.88462 .00625 L
s
[(20)] .88462 -0.0125 0 1 Mshowa
.125 Mabswid
.15385 0 m
.15385 .00375 L
s
.19231 0 m
.19231 .00375 L
s
.23077 0 m
.23077 .00375 L
s
.26923 0 m
.26923 .00375 L
s
.34615 0 m
.34615 .00375 L
s
.38462 0 m
.38462 .00375 L
s
.42308 0 m
.42308 .00375 L
s
.46154 0 m
.46154 .00375 L
s
.53846 0 m
.53846 .00375 L
s
.57692 0 m
.57692 .00375 L
s
.61538 0 m
.61538 .00375 L
s
.65385 0 m
.65385 .00375 L
s
.73077 0 m
.73077 .00375 L
s
.76923 0 m
.76923 .00375 L
s
.80769 0 m
.80769 .00375 L
s
.84615 0 m
.84615 .00375 L
s
.07692 0 m
.07692 .00375 L
s
.03846 0 m
.03846 .00375 L
s
.92308 0 m
.92308 .00375 L
s
.96154 0 m
.96154 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(-10)] -0.0125 .01923 1 0 Mshowa
0 .21154 m
.00625 .21154 L
s
[(0)] -0.0125 .21154 1 0 Mshowa
0 .40385 m
.00625 .40385 L
s
[(10)] -0.0125 .40385 1 0 Mshowa
0 .59615 m
.00625 .59615 L
s
[(20)] -0.0125 .59615 1 0 Mshowa
0 .78846 m
.00625 .78846 L
s
[(30)] -0.0125 .78846 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(40)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .05769 m
.00375 .05769 L
s
0 .09615 m
.00375 .09615 L
s
0 .13462 m
.00375 .13462 L
s
0 .17308 m
.00375 .17308 L
s
0 .25 m
.00375 .25 L
s
0 .28846 m
.00375 .28846 L
s
0 .32692 m
.00375 .32692 L
s
0 .36538 m
.00375 .36538 L
s
0 .44231 m
.00375 .44231 L
s
0 .48077 m
.00375 .48077 L
s
0 .51923 m
.00375 .51923 L
s
0 .55769 m
.00375 .55769 L
s
0 .63462 m
.00375 .63462 L
s
0 .67308 m
.00375 .67308 L
s
0 .71154 m
.00375 .71154 L
s
0 .75 m
.00375 .75 L
s
0 .82692 m
.00375 .82692 L
s
0 .86538 m
.00375 .86538 L
s
0 .90385 m
.00375 .90385 L
s
0 .94231 m
.00375 .94231 L
s
.25 Mabswid
0 0 m
0 1 L
s
.11538 .99375 m
.11538 1 L
s
.30769 .99375 m
.30769 1 L
s
.5 .99375 m
.5 1 L
s
.69231 .99375 m
.69231 1 L
s
.88462 .99375 m
.88462 1 L
s
.125 Mabswid
.15385 .99625 m
.15385 1 L
s
.19231 .99625 m
.19231 1 L
s
.23077 .99625 m
.23077 1 L
s
.26923 .99625 m
.26923 1 L
s
.34615 .99625 m
.34615 1 L
s
.38462 .99625 m
.38462 1 L
s
.42308 .99625 m
.42308 1 L
s
.46154 .99625 m
.46154 1 L
s
.53846 .99625 m
.53846 1 L
s
.57692 .99625 m
.57692 1 L
s
.61538 .99625 m
.61538 1 L
s
.65385 .99625 m
.65385 1 L
s
.73077 .99625 m
.73077 1 L
s
.76923 .99625 m
.76923 1 L
s
.80769 .99625 m
.80769 1 L
s
.84615 .99625 m
.84615 1 L
s
.07692 .99625 m
.07692 1 L
s
.03846 .99625 m
.03846 1 L
s
.92308 .99625 m
.92308 1 L
s
.96154 .99625 m
.96154 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .21154 m
1 .21154 L
s
.99375 .40385 m
1 .40385 L
s
.99375 .59615 m
1 .59615 L
s
.99375 .78846 m
1 .78846 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .05769 m
1 .05769 L
s
.99625 .09615 m
1 .09615 L
s
.99625 .13462 m
1 .13462 L
s
.99625 .17308 m
1 .17308 L
s
.99625 .25 m
1 .25 L
s
.99625 .28846 m
1 .28846 L
s
.99625 .32692 m
1 .32692 L
s
.99625 .36538 m
1 .36538 L
s
.99625 .44231 m
1 .44231 L
s
.99625 .48077 m
1 .48077 L
s
.99625 .51923 m
1 .51923 L
s
.99625 .55769 m
1 .55769 L
s
.99625 .63462 m
1 .63462 L
s
.99625 .67308 m
1 .67308 L
s
.99625 .71154 m
1 .71154 L
s
.99625 .75 m
1 .75 L
s
.99625 .82692 m
1 .82692 L
s
.99625 .86538 m
1 .86538 L
s
.99625 .90385 m
1 .90385 L
s
.99625 .94231 m
1 .94231 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.6 g
.49019 .54784 m
.50278 .54906 L
.50981 .55047 L
.52943 .55513 L
.54906 .55987 L
.56868 .56224 L
.5883 .5684 L
.58974 .56868 L
.60793 .57245 L
.62755 .57574 L
.64717 .57823 L
.6668 .57446 L
.68642 .5768 L
.70604 .57728 L
.72567 .57608 L
.74529 .57271 L
.76491 .57728 L
.78454 .57446 L
.80416 .57083 L
.81372 .56868 L
.82378 .56631 L
.84341 .55776 L
.86303 .5579 L
.88265 .55312 L
.90094 .54906 L
.90228 .54859 L
.9219 .54858 L
.92345 .54906 L
.9219 .56244 L
.91719 .56868 L
.90228 .58064 L
.89092 .5883 L
.88265 .59522 L
.86303 .60374 L
.85389 .60793 L
.84341 .61183 L
.82378 .62081 L
.80416 .62635 L
.79977 .62755 L
.78454 .62931 L
.76491 .63373 L
.74529 .63735 L
.72567 .63965 L
.70604 .64058 L
.68642 .6402 L
.6668 .63848 L
.64717 .6354 L
.62755 .63117 L
.60793 .62868 L
.60409 .62755 L
.5883 .62432 L
.56868 .61558 L
.54987 .60793 L
.54906 .60756 L
.52943 .60533 L
.51283 .5883 L
.50981 .58633 L
.49019 .57181 L
.48677 .56868 L
.48048 .54906 L
F
0 g
.49019 .54784 m
.50278 .54906 L
.50981 .55047 L
.52943 .55513 L
.54906 .55987 L
.56868 .56224 L
.5883 .5684 L
.58974 .56868 L
.60793 .57245 L
.62755 .57574 L
.64717 .57823 L
.6668 .57446 L
.68642 .5768 L
.70604 .57728 L
.72567 .57608 L
.74529 .57271 L
.76491 .57728 L
.78454 .57446 L
.80416 .57083 L
.81372 .56868 L
.82378 .56631 L
.84341 .55776 L
.86303 .5579 L
.88265 .55312 L
.90094 .54906 L
.90228 .54859 L
.9219 .54858 L
.92345 .54906 L
.9219 .56244 L
.91719 .56868 L
.90228 .58064 L
.89092 .5883 L
.88265 .59522 L
.86303 .60374 L
.85389 .60793 L
.84341 .61183 L
.82378 .62081 L
.80416 .62635 L
.79977 .62755 L
.78454 .62931 L
.76491 .63373 L
.74529 .63735 L
.72567 .63965 L
.70604 .64058 L
.68642 .6402 L
.6668 .63848 L
.64717 .6354 L
.62755 .63117 L
.60793 .62868 L
.60409 .62755 L
Mistroke
.5883 .62432 L
.56868 .61558 L
.54987 .60793 L
.54906 .60756 L
.52943 .60533 L
.51283 .5883 L
.50981 .58633 L
.49019 .57181 L
.48677 .56868 L
.48048 .54906 L
.49019 .54784 L
Mfstroke
.4 g
.49019 .49021 m
.50981 .49164 L
.52943 .49511 L
.54906 .49894 L
.56868 .50188 L
.5883 .50943 L
.60793 .50968 L
.60879 .50981 L
.62755 .51258 L
.64717 .51479 L
.6668 .51632 L
.68642 .5121 L
.70604 .51266 L
.72567 .51125 L
.74529 .51576 L
.76491 .51394 L
.78454 .51144 L
.79492 .50981 L
.80416 .50832 L
.82378 .50646 L
.84341 .49741 L
.86303 .49733 L
.88265 .49356 L
.90228 .49057 L
.91779 .50981 L
.90228 .52127 L
.88912 .52943 L
.88265 .53474 L
.86303 .54197 L
.84518 .54906 L
.84341 .54932 L
.82378 .55631 L
.80416 .56482 L
.78454 .566 L
.76979 .56868 L
.76491 .56949 L
.74529 .56897 L
.72567 .57078 L
.70604 .57162 L
.68642 .57128 L
.6668 .56981 L
.64717 .57073 L
.634 .56868 L
.62755 .56756 L
.60793 .5636 L
.5883 .55982 L
.56868 .55175 L
.55873 .54906 L
.54906 .54535 L
.52943 .54466 L
.51458 .52943 L
.50981 .52657 L
.49019 .5132 L
.48615 .50981 L
F
0 g
.49019 .49021 m
.50981 .49164 L
.52943 .49511 L
.54906 .49894 L
.56868 .50188 L
.5883 .50943 L
.60793 .50968 L
.60879 .50981 L
.62755 .51258 L
.64717 .51479 L
.6668 .51632 L
.68642 .5121 L
.70604 .51266 L
.72567 .51125 L
.74529 .51576 L
.76491 .51394 L
.78454 .51144 L
.79492 .50981 L
.80416 .50832 L
.82378 .50646 L
.84341 .49741 L
.86303 .49733 L
.88265 .49356 L
.90228 .49057 L
.91779 .50981 L
.90228 .52127 L
.88912 .52943 L
.88265 .53474 L
.86303 .54197 L
.84518 .54906 L
.84341 .54932 L
.82378 .55631 L
.80416 .56482 L
.78454 .566 L
.76979 .56868 L
.76491 .56949 L
.74529 .56897 L
.72567 .57078 L
.70604 .57162 L
.68642 .57128 L
.6668 .56981 L
.64717 .57073 L
.634 .56868 L
.62755 .56756 L
.60793 .5636 L
.5883 .55982 L
.56868 .55175 L
.55873 .54906 L
.54906 .54535 L
.52943 .54466 L
Mistroke
.51458 .52943 L
.50981 .52657 L
.49019 .5132 L
.48615 .50981 L
.49019 .49021 L
Mfstroke
.6 g
.50981 .44614 m
.52943 .44548 L
.54906 .44883 L
.56868 .45013 L
.57473 .45094 L
.5883 .45302 L
.60793 .45557 L
.62755 .45772 L
.64717 .45854 L
.6668 .46258 L
.68642 .46491 L
.70604 .46546 L
.72567 .46413 L
.74529 .46112 L
.76491 .45603 L
.78454 .45687 L
.80416 .45455 L
.82378 .45185 L
.82733 .45094 L
.84341 .4489 L
.86303 .44432 L
.88265 .44524 L
.90228 .44956 L
.9035 .45094 L
.90228 .45423 L
.88621 .47057 L
.88265 .47255 L
.86303 .48171 L
.84341 .48973 L
.84218 .49019 L
.82378 .49928 L
.80416 .50065 L
.78454 .50468 L
.76491 .50793 L
.75056 .50981 L
.74529 .51033 L
.72567 .51023 L
.70604 .51082 L
.68642 .51056 L
.6668 .51105 L
.65301 .50981 L
.64717 .50905 L
.62755 .50614 L
.60793 .50244 L
.5883 .5059 L
.56868 .49297 L
.56181 .49019 L
.54906 .48518 L
.52943 .47661 L
.51762 .47057 L
.50981 .46407 L
.49976 .45094 L
F
0 g
.50981 .44614 m
.52943 .44548 L
.54906 .44883 L
.56868 .45013 L
.57473 .45094 L
.5883 .45302 L
.60793 .45557 L
.62755 .45772 L
.64717 .45854 L
.6668 .46258 L
.68642 .46491 L
.70604 .46546 L
.72567 .46413 L
.74529 .46112 L
.76491 .45603 L
.78454 .45687 L
.80416 .45455 L
.82378 .45185 L
.82733 .45094 L
.84341 .4489 L
.86303 .44432 L
.88265 .44524 L
.90228 .44956 L
.9035 .45094 L
.90228 .45423 L
.88621 .47057 L
.88265 .47255 L
.86303 .48171 L
.84341 .48973 L
.84218 .49019 L
.82378 .49928 L
.80416 .50065 L
.78454 .50468 L
.76491 .50793 L
.75056 .50981 L
.74529 .51033 L
.72567 .51023 L
.70604 .51082 L
.68642 .51056 L
.6668 .51105 L
.65301 .50981 L
.64717 .50905 L
.62755 .50614 L
.60793 .50244 L
.5883 .5059 L
.56868 .49297 L
.56181 .49019 L
.54906 .48518 L
.52943 .47661 L
.51762 .47057 L
Mistroke
.50981 .46407 L
.49976 .45094 L
.50981 .44614 L
Mfstroke
.4 g
.54906 .40813 m
.56868 .40676 L
.5883 .40747 L
.60793 .40871 L
.62755 .41017 L
.64717 .41151 L
.65005 .4117 L
.6668 .41243 L
.68642 .41295 L
.70604 .41307 L
.72567 .41278 L
.74529 .4121 L
.75374 .4117 L
.76491 .41098 L
.78454 .40956 L
.80416 .40812 L
.82378 .40701 L
.84341 .40692 L
.86303 .411 L
.86399 .4117 L
.86303 .41528 L
.84351 .43132 L
.84341 .43136 L
.82378 .43782 L
.80416 .44318 L
.78454 .44772 L
.76746 .45094 L
.76491 .45129 L
.74529 .4547 L
.72567 .45775 L
.70604 .45927 L
.68642 .45863 L
.6668 .4561 L
.64717 .45266 L
.6363 .45094 L
.62755 .44936 L
.60793 .44519 L
.5883 .44017 L
.56868 .43425 L
.56041 .43132 L
.54906 .42388 L
.53953 .4117 L
F
0 g
.54906 .40813 m
.56868 .40676 L
.5883 .40747 L
.60793 .40871 L
.62755 .41017 L
.64717 .41151 L
.65005 .4117 L
.6668 .41243 L
.68642 .41295 L
.70604 .41307 L
.72567 .41278 L
.74529 .4121 L
.75374 .4117 L
.76491 .41098 L
.78454 .40956 L
.80416 .40812 L
.82378 .40701 L
.84341 .40692 L
.86303 .411 L
.86399 .4117 L
.86303 .41528 L
.84351 .43132 L
.84341 .43136 L
.82378 .43782 L
.80416 .44318 L
.78454 .44772 L
.76746 .45094 L
.76491 .45129 L
.74529 .4547 L
.72567 .45775 L
.70604 .45927 L
.68642 .45863 L
.6668 .4561 L
.64717 .45266 L
.6363 .45094 L
.62755 .44936 L
.60793 .44519 L
.5883 .44017 L
.56868 .43425 L
.56041 .43132 L
.54906 .42388 L
.53953 .4117 L
.54906 .40813 L
s
.3 g
.56868 .51505 m
.5883 .5159 L
.60793 .51752 L
.62755 .51919 L
.64717 .52062 L
.6668 .52168 L
.68642 .51616 L
.70604 .51681 L
.72567 .51511 L
.74529 .52128 L
.76491 .52005 L
.78454 .5185 L
.80416 .51681 L
.82378 .51537 L
.84341 .51549 L
.85173 .52943 L
.84341 .53496 L
.82378 .54502 L
.81441 .54906 L
.80416 .55545 L
.78454 .5581 L
.76491 .56226 L
.74529 .56525 L
.72567 .56715 L
.70604 .56793 L
.68642 .56761 L
.6668 .56618 L
.64717 .56365 L
.62755 .56 L
.60793 .5551 L
.58944 .54906 L
.5883 .54859 L
.56868 .53952 L
.55211 .52943 L
F
0 g
.56868 .51505 m
.5883 .5159 L
.60793 .51752 L
.62755 .51919 L
.64717 .52062 L
.6668 .52168 L
.68642 .51616 L
.70604 .51681 L
.72567 .51511 L
.74529 .52128 L
.76491 .52005 L
.78454 .5185 L
.80416 .51681 L
.82378 .51537 L
.84341 .51549 L
.85173 .52943 L
.84341 .53496 L
.82378 .54502 L
.81441 .54906 L
.80416 .55545 L
.78454 .5581 L
.76491 .56226 L
.74529 .56525 L
.72567 .56715 L
.70604 .56793 L
.68642 .56761 L
.6668 .56618 L
.64717 .56365 L
.62755 .56 L
.60793 .5551 L
.58944 .54906 L
.5883 .54859 L
.56868 .53952 L
.55211 .52943 L
.56868 .51505 L
s
.7 g
.56868 .46989 m
.5883 .46529 L
.60793 .46505 L
.62755 .46565 L
.64717 .46427 L
.6668 .46698 L
.68642 .46821 L
.70604 .46848 L
.72567 .46782 L
.74529 .46609 L
.76491 .46219 L
.78454 .46535 L
.80416 .46498 L
.82378 .4661 L
.83617 .47057 L
.82378 .48242 L
.80937 .49019 L
.80416 .49192 L
.78454 .4973 L
.76491 .50136 L
.74529 .5043 L
.72567 .50616 L
.70604 .50694 L
.68642 .50662 L
.6668 .50522 L
.64717 .50273 L
.62755 .49915 L
.60793 .49437 L
.59447 .49019 L
.5883 .48717 L
.56868 .47245 L
.56793 .47057 L
F
0 g
.56868 .46989 m
.5883 .46529 L
.60793 .46505 L
.62755 .46565 L
.64717 .46427 L
.6668 .46698 L
.68642 .46821 L
.70604 .46848 L
.72567 .46782 L
.74529 .46609 L
.76491 .46219 L
.78454 .46535 L
.80416 .46498 L
.82378 .4661 L
.83617 .47057 L
.82378 .48242 L
.80937 .49019 L
.80416 .49192 L
.78454 .4973 L
.76491 .50136 L
.74529 .5043 L
.72567 .50616 L
.70604 .50694 L
.68642 .50662 L
.6668 .50522 L
.64717 .50273 L
.62755 .49915 L
.60793 .49437 L
.59447 .49019 L
.5883 .48717 L
.56868 .47245 L
.56793 .47057 L
.56868 .46989 L
s
.7 g
.5883 .58394 m
.60793 .58443 L
.62755 .58573 L
.64717 .58705 L
.6668 .58784 L
.67239 .5883 L
.68642 .5888 L
.70604 .58897 L
.72567 .58855 L
.73272 .5883 L
.74529 .58691 L
.76491 .58652 L
.78454 .58516 L
.80416 .58403 L
.82378 .58472 L
.83197 .5883 L
.82378 .59632 L
.80416 .60752 L
.8033 .60793 L
.78454 .61479 L
.76491 .61996 L
.74529 .62359 L
.72567 .62585 L
.70604 .62679 L
.68642 .6264 L
.6668 .6247 L
.64717 .62166 L
.62755 .61717 L
.60793 .6109 L
.60051 .60793 L
.5883 .60161 L
.57111 .5883 L
F
0 g
.5883 .58394 m
.60793 .58443 L
.62755 .58573 L
.64717 .58705 L
.6668 .58784 L
.67239 .5883 L
.68642 .5888 L
.70604 .58897 L
.72567 .58855 L
.73272 .5883 L
.74529 .58691 L
.76491 .58652 L
.78454 .58516 L
.80416 .58403 L
.82378 .58472 L
.83197 .5883 L
.82378 .59632 L
.80416 .60752 L
.8033 .60793 L
.78454 .61479 L
.76491 .61996 L
.74529 .62359 L
.72567 .62585 L
.70604 .62679 L
.68642 .6264 L
.6668 .6247 L
.64717 .62166 L
.62755 .61717 L
.60793 .6109 L
.60051 .60793 L
.5883 .60161 L
.57111 .5883 L
.5883 .58394 L
s
.4 g
.5883 .65207 m
.60793 .65548 L
.62755 .65858 L
.64717 .66102 L
.6668 .66273 L
.68642 .6637 L
.70604 .66391 L
.72567 .66338 L
.74529 .6621 L
.76491 .66008 L
.78454 .65735 L
.80416 .65405 L
.82349 .6668 L
.80416 .6753 L
.78454 .68153 L
.76491 .6862 L
.76393 .68642 L
.74529 .68983 L
.72567 .69203 L
.70604 .69293 L
.68642 .69256 L
.6668 .69092 L
.64717 .68965 L
.63977 .68642 L
.62755 .68365 L
.60793 .67814 L
.5883 .67067 L
.57994 .6668 L
F
0 g
.5883 .65207 m
.60793 .65548 L
.62755 .65858 L
.64717 .66102 L
.6668 .66273 L
.68642 .6637 L
.70604 .66391 L
.72567 .66338 L
.74529 .6621 L
.76491 .66008 L
.78454 .65735 L
.80416 .65405 L
.82349 .6668 L
.80416 .6753 L
.78454 .68153 L
.76491 .6862 L
.76393 .68642 L
.74529 .68983 L
.72567 .69203 L
.70604 .69293 L
.68642 .69256 L
.6668 .69092 L
.64717 .68965 L
.63977 .68642 L
.62755 .68365 L
.60793 .67814 L
.5883 .67067 L
.57994 .6668 L
.5883 .65207 L
s
.2 g
.60793 .52793 m
.62755 .52705 L
.64717 .52726 L
.6668 .52766 L
.68642 .52601 L
.70604 .5263 L
.72567 .52553 L
.74529 .52749 L
.76491 .52712 L
.78454 .52719 L
.80415 .52943 L
.78454 .54839 L
.78299 .54906 L
.76491 .55411 L
.74529 .55784 L
.72567 .56011 L
.70604 .56105 L
.68642 .56067 L
.6668 .55896 L
.64717 .55587 L
.62755 .55114 L
.62083 .54906 L
.60793 .54262 L
.59877 .52943 L
F
0 g
.60793 .52793 m
.62755 .52705 L
.64717 .52726 L
.6668 .52766 L
.68642 .52601 L
.70604 .5263 L
.72567 .52553 L
.74529 .52749 L
.76491 .52712 L
.78454 .52719 L
.80415 .52943 L
.78454 .54839 L
.78299 .54906 L
.76491 .55411 L
.74529 .55784 L
.72567 .56011 L
.70604 .56105 L
.68642 .56067 L
.6668 .55896 L
.64717 .55587 L
.62755 .55114 L
.62083 .54906 L
.60793 .54262 L
.59877 .52943 L
.60793 .52793 L
s
.3 g
.62755 .42953 m
.64717 .42562 L
.6668 .42462 L
.68642 .42428 L
.70604 .42422 L
.72567 .42438 L
.74529 .42491 L
.76491 .42654 L
.77871 .43132 L
.76491 .43754 L
.74529 .44255 L
.72567 .4454 L
.70604 .44654 L
.68642 .44608 L
.6668 .44397 L
.64717 .43997 L
.62755 .43279 L
.62525 .43132 L
F
0 g
.62755 .42953 m
.64717 .42562 L
.6668 .42462 L
.68642 .42428 L
.70604 .42422 L
.72567 .42438 L
.74529 .42491 L
.76491 .42654 L
.77871 .43132 L
.76491 .43754 L
.74529 .44255 L
.72567 .4454 L
.70604 .44654 L
.68642 .44608 L
.6668 .44397 L
.64717 .43997 L
.62755 .43279 L
.62525 .43132 L
.62755 .42953 L
s
.6 g
.62755 .37451 m
.64717 .37348 L
.6668 .37326 L
.68642 .37324 L
.70604 .37325 L
.72567 .37324 L
.74529 .37331 L
.76491 .37375 L
.77816 .39207 L
.76491 .39442 L
.74529 .39701 L
.72567 .39863 L
.70604 .39931 L
.68642 .39903 L
.6668 .39781 L
.64717 .39563 L
.62755 .39242 L
.62575 .39207 L
F
0 g
.62755 .37451 m
.64717 .37348 L
.6668 .37326 L
.68642 .37324 L
.70604 .37325 L
.72567 .37324 L
.74529 .37331 L
.76491 .37375 L
.77816 .39207 L
.76491 .39442 L
.74529 .39701 L
.72567 .39863 L
.70604 .39931 L
.68642 .39903 L
.6668 .39781 L
.64717 .39563 L
.62755 .39242 L
.62575 .39207 L
.62755 .37451 L
s
.8 g
.64717 .47572 m
.6668 .47513 L
.68642 .47501 L
.70604 .475 L
.72567 .47504 L
.74529 .47528 L
.76491 .47637 L
.77464 .49019 L
.76491 .49294 L
.74529 .49694 L
.72567 .49932 L
.70604 .50029 L
.68642 .4999 L
.6668 .49812 L
.64717 .49484 L
.62928 .49019 L
F
0 g
.64717 .47572 m
.6668 .47513 L
.68642 .47501 L
.70604 .475 L
.72567 .47504 L
.74529 .47528 L
.76491 .47637 L
.77464 .49019 L
.76491 .49294 L
.74529 .49694 L
.72567 .49932 L
.70604 .50029 L
.68642 .4999 L
.6668 .49812 L
.64717 .49484 L
.62928 .49019 L
.64717 .47572 L
s
.1 g
.68642 .53793 m
.70604 .53768 L
.72567 .53836 L
.73737 .54906 L
.72567 .55056 L
.70604 .55196 L
.68642 .5514 L
.66867 .54906 L
F
0 g
.68642 .53793 m
.70604 .53768 L
.72567 .53836 L
.73737 .54906 L
.72567 .55056 L
.70604 .55196 L
.68642 .5514 L
.66867 .54906 L
.68642 .53793 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00?Oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0dooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kS?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0hooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8b
onk^kS?ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08_ooool003gooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0=_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0<oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg03?ooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL08_ooool003Gooooo1_l0
0003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400[ooooo`Ko0000
1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100<oooool01Ol@413o
oooooooooooooooo410@03[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@03Cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@02;ooooo000o
ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000fooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000cooooo`05o`000?ooooooooooooooool0
0000>_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000=Oooool00onH
V9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000008_ooool0043ooooo00?oMgMgofIV
I_ooool00_ooool01Ol0003ooooooooooooooooo000003Kooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000003?ooooo00Go0000ooooooooooooooooo`00000jooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`03ogMgMomVIVKooooo00;o
oooo00Go0000ooooooooooooooooo`00000Rooooo`00@Oooool01Ol0003ooooooooooooooooo410@
00?ooooo00?o410@ooooooooool0=?ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@4100<oooool01Ol@413ooooooooooooooooo410@03[ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@03Oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo023ooooo000mooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg03Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg03?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0jooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0cooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02;ooooo000mooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^03Cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^03?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`03oeEEEOmVIVKo000000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0cooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02;ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo000Joooooooo0000C_l00001ooooo`00
6_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0?Ooo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool08ooo
ool1o`00007ooooo0008ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKo
oooo00?o0000ooooooooool0oooooom:ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooom:ooooo`7o
00000Oooool000Go00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41001_ooool00ol0003oooooooooo`3ooooood[ooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?ooooooB?ooool3o`00007o
oooo000:ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo0008ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Oooooooogmo
Od3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Ooo
ooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000oooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`003ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000?ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000oooooo00Go0000oooooooooooooooo
o`000006ooooo`?o00001?ooooooogmoOd3oOgmo1?ooool3o`00007ooooo000?ooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool000oooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`003oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000?ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooo:ogmoObko0000AomoOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?ooooo:ogmoO`03o`000?nIVIWoVIVI02[oVIVI00?o0000ogmoOomoOgl0AOmo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooo:ogmoO`03o`000?nIVIWo
VIVI02_oVIVI00?o0000ogmoOomoOgl0A?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?ooooo:ogmoO`03o`000?nIVIWoVIVI02coVIVI00?o0000ogmoOomoOgl0@omoOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooo9ogmoO`03o`000?nIVIWoVIVI02ko
VIVI00?o0000ogmoOomoOgl0@_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?ooooo9ogmoO`03o`000?nIVIWoVIVI02ooVIVI00?o0000ogmoOomoOgl0@OmoOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooo9ogmoO`Go0000;?nIVIT3o`0004;oOgmo1_oo
ool1o`00007ooooo0008ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKo
oooo00?o0000ooooooooool01?ooooo>ogmoO`Oo00006OnIVIT<o`0004GoOgmo1_ooool1o`00007o
oooo000:ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03
o`000?oooooooooo00CoooooeOmoOglIo`00057oOgmo1_ooool1o`00007ooooo000:ooooo`03o`00
0?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00Co
oooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000001_ooool3o`0000CooooooomoOgm0ogmoO`Cooooo0ol00001ooooo`00
2_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`04ooooojkoOgmo6_l0000iogmoOaGo0000:OmoOgl6ooooo`7o00000Oooool000[ooooo
00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000oooooooo
ool01?oooon/ogmoO`;o00006_mVIVH=o`0001WoOgmo4ol0000EofIVIP?o00009_moOgl6ooooo`7o
00000Oooool000[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Ko
oooo00?o0000ooooooooool01?oooon]ogmoO`03o`000?mVIVKoIVIV02GoIVIV6Ol0000ZofIVIP03
o`000?moOgooOgmo02CoOgmo1_ooool1o`00007ooooo0008ooooo`03oeEEEOmVIVKo000000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo00Cooooo[_moOgl00ol0003o
IVIVofIVIP1VofIVIP;o00009_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?oooon_ogmoO`03o`000?mVIVKoIVIV06CoIVIV00?o0000ogmoOomoOgl09_moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?oooon`ogmoO`03o`000?mVIVKoIVIV067oIVIV0_l0
000YogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooook7oOgmo00?o0000
ofIVI_mVIVH06OmVIVH/o`0001[oIVIV00?o0000ogmoOomoOgl0:OmoOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?oooonbogmoO`03o`000?mVIVKoIVIV01GoIVIV0ol0000/oda<
C0?o00005_mVIVH00ol0003oOgmoogmoO`0ZogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04oooook?oOgmo0ol0000CofIVIP?o0000;om<C4`2o`0001?oIVIV0ol0000/ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooookKoOgmo0ol0000CofIVIP;o0000
:_m<C4`3o`0001;oIVIV0ol0000_ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04oooookWoOgmo0ol0000BofIVIP;o00009_m<C4`2o`00017oIVIV1?l0000bogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04oooookcoOgmo1Ol0000?ofIVIPGo00007_m<C4`3
o`00013oIVIV0ol0000fogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000Gooooo`OmoOgl5o`00
00ooIVIV1_l0000Coda<C0Go00003_mVIVH5o`00013oOgmo1_l0000SogmoO`Gooooo0_l00001oooo
o`006_ooool00ol0003oooooooooo`04oooooj7oOgmo3Ol0000HogmoO`?o00004_mVIVHCo`0000go
IVIV1_l0000BogmoO`?o00001_nIVIT7o`0001coOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CoooooWomoOgl2o`0000goVIVI3_l0000=ogmoO`Oo0000:?mVIVH3o`00017oOgmo
1ol0000@oiVIV@?o00006OmoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
oonOogmoO`03o`000?nIVIWoVIVI01[oVIVI1Ol0000?ogmoO`Go00007omVIVH4o`00013oOgmo1?l0
000IoiVIV@03o`000?moOgooOgmo01OoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CoooooX?moOgl00ol0003oVIVIoiVIV@0NoiVIV@Oo00003OmoOgl6o`0001?oIVIV1_l00002
ogmoOa;o00007OnIVIT00ol0003oOgmoogmoO`0GogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04oooooj7oOgmo00?o0000oiVIVOnIVIT09?nIVIT=o`0000KoOgmo4ol00005ogmo
O`?o0000;_nIVIT00ol0003oOgmoogmoO`0HogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04oooooj;oOgmo00?o0000oiVIVOnIVIT0<?nIVIT6o`0001?oOgmo1Ol000000onIVIWo
0000o`000006o`0002OoVIVI00?o0000ogmoOomoOgl06OmoOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?oooonSogmoO`03o`000?nIVIWoVIVI01GoVIVI6_l00006oiVIVAWo0000
2?nc/k<Ao`0001GoVIVI00?o0000ogmoOomoOgl06_moOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?oooonTogmoO`03o`000?nIVIWoVIVI017oVIVI0ol0000Jok>c/aWo00007onc
/k<2o`0001;oVIVI00?o0000ogmoOomoOgl06omoOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?oooonUogmoO`;o00003onIVIT2o`0005Oo/k>c00?o0000oiVIVOnIVIT03OnIVIT2
o`0001koOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooYomoOgl2o`00
00goVIVI0_l0000Lok>c/b7o00006Onc/k<00ol0003oVIVIoiVIV@0<oiVIV@;o00008?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonYogmoO`;o00003OnIVIT2o`0001Go
/k>c1Ol0000Qolc<c0?o00005Onc/k<00ol0003oVIVIoiVIV@0;oiVIV@;o00008_moOgl6ooooo`7o
00000Oooool001[ooooo0_l00005oooooj_oOgmo0ol0000<oiVIV@03o`000?nc/k?o/k>c017o/k>c
00?o0000olc<c?o<c<`09_o<c<`00ol0003o/k>cok>c/`0Bok>c/`03o`000?nIVIWoVIVI00[oVIVI
0_l0000TogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04ooooojkoOgmo0_l0
000;oiVIV@;o00003onc/k<2o`0002[oc<c<00?o0000ok>c/onc/k<03onc/k<2o`0000[oVIVI0ol0
000VogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooook3oOgmo0ol0000:
oiVIV@;o00003?nc/k<00ol0003oc<c<olc<c00[olc<c003o`000?nc/k?o/k>c00_o/k>c0ol00009
oiVIV@?o0000:OmoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonLogmo
O`Go00004_moOgl3o`0000WoVIVI0_l00009ok>c/`?o0000;?o<c<`2o`0000[o/k>c0_l00009oiVI
V@?o0000;?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonLogmoO`03
o`000?mVIVKoIVIV00;oIVIV1_l0000?ogmoO`;o00002OnIVIT2o`0000[o/k>c0ol0000Volc<c0?o
00002_nc/k<2o`0000WoVIVI0_l0000BogmoO`Co00006OmoOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?oooonLogmoO`03o`000?mVIVKoIVIV00SoIVIV1ol0000:ogmoO`03o`00
0?nIVIWoVIVI00SoVIVI1Ol00008ok>c/`Go00007_o<c<`3o`0000[o/k>c0ol00009oiVIV@;o0000
3OmoOgl7o`0000?oIVIV00?o0000ogmoOomoOgl05omoOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?oooonLogmoO`03o`000?mVIVKoIVIV00ooIVIV1_l00005ogmoO`;o00003OnI
VIT5o`0000So/k>c1_l0000<olc<c0co00002?nc/k<5o`0000SoVIVI1?l00004ogmoO`_o00002omV
IVH00ol0003oOgmoogmoO`0FogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
oooooi_oOgmo00?o0000ofIVI_mVIVH05_mVIVH4o`0000?oOgmo00?o0000oiVIVOnIVIT03onIVIT3
o`0000_o/k>c3?l0000=ok>c/`Oo00001_nIVIT7o`0000KoOgmo0_l0000GofIVIP03o`000?moOgoo
Ogmo01GoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooVomoOgl00ol0
003oIVIVofIVIP0JofIVIP?o000000?oOgmoo`000?nIVIT00_nIVIT8o`0000SoVIVI2ol0000Cok>c
/`Ko00001onIVIT6o`0000_oOgmo0_l0000JofIVIP03o`000?moOgooOgmo01CoOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CoooooVomoOgl00ol0003oIVIVofIVIP0MofIVIPGo
00002?moOgl6o`0000goVIVI4ol00007oiVIV@Ko00002?moOgl9o`0001goIVIV00?o0000ogmoOomo
Ogl04omoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonKogmoO`03o`00
0?mVIVKoIVIV01ooIVIV2ol00006ogmoObOo00001_moOgl8o`0002KoIVIV0_l0000DogmoO`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooicoOgmo0_l0000ZofIVIPKo00003?mo
Ogl=o`0000KoIVIV0ol00004ogmoO`Oo0000;OmVIVH00ol0003oOgmoogmoO`0DogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04oooooikoOgmo00?o0000ofIVI_mVIVH05?mVIVH<
o`0000goIVIV3?l00002ofIVIQ7o00000omVIVH4o`0000goIVIV4Ol0000EofIVIP03o`000?moOgoo
Ogmo01GoOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OoooonOogmoO`;o00004omVIVH00ol0
003oC4a<oda<C00:oda<C0go00002omVIVH3o`00017oC4a<0ol00004ofIVIPgo00004?m<C4`00ol0
003oIVIVofIVIP0BofIVIP03o`000?moOgooOgmo01KoOgmo1Oooool2o`00007ooooo000Jooooo`03
o`000?oooooooooo00CoooooXOmoOgl00ol0003oIVIVofIVIP0?ofIVIP03o`000?m<C4coC4a<01So
C4a<2ol0000Goda<C0Co00007_m<C4`00ol0003oIVIVofIVIP0?ofIVIP;o00006OmoOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?oooonRogmoO`03o`000?mVIVKoIVIV00goIVIV
00?o0000oda<C?m<C4`09Om<C4`Eo`0002CoC4a<00?o0000ofIVI_mVIVH03?mVIVH2o`0001_oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooXomoOgl2o`0000coIVIV0_l0
000=oda<C1[o00005Olc<c<Fo`0000koC4a<0_l0000;ofIVIP;o00007OmoOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?oooonTogmoO`03o`000?mVIVKoIVIV00coIVIV00?o0000
oda<C?m<C4`02_m<C4`00ol0003o<c<coc<c<`11oc<c<`03o`000?m<C4coC4a<00_oC4a<00?o0000
ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`0MogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooojGoOgmo00?o0000ofIVI_mVIVH03?mVIVH00ol0003oC4a<oda<C00:oda<
C003o`000?lc<c?o<c<c03oo<c<c00?o0000oda<C?m<C4`02_m<C4`2o`0000_oIVIV0_l0000Pogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooojKoOgmo00?o0000ofIVI_mV
IVH03?mVIVH00ol0003oC4a<oda<C00:oda<C003o`000?lc<c?o<c<c01Oo<c<c3ol0000Goc<c<`03
o`000?m<C4coC4a<00[oC4a<00?o0000ofIVI_mVIVH02OmVIVH2o`0002;oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CoooooYomoOgl00ol0003oIVIVofIVIP0<ofIVIP;o0000
2_m<C4`00ol0003o<c<coc<c<`0Foc<c<`03o`000?lI6AWo6ATI00go6ATI00?o0000oc<c<olc<c<0
4olc<c<00ol0003oC4a<oda<C009oda<C0;o00002_mVIVH2o`0002CoOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CoooooZ?moOgl00ol0003oIVIVofIVIP0=ofIVIP?o00002?m<
C4`2o`0001Co<c<c0_l0000AoaTI6@03o`000?lc<c?o<c<c017o<c<c00?o0000oda<C?m<C4`02Om<
C4`00ol0003oIVIVofIVIP08ofIVIP;o00009_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?oooonYogmoO`[o00002?mVIVH2o`0000SoC4a<0_l0000Aoc<c<`03o`000?lI6AWo
6ATI01;o6ATI00?o0000oc<c<olc<c<03olc<c<00ol0003oC4a<oda<C008oda<C0;o00002?mVIVH3
o`0002SoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooVOmoOgl=o`00
00goOgmo0ol00007ofIVIP?o00001om<C4`3o`0000go<c<c1?l0000<oaTI6@So00003Olc<c<3o`00
00SoC4a<0ol00006ofIVIPCo00003OmoOgl<o`0001;oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CoooooVOmoOgl00ol0003oVIVIoiVIV@0:oiVIV@?o00003OmoOgl2o`0000So
IVIV0ol00007oda<C0Co00003Olc<c<<o`0001;o<c<c0ol00009oda<C0;o00001_mVIVH3o`0000go
Ogmo1?l0000;oiVIV@03o`000?moOgooOgmo013oOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CoooooVOmoOgl00ol0003oVIVIoiVIV@0=oiVIV@?o00003?moOgl3o`0000SoIVIV
0ol00008oda<C0Oo00007olc<c<5o`0000SoC4a<1?l00005ofIVIP?o00003OmoOgl3o`0000ooVIVI
00?o0000ogmoOomoOgl04?moOgl6ooooo`7o00000Oooool001[ooooo0_l00005oooooi[oOgmo00?o
0000oiVIVOnIVIT03onIVIT3o`0000coOgmo0_l00009ofIVIP?o00003?m<C4`6o`0001?o<c<c1_l0
0007oda<C0Ko00001_mVIVH3o`0000KoOgmo2_l0000AoiVIV@03o`000?moOgooOgmo017oOgmo1Ooo
ool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooV_moOgl00ol0003oVIVIoiVIV@0B
oiVIV@[o00001?moOgl4o`0000SoIVIV1Ol0000=oda<C1?o00001_m<C4`7o`0000[oIVIV0_l00007
ogmoO`;o00006onIVIT00ol0003oOgmoogmoO`0AogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04oooooi[oOgmo00?o0000oiVIVOnIVIT07?nIVIT3o`0000GoOgmo1ol00006ofIV
IPOo00006Om<C4`6o`0000goIVIV1?l00007ogmoO`;o00007OnIVIT00ol0003oOgmoogmoO`0Aogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooi_oOgmo00?o0000oiVIVOnI
VIT07_nIVIT2o`0000[oOgmo1?l00009ofIVIQWo00003_mVIVH5o`0000SoOgmo0ol0000NoiVIV@03
o`000?moOgooOgmo01;oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
VomoOgl00ol0003oVIVIoiVIV@0OoiVIV@Co00002omoOgl`o`0000GoOgmo2?l0000PoiVIV@;o0000
5?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonLogmoO`;o00008onI
VIT7o`0000goOgmo1_l0000CogmoO`Oo00001_moOgl6o`0002KoVIVI0_l0000FogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04oooooikoOgmo0_l0000XoiVIV@Ko00001?moOgl3
o`0000KoVIVI4ol00007oiVIV@Ko0000:onIVIT00ol0003oOgmoogmoO`0FogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04oooooj3oOgmo00?o0000oiVIVOnIVIT0:onIVIT4o`00
05;oVIVI0_l0000IogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooj7o
Ogmo0_l00020oiVIV@03o`000?moOgooOgmo01WoOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CoooooXomoOgl00ol0003oVIVIoiVIV@0DoiVIVACo00009_nIVITJo`0001CoVIVI
00?o0000ogmoOomoOgl06_moOgl6ooooo`7o00000Oooool000Oooooo1Ol00003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`04ooooojCoOgmo00?o0000oiVIVOnIVIT0
4?nIVIT3o`0001Co/k>c9_l0000Jok>c/`03o`000?nIVIWoVIVI00ooVIVI0_l0000MogmoO`Kooooo
0Ol00001ooooo`001oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`06ooooo`03o`000?oooooooooo00CoooooY?moOgl00ol0003oVIVIoiVIV@0BoiVIV@03
o`000?nc/k?o/k>c057o/k>c00?o0000oiVIVOnIVIT03onIVIT00ol0003oOgmoogmoO`0MogmoO`Ko
oooo0Ol00001ooooo`002?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@
41001_ooool00ol0003oooooooooo`04ooooojGoOgmo00?o0000oiVIVOnIVIT04_nIVIT2o`00053o
/k>c00?o0000oiVIVOnIVIT03_nIVIT2o`00023oOgmo1_ooool1o`00007ooooo0009ooooo`03oiRH
V?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000006ooooo`?o00001?oooonVogmoO`03
o`000?nIVIWoVIVI01?oVIVI00?o0000ok>c/onc/k<0Bonc/k<2o`0000ooVIVI0_l0000RogmoO`Co
oooo0ol00001ooooo`002_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool0
00001_ooool00ol0003oooooooooo`04ooooojOoOgmo00?o0000oiVIVOnIVIT04onIVIT2o`0004So
/k>c0ol0000?oiVIV@;o00009?moOgl6ooooo`7o00000Oooool000_ooooo00Go0000oooooooooooo
oooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o0000ooooooooool01?oooonXogmoO`03
o`000?nIVIWoVIVI01CoVIVI00?o0000ok>c/onc/k<0@onc/k<2o`00013oVIVI0_l0000VogmoO`Ko
oooo0Ol00001ooooo`001oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`06ooooo`03o`000?oooooooooo00CoooooZOmoOgl8o`0000ooVIVI00?o0000ok>c
/onc/k<0@Onc/k<00ol0003oVIVIoiVIV@0?oiVIV@03o`000?moOgooOgmo02KoOgmo1_ooool1o`00
007ooooo0007ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Kooooo00?o0000ooooooooool01?oooon`ogmoO`?o00003_nIVIT2o`00043o/k>c0_l0000>
oiVIV@?o0000:OmoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooncogmo
O`?o00003OnIVIT3o`0003[o/k>c0ol0000=oiVIV@?o0000;?moOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?oooonfogmoO`;o00003_nIVIT3o`0003?o/k>c1?l0000>oiVIV@;o
0000;omoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonhogmoO`?o0000
3_nIVIT5o`0002_o/k>c0ol0000@oiVIV@;o0000<OmoOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?oooonkogmoO`;o00004OnIVIT7o`0001oo/k>c1Ol0000@oiVIV@?o0000<omo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonmogmoO`Co00005?nIVIT6
o`0001?o/k>c1_l0000BoiVIV@?o0000=_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?ooooo1ogmoO`Oo00004onIVITCo`0001?oVIVI1Ol0000iogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooolSoOgmo1Ol0000^oiVIV@Ko0000?_moOgl6ooooo`7o
00000Oooool001[ooooo0_l00005ooooolgoOgmo0ol0000ToiVIV@Oo0000A?moOgl5ooooo`;o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooo@ogmoO`Go00006OnIVIT6o`0004_oOgmo1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooeOmoOglIo`00057oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00Cooooo_OmoOgl4o`0007koOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00Cooooo_OmoOgl01?l0003oIVIVofIVI_mVIVH7o`0003WoOgmo1Ol0000iogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04oooookcoOgmo00?o0000ofIVI_mVIVH02OmVIVH6
o`0002goOgmo1_l00005ofIVIP;o0000=omoOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?oooonkogmoO`03o`000?mVIVKoIVIV013oIVIV1ol0000OogmoO`Oo00003OmVIVH00ol0
003oOgmoogmoO`0dogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooook_o
Ogmo00?o0000ofIVI_mVIVH05omVIVHOo`0001GoIVIV0_l0000dogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04oooook[oOgmo0ol0001=ofIVIP;o0000<omoOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?oooonmogmoO`;o0000B?mVIVH3o`0003GoOgmo1_oo
ool1o`00007ooooo000Jooooo`;o00001OoooonoogmoO`;o0000A?mVIVH2o`0003SoOgmo1Oooool2
o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo`OmoOgl2o`00043oIVIV0_l0000jogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooool?oOgmo0ol0000jofIVIP?o
0000??moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooo6ogmoO`?o0000
<omVIVH4o`0003ooOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooobOmo
Ogl4o`0002coIVIV0ol00013ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooolgoOgmo0ol0000TofIVIPGo0000A_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?ooooo@ogmoO`_o00003?mVIVH=o`0004_oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooofomoOgl<o`0005SoOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooo
ogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool001[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o
0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
ooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3o
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooooomo
Ogm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6
ooooo`7o00000Oooool001[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[o
oooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooo
ogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000Oooooo00GoV9RHoa0@
4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003ooooooooo
o`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000Oooooo00Go410@okZj^_ooooooMgMgoc8b
<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`04ooooooooOgmo
@?moOgl6ooooo`7o00000Oooool000_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@
4?oooooooooo00Cooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo
000:ooooo`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`?o0000
1?ooooooogmoOd3oOgmo1?ooool3o`00007ooooo0009ooooo`03oa0@4?l0003o^[Zj00?ooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo
0Ol00001ooooo`002_ooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@4100
1_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000Oooooo00Go
410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003o
ooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000Oooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`04oooo
ooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3o
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Ooo
ool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooo
ogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3o
Ogmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooooomo
Ogm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Ooooooo
ogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo
@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o0000
1OooooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooooomo
Ogm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
ooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3o
Ogmo1_ooool1o`00007ooooo0009ooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000
oc8b<_o^k^h01_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
00[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo0007ooooo`Go00000oooool01Ol@
413ooooooooooooooooo410@00Kooooo0ol00004ooooooooOgmo@?moOgl4ooooo`?o00000Oooool0
00Oooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o
0000ooooooooool0oooooom:ooooo`7o00000Oooool000Oooooo00CogMgMoeEEEOoooooo00001?oo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0oooooom:ooooo`7o0000
0Oooool000Sooooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo410@00Kooooo
00?o0000ooooooooool0oooooom:ooooo`7o00000Oooool000Sooooo00?ok^k^odA4A?l000001?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooom:ooooo`7o0000
0Oooool000Wooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03gooooo
00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo02?ooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo0Ol0
0001ooooo`006_ooooooo`0004ko00000Oooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-30.1723, -14.304, 0.195672, \
0.195672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0192308 0.211538 0.0192308 [
[.11538 -0.0125 -9 -9 ]
[.11538 -0.0125 9 0 ]
[.30769 -0.0125 -9 -9 ]
[.30769 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69231 -0.0125 -6 -9 ]
[.69231 -0.0125 6 0 ]
[.88462 -0.0125 -6 -9 ]
[.88462 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -18 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .21154 -6 -4.5 ]
[-0.0125 .21154 0 4.5 ]
[-0.0125 .40385 -12 -4.5 ]
[-0.0125 .40385 0 4.5 ]
[-0.0125 .59615 -12 -4.5 ]
[-0.0125 .59615 0 4.5 ]
[-0.0125 .78846 -12 -4.5 ]
[-0.0125 .78846 0 4.5 ]
[-0.0125 .98077 -12 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11538 0 m
.11538 .00625 L
s
[(-20)] .11538 -0.0125 0 1 Mshowa
.30769 0 m
.30769 .00625 L
s
[(-10)] .30769 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69231 0 m
.69231 .00625 L
s
[(10)] .69231 -0.0125 0 1 Mshowa
.88462 0 m
.88462 .00625 L
s
[(20)] .88462 -0.0125 0 1 Mshowa
.125 Mabswid
.15385 0 m
.15385 .00375 L
s
.19231 0 m
.19231 .00375 L
s
.23077 0 m
.23077 .00375 L
s
.26923 0 m
.26923 .00375 L
s
.34615 0 m
.34615 .00375 L
s
.38462 0 m
.38462 .00375 L
s
.42308 0 m
.42308 .00375 L
s
.46154 0 m
.46154 .00375 L
s
.53846 0 m
.53846 .00375 L
s
.57692 0 m
.57692 .00375 L
s
.61538 0 m
.61538 .00375 L
s
.65385 0 m
.65385 .00375 L
s
.73077 0 m
.73077 .00375 L
s
.76923 0 m
.76923 .00375 L
s
.80769 0 m
.80769 .00375 L
s
.84615 0 m
.84615 .00375 L
s
.07692 0 m
.07692 .00375 L
s
.03846 0 m
.03846 .00375 L
s
.92308 0 m
.92308 .00375 L
s
.96154 0 m
.96154 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(-10)] -0.0125 .01923 1 0 Mshowa
0 .21154 m
.00625 .21154 L
s
[(0)] -0.0125 .21154 1 0 Mshowa
0 .40385 m
.00625 .40385 L
s
[(10)] -0.0125 .40385 1 0 Mshowa
0 .59615 m
.00625 .59615 L
s
[(20)] -0.0125 .59615 1 0 Mshowa
0 .78846 m
.00625 .78846 L
s
[(30)] -0.0125 .78846 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(40)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .05769 m
.00375 .05769 L
s
0 .09615 m
.00375 .09615 L
s
0 .13462 m
.00375 .13462 L
s
0 .17308 m
.00375 .17308 L
s
0 .25 m
.00375 .25 L
s
0 .28846 m
.00375 .28846 L
s
0 .32692 m
.00375 .32692 L
s
0 .36538 m
.00375 .36538 L
s
0 .44231 m
.00375 .44231 L
s
0 .48077 m
.00375 .48077 L
s
0 .51923 m
.00375 .51923 L
s
0 .55769 m
.00375 .55769 L
s
0 .63462 m
.00375 .63462 L
s
0 .67308 m
.00375 .67308 L
s
0 .71154 m
.00375 .71154 L
s
0 .75 m
.00375 .75 L
s
0 .82692 m
.00375 .82692 L
s
0 .86538 m
.00375 .86538 L
s
0 .90385 m
.00375 .90385 L
s
0 .94231 m
.00375 .94231 L
s
.25 Mabswid
0 0 m
0 1 L
s
.11538 .99375 m
.11538 1 L
s
.30769 .99375 m
.30769 1 L
s
.5 .99375 m
.5 1 L
s
.69231 .99375 m
.69231 1 L
s
.88462 .99375 m
.88462 1 L
s
.125 Mabswid
.15385 .99625 m
.15385 1 L
s
.19231 .99625 m
.19231 1 L
s
.23077 .99625 m
.23077 1 L
s
.26923 .99625 m
.26923 1 L
s
.34615 .99625 m
.34615 1 L
s
.38462 .99625 m
.38462 1 L
s
.42308 .99625 m
.42308 1 L
s
.46154 .99625 m
.46154 1 L
s
.53846 .99625 m
.53846 1 L
s
.57692 .99625 m
.57692 1 L
s
.61538 .99625 m
.61538 1 L
s
.65385 .99625 m
.65385 1 L
s
.73077 .99625 m
.73077 1 L
s
.76923 .99625 m
.76923 1 L
s
.80769 .99625 m
.80769 1 L
s
.84615 .99625 m
.84615 1 L
s
.07692 .99625 m
.07692 1 L
s
.03846 .99625 m
.03846 1 L
s
.92308 .99625 m
.92308 1 L
s
.96154 .99625 m
.96154 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .21154 m
1 .21154 L
s
.99375 .40385 m
1 .40385 L
s
.99375 .59615 m
1 .59615 L
s
.99375 .78846 m
1 .78846 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .05769 m
1 .05769 L
s
.99625 .09615 m
1 .09615 L
s
.99625 .13462 m
1 .13462 L
s
.99625 .17308 m
1 .17308 L
s
.99625 .25 m
1 .25 L
s
.99625 .28846 m
1 .28846 L
s
.99625 .32692 m
1 .32692 L
s
.99625 .36538 m
1 .36538 L
s
.99625 .44231 m
1 .44231 L
s
.99625 .48077 m
1 .48077 L
s
.99625 .51923 m
1 .51923 L
s
.99625 .55769 m
1 .55769 L
s
.99625 .63462 m
1 .63462 L
s
.99625 .67308 m
1 .67308 L
s
.99625 .71154 m
1 .71154 L
s
.99625 .75 m
1 .75 L
s
.99625 .82692 m
1 .82692 L
s
.99625 .86538 m
1 .86538 L
s
.99625 .90385 m
1 .90385 L
s
.99625 .94231 m
1 .94231 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.4 g
.49019 .51766 m
.50981 .51854 L
.52943 .5219 L
.54906 .52602 L
.56685 .52943 L
.56868 .5303 L
.5883 .53452 L
.60793 .53221 L
.62755 .53985 L
.64717 .54433 L
.6668 .54732 L
.68642 .54671 L
.70604 .54725 L
.72567 .54709 L
.74529 .54844 L
.76491 .54617 L
.78454 .54257 L
.80416 .53714 L
.82378 .53662 L
.84341 .53274 L
.85751 .52943 L
.86303 .52928 L
.88265 .52199 L
.90228 .52029 L
.9219 .51758 L
.94108 .52943 L
.9219 .54671 L
.91877 .54906 L
.90228 .55881 L
.88278 .56868 L
.88265 .56873 L
.86303 .57891 L
.84341 .58411 L
.82992 .5883 L
.82378 .5886 L
.80416 .59376 L
.78454 .59902 L
.76491 .60306 L
.74529 .60569 L
.72567 .60696 L
.70604 .60716 L
.68642 .6064 L
.6668 .60439 L
.64717 .60096 L
.62755 .5962 L
.60793 .5906 L
.59311 .5883 L
.5883 .58686 L
.56868 .58501 L
.54906 .57256 L
.54049 .56868 L
.52943 .56332 L
.50981 .55707 L
.50445 .54906 L
.49019 .53765 L
.48191 .52943 L
F
0 g
.49019 .51766 m
.50981 .51854 L
.52943 .5219 L
.54906 .52602 L
.56685 .52943 L
.56868 .5303 L
.5883 .53452 L
.60793 .53221 L
.62755 .53985 L
.64717 .54433 L
.6668 .54732 L
.68642 .54671 L
.70604 .54725 L
.72567 .54709 L
.74529 .54844 L
.76491 .54617 L
.78454 .54257 L
.80416 .53714 L
.82378 .53662 L
.84341 .53274 L
.85751 .52943 L
.86303 .52928 L
.88265 .52199 L
.90228 .52029 L
.9219 .51758 L
.94108 .52943 L
.9219 .54671 L
.91877 .54906 L
.90228 .55881 L
.88278 .56868 L
.88265 .56873 L
.86303 .57891 L
.84341 .58411 L
.82992 .5883 L
.82378 .5886 L
.80416 .59376 L
.78454 .59902 L
.76491 .60306 L
.74529 .60569 L
.72567 .60696 L
.70604 .60716 L
.68642 .6064 L
.6668 .60439 L
.64717 .60096 L
.62755 .5962 L
.60793 .5906 L
.59311 .5883 L
.5883 .58686 L
.56868 .58501 L
.54906 .57256 L
Mistroke
.54049 .56868 L
.52943 .56332 L
.50981 .55707 L
.50445 .54906 L
.49019 .53765 L
.48191 .52943 L
.49019 .51766 L
Mfstroke
.6 g
.49019 .58115 m
.50981 .58089 L
.52943 .58469 L
.54507 .5883 L
.54906 .58941 L
.56868 .59468 L
.5883 .59934 L
.60793 .60051 L
.62755 .60629 L
.63591 .60793 L
.64717 .60964 L
.6668 .61197 L
.68642 .61345 L
.70604 .6141 L
.72567 .61392 L
.74529 .6129 L
.76491 .61105 L
.78454 .60836 L
.78714 .60793 L
.80416 .60416 L
.82378 .59633 L
.84341 .59737 L
.86303 .59243 L
.87617 .5883 L
.88265 .58646 L
.90228 .58286 L
.9219 .57992 L
.93949 .5883 L
.9219 .60369 L
.91701 .60793 L
.90228 .6182 L
.88638 .62755 L
.88265 .62967 L
.86303 .64379 L
.84453 .64717 L
.84341 .64743 L
.82378 .65404 L
.80416 .66092 L
.78454 .66593 L
.7771 .6668 L
.76491 .66744 L
.74529 .6694 L
.72567 .67078 L
.70604 .67104 L
.68642 .67013 L
.6668 .66829 L
.64717 .66701 L
.64611 .6668 L
.62755 .66346 L
.60793 .6572 L
.5883 .65002 L
.57857 .64717 L
.56868 .64324 L
.54906 .63517 L
.53669 .62755 L
.52943 .62344 L
.50981 .61076 L
.50613 .60793 L
.49019 .59269 L
.48673 .5883 L
F
0 g
.49019 .58115 m
.50981 .58089 L
.52943 .58469 L
.54507 .5883 L
.54906 .58941 L
.56868 .59468 L
.5883 .59934 L
.60793 .60051 L
.62755 .60629 L
.63591 .60793 L
.64717 .60964 L
.6668 .61197 L
.68642 .61345 L
.70604 .6141 L
.72567 .61392 L
.74529 .6129 L
.76491 .61105 L
.78454 .60836 L
.78714 .60793 L
.80416 .60416 L
.82378 .59633 L
.84341 .59737 L
.86303 .59243 L
.87617 .5883 L
.88265 .58646 L
.90228 .58286 L
.9219 .57992 L
.93949 .5883 L
.9219 .60369 L
.91701 .60793 L
.90228 .6182 L
.88638 .62755 L
.88265 .62967 L
.86303 .64379 L
.84453 .64717 L
.84341 .64743 L
.82378 .65404 L
.80416 .66092 L
.78454 .66593 L
.7771 .6668 L
.76491 .66744 L
.74529 .6694 L
.72567 .67078 L
.70604 .67104 L
.68642 .67013 L
.6668 .66829 L
.64717 .66701 L
.64611 .6668 L
.62755 .66346 L
.60793 .6572 L
Mistroke
.5883 .65002 L
.57857 .64717 L
.56868 .64324 L
.54906 .63517 L
.53669 .62755 L
.52943 .62344 L
.50981 .61076 L
.50613 .60793 L
.49019 .59269 L
.48673 .5883 L
.49019 .58115 L
Mfstroke
.6 g
.50981 .46993 m
.52943 .47049 L
.53035 .47057 L
.54906 .47316 L
.56868 .47622 L
.5883 .47923 L
.60793 .48368 L
.62755 .4846 L
.64717 .48676 L
.6668 .48844 L
.68642 .48957 L
.70604 .49007 L
.72567 .48993 L
.74529 .48915 L
.76491 .48777 L
.78454 .48586 L
.80416 .48848 L
.82378 .47969 L
.84341 .47792 L
.86303 .47486 L
.88265 .47188 L
.89288 .47057 L
.90228 .46905 L
.91754 .47057 L
.91491 .49019 L
.90228 .49795 L
.88265 .50831 L
.87956 .50981 L
.86303 .52393 L
.84341 .52265 L
.82378 .52829 L
.81943 .52943 L
.80416 .53211 L
.78454 .53738 L
.76491 .54247 L
.74529 .54704 L
.72567 .54194 L
.70604 .54212 L
.68642 .54148 L
.6668 .54457 L
.64717 .53966 L
.62755 .5344 L
.60793 .52975 L
.60368 .52943 L
.5883 .52522 L
.56868 .51916 L
.54906 .51327 L
.54365 .50981 L
.52943 .50265 L
.50981 .49134 L
.50816 .49019 L
.50551 .47057 L
F
0 g
.50981 .46993 m
.52943 .47049 L
.53035 .47057 L
.54906 .47316 L
.56868 .47622 L
.5883 .47923 L
.60793 .48368 L
.62755 .4846 L
.64717 .48676 L
.6668 .48844 L
.68642 .48957 L
.70604 .49007 L
.72567 .48993 L
.74529 .48915 L
.76491 .48777 L
.78454 .48586 L
.80416 .48848 L
.82378 .47969 L
.84341 .47792 L
.86303 .47486 L
.88265 .47188 L
.89288 .47057 L
.90228 .46905 L
.91754 .47057 L
.91491 .49019 L
.90228 .49795 L
.88265 .50831 L
.87956 .50981 L
.86303 .52393 L
.84341 .52265 L
.82378 .52829 L
.81943 .52943 L
.80416 .53211 L
.78454 .53738 L
.76491 .54247 L
.74529 .54704 L
.72567 .54194 L
.70604 .54212 L
.68642 .54148 L
.6668 .54457 L
.64717 .53966 L
.62755 .5344 L
.60793 .52975 L
.60368 .52943 L
.5883 .52522 L
.56868 .51916 L
.54906 .51327 L
.54365 .50981 L
.52943 .50265 L
.50981 .49134 L
Mistroke
.50816 .49019 L
.50551 .47057 L
.50981 .46993 L
Mfstroke
.4 g
.54906 .43061 m
.56868 .43077 L
.57657 .43132 L
.5883 .4323 L
.60793 .43409 L
.62755 .43577 L
.64717 .43721 L
.6668 .43834 L
.68642 .43909 L
.70604 .43595 L
.72567 .43518 L
.74529 .43881 L
.76491 .43789 L
.78454 .43661 L
.80416 .43505 L
.82378 .4333 L
.84341 .43156 L
.84646 .43132 L
.86303 .42983 L
.88038 .43132 L
.87749 .45094 L
.86303 .45722 L
.84341 .46454 L
.82509 .47057 L
.82378 .47101 L
.80416 .48105 L
.78454 .47843 L
.76491 .48097 L
.74529 .48274 L
.72567 .48372 L
.70604 .4839 L
.68642 .48327 L
.6668 .48184 L
.64717 .47964 L
.62755 .47668 L
.60793 .47461 L
.59801 .47057 L
.5883 .46749 L
.56868 .46055 L
.54906 .45257 L
.54561 .45094 L
.54274 .43132 L
F
0 g
.54906 .43061 m
.56868 .43077 L
.57657 .43132 L
.5883 .4323 L
.60793 .43409 L
.62755 .43577 L
.64717 .43721 L
.6668 .43834 L
.68642 .43909 L
.70604 .43595 L
.72567 .43518 L
.74529 .43881 L
.76491 .43789 L
.78454 .43661 L
.80416 .43505 L
.82378 .4333 L
.84341 .43156 L
.84646 .43132 L
.86303 .42983 L
.88038 .43132 L
.87749 .45094 L
.86303 .45722 L
.84341 .46454 L
.82509 .47057 L
.82378 .47101 L
.80416 .48105 L
.78454 .47843 L
.76491 .48097 L
.74529 .48274 L
.72567 .48372 L
.70604 .4839 L
.68642 .48327 L
.6668 .48184 L
.64717 .47964 L
.62755 .47668 L
.60793 .47461 L
.59801 .47057 L
.5883 .46749 L
.56868 .46055 L
.54906 .45257 L
.54561 .45094 L
.54274 .43132 L
.54906 .43061 L
s
.3 g
.56868 .54438 m
.5883 .54475 L
.60793 .54288 L
.62755 .54775 L
.63798 .54906 L
.64717 .54996 L
.6668 .55148 L
.68642 .55248 L
.70604 .55292 L
.72567 .5528 L
.74529 .55211 L
.76491 .55088 L
.78454 .54915 L
.78527 .54906 L
.80416 .54617 L
.82378 .54557 L
.84341 .54433 L
.86303 .54553 L
.87007 .54906 L
.86303 .55784 L
.84806 .56868 L
.84341 .571 L
.82378 .57911 L
.80416 .58553 L
.79423 .5883 L
.78454 .59084 L
.76491 .59592 L
.74529 .60032 L
.72567 .60328 L
.70604 .60388 L
.68642 .60185 L
.6668 .59798 L
.64717 .59312 L
.62888 .5883 L
.62755 .58795 L
.60793 .58211 L
.5883 .57484 L
.575 .56868 L
.56868 .56455 L
.55226 .54906 L
F
0 g
.56868 .54438 m
.5883 .54475 L
.60793 .54288 L
.62755 .54775 L
.63798 .54906 L
.64717 .54996 L
.6668 .55148 L
.68642 .55248 L
.70604 .55292 L
.72567 .5528 L
.74529 .55211 L
.76491 .55088 L
.78454 .54915 L
.78527 .54906 L
.80416 .54617 L
.82378 .54557 L
.84341 .54433 L
.86303 .54553 L
.87007 .54906 L
.86303 .55784 L
.84806 .56868 L
.84341 .571 L
.82378 .57911 L
.80416 .58553 L
.79423 .5883 L
.78454 .59084 L
.76491 .59592 L
.74529 .60032 L
.72567 .60328 L
.70604 .60388 L
.68642 .60185 L
.6668 .59798 L
.64717 .59312 L
.62888 .5883 L
.62755 .58795 L
.60793 .58211 L
.5883 .57484 L
.575 .56868 L
.56868 .56455 L
.55226 .54906 L
.56868 .54438 L
s
.7 g
.5883 .49127 m
.60793 .49161 L
.62755 .49274 L
.64717 .49393 L
.6668 .49493 L
.68642 .49561 L
.70604 .49592 L
.72567 .49583 L
.74529 .49535 L
.76491 .49452 L
.78454 .49342 L
.80416 .49221 L
.82378 .49128 L
.84341 .49199 L
.84445 .50981 L
.84341 .51033 L
.82378 .5185 L
.80416 .52488 L
.78688 .52943 L
.78454 .53008 L
.76491 .53589 L
.74529 .54185 L
.72567 .53663 L
.70604 .53685 L
.68642 .53609 L
.6668 .53854 L
.64717 .53258 L
.63614 .52943 L
.62755 .52728 L
.60793 .52148 L
.5883 .51424 L
.57862 .50981 L
F
0 g
.5883 .49127 m
.60793 .49161 L
.62755 .49274 L
.64717 .49393 L
.6668 .49493 L
.68642 .49561 L
.70604 .49592 L
.72567 .49583 L
.74529 .49535 L
.76491 .49452 L
.78454 .49342 L
.80416 .49221 L
.82378 .49128 L
.84341 .49199 L
.84445 .50981 L
.84341 .51033 L
.82378 .5185 L
.80416 .52488 L
.78688 .52943 L
.78454 .53008 L
.76491 .53589 L
.74529 .54185 L
.72567 .53663 L
.70604 .53685 L
.68642 .53609 L
.6668 .53854 L
.64717 .53258 L
.63614 .52943 L
.62755 .52728 L
.60793 .52148 L
.5883 .51424 L
.57862 .50981 L
.5883 .49127 L
s
.6 g
.60793 .39739 m
.62755 .39632 L
.64717 .39631 L
.6668 .39657 L
.68642 .39681 L
.70604 .39694 L
.72567 .3969 L
.74529 .39671 L
.76491 .39644 L
.78454 .39626 L
.80416 .39657 L
.82378 .39901 L
.82506 .4117 L
.82378 .41212 L
.80416 .41769 L
.78454 .42209 L
.76491 .4255 L
.74529 .42786 L
.72567 .42915 L
.70604 .42938 L
.68642 .42855 L
.6668 .42667 L
.64717 .42372 L
.62755 .41975 L
.60793 .41476 L
.59801 .4117 L
F
0 g
.60793 .39739 m
.62755 .39632 L
.64717 .39631 L
.6668 .39657 L
.68642 .39681 L
.70604 .39694 L
.72567 .3969 L
.74529 .39671 L
.76491 .39644 L
.78454 .39626 L
.80416 .39657 L
.82378 .39901 L
.82506 .4117 L
.82378 .41212 L
.80416 .41769 L
.78454 .42209 L
.76491 .4255 L
.74529 .42786 L
.72567 .42915 L
.70604 .42938 L
.68642 .42855 L
.6668 .42667 L
.64717 .42372 L
.62755 .41975 L
.60793 .41476 L
.59801 .4117 L
.60793 .39739 L
s
.7 g
.62755 .62373 m
.64717 .62397 L
.6668 .62471 L
.68642 .62532 L
.70604 .62562 L
.72567 .62554 L
.74529 .62508 L
.76491 .62438 L
.78454 .62373 L
.80416 .62438 L
.8127 .62755 L
.80416 .63375 L
.78454 .64199 L
.76621 .64717 L
.76491 .64745 L
.74529 .65087 L
.72567 .65266 L
.70604 .65298 L
.68642 .65185 L
.6668 .64918 L
.65651 .64717 L
.64717 .64465 L
.62755 .63788 L
.61004 .62755 L
F
0 g
.62755 .62373 m
.64717 .62397 L
.6668 .62471 L
.68642 .62532 L
.70604 .62562 L
.72567 .62554 L
.74529 .62508 L
.76491 .62438 L
.78454 .62373 L
.80416 .62438 L
.8127 .62755 L
.80416 .63375 L
.78454 .64199 L
.76621 .64717 L
.76491 .64745 L
.74529 .65087 L
.72567 .65266 L
.70604 .65298 L
.68642 .65185 L
.6668 .64918 L
.65651 .64717 L
.64717 .64465 L
.62755 .63788 L
.61004 .62755 L
.62755 .62373 L
s
.2 g
.62755 .55936 m
.64717 .55886 L
.6668 .55915 L
.68642 .5595 L
.70604 .55969 L
.72567 .55964 L
.74529 .55936 L
.76491 .55899 L
.78454 .55889 L
.80416 .56057 L
.81058 .56868 L
.80416 .57224 L
.78454 .57982 L
.76491 .58498 L
.74608 .5883 L
.74529 .58847 L
.72567 .59201 L
.70604 .59275 L
.68642 .59028 L
.67533 .5883 L
.6668 .58669 L
.64717 .58232 L
.62755 .57599 L
.61247 .56868 L
F
0 g
.62755 .55936 m
.64717 .55886 L
.6668 .55915 L
.68642 .5595 L
.70604 .55969 L
.72567 .55964 L
.74529 .55936 L
.76491 .55899 L
.78454 .55889 L
.80416 .56057 L
.81058 .56868 L
.80416 .57224 L
.78454 .57982 L
.76491 .58498 L
.74608 .5883 L
.74529 .58847 L
.72567 .59201 L
.70604 .59275 L
.68642 .59028 L
.67533 .5883 L
.6668 .58669 L
.64717 .58232 L
.62755 .57599 L
.61247 .56868 L
.62755 .55936 L
s
.8 g
.62755 .50431 m
.64717 .50256 L
.6668 .50224 L
.68642 .50227 L
.70604 .50233 L
.72567 .50231 L
.74529 .50224 L
.76491 .50231 L
.78454 .50301 L
.80416 .50728 L
.8061 .50981 L
.80416 .51127 L
.78454 .52011 L
.76491 .52556 L
.74529 .52906 L
.74239 .52943 L
.72567 .53064 L
.70604 .53091 L
.68642 .52995 L
.67935 .52943 L
.6668 .52732 L
.64717 .52278 L
.62755 .51588 L
.61687 .50981 L
F
0 g
.62755 .50431 m
.64717 .50256 L
.6668 .50224 L
.68642 .50227 L
.70604 .50233 L
.72567 .50231 L
.74529 .50224 L
.76491 .50231 L
.78454 .50301 L
.80416 .50728 L
.8061 .50981 L
.80416 .51127 L
.78454 .52011 L
.76491 .52556 L
.74529 .52906 L
.74239 .52943 L
.72567 .53064 L
.70604 .53091 L
.68642 .52995 L
.67935 .52943 L
.6668 .52732 L
.64717 .52278 L
.62755 .51588 L
.61687 .50981 L
.62755 .50431 L
s
.3 g
.62755 .44998 m
.64717 .4488 L
.6668 .44857 L
.68642 .44861 L
.70604 .4451 L
.72567 .44468 L
.74529 .44858 L
.76491 .44861 L
.78454 .44912 L
.80223 .45094 L
.78454 .46865 L
.7788 .47057 L
.76491 .47298 L
.74529 .47536 L
.72567 .47664 L
.70604 .47687 L
.68642 .47605 L
.6668 .47417 L
.64717 .4711 L
.64439 .47057 L
.62755 .46399 L
.62081 .45094 L
F
0 g
.62755 .44998 m
.64717 .4488 L
.6668 .44857 L
.68642 .44861 L
.70604 .4451 L
.72567 .44468 L
.74529 .44858 L
.76491 .44861 L
.78454 .44912 L
.80223 .45094 L
.78454 .46865 L
.7788 .47057 L
.76491 .47298 L
.74529 .47536 L
.72567 .47664 L
.70604 .47687 L
.68642 .47605 L
.6668 .47417 L
.64717 .4711 L
.64439 .47057 L
.62755 .46399 L
.62081 .45094 L
.62755 .44998 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00?Oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0dooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kS?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0hooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8b
onk^kS?ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08_ooool003gooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0=_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0<oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg03?ooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL08_ooool003Gooooo1_l0
0003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400[ooooo`Ko0000
1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100<oooool01Ol@413o
oooooooooooooooo410@03[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@03Cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@02;ooooo000o
ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000fooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000cooooo`05o`000?ooooooooooooooool0
0000>_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000=Oooool00onH
V9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000008_ooool0043ooooo00?oMgMgofIV
I_ooool00_ooool01Ol0003ooooooooooooooooo000003Kooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000003?ooooo00Go0000ooooooooooooooooo`00000jooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`03ogMgMomVIVKooooo00;o
oooo00Go0000ooooooooooooooooo`00000Rooooo`00@Oooool01Ol0003ooooooooooooooooo410@
00?ooooo00?o410@ooooooooool0=?ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@4100<oooool01Ol@413ooooooooooooooooo410@03[ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@03Oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo023ooooo000mooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg03Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg03?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0jooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0cooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02;ooooo000mooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^03Cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^03?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`03oeEEEOmVIVKo000000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0cooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02;ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo000Joooooooo0000C_l00001ooooo`00
6_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0?Ooo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool08ooo
ool1o`00007ooooo0008ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKo
oooo00?o0000ooooooooool0oooooom:ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooom:ooooo`7o
00000Oooool000Go00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41001_ooool00ol0003oooooooooo`3ooooood[ooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?ooooooB?ooool3o`00007o
oooo000:ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo0008ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Oooooooogmo
Od3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Ooo
ooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000oooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`003ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000?ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000oooooo00Go0000oooooooooooooooo
o`000006ooooo`?o00001?ooooooogmoOd3oOgmo1?ooool3o`00007ooooo000?ooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool000oooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`003oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000?ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo0008
ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo00?o0000oooooooo
ool01?ooooo7ogmoOd;o0000=_moOgl6ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooo3ogmoO`Co
0000@_nIVIT3o`0003?oOgmo1_ooool1o`00007ooooo000:ooooo`03o`000?oooooooooo00;ooooo
00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00Cooooo`omoOgl00ol0003o
VIVIoiVIV@15oiVIV@03o`000?moOgooOgmo037oOgmo1_ooool1o`00007ooooo000:ooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`?o00001?ooooo2ogmoO`03
o`000?nIVIWoVIVI04KoVIVI00?o0000ogmoOomoOgl0<OmoOgl4ooooo`?o00000Oooool000[ooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool01?ooooo1ogmoO`03o`000?nIVIWoVIVI04OoVIVI00?o0000ogmoOomoOgl0<OmoOgl6ooooo`7o
00000Oooool000[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Ko
oooo00?o0000ooooooooool01?ooooo0ogmoO`?o0000B?nIVIT00ol0003oOgmoogmoO`0aogmoO`Ko
oooo0Ol00001ooooo`002_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01_ooool00ol0003oooooooooo`04oooool?oOgmo0ol00012oiVIV@Co0000<omoOgl6ooooo`7o
00000Oooool000Sooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Ko
oooo00?o0000ooooooooool01?ooooo6ogmoO`?o0000>_nIVIT5o`0003OoOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooobOmoOgl5o`0003;oVIVI0ol0000logmoO`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooolkoOgmo1ol0000VoiVIV@Go0000?omo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooEogmoO`Ko00006OnIVIT7
o`0004CoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooofomoOglIo`00
027oOgmo1ol0000SogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooojgo
Ogmo5?l0001=ogmoO`Oo00001omVIVH3o`00023oOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00Cooooo[OmoOgl00ol0003oIVIVofIVIP0AofIVIPgo00004omoOgl>o`0001;oOgmo
3Ol0000@ofIVIP03o`000?moOgooOgmo01koOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00Cooooo[OmoOgl00ol0003oIVIVofIVIP0NofIVIQ?o00003_mVIVHBo`0001goIVIV00?o
0000ogmoOomoOgl07_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon]
ogmoO`03o`000?mVIVKoIVIV06koIVIV00?o0000ogmoOomoOgl07_moOgl6ooooo`7o00000Oooool0
01[ooooo0_l00005ooooojkoOgmo00?o0000ofIVI_mVIVH0<OmVIVH;o`00033oIVIV00?o0000ogmo
OomoOgl07omoOgl5ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool01?oooon^ogmoO`03
o`000?mVIVKoIVIV02koIVIV0ol0000;oda<C0?o0000;OmVIVH00ol0003oOgmoogmoO`0OogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooojkoOgmo0_l0000GofIVIQSo0000
4Om<C4`Eo`0001OoIVIV0_l0000QogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04oooook3oOgmo0_l0000EofIVIP03o`000?m<C4coC4a<03WoC4a<00?o0000ofIVI_mVIVH04omV
IVH3o`0002?oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo/_moOgl2
o`0001CoIVIV00?o0000oda<C?m<C4`0=om<C4`00ol0003oIVIVofIVIP0BofIVIP;o00009_moOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooondogmoO`;o00004omVIVH00ol0
003oC4a<oda<C00eoda<C003o`000?mVIVKoIVIV013oIVIV0ol0000XogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04oooookKoOgmo0ol0000@ofIVIP03o`000?m<C4coC4a<03Co
C4a<00?o0000ofIVI_mVIVH03omVIVH2o`0002_oOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00Cooooo^OmoOgl3o`0000koIVIV0_l0000coda<C003o`000?mVIVKoIVIV00koIVIV
0_l0000]ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooookcoOgmo1?l0
000<ofIVIP?o0000;_m<C4`2o`0000koIVIV0ol0000DogmoO`Go00005_moOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?oooonQogmoO`go00004_moOgl3o`0000coIVIV1_l0000U
oda<C0?o00003OmVIVH3o`0000koOgmo2Ol00005oiVIV@;o00005?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?oooonQogmoO`03o`000?nIVIWoVIVI00[oVIVI1_l0000?ogmo
O`Go00003OmVIVH6o`0001WoC4a<1_l0000=ofIVIP?o00002omoOgl6o`0000ooVIVI00?o0000ogmo
OomoOgl04_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonQogmoO`03
o`000?nIVIWoVIVI013oVIVI1ol0000=ogmoO`Ko00003OmVIVHIo`00017oIVIV0_l00007ogmoO`Oo
00005OnIVIT00ol0003oOgmoogmoO`0BogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000Gooooo
XOmoOgl00ol0003oVIVIoiVIV@0GoiVIV@Ko00003OmoOgl7o`0001ooIVIV4Ol00005ogmoO`Co0000
7?nIVIT00ol0003oOgmoogmoO`0BogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003ooooooooo
o`04oooooj;oOgmo00?o0000oiVIVOnIVIT07?nIVIT7o`0000goOgmo7ol0000CogmoO`?o00007onI
VIT00ol0003oOgmoogmoO`0CogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
oooooj;oOgmo00?o0000oiVIVOnIVIT08onIVIT=o`0002KoOgmo1ol00003ogmoO`;o00008_nIVIT0
0ol0003oOgmoogmoO`0CogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
oj;oOgmo00?o0000oiVIVOnIVIT0<?nIVITVo`0000OoVIVI0ol0000SoiVIV@;o00005OmoOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonSogmoO`;o00006?nIVITAo`0003?o
VIVI4Ol0000EoiVIV@03o`000?moOgooOgmo01GoOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CoooooYOmoOgl00ol0003oVIVIoiVIV@0EoiVIV@03o`000?nc/k?o/k>c00ko/k>c
<ol0000@ok>c/`03o`000?nIVIWoVIVI01;oVIVI00?o0000ogmoOomoOgl05_moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?oooonVogmoO`;o00005?nIVIT00ol0003o/k>cok>c
/`1Bok>c/`03o`000?nIVIWoVIVI013oVIVI0_l0000IogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooojSoOgmo00?o0000oiVIVOnIVIT04?nIVIT00ol0003o/k>cok>c/`0F
ok>c/bSo00005Onc/k<00ol0003oVIVIoiVIV@0=oiVIV@?o00006omoOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?oooonYogmoO`;o00004?nIVIT00ol0003o/k>cok>c/`0;ok>c
/`_o0000:?o<c<`6o`00013o/k>c00?o0000oiVIVOnIVIT02_nIVIT2o`0001koOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CoooooZomoOgl3o`0000coVIVI00?o0000ok>c/onc
/k<02_nc/k<2o`0003Woc<c<0ol0000=ok>c/`03o`000?nIVIWoVIVI00WoVIVI00?o0000ogmoOomo
Ogl07_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon^ogmoO`;o0000
2OnIVIT3o`0000[o/k>c0_l0000kolc<c0?o00002_nc/k<3o`0000[oVIVI00?o0000ogmoOomoOgl0
7omoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon`ogmoO`?o00002OnI
VIT3o`0000Wo/k>c0_l0000golc<c0;o00002onc/k<2o`0000coVIVI00?o0000ogmoOomoOgl08?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooncogmoO`?o00002OnIVIT2
o`0000Wo/k>c0ol0000bolc<c0;o00002onc/k<2o`0000goVIVI00?o0000ogmoOomoOgl08OmoOgl6
ooooo`7o00000Oooool001[ooooo0_l00005oooooicoOgmo2ol0000?ogmoO`?o00002?nIVIT2o`00
00[o/k>c0ol0000/olc<c0?o00002_nc/k<3o`0000koVIVI00?o0000ogmoOomoOgl01OmoOgl;o`00
01;oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooVomoOgl00ol0003o
IVIVofIVIP09ofIVIPOo00002omoOgl3o`0000OoVIVI0ol0000:ok>c/`?o00009_o<c<`3o`0000[o
/k>c0ol00007oiVIV@Ko00000onIVIT01?l0003oOgmoogmoOomoOgl5o`0000_oIVIV0ol0000?ogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooi[oOgmo00?o0000ofIVI_mV
IVH04OmVIVH6o`0000SoOgmo1Ol00005oiVIV@?o00002_nc/k<3o`0001koc<c<1Ol00009ok>c/`Co
00001onIVIT3o`0000KoOgmo0ol000001?moOgoo0000o`000?l0000CofIVIP;o00003OmoOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonIogmoO`03o`000?mVIVKoIVIV01So
IVIV0_l0000;ogmoO`;o00001_nIVIT5o`0000So/k>c1ol0000@olc<c0Oo00002onc/k<3o`0000Go
VIVI1_l00008ogmoO`Go00005omVIVH2o`0000coOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CoooooV_moOgl00ol0003oIVIVofIVIP0IofIVIPGo00001OmoOgl8o`0000KoVIVI
0_l0000=ok>c/a3o00003onc/k<3o`0000CoVIVI1?l0000;ogmoO`?o00006omVIVH00ol0003oOgmo
ogmoO`0<ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooi_oOgmo00?o
0000ofIVI_mVIVH07OmVIVH5o`0000GoIVIV2?l00003oiVIV@?o00009_nc/k<3o`0000CoVIVI0ol0
000;ogmoO`Co00007OmVIVH00ol0003oOgmoogmoO`0=ogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04oooooicoOgmo0_l0000ZofIVIP;o00000omoOgl3o`0000?oVIVI0ol00004
ok>c/a?o00002Onc/k<3o`0000?oVIVI1?l00003ogmoO`_o00008?mVIVH00ol0003oOgmoogmoO`0>
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooikoOgmo00?o0000ofIV
I_mVIVH0:OmVIVH4o`0000;oOgmo0ol00003oiVIV@Co00000_nIVIT6o`0000_oVIVI0ol00003ok>c
/`?o00000onIVIT3o`0000CoOgmo0ol0000ZofIVIP03o`000?moOgooOgmo00ooOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CoooooWomoOgl00ol0003oIVIVofIVIP0CofIVIPKo
00001OmVIVH6o`0000SoIVIV2?l00003oiVIV@?o00001_moOgl=o`000005oiVIVOl0003o0000o`00
0?nIVIT01Ol00002ogmoO`Go00003_mVIVH8o`0001KoIVIV00?o0000ogmoOomoOgl04?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonPogmoO`03o`000?mVIVKoIVIV00oo
IVIV0ol00006oda<C0Go00001_m<C4`3o`0000coIVIV9_l00006ofIVIPgo00002?m<C4`4o`00017o
IVIV00?o0000ogmoOomoOgl04OmoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?oooonQogmoO`03o`000?mVIVKoIVIV00goIVIV00?o0000oda<C?m<C4`05Om<C4`<o`0001[oIVIV
1Ol00007ofIVIPKo00006Om<C4`00ol0003oIVIVofIVIP0<ofIVIP;o00005?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?oooonQogmoO`03o`000?mVIVKoIVIV00koIVIV00?o
0000oda<C?m<C4`08?m<C4`Vo`0001ooC4a<00?o0000ofIVI_mVIVH02_mVIVH2o`0001KoOgmo1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooX_moOgl00ol0003oIVIVofIVIP0>
ofIVIP03o`000?m<C4coC4a<06?oC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`0F
ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000GoooooXomoOgl3o`0000koIVIV00?o0000oda<
C?m<C4`04_m<C4`Io`0000coC4a<5?l0000Eoda<C0;o00002omVIVH2o`0001WoOgmo1Oooool2o`00
007ooooo000Jooooo`03o`000?oooooooooo00CoooooY_moOgl3o`0000coIVIV00?o0000oda<C?m<
C4`04?m<C4`00ol0003o<c<coc<c<`0Goc<c<`co00005?lc<c<3o`00017oC4a<00?o0000ofIVI_mV
IVH02OmVIVH2o`0001_oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
ZOmoOgl2o`0000_oIVIV00?o0000oda<C?m<C4`03_m<C4`00ol0003o<c<coc<c<`0joc<c<`03o`00
0?m<C4coC4a<00koC4a<00?o0000ofIVI_mVIVH02OmVIVH00ol0003oOgmoogmoO`0KogmoO`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooj_oOgmo0_l0000:ofIVIP03o`000?m<
C4coC4a<00coC4a<00?o0000oc<c<olc<c<0??lc<c<00ol0003oC4a<oda<C00<oda<C003o`000?mV
IVKoIVIV00SoIVIV0_l0000NogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooojgoOgmo0ol00008ofIVIP;o00002om<C4`2o`0003ko<c<c0_l00009oda<C0Co00002OmVIVH2
o`00023oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo/?moOgl2o`00
00SoIVIV0ol0000:oda<C0?o0000>Olc<c<2o`0000WoC4a<0_l0000;ofIVIP;o00008_moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonbogmoO`03o`000?mVIVKoIVIV00So
IVIV0ol0000:oda<C0?o0000<olc<c<3o`0000WoC4a<0_l0000;ofIVIP;o00009?moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooncogmoO`;o00002omVIVH3o`0000[oC4a<
0ol0000/oc<c<`Co00002Om<C4`3o`0000[oIVIV0ol0000?ogmoO`Go00004_moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?oooonLogmoO`_o00003_moOgl00ol0003oIVIVofIV
IP0;ofIVIP?o00002_m<C4`5o`0002Co<c<c0ol0000:oda<C0?o00002_mVIVH3o`0000coOgmo1_l0
0005oiVIV@;o00004?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonL
ogmoO`03o`000?nIVIWoVIVI00SoVIVI1_l00009ogmoO`Go00002omVIVH3o`0000coC4a<1?l0000K
oc<c<`Go00002_m<C4`3o`0000WoIVIV1?l0000:ogmoO`Go00003OnIVIT2o`0000koOgmo1_ooool1
o`00007ooooo0007ooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000
ooooooooool01?oooonKogmoO`03o`000?nIVIWoVIVI00ooVIVI1_l00008ogmoO`Oo00001omVIVH4
o`0000coC4a<0ol0000Boc<c<`Ko00003?m<C4`3o`0000KoIVIV1_l0000;ogmoO`?o00004onIVIT2
o`0000goOgmo1_ooool1o`00007ooooo0007ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?oooonLogmoO`03o`000?nI
VIWoVIVI01CoVIVI0ol0000<ogmoO`Co00001omVIVH3o`0000coC4a<1_l00005oc<c<`Oo00003_m<
C4`4o`0000KoIVIV0ol0000=ogmoO`Co00005OnIVIT00ol0003oOgmoogmoO`0=ogmoO`Kooooo0Ol0
0001ooooo`002?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41001_oo
ool00ol0003oooooooooo`04oooooicoOgmo00?o0000oiVIVOnIVIT05onIVIT3o`0000goOgmo0ol0
0007ofIVIPGo00003Om<C4`5o`0001;oC4a<0ol00007ofIVIP?o00003OmoOgl3o`0001SoVIVI00?o
0000ogmoOomoOgl03_moOgl6ooooo`7o00000Oooool000Wooooo00?oV9RHob4Q8Oo^k^h00oooool0
1Ol0003ooooooooooooooooo000000Kooooo0ol00004oooooigoOgmo00?o0000oiVIVOnIVIT06OnI
VIT3o`0000goOgmo1Ol00007ofIVIPGo00006_m<C4`5o`0000OoIVIV0ol00006ogmoO`[o00006_nI
VIT00ol0003oOgmoogmoO`0?ogmoO`Cooooo0ol00001ooooo`002_ooool00omgMgOoIVIVooooo`02
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`04oooooikoOgmo00?o
0000oiVIVOnIVIT06onIVIT:o`0000SoOgmo1ol00005ofIVIP?o00004Om<C4`6o`0000OoIVIV1Ol0
0006ogmoO`?o00008onIVIT00ol0003oOgmoogmoO`0@ogmoO`Kooooo0Ol00001ooooo`002oooool0
1Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool01?ooool00ol0003ooooooooo
o`04oooooiooOgmo00?o0000oiVIVOnIVIT09?nIVIT3o`0000coOgmo1_l00002ofIVIQ7o00001_mV
IVH7o`0000SoOgmo0ol0000UoiVIV@03o`000?moOgooOgmo017oOgmo1_ooool1o`00007ooooo0007
ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo
00?o0000ooooooooool01?oooonPogmoO`03o`000?nIVIWoVIVI02KoVIVI0ol0000?ogmoOaWo0000
3?moOgl3o`0002SoVIVI00?o0000ogmoOomoOgl04OmoOgl6ooooo`7o00000Oooool000Oooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003o
ooooooooo`04oooooj7oOgmo1?l0000WoiVIV@Wo00009_moOgl5o`0002WoVIVI0_l0000DogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooojGoOgmo00?o0000oiVIVOnIVIT0
;OnIVIT=o`0000coOgmo3Ol0000/oiVIV@;o00005_moOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?oooonVogmoO`03o`000?nIVIWoVIVI03WoVIVI3?l0000hoiVIV@03o`000?mo
OgooOgmo01KoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooYomoOgl0
0ol0003oVIVIoiVIV@1joiVIV@;o00006OmoOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?oooonXogmoO`03o`000?nIVIWoVIVI07OoVIVI0_l0000KogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooojWoOgmo0_l0000LoiVIVD3o00006_nIVIT00ol0003o
OgmoogmoO`0KogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooj_oOgmo
0_l0000GoiVIV@?o0000?onc/k<2o`0001OoVIVI0_l0000NogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooojgoOgmo0_l0000GoiVIV@03o`000?nc/k?o/k>c03co/k>c00?o
0000oiVIVOnIVIT05OnIVIT2o`00023oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Ooooon_
ogmoO`03o`000?nIVIWoVIVI01GoVIVI0_l0000jok>c/`;o00005onIVIT00ol0003oOgmoogmoO`0P
ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04oooook3oOgmo0ol0000FoiVI
V@03o`000?nc/k?o/k>c03Go/k>c0_l0000GoiVIV@;o00008omoOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?ooooncogmoO`?o00005?nIVIT3o`0003;o/k>c0_l0000HoiVIV@03
o`000?moOgooOgmo02?oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
]_moOgl2o`0001GoVIVI0ol0000]ok>c/`;o00006?nIVIT2o`0002KoOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00Cooooo^?moOgl00ol0003oVIVIoiVIV@0EoiVIV@?o00009onc
/k<3o`0001OoVIVI0ol0000XogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
oooookWoOgmo0ol0000GoiVIV@So00006Onc/k<6o`0001KoVIVI1?l0000[ogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04oooookcoOgmo1?l0000KoiVIV@Oo00001Onc/k<=o`00
01WoVIVI0ol0000_ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooool3o
Ogmo0ol0000OoiVIV@Go00008_nIVIT4o`0003;oOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00Cooooo`omoOgl3o`00043oVIVI0ol0000fogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooolKoOgmo0ol0000joiVIV@?o0000>OmoOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?ooooo9ogmoO`Go0000<_nIVIT3o`0003coOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00Coooooc_moOgl7o`0001ooVIVI3?l0000oogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooomGoOgmo3Ol00005oiVIV@go
0000BomoOgl6ooooo`7o00000Oooool001[ooooo0_l00005ooooon;oOgmo1Ol0001HogmoO`Gooooo
0_l00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooooomo
Ogm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000GooooooomoOgm0ogmo
O`Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo
@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000Gooooooomo
Ogm0ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
ooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3o
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo
0Ol00001ooooo`001oooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`00
1oooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06oooo
o`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002oooool01Ol0003o
oooooooooooooooo410@00?ooooo00?o410@ooooooooool01?ooool00ol0003oooooooooo`04oooo
ooooOgmo@?moOgl6ooooo`7o00000Oooool000[ooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003o
oooooooooooooooo000000Kooooo0ol00004ooooooooOgmo@?moOgl4ooooo`?o00000Oooool000Wo
oooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooo
ooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000:ooooo`03okZj^_lQ8B7ooooo00;o
oooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmo
O`Kooooo0Ol00001ooooo`001oooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001
ooooo`001oooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo
@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[o
oooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool0
1?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooooomo
Ogm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
ooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3o
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Ooo
ool001[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000oooo
ooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo
@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooo
ogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool001[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o
0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
ooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3o
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooooomo
Ogm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6
ooooo`7o00000Oooool001[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[o
oooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooo
ogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000Wooooo0_l000002Ol@
413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool000Oooooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@41001_ooool3o`0000Cooooo
oomoOgm0ogmoO`Cooooo0ol00001ooooo`001oooool01?m4A4CogMgMooooool00004ooooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooood[ooooo0Ol00001ooooo`00
1oooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool000001_ooool00ol0
003oooooooooo`3ooooood[ooooo0Ol00001ooooo`002?ooool00omgMgOoc<c<o`000004ooooo`05
oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`3ooooood[ooooo0Ol00001oooo
o`002?ooool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0
003oooooooooo`3ooooood[ooooo0Ol00001ooooo`002Oooool00omgMgOo0000ooooo`03ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
03gooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo
03gooooo00?o0000ooooooooool08oooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02Oooool1o`00007ooooo000Joooooooo0000C_l00001ooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-30.1723, -14.304, 0.195672, \
0.195672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0192308 0.211538 0.0192308 [
[.11538 -0.0125 -9 -9 ]
[.11538 -0.0125 9 0 ]
[.30769 -0.0125 -9 -9 ]
[.30769 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69231 -0.0125 -6 -9 ]
[.69231 -0.0125 6 0 ]
[.88462 -0.0125 -6 -9 ]
[.88462 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -18 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .21154 -6 -4.5 ]
[-0.0125 .21154 0 4.5 ]
[-0.0125 .40385 -12 -4.5 ]
[-0.0125 .40385 0 4.5 ]
[-0.0125 .59615 -12 -4.5 ]
[-0.0125 .59615 0 4.5 ]
[-0.0125 .78846 -12 -4.5 ]
[-0.0125 .78846 0 4.5 ]
[-0.0125 .98077 -12 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11538 0 m
.11538 .00625 L
s
[(-20)] .11538 -0.0125 0 1 Mshowa
.30769 0 m
.30769 .00625 L
s
[(-10)] .30769 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69231 0 m
.69231 .00625 L
s
[(10)] .69231 -0.0125 0 1 Mshowa
.88462 0 m
.88462 .00625 L
s
[(20)] .88462 -0.0125 0 1 Mshowa
.125 Mabswid
.15385 0 m
.15385 .00375 L
s
.19231 0 m
.19231 .00375 L
s
.23077 0 m
.23077 .00375 L
s
.26923 0 m
.26923 .00375 L
s
.34615 0 m
.34615 .00375 L
s
.38462 0 m
.38462 .00375 L
s
.42308 0 m
.42308 .00375 L
s
.46154 0 m
.46154 .00375 L
s
.53846 0 m
.53846 .00375 L
s
.57692 0 m
.57692 .00375 L
s
.61538 0 m
.61538 .00375 L
s
.65385 0 m
.65385 .00375 L
s
.73077 0 m
.73077 .00375 L
s
.76923 0 m
.76923 .00375 L
s
.80769 0 m
.80769 .00375 L
s
.84615 0 m
.84615 .00375 L
s
.07692 0 m
.07692 .00375 L
s
.03846 0 m
.03846 .00375 L
s
.92308 0 m
.92308 .00375 L
s
.96154 0 m
.96154 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(-10)] -0.0125 .01923 1 0 Mshowa
0 .21154 m
.00625 .21154 L
s
[(0)] -0.0125 .21154 1 0 Mshowa
0 .40385 m
.00625 .40385 L
s
[(10)] -0.0125 .40385 1 0 Mshowa
0 .59615 m
.00625 .59615 L
s
[(20)] -0.0125 .59615 1 0 Mshowa
0 .78846 m
.00625 .78846 L
s
[(30)] -0.0125 .78846 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(40)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .05769 m
.00375 .05769 L
s
0 .09615 m
.00375 .09615 L
s
0 .13462 m
.00375 .13462 L
s
0 .17308 m
.00375 .17308 L
s
0 .25 m
.00375 .25 L
s
0 .28846 m
.00375 .28846 L
s
0 .32692 m
.00375 .32692 L
s
0 .36538 m
.00375 .36538 L
s
0 .44231 m
.00375 .44231 L
s
0 .48077 m
.00375 .48077 L
s
0 .51923 m
.00375 .51923 L
s
0 .55769 m
.00375 .55769 L
s
0 .63462 m
.00375 .63462 L
s
0 .67308 m
.00375 .67308 L
s
0 .71154 m
.00375 .71154 L
s
0 .75 m
.00375 .75 L
s
0 .82692 m
.00375 .82692 L
s
0 .86538 m
.00375 .86538 L
s
0 .90385 m
.00375 .90385 L
s
0 .94231 m
.00375 .94231 L
s
.25 Mabswid
0 0 m
0 1 L
s
.11538 .99375 m
.11538 1 L
s
.30769 .99375 m
.30769 1 L
s
.5 .99375 m
.5 1 L
s
.69231 .99375 m
.69231 1 L
s
.88462 .99375 m
.88462 1 L
s
.125 Mabswid
.15385 .99625 m
.15385 1 L
s
.19231 .99625 m
.19231 1 L
s
.23077 .99625 m
.23077 1 L
s
.26923 .99625 m
.26923 1 L
s
.34615 .99625 m
.34615 1 L
s
.38462 .99625 m
.38462 1 L
s
.42308 .99625 m
.42308 1 L
s
.46154 .99625 m
.46154 1 L
s
.53846 .99625 m
.53846 1 L
s
.57692 .99625 m
.57692 1 L
s
.61538 .99625 m
.61538 1 L
s
.65385 .99625 m
.65385 1 L
s
.73077 .99625 m
.73077 1 L
s
.76923 .99625 m
.76923 1 L
s
.80769 .99625 m
.80769 1 L
s
.84615 .99625 m
.84615 1 L
s
.07692 .99625 m
.07692 1 L
s
.03846 .99625 m
.03846 1 L
s
.92308 .99625 m
.92308 1 L
s
.96154 .99625 m
.96154 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .21154 m
1 .21154 L
s
.99375 .40385 m
1 .40385 L
s
.99375 .59615 m
1 .59615 L
s
.99375 .78846 m
1 .78846 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .05769 m
1 .05769 L
s
.99625 .09615 m
1 .09615 L
s
.99625 .13462 m
1 .13462 L
s
.99625 .17308 m
1 .17308 L
s
.99625 .25 m
1 .25 L
s
.99625 .28846 m
1 .28846 L
s
.99625 .32692 m
1 .32692 L
s
.99625 .36538 m
1 .36538 L
s
.99625 .44231 m
1 .44231 L
s
.99625 .48077 m
1 .48077 L
s
.99625 .51923 m
1 .51923 L
s
.99625 .55769 m
1 .55769 L
s
.99625 .63462 m
1 .63462 L
s
.99625 .67308 m
1 .67308 L
s
.99625 .71154 m
1 .71154 L
s
.99625 .75 m
1 .75 L
s
.99625 .82692 m
1 .82692 L
s
.99625 .86538 m
1 .86538 L
s
.99625 .90385 m
1 .90385 L
s
.99625 .94231 m
1 .94231 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.4 g
.49019 .54461 m
.50981 .54531 L
.52943 .54894 L
.5302 .54906 L
.54906 .55379 L
.56868 .5584 L
.5883 .56121 L
.60793 .56731 L
.6199 .56868 L
.62755 .57011 L
.64717 .57317 L
.6668 .57548 L
.68642 .57093 L
.70604 .57328 L
.72567 .57373 L
.74529 .57247 L
.76491 .57643 L
.78454 .57451 L
.80416 .57186 L
.82257 .56868 L
.82378 .56847 L
.84341 .56493 L
.86303 .55675 L
.88265 .55632 L
.90228 .55156 L
.91245 .54906 L
.9219 .54586 L
.94152 .54434 L
.95997 .54906 L
.94549 .56868 L
.94152 .57177 L
.9219 .5846 L
.91559 .5883 L
.90228 .59835 L
.88265 .60425 L
.8736 .60793 L
.86303 .61111 L
.84341 .61933 L
.82378 .62695 L
.80987 .62755 L
.80416 .62887 L
.78454 .62993 L
.76491 .63313 L
.74529 .63528 L
.72567 .6362 L
.70604 .63586 L
.68642 .63427 L
.6668 .6315 L
.64717 .62813 L
.63242 .62755 L
.62755 .62645 L
.60793 .62303 L
.5883 .61483 L
.56868 .60794 L
.5686 .60793 L
.54906 .59963 L
.52943 .59005 L
.52674 .5883 L
.50981 .57797 L
.49675 .56868 L
.49019 .56186 L
.47891 .54906 L
F
0 g
.49019 .54461 m
.50981 .54531 L
.52943 .54894 L
.5302 .54906 L
.54906 .55379 L
.56868 .5584 L
.5883 .56121 L
.60793 .56731 L
.6199 .56868 L
.62755 .57011 L
.64717 .57317 L
.6668 .57548 L
.68642 .57093 L
.70604 .57328 L
.72567 .57373 L
.74529 .57247 L
.76491 .57643 L
.78454 .57451 L
.80416 .57186 L
.82257 .56868 L
.82378 .56847 L
.84341 .56493 L
.86303 .55675 L
.88265 .55632 L
.90228 .55156 L
.91245 .54906 L
.9219 .54586 L
.94152 .54434 L
.95997 .54906 L
.94549 .56868 L
.94152 .57177 L
.9219 .5846 L
.91559 .5883 L
.90228 .59835 L
.88265 .60425 L
.8736 .60793 L
.86303 .61111 L
.84341 .61933 L
.82378 .62695 L
.80987 .62755 L
.80416 .62887 L
.78454 .62993 L
.76491 .63313 L
.74529 .63528 L
.72567 .6362 L
.70604 .63586 L
.68642 .63427 L
.6668 .6315 L
.64717 .62813 L
.63242 .62755 L
Mistroke
.62755 .62645 L
.60793 .62303 L
.5883 .61483 L
.56868 .60794 L
.5686 .60793 L
.54906 .59963 L
.52943 .59005 L
.52674 .5883 L
.50981 .57797 L
.49675 .56868 L
.49019 .56186 L
.47891 .54906 L
.49019 .54461 L
Mfstroke
.6 g
.50981 .49527 m
.52943 .49613 L
.54906 .4989 L
.56868 .49965 L
.5883 .50564 L
.60793 .50904 L
.61261 .50981 L
.62755 .51213 L
.64717 .51462 L
.6668 .5105 L
.68642 .5151 L
.70604 .51714 L
.72567 .51755 L
.74529 .51642 L
.76491 .51344 L
.78454 .51572 L
.80416 .51355 L
.82378 .51078 L
.82951 .50981 L
.84341 .50749 L
.86303 .50561 L
.88265 .50065 L
.90228 .49752 L
.9219 .4953 L
.94124 .50981 L
.9219 .52373 L
.91263 .52943 L
.90228 .53448 L
.88265 .54269 L
.86571 .54906 L
.86303 .54967 L
.84341 .55751 L
.82378 .56078 L
.80416 .56479 L
.78454 .56802 L
.77993 .56868 L
.76491 .57042 L
.74529 .56975 L
.72567 .57045 L
.70604 .57018 L
.68642 .56907 L
.6668 .56923 L
.66249 .56868 L
.64717 .56637 L
.62755 .56272 L
.60793 .56222 L
.5883 .55281 L
.57661 .54906 L
.56868 .54616 L
.54906 .53839 L
.52951 .52943 L
.52943 .52939 L
.50981 .51659 L
.50108 .50981 L
F
0 g
.50981 .49527 m
.52943 .49613 L
.54906 .4989 L
.56868 .49965 L
.5883 .50564 L
.60793 .50904 L
.61261 .50981 L
.62755 .51213 L
.64717 .51462 L
.6668 .5105 L
.68642 .5151 L
.70604 .51714 L
.72567 .51755 L
.74529 .51642 L
.76491 .51344 L
.78454 .51572 L
.80416 .51355 L
.82378 .51078 L
.82951 .50981 L
.84341 .50749 L
.86303 .50561 L
.88265 .50065 L
.90228 .49752 L
.9219 .4953 L
.94124 .50981 L
.9219 .52373 L
.91263 .52943 L
.90228 .53448 L
.88265 .54269 L
.86571 .54906 L
.86303 .54967 L
.84341 .55751 L
.82378 .56078 L
.80416 .56479 L
.78454 .56802 L
.77993 .56868 L
.76491 .57042 L
.74529 .56975 L
.72567 .57045 L
.70604 .57018 L
.68642 .56907 L
.6668 .56923 L
.66249 .56868 L
.64717 .56637 L
.62755 .56272 L
.60793 .56222 L
.5883 .55281 L
.57661 .54906 L
.56868 .54616 L
.54906 .53839 L
Mistroke
.52951 .52943 L
.52943 .52939 L
.50981 .51659 L
.50108 .50981 L
.50981 .49527 L
Mfstroke
.6 g
.50981 .61313 m
.52943 .61626 L
.54906 .62091 L
.56868 .62392 L
.57832 .62755 L
.5883 .63066 L
.60793 .63543 L
.62755 .63939 L
.64717 .63856 L
.6668 .64369 L
.68642 .64646 L
.69469 .64717 L
.70604 .64772 L
.72567 .64796 L
.74529 .64731 L
.74831 .64717 L
.76491 .64539 L
.78454 .64174 L
.80416 .6412 L
.82378 .63767 L
.84341 .63333 L
.86303 .62823 L
.86551 .62755 L
.88265 .62347 L
.90228 .61872 L
.9219 .61442 L
.93885 .62755 L
.9219 .64122 L
.91365 .64717 L
.90228 .65445 L
.88265 .66504 L
.87907 .6668 L
.86303 .6751 L
.84341 .68215 L
.83056 .68642 L
.82378 .68802 L
.80416 .69342 L
.78454 .69825 L
.76491 .70179 L
.74529 .70389 L
.72567 .70468 L
.70604 .70439 L
.68642 .70293 L
.6668 .70006 L
.64717 .69578 L
.62755 .69048 L
.61174 .68642 L
.60793 .6852 L
.5883 .68049 L
.56868 .66941 L
.56327 .6668 L
.54906 .65956 L
.52943 .64792 L
.5287 .64717 L
.50981 .63274 L
.50413 .62755 L
F
0 g
.50981 .61313 m
.52943 .61626 L
.54906 .62091 L
.56868 .62392 L
.57832 .62755 L
.5883 .63066 L
.60793 .63543 L
.62755 .63939 L
.64717 .63856 L
.6668 .64369 L
.68642 .64646 L
.69469 .64717 L
.70604 .64772 L
.72567 .64796 L
.74529 .64731 L
.74831 .64717 L
.76491 .64539 L
.78454 .64174 L
.80416 .6412 L
.82378 .63767 L
.84341 .63333 L
.86303 .62823 L
.86551 .62755 L
.88265 .62347 L
.90228 .61872 L
.9219 .61442 L
.93885 .62755 L
.9219 .64122 L
.91365 .64717 L
.90228 .65445 L
.88265 .66504 L
.87907 .6668 L
.86303 .6751 L
.84341 .68215 L
.83056 .68642 L
.82378 .68802 L
.80416 .69342 L
.78454 .69825 L
.76491 .70179 L
.74529 .70389 L
.72567 .70468 L
.70604 .70439 L
.68642 .70293 L
.6668 .70006 L
.64717 .69578 L
.62755 .69048 L
.61174 .68642 L
.60793 .6852 L
.5883 .68049 L
.56868 .66941 L
Mistroke
.56327 .6668 L
.54906 .65956 L
.52943 .64792 L
.5287 .64717 L
.50981 .63274 L
.50413 .62755 L
.50981 .61313 L
Mfstroke
.4 g
.54906 .45447 m
.56868 .45533 L
.5883 .45717 L
.60793 .45922 L
.62755 .45979 L
.64717 .46305 L
.6668 .46457 L
.68642 .46569 L
.70604 .46634 L
.72567 .46648 L
.74529 .4661 L
.76491 .46523 L
.78454 .46392 L
.80416 .46523 L
.82378 .46032 L
.84341 .45827 L
.86303 .45627 L
.88265 .45473 L
.90228 .45511 L
.90796 .47057 L
.90228 .47386 L
.88265 .4836 L
.86768 .49019 L
.86303 .49321 L
.84341 .49731 L
.82378 .50201 L
.80416 .506 L
.78454 .50925 L
.78069 .50981 L
.76491 .51085 L
.74529 .51258 L
.72567 .51344 L
.70604 .51312 L
.68642 .51171 L
.6668 .50997 L
.6617 .50981 L
.64717 .50759 L
.62755 .50393 L
.60793 .49957 L
.5883 .49443 L
.57459 .49019 L
.56868 .48769 L
.54906 .47853 L
.53431 .47057 L
F
0 g
.54906 .45447 m
.56868 .45533 L
.5883 .45717 L
.60793 .45922 L
.62755 .45979 L
.64717 .46305 L
.6668 .46457 L
.68642 .46569 L
.70604 .46634 L
.72567 .46648 L
.74529 .4661 L
.76491 .46523 L
.78454 .46392 L
.80416 .46523 L
.82378 .46032 L
.84341 .45827 L
.86303 .45627 L
.88265 .45473 L
.90228 .45511 L
.90796 .47057 L
.90228 .47386 L
.88265 .4836 L
.86768 .49019 L
.86303 .49321 L
.84341 .49731 L
.82378 .50201 L
.80416 .506 L
.78454 .50925 L
.78069 .50981 L
.76491 .51085 L
.74529 .51258 L
.72567 .51344 L
.70604 .51312 L
.68642 .51171 L
.6668 .50997 L
.6617 .50981 L
.64717 .50759 L
.62755 .50393 L
.60793 .49957 L
.5883 .49443 L
.57459 .49019 L
.56868 .48769 L
.54906 .47853 L
.53431 .47057 L
.54906 .45447 L
s
.3 g
.5883 .57534 m
.60793 .57682 L
.62755 .57877 L
.64717 .58062 L
.6668 .58216 L
.68642 .57793 L
.70604 .58026 L
.72567 .58068 L
.74529 .57948 L
.76491 .58283 L
.78454 .5815 L
.80416 .5798 L
.82378 .57786 L
.84341 .57602 L
.86303 .57528 L
.87345 .5883 L
.86303 .59509 L
.84341 .60499 L
.83668 .60793 L
.82378 .61783 L
.80416 .61823 L
.78454 .62253 L
.76491 .62565 L
.74659 .62755 L
.74529 .62761 L
.72567 .62835 L
.70604 .62807 L
.69605 .62755 L
.68642 .6267 L
.6668 .62411 L
.64717 .62036 L
.62755 .61537 L
.60793 .60935 L
.60565 .60793 L
.5883 .59995 L
.56898 .5883 L
F
0 g
.5883 .57534 m
.60793 .57682 L
.62755 .57877 L
.64717 .58062 L
.6668 .58216 L
.68642 .57793 L
.70604 .58026 L
.72567 .58068 L
.74529 .57948 L
.76491 .58283 L
.78454 .5815 L
.80416 .5798 L
.82378 .57786 L
.84341 .57602 L
.86303 .57528 L
.87345 .5883 L
.86303 .59509 L
.84341 .60499 L
.83668 .60793 L
.82378 .61783 L
.80416 .61823 L
.78454 .62253 L
.76491 .62565 L
.74659 .62755 L
.74529 .62761 L
.72567 .62835 L
.70604 .62807 L
.69605 .62755 L
.68642 .6267 L
.6668 .62411 L
.64717 .62036 L
.62755 .61537 L
.60793 .60935 L
.60565 .60793 L
.5883 .59995 L
.56898 .5883 L
.5883 .57534 L
s
.7 g
.5883 .51866 m
.60793 .51896 L
.62755 .52014 L
.64717 .52146 L
.6668 .5145 L
.68642 .51987 L
.70604 .52184 L
.72567 .52221 L
.74529 .52118 L
.76491 .51809 L
.78454 .52213 L
.80416 .52086 L
.82378 .51955 L
.84341 .51863 L
.86303 .51951 L
.87233 .52943 L
.86303 .53559 L
.84341 .54547 L
.83494 .54906 L
.82378 .55258 L
.80416 .5576 L
.78454 .56145 L
.76491 .56426 L
.74529 .56605 L
.72567 .56681 L
.70604 .56653 L
.68642 .56521 L
.6668 .56287 L
.64717 .55951 L
.62755 .55505 L
.60793 .54943 L
.60738 .54906 L
.5883 .54045 L
.57002 .52943 L
F
0 g
.5883 .51866 m
.60793 .51896 L
.62755 .52014 L
.64717 .52146 L
.6668 .5145 L
.68642 .51987 L
.70604 .52184 L
.72567 .52221 L
.74529 .52118 L
.76491 .51809 L
.78454 .52213 L
.80416 .52086 L
.82378 .51955 L
.84341 .51863 L
.86303 .51951 L
.87233 .52943 L
.86303 .53559 L
.84341 .54547 L
.83494 .54906 L
.82378 .55258 L
.80416 .5576 L
.78454 .56145 L
.76491 .56426 L
.74529 .56605 L
.72567 .56681 L
.70604 .56653 L
.68642 .56521 L
.6668 .56287 L
.64717 .55951 L
.62755 .55505 L
.60793 .54943 L
.60738 .54906 L
.5883 .54045 L
.57002 .52943 L
.5883 .51866 L
s
.6 g
.5883 .42091 m
.60793 .41916 L
.62755 .41924 L
.64717 .41981 L
.6668 .42046 L
.68642 .421 L
.70604 .42133 L
.72567 .4214 L
.74529 .42121 L
.76491 .42077 L
.78454 .42016 L
.80416 .41952 L
.82378 .4191 L
.84341 .41955 L
.86203 .43132 L
.84341 .43902 L
.82378 .44564 L
.8043 .45094 L
.80416 .451 L
.78454 .45386 L
.76491 .45593 L
.74529 .45723 L
.72567 .45778 L
.70604 .45758 L
.68642 .45662 L
.6668 .45491 L
.64717 .45241 L
.63797 .45094 L
.62755 .44826 L
.60793 .44221 L
.5883 .4349 L
.58027 .43132 L
F
0 g
.5883 .42091 m
.60793 .41916 L
.62755 .41924 L
.64717 .41981 L
.6668 .42046 L
.68642 .421 L
.70604 .42133 L
.72567 .4214 L
.74529 .42121 L
.76491 .42077 L
.78454 .42016 L
.80416 .41952 L
.82378 .4191 L
.84341 .41955 L
.86203 .43132 L
.84341 .43902 L
.82378 .44564 L
.8043 .45094 L
.80416 .451 L
.78454 .45386 L
.76491 .45593 L
.74529 .45723 L
.72567 .45778 L
.70604 .45758 L
.68642 .45662 L
.6668 .45491 L
.64717 .45241 L
.63797 .45094 L
.62755 .44826 L
.60793 .44221 L
.5883 .4349 L
.58027 .43132 L
.5883 .42091 L
s
.3 g
.62755 .47464 m
.64717 .47406 L
.6668 .47425 L
.68642 .47458 L
.70604 .47482 L
.72567 .47487 L
.74529 .47473 L
.76491 .47443 L
.78454 .47412 L
.80416 .47415 L
.82378 .47581 L
.82513 .49019 L
.82378 .49067 L
.80416 .49654 L
.78454 .50089 L
.76491 .50405 L
.74529 .50604 L
.72567 .50688 L
.70604 .50657 L
.68642 .50511 L
.6668 .50249 L
.64717 .4987 L
.62755 .49361 L
.61714 .49019 L
F
0 g
.62755 .47464 m
.64717 .47406 L
.6668 .47425 L
.68642 .47458 L
.70604 .47482 L
.72567 .47487 L
.74529 .47473 L
.76491 .47443 L
.78454 .47412 L
.80416 .47415 L
.82378 .47581 L
.82513 .49019 L
.82378 .49067 L
.80416 .49654 L
.78454 .50089 L
.76491 .50405 L
.74529 .50604 L
.72567 .50688 L
.70604 .50657 L
.68642 .50511 L
.6668 .50249 L
.64717 .4987 L
.62755 .49361 L
.61714 .49019 L
.62755 .47464 L
s
.8 g
.64717 .52971 m
.6668 .5297 L
.68642 .53001 L
.70604 .53027 L
.72567 .53033 L
.74529 .53017 L
.76491 .52986 L
.78454 .52962 L
.8024 .54906 L
.78454 .55371 L
.76491 .55722 L
.74529 .55938 L
.72567 .56028 L
.70604 .55995 L
.68642 .55837 L
.6668 .5555 L
.64717 .55115 L
.63987 .54906 L
F
0 g
.64717 .52971 m
.6668 .5297 L
.68642 .53001 L
.70604 .53027 L
.72567 .53033 L
.74529 .53017 L
.76491 .52986 L
.78454 .52962 L
.8024 .54906 L
.78454 .55371 L
.76491 .55722 L
.74529 .55938 L
.72567 .56028 L
.70604 .55995 L
.68642 .55837 L
.6668 .5555 L
.64717 .55115 L
.63987 .54906 L
.64717 .52971 L
s
.2 g
.6668 .59143 m
.68642 .5917 L
.70604 .59197 L
.72567 .59204 L
.74529 .59187 L
.76491 .59155 L
.78454 .59146 L
.79341 .60793 L
.78454 .61054 L
.76491 .61479 L
.74529 .61731 L
.72567 .61835 L
.70604 .61797 L
.68642 .61614 L
.6668 .61274 L
.64897 .60793 L
F
0 g
.6668 .59143 m
.68642 .5917 L
.70604 .59197 L
.72567 .59204 L
.74529 .59187 L
.76491 .59155 L
.78454 .59146 L
.79341 .60793 L
.78454 .61054 L
.76491 .61479 L
.74529 .61731 L
.72567 .61835 L
.70604 .61797 L
.68642 .61614 L
.6668 .61274 L
.64897 .60793 L
.6668 .59143 L
s
.2 g
.68642 .48775 m
.70604 .48609 L
.72567 .48585 L
.74529 .48657 L
.76437 .49019 L
.74529 .49457 L
.72567 .4961 L
.70604 .49555 L
.68642 .49266 L
.67765 .49019 L
F
0 g
.68642 .48775 m
.70604 .48609 L
.72567 .48585 L
.74529 .48657 L
.76437 .49019 L
.74529 .49457 L
.72567 .4961 L
.70604 .49555 L
.68642 .49266 L
.67765 .49019 L
.68642 .48775 L
s
.4 g
.68642 .39171 m
.70604 .38998 L
.72567 .38973 L
.74529 .39048 L
.75985 .39207 L
.74529 .39566 L
.72567 .3974 L
.70604 .39679 L
.68642 .39305 L
.68436 .39207 L
F
0 g
.68642 .39171 m
.70604 .38998 L
.72567 .38973 L
.74529 .39048 L
.75985 .39207 L
.74529 .39566 L
.72567 .3974 L
.70604 .39679 L
.68642 .39305 L
.68436 .39207 L
.68642 .39171 L
s
.9 g
.70604 .54186 m
.72567 .54143 L
.74529 .54285 L
.74944 .54906 L
.74529 .54952 L
.72567 .55101 L
.70604 .55048 L
.69383 .54906 L
F
0 g
.70604 .54186 m
.72567 .54143 L
.74529 .54285 L
.74944 .54906 L
.74529 .54952 L
.72567 .55101 L
.70604 .55048 L
.69383 .54906 L
.70604 .54186 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00?Oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0dooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kS?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0hooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8b
onk^kS?ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08_ooool003gooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0=_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0<oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg03?ooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL08_ooool003Gooooo1_l0
0003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400[ooooo`Ko0000
1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100<oooool01Ol@413o
oooooooooooooooo410@03[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@03Cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@02;ooooo000o
ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000fooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000cooooo`05o`000?ooooooooooooooool0
0000>_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000=Oooool00onH
V9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000008_ooool0043ooooo00?oMgMgofIV
I_ooool00_ooool01Ol0003ooooooooooooooooo000003Kooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000003?ooooo00Go0000ooooooooooooooooo`00000jooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`03ogMgMomVIVKooooo00;o
oooo00Go0000ooooooooooooooooo`00000Rooooo`00@Oooool01Ol0003ooooooooooooooooo410@
00?ooooo00?o410@ooooooooool0=?ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@4100<oooool01Ol@413ooooooooooooooooo410@03[ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@03Oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo023ooooo000mooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg03Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg03?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0jooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0cooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02;ooooo000mooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^03Cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^03?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`03oeEEEOmVIVKo000000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0cooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02;ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo000Joooooooo0000C_l00001ooooo`00
6_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0?Ooo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool08ooo
ool1o`00007ooooo0008ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKo
oooo00?o0000ooooooooool0oooooom:ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooom:ooooo`7o
00000Oooool000Go00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41001_ooool00ol0003oooooooooo`3ooooood[ooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?ooooooB?ooool3o`00007o
oooo000:ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo0008ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Oooooooogmo
Od3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Ooo
ooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000oooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`003ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000?ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000oooooo00Go0000oooooooooooooooo
o`000006ooooo`?o00001?ooooooogmoOd3oOgmo1?ooool3o`00007ooooo000?ooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool000oooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`003oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000?ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooon7oOgmo5?l0001:ogmoO`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooomcoOgmo1_l0000BofIVIP?o0000B?mo
Ogl6ooooo`7o00000Oooool000Sooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;o
k^k^1_ooool00ol0003oooooooooo`04ooooon;oOgmo1_l00006ofIVIPKo0000BomoOgl6ooooo`7o
00000Oooool000[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Ko
oooo00?o0000ooooooooool01?oooooXogmoO`Ko0000DOmoOgl6ooooo`7o00000Oooool000[ooooo
00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000:ooooo`03o`000?oooooooooo00;ooooo
00Go0000ooooooooooooooooo`000006ooooo`?o00001?ooooooogmoOd3oOgmo1?ooool3o`00007o
oooo000:ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo0008ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04oooookgoOgmo9Ol0000BogmoOaoo0000;?moOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?oooonmogmoO`03o`000?nIVIWoVIVI02;oVIVI4_l0000OoiVIV@;o0000:_mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonlogmoO`03o`000?nIVIWo
VIVI05KoVIVI00?o0000ogmoOomoOgl09omoOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?oooonkogmoO`03o`000?nIVIWoVIVI05SoVIVI0_l0000WogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04oooook[oOgmo0ol0001IoiVIV@?o00009_moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?oooonmogmoO`;o0000E?nIVIT3o`0002WoOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo_omoOgl2o`0004ooVIVI0ol0
000/ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooool7oOgmo0_l0001;
oiVIV@;o0000;omoOgl6ooooo`7o00000Oooool001[ooooo0_l00005oooool?oOgmo0ol00016oiVI
V@;o0000<OmoOgl5ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool01?ooooo6ogmoO`?o
0000?onIVIT4o`0003?oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
bOmoOgl7o`00037oVIVI1ol0000gogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooom3oOgmo1Ol0000VoiVIV@Ko0000?_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?oooon`ogmoOa7o00005?moOgl=o`0000coVIVI3Ol0000JogmoOa7o00006OmoOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon_ogmoO`03o`000?mVIVKoIVIV
00ooIVIV3Ol0000DogmoO`co00008?moOgl7o`00013oIVIV00?o0000ogmoOomoOgl05omoOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon^ogmoO`03o`000?mVIVKoIVIV01go
IVIV1ol0000cogmoO`Ko00006?mVIVH00ol0003oOgmoogmoO`0FogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooojgoOgmo00?o0000ofIVI_mVIVH09OmVIVH=o`0000coOgmo
6_l0000NofIVIP03o`000?moOgooOgmo01KoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00Cooooo[?moOgl00ol0003oIVIVofIVIP0cofIVIPco0000>?mVIVH00ol0003oOgmoogmo
O`0FogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooj_oOgmo0_l0001i
ofIVIP;o00005omoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon]ogmo
O`;o00006omVIVHoo`0001_oIVIV0_l0000IogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooojooOgmo00?o0000ofIVI_mVIVH06?mVIVH00ol0003oC4a<oda<C00loda<C0?o
00005OmVIVH3o`0001_oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Ooooon`ogmoO`;o0000
5omVIVH00ol0003oC4a<oda<C00ooda<C003o`000?mVIVKoIVIV017oIVIV0_l0000NogmoO`Gooooo
0_l00001ooooo`006_ooool00ol0003oooooooooo`04oooook;oOgmo0_l0000DofIVIP03o`000?m<
C4coC4a<043oC4a<00?o0000ofIVI_mVIVH03omVIVH2o`00023oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00Cooooo]?moOgl2o`00017oIVIV00?o0000oda<C?m<C4`05om<C4`D
o`0001KoC4a<00?o0000ofIVI_mVIVH03?mVIVH3o`0002;oOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00Cooooo]_moOgl4o`0000coIVIV0_l0000Boda<C0Oo00005?lc<c<3o`00
01?oC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`0SogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04oooook[oOgmo0ol0000;ofIVIP;o00004om<C4`5o`00017o
<c<c0ol0000Coda<C0?o00002_mVIVH3o`0002KoOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CoooooXomoOgl;o`0000ooOgmo0ol0000:ofIVIPCo00005?m<C4`Ao`0001?oC4a<
0ol0000:ofIVIP?o00004_moOgl5o`0001;oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CoooooXomoOgl00ol0003oVIVIoiVIV@08oiVIV@Ko00003?moOgl3o`0000_oIVIV1Ol0
000^oda<C0Go00002?mVIVH5o`0000ooOgmo1_l00005oiVIV@03o`000?moOgooOgmo00ooOgmo1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooX_moOgl00ol0003oVIVIoiVIV@0?
oiVIV@Go00002_moOgl5o`0000_oIVIV0ol0000Uoda<C0Ko00002?mVIVH5o`0000ooOgmo1Ol0000<
oiVIV@;o00003omoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonQogmo
O`03o`000?nIVIWoVIVI01GoVIVI0ol0000<ogmoO`Ko00002?mVIVH<o`0001;oC4a<1ol0000;ofIV
IP?o00004OmoOgl3o`0001?oVIVI00?o0000ogmoOomoOgl03?moOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?oooonQogmoO`03o`000?nIVIWoVIVI01SoVIVI1Ol0000=ogmoO`Ko
00003_mVIVHBo`0000goIVIV1Ol00009ogmoO`_o00005onIVIT00ol0003oOgmoogmoO`0;ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooj3oOgmo0_l0000OoiVIV@So0000
2omoOgl7o`0001WoIVIV3Ol00007ogmoO`Oo00008_nIVIT2o`0000coOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CoooooX_moOgl00ol0003oVIVIoiVIV@0ToiVIV@Go00001?mo
Ogl3o`0000GoVIVI8_l00005ogmoO`Oo0000:?nIVIT00ol0003oOgmoogmoO`0<ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04oooooj?oOgmo0_l0000YoiVIV@Co00000onIVIT6
o`0000;oVIVI2ol00006ogmoO`Ko00002?nIVIT5o`0002goVIVI0_l0000?ogmoO`Kooooo0Ol00001
ooooo`006_ooool2o`0000GoooooYOmoOgl00ol0003oVIVIoiVIV@0DoiVIVA;o00001?nIVIT3o`00
00Ko/k>c1ol00006oiVIV@Ko00001_nIVIT8o`0000coVIVI4Ol0000DoiVIV@03o`000?moOgooOgmo
00ooOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooY_moOgl2o`0001;o
VIVI0_l0000Bok>c/`Co00004?nc/k<Bo`0000So/k>c3?l0000Aok>c/`03o`000?nIVIWoVIVI013o
VIVI00?o0000ogmoOomoOgl04?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?oooonXogmoO`03o`000?nIVIWoVIVI00goVIVI0_l0001Pok>c/`03o`000?nIVIWoVIVI00goVIVI
0_l0000CogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooojWoOgmo0_l0
000<oiVIV@;o0000H_nc/k<00ol0003oVIVIoiVIV@09oiVIV@?o00005OmoOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?oooon[ogmoO`?o00002onIVIT00ol0003o/k>cok>c/`0D
ok>c/boo00006onc/k<00ol0003oVIVIoiVIV@09oiVIV@03o`000?moOgooOgmo01KoOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo[_moOgl2o`0000[oVIVI0_l0000Dok>c
/`03o`000?o<c<coc<c<02coc<c<00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@08oiVI
V@;o00006OmoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon`ogmoO`;o
00002_nIVIT00ol0003o/k>cok>c/`0@ok>c/`03o`000?o<c<coc<c<02koc<c<00?o0000ok>c/onc
/k<05?nc/k<2o`0000SoVIVI0ol0000KogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04oooook;oOgmo0_l00009oiVIV@;o00004?nc/k<00ol0003oc<c<olc<c00Eolc<c0So0000
4_o<c<`00ol0003o/k>cok>c/`0@ok>c/`?o00002?nIVIT2o`0001koOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00Cooooo]?moOgl2o`0000WoVIVI0_l0000>ok>c/`03o`000?o<
c<coc<c<017oc<c<1?l00008onKViP?o00004?o<c<`00ol0003o/k>cok>c/`0=ok>c/`;o00002OnI
VIT2o`00013oOgmo1_l0000:ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
oooooi[oOgmo3Ol0000?ogmoO`?o00002?nIVIT2o`0000_o/k>c00?o0000olc<c?o<c<`04?o<c<`2
o`0000koi^KV00?o0000olc<c?o<c<`03oo<c<`00ol0003o/k>cok>c/`0:ok>c/`;o00002?nIVIT3
o`0000goOgmo1Ol00006ofIVIP?o00001omoOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?oooonHogmoO`;o00003OmVIVH5o`0000goOgmo0ol00007oiVIV@?o00002?nc/k<2o`00
013oc<c<2?l00006onKViPGo00004?o<c<`2o`0000So/k>c0ol00007oiVIV@?o00003OmoOgl3o`00
00koIVIV00?o0000ogmoOomoOgl01?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?oooonIogmoO`03o`000?mVIVKoIVIV013oIVIV0ol0000=ogmoO`?o00001onIVIT3o`0000Oo
/k>c1Ol0000Colc<c0Ko00004_o<c<`3o`0000Ko/k>c1?l00007oiVIV@?o00002omoOgl5o`00017o
IVIV00?o0000ogmoOomoOgl01?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?oooonJogmoO`03o`000?mVIVKoIVIV01;oIVIV1Ol0000;ogmoO`;o00002?nIVIT5o`0000Oo/k>c
1_l0000Polc<c0Go00001_nc/k<3o`0000WoVIVI0_l00007ogmoO`Oo00005OmVIVH00ol0003oOgmo
ogmoO`05ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000GoooooVomoOgl00ol0003oIVIVofIV
IP0FofIVIPOo00001_moOgl2o`0000_oVIVI1Ol00008ok>c/`Oo00003?o<c<`=o`0000Ko/k>c1Ol0
0008oiVIV@Co00001?moOgl5o`0001_oIVIV00?o0000ogmoOomoOgl01_moOgl5ooooo`;o00000Ooo
ool001[ooooo00?o0000ooooooooool01?oooonLogmoO`03o`000?mVIVKoIVIV01coIVIV1Ol00003
ogmoO`Go00002onIVIT3o`0000co/k>c3?l0000=ok>c/`Ko00001onIVIT6o`0000GoOgmo0ol0000O
ofIVIP03o`000?moOgooOgmo00OoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CoooooW?moOgl00ol0003oIVIVofIVIP0QofIVIP?o00001OmoOgl6o`0000SoVIVI3?l0000Bok>c
/`Oo00001_nIVIT7o`0000KoOgmo1Ol0000RofIVIP03o`000?moOgooOgmo00OoOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CoooooWOmoOgl00ol0003oIVIVofIVIP0SofIVIP?o
00002?moOgl6o`0000koVIVI4_l00009oiVIV@Co00002_moOgl3o`0002KoIVIV00?o0000ogmoOomo
Ogl02?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonNogmoO`;o0000
9_mVIVH8o`0000KoOgmo:Ol0000:ogmoO`Co0000:?mVIVH00ol0003oOgmoogmoO`09ogmoO`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooj3oOgmo0_l0000/ofIVIPOo00001?mo
Ogl3o`0000KoIVIV4ol00006ogmoO`co0000:_mVIVH2o`0000coOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CoooooX_moOgl00ol0003oIVIVofIVIP0GofIVIPco00003OmVIVH4
o`0001coIVIV1_l0000CofIVIP_o00005_mVIVH2o`0000koOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CoooooXomoOgl2o`0001GoIVIV0_l0000<oda<C0go00001OmVIVH>o`00
00KoIVIV1ol0000<ofIVIPgo00002_m<C4`00ol0003oIVIVofIVIP0CofIVIP03o`000?moOgooOgmo
00koOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooYOmoOgl2o`0001;o
IVIV00?o0000oda<C?m<C4`06Om<C4`5o`0000koC4a<1_l00007oda<C0co00006?m<C4`00ol0003o
IVIVofIVIP0@ofIVIP;o00004OmoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?oooonWogmoO`03o`000?mVIVKoIVIV00goIVIV0_l0001Qoda<C003o`000?mVIVKoIVIV00goIVIV
0_l0000CogmoO`Kooooo0Ol00001ooooo`001oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP06ooooo`03o`000?oooooooooo00CoooooZ?moOgl00ol0003oIVIVofIVIP0;ofIVIP;o0000
H_m<C4`2o`0000coIVIV0_l0000EogmoO`Kooooo0Ol00001ooooo`001oooool01OnHV9So8B4Qonk^
k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00Co
ooooZOmoOgl2o`0000goIVIV0_l0000Moda<C2So00006_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03
o`000?moOgooOgmo01GoOgmo1_ooool1o`00007ooooo0008ooooo`03oiRHV?lQ8B7ok^k^00Cooooo
00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00CoooooZomoOgl3o`0000co
IVIV00?o0000oda<C?m<C4`06Om<C4`00ol0003o<c<coc<c<`0Uoc<c<`03o`000?m<C4coC4a<01Ko
C4a<0_l0000=ofIVIP03o`000?moOgooOgmo01KoOgmo1_ooool1o`00007ooooo0009ooooo`03oiRH
V?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000006ooooo`?o00001?oooon^ogmoO`;o
00002omVIVH2o`0001SoC4a<00?o0000oc<c<olc<c<09olc<c<00ol0003oC4a<oda<C00Coda<C0;o
00003?mVIVH3o`0001WoOgmo1?ooool3o`00007ooooo000:ooooo`03ogMgMomVIVKooooo00;ooooo
00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00Cooooo/?moOgl2o`0000_o
IVIV0_l0000Eoda<C003o`000?lc<c?o<c<c02So<c<c00?o0000oda<C?m<C4`04_m<C4`00ol0003o
IVIVofIVIP09ofIVIP?o00007?moOgl6ooooo`7o00000Oooool000_ooooo00Go0000oooooooooooo
oooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o0000ooooooooool01?oooonbogmoO`;o
00002omVIVH2o`0001;oC4a<00?o0000oc<c<olc<c<0:_lc<c<00ol0003oC4a<oda<C00?oda<C0;o
00002OmVIVH3o`0001ooOgmo1_ooool1o`00007ooooo0007ooooo`05o`000?nj^[[ooooooiRHV?l@
41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?oooondogmo
O`;o00002omVIVH00ol0003oC4a<oda<C00>oda<C003o`000?lc<c?o<c<c02_o<c<c00?o0000oda<
C?m<C4`03Om<C4`2o`0000[oIVIV00?o0000ogmoOomoOgl08?moOgl6ooooo`7o00000Oooool000Oo
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool0
0ol0003oooooooooo`04oooookKoOgmo0ol00009ofIVIPCo00002om<C4`4o`0002Oo<c<c1_l0000<
oda<C0;o00002_mVIVH2o`0002?oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CoooooXomoOgl4o`0001;oOgmo0ol0000:ofIVIP?o00003?m<C4`6o`0001ko<c<c0ol0000Aoda<
C003o`000?mVIVKoIVIV00KoIVIV1?l0000UogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04oooooj?oOgmo00Co0000oiVIVOnIVIWoVIVI1Ol0000@ogmoO`?o00002_mVIVH4o`00
00koC4a<1ol0000Boc<c<`Go00004om<C4`00ol0003oIVIVofIVIP04ofIVIP?o00004_moOgl5o`00
01;oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooX_moOgl00ol0003o
VIVIoiVIV@07oiVIV@?o00004?moOgl2o`0000coIVIV0ol0000Boda<C1;o00003Om<C4`;o`0000Co
IVIV0ol0000@ogmoO`Go00001OnIVIT00ol0003oOgmoogmoO`0?ogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04oooooj;oOgmo00?o0000oiVIVOnIVIT02_nIVIT5o`0000goOgmo
0_l0000=ofIVIPGo00009_m<C4`6o`0000goIVIV0_l0000@ogmoO`?o00002onIVIT2o`0000ooOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooX_moOgl00ol0003oVIVIoiVI
V@0?oiVIV@Go00002_moOgl5o`0000goIVIV1_l0000Ioda<C0Oo00004OmVIVH2o`0000koOgmo1?l0
000@oiVIV@03o`000?moOgooOgmo00coOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CoooooXOmoOgl00ol0003oVIVIoiVIV@0EoiVIV@?o00003?moOgl=o`0000KoIVIV6Ol0000A
ofIVIPOo00002_moOgl6o`0001CoVIVI0_l0000=ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04oooooj;oOgmo00?o0000oiVIVOnIVIT05onIVIT4o`0001GoOgmo1_l0000PofIV
IP[o00003_moOgl3o`0001WoVIVI00?o0000ogmoOomoOgl03OmoOgl6ooooo`7o00000Oooool001[o
oooo0_l00005oooooj?oOgmo0_l0000KoiVIV@?o00006?moOgl7o`0001;oIVIV1ol0000CogmoO`Go
00006onIVIT00ol0003oOgmoogmoO`0>ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooojGoOgmo00?o0000oiVIVOnIVIT06onIVIT5o`0001[oOgmo4_l0000EogmoO`Go0000
7onIVIT00ol0003oOgmoogmoO`0?ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooojKoOgmo00?o0000oiVIVOnIVIT07onIVIT=o`00037oOgmo0ol0000SoiVIV@03o`000?mo
OgooOgmo013oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooYomoOgl0
0ol0003oVIVIoiVIV@0[oiVIV@Ko00008?moOgl;o`0002GoVIVI00?o0000ogmoOomoOgl04OmoOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonXogmoO`03o`000?nIVIWoVIVI
033oVIVI1Ol0000EogmoO`Ko0000;onIVIT00ol0003oOgmoogmoO`0BogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooojWoOgmo0_l0000eoiVIVAGo0000<onIVIT2o`0001Go
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooZomoOgl2o`0007WoVIVI
0_l0000GogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooojgoOgmo00?o
0000oiVIVOnIVIT0M?nIVIT2o`0001WoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00Cooooo[_moOgl2o`0007;oVIVI0_l0000KogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04oooook3oOgmo0_l0001_oiVIV@03o`000?moOgooOgmo01_oOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00Cooooo/_moOgl2o`0006_oVIVI0_l0000NogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooookCoOgmo0_l0001VoiVIV@?o0000
8?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonfogmoO`;o0000H_nI
VIT2o`0002?oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OoooonhogmoO`;o0000GonIVIT0
0ol0003oOgmoogmoO`0SogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04oooo
ok[oOgmo00?o0000oiVIVOnIVIT0FOnIVIT3o`0002KoOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00Cooooo^omoOgl2o`0005KoVIVI0ol0000YogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04oooookgoOgmo1?l0001?oiVIV@?o0000;?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooo1ogmoO`?o0000B_nIVIT2o`0002ooOgmo1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Coooooa?moOgl4o`00047oVIVI1Ol0000a
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooolSoOgmo1Ol0000ioiVI
V@?o0000=_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooo=ogmoO`?o
0000<onIVIT3o`0003WoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
d?moOgl5o`0002_oVIVI0ol0000logmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooomGoOgmo1_l0000PoiVIV@Go0000?omoOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?oooooKogmoO`Oo00003?nIVIT=o`0004CoOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00Coooooh_moOgl<o`00057oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000Gooooo
oomoOgm0ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`00
00GooooooomoOgm0ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`001oooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`001oooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002ooo
ool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool01?ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000[ooooo00?oZJVYoa0@4?ooool00_oo
ool01Ol0003ooooooooooooooooo000000Kooooo0ol00004ooooooooOgmo@?moOgl4ooooo`?o0000
0Oooool000Wooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000:ooooo`03okZj^_lQ
8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`001oooool01Ol@413oV9RHoooooonj^[[o000000?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`001oooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000Wooooo
0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooo
oooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6
ooooo`7o00000Oooool000Oooooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@41001_ooool3
o`0000CooooooomoOgm0ogmoO`Cooooo0ol00001ooooo`001oooool01?m4A4CogMgMooooool00004
ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooood[ooooo0Ol0
0001ooooo`001oooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`3ooooood[ooooo0Ol00001ooooo`002?ooool00omgMgOoc<c<o`00
0004ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`3ooooood[ooooo
0Ol00001ooooo`002?ooool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1_ooool00ol0003oooooooooo`3ooooood[ooooo0Ol00001ooooo`002Oooool00omgMgOo0000oooo
o`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`0Sooooo`03o`00
0?oooooooooo03gooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0mooooo`03o`00
0?oooooooooo03gooooo00?o0000ooooooooool08oooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02Oooool1o`00007ooooo000Joooooooo0000C_l00001
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-30.1723, -14.304, 0.195672, \
0.195672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0192308 0.211538 0.0192308 [
[.11538 -0.0125 -9 -9 ]
[.11538 -0.0125 9 0 ]
[.30769 -0.0125 -9 -9 ]
[.30769 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69231 -0.0125 -6 -9 ]
[.69231 -0.0125 6 0 ]
[.88462 -0.0125 -6 -9 ]
[.88462 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -18 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .21154 -6 -4.5 ]
[-0.0125 .21154 0 4.5 ]
[-0.0125 .40385 -12 -4.5 ]
[-0.0125 .40385 0 4.5 ]
[-0.0125 .59615 -12 -4.5 ]
[-0.0125 .59615 0 4.5 ]
[-0.0125 .78846 -12 -4.5 ]
[-0.0125 .78846 0 4.5 ]
[-0.0125 .98077 -12 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11538 0 m
.11538 .00625 L
s
[(-20)] .11538 -0.0125 0 1 Mshowa
.30769 0 m
.30769 .00625 L
s
[(-10)] .30769 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69231 0 m
.69231 .00625 L
s
[(10)] .69231 -0.0125 0 1 Mshowa
.88462 0 m
.88462 .00625 L
s
[(20)] .88462 -0.0125 0 1 Mshowa
.125 Mabswid
.15385 0 m
.15385 .00375 L
s
.19231 0 m
.19231 .00375 L
s
.23077 0 m
.23077 .00375 L
s
.26923 0 m
.26923 .00375 L
s
.34615 0 m
.34615 .00375 L
s
.38462 0 m
.38462 .00375 L
s
.42308 0 m
.42308 .00375 L
s
.46154 0 m
.46154 .00375 L
s
.53846 0 m
.53846 .00375 L
s
.57692 0 m
.57692 .00375 L
s
.61538 0 m
.61538 .00375 L
s
.65385 0 m
.65385 .00375 L
s
.73077 0 m
.73077 .00375 L
s
.76923 0 m
.76923 .00375 L
s
.80769 0 m
.80769 .00375 L
s
.84615 0 m
.84615 .00375 L
s
.07692 0 m
.07692 .00375 L
s
.03846 0 m
.03846 .00375 L
s
.92308 0 m
.92308 .00375 L
s
.96154 0 m
.96154 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(-10)] -0.0125 .01923 1 0 Mshowa
0 .21154 m
.00625 .21154 L
s
[(0)] -0.0125 .21154 1 0 Mshowa
0 .40385 m
.00625 .40385 L
s
[(10)] -0.0125 .40385 1 0 Mshowa
0 .59615 m
.00625 .59615 L
s
[(20)] -0.0125 .59615 1 0 Mshowa
0 .78846 m
.00625 .78846 L
s
[(30)] -0.0125 .78846 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(40)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .05769 m
.00375 .05769 L
s
0 .09615 m
.00375 .09615 L
s
0 .13462 m
.00375 .13462 L
s
0 .17308 m
.00375 .17308 L
s
0 .25 m
.00375 .25 L
s
0 .28846 m
.00375 .28846 L
s
0 .32692 m
.00375 .32692 L
s
0 .36538 m
.00375 .36538 L
s
0 .44231 m
.00375 .44231 L
s
0 .48077 m
.00375 .48077 L
s
0 .51923 m
.00375 .51923 L
s
0 .55769 m
.00375 .55769 L
s
0 .63462 m
.00375 .63462 L
s
0 .67308 m
.00375 .67308 L
s
0 .71154 m
.00375 .71154 L
s
0 .75 m
.00375 .75 L
s
0 .82692 m
.00375 .82692 L
s
0 .86538 m
.00375 .86538 L
s
0 .90385 m
.00375 .90385 L
s
0 .94231 m
.00375 .94231 L
s
.25 Mabswid
0 0 m
0 1 L
s
.11538 .99375 m
.11538 1 L
s
.30769 .99375 m
.30769 1 L
s
.5 .99375 m
.5 1 L
s
.69231 .99375 m
.69231 1 L
s
.88462 .99375 m
.88462 1 L
s
.125 Mabswid
.15385 .99625 m
.15385 1 L
s
.19231 .99625 m
.19231 1 L
s
.23077 .99625 m
.23077 1 L
s
.26923 .99625 m
.26923 1 L
s
.34615 .99625 m
.34615 1 L
s
.38462 .99625 m
.38462 1 L
s
.42308 .99625 m
.42308 1 L
s
.46154 .99625 m
.46154 1 L
s
.53846 .99625 m
.53846 1 L
s
.57692 .99625 m
.57692 1 L
s
.61538 .99625 m
.61538 1 L
s
.65385 .99625 m
.65385 1 L
s
.73077 .99625 m
.73077 1 L
s
.76923 .99625 m
.76923 1 L
s
.80769 .99625 m
.80769 1 L
s
.84615 .99625 m
.84615 1 L
s
.07692 .99625 m
.07692 1 L
s
.03846 .99625 m
.03846 1 L
s
.92308 .99625 m
.92308 1 L
s
.96154 .99625 m
.96154 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .21154 m
1 .21154 L
s
.99375 .40385 m
1 .40385 L
s
.99375 .59615 m
1 .59615 L
s
.99375 .78846 m
1 .78846 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .05769 m
1 .05769 L
s
.99625 .09615 m
1 .09615 L
s
.99625 .13462 m
1 .13462 L
s
.99625 .17308 m
1 .17308 L
s
.99625 .25 m
1 .25 L
s
.99625 .28846 m
1 .28846 L
s
.99625 .32692 m
1 .32692 L
s
.99625 .36538 m
1 .36538 L
s
.99625 .44231 m
1 .44231 L
s
.99625 .48077 m
1 .48077 L
s
.99625 .51923 m
1 .51923 L
s
.99625 .55769 m
1 .55769 L
s
.99625 .63462 m
1 .63462 L
s
.99625 .67308 m
1 .67308 L
s
.99625 .71154 m
1 .71154 L
s
.99625 .75 m
1 .75 L
s
.99625 .82692 m
1 .82692 L
s
.99625 .86538 m
1 .86538 L
s
.99625 .90385 m
1 .90385 L
s
.99625 .94231 m
1 .94231 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.4 g
.50981 .57327 m
.52943 .57719 L
.54906 .57498 L
.56868 .5863 L
.57728 .5883 L
.5883 .59137 L
.60793 .59586 L
.62755 .5956 L
.64717 .60177 L
.6668 .60545 L
.68642 .6075 L
.69313 .60793 L
.70604 .60863 L
.72567 .60922 L
.74529 .60904 L
.76491 .60806 L
.767 .60793 L
.78454 .60671 L
.80416 .60391 L
.82378 .59925 L
.84341 .59792 L
.86303 .59379 L
.88265 .58897 L
.88378 .5883 L
.90228 .5825 L
.9219 .57953 L
.94152 .57516 L
.96115 .57224 L
.96376 .5883 L
.96115 .59589 L
.94516 .60793 L
.94152 .61181 L
.9219 .62163 L
.91023 .62755 L
.90228 .63127 L
.88265 .64303 L
.86303 .64706 L
.86268 .64717 L
.84341 .65202 L
.82378 .6583 L
.80416 .66335 L
.78454 .66639 L
.77832 .6668 L
.76491 .66823 L
.74529 .66954 L
.72567 .66979 L
.70604 .66899 L
.68642 .66713 L
.68369 .6668 L
.6668 .66511 L
.64717 .66093 L
.62755 .65513 L
.60793 .64884 L
.59892 .64717 L
.5883 .64347 L
.56868 .63655 L
.5512 .62755 L
.54906 .62649 L
.52943 .61604 L
.51633 .60793 L
.50981 .60321 L
.49178 .5883 L
F
0 g
.50981 .57327 m
.52943 .57719 L
.54906 .57498 L
.56868 .5863 L
.57728 .5883 L
.5883 .59137 L
.60793 .59586 L
.62755 .5956 L
.64717 .60177 L
.6668 .60545 L
.68642 .6075 L
.69313 .60793 L
.70604 .60863 L
.72567 .60922 L
.74529 .60904 L
.76491 .60806 L
.767 .60793 L
.78454 .60671 L
.80416 .60391 L
.82378 .59925 L
.84341 .59792 L
.86303 .59379 L
.88265 .58897 L
.88378 .5883 L
.90228 .5825 L
.9219 .57953 L
.94152 .57516 L
.96115 .57224 L
.96376 .5883 L
.96115 .59589 L
.94516 .60793 L
.94152 .61181 L
.9219 .62163 L
.91023 .62755 L
.90228 .63127 L
.88265 .64303 L
.86303 .64706 L
.86268 .64717 L
.84341 .65202 L
.82378 .6583 L
.80416 .66335 L
.78454 .66639 L
.77832 .6668 L
.76491 .66823 L
.74529 .66954 L
.72567 .66979 L
.70604 .66899 L
.68642 .66713 L
.68369 .6668 L
.6668 .66511 L
Mistroke
.64717 .66093 L
.62755 .65513 L
.60793 .64884 L
.59892 .64717 L
.5883 .64347 L
.56868 .63655 L
.5512 .62755 L
.54906 .62649 L
.52943 .61604 L
.51633 .60793 L
.50981 .60321 L
.49178 .5883 L
.50981 .57327 L
Mfstroke
.6 g
.50981 .52039 m
.52943 .52161 L
.54906 .52317 L
.56868 .5286 L
.57325 .52943 L
.5883 .53268 L
.60793 .53633 L
.62755 .53753 L
.64717 .54398 L
.6668 .54449 L
.68642 .54621 L
.70604 .54733 L
.72567 .54782 L
.74529 .54767 L
.76491 .54687 L
.78454 .54545 L
.80416 .54683 L
.82378 .54116 L
.84341 .53282 L
.86303 .53464 L
.88265 .53076 L
.88629 .52943 L
.90228 .52793 L
.9219 .52312 L
.94152 .52062 L
.96115 .52234 L
.9619 .52943 L
.96115 .53377 L
.94299 .54906 L
.94152 .55148 L
.9219 .56041 L
.90435 .56868 L
.90228 .56954 L
.88265 .58181 L
.86303 .58339 L
.84578 .5883 L
.84341 .58895 L
.82378 .59248 L
.80416 .59753 L
.78454 .60183 L
.76491 .60513 L
.74529 .60712 L
.72567 .60753 L
.70604 .60627 L
.68642 .60356 L
.6668 .59971 L
.64717 .59496 L
.62755 .58988 L
.61576 .5883 L
.60793 .58615 L
.5883 .58021 L
.56868 .57445 L
.55723 .56868 L
.54906 .56495 L
.52943 .55523 L
.51859 .54906 L
.50981 .54225 L
.496 .52943 L
F
0 g
.50981 .52039 m
.52943 .52161 L
.54906 .52317 L
.56868 .5286 L
.57325 .52943 L
.5883 .53268 L
.60793 .53633 L
.62755 .53753 L
.64717 .54398 L
.6668 .54449 L
.68642 .54621 L
.70604 .54733 L
.72567 .54782 L
.74529 .54767 L
.76491 .54687 L
.78454 .54545 L
.80416 .54683 L
.82378 .54116 L
.84341 .53282 L
.86303 .53464 L
.88265 .53076 L
.88629 .52943 L
.90228 .52793 L
.9219 .52312 L
.94152 .52062 L
.96115 .52234 L
.9619 .52943 L
.96115 .53377 L
.94299 .54906 L
.94152 .55148 L
.9219 .56041 L
.90435 .56868 L
.90228 .56954 L
.88265 .58181 L
.86303 .58339 L
.84578 .5883 L
.84341 .58895 L
.82378 .59248 L
.80416 .59753 L
.78454 .60183 L
.76491 .60513 L
.74529 .60712 L
.72567 .60753 L
.70604 .60627 L
.68642 .60356 L
.6668 .59971 L
.64717 .59496 L
.62755 .58988 L
.61576 .5883 L
.60793 .58615 L
Mistroke
.5883 .58021 L
.56868 .57445 L
.55723 .56868 L
.54906 .56495 L
.52943 .55523 L
.51859 .54906 L
.50981 .54225 L
.496 .52943 L
.50981 .52039 L
Mfstroke
.4 g
.52943 .48046 m
.54906 .47841 L
.56868 .47984 L
.5883 .47425 L
.60793 .48466 L
.62755 .48723 L
.64717 .48965 L
.65191 .49019 L
.6668 .4916 L
.68642 .49301 L
.70604 .49391 L
.72567 .4943 L
.74529 .49418 L
.76491 .49354 L
.78454 .4924 L
.80416 .49074 L
.80957 .49019 L
.82378 .48852 L
.84341 .48601 L
.86303 .48383 L
.88265 .48096 L
.90228 .47899 L
.9219 .47851 L
.93587 .49019 L
.9219 .49966 L
.90418 .50981 L
.90228 .51171 L
.88265 .5178 L
.86303 .52404 L
.84415 .52943 L
.84341 .52954 L
.82378 .53498 L
.80416 .54277 L
.78454 .53949 L
.76491 .54121 L
.74529 .54216 L
.72567 .54235 L
.70604 .54176 L
.68642 .54041 L
.6668 .5383 L
.64717 .53843 L
.62755 .53172 L
.61741 .52943 L
.60793 .52681 L
.5883 .52088 L
.56868 .51423 L
.55739 .50981 L
.54906 .50526 L
.52943 .49298 L
.52576 .49019 L
F
0 g
.52943 .48046 m
.54906 .47841 L
.56868 .47984 L
.5883 .47425 L
.60793 .48466 L
.62755 .48723 L
.64717 .48965 L
.65191 .49019 L
.6668 .4916 L
.68642 .49301 L
.70604 .49391 L
.72567 .4943 L
.74529 .49418 L
.76491 .49354 L
.78454 .4924 L
.80416 .49074 L
.80957 .49019 L
.82378 .48852 L
.84341 .48601 L
.86303 .48383 L
.88265 .48096 L
.90228 .47899 L
.9219 .47851 L
.93587 .49019 L
.9219 .49966 L
.90418 .50981 L
.90228 .51171 L
.88265 .5178 L
.86303 .52404 L
.84415 .52943 L
.84341 .52954 L
.82378 .53498 L
.80416 .54277 L
.78454 .53949 L
.76491 .54121 L
.74529 .54216 L
.72567 .54235 L
.70604 .54176 L
.68642 .54041 L
.6668 .5383 L
.64717 .53843 L
.62755 .53172 L
.61741 .52943 L
.60793 .52681 L
.5883 .52088 L
.56868 .51423 L
.55739 .50981 L
.54906 .50526 L
.52943 .49298 L
.52576 .49019 L
Mistroke
.52943 .48046 L
Mfstroke
.6 g
.52943 .6505 m
.54906 .65429 L
.56868 .6592 L
.5883 .66394 L
.60294 .6668 L
.60793 .66861 L
.62755 .67327 L
.64717 .67711 L
.6668 .68009 L
.68642 .68225 L
.70604 .68361 L
.72567 .6842 L
.74529 .68402 L
.76491 .68305 L
.78454 .68131 L
.80416 .67876 L
.82378 .67537 L
.84341 .67113 L
.86031 .6668 L
.86303 .66569 L
.88265 .66171 L
.90228 .65683 L
.9219 .65214 L
.93527 .6668 L
.9219 .67633 L
.90613 .68642 L
.90228 .69016 L
.88265 .69894 L
.86631 .70604 L
.86303 .70743 L
.84341 .71686 L
.82378 .72084 L
.80416 .72545 L
.80316 .72567 L
.78454 .72884 L
.76491 .73149 L
.74529 .73304 L
.72567 .73334 L
.70604 .73238 L
.68642 .73023 L
.6668 .72714 L
.65829 .72567 L
.64717 .7232 L
.62755 .72284 L
.60793 .71169 L
.59521 .70604 L
.5883 .70315 L
.56868 .69392 L
.55533 .68642 L
.54906 .68251 L
.52943 .6686 L
.52726 .6668 L
F
0 g
.52943 .6505 m
.54906 .65429 L
.56868 .6592 L
.5883 .66394 L
.60294 .6668 L
.60793 .66861 L
.62755 .67327 L
.64717 .67711 L
.6668 .68009 L
.68642 .68225 L
.70604 .68361 L
.72567 .6842 L
.74529 .68402 L
.76491 .68305 L
.78454 .68131 L
.80416 .67876 L
.82378 .67537 L
.84341 .67113 L
.86031 .6668 L
.86303 .66569 L
.88265 .66171 L
.90228 .65683 L
.9219 .65214 L
.93527 .6668 L
.9219 .67633 L
.90613 .68642 L
.90228 .69016 L
.88265 .69894 L
.86631 .70604 L
.86303 .70743 L
.84341 .71686 L
.82378 .72084 L
.80416 .72545 L
.80316 .72567 L
.78454 .72884 L
.76491 .73149 L
.74529 .73304 L
.72567 .73334 L
.70604 .73238 L
.68642 .73023 L
.6668 .72714 L
.65829 .72567 L
.64717 .7232 L
.62755 .72284 L
.60793 .71169 L
.59521 .70604 L
.5883 .70315 L
.56868 .69392 L
.55533 .68642 L
.54906 .68251 L
Mistroke
.52943 .6686 L
.52726 .6668 L
.52943 .6505 L
Mfstroke
.6 g
.56868 .44739 m
.5883 .44214 L
.60793 .44203 L
.62755 .44286 L
.64717 .43982 L
.6668 .4451 L
.68642 .44604 L
.70604 .4467 L
.72567 .44699 L
.74529 .4469 L
.76491 .44642 L
.78454 .44562 L
.80416 .44679 L
.82378 .44343 L
.84341 .4424 L
.86303 .44189 L
.88265 .44313 L
.89387 .45094 L
.88265 .45767 L
.86303 .46706 L
.85427 .47057 L
.84341 .47329 L
.82378 .47742 L
.80416 .48079 L
.78454 .48343 L
.76491 .4853 L
.74529 .48635 L
.72567 .48655 L
.70604 .48591 L
.68642 .48442 L
.6668 .48215 L
.64717 .47913 L
.62755 .47538 L
.60793 .47075 L
.60725 .47057 L
.5883 .46243 L
.56868 .45161 L
.56775 .45094 L
F
0 g
.56868 .44739 m
.5883 .44214 L
.60793 .44203 L
.62755 .44286 L
.64717 .43982 L
.6668 .4451 L
.68642 .44604 L
.70604 .4467 L
.72567 .44699 L
.74529 .4469 L
.76491 .44642 L
.78454 .44562 L
.80416 .44679 L
.82378 .44343 L
.84341 .4424 L
.86303 .44189 L
.88265 .44313 L
.89387 .45094 L
.88265 .45767 L
.86303 .46706 L
.85427 .47057 L
.84341 .47329 L
.82378 .47742 L
.80416 .48079 L
.78454 .48343 L
.76491 .4853 L
.74529 .48635 L
.72567 .48655 L
.70604 .48591 L
.68642 .48442 L
.6668 .48215 L
.64717 .47913 L
.62755 .47538 L
.60793 .47075 L
.60725 .47057 L
.5883 .46243 L
.56868 .45161 L
.56775 .45094 L
.56868 .44739 L
s
.7 g
.5883 .5456 m
.60793 .54611 L
.62755 .54661 L
.64556 .54906 L
.64717 .54929 L
.6668 .55099 L
.68642 .5523 L
.70604 .55315 L
.72567 .55353 L
.74529 .55341 L
.76491 .5528 L
.78454 .55173 L
.80416 .55022 L
.81636 .54906 L
.82378 .5483 L
.84341 .54391 L
.86303 .54567 L
.88265 .54637 L
.89202 .54906 L
.88265 .56051 L
.87091 .56868 L
.86303 .57218 L
.84341 .57944 L
.82378 .58535 L
.81231 .5883 L
.80416 .59038 L
.78454 .59553 L
.76491 .60033 L
.74529 .60384 L
.72567 .60463 L
.70604 .60226 L
.68642 .59792 L
.6668 .59286 L
.64924 .5883 L
.64717 .58779 L
.62755 .58242 L
.60793 .57587 L
.59062 .56868 L
.5883 .56724 L
.57083 .54906 L
F
0 g
.5883 .5456 m
.60793 .54611 L
.62755 .54661 L
.64556 .54906 L
.64717 .54929 L
.6668 .55099 L
.68642 .5523 L
.70604 .55315 L
.72567 .55353 L
.74529 .55341 L
.76491 .5528 L
.78454 .55173 L
.80416 .55022 L
.81636 .54906 L
.82378 .5483 L
.84341 .54391 L
.86303 .54567 L
.88265 .54637 L
.89202 .54906 L
.88265 .56051 L
.87091 .56868 L
.86303 .57218 L
.84341 .57944 L
.82378 .58535 L
.81231 .5883 L
.80416 .59038 L
.78454 .59553 L
.76491 .60033 L
.74529 .60384 L
.72567 .60463 L
.70604 .60226 L
.68642 .59792 L
.6668 .59286 L
.64924 .5883 L
.64717 .58779 L
.62755 .58242 L
.60793 .57587 L
.59062 .56868 L
.5883 .56724 L
.57083 .54906 L
.5883 .5456 L
s
.3 g
.5883 .60717 m
.60793 .6076 L
.61222 .60793 L
.62755 .60963 L
.64717 .61186 L
.6668 .6138 L
.68642 .61529 L
.70604 .61626 L
.72567 .61668 L
.74529 .61655 L
.76491 .61586 L
.78454 .61464 L
.80416 .61292 L
.82378 .61081 L
.84341 .60855 L
.84935 .60793 L
.86303 .6071 L
.87935 .60793 L
.86678 .62755 L
.86303 .62953 L
.84341 .63814 L
.82378 .64488 L
.81606 .64717 L
.80416 .65123 L
.78454 .6586 L
.76491 .65669 L
.74529 .6581 L
.72567 .65837 L
.70604 .65751 L
.68642 .66262 L
.6668 .65464 L
.64717 .64772 L
.64554 .64717 L
.62755 .64156 L
.60793 .63397 L
.59471 .62755 L
.5883 .62293 L
.58223 .60793 L
F
0 g
.5883 .60717 m
.60793 .6076 L
.61222 .60793 L
.62755 .60963 L
.64717 .61186 L
.6668 .6138 L
.68642 .61529 L
.70604 .61626 L
.72567 .61668 L
.74529 .61655 L
.76491 .61586 L
.78454 .61464 L
.80416 .61292 L
.82378 .61081 L
.84341 .60855 L
.84935 .60793 L
.86303 .6071 L
.87935 .60793 L
.86678 .62755 L
.86303 .62953 L
.84341 .63814 L
.82378 .64488 L
.81606 .64717 L
.80416 .65123 L
.78454 .6586 L
.76491 .65669 L
.74529 .6581 L
.72567 .65837 L
.70604 .65751 L
.68642 .66262 L
.6668 .65464 L
.64717 .64772 L
.64554 .64717 L
.62755 .64156 L
.60793 .63397 L
.59471 .62755 L
.5883 .62293 L
.58223 .60793 L
.5883 .60717 L
s
.3 g
.60793 .50204 m
.62755 .49962 L
.64717 .4996 L
.6668 .5001 L
.68642 .50067 L
.70604 .5011 L
.72567 .5013 L
.74529 .50124 L
.76491 .50092 L
.78454 .50041 L
.80416 .49984 L
.82378 .49949 L
.84341 .50018 L
.85893 .50981 L
.84341 .51732 L
.82378 .52444 L
.80618 .52943 L
.80416 .53036 L
.78454 .533 L
.76491 .53512 L
.74529 .53627 L
.72567 .5365 L
.70604 .53579 L
.68642 .53414 L
.6668 .53149 L
.65529 .52943 L
.64717 .52727 L
.62755 .52096 L
.60793 .51271 L
.60263 .50981 L
F
0 g
.60793 .50204 m
.62755 .49962 L
.64717 .4996 L
.6668 .5001 L
.68642 .50067 L
.70604 .5011 L
.72567 .5013 L
.74529 .50124 L
.76491 .50092 L
.78454 .50041 L
.80416 .49984 L
.82378 .49949 L
.84341 .50018 L
.85893 .50981 L
.84341 .51732 L
.82378 .52444 L
.80618 .52943 L
.80416 .53036 L
.78454 .533 L
.76491 .53512 L
.74529 .53627 L
.72567 .5365 L
.70604 .53579 L
.68642 .53414 L
.6668 .53149 L
.65529 .52943 L
.64717 .52727 L
.62755 .52096 L
.60793 .51271 L
.60263 .50981 L
.60793 .50204 L
s
.8 g
.62755 .56407 m
.64717 .55956 L
.6668 .55924 L
.68642 .55949 L
.70604 .55979 L
.72567 .55995 L
.74529 .5599 L
.76491 .55966 L
.78454 .55935 L
.80416 .55926 L
.82378 .56043 L
.83444 .56868 L
.82378 .57388 L
.80416 .58061 L
.78454 .58539 L
.7673 .5883 L
.76491 .58881 L
.74529 .59255 L
.72567 .59341 L
.70604 .59085 L
.69264 .5883 L
.68642 .58711 L
.6668 .58311 L
.64717 .57742 L
.62755 .56888 L
.62723 .56868 L
F
0 g
.62755 .56407 m
.64717 .55956 L
.6668 .55924 L
.68642 .55949 L
.70604 .55979 L
.72567 .55995 L
.74529 .5599 L
.76491 .55966 L
.78454 .55935 L
.80416 .55926 L
.82378 .56043 L
.83444 .56868 L
.82378 .57388 L
.80416 .58061 L
.78454 .58539 L
.7673 .5883 L
.76491 .58881 L
.74529 .59255 L
.72567 .59341 L
.70604 .59085 L
.69264 .5883 L
.68642 .58711 L
.6668 .58311 L
.64717 .57742 L
.62755 .56888 L
.62723 .56868 L
.62755 .56407 L
s
.4 g
.6668 .41052 m
.68642 .40976 L
.70604 .40952 L
.72567 .40946 L
.74529 .40948 L
.76491 .4096 L
.78454 .41002 L
.80416 .41137 L
.80676 .4117 L
.80416 .421 L
.78454 .42746 L
.76491 .43089 L
.76119 .43132 L
.74529 .43208 L
.72567 .43227 L
.70604 .43165 L
.69896 .43132 L
.68642 .42936 L
.6668 .42467 L
.65443 .4117 L
F
0 g
.6668 .41052 m
.68642 .40976 L
.70604 .40952 L
.72567 .40946 L
.74529 .40948 L
.76491 .4096 L
.78454 .41002 L
.80416 .41137 L
.80676 .4117 L
.80416 .421 L
.78454 .42746 L
.76491 .43089 L
.76119 .43132 L
.74529 .43208 L
.72567 .43227 L
.70604 .43165 L
.69896 .43132 L
.68642 .42936 L
.6668 .42467 L
.65443 .4117 L
.6668 .41052 L
s
.7 g
.68642 .46573 m
.70604 .46306 L
.72567 .46245 L
.74529 .46263 L
.76491 .46384 L
.7784 .47057 L
.76491 .47265 L
.74529 .47443 L
.72567 .47476 L
.70604 .4737 L
.68642 .47105 L
.68373 .47057 L
F
0 g
.68642 .46573 m
.70604 .46306 L
.72567 .46245 L
.74529 .46263 L
.76491 .46384 L
.7784 .47057 L
.76491 .47265 L
.74529 .47443 L
.72567 .47476 L
.70604 .4737 L
.68642 .47105 L
.68373 .47057 L
.68642 .46573 L
s
.2 g
.68642 .62744 m
.70604 .62709 L
.72567 .62704 L
.74529 .62705 L
.76491 .62719 L
.77769 .62755 L
.76491 .64103 L
.74529 .64361 L
.72567 .64409 L
.70604 .64255 L
.68642 .63864 L
.68389 .62755 L
F
0 g
.68642 .62744 m
.70604 .62709 L
.72567 .62704 L
.74529 .62705 L
.76491 .62719 L
.77769 .62755 L
.76491 .64103 L
.74529 .64361 L
.72567 .64409 L
.70604 .64255 L
.68642 .63864 L
.68389 .62755 L
.68642 .62744 L
s
.2 g
.70604 .50979 m
.72567 .50963 L
.74529 .50967 L
.75708 .50981 L
.74529 .52869 L
.72567 .52914 L
.70604 .52768 L
.70457 .50981 L
F
0 g
.70604 .50979 m
.72567 .50963 L
.74529 .50967 L
.75708 .50981 L
.74529 .52869 L
.72567 .52914 L
.70604 .52768 L
.70457 .50981 L
.70604 .50979 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00?Oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0dooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kS?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0hooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8b
onk^kS?ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08_ooool003gooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0=_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0<oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg03?ooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL08_ooool003Gooooo1_l0
0003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400[ooooo`Ko0000
1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100<oooool01Ol@413o
oooooooooooooooo410@03[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@03Cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@02;ooooo000o
ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000fooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000cooooo`05o`000?ooooooooooooooool0
0000>_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000=Oooool00onH
V9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000008_ooool0043ooooo00?oMgMgofIV
I_ooool00_ooool01Ol0003ooooooooooooooooo000003Kooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000003?ooooo00Go0000ooooooooooooooooo`00000jooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`03ogMgMomVIVKooooo00;o
oooo00Go0000ooooooooooooooooo`00000Rooooo`00@Oooool01Ol0003ooooooooooooooooo410@
00?ooooo00?o410@ooooooooool0=?ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@4100<oooool01Ol@413ooooooooooooooooo410@03[ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@03Oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo023ooooo000mooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg03Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg03?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0jooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0cooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02;ooooo000mooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^03Cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^03?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`03oeEEEOmVIVKo000000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0cooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02;ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo000Joooooooo0000C_l00001ooooo`00
6_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0?Ooo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool08ooo
ool1o`00007ooooo0008ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKo
oooo00?o0000ooooooooool0oooooom:ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooom:ooooo`7o
00000Oooool000Go00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41001_ooool00ol0003oooooooooo`3ooooood[ooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?ooooooB?ooool3o`00007o
oooo000:ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo0008ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Oooooooogmo
Od3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Ooo
ooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000oooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`003ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000?ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000oooooo00Go0000oooooooooooooooo
o`000006ooooo`?o00001?ooooooogmoOd3oOgmo1?ooool3o`00007ooooo000?ooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool000oooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`003oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000?ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo0008
ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000:ooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`002_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41001_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000[ooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo0ol00004oooooooo
Ogmo@?moOgl4ooooo`?o00000Oooool000[ooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000:ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03
o`000?oooooooooo00CooooodomoOglco`0003WoOgmo1_ooool1o`00007ooooo000:ooooo`03o`00
0?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00Co
oooodomoOgl00ol0003oIVIVofIVIP0_ofIVIP03o`000?moOgooOgmo03OoOgmo1_ooool1o`00007o
oooo0008ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03
o`000?oooooooooo00Coooooe?moOgl00ol0003oIVIVofIVIP0]ofIVIP03o`000?moOgooOgmo03So
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooeOmoOgl00ol0003oIVIV
ofIVIP0[ofIVIP;o0000>_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
oooFogmoO`03o`000?mVIVKoIVIV02SoIVIV0_l0000logmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooomOoOgmo1?l0000TofIVIP;o0000?_moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?oooooKogmoO`Go00006omVIVH4o`00043oOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00Coooooh?moOglKo`0004CoOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?oooonkogmoO`go00001OmoOgl8o`00043oOgmo1ol0000SogmoO`Kooooo0Ol00001
ooooo`006_ooool2o`0000Gooooo^?moOgl3o`0000goVIVI1Ol00008oiVIV@Ko0000;OmoOgl=o`00
00OoVIVI1?l0000OogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04oooookKo
Ogmo0_l0000SoiVIVBgo00006?nIVIT2o`0001goOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00Cooooo]_moOgl00ol0003oVIVIoiVIV@1XoiVIV@;o00007?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?oooonfogmoO`;o0000J?nIVIT00ol0003oOgmoogmo
O`0LogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooookSoOgmo0ol0001T
oiVIV@03o`000?moOgooOgmo01goOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00Cooooo^omoOgl2o`00063oVIVI0_l0000PogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04oooookgoOgmo0_l0000RoiVIVACo00009_nIVIT2o`0002;oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00Cooooo_omoOgl2o`0001coVIVI1?l0000Dok>c/`Co0000
8?nIVIT2o`0002CoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo`Omo
Ogl2o`0001[oVIVI00?o0000ok>c/onc/k<06Onc/k<3o`0001_oVIVI0_l0000VogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04oooool?oOgmo0ol0000FoiVIV@Ko00006?nc/k<3
o`0001KoVIVI1?l0000XogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
ok_oOgmo1?l00007ogmoO`?o00006OnIVITHo`0001CoVIVI1Ol0000/ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04oooookSoOgmo0ol00004ofIVIP03o`000?moOgooOgmo00Oo
Ogmo1Ol0000joiVIV@Ko0000<OmoOgl6ooooo`7o00000Oooool001[ooooo0_l00005ooooojWoOgmo
3ol00008ofIVIP;o00003?moOgl7o`0002coVIVI1ol0000CogmoOa;o00004_moOgl5ooooo`;o0000
0Oooool001[ooooo00?o0000ooooooooool01?oooonYogmoO`03o`000?mVIVKoIVIV01KoIVIV00?o
0000ogmoOomoOgl04?moOgl6o`00023oVIVI1_l0000DogmoO`Ko00004_mVIVH2o`00013oOgmo1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooZ?moOgl00ol0003oIVIVofIVIP0H
ofIVIP_o00003OmoOglPo`0001?oOgmo1ol0000JofIVIP03o`000?moOgooOgmo00goOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooZ?moOgl00ol0003oIVIVofIVIP0SofIV
IPSo0000;omoOgl9o`00027oIVIV0_l0000>ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooojWoOgmo0_l0000[ofIVIPco00006OmoOgl:o`0002WoIVIV00?o0000ogmoOomo
Ogl03_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon[ogmoO`;o0000
=OmVIVHIo`0003;oIVIV00?o0000ogmoOomoOgl03omoOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?oooon]ogmoO`03o`000?mVIVKoIVIV07coIVIV00?o0000ogmoOomoOgl04?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon^ogmoO`;o00004omVIVI@
o`0001OoIVIV0_l0000CogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
ok3oOgmo00?o0000ofIVI_mVIVH04?mVIVH00ol0003oC4a<oda<C01=oda<C0;o00004omVIVH2o`00
01GoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo/OmoOgl00ol0003o
IVIVofIVIP0>ofIVIP03o`000?m<C4coC4a<053oC4a<00?o0000ofIVI_mVIVH03omVIVH00ol0003o
OgmoogmoO`0EogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooook;oOgmo
0ol0000<ofIVIP;o00008?m<C4`Co`0001ooC4a<0_l0000?ofIVIP03o`000?moOgooOgmo01KoOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo]OmoOgl3o`0000_oIVIV0_l0
000Noda<C003o`000?lc<c?o<c<c00oo<c<c00?o0000oda<C?m<C4`06_m<C4`3o`0000koIVIV0ol0
000IogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooookSoOgmo0ol0000:
ofIVIP?o00006om<C4`00ol0003o<c<coc<c<`0>oc<c<`03o`000?m<C4coC4a<01WoC4a<0_l0000>
ofIVIP?o00007?moOgl6ooooo`7o00000Oooool001[ooooo0_l00005oooooj;oOgmo1Ol0000Dogmo
O`;o00002omVIVH2o`0001WoC4a<00?o0000oc<c<olc<c<03Olc<c<00ol0003oC4a<oda<C00Hoda<
C0;o00003OmVIVH3o`0001ooOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
ooooX?moOgl2o`0000GoVIVI3?l0000:ogmoO`?o00002_mVIVH3o`0001OoC4a<00?o0000oc<c<olc
<c<03?lc<c<00ol0003oC4a<oda<C00Foda<C0;o00003?mVIVH3o`0000goOgmo3ol00006ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooiooOgmo00?o0000oiVIVOnIVIT0
4OnIVIT3o`0000[oOgmo0ol0000:ofIVIP?o00005?m<C4`00ol0003o<c<coc<c<`0;oc<c<`03o`00
0?m<C4coC4a<01?oC4a<1?l00009ofIVIPGo00003OmoOgl3o`0000koVIVI00?o0000ogmoOomoOgl0
1?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonNogmoO`03o`000?nI
VIWoVIVI01GoVIVI1?l00009ogmoO`Ko00001omVIVH6o`0000koC4a<3_l0000Coda<C0?o00002_mV
IVH3o`0000[oOgmo2?l0000BoiVIV@03o`000?moOgooOgmo00?oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CoooooWomoOgl00ol0003oVIVIoiVIV@0HoiVIV@?o00003?moOgl4
o`0000WoIVIV1Ol0000Voda<C0Co00002OmVIVH4o`0000WoOgmo1?l0000JoiVIV@03o`000?moOgoo
Ogmo00?oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooX?moOgl00ol0
003oVIVIoiVIV@0JoiVIV@Co00003?moOgl3o`0000_oIVIV1ol0000Boda<C0go00002OmVIVH4o`00
00;oOgmo2ol0000LoiVIV@;o00001_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?oooonQogmoO`03o`000?nIVIWoVIVI01goVIVI3?l00003ogmoO`_o00001omVIVHBo`0001?o
IVIV0ol00003ogmoO`?o00009_nIVIT00ol0003oOgmoogmoO`06ogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04oooooj;oOgmo00?o0000oiVIVOnIVIT0:?nIVIT3o`0000_oOgmo
1ol0000BofIVIPko00000omVIVH2o`0000;oOgmo1?l0000XoiVIV@03o`000?moOgooOgmo00OoOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooXomoOgl00ol0003oVIVIoiVI
V@0ZoiVIV@_o00001omoOglBo`0000koOgmo0ol000001?moOgoo0000o`000?l00007oiVIV@Ko0000
7_nIVIT00ol0003oOgmoogmoO`08ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooojCoOgmo00?o0000oiVIVOnIVIT04onIVITDo`0000goVIVI3Ol0000<ogmoOa;o00001onI
VIT3o`0000Ko/k>c2ol0000BoiVIV@03o`000?moOgooOgmo00WoOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CoooooYOmoOgl2o`00013oVIVI0ol0000Dok>c/`Oo00004onIVIT<
o`0000goVIVI3?l0000Dok>c/`03o`000?nIVIWoVIVI00koVIVI00?o0000ogmoOomoOgl02_moOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonWogmoO`;o00003onIVIT00ol0
003o/k>cok>c/`0Jok>c/bco00008?nc/k<00ol0003oVIVIoiVIV@0=oiVIV@;o00003?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonYogmoO`;o00003_nIVIT00ol0003o
/k>cok>c/`1Tok>c/`03o`000?nIVIWoVIVI00_oVIVI0ol0000>ogmoO`Kooooo0Ol00001ooooo`00
6_ooool2o`0000GoooooZomoOgl3o`0000coVIVI00?o0000ok>c/onc/k<04_nc/k<Co`0001Wo/k>c
3_l0000Fok>c/`03o`000?nIVIWoVIVI00[oVIVI0_l0000AogmoO`Gooooo0_l00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooojkoOgmo0_l0000;oiVIV@03o`000?nc/k?o/k>c00ko/k>c0ol0
000Colc<c1Wo00003_o<c<`3o`00017o/k>c0_l0000;oiVIV@;o00004omoOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?oooon`ogmoO`03o`000?nIVIWoVIVI00WoVIVI00?o0000
ok>c/onc/k<02onc/k<2o`00043oc<c<00?o0000ok>c/onc/k<03Onc/k<00ol0003oVIVIoiVIV@09
oiVIV@;o00005OmoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonaogmo
O`03o`000?nIVIWoVIVI00WoVIVI00?o0000ok>c/onc/k<02_nc/k<00ol0003oc<c<olc<c010olc<
c003o`000?nc/k?o/k>c00_o/k>c00?o0000oiVIVOnIVIT02OnIVIT00ol0003oOgmoogmoO`0Eogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooook;oOgmo0ol00008oiVIV@?o
00002_nc/k<3o`00043oc<c<0_l0000:ok>c/`;o00002OnIVIT3o`0001SoOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CoooooX_moOgl5o`0000koOgmo1?l00007oiVIV@?o0000
2_nc/k<3o`0003Woc<c<1?l00009ok>c/`?o00002OnIVIT2o`00017oOgmo1?l00006ogmoO`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooj7oOgmo00?o0000ofIVI_mVIVH00omV
IVH;o`0000OoOgmo0ol00007oiVIV@?o00002_nc/k<3o`0003?oc<c<0ol0000:ok>c/`?o00002onI
VIT00ol0003oOgmoogmoO`0;ogmoO`Ko00000omVIVH00ol0003oOgmoogmoO`04ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04oooooj3oOgmo00?o0000ofIVI_mVIVH03omVIVH2
o`0000SoOgmo1?l00006oiVIV@?o00002_nc/k<3o`0002goc<c<0ol0000:ok>c/`?o00003?nIVIT2
o`0000OoOgmo1ol00009ofIVIP03o`000?moOgooOgmo00CoOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CoooooWomoOgl00ol0003oIVIVofIVIP0BofIVIP;o00002_moOgl3o`00
00KoVIVI1?l00009ok>c/`Co00009_o<c<`3o`0000[o/k>c0ol00007oiVIV@So00001OmoOgl4o`00
017oIVIV00?o0000ogmoOomoOgl00omoOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?oooonNogmoO`03o`000?mVIVKoIVIV01GoIVIV0ol0000:ogmoO`?o00001onIVIT3o`0000[o
/k>c0ol0000Nolc<c0Go00002Onc/k<4o`0000OoVIVI0ol0000:ogmoO`?o00005OmVIVH00ol0003o
OgmoogmoO`03ogmoO`Kooooo0Ol00001ooooo`001oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP06ooooo`03o`000?oooooooooo00CoooooWOmoOgl2o`0001[oIVIV0ol0000:ogmoO`?o
00001onIVIT4o`0000Wo/k>c1_l0000Aolc<c0Oo00002onc/k<3o`0000GoVIVI1_l00009ogmoO`Co
00006?mVIVH00ol0003oOgmoogmoO`03ogmoO`Kooooo0Ol00001ooooo`001oooool01OnHV9So8B4Q
onk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo
00CoooooWomoOgl00ol0003oIVIVofIVIP0JofIVIPCo00002OmoOgl5o`0000KoVIVI0ol0000<ok>c
/`Go00001_o<c<`6o`0000go/k>c1Ol00003oiVIV@Go00003?moOgl3o`0001coIVIV00?o0000ogmo
OomoOgl00omoOgl6ooooo`7o00000Oooool000Sooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@00Kooooo00?o0000ooooooooool01?oooonPogmoO`03o`000?mVIVKoIVIV
01goIVIV0ol00004ogmoO`Go00000_moOgl5o`0000CoVIVI1?l0000=ok>c/`Ko00003_nc/k<5o`00
00GoVIVI0ol0000<ogmoO`Go00007_mVIVH00ol0003oOgmoogmoO`04ogmoO`Kooooo0Ol00001oooo
o`002Oooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000001_ooool3o`00
00CoooooXOmoOgl00ol0003oIVIVofIVIP0OofIVIPCo00001OmVIVH2o`0000GoOgmo0ol00005oiVI
V@Go00006Onc/k<3o`0000OoVIVI0ol00008ogmoO`Oo00008_mVIVH2o`0000KoOgmo1?ooool3o`00
007ooooo000:ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000006oooo
o`03o`000?oooooooooo00CoooooX_moOgl00ol0003oIVIVofIVIP0YofIVIP;o00001_moOgl5o`00
00GoVIVI0ol0000Aok>c/`Go00001onIVIT3o`0000GoOgmo1_l0000XofIVIP03o`000?moOgooOgmo
00KoOgmo1_ooool1o`00007ooooo000;ooooo`05o`000?ooooooooooooooool@41000oooool00ol@
413oooooooooo`04ooooo`03o`000?oooooooooo00CoooooXomoOgl00ol0003oIVIVofIVIP0ZofIV
IPGo00001_moOgl7o`000003oiVIVOl0003o000000oo00001onIVIT5o`000003ogmoOol0003o0000
00Go0000;OmVIVH00ol0003oOgmoogmoO`07ogmoO`Kooooo0Ol00001ooooo`001oooool01Ol0003o
^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooo
oooo00CoooooY?moOgl00ol0003oIVIVofIVIP0EofIVIPWo00004?mVIVH:o`0000?oOgmo7ol0000E
ofIVIPKo00006?mVIVH00ol0003oOgmoogmoO`08ogmoO`Kooooo0Ol00001ooooo`001oooool01OnH
V9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oo
oooooooo00CoooooYOmoOgl2o`0001CoIVIV00?o0000oda<C?m<C4`01om<C4`9o`00017oIVIV7?l0
000CofIVIPSo00001_m<C4`2o`0001GoIVIV00?o0000ogmoOomoOgl02OmoOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?oooonWogmoO`;o00004_mVIVH00ol0003oC4a<oda<C00@
oda<C0Oo0000;?mVIVH=o`0000ooC4a<00?o0000ofIVI_mVIVH04OmVIVH2o`0000coOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooZOmoOgl2o`00017oIVIV00?o0000oda<
C?m<C4`05_m<C4`/o`0001_oC4a<00?o0000ofIVI_mVIVH03omVIVH3o`0000koOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CoooooZomoOgl2o`0000ooIVIV00?o0000oda<C?m<
C4`0G?m<C4`00ol0003oIVIVofIVIP0>ofIVIP;o00004OmoOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?oooon]ogmoO`03o`000?mVIVKoIVIV00coIVIV00?o0000oda<C?m<C4`0
G?m<C4`00ol0003oIVIVofIVIP0<ofIVIP;o00004omoOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?oooon^ogmoO`;o00003OmVIVH2o`0005_oC4a<00?o0000ofIVI_mVIVH03?mV
IVH00ol0003oOgmoogmoO`0CogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
oooook3oOgmo0_l0000=ofIVIP;o00006om<C4`Po`0001goC4a<00?o0000ofIVI_mVIVH02omVIVH2
o`0001KoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo/_moOgl2o`00
00goIVIV0_l0000Ioda<C003o`000?lc<c?o<c<c01co<c<c00?o0000oda<C?m<C4`06Om<C4`2o`00
00_oIVIV0ol0000HogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000Gooooo]?moOgl2o`0000go
IVIV0_l0000Goda<C003o`000?lc<c?o<c<c01_o<c<c00?o0000oda<C?m<C4`05om<C4`3o`0000_o
IVIV0_l0000KogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04oooookKoOgmo
0ol0000<ofIVIP?o00005Om<C4`00ol0003o<c<coc<c<`0Ioc<c<`03o`000?m<C4coC4a<01KoC4a<
0_l0000=ofIVIP03o`000?moOgooOgmo01_oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00Cooooo^OmoOgl3o`0000coIVIV0_l0000Coda<C0Go00005_lc<c<00ol0003oC4a<oda<
C00Eoda<C0;o00003OmVIVH2o`0001koOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00Cooooo_?moOgl3o`0000_oIVIV0ol0000Eoda<C0Ko00001_lc<c<:o`0001GoC4a<0ol0000=
ofIVIP;o00008?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonoogmo
O`03o`000?mVIVKoIVIV00_oIVIV0ol0000Hoda<C0Ko00007?m<C4`3o`0000goIVIV0ol0000Rogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooool3oOgmo1_l0000:ofIVIP?o
0000<om<C4`4o`0000_oIVIV1Ol0000UogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooojWoOgmo1Ol0000HogmoO`?o00002_mVIVH3o`0002goC4a<0ol0000:ofIVIPGo0000
5OmoOgl2o`0001?oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooZOmo
Ogl00ol0003oVIVIoiVIV@02oiVIV@Go00005_moOgl4o`0000WoIVIV0ol0000Woda<C0?o00002_mV
IVH3o`0001OoOgmo0ol00002oiVIV@03o`000?moOgooOgmo013oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CoooooZOmoOgl00ol0003oVIVIoiVIV@07oiVIV@?o00005omoOgl3
o`0000WoIVIV0_l00007oda<C1ko00002OmVIVH4o`0001GoOgmo1Ol00006oiVIV@03o`000?moOgoo
Ogmo00ooOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooZ?moOgl00ol0
003oVIVIoiVIV@0;oiVIV@Go00005OmoOgl3o`0000SoIVIV0_l00002oda<C0?o00009?mVIVH3o`00
01CoOgmo1Ol0000<oiVIV@03o`000?moOgooOgmo00koOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CoooooZ?moOgl00ol0003oVIVIoiVIV@0@oiVIV@Go00004omoOgl3o`0000Oo
IVIV0_l0000RofIVIPGo00005?moOgl3o`0001;oVIVI00?o0000ogmoOomoOgl03OmoOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?oooonXogmoO`03o`000?nIVIWoVIVI01GoVIVI
0ol0000CogmoO`co00006?mVIVH7o`0001GoOgmo1?l0000EoiVIV@;o00003_moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?oooonYogmoO`;o00006?nIVIT5o`0001[oOgmo6?l0
000IogmoO`?o00005onIVIT2o`00013oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Ooooon[
ogmoO`;o00006onIVIT5o`00047oOgmo1Ol0000IoiVIV@03o`000?moOgooOgmo013oOgmo1Oooool2
o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo[OmoOgl00ol0003oVIVIoiVIV@0MoiVI
V@?o0000>?moOgl6o`0001coVIVI0_l0000CogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooojkoOgmo0_l0000PoiVIV@Go0000;?moOgl7o`00027oVIVI00?o0000ogmoOomo
Ogl04omoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon`ogmoO`03o`00
0?nIVIWoVIVI02;oVIVI3Ol0000IogmoO`Ko00009onIVIT00ol0003oOgmoogmoO`0DogmoO`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooook7oOgmo00?o0000oiVIVOnIVIT0;_nI
VITIo`0002coVIVI00?o0000ogmoOomoOgl05OmoOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?oooonbogmoO`;o0000L_nIVIT00ol0003oOgmoogmoO`0FogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04oooookCoOgmo0_l0001^oiVIV@;o00006OmoOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonfogmoO`;o0000JOnIVIT3o`0001_o
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo^?moOgl3o`0006CoVIVI
0_l0000NogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooook_oOgmo0_l0
001PoiVIV@;o00008?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonm
ogmoO`;o0000FonIVIT3o`0002;oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00Cooooo_omoOgl2o`0005SoVIVI00?o0000ogmoOomoOgl08omoOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?ooooo1ogmoO`;o0000E?nIVIT2o`0002KoOgmo1_ooool1o`00007o
oooo000Jooooo`;o00001Oooooo3ogmoO`;o0000ConIVIT3o`0002SoOgmo1Oooool2o`00007ooooo
000Jooooo`03o`000?oooooooooo00CoooooaOmoOgl2o`0004_oVIVI0_l0000[ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooolOoOgmo00?o0000oiVIVOnIVIT0A?nIVIT4
o`0002goOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooob?moOgl2o`00
03ooVIVI1Ol0000aogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooool[o
Ogmo2Ol0000coiVIV@?o0000=_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?oooooCogmoO`So00009_nIVIT5o`0003WoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooofomoOgl7o`0001WoVIVI1_l0000nogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooon;oOgmo6Ol00014ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo0007ooooo`05oiRHV?l@413o0000
oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo0007ooooo`05oa0@4?nj^[[oooooogMgMolb<S800ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000;ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413ooooo
ooooo`04ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_oo
ool00onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool3o`0000Cooooo
oomoOgm0ogmoO`Cooooo0ol00001ooooo`002Oooool00ol@413o0000okZj^P03ooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool000[ooooo00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@00Kooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo0007ooooo`05oa0@4?nH
V9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo0007ooooo`05ojVYZOl@413o0000oa0@4?nY
ZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000GooooooomoOgm0ogmoO`Go
oooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000GooooooomoOgm0
ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000Gooooo
oomoOgm0ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`002Oooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;o
k^k^00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000:oooo
o`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooo
oooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`001oooool5o`0000?ooooo00Go410@oooo
oooooooooooooa0@4006ooooo`?o00001?ooooooogmoOd3oOgmo1?ooool3o`00007ooooo0007oooo
o`04odA4A?oMgMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oo
oooooooo0?ooooooB_ooool1o`00007ooooo0007ooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?ooooooB_ooool1o`00007ooooo
0008ooooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`00
0?oooooooooo0?ooooooB_ooool1o`00007ooooo0008ooooo`03onk^k_m4A4Co000000Cooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?ooooooB_ooool1o`00007ooooo
0009ooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`00
0?oooooooooo02?ooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0mooooo`03o`00
0?oooooooooo03gooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Sooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`7o00000Ooo
ool001[oooooool0001>o`00007ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-30.1723, -14.304, 0.195672, \
0.195672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0192308 0.211538 0.0192308 [
[.11538 -0.0125 -9 -9 ]
[.11538 -0.0125 9 0 ]
[.30769 -0.0125 -9 -9 ]
[.30769 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69231 -0.0125 -6 -9 ]
[.69231 -0.0125 6 0 ]
[.88462 -0.0125 -6 -9 ]
[.88462 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -18 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .21154 -6 -4.5 ]
[-0.0125 .21154 0 4.5 ]
[-0.0125 .40385 -12 -4.5 ]
[-0.0125 .40385 0 4.5 ]
[-0.0125 .59615 -12 -4.5 ]
[-0.0125 .59615 0 4.5 ]
[-0.0125 .78846 -12 -4.5 ]
[-0.0125 .78846 0 4.5 ]
[-0.0125 .98077 -12 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11538 0 m
.11538 .00625 L
s
[(-20)] .11538 -0.0125 0 1 Mshowa
.30769 0 m
.30769 .00625 L
s
[(-10)] .30769 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69231 0 m
.69231 .00625 L
s
[(10)] .69231 -0.0125 0 1 Mshowa
.88462 0 m
.88462 .00625 L
s
[(20)] .88462 -0.0125 0 1 Mshowa
.125 Mabswid
.15385 0 m
.15385 .00375 L
s
.19231 0 m
.19231 .00375 L
s
.23077 0 m
.23077 .00375 L
s
.26923 0 m
.26923 .00375 L
s
.34615 0 m
.34615 .00375 L
s
.38462 0 m
.38462 .00375 L
s
.42308 0 m
.42308 .00375 L
s
.46154 0 m
.46154 .00375 L
s
.53846 0 m
.53846 .00375 L
s
.57692 0 m
.57692 .00375 L
s
.61538 0 m
.61538 .00375 L
s
.65385 0 m
.65385 .00375 L
s
.73077 0 m
.73077 .00375 L
s
.76923 0 m
.76923 .00375 L
s
.80769 0 m
.80769 .00375 L
s
.84615 0 m
.84615 .00375 L
s
.07692 0 m
.07692 .00375 L
s
.03846 0 m
.03846 .00375 L
s
.92308 0 m
.92308 .00375 L
s
.96154 0 m
.96154 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(-10)] -0.0125 .01923 1 0 Mshowa
0 .21154 m
.00625 .21154 L
s
[(0)] -0.0125 .21154 1 0 Mshowa
0 .40385 m
.00625 .40385 L
s
[(10)] -0.0125 .40385 1 0 Mshowa
0 .59615 m
.00625 .59615 L
s
[(20)] -0.0125 .59615 1 0 Mshowa
0 .78846 m
.00625 .78846 L
s
[(30)] -0.0125 .78846 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(40)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .05769 m
.00375 .05769 L
s
0 .09615 m
.00375 .09615 L
s
0 .13462 m
.00375 .13462 L
s
0 .17308 m
.00375 .17308 L
s
0 .25 m
.00375 .25 L
s
0 .28846 m
.00375 .28846 L
s
0 .32692 m
.00375 .32692 L
s
0 .36538 m
.00375 .36538 L
s
0 .44231 m
.00375 .44231 L
s
0 .48077 m
.00375 .48077 L
s
0 .51923 m
.00375 .51923 L
s
0 .55769 m
.00375 .55769 L
s
0 .63462 m
.00375 .63462 L
s
0 .67308 m
.00375 .67308 L
s
0 .71154 m
.00375 .71154 L
s
0 .75 m
.00375 .75 L
s
0 .82692 m
.00375 .82692 L
s
0 .86538 m
.00375 .86538 L
s
0 .90385 m
.00375 .90385 L
s
0 .94231 m
.00375 .94231 L
s
.25 Mabswid
0 0 m
0 1 L
s
.11538 .99375 m
.11538 1 L
s
.30769 .99375 m
.30769 1 L
s
.5 .99375 m
.5 1 L
s
.69231 .99375 m
.69231 1 L
s
.88462 .99375 m
.88462 1 L
s
.125 Mabswid
.15385 .99625 m
.15385 1 L
s
.19231 .99625 m
.19231 1 L
s
.23077 .99625 m
.23077 1 L
s
.26923 .99625 m
.26923 1 L
s
.34615 .99625 m
.34615 1 L
s
.38462 .99625 m
.38462 1 L
s
.42308 .99625 m
.42308 1 L
s
.46154 .99625 m
.46154 1 L
s
.53846 .99625 m
.53846 1 L
s
.57692 .99625 m
.57692 1 L
s
.61538 .99625 m
.61538 1 L
s
.65385 .99625 m
.65385 1 L
s
.73077 .99625 m
.73077 1 L
s
.76923 .99625 m
.76923 1 L
s
.80769 .99625 m
.80769 1 L
s
.84615 .99625 m
.84615 1 L
s
.07692 .99625 m
.07692 1 L
s
.03846 .99625 m
.03846 1 L
s
.92308 .99625 m
.92308 1 L
s
.96154 .99625 m
.96154 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .21154 m
1 .21154 L
s
.99375 .40385 m
1 .40385 L
s
.99375 .59615 m
1 .59615 L
s
.99375 .78846 m
1 .78846 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .05769 m
1 .05769 L
s
.99625 .09615 m
1 .09615 L
s
.99625 .13462 m
1 .13462 L
s
.99625 .17308 m
1 .17308 L
s
.99625 .25 m
1 .25 L
s
.99625 .28846 m
1 .28846 L
s
.99625 .32692 m
1 .32692 L
s
.99625 .36538 m
1 .36538 L
s
.99625 .44231 m
1 .44231 L
s
.99625 .48077 m
1 .48077 L
s
.99625 .51923 m
1 .51923 L
s
.99625 .55769 m
1 .55769 L
s
.99625 .63462 m
1 .63462 L
s
.99625 .67308 m
1 .67308 L
s
.99625 .71154 m
1 .71154 L
s
.99625 .75 m
1 .75 L
s
.99625 .82692 m
1 .82692 L
s
.99625 .86538 m
1 .86538 L
s
.99625 .90385 m
1 .90385 L
s
.99625 .94231 m
1 .94231 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.4 g
.98077 .61895 m
.97057 .62755 L
.96115 .63538 L
.94249 .64717 L
.94152 .6478 L
.9219 .65834 L
.90352 .6668 L
.90228 .66717 L
.88265 .67541 L
.86303 .68407 L
.84917 .68642 L
.84341 .68699 L
.82378 .69139 L
.80416 .69583 L
.78454 .69917 L
.76491 .70124 L
.74529 .7021 L
.72567 .70181 L
.70604 .70036 L
.68642 .69766 L
.6668 .69372 L
.64717 .68899 L
.63159 .68642 L
.62755 .68528 L
.60793 .67989 L
.5883 .67096 L
.57728 .6668 L
.56868 .66298 L
.54906 .65508 L
.53833 .64717 L
.52943 .64175 L
.50981 .62827 L
.50892 .62755 L
.49157 .60793 L
.50981 .60192 L
.52943 .60187 L
.54074 .60793 L
.54906 .61028 L
.56868 .61569 L
.5883 .61545 L
.60793 .62462 L
.61955 .62755 L
.62755 .62943 L
.64717 .63331 L
.6668 .6364 L
.68642 .63371 L
.70604 .63722 L
.72567 .6389 L
.74529 .63922 L
.76491 .63825 L
.78454 .63575 L
.80416 .6308 L
.82378 .63495 L
.84341 .63147 L
.8615 .62755 L
.86303 .62724 L
.88265 .62097 L
.90228 .61822 L
.9219 .61303 L
.93921 .60793 L
.94152 .60736 L
.96115 .60334 L
.98077 .60171 L
F
0 g
.98077 .61895 m
.97057 .62755 L
.96115 .63538 L
.94249 .64717 L
.94152 .6478 L
.9219 .65834 L
.90352 .6668 L
.90228 .66717 L
.88265 .67541 L
.86303 .68407 L
.84917 .68642 L
.84341 .68699 L
.82378 .69139 L
.80416 .69583 L
.78454 .69917 L
.76491 .70124 L
.74529 .7021 L
.72567 .70181 L
.70604 .70036 L
.68642 .69766 L
.6668 .69372 L
.64717 .68899 L
.63159 .68642 L
.62755 .68528 L
.60793 .67989 L
.5883 .67096 L
.57728 .6668 L
.56868 .66298 L
.54906 .65508 L
.53833 .64717 L
.52943 .64175 L
.50981 .62827 L
.50892 .62755 L
.49157 .60793 L
.50981 .60192 L
.52943 .60187 L
.54074 .60793 L
.54906 .61028 L
.56868 .61569 L
.5883 .61545 L
.60793 .62462 L
.61955 .62755 L
.62755 .62943 L
.64717 .63331 L
.6668 .6364 L
.68642 .63371 L
.70604 .63722 L
.72567 .6389 L
.74529 .63922 L
.76491 .63825 L
Mistroke
.78454 .63575 L
.80416 .6308 L
.82378 .63495 L
.84341 .63147 L
.8615 .62755 L
.86303 .62724 L
.88265 .62097 L
.90228 .61822 L
.9219 .61303 L
.93921 .60793 L
.94152 .60736 L
.96115 .60334 L
.98077 .60171 L
Mfstroke
.6 g
.98077 .55783 m
.97056 .56868 L
.96115 .57523 L
.94152 .58673 L
.93866 .5883 L
.9219 .60361 L
.90228 .60413 L
.89207 .60793 L
.88265 .6105 L
.86303 .61848 L
.84341 .62215 L
.82378 .62624 L
.8166 .62755 L
.80416 .62759 L
.78454 .6298 L
.76491 .63164 L
.74529 .63247 L
.72567 .63219 L
.70604 .63083 L
.68642 .62864 L
.6668 .62801 L
.66422 .62755 L
.64717 .62429 L
.62755 .62289 L
.60793 .61432 L
.58859 .60793 L
.5883 .60782 L
.56868 .60027 L
.54906 .59309 L
.54224 .5883 L
.52943 .58112 L
.50981 .5687 L
.50979 .56868 L
.49642 .54906 L
.50981 .54554 L
.52943 .54624 L
.53884 .54906 L
.54906 .55127 L
.56868 .55556 L
.5883 .55469 L
.60793 .56461 L
.62755 .56714 L
.6366 .56868 L
.64717 .57044 L
.6668 .57316 L
.68642 .57521 L
.70604 .57198 L
.72567 .57402 L
.74529 .5744 L
.76491 .57324 L
.78454 .57008 L
.80416 .57426 L
.82378 .57188 L
.84341 .56883 L
.84425 .56868 L
.86303 .56811 L
.88265 .56055 L
.90228 .55764 L
.9219 .55343 L
.94152 .54912 L
.94183 .54906 L
.96115 .54607 L
.98077 .54689 L
F
0 g
.98077 .55783 m
.97056 .56868 L
.96115 .57523 L
.94152 .58673 L
.93866 .5883 L
.9219 .60361 L
.90228 .60413 L
.89207 .60793 L
.88265 .6105 L
.86303 .61848 L
.84341 .62215 L
.82378 .62624 L
.8166 .62755 L
.80416 .62759 L
.78454 .6298 L
.76491 .63164 L
.74529 .63247 L
.72567 .63219 L
.70604 .63083 L
.68642 .62864 L
.6668 .62801 L
.66422 .62755 L
.64717 .62429 L
.62755 .62289 L
.60793 .61432 L
.58859 .60793 L
.5883 .60782 L
.56868 .60027 L
.54906 .59309 L
.54224 .5883 L
.52943 .58112 L
.50981 .5687 L
.50979 .56868 L
.49642 .54906 L
.50981 .54554 L
.52943 .54624 L
.53884 .54906 L
.54906 .55127 L
.56868 .55556 L
.5883 .55469 L
.60793 .56461 L
.62755 .56714 L
.6366 .56868 L
.64717 .57044 L
.6668 .57316 L
.68642 .57521 L
.70604 .57198 L
.72567 .57402 L
.74529 .5744 L
.76491 .57324 L
Mistroke
.78454 .57008 L
.80416 .57426 L
.82378 .57188 L
.84341 .56883 L
.84425 .56868 L
.86303 .56811 L
.88265 .56055 L
.90228 .55764 L
.9219 .55343 L
.94152 .54912 L
.94183 .54906 L
.96115 .54607 L
.98077 .54689 L
Mfstroke
.4 g
.52943 .50287 m
.54906 .50254 L
.56868 .50111 L
.5883 .50756 L
.60333 .50981 L
.60793 .51078 L
.62755 .51371 L
.64717 .51622 L
.6668 .51513 L
.68642 .52104 L
.70604 .5249 L
.72567 .52734 L
.74529 .52788 L
.76491 .52632 L
.78454 .52314 L
.80416 .5185 L
.82378 .51731 L
.84341 .51501 L
.86303 .5123 L
.87848 .50981 L
.88265 .50917 L
.90228 .50755 L
.9219 .50344 L
.94152 .50217 L
.96097 .50981 L
.94152 .52637 L
.93698 .52943 L
.9219 .53634 L
.90228 .54426 L
.88948 .54906 L
.88265 .55163 L
.86303 .56412 L
.84341 .56111 L
.82378 .5649 L
.80416 .56798 L
.79907 .56868 L
.78454 .56898 L
.76491 .57032 L
.74529 .57103 L
.72567 .57079 L
.70604 .56967 L
.68642 .56921 L
.68182 .56868 L
.6668 .56653 L
.64717 .56309 L
.62755 .55895 L
.60793 .55672 L
.59122 .54906 L
.5883 .54799 L
.56868 .54039 L
.54906 .53199 L
.54385 .52943 L
.52943 .51897 L
.51945 .50981 L
F
0 g
.52943 .50287 m
.54906 .50254 L
.56868 .50111 L
.5883 .50756 L
.60333 .50981 L
.60793 .51078 L
.62755 .51371 L
.64717 .51622 L
.6668 .51513 L
.68642 .52104 L
.70604 .5249 L
.72567 .52734 L
.74529 .52788 L
.76491 .52632 L
.78454 .52314 L
.80416 .5185 L
.82378 .51731 L
.84341 .51501 L
.86303 .5123 L
.87848 .50981 L
.88265 .50917 L
.90228 .50755 L
.9219 .50344 L
.94152 .50217 L
.96097 .50981 L
.94152 .52637 L
.93698 .52943 L
.9219 .53634 L
.90228 .54426 L
.88948 .54906 L
.88265 .55163 L
.86303 .56412 L
.84341 .56111 L
.82378 .5649 L
.80416 .56798 L
.79907 .56868 L
.78454 .56898 L
.76491 .57032 L
.74529 .57103 L
.72567 .57079 L
.70604 .56967 L
.68642 .56921 L
.68182 .56868 L
.6668 .56653 L
.64717 .56309 L
.62755 .55895 L
.60793 .55672 L
.59122 .54906 L
.5883 .54799 L
.56868 .54039 L
Mistroke
.54906 .53199 L
.54385 .52943 L
.52943 .51897 L
.51945 .50981 L
.52943 .50287 L
Mfstroke
.6 g
.56868 .46595 m
.5883 .4648 L
.60793 .4657 L
.62755 .46728 L
.64717 .46905 L
.66454 .47057 L
.6668 .47074 L
.68642 .47202 L
.70604 .47292 L
.72567 .47343 L
.74529 .47353 L
.76491 .47323 L
.78454 .47252 L
.80416 .47143 L
.81625 .47057 L
.82378 .46993 L
.84341 .46816 L
.86303 .4672 L
.88265 .46512 L
.90228 .46492 L
.92159 .47057 L
.90228 .4857 L
.89411 .49019 L
.88265 .49396 L
.86303 .49954 L
.84341 .50443 L
.82378 .50863 L
.81755 .50981 L
.80416 .51221 L
.78454 .51648 L
.76491 .52032 L
.74529 .5224 L
.72567 .52167 L
.70604 .51853 L
.68642 .51433 L
.6668 .51033 L
.66326 .50981 L
.64717 .50663 L
.62755 .50207 L
.60793 .49685 L
.5883 .49077 L
.58664 .49019 L
.56868 .47929 L
.55888 .47057 L
F
0 g
.56868 .46595 m
.5883 .4648 L
.60793 .4657 L
.62755 .46728 L
.64717 .46905 L
.66454 .47057 L
.6668 .47074 L
.68642 .47202 L
.70604 .47292 L
.72567 .47343 L
.74529 .47353 L
.76491 .47323 L
.78454 .47252 L
.80416 .47143 L
.81625 .47057 L
.82378 .46993 L
.84341 .46816 L
.86303 .4672 L
.88265 .46512 L
.90228 .46492 L
.92159 .47057 L
.90228 .4857 L
.89411 .49019 L
.88265 .49396 L
.86303 .49954 L
.84341 .50443 L
.82378 .50863 L
.81755 .50981 L
.80416 .51221 L
.78454 .51648 L
.76491 .52032 L
.74529 .5224 L
.72567 .52167 L
.70604 .51853 L
.68642 .51433 L
.6668 .51033 L
.66326 .50981 L
.64717 .50663 L
.62755 .50207 L
.60793 .49685 L
.5883 .49077 L
.58664 .49019 L
.56868 .47929 L
.55888 .47057 L
.56868 .46595 L
s
.6 g
.56868 .69798 m
.5883 .70156 L
.60793 .70567 L
.61029 .70604 L
.62755 .71051 L
.64717 .71485 L
.6668 .71835 L
.68642 .72099 L
.70604 .7228 L
.72567 .7238 L
.74529 .72399 L
.76491 .7234 L
.78454 .722 L
.80416 .71978 L
.82378 .71671 L
.84341 .71277 L
.86303 .70809 L
.8711 .70604 L
.88265 .70362 L
.90228 .69958 L
.92058 .70604 L
.90228 .71849 L
.88905 .72567 L
.88265 .7287 L
.86303 .73686 L
.84341 .74333 L
.83674 .74529 L
.82378 .75133 L
.80416 .75306 L
.78454 .75604 L
.76491 .75788 L
.74529 .75866 L
.72567 .7584 L
.70604 .7571 L
.68642 .7547 L
.6668 .75111 L
.64717 .74649 L
.64413 .74529 L
.62755 .74027 L
.60793 .73304 L
.59158 .72567 L
.5883 .72379 L
.56868 .71252 L
.56024 .70604 L
F
0 g
.56868 .69798 m
.5883 .70156 L
.60793 .70567 L
.61029 .70604 L
.62755 .71051 L
.64717 .71485 L
.6668 .71835 L
.68642 .72099 L
.70604 .7228 L
.72567 .7238 L
.74529 .72399 L
.76491 .7234 L
.78454 .722 L
.80416 .71978 L
.82378 .71671 L
.84341 .71277 L
.86303 .70809 L
.8711 .70604 L
.88265 .70362 L
.90228 .69958 L
.92058 .70604 L
.90228 .71849 L
.88905 .72567 L
.88265 .7287 L
.86303 .73686 L
.84341 .74333 L
.83674 .74529 L
.82378 .75133 L
.80416 .75306 L
.78454 .75604 L
.76491 .75788 L
.74529 .75866 L
.72567 .7584 L
.70604 .7571 L
.68642 .7547 L
.6668 .75111 L
.64717 .74649 L
.64413 .74529 L
.62755 .74027 L
.60793 .73304 L
.59158 .72567 L
.5883 .72379 L
.56868 .71252 L
.56024 .70604 L
.56868 .69798 L
s
.7 g
.5883 .57453 m
.60793 .57477 L
.62755 .57641 L
.64717 .57825 L
.6668 .57996 L
.68642 .58137 L
.70604 .57735 L
.72567 .5795 L
.74529 .57987 L
.76491 .5787 L
.78454 .57516 L
.80416 .58071 L
.82378 .57914 L
.84341 .57733 L
.86303 .57552 L
.88265 .57431 L
.89963 .5883 L
.88265 .59778 L
.86303 .60648 L
.85941 .60793 L
.84341 .61303 L
.82378 .61801 L
.80416 .62186 L
.78454 .62468 L
.76491 .62648 L
.74529 .62726 L
.72567 .627 L
.70604 .62571 L
.68642 .6234 L
.6668 .62007 L
.64717 .61567 L
.62755 .61171 L
.62137 .60793 L
.60793 .60233 L
.5883 .59266 L
.58113 .5883 L
F
0 g
.5883 .57453 m
.60793 .57477 L
.62755 .57641 L
.64717 .57825 L
.6668 .57996 L
.68642 .58137 L
.70604 .57735 L
.72567 .5795 L
.74529 .57987 L
.76491 .5787 L
.78454 .57516 L
.80416 .58071 L
.82378 .57914 L
.84341 .57733 L
.86303 .57552 L
.88265 .57431 L
.89963 .5883 L
.88265 .59778 L
.86303 .60648 L
.85941 .60793 L
.84341 .61303 L
.82378 .61801 L
.80416 .62186 L
.78454 .62468 L
.76491 .62648 L
.74529 .62726 L
.72567 .627 L
.70604 .62571 L
.68642 .6234 L
.6668 .62007 L
.64717 .61567 L
.62755 .61171 L
.62137 .60793 L
.60793 .60233 L
.5883 .59266 L
.58113 .5883 L
.5883 .57453 L
s
.3 g
.60793 .52582 m
.62755 .52483 L
.64717 .52535 L
.6668 .523 L
.68642 .52666 L
.70604 .52826 L
.72567 .52893 L
.74529 .52904 L
.76491 .52868 L
.78454 .52761 L
.80416 .52526 L
.82378 .52579 L
.84341 .525 L
.86303 .52498 L
.88265 .52888 L
.88337 .52943 L
.88265 .53099 L
.86303 .54496 L
.8544 .54906 L
.84341 .55238 L
.82378 .55721 L
.80416 .56095 L
.78454 .56371 L
.76491 .56547 L
.74529 .56623 L
.72567 .56598 L
.70604 .56471 L
.68642 .56245 L
.6668 .55921 L
.64717 .55495 L
.62755 .54944 L
.62639 .54906 L
.60793 .53937 L
.59693 .52943 L
F
0 g
.60793 .52582 m
.62755 .52483 L
.64717 .52535 L
.6668 .523 L
.68642 .52666 L
.70604 .52826 L
.72567 .52893 L
.74529 .52904 L
.76491 .52868 L
.78454 .52761 L
.80416 .52526 L
.82378 .52579 L
.84341 .525 L
.86303 .52498 L
.88265 .52888 L
.88337 .52943 L
.88265 .53099 L
.86303 .54496 L
.8544 .54906 L
.84341 .55238 L
.82378 .55721 L
.80416 .56095 L
.78454 .56371 L
.76491 .56547 L
.74529 .56623 L
.72567 .56598 L
.70604 .56471 L
.68642 .56245 L
.6668 .55921 L
.64717 .55495 L
.62755 .54944 L
.62639 .54906 L
.60793 .53937 L
.59693 .52943 L
.60793 .52582 L
s
.3 g
.60793 .64346 m
.62755 .64339 L
.64717 .64482 L
.6668 .64644 L
.6766 .64717 L
.68642 .64804 L
.70604 .64935 L
.72567 .65009 L
.74529 .65024 L
.76491 .64979 L
.78454 .64876 L
.80416 .6472 L
.80438 .64717 L
.82378 .64564 L
.84341 .64404 L
.86303 .64304 L
.88128 .64717 L
.86303 .66104 L
.85144 .6668 L
.84341 .66991 L
.82378 .67612 L
.80416 .68077 L
.78454 .68412 L
.76491 .68625 L
.76255 .68642 L
.74529 .68729 L
.72567 .68693 L
.71823 .68642 L
.70604 .68533 L
.68642 .6826 L
.6668 .67861 L
.64717 .67324 L
.62936 .6668 L
.62755 .66595 L
.60793 .6552 L
.59769 .64717 L
F
0 g
.60793 .64346 m
.62755 .64339 L
.64717 .64482 L
.6668 .64644 L
.6766 .64717 L
.68642 .64804 L
.70604 .64935 L
.72567 .65009 L
.74529 .65024 L
.76491 .64979 L
.78454 .64876 L
.80416 .6472 L
.80438 .64717 L
.82378 .64564 L
.84341 .64404 L
.86303 .64304 L
.88128 .64717 L
.86303 .66104 L
.85144 .6668 L
.84341 .66991 L
.82378 .67612 L
.80416 .68077 L
.78454 .68412 L
.76491 .68625 L
.76255 .68642 L
.74529 .68729 L
.72567 .68693 L
.71823 .68642 L
.70604 .68533 L
.68642 .6826 L
.6668 .67861 L
.64717 .67324 L
.62936 .6668 L
.62755 .66595 L
.60793 .6552 L
.59769 .64717 L
.60793 .64346 L
s
.4 g
.64717 .4327 m
.6668 .43216 L
.68642 .43229 L
.70604 .43253 L
.72567 .43271 L
.74529 .43275 L
.76491 .43263 L
.78454 .43241 L
.80416 .43219 L
.82378 .43228 L
.834 .45094 L
.82378 .45295 L
.80416 .45609 L
.78454 .45839 L
.76491 .45987 L
.74529 .46051 L
.72567 .4603 L
.70604 .45923 L
.68642 .45734 L
.6668 .45463 L
.64717 .45102 L
.64682 .45094 L
F
0 g
.64717 .4327 m
.6668 .43216 L
.68642 .43229 L
.70604 .43253 L
.72567 .43271 L
.74529 .43275 L
.76491 .43263 L
.78454 .43241 L
.80416 .43219 L
.82378 .43228 L
.834 .45094 L
.82378 .45295 L
.80416 .45609 L
.78454 .45839 L
.76491 .45987 L
.74529 .46051 L
.72567 .4603 L
.70604 .45923 L
.68642 .45734 L
.6668 .45463 L
.64717 .45102 L
.64682 .45094 L
.64717 .4327 L
s
.8 g
.6668 .58825 m
.67207 .5883 L
.68642 .58867 L
.70604 .58921 L
.72567 .58957 L
.74529 .58965 L
.76491 .58942 L
.78454 .58895 L
.80416 .5884 L
.82311 .60793 L
.80416 .61287 L
.78454 .61638 L
.76491 .61854 L
.74529 .61946 L
.72567 .61916 L
.70604 .61762 L
.68642 .6148 L
.6668 .61054 L
.65757 .60793 L
.65567 .5883 L
F
0 g
.6668 .58825 m
.67207 .5883 L
.68642 .58867 L
.70604 .58921 L
.72567 .58957 L
.74529 .58965 L
.76491 .58942 L
.78454 .58895 L
.80416 .5884 L
.82311 .60793 L
.80416 .61287 L
.78454 .61638 L
.76491 .61854 L
.74529 .61946 L
.72567 .61916 L
.70604 .61762 L
.68642 .6148 L
.6668 .61054 L
.65757 .60793 L
.65567 .5883 L
.6668 .58825 L
s
.7 g
.6668 .48701 m
.68642 .48527 L
.70604 .48475 L
.72567 .48461 L
.74529 .48459 L
.76491 .48466 L
.78454 .48494 L
.80416 .48586 L
.82374 .49019 L
.80416 .49834 L
.78454 .50279 L
.76491 .50541 L
.74529 .5065 L
.72567 .50614 L
.70604 .5043 L
.68642 .50083 L
.6668 .49515 L
.65685 .49019 L
F
0 g
.6668 .48701 m
.68642 .48527 L
.70604 .48475 L
.72567 .48461 L
.74529 .48459 L
.76491 .48466 L
.78454 .48494 L
.80416 .48586 L
.82374 .49019 L
.80416 .49834 L
.78454 .50279 L
.76491 .50541 L
.74529 .5065 L
.72567 .50614 L
.70604 .5043 L
.68642 .50083 L
.6668 .49515 L
.65685 .49019 L
.6668 .48701 L
s
.2 g
.68642 .53752 m
.70604 .53692 L
.72567 .53679 L
.74529 .53677 L
.76491 .53683 L
.78454 .53712 L
.80416 .53834 L
.81337 .54906 L
.80416 .55151 L
.78454 .55532 L
.76491 .55762 L
.74529 .55859 L
.72567 .55827 L
.70604 .55665 L
.68642 .55363 L
.66752 .54906 L
F
0 g
.68642 .53752 m
.70604 .53692 L
.72567 .53679 L
.74529 .53677 L
.76491 .53683 L
.78454 .53712 L
.80416 .53834 L
.81337 .54906 L
.80416 .55151 L
.78454 .55532 L
.76491 .55762 L
.74529 .55859 L
.72567 .55827 L
.70604 .55665 L
.68642 .55363 L
.66752 .54906 L
.68642 .53752 L
s
.8 g
.82378 .58828 m
.82519 .5883 L
.82378 .60764 L
.80875 .5883 L
F
0 g
.82378 .58828 m
.82519 .5883 L
.82378 .60764 L
.80875 .5883 L
.82378 .58828 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00?Oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0dooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kS?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0hooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8b
onk^kS?ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08_ooool003gooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0=_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0<oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg03?ooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL08_ooool003Gooooo1_l0
0003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400[ooooo`Ko0000
1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100<oooool01Ol@413o
oooooooooooooooo410@03[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@03Cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@02;ooooo000o
ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000fooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000cooooo`05o`000?ooooooooooooooool0
0000>_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000=Oooool00onH
V9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000008_ooool0043ooooo00?oMgMgofIV
I_ooool00_ooool01Ol0003ooooooooooooooooo000003Kooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000003?ooooo00Go0000ooooooooooooooooo`00000jooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`03ogMgMomVIVKooooo00;o
oooo00Go0000ooooooooooooooooo`00000Rooooo`00@Oooool01Ol0003ooooooooooooooooo410@
00?ooooo00?o410@ooooooooool0=?ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@4100<oooool01Ol@413ooooooooooooooooo410@03[ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@03Oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo023ooooo000mooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg03Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg03?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0jooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0cooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02;ooooo000mooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^03Cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^03?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`03oeEEEOmVIVKo000000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0cooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02;ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo000Joooooooo0000C_l00001ooooo`00
6_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0?Ooo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool08ooo
ool1o`00007ooooo0008ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKo
oooo00?o0000ooooooooool0oooooom:ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooom:ooooo`7o
00000Oooool000Go00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41001_ooool00ol0003oooooooooo`3ooooood[ooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?ooooooB?ooool3o`00007o
oooo000:ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo0008ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Oooooooogmo
Od3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Ooo
ooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000oooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`003ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000?ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000oooooo00Go0000oooooooooooooooo
o`000006ooooo`?o00001?ooooooogmoOd3oOgmo1?ooool3o`00007ooooo000?ooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool000oooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`003oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000?ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo0008
ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000:ooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`002_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41001_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000[ooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo0ol00004oooooooo
Ogmo@?moOgl4ooooo`?o00000Oooool000[ooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000:ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool000Sooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooom3o
Ogmo??l0000cogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooom3oOgmo
00?o0000ofIVI_mVIVH0>?mVIVH00ol0003oOgmoogmoO`0aogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooom3oOgmo00?o0000ofIVI_mVIVH0>OmVIVH00ol0003oOgmoogmo
O`0`ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooom3oOgmo00?o0000
ofIVI_mVIVH0>OmVIVH00ol0003oOgmoogmoO`0`ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`00
00Goooood?moOgl00ol0003oIVIVofIVIP0jofIVIP03o`000?moOgooOgmo02ooOgmo1Oooool2o`00
007ooooo000Jooooo`03o`000?oooooooooo00Coooood?moOgl00ol0003oIVIVofIVIP0jofIVIP03
o`000?moOgooOgmo02ooOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
d?moOgl3o`0003[oIVIV0_l0000`ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooom?oOgmo0ol0000bofIVIPGo0000<_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?oooooFogmoO`Go00009_mVIVH7o`0003OoOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CooooofomoOgl=o`0000coIVIV3Ol0000nogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooonSoOgmo3?l0001;ogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04oooookGoOgmo4ol0001CogmoO`go00005omoOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?oooondogmoO`03o`000?nIVIWoVIVI017oVIVI3?l0
000jogmoO`go00003OnIVIT3o`0001CoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00Cooooo/omoOgl00ol0003oVIVIoiVIV@0NoiVIV@ko00007omoOgl=o`0001coVIVI0_l0000C
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooookCoOgmo00?o0000oiVI
VOnIVIT0:onIVITOo`0002SoVIVI00?o0000ogmoOomoOgl04omoOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?ooooneogmoO`03o`000?nIVIWoVIVI073oVIVI00?o0000ogmoOomo
Ogl05?moOgl6ooooo`7o00000Oooool001[ooooo0_l00005oooookKoOgmo0_l0001_oiVIV@03o`00
0?moOgooOgmo01GoOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo^?mo
Ogl2o`0006coVIVI00?o0000ogmoOomoOgl05_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?oooonjogmoO`;o00006OnIVITdo`0001_oVIVI0_l0000IogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04oooookcoOgmo00?o0000oiVIVOnIVIT05?nIVIT2o`00
03Co/k>c0ol0000EoiVIV@?o00006omoOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?oooonmogmoO`?o00005OnIVIT2o`00033o/k>c0ol0000EoiVIV@;o00007_moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooo0ogmoO`?o00005?nIVIT3o`0002_o/k>c
0_l0000FoiVIV@;o00008?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooo3ogmoO`Go00004_nIVIT3o`0002Ko/k>c0_l0000EoiVIV@?o00008_moOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?ooooncogmoO`Ko00003omoOgl5o`00013oVIVI1Ol0000N
ok>c/`?o00004_nIVIT5o`0001GoOgmo1Ol0000;ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooojSoOgmo2ol00006ofIVIP?o00004OmoOgl3o`0001;oVIVI1_l0000<ok>c
/`co00004?nIVIT5o`0001?oOgmo1ol00005ofIVIP;o00002OmoOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?oooonWogmoO`03o`000?mVIVKoIVIV01;oIVIV1Ol0000?ogmoO`Co
00005?nIVIT<o`0001WoVIVI0ol0000BogmoO`Ko00003_mVIVH2o`0000OoOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CoooooY_moOgl00ol0003oIVIVofIVIP0HofIVIPOo0000
3?moOgl7o`0002coVIVI1_l0000>ogmoO`Oo00005OmVIVH2o`0000KoOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CoooooYomoOgl00ol0003oIVIVofIVIP0NofIVIPKo00003Omo
Ogl5o`00027oVIVI1_l0000>ogmoO`Ko00006omVIVH00ol0003oOgmoogmoO`06ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooojSoOgmo00?o0000ofIVI_mVIVH08omVIVH<
o`0000KoOgmo0ol0000HoiVIV@Ko00001omoOgl=o`00023oIVIV00?o0000ogmoOomoOgl01omoOgl6
ooooo`7o00000Oooool001[ooooo0_l00005ooooojWoOgmo0_l0000_ofIVIP?o00001_moOgl5o`00
00coVIVI1ol00006ogmoO`Oo0000;?mVIVH00ol0003oOgmoogmoO`08ogmoO`Gooooo0_l00001oooo
o`006_ooool00ol0003oooooooooo`04oooooj_oOgmo0_l0000WofIVIPKo00000omVIVH5o`0000Ko
Ogmo3?l00007ogmoO`Ko0000<_mVIVH00ol0003oOgmoogmoO`09ogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooojgoOgmo00?o0000ofIVI_mVIVH04OmVIVHCo`0000KoC4a<
0ol00005ofIVIPKo00003?moOgl7o`0000KoIVIV6ol0000EofIVIP;o00003?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?oooon^ogmoO`;o00003omVIVH2o`0001coC4a<9?l0
000Koda<C0Co00003omVIVH2o`0000koOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00Cooooo/?moOgl2o`0000koIVIV00?o0000oda<C?m<C4`0F_m<C4`2o`0000koIVIV0_l0000@
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooook;oOgmo0_l0000=ofIV
IP03o`000?m<C4coC4a<05SoC4a<00?o0000ofIVI_mVIVH03OmVIVH00ol0003oOgmoogmoO`0@ogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooookCoOgmo0_l0000<ofIVIP03
o`000?m<C4coC4a<01OoC4a<:Ol0000Foda<C003o`000?mVIVKoIVIV00coIVIV0_l0000CogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooookKoOgmo0_l0000;ofIVIP;o0000
5_m<C4`00ol0003o<c<coc<c<`0Voc<c<`03o`000?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH0
2_mVIVH3o`0001GoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo^?mo
Ogl3o`0000[oIVIV0_l0000Boda<C0;o0000:_lc<c<00ol0003oC4a<oda<C00Aoda<C003o`000?mV
IVKoIVIV00SoIVIV0ol0000HogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
oooooj7oOgmo2ol0000?ogmoO`;o00002_mVIVH2o`0000ooC4a<00?o0000oc<c<olc<c<0:olc<c<0
0ol0003oC4a<oda<C00>oda<C0;o00002OmVIVH2o`00017oOgmo2ol00005ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?oooonNogmoO`?o00002onIVIT3o`0000koOgmo0ol00009ofIV
IPCo00002_m<C4`3o`0002co<c<c0_l0000;oda<C0Co00002OmVIVH2o`0000goOgmo1_l0000:oiVI
V@Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooikoOgmo00?o0000oiVIVOnI
VIT03_nIVIT5o`0000coOgmo0_l0000;ofIVIP?o00002_m<C4`3o`0002Co<c<c1Ol0000:oda<C0?o
00002_mVIVH3o`0000[oOgmo1Ol0000@oiVIV@Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04oooooiooOgmo00?o0000oiVIVOnIVIT04_nIVIT;o`0000?oOgmo00?o0000ofIVI_mVIVH0
2omVIVH5o`0000SoC4a<1Ol0000Ioc<c<`Ko00003?m<C4`3o`0000coIVIV00?o0000ogmoOomoOgl0
2?moOgl3o`0001GoVIVI1_ooool1o`00007ooooo000Jooooo`;o00001OoooonPogmoO`03o`000?nI
VIWoVIVI01coVIVI0_l00002ogmoO`[o00002?mVIVH6o`0000OoC4a<6Ol0000=oda<C0Go00003OmV
IVH2o`0000KoOgmo1Ol0000HoiVIV@03o`000?oooooooooo00;ooooo0_l00001ooooo`006_ooool0
0ol0003oooooooooo`04oooooj7oOgmo00?o0000oiVIVOnIVIT07OnIVIT2o`0000[oOgmo0ol0000;
ofIVIPOo00007om<C4`7o`0000KoIVIV2?l00003ofIVIP04o`000?moOgooOgmoogmoO`Go00007OnI
VIT00ol0003oooooooooo`03ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonQ
ogmoO`03o`000?nIVIWoVIVI01ooVIVI1Ol00008ogmoO`Go00003OmVIVH6o`0000coC4a<3Ol00007
ofIVIPKo00002?moOgl3o`000004ogmoOol0003o0000o`00027oVIVI00?o0000ooooooooool01?oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooX_moOgl2o`0002CoVIVI1Ol00008
ogmoO`Ko00003OmVIVH<o`00013oIVIV1?l0000=ogmoO`Go00008onIVIT00ol0003oOgmoooooo`05
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonSogmoO`;o0000:?nIVIT8o`00
00KoOgmo:Ol0000:ogmoO`Oo00009_nIVIT2o`0000;oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CoooooYOmoOgl00ol0003oVIVIoiVIV@0EoiVIV@Co00005?nIVIT6o`0000Ko
Ogmo6_l00007oiVIV@co00003OnIVIT5o`0001WoVIVI0_l00004ogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooojKoOgmo0_l0000EoiVIV@04o`000?nc/k?o/k>cok>c/`go
00003OnIVIT6o`000003oiVIVOl0003o000000Co00004onIVIT6o`0000goVIVI3Ol00005ok>c/`03
o`000?nIVIWoVIVI01CoVIVI0_l00006ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooojSoOgmo00?o0000oiVIVOnIVIT04OnIVIT00ol0003o/k>cok>c/`0?ok>c/`go0000
1?nIVIT3o`0000Ko/k>c4ol00006ok>c/`?o00001?nIVIT6o`0001?o/k>c00?o0000oiVIVOnIVIT0
4_nIVIT00ol0003oOgmoogmoO`06ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooojWoOgmo0_l0000@oiVIV@03o`000?nc/k?o/k>c01go/k>c1?l0000Uok>c/`Co00006_nc
/k<00ol0003oVIVIoiVIV@0?oiVIV@;o00002OmoOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?oooon[ogmoO`;o00003_nIVIT00ol0003o/k>cok>c/`1Uok>c/`03o`000?nIVIWo
VIVI00goVIVI00?o0000ogmoOomoOgl02OmoOgl6ooooo`7o00000Oooool000Oooooo1Ol00003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`04ooooojgoOgmo0_l0000;
oiVIV@?o00005_nc/k<bo`000003ok>c/ol0003o000000Co00005onc/k<2o`0000_oVIVI0ol0000<
ogmoO`Kooooo0Ol00001ooooo`001oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00Cooooo[omoOgl00ol0003oVIVIoiVI
V@0;oiVIV@;o00005?nc/k<00ol0003oc<c<olc<c00_olc<c0;o00001?o<c<`00ol0003o/k>cok>c
/`0Cok>c/`;o00003?nIVIT00ol0003oOgmoogmoO`0=ogmoO`Kooooo0Ol00001ooooo`002?ooool0
0onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003ooooooooo
o`04oooook3oOgmo0ol0000<oiVIV@03o`000?nc/k?o/k>c017o/k>c00?o0000olc<c?o<c<`0<?o<
c<`2o`0000?oc<c<00?o0000ok>c/onc/k<04Onc/k<2o`0000goVIVI00?o0000ogmoOomoOgl03_mo
Ogl6ooooo`7o00000Oooool000Wooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooo
oooo000000Kooooo0ol00004oooook?oOgmo0ol0000:oiVIV@;o00004Onc/k<00ol0003oc<c<olc<
c00aolc<c0;o00000_o<c<`00ol0003o/k>cok>c/`0?ok>c/`;o00003_nIVIT00ol0003oOgmoogmo
O`0?ogmoO`Cooooo0ol00001ooooo`002_ooool00omgMgOoIVIVooooo`02ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`04oooookKoOgmo0_l0000:oiVIV@03o`000?nc
/k?o/k>c00oo/k>c00?o0000olc<c?o<c<`0<Oo<c<`2o`000003olc<c?l0003o/k>c00ko/k>c0_l0
000?oiVIV@03o`000?moOgooOgmo00goOgmo1?l00005ooooo`7o00000Oooool000_ooooo00Go0000
oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o0000ooooooooool01?oo
oonQogmoO`[o00003OmoOgl3o`0000SoVIVI0_l0000?ok>c/`03o`000?o<c<coc<c<03;oc<c<0ol0
000=ok>c/`;o00002OnIVIT8o`0000WoOgmo1ol00003ofIVIPKooooo0Ol00001ooooo`001oooool0
1Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`00
0?oooooooooo00CoooooW_moOgl3o`0000[oIVIV0_l0000>ogmoO`;o00002?nIVIT3o`0000co/k>c
00?o0000olc<c?o<c<`0<oo<c<`2o`0000co/k>c00?o0000oiVIVOnIVIT01onIVIT2o`0000koOgmo
0ol0000:ofIVIPKooooo0Ol00001ooooo`001oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo00CoooooW?moOgl2o`0000oo
IVIV1_l0000:ogmoO`?o00002?nIVIT2o`0000[o/k>c1_l0000^olc<c0Co00002?nc/k<4o`0000Go
VIVI1Ol0000<ogmoO`Co00003OmVIVH6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?oooonMogmoO`03o`000?mVIVKoIVIV01?oIVIV0ol0000:ogmoO`?o00001onIVIT4o`0000co/k>c
0ol0000Tolc<c0Oo00002?nc/k<4o`0000OoVIVI0_l0000=ogmoO`Co00004OmVIVH6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?oooonNogmoO`03o`000?mVIVKoIVIV01GoIVIV2Ol0
0004ogmoO`;o00002OnIVIT5o`0000[o/k>c1Ol0000Iolc<c0Ko00003?nc/k<3o`0000WoVIVI0_l0
000<ogmoO`?o00005OmVIVH6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonO
ogmoO`03o`000?mVIVKoIVIV01goIVIV0_l00004ogmoO`?o00002onIVIT3o`0000co/k>c6Ol0000=
ok>c/`Go00002?nIVIT4o`0000WoOgmo1Ol0000HofIVIP03o`000?oooooooooo00?ooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04oooooj3oOgmo00?o0000ofIVI_mVIVH07_mVIVH2o`00
00GoOgmo0_l0000<oiVIV@Go00009_nc/k<7o`0000SoVIVI1Ol00008ogmoO`Go00007?mVIVH00ol0
003oooooooooo`04ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonQogmoO`03
o`000?mVIVKoIVIV01ooIVIV0ol00004ogmoO`[o00001onIVIT=o`0001?o/k>c1_l0000<oiVIV@?o
00002_moOgl3o`00023oIVIV00?o0000ogmoOoooool01Oooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CoooooX_moOgl3o`00027oIVIV1?l0000:ogmoO`ko00001_nIVITCo`0000KoVIVI
3?l00007ogmoO`Ko00008OmVIVH2o`0000;oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CoooooYOmoOgl00ol0003oIVIVofIVIP0RofIVIPCo00005?moOgl6o`0000coVIVI3Ol0
0002ogmoO`Co00002OmoOgl4o`0002KoIVIV00?o0000ogmoOomoOgl00_moOgl6ooooo`7o00000Ooo
ool001[ooooo0_l00005ooooojKoOgmo00?o0000ofIVI_mVIVH09OmVIVH7o`0000GoOgmo2?l00006
ogmoO`co00003?moOgl3o`0000CoIVIV0ol00003ogmoO`?o0000:OmVIVH00ol0003oOgmoogmoO`03
ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04ooooojOoOgmo00?o0000ofIV
I_mVIVH0:omVIVH5o`0000SoIVIV1_l0000CogmoO`Go00002_mVIVH3o`0002[oIVIV0_l00006ogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooojSoOgmo00?o0000ofIVI_mV
IVH0?OmVIVHCo`0003_oIVIV00?o0000ogmoOomoOgl01_moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?oooonYogmoO`;o00005omVIVH<o`0004OoIVIV1_l0000IofIVIP;o0000
2OmoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon[ogmoO`03o`000?mV
IVKoIVIV01?oIVIV00?o0000oda<C?m<C4`02_m<C4`<o`0002koIVIV3Ol00006oda<C0?o00005OmV
IVH00ol0003oOgmoogmoO`09ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooojcoOgmo0_l0000BofIVIP;o00006?m<C4`>o`0000coIVIV5?l0000Eoda<C0;o00004_mVIVH2
o`0000coOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo[_moOgl2o`00
01;oIVIV00?o0000oda<C?m<C4`08om<C4`<o`0002SoC4a<00?o0000ofIVI_mVIVH03omVIVH3o`00
00koOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo/?moOgl2o`00017o
IVIV0_l0001Eoda<C0;o00004?mVIVH2o`00017oOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00Cooooo/_moOgl2o`00017oIVIV0_l0001Boda<C003o`000?mVIVKoIVIV00koIVIV
0_l0000CogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooookCoOgmo0_l0
000AofIVIP03o`000?m<C4coC4a<04goC4a<0_l0000?ofIVIP;o00005OmoOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?oooonfogmoO`?o00003omVIVH2o`0004_oC4a<0_l0000?
ofIVIP;o00005omoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooniogmo
O`?o00003_mVIVH3o`0004KoC4a<0_l0000?ofIVIP;o00006OmoOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?oooonlogmoO`?o00003_mVIVH3o`00043oC4a<0ol0000>ofIVIP?o
00006omoOgl6ooooo`7o00000Oooool001[ooooo0_l00005oooookooOgmo0_l0000?ofIVIP?o0000
>_m<C4`3o`0000ooIVIV0_l0000NogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003ooooooooo
o`04oooool7oOgmo0_l0000@ofIVIP?o0000<om<C4`4o`00013oIVIV0_l0000PogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04oooool?oOgmo0ol0000@ofIVIPGo0000:om<C4`3
o`0001;oIVIV0_l0000RogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
olKoOgmo0ol0000BofIVIPOo00007om<C4`5o`0001?oIVIV0_l0000TogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooolWoOgmo0_l0000GofIVIPGo00005?m<C4`6o`0001Go
IVIV0ol0000VogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooool_oOgmo
2?l0000DofIVIQCo00004omVIVH8o`0002WoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooodomoOgl3o`0003?oIVIV1Ol0000aogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooomKoOgmo1Ol0000[ofIVIP?o0000=_moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?oooonfogmoO`?o00008_moOgl7o`0001ooIVIV1Ol0000iogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooookGoOgmo00Co0000oiVIVOnI
VIWoVIVI0ol0000VogmoO`Ko00004omVIVH6o`00027oOgmo1_l0000GogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04oooookCoOgmo00?o0000oiVIVOnIVIT01OnIVIT5o`0002Oo
Ogmo4ol0000RogmoO`Go00001_nIVIT3o`0001CoOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00Cooooo/omoOgl2o`0000coVIVI1_l0001CogmoO`?o00003OnIVIT2o`0001?oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo]OmoOgl00ol0003oVIVIoiVI
V@0?oiVIV@?o0000BomoOgl5o`0000ooVIVI00?o0000ogmoOomoOgl04omoOgl6ooooo`7o00000Ooo
ool001[ooooo0_l00005oooookKoOgmo0_l0000BoiVIV@Co0000@_moOgl5o`0001;oVIVI0_l0000F
ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04oooookSoOgmo0_l0000DoiVI
V@Oo0000>?moOgl3o`0001KoVIVI00?o0000ogmoOomoOgl05_moOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?oooonjogmoO`03o`000?nIVIWoVIVI01SoVIVI1_l0000]ogmoO`Go
00005onIVIT2o`0001WoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
^omoOgl2o`0001koVIVI1ol0000IogmoO`go00006_nIVIT2o`0001_oOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00Cooooo_OmoOgl00ol0003oVIVIoiVIV@0RoiVIVAWo00009_nI
VIT00ol0003oOgmoogmoO`0KogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
oooookkoOgmo0_l0001OoiVIV@;o00007_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?ooooo0ogmoO`?o0000F_nIVIT2o`00023oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00Cooooo`omoOgl2o`0005GoVIVI0ol0000RogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooolGoOgmo0ol0001?oiVIV@?o00009OmoOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooo8ogmoO`;o0000B_nIVIT3o`0002SoOgmo1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooob_moOgl4o`0004CoVIVI0_l0000[
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooolkoOgmo0_l0000noiVI
V@Co0000;OmoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooo@ogmoO`Go
0000=onIVIT2o`00037oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OoooooEogmoO`Ko0000
;OnIVIT4o`0003?oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooofomo
Ogl7o`0001ooVIVI1ol0000gogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooon;oOgmo1_l0000<oiVIV@go0000?_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?oooooXogmoO`co0000BomoOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000Oooooo
00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000Oooooo00Go410@okZj^_oo
ooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000_ooooo00Go0000oooooooooooooooooa0@4003
ooooo`03oa0@4?oooooooooo00Cooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000:ooooo`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`000006
ooooo`?o00001?ooooooogmoOd3oOgmo1?ooool3o`00007ooooo0009ooooo`03oa0@4?l0003o^[Zj
00?ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`002_ooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?oooooooooo
ooooool@41001_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
00Oooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000Oooooo00GoZJVY
oa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Oooooooogmo
Od3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Ooo
ooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o
00001OooooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo0009ooooo`;o000000Wo410@ooooooooooooooooonk^
k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool000[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Ko
oooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo0007ooooo`Go0000
0oooool01Ol@413ooooooooooooooooo410@00Kooooo0ol00004ooooooooOgmo@?moOgl4ooooo`?o
00000Oooool000Oooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo0000
00Kooooo00?o0000ooooooooool0oooooom:ooooo`7o00000Oooool000Oooooo00CogMgMoeEEEOoo
oooo00001?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0oooooom:
ooooo`7o00000Oooool000Sooooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo
410@00Kooooo00?o0000ooooooooool0oooooom:ooooo`7o00000Oooool000Sooooo00?ok^k^odA4
A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooom:
ooooo`7o00000Oooool000Wooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Kooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
oooo03gooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooo
oooo02?ooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00Wooooo0Ol00001ooooo`006_ooooooo`0004ko00000Oooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-30.1723, -14.304, 0.195672, \
0.195672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0192308 0.211538 0.0192308 [
[.11538 -0.0125 -9 -9 ]
[.11538 -0.0125 9 0 ]
[.30769 -0.0125 -9 -9 ]
[.30769 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69231 -0.0125 -6 -9 ]
[.69231 -0.0125 6 0 ]
[.88462 -0.0125 -6 -9 ]
[.88462 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -18 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .21154 -6 -4.5 ]
[-0.0125 .21154 0 4.5 ]
[-0.0125 .40385 -12 -4.5 ]
[-0.0125 .40385 0 4.5 ]
[-0.0125 .59615 -12 -4.5 ]
[-0.0125 .59615 0 4.5 ]
[-0.0125 .78846 -12 -4.5 ]
[-0.0125 .78846 0 4.5 ]
[-0.0125 .98077 -12 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11538 0 m
.11538 .00625 L
s
[(-20)] .11538 -0.0125 0 1 Mshowa
.30769 0 m
.30769 .00625 L
s
[(-10)] .30769 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69231 0 m
.69231 .00625 L
s
[(10)] .69231 -0.0125 0 1 Mshowa
.88462 0 m
.88462 .00625 L
s
[(20)] .88462 -0.0125 0 1 Mshowa
.125 Mabswid
.15385 0 m
.15385 .00375 L
s
.19231 0 m
.19231 .00375 L
s
.23077 0 m
.23077 .00375 L
s
.26923 0 m
.26923 .00375 L
s
.34615 0 m
.34615 .00375 L
s
.38462 0 m
.38462 .00375 L
s
.42308 0 m
.42308 .00375 L
s
.46154 0 m
.46154 .00375 L
s
.53846 0 m
.53846 .00375 L
s
.57692 0 m
.57692 .00375 L
s
.61538 0 m
.61538 .00375 L
s
.65385 0 m
.65385 .00375 L
s
.73077 0 m
.73077 .00375 L
s
.76923 0 m
.76923 .00375 L
s
.80769 0 m
.80769 .00375 L
s
.84615 0 m
.84615 .00375 L
s
.07692 0 m
.07692 .00375 L
s
.03846 0 m
.03846 .00375 L
s
.92308 0 m
.92308 .00375 L
s
.96154 0 m
.96154 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(-10)] -0.0125 .01923 1 0 Mshowa
0 .21154 m
.00625 .21154 L
s
[(0)] -0.0125 .21154 1 0 Mshowa
0 .40385 m
.00625 .40385 L
s
[(10)] -0.0125 .40385 1 0 Mshowa
0 .59615 m
.00625 .59615 L
s
[(20)] -0.0125 .59615 1 0 Mshowa
0 .78846 m
.00625 .78846 L
s
[(30)] -0.0125 .78846 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(40)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .05769 m
.00375 .05769 L
s
0 .09615 m
.00375 .09615 L
s
0 .13462 m
.00375 .13462 L
s
0 .17308 m
.00375 .17308 L
s
0 .25 m
.00375 .25 L
s
0 .28846 m
.00375 .28846 L
s
0 .32692 m
.00375 .32692 L
s
0 .36538 m
.00375 .36538 L
s
0 .44231 m
.00375 .44231 L
s
0 .48077 m
.00375 .48077 L
s
0 .51923 m
.00375 .51923 L
s
0 .55769 m
.00375 .55769 L
s
0 .63462 m
.00375 .63462 L
s
0 .67308 m
.00375 .67308 L
s
0 .71154 m
.00375 .71154 L
s
0 .75 m
.00375 .75 L
s
0 .82692 m
.00375 .82692 L
s
0 .86538 m
.00375 .86538 L
s
0 .90385 m
.00375 .90385 L
s
0 .94231 m
.00375 .94231 L
s
.25 Mabswid
0 0 m
0 1 L
s
.11538 .99375 m
.11538 1 L
s
.30769 .99375 m
.30769 1 L
s
.5 .99375 m
.5 1 L
s
.69231 .99375 m
.69231 1 L
s
.88462 .99375 m
.88462 1 L
s
.125 Mabswid
.15385 .99625 m
.15385 1 L
s
.19231 .99625 m
.19231 1 L
s
.23077 .99625 m
.23077 1 L
s
.26923 .99625 m
.26923 1 L
s
.34615 .99625 m
.34615 1 L
s
.38462 .99625 m
.38462 1 L
s
.42308 .99625 m
.42308 1 L
s
.46154 .99625 m
.46154 1 L
s
.53846 .99625 m
.53846 1 L
s
.57692 .99625 m
.57692 1 L
s
.61538 .99625 m
.61538 1 L
s
.65385 .99625 m
.65385 1 L
s
.73077 .99625 m
.73077 1 L
s
.76923 .99625 m
.76923 1 L
s
.80769 .99625 m
.80769 1 L
s
.84615 .99625 m
.84615 1 L
s
.07692 .99625 m
.07692 1 L
s
.03846 .99625 m
.03846 1 L
s
.92308 .99625 m
.92308 1 L
s
.96154 .99625 m
.96154 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .21154 m
1 .21154 L
s
.99375 .40385 m
1 .40385 L
s
.99375 .59615 m
1 .59615 L
s
.99375 .78846 m
1 .78846 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .05769 m
1 .05769 L
s
.99625 .09615 m
1 .09615 L
s
.99625 .13462 m
1 .13462 L
s
.99625 .17308 m
1 .17308 L
s
.99625 .25 m
1 .25 L
s
.99625 .28846 m
1 .28846 L
s
.99625 .32692 m
1 .32692 L
s
.99625 .36538 m
1 .36538 L
s
.99625 .44231 m
1 .44231 L
s
.99625 .48077 m
1 .48077 L
s
.99625 .51923 m
1 .51923 L
s
.99625 .55769 m
1 .55769 L
s
.99625 .63462 m
1 .63462 L
s
.99625 .67308 m
1 .67308 L
s
.99625 .71154 m
1 .71154 L
s
.99625 .75 m
1 .75 L
s
.99625 .82692 m
1 .82692 L
s
.99625 .86538 m
1 .86538 L
s
.99625 .90385 m
1 .90385 L
s
.99625 .94231 m
1 .94231 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.6 g
.98077 .6005 m
.96988 .60793 L
.96115 .61872 L
.94152 .62271 L
.93099 .62755 L
.9219 .6315 L
.90228 .64364 L
.88265 .64536 L
.87658 .64717 L
.86303 .64956 L
.84341 .65514 L
.82378 .66012 L
.80416 .66394 L
.78454 .66632 L
.76491 .66533 L
.74529 .66555 L
.72567 .66491 L
.70604 .66537 L
.68642 .66227 L
.6668 .65786 L
.64717 .65246 L
.62755 .64748 L
.62343 .64717 L
.60793 .64238 L
.5883 .63717 L
.56888 .62755 L
.56868 .62746 L
.54906 .61815 L
.5301 .60793 L
.52943 .60749 L
.50981 .59362 L
.50329 .5883 L
.50981 .57194 L
.52943 .57419 L
.54906 .57811 L
.56868 .57973 L
.5883 .58783 L
.59516 .5883 L
.60793 .59139 L
.62755 .59543 L
.64717 .59594 L
.6668 .60167 L
.68642 .60548 L
.70604 .60583 L
.72567 .60697 L
.74529 .60746 L
.76491 .60728 L
.78454 .60645 L
.80416 .6068 L
.82378 .60368 L
.84341 .59903 L
.86303 .59114 L
.88265 .59341 L
.90228 .58904 L
.90444 .5883 L
.9219 .5845 L
.94152 .58015 L
.96115 .57599 L
.98077 .57261 L
F
0 g
.98077 .6005 m
.96988 .60793 L
.96115 .61872 L
.94152 .62271 L
.93099 .62755 L
.9219 .6315 L
.90228 .64364 L
.88265 .64536 L
.87658 .64717 L
.86303 .64956 L
.84341 .65514 L
.82378 .66012 L
.80416 .66394 L
.78454 .66632 L
.76491 .66533 L
.74529 .66555 L
.72567 .66491 L
.70604 .66537 L
.68642 .66227 L
.6668 .65786 L
.64717 .65246 L
.62755 .64748 L
.62343 .64717 L
.60793 .64238 L
.5883 .63717 L
.56888 .62755 L
.56868 .62746 L
.54906 .61815 L
.5301 .60793 L
.52943 .60749 L
.50981 .59362 L
.50329 .5883 L
.50981 .57194 L
.52943 .57419 L
.54906 .57811 L
.56868 .57973 L
.5883 .58783 L
.59516 .5883 L
.60793 .59139 L
.62755 .59543 L
.64717 .59594 L
.6668 .60167 L
.68642 .60548 L
.70604 .60583 L
.72567 .60697 L
.74529 .60746 L
.76491 .60728 L
.78454 .60645 L
.80416 .6068 L
.82378 .60368 L
Mistroke
.84341 .59903 L
.86303 .59114 L
.88265 .59341 L
.90228 .58904 L
.90444 .5883 L
.9219 .5845 L
.94152 .58015 L
.96115 .57599 L
.98077 .57261 L
Mfstroke
.4 g
.98077 .65947 m
.97051 .6668 L
.96115 .67333 L
.94152 .6846 L
.93811 .68642 L
.9219 .69598 L
.90228 .70323 L
.89509 .70604 L
.88265 .71004 L
.86303 .71737 L
.84341 .72357 L
.83052 .72567 L
.82378 .72625 L
.80416 .729 L
.78454 .73147 L
.76491 .73294 L
.74529 .73324 L
.72567 .73237 L
.70604 .73038 L
.68642 .72762 L
.66949 .72567 L
.6668 .72549 L
.64717 .72085 L
.62755 .71389 L
.60793 .70686 L
.60491 .70604 L
.5883 .70373 L
.56868 .69009 L
.56193 .68642 L
.54906 .67939 L
.52943 .66729 L
.52897 .6668 L
.50981 .6517 L
.50484 .64717 L
.50981 .63198 L
.52943 .63509 L
.54906 .6399 L
.56868 .64361 L
.57895 .64717 L
.5883 .65045 L
.60793 .6557 L
.62755 .65531 L
.64717 .6631 L
.66317 .6668 L
.6668 .66744 L
.68642 .67042 L
.70604 .67259 L
.72567 .67395 L
.74529 .67453 L
.76491 .67432 L
.78454 .67334 L
.80416 .67156 L
.82378 .66897 L
.83686 .6668 L
.84341 .66546 L
.86303 .65973 L
.88265 .65796 L
.90228 .65306 L
.9219 .64745 L
.92283 .64717 L
.94152 .64233 L
.96115 .63734 L
.98077 .63302 L
F
0 g
.98077 .65947 m
.97051 .6668 L
.96115 .67333 L
.94152 .6846 L
.93811 .68642 L
.9219 .69598 L
.90228 .70323 L
.89509 .70604 L
.88265 .71004 L
.86303 .71737 L
.84341 .72357 L
.83052 .72567 L
.82378 .72625 L
.80416 .729 L
.78454 .73147 L
.76491 .73294 L
.74529 .73324 L
.72567 .73237 L
.70604 .73038 L
.68642 .72762 L
.66949 .72567 L
.6668 .72549 L
.64717 .72085 L
.62755 .71389 L
.60793 .70686 L
.60491 .70604 L
.5883 .70373 L
.56868 .69009 L
.56193 .68642 L
.54906 .67939 L
.52943 .66729 L
.52897 .6668 L
.50981 .6517 L
.50484 .64717 L
.50981 .63198 L
.52943 .63509 L
.54906 .6399 L
.56868 .64361 L
.57895 .64717 L
.5883 .65045 L
.60793 .6557 L
.62755 .65531 L
.64717 .6631 L
.66317 .6668 L
.6668 .66744 L
.68642 .67042 L
.70604 .67259 L
.72567 .67395 L
.74529 .67453 L
.76491 .67432 L
Mistroke
.78454 .67334 L
.80416 .67156 L
.82378 .66897 L
.83686 .6668 L
.84341 .66546 L
.86303 .65973 L
.88265 .65796 L
.90228 .65306 L
.9219 .64745 L
.92283 .64717 L
.94152 .64233 L
.96115 .63734 L
.98077 .63302 L
Mfstroke
.4 g
.98077 .53449 m
.96712 .54906 L
.96115 .55248 L
.94152 .56237 L
.92796 .56868 L
.9219 .57217 L
.90228 .57784 L
.88265 .58374 L
.86578 .5883 L
.86303 .58851 L
.84341 .59306 L
.82378 .59859 L
.80416 .60425 L
.78454 .60067 L
.76491 .60164 L
.74529 .60184 L
.72567 .60127 L
.70604 .59994 L
.68642 .60151 L
.6668 .59592 L
.64717 .59056 L
.63422 .5883 L
.62755 .58656 L
.60793 .58099 L
.5883 .58103 L
.57195 .56868 L
.56868 .56719 L
.54906 .55776 L
.53282 .54906 L
.52943 .54614 L
.51797 .52943 L
.52943 .52626 L
.54906 .52477 L
.56501 .52943 L
.56868 .53007 L
.5883 .53354 L
.60793 .53686 L
.62755 .53794 L
.64717 .547 L
.6668 .54526 L
.68642 .54736 L
.70604 .54897 L
.7069 .54906 L
.72567 .54999 L
.74529 .55043 L
.76491 .55027 L
.78454 .54954 L
.79322 .54906 L
.80416 .5482 L
.82378 .54632 L
.84341 .544 L
.86303 .54253 L
.88265 .53837 L
.90228 .53516 L
.9219 .53175 L
.93501 .52943 L
.94152 .52866 L
.96115 .52628 L
.98077 .52857 L
F
0 g
.98077 .53449 m
.96712 .54906 L
.96115 .55248 L
.94152 .56237 L
.92796 .56868 L
.9219 .57217 L
.90228 .57784 L
.88265 .58374 L
.86578 .5883 L
.86303 .58851 L
.84341 .59306 L
.82378 .59859 L
.80416 .60425 L
.78454 .60067 L
.76491 .60164 L
.74529 .60184 L
.72567 .60127 L
.70604 .59994 L
.68642 .60151 L
.6668 .59592 L
.64717 .59056 L
.63422 .5883 L
.62755 .58656 L
.60793 .58099 L
.5883 .58103 L
.57195 .56868 L
.56868 .56719 L
.54906 .55776 L
.53282 .54906 L
.52943 .54614 L
.51797 .52943 L
.52943 .52626 L
.54906 .52477 L
.56501 .52943 L
.56868 .53007 L
.5883 .53354 L
.60793 .53686 L
.62755 .53794 L
.64717 .547 L
.6668 .54526 L
.68642 .54736 L
.70604 .54897 L
.7069 .54906 L
.72567 .54999 L
.74529 .55043 L
.76491 .55027 L
.78454 .54954 L
.79322 .54906 L
.80416 .5482 L
.82378 .54632 L
Mistroke
.84341 .544 L
.86303 .54253 L
.88265 .53837 L
.90228 .53516 L
.9219 .53175 L
.93501 .52943 L
.94152 .52866 L
.96115 .52628 L
.98077 .52857 L
Mfstroke
.6 g
.56868 .48798 m
.5883 .48718 L
.60736 .49019 L
.60793 .49025 L
.62755 .49241 L
.64717 .49443 L
.6668 .4962 L
.68642 .49767 L
.70604 .49878 L
.72567 .4979 L
.74529 .49978 L
.76491 .49914 L
.78454 .49562 L
.80416 .49825 L
.82378 .49695 L
.84341 .49532 L
.86303 .49341 L
.88265 .4913 L
.89269 .49019 L
.90228 .48919 L
.9219 .48791 L
.94152 .48933 L
.94483 .49019 L
.94152 .49936 L
.92899 .50981 L
.9219 .51277 L
.90228 .52001 L
.88265 .52657 L
.87333 .52943 L
.86303 .5335 L
.84341 .53564 L
.82378 .5387 L
.80416 .54108 L
.78454 .54276 L
.76491 .54371 L
.74529 .54391 L
.72567 .54335 L
.70604 .54205 L
.68642 .54003 L
.6668 .53732 L
.64717 .53945 L
.62755 .52972 L
.62666 .52943 L
.60793 .52349 L
.5883 .51665 L
.57097 .50981 L
.56868 .50825 L
.55594 .49019 L
F
0 g
.56868 .48798 m
.5883 .48718 L
.60736 .49019 L
.60793 .49025 L
.62755 .49241 L
.64717 .49443 L
.6668 .4962 L
.68642 .49767 L
.70604 .49878 L
.72567 .4979 L
.74529 .49978 L
.76491 .49914 L
.78454 .49562 L
.80416 .49825 L
.82378 .49695 L
.84341 .49532 L
.86303 .49341 L
.88265 .4913 L
.89269 .49019 L
.90228 .48919 L
.9219 .48791 L
.94152 .48933 L
.94483 .49019 L
.94152 .49936 L
.92899 .50981 L
.9219 .51277 L
.90228 .52001 L
.88265 .52657 L
.87333 .52943 L
.86303 .5335 L
.84341 .53564 L
.82378 .5387 L
.80416 .54108 L
.78454 .54276 L
.76491 .54371 L
.74529 .54391 L
.72567 .54335 L
.70604 .54205 L
.68642 .54003 L
.6668 .53732 L
.64717 .53945 L
.62755 .52972 L
.62666 .52943 L
.60793 .52349 L
.5883 .51665 L
.57097 .50981 L
.56868 .50825 L
.55594 .49019 L
.56868 .48798 L
s
.7 g
.5883 .60424 m
.60793 .60359 L
.62755 .60506 L
.64717 .60631 L
.65697 .60793 L
.6668 .60911 L
.68642 .61101 L
.70604 .61244 L
.72567 .61337 L
.74529 .61376 L
.76491 .61362 L
.78454 .61295 L
.80416 .61176 L
.82378 .61008 L
.84341 .60796 L
.84353 .60793 L
.86303 .6034 L
.88265 .60419 L
.90228 .6034 L
.92115 .60793 L
.90228 .62294 L
.89472 .62755 L
.88265 .63285 L
.86303 .63997 L
.84341 .64585 L
.83845 .64717 L
.82378 .65134 L
.80416 .6571 L
.78454 .66278 L
.76491 .65742 L
.74529 .65768 L
.72567 .65694 L
.70604 .6601 L
.68642 .65433 L
.6668 .64863 L
.66157 .64717 L
.64717 .64317 L
.62755 .63674 L
.60793 .62878 L
.60531 .62755 L
.5883 .61623 L
.57995 .60793 L
F
0 g
.5883 .60424 m
.60793 .60359 L
.62755 .60506 L
.64717 .60631 L
.65697 .60793 L
.6668 .60911 L
.68642 .61101 L
.70604 .61244 L
.72567 .61337 L
.74529 .61376 L
.76491 .61362 L
.78454 .61295 L
.80416 .61176 L
.82378 .61008 L
.84341 .60796 L
.84353 .60793 L
.86303 .6034 L
.88265 .60419 L
.90228 .6034 L
.92115 .60793 L
.90228 .62294 L
.89472 .62755 L
.88265 .63285 L
.86303 .63997 L
.84341 .64585 L
.83845 .64717 L
.82378 .65134 L
.80416 .6571 L
.78454 .66278 L
.76491 .65742 L
.74529 .65768 L
.72567 .65694 L
.70604 .6601 L
.68642 .65433 L
.6668 .64863 L
.66157 .64717 L
.64717 .64317 L
.62755 .63674 L
.60793 .62878 L
.60531 .62755 L
.5883 .61623 L
.57995 .60793 L
.5883 .60424 L
s
.3 g
.62755 .55116 m
.64717 .55221 L
.6668 .55353 L
.68642 .55476 L
.70604 .55574 L
.72567 .55639 L
.74529 .55667 L
.76491 .55657 L
.78454 .55609 L
.80416 .55527 L
.82378 .55415 L
.84341 .55284 L
.86303 .55159 L
.88265 .55104 L
.89074 .56868 L
.88265 .57217 L
.86303 .57922 L
.84341 .58503 L
.83032 .5883 L
.82378 .59028 L
.80416 .59703 L
.78454 .59467 L
.76491 .5958 L
.74529 .59604 L
.72567 .59537 L
.70604 .5938 L
.68642 .59363 L
.66968 .5883 L
.6668 .58762 L
.64717 .58238 L
.62755 .57603 L
.60928 .56868 L
F
0 g
.62755 .55116 m
.64717 .55221 L
.6668 .55353 L
.68642 .55476 L
.70604 .55574 L
.72567 .55639 L
.74529 .55667 L
.76491 .55657 L
.78454 .55609 L
.80416 .55527 L
.82378 .55415 L
.84341 .55284 L
.86303 .55159 L
.88265 .55104 L
.89074 .56868 L
.88265 .57217 L
.86303 .57922 L
.84341 .58503 L
.83032 .5883 L
.82378 .59028 L
.80416 .59703 L
.78454 .59467 L
.76491 .5958 L
.74529 .59604 L
.72567 .59537 L
.70604 .5938 L
.68642 .59363 L
.66968 .5883 L
.6668 .58762 L
.64717 .58238 L
.62755 .57603 L
.60928 .56868 L
.62755 .55116 L
s
.4 g
.62755 .45558 m
.64717 .45488 L
.6668 .4552 L
.68642 .45575 L
.70604 .45627 L
.72567 .45665 L
.74529 .45681 L
.76491 .45675 L
.78454 .45647 L
.80416 .45602 L
.82378 .45546 L
.84341 .45498 L
.86303 .45501 L
.87893 .47057 L
.86303 .47511 L
.84341 .47981 L
.82378 .48374 L
.80416 .48682 L
.78454 .48897 L
.76491 .49016 L
.76414 .49019 L
.74529 .49049 L
.73591 .49019 L
.72567 .48971 L
.70604 .48806 L
.68642 .48545 L
.6668 .48195 L
.64717 .47765 L
.62755 .47252 L
.62107 .47057 L
F
0 g
.62755 .45558 m
.64717 .45488 L
.6668 .4552 L
.68642 .45575 L
.70604 .45627 L
.72567 .45665 L
.74529 .45681 L
.76491 .45675 L
.78454 .45647 L
.80416 .45602 L
.82378 .45546 L
.84341 .45498 L
.86303 .45501 L
.87893 .47057 L
.86303 .47511 L
.84341 .47981 L
.82378 .48374 L
.80416 .48682 L
.78454 .48897 L
.76491 .49016 L
.76414 .49019 L
.74529 .49049 L
.73591 .49019 L
.72567 .48971 L
.70604 .48806 L
.68642 .48545 L
.6668 .48195 L
.64717 .47765 L
.62755 .47252 L
.62107 .47057 L
.62755 .45558 L
s
.3 g
.64717 .68374 m
.6668 .68358 L
.68642 .6845 L
.70604 .68546 L
.72567 .68615 L
.74067 .68642 L
.74529 .68647 L
.75927 .68642 L
.76491 .68635 L
.78454 .68583 L
.80416 .68498 L
.82378 .68399 L
.84341 .68336 L
.86107 .68642 L
.84341 .69733 L
.82378 .70417 L
.81737 .70604 L
.80416 .70888 L
.78454 .71187 L
.76491 .71348 L
.74529 .71381 L
.72567 .71287 L
.70604 .71062 L
.68642 .70689 L
.68281 .70604 L
.6668 .70117 L
.64717 .69295 L
.63663 .68642 L
F
0 g
.64717 .68374 m
.6668 .68358 L
.68642 .6845 L
.70604 .68546 L
.72567 .68615 L
.74067 .68642 L
.74529 .68647 L
.75927 .68642 L
.76491 .68635 L
.78454 .68583 L
.80416 .68498 L
.82378 .68399 L
.84341 .68336 L
.86107 .68642 L
.84341 .69733 L
.82378 .70417 L
.81737 .70604 L
.80416 .70888 L
.78454 .71187 L
.76491 .71348 L
.74529 .71381 L
.72567 .71287 L
.70604 .71062 L
.68642 .70689 L
.68281 .70604 L
.6668 .70117 L
.64717 .69295 L
.63663 .68642 L
.64717 .68374 L
s
.8 g
.6668 .62098 m
.68642 .62058 L
.70604 .62085 L
.72567 .62116 L
.74529 .62132 L
.76491 .62126 L
.78454 .62101 L
.80416 .62068 L
.82378 .62062 L
.84341 .62228 L
.8501 .62755 L
.84341 .63125 L
.82378 .63855 L
.80416 .64351 L
.78454 .64682 L
.78171 .64717 L
.76491 .64847 L
.74529 .64879 L
.72567 .64786 L
.71649 .64717 L
.70604 .64543 L
.68642 .64136 L
.6668 .63545 L
.64992 .62755 L
F
0 g
.6668 .62098 m
.68642 .62058 L
.70604 .62085 L
.72567 .62116 L
.74529 .62132 L
.76491 .62126 L
.78454 .62101 L
.80416 .62068 L
.82378 .62062 L
.84341 .62228 L
.8501 .62755 L
.84341 .63125 L
.82378 .63855 L
.80416 .64351 L
.78454 .64682 L
.78171 .64717 L
.76491 .64847 L
.74529 .64879 L
.72567 .64786 L
.71649 .64717 L
.70604 .64543 L
.68642 .64136 L
.6668 .63545 L
.64992 .62755 L
.6668 .62098 L
s
.2 g
.6668 .56527 m
.68642 .56387 L
.70604 .56363 L
.72567 .56368 L
.74529 .56373 L
.76491 .56371 L
.78454 .56364 L
.80416 .56369 L
.82378 .56432 L
.84341 .56846 L
.84368 .56868 L
.84341 .56899 L
.82378 .5786 L
.80416 .58393 L
.78454 .58735 L
.77627 .5883 L
.76491 .589 L
.74529 .58929 L
.72567 .58845 L
.72314 .5883 L
.70604 .58592 L
.68642 .58165 L
.6668 .57506 L
.65607 .56868 L
F
0 g
.6668 .56527 m
.68642 .56387 L
.70604 .56363 L
.72567 .56368 L
.74529 .56373 L
.76491 .56371 L
.78454 .56364 L
.80416 .56369 L
.82378 .56432 L
.84341 .56846 L
.84368 .56868 L
.84341 .56899 L
.82378 .5786 L
.80416 .58393 L
.78454 .58735 L
.77627 .5883 L
.76491 .589 L
.74529 .58929 L
.72567 .58845 L
.72314 .5883 L
.70604 .58592 L
.68642 .58165 L
.6668 .57506 L
.65607 .56868 L
.6668 .56527 L
s
.7 g
.6668 .5093 m
.68642 .5089 L
.70604 .50899 L
.72567 .50836 L
.74529 .50876 L
.76491 .50863 L
.78454 .50784 L
.80416 .50891 L
.82378 .509 L
.84099 .50981 L
.82378 .52942 L
.82374 .52943 L
.80416 .53271 L
.78454 .53489 L
.76491 .53609 L
.74529 .53634 L
.72567 .53564 L
.70604 .53397 L
.68642 .53128 L
.67614 .52943 L
.6668 .52618 L
.65704 .50981 L
F
0 g
.6668 .5093 m
.68642 .5089 L
.70604 .50899 L
.72567 .50836 L
.74529 .50876 L
.76491 .50863 L
.78454 .50784 L
.80416 .50891 L
.82378 .509 L
.84099 .50981 L
.82378 .52942 L
.82374 .52943 L
.80416 .53271 L
.78454 .53489 L
.76491 .53609 L
.74529 .53634 L
.72567 .53564 L
.70604 .53397 L
.68642 .53128 L
.67614 .52943 L
.6668 .52618 L
.65704 .50981 L
.6668 .5093 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00?Oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0dooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kS?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0hooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8b
onk^kS?ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08_ooool003gooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0=_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0<oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg03?ooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL08_ooool003Gooooo1_l0
0003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400[ooooo`Ko0000
1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100<oooool01Ol@413o
oooooooooooooooo410@03[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@03Cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@02;ooooo000o
ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000fooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000cooooo`05o`000?ooooooooooooooool0
0000>_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000=Oooool00onH
V9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000008_ooool0043ooooo00?oMgMgofIV
I_ooool00_ooool01Ol0003ooooooooooooooooo000003Kooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000003?ooooo00Go0000ooooooooooooooooo`00000jooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`03ogMgMomVIVKooooo00;o
oooo00Go0000ooooooooooooooooo`00000Rooooo`00@Oooool01Ol0003ooooooooooooooooo410@
00?ooooo00?o410@ooooooooool0=?ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@4100<oooool01Ol@413ooooooooooooooooo410@03[ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@03Oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo023ooooo000mooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg03Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg03?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0jooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0cooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02;ooooo000mooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^03Cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^03?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`03oeEEEOmVIVKo000000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0cooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02;ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo000Joooooooo0000C_l00001ooooo`00
6_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0?Ooo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool08ooo
ool1o`00007ooooo0008ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKo
oooo00?o0000ooooooooool0oooooom:ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooom:ooooo`7o
00000Oooool000Go00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41001_ooool00ol0003oooooooooo`3ooooood[ooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?ooooooB?ooool3o`00007o
oooo000:ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo0008ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Oooooooogmo
Od3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Ooo
ooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000oooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`003ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000?ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000oooooo00Go0000oooooooooooooooo
o`000006ooooo`?o00001?ooooooogmoOd3oOgmo1?ooool3o`00007ooooo000?ooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool000oooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`003oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000?ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo0008
ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000:ooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`002_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41001_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000[ooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo0ol00004oooooooo
Ogmo@?moOgl4ooooo`?o00000Oooool000[ooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000:ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool000Sooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooo:ogmoOdoo00009_moOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooo:ogmoO`03o`000?mVIVKoIVIV
04coIVIV00?o0000ogmoOomoOgl08omoOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooo9ogmoO`03o`000?mVIVKoIVIV04koIVIV00?o0000ogmoOomoOgl08_moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooo8ogmoO`03o`000?mVIVKoIVIV053oIVIV
00?o0000ogmoOomoOgl08OmoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooo8ogmoO`03o`000?mVIVKoIVIV057oIVIV00?o0000ogmoOomoOgl08?moOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?ooooo7ogmoO`?o0000DOmVIVH3o`00027oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooob_moOgl4o`0004SoIVIV1Ol0000Togmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooolkoOgmo1Ol00010ofIVIP?o
0000:OmoOgl6ooooo`7o00000Oooool001[ooooo0_l00005ooooom?oOgmo0ol0000hofIVIPGo0000
;?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool01?oooooFogmoO`Go0000;OmV
IVH6o`00037oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo^_moOgl7
o`0001[oOgmo1ol0000OofIVIPOo0000=omoOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?oooonbogmoO`So00001onIVIT7o`0001[oOgmo3ol00003ofIVIPgo00007omoOglDo`00
00_oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo/_moOgl00ol0003o
VIVIoiVIV@0CoiVIV@Ko00008omoOgl3o`0002OoOgmo1Ol0000CoiVIV@03o`000?moOgooOgmo00Wo
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo/omoOgl00ol0003oVIVI
oiVIV@0HoiVIV@go00008?moOgl7o`0000coOgmo3Ol0000GoiVIV@03o`000?moOgooOgmo00[oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo]?moOgl00ol0003oVIVIoiVI
V@0ToiVIVACo00001OmoOgl7o`0000OoVIVI3?l0000ToiVIV@03o`000?moOgooOgmo00[oOgmo1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo]?moOgl00ol0003oVIVIoiVIV@0h
oiVIV@Go0000?OnIVIT00ol0003oOgmoogmoO`0;ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04oooookGoOgmo00?o0000oiVIVOnIVIT0N?nIVIT00ol0003oOgmoogmoO`0<ogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooookKoOgmo00?o0000oiVIVOnI
VIT0;_nIVIT8o`0000coVIVI1ol0000]oiVIV@03o`000?moOgooOgmo00goOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00Cooooo]omoOgl3o`0001WoVIVI5?l00008ok>c/`co0000
1onc/k<@o`0001_oVIVI0_l0000@ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04oooook[oOgmo0ol0000FoiVIV@03o`000?nc/k?o/k>c03[o/k>c00?o0000oiVIVOnIVIT05onI
VIT3o`0001;oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo_OmoOgl2
o`0001GoVIVI00?o0000ok>c/onc/k<0>?nc/k<00ol0003oVIVIoiVIV@0EoiVIV@?o00005OmoOgl6
ooooo`7o00000Oooool001[ooooo0_l00005oooookooOgmo0_l0000DoiVIV@03o`000?nc/k?o/k>c
03Ko/k>c00?o0000oiVIVOnIVIT04onIVIT3o`0001SoOgmo1Oooool2o`00007ooooo000Jooooo`03
o`000?oooooooooo00Cooooo`OmoOgl2o`0001?oVIVI00?o0000ok>c/onc/k<0=?nc/k<00ol0003o
VIVIoiVIV@0AoiVIV@?o00006omoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?oooonWogmoO`go00003omoOgl4o`00013oVIVI0ol0000bok>c/`03o`000?nIVIWoVIVI013oVIVI
0_l0000DogmoO`So00000_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
oonUogmoO`;o00003OmVIVH2o`00017oOgmo0ol0000@oiVIV@?o0000;?nc/k<3o`0000koVIVI1Ol0
000?ogmoO`Oo00002?mVIVH3o`0000Gooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooojGoOgmo00?o0000ofIVI_mVIVH03_mVIVH5o`0000ooOgmo0_l0000AoiVIV@Go00009?nc/k<3
o`00013oVIVI00?o0000ogmoOomoOgl03?moOgl6o`00017oIVIV1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CoooooY_moOgl00ol0003oIVIVofIVIP0BofIVIPKo00002omoOgl2o`00
01CoVIVI1_l0000Cok>c/`_o00003onIVIT4o`0000WoOgmo1_l0000GofIVIP03o`000?oooooooooo
00?ooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooojOoOgmo00?o0000ofIVI_mV
IVH05omVIVH;o`0000;oOgmo0_l00004oiVIV@Oo00003OnIVITCo`0001?oVIVI1ol00008ogmoO`Go
00007?mVIVH00ol0003oooooooooo`04ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?oooonWogmoO`03o`000?mVIVKoIVIV02;oIVIV0_l00002ogmoO`Co00001omoOgl7o`0001ooVIVI
3Ol0000<ogmoO`?o00008?mVIVH00ol0003oOgmoooooo`05ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?oooonXogmoO`03o`000?mVIVKoIVIV02?oIVIV0_l0000BogmoOaoo00003Omo
Ogl<o`0002;oIVIV00?o0000ogmoOomoOgl01_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CoooooZOmoOgl00ol0003oIVIVofIVIP0TofIVIQ;o00009_moOgl6o`0002goIVIV00Co0000
ogmoOomoOgooOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooZ_moOgl2
o`0003KoIVIV9_l0000aofIVIP;o00001?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?oooon/ogmoO`;o00007?mVIVHAo`0003?oIVIV4Ol0000HofIVIP;o00001_moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon^ogmoO`;o00006OmVIVH00ol0003o
C4a<oda<C00?oda<C1Co00001OmVIVHJo`00013oC4a<00?o0000ofIVI_mVIVH05?mVIVH2o`0000So
Ogmo1_ooool1o`00007ooooo000Jooooo`;o00001Ooooon`ogmoO`;o00005_mVIVH00ol0003oC4a<
oda<C00Toda<C0Go0000:om<C4`00ol0003oIVIVofIVIP0AofIVIP;o00002_moOgl5ooooo`;o0000
0Oooool001[ooooo00?o0000ooooooooool01?oooonbogmoO`;o00004omVIVH00ol0003oC4a<oda<
C01Eoda<C003o`000?mVIVKoIVIV00ooIVIV0_l0000<ogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04oooookCoOgmo0_l0000@ofIVIP03o`000?m<C4coC4a<00goC4a<>Ol0000A
oda<C003o`000?mVIVKoIVIV00coIVIV0_l0000>ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04oooookKoOgmo00?o0000ofIVI_mVIVH03?mVIVH00ol0003oC4a<oda<C00<oda<
C0;o0000>Olc<c<3o`0000koC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`0>ogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooookOoOgmo0_l0000;ofIVIP?o
00003?m<C4`2o`0003_o<c<c0_l0000>oda<C0;o00002_mVIVH2o`00017oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CoooooXomoOgl9o`0000goOgmo00?o0000ofIVI_mVIVH0
2omVIVH3o`0000_oC4a<0_l0000goc<c<`;o00003Om<C4`3o`0000[oIVIV0_l0000@ogmoO`Co0000
1Oooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooXomoOgl00ol0003oVIVIoiVI
V@06oiVIV@?o00002omoOgl2o`0000koIVIV0ol0000:oda<C0?o0000<_lc<c<2o`0000coC4a<0ol0
000:ofIVIP?o00002omoOgl7o`0000?oVIVI1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CoooooX_moOgl00ol0003oVIVIoiVIV@0:oiVIV@Wo00001?moOgl00ol0003oIVIVofIVIP0>
ofIVIP?o00002_m<C4`3o`0002co<c<c0ol0000:oda<C0Co00002OmVIVH4o`0000WoOgmo1Ol0000:
oiVIV@Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooj7oOgmo00?o0000oiVI
VOnIVIT05?nIVIT3o`0000;oOgmo2ol00008ofIVIP?o00002_m<C4`5o`0002Co<c<c0ol0000:oda<
C0?o00002_mVIVH3o`0000[oOgmo0ol0000?oiVIV@Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04oooooj7oOgmo00?o0000oiVIVOnIVIT05onIVIT2o`0000_oOgmo1?l00007ofIVIP?o
00003?m<C4`6o`0001Wo<c<c1Ol00009oda<C0Co00002OmVIVH4o`0000WoOgmo1?l0000BoiVIV@Ko
oooo0Ol00001ooooo`001oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03
o`000?oooooooooo00CoooooX?moOgl2o`0001_oVIVI1Ol0000:ogmoO`?o00001omVIVH4o`0000ko
C4a<6Ol0000;oda<C0?o00001omVIVH6o`0000OoOgmo1_l0000FoiVIV@Kooooo0Ol00001ooooo`00
1oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06oooo
o`03o`000?oooooooooo00CoooooX_moOgl00ol0003oVIVIoiVIV@0MoiVIV@Ko00001omoOgl4o`00
00OoIVIV0ol0000/oda<C0?o00001omVIVH3o`000003ogmoOol0003o000000?o00001?moOgl3o`00
01coVIVI1_ooool1o`00007ooooo0008ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooo
oooooooooa0@4006ooooo`03o`000?oooooooooo00CoooooXomoOgl2o`0002?oVIVI1_l00005ogmo
O`?o00001omVIVHBo`0000coC4a<1ol00004oda<C0?o00001OmVIVH5o`000004ogmoOol0003o0000
o`0000GoVIVI1?l0000OoiVIV@Kooooo0Ol00001ooooo`002Oooool00onHV9So8B4Qonk^kP03oooo
o`05o`000?ooooooooooooooool000001_ooool3o`0000CoooooYOmoOgl00ol0003oVIVIoiVIV@0V
oiVIV@Oo000000?oOgmoo`000?l000000ol0000DofIVIPco00001omVIVH4o`0000?oIVIV1Ol00004
ogmoO`;o0000:onIVIT4ooooo`?o00000Oooool000[ooooo00?oMgMgofIVI_ooool00_ooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool01?oooonVogmoO`;o0000;OnIVIT5
o`000003ogmoOol0003o000001;o00001OmVIVH>o`0000CoIVIV0ol00005ogmoO`Co0000;?nIVIT2
o`0000Gooooo0Ol00001ooooo`002oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@
ooooooooool01?ooool00ol0003oooooooooo`04ooooojSoOgmo00?o0000oiVIVOnIVIT04OnIVIT<
o`0001;oVIVI0ol0000BogmoO`Go00003_moOgl4o`0000;oOgmo1_l00008oiVIVA;o00005OnIVIT0
0ol0003oOgmoooooo`05ooooo`7o00000Oooool000Oooooo00Go0000okZj^_ooooooV9RHoa0@4003
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`04ooooojWoOgmo00?o
0000oiVIVOnIVIT03onIVIT00ol0003o/k>cok>c/`0:ok>c/`_o00002_nIVIT[o`0000[oVIVI1?l0
000Bok>c/`?o00004OnIVIT00ol0003oOgmoogmoO`06ooooo`7o00000Oooool000Oooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003ooooo
ooooo`04ooooojWoOgmo0_l0000?oiVIV@;o00005onc/k<8o`0002goVIVI2ol0000Gok>c/`;o0000
3onIVIT01?l0003oOgmoogmoOomoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?oooon[ogmoO`?o00003_nIVIT00ol0003o/k>cok>c/`0Lok>c/bgo00008Onc/k<00ol0003oVIVI
oiVIV@0>oiVIV@03o`000?moOgooOgmo00;oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00Cooooo[_moOgl2o`0000goVIVI0_l0001Yok>c/`03o`000?nIVIWoVIVI00koVIVI00?o
0000ogmoOomoOgl00omoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon`
ogmoO`;o00003OnIVIT00ol0003o/k>cok>c/`1Uok>c/`03o`000?nIVIWoVIVI00_oVIVI1?l00006
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooook;oOgmo0_l0000<oiVI
V@03o`000?nc/k?o/k>c01?o/k>c?Ol0000Cok>c/`03o`000?nIVIWoVIVI00SoVIVI1?l0000:ogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooookCoOgmo0_l0000;oiVIV@03
o`000?nc/k?o/k>c00oo/k>c0ol0000molc<c003o`000?nc/k?o/k>c00ko/k>c0_l00009oiVIV@;o
00003_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonfogmoO`;o0000
2_nIVIT3o`0000co/k>c0_l00010olc<c0;o00003?nc/k<3o`0000WoVIVI0_l0000@ogmoO`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooookSoOgmo0ol0000:oiVIV@?o00002onc
/k<2o`0003_oc<c<0ol0000<ok>c/`;o00002OnIVIT3o`0001;oOgmo1_ooool1o`00007ooooo000J
ooooo`;o00001OoooonSogmoO`Co00005?moOgl2o`0000_oVIVI0_l0000;ok>c/`;o0000=oo<c<`2
o`0000go/k>c0_l0000:oiVIV@03o`000?moOgooOgmo013oOgmo1?l00004ooooo`;o00000Oooool0
01[ooooo00?o0000ooooooooool01?oooonSogmoO`04o`000?mVIVKoIVIVofIVIPOo00003omoOgl3
o`0000[oVIVI0ol0000:ok>c/`?o0000<_o<c<`2o`0000co/k>c0ol0000:oiVIV@;o00003_moOgl5
o`0000?oIVIV1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooX_moOgl00ol0
003oIVIVofIVIP09ofIVIPKo00003?moOgl3o`0000[oVIVI0ol0000:ok>c/`?o0000:oo<c<`4o`00
00[o/k>c1?l0000<oiVIV@03o`000?moOgooOgmo00_oOgmo0ol00008ofIVIPKooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04oooooj;oOgmo00?o0000ofIVI_mVIVH03omVIVH4o`0000_o
Ogmo0_l0000;oiVIV@;o00002onc/k<5o`0001ooc<c<1ol0000;ok>c/`?o00003?nIVIT4o`0000_o
Ogmo0ol0000;ofIVIPKooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooj;oOgmo
00?o0000ofIVI_mVIVH04omVIVH00ol0003oOgmoogmoO`0:ogmoO`?o00002_nIVIT3o`0000go/k>c
1Ol0000Golc<c0?o00004?nc/k<2o`0000[oVIVI1Ol0000<ogmoO`?o00003_mVIVH6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?oooonQogmoO`;o00005_mVIVH3o`0000coOgmo1_l0
0007oiVIV@Go00003Onc/k<Go`00013o/k>c0ol00005oiVIV@Oo00003OmoOgl4o`00017oIVIV1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooXomoOgl2o`0001OoIVIV1Ol0000=
ogmoO`Go00001onIVIT3o`0002co/k>c1Ol00005oiVIV@?o00004OmoOgl3o`0001GoIVIV1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooYOmoOgl00ol0003oIVIVofIVIP0IofIV
IP_o00001omoOgl3o`0000OoVIVI0ol0000Vok>c/`?o00001onIVIT3o`0000ooOgmo1Ol0000HofIV
IPKooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooojKoOgmo00?o0000ofIVI_mV
IVH08omVIVH2o`0000SoOgmo1?l00006oiVIV@?o00001?nc/k<Co`0000Wo/k>c0ol00007oiVIV@?o
00002omoOgl7o`0001goIVIV1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
YomoOgl00ol0003oIVIVofIVIP0TofIVIP;o00002_moOgl3o`0000KoVIVI1?l0000CoiVIV@?o0000
0onc/k<3o`0000GoVIVI1Ol00009ogmoO`Go00008omVIVH2o`0000Gooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooojSoOgmo00?o0000ofIVI_mVIVH09OmVIVH4o`0000WoOgmo1Ol0
0005oiVIV@So00003_nIVIT3o`000003oiVIVOl0003o000000Go00002omoOgl3o`0002OoIVIV00?o
0000ogmoOoooool01Oooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooZOmoOgl2
o`0002WoIVIV1ol00007ogmoO`Go00002?moOglBo`0000coOgmo1_l0000XofIVIP;o00000_moOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon[ogmoO`;o0000;_mVIVH7o`00
02KoOgmo1Ol0000/ofIVIP;o00001?moOgl6ooooo`7o00000Oooool001[ooooo0_l00005ooooojgo
Ogmo00?o0000ofIVI_mVIVH0<_mVIVH=o`0000coOgmo3Ol0000_ofIVIP;o00001_moOgl5ooooo`;o
00000Oooool001[ooooo00?o0000ooooooooool01?oooon^ogmoO`;o0000?omVIVH<o`0003_oIVIV
00?o0000ogmoOomoOgl01_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
oon`ogmoO`;o0000P_mVIVH2o`0000WoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00Cooooo/_moOgl00ol0003oIVIVofIVIP1nofIVIP03o`000?moOgooOgmo00WoOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo/omoOgl00ol0003oIVIVofIVIP0IofIV
IQWo00004omVIVHJo`0001goIVIV00?o0000ogmoOomoOgl02_moOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?oooondogmoO`;o00005omVIVH2o`0001WoC4a<4ol0000Joda<C0?o
00006?mVIVH2o`0000goOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
]_moOgl2o`0001OoIVIV00?o0000oda<C?m<C4`0@_m<C4`2o`0001SoIVIV0_l0000?ogmoO`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooookSoOgmo0_l0000FofIVIP;o0000@?m<
C4`2o`0001SoIVIV0_l0000AogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
oooook[oOgmo00?o0000ofIVI_mVIVH05OmVIVH3o`0003_oC4a<0_l0000HofIVIP;o00004omoOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonkogmoO`;o00006?mVIVH2o`00
03OoC4a<0_l0000GofIVIP?o00005OmoOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?oooonmogmoO`Co00005_mVIVH4o`00037oC4a<0_l0000FofIVIP?o00006?moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooo1ogmoO`Co00005_mVIVH5o`0002OoC4a<
1Ol0000DofIVIPCo00006omoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooo5ogmoO`?o00006?mVIVH3o`0001koC4a<1_l0000FofIVIP?o00007omoOgl6ooooo`7o00000Ooo
ool001[ooooo0_l00005ooooolSoOgmo0_l0000IofIVIPco00003?m<C4`6o`0001[oIVIV0_l0000R
ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04oooool[oOgmo0ol0000RofIV
IPco00007_mVIVH2o`0002CoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooocOmoOgl3o`0004KoIVIV0ol0000VogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooom3oOgmo0ol00010ofIVIP?o0000:OmoOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?oooooCogmoO`?o0000>OmVIVH4o`0002coOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00Coooooe_moOgl<o`0002KoIVIV1ol0000`ogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooon;oOgmo1_l0000IofIVIPOo0000=omoOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooXogmoOaWo0000?_moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo
0_l00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooooomo
Ogm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`00
1oooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06oooo
o`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`001oooool01Ol@413o
^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooo
oooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002oooool01Ol0003ooooooooooooooooo
410@00?ooooo00?o410@ooooooooool01?ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6
ooooo`7o00000Oooool000[ooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo
000000Kooooo0ol00004ooooooooOgmo@?moOgl4ooooo`?o00000Oooool000Wooooo00?o410@o`00
0?nj^[X00oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool01?oooooo
ogmoOd3oOgmo1_ooool1o`00007ooooo000:ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooo
oooooooooooooa0@4006ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001
ooooo`001oooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`001oooool0
1OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`00
0?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooo
ogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo0_l00005oooo
ooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3o
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooooomo
Ogm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo0_l0
0005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool01?oooooo
ogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo
@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[o
oooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool0
1?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooooomo
Ogm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
ooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3o
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Ooo
ool001[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000oooo
ooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo
@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000Wooooo0_l000002Ol@413ooooooooooooo
ooook^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`002_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000Oooooo
1Ol00003ooooo`05oa0@4?ooooooooooooooool@41001_ooool3o`0000CooooooomoOgm0ogmoO`Co
oooo0ol00001ooooo`001oooool01?m4A4CogMgMooooool00004ooooo`05o`000?oooooooooooooo
ool000001_ooool00ol0003oooooooooo`3ooooood[ooooo0Ol00001ooooo`001oooool01?oMgMgo
EEEEooooool00004ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3o
oooood[ooooo0Ol00001ooooo`002?ooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooooooo
ooooool@41001_ooool00ol0003oooooooooo`3ooooood[ooooo0Ol00001ooooo`002?ooool00oo^
k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3o
oooood[ooooo0Ol00001ooooo`002Oooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03gooooo00?o0000
ooooooooool0?Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03gooooo00?o0000
ooooooooool08oooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02Oooool1o`00007ooooo000Joooooooo0000C_l00001ooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-30.1723, -14.304, 0.195672, \
0.195672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0192308 0.211538 0.0192308 [
[.11538 -0.0125 -9 -9 ]
[.11538 -0.0125 9 0 ]
[.30769 -0.0125 -9 -9 ]
[.30769 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69231 -0.0125 -6 -9 ]
[.69231 -0.0125 6 0 ]
[.88462 -0.0125 -6 -9 ]
[.88462 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -18 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .21154 -6 -4.5 ]
[-0.0125 .21154 0 4.5 ]
[-0.0125 .40385 -12 -4.5 ]
[-0.0125 .40385 0 4.5 ]
[-0.0125 .59615 -12 -4.5 ]
[-0.0125 .59615 0 4.5 ]
[-0.0125 .78846 -12 -4.5 ]
[-0.0125 .78846 0 4.5 ]
[-0.0125 .98077 -12 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11538 0 m
.11538 .00625 L
s
[(-20)] .11538 -0.0125 0 1 Mshowa
.30769 0 m
.30769 .00625 L
s
[(-10)] .30769 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69231 0 m
.69231 .00625 L
s
[(10)] .69231 -0.0125 0 1 Mshowa
.88462 0 m
.88462 .00625 L
s
[(20)] .88462 -0.0125 0 1 Mshowa
.125 Mabswid
.15385 0 m
.15385 .00375 L
s
.19231 0 m
.19231 .00375 L
s
.23077 0 m
.23077 .00375 L
s
.26923 0 m
.26923 .00375 L
s
.34615 0 m
.34615 .00375 L
s
.38462 0 m
.38462 .00375 L
s
.42308 0 m
.42308 .00375 L
s
.46154 0 m
.46154 .00375 L
s
.53846 0 m
.53846 .00375 L
s
.57692 0 m
.57692 .00375 L
s
.61538 0 m
.61538 .00375 L
s
.65385 0 m
.65385 .00375 L
s
.73077 0 m
.73077 .00375 L
s
.76923 0 m
.76923 .00375 L
s
.80769 0 m
.80769 .00375 L
s
.84615 0 m
.84615 .00375 L
s
.07692 0 m
.07692 .00375 L
s
.03846 0 m
.03846 .00375 L
s
.92308 0 m
.92308 .00375 L
s
.96154 0 m
.96154 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(-10)] -0.0125 .01923 1 0 Mshowa
0 .21154 m
.00625 .21154 L
s
[(0)] -0.0125 .21154 1 0 Mshowa
0 .40385 m
.00625 .40385 L
s
[(10)] -0.0125 .40385 1 0 Mshowa
0 .59615 m
.00625 .59615 L
s
[(20)] -0.0125 .59615 1 0 Mshowa
0 .78846 m
.00625 .78846 L
s
[(30)] -0.0125 .78846 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(40)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .05769 m
.00375 .05769 L
s
0 .09615 m
.00375 .09615 L
s
0 .13462 m
.00375 .13462 L
s
0 .17308 m
.00375 .17308 L
s
0 .25 m
.00375 .25 L
s
0 .28846 m
.00375 .28846 L
s
0 .32692 m
.00375 .32692 L
s
0 .36538 m
.00375 .36538 L
s
0 .44231 m
.00375 .44231 L
s
0 .48077 m
.00375 .48077 L
s
0 .51923 m
.00375 .51923 L
s
0 .55769 m
.00375 .55769 L
s
0 .63462 m
.00375 .63462 L
s
0 .67308 m
.00375 .67308 L
s
0 .71154 m
.00375 .71154 L
s
0 .75 m
.00375 .75 L
s
0 .82692 m
.00375 .82692 L
s
0 .86538 m
.00375 .86538 L
s
0 .90385 m
.00375 .90385 L
s
0 .94231 m
.00375 .94231 L
s
.25 Mabswid
0 0 m
0 1 L
s
.11538 .99375 m
.11538 1 L
s
.30769 .99375 m
.30769 1 L
s
.5 .99375 m
.5 1 L
s
.69231 .99375 m
.69231 1 L
s
.88462 .99375 m
.88462 1 L
s
.125 Mabswid
.15385 .99625 m
.15385 1 L
s
.19231 .99625 m
.19231 1 L
s
.23077 .99625 m
.23077 1 L
s
.26923 .99625 m
.26923 1 L
s
.34615 .99625 m
.34615 1 L
s
.38462 .99625 m
.38462 1 L
s
.42308 .99625 m
.42308 1 L
s
.46154 .99625 m
.46154 1 L
s
.53846 .99625 m
.53846 1 L
s
.57692 .99625 m
.57692 1 L
s
.61538 .99625 m
.61538 1 L
s
.65385 .99625 m
.65385 1 L
s
.73077 .99625 m
.73077 1 L
s
.76923 .99625 m
.76923 1 L
s
.80769 .99625 m
.80769 1 L
s
.84615 .99625 m
.84615 1 L
s
.07692 .99625 m
.07692 1 L
s
.03846 .99625 m
.03846 1 L
s
.92308 .99625 m
.92308 1 L
s
.96154 .99625 m
.96154 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .21154 m
1 .21154 L
s
.99375 .40385 m
1 .40385 L
s
.99375 .59615 m
1 .59615 L
s
.99375 .78846 m
1 .78846 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .05769 m
1 .05769 L
s
.99625 .09615 m
1 .09615 L
s
.99625 .13462 m
1 .13462 L
s
.99625 .17308 m
1 .17308 L
s
.99625 .25 m
1 .25 L
s
.99625 .28846 m
1 .28846 L
s
.99625 .32692 m
1 .32692 L
s
.99625 .36538 m
1 .36538 L
s
.99625 .44231 m
1 .44231 L
s
.99625 .48077 m
1 .48077 L
s
.99625 .51923 m
1 .51923 L
s
.99625 .55769 m
1 .55769 L
s
.99625 .63462 m
1 .63462 L
s
.99625 .67308 m
1 .67308 L
s
.99625 .71154 m
1 .71154 L
s
.99625 .75 m
1 .75 L
s
.99625 .82692 m
1 .82692 L
s
.99625 .86538 m
1 .86538 L
s
.99625 .90385 m
1 .90385 L
s
.99625 .94231 m
1 .94231 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.6 g
.98077 .63871 m
.9657 .64717 L
.96115 .64977 L
.94152 .65865 L
.9219 .66666 L
.92155 .6668 L
.90228 .67355 L
.88265 .68181 L
.86303 .685 L
.8569 .68642 L
.84341 .68754 L
.82378 .69108 L
.80416 .69412 L
.78454 .69611 L
.76491 .69698 L
.74529 .69672 L
.72567 .69533 L
.70604 .69283 L
.68642 .68943 L
.6668 .68645 L
.66235 .68642 L
.64717 .68605 L
.62755 .67802 L
.60793 .66991 L
.59775 .6668 L
.5883 .66307 L
.56868 .65769 L
.55361 .64717 L
.54906 .64469 L
.52943 .63333 L
.52065 .62755 L
.50981 .61835 L
.49843 .60793 L
.50981 .59918 L
.52943 .60098 L
.54906 .60322 L
.56158 .60793 L
.56868 .60984 L
.5883 .61488 L
.60793 .61529 L
.62755 .62368 L
.64717 .6274 L
.648 .62755 L
.6668 .63093 L
.68642 .63375 L
.70604 .62965 L
.72567 .63337 L
.74529 .63509 L
.76491 .6354 L
.78454 .63436 L
.80416 .63169 L
.82378 .63482 L
.84341 .63232 L
.86303 .62911 L
.8711 .62755 L
.88265 .6261 L
.90228 .61987 L
.9219 .61703 L
.94152 .61222 L
.95663 .60793 L
.96115 .60702 L
.98077 .60267 L
F
0 g
.98077 .63871 m
.9657 .64717 L
.96115 .64977 L
.94152 .65865 L
.9219 .66666 L
.92155 .6668 L
.90228 .67355 L
.88265 .68181 L
.86303 .685 L
.8569 .68642 L
.84341 .68754 L
.82378 .69108 L
.80416 .69412 L
.78454 .69611 L
.76491 .69698 L
.74529 .69672 L
.72567 .69533 L
.70604 .69283 L
.68642 .68943 L
.6668 .68645 L
.66235 .68642 L
.64717 .68605 L
.62755 .67802 L
.60793 .66991 L
.59775 .6668 L
.5883 .66307 L
.56868 .65769 L
.55361 .64717 L
.54906 .64469 L
.52943 .63333 L
.52065 .62755 L
.50981 .61835 L
.49843 .60793 L
.50981 .59918 L
.52943 .60098 L
.54906 .60322 L
.56158 .60793 L
.56868 .60984 L
.5883 .61488 L
.60793 .61529 L
.62755 .62368 L
.64717 .6274 L
.648 .62755 L
.6668 .63093 L
.68642 .63375 L
.70604 .62965 L
.72567 .63337 L
.74529 .63509 L
.76491 .6354 L
.78454 .63436 L
Mistroke
.80416 .63169 L
.82378 .63482 L
.84341 .63232 L
.86303 .62911 L
.8711 .62755 L
.88265 .6261 L
.90228 .61987 L
.9219 .61703 L
.94152 .61222 L
.95663 .60793 L
.96115 .60702 L
.98077 .60267 L
Mfstroke
.4 g
.98077 .69762 m
.96772 .70604 L
.96115 .71221 L
.94152 .72094 L
.93182 .72567 L
.9219 .73044 L
.90228 .74151 L
.88355 .74529 L
.88265 .74551 L
.86303 .75118 L
.84341 .75679 L
.82378 .76126 L
.80416 .76409 L
.79142 .76491 L
.78454 .76514 L
.76491 .76565 L
.74529 .76549 L
.72916 .76491 L
.72567 .7648 L
.70604 .76302 L
.68642 .75938 L
.6668 .75431 L
.64717 .74845 L
.63567 .74529 L
.62755 .74255 L
.60793 .73616 L
.5883 .72607 L
.5874 .72567 L
.56868 .71626 L
.55121 .70604 L
.54906 .70464 L
.52943 .69112 L
.5234 .68642 L
.50981 .66891 L
.50966 .6668 L
.50981 .66665 L
.52943 .66547 L
.53646 .6668 L
.54906 .67027 L
.56868 .67598 L
.5883 .68138 L
.60793 .6864 L
.608 .68642 L
.62755 .69177 L
.64717 .69634 L
.6668 .69487 L
.68642 .70153 L
.70604 .70523 L
.71167 .70604 L
.72567 .70724 L
.74529 .70828 L
.76491 .70847 L
.78454 .70783 L
.80416 .70633 L
.80716 .70604 L
.82378 .70347 L
.84341 .6985 L
.86303 .69817 L
.88265 .69397 L
.90228 .68896 L
.9102 .68642 L
.9219 .68166 L
.94152 .67851 L
.96115 .67291 L
.98077 .66729 L
F
0 g
.98077 .69762 m
.96772 .70604 L
.96115 .71221 L
.94152 .72094 L
.93182 .72567 L
.9219 .73044 L
.90228 .74151 L
.88355 .74529 L
.88265 .74551 L
.86303 .75118 L
.84341 .75679 L
.82378 .76126 L
.80416 .76409 L
.79142 .76491 L
.78454 .76514 L
.76491 .76565 L
.74529 .76549 L
.72916 .76491 L
.72567 .7648 L
.70604 .76302 L
.68642 .75938 L
.6668 .75431 L
.64717 .74845 L
.63567 .74529 L
.62755 .74255 L
.60793 .73616 L
.5883 .72607 L
.5874 .72567 L
.56868 .71626 L
.55121 .70604 L
.54906 .70464 L
.52943 .69112 L
.5234 .68642 L
.50981 .66891 L
.50966 .6668 L
.50981 .66665 L
.52943 .66547 L
.53646 .6668 L
.54906 .67027 L
.56868 .67598 L
.5883 .68138 L
.60793 .6864 L
.608 .68642 L
.62755 .69177 L
.64717 .69634 L
.6668 .69487 L
.68642 .70153 L
.70604 .70523 L
.71167 .70604 L
.72567 .70724 L
Mistroke
.74529 .70828 L
.76491 .70847 L
.78454 .70783 L
.80416 .70633 L
.80716 .70604 L
.82378 .70347 L
.84341 .6985 L
.86303 .69817 L
.88265 .69397 L
.90228 .68896 L
.9102 .68642 L
.9219 .68166 L
.94152 .67851 L
.96115 .67291 L
.98077 .66729 L
Mfstroke
.4 g
.98077 .57788 m
.9626 .5883 L
.96115 .58937 L
.94152 .59734 L
.9219 .60474 L
.91287 .60793 L
.90228 .61119 L
.88265 .62036 L
.86303 .62115 L
.84341 .62492 L
.82683 .62755 L
.82378 .62797 L
.80416 .62853 L
.78454 .63004 L
.76491 .63079 L
.74529 .63056 L
.72567 .62941 L
.70604 .62778 L
.69231 .62755 L
.68642 .62666 L
.6668 .62327 L
.64717 .61918 L
.62755 .61573 L
.60793 .60827 L
.60633 .60793 L
.5883 .60141 L
.56868 .59367 L
.55673 .5883 L
.54906 .58404 L
.52943 .57233 L
.52404 .56868 L
.52943 .55088 L
.54906 .55265 L
.56868 .55586 L
.5883 .55939 L
.60793 .56407 L
.62755 .56655 L
.6399 .56868 L
.64717 .56995 L
.6668 .57284 L
.68642 .57516 L
.70604 .57332 L
.72567 .5768 L
.74529 .5785 L
.76491 .5788 L
.78454 .57776 L
.80416 .5752 L
.82378 .57009 L
.84341 .57397 L
.86303 .57135 L
.87951 .56868 L
.88265 .56815 L
.90228 .56463 L
.9219 .55784 L
.94152 .55747 L
.96115 .55406 L
.98077 .55134 L
F
0 g
.98077 .57788 m
.9626 .5883 L
.96115 .58937 L
.94152 .59734 L
.9219 .60474 L
.91287 .60793 L
.90228 .61119 L
.88265 .62036 L
.86303 .62115 L
.84341 .62492 L
.82683 .62755 L
.82378 .62797 L
.80416 .62853 L
.78454 .63004 L
.76491 .63079 L
.74529 .63056 L
.72567 .62941 L
.70604 .62778 L
.69231 .62755 L
.68642 .62666 L
.6668 .62327 L
.64717 .61918 L
.62755 .61573 L
.60793 .60827 L
.60633 .60793 L
.5883 .60141 L
.56868 .59367 L
.55673 .5883 L
.54906 .58404 L
.52943 .57233 L
.52404 .56868 L
.52943 .55088 L
.54906 .55265 L
.56868 .55586 L
.5883 .55939 L
.60793 .56407 L
.62755 .56655 L
.6399 .56868 L
.64717 .56995 L
.6668 .57284 L
.68642 .57516 L
.70604 .57332 L
.72567 .5768 L
.74529 .5785 L
.76491 .5788 L
.78454 .57776 L
.80416 .5752 L
.82378 .57009 L
.84341 .57397 L
.86303 .57135 L
Mistroke
.87951 .56868 L
.88265 .56815 L
.90228 .56463 L
.9219 .55784 L
.94152 .55747 L
.96115 .55406 L
.98077 .55134 L
Mfstroke
.6 g
.56868 .51152 m
.5883 .5129 L
.60793 .51507 L
.62755 .51739 L
.64717 .51965 L
.6668 .52444 L
.68642 .52359 L
.70604 .5251 L
.72567 .52619 L
.74529 .52681 L
.76491 .52693 L
.78454 .52654 L
.80416 .52565 L
.82378 .52433 L
.84341 .52263 L
.86303 .51865 L
.88265 .51845 L
.90228 .51614 L
.9219 .51386 L
.94152 .51197 L
.96074 .52943 L
.94152 .53852 L
.9219 .54688 L
.91644 .54906 L
.90228 .55328 L
.88265 .5583 L
.86303 .56265 L
.84341 .56639 L
.82921 .56868 L
.82378 .56892 L
.80416 .57107 L
.78454 .57303 L
.76491 .57399 L
.74529 .5737 L
.72567 .57223 L
.70604 .57 L
.68999 .56868 L
.68642 .56813 L
.6668 .56475 L
.64717 .56073 L
.62755 .55609 L
.60793 .55206 L
.60282 .54906 L
.5883 .54311 L
.56868 .53445 L
.5585 .52943 L
F
0 g
.56868 .51152 m
.5883 .5129 L
.60793 .51507 L
.62755 .51739 L
.64717 .51965 L
.6668 .52444 L
.68642 .52359 L
.70604 .5251 L
.72567 .52619 L
.74529 .52681 L
.76491 .52693 L
.78454 .52654 L
.80416 .52565 L
.82378 .52433 L
.84341 .52263 L
.86303 .51865 L
.88265 .51845 L
.90228 .51614 L
.9219 .51386 L
.94152 .51197 L
.96074 .52943 L
.94152 .53852 L
.9219 .54688 L
.91644 .54906 L
.90228 .55328 L
.88265 .5583 L
.86303 .56265 L
.84341 .56639 L
.82921 .56868 L
.82378 .56892 L
.80416 .57107 L
.78454 .57303 L
.76491 .57399 L
.74529 .5737 L
.72567 .57223 L
.70604 .57 L
.68999 .56868 L
.68642 .56813 L
.6668 .56475 L
.64717 .56073 L
.62755 .55609 L
.60793 .55206 L
.60282 .54906 L
.5883 .54311 L
.56868 .53445 L
.5585 .52943 L
.56868 .51152 L
s
.7 g
.60793 .63446 m
.62755 .63555 L
.64717 .63756 L
.6668 .63962 L
.68642 .64146 L
.70604 .63814 L
.72567 .6416 L
.74529 .64304 L
.76491 .64328 L
.78454 .64244 L
.80416 .6401 L
.82378 .6422 L
.84341 .6405 L
.86303 .63852 L
.88265 .63644 L
.90228 .63473 L
.92162 .64717 L
.90228 .65804 L
.88265 .66672 L
.88247 .6668 L
.86303 .67326 L
.84341 .67837 L
.82378 .68234 L
.80416 .68526 L
.79519 .68642 L
.78454 .68712 L
.76491 .68796 L
.74529 .6877 L
.7258 .68642 L
.72567 .68641 L
.70604 .68405 L
.68642 .68065 L
.6668 .67617 L
.64717 .67513 L
.63673 .6668 L
.62755 .66292 L
.60793 .65343 L
.59742 .64717 L
F
0 g
.60793 .63446 m
.62755 .63555 L
.64717 .63756 L
.6668 .63962 L
.68642 .64146 L
.70604 .63814 L
.72567 .6416 L
.74529 .64304 L
.76491 .64328 L
.78454 .64244 L
.80416 .6401 L
.82378 .6422 L
.84341 .6405 L
.86303 .63852 L
.88265 .63644 L
.90228 .63473 L
.92162 .64717 L
.90228 .65804 L
.88265 .66672 L
.88247 .6668 L
.86303 .67326 L
.84341 .67837 L
.82378 .68234 L
.80416 .68526 L
.79519 .68642 L
.78454 .68712 L
.76491 .68796 L
.74529 .6877 L
.7258 .68642 L
.72567 .68641 L
.70604 .68405 L
.68642 .68065 L
.6668 .67617 L
.64717 .67513 L
.63673 .6668 L
.62755 .66292 L
.60793 .65343 L
.59742 .64717 L
.60793 .63446 L
s
.3 g
.60793 .57904 m
.62755 .57836 L
.64717 .57941 L
.6668 .58082 L
.68642 .58221 L
.70604 .57934 L
.72567 .58247 L
.74529 .58377 L
.76491 .584 L
.78454 .58323 L
.80416 .58111 L
.82378 .57586 L
.84341 .58147 L
.86303 .58004 L
.88265 .57876 L
.90228 .5783 L
.91983 .5883 L
.90228 .59813 L
.88265 .60674 L
.87962 .60793 L
.86303 .61276 L
.84341 .61733 L
.82378 .6209 L
.80416 .62353 L
.78454 .62523 L
.76491 .62598 L
.74529 .62575 L
.72567 .62457 L
.70604 .62244 L
.68642 .61937 L
.6668 .61536 L
.64717 .61026 L
.63961 .60793 L
.62755 .60298 L
.60793 .5935 L
.59936 .5883 L
F
0 g
.60793 .57904 m
.62755 .57836 L
.64717 .57941 L
.6668 .58082 L
.68642 .58221 L
.70604 .57934 L
.72567 .58247 L
.74529 .58377 L
.76491 .584 L
.78454 .58323 L
.80416 .58111 L
.82378 .57586 L
.84341 .58147 L
.86303 .58004 L
.88265 .57876 L
.90228 .5783 L
.91983 .5883 L
.90228 .59813 L
.88265 .60674 L
.87962 .60793 L
.86303 .61276 L
.84341 .61733 L
.82378 .6209 L
.80416 .62353 L
.78454 .62523 L
.76491 .62598 L
.74529 .62575 L
.72567 .62457 L
.70604 .62244 L
.68642 .61937 L
.6668 .61536 L
.64717 .61026 L
.63961 .60793 L
.62755 .60298 L
.60793 .5935 L
.59936 .5883 L
.60793 .57904 L
s
.4 g
.60793 .47901 m
.62755 .47743 L
.64717 .47781 L
.6668 .47866 L
.68642 .47958 L
.70604 .48041 L
.72567 .48105 L
.74529 .48141 L
.76491 .48148 L
.78454 .48125 L
.80416 .48073 L
.82378 .47999 L
.84341 .47909 L
.86303 .47817 L
.88265 .4775 L
.90228 .4778 L
.91613 .49019 L
.90228 .49551 L
.88265 .50208 L
.86303 .50783 L
.8553 .50981 L
.84341 .51177 L
.82378 .51438 L
.80416 .51628 L
.78454 .5175 L
.76491 .51803 L
.74529 .51787 L
.72567 .51702 L
.70604 .51549 L
.68642 .51327 L
.6668 .51104 L
.66396 .50981 L
.64717 .5053 L
.62755 .49915 L
.60793 .49214 L
.60313 .49019 L
F
0 g
.60793 .47901 m
.62755 .47743 L
.64717 .47781 L
.6668 .47866 L
.68642 .47958 L
.70604 .48041 L
.72567 .48105 L
.74529 .48141 L
.76491 .48148 L
.78454 .48125 L
.80416 .48073 L
.82378 .47999 L
.84341 .47909 L
.86303 .47817 L
.88265 .4775 L
.90228 .4778 L
.91613 .49019 L
.90228 .49551 L
.88265 .50208 L
.86303 .50783 L
.8553 .50981 L
.84341 .51177 L
.82378 .51438 L
.80416 .51628 L
.78454 .5175 L
.76491 .51803 L
.74529 .51787 L
.72567 .51702 L
.70604 .51549 L
.68642 .51327 L
.6668 .51104 L
.66396 .50981 L
.64717 .5053 L
.62755 .49915 L
.60793 .49214 L
.60313 .49019 L
.60793 .47901 L
s
.7 g
.6668 .53447 m
.68642 .53448 L
.70604 .53487 L
.72567 .53526 L
.74529 .53552 L
.76491 .53557 L
.78454 .5354 L
.80416 .53506 L
.82378 .53465 L
.84341 .53439 L
.86303 .53501 L
.87067 .54906 L
.86303 .5515 L
.84341 .55666 L
.82378 .56064 L
.80416 .56357 L
.78454 .56545 L
.76491 .56626 L
.74529 .56602 L
.72567 .56471 L
.70604 .56235 L
.68642 .55894 L
.6668 .55446 L
.64859 .54906 L
F
0 g
.6668 .53447 m
.68642 .53448 L
.70604 .53487 L
.72567 .53526 L
.74529 .53552 L
.76491 .53557 L
.78454 .5354 L
.80416 .53506 L
.82378 .53465 L
.84341 .53439 L
.86303 .53501 L
.87067 .54906 L
.86303 .5515 L
.84341 .55666 L
.82378 .56064 L
.80416 .56357 L
.78454 .56545 L
.76491 .56626 L
.74529 .56602 L
.72567 .56471 L
.70604 .56235 L
.68642 .55894 L
.6668 .55446 L
.64859 .54906 L
.6668 .53447 L
s
.2 g
.68642 .59185 m
.70604 .59173 L
.72567 .59196 L
.74529 .59216 L
.76491 .5922 L
.78454 .59207 L
.80416 .59182 L
.82378 .5917 L
.84138 .60793 L
.82378 .61221 L
.80416 .61553 L
.78454 .6176 L
.76491 .61849 L
.74529 .61822 L
.72567 .6168 L
.70604 .61417 L
.68642 .61019 L
.6778 .60793 L
F
0 g
.68642 .59185 m
.70604 .59173 L
.72567 .59196 L
.74529 .59216 L
.76491 .5922 L
.78454 .59207 L
.80416 .59182 L
.82378 .5917 L
.84138 .60793 L
.82378 .61221 L
.80416 .61553 L
.78454 .6176 L
.76491 .61849 L
.74529 .61822 L
.72567 .6168 L
.70604 .61417 L
.68642 .61019 L
.6778 .60793 L
.68642 .59185 L
s
.6 g
.70604 .44759 m
.72567 .44668 L
.74529 .44636 L
.76491 .44631 L
.78454 .44649 L
.80416 .44705 L
.82378 .44875 L
.83229 .45094 L
.82378 .45403 L
.80416 .45845 L
.78454 .46099 L
.76491 .46206 L
.74529 .46174 L
.72567 .46001 L
.70604 .45671 L
.6871 .45094 L
F
0 g
.70604 .44759 m
.72567 .44668 L
.74529 .44636 L
.76491 .44631 L
.78454 .44649 L
.80416 .44705 L
.82378 .44875 L
.83229 .45094 L
.82378 .45403 L
.80416 .45845 L
.78454 .46099 L
.76491 .46206 L
.74529 .46174 L
.72567 .46001 L
.70604 .45671 L
.6871 .45094 L
.70604 .44759 L
s
.8 g
.70604 .65418 m
.72567 .65425 L
.74529 .65442 L
.76491 .65446 L
.78454 .65434 L
.80416 .65417 L
.82378 .65444 L
.83132 .6668 L
.82378 .66891 L
.80416 .673 L
.78454 .67545 L
.76491 .67649 L
.74529 .67618 L
.72567 .6745 L
.70604 .67135 L
.688 .6668 L
F
0 g
.70604 .65418 m
.72567 .65425 L
.74529 .65442 L
.76491 .65446 L
.78454 .65434 L
.80416 .65417 L
.82378 .65444 L
.83132 .6668 L
.82378 .66891 L
.80416 .673 L
.78454 .67545 L
.76491 .67649 L
.74529 .67618 L
.72567 .6745 L
.70604 .67135 L
.688 .6668 L
.70604 .65418 L
s
.8 g
.74529 .54827 m
.76491 .54799 L
.78404 .54906 L
.76491 .55239 L
.74529 .55169 L
.73517 .54906 L
F
0 g
.74529 .54827 m
.76491 .54799 L
.78404 .54906 L
.76491 .55239 L
.74529 .55169 L
.73517 .54906 L
.74529 .54827 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00?Oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0dooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kS?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0hooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8b
onk^kS?ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08_ooool003gooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0=_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0<oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg03?ooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL08_ooool003Gooooo1_l0
0003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400[ooooo`Ko0000
1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100<oooool01Ol@413o
oooooooooooooooo410@03[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@03Cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@02;ooooo000o
ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000fooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000cooooo`05o`000?ooooooooooooooool0
0000>_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000=Oooool00onH
V9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000008_ooool0043ooooo00?oMgMgofIV
I_ooool00_ooool01Ol0003ooooooooooooooooo000003Kooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000003?ooooo00Go0000ooooooooooooooooo`00000jooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`03ogMgMomVIVKooooo00;o
oooo00Go0000ooooooooooooooooo`00000Rooooo`00@Oooool01Ol0003ooooooooooooooooo410@
00?ooooo00?o410@ooooooooool0=?ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@4100<oooool01Ol@413ooooooooooooooooo410@03[ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@03Oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo023ooooo000mooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg03Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg03?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0jooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0cooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02;ooooo000mooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^03Cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^03?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`03oeEEEOmVIVKo000000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0cooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02;ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo000Joooooooo0000C_l00001ooooo`00
6_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0?Ooo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool08ooo
ool1o`00007ooooo0008ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKo
oooo00?o0000ooooooooool0oooooom:ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooom:ooooo`7o
00000Oooool000Go00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41001_ooool00ol0003oooooooooo`3ooooood[ooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?ooooooB?ooool3o`00007o
oooo000:ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo0008ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Oooooooogmo
Od3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Ooo
ooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000oooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`003ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000?ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000oooooo00Go0000oooooooooooooooo
o`000006ooooo`?o00001?ooooooogmoOd3oOgmo1?ooool3o`00007ooooo000?ooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool000oooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`003oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000?ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo0008
ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000:ooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`002_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41001_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000[ooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo0ol00004oooooooo
Ogmo@?moOgl4ooooo`?o00000Oooool000[ooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000:ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool000Sooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000oooooooo
ool01?oooooQogmoObSo0000=_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?oooooMogmoO`Co0000:?nIVIT6o`00033oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00Coooooh?moOgl3o`0002KoVIVI1?l0000bogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooon?oOgmo1Ol0000NoiVIV@?o0000=_moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?oooooXogmoO`Oo00004_nIVIT5o`0003WoOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CoooookomoOglBo`0003koOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooolOo
Ogmo3_l00010ogmoOa7o00006OmoOgl6ooooo`7o00000Oooool001[ooooo0_l00005oooool?oOgmo
1?l0000>ofIVIQ[o00003?moOglJo`00017oIVIV00?o0000ogmoOomoOgl05_moOgl5ooooo`;o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooo3ogmoO`03o`000?mVIVKoIVIV02WoIVIV3?l0
000/ofIVIP03o`000?moOgooOgmo01GoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00Cooooo`_moOgl00ol0003oIVIVofIVIP1SofIVIP03o`000?moOgooOgmo01CoOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo`_moOgl00ol0003oIVIVofIVIP1SofIV
IP;o00005OmoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooo3ogmoO`?o
0000H?mVIVH2o`0001OoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
a_moOgl3o`0005[oIVIV0ol0000IogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooolWoOgmo1?l0001CofIVIP?o00007?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooo=ogmoO`?o0000COmVIVH3o`0001ooOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00Coooood?moOgl3o`0004OoIVIV0ol0000RogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooom?oOgmo0ol00011ofIVIP?o00009OmoOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?oooooFogmoO`Go0000>?mVIVH4o`0002SoOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo]_moOgl;o`0001[oOgmo1ol0
000VofIVIP_o00005OmoOgl<o`0000_oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00Cooooo]_moOgl00ol0003oVIVIoiVIV@08oiVIV@go00005?moOgl=o`0001;oIVIV1ol0000J
ogmoO`Ko00003?nIVIT00ol0003oOgmoogmoO`08ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`00
00Gooooo]OmoOgl00ol0003oVIVIoiVIV@0FoiVIV@Go00007?moOglBo`0001CoOgmo3Ol0000CoiVI
V@03o`000?moOgooOgmo00OoOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooo]?moOgl00ol0003oVIVIoiVIV@0LoiVIV@?o0000>?moOgl7o`00027oVIVI00?o0000ogmoOomo
Ogl01_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooondogmoO`03o`00
0?nIVIWoVIVI01ooVIVI6Ol0000BogmoO`go0000:OnIVIT00ol0003oOgmoogmoO`05ogmoO`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooook?oOgmo0_l0000joiVIVA;o0000=_nI
VIT2o`0000KoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo]OmoOgl0
0ol0003oVIVIoiVIV@1moiVIV@;o00002?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?oooonfogmoO`;o00007_nIVITOo`0000KoVIVI7_l0000JoiVIV@;o00002_moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonhogmoO`?o00006_nIVIT00ol0003o
/k>cok>c/`0Mok>c/`Ko00007Onc/k<00ol0003oVIVIoiVIV@0FoiVIV@;o00003?moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?oooonkogmoO`;o00005onIVIT00ol0003o/k>c
ok>c/`12ok>c/`03o`000?nIVIWoVIVI01;oVIVI0ol0000>ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04oooookgoOgmo0_l0000DoiVIV@03o`000?nc/k?o/k>c04?o/k>c00?o
0000oiVIVOnIVIT04?nIVIT2o`00017oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00Cooooo_omoOgl2o`00017oVIVI00?o0000ok>c/onc/k<0A?nc/k<00ol0003oVIVIoiVIV@0?
oiVIV@03o`000?moOgooOgmo017oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00Cooooo`OmoOgl2o`0000koVIVI0ol0000Iok>c/a;o00006_nc/k<2o`0000goVIVI0ol0000Dogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooojWoOgmo2ol0000?ogmoO`Go
00003?nIVIT3o`0001Wo/k>c2ol0000Kok>c/`?o00002_nIVIT5o`0001CoOgmo1?l00005ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?oooonYogmoO`03o`000?mVIVKoIVIV00SoIVIV
1ol0000=ogmoO`Go00002_nIVIT4o`0003So/k>c0ol0000:oiVIV@?o00004_moOgl7o`0000?oIVIV
1_ooool1o`00007ooooo000Jooooo`;o00001OoooonXogmoO`03o`000?mVIVKoIVIV013oIVIV1Ol0
000=ogmoO`?o00002onIVIT7o`0002co/k>c1Ol0000:oiVIV@?o00002_moOgl;o`0000[oIVIV1Ooo
ool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooZ?moOgl00ol0003oIVIVofIVIP0E
ofIVIP?o00003OmoOgl5o`0000goVIVI1_l0000Pok>c/`Ko00003?nIVIT3o`0000[oOgmo0ol0000E
ofIVIPKooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooojSoOgmo00?o0000ofIV
I_mVIVH06?mVIVH5o`0000goOgmo1_l0000=oiVIV@Oo00003?nc/k<=o`0000goVIVI1Ol00008ogmo
O`Go00006?mVIVH6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonWogmoO`03
o`000?mVIVKoIVIV01koIVIV1Ol0000>ogmoO`?o00004OnIVIT<o`0001CoVIVI1_l00009ogmoO`Co
00007OmVIVH6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonWogmoO`;o0000
9?mVIVH8o`0000WoOgmo2_l0000IoiVIV@ko00001_moOgl9o`00027oIVIV1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CoooooZOmoOgl2o`0002[oIVIV1_l00006ogmoOb3o00001Omo
Ogl3o`0000KoIVIV1_l0000ZofIVIPKooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
oooooj_oOgmo0_l0000^ofIVIPKo00001omVIVH7o`0001;oOgmo1Ol00003ofIVIPGo0000<OmVIVH6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon]ogmoO`03o`000?mVIVKoIVIV
01?oIVIV4_l0000<ofIVIPOo00001omVIVHBo`0000GoIVIV0ol00005oda<C0?o00001?mVIVHBo`00
01OoIVIV0_l00005ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon^ogmoO`;o
00004_mVIVH00ol0003oC4a<oda<C00@oda<C0co00001om<C4`7o`0000coIVIV2ol0000;oda<C0Co
00004_m<C4`2o`0001?oIVIV0_l000000omoOgooooooooooo`04ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?oooon`ogmoO`;o00003omVIVH00ol0003oC4a<oda<C00[oda<C0co0000
;_m<C4`2o`0000ooIVIV0_l00003ogmoO`Kooooo0Ol00001ooooo`001oooool5o`0000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo00Cooooo/_moOgl2o`0000coIVIV
0_l0001Xoda<C0;o00002omVIVH3o`0000GoOgmo1_ooool1o`00007ooooo0007ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000oooooooo
ool01?oooondogmoO`;o00003?mVIVH00ol0003oC4a<oda<C00Hoda<C2oo00007?m<C4`2o`0000_o
IVIV0_l00008ogmoO`Kooooo0Ol00001ooooo`002?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@
4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`04oooookKoOgmo0ol0000:ofIVIP;o
00006?m<C4`00ol0003o<c<coc<c<`0/oc<c<`03o`000?m<C4coC4a<01OoC4a<0_l0000;ofIVIP;o
00002_moOgl6ooooo`7o00000Oooool000Wooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooo
oooooooooooo000000Kooooo0ol00004oooookWoOgmo0ol00009ofIVIP?o00005?m<C4`00ol0003o
<c<coc<c<`0^oc<c<`03o`000?m<C4coC4a<01CoC4a<0_l0000:ofIVIP?o00003?moOgl4ooooo`?o
00000Oooool000[ooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooooooool01?oooonRogmoO`co00003_moOgl3o`0000WoIVIV0_l0000Boda<C003
o`000?lc<c?o<c<c02oo<c<c00?o0000oda<C?m<C4`04?m<C4`3o`0000WoIVIV0ol0000?ogmoO`Ko
oooo0Ol00001ooooo`002oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@oooooooo
ool01?ooool00ol0003oooooooooo`04oooooj7oOgmo00?o0000oiVIVOnIVIT02_nIVIT4o`0000go
Ogmo0_l00009ofIVIP;o00003om<C4`00ol0003o<c<coc<c<`0aoc<c<`03o`000?m<C4coC4a<00go
C4a<0_l00009ofIVIP?o00003omoOgl4o`0000Gooooo0Ol00001ooooo`001oooool01Ol0003o^[Zj
oooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo
00CoooooX?moOgl00ol0003oVIVIoiVIV@0?oiVIV@;o00003OmoOgl2o`0000WoIVIV0_l0000=oda<
C003o`000?lc<c?o<c<c03;o<c<c00?o0000oda<C?m<C4`02om<C4`00ol0003oIVIVofIVIP08ofIV
IP03o`000?moOgooOgmo00coOgmo1?l00003oiVIV@Kooooo0Ol00001ooooo`001oooool01OnHV9So
410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooo
oooo00CoooooWomoOgl2o`0001?oVIVI1Ol0000:ogmoO`?o00002?mVIVH5o`0000OoC4a<1_l0000^
oc<c<`Co00002Om<C4`3o`0000WoIVIV0_l0000<ogmoO`?o00001onIVIT6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?oooonQogmoO`03o`000?nIVIWoVIVI01GoVIVI0ol0000:ogmo
O`?o00002_mVIVH3o`0000[oC4a<0ol0000Uoc<c<`Ko00002?m<C4`5o`0000WoIVIV0ol00009ogmo
O`Go00002_nIVIT6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonRogmoO`03
o`000?nIVIWoVIVI01OoVIVI2Ol00004ogmoO`Go00002?mVIVH5o`0000SoC4a<3?l0000Boc<c<`Oo
00002om<C4`3o`0000_oIVIV0ol00009ogmoO`?o00003onIVIT6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?oooonSogmoO`03o`000?nIVIWoVIVI01ooVIVI0ol00006ogmoO`Go0000
2?mVIVH7o`0000goC4a<4_l0000=oda<C0Go00003?mVIVH2o`0000OoOgmo1Ol0000BoiVIV@Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooojCoOgmo00?o0000oiVIVOnIVIT08OnI
VIT2o`0000WoOgmo0ol0000<ofIVIPKo00008?m<C4`6o`0000OoIVIV2_l00004ogmoO`Go00005onI
VIT6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonUogmoO`03o`000?nIVIWo
VIVI02;oVIVI1?l00008ogmoO`Go00003OmVIVH=o`0000KoC4a<3Ol00007ofIVIPKo00002omoOgl3
o`0001coVIVI1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooY_moOgl2o`00
02KoVIVI1ol00006ogmoO`go00003OmVIVH6o`0000KoIVIV3_l0000;ogmoO`Ko00007onIVIT6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonXogmoO`03o`000?nIVIWoVIVI02[o
VIVI1_l00006ogmoObSo00003?moOgl5o`0002GoVIVI1_ooool1o`00007ooooo000Jooooo`;o0000
1OoooonYogmoO`;o00006?nIVIT5o`0001?oVIVI1_l00007oiVIV@Oo00003?moOgl6o`0000SoVIVI
3?l0000=oiVIV@Go00006?nIVIT5ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool01?oo
oon[ogmoO`;o00005_nIVIT00ol0003o/k>cok>c/`02ok>c/`go00006_nIVIT<o`00023oVIVI1ol0
0005ok>c/`03o`000?nIVIWoVIVI01GoVIVI1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00Cooooo[OmoOgl00ol0003oVIVIoiVIV@0BoiVIV@03o`000?nc/k?o/k>c013o/k>c1_l00006
oiVIV@Oo00006OnIVIT8o`0000GoVIVI3Ol0000=ok>c/`03o`000?nIVIWoVIVI01?oVIVI0_l00005
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon^ogmoO`;o00004OnIVIT00ol0
003o/k>cok>c/`0Gok>c/`Ko00001onc/k<Io`0000So/k>c1Ol0000Kok>c/`03o`000?nIVIWoVIVI
013oVIVI0_l000000omoOgooooooooooo`04ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?oooon`ogmoO`03o`000?nIVIWoVIVI00koVIVI00?o0000ok>c/onc/k<0I_nc/k<00ol0003o
VIVIoiVIV@0>oiVIV@04o`000?moOgooOgmoogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04oooook7oOgmo0_l0000=oiVIV@;o0000J?nc/k<2o`0000_oVIVI1?l00004ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooook?oOgmo0_l0000=oiVIV@03o`00
0?nc/k?o/k>c06?o/k>c0_l0000;oiVIV@;o00002?moOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?ooooneogmoO`03o`000?nIVIWoVIVI00_oVIVI0_l0000Nok>c/bWo00006_nc
/k<2o`0000_oVIVI0_l0000:ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
oooookKoOgmo0ol0000<oiVIV@?o00006_nc/k<00ol0003oc<c<olc<c00Volc<c003o`000?nc/k?o
/k>c01Ko/k>c0_l0000;oiVIV@;o00003?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?ooooniogmoO`?o00003?nIVIT2o`0001Ko/k>c0_l0000Zolc<c003o`000?nc/k?o/k>c
01;o/k>c0ol0000:oiVIV@?o00003_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?oooonlogmoO`Co00002_nIVIT3o`0001;o/k>c00?o0000olc<c?o<c<`0:_o<c<`00ol0003o
/k>cok>c/`0@ok>c/`;o00002onIVIT2o`00017oOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CoooooX_moOgl=o`00017oOgmo0ol0000:oiVIV@03o`000?nc/k?o/k>c00ko/k>c
0ol0000[olc<c0;o00003onc/k<2o`0000_oVIVI0_l0000AogmoO`?o00001Oooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CoooooXomoOgl00ol0003oIVIVofIVIP09ofIVIPCo00004?mo
Ogl2o`0000WoVIVI00?o0000ok>c/onc/k<04?nc/k<3o`0002Coc<c<1?l0000>ok>c/`?o00002_nI
VIT3o`00013oOgmo0ol00002ofIVIPKooooo0Ol00001ooooo`006_ooool2o`0000GoooooXomoOgl0
0ol0003oIVIVofIVIP0=ofIVIP?o00003omoOgl3o`0000OoVIVI00?o0000ok>c/onc/k<04_nc/k<4
o`0001Woc<c<1ol0000>ok>c/`Co00002_nIVIT3o`00013oOgmo0ol00005ofIVIPGooooo0_l00001
ooooo`006_ooool00ol0003oooooooooo`04ooooojCoOgmo00?o0000ofIVI_mVIVH03omVIVH3o`00
00ooOgmo0_l00006oiVIV@[o00003_nc/k<Io`0001;o/k>c0ol0000;oiVIV@?o00004?moOgl3o`00
00SoIVIV1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooYOmoOgl00ol0003o
IVIVofIVIP0AofIVIP?o00003_moOgl2o`0000koVIVI0ol0000aok>c/`Go00003?nIVIT2o`0000ko
Ogmo1Ol0000;ofIVIPKooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooojGoOgmo
00?o0000ofIVI_mVIVH05?mVIVH4o`0000coOgmo0_l0000?oiVIV@Go00009_nc/k<6o`0000goVIVI
1?l0000;ogmoO`Go00004?mVIVH6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
oonVogmoO`03o`000?mVIVKoIVIV01OoIVIV0ol0000;ogmoO`;o00004_nIVIT6o`0001_o/k>c1Ol0
000?oiVIV@Co00003_moOgl00ol0003oIVIVofIVIP0CofIVIPKooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooojOoOgmo0_l0000JofIVIPGo00002?moOgl;o`0000goVIVI6ol0000;
oiVIV@Wo00003?moOgl6o`0001KoIVIV1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CoooooZOmoOgl2o`0001goIVIV1Ol0000>ogmoO`Oo00009_nIVIT6o`0001;oOgmo0ol0000LofIV
IPKooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooj_oOgmo00?o0000ofIVI_mV
IVH07omVIVH3o`0000CoOgmo1Ol00009ogmoO`Ko00006OnIVIT7o`0001GoOgmo0ol0000OofIVIPKo
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooojcoOgmo0_l0000RofIVIPCo0000
1OmVIVH2o`0000goOgmo6Ol0000IogmoO`?o00008OmVIVH2o`0000Gooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooojkoOgmo00?o0000ofIVI_mVIVH0:_mVIVH2o`00037oOgmo3?l0
000SofIVIP03o`000?moOgoooooo00Gooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooojooOgmo00?o0000ofIVI_mVIVH0:omVIVH5o`0002KoOgmo1_l0000^ofIVIP03o`000?moOgoo
Ogmo00Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooook3oOgmo0_l0000`ofIV
IPOo00006?moOgl7o`0003;oIVIV0_l00003ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04oooook;oOgmo00?o0000ofIVI_mVIVH0=?mVIVHHo`0003SoIVIV00?o0000ogmoOomo
Ogl00omoOgl6ooooo`7o00000Oooool001[ooooo0_l00005oooook?oOgmo0_l00022ofIVIP;o0000
1_moOgl5ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool01?ooooneogmoO`03o`000?mV
IVKoIVIV07goIVIV0_l00008ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
oooookKoOgmo0_l0001kofIVIP;o00002_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?oooonhogmoO`;o0000MomVIVH2o`0000coOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00Cooooo^_moOgl2o`0007CoIVIV00?o0000ogmoOomoOgl03?moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?oooonlogmoO`?o0000K_mVIVH3o`0000ooOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo_omoOgl2o`0006WoIVIV0ol0
000BogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooool7oOgmo0_l0001V
ofIVIP03o`000?moOgooOgmo01?oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00Cooooo`omoOgl3o`00067oIVIV0_l0000FogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooolKoOgmo0ol0001MofIVIP03o`000?moOgooOgmo01KoOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooobOmoOgl3o`0005KoIVIV1?l0000IogmoO`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooolcoOgmo0ol0001>ofIVIPGo00007Omo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooo?ogmoO`Co0000AomVIVH3
o`0002;oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OoooooCogmoO`?o0000@?mVIVH4o`00
02GoOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00Coooooe_moOgl4o`0003Wo
IVIV0ol0000YogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooom[oOgmo
0ol0000aofIVIPGo0000;?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
oooMogmoO`Go00009_mVIVH6o`00037oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00Coooooh_moOgl6o`0001[oIVIV1_l0000gogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooonSoOgmo6_l0000mogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooooomo
Ogm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6
ooooo`7o00000Oooool000Oooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Ooo
ool000Oooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000_ooooo00Go
0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0
1?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000:ooooo`03ojVYZOl@413ooooo00;ooooo00Go
0000ooooooooooooooooo`000006ooooo`?o00001?ooooooogmoOd3oOgmo1?ooool3o`00007ooooo
0009ooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool00onj^[[o8B4Qoooo
o`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`04ooooooooOgmo
@?moOgl6ooooo`7o00000Oooool000Oooooo00Go410@oiRHV?oooooo^[Zjo`000003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool000Oooooo00GoZJVYoa0@4?l0003o410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooo
ogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo
000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
ooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3o
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooooomo
Ogm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00
007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooo
ogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo
@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_oo
ool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007ooooo000Joooo
o`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooooomo
Ogm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
ooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3o
Ogmo1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007ooooo
000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo
@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo0009ooooo`;o0000
00Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool00_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo0007ooooo`Go00000oooool01Ol@413ooooooooooooooooo410@00Kooooo0ol00004
ooooooooOgmo@?moOgl4ooooo`?o00000Oooool000Oooooo00CoA4A4omgMgOoooooo00001?ooool0
1Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0oooooom:ooooo`7o00000Ooo
ool000Oooooo00CogMgMoeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool0oooooom:ooooo`7o00000Oooool000Sooooo00?oMgMgolc<c?l000001?oo
ool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool0oooooom:ooooo`7o0000
0Oooool000Sooooo00?ok^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo
00?o0000ooooooooool0oooooom:ooooo`7o00000Oooool000Wooooo00?oMgMgo`000?ooool00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool08oooool00ol0003ooooo
ooooo`0mooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0?Oooool00ol0003ooooo
ooooo`0mooooo`03o`000?oooooooooo02?ooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00Wooooo0Ol00001ooooo`006_ooooooo`0004ko00000Oooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-30.1723, -14.304, 0.195672, \
0.195672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0192308 0.211538 0.0192308 [
[.11538 -0.0125 -9 -9 ]
[.11538 -0.0125 9 0 ]
[.30769 -0.0125 -9 -9 ]
[.30769 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69231 -0.0125 -6 -9 ]
[.69231 -0.0125 6 0 ]
[.88462 -0.0125 -6 -9 ]
[.88462 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -18 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .21154 -6 -4.5 ]
[-0.0125 .21154 0 4.5 ]
[-0.0125 .40385 -12 -4.5 ]
[-0.0125 .40385 0 4.5 ]
[-0.0125 .59615 -12 -4.5 ]
[-0.0125 .59615 0 4.5 ]
[-0.0125 .78846 -12 -4.5 ]
[-0.0125 .78846 0 4.5 ]
[-0.0125 .98077 -12 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11538 0 m
.11538 .00625 L
s
[(-20)] .11538 -0.0125 0 1 Mshowa
.30769 0 m
.30769 .00625 L
s
[(-10)] .30769 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69231 0 m
.69231 .00625 L
s
[(10)] .69231 -0.0125 0 1 Mshowa
.88462 0 m
.88462 .00625 L
s
[(20)] .88462 -0.0125 0 1 Mshowa
.125 Mabswid
.15385 0 m
.15385 .00375 L
s
.19231 0 m
.19231 .00375 L
s
.23077 0 m
.23077 .00375 L
s
.26923 0 m
.26923 .00375 L
s
.34615 0 m
.34615 .00375 L
s
.38462 0 m
.38462 .00375 L
s
.42308 0 m
.42308 .00375 L
s
.46154 0 m
.46154 .00375 L
s
.53846 0 m
.53846 .00375 L
s
.57692 0 m
.57692 .00375 L
s
.61538 0 m
.61538 .00375 L
s
.65385 0 m
.65385 .00375 L
s
.73077 0 m
.73077 .00375 L
s
.76923 0 m
.76923 .00375 L
s
.80769 0 m
.80769 .00375 L
s
.84615 0 m
.84615 .00375 L
s
.07692 0 m
.07692 .00375 L
s
.03846 0 m
.03846 .00375 L
s
.92308 0 m
.92308 .00375 L
s
.96154 0 m
.96154 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(-10)] -0.0125 .01923 1 0 Mshowa
0 .21154 m
.00625 .21154 L
s
[(0)] -0.0125 .21154 1 0 Mshowa
0 .40385 m
.00625 .40385 L
s
[(10)] -0.0125 .40385 1 0 Mshowa
0 .59615 m
.00625 .59615 L
s
[(20)] -0.0125 .59615 1 0 Mshowa
0 .78846 m
.00625 .78846 L
s
[(30)] -0.0125 .78846 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(40)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .05769 m
.00375 .05769 L
s
0 .09615 m
.00375 .09615 L
s
0 .13462 m
.00375 .13462 L
s
0 .17308 m
.00375 .17308 L
s
0 .25 m
.00375 .25 L
s
0 .28846 m
.00375 .28846 L
s
0 .32692 m
.00375 .32692 L
s
0 .36538 m
.00375 .36538 L
s
0 .44231 m
.00375 .44231 L
s
0 .48077 m
.00375 .48077 L
s
0 .51923 m
.00375 .51923 L
s
0 .55769 m
.00375 .55769 L
s
0 .63462 m
.00375 .63462 L
s
0 .67308 m
.00375 .67308 L
s
0 .71154 m
.00375 .71154 L
s
0 .75 m
.00375 .75 L
s
0 .82692 m
.00375 .82692 L
s
0 .86538 m
.00375 .86538 L
s
0 .90385 m
.00375 .90385 L
s
0 .94231 m
.00375 .94231 L
s
.25 Mabswid
0 0 m
0 1 L
s
.11538 .99375 m
.11538 1 L
s
.30769 .99375 m
.30769 1 L
s
.5 .99375 m
.5 1 L
s
.69231 .99375 m
.69231 1 L
s
.88462 .99375 m
.88462 1 L
s
.125 Mabswid
.15385 .99625 m
.15385 1 L
s
.19231 .99625 m
.19231 1 L
s
.23077 .99625 m
.23077 1 L
s
.26923 .99625 m
.26923 1 L
s
.34615 .99625 m
.34615 1 L
s
.38462 .99625 m
.38462 1 L
s
.42308 .99625 m
.42308 1 L
s
.46154 .99625 m
.46154 1 L
s
.53846 .99625 m
.53846 1 L
s
.57692 .99625 m
.57692 1 L
s
.61538 .99625 m
.61538 1 L
s
.65385 .99625 m
.65385 1 L
s
.73077 .99625 m
.73077 1 L
s
.76923 .99625 m
.76923 1 L
s
.80769 .99625 m
.80769 1 L
s
.84615 .99625 m
.84615 1 L
s
.07692 .99625 m
.07692 1 L
s
.03846 .99625 m
.03846 1 L
s
.92308 .99625 m
.92308 1 L
s
.96154 .99625 m
.96154 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .21154 m
1 .21154 L
s
.99375 .40385 m
1 .40385 L
s
.99375 .59615 m
1 .59615 L
s
.99375 .78846 m
1 .78846 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .05769 m
1 .05769 L
s
.99625 .09615 m
1 .09615 L
s
.99625 .13462 m
1 .13462 L
s
.99625 .17308 m
1 .17308 L
s
.99625 .25 m
1 .25 L
s
.99625 .28846 m
1 .28846 L
s
.99625 .32692 m
1 .32692 L
s
.99625 .36538 m
1 .36538 L
s
.99625 .44231 m
1 .44231 L
s
.99625 .48077 m
1 .48077 L
s
.99625 .51923 m
1 .51923 L
s
.99625 .55769 m
1 .55769 L
s
.99625 .63462 m
1 .63462 L
s
.99625 .67308 m
1 .67308 L
s
.99625 .71154 m
1 .71154 L
s
.99625 .75 m
1 .75 L
s
.99625 .82692 m
1 .82692 L
s
.99625 .86538 m
1 .86538 L
s
.99625 .90385 m
1 .90385 L
s
.99625 .94231 m
1 .94231 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.6 g
.98077 .676 m
.96115 .68577 L
.95976 .68642 L
.94152 .69552 L
.9219 .70209 L
.91041 .70604 L
.90228 .70774 L
.88265 .71397 L
.86303 .71988 L
.84341 .72429 L
.82812 .72567 L
.82378 .72628 L
.80416 .72652 L
.78454 .72753 L
.76491 .72777 L
.74529 .72716 L
.72567 .726 L
.71022 .72567 L
.70604 .72556 L
.68642 .7226 L
.6668 .71742 L
.64717 .71114 L
.62801 .70604 L
.62755 .70589 L
.60793 .70244 L
.5883 .69079 L
.57877 .68642 L
.56868 .68157 L
.54906 .67403 L
.5415 .6668 L
.52943 .65887 L
.5133 .64717 L
.50981 .64309 L
.50338 .62755 L
.50981 .6261 L
.52714 .62755 L
.52943 .62803 L
.54906 .63285 L
.56868 .63788 L
.5883 .64118 L
.60653 .64717 L
.60793 .64772 L
.62755 .65264 L
.64717 .64999 L
.6668 .65852 L
.68642 .66323 L
.70604 .66606 L
.71527 .6668 L
.72567 .66773 L
.74529 .66899 L
.76491 .66951 L
.78454 .66931 L
.80416 .66838 L
.82301 .6668 L
.82378 .66675 L
.84341 .66469 L
.86303 .66087 L
.88265 .65458 L
.90228 .65458 L
.9219 .64997 L
.93189 .64717 L
.94152 .64476 L
.96115 .63299 L
.98077 .63507 L
F
0 g
.98077 .676 m
.96115 .68577 L
.95976 .68642 L
.94152 .69552 L
.9219 .70209 L
.91041 .70604 L
.90228 .70774 L
.88265 .71397 L
.86303 .71988 L
.84341 .72429 L
.82812 .72567 L
.82378 .72628 L
.80416 .72652 L
.78454 .72753 L
.76491 .72777 L
.74529 .72716 L
.72567 .726 L
.71022 .72567 L
.70604 .72556 L
.68642 .7226 L
.6668 .71742 L
.64717 .71114 L
.62801 .70604 L
.62755 .70589 L
.60793 .70244 L
.5883 .69079 L
.57877 .68642 L
.56868 .68157 L
.54906 .67403 L
.5415 .6668 L
.52943 .65887 L
.5133 .64717 L
.50981 .64309 L
.50338 .62755 L
.50981 .6261 L
.52714 .62755 L
.52943 .62803 L
.54906 .63285 L
.56868 .63788 L
.5883 .64118 L
.60653 .64717 L
.60793 .64772 L
.62755 .65264 L
.64717 .64999 L
.6668 .65852 L
.68642 .66323 L
.70604 .66606 L
.71527 .6668 L
.72567 .66773 L
.74529 .66899 L
Mistroke
.76491 .66951 L
.78454 .66931 L
.80416 .66838 L
.82301 .6668 L
.82378 .66675 L
.84341 .66469 L
.86303 .66087 L
.88265 .65458 L
.90228 .65458 L
.9219 .64997 L
.93189 .64717 L
.94152 .64476 L
.96115 .63299 L
.98077 .63507 L
Mfstroke
.4 g
.98077 .61486 m
.96115 .62388 L
.95268 .62755 L
.94152 .63283 L
.9219 .63856 L
.90228 .64441 L
.89214 .64717 L
.88265 .64849 L
.86303 .65352 L
.84341 .65853 L
.82378 .66297 L
.80416 .66151 L
.78454 .66251 L
.76491 .66273 L
.74529 .66216 L
.72567 .66513 L
.70604 .6611 L
.68642 .65638 L
.6668 .65121 L
.64717 .6472 L
.6463 .64717 L
.62755 .64192 L
.60793 .6404 L
.5883 .62855 L
.58576 .62755 L
.56868 .62 L
.54906 .61055 L
.54425 .60793 L
.52943 .59777 L
.517 .5883 L
.52943 .57636 L
.54906 .5782 L
.56868 .58156 L
.5883 .5867 L
.60291 .5883 L
.60793 .58972 L
.62755 .59371 L
.64717 .59153 L
.6668 .60022 L
.68642 .60595 L
.70604 .60496 L
.72567 .60658 L
.74529 .60762 L
.75556 .60793 L
.76491 .60807 L
.78298 .60793 L
.78454 .60789 L
.80416 .60711 L
.82378 .60574 L
.84341 .60383 L
.86303 .60286 L
.88265 .59616 L
.90228 .5953 L
.9219 .59154 L
.93652 .5883 L
.94152 .58732 L
.96115 .58126 L
.98077 .57958 L
F
0 g
.98077 .61486 m
.96115 .62388 L
.95268 .62755 L
.94152 .63283 L
.9219 .63856 L
.90228 .64441 L
.89214 .64717 L
.88265 .64849 L
.86303 .65352 L
.84341 .65853 L
.82378 .66297 L
.80416 .66151 L
.78454 .66251 L
.76491 .66273 L
.74529 .66216 L
.72567 .66513 L
.70604 .6611 L
.68642 .65638 L
.6668 .65121 L
.64717 .6472 L
.6463 .64717 L
.62755 .64192 L
.60793 .6404 L
.5883 .62855 L
.58576 .62755 L
.56868 .62 L
.54906 .61055 L
.54425 .60793 L
.52943 .59777 L
.517 .5883 L
.52943 .57636 L
.54906 .5782 L
.56868 .58156 L
.5883 .5867 L
.60291 .5883 L
.60793 .58972 L
.62755 .59371 L
.64717 .59153 L
.6668 .60022 L
.68642 .60595 L
.70604 .60496 L
.72567 .60658 L
.74529 .60762 L
.75556 .60793 L
.76491 .60807 L
.78298 .60793 L
.78454 .60789 L
.80416 .60711 L
.82378 .60574 L
.84341 .60383 L
Mistroke
.86303 .60286 L
.88265 .59616 L
.90228 .5953 L
.9219 .59154 L
.93652 .5883 L
.94152 .58732 L
.96115 .58126 L
.98077 .57958 L
Mfstroke
.4 g
.98077 .73408 m
.96207 .74529 L
.96115 .74597 L
.94152 .75618 L
.9219 .76488 L
.92182 .76491 L
.90228 .77376 L
.88265 .77935 L
.8636 .78454 L
.86303 .78466 L
.84341 .78893 L
.82378 .79265 L
.80416 .79539 L
.78454 .79696 L
.76491 .79731 L
.74529 .79642 L
.72567 .79432 L
.70604 .79112 L
.68642 .78708 L
.6748 .78454 L
.6668 .78247 L
.64717 .77959 L
.62755 .76967 L
.61661 .76491 L
.60793 .7612 L
.5883 .75635 L
.57627 .74529 L
.56868 .74084 L
.54906 .72822 L
.5455 .72567 L
.52943 .7109 L
.52592 .70604 L
.52943 .70153 L
.54906 .7029 L
.56293 .70604 L
.56868 .7078 L
.5883 .71387 L
.60793 .71945 L
.62755 .72337 L
.63313 .72567 L
.64717 .72947 L
.6668 .73398 L
.68642 .73763 L
.70604 .74046 L
.72567 .74015 L
.74529 .74275 L
.76491 .74372 L
.78454 .74335 L
.80416 .74153 L
.82378 .74146 L
.84341 .73898 L
.86303 .73569 L
.88265 .73156 L
.90228 .7266 L
.90489 .72567 L
.9219 .72171 L
.94152 .7164 L
.96115 .7105 L
.9765 .70604 L
.98077 .70477 L
F
0 g
.98077 .73408 m
.96207 .74529 L
.96115 .74597 L
.94152 .75618 L
.9219 .76488 L
.92182 .76491 L
.90228 .77376 L
.88265 .77935 L
.8636 .78454 L
.86303 .78466 L
.84341 .78893 L
.82378 .79265 L
.80416 .79539 L
.78454 .79696 L
.76491 .79731 L
.74529 .79642 L
.72567 .79432 L
.70604 .79112 L
.68642 .78708 L
.6748 .78454 L
.6668 .78247 L
.64717 .77959 L
.62755 .76967 L
.61661 .76491 L
.60793 .7612 L
.5883 .75635 L
.57627 .74529 L
.56868 .74084 L
.54906 .72822 L
.5455 .72567 L
.52943 .7109 L
.52592 .70604 L
.52943 .70153 L
.54906 .7029 L
.56293 .70604 L
.56868 .7078 L
.5883 .71387 L
.60793 .71945 L
.62755 .72337 L
.63313 .72567 L
.64717 .72947 L
.6668 .73398 L
.68642 .73763 L
.70604 .74046 L
.72567 .74015 L
.74529 .74275 L
.76491 .74372 L
.78454 .74335 L
.80416 .74153 L
.82378 .74146 L
Mistroke
.84341 .73898 L
.86303 .73569 L
.88265 .73156 L
.90228 .7266 L
.90489 .72567 L
.9219 .72171 L
.94152 .7164 L
.96115 .7105 L
.9765 .70604 L
.98077 .70477 L
Mfstroke
.6 g
.98077 .55457 m
.96115 .56504 L
.95384 .56868 L
.94152 .57321 L
.9219 .57956 L
.90228 .58532 L
.89129 .5883 L
.88265 .59016 L
.86303 .59682 L
.84341 .59706 L
.82378 .59937 L
.80416 .60099 L
.78454 .60191 L
.76491 .60211 L
.74529 .60159 L
.72567 .60036 L
.70604 .59844 L
.68642 .60168 L
.6668 .59361 L
.64717 .58831 L
.64715 .5883 L
.62755 .58285 L
.60793 .57686 L
.5883 .57194 L
.58464 .56868 L
.56868 .56054 L
.54906 .54944 L
.54847 .54906 L
.54906 .53729 L
.56868 .53562 L
.5883 .53737 L
.60793 .53984 L
.62755 .54256 L
.64717 .5453 L
.6668 .54796 L
.67549 .54906 L
.68642 .55029 L
.70604 .55209 L
.72567 .5534 L
.74529 .55423 L
.76491 .55458 L
.78454 .55444 L
.80416 .55382 L
.82378 .55272 L
.84341 .55114 L
.86303 .54906 L
.86303 .54906 L
.88265 .54649 L
.90228 .54783 L
.9219 .54102 L
.94152 .53841 L
.96115 .53624 L
.98077 .53557 L
F
0 g
.98077 .55457 m
.96115 .56504 L
.95384 .56868 L
.94152 .57321 L
.9219 .57956 L
.90228 .58532 L
.89129 .5883 L
.88265 .59016 L
.86303 .59682 L
.84341 .59706 L
.82378 .59937 L
.80416 .60099 L
.78454 .60191 L
.76491 .60211 L
.74529 .60159 L
.72567 .60036 L
.70604 .59844 L
.68642 .60168 L
.6668 .59361 L
.64717 .58831 L
.64715 .5883 L
.62755 .58285 L
.60793 .57686 L
.5883 .57194 L
.58464 .56868 L
.56868 .56054 L
.54906 .54944 L
.54847 .54906 L
.54906 .53729 L
.56868 .53562 L
.5883 .53737 L
.60793 .53984 L
.62755 .54256 L
.64717 .5453 L
.6668 .54796 L
.67549 .54906 L
.68642 .55029 L
.70604 .55209 L
.72567 .5534 L
.74529 .55423 L
.76491 .55458 L
.78454 .55444 L
.80416 .55382 L
.82378 .55272 L
.84341 .55114 L
.86303 .54906 L
.86303 .54906 L
.88265 .54649 L
.90228 .54783 L
.9219 .54102 L
Mistroke
.94152 .53841 L
.96115 .53624 L
.98077 .53557 L
Mfstroke
.4 g
.60793 .50008 m
.62755 .50021 L
.64717 .50128 L
.6668 .50264 L
.68642 .50403 L
.70604 .50529 L
.72567 .50629 L
.74529 .50697 L
.76491 .50726 L
.78454 .50715 L
.80416 .50664 L
.82378 .50577 L
.84341 .50461 L
.86303 .49938 L
.88265 .50186 L
.90228 .50062 L
.9219 .49994 L
.94152 .50134 L
.94893 .50981 L
.94152 .51363 L
.9219 .52248 L
.90429 .52943 L
.90228 .53107 L
.88265 .53447 L
.86303 .53821 L
.84341 .54133 L
.82378 .54379 L
.80416 .54555 L
.78454 .54656 L
.76491 .54678 L
.74529 .54621 L
.72567 .54487 L
.70604 .54279 L
.68642 .54003 L
.6668 .53665 L
.64717 .5326 L
.63416 .52943 L
.62755 .52696 L
.60793 .51873 L
.58957 .50981 L
F
0 g
.60793 .50008 m
.62755 .50021 L
.64717 .50128 L
.6668 .50264 L
.68642 .50403 L
.70604 .50529 L
.72567 .50629 L
.74529 .50697 L
.76491 .50726 L
.78454 .50715 L
.80416 .50664 L
.82378 .50577 L
.84341 .50461 L
.86303 .49938 L
.88265 .50186 L
.90228 .50062 L
.9219 .49994 L
.94152 .50134 L
.94893 .50981 L
.94152 .51363 L
.9219 .52248 L
.90429 .52943 L
.90228 .53107 L
.88265 .53447 L
.86303 .53821 L
.84341 .54133 L
.82378 .54379 L
.80416 .54555 L
.78454 .54656 L
.76491 .54678 L
.74529 .54621 L
.72567 .54487 L
.70604 .54279 L
.68642 .54003 L
.6668 .53665 L
.64717 .5326 L
.63416 .52943 L
.62755 .52696 L
.60793 .51873 L
.58957 .50981 L
.60793 .50008 L
s
.3 g
.60793 .60561 m
.62755 .60528 L
.64717 .6047 L
.66218 .60793 L
.6668 .60842 L
.68642 .61036 L
.70604 .61197 L
.72567 .61318 L
.74529 .61396 L
.76491 .61429 L
.78454 .61416 L
.80416 .61358 L
.82378 .61255 L
.84341 .61111 L
.86303 .6093 L
.87531 .60793 L
.88265 .6069 L
.90228 .60576 L
.9219 .60508 L
.9388 .60793 L
.9219 .62462 L
.917 .62755 L
.90228 .63342 L
.88265 .63991 L
.86303 .64535 L
.85561 .64717 L
.84341 .65053 L
.82378 .65638 L
.80416 .65472 L
.78454 .65588 L
.76491 .65613 L
.74529 .65548 L
.72567 .65983 L
.70604 .65375 L
.68642 .64812 L
.68289 .64717 L
.6668 .64308 L
.64717 .6372 L
.62755 .63011 L
.62147 .62755 L
.60793 .61869 L
.59707 .60793 L
F
0 g
.60793 .60561 m
.62755 .60528 L
.64717 .6047 L
.66218 .60793 L
.6668 .60842 L
.68642 .61036 L
.70604 .61197 L
.72567 .61318 L
.74529 .61396 L
.76491 .61429 L
.78454 .61416 L
.80416 .61358 L
.82378 .61255 L
.84341 .61111 L
.86303 .6093 L
.87531 .60793 L
.88265 .6069 L
.90228 .60576 L
.9219 .60508 L
.9388 .60793 L
.9219 .62462 L
.917 .62755 L
.90228 .63342 L
.88265 .63991 L
.86303 .64535 L
.85561 .64717 L
.84341 .65053 L
.82378 .65638 L
.80416 .65472 L
.78454 .65588 L
.76491 .65613 L
.74529 .65548 L
.72567 .65983 L
.70604 .65375 L
.68642 .64812 L
.68289 .64717 L
.6668 .64308 L
.64717 .6372 L
.62755 .63011 L
.62147 .62755 L
.60793 .61869 L
.59707 .60793 L
.60793 .60561 L
s
.7 g
.62755 .66643 m
.63326 .6668 L
.64717 .66834 L
.6668 .67075 L
.68642 .67299 L
.70604 .67485 L
.72567 .67624 L
.74529 .67714 L
.76491 .67751 L
.78454 .67737 L
.80416 .6767 L
.82378 .67552 L
.84341 .67386 L
.86303 .67178 L
.88265 .6694 L
.90228 .66708 L
.91436 .68642 L
.90228 .69201 L
.88265 .69949 L
.86303 .70563 L
.8616 .70604 L
.84341 .71323 L
.82378 .71396 L
.80416 .71636 L
.78454 .71769 L
.76491 .71798 L
.74529 .71723 L
.72567 .71544 L
.70604 .71879 L
.68642 .70961 L
.67682 .70604 L
.6668 .70307 L
.64717 .69639 L
.62755 .68809 L
.62417 .68642 L
.6103 .6668 L
F
0 g
.62755 .66643 m
.63326 .6668 L
.64717 .66834 L
.6668 .67075 L
.68642 .67299 L
.70604 .67485 L
.72567 .67624 L
.74529 .67714 L
.76491 .67751 L
.78454 .67737 L
.80416 .6767 L
.82378 .67552 L
.84341 .67386 L
.86303 .67178 L
.88265 .6694 L
.90228 .66708 L
.91436 .68642 L
.90228 .69201 L
.88265 .69949 L
.86303 .70563 L
.8616 .70604 L
.84341 .71323 L
.82378 .71396 L
.80416 .71636 L
.78454 .71769 L
.76491 .71798 L
.74529 .71723 L
.72567 .71544 L
.70604 .71879 L
.68642 .70961 L
.67682 .70604 L
.6668 .70307 L
.64717 .69639 L
.62755 .68809 L
.62417 .68642 L
.6103 .6668 L
.62755 .66643 L
s
.7 g
.64717 .56023 m
.6668 .55959 L
.68642 .56001 L
.70604 .56067 L
.72567 .56129 L
.74529 .56173 L
.76491 .56193 L
.78454 .56185 L
.80416 .56151 L
.82378 .56096 L
.84341 .56029 L
.86303 .55971 L
.88265 .5597 L
.90228 .56261 L
.9052 .56868 L
.90228 .57022 L
.88265 .57841 L
.86303 .5848 L
.84996 .5883 L
.84341 .5895 L
.82378 .5924 L
.80416 .59437 L
.78454 .59546 L
.76491 .5957 L
.74529 .59508 L
.72567 .59361 L
.70604 .59124 L
.68851 .5883 L
.68642 .58778 L
.6668 .58216 L
.64717 .57512 L
.63319 .56868 L
F
0 g
.64717 .56023 m
.6668 .55959 L
.68642 .56001 L
.70604 .56067 L
.72567 .56129 L
.74529 .56173 L
.76491 .56193 L
.78454 .56185 L
.80416 .56151 L
.82378 .56096 L
.84341 .56029 L
.86303 .55971 L
.88265 .5597 L
.90228 .56261 L
.9052 .56868 L
.90228 .57022 L
.88265 .57841 L
.86303 .5848 L
.84996 .5883 L
.84341 .5895 L
.82378 .5924 L
.80416 .59437 L
.78454 .59546 L
.76491 .5957 L
.74529 .59508 L
.72567 .59361 L
.70604 .59124 L
.68851 .5883 L
.68642 .58778 L
.6668 .58216 L
.64717 .57512 L
.63319 .56868 L
.64717 .56023 L
s
.6 g
.6668 .47006 m
.68642 .46826 L
.70604 .4679 L
.72567 .46794 L
.74529 .46806 L
.76491 .46813 L
.78454 .4681 L
.80416 .46799 L
.82378 .46789 L
.84341 .46802 L
.86303 .46893 L
.87444 .47057 L
.86303 .47977 L
.84341 .48642 L
.82626 .49019 L
.82378 .49044 L
.80416 .49208 L
.78454 .49298 L
.76491 .49318 L
.74529 .49267 L
.72567 .49145 L
.71196 .49019 L
.70604 .489 L
.68642 .48388 L
.6668 .47516 L
.66437 .47057 L
F
0 g
.6668 .47006 m
.68642 .46826 L
.70604 .4679 L
.72567 .46794 L
.74529 .46806 L
.76491 .46813 L
.78454 .4681 L
.80416 .46799 L
.82378 .46789 L
.84341 .46802 L
.86303 .46893 L
.87444 .47057 L
.86303 .47977 L
.84341 .48642 L
.82626 .49019 L
.82378 .49044 L
.80416 .49208 L
.78454 .49298 L
.76491 .49318 L
.74529 .49267 L
.72567 .49145 L
.71196 .49019 L
.70604 .489 L
.68642 .48388 L
.6668 .47516 L
.66437 .47057 L
.6668 .47006 L
s
.2 g
.6668 .62512 m
.68642 .62118 L
.70604 .62087 L
.72567 .62108 L
.74529 .62133 L
.76491 .62146 L
.78454 .62141 L
.80416 .6212 L
.82378 .62094 L
.84341 .62092 L
.86303 .62219 L
.87302 .62755 L
.86303 .63246 L
.84341 .63904 L
.82378 .64366 L
.80416 .64676 L
.80059 .64717 L
.78454 .64827 L
.76491 .64858 L
.74529 .64778 L
.73599 .64717 L
.72567 .64558 L
.70604 .64182 L
.68642 .63645 L
.6668 .62827 L
.66564 .62755 L
F
0 g
.6668 .62512 m
.68642 .62118 L
.70604 .62087 L
.72567 .62108 L
.74529 .62133 L
.76491 .62146 L
.78454 .62141 L
.80416 .6212 L
.82378 .62094 L
.84341 .62092 L
.86303 .62219 L
.87302 .62755 L
.86303 .63246 L
.84341 .63904 L
.82378 .64366 L
.80416 .64676 L
.80059 .64717 L
.78454 .64827 L
.76491 .64858 L
.74529 .64778 L
.73599 .64717 L
.72567 .64558 L
.70604 .64182 L
.68642 .63645 L
.6668 .62827 L
.66564 .62755 L
.6668 .62512 L
s
.3 g
.72567 .52404 m
.74529 .52262 L
.76491 .52225 L
.78454 .52238 L
.80416 .5232 L
.8236 .52943 L
.80416 .53253 L
.78454 .53416 L
.76491 .5345 L
.74529 .5336 L
.72567 .53137 L
.71445 .52943 L
F
0 g
.72567 .52404 m
.74529 .52262 L
.76491 .52225 L
.78454 .52238 L
.80416 .5232 L
.8236 .52943 L
.80416 .53253 L
.78454 .53416 L
.76491 .5345 L
.74529 .5336 L
.72567 .53137 L
.71445 .52943 L
.72567 .52404 L
s
.7 g
.9219 .66625 m
.92808 .6668 L
.9219 .68127 L
.90518 .6668 L
F
0 g
.9219 .66625 m
.92808 .6668 L
.9219 .68127 L
.90518 .6668 L
.9219 .66625 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00?Oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0dooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kS?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0hooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8b
onk^kS?ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08_ooool003gooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0=_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0<oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg03?ooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL08_ooool003Gooooo1_l0
0003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400[ooooo`Ko0000
1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100<oooool01Ol@413o
oooooooooooooooo410@03[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@03Cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@02;ooooo000o
ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000fooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000cooooo`05o`000?ooooooooooooooool0
0000>_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000=Oooool00onH
V9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000008_ooool0043ooooo00?oMgMgofIV
I_ooool00_ooool01Ol0003ooooooooooooooooo000003Kooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000003?ooooo00Go0000ooooooooooooooooo`00000jooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`03ogMgMomVIVKooooo00;o
oooo00Go0000ooooooooooooooooo`00000Rooooo`00@Oooool01Ol0003ooooooooooooooooo410@
00?ooooo00?o410@ooooooooool0=?ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@4100<oooool01Ol@413ooooooooooooooooo410@03[ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@03Oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo023ooooo000mooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg03Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg03?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0jooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0cooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02;ooooo000mooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^03Cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^03?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`03oeEEEOmVIVKo000000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0cooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02;ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo000Joooooooo0000C_l00001ooooo`00
6_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0?Ooo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool08ooo
ool1o`00007ooooo0008ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKo
oooo00?o0000ooooooooool0oooooom:ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooom:ooooo`7o
00000Oooool000Go00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41001_ooool00ol0003oooooooooo`3ooooood[ooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?ooooooB?ooool3o`00007o
oooo000:ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo0008ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Oooooooogmo
Od3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Ooo
ooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000oooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`003ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000?ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000oooooo00Go0000oooooooooooooooo
o`000006ooooo`?o00001?ooooooogmoOd3oOgmo1?ooool3o`00007ooooo000?ooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool000oooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`003oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000?ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo0008
ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000:ooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`002_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41001_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000[ooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo0ol00004oooooooo
Ogmo@?moOgl4ooooo`?o00000Oooool000[ooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000:ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool000Sooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00Cooooof_moOgm1o`0002CoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00Coooooe_moOgl4o`00047oVIVI0_l0000RogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooomOoOgmo0_l00011oiVIV@03o`000?moOgooOgmo02;oOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CooooofOmoOgl2o`0003koVIVI00?o0000ogmoOomo
Ogl08omoOgl6ooooo`7o00000Oooool001[ooooo0_l00005ooooom_oOgmo0_l0000ioiVIV@?o0000
9_moOgl5ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool01?oooooMogmoO`?o0000<onI
VIT3o`0002WoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Coooooh?moOgl3
o`0002coVIVI1?l0000/ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
on?oOgmo1_l0000SoiVIV@?o0000<?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?oooooYogmoOb?o0000<omoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooooomo
OglGogmoO`Ko00008omoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooo2
ogmoOa?o0000?_moOgl3o`0000KoIVIV5ol0000<ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04oooool3oOgmo0_l0000CofIVIQ?o00009_moOgl5o`0001ooIVIV00?o0000ogmo
OomoOgl02_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonnogmoO`;o
0000:?mVIVHVo`0002GoIVIV00?o0000ogmoOomoOgl02OmoOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?oooonmogmoO`;o0000M?mVIVH2o`0000[oOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00Cooooo_omoOgl2o`00073oIVIV0_l0000<ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04oooool7oOgmo0_l0001[ofIVIP?o00003_moOgl6
ooooo`7o00000Oooool001[ooooo0_l00005oooool?oOgmo0_l0001WofIVIP;o00004OmoOgl5oooo
o`;o00000Oooool001[ooooo00?o0000ooooooooool01?ooooo5ogmoO`?o00009_mVIVHIo`0002?o
IVIV0_l0000CogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooolSoOgmo
0_l0000NofIVIPKo00006Om<C4`3o`0001goIVIV0ol0000EogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04oooool[oOgmo1?l0000HofIVIP?o00008?m<C4`3o`0001[oIVIV00?o
0000ogmoOomoOgl05_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooo>
ogmoO`;o00006OmVIVH6o`0001OoC4a<0ol0000IofIVIPCo00006OmoOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooo@ogmoO`Go00006_mVIVHGo`0001GoIVIV1ol0000Mogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooook3oOgmo4Ol0000DogmoO`Ko
0000>_mVIVH6o`0001CoOgmo4Ol00005ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?oooon`ogmoO`03o`000?nIVIWoVIVI00koVIVI1ol0000CogmoO`Oo0000;?mVIVH7o`0001GoOgmo
1Ol0000@oiVIV@Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooook3oOgmo00?o
0000oiVIVOnIVIT05OnIVIT6o`0001CoOgmo1_l0000PofIVIPKo00006_moOgl2o`0001GoVIVI1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo[omoOgl00ol0003oVIVIoiVIV@0L
oiVIV@Oo00004omoOglPo`0001?oOgmo2?l00003ogmoO`;o00005onIVIT6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?oooon_ogmoO`?o00008onIVIT=o`0003?oOgmo1_l00008oiVI
V@?o00006OnIVIT6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonbogmoO`03
o`000?nIVIWoVIVI02goVIVI3Ol0000IogmoO`go0000:_nIVIT6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooncogmoO`;o0000>_nIVITIo`0003KoVIVI0_l00005ooooo`7o0000
0Oooool001[ooooo0_l00005oooookGoOgmo00?o0000oiVIVOnIVIT07?nIVIT7o`00063oVIVI0ol0
00000omoOgooooooooooo`03ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool01?oooonf
ogmoO`;o00005onIVIT5o`0000Oo/k>cBol0000CoiVIV@;o00001?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?oooonhogmoO`;o00004onIVIT2o`0005Ko/k>c00?o0000oiVI
VOnIVIT04?nIVIT00ol0003oOgmoogmoO`04ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04oooook[oOgmo00?o0000oiVIVOnIVIT03onIVIT00ol0003o/k>cok>c/`1Gok>c/`03
o`000?nIVIWoVIVI00koVIVI00?o0000ogmoOomoOgl01OmoOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?oooonkogmoO`;o00003_nIVIT2o`0005Oo/k>c0ol0000=oiVIV@?o0000
2?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonmogmoO`Co00003?nI
VIT3o`00057o/k>c0ol0000<oiVIV@Co00002omoOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?oooonYogmoO`Go00004omoOgl5o`0000[oVIVI0ol0001<ok>c/`;o00003?nIVIT3
o`0000ooOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooZ?moOgl00ol0
003oIVIVofIVIP03ofIVIPKo00004_moOgl3o`0000[oVIVI0ol00017ok>c/`;o00002onIVIT3o`00
00ooOgmo1?l00005ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonWogmoO`03
o`000?mVIVKoIVIV00[oIVIV1ol0000>ogmoO`Co00002OnIVIT4o`00043o/k>c0ol0000:oiVIV@?o
00003OmoOgl5o`0000?oIVIV1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
Y_moOgl00ol0003oIVIVofIVIP0BofIVIPGo00003OmoOgl3o`0000[oVIVI0ol0000iok>c/`Co0000
2OnIVIT4o`0000goOgmo0ol00008ofIVIPKooooo0Ol00001ooooo`001oooool5o`0000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo00CoooooYOmoOgl2o`0001WoIVIV
0ol0000=ogmoO`?o00002_nIVIT5o`0002co/k>c2?l0000:oiVIV@?o00002omoOgl6o`0000_oIVIV
1_ooool1o`00007ooooo0007ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?oooonWogmoO`03o`000?mVIVKoIVIV01Wo
IVIV1Ol00005ogmoO`Go000000CoOgmoo`000?l0003o00003?nIVIT6o`00023o/k>c1_l0000?oiVI
V@?o00002?moOgl6o`00017oIVIV1_ooool1o`00007ooooo0008ooooo`03oiRHV?lQ8B7ok^k^00Co
oooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00CoooooZ?moOgl00ol0
003oIVIVofIVIP0MofIVIPGo00001OmVIVH3o`000003ogmoOol0003o000000;o00003_nIVITPo`00
01;oVIVI0ol00005ogmoO`Ko00005omVIVH6ooooo`7o00000Oooool000Wooooo00?oV9RHob4Q8Oo^
k^h00oooool01Ol0003ooooooooooooooooo000000Kooooo0ol00004ooooojWoOgmo0_l0000ZofIV
IP;o00000omoOgl3o`0000CoVIVI1ol0000VoiVIV@co00000omoOgl5o`0001goIVIV1?ooool3o`00
007ooooo000:ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000006oooo
o`03o`000?oooooooooo00CoooooZomoOgl00ol0003oIVIVofIVIP0YofIVIP?o00000omoOgl4o`00
00OoOgmo3Ol0000<oiVIV@go00003?moOgl3o`0002;oIVIV1_ooool1o`00007ooooo000;ooooo`05
o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`04ooooo`03o`000?oooooooooo
00Cooooo[?moOgl00ol0003oIVIVofIVIP0NofIVIPGo00002?mVIVH3o`0001SoOgmo3?l0000=ogmo
O`co00009OmVIVH6ooooo`7o00000Oooool000Oooooo00Go0000okZj^_ooooooV9RHoa0@4003oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`04ooooojgoOgmo00?o0000
ofIVI_mVIVH04OmVIVH<o`0000GoC4a<0ol00008ofIVIQOo00003OmoOgl=o`0000ooIVIV4_l0000@
ofIVIPKooooo0Ol00001ooooo`001oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo00Cooooo[_moOgl4o`0000goIVIV0_l0
000Doda<C0go00004_mVIVH=o`0001CoIVIV2?l0000Boda<C0?o00003OmVIVH6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?oooonbogmoO`03o`000?mVIVKoIVIV00coIVIV00?o0000
oda<C?m<C4`07_m<C4`=o`0001;oIVIV5?l0000Joda<C003o`000?mVIVKoIVIV00goIVIV1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo/omoOgl2o`0000goIVIV00?o0000oda<
C?m<C4`0:_m<C4`Bo`0002goC4a<00?o0000ofIVI_mVIVH03OmVIVH2o`0000Gooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04oooookGoOgmo00?o0000ofIVI_mVIVH02omVIVH2o`0006So
C4a<00?o0000ofIVI_mVIVH02omVIVH3o`000003ogmoOooooooooooo00Cooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04oooookKoOgmo0ol0000<ofIVIP;o00004om<C4a0o`0001;oC4a<
00?o0000ofIVI_mVIVH02_mVIVH2o`0000CoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00Cooooo^OmoOgl3o`0000_oIVIV00?o0000oda<C?m<C4`03Om<C4`3o`00043o<c<c00?o
0000oda<C?m<C4`03_m<C4`00ol0003oIVIVofIVIP09ofIVIP;o00001_moOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?oooonPogmoO`co00004?moOgl3o`0000WoIVIV0_l0000<
oda<C0?o0000@Olc<c<2o`0000goC4a<0_l0000:ofIVIP;o00002?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?oooonPogmoO`03o`000?nIVIWoVIVI00WoVIVI0ol0000@ogmo
O`03o`000?mVIVKoIVIV00SoIVIV0ol0000<oda<C0;o0000?_lc<c<00ol0003oC4a<oda<C00:oda<
C0?o00002_mVIVH2o`0000[oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OoooonQogmoO`03
o`000?nIVIWoVIVI00_oVIVI1?l0000=ogmoO`;o00002omVIVH3o`0000_oC4a<0_l0000ioc<c<`?o
00002_m<C4`3o`0000[oIVIV0ol00004ogmoO`Ko00000_moOgl5ooooo`;o00000Oooool001[ooooo
00?o0000ooooooooool01?oooonRogmoO`03o`000?nIVIWoVIVI00koVIVI0ol0000<ogmoO`03o`00
0?mVIVKoIVIV00_oIVIV0ol0000:oda<C0?o0000<olc<c<3o`0000[oC4a<0ol0000:ofIVIP?o0000
1_moOgl00ol0003oVIVIoiVIV@04oiVIV@?o00001Oooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CoooooX_moOgl00ol0003oVIVIoiVIV@0AoiVIV@Go00002?moOgl5o`0000_oIVIV0ol0
000:oda<C0?o0000:olc<c<5o`0000[oC4a<0ol0000:ofIVIP?o00001omoOgl2o`0000WoVIVI1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooXomoOgl00ol0003oVIVIoiVIV@0E
oiVIV@Go00002?moOgl5o`0000WoIVIV0ol0000:oda<C0Go00008?lc<c<6o`0000coC4a<0ol0000:
ofIVIP?o00002OmoOgl00ol0003oVIVIoiVIV@09oiVIV@Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04oooooj?oOgmo00?o0000oiVIVOnIVIT06_nIVIT3o`0000[oOgmo0ol00009ofIV
IP?o00003?m<C4`5o`0001Oo<c<c1?l0000?oda<C0?o00002_mVIVH3o`0000[oOgmo0_l0000<oiVI
V@Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooojCoOgmo0_l0000MoiVIV@Go
00002?moOgl5o`0000OoIVIV1?l0000=oda<C1Oo00003om<C4`4o`0000KoIVIV1ol00009ogmoO`Co
00003_nIVIT6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonVogmoO`;o0000
8?nIVIT;o`0000;oOgmo1Ol00006ofIVIP?o0000;Om<C4`3o`0000OoIVIV0ol0000;ogmoO`Go0000
4_nIVIT6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonXogmoO`03o`000?nI
VIWoVIVI02SoVIVI0ol00004ogmoO`?o00001_mVIVH4o`0000SoC4a<1_l00006oda<C0ko00001?m<
C4`3o`0000GoIVIV1Ol00003ogmoO`_o00005onIVIT6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?oooonYogmoO`;o0000:onIVIT4o`0000?oOgmo1Ol00005ofIVIP?o00000_m<C4`3
o`0000KoIVIV1_l0000>ofIVIPCo00000omVIVH5o`0000GoOgmo0ol0000RoiVIV@Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04oooooj_oOgmo00?o0000oiVIVOnIVIT0;?nIVIT3o`00
00GoOgmo1Ol00003ofIVIP;o00005OmVIVH8o`0000CoIVIV0ol00005ogmoO`Go00009OnIVIT6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon/ogmoO`03o`000?nIVIWoVIVI02ko
VIVI1Ol00005ogmoO`?o00001?mVIVHCo`0000SoOgmo1?l000000omoOgoo0000o`000005o`0002[o
VIVI1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo[OmoOgl00ol0003oVIVI
oiVIV@0DoiVIV@_o00004onIVIT=o`0001WoOgmo1_l0000DoiVIV@co00004OnIVIT6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?oooon^ogmoO`03o`000?nIVIWoVIVI01?oVIVI00?o
0000ok>c/onc/k<02?nc/k<<o`0001CoVIVI6Ol0000CoiVIV@Oo00000onc/k<00ol0003oVIVIo`00
0005ok>c/`03o`000?nIVIWoVIVI00ooVIVI1_ooool1o`00007ooooo000Jooooo`;o00001Ooooon_
ogmoO`03o`000?nIVIWoVIVI01?oVIVI00?o0000ok>c/onc/k<04onc/k<7o`0002coVIVI3Ol0000;
ok>c/`03o`000?nIVIWo000000?o/k>c00?o0000oiVIVOnIVIT04?nIVIT5ooooo`;o00000Oooool0
01[ooooo00?o0000ooooooooool01?oooon`ogmoO`?o00004_nIVIT00ol0003o/k>cok>c/`0Jok>c
/`go00004_nIVIT=o`0001So/k>c00Co0000oiVIVOnIVIWo00000_nc/k<00ol0003oVIVIoiVIV@0?
oiVIV@;o00001Oooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo/omoOgl3o`00
013oVIVI00?o0000ok>c/onc/k<09_nc/k<Bo`0002Ko/k>c00Ko0000oiVIVOnIVIWo0000ok>c/ol0
000>oiVIV@?o000000?oOgmoooooooooool01?ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00Cooooo]_moOgl2o`0000ooVIVI00?o0000ok>c/onc/k<0G_nc/k<01?l0003oVIVIoiVIVOl0
000=oiVIV@;o00001?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonh
ogmoO`03o`000?nIVIWoVIVI00coVIVI00?o0000ok>c/onc/k<0G_nc/k<00ol0003oVIVIoiVIV@0=
oiVIV@03o`000?moOgooOgmo00CoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00Cooooo^OmoOgl3o`0000coVIVI1?l0001Kok>c/`?o00003OnIVIT2o`0000KoOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00Cooooo_?moOgl3o`0000goVIVI0_l0001Fok>c/`?o
00003_nIVIT2o`0000SoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
_omoOgl00ol0003oVIVIoiVIV@0<oiVIV@;o0000DOnc/k<3o`0000ooVIVI0_l0000:ogmoO`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooool3oOgmo0_l0000>oiVIV@?o0000C?nc
/k<2o`0000ooVIVI0ol0000<ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
oooool;oOgmo00?o0000oiVIVOnIVIT03_nIVIT3o`0004Oo/k>c0_l0000>oiVIV@?o00003omoOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonYogmoO`[o00004?moOgl5o`00
00koVIVI1?l00010ok>c/`?o00003OnIVIT3o`0001;oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CoooooZ?moOgl00ol0003oIVIVofIVIP08ofIVIP?o00004_moOgl5o`0000go
VIVI0ol0000iok>c/`Co00003OnIVIT3o`0001?oOgmo0ol00005ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?oooonXogmoO`03o`000?mVIVKoIVIV00_oIVIV0ol0000DogmoO`?o0000
3OnIVIT2o`0003Go/k>c0_l0000=oiVIV@Co00004omoOgl3o`0000;oIVIV1_ooool1o`00007ooooo
000Jooooo`;o00001OoooonYogmoO`03o`000?mVIVKoIVIV00goIVIV0ol0000DogmoO`?o00003?nI
VIT3o`00033o/k>c0_l0000<oiVIV@?o00005?moOgl3o`0000GoIVIV1Oooool2o`00007ooooo000J
ooooo`03o`000?oooooooooo00CoooooZ_moOgl00ol0003oIVIVofIVIP0?ofIVIPCo00004omoOgl3
o`0000coVIVI0_l00003ok>c/`So00006Onc/k<:o`0000_oVIVI0ol0000DogmoO`?o00002?mVIVH6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon[ogmoO`03o`000?mVIVKoIVIV
01;oIVIV0ol0000CogmoO`Co00002_nIVIT3o`0000SoVIVI6Ol0000BoiVIV@?o00004_moOgl5o`00
00_oIVIV1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo[?moOgl00ol0003o
IVIVofIVIP0DofIVIPGo00004_moOgl3o`0003SoVIVI1Ol0000@ogmoO`Go00004?mVIVH6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?oooon]ogmoO`03o`000?mVIVKoIVIV01SoIVIV
0ol0000BogmoO`Go0000;OnIVIT6o`0001;oOgmo0ol0000EofIVIPKooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooojkoOgmo0_l0000KofIVIPCo00004omoOgl]o`0001CoOgmo1?l0
000HofIVIPKooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooook3oOgmo0_l0000M
ofIVIPKo0000BomoOgl3o`0001coIVIV1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00Cooooo/_moOgl00ol0003oIVIVofIVIP0PofIVIPGo0000@OmoOgl5o`0001koIVIV0_l00005oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooncogmoO`;o00009OmVIVH3o`0003So
Ogmo1_l0000RofIVIP03o`000?moOgoooooo00Gooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04oooookGoOgmo00?o0000ofIVI_mVIVH09OmVIVH5o`0000GoOgmo2?l0000OogmoO`Oo0000
9_mVIVH2o`0000;oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo]_mo
Ogl3o`0002WoIVIV1Ol00008ofIVIPKo00003?moOgl=o`0002coIVIV00?o0000ogmoOomoOgl00_mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooniogmoO`03o`000?mVIVKo
IVIV03WoIVIV3?l0000fofIVIP?o00001OmoOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?oooonjogmoO`03o`000?mVIVKoIVIV07WoIVIV00?o0000ogmoOomoOgl01_moOgl6oooo
o`7o00000Oooool001[ooooo0_l00005oooook_oOgmo00?o0000ofIVI_mVIVH0M_mVIVH2o`0000Wo
Ogmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo_?moOgl00ol0003oIVIV
ofIVIP1dofIVIP03o`000?moOgooOgmo00WoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00Cooooo_OmoOgl4o`00073oIVIV0_l0000<ogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04oooool7oOgmo1?l0001YofIVIP?o00003_moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooo5ogmoO`03o`000?mVIVKoIVIV06CoIVIV0_l0000Aogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooolKoOgmo0ol0001QofIVIP;o
00004omoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooo9ogmoO`?o0000
G?mVIVH2o`0001GoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Coooooc?mo
Ogl00ol0003oIVIVofIVIP1GofIVIP;o00005omoOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooo=ogmoO`;o0000DomVIVH4o`0001WoOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CooooocomoOgl00ol0003oIVIVofIVIP1;ofIVIPGo00007OmoOgl6oooo
o`7o00000Oooool000Oooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01_ooool00ol0003oooooooooo`04ooooom3oOgmo1Ol00015ofIVIP?o00008_moOgl6
ooooo`7o00000Oooool000Oooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01_ooool00ol0003oooooooooo`04ooooomGoOgmo1ol0000jofIVIPCo00009Omo
Ogl6ooooo`7o00000Oooool000_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oo
oooooooo00Cooooo00?o0000ooooooooool01?oooooLogmoO`Ko0000<OmVIVH3o`0002WoOgmo1_oo
ool1o`00007ooooo000:ooooo`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00
0006ooooo`?o00001?oooooRogmoO`Ko00009_mVIVH5o`0002coOgmo1?ooool3o`00007ooooo0009
ooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oo
oooooooo00Coooooj?moOgl7o`0001WoIVIV1_l0000aogmoO`Kooooo0Ol00001ooooo`002_ooool0
0onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003ooooooooo
o`04ooooonooOgmo6Ol0000gogmoO`Kooooo0Ol00001ooooo`001oooool01Ol@413oV9RHoooooonj
^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`001oooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo0_l00005ooooooooOgmo@?moOgl5oooo
o`;o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo0_l00005ooooooooOgmo@?mo
Ogl5ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool000Wooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP06oooo
o`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`04oooo
ooooOgmo@?moOgl6ooooo`7o00000Oooool000Oooooo1Ol00003ooooo`05oa0@4?oooooooooooooo
ool@41001_ooool3o`0000CooooooomoOgm0ogmoO`Cooooo0ol00001ooooo`001oooool01?m4A4Co
gMgMooooool00004ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3o
oooood[ooooo0Ol00001ooooo`001oooool01?oMgMgoEEEEooooool00004ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`3ooooood[ooooo0Ol00001ooooo`002?ooool0
0omgMgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003ooooooooo
o`3ooooood[ooooo0Ol00001ooooo`002?ooool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooood[ooooo0Ol00001ooooo`002Oooool0
0omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003ooooooooo
o`0Sooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0?Oooool00ol0003ooooooooo
o`0mooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool08oooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool1o`00007ooooo000Joooo
oooo0000C_l00001ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-30.1723, -14.304, 0.195672, \
0.195672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0192308 0.211538 0.0192308 [
[.11538 -0.0125 -9 -9 ]
[.11538 -0.0125 9 0 ]
[.30769 -0.0125 -9 -9 ]
[.30769 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69231 -0.0125 -6 -9 ]
[.69231 -0.0125 6 0 ]
[.88462 -0.0125 -6 -9 ]
[.88462 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -18 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .21154 -6 -4.5 ]
[-0.0125 .21154 0 4.5 ]
[-0.0125 .40385 -12 -4.5 ]
[-0.0125 .40385 0 4.5 ]
[-0.0125 .59615 -12 -4.5 ]
[-0.0125 .59615 0 4.5 ]
[-0.0125 .78846 -12 -4.5 ]
[-0.0125 .78846 0 4.5 ]
[-0.0125 .98077 -12 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11538 0 m
.11538 .00625 L
s
[(-20)] .11538 -0.0125 0 1 Mshowa
.30769 0 m
.30769 .00625 L
s
[(-10)] .30769 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69231 0 m
.69231 .00625 L
s
[(10)] .69231 -0.0125 0 1 Mshowa
.88462 0 m
.88462 .00625 L
s
[(20)] .88462 -0.0125 0 1 Mshowa
.125 Mabswid
.15385 0 m
.15385 .00375 L
s
.19231 0 m
.19231 .00375 L
s
.23077 0 m
.23077 .00375 L
s
.26923 0 m
.26923 .00375 L
s
.34615 0 m
.34615 .00375 L
s
.38462 0 m
.38462 .00375 L
s
.42308 0 m
.42308 .00375 L
s
.46154 0 m
.46154 .00375 L
s
.53846 0 m
.53846 .00375 L
s
.57692 0 m
.57692 .00375 L
s
.61538 0 m
.61538 .00375 L
s
.65385 0 m
.65385 .00375 L
s
.73077 0 m
.73077 .00375 L
s
.76923 0 m
.76923 .00375 L
s
.80769 0 m
.80769 .00375 L
s
.84615 0 m
.84615 .00375 L
s
.07692 0 m
.07692 .00375 L
s
.03846 0 m
.03846 .00375 L
s
.92308 0 m
.92308 .00375 L
s
.96154 0 m
.96154 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(-10)] -0.0125 .01923 1 0 Mshowa
0 .21154 m
.00625 .21154 L
s
[(0)] -0.0125 .21154 1 0 Mshowa
0 .40385 m
.00625 .40385 L
s
[(10)] -0.0125 .40385 1 0 Mshowa
0 .59615 m
.00625 .59615 L
s
[(20)] -0.0125 .59615 1 0 Mshowa
0 .78846 m
.00625 .78846 L
s
[(30)] -0.0125 .78846 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(40)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .05769 m
.00375 .05769 L
s
0 .09615 m
.00375 .09615 L
s
0 .13462 m
.00375 .13462 L
s
0 .17308 m
.00375 .17308 L
s
0 .25 m
.00375 .25 L
s
0 .28846 m
.00375 .28846 L
s
0 .32692 m
.00375 .32692 L
s
0 .36538 m
.00375 .36538 L
s
0 .44231 m
.00375 .44231 L
s
0 .48077 m
.00375 .48077 L
s
0 .51923 m
.00375 .51923 L
s
0 .55769 m
.00375 .55769 L
s
0 .63462 m
.00375 .63462 L
s
0 .67308 m
.00375 .67308 L
s
0 .71154 m
.00375 .71154 L
s
0 .75 m
.00375 .75 L
s
0 .82692 m
.00375 .82692 L
s
0 .86538 m
.00375 .86538 L
s
0 .90385 m
.00375 .90385 L
s
0 .94231 m
.00375 .94231 L
s
.25 Mabswid
0 0 m
0 1 L
s
.11538 .99375 m
.11538 1 L
s
.30769 .99375 m
.30769 1 L
s
.5 .99375 m
.5 1 L
s
.69231 .99375 m
.69231 1 L
s
.88462 .99375 m
.88462 1 L
s
.125 Mabswid
.15385 .99625 m
.15385 1 L
s
.19231 .99625 m
.19231 1 L
s
.23077 .99625 m
.23077 1 L
s
.26923 .99625 m
.26923 1 L
s
.34615 .99625 m
.34615 1 L
s
.38462 .99625 m
.38462 1 L
s
.42308 .99625 m
.42308 1 L
s
.46154 .99625 m
.46154 1 L
s
.53846 .99625 m
.53846 1 L
s
.57692 .99625 m
.57692 1 L
s
.61538 .99625 m
.61538 1 L
s
.65385 .99625 m
.65385 1 L
s
.73077 .99625 m
.73077 1 L
s
.76923 .99625 m
.76923 1 L
s
.80769 .99625 m
.80769 1 L
s
.84615 .99625 m
.84615 1 L
s
.07692 .99625 m
.07692 1 L
s
.03846 .99625 m
.03846 1 L
s
.92308 .99625 m
.92308 1 L
s
.96154 .99625 m
.96154 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .21154 m
1 .21154 L
s
.99375 .40385 m
1 .40385 L
s
.99375 .59615 m
1 .59615 L
s
.99375 .78846 m
1 .78846 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .05769 m
1 .05769 L
s
.99625 .09615 m
1 .09615 L
s
.99625 .13462 m
1 .13462 L
s
.99625 .17308 m
1 .17308 L
s
.99625 .25 m
1 .25 L
s
.99625 .28846 m
1 .28846 L
s
.99625 .32692 m
1 .32692 L
s
.99625 .36538 m
1 .36538 L
s
.99625 .44231 m
1 .44231 L
s
.99625 .48077 m
1 .48077 L
s
.99625 .51923 m
1 .51923 L
s
.99625 .55769 m
1 .55769 L
s
.99625 .63462 m
1 .63462 L
s
.99625 .67308 m
1 .67308 L
s
.99625 .71154 m
1 .71154 L
s
.99625 .75 m
1 .75 L
s
.99625 .82692 m
1 .82692 L
s
.99625 .86538 m
1 .86538 L
s
.99625 .90385 m
1 .90385 L
s
.99625 .94231 m
1 .94231 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.6 g
.98077 .71489 m
.96115 .72208 L
.9528 .72567 L
.94152 .72993 L
.9219 .73877 L
.90228 .74392 L
.89748 .74529 L
.88265 .74812 L
.86303 .75298 L
.84341 .75714 L
.82378 .76017 L
.80416 .76201 L
.78454 .76277 L
.76491 .76257 L
.74529 .76137 L
.72567 .75904 L
.70604 .75552 L
.68642 .75097 L
.6668 .74628 L
.66022 .74529 L
.64717 .74366 L
.62755 .73502 L
.60793 .72666 L
.60489 .72567 L
.5883 .71838 L
.56868 .70889 L
.56406 .70604 L
.54906 .69741 L
.53193 .68642 L
.52943 .68442 L
.50981 .66721 L
.50942 .6668 L
.50981 .65712 L
.52943 .65683 L
.54906 .66097 L
.56868 .66559 L
.57278 .6668 L
.5883 .67167 L
.60793 .67702 L
.62755 .68009 L
.64717 .68621 L
.64818 .68642 L
.6668 .69052 L
.68642 .6941 L
.70604 .69143 L
.72567 .69616 L
.74529 .69879 L
.76491 .70009 L
.78454 .70031 L
.80416 .69948 L
.82378 .69745 L
.84341 .69377 L
.86303 .69538 L
.88265 .69211 L
.90228 .6881 L
.90928 .68642 L
.9219 .68314 L
.94152 .67377 L
.96115 .67399 L
.98077 .66831 L
F
0 g
.98077 .71489 m
.96115 .72208 L
.9528 .72567 L
.94152 .72993 L
.9219 .73877 L
.90228 .74392 L
.89748 .74529 L
.88265 .74812 L
.86303 .75298 L
.84341 .75714 L
.82378 .76017 L
.80416 .76201 L
.78454 .76277 L
.76491 .76257 L
.74529 .76137 L
.72567 .75904 L
.70604 .75552 L
.68642 .75097 L
.6668 .74628 L
.66022 .74529 L
.64717 .74366 L
.62755 .73502 L
.60793 .72666 L
.60489 .72567 L
.5883 .71838 L
.56868 .70889 L
.56406 .70604 L
.54906 .69741 L
.53193 .68642 L
.52943 .68442 L
.50981 .66721 L
.50942 .6668 L
.50981 .65712 L
.52943 .65683 L
.54906 .66097 L
.56868 .66559 L
.57278 .6668 L
.5883 .67167 L
.60793 .67702 L
.62755 .68009 L
.64717 .68621 L
.64818 .68642 L
.6668 .69052 L
.68642 .6941 L
.70604 .69143 L
.72567 .69616 L
.74529 .69879 L
.76491 .70009 L
.78454 .70031 L
.80416 .69948 L
Mistroke
.82378 .69745 L
.84341 .69377 L
.86303 .69538 L
.88265 .69211 L
.90228 .6881 L
.90928 .68642 L
.9219 .68314 L
.94152 .67377 L
.96115 .67399 L
.98077 .66831 L
Mfstroke
.4 g
.98077 .65196 m
.96115 .6588 L
.94152 .66609 L
.93953 .6668 L
.9219 .67251 L
.90228 .68105 L
.88265 .68255 L
.86303 .6864 L
.8629 .68642 L
.84341 .68783 L
.82378 .69029 L
.80416 .69207 L
.78454 .69289 L
.76491 .69267 L
.74529 .69143 L
.72567 .6893 L
.70604 .68687 L
.69475 .68642 L
.68642 .68487 L
.6668 .68072 L
.64717 .67728 L
.62755 .6694 L
.61821 .6668 L
.60793 .6631 L
.5883 .65553 L
.56932 .64717 L
.56868 .64685 L
.54906 .63643 L
.53386 .62755 L
.52943 .6239 L
.51354 .60793 L
.52943 .60155 L
.54906 .60378 L
.56868 .60775 L
.57022 .60793 L
.5883 .61232 L
.60793 .61669 L
.62755 .61965 L
.64717 .62698 L
.66393 .62755 L
.6668 .62808 L
.68642 .6312 L
.70604 .63369 L
.72567 .6304 L
.74529 .63381 L
.76491 .6354 L
.78454 .63566 L
.80416 .63466 L
.82378 .63213 L
.84341 .63455 L
.86303 .63232 L
.88265 .62947 L
.89375 .62755 L
.90228 .62606 L
.9219 .62306 L
.94152 .61255 L
.96115 .6142 L
.98077 .60964 L
F
0 g
.98077 .65196 m
.96115 .6588 L
.94152 .66609 L
.93953 .6668 L
.9219 .67251 L
.90228 .68105 L
.88265 .68255 L
.86303 .6864 L
.8629 .68642 L
.84341 .68783 L
.82378 .69029 L
.80416 .69207 L
.78454 .69289 L
.76491 .69267 L
.74529 .69143 L
.72567 .6893 L
.70604 .68687 L
.69475 .68642 L
.68642 .68487 L
.6668 .68072 L
.64717 .67728 L
.62755 .6694 L
.61821 .6668 L
.60793 .6631 L
.5883 .65553 L
.56932 .64717 L
.56868 .64685 L
.54906 .63643 L
.53386 .62755 L
.52943 .6239 L
.51354 .60793 L
.52943 .60155 L
.54906 .60378 L
.56868 .60775 L
.57022 .60793 L
.5883 .61232 L
.60793 .61669 L
.62755 .61965 L
.64717 .62698 L
.66393 .62755 L
.6668 .62808 L
.68642 .6312 L
.70604 .63369 L
.72567 .6304 L
.74529 .63381 L
.76491 .6354 L
.78454 .63566 L
.80416 .63466 L
.82378 .63213 L
.84341 .63455 L
Mistroke
.86303 .63232 L
.88265 .62947 L
.89375 .62755 L
.90228 .62606 L
.9219 .62306 L
.94152 .61255 L
.96115 .6142 L
.98077 .60964 L
Mfstroke
.6 g
.98077 .59142 m
.96115 .59924 L
.94152 .60647 L
.93738 .60793 L
.9219 .61457 L
.90228 .61732 L
.88265 .6215 L
.86303 .62506 L
.84656 .62755 L
.84341 .62795 L
.82378 .62889 L
.80416 .63045 L
.78454 .63122 L
.76491 .63102 L
.74529 .62987 L
.72567 .62816 L
.71105 .62755 L
.70604 .62683 L
.68642 .62364 L
.6668 .61982 L
.64717 .62278 L
.62755 .61052 L
.62035 .60793 L
.60793 .60348 L
.5883 .59606 L
.56987 .5883 L
.56868 .5876 L
.54906 .57497 L
.54042 .56868 L
.54906 .55968 L
.56868 .5597 L
.5883 .56197 L
.60793 .56657 L
.62755 .56833 L
.62969 .56868 L
.64717 .57159 L
.6668 .5744 L
.68642 .57679 L
.70604 .57812 L
.72567 .58315 L
.74529 .58703 L
.76491 .58204 L
.78454 .58215 L
.80416 .58175 L
.82378 .5849 L
.84341 .58044 L
.86303 .57385 L
.88265 .57546 L
.90228 .57282 L
.9219 .56975 L
.92725 .56868 L
.94152 .56636 L
.96115 .55853 L
.98077 .56052 L
F
0 g
.98077 .59142 m
.96115 .59924 L
.94152 .60647 L
.93738 .60793 L
.9219 .61457 L
.90228 .61732 L
.88265 .6215 L
.86303 .62506 L
.84656 .62755 L
.84341 .62795 L
.82378 .62889 L
.80416 .63045 L
.78454 .63122 L
.76491 .63102 L
.74529 .62987 L
.72567 .62816 L
.71105 .62755 L
.70604 .62683 L
.68642 .62364 L
.6668 .61982 L
.64717 .62278 L
.62755 .61052 L
.62035 .60793 L
.60793 .60348 L
.5883 .59606 L
.56987 .5883 L
.56868 .5876 L
.54906 .57497 L
.54042 .56868 L
.54906 .55968 L
.56868 .5597 L
.5883 .56197 L
.60793 .56657 L
.62755 .56833 L
.62969 .56868 L
.64717 .57159 L
.6668 .5744 L
.68642 .57679 L
.70604 .57812 L
.72567 .58315 L
.74529 .58703 L
.76491 .58204 L
.78454 .58215 L
.80416 .58175 L
.82378 .5849 L
.84341 .58044 L
.86303 .57385 L
.88265 .57546 L
.90228 .57282 L
.9219 .56975 L
Mistroke
.92725 .56868 L
.94152 .56636 L
.96115 .55853 L
.98077 .56052 L
Mfstroke
.4 g
.98077 .76746 m
.96115 .77885 L
.95023 .78454 L
.94152 .78869 L
.9219 .79697 L
.90228 .80388 L
.90142 .80416 L
.88265 .81253 L
.86303 .81487 L
.84341 .81856 L
.82378 .82123 L
.80416 .82292 L
.78454 .82367 L
.76491 .82347 L
.74529 .82233 L
.72567 .82023 L
.70604 .81714 L
.68642 .81298 L
.6668 .80844 L
.65618 .80416 L
.64717 .80111 L
.62755 .7937 L
.60793 .78473 L
.60768 .78454 L
.5883 .77436 L
.57137 .76491 L
.56868 .76152 L
.55303 .74529 L
.56868 .744 L
.57555 .74529 L
.5883 .74894 L
.60793 .75484 L
.62755 .76025 L
.64666 .76491 L
.64717 .76506 L
.6668 .77017 L
.68642 .7745 L
.70604 .77794 L
.72567 .78051 L
.74529 .78225 L
.76491 .78321 L
.78454 .78337 L
.80416 .78275 L
.82378 .78134 L
.84341 .77912 L
.86303 .77605 L
.88265 .7721 L
.90228 .76729 L
.90971 .76491 L
.9219 .76233 L
.94152 .75719 L
.96115 .75145 L
.98077 .74562 L
F
0 g
.98077 .76746 m
.96115 .77885 L
.95023 .78454 L
.94152 .78869 L
.9219 .79697 L
.90228 .80388 L
.90142 .80416 L
.88265 .81253 L
.86303 .81487 L
.84341 .81856 L
.82378 .82123 L
.80416 .82292 L
.78454 .82367 L
.76491 .82347 L
.74529 .82233 L
.72567 .82023 L
.70604 .81714 L
.68642 .81298 L
.6668 .80844 L
.65618 .80416 L
.64717 .80111 L
.62755 .7937 L
.60793 .78473 L
.60768 .78454 L
.5883 .77436 L
.57137 .76491 L
.56868 .76152 L
.55303 .74529 L
.56868 .744 L
.57555 .74529 L
.5883 .74894 L
.60793 .75484 L
.62755 .76025 L
.64666 .76491 L
.64717 .76506 L
.6668 .77017 L
.68642 .7745 L
.70604 .77794 L
.72567 .78051 L
.74529 .78225 L
.76491 .78321 L
.78454 .78337 L
.80416 .78275 L
.82378 .78134 L
.84341 .77912 L
.86303 .77605 L
.88265 .7721 L
.90228 .76729 L
.90971 .76491 L
.9219 .76233 L
Mistroke
.94152 .75719 L
.96115 .75145 L
.98077 .74562 L
Mfstroke
.4 g
.5883 .52355 m
.60793 .52256 L
.62755 .52366 L
.64717 .52542 L
.6668 .5274 L
.68642 .52939 L
.68694 .52943 L
.70604 .53102 L
.72567 .53227 L
.74529 .53313 L
.76491 .53361 L
.78454 .53369 L
.80416 .53338 L
.82378 .53268 L
.84341 .53159 L
.86303 .53012 L
.87061 .52943 L
.88265 .52825 L
.90228 .52624 L
.9219 .52435 L
.94152 .5229 L
.96115 .52265 L
.97832 .52943 L
.96115 .54044 L
.94459 .54906 L
.94152 .55007 L
.9219 .55582 L
.90228 .56088 L
.88265 .5654 L
.86635 .56868 L
.86303 .56917 L
.84341 .57347 L
.82378 .5786 L
.80416 .57469 L
.78454 .5752 L
.76491 .57506 L
.74529 .58158 L
.72567 .57641 L
.70604 .57149 L
.69131 .56868 L
.68642 .56774 L
.6668 .56357 L
.64717 .55882 L
.62755 .55352 L
.61309 .54906 L
.60793 .54655 L
.5883 .53559 L
.57912 .52943 L
F
0 g
.5883 .52355 m
.60793 .52256 L
.62755 .52366 L
.64717 .52542 L
.6668 .5274 L
.68642 .52939 L
.68694 .52943 L
.70604 .53102 L
.72567 .53227 L
.74529 .53313 L
.76491 .53361 L
.78454 .53369 L
.80416 .53338 L
.82378 .53268 L
.84341 .53159 L
.86303 .53012 L
.87061 .52943 L
.88265 .52825 L
.90228 .52624 L
.9219 .52435 L
.94152 .5229 L
.96115 .52265 L
.97832 .52943 L
.96115 .54044 L
.94459 .54906 L
.94152 .55007 L
.9219 .55582 L
.90228 .56088 L
.88265 .5654 L
.86635 .56868 L
.86303 .56917 L
.84341 .57347 L
.82378 .5786 L
.80416 .57469 L
.78454 .5752 L
.76491 .57506 L
.74529 .58158 L
.72567 .57641 L
.70604 .57149 L
.69131 .56868 L
.68642 .56774 L
.6668 .56357 L
.64717 .55882 L
.62755 .55352 L
.61309 .54906 L
.60793 .54655 L
.5883 .53559 L
.57912 .52943 L
.5883 .52355 L
s
.3 g
.62755 .63404 m
.64717 .6354 L
.6668 .63728 L
.68642 .63914 L
.70604 .6408 L
.72567 .63711 L
.74529 .64047 L
.76491 .64186 L
.78454 .64208 L
.80416 .64122 L
.82378 .63888 L
.84341 .64141 L
.86303 .63987 L
.88265 .63808 L
.90228 .63617 L
.9219 .63449 L
.94152 .63421 L
.94702 .64717 L
.94152 .6503 L
.9219 .65966 L
.9042 .6668 L
.90228 .66795 L
.88265 .67316 L
.86303 .67771 L
.84341 .68129 L
.82378 .68393 L
.80416 .68565 L
.78454 .6864 L
.76491 .6862 L
.74529 .68504 L
.72567 .68293 L
.70604 .6799 L
.68642 .67593 L
.6668 .67092 L
.65347 .6668 L
.64717 .66436 L
.62755 .65597 L
.61065 .64717 L
F
0 g
.62755 .63404 m
.64717 .6354 L
.6668 .63728 L
.68642 .63914 L
.70604 .6408 L
.72567 .63711 L
.74529 .64047 L
.76491 .64186 L
.78454 .64208 L
.80416 .64122 L
.82378 .63888 L
.84341 .64141 L
.86303 .63987 L
.88265 .63808 L
.90228 .63617 L
.9219 .63449 L
.94152 .63421 L
.94702 .64717 L
.94152 .6503 L
.9219 .65966 L
.9042 .6668 L
.90228 .66795 L
.88265 .67316 L
.86303 .67771 L
.84341 .68129 L
.82378 .68393 L
.80416 .68565 L
.78454 .6864 L
.76491 .6862 L
.74529 .68504 L
.72567 .68293 L
.70604 .6799 L
.68642 .67593 L
.6668 .67092 L
.65347 .6668 L
.64717 .66436 L
.62755 .65597 L
.61065 .64717 L
.62755 .63404 L
s
.7 g
.62755 .70596 m
.64717 .70247 L
.6668 .70374 L
.68642 .70551 L
.69291 .70604 L
.70604 .7075 L
.72567 .70924 L
.74529 .71048 L
.76491 .71116 L
.78454 .71128 L
.80416 .71083 L
.82378 .70983 L
.84341 .70829 L
.86303 .7063 L
.86366 .70604 L
.88265 .70447 L
.90228 .70288 L
.9219 .70272 L
.93308 .70604 L
.9219 .71348 L
.90228 .72402 L
.89873 .72567 L
.88265 .73137 L
.86303 .73688 L
.84341 .74113 L
.82378 .74426 L
.81685 .74529 L
.80416 .74654 L
.78454 .74776 L
.76491 .74742 L
.74529 .74562 L
.74235 .74529 L
.72567 .74308 L
.70604 .73949 L
.68642 .73474 L
.6668 .7286 L
.65895 .72567 L
.64717 .71999 L
.62755 .70614 L
.62749 .70604 L
F
0 g
.62755 .70596 m
.64717 .70247 L
.6668 .70374 L
.68642 .70551 L
.69291 .70604 L
.70604 .7075 L
.72567 .70924 L
.74529 .71048 L
.76491 .71116 L
.78454 .71128 L
.80416 .71083 L
.82378 .70983 L
.84341 .70829 L
.86303 .7063 L
.86366 .70604 L
.88265 .70447 L
.90228 .70288 L
.9219 .70272 L
.93308 .70604 L
.9219 .71348 L
.90228 .72402 L
.89873 .72567 L
.88265 .73137 L
.86303 .73688 L
.84341 .74113 L
.82378 .74426 L
.81685 .74529 L
.80416 .74654 L
.78454 .74776 L
.76491 .74742 L
.74529 .74562 L
.74235 .74529 L
.72567 .74308 L
.70604 .73949 L
.68642 .73474 L
.6668 .7286 L
.65895 .72567 L
.64717 .71999 L
.62755 .70614 L
.62749 .70604 L
.62755 .70596 L
s
.7 g
.64717 .58482 m
.6668 .58498 L
.68642 .58587 L
.70604 .58611 L
.72567 .58791 L
.73494 .5883 L
.74529 .58867 L
.76491 .58913 L
.78454 .58921 L
.80416 .58891 L
.82263 .5883 L
.82378 .58826 L
.84341 .58707 L
.86303 .58389 L
.88265 .58531 L
.90228 .58473 L
.9219 .58578 L
.93046 .5883 L
.9219 .59618 L
.90228 .6066 L
.89921 .60793 L
.88265 .61254 L
.86303 .61693 L
.84341 .6204 L
.82378 .62297 L
.80416 .62465 L
.78454 .62539 L
.76491 .62519 L
.74529 .62406 L
.72567 .622 L
.70604 .61905 L
.68642 .61521 L
.6668 .61036 L
.65848 .60793 L
.64717 .6027 L
.62776 .5883 L
F
0 g
.64717 .58482 m
.6668 .58498 L
.68642 .58587 L
.70604 .58611 L
.72567 .58791 L
.73494 .5883 L
.74529 .58867 L
.76491 .58913 L
.78454 .58921 L
.80416 .58891 L
.82263 .5883 L
.82378 .58826 L
.84341 .58707 L
.86303 .58389 L
.88265 .58531 L
.90228 .58473 L
.9219 .58578 L
.93046 .5883 L
.9219 .59618 L
.90228 .6066 L
.89921 .60793 L
.88265 .61254 L
.86303 .61693 L
.84341 .6204 L
.82378 .62297 L
.80416 .62465 L
.78454 .62539 L
.76491 .62519 L
.74529 .62406 L
.72567 .622 L
.70604 .61905 L
.68642 .61521 L
.6668 .61036 L
.65848 .60793 L
.64717 .6027 L
.62776 .5883 L
.64717 .58482 L
s
.6 g
.6668 .49018 m
.68478 .49019 L
.68642 .49022 L
.70604 .49075 L
.72567 .49133 L
.74529 .49178 L
.76491 .49204 L
.78454 .49209 L
.80416 .49192 L
.82378 .49154 L
.84341 .491 L
.86303 .49042 L
.87296 .49019 L
.88265 .4901 L
.89095 .49019 L
.88765 .50981 L
.88265 .51085 L
.86303 .51437 L
.84341 .51715 L
.82378 .51923 L
.80416 .5206 L
.78454 .52122 L
.76491 .52105 L
.74529 .52012 L
.72567 .51844 L
.70604 .51606 L
.68642 .51299 L
.67004 .50981 L
.6668 .50855 L
.66658 .49019 L
F
0 g
.6668 .49018 m
.68478 .49019 L
.68642 .49022 L
.70604 .49075 L
.72567 .49133 L
.74529 .49178 L
.76491 .49204 L
.78454 .49209 L
.80416 .49192 L
.82378 .49154 L
.84341 .491 L
.86303 .49042 L
.87296 .49019 L
.88265 .4901 L
.89095 .49019 L
.88765 .50981 L
.88265 .51085 L
.86303 .51437 L
.84341 .51715 L
.82378 .51923 L
.80416 .5206 L
.78454 .52122 L
.76491 .52105 L
.74529 .52012 L
.72567 .51844 L
.70604 .51606 L
.68642 .51299 L
.67004 .50981 L
.6668 .50855 L
.66658 .49019 L
.6668 .49018 L
s
.3 g
.70604 .54599 m
.72567 .54509 L
.74529 .54485 L
.76491 .54481 L
.78454 .54481 L
.80416 .54482 L
.82378 .54495 L
.84341 .54547 L
.86303 .54755 L
.86787 .54906 L
.86303 .55205 L
.84341 .55859 L
.82378 .56263 L
.80416 .56506 L
.78454 .5661 L
.76491 .56583 L
.74529 .56422 L
.72567 .56115 L
.70604 .55629 L
.68978 .54906 L
F
0 g
.70604 .54599 m
.72567 .54509 L
.74529 .54485 L
.76491 .54481 L
.78454 .54481 L
.80416 .54482 L
.82378 .54495 L
.84341 .54547 L
.86303 .54755 L
.86787 .54906 L
.86303 .55205 L
.84341 .55859 L
.82378 .56263 L
.80416 .56506 L
.78454 .5661 L
.76491 .56583 L
.74529 .56422 L
.72567 .56115 L
.70604 .55629 L
.68978 .54906 L
.70604 .54599 L
s
.2 g
.70604 .65078 m
.72567 .651 L
.74529 .6514 L
.76491 .65168 L
.78454 .65173 L
.80416 .65154 L
.82378 .65117 L
.84341 .65082 L
.86134 .6668 L
.84341 .67118 L
.82378 .67451 L
.80416 .6766 L
.78454 .67751 L
.76491 .67726 L
.74529 .67587 L
.72567 .67327 L
.70604 .66934 L
.69628 .6668 L
F
0 g
.70604 .65078 m
.72567 .651 L
.74529 .6514 L
.76491 .65168 L
.78454 .65173 L
.80416 .65154 L
.82378 .65117 L
.84341 .65082 L
.86134 .6668 L
.84341 .67118 L
.82378 .67451 L
.80416 .6766 L
.78454 .67751 L
.76491 .67726 L
.74529 .67587 L
.72567 .67327 L
.70604 .66934 L
.69628 .6668 L
.70604 .65078 L
s
.8 g
.72567 .59965 m
.74529 .59887 L
.76491 .59866 L
.78454 .59863 L
.80416 .59874 L
.82378 .5992 L
.84341 .60101 L
.84922 .60793 L
.84341 .60943 L
.82378 .61322 L
.80416 .61548 L
.78454 .61646 L
.76491 .6162 L
.74529 .6147 L
.72567 .61184 L
.70847 .60793 L
F
0 g
.72567 .59965 m
.74529 .59887 L
.76491 .59866 L
.78454 .59863 L
.80416 .59874 L
.82378 .5992 L
.84341 .60101 L
.84922 .60793 L
.84341 .60943 L
.82378 .61322 L
.80416 .61548 L
.78454 .61646 L
.76491 .6162 L
.74529 .6147 L
.72567 .61184 L
.70847 .60793 L
.72567 .59965 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00?Oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0dooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kS?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0hooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8b
onk^kS?ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08_ooool003gooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0=_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0<oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg03?ooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL08_ooool003Gooooo1_l0
0003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400[ooooo`Ko0000
1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100<oooool01Ol@413o
oooooooooooooooo410@03[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@03Cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@02;ooooo000o
ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000fooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000cooooo`05o`000?ooooooooooooooool0
0000>_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000=Oooool00onH
V9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000008_ooool0043ooooo00?oMgMgofIV
I_ooool00_ooool01Ol0003ooooooooooooooooo000003Kooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000003?ooooo00Go0000ooooooooooooooooo`00000jooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`03ogMgMomVIVKooooo00;o
oooo00Go0000ooooooooooooooooo`00000Rooooo`00@Oooool01Ol0003ooooooooooooooooo410@
00?ooooo00?o410@ooooooooool0=?ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@4100<oooool01Ol@413ooooooooooooooooo410@03[ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@03Oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo023ooooo000mooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg03Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg03?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0jooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0cooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02;ooooo000mooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^03Cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^03?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`03oeEEEOmVIVKo000000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0cooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02;ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo000Joooooooo0000C_l00001ooooo`00
6_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0?Ooo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool08ooo
ool1o`00007ooooo0008ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKo
oooo00?o0000ooooooooool0oooooom:ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooom:ooooo`7o
00000Oooool000Go00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41001_ooool00ol0003oooooooooo`3ooooood[ooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?ooooooB?ooool3o`00007o
oooo000:ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo0008ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Oooooooogmo
Od3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Ooo
ooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000oooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`003ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000?ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000oooooo00Go0000oooooooooooooooo
o`000006ooooo`?o00001?ooooooogmoOd3oOgmo1?ooool3o`00007ooooo000?ooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool000oooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`003oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000?ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo0008
ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000:ooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`002_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41001_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000[ooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo0ol00004oooooooo
Ogmo@?moOgl4ooooo`?o00000Oooool000[ooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000:ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool000Sooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CoooooeomoOgl;o`0003SoOgmo2?l0000MogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooomOoOgmo00?o0000oiVIVOnIVIT02?nIVITho`0000OoVIVI00?o0000ogmoOomo
Ogl06omoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooGogmoO`03o`00
0?nIVIWoVIVI04OoVIVI00?o0000ogmoOomoOgl06omoOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?oooooGogmoO`03o`000?nIVIWoVIVI04OoVIVI00?o0000ogmoOomoOgl06omo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooGogmoO`03o`000?nIVIWo
VIVI04KoVIVI00?o0000ogmoOomoOgl07?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?oooooGogmoO`03o`000?nIVIWoVIVI04KoVIVI00?o0000ogmoOomoOgl07?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooGogmoO`03o`000?nIVIWoVIVI04Ko
VIVI00?o0000ogmoOomoOgl07?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?oooooGogmoO`Go0000?onIVIT6o`0001koOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00Cooooog?moOgl6o`0003?oVIVI1_l0000TogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooon;oOgmo1_l0000VoiVIV@Oo0000:_moOgl6ooooo`7o00000Oooool0
01[ooooo0_l00005ooooonSoOgmo3Ol0000CoiVIV@Ko0000<OmoOgl5ooooo`;o00000Oooool001[o
oooo00?o0000ooooooooool01?ooooo0ogmoO`So0000;OmoOglCo`0002OoOgmo3?l00004ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooookcoOgmo1?l00008ofIVIPgo0000
COmoOgl=o`0000coIVIV0ol000000omoOgooooooooooo`04ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?oooonjogmoO`;o00006OmVIVH=o`0003OoOgmo2Ol0000KofIVIP;o00001_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo^omoOgl00ol0003oIVIVofIVIP0T
ofIVIPgo00007omoOgl;o`0002?oIVIV00?o0000ogmoOomoOgl01_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00Cooooo_?moOgl00ol0003oIVIVofIVIP0`ofIVIQoo0000;?mVIVH2o`00
00?oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo_OmoOgl2o`0007[o
IVIV00?o0000ogmoOomoOgl00omoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?oooonoogmoO`;o0000M_mVIVH2o`0000KoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00Cooooo`OmoOgl2o`0007;oIVIV0_l00008ogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04oooool?oOgmo0_l0000LofIVISSo00006omVIVH00ol0003oOgmoogmoO`08
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooolGoOgmo1?l0000EofIV
IP?o0000>?m<C4`00ol0003oIVIVofIVIP0DofIVIPCo00002omoOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?ooooo9ogmoO`Co00005?mVIVH3o`0003;oC4a<0ol0000DofIVIP?o
00003omoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooo=ogmoO`?o0000
5?mVIVH3o`0002coC4a<0ol0000DofIVIP?o00004_moOgl6ooooo`7o00000Oooool001[ooooo0_l0
0005ooooom3oOgmo0ol0000DofIVIP?o00009_m<C4`3o`0001CoIVIV0ol0000=ogmoO`Ko00000_mo
Ogl5ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool01?oooon`ogmoOa3o00004omoOgl3
o`0001CoIVIV1Ol0000Noda<C0?o00004_mVIVH5o`0000koOgmo0_l00006oiVIV@?o00001Oooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo[omoOgl00ol0003oVIVIoiVIV@0>oiVI
V@?o00004omoOgl5o`0001CoIVIV1_l0000<oda<C0co00004?mVIVH5o`00017oOgmo0_l0000:oiVI
V@Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooojkoOgmo00?o0000oiVIVOnI
VIT04_nIVIT8o`00013oOgmo1?l0000FofIVIPco00006OmVIVH3o`0001?oOgmo0ol0000<oiVIV@Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooojgoOgmo0_l0000KoiVIV@_o0000
2_moOgl8o`0002koIVIV1Ol0000>ogmoO`So00003onIVIT6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?oooon_ogmoO`03o`000?nIVIWoVIVI02?oVIVI1_l0000<ogmoO`?o00009_mV
IVH5o`000003ogmoOol0003o000000Co00001_moOgl6o`0001OoVIVI1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00Cooooo/?moOgl2o`0002WoVIVI1ol00008ogmoO`?o00002OmVIVHC
o`0000CoIVIV0ol00003ogmoO`?o00001_nIVIT6o`0001goVIVI1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00Cooooo/_moOgl00ol0003oVIVIoiVIV@0]oiVIV@Ko00001OmoOgl3o`00
00?oIVIV0ol0000CogmoO`Co00000omoOgl3o`0002coVIVI1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00Cooooo/omoOgl2o`0003?oVIVI1Ol00003ogmoO`?o00000omoOglCo`0000Co
Ogmo0ol0000_oiVIV@Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooookGoOgmo
00?o0000oiVIVOnIVIT05OnIVITKo`0000GoVIVI0ol00003ogmoO`?o00004onIVIT4o`0000SoVIVI
6Ol0000AoiVIV@Kooooo0Ol00001ooooo`001oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP06ooooo`03o`000?oooooooooo00Cooooo]_moOgl2o`0001;oVIVI0ol0000Kok>c/bgo0000
6Onc/k<00ol0003oVIVIoiVIV@0>oiVIV@Kooooo0Ol00001ooooo`001oooool01OnHV9So8B4Qonk^
k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00Co
oooo^?moOgl3o`00017oVIVI00?o0000ok>c/onc/k<0G_nc/k<00ol0003oVIVIoiVIV@0>oiVIV@;o
00001Oooool1o`00007ooooo0008ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooo
oooooa0@4006ooooo`03o`000?oooooooooo00Cooooo^omoOgl2o`00013oVIVI00?o0000ok>c/onc
/k<0G?nc/k<00ol0003oVIVIoiVIV@0<oiVIV@?o000000?oOgmoooooooooool01?ooool1o`00007o
oooo0009ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000006ooooo`?o
00001?oooonmogmoO`?o00003_nIVIT00ol0003o/k>cok>c/`0Sok>c/aGo00008Onc/k<2o`0000go
VIVI0_l00004ogmoO`Cooooo0ol00001ooooo`002_ooool00omgMgOoIVIVooooo`02ooooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooooooo`04ooooojSoOgmo1_l0000BogmoO`?o
00003?nIVIT00ol0003o/k>cok>c/`0Gok>c/`_o00005Oo<c<`9o`0001Ko/k>c0_l0000=oiVIV@;o
00001_moOgl6ooooo`7o00000Oooool000_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo00Cooooo00?o0000ooooooooool01?oooonVogmoO`;o00001_mVIVH6o`0000oo
Ogmo0_l0000;oiVIV@;o00005Onc/k<2o`0002Soc<c<00?o0000ok>c/onc/k<04_nc/k<2o`0000co
VIVI0ol00008ogmoO`Kooooo0Ol00001ooooo`001oooool01Ol0003o^[ZjoooooonHV9So410@00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00CoooooYOmoOgl00ol0
003oIVIVofIVIP0<ofIVIP?o00003_moOgl2o`0000_oVIVI0_l0000Bok>c/`03o`000?o<c<coc<c<
02Woc<c<00?o0000ok>c/onc/k<04?nc/k<00ol0003oVIVIoiVIV@0:oiVIV@;o00002omoOgl6oooo
o`7o00000Oooool000Oooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01_ooool00ol0003oooooooooo`04ooooojCoOgmo00?o0000ofIVI_mVIVH04?mVIVH4
o`0000coOgmo1Ol00008oiVIV@Ko00002onc/k<4o`0002Goc<c<1_l0000=ok>c/`Co00002onIVIT2
o`0000_oOgmo0ol00005ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonUogmo
O`03o`000?mVIVKoIVIV01?oIVIV1_l0000;ogmoO`03o`000?nIVIWoVIVI00_oVIVI0ol0000<ok>c
/`Ko00006Oo<c<`6o`0000oo/k>c1?l0000<oiVIV@?o000000?oOgmoo`000?l000000ol00004ogmo
O`?o00000_mVIVH6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonVogmoO`03
o`000?mVIVKoIVIV01SoIVIV1ol00005ogmoO`;o00003_nIVIT5o`0000go/k>c6Ol0000Bok>c/`?o
00002onIVIT5o`0000;oOgmo0_l00005ofIVIPCo00001OmVIVH6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?oooonWogmoO`03o`000?mVIVKoIVIV01koIVIV1?l00003ogmoO`03o`00
0?nIVIWoVIVI013oVIVI1_l0000]ok>c/`Go00002?nIVIT6o`0000KoOgmo00?o0000ofIVI_mVIVH0
3_mVIVH6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonXogmoO`03o`000?mV
IVKoIVIV027oIVIV0_l00002ogmoO`_o00003OnIVIT7o`0001oo/k>c1ol00006oiVIV@Oo00002_mo
Ogl2o`00017oIVIV1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooZOmoOgl0
0ol0003oIVIVofIVIP0RofIVIP;o00002omoOgl7o`0000goVIVI7ol00007oiVIV@Ko00003OmoOgl4
o`0001?oIVIV1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooZ_moOgl2o`00
02CoIVIV2ol00007ogmoO`go00007onIVIT7o`0000_oOgmo2?l0000GofIVIPKooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooojcoOgmo0_l0000]ofIVIPOo00001OmoOglWo`0000go
Ogmo1Ol0000OofIVIPKooooo0Ol00001ooooo`006_ooool2o`0000Gooooo[_moOgl2o`0001WoIVIV
1Ol0000DofIVIPGo00002?mVIVH6o`0000coOgmo6_l0000=ofIVIP_o00003?mVIVH5ooooo`;o0000
0Oooool001[ooooo00?o0000ooooooooool01?oooon`ogmoO`;o00005_mVIVH00ol0003oC4a<oda<
C003oda<C0go00003?mVIVH8o`0000KoIVIV3?l0000QofIVIPKo00002_m<C4`00ol0003oIVIVofIV
IP0:ofIVIPKooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooook;oOgmo0_l0000C
ofIVIP03o`000?m<C4coC4a<017oC4a<3?l00008oda<C0Ko00004omVIVH7o`0000KoIVIV3Ol0000A
oda<C003o`000?mVIVKoIVIV00WoIVIV1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00Cooooo]?moOgl2o`00013oIVIV00?o0000oda<C?m<C4`0;?m<C4`Co`0000OoC4a<1_l0000Noda<
C003o`000?mVIVKoIVIV00WoIVIV1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooo]_moOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<06_oC4a<00?o0000ofIVI_mV
IVH02OmVIVH6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonfogmoO`?o0000
2omVIVH2o`0006goC4a<0_l0000:ofIVIPKooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04oooookWoOgmo0ol0000:ofIVIP;o00007?m<C4`_o`0001koC4a<0_l0000:ofIVIP?o00001Ooo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo_?moOgl3o`0000WoIVIV0_l0000J
oda<C003o`000?lc<c?o<c<c02co<c<c00?o0000oda<C?m<C4`06?m<C4`3o`0000WoIVIV0ol00002
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooj?oOgmo2ol0000Aogmo
O`;o00002OmVIVH3o`0001KoC4a<00?o0000oc<c<olc<c<0;_lc<c<00ol0003oC4a<oda<C00Eoda<
C0;o00002OmVIVH3o`0000GoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
ooooXomoOgl00ol0003oVIVIoiVIV@08oiVIV@Go00003_moOgl2o`0000[oIVIV0ol0000Boda<C003
o`000?lc<c?o<c<c033o<c<c00?o0000oda<C?m<C4`04_m<C4`2o`0000WoIVIV0_l00008ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooj;oOgmo00?o0000oiVIVOnIVIT0
3_nIVIT3o`0000goOgmo0ol0000:ofIVIP;o00003om<C4`00ol0003o<c<coc<c<`0boc<c<`03o`00
0?m<C4coC4a<00koC4a<0ol00009ofIVIP;o00002_moOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?oooonRogmoO`;o00004_nIVIT4o`0000coOgmo1?l00008ofIVIPCo00002_m<
C4`3o`0003?o<c<c0_l0000;oda<C0Co00002OmVIVH3o`0000coOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CoooooY?moOgl00ol0003oVIVIoiVIV@0CoiVIV@?o00003OmoOgl2
o`0000[oIVIV1?l00009oda<C0Go0000:olc<c<3o`0000[oC4a<0ol0000:ofIVIP?o00003?moOgl4
o`0000Gooooo0Ol00001ooooo`006_ooool2o`0000GoooooYOmoOgl00ol0003oVIVIoiVIV@0EoiVI
V@?o00003?moOgl2o`0000coIVIV0ol0000;oda<C0Oo00007olc<c<5o`0000[oC4a<0ol0000:ofIV
IP?o00001?moOgl;o`0000?oVIVI1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
ooooY_moOgl00ol0003oVIVIoiVIV@0GoiVIV@?o00002omoOgl2o`0000goIVIV1Ol0000=oda<C0Ko
00003?lc<c<=o`0000coC4a<0ol0000;ofIVIP;o00001OmoOgl2o`0000koVIVI1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CoooooYomoOgl00ol0003oVIVIoiVIV@0IoiVIV@Go0000
2?moOgl5o`0000goIVIV1_l0000=oda<C0co00005?m<C4`5o`0000coIVIV0_l00006ogmoO`03o`00
0?nIVIWoVIVI00koVIVI1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooZ?mo
Ogl00ol0003oVIVIoiVIV@0MoiVIV@Go00002?moOgl6o`0000goIVIV1ol0000Ooda<C0Oo00002?mV
IVH9o`0000KoOgmo0_l0000AoiVIV@Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooojWoOgmo00?o0000oiVIVOnIVIT08OnIVIT3o`0000_oOgmo1Ol0000?ofIVIPKo00003?m<C4`=
o`0000coIVIV0ol0000<ogmoO`?o00004onIVIT6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?oooonZogmoO`;o00009?nIVIT5o`0000_oOgmo2?l0000=ofIVIPco00003OmVIVH<o`00
00WoOgmo1_l0000FoiVIV@Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooojco
Ogmo0_l0000WoiVIV@Ko00001_moOgl6o`000003ogmoOol0003o000000_o00004omVIVH6o`0001;o
Ogmo0ol0000LoiVIV@Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooojkoOgmo
0_l0000[oiVIV@Ko00001_nIVIT3o`0000_oOgmo4ol00006ogmoO`So00001OmoOgl5o`0001ooVIVI
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo/?moOgl2o`0003SoVIVI1Ol0
000IogmoO`Ko00002?nIVIT5o`0002CoVIVI1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00Cooooo/_moOgl2o`0003_oVIVI6Ol0000goiVIV@Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04oooookCoOgmo00?o0000oiVIVOnIVIT05_nIVIT>o`0004OoVIVI3?l0000AoiVI
V@Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooookGoOgmo00?o0000oiVIVOnI
VIT04_nIVIT3o`0000ko/k>c2?l0000boiVIV@go00003?nc/k<2o`0000ooVIVI1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00Cooooo]_moOgl2o`0001CoVIVI00?o0000ok>c/onc/k<0
5?nc/k<<o`0001WoVIVI3Ol0000Hok>c/`03o`000?nIVIWoVIVI00ooVIVI1_ooool1o`00007ooooo
000Jooooo`;o00001OoooonhogmoO`?o00004_nIVIT00ol0003o/k>cok>c/`0Ook>c/aWo00009?nc
/k<00ol0003oVIVIoiVIV@0@oiVIV@Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04
oooook_oOgmo0_l0000AoiVIV@03o`000?nc/k?o/k>c05Wo/k>c0_l0000AoiVIV@?o00001Oooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo_OmoOgl2o`00013oVIVI00?o0000ok>c
/onc/k<0E_nc/k<2o`00013oVIVI0ol00002ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04oooookooOgmo0_l0000?oiVIV@;o0000E?nc/k<2o`00013oVIVI0_l00005ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooool7oOgmo00?o0000oiVIVOnIVIT0
3_nIVIT2o`00057o/k>c00?o0000oiVIVOnIVIT03onIVIT00ol0003oOgmoogmoO`05ogmoO`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooool;oOgmo0ol0000?oiVIV@?o0000C?nc
/k<2o`0000ooVIVI0ol00008ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooolGoOgmo0ol0000?oiVIV@?o0000A_nc/k<3o`0000koVIVI0ol0000;ogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooolSoOgmo0_l0000@oiVIV@?o0000?_nc/k<5o`00
00koVIVI0ol0000>ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooool[o
Ogmo0_l0000AoiVIV@Go0000=?nc/k<5o`00017oVIVI0_l0000AogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooolcoOgmo0_l0000DoiVIV@Ko0000:onc/k<3o`0001CoVIVI
0_l0000CogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooolkoOgmo0_l0
000HoiVIV@Ko00008?nc/k<5o`0001CoVIVI0ol0000EogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04oooook7oOgmo2ol0000DogmoO`Oo00005onIVIT7o`0001;o/k>c1ol0000C
oiVIV@Ko00005_moOgl3o`0000Gooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
ok7oOgmo00?o0000ofIVI_mVIVH02?mVIVH4o`0001OoOgmo1?l0000JoiVIVA;o00005_nIVIT4o`00
01WoOgmo0ol00002ofIVIPKooooo0Ol00001ooooo`006_ooool2o`0000Gooooo/_moOgl00ol0003o
IVIVofIVIP0;ofIVIP?o00006?moOgl5o`0003[oVIVI0ol0000JogmoO`?o00001OmVIVH5ooooo`;o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooncogmoO`03o`000?mVIVKoIVIV00goIVIV
0ol0000JogmoO`?o0000<_nIVIT5o`0001[oOgmo0ol00008ofIVIPKooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04oooookCoOgmo00?o0000ofIVI_mVIVH03omVIVH3o`0001[oOgmo1Ol0
000VoiVIV@Oo00006omoOgl4o`0000_oIVIV1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00Cooooo]OmoOgl00ol0003oIVIVofIVIP0AofIVIPCo00006omoOgl7o`0001WoVIVI1_l0000O
ogmoO`?o00003omVIVH6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonfogmo
O`03o`000?mVIVKoIVIV01CoIVIV0ol0000OogmoOaWo00008OmoOgl4o`0001;oIVIV1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00Cooooo]omoOgl2o`0001OoIVIV1Ol0001>ogmoO`Ko
00005_mVIVH6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooniogmoO`;o0000
6_mVIVH5o`0004KoOgmo0ol0000KofIVIP;o00001Oooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00Cooooo^omoOgl2o`0001goIVIV0ol0000nogmoO`Go00006omVIVH3o`000003ogmoOooo
oooooooo00Cooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooookgoOgmo0_l0000N
ofIVIPGo0000<omoOgl6o`0001koIVIV0_l00004ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04oooookooOgmo0_l0000QofIVIPKo00009_moOgl7o`0002;oIVIV0_l00006ogmo
O`Kooooo0Ol00001ooooo`001oooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo00Cooooo`OmoOgl2o`0002GoIVIV3Ol0000C
ogmoO`Ko0000:?mVIVH00ol0003oOgmoogmoO`06ogmoO`Kooooo0Ol00001ooooo`001oooool01Ol@
413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oo
oooooooo00Cooooo`omoOgl2o`00033oIVIV4ol0000/ofIVIP;o00002OmoOgl6ooooo`7o00000Ooo
ool000_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o
0000ooooooooool01?ooooo5ogmoO`?o0000JomVIVH00ol0003oOgmoogmoO`09ogmoO`Kooooo0Ol0
0001ooooo`002_ooool00onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool000001_oo
ool3o`0000Cooooob?moOgl2o`0006KoIVIV0ol0000<ogmoO`Cooooo0ol00001ooooo`002Oooool0
0ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooooooo
o`04oooool[oOgmo0_l0001QofIVIP?o00003omoOgl6ooooo`7o00000Oooool000[ooooo00?o^[Zj
ob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool01?oo
ooo<ogmoO`;o0000G?mVIVH3o`0001;oOgmo1_ooool1o`00007ooooo0007ooooo`05oa0@4?nHV9So
oooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0
1?ooooo>ogmoO`;o0000F?mVIVH2o`0001GoOgmo1_ooool1o`00007ooooo0007ooooo`05ojVYZOl@
413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooooooo
ool01?ooooo@ogmoO`?o0000DomVIVH2o`0001OoOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CooooodomoOgl3o`0004koIVIV0_l0000IogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooomKoOgmo1?l00017ofIVIP?o00006omoOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?oooooJogmoO`?o0000@_mVIVH2o`0001koOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooogOmoOgl5o`0003CoIVIV2Ol0000Pogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooon;oOgmo1_l0000[ofIVIP?o
0000:OmoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooXogmoO`Oo0000
6OmVIVH;o`0002coOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Coooookomo
OglIo`0003OoOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo
1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Oooooooogmo
Od3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Ooo
ooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo0009ooooo`;o000000Wo410@ooooooooooooooooonk^k_lb<S;o0000oc8b
<_o^k^h01_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000[o
oooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000oooo
ooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo0007ooooo`Go00000oooool01Ol@413o
oooooooooooooooo410@00Kooooo0ol00004ooooooooOgmo@?moOgl4ooooo`?o00000Oooool000Oo
oooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000
ooooooooool0oooooom:ooooo`7o00000Oooool000Oooooo00CogMgMoeEEEOoooooo00001?ooool0
1Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0oooooom:ooooo`7o00000Ooo
ool000Sooooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooooooooooo410@00Kooooo00?o
0000ooooooooool0oooooom:ooooo`7o00000Oooool000Sooooo00?ok^k^odA4A?l000001?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooom:ooooo`7o00000Ooo
ool000Wooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03gooooo00?o
0000ooooooooool0?Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo02?ooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo0Ol00001
ooooo`006_ooooooo`0004ko00000Oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-30.1723, -14.304, 0.195672, \
0.195672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0192308 0.211538 0.0192308 [
[.11538 -0.0125 -9 -9 ]
[.11538 -0.0125 9 0 ]
[.30769 -0.0125 -9 -9 ]
[.30769 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69231 -0.0125 -6 -9 ]
[.69231 -0.0125 6 0 ]
[.88462 -0.0125 -6 -9 ]
[.88462 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -18 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .21154 -6 -4.5 ]
[-0.0125 .21154 0 4.5 ]
[-0.0125 .40385 -12 -4.5 ]
[-0.0125 .40385 0 4.5 ]
[-0.0125 .59615 -12 -4.5 ]
[-0.0125 .59615 0 4.5 ]
[-0.0125 .78846 -12 -4.5 ]
[-0.0125 .78846 0 4.5 ]
[-0.0125 .98077 -12 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11538 0 m
.11538 .00625 L
s
[(-20)] .11538 -0.0125 0 1 Mshowa
.30769 0 m
.30769 .00625 L
s
[(-10)] .30769 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69231 0 m
.69231 .00625 L
s
[(10)] .69231 -0.0125 0 1 Mshowa
.88462 0 m
.88462 .00625 L
s
[(20)] .88462 -0.0125 0 1 Mshowa
.125 Mabswid
.15385 0 m
.15385 .00375 L
s
.19231 0 m
.19231 .00375 L
s
.23077 0 m
.23077 .00375 L
s
.26923 0 m
.26923 .00375 L
s
.34615 0 m
.34615 .00375 L
s
.38462 0 m
.38462 .00375 L
s
.42308 0 m
.42308 .00375 L
s
.46154 0 m
.46154 .00375 L
s
.53846 0 m
.53846 .00375 L
s
.57692 0 m
.57692 .00375 L
s
.61538 0 m
.61538 .00375 L
s
.65385 0 m
.65385 .00375 L
s
.73077 0 m
.73077 .00375 L
s
.76923 0 m
.76923 .00375 L
s
.80769 0 m
.80769 .00375 L
s
.84615 0 m
.84615 .00375 L
s
.07692 0 m
.07692 .00375 L
s
.03846 0 m
.03846 .00375 L
s
.92308 0 m
.92308 .00375 L
s
.96154 0 m
.96154 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(-10)] -0.0125 .01923 1 0 Mshowa
0 .21154 m
.00625 .21154 L
s
[(0)] -0.0125 .21154 1 0 Mshowa
0 .40385 m
.00625 .40385 L
s
[(10)] -0.0125 .40385 1 0 Mshowa
0 .59615 m
.00625 .59615 L
s
[(20)] -0.0125 .59615 1 0 Mshowa
0 .78846 m
.00625 .78846 L
s
[(30)] -0.0125 .78846 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(40)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .05769 m
.00375 .05769 L
s
0 .09615 m
.00375 .09615 L
s
0 .13462 m
.00375 .13462 L
s
0 .17308 m
.00375 .17308 L
s
0 .25 m
.00375 .25 L
s
0 .28846 m
.00375 .28846 L
s
0 .32692 m
.00375 .32692 L
s
0 .36538 m
.00375 .36538 L
s
0 .44231 m
.00375 .44231 L
s
0 .48077 m
.00375 .48077 L
s
0 .51923 m
.00375 .51923 L
s
0 .55769 m
.00375 .55769 L
s
0 .63462 m
.00375 .63462 L
s
0 .67308 m
.00375 .67308 L
s
0 .71154 m
.00375 .71154 L
s
0 .75 m
.00375 .75 L
s
0 .82692 m
.00375 .82692 L
s
0 .86538 m
.00375 .86538 L
s
0 .90385 m
.00375 .90385 L
s
0 .94231 m
.00375 .94231 L
s
.25 Mabswid
0 0 m
0 1 L
s
.11538 .99375 m
.11538 1 L
s
.30769 .99375 m
.30769 1 L
s
.5 .99375 m
.5 1 L
s
.69231 .99375 m
.69231 1 L
s
.88462 .99375 m
.88462 1 L
s
.125 Mabswid
.15385 .99625 m
.15385 1 L
s
.19231 .99625 m
.19231 1 L
s
.23077 .99625 m
.23077 1 L
s
.26923 .99625 m
.26923 1 L
s
.34615 .99625 m
.34615 1 L
s
.38462 .99625 m
.38462 1 L
s
.42308 .99625 m
.42308 1 L
s
.46154 .99625 m
.46154 1 L
s
.53846 .99625 m
.53846 1 L
s
.57692 .99625 m
.57692 1 L
s
.61538 .99625 m
.61538 1 L
s
.65385 .99625 m
.65385 1 L
s
.73077 .99625 m
.73077 1 L
s
.76923 .99625 m
.76923 1 L
s
.80769 .99625 m
.80769 1 L
s
.84615 .99625 m
.84615 1 L
s
.07692 .99625 m
.07692 1 L
s
.03846 .99625 m
.03846 1 L
s
.92308 .99625 m
.92308 1 L
s
.96154 .99625 m
.96154 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .21154 m
1 .21154 L
s
.99375 .40385 m
1 .40385 L
s
.99375 .59615 m
1 .59615 L
s
.99375 .78846 m
1 .78846 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .05769 m
1 .05769 L
s
.99625 .09615 m
1 .09615 L
s
.99625 .13462 m
1 .13462 L
s
.99625 .17308 m
1 .17308 L
s
.99625 .25 m
1 .25 L
s
.99625 .28846 m
1 .28846 L
s
.99625 .32692 m
1 .32692 L
s
.99625 .36538 m
1 .36538 L
s
.99625 .44231 m
1 .44231 L
s
.99625 .48077 m
1 .48077 L
s
.99625 .51923 m
1 .51923 L
s
.99625 .55769 m
1 .55769 L
s
.99625 .63462 m
1 .63462 L
s
.99625 .67308 m
1 .67308 L
s
.99625 .71154 m
1 .71154 L
s
.99625 .75 m
1 .75 L
s
.99625 .82692 m
1 .82692 L
s
.99625 .86538 m
1 .86538 L
s
.99625 .90385 m
1 .90385 L
s
.99625 .94231 m
1 .94231 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.6 g
.98077 .74971 m
.96115 .76291 L
.9448 .76491 L
.94152 .76586 L
.9219 .77295 L
.90228 .77998 L
.88265 .78451 L
.88079 .78454 L
.86303 .78717 L
.84341 .79037 L
.82378 .79282 L
.80416 .79424 L
.78454 .79457 L
.76491 .7938 L
.74529 .79196 L
.72567 .78915 L
.70604 .78586 L
.69611 .78454 L
.68642 .78332 L
.6668 .7773 L
.64717 .76998 L
.63211 .76491 L
.62755 .76317 L
.60793 .757 L
.5883 .74559 L
.58769 .74529 L
.56868 .73524 L
.55262 .72567 L
.54906 .72325 L
.52943 .70929 L
.52532 .70604 L
.51339 .68642 L
.52943 .6854 L
.53562 .68642 L
.54906 .6899 L
.56868 .69548 L
.5883 .69568 L
.60777 .70604 L
.60793 .70628 L
.62755 .71196 L
.64717 .71691 L
.6668 .71916 L
.68642 .72468 L
.69125 .72567 L
.70604 .72824 L
.72567 .73098 L
.74529 .73296 L
.76491 .73419 L
.78454 .7347 L
.80416 .73448 L
.82378 .73354 L
.84341 .73186 L
.86303 .72943 L
.88265 .72623 L
.88565 .72567 L
.90228 .72171 L
.9219 .71381 L
.94152 .71403 L
.96115 .70863 L
.97011 .70604 L
.98077 .70136 L
F
0 g
.98077 .74971 m
.96115 .76291 L
.9448 .76491 L
.94152 .76586 L
.9219 .77295 L
.90228 .77998 L
.88265 .78451 L
.88079 .78454 L
.86303 .78717 L
.84341 .79037 L
.82378 .79282 L
.80416 .79424 L
.78454 .79457 L
.76491 .7938 L
.74529 .79196 L
.72567 .78915 L
.70604 .78586 L
.69611 .78454 L
.68642 .78332 L
.6668 .7773 L
.64717 .76998 L
.63211 .76491 L
.62755 .76317 L
.60793 .757 L
.5883 .74559 L
.58769 .74529 L
.56868 .73524 L
.55262 .72567 L
.54906 .72325 L
.52943 .70929 L
.52532 .70604 L
.51339 .68642 L
.52943 .6854 L
.53562 .68642 L
.54906 .6899 L
.56868 .69548 L
.5883 .69568 L
.60777 .70604 L
.60793 .70628 L
.62755 .71196 L
.64717 .71691 L
.6668 .71916 L
.68642 .72468 L
.69125 .72567 L
.70604 .72824 L
.72567 .73098 L
.74529 .73296 L
.76491 .73419 L
.78454 .7347 L
.80416 .73448 L
Mistroke
.82378 .73354 L
.84341 .73186 L
.86303 .72943 L
.88265 .72623 L
.88565 .72567 L
.90228 .72171 L
.9219 .71381 L
.94152 .71403 L
.96115 .70863 L
.97011 .70604 L
.98077 .70136 L
Mfstroke
.4 g
.98077 .68599 m
.97977 .68642 L
.96115 .69527 L
.94152 .70051 L
.92333 .70604 L
.9219 .70616 L
.90228 .7108 L
.88265 .7163 L
.86303 .72109 L
.84341 .72476 L
.82378 .72398 L
.80416 .72502 L
.78454 .72527 L
.76491 .7247 L
.74529 .72333 L
.72567 .72346 L
.70604 .71928 L
.68642 .71415 L
.6668 .70861 L
.65359 .70604 L
.64717 .70416 L
.62755 .70338 L
.60793 .69102 L
.59723 .68642 L
.5883 .68252 L
.56868 .67342 L
.55594 .6668 L
.54906 .6626 L
.52943 .64992 L
.52563 .64717 L
.5179 .62755 L
.52943 .62699 L
.53497 .62755 L
.54906 .6302 L
.56868 .63461 L
.5883 .63915 L
.60793 .64381 L
.62371 .64717 L
.62755 .64827 L
.64717 .65264 L
.6668 .65077 L
.68642 .65849 L
.70604 .66313 L
.72567 .66618 L
.74529 .66614 L
.75432 .6668 L
.76491 .66721 L
.78454 .66767 L
.80416 .66747 L
.82066 .6668 L
.82378 .66663 L
.84341 .66522 L
.86303 .66454 L
.88265 .66056 L
.90228 .65453 L
.9219 .65421 L
.94152 .65009 L
.95346 .64717 L
.96115 .64637 L
.98077 .63778 L
F
0 g
.98077 .68599 m
.97977 .68642 L
.96115 .69527 L
.94152 .70051 L
.92333 .70604 L
.9219 .70616 L
.90228 .7108 L
.88265 .7163 L
.86303 .72109 L
.84341 .72476 L
.82378 .72398 L
.80416 .72502 L
.78454 .72527 L
.76491 .7247 L
.74529 .72333 L
.72567 .72346 L
.70604 .71928 L
.68642 .71415 L
.6668 .70861 L
.65359 .70604 L
.64717 .70416 L
.62755 .70338 L
.60793 .69102 L
.59723 .68642 L
.5883 .68252 L
.56868 .67342 L
.55594 .6668 L
.54906 .6626 L
.52943 .64992 L
.52563 .64717 L
.5179 .62755 L
.52943 .62699 L
.53497 .62755 L
.54906 .6302 L
.56868 .63461 L
.5883 .63915 L
.60793 .64381 L
.62371 .64717 L
.62755 .64827 L
.64717 .65264 L
.6668 .65077 L
.68642 .65849 L
.70604 .66313 L
.72567 .66618 L
.74529 .66614 L
.75432 .6668 L
.76491 .66721 L
.78454 .66767 L
.80416 .66747 L
.82066 .6668 L
Mistroke
.82378 .66663 L
.84341 .66522 L
.86303 .66454 L
.88265 .66056 L
.90228 .65453 L
.9219 .65421 L
.94152 .65009 L
.95346 .64717 L
.96115 .64637 L
.98077 .63778 L
Mfstroke
.6 g
.98077 .62589 m
.97693 .62755 L
.96115 .63825 L
.94152 .63924 L
.9219 .64473 L
.91248 .64717 L
.90228 .64887 L
.88265 .65419 L
.86303 .66011 L
.84341 .65872 L
.82378 .66035 L
.80416 .66128 L
.78454 .66149 L
.76491 .66099 L
.74529 .65978 L
.72567 .66402 L
.70604 .65768 L
.68642 .65195 L
.6668 .64739 L
.66444 .64717 L
.64717 .6426 L
.62755 .63689 L
.60793 .63188 L
.60007 .62755 L
.5883 .62242 L
.56868 .61346 L
.55769 .60793 L
.54906 .60136 L
.53192 .5883 L
.54906 .58295 L
.56868 .5841 L
.5883 .58763 L
.59745 .5883 L
.60793 .59081 L
.62755 .5944 L
.64717 .5977 L
.6668 .60176 L
.68642 .60346 L
.70604 .60587 L
.72567 .60788 L
.72621 .60793 L
.74529 .60935 L
.76491 .61028 L
.78454 .61065 L
.80416 .61049 L
.82378 .60979 L
.84341 .60854 L
.85079 .60793 L
.86303 .60673 L
.88265 .60447 L
.90228 .60511 L
.9219 .59579 L
.94152 .59575 L
.96115 .59228 L
.98077 .58852 L
F
0 g
.98077 .62589 m
.97693 .62755 L
.96115 .63825 L
.94152 .63924 L
.9219 .64473 L
.91248 .64717 L
.90228 .64887 L
.88265 .65419 L
.86303 .66011 L
.84341 .65872 L
.82378 .66035 L
.80416 .66128 L
.78454 .66149 L
.76491 .66099 L
.74529 .65978 L
.72567 .66402 L
.70604 .65768 L
.68642 .65195 L
.6668 .64739 L
.66444 .64717 L
.64717 .6426 L
.62755 .63689 L
.60793 .63188 L
.60007 .62755 L
.5883 .62242 L
.56868 .61346 L
.55769 .60793 L
.54906 .60136 L
.53192 .5883 L
.54906 .58295 L
.56868 .5841 L
.5883 .58763 L
.59745 .5883 L
.60793 .59081 L
.62755 .5944 L
.64717 .5977 L
.6668 .60176 L
.68642 .60346 L
.70604 .60587 L
.72567 .60788 L
.72621 .60793 L
.74529 .60935 L
.76491 .61028 L
.78454 .61065 L
.80416 .61049 L
.82378 .60979 L
.84341 .60854 L
.85079 .60793 L
.86303 .60673 L
.88265 .60447 L
Mistroke
.90228 .60511 L
.9219 .59579 L
.94152 .59575 L
.96115 .59228 L
.98077 .58852 L
Mfstroke
.4 g
.98077 .56844 m
.98035 .56868 L
.96115 .57572 L
.94152 .58219 L
.9219 .5882 L
.92152 .5883 L
.90228 .59711 L
.88265 .59598 L
.86303 .59883 L
.84341 .60106 L
.82378 .60265 L
.80416 .60356 L
.78454 .60377 L
.76491 .60328 L
.74529 .60209 L
.72567 .60025 L
.70604 .59777 L
.68642 .59466 L
.6668 .59269 L
.65541 .5883 L
.64717 .58586 L
.62755 .57965 L
.60793 .57298 L
.59657 .56868 L
.5883 .56341 L
.5728 .54906 L
.5883 .5453 L
.60793 .54591 L
.62755 .54789 L
.63925 .54906 L
.64717 .55036 L
.6668 .55269 L
.68642 .55475 L
.70604 .55651 L
.72567 .55794 L
.74529 .55675 L
.76491 .5607 L
.78454 .5622 L
.80416 .56156 L
.82378 .5587 L
.84341 .55213 L
.86303 .55712 L
.88265 .55549 L
.90228 .55355 L
.9219 .55132 L
.93969 .54906 L
.94152 .54885 L
.96115 .54433 L
.98077 .54528 L
F
0 g
.98077 .56844 m
.98035 .56868 L
.96115 .57572 L
.94152 .58219 L
.9219 .5882 L
.92152 .5883 L
.90228 .59711 L
.88265 .59598 L
.86303 .59883 L
.84341 .60106 L
.82378 .60265 L
.80416 .60356 L
.78454 .60377 L
.76491 .60328 L
.74529 .60209 L
.72567 .60025 L
.70604 .59777 L
.68642 .59466 L
.6668 .59269 L
.65541 .5883 L
.64717 .58586 L
.62755 .57965 L
.60793 .57298 L
.59657 .56868 L
.5883 .56341 L
.5728 .54906 L
.5883 .5453 L
.60793 .54591 L
.62755 .54789 L
.63925 .54906 L
.64717 .55036 L
.6668 .55269 L
.68642 .55475 L
.70604 .55651 L
.72567 .55794 L
.74529 .55675 L
.76491 .5607 L
.78454 .5622 L
.80416 .56156 L
.82378 .5587 L
.84341 .55213 L
.86303 .55712 L
.88265 .55549 L
.90228 .55355 L
.9219 .55132 L
.93969 .54906 L
.94152 .54885 L
.96115 .54433 L
.98077 .54528 L
s
.3 g
.62755 .66293 m
.64717 .66397 L
.6668 .66466 L
.67696 .6668 L
.68642 .66812 L
.70604 .6703 L
.72567 .67206 L
.74529 .67337 L
.76491 .67421 L
.78454 .67455 L
.80416 .6744 L
.82378 .67377 L
.84341 .67264 L
.86303 .67106 L
.88265 .66904 L
.90113 .6668 L
.90228 .66659 L
.9219 .66468 L
.94152 .66316 L
.96115 .66384 L
.9672 .6668 L
.96115 .67349 L
.94152 .6861 L
.94095 .68642 L
.9219 .69403 L
.90228 .70047 L
.88265 .7059 L
.88209 .70604 L
.86303 .71197 L
.84341 .71905 L
.82378 .71533 L
.80416 .71653 L
.78454 .7168 L
.76491 .71616 L
.74529 .71459 L
.72567 .71605 L
.70604 .70944 L
.69478 .70604 L
.68642 .70384 L
.6668 .69802 L
.64717 .6911 L
.63593 .68642 L
.62755 .68156 L
.60982 .6668 L
F
0 g
.62755 .66293 m
.64717 .66397 L
.6668 .66466 L
.67696 .6668 L
.68642 .66812 L
.70604 .6703 L
.72567 .67206 L
.74529 .67337 L
.76491 .67421 L
.78454 .67455 L
.80416 .6744 L
.82378 .67377 L
.84341 .67264 L
.86303 .67106 L
.88265 .66904 L
.90113 .6668 L
.90228 .66659 L
.9219 .66468 L
.94152 .66316 L
.96115 .66384 L
.9672 .6668 L
.96115 .67349 L
.94152 .6861 L
.94095 .68642 L
.9219 .69403 L
.90228 .70047 L
.88265 .7059 L
.88209 .70604 L
.86303 .71197 L
.84341 .71905 L
.82378 .71533 L
.80416 .71653 L
.78454 .7168 L
.76491 .71616 L
.74529 .71459 L
.72567 .71605 L
.70604 .70944 L
.69478 .70604 L
.68642 .70384 L
.6668 .69802 L
.64717 .6911 L
.63593 .68642 L
.62755 .68156 L
.60982 .6668 L
.62755 .66293 L
s
.7 g
.64717 .61112 m
.6668 .61173 L
.68642 .61303 L
.70604 .61438 L
.72567 .61557 L
.74529 .61649 L
.76491 .61709 L
.78454 .61734 L
.80416 .61723 L
.82378 .61677 L
.84341 .61597 L
.86303 .61488 L
.88265 .61358 L
.90228 .61222 L
.9219 .6112 L
.9367 .62755 L
.9219 .63329 L
.90228 .63962 L
.88265 .64498 L
.87344 .64717 L
.86303 .65065 L
.84341 .65186 L
.82378 .65378 L
.80416 .65486 L
.78454 .6551 L
.76491 .65453 L
.74529 .65312 L
.72567 .65533 L
.70604 .64797 L
.70353 .64717 L
.68642 .64295 L
.6668 .63722 L
.64717 .63038 L
.64023 .62755 L
F
0 g
.64717 .61112 m
.6668 .61173 L
.68642 .61303 L
.70604 .61438 L
.72567 .61557 L
.74529 .61649 L
.76491 .61709 L
.78454 .61734 L
.80416 .61723 L
.82378 .61677 L
.84341 .61597 L
.86303 .61488 L
.88265 .61358 L
.90228 .61222 L
.9219 .6112 L
.9367 .62755 L
.9219 .63329 L
.90228 .63962 L
.88265 .64498 L
.87344 .64717 L
.86303 .65065 L
.84341 .65186 L
.82378 .65378 L
.80416 .65486 L
.78454 .6551 L
.76491 .65453 L
.74529 .65312 L
.72567 .65533 L
.70604 .64797 L
.70353 .64717 L
.68642 .64295 L
.6668 .63722 L
.64717 .63038 L
.64023 .62755 L
.64717 .61112 L
s
.6 g
.64717 .51312 m
.6668 .51287 L
.68642 .51355 L
.70604 .51441 L
.72567 .51521 L
.74529 .51586 L
.76491 .51628 L
.78454 .51646 L
.80416 .51639 L
.82378 .51605 L
.84341 .51549 L
.86303 .51474 L
.88265 .51389 L
.90228 .51309 L
.9219 .5128 L
.93185 .52943 L
.9219 .53223 L
.90228 .53706 L
.88265 .54127 L
.86303 .54483 L
.84341 .54764 L
.83062 .54906 L
.82378 .5498 L
.80416 .5517 L
.78454 .55221 L
.76491 .55106 L
.7462 .54906 L
.74529 .54891 L
.72567 .54661 L
.70604 .54349 L
.68642 .53965 L
.6668 .53521 L
.64717 .53005 L
.64509 .52943 L
F
0 g
.64717 .51312 m
.6668 .51287 L
.68642 .51355 L
.70604 .51441 L
.72567 .51521 L
.74529 .51586 L
.76491 .51628 L
.78454 .51646 L
.80416 .51639 L
.82378 .51605 L
.84341 .51549 L
.86303 .51474 L
.88265 .51389 L
.90228 .51309 L
.9219 .5128 L
.93185 .52943 L
.9219 .53223 L
.90228 .53706 L
.88265 .54127 L
.86303 .54483 L
.84341 .54764 L
.83062 .54906 L
.82378 .5498 L
.80416 .5517 L
.78454 .55221 L
.76491 .55106 L
.7462 .54906 L
.74529 .54891 L
.72567 .54661 L
.70604 .54349 L
.68642 .53965 L
.6668 .53521 L
.64717 .53005 L
.64509 .52943 L
.64717 .51312 L
s
.7 g
.68642 .74296 m
.70604 .74384 L
.72567 .74502 L
.73055 .74529 L
.74529 .74627 L
.76491 .74716 L
.78454 .74754 L
.80416 .74738 L
.82378 .74668 L
.84341 .74551 L
.84545 .74529 L
.86303 .74431 L
.88265 .74322 L
.90228 .74327 L
.90933 .74529 L
.90228 .75123 L
.88265 .75967 L
.86622 .76491 L
.86303 .7657 L
.84341 .76973 L
.82378 .77241 L
.80416 .7739 L
.78454 .77424 L
.76491 .77344 L
.74529 .77149 L
.72567 .76829 L
.71059 .76491 L
.70604 .76353 L
.68642 .75669 L
.66754 .74529 L
F
0 g
.68642 .74296 m
.70604 .74384 L
.72567 .74502 L
.73055 .74529 L
.74529 .74627 L
.76491 .74716 L
.78454 .74754 L
.80416 .74738 L
.82378 .74668 L
.84341 .74551 L
.84545 .74529 L
.86303 .74431 L
.88265 .74322 L
.90228 .74327 L
.90933 .74529 L
.90228 .75123 L
.88265 .75967 L
.86622 .76491 L
.86303 .7657 L
.84341 .76973 L
.82378 .77241 L
.80416 .7739 L
.78454 .77424 L
.76491 .77344 L
.74529 .77149 L
.72567 .76829 L
.71059 .76491 L
.70604 .76353 L
.68642 .75669 L
.66754 .74529 L
.68642 .74296 L
s
.2 g
.70604 .68316 m
.72567 .68256 L
.74529 .68271 L
.76491 .68294 L
.78454 .68306 L
.80416 .683 L
.82378 .6828 L
.84341 .68259 L
.86303 .68274 L
.88265 .68535 L
.88455 .68642 L
.88265 .68807 L
.86303 .6964 L
.84341 .7014 L
.82378 .7047 L
.81093 .70604 L
.80416 .70644 L
.78454 .70679 L
.76599 .70604 L
.76491 .70596 L
.74529 .70357 L
.72567 .69963 L
.70604 .69374 L
.69189 .68642 L
F
0 g
.70604 .68316 m
.72567 .68256 L
.74529 .68271 L
.76491 .68294 L
.78454 .68306 L
.80416 .683 L
.82378 .6828 L
.84341 .68259 L
.86303 .68274 L
.88265 .68535 L
.88455 .68642 L
.88265 .68807 L
.86303 .6964 L
.84341 .7014 L
.82378 .7047 L
.81093 .70604 L
.80416 .70644 L
.78454 .70679 L
.76599 .70604 L
.76491 .70596 L
.74529 .70357 L
.72567 .69963 L
.70604 .69374 L
.69189 .68642 L
.70604 .68316 L
s
.8 g
.70604 .6269 m
.72567 .62544 L
.74529 .62518 L
.76491 .62519 L
.78454 .62522 L
.80416 .62521 L
.82378 .62517 L
.84341 .62527 L
.86303 .62603 L
.87497 .62755 L
.86303 .63603 L
.84341 .64169 L
.82378 .64517 L
.80416 .64702 L
.80122 .64717 L
.78454 .64738 L
.77571 .64717 L
.76491 .64646 L
.74529 .64399 L
.72567 .63975 L
.70604 .63251 L
.70238 .62755 L
F
0 g
.70604 .6269 m
.72567 .62544 L
.74529 .62518 L
.76491 .62519 L
.78454 .62522 L
.80416 .62521 L
.82378 .62517 L
.84341 .62527 L
.86303 .62603 L
.87497 .62755 L
.86303 .63603 L
.84341 .64169 L
.82378 .64517 L
.80416 .64702 L
.80122 .64717 L
.78454 .64738 L
.77571 .64717 L
.76491 .64646 L
.74529 .64399 L
.72567 .63975 L
.70604 .63251 L
.70238 .62755 L
.70604 .6269 L
s
.3 g
.72567 .56919 m
.74529 .56948 L
.76491 .56974 L
.78454 .56987 L
.80416 .56981 L
.82378 .56959 L
.84341 .56929 L
.86303 .56913 L
.86804 .5883 L
.86303 .58923 L
.84341 .5922 L
.82378 .59421 L
.80416 .59534 L
.78454 .5956 L
.76491 .59499 L
.74529 .59351 L
.72567 .59113 L
.70888 .5883 L
F
0 g
.72567 .56919 m
.74529 .56948 L
.76491 .56974 L
.78454 .56987 L
.80416 .56981 L
.82378 .56959 L
.84341 .56929 L
.86303 .56913 L
.86804 .5883 L
.86303 .58923 L
.84341 .5922 L
.82378 .59421 L
.80416 .59534 L
.78454 .5956 L
.76491 .59499 L
.74529 .59351 L
.72567 .59113 L
.70888 .5883 L
.72567 .56919 L
s
.4 g
.74529 .48686 m
.76491 .48491 L
.78454 .48445 L
.80416 .48463 L
.82378 .48573 L
.83728 .49019 L
.82378 .49167 L
.80416 .493 L
.78454 .49331 L
.76491 .49259 L
.74529 .49082 L
.74005 .49019 L
F
0 g
.74529 .48686 m
.76491 .48491 L
.78454 .48445 L
.80416 .48463 L
.82378 .48573 L
.83728 .49019 L
.82378 .49167 L
.80416 .493 L
.78454 .49331 L
.76491 .49259 L
.74529 .49082 L
.74005 .49019 L
.74529 .48686 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00?Oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0dooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kS?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0hooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8b
onk^kS?ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08_ooool003gooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0=_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0<oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg03?ooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL08_ooool003Gooooo1_l0
0003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400[ooooo`Ko0000
1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100<oooool01Ol@413o
oooooooooooooooo410@03[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@03Cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@02;ooooo000o
ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000fooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000cooooo`05o`000?ooooooooooooooool0
0000>_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000=Oooool00onH
V9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000008_ooool0043ooooo00?oMgMgofIV
I_ooool00_ooool01Ol0003ooooooooooooooooo000003Kooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000003?ooooo00Go0000ooooooooooooooooo`00000jooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`03ogMgMomVIVKooooo00;o
oooo00Go0000ooooooooooooooooo`00000Rooooo`00@Oooool01Ol0003ooooooooooooooooo410@
00?ooooo00?o410@ooooooooool0=?ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@4100<oooool01Ol@413ooooooooooooooooo410@03[ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@03Oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo023ooooo000mooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg03Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg03?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0jooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0cooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02;ooooo000mooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^03Cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^03?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`03oeEEEOmVIVKo000000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0cooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02;ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo000Joooooooo0000C_l00001ooooo`00
6_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0?Ooo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool08ooo
ool1o`00007ooooo0008ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKo
oooo00?o0000ooooooooool0oooooom:ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooom:ooooo`7o
00000Oooool000Go00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41001_ooool00ol0003oooooooooo`3ooooood[ooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?ooooooB?ooool3o`00007o
oooo000:ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo0008ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Oooooooogmo
Od3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Ooo
ooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000oooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`003ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000?ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000oooooo00Go0000oooooooooooooooo
o`000006ooooo`?o00001?ooooooogmoOd3oOgmo1?ooool3o`00007ooooo000?ooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool000oooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`003oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000?ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo0008
ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000:ooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`002_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41001_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000[ooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo0ol00004oooooooo
Ogmo@?moOgl4ooooo`?o00000Oooool000[ooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000:ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool000Sooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooo`ogmoOako0000<OmoOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?ooooo_ogmoO`;o00007?mVIVH3o`0002ooOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooolOmoOglLo`0003;oOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooo
ogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00Coooood?moOglHo`0003?oOgmo4Ol0000CogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooom3oOgmo00?o0000oiVIVOnIVIT05OnIVITc
o`00013oVIVI00?o0000ogmoOomoOgl04OmoOgl6ooooo`7o00000Oooool001[ooooo0_l00005oooo
om3oOgmo00?o0000oiVIVOnIVIT0FOnIVIT00ol0003oOgmoogmoO`0@ogmoO`Gooooo0_l00001oooo
o`006_ooool00ol0003oooooooooo`04ooooolooOgmo00?o0000oiVIVOnIVIT0FonIVIT00ol0003o
OgmoogmoO`0?ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooolooOgmo
00?o0000oiVIVOnIVIT0G?nIVIT00ol0003oOgmoogmoO`0>ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooolooOgmo00?o0000oiVIVOnIVIT0FonIVIT3o`0000ooOgmo1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Coooood?moOgl5o`0005GoVIVI0ol0000B
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooomGoOgmo1Ol0001=oiVI
V@?o00005OmoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooJogmoO`?o
0000AOnIVIT5o`0001SoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
gOmoOgl5o`0003_oVIVI1Ol0000MogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooon;oOgmo1_l0000boiVIV@?o00006_moOgl6o`0000;oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00Cooooo^_moOgl>o`00023oOgmo1ol0000VoiVIV@Go00006_moOgl3
o`0000KoIVIV0ol00005ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooongogmo
O`?o00003_mVIVH=o`0001[oOgmo1_l0000CoiVIV@go00006OmoOgl6o`0000_oIVIV1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00Cooooo^OmoOgl00ol0003oIVIVofIVIP0IofIVIPKo
00006_moOglCo`0000SoOgmo1?l0000>ogmoO`co00004OmVIVH6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?oooonjogmoO`03o`000?mVIVKoIVIV01koIVIV3Ol0000UogmoO`?o0000
1?mVIVH3o`0000CoOgmo1ol0000MofIVIPKooooo0Ol00001ooooo`006_ooool2o`0000Gooooo^omo
Ogl00ol0003oIVIVofIVIP0ZofIVIPgo00004omoOgl5o`0000[oIVIV1?l0000TofIVIPGooooo0_l0
0001ooooo`006_ooool00ol0003oooooooooo`04oooookcoOgmo00?o0000ofIVI_mVIVH0=_mVIVHC
o`0003OoIVIV1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo_OmoOgl00ol0
003oIVIVofIVIP1oofIVIPKooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooookko
Ogmo00?o0000ofIVI_mVIVH0O_mVIVH00ol0003oooooooooo`03ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?oooonoogmoO`?o0000:?mVIVH_o`0002CoIVIV0ol00005ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooo2ogmoO`Co00009?mVIVH00ol0003oC4a<oda<
C00[oda<C003o`000?mVIVKoIVIV01ooIVIV0ol00002ogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooolKoOgmo0ol0000PofIVIP03o`000?m<C4coC4a<02goC4a<00?o0000
ofIVI_mVIVH06omVIVH3o`0000GoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooobOmoOgl4o`0001_oIVIV00?o0000oda<C?m<C4`0;_m<C4`00ol0003oIVIVofIVIP0HofIV
IP?o00002?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon_ogmoO`Go
00006OmoOgl3o`0001OoIVIV00?o0000oda<C?m<C4`0;om<C4`00ol0003oIVIVofIVIP0DofIVIPCo
00002omoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon/ogmoO`?o0000
1OnIVIT7o`0001GoOgmo0ol0000CofIVIP03o`000?m<C4coC4a<037oC4a<00?o0000ofIVI_mVIVH0
4?mVIVH3o`0000ooOgmo1_ooool1o`00007ooooo0007ooooo`Go00000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Kooooo00?o0000ooooooooool01?oooonZogmoO`;o00003onIVIT8o`00013oOgmo
0ol0000?ofIVIPCo0000;?m<C4`6o`0000ooIVIV0ol0000?ogmoO`Co00001Oooool1o`00007ooooo
0007ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Ko
oooo00?o0000ooooooooool01?oooon/ogmoO`03o`000?nIVIWoVIVI01CoVIVI1Ol0000>ogmoO`Go
00003_mVIVH6o`0001ooC4a<1ol0000CofIVIP;o00003OmoOgl5o`0000?oVIVI1_ooool1o`00007o
oooo0008ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4006ooooo`03
o`000?oooooooooo00Cooooo[OmoOgl2o`0001WoVIVI1_l0000=ogmoO`Oo00003OmVIVHOo`0001So
IVIV0_l0000<ogmoO`?o00002?nIVIT6ooooo`7o00000Oooool000Wooooo00?oV9RHob4Q8Oo^k^h0
0oooool01Ol0003ooooooooooooooooo000000Kooooo0ol00004ooooojooOgmo00?o0000oiVIVOnI
VIT07?nIVIT5o`0000ooOgmo1_l0000cofIVIP_o00001?moOgl:o`0000_oVIVI1?ooool3o`00007o
oooo000:ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00Cooooo/?moOgl00ol0003oVIVIoiVIV@0PoiVIV@?o00004_moOgl7o`0001oo
IVIV3Ol0000=ogmoO`;o00005OnIVIT6ooooo`7o00000Oooool000_ooooo00Go0000oooooooooooo
oooooa0@4003ooooo`03oa0@4?oooooooooo00Cooooo00?o0000ooooooooool01?oooon`ogmoO`03
o`000?nIVIWoVIVI02?oVIVI3?l0000=ogmoOaoo00003OmoOgl8o`0000?oOgmo0_l0000GoiVIV@Ko
oooo0Ol00001ooooo`001oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`06ooooo`03o`000?oooooooooo00Cooooo/OmoOgl00ol0003oVIVIoiVIV@0^oiVI
V@Ko0000;_moOgl5o`0000SoVIVI0ol0000IoiVIV@Kooooo0Ol00001ooooo`001oooool01OnHV9So
410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooo
oooo00Cooooo/_moOgl3o`0003?oVIVI;_l0000YoiVIV@Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04oooookGoOgmo0ol0000HoiVIVA;o0000>OnIVITAo`0001?oVIVI1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00Cooooo^?moOgl3o`0001GoVIVI00?o0000ok>c/onc
/k<03onc/k<Co`0001?oVIVI4ol0000Aok>c/`03o`000?nIVIWoVIVI013oVIVI1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00Cooooo^omoOgl2o`0001;oVIVI00?o0000ok>c/onc/k<0
8onc/k<Co`0002Go/k>c00?o0000oiVIVOnIVIT03onIVIT6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?oooonmogmoO`;o00004?nIVIT00ol0003o/k>cok>c/`1Lok>c/`03o`000?nI
VIWoVIVI00koVIVI1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo_omoOgl0
0ol0003oVIVIoiVIV@0=oiVIV@03o`000?nc/k?o/k>c01Go/k>c;ol0000Iok>c/`03o`000?nIVIWo
VIVI00goVIVI1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooYOmoOgl:o`00
017oOgmo0_l0000<oiVIV@;o00004_nc/k<5o`0002ooc<c<1ol0000Bok>c/`;o00003?nIVIT3o`00
00Gooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooojGoOgmo00?o0000ofIVI_mV
IVH01omVIVH5o`0000koOgmo00?o0000oiVIVOnIVIT02onIVIT3o`00013o/k>c00?o0000olc<c?o<
c<`0=?o<c<`00ol0003o/k>cok>c/`0?ok>c/`?o00003OnIVIT00ol0003oOgmoogmoO`06ooooo`7o
00000Oooool001[ooooo0_l00005ooooojKoOgmo00?o0000ofIVI_mVIVH02omVIVH5o`0000[oOgmo
1Ol0000;oiVIV@?o00003_nc/k<3o`0003;oc<c<00?o0000ok>c/onc/k<03_nc/k<2o`0000koVIVI
0_l00003ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04ooooojKoOgmo00?o
0000ofIVI_mVIVH04?mVIVH3o`0000coOgmo1Ol00009oiVIV@Co00003Onc/k<3o`0002coc<c<0ol0
000>ok>c/`?o00003onIVIT00ol0003oOgmoogmoO`02ogmoO`;o00001Oooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CoooooYomoOgl00ol0003oIVIVofIVIP0BofIVIPGo00003?moOgl3
o`0000[oVIVI0ol0000=ok>c/`?o00009_o<c<`3o`0000go/k>c1?l00009oiVIV@Wo00000_moOgl3
o`000003ofIVI_oooooooooo00Cooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
ojOoOgmo00?o0000ofIVI_mVIVH05omVIVH4o`0000_oOgmo0ol0000:oiVIV@?o00003Onc/k<3o`00
01koc<c<1Ol0000=ok>c/`?o00002_nIVIT3o`0000WoOgmo0_l00004ofIVIPKooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooojOoOgmo00?o0000ofIVI_mVIVH06omVIVH3o`0000_o
Ogmo0ol0000:oiVIV@?o00003Onc/k<:o`0000koc<c<1_l0000?ok>c/`?o00002_nIVIT3o`0000[o
Ogmo0_l00006ofIVIPKooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooojSoOgmo
00?o0000ofIVI_mVIVH07OmVIVH6o`0000SoOgmo1Ol00008oiVIV@Co00004onc/k<>o`0001;o/k>c
0ol00006oiVIV@Oo00002_moOgl3o`0000SoIVIV1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CoooooZOmoOgl2o`0002?oIVIV3?l000000omoOgoo0000o`000003o`0000OoVIVI0ol0
000Tok>c/`co00001_nIVIT3o`0000coOgmo1Ol0000;ofIVIPKooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04oooooj_oOgmo0_l0000]ofIVIP?o00000omoOgl3o`0000OoVIVI9?l0000?
oiVIV@?o00000omoOgl<o`00013oIVIV1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00Cooooo[OmoOgl00ol0003oIVIVofIVIP0]ofIVIP?o00000omoOgl4o`0002OoVIVI2?l00004oiVI
V@?o00000omoOgl3o`0001coIVIV1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooo[_moOgl2o`00033oIVIV0ol00004ogmoO`?o00001?nIVITPo`0000SoOgmo1?l000000omoOgoo
0000o`000003o`0001ooIVIV1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
/?moOgl2o`0001GoIVIV4ol00009ofIVIPGo00000_moOgl4o`0002OoOgmo1_l0000=ofIVIQ;o0000
1OmVIVH6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonbogmoO`;o00004?mV
IVH3o`0001?oC4a<0ol0000;ofIVIRgo00003OmVIVH6o`0001;oC4a<00?o0000ofIVI_mVIVH00_mV
IVH6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooondogmoO`;o00004?mVIVH0
0ol0003oC4a<oda<C00Doda<C0_o0000<omVIVH7o`0001OoC4a<00?o0000ofIVI_mVIVH00omVIVH6
ooooo`7o00000Oooool001[ooooo0_l00005oooookKoOgmo0_l0000?ofIVIP03o`000?m<C4coC4a<
01koC4a<3Ol0000CofIVIQ?o00007?m<C4`2o`0000KoIVIV1Oooool2o`00007ooooo000Jooooo`03
o`000?oooooooooo00Cooooo^?moOgl3o`0000goIVIV00?o0000oda<C?m<C4`0:_m<C4`Co`0002ko
C4a<00?o0000ofIVI_mVIVH01_mVIVH6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?oooonkogmoO`;o00003?mVIVH00ol0003oC4a<oda<C01Yoda<C003o`000?mVIVKoIVIV00OoIVIV
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo_OmoOgl2o`0000_oIVIV00?o
0000oda<C?m<C4`06_m<C4`Eo`0000GoC4a<6ol0000Hoda<C003o`000?mVIVKoIVIV00SoIVIV1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooYomoOgl4o`0001CoOgmo00?o0000
ofIVI_mVIVH02OmVIVH00ol0003oC4a<oda<C00Doda<C0Go00005Olc<c<5o`0001_o<c<c0ol0000D
oda<C003o`000?mVIVKoIVIV00WoIVIV00?o0000ooooooooool00oooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CoooooY?moOgl3o`0000CoVIVI1?l0000AogmoO`?o00002OmVIVH3o`00
013oC4a<0ol0000koc<c<`?o00004?m<C4`3o`0000_oIVIV0_l00005ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?oooonTogmoO`03o`000?nIVIWoVIVI00SoVIVI1?l0000@ogmoO`;o
00002_mVIVH4o`0000koC4a<0ol0000goc<c<`;o00004?m<C4`3o`0000_oIVIV0ol000000omoOgoo
ooooooooo`04ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonUogmoO`03o`00
0?nIVIWoVIVI00_oVIVI0ol0000?ogmoO`;o00003?mVIVH3o`0000koC4a<0ol0000boc<c<`;o0000
3om<C4`3o`0000coIVIV0_l00004ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooojKoOgmo00?o0000oiVIVOnIVIT03OnIVIT9o`0000SoOgmo00?o0000ofIVI_mVIVH03?mV
IVH4o`0000goC4a<0ol0000/oc<c<`?o00003_m<C4`3o`0000_oIVIV1?l00006ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooojKoOgmo00?o0000oiVIVOnIVIT05_nIVIT2
o`0000OoOgmo0_l0000@ofIVIP?o00003Om<C4`5o`0002Co<c<c0ol0000=oda<C0Co00002_mVIVH4
o`0000[oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooYomoOgl00ol0
003oVIVIoiVIV@0GoiVIV@;o00001omoOgl4o`0000ooIVIV0ol0000?oda<C0Ko00006Olc<c<5o`00
00goC4a<0ol0000;ofIVIP?o00003?moOgl3o`0000Gooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooojSoOgmo00?o0000oiVIVOnIVIT06?nIVIT3o`0000SoOgmo2?l0000:ofIVIP?o
00004_m<C4`Io`0000ooC4a<0ol0000:ofIVIPCo00003?moOgl3o`0000;oVIVI1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CoooooZOmoOgl2o`0001_oVIVI0ol0000=ogmoO`Co0000
2OmVIVH4o`0003?oC4a<0ol0000:ofIVIP?o00003OmoOgl3o`0000GoVIVI1_ooool1o`00007ooooo
000Jooooo`;o00001Ooooon[ogmoO`03o`000?nIVIWoVIVI01_oVIVI1?l0000=ogmoO`?o00002_mV
IVH3o`0002coC4a<1?l00009ofIVIPCo00003OmoOgl3o`0000SoVIVI1Oooool2o`00007ooooo000J
ooooo`03o`000?oooooooooo00Cooooo[?moOgl2o`0001ooVIVI0ol0000=ogmoO`?o00002_mVIVH;
o`0001?oC4a<1ol00004oda<C0?o00002_mVIVH3o`0000OoOgmo2_l0000;oiVIV@Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooojkoOgmo00?o0000oiVIVOnIVIT07onIVIT5o`00
00_oOgmo0ol0000BofIVIQ?o00001omVIVH4o`0000SoIVIV1Ol00007ogmoO`?o00005OnIVIT6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon_ogmoO`03o`000?nIVIWoVIVI02?o
VIVI1_l00008ogmoO`Go0000;OmVIVH6o`0000WoOgmo0ol0000HoiVIV@Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04oooook3oOgmo00?o0000oiVIVOnIVIT0:?nIVIT4o`0000WoOgmo
5?l00005ofIVIQCo00003?moOgl3o`0001_oVIVI1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00Cooooo/OmoOgl2o`0002coVIVI1?l0000IogmoO`Go00006_moOgl6o`0001koVIVI1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo/omoOgl2o`0002koVIVI3?l0000V
ogmoO`Ko00009?nIVIT6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooneogmo
O`03o`000?nIVIWoVIVI03OoVIVI3Ol0000<ogmoO`go0000:_nIVIT6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?oooonfogmoO`;o0000A?nIVIT<o`0003OoVIVI1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00Cooooo^?moOgl2o`0008GoVIVI1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00Cooooo^_moOgl2o`0001koVIVI2?l0000ioiVIV@So00007?nI
VIT6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonlogmoO`?o00006?nIVIT3
o`0000So/k>c3_l0000NoiVIV@go00002?nc/k<5o`0001OoVIVI1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00Cooooo_omoOgl00ol0003oVIVIoiVIV@0GoiVIV@03o`000?nc/k?o/k>c
01Co/k>c7_l0000Hok>c/`03o`000?nIVIWoVIVI01KoVIVI1_ooool1o`00007ooooo000Jooooo`;o
00001Oooooo0ogmoO`;o00006?nIVIT2o`0004So/k>c0_l0000HoiVIV@;o00001?ooool2o`00007o
oooo000Jooooo`03o`000?oooooooooo00Cooooo`_moOgl00ol0003oVIVIoiVIV@0GoiVIV@03o`00
0?nc/k?o/k>c04;o/k>c0ol0000HoiVIV@;o000000?oOgmoooooooooool01?ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00Cooooo`omoOgl3o`0001OoVIVI0ol0000ook>c/`;o00006_nI
VIT01?l0003oOgmoogmoOomoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooo6ogmoO`?o00005onIVIT3o`0003[o/k>c0_l0000JoiVIV@;o00001?moOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?ooooo9ogmoO`;o00006?nIVIT2o`0003Go/k>c0ol0000I
oiVIV@?o00001_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooo;ogmo
O`Co00005_nIVIT4o`0002co/k>c1Ol0000FoiVIV@Ko00002OmoOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?ooooo?ogmoO`?o00005onIVIT6o`0001oo/k>c1ol0000HoiVIV@?o
00003omoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooBogmoO`?o0000
6_nIVIT6o`0001?o/k>c1_l0000LoiVIV@?o00004_moOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?oooooEogmoO`;o00007_nIVITCo`00023oVIVI0_l0000EogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooomOoOgmo0ol0001<oiVIV@;o00005omoOgl6
ooooo`7o00000Oooool000Oooooo00GoV9RHoa0@4?l0003o<S8bolc<c003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`04ooooom[oOgmo0ol00015oiVIV@Co00006Omo
Ogl6ooooo`7o00000Oooool000Oooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`04ooooomgoOgmo1_l0000hoiVIV@Oo0000
7OmoOgl6ooooo`7o00000Oooool000_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@
4?oooooooooo00Cooooo00?o0000ooooooooool01?oooooSogmoO`Go0000;OnIVIT6o`0002CoOgmo
1_ooool1o`00007ooooo000:ooooo`03ojVYZOl@413ooooo00;ooooo00Go0000oooooooooooooooo
o`000006ooooo`?o00001?oooooXogmoO`Oo00007onIVIT7o`0002[oOgmo1?ooool3o`00007ooooo
0009ooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo00CoooookomoOgl=o`0000GoVIVI3Ol0000aogmoO`Kooooo0Ol00001ooooo`002_oo
ool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003ooooo
ooooo`04oooooocoOgmo1Ol0000nogmoO`Kooooo0Ol00001ooooo`001oooool01Ol@413oV9RHoooo
oonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00Co
oooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`001oooool01OnYZJWo410@o`000?l@413oZJVY00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo
@?moOgl6ooooo`7o00000Oooool001[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Ooo
ool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooooomo
Ogm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
ooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo
@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo0_l00005ooooooooOgmo@?moOgl5
ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
ooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3o
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo0_l00005ooooooooOgmo
@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooo
ogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool000Wooooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP06
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0
003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000Oooooo1Ol00003ooooo`05oa0@4?oooooooooo
ooooool@41001_ooool3o`0000CooooooomoOgm0ogmoO`Cooooo0ol00001ooooo`001oooool01?m4
A4CogMgMooooool00004ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooooooo
o`3ooooood[ooooo0Ol00001ooooo`001oooool01?oMgMgoEEEEooooool00004ooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`3ooooood[ooooo0Ol00001ooooo`002?oo
ool00omgMgOoc<c<o`000004ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003ooooo
ooooo`3ooooood[ooooo0Ol00001ooooo`002?ooool00oo^k^koA4A4o`000004ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooood[ooooo0Ol00001ooooo`002Ooo
ool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003ooooo
ooooo`0Sooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0?Oooool00ol0003ooooo
ooooo`0mooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool08oooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool1o`00007ooooo000J
oooooooo0000C_l00001ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-30.1723, -14.304, 0.195672, \
0.195672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0192308 0.211538 0.0192308 [
[.11538 -0.0125 -9 -9 ]
[.11538 -0.0125 9 0 ]
[.30769 -0.0125 -9 -9 ]
[.30769 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69231 -0.0125 -6 -9 ]
[.69231 -0.0125 6 0 ]
[.88462 -0.0125 -6 -9 ]
[.88462 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -18 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .21154 -6 -4.5 ]
[-0.0125 .21154 0 4.5 ]
[-0.0125 .40385 -12 -4.5 ]
[-0.0125 .40385 0 4.5 ]
[-0.0125 .59615 -12 -4.5 ]
[-0.0125 .59615 0 4.5 ]
[-0.0125 .78846 -12 -4.5 ]
[-0.0125 .78846 0 4.5 ]
[-0.0125 .98077 -12 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11538 0 m
.11538 .00625 L
s
[(-20)] .11538 -0.0125 0 1 Mshowa
.30769 0 m
.30769 .00625 L
s
[(-10)] .30769 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69231 0 m
.69231 .00625 L
s
[(10)] .69231 -0.0125 0 1 Mshowa
.88462 0 m
.88462 .00625 L
s
[(20)] .88462 -0.0125 0 1 Mshowa
.125 Mabswid
.15385 0 m
.15385 .00375 L
s
.19231 0 m
.19231 .00375 L
s
.23077 0 m
.23077 .00375 L
s
.26923 0 m
.26923 .00375 L
s
.34615 0 m
.34615 .00375 L
s
.38462 0 m
.38462 .00375 L
s
.42308 0 m
.42308 .00375 L
s
.46154 0 m
.46154 .00375 L
s
.53846 0 m
.53846 .00375 L
s
.57692 0 m
.57692 .00375 L
s
.61538 0 m
.61538 .00375 L
s
.65385 0 m
.65385 .00375 L
s
.73077 0 m
.73077 .00375 L
s
.76923 0 m
.76923 .00375 L
s
.80769 0 m
.80769 .00375 L
s
.84615 0 m
.84615 .00375 L
s
.07692 0 m
.07692 .00375 L
s
.03846 0 m
.03846 .00375 L
s
.92308 0 m
.92308 .00375 L
s
.96154 0 m
.96154 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(-10)] -0.0125 .01923 1 0 Mshowa
0 .21154 m
.00625 .21154 L
s
[(0)] -0.0125 .21154 1 0 Mshowa
0 .40385 m
.00625 .40385 L
s
[(10)] -0.0125 .40385 1 0 Mshowa
0 .59615 m
.00625 .59615 L
s
[(20)] -0.0125 .59615 1 0 Mshowa
0 .78846 m
.00625 .78846 L
s
[(30)] -0.0125 .78846 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(40)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .05769 m
.00375 .05769 L
s
0 .09615 m
.00375 .09615 L
s
0 .13462 m
.00375 .13462 L
s
0 .17308 m
.00375 .17308 L
s
0 .25 m
.00375 .25 L
s
0 .28846 m
.00375 .28846 L
s
0 .32692 m
.00375 .32692 L
s
0 .36538 m
.00375 .36538 L
s
0 .44231 m
.00375 .44231 L
s
0 .48077 m
.00375 .48077 L
s
0 .51923 m
.00375 .51923 L
s
0 .55769 m
.00375 .55769 L
s
0 .63462 m
.00375 .63462 L
s
0 .67308 m
.00375 .67308 L
s
0 .71154 m
.00375 .71154 L
s
0 .75 m
.00375 .75 L
s
0 .82692 m
.00375 .82692 L
s
0 .86538 m
.00375 .86538 L
s
0 .90385 m
.00375 .90385 L
s
0 .94231 m
.00375 .94231 L
s
.25 Mabswid
0 0 m
0 1 L
s
.11538 .99375 m
.11538 1 L
s
.30769 .99375 m
.30769 1 L
s
.5 .99375 m
.5 1 L
s
.69231 .99375 m
.69231 1 L
s
.88462 .99375 m
.88462 1 L
s
.125 Mabswid
.15385 .99625 m
.15385 1 L
s
.19231 .99625 m
.19231 1 L
s
.23077 .99625 m
.23077 1 L
s
.26923 .99625 m
.26923 1 L
s
.34615 .99625 m
.34615 1 L
s
.38462 .99625 m
.38462 1 L
s
.42308 .99625 m
.42308 1 L
s
.46154 .99625 m
.46154 1 L
s
.53846 .99625 m
.53846 1 L
s
.57692 .99625 m
.57692 1 L
s
.61538 .99625 m
.61538 1 L
s
.65385 .99625 m
.65385 1 L
s
.73077 .99625 m
.73077 1 L
s
.76923 .99625 m
.76923 1 L
s
.80769 .99625 m
.80769 1 L
s
.84615 .99625 m
.84615 1 L
s
.07692 .99625 m
.07692 1 L
s
.03846 .99625 m
.03846 1 L
s
.92308 .99625 m
.92308 1 L
s
.96154 .99625 m
.96154 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .21154 m
1 .21154 L
s
.99375 .40385 m
1 .40385 L
s
.99375 .59615 m
1 .59615 L
s
.99375 .78846 m
1 .78846 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .05769 m
1 .05769 L
s
.99625 .09615 m
1 .09615 L
s
.99625 .13462 m
1 .13462 L
s
.99625 .17308 m
1 .17308 L
s
.99625 .25 m
1 .25 L
s
.99625 .28846 m
1 .28846 L
s
.99625 .32692 m
1 .32692 L
s
.99625 .36538 m
1 .36538 L
s
.99625 .44231 m
1 .44231 L
s
.99625 .48077 m
1 .48077 L
s
.99625 .51923 m
1 .51923 L
s
.99625 .55769 m
1 .55769 L
s
.99625 .63462 m
1 .63462 L
s
.99625 .67308 m
1 .67308 L
s
.99625 .71154 m
1 .71154 L
s
.99625 .75 m
1 .75 L
s
.99625 .82692 m
1 .82692 L
s
.99625 .86538 m
1 .86538 L
s
.99625 .90385 m
1 .90385 L
s
.99625 .94231 m
1 .94231 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.4 g
.98077 .72134 m
.96952 .72567 L
.96115 .72816 L
.94152 .73605 L
.9219 .7445 L
.90337 .74529 L
.90228 .74532 L
.88265 .74818 L
.86303 .75177 L
.84341 .75461 L
.82378 .75648 L
.80416 .75731 L
.78454 .75711 L
.76491 .75589 L
.74529 .75364 L
.72567 .75046 L
.70604 .74682 L
.69277 .74529 L
.68642 .74382 L
.6668 .74126 L
.64717 .73293 L
.62755 .72587 L
.62666 .72567 L
.60793 .71836 L
.5883 .71053 L
.58051 .70604 L
.56868 .69992 L
.54906 .69273 L
.54489 .68642 L
.52943 .67497 L
.519 .6668 L
.52943 .65441 L
.54906 .65716 L
.56868 .6614 L
.5883 .66624 L
.59104 .6668 L
.60793 .67149 L
.62755 .67633 L
.64717 .67947 L
.6668 .68535 L
.67591 .68642 L
.68642 .68846 L
.70604 .6917 L
.72567 .69428 L
.74529 .6922 L
.76491 .69498 L
.78454 .69633 L
.80416 .69654 L
.82378 .69564 L
.84341 .69346 L
.86303 .68937 L
.88265 .69275 L
.90228 .68977 L
.92032 .68642 L
.9219 .68638 L
.94152 .68212 L
.96115 .67326 L
.98077 .67339 L
F
0 g
.98077 .72134 m
.96952 .72567 L
.96115 .72816 L
.94152 .73605 L
.9219 .7445 L
.90337 .74529 L
.90228 .74532 L
.88265 .74818 L
.86303 .75177 L
.84341 .75461 L
.82378 .75648 L
.80416 .75731 L
.78454 .75711 L
.76491 .75589 L
.74529 .75364 L
.72567 .75046 L
.70604 .74682 L
.69277 .74529 L
.68642 .74382 L
.6668 .74126 L
.64717 .73293 L
.62755 .72587 L
.62666 .72567 L
.60793 .71836 L
.5883 .71053 L
.58051 .70604 L
.56868 .69992 L
.54906 .69273 L
.54489 .68642 L
.52943 .67497 L
.519 .6668 L
.52943 .65441 L
.54906 .65716 L
.56868 .6614 L
.5883 .66624 L
.59104 .6668 L
.60793 .67149 L
.62755 .67633 L
.64717 .67947 L
.6668 .68535 L
.67591 .68642 L
.68642 .68846 L
.70604 .6917 L
.72567 .69428 L
.74529 .6922 L
.76491 .69498 L
.78454 .69633 L
.80416 .69654 L
.82378 .69564 L
.84341 .69346 L
Mistroke
.86303 .68937 L
.88265 .69275 L
.90228 .68977 L
.92032 .68642 L
.9219 .68638 L
.94152 .68212 L
.96115 .67326 L
.98077 .67339 L
Mfstroke
.6 g
.98077 .78575 m
.96115 .79572 L
.94152 .80184 L
.93469 .80416 L
.9219 .80787 L
.90228 .81395 L
.88265 .81924 L
.86303 .82292 L
.85285 .82378 L
.84341 .82456 L
.82378 .82599 L
.80416 .8267 L
.78454 .82653 L
.76491 .82551 L
.74529 .82392 L
.74357 .82378 L
.72567 .82178 L
.70604 .81737 L
.68642 .81169 L
.6668 .80562 L
.66147 .80416 L
.64717 .80283 L
.62755 .79172 L
.61261 .78454 L
.60793 .78234 L
.5883 .77696 L
.57482 .76491 L
.56868 .76118 L
.54906 .7485 L
.54456 .74529 L
.52943 .73209 L
.52103 .72567 L
.52943 .71766 L
.54906 .72019 L
.56868 .72437 L
.57223 .72567 L
.5883 .73126 L
.60793 .73718 L
.62755 .74088 L
.63876 .74529 L
.64717 .74787 L
.6668 .75291 L
.68642 .75717 L
.70604 .75828 L
.72567 .763 L
.73732 .76491 L
.74529 .76582 L
.76491 .76755 L
.78454 .76848 L
.80416 .76863 L
.82378 .76799 L
.84341 .76657 L
.85886 .76491 L
.86303 .76427 L
.88265 .76036 L
.90228 .75364 L
.9219 .75462 L
.94152 .74988 L
.95785 .74529 L
.96115 .74415 L
.98077 .73928 L
F
0 g
.98077 .78575 m
.96115 .79572 L
.94152 .80184 L
.93469 .80416 L
.9219 .80787 L
.90228 .81395 L
.88265 .81924 L
.86303 .82292 L
.85285 .82378 L
.84341 .82456 L
.82378 .82599 L
.80416 .8267 L
.78454 .82653 L
.76491 .82551 L
.74529 .82392 L
.74357 .82378 L
.72567 .82178 L
.70604 .81737 L
.68642 .81169 L
.6668 .80562 L
.66147 .80416 L
.64717 .80283 L
.62755 .79172 L
.61261 .78454 L
.60793 .78234 L
.5883 .77696 L
.57482 .76491 L
.56868 .76118 L
.54906 .7485 L
.54456 .74529 L
.52943 .73209 L
.52103 .72567 L
.52943 .71766 L
.54906 .72019 L
.56868 .72437 L
.57223 .72567 L
.5883 .73126 L
.60793 .73718 L
.62755 .74088 L
.63876 .74529 L
.64717 .74787 L
.6668 .75291 L
.68642 .75717 L
.70604 .75828 L
.72567 .763 L
.73732 .76491 L
.74529 .76582 L
.76491 .76755 L
.78454 .76848 L
.80416 .76863 L
Mistroke
.82378 .76799 L
.84341 .76657 L
.85886 .76491 L
.86303 .76427 L
.88265 .76036 L
.90228 .75364 L
.9219 .75462 L
.94152 .74988 L
.95785 .74529 L
.96115 .74415 L
.98077 .73928 L
Mfstroke
.6 g
.98077 .65972 m
.96115 .66658 L
.96049 .6668 L
.94152 .67345 L
.9219 .68471 L
.90228 .68146 L
.88265 .685 L
.87362 .68642 L
.86303 .68676 L
.84341 .68863 L
.82378 .69022 L
.80416 .69098 L
.78454 .6908 L
.76491 .6897 L
.74529 .68789 L
.72567 .68686 L
.72259 .68642 L
.70604 .68373 L
.68642 .67995 L
.6668 .67962 L
.64717 .67036 L
.6357 .6668 L
.62755 .66402 L
.60793 .65699 L
.5883 .65062 L
.58363 .64717 L
.56868 .6394 L
.54906 .62852 L
.5475 .62755 L
.53719 .60793 L
.54906 .60694 L
.56043 .60793 L
.56868 .60925 L
.5883 .6129 L
.60793 .61666 L
.62755 .61773 L
.64717 .62403 L
.66664 .62755 L
.6668 .62758 L
.68642 .63081 L
.70604 .63348 L
.72567 .63011 L
.74529 .63533 L
.76491 .63816 L
.78454 .63961 L
.80416 .63984 L
.82378 .63886 L
.84341 .63659 L
.86303 .63254 L
.88265 .63435 L
.90228 .63189 L
.9219 .62888 L
.92933 .62755 L
.94152 .6254 L
.96115 .62204 L
.98077 .61807 L
F
0 g
.98077 .65972 m
.96115 .66658 L
.96049 .6668 L
.94152 .67345 L
.9219 .68471 L
.90228 .68146 L
.88265 .685 L
.87362 .68642 L
.86303 .68676 L
.84341 .68863 L
.82378 .69022 L
.80416 .69098 L
.78454 .6908 L
.76491 .6897 L
.74529 .68789 L
.72567 .68686 L
.72259 .68642 L
.70604 .68373 L
.68642 .67995 L
.6668 .67962 L
.64717 .67036 L
.6357 .6668 L
.62755 .66402 L
.60793 .65699 L
.5883 .65062 L
.58363 .64717 L
.56868 .6394 L
.54906 .62852 L
.5475 .62755 L
.53719 .60793 L
.54906 .60694 L
.56043 .60793 L
.56868 .60925 L
.5883 .6129 L
.60793 .61666 L
.62755 .61773 L
.64717 .62403 L
.66664 .62755 L
.6668 .62758 L
.68642 .63081 L
.70604 .63348 L
.72567 .63011 L
.74529 .63533 L
.76491 .63816 L
.78454 .63961 L
.80416 .63984 L
.82378 .63886 L
.84341 .63659 L
.86303 .63254 L
.88265 .63435 L
Mistroke
.90228 .63189 L
.9219 .62888 L
.92933 .62755 L
.94152 .6254 L
.96115 .62204 L
.98077 .61807 L
Mfstroke
.4 g
.98077 .60192 m
.96528 .60793 L
.96115 .61006 L
.94152 .6145 L
.9219 .6191 L
.90228 .62316 L
.88265 .62667 L
.87713 .62755 L
.86303 .62881 L
.84341 .63143 L
.82378 .63353 L
.80416 .63458 L
.78454 .63433 L
.76491 .63284 L
.74529 .63045 L
.72567 .62795 L
.71904 .62755 L
.70604 .62541 L
.68642 .62168 L
.6668 .61742 L
.64717 .61258 L
.63089 .60793 L
.62755 .60667 L
.60793 .59894 L
.5883 .59073 L
.58303 .5883 L
.57483 .56868 L
.5883 .56834 L
.59381 .56868 L
.60793 .57021 L
.62755 .57275 L
.64717 .57533 L
.6668 .5778 L
.68642 .57821 L
.70604 .58219 L
.72567 .584 L
.74529 .58546 L
.76491 .5865 L
.78454 .58708 L
.80416 .58717 L
.82378 .58678 L
.84341 .5859 L
.86303 .5846 L
.88265 .58292 L
.90228 .58237 L
.9219 .5787 L
.94152 .57628 L
.96115 .57373 L
.98077 .57115 L
F
0 g
.98077 .60192 m
.96528 .60793 L
.96115 .61006 L
.94152 .6145 L
.9219 .6191 L
.90228 .62316 L
.88265 .62667 L
.87713 .62755 L
.86303 .62881 L
.84341 .63143 L
.82378 .63353 L
.80416 .63458 L
.78454 .63433 L
.76491 .63284 L
.74529 .63045 L
.72567 .62795 L
.71904 .62755 L
.70604 .62541 L
.68642 .62168 L
.6668 .61742 L
.64717 .61258 L
.63089 .60793 L
.62755 .60667 L
.60793 .59894 L
.5883 .59073 L
.58303 .5883 L
.57483 .56868 L
.5883 .56834 L
.59381 .56868 L
.60793 .57021 L
.62755 .57275 L
.64717 .57533 L
.6668 .5778 L
.68642 .57821 L
.70604 .58219 L
.72567 .584 L
.74529 .58546 L
.76491 .5865 L
.78454 .58708 L
.80416 .58717 L
.82378 .58678 L
.84341 .5859 L
.86303 .5846 L
.88265 .58292 L
.90228 .58237 L
.9219 .5787 L
.94152 .57628 L
.96115 .57373 L
.98077 .57115 L
s
.6 g
.62755 .53662 m
.64717 .53527 L
.6668 .53594 L
.68642 .53705 L
.70604 .53823 L
.72567 .53932 L
.74529 .54023 L
.76491 .54089 L
.78454 .54126 L
.80416 .54132 L
.82378 .54107 L
.84341 .54051 L
.86303 .53969 L
.88265 .53866 L
.90228 .5375 L
.9219 .53634 L
.94152 .53543 L
.96115 .53557 L
.96928 .54906 L
.96115 .55206 L
.94152 .55842 L
.9219 .56424 L
.90502 .56868 L
.90228 .5698 L
.88265 .57223 L
.86303 .57461 L
.84341 .57637 L
.82378 .57751 L
.80416 .57803 L
.78454 .57791 L
.76491 .57715 L
.74529 .57578 L
.72567 .57378 L
.70604 .57116 L
.69111 .56868 L
.68642 .56751 L
.6668 .56209 L
.64717 .55608 L
.62755 .54938 L
.6267 .54906 L
F
0 g
.62755 .53662 m
.64717 .53527 L
.6668 .53594 L
.68642 .53705 L
.70604 .53823 L
.72567 .53932 L
.74529 .54023 L
.76491 .54089 L
.78454 .54126 L
.80416 .54132 L
.82378 .54107 L
.84341 .54051 L
.86303 .53969 L
.88265 .53866 L
.90228 .5375 L
.9219 .53634 L
.94152 .53543 L
.96115 .53557 L
.96928 .54906 L
.96115 .55206 L
.94152 .55842 L
.9219 .56424 L
.90502 .56868 L
.90228 .5698 L
.88265 .57223 L
.86303 .57461 L
.84341 .57637 L
.82378 .57751 L
.80416 .57803 L
.78454 .57791 L
.76491 .57715 L
.74529 .57578 L
.72567 .57378 L
.70604 .57116 L
.69111 .56868 L
.68642 .56751 L
.6668 .56209 L
.64717 .55608 L
.62755 .54938 L
.6267 .54906 L
.62755 .53662 L
s
.3 g
.62755 .69513 m
.64717 .69465 L
.6668 .69645 L
.68642 .69856 L
.70604 .70058 L
.72567 .70235 L
.74529 .70189 L
.76491 .70403 L
.78454 .705 L
.80416 .70514 L
.82378 .70451 L
.84341 .70289 L
.86303 .69947 L
.88265 .70129 L
.90228 .69935 L
.9219 .69725 L
.94152 .69524 L
.96115 .69427 L
.96705 .70604 L
.96115 .71068 L
.94152 .72001 L
.92781 .72567 L
.9219 .7303 L
.90228 .73353 L
.88265 .7382 L
.86303 .74189 L
.84341 .74463 L
.83878 .74529 L
.82378 .74649 L
.80416 .74739 L
.78454 .74718 L
.76491 .74588 L
.75824 .74529 L
.74529 .7437 L
.72567 .7406 L
.70604 .73655 L
.68642 .73146 L
.66836 .72567 L
.6668 .72505 L
.64717 .71668 L
.62755 .70636 L
.62704 .70604 L
F
0 g
.62755 .69513 m
.64717 .69465 L
.6668 .69645 L
.68642 .69856 L
.70604 .70058 L
.72567 .70235 L
.74529 .70189 L
.76491 .70403 L
.78454 .705 L
.80416 .70514 L
.82378 .70451 L
.84341 .70289 L
.86303 .69947 L
.88265 .70129 L
.90228 .69935 L
.9219 .69725 L
.94152 .69524 L
.96115 .69427 L
.96705 .70604 L
.96115 .71068 L
.94152 .72001 L
.92781 .72567 L
.9219 .7303 L
.90228 .73353 L
.88265 .7382 L
.86303 .74189 L
.84341 .74463 L
.83878 .74529 L
.82378 .74649 L
.80416 .74739 L
.78454 .74718 L
.76491 .74588 L
.75824 .74529 L
.74529 .7437 L
.72567 .7406 L
.70604 .73655 L
.68642 .73146 L
.66836 .72567 L
.6668 .72505 L
.64717 .71668 L
.62755 .70636 L
.62704 .70604 L
.62755 .69513 L
s
.7 g
.64717 .63822 m
.6668 .6388 L
.68642 .64013 L
.70604 .64161 L
.72567 .63782 L
.74529 .64236 L
.76491 .64432 L
.78454 .64517 L
.80416 .6453 L
.82378 .64474 L
.84341 .64328 L
.86303 .64008 L
.88265 .64216 L
.90228 .6407 L
.9219 .63926 L
.94152 .63827 L
.96115 .6394 L
.96577 .64717 L
.96115 .65042 L
.94152 .65981 L
.9241 .6668 L
.9219 .66857 L
.90228 .6727 L
.88265 .6769 L
.86303 .68022 L
.84341 .68269 L
.82378 .6843 L
.80416 .68503 L
.78454 .68486 L
.76491 .68379 L
.74529 .68185 L
.72567 .67905 L
.70604 .67541 L
.68642 .67085 L
.67204 .6668 L
.6668 .6648 L
.64717 .65649 L
.62943 .64717 L
F
0 g
.64717 .63822 m
.6668 .6388 L
.68642 .64013 L
.70604 .64161 L
.72567 .63782 L
.74529 .64236 L
.76491 .64432 L
.78454 .64517 L
.80416 .6453 L
.82378 .64474 L
.84341 .64328 L
.86303 .64008 L
.88265 .64216 L
.90228 .6407 L
.9219 .63926 L
.94152 .63827 L
.96115 .6394 L
.96577 .64717 L
.96115 .65042 L
.94152 .65981 L
.9241 .6668 L
.9219 .66857 L
.90228 .6727 L
.88265 .6769 L
.86303 .68022 L
.84341 .68269 L
.82378 .6843 L
.80416 .68503 L
.78454 .68486 L
.76491 .68379 L
.74529 .68185 L
.72567 .67905 L
.70604 .67541 L
.68642 .67085 L
.67204 .6668 L
.6668 .6648 L
.64717 .65649 L
.62943 .64717 L
.64717 .63822 L
s
.3 g
.68642 .59538 m
.70604 .59468 L
.72567 .59496 L
.74529 .59543 L
.76491 .59583 L
.78454 .59608 L
.80416 .59612 L
.82378 .59595 L
.84341 .5956 L
.86303 .59513 L
.88265 .59474 L
.90228 .59488 L
.91563 .60793 L
.90228 .61184 L
.88265 .61649 L
.86303 .62017 L
.84341 .6229 L
.82378 .62468 L
.80416 .62547 L
.78454 .62528 L
.76491 .62412 L
.74529 .62197 L
.72567 .61888 L
.70604 .61485 L
.68642 .60974 L
.68054 .60793 L
F
0 g
.68642 .59538 m
.70604 .59468 L
.72567 .59496 L
.74529 .59543 L
.76491 .59583 L
.78454 .59608 L
.80416 .59612 L
.82378 .59595 L
.84341 .5956 L
.86303 .59513 L
.88265 .59474 L
.90228 .59488 L
.91563 .60793 L
.90228 .61184 L
.88265 .61649 L
.86303 .62017 L
.84341 .6229 L
.82378 .62468 L
.80416 .62547 L
.78454 .62528 L
.76491 .62412 L
.74529 .62197 L
.72567 .61888 L
.70604 .61485 L
.68642 .60974 L
.68054 .60793 L
.68642 .59538 L
s
.4 g
.70604 .50675 m
.72567 .50476 L
.74529 .50423 L
.76491 .5041 L
.78454 .50408 L
.80416 .50409 L
.82378 .50409 L
.84341 .50415 L
.86303 .50448 L
.88265 .50564 L
.89734 .50981 L
.88265 .51414 L
.86303 .51845 L
.84341 .52157 L
.82378 .52356 L
.80416 .52444 L
.78454 .52424 L
.76491 .52294 L
.74529 .52052 L
.72567 .51696 L
.70604 .51211 L
.69883 .50981 L
F
0 g
.70604 .50675 m
.72567 .50476 L
.74529 .50423 L
.76491 .5041 L
.78454 .50408 L
.80416 .50409 L
.82378 .50409 L
.84341 .50415 L
.86303 .50448 L
.88265 .50564 L
.89734 .50981 L
.88265 .51414 L
.86303 .51845 L
.84341 .52157 L
.82378 .52356 L
.80416 .52444 L
.78454 .52424 L
.76491 .52294 L
.74529 .52052 L
.72567 .51696 L
.70604 .51211 L
.69883 .50981 L
.70604 .50675 L
s
.8 g
.72567 .65457 m
.74529 .65406 L
.76491 .65411 L
.78454 .65421 L
.80416 .65423 L
.82378 .65415 L
.84341 .65405 L
.86303 .65424 L
.8781 .6668 L
.86303 .67025 L
.84341 .67346 L
.82378 .67546 L
.80416 .67635 L
.78454 .67615 L
.76491 .67484 L
.74529 .67239 L
.72567 .66865 L
.71807 .6668 L
F
0 g
.72567 .65457 m
.74529 .65406 L
.76491 .65411 L
.78454 .65421 L
.80416 .65423 L
.82378 .65415 L
.84341 .65405 L
.86303 .65424 L
.8781 .6668 L
.86303 .67025 L
.84341 .67346 L
.82378 .67546 L
.80416 .67635 L
.78454 .67615 L
.76491 .67484 L
.74529 .67239 L
.72567 .66865 L
.71807 .6668 L
.72567 .65457 L
s
.2 g
.74529 .71765 m
.76491 .7172 L
.78454 .71717 L
.80416 .71718 L
.82378 .71718 L
.84341 .71737 L
.86303 .71898 L
.86445 .72567 L
.86303 .72607 L
.84341 .73037 L
.82378 .73286 L
.80416 .73393 L
.78454 .73368 L
.76491 .73209 L
.74529 .729 L
.7314 .72567 L
F
0 g
.74529 .71765 m
.76491 .7172 L
.78454 .71717 L
.80416 .71718 L
.82378 .71718 L
.84341 .71737 L
.86303 .71898 L
.86445 .72567 L
.86303 .72607 L
.84341 .73037 L
.82378 .73286 L
.80416 .73393 L
.78454 .73368 L
.76491 .73209 L
.74529 .729 L
.7314 .72567 L
.74529 .71765 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00?Oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0dooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kS?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0hooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8b
onk^kS?ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08_ooool003gooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0=_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0<oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg03?ooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL08_ooool003Gooooo1_l0
0003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400[ooooo`Ko0000
1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100<oooool01Ol@413o
oooooooooooooooo410@03[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@03Cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@02;ooooo000o
ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000fooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000cooooo`05o`000?ooooooooooooooool0
0000>_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000=Oooool00onH
V9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000008_ooool0043ooooo00?oMgMgofIV
I_ooool00_ooool01Ol0003ooooooooooooooooo000003Kooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000003?ooooo00Go0000ooooooooooooooooo`00000jooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`03ogMgMomVIVKooooo00;o
oooo00Go0000ooooooooooooooooo`00000Rooooo`00@Oooool01Ol0003ooooooooooooooooo410@
00?ooooo00?o410@ooooooooool0=?ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@4100<oooool01Ol@413ooooooooooooooooo410@03[ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@03Oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo023ooooo000mooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg03Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg03?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0jooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0cooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02;ooooo000mooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^03Cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^03?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`03oeEEEOmVIVKo000000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0cooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02;ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo000Joooooooo0000C_l00001ooooo`00
6_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0?Ooo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool08ooo
ool1o`00007ooooo0008ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKo
oooo00?o0000ooooooooool0oooooom:ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooom:ooooo`7o
00000Oooool000Go00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41001_ooool00ol0003oooooooooo`3ooooood[ooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?ooooooB?ooool3o`00007o
oooo000:ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo0008ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Oooooooogmo
Od3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Ooo
ooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000oooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`003ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000?ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000oooooo00Go0000oooooooooooooooo
o`000006ooooo`?o00001?ooooooogmoOd3oOgmo1?ooool3o`00007ooooo000?ooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool000oooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`003oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000?ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo0008
ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000:ooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`002_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41001_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000[ooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo0ol00004oooooooo
Ogmo@?moOgl4ooooo`?o00000Oooool000[ooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000:ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool000Sooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?oooooWogmoOcGo00008omoOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?oooooSogmoO`Co0000=OmVIVH6o`0001goOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooohOmoOgl3o`0003goIVIV0ol0000KogmoO`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooonCoOgmo1?l0000eofIVIPCo00007_mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooXogmoO`Go0000;OmVIVH3
o`0002;oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Oooooo]ogmoO`?o00009OmVIVH5o`00
02GoOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00Coooool?moOgl<o`0001;o
IVIV1ol0000ZogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooocoOgmo
4_l0000aogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooocOmoOgl8o`0005[oOgmo1ol00009ogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooool[oOgmo0ol00008oiVIVA?o
0000>_moOgl=o`0000OoVIVI0ol00006ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04oooool[oOgmo00?o0000oiVIVOnIVIT06onIVITjo`0001KoVIVI00?o0000ogmoOomoOgl0
1?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooo:ogmoO`03o`000?nI
VIWoVIVI06coVIVI00?o0000ogmoOomoOgl00omoOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooo9ogmoO`03o`000?nIVIWoVIVI06koVIVI00?o0000ogmoOomoOgl00_moOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooo9ogmoO`Co0000KOnIVIT2o`00
00?oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooocOmoOgl3o`0006Oo
VIVI0ol00005ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooom3oOgmo
0ol0001QoiVIV@?o00002?moOgl6ooooo`7o00000Oooool001[ooooo0_l00005ooooom?oOgmo0ol0
001JoiVIV@Co00002omoOgl5ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool01?oooooF
ogmoO`Co0000DonIVIT3o`0000ooOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00Cooooof_moOgl3o`0004goVIVI0ol0000BogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04oooook_oOgmo0ol0000OogmoO`;o0000B?nIVIT3o`0001GoOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00Cooooo^?moOgl3o`0000?oIVIV2_l0000GogmoO`Wo0000
>_nIVIT5o`0001GoOgmo1?l00005ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
oonhogmoO`03o`000?mVIVKoIVIV00goIVIV1_l0000JogmoO`Oo00009_nIVIT=o`0001?oOgmo1ol0
0003ofIVIPKooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooookWoOgmo00?o0000
ofIVI_mVIVH04_mVIVH7o`0001[oOgmo3Ol0000<oiVIV@go00006_moOgl6o`0000[oIVIV1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo^OmoOgl00ol0003oIVIVofIVIP0IofIV
IPgo00006_moOgl<o`00023oOgmo1ol0000@ofIVIPKooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04oooook[oOgmo00?o0000ofIVI_mVIVH09OmVIVH6o`0003?oOgmo3Ol0000GofIVIPKo
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooook[oOgmo00?o0000ofIVI_mVIVH0
:omVIVHDo`0001;oOgmo3Ol0000TofIVIPKooooo0Ol00001ooooo`001oooool5o`0000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo00Cooooo^omoOgl2o`0003ooIVIV
4_l0000aofIVIPKooooo0Ol00001ooooo`001oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00Cooooo_OmoOgl2o`00083o
IVIV1_ooool1o`00007ooooo0008ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooo
oooooa0@4006ooooo`03o`000?oooooooooo00Cooooo_omoOgl2o`0001coIVIV6?l0000IofIVIQSo
00006OmVIVH6ooooo`7o00000Oooool000Wooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooo
oooooooooooo000000Kooooo0ol00004oooool7oOgmo0_l0000JofIVIP03o`000?m<C4coC4a<01Go
C4a<6Ol0000Goda<C003o`000?mVIVKoIVIV01OoIVIV1?ooool3o`00007ooooo000:ooooo`03ogMg
MomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00Co
oooo`omoOgl3o`0001KoIVIV00?o0000oda<C?m<C4`0Aom<C4`00ol0003oIVIVofIVIP0FofIVIPKo
oooo0Ol00001ooooo`002oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@oooooooo
ool01?ooool00ol0003oooooooooo`04ooooolKoOgmo0ol0000CofIVIP03o`000?m<C4coC4a<04So
C4a<00?o0000ofIVI_mVIVH05?mVIVH2o`0000Gooooo0Ol00001ooooo`001oooool01Ol0003o^[Zj
oooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo
00Cooooo[_moOgl5o`0001KoOgmo0_l0000AofIVIP03o`000?m<C4coC4a<04WoC4a<00?o0000ofIV
I_mVIVH04?mVIVH3o`000003ogmoOooooooooooo00Cooooo0Ol00001ooooo`001oooool01OnHV9So
410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooo
oooo00Cooooo[?moOgl2o`0000GoVIVI2?l0000@ogmoO`Co00003?mVIVH5o`0004OoC4a<0ol0000=
ofIVIPCo00001?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon/ogmo
O`03o`000?nIVIWoVIVI00coVIVI1_l0000>ogmoO`Co00003OmVIVH3o`0003ooC4a<1Ol0000=ofIV
IP?o00002?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon]ogmoO`03
o`000?nIVIWoVIVI017oVIVI1ol0000;ogmoO`?o00003OmVIVH5o`0003GoC4a<1Ol0000=ofIVIPGo
00002omoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon]ogmoO`03o`00
0?nIVIWoVIVI01SoVIVI1Ol00009ogmoO`Go00003OmVIVH7o`0002_oC4a<0ol0000=ofIVIPGo0000
3OmoOgl4o`0000Gooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooojkoOgmo00?o
0000oiVIVOnIVIT07?nIVIT3o`0000_oOgmo1ol0000=ofIVIPKo00008?m<C4`5o`0000goIVIV0ol0
000;ogmoO`Oo00000onIVIT6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon^
ogmoO`03o`000?nIVIWoVIVI01ooVIVI1Ol0000=ogmoO`Go00003_mVIVHPo`0000goIVIV1Ol00009
ogmoO`Go00002_nIVIT6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon_ogmo
O`?o00008onIVIT6o`0000coOgmo2?l0000VofIVIPgo00002omoOgl3o`0000ooVIVI1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00Cooooo/_moOgl00ol0003oVIVIoiVIV@0VoiVIV@Oo
00001OmoOgl6o`0000;oOgmo1_l0000IofIVIPOo00004omoOgl5o`0001;oVIVI1_ooool1o`00007o
oooo000Jooooo`;o00001OooooncogmoO`;o0000;OnIVIT5o`0000KoVIVI0ol00005ogmoOaWo0000
1omoOglCo`0001OoVIVI1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo]Omo
Ogl00ol0003oVIVIoiVIV@0aoiVIV@Co00000onIVIT5o`0001WoOgmo1ol0000ZoiVIV@Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04oooookKoOgmo0_l0000GoiVIVA?o00001?nIVIT3
o`0000Co/k>c0ol00005oiVIVAWo00001onIVIT7o`0000KoVIVI5ol00006oiVIV@Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04oooookSoOgmo0_l0000CoiVIV@;o00004onc/k<4o`00
00[o/k>c1Ol0000IoiVIV@Oo00001onc/k<6o`0001Ko/k>c00?o0000oiVIVOnIVIT01?nIVIT6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonjogmoO`03o`000?nIVIWoVIVI00ko
VIVI0_l0000Xok>c/aWo0000:onc/k<00ol0003oVIVIoiVIV@03oiVIV@Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04oooook_oOgmo0_l0000=oiVIV@;o0000KOnc/k<2o`0000CoVIVI
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo_OmoOgl3o`0000coVIVI0_l0
001Yok>c/`;o00001_nIVIT6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonY
ogmoO`Go00004_moOgl3o`0000_oVIVI0_l0000Jok>c/c3o00006onc/k<2o`0000SoVIVI1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooZOmoOgl00ol0003oIVIVofIVIP02ofIV
IPKo00003omoOgl3o`0000[oVIVI0ol0000Gok>c/`03o`000?o<c<coc<c<02goc<c<00?o0000ok>c
/onc/k<05_nc/k<2o`0000[oVIVI1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
ooooZ?moOgl00ol0003oIVIVofIVIP09ofIVIPGo00003OmoOgl3o`0000[oVIVI0ol0000Cok>c/`03
o`000?o<c<coc<c<02ooc<c<00?o0000ok>c/onc/k<04onc/k<2o`0000[oVIVI0ol00005ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?oooonWogmoO`03o`000?mVIVKoIVIV00ooIVIV
0ol0000=ogmoO`?o00002_nIVIT2o`00017o/k>c00?o0000olc<c?o<c<`0<?o<c<`00ol0003o/k>c
ok>c/`0?ok>c/`?o00002OnIVIT3o`0000;oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CoooooY_moOgl00ol0003oIVIVofIVIP0CofIVIPCo00003?moOgl3o`0000WoVIVI1?l0
000<ok>c/`;o0000<Oo<c<`3o`0000ko/k>c0_l00009oiVIV@?o00001OmoOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?oooonWogmoO`03o`000?mVIVKoIVIV01KoIVIV0ol0000<
ogmoO`?o00002_nIVIT4o`0000[o/k>c1Ol0000Volc<c0Ko00003Onc/k<4o`0000SoVIVI0ol00008
ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000GoooooZ?moOgl00ol0003oIVIVofIVIP0HofIV
IPGo00002_moOgl3o`0000_oVIVI0ol0000<ok>c/`Ko00006Oo<c<`7o`0000go/k>c1_l00009oiVI
V@?o00000omoOgl9o`0000Cooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04ooooojWo
Ogmo0_l0000MofIVIPKo00001omoOgl2o`0000coVIVI1Ol0000=ok>c/aWo00003onc/k<5o`0000go
VIVI0_l00004ogmoO`;o00002?mVIVH6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?oooon[ogmoO`03o`000?mVIVKoIVIV023oIVIV1Ol00004ogmoO`Wo00002?nIVIT7o`0002_o/k>c
0ol0000AoiVIV@03o`000?moOgooOgmo00;oOgmo0_l0000:ofIVIPKooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooojcoOgmo00?o0000ofIVI_mVIVH09?mVIVH3o`0000[oOgmo0ol0
000<oiVIV@Ko00006Onc/k<<o`0000SoVIVI1ol00003oiVIV@;o00000_moOgl3o`0000coIVIV1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo[OmoOgl00ol0003oIVIVofIVIP0V
ofIVIPCo00002OmoOgl5o`0000goVIVI6Ol0000?oiVIV@Go00001omoOgl3o`000004ogmoOol0003o
0000o`0000ooIVIV1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo[_moOgl0
0ol0003oIVIVofIVIP0YofIVIPSo00001_moOgl=o`0001WoVIVI3ol0000;ogmoO`Go00004_mVIVH6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon_ogmoO`03o`000?mVIVKoIVIV
033oIVIV1_l0000=ogmoOaWo00001omoOgl7o`0000KoOgmo1_l0000GofIVIPKooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04oooook3oOgmo0ol0000JofIVIPSo00004omVIVHDo`0001;o
Ogmo1ol00007ofIVIPKo00004omVIVH4o`0000KoIVIV1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00Cooooo/omoOgl3o`0001CoIVIV0ol00008oda<C0Ko00008OmVIVHBo`0001[oIVIV
3Ol00003oda<C003o`000?mVIVKoIVIV00CoIVIV1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00Cooooo]_moOgl2o`0001;oIVIV00?o0000oda<C?m<C4`03_m<C4`=o`0002goIVIV1ol0
0006ofIVIPKo00004Om<C4`00ol0003oIVIVofIVIP03ofIVIPKooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04oooookSoOgmo0_l0000?ofIVIP03o`000?m<C4coC4a<01coC4a<5?l0000B
ofIVIPOo00001om<C4`6o`0001OoC4a<00?o0000ofIVI_mVIVH00omVIVH6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?oooonjogmoO`;o00003OmVIVH3o`00033oC4a<4_l0000/oda<
C003o`000?mVIVKoIVIV00;oIVIV1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooo_?moOgl00ol0003oIVIVofIVIP0=ofIVIP03o`000?m<C4coC4a<06[oC4a<00?o0000ofIVI_mV
IVH00omVIVH6ooooo`7o00000Oooool001[ooooo0_l00005oooookgoOgmo0ol0000=ofIVIP;o0000
J?m<C4`2o`0000KoIVIV1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo`?mo
Ogl3o`0000coIVIV00?o0000oda<C?m<C4`0Hom<C4`2o`0000SoIVIV1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CoooooZOmoOgl5o`0001GoOgmo0_l0000;ofIVIP?o00007Om<C4`Y
o`0001[oC4a<0_l0000:ofIVIPKooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
ojSoOgmo00?o0000oiVIVOnIVIT00onIVIT6o`00017oOgmo0_l0000<ofIVIP?o00006?m<C4`2o`00
02So<c<c00?o0000oda<C?m<C4`05_m<C4`2o`0000_oIVIV0_l00005ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?oooonWogmoO`03o`000?nIVIWoVIVI00[oVIVI0ol0000@ogmoO`;o
00003OmVIVH2o`0001GoC4a<00?o0000oc<c<olc<c<0:?lc<c<00ol0003oC4a<oda<C00Coda<C0?o
00002omVIVH2o`000003ogmoOooooooooooo00Cooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooojKoOgmo0_l0000?oiVIV@?o00003omoOgl4o`0000[oIVIV0ol0000Boda<C0Co0000
9Olc<c<4o`0001?oC4a<0_l00009ofIVIPGo00000omoOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?oooonXogmoO`03o`000?nIVIWoVIVI00ooVIVI0ol0000@ogmoO`?o00002_mV
IVH3o`0001?oC4a<1Ol0000Ioc<c<`Oo00004om<C4`4o`0000WoIVIV0_l00008ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooojWoOgmo0_l0000BoiVIV@Co00003omoOgl2
o`0000_oIVIV1Ol0000Coda<C1Wo00005Om<C4`5o`0000_oIVIV0_l0000:ogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04oooooj_oOgmo00?o0000oiVIVOnIVIT04onIVIT5o`00
00coOgmo0ol0000=ofIVIPGo0000>Om<C4`3o`0000koIVIV0_l0000<ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooojcoOgmo00?o0000oiVIVOnIVIT05onIVIT3o`0000co
Ogmo0_l0000@ofIVIP?o0000<Om<C4`5o`0000koIVIV0ol0000<ogmoO`?o00001Oooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00Cooooo[OmoOgl00ol0003oVIVIoiVIV@0IoiVIV@Co0000
2_moOgl4o`0000ooIVIV1Ol0000Voda<C0Ko00004OmVIVH2o`0000coOgmo0ol00002oiVIV@Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooojkoOgmo0_l0000MoiVIV@?o00002omo
Ogl8o`0000coIVIV3Ol0000Boda<C0Oo00003OmVIVH:o`0000[oOgmo1?l00005oiVIV@Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04oooook3oOgmo0_l0000NoiVIV@?o00004?moOgl5
o`0001CoIVIV4_l0000=ofIVIPOo00004OmoOgl3o`0000WoVIVI1_ooool1o`00007ooooo000Joooo
o`;o00001OoooonbogmoO`03o`000?nIVIWoVIVI01koVIVI0ol0000BogmoO`Oo00009_mVIVH6o`00
01CoOgmo1?l0000<oiVIV@Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04oooook?o
Ogmo0_l0000QoiVIV@Go00005?moOgl6o`0001WoIVIV1ol0000>ogmoO`co00004?nIVIT6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooneogmoO`03o`000?nIVIWoVIVI02?oVIVI
3?l0000>ogmoOaWo00004_moOgl3o`0001coVIVI1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00Cooooo]_moOgl00ol0003oVIVIoiVIV@0^oiVIV@?o0000<OmoOgl5o`0001ooVIVI1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo]omoOgl00ol0003oVIVIoiVIV@0`
oiVIV@?o0000:_moOgl4o`0002CoVIVI1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00Cooooo^?moOgl2o`0003?oVIVI2?l0000IogmoO`Wo0000:?nIVIT6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?oooonjogmoO`03o`000?nIVIWoVIVI03SoVIVI6Ol0000aoiVIV@Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooook_oOgmo00?o0000oiVIVOnIVIT0
POnIVIT6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonlogmoO`03o`000?nI
VIWoVIVI083oVIVI1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo_OmoOgl4
o`0007koVIVI1_ooool1o`00007ooooo0007ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool01?ooooo1ogmoO`Co0000N_nI
VIT6ooooo`7o00000Oooool000Oooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`04ooooolGoOgmo0_l0001hoiVIV@Kooooo
0Ol00001ooooo`002oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0
1?ooool00ol0003oooooooooo`04ooooolOoOgmo0_l0001eoiVIV@;o00001Oooool1o`00007ooooo
000:ooooo`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`?o0000
1?ooooo9ogmoO`03o`000?nIVIWoVIVI06ooVIVI0ol000000omoOgooooooooooo`02ooooo`?o0000
0Oooool000Wooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool01?ooooo:ogmoO`;o0000KOnIVIT2o`0000CoOgmo1_ooool1o`00007ooooo
000:ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`00
0?oooooooooo00Coooooc?moOgl2o`0006WoVIVI0_l00006ogmoO`Kooooo0Ol00001ooooo`001ooo
ool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03
o`000?oooooooooo00Coooooc_moOgl2o`0006CoVIVI0ol00008ogmoO`Kooooo0Ol00001ooooo`00
1oooool01OnYZJWo410@o`000?l@413oZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06oooo
o`03o`000?oooooooooo00Coooood?moOgl4o`0005goVIVI0ol0000;ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooomCoOgmo1_l0001DoiVIV@?o00003_moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?oooooJogmoO`?o0000COnIVIT4o`00017oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooogOmoOgl3o`0004OoVIVI0ol0
000EogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooon3oOgmo0ol00010
oiVIV@Co00006?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooSogmo
O`Co0000>OnIVIT3o`0001coOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
ooooiomoOgl3o`00037oVIVI1Ol0000OogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooon[oOgmo2ol0000NoiVIV@So00009?moOgl6ooooo`7o00000Oooool001[ooooo0_l0
0005ooooooGoOgmo7_l0000/ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002Oooool2o`000009oa0@
4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool01?oooooo
ogmoOd3oOgmo1_ooool1o`00007ooooo000:ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001
ooooo`001oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@4006ooooo`?o00001?oooooo
ogmoOd3oOgmo1?ooool3o`00007ooooo0007ooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?ooooooB_ooool1o`00007ooooo0007
ooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo0?ooooooB_ooool1o`00007ooooo0008ooooo`03ogMgMoo<c<co000000Cooooo00Go
410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo0?ooooooB_ooool1o`00007ooooo
0008ooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`00
0?oooooooooo0?ooooooB_ooool1o`00007ooooo0009ooooo`03ogMgMol0003ooooo00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0
?Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0
?Oooool00ol0003oooooooooo`0Sooooo`7o00000Oooool001[ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`09ooooo`7o00000Oooool001[oooooool0001>o`00007ooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-30.1723, -14.304, 0.195672, \
0.195672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0192308 0.211538 0.0192308 [
[.11538 -0.0125 -9 -9 ]
[.11538 -0.0125 9 0 ]
[.30769 -0.0125 -9 -9 ]
[.30769 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69231 -0.0125 -6 -9 ]
[.69231 -0.0125 6 0 ]
[.88462 -0.0125 -6 -9 ]
[.88462 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -18 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .21154 -6 -4.5 ]
[-0.0125 .21154 0 4.5 ]
[-0.0125 .40385 -12 -4.5 ]
[-0.0125 .40385 0 4.5 ]
[-0.0125 .59615 -12 -4.5 ]
[-0.0125 .59615 0 4.5 ]
[-0.0125 .78846 -12 -4.5 ]
[-0.0125 .78846 0 4.5 ]
[-0.0125 .98077 -12 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11538 0 m
.11538 .00625 L
s
[(-20)] .11538 -0.0125 0 1 Mshowa
.30769 0 m
.30769 .00625 L
s
[(-10)] .30769 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69231 0 m
.69231 .00625 L
s
[(10)] .69231 -0.0125 0 1 Mshowa
.88462 0 m
.88462 .00625 L
s
[(20)] .88462 -0.0125 0 1 Mshowa
.125 Mabswid
.15385 0 m
.15385 .00375 L
s
.19231 0 m
.19231 .00375 L
s
.23077 0 m
.23077 .00375 L
s
.26923 0 m
.26923 .00375 L
s
.34615 0 m
.34615 .00375 L
s
.38462 0 m
.38462 .00375 L
s
.42308 0 m
.42308 .00375 L
s
.46154 0 m
.46154 .00375 L
s
.53846 0 m
.53846 .00375 L
s
.57692 0 m
.57692 .00375 L
s
.61538 0 m
.61538 .00375 L
s
.65385 0 m
.65385 .00375 L
s
.73077 0 m
.73077 .00375 L
s
.76923 0 m
.76923 .00375 L
s
.80769 0 m
.80769 .00375 L
s
.84615 0 m
.84615 .00375 L
s
.07692 0 m
.07692 .00375 L
s
.03846 0 m
.03846 .00375 L
s
.92308 0 m
.92308 .00375 L
s
.96154 0 m
.96154 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(-10)] -0.0125 .01923 1 0 Mshowa
0 .21154 m
.00625 .21154 L
s
[(0)] -0.0125 .21154 1 0 Mshowa
0 .40385 m
.00625 .40385 L
s
[(10)] -0.0125 .40385 1 0 Mshowa
0 .59615 m
.00625 .59615 L
s
[(20)] -0.0125 .59615 1 0 Mshowa
0 .78846 m
.00625 .78846 L
s
[(30)] -0.0125 .78846 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(40)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .05769 m
.00375 .05769 L
s
0 .09615 m
.00375 .09615 L
s
0 .13462 m
.00375 .13462 L
s
0 .17308 m
.00375 .17308 L
s
0 .25 m
.00375 .25 L
s
0 .28846 m
.00375 .28846 L
s
0 .32692 m
.00375 .32692 L
s
0 .36538 m
.00375 .36538 L
s
0 .44231 m
.00375 .44231 L
s
0 .48077 m
.00375 .48077 L
s
0 .51923 m
.00375 .51923 L
s
0 .55769 m
.00375 .55769 L
s
0 .63462 m
.00375 .63462 L
s
0 .67308 m
.00375 .67308 L
s
0 .71154 m
.00375 .71154 L
s
0 .75 m
.00375 .75 L
s
0 .82692 m
.00375 .82692 L
s
0 .86538 m
.00375 .86538 L
s
0 .90385 m
.00375 .90385 L
s
0 .94231 m
.00375 .94231 L
s
.25 Mabswid
0 0 m
0 1 L
s
.11538 .99375 m
.11538 1 L
s
.30769 .99375 m
.30769 1 L
s
.5 .99375 m
.5 1 L
s
.69231 .99375 m
.69231 1 L
s
.88462 .99375 m
.88462 1 L
s
.125 Mabswid
.15385 .99625 m
.15385 1 L
s
.19231 .99625 m
.19231 1 L
s
.23077 .99625 m
.23077 1 L
s
.26923 .99625 m
.26923 1 L
s
.34615 .99625 m
.34615 1 L
s
.38462 .99625 m
.38462 1 L
s
.42308 .99625 m
.42308 1 L
s
.46154 .99625 m
.46154 1 L
s
.53846 .99625 m
.53846 1 L
s
.57692 .99625 m
.57692 1 L
s
.61538 .99625 m
.61538 1 L
s
.65385 .99625 m
.65385 1 L
s
.73077 .99625 m
.73077 1 L
s
.76923 .99625 m
.76923 1 L
s
.80769 .99625 m
.80769 1 L
s
.84615 .99625 m
.84615 1 L
s
.07692 .99625 m
.07692 1 L
s
.03846 .99625 m
.03846 1 L
s
.92308 .99625 m
.92308 1 L
s
.96154 .99625 m
.96154 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .21154 m
1 .21154 L
s
.99375 .40385 m
1 .40385 L
s
.99375 .59615 m
1 .59615 L
s
.99375 .78846 m
1 .78846 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .05769 m
1 .05769 L
s
.99625 .09615 m
1 .09615 L
s
.99625 .13462 m
1 .13462 L
s
.99625 .17308 m
1 .17308 L
s
.99625 .25 m
1 .25 L
s
.99625 .28846 m
1 .28846 L
s
.99625 .32692 m
1 .32692 L
s
.99625 .36538 m
1 .36538 L
s
.99625 .44231 m
1 .44231 L
s
.99625 .48077 m
1 .48077 L
s
.99625 .51923 m
1 .51923 L
s
.99625 .55769 m
1 .55769 L
s
.99625 .63462 m
1 .63462 L
s
.99625 .67308 m
1 .67308 L
s
.99625 .71154 m
1 .71154 L
s
.99625 .75 m
1 .75 L
s
.99625 .82692 m
1 .82692 L
s
.99625 .86538 m
1 .86538 L
s
.99625 .90385 m
1 .90385 L
s
.99625 .94231 m
1 .94231 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.4 g
.98077 .76035 m
.96115 .76387 L
.95797 .76491 L
.94152 .76929 L
.9219 .77557 L
.90228 .78108 L
.88265 .78346 L
.8758 .78454 L
.86303 .78519 L
.84341 .78676 L
.82378 .78788 L
.80416 .78816 L
.78454 .78756 L
.76491 .78621 L
.74529 .78472 L
.73965 .78454 L
.72567 .78368 L
.70604 .77924 L
.68642 .77335 L
.6668 .76713 L
.65744 .76491 L
.64717 .76148 L
.62755 .75589 L
.60793 .74593 L
.60628 .74529 L
.5883 .7369 L
.56868 .72703 L
.56682 .72567 L
.54906 .71481 L
.5358 .70604 L
.52943 .70008 L
.5176 .68642 L
.52943 .68143 L
.54906 .684 L
.55996 .68642 L
.56868 .68885 L
.5883 .69428 L
.60793 .69446 L
.62755 .70435 L
.63467 .70604 L
.64717 .7094 L
.6668 .71394 L
.68642 .71457 L
.70604 .72051 L
.72567 .72418 L
.73966 .72567 L
.74529 .72631 L
.76491 .72812 L
.78454 .72924 L
.80416 .7297 L
.82378 .72948 L
.84341 .7286 L
.86303 .72704 L
.87578 .72567 L
.88265 .72506 L
.90228 .72204 L
.9219 .71708 L
.94152 .71542 L
.96115 .71111 L
.98077 .70612 L
F
0 g
.98077 .76035 m
.96115 .76387 L
.95797 .76491 L
.94152 .76929 L
.9219 .77557 L
.90228 .78108 L
.88265 .78346 L
.8758 .78454 L
.86303 .78519 L
.84341 .78676 L
.82378 .78788 L
.80416 .78816 L
.78454 .78756 L
.76491 .78621 L
.74529 .78472 L
.73965 .78454 L
.72567 .78368 L
.70604 .77924 L
.68642 .77335 L
.6668 .76713 L
.65744 .76491 L
.64717 .76148 L
.62755 .75589 L
.60793 .74593 L
.60628 .74529 L
.5883 .7369 L
.56868 .72703 L
.56682 .72567 L
.54906 .71481 L
.5358 .70604 L
.52943 .70008 L
.5176 .68642 L
.52943 .68143 L
.54906 .684 L
.55996 .68642 L
.56868 .68885 L
.5883 .69428 L
.60793 .69446 L
.62755 .70435 L
.63467 .70604 L
.64717 .7094 L
.6668 .71394 L
.68642 .71457 L
.70604 .72051 L
.72567 .72418 L
.73966 .72567 L
.74529 .72631 L
.76491 .72812 L
.78454 .72924 L
.80416 .7297 L
Mistroke
.82378 .72948 L
.84341 .7286 L
.86303 .72704 L
.87578 .72567 L
.88265 .72506 L
.90228 .72204 L
.9219 .71708 L
.94152 .71542 L
.96115 .71111 L
.98077 .70612 L
Mfstroke
.6 g
.98077 .69752 m
.96115 .69986 L
.94152 .70532 L
.93877 .70604 L
.9219 .70932 L
.90228 .71455 L
.88265 .71966 L
.86303 .72451 L
.84341 .72114 L
.82378 .7221 L
.80416 .72233 L
.78454 .72183 L
.76491 .72062 L
.74529 .72279 L
.72567 .71785 L
.70604 .71266 L
.68642 .7076 L
.67662 .70604 L
.6668 .70342 L
.64717 .69776 L
.62755 .69282 L
.614 .68642 L
.60793 .68391 L
.5883 .6755 L
.56984 .6668 L
.56868 .6661 L
.54906 .65389 L
.53897 .64717 L
.54906 .63255 L
.56868 .635 L
.5883 .6386 L
.60793 .64148 L
.62755 .64679 L
.62942 .64717 L
.64717 .65105 L
.6668 .65479 L
.68642 .65592 L
.70604 .66243 L
.72567 .6634 L
.74529 .6654 L
.76312 .6668 L
.76491 .66691 L
.78454 .66789 L
.80416 .66828 L
.82378 .6681 L
.84341 .66733 L
.85272 .6668 L
.86303 .666 L
.88265 .66417 L
.90228 .66438 L
.9219 .65857 L
.94152 .6487 L
.96115 .65245 L
.98077 .64837 L
F
0 g
.98077 .69752 m
.96115 .69986 L
.94152 .70532 L
.93877 .70604 L
.9219 .70932 L
.90228 .71455 L
.88265 .71966 L
.86303 .72451 L
.84341 .72114 L
.82378 .7221 L
.80416 .72233 L
.78454 .72183 L
.76491 .72062 L
.74529 .72279 L
.72567 .71785 L
.70604 .71266 L
.68642 .7076 L
.67662 .70604 L
.6668 .70342 L
.64717 .69776 L
.62755 .69282 L
.614 .68642 L
.60793 .68391 L
.5883 .6755 L
.56984 .6668 L
.56868 .6661 L
.54906 .65389 L
.53897 .64717 L
.54906 .63255 L
.56868 .635 L
.5883 .6386 L
.60793 .64148 L
.62755 .64679 L
.62942 .64717 L
.64717 .65105 L
.6668 .65479 L
.68642 .65592 L
.70604 .66243 L
.72567 .6634 L
.74529 .6654 L
.76312 .6668 L
.76491 .66691 L
.78454 .66789 L
.80416 .66828 L
.82378 .6681 L
.84341 .66733 L
.85272 .6668 L
.86303 .666 L
.88265 .66417 L
.90228 .66438 L
Mistroke
.9219 .65857 L
.94152 .6487 L
.96115 .65245 L
.98077 .64837 L
Mfstroke
.6 g
.98077 .8215 m
.97514 .82378 L
.96115 .82996 L
.94152 .83969 L
.9219 .84264 L
.91911 .84341 L
.90228 .84753 L
.88265 .85205 L
.86303 .85572 L
.84341 .85833 L
.82378 .85979 L
.80416 .86013 L
.78454 .85939 L
.76491 .85752 L
.74529 .85451 L
.72567 .8505 L
.70604 .84579 L
.69626 .84341 L
.68642 .84063 L
.6668 .83598 L
.64717 .82679 L
.64002 .82378 L
.62755 .81841 L
.60793 .81046 L
.59889 .80416 L
.5883 .79823 L
.56868 .78836 L
.56616 .78454 L
.54906 .77164 L
.53938 .76491 L
.54906 .75269 L
.56868 .75715 L
.5883 .76254 L
.59666 .76491 L
.60793 .76869 L
.62755 .77486 L
.64717 .78033 L
.66441 .78454 L
.6668 .78529 L
.68642 .7903 L
.70604 .7945 L
.72567 .79789 L
.74529 .79775 L
.76491 .80141 L
.78454 .80336 L
.80416 .80409 L
.82378 .80375 L
.84341 .80227 L
.86303 .79932 L
.88265 .79893 L
.90228 .79581 L
.9219 .79191 L
.94152 .78718 L
.95094 .78454 L
.96115 .78023 L
.98077 .77691 L
F
0 g
.98077 .8215 m
.97514 .82378 L
.96115 .82996 L
.94152 .83969 L
.9219 .84264 L
.91911 .84341 L
.90228 .84753 L
.88265 .85205 L
.86303 .85572 L
.84341 .85833 L
.82378 .85979 L
.80416 .86013 L
.78454 .85939 L
.76491 .85752 L
.74529 .85451 L
.72567 .8505 L
.70604 .84579 L
.69626 .84341 L
.68642 .84063 L
.6668 .83598 L
.64717 .82679 L
.64002 .82378 L
.62755 .81841 L
.60793 .81046 L
.59889 .80416 L
.5883 .79823 L
.56868 .78836 L
.56616 .78454 L
.54906 .77164 L
.53938 .76491 L
.54906 .75269 L
.56868 .75715 L
.5883 .76254 L
.59666 .76491 L
.60793 .76869 L
.62755 .77486 L
.64717 .78033 L
.66441 .78454 L
.6668 .78529 L
.68642 .7903 L
.70604 .7945 L
.72567 .79789 L
.74529 .79775 L
.76491 .80141 L
.78454 .80336 L
.80416 .80409 L
.82378 .80375 L
.84341 .80227 L
.86303 .79932 L
.88265 .79893 L
Mistroke
.90228 .79581 L
.9219 .79191 L
.94152 .78718 L
.95094 .78454 L
.96115 .78023 L
.98077 .77691 L
Mfstroke
.4 g
.98077 .63522 m
.96115 .64104 L
.94152 .64642 L
.93861 .64717 L
.9219 .65148 L
.90228 .65929 L
.88265 .65701 L
.86303 .65918 L
.84341 .66071 L
.82378 .66159 L
.80416 .66181 L
.78454 .66135 L
.76491 .66023 L
.74529 .65847 L
.72567 .65608 L
.70604 .65612 L
.68642 .6493 L
.67679 .64717 L
.6668 .64453 L
.64717 .639 L
.62755 .63299 L
.61178 .62755 L
.60793 .62578 L
.5883 .6164 L
.57169 .60793 L
.5883 .5927 L
.60793 .59481 L
.62755 .59748 L
.64717 .59258 L
.6668 .60319 L
.68642 .606 L
.70065 .60793 L
.70604 .60862 L
.72567 .61076 L
.74529 .61243 L
.76491 .61364 L
.78454 .6144 L
.80416 .61471 L
.82378 .61456 L
.84341 .61397 L
.86303 .61292 L
.88265 .61141 L
.90228 .60944 L
.91477 .60793 L
.9219 .60698 L
.94152 .60422 L
.96115 .59972 L
.98077 .5985 L
F
0 g
.98077 .63522 m
.96115 .64104 L
.94152 .64642 L
.93861 .64717 L
.9219 .65148 L
.90228 .65929 L
.88265 .65701 L
.86303 .65918 L
.84341 .66071 L
.82378 .66159 L
.80416 .66181 L
.78454 .66135 L
.76491 .66023 L
.74529 .65847 L
.72567 .65608 L
.70604 .65612 L
.68642 .6493 L
.67679 .64717 L
.6668 .64453 L
.64717 .639 L
.62755 .63299 L
.61178 .62755 L
.60793 .62578 L
.5883 .6164 L
.57169 .60793 L
.5883 .5927 L
.60793 .59481 L
.62755 .59748 L
.64717 .59258 L
.6668 .60319 L
.68642 .606 L
.70065 .60793 L
.70604 .60862 L
.72567 .61076 L
.74529 .61243 L
.76491 .61364 L
.78454 .6144 L
.80416 .61471 L
.82378 .61456 L
.84341 .61397 L
.86303 .61292 L
.88265 .61141 L
.90228 .60944 L
.91477 .60793 L
.9219 .60698 L
.94152 .60422 L
.96115 .59972 L
.98077 .5985 L
s
.6 g
.98077 .57816 m
.96115 .58571 L
.95385 .5883 L
.94152 .59124 L
.9219 .59529 L
.90228 .59873 L
.88265 .60163 L
.86303 .60394 L
.84341 .6056 L
.82378 .60655 L
.80416 .60678 L
.78454 .60629 L
.76491 .60508 L
.74529 .60318 L
.72567 .60065 L
.70604 .59755 L
.68642 .59391 L
.6668 .5896 L
.66155 .5883 L
.64717 .58306 L
.62755 .57531 L
.61215 .56868 L
.62755 .55774 L
.64717 .55808 L
.6668 .55936 L
.68642 .56092 L
.70604 .55967 L
.72567 .56402 L
.74529 .56532 L
.76491 .56634 L
.78454 .567 L
.80416 .56728 L
.82378 .56715 L
.84341 .56662 L
.86303 .56572 L
.88265 .56452 L
.90228 .56308 L
.9219 .5615 L
.94152 .55991 L
.96115 .55849 L
.98077 .55767 L
F
0 g
.98077 .57816 m
.96115 .58571 L
.95385 .5883 L
.94152 .59124 L
.9219 .59529 L
.90228 .59873 L
.88265 .60163 L
.86303 .60394 L
.84341 .6056 L
.82378 .60655 L
.80416 .60678 L
.78454 .60629 L
.76491 .60508 L
.74529 .60318 L
.72567 .60065 L
.70604 .59755 L
.68642 .59391 L
.6668 .5896 L
.66155 .5883 L
.64717 .58306 L
.62755 .57531 L
.61215 .56868 L
.62755 .55774 L
.64717 .55808 L
.6668 .55936 L
.68642 .56092 L
.70604 .55967 L
.72567 .56402 L
.74529 .56532 L
.76491 .56634 L
.78454 .567 L
.80416 .56728 L
.82378 .56715 L
.84341 .56662 L
.86303 .56572 L
.88265 .56452 L
.90228 .56308 L
.9219 .5615 L
.94152 .55991 L
.96115 .55849 L
.98077 .55767 L
s
.7 g
.98077 .67453 m
.96268 .68642 L
.96115 .68706 L
.94152 .69417 L
.9219 .70011 L
.90228 .70517 L
.89853 .70604 L
.88265 .71082 L
.86303 .71794 L
.84341 .71376 L
.82378 .71486 L
.80416 .71512 L
.78454 .71456 L
.76491 .71317 L
.74529 .71519 L
.72567 .70861 L
.71684 .70604 L
.70604 .70345 L
.68642 .69807 L
.6668 .69178 L
.65263 .68642 L
.64717 .68329 L
.63052 .6668 L
.64717 .66489 L
.6668 .66577 L
.67932 .6668 L
.68642 .66756 L
.70604 .66963 L
.72567 .67145 L
.74529 .67293 L
.76491 .67404 L
.78454 .67474 L
.80416 .67502 L
.82378 .67489 L
.84341 .67434 L
.86303 .67337 L
.88265 .67202 L
.90228 .67032 L
.9219 .66832 L
.9337 .6668 L
.94152 .66546 L
.96115 .66504 L
.98077 .66571 L
F
0 g
.98077 .67453 m
.96268 .68642 L
.96115 .68706 L
.94152 .69417 L
.9219 .70011 L
.90228 .70517 L
.89853 .70604 L
.88265 .71082 L
.86303 .71794 L
.84341 .71376 L
.82378 .71486 L
.80416 .71512 L
.78454 .71456 L
.76491 .71317 L
.74529 .71519 L
.72567 .70861 L
.71684 .70604 L
.70604 .70345 L
.68642 .69807 L
.6668 .69178 L
.65263 .68642 L
.64717 .68329 L
.63052 .6668 L
.64717 .66489 L
.6668 .66577 L
.67932 .6668 L
.68642 .66756 L
.70604 .66963 L
.72567 .67145 L
.74529 .67293 L
.76491 .67404 L
.78454 .67474 L
.80416 .67502 L
.82378 .67489 L
.84341 .67434 L
.86303 .67337 L
.88265 .67202 L
.90228 .67032 L
.9219 .66832 L
.9337 .6668 L
.94152 .66546 L
.96115 .66504 L
.98077 .66571 L
s
.3 g
.6668 .72727 m
.68642 .72964 L
.70604 .73203 L
.72567 .73413 L
.74529 .73585 L
.76491 .73712 L
.78454 .73793 L
.80416 .73826 L
.82378 .73811 L
.84341 .73747 L
.86303 .73636 L
.88265 .7348 L
.90228 .73283 L
.9219 .73052 L
.94152 .72809 L
.96102 .74529 L
.94152 .75354 L
.9219 .76029 L
.90627 .76491 L
.90228 .76647 L
.88265 .77027 L
.86303 .7735 L
.84341 .77572 L
.82378 .77698 L
.80416 .77729 L
.78454 .77664 L
.76491 .77504 L
.74529 .77246 L
.72567 .7723 L
.70911 .76491 L
.70604 .76405 L
.68642 .758 L
.6668 .75078 L
.65422 .74529 L
F
0 g
.6668 .72727 m
.68642 .72964 L
.70604 .73203 L
.72567 .73413 L
.74529 .73585 L
.76491 .73712 L
.78454 .73793 L
.80416 .73826 L
.82378 .73811 L
.84341 .73747 L
.86303 .73636 L
.88265 .7348 L
.90228 .73283 L
.9219 .73052 L
.94152 .72809 L
.96102 .74529 L
.94152 .75354 L
.9219 .76029 L
.90627 .76491 L
.90228 .76647 L
.88265 .77027 L
.86303 .7735 L
.84341 .77572 L
.82378 .77698 L
.80416 .77729 L
.78454 .77664 L
.76491 .77504 L
.74529 .77246 L
.72567 .7723 L
.70911 .76491 L
.70604 .76405 L
.68642 .758 L
.6668 .75078 L
.65422 .74529 L
.6668 .72727 L
s
.3 g
.6668 .62281 m
.68642 .61979 L
.70604 .61986 L
.72567 .6205 L
.74529 .62122 L
.76491 .62185 L
.78454 .62229 L
.80416 .62247 L
.82378 .62238 L
.84341 .62204 L
.86303 .62147 L
.88265 .62076 L
.90228 .62006 L
.9219 .6197 L
.94152 .62079 L
.9509 .62755 L
.94152 .63182 L
.9219 .63901 L
.90228 .64487 L
.89324 .64717 L
.88265 .64899 L
.86303 .65166 L
.84341 .65349 L
.82378 .65453 L
.80416 .65478 L
.78454 .65424 L
.76491 .65292 L
.74529 .6508 L
.72567 .6478 L
.72219 .64717 L
.70604 .6429 L
.68642 .6366 L
.6668 .62865 L
.66461 .62755 L
F
0 g
.6668 .62281 m
.68642 .61979 L
.70604 .61986 L
.72567 .6205 L
.74529 .62122 L
.76491 .62185 L
.78454 .62229 L
.80416 .62247 L
.82378 .62238 L
.84341 .62204 L
.86303 .62147 L
.88265 .62076 L
.90228 .62006 L
.9219 .6197 L
.94152 .62079 L
.9509 .62755 L
.94152 .63182 L
.9219 .63901 L
.90228 .64487 L
.89324 .64717 L
.88265 .64899 L
.86303 .65166 L
.84341 .65349 L
.82378 .65453 L
.80416 .65478 L
.78454 .65424 L
.76491 .65292 L
.74529 .6508 L
.72567 .6478 L
.72219 .64717 L
.70604 .6429 L
.68642 .6366 L
.6668 .62865 L
.66461 .62755 L
.6668 .62281 L
s
.4 g
.68642 .52712 m
.70604 .52587 L
.72567 .52583 L
.74529 .52613 L
.76491 .52649 L
.78454 .52677 L
.80416 .5269 L
.82378 .52684 L
.84341 .52661 L
.86303 .52626 L
.88265 .52592 L
.90228 .52578 L
.9219 .5264 L
.93833 .52943 L
.9219 .5376 L
.90228 .54418 L
.88265 .54897 L
.88221 .54906 L
.86303 .55113 L
.84341 .55258 L
.82378 .55341 L
.80416 .55361 L
.78454 .55318 L
.76491 .55213 L
.74529 .55044 L
.73306 .54906 L
.72567 .54743 L
.70604 .54204 L
.68642 .53466 L
.67702 .52943 L
F
0 g
.68642 .52712 m
.70604 .52587 L
.72567 .52583 L
.74529 .52613 L
.76491 .52649 L
.78454 .52677 L
.80416 .5269 L
.82378 .52684 L
.84341 .52661 L
.86303 .52626 L
.88265 .52592 L
.90228 .52578 L
.9219 .5264 L
.93833 .52943 L
.9219 .5376 L
.90228 .54418 L
.88265 .54897 L
.88221 .54906 L
.86303 .55113 L
.84341 .55258 L
.82378 .55341 L
.80416 .55361 L
.78454 .55318 L
.76491 .55213 L
.74529 .55044 L
.73306 .54906 L
.72567 .54743 L
.70604 .54204 L
.68642 .53466 L
.67702 .52943 L
.68642 .52712 L
s
.8 g
.72567 .68323 m
.74529 .68273 L
.76491 .68282 L
.78454 .683 L
.80416 .68309 L
.82378 .68305 L
.84341 .68289 L
.86303 .68274 L
.88265 .68291 L
.90228 .68486 L
.90639 .68642 L
.90228 .68932 L
.88265 .69667 L
.86303 .70137 L
.84341 .70448 L
.82646 .70604 L
.82378 .70617 L
.80416 .70651 L
.78892 .70604 L
.78454 .70574 L
.76491 .70353 L
.74529 .69988 L
.72567 .69449 L
.70885 .68642 L
F
0 g
.72567 .68323 m
.74529 .68273 L
.76491 .68282 L
.78454 .683 L
.80416 .68309 L
.82378 .68305 L
.84341 .68289 L
.86303 .68274 L
.88265 .68291 L
.90228 .68486 L
.90639 .68642 L
.90228 .68932 L
.88265 .69667 L
.86303 .70137 L
.84341 .70448 L
.82646 .70604 L
.82378 .70617 L
.80416 .70651 L
.78892 .70604 L
.78454 .70574 L
.76491 .70353 L
.74529 .69988 L
.72567 .69449 L
.70885 .68642 L
.72567 .68323 L
s
.7 g
.76491 .58325 m
.78454 .58234 L
.80416 .58209 L
.82378 .5822 L
.84341 .5828 L
.86303 .58501 L
.86768 .5883 L
.86303 .5892 L
.84341 .59203 L
.82378 .59353 L
.80416 .59389 L
.78454 .59313 L
.76491 .59118 L
.74763 .5883 L
F
0 g
.76491 .58325 m
.78454 .58234 L
.80416 .58209 L
.82378 .5822 L
.84341 .5828 L
.86303 .58501 L
.86768 .5883 L
.86303 .5892 L
.84341 .59203 L
.82378 .59353 L
.80416 .59389 L
.78454 .59313 L
.76491 .59118 L
.74763 .5883 L
.76491 .58325 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00?Oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0dooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kS?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0hooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8b
onk^kS?ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08_ooool003gooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0=_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0<oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg03?ooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL08_ooool003Gooooo1_l0
0003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400[ooooo`Ko0000
1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100<oooool01Ol@413o
oooooooooooooooo410@03[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@03Cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@02;ooooo000o
ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000fooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000cooooo`05o`000?ooooooooooooooool0
0000>_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000=Oooool00onH
V9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000008_ooool0043ooooo00?oMgMgofIV
I_ooool00_ooool01Ol0003ooooooooooooooooo000003Kooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000003?ooooo00Go0000ooooooooooooooooo`00000jooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`03ogMgMomVIVKooooo00;o
oooo00Go0000ooooooooooooooooo`00000Rooooo`00@Oooool01Ol0003ooooooooooooooooo410@
00?ooooo00?o410@ooooooooool0=?ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@4100<oooool01Ol@413ooooooooooooooooo410@03[ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@03Oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo023ooooo000mooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg03Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg03?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0jooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0cooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02;ooooo000mooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^03Cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^03?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`03oeEEEOmVIVKo000000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0cooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02;ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo000Joooooooo0000C_l00001ooooo`00
6_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0?Ooo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool08ooo
ool1o`00007ooooo0008ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKo
oooo00?o0000ooooooooool0oooooom:ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooom:ooooo`7o
00000Oooool000Go00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41001_ooool00ol0003oooooooooo`3ooooood[ooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?ooooooB?ooool3o`00007o
oooo000:ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo0008ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Oooooooogmo
Od3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Ooo
ooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000oooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`003ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000?ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000oooooo00Go0000oooooooooooooooo
o`000006ooooo`?o00001?ooooooogmoOd3oOgmo1?ooool3o`00007ooooo000?ooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool000oooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`003oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000?ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo0008
ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000:ooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`002_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41001_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000[ooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo0ol00004oooooooo
Ogmo@?moOgl4ooooo`?o00000Oooool000[ooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000:ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool000Sooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?oooooQogmoOa_o00006OmoOglJo`00013oOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00Cooooof_moOgl7o`0001_oIVIV6Ol0000JofIVIP?o00003Omo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooLogmoO`03o`000?mVIVKo
IVIV04ooIVIV0_l0000?ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
omgoOgmo0_l0001=ofIVIP;o00004OmoOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?oooooOogmoO`?o0000B?mVIVH2o`0001?oOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00Coooooh_moOgl2o`0004?oIVIV0ol0000EogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooonCoOgmo1?l0000kofIVIPCo00006?moOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?oooooXogmoO`Go0000<omVIVH3o`0001coOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooookOmoOgl8o`0002KoIVIV1Ol0000Oogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooGoOgmo3Ol00006ofIVIQ?o
00009?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoO`?oOgmo
1_l0000gogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000GooooobOmoOglBo`0005[oOgmo2ol0
0004ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool01?ooooo8ogmoO`03o`000?nIVIWo
VIVI013oVIVI3Ol00010ogmoO`go00002_nIVIT6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?ooooo7ogmoO`03o`000?nIVIWoVIVI01koVIVI3Ol0000VogmoO`go00005onIVIT6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooo6ogmoO`03o`000?nIVIWoVIVI02co
VIVI9_l0000ToiVIV@Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooolGoOgmo
0_l0001hoiVIV@Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooolOoOgmo0ol0
001eoiVIV@Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooool[oOgmo0ol0001b
oiVIV@Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooolgoOgmo0ol0001]oiVI
V@?o00001Oooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Coooood?moOgl2o`0002Co
VIVI8?l0000ToiVIV@?o00000_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?oooooBogmoO`?o00007_nIVIT3o`00023o/k>c0ol0000NoiVIV@?o00001OmoOgl6ooooo`7o0000
0Oooool000Oooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003ooooo
ooooo`04ooooomGoOgmo1Ol0000HoiVIV@Co00007onc/k<5o`0001[oVIVI0ol00008ogmoO`Kooooo
0Ol00001ooooo`001oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`06ooooo`03o`000?oooooooooo00Cooooo_OmoOgl4o`0000koOgmo0ol00008ogmoO`?o
00006OnIVIT6o`0001;o/k>c1ol0000JoiVIV@Go00002omoOgl6ooooo`7o00000Oooool000Sooooo
00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000oooooooo
ool01?oooonlogmoO`03o`000?mVIVKoIVIV00;oIVIV1ol00004ogmoO`?o00000omVIVH2o`0000Wo
Ogmo1Ol0000JoiVIVA;o00006_nIVIT7o`00013oOgmo1_ooool1o`00007ooooo0009ooooo`03oiRH
V?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000006ooooo`?o00001?oooonkogmoO`03
o`000?mVIVKoIVIV00[oIVIV1?l00008ofIVIP03o`000?moOgooOgmo00_oOgmo1_l0000joiVIV@Ko
00005?moOgl4o`0000?ooooo0ol00001ooooo`002_ooool00omgMgOoIVIVooooo`02ooooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooooooo`04oooook[oOgmo00?o0000ofIVI_mV
IVH06?mVIVH2o`00017oOgmo1ol0000/oiVIV@Oo00004omoOgl7o`0000?oIVIV1_ooool1o`00007o
oooo000;ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo^OmoOgl00ol0003oIVIVofIVIP0KofIVIPCo00005?moOgl6o`00023o
VIVI1_l0000DogmoO`Ko00002_mVIVH6ooooo`7o00000Oooool000Oooooo00Go0000okZj^_oooooo
V9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`04oooo
okSoOgmo00?o0000ofIVI_mVIVH08?mVIVH6o`0001CoOgmo8?l0000EogmoO`Go00004?mVIVH6oooo
o`7o00000Oooool000Oooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01_ooool00ol0003oooooooooo`04oooookOoOgmo0ol0000WofIVIPko0000<omoOgl8
o`0001GoIVIV1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo^_moOgl3o`00
03;oIVIV3Ol0000IogmoO`go00007OmVIVH6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?oooonmogmoO`;o0000?OmVIVHIo`0002[oIVIV1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00Cooooo_omoOgl2o`0001WoIVIV2?l00016ofIVIPSo00003omVIVH6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooo1ogmoO`;o00005?mVIVH3o`0000SoC4a<A_l0
0008oda<C0Co00002omVIVH6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooo3
ogmoO`03o`000?mVIVKoIVIV017oIVIV00?o0000oda<C?m<C4`0F_m<C4`00ol0003oIVIVofIVIP08
ofIVIPKooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooolCoOgmo0ol0000?ofIV
IP?o0000Fom<C4`2o`0000WoIVIV1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
ooooaomoOgl3o`0000ooIVIV0_l0001Foda<C0?o00002omVIVH6ooooo`7o00000Oooool001[ooooo
0_l00005oooook3oOgmo1?l0000FogmoO`?o00003_mVIVH2o`00057oC4a<0ol0000>ofIVIPGooooo
0_l00001ooooo`006_ooool00ol0003oooooooooo`04oooook3oOgmo00Co0000oiVIVOnIVIWoVIVI
1ol0000BogmoO`?o00003OmVIVH3o`0004coC4a<0_l0000?ofIVIP?o00001Oooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00Cooooo[omoOgl00ol0003oVIVIoiVIV@09oiVIV@Ko00003omo
Ogl3o`0000goIVIV0ol00017oda<C0;o00003_mVIVH3o`0000;oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00Cooooo[_moOgl00ol0003oVIVIoiVIV@0@oiVIV@Oo00002omoOgl3
o`0000goIVIV0ol00011oda<C0?o00002omVIVH5o`0000GoOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00Cooooo[OmoOgl00ol0003oVIVIoiVIV@0HoiVIV@?o00002omoOgl4o`00
00coIVIV0ol0000koda<C0?o00002omVIVH3o`0000[oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00Cooooo[?moOgl2o`0001coVIVI1?l0000<ogmoO`Go00002_mVIVH6o`0002co
C4a<2Ol0000:ofIVIPSo00001_moOgl4o`0000Gooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooojkoOgmo0_l0000NoiVIV@Oo00002_moOgl3o`0000goIVIV3Ol0000Ioda<C0Ko0000
3omVIVH7o`0000GoVIVI1_l00003oiVIV@Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04oooook3oOgmo0_l0000SoiVIV@[o00000omoOgl2o`0001SoIVIV6Ol0000CofIVIP;o00000_mo
Ogl2o`00017oVIVI1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo/_moOgl0
0ol0003oVIVIoiVIV@0ZoiVIV@?o00000_moOglAo`0002KoIVIV2?l00003ofIVIP;o00000_moOgl2
o`0001?oVIVI1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo/omoOgl2o`00
02goVIVI0_l0000AogmoObKo00002?moOgl3o`000004ogmoOol0003o0000o`0001GoVIVI1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo]OmoOgl00ol0003oVIVIoiVIV@0FoiVI
V@Oo00003onIVIT;o`0002coOgmo3?l0000HoiVIV@Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04oooookKoOgmo0_l0000CoiVIV@?o00001onc/k<=o`0000goVIVI4ol0000<ogmoO`go
00004_nIVITCo`0000Gooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooookSoOgmo
0ol0000@oiVIV@03o`000?nc/k?o/k>c01Co/k>c1_l0000JoiVIV@co00005?nIVIT;o`0001;o/k>c
1_ooool1o`00007ooooo000Jooooo`;o00001OoooonkogmoO`;o00003onIVIT00ol0003o/k>cok>c
/`0Iok>c/`go00008?nIVIT=o`0001go/k>c1Oooool2o`00007ooooo000Jooooo`03o`000?oooooo
oooo00Cooooo_OmoOgl2o`0000koVIVI00?o0000ok>c/onc/k<09Onc/k<Po`0002Wo/k>c0_l00005
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonoogmoO`;o00003OnIVIT00ol0
003o/k>cok>c/`1/ok>c/`03o`000?nIVIWooooo00Gooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooojSoOgmo1_l0000CogmoO`;o00003?nIVIT00ol0003o/k>cok>c/`0Lok>c/aCo
00003?nc/k<Eo`0001So/k>c0_l00002oiVIV@Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooojKoOgmo0_l00006ofIVIPGo00004?moOgl2o`0000_oVIVI0_l0000Fok>c/`Ko0000
5?o<c<`<o`0001Goc<c<0ol0000Dok>c/`03o`000?nIVIWoVIVI00;oVIVI1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CoooooYOmoOgl00ol0003oIVIVofIVIP0;ofIVIPKo00003?mo
Ogl2o`0000_oVIVI1?l0000?ok>c/`?o0000?_o<c<`00ol0003o/k>cok>c/`0>ok>c/`?o00001OnI
VIT6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonVogmoO`03o`000?mVIVKo
IVIV013oIVIV0ol0000;ogmoO`?o00003?nIVIT4o`0000go/k>c0ol0000iolc<c0?o00003_nc/k<3
o`0000SoVIVI1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooYomoOgl00ol0
003oIVIVofIVIP0BofIVIPWo00001OmoOgl4o`0000coVIVI0ol0000=ok>c/`?o0000<oo<c<`3o`00
00go/k>c1?l0000;oiVIV@Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooojSo
Ogmo00?o0000ofIVI_mVIVH06_mVIVH2o`0000OoOgmo1Ol0000:oiVIV@?o00003Onc/k<3o`0002go
c<c<0ol0000=ok>c/`?o00003?nIVIT4o`0000Gooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooojWoOgmo00?o0000ofIVI_mVIVH06omVIVH00ol0003oOgmoogmoO`09ogmoO`?o0000
2_nIVIT3o`0000go/k>c1Ol0000Uolc<c0?o00003Onc/k<3o`0000[oVIVI1Ol00003ogmoO`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooj[oOgmo00?o0000ofIVI_mVIVH06omV
IVH2o`0000coOgmo1?l00009oiVIV@Co00003_nc/k<7o`0001Woc<c<1Ol0000=ok>c/`?o00002_nI
VIT3o`0000SoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooZomoOgl2
o`0001goIVIV1Ol0000;ogmoO`?o00002_nIVIT3o`0001;o/k>c6Ol0000>ok>c/`Co00001onIVIT6
o`0000WoOgmo0ol00005ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon]ogmo
O`;o00008?mVIVH4o`0000[oOgmo1Ol00008oiVIV@?o0000<onc/k<3o`0000OoVIVI1?l0000<ogmo
O`?o00000_mVIVH6ooooo`7o00000Oooool001[ooooo0_l00005ooooojooOgmo00?o0000ofIVI_mV
IVH08OmVIVH3o`0000coOgmo1Ol00006oiVIV@?o0000;Onc/k<3o`0000OoVIVI0ol0000;ogmoO`Go
00001OmVIVH5ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool01?oooon`ogmoO`;o0000
9?mVIVH:o`0000OoOgmo0ol00006oiVIVBKo00001?nc/k<3o`0000KoVIVI1?l00008ogmoO`Ko0000
2_mVIVH6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonbogmoO`03o`000?mV
IVKoIVIV02_oIVIV0ol00007ogmoO`?o0000:OnIVIT4o`0000KoVIVI0ol00005ogmoO`Oo00004?mV
IVH6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooncogmoO`03o`000?mVIVKo
IVIV02goIVIV1Ol00005ogmoO`?o00001?nIVIT>o`0000KoVIVI3_l00005oiVIV@Go00000_moOgl6
o`0001OoIVIV1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo]?moOgl00ol0
003oIVIVofIVIP0aofIVIPKo00000_moOgl4o`0000koOgmo1_l0000>ogmoO`Go00000_moOgl5o`00
01goIVIV1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo]OmoOgl3o`0001oo
IVIV1?l0000CofIVIPko00006OmoOgl8o`0001;oIVIV1?l0000<ofIVIPKooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04oooookSoOgmo0ol0000LofIVIP04o`000?m<C4coC4a<oda<C0Oo
00006_mVIVHIo`0001?oIVIV1ol00004oda<C003o`000?mVIVKoIVIV00WoIVIV1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00Cooooo^omoOgl2o`0001WoIVIV00?o0000oda<C?m<C4`0
2Om<C4`=o`0003?oIVIV1_l0000<oda<C003o`000?mVIVKoIVIV00SoIVIV1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00Cooooo_OmoOgl2o`0001KoIVIV00?o0000oda<C?m<C4`05om<
C4`=o`0001WoIVIV3Ol0000Coda<C003o`000?mVIVKoIVIV00OoIVIV1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00Cooooo_omoOgl2o`0001?oIVIV00?o0000oda<C?m<C4`09Om<C4`I
o`00027oC4a<00?o0000ofIVI_mVIVH01_mVIVH6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?ooooo1ogmoO`;o00004?mVIVH00ol0003oC4a<oda<C01Qoda<C003o`000?mVIVKoIVIV
00GoIVIV1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo`omoOgl2o`0000go
IVIV0_l0001Soda<C0;o00001_mVIVH6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?ooooo5ogmoO`;o00003OmVIVH3o`0005koC4a<0_l00008ofIVIPKooooo0Ol00001ooooo`006_oo
ool2o`0000GoooooaomoOgl00ol0003oIVIVofIVIP0=ofIVIP?o0000FOm<C4`2o`0000[oIVIV1Ooo
ool2o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo/?moOgl4o`0001CoOgmo0_l0000@
ofIVIP?o0000Dom<C4`3o`0000coIVIV1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00Cooooo[omoOgl00ol0003oVIVIoiVIV@02oiVIV@Go00004OmoOgl3o`00013oIVIV0ol0001=oda<
C0?o00003omVIVH6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon^ogmoO`03
o`000?nIVIWoVIVI00SoVIVI0ol0000AogmoO`?o00004?mVIVH3o`0004OoC4a<0ol0000?ofIVIPCo
00001Oooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo[OmoOgl00ol0003oVIVI
oiVIV@0<oiVIV@?o00004OmoOgl3o`00013oIVIV0_l00012oda<C0?o00003_mVIVH4o`0000?oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo[?moOgl2o`00017oVIVI0ol0
000AogmoO`Ko00003?mVIVH2o`0003_oC4a<1Ol0000>ofIVIP?o00001omoOgl6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?oooon^ogmoO`;o00004_nIVIT4o`0001?oOgmo0_l0000<
ofIVIP?o0000<om<C4`5o`0000koIVIV1Ol0000:ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04oooook3oOgmo0_l0000DoiVIV@?o00004_moOgl2o`0000goIVIV2ol0000Uoda<
C0?o00004?mVIVH3o`0000ooOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooo/_moOgl00ol0003oVIVIoiVIV@0DoiVIV@Co00004?moOgl5o`0001?oIVIV1ol0000Boda<C0co
00004?mVIVH3o`0001;oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
/omoOgl00ol0003oVIVIoiVIV@0GoiVIV@?o00004_moOgl5o`0001GoIVIV4_l0000IofIVIP?o0000
4_moOgl4o`0000Gooooo0Ol00001ooooo`001oooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo00Cooooo]?moOgl00ol0003o
VIVIoiVIV@0IoiVIV@Co00004omoOgl3o`0003SoIVIV1Ol0000@ogmoO`Go00000onIVIT6ooooo`7o
00000Oooool000Oooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01_ooool00ol0003oooooooooo`04oooookGoOgmo00?o0000oiVIVOnIVIT07?nIVIT6o`00
013oOgmo2ol0000PofIVIPgo00004_moOgl3o`0000SoVIVI1_ooool1o`00007ooooo000;ooooo`05
o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`04ooooo`03o`000?oooooooooo
00Cooooo]_moOgl2o`0002;oVIVI0ol0000HogmoOb3o00006omoOgl4o`0000_oVIVI1_ooool1o`00
007ooooo000:ooooo`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`000006oooo
o`?o00001?oooonhogmoO`;o00008onIVIT3o`0004goOgmo0ol0000?oiVIV@Cooooo0ol00001oooo
o`002Oooool00ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool000001_ooool00ol0
003oooooooooo`04oooook[oOgmo00?o0000oiVIVOnIVIT08onIVIT3o`0004GoOgmo1Ol0000BoiVI
V@Kooooo0Ol00001ooooo`002_ooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?oooooooooooooo
ool@41001_ooool00ol0003oooooooooo`04oooook_oOgmo0_l0000VoiVIV@Go0000>_moOgl6o`00
01OoVIVI1_ooool1o`00007ooooo0007ooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?oooonmogmoO`;o0000:OnIVIT=
o`00023oOgmo3Ol0000MoiVIV@Kooooo0Ol00001ooooo`001oooool01OnYZJWo410@o`000?l@413o
ZJVY00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo00Cooooo_omo
Ogl00ol0003oVIVIoiVIV@0coiVIV@go00003?moOgl7o`0002[oVIVI1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00Cooooo`?moOgl2o`00043oVIVI3?l0000aoiVIV@Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04oooool;oOgmo00?o0000oiVIVOnIVIT0N_nIVIT6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooo3ogmoO`?o0000NOnIVIT6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooo6ogmoO`?o0000M_nIVIT6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooo9ogmoO`?o0000LonIVIT6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?ooooo<ogmoO`;o0000L?nIVIT2o`0000Gooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooolkoOgmo0_l0001/oiVIV@;o000000?oOgmooooo
ooooool01?ooool1o`00007ooooo000Jooooo`;o00001Oooooo@ogmoO`;o0000IonIVIT3o`0000?o
Ogmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00Coooood_moOgl3o`0006;oVIVI
0_l00006ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooomGoOgmo0_l0
001OoiVIV@03o`000?moOgooOgmo00KoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CoooooeomoOgl3o`0005[oVIVI0_l00009ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooom[oOgmo0ol0001FoiVIV@03o`000?moOgooOgmo00WoOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CooooogOmoOgl3o`0004ooVIVI1?l0000<ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooon3oOgmo0ol00015oiVIV@Oo0000
4?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooSogmoO`Go0000>onI
VIT5o`0001OoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Coooooj?moOgl7
o`00037oVIVI0ol0000LogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
onooOgmo1_l0000VoiVIV@Go00007omoOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?oooooeogmoO`Oo00006OnIVIT6o`0002CoOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00Coooooo?moOglIo`0002[oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000GooooooomoOgm0
ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000Gooooo
oomoOgm0ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`00
00GooooooomoOgm0ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`002Oooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`00
0?lb<S;ok^k^00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo
000:ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`00
0?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`001oooool5o`0000?ooooo00Go
410@oooooooooooooooooa0@4006ooooo`?o00001?ooooooogmoOd3oOgmo1?ooool3o`00007ooooo
0007ooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo0?ooooooB_ooool1o`00007ooooo0007ooooo`04omgMgOmEEEGoooooo`0000Co
oooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?ooooooB_ooool1o`00
007ooooo0008ooooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooooooooa0@4006oooo
o`03o`000?oooooooooo0?ooooooB_ooool1o`00007ooooo0008ooooo`03onk^k_m4A4Co000000Co
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?ooooooB_ooool1o`00
007ooooo0009ooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06oooo
o`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0moooo
o`03o`000?oooooooooo03gooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Soooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`7o
00000Oooool001[oooooool0001>o`00007ooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-30.1723, -14.304, 0.195672, \
0.195672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0192308 0.211538 0.0192308 [
[.11538 -0.0125 -9 -9 ]
[.11538 -0.0125 9 0 ]
[.30769 -0.0125 -9 -9 ]
[.30769 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69231 -0.0125 -6 -9 ]
[.69231 -0.0125 6 0 ]
[.88462 -0.0125 -6 -9 ]
[.88462 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -18 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .21154 -6 -4.5 ]
[-0.0125 .21154 0 4.5 ]
[-0.0125 .40385 -12 -4.5 ]
[-0.0125 .40385 0 4.5 ]
[-0.0125 .59615 -12 -4.5 ]
[-0.0125 .59615 0 4.5 ]
[-0.0125 .78846 -12 -4.5 ]
[-0.0125 .78846 0 4.5 ]
[-0.0125 .98077 -12 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11538 0 m
.11538 .00625 L
s
[(-20)] .11538 -0.0125 0 1 Mshowa
.30769 0 m
.30769 .00625 L
s
[(-10)] .30769 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69231 0 m
.69231 .00625 L
s
[(10)] .69231 -0.0125 0 1 Mshowa
.88462 0 m
.88462 .00625 L
s
[(20)] .88462 -0.0125 0 1 Mshowa
.125 Mabswid
.15385 0 m
.15385 .00375 L
s
.19231 0 m
.19231 .00375 L
s
.23077 0 m
.23077 .00375 L
s
.26923 0 m
.26923 .00375 L
s
.34615 0 m
.34615 .00375 L
s
.38462 0 m
.38462 .00375 L
s
.42308 0 m
.42308 .00375 L
s
.46154 0 m
.46154 .00375 L
s
.53846 0 m
.53846 .00375 L
s
.57692 0 m
.57692 .00375 L
s
.61538 0 m
.61538 .00375 L
s
.65385 0 m
.65385 .00375 L
s
.73077 0 m
.73077 .00375 L
s
.76923 0 m
.76923 .00375 L
s
.80769 0 m
.80769 .00375 L
s
.84615 0 m
.84615 .00375 L
s
.07692 0 m
.07692 .00375 L
s
.03846 0 m
.03846 .00375 L
s
.92308 0 m
.92308 .00375 L
s
.96154 0 m
.96154 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(-10)] -0.0125 .01923 1 0 Mshowa
0 .21154 m
.00625 .21154 L
s
[(0)] -0.0125 .21154 1 0 Mshowa
0 .40385 m
.00625 .40385 L
s
[(10)] -0.0125 .40385 1 0 Mshowa
0 .59615 m
.00625 .59615 L
s
[(20)] -0.0125 .59615 1 0 Mshowa
0 .78846 m
.00625 .78846 L
s
[(30)] -0.0125 .78846 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(40)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .05769 m
.00375 .05769 L
s
0 .09615 m
.00375 .09615 L
s
0 .13462 m
.00375 .13462 L
s
0 .17308 m
.00375 .17308 L
s
0 .25 m
.00375 .25 L
s
0 .28846 m
.00375 .28846 L
s
0 .32692 m
.00375 .32692 L
s
0 .36538 m
.00375 .36538 L
s
0 .44231 m
.00375 .44231 L
s
0 .48077 m
.00375 .48077 L
s
0 .51923 m
.00375 .51923 L
s
0 .55769 m
.00375 .55769 L
s
0 .63462 m
.00375 .63462 L
s
0 .67308 m
.00375 .67308 L
s
0 .71154 m
.00375 .71154 L
s
0 .75 m
.00375 .75 L
s
0 .82692 m
.00375 .82692 L
s
0 .86538 m
.00375 .86538 L
s
0 .90385 m
.00375 .90385 L
s
0 .94231 m
.00375 .94231 L
s
.25 Mabswid
0 0 m
0 1 L
s
.11538 .99375 m
.11538 1 L
s
.30769 .99375 m
.30769 1 L
s
.5 .99375 m
.5 1 L
s
.69231 .99375 m
.69231 1 L
s
.88462 .99375 m
.88462 1 L
s
.125 Mabswid
.15385 .99625 m
.15385 1 L
s
.19231 .99625 m
.19231 1 L
s
.23077 .99625 m
.23077 1 L
s
.26923 .99625 m
.26923 1 L
s
.34615 .99625 m
.34615 1 L
s
.38462 .99625 m
.38462 1 L
s
.42308 .99625 m
.42308 1 L
s
.46154 .99625 m
.46154 1 L
s
.53846 .99625 m
.53846 1 L
s
.57692 .99625 m
.57692 1 L
s
.61538 .99625 m
.61538 1 L
s
.65385 .99625 m
.65385 1 L
s
.73077 .99625 m
.73077 1 L
s
.76923 .99625 m
.76923 1 L
s
.80769 .99625 m
.80769 1 L
s
.84615 .99625 m
.84615 1 L
s
.07692 .99625 m
.07692 1 L
s
.03846 .99625 m
.03846 1 L
s
.92308 .99625 m
.92308 1 L
s
.96154 .99625 m
.96154 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .21154 m
1 .21154 L
s
.99375 .40385 m
1 .40385 L
s
.99375 .59615 m
1 .59615 L
s
.99375 .78846 m
1 .78846 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .05769 m
1 .05769 L
s
.99625 .09615 m
1 .09615 L
s
.99625 .13462 m
1 .13462 L
s
.99625 .17308 m
1 .17308 L
s
.99625 .25 m
1 .25 L
s
.99625 .28846 m
1 .28846 L
s
.99625 .32692 m
1 .32692 L
s
.99625 .36538 m
1 .36538 L
s
.99625 .44231 m
1 .44231 L
s
.99625 .48077 m
1 .48077 L
s
.99625 .51923 m
1 .51923 L
s
.99625 .55769 m
1 .55769 L
s
.99625 .63462 m
1 .63462 L
s
.99625 .67308 m
1 .67308 L
s
.99625 .71154 m
1 .71154 L
s
.99625 .75 m
1 .75 L
s
.99625 .82692 m
1 .82692 L
s
.99625 .86538 m
1 .86538 L
s
.99625 .90385 m
1 .90385 L
s
.99625 .94231 m
1 .94231 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.4 g
.98077 .79302 m
.96115 .80184 L
.94491 .80416 L
.94152 .8047 L
.9219 .8093 L
.90228 .81403 L
.88265 .81788 L
.86303 .82061 L
.84341 .8222 L
.82378 .82283 L
.80416 .82271 L
.78454 .82178 L
.76491 .81981 L
.74529 .81669 L
.72567 .8125 L
.70604 .80762 L
.6897 .80416 L
.68642 .80324 L
.6668 .79887 L
.64717 .79008 L
.63283 .78454 L
.62755 .78236 L
.60793 .77735 L
.59003 .76491 L
.5883 .76399 L
.56868 .75318 L
.55564 .74529 L
.54906 .74057 L
.52949 .72567 L
.54906 .71233 L
.56868 .71709 L
.5883 .71968 L
.60387 .72567 L
.60793 .72784 L
.62755 .7335 L
.64717 .73461 L
.6668 .74282 L
.6768 .74529 L
.68642 .74754 L
.70604 .75151 L
.72567 .75478 L
.74529 .75412 L
.76491 .75766 L
.78454 .75975 L
.80416 .7608 L
.82378 .76095 L
.84341 .76022 L
.86303 .75851 L
.88265 .75553 L
.90228 .75048 L
.9219 .7527 L
.94152 .74897 L
.95793 .74529 L
.96115 .7446 L
.98077 .73809 L
F
0 g
.98077 .79302 m
.96115 .80184 L
.94491 .80416 L
.94152 .8047 L
.9219 .8093 L
.90228 .81403 L
.88265 .81788 L
.86303 .82061 L
.84341 .8222 L
.82378 .82283 L
.80416 .82271 L
.78454 .82178 L
.76491 .81981 L
.74529 .81669 L
.72567 .8125 L
.70604 .80762 L
.6897 .80416 L
.68642 .80324 L
.6668 .79887 L
.64717 .79008 L
.63283 .78454 L
.62755 .78236 L
.60793 .77735 L
.59003 .76491 L
.5883 .76399 L
.56868 .75318 L
.55564 .74529 L
.54906 .74057 L
.52949 .72567 L
.54906 .71233 L
.56868 .71709 L
.5883 .71968 L
.60387 .72567 L
.60793 .72784 L
.62755 .7335 L
.64717 .73461 L
.6668 .74282 L
.6768 .74529 L
.68642 .74754 L
.70604 .75151 L
.72567 .75478 L
.74529 .75412 L
.76491 .75766 L
.78454 .75975 L
.80416 .7608 L
.82378 .76095 L
.84341 .76022 L
.86303 .75851 L
.88265 .75553 L
.90228 .75048 L
Mistroke
.9219 .7527 L
.94152 .74897 L
.95793 .74529 L
.96115 .7446 L
.98077 .73809 L
Mfstroke
.6 g
.98077 .72732 m
.96115 .73482 L
.94152 .74463 L
.9219 .74285 L
.90909 .74529 L
.90228 .74562 L
.88265 .74809 L
.86303 .75055 L
.84341 .75227 L
.82378 .75307 L
.80416 .75291 L
.78454 .75179 L
.76491 .74978 L
.74529 .74717 L
.72567 .74531 L
.72555 .74529 L
.70604 .74147 L
.68642 .74085 L
.6668 .73206 L
.64744 .72567 L
.64717 .72558 L
.62755 .71861 L
.60793 .71345 L
.59646 .70604 L
.5883 .70207 L
.56868 .69216 L
.55826 .68642 L
.54906 .6797 L
.53108 .6668 L
.54906 .65799 L
.56868 .66057 L
.5883 .66374 L
.60165 .6668 L
.60793 .66919 L
.62755 .6738 L
.64717 .67353 L
.6668 .68286 L
.68642 .68562 L
.69093 .68642 L
.70604 .68905 L
.72567 .6919 L
.74529 .68751 L
.76491 .69255 L
.78454 .69519 L
.80416 .69648 L
.82378 .69666 L
.84341 .69577 L
.86303 .69363 L
.88265 .68965 L
.90228 .69273 L
.9219 .69008 L
.94152 .68683 L
.94366 .68642 L
.96115 .68504 L
.98077 .67753 L
F
0 g
.98077 .72732 m
.96115 .73482 L
.94152 .74463 L
.9219 .74285 L
.90909 .74529 L
.90228 .74562 L
.88265 .74809 L
.86303 .75055 L
.84341 .75227 L
.82378 .75307 L
.80416 .75291 L
.78454 .75179 L
.76491 .74978 L
.74529 .74717 L
.72567 .74531 L
.72555 .74529 L
.70604 .74147 L
.68642 .74085 L
.6668 .73206 L
.64744 .72567 L
.64717 .72558 L
.62755 .71861 L
.60793 .71345 L
.59646 .70604 L
.5883 .70207 L
.56868 .69216 L
.55826 .68642 L
.54906 .6797 L
.53108 .6668 L
.54906 .65799 L
.56868 .66057 L
.5883 .66374 L
.60165 .6668 L
.60793 .66919 L
.62755 .6738 L
.64717 .67353 L
.6668 .68286 L
.68642 .68562 L
.69093 .68642 L
.70604 .68905 L
.72567 .6919 L
.74529 .68751 L
.76491 .69255 L
.78454 .69519 L
.80416 .69648 L
.82378 .69666 L
.84341 .69577 L
.86303 .69363 L
.88265 .68965 L
.90228 .69273 L
Mistroke
.9219 .69008 L
.94152 .68683 L
.94366 .68642 L
.96115 .68504 L
.98077 .67753 L
Mfstroke
.4 g
.98077 .6683 m
.96115 .67897 L
.94152 .67791 L
.9219 .68182 L
.90228 .68517 L
.89393 .68642 L
.88265 .68697 L
.86303 .68896 L
.84341 .6906 L
.82378 .69141 L
.80416 .69124 L
.78454 .69013 L
.76491 .68828 L
.74529 .6865 L
.74073 .68642 L
.72567 .6841 L
.70604 .68055 L
.68642 .67646 L
.6668 .67443 L
.64916 .6668 L
.64717 .66613 L
.62755 .65927 L
.60793 .65202 L
.59606 .64717 L
.5883 .64288 L
.56868 .63149 L
.56239 .62755 L
.56868 .61653 L
.5883 .61692 L
.60793 .61936 L
.62755 .61965 L
.64717 .62581 L
.65746 .62755 L
.6668 .62928 L
.68642 .63237 L
.70604 .63503 L
.72567 .63388 L
.74529 .64035 L
.76491 .64504 L
.78454 .64164 L
.80416 .64221 L
.82378 .64229 L
.84341 .64189 L
.86303 .64648 L
.88265 .64204 L
.90228 .6365 L
.9219 .63584 L
.94152 .63332 L
.96115 .63038 L
.97775 .62755 L
.98077 .62699 L
F
0 g
.98077 .6683 m
.96115 .67897 L
.94152 .67791 L
.9219 .68182 L
.90228 .68517 L
.89393 .68642 L
.88265 .68697 L
.86303 .68896 L
.84341 .6906 L
.82378 .69141 L
.80416 .69124 L
.78454 .69013 L
.76491 .68828 L
.74529 .6865 L
.74073 .68642 L
.72567 .6841 L
.70604 .68055 L
.68642 .67646 L
.6668 .67443 L
.64916 .6668 L
.64717 .66613 L
.62755 .65927 L
.60793 .65202 L
.59606 .64717 L
.5883 .64288 L
.56868 .63149 L
.56239 .62755 L
.56868 .61653 L
.5883 .61692 L
.60793 .61936 L
.62755 .61965 L
.64717 .62581 L
.65746 .62755 L
.6668 .62928 L
.68642 .63237 L
.70604 .63503 L
.72567 .63388 L
.74529 .64035 L
.76491 .64504 L
.78454 .64164 L
.80416 .64221 L
.82378 .64229 L
.84341 .64189 L
.86303 .64648 L
.88265 .64204 L
.90228 .6365 L
.9219 .63584 L
.94152 .63332 L
.96115 .63038 L
.97775 .62755 L
Mistroke
.98077 .62699 L
Mfstroke
.6 g
.98077 .85551 m
.96115 .86284 L
.96061 .86303 L
.94152 .87094 L
.9219 .87497 L
.90228 .87936 L
.88367 .88265 L
.88265 .88281 L
.86303 .88556 L
.84341 .88747 L
.82378 .88838 L
.80416 .88819 L
.78454 .88692 L
.76491 .88471 L
.75073 .88265 L
.74529 .88174 L
.72567 .87798 L
.70604 .87833 L
.68642 .86798 L
.67393 .86303 L
.6668 .86046 L
.64717 .85276 L
.62755 .84374 L
.62701 .84341 L
.60793 .83362 L
.59064 .82378 L
.5883 .82189 L
.56868 .80801 L
.56258 .80416 L
.56868 .79221 L
.5883 .79684 L
.60793 .80232 L
.61443 .80416 L
.62755 .80861 L
.64717 .8148 L
.6668 .82022 L
.68189 .82378 L
.68642 .82517 L
.70604 .83007 L
.72567 .83413 L
.74529 .83735 L
.76491 .83975 L
.78454 .84139 L
.80416 .84226 L
.82378 .84239 L
.84341 .84177 L
.86303 .8404 L
.88265 .83825 L
.90228 .83532 L
.9219 .83154 L
.94152 .82692 L
.95293 .82378 L
.96115 .8219 L
.98077 .81673 L
F
0 g
.98077 .85551 m
.96115 .86284 L
.96061 .86303 L
.94152 .87094 L
.9219 .87497 L
.90228 .87936 L
.88367 .88265 L
.88265 .88281 L
.86303 .88556 L
.84341 .88747 L
.82378 .88838 L
.80416 .88819 L
.78454 .88692 L
.76491 .88471 L
.75073 .88265 L
.74529 .88174 L
.72567 .87798 L
.70604 .87833 L
.68642 .86798 L
.67393 .86303 L
.6668 .86046 L
.64717 .85276 L
.62755 .84374 L
.62701 .84341 L
.60793 .83362 L
.59064 .82378 L
.5883 .82189 L
.56868 .80801 L
.56258 .80416 L
.56868 .79221 L
.5883 .79684 L
.60793 .80232 L
.61443 .80416 L
.62755 .80861 L
.64717 .8148 L
.6668 .82022 L
.68189 .82378 L
.68642 .82517 L
.70604 .83007 L
.72567 .83413 L
.74529 .83735 L
.76491 .83975 L
.78454 .84139 L
.80416 .84226 L
.82378 .84239 L
.84341 .84177 L
.86303 .8404 L
.88265 .83825 L
.90228 .83532 L
.9219 .83154 L
Mistroke
.94152 .82692 L
.95293 .82378 L
.96115 .8219 L
.98077 .81673 L
Mfstroke
.6 g
.98077 .61208 m
.96115 .61723 L
.94152 .6219 L
.9219 .62611 L
.91452 .62755 L
.90228 .62983 L
.88265 .63502 L
.86303 .6413 L
.84341 .63444 L
.82378 .63494 L
.80416 .63484 L
.78454 .63414 L
.76491 .63905 L
.74529 .63312 L
.72567 .62843 L
.72011 .62755 L
.70604 .62474 L
.68642 .62036 L
.6668 .61554 L
.64717 .61017 L
.63986 .60793 L
.62755 .60225 L
.60793 .59239 L
.60051 .5883 L
.60793 .58108 L
.62755 .58018 L
.64717 .58142 L
.6668 .58331 L
.68642 .58543 L
.70604 .5876 L
.71267 .5883 L
.72567 .58957 L
.74529 .59114 L
.76491 .59233 L
.78454 .59315 L
.80416 .59359 L
.82378 .59365 L
.84341 .59334 L
.86303 .59265 L
.88265 .59159 L
.90228 .59015 L
.9219 .58832 L
.92202 .5883 L
.94152 .58618 L
.96115 .58307 L
.98077 .58202 L
F
0 g
.98077 .61208 m
.96115 .61723 L
.94152 .6219 L
.9219 .62611 L
.91452 .62755 L
.90228 .62983 L
.88265 .63502 L
.86303 .6413 L
.84341 .63444 L
.82378 .63494 L
.80416 .63484 L
.78454 .63414 L
.76491 .63905 L
.74529 .63312 L
.72567 .62843 L
.72011 .62755 L
.70604 .62474 L
.68642 .62036 L
.6668 .61554 L
.64717 .61017 L
.63986 .60793 L
.62755 .60225 L
.60793 .59239 L
.60051 .5883 L
.60793 .58108 L
.62755 .58018 L
.64717 .58142 L
.6668 .58331 L
.68642 .58543 L
.70604 .5876 L
.71267 .5883 L
.72567 .58957 L
.74529 .59114 L
.76491 .59233 L
.78454 .59315 L
.80416 .59359 L
.82378 .59365 L
.84341 .59334 L
.86303 .59265 L
.88265 .59159 L
.90228 .59015 L
.9219 .58832 L
.92202 .5883 L
.94152 .58618 L
.96115 .58307 L
.98077 .58202 L
s
.7 g
.98077 .7126 m
.96115 .72095 L
.94871 .72567 L
.94152 .7311 L
.9219 .73304 L
.90228 .73723 L
.88265 .74056 L
.86303 .74305 L
.84341 .74467 L
.82945 .74529 L
.82378 .74542 L
.80515 .74529 L
.80416 .74526 L
.78454 .74422 L
.76491 .7423 L
.74529 .73953 L
.72567 .73591 L
.70604 .7314 L
.68642 .72598 L
.68593 .72567 L
.6668 .71825 L
.64717 .70938 L
.64083 .70604 L
.64717 .69426 L
.6668 .69471 L
.68642 .69641 L
.70604 .6983 L
.72567 .7001 L
.74529 .69585 L
.76491 .70063 L
.78454 .70274 L
.80416 .70367 L
.82378 .7038 L
.84341 .70316 L
.86303 .70153 L
.88265 .69801 L
.90228 .70067 L
.9219 .69893 L
.94152 .69705 L
.96115 .69523 L
.98077 .6941 L
F
0 g
.98077 .7126 m
.96115 .72095 L
.94871 .72567 L
.94152 .7311 L
.9219 .73304 L
.90228 .73723 L
.88265 .74056 L
.86303 .74305 L
.84341 .74467 L
.82945 .74529 L
.82378 .74542 L
.80515 .74529 L
.80416 .74526 L
.78454 .74422 L
.76491 .7423 L
.74529 .73953 L
.72567 .73591 L
.70604 .7314 L
.68642 .72598 L
.68593 .72567 L
.6668 .71825 L
.64717 .70938 L
.64083 .70604 L
.64717 .69426 L
.6668 .69471 L
.68642 .69641 L
.70604 .6983 L
.72567 .7001 L
.74529 .69585 L
.76491 .70063 L
.78454 .70274 L
.80416 .70367 L
.82378 .7038 L
.84341 .70316 L
.86303 .70153 L
.88265 .69801 L
.90228 .70067 L
.9219 .69893 L
.94152 .69705 L
.96115 .69523 L
.98077 .6941 L
s
.3 g
.6668 .76228 m
.68642 .76279 L
.70604 .76448 L
.71167 .76491 L
.72567 .76669 L
.74529 .76874 L
.76491 .77036 L
.78454 .77148 L
.80416 .77209 L
.82378 .77218 L
.84341 .77175 L
.86303 .7708 L
.88265 .76934 L
.90228 .76743 L
.9219 .76516 L
.92397 .76491 L
.94152 .76331 L
.96115 .76215 L
.97727 .76491 L
.96115 .77679 L
.94502 .78454 L
.94152 .78583 L
.9219 .79215 L
.90228 .79716 L
.88265 .8011 L
.86303 .80402 L
.86229 .80416 L
.84341 .80673 L
.82378 .80816 L
.80416 .80786 L
.78454 .80591 L
.77184 .80416 L
.76491 .80314 L
.74529 .79987 L
.72567 .79558 L
.70604 .79017 L
.68956 .78454 L
.68642 .78311 L
.6668 .77301 L
.65748 .76491 L
F
0 g
.6668 .76228 m
.68642 .76279 L
.70604 .76448 L
.71167 .76491 L
.72567 .76669 L
.74529 .76874 L
.76491 .77036 L
.78454 .77148 L
.80416 .77209 L
.82378 .77218 L
.84341 .77175 L
.86303 .7708 L
.88265 .76934 L
.90228 .76743 L
.9219 .76516 L
.92397 .76491 L
.94152 .76331 L
.96115 .76215 L
.97727 .76491 L
.96115 .77679 L
.94502 .78454 L
.94152 .78583 L
.9219 .79215 L
.90228 .79716 L
.88265 .8011 L
.86303 .80402 L
.86229 .80416 L
.84341 .80673 L
.82378 .80816 L
.80416 .80786 L
.78454 .80591 L
.77184 .80416 L
.76491 .80314 L
.74529 .79987 L
.72567 .79558 L
.70604 .79017 L
.68956 .78454 L
.68642 .78311 L
.6668 .77301 L
.65748 .76491 L
.6668 .76228 L
s
.3 g
.6668 .64557 m
.68642 .64475 L
.70604 .64544 L
.72567 .64574 L
.73753 .64717 L
.74529 .6477 L
.76491 .64876 L
.78454 .64951 L
.80416 .64992 L
.82378 .64998 L
.84341 .64969 L
.86303 .64905 L
.88265 .64809 L
.89738 .64717 L
.90228 .64669 L
.9219 .64578 L
.94152 .6449 L
.96115 .64495 L
.97448 .64717 L
.96115 .65859 L
.94365 .6668 L
.94152 .66741 L
.9219 .67243 L
.90228 .67648 L
.88265 .67971 L
.86303 .68213 L
.84341 .68372 L
.82378 .68444 L
.80416 .68429 L
.78454 .68327 L
.76491 .6814 L
.74529 .6787 L
.72567 .6752 L
.70604 .67085 L
.69094 .6668 L
.68642 .66489 L
.6668 .65461 L
.6589 .64717 L
F
0 g
.6668 .64557 m
.68642 .64475 L
.70604 .64544 L
.72567 .64574 L
.73753 .64717 L
.74529 .6477 L
.76491 .64876 L
.78454 .64951 L
.80416 .64992 L
.82378 .64998 L
.84341 .64969 L
.86303 .64905 L
.88265 .64809 L
.89738 .64717 L
.90228 .64669 L
.9219 .64578 L
.94152 .6449 L
.96115 .64495 L
.97448 .64717 L
.96115 .65859 L
.94365 .6668 L
.94152 .66741 L
.9219 .67243 L
.90228 .67648 L
.88265 .67971 L
.86303 .68213 L
.84341 .68372 L
.82378 .68444 L
.80416 .68429 L
.78454 .68327 L
.76491 .6814 L
.74529 .6787 L
.72567 .6752 L
.70604 .67085 L
.69094 .6668 L
.68642 .66489 L
.6668 .65461 L
.6589 .64717 L
.6668 .64557 L
s
.4 g
.6668 .54889 m
.68642 .54763 L
.70604 .54796 L
.72567 .54876 L
.73266 .54906 L
.74529 .54967 L
.76491 .55044 L
.78454 .55098 L
.80416 .55128 L
.82378 .55133 L
.84341 .55111 L
.86303 .55065 L
.88265 .54995 L
.90228 .54907 L
.90245 .54906 L
.9219 .54821 L
.94152 .54766 L
.96115 .54811 L
.9688 .54906 L
.96115 .55906 L
.94152 .56803 L
.9397 .56868 L
.9219 .57211 L
.90228 .57523 L
.88265 .57775 L
.86303 .57967 L
.84341 .58095 L
.82378 .58154 L
.80416 .58142 L
.78454 .58059 L
.76491 .57909 L
.74529 .57696 L
.72567 .57424 L
.70604 .5709 L
.6949 .56868 L
.68642 .56541 L
.6668 .55446 L
.66569 .54906 L
F
0 g
.6668 .54889 m
.68642 .54763 L
.70604 .54796 L
.72567 .54876 L
.73266 .54906 L
.74529 .54967 L
.76491 .55044 L
.78454 .55098 L
.80416 .55128 L
.82378 .55133 L
.84341 .55111 L
.86303 .55065 L
.88265 .54995 L
.90228 .54907 L
.90245 .54906 L
.9219 .54821 L
.94152 .54766 L
.96115 .54811 L
.9688 .54906 L
.96115 .55906 L
.94152 .56803 L
.9397 .56868 L
.9219 .57211 L
.90228 .57523 L
.88265 .57775 L
.86303 .57967 L
.84341 .58095 L
.82378 .58154 L
.80416 .58142 L
.78454 .58059 L
.76491 .57909 L
.74529 .57696 L
.72567 .57424 L
.70604 .5709 L
.6949 .56868 L
.68642 .56541 L
.6668 .55446 L
.66569 .54906 L
.6668 .54889 L
s
.7 g
.72567 .6077 m
.74529 .6055 L
.76491 .60502 L
.78454 .60494 L
.80416 .60496 L
.82378 .60497 L
.84341 .60495 L
.86303 .60497 L
.88265 .60525 L
.90228 .60651 L
.9101 .60793 L
.90228 .61253 L
.88265 .61838 L
.86303 .62213 L
.84341 .62442 L
.82378 .62542 L
.80416 .62522 L
.78454 .62379 L
.76491 .62103 L
.74529 .6167 L
.72567 .60898 L
.72479 .60793 L
F
0 g
.72567 .6077 m
.74529 .6055 L
.76491 .60502 L
.78454 .60494 L
.80416 .60496 L
.82378 .60497 L
.84341 .60495 L
.86303 .60497 L
.88265 .60525 L
.90228 .60651 L
.9101 .60793 L
.90228 .61253 L
.88265 .61838 L
.86303 .62213 L
.84341 .62442 L
.82378 .62542 L
.80416 .62522 L
.78454 .62379 L
.76491 .62103 L
.74529 .6167 L
.72567 .60898 L
.72479 .60793 L
.72567 .6077 L
s
.8 g
.74529 .71408 m
.76491 .71375 L
.78454 .71389 L
.80416 .71404 L
.82378 .71406 L
.84341 .71395 L
.86303 .71378 L
.88265 .71385 L
.89662 .72567 L
.88265 .72889 L
.86303 .73216 L
.84341 .7342 L
.82378 .73512 L
.80416 .73493 L
.78454 .73364 L
.76491 .7312 L
.74529 .72745 L
.73803 .72567 L
F
0 g
.74529 .71408 m
.76491 .71375 L
.78454 .71389 L
.80416 .71404 L
.82378 .71406 L
.84341 .71395 L
.86303 .71378 L
.88265 .71385 L
.89662 .72567 L
.88265 .72889 L
.86303 .73216 L
.84341 .7342 L
.82378 .73512 L
.80416 .73493 L
.78454 .73364 L
.76491 .7312 L
.74529 .72745 L
.73803 .72567 L
.74529 .71408 L
s
.2 g
.76491 .66252 m
.78454 .66117 L
.80416 .6608 L
.82378 .66076 L
.84341 .66099 L
.86303 .66184 L
.87998 .6668 L
.86303 .67031 L
.84341 .6727 L
.82378 .67373 L
.80416 .67352 L
.78454 .67205 L
.76491 .66912 L
.75454 .6668 L
F
0 g
.76491 .66252 m
.78454 .66117 L
.80416 .6608 L
.82378 .66076 L
.84341 .66099 L
.86303 .66184 L
.87998 .6668 L
.86303 .67031 L
.84341 .6727 L
.82378 .67373 L
.80416 .67352 L
.78454 .67205 L
.76491 .66912 L
.75454 .6668 L
.76491 .66252 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00?Oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0dooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kS?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0hooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8b
onk^kS?ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08_ooool003gooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0=_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0<oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg03?ooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL08_ooool003Gooooo1_l0
0003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400[ooooo`Ko0000
1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100<oooool01Ol@413o
oooooooooooooooo410@03[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@03Cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@02;ooooo000o
ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000fooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000cooooo`05o`000?ooooooooooooooool0
0000>_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000=Oooool00onH
V9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000008_ooool0043ooooo00?oMgMgofIV
I_ooool00_ooool01Ol0003ooooooooooooooooo000003Kooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000003?ooooo00Go0000ooooooooooooooooo`00000jooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`03ogMgMomVIVKooooo00;o
oooo00Go0000ooooooooooooooooo`00000Rooooo`00@Oooool01Ol0003ooooooooooooooooo410@
00?ooooo00?o410@ooooooooool0=?ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@4100<oooool01Ol@413ooooooooooooooooo410@03[ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@03Oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo023ooooo000mooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg03Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg03?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0jooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0cooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02;ooooo000mooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^03Cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^03?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`03oeEEEOmVIVKo000000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0cooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02;ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo000Joooooooo0000C_l00001ooooo`00
6_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0?Ooo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool08ooo
ool1o`00007ooooo0008ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKo
oooo00?o0000ooooooooool0oooooom:ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooom:ooooo`7o
00000Oooool000Go00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41001_ooool00ol0003oooooooooo`3ooooood[ooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?ooooooB?ooool3o`00007o
oooo000:ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo0008ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Oooooooogmo
Od3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Ooo
ooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000oooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`003ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000?ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000oooooo00Go0000oooooooooooooooo
o`000006ooooo`?o00001?ooooooogmoOd3oOgmo1?ooool3o`00007ooooo000?ooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool000oooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`003oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000?ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo0008
ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000:ooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`002_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41001_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000[ooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo0ol00004oooooooo
Ogmo@?moOgl4ooooo`?o00000Oooool000[ooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000:ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool000Sooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooomKoOgmo9_l0000OogmoOb7o00000omoOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?oooooFogmoO`03o`000?mVIVKoIVIV02?oIVIV7ol0000OofIVIP03
o`000?moOgooOgmo00;oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
eomoOgl2o`00063oIVIV00?o0000ogmoOomoOgl00omoOgl6ooooo`7o00000Oooool001[ooooo0_l0
0005ooooomWoOgmo0_l0001LofIVIP;o00001_moOgl5ooooo`;o00000Oooool001[ooooo00?o0000
ooooooooool01?oooooKogmoO`;o0000F?mVIVH2o`0000SoOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CooooogOmoOgl2o`0005CoIVIV0_l0000:ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooomooOgmo00?o0000ofIVI_mVIVH0D?mVIVH00ol0003o
OgmoogmoO`0:ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooon3oOgmo
2?l00016ofIVIPCo00003OmoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
oooXogmoO`Oo0000>OmVIVH6o`00017oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CoooookomoOgl6o`0002goIVIV1_l0000GogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooolOoOgmo1ol0000WogmoO`go00004omVIVH=o`0001goOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00Cooooo`omoOgl4o`0000OoVIVI3Ol0000WogmoOa?o
00008?moOgl;o`0000Gooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooool;oOgmo
00?o0000oiVIVOnIVIT05_nIVIT7o`0004goOgmo1_l0000:oiVIV@Kooooo0Ol00001ooooo`001ooo
ool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo00Cooooo
`OmoOgl2o`0001ooVIVI3Ol0000iogmoO`Oo00004?nIVIT6ooooo`7o00000Oooool000Oooooo00Go
V9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003o
ooooooooo`04oooool?oOgmo0_l0000ZoiVIV@go00006OmoOglCo`0001OoVIVI1_ooool1o`00007o
oooo0008ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4006ooooo`03
o`000?oooooooooo00CoooooaOmoOgl2o`0003GoVIVI6Ol0000ZoiVIV@Kooooo0Ol00001ooooo`00
2Oooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000001_ooool3o`0000Co
ooooaomoOgl00ol0003oVIVIoiVIV@1eoiVIV@Cooooo0ol00001ooooo`002_ooool00omgMgOoIVIV
ooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`04ooooolSo
Ogmo0_l0001eoiVIV@Kooooo0Ol00001ooooo`002oooool01Ol0003ooooooooooooooooo410@00?o
oooo00?o410@ooooooooool01?ooool00ol0003oooooooooo`04oooool[oOgmo0_l0001coiVIV@Ko
oooo0Ol00001ooooo`001oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`06ooooo`03o`000?oooooooooo00Coooooc?moOgl2o`0001coVIVI?Ol0000HoiVI
V@Kooooo0Ol00001ooooo`001oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo00Coooooc_moOgl5o`0001OoVIVI0ol0000i
ok>c/`;o00005onIVIT6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooCogmo
O`?o00005onIVIT3o`0003?o/k>c0ol0000GoiVIV@?o00001Oooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00Cooooo]_moOgl5o`0001_oOgmo1?l0000FoiVIV@Co0000;?nc/k<3o`0001Oo
VIVI0ol00002ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooookKoOgmo
00?o0000ofIVI_mVIVH00_mVIVHBo`0000goOgmo0ol0000GoiVIV@?o00009?nc/k<5o`0001GoVIVI
1Ol00005ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooookGoOgmo00?o
0000ofIVI_mVIVH05OmVIVH3o`0000goOgmo1Ol0000EoiVIV@Go00006Onc/k<6o`0001GoVIVI1Ol0
000:ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooookGoOgmo00?o0000
ofIVI_mVIVH06?mVIVH3o`0000ooOgmo1Ol0000EoiVIVAWo00006?nIVIT3o`0000ooOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo]?moOgl2o`0001goIVIV1?l0000@ogmo
O`Ko0000>_nIVIT6o`0000koOgmo1Ol00005ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?oooonfogmoO`;o00007omVIVH4o`0001;oOgmo0ol0000coiVIV@Co00003_moOgl6o`0000Co
IVIV1_ooool1o`00007ooooo000Jooooo`;o00001OoooonhogmoO`;o00008OmVIVH7o`0000GoOgmo
1_l00003ogmoO`Co00002?nIVIT=o`0000GoVIVI1Ol0000=oiVIV@?o00003?moOgl6o`0000[oIVIV
1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo^_moOgl00ol0003oIVIVofIV
IP0UofIVIPGo00001_mVIVH3o`0000CoOgmo0ol00002oiVIV@?o00003OmoOgl5o`0000GoOgmo0ol0
0007oiVIV@?o00000omoOgl<o`00013oIVIV1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00Cooooo^omoOgl2o`0003?oIVIV1?l00003ogmoO`;o00007OmoOgl2o`0000;oVIVI0ol00003
ogmoO`?o00007?mVIVH6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonmogmo
O`03o`000?mVIVKoIVIV03CoIVIV0ol00004ogmoOa_o00000_moOgl2o`000003ogmoOol0003o0000
00?o00007omVIVH6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonnogmoO`03
o`000?mVIVKoIVIV01GoIVIV5ol0000:ofIVIPCo00006omVIVH5o`0000WoIVIV6?l00003ofIVIPKo
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooookooOgmo0ol0000BofIVIP;o0000
5om<C4`Eo`0000coIVIV5_l0000Hoda<C0;o000000?oIVIVooooooooool01?ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00Cooooo`_moOgl3o`00017oIVIV00?o0000oda<C?m<C4`0:Om<
C4`<o`0002coC4a<0_l00003ofIVIPKooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooolGoOgmo0ol0000?ofIVIP;o0000H?m<C4`00ol0003oIVIVofIVIP03ofIVIPKooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooojooOgmo1Ol0000DogmoO`;o00003omVIVH2o`00
05coC4a<0_l00006ofIVIPKooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooojgo
Ogmo0_l00005oiVIV@Oo00003omoOgl3o`0000koIVIV0_l0000Noda<C1oo00006om<C4`2o`0000So
IVIV1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooZomoOgl2o`0000koVIVI
1Ol0000=ogmoO`?o00003OmVIVH2o`0001OoC4a<1Ol0000Ooc<c<`?o00005om<C4`00ol0003oIVIV
ofIVIP08ofIVIPKooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooj[oOgmo0_l0
000DoiVIV@?o00003OmoOgl3o`0000coIVIV1?l0000Aoda<C0?o00009?lc<c<3o`0001;oC4a<1?l0
000;ofIVIPKooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooojcoOgmo00?o0000
oiVIVOnIVIT05?nIVIT5o`0000_oOgmo0_l0000>ofIVIPCo00004?m<C4`5o`0001Wo<c<c1_l0000B
oda<C0?o00003_mVIVH2o`0000Gooooo0Ol00001ooooo`006_ooool2o`0000Gooooo[OmoOgl2o`00
01WoVIVI2_l00003ogmoO`;o00004?mVIVH3o`0001;oC4a<6Ol0000Coda<C0Go00003_mVIVH3o`00
0003ogmoOooooooooooo00?ooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04ooooojoo
Ogmo00?o0000oiVIVOnIVIT08?nIVIT3o`0000;oOgmo2Ol0000:ofIVIPGo0000<om<C4`6o`00017o
IVIV0_l00004ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooook3oOgmo
00?o0000oiVIVOnIVIT08_nIVIT2o`0000WoOgmo0ol0000<ofIVIPKo00009_m<C4`7o`0000goIVIV
2_l00004ogmoO`?o00001Oooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo/Omo
Ogl00ol0003oVIVIoiVIV@0SoiVIV@Co00002?moOgl5o`0000goIVIV1ol0000Ioda<C0Ko00003OmV
IVH7o`0000_oOgmo0ol00002oiVIV@Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
oooook;oOgmo00?o0000oiVIVOnIVIT09_nIVIT4o`0000WoOgmo1_l0000>ofIVIQWo00003omVIVH4
o`0000koOgmo1?l00005oiVIV@Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
ok?oOgmo0_l0000ZoiVIV@Wo00001_moOgl>o`0001WoIVIV3ol0000;ogmoO`Oo00002OnIVIT6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooneogmoO`03o`000?nIVIWoVIVI033o
VIVI1_l00006oiVIV@?o00001OmoOglIo`0000KoOgmo2?l00005ogmoO`Oo00004?nIVIT6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?oooonfogmoO`;o00006?nIVIT;o`0001coVIVI
1Ol0000IogmoO`Ko00002?nIVIT5o`0001CoVIVI1?l00005ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?oooonhogmoO`?o00005OnIVIT00ol0003o/k>cok>c/`08ok>c/`Oo00003?nI
VIT7o`0000OoVIVI6Ol00008oiVIV@Ko00003?nIVIT=o`0000?o/k>c1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00Cooooo^omoOgl2o`0001;oVIVI00?o0000ok>c/onc/k<04?nc/k<<
o`0000Oo/k>c1ol0000NoiVIV@?o00001_nc/k<<o`00013o/k>c1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00Cooooo_OmoOgl2o`00013oVIVI00?o0000ok>c/onc/k<0:_nc/k<No`00
02Go/k>c1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo_omoOgl2o`0000go
VIVI0_l0001_ok>c/`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooool7oOgmo
00?o0000oiVIVOnIVIT03?nIVIT2o`0006go/k>c1_ooool1o`00007ooooo000Jooooo`;o00001Ooo
oon_ogmoO`Co00003omoOgl00ol0003oVIVIoiVIV@0=oiVIV@?o0000JOnc/k<2o`0000Cooooo0_l0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooojkoOgmo00?o0000ofIVI_mVIVH00_mVIVH3
o`0000goOgmo1Ol0000=oiVIV@;o00006_nc/k<_o`0001_o/k>c0ol000000onIVIWoooooooooo`04
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon/ogmoO`;o00002?mVIVH5o`00
00goOgmo1?l0000;oiVIV@;o00006?nc/k<00ol0003oc<c<olc<c00/olc<c003o`000?nc/k?o/k>c
01Ko/k>c0_l00004oiVIV@Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooj_o
Ogmo00?o0000ofIVI_mVIVH03OmVIVH4o`0000goOgmo0_l0000;oiVIV@;o00005Onc/k<00ol0003o
c<c<olc<c00^olc<c003o`000?nc/k?o/k>c01?o/k>c0_l00006oiVIV@Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04oooooj[oOgmo00?o0000ofIVI_mVIVH04_mVIVH3o`0000coOgmo
0_l0000;oiVIV@;o00004_nc/k<00ol0003oc<c<olc<c00`olc<c003o`000?nc/k?o/k>c013o/k>c
0_l00008oiVIV@Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooojWoOgmo0_l0
000GofIVIPCo00002_moOgl3o`0000[oVIVI0ol0000>ok>c/`Ko0000;Oo<c<`3o`0000oo/k>c0_l0
0009oiVIV@;o00001Oooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooZomoOgl0
0ol0003oIVIVofIVIP0HofIVIP?o00002_moOgl3o`0000[oVIVI0ol0000Aok>c/`?o00009?o<c<`6
o`0000ko/k>c1?l00008oiVIV@?o000000?oOgmoooooooooool01?ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00Cooooo[?moOgl2o`0001_oIVIV1Ol00008ogmoO`?o00002_nIVIT5o`00
00oo/k>c2ol0000<olc<c0go00003onc/k<5o`0000[oVIVI0_l00004ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooojkoOgmo00?o0000ofIVI_mVIVH07OmVIVH5o`0000Ko
Ogmo0_l0000=oiVIV@Oo00004onc/k<<o`0001Wo/k>c0ol0000=oiVIV@;o00001_moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?oooon_ogmoO`03o`000?mVIVKoIVIV027oIVIV
0ol00005ogmoO`;o00004_nIVIT6o`0002go/k>c1Ol0000>oiVIV@;o00001_moOgl3o`0000Gooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooook3oOgmo0_l0000TofIVIPCo00000omo
Ogl;o`0000goVIVI1ol0000Iok>c/`go00001onIVIT7o`0000?oVIVI0_l00005ogmoO`?o00000_mV
IVH6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonbogmoO`;o00009_mVIVH3
o`0000_oOgmo1ol0000=oiVIVAWo00003OnIVIT7o`0000OoOgmo0ol00002ogmoO`Go00001OmVIVH6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooondogmoO`03o`000?mVIVKoIVIV
02KoIVIV1Ol0000=ogmoO`Ko00009_nIVIT7o`0000koOgmo1Ol0000:ofIVIPKooooo0Ol00001oooo
o`006_ooool2o`0000Gooooo]OmoOgl00ol0003oIVIVofIVIP0ZofIVIPKo00003OmoOgl=o`0001?o
VIVI1_l00008ogmoO`Ko00001?moOgl3o`0000ooIVIV1Oooool2o`00007ooooo000Jooooo`03o`00
0?oooooooooo00Cooooo]_moOgl2o`00033oIVIV3Ol0000=ogmoOa?o00002omoOgl3o`0000KoIVIV
1?l0000BofIVIPKooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooookSoOgmo0ol0
000jofIVIPOo00007omoOgl5o`0001ooIVIV1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00Cooooo^omoOgl2o`0003ooIVIV7ol0000TofIVIPKooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04oooookgoOgmo00?o0000ofIVI_mVIVH05_mVIVH<o`0004goIVIV3Ol00003ofIV
IPKooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooookgoOgmo0_l0000EofIVIP;o
00003?m<C4`=o`0003WoIVIV1ol0000=oda<C0?o00001_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00Cooooo_omoOgl00ol0003oIVIVofIVIP0DofIVIP03o`000?m<C4coC4a<01KoC4a<
1_l0000VofIVIPgo00005?m<C4`00ol0003oIVIVofIVIP06ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?ooooo0ogmoO`;o00005OmVIVH2o`0001coC4a<9_l0000Ooda<C0;o00000omV
IVH6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooo2ogmoO`03o`000?mVIVKo
IVIV01CoIVIV00?o0000oda<C?m<C4`0GOm<C4`00ol0003oIVIVofIVIP03ofIVIPKooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04oooool?oOgmo1Ol0000BofIVIP;o0000Fom<C4`2o`00
00KoIVIV1_ooool1o`00007ooooo0007ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool01?ooooo8ogmoO`?o00004OmVIVH0
0ol0003oC4a<oda<C01Eoda<C0?o00002?mVIVH6ooooo`7o00000Oooool000Oooooo00Go410@okZj
^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003ooooooooo
o`04oooool_oOgmo0_l0000@ofIVIPCo0000D_m<C4`00ol0003oIVIVofIVIP09ofIVIPKooooo0Ol0
0001ooooo`002oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool01?oo
ool00ol0003oooooooooo`04ooooolgoOgmo0ol0000AofIVIP?o0000C?m<C4`3o`0000coIVIV1_oo
ool1o`00007ooooo000:ooooo`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`00
0006ooooo`?o00001?ooooo@ogmoO`;o00004_mVIVH3o`0004KoC4a<0ol0000?ofIVIPCooooo0ol0
0001ooooo`002Oooool00ol@413o0000okZj^P03ooooo`05o`000?ooooooooooooooool000001_oo
ool00ol0003oooooooooo`04oooookKoOgmo1Ol0000GogmoO`?o00004_mVIVH3o`0003koC4a<1Ol0
000AofIVIP;o00001Oooool1o`00007ooooo000:ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@
oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00Cooooo]_moOgl00ol0003oVIVIoiVI
V@02oiVIV@Go00005OmoOgl2o`0001?oIVIV1Ol0000doda<C0Go00004omVIVH3o`000003ogmoOooo
oooooooo00Cooooo0Ol00001ooooo`001oooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00Cooooo]OmoOgl00ol0003oVIVI
oiVIV@08oiVIV@?o00005?moOgl4o`0001CoIVIV1_l0000[oda<C0?o00005_mVIVH2o`0000CoOgmo
1_ooool1o`00007ooooo0007ooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool01?ooooneogmoO`03o`000?nIVIWoVIVI00_o
VIVI0_l0000FogmoO`?o00005omVIVH5o`00027oC4a<1Ol0000FofIVIP?o00001_moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?oooondogmoO`;o00003onIVIT4o`0001GoOgmo
1?l0000HofIVIPSo00004om<C4`6o`0001CoIVIV1ol00009ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04oooookKoOgmo0_l0000AoiVIV@Co00005OmoOgl5o`0001_oIVIV4ol0
000EofIVIPGo00004?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonh
ogmoO`03o`000?nIVIWoVIVI01;oVIVI0ol0000GogmoO`?o0000?OmVIVH3o`0001GoOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo^OmoOgl2o`0001GoVIVI0ol0000Gogmo
O`Go0000<omVIVH5o`0001SoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooo^omoOgl00ol0003oVIVIoiVIV@0EoiVIV@?o00006OmoOgl6o`0002KoIVIV1ol0000KogmoO`?o
00001Oooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo_?moOgl00ol0003oVIVI
oiVIV@0GoiVIV@Go00006_moOgl7o`0001WoIVIV1_l0000OogmoO`?o00000_nIVIT6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?oooonmogmoO`;o00007?nIVIT2o`0001ooOgmo6Ol0
000OogmoO`Ko00001OnIVIT6ooooo`7o00000Oooool001[ooooo0_l00005oooookooOgmo00?o0000
oiVIVOnIVIT06onIVIT5o`0004koOgmo1?l0000;oiVIV@Gooooo0_l00001ooooo`006_ooool00ol0
003oooooooooo`04oooool3oOgmo0_l0000PoiVIV@Go0000A_moOgl3o`0000ooVIVI1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00Cooooo`_moOgl00ol0003oVIVIoiVIV@0RoiVIV@?o
0000?_moOgl5o`0001;oVIVI1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
`omoOgl2o`0002GoVIVI1Ol0000cogmoO`Ko00005onIVIT6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?ooooo5ogmoO`;o0000:?nIVIT6o`0002KoOgmo1ol0000MoiVIV@Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooolOoOgmo0_l0000/oiVIVBKo00009?nIVIT6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooo9ogmoO`?o0000LonIVIT6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooo<ogmoO`;o0000LOnIVIT6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooo>ogmoO`;o0000KonIVIT6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooo@ogmoO`?o0000K?nIVIT6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?oooooCogmoO`?o0000IonIVIT3o`0000Gooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooomKoOgmo0ol0001QoiVIV@?o00000_moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooIogmoO`;o0000G?nIVIT3o`0000Go
Ogmo1_ooool1o`00007ooooo000Jooooo`;o00001OoooooKogmoO`;o0000F?nIVIT2o`0000SoOgmo
1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooogOmoOgl2o`0005CoVIVI0_l0
000:ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooomooOgmo0ol0001=
oiVIV@Co00003?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooRogmo
O`;o0000A_nIVIT5o`00013oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
ooooi?moOgl9o`0003[oVIVI0ol0000EogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooongoOgmo0ol0000boiVIV@Go00006?moOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?ooooo`ogmoO`co00007onIVIT7o`0001goOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00Coooooo?moOgl6o`0000coVIVI3Ol0000TogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo0omoOgl<o`00037oOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000GooooooomoOgm0ogmo
O`Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo
@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000Gooooooomo
Ogm0ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
ooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3o
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo
0Ol00001ooooo`002Oooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^
00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000:ooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`001oooool5o`0000?ooooo00Go410@oooooooo
oooooooooa0@4006ooooo`?o00001?ooooooogmoOd3oOgmo1?ooool3o`00007ooooo0007ooooo`04
odA4A?oMgMgoooooo`0000Cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
oooo0?ooooooB_ooool1o`00007ooooo0007ooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?ooooooB_ooool1o`00007ooooo0008
ooooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oo
oooooooo0?ooooooB_ooool1o`00007ooooo0008ooooo`03onk^k_m4A4Co000000Cooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?ooooooB_ooool1o`00007ooooo0009
ooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oo
oooooooo02?ooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0mooooo`03o`000?oo
oooooooo03gooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Sooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`7o00000Oooool0
01[oooooool0001>o`00007ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-30.1723, -14.304, 0.195672, \
0.195672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0192308 0.211538 0.0192308 [
[.11538 -0.0125 -9 -9 ]
[.11538 -0.0125 9 0 ]
[.30769 -0.0125 -9 -9 ]
[.30769 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69231 -0.0125 -6 -9 ]
[.69231 -0.0125 6 0 ]
[.88462 -0.0125 -6 -9 ]
[.88462 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -18 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .21154 -6 -4.5 ]
[-0.0125 .21154 0 4.5 ]
[-0.0125 .40385 -12 -4.5 ]
[-0.0125 .40385 0 4.5 ]
[-0.0125 .59615 -12 -4.5 ]
[-0.0125 .59615 0 4.5 ]
[-0.0125 .78846 -12 -4.5 ]
[-0.0125 .78846 0 4.5 ]
[-0.0125 .98077 -12 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11538 0 m
.11538 .00625 L
s
[(-20)] .11538 -0.0125 0 1 Mshowa
.30769 0 m
.30769 .00625 L
s
[(-10)] .30769 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69231 0 m
.69231 .00625 L
s
[(10)] .69231 -0.0125 0 1 Mshowa
.88462 0 m
.88462 .00625 L
s
[(20)] .88462 -0.0125 0 1 Mshowa
.125 Mabswid
.15385 0 m
.15385 .00375 L
s
.19231 0 m
.19231 .00375 L
s
.23077 0 m
.23077 .00375 L
s
.26923 0 m
.26923 .00375 L
s
.34615 0 m
.34615 .00375 L
s
.38462 0 m
.38462 .00375 L
s
.42308 0 m
.42308 .00375 L
s
.46154 0 m
.46154 .00375 L
s
.53846 0 m
.53846 .00375 L
s
.57692 0 m
.57692 .00375 L
s
.61538 0 m
.61538 .00375 L
s
.65385 0 m
.65385 .00375 L
s
.73077 0 m
.73077 .00375 L
s
.76923 0 m
.76923 .00375 L
s
.80769 0 m
.80769 .00375 L
s
.84615 0 m
.84615 .00375 L
s
.07692 0 m
.07692 .00375 L
s
.03846 0 m
.03846 .00375 L
s
.92308 0 m
.92308 .00375 L
s
.96154 0 m
.96154 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(-10)] -0.0125 .01923 1 0 Mshowa
0 .21154 m
.00625 .21154 L
s
[(0)] -0.0125 .21154 1 0 Mshowa
0 .40385 m
.00625 .40385 L
s
[(10)] -0.0125 .40385 1 0 Mshowa
0 .59615 m
.00625 .59615 L
s
[(20)] -0.0125 .59615 1 0 Mshowa
0 .78846 m
.00625 .78846 L
s
[(30)] -0.0125 .78846 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(40)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .05769 m
.00375 .05769 L
s
0 .09615 m
.00375 .09615 L
s
0 .13462 m
.00375 .13462 L
s
0 .17308 m
.00375 .17308 L
s
0 .25 m
.00375 .25 L
s
0 .28846 m
.00375 .28846 L
s
0 .32692 m
.00375 .32692 L
s
0 .36538 m
.00375 .36538 L
s
0 .44231 m
.00375 .44231 L
s
0 .48077 m
.00375 .48077 L
s
0 .51923 m
.00375 .51923 L
s
0 .55769 m
.00375 .55769 L
s
0 .63462 m
.00375 .63462 L
s
0 .67308 m
.00375 .67308 L
s
0 .71154 m
.00375 .71154 L
s
0 .75 m
.00375 .75 L
s
0 .82692 m
.00375 .82692 L
s
0 .86538 m
.00375 .86538 L
s
0 .90385 m
.00375 .90385 L
s
0 .94231 m
.00375 .94231 L
s
.25 Mabswid
0 0 m
0 1 L
s
.11538 .99375 m
.11538 1 L
s
.30769 .99375 m
.30769 1 L
s
.5 .99375 m
.5 1 L
s
.69231 .99375 m
.69231 1 L
s
.88462 .99375 m
.88462 1 L
s
.125 Mabswid
.15385 .99625 m
.15385 1 L
s
.19231 .99625 m
.19231 1 L
s
.23077 .99625 m
.23077 1 L
s
.26923 .99625 m
.26923 1 L
s
.34615 .99625 m
.34615 1 L
s
.38462 .99625 m
.38462 1 L
s
.42308 .99625 m
.42308 1 L
s
.46154 .99625 m
.46154 1 L
s
.53846 .99625 m
.53846 1 L
s
.57692 .99625 m
.57692 1 L
s
.61538 .99625 m
.61538 1 L
s
.65385 .99625 m
.65385 1 L
s
.73077 .99625 m
.73077 1 L
s
.76923 .99625 m
.76923 1 L
s
.80769 .99625 m
.80769 1 L
s
.84615 .99625 m
.84615 1 L
s
.07692 .99625 m
.07692 1 L
s
.03846 .99625 m
.03846 1 L
s
.92308 .99625 m
.92308 1 L
s
.96154 .99625 m
.96154 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .21154 m
1 .21154 L
s
.99375 .40385 m
1 .40385 L
s
.99375 .59615 m
1 .59615 L
s
.99375 .78846 m
1 .78846 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .05769 m
1 .05769 L
s
.99625 .09615 m
1 .09615 L
s
.99625 .13462 m
1 .13462 L
s
.99625 .17308 m
1 .17308 L
s
.99625 .25 m
1 .25 L
s
.99625 .28846 m
1 .28846 L
s
.99625 .32692 m
1 .32692 L
s
.99625 .36538 m
1 .36538 L
s
.99625 .44231 m
1 .44231 L
s
.99625 .48077 m
1 .48077 L
s
.99625 .51923 m
1 .51923 L
s
.99625 .55769 m
1 .55769 L
s
.99625 .63462 m
1 .63462 L
s
.99625 .67308 m
1 .67308 L
s
.99625 .71154 m
1 .71154 L
s
.99625 .75 m
1 .75 L
s
.99625 .82692 m
1 .82692 L
s
.99625 .86538 m
1 .86538 L
s
.99625 .90385 m
1 .90385 L
s
.99625 .94231 m
1 .94231 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.4 g
.98077 .8281 m
.96115 .83539 L
.94152 .84179 L
.92903 .84341 L
.9219 .84447 L
.90228 .848 L
.88265 .85118 L
.86303 .8535 L
.84341 .85484 L
.82378 .85518 L
.80416 .85452 L
.78454 .85286 L
.76491 .85024 L
.74529 .84686 L
.72567 .84351 L
.72484 .84341 L
.70604 .83997 L
.68642 .83308 L
.6668 .82587 L
.66012 .82378 L
.64717 .81884 L
.62755 .81125 L
.61404 .80416 L
.60793 .80116 L
.5883 .79587 L
.577 .78454 L
.56868 .77933 L
.54906 .76631 L
.54713 .76491 L
.52943 .74794 L
.52662 .74529 L
.52943 .74104 L
.54906 .74089 L
.56868 .74524 L
.56877 .74529 L
.5883 .75136 L
.60793 .75715 L
.62755 .76165 L
.63669 .76491 L
.64717 .76823 L
.6668 .7735 L
.68642 .77441 L
.70604 .78141 L
.71971 .78454 L
.72567 .78566 L
.74529 .78888 L
.76491 .79137 L
.78454 .79316 L
.80416 .79427 L
.82378 .79471 L
.84341 .79448 L
.86303 .79359 L
.88265 .79202 L
.90228 .78975 L
.9219 .78677 L
.93416 .78454 L
.94152 .78298 L
.96115 .77712 L
.98077 .77504 L
F
0 g
.98077 .8281 m
.96115 .83539 L
.94152 .84179 L
.92903 .84341 L
.9219 .84447 L
.90228 .848 L
.88265 .85118 L
.86303 .8535 L
.84341 .85484 L
.82378 .85518 L
.80416 .85452 L
.78454 .85286 L
.76491 .85024 L
.74529 .84686 L
.72567 .84351 L
.72484 .84341 L
.70604 .83997 L
.68642 .83308 L
.6668 .82587 L
.66012 .82378 L
.64717 .81884 L
.62755 .81125 L
.61404 .80416 L
.60793 .80116 L
.5883 .79587 L
.577 .78454 L
.56868 .77933 L
.54906 .76631 L
.54713 .76491 L
.52943 .74794 L
.52662 .74529 L
.52943 .74104 L
.54906 .74089 L
.56868 .74524 L
.56877 .74529 L
.5883 .75136 L
.60793 .75715 L
.62755 .76165 L
.63669 .76491 L
.64717 .76823 L
.6668 .7735 L
.68642 .77441 L
.70604 .78141 L
.71971 .78454 L
.72567 .78566 L
.74529 .78888 L
.76491 .79137 L
.78454 .79316 L
.80416 .79427 L
.82378 .79471 L
Mistroke
.84341 .79448 L
.86303 .79359 L
.88265 .79202 L
.90228 .78975 L
.9219 .78677 L
.93416 .78454 L
.94152 .78298 L
.96115 .77712 L
.98077 .77504 L
Mfstroke
.6 g
.98077 .76182 m
.97013 .76491 L
.96115 .76659 L
.94152 .77197 L
.9219 .77735 L
.90228 .78211 L
.88265 .78186 L
.86303 .7836 L
.84534 .78454 L
.84341 .78461 L
.82378 .78488 L
.80852 .78454 L
.80416 .78436 L
.78454 .78312 L
.76491 .78114 L
.74529 .78067 L
.72567 .77568 L
.70604 .77019 L
.68642 .76528 L
.68371 .76491 L
.6668 .75992 L
.64717 .75588 L
.62755 .74609 L
.6253 .74529 L
.60793 .73791 L
.5883 .73104 L
.58181 .72567 L
.56868 .71821 L
.54906 .70635 L
.5486 .70604 L
.53106 .68642 L
.54906 .68336 L
.56841 .68642 L
.56868 .68648 L
.5883 .69133 L
.60793 .69608 L
.62755 .69885 L
.64717 .70588 L
.65078 .70604 L
.6668 .70982 L
.68642 .71385 L
.70604 .71473 L
.72567 .72041 L
.74529 .72416 L
.76491 .7249 L
.77357 .72567 L
.78454 .72647 L
.80416 .72747 L
.82378 .72787 L
.84341 .72767 L
.86303 .72686 L
.8802 .72567 L
.88265 .72545 L
.90228 .725 L
.9219 .72178 L
.94152 .71685 L
.96115 .70811 L
.98077 .71118 L
F
0 g
.98077 .76182 m
.97013 .76491 L
.96115 .76659 L
.94152 .77197 L
.9219 .77735 L
.90228 .78211 L
.88265 .78186 L
.86303 .7836 L
.84534 .78454 L
.84341 .78461 L
.82378 .78488 L
.80852 .78454 L
.80416 .78436 L
.78454 .78312 L
.76491 .78114 L
.74529 .78067 L
.72567 .77568 L
.70604 .77019 L
.68642 .76528 L
.68371 .76491 L
.6668 .75992 L
.64717 .75588 L
.62755 .74609 L
.6253 .74529 L
.60793 .73791 L
.5883 .73104 L
.58181 .72567 L
.56868 .71821 L
.54906 .70635 L
.5486 .70604 L
.53106 .68642 L
.54906 .68336 L
.56841 .68642 L
.56868 .68648 L
.5883 .69133 L
.60793 .69608 L
.62755 .69885 L
.64717 .70588 L
.65078 .70604 L
.6668 .70982 L
.68642 .71385 L
.70604 .71473 L
.72567 .72041 L
.74529 .72416 L
.76491 .7249 L
.77357 .72567 L
.78454 .72647 L
.80416 .72747 L
.82378 .72787 L
.84341 .72767 L
Mistroke
.86303 .72686 L
.8802 .72567 L
.88265 .72545 L
.90228 .725 L
.9219 .72178 L
.94152 .71685 L
.96115 .70811 L
.98077 .71118 L
Mfstroke
.4 g
.98077 .70046 m
.96115 .70561 L
.95941 .70604 L
.94152 .70979 L
.9219 .71553 L
.90228 .72223 L
.88265 .71845 L
.86303 .71999 L
.84341 .72088 L
.82378 .7211 L
.80416 .72067 L
.78454 .71957 L
.76491 .71782 L
.74529 .71993 L
.72567 .71361 L
.70604 .70817 L
.69444 .70604 L
.68642 .70401 L
.6668 .69872 L
.64717 .70029 L
.62787 .68642 L
.62755 .68629 L
.60793 .67808 L
.5883 .66947 L
.58275 .6668 L
.56868 .65729 L
.55383 .64717 L
.56868 .63989 L
.5883 .64125 L
.60793 .64261 L
.62347 .64717 L
.62755 .64802 L
.64717 .65188 L
.6668 .65537 L
.68642 .65618 L
.70604 .66488 L
.72567 .66413 L
.74529 .66643 L
.74869 .6668 L
.76491 .6683 L
.78454 .66964 L
.80416 .67047 L
.82378 .6708 L
.84341 .67063 L
.86303 .66996 L
.88265 .66879 L
.90228 .66709 L
.90512 .6668 L
.9219 .66491 L
.94152 .66237 L
.96115 .65933 L
.98077 .65643 L
F
0 g
.98077 .70046 m
.96115 .70561 L
.95941 .70604 L
.94152 .70979 L
.9219 .71553 L
.90228 .72223 L
.88265 .71845 L
.86303 .71999 L
.84341 .72088 L
.82378 .7211 L
.80416 .72067 L
.78454 .71957 L
.76491 .71782 L
.74529 .71993 L
.72567 .71361 L
.70604 .70817 L
.69444 .70604 L
.68642 .70401 L
.6668 .69872 L
.64717 .70029 L
.62787 .68642 L
.62755 .68629 L
.60793 .67808 L
.5883 .66947 L
.58275 .6668 L
.56868 .65729 L
.55383 .64717 L
.56868 .63989 L
.5883 .64125 L
.60793 .64261 L
.62347 .64717 L
.62755 .64802 L
.64717 .65188 L
.6668 .65537 L
.68642 .65618 L
.70604 .66488 L
.72567 .66413 L
.74529 .66643 L
.74869 .6668 L
.76491 .6683 L
.78454 .66964 L
.80416 .67047 L
.82378 .6708 L
.84341 .67063 L
.86303 .66996 L
.88265 .66879 L
.90228 .66709 L
.90512 .6668 L
.9219 .66491 L
.94152 .66237 L
Mistroke
.96115 .65933 L
.98077 .65643 L
Mfstroke
.6 g
.98077 .64394 m
.96956 .64717 L
.96115 .65007 L
.94152 .65295 L
.9219 .65618 L
.90228 .65884 L
.88265 .66094 L
.86303 .66244 L
.84341 .66331 L
.82378 .66354 L
.80416 .6631 L
.78454 .66203 L
.76491 .66033 L
.74529 .65805 L
.72567 .65521 L
.70604 .65737 L
.68642 .64779 L
.68427 .64717 L
.6668 .64206 L
.64717 .63598 L
.62755 .62942 L
.62247 .62755 L
.60793 .6191 L
.59042 .60793 L
.60793 .60264 L
.62755 .60337 L
.64717 .60435 L
.66623 .60793 L
.6668 .60801 L
.68642 .61066 L
.70604 .61299 L
.72567 .615 L
.74529 .6167 L
.76491 .61316 L
.78454 .61938 L
.80416 .6226 L
.82378 .6239 L
.84341 .62322 L
.86303 .62063 L
.88265 .6157 L
.90228 .61718 L
.9219 .61558 L
.94152 .61366 L
.96115 .61144 L
.98077 .60889 L
F
0 g
.98077 .64394 m
.96956 .64717 L
.96115 .65007 L
.94152 .65295 L
.9219 .65618 L
.90228 .65884 L
.88265 .66094 L
.86303 .66244 L
.84341 .66331 L
.82378 .66354 L
.80416 .6631 L
.78454 .66203 L
.76491 .66033 L
.74529 .65805 L
.72567 .65521 L
.70604 .65737 L
.68642 .64779 L
.68427 .64717 L
.6668 .64206 L
.64717 .63598 L
.62755 .62942 L
.62247 .62755 L
.60793 .6191 L
.59042 .60793 L
.60793 .60264 L
.62755 .60337 L
.64717 .60435 L
.66623 .60793 L
.6668 .60801 L
.68642 .61066 L
.70604 .61299 L
.72567 .615 L
.74529 .6167 L
.76491 .61316 L
.78454 .61938 L
.80416 .6226 L
.82378 .6239 L
.84341 .62322 L
.86303 .62063 L
.88265 .6157 L
.90228 .61718 L
.9219 .61558 L
.94152 .61366 L
.96115 .61144 L
.98077 .60889 L
s
.6 g
.98077 .88449 m
.96115 .89121 L
.94152 .89666 L
.9219 .90113 L
.91662 .90228 L
.90228 .90483 L
.88265 .90758 L
.86303 .90944 L
.84341 .91047 L
.82378 .91073 L
.80416 .91023 L
.78454 .90894 L
.76491 .9068 L
.74529 .90374 L
.73731 .90228 L
.72567 .8998 L
.70604 .89504 L
.68642 .88922 L
.66759 .88265 L
.6668 .88202 L
.64717 .87374 L
.62755 .86396 L
.62551 .86303 L
.60793 .85083 L
.60243 .84341 L
.60793 .84291 L
.61204 .84341 L
.62755 .84768 L
.64717 .85384 L
.6668 .85953 L
.68021 .86303 L
.68642 .86492 L
.70604 .87054 L
.72567 .87534 L
.74529 .8792 L
.76491 .88216 L
.76876 .88265 L
.78454 .88464 L
.80416 .88628 L
.82378 .88695 L
.84341 .8866 L
.86303 .88527 L
.88265 .88298 L
.88495 .88265 L
.90228 .88024 L
.9219 .87667 L
.94152 .87217 L
.96115 .86679 L
.97412 .86303 L
.98077 .8612 L
F
0 g
.98077 .88449 m
.96115 .89121 L
.94152 .89666 L
.9219 .90113 L
.91662 .90228 L
.90228 .90483 L
.88265 .90758 L
.86303 .90944 L
.84341 .91047 L
.82378 .91073 L
.80416 .91023 L
.78454 .90894 L
.76491 .9068 L
.74529 .90374 L
.73731 .90228 L
.72567 .8998 L
.70604 .89504 L
.68642 .88922 L
.66759 .88265 L
.6668 .88202 L
.64717 .87374 L
.62755 .86396 L
.62551 .86303 L
.60793 .85083 L
.60243 .84341 L
.60793 .84291 L
.61204 .84341 L
.62755 .84768 L
.64717 .85384 L
.6668 .85953 L
.68021 .86303 L
.68642 .86492 L
.70604 .87054 L
.72567 .87534 L
.74529 .8792 L
.76491 .88216 L
.76876 .88265 L
.78454 .88464 L
.80416 .88628 L
.82378 .88695 L
.84341 .8866 L
.86303 .88527 L
.88265 .88298 L
.88495 .88265 L
.90228 .88024 L
.9219 .87667 L
.94152 .87217 L
.96115 .86679 L
.97412 .86303 L
.98077 .8612 L
Mistroke
Mfstroke
.7 g
.98077 .74772 m
.96115 .75472 L
.94152 .76065 L
.92526 .76491 L
.9219 .76596 L
.90228 .77297 L
.88265 .77236 L
.86303 .77435 L
.84341 .77548 L
.82378 .77577 L
.80416 .77521 L
.78454 .77381 L
.76491 .77154 L
.74529 .77052 L
.72857 .76491 L
.72567 .76419 L
.70604 .75885 L
.68642 .75262 L
.66714 .74529 L
.6668 .74511 L
.64717 .73313 L
.64048 .72567 L
.64717 .7234 L
.6668 .72324 L
.68642 .72486 L
.69714 .72567 L
.70604 .72716 L
.72567 .7295 L
.74529 .7315 L
.76491 .7331 L
.78454 .73428 L
.80416 .73503 L
.82378 .73532 L
.84341 .73517 L
.86303 .73457 L
.88265 .73353 L
.90228 .73206 L
.9219 .73018 L
.94152 .72794 L
.95921 .72567 L
.96115 .72523 L
.98077 .72367 L
F
0 g
.98077 .74772 m
.96115 .75472 L
.94152 .76065 L
.92526 .76491 L
.9219 .76596 L
.90228 .77297 L
.88265 .77236 L
.86303 .77435 L
.84341 .77548 L
.82378 .77577 L
.80416 .77521 L
.78454 .77381 L
.76491 .77154 L
.74529 .77052 L
.72857 .76491 L
.72567 .76419 L
.70604 .75885 L
.68642 .75262 L
.66714 .74529 L
.6668 .74511 L
.64717 .73313 L
.64048 .72567 L
.64717 .7234 L
.6668 .72324 L
.68642 .72486 L
.69714 .72567 L
.70604 .72716 L
.72567 .7295 L
.74529 .7315 L
.76491 .7331 L
.78454 .73428 L
.80416 .73503 L
.82378 .73532 L
.84341 .73517 L
.86303 .73457 L
.88265 .73353 L
.90228 .73206 L
.9219 .73018 L
.94152 .72794 L
.95921 .72567 L
.96115 .72523 L
.98077 .72367 L
s
.4 g
.98077 .58914 m
.96115 .59406 L
.94152 .59838 L
.9219 .60223 L
.90228 .6055 L
.88386 .60793 L
.88265 .60809 L
.86303 .61102 L
.84341 .61339 L
.82378 .6141 L
.80416 .61277 L
.78454 .61008 L
.76972 .60793 L
.76491 .60732 L
.74529 .60452 L
.72567 .60105 L
.70604 .59705 L
.68642 .59257 L
.67006 .5883 L
.68642 .57039 L
.70604 .57147 L
.72567 .57264 L
.74529 .57373 L
.76491 .57464 L
.78454 .57534 L
.80416 .57578 L
.82378 .57596 L
.84341 .57587 L
.86303 .57551 L
.88265 .57489 L
.90228 .57404 L
.9219 .57301 L
.94152 .57185 L
.96115 .5707 L
.98077 .56999 L
F
0 g
.98077 .58914 m
.96115 .59406 L
.94152 .59838 L
.9219 .60223 L
.90228 .6055 L
.88386 .60793 L
.88265 .60809 L
.86303 .61102 L
.84341 .61339 L
.82378 .6141 L
.80416 .61277 L
.78454 .61008 L
.76972 .60793 L
.76491 .60732 L
.74529 .60452 L
.72567 .60105 L
.70604 .59705 L
.68642 .59257 L
.67006 .5883 L
.68642 .57039 L
.70604 .57147 L
.72567 .57264 L
.74529 .57373 L
.76491 .57464 L
.78454 .57534 L
.80416 .57578 L
.82378 .57596 L
.84341 .57587 L
.86303 .57551 L
.88265 .57489 L
.90228 .57404 L
.9219 .57301 L
.94152 .57185 L
.96115 .5707 L
.98077 .56999 L
s
.3 g
.98077 .68696 m
.96115 .69392 L
.94152 .69975 L
.9219 .70475 L
.9162 .70604 L
.90228 .71139 L
.88265 .71101 L
.86303 .7128 L
.84341 .71383 L
.82378 .71409 L
.80416 .71358 L
.78454 .71232 L
.76491 .71027 L
.74529 .70878 L
.73766 .70604 L
.72567 .70324 L
.70604 .69798 L
.68642 .69185 L
.67166 .68642 L
.68642 .67159 L
.70604 .6726 L
.72567 .67394 L
.74529 .67523 L
.76491 .67635 L
.78454 .6772 L
.80416 .67775 L
.82378 .67797 L
.84341 .67786 L
.86303 .67741 L
.88265 .67665 L
.90228 .67562 L
.9219 .67437 L
.94152 .67302 L
.96115 .67183 L
.98077 .67174 L
F
0 g
.98077 .68696 m
.96115 .69392 L
.94152 .69975 L
.9219 .70475 L
.9162 .70604 L
.90228 .71139 L
.88265 .71101 L
.86303 .7128 L
.84341 .71383 L
.82378 .71409 L
.80416 .71358 L
.78454 .71232 L
.76491 .71027 L
.74529 .70878 L
.73766 .70604 L
.72567 .70324 L
.70604 .69798 L
.68642 .69185 L
.67166 .68642 L
.68642 .67159 L
.70604 .6726 L
.72567 .67394 L
.74529 .67523 L
.76491 .67635 L
.78454 .6772 L
.80416 .67775 L
.82378 .67797 L
.84341 .67786 L
.86303 .67741 L
.88265 .67665 L
.90228 .67562 L
.9219 .67437 L
.94152 .67302 L
.96115 .67183 L
.98077 .67174 L
s
.3 g
.70604 .80281 m
.72567 .80308 L
.74327 .80416 L
.74529 .80434 L
.76491 .80596 L
.78454 .80725 L
.80416 .80809 L
.82378 .80843 L
.84341 .80825 L
.86303 .80757 L
.88265 .80642 L
.90228 .80488 L
.91355 .82378 L
.90228 .82642 L
.88265 .83003 L
.86303 .83249 L
.84341 .83387 L
.82378 .83422 L
.80416 .83354 L
.78454 .83182 L
.76491 .82901 L
.74529 .82498 L
.74039 .82378 L
.72567 .81902 L
.70604 .81079 L
.6986 .80416 L
F
0 g
.70604 .80281 m
.72567 .80308 L
.74327 .80416 L
.74529 .80434 L
.76491 .80596 L
.78454 .80725 L
.80416 .80809 L
.82378 .80843 L
.84341 .80825 L
.86303 .80757 L
.88265 .80642 L
.90228 .80488 L
.91355 .82378 L
.90228 .82642 L
.88265 .83003 L
.86303 .83249 L
.84341 .83387 L
.82378 .83422 L
.80416 .83354 L
.78454 .83182 L
.76491 .82901 L
.74529 .82498 L
.74039 .82378 L
.72567 .81902 L
.70604 .81079 L
.6986 .80416 L
.70604 .80281 L
s
.7 g
.74529 .62963 m
.76491 .62976 L
.78454 .63008 L
.80416 .63034 L
.82378 .63046 L
.84341 .6304 L
.86303 .63018 L
.88265 .62986 L
.90228 .62962 L
.91145 .64717 L
.90228 .64876 L
.88265 .65148 L
.86303 .65336 L
.84341 .65443 L
.82378 .6547 L
.80416 .65417 L
.78454 .65285 L
.76491 .65071 L
.74529 .64769 L
.74246 .64717 L
F
0 g
.74529 .62963 m
.76491 .62976 L
.78454 .63008 L
.80416 .63034 L
.82378 .63046 L
.84341 .6304 L
.86303 .63018 L
.88265 .62986 L
.90228 .62962 L
.91145 .64717 L
.90228 .64876 L
.88265 .65148 L
.86303 .65336 L
.84341 .65443 L
.82378 .6547 L
.80416 .65417 L
.78454 .65285 L
.76491 .65071 L
.74529 .64769 L
.74246 .64717 L
.74529 .62963 L
s
.6 g
.76491 .54221 m
.78454 .54124 L
.80416 .54091 L
.82378 .54081 L
.84341 .54086 L
.86303 .54109 L
.88265 .54177 L
.90228 .54424 L
.90469 .54906 L
.90228 .54945 L
.88265 .55215 L
.86303 .55401 L
.84341 .55509 L
.82378 .55536 L
.80416 .55483 L
.78454 .5535 L
.76491 .55138 L
.74907 .54906 L
F
0 g
.76491 .54221 m
.78454 .54124 L
.80416 .54091 L
.82378 .54081 L
.84341 .54086 L
.86303 .54109 L
.88265 .54177 L
.90228 .54424 L
.90469 .54906 L
.90228 .54945 L
.88265 .55215 L
.86303 .55401 L
.84341 .55509 L
.82378 .55536 L
.80416 .55483 L
.78454 .5535 L
.76491 .55138 L
.74907 .54906 L
.76491 .54221 L
s
.8 g
.76491 .74493 m
.78454 .74484 L
.80416 .74495 L
.82378 .74502 L
.84341 .74498 L
.86303 .74487 L
.88265 .74485 L
.89918 .74529 L
.88265 .75818 L
.86303 .76175 L
.84341 .76367 L
.82378 .76415 L
.80416 .76322 L
.78454 .76081 L
.76491 .75661 L
.75467 .74529 L
F
0 g
.76491 .74493 m
.78454 .74484 L
.80416 .74495 L
.82378 .74502 L
.84341 .74498 L
.86303 .74487 L
.88265 .74485 L
.89918 .74529 L
.88265 .75818 L
.86303 .76175 L
.84341 .76367 L
.82378 .76415 L
.80416 .76322 L
.78454 .76081 L
.76491 .75661 L
.75467 .74529 L
.76491 .74493 L
s
.3 g
.9219 .80344 m
.94152 .80265 L
.95526 .80416 L
.94152 .81379 L
.9219 .82115 L
.91057 .80416 L
F
0 g
.9219 .80344 m
.94152 .80265 L
.95526 .80416 L
.94152 .81379 L
.9219 .82115 L
.91057 .80416 L
.9219 .80344 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00?Oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0dooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kS?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0hooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8b
onk^kS?ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08_ooool003gooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0=_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0<oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg03?ooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL08_ooool003Gooooo1_l0
0003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400[ooooo`Ko0000
1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100<oooool01Ol@413o
oooooooooooooooo410@03[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@03Cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@02;ooooo000o
ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000fooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000cooooo`05o`000?ooooooooooooooool0
0000>_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000=Oooool00onH
V9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000008_ooool0043ooooo00?oMgMgofIV
I_ooool00_ooool01Ol0003ooooooooooooooooo000003Kooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000003?ooooo00Go0000ooooooooooooooooo`00000jooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`03ogMgMomVIVKooooo00;o
oooo00Go0000ooooooooooooooooo`00000Rooooo`00@Oooool01Ol0003ooooooooooooooooo410@
00?ooooo00?o410@ooooooooool0=?ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@4100<oooool01Ol@413ooooooooooooooooo410@03[ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@03Oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo023ooooo000mooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg03Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg03?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0jooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0cooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02;ooooo000mooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^03Cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^03?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`03oeEEEOmVIVKo000000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0cooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02;ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo000Joooooooo0000C_l00001ooooo`00
6_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0?Ooo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool08ooo
ool1o`00007ooooo0008ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKo
oooo00?o0000ooooooooool0oooooom:ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooom:ooooo`7o
00000Oooool000Go00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41001_ooool00ol0003oooooooooo`3ooooood[ooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?ooooooB?ooool3o`00007o
oooo000:ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo0008ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Oooooooogmo
Od3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Ooo
ooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000oooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`003ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000?ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000oooooo00Go0000oooooooooooooooo
o`000006ooooo`?o00001?ooooooogmoOd3oOgmo1?ooool3o`00007ooooo000?ooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool000oooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`003oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000?ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo0008
ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000:ooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`002_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41001_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000[ooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo0ol00004oooooooo
Ogmo@?moOgl4ooooo`?o00000Oooool000[ooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000:ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool000Sooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooo_oOgmo8Ol0000SogmoO`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooKoOgmo1Ol0000QoiVIV@[o00006Omo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooocogmoO`?o0000;onIVIT0
0ol0003oOgmoogmoO`0GogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
oo;oOgmo1?l0000/oiVIV@Go00006?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooofogmoO`co00006OnIVIT7o`0001goOgmo1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CooooooomoOgl3ogmoOaWo00009?moOgl6ooooo`7o00000Oooool001[ooooo0_l0
0005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool01?oooooo
ogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?oooooMogmoO`_o0000COmoOgl;o`0000Gooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooomgoOgmo00?o0000ofIVI_mVIVH02?mV
IVHDo`0002KoOgmo4ol0000:ofIVIPKooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooomcoOgmo00?o0000ofIVI_mVIVH07OmVIVHVo`0001goIVIV1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CooooofomoOgl00ol0003oIVIVofIVIP1QofIVIPKooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooom[oOgmo00?o0000ofIVI_mVIVH0H_mVIVH6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?oooooIogmoO`03o`000?mVIVKoIVIV06?oIVIV
1_ooool1o`00007ooooo0007ooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo
00?o0000ooooooooool01?oooooHogmoO`Co0000HOmVIVH3o`0000Gooooo0Ol00001ooooo`001ooo
ool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03
o`000?oooooooooo00Cooooog?moOgl4o`0005[oIVIV0ol00002ogmoO`Kooooo0Ol00001ooooo`00
2?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003o
ooooooooo`04ooooon3oOgmo0ol0001BofIVIPGo00001OmoOgl6ooooo`7o00000Oooool000Wooooo
00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000Kooooo0ol00004ooooon?o
Ogmo1Ol00018ofIVIPGo00002_moOgl4ooooo`?o00000Oooool000[ooooo00?oMgMgofIVI_ooool0
0_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool01?oooooXogmoO`Oo
0000?_mVIVH3o`0000ooOgmo1_ooool1o`00007ooooo000;ooooo`05o`000?ooooooooooooooool@
41000oooool00ol@413oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo`_moOglAo`0001co
Ogmo1_l0000cofIVIPGo00004_moOgl6ooooo`7o00000Oooool000Oooooo00Go0000okZj^_oooooo
V9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`04oooo
okooOgmo0ol0000AoiVIV@?o00007omoOgl4o`0002WoIVIV1_l0000GogmoO`Kooooo0Ol00001oooo
o`001oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06
ooooo`03o`000?oooooooooo00Cooooo_OmoOgl2o`0001OoVIVI3?l0000GogmoO`Wo00006OmVIVH7
o`0001[oOgmo1?l00005ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonoogmo
O`;o00008OnIVIT6o`0000coOgmo1_l00008ogmoO`Oo00001OmVIVH=o`0001CoOgmo3Ol00003oiVI
V@Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooool7oOgmo0_l0000UoiVIV@co
00001_nIVIT3o`0000coOgmo1Ol0000?ogmoO`Ko00001OmoOgl7o`00013oVIVI1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00Cooooo`omoOgl2o`0003SoVIVI1Ol0000HogmoO`?o0000
1_nIVIT5o`0001OoVIVI1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooaOmo
Ogl2o`0003_oVIVI1ol0000<ogmoO`Go00009OnIVIT6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooo7ogmoO`03o`000?nIVIWoVIVI03ooVIVI3?l0000ZoiVIV@Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooolSoOgmo0_l0001eoiVIV@Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04oooool[oOgmo0ol0000ToiVIVCGo00006OnIVIT6ooooo`7o
00000Oooool001[ooooo0_l00005ooooolgoOgmo0ol0000QoiVIV@03o`000?nc/k?o/k>c037o/k>c
00?o0000oiVIVOnIVIT05onIVIT5ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooo@ogmoO`?o00007_nIVIT00ol0003o/k>cok>c/`0bok>c/`03o`000?nIVIWoVIVI01KoVIVI1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo]OmoOgl6o`0001SoOgmo0ol0000K
oiVIV@03o`000?nc/k?o/k>c03;o/k>c00?o0000oiVIVOnIVIT05_nIVIT6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooncogmoO`;o00001_mVIVH:o`00017oOgmo0ol0000GoiVI
V@03o`000?nc/k?o/k>c03Co/k>c00?o0000oiVIVOnIVIT05OnIVIT6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?oooonbogmoO`03o`000?mVIVKoIVIV013oIVIV0ol0000AogmoO`?o
00005?nIVIT00ol0003o/k>cok>c/`0dok>c/`03o`000?nIVIWoVIVI01?oVIVI0ol00005ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?oooonaogmoO`;o00005OmVIVH6o`0000koOgmo
0ol0000AoiVIV@Go0000;Onc/k<7o`00017oVIVI0ol00002ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04oooook?oOgmo0_l0000IofIVIPOo00002_moOgl3o`0001?oVIVI3Ol0
000Iok>c/`Oo00004onIVIT5o`0000GoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00Cooooo]OmoOgl00ol0003oIVIVofIVIP0MofIVIPKo00001omoOgl2o`0000?oVIVI2?l0000C
oiVIVAWo00005?nIVIT6o`0000[oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00Cooooo]_moOgl2o`0002?oIVIV1Ol00004ogmoO`?o00002?moOgl6o`0002goVIVI3Ol0000=ogmo
O`Co00001Oooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo^?moOgl2o`0002Ko
IVIV0ol0000BogmoO`Oo00007onIVIT7o`0001?oOgmo1ol00003ofIVIPKooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04oooook[oOgmo00?o0000ofIVI_mVIVH09_mVIVH<o`0000goOgmo
7ol0000>ogmoO`co00002_mVIVH6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
oonkogmoO`;o0000<_mVIVH7o`0002coOgmo1ol0000FofIVIPKooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04oooookgoOgmo0_l0000gofIVIRco00007OmVIVH6ooooo`7o00000Oooool0
01[ooooo0_l00005oooookooOgmo0_l0000LofIVIQ;o0000@?mVIVHAo`0000Cooooo0_l00001oooo
o`006_ooool00ol0003oooooooooo`04oooool7oOgmo0_l0000IofIVIP03o`000?m<C4coC4a<013o
C4a<3Ol0000OofIVIQCo00004?m<C4`6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?ooooo3ogmoO`;o00005_mVIVH00ol0003oC4a<oda<C00Noda<C1oo00009?m<C4`6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooo5ogmoO`?o00004_mVIVH00ol0003oC4a<oda<
C01Roda<C0Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooojgoOgmo1ol0000D
ogmoO`;o00003omVIVH00ol0003oC4a<oda<C01Soda<C0Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04oooooj[oOgmo0ol00007oiVIV@Oo00003omoOgl2o`0000coIVIV1?l0001Qoda<
C0?o00001Oooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooZ_moOgl00ol0003o
VIVIoiVIV@0>oiVIV@Go00003?moOgl00ol0003oIVIVofIVIP0=ofIVIPCo0000F_m<C4`3o`0000;o
IVIV1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooZomoOgl00ol0003oVIVI
oiVIV@0BoiVIV@?o00002_moOgl2o`00017oIVIV0ol0001Doda<C0?o00001OmVIVH6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?oooon/ogmoO`03o`000?nIVIWoVIVI01CoVIVI1Ol0
0007ogmoO`03o`000?mVIVKoIVIV017oIVIV1?l0001=oda<C0?o00002?mVIVH6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?oooon]ogmoO`03o`000?nIVIWoVIVI01SoVIVI1Ol00003
ogmoO`_o00003?mVIVH3o`0004KoC4a<1?l00009ofIVIP?o00001Oooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00Cooooo[_moOgl00ol0003oVIVIoiVIV@0LoiVIV@?o00002omoOgl5o`00
00[oIVIV0ol00010oda<C0?o00002_mVIVH3o`0000;oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00Cooooo[omoOgl3o`0001koVIVI1Ol0000;ogmoO`?o00002_mVIVH4o`0003So
C4a<1?l00008ofIVIPGo00001OmoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?oooonbogmoO`03o`000?nIVIWoVIVI023oVIVI1Ol00009ogmoO`Co00002_mVIVH4o`00037oC4a<
0ol00007ofIVIPGo00000_moOgl6o`0000;oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Ooo
ooncogmoO`;o00009OnIVIT3o`0000[oOgmo0ol0000;ofIVIPgo00004om<C4`Ao`0000OoIVIV0ol0
0005ogmoO`;o00001_nIVIT3o`0000Cooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04
oooookGoOgmo00?o0000oiVIVOnIVIT09OnIVIT:o`0000?oOgmo0ol0000EofIVIQ?o00005OmVIVH3
o`0000KoOgmo0_l0000:oiVIV@Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
okKoOgmo0_l0000_oiVIV@?o00000omoOgl3o`0000CoIVIV2?l0000OofIVIPKo00001omVIVH2o`00
00GoOgmo1?l0000<oiVIV@Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooookSo
Ogmo00?o0000oiVIVOnIVIT0;onIVIT5o`000003ogmoOol0003o000000;o00002?moOglOo`0000Ko
Ogmo0ol00002ofIVIPWo00004?nIVIT6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?ooooniogmoO`03o`000?nIVIWoVIVI01?oVIVI4Ol0000?oiVIV@_o0000:?moOgl6o`0001CoVIVI
1?l00005ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonjogmoO`?o00004OnI
VIT00ol0003o/k>cok>c/`0?ok>c/`So00004_nIVITXo`0000goVIVI3Ol00003ok>c/`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04oooookgoOgmo0_l0000@oiVIV@03o`000?nc/k?o
/k>c01Ko/k>c1ol0000ioiVIV@Oo00004?nc/k<6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?oooonoogmoO`;o00003onIVIT2o`0001go/k>c3Ol0000OoiVIV@go00005onc/k<6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooo1ogmoO`;o00003onIVIT2o`0002So
/k>c7ol0000Tok>c/`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooool?oOgmo
0ol0000>oiVIV@03o`000?nc/k?o/k>c06So/k>c1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CoooooZOmoOgl;o`0001;oOgmo0ol0000<oiVIV@;o0000J?nc/k<6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?oooonXogmoO`03o`000?mVIVKoIVIV00WoIVIV1Ol0000@
ogmoO`?o00002onIVIT2o`0001_o/k>c<Ol0000Jok>c/`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooojWoOgmo00?o0000ofIVI_mVIVH03OmVIVH3o`00013oOgmo00?o0000oiVI
VOnIVIT02_nIVIT2o`0001Wo/k>c00?o0000olc<c?o<c<`0:oo<c<`00ol0003o/k>cok>c/`0Hok>c
/`?o00001Oooool1o`00007ooooo000Jooooo`;o00001OoooonZogmoO`03o`000?mVIVKoIVIV00oo
IVIV1?l0000=ogmoO`;o00003?nIVIT2o`0001So/k>c00?o0000olc<c?o<c<`0:?o<c<`2o`0001So
/k>c0ol00002oiVIV@Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04oooooj_oOgmo
00?o0000ofIVI_mVIVH04_mVIVH3o`0000coOgmo00?o0000oiVIVOnIVIT02onIVIT3o`0001Ko/k>c
00?o0000olc<c?o<c<`09_o<c<`00ol0003o/k>cok>c/`0Eok>c/`?o00001OnIVIT6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?oooon/ogmoO`03o`000?mVIVKoIVIV01CoIVIV0ol0
000:ogmoO`Go00002onIVIT3o`0001Co/k>c1Ol0000Qolc<c0;o00005Onc/k<3o`0000SoVIVI1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo[OmoOgl00ol0003oIVIVofIVIP0F
ofIVIP?o00003?moOgl4o`0000[oVIVI1Ol0000Dok>c/`Ko00006?o<c<`3o`0001Co/k>c0ol0000;
oiVIV@Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooojkoOgmo00?o0000ofIV
I_mVIVH06?mVIVH4o`0000coOgmo0ol0000<oiVIV@?o00005onc/k<Ho`0001Co/k>c0ol0000<oiVI
V@?o00001Oooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo[omoOgl3o`0001_o
IVIV0ol0000<ogmoO`Ko00002OnIVIT3o`0003co/k>c1?l00009oiVIV@Ko00000_moOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?oooonbogmoO`03o`000?mVIVKoIVIV01_oIVIV
0ol0000?ogmoO`Go00001onIVIT3o`0003Ko/k>c0ol0000:oiVIV@?o00002?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooncogmoO`;o00007_mVIVH3o`00017oOgmo0ol0
0007oiVIV@_o00007onc/k<<o`0000WoVIVI1?l0000;ogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04oooookGoOgmo00?o0000ofIVI_mVIVH07_mVIVH:o`0000[oOgmo0ol0000?
oiVIVAoo00004_nIVIT3o`0000coOgmo1?l00005ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?oooonfogmoO`;o0000:?mVIVH3o`0000[oOgmo0ol0000hoiVIV@Go00002_moOgl5o`00
00?oIVIV1_ooool1o`00007ooooo0007ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool01?oooonhogmoO`03o`000?mVIVKo
IVIV02SoIVIV1?l00009ogmoO`co00007onIVIT=o`0000coOgmo0ol00008ofIVIPKooooo0Ol00001
ooooo`001oooool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`06ooooo`03o`000?oooooooooo00Cooooo^OmoOgl00ol0003oIVIVofIVIP0[ofIVIP?o00004_mo
OglOo`0001;oOgmo1ol0000;ofIVIPKooooo0Ol00001ooooo`002oooool01Ol0003ooooooooooooo
oooo410@00?ooooo00?o410@ooooooooool01?ooool00ol0003oooooooooo`04oooook[oOgmo00?o
0000ofIVI_mVIVH0;OmVIVH5o`0003WoOgmo1Ol0000BofIVIPKooooo0Ol00001ooooo`002_ooool0
0onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool3o`0000Cooooo^omo
Ogl00ol0003oIVIVofIVIP0aofIVIPgo00009_moOgl6o`0001OoIVIV1?ooool3o`00007ooooo0009
ooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oo
oooooooo00Cooooo_?moOgl00ol0003oIVIVofIVIP0mofIVIPgo00003?moOgl=o`0001goIVIV1_oo
ool1o`00007ooooo000:ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@
4006ooooo`03o`000?oooooooooo00Cooooo_OmoOgl3o`0004WoIVIV3?l0000ZofIVIPKooooo0Ol0
0001ooooo`001oooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`06ooooo`03o`000?oooooooooo00Cooooo`?moOgl3o`0007coIVIV1_ooool1o`00007ooooo
0007ooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Ko
oooo00?o0000ooooooooool01?ooooo3ogmoO`;o00007_mVIVH;o`0003coIVIV2ol0000:ofIVIPKo
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooolGoOgmo0_l0000JofIVIP;o0000
2om<C4`>o`0001ooIVIV2ol00002ofIVIP;o00002om<C4`2o`0000SoIVIV1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CoooooaomoOgl3o`0001WoIVIV00?o0000oda<C?m<C4`05_m<
C4`Oo`0000[oC4a<00Co0000ofIVI_mVIVKo00002om<C4`00ol0003oIVIVofIVIP08ofIVIPKooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooool[oOgmo0_l0000HofIVIP;o0000@?m<
C4`01?l0003oIVIVofIVI_l00009oda<C003o`000?mVIVKoIVIV00WoIVIV1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00Coooooc?moOgl2o`0001SoIVIV0_l0000ooda<C004o`000?mV
IVKoIVIVo`0000GoC4a<0ol0000<ofIVIPKooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooolkoOgmo0_l0000HofIVIP;o0000?Om<C4`01?l0003oIVIVofIVI_l00002oda<C0?o0000
3omVIVH6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooo@ogmoO`?o00005omV
IVH4o`0003[oC4a<00?o0000ofIVI_mVIVH00_l0000BofIVIPKooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooom?oOgmo1?l0000GofIVIP?o0000=_m<C4`3o`0001GoIVIV1_ooool1
o`00007ooooo000Jooooo`;o00001OoooooGogmoO`?o00005omVIVH4o`0002goC4a<1Ol0000HofIV
IPGooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04ooooom[oOgmo0ol0000HofIVIPOo
00007om<C4`7o`0001_oIVIV0ol00005ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?oooooMogmoO`;o00007OmVIVH=o`0000coC4a<1_l0000OofIVIP?o00000_moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?oooooOogmoO`?o00009omVIVH<o`0002;oIVIV0ol0
0005ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooon;oOgmo0_l0001@
ofIVIP?o00002?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooTogmo
O`Co0000B?mVIVH4o`0000_oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooo`OmoOgl7o`00023oOgmo1ol0000iofIVIPSo00003omoOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooo2ogmoO`03o`000?nIVIWoVIVI00?oVIVI1Ol0000RogmoO`Ko0000
;OmVIVH6o`0001OoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo`omo
Ogl2o`0000SoVIVI0ol0000UogmoO`Oo00007omVIVH7o`0001goOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CoooooaOmoOgl00ol0003oVIVIoiVIV@08oiVIV@?o0000:OmoOgl=
o`0000coIVIV1_l0000TogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
olKoOgmo0_l0000;oiVIV@?o0000<omoOgl<o`0002[oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00Cooooob?moOgl00ol0003oVIVIoiVIV@0;oiVIV@Co0000IOmoOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooo9ogmoO`03o`000?nIVIWoVIVI00koVIVI
0ol0001OogmoO`Co00001Oooool1o`00007ooooo000Jooooo`;o00001Oooooo:ogmoO`;o00004OnI
VIT3o`0005WoOgmo0ol00003oiVIV@Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04
ooooolcoOgmo0_l0000BoiVIV@?o0000D_moOgl4o`0000KoVIVI1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00Coooooc_moOgl2o`0001?oVIVI1Ol00018ogmoO`Go00002_nIVIT6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooo@ogmoO`;o00005_nIVIT5o`00043o
Ogmo0ol0000?oiVIV@Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooom;oOgmo
0ol0000HoiVIV@?o0000>?moOgl5o`0001;oVIVI1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CoooooeOmoOgl2o`0001WoVIVI1Ol0000]ogmoO`Ko00005onIVIT6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?oooooGogmoO`?o00006onIVIT=o`0001WoOgmo1ol0000L
oiVIV@;o00001Oooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooof_moOgl3o`00
02GoVIVI6Ol0000PoiVIV@?o000000?oOgmoooooooooool01?ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooogOmoOgl3o`0005WoVIVI0_l00004ogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooon3oOgmo0ol0001BoiVIV@Co00001_moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?oooooSogmoO`Co0000BOnIVIT5o`0000[oOgmo1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooiomoOgl3o`0004?oVIVI0ol0000?
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooon[oOgmo1ol0000goiVI
V@Go00004_moOgl6ooooo`7o00000Oooool001[ooooo0_l00005oooooo7oOgmo1?l0000]oiVIV@Ko
00005omoOgl5ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool01?oooooeogmoO`Oo0000
7onIVIT7o`0001goOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Coooooo?mo
OglOo`0002CoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002Oooool2o`000009oa0@4?oooooo
ooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool01?ooooooogmoOd3o
Ogmo1_ooool1o`00007ooooo000:ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`00
1oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@4006ooooo`?o00001?ooooooogmoOd3o
Ogmo1?ooool3o`00007ooooo0007ooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000oooooooo
ooooooooo`000006ooooo`03o`000?oooooooooo0?ooooooB_ooool1o`00007ooooo0007ooooo`04
omgMgOmEEEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
oooo0?ooooooB_ooool1o`00007ooooo0008ooooo`03ogMgMoo<c<co000000Cooooo00Go410@oooo
oooooooooooooa0@4006ooooo`03o`000?oooooooooo0?ooooooB_ooool1o`00007ooooo0008oooo
o`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooo
oooo0?ooooooB_ooool1o`00007ooooo0009ooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0?Oooool0
0ol0003oooooooooo`0mooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0?Oooool0
0ol0003oooooooooo`0Sooooo`7o00000Oooool001[ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`09ooooo`7o00000Oooool001[oooooool0001>o`00007ooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-30.1723, -14.304, 0.195672, \
0.195672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0192308 0.211538 0.0192308 [
[.11538 -0.0125 -9 -9 ]
[.11538 -0.0125 9 0 ]
[.30769 -0.0125 -9 -9 ]
[.30769 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69231 -0.0125 -6 -9 ]
[.69231 -0.0125 6 0 ]
[.88462 -0.0125 -6 -9 ]
[.88462 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -18 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .21154 -6 -4.5 ]
[-0.0125 .21154 0 4.5 ]
[-0.0125 .40385 -12 -4.5 ]
[-0.0125 .40385 0 4.5 ]
[-0.0125 .59615 -12 -4.5 ]
[-0.0125 .59615 0 4.5 ]
[-0.0125 .78846 -12 -4.5 ]
[-0.0125 .78846 0 4.5 ]
[-0.0125 .98077 -12 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11538 0 m
.11538 .00625 L
s
[(-20)] .11538 -0.0125 0 1 Mshowa
.30769 0 m
.30769 .00625 L
s
[(-10)] .30769 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69231 0 m
.69231 .00625 L
s
[(10)] .69231 -0.0125 0 1 Mshowa
.88462 0 m
.88462 .00625 L
s
[(20)] .88462 -0.0125 0 1 Mshowa
.125 Mabswid
.15385 0 m
.15385 .00375 L
s
.19231 0 m
.19231 .00375 L
s
.23077 0 m
.23077 .00375 L
s
.26923 0 m
.26923 .00375 L
s
.34615 0 m
.34615 .00375 L
s
.38462 0 m
.38462 .00375 L
s
.42308 0 m
.42308 .00375 L
s
.46154 0 m
.46154 .00375 L
s
.53846 0 m
.53846 .00375 L
s
.57692 0 m
.57692 .00375 L
s
.61538 0 m
.61538 .00375 L
s
.65385 0 m
.65385 .00375 L
s
.73077 0 m
.73077 .00375 L
s
.76923 0 m
.76923 .00375 L
s
.80769 0 m
.80769 .00375 L
s
.84615 0 m
.84615 .00375 L
s
.07692 0 m
.07692 .00375 L
s
.03846 0 m
.03846 .00375 L
s
.92308 0 m
.92308 .00375 L
s
.96154 0 m
.96154 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(-10)] -0.0125 .01923 1 0 Mshowa
0 .21154 m
.00625 .21154 L
s
[(0)] -0.0125 .21154 1 0 Mshowa
0 .40385 m
.00625 .40385 L
s
[(10)] -0.0125 .40385 1 0 Mshowa
0 .59615 m
.00625 .59615 L
s
[(20)] -0.0125 .59615 1 0 Mshowa
0 .78846 m
.00625 .78846 L
s
[(30)] -0.0125 .78846 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(40)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .05769 m
.00375 .05769 L
s
0 .09615 m
.00375 .09615 L
s
0 .13462 m
.00375 .13462 L
s
0 .17308 m
.00375 .17308 L
s
0 .25 m
.00375 .25 L
s
0 .28846 m
.00375 .28846 L
s
0 .32692 m
.00375 .32692 L
s
0 .36538 m
.00375 .36538 L
s
0 .44231 m
.00375 .44231 L
s
0 .48077 m
.00375 .48077 L
s
0 .51923 m
.00375 .51923 L
s
0 .55769 m
.00375 .55769 L
s
0 .63462 m
.00375 .63462 L
s
0 .67308 m
.00375 .67308 L
s
0 .71154 m
.00375 .71154 L
s
0 .75 m
.00375 .75 L
s
0 .82692 m
.00375 .82692 L
s
0 .86538 m
.00375 .86538 L
s
0 .90385 m
.00375 .90385 L
s
0 .94231 m
.00375 .94231 L
s
.25 Mabswid
0 0 m
0 1 L
s
.11538 .99375 m
.11538 1 L
s
.30769 .99375 m
.30769 1 L
s
.5 .99375 m
.5 1 L
s
.69231 .99375 m
.69231 1 L
s
.88462 .99375 m
.88462 1 L
s
.125 Mabswid
.15385 .99625 m
.15385 1 L
s
.19231 .99625 m
.19231 1 L
s
.23077 .99625 m
.23077 1 L
s
.26923 .99625 m
.26923 1 L
s
.34615 .99625 m
.34615 1 L
s
.38462 .99625 m
.38462 1 L
s
.42308 .99625 m
.42308 1 L
s
.46154 .99625 m
.46154 1 L
s
.53846 .99625 m
.53846 1 L
s
.57692 .99625 m
.57692 1 L
s
.61538 .99625 m
.61538 1 L
s
.65385 .99625 m
.65385 1 L
s
.73077 .99625 m
.73077 1 L
s
.76923 .99625 m
.76923 1 L
s
.80769 .99625 m
.80769 1 L
s
.84615 .99625 m
.84615 1 L
s
.07692 .99625 m
.07692 1 L
s
.03846 .99625 m
.03846 1 L
s
.92308 .99625 m
.92308 1 L
s
.96154 .99625 m
.96154 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .21154 m
1 .21154 L
s
.99375 .40385 m
1 .40385 L
s
.99375 .59615 m
1 .59615 L
s
.99375 .78846 m
1 .78846 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .05769 m
1 .05769 L
s
.99625 .09615 m
1 .09615 L
s
.99625 .13462 m
1 .13462 L
s
.99625 .17308 m
1 .17308 L
s
.99625 .25 m
1 .25 L
s
.99625 .28846 m
1 .28846 L
s
.99625 .32692 m
1 .32692 L
s
.99625 .36538 m
1 .36538 L
s
.99625 .44231 m
1 .44231 L
s
.99625 .48077 m
1 .48077 L
s
.99625 .51923 m
1 .51923 L
s
.99625 .55769 m
1 .55769 L
s
.99625 .63462 m
1 .63462 L
s
.99625 .67308 m
1 .67308 L
s
.99625 .71154 m
1 .71154 L
s
.99625 .75 m
1 .75 L
s
.99625 .82692 m
1 .82692 L
s
.99625 .86538 m
1 .86538 L
s
.99625 .90385 m
1 .90385 L
s
.99625 .94231 m
1 .94231 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.6 g
.98077 .79865 m
.96115 .80146 L
.94954 .80416 L
.94152 .8051 L
.9219 .80869 L
.90228 .81215 L
.88265 .81483 L
.86303 .81659 L
.84341 .8174 L
.82378 .81726 L
.80416 .81616 L
.78454 .81412 L
.76491 .81118 L
.74529 .80756 L
.72567 .80433 L
.72354 .80416 L
.70604 .8 L
.68642 .79608 L
.6668 .7881 L
.65561 .78454 L
.64717 .78143 L
.62755 .77886 L
.60793 .76521 L
.60732 .76491 L
.5883 .75547 L
.56938 .74529 L
.56868 .74482 L
.54906 .73164 L
.54054 .72567 L
.54906 .71013 L
.56868 .71367 L
.5883 .71817 L
.60793 .72213 L
.61996 .72567 L
.62755 .72823 L
.64717 .73329 L
.6668 .73449 L
.68642 .74216 L
.70332 .74529 L
.70604 .74585 L
.72567 .74944 L
.74529 .75239 L
.76491 .75008 L
.78454 .75394 L
.80416 .75615 L
.82378 .75724 L
.84341 .75738 L
.86303 .75659 L
.88265 .75474 L
.90228 .75148 L
.9219 .75316 L
.94152 .75039 L
.96115 .747 L
.96986 .74529 L
.98077 .74368 L
F
0 g
.98077 .79865 m
.96115 .80146 L
.94954 .80416 L
.94152 .8051 L
.9219 .80869 L
.90228 .81215 L
.88265 .81483 L
.86303 .81659 L
.84341 .8174 L
.82378 .81726 L
.80416 .81616 L
.78454 .81412 L
.76491 .81118 L
.74529 .80756 L
.72567 .80433 L
.72354 .80416 L
.70604 .8 L
.68642 .79608 L
.6668 .7881 L
.65561 .78454 L
.64717 .78143 L
.62755 .77886 L
.60793 .76521 L
.60732 .76491 L
.5883 .75547 L
.56938 .74529 L
.56868 .74482 L
.54906 .73164 L
.54054 .72567 L
.54906 .71013 L
.56868 .71367 L
.5883 .71817 L
.60793 .72213 L
.61996 .72567 L
.62755 .72823 L
.64717 .73329 L
.6668 .73449 L
.68642 .74216 L
.70332 .74529 L
.70604 .74585 L
.72567 .74944 L
.74529 .75239 L
.76491 .75008 L
.78454 .75394 L
.80416 .75615 L
.82378 .75724 L
.84341 .75738 L
.86303 .75659 L
.88265 .75474 L
.90228 .75148 L
Mistroke
.9219 .75316 L
.94152 .75039 L
.96115 .747 L
.96986 .74529 L
.98077 .74368 L
Mfstroke
.4 g
.98077 .864 m
.96115 .8701 L
.94152 .87599 L
.9219 .88072 L
.90539 .88265 L
.90228 .88299 L
.88265 .8851 L
.86303 .88669 L
.84341 .88746 L
.82378 .88732 L
.80416 .88629 L
.78454 .8845 L
.76763 .88265 L
.76491 .88255 L
.74529 .87948 L
.72567 .87431 L
.70604 .86823 L
.68879 .86303 L
.68642 .86224 L
.6668 .85735 L
.64717 .84716 L
.63881 .84341 L
.62755 .83824 L
.60793 .82984 L
.59936 .82378 L
.5883 .81743 L
.56868 .8065 L
.56697 .80416 L
.54906 .79059 L
.54076 .78454 L
.54906 .77126 L
.56868 .77553 L
.5883 .78086 L
.60115 .78454 L
.60793 .78681 L
.62755 .7931 L
.64717 .79398 L
.6668 .80387 L
.66768 .80416 L
.68642 .8093 L
.70604 .81394 L
.72567 .81412 L
.74529 .82006 L
.76491 .82375 L
.76511 .82378 L
.78454 .82605 L
.80416 .82762 L
.82378 .82845 L
.84341 .82856 L
.86303 .82794 L
.88265 .8266 L
.90228 .82452 L
.90801 .82378 L
.9219 .82134 L
.94152 .81626 L
.96115 .81519 L
.98077 .81077 L
F
0 g
.98077 .864 m
.96115 .8701 L
.94152 .87599 L
.9219 .88072 L
.90539 .88265 L
.90228 .88299 L
.88265 .8851 L
.86303 .88669 L
.84341 .88746 L
.82378 .88732 L
.80416 .88629 L
.78454 .8845 L
.76763 .88265 L
.76491 .88255 L
.74529 .87948 L
.72567 .87431 L
.70604 .86823 L
.68879 .86303 L
.68642 .86224 L
.6668 .85735 L
.64717 .84716 L
.63881 .84341 L
.62755 .83824 L
.60793 .82984 L
.59936 .82378 L
.5883 .81743 L
.56868 .8065 L
.56697 .80416 L
.54906 .79059 L
.54076 .78454 L
.54906 .77126 L
.56868 .77553 L
.5883 .78086 L
.60115 .78454 L
.60793 .78681 L
.62755 .7931 L
.64717 .79398 L
.6668 .80387 L
.66768 .80416 L
.68642 .8093 L
.70604 .81394 L
.72567 .81412 L
.74529 .82006 L
.76491 .82375 L
.76511 .82378 L
.78454 .82605 L
.80416 .82762 L
.82378 .82845 L
.84341 .82856 L
.86303 .82794 L
Mistroke
.88265 .8266 L
.90228 .82452 L
.90801 .82378 L
.9219 .82134 L
.94152 .81626 L
.96115 .81519 L
.98077 .81077 L
Mfstroke
.4 g
.98077 .73637 m
.96115 .73779 L
.94152 .7417 L
.9219 .74503 L
.92023 .74529 L
.90228 .74662 L
.88265 .74874 L
.86303 .75033 L
.84341 .75111 L
.82378 .75097 L
.80416 .74993 L
.78454 .74813 L
.76491 .746 L
.75281 .74529 L
.74529 .74409 L
.72567 .74059 L
.70604 .73651 L
.68642 .73345 L
.6668 .72612 L
.66481 .72567 L
.64717 .71977 L
.62755 .71281 L
.61039 .70604 L
.60793 .70485 L
.5883 .69523 L
.57131 .68642 L
.56868 .6843 L
.55206 .6668 L
.56868 .66377 L
.5883 .66533 L
.59258 .6668 L
.60793 .66997 L
.62755 .67397 L
.64717 .67781 L
.6668 .68247 L
.68642 .68516 L
.69351 .68642 L
.70604 .68863 L
.72567 .69159 L
.74529 .69405 L
.76491 .69292 L
.78454 .69689 L
.80416 .69929 L
.82378 .70055 L
.84341 .70071 L
.86303 .69978 L
.88265 .69774 L
.90228 .69435 L
.9219 .68811 L
.94152 .69238 L
.96115 .68957 L
.97969 .68642 L
.98077 .68622 L
F
0 g
.98077 .73637 m
.96115 .73779 L
.94152 .7417 L
.9219 .74503 L
.92023 .74529 L
.90228 .74662 L
.88265 .74874 L
.86303 .75033 L
.84341 .75111 L
.82378 .75097 L
.80416 .74993 L
.78454 .74813 L
.76491 .746 L
.75281 .74529 L
.74529 .74409 L
.72567 .74059 L
.70604 .73651 L
.68642 .73345 L
.6668 .72612 L
.66481 .72567 L
.64717 .71977 L
.62755 .71281 L
.61039 .70604 L
.60793 .70485 L
.5883 .69523 L
.57131 .68642 L
.56868 .6843 L
.55206 .6668 L
.56868 .66377 L
.5883 .66533 L
.59258 .6668 L
.60793 .66997 L
.62755 .67397 L
.64717 .67781 L
.6668 .68247 L
.68642 .68516 L
.69351 .68642 L
.70604 .68863 L
.72567 .69159 L
.74529 .69405 L
.76491 .69292 L
.78454 .69689 L
.80416 .69929 L
.82378 .70055 L
.84341 .70071 L
.86303 .69978 L
.88265 .69774 L
.90228 .69435 L
.9219 .68811 L
.94152 .69238 L
Mistroke
.96115 .68957 L
.97969 .68642 L
.98077 .68622 L
Mfstroke
.6 g
.98077 .67545 m
.96115 .67973 L
.94152 .68355 L
.92462 .68642 L
.9219 .68655 L
.90228 .68904 L
.88265 .69189 L
.86303 .69413 L
.84341 .69529 L
.82378 .69508 L
.80416 .69355 L
.78454 .69108 L
.76491 .68817 L
.74844 .68642 L
.74529 .68591 L
.72567 .68246 L
.70604 .6785 L
.68642 .67407 L
.6668 .67094 L
.65904 .6668 L
.64717 .66246 L
.62755 .65508 L
.60795 .64717 L
.60793 .64716 L
.5883 .6306 L
.58683 .62755 L
.5883 .62708 L
.60793 .62549 L
.62755 .62727 L
.6292 .62755 L
.64717 .63023 L
.6668 .63308 L
.68642 .63575 L
.70604 .63823 L
.72567 .64235 L
.74529 .64255 L
.76491 .6443 L
.78454 .6457 L
.80416 .64668 L
.82126 .64717 L
.82378 .64722 L
.84341 .64729 L
.85178 .64717 L
.86303 .64689 L
.88265 .64604 L
.90228 .64476 L
.9219 .64311 L
.94152 .64515 L
.96115 .63426 L
.98077 .63651 L
F
0 g
.98077 .67545 m
.96115 .67973 L
.94152 .68355 L
.92462 .68642 L
.9219 .68655 L
.90228 .68904 L
.88265 .69189 L
.86303 .69413 L
.84341 .69529 L
.82378 .69508 L
.80416 .69355 L
.78454 .69108 L
.76491 .68817 L
.74844 .68642 L
.74529 .68591 L
.72567 .68246 L
.70604 .6785 L
.68642 .67407 L
.6668 .67094 L
.65904 .6668 L
.64717 .66246 L
.62755 .65508 L
.60795 .64717 L
.60793 .64716 L
.5883 .6306 L
.58683 .62755 L
.5883 .62708 L
.60793 .62549 L
.62755 .62727 L
.6292 .62755 L
.64717 .63023 L
.6668 .63308 L
.68642 .63575 L
.70604 .63823 L
.72567 .64235 L
.74529 .64255 L
.76491 .6443 L
.78454 .6457 L
.80416 .64668 L
.82126 .64717 L
.82378 .64722 L
.84341 .64729 L
.85178 .64717 L
.86303 .64689 L
.88265 .64604 L
.90228 .64476 L
.9219 .64311 L
.94152 .64515 L
.96115 .63426 L
.98077 .63651 L
Mistroke
Mfstroke
.4 g
.98077 .62048 m
.96115 .62576 L
.95392 .62755 L
.94152 .63347 L
.9219 .63244 L
.90228 .63463 L
.88265 .63627 L
.86303 .63735 L
.84341 .63785 L
.82378 .63776 L
.80416 .63709 L
.78454 .63584 L
.76491 .63403 L
.74529 .63167 L
.72567 .63023 L
.71916 .62755 L
.70604 .62424 L
.68642 .61881 L
.6668 .61302 L
.65108 .60793 L
.6668 .59274 L
.68642 .59374 L
.70604 .59511 L
.72567 .59652 L
.74529 .59784 L
.76491 .59899 L
.78454 .59992 L
.80416 .60059 L
.82378 .59991 L
.84341 .60037 L
.86303 .59764 L
.88265 .60015 L
.90228 .5993 L
.9219 .59821 L
.94152 .59693 L
.96115 .59554 L
.98077 .59414 L
F
0 g
.98077 .62048 m
.96115 .62576 L
.95392 .62755 L
.94152 .63347 L
.9219 .63244 L
.90228 .63463 L
.88265 .63627 L
.86303 .63735 L
.84341 .63785 L
.82378 .63776 L
.80416 .63709 L
.78454 .63584 L
.76491 .63403 L
.74529 .63167 L
.72567 .63023 L
.71916 .62755 L
.70604 .62424 L
.68642 .61881 L
.6668 .61302 L
.65108 .60793 L
.6668 .59274 L
.68642 .59374 L
.70604 .59511 L
.72567 .59652 L
.74529 .59784 L
.76491 .59899 L
.78454 .59992 L
.80416 .60059 L
.82378 .59991 L
.84341 .60037 L
.86303 .59764 L
.88265 .60015 L
.90228 .5993 L
.9219 .59821 L
.94152 .59693 L
.96115 .59554 L
.98077 .59414 L
s
.7 g
.98077 .78133 m
.9723 .78454 L
.96115 .78816 L
.94152 .79346 L
.9219 .79777 L
.90228 .80121 L
.88265 .80379 L
.8801 .80416 L
.86303 .80569 L
.84341 .80666 L
.82378 .80648 L
.80416 .8052 L
.79307 .80416 L
.78454 .80311 L
.76491 .80027 L
.74529 .79657 L
.72567 .79198 L
.70604 .78634 L
.70052 .78454 L
.68642 .77893 L
.6668 .77006 L
.65698 .76491 L
.6668 .75458 L
.68642 .75564 L
.70604 .75761 L
.72567 .75967 L
.74529 .7616 L
.76491 .76166 L
.78454 .7644 L
.78969 .76491 L
.80416 .76565 L
.82378 .76624 L
.84341 .76632 L
.86303 .76588 L
.88265 .76493 L
.88286 .76491 L
.90228 .76269 L
.9219 .76213 L
.94152 .76027 L
.96115 .75823 L
.98077 .75619 L
F
0 g
.98077 .78133 m
.9723 .78454 L
.96115 .78816 L
.94152 .79346 L
.9219 .79777 L
.90228 .80121 L
.88265 .80379 L
.8801 .80416 L
.86303 .80569 L
.84341 .80666 L
.82378 .80648 L
.80416 .8052 L
.79307 .80416 L
.78454 .80311 L
.76491 .80027 L
.74529 .79657 L
.72567 .79198 L
.70604 .78634 L
.70052 .78454 L
.68642 .77893 L
.6668 .77006 L
.65698 .76491 L
.6668 .75458 L
.68642 .75564 L
.70604 .75761 L
.72567 .75967 L
.74529 .7616 L
.76491 .76166 L
.78454 .7644 L
.78969 .76491 L
.80416 .76565 L
.82378 .76624 L
.84341 .76632 L
.86303 .76588 L
.88265 .76493 L
.88286 .76491 L
.90228 .76269 L
.9219 .76213 L
.94152 .76027 L
.96115 .75823 L
.98077 .75619 L
s
.3 g
.98077 .72095 m
.96817 .72567 L
.96115 .72767 L
.94152 .73244 L
.9219 .73632 L
.90228 .73943 L
.88265 .74176 L
.86303 .74329 L
.84341 .74399 L
.82378 .74387 L
.80416 .74291 L
.78454 .74114 L
.76491 .73858 L
.74529 .73524 L
.72567 .73111 L
.70604 .72603 L
.7048 .72567 L
.68642 .71855 L
.6668 .7096 L
.66027 .70604 L
.6668 .69937 L
.68642 .69852 L
.70604 .69955 L
.72567 .70099 L
.74529 .70247 L
.76491 .70192 L
.78454 .70444 L
.80416 .70564 L
.8183 .70604 L
.82378 .70614 L
.84341 .70621 L
.85476 .70604 L
.86303 .70584 L
.88265 .7049 L
.90228 .70289 L
.9219 .69812 L
.94152 .70144 L
.96115 .69997 L
.98077 .69874 L
F
0 g
.98077 .72095 m
.96817 .72567 L
.96115 .72767 L
.94152 .73244 L
.9219 .73632 L
.90228 .73943 L
.88265 .74176 L
.86303 .74329 L
.84341 .74399 L
.82378 .74387 L
.80416 .74291 L
.78454 .74114 L
.76491 .73858 L
.74529 .73524 L
.72567 .73111 L
.70604 .72603 L
.7048 .72567 L
.68642 .71855 L
.6668 .7096 L
.66027 .70604 L
.6668 .69937 L
.68642 .69852 L
.70604 .69955 L
.72567 .70099 L
.74529 .70247 L
.76491 .70192 L
.78454 .70444 L
.80416 .70564 L
.8183 .70604 L
.82378 .70614 L
.84341 .70621 L
.85476 .70604 L
.86303 .70584 L
.88265 .7049 L
.90228 .70289 L
.9219 .69812 L
.94152 .70144 L
.96115 .69997 L
.98077 .69874 L
s
.7 g
.72567 .65525 m
.74529 .65506 L
.76491 .65546 L
.78454 .65594 L
.80416 .65634 L
.82378 .65657 L
.84341 .6566 L
.86303 .65643 L
.88265 .65608 L
.90228 .65561 L
.9219 .65516 L
.94152 .65507 L
.95983 .6668 L
.94152 .67179 L
.9219 .67608 L
.90228 .67951 L
.88265 .68208 L
.86303 .68376 L
.84341 .68454 L
.82378 .6844 L
.80416 .68335 L
.78454 .6814 L
.76491 .67857 L
.74529 .67489 L
.72567 .67031 L
.71319 .6668 L
F
0 g
.72567 .65525 m
.74529 .65506 L
.76491 .65546 L
.78454 .65594 L
.80416 .65634 L
.82378 .65657 L
.84341 .6566 L
.86303 .65643 L
.88265 .65608 L
.90228 .65561 L
.9219 .65516 L
.94152 .65507 L
.95983 .6668 L
.94152 .67179 L
.9219 .67608 L
.90228 .67951 L
.88265 .68208 L
.86303 .68376 L
.84341 .68454 L
.82378 .6844 L
.80416 .68335 L
.78454 .6814 L
.76491 .67857 L
.74529 .67489 L
.72567 .67031 L
.71319 .6668 L
.72567 .65525 L
s
.6 g
.72567 .56358 m
.74529 .56216 L
.76491 .56192 L
.78454 .562 L
.80416 .56216 L
.82378 .56227 L
.84341 .56228 L
.86303 .5622 L
.88265 .56205 L
.90228 .56192 L
.9219 .56202 L
.94152 .56289 L
.95765 .56868 L
.94152 .57289 L
.9219 .57714 L
.90228 .58061 L
.88265 .58322 L
.86303 .58491 L
.84341 .58569 L
.82378 .58555 L
.80416 .5845 L
.78454 .58253 L
.76491 .57965 L
.74529 .57595 L
.72567 .57145 L
.7154 .56868 L
F
0 g
.72567 .56358 m
.74529 .56216 L
.76491 .56192 L
.78454 .562 L
.80416 .56216 L
.82378 .56227 L
.84341 .56228 L
.86303 .5622 L
.88265 .56205 L
.90228 .56192 L
.9219 .56202 L
.94152 .56289 L
.95765 .56868 L
.94152 .57289 L
.9219 .57714 L
.90228 .58061 L
.88265 .58322 L
.86303 .58491 L
.84341 .58569 L
.82378 .58555 L
.80416 .5845 L
.78454 .58253 L
.76491 .57965 L
.74529 .57595 L
.72567 .57145 L
.7154 .56868 L
.72567 .56358 L
s
.2 g
.76491 .71845 m
.78454 .71687 L
.80416 .71658 L
.82378 .71654 L
.84341 .71654 L
.86303 .71655 L
.88265 .71673 L
.90228 .71765 L
.91091 .72567 L
.90228 .72757 L
.88265 .73083 L
.86303 .73285 L
.84341 .73376 L
.82378 .7336 L
.80416 .73236 L
.78454 .73 L
.76491 .72628 L
.76231 .72567 L
F
0 g
.76491 .71845 m
.78454 .71687 L
.80416 .71658 L
.82378 .71654 L
.84341 .71654 L
.86303 .71655 L
.88265 .71673 L
.90228 .71765 L
.91091 .72567 L
.90228 .72757 L
.88265 .73083 L
.86303 .73285 L
.84341 .73376 L
.82378 .7336 L
.80416 .73236 L
.78454 .73 L
.76491 .72628 L
.76231 .72567 L
.76491 .71845 L
s
.8 g
.80416 .7812 m
.82378 .78069 L
.84341 .78064 L
.86303 .78096 L
.88265 .78268 L
.88674 .78454 L
.88265 .78559 L
.86303 .78881 L
.84341 .79009 L
.82378 .78987 L
.80416 .7881 L
.78609 .78454 L
F
0 g
.80416 .7812 m
.82378 .78069 L
.84341 .78064 L
.86303 .78096 L
.88265 .78268 L
.88674 .78454 L
.88265 .78559 L
.86303 .78881 L
.84341 .79009 L
.82378 .78987 L
.80416 .7881 L
.78609 .78454 L
.80416 .7812 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00?Oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0dooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kS?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0hooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8b
onk^kS?ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08_ooool003gooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0=_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0<oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg03?ooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL08_ooool003Gooooo1_l0
0003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400[ooooo`Ko0000
1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100<oooool01Ol@413o
oooooooooooooooo410@03[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@03Cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@02;ooooo000o
ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000fooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000cooooo`05o`000?ooooooooooooooool0
0000>_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000=Oooool00onH
V9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000008_ooool0043ooooo00?oMgMgofIV
I_ooool00_ooool01Ol0003ooooooooooooooooo000003Kooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000003?ooooo00Go0000ooooooooooooooooo`00000jooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`03ogMgMomVIVKooooo00;o
oooo00Go0000ooooooooooooooooo`00000Rooooo`00@Oooool01Ol0003ooooooooooooooooo410@
00?ooooo00?o410@ooooooooool0=?ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@4100<oooool01Ol@413ooooooooooooooooo410@03[ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@03Oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo023ooooo000mooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg03Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg03?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0jooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0cooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02;ooooo000mooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^03Cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^03?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`03oeEEEOmVIVKo000000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0cooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02;ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo000Joooooooo0000C_l00001ooooo`00
6_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0?Ooo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool08ooo
ool1o`00007ooooo0008ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKo
oooo00?o0000ooooooooool0oooooom:ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooom:ooooo`7o
00000Oooool000Go00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41001_ooool00ol0003oooooooooo`3ooooood[ooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?ooooooB?ooool3o`00007o
oooo000:ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo0008ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Oooooooogmo
Od3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Ooo
ooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000oooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`003ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000?ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000oooooo00Go0000oooooooooooooooo
o`000006ooooo`?o00001?ooooooogmoOd3oOgmo1?ooool3o`00007ooooo000?ooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool000oooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`003oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000?ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo0008
ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000:ooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`002_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41001_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000[ooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo0ol00004oooooooo
Ogmo@?moOgl4ooooo`?o00000Oooool000[ooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000:ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool000Sooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooonkoOgmo@_l0000?ogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooonWoOgmo1Ol00012oiVIV@Co00002omoOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooXogmoO`03o`000?nIVIWoVIVI04Wo
VIVI0ol00008ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooonOoOgmo
1_l00018oiVIV@?o00001omoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooo]ogmoO`?o0000?onIVIT6o`0000[oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00Coooool?moOgl5o`0003?oVIVI1ol0000@ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooGoOgmo1ol0000VoiVIV@Ko00005omoOgl6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?ooooologmoO`Ko00006OnIVIT7o`0001goOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgl3ogmoOaWo00009?moOgl6ooooo`7o0000
0Oooool000Oooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000Oooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool000Sooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooo
oooooooooooo410@00Kooooo00?o0000ooooooooool01?oooooFogmoOa;o0000COmoOgl;o`0000Go
oooo0Ol00001ooooo`002Oooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool0
00001_ooool3o`0000CoooooeOmoOgl00ol0003oIVIVofIVIP0@ofIVIPgo00008?moOgl7o`0000co
Ogmo3Ol0000:ofIVIPCooooo0ol00001ooooo`002_ooool00omgMgOoIVIVooooo`02ooooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooooooo`04ooooomCoOgmo00?o0000ofIVI_mV
IVH07_mVIVHPo`0000OoIVIV3?l0000GofIVIPKooooo0Ol00001ooooo`002oooool01Ol0003ooooo
oooooooooooo410@00?ooooo00?o410@ooooooooool01?ooool00ol0003oooooooooo`04ooooom?o
Ogmo00?o0000ofIVI_mVIVH0JOmVIVH6ooooo`7o00000Oooool000Oooooo00Go0000okZj^_oooooo
V9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`04oooo
om;oOgmo00?o0000ofIVI_mVIVH0J_mVIVH6ooooo`7o00000Oooool000Oooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`04
ooooom7oOgmo1?l0001ZofIVIPKooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
omGoOgmo1Ol0001UofIVIPKooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooom[o
Ogmo0ol0001RofIVIPKooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooomgoOgmo
0ol0001OofIVIPKooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooon3oOgmo0ol0
001IofIVIPCo00001Oooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo`?moOgl8
o`0001_oOgmo1?l0001@ofIVIPGo00000omoOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?oooonlogmoO`Co00002?nIVIT6o`0001WoOgmo0ol0001;ofIVIP;o00002?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonmogmoO`03o`000?nIVIWoVIVI00ko
VIVI1ol0000EogmoO`_o0000?_mVIVH2o`0000[oOgmo1_ooool1o`00007ooooo000Jooooo`;o0000
1OoooonnogmoO`03o`000?nIVIWoVIVI01CoVIVI1_l0000JogmoO`Oo00009_mVIVHAo`0000CoOgmo
1_l00002ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04oooookooOgmo00?o
0000oiVIVOnIVIT06OnIVIT7o`0001[oOgmo9_l0000DogmoO`03o`000?nIVIWoVIVI00CoVIVI0ol0
0005ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooo0ogmoO`03o`000?nIVIWo
VIVI01ooVIVI1_l0001<ogmoO`;o00002OnIVIT6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?ooooo1ogmoO`03o`000?nIVIWoVIVI02CoVIVI3Ol0000cogmoO`So00000omoOgl00ol0
003oVIVIoiVIV@09oiVIV@Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooool;o
Ogmo0_l0000aoiVIVA?o00003_moOglBo`0000SoVIVI0ol0000<oiVIV@Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04oooool?oOgmo0ol00012oiVIV@ko0000:OnIVIT6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooo6ogmoO`?o0000M_nIVIT6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?ooooo9ogmoO`?o00007_nIVITBo`0002KoVIVI4_l0000;
oiVIV@Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooolcoOgmo0_l0000KoiVI
V@03o`000?nc/k?o/k>c013o/k>c9_l0000Bok>c/`03o`000?nIVIWoVIVI00SoVIVI1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00Coooooc_moOgl2o`0001SoVIVI00?o0000ok>c/onc
/k<0B_nc/k<2o`0000SoVIVI1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
]?moOgl7o`0001GoOgmo0ol0000DoiVIV@03o`000?nc/k?o/k>c04go/k>c00?o0000oiVIVOnIVIT0
1OnIVIT6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonaogmoO`?o00001omV
IVH7o`00017oOgmo1?l0000?oiVIV@?o0000C_nc/k<2o`0000KoVIVI1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00Cooooo/OmoOgl00ol0003oIVIVofIVIP0>ofIVIPKo00003omoOgl3
o`0000ooVIVI1?l00017ok>c/`?o00002?nIVIT6ooooo`7o00000Oooool001[ooooo0_l00005oooo
ok;oOgmo00?o0000ofIVI_mVIVH04omVIVH5o`0000goOgmo0ol0000@oiVIV@?o0000?onc/k<5o`00
00_oVIVI1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo/omoOgl00ol0003o
IVIVofIVIP0GofIVIP?o00003OmoOgl5o`0000koVIVI1Ol0000cok>c/`Oo00003OnIVIT4o`0000Go
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooookCoOgmo00?o0000ofIVI_mVIVH0
6OmVIVH5o`0000goOgmo1_l0000=oiVIV@Oo00009_nc/k<6o`0000ooVIVI1Ol00003ogmoO`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooookGoOgmo00?o0000ofIVI_mVIVH07OmV
IVH6o`0000goOgmo1ol0000=oiVIV@Ko00006Onc/k<7o`0001;oVIVI0ol00008ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04oooookKoOgmo00?o0000ofIVI_mVIVH08_mVIVH5
o`0000ooOgmo0ol0000@oiVIVAWo00005?nIVIT5o`0000_oOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00Cooooo]omoOgl2o`0002OoIVIV2?l0000:ogmoO`[o00009_nIVIT=o`00
00goOgmo1?l00005ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooniogmoO`;o
0000;OmVIVH7o`0000goOgmo1_l0000IoiVIV@Oo00001OmoOgl3o`0000CoIVIV0ol00004ogmoO`Oo
00000omVIVH6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonkogmoO`;o0000
<_mVIVH=o`0000KoOgmo1ol0000<oiVIV@Ko00001omoOgl5o`0000[oIVIV1?l0000:ofIVIPKooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooookgoOgmo0_l0000mofIVIPKo00001omo
Ogl<o`0000KoOgmo1ol0000MofIVIPKooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
oooookooOgmo0_l0000EofIVIQWo00004omVIVHIo`0000goIVIV2?l00005ofIVIP_o00001Oooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo`OmoOgl2o`0001;oIVIV00?o0000oda<
C?m<C4`05om<C4`=o`0002KoIVIV1_l00008oda<C0Go00002_m<C4`6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?ooooo3ogmoO`Co00003OmVIVH3o`0002GoC4a<9_l0000Moda<C0Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooolOoOgmo0ol0000=ofIVIP;o0000
I_m<C4`6ooooo`7o00000Oooool001[ooooo0_l00005oooook3oOgmo1?l0000FogmoO`;o00003OmV
IVH2o`0006CoC4a<1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo/?moOgl0
1?l0003oVIVIoiVIVOnIVIT7o`00017oOgmo0_l0000=ofIVIP;o0000H_m<C4`6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?oooon_ogmoO`03o`000?nIVIWoVIVI00WoVIVI1_l0000=
ogmoO`;o00003OmVIVH2o`0001SoC4a<;ol0000Ioda<C0Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooojkoOgmo00?o0000oiVIVOnIVIT04?nIVIT4o`0000_oOgmo0ol0000<ofIV
IP;o00005_m<C4`00ol0003o<c<coc<c<`0/oc<c<`03o`000?m<C4coC4a<01GoC4a<0_l00005oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooon^ogmoO`03o`000?nIVIWoVIVI01Co
VIVI0_l0000<ogmoO`?o00002omVIVH2o`0001?oC4a<00?o0000oc<c<olc<c<0;_lc<c<00ol0003o
C4a<oda<C00Boda<C0;o000000?oIVIVooooooooool01?ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00Cooooo[OmoOgl2o`0001SoVIVI0ol0000<ogmoO`Co00002OmVIVH5o`0000koC4a<
1_l0000Voc<c<`Oo00003_m<C4`5o`0000?oIVIV1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00Cooooo[omoOgl00ol0003oVIVIoiVIV@0HoiVIV@Co00003?moOgl3o`0000_oIVIV1Ol0
000?oda<C0Ko00006Olc<c<7o`0001;oC4a<0ol00008ofIVIPKooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04oooook3oOgmo0_l0000LoiVIV@Oo00002?moOgl5o`0000_oIVIV0ol0000B
oda<C1Wo00005?m<C4`5o`0000_oIVIV1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00Cooooo/_moOgl00ol0003oVIVIoiVIV@0PoiVIV@Go00002?moOgl5o`0000WoIVIV1Ol0000coda<
C0Oo00003OmVIVH4o`0000Gooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooook?o
Ogmo0_l0000UoiVIV@?o00002_moOgl3o`0000_oIVIV1ol0000Voda<C0Ko00003OmVIVH7o`0000?o
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo]OmoOgl00ol0003oVIVI
oiVIV@0UoiVIV@Co00002OmoOgl5o`0000goIVIV3Ol0000Boda<C0Oo00003OmVIVH6o`0000[oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo]_moOgl2o`0002WoVIVI1_l0
0008ogmoO`go00003OmVIVHBo`0000goIVIV1ol0000;ogmoO`Ko00001Oooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00Cooooo^?moOgl2o`0002goVIVI0ol0000BogmoO`Ko00006OmVIVH=
o`0000goOgmo1Ol00005oiVIV@Kooooo0Ol00001ooooo`006_ooool2o`0000Gooooo^_moOgl00ol0
003oVIVIoiVIV@0]oiVIV@Go00001OmoOgl8o`0000KoOgmo6Ol00007ogmoO`Oo00001_moOgl6o`00
00[oVIVI1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo^omoOgl2o`0001[o
VIVI1?l0000DoiVIV@Go00002?nIVIT6o`0001WoOgmo1ol00007oiVIV@Ko00004?nIVIT6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?oooonmogmoO`;o00005onIVIT00ol0003o/k>c
ok>c/`02ok>c/`go00006_nIVITIo`0001[oVIVI2ol00005ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?oooonoogmoO`;o00005?nIVIT00ol0003o/k>cok>c/`0@ok>c/`Oo0000@?nI
VIT6o`0000[o/k>c1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo`OmoOgl2
o`00017oVIVI00?o0000ok>c/onc/k<06?nc/k<=o`0002KoVIVI3Ol0000@ok>c/`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04oooool?oOgmo0_l0000>oiVIV@?o00009_nc/k<Vo`00
01go/k>c1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooaOmoOgl2o`0000oo
VIVI0ol0001Vok>c/`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooook3oOgmo
1?l0000CogmoO`03o`000?nIVIWoVIVI00ooVIVI0_l0001Tok>c/`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04oooook3oOgmo00Co0000ofIVI_mVIVKoIVIV1Ol0000?ogmoO`;o0000
4OnIVIT2o`0006;o/k>c1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo[omo
Ogl00ol0003oIVIVofIVIP07ofIVIP?o00003_moOgl4o`0000ooVIVI0_l0001Pok>c/`Kooooo0Ol0
0001ooooo`001oooool01OnHV9So410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP06ooooo`03o`000?oooooooooo00Cooooo[_moOgl00ol0003oIVIVofIVIP0;ofIVIPCo0000
3_moOgl5o`0000coVIVI0ol0000Ook>c/a_o00008_nc/k<2o`0000Gooooo0Ol00001ooooo`001ooo
ool01Ol@413o^[ZjoooooomgMgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03
o`000?oooooooooo00Cooooo[OmoOgl2o`00017oIVIV0ol0000@ogmoO`?o00003?nIVIT2o`0001[o
/k>c1?l0000Jolc<c0Go00006Onc/k<4o`000003oiVIVOoooooooooo00Cooooo0Ol00001ooooo`00
2oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool01?ooool00ol0003o
ooooooooo`04ooooojooOgmo00?o0000ofIVI_mVIVH04OmVIVH3o`00013oOgmo0ol0000;oiVIV@?o
00006onc/k<7o`0001;oc<c<1?l0000Hok>c/`?o00001OnIVIT6ooooo`7o00000Oooool000[ooooo
00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo0ol00004oooook3o
Ogmo00?o0000ofIVI_mVIVH04omVIVH3o`00013oOgmo0_l0000<oiVIV@?o00007onc/k<Bo`0001Wo
/k>c0ol00008oiVIV@Cooooo0ol00001ooooo`002Oooool00ol@413o0000okZj^P03ooooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooooooo`04oooook7oOgmo00?o0000ofIVI_mV
IVH05OmVIVH9o`0000WoOgmo0_l0000=oiVIV@Go0000@Onc/k<4o`0000_oVIVI1_ooool1o`00007o
oooo000:ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03
o`000?oooooooooo00Cooooo/_moOgl00ol0003oIVIVofIVIP0MofIVIP;o00002OmoOgl5o`0000go
VIVI1_l0000hok>c/`?o00003onIVIT6ooooo`7o00000Oooool000Oooooo00Go410@oiRHV?oooooo
^[Zjo`000003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`04oooo
ok?oOgmo00?o0000ofIVI_mVIVH07_mVIVH00ol0003oOgmoogmoO`0;ogmoO`Go00003_nIVIT7o`00
02co/k>c1Ol0000?oiVIV@Co00001Oooool1o`00007ooooo0007ooooo`05ojVYZOl@413o0000oa0@
4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool01?oooond
ogmoO`03o`000?mVIVKoIVIV01koIVIV0_l0000@ogmoO`?o00004_nIVIT5o`00027o/k>c1_l0000?
oiVIV@Go00000omoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooneogmo
O`03o`000?mVIVKoIVIV01ooIVIV1?l0000?ogmoO`Go00004_nIVIT8o`0000co/k>c3Ol0000=oiVI
V@So00002?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonfogmoO`;o
00008omVIVH5o`0000ooOgmo1_l0000DoiVIV@co00004onIVIT7o`00013oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00Cooooo^?moOgl3o`0002GoIVIV0ol0000BogmoO`Oo0000
9_nIVIT6o`0001CoOgmo1?l00005ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
oonkogmoO`;o00009_mVIVH:o`0000ooOgmo1_l0000IoiVIV@Oo00004omoOgl7o`0000?oIVIV1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo_OmoOgl2o`0002koIVIV0ol0000B
ogmoOaWo00005?moOgl6o`0000[oIVIV1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00Cooooo_omoOgl00ol0003oIVIVofIVIP0^ofIVIPGo0000=?moOgl6o`00013oIVIV1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00Cooooo`?moOgl2o`0003?oIVIV1ol0000ZogmoO`?o
00005_mVIVH6ooooo`7o00000Oooool001[ooooo0_l00005oooool;oOgmo00?o0000ofIVI_mVIVH0
=omVIVH6o`0001WoOgmo2ol0000IofIVIPGooooo0_l00001ooooo`006_ooool00ol0003ooooooooo
o`04oooool?oOgmo0_l0000mofIVIQWo00009?mVIVH6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooo5ogmoO`?o0000MomVIVH6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?ooooo8ogmoO`;o0000MOmVIVH6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooo:ogmoO`;o0000LomVIVH6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?ooooo<ogmoO`03o`000?mVIVKoIVIV073oIVIV1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooocOmoOgl3o`0006ooIVIV1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00Coooood?moOgl2o`0006goIVIV1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00Coooood_moOgl3o`0006[oIVIV1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
ooooeOmoOgl2o`0006SoIVIV1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
eomoOgl3o`0006GoIVIV1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooof_mo
Ogl3o`0006;oIVIV1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooogOmoOgl4
o`0005koIVIV1_ooool1o`00007ooooo000Jooooo`;o00001OoooooQogmoO`?o0000FOmVIVH3o`00
00Cooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04ooooonCoOgmo0ol0001CofIVIP?o
00000_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooWogmoO`?o0000
COmVIVH3o`0000GoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Coooooj_mo
Ogl3o`0004OoIVIV0ol00008ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooongoOgmo0ol0000oofIVIPGo00002omoOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?ooooo`ogmoO`Go0000=?mVIVH6o`00013oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooomOmoOgl=o`00023oIVIV1ol0000FogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooooooOgmo0omoOglPo`0001goOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo
@?moOgl6ooooo`7o00000Oooool001[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Ooo
ool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooooomo
Ogm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
ooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo
@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000Wo
oooo0_l000002Ol@413oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool000Oooooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@41001_oo
ool3o`0000CooooooomoOgm0ogmoO`Cooooo0ol00001ooooo`001oooool01?m4A4CogMgMooooool0
0004ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooood[ooooo
0Ol00001ooooo`001oooool01?oMgMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool0
00001_ooool00ol0003oooooooooo`3ooooood[ooooo0Ol00001ooooo`002?ooool00omgMgOoc<c<
o`000004ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`3ooooood[o
oooo0Ol00001ooooo`002?ooool00oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01_ooool00ol0003oooooooooo`3ooooood[ooooo0Ol00001ooooo`002Oooool00omgMgOo0000
ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo03gooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0mooooo`03
o`000?oooooooooo03gooooo00?o0000ooooooooool08oooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02Oooool1o`00007ooooo000Joooooooo0000C_l0
0001ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-30.1723, -14.304, 0.195672, \
0.195672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0192308 0.211538 0.0192308 [
[.11538 -0.0125 -9 -9 ]
[.11538 -0.0125 9 0 ]
[.30769 -0.0125 -9 -9 ]
[.30769 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69231 -0.0125 -6 -9 ]
[.69231 -0.0125 6 0 ]
[.88462 -0.0125 -6 -9 ]
[.88462 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -18 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .21154 -6 -4.5 ]
[-0.0125 .21154 0 4.5 ]
[-0.0125 .40385 -12 -4.5 ]
[-0.0125 .40385 0 4.5 ]
[-0.0125 .59615 -12 -4.5 ]
[-0.0125 .59615 0 4.5 ]
[-0.0125 .78846 -12 -4.5 ]
[-0.0125 .78846 0 4.5 ]
[-0.0125 .98077 -12 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11538 0 m
.11538 .00625 L
s
[(-20)] .11538 -0.0125 0 1 Mshowa
.30769 0 m
.30769 .00625 L
s
[(-10)] .30769 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69231 0 m
.69231 .00625 L
s
[(10)] .69231 -0.0125 0 1 Mshowa
.88462 0 m
.88462 .00625 L
s
[(20)] .88462 -0.0125 0 1 Mshowa
.125 Mabswid
.15385 0 m
.15385 .00375 L
s
.19231 0 m
.19231 .00375 L
s
.23077 0 m
.23077 .00375 L
s
.26923 0 m
.26923 .00375 L
s
.34615 0 m
.34615 .00375 L
s
.38462 0 m
.38462 .00375 L
s
.42308 0 m
.42308 .00375 L
s
.46154 0 m
.46154 .00375 L
s
.53846 0 m
.53846 .00375 L
s
.57692 0 m
.57692 .00375 L
s
.61538 0 m
.61538 .00375 L
s
.65385 0 m
.65385 .00375 L
s
.73077 0 m
.73077 .00375 L
s
.76923 0 m
.76923 .00375 L
s
.80769 0 m
.80769 .00375 L
s
.84615 0 m
.84615 .00375 L
s
.07692 0 m
.07692 .00375 L
s
.03846 0 m
.03846 .00375 L
s
.92308 0 m
.92308 .00375 L
s
.96154 0 m
.96154 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(-10)] -0.0125 .01923 1 0 Mshowa
0 .21154 m
.00625 .21154 L
s
[(0)] -0.0125 .21154 1 0 Mshowa
0 .40385 m
.00625 .40385 L
s
[(10)] -0.0125 .40385 1 0 Mshowa
0 .59615 m
.00625 .59615 L
s
[(20)] -0.0125 .59615 1 0 Mshowa
0 .78846 m
.00625 .78846 L
s
[(30)] -0.0125 .78846 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(40)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .05769 m
.00375 .05769 L
s
0 .09615 m
.00375 .09615 L
s
0 .13462 m
.00375 .13462 L
s
0 .17308 m
.00375 .17308 L
s
0 .25 m
.00375 .25 L
s
0 .28846 m
.00375 .28846 L
s
0 .32692 m
.00375 .32692 L
s
0 .36538 m
.00375 .36538 L
s
0 .44231 m
.00375 .44231 L
s
0 .48077 m
.00375 .48077 L
s
0 .51923 m
.00375 .51923 L
s
0 .55769 m
.00375 .55769 L
s
0 .63462 m
.00375 .63462 L
s
0 .67308 m
.00375 .67308 L
s
0 .71154 m
.00375 .71154 L
s
0 .75 m
.00375 .75 L
s
0 .82692 m
.00375 .82692 L
s
0 .86538 m
.00375 .86538 L
s
0 .90385 m
.00375 .90385 L
s
0 .94231 m
.00375 .94231 L
s
.25 Mabswid
0 0 m
0 1 L
s
.11538 .99375 m
.11538 1 L
s
.30769 .99375 m
.30769 1 L
s
.5 .99375 m
.5 1 L
s
.69231 .99375 m
.69231 1 L
s
.88462 .99375 m
.88462 1 L
s
.125 Mabswid
.15385 .99625 m
.15385 1 L
s
.19231 .99625 m
.19231 1 L
s
.23077 .99625 m
.23077 1 L
s
.26923 .99625 m
.26923 1 L
s
.34615 .99625 m
.34615 1 L
s
.38462 .99625 m
.38462 1 L
s
.42308 .99625 m
.42308 1 L
s
.46154 .99625 m
.46154 1 L
s
.53846 .99625 m
.53846 1 L
s
.57692 .99625 m
.57692 1 L
s
.61538 .99625 m
.61538 1 L
s
.65385 .99625 m
.65385 1 L
s
.73077 .99625 m
.73077 1 L
s
.76923 .99625 m
.76923 1 L
s
.80769 .99625 m
.80769 1 L
s
.84615 .99625 m
.84615 1 L
s
.07692 .99625 m
.07692 1 L
s
.03846 .99625 m
.03846 1 L
s
.92308 .99625 m
.92308 1 L
s
.96154 .99625 m
.96154 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .21154 m
1 .21154 L
s
.99375 .40385 m
1 .40385 L
s
.99375 .59615 m
1 .59615 L
s
.99375 .78846 m
1 .78846 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .05769 m
1 .05769 L
s
.99625 .09615 m
1 .09615 L
s
.99625 .13462 m
1 .13462 L
s
.99625 .17308 m
1 .17308 L
s
.99625 .25 m
1 .25 L
s
.99625 .28846 m
1 .28846 L
s
.99625 .32692 m
1 .32692 L
s
.99625 .36538 m
1 .36538 L
s
.99625 .44231 m
1 .44231 L
s
.99625 .48077 m
1 .48077 L
s
.99625 .51923 m
1 .51923 L
s
.99625 .55769 m
1 .55769 L
s
.99625 .63462 m
1 .63462 L
s
.99625 .67308 m
1 .67308 L
s
.99625 .71154 m
1 .71154 L
s
.99625 .75 m
1 .75 L
s
.99625 .82692 m
1 .82692 L
s
.99625 .86538 m
1 .86538 L
s
.99625 .90385 m
1 .90385 L
s
.99625 .94231 m
1 .94231 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.6 g
.98077 .83081 m
.96115 .8369 L
.94152 .84204 L
.9219 .8434 L
.92186 .84341 L
.90228 .84502 L
.88265 .84676 L
.86303 .84789 L
.84341 .84819 L
.82378 .84765 L
.80416 .84632 L
.78454 .84449 L
.77035 .84341 L
.76491 .84254 L
.74529 .84076 L
.72567 .83525 L
.70604 .82905 L
.68704 .82378 L
.68642 .82358 L
.6668 .82235 L
.64717 .81013 L
.63394 .80416 L
.62755 .80136 L
.60793 .79995 L
.59237 .78454 L
.5883 .78223 L
.56868 .77091 L
.55898 .76491 L
.54906 .75691 L
.53611 .74529 L
.54906 .73744 L
.56868 .74053 L
.5883 .74511 L
.58894 .74529 L
.60793 .75088 L
.62755 .75621 L
.64717 .76026 L
.66248 .76491 L
.6668 .76618 L
.68642 .771 L
.70604 .76956 L
.72567 .77734 L
.74529 .7819 L
.76491 .78452 L
.76507 .78454 L
.78454 .78679 L
.80416 .78843 L
.82378 .78943 L
.84341 .78983 L
.86303 .78961 L
.88265 .78877 L
.90228 .78731 L
.9219 .78522 L
.92725 .78454 L
.94152 .78283 L
.96115 .77883 L
.98077 .77233 L
F
0 g
.98077 .83081 m
.96115 .8369 L
.94152 .84204 L
.9219 .8434 L
.92186 .84341 L
.90228 .84502 L
.88265 .84676 L
.86303 .84789 L
.84341 .84819 L
.82378 .84765 L
.80416 .84632 L
.78454 .84449 L
.77035 .84341 L
.76491 .84254 L
.74529 .84076 L
.72567 .83525 L
.70604 .82905 L
.68704 .82378 L
.68642 .82358 L
.6668 .82235 L
.64717 .81013 L
.63394 .80416 L
.62755 .80136 L
.60793 .79995 L
.59237 .78454 L
.5883 .78223 L
.56868 .77091 L
.55898 .76491 L
.54906 .75691 L
.53611 .74529 L
.54906 .73744 L
.56868 .74053 L
.5883 .74511 L
.58894 .74529 L
.60793 .75088 L
.62755 .75621 L
.64717 .76026 L
.66248 .76491 L
.6668 .76618 L
.68642 .771 L
.70604 .76956 L
.72567 .77734 L
.74529 .7819 L
.76491 .78452 L
.76507 .78454 L
.78454 .78679 L
.80416 .78843 L
.82378 .78943 L
.84341 .78983 L
.86303 .78961 L
Mistroke
.88265 .78877 L
.90228 .78731 L
.9219 .78522 L
.92725 .78454 L
.94152 .78283 L
.96115 .77883 L
.98077 .77233 L
Mfstroke
.4 g
.98077 .89949 m
.97105 .90228 L
.96115 .90486 L
.94152 .90989 L
.9219 .9143 L
.90228 .91775 L
.88265 .92003 L
.86303 .92114 L
.84341 .92138 L
.82378 .92093 L
.80416 .91951 L
.78454 .91689 L
.76491 .91315 L
.74529 .90852 L
.72567 .90343 L
.72111 .90228 L
.70604 .90181 L
.68642 .89193 L
.6668 .88329 L
.6652 .88265 L
.64717 .87492 L
.62755 .86579 L
.62295 .86303 L
.60793 .85495 L
.58843 .84341 L
.5883 .84332 L
.56868 .82993 L
.55964 .82378 L
.54906 .81108 L
.54793 .80416 L
.54906 .80384 L
.56013 .80416 L
.56868 .80616 L
.5883 .812 L
.60793 .81798 L
.6275 .82378 L
.62755 .8238 L
.64717 .83034 L
.6668 .83618 L
.68642 .84009 L
.69514 .84341 L
.70604 .84636 L
.72567 .85098 L
.74529 .85484 L
.76491 .85409 L
.78454 .85893 L
.80416 .86175 L
.8173 .86303 L
.82378 .86327 L
.84341 .86376 L
.86303 .86349 L
.87338 .86303 L
.88265 .8623 L
.90228 .85987 L
.9219 .85574 L
.94152 .85578 L
.96115 .85214 L
.98077 .84773 L
F
0 g
.98077 .89949 m
.97105 .90228 L
.96115 .90486 L
.94152 .90989 L
.9219 .9143 L
.90228 .91775 L
.88265 .92003 L
.86303 .92114 L
.84341 .92138 L
.82378 .92093 L
.80416 .91951 L
.78454 .91689 L
.76491 .91315 L
.74529 .90852 L
.72567 .90343 L
.72111 .90228 L
.70604 .90181 L
.68642 .89193 L
.6668 .88329 L
.6652 .88265 L
.64717 .87492 L
.62755 .86579 L
.62295 .86303 L
.60793 .85495 L
.58843 .84341 L
.5883 .84332 L
.56868 .82993 L
.55964 .82378 L
.54906 .81108 L
.54793 .80416 L
.54906 .80384 L
.56013 .80416 L
.56868 .80616 L
.5883 .812 L
.60793 .81798 L
.6275 .82378 L
.62755 .8238 L
.64717 .83034 L
.6668 .83618 L
.68642 .84009 L
.69514 .84341 L
.70604 .84636 L
.72567 .85098 L
.74529 .85484 L
.76491 .85409 L
.78454 .85893 L
.80416 .86175 L
.8173 .86303 L
.82378 .86327 L
.84341 .86376 L
Mistroke
.86303 .86349 L
.87338 .86303 L
.88265 .8623 L
.90228 .85987 L
.9219 .85574 L
.94152 .85578 L
.96115 .85214 L
.98077 .84773 L
Mfstroke
.4 g
.98077 .76558 m
.96115 .77032 L
.94152 .77567 L
.9219 .78112 L
.90228 .77915 L
.88265 .78073 L
.86303 .78165 L
.84341 .78189 L
.82378 .78146 L
.80416 .78035 L
.78454 .77859 L
.76491 .77957 L
.74529 .77416 L
.72567 .76886 L
.70674 .76491 L
.70604 .76474 L
.68642 .75947 L
.6668 .75946 L
.64717 .74726 L
.6421 .74529 L
.62755 .73947 L
.60793 .73129 L
.5956 .72567 L
.5883 .72156 L
.56868 .7103 L
.56167 .70604 L
.56868 .68889 L
.5883 .69194 L
.60793 .69578 L
.62755 .69386 L
.64717 .70522 L
.65701 .70604 L
.6668 .70836 L
.68642 .71233 L
.70604 .71028 L
.72567 .7188 L
.74529 .72425 L
.76491 .72393 L
.7828 .72567 L
.78454 .72582 L
.80416 .72724 L
.82378 .72812 L
.84341 .72846 L
.86303 .72827 L
.88265 .72754 L
.90228 .72627 L
.9096 .72567 L
.9219 .7245 L
.94152 .7223 L
.96115 .72047 L
.98077 .71339 L
F
0 g
.98077 .76558 m
.96115 .77032 L
.94152 .77567 L
.9219 .78112 L
.90228 .77915 L
.88265 .78073 L
.86303 .78165 L
.84341 .78189 L
.82378 .78146 L
.80416 .78035 L
.78454 .77859 L
.76491 .77957 L
.74529 .77416 L
.72567 .76886 L
.70674 .76491 L
.70604 .76474 L
.68642 .75947 L
.6668 .75946 L
.64717 .74726 L
.6421 .74529 L
.62755 .73947 L
.60793 .73129 L
.5956 .72567 L
.5883 .72156 L
.56868 .7103 L
.56167 .70604 L
.56868 .68889 L
.5883 .69194 L
.60793 .69578 L
.62755 .69386 L
.64717 .70522 L
.65701 .70604 L
.6668 .70836 L
.68642 .71233 L
.70604 .71028 L
.72567 .7188 L
.74529 .72425 L
.76491 .72393 L
.7828 .72567 L
.78454 .72582 L
.80416 .72724 L
.82378 .72812 L
.84341 .72846 L
.86303 .72827 L
.88265 .72754 L
.90228 .72627 L
.9096 .72567 L
.9219 .7245 L
.94152 .7223 L
.96115 .72047 L
Mistroke
.98077 .71339 L
Mfstroke
.6 g
.98077 .70703 m
.96115 .71324 L
.94152 .7143 L
.9219 .71691 L
.90228 .71894 L
.88265 .72039 L
.86303 .72124 L
.84341 .72146 L
.82378 .72106 L
.80416 .72005 L
.78454 .71843 L
.76491 .71623 L
.74529 .71967 L
.72567 .71123 L
.70631 .70604 L
.70604 .70598 L
.68642 .7008 L
.6668 .69526 L
.64717 .69315 L
.63903 .68642 L
.62755 .68139 L
.60793 .67264 L
.59553 .6668 L
.60793 .64965 L
.62755 .65216 L
.64717 .65506 L
.6668 .65802 L
.68642 .66064 L
.70604 .66389 L
.72567 .66668 L
.7265 .6668 L
.74529 .66914 L
.76491 .67112 L
.78454 .67266 L
.80416 .67378 L
.82378 .67447 L
.84341 .67474 L
.86303 .67459 L
.88265 .67402 L
.90228 .67302 L
.9219 .6716 L
.94152 .66974 L
.96115 .66742 L
.96583 .6668 L
.98077 .66469 L
F
0 g
.98077 .70703 m
.96115 .71324 L
.94152 .7143 L
.9219 .71691 L
.90228 .71894 L
.88265 .72039 L
.86303 .72124 L
.84341 .72146 L
.82378 .72106 L
.80416 .72005 L
.78454 .71843 L
.76491 .71623 L
.74529 .71967 L
.72567 .71123 L
.70631 .70604 L
.70604 .70598 L
.68642 .7008 L
.6668 .69526 L
.64717 .69315 L
.63903 .68642 L
.62755 .68139 L
.60793 .67264 L
.59553 .6668 L
.60793 .64965 L
.62755 .65216 L
.64717 .65506 L
.6668 .65802 L
.68642 .66064 L
.70604 .66389 L
.72567 .66668 L
.7265 .6668 L
.74529 .66914 L
.76491 .67112 L
.78454 .67266 L
.80416 .67378 L
.82378 .67447 L
.84341 .67474 L
.86303 .67459 L
.88265 .67402 L
.90228 .67302 L
.9219 .6716 L
.94152 .66974 L
.96115 .66742 L
.96583 .6668 L
.98077 .66469 L
s
.4 g
.98077 .65213 m
.96115 .65583 L
.94152 .65904 L
.9219 .66176 L
.90228 .66392 L
.88265 .66548 L
.86303 .66639 L
.84341 .66664 L
.82378 .66621 L
.80416 .66511 L
.78454 .66338 L
.76491 .66105 L
.74529 .65819 L
.72567 .65485 L
.70604 .65099 L
.68935 .64717 L
.68642 .6462 L
.6668 .63929 L
.64717 .63207 L
.63567 .62755 L
.64717 .61517 L
.6668 .61574 L
.68642 .61722 L
.70604 .61894 L
.72567 .62071 L
.74529 .6224 L
.76491 .62394 L
.78454 .62524 L
.80416 .62623 L
.82378 .62687 L
.84341 .62713 L
.86303 .62698 L
.88265 .62645 L
.90228 .62555 L
.9219 .62433 L
.94152 .62285 L
.96115 .6212 L
.98077 .61944 L
F
0 g
.98077 .65213 m
.96115 .65583 L
.94152 .65904 L
.9219 .66176 L
.90228 .66392 L
.88265 .66548 L
.86303 .66639 L
.84341 .66664 L
.82378 .66621 L
.80416 .66511 L
.78454 .66338 L
.76491 .66105 L
.74529 .65819 L
.72567 .65485 L
.70604 .65099 L
.68935 .64717 L
.68642 .6462 L
.6668 .63929 L
.64717 .63207 L
.63567 .62755 L
.64717 .61517 L
.6668 .61574 L
.68642 .61722 L
.70604 .61894 L
.72567 .62071 L
.74529 .6224 L
.76491 .62394 L
.78454 .62524 L
.80416 .62623 L
.82378 .62687 L
.84341 .62713 L
.86303 .62698 L
.88265 .62645 L
.90228 .62555 L
.9219 .62433 L
.94152 .62285 L
.96115 .6212 L
.98077 .61944 L
s
.3 g
.98077 .75456 m
.96115 .76007 L
.94152 .76481 L
.94107 .76491 L
.9219 .77146 L
.90228 .77091 L
.88265 .77272 L
.86303 .77375 L
.84341 .77403 L
.82378 .77354 L
.80416 .77229 L
.78454 .77026 L
.76491 .76939 L
.75118 .76491 L
.74529 .76357 L
.72567 .7586 L
.70604 .75287 L
.68642 .74611 L
.6843 .74529 L
.6668 .73406 L
.6655 .72567 L
.6668 .72549 L
.68642 .72527 L
.69326 .72567 L
.70604 .7269 L
.72567 .72894 L
.74529 .73087 L
.76491 .73253 L
.78454 .73388 L
.80416 .73487 L
.82378 .7355 L
.84341 .73575 L
.86303 .73561 L
.88265 .73509 L
.90228 .73419 L
.9219 .73294 L
.94152 .73136 L
.96115 .7295 L
.98077 .72747 L
F
0 g
.98077 .75456 m
.96115 .76007 L
.94152 .76481 L
.94107 .76491 L
.9219 .77146 L
.90228 .77091 L
.88265 .77272 L
.86303 .77375 L
.84341 .77403 L
.82378 .77354 L
.80416 .77229 L
.78454 .77026 L
.76491 .76939 L
.75118 .76491 L
.74529 .76357 L
.72567 .7586 L
.70604 .75287 L
.68642 .74611 L
.6843 .74529 L
.6668 .73406 L
.6655 .72567 L
.6668 .72549 L
.68642 .72527 L
.69326 .72567 L
.70604 .7269 L
.72567 .72894 L
.74529 .73087 L
.76491 .73253 L
.78454 .73388 L
.80416 .73487 L
.82378 .7355 L
.84341 .73575 L
.86303 .73561 L
.88265 .73509 L
.90228 .73419 L
.9219 .73294 L
.94152 .73136 L
.96115 .7295 L
.98077 .72747 L
s
.7 g
.98077 .81441 m
.96115 .82065 L
.95006 .82378 L
.94152 .82769 L
.9219 .82978 L
.90228 .83276 L
.88265 .83484 L
.86303 .83603 L
.84341 .83635 L
.82378 .83579 L
.80416 .83435 L
.78454 .83202 L
.76491 .82878 L
.74529 .82506 L
.74229 .82378 L
.72567 .819 L
.70604 .81249 L
.68642 .80464 L
.68536 .80416 L
.68642 .78681 L
.70604 .78876 L
.72567 .79111 L
.74529 .79333 L
.76491 .79525 L
.78454 .79681 L
.80416 .79797 L
.82378 .79869 L
.84341 .79898 L
.86303 .79882 L
.88265 .79821 L
.90228 .79718 L
.9219 .79573 L
.94152 .7939 L
.96115 .79175 L
.98077 .78942 L
F
0 g
.98077 .81441 m
.96115 .82065 L
.95006 .82378 L
.94152 .82769 L
.9219 .82978 L
.90228 .83276 L
.88265 .83484 L
.86303 .83603 L
.84341 .83635 L
.82378 .83579 L
.80416 .83435 L
.78454 .83202 L
.76491 .82878 L
.74529 .82506 L
.74229 .82378 L
.72567 .819 L
.70604 .81249 L
.68642 .80464 L
.68536 .80416 L
.68642 .78681 L
.70604 .78876 L
.72567 .79111 L
.74529 .79333 L
.76491 .79525 L
.78454 .79681 L
.80416 .79797 L
.82378 .79869 L
.84341 .79898 L
.86303 .79882 L
.88265 .79821 L
.90228 .79718 L
.9219 .79573 L
.94152 .7939 L
.96115 .79175 L
.98077 .78942 L
s
.6 g
.98077 .59503 m
.96115 .60126 L
.94152 .60641 L
.93468 .60793 L
.9219 .60949 L
.90228 .6114 L
.88265 .61273 L
.86303 .61349 L
.84341 .6137 L
.82378 .61334 L
.80416 .61241 L
.78454 .61092 L
.76491 .60885 L
.75764 .60793 L
.74529 .6051 L
.72567 .59961 L
.70604 .5931 L
.69376 .5883 L
.70604 .58433 L
.72567 .5834 L
.74529 .58359 L
.76491 .58412 L
.78454 .58471 L
.80416 .58522 L
.82378 .58557 L
.84341 .58571 L
.86303 .58563 L
.88265 .58533 L
.90228 .58486 L
.9219 .58428 L
.94152 .58372 L
.96115 .58339 L
.98077 .58385 L
F
0 g
.98077 .59503 m
.96115 .60126 L
.94152 .60641 L
.93468 .60793 L
.9219 .60949 L
.90228 .6114 L
.88265 .61273 L
.86303 .61349 L
.84341 .6137 L
.82378 .61334 L
.80416 .61241 L
.78454 .61092 L
.76491 .60885 L
.75764 .60793 L
.74529 .6051 L
.72567 .59961 L
.70604 .5931 L
.69376 .5883 L
.70604 .58433 L
.72567 .5834 L
.74529 .58359 L
.76491 .58412 L
.78454 .58471 L
.80416 .58522 L
.82378 .58557 L
.84341 .58571 L
.86303 .58563 L
.88265 .58533 L
.90228 .58486 L
.9219 .58428 L
.94152 .58372 L
.96115 .58339 L
.98077 .58385 L
s
.7 g
.98077 .69262 m
.96115 .69923 L
.94152 .70469 L
.93597 .70604 L
.9219 .70832 L
.90228 .7108 L
.88265 .71251 L
.86303 .7135 L
.84341 .71376 L
.82378 .7133 L
.80416 .71211 L
.78454 .71018 L
.76491 .70748 L
.75634 .70604 L
.74529 .70328 L
.72567 .6975 L
.70604 .6905 L
.69674 .68642 L
.70604 .68091 L
.72567 .67991 L
.74529 .6803 L
.76491 .68103 L
.78454 .68178 L
.80416 .6824 L
.82378 .68281 L
.84341 .68298 L
.86303 .68289 L
.88265 .68254 L
.90228 .68197 L
.9219 .68125 L
.94152 .68049 L
.96115 .67995 L
.98077 .68032 L
F
0 g
.98077 .69262 m
.96115 .69923 L
.94152 .70469 L
.93597 .70604 L
.9219 .70832 L
.90228 .7108 L
.88265 .71251 L
.86303 .7135 L
.84341 .71376 L
.82378 .7133 L
.80416 .71211 L
.78454 .71018 L
.76491 .70748 L
.75634 .70604 L
.74529 .70328 L
.72567 .6975 L
.70604 .6905 L
.69674 .68642 L
.70604 .68091 L
.72567 .67991 L
.74529 .6803 L
.76491 .68103 L
.78454 .68178 L
.80416 .6824 L
.82378 .68281 L
.84341 .68298 L
.86303 .68289 L
.88265 .68254 L
.90228 .68197 L
.9219 .68125 L
.94152 .68049 L
.96115 .67995 L
.98077 .68032 L
s
.2 g
.78454 .74496 m
.80416 .74484 L
.82378 .74491 L
.84341 .74496 L
.86303 .74493 L
.88265 .74486 L
.90228 .74488 L
.91841 .74529 L
.90228 .75806 L
.88265 .76146 L
.86303 .7633 L
.84341 .76378 L
.82378 .76293 L
.80416 .76068 L
.78454 .75676 L
.7739 .74529 L
F
0 g
.78454 .74496 m
.80416 .74484 L
.82378 .74491 L
.84341 .74496 L
.86303 .74493 L
.88265 .74486 L
.90228 .74488 L
.91841 .74529 L
.90228 .75806 L
.88265 .76146 L
.86303 .7633 L
.84341 .76378 L
.82378 .76293 L
.80416 .76068 L
.78454 .75676 L
.7739 .74529 L
.78454 .74496 L
s
.3 g
.78454 .64572 m
.80416 .64285 L
.82378 .64218 L
.84341 .642 L
.86303 .6421 L
.88265 .64258 L
.90228 .64425 L
.90962 .64717 L
.90228 .64853 L
.88265 .65116 L
.86303 .6526 L
.84341 .65297 L
.82378 .65231 L
.80416 .65056 L
.78454 .6475 L
.78289 .64717 L
F
0 g
.78454 .64572 m
.80416 .64285 L
.82378 .64218 L
.84341 .642 L
.86303 .6421 L
.88265 .64258 L
.90228 .64425 L
.90962 .64717 L
.90228 .64853 L
.88265 .65116 L
.86303 .6526 L
.84341 .65297 L
.82378 .65231 L
.80416 .65056 L
.78454 .6475 L
.78289 .64717 L
.78454 .64572 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00?Oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0dooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kS?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0hooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8b
onk^kS?ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08_ooool003gooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0=_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0<oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg03?ooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL08_ooool003Gooooo1_l0
0003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400[ooooo`Ko0000
1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100<oooool01Ol@413o
oooooooooooooooo410@03[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@03Cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@02;ooooo000o
ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000fooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000cooooo`05o`000?ooooooooooooooool0
0000>_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000=Oooool00onH
V9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000008_ooool0043ooooo00?oMgMgofIV
I_ooool00_ooool01Ol0003ooooooooooooooooo000003Kooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000003?ooooo00Go0000ooooooooooooooooo`00000jooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`03ogMgMomVIVKooooo00;o
oooo00Go0000ooooooooooooooooo`00000Rooooo`00@Oooool01Ol0003ooooooooooooooooo410@
00?ooooo00?o410@ooooooooool0=?ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@4100<oooool01Ol@413ooooooooooooooooo410@03[ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@03Oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo023ooooo000mooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg03Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg03?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0jooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0cooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02;ooooo000mooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^03Cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^03?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`03oeEEEOmVIVKo000000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0cooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02;ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo000Joooooooo0000C_l00001ooooo`00
6_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0?Ooo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool08ooo
ool1o`00007ooooo0008ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKo
oooo00?o0000ooooooooool0oooooom:ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooom:ooooo`7o
00000Oooool000Go00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41001_ooool00ol0003oooooooooo`3ooooood[ooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?ooooooB?ooool3o`00007o
oooo000:ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo0008ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Oooooooogmo
Od3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Ooo
ooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000oooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`003ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000?ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000oooooo00Go0000oooooooooooooooo
o`000006ooooo`?o00001?ooooooogmoOd3oOgmo1?ooool3o`00007ooooo000?ooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool000oooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`003oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000?ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo0008
ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000:ooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`002_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41001_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000[ooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo0ol00004oooooooo
Ogmo@?moOgl4ooooo`?o00000Oooool000[ooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000:ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool000Sooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooWogmoO`ko0000@?moOgl8o`0000;o
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Coooooh_moOgl5o`0000koVIVI
@?l00008oiVIV@?o00001Oooool1o`00007ooooo0007ooooo`Go00000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Kooooo00?o0000ooooooooool01?oooooPogmoO`;o0000GOnIVIT6ooooo`7o0000
0Oooool000Oooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01_ooool00ol0003oooooooooo`04ooooon;oOgmo0_l0001KoiVIV@Kooooo0Ol00001ooooo`00
2?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003o
ooooooooo`04ooooonCoOgmo0ol0001FoiVIV@?o00001Oooool1o`00007ooooo0009ooooo`03oiRH
V?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000006ooooo`?o00001?oooooWogmoO`?o
0000D?nIVIT3o`0000;oOgmo1?ooool3o`00007ooooo000:ooooo`03ogMgMomVIVKooooo00;ooooo
00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00Coooooj_moOgl3o`0004[o
VIVI0ol00005ogmoO`Kooooo0Ol00001ooooo`002oooool01Ol0003ooooooooooooooooo410@00?o
oooo00?o410@ooooooooool01?ooool00ol0003oooooooooo`04ooooongoOgmo0ol00014oiVIV@?o
00002?moOgl6ooooo`7o00000Oooool000Oooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`04oooooo3oOgmo1?l0000moiVI
V@?o00002omoOgl6ooooo`7o00000Oooool000Oooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`04ooooooCoOgmo2?l0000/
oiVIV@Wo00003_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooologmo
Obco00005omoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooo@ogmoO`_o
0000I?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooo?ogmoO`03o`00
0?mVIVKoIVIV00WoIVIV3Ol0001DogmoO`Co00001Oooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00Coooooc_moOgl00ol0003oIVIVofIVIP0GofIVIPgo0000@?moOgl7o`0000?oIVIV1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooocOmoOgl00ol0003oIVIVofIVIP0U
ofIVIPgo00008?moOglCo`0000[oIVIV1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00Coooooc?moOgl2o`0003CoIVIV8?l0000MofIVIPKooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooolkoOgmo0_l0001_ofIVIPKooooo0Ol00001ooooo`006_ooool2o`0000Gooooo
d?moOgl3o`0006coIVIV1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooodomo
Ogl3o`0006WoIVIV1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Coooooe_moOgl4
o`0006GoIVIV1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooof_moOgl3o`00
02CoIVIV8_l0000LofIVIPKooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooomgo
Ogmo00?o0000ofIVI_mVIVH07_mVIVH3o`0002;oC4a<1?l0000HofIVIPKooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04oooool?oOgmo1Ol0000FogmoO`Co00006omVIVH5o`00023oC4a<
1_l0000GofIVIPKooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooool?oOgmo00?o
0000oiVIVOnIVIT00_nIVIT6o`0001CoOgmo1_l0000JofIVIPgo00001_m<C4`=o`0001[oIVIV1?l0
0005ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooo2ogmoO`03o`000?nIVIWo
VIVI00WoVIVI1ol0000CogmoO`Oo00008?mVIVH6o`0002;oIVIV1Ol00003ogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04oooool7oOgmo00?o0000oiVIVOnIVIT04OnIVIT6o`00
01CoOgmo1_l0000oofIVIP?o00002?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooo1ogmoO`03o`000?nIVIWoVIVI01OoVIVI1ol0000CogmoO`Oo0000;?mVIVH<o`0000_o
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo`?moOgl00ol0003oVIVI
oiVIV@0OoiVIV@Ko00005?moOgl6o`00023oIVIV1_l0000EogmoO`?o00001Oooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00Cooooo_omoOgl2o`0002OoVIVI1ol0000CogmoOb3o00004omo
Ogl8o`0000;oVIVI1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo`OmoOgl2
o`0002coVIVI1_l0000jogmoO`Ko00002_nIVIT6ooooo`7o00000Oooool001[ooooo0_l00005oooo
ol?oOgmo0_l0000`oiVIVACo00006OmoOgl=o`00013oVIVI1Oooool2o`00007ooooo000Jooooo`03
o`000?oooooooooo00CoooooaOmoOgl3o`00047oVIVI6Ol0000MoiVIV@Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooolSoOgmo0_l0000MoiVIV@So0000A_nIVIT8o`0000;oVIVI
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooob_moOgl2o`0001OoVIVI1?l0
0008ok>c/dKo00002?nc/k<3o`0000Gooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooolcoOgmo00?o0000oiVIVOnIVIT04onIVIT00ol0003o/k>cok>c/`1Jok>c/`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04oooookKoOgmo1Ol0000BogmoO`;o00004_nIVIT3o`00
05_o/k>c1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo]_moOgl00ol0003o
IVIVofIVIP02ofIVIPGo00003omoOgl00ol0003oVIVIoiVIV@0BoiVIV@?o0000F?nc/k<6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooneogmoO`03o`000?mVIVKoIVIV00SoIVIV
0ol00004ogmoO`Go00001?moOgl5o`0001;oVIVI0ol0001Cok>c/`?o00001Oooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00Cooooo]OmoOgl00ol0003oIVIVofIVIP0;ofIVIPCo00001OmV
IVH00ol0003oOgmoogmoO`06ogmoO`Ko00003onIVIT3o`0004go/k>c0ol00002oiVIV@Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04oooookGoOgmo00?o0000ofIVI_mVIVH05OmVIVH2
o`0000coOgmo1Ol0000=oiVIV@?o0000Aonc/k<3o`0000GoVIVI1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00Cooooo]?moOgl00ol0003oIVIVofIVIP0HofIVIP03o`000?moOgooOgmo
00koOgmo0ol0000=oiVIV@Co0000@?nc/k<3o`0000SoVIVI1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00Cooooo]?moOgl00ol0003oIVIVofIVIP0IofIVIPKo00003OmoOgl4o`0000go
VIVI0ol0000gok>c/`Ko00002_nIVIT2o`0000Gooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04oooookGoOgmo00?o0000ofIVI_mVIVH07_mVIVH5o`0000coOgmo0ol0000=oiVIV@Go0000
;?nc/k<6o`0000goVIVI0ol000000omoOgooooooooooo`04ooooo`7o00000Oooool001[ooooo0_l0
0005oooookKoOgmo0_l0000SofIVIPco00000omoOgl2o`00013oVIVI3Ol0000Bok>c/`go00004OnI
VIT2o`0000CoOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo^?moOgl3
o`0002coIVIV0ol00002ogmoO`?o00006_nIVITBo`0001CoVIVI2_l00004ogmoO`?o00001Oooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo^omoOgl2o`0002goIVIV0ol00002ogmo
O`;o00000onIVIT>o`00023oVIVI3Ol0000;ogmoO`?o00000_mVIVH6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?oooonmogmoO`03o`000?mVIVKoIVIV02goIVIV0ol000001?moOgoo
0000o`000?l0000>ogmoOb3o00004omoOgl5o`0000GoIVIV1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00Cooooo__moOgl00ol0003oIVIVofIVIP0_ofIVIP_o0000;_moOgl<o`0000[o
IVIV1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo_omoOgl2o`0001GoIVIV
4_l0000CofIVIQCo00003?moOgl>o`0001?oIVIV1?l00005ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?ooooo1ogmoO`;o00004omVIVH00ol0003oC4a<oda<C00?oda<C0go00006_mV
IVH<o`0001[oIVIV1ol00003oda<C0Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
oooool?oOgmo0ol0000AofIVIP;o00007?m<C4`=o`00023oIVIV4ol0000:oda<C0Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooolKoOgmo0ol0000@ofIVIP03o`000?m<C4coC4a<
02KoC4a<8?l0000Moda<C0Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooojoo
Ogmo1Ol0000EogmoO`?o00003_mVIVH00ol0003oC4a<oda<C01Roda<C0Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooojcoOgmo0ol00005oiVIV@Oo00004OmoOgl2o`0000goIVIV
00?o0000oda<C?m<C4`0HOm<C4`6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
oon[ogmoO`;o00003_nIVIT5o`0000koOgmo0_l0000<ofIVIP?o00006om<C4`ao`0001CoC4a<1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo[OmoOgl00ol0003oVIVIoiVIV@0@
oiVIV@?o00003OmoOgl2o`0000goIVIV0ol0000Ioda<C003o`000?lc<c?o<c<c02[o<c<c00?o0000
oda<C?m<C4`05?m<C4`6ooooo`7o00000Oooool001[ooooo0_l00005ooooojkoOgmo00?o0000oiVI
VOnIVIT04_nIVIT3o`0000coOgmo0_l0000>ofIVIP;o00006?m<C4`00ol0003o<c<coc<c<`0Xoc<c
<`03o`000?m<C4coC4a<01GoC4a<1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooo[omoOgl00ol0003oVIVIoiVIV@0DoiVIV@?o00002omoOgl00ol0003oIVIVofIVIP0=ofIVIP?o
00005_m<C4`00ol0003o<c<coc<c<`0Voc<c<`03o`000?m<C4coC4a<01CoC4a<0ol00005ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?oooon`ogmoO`03o`000?nIVIWoVIVI01KoVIVI
1Ol00007ogmoO`;o00004?mVIVH3o`0001CoC4a<1?l0000Qoc<c<`?o00005?m<C4`3o`0000;oIVIV
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo/OmoOgl00ol0003oVIVIoiVI
V@0JoiVIV@Co00001OmoOgl9o`0000[oIVIV1Ol0000Coda<C0Oo00005olc<c<3o`0001CoC4a<0ol0
0005ofIVIPKooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooook;oOgmo00?o0000
oiVIVOnIVIT07OnIVIT3o`0000_oOgmo0ol0000<ofIVIPCo00005_m<C4`Go`0001CoC4a<0ol00008
ofIVIPKooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooook?oOgmo0_l0000PoiVI
V@Go00002OmoOgl5o`0000_oIVIV0ol0000joda<C0Co00002?mVIVH4o`0000Gooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04oooookGoOgmo00?o0000oiVIVOnIVIT08_nIVIT3o`0000Co
Ogmo1Ol00002ogmoO`Go00002OmVIVH<o`0002_oC4a<0ol00007ofIVIPGo00000omoOgl6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?oooonfogmoO`;o00009OnIVIT4o`0000GoVIVI
0_l00005ogmoO`?o00004_mVIVH7o`0001;oC4a<4_l00007ofIVIP?o00001_moOgl3o`0000Gooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooookSoOgmo0ol0000]oiVIV@;o00001_mo
Ogl4o`0001GoIVIV4_l0000EofIVIPCo00001_moOgl3o`0000;oVIVI1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00Cooooo^omoOgl2o`0002goVIVI1Ol00005ogmoO`?o00001?mVIVH7
o`00023oIVIV1ol00004ofIVIP?o00001omoOgl3o`0000GoVIVI1_ooool1o`00007ooooo0007oooo
o`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o
0000ooooooooool01?oooonmogmoO`03o`000?nIVIWoVIVI02ooVIVI1_l00002ogmoO`Co00001omo
OglPo`0000OoOgmo1?l00007ogmoO`?o00002?nIVIT6ooooo`7o00000Oooool000Oooooo00Go410@
okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003ooooo
ooooo`04oooookkoOgmo00?o0000oiVIVOnIVIT0=?nIVIT7o`0002coOgmo3?l0000;oiVIV@Kooooo
0Ol00001ooooo`002oooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0
1?ooool00ol0003oooooooooo`04oooookooOgmo00?o0000oiVIVOnIVIT06onIVIT5o`0001[oVIVI
1_l0000PogmoO`Ko00005onIVIT6ooooo`7o00000Oooool000[ooooo00?oZJVYoa0@4?ooool00_oo
ool01Ol0003ooooooooooooooooo000000Kooooo0ol00004oooool3oOgmo00?o0000oiVIVOnIVIT0
6_nIVIT00ol0003o/k>cok>c/`02ok>c/`go00004onIVITPo`0001[oVIVI1?l00003ooooo`?o0000
0Oooool000Wooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool01?ooooo1ogmoO`03o`000?nIVIWoVIVI01WoVIVI00?o0000ok>c/onc/k<0
3onc/k<6o`0003[oVIVI3Ol00003ok>c/`Kooooo0Ol00001ooooo`002_ooool00onj^[[o8B4Qoooo
o`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`04oooool;oOgmo
00?o0000oiVIVOnIVIT06?nIVIT00ol0003o/k>cok>c/`0Eok>c/`go00008?nIVIT=o`00013o/k>c
1_ooool1o`00007ooooo0007ooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooo3ogmoO`Go00005OnIVIT00ol0003o
/k>cok>c/`0Rok>c/b3o00007Onc/k<6ooooo`7o00000Oooool000Oooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`04oooo
olSoOgmo1?l0000AoiVIV@03o`000?nc/k?o/k>c05oo/k>c1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00Cooooo[omoOgl:o`0001?oOgmo0_l0000?oiVIV@;o0000H?nc/k<6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?oooon_ogmoO`03o`000?mVIVKoIVIV00OoIVIV
0ol0000BogmoO`;o00003onIVIT3o`0005go/k>c1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00Cooooo/?moOgl00ol0003oIVIVofIVIP09ofIVIPCo00004?moOgl2o`00013oVIVI0_l0
001Kok>c/`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooook3oOgmo00?o0000
ofIVI_mVIVH03OmVIVH3o`0000ooOgmo0_l0000@oiVIV@?o0000E_nc/k<3o`0000Gooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04oooook7oOgmo00?o0000ofIVI_mVIVH03omVIVH3o`00
00koOgmo00?o0000oiVIVOnIVIT04?nIVIT3o`00053o/k>c0ol00002oiVIV@Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04oooook;oOgmo00?o0000ofIVI_mVIVH04OmVIVH3o`0000co
Ogmo0_l0000CoiVIV@Co0000BOnc/k<3o`0000GoVIVI1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00Cooooo/omoOgl2o`0001CoIVIV1?l0000:ogmoO`Wo00003_nIVIT3o`0004?o/k>c
0ol00008oiVIV@Kooooo0Ol00001ooooo`006_ooool2o`0000Gooooo]OmoOgl00ol0003oIVIVofIV
IP0EofIVIP?o00004?moOgl3o`0000koVIVI1?l0000nok>c/`03o`000?nIVIWoVIVI00WoVIVI1Ooo
ool2o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo]_moOgl2o`0001SoIVIV0ol0000@
ogmoO`Co00003_nIVIT7o`0002co/k>c2ol0000<oiVIV@Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04oooookSoOgmo00?o0000ofIVI_mVIVH06?mVIVH3o`00017oOgmo0ol0000BoiVI
V@Ko00008?nc/k<6o`0001GoVIVI0ol00005ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooniogmoO`;o00006omVIVH4o`00013oOgmo0ol0000EoiVIVB3o00006?nIVIT3o`0000;o
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo^omoOgl00ol0003oIVIV
ofIVIP0LofIVIP?o00004?moOgl3o`0004GoVIVI1Ol00005ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04oooookcoOgmo00?o0000ofIVI_mVIVH07_mVIVH3o`00013oOgmo2Ol0
000foiVIV@Ko00002_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonm
ogmoO`;o00008OmVIVH3o`0001KoOgmo2Ol0000PoiVIV@go00004?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?oooonoogmoO`03o`000?mVIVKoIVIV027oIVIV1Ol0000Jogmo
Ob3o00006omoOgl3o`0000Gooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooool3o
Ogmo0_l0000VofIVIPGo0000COmoOgl3o`0000;oIVIV1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00Cooooo`_moOgl00ol0003oIVIVofIVIP0XofIVIP?o00001?moOgl6o`0003_oOgmo
1Ol00005ofIVIPKooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooool?oOgmo0_l0
000[ofIVIPCo00001_mVIVH3o`0002_oOgmo3Ol0000:ofIVIPKooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooolGoOgmo0ol0000eofIVIPGo00008?moOgl6o`0001OoIVIV1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooob?moOgl2o`0003SoIVIV3Ol00006ogmo
O`go00007OmVIVH6ooooo`7o00000Oooool001[ooooo0_l00005oooool[oOgmo0_l00013ofIVIPKo
0000:_mVIVH5ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool01?ooooo<ogmoO`;o0000
LOmVIVH6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooo>ogmoO`;o0000KomV
IVH6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooo@ogmoO`;o0000KOmVIVH6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooBogmoO`;o0000JomVIVH6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooDogmoO`;o0000JOmVIVH6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?oooooFogmoO`?o0000I_mVIVH6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?oooooIogmoO`;o0000I?mVIVH6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?oooooKogmoO`;o0000H_mVIVH6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?oooooMogmoO`;o0000H?mVIVH6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?oooooOogmoO`?o0000GOmVIVH6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?oooooRogmoO`;o0000F_mVIVH2o`0000Gooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooonCoOgmo1_l0001@ofIVIPCo000000?oOgmoooooooooool01?oo
ool1o`00007ooooo000Jooooo`;o00001OoooooZogmoO`Go0000B?mVIVH3o`0000GoOgmo1Oooool2
o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooookomoOgl5o`00043oIVIV0ol00008ogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooCoOgmo0ol0000hofIVIPGo
00002omoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooogogmoO`Go0000
;?mVIVH7o`00013oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Coooooo?mo
Ogl6o`00023oIVIV1_l0000GogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo0omoOgl7o`0001;oIVIV1ol0000MogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo2_moOglBo`0002CoOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo0009ooooo`;o000000Wo410@oooooooooooo
ooooonk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6
ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo0007oooo
o`Go00000oooool01Ol@413ooooooooooooooooo410@00Kooooo0ol00004ooooooooOgmo@?moOgl4
ooooo`?o00000Oooool000Oooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooo
oooo000000Kooooo00?o0000ooooooooool0oooooom:ooooo`7o00000Oooool000Oooooo00CogMgM
oeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0
oooooom:ooooo`7o00000Oooool000Sooooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooo
oooooooo410@00Kooooo00?o0000ooooooooool0oooooom:ooooo`7o00000Oooool000Sooooo00?o
k^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0
oooooom:ooooo`7o00000Oooool000Wooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Kooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0mooooo`03o`00
0?oooooooooo03gooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0mooooo`03o`00
0?oooooooooo02?ooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00Wooooo0Ol00001ooooo`006_ooooooo`0004ko00000Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-30.1723, -14.304, 0.195672, \
0.195672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0192308 0.211538 0.0192308 [
[.11538 -0.0125 -9 -9 ]
[.11538 -0.0125 9 0 ]
[.30769 -0.0125 -9 -9 ]
[.30769 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69231 -0.0125 -6 -9 ]
[.69231 -0.0125 6 0 ]
[.88462 -0.0125 -6 -9 ]
[.88462 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -18 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .21154 -6 -4.5 ]
[-0.0125 .21154 0 4.5 ]
[-0.0125 .40385 -12 -4.5 ]
[-0.0125 .40385 0 4.5 ]
[-0.0125 .59615 -12 -4.5 ]
[-0.0125 .59615 0 4.5 ]
[-0.0125 .78846 -12 -4.5 ]
[-0.0125 .78846 0 4.5 ]
[-0.0125 .98077 -12 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11538 0 m
.11538 .00625 L
s
[(-20)] .11538 -0.0125 0 1 Mshowa
.30769 0 m
.30769 .00625 L
s
[(-10)] .30769 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69231 0 m
.69231 .00625 L
s
[(10)] .69231 -0.0125 0 1 Mshowa
.88462 0 m
.88462 .00625 L
s
[(20)] .88462 -0.0125 0 1 Mshowa
.125 Mabswid
.15385 0 m
.15385 .00375 L
s
.19231 0 m
.19231 .00375 L
s
.23077 0 m
.23077 .00375 L
s
.26923 0 m
.26923 .00375 L
s
.34615 0 m
.34615 .00375 L
s
.38462 0 m
.38462 .00375 L
s
.42308 0 m
.42308 .00375 L
s
.46154 0 m
.46154 .00375 L
s
.53846 0 m
.53846 .00375 L
s
.57692 0 m
.57692 .00375 L
s
.61538 0 m
.61538 .00375 L
s
.65385 0 m
.65385 .00375 L
s
.73077 0 m
.73077 .00375 L
s
.76923 0 m
.76923 .00375 L
s
.80769 0 m
.80769 .00375 L
s
.84615 0 m
.84615 .00375 L
s
.07692 0 m
.07692 .00375 L
s
.03846 0 m
.03846 .00375 L
s
.92308 0 m
.92308 .00375 L
s
.96154 0 m
.96154 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(-10)] -0.0125 .01923 1 0 Mshowa
0 .21154 m
.00625 .21154 L
s
[(0)] -0.0125 .21154 1 0 Mshowa
0 .40385 m
.00625 .40385 L
s
[(10)] -0.0125 .40385 1 0 Mshowa
0 .59615 m
.00625 .59615 L
s
[(20)] -0.0125 .59615 1 0 Mshowa
0 .78846 m
.00625 .78846 L
s
[(30)] -0.0125 .78846 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(40)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .05769 m
.00375 .05769 L
s
0 .09615 m
.00375 .09615 L
s
0 .13462 m
.00375 .13462 L
s
0 .17308 m
.00375 .17308 L
s
0 .25 m
.00375 .25 L
s
0 .28846 m
.00375 .28846 L
s
0 .32692 m
.00375 .32692 L
s
0 .36538 m
.00375 .36538 L
s
0 .44231 m
.00375 .44231 L
s
0 .48077 m
.00375 .48077 L
s
0 .51923 m
.00375 .51923 L
s
0 .55769 m
.00375 .55769 L
s
0 .63462 m
.00375 .63462 L
s
0 .67308 m
.00375 .67308 L
s
0 .71154 m
.00375 .71154 L
s
0 .75 m
.00375 .75 L
s
0 .82692 m
.00375 .82692 L
s
0 .86538 m
.00375 .86538 L
s
0 .90385 m
.00375 .90385 L
s
0 .94231 m
.00375 .94231 L
s
.25 Mabswid
0 0 m
0 1 L
s
.11538 .99375 m
.11538 1 L
s
.30769 .99375 m
.30769 1 L
s
.5 .99375 m
.5 1 L
s
.69231 .99375 m
.69231 1 L
s
.88462 .99375 m
.88462 1 L
s
.125 Mabswid
.15385 .99625 m
.15385 1 L
s
.19231 .99625 m
.19231 1 L
s
.23077 .99625 m
.23077 1 L
s
.26923 .99625 m
.26923 1 L
s
.34615 .99625 m
.34615 1 L
s
.38462 .99625 m
.38462 1 L
s
.42308 .99625 m
.42308 1 L
s
.46154 .99625 m
.46154 1 L
s
.53846 .99625 m
.53846 1 L
s
.57692 .99625 m
.57692 1 L
s
.61538 .99625 m
.61538 1 L
s
.65385 .99625 m
.65385 1 L
s
.73077 .99625 m
.73077 1 L
s
.76923 .99625 m
.76923 1 L
s
.80769 .99625 m
.80769 1 L
s
.84615 .99625 m
.84615 1 L
s
.07692 .99625 m
.07692 1 L
s
.03846 .99625 m
.03846 1 L
s
.92308 .99625 m
.92308 1 L
s
.96154 .99625 m
.96154 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .21154 m
1 .21154 L
s
.99375 .40385 m
1 .40385 L
s
.99375 .59615 m
1 .59615 L
s
.99375 .78846 m
1 .78846 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .05769 m
1 .05769 L
s
.99625 .09615 m
1 .09615 L
s
.99625 .13462 m
1 .13462 L
s
.99625 .17308 m
1 .17308 L
s
.99625 .25 m
1 .25 L
s
.99625 .28846 m
1 .28846 L
s
.99625 .32692 m
1 .32692 L
s
.99625 .36538 m
1 .36538 L
s
.99625 .44231 m
1 .44231 L
s
.99625 .48077 m
1 .48077 L
s
.99625 .51923 m
1 .51923 L
s
.99625 .55769 m
1 .55769 L
s
.99625 .63462 m
1 .63462 L
s
.99625 .67308 m
1 .67308 L
s
.99625 .71154 m
1 .71154 L
s
.99625 .75 m
1 .75 L
s
.99625 .82692 m
1 .82692 L
s
.99625 .86538 m
1 .86538 L
s
.99625 .90385 m
1 .90385 L
s
.99625 .94231 m
1 .94231 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.6 g
.98077 .86531 m
.96115 .87019 L
.94152 .87467 L
.9219 .87824 L
.90228 .88068 L
.88265 .88197 L
.86303 .88241 L
.84341 .88235 L
.82378 .88174 L
.80416 .88016 L
.78454 .87741 L
.76491 .87358 L
.74529 .86893 L
.72567 .86415 L
.71983 .86303 L
.70604 .86269 L
.68642 .85369 L
.6668 .84539 L
.66111 .84341 L
.64717 .83777 L
.62755 .83041 L
.61638 .82378 L
.60793 .81947 L
.5883 .80903 L
.57988 .80416 L
.56868 .7968 L
.55048 .78454 L
.54906 .78258 L
.54026 .76491 L
.54906 .76441 L
.55366 .76491 L
.56868 .76827 L
.5883 .77352 L
.60793 .77886 L
.62755 .78418 L
.62875 .78454 L
.64717 .79008 L
.6668 .79534 L
.68642 .79889 L
.70477 .80416 L
.70604 .80448 L
.72567 .80877 L
.74529 .81239 L
.76491 .8113 L
.78454 .81583 L
.80416 .81866 L
.82378 .82037 L
.84341 .82122 L
.86303 .82132 L
.88265 .82067 L
.90228 .8192 L
.9219 .81669 L
.94152 .81271 L
.96115 .81322 L
.98077 .80977 L
F
0 g
.98077 .86531 m
.96115 .87019 L
.94152 .87467 L
.9219 .87824 L
.90228 .88068 L
.88265 .88197 L
.86303 .88241 L
.84341 .88235 L
.82378 .88174 L
.80416 .88016 L
.78454 .87741 L
.76491 .87358 L
.74529 .86893 L
.72567 .86415 L
.71983 .86303 L
.70604 .86269 L
.68642 .85369 L
.6668 .84539 L
.66111 .84341 L
.64717 .83777 L
.62755 .83041 L
.61638 .82378 L
.60793 .81947 L
.5883 .80903 L
.57988 .80416 L
.56868 .7968 L
.55048 .78454 L
.54906 .78258 L
.54026 .76491 L
.54906 .76441 L
.55366 .76491 L
.56868 .76827 L
.5883 .77352 L
.60793 .77886 L
.62755 .78418 L
.62875 .78454 L
.64717 .79008 L
.6668 .79534 L
.68642 .79889 L
.70477 .80416 L
.70604 .80448 L
.72567 .80877 L
.74529 .81239 L
.76491 .8113 L
.78454 .81583 L
.80416 .81866 L
.82378 .82037 L
.84341 .82122 L
.86303 .82132 L
.88265 .82067 L
Mistroke
.90228 .8192 L
.9219 .81669 L
.94152 .81271 L
.96115 .81322 L
.98077 .80977 L
Mfstroke
.4 g
.98077 .79906 m
.96115 .80306 L
.95522 .80416 L
.94152 .8055 L
.9219 .80828 L
.90228 .81069 L
.88265 .81236 L
.86303 .81315 L
.84341 .81303 L
.82378 .812 L
.80416 .81013 L
.78454 .80756 L
.76491 .80486 L
.75633 .80416 L
.74529 .80208 L
.72567 .79793 L
.70604 .79517 L
.68642 .78736 L
.6766 .78454 L
.6668 .78124 L
.64717 .7743 L
.62755 .76704 L
.62348 .76491 L
.60793 .75767 L
.5883 .74814 L
.5829 .74529 L
.56868 .7359 L
.55294 .72567 L
.56868 .71471 L
.5883 .71762 L
.60793 .71722 L
.62574 .72567 L
.62755 .72613 L
.64717 .73098 L
.6668 .73535 L
.68642 .73855 L
.70604 .74498 L
.71774 .74529 L
.72567 .74675 L
.74529 .74992 L
.76491 .75252 L
.78454 .75043 L
.80416 .75416 L
.82378 .75631 L
.84341 .75737 L
.86303 .75749 L
.88265 .75668 L
.90228 .75484 L
.9219 .75161 L
.94152 .75311 L
.96115 .75065 L
.98077 .74763 L
F
0 g
.98077 .79906 m
.96115 .80306 L
.95522 .80416 L
.94152 .8055 L
.9219 .80828 L
.90228 .81069 L
.88265 .81236 L
.86303 .81315 L
.84341 .81303 L
.82378 .812 L
.80416 .81013 L
.78454 .80756 L
.76491 .80486 L
.75633 .80416 L
.74529 .80208 L
.72567 .79793 L
.70604 .79517 L
.68642 .78736 L
.6766 .78454 L
.6668 .78124 L
.64717 .7743 L
.62755 .76704 L
.62348 .76491 L
.60793 .75767 L
.5883 .74814 L
.5829 .74529 L
.56868 .7359 L
.55294 .72567 L
.56868 .71471 L
.5883 .71762 L
.60793 .71722 L
.62574 .72567 L
.62755 .72613 L
.64717 .73098 L
.6668 .73535 L
.68642 .73855 L
.70604 .74498 L
.71774 .74529 L
.72567 .74675 L
.74529 .74992 L
.76491 .75252 L
.78454 .75043 L
.80416 .75416 L
.82378 .75631 L
.84341 .75737 L
.86303 .75749 L
.88265 .75668 L
.90228 .75484 L
.9219 .75161 L
.94152 .75311 L
Mistroke
.96115 .75065 L
.98077 .74763 L
Mfstroke
.4 g
.98077 .93744 m
.96115 .93844 L
.94697 .94152 L
.94152 .94259 L
.9219 .94615 L
.90228 .94902 L
.88265 .951 L
.86303 .95196 L
.84341 .95182 L
.82378 .95058 L
.80416 .94835 L
.78454 .94528 L
.76491 .94158 L
.76463 .94152 L
.74529 .93723 L
.72567 .93462 L
.70604 .92591 L
.6957 .9219 L
.68642 .91845 L
.6668 .91575 L
.64903 .90228 L
.64717 .90134 L
.62755 .89143 L
.61172 .88265 L
.60793 .88011 L
.5883 .86746 L
.58132 .86303 L
.56868 .85068 L
.56378 .84341 L
.56868 .8413 L
.58508 .84341 L
.5883 .84434 L
.60793 .85071 L
.62755 .85699 L
.64717 .86277 L
.64767 .86303 L
.6668 .86949 L
.68642 .87538 L
.70604 .88052 L
.71526 .88265 L
.72567 .88542 L
.74529 .88996 L
.76491 .8937 L
.78454 .89666 L
.80416 .89887 L
.82378 .89884 L
.84341 .90036 L
.86303 .90053 L
.88265 .89938 L
.90228 .89933 L
.9219 .8973 L
.94152 .89454 L
.96115 .89101 L
.98077 .88667 L
F
0 g
.98077 .93744 m
.96115 .93844 L
.94697 .94152 L
.94152 .94259 L
.9219 .94615 L
.90228 .94902 L
.88265 .951 L
.86303 .95196 L
.84341 .95182 L
.82378 .95058 L
.80416 .94835 L
.78454 .94528 L
.76491 .94158 L
.76463 .94152 L
.74529 .93723 L
.72567 .93462 L
.70604 .92591 L
.6957 .9219 L
.68642 .91845 L
.6668 .91575 L
.64903 .90228 L
.64717 .90134 L
.62755 .89143 L
.61172 .88265 L
.60793 .88011 L
.5883 .86746 L
.58132 .86303 L
.56868 .85068 L
.56378 .84341 L
.56868 .8413 L
.58508 .84341 L
.5883 .84434 L
.60793 .85071 L
.62755 .85699 L
.64717 .86277 L
.64767 .86303 L
.6668 .86949 L
.68642 .87538 L
.70604 .88052 L
.71526 .88265 L
.72567 .88542 L
.74529 .88996 L
.76491 .8937 L
.78454 .89666 L
.80416 .89887 L
.82378 .89884 L
.84341 .90036 L
.86303 .90053 L
.88265 .89938 L
.90228 .89933 L
Mistroke
.9219 .8973 L
.94152 .89454 L
.96115 .89101 L
.98077 .88667 L
Mfstroke
.6 g
.98077 .73839 m
.96115 .74207 L
.94152 .74522 L
.94105 .74529 L
.9219 .74689 L
.90228 .7491 L
.88265 .75079 L
.86303 .75163 L
.84341 .75151 L
.82378 .75043 L
.80416 .74856 L
.78454 .74631 L
.77044 .74529 L
.76491 .74445 L
.74529 .74116 L
.72567 .73736 L
.70604 .74086 L
.68642 .72862 L
.67792 .72567 L
.6668 .72199 L
.64717 .71529 L
.62755 .70813 L
.62233 .70604 L
.60793 .69862 L
.5883 .6882 L
.58516 .68642 L
.5883 .67335 L
.60793 .67415 L
.62755 .67679 L
.64717 .67992 L
.6668 .68491 L
.68448 .68642 L
.68642 .68684 L
.70604 .69019 L
.72567 .69309 L
.74529 .69559 L
.76491 .69687 L
.78454 .7022 L
.80416 .70084 L
.82378 .7018 L
.84341 .70231 L
.86303 .70237 L
.88265 .70197 L
.90228 .70113 L
.9219 .70342 L
.94152 .69842 L
.96115 .69076 L
.98077 .69377 L
F
0 g
.98077 .73839 m
.96115 .74207 L
.94152 .74522 L
.94105 .74529 L
.9219 .74689 L
.90228 .7491 L
.88265 .75079 L
.86303 .75163 L
.84341 .75151 L
.82378 .75043 L
.80416 .74856 L
.78454 .74631 L
.77044 .74529 L
.76491 .74445 L
.74529 .74116 L
.72567 .73736 L
.70604 .74086 L
.68642 .72862 L
.67792 .72567 L
.6668 .72199 L
.64717 .71529 L
.62755 .70813 L
.62233 .70604 L
.60793 .69862 L
.5883 .6882 L
.58516 .68642 L
.5883 .67335 L
.60793 .67415 L
.62755 .67679 L
.64717 .67992 L
.6668 .68491 L
.68448 .68642 L
.68642 .68684 L
.70604 .69019 L
.72567 .69309 L
.74529 .69559 L
.76491 .69687 L
.78454 .7022 L
.80416 .70084 L
.82378 .7018 L
.84341 .70231 L
.86303 .70237 L
.88265 .70197 L
.90228 .70113 L
.9219 .70342 L
.94152 .69842 L
.96115 .69076 L
.98077 .69377 L
s
.4 g
.98077 .68268 m
.96218 .68642 L
.96115 .68655 L
.94152 .69086 L
.9219 .69699 L
.90228 .69308 L
.88265 .6941 L
.86303 .69458 L
.84341 .69451 L
.82378 .69389 L
.80416 .69272 L
.78454 .69523 L
.76491 .68953 L
.74933 .68642 L
.74529 .68564 L
.72567 .68158 L
.70604 .6771 L
.68642 .67224 L
.66695 .6668 L
.6668 .66674 L
.64717 .65825 L
.62755 .64936 L
.62302 .64717 L
.62755 .6386 L
.64717 .6377 L
.6668 .63908 L
.68642 .64106 L
.70604 .64376 L
.72567 .64557 L
.73983 .64717 L
.74529 .64778 L
.76491 .64965 L
.78454 .65114 L
.80416 .65227 L
.82378 .65303 L
.84341 .65344 L
.86303 .65349 L
.88265 .65317 L
.90228 .6525 L
.9219 .65147 L
.94152 .65008 L
.96115 .64831 L
.97185 .64717 L
.98077 .64616 L
F
0 g
.98077 .68268 m
.96218 .68642 L
.96115 .68655 L
.94152 .69086 L
.9219 .69699 L
.90228 .69308 L
.88265 .6941 L
.86303 .69458 L
.84341 .69451 L
.82378 .69389 L
.80416 .69272 L
.78454 .69523 L
.76491 .68953 L
.74933 .68642 L
.74529 .68564 L
.72567 .68158 L
.70604 .6771 L
.68642 .67224 L
.66695 .6668 L
.6668 .66674 L
.64717 .65825 L
.62755 .64936 L
.62302 .64717 L
.62755 .6386 L
.64717 .6377 L
.6668 .63908 L
.68642 .64106 L
.70604 .64376 L
.72567 .64557 L
.73983 .64717 L
.74529 .64778 L
.76491 .64965 L
.78454 .65114 L
.80416 .65227 L
.82378 .65303 L
.84341 .65344 L
.86303 .65349 L
.88265 .65317 L
.90228 .6525 L
.9219 .65147 L
.94152 .65008 L
.96115 .64831 L
.97185 .64717 L
.98077 .64616 L
s
.3 g
.98077 .78795 m
.96115 .7927 L
.94152 .79659 L
.9219 .79971 L
.90228 .80206 L
.88265 .8036 L
.86999 .80416 L
.86303 .80434 L
.84341 .80422 L
.84154 .80416 L
.82378 .80328 L
.80416 .80152 L
.78454 .79898 L
.76491 .79566 L
.74529 .79155 L
.72567 .78656 L
.71873 .78454 L
.70604 .77988 L
.68642 .77189 L
.67165 .76491 L
.68642 .75467 L
.70604 .7558 L
.72567 .75755 L
.74529 .75939 L
.76491 .7611 L
.78454 .76039 L
.80416 .76312 L
.82378 .76449 L
.83495 .76491 L
.84341 .76508 L
.86303 .76515 L
.8766 .76491 L
.88265 .76471 L
.90228 .76357 L
.9219 .76131 L
.94152 .76151 L
.96115 .75985 L
.98077 .75803 L
F
0 g
.98077 .78795 m
.96115 .7927 L
.94152 .79659 L
.9219 .79971 L
.90228 .80206 L
.88265 .8036 L
.86999 .80416 L
.86303 .80434 L
.84341 .80422 L
.84154 .80416 L
.82378 .80328 L
.80416 .80152 L
.78454 .79898 L
.76491 .79566 L
.74529 .79155 L
.72567 .78656 L
.71873 .78454 L
.70604 .77988 L
.68642 .77189 L
.67165 .76491 L
.68642 .75467 L
.70604 .7558 L
.72567 .75755 L
.74529 .75939 L
.76491 .7611 L
.78454 .76039 L
.80416 .76312 L
.82378 .76449 L
.83495 .76491 L
.84341 .76508 L
.86303 .76515 L
.8766 .76491 L
.88265 .76471 L
.90228 .76357 L
.9219 .76131 L
.94152 .76151 L
.96115 .75985 L
.98077 .75803 L
s
.6 g
.98077 .62947 m
.96115 .63286 L
.94152 .6357 L
.9219 .63803 L
.90228 .63981 L
.88265 .641 L
.86303 .64157 L
.84341 .64148 L
.82378 .64075 L
.80416 .6394 L
.78454 .63747 L
.76491 .63501 L
.74529 .63203 L
.72567 .62848 L
.72109 .62755 L
.70604 .62195 L
.68642 .61278 L
.67855 .60793 L
.68642 .60601 L
.70604 .60501 L
.72567 .60553 L
.74529 .60652 L
.76491 .60764 L
.77003 .60793 L
.78454 .60872 L
.80416 .60957 L
.82378 .61015 L
.84341 .61046 L
.86303 .61049 L
.88265 .61025 L
.90228 .60974 L
.9219 .60897 L
.94152 .60793 L
.94158 .60793 L
.96115 .60681 L
.98077 .60576 L
F
0 g
.98077 .62947 m
.96115 .63286 L
.94152 .6357 L
.9219 .63803 L
.90228 .63981 L
.88265 .641 L
.86303 .64157 L
.84341 .64148 L
.82378 .64075 L
.80416 .6394 L
.78454 .63747 L
.76491 .63501 L
.74529 .63203 L
.72567 .62848 L
.72109 .62755 L
.70604 .62195 L
.68642 .61278 L
.67855 .60793 L
.68642 .60601 L
.70604 .60501 L
.72567 .60553 L
.74529 .60652 L
.76491 .60764 L
.77003 .60793 L
.78454 .60872 L
.80416 .60957 L
.82378 .61015 L
.84341 .61046 L
.86303 .61049 L
.88265 .61025 L
.90228 .60974 L
.9219 .60897 L
.94152 .60793 L
.94158 .60793 L
.96115 .60681 L
.98077 .60576 L
s
.7 g
.98077 .84667 m
.96115 .85238 L
.94152 .85701 L
.9219 .8607 L
.90597 .86303 L
.90228 .86367 L
.88265 .86683 L
.86303 .86864 L
.84341 .86835 L
.82378 .8661 L
.80545 .86303 L
.80416 .86283 L
.78454 .85983 L
.76491 .8559 L
.74529 .85101 L
.72567 .84496 L
.72123 .84341 L
.70604 .83625 L
.69033 .82378 L
.70604 .82233 L
.72567 .82358 L
.72794 .82378 L
.74529 .82586 L
.76491 .82807 L
.78454 .82995 L
.80416 .83141 L
.82378 .83241 L
.84341 .83295 L
.86303 .83301 L
.88265 .8326 L
.90228 .83171 L
.9219 .83037 L
.94152 .8286 L
.96115 .82646 L
.98077 .82412 L
F
0 g
.98077 .84667 m
.96115 .85238 L
.94152 .85701 L
.9219 .8607 L
.90597 .86303 L
.90228 .86367 L
.88265 .86683 L
.86303 .86864 L
.84341 .86835 L
.82378 .8661 L
.80545 .86303 L
.80416 .86283 L
.78454 .85983 L
.76491 .8559 L
.74529 .85101 L
.72567 .84496 L
.72123 .84341 L
.70604 .83625 L
.69033 .82378 L
.70604 .82233 L
.72567 .82358 L
.72794 .82378 L
.74529 .82586 L
.76491 .82807 L
.78454 .82995 L
.80416 .83141 L
.82378 .83241 L
.84341 .83295 L
.86303 .83301 L
.88265 .8326 L
.90228 .83171 L
.9219 .83037 L
.94152 .8286 L
.96115 .82646 L
.98077 .82412 L
s
.7 g
.98077 .72752 m
.96115 .73211 L
.94152 .73587 L
.9219 .7389 L
.90228 .74119 L
.88265 .7427 L
.86303 .74341 L
.84341 .7433 L
.82378 .74238 L
.80416 .74067 L
.78454 .73819 L
.76491 .73497 L
.74529 .73101 L
.72567 .72616 L
.7239 .72567 L
.70604 .71743 L
.69587 .70604 L
.70604 .70502 L
.72567 .70513 L
.74462 .70604 L
.74529 .70609 L
.76491 .70746 L
.78454 .70867 L
.80416 .70964 L
.82378 .71031 L
.84341 .71067 L
.86303 .71072 L
.88265 .71044 L
.90228 .70984 L
.9219 .70895 L
.94152 .70779 L
.96115 .70645 L
.96748 .70604 L
.98077 .70534 L
F
0 g
.98077 .72752 m
.96115 .73211 L
.94152 .73587 L
.9219 .7389 L
.90228 .74119 L
.88265 .7427 L
.86303 .74341 L
.84341 .7433 L
.82378 .74238 L
.80416 .74067 L
.78454 .73819 L
.76491 .73497 L
.74529 .73101 L
.72567 .72616 L
.7239 .72567 L
.70604 .71743 L
.69587 .70604 L
.70604 .70502 L
.72567 .70513 L
.74462 .70604 L
.74529 .70609 L
.76491 .70746 L
.78454 .70867 L
.80416 .70964 L
.82378 .71031 L
.84341 .71067 L
.86303 .71072 L
.88265 .71044 L
.90228 .70984 L
.9219 .70895 L
.94152 .70779 L
.96115 .70645 L
.96748 .70604 L
.98077 .70534 L
s
.3 g
.76491 .66655 m
.78454 .66529 L
.80416 .66504 L
.82378 .66506 L
.84341 .66511 L
.86303 .66511 L
.88265 .66507 L
.90228 .66504 L
.9219 .66518 L
.94152 .66602 L
.9489 .6668 L
.94152 .67218 L
.9219 .67776 L
.90228 .68133 L
.88265 .68352 L
.86303 .6845 L
.84341 .68436 L
.82378 .68307 L
.80416 .68055 L
.78454 .67656 L
.76491 .66981 L
.76304 .6668 L
F
0 g
.76491 .66655 m
.78454 .66529 L
.80416 .66504 L
.82378 .66506 L
.84341 .66511 L
.86303 .66511 L
.88265 .66507 L
.90228 .66504 L
.9219 .66518 L
.94152 .66602 L
.9489 .6668 L
.94152 .67218 L
.9219 .67776 L
.90228 .68133 L
.88265 .68352 L
.86303 .6845 L
.84341 .68436 L
.82378 .68307 L
.80416 .68055 L
.78454 .67656 L
.76491 .66981 L
.76304 .6668 L
.76491 .66655 L
s
.2 g
.80416 .77724 m
.82378 .77687 L
.84341 .77682 L
.86303 .77682 L
.88265 .77685 L
.90228 .77708 L
.9219 .7784 L
.92619 .78454 L
.9219 .78553 L
.90228 .78902 L
.88265 .79114 L
.86303 .7921 L
.84341 .79195 L
.82378 .7907 L
.80416 .78827 L
.78541 .78454 L
F
0 g
.80416 .77724 m
.82378 .77687 L
.84341 .77682 L
.86303 .77682 L
.88265 .77685 L
.90228 .77708 L
.9219 .7784 L
.92619 .78454 L
.9219 .78553 L
.90228 .78902 L
.88265 .79114 L
.86303 .7921 L
.84341 .79195 L
.82378 .7907 L
.80416 .78827 L
.78541 .78454 L
.80416 .77724 L
s
.8 g
.82378 .72456 m
.84341 .72366 L
.86303 .72359 L
.88265 .72419 L
.89765 .72567 L
.88265 .72817 L
.86303 .72959 L
.84341 .72939 L
.82378 .72745 L
.8145 .72567 L
F
0 g
.82378 .72456 m
.84341 .72366 L
.86303 .72359 L
.88265 .72419 L
.89765 .72567 L
.88265 .72817 L
.86303 .72959 L
.84341 .72939 L
.82378 .72745 L
.8145 .72567 L
.82378 .72456 L
s
.4 g
.84341 .57913 m
.86303 .57904 L
.87092 .5883 L
.86303 .58845 L
.84341 .58837 L
.84063 .5883 L
F
0 g
.84341 .57913 m
.86303 .57904 L
.87092 .5883 L
.86303 .58845 L
.84341 .58837 L
.84063 .5883 L
.84341 .57913 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00?Oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0dooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kS?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0hooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8b
onk^kS?ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08_ooool003gooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0=_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0<oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg03?ooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL08_ooool003Gooooo1_l0
0003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400[ooooo`Ko0000
1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100<oooool01Ol@413o
oooooooooooooooo410@03[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@03Cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@02;ooooo000o
ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000fooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000cooooo`05o`000?ooooooooooooooool0
0000>_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000=Oooool00onH
V9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000008_ooool0043ooooo00?oMgMgofIV
I_ooool00_ooool01Ol0003ooooooooooooooooo000003Kooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000003?ooooo00Go0000ooooooooooooooooo`00000jooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`03ogMgMomVIVKooooo00;o
oooo00Go0000ooooooooooooooooo`00000Rooooo`00@Oooool01Ol0003ooooooooooooooooo410@
00?ooooo00?o410@ooooooooool0=?ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@4100<oooool01Ol@413ooooooooooooooooo410@03[ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@03Oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo023ooooo000mooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg03Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg03?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0jooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0cooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02;ooooo000mooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^03Cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^03?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`03oeEEEOmVIVKo000000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0cooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02;ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo000Joooooooo0000C_l00001ooooo`00
6_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0?Ooo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool08ooo
ool1o`00007ooooo0008ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKo
oooo00?o0000ooooooooool0oooooom:ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooom:ooooo`7o
00000Oooool000Go00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41001_ooool00ol0003oooooooooo`3ooooood[ooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?ooooooB?ooool3o`00007o
oooo000:ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo0008ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Oooooooogmo
Od3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Ooo
ooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000oooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`003ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000?ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000oooooo00Go0000oooooooooooooooo
o`000006ooooo`?o00001?ooooooogmoOd3oOgmo1?ooool3o`00007ooooo000?ooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool000oooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`003oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000?ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo0008
ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000:ooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`002_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41001_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000[ooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo0ol00004oooooooo
Ogmo@?moOgl4ooooo`?o00000Oooool000[ooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000:ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool000Sooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo4_moOgl8o`00
02KoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOglBogmoO`03
o`000?mVIVKoIVIV00CoIVIV00?o0000ogmoOomoOgl09?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOa7oOgmo00?o0000ofIVI_mVIVH01_mVIVH00ol0003oOgmo
ogmoO`0SogmoO`Kooooo0Ol00001ooooo`001oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP06ooooo`03o`000?oooooooooo00CooooooomoOglAogmoO`_o00009?moOgl6ooooo`7o0000
0Oooool000Oooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000Sooooo
00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo0009ooooo`03oiRHV?lQ8B7ok^k^00?ooooo
00Go0000ooooooooooooooooo`000006ooooo`?o00001?ooooooogmoOd3oOgmo1?ooool3o`00007o
oooo000:ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002oooool01Ol0003ooooo
oooooooooooo410@00?ooooo00?o410@ooooooooool01?ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool000Oooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`04ooooomcoOgmo7Ol0000logmo
O`_o00001Oooool1o`00007ooooo0007ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool01?oooooKogmoO`;o00007?nIVITl
o`0000[oVIVI1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooogOmoOgl2o`00
063oVIVI1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooogomoOgl3o`0005go
VIVI1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Coooooh_moOgl2o`0005_oVIVI
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Coooooi?moOgl2o`0005WoVIVI1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Coooooi_moOgl3o`0005KoVIVI1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooojOmoOgl4o`0005;oVIVI1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CoooookOmoOgl3o`0004coVIVI1?l00005ooooo`7o
00000Oooool001[ooooo0_l00005oooooo3oOgmo1Ol00010oiVIV@Oo00000omoOgl5ooooo`;o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooo=ogmoO`So00008?moOgl=o`0002goVIVI1_l0
000:ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooool[oOgmo0ol00008
ofIVIPKo00009omoOgl=o`0001?oVIVI3Ol0000@ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04oooool[oOgmo00?o0000ofIVI_mVIVH03_mVIVH=o`0002OoOgmo4ol0000Mogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooolWoOgmo00?o0000ofIVI_mV
IVH07?mVIVH6o`00053oOgmo0_l00005ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?ooooo8ogmoO`Co00008_mVIVH>o`0003WoOgmo2Ol000000omVIVKoooooooooo`04ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooo<ogmoO`;o0000;_mVIVH=o`0001WoOgmo4ol0
000:ofIVIPKooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooolkoOgmo0_l0000i
ofIVIQWo00007OmVIVH6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooo@ogmo
O`;o0000KOmVIVH6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooBogmoO`?o
0000J_mVIVH6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooEogmoO`;o0000
J?mVIVH6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooGogmoO`?o00007OmV
IVHno`0000[oIVIV1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooof_moOgl3
o`0001[oIVIV0ol0000ioda<C003o`000?mVIVKoIVIV00WoIVIV1_ooool1o`00007ooooo000Joooo
o`;o00001OoooonmogmoO`Co00007?moOgl3o`0001[oIVIV0ol0000coda<C0?o00003?mVIVH5oooo
o`;o00000Oooool001[ooooo00?o0000ooooooooool01?oooonmogmoO`04o`000?nIVIWoVIVIoiVI
V@go00004_moOgl3o`0001[oIVIV1?l0000/oda<C0?o00003omVIVH6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?oooonmogmoO`03o`000?nIVIWoVIVI00koVIVI1Ol0000@ogmoO`Go
00006OmVIVH3o`0002CoC4a<1Ol0000BofIVIPKooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04oooookcoOgmo00?o0000oiVIVOnIVIT05?nIVIT3o`0001;oOgmo1ol0000EofIVIPGo0000
6Om<C4`6o`0001KoIVIV0_l00005ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
oonlogmoO`03o`000?nIVIWoVIVI01OoVIVI1Ol0000DogmoO`?o00005omVIVHIo`0001WoIVIV0ol0
00000omoOgooooooooooo`04ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonl
ogmoO`?o00007?nIVIT7o`00013oOgmo1?l0000oofIVIPKo00001?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?oooonoogmoO`03o`000?nIVIWoVIVI023oVIVI1_l0000>ogmo
O`Co0000=_mVIVH5o`0000;oOgmo1_l00002ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04oooool3oOgmo0_l0000VoiVIV@Oo00002omoOgl3o`0000CoIVIV:?l00004ofIVIP?o
00001OmoOgl2o`0000KoVIVI0ol00005ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?ooooo2ogmoO`03o`000?nIVIWoVIVI02[oVIVI2ol00003ogmoO`Co0000:?moOgl4o`0000KoOgmo
0_l0000:oiVIV@Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooool?oOgmo0_l0
000eoiVIV@?o00001?moOgl8o`0002KoOgmo1?l0000<oiVIV@Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooolGoOgmo0ol0000eoiVIV@Co00002?nIVITVo`00013oVIVI1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooob?moOgl2o`0001KoVIVI5Ol00010oiVI
V@_o00001Oooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooob_moOgl3o`0001Co
VIVI00?o0000ok>c/onc/k<04Onc/k<Do`0001WoVIVI4ol0000:ok>c/`Kooooo0Ol00001ooooo`00
6_ooool2o`0000GooooocOmoOgl3o`0001;oVIVI00?o0000ok>c/onc/k<09?nc/k<Io`0001go/k>c
1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo]OmoOgl6o`0001GoOgmo0ol0
000@oiVIV@03o`000?nc/k?o/k>c05Wo/k>c1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00Cooooo]?moOgl00ol0003oIVIVofIVIP04ofIVIP[o00003_moOgl3o`0000koVIVI0_l0001I
ok>c/`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooook?oOgmo00?o0000ofIV
I_mVIVH03omVIVH2o`0000ooOgmo0ol0000=oiVIV@;o0000Eonc/k<6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?oooonbogmoO`03o`000?mVIVKoIVIV01;oIVIV0_l0000@ogmoO`03
o`000?nIVIWoVIVI00coVIVI0_l0000Pok>c/aSo00007Onc/k<6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?oooonaogmoO`;o00005_mVIVH5o`0000coOgmo0ol0000=oiVIV@Go0000
6Onc/k<7o`0000coc<c<2Ol0000Iok>c/`?o00001Oooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00Cooooo/omoOgl2o`0001WoIVIV1Ol0000:ogmoO`;o00004?nIVIT5o`0001_o/k>c3?l0
000Ook>c/`?o00000_nIVIT6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooone
ogmoO`03o`000?mVIVKoIVIV01_oIVIV0ol00009ogmoO`;o00004onIVIT3o`0003ko/k>c1Ol00005
oiVIV@Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooookKoOgmo0_l0000NofIV
IPGo00001_moOgl00ol0003oVIVIoiVIV@0CoiVIV@Go0000<onc/k<6o`0000[oVIVI1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00Cooooo^?moOgl2o`00027oIVIV1Ol00002ogmoO`;o
00000onIVIT8o`0000goVIVI1_l0000Vok>c/`Oo00003OnIVIT4o`0000Gooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04oooook[oOgmo00?o0000ofIVI_mVIVH08omVIVH3o`000004ogmo
Ool0003o0000o`0000SoOgmo1_l0000=oiVIV@go00003?nc/k<=o`0000goVIVI1ol00003ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooook_oOgmo0_l0000VofIVIPOo0000
2omoOgl8o`0001;oVIVI3?l0000DoiVIV@Ko00002_moOgl6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?oooonmogmoO`;o0000:omVIVH5o`0000koOgmo3?l0000IoiVIV@go00003Omo
Ogl4o`0000Gooooo0Ol00001ooooo`006_ooool2o`0000Gooooo_omoOgl2o`0002koIVIV1_l00006
ogmoO`Oo00001omoOglIo`0000KoOgmo2?l00005ogmoO`Oo00000omVIVH5ooooo`;o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooo1ogmoO`;o00006OmVIVH6o`0001?oIVIV1_l00007ofIV
IPOo00006OmoOgl6o`0000SoIVIV1Ol0000:ofIVIPKooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04oooool?oOgmo0_l0000FofIVIP03o`000?m<C4coC4a<00CoC4a<3Ol0000JofIVIQWo
00006_mVIVH4o`0000Gooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooolGoOgmo
0_l0000CofIVIP03o`000?m<C4coC4a<01;oC4a<4ol0000cofIVIPOo00000om<C4`6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooo7ogmoO`03o`000?mVIVKoIVIV00ooIVIV00?o
0000oda<C?m<C4`09_m<C4`7o`0001WoIVIV4ol0000:oda<C0Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooojgoOgmo2?l0000CogmoO`Co00003?mVIVH2o`0002ooC4a<6Ol0000M
oda<C0Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooojgoOgmo00?o0000oiVI
VOnIVIT01OnIVIT4o`0001?oOgmo0_l0000<ofIVIP?o0000H_m<C4`6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?oooon^ogmoO`03o`000?nIVIWoVIVI00SoVIVI0ol0000BogmoO`;o
00003OmVIVH2o`00063oC4a<1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
[_moOgl00ol0003oVIVIoiVIV@0;oiVIV@Go00003omoOgl3o`0000coIVIV0ol0001Moda<C0Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooojooOgmo00?o0000oiVIVOnIVIT03onI
VIT5o`0000goOgmo0ol0000<ofIVIP;o00007om<C4`Yo`0001?oC4a<1_ooool1o`00007ooooo0007
ooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo
00?o0000ooooooooool01?oooon_ogmoO`03o`000?nIVIWoVIVI01CoVIVI0ol0000=ogmoO`Co0000
2_mVIVH3o`0001WoC4a<0ol0000Yoc<c<`03o`000?m<C4coC4a<013oC4a<1_ooool1o`00007ooooo
0007ooooo`05oa0@4?nj^[[oooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Ko
oooo00?o0000ooooooooool01?oooon`ogmoO`;o00005onIVIT4o`0000goOgmo0ol0000:ofIVIP?o
00005?m<C4`4o`0002[o<c<c0_l0000Aoda<C0Kooooo0Ol00001ooooo`002oooool01Ol0003ooooo
oooooooooooo410@00?ooooo00?o410@ooooooooool01?ooool00ol0003oooooooooo`04oooook;o
Ogmo00?o0000oiVIVOnIVIT06?nIVIT3o`0000goOgmo0_l0000;ofIVIP?o00005Om<C4`7o`0001oo
<c<c1?l0000Aoda<C0?o00001Oooool1o`00007ooooo000:ooooo`03ojVYZOl@413ooooo00;ooooo
00Go0000ooooooooooooooooo`000006ooooo`?o00001?ooooncogmoO`;o00006onIVIT3o`0000co
Ogmo0ol0000;ofIVIP?o00006Om<C4`6o`0000co<c<c3Ol0000Boda<C0?o00000_mVIVH4ooooo`?o
00000Oooool000Wooooo00?o410@o`000?nj^[X00oooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooooooool01?ooooneogmoO`03o`000?nIVIWoVIVI01_oVIVI0ol0000<ogmoO`;o
00003?mVIVH5o`0001[oC4a<3?l0000Joda<C0Go00001OmVIVH6ooooo`7o00000Oooool000[ooooo
00?o^[Zjob4Q8Oooool00_ooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000oooooooo
ool01?oooonfogmoO`;o00007_nIVIT5o`0000WoOgmo1?l0000=ofIVIPOo0000<om<C4`6o`0000[o
IVIV1_ooool1o`00007ooooo0007ooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?oooonhogmoO`03o`000?nIVIWoVIVI
023oVIVI1Ol00008ogmoO`Oo00003OmVIVH6o`0002KoC4a<1ol0000=ofIVIPCo00001Oooool1o`00
007ooooo0007ooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Kooooo00?o0000ooooooooool01?ooooniogmoO`03o`000?nIVIWoVIVI02CoVIVI0ol0000<
ogmoO`Go00003_mVIVH=o`0001?oC4a<1_l0000?ofIVIPGo00000omoOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?oooonjogmoO`?o00009_nIVIT5o`0000coOgmo2?l0000CofIV
IQ?o00003OmVIVH8o`0000SoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooo_OmoOgl2o`0002WoVIVI1ol0000=ogmoO`Ko00009_mVIVH7o`00013oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00Cooooo_omoOgl00ol0003oVIVIoiVIV@0]oiVIV@_o0000
2?moOgl=o`0000coIVIV3Ol0000DogmoO`Co00001Oooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00Cooooo`?moOgl2o`0003SoVIVI0ol0000BogmoO`co00005?moOgl=o`0000?oVIVI1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo`_moOgl00ol0003oVIVIoiVIV@0h
oiVIV@Go00009_moOgl7o`00013oVIVI1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00Cooooo`omoOgl3o`0003coVIVI9_l0000GoiVIV@Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooolKoOgmo0_l0000FoiVIVA7o0000COnIVIT4o`0000Gooooo0Ol00001ooooo`00
6_ooool2o`0000Gooooob?moOgl2o`0001KoVIVI00?o0000ok>c/onc/k<03?nc/k<6o`00043oVIVI
1ol00003ok>c/`Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04oooool[oOgmo0_l0
000EoiVIV@;o00004_nc/k<=o`0002KoVIVI3Ol0000:ok>c/`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooolcoOgmo0_l0000EoiVIV@03o`000?nc/k?o/k>c01co/k>c9_l0000G
ok>c/`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooolkoOgmo0_l0000DoiVI
V@;o0000FOnc/k<6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooo@ogmoO`;o
00005?nIVIT2o`0005Oo/k>c1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
]OmoOgl5o`0001SoOgmo0ol0000CoiVIV@03o`000?nc/k?o/k>c05Co/k>c1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00Cooooo]?moOgl00ol0003oIVIVofIVIP03ofIVIPKo00005Omo
Ogl4o`00013oVIVI1?l0001Bok>c/`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
oooookGoOgmo00?o0000ofIVI_mVIVH02?mVIVH3o`0001KoOgmo0_l0000BoiVIV@?o0000COnc/k<3
o`0000Gooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooookKoOgmo00?o0000ofIV
I_mVIVH02_mVIVH3o`0001GoOgmo0_l0000CoiVIV@Co0000A_nc/k<3o`0000;oVIVI1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00Cooooo]omoOgl00ol0003oIVIVofIVIP0<ofIVIP?o
00005?moOgl2o`0001GoVIVI0ol0000nok>c/`Go00001OnIVIT6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?oooonhogmoO`03o`000?mVIVKoIVIV00koIVIV1?l0000BogmoO`?o0000
5OnIVIT5o`0003Co/k>c1Ol0000:oiVIV@Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04oooookWoOgmo00?o0000ofIVI_mVIVH04OmVIVH3o`0001;oOgmo0_l0000HoiVIV@Ko0000:onc
/k<3o`0000ooVIVI1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo^_moOgl2
o`0001CoIVIV0ol0000AogmoO`Ko00006?nIVIT7o`0001go/k>c1ol0000BoiVIV@Kooooo0Ol00001
ooooo`006_ooool2o`0000Gooooo_?moOgl00ol0003oIVIVofIVIP0DofIVIP?o00005?moOgl5o`00
01[oVIVI1_l0000Cok>c/`Co00005onIVIT3o`0000Cooooo0_l00001ooooo`006_ooool00ol0003o
ooooooooo`04oooookgoOgmo0_l0000GofIVIPCo00005OmoOgl5o`0001_oVIVI4ol0000HoiVIV@?o
00000_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonoogmoO`03o`00
0?mVIVKoIVIV01SoIVIV0ol0000GogmoO`?o0000?_nIVIT5o`0000GoOgmo1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00Cooooo`?moOgl2o`0001_oIVIV0ol0000GogmoO`Go0000<onI
VIT6o`0000[oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo`_moOgl0
0ol0003oIVIVofIVIP0KofIVIP?o00006OmoOgl6o`0002KoVIVI1ol0000@ogmoO`Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04oooool?oOgmo00?o0000ofIVI_mVIVH07OmVIVH4o`00
01_oOgmo1ol0000IoiVIV@Ko00005omoOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooo4ogmoO`;o00008OmVIVH3o`0001ooOgmo6Ol0000MogmoO`Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooolKoOgmo0_l0000RofIVIPGo0000C_moOgl3o`0000Gooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooolSoOgmo0_l0000UofIVIPKo0000AOmo
Ogl3o`0000;oIVIV1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooob_moOgl2
o`0002WoIVIV1ol0000iogmoO`Go00001OmVIVH6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?ooooo<ogmoO`;o0000;_mVIVH6o`0002goOgmo1_l0000:ofIVIPKooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooolkoOgmo0_l0000bofIVIPgo00003?moOglDo`00013o
IVIV1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Coooood?moOgl3o`0003coIVIV
3?l0000TofIVIPKooooo0Ol00001ooooo`006_ooool2o`0000GooooodomoOgl00ol0003oIVIVofIV
IP1YofIVIPGooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04ooooomCoOgmo00?o0000
ofIVI_mVIVH0J?mVIVH6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooEogmo
O`03o`000?mVIVKoIVIV06OoIVIV1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
ooooe_moOgl00ol0003oIVIVofIVIP1VofIVIPKooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooomOoOgmo1?l0001TofIVIPKooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooom_oOgmo1Ol0001OofIVIPKooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooon3oOgmo0ol0001LofIVIPKooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
on?oOgmo0ol0001IofIVIPKooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooonKo
Ogmo0_l0001GofIVIPKooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooonSoOgmo
0_l0001EofIVIPKooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooon[oOgmo1Ol0
001@ofIVIPKooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooonooOgmo1_l00011
ofIVIP[o00001Oooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooomOmoOgl5o`00
03WoIVIV0ol00009ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000Gooooon_moOgl3o`0003;o
IVIV1?l0000<ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04oooooogoOgmo
1Ol0000VofIVIPOo00004?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoO`?oOgmo3Ol0000CofIVIPKo00005omoOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOa3oOgmo4ol0000MogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`002Oooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o
0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000:ooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00Cooooooomo
Ogm0ogmoO`Kooooo0Ol00001ooooo`001oooool5o`0000?ooooo00Go410@oooooooooooooooooa0@
4006ooooo`?o00001?ooooooogmoOd3oOgmo1?ooool3o`00007ooooo0007ooooo`04odA4A?oMgMgo
ooooo`0000Cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo
B_ooool1o`00007ooooo0007ooooo`04omgMgOmEEEGoooooo`0000Cooooo00Go0000oooooooooooo
ooooo`000006ooooo`03o`000?oooooooooo0?ooooooB_ooool1o`00007ooooo0008ooooo`03ogMg
Moo<c<co000000Cooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo0?oo
ooooB_ooool1o`00007ooooo0008ooooo`03onk^k_m4A4Co000000Cooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`06ooooo`03o`000?oooooooooo0?ooooooB_ooool1o`00007ooooo0009ooooo`03ogMg
Mol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo02?o
oooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03go
oooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Sooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`7o00000Oooool001[oooooool0
001>o`00007ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-30.1723, -14.304, 0.195672, \
0.195672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0192308 0.211538 0.0192308 [
[.11538 -0.0125 -9 -9 ]
[.11538 -0.0125 9 0 ]
[.30769 -0.0125 -9 -9 ]
[.30769 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69231 -0.0125 -6 -9 ]
[.69231 -0.0125 6 0 ]
[.88462 -0.0125 -6 -9 ]
[.88462 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -18 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .21154 -6 -4.5 ]
[-0.0125 .21154 0 4.5 ]
[-0.0125 .40385 -12 -4.5 ]
[-0.0125 .40385 0 4.5 ]
[-0.0125 .59615 -12 -4.5 ]
[-0.0125 .59615 0 4.5 ]
[-0.0125 .78846 -12 -4.5 ]
[-0.0125 .78846 0 4.5 ]
[-0.0125 .98077 -12 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11538 0 m
.11538 .00625 L
s
[(-20)] .11538 -0.0125 0 1 Mshowa
.30769 0 m
.30769 .00625 L
s
[(-10)] .30769 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69231 0 m
.69231 .00625 L
s
[(10)] .69231 -0.0125 0 1 Mshowa
.88462 0 m
.88462 .00625 L
s
[(20)] .88462 -0.0125 0 1 Mshowa
.125 Mabswid
.15385 0 m
.15385 .00375 L
s
.19231 0 m
.19231 .00375 L
s
.23077 0 m
.23077 .00375 L
s
.26923 0 m
.26923 .00375 L
s
.34615 0 m
.34615 .00375 L
s
.38462 0 m
.38462 .00375 L
s
.42308 0 m
.42308 .00375 L
s
.46154 0 m
.46154 .00375 L
s
.53846 0 m
.53846 .00375 L
s
.57692 0 m
.57692 .00375 L
s
.61538 0 m
.61538 .00375 L
s
.65385 0 m
.65385 .00375 L
s
.73077 0 m
.73077 .00375 L
s
.76923 0 m
.76923 .00375 L
s
.80769 0 m
.80769 .00375 L
s
.84615 0 m
.84615 .00375 L
s
.07692 0 m
.07692 .00375 L
s
.03846 0 m
.03846 .00375 L
s
.92308 0 m
.92308 .00375 L
s
.96154 0 m
.96154 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(-10)] -0.0125 .01923 1 0 Mshowa
0 .21154 m
.00625 .21154 L
s
[(0)] -0.0125 .21154 1 0 Mshowa
0 .40385 m
.00625 .40385 L
s
[(10)] -0.0125 .40385 1 0 Mshowa
0 .59615 m
.00625 .59615 L
s
[(20)] -0.0125 .59615 1 0 Mshowa
0 .78846 m
.00625 .78846 L
s
[(30)] -0.0125 .78846 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(40)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .05769 m
.00375 .05769 L
s
0 .09615 m
.00375 .09615 L
s
0 .13462 m
.00375 .13462 L
s
0 .17308 m
.00375 .17308 L
s
0 .25 m
.00375 .25 L
s
0 .28846 m
.00375 .28846 L
s
0 .32692 m
.00375 .32692 L
s
0 .36538 m
.00375 .36538 L
s
0 .44231 m
.00375 .44231 L
s
0 .48077 m
.00375 .48077 L
s
0 .51923 m
.00375 .51923 L
s
0 .55769 m
.00375 .55769 L
s
0 .63462 m
.00375 .63462 L
s
0 .67308 m
.00375 .67308 L
s
0 .71154 m
.00375 .71154 L
s
0 .75 m
.00375 .75 L
s
0 .82692 m
.00375 .82692 L
s
0 .86538 m
.00375 .86538 L
s
0 .90385 m
.00375 .90385 L
s
0 .94231 m
.00375 .94231 L
s
.25 Mabswid
0 0 m
0 1 L
s
.11538 .99375 m
.11538 1 L
s
.30769 .99375 m
.30769 1 L
s
.5 .99375 m
.5 1 L
s
.69231 .99375 m
.69231 1 L
s
.88462 .99375 m
.88462 1 L
s
.125 Mabswid
.15385 .99625 m
.15385 1 L
s
.19231 .99625 m
.19231 1 L
s
.23077 .99625 m
.23077 1 L
s
.26923 .99625 m
.26923 1 L
s
.34615 .99625 m
.34615 1 L
s
.38462 .99625 m
.38462 1 L
s
.42308 .99625 m
.42308 1 L
s
.46154 .99625 m
.46154 1 L
s
.53846 .99625 m
.53846 1 L
s
.57692 .99625 m
.57692 1 L
s
.61538 .99625 m
.61538 1 L
s
.65385 .99625 m
.65385 1 L
s
.73077 .99625 m
.73077 1 L
s
.76923 .99625 m
.76923 1 L
s
.80769 .99625 m
.80769 1 L
s
.84615 .99625 m
.84615 1 L
s
.07692 .99625 m
.07692 1 L
s
.03846 .99625 m
.03846 1 L
s
.92308 .99625 m
.92308 1 L
s
.96154 .99625 m
.96154 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .21154 m
1 .21154 L
s
.99375 .40385 m
1 .40385 L
s
.99375 .59615 m
1 .59615 L
s
.99375 .78846 m
1 .78846 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .05769 m
1 .05769 L
s
.99625 .09615 m
1 .09615 L
s
.99625 .13462 m
1 .13462 L
s
.99625 .17308 m
1 .17308 L
s
.99625 .25 m
1 .25 L
s
.99625 .28846 m
1 .28846 L
s
.99625 .32692 m
1 .32692 L
s
.99625 .36538 m
1 .36538 L
s
.99625 .44231 m
1 .44231 L
s
.99625 .48077 m
1 .48077 L
s
.99625 .51923 m
1 .51923 L
s
.99625 .55769 m
1 .55769 L
s
.99625 .63462 m
1 .63462 L
s
.99625 .67308 m
1 .67308 L
s
.99625 .71154 m
1 .71154 L
s
.99625 .75 m
1 .75 L
s
.99625 .82692 m
1 .82692 L
s
.99625 .86538 m
1 .86538 L
s
.99625 .90385 m
1 .90385 L
s
.99625 .94231 m
1 .94231 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.6 g
.98077 .90113 m
.97565 .90228 L
.96115 .90483 L
.94152 .90845 L
.9219 .91148 L
.90228 .91367 L
.88265 .91493 L
.86303 .91528 L
.84341 .91471 L
.82378 .91323 L
.80416 .91083 L
.78454 .90761 L
.76491 .90395 L
.75495 .90228 L
.74529 .90182 L
.72567 .89573 L
.70604 .88854 L
.68874 .88265 L
.68642 .88181 L
.6668 .87779 L
.64717 .86603 L
.64087 .86303 L
.62755 .85671 L
.60793 .84801 L
.60193 .84341 L
.5883 .83539 L
.56969 .82378 L
.56868 .82292 L
.54906 .80702 L
.54539 .80416 L
.54906 .79499 L
.56868 .79695 L
.5883 .80163 L
.59758 .80416 L
.60793 .80751 L
.62755 .81356 L
.64717 .81605 L
.66473 .82378 L
.6668 .82457 L
.68642 .83009 L
.70604 .8283 L
.72567 .83767 L
.74529 .84285 L
.74811 .84341 L
.76491 .84645 L
.78454 .84937 L
.80416 .85163 L
.82378 .85325 L
.84341 .84925 L
.86303 .8501 L
.88265 .84958 L
.90228 .84756 L
.9219 .85208 L
.94152 .84997 L
.96115 .84721 L
.98077 .84377 L
F
0 g
.98077 .90113 m
.97565 .90228 L
.96115 .90483 L
.94152 .90845 L
.9219 .91148 L
.90228 .91367 L
.88265 .91493 L
.86303 .91528 L
.84341 .91471 L
.82378 .91323 L
.80416 .91083 L
.78454 .90761 L
.76491 .90395 L
.75495 .90228 L
.74529 .90182 L
.72567 .89573 L
.70604 .88854 L
.68874 .88265 L
.68642 .88181 L
.6668 .87779 L
.64717 .86603 L
.64087 .86303 L
.62755 .85671 L
.60793 .84801 L
.60193 .84341 L
.5883 .83539 L
.56969 .82378 L
.56868 .82292 L
.54906 .80702 L
.54539 .80416 L
.54906 .79499 L
.56868 .79695 L
.5883 .80163 L
.59758 .80416 L
.60793 .80751 L
.62755 .81356 L
.64717 .81605 L
.66473 .82378 L
.6668 .82457 L
.68642 .83009 L
.70604 .8283 L
.72567 .83767 L
.74529 .84285 L
.74811 .84341 L
.76491 .84645 L
.78454 .84937 L
.80416 .85163 L
.82378 .85325 L
.84341 .84925 L
.86303 .8501 L
Mistroke
.88265 .84958 L
.90228 .84756 L
.9219 .85208 L
.94152 .84997 L
.96115 .84721 L
.98077 .84377 L
Mfstroke
.4 g
.98077 .83308 m
.96115 .83847 L
.94152 .83918 L
.9219 .8415 L
.90228 .84314 L
.89811 .84341 L
.88265 .84361 L
.86303 .84374 L
.84341 .84355 L
.82999 .84341 L
.82378 .84281 L
.80416 .841 L
.78454 .84231 L
.76491 .8372 L
.74529 .83175 L
.72567 .8263 L
.71379 .82378 L
.70604 .8216 L
.68642 .81572 L
.6668 .8099 L
.65334 .80416 L
.64717 .80168 L
.62755 .79355 L
.60793 .78469 L
.60769 .78454 L
.5883 .77414 L
.5719 .76491 L
.56868 .7623 L
.54937 .74529 L
.56868 .74017 L
.5883 .74039 L
.59687 .74529 L
.60793 .74819 L
.62755 .75316 L
.64717 .75198 L
.6668 .76277 L
.67804 .76491 L
.68642 .76701 L
.70604 .77127 L
.72567 .76999 L
.74529 .77734 L
.76491 .78183 L
.78454 .78338 L
.79567 .78454 L
.80416 .78534 L
.82378 .7868 L
.84341 .7877 L
.86303 .78805 L
.88265 .78784 L
.90228 .78707 L
.9219 .78574 L
.93512 .78454 L
.94152 .78389 L
.96115 .78266 L
.98077 .77859 L
F
0 g
.98077 .83308 m
.96115 .83847 L
.94152 .83918 L
.9219 .8415 L
.90228 .84314 L
.89811 .84341 L
.88265 .84361 L
.86303 .84374 L
.84341 .84355 L
.82999 .84341 L
.82378 .84281 L
.80416 .841 L
.78454 .84231 L
.76491 .8372 L
.74529 .83175 L
.72567 .8263 L
.71379 .82378 L
.70604 .8216 L
.68642 .81572 L
.6668 .8099 L
.65334 .80416 L
.64717 .80168 L
.62755 .79355 L
.60793 .78469 L
.60769 .78454 L
.5883 .77414 L
.5719 .76491 L
.56868 .7623 L
.54937 .74529 L
.56868 .74017 L
.5883 .74039 L
.59687 .74529 L
.60793 .74819 L
.62755 .75316 L
.64717 .75198 L
.6668 .76277 L
.67804 .76491 L
.68642 .76701 L
.70604 .77127 L
.72567 .76999 L
.74529 .77734 L
.76491 .78183 L
.78454 .78338 L
.79567 .78454 L
.80416 .78534 L
.82378 .7868 L
.84341 .7877 L
.86303 .78805 L
.88265 .78784 L
.90228 .78707 L
Mistroke
.9219 .78574 L
.93512 .78454 L
.94152 .78389 L
.96115 .78266 L
.98077 .77859 L
Mfstroke
.6 g
.98077 .77096 m
.96115 .77724 L
.94152 .77611 L
.9219 .77816 L
.90228 .77961 L
.88265 .78046 L
.86303 .7807 L
.84341 .78032 L
.82378 .77932 L
.80416 .77772 L
.78454 .77553 L
.76491 .77562 L
.74529 .76961 L
.72567 .76507 L
.72428 .76491 L
.70604 .76029 L
.68642 .75492 L
.6668 .75119 L
.6557 .74529 L
.64717 .74193 L
.62755 .73405 L
.608 .72567 L
.60793 .72562 L
.5883 .71364 L
.57575 .70604 L
.5883 .69699 L
.60793 .69854 L
.62755 .70158 L
.64717 .70526 L
.65157 .70604 L
.6668 .70931 L
.68642 .713 L
.70604 .71634 L
.72567 .72003 L
.74529 .72223 L
.76491 .72476 L
.77266 .72567 L
.78454 .72694 L
.80416 .72865 L
.82378 .72986 L
.84341 .73061 L
.86303 .7309 L
.88265 .73072 L
.90228 .73009 L
.9219 .72898 L
.94152 .7274 L
.9581 .72567 L
.96115 .72531 L
.98077 .72286 L
F
0 g
.98077 .77096 m
.96115 .77724 L
.94152 .77611 L
.9219 .77816 L
.90228 .77961 L
.88265 .78046 L
.86303 .7807 L
.84341 .78032 L
.82378 .77932 L
.80416 .77772 L
.78454 .77553 L
.76491 .77562 L
.74529 .76961 L
.72567 .76507 L
.72428 .76491 L
.70604 .76029 L
.68642 .75492 L
.6668 .75119 L
.6557 .74529 L
.64717 .74193 L
.62755 .73405 L
.608 .72567 L
.60793 .72562 L
.5883 .71364 L
.57575 .70604 L
.5883 .69699 L
.60793 .69854 L
.62755 .70158 L
.64717 .70526 L
.65157 .70604 L
.6668 .70931 L
.68642 .713 L
.70604 .71634 L
.72567 .72003 L
.74529 .72223 L
.76491 .72476 L
.77266 .72567 L
.78454 .72694 L
.80416 .72865 L
.82378 .72986 L
.84341 .73061 L
.86303 .7309 L
.88265 .73072 L
.90228 .73009 L
.9219 .72898 L
.94152 .7274 L
.9581 .72567 L
.96115 .72531 L
.98077 .72286 L
s
.4 g
.98077 .96365 m
.96115 .96812 L
.94152 .97178 L
.9219 .97455 L
.90228 .97644 L
.88265 .97749 L
.86303 .97778 L
.84341 .97731 L
.82378 .97606 L
.80416 .97396 L
.78454 .97098 L
.76491 .96712 L
.74529 .96246 L
.74014 .96115 L
.72567 .95703 L
.70604 .9507 L
.68642 .94444 L
.68223 .94152 L
.6668 .93478 L
.64717 .92532 L
.64021 .9219 L
.62755 .91426 L
.60886 .90228 L
.62755 .89312 L
.64717 .89909 L
.65794 .90228 L
.6668 .9054 L
.68642 .91198 L
.70604 .91776 L
.72288 .9219 L
.72567 .92292 L
.74529 .92817 L
.76491 .93261 L
.78454 .9362 L
.80416 .93896 L
.82378 .94094 L
.82943 .94152 L
.84341 .94226 L
.86303 .94281 L
.88265 .94247 L
.89899 .94152 L
.90228 .9413 L
.9219 .9395 L
.94152 .93694 L
.96115 .93355 L
.98077 .92931 L
F
0 g
.98077 .96365 m
.96115 .96812 L
.94152 .97178 L
.9219 .97455 L
.90228 .97644 L
.88265 .97749 L
.86303 .97778 L
.84341 .97731 L
.82378 .97606 L
.80416 .97396 L
.78454 .97098 L
.76491 .96712 L
.74529 .96246 L
.74014 .96115 L
.72567 .95703 L
.70604 .9507 L
.68642 .94444 L
.68223 .94152 L
.6668 .93478 L
.64717 .92532 L
.64021 .9219 L
.62755 .91426 L
.60886 .90228 L
.62755 .89312 L
.64717 .89909 L
.65794 .90228 L
.6668 .9054 L
.68642 .91198 L
.70604 .91776 L
.72288 .9219 L
.72567 .92292 L
.74529 .92817 L
.76491 .93261 L
.78454 .9362 L
.80416 .93896 L
.82378 .94094 L
.82943 .94152 L
.84341 .94226 L
.86303 .94281 L
.88265 .94247 L
.89899 .94152 L
.90228 .9413 L
.9219 .9395 L
.94152 .93694 L
.96115 .93355 L
.98077 .92931 L
s
.4 g
.98077 .71325 m
.96115 .71626 L
.94152 .71876 L
.9219 .72074 L
.90228 .72217 L
.88265 .723 L
.86303 .72324 L
.84341 .72286 L
.82378 .72188 L
.80416 .72031 L
.78454 .71821 L
.76491 .71559 L
.74529 .71245 L
.72567 .71055 L
.71326 .70604 L
.70604 .70404 L
.68642 .69836 L
.6668 .69241 L
.6487 .68642 L
.64717 .68566 L
.62755 .67527 L
.61192 .6668 L
.62755 .66004 L
.64717 .66084 L
.6668 .66292 L
.68642 .66553 L
.69588 .6668 L
.70604 .66839 L
.72567 .67098 L
.74529 .67324 L
.76491 .67517 L
.78454 .6768 L
.80416 .67644 L
.82378 .68113 L
.84341 .68398 L
.86303 .67994 L
.88265 .68443 L
.90228 .68196 L
.9219 .6778 L
.94152 .66985 L
.96115 .67559 L
.98077 .67373 L
F
0 g
.98077 .71325 m
.96115 .71626 L
.94152 .71876 L
.9219 .72074 L
.90228 .72217 L
.88265 .723 L
.86303 .72324 L
.84341 .72286 L
.82378 .72188 L
.80416 .72031 L
.78454 .71821 L
.76491 .71559 L
.74529 .71245 L
.72567 .71055 L
.71326 .70604 L
.70604 .70404 L
.68642 .69836 L
.6668 .69241 L
.6487 .68642 L
.64717 .68566 L
.62755 .67527 L
.61192 .6668 L
.62755 .66004 L
.64717 .66084 L
.6668 .66292 L
.68642 .66553 L
.69588 .6668 L
.70604 .66839 L
.72567 .67098 L
.74529 .67324 L
.76491 .67517 L
.78454 .6768 L
.80416 .67644 L
.82378 .68113 L
.84341 .68398 L
.86303 .67994 L
.88265 .68443 L
.90228 .68196 L
.9219 .6778 L
.94152 .66985 L
.96115 .67559 L
.98077 .67373 L
s
.6 g
.98077 .65927 m
.96115 .66283 L
.94152 .66584 L
.93439 .6668 L
.9219 .66879 L
.90228 .67234 L
.88265 .67522 L
.86303 .67006 L
.84341 .67466 L
.82378 .6715 L
.80416 .66798 L
.79641 .6668 L
.78454 .66518 L
.76491 .66202 L
.74529 .65835 L
.72567 .65427 L
.70604 .64976 L
.69597 .64717 L
.68642 .64249 L
.67296 .62755 L
.68642 .62683 L
.70604 .62751 L
.70665 .62755 L
.72567 .62903 L
.74529 .63055 L
.76491 .63192 L
.78454 .6331 L
.80416 .63405 L
.82378 .63475 L
.84341 .63519 L
.86303 .63536 L
.88265 .63526 L
.90228 .63488 L
.9219 .63424 L
.94152 .63335 L
.96115 .63222 L
.98077 .63089 L
F
0 g
.98077 .65927 m
.96115 .66283 L
.94152 .66584 L
.93439 .6668 L
.9219 .66879 L
.90228 .67234 L
.88265 .67522 L
.86303 .67006 L
.84341 .67466 L
.82378 .6715 L
.80416 .66798 L
.79641 .6668 L
.78454 .66518 L
.76491 .66202 L
.74529 .65835 L
.72567 .65427 L
.70604 .64976 L
.69597 .64717 L
.68642 .64249 L
.67296 .62755 L
.68642 .62683 L
.70604 .62751 L
.70665 .62755 L
.72567 .62903 L
.74529 .63055 L
.76491 .63192 L
.78454 .6331 L
.80416 .63405 L
.82378 .63475 L
.84341 .63519 L
.86303 .63536 L
.88265 .63526 L
.90228 .63488 L
.9219 .63424 L
.94152 .63335 L
.96115 .63222 L
.98077 .63089 L
s
.3 g
.98077 .82056 m
.9677 .82378 L
.96115 .82609 L
.94152 .82872 L
.9219 .83139 L
.90228 .83325 L
.88265 .83432 L
.86303 .83462 L
.84341 .83413 L
.82378 .83287 L
.80416 .83082 L
.78454 .83241 L
.76491 .82445 L
.76291 .82378 L
.74529 .8193 L
.72567 .81358 L
.70604 .80693 L
.69881 .80416 L
.68642 .79718 L
.67422 .78454 L
.68642 .7832 L
.70604 .78416 L
.71044 .78454 L
.72567 .78638 L
.74529 .78874 L
.76491 .79087 L
.78454 .79268 L
.80416 .79412 L
.82378 .79518 L
.84341 .79584 L
.86303 .79609 L
.88265 .79594 L
.90228 .79537 L
.9219 .79441 L
.94152 .79306 L
.96115 .79134 L
.98077 .78928 L
F
0 g
.98077 .82056 m
.9677 .82378 L
.96115 .82609 L
.94152 .82872 L
.9219 .83139 L
.90228 .83325 L
.88265 .83432 L
.86303 .83462 L
.84341 .83413 L
.82378 .83287 L
.80416 .83082 L
.78454 .83241 L
.76491 .82445 L
.76291 .82378 L
.74529 .8193 L
.72567 .81358 L
.70604 .80693 L
.69881 .80416 L
.68642 .79718 L
.67422 .78454 L
.68642 .7832 L
.70604 .78416 L
.71044 .78454 L
.72567 .78638 L
.74529 .78874 L
.76491 .79087 L
.78454 .79268 L
.80416 .79412 L
.82378 .79518 L
.84341 .79584 L
.86303 .79609 L
.88265 .79594 L
.90228 .79537 L
.9219 .79441 L
.94152 .79306 L
.96115 .79134 L
.98077 .78928 L
s
.7 g
.98077 .75965 m
.96115 .76435 L
.95855 .76491 L
.94152 .76765 L
.9219 .77007 L
.90228 .77176 L
.88265 .77273 L
.86303 .773 L
.84341 .77256 L
.82378 .77142 L
.80416 .76956 L
.78454 .76696 L
.77219 .76491 L
.76491 .7633 L
.74529 .75841 L
.72567 .75277 L
.70604 .74614 L
.7038 .74529 L
.70604 .73246 L
.72567 .73247 L
.74529 .73358 L
.76491 .73487 L
.78454 .73609 L
.80416 .73712 L
.82378 .7379 L
.84341 .7384 L
.86303 .7386 L
.88265 .73848 L
.90228 .73805 L
.9219 .73733 L
.94152 .73635 L
.96115 .73517 L
.98077 .73389 L
F
0 g
.98077 .75965 m
.96115 .76435 L
.95855 .76491 L
.94152 .76765 L
.9219 .77007 L
.90228 .77176 L
.88265 .77273 L
.86303 .773 L
.84341 .77256 L
.82378 .77142 L
.80416 .76956 L
.78454 .76696 L
.77219 .76491 L
.76491 .7633 L
.74529 .75841 L
.72567 .75277 L
.70604 .74614 L
.7038 .74529 L
.70604 .73246 L
.72567 .73247 L
.74529 .73358 L
.76491 .73487 L
.78454 .73609 L
.80416 .73712 L
.82378 .7379 L
.84341 .7384 L
.86303 .7386 L
.88265 .73848 L
.90228 .73805 L
.9219 .73733 L
.94152 .73635 L
.96115 .73517 L
.98077 .73389 L
s
.7 g
.74529 .86271 m
.75512 .86303 L
.74529 .8731 L
.73567 .86303 L
F
0 g
.74529 .86271 m
.75512 .86303 L
.74529 .8731 L
.73567 .86303 L
.74529 .86271 L
s
.4 g
.78454 .59896 m
.80416 .59839 L
.82378 .59827 L
.84341 .59827 L
.86303 .59828 L
.88265 .59827 L
.90228 .59826 L
.9219 .59834 L
.94152 .59875 L
.96115 .60049 L
.96411 .60793 L
.96115 .60845 L
.94152 .61135 L
.9219 .61358 L
.90228 .61519 L
.88265 .61614 L
.86303 .61641 L
.84341 .61597 L
.82378 .61486 L
.80416 .6131 L
.78454 .61072 L
.76653 .60793 L
F
0 g
.78454 .59896 m
.80416 .59839 L
.82378 .59827 L
.84341 .59827 L
.86303 .59828 L
.88265 .59827 L
.90228 .59826 L
.9219 .59834 L
.94152 .59875 L
.96115 .60049 L
.96411 .60793 L
.96115 .60845 L
.94152 .61135 L
.9219 .61358 L
.90228 .61519 L
.88265 .61614 L
.86303 .61641 L
.84341 .61597 L
.82378 .61486 L
.80416 .6131 L
.78454 .61072 L
.76653 .60793 L
.78454 .59896 L
s
.7 g
.78454 .86548 m
.80416 .86702 L
.82378 .8682 L
.84341 .86895 L
.86303 .86924 L
.88265 .86907 L
.90228 .86842 L
.9219 .86734 L
.94152 .86588 L
.95879 .88265 L
.94152 .88652 L
.9219 .88983 L
.90228 .89211 L
.88265 .89343 L
.86303 .89379 L
.84341 .8932 L
.82378 .89165 L
.80416 .88913 L
.78454 .88556 L
.77188 .88265 L
F
0 g
.78454 .86548 m
.80416 .86702 L
.82378 .8682 L
.84341 .86895 L
.86303 .86924 L
.88265 .86907 L
.90228 .86842 L
.9219 .86734 L
.94152 .86588 L
.95879 .88265 L
.94152 .88652 L
.9219 .88983 L
.90228 .89211 L
.88265 .89343 L
.86303 .89379 L
.84341 .8932 L
.82378 .89165 L
.80416 .88913 L
.78454 .88556 L
.77188 .88265 L
.78454 .86548 L
s
.3 g
.78454 .69021 m
.80416 .69038 L
.82378 .69068 L
.84341 .69092 L
.86303 .69102 L
.88265 .69096 L
.90228 .69075 L
.9219 .69045 L
.94152 .69022 L
.95394 .70604 L
.94152 .70807 L
.9219 .7106 L
.90228 .71236 L
.88265 .71338 L
.86303 .71366 L
.84341 .7132 L
.82378 .712 L
.80416 .71006 L
.78454 .70734 L
.77685 .70604 L
F
0 g
.78454 .69021 m
.80416 .69038 L
.82378 .69068 L
.84341 .69092 L
.86303 .69102 L
.88265 .69096 L
.90228 .69075 L
.9219 .69045 L
.94152 .69022 L
.95394 .70604 L
.94152 .70807 L
.9219 .7106 L
.90228 .71236 L
.88265 .71338 L
.86303 .71366 L
.84341 .7132 L
.82378 .712 L
.80416 .71006 L
.78454 .70734 L
.77685 .70604 L
.78454 .69021 L
s
.7 g
.98077 .87507 m
.97728 .86303 L
.98077 .86282 L
F
0 g
.98077 .87507 m
.97728 .86303 L
.98077 .86282 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00?Oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0dooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kS?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0hooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8b
onk^kS?ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08_ooool003gooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0=_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0<oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg03?ooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL08_ooool003Gooooo1_l0
0003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400[ooooo`Ko0000
1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100<oooool01Ol@413o
oooooooooooooooo410@03[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@03Cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@02;ooooo000o
ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000fooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000cooooo`05o`000?ooooooooooooooool0
0000>_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000=Oooool00onH
V9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000008_ooool0043ooooo00?oMgMgofIV
I_ooool00_ooool01Ol0003ooooooooooooooooo000003Kooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000003?ooooo00Go0000ooooooooooooooooo`00000jooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`03ogMgMomVIVKooooo00;o
oooo00Go0000ooooooooooooooooo`00000Rooooo`00@Oooool01Ol0003ooooooooooooooooo410@
00?ooooo00?o410@ooooooooool0=?ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@4100<oooool01Ol@413ooooooooooooooooo410@03[ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@03Oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo023ooooo000mooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg03Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg03?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0jooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0cooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02;ooooo000mooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^03Cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^03?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`03oeEEEOmVIVKo000000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0cooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02;ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo000Joooooooo0000C_l00001ooooo`00
6_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0?Ooo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool08ooo
ool1o`00007ooooo0008ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKo
oooo00?o0000ooooooooool0oooooom:ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooom:ooooo`7o
00000Oooool000Go00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41001_ooool00ol0003oooooooooo`3ooooood[ooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?ooooooB?ooool3o`00007o
oooo000:ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo0008ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Oooooooogmo
Od3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Ooo
ooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000oooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`003ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000?ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000oooooo00Go0000oooooooooooooooo
o`000006ooooo`?o00001?ooooooogmoOd3oOgmo1?ooool3o`00007ooooo000?ooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool000oooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`003oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000?ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo0008
ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000:ooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`002_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41001_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000[ooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo0ol00004oooooooo
Ogmo@?moOgl4ooooo`?o00000Oooool000[ooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000:ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool000Sooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`001ooo
ool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`001oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`002?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@
41001_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000Wooooo
00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000Kooooo0ol00004oooooooo
Ogmo0_moOgl_o`0000ooOgmo1?ooool3o`00007ooooo000:ooooo`03ogMgMomVIVKooooo00;ooooo
00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00CooooooOmoOgl4o`0002oo
IVIV2Ol00006ogmoO`Kooooo0Ol00001ooooo`002oooool01Ol0003ooooooooooooooooo410@00?o
oooo00?o410@ooooooooool01?ooool00ol0003oooooooooo`04oooooo_oOgmo0_l0000kofIVIP03
o`000?moOgooOgmo00CoOgmo1_ooool1o`00007ooooo0007ooooo`05o`000?nj^[[ooooooiRHV?l@
41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?oooooiogmo
O`;o0000?_mVIVH00ol0003oOgmoogmoO`03ogmoO`Kooooo0Ol00001ooooo`001oooool01OnHV9So
410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooo
oooo00Cooooon?moOgl:o`0003?oIVIV1Ol00005ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo0omoOgl7o`0001ooIVIV3Ol0000:ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo2_moOglOo`0001OoOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooofOmoOgl?o`0005OoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooofOmoOgl00ol0003oVIVIoiVIV@0<oiVIV@go0000AomoOgl4o`0000Gooooo0Ol00001ooooo`00
6_ooool2o`0000Gooooof_moOgl00ol0003oVIVIoiVIV@0HoiVIVA[o00006OmoOglDo`0000?oVIVI
1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooofomoOgl00ol0003oVIVIoiVI
V@0aoiVIVAWo00005onIVIT6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooL
ogmoO`03o`000?nIVIWoVIVI063oVIVI1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooogOmoOgl2o`00063oVIVI1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooogomoOgl00ol0003oVIVIoiVIV@1MoiVIV@Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooon3oOgmo1ol0001HoiVIV@Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooonOoOgmo0ol0001EoiVIV@Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooon[oOgmo1Ol0001@oiVIV@Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
onooOgmo1Ol0001;oiVIV@Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooolWo
Ogmo3?l0000OogmoO`?o0000AOnIVIT4o`0000Gooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooolKoOgmo0ol0000<ofIVIPKo00007?moOgl5o`0003WoVIVI1ol00003ogmoO`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooolCoOgmo0_l0000EofIVIPSo00006Omo
Ogl8o`0002[oVIVI1ol0000:ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooolKoOgmo0_l0000KofIVIPco00005OmoOgl5o`0000goVIVI1Ol0000=oiVIV@Ko00000omoOgl4
o`0000[oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Oooooo8ogmoO`;o00009OmVIVH6o`00
01CoOgmo1_l00004oiVIV@?o00001OmoOgl3o`0000CoVIVI1_l00006ogmoO`?o00001?mVIVH3o`00
00CoOgmo1?l00004ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool01?ooooo:ogmoO`;o
0000:OmVIVHBo`0000SoOgmo1?l0000;ogmoO`Co00002_moOgl2o`0000[oIVIV1?l00003ofIVIPKo
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooolcoOgmo0_l0000iofIVIP?o0000
3?moOgl5o`0000goOgmo1?l0000CofIVIPKooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooolkoOgmo0_l0000jofIVIPGo00001?moOgl3o`0000GoIVIV0ol00004ogmoO`Ko00005omV
IVH6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooo@ogmoO`03o`000?mVIVKo
IVIV03coIVIV1?l0000;ofIVIPCo00007OmVIVH6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?oooooAogmoO`?o0000JomVIVH6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?oooooDogmoO`?o00009omVIVHeo`0000coIVIV1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CoooooeomoOgl3o`0002CoIVIV00?o0000oda<C?m<C4`0<Om<C4`00ol0003oIVIV
ofIVIP0:ofIVIPKooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooookcoOgmo1Ol0
000IogmoO`?o00008?mVIVH00ol0003oC4a<oda<C00coda<C003o`000?mVIVKoIVIV00WoIVIV1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo^_moOgl2o`0000GoVIVI1ol0000E
ogmoO`Go00006_mVIVH00ol0003oC4a<oda<C00eoda<C003o`000?mVIVKoIVIV00SoIVIV1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo^OmoOgl00ol0003oVIVIoiVIV@0<oiVI
V@Ko00005?moOgl4o`0001KoIVIV00?o0000oda<C?m<C4`0=_m<C4`00ol0003oIVIVofIVIP07ofIV
IPKooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooookSoOgmo0_l0000DoiVIV@So
00004?moOgl2o`0001?oIVIV0ol0000foda<C0?o00002?mVIVH6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?oooonjogmoO`;o00006_nIVIT5o`0000goOgmo0_l0000DofIVIP_o0000
9_m<C4`5o`0000_oIVIV1_ooool1o`00007ooooo000Jooooo`;o00001OoooonlogmoO`03o`000?nI
VIWoVIVI01coVIVI1Ol0000:ogmoO`_o00005?mVIVH6o`0001?oC4a<3Ol0000@ofIVIPGooooo0_l0
0001ooooo`006_ooool00ol0003oooooooooo`04oooookgoOgmo0_l0000QoiVIV@?o00004_moOgl7
o`0001?oIVIV4ol0000JofIVIPCo00001Oooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00Cooooo_omoOgl00ol0003oVIVIoiVIV@0QoiVIV@Go00005?moOgl6o`0002goIVIV3Ol00003ogmo
O`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooool3oOgmo0_l0000VoiVIV@Oo
00004omoOgl=o`0001WoIVIV1ol0000@ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04oooool;oOgmo00?o0000oiVIVOnIVIT0:_nIVIT;o`0001GoOgmo6Ol0000DogmoO`Co0000
1Oooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo`omoOgl3o`0003CoVIVI2?l0
000]ogmoO`go00000onIVIT6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooo6
ogmoO`?o0000>OnIVIT]o`00013oVIVI1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooobOmoOgl3o`0001SoVIVI4Ol00017oiVIV@Co00001Oooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00Coooooc?moOgl2o`0001KoVIVI00?o0000ok>c/onc/k<03_nc/k<Do`0002Ko
VIVI3Ol00003ok>c/`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooookGoOgmo
1_l0000CogmoO`;o00005?nIVIT00ol0003o/k>cok>c/`0Rok>c/bKo00004?nc/k<6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?oooonbogmoO`?o00001_mVIVH4o`00017oOgmo0ol0
000@oiVIV@03o`000?nc/k?o/k>c05Wo/k>c1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00Cooooo/?moOgl2o`0000goIVIV0ol0000AogmoO`;o00003_nIVIT3o`0005Wo/k>c1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo/OmoOgl00ol0003oIVIVofIVIP0>ofIV
IPCo00003omoOgl2o`0000ooVIVI0_l0001Gok>c/`Kooooo0Ol00001ooooo`006_ooool2o`0000Go
oooo/_moOgl00ol0003oIVIVofIVIP0AofIVIP?o00001?moOgl5o`0000GoOgmo1?l0000=oiVIV@;o
0000EOnc/k<5ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool01?ooooncogmoO`03o`00
0?mVIVKoIVIV01?oIVIV1?l00005ofIVIP;o00001omoOgl5o`0000[oVIVI0ol0001Bok>c/`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooookCoOgmo00?o0000ofIVI_mVIVH07OmV
IVH00ol0003oOgmoogmoO`09ogmoO`?o00002_nIVIT3o`0004oo/k>c1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00Cooooo]OmoOgl00ol0003oIVIVofIVIP0MofIVIP;o00003?moOgl4
o`0000WoVIVI1Ol00018ok>c/`?o00001Oooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00Cooooo]_moOgl00ol0003oIVIVofIVIP0NofIVIP?o00003OmoOgl3o`0000_oVIVI1Ol00010ok>c
/`?o00000_nIVIT6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooongogmoO`;o
00008OmVIVH6o`0000[oOgmo1Ol0000;oiVIV@So0000<onc/k<5o`0000GoVIVI1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00Cooooo^OmoOgl2o`0002GoIVIV0ol00004ogmoO`Go0000
0omoOgl5o`0000koVIVI1ol0000Ook>c/`go00002_nIVIT6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?oooonkogmoO`;o00009_mVIVH4o`0000GoIVIV0ol00005ogmoO`?o00004_nI
VITOo`0001GoVIVI0ol00005ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonm
ogmoO`;o0000<?mVIVH2o`0000KoOgmo2ol0000]oiVIV@Oo00001?nIVIT3o`0000;oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo_omoOgl2o`00033oIVIV1?l0000=ogmo
O`go00006OnIVIT7o`0000OoOgmo1?l00003ogmoO`?o00001Oooool1o`00007ooooo0007ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000
ooooooooool01?ooooo1ogmoO`;o0000<_mVIVH7o`0001?oOgmo6Ol0000BogmoO`?o00000_mVIVH6
ooooo`7o00000Oooool000Oooooo00Go410@okZj^_ooooooMgMgoc8b<P03ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01_ooool00ol0003oooooooooo`04oooool?oOgmo0_l0000DofIVIQ3o00004omV
IVH=o`0002GoOgmo3?l00005ofIVIPKooooo0Ol00001ooooo`002oooool01Ol0003ooooooooooooo
oooo410@00?ooooo00?o410@ooooooooool01?ooool00ol0003oooooooooo`04ooooolGoOgmo0ol0
000BofIVIP03o`000?m<C4coC4a<00coC4a<1_l0000JofIVIRGo00004OmVIVH6ooooo`7o00000Ooo
ool000[ooooo00?oZJVYoa0@4?ooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo0ol0
0004ooooolSoOgmo0_l0000AofIVIP03o`000?m<C4coC4a<017oC4a<3Ol0000iofIVIP_o00000ooo
ool3o`00007ooooo0009ooooo`03oa0@4?l0003o^[Zj00?ooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo00Cooooob_moOgl2o`00013oIVIV00?o0000oda<C?m<C4`07Om<
C4`=o`0001ooIVIV3Ol0000:oda<C0Kooooo0Ol00001ooooo`002_ooool00onj^[[o8B4Qooooo`02
ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`04oooook3oOgmo2Ol0
000CogmoO`;o00003omVIVH2o`0002[oC4a<7ol0000Goda<C0Kooooo0Ol00001ooooo`001oooool0
1Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`00
0?oooooooooo00Cooooo/?moOgl00ol0003oVIVIoiVIV@06oiVIV@?o00004_moOgl2o`0000ooIVIV
00?o0000oda<C?m<C4`0GOm<C4`6ooooo`7o00000Oooool000Oooooo00GoZJVYoa0@4?l0003o410@
ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`04ooooojoo
Ogmo00?o0000oiVIVOnIVIT02_nIVIT4o`00013oOgmo0_l0000>ofIVIP03o`000?m<C4coC4a<05co
C4a<1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo[_moOgl2o`00013oVIVI
0ol0000?ogmoO`;o00003OmVIVH3o`0005_oC4a<1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00Cooooo/?moOgl2o`00017oVIVI0ol0000>ogmoO`?o00003OmVIVH3o`0005SoC4a<1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo/_moOgl00ol0003oVIVIoiVIV@0A
oiVIV@?o00003_moOgl3o`0000goIVIV0ol0001Eoda<C0Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04oooook?oOgmo00?o0000oiVIVOnIVIT04onIVIT5o`0000coOgmo0ol0000=ofIV
IP?o0000D_m<C4`6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooondogmoO`03
o`000?nIVIWoVIVI01OoVIVI1Ol0000:ogmoO`?o00003OmVIVH3o`0004ooC4a<1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00Cooooo]OmoOgl00ol0003oVIVIoiVIV@0KoiVIV@?o0000
2_moOgl3o`0000goIVIV1Ol00018oda<C0?o00001Oooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00Cooooo]_moOgl2o`0001koVIVI00?o0000ogmoOomoOgl02_moOgl6o`0000coIVIV1?l0
0011oda<C0?o00000_mVIVH6ooooo`7o00000Oooool001[ooooo0_l00005oooookSoOgmo0_l0000M
oiVIV@Co00003_moOgl4o`0000coIVIV0ol0000ioda<C0Go00001OmVIVH5ooooo`;o00000Oooool0
01[ooooo00?o0000ooooooooool01?oooonjogmoO`03o`000?nIVIWoVIVI01koVIVI2ol00007ogmo
O`?o00003?mVIVH2o`00037oC4a<1_l0000:ofIVIPKooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04oooook_oOgmo0_l0000YoiVIV@;o00002?moOgl4o`0000[oIVIV4Ol0000Coda<C0go
00003_mVIVH3o`0000Gooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooookgoOgmo
0_l0000YoiVIV@;o00002_moOgl3o`0001SoIVIV4ol0000HofIVIP?o00000_moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?oooonoogmoO`03o`000?nIVIWoVIVI02SoVIVI0ol0
000:ogmoO`Go0000<omVIVH;o`0000GoOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00Cooooo`?moOgl00ol0003oVIVIoiVIV@0ZoiVIV@?o00003?moOgl=o`0001ooIVIV1ol0000@
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooool7oOgmo0_l0000]oiVI
V@Ko00004omoOglOo`0001CoOgmo1?l00005ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooo3ogmoO`;o0000<OnIVIT6o`0002KoOgmo1_l0000=ogmoO`Oo00000onIVIT6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooo5ogmoO`?o0000=?nIVIT6o`0000coOgmo
5?l00006oiVIV@?o00001?moOgl6o`0000[oVIVI1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00Cooooob?moOgl2o`0003SoVIVI3?l0000MoiVIV@Co00004?nIVIT6ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?ooooo:ogmoO`;o0000LonIVIT6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooo<ogmoO`;o0000LOnIVIT6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?ooooo>ogmoO`;o00007_nIVIT7o`0004WoVIVI0_l00005ooooo`7o
00000Oooool001[ooooo0_l00005ooooom3oOgmo0_l0000LoiVIV@03o`000?nc/k?o/k>c00?o/k>c
00?o0000oiVIVOnIVIT01onIVIT4o`0002goVIVI1?l0000;oiVIV@03o`000?oooooooooo00?ooooo
0_l00001ooooo`006_ooool00ol0003oooooooooo`04ooooom;oOgmo0_l0000KoiVIV@05o`000?nc
/k?o/k>cok>c/ol000002_nIVIT01?l0003o/k>cok>c/onc/k<]o`0000Co/k>c00?o0000oiVIVOnI
VIT02?nIVIT00ol0003oooooooooo`04ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?oooooDogmoO`03o`000?nIVIWoVIVI01WoVIVI00?o0000ok>c/ol000002_nIVIT00ol0003o/k>c
ok>c/`0dok>c/`03o`000?nIVIWoVIVI00SoVIVI00?o0000ooooooooool00oooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CoooooeOmoOgl2o`0001[oVIVI00?o0000oiVIVOnIVIT02?nI
VIT00ol0003o/k>cok>c/`0fok>c/`03o`000?nIVIWoVIVI00OoVIVI00?o0000ooooooooool00ooo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooeomoOgl3o`0002;oVIVI00?o0000
ok>c/onc/k<0=onc/k<00ol0003oVIVIoiVIV@06oiVIV@Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooom[oOgmo0ol0000NoiVIV@03o`000?nc/k?o/k>c03Wo/k>c00?o0000oiVI
VOnIVIT01OnIVIT6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooMogmoO`Co
00006OnIVIT3o`0003So/k>c1?l00006oiVIV@Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooon7oOgmo0ol0000IoiVIV@Go0000;Onc/k<6o`0000[oVIVI1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00Coooooi?moOgl3o`0001_oVIVI1ol0000Ook>c/`Oo00004?nI
VIT6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooo9ogmoO`Co00006_moOgl3
o`0001ooVIVI3Ol00005ok>c/`go00005onIVIT6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?ooooo6ogmoO`?o00001?mVIVH3o`0001[oOgmo0ol0000YoiVIV@Go00009?nIVIT6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooo4ogmoO`;o00002_mVIVH3o`0001[o
Ogmo0ol0001?oiVIV@Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooool?oOgmo
0_l0000>ofIVIPCo00006OmoOgl7o`0004CoVIVI1Ol00005ooooo`7o00000Oooool001[ooooo0_l0
0005ooooolGoOgmo0_l0000@ofIVIP;o00007_moOgl5o`0003WoVIVI1_l00004ogmoO`Gooooo0_l0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooolOoOgmo00?o0000ofIVI_mVIVH03omVIVH2
o`00027oOgmo1_l0000]oiVIV@Ko00002_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?ooooo8ogmoO`;o00004OmVIVH2o`0002GoOgmo1ol0000OoiVIV@Oo00004?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooo:ogmoO`;o00004OmVIVH5o`0002Oo
Ogmo3Ol0000<oiVIV@Ko00005omoOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?ooooo<ogmoO`03o`000?mVIVKoIVIV01?oIVIV1?l0000`ogmoO`co00007OmoOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooo=ogmoO`03o`000?mVIVKoIVIV01KoIVIV0ol0
001FogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooolkoOgmo0_l0000I
ofIVIPCo0000D_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooo@ogmo
O`;o00006omVIVH3o`0004ooOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
ooood_moOgl3o`0001_oIVIV1Ol00018ogmoO`?o00001Oooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00CoooooeOmoOgl2o`0001koIVIV1Ol00010ogmoO`?o00000_mVIVH6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?oooooGogmoO`;o00008OmVIVH3o`0003SoOgmo1Ol0
0005ofIVIPKooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooomWoOgmo0ol0000Q
ofIVIPGo0000;OmoOgl6o`0000[oIVIV1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00Cooooog?moOgl00ol0003oIVIVofIVIP0SofIVIPko00004OmoOgl>o`00013oIVIV1_ooool1o`00
007ooooo000Jooooo`;o00001OoooooMogmoO`?o0000<?mVIVHAo`0001koIVIV1Oooool2o`00007o
oooo000Jooooo`03o`000?oooooooooo00Coooooh?moOgl3o`0005coIVIV1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CooooohomoOgl3o`0005WoIVIV1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00Coooooi_moOgl2o`0005OoIVIV1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00Coooooj?moOgl2o`0005GoIVIV1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00Coooooj_moOgl4o`00057oIVIV1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00Coooook_moOgl6o`0004_oIVIV1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00Cooooom?moOgl3o`0004GoIVIV1?l00005ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooogogmoO`Go0000>OmVIVH7o`0000?oOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00Coooooo?moOgl6o`0002goIVIV1_l0000:ogmoO`Kooooo0Ol00001oooo
o`002Oooool2o`000009oa0@4?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o
0000ooooooooool01?ooooooogmoO`?oOgmo1ol0000OofIVIPOo00004?moOgl6ooooo`7o00000Ooo
ool000[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o
0000ooooooooool01?ooooooogmoO`[oOgmo7ol0000GogmoO`Kooooo0Ol00001ooooo`001oooool5
o`0000?ooooo00Go410@oooooooooooooooooa0@4006ooooo`?o00001?ooooooogmoOd3oOgmo1?oo
ool3o`00007ooooo0007ooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo0?ooooooB_ooool1o`00007ooooo0007ooooo`04omgMgOmE
EEGoooooo`0000Cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oo
ooooB_ooool1o`00007ooooo0008ooooo`03ogMgMoo<c<co000000Cooooo00Go410@oooooooooooo
oooooa0@4006ooooo`03o`000?oooooooooo0?ooooooB_ooool1o`00007ooooo0008ooooo`03onk^
k_m4A4Co000000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo0?oo
ooooB_ooool1o`00007ooooo0009ooooo`03ogMgMol0003ooooo00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP06ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0?Oooool00ol0003o
ooooooooo`0mooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0?Oooool00ol0003o
ooooooooo`0Sooooo`7o00000Oooool001[ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`09ooooo`7o00000Oooool001[oooooool0001>o`00007ooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-30.1723, -14.304, 0.195672, \
0.195672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0192308 0.211538 0.0192308 [
[.11538 -0.0125 -9 -9 ]
[.11538 -0.0125 9 0 ]
[.30769 -0.0125 -9 -9 ]
[.30769 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69231 -0.0125 -6 -9 ]
[.69231 -0.0125 6 0 ]
[.88462 -0.0125 -6 -9 ]
[.88462 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -18 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .21154 -6 -4.5 ]
[-0.0125 .21154 0 4.5 ]
[-0.0125 .40385 -12 -4.5 ]
[-0.0125 .40385 0 4.5 ]
[-0.0125 .59615 -12 -4.5 ]
[-0.0125 .59615 0 4.5 ]
[-0.0125 .78846 -12 -4.5 ]
[-0.0125 .78846 0 4.5 ]
[-0.0125 .98077 -12 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11538 0 m
.11538 .00625 L
s
[(-20)] .11538 -0.0125 0 1 Mshowa
.30769 0 m
.30769 .00625 L
s
[(-10)] .30769 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69231 0 m
.69231 .00625 L
s
[(10)] .69231 -0.0125 0 1 Mshowa
.88462 0 m
.88462 .00625 L
s
[(20)] .88462 -0.0125 0 1 Mshowa
.125 Mabswid
.15385 0 m
.15385 .00375 L
s
.19231 0 m
.19231 .00375 L
s
.23077 0 m
.23077 .00375 L
s
.26923 0 m
.26923 .00375 L
s
.34615 0 m
.34615 .00375 L
s
.38462 0 m
.38462 .00375 L
s
.42308 0 m
.42308 .00375 L
s
.46154 0 m
.46154 .00375 L
s
.53846 0 m
.53846 .00375 L
s
.57692 0 m
.57692 .00375 L
s
.61538 0 m
.61538 .00375 L
s
.65385 0 m
.65385 .00375 L
s
.73077 0 m
.73077 .00375 L
s
.76923 0 m
.76923 .00375 L
s
.80769 0 m
.80769 .00375 L
s
.84615 0 m
.84615 .00375 L
s
.07692 0 m
.07692 .00375 L
s
.03846 0 m
.03846 .00375 L
s
.92308 0 m
.92308 .00375 L
s
.96154 0 m
.96154 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(-10)] -0.0125 .01923 1 0 Mshowa
0 .21154 m
.00625 .21154 L
s
[(0)] -0.0125 .21154 1 0 Mshowa
0 .40385 m
.00625 .40385 L
s
[(10)] -0.0125 .40385 1 0 Mshowa
0 .59615 m
.00625 .59615 L
s
[(20)] -0.0125 .59615 1 0 Mshowa
0 .78846 m
.00625 .78846 L
s
[(30)] -0.0125 .78846 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(40)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .05769 m
.00375 .05769 L
s
0 .09615 m
.00375 .09615 L
s
0 .13462 m
.00375 .13462 L
s
0 .17308 m
.00375 .17308 L
s
0 .25 m
.00375 .25 L
s
0 .28846 m
.00375 .28846 L
s
0 .32692 m
.00375 .32692 L
s
0 .36538 m
.00375 .36538 L
s
0 .44231 m
.00375 .44231 L
s
0 .48077 m
.00375 .48077 L
s
0 .51923 m
.00375 .51923 L
s
0 .55769 m
.00375 .55769 L
s
0 .63462 m
.00375 .63462 L
s
0 .67308 m
.00375 .67308 L
s
0 .71154 m
.00375 .71154 L
s
0 .75 m
.00375 .75 L
s
0 .82692 m
.00375 .82692 L
s
0 .86538 m
.00375 .86538 L
s
0 .90385 m
.00375 .90385 L
s
0 .94231 m
.00375 .94231 L
s
.25 Mabswid
0 0 m
0 1 L
s
.11538 .99375 m
.11538 1 L
s
.30769 .99375 m
.30769 1 L
s
.5 .99375 m
.5 1 L
s
.69231 .99375 m
.69231 1 L
s
.88462 .99375 m
.88462 1 L
s
.125 Mabswid
.15385 .99625 m
.15385 1 L
s
.19231 .99625 m
.19231 1 L
s
.23077 .99625 m
.23077 1 L
s
.26923 .99625 m
.26923 1 L
s
.34615 .99625 m
.34615 1 L
s
.38462 .99625 m
.38462 1 L
s
.42308 .99625 m
.42308 1 L
s
.46154 .99625 m
.46154 1 L
s
.53846 .99625 m
.53846 1 L
s
.57692 .99625 m
.57692 1 L
s
.61538 .99625 m
.61538 1 L
s
.65385 .99625 m
.65385 1 L
s
.73077 .99625 m
.73077 1 L
s
.76923 .99625 m
.76923 1 L
s
.80769 .99625 m
.80769 1 L
s
.84615 .99625 m
.84615 1 L
s
.07692 .99625 m
.07692 1 L
s
.03846 .99625 m
.03846 1 L
s
.92308 .99625 m
.92308 1 L
s
.96154 .99625 m
.96154 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .21154 m
1 .21154 L
s
.99375 .40385 m
1 .40385 L
s
.99375 .59615 m
1 .59615 L
s
.99375 .78846 m
1 .78846 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .05769 m
1 .05769 L
s
.99625 .09615 m
1 .09615 L
s
.99625 .13462 m
1 .13462 L
s
.99625 .17308 m
1 .17308 L
s
.99625 .25 m
1 .25 L
s
.99625 .28846 m
1 .28846 L
s
.99625 .32692 m
1 .32692 L
s
.99625 .36538 m
1 .36538 L
s
.99625 .44231 m
1 .44231 L
s
.99625 .48077 m
1 .48077 L
s
.99625 .51923 m
1 .51923 L
s
.99625 .55769 m
1 .55769 L
s
.99625 .63462 m
1 .63462 L
s
.99625 .67308 m
1 .67308 L
s
.99625 .71154 m
1 .71154 L
s
.99625 .75 m
1 .75 L
s
.99625 .82692 m
1 .82692 L
s
.99625 .86538 m
1 .86538 L
s
.99625 .90385 m
1 .90385 L
s
.99625 .94231 m
1 .94231 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.6 g
.98077 .93737 m
.96115 .9412 L
.95411 .94152 L
.94152 .94309 L
.9219 .94534 L
.90228 .94693 L
.88265 .9477 L
.86303 .94761 L
.84341 .94665 L
.82378 .94489 L
.80416 .94255 L
.7959 .94152 L
.78454 .94062 L
.76491 .93624 L
.74529 .93048 L
.72567 .92432 L
.71733 .9219 L
.70604 .91812 L
.68642 .91195 L
.6668 .90268 L
.66581 .90228 L
.64717 .89392 L
.62755 .88442 L
.62465 .88265 L
.60793 .87349 L
.59016 .86303 L
.5883 .86169 L
.56868 .84811 L
.56187 .84341 L
.56868 .82602 L
.5883 .83132 L
.60793 .83702 L
.62755 .84237 L
.63013 .84341 L
.64717 .84917 L
.6668 .85506 L
.68642 .8592 L
.69701 .86303 L
.70604 .86563 L
.72567 .87057 L
.74529 .86883 L
.76491 .87656 L
.78454 .8811 L
.79365 .88265 L
.80416 .88404 L
.82378 .88614 L
.84341 .88755 L
.86303 .88829 L
.88265 .88836 L
.90228 .88777 L
.9219 .8865 L
.94152 .88456 L
.95634 .88265 L
.96115 .88187 L
.98077 .87773 L
F
0 g
.98077 .93737 m
.96115 .9412 L
.95411 .94152 L
.94152 .94309 L
.9219 .94534 L
.90228 .94693 L
.88265 .9477 L
.86303 .94761 L
.84341 .94665 L
.82378 .94489 L
.80416 .94255 L
.7959 .94152 L
.78454 .94062 L
.76491 .93624 L
.74529 .93048 L
.72567 .92432 L
.71733 .9219 L
.70604 .91812 L
.68642 .91195 L
.6668 .90268 L
.66581 .90228 L
.64717 .89392 L
.62755 .88442 L
.62465 .88265 L
.60793 .87349 L
.59016 .86303 L
.5883 .86169 L
.56868 .84811 L
.56187 .84341 L
.56868 .82602 L
.5883 .83132 L
.60793 .83702 L
.62755 .84237 L
.63013 .84341 L
.64717 .84917 L
.6668 .85506 L
.68642 .8592 L
.69701 .86303 L
.70604 .86563 L
.72567 .87057 L
.74529 .86883 L
.76491 .87656 L
.78454 .8811 L
.79365 .88265 L
.80416 .88404 L
.82378 .88614 L
.84341 .88755 L
.86303 .88829 L
.88265 .88836 L
.90228 .88777 L
Mistroke
.9219 .8865 L
.94152 .88456 L
.95634 .88265 L
.96115 .88187 L
.98077 .87773 L
Mfstroke
.4 g
.98077 .8653 m
.96115 .86904 L
.94152 .87235 L
.9219 .87491 L
.90228 .8766 L
.88265 .8774 L
.86303 .8773 L
.84341 .8763 L
.82378 .87442 L
.80416 .87168 L
.78454 .86823 L
.76491 .86452 L
.75448 .86303 L
.74529 .86094 L
.72567 .85964 L
.70604 .85098 L
.68642 .8439 L
.68456 .84341 L
.6668 .83699 L
.64717 .83115 L
.63427 .82378 L
.62755 .82064 L
.60793 .81125 L
.59416 .80416 L
.5883 .80054 L
.56868 .78832 L
.56283 .78454 L
.56868 .76623 L
.5883 .77042 L
.60793 .77516 L
.62755 .77655 L
.64631 .78454 L
.64717 .78507 L
.6668 .79033 L
.68642 .78752 L
.70604 .79849 L
.72567 .80367 L
.73039 .80416 L
.74529 .80706 L
.76491 .81032 L
.78454 .80702 L
.80416 .8122 L
.82378 .81523 L
.84341 .81705 L
.86303 .81795 L
.88265 .81804 L
.90228 .81732 L
.9219 .81572 L
.94152 .813 L
.96115 .80845 L
.98077 .81096 L
F
0 g
.98077 .8653 m
.96115 .86904 L
.94152 .87235 L
.9219 .87491 L
.90228 .8766 L
.88265 .8774 L
.86303 .8773 L
.84341 .8763 L
.82378 .87442 L
.80416 .87168 L
.78454 .86823 L
.76491 .86452 L
.75448 .86303 L
.74529 .86094 L
.72567 .85964 L
.70604 .85098 L
.68642 .8439 L
.68456 .84341 L
.6668 .83699 L
.64717 .83115 L
.63427 .82378 L
.62755 .82064 L
.60793 .81125 L
.59416 .80416 L
.5883 .80054 L
.56868 .78832 L
.56283 .78454 L
.56868 .76623 L
.5883 .77042 L
.60793 .77516 L
.62755 .77655 L
.64631 .78454 L
.64717 .78507 L
.6668 .79033 L
.68642 .78752 L
.70604 .79849 L
.72567 .80367 L
.73039 .80416 L
.74529 .80706 L
.76491 .81032 L
.78454 .80702 L
.80416 .8122 L
.82378 .81523 L
.84341 .81705 L
.86303 .81795 L
.88265 .81804 L
.90228 .81732 L
.9219 .81572 L
.94152 .813 L
.96115 .80845 L
Mistroke
.98077 .81096 L
Mfstroke
.6 g
.98077 .80188 m
.96677 .80416 L
.96115 .80447 L
.94152 .80664 L
.9219 .80884 L
.90228 .81044 L
.88265 .81122 L
.86303 .81112 L
.84341 .81015 L
.82378 .8084 L
.80416 .80612 L
.78454 .80421 L
.78311 .80416 L
.76491 .80112 L
.74529 .79733 L
.72567 .79772 L
.70604 .78834 L
.69379 .78454 L
.68642 .78218 L
.6668 .7757 L
.64717 .77225 L
.63725 .76491 L
.62755 .76046 L
.60793 .75135 L
.59554 .74529 L
.5883 .74003 L
.57088 .72567 L
.5883 .72089 L
.60793 .72323 L
.62127 .72567 L
.62755 .72706 L
.64717 .73131 L
.6668 .73528 L
.68642 .73708 L
.70604 .74274 L
.72014 .74529 L
.72567 .74633 L
.74529 .74956 L
.76491 .75228 L
.78454 .74949 L
.80416 .75493 L
.82378 .75817 L
.84341 .76025 L
.86303 .76135 L
.88265 .76146 L
.90228 .76058 L
.9219 .75872 L
.94152 .75577 L
.96115 .75102 L
.98077 .75282 L
F
0 g
.98077 .80188 m
.96677 .80416 L
.96115 .80447 L
.94152 .80664 L
.9219 .80884 L
.90228 .81044 L
.88265 .81122 L
.86303 .81112 L
.84341 .81015 L
.82378 .8084 L
.80416 .80612 L
.78454 .80421 L
.78311 .80416 L
.76491 .80112 L
.74529 .79733 L
.72567 .79772 L
.70604 .78834 L
.69379 .78454 L
.68642 .78218 L
.6668 .7757 L
.64717 .77225 L
.63725 .76491 L
.62755 .76046 L
.60793 .75135 L
.59554 .74529 L
.5883 .74003 L
.57088 .72567 L
.5883 .72089 L
.60793 .72323 L
.62127 .72567 L
.62755 .72706 L
.64717 .73131 L
.6668 .73528 L
.68642 .73708 L
.70604 .74274 L
.72014 .74529 L
.72567 .74633 L
.74529 .74956 L
.76491 .75228 L
.78454 .74949 L
.80416 .75493 L
.82378 .75817 L
.84341 .76025 L
.86303 .76135 L
.88265 .76146 L
.90228 .76058 L
.9219 .75872 L
.94152 .75577 L
.96115 .75102 L
.98077 .75282 L
Mistroke
Mfstroke
.4 g
.98077 .74383 m
.97176 .74529 L
.96115 .74637 L
.94152 .74944 L
.9219 .75248 L
.90228 .75491 L
.88265 .75622 L
.86303 .75605 L
.84341 .75445 L
.82378 .75185 L
.80416 .74874 L
.78454 .74582 L
.77802 .74529 L
.76491 .74308 L
.74529 .73938 L
.72567 .73526 L
.70604 .73068 L
.68723 .72567 L
.68642 .72539 L
.6668 .71848 L
.64717 .71141 L
.63324 .70604 L
.62755 .70255 L
.60793 .68878 L
.60498 .68642 L
.60793 .68449 L
.62755 .68277 L
.64717 .68463 L
.65996 .68642 L
.6668 .68756 L
.68642 .69069 L
.70604 .69356 L
.72567 .69621 L
.74529 .69596 L
.76491 .70087 L
.78454 .70285 L
.80416 .70453 L
.82378 .70585 L
.82677 .70604 L
.84341 .70676 L
.86303 .70723 L
.88265 .70727 L
.90228 .7069 L
.9219 .70609 L
.92278 .70604 L
.94152 .70485 L
.96115 .70325 L
.98077 .70133 L
F
0 g
.98077 .74383 m
.97176 .74529 L
.96115 .74637 L
.94152 .74944 L
.9219 .75248 L
.90228 .75491 L
.88265 .75622 L
.86303 .75605 L
.84341 .75445 L
.82378 .75185 L
.80416 .74874 L
.78454 .74582 L
.77802 .74529 L
.76491 .74308 L
.74529 .73938 L
.72567 .73526 L
.70604 .73068 L
.68723 .72567 L
.68642 .72539 L
.6668 .71848 L
.64717 .71141 L
.63324 .70604 L
.62755 .70255 L
.60793 .68878 L
.60498 .68642 L
.60793 .68449 L
.62755 .68277 L
.64717 .68463 L
.65996 .68642 L
.6668 .68756 L
.68642 .69069 L
.70604 .69356 L
.72567 .69621 L
.74529 .69596 L
.76491 .70087 L
.78454 .70285 L
.80416 .70453 L
.82378 .70585 L
.82677 .70604 L
.84341 .70676 L
.86303 .70723 L
.88265 .70727 L
.90228 .7069 L
.9219 .70609 L
.92278 .70604 L
.94152 .70485 L
.96115 .70325 L
.98077 .70133 L
s
.6 g
.98077 .68989 m
.96115 .69245 L
.94152 .6945 L
.9219 .69604 L
.90228 .69706 L
.88265 .69754 L
.86303 .69748 L
.84341 .69688 L
.82378 .69574 L
.80416 .69409 L
.78454 .69193 L
.76491 .68925 L
.74784 .68642 L
.74529 .68581 L
.72567 .68085 L
.70604 .67554 L
.68642 .66994 L
.67631 .6668 L
.68642 .64988 L
.70604 .65127 L
.72567 .65292 L
.74529 .65456 L
.76491 .65609 L
.78454 .65746 L
.80416 .65862 L
.82378 .65954 L
.84341 .65889 L
.86303 .6617 L
.88265 .66057 L
.90228 .65975 L
.9219 .65971 L
.94152 .65884 L
.96115 .65773 L
.98077 .65641 L
F
0 g
.98077 .68989 m
.96115 .69245 L
.94152 .6945 L
.9219 .69604 L
.90228 .69706 L
.88265 .69754 L
.86303 .69748 L
.84341 .69688 L
.82378 .69574 L
.80416 .69409 L
.78454 .69193 L
.76491 .68925 L
.74784 .68642 L
.74529 .68581 L
.72567 .68085 L
.70604 .67554 L
.68642 .66994 L
.67631 .6668 L
.68642 .64988 L
.70604 .65127 L
.72567 .65292 L
.74529 .65456 L
.76491 .65609 L
.78454 .65746 L
.80416 .65862 L
.82378 .65954 L
.84341 .65889 L
.86303 .6617 L
.88265 .66057 L
.90228 .65975 L
.9219 .65971 L
.94152 .65884 L
.96115 .65773 L
.98077 .65641 L
s
.3 g
.98077 .8531 m
.96115 .85712 L
.94152 .86035 L
.9219 .86278 L
.92012 .86303 L
.90228 .86475 L
.88265 .86579 L
.86303 .86566 L
.84341 .86438 L
.82965 .86303 L
.82378 .86232 L
.80416 .85971 L
.78454 .8563 L
.76491 .85211 L
.74529 .84703 L
.73328 .84341 L
.72567 .84051 L
.70604 .8324 L
.68827 .82378 L
.70604 .81547 L
.72567 .81692 L
.74529 .81887 L
.76491 .82084 L
.78454 .82123 L
.79836 .82378 L
.80416 .8243 L
.82378 .82575 L
.84341 .82674 L
.86303 .82726 L
.88265 .82731 L
.90228 .82689 L
.9219 .82601 L
.94152 .82466 L
.95166 .82378 L
.96115 .82219 L
.98077 .82125 L
F
0 g
.98077 .8531 m
.96115 .85712 L
.94152 .86035 L
.9219 .86278 L
.92012 .86303 L
.90228 .86475 L
.88265 .86579 L
.86303 .86566 L
.84341 .86438 L
.82965 .86303 L
.82378 .86232 L
.80416 .85971 L
.78454 .8563 L
.76491 .85211 L
.74529 .84703 L
.73328 .84341 L
.72567 .84051 L
.70604 .8324 L
.68827 .82378 L
.70604 .81547 L
.72567 .81692 L
.74529 .81887 L
.76491 .82084 L
.78454 .82123 L
.79836 .82378 L
.80416 .8243 L
.82378 .82575 L
.84341 .82674 L
.86303 .82726 L
.88265 .82731 L
.90228 .82689 L
.9219 .82601 L
.94152 .82466 L
.95166 .82378 L
.96115 .82219 L
.98077 .82125 L
s
.7 g
.98077 .79199 m
.96115 .79562 L
.94152 .79854 L
.9219 .80074 L
.90228 .8022 L
.88265 .80289 L
.86303 .80281 L
.84341 .80195 L
.82378 .80032 L
.80416 .79796 L
.78454 .79488 L
.76491 .7911 L
.74529 .78651 L
.73791 .78454 L
.72567 .78003 L
.70604 .77186 L
.69187 .76491 L
.70604 .75902 L
.72567 .75925 L
.74529 .76047 L
.76491 .76193 L
.78454 .76141 L
.80416 .7645 L
.8085 .76491 L
.82378 .76581 L
.84341 .76663 L
.86303 .76707 L
.88265 .76711 L
.90228 .76676 L
.9219 .76603 L
.94143 .76491 L
.94152 .76491 L
.96115 .76235 L
.98077 .76225 L
F
0 g
.98077 .79199 m
.96115 .79562 L
.94152 .79854 L
.9219 .80074 L
.90228 .8022 L
.88265 .80289 L
.86303 .80281 L
.84341 .80195 L
.82378 .80032 L
.80416 .79796 L
.78454 .79488 L
.76491 .7911 L
.74529 .78651 L
.73791 .78454 L
.72567 .78003 L
.70604 .77186 L
.69187 .76491 L
.70604 .75902 L
.72567 .75925 L
.74529 .76047 L
.76491 .76193 L
.78454 .76141 L
.80416 .7645 L
.8085 .76491 L
.82378 .76581 L
.84341 .76663 L
.86303 .76707 L
.88265 .76711 L
.90228 .76676 L
.9219 .76603 L
.94143 .76491 L
.94152 .76491 L
.96115 .76235 L
.98077 .76225 L
s
.4 g
.98077 .63511 m
.96115 .63874 L
.94152 .64176 L
.9219 .64405 L
.90228 .64554 L
.88265 .64624 L
.86303 .64615 L
.84341 .64528 L
.82378 .64361 L
.80416 .64116 L
.78454 .63799 L
.76491 .63424 L
.74529 .62996 L
.7355 .62755 L
.74529 .6207 L
.76491 .61959 L
.78454 .61958 L
.80416 .61988 L
.82378 .62023 L
.84341 .62051 L
.86303 .62068 L
.88265 .62069 L
.90228 .62056 L
.9219 .6203 L
.94152 .61996 L
.96115 .61964 L
.98077 .61954 L
F
0 g
.98077 .63511 m
.96115 .63874 L
.94152 .64176 L
.9219 .64405 L
.90228 .64554 L
.88265 .64624 L
.86303 .64615 L
.84341 .64528 L
.82378 .64361 L
.80416 .64116 L
.78454 .63799 L
.76491 .63424 L
.74529 .62996 L
.7355 .62755 L
.74529 .6207 L
.76491 .61959 L
.78454 .61958 L
.80416 .61988 L
.82378 .62023 L
.84341 .62051 L
.86303 .62068 L
.88265 .62069 L
.90228 .62056 L
.9219 .6203 L
.94152 .61996 L
.96115 .61964 L
.98077 .61954 L
s
.3 g
.98077 .73143 m
.96115 .73545 L
.94152 .73868 L
.9219 .74112 L
.90228 .74273 L
.88265 .74349 L
.86303 .7434 L
.84341 .74245 L
.82378 .74066 L
.80416 .73804 L
.78454 .73463 L
.76491 .73044 L
.74679 .72567 L
.76491 .71552 L
.78454 .71555 L
.80416 .71598 L
.82378 .71646 L
.84341 .71683 L
.86303 .71704 L
.88265 .71706 L
.90228 .71689 L
.9219 .71655 L
.94152 .71609 L
.96115 .71563 L
.98077 .71546 L
F
0 g
.98077 .73143 m
.96115 .73545 L
.94152 .73868 L
.9219 .74112 L
.90228 .74273 L
.88265 .74349 L
.86303 .7434 L
.84341 .74245 L
.82378 .74066 L
.80416 .73804 L
.78454 .73463 L
.76491 .73044 L
.74679 .72567 L
.76491 .71552 L
.78454 .71555 L
.80416 .71598 L
.82378 .71646 L
.84341 .71683 L
.86303 .71704 L
.88265 .71706 L
.90228 .71689 L
.9219 .71655 L
.94152 .71609 L
.96115 .71563 L
.98077 .71546 L
s
.8 g
.82378 .78094 m
.84341 .77973 L
.86303 .77943 L
.88265 .7794 L
.90228 .77963 L
.9219 .7805 L
.93559 .78454 L
.9219 .78705 L
.90228 .78931 L
.88265 .79032 L
.86303 .79019 L
.84341 .78893 L
.82378 .78634 L
.81447 .78454 L
F
0 g
.82378 .78094 m
.84341 .77973 L
.86303 .77943 L
.88265 .7794 L
.90228 .77963 L
.9219 .7805 L
.93559 .78454 L
.9219 .78705 L
.90228 .78931 L
.88265 .79032 L
.86303 .79019 L
.84341 .78893 L
.82378 .78634 L
.81447 .78454 L
.82378 .78094 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00?Oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0dooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kS?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0hooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8b
onk^kS?ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08_ooool003gooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0=_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0<oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg03?ooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL08_ooool003Gooooo1_l0
0003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400[ooooo`Ko0000
1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100<oooool01Ol@413o
oooooooooooooooo410@03[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@03Cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@02;ooooo000o
ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000fooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000cooooo`05o`000?ooooooooooooooool0
0000>_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000=Oooool00onH
V9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000008_ooool0043ooooo00?oMgMgofIV
I_ooool00_ooool01Ol0003ooooooooooooooooo000003Kooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000003?ooooo00Go0000ooooooooooooooooo`00000jooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`03ogMgMomVIVKooooo00;o
oooo00Go0000ooooooooooooooooo`00000Rooooo`00@Oooool01Ol0003ooooooooooooooooo410@
00?ooooo00?o410@ooooooooool0=?ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@4100<oooool01Ol@413ooooooooooooooooo410@03[ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@03Oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo023ooooo000mooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg03Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg03?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0jooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0cooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02;ooooo000mooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^03Cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^03?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`03oeEEEOmVIVKo000000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0cooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02;ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo000Joooooooo0000C_l00001ooooo`00
6_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0?Ooo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool08ooo
ool1o`00007ooooo0008ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKo
oooo00?o0000ooooooooool0oooooom:ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooom:ooooo`7o
00000Oooool000Go00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41001_ooool00ol0003oooooooooo`3ooooood[ooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?ooooooB?ooool3o`00007o
oooo000:ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo0008ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Oooooooogmo
Od3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Ooo
ooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000oooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`003ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000?ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000oooooo00Go0000oooooooooooooooo
o`000006ooooo`?o00001?ooooooogmoOd3oOgmo1?ooool3o`00007ooooo000?ooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool000oooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`003oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000?ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo0008
ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000:ooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`002_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41001_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000[ooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo0ol00004oooooooo
Ogmo@?moOgl4ooooo`?o00000Oooool000[ooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000:ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool000Sooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`001ooo
ool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`001oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`002?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@
41001_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000Wooooo
00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000Kooooo0ol00004oooooooo
Ogmo@?moOgl4ooooo`?o00000Oooool000[ooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000;ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`04ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`001oooool01Ol0003o^[Zj
oooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`001oooool01OnHV9So410@o`000?lQ8B7oc<c<
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00Cooooom?moOgl>o`0003?oOgmo2ol00005ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooo`ogmoO`Co00003_mVIVHco`0000[oIVIV1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Coooook_moOgl2o`0004ooIVIV1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooookOmoOgl3o`0004ooIVIV1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00Coooool?moOgl5o`0004[oIVIV1_ooool1o`00007o
oooo000Jooooo`;o00001OoooooeogmoO`Go0000AOmVIVH5ooooo`;o00000Oooool001[ooooo00?o
0000ooooooooool01?ooooojogmoO`?o0000?omVIVH4o`0000Gooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04oooooogoOgmo1Ol0000cofIVIPOo00000omoOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoO`?oOgmo3Ol0000PofIVIPKo00002_moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOa3oOgmo8?l0000@ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooomgoOgmo1Ol0001MogmoO`Kooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooomgoOgmo00?o0000oiVIVOnIVIT00_nI
VIT=o`00053oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooog?moOgl0
0ol0003oVIVIoiVIV@0@oiVIV@Ko0000B_moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?oooooLogmoO`03o`000?nIVIWoVIVI01KoVIVI5?l00005ogmoO`So00006OmoOglAo`00
00Gooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooom_oOgmo00?o0000oiVIVOnI
VIT0:onIVIT5o`0000SoVIVI6Ol0000@oiVIV@Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooom_oOgmo00?o0000oiVIVOnIVIT0HOnIVIT6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?oooooJogmoO`?o0000H_nIVIT6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?oooooMogmoO`?o0000GonIVIT6ooooo`7o00000Oooool001[ooooo0_l00005oooo
on3oOgmo0ol0001LoiVIV@Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04ooooon?o
Ogmo1?l0001HoiVIV@Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooonOoOgmo
0ol0001EoiVIV@Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooolOoOgmo1ol0
000LogmoO`Go0000D?nIVIT6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooo3
ogmoO`Co00001omVIVH5o`0001coOgmo0ol0001=oiVIV@Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04oooool;oOgmo0ol0000>ofIVIPSo00005omoOgl4o`0004WoVIVI1_ooool1o`00
007ooooo000Jooooo`03o`000?oooooooooo00CoooooaOmoOgl00ol0003oIVIVofIVIP0CofIVIPOo
00005?moOgl<o`0003[oVIVI1?l00005ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?ooooo6ogmoO`;o00006_mVIVH6o`0001[oOgmo1ol0000VoiVIV@go00000omoOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooo8ogmoO`03o`000?mVIVKoIVIV01goIVIV3Ol0
000DogmoObKo00004?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooo9
ogmoO`03o`000?mVIVKoIVIV02WoIVIV1ol00013ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04oooool[oOgmo0_l0000`ofIVIPKo0000<omoOgl;o`0000Gooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooolcoOgmo0_l0000dofIVIQCo00003?moOglCo`0000[o
IVIV1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Coooooc_moOgl2o`0004KoIVIV
3?l0000MofIVIPKooooo0Ol00001ooooo`006_ooool2o`0000Goooood?moOgl3o`0006coIVIV1Ooo
ool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooodomoOgl3o`00023oIVIV4ol0000V
ofIVIQ7o00001Oooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Coooooe_moOgl3o`00
01coIVIV00?o0000oda<C?m<C4`04Om<C4`Vo`00013oC4a<1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00Cooooo_?moOgl5o`0001SoOgmo0_l0000HofIVIP;o0000B_m<C4`6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooniogmoO`?o00001OnIVIT6o`0001CoOgmo
0_l0000EofIVIP03o`000?m<C4coC4a<04[oC4a<1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00Cooooo]omoOgl2o`0000koVIVI1_l0000@ogmoO`Go00003omVIVH4o`0004[oC4a<1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo^OmoOgl00ol0003oVIVIoiVIV@0A
oiVIV@?o00004_moOgl5o`0000koIVIV1Ol00015oda<C0Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04oooook[oOgmo0_l0000DoiVIV@Go00004_moOgl3o`00013oIVIV0ol0000ooda<
C0Co00001Oooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo_?moOgl00ol0003o
VIVIoiVIV@0FoiVIV@_o00002_moOgl5o`0000koIVIV1Ol0000coda<C0Oo00000omVIVH6ooooo`7o
00000Oooool001[ooooo00?o0000ooooooooool01?oooonmogmoO`03o`000?nIVIWoVIVI023oVIVI
0ol0000<ogmoO`Ko00003OmVIVH7o`0002KoC4a<1_l0000:ofIVIPKooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04oooookkoOgmo00?o0000oiVIVOnIVIT08_nIVIT4o`0000koOgmo1_l0
000>ofIVIPgo00003?m<C4`=o`00013oIVIV1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00Cooooo_omoOgl2o`0002KoVIVI0ol0000AogmoO`Oo00005?mVIVH<o`0001SoIVIV1_l00005
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooo1ogmoO`;o00009onIVIT5o`00
01?oOgmo1ol0000/ofIVIPGo00001OmoOgl6ooooo`7o00000Oooool001[ooooo0_l00005oooool?o
Ogmo0_l0000ZoiVIV@Ko00001_moOgl7o`0000OoOgmo1_l0000PofIVIPKo00000_moOgl6o`0000;o
Ogmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooaOmoOgl3o`0002goVIVI
1_l00007oiVIV@Oo00001_moOgl7o`0000coIVIV3Ol00005ogmoO`?o00001_nIVIT3o`0000Gooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooolSoOgmo0_l0000ooiVIV@Ko00001omo
Ogl<o`0000goOgmo1Ol0000;oiVIV@Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
oooool[oOgmo0_l0000GoiVIVA;o00006_nIVIT7o`0000coOgmo3Ol0000@oiVIV@Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooolcoOgmo00?o0000oiVIVOnIVIT04OnIVIT3o`00
01;o/k>c3Ol0000DoiVIV@co00004onIVIT;o`0000Gooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04oooookKoOgmo0ol0000DogmoO`;o00004?nIVIT2o`00027o/k>c<ol0000:ok>c/`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooookKoOgmo00?o0000ofIVI_mVIVH0
0ol0000CogmoO`03o`000?nIVIWoVIVI00ooVIVI0ol0001Kok>c/`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04oooookGoOgmo00?o0000ofIVI_mVIVH01?mVIVH5o`0000ooOgmo1Ol0
000?oiVIV@;o0000FOnc/k<6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooone
ogmoO`03o`000?mVIVKoIVIV00WoIVIV1ol0000=ogmoO`Go00003?nIVIT2o`0005Oo/k>c1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo]OmoOgl00ol0003oIVIVofIVIP0@ofIV
IPGo00003OmoOgl3o`0000_oVIVI0_l0001Eok>c/`Kooooo0Ol00001ooooo`001oooool01OnHV9So
410@o`000?lb<S;oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooo
oooo00Cooooo]?moOgl00ol0003oIVIVofIVIP0FofIVIP?o00003OmoOgl3o`0000[oVIVI0ol0000M
ok>c/bGo00004?nc/k<6ooooo`7o00000Oooool000Oooooo00Go410@okZj^_ooooooMgMgoc8b<P03
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`04oooookCoOgmo0_l0
000JofIVIP?o00003OmoOgl3o`0000[oVIVI1?l0000Gok>c/`?o00008oo<c<`3o`0000ko/k>c1_oo
ool1o`00007ooooo000;ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo]_moOgl2o`0001_oIVIV0ol00004ogmoO`Go00001?mo
Ogl3o`0000_oVIVI1?l0000Fok>c/`Co00006Oo<c<`6o`00017o/k>c1_ooool1o`00007ooooo000:
ooooo`03ojVYZOl@413ooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`?o00001?oo
oonhogmoO`03o`000?mVIVKoIVIV01_oIVIV1?l00005ofIVIP;o00001OmoOgl00ol0003oVIVIoiVI
V@0<oiVIV@Go00005Onc/k<Io`0001Oo/k>c1?ooool3o`00007ooooo0009ooooo`03oa0@4?l0003o
^[Zj00?ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00Cooooo^Omo
Ogl2o`0002KoIVIV00?o0000ogmoOomoOgl00omoOgl2o`00017oVIVI0ol0000ook>c/`Co00001Ooo
ool1o`00007ooooo000:ooooo`03okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@
4006ooooo`03o`000?oooooooooo00Cooooo^omoOgl00ol0003oIVIVofIVIP0TofIVIP;o00001Omo
Ogl00ol0003oVIVIoiVIV@02oiVIV@Ko00002OnIVIT5o`0003?o/k>c1ol00003oiVIV@Kooooo0Ol0
0001ooooo`001oooool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`06ooooo`03o`000?oooooooooo00Cooooo_?moOgl00ol0003oIVIVofIVIP0UofIVIP?o0000
0omoOgl4o`0000KoOgmo0ol0000;oiVIV@go00008?nc/k<6o`0000[oVIVI1_ooool1o`00007ooooo
0007ooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Ko
oooo00?o0000ooooooooool01?oooonmogmoO`;o0000:?mVIVH3o`0000goOgmo1?l0000DoiVIVB3o
00003_nIVIT3o`0000Gooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooookooOgmo
0_l0000YofIVIPKo00002omoOgl>o`0002coVIVI2?l00002ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04oooool7oOgmo0_l0000]ofIVIPGo00001_moOgl7o`0000OoOgmo1_l0
000IoiVIV@go00000_moOgl6o`0000;oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00Cooooo`omoOgl2o`00033oIVIV1_l00007ofIVIPOo00001_moOglIo`0000coOgmo0ol00006
ofIVIP?o00001Oooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooaOmoOgl3o`00
01_oIVIV1Ol0000QofIVIPKo00008?moOgl5o`0000_oIVIV1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00Cooooob?moOgl2o`0001OoIVIV0_l00005oda<C0Oo00008?mVIVHPo`00013o
IVIV1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooob_moOgl2o`0001?oIVIV
0_l0000>oda<C1;o0000>omVIVH4o`0000Gooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooolcoOgmo0_l0000@ofIVIP;o00008Om<C4`8o`0002_oIVIV2?l00003oda<C0Kooooo0Ol0
0001ooooo`006_ooool2o`0000Gooooo]_moOgl3o`0001GoOgmo00?o0000ofIVI_mVIVH03omVIVH2
o`0002OoC4a<:ol0000;oda<C0Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04oooo
okKoOgmo00?o0000oiVIVOnIVIT00ol0000CogmoO`03o`000?mVIVKoIVIV013oIVIV0_l0001Koda<
C0Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooookGoOgmo00?o0000oiVIVOnI
VIT01?nIVIT4o`00013oOgmo0ol0000AofIVIP;o0000FOm<C4`6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooneogmoO`03o`000?nIVIWoVIVI00SoVIVI0ol0000@ogmoO`?o0000
4?mVIVH2o`0005OoC4a<1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo]Omo
Ogl00ol0003oVIVIoiVIV@0;oiVIV@Go00003_moOgl4o`0000koIVIV0_l0001Eoda<C0Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04oooookCoOgmo00?o0000oiVIVOnIVIT04OnIVIT3
o`0000ooOgmo0ol0000=ofIVIP?o0000D_m<C4`6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?oooondogmoO`;o00005?nIVIT3o`00013oOgmo0ol0000=ofIVIP?o0000Com<C4`6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonfogmoO`;o00005OnIVIT3o`00013o
Ogmo0ol0000=ofIVIPCo0000Bom<C4`6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?oooonhogmoO`03o`000?nIVIWoVIVI01GoVIVI0ol0000@ogmoO`?o00003_mVIVH3o`0004SoC4a<
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo^OmoOgl2o`0001SoVIVI0ol0
000@ogmoO`;o00003omVIVH5o`00043oC4a<1?l00005ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?oooonkogmoO`03o`000?nIVIWoVIVI01SoVIVI1Ol0000=ogmoO`;o00004_mVIVH6
o`0003?oC4a<1ol00003ofIVIPKooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
okcoOgmo00?o0000oiVIVOnIVIT07?nIVIT5o`0000[oOgmo1Ol0000CofIVIPOo00009_m<C4`6o`00
00[oIVIV1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo_OmoOgl2o`00027o
VIVI1?l0000;ogmoO`So00004_mVIVH7o`0001SoC4a<1ol0000@ofIVIPKooooo0Ol00001ooooo`00
6_ooool2o`0000Gooooo_omoOgl00ol0003oVIVIoiVIV@0RoiVIV@?o00004?moOgl5o`0001CoIVIV
6?l0000DofIVIPCo00001?ooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo`?mo
Ogl2o`0002GoVIVI0ol00004ogmoO`Go00002OmoOgl6o`0003?oIVIV1ol00003ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04oooool;oOgmo00?o0000oiVIVOnIVIT09OnIVIT4
o`0000GoVIVI0_l0000=ogmoO`Oo00009_mVIVH6o`0000[oOgmo1_ooool1o`00007ooooo000Joooo
o`03o`000?oooooooooo00Cooooo`omoOgl2o`00033oVIVI0_l0000BogmoO`Ko00006OmVIVH7o`00
013oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooaOmoOgl2o`00033o
VIVI1Ol0000CogmoOaWo00005OmoOgl3o`0000Gooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooolOoOgmo0_l0000coiVIV@Go0000>OmoOgl3o`0000;oVIVI1_ooool1o`00007ooooo
000Jooooo`03o`000?oooooooooo00CooooobOmoOgl3o`0003GoVIVI2?l0000VogmoO`_o00001OnI
VIT6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooo<ogmoO`03o`000?nIVIWo
VIVI03[oVIVI3Ol0000BogmoO`Oo00004?nIVIT6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?ooooo=ogmoO`;o0000AonIVITBo`0001OoVIVI1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooocomoOgl00ol0003oVIVIoiVIV@1]oiVIV@Kooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooom3oOgmo0ol0001/oiVIV@Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooom?oOgmo0ol0001YoiVIV@Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooomKoOgmo0ol0001VoiVIV@Kooooo0Ol00001ooooo`006_ooool2o`00
00GooooofOmoOgl00ol0003oVIVIoiVIV@1SoiVIV@Gooooo0_l00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooom[oOgmo0_l0001SoiVIV@Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooomcoOgmo00?o0000oiVIVOnIVIT0H?nIVIT6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?oooooMogmoO`?o0000GonIVIT6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?oooooPogmoO`?o0000G?nIVIT6ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?oooooSogmoO`Co0000F?nIVIT6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?oooooWogmoO`?o0000EOnIVIT6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?oooooZogmoO`?o0000D_nIVIT6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooo]ogmoO`?o0000ConIVIT6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooo`
ogmoO`Co0000BonIVIT6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooodogmo
O`?o0000B?nIVIT6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooogogmoO`Go
0000@?nIVIT4o`0000Gooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooocoOgmo
2?l0000`oiVIV@So00000omoOgl6ooooo`7o00000Oooool001[ooooo0_l00005ooooooooOgmo1Omo
Ogl;o`00023oVIVI1Ol0000;ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo4?moOglPo`00013oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000Wooooo0_l000002Ol@413ooooooooo
ooooooook^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmo
O`Kooooo0Ol00001ooooo`002_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000Oo
oooo1Ol00003ooooo`05oa0@4?ooooooooooooooool@41001_ooool3o`0000CooooooomoOgm0ogmo
O`Cooooo0ol00001ooooo`001oooool01?m4A4CogMgMooooool00004ooooo`05o`000?oooooooooo
ooooool000001_ooool00ol0003oooooooooo`3ooooood[ooooo0Ol00001ooooo`001oooool01?oM
gMgoEEEEooooool00004ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooooooo
o`3ooooood[ooooo0Ol00001ooooo`002?ooool00omgMgOoc<c<o`000004ooooo`05oa0@4?oooooo
ooooooooool@41001_ooool00ol0003oooooooooo`3ooooood[ooooo0Ol00001ooooo`002?ooool0
0oo^k^koA4A4o`000004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003ooooooooo
o`3ooooood[ooooo0Ol00001ooooo`002Oooool00omgMgOo0000ooooo`03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03gooooo00?o
0000ooooooooool0?Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03gooooo00?o
0000ooooooooool08oooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02Oooool1o`00007ooooo000Joooooooo0000C_l00001ooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-30.1723, -14.304, 0.195672, \
0.195672}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.0192308 0.211538 0.0192308 [
[.11538 -0.0125 -9 -9 ]
[.11538 -0.0125 9 0 ]
[.30769 -0.0125 -9 -9 ]
[.30769 -0.0125 9 0 ]
[.5 -0.0125 -3 -9 ]
[.5 -0.0125 3 0 ]
[.69231 -0.0125 -6 -9 ]
[.69231 -0.0125 6 0 ]
[.88462 -0.0125 -6 -9 ]
[.88462 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[-0.0125 .01923 -18 -4.5 ]
[-0.0125 .01923 0 4.5 ]
[-0.0125 .21154 -6 -4.5 ]
[-0.0125 .21154 0 4.5 ]
[-0.0125 .40385 -12 -4.5 ]
[-0.0125 .40385 0 4.5 ]
[-0.0125 .59615 -12 -4.5 ]
[-0.0125 .59615 0 4.5 ]
[-0.0125 .78846 -12 -4.5 ]
[-0.0125 .78846 0 4.5 ]
[-0.0125 .98077 -12 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.11538 0 m
.11538 .00625 L
s
[(-20)] .11538 -0.0125 0 1 Mshowa
.30769 0 m
.30769 .00625 L
s
[(-10)] .30769 -0.0125 0 1 Mshowa
.5 0 m
.5 .00625 L
s
[(0)] .5 -0.0125 0 1 Mshowa
.69231 0 m
.69231 .00625 L
s
[(10)] .69231 -0.0125 0 1 Mshowa
.88462 0 m
.88462 .00625 L
s
[(20)] .88462 -0.0125 0 1 Mshowa
.125 Mabswid
.15385 0 m
.15385 .00375 L
s
.19231 0 m
.19231 .00375 L
s
.23077 0 m
.23077 .00375 L
s
.26923 0 m
.26923 .00375 L
s
.34615 0 m
.34615 .00375 L
s
.38462 0 m
.38462 .00375 L
s
.42308 0 m
.42308 .00375 L
s
.46154 0 m
.46154 .00375 L
s
.53846 0 m
.53846 .00375 L
s
.57692 0 m
.57692 .00375 L
s
.61538 0 m
.61538 .00375 L
s
.65385 0 m
.65385 .00375 L
s
.73077 0 m
.73077 .00375 L
s
.76923 0 m
.76923 .00375 L
s
.80769 0 m
.80769 .00375 L
s
.84615 0 m
.84615 .00375 L
s
.07692 0 m
.07692 .00375 L
s
.03846 0 m
.03846 .00375 L
s
.92308 0 m
.92308 .00375 L
s
.96154 0 m
.96154 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
0 .01923 m
.00625 .01923 L
s
[(-10)] -0.0125 .01923 1 0 Mshowa
0 .21154 m
.00625 .21154 L
s
[(0)] -0.0125 .21154 1 0 Mshowa
0 .40385 m
.00625 .40385 L
s
[(10)] -0.0125 .40385 1 0 Mshowa
0 .59615 m
.00625 .59615 L
s
[(20)] -0.0125 .59615 1 0 Mshowa
0 .78846 m
.00625 .78846 L
s
[(30)] -0.0125 .78846 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(40)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .05769 m
.00375 .05769 L
s
0 .09615 m
.00375 .09615 L
s
0 .13462 m
.00375 .13462 L
s
0 .17308 m
.00375 .17308 L
s
0 .25 m
.00375 .25 L
s
0 .28846 m
.00375 .28846 L
s
0 .32692 m
.00375 .32692 L
s
0 .36538 m
.00375 .36538 L
s
0 .44231 m
.00375 .44231 L
s
0 .48077 m
.00375 .48077 L
s
0 .51923 m
.00375 .51923 L
s
0 .55769 m
.00375 .55769 L
s
0 .63462 m
.00375 .63462 L
s
0 .67308 m
.00375 .67308 L
s
0 .71154 m
.00375 .71154 L
s
0 .75 m
.00375 .75 L
s
0 .82692 m
.00375 .82692 L
s
0 .86538 m
.00375 .86538 L
s
0 .90385 m
.00375 .90385 L
s
0 .94231 m
.00375 .94231 L
s
.25 Mabswid
0 0 m
0 1 L
s
.11538 .99375 m
.11538 1 L
s
.30769 .99375 m
.30769 1 L
s
.5 .99375 m
.5 1 L
s
.69231 .99375 m
.69231 1 L
s
.88462 .99375 m
.88462 1 L
s
.125 Mabswid
.15385 .99625 m
.15385 1 L
s
.19231 .99625 m
.19231 1 L
s
.23077 .99625 m
.23077 1 L
s
.26923 .99625 m
.26923 1 L
s
.34615 .99625 m
.34615 1 L
s
.38462 .99625 m
.38462 1 L
s
.42308 .99625 m
.42308 1 L
s
.46154 .99625 m
.46154 1 L
s
.53846 .99625 m
.53846 1 L
s
.57692 .99625 m
.57692 1 L
s
.61538 .99625 m
.61538 1 L
s
.65385 .99625 m
.65385 1 L
s
.73077 .99625 m
.73077 1 L
s
.76923 .99625 m
.76923 1 L
s
.80769 .99625 m
.80769 1 L
s
.84615 .99625 m
.84615 1 L
s
.07692 .99625 m
.07692 1 L
s
.03846 .99625 m
.03846 1 L
s
.92308 .99625 m
.92308 1 L
s
.96154 .99625 m
.96154 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .01923 m
1 .01923 L
s
.99375 .21154 m
1 .21154 L
s
.99375 .40385 m
1 .40385 L
s
.99375 .59615 m
1 .59615 L
s
.99375 .78846 m
1 .78846 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .05769 m
1 .05769 L
s
.99625 .09615 m
1 .09615 L
s
.99625 .13462 m
1 .13462 L
s
.99625 .17308 m
1 .17308 L
s
.99625 .25 m
1 .25 L
s
.99625 .28846 m
1 .28846 L
s
.99625 .32692 m
1 .32692 L
s
.99625 .36538 m
1 .36538 L
s
.99625 .44231 m
1 .44231 L
s
.99625 .48077 m
1 .48077 L
s
.99625 .51923 m
1 .51923 L
s
.99625 .55769 m
1 .55769 L
s
.99625 .63462 m
1 .63462 L
s
.99625 .67308 m
1 .67308 L
s
.99625 .71154 m
1 .71154 L
s
.99625 .75 m
1 .75 L
s
.99625 .82692 m
1 .82692 L
s
.99625 .86538 m
1 .86538 L
s
.99625 .90385 m
1 .90385 L
s
.99625 .94231 m
1 .94231 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.5 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.4 g
.98077 .90006 m
.96705 .90228 L
.96115 .90278 L
.94152 .9048 L
.9219 .90655 L
.90228 .90765 L
.88265 .90798 L
.86303 .90749 L
.84341 .90625 L
.82378 .90439 L
.80416 .90244 L
.80195 .90228 L
.78454 .90216 L
.76491 .89698 L
.74529 .89093 L
.72567 .88487 L
.71686 .88265 L
.70604 .87924 L
.68642 .87527 L
.6668 .86506 L
.66174 .86303 L
.64717 .85684 L
.62755 .85033 L
.61819 .84341 L
.60793 .83791 L
.5883 .82709 L
.58267 .82378 L
.56868 .81367 L
.55324 .80416 L
.56868 .79388 L
.5883 .79739 L
.60793 .80017 L
.61907 .80416 L
.62755 .80764 L
.64717 .81314 L
.6668 .81529 L
.68642 .82317 L
.68931 .82378 L
.70604 .82806 L
.72567 .83245 L
.74529 .83366 L
.76491 .83925 L
.78454 .84273 L
.79088 .84341 L
.80416 .84514 L
.82378 .8472 L
.84341 .84868 L
.86303 .84958 L
.88265 .84992 L
.90228 .8497 L
.9219 .84891 L
.94152 .84755 L
.96115 .8456 L
.97818 .84341 L
.98077 .84318 L
F
0 g
.98077 .90006 m
.96705 .90228 L
.96115 .90278 L
.94152 .9048 L
.9219 .90655 L
.90228 .90765 L
.88265 .90798 L
.86303 .90749 L
.84341 .90625 L
.82378 .90439 L
.80416 .90244 L
.80195 .90228 L
.78454 .90216 L
.76491 .89698 L
.74529 .89093 L
.72567 .88487 L
.71686 .88265 L
.70604 .87924 L
.68642 .87527 L
.6668 .86506 L
.66174 .86303 L
.64717 .85684 L
.62755 .85033 L
.61819 .84341 L
.60793 .83791 L
.5883 .82709 L
.58267 .82378 L
.56868 .81367 L
.55324 .80416 L
.56868 .79388 L
.5883 .79739 L
.60793 .80017 L
.61907 .80416 L
.62755 .80764 L
.64717 .81314 L
.6668 .81529 L
.68642 .82317 L
.68931 .82378 L
.70604 .82806 L
.72567 .83245 L
.74529 .83366 L
.76491 .83925 L
.78454 .84273 L
.79088 .84341 L
.80416 .84514 L
.82378 .8472 L
.84341 .84868 L
.86303 .84958 L
.88265 .84992 L
.90228 .8497 L
Mistroke
.9219 .84891 L
.94152 .84755 L
.96115 .8456 L
.97818 .84341 L
.98077 .84318 L
Mfstroke
.6 g
.98077 .91093 m
.96115 .91656 L
.94152 .91994 L
.92353 .9219 L
.9219 .92201 L
.90228 .923 L
.88265 .92328 L
.86303 .92285 L
.84462 .9219 L
.84341 .92169 L
.82378 .91938 L
.80416 .91567 L
.78454 .91504 L
.76491 .91152 L
.74529 .90729 L
.72567 .90234 L
.72544 .90228 L
.70604 .89362 L
.68642 .89207 L
.6668 .88596 L
.6584 .88265 L
.64717 .87677 L
.62755 .87372 L
.60793 .86731 L
.59506 .86303 L
.5883 .86129 L
.56868 .85794 L
.5606 .86303 L
.56868 .8715 L
.58122 .88265 L
.5883 .88727 L
.60793 .89983 L
.61169 .90228 L
.62755 .91121 L
.64717 .92142 L
.64811 .9219 L
.6668 .93476 L
.68642 .93935 L
.69174 .94152 L
.70604 .94749 L
.72567 .95662 L
.74529 .96026 L
.74838 .96115 L
.76491 .96557 L
.78454 .97018 L
.80416 .97403 L
.82378 .97705 L
.84341 .97919 L
.86303 .98048 L
.87104 .98077 L
.98077 .98077 L
F
0 g
.98077 .91093 m
.96115 .91656 L
.94152 .91994 L
.92353 .9219 L
.9219 .92201 L
.90228 .923 L
.88265 .92328 L
.86303 .92285 L
.84462 .9219 L
.84341 .92169 L
.82378 .91938 L
.80416 .91567 L
.78454 .91504 L
.76491 .91152 L
.74529 .90729 L
.72567 .90234 L
.72544 .90228 L
.70604 .89362 L
.68642 .89207 L
.6668 .88596 L
.6584 .88265 L
.64717 .87677 L
.62755 .87372 L
.60793 .86731 L
.59506 .86303 L
.5883 .86129 L
.56868 .85794 L
.5606 .86303 L
.56868 .8715 L
.58122 .88265 L
.5883 .88727 L
.60793 .89983 L
.61169 .90228 L
.62755 .91121 L
.64717 .92142 L
.64811 .9219 L
.6668 .93476 L
.68642 .93935 L
.69174 .94152 L
.70604 .94749 L
.72567 .95662 L
.74529 .96026 L
.74838 .96115 L
.76491 .96557 L
.78454 .97018 L
.80416 .97403 L
.82378 .97705 L
.84341 .97919 L
.86303 .98048 L
.87104 .98077 L
Mistroke
Mfstroke
.6 g
.98077 .83703 m
.96115 .83671 L
.94152 .83881 L
.9219 .8403 L
.90228 .84118 L
.88265 .84143 L
.86303 .84105 L
.84341 .84005 L
.82378 .83843 L
.80416 .842 L
.78454 .83587 L
.76491 .83032 L
.74529 .82529 L
.73673 .82378 L
.72567 .82095 L
.70604 .81558 L
.68642 .81184 L
.67008 .80416 L
.6668 .80291 L
.64717 .79529 L
.62755 .79027 L
.62147 .78454 L
.60793 .77738 L
.5883 .76684 L
.58492 .76491 L
.5883 .74537 L
.60793 .74897 L
.62755 .75305 L
.64717 .75718 L
.6668 .76108 L
.68366 .76491 L
.68642 .76566 L
.70604 .76985 L
.72567 .77353 L
.74529 .77479 L
.76491 .78097 L
.78454 .78226 L
.80416 .78444 L
.80509 .78454 L
.82378 .78624 L
.84341 .78753 L
.86303 .78832 L
.88265 .78861 L
.90228 .78842 L
.9219 .78773 L
.94152 .78654 L
.96115 .78484 L
.96405 .78454 L
.98077 .78273 L
F
0 g
.98077 .83703 m
.96115 .83671 L
.94152 .83881 L
.9219 .8403 L
.90228 .84118 L
.88265 .84143 L
.86303 .84105 L
.84341 .84005 L
.82378 .83843 L
.80416 .842 L
.78454 .83587 L
.76491 .83032 L
.74529 .82529 L
.73673 .82378 L
.72567 .82095 L
.70604 .81558 L
.68642 .81184 L
.67008 .80416 L
.6668 .80291 L
.64717 .79529 L
.62755 .79027 L
.62147 .78454 L
.60793 .77738 L
.5883 .76684 L
.58492 .76491 L
.5883 .74537 L
.60793 .74897 L
.62755 .75305 L
.64717 .75718 L
.6668 .76108 L
.68366 .76491 L
.68642 .76566 L
.70604 .76985 L
.72567 .77353 L
.74529 .77479 L
.76491 .78097 L
.78454 .78226 L
.80416 .78444 L
.80509 .78454 L
.82378 .78624 L
.84341 .78753 L
.86303 .78832 L
.88265 .78861 L
.90228 .78842 L
.9219 .78773 L
.94152 .78654 L
.96115 .78484 L
.96405 .78454 L
.98077 .78273 L
s
.4 g
.98077 .7743 m
.96115 .77675 L
.94152 .77867 L
.9219 .78005 L
.90228 .78086 L
.88265 .78109 L
.86303 .78074 L
.84341 .77981 L
.82378 .77833 L
.80416 .7763 L
.78454 .77375 L
.76491 .77385 L
.74529 .76701 L
.7358 .76491 L
.72567 .76236 L
.70604 .75715 L
.68642 .75161 L
.6668 .74555 L
.66634 .74529 L
.64717 .73732 L
.62755 .72906 L
.61994 .72567 L
.60793 .7157 L
.60516 .70604 L
.60793 .70568 L
.62396 .70604 L
.62755 .70648 L
.64717 .70943 L
.6668 .71257 L
.68642 .71568 L
.70604 .7119 L
.72567 .7217 L
.74529 .72459 L
.75289 .72567 L
.76491 .72729 L
.78454 .72956 L
.80416 .73139 L
.82378 .73282 L
.84341 .73385 L
.86303 .73448 L
.88265 .72825 L
.90228 .72728 L
.9219 .73401 L
.94152 .73306 L
.96115 .73171 L
.98077 .72996 L
F
0 g
.98077 .7743 m
.96115 .77675 L
.94152 .77867 L
.9219 .78005 L
.90228 .78086 L
.88265 .78109 L
.86303 .78074 L
.84341 .77981 L
.82378 .77833 L
.80416 .7763 L
.78454 .77375 L
.76491 .77385 L
.74529 .76701 L
.7358 .76491 L
.72567 .76236 L
.70604 .75715 L
.68642 .75161 L
.6668 .74555 L
.66634 .74529 L
.64717 .73732 L
.62755 .72906 L
.61994 .72567 L
.60793 .7157 L
.60516 .70604 L
.60793 .70568 L
.62396 .70604 L
.62755 .70648 L
.64717 .70943 L
.6668 .71257 L
.68642 .71568 L
.70604 .7119 L
.72567 .7217 L
.74529 .72459 L
.75289 .72567 L
.76491 .72729 L
.78454 .72956 L
.80416 .73139 L
.82378 .73282 L
.84341 .73385 L
.86303 .73448 L
.88265 .72825 L
.90228 .72728 L
.9219 .73401 L
.94152 .73306 L
.96115 .73171 L
.98077 .72996 L
s
.6 g
.98077 .71919 m
.96115 .72175 L
.94152 .72379 L
.9219 .72526 L
.91435 .72567 L
.90228 .72587 L
.88265 .72604 L
.86303 .72596 L
.85223 .72567 L
.84341 .72501 L
.82378 .72342 L
.80416 .72127 L
.78454 .71862 L
.76491 .71552 L
.74529 .71198 L
.72567 .70792 L
.71756 .70604 L
.70604 .70231 L
.68642 .69569 L
.6668 .6889 L
.66009 .68642 L
.6668 .67236 L
.68642 .67323 L
.70604 .67492 L
.72567 .6768 L
.74529 .67871 L
.76491 .67617 L
.78454 .68228 L
.80416 .6838 L
.82378 .68507 L
.84341 .68603 L
.85204 .68642 L
.86303 .68663 L
.88265 .68685 L
.90228 .68671 L
.91462 .68642 L
.9219 .68618 L
.94152 .68529 L
.96115 .68408 L
.98077 .6826 L
F
0 g
.98077 .71919 m
.96115 .72175 L
.94152 .72379 L
.9219 .72526 L
.91435 .72567 L
.90228 .72587 L
.88265 .72604 L
.86303 .72596 L
.85223 .72567 L
.84341 .72501 L
.82378 .72342 L
.80416 .72127 L
.78454 .71862 L
.76491 .71552 L
.74529 .71198 L
.72567 .70792 L
.71756 .70604 L
.70604 .70231 L
.68642 .69569 L
.6668 .6889 L
.66009 .68642 L
.6668 .67236 L
.68642 .67323 L
.70604 .67492 L
.72567 .6768 L
.74529 .67871 L
.76491 .67617 L
.78454 .68228 L
.80416 .6838 L
.82378 .68507 L
.84341 .68603 L
.85204 .68642 L
.86303 .68663 L
.88265 .68685 L
.90228 .68671 L
.91462 .68642 L
.9219 .68618 L
.94152 .68529 L
.96115 .68408 L
.98077 .6826 L
s
.4 g
.98077 .66736 m
.96115 .66964 L
.94152 .67138 L
.9219 .67261 L
.90228 .67333 L
.88265 .67354 L
.86303 .67323 L
.84341 .67241 L
.82378 .67107 L
.80416 .66923 L
.78454 .66683 L
.78433 .6668 L
.76491 .66228 L
.74529 .65692 L
.72567 .65106 L
.71372 .64717 L
.72567 .64166 L
.74529 .64089 L
.76491 .64126 L
.78454 .64196 L
.80416 .64274 L
.82378 .64346 L
.84341 .64404 L
.86303 .64441 L
.88265 .64456 L
.90228 .64446 L
.9219 .64413 L
.94152 .64359 L
.96115 .64289 L
.98077 .64212 L
F
0 g
.98077 .66736 m
.96115 .66964 L
.94152 .67138 L
.9219 .67261 L
.90228 .67333 L
.88265 .67354 L
.86303 .67323 L
.84341 .67241 L
.82378 .67107 L
.80416 .66923 L
.78454 .66683 L
.78433 .6668 L
.76491 .66228 L
.74529 .65692 L
.72567 .65106 L
.71372 .64717 L
.72567 .64166 L
.74529 .64089 L
.76491 .64126 L
.78454 .64196 L
.80416 .64274 L
.82378 .64346 L
.84341 .64404 L
.86303 .64441 L
.88265 .64456 L
.90228 .64446 L
.9219 .64413 L
.94152 .64359 L
.96115 .64289 L
.98077 .64212 L
s
.7 g
.98077 .8246 m
.96115 .82746 L
.94152 .82989 L
.9219 .83159 L
.90228 .83258 L
.88265 .83287 L
.86303 .83244 L
.84341 .83131 L
.82378 .82947 L
.80416 .83088 L
.78597 .82378 L
.78454 .82347 L
.76491 .81885 L
.74529 .81352 L
.72567 .80741 L
.71643 .80416 L
.72567 .78668 L
.74529 .78846 L
.76491 .79035 L
.78454 .79209 L
.80416 .7936 L
.82378 .79481 L
.84341 .79571 L
.86303 .79627 L
.88265 .79648 L
.90228 .79634 L
.9219 .79585 L
.94152 .79502 L
.96115 .79386 L
.98077 .79242 L
F
0 g
.98077 .8246 m
.96115 .82746 L
.94152 .82989 L
.9219 .83159 L
.90228 .83258 L
.88265 .83287 L
.86303 .83244 L
.84341 .83131 L
.82378 .82947 L
.80416 .83088 L
.78597 .82378 L
.78454 .82347 L
.76491 .81885 L
.74529 .81352 L
.72567 .80741 L
.71643 .80416 L
.72567 .78668 L
.74529 .78846 L
.76491 .79035 L
.78454 .79209 L
.80416 .7936 L
.82378 .79481 L
.84341 .79571 L
.86303 .79627 L
.88265 .79648 L
.90228 .79634 L
.9219 .79585 L
.94152 .79502 L
.96115 .79386 L
.98077 .79242 L
s
.3 g
.98077 .88539 m
.96115 .88903 L
.94152 .8918 L
.9219 .89375 L
.90228 .89488 L
.88265 .89521 L
.86303 .89472 L
.84341 .89342 L
.82378 .89132 L
.80416 .88837 L
.78454 .88711 L
.77628 .88265 L
.76491 .87953 L
.74529 .87351 L
.72567 .86649 L
.7171 .86303 L
.72567 .84848 L
.74529 .85044 L
.76491 .8526 L
.78454 .85461 L
.80416 .85635 L
.82378 .85776 L
.84341 .8588 L
.86303 .85945 L
.88265 .8597 L
.90228 .85953 L
.9219 .85896 L
.94152 .858 L
.96115 .85666 L
.98077 .85499 L
F
0 g
.98077 .88539 m
.96115 .88903 L
.94152 .8918 L
.9219 .89375 L
.90228 .89488 L
.88265 .89521 L
.86303 .89472 L
.84341 .89342 L
.82378 .89132 L
.80416 .88837 L
.78454 .88711 L
.77628 .88265 L
.76491 .87953 L
.74529 .87351 L
.72567 .86649 L
.7171 .86303 L
.72567 .84848 L
.74529 .85044 L
.76491 .8526 L
.78454 .85461 L
.80416 .85635 L
.82378 .85776 L
.84341 .8588 L
.86303 .85945 L
.88265 .8597 L
.90228 .85953 L
.9219 .85896 L
.94152 .858 L
.96115 .85666 L
.98077 .85499 L
s
.3 g
.98077 .76429 m
.97775 .76491 L
.96115 .76752 L
.94152 .76983 L
.9219 .77145 L
.90228 .77239 L
.88265 .77266 L
.86303 .77226 L
.84341 .77118 L
.82378 .76942 L
.80416 .76697 L
.79108 .76491 L
.78454 .76335 L
.76491 .75797 L
.74529 .75148 L
.73023 .74529 L
.74529 .74059 L
.76491 .74029 L
.78454 .74085 L
.80416 .74161 L
.82378 .74235 L
.84341 .74295 L
.86303 .74334 L
.88265 .74034 L
.90228 .73974 L
.9219 .74304 L
.94152 .74248 L
.96115 .74176 L
.98077 .74099 L
F
0 g
.98077 .76429 m
.97775 .76491 L
.96115 .76752 L
.94152 .76983 L
.9219 .77145 L
.90228 .77239 L
.88265 .77266 L
.86303 .77226 L
.84341 .77118 L
.82378 .76942 L
.80416 .76697 L
.79108 .76491 L
.78454 .76335 L
.76491 .75797 L
.74529 .75148 L
.73023 .74529 L
.74529 .74059 L
.76491 .74029 L
.78454 .74085 L
.80416 .74161 L
.82378 .74235 L
.84341 .74295 L
.86303 .74334 L
.88265 .74034 L
.90228 .73974 L
.9219 .74304 L
.94152 .74248 L
.96115 .74176 L
.98077 .74099 L
s
.7 g
.82378 .70479 m
.84341 .70271 L
.86303 .70216 L
.88265 .70202 L
.90228 .70211 L
.9219 .70255 L
.94152 .70403 L
.94879 .70604 L
.94152 .70737 L
.9219 .70994 L
.90228 .71134 L
.88265 .71174 L
.86303 .71114 L
.84341 .70953 L
.82378 .70666 L
.82059 .70604 L
F
0 g
.82378 .70479 m
.84341 .70271 L
.86303 .70216 L
.88265 .70202 L
.90228 .70211 L
.9219 .70255 L
.94152 .70403 L
.94879 .70604 L
.94152 .70737 L
.9219 .70994 L
.90228 .71134 L
.88265 .71174 L
.86303 .71114 L
.84341 .70953 L
.82378 .70666 L
.82059 .70604 L
.82378 .70479 L
s
.5 g
.98077 .97102 m
.96115 .97471 L
.94152 .97755 L
.9219 .97951 L
.90228 .98064 L
.8982 .98077 L
.98077 .98077 L
F
0 g
.98077 .97102 m
.96115 .97471 L
.94152 .97755 L
.9219 .97951 L
.90228 .98064 L
.8982 .98077 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00?Oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0dooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kS?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0hooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8b
onk^kS?ooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08_ooool003gooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0=_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0<oooool01OmgMgOoV9RHoooooonHV9SoMgMg
03[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg03?ooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL08_ooool003Gooooo1_l0
0003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@400[ooooo`Ko0000
1Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100<oooool01Ol@413o
oooooooooooooooo410@03[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@03Cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@02;ooooo000o
ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000fooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000cooooo`05o`000?ooooooooooooooool0
0000>_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000=Oooool00onH
V9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000008_ooool0043ooooo00?oMgMgofIV
I_ooool00_ooool01Ol0003ooooooooooooooooo000003Kooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000003?ooooo00Go0000ooooooooooooooooo`00000jooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000fooooo`03ogMgMomVIVKooooo00;o
oooo00Go0000ooooooooooooooooo`00000Rooooo`00@Oooool01Ol0003ooooooooooooooooo410@
00?ooooo00?o410@ooooooooool0=?ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@4100<oooool01Ol@413ooooooooooooooooo410@03[ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@03Oooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo023ooooo000mooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg03Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg03?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0jooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0cooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg02;ooooo000mooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^03Cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^03?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0hooooo`03oeEEEOmVIVKo000000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0cooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02;ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo000Joooooooo0000C_l00001ooooo`00
6_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0?Ooo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool08ooo
ool1o`00007ooooo0008ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKo
oooo00?o0000ooooooooool0oooooom:ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0oooooom:ooooo`7o
00000Oooool000Go00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41001_ooool00ol0003oooooooooo`3ooooood[ooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool3o`000?ooooooB?ooool3o`00007o
oooo000:ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool000[ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo0008ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Oooooooogmo
Od3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001Ooo
ooooogmoOd3oOgmo1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000oooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`003ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000?ooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000oooooo00Go0000oooooooooooooooo
o`000006ooooo`?o00001?ooooooogmoOd3oOgmo1?ooool3o`00007ooooo000?ooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool000oooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`003oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000?ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`;o00001OooooooogmoOd3oOgmo1Oooool2
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo0008
ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000:ooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`002_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41001_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000[ooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo0ol00004oooooooo
Ogmo@?moOgl4ooooo`?o00000Oooool000[ooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000:ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool000Sooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?mo
Ogl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l00001oooo
o`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo
00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmo
Od3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool2o`0000GooooooomoOgm0ogmoO`Gooooo0_l0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
ooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`001ooo
ool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo00Cooooo
oomoOgm0ogmoO`Kooooo0Ol00001ooooo`001oooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Ko
oooo0Ol00001ooooo`002?ooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@
41001_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool000Wooooo
00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000Kooooo0ol00004oooooooo
Ogmo@?moOgl4ooooo`?o00000Oooool000[ooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000;ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`04ooooo`03
o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`001oooool01Ol0003o^[Zj
oooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`001oooool01OnHV9So410@o`000?lQ8B7oc<c<
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo00CooooooomoOgm0
ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooooooOgmo@?moOgl6ooooo`7o00000Oooool001[ooooo00?o0000
ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo
00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooooo
Ogmo@?moOgl6ooooo`7o00000Oooool001[ooooo0_l00005ooooooooOgmo@?moOgl5ooooo`;o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooooogmoOd3oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00CooooooomoOgm0ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooonWoOgmo9_l0000PogmoOa7o00001Oooool1o`00007ooooo000Jooooo`03
o`000?oooooooooo00CoooooiomoOgl2o`0002KoIVIV8?l0000@ofIVIPKooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooonKoOgmo0ol0001FofIVIPKooooo0Ol00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooonWoOgmo1?l0001BofIVIPKooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooongoOgmo0ol0001?ofIVIPKooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04oooooo3oOgmo1?l0001;ofIVIPKooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooooCoOgmo0ol00018ofIVIPKooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooooOoOgmo1Ol00013ofIVIPKooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04oooooocoOgmo1_l0000jofIVIPCo00001Oooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CooooooomoOgl3ogmoO`Oo0000;?mVIVH7o`0000?oOgmo1_ooool1o`00007ooooo000Joooo
o`;o00001OoooooGogmoO`_o00009omoOgl/o`0000[oOgmo1Oooool2o`00007ooooo000Jooooo`03
o`000?oooooooooo00CoooooeomoOgl00ol0003oVIVIoiVIV@08oiVIV@go00001OmoOgl6o`0004Go
Ogmo1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Coooooe_moOgl00ol0003oVIVI
oiVIV@0FoiVIV@Go00001_nIVIT3o`0004;oOgmo1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CoooooeOmoOgl00ol0003oVIVIoiVIV@0UoiVIV@Go0000>_moOgl4o`0000Gooooo0Ol0
0001ooooo`006_ooool00ol0003oooooooooo`04ooooomGoOgmo00?o0000oiVIVOnIVIT0:_nIVITB
o`0001_oOgmo3Ol00003oiVIV@Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
omCoOgmo1Ol0000koiVIVA_o00004?nIVIT6ooooo`7o00000Oooool001[ooooo00?o0000oooooooo
ool01?oooooIogmoO`;o0000I?nIVIT6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?oooooKogmoO`;o0000H_nIVIT6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oo
oooMogmoO`?o0000GonIVIT6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooP
ogmoO`?o0000G?nIVIT6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooSogmo
O`Co00009onIVITVo`0000_oVIVI1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooo`_moOgl<o`0001WoOgmo0ol0000PoiVIV@Go00009?nc/k<2o`0000[oVIVI1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00Cooooo`_moOgl00ol0003oIVIVofIVIP09ofIVIPOo0000
5OmoOgl5o`00023oVIVI1ol0000Bok>c/`_o00003?nIVIT6ooooo`7o00000Oooool001[ooooo0_l0
0005oooool?oOgmo00?o0000ofIVI_mVIVH03omVIVH6o`0000KoOgmo1Ol00009ogmoO`Ko00008OnI
VITBo`0001OoVIVI1Oooool2o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo`omoOgl0
0ol0003oIVIVofIVIP0EofIVIPKo00001OmVIVH2o`0000goOgmo1ol00013oiVIV@Kooooo0Ol00001
ooooo`006_ooool00ol0003oooooooooo`04ooooolCoOgmo00?o0000ofIVI_mVIVH08OmVIVH2o`00
01;oOgmo1_l0000moiVIV@Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooolGo
Ogmo00?o0000ofIVI_mVIVH08_mVIVH5o`0001?oOgmo1ol0000/oiVIV@_o00001Oooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00Coooooa_moOgl00ol0003oIVIVofIVIP0VofIVIPCo0000
5_moOgl;o`0001_oVIVI1_l0000:ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04ooooolOoOgmo0ol0000YofIVIPWo00006?moOglKo`00013oOgmo1_ooool1o`00007ooooo000J
ooooo`03o`000?oooooooooo00Cooooob_moOgl2o`00033oIVIV1_l0000KogmoO`Go00001_mVIVH3
o`00017oOgmo1?l00005ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooo<ogmo
O`;o0000=?mVIVHDo`0000CoOgmo0ol0000>ofIVIQ7o00000omVIVH6ooooo`7o00000Oooool001[o
oooo00?o0000ooooooooool01?ooooo>ogmoO`;o0000A_mVIVH4o`0002GoIVIV1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00Coooood?moOgl3o`0004ooIVIV1ol0000FofIVIPKooooo
0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooom?oOgmo0ol0000IofIVIROo00001OmV
IVH7o`0000OoC4a<5ol00005ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonm
ogmoO`Co00005OmoOgl4o`0001;oIVIV0ol0000Woda<C0Go00009?m<C4`6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?oooonmogmoO`04o`000?nIVIWoVIVIoiVIV@Go00005?moOgl3
o`00017oIVIV0ol0001>oda<C0Kooooo0Ol00001ooooo`006_ooool2o`0000Gooooo_OmoOgl00ol0
003oVIVIoiVIV@06oiVIV@?o00005?moOgl3o`00017oIVIV0ol0001;oda<C0Gooooo0_l00001oooo
o`006_ooool00ol0003oooooooooo`04oooookcoOgmo00?o0000oiVIVOnIVIT02_nIVIT5o`0001;o
Ogmo0ol0000AofIVIP?o0000B?m<C4`6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?oooonlogmoO`03o`000?nIVIWoVIVI00ooVIVI1ol0000>ogmoO`Co00004?mVIVH3o`0004GoC4a<
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo_?moOgl00ol0003oVIVIoiVI
V@0FoiVIV@Co00003_moOgl3o`00013oIVIV0ol00012oda<C0Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04oooook_oOgmo00?o0000oiVIVOnIVIT06onIVIT3o`0000koOgmo0ol0000@
ofIVIP?o0000?om<C4`00ol0003oooooooooo`03ooooo`7o00000Oooool001[ooooo00?o0000oooo
ooooool01?oooonkogmoO`Co00007OnIVIT6o`0000_oOgmo1_l0000=ofIVIPWo0000<_m<C4`4o`00
00Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooookooOgmo00?o0000oiVIVOnI
VIT08?nIVIT5o`0000coOgmo0_l0000DofIVIPKo00008?m<C4`<o`0000CoIVIV1_ooool1o`00007o
oooo000Jooooo`03o`000?oooooooooo00Cooooo`?moOgl2o`0002GoVIVI0ol0000;ogmoO`;o0000
6?mVIVHPo`00013oIVIV1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo`_mo
Ogl00ol0003oVIVIoiVIV@0UoiVIV@[o00000omoOglBo`0003?oIVIV1?l00005ooooo`7o00000Ooo
ool001[ooooo00?o0000ooooooooool01?ooooo3ogmoO`;o0000;onIVIT3o`0001;oOgmo1_l0000P
ofIVIPgo00000omoOgl6ooooo`7o00000Oooool000Oooooo00GoV9RHoa0@4?l0003o<S8bolc<c003
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`04ooooolGoOgmo0ol0
000_oiVIV@_o00003OmoOglPo`00013oOgmo1_ooool1o`00007ooooo0007ooooo`05oa0@4?nj^[[o
ooooogMgMolb<S800oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0
1?ooooo8ogmoO`03o`000?nIVIWoVIVI03OoVIVI1ol0000/ogmoO`_o00001Oooool1o`00007ooooo
000;ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`04ooooo`03o`00
0?oooooooooo00CooooobOmoOgl00ol0003oVIVIoiVIV@0NoiVIV@Go00006_nIVITCo`0000coOgmo
3Ol0000:oiVIV@Kooooo0Ol00001ooooo`002_ooool00onYZJWo410@ooooo`02ooooo`05o`000?oo
ooooooooooooool000001_ooool3o`0000Cooooob_moOgl3o`0001goVIVI00?o0000ok>c/onc/k<0
0_nc/k<=o`00023oVIVI3?l0000GoiVIV@Cooooo0ol00001ooooo`002Oooool00ol@413o0000okZj
^P03ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`04oooookGoOgmo
1_l0000BogmoO`?o00006OnIVIT00ol0003o/k>cok>c/`0@ok>c/`go0000;?nIVIT;o`0000Gooooo
0Ol00001ooooo`002_ooool00onj^[[o8B4Qooooo`02ooooo`05oa0@4?ooooooooooooooool@4100
1_ooool00ol0003oooooooooo`04oooookCoOgmo00?o0000ofIVI_mVIVH01?mVIVH6o`0000ooOgmo
0ol0000FoiVIV@03o`000?nc/k?o/k>c01go/k>c;?l0000:ok>c/`Kooooo0Ol00001ooooo`001ooo
ool01Ol@413oV9RHoooooonj^[[o000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03
o`000?oooooooooo00Cooooo/omoOgl00ol0003oIVIVofIVIP0;ofIVIPCo00003_moOgl3o`0001;o
VIVI00?o0000ok>c/onc/k<0E?nc/k<6ooooo`7o00000Oooool000Oooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`04oooo
ok;oOgmo00?o0000ofIVI_mVIVH04?mVIVH2o`0000ooOgmo0_l0000@oiVIV@03o`000?nc/k?o/k>c
05Co/k>c1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo/OmoOgl2o`0001Co
IVIV0ol0000>ogmoO`;o00003OnIVIT3o`0005Go/k>c1_ooool1o`00007ooooo000Jooooo`03o`00
0?oooooooooo00Cooooo/omoOgl2o`0001GoIVIV0ol0000=ogmoO`?o00003OnIVIT3o`0005;o/k>c
1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo]OmoOgl00ol0003oIVIVofIV
IP0EofIVIP?o00003OmoOgl3o`0000goVIVI0ol0001?ok>c/`Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04oooookKoOgmo0_l0000HofIVIPWo00001omoOgl3o`0000goVIVI1?l0001;
ok>c/`Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooookSoOgmo0_l0000OofIV
IP;o00002?moOgl5o`0000coVIVI0ol00018ok>c/`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04oooook[oOgmo00?o0000ofIVI_mVIVH07_mVIVH2o`0000_oOgmo1Ol0000:oiVIV@Go
0000@onc/k<6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooonkogmoO`;o0000
8?mVIVH4o`0000coOgmo1?l0000;oiVIV@Co0000?onc/k<6ooooo`7o00000Oooool001[ooooo0_l0
0005oooookgoOgmo0_l0000RofIVIP?o00003OmoOgl4o`0000_oVIVI0_l0000cok>c/`_o00001?oo
ool2o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo_omoOgl00ol0003oIVIVofIVIP0R
ofIVIPCo00003OmoOgl5o`0000SoVIVI0_l00004ok>c/`Oo00008?nc/k<6o`0000[oVIVI1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo`?moOgl2o`0002KoIVIV1ol0000;ogmo
O`?o00001onIVIT4o`0000OoVIVI8?l0000@oiVIV@Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04oooool;oOgmo00?o0000ofIVI_mVIVH0:_mVIVH6o`0000SoOgmo1?l0000noiVIV@Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooool?oOgmo0_l0000`ofIVIPGo0000
1omoOgl3o`0000CoVIVI1ol0000PoiVIVA7o00001Oooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00CoooooaOmoOgl2o`0003?oIVIV0ol00007ogmoO`Co00001omoOglPo`00013oOgmo1_oo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CoooooaomoOgl2o`0003CoIVIV3?l0000b
ogmoO`Go00001Oooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00CooooobOmoOgl00ol0
003oIVIVofIVIP0NofIVIPGo00006_mVIVH6o`00023oOgmo3?l00004ofIVIPKooooo0Ol00001oooo
o`006_ooool00ol0003oooooooooo`04oooool[oOgmo0ol0000MofIVIP03o`000?m<C4coC4a<00;o
C4a<1_l0000JofIVIR3o00004?mVIVH6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool0
1?ooooo=ogmoO`?o00006OmVIVH00ol0003oC4a<oda<C009oda<C0go0000?OmVIVH6ooooo`7o0000
0Oooool001[ooooo00?o0000ooooooooool01?ooooo@ogmoO`;o00005_mVIVH00ol0003oC4a<oda<
C00Goda<C0Oo0000;?mVIVH;o`0000Gooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
oooookGoOgmo1_l0000GogmoO`?o00004omVIVH00ol0003oC4a<oda<C00Noda<C2co00002_m<C4`6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooncogmoO`;o00001_nIVIT6o`00
01CoOgmo0_l0000@ofIVIP?o0000EOm<C4`6ooooo`7o00000Oooool001[ooooo0_l00005oooookCo
Ogmo00?o0000oiVIVOnIVIT02_nIVIT2o`0001CoOgmo0_l0000AofIVIP;o0000Dom<C4`5ooooo`;o
00000Oooool001[ooooo00?o0000ooooooooool01?ooooneogmoO`03o`000?nIVIWoVIVI00_oVIVI
0ol0000CogmoO`;o00004OmVIVH3o`00053oC4a<1_ooool1o`00007ooooo000Jooooo`03o`000?oo
oooooooo00Cooooo]_moOgl00ol0003oVIVIoiVIV@0=oiVIV@?o00004_moOgl2o`0001;oIVIV0_l0
001>oda<C0Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooookOoOgmo00?o0000
oiVIVOnIVIT03onIVIT5o`0000ooOgmo0ol0000AofIVIP?o0000Bom<C4`6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?oooonhogmoO`03o`000?nIVIWoVIVI01?oVIVI1?l0000>ogmo
O`?o00004OmVIVH3o`0004SoC4a<1_ooool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Co
oooo^OmoOgl00ol0003oVIVIoiVIV@0FoiVIV@;o00003omoOgl4o`00013oIVIV0ol00015oda<C0Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooook[oOgmo0ol0000GoiVIV@?o0000
4?moOgl3o`00013oIVIV1?l00011oda<C0Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04oooookgoOgmo0_l0000HoiVIV@?o00004?moOgl3o`00017oIVIV1?l0000joda<C0Co00001Ooo
ool1o`00007ooooo000Jooooo`03o`000?oooooooooo00Cooooo_omoOgl00ol0003oVIVIoiVIV@0H
oiVIV@?o00004?moOgl3o`0001;oIVIV1ol0000/oda<C0Oo00000omVIVH6ooooo`7o00000Oooool0
01[ooooo00?o0000ooooooooool01?ooooo0ogmoO`03o`000?nIVIWoVIVI01[oVIVI2Ol0000:ogmo
O`Co00005OmVIVH=o`0001;oC4a<3Ol0000:ofIVIPKooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04oooool7oOgmo00?o0000oiVIVOnIVIT08_nIVIT2o`0000coOgmo0ol0000OofIVIQ;o
00005omVIVH6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?ooooo2ogmoO`03o`00
0?nIVIWoVIVI02?oVIVI0_l0000=ogmoO`Go0000@omVIVH6ooooo`7o00000Oooool001[ooooo00?o
0000ooooooooool01?ooooo3ogmoO`?o00009?nIVIT3o`0000ooOgmo3Ol0000/ofIVIP_o00001Ooo
ool1o`00007ooooo000Jooooo`;o00001Oooooo6ogmoO`;o00009OnIVIT3o`0001WoOgmo1_l0000P
ofIVIPKo00002_moOgl5ooooo`;o00000Oooool001[ooooo00?o0000ooooooooool01?ooooo8ogmo
O`;o00009_nIVIT5o`0001[oOgmo8?l0000@ogmoO`Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04oooool[oOgmo0_l0000YoiVIV@Go0000@omoOgl3o`0000Gooooo0Ol00001ooooo`00
6_ooool00ol0003oooooooooo`04ooooolcoOgmo00?o0000oiVIVOnIVIT0:onIVIT3o`0003goOgmo
0ol00002oiVIV@Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooolgoOgmo0_l0
000^oiVIV@co0000;?moOgl5o`0000GoVIVI1_ooool1o`00007ooooo000Jooooo`03o`000?oooooo
oooo00CooooocomoOgl00ol0003oVIVIoiVIV@0goiVIV@Ko00008?moOgl6o`0000[oVIVI1_ooool1
o`00007ooooo000Jooooo`03o`000?oooooooooo00Coooood?moOgl2o`0003goVIVI8?l0000@oiVI
V@Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooom;oOgmo0_l0001[oiVIV@Ko
oooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04ooooomCoOgmo00?o0000oiVIVOnIVIT0
J?nIVIT6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooEogmoO`;o0000J?nI
VIT6ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooGogmoO`?o0000IOnIVIT6
ooooo`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooJogmoO`?o0000H_nIVIT6oooo
o`7o00000Oooool001[ooooo00?o0000ooooooooool01?oooooMogmoO`Co0000G_nIVIT6ooooo`7o
00000Oooool001[ooooo0_l00005ooooon7oOgmo0ol0001KoiVIV@Gooooo0_l00001ooooo`006_oo
ool00ol0003oooooooooo`04ooooonCoOgmo0_l0001IoiVIV@Kooooo0Ol00001ooooo`006_ooool0
0ol0003oooooooooo`04ooooonKoOgmo0_l0001GoiVIV@Kooooo0Ol00001ooooo`006_ooool00ol0
003oooooooooo`04ooooonSoOgmo0_l0001EoiVIV@Kooooo0Ol00001ooooo`006_ooool00ol0003o
ooooooooo`04ooooon[oOgmo0ol0001BoiVIV@Kooooo0Ol00001ooooo`006_ooool00ol0003ooooo
ooooo`04ooooongoOgmo0ol0001?oiVIV@Kooooo0Ol00001ooooo`006_ooool00ol0003ooooooooo
o`04oooooo3oOgmo1_l00019oiVIV@Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04
ooooooKoOgmo1?l00015oiVIV@Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooo
oo[oOgmo0ol00012oiVIV@Kooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`04oooooogo
Ogmo1Ol0000joiVIV@Co00001Oooool1o`00007ooooo0009ooooo`;o000000Wo410@oooooooooooo
ooooonk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`04ooooooooOgmo0omoOgl7
o`0002coVIVI1ol00003ogmoO`Kooooo0Ol00001ooooo`002_ooool00ol0003oooooooooo`02oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`04ooooooooOgmo2_moOgl6
o`00023oVIVI1_l0000:ogmoO`Kooooo0Ol00001ooooo`001oooool5o`0000?ooooo00Go410@oooo
oooooooooooooa0@4006ooooo`?o00001?ooooooogmoOa3oOgmo3Ol00008oiVIV@_o00004?moOgl4
ooooo`?o00000Oooool000Oooooo00CoA4A4omgMgOoooooo00001?ooool01Ol0003ooooooooooooo
oooo000000Kooooo00?o0000ooooooooool0oooooom:ooooo`7o00000Oooool000Oooooo00CogMgM
oeEEEOoooooo00001?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0
oooooom:ooooo`7o00000Oooool000Sooooo00?oMgMgolc<c?l000001?ooool01Ol@413ooooooooo
oooooooo410@00Kooooo00?o0000ooooooooool0oooooom:ooooo`7o00000Oooool000Sooooo00?o
k^k^odA4A?l000001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0
oooooom:ooooo`7o00000Oooool000Wooooo00?oMgMgo`000?ooool00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Kooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0mooooo`03o`00
0?oooooooooo03gooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0mooooo`03o`00
0?oooooooooo02?ooooo0Ol00001ooooo`006_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00Wooooo0Ol00001ooooo`006_ooooooo`0004ko00000Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-30.1723, -14.304, 0.195672, \
0.195672}}]
}, Closed]],

Cell["\<\
Fig. 5.3 (animation) Gaussian wave packet  in deep water, moving \
across a current. [See Exercise (26).]\
\>", "Caption",
  CellTags->"Fig. 5.3"]
}, Closed]],

Cell[CellGroupData[{

Cell["Heat Equation", "Section",
  CellTags->"c:17"],

Cell[CellGroupData[{

Cell["General Solution", "Subsubsection"],

Cell[TextData[{
  "Consider the heat equation for the evolution of the temperature ",
  Cell[BoxData[
      FormBox[
        RowBox[{"T", "(", 
          RowBox[{
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[",",
              FontWeight->"Plain"], 
            StyleBox["t",
              FontWeight->"Plain"]}], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  " in an isotropic homogeneous material:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(\[PartialD]\/\[PartialD]t\), 
            RowBox[{"T", "(", 
              RowBox[{
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox[",",
                  FontWeight->"Plain"], 
                StyleBox["t",
                  FontWeight->"Plain"]}], 
              StyleBox[")",
                FontWeight->"Plain"]}]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{
            RowBox[{
              StyleBox["\[Chi]",
                FontWeight->"Plain"], 
              RowBox[{\(\[Del]\^2\), 
                RowBox[{"T", "(", 
                  RowBox[{
                    StyleBox["r",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], 
                    StyleBox[",",
                      FontWeight->"Plain"], 
                    StyleBox["t",
                      FontWeight->"Plain"]}], 
                  StyleBox[")",
                    FontWeight->"Plain"]}]}]}], 
            StyleBox["+",
              FontWeight->"Plain"], 
            RowBox[{
              StyleBox["S",
                FontWeight->"Plain"], 
              StyleBox["(",
                FontWeight->"Plain"], 
              RowBox[{
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox[",",
                  FontWeight->"Plain"], 
                StyleBox["t",
                  FontWeight->"Plain"]}], 
              StyleBox[")",
                FontWeight->"Plain"]}]}]}], TraditionalForm]]],
  "."
}], "NumberedEquation",
  CellTags->"(5.1.91)"],

Cell[TextData[{
  "This equation is supplemented by an initial condition, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"T", "(", 
            RowBox[{
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[",",
                FontWeight->"Plain"], 
              StyleBox["t",
                FontWeight->"Plain"]}], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{
            StyleBox[\(T\_o\),
              FontWeight->"Plain"], 
            StyleBox["(",
              FontWeight->"Plain"], 
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[")",
              FontWeight->"Plain"]}]}], TraditionalForm]]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tWe can solve Eq. ",
  ButtonBox["(5.1.91)",
    ButtonData:>"(5.1.91)",
    ButtonStyle->"Hyperlink"],
  " using Fourier transforms. Applying spatial Fourier transforms in ",
  Cell[BoxData[
      \(TraditionalForm\`x, y, \)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  ", Eq. ",
  ButtonBox["(5.1.91)",
    ButtonData:>"(5.1.91)",
    ButtonStyle->"Hyperlink"],
  " becomes the following ODE  for the Fourier-transformed temperature ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(T\&~\), "(", 
          RowBox[{
            StyleBox["k",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[",",
              FontWeight->"Plain"], 
            StyleBox["t",
              FontWeight->"Plain"]}], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  ":"
}], "Text",
  CellTags->"i:60"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(\[PartialD]\/\[PartialD]t\), 
            RowBox[{\(T\&~\), "(", 
              RowBox[{
                StyleBox["k",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox[",",
                  FontWeight->"Plain"], 
                StyleBox["t",
                  FontWeight->"Plain"]}], 
              StyleBox[")",
                FontWeight->"Plain"]}]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{
            RowBox[{
              RowBox[{"-", 
                StyleBox["\[Chi]",
                  FontWeight->"Plain"]}], 
              StyleBox[" ",
                FontWeight->"Plain"], 
              StyleBox[\(k\^2\),
                FontWeight->"Plain"], 
              StyleBox[" ",
                FontWeight->"Plain"], 
              RowBox[{\(T\&~\), "(", 
                RowBox[{
                  StyleBox["k",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], 
                  StyleBox[",",
                    FontWeight->"Plain"], 
                  StyleBox["t",
                    FontWeight->"Plain"]}], 
                StyleBox[")",
                  FontWeight->"Plain"]}]}], 
            StyleBox["+",
              FontWeight->"Plain"], 
            RowBox[{\(S\&~\), "(", 
              RowBox[{
                StyleBox["k",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox[",",
                  FontWeight->"Plain"], 
                StyleBox["t",
                  FontWeight->"Plain"]}], 
              StyleBox[")",
                FontWeight->"Plain"]}]}]}], TraditionalForm]]],
  ","
}], "Text"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(S\&~\), "(", 
          RowBox[{
            StyleBox["k",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[",",
              FontWeight->"Plain"], 
            StyleBox["t",
              FontWeight->"Plain"]}], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  " is the spatial Fourier transform of ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["S",
            FontWeight->"Plain"], 
          StyleBox["(",
            FontWeight->"Plain"], 
          RowBox[{
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[",",
              FontWeight->"Plain"], 
            StyleBox["t",
              FontWeight->"Plain"]}], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  ". This inhomogeneous first",
  "-order",
  " ODE has the general solution"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(T\&~\), "(", 
            RowBox[{
              StyleBox["k",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[",",
                FontWeight->"Plain"], 
              StyleBox["t",
                FontWeight->"Plain"]}], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{
            RowBox[{
              RowBox[{
                StyleBox["A",
                  FontWeight->"Plain"], 
                StyleBox["(",
                  FontWeight->"Plain"], 
                StyleBox["k",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox[")",
                  FontWeight->"Plain"]}], 
              StyleBox[" ",
                FontWeight->"Plain"], 
              StyleBox[\(\[ExponentialE]\^\(\(-\[Chi]\)\ \(k\^2\) t\)\),
                FontWeight->"Plain"]}], 
            StyleBox["+",
              FontWeight->"Plain"], 
            StyleBox[" ",
              FontWeight->"Plain"], 
            RowBox[{\(\[Integral]\_0\%t\), 
              
              RowBox[{\(\[ExponentialE]\^\(\(-\[Chi]\)\ \(\(k\^2\)(
                        t - t\&_)\)\)\), 
                RowBox[{\(S\&~\), "(", 
                  RowBox[{
                    StyleBox["k",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], 
                    StyleBox[",",
                      FontWeight->"Plain"], 
                    StyleBox[
                      OverscriptBox[
                        StyleBox["t",
                          FontWeight->"Plain"], "_"],
                      FontWeight->"Plain"]}], 
                  StyleBox[")",
                    FontWeight->"Plain"]}], \(\[DifferentialD]t\&_\)}]}]}]}], 
        TraditionalForm]]],
  "."
}], "NumberedEquation",
  CellTags->"(5.1.92)"],

Cell[TextData[{
  "The coefficient ",
  Cell[BoxData[
      FormBox[
        RowBox[{"A", "(", 
          StyleBox["k",
            FontWeight->"Bold",
            FontSlant->"Plain"], ")"}], TraditionalForm]]],
  " is determined by the initial condition, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(T\&~\), "(", 
            RowBox[{
              StyleBox["k",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[",",
                FontWeight->"Plain"], 
              StyleBox["0",
                FontWeight->"Plain"]}], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{
            StyleBox[\(T\&~\_o\),
              FontWeight->"Plain"], "(", 
            StyleBox["k",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[")",
              FontWeight->"Plain"]}]}], TraditionalForm]]],
  ".  This implies that ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["A",
              FontWeight->"Plain"], 
            StyleBox["(",
              FontWeight->"Plain"], 
            StyleBox["k",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{
            StyleBox[\(T\&~\_o\),
              FontWeight->"Plain"], "(", 
            StyleBox["k",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[")",
              FontWeight->"Plain"]}]}], TraditionalForm]]],
  ". Taking the inverse Fourier transform of Eq. ",
  ButtonBox["(5.1.92)",
    ButtonData:>"(5.1.92)",
    ButtonStyle->"Hyperlink"],
  " then yields the solution,"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"T", "(", 
            RowBox[{
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[",",
                FontWeight->"Plain"], 
              StyleBox["t",
                FontWeight->"Plain"]}], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox[" ",
            FontWeight->"Plain"], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox[" ",
            FontWeight->"Plain"], 
          RowBox[{"\[Integral]", 
            RowBox[{\(\[DifferentialD]\^3 k\/\((2  \[Pi])\)\^3\), 
              SuperscriptBox["\[ExponentialE]", 
                RowBox[{
                  RowBox[{"\[ImaginaryI]", " ", 
                    RowBox[{
                      StyleBox["k",
                        FontWeight->"Bold",
                        FontSlant->"Plain"], "\[CenterDot]", 
                      StyleBox["r",
                        FontWeight->"Bold",
                        FontSlant->"Plain"]}]}], 
                  "-", \(\[Chi]\ \(k\^2\) t\)}]], " ", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{\(T\&~\_o\), "(", 
                    StyleBox["k",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], 
                    StyleBox[")",
                      FontWeight->"Plain"]}], 
                  StyleBox["+",
                    FontWeight->"Plain"], 
                  StyleBox[" ",
                    FontWeight->"Plain"], 
                  RowBox[{
                    StyleBox[\(\[Integral]\_0\%t\),
                      FontWeight->"Plain"], 
                    RowBox[{
                      
                      StyleBox[\(\[ExponentialE]\^\(\[Chi]\ \(k\^2\) t\&_\)\),
                        
                        FontWeight->"Plain"], 
                      RowBox[{
                        StyleBox[\(S\&~\),
                          FontWeight->"Plain"], 
                        StyleBox["(",
                          FontWeight->"Plain"], 
                        RowBox[{
                          StyleBox["k",
                            FontWeight->"Bold",
                            FontSlant->"Plain"], 
                          StyleBox[",",
                            FontWeight->"Plain"], 
                          StyleBox[\(t\&_\),
                            FontWeight->"Plain"]}], 
                        StyleBox[")",
                          FontWeight->"Plain"]}], 
                      StyleBox[\(\[DifferentialD]t\&_\),
                        FontWeight->"Plain"]}]}]}], 
                StyleBox[")",
                  FontWeight->"Plain"]}]}]}]}], TraditionalForm]]],
  "."
}], "NumberedEquation",
  CellTags->"(5.1.93)"],

Cell[TextData[{
  "The exponential that appears in this solution, ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox["\[ExponentialE]", 
          RowBox[{
            RowBox[{"\[ImaginaryI]", " ", 
              RowBox[{
                StyleBox["k",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "\[CenterDot]", 
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"]}]}], "-", \(\[Chi]\ \(k\^2\) t\)}]], 
        TraditionalForm]]],
  ", looks something like the traveling waves ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox["\[ExponentialE]", 
          RowBox[{"\[ImaginaryI]", "(", " ", 
            RowBox[{
              RowBox[{
                StyleBox["k",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "\[CenterDot]", 
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"]}], "-", \(\(\[Omega](k)\)\ t\)}], 
            ")"}]], TraditionalForm]]],
  "that appear in the solutions of the wave and Schr\[ODoubleDot]dinger \
equations. In fact, by comparing with that form for traveling waves, we can \
identify a dispersion relation:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Omega](
          k) = \ \(-\[ImaginaryI]\)\ \[Chi]\ k\^2\)]],
  ". "
}], "NumberedEquation",
  CellTags->"(5.1.94)"],

Cell["\<\
The \"frequency \" of these temperature waves is imaginary, \
indicating that the waves do not propagate, but rather decay with time. \
\
\>", "Text",
  CellTags->"i:44"],

Cell[TextData[{
  "\tIt is often the case that dispersion relations yield ",
  StyleBox["complex",
    FontSlant->"Italic"],
  " frequencies. Waves on a real string damp as they propagate due to a \
variety of effects, and a mathematical description of the motion leads to a \
dispersion relation  with complex frequencies.  Only the real part of the \
frequency describes propagation. Thus, for damped waves, the phase velocity \
is defined as "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox[
            StyleBox["v",
              FontWeight->"Bold",
              FontSlant->"Plain"], "\[Phi]"], "=", 
          RowBox[{\(Re[\[Omega]]\), "   ", 
            RowBox[{
              StyleBox[
                OverscriptBox[
                  StyleBox["k",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "^"],
                FontWeight->"Bold"], "/", "k"}]}]}], TraditionalForm]]],
  ","
}], "NumberedEquation",
  CellTags->{"i:43", "(5.1.95)"}],

Cell["and the group velocity is", "Text",
  CellTags->"i:42"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox[
            StyleBox["v",
              FontWeight->"Bold",
              FontSlant->"Plain"], "g"], "=", 
          RowBox[{
            FractionBox["\[PartialD]", 
              RowBox[{"\[PartialD]", 
                StyleBox["k",
                  FontWeight->"Bold",
                  FontSlant->"Plain"]}]], \(Re[\[Omega]]\)}]}], 
        TraditionalForm]]],
  "."
}], "NumberedEquation",
  CellTags->"(5.1.96)"],

Cell[TextData[{
  "\tFor the heat equation, however, the waves do not propagate at all; the \
phase and group velocities are zero.  However, this does not mean that heat \
does not propagate through a material. Rather, it merely implies that heat \
does not propagate like a wave, with constant phase and group velocities. \
Rather, heat ",
  StyleBox["diffuses",
    FontSlant->"Italic"],
  " through a material. This diffusion is described by the general solution \
to the heat equation, Eq. ",
  ButtonBox["(5.1.93)",
    ButtonData:>"(5.1.93)",
    ButtonStyle->"Hyperlink"],
  ". To understand this diffusion, it suffices to consider an example."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Green's Function for the Heat Equation", "Subsubsection",
  CellTags->"i:41"],

Cell[TextData[{
  "Let us take as an example a system that is initially at zero temperature, \
",
  Cell[BoxData[
      \(TraditionalForm\`T\_o = 0\)]],
  ", and that is subjected to a ",
  Cell[BoxData[
      \(TraditionalForm\`\[Delta]\)]],
  "-function heat source at time ",
  Cell[BoxData[
      \(TraditionalForm\`t\_o\)]],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"S", "(", 
            RowBox[{
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[",",
                FontWeight->"Plain"], 
              StyleBox["t",
                FontWeight->"Plain"]}], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{
            RowBox[{
              StyleBox["\[Delta]",
                FontWeight->"Plain"], 
              StyleBox["(",
                FontWeight->"Plain"], 
              RowBox[{
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox["-",
                  FontWeight->"Plain"], 
                StyleBox[
                  SubscriptBox[
                    StyleBox["r",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], "o"],
                  FontWeight->"Plain"]}], 
              StyleBox[")",
                FontWeight->"Plain"]}], 
            StyleBox[\(\[Delta](t - t\_o)\),
              FontWeight->"Plain"]}]}], TraditionalForm]]],
  "."
}], "NumberedEquation",
  CellTags->"(5.1.97)"],

Cell[TextData[{
  "The evolution of the temperature  resulting from this heat pulse is given \
by Eq. ",
  ButtonBox["(5.1.93)",
    ButtonData:>"(5.1.93)",
    ButtonStyle->"Hyperlink"],
  ". The initial condition ",
  Cell[BoxData[
      \(TraditionalForm\`T\_o = 0\)]],
  " implies that ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(T\&~\_o\), "(", 
            StyleBox["k",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox["0",
            FontWeight->"Plain"]}], TraditionalForm]]],
  ", and Eq, ",
  ButtonBox["(5.1.97)",
    ButtonData:>"(5.1.97)",
    ButtonStyle->"Hyperlink"],
  " implies that ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox[\(S\&~\),
              FontWeight->"Plain"], 
            StyleBox["(",
              FontWeight->"Plain"], 
            RowBox[{
              StyleBox["k",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[",",
                FontWeight->"Plain"], 
              StyleBox[\(t\&_\),
                FontWeight->"Plain"]}], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox[
            RowBox[{
              SuperscriptBox["\[ExponentialE]", 
                RowBox[{\(-\[ImaginaryI]\), " ", 
                  RowBox[{
                    StyleBox["k",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], "\[CenterDot]", 
                    StyleBox[\(r\_o\),
                      FontWeight->"Bold"]}]}]], \(\[Delta](t\&_ - t\_o)\)}],
            FontWeight->"Plain"]}], TraditionalForm]]],
  " . Applying these results to Eq. ",
  ButtonBox["(5.1.93)",
    ButtonData:>"(5.1.93)",
    ButtonStyle->"Hyperlink"],
  " and performing the integrationl over ",
  Cell[BoxData[
      \(TraditionalForm\`t\&_\)]],
  " yields"
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"T", "(", 
            RowBox[{
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[",",
                FontWeight->"Plain"], 
              StyleBox["t",
                FontWeight->"Plain"]}], 
            StyleBox[")",
              FontWeight->"Plain"]}], "=", 
          TagBox[
            RowBox[{
              StyleBox["{",
                ShowAutoStyles->False,
                FontSize->18], 
              StyleBox[GridBox[{
                    {
                      RowBox[{
                        RowBox[{
                          StyleBox["\[Integral]",
                            FontSize->7], 
                          
                          RowBox[{\(\[DifferentialD]\^3 
                                  k\/\((2  \[Pi])\)\^3\), 
                            SuperscriptBox["\[ExponentialE]", 
                              RowBox[{
                                RowBox[{"\[ImaginaryI]", " ", 
                                  RowBox[{
                                    StyleBox["k",
                                      FontWeight->"Bold",
                                      FontSlant->"Plain"], "\[CenterDot]", 
                                    RowBox[{"(", 
                                      RowBox[{
                                        StyleBox["r",
                                        FontWeight->"Bold",
                                        FontSlant->"Plain"], "-", 
                                        SubscriptBox[
                                        StyleBox["r",
                                        FontWeight->"Bold",
                                        FontSlant->"Plain"], "o"]}], 
                                      ")"}]}]}], " ", 
                                "-", \(\[Chi]\ \(\(k\^2\)(
                                    t - t\_o)\)\)}]]}]}], ",", 
                        "  ", \(t > t\_o\), ","}]},
                    {
                      
                      StyleBox[\(0, \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ t \
< \(\(t\_o\)\(.\)\)\),
                        ShowAutoStyles->True]}
                    },
                  RowSpacings->2],
                ShowAutoStyles->True]}],
            (#&)]}], TraditionalForm]]]
}], "Text",
  GridBoxOptions->{ColumnSpacings->0.3,
  ColumnAlignments->{Right, Left}}],

Cell[TextData[{
  "The integral can be evaluated in the usual way, by writing ",
  Cell[BoxData[
      FormBox[
        StyleBox["k",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " in spherical coordinates with the ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  " axis chosen in the direction of ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], "-", 
          SubscriptBox[
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], "o"]}], TraditionalForm]]],
  ". Then ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          RowBox[{
            RowBox[{
              RowBox[{
                StyleBox["k",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "\[CenterDot]", 
                RowBox[{"(", 
                  RowBox[{
                    StyleBox["r",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], "-", 
                    SubscriptBox[
                      StyleBox["r",
                        FontWeight->"Bold",
                        FontSlant->"Plain"], "o"]}], ")"}]}], 
              "=", \(k\ \[CapitalDelta]r\ cos\ \[Theta]\)}], ","}]}], 
        TraditionalForm]]],
  " where ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalDelta]r", "=", 
          RowBox[{"|", 
            RowBox[{
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], "-", 
              SubscriptBox[
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "o"]}], "|"}]}], TraditionalForm]]],
  ", and  ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]\^3 
          k = \(k\^2\) \[DifferentialD]k\ sin\[Theta]\ \[DifferentialD]\
\[Theta]\ \[DifferentialD]\ \[Phi]\)]],
  ". The ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Theta]\)\(\ \)\)\)]],
  "and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " integrals then yield  "
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"T", "(", 
            RowBox[{
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[",",
                FontWeight->"Plain"], 
              StyleBox["t",
                FontWeight->"Plain"]}], 
            StyleBox[")",
              FontWeight->"Plain"]}], "=", 
          TagBox[
            RowBox[{
              StyleBox["{",
                ShowAutoStyles->False,
                FontSize->18], 
              StyleBox[GridBox[{
                    {
                      RowBox[{
                        RowBox[{
                          SubsuperscriptBox[
                            StyleBox["\[Integral]",
                              FontSize->9], "0", 
                            "\[Infinity]"], \(\(\(k\ \
\[DifferentialD]k\)\/\((2  \[Pi])\)\^2\) 
                            2 \( sin(k\ \[CapitalDelta]r)\)\/\[CapitalDelta]r\
\ \ \[ExponentialE]\^\(\(\ \)\(\(-\[Chi]\)\ \(\(k\^2\)(t - t\_o)\)\)\)\)}], 
                        ",", "  ", \(t > t\_o\), ","}]},
                    {
                      
                      StyleBox[\(0, \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ t < \(\(t\_o\)\(.\)\)\),
                        ShowAutoStyles->True]}
                    },
                  RowSpacings->2],
                ShowAutoStyles->True]}],
            (#&)]}], TraditionalForm]]]
}], "Text",
  GridBoxOptions->{ColumnSpacings->0.3,
  ColumnAlignments->{Right, Left}}],

Cell[TextData[{
  "The ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  "-integral can also be evaluated analytically:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(FullSimplify[
      Integrate[
          2\ Exp[\(-\[Chi]\)\ \(k\^2\) \((t - 
                    t\_o)\)] \(\(\ \)\(Sin[k\ \[CapitalDelta]r]\)\)\/\
\[CapitalDelta]r\ k, {k, 0, Infinity}]/\((2\ Pi)\)\^2, \[CapitalDelta]r > 
          0\  && \ \[Chi] \((t - t\_o)\) > 0]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 5.11"],

Cell[BoxData[
    \(\(\(\[ExponentialE]\^\(\[CapitalDelta]r\^2\/\(\(-4\)\ t\ \[Chi] + 4\ \
\[Chi]\ t\_o\)\)\)\(\ \)\)\/\(8\ \[Pi]\^\(3/2\)\ \((\[Chi]\ \((t - t\_o)\))\)\
\^\(3/2\)\)\)], "Output"]
}, Open  ]],

Cell["Thus, we find that the temperature pulse is described by", "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{" ", 
        RowBox[{GridBox[{
              {
                RowBox[{
                  RowBox[{"T", "(", 
                    RowBox[{
                      StyleBox["r",
                        FontWeight->"Bold",
                        FontSlant->"Plain"], 
                      StyleBox[",",
                        FontWeight->"Plain"], 
                      StyleBox["t",
                        FontWeight->"Plain"]}], 
                    StyleBox[")",
                      FontWeight->"Plain"]}], 
                  StyleBox[" ",
                    FontWeight->"Plain"]}], 
                RowBox[{
                  StyleBox["=",
                    
                    FontWeight->
                      "Plain"], \(\(\(h(
                          t - t\_o)\)\/\(8\ \[Pi]\^\(3/2\)\ \((\[Chi]\ \((t - \
t\_o)\))\)\^\(3/2\)\)\) \(\[ExponentialE]\^\(-\ \(\[CapitalDelta]r\^\(\(\ \
\)\(2\)\)\/\(4\ \[Chi]\ \((t\  - \ t\_o)\)\)\)\)\)\(\ \)\)}]}
              }], ",", " "}]}], TraditionalForm]]]], "NumberedEquation",
  GridBoxOptions->{ColumnSpacings->0.3,
  ColumnAlignments->{Right, Left}},
  CellTags->"(5.1.98)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`h\)]],
  " is a Heaviside step function. This is a Gaussian pulse that spreads in \
time. Initially the width of the pulse is zero because it begins as a \
\[Delta]-function. In fact, Eq. ",
  ButtonBox["(5.1.98)",
    ButtonData:>"(5.1.98)",
    ButtonStyle->"Hyperlink"],
  " can be regarded as a Green's function for the heat equation."
}], "Text"],

Cell[TextData[{
  "\t The evolution from any source ",
  Cell[BoxData[
      FormBox[
        RowBox[{"S", "(", 
          RowBox[{
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[",",
              FontWeight->"Plain"], 
            StyleBox["t",
              FontWeight->"Plain"]}], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  " can be written as"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"T", "(", 
            RowBox[{
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[",",
                FontWeight->"Plain"], 
              StyleBox["t",
                FontWeight->"Plain"]}], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox[" ",
            FontWeight->"Plain"], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox[" ",
            FontWeight->"Plain"]}], TraditionalForm]]],
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Integral]", 
          
          RowBox[{\(\[DifferentialD]\^3 r\_o\), \
\(\[DifferentialD]t\_\(\(o\)\(\ \)\)\), 
            RowBox[{"g", "(", 
              RowBox[{
                RowBox[{
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], " ", "-", 
                  StyleBox[
                    SubscriptBox[
                      StyleBox["r",
                        FontSlant->"Plain"], 
                      StyleBox["o",
                        FontWeight->"Plain"]],
                    FontWeight->"Bold"]}], ",", \(t - t\_o\)}], ")"}], " ", 
            RowBox[{"S", "(", 
              RowBox[{
                StyleBox[
                  SubscriptBox[
                    StyleBox["r",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], 
                    StyleBox["o",
                      FontWeight->"Plain"]],
                  FontWeight->"Bold"], 
                StyleBox[",",
                  FontWeight->"Plain"], 
                StyleBox[\(t\_o\),
                  FontWeight->"Plain"]}], ")"}]}]}], TraditionalForm]]],
  ","
}], "NumberedEquation",
  CellTags->"(5.1.99)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`g\)]],
  " is  given by Eq. ",
  ButtonBox["(5.1.98)",
    ButtonData:>"(5.1.98)",
    ButtonStyle->"Hyperlink"],
  ". The proof of this equation is left as an exercise.  However, this is \
easy to understand physically. Breaking the source ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  " into a collection of  delta function sources at different positions and \
times, the resulting temperature is a superposition of the responses to all \
of them. Of course, Eq. ",
  ButtonBox["(5.1.99)",
    ButtonData:>"(5.1.99)",
    ButtonStyle->"Hyperlink"],
  " is only a particular solution because it does not necessarily satisfy the \
initial conditions. "
}], "Text"],

Cell[TextData[{
  "\t The width ",
  Cell[BoxData[
      \(TraditionalForm\`w\)]],
  " of the Gaussian heat pulse given by Eq. ",
  ButtonBox["(5.1.98)",
    ButtonData:>"(5.1.98)",
    ButtonStyle->"Hyperlink"],
  ", defined in the same manner as in Eq. ",
  ButtonBox["(5.1.31)",
    ButtonData:>"(5.1.31)",
    ButtonStyle->"Hyperlink"],
  ",  increases with time according to"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`w = \@\(\(2\)  \(\[Chi]\)\(\ \)\((t\  - \ t\_o)\)\(\ \
\)\)\)]],
  ",   ",
  Cell[BoxData[
      \(TraditionalForm\`t > t\_o\)]],
  "."
}], "NumberedEquation",
  CellTags->"(5.1.100)"],

Cell[TextData[{
  "Thus, the heat pulse does not propagate outward with a constant speed as \
in the wave equation. Rather, the pulse width increases as the square root of \
time. This is a signature of diffusion, a subject to which we will return in \
Chapter ",
  ButtonBox["8",
    ButtonData:>{"Chapter8.nb", None},
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Exercises for Sec. 5.1", "Subsubtitle",
  CellTags->"c:18"],

Cell[TextData[{
  StyleBox["(1)",
    FontWeight->"Bold"],
  " Using Fourier transforms, find the solution of the 1D wave equation in an \
infinite system with ",
  Cell[BoxData[
      \(TraditionalForm\`c = 1\)]],
  ", for the following initial conditions. Animate the solution for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 2\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  Cell[BoxData[
      FormBox[
        RowBox[{" ", Cell[TextData[Cell[BoxData[
              \(TraditionalForm\`\(\[PartialD]y\/\[PartialD]t\) \((x, 
                    0)\)\  = 
                x\ \[ExponentialE]\^\(-\(\(|\)\(x\)\(|\)\)\)\)]]]]}], 
        TraditionalForm]]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`y(x, 0) = 0\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(y(x, 0) = h(x)\), ",", " ", Cell[TextData[Cell[BoxData[
              \(TraditionalForm\`\(\[PartialD]y\/\[PartialD]t\) \((x, 
                    0)\)\  = 0\)]]]], ",", " "}], TraditionalForm]]],
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`h(x)\)]],
  " is a Heaviside step function."
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`y(x, 0) = 0\)]],
  ", with boundary condition ",
  Cell[BoxData[
      \(TraditionalForm\`y(0, t) = t\ \ \[ExponentialE]\^\(-\ t\)\)]],
  ",  and initial condition that  ",
  Cell[BoxData[
      \(TraditionalForm\`y = 0\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`t < 0\)]],
  ". Solve for ",
  Cell[BoxData[
      \(TraditionalForm\`y(x, t)\)]],
  " on ",
  Cell[BoxData[
      \(TraditionalForm\`0 < x < \[Infinity]\)]],
  ". (Hint: Put the equation in standard form, and use a Fourier sine \
integral.)"
}], "Text"],

Cell[TextData[{
  StyleBox["(2)",
    FontWeight->"Bold"],
  " A quantum particle moving freely in one dimension has an initial wave \
packet given in ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  " space by ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(\(\[Psi]\&~\_o\)(k)\), "=", 
            RowBox[{"\[Pi]", "/", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["k",
                    FontSlant->"Italic"]}]]}]}], ",", " ", 
          RowBox[{"|", \(k - k\_o\), "|", 
            RowBox[{"\[LessEqual]", " ", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["k",
                    FontSlant->"Italic"]}]]}]}]}], TraditionalForm]]],
  ", and zero otherwise. Find the subsequent evolution of the wave packet. \
Animate the evolution of ",
  Cell[BoxData[
      \(TraditionalForm\`\((\(|\)\(\[Psi]\)\(|\))\)\^2\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`\[HBar] = \(m = 1\)\)]],
  "and ",
  Cell[BoxData[
      \(TraditionalForm\`k\_o = 5\)]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["k",
                FontSlant->"Italic"]}]], "=", \(1/2\)}], TraditionalForm]]],
  ", for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 4\)]],
  "."
}], "Text"],

Cell[TextData[{
  "How far does the center of the wave packet move in this time?  Compare the \
speed of the wave packet with the mean group velocity and the mean phase \
velocity, based on the central wavenumber ",
  Cell[BoxData[
      \(TraditionalForm\`k\_o\)]],
  ". Which velocity best fits the actual motion of the packet?"
}], "Text"],

Cell[TextData[{
  StyleBox["(3)",
    FontWeight->"Bold"],
  " Water waves in water of depth ",
  Cell[BoxData[
      \(TraditionalForm\`h\)]],
  " have a dispersion relation given by the equation ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\  = \@\(\(\ \)\(\(g\)\(\ \)\(k\)\(\ \
\)\(tanh\)\(\ \)\(k\)\(\ \)\(h\)\(\ \)\)\)\)]],
  ", where  ",
  Cell[BoxData[
      \(TraditionalForm\`g\)]],
  " is the acceleration of gravity, ",
  Cell[BoxData[
      FormBox[
        RowBox[{"g", " ", "=", " ", 
          RowBox[{"9.8", " ", 
            RowBox[{
              StyleBox["m",
                FontSlant->"Plain"], "/", 
              SuperscriptBox[
                StyleBox["s",
                  FontSlant->"Plain"], "2"]}]}]}], TraditionalForm]]],
  ". [See ",
  ButtonBox["Kundu (1990, pg.194)",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  ".] Plot the phase and group velocities of these waves, in ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(meters\ per\ second\)\(,\)\)\)]],
  " as a function of ",
  Cell[BoxData[
      \(TraditionalForm\`k\ h\)]],
  ". Show analytically that in the limit that ",
  Cell[BoxData[
      \(TraditionalForm\`k\ h >> 1\)]],
  "  (deep water waves) the phase velocity is twice the group velocity."
}], "Text",
  CellTags->"i:45"],

Cell[TextData[{
  StyleBox["(4)",
    FontWeight->"Bold"],
  " Water waves in deep water, including surface tension, have the following \
dispersion relation: ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\  = \@\(\(\ \)\(g\ k + \[Sigma]\ \
k\^3\)\)\)]],
  ", where \[Sigma] is the surface tension coefficient, equal to 71.4 ",
  Cell[BoxData[
      \(TraditionalForm\`cm\^3\)]],
  "/",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox[
            StyleBox["s",
              FontSlant->"Plain"], "2"], " "}], TraditionalForm]]],
  "for fresh water. [See ",
  ButtonBox["Kundu (1990, pg. 206)",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  ".]"
}], "Text",
  CellTags->"i:46"],

Cell[TextData[{
  StyleBox["(a) ",
    FontWeight->"Bold"],
  "Find the group and phase velocities for a wave packet with central \
wavenumber of magnitude  ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  ". Plot each as a function of ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  ".  Find the critical value of ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  " , ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(k\^*\)\(,\)\(\ \)\)\)]],
  "at which the phase and group velocities coincide. Waves with wavenumbers \
above ",
  Cell[BoxData[
      \(TraditionalForm\`\(k\^*\)\)]],
  "are dominated by surface tension; waves below ",
  Cell[BoxData[
      \(TraditionalForm\`\(k\^*\)\)]],
  " are gravity-dominated. "
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Show that ",
  Cell[BoxData[
      \(TraditionalForm\`\(k\^*\)\)]],
  " also corresponds to  a minimum possible  phase velocity as a function of \
",
  Cell[BoxData[
      \(TraditionalForm\`\(\(k\)\(,\)\)\)]],
  " and find its value in centimeters per second. As one moves a stick \
through water, the speed of the stick must be larger than this minimum phase \
velocity in order to excite waves, since the stick only excites waves which \
move at the same phase velocity.  (You can test this in your sink or \
bathtub.)"
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Using Eq. ",
  ButtonBox["(5.1.30)",
    ButtonData:>"(5.1.30)",
    ButtonStyle->"Hyperlink"],
  ", construct a 1D  Gaussian wave packet consisting of ripples traveling in \
the positive ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(x\)\(-\)\)\)]],
  "direction, with central wavenumber ",
  Cell[BoxData[
      \(TraditionalForm\`k\_0 = 5\ cm\^\(-1\)\)]],
  ", and initial shape in ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  "-space  ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(C(k)\), "=", 
          SuperscriptBox["\[ExponentialE]", 
            RowBox[{"-", 
              FractionBox[\(\((k - k\_o)\)\^2\), 
                RowBox[{"2", " ", 
                  SuperscriptBox[
                    StyleBox[
                      RowBox[{"\[CapitalDelta]", 
                        StyleBox["k",
                          FontSlant->"Italic"]}]], "2"]}]]}]]}], 
        TraditionalForm]]],
  " with ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["k",
                FontSlant->"Italic"]}]], "=", \(1\ cm\^\(-1\)\)}], 
        TraditionalForm]]],
  ". Keeping the effect of dispersion to the lowest possible nontrivial \
order, make a movie of the propagation of the real part of this wave packet \
for ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(0 < t < 1\)\)\)]],
  "s , in increments of 0.025 s, as seen in the lab frame. How many cm does \
the packet travel in 1 s? Compare the mean speed of the packet with the group \
and phase velocities at wavenumber ",
  Cell[BoxData[
      \(TraditionalForm\`k\_o\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(5)",
    FontWeight->"Bold"],
  " Find the solution to the heat equation with ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi] = 1\)]],
  " for the following initial conditions"
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(T(x, 
          0)\)\(\ \)\(=\)\(\[ExponentialE]\^\(-\(\(|\)\(x\)\(|\)\)\)\)\(\ \
\)\)\)]],
  ". Animate the solution on ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(-5\), "<", "x", "<", 
          RowBox[{"5", " ", "for", " ", 
            RowBox[{
              FormBox[\(0 < t < 2\),
                "TraditionalForm"], "."}]}]}], TraditionalForm]]]
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`T(x, 0)\  = \ h(x)\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`h(x)\)]],
  "is a Heaviside step function.  Animate the solution on ",
  Cell[BoxData[
      \(TraditionalForm\`\(-5\) < x < 5\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 2\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(6)",
    FontWeight->"Bold"],
  " The biharmonic wave equation,"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(\[PartialD]\^2\/\[PartialD]t\^2\) \(y(x, 
            t)\) = \(-\[Alpha]\) \(\[PartialD]\^4\/\[PartialD]x\^4\) \(y(x, 
            t)\)\)\(,\)\)\)]]
}], "Text"],

Cell[TextData[{
  "where \[Alpha] is a constant with units of ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SuperscriptBox[
            StyleBox["m",
              FontSlant->"Plain"], "4"], "/", 
          SuperscriptBox[
            StyleBox["s",
              FontSlant->"Plain"], "2"]}], TraditionalForm]]],
  ",  describes transverse waves on a long rod [see Eq. ",
  ButtonBox["(4.2.47)",
    ButtonData:>{"Chapter4.nb", "(4.2.47)"},
    ButtonStyle->"Hyperlink"],
  "]. "
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " What is the dispersion relation for waves on this rod?"
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Without making approximations, find the evolution of the following \
initial perturbation on the rod:"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`y(x, 
          0) = \(sin(
            10\ x/a)\)\ \[ExponentialE]\^\(\(-x\^2\)/a\^2\), \(\[PartialD]y\/\
\[PartialD]t\) \((x, 0)\) = 0\)]],
  "."
}], "Text"],

Cell[TextData[{
  "Animate the evolution, taking ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\  = \(a = \ 1\)\)]],
  ", for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 0.2\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(7)",
    FontWeight->"Bold"],
  " A laser beam of frequency ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Omega]\_o\)\(\ \)\)\)]],
  "and wavenumber ",
  Cell[BoxData[
      \(TraditionalForm\`k\_o\)]],
  "in the ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  "-direction is fired into a vacuum. The form of the beam is  ",
  Cell[BoxData[
      \(TraditionalForm\`p(r, z, 
          t) = \(\[ExponentialE]\^\(\[ImaginaryI]\ \((\(k\_o\) 
                      z - \(\[Omega]\_o\) t)\)\)\) \(\(p\_o\)(r)\)\)]],
  ".  Using the wave equation, show that  ",
  Cell[BoxData[
      \(TraditionalForm\`\(p\_o\)(r) = 
        A\ \(\(J\_o\)(\(k\_ \[UpTee] \) r)\)\)]],
  "provided that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_o > c\ k\_o\)]],
  ", and find ",
  Cell[BoxData[
      \(TraditionalForm\`\(k\_ \[UpTee] \)\)]],
  " . Note that, unlike a Gaussian wave packet, this beam does not spread as \
it propagates. This does not violate our expression for the Rayleigh length, \
because the Bessel function already has an effectively infinite transverse \
extent, falling off slowly with increasing ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  " . This type of beam is called a ",
  StyleBox["Bessel beam.",
    FontSlant->"Italic"]
}], "Text",
  CellTags->"i:47"],

Cell[TextData[{
  StyleBox["(8)",
    FontWeight->"Bold"],
  " The starship Enterprise fires its phaser at a Klingon warship ",
  Cell[BoxData[
      \(TraditionalForm\`10\^5\)]],
  "km away. Assuming that the beam is initially 1 m in radius and consists of \
electromagnetic waves that have a frequency centered in the visible (",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Lambda]", "=", 
          RowBox[{\(5\[Cross]10\^\(-7\)\), 
            StyleBox["m",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  "),  how wide is the beam  by the time it strikes the warship?"
}], "Text"],

Cell[TextData[{
  StyleBox["(9) ",
    FontWeight->"Bold"],
  "Prove Eqs. ",
  ButtonBox["(5.1.75)",
    ButtonData:>"(5.1.75)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(5.1.76)",
    ButtonData:>"(5.1.76)",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(10(a)",
    FontWeight->"Bold"],
  " Schr\[ODoubleDot]dinger's equation, ",
  Cell[BoxData[
      \(TraditionalForm\`\(-\[ImaginaryI]\)\ \[HBar]\ \[PartialD]\[Psi]/\
\[PartialD]t = \(-\(\[HBar]\^2\/\(2\ m\)\)\) \[Del]\^2 \[Psi] + 
          V\ \[Psi]\)]],
  ", does not fit the pattern of the classical wave equations described by \
Eq. ",
  ButtonBox["(5.1.63)",
    ButtonData:>"(5.1.63)",
    ButtonStyle->"Hyperlink"],
  ", because it has a first-order time derivative. Now the conserved density \
is the probability density ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho](r, t) = \((\(|\)\(\[Psi]\)\(|\))\)\^2\)]],
  ". Prove that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\)]],
  " satisfies a conservation law of the form of Eq. ",
  ButtonBox["(5.1.57)",
    ButtonData:>"(5.1.57)",
    ButtonStyle->"Hyperlink"],
  ", and find the form of the flux ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalGamma]\)]],
  ". Hint:  Multiply Schr\[ODoubleDot]dinger's equation by ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\^*\)\)]],
  ", then subtract the result from its complex conjugate."
}], "Text",
  CellTags->"i:48"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " By applying the results of part (a) to a wave packet  of the form ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Psi]", " ", "=", " ", 
          RowBox[{
            RowBox[{\(\[Psi]\_o\), "(", 
              RowBox[{
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox["-",
                  FontWeight->"Plain"], 
                StyleBox[
                  RowBox[{
                    SubscriptBox[
                      StyleBox["v",
                        FontWeight->"Bold",
                        FontSlant->"Plain"], "g"], " ", "t"}],
                  FontWeight->"Plain"]}], 
              StyleBox[")",
                FontWeight->"Plain"]}], 
            StyleBox[" ",
              FontWeight->"Plain"], 
            StyleBox[
              SuperscriptBox["\[ExponentialE]", 
                RowBox[{"\[ImaginaryI]", "(", " ", 
                  RowBox[{
                    RowBox[{
                      StyleBox["k",
                        FontWeight->"Bold",
                        FontSlant->"Plain"], "\[CenterDot]", 
                      StyleBox["r",
                        FontWeight->"Bold",
                        FontSlant->"Plain"]}], "-", \(\[Omega]\ t\)}], ")"}]],
              
              FontWeight->"Plain"]}]}], TraditionalForm]]],
  ", show that the flux of probability density is ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["\[CapitalGamma]",
            FontWeight->"Bold"], "=", 
          RowBox[{"\[Rho]", " ", "\[HBar]", " ", 
            RowBox[{
              StyleBox["k",
                FontWeight->"Bold",
                FontSlant->"Plain"], "/", "m", " "}]}]}], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(11)",
    FontWeight->"Bold"],
  " Schr\[ODoubleDot]dinger's equation is just one member of a class of wave \
equations with odd-order time derivatives, describing the evolution of a \
complex function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Psi]", "(", 
          RowBox[{
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[",",
              FontWeight->"Plain"], 
            StyleBox["t",
              FontWeight->"Plain"]}], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  ": "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[ImaginaryI] \(\[Sum]\+\(n = \ 1, 3, 5,  ... \)\(a\_n\) \(\
\[PartialD]\^n\/\[PartialD]t\^n\) \[Psi]\)\), " ", "=", " ", 
          RowBox[{
            UnderscriptBox[
              StyleBox["\[Sum]",
                FontSize->9], \(n = 2, 4, 6,  ... \)], 
            RowBox[{
              UnderscriptBox[
                StyleBox["\[Sum]",
                  FontSize->9], \(j = 1, 2, 
                3\)], \(\(b\_\(n\ j\)\) \
\(\[PartialD]\^n\/\[PartialD]r\_j\^n\) \[Psi]\)}]}]}], TraditionalForm]]],
  ","
}], "NumberedEquation",
  CellTags->{"i:49", "(5.1.101)"}],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`a\_n\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`b\_\(n\ j\)\)]],
  " are real coefficients. Using the same manipulations as described in the \
previous problem, show that a conservation law of the form of Eq. ",
  ButtonBox["(5.1.57)",
    ButtonData:>"(5.1.57)",
    ButtonStyle->"Hyperlink"],
  " exists for a generalized probability density ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"N", "(", 
            RowBox[{
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], ",", "t"}], ")"}], " "}], 
        TraditionalForm]]],
  ", and that for a ",
  "wave packet",
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{"N", "(", 
          RowBox[{
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[",",
              FontWeight->"Plain"], 
            StyleBox["t",
              FontWeight->"Plain"]}], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  " is given by"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{"N", "(", 
            RowBox[{
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[",",
                FontWeight->"Plain"], 
              StyleBox["t",
                FontWeight->"Plain"]}], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox[" ",
            FontWeight->"Plain"], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{
            StyleBox[\(\((\(|\)\(\[Psi]\)\(|\))\)\^2\),
              FontWeight->"Plain"], 
            RowBox[{
              RowBox[{"\[PartialD]", 
                RowBox[{"D", "(", 
                  RowBox[{
                    StyleBox["k",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], 
                    StyleBox[",",
                      FontWeight->"Plain"], 
                    StyleBox["\[Omega]",
                      FontWeight->"Plain"]}], 
                  StyleBox[")",
                    FontWeight->"Plain"]}]}], 
              StyleBox["/",
                FontWeight->"Plain"], \(\[PartialD]\[Omega]\)}]}]}], " ", 
        ","}], TraditionalForm]]]], "NumberedEquation",
  CellTags->{"i:50", "(5.1.102)"}],

Cell[TextData[{
  "and the flux of ",
  Cell[BoxData[
      \(TraditionalForm\`N\)]],
  " is",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{Cell[""], 
            StyleBox["\[CapitalGamma]",
              FontWeight->"Bold"]}], "=", 
          RowBox[{"N", " ", 
            SubscriptBox[
              StyleBox["v",
                FontWeight->"Bold",
                FontSlant->"Plain"], "g"]}]}], TraditionalForm]]],
  ",where ",
  Cell[BoxData[
      FormBox[
        RowBox[{"D", "(", 
          RowBox[{
            StyleBox["k",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[",",
              FontWeight->"Plain"], 
            StyleBox["\[Omega]",
              FontWeight->"Plain"]}], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  " is the dispersion function associated with Eq. ",
  ButtonBox["(5.1.101)",
    ButtonData:>"(5.1.101)",
    ButtonStyle->"Hyperlink"],
  " , and where ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          SubscriptBox[
            StyleBox["v",
              FontSlant->"Plain"], 
            StyleBox["g",
              FontWeight->"Plain"]],
          FontWeight->"Bold"], TraditionalForm]]],
  " is the group velocity",
  Cell[BoxData[
      FormBox[Cell[""], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(12)",
    FontWeight->"Bold"],
  " Sunlight creates an energy flux (Poynting flux) at the Earth with \
intensity ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[CapitalGamma]", "=", " ", 
          RowBox[{"1300", " ", 
            RowBox[{
              StyleBox["W",
                FontSlant->"Plain"], "/", 
              SuperscriptBox[
                StyleBox["m",
                  FontSlant->"Plain"], "2"]}]}]}], TraditionalForm]]],
  ". Use this result to determine the pressure per unit area on a solar sail \
in earth orbit, via Eqs. ",
  ButtonBox["(5.1.73)",
    ButtonData:>"(5.1.73)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(5.1.76)",
    ButtonData:>"(5.1.76)",
    ButtonStyle->"Hyperlink"],
  ". The sail consists of an ultrathin Mylar surface oriented normal to the \
direction of the sun's rays. For simplicity, assume the sail absorbs all \
incoming radiation. For a sail with area ",
  Cell[BoxData[
      \(TraditionalForm\`A = 1\ km\^2\)]],
  " and mass 1000 kg, find the acceleration due to the light pressure. (It's \
not very large, but it lasts 24 hours a day, and it's free.). Neglecting \
gravitational effects, how fast (in kilometers per second) is the sail moving \
after one month of constant acceleration?"
}], "Text",
  CellTags->"i:51"],

Cell[TextData[{
  StyleBox["(13)",
    FontWeight->"Bold"],
  " Prove that Eq. ",
  ButtonBox["(5.1.84)",
    ButtonData:>"(5.1.84)",
    ButtonStyle->"Hyperlink"],
  " follows from Eq. ",
  ButtonBox["(5.1.83)",
    ButtonData:>"(5.1.83)",
    ButtonStyle->"Hyperlink"],
  " by calculating the required generalized Fourier integral by hand ."
}], "Text"],

Cell[TextData[{
  StyleBox["(14)",
    FontWeight->"Bold"],
  " The intensity of sound is measured on a logarithmic scale in units of ",
  StyleBox["bels",
    FontSlant->"Italic"],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " bels is an energy flux of ",
  Cell[BoxData[
      \(TraditionalForm\`10\^x\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalGamma]\&_\_o\)]],
  "and ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalGamma]\&_\_o\)]],
  " = ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(10\^\(-12\)\), " ", 
          StyleBox[\(W/m\^2\),
            FontSlant->"Plain"]}], TraditionalForm]]],
  ". A ",
  StyleBox["decibel",
    FontSlant->"Italic"],
  " is 0.1 bel. Assume that the sound travels in air at atmospheric pressure \
and a temperature of 20\[Degree]C,  the frequency is 440 hz, and the \
intensity is 20 decibels. \n",
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Find the mean energy density in the sound wave, in Joules per cubic \
meter. \n",
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Find the maximum displacement of the air, in microns (1 micron = ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(10\^\(-6\)\), " ", 
          StyleBox["m",
            FontSlant->"Plain"]}], TraditionalForm]]],
  "). The displacement ",
  Cell[BoxData[
      \(TraditionalForm\`\[Eta](x, t)\)]],
  " of air in a compressional sound wave follows the wave equation, Eq. ",
  ButtonBox["(4.2.48)",
    ButtonData:>{"Chapter4.nb", "(4.2.48)"},
    ButtonStyle->"Hyperlink"],
  ". \n",
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Find the maximum pressure change due to the wave, in atmospheres. The \
pressure change in the air is related to the displacement by Eq. ",
  ButtonBox["(4.4.40)",
    ButtonData:>{"Chapter4.nb", "(4.4.40)"},
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text",
  CellTags->"i:131"],

Cell[TextData[{
  StyleBox["(15)",
    FontWeight->"Bold"],
  " A particle of mass ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(m\)\(\ \)\)\)]],
  " is described initially by a spherically symmetric Gaussian wave function, \
 ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi](r, t = 0) = 
        A\ \(\(\[ExponentialE]\^\(\(-\[Beta]\)\ r\^2\)\)\(.\)\)\)]],
  " Find the subsequent evolution in three dimensions, using \
Schr\[ODoubleDot]dinger's equation.  Animate the solution for ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\((\(|\)\(\[Psi](r, 
                t)\)\(|\))\)\^2\)\(,\)\)\)]],
  " taking ",
  Cell[BoxData[
      \(TraditionalForm\`\[Beta]\  = \ 1/10\)]],
  ", for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 20\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(16)",
    FontWeight->"Bold"],
  " In an exploding-wire experiment, a long thin wire is subjected to an \
extremely large current, causing the wire to vaporize and explode. (Such \
explosions are used as x-ray sources, and to study the properties of hot \
dense materials.) Assuming that the wire creates a pressure source of the \
form ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"S", "(", 
            RowBox[{
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[",",
                FontWeight->"Plain"], 
              StyleBox["t",
                FontWeight->"Plain"]}], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{
            StyleBox["s",
              FontWeight->"Plain"], 
            StyleBox[" ",
              FontWeight->"Plain"], 
            StyleBox[\(h(t)\),
              FontWeight->"Plain"], 
            StyleBox[" ",
              FontWeight->"Plain"], 
            RowBox[{
              StyleBox["\[Delta]",
                FontWeight->"Plain"], 
              StyleBox["(",
                FontWeight->"Plain"], 
              StyleBox["x",
                FontWeight->"Plain"], ")"}], \(\[Delta](y)\)}]}], 
        TraditionalForm]]],
  " where  ",
  Cell[BoxData[
      \(TraditionalForm\`h(t)\)]],
  " is a Heaviside function, solve Eq. (",
  ButtonBox["5.1.79",
    ButtonData:>"(5.1.79)",
    ButtonStyle->"Hyperlink"],
  ") for the resulting pressure wave, assuming that ",
  Cell[BoxData[
      \(TraditionalForm\`p = 0\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`t < 0\)]],
  ". Show that"
}], "Text",
  CellTags->"i:62"],

Cell[TextData[{
  "\t\t ",
  Cell[BoxData[
      FormBox[
        TagBox[
          RowBox[{\(p(r, t)\), " ", "=", 
            TagBox[
              RowBox[{
                StyleBox["{",
                  ShowAutoStyles->False,
                  FontSize->18], 
                StyleBox[GridBox[{
                      {\(\(s\/\(2  \[Pi]\ \ c\^2\)\) 
                          log[c\ t/
                                  r + \@\(c\^2\ t\^2/r\^2 - 1\)], \ \ \ \ \ \ \
r \[LessEqual] \ c\ t, \)},
                      {\(0, \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ r > \ c\ t, \)}
                      },
                    RowSpacings->2.5],
                  ShowAutoStyles->True]}],
              (#&)]}],
          (#&)], TraditionalForm]]],
  " "
}], "Text"],

Cell[TextData[{
  "where  ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  " is the ",
  StyleBox["cylindrical",
    FontSlant->"Italic"],
  " radial coordinate. Taking ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(c = \(s = 1\)\)\(,\)\)\)]],
  " animate ",
  Cell[BoxData[
      \(TraditionalForm\`p(r, t)\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 10\)]],
  ".  \n[Hint: Find the solution for ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  " in terms of an inverse Fourier transform involving ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["k",
            FontWeight->"Bold",
            FontSlant->"Plain"], "=", \((k\_x, k\_y)\)}], TraditionalForm]]],
  ". Then write ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["k",
              FontWeight->"Bold",
              FontSlant->"Plain"], "\[CenterDot]", \((x, y)\)}], 
          "=", \(k\ r\ cos\ \[Theta]\)}], TraditionalForm]]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\)]],
  " is the angle between ",
  Cell[BoxData[
      FormBox[
        StyleBox["k",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], "=", \((x, y)\)}], TraditionalForm]]],
  ",  and perform the integral over ",
  Cell[BoxData[
      FormBox[
        StyleBox["k",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " in polar coordinates ",
  Cell[BoxData[
      \(TraditionalForm\`\((k, \[Theta])\)\)]],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`k\_x\  = \ k\ cos\ \[Theta]\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`k\_\(\(y\)\(\ \)\) = \ k\ sin\ \[Theta]\)]],
  ". In these coordinates, ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]\^2 k = 
        k\ \[DifferentialD]k\ \[DifferentialD]\[Theta]\)]],
  ". ] "
}], "Text"],

Cell[TextData[{
  StyleBox["(17)",
    FontWeight->"Bold"],
  " Waves in deep water, neglecting surface tension, follow the dispersion \
relation ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega](k)\  = \ \@\(g\ k\)\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`g\)]],
  " is the acceleration of gravity. \n",
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Show that a wave packet with cylindrical symmetry will evolve according \
to "
}], "Text",
  CellTags->"i:52"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(\(z(r, t) = 
        2\ Re \(\[Integral]\_0\%\[Infinity] 
              k\ \(A(k)\) \(\(J\_o\)(\ 
                k\ r)\)\ \(\[ExponentialE]\^\(\(\ \)\(\(-\[ImaginaryI]\)\ \(\
\[Omega](k)\) t\)\)\) \[DifferentialD]k/\((2\ \[Pi])\)\)\)\(,\)\)\)]]
}], "Text"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`A(k)\)]],
  " is the Fourier amplitude of the packet at time ",
  Cell[BoxData[
      \(TraditionalForm\`t = 0\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Assuming that ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(A(
          k)\)\(\ \)\(=\)\(\[ExponentialE]\^\(\(-k\^2\)/36\)\)\(\ \)\)\)]],
  "(distances in meters), evaluate ",
  Cell[BoxData[
      \(TraditionalForm\`z(r, t)\)]],
  " numerically and create a sequence of ",
  StyleBox["Plot3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " graphics objects, plotting ",
  Cell[BoxData[
      \(TraditionalForm\`z(\@\(x\^2 + y\^2\), t)\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`\(-3\) < x < 3\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(-3\) < y < 3\)]],
  " in steps of ",
  Cell[BoxData[
      FormBox[
        RowBox[{"0.1", " ", 
          StyleBox["s",
            FontSlant->"Plain"]}], TraditionalForm]]],
  " for ",
  Cell[BoxData[
      FormBox[
        RowBox[{"0", "<", "t", "<", 
          RowBox[{"3", " ", 
            StyleBox["s",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  ". \n[Hint: These plots would take a long time to evaluate if done \
directly. Therefore, use the following technique. First, define ",
  Cell[BoxData[
      \(TraditionalForm\`z(r, t)\)]],
  " using ",
  StyleBox["NIntegrate",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", and do the ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  "-integral only over the range ",
  Cell[BoxData[
      \(TraditionalForm\`0 < k < 15\)]],
  ". Then, evaluate a table of values of ",
  Cell[BoxData[
      \(TraditionalForm\`z(r\_i, t)\)]],
  " and interpolate them via the command ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[\(zint[t_]\),
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox[" ",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox[":=",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          StyleBox[" ",
            FontFamily->"Courier",
            FontWeight->"Bold"], 
          RowBox[{
            RowBox[{
              StyleBox["zint",
                FontFamily->"Courier",
                FontWeight->"Bold"], 
              StyleBox["[",
                FontFamily->"Courier",
                FontWeight->"Bold"], 
              StyleBox["t",
                FontFamily->"Courier",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox["]",
                FontFamily->"Courier",
                FontWeight->"Bold"]}], 
            StyleBox["=",
              FontFamily->"Courier",
              FontWeight->"Bold"], 
            RowBox[{
              StyleBox["Interpolation",
                FontFamily->"Courier",
                FontWeight->"Bold"], 
              StyleBox["[",
                FontFamily->"Courier",
                FontWeight->"Bold"], 
              StyleBox[" ",
                FontFamily->"Courier",
                FontWeight->"Bold"], 
              RowBox[{
                StyleBox["Table",
                  FontFamily->"Courier",
                  FontWeight->"Bold"], 
                StyleBox["[",
                  FontFamily->"Courier",
                  FontWeight->"Bold"], 
                RowBox[{
                  RowBox[{
                    StyleBox["{",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    RowBox[{
                      StyleBox["r",
                        FontFamily->"Courier",
                        FontWeight->"Bold",
                        FontSlant->"Plain"], 
                      StyleBox[",",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], 
                      RowBox[{
                        StyleBox["z",
                          FontFamily->"Courier",
                          FontWeight->"Bold",
                          FontSlant->"Plain"], 
                        StyleBox["[",
                          FontFamily->"Courier",
                          FontWeight->"Bold"], 
                        RowBox[{
                          StyleBox["r",
                            FontFamily->"Courier",
                            FontWeight->"Bold",
                            FontSlant->"Plain"], 
                          StyleBox[",",
                            FontFamily->"Courier",
                            FontWeight->"Bold"], 
                          StyleBox["t",
                            FontFamily->"Courier",
                            FontWeight->"Bold",
                            FontSlant->"Plain"]}], 
                        StyleBox["]",
                          FontFamily->"Courier",
                          FontWeight->"Bold"]}]}], 
                    StyleBox["}",
                      FontFamily->"Courier",
                      FontWeight->"Bold"]}], 
                  StyleBox[",",
                    FontFamily->"Courier",
                    FontWeight->"Bold"], 
                  RowBox[{
                    StyleBox["{",
                      FontFamily->"Courier",
                      FontWeight->"Bold"], 
                    RowBox[{
                      StyleBox["r",
                        FontFamily->"Courier",
                        FontWeight->"Bold",
                        FontSlant->"Plain"], 
                      StyleBox[",",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], 
                      StyleBox["0",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], 
                      StyleBox[",",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], 
                      StyleBox["5",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], 
                      StyleBox[",",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], 
                      StyleBox[" ",
                        FontFamily->"Courier",
                        FontWeight->"Bold"], 
                      StyleBox[".2",
                        FontFamily->"Courier",
                        FontWeight->"Bold"]}], 
                    StyleBox["}",
                      FontFamily->"Courier",
                      FontWeight->"Bold"]}]}], 
                StyleBox["]",
                  FontFamily->"Courier",
                  FontWeight->"Bold"]}], 
              StyleBox["]",
                FontFamily->"Courier",
                FontWeight->"Bold"]}]}]}], TraditionalForm]]],
  ". Using ",
  StyleBox["Plot3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " the interpolation function ",
  StyleBox["zint[t][",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  Cell[BoxData[
      FormBox[
        SqrtBox[
          RowBox[{
            SuperscriptBox[
              StyleBox["x",
                FontSlant->"Plain"], "2"], "+", 
            SuperscriptBox[
              StyleBox["y",
                FontSlant->"Plain"], "2"]}]], TraditionalForm]],
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox["]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " can now be plotted.] "
}], "Text"],

Cell[TextData[{
  " The result is shown in Fig. ",
  ButtonBox["5.4",
    ButtonData:>"Fig. 5.4",
    ButtonStyle->"Hyperlink"],
  " for the case of shallow-water waves, where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\  = \ \(\@\(g\ h\)\) k\)]],
  ", taking ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\@\(g\ h\)\), " ", "=", " ", 
          RowBox[{"1", " ", 
            RowBox[{
              StyleBox["m",
                FontSlant->"Plain"], "/", "sec"}]}]}], TraditionalForm]]],
  ". The reader is encouraged to vary the parameters of the problem, and to \
investigate the behavior of other dispersion relations. (For example, what \
happens if surface tension is added? ) "
}], "Text"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[.12586 .2075 -12 -8.99448 ]
[.12586 .2075 0 .00552 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.56094 .0364 -5.16972 -9 ]
[.56094 .0364 .83028 0 ]
[.75679 .08071 0 -6.17777 ]
[.75679 .08071 12 2.82223 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.9429 .3657 0 -5.9083 ]
[.9429 .3657 6 3.0917 ]
[.02494 .25992 -18 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.01611 .31527 -18 -2.78472 ]
[.01611 .31527 0 6.21528 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00254 .43215 -12 -2.88407 ]
[-0.00254 .43215 0 6.11593 ]
[-0.0124 .49393 -12 -2.93688 ]
[-0.0124 .49393 0 6.06312 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
[(-2)] .12586 .2075 1 .99877 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.56863 .04703 m
.57247 .05235 L
s
[(2)] .56094 .0364 .72324 1 Mshowa
.125 Mabswid
.18558 .19702 m
.18832 .19985 L
s
.23703 .17687 m
.23971 .17975 L
s
.28951 .15632 m
.29214 .15925 L
s
.39772 .11395 m
.40023 .11699 L
s
.4535 .09211 m
.45595 .0952 L
s
.51046 .06981 m
.51284 .07294 L
s
.08568 .23614 m
.08851 .23887 L
s
.62804 .02377 m
.63027 .02701 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.7445 .0853 m
.73835 .08759 L
s
[(-2)] .75679 .08071 -1 .37284 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.93037 .36962 m
.92411 .37158 L
s
[(2)] .9429 .3657 -1 .31296 Mshowa
.125 Mabswid
.7708 .12553 m
.7671 .12688 L
s
.79613 .16428 m
.79242 .1656 L
s
.82054 .20161 m
.81682 .20291 L
s
.86679 .27235 m
.86305 .2736 L
s
.88871 .30589 m
.88497 .30711 L
s
.9099 .3383 m
.90615 .3395 L
s
.71716 .04348 m
.71349 .04489 L
s
.95018 .39992 m
.94642 .40107 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(-20)] .02494 .25992 1 -0.39157 Mshowa
.02837 .31059 m
.0345 .30825 L
s
[(-10)] .01611 .31527 1 -0.38117 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.00981 .42772 m
.01599 .4255 L
s
[(10)] -0.00254 .43215 1 -0.3591 Mshowa
0 .48963 m
.0062 .48748 L
s
[(20)] -0.0124 .49393 1 -0.34736 Mshowa
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.654 .753 .923 r
.39362 .69483 .40169 .70181 .4152 .69807 .40717 .69106 Mtetra
.657 .754 .921 r
.40717 .69106 .4152 .69807 .42878 .69431 .42079 .68714 Mtetra
.659 .751 .918 r
.42079 .68714 .42878 .69431 .44242 .69042 .43448 .68316 Mtetra
.657 .749 .918 r
.43448 .68316 .44242 .69042 .45614 .68646 .44824 .67923 Mtetra
.655 .75 .919 r
.44824 .67923 .45614 .68646 .46992 .68253 .46207 .67532 Mtetra
.653 .751 .922 r
.46207 .67532 .46992 .68253 .48378 .67863 .47597 .67147 Mtetra
.653 .753 .923 r
.47597 .67147 .48378 .67863 .4977 .67476 .48994 .66759 Mtetra
.656 .755 .923 r
.48994 .66759 .4977 .67476 .5117 .6709 .50398 .6636 Mtetra
.658 .753 .92 r
.50398 .6636 .5117 .6709 .52577 .667 .5181 .65952 Mtetra
.658 .749 .917 r
.5181 .65952 .52577 .667 .53991 .66298 .53229 .65542 Mtetra
.657 .748 .917 r
.53229 .65542 .53991 .66298 .55412 .6589 .54655 .65133 Mtetra
.54655 .65133 .55412 .6589 .56841 .65481 .56088 .64724 Mtetra
.656 .749 .919 r
.56088 .64724 .56841 .65481 .58277 .65072 .57529 .64315 Mtetra
.655 .75 .92 r
.57529 .64315 .58277 .65072 .5972 .64662 .58978 .63909 Mtetra
.654 .752 .922 r
.58978 .63909 .5972 .64662 .61171 .64252 .60434 .63502 Mtetra
.654 .754 .923 r
.60434 .63502 .61171 .64252 .6263 .6384 .61898 .63092 Mtetra
.654 .755 .924 r
.61898 .63092 .6263 .6384 .64096 .63427 .6337 .62678 Mtetra
.655 .756 .925 r
.6337 .62678 .64096 .63427 .6557 .63012 .64849 .62261 Mtetra
.655 .757 .925 r
.64849 .62261 .6557 .63012 .67052 .62594 .66336 .6184 Mtetra
.66336 .6184 .67052 .62594 .68541 .62174 .67831 .61416 Mtetra
.67831 .61416 .68541 .62174 .70039 .61752 .69334 .60989 Mtetra
.656 .757 .925 r
.69334 .60989 .70039 .61752 .71544 .61327 .70845 .60558 Mtetra
.656 .757 .924 r
.70845 .60558 .71544 .61327 .73058 .609 .72364 .60123 Mtetra
.657 .756 .923 r
.72364 .60123 .73058 .609 .74579 .60472 .73891 .59685 Mtetra
.657 .755 .922 r
.73891 .59685 .74579 .60472 .76109 .60042 .75426 .59243 Mtetra
.657 .753 .921 r
.75426 .59243 .76109 .60042 .77647 .59611 .76969 .588 Mtetra
.656 .75 .919 r
.76969 .588 .77647 .59611 .79193 .59179 .78521 .5836 Mtetra
.655 .749 .919 r
.78521 .5836 .79193 .59179 .80748 .58747 .80081 .57919 Mtetra
.655 .748 .918 r
.80081 .57919 .80748 .58747 .82311 .58313 .8165 .57479 Mtetra
.654 .747 .918 r
.8165 .57479 .82311 .58313 .83883 .57874 .83229 .5704 Mtetra
.654 .748 .919 r
.83229 .5704 .83883 .57874 .85462 .57422 .84815 .56598 Mtetra
.655 .752 .921 r
.84815 .56598 .85462 .57422 .8705 .56965 .8641 .56146 Mtetra
.658 .756 .922 r
.8641 .56146 .8705 .56965 .88646 .56509 .88013 .55682 Mtetra
.658 .755 .922 r
.88013 .55682 .88646 .56509 .90252 .56056 .89624 .55215 Mtetra
.656 .752 .92 r
.89624 .55215 .90252 .56056 .91867 .55605 .91245 .54753 Mtetra
.655 .75 .92 r
.91245 .54753 .91867 .55605 .93492 .55157 .92875 .54294 Mtetra
.654 .748 .919 r
.92875 .54294 .93492 .55157 .95125 .54701 .94516 .53839 Mtetra
.655 .75 .92 r
.94516 .53839 .95125 .54701 .96766 .54231 .96165 .53377 Mtetra
.657 .754 .921 r
.96165 .53377 .96766 .54231 .98416 .53759 .97822 .529 Mtetra
.657 .753 .921 r
.38546 .68779 .39362 .69483 .40717 .69106 .39906 .68385 Mtetra
.659 .751 .918 r
.39906 .68385 .40717 .69106 .42079 .68714 .41273 .67985 Mtetra
.657 .749 .918 r
.41273 .67985 .42079 .68714 .43448 .68316 .42646 .67591 Mtetra
.655 .75 .92 r
.42646 .67591 .43448 .68316 .44824 .67923 .44027 .672 Mtetra
.653 .751 .922 r
.44027 .672 .44824 .67923 .46207 .67532 .45414 .66814 Mtetra
.653 .754 .924 r
.45414 .66814 .46207 .67532 .47597 .67147 .46808 .66425 Mtetra
.657 .755 .922 r
.46808 .66425 .47597 .67147 .48994 .66759 .4821 .66018 Mtetra
.659 .751 .918 r
.4821 .66018 .48994 .66759 .50398 .6636 .49619 .65606 Mtetra
.658 .748 .917 r
.49619 .65606 .50398 .6636 .5181 .65952 .51035 .65195 Mtetra
.657 .748 .918 r
.51035 .65195 .5181 .65952 .53229 .65542 .52459 .64786 Mtetra
.655 .75 .919 r
.52459 .64786 .53229 .65542 .54655 .65133 .5389 .6438 Mtetra
.653 .75 .921 r
.5389 .6438 .54655 .65133 .56088 .64724 .55328 .63978 Mtetra
.653 .753 .923 r
.55328 .63978 .56088 .64724 .57529 .64315 .56775 .63575 Mtetra
.653 .756 .925 r
.56775 .63575 .57529 .64315 .58978 .63909 .58228 .63166 Mtetra
.655 .757 .925 r
.58228 .63166 .58978 .63909 .60434 .63502 .5969 .62751 Mtetra
.656 .756 .924 r
.5969 .62751 .60434 .63502 .61898 .63092 .61159 .6233 Mtetra
.656 .754 .922 r
.61159 .6233 .61898 .63092 .6337 .62678 .62635 .61906 Mtetra
.656 .753 .921 r
.62635 .61906 .6337 .62678 .64849 .62261 .6412 .61481 Mtetra
.656 .751 .92 r
.6412 .61481 .64849 .62261 .66336 .6184 .65612 .61054 Mtetra
.65612 .61054 .66336 .6184 .67831 .61416 .67113 .60625 Mtetra
.67113 .60625 .67831 .61416 .69334 .60989 .68621 .60196 Mtetra
.655 .751 .92 r
.68621 .60196 .69334 .60989 .70845 .60558 .70138 .59765 Mtetra
.655 .752 .921 r
.70138 .59765 .70845 .60558 .72364 .60123 .71663 .59332 Mtetra
.655 .754 .923 r
.71663 .59332 .72364 .60123 .73891 .59685 .73196 .58896 Mtetra
.656 .756 .924 r
.73196 .58896 .73891 .59685 .75426 .59243 .74737 .58455 Mtetra
.657 .758 .924 r
.74737 .58455 .75426 .59243 .76969 .588 .76286 .58006 Mtetra
.658 .757 .923 r
.76286 .58006 .76969 .588 .78521 .5836 .77843 .57552 Mtetra
.658 .755 .922 r
.77843 .57552 .78521 .5836 .80081 .57919 .79409 .57095 Mtetra
.656 .751 .92 r
.79409 .57095 .80081 .57919 .8165 .57479 .80984 .56644 Mtetra
.655 .749 .919 r
.80984 .56644 .8165 .57479 .83229 .5704 .82567 .56195 Mtetra
.654 .748 .918 r
.82567 .56195 .83229 .5704 .84815 .56598 .8416 .55747 Mtetra
.654 .747 .918 r
.8416 .55747 .84815 .56598 .8641 .56146 .85762 .553 Mtetra
.654 .75 .92 r
.85762 .553 .8641 .56146 .88013 .55682 .87373 .54847 Mtetra
.658 .755 .922 r
.87373 .54847 .88013 .55682 .89624 .55215 .88991 .54377 Mtetra
.658 .756 .922 r
.88991 .54377 .89624 .55215 .91245 .54753 .90617 .53901 Mtetra
.656 .752 .921 r
.90617 .53901 .91245 .54753 .92875 .54294 .92253 .5343 Mtetra
.655 .75 .92 r
.92253 .5343 .92875 .54294 .94516 .53839 .939 .52963 Mtetra
.653 .748 .919 r
.939 .52963 .94516 .53839 .96165 .53377 .95556 .52502 Mtetra
.655 .749 .92 r
.95556 .52502 .96165 .53377 .97822 .529 .97221 .52032 Mtetra
.659 .751 .918 r
.37724 .68057 .38546 .68779 .39906 .68385 .39088 .67654 Mtetra
.657 .749 .918 r
.39088 .67654 .39906 .68385 .41273 .67985 .40459 .67257 Mtetra
.655 .75 .92 r
.40459 .67257 .41273 .67985 .42646 .67591 .41837 .66865 Mtetra
.652 .751 .922 r
.41837 .66865 .42646 .67591 .44027 .672 .43221 .66479 Mtetra
.654 .754 .923 r
.43221 .66479 .44027 .672 .45414 .66814 .44613 .66085 Mtetra
.658 .754 .921 r
.44613 .66085 .45414 .66814 .46808 .66425 .46012 .65674 Mtetra
.659 .75 .917 r
.46012 .65674 .46808 .66425 .4821 .66018 .47419 .65261 Mtetra
.657 .748 .917 r
.47419 .65261 .4821 .66018 .49619 .65606 .48833 .6485 Mtetra
.656 .749 .919 r
.48833 .6485 .49619 .65606 .51035 .65195 .50254 .64441 Mtetra
.653 .75 .921 r
.50254 .64441 .51035 .65195 .52459 .64786 .51682 .64042 Mtetra
.652 .753 .924 r
.51682 .64042 .52459 .64786 .5389 .6438 .53118 .63641 Mtetra
.653 .756 .925 r
.53118 .63641 .5389 .6438 .55328 .63978 .54561 .63232 Mtetra
.656 .756 .923 r
.54561 .63232 .55328 .63978 .56775 .63575 .56012 .62812 Mtetra
.657 .753 .921 r
.56012 .62812 .56775 .63575 .58228 .63166 .57471 .62387 Mtetra
.657 .75 .918 r
.57471 .62387 .58228 .63166 .5969 .62751 .58937 .61961 Mtetra
.657 .748 .917 r
.58937 .61961 .5969 .62751 .61159 .6233 .60411 .61532 Mtetra
.657 .747 .916 r
.60411 .61532 .61159 .6233 .62635 .61906 .61893 .61103 Mtetra
.61893 .61103 .62635 .61906 .6412 .61481 .63383 .60673 Mtetra
.63383 .60673 .6412 .61481 .65612 .61054 .64881 .60241 Mtetra
.656 .746 .916 r
.64881 .60241 .65612 .61054 .67113 .60625 .66387 .59809 Mtetra
.66387 .59809 .67113 .60625 .68621 .60196 .67901 .59375 Mtetra
.656 .746 .917 r
.67901 .59375 .68621 .60196 .70138 .59765 .69423 .5894 Mtetra
.655 .746 .917 r
.69423 .5894 .70138 .59765 .71663 .59332 .70953 .58505 Mtetra
.655 .747 .917 r
.70953 .58505 .71663 .59332 .73196 .58896 .72492 .58068 Mtetra
.655 .747 .918 r
.72492 .58068 .73196 .58896 .74737 .58455 .74039 .57629 Mtetra
.654 .749 .919 r
.74039 .57629 .74737 .58455 .76286 .58006 .75595 .57188 Mtetra
.655 .752 .922 r
.75595 .57188 .76286 .58006 .77843 .57552 .77159 .56743 Mtetra
.657 .757 .923 r
.77159 .56743 .77843 .57552 .79409 .57095 .78731 .56285 Mtetra
.658 .758 .923 r
.78731 .56285 .79409 .57095 .80984 .56644 .80311 .55819 Mtetra
.658 .755 .922 r
.80311 .55819 .80984 .56644 .82567 .56195 .819 .55351 Mtetra
.656 .751 .92 r
.819 .55351 .82567 .56195 .8416 .55747 .83499 .54892 Mtetra
.655 .749 .919 r
.83499 .54892 .8416 .55747 .85762 .553 .85106 .54436 Mtetra
.653 .747 .918 r
.85106 .54436 .85762 .553 .87373 .54847 .86724 .53982 Mtetra
.654 .748 .919 r
.86724 .53982 .87373 .54847 .88991 .54377 .8835 .53524 Mtetra
.657 .754 .921 r
.8835 .53524 .88991 .54377 .90617 .53901 .89984 .53049 Mtetra
.659 .756 .922 r
.89984 .53049 .90617 .53901 .92253 .5343 .91626 .52565 Mtetra
.657 .753 .921 r
.91626 .52565 .92253 .5343 .939 .52963 .93278 .52086 Mtetra
.655 .75 .92 r
.93278 .52086 .939 .52963 .95556 .52502 .9494 .51612 Mtetra
.653 .748 .919 r
.9494 .51612 .95556 .52502 .97221 .52032 .96613 .51144 Mtetra
.657 .749 .918 r
.36894 .67323 .37724 .68057 .39088 .67654 .38262 .66923 Mtetra
.655 .75 .92 r
.38262 .66923 .39088 .67654 .40459 .67257 .39637 .66528 Mtetra
.652 .751 .922 r
.39637 .66528 .40459 .67257 .41837 .66865 .41019 .66141 Mtetra
.654 .754 .923 r
.41019 .66141 .41837 .66865 .43221 .66479 .42408 .65745 Mtetra
.659 .753 .92 r
.42408 .65745 .43221 .66479 .44613 .66085 .43805 .65331 Mtetra
.659 .749 .917 r
.43805 .65331 .44613 .66085 .46012 .65674 .45209 .64916 Mtetra
.657 .749 .917 r
.45209 .64916 .46012 .65674 .47419 .65261 .4662 .64504 Mtetra
.655 .75 .92 r
.4662 .64504 .47419 .65261 .48833 .6485 .48038 .64099 Mtetra
.652 .751 .923 r
.48038 .64099 .48833 .6485 .50254 .64441 .49464 .63701 Mtetra
.652 .755 .925 r
.49464 .63701 .50254 .64441 .51682 .64042 .50897 .63297 Mtetra
.657 .756 .923 r
.50897 .63297 .51682 .64042 .53118 .63641 .52338 .62875 Mtetra
.658 .752 .92 r
.52338 .62875 .53118 .63641 .54561 .63232 .53787 .62449 Mtetra
.658 .749 .917 r
.53787 .62449 .54561 .63232 .56012 .62812 .55243 .62019 Mtetra
.658 .748 .916 r
.55243 .62019 .56012 .62812 .57471 .62387 .56706 .61589 Mtetra
.657 .747 .916 r
.56706 .61589 .57471 .62387 .58937 .61961 .58178 .61159 Mtetra
.58178 .61159 .58937 .61961 .60411 .61532 .59657 .60729 Mtetra
.656 .748 .917 r
.59657 .60729 .60411 .61532 .61893 .61103 .61144 .60299 Mtetra
.656 .748 .918 r
.61144 .60299 .61893 .61103 .63383 .60673 .62639 .59867 Mtetra
.656 .749 .919 r
.62639 .59867 .63383 .60673 .64881 .60241 .64142 .59434 Mtetra
.656 .75 .919 r
.64142 .59434 .64881 .60241 .66387 .59809 .65654 .58998 Mtetra
.65654 .58998 .66387 .59809 .67901 .59375 .67173 .58557 Mtetra
.656 .749 .918 r
.67173 .58557 .67901 .59375 .69423 .5894 .68701 .58114 Mtetra
.656 .748 .918 r
.68701 .58114 .69423 .5894 .70953 .58505 .70237 .57671 Mtetra
.655 .747 .917 r
.70237 .57671 .70953 .58505 .72492 .58068 .71781 .57227 Mtetra
.655 .746 .917 r
.71781 .57227 .72492 .58068 .74039 .57629 .73334 .56783 Mtetra
.654 .746 .917 r
.73334 .56783 .74039 .57629 .75595 .57188 .74896 .56339 Mtetra
.654 .746 .918 r
.74896 .56339 .75595 .57188 .77159 .56743 .76466 .55894 Mtetra
.654 .747 .918 r
.76466 .55894 .77159 .56743 .78731 .56285 .78045 .55446 Mtetra
.654 .751 .921 r
.78045 .55446 .78731 .56285 .80311 .55819 .79633 .54992 Mtetra
.658 .757 .923 r
.79633 .54992 .80311 .55819 .819 .55351 .81228 .54521 Mtetra
.659 .758 .923 r
.81228 .54521 .819 .55351 .83499 .54892 .82832 .54043 Mtetra
.657 .753 .921 r
.82832 .54043 .83499 .54892 .85106 .54436 .84445 .53571 Mtetra
.655 .75 .919 r
.84445 .53571 .85106 .54436 .86724 .53982 .86068 .53106 Mtetra
.653 .747 .919 r
.86068 .53106 .86724 .53982 .8835 .53524 .87701 .52645 Mtetra
.653 .748 .919 r
.87701 .52645 .8835 .53524 .89984 .53049 .89343 .52181 Mtetra
.657 .753 .921 r
.89343 .52181 .89984 .53049 .91626 .52565 .90993 .51699 Mtetra
.659 .756 .922 r
.90993 .51699 .91626 .52565 .93278 .52086 .92651 .51206 Mtetra
.656 .752 .921 r
.92651 .51206 .93278 .52086 .9494 .51612 .94319 .50721 Mtetra
.655 .75 .92 r
.94319 .50721 .9494 .51612 .96613 .51144 .95998 .50241 Mtetra
.36056 .66587 .36894 .67323 .38262 .66923 .37428 .66189 Mtetra
.652 .751 .922 r
.37428 .66189 .38262 .66923 .39637 .66528 .38807 .658 Mtetra
.653 .754 .923 r
.38807 .658 .39637 .66528 .41019 .66141 .40194 .65404 Mtetra
.659 .754 .92 r
.40194 .65404 .41019 .66141 .42408 .65745 .41588 .64988 Mtetra
.659 .75 .917 r
.41588 .64988 .42408 .65745 .43805 .65331 .42989 .6457 Mtetra
.657 .749 .918 r
.42989 .6457 .43805 .65331 .45209 .64916 .44398 .64157 Mtetra
.653 .75 .92 r
.44398 .64157 .45209 .64916 .4662 .64504 .45813 .63754 Mtetra
.651 .752 .924 r
.45813 .63754 .4662 .64504 .48038 .64099 .47236 .63355 Mtetra
.654 .756 .924 r
.47236 .63355 .48038 .64099 .49464 .63701 .48667 .62942 Mtetra
.658 .754 .921 r
.48667 .62942 .49464 .63701 .50897 .63297 .50105 .62515 Mtetra
.659 .75 .917 r
.50105 .62515 .50897 .63297 .52338 .62875 .51551 .62084 Mtetra
.659 .748 .916 r
.51551 .62084 .52338 .62875 .53787 .62449 .53004 .61652 Mtetra
.658 .747 .916 r
.53004 .61652 .53787 .62449 .55243 .62019 .54465 .61222 Mtetra
.656 .748 .918 r
.54465 .61222 .55243 .62019 .56706 .61589 .55934 .60797 Mtetra
.653 .749 .92 r
.55934 .60797 .56706 .61589 .58178 .61159 .57411 .60378 Mtetra
.653 .753 .923 r
.57411 .60378 .58178 .61159 .59657 .60729 .58896 .59955 Mtetra
.653 .756 .925 r
.58896 .59955 .59657 .60729 .61144 .60299 .60388 .59528 Mtetra
.654 .758 .926 r
.60388 .59528 .61144 .60299 .62639 .59867 .61889 .59096 Mtetra
.654 .76 .927 r
.61889 .59096 .62639 .59867 .64142 .59434 .63398 .5866 Mtetra
.655 .76 .927 r
.63398 .5866 .64142 .59434 .65654 .58998 .64915 .58218 Mtetra
.656 .76 .927 r
.64915 .58218 .65654 .58998 .67173 .58557 .6644 .57773 Mtetra
.656 .76 .926 r
.6644 .57773 .67173 .58557 .68701 .58114 .67973 .57322 Mtetra
.657 .759 .925 r
.67973 .57322 .68701 .58114 .70237 .57671 .69515 .56867 Mtetra
.658 .758 .924 r
.69515 .56867 .70237 .57671 .71781 .57227 .71065 .56406 Mtetra
.658 .755 .921 r
.71065 .56406 .71781 .57227 .73334 .56783 .72623 .55943 Mtetra
.656 .75 .919 r
.72623 .55943 .73334 .56783 .74896 .56339 .7419 .55485 Mtetra
.655 .747 .918 r
.7419 .55485 .74896 .56339 .76466 .55894 .75766 .55032 Mtetra
.654 .746 .918 r
.75766 .55032 .76466 .55894 .78045 .55446 .77351 .5458 Mtetra
.653 .746 .918 r
.77351 .5458 .78045 .55446 .79633 .54992 .78945 .54128 Mtetra
.654 .748 .919 r
.78945 .54128 .79633 .54992 .81228 .54521 .80548 .53671 Mtetra
.656 .754 .922 r
.80548 .53671 .81228 .54521 .82832 .54043 .82159 .53199 Mtetra
.659 .758 .923 r
.82159 .53199 .82832 .54043 .84445 .53571 .83778 .52712 Mtetra
.658 .754 .921 r
.83778 .52712 .84445 .53571 .86068 .53106 .85406 .52229 Mtetra
.655 .75 .92 r
.85406 .52229 .86068 .53106 .87701 .52645 .87045 .51756 Mtetra
.653 .748 .919 r
.87045 .51756 .87701 .52645 .89343 .52181 .88694 .51288 Mtetra
.88694 .51288 .89343 .52181 .90993 .51699 .90352 .50817 Mtetra
.657 .754 .921 r
.90352 .50817 .90993 .51699 .92651 .51206 .92018 .50325 Mtetra
.659 .756 .922 r
.92018 .50325 .92651 .51206 .94319 .50721 .93692 .49825 Mtetra
.656 .752 .921 r
.93692 .49825 .94319 .50721 .95998 .50241 .95377 .49333 Mtetra
.653 .751 .922 r
.3521 .65849 .36056 .66587 .37428 .66189 .36586 .65456 Mtetra
.652 .753 .923 r
.36586 .65456 .37428 .66189 .38807 .658 .3797 .65062 Mtetra
.658 .754 .921 r
.3797 .65062 .38807 .658 .40194 .65404 .39361 .64645 Mtetra
.659 .75 .917 r
.39361 .64645 .40194 .65404 .41588 .64988 .4076 .64224 Mtetra
.657 .749 .918 r
.4076 .64224 .41588 .64988 .42989 .6457 .42166 .63809 Mtetra
.653 .75 .921 r
.42166 .63809 .42989 .6457 .44398 .64157 .43578 .63405 Mtetra
.651 .753 .924 r
.43578 .63405 .44398 .64157 .45813 .63754 .44999 .63005 Mtetra
.656 .756 .924 r
.44999 .63005 .45813 .63754 .47236 .63355 .46427 .62587 Mtetra
.659 .753 .919 r
.46427 .62587 .47236 .63355 .48667 .62942 .47862 .62155 Mtetra
.659 .749 .916 r
.47862 .62155 .48667 .62942 .50105 .62515 .49305 .61721 Mtetra
.658 .748 .916 r
.49305 .61721 .50105 .62515 .51551 .62084 .50756 .61288 Mtetra
.655 .748 .918 r
.50756 .61288 .51551 .62084 .53004 .61652 .52214 .60865 Mtetra
.652 .75 .922 r
.52214 .60865 .53004 .61652 .54465 .61222 .53681 .60451 Mtetra
.651 .755 .925 r
.53681 .60451 .54465 .61222 .55934 .60797 .55155 .60033 Mtetra
.653 .759 .927 r
.55155 .60033 .55934 .60797 .57411 .60378 .56637 .59608 Mtetra
.655 .759 .926 r
.56637 .59608 .57411 .60378 .58896 .59955 .58127 .5917 Mtetra
.656 .756 .924 r
.58127 .5917 .58896 .59955 .60388 .59528 .59625 .58729 Mtetra
.656 .754 .922 r
.59625 .58729 .60388 .59528 .61889 .59096 .61131 .58286 Mtetra
.656 .752 .921 r
.61131 .58286 .61889 .59096 .63398 .5866 .62645 .57842 Mtetra
.656 .751 .92 r
.62645 .57842 .63398 .5866 .64915 .58218 .64168 .57396 Mtetra
.655 .751 .92 r
.64168 .57396 .64915 .58218 .6644 .57773 .65698 .5695 Mtetra
.655 .752 .921 r
.65698 .5695 .6644 .57773 .67973 .57322 .67238 .56501 Mtetra
.655 .753 .922 r
.67238 .56501 .67973 .57322 .69515 .56867 .68786 .56051 Mtetra
.655 .756 .924 r
.68786 .56051 .69515 .56867 .71065 .56406 .70342 .55597 Mtetra
.657 .759 .925 r
.70342 .55597 .71065 .56406 .72623 .55943 .71906 .55131 Mtetra
.659 .761 .925 r
.71906 .55131 .72623 .55943 .7419 .55485 .73478 .54656 Mtetra
.659 .758 .923 r
.73478 .54656 .7419 .55485 .75766 .55032 .75059 .54177 Mtetra
.657 .751 .92 r
.75059 .54177 .75766 .55032 .77351 .5458 .7665 .53709 Mtetra
.654 .747 .918 r
.7665 .53709 .77351 .5458 .78945 .54128 .7825 .53248 Mtetra
.653 .746 .918 r
.7825 .53248 .78945 .54128 .80548 .53671 .7986 .5279 Mtetra
.653 .747 .919 r
.7986 .5279 .80548 .53671 .82159 .53199 .81478 .52328 Mtetra
.656 .752 .921 r
.81478 .52328 .82159 .53199 .83778 .52712 .83105 .51853 Mtetra
.66 .757 .922 r
.83105 .51853 .83778 .52712 .85406 .52229 .84739 .51358 Mtetra
.658 .755 .921 r
.84739 .51358 .85406 .52229 .87045 .51756 .86383 .50866 Mtetra
.655 .75 .92 r
.86383 .50866 .87045 .51756 .88694 .51288 .88038 .50386 Mtetra
.653 .748 .919 r
.88038 .50386 .88694 .51288 .90352 .50817 .89703 .49911 Mtetra
.89703 .49911 .90352 .50817 .92018 .50325 .91378 .49431 Mtetra
.658 .755 .921 r
.91378 .49431 .92018 .50325 .93692 .49825 .93059 .48927 Mtetra
.93059 .48927 .93692 .49825 .95377 .49333 .9475 .48421 Mtetra
.652 .752 .923 r
.34355 .65109 .3521 .65849 .36586 .65456 .35736 .64715 Mtetra
.657 .754 .921 r
.35736 .64715 .36586 .65456 .3797 .65062 .37125 .64302 Mtetra
.66 .751 .917 r
.37125 .64302 .3797 .65062 .39361 .64645 .38521 .63878 Mtetra
.658 .749 .918 r
.38521 .63878 .39361 .64645 .4076 .64224 .39924 .63459 Mtetra
.653 .75 .92 r
.39924 .63459 .4076 .64224 .42166 .63809 .41334 .63052 Mtetra
.651 .752 .924 r
.41334 .63052 .42166 .63809 .43578 .63405 .42751 .62652 Mtetra
.656 .756 .923 r
.42751 .62652 .43578 .63405 .44999 .63005 .44176 .6223 Mtetra
.659 .752 .919 r
.44176 .6223 .44999 .63005 .46427 .62587 .45609 .61796 Mtetra
.66 .749 .916 r
.45609 .61796 .46427 .62587 .47862 .62155 .4705 .61358 Mtetra
.658 .748 .917 r
.4705 .61358 .47862 .62155 .49305 .61721 .48498 .60926 Mtetra
.652 .748 .92 r
.48498 .60926 .49305 .61721 .50756 .61288 .49953 .60512 Mtetra
.65 .753 .925 r
.49953 .60512 .50756 .61288 .52214 .60865 .51417 .601 Mtetra
.653 .758 .927 r
.51417 .601 .52214 .60865 .53681 .60451 .52888 .59674 Mtetra
.657 .757 .924 r
.52888 .59674 .53681 .60451 .55155 .60033 .54367 .59234 Mtetra
.658 .753 .92 r
.54367 .59234 .55155 .60033 .56637 .59608 .55854 .58789 Mtetra
.658 .749 .917 r
.55854 .58789 .56637 .59608 .58127 .5917 .5735 .5834 Mtetra
.658 .748 .916 r
.5735 .5834 .58127 .5917 .59625 .58729 .58853 .57889 Mtetra
.658 .746 .915 r
.58853 .57889 .59625 .58729 .61131 .58286 .60364 .57438 Mtetra
.657 .745 .915 r
.60364 .57438 .61131 .58286 .62645 .57842 .61884 .56987 Mtetra
.656 .744 .915 r
.61884 .56987 .62645 .57842 .64168 .57396 .63412 .56537 Mtetra
.63412 .56537 .64168 .57396 .65698 .5695 .64948 .56088 Mtetra
.655 .744 .915 r
.64948 .56088 .65698 .5695 .67238 .56501 .66493 .55638 Mtetra
.654 .745 .916 r
.66493 .55638 .67238 .56501 .68786 .56051 .68047 .55189 Mtetra
.654 .746 .917 r
.68047 .55189 .68786 .56051 .70342 .55597 .69609 .54737 Mtetra
.654 .748 .919 r
.69609 .54737 .70342 .55597 .71906 .55131 .7118 .54282 Mtetra
.655 .752 .921 r
.7118 .54282 .71906 .55131 .73478 .54656 .7276 .53821 Mtetra
.657 .758 .924 r
.7276 .53821 .73478 .54656 .75059 .54177 .74348 .53346 Mtetra
.66 .761 .924 r
.74348 .53346 .75059 .54177 .7665 .53709 .75943 .52856 Mtetra
.659 .756 .922 r
.75943 .52856 .7665 .53709 .7825 .53248 .77548 .52368 Mtetra
.654 .749 .919 r
.77548 .52368 .7825 .53248 .7986 .5279 .79164 .51898 Mtetra
.653 .746 .918 r
.79164 .51898 .7986 .5279 .81478 .52328 .80789 .51433 Mtetra
.653 .747 .919 r
.80789 .51433 .81478 .52328 .83105 .51853 .82423 .50965 Mtetra
.655 .751 .92 r
.82423 .50965 .83105 .51853 .84739 .51358 .84066 .50483 Mtetra
.66 .757 .922 r
.84066 .50483 .84739 .51358 .86383 .50866 .85716 .49979 Mtetra
.658 .754 .921 r
.85716 .49979 .86383 .50866 .88038 .50386 .87376 .4948 Mtetra
.654 .75 .92 r
.87376 .4948 .88038 .50386 .89703 .49911 .89047 .48994 Mtetra
.653 .747 .919 r
.89047 .48994 .89703 .49911 .91378 .49431 .90729 .48513 Mtetra
.655 .749 .919 r
.90729 .48513 .91378 .49431 .93059 .48927 .9242 .4802 Mtetra
.659 .755 .921 r
.9242 .4802 .93059 .48927 .9475 .48421 .94118 .47505 Mtetra
.654 .753 .922 r
.33493 .64365 .34355 .65109 .35736 .64715 .34878 .63958 Mtetra
.66 .752 .919 r
.34878 .63958 .35736 .64715 .37125 .64302 .36271 .63532 Mtetra
.658 .75 .917 r
.36271 .63532 .37125 .64302 .38521 .63878 .37672 .63108 Mtetra
.655 .75 .92 r
.37672 .63108 .38521 .63878 .39924 .63459 .39079 .62695 Mtetra
.65 .751 .923 r
.39079 .62695 .39924 .63459 .41334 .63052 .40493 .62295 Mtetra
.655 .755 .923 r
.40493 .62295 .41334 .63052 .42751 .62652 .41916 .61874 Mtetra
.66 .752 .919 r
.41916 .61874 .42751 .62652 .44176 .6223 .43346 .61437 Mtetra
.66 .749 .916 r
.43346 .61437 .44176 .6223 .45609 .61796 .44784 .60997 Mtetra
.657 .748 .917 r
.44784 .60997 .45609 .61796 .4705 .61358 .46229 .60564 Mtetra
.65 .748 .922 r
.46229 .60564 .4705 .61358 .48498 .60926 .47682 .60155 Mtetra
.65 .755 .927 r
.47682 .60155 .48498 .60926 .49953 .60512 .49142 .59741 Mtetra
.656 .758 .925 r
.49142 .59741 .49953 .60512 .51417 .601 .50611 .59302 Mtetra
.658 .753 .92 r
.50611 .59302 .51417 .601 .52888 .59674 .52087 .58854 Mtetra
.66 .749 .916 r
.52087 .58854 .52888 .59674 .54367 .59234 .53572 .584 Mtetra
.66 .747 .914 r
.53572 .584 .54367 .59234 .55854 .58789 .55064 .57943 Mtetra
.659 .745 .914 r
.55064 .57943 .55854 .58789 .5735 .5834 .56565 .5749 Mtetra
.657 .744 .914 r
.56565 .5749 .5735 .5834 .58853 .57889 .58073 .57039 Mtetra
.655 .745 .916 r
.58073 .57039 .58853 .57889 .60364 .57438 .5959 .56592 Mtetra
.655 .747 .917 r
.5959 .56592 .60364 .57438 .61884 .56987 .61115 .56144 Mtetra
.656 .749 .918 r
.61115 .56144 .61884 .56987 .63412 .56537 .62649 .55689 Mtetra
.657 .749 .918 r
.62649 .55689 .63412 .56537 .64948 .56088 .64191 .55228 Mtetra
.657 .747 .917 r
.64191 .55228 .64948 .56088 .66493 .55638 .65741 .54765 Mtetra
.655 .745 .916 r
.65741 .54765 .66493 .55638 .68047 .55189 .673 .54307 Mtetra
.654 .743 .915 r
.673 .54307 .68047 .55189 .69609 .54737 .68869 .5385 Mtetra
.653 .743 .916 r
.68869 .5385 .69609 .54737 .7118 .54282 .70446 .53397 Mtetra
.652 .744 .917 r
.70446 .53397 .7118 .54282 .7276 .53821 .72032 .52942 Mtetra
.653 .747 .919 r
.72032 .52942 .7276 .53821 .74348 .53346 .73627 .5248 Mtetra
.655 .752 .921 r
.73627 .5248 .74348 .53346 .75943 .52856 .75231 .52008 Mtetra
.66 .76 .924 r
.75231 .52008 .75943 .52856 .77548 .52368 .76842 .5151 Mtetra
.661 .759 .923 r
.76842 .5151 .77548 .52368 .79164 .51898 .78461 .51008 Mtetra
.655 .75 .92 r
.78461 .51008 .79164 .51898 .80789 .51433 .80092 .50529 Mtetra
.652 .747 .919 r
.80092 .50529 .80789 .51433 .82423 .50965 .81733 .50057 Mtetra
.81733 .50057 .82423 .50965 .84066 .50483 .83383 .49582 Mtetra
.656 .751 .92 r
.83383 .49582 .84066 .50483 .85716 .49979 .85042 .49089 Mtetra
.66 .757 .922 r
.85042 .49089 .85716 .49979 .87376 .4948 .86708 .48575 Mtetra
.657 .753 .921 r
.86708 .48575 .87376 .4948 .89047 .48994 .88385 .48073 Mtetra
.654 .749 .92 r
.88385 .48073 .89047 .48994 .90729 .48513 .90073 .47582 Mtetra
.653 .748 .919 r
.90073 .47582 .90729 .48513 .9242 .4802 .91772 .47093 Mtetra
.657 .752 .92 r
.91772 .47093 .9242 .4802 .94118 .47505 .93479 .46583 Mtetra
.659 .754 .92 r
.32621 .63611 .33493 .64365 .34878 .63958 .34012 .63186 Mtetra
.659 .75 .917 r
.34012 .63186 .34878 .63958 .36271 .63532 .3541 .62757 Mtetra
.657 .75 .919 r
.3541 .62757 .36271 .63532 .37672 .63108 .36815 .62336 Mtetra
.65 .75 .922 r
.36815 .62336 .37672 .63108 .39079 .62695 .38226 .61933 Mtetra
.653 .754 .924 r
.38226 .61933 .39079 .62695 .40493 .62295 .39645 .61518 Mtetra
.659 .753 .919 r
.39645 .61518 .40493 .62295 .41916 .61874 .41073 .61079 Mtetra
.66 .75 .916 r
.41073 .61079 .41916 .61874 .43346 .61437 .42508 .60635 Mtetra
.657 .749 .917 r
.42508 .60635 .43346 .61437 .44784 .60997 .4395 .602 Mtetra
.649 .748 .922 r
.4395 .602 .44784 .60997 .46229 .60564 .454 .59791 Mtetra
.65 .756 .927 r
.454 .59791 .46229 .60564 .47682 .60155 .46858 .59373 Mtetra
.657 .757 .923 r
.46858 .59373 .47682 .60155 .49142 .59741 .48323 .58928 Mtetra
.66 .751 .917 r
.48323 .58928 .49142 .59741 .50611 .59302 .49797 .58473 Mtetra
.661 .748 .915 r
.49797 .58473 .50611 .59302 .52087 .58854 .51279 .58012 Mtetra
.659 .745 .914 r
.51279 .58012 .52087 .58854 .53572 .584 .52769 .57556 Mtetra
.654 .744 .916 r
.52769 .57556 .53572 .584 .55064 .57943 .54266 .57119 Mtetra
.651 .749 .922 r
.54266 .57119 .55064 .57943 .56565 .5749 .55772 .56687 Mtetra
.651 .756 .927 r
.55772 .56687 .56565 .5749 .58073 .57039 .57287 .56251 Mtetra
.652 .761 .93 r
.57287 .56251 .58073 .57039 .5959 .56592 .5881 .55806 Mtetra
.653 .764 .93 r
.5881 .55806 .5959 .56592 .61115 .56144 .60341 .55354 Mtetra
.655 .764 .93 r
.60341 .55354 .61115 .56144 .62649 .55689 .6188 .54895 Mtetra
.656 .765 .93 r
.6188 .54895 .62649 .55689 .64191 .55228 .63428 .54428 Mtetra
.657 .765 .929 r
.63428 .54428 .64191 .55228 .65741 .54765 .64984 .53954 Mtetra
.659 .764 .927 r
.64984 .53954 .65741 .54765 .673 .54307 .66549 .53472 Mtetra
.66 .759 .923 r
.66549 .53472 .673 .54307 .68869 .5385 .68122 .52984 Mtetra
.658 .752 .919 r
.68122 .52984 .68869 .5385 .70446 .53397 .69704 .52502 Mtetra
.653 .744 .916 r
.69704 .52502 .70446 .53397 .72032 .52942 .71296 .52038 Mtetra
.651 .743 .917 r
.71296 .52038 .72032 .52942 .73627 .5248 .72897 .51581 Mtetra
.652 .745 .918 r
.72897 .51581 .73627 .5248 .75231 .52008 .74508 .51116 Mtetra
.654 .749 .92 r
.74508 .51116 .75231 .52008 .76842 .5151 .76127 .50641 Mtetra
.66 .758 .923 r
.76127 .50641 .76842 .5151 .78461 .51008 .77754 .50138 Mtetra
.662 .76 .923 r
.77754 .50138 .78461 .51008 .80092 .50529 .79389 .49625 Mtetra
.655 .75 .92 r
.79389 .49625 .80092 .50529 .81733 .50057 .81036 .49139 Mtetra
.652 .747 .919 r
.81036 .49139 .81733 .50057 .83383 .49582 .82693 .4866 Mtetra
.653 .747 .919 r
.82693 .4866 .83383 .49582 .85042 .49089 .8436 .48177 Mtetra
.658 .753 .92 r
.8436 .48177 .85042 .49089 .86708 .48575 .86034 .47669 Mtetra
.66 .757 .922 r
.86034 .47669 .86708 .48575 .88385 .48073 .87716 .47147 Mtetra
.655 .751 .92 r
.87716 .47147 .88385 .48073 .90073 .47582 .89411 .46644 Mtetra
.653 .748 .92 r
.89411 .46644 .90073 .47582 .91772 .47093 .91117 .46148 Mtetra
.91117 .46148 .91772 .47093 .93479 .46583 .92832 .45647 Mtetra
.66 .751 .918 r
.31742 .6284 .32621 .63611 .34012 .63186 .33138 .62407 Mtetra
.658 .75 .918 r
.33138 .62407 .34012 .63186 .3541 .62757 .3454 .61979 Mtetra
.653 .75 .921 r
.3454 .61979 .3541 .62757 .36815 .62336 .35948 .61567 Mtetra
.65 .753 .924 r
.35948 .61567 .36815 .62336 .38226 .61933 .37364 .6116 Mtetra
.659 .755 .921 r
.37364 .6116 .38226 .61933 .39645 .61518 .38789 .60721 Mtetra
.661 .75 .917 r
.38789 .60721 .39645 .61518 .41073 .61079 .40222 .60274 Mtetra
.658 .749 .917 r
.40222 .60274 .41073 .61079 .42508 .60635 .41661 .59833 Mtetra
.65 .748 .922 r
.41661 .59833 .42508 .60635 .4395 .602 .43108 .59421 Mtetra
.65 .755 .926 r
.43108 .59421 .4395 .602 .454 .59791 .44562 .59003 Mtetra
.658 .756 .923 r
.44562 .59003 .454 .59791 .46858 .59373 .46026 .58555 Mtetra
.661 .751 .917 r
.46026 .58555 .46858 .59373 .48323 .58928 .47497 .58094 Mtetra
.662 .748 .914 r
.47497 .58094 .48323 .58928 .49797 .58473 .48976 .57629 Mtetra
.656 .745 .915 r
.48976 .57629 .49797 .58473 .51279 .58012 .50462 .57183 Mtetra
.648 .748 .922 r
.50462 .57183 .51279 .58012 .52769 .57556 .51957 .56762 Mtetra
.648 .757 .929 r
.51957 .56762 .52769 .57556 .54266 .57119 .5346 .56334 Mtetra
.653 .762 .93 r
.5346 .56334 .54266 .57119 .55772 .56687 .54972 .55888 Mtetra
.655 .76 .927 r
.54972 .55888 .55772 .56687 .57287 .56251 .56492 .5543 Mtetra
.656 .757 .924 r
.56492 .5543 .57287 .56251 .5881 .55806 .5802 .54968 Mtetra
.656 .753 .921 r
.5802 .54968 .5881 .55806 .60341 .55354 .59557 .54505 Mtetra
.656 .752 .92 r
.59557 .54505 .60341 .55354 .6188 .54895 .61102 .54041 Mtetra
.655 .751 .921 r
.61102 .54041 .6188 .54895 .63428 .54428 .62656 .53576 Mtetra
.655 .753 .922 r
.62656 .53576 .63428 .54428 .64984 .53954 .64218 .5311 Mtetra
.655 .756 .924 r
.64218 .5311 .64984 .53954 .66549 .53472 .6579 .5264 Mtetra
.657 .761 .926 r
.6579 .5264 .66549 .53472 .68122 .52984 .67369 .52158 Mtetra
.661 .765 .927 r
.67369 .52158 .68122 .52984 .69704 .52502 .68957 .51656 Mtetra
.662 .762 .924 r
.68957 .51656 .69704 .52502 .71296 .52038 .70553 .51149 Mtetra
.656 .75 .919 r
.70553 .51149 .71296 .52038 .72897 .51581 .7216 .50665 Mtetra
.651 .743 .917 r
.7216 .50665 .72897 .51581 .74508 .51116 .73777 .50201 Mtetra
.651 .744 .918 r
.73777 .50201 .74508 .51116 .76127 .50641 .75403 .49733 Mtetra
.654 .748 .919 r
.75403 .49733 .76127 .50641 .77754 .50138 .77038 .49251 Mtetra
.661 .758 .922 r
.77038 .49251 .77754 .50138 .79389 .49625 .7868 .48737 Mtetra
.661 .759 .922 r
.7868 .48737 .79389 .49625 .81036 .49139 .80332 .48218 Mtetra
.654 .749 .92 r
.80332 .48218 .81036 .49139 .82693 .4866 .81995 .47728 Mtetra
.652 .747 .919 r
.81995 .47728 .82693 .4866 .8436 .48177 .83669 .47243 Mtetra
.653 .748 .919 r
.83669 .47243 .8436 .48177 .86034 .47669 .85352 .46749 Mtetra
.66 .756 .921 r
.85352 .46749 .86034 .47669 .87716 .47147 .87042 .46223 Mtetra
.658 .755 .921 r
.87042 .46223 .87716 .47147 .89411 .46644 .88742 .457 Mtetra
.654 .75 .92 r
.88742 .457 .89411 .46644 .91117 .46148 .90454 .45193 Mtetra
.652 .748 .92 r
.90454 .45193 .91117 .46148 .92832 .45647 .92178 .44691 Mtetra
.659 .751 .917 r
.30855 .62059 .31742 .6284 .33138 .62407 .32255 .61623 Mtetra
.656 .75 .919 r
.32255 .61623 .33138 .62407 .3454 .61979 .33661 .61198 Mtetra
.65 .75 .923 r
.33661 .61198 .3454 .61979 .35948 .61567 .35074 .60791 Mtetra
.655 .754 .923 r
.35074 .60791 .35948 .61567 .37364 .6116 .36495 .60363 Mtetra
.66 .751 .917 r
.36495 .60363 .37364 .6116 .38789 .60721 .37925 .59915 Mtetra
.66 .75 .917 r
.37925 .59915 .38789 .60721 .40222 .60274 .39362 .59467 Mtetra
.652 .748 .92 r
.39362 .59467 .40222 .60274 .41661 .59833 .40806 .59044 Mtetra
.648 .753 .926 r
.40806 .59044 .41661 .59833 .43108 .59421 .42257 .58631 Mtetra
.657 .757 .923 r
.42257 .58631 .43108 .59421 .44562 .59003 .43717 .58183 Mtetra
.662 .751 .917 r
.43717 .58183 .44562 .59003 .46026 .58555 .45186 .57718 Mtetra
.662 .748 .914 r
.45186 .57718 .46026 .58555 .47497 .58094 .46662 .57249 Mtetra
.653 .745 .917 r
.46662 .57249 .47497 .58094 .48976 .57629 .48146 .56812 Mtetra
.646 .751 .926 r
.48146 .56812 .48976 .57629 .50462 .57183 .49637 .56395 Mtetra
.65 .76 .93 r
.49637 .56395 .50462 .57183 .51957 .56762 .51138 .55958 Mtetra
.656 .759 .926 r
.51138 .55958 .51957 .56762 .5346 .56334 .52646 .55497 Mtetra
.659 .753 .92 r
.52646 .55497 .5346 .56334 .54972 .55888 .54163 .55027 Mtetra
.661 .749 .915 r
.54163 .55027 .54972 .55888 .56492 .5543 .55688 .54546 Mtetra
.66 .744 .912 r
.55688 .54546 .56492 .5543 .5802 .54968 .57222 .54066 Mtetra
.658 .741 .911 r
.57222 .54066 .5802 .54968 .59557 .54505 .58764 .53592 Mtetra
.656 .739 .91 r
.58764 .53592 .59557 .54505 .61102 .54041 .60314 .53123 Mtetra
.654 .738 .911 r
.60314 .53123 .61102 .54041 .62656 .53576 .61874 .52659 Mtetra
.652 .738 .913 r
.61874 .52659 .62656 .53576 .64218 .5311 .63443 .52202 Mtetra
.651 .741 .916 r
.63443 .52202 .64218 .5311 .6579 .5264 .6502 .51746 Mtetra
.653 .747 .918 r
.6502 .51746 .6579 .5264 .67369 .52158 .66607 .51278 Mtetra
.655 .752 .921 r
.66607 .51278 .67369 .52158 .68957 .51656 .68202 .508 Mtetra
.66 .761 .925 r
.68202 .508 .68957 .51656 .70553 .51149 .69805 .50299 Mtetra
.664 .765 .925 r
.69805 .50299 .70553 .51149 .7216 .50665 .71416 .49777 Mtetra
.659 .755 .921 r
.71416 .49777 .7216 .50665 .73777 .50201 .73038 .49275 Mtetra
.65 .744 .918 r
.73038 .49275 .73777 .50201 .75403 .49733 .74671 .48804 Mtetra
.651 .745 .918 r
.74671 .48804 .75403 .49733 .77038 .49251 .76313 .4833 Mtetra
.654 .749 .92 r
.76313 .4833 .77038 .49251 .7868 .48737 .77964 .47839 Mtetra
.662 .759 .922 r
.77964 .47839 .7868 .48737 .80332 .48218 .79622 .4731 Mtetra
.659 .756 .922 r
.79622 .4731 .80332 .48218 .81995 .47728 .8129 .46791 Mtetra
.652 .748 .92 r
.8129 .46791 .81995 .47728 .83669 .47243 .82971 .46297 Mtetra
.652 .747 .92 r
.82971 .46297 .83669 .47243 .85352 .46749 .84661 .45804 Mtetra
.656 .75 .919 r
.84661 .45804 .85352 .46749 .87042 .46223 .8636 .45289 Mtetra
.661 .756 .921 r
.8636 .45289 .87042 .46223 .88742 .457 .88066 .4475 Mtetra
.656 .752 .921 r
.88066 .4475 .88742 .457 .90454 .45193 .89785 .44231 Mtetra
.653 .749 .92 r
.89785 .44231 .90454 .45193 .92178 .44691 .91515 .43722 Mtetra
.658 .75 .918 r
.29959 .6127 .30855 .62059 .32255 .61623 .31363 .60835 Mtetra
.653 .75 .921 r
.31363 .60835 .32255 .61623 .33661 .61198 .32773 .60416 Mtetra
.65 .752 .924 r
.32773 .60416 .33661 .61198 .35074 .60791 .3419 .60003 Mtetra
.659 .754 .92 r
.3419 .60003 .35074 .60791 .36495 .60363 .35617 .59556 Mtetra
.661 .751 .917 r
.35617 .59556 .36495 .60363 .37925 .59915 .37052 .59102 Mtetra
.656 .749 .918 r
.37052 .59102 .37925 .59915 .39362 .59467 .38493 .58662 Mtetra
.647 .75 .924 r
.38493 .58662 .39362 .59467 .40806 .59044 .39941 .5825 Mtetra
.654 .756 .924 r
.39941 .5825 .40806 .59044 .42257 .58631 .41398 .57811 Mtetra
.661 .752 .918 r
.41398 .57811 .42257 .58631 .43717 .58183 .42864 .57346 Mtetra
.663 .75 .915 r
.42864 .57346 .43717 .58183 .45186 .57718 .44337 .56872 Mtetra
.654 .746 .917 r
.44337 .56872 .45186 .57718 .46662 .57249 .45818 .5643 Mtetra
.645 .751 .926 r
.45818 .5643 .46662 .57249 .48146 .56812 .47307 .56016 Mtetra
.652 .76 .929 r
.47307 .56016 .48146 .56812 .49637 .56395 .48804 .55572 Mtetra
.659 .756 .922 r
.48804 .55572 .49637 .56395 .51138 .55958 .5031 .55102 Mtetra
.664 .751 .915 r
.5031 .55102 .51138 .55958 .52646 .55497 .51824 .54609 Mtetra
.664 .744 .91 r
.51824 .54609 .52646 .55497 .54163 .55027 .53346 .54114 Mtetra
.66 .739 .908 r
.53346 .54114 .54163 .55027 .55688 .54546 .54876 .53632 Mtetra
.655 .738 .911 r
.54876 .53632 .55688 .54546 .57222 .54066 .56415 .53171 Mtetra
.654 .743 .915 r
.56415 .53171 .57222 .54066 .58764 .53592 .57963 .5271 Mtetra
.656 .748 .918 r
.57963 .5271 .58764 .53592 .60314 .53123 .5952 .52236 Mtetra
.659 .749 .917 r
.5952 .52236 .60314 .53123 .61874 .52659 .61085 .5175 Mtetra
.658 .744 .914 r
.61085 .5175 .61874 .52659 .63443 .52202 .62658 .51263 Mtetra
.652 .737 .911 r
.62658 .51263 .63443 .52202 .6502 .51746 .64242 .50798 Mtetra
.648 .734 .912 r
.64242 .50798 .6502 .51746 .66607 .51278 .65835 .50345 Mtetra
.648 .739 .916 r
.65835 .50345 .66607 .51278 .68202 .508 .67437 .49891 Mtetra
.653 .747 .919 r
.67437 .49891 .68202 .508 .69805 .50299 .69048 .49413 Mtetra
.658 .756 .922 r
.69048 .49413 .69805 .50299 .71416 .49777 .70667 .48909 Mtetra
.665 .764 .924 r
.70667 .48909 .71416 .49777 .73038 .49275 .72293 .48373 Mtetra
.658 .755 .922 r
.72293 .48373 .73038 .49275 .74671 .48804 .73931 .47865 Mtetra
.649 .744 .919 r
.73931 .47865 .74671 .48804 .76313 .4833 .7558 .47391 Mtetra
.651 .746 .919 r
.7558 .47391 .76313 .4833 .77964 .47839 .77239 .46907 Mtetra
.657 .751 .919 r
.77239 .46907 .77964 .47839 .79622 .4731 .78905 .46395 Mtetra
.663 .759 .921 r
.78905 .46395 .79622 .4731 .8129 .46791 .80579 .45854 Mtetra
.655 .752 .921 r
.80579 .45854 .8129 .46791 .82971 .46297 .82265 .45343 Mtetra
.651 .747 .92 r
.82265 .45343 .82971 .46297 .84661 .45804 .83963 .44845 Mtetra
.653 .748 .92 r
.83963 .44845 .84661 .45804 .8636 .45289 .8567 .4434 Mtetra
.66 .755 .92 r
.8567 .4434 .8636 .45289 .88066 .4475 .87384 .43799 Mtetra
.658 .755 .921 r
.87384 .43799 .88066 .4475 .89785 .44231 .89109 .43262 Mtetra
.654 .75 .92 r
.89109 .43262 .89785 .44231 .91515 .43722 .90846 .42742 Mtetra
.657 .751 .919 r
.29054 .60475 .29959 .6127 .31363 .60835 .30462 .6004 Mtetra
.65 .75 .923 r
.30462 .6004 .31363 .60835 .32773 .60416 .31876 .59627 Mtetra
.654 .753 .923 r
.31876 .59627 .32773 .60416 .3419 .60003 .33299 .59196 Mtetra
.661 .752 .918 r
.33299 .59196 .3419 .60003 .35617 .59556 .34731 .5874 Mtetra
.66 .75 .917 r
.34731 .5874 .35617 .59556 .37052 .59102 .3617 .58285 Mtetra
.65 .749 .921 r
.3617 .58285 .37052 .59102 .38493 .58662 .37615 .57861 Mtetra
.649 .753 .926 r
.37615 .57861 .38493 .58662 .39941 .5825 .39068 .57438 Mtetra
.659 .754 .92 r
.39068 .57438 .39941 .5825 .41398 .57811 .40531 .56976 Mtetra
.664 .751 .915 r
.40531 .56976 .41398 .57811 .42864 .57346 .42002 .56497 Mtetra
.658 .747 .916 r
.42002 .56497 .42864 .57346 .44337 .56872 .4348 .56039 Mtetra
.644 .748 .925 r
.4348 .56039 .44337 .56872 .45818 .5643 .44965 .55626 Mtetra
.651 .758 .928 r
.44965 .55626 .45818 .5643 .47307 .56016 .46459 .55184 Mtetra
.66 .755 .921 r
.46459 .55184 .47307 .56016 .48804 .55572 .47962 .54708 Mtetra
.668 .751 .913 r
.47962 .54708 .48804 .55572 .5031 .55102 .49474 .54201 Mtetra
.664 .742 .908 r
.49474 .54201 .5031 .55102 .51824 .54609 .50993 .53704 Mtetra
.649 .738 .914 r
.50993 .53704 .51824 .54609 .53346 .54114 .52521 .53265 Mtetra
.644 .751 .927 r
.52521 .53265 .53346 .54114 .54876 .53632 .54057 .52835 Mtetra
.646 .766 .936 r
.54057 .52835 .54876 .53632 .56415 .53171 .55602 .52391 Mtetra
.65 .773 .938 r
.55602 .52391 .56415 .53171 .57963 .5271 .57156 .51929 Mtetra
.653 .775 .938 r
.57156 .51929 .57963 .5271 .5952 .52236 .58719 .51451 Mtetra
.657 .776 .936 r
.58719 .51451 .5952 .52236 .61085 .5175 .6029 .50955 Mtetra
.662 .776 .934 r
.6029 .50955 .61085 .5175 .62658 .51263 .6187 .50442 Mtetra
.665 .772 .929 r
.6187 .50442 .62658 .51263 .64242 .50798 .63457 .49914 Mtetra
.663 .757 .92 r
.63457 .49914 .64242 .50798 .65835 .50345 .65054 .49395 Mtetra
.648 .737 .914 r
.65054 .49395 .65835 .50345 .67437 .49891 .66663 .48935 Mtetra
.645 .736 .915 r
.66663 .48935 .67437 .49891 .69048 .49413 .68281 .48485 Mtetra
.652 .746 .919 r
.68281 .48485 .69048 .49413 .70667 .48909 .69908 .48003 Mtetra
.66 .756 .921 r
.69908 .48003 .70667 .48909 .72293 .48373 .71542 .47486 Mtetra
.666 .764 .923 r
.71542 .47486 .72293 .48373 .73931 .47865 .73184 .46939 Mtetra
.654 .751 .921 r
.73184 .46939 .73931 .47865 .7558 .47391 .74839 .46438 Mtetra
.649 .744 .919 r
.74839 .46438 .7558 .47391 .77239 .46907 .76505 .45958 Mtetra
.652 .748 .919 r
.76505 .45958 .77239 .46907 .78905 .46395 .78179 .45459 Mtetra
.661 .755 .92 r
.78179 .45459 .78905 .46395 .80579 .45854 .79861 .44921 Mtetra
.66 .757 .922 r
.79861 .44921 .80579 .45854 .82265 .45343 .81552 .44382 Mtetra
.652 .749 .92 r
.81552 .44382 .82265 .45343 .83963 .44845 .83256 .43876 Mtetra
.651 .748 .92 r
.83256 .43876 .83963 .44845 .8567 .4434 .84971 .43369 Mtetra
.657 .751 .919 r
.84971 .43369 .8567 .4434 .87384 .43799 .86694 .42836 Mtetra
.661 .756 .92 r
.86694 .42836 .87384 .43799 .89109 .43262 .88425 .42284 Mtetra
.655 .751 .921 r
.88425 .42284 .89109 .43262 .90846 .42742 .9017 .41754 Mtetra
.655 .751 .92 r
.2814 .59675 .29054 .60475 .30462 .6004 .29552 .59243 Mtetra
.649 .751 .924 r
.29552 .59243 .30462 .6004 .31876 .59627 .3097 .58827 Mtetra
.658 .754 .921 r
.3097 .58827 .31876 .59627 .33299 .59196 .32399 .58379 Mtetra
.661 .751 .917 r
.32399 .58379 .33299 .59196 .34731 .5874 .33835 .57918 Mtetra
.657 .75 .918 r
.33835 .57918 .34731 .5874 .3617 .58285 .35279 .57467 Mtetra
.647 .749 .924 r
.35279 .57467 .3617 .58285 .37615 .57861 .36728 .57051 Mtetra
.655 .755 .923 r
.36728 .57051 .37615 .57861 .39068 .57438 .38187 .56605 Mtetra
.662 .752 .917 r
.38187 .56605 .39068 .57438 .40531 .56976 .39655 .56128 Mtetra
.663 .75 .915 r
.39655 .56128 .40531 .56976 .42002 .56497 .41131 .55648 Mtetra
.647 .746 .922 r
.41131 .55648 .42002 .56497 .4348 .56039 .42613 .55224 Mtetra
.646 .755 .929 r
.42613 .55224 .4348 .56039 .44965 .55626 .44104 .54795 Mtetra
.659 .756 .922 r
.44104 .54795 .44965 .55626 .46459 .55184 .45604 .54321 Mtetra
.669 .752 .913 r
.45604 .54321 .46459 .55184 .47962 .54708 .47113 .53807 Mtetra
.664 .743 .909 r
.47113 .53807 .47962 .54708 .49474 .54201 .48629 .53307 Mtetra
.641 .739 .92 r
.48629 .53307 .49474 .54201 .50993 .53704 .50153 .52893 Mtetra
.638 .76 .936 r
.50153 .52893 .50993 .53704 .52521 .53265 .51687 .52478 Mtetra
.654 .772 .936 r
.51687 .52478 .52521 .53265 .54057 .52835 .53229 .52004 Mtetra
.655 .762 .928 r
.53229 .52004 .54057 .52835 .55602 .52391 .5478 .51524 Mtetra
.655 .755 .923 r
.5478 .51524 .55602 .52391 .57156 .51929 .56339 .51044 Mtetra
.656 .752 .92 r
.56339 .51044 .57156 .51929 .58719 .51451 .57908 .50561 Mtetra
.57908 .50561 .58719 .51451 .6029 .50955 .59485 .50073 Mtetra
.655 .755 .923 r
.59485 .50073 .6029 .50955 .6187 .50442 .61072 .49586 Mtetra
.655 .762 .928 r
.61072 .49586 .6187 .50442 .63457 .49914 .62667 .49093 Mtetra
.67 .777 .93 r
.62667 .49093 .63457 .49914 .65054 .49395 .6427 .4854 Mtetra
.67 .77 .925 r
.6427 .4854 .65054 .49395 .66663 .48935 .65881 .47985 Mtetra
.648 .741 .917 r
.65881 .47985 .66663 .48935 .68281 .48485 .67505 .47518 Mtetra
.644 .736 .916 r
.67505 .47518 .68281 .48485 .69908 .48003 .6914 .47064 Mtetra
.653 .747 .919 r
.6914 .47064 .69908 .48003 .71542 .47486 .70782 .4657 Mtetra
.664 .758 .921 r
.70782 .4657 .71542 .47486 .73184 .46939 .72431 .46029 Mtetra
.664 .761 .922 r
.72431 .46029 .73184 .46939 .74839 .46438 .7409 .45482 Mtetra
.649 .746 .92 r
.7409 .45482 .74839 .46438 .76505 .45958 .75762 .44994 Mtetra
.65 .745 .919 r
.75762 .44994 .76505 .45958 .78179 .45459 .77445 .445 Mtetra
.657 .751 .919 r
.77445 .445 .78179 .45459 .79861 .44921 .79135 .43976 Mtetra
.664 .758 .92 r
.79135 .43976 .79861 .44921 .81552 .44382 .80832 .43419 Mtetra
.654 .751 .921 r
.80832 .43419 .81552 .44382 .83256 .43876 .82543 .42897 Mtetra
.651 .748 .92 r
.82543 .42897 .83256 .43876 .84971 .43369 .84265 .42386 Mtetra
.654 .749 .92 r
.84265 .42386 .84971 .43369 .86694 .42836 .85997 .41861 Mtetra
.661 .755 .92 r
.85997 .41861 .86694 .42836 .88425 .42284 .87735 .413 Mtetra
.657 .753 .921 r
.87735 .413 .88425 .42284 .9017 .41754 .89486 .40757 Mtetra
.653 .75 .921 r
.27216 .58868 .2814 .59675 .29552 .59243 .28633 .58439 Mtetra
.651 .752 .924 r
.28633 .58439 .29552 .59243 .3097 .58827 .30056 .58014 Mtetra
.66 .753 .919 r
.30056 .58014 .3097 .58827 .32399 .58379 .31489 .57555 Mtetra
.661 .751 .917 r
.31489 .57555 .32399 .58379 .33835 .57918 .32931 .57089 Mtetra
.653 .75 .92 r
.32931 .57089 .33835 .57918 .35279 .57467 .34378 .56649 Mtetra
.647 .752 .925 r
.34378 .56649 .35279 .57467 .36728 .57051 .35833 .56227 Mtetra
.659 .754 .92 r
.35833 .56227 .36728 .57051 .38187 .56605 .37297 .5576 Mtetra
.664 .752 .916 r
.37297 .5576 .38187 .56605 .39655 .56128 .3877 .55273 Mtetra
.656 .748 .918 r
.3877 .55273 .39655 .56128 .41131 .55648 .40251 .54811 Mtetra
.642 .75 .927 r
.40251 .54811 .41131 .55648 .42613 .55224 .41737 .54397 Mtetra
.655 .757 .925 r
.41737 .54397 .42613 .55224 .44104 .54795 .43234 .53935 Mtetra
.666 .753 .915 r
.43234 .53935 .44104 .54795 .45604 .54321 .4474 .53428 Mtetra
.668 .747 .91 r
.4474 .53428 .45604 .54321 .47113 .53807 .46254 .5291 Mtetra
.641 .739 .92 r
.46254 .5291 .47113 .53807 .48629 .53307 .47775 .52493 Mtetra
.637 .76 .937 r
.47775 .52493 .48629 .53307 .50153 .52893 .49305 .52078 Mtetra
.655 .766 .931 r
.49305 .52078 .50153 .52893 .51687 .52478 .50844 .51598 Mtetra
.656 .751 .92 r
.50844 .51598 .51687 .52478 .53229 .52004 .52392 .51117 Mtetra
.667 .755 .916 r
.52392 .51117 .53229 .52004 .5478 .51524 .53948 .50592 Mtetra
.654 .741 .914 r
.53948 .50592 .5478 .51524 .56339 .51044 .55513 .50114 Mtetra
.656 .743 .914 r
.55513 .50114 .56339 .51044 .57908 .50561 .57088 .49625 Mtetra
.658 .744 .913 r
.57088 .49625 .57908 .50561 .59485 .50073 .58671 .49126 Mtetra
.645 .738 .916 r
.58671 .49126 .59485 .50073 .61072 .49586 .60264 .48674 Mtetra
.656 .751 .92 r
.60264 .48674 .61072 .49586 .62667 .49093 .61866 .48177 Mtetra
.655 .751 .921 r
.61866 .48177 .62667 .49093 .6427 .4854 .63477 .4768 Mtetra
.671 .771 .925 r
.63477 .4768 .6427 .4854 .65881 .47985 .65094 .47116 Mtetra
.669 .77 .925 r
.65094 .47116 .65881 .47985 .67505 .47518 .66721 .46554 Mtetra
.644 .739 .919 r
.66721 .46554 .67505 .47518 .6914 .47064 .68362 .46094 Mtetra
.646 .74 .918 r
.68362 .46094 .6914 .47064 .70782 .4657 .70012 .45624 Mtetra
.657 .751 .919 r
.70012 .45624 .70782 .4657 .72431 .46029 .7167 .45106 Mtetra
.668 .762 .921 r
.7167 .45106 .72431 .46029 .7409 .45482 .73335 .44539 Mtetra
.655 .754 .922 r
.73335 .44539 .7409 .45482 .75762 .44994 .75012 .4402 Mtetra
.648 .745 .92 r
.75012 .4402 .75762 .44994 .77445 .445 .76702 .43528 Mtetra
.653 .748 .92 r
.76702 .43528 .77445 .445 .79135 .43976 .784 .43014 Mtetra
.663 .756 .919 r
.784 .43014 .79135 .43976 .80832 .43419 .80105 .42453 Mtetra
.658 .755 .921 r
.80105 .42453 .80832 .43419 .82543 .42897 .81821 .4191 Mtetra
.651 .748 .921 r
.81821 .4191 .82543 .42897 .84265 .42386 .83551 .41393 Mtetra
.652 .748 .92 r
.83551 .41393 .84265 .42386 .85997 .41861 .85291 .40869 Mtetra
.66 .754 .919 r
.85291 .40869 .85997 .41861 .87735 .413 .87037 .40307 Mtetra
.658 .754 .921 r
.87037 .40307 .87735 .413 .89486 .40757 .88795 .3975 Mtetra
.651 .75 .922 r
.26284 .58053 .27216 .58868 .28633 .58439 .27704 .57626 Mtetra
.653 .752 .922 r
.27704 .57626 .28633 .58439 .30056 .58014 .29133 .57189 Mtetra
.661 .752 .918 r
.29133 .57189 .30056 .58014 .31489 .57555 .30571 .56722 Mtetra
.66 .751 .918 r
.30571 .56722 .31489 .57555 .32931 .57089 .32017 .56255 Mtetra
.65 .749 .922 r
.32017 .56255 .32931 .57089 .34378 .56649 .33468 .55823 Mtetra
.65 .752 .924 r
.33468 .55823 .34378 .56649 .35833 .56227 .34928 .55385 Mtetra
.661 .753 .918 r
.34928 .55385 .35833 .56227 .37297 .5576 .36398 .54907 Mtetra
.664 .752 .915 r
.36398 .54907 .37297 .5576 .3877 .55273 .37877 .54413 Mtetra
.649 .747 .921 r
.37877 .54413 .3877 .55273 .40251 .54811 .39361 .53975 Mtetra
.645 .753 .928 r
.39361 .53975 .40251 .54811 .41737 .54397 .40853 .53545 Mtetra
.66 .754 .92 r
.40853 .53545 .41737 .54397 .43234 .53935 .42355 .53059 Mtetra
.671 .753 .912 r
.42355 .53059 .43234 .53935 .4474 .53428 .43867 .52527 Mtetra
.653 .743 .916 r
.43867 .52527 .4474 .53428 .46254 .5291 .45386 .52065 Mtetra
.631 .751 .934 r
.45386 .52065 .46254 .5291 .47775 .52493 .46911 .51672 Mtetra
.655 .765 .931 r
.46911 .51672 .47775 .52493 .49305 .52078 .48447 .51191 Mtetra
.663 .753 .917 r
.48447 .51191 .49305 .52078 .50844 .51598 .49992 .50681 Mtetra
.646 .742 .919 r
.49992 .50681 .50844 .51598 .52392 .51117 .51546 .50233 Mtetra
.564 .721 .947 r
.51546 .50233 .52392 .51117 .53948 .50592 .53109 .50037 Mtetra
.476 .778 .997 r
.53109 .50037 .53948 .50592 .55513 .50114 .54684 .49889 Mtetra
.548 .895 .98 r
.54684 .49889 .55513 .50114 .57088 .49625 .56267 .49396 Mtetra
.707 .942 .959 r
.56267 .49396 .57088 .49625 .58671 .49126 .57854 .48557 Mtetra
.726 .859 .944 r
.57854 .48557 .58671 .49126 .60264 .48674 .59448 .47764 Mtetra
.665 .757 .919 r
.59448 .47764 .60264 .48674 .61866 .48177 .61055 .47224 Mtetra
.649 .743 .918 r
.61055 .47224 .61866 .48177 .63477 .4768 .62673 .46747 Mtetra
.656 .751 .92 r
.62673 .46747 .63477 .4768 .65094 .47116 .64299 .46239 Mtetra
.677 .772 .923 r
.64299 .46239 .65094 .47116 .66721 .46554 .65932 .45642 Mtetra
.659 .759 .924 r
.65932 .45642 .66721 .46554 .68362 .46094 .67576 .45115 Mtetra
.641 .738 .919 r
.67576 .45115 .68362 .46094 .70012 .45624 .69234 .44659 Mtetra
.652 .747 .92 r
.69234 .44659 .70012 .45624 .7167 .45106 .709 .44155 Mtetra
.665 .757 .919 r
.709 .44155 .7167 .45106 .73335 .44539 .72572 .43594 Mtetra
.662 .758 .921 r
.72572 .43594 .73335 .44539 .75012 .4402 .74254 .43042 Mtetra
.648 .746 .921 r
.74254 .43042 .75012 .4402 .76702 .43528 .75951 .42545 Mtetra
.651 .748 .92 r
.75951 .42545 .76702 .43528 .784 .43014 .77657 .42032 Mtetra
.66 .753 .919 r
.77657 .42032 .784 .43014 .80105 .42453 .7937 .41476 Mtetra
.661 .756 .92 r
.7937 .41476 .80105 .42453 .81821 .4191 .81092 .40915 Mtetra
.652 .749 .921 r
.81092 .40915 .81821 .4191 .83551 .41393 .82829 .40389 Mtetra
.651 .748 .921 r
.82829 .40389 .83551 .41393 .85291 .40869 .84576 .39862 Mtetra
.658 .752 .919 r
.84576 .39862 .85291 .40869 .87037 .40307 .86331 .39302 Mtetra
.66 .754 .92 r
.86331 .39302 .87037 .40307 .88795 .3975 .88096 .38732 Mtetra
.65 .75 .923 r
.25342 .57231 .26284 .58053 .27704 .57626 .26766 .56803 Mtetra
.655 .752 .921 r
.26766 .56803 .27704 .57626 .29133 .57189 .282 .56356 Mtetra
.661 .752 .918 r
.282 .56356 .29133 .57189 .30571 .56722 .29643 .55883 Mtetra
.659 .751 .918 r
.29643 .55883 .30571 .56722 .32017 .56255 .31094 .55414 Mtetra
.647 .749 .923 r
.31094 .55414 .32017 .56255 .33468 .55823 .3255 .54985 Mtetra
.653 .752 .923 r
.3255 .54985 .33468 .55823 .34928 .55385 .34015 .54533 Mtetra
.663 .753 .917 r
.34015 .54533 .34928 .55385 .36398 .54907 .3549 .54044 Mtetra
.663 .751 .916 r
.3549 .54044 .36398 .54907 .37877 .54413 .36973 .53551 Mtetra
.643 .747 .924 r
.36973 .53551 .37877 .54413 .39361 .53975 .38462 .53126 Mtetra
.65 .753 .925 r
.38462 .53126 .39361 .53975 .40853 .53545 .3996 .52675 Mtetra
.665 .754 .916 r
.3996 .52675 .40853 .53545 .42355 .53059 .41468 .52165 Mtetra
.67 .751 .911 r
.41468 .52165 .42355 .53059 .43867 .52527 .42985 .51632 Mtetra
.637 .742 .924 r
.42985 .51632 .43867 .52527 .45386 .52065 .44508 .51222 Mtetra
.642 .757 .932 r
.44508 .51222 .45386 .52065 .46911 .51672 .4604 .50785 Mtetra
.656 .752 .92 r
.4604 .50785 .46911 .51672 .48447 .51191 .47581 .50298 Mtetra
.653 .751 .921 r
.47581 .50298 .48447 .51191 .49992 .50681 .49132 .4982 Mtetra
.406 .657 .961 r
.49132 .4982 .49992 .50681 .51546 .50233 .50688 .49965 Mtetra
.325 0 0 r
.50688 .49965 .51546 .50233 .53109 .50037 .52258 .50611 Mtetra
.502 0 0 r
.52258 .50611 .53109 .50037 .54684 .49889 .53848 .51057 Mtetra
.266 0 0 r
.53848 .51057 .54684 .49889 .56267 .49396 .55447 .50562 Mtetra
0 0 0 r
.55447 .50562 .56267 .49396 .57854 .48557 .57043 .49121 Mtetra
.684 .943 .663 r
.57043 .49121 .57854 .48557 .59448 .47764 .58635 .47474 Mtetra
.797 .941 .921 r
.58635 .47474 .59448 .47764 .61055 .47224 .60237 .46326 Mtetra
.658 .761 .926 r
.60237 .46326 .61055 .47224 .62673 .46747 .6186 .45806 Mtetra
.655 .751 .92 r
.6186 .45806 .62673 .46747 .64299 .46239 .63493 .45294 Mtetra
.667 .756 .917 r
.63493 .45294 .64299 .46239 .65932 .45642 .65134 .44732 Mtetra
.673 .767 .921 r
.65134 .44732 .65932 .45642 .67576 .45115 .66783 .44141 Mtetra
.641 .742 .922 r
.66783 .44141 .67576 .45115 .69234 .44659 .68447 .43675 Mtetra
.647 .743 .92 r
.68447 .43675 .69234 .44659 .709 .44155 .7012 .43186 Mtetra
.661 .753 .918 r
.7012 .43186 .709 .44155 .72572 .43594 .718 .42636 Mtetra
.667 .759 .919 r
.718 .42636 .72572 .43594 .74254 .43042 .73489 .42058 Mtetra
.649 .748 .922 r
.73489 .42058 .74254 .43042 .75951 .42545 .75192 .4155 Mtetra
.649 .747 .921 r
.75192 .4155 .75951 .42545 .77657 .42032 .76905 .41037 Mtetra
.658 .752 .919 r
.76905 .41037 .77657 .42032 .7937 .41476 .78626 .40486 Mtetra
.663 .756 .919 r
.78626 .40486 .7937 .41476 .81092 .40915 .80356 .3991 Mtetra
.653 .75 .921 r
.80356 .3991 .81092 .40915 .82829 .40389 .82099 .39375 Mtetra
.651 .748 .921 r
.82099 .39375 .82829 .40389 .84576 .39862 .83854 .38844 Mtetra
.657 .751 .92 r
.83854 .38844 .84576 .39862 .86331 .39302 .85618 .38284 Mtetra
.661 .754 .919 r
.85618 .38284 .86331 .39302 .88096 .38732 .8739 .37704 Mtetra
.649 .75 .923 r
.2439 .56401 .25342 .57231 .26766 .56803 .25819 .55971 Mtetra
.656 .752 .921 r
.25819 .55971 .26766 .56803 .282 .56356 .27258 .55515 Mtetra
.661 .752 .918 r
.27258 .55515 .282 .56356 .29643 .55883 .28706 .55036 Mtetra
.658 .751 .919 r
.28706 .55036 .29643 .55883 .31094 .55414 .30161 .54566 Mtetra
.646 .749 .924 r
.30161 .54566 .31094 .55414 .3255 .54985 .31621 .54136 Mtetra
.655 .752 .921 r
.31621 .54136 .3255 .54985 .34015 .54533 .33092 .53672 Mtetra
.664 .753 .917 r
.33092 .53672 .34015 .54533 .3549 .54044 .34573 .53175 Mtetra
.661 .751 .917 r
.34573 .53175 .3549 .54044 .36973 .53551 .36061 .52686 Mtetra
.641 .748 .926 r
.36061 .52686 .36973 .53551 .38462 .53126 .37554 .52263 Mtetra
.654 .753 .923 r
.37554 .52263 .38462 .53126 .3996 .52675 .39057 .51794 Mtetra
.669 .754 .915 r
.39057 .51794 .3996 .52675 .41468 .52165 .40572 .51266 Mtetra
.664 .75 .914 r
.40572 .51266 .41468 .52165 .42985 .51632 .42094 .50752 Mtetra
.629 .745 .931 r
.42094 .50752 .42985 .51632 .44508 .51222 .43621 .50359 Mtetra
.652 .757 .927 r
.43621 .50359 .44508 .51222 .4604 .50785 .45159 .49886 Mtetra
.667 .754 .916 r
.45159 .49886 .4604 .50785 .47581 .50298 .46707 .49353 Mtetra
.549 .703 .941 r
.46707 .49353 .47581 .50298 .49132 .4982 .48258 .49206 Mtetra
0 .202 .637 r
.48258 .49206 .49132 .4982 .50688 .49965 .49813 .50194 Mtetra
.779 .308 .118 r
.49813 .50194 .50688 .49965 .52258 .50611 .51387 .5214 Mtetra
.685 .291 .294 r
.51387 .5214 .52258 .50611 .53848 .51057 .52994 .53645 Mtetra
.428 .087 .283 r
.52994 .53645 .53848 .51057 .55447 .50562 .54616 .5315 Mtetra
0 0 .09 r
.54616 .5315 .55447 .50562 .57043 .49121 .56226 .50645 Mtetra
0 0 0 r
.56226 .50645 .57043 .49121 .58635 .47474 .57818 .47684 Mtetra
.892 .989 .777 r
.57818 .47684 .58635 .47474 .60237 .46326 .59416 .45678 Mtetra
.74 .847 .93 r
.59416 .45678 .60237 .46326 .6186 .45806 .61038 .44812 Mtetra
.645 .738 .916 r
.61038 .44812 .6186 .45806 .63493 .45294 .62678 .44336 Mtetra
.659 .752 .919 r
.62678 .44336 .63493 .45294 .65134 .44732 .64327 .438 Mtetra
.679 .766 .917 r
.64327 .438 .65134 .44732 .66783 .44141 .65982 .4318 Mtetra
.647 .75 .924 r
.65982 .4318 .66783 .44141 .68447 .43675 .67651 .42685 Mtetra
.643 .743 .921 r
.67651 .42685 .68447 .43675 .7012 .43186 .69332 .42203 Mtetra
.658 .751 .919 r
.69332 .42203 .7012 .43186 .718 .42636 .7102 .41661 Mtetra
.668 .758 .918 r
.7102 .41661 .718 .42636 .73489 .42058 .72715 .4107 Mtetra
.651 .75 .922 r
.72715 .4107 .73489 .42058 .75192 .4155 .74424 .40547 Mtetra
.648 .747 .921 r
.74424 .40547 .75192 .4155 .76905 .41037 .76145 .40032 Mtetra
.656 .751 .92 r
.76145 .40032 .76905 .41037 .78626 .40486 .77874 .39482 Mtetra
.664 .756 .918 r
.77874 .39482 .78626 .40486 .80356 .3991 .79611 .38896 Mtetra
.653 .751 .921 r
.79611 .38896 .80356 .3991 .82099 .39375 .81361 .38352 Mtetra
.651 .749 .921 r
.81361 .38352 .82099 .39375 .83854 .38844 .83124 .37815 Mtetra
.656 .751 .92 r
.83124 .37815 .83854 .38844 .85618 .38284 .84896 .37253 Mtetra
.661 .754 .919 r
.84896 .37253 .85618 .38284 .8739 .37704 .86675 .36665 Mtetra
.649 .75 .923 r
.23429 .55563 .2439 .56401 .25819 .55971 .24863 .55128 Mtetra
.656 .752 .92 r
.24863 .55128 .25819 .55971 .27258 .55515 .26306 .54666 Mtetra
.661 .753 .918 r
.26306 .54666 .27258 .55515 .28706 .55036 .27759 .54182 Mtetra
.658 .752 .919 r
.27759 .54182 .28706 .55036 .30161 .54566 .29219 .5371 Mtetra
.646 .749 .924 r
.29219 .5371 .30161 .54566 .31621 .54136 .30684 .53276 Mtetra
.656 .752 .92 r
.30684 .53276 .31621 .54136 .33092 .53672 .3216 .52804 Mtetra
.664 .753 .917 r
.3216 .52804 .33092 .53672 .34573 .53175 .33646 .523 Mtetra
.659 .752 .919 r
.33646 .523 .34573 .53175 .36061 .52686 .35138 .51813 Mtetra
.641 .748 .926 r
.35138 .51813 .36061 .52686 .37554 .52263 .36636 .51386 Mtetra
.656 .752 .921 r
.36636 .51386 .37554 .52263 .39057 .51794 .38146 .50905 Mtetra
.67 .755 .914 r
.38146 .50905 .39057 .51794 .40572 .51266 .39666 .50366 Mtetra
.66 .751 .917 r
.39666 .50366 .40572 .51266 .42094 .50752 .41192 .49865 Mtetra
.628 .745 .932 r
.41192 .49865 .42094 .50752 .43621 .50359 .42724 .49471 Mtetra
.655 .755 .923 r
.42724 .49471 .43621 .50359 .45159 .49886 .44268 .4898 Mtetra
.665 .754 .917 r
.44268 .4898 .45159 .49886 .46707 .49353 .45822 .48449 Mtetra
.388 .641 .956 r
.45822 .48449 .46707 .49353 .48258 .49206 .47373 .48633 Mtetra
.647 .108 0 r
.47373 .48633 .48258 .49206 .49813 .50194 .48925 .50217 Mtetra
.855 .421 .184 r
.48925 .50217 .49813 .50194 .51387 .5214 .50497 .53226 Mtetra
.76 .352 .278 r
.50497 .53226 .51387 .5214 .52994 .53645 .52113 .55454 Mtetra
.362 0 .161 r
.52113 .55454 .52994 .53645 .54616 .5315 .53755 .54957 Mtetra
0 0 0 r
.53755 .54957 .54616 .5315 .56226 .50645 .55384 .51723 Mtetra
.939 .916 .538 r
.55384 .51723 .56226 .50645 .57818 .47684 .56984 .47687 Mtetra
.95 .931 .744 r
.56984 .47687 .57818 .47684 .59416 .45678 .58585 .4507 Mtetra
.805 .866 .894 r
.58585 .4507 .59416 .45678 .61038 .44812 .60208 .43859 Mtetra
.646 .75 .925 r
.60208 .43859 .61038 .44812 .62678 .44336 .61855 .4337 Mtetra
.656 .752 .92 r
.61855 .4337 .62678 .44336 .64327 .438 .6351 .42842 Mtetra
.68 .763 .914 r
.6351 .42842 .64327 .438 .65982 .4318 .65172 .42212 Mtetra
.652 .752 .923 r
.65172 .42212 .65982 .4318 .67651 .42685 .66847 .41692 Mtetra
.642 .744 .923 r
.66847 .41692 .67651 .42685 .69332 .42203 .68535 .41211 Mtetra
.656 .751 .92 r
.68535 .41211 .69332 .42203 .7102 .41661 .7023 .4067 Mtetra
.669 .757 .917 r
.7023 .4067 .7102 .41661 .72715 .4107 .71932 .40072 Mtetra
.653 .751 .922 r
.71932 .40072 .72715 .4107 .74424 .40547 .73649 .39536 Mtetra
.648 .748 .922 r
.73649 .39536 .74424 .40547 .76145 .40032 .75377 .39017 Mtetra
.655 .751 .92 r
.75377 .39017 .76145 .40032 .77874 .39482 .77113 .38464 Mtetra
.664 .755 .918 r
.77113 .38464 .77874 .39482 .79611 .38896 .78857 .37871 Mtetra
.654 .751 .921 r
.78857 .37871 .79611 .38896 .81361 .38352 .80615 .37318 Mtetra
.651 .749 .922 r
.80615 .37318 .81361 .38352 .83124 .37815 .82386 .36775 Mtetra
.655 .751 .92 r
.82386 .36775 .83124 .37815 .84896 .37253 .84165 .36209 Mtetra
.662 .754 .919 r
.84165 .36209 .84896 .37253 .86675 .36665 .85953 .35613 Mtetra
.649 .75 .923 r
.22458 .54715 .23429 .55563 .24863 .55128 .23896 .54276 Mtetra
.656 .752 .92 r
.23896 .54276 .24863 .55128 .26306 .54666 .25345 .53809 Mtetra
.661 .753 .918 r
.25345 .53809 .26306 .54666 .27759 .54182 .26802 .53321 Mtetra
.658 .752 .919 r
.26802 .53321 .27759 .54182 .29219 .5371 .28267 .52844 Mtetra
.646 .749 .924 r
.28267 .52844 .29219 .5371 .30684 .53276 .29737 .52405 Mtetra
.656 .752 .92 r
.29737 .52405 .30684 .53276 .3216 .52804 .31218 .51927 Mtetra
.664 .754 .917 r
.31218 .51927 .3216 .52804 .33646 .523 .32709 .51419 Mtetra
.659 .752 .919 r
.32709 .51419 .33646 .523 .35138 .51813 .34207 .50927 Mtetra
.641 .747 .926 r
.34207 .50927 .35138 .51813 .36636 .51386 .3571 .50495 Mtetra
.656 .751 .92 r
.3571 .50495 .36636 .51386 .38146 .50905 .37224 .50009 Mtetra
.67 .755 .914 r
.37224 .50009 .38146 .50905 .39666 .50366 .3875 .49465 Mtetra
.66 .752 .919 r
.3875 .49465 .39666 .50366 .41192 .49865 .40282 .48958 Mtetra
.628 .743 .93 r
.40282 .48958 .41192 .49865 .42724 .49471 .41819 .4856 Mtetra
.656 .751 .92 r
.41819 .4856 .42724 .49471 .44268 .4898 .43369 .48063 Mtetra
.665 .754 .917 r
.43369 .48063 .44268 .4898 .45822 .48449 .44928 .47527 Mtetra
.39 .64 .955 r
.44928 .47527 .45822 .48449 .47373 .48633 .46483 .47707 Mtetra
0 0 .503 r
.46483 .47707 .47373 .48633 .48925 .50217 .48035 .49291 Mtetra
.827 .374 0 r
.48035 .49291 .48925 .50217 .50497 .53226 .49604 .52304 Mtetra
.691 .204 0 r
.49604 .52304 .50497 .53226 .52113 .55454 .51219 .54534 Mtetra
.648 .76 .931 r
.51219 .54534 .52113 .55454 .53755 .54957 .52867 .54032 Mtetra
.909 .782 .709 r
.52867 .54032 .53755 .54957 .55384 .51723 .54509 .50785 Mtetra
.927 .773 .671 r
.54509 .50785 .55384 .51723 .56984 .47687 .56125 .46734 Mtetra
.89 .787 .741 r
.56125 .46734 .56984 .47687 .58585 .4507 .57738 .44106 Mtetra
.784 .786 .854 r
.57738 .44106 .58585 .4507 .60208 .43859 .59369 .42888 Mtetra
.646 .748 .923 r
.59369 .42888 .60208 .43859 .61855 .4337 .61022 .42393 Mtetra
.656 .751 .92 r
.61022 .42393 .61855 .4337 .6351 .42842 .62684 .41859 Mtetra
.679 .76 .912 r
.62684 .41859 .6351 .42842 .65172 .42212 .64353 .41223 Mtetra
.652 .75 .921 r
.64353 .41223 .65172 .42212 .66847 .41692 .66035 .40697 Mtetra
.641 .746 .925 r
.66035 .40697 .66847 .41692 .68535 .41211 .67729 .4021 Mtetra
.656 .751 .92 r
.67729 .4021 .68535 .41211 .7023 .4067 .69432 .39663 Mtetra
.669 .756 .916 r
.69432 .39663 .7023 .4067 .71932 .40072 .71141 .39059 Mtetra
.653 .75 .921 r
.71141 .39059 .71932 .40072 .73649 .39536 .72864 .38517 Mtetra
.648 .748 .923 r
.72864 .38517 .73649 .39536 .75377 .39017 .746 .37991 Mtetra
.655 .751 .92 r
.746 .37991 .75377 .39017 .77113 .38464 .76344 .37433 Mtetra
.664 .755 .918 r
.76344 .37433 .77113 .38464 .78857 .37871 .78095 .36833 Mtetra
.654 .751 .921 r
.78095 .36833 .78857 .37871 .80615 .37318 .79861 .36273 Mtetra
.651 .749 .922 r
.79861 .36273 .80615 .37318 .82386 .36775 .81639 .35724 Mtetra
.655 .751 .92 r
.81639 .35724 .82386 .36775 .84165 .36209 .83426 .35152 Mtetra
.662 .754 .919 r
.83426 .35152 .84165 .36209 .85953 .35613 .85222 .3455 Mtetra
.649 .75 .923 r
.21478 .53859 .22458 .54715 .23896 .54276 .2292 .53414 Mtetra
.656 .751 .92 r
.2292 .53414 .23896 .54276 .25345 .53809 .24373 .52944 Mtetra
.661 .753 .918 r
.24373 .52944 .25345 .53809 .26802 .53321 .25835 .52451 Mtetra
.658 .752 .919 r
.25835 .52451 .26802 .53321 .28267 .52844 .27305 .51966 Mtetra
.646 .748 .924 r
.27305 .51966 .28267 .52844 .29737 .52405 .2878 .51522 Mtetra
.655 .751 .92 r
.2878 .51522 .29737 .52405 .31218 .51927 .30266 .51044 Mtetra
.664 .754 .917 r
.30266 .51044 .31218 .51927 .32709 .51419 .31762 .50531 Mtetra
.661 .753 .919 r
.31762 .50531 .32709 .51419 .34207 .50927 .33265 .50027 Mtetra
.641 .746 .925 r
.33265 .50027 .34207 .50927 .3571 .50495 .34774 .4959 Mtetra
.654 .75 .92 r
.34774 .4959 .3571 .50495 .37224 .50009 .36293 .49106 Mtetra
.669 .755 .915 r
.36293 .49106 .37224 .50009 .3875 .49465 .37824 .48562 Mtetra
.664 .756 .918 r
.37824 .48562 .3875 .49465 .40282 .48958 .39362 .48032 Mtetra
.63 .741 .928 r
.39362 .48032 .40282 .48958 .41819 .4856 .40905 .47625 Mtetra
.652 .747 .919 r
.40905 .47625 .41819 .4856 .43369 .48063 .4246 .47136 Mtetra
.667 .754 .916 r
.4246 .47136 .43369 .48063 .44928 .47527 .44025 .46587 Mtetra
.545 .71 .947 r
.44025 .46587 .44928 .47527 .46483 .47707 .45591 .46426 Mtetra
.056 .356 .829 r
.45591 .46426 .46483 .47707 .48035 .49291 .47151 .47409 Mtetra
0 .104 .657 r
.47151 .47409 .48035 .49291 .49604 .52304 .48723 .49359 Mtetra
.278 .302 .707 r
.48723 .49359 .49604 .52304 .51219 .54534 .50332 .50863 Mtetra
.603 .481 .687 r
.50332 .50863 .51219 .54534 .52867 .54032 .51974 .50351 Mtetra
.734 .563 .661 r
.51974 .50351 .52867 .54032 .54509 .50785 .53618 .47814 Mtetra
.782 .611 .668 r
.53618 .47814 .54509 .50785 .56125 .46734 .55248 .44817 Mtetra
.788 .667 .73 r
.55248 .44817 .56125 .46734 .57738 .44106 .56877 .42782 Mtetra
.714 .706 .841 r
.56877 .42782 .57738 .44106 .59369 .42888 .58521 .41897 Mtetra
.645 .746 .923 r
.58521 .41897 .59369 .42888 .61022 .42393 .6018 .41404 Mtetra
.659 .752 .919 r
.6018 .41404 .61022 .42393 .62684 .41859 .61849 .4085 Mtetra
.678 .756 .91 r
.61849 .4085 .62684 .41859 .64353 .41223 .63524 .40213 Mtetra
.647 .746 .921 r
.63524 .40213 .64353 .41223 .66035 .40697 .65214 .397 Mtetra
.643 .748 .926 r
.65214 .397 .66035 .40697 .67729 .4021 .66915 .39201 Mtetra
.658 .753 .92 r
.66915 .39201 .67729 .4021 .69432 .39663 .68624 .3864 Mtetra
.668 .755 .915 r
.68624 .3864 .69432 .39663 .71141 .39059 .70341 .38031 Mtetra
.651 .749 .921 r
.70341 .38031 .71141 .39059 .72864 .38517 .72072 .37489 Mtetra
.648 .749 .923 r
.72072 .37489 .72864 .38517 .746 .37991 .73814 .36956 Mtetra
.656 .752 .92 r
.73814 .36956 .746 .37991 .76344 .37433 .75565 .36387 Mtetra
.664 .754 .917 r
.75565 .36387 .76344 .37433 .78095 .36833 .77325 .35782 Mtetra
.653 .75 .921 r
.77325 .35782 .78095 .36833 .79861 .36273 .79098 .35218 Mtetra
.651 .75 .922 r
.79098 .35218 .79861 .36273 .81639 .35724 .80884 .34662 Mtetra
.656 .752 .92 r
.80884 .34662 .81639 .35724 .83426 .35152 .82679 .34082 Mtetra
.661 .753 .918 r
.82679 .34082 .83426 .35152 .85222 .3455 .84483 .33474 Mtetra
.65 .75 .923 r
.20487 .52994 .21478 .53859 .2292 .53414 .21934 .52542 Mtetra
.655 .751 .92 r
.21934 .52542 .2292 .53414 .24373 .52944 .23391 .52071 Mtetra
.661 .753 .918 r
.23391 .52071 .24373 .52944 .25835 .52451 .24859 .51574 Mtetra
.659 .753 .919 r
.24859 .51574 .25835 .52451 .27305 .51966 .26334 .51081 Mtetra
.647 .749 .923 r
.26334 .51081 .27305 .51966 .2878 .51522 .27814 .50628 Mtetra
.653 .75 .92 r
.27814 .50628 .2878 .51522 .30266 .51044 .29304 .50151 Mtetra
.663 .754 .918 r
.29304 .50151 .30266 .51044 .31762 .50531 .30805 .49638 Mtetra
.663 .755 .918 r
.30805 .49638 .31762 .50531 .33265 .50027 .32314 .49119 Mtetra
.643 .747 .924 r
.32314 .49119 .33265 .50027 .34774 .4959 .33828 .4867 Mtetra
.65 .748 .921 r
.33828 .4867 .34774 .4959 .36293 .49106 .35352 .48194 Mtetra
.665 .755 .917 r
.35352 .48194 .36293 .49106 .37824 .48562 .36888 .47659 Mtetra
.671 .759 .917 r
.36888 .47659 .37824 .48562 .39362 .48032 .38433 .47099 Mtetra
.636 .744 .926 r
.38433 .47099 .39362 .48032 .40905 .47625 .39981 .46664 Mtetra
.644 .741 .92 r
.39981 .46664 .40905 .47625 .4246 .47136 .41541 .46201 Mtetra
.656 .752 .92 r
.41541 .46201 .4246 .47136 .44025 .46587 .43111 .45688 Mtetra
.653 .76 .929 r
.43111 .45688 .44025 .46587 .45591 .46426 .4469 .45183 Mtetra
.468 .609 .908 r
.4469 .45183 .45591 .46426 .47151 .47409 .46266 .45309 Mtetra
.398 .445 .792 r
.46266 .45309 .47151 .47409 .48723 .49359 .47851 .45943 Mtetra
.498 .421 .701 r
.47851 .45943 .48723 .49359 .50332 .50863 .49458 .46373 Mtetra
.593 .453 .66 r
.49458 .46373 .50332 .50863 .51974 .50351 .51088 .45851 Mtetra
.656 .495 .654 r
.51088 .45851 .51974 .50351 .53618 .47814 .52728 .4437 Mtetra
.696 .546 .679 r
.52728 .4437 .53618 .47814 .55248 .44817 .54366 .42681 Mtetra
.708 .615 .751 r
.54366 .42681 .55248 .44817 .56877 .42782 .56008 .41497 Mtetra
.655 .692 .872 r
.56008 .41497 .56877 .42782 .58521 .41897 .57664 .40948 Mtetra
.655 .761 .928 r
.57664 .40948 .58521 .41897 .6018 .41404 .59329 .40407 Mtetra
.667 .756 .917 r
.59329 .40407 .6018 .41404 .61849 .4085 .61004 .39815 Mtetra
.673 .751 .909 r
.61004 .39815 .61849 .4085 .63524 .40213 .62687 .39194 Mtetra
.641 .744 .924 r
.62687 .39194 .63524 .40213 .65214 .397 .64384 .387 Mtetra
.646 .752 .926 r
.64384 .387 .65214 .397 .66915 .39201 .66091 .3818 Mtetra
.661 .754 .919 r
.66091 .3818 .66915 .39201 .68624 .3864 .67807 .376 Mtetra
.667 .753 .915 r
.67807 .376 .68624 .3864 .70341 .38031 .69531 .36991 Mtetra
.649 .748 .922 r
.69531 .36991 .70341 .38031 .72072 .37489 .7127 .36453 Mtetra
.649 .75 .923 r
.7127 .36453 .72072 .37489 .73814 .36956 .7302 .3591 Mtetra
.658 .753 .92 r
.7302 .3591 .73814 .36956 .75565 .36387 .74778 .35327 Mtetra
.663 .753 .917 r
.74778 .35327 .75565 .36387 .77325 .35782 .76545 .34719 Mtetra
.653 .75 .921 r
.76545 .34719 .77325 .35782 .79098 .35218 .78327 .34153 Mtetra
.651 .75 .922 r
.78327 .34153 .79098 .35218 .80884 .34662 .8012 .33589 Mtetra
.657 .752 .92 r
.8012 .33589 .80884 .34662 .82679 .34082 .81923 .32998 Mtetra
.661 .753 .918 r
.81923 .32998 .82679 .34082 .84483 .33474 .83735 .32385 Mtetra
.651 .75 .922 r
.19485 .52119 .20487 .52994 .21934 .52542 .20938 .51659 Mtetra
.653 .75 .921 r
.20938 .51659 .21934 .52542 .23391 .52071 .22399 .5119 Mtetra
.661 .753 .919 r
.22399 .5119 .23391 .52071 .24859 .51574 .23871 .50689 Mtetra
.66 .753 .919 r
.23871 .50689 .24859 .51574 .26334 .51081 .25352 .50188 Mtetra
.65 .75 .923 r
.25352 .50188 .26334 .51081 .27814 .50628 .26837 .49722 Mtetra
.651 .748 .921 r
.26837 .49722 .27814 .50628 .29304 .50151 .28331 .4925 Mtetra
.661 .753 .919 r
.28331 .4925 .29304 .50151 .30805 .49638 .29837 .48737 Mtetra
.664 .756 .918 r
.29837 .48737 .30805 .49638 .32314 .49119 .31352 .48209 Mtetra
.649 .75 .924 r
.31352 .48209 .32314 .49119 .33828 .4867 .32872 .47735 Mtetra
.646 .745 .922 r
.32872 .47735 .33828 .4867 .35352 .48194 .34401 .47271 Mtetra
.66 .753 .919 r
.34401 .47271 .35352 .48194 .36888 .47659 .35941 .46749 Mtetra
.672 .76 .917 r
.35941 .46749 .36888 .47659 .38433 .47099 .37492 .4618 Mtetra
.652 .754 .924 r
.37492 .4618 .38433 .47099 .39981 .46664 .39049 .45681 Mtetra
.633 .735 .921 r
.39049 .45681 .39981 .46664 .41541 .46201 .40612 .45253 Mtetra
.656 .751 .92 r
.40612 .45253 .41541 .46201 .43111 .45688 .42188 .44736 Mtetra
.663 .754 .918 r
.42188 .44736 .43111 .45688 .4469 .45183 .43773 .44188 Mtetra
.646 .74 .918 r
.43773 .44188 .4469 .45183 .46266 .45309 .45367 .43703 Mtetra
.586 .609 .841 r
.45367 .43703 .46266 .45309 .47851 .45943 .46966 .43474 Mtetra
.575 .519 .755 r
.46966 .43474 .47851 .45943 .49458 .46373 .48576 .43294 Mtetra
.612 .507 .711 r
.48576 .43294 .49458 .46373 .51088 .45851 .50203 .42763 Mtetra
.646 .528 .706 r
.50203 .42763 .51088 .45851 .52728 .4437 .51839 .41878 Mtetra
.658 .565 .739 r
.51839 .41878 .52728 .4437 .54366 .42681 .53482 .41041 Mtetra
.651 .639 .824 r
.53482 .41041 .54366 .42681 .56008 .41497 .55134 .40461 Mtetra
.649 .741 .916 r
.55134 .40461 .56008 .41497 .57664 .40948 .56796 .39944 Mtetra
.656 .751 .92 r
.56796 .39944 .57664 .40948 .59329 .40407 .58469 .39395 Mtetra
.677 .758 .913 r
.58469 .39395 .59329 .40407 .61004 .39815 .60149 .38756 Mtetra
.659 .743 .912 r
.60149 .38756 .61004 .39815 .62687 .39194 .6184 .38188 Mtetra
.64 .749 .928 r
.6184 .38188 .62687 .39194 .64384 .387 .63545 .37692 Mtetra
.651 .755 .925 r
.63545 .37692 .64384 .387 .66091 .3818 .65259 .37147 Mtetra
.665 .755 .917 r
.65259 .37147 .66091 .3818 .67807 .376 .6698 .36543 Mtetra
.662 .75 .916 r
.6698 .36543 .67807 .376 .69531 .36991 .68713 .35947 Mtetra
.648 .749 .923 r
.68713 .35947 .69531 .36991 .7127 .36453 .70459 .35408 Mtetra
.651 .751 .923 r
.70459 .35408 .7127 .36453 .7302 .3591 .72216 .34852 Mtetra
.66 .754 .919 r
.72216 .34852 .7302 .3591 .74778 .35327 .73981 .34252 Mtetra
.661 .752 .917 r
.73981 .34252 .74778 .35327 .76545 .34719 .75757 .33646 Mtetra
.652 .75 .922 r
.75757 .33646 .76545 .34719 .78327 .34153 .77547 .33076 Mtetra
.651 .75 .922 r
.77547 .33076 .78327 .34153 .8012 .33589 .79348 .32505 Mtetra
.658 .753 .92 r
.79348 .32505 .8012 .33589 .81923 .32998 .81158 .31899 Mtetra
.66 .752 .918 r
.81158 .31899 .81923 .32998 .83735 .32385 .82978 .31283 Mtetra
.653 .751 .922 r
.18474 .51237 .19485 .52119 .20938 .51659 .19931 .50766 Mtetra
.651 .749 .921 r
.19931 .50766 .20938 .51659 .22399 .5119 .21397 .50299 Mtetra
.66 .753 .919 r
.21397 .50299 .22399 .5119 .23871 .50689 .22874 .49796 Mtetra
.661 .754 .919 r
.22874 .49796 .23871 .50689 .25352 .50188 .24359 .49287 Mtetra
.653 .751 .922 r
.24359 .49287 .25352 .50188 .26837 .49722 .2585 .48804 Mtetra
.648 .747 .922 r
.2585 .48804 .26837 .49722 .28331 .4925 .27349 .48338 Mtetra
.659 .753 .919 r
.27349 .48338 .28331 .4925 .29837 .48737 .2886 .47827 Mtetra
.664 .755 .918 r
.2886 .47827 .29837 .48737 .31352 .48209 .3038 .47293 Mtetra
.656 .753 .922 r
.3038 .47293 .31352 .48209 .32872 .47735 .31907 .46787 Mtetra
.643 .743 .922 r
.31907 .46787 .32872 .47735 .34401 .47271 .3344 .46328 Mtetra
.655 .75 .919 r
.3344 .46328 .34401 .47271 .35941 .46749 .34985 .45821 Mtetra
.666 .757 .918 r
.34985 .45821 .35941 .46749 .37492 .4618 .36541 .45266 Mtetra
.668 .762 .92 r
.36541 .45266 .37492 .4618 .39049 .45681 .38106 .44701 Mtetra
.641 .74 .921 r
.38106 .44701 .39049 .45681 .40612 .45253 .39675 .44238 Mtetra
.64 .733 .916 r
.39675 .44238 .40612 .45253 .42188 .44736 .41254 .43776 Mtetra
.656 .752 .921 r
.41254 .43776 .42188 .44736 .43773 .44188 .42845 .43248 Mtetra
.655 .758 .925 r
.42845 .43248 .43773 .44188 .45367 .43703 .44446 .42719 Mtetra
.667 .753 .915 r
.44446 .42719 .45367 .43703 .46966 .43474 .46057 .42144 Mtetra
.65 .681 .866 r
.46057 .42144 .46966 .43474 .48576 .43294 .47676 .41617 Mtetra
.643 .63 .821 r
.47676 .41617 .48576 .43294 .50203 .42763 .49305 .41079 Mtetra
.645 .63 .821 r
.49305 .41079 .50203 .42763 .51839 .41878 .50943 .40529 Mtetra
.643 .678 .869 r
.50943 .40529 .51839 .41878 .53482 .41041 .52592 .40028 Mtetra
.656 .749 .919 r
.52592 .40028 .53482 .41041 .55134 .40461 .54251 .3948 Mtetra
.655 .757 .925 r
.54251 .3948 .55134 .40461 .56796 .39944 .5592 .38931 Mtetra
.671 .757 .915 r
.5592 .38931 .56796 .39944 .58469 .39395 .57597 .38314 Mtetra
.669 .743 .906 r
.57597 .38314 .58469 .39395 .60149 .38756 .59285 .37699 Mtetra
.644 .74 .919 r
.59285 .37699 .60149 .38756 .6184 .38188 .60985 .37187 Mtetra
.645 .755 .929 r
.60985 .37187 .6184 .38188 .63545 .37692 .62696 .36664 Mtetra
.656 .754 .922 r
.62696 .36664 .63545 .37692 .65259 .37147 .64416 .36092 Mtetra
.668 .754 .915 r
.64416 .36092 .65259 .37147 .6698 .36543 .66144 .3547 Mtetra
.655 .747 .917 r
.66144 .3547 .6698 .36543 .68713 .35947 .67886 .34897 Mtetra
.648 .75 .924 r
.67886 .34897 .68713 .35947 .70459 .35408 .69639 .3435 Mtetra
.653 .752 .923 r
.69639 .3435 .70459 .35408 .72216 .34852 .71403 .3378 Mtetra
.663 .755 .918 r
.71403 .3378 .72216 .34852 .73981 .34252 .73175 .33163 Mtetra
.658 .75 .918 r
.73175 .33163 .73981 .34252 .75757 .33646 .7496 .32563 Mtetra
.651 .75 .922 r
.7496 .32563 .75757 .33646 .77547 .33076 .76757 .31988 Mtetra
.652 .751 .922 r
.76757 .31988 .77547 .33076 .79348 .32505 .78566 .31407 Mtetra
.66 .754 .919 r
.78566 .31407 .79348 .32505 .81158 .31899 .80384 .30787 Mtetra
.659 .751 .919 r
.80384 .30787 .81158 .31899 .82978 .31283 .82213 .3017 Mtetra
.655 .751 .921 r
.17451 .50346 .18474 .51237 .19931 .50766 .18914 .49862 Mtetra
.649 .748 .922 r
.18914 .49862 .19931 .50766 .21397 .50299 .20384 .49395 Mtetra
.658 .752 .919 r
.20384 .49395 .21397 .50299 .22874 .49796 .21865 .48895 Mtetra
.661 .754 .919 r
.21865 .48895 .22874 .49796 .24359 .49287 .23356 .48379 Mtetra
.657 .753 .92 r
.23356 .48379 .24359 .49287 .2585 .48804 .24854 .47875 Mtetra
.647 .747 .922 r
.24854 .47875 .2585 .48804 .27349 .48338 .26357 .47406 Mtetra
.655 .749 .919 r
.26357 .47406 .27349 .48338 .2886 .47827 .27871 .46906 Mtetra
.662 .755 .919 r
.27871 .46906 .2886 .47827 .3038 .47293 .29397 .46374 Mtetra
.663 .756 .92 r
.29397 .46374 .3038 .47293 .31907 .46787 .30931 .45837 Mtetra
.647 .746 .922 r
.30931 .45837 .31907 .46787 .3344 .46328 .3247 .45359 Mtetra
.647 .743 .919 r
.3247 .45359 .3344 .46328 .34985 .45821 .34018 .44875 Mtetra
.659 .753 .92 r
.34018 .44875 .34985 .45821 .36541 .45266 .35579 .44343 Mtetra
.669 .762 .92 r
.35579 .44343 .36541 .45266 .38106 .44701 .3715 .43771 Mtetra
.664 .761 .922 r
.3715 .43771 .38106 .44701 .39675 .44238 .38729 .43212 Mtetra
.641 .734 .916 r
.38729 .43212 .39675 .44238 .41254 .43776 .40313 .42742 Mtetra
.641 .733 .916 r
.40313 .42742 .41254 .43776 .42845 .43248 .41908 .4227 Mtetra
.655 .751 .921 r
.41908 .4227 .42845 .43248 .44446 .42719 .43514 .41736 Mtetra
.656 .752 .92 r
.43514 .41736 .44446 .42719 .46057 .42144 .4513 .41197 Mtetra
.655 .761 .927 r
.4513 .41197 .46057 .42144 .47676 .41617 .46756 .40657 Mtetra
.655 .759 .926 r
.46756 .40657 .47676 .41617 .49305 .41079 .48391 .40113 Mtetra
.656 .759 .926 r
.48391 .40113 .49305 .41079 .50943 .40529 .50037 .39564 Mtetra
.655 .761 .928 r
.50037 .39564 .50943 .40529 .52592 .40028 .51692 .39015 Mtetra
.656 .752 .92 r
.51692 .39015 .52592 .40028 .54251 .3948 .53357 .3846 Mtetra
.67 .756 .915 r
.53357 .3846 .54251 .3948 .5592 .38931 .55032 .37842 Mtetra
.67 .743 .905 r
.55032 .37842 .5592 .38931 .57597 .38314 .56717 .37222 Mtetra
.648 .736 .913 r
.56717 .37222 .57597 .38314 .59285 .37699 .58413 .36692 Mtetra
.642 .754 .93 r
.58413 .36692 .59285 .37699 .60985 .37187 .6012 .36175 Mtetra
.652 .758 .927 r
.6012 .36175 .60985 .37187 .62696 .36664 .61837 .35616 Mtetra
.664 .755 .918 r
.61837 .35616 .62696 .36664 .64416 .36092 .63563 .35008 Mtetra
.664 .749 .913 r
.63563 .35008 .64416 .36092 .66144 .3547 .65299 .34395 Mtetra
.649 .747 .921 r
.65299 .34395 .66144 .3547 .67886 .34897 .67049 .3384 Mtetra
.649 .752 .925 r
.67049 .3384 .67886 .34897 .69639 .3435 .6881 .33279 Mtetra
.657 .753 .921 r
.6881 .33279 .69639 .3435 .71403 .3378 .7058 .32686 Mtetra
.664 .753 .916 r
.7058 .32686 .71403 .3378 .73175 .33163 .7236 .3206 Mtetra
.654 .748 .919 r
.7236 .3206 .73175 .33163 .7496 .32563 .74153 .31469 Mtetra
.651 .75 .923 r
.74153 .31469 .7496 .32563 .76757 .31988 .75959 .30889 Mtetra
.654 .752 .922 r
.75959 .30889 .76757 .31988 .78566 .31407 .77775 .30292 Mtetra
.661 .753 .918 r
.77775 .30292 .78566 .31407 .80384 .30787 .796 .2966 Mtetra
.657 .75 .919 r
.796 .2966 .80384 .30787 .82213 .3017 .81439 .29044 Mtetra
.657 .752 .92 r
.16418 .49447 .17451 .50346 .18914 .49862 .17887 .48951 Mtetra
.65 .749 .922 r
.17887 .48951 .18914 .49862 .20384 .49395 .19361 .48476 Mtetra
.654 .749 .92 r
.19361 .48476 .20384 .49395 .21865 .48895 .20846 .47983 Mtetra
.661 .754 .919 r
.20846 .47983 .21865 .48895 .23356 .48379 .22342 .47464 Mtetra
.66 .754 .92 r
.22342 .47464 .23356 .48379 .24854 .47875 .23845 .46946 Mtetra
.65 .75 .922 r
.23845 .46946 .24854 .47875 .26357 .47406 .25355 .46459 Mtetra
.65 .747 .92 r
.25355 .46459 .26357 .47406 .27871 .46906 .26873 .45972 Mtetra
.66 .753 .92 r
.26873 .45972 .27871 .46906 .29397 .46374 .28403 .45445 Mtetra
.664 .757 .92 r
.28403 .45445 .29397 .46374 .30931 .45837 .29943 .449 Mtetra
.657 .754 .922 r
.29943 .449 .30931 .45837 .3247 .45359 .3149 .44375 Mtetra
.644 .742 .92 r
.3149 .44375 .3247 .45359 .34018 .44875 .33043 .43897 Mtetra
.651 .746 .919 r
.33043 .43897 .34018 .44875 .35579 .44343 .34607 .43389 Mtetra
.66 .755 .921 r
.34607 .43389 .35579 .44343 .3715 .43771 .36182 .42845 Mtetra
.668 .765 .923 r
.36182 .42845 .3715 .43771 .38729 .43212 .37768 .42268 Mtetra
.664 .761 .922 r
.37768 .42268 .38729 .43212 .40313 .42742 .39362 .41701 Mtetra
.648 .737 .914 r
.39362 .41701 .40313 .42742 .41908 .4227 .40963 .41194 Mtetra
.645 .729 .91 r
.40963 .41194 .41908 .4227 .43514 .41736 .42574 .40695 Mtetra
.648 .739 .916 r
.42574 .40695 .43514 .41736 .4513 .41197 .44195 .40182 Mtetra
.652 .747 .919 r
.44195 .40182 .4513 .41197 .46756 .40657 .45827 .39649 Mtetra
.656 .751 .92 r
.45827 .39649 .46756 .40657 .48391 .40113 .47468 .39099 Mtetra
.659 .753 .919 r
.47468 .39099 .48391 .40113 .50037 .39564 .4912 .38531 Mtetra
.663 .751 .915 r
.4912 .38531 .50037 .39564 .51692 .39015 .50782 .37943 Mtetra
.666 .745 .909 r
.50782 .37943 .51692 .39015 .53357 .3846 .52454 .3734 Mtetra
.663 .735 .904 r
.52454 .3734 .53357 .3846 .55032 .37842 .54135 .36746 Mtetra
.648 .736 .914 r
.54135 .36746 .55032 .37842 .56717 .37222 .55827 .36211 Mtetra
.643 .754 .93 r
.55827 .36211 .56717 .37222 .58413 .36692 .57531 .35688 Mtetra
.651 .76 .929 r
.57531 .35688 .58413 .36692 .6012 .36175 .59244 .3513 Mtetra
.66 .756 .921 r
.59244 .3513 .6012 .36175 .61837 .35616 .60967 .34535 Mtetra
.666 .752 .914 r
.60967 .34535 .61837 .35616 .63563 .35008 .627 .33909 Mtetra
.654 .745 .916 r
.627 .33909 .63563 .35008 .65299 .34395 .64446 .33329 Mtetra
.648 .751 .925 r
.64446 .33329 .65299 .34395 .67049 .3384 .66203 .32771 Mtetra
.652 .753 .924 r
.66203 .32771 .67049 .3384 .6881 .33279 .67971 .32193 Mtetra
.661 .755 .919 r
.67971 .32193 .6881 .33279 .7058 .32686 .69748 .31574 Mtetra
.661 .75 .916 r
.69748 .31574 .7058 .32686 .7236 .3206 .71536 .30953 Mtetra
.652 .749 .921 r
.71536 .30953 .7236 .3206 .74153 .31469 .73338 .30365 Mtetra
.651 .751 .923 r
.73338 .30365 .74153 .31469 .75959 .30889 .75151 .29776 Mtetra
.657 .753 .921 r
.75151 .29776 .75959 .30889 .77775 .30292 .76975 .29159 Mtetra
.661 .752 .918 r
.76975 .29159 .77775 .30292 .796 .2966 .78808 .28522 Mtetra
.655 .75 .92 r
.78808 .28522 .796 .2966 .81439 .29044 .80656 .27907 Mtetra
.658 .753 .92 r
.15374 .4854 .16418 .49447 .17887 .48951 .16848 .48034 Mtetra
.653 .751 .922 r
.16848 .48034 .17887 .48951 .19361 .48476 .18328 .47545 Mtetra
.651 .748 .921 r
.18328 .47545 .19361 .48476 .20846 .47983 .19816 .4706 Mtetra
.659 .753 .919 r
.19816 .4706 .20846 .47983 .22342 .47464 .21316 .46541 Mtetra
.661 .755 .92 r
.21316 .46541 .22342 .47464 .23845 .46946 .22826 .46013 Mtetra
.656 .753 .921 r
.22826 .46013 .23845 .46946 .25355 .46459 .24342 .45499 Mtetra
.648 .746 .921 r
.24342 .45499 .25355 .46459 .26873 .45972 .25865 .45015 Mtetra
.655 .749 .919 r
.25865 .45015 .26873 .45972 .28403 .45445 .27398 .44501 Mtetra
.661 .755 .92 r
.27398 .44501 .28403 .45445 .29943 .449 .28943 .4396 Mtetra
.663 .758 .921 r
.28943 .4396 .29943 .449 .3149 .44375 .30497 .43408 Mtetra
.653 .75 .921 r
.30497 .43408 .3149 .44375 .33043 .43897 .32058 .42891 Mtetra
.645 .741 .919 r
.32058 .42891 .33043 .43897 .34607 .43389 .33626 .42401 Mtetra
.653 .748 .92 r
.33626 .42401 .34607 .43389 .36182 .42845 .35205 .41879 Mtetra
.659 .756 .922 r
.35205 .41879 .36182 .42845 .37768 .42268 .36796 .41329 Mtetra
.664 .765 .925 r
.36796 .41329 .37768 .42268 .39362 .41701 .38396 .40756 Mtetra
.38396 .40756 .39362 .41701 .40963 .41194 .40006 .4018 Mtetra
.66 .75 .917 r
.40006 .4018 .40963 .41194 .42574 .40695 .41624 .39617 Mtetra
.654 .735 .909 r
.41624 .39617 .42574 .40695 .44195 .40182 .43252 .39074 Mtetra
.653 .731 .906 r
.43252 .39074 .44195 .40182 .45827 .39649 .44889 .38531 Mtetra
.656 .731 .905 r
.44889 .38531 .45827 .39649 .47468 .39099 .46537 .37975 Mtetra
.658 .731 .904 r
.46537 .37975 .47468 .39099 .4912 .38531 .48195 .37404 Mtetra
.657 .732 .905 r
.48195 .37404 .4912 .38531 .50782 .37943 .49862 .36833 Mtetra
.652 .735 .91 r
.49862 .36833 .50782 .37943 .52454 .3734 .5154 .36283 Mtetra
.648 .746 .921 r
.5154 .36283 .52454 .3734 .54135 .36746 .53229 .35746 Mtetra
.647 .759 .931 r
.53229 .35746 .54135 .36746 .55827 .36211 .54928 .35206 Mtetra
.652 .761 .929 r
.54928 .35206 .55827 .36211 .57531 .35688 .56638 .34641 Mtetra
.659 .756 .922 r
.56638 .34641 .57531 .35688 .59244 .3513 .58358 .34048 Mtetra
.666 .752 .915 r
.58358 .34048 .59244 .3513 .60967 .34535 .60088 .33422 Mtetra
.658 .745 .914 r
.60088 .33422 .60967 .34535 .627 .33909 .61829 .32824 Mtetra
.649 .748 .922 r
.61829 .32824 .627 .33909 .64446 .33329 .63582 .3226 Mtetra
.651 .754 .925 r
.63582 .3226 .64446 .33329 .66203 .32771 .65347 .31685 Mtetra
.657 .754 .922 r
.65347 .31685 .66203 .32771 .67971 .32193 .67121 .31081 Mtetra
.663 .753 .917 r
.67121 .31081 .67971 .32193 .69748 .31574 .68905 .30446 Mtetra
.655 .748 .918 r
.68905 .30446 .69748 .31574 .71536 .30953 .70703 .29841 Mtetra
.651 .751 .922 r
.70703 .29841 .71536 .30953 .73338 .30365 .72512 .29249 Mtetra
.652 .752 .923 r
.72512 .29249 .73338 .30365 .75151 .29776 .74334 .28648 Mtetra
.66 .754 .92 r
.74334 .28648 .75151 .29776 .76975 .29159 .76164 .2801 Mtetra
.659 .75 .918 r
.76164 .2801 .76975 .29159 .78808 .28522 .78007 .27375 Mtetra
.654 .75 .921 r
.78007 .27375 .78808 .28522 .80656 .27907 .79863 .26757 Mtetra
.659 .754 .92 r
.14318 .47626 .15374 .4854 .16848 .48034 .15797 .4711 Mtetra
.656 .752 .921 r
.15797 .4711 .16848 .48034 .18328 .47545 .17284 .46604 Mtetra
.65 .748 .921 r
.17284 .46604 .18328 .47545 .19816 .4706 .18776 .46117 Mtetra
.655 .75 .919 r
.18776 .46117 .19816 .4706 .21316 .46541 .2028 .45607 Mtetra
.66 .754 .92 r
.2028 .45607 .21316 .46541 .22826 .46013 .21794 .45075 Mtetra
.21794 .45075 .22826 .46013 .24342 .45499 .23317 .44543 Mtetra
.652 .75 .921 r
.23317 .44543 .24342 .45499 .25865 .45015 .24846 .44036 Mtetra
.648 .745 .92 r
.24846 .44036 .25865 .45015 .27398 .44501 .26384 .4354 Mtetra
.658 .753 .92 r
.26384 .4354 .27398 .44501 .28943 .4396 .27933 .43006 Mtetra
.662 .757 .921 r
.27933 .43006 .28943 .4396 .30497 .43408 .29492 .42454 Mtetra
.662 .758 .921 r
.29492 .42454 .30497 .43408 .32058 .42891 .31061 .41897 Mtetra
.653 .748 .92 r
.31061 .41897 .32058 .42891 .33626 .42401 .32636 .41373 Mtetra
.647 .74 .917 r
.32636 .41373 .33626 .42401 .35205 .41879 .3422 .40868 Mtetra
.651 .746 .919 r
.3422 .40868 .35205 .41879 .36796 .41329 .35814 .40343 Mtetra
.657 .755 .922 r
.35814 .40343 .36796 .41329 .38396 .40756 .37419 .39792 Mtetra
.659 .761 .926 r
.37419 .39792 .38396 .40756 .40006 .4018 .39035 .39231 Mtetra
.661 .767 .928 r
.39035 .39231 .40006 .4018 .41624 .39617 .4066 .38657 Mtetra
.66 .765 .928 r
.4066 .38657 .41624 .39617 .43252 .39074 .42295 .38084 Mtetra
.658 .759 .925 r
.42295 .38084 .43252 .39074 .44889 .38531 .43939 .37516 Mtetra
.656 .755 .923 r
.43939 .37516 .44889 .38531 .46537 .37975 .45593 .36953 Mtetra
.654 .754 .923 r
.45593 .36953 .46537 .37975 .48195 .37404 .47257 .36395 Mtetra
.651 .757 .927 r
.47257 .36395 .48195 .37404 .49862 .36833 .48931 .35842 Mtetra
.65 .762 .931 r
.48931 .35842 .49862 .36833 .5154 .36283 .50616 .35291 Mtetra
.652 .764 .931 r
.50616 .35291 .5154 .36283 .53229 .35746 .52311 .34726 Mtetra
.654 .76 .927 r
.52311 .34726 .53229 .35746 .54928 .35206 .54018 .3415 Mtetra
.66 .756 .921 r
.54018 .3415 .54928 .35206 .56638 .34641 .55734 .33549 Mtetra
.664 .751 .915 r
.55734 .33549 .56638 .34641 .58358 .34048 .57461 .32925 Mtetra
.659 .744 .913 r
.57461 .32925 .58358 .34048 .60088 .33422 .59198 .32321 Mtetra
.65 .747 .92 r
.59198 .32321 .60088 .33422 .61829 .32824 .60948 .3175 Mtetra
.65 .754 .925 r
.60948 .3175 .61829 .32824 .63582 .3226 .62708 .31174 Mtetra
.654 .754 .923 r
.62708 .31174 .63582 .3226 .65347 .31685 .6448 .30579 Mtetra
.663 .755 .919 r
.6448 .30579 .65347 .31685 .67121 .31081 .66261 .29944 Mtetra
.659 .749 .916 r
.66261 .29944 .67121 .31081 .68905 .30446 .68054 .29319 Mtetra
.652 .749 .921 r
.68054 .29319 .68905 .30446 .70703 .29841 .6986 .2872 Mtetra
.651 .752 .923 r
.6986 .2872 .70703 .29841 .72512 .29249 .71677 .2812 Mtetra
.656 .753 .922 r
.71677 .2812 .72512 .29249 .74334 .28648 .73506 .27496 Mtetra
.661 .752 .918 r
.73506 .27496 .74334 .28648 .76164 .2801 .75344 .26847 Mtetra
.656 .749 .919 r
.75344 .26847 .76164 .2801 .78007 .27375 .77196 .26217 Mtetra
.653 .751 .922 r
.77196 .26217 .78007 .27375 .79863 .26757 .79061 .25597 Mtetra
.66 .754 .92 r
.13251 .46702 .14318 .47626 .15797 .4711 .14735 .46179 Mtetra
.658 .753 .92 r
.14735 .46179 .15797 .4711 .17284 .46604 .16227 .4566 Mtetra
.653 .75 .921 r
.16227 .4566 .17284 .46604 .18776 .46117 .17726 .45158 Mtetra
.651 .747 .92 r
.17726 .45158 .18776 .46117 .2028 .45607 .19233 .4466 Mtetra
.659 .753 .92 r
.19233 .4466 .2028 .45607 .21794 .45075 .20752 .44128 Mtetra
.66 .755 .92 r
.20752 .44128 .21794 .45075 .23317 .44543 .2228 .43587 Mtetra
.658 .754 .921 r
.2228 .43587 .23317 .44543 .24846 .44036 .23817 .43051 Mtetra
.65 .746 .92 r
.23817 .43051 .24846 .44036 .26384 .4354 .2536 .42545 Mtetra
.65 .746 .919 r
.2536 .42545 .26384 .4354 .27933 .43006 .26912 .42033 Mtetra
.658 .754 .921 r
.26912 .42033 .27933 .43006 .29492 .42454 .28476 .41488 Mtetra
.661 .757 .921 r
.28476 .41488 .29492 .42454 .31061 .41897 .3005 .40928 Mtetra
.661 .758 .922 r
.3005 .40928 .31061 .41897 .32636 .41373 .31633 .40364 Mtetra
.655 .749 .919 r
.31633 .40364 .32636 .41373 .3422 .40868 .33225 .3982 Mtetra
.648 .74 .916 r
.33225 .3982 .3422 .40868 .35814 .40343 .34824 .39299 Mtetra
.649 .742 .918 r
.34824 .39299 .35814 .40343 .37419 .39792 .36434 .38772 Mtetra
.654 .75 .921 r
.36434 .38772 .37419 .39792 .39035 .39231 .38054 .38225 Mtetra
.656 .755 .923 r
.38054 .38225 .39035 .39231 .4066 .38657 .39685 .37664 Mtetra
.656 .76 .926 r
.39685 .37664 .4066 .38657 .42295 .38084 .41326 .37099 Mtetra
.656 .763 .928 r
.41326 .37099 .42295 .38084 .43939 .37516 .42976 .36531 Mtetra
.655 .764 .929 r
.42976 .36531 .43939 .37516 .45593 .36953 .44637 .35962 Mtetra
.655 .763 .929 r
.44637 .35962 .45593 .36953 .47257 .36395 .46308 .35391 Mtetra
.655 .762 .929 r
.46308 .35391 .47257 .36395 .48931 .35842 .47989 .34818 Mtetra
.655 .759 .926 r
.47989 .34818 .48931 .35842 .50616 .35291 .49681 .3424 Mtetra
.658 .756 .922 r
.49681 .3424 .50616 .35291 .52311 .34726 .51384 .33649 Mtetra
.662 .753 .918 r
.51384 .33649 .52311 .34726 .54018 .3415 .53097 .33036 Mtetra
.663 .747 .913 r
.53097 .33036 .54018 .3415 .55734 .33549 .5482 .32416 Mtetra
.656 .742 .913 r
.5482 .32416 .55734 .33549 .57461 .32925 .56554 .3182 Mtetra
.65 .747 .92 r
.56554 .3182 .57461 .32925 .59198 .32321 .58299 .31244 Mtetra
.65 .755 .926 r
.58299 .31244 .59198 .32321 .60948 .3175 .60056 .30663 Mtetra
.653 .755 .924 r
.60056 .30663 .60948 .3175 .62708 .31174 .61824 .30067 Mtetra
.661 .755 .92 r
.61824 .30067 .62708 .31174 .6448 .30579 .63602 .29436 Mtetra
.661 .749 .915 r
.63602 .29436 .6448 .30579 .66261 .29944 .65391 .28798 Mtetra
.653 .747 .918 r
.65391 .28798 .66261 .29944 .68054 .29319 .67193 .28191 Mtetra
.651 .751 .923 r
.67193 .28191 .68054 .29319 .6986 .2872 .69007 .27587 Mtetra
.653 .753 .923 r
.69007 .27587 .6986 .2872 .71677 .2812 .70832 .26974 Mtetra
.66 .754 .92 r
.70832 .26974 .71677 .2812 .73506 .27496 .72668 .26324 Mtetra
.659 .75 .917 r
.72668 .26324 .73506 .27496 .75344 .26847 .74515 .25678 Mtetra
.654 .75 .92 r
.74515 .25678 .75344 .26847 .77196 .26217 .76376 .25048 Mtetra
.652 .751 .922 r
.76376 .25048 .77196 .26217 .79061 .25597 .7825 .24422 Mtetra
.659 .753 .92 r
.12172 .45766 .13251 .46702 .14735 .46179 .13661 .45241 Mtetra
.659 .754 .92 r
.13661 .45241 .14735 .46179 .16227 .4566 .15159 .44711 Mtetra
.656 .752 .92 r
.15159 .44711 .16227 .4566 .17726 .45158 .16664 .44189 Mtetra
.65 .748 .921 r
.16664 .44189 .17726 .45158 .19233 .4466 .18176 .43686 Mtetra
.653 .748 .92 r
.18176 .43686 .19233 .4466 .20752 .44128 .19698 .43169 Mtetra
.66 .754 .92 r
.19698 .43169 .20752 .44128 .2228 .43587 .21232 .42626 Mtetra
.66 .755 .921 r
.21232 .42626 .2228 .43587 .23817 .43051 .22774 .42077 Mtetra
.657 .753 .921 r
.22774 .42077 .23817 .43051 .2536 .42545 .24325 .41537 Mtetra
.649 .745 .919 r
.24325 .41537 .2536 .42545 .26912 .42033 .25882 .41023 Mtetra
.651 .746 .919 r
.25882 .41023 .26912 .42033 .28476 .41488 .27449 .40499 Mtetra
.658 .754 .921 r
.27449 .40499 .28476 .41488 .3005 .40928 .29028 .39947 Mtetra
.66 .757 .922 r
.29028 .39947 .3005 .40928 .31633 .40364 .30617 .39382 Mtetra
.661 .759 .922 r
.30617 .39382 .31633 .40364 .33225 .3982 .32216 .3881 Mtetra
.659 .754 .92 r
.32216 .3881 .33225 .3982 .34824 .39299 .33824 .38242 Mtetra
.653 .743 .916 r
.33824 .38242 .34824 .39299 .36434 .38772 .3544 .37694 Mtetra
.651 .739 .914 r
.3544 .37694 .36434 .38772 .38054 .38225 .37065 .37152 Mtetra
.652 .742 .916 r
.37065 .37152 .38054 .38225 .39685 .37664 .38701 .36602 Mtetra
.653 .746 .918 r
.38701 .36602 .39685 .37664 .41326 .37099 .40348 .36044 Mtetra
.655 .749 .92 r
.40348 .36044 .41326 .37099 .42976 .36531 .42005 .35476 Mtetra
.656 .751 .92 r
.42005 .35476 .42976 .36531 .44637 .35962 .43672 .34901 Mtetra
.657 .752 .92 r
.43672 .34901 .44637 .35962 .46308 .35391 .45349 .34317 Mtetra
.658 .751 .918 r
.45349 .34317 .46308 .35391 .47989 .34818 .47038 .33724 Mtetra
.66 .748 .916 r
.47038 .33724 .47989 .34818 .49681 .3424 .48736 .33121 Mtetra
.66 .745 .913 r
.48736 .33121 .49681 .3424 .51384 .33649 .50445 .32511 Mtetra
.658 .742 .912 r
.50445 .32511 .51384 .33649 .53097 .33036 .52165 .31907 Mtetra
.653 .743 .916 r
.52165 .31907 .53097 .33036 .5482 .32416 .53896 .31321 Mtetra
.651 .751 .923 r
.53896 .31321 .5482 .32416 .56554 .3182 .55637 .30741 Mtetra
.652 .756 .926 r
.55637 .30741 .56554 .3182 .58299 .31244 .5739 .30152 Mtetra
.654 .755 .924 r
.5739 .30152 .58299 .31244 .60056 .30663 .59154 .29551 Mtetra
.66 .755 .92 r
.59154 .29551 .60056 .30663 .61824 .30067 .60928 .2892 Mtetra
.662 .75 .915 r
.60928 .2892 .61824 .30067 .63602 .29436 .62714 .28277 Mtetra
.654 .746 .917 r
.62714 .28277 .63602 .29436 .65391 .28798 .64512 .27662 Mtetra
.652 .751 .922 r
.64512 .27662 .65391 .28798 .67193 .28191 .66322 .27053 Mtetra
.652 .753 .923 r
.66322 .27053 .67193 .28191 .69007 .27587 .68144 .26439 Mtetra
.658 .754 .921 r
.68144 .26439 .69007 .27587 .70832 .26974 .69976 .25797 Mtetra
.66 .751 .917 r
.69976 .25797 .70832 .26974 .72668 .26324 .7182 .2514 Mtetra
.655 .749 .919 r
.7182 .2514 .72668 .26324 .74515 .25678 .73676 .24501 Mtetra
.653 .751 .922 r
.73676 .24501 .74515 .25678 .76376 .25048 .75546 .23869 Mtetra
.653 .752 .922 r
.75546 .23869 .76376 .25048 .7825 .24422 .77428 .2323 Mtetra
.655 .75 .92 r
.11084 .44808 .12172 .45766 .13661 .45241 .12576 .44293 Mtetra
.66 .754 .92 r
.12576 .44293 .13661 .45241 .15159 .44711 .14079 .43756 Mtetra
.658 .753 .92 r
.14079 .43756 .15159 .44711 .16664 .44189 .1559 .43222 Mtetra
.655 .751 .921 r
.1559 .43222 .16664 .44189 .18176 .43686 .17108 .42698 Mtetra
.65 .747 .92 r
.17108 .42698 .18176 .43686 .19698 .43169 .18634 .42186 Mtetra
.655 .751 .92 r
.18634 .42186 .19698 .43169 .21232 .42626 .20171 .41653 Mtetra
.66 .755 .921 r
.20171 .41653 .21232 .42626 .22774 .42077 .21719 .411 Mtetra
.21719 .411 .22774 .42077 .24325 .41537 .23276 .40544 Mtetra
.657 .753 .92 r
.23276 .40544 .24325 .41537 .25882 .41023 .24841 .39995 Mtetra
.65 .744 .919 r
.24841 .39995 .25882 .41023 .27449 .40499 .26414 .3947 Mtetra
.65 .745 .919 r
.26414 .3947 .27449 .40499 .29028 .39947 .27996 .38939 Mtetra
.657 .753 .921 r
.27996 .38939 .29028 .39947 .30617 .39382 .2959 .38381 Mtetra
.659 .757 .922 r
.2959 .38381 .30617 .39382 .32216 .3881 .31194 .37812 Mtetra
.66 .759 .923 r
.31194 .37812 .32216 .3881 .33824 .38242 .32808 .37236 Mtetra
.66 .758 .923 r
.32808 .37236 .33824 .38242 .3544 .37694 .34432 .36656 Mtetra
.658 .752 .92 r
.34432 .36656 .3544 .37694 .37065 .37152 .36065 .36079 Mtetra
.657 .746 .916 r
.36065 .36079 .37065 .37152 .38701 .36602 .37708 .35503 Mtetra
.655 .741 .913 r
.37708 .35503 .38701 .36602 .40348 .36044 .3936 .34931 Mtetra
.655 .74 .912 r
.3936 .34931 .40348 .36044 .42005 .35476 .41023 .34356 Mtetra
.656 .74 .912 r
.41023 .34356 .42005 .35476 .43672 .34901 .42697 .33774 Mtetra
.657 .74 .912 r
.42697 .33774 .43672 .34901 .45349 .34317 .44381 .33184 Mtetra
.656 .741 .912 r
.44381 .33184 .45349 .34317 .47038 .33724 .46075 .32591 Mtetra
.655 .741 .913 r
.46075 .32591 .47038 .33724 .48736 .33121 .4778 .32001 Mtetra
.653 .745 .917 r
.4778 .32001 .48736 .33121 .50445 .32511 .49496 .31414 Mtetra
.652 .75 .922 r
.49496 .31414 .50445 .32511 .52165 .31907 .51223 .30828 Mtetra
.652 .756 .926 r
.51223 .30828 .52165 .31907 .53896 .31321 .5296 .30239 Mtetra
.653 .757 .926 r
.5296 .30239 .53896 .31321 .55637 .30741 .54709 .29641 Mtetra
.655 .755 .924 r
.54709 .29641 .55637 .30741 .5739 .30152 .56469 .29032 Mtetra
.661 .755 .92 r
.56469 .29032 .5739 .30152 .59154 .29551 .5824 .28395 Mtetra
.661 .749 .915 r
.5824 .28395 .59154 .29551 .60928 .2892 .60022 .27752 Mtetra
.655 .746 .917 r
.60022 .27752 .60928 .2892 .62714 .28277 .61816 .27132 Mtetra
.652 .751 .922 r
.61816 .27132 .62714 .28277 .64512 .27662 .63622 .26519 Mtetra
.652 .753 .923 r
.63622 .26519 .64512 .27662 .66322 .27053 .6544 .25901 Mtetra
.656 .754 .922 r
.6544 .25901 .66322 .27053 .68144 .26439 .67269 .25263 Mtetra
.661 .753 .918 r
.67269 .25263 .68144 .26439 .69976 .25797 .69109 .24602 Mtetra
.657 .749 .918 r
.69109 .24602 .69976 .25797 .7182 .2514 .70962 .23953 Mtetra
.654 .751 .921 r
.70962 .23953 .7182 .2514 .73676 .24501 .72828 .23313 Mtetra
.652 .751 .922 r
.72828 .23313 .73676 .24501 .75546 .23869 .74706 .22674 Mtetra
.657 .754 .921 r
.74706 .22674 .75546 .23869 .77428 .2323 .76596 .22013 Mtetra
.652 .748 .92 r
.09984 .43838 .11084 .44808 .12576 .44293 .11479 .43327 Mtetra
.657 .752 .92 r
.11479 .43327 .12576 .44293 .14079 .43756 .12986 .42794 Mtetra
.66 .754 .92 r
.12986 .42794 .14079 .43756 .1559 .43222 .14503 .42249 Mtetra
.657 .753 .92 r
.14503 .42249 .1559 .43222 .17108 .42698 .16028 .41708 Mtetra
.653 .75 .92 r
.16028 .41708 .17108 .42698 .18634 .42186 .1756 .4118 Mtetra
.651 .747 .92 r
.1756 .4118 .18634 .42186 .20171 .41653 .191 .40658 Mtetra
.656 .752 .92 r
.191 .40658 .20171 .41653 .21719 .411 .20652 .40112 Mtetra
.659 .755 .921 r
.20652 .40112 .21719 .411 .23276 .40544 .22215 .39551 Mtetra
.22215 .39551 .23276 .40544 .24841 .39995 .23786 .38986 Mtetra
.657 .753 .92 r
.23786 .38986 .24841 .39995 .26414 .3947 .25367 .38426 Mtetra
.652 .745 .918 r
.25367 .38426 .26414 .3947 .27996 .38939 .26955 .37885 Mtetra
.651 .744 .918 r
.26955 .37885 .27996 .38939 .2959 .38381 .28553 .37344 Mtetra
.654 .75 .92 r
.28553 .37344 .2959 .38381 .31194 .37812 .30161 .36788 Mtetra
.657 .755 .922 r
.30161 .36788 .31194 .37812 .32808 .37236 .31781 .36216 Mtetra
.658 .757 .923 r
.31781 .36216 .32808 .37236 .34432 .36656 .3341 .35637 Mtetra
.658 .759 .924 r
.3341 .35637 .34432 .36656 .36065 .36079 .3505 .35054 Mtetra
.3505 .35054 .36065 .36079 .37708 .35503 .36699 .34466 Mtetra
.657 .758 .924 r
.36699 .34466 .37708 .35503 .3936 .34931 .38359 .33878 Mtetra
.657 .755 .923 r
.38359 .33878 .3936 .34931 .41023 .34356 .40029 .3329 Mtetra
.656 .754 .922 r
.40029 .3329 .41023 .34356 .42697 .33774 .41709 .32701 Mtetra
.655 .754 .922 r
.41709 .32701 .42697 .33774 .44381 .33184 .43399 .32111 Mtetra
.654 .755 .924 r
.43399 .32111 .44381 .33184 .46075 .32591 .45101 .31521 Mtetra
.653 .756 .925 r
.45101 .31521 .46075 .32591 .4778 .32001 .46812 .30929 Mtetra
.654 .758 .926 r
.46812 .30929 .4778 .32001 .49496 .31414 .48535 .30334 Mtetra
.654 .757 .926 r
.48535 .30334 .49496 .31414 .51223 .30828 .50269 .29734 Mtetra
.655 .756 .925 r
.50269 .29734 .51223 .30828 .5296 .30239 .52014 .29127 Mtetra
.658 .755 .922 r
.52014 .29127 .5296 .30239 .54709 .29641 .5377 .28503 Mtetra
.661 .752 .918 r
.5377 .28503 .54709 .29641 .56469 .29032 .55538 .27863 Mtetra
.66 .747 .915 r
.55538 .27863 .56469 .29032 .5824 .28395 .57316 .27223 Mtetra
.654 .746 .917 r
.57316 .27223 .5824 .28395 .60022 .27752 .59106 .26602 Mtetra
.652 .751 .922 r
.59106 .26602 .60022 .27752 .61816 .27132 .60908 .25984 Mtetra
.652 .753 .924 r
.60908 .25984 .61816 .27132 .63622 .26519 .62722 .25362 Mtetra
.655 .754 .923 r
.62722 .25362 .63622 .26519 .6544 .25901 .64547 .24724 Mtetra
.66 .753 .919 r
.64547 .24724 .6544 .25901 .67269 .25263 .66384 .24061 Mtetra
.658 .749 .917 r
.66384 .24061 .67269 .25263 .69109 .24602 .68233 .23403 Mtetra
.654 .75 .92 r
.68233 .23403 .69109 .24602 .70962 .23953 .70094 .22756 Mtetra
.652 .751 .922 r
.70094 .22756 .70962 .23953 .72828 .23313 .71969 .22114 Mtetra
.655 .753 .922 r
.71969 .22114 .72828 .23313 .74706 .22674 .73856 .21458 Mtetra
.659 .753 .919 r
.73856 .21458 .74706 .22674 .76596 .22013 .75753 .20777 Mtetra
.653 .749 .921 r
.08871 .4286 .09984 .43838 .11479 .43327 .10372 .4234 Mtetra
.653 .749 .92 r
.10372 .4234 .11479 .43327 .12986 .42794 .11882 .41818 Mtetra
.659 .754 .92 r
.11882 .41818 .12986 .42794 .14503 .42249 .13403 .4127 Mtetra
.659 .754 .921 r
.13403 .4127 .14503 .42249 .16028 .41708 .14934 .40718 Mtetra
.657 .753 .92 r
.14934 .40718 .16028 .41708 .1756 .4118 .16473 .4017 Mtetra
.653 .749 .92 r
.16473 .4017 .1756 .4118 .191 .40658 .18019 .39633 Mtetra
.651 .747 .919 r
.18019 .39633 .191 .40658 .20652 .40112 .19575 .39101 Mtetra
.656 .752 .92 r
.19575 .39101 .20652 .40112 .22215 .39551 .21141 .38546 Mtetra
.659 .755 .921 r
.21141 .38546 .22215 .39551 .23786 .38986 .22719 .37977 Mtetra
.659 .756 .921 r
.22719 .37977 .23786 .38986 .25367 .38426 .24305 .37404 Mtetra
.658 .754 .921 r
.24305 .37404 .25367 .38426 .26955 .37885 .25901 .36832 Mtetra
.655 .748 .918 r
.25901 .36832 .26955 .37885 .28553 .37344 .27506 .36268 Mtetra
.651 .744 .917 r
.27506 .36268 .28553 .37344 .30161 .36788 .2912 .35714 Mtetra
.652 .745 .918 r
.2912 .35714 .30161 .36788 .31781 .36216 .30744 .35155 Mtetra
.654 .75 .921 r
.30744 .35155 .31781 .36216 .3341 .35637 .32378 .34586 Mtetra
.656 .754 .922 r
.32378 .34586 .3341 .35637 .3505 .35054 .34024 .34003 Mtetra
.656 .756 .923 r
.34024 .34003 .3505 .35054 .36699 .34466 .35679 .33416 Mtetra
.656 .757 .924 r
.35679 .33416 .36699 .34466 .38359 .33878 .37345 .32825 Mtetra
.656 .758 .925 r
.37345 .32825 .38359 .33878 .40029 .3329 .39022 .32231 Mtetra
.39022 .32231 .40029 .3329 .41709 .32701 .40709 .31635 Mtetra
.655 .758 .925 r
.40709 .31635 .41709 .32701 .43399 .32111 .42406 .31037 Mtetra
.655 .757 .925 r
.42406 .31037 .43399 .32111 .45101 .31521 .44114 .30436 Mtetra
.44114 .30436 .45101 .31521 .46812 .30929 .45833 .29831 Mtetra
.655 .755 .923 r
.45833 .29831 .46812 .30929 .48535 .30334 .47563 .29221 Mtetra
.658 .755 .921 r
.47563 .29221 .48535 .30334 .50269 .29734 .49304 .28598 Mtetra
.659 .752 .919 r
.49304 .28598 .50269 .29734 .52014 .29127 .51057 .27964 Mtetra
.66 .748 .915 r
.51057 .27964 .52014 .29127 .5377 .28503 .5282 .27324 Mtetra
.656 .745 .915 r
.5282 .27324 .5377 .28503 .55538 .27863 .54595 .26693 Mtetra
.654 .748 .919 r
.54595 .26693 .55538 .27863 .57316 .27223 .56381 .26071 Mtetra
.653 .752 .923 r
.56381 .26071 .57316 .27223 .59106 .26602 .58179 .25449 Mtetra
.653 .754 .924 r
.58179 .25449 .59106 .26602 .60908 .25984 .59989 .24822 Mtetra
.656 .754 .923 r
.59989 .24822 .60908 .25984 .62722 .25362 .6181 .24179 Mtetra
.66 .753 .919 r
.6181 .24179 .62722 .25362 .64547 .24724 .63643 .23514 Mtetra
.658 .749 .917 r
.63643 .23514 .64547 .24724 .66384 .24061 .65488 .22851 Mtetra
.655 .749 .919 r
.65488 .22851 .66384 .24061 .68233 .23403 .67346 .22199 Mtetra
.653 .751 .922 r
.67346 .22199 .68233 .23403 .70094 .22756 .69216 .21551 Mtetra
.653 .753 .923 r
.69216 .21551 .70094 .22756 .71969 .22114 .71099 .20897 Mtetra
.659 .754 .921 r
.71099 .20897 .71969 .22114 .73856 .21458 .72993 .20215 Mtetra
.658 .75 .918 r
.72993 .20215 .73856 .21458 .75753 .20777 .749 .1953 Mtetra
.655 .751 .92 r
.07746 .41877 .08871 .4286 .10372 .4234 .09253 .41342 Mtetra
.652 .748 .92 r
.09253 .41342 .10372 .4234 .11882 .41818 .10767 .40815 Mtetra
.654 .749 .92 r
.10767 .40815 .11882 .41818 .13403 .4127 .12291 .4028 Mtetra
.659 .754 .92 r
.12291 .4028 .13403 .4127 .14934 .40718 .13827 .39722 Mtetra
.659 .754 .921 r
.13827 .39722 .14934 .40718 .16473 .4017 .15372 .39161 Mtetra
.657 .752 .92 r
.15372 .39161 .16473 .4017 .18019 .39633 .16926 .38605 Mtetra
.653 .748 .92 r
.16926 .38605 .18019 .39633 .19575 .39101 .18487 .38058 Mtetra
.651 .746 .919 r
.18487 .38058 .19575 .39101 .21141 .38546 .20057 .37514 Mtetra
.655 .751 .92 r
.20057 .37514 .21141 .38546 .22719 .37977 .21639 .36955 Mtetra
.658 .755 .921 r
.21639 .36955 .22719 .37977 .24305 .37404 .23231 .36379 Mtetra
.659 .756 .922 r
.23231 .36379 .24305 .37404 .25901 .36832 .24833 .35797 Mtetra
.658 .755 .921 r
.24833 .35797 .25901 .36832 .27506 .36268 .26445 .35214 Mtetra
.657 .752 .92 r
.26445 .35214 .27506 .36268 .2912 .35714 .28066 .34631 Mtetra
.655 .747 .917 r
.28066 .34631 .2912 .35714 .30744 .35155 .29697 .34052 Mtetra
.653 .744 .916 r
.29697 .34052 .30744 .35155 .32378 .34586 .31337 .33479 Mtetra
.653 .744 .917 r
.31337 .33479 .32378 .34586 .34024 .34003 .32988 .32901 Mtetra
.654 .747 .918 r
.32988 .32901 .34024 .34003 .35679 .33416 .34649 .32317 Mtetra
.655 .749 .919 r
.34649 .32317 .35679 .33416 .37345 .32825 .36321 .31726 Mtetra
.655 .751 .92 r
.36321 .31726 .37345 .32825 .39022 .32231 .38004 .3113 Mtetra
.656 .752 .921 r
.38004 .3113 .39022 .32231 .40709 .31635 .39698 .30527 Mtetra
.656 .752 .92 r
.39698 .30527 .40709 .31635 .42406 .31037 .41402 .29918 Mtetra
.657 .751 .92 r
.41402 .29918 .42406 .31037 .44114 .30436 .43117 .29302 Mtetra
.658 .75 .918 r
.43117 .29302 .44114 .30436 .45833 .29831 .44843 .2868 Mtetra
.658 .748 .916 r
.44843 .2868 .45833 .29831 .47563 .29221 .46581 .28052 Mtetra
.658 .746 .915 r
.46581 .28052 .47563 .29221 .49304 .28598 .48329 .27418 Mtetra
.656 .745 .915 r
.48329 .27418 .49304 .28598 .51057 .27964 .50088 .2679 Mtetra
.654 .747 .918 r
.50088 .2679 .51057 .27964 .5282 .27324 .51859 .26165 Mtetra
.653 .751 .921 r
.51859 .26165 .5282 .27324 .54595 .26693 .53641 .2554 Mtetra
.653 .753 .923 r
.53641 .2554 .54595 .26693 .56381 .26071 .55435 .24913 Mtetra
.653 .754 .924 r
.55435 .24913 .56381 .26071 .58179 .25449 .57241 .2428 Mtetra
.657 .755 .922 r
.57241 .2428 .58179 .25449 .59989 .24822 .59058 .23629 Mtetra
.66 .753 .919 r
.59058 .23629 .59989 .24822 .6181 .24179 .60887 .22961 Mtetra
.658 .748 .917 r
.60887 .22961 .6181 .24179 .63643 .23514 .62728 .22296 Mtetra
.655 .749 .919 r
.62728 .22296 .63643 .23514 .65488 .22851 .64582 .2164 Mtetra
.653 .751 .922 r
.64582 .2164 .65488 .22851 .67346 .22199 .66449 .20987 Mtetra
.653 .753 .923 r
.66449 .20987 .67346 .22199 .69216 .21551 .68328 .2033 Mtetra
.658 .754 .921 r
.68328 .2033 .69216 .21551 .71099 .20897 .70218 .19649 Mtetra
.659 .751 .918 r
.70218 .19649 .71099 .20897 .72993 .20215 .72121 .18958 Mtetra
.656 .75 .919 r
.72121 .18958 .72993 .20215 .749 .1953 .74037 .18273 Mtetra
.657 .753 .92 r
.06607 .40889 .07746 .41877 .09253 .41342 .0812 .40341 Mtetra
.655 .751 .92 r
.0812 .40341 .09253 .41342 .10767 .40815 .09641 .39798 Mtetra
.652 .748 .92 r
.09641 .39798 .10767 .40815 .12291 .4028 .11169 .39263 Mtetra
.654 .75 .92 r
.11169 .39263 .12291 .4028 .13827 .39722 .12708 .38716 Mtetra
.659 .754 .921 r
.12708 .38716 .13827 .39722 .15372 .39161 .14258 .38149 Mtetra
.14258 .38149 .15372 .39161 .16926 .38605 .15818 .37579 Mtetra
.657 .753 .92 r
.15818 .37579 .16926 .38605 .18487 .38058 .17386 .37012 Mtetra
.654 .749 .919 r
.17386 .37012 .18487 .38058 .20057 .37514 .18963 .36452 Mtetra
.652 .746 .919 r
.18963 .36452 .20057 .37514 .21639 .36955 .20549 .35897 Mtetra
.653 .749 .92 r
.20549 .35897 .21639 .36955 .23231 .36379 .22145 .35335 Mtetra
.657 .754 .921 r
.22145 .35335 .23231 .36379 .24833 .35797 .23752 .34753 Mtetra
.658 .756 .922 r
.23752 .34753 .24833 .35797 .26445 .35214 .2537 .34164 Mtetra
.2537 .34164 .26445 .35214 .28066 .34631 .26998 .33572 Mtetra
.658 .755 .922 r
.26998 .33572 .28066 .34631 .29697 .34052 .28635 .32977 Mtetra
.657 .753 .921 r
.28635 .32977 .29697 .34052 .31337 .33479 .30283 .3238 Mtetra
.656 .749 .918 r
.30283 .3238 .31337 .33479 .32988 .32901 .31941 .31783 Mtetra
.656 .747 .917 r
.31941 .31783 .32988 .32901 .34649 .32317 .33609 .31183 Mtetra
.655 .745 .916 r
.33609 .31183 .34649 .32317 .36321 .31726 .35287 .30582 Mtetra
.655 .744 .915 r
.35287 .30582 .36321 .31726 .38004 .3113 .36977 .29978 Mtetra
.656 .744 .915 r
.36977 .29978 .38004 .3113 .39698 .30527 .38677 .29368 Mtetra
.38677 .29368 .39698 .30527 .41402 .29918 .40387 .28752 Mtetra
.40387 .28752 .41402 .29918 .43117 .29302 .42109 .28133 Mtetra
.655 .745 .916 r
.42109 .28133 .43117 .29302 .44843 .2868 .43842 .27512 Mtetra
.655 .746 .917 r
.43842 .27512 .44843 .2868 .46581 .28052 .45586 .26889 Mtetra
.654 .749 .919 r
.45586 .26889 .46581 .28052 .48329 .27418 .47341 .26264 Mtetra
.654 .752 .922 r
.47341 .26264 .48329 .27418 .50088 .2679 .49108 .25638 Mtetra
.654 .754 .923 r
.49108 .25638 .50088 .2679 .51859 .26165 .50886 .25009 Mtetra
.654 .755 .924 r
.50886 .25009 .51859 .26165 .53641 .2554 .52676 .24376 Mtetra
.655 .755 .923 r
.52676 .24376 .53641 .2554 .55435 .24913 .54477 .23735 Mtetra
.659 .755 .921 r
.54477 .23735 .55435 .24913 .57241 .2428 .56291 .23073 Mtetra
.659 .751 .918 r
.56291 .23073 .57241 .2428 .59058 .23629 .58116 .22403 Mtetra
.657 .748 .917 r
.58116 .22403 .59058 .23629 .60887 .22961 .59953 .21738 Mtetra
.655 .749 .919 r
.59953 .21738 .60887 .22961 .62728 .22296 .61803 .21079 Mtetra
.653 .751 .922 r
.61803 .21079 .62728 .22296 .64582 .2164 .63665 .20421 Mtetra
.653 .753 .923 r
.63665 .20421 .64582 .2164 .66449 .20987 .6554 .1976 Mtetra
.657 .754 .921 r
.6554 .1976 .66449 .20987 .68328 .2033 .67427 .19077 Mtetra
.659 .751 .918 r
.67427 .19077 .68328 .2033 .70218 .19649 .69326 .18382 Mtetra
.656 .749 .918 r
.69326 .18382 .70218 .19649 .72121 .18958 .71238 .17692 Mtetra
.655 .75 .92 r
.71238 .17692 .72121 .18958 .74037 .18273 .73164 .17007 Mtetra
.659 .754 .92 r
.05455 .39894 .06607 .40889 .0812 .40341 .06974 .39334 Mtetra
.657 .752 .92 r
.06974 .39334 .0812 .40341 .09641 .39798 .085 .38779 Mtetra
.655 .75 .92 r
.085 .38779 .09641 .39798 .11169 .39263 .10035 .38227 Mtetra
.652 .748 .92 r
.10035 .38227 .11169 .39263 .12708 .38716 .11578 .37681 Mtetra
.654 .75 .92 r
.11578 .37681 .12708 .38716 .14258 .38149 .13132 .37126 Mtetra
.658 .754 .921 r
.13132 .37126 .14258 .38149 .15818 .37579 .14697 .3655 Mtetra
.659 .755 .921 r
.14697 .3655 .15818 .37579 .17386 .37012 .16272 .35971 Mtetra
.657 .753 .921 r
.16272 .35971 .17386 .37012 .18963 .36452 .17855 .35393 Mtetra
.656 .75 .92 r
.17855 .35393 .18963 .36452 .20549 .35897 .19448 .34817 Mtetra
.653 .746 .918 r
.19448 .34817 .20549 .35897 .22145 .35335 .2105 .34248 Mtetra
.652 .747 .919 r
.2105 .34248 .22145 .35335 .23752 .34753 .22661 .33678 Mtetra
.654 .751 .921 r
.22661 .33678 .23752 .34753 .2537 .34164 .24283 .33098 Mtetra
.657 .755 .922 r
.24283 .33098 .2537 .34164 .26998 .33572 .25917 .32503 Mtetra
.657 .756 .922 r
.25917 .32503 .26998 .33572 .28635 .32977 .2756 .31903 Mtetra
.657 .756 .923 r
.2756 .31903 .28635 .32977 .30283 .3238 .29214 .31299 Mtetra
.29214 .31299 .30283 .3238 .31941 .31783 .30879 .30692 Mtetra
.657 .755 .922 r
.30879 .30692 .31941 .31783 .33609 .31183 .32554 .30082 Mtetra
.656 .754 .922 r
.32554 .30082 .33609 .31183 .35287 .30582 .34239 .2947 Mtetra
.34239 .2947 .35287 .30582 .36977 .29978 .35935 .28855 Mtetra
.656 .753 .921 r
.35935 .28855 .36977 .29978 .38677 .29368 .37641 .28238 Mtetra
.37641 .28238 .38677 .29368 .40387 .28752 .39359 .27618 Mtetra
.655 .753 .922 r
.39359 .27618 .40387 .28752 .42109 .28133 .41088 .26996 Mtetra
.655 .754 .923 r
.41088 .26996 .42109 .28133 .43842 .27512 .42827 .26371 Mtetra
.42827 .26371 .43842 .27512 .45586 .26889 .44579 .25743 Mtetra
.654 .755 .924 r
.44579 .25743 .45586 .26889 .47341 .26264 .46341 .25111 Mtetra
.46341 .25111 .47341 .26264 .49108 .25638 .48115 .24476 Mtetra
.655 .755 .923 r
.48115 .24476 .49108 .25638 .50886 .25009 .49901 .23834 Mtetra
.657 .755 .922 r
.49901 .23834 .50886 .25009 .52676 .24376 .51699 .23177 Mtetra
.659 .752 .919 r
.51699 .23177 .52676 .24376 .54477 .23735 .53508 .2251 Mtetra
.658 .748 .917 r
.53508 .2251 .54477 .23735 .56291 .23073 .55329 .2184 Mtetra
.656 .747 .917 r
.55329 .2184 .56291 .23073 .58116 .22403 .57162 .21177 Mtetra
.654 .75 .92 r
.57162 .21177 .58116 .22403 .59953 .21738 .59008 .20515 Mtetra
.653 .752 .922 r
.59008 .20515 .59953 .21738 .61803 .21079 .60866 .19854 Mtetra
.653 .753 .923 r
.60866 .19854 .61803 .21079 .63665 .20421 .62737 .19188 Mtetra
.657 .754 .921 r
.62737 .19188 .63665 .20421 .6554 .1976 .64619 .18501 Mtetra
.659 .751 .919 r
.64619 .18501 .6554 .1976 .67427 .19077 .66514 .17802 Mtetra
.657 .749 .918 r
.66514 .17802 .67427 .19077 .69326 .18382 .68423 .17108 Mtetra
.655 .75 .92 r
.68423 .17108 .69326 .18382 .71238 .17692 .70344 .16417 Mtetra
.653 .751 .922 r
.70344 .16417 .71238 .17692 .73164 .17007 .72279 .15729 Mtetra
.657 .753 .92 r
.04291 .38883 .05455 .39894 .06974 .39334 .05814 .38323 Mtetra
.659 .754 .921 r
.05814 .38323 .06974 .39334 .085 .38779 .07347 .37754 Mtetra
.657 .752 .92 r
.07347 .37754 .085 .38779 .10035 .38227 .08888 .37189 Mtetra
.655 .75 .92 r
.08888 .37189 .10035 .38227 .11578 .37681 .10437 .36628 Mtetra
.653 .748 .92 r
.10437 .36628 .11578 .37681 .13132 .37126 .11995 .36071 Mtetra
.653 .749 .92 r
.11995 .36071 .13132 .37126 .14697 .3655 .13563 .35508 Mtetra
.658 .754 .921 r
.13563 .35508 .14697 .3655 .16272 .35971 .15143 .34925 Mtetra
.659 .755 .921 r
.15143 .34925 .16272 .35971 .17855 .35393 .16733 .34336 Mtetra
.658 .754 .921 r
.16733 .34336 .17855 .35393 .19448 .34817 .18332 .33746 Mtetra
.657 .752 .92 r
.18332 .33746 .19448 .34817 .2105 .34248 .19941 .33157 Mtetra
.655 .749 .919 r
.19941 .33157 .2105 .34248 .22661 .33678 .21559 .32569 Mtetra
.653 .746 .918 r
.21559 .32569 .22661 .33678 .24283 .33098 .23187 .31985 Mtetra
.653 .747 .918 r
.23187 .31985 .24283 .33098 .25917 .32503 .24825 .31398 Mtetra
.654 .75 .92 r
.24825 .31398 .25917 .32503 .2756 .31903 .26474 .30804 Mtetra
.655 .753 .922 r
.26474 .30804 .2756 .31903 .29214 .31299 .28133 .30201 Mtetra
.656 .755 .922 r
.28133 .30201 .29214 .31299 .30879 .30692 .29804 .2959 Mtetra
.656 .755 .923 r
.29804 .2959 .30879 .30692 .32554 .30082 .31485 .28975 Mtetra
.656 .756 .923 r
.31485 .28975 .32554 .30082 .34239 .2947 .33177 .28356 Mtetra
.33177 .28356 .34239 .2947 .35935 .28855 .3488 .27734 Mtetra
.3488 .27734 .35935 .28855 .37641 .28238 .36593 .2711 Mtetra
.36593 .2711 .37641 .28238 .39359 .27618 .38318 .26482 Mtetra
.655 .756 .924 r
.38318 .26482 .39359 .27618 .41088 .26996 .40054 .25852 Mtetra
.655 .755 .923 r
.40054 .25852 .41088 .26996 .42827 .26371 .41801 .25217 Mtetra
.41801 .25217 .42827 .26371 .44579 .25743 .43559 .24579 Mtetra
.656 .755 .922 r
.43559 .24579 .44579 .25743 .46341 .25111 .45329 .23932 Mtetra
.658 .754 .921 r
.45329 .23932 .46341 .25111 .48115 .24476 .47111 .23275 Mtetra
.658 .751 .919 r
.47111 .23275 .48115 .24476 .49901 .23834 .48904 .22611 Mtetra
.658 .748 .917 r
.48904 .22611 .49901 .23834 .51699 .23177 .5071 .21943 Mtetra
.656 .747 .917 r
.5071 .21943 .51699 .23177 .53508 .2251 .52527 .21279 Mtetra
.655 .749 .919 r
.52527 .21279 .53508 .2251 .55329 .2184 .54356 .20615 Mtetra
.654 .751 .921 r
.54356 .20615 .55329 .2184 .57162 .21177 .56197 .19951 Mtetra
.653 .752 .922 r
.56197 .19951 .57162 .21177 .59008 .20515 .58051 .19286 Mtetra
.654 .754 .923 r
.58051 .19286 .59008 .20515 .60866 .19854 .59918 .18613 Mtetra
.658 .754 .921 r
.59918 .18613 .60866 .19854 .62737 .19188 .61796 .17919 Mtetra
.659 .751 .918 r
.61796 .17919 .62737 .19188 .64619 .18501 .63687 .17218 Mtetra
.656 .749 .918 r
.63687 .17218 .64619 .18501 .66514 .17802 .65591 .1652 Mtetra
.655 .75 .92 r
.65591 .1652 .66514 .17802 .68423 .17108 .67509 .15824 Mtetra
.653 .751 .921 r
.67509 .15824 .68423 .17108 .70344 .16417 .6944 .15132 Mtetra
.654 .753 .922 r
.6944 .15132 .70344 .16417 .72279 .15729 .71384 .1443 Mtetra
.654 .749 .92 r
.03116 .37849 .04291 .38883 .05814 .38323 .04641 .37296 Mtetra
.657 .753 .92 r
.04641 .37296 .05814 .38323 .07347 .37754 .06179 .36726 Mtetra
.659 .754 .921 r
.06179 .36726 .07347 .37754 .08888 .37189 .07726 .36147 Mtetra
.657 .752 .92 r
.07726 .36147 .08888 .37189 .10437 .36628 .09282 .35572 Mtetra
.655 .751 .92 r
.09282 .35572 .10437 .36628 .11995 .36071 .10846 .34999 Mtetra
.653 .748 .919 r
.10846 .34999 .11995 .36071 .13563 .35508 .12419 .34431 Mtetra
.653 .748 .92 r
.12419 .34431 .13563 .35508 .15143 .34925 .14003 .33858 Mtetra
.656 .752 .921 r
.14003 .33858 .15143 .34925 .16733 .34336 .15597 .33272 Mtetra
.658 .755 .922 r
.15597 .33272 .16733 .34336 .18332 .33746 .17202 .32674 Mtetra
.658 .755 .921 r
.17202 .32674 .18332 .33746 .19941 .33157 .18817 .32072 Mtetra
.657 .753 .921 r
.18817 .32072 .19941 .33157 .21559 .32569 .20442 .3147 Mtetra
.656 .752 .92 r
.20442 .3147 .21559 .32569 .23187 .31985 .22077 .30867 Mtetra
.656 .749 .919 r
.22077 .30867 .23187 .31985 .24825 .31398 .23722 .30263 Mtetra
.654 .747 .918 r
.23722 .30263 .24825 .31398 .26474 .30804 .25377 .2966 Mtetra
.654 .746 .917 r
.25377 .2966 .26474 .30804 .28133 .30201 .27042 .29055 Mtetra
.654 .747 .918 r
.27042 .29055 .28133 .30201 .29804 .2959 .28719 .28444 Mtetra
.655 .749 .919 r
.28719 .28444 .29804 .2959 .31485 .28975 .30406 .27829 Mtetra
.655 .75 .92 r
.30406 .27829 .31485 .28975 .33177 .28356 .32104 .27207 Mtetra
.655 .751 .92 r
.32104 .27207 .33177 .28356 .3488 .27734 .33813 .26581 Mtetra
.656 .752 .921 r
.33813 .26581 .3488 .27734 .36593 .2711 .35534 .25949 Mtetra
.35534 .25949 .36593 .2711 .38318 .26482 .37265 .25311 Mtetra
.656 .752 .92 r
.37265 .25311 .38318 .26482 .40054 .25852 .39008 .24668 Mtetra
.657 .751 .919 r
.39008 .24668 .40054 .25852 .41801 .25217 .40762 .2402 Mtetra
.657 .75 .918 r
.40762 .2402 .41801 .25217 .43559 .24579 .42528 .23365 Mtetra
.657 .748 .917 r
.42528 .23365 .43559 .24579 .45329 .23932 .44306 .22705 Mtetra
.657 .747 .916 r
.44306 .22705 .45329 .23932 .47111 .23275 .46095 .22043 Mtetra
.656 .747 .917 r
.46095 .22043 .47111 .23275 .48904 .22611 .47896 .21381 Mtetra
.655 .749 .919 r
.47896 .21381 .48904 .22611 .5071 .21943 .49709 .20717 Mtetra
.655 .751 .921 r
.49709 .20717 .5071 .21943 .52527 .21279 .51533 .20052 Mtetra
.654 .752 .922 r
.51533 .20052 .52527 .21279 .54356 .20615 .53371 .19386 Mtetra
.654 .753 .923 r
.53371 .19386 .54356 .20615 .56197 .19951 .5522 .18715 Mtetra
.656 .754 .922 r
.5522 .18715 .56197 .19951 .58051 .19286 .57082 .18032 Mtetra
.658 .753 .92 r
.57082 .18032 .58051 .19286 .59918 .18613 .58957 .17333 Mtetra
.658 .75 .918 r
.58957 .17333 .59918 .18613 .61796 .17919 .60844 .16629 Mtetra
.656 .749 .918 r
.60844 .16629 .61796 .17919 .63687 .17218 .62744 .15929 Mtetra
.655 .75 .92 r
.62744 .15929 .63687 .17218 .65591 .1652 .64657 .1523 Mtetra
.653 .751 .922 r
.64657 .1523 .65591 .1652 .67509 .15824 .66583 .14533 Mtetra
.654 .753 .922 r
.66583 .14533 .67509 .15824 .6944 .15132 .68523 .13827 Mtetra
.658 .753 .921 r
.68523 .13827 .6944 .15132 .71384 .1443 .70476 .13101 Mtetra
.654 .749 .92 r
.01927 .36803 .03116 .37849 .04641 .37296 .03458 .36244 Mtetra
.03458 .36244 .04641 .37296 .06179 .36726 .04998 .3568 Mtetra
.657 .753 .921 r
.04998 .3568 .06179 .36726 .07726 .36147 .0655 .35101 Mtetra
.659 .754 .921 r
.0655 .35101 .07726 .36147 .09282 .35572 .08112 .34513 Mtetra
.657 .753 .92 r
.08112 .34513 .09282 .35572 .10846 .34999 .09682 .33927 Mtetra
.656 .751 .92 r
.09682 .33927 .10846 .34999 .12419 .34431 .11262 .33342 Mtetra
.654 .749 .919 r
.11262 .33342 .12419 .34431 .14003 .33858 .12851 .32759 Mtetra
.653 .748 .919 r
.12851 .32759 .14003 .33858 .15597 .33272 .1445 .32177 Mtetra
.654 .75 .92 r
.1445 .32177 .15597 .33272 .17202 .32674 .16059 .31587 Mtetra
.657 .754 .921 r
.16059 .31587 .17202 .32674 .18817 .32072 .1768 .30983 Mtetra
.658 .755 .922 r
.1768 .30983 .18817 .32072 .20442 .3147 .19311 .30372 Mtetra
.19311 .30372 .20442 .3147 .22077 .30867 .20952 .29758 Mtetra
.657 .754 .921 r
.20952 .29758 .22077 .30867 .23722 .30263 .22604 .29141 Mtetra
.657 .752 .921 r
.22604 .29141 .23722 .30263 .25377 .2966 .24266 .28523 Mtetra
.656 .751 .92 r
.24266 .28523 .25377 .2966 .27042 .29055 .25938 .27903 Mtetra
.656 .749 .919 r
.25938 .27903 .27042 .29055 .28719 .28444 .27621 .27279 Mtetra
.656 .748 .918 r
.27621 .27279 .28719 .28444 .30406 .27829 .29315 .26652 Mtetra
.656 .747 .917 r
.29315 .26652 .30406 .27829 .32104 .27207 .3102 .26021 Mtetra
.3102 .26021 .32104 .27207 .33813 .26581 .32736 .25385 Mtetra
.656 .746 .917 r
.32736 .25385 .33813 .26581 .35534 .25949 .34463 .24746 Mtetra
.34463 .24746 .35534 .25949 .37265 .25311 .36201 .24102 Mtetra
.656 .747 .917 r
.36201 .24102 .37265 .25311 .39008 .24668 .37951 .23453 Mtetra
.37951 .23453 .39008 .24668 .40762 .2402 .39712 .228 Mtetra
.656 .748 .918 r
.39712 .228 .40762 .2402 .42528 .23365 .41485 .22144 Mtetra
.655 .749 .919 r
.41485 .22144 .42528 .23365 .44306 .22705 .4327 .21485 Mtetra
.655 .75 .92 r
.4327 .21485 .44306 .22705 .46095 .22043 .45066 .20822 Mtetra
.655 .752 .921 r
.45066 .20822 .46095 .22043 .47896 .21381 .46874 .20157 Mtetra
.654 .753 .922 r
.46874 .20157 .47896 .21381 .49709 .20717 .48695 .1949 Mtetra
.654 .754 .923 r
.48695 .1949 .49709 .20717 .51533 .20052 .50528 .18818 Mtetra
.655 .754 .923 r
.50528 .18818 .51533 .20052 .53371 .19386 .52373 .18139 Mtetra
.658 .754 .921 r
.52373 .18139 .53371 .19386 .5522 .18715 .54231 .17444 Mtetra
.658 .751 .919 r
.54231 .17444 .5522 .18715 .57082 .18032 .56101 .16742 Mtetra
.657 .749 .918 r
.56101 .16742 .57082 .18032 .58957 .17333 .57984 .16038 Mtetra
.656 .749 .919 r
.57984 .16038 .58957 .17333 .60844 .16629 .59879 .15335 Mtetra
.655 .751 .92 r
.59879 .15335 .60844 .16629 .62744 .15929 .61788 .14633 Mtetra
.653 .751 .922 r
.61788 .14633 .62744 .15929 .64657 .1523 .63711 .13932 Mtetra
.655 .753 .922 r
.63711 .13932 .64657 .1523 .66583 .14533 .65646 .1322 Mtetra
.658 .753 .921 r
.65646 .1322 .66583 .14533 .68523 .13827 .67594 .1249 Mtetra
.658 .751 .919 r
.67594 .1249 .68523 .13827 .70476 .13101 .69556 .11756 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
[(-2)] .12586 .2075 1 .99877 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.56863 .04703 m
.57247 .05235 L
s
[(2)] .56094 .0364 .72324 1 Mshowa
.125 Mabswid
.18558 .19702 m
.18832 .19985 L
s
.23703 .17687 m
.23971 .17975 L
s
.28951 .15632 m
.29214 .15925 L
s
.39772 .11395 m
.40023 .11699 L
s
.4535 .09211 m
.45595 .0952 L
s
.51046 .06981 m
.51284 .07294 L
s
.08568 .23614 m
.08851 .23887 L
s
.62804 .02377 m
.63027 .02701 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 233.5},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00o?ooool2o`0006[ooooo003iooooo`?o000000?oooooo`000?ooool0
JOooool00?Oooooo0_l00004ooooo`;o0000JOooool00?Cooooo0ol00006ooooo`03o`000?oooooo
000006Sooooo003;ooooo`Go00008_ooool2o`0000Wooooo00?o0000ooooool00000J?ooool00<_o
oooo00GoV9RHob4Q8Oo^k^koooooodA4A00Oooooo`?o00002oooool01?l0003oooooooooool0001W
ooooo`00c?ooool00onHV9So8B4Qonk^kP0Mooooo`?o00003_ooool01Ol0003ooooooooooooooooo
000006Kooooo003=ooooo`03oiRHV?lQ8B7ok^k^01[ooooo0_l0000Aooooo`05o`000?oooooooooo
ooooool00000I_ooool00<kooooo00?oMgMgofIVI_ooool05_ooool3o`0001?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1Sooooo`00coooool00ol0003oooooooooo`0Cooooo`;o
00000_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0H_ooool00<_ooooo00Go0000okZj^_ooooooV9RHoa0@400Booooo`?o00006Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo06;ooooo003;ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`04?ooool2o`0001cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Qooooo`00
gOooool3o`0001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Qooooo`00fooo
ool2o`00027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Pooooo`00f?ooool3
o`0002?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Oooooo`00eOooool3o`00
02Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Oooooo`00doooool2o`0002Wo
oooo00?o0000ooooooooool01?ooool00ol0003oooooo`00001Pooooo`00d?ooool3o`000003oooo
ool0003ooooo02Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Mooooo`00c_oo
ool2o`0000Gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo05gooooo003;ooooo`?o0000<?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo05cooooo0039ooooo`;o0000<oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
05_ooooo0036ooooo`?o0000=Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo05_o
oooo0034ooooo`;o0000>?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05[ooooo
0031ooooo`?o0000>_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00kooooo1Ol0
0016ooooo`00__ooool3o`0003gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0>
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0A_ooool00;cooooo0_l00003ooooo`03o`000?oooooo
oooo03[ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`05ooooo`Ko00000oooool0
0onHV9So8B4Qonk^kP17ooooo`00^Oooool3o`0004?ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0>ooooo`03oiRHV?lQ8B7ok^k^04Kooooo002gooooo`;o0000A_ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00oooooo00?oMgMgofIVI_ooool0AOooool00;Cooooo
0ol00018ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`14ooooo`00/_ooool2o`0004_ooooo00?o0000ooooooooool03Oooool2o`0000cooooo00Go
0000okZj^_ooooooV9RHoa0@4016ooooo`00[oooool3o`0004gooooo00?o0000ooooooooool03?oo
ool00ol0003oooooo`00000<ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0A_ooool00:gooooo0_l0
001@ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0E?ooool00:[ooooo1?l0001A
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0E?ooool00:Sooooo0_l00004oooo
o`03o`000?oooooooooo04kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Coooo
o`00O_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02;ooooo0ol0001Gooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool0D_ooool007kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Ooooo
o`?o0000F_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo05;ooooo001nooooo`05
oa0@4?ooooooooooooooool@41007Oooool2o`0005gooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`1Aooooo`00O_ooool01Ol0003ooooooooooooooooo000001[ooooo0ol0001Ooooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0D?ooool007kooooo00Go0000oooooooo
ooooooooo`00000Hooooo`;o0000H_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
053ooooo001nooooo`05oa0@4?ooooooooooooooool@41005Oooool3o`0006Cooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`1?ooooo`00O_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
01?ooooo0_l00003ooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`1>ooooo`00O_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^013ooooo0ol0001Xoooo
o`03ojS0jol0003ooooo01Kooooo00?o0000ooooooooool0C_ooool0097ooooo0_l0001Xooooo`Co
Z<3[00?o0000ooooooooool05_ooool00ol0003oooooooooo`1=ooooo`00S_ooool3o`0006Sooooo
1onX`>/00ol0003oooooooooo`0Dooooo`?o0000C_ooool008_ooooo0ol0001Yooooo`WoZ<3[00?o
0000ooooooooool05_ooool00ol0003oooooooooo`1<ooooo`00ROooool2o`0006Wooooo3?nX`>/0
0ol0003oZ<3[ooooo`0Gooooo`03o`000?oooooooooo04_ooooo0026ooooo`?o0000J?ooool00onW
`>coZ<3[ojS0j`0<ojS0j`03o`000?nX`>_ooooo01Sooooo00?o0000ooooooooool0B_ooool008Co
oooo0_l00002ooooo`03o`000?oooooooooo06?ooooo1OnW`>`=ojS0j`03o`000?nX`>_oZ<3[01So
oooo00?o0000ooooooooool0B_ooool0087ooooo0ol00005ooooo`03o`000?oooooooooo063ooooo
2?nW`>`7ojS0j`03ojO0k?nX`>_oZ<3[00;oZ<3[00Co0000ojS0jonX`>_oZ<3[6?ooool00ol0003o
ooooooooo`19ooooo`00Ooooool2o`0006Wooooo2_nW`>`4ojS0j`GoYl3/0onX`>/00ol0003oZ<3[
ojS0j`02ojS0jaSooooo00?o0000ooooooooool0B?ooool007cooooo0ol0001Xooooo`koYl3/00?o
Z<3[ojO0k?nW`>`01_nW`>`2ojS0j`05o`000?nX`>_oZ<3[ojS0jonW`>`06?ooool00ol0003ooooo
ooooo`18ooooo`00N_ooool2o`0006Oooooo0_nW`>/IojO0k0;oZ<3[00?o0000ojS0jonW`>`00onW
`>`Hooooo`03o`000?oooooooooo04Oooooo001gooooo`?o0000I_ooool6ojO0jaWoYl3/00?oZ<3[
o`000?nW`>`01OnW`>`Hooooo`03o`000?oooooooooo04Kooooo001dooooo`?o0000I_ooool00onW
_n_oYl3[ojO0j`07ojO0j`KoYl3/0_nW_n/>ojO0k0;oYl3[00?oYl3/o`000?nW`>`01OnW`>`Hoooo
o`03o`000?oooooooooo04Kooooo001booooo`;o00000_ooool00ol0003oooooooooo`1Rooooo`Co
Yko[2OnW`>/2ojO0k0KoYko[2_nW`>`6ojO0j`03o`000?nW`>coYl3/00GoYl3/6?ooool00ol0003o
ooooooooo`15ooooo`00Koooool3o`0006Oooooo1onW_n/7ojO0j`[oYko[1_nW`>`00onW_n_oYl3[
ojO0j`06ojO0j`03o`000?nW`>coYl3/00GoYl3/6?ooool00ol0003oooooooooo`15ooooo`00KOoo
ool2o`0006Oooooo0_nX_n/8ojNoj`CoYl3[3_nW_n/2ojO0k0GoYko[1onW`>/00ol0003oYl3[ojO0
k006ojO0k1Sooooo00?o0000ooooooooool0A?ooool006[ooooo0ol0001Vooooo`KoZ;o[2?nW_n/0
0onW`>_oYko[ojNoj`0FojNoj`KoYl3[00?o0000ojNojonW`>`01onW`>`Fooooo`03o`000?oooooo
000004Gooooo001Xooooo`;o0000I_ooool00onX`>_oZ;o[ojRoj`07ojRoj`KoYko[0_nX_n/IojNo
j`;oYl3[0onW_n/00ol0003oYko[ojNoj`08ojO0k1Oooooo00?o0000ooooooooool0@oooool006Go
oooo0ol0001Vooooo`CoZ<3[2OnX_n/2ojNoj`KoZ;o[5onW_n/00onX_n_oYko[ojNoj`03ojNoj`04
o`000?nW_n_oYko[ojNoj`KoYl3/00?oYko[ooooooooool05_ooool00ol0003oooooooooo`12oooo
o`00Hoooool2o`0006Oooooo1onX`>/7ojRoj`03ojS0jonX_n_oZ;o[00OoZ;o[1_nW_n/00onX`>_o
Yko[ojNoj`0;ojNoj`CoZ;o[1OnW_n/01?l0003oYko[ojNojonW_n/2ojO0k0GoYko[6?ooool00ol0
003oooooooooo`11ooooo`00H?ooool3o`000003ooooool0003ooooo06Cooooo00?oZ<7[ojS0jonX
`>/01onX`>/4ojRoj`CoZ<3[2OnX_n/2ojNoj`GoZ<3[2_nW_n/7ojRoj`CoYko[00?o0000ojNojonW
_n/02OnW_n/Gooooo`03o`000?oooooooooo047ooooo000fooooo`Go00008oooool2o`0006Oooooo
1OnX`N/9ojS0j`03ojRojonX`>_oZ<3[00GoZ<3[1_nX_n/2ojS1j`SoZ<3[1_nW_n/2ojS0j`SoZ;o[
1?nW_n/00ol0003oYko[ojNoj`0:ojNojaOooooo00?o0000ooooooooool0@?ooool003Kooooo00Go
V9RHob4Q8Oo^k^koooooodA4A00Pooooo`?o0000IOooool2ojO1k0SoZ<7[1_nX`>/2ojO1k0WoZ<3[
0_nX_n/6ojS1j`SoZ<3[0_nW_n/6ojS0j`SoZ;o[0onW_n/00ol0003oYko[ojNoj`0:ojNojaSooooo
00?o0000ooooooooool0?oooool002kooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^01kooooo0ol0
001Uooooo`KoYl7/2?nX`N/2ojS0j`KoYl7/1onX`>/00onW`NcoZ<7[ojS1j`07ojS1j`KoZ<3[00?o
Z<7[ojS0jonX`>/01onX`>/6ojRoj`05ojS0jonW_n_oYko[ojNojol000003OnW_n/Gooooo`03o`00
0?oooooooooo03oooooo000hooooo`03oiRHV?lQ8B7ok^k^01_ooooo0_l0001Uooooo`[oYl7/1_nX
`N/2ojO0k0SoYl7/1?nX`>/4ojO1k0WoZ<7[0_nX`>/5ojS1j`WoZ<3[0_nX_n/5ojS0j`;oYko[00?o
0000ojNojonW_n/03?nW_n/Gooooo`03o`000?oooooooooo03kooooo000iooooo`03ogMgMomVIVKo
oooo01Oooooo0ol0001Tooooo`koYl7/0_nX`N/6ojO0k0SoYl7/00?oZ<3[ojO1k?nW`N`01OnW`N`7
ojS1j`03ojO0k?nX`N_oZ<7[00KoZ<7[1_nX`>/2ojS1j`SoZ<3[00?oYko[o`000?nW_n/00onW_n/2
ojS0j`SoYko[6?ooool00ol0003oooooooooo`0mooooo`00>_ooool00ol0003oooooooooo`0Doooo
o`;o0000I?ooool00onW`>coYl7/ojO1k00=ojO1k0[oYl3/1_nW`N`00onW`>coYl7/ojO1k007ojO1
k0CoZ<7[1?nW`>`8ojS1j`;oZ<3[1_nX`N/8ojS0j`03o`000?nW_n_oZ<3[00GoZ<3[2?nW_n/Goooo
o`03o`000?oooooooooo03gooooo000fooooo`05o`000?nj^[[ooooooiRHV?l@41004oooool3o`00
00;ooooo00?o0000ooooooooool0Goooool4ojO0k0_oYl7/3_nW`>`2ojO1k0GoYl3/2OnW`N`00onX
`N_oYl3/ojO0k005ojO0k0KoZ<7[00?oYl3/ojS1jonX`N/01onX`N/6ojS0j`03ojS1jol0003oZ<3[
00OoZ<3[1_nW_n/00onX_n_oooooooooo`0Fooooo`03o`000?oooooooooo03cooooo000fooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`04Oooool2o`0006Gooooo1onW`>`7ojO1k003ojO0jonW`>coYl3/
00coYl3/0_nW`>/8ojO0k0KoYl7/2_nW`>`4ojS1j`CoYl3/2OnX`N/2ojS0j`CoZ<7[00?o0000ojS0
jonX`>/01onX`>/2ojNoj`GoZ;o[5_ooool3o`0003gooooo0019ooooo`?o0000IOooool00onW`>_o
Yl3/ojO0k007ojO0k0CoYl7/1?nW`>/:ojO0k0KoYl3[2?nW`>`2ojO1k0koYl3/00?oZ<7[ojO0k?nW
`>`01OnW`>`7ojS1j`03ojO0k?nX`N_oZ<7[00CoZ<7[00?o0000ojS1jonX`>/01OnX`>/2ojS1j`So
Z;o[5oooool00ol0003oooooooooo`0kooooo`00Aoooool2o`0006Gooooo1OnW`>/9ojO0k003ojO1
k?nW`>_oYl3[00GoYl3[1_nW`>`2ojNoj`SoYl3[1_nW`>`00onW_n_oYl3/ojO0k00FojO0k0CoZ<7[
1OnW`>`5ojS1j`03o`000?nX`N_oZ<7[00;oZ<3[1_nX`N/8ojRojaOooooo00?o0000ooooooooool0
>_ooool004Cooooo0ol0001Tooooo`03ojNojonW`>_oYl3[00KoYl3[1_nW`>`2ojNoj`SoYl3[1?nW
`>`5ojNoj`SoYl3[0_nW`>`5ojNojaSoYl3/00?oZ<7[ojO0k?nW`>`01_nW`>`4ojS1j`03o`000?nX
`N_oYl3/00WoZ<7[1_nX_n/00onX`>_oooooooooo`0Fooooo`03o`000?oooooooooo03Wooooo0011
ooooo`?o0000I?ooool5ojNoj`SoYl3[0_nW`>`6ojNoj`SoYl3[00?oYl3/ojNojonW_n/01_nW_n/6
ojO0j`03ojNoj_nW_n_oYko[00KoYko[1_nW`>`2ojNojaWoYl3/0_nX`N/00onW`>co0000ojO0k002
ojO0k0WoZ<7[0_nX_n/5ojS0jaOooooo00?o0000ooooooooool0>Oooool003oooooo0ol0001Soooo
o`WoYko[1_nW`>/2ojNojPSoYko[1_nW`>/2ojNojPWoYko[0_nW`>/5ojNojPSoYko[0_nW`>`6ojNo
ja_oYl3/00?o0000ojO0k?nW`>`00_nW`>`6ojS1j`;oYl3/2?nX`>/Gooooo`03o`000?oooooooooo
03Sooooo000looooo`?o00000oooool00ol0003oooooooooo`1Mooooo`goYko[0_nW`>/6ojNojPSo
Yko[0_nW`>/6ojNojPOoYko[00?oZ;oZojNoj_nW_nX01_nW_nX6ojNoj`;oZ;oZ2?nW_n/6ojO0k003
ojNojonW`>coYl3/017oYl3/00?o0000ojO0k?nW`>`00onW`>`2ojS1j`KoYl3/2?nX`>/Fooooo`03
o`000?oooooooooo00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0/ooooo`00>_ooool2o`0006?o
oooo3onW_n/2ojRojPSoYkoZ1_nW_n/00onX_n[oYkoZojNojP07ojNojPCoYko[1?nX_nX8ojNojP;o
Yko[1_nX_nX8ojNoj`;oYl3/1OnW_n/BojO0k003o`000?nW`>coYl3/00;oYl3/00?oY/3/ojO0k?nW
`>`01onW`>`6ojS0j`03ojS1jooooooooooo01Gooooo00?o0000ooooooooool01_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg02cooooo000gooooo`?o0000Hoooool>ojNoj`KoZ;oZ2?nW_nX2ojNoj`Go
Z;oZ2OnW_nX00onW_n_oZ;oZojRojP05ojRojPKoYkoZ00?oZ<3[ojRoj_nX_nX01onX_nX6ojNoj`03
ojRoj_nW_n_oYko[00KoYko[1_nW`>`2ojNoj`[oYl3/00?o0000ojO0k?nV`>`00onV`>`9ojO0k0;o
Z<3[1OnX`N/Gooooo`03o`000?oooooooooo00Gooooo00Go410@oooooooooooooooooa0@400/oooo
o`00=Oooool2o`0006Cooooo3OnW_n/:ojRojPKoYkoZ00?oZ<3[ojRoj_nX_nX01_nX_nX6ojNojP;o
Z<3[2?nX_nX4ojNojPCoZ<3[2OnX_nX2ojNoj`GoZ;oZ2?nW_n/2ojO0k0KoYko[2OnW`>`00ol0003o
Y/3/ojK0k004ojK0k0KoYl3/0_nV`>`8ojS1jaKooooo00?o0000ooooooooool01Oooool01Ol0003o
oooooooooooooooo000002cooooo000booooo`?o0000I?ooool00onW_n[oYko[ojNoj`0:ojNoj`go
Z;oZ0_nW_nX5ojS0j`SoZ;oZ0_nW_nX6ojS0j`SoZ;oZ00?oYkoZojS0jonX`>/01OnX`>/7ojRojP03
ojS0jonX_n[oZ;oZ00KoZ;oZ1_nW_n/00onX_n[oYko[ojNoj`07ojNoj`KoYl3/00?oYko[ojK0k?l0
00001onV`>`2ojO0k0KoY/3/2?nX`N/Fooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooo
ooooooooo`00000/ooooo`00<?ooool2o`0006Cooooo1OnW_nX9ojNoj`koZ;oZ00?oZ<7[ojS0jonX
`>/01_nX`>/6ojRojP;oZ<7/2?nX`>/6ojRojP03ojS1jonX`>_oZ<3[00KoZ<3[1?nX_nX5ojS0j`So
Z;oZ0_nW_n/5ojRojPWoYko[0_nW`>`5ojNoj`03o`000?nV`>coY/3/00CoY/3/00?oYl3[ojK0k?nV
`>`01_nV`>`6ojS1j`;oYl3/5oooool00ol0003oooooooooo`03ooooo`05oa0@4?oooooooooooooo
ool@4100;?ooool002gooooo0ol000000ooooooo0000ooooo`1Pooooo`WoYkoZ1_nW_n/2ojRoj`co
Z;oZ1?nX`N/8ojS0j`;oZ;oZ1_nX`N`8ojS0j`;oZ;oZ1OnX`N/8ojS0j`03ojRoj_nX`>_oZ<3[00Ko
Z<3[1_nX_nX00onX`>_oZ;oZojRojP06ojRojPKoYko[0_nX_nX7ojNoj`03o`000?nV`>coY/3/00;o
Y/3/1?nW`>/8ojK0k0;oZ<7[1_nW`>`Fooooo`;o00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg
02cooooo000Zooooo`?o0000Hoooool=ojNojP;oYko[1_nX_n/9ojRojPOoZ<7[1_nX`>/2ojO1k0So
Z<7/1_nX`>/00onW`NcoZ<7[ojS1j`06ojS1j`KoZ<3[0_nX`N`9ojS0j`;oZ;oZ1OnX`>/8ojRojP;o
Yko[1_nX_nX6ojNoj`03o`000?nW_n_oY/3/00OoYl3[1_nV`>`:ojO0k1?ooooo0_l000000ooooooo
0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0;?ooool002Sooooo0_l0001Sooooo`03
ojNnj_nW_n[oYkoZ00coYkoZ0_nX`>/8ojRoj`KoZ;oZ00?oYl7/ojS1jonX`N/01onX`N/2ojS0j`Ko
Yl7/2?nX`N`2ojS0j`GoYl7/2?nX`N/2ojS0j`KoZ<7/1onX`>/00onW`NcoZ<3[ojS0j`06ojS0j`Ko
Z;oZ00?oZ<3[ojRoj_nX_nX01onX_nX5ojNoj`03o`000?nX_n_oYl3[00OoYl3[1?nV`>`=ojO0k1Ko
oooo00?o0000ooooooooool0<_ooool002Gooooo0ol0001Rooooo`GoYkkZ2_nW_nX6ojS0j`SoZ;o[
0_nX_nX5ojO1k0OoZ<7[2_nW`N`6ojS1k0WoYl7/1_nX`N/00onW`NcoZ<7/ojS1k007ojS1k0CoZ<3[
1?nW`N`8ojS0j`;oZ;oZ1OnX`>/9ojRojP;oYko[00?oZ;o[o`000?l000000_nX_n/8ojO0j`03ojK0
k?nW`>coYl3/00_oYl3/0_nV`>`Fooooo`03o`000?oooooooooo03;ooooo000Sooooo`;o0000H_oo
ool9ojNnjPKoYkoZ0_nW`>/8ojS0j`KoZ;o[2OnW`N`4ojS1j`goYl7/0_nX`N`=ojO1k0;oZ<7[1OnW
`N`9ojS1k003ojS0jonW`NcoYl7/00GoYl7/1_nX`>/00onW`NcoZ<3[ojS0j`06ojS0j`KoZ;oZ0_nY
`>/3o`000003ojRojol0003oZ;o[00;oZ;o[1_nW`>/00onW_n_oYl3/ojO0k009ojO0k0KoY/3/5_oo
ool00ol0003oooooooooo`0aooooo`008?ooool3o`0006;ooooo3?nW_^X2ojNojPKoYl3[2?nX`>/2
ojRoj`goYl7/00?oZ<7[ojO1k?nW`N`06onW`N`00onW`>coYl7/ojO1k006ojO1k0KoZ<7/2onW`N`2
ojS0j`GoYl7/2?nX`>/2ojRojP;oZL3[0ol000000onY`>_oZ;o[ojRoj`02ojRoj`04o`000?nX_n_o
Z;o[ojRoj`;oYl3[1OnW_n/7ojO0k003ojNojonV`>coY/3/00KoY/3/5oooool00ol0003ooooooooo
o`0`ooooo`007oooool2o`0006;ooooo3OnW_^X:ojO0j`KoZ<3[:onW`N`5ojO0k0SoYl7/0_nX`N`=
ojO1k003ojK0k?nW`NcoYl7/00KoYl7/1_nX`>/00onW`NcoZL3[o`000002o`0000CoZL3[1OnX_n/0
0ol0003oZ<3ZojS0jP08ojNoj`CoYl3/1?nW_n/8ojK0k1Kooooo00?o0000ooooooooool0<?ooool0
01oooooo00?o0000ooooool00000Goooool2ojNojP[oYkkZ3_nW`>/2ojS0jacoYl7/00?oYl3/ojO1
k?nW`N`03?nW`N`00onW`>_oYl3/ojO0k006ojO0k0KoYl7/0_nW`>`<ojO1k0CoY/3/2?nW`N`2ojS0
j`;oYl7/0ol00008ojW0j`;oZ;o[0onX`>X00ol0003oZ<3ZojS0jP08ojNoj`03ojO0k?nW_n_oYko[
00GoYko[1_nV`>`00onW`>coooooooooo`0Eooooo`03o`000?oooooooooo02oooooo000<ooooo`Go
00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00Co0000oooooooooooo0000Foooool6
ojNojPKoYkkZ4?nW`>/LojO1k0GoYl3/2_nW`N`5ojO0j`SoYl3/0_nW`N`6ojO0k0WoYl7/1onV`>`6
ojO1k003ojK0k?nW`Nco000000;o00001?nW`N`6ojW0j`03ojS1jonX`>[oZ<3Z00?oZ<3Z00Co0000
ojS0j_nX`>[oZ<3Z1_nW_n/2ojRojPSoYko[0_nV`>`5ojO0k1Oooooo00?o0000ooooooooool0;_oo
ool000cooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1_ooool2o`0000;ooooo00?o0000ooooooooool0EOooool:ojNojP?oYkkZ3onW`>/LojO1k003ojNo
jonW`>coYl3/00KoYl3/1_nW`N`00onW_n_oYl3[ojO0j`06ojO0j`KoYl3/00?oYko[ojO0k?nW`>`0
1onW`>`6ojO1k0[oY/3/0_nW`N`2ojK0k0?o00002?nW`N`2ojW0j`GoZ<7[1OnX`>X01?l0003oZ<3Z
ojS0j_nX`>X2ojNoj`KoZ;oZ1onW_n/8ojO0k1Kooooo00?o0000ooooooooool0;_ooool000Cooooo
1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4005ooooo`;o
00001?ooool00ol0003oooooooooo`1Aooooo`koYkoZ00?oYkkZojO0jonW`>/02onW`>/MojO1k0Co
Yko[2?nW`>`2ojO1k0GoYko[2?nW`>/2ojO0k0GoYko[2OnW`>`2ojO1k0koY/3/0ol00004ojK0k0Ko
Yl7/00?oY/3/ojS1jonX`N/01_nX`N/5ojS0jP03o`000?nX`N_oZ<7[00WoZ;oZ1onW_n/8ojO0k1Ko
oooo00?o0000ooooooooool0;Oooool000kooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooo
oooooooooooo000000Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1=ooooo`;o
Yko[3_nW_nX<ojO0jakoYl7/1onW_n/6ojO0k003ojNnj_nW_n_oYko[00KoYko[1_nW`>/00onW_^[o
Yko[ojNoj`06ojNoj`KoYl3/0_nW_^X>ojK0k0;o00002?nV`>`2ojO1k0GoY/3/2?nX`N/2ojS0jP;o
Z<7[00Co0000ojS1jonX`N_oZ<7[1onX_nX00onY`>_oYko[ojNoj`06ojNoj`KoYl3/00?oYko[oooo
ooooool05Oooool00ol0003oooooooooo`0/ooooo`003oooool00omgMgOoIVIVooooo`02ooooo`05
o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
04Wooooo1_nW_n/:ojNojPcoYl3[3onW`N`2ojO0k0koYl7/00?oYkkZojNojonW_n/01onW_n/2ojO0
k0GoYkkZ2?nW_n/2ojO0j`GoYkkZ2?nW_n/2ojO0k0KoYkkZ1onV`>`00onW_^[oY/3/ojK0k003o`00
01;oY/3/1_nX`N/00onW`>coZ<7[ojS1j`03ojS1j`03o`000?nX`N_oZ<7[00CoZ;oZ1OnY`>/8ojNo
j`;oYl3/1OnW_n/Eooooo`;o0000;_ooool0013ooooo00Go0000oooooooooooooooooa0@4003oooo
o`03oa0@4?oooooooooo00?ooooo0_l00007ooooo`03o`000?oooooooooo04Kooooo2OnW_n/6ojNo
jP03ojNojonW`>_oYl3[00WoYl3[3onW`N`6ojO0k0[oYl7/1OnW_^X7ojNoj`03ojRnj_nW_^[oYkkZ
00KoYkkZ1_nW_n/00onX_n[oYkkZojNnjP06ojNnjPKoYko[0_nX_nX8ojNnjPCoY/3/0_nW_^X3o`00
01KoY/3/0_nX`N/5ojO0k0GoZ<7[00Co0000ojS1jonX`N_oZ;oZ2?nY`>/6ojNoj`03ojRojonW_n_o
Yko[00KoYko[5_ooool00ol0003oooooooooo`0[ooooo`003?ooool01Ol0003o^[ZjoooooonHV9So
410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0@_ooool=ojNoj`;oYkoZ1OnW_n/7ojO0j`ooYl7/0_nW`>/8ojO0k0KoYl7/2OnW
_^X4ojNoj`CoZ;kZ2?nW_^X2ojNoj`GoZ;oZ2?nW_^X2ojNoj`KoZ;oZ2?nW_^X00onV`>coYkkZo`00
0002o`0000?oYkkZ1_nV`>`00onW_^[oY/3/ojK0k00=ojK0k0SoYl3/1OnX`N/00ol0003oYl3/ojW0
j`09ojW0j`;oYko[1OnX_n/8ojNojaGooooo00?o0000ooooooooool0:oooool000cooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo03kooooo0_nW`>/FojNoj`CoYl3[3_nW`N`6ojO0j`SoYl3/
0_nW`N`=ojNnjP03ojNojonX_^[oZ;kZ00GoZ;kZ1_nW_^X00onX`>_oZ;oZojRojP06ojRojPKoYkkZ
0_nY`>/8ojRojPKoYkkZ0ol00007ojNnjP;oY/3/1OnW_^X?ojK0k0SoYl3/0_nX`N/2ojO0k003o`00
0?nW`>coYl3/00SoZL3[00?oZ<7[ojRojonX_n/01OnX_n/8ojNojaKooooo00?o0000ooooooooool0
:_ooool001kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0jooooo`KoYl3[5_nW
_n/00onW`>_oYl7/ojO1k00<ojO1k0WoYl3[1_nW`>`?ojNnjP03ojRoj_nX_^[oZ;kZ00OoZ;kZ0_nW
_^X5ojS0j`SoZ;oZ0_nW_^X6ojW0j`SoZ;oZ0_nW_^X3o`0000;oZKoZ1onW_^X00onY_n[oYkkZojNn
jP06ojNnjPKoY/3/00?oYko[ojK0k?nV`>`01_nV`>`6ojO0k003ojK0k?nW`>coYl3/00?oYl3/00?o
0000ojO0k?nW`>`01?nY`>/5ojS1j`OoZ;o[2?nW_n/Fooooo`03o`000?oooooooooo02Wooooo000M
ooooo`?o00002oooool00ol0003oooooooooo`0fooooo`;oZ<3[2?nW`>/DojNoj`goYl7/3OnW`>/2
ojO0k0ooYkkZ1OnX_nX7ojRnjP;oZ<7[1onX`>/6ojRojP;oZ<7/2?nY`>/6ojRojP?o00001_nY_nX4
ojNnjPCoZKoZ2?nW_^X2ojK0k0GoYko[2?nV`>`2ojO0k0GoY/3/1OnW`>`01?l0003oYl3/ojO0k?nY
`>/7ojS1j`KoZ;o[00?oZL3[ojNojonW_n/01_nW_n/Fooooo`03o`000?oooooooooo02Wooooo000M
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0<_ooool6ojS0j`SoYl3[4?nW_n/>
ojO1k0koYl3[3onW_^X00onX_n_oZ;oZojRojP06ojRojPCoZ;kZ1OnX`N/7ojS0j`;oZ;oZ1_nX`N`8
ojW0j`;oZ;oZ0ol00002ojW1j`SoZKoZ00?oYkkZojVoj_nY_nX01OnY_nX6ojNnjP03ojVoj_nW_n_o
Yko[00KoYko[1_nV`>`00onV_n_oY/3/ojK0k006ojK0k0GoYl3/00?o0000ojK0k?nV`>`02?nX`N/2
ojRoj`GoZL3[2?nW_n/Fooooo`03o`000?oooooooooo02Sooooo000Mooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool0;oooool00onX`N_oZ<3[ojS0j`06ojS0j`KoYl3[00?oYkkZojNo
jonW_n/03?nW_n/AojO1k0[oYl3[3onW_^X5ojRoj`SoZ;oZ00?oZ;kZojS1jonX`N/01_nX`N/5ojS0
j`;oYl7/2?nX`N`6ojW0j`?o00001_nY`N/6ojVojP;oZ<7[2?nY_nX2ojNnjPGoZKoZ2?nW_n/2ojK0
k0GoY[o[2?nV`>`2ojO0k0;oY/3/00Co0000ojK0k?nV`>coY/3/1_nX`N/00onX`>_oZL3[ojW0j`06
ojW0j`KoYko[00?oZ;o[ooooooooool05Oooool00ol0003oooooooooo`0Wooooo`007Oooool2o`00
00oooooo00?o0000ooooooooool0:oooool5ojS1j`SoZ<3[0_nW`>/5ojNnjP[oYko[5OnW`N`6ojO0
j`ooYkkZ0_nX`>/7ojRoj`KoZ;oZ0onW`N`8ojS1j`03ojS0jonW`NcoYl7/00CoYl7/2?nX`N`2ojW0
j`03ojO1k?l0003o000000;oYl7/2?nY`N/2ojVojPKoZ<7[1_nY_nX00onY`N_oZKoZojVojP06ojVo
jPKoYko[00?oZ;oZojJojonV_n/01_nV_n/<ojK0k004o`000?nV`>coY/3/ojK0k0;oZ<7[1OnX`>/8
ojW0j`;oYko[1OnX_n/Fooooo`03o`000?oooooooooo02Oooooo000Mooooo`03o`000?oooooooooo
00oooooo0_l0000Xooooo`;oZ<7/1onX`N/6ojS0j`;oYko[1onW_^X6ojNojaWoYl7/0_nW`>/?ojNn
jPKoZ<3[1onX_n/2ojRojPOoYl7/1_nX`N/00onW`NgoYl7/ojO1k006ojO1k0KoZ<7/00CoYl7]o`00
0?l0003o00001OnW`N`6ojW1j`;oYl7/2?nX`N/2ojVojPGoZL7[2?nY_nX2ojNoj`GoZ;oZ2?nV_n/<
ojK0k003o`000?nV`>coY/3/00SoZ<3[1onY`>/8ojRojaKooooo00?o0000ooooooooool09_ooool0
01gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Rooooo`KoZ<7/1onX`N/2ojS0
j`KoYko[1onW_^X2ojNoj`coYl7/0_nX`N`=ojO1k0ooYkkZ0_nW`>/8ojS0j`GoZ;o[2onW`N`2ojS1
j`GoYl7]2?nW`N`2ojS1k005ojO1kOl0003o0000o`000?nW`Nd02?nW`N`2ojW1j`KoYl7/1_nX`N/0
0onW`NcoZL7[ojW1j`06ojW1j`KoZKoZ00?oZL7[ojRoj_nX_nX01_nX_nX6ojJoj`;oYko[3?nV`>`0
0ol0003oY/3/ojK0k008ojS0j`OoZL3[2?nX_n/Fooooo`03o`000?oooooooooo02Gooooo000Moooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool07_ooool:ojS1k0GoZ<7[2_nW_n/5ojNn
jP;oYl3/2onW`N`5ojS1k0WoYl7/3onW_^X6ojO0j`SoZ<3[00?oZ;o[ojO1k?nW`N`02onW`N`00onW
`^goYl7]ojO1k@06ojO1k@KoYl7/00CoY/7]o`000?l0003o00001OnW`Nd6ojO1k0;oY/7]2?nW`N`2
ojS1j`GoYl7/2?nY`N/2ojVojPGoZL7[2?nX_nX2ojJoj`KoYko[1_nV`>`00onV_n_oY/3/ojK0k002
ojK0k004o`000?nV`>coY/3/ojK0k0KoZ<3[00?oYl3/ojW0jonY`>/01_nY`>/6ojRoj`03ojS0jooo
oooooooo01Cooooo0_l0000Vooooo`007?ooool3o`0001Cooooo00?o0000ooooooooool06oooool=
ojS1k003ojS1jonW_n_oYko[00coYko[00?oYkkZojO0k?nW`>`01?nW`>`9ojO1k0OoZ<7/1_nW`N`?
ojNnjPWoYl3[1_nX`>/<ojO1k0GoYl;]2?nW`Nd2ojO1k005ojK1kOl0003o0000o`000?nV`Nd02?nW
`Nd2ojO1k0KoY/7]1_nW`N`00onV`NgoYl7/ojO1k006ojO1k0KoZL7[00?oYl7/ojW1jonY`N/01_nY
`N/6ojRojP03ojW0j_nW_n_oYko[00OoYko[0_nV`>`5ojJoj`CoY/3/00Co0000ojK0k?nV`>coY/3/
0_nX`>/5ojO0k0SoZL3[0_nX_n/5ojS0jaCooooo00?o0000ooooool000009_ooool001cooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`0Iooooo`goZ<7/0_nW`>/>ojNoj`SoYl3/1_nW
`N`:ojS1k0;oYl7/3onW_^X=ojO0j`;oZ<3[3OnW`N`8ojO2k@KoYl7]00CoY[o/o`000?l0003o0000
1OnV`Nd6ojO1k@;oY/3/2?nV`Nd2ojO1k0GoY/7]2?nW`N`2ojW1j`GoYl7/2?nY`N/2ojRojPGoZL3Z
1onW_n/00onY_n[oY[o[ojJoj`06ojJoj`CoY/3/00?o0000ojK0k?nV_n`02?nW`>`6ojW0j`03ojS1
jonX`>_oZ<3[00KoZ<3[5_ooool00ol0003oooooooooo`0Sooooo`002_ooool4o`000008oa0@4?oo
ooooooooonk^k_lb<S;o0000oc8b<_o^k^h6ooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool05_ooool3ojS1j`WoZ<7/1_nW`>/>ojNoj`SoYl3/0_nW`N`<ojS1k003ojNoj_nW_^[oYkkZ
00coYkkZ3onW`>/2ojO2k0ooYl7/2?nW`^d2ojO1k@05ojJok?l0003o0000o`000?nV_n`02?nV`Nd2
ojO1k@KoY/3/1_nV`Nd00onV_n_oY/7]ojK1k@06ojK1k@KoYl7/00?oY/7/ojO1k?nW`N`01_nW`N`6
ojW1j`03ojS1k?nY`>[oZL3Z00KoZL3Z1?nW_n/4ojVojPSoY[o[0_nV`>`00onV_nco0000ojJok002
ojJok0SoYl3/0_nY`>/5ojS1j`SoZ<3[5Oooool00ol0003oooooooooo`0Sooooo`003?ooool00ol0
003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo01;ooooo1onX`N/5ojS1k0;oZ<3[2?nW`>/>ojNoj`KoYl3/3?nX`N`5
ojNojP[oYkkZ3onW`>/6ojO2k0ooYl7/1_nW`^d01?nW_^[o0000o`000?l00005ojJok0KoY/7]0_nW
_^X8ojK0k0;oY/7]1OnV_n/8ojK1k@;oYl7/1OnV`N`8ojO1k0;oZL7[1OnX`N`8ojW0jP03ojNojonY
_n[oZKoZ00GoZKoZ1_nV_n/00onW_n_oY[o/ojJok002ojJok004o`000?nV_ncoY[o/ojJok0KoYl3/
00?oY/3/ojS1jonX`N/01OnX`N/8ojS0jaKooooo00?o0000ooooooooool08_ooool00003ooooool0
003o000000Co00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100
1_ooool2o`0001Wooooo00?o0000ooooooooool03_ooool3ojNoj`SoZ<7[00?oZ<7/ojS0jonX`>/0
1?nX`>/8ojO0j`koYko[0_nW`>`<ojS1k0;oYko[1onW_nX6ojNnjP;oYko[3OnW`>/:ojO2k0ooYl7/
0_nW`^d2ojNnjP;o000000?oYkkZojJok?nV_n`01_nV_n`2ojK1k@KoYkkZ1_nV`>`00onW_NWoY[o[
ojJoj`06ojJoj`KoY/7]00?oY[o[ojK1k?nV`N`01_nV`N`6ojO1k003ojK1k?nX`NcoZ<7/00KoZ<7/
1_nY`>X2ojW1j`SoZKoZ0_nV_n/5ojNoj`CoY[o/00Co0000ojJok?nV_ncoY[o/0_nW`>`5ojK0k0Oo
Z<7[2?nX`>/Fooooo`03o`000?oooooooooo027ooooo000<ooooo`03o`000?oooooooooo00;ooooo
00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool02_ooool7ojNoj`OoZ<7[2?nX`>/6ojO0j`03ojNnjonW_n_oYko[00_oYko[3?nX`N`6ojNoj`Oo
YkoZ0_nW_^X6ojNoj`WoYl3[3?nW`^`?ojO1k003ojNmjOnW_^[o000000;o00001?nW_^X6ojJok003
ojRmjOnW_^[oYkkZ00OoYkkZ0_nV`>`5ojNmj@SoY[o[0_nV`Nd5ojJoj`SoY/7/0_nW`N`5ojK1k0So
Z<7/0_nY`>X6ojW1j`KoZKoZ00?oZL3ZojNojonW_n/01OnW_n/5ojJok003o`000?nV_ncoY[o/00Oo
Y/3/1_nX`N/:ojS0jaGooooo00?o0000ooooooooool08Oooool000cooooo00?o0000ooooooooool0
0_ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`07ooooo`[oYko[1onX`N/8ojS0j`;oYl3[1OnW_^/9ojNoj`goZ<7/00?oZ<3[ojNojonW
_n/01_nW_n/5ojNojP[oYko[1OnW`>/<ojO2k0ooYl7/0_nW_NT3o`0000SoYkkZ0_nV_n`5ojRmj@Oo
YkkZ00?oZKoYojNmjOnW_NT01_nW_NT6ojJoj`03ojRnjOnV_n_oY[o[00KoY[o[1_nV`N`00onV_nco
Y/7/ojK1k006ojK1k0KoZ<7/0_nV`>`8ojW1j`;oZKoZ1OnY`>X7ojNoj`CoY[o/00Co0000ojJok?nV
_ncoY[o/1onV`>`2ojS1j`coZ<3[00?oZL3[ooooooooool05?ooool00ol0003oooooooooo`0Poooo
o`003?ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo00?ooooo3?nW_n/2ojS1k0OoZ<7[1_nX`>/2ojNo
j`OoYkk[1_nW_n/<ojS1k0GoZ<3[2?nW_n/00onW_n[oYko[ojNoj`0<ojNoj`03ojO0jonW`^coYl;/
00[oYl;/3onW`N`2ojNmj@?o00001?nW_NT6ojNnjP03ojRnjOnX_NWoZ;gY00KoZ;gY1?nW_^X4ojVo
j@SoYkgY0_nV_n/5ojRnj@SoY[o[0_nV`N`5ojJok0SoY/7/0_nX`N`6ojK0k0KoZL7[00?oZ<3[ojW0
j_nY`>X01OnY`>X6ojNoj`03ojRojonV_ncoY[o/00?oY[o/00?o0000ojJok?nV_n`01_nV`>`2ojJo
k0[oZ<3[1OnY`>/Fooooo`03o`000?oooooooooo01oooooo000<ooooo`03o`000?oooooooooo00;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o00007_ooool00ol0003oooooojNoj`0;ojNo
j`KoZ<7/1onX`N/2ojS0j`KoYko[1onW_^/2ojNoj`koZ<7/1onX`>/6ojNoj`03ojNnj_nW_n_oYko[
00coYko[0_nW`N`9ojO2k0ooYl7/0_nW_NT3o`0000SoYkgY0_nW_^X5ojRnj@SoZ;gY00?oYkkZojVo
jOnY_nT01OnY_nT6ojNmj@03ojW0j_nX_^WoZ;kY00KoZ;kY1_nV_n/2ojRnj@OoY[o/1_nV`N`2ojG0
k0SoY/3/0_nY`N/5ojS0j`OoZL3Z0_nW_n/5ojRoj`GoY[o/00?o0000ojJok?nV_n`00_nV`>`6ojJo
k0OoZ<3[2?nY`>/Eooooo`03o`000?oooooooooo01oooooo000:ooooo`03oeEEEOmVIVKo000000Co
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo01cooooo3OnW_n/2ojO0
j`OoZ<7/1OnX`N/2ojS0j`SoYko[1OnW_^/3ojO0j`ooZ<7/1onX`>/2ojNoj`GoYkkZ2_nW_n/6ojO1
k0KoYl;/00?oZ<7/ojO1k?nW`N`03?nW`N`01?nX_NWo0000o`000?l0000:ojNmj@;oZ;oZ1onX_^T6
ojRmj@;oZL3[2?nY_nT2ojNmj@GoZL3Z2?nX_^T2ojJoj`KoZ;kY1onV_n`2ojK1k0KoYL3/1onV`>`7
ojS0j`KoZL3Z00?oZL7[ojRojonX_n/01_nX_n/5ojJok003o`000?nV_ncoY[o/00SoY[o/1onX`>/8
ojW0jaGooooo00?o0000ooooooooool07_ooool001_ooooo00?o0000ooooooooool06_ooool3ojO0
j`WoYko[1_nW`>/7ojS1k003ojS1jonX`>_oZ<3[00CoZ<3[2?nW_n/00onW_^_oYl3[ojO0j`05ojO0
j`ooZ<7/1OnX`>/9ojNnjPKoYko[2_nW`N`2ojO2k0GoZ<7/2_nW`N`01OnX_NWo0000o`000?l0003o
Z;gY00WoYkgY1_nX_nX7ojRnj@;oZ;gY1_nY`>/6ojVoj@03ojS1jonY`>[oZL3Z00KoZL3Z1_nX_^T0
0onZ`>[oZ;kYojRnj@07ojRnj@?oY[o/1?nW_^X8ojG0k0OoY/3/1onX`>/2ojW0jPGoZL7[2?nX_n/4
ojJok003o`000?nV_ncoY[o/00SoY[o/2?nX`>/7ojW0jaKooooo00?o0000ooooooooool07Oooool0
01_ooooo00?o0000ooooooooool05oooool7ojO0j`OoYko[2?nW`>/5ojS1k0;oZ<7[1onX`>/6ojNo
j`;oY[o[2?nW`>/?ojS1k003ojS0jonW_^[oYkkZ00_oYkkZ0_nW_n/<ojO1k003ojS2k?nX`NcoZ<7/
00KoZ<7/1_nW`N`01?nW_NWo0000o`000?l00005ojRmj@KoYkgY00?oZ<3[ojRoj_nX_nX01_nX_nX5
ojRnj@;oZ<7/2?nY`>/2ojVoj@GoZ<7[2?nY`>X2ojRnj@GoZ/3Z1onX_^T00onZ`>WoYkkZojNnjP06
ojNnjPKoYL3/00?oY[o[ojK0k?nV`>`01OnV`>`6ojS0j`03ojO0k?nY`N_oZL7[00KoZL7[1_nX_n/2
ojW0jPCoY[o/00?o0000ojJok?nV_n`02?nV_n`8ojS0j`OoZL3[5?ooool2o`0001oooooo000Koooo
o`;o00005_ooool3ojS0j`OoYl3[1onW_n/8ojO0j`03ojS1k?nX`N_oZ<7[00CoZ<7[1onX`>/2ojNo
j`KoY[o[1_nW`>/?ojS1k003ojNoj_nW_^[oYkkZ00_oYkkZ3?nW`N`5ojS2k0SoZ<7/0_nW`N`2ojNm
j@;o000000?oYkgYojRmjOnX_NT01_nX_NT2ojNmj@GoZ<3[2?nX_nX00onX_^WoZ<7/ojS1k004ojS1
k0KoZL3[00?oYl;]ojS1jonX`N/01_nX`N/6ojW0jP03ojS1k?nZ`>[oZ/3Z00KoZ/3Z1?nX_^T4oj[0
j@SoYkkZ0_nU`>`5ojJoj`OoY/3/0_nX`>/5ojO0k0SoZL7[0_nX_n/6ojW0jPCoY[o/00?o0000ojJo
k?nW_n/02?nV_n`6ojS0j`03ojO0jonY`>_oZL3[00GoZL3[5_ooool00ol0003oooooooooo`0Loooo
o`006_ooool00ol0003oooooooooo`0Cooooo`OoZ<3[1OnW`>/9ojNoj`KoYl3[2OnX`N/5ojS0j`?o
Ykk[1onV_n/2ojO0j`ooZ<7/1OnW_nX9ojNnjPcoYl7/2OnX`^`6ojS1k0;oYkgY0ol00004ojNmj@Ko
Z;gY2OnX`>/6ojRojP;oYl;]1onX`N`2ojW0j`GoYl;]2?nX`N/2ojW0jPGoZ<7/2?nZ`>X00onX_^Wo
Z/3Yoj[0j@05oj[0j@KoYkkZ00?oZKoYojJojonV_n/01OnV_n/6ojK0k003ojFok?nW`>coYl3/00Ko
Yl3/1_nY`N/2ojS1j`SoZL3Z0_nV_n`2ojNoj`03o`000?nW_n_oYko[00SoY[o/0_nX`>/5ojO0j`Oo
ZL3[5Oooool00ol0003oooooooooo`0Looooo`006_ooool00ol0003oooooooooo`0@ooooo`?oZ<7[
2?nX`>/00onW`>_oYko[ojNoj`0;ojNoj`;oYl3[3OnX`N/00onX`>_oYkk[ojNnj`05ojNnj`GoY[o[
0_nX`N/=ojS1k0;oZ<3[1onW_nX6ojNnjP;oYko[2OnW`N`=ojS2k0;oZ<7/0_nW_NT3o`0000SoYkgY
0_nX_NT=ojS0j`;oZ;oZ1_nW`^d5ojS1k0;oY/?^1onW`^d6ojS1j`03ojK2kOnX`NcoZ<7/00KoZ<7/
1_nZ`>X2ojS1j`SoZ/3Y0_nW_^X5ojVoj@OoY[o[0_nV`>`5ojFok0SoYl3/0_nY`N/6ojS1j`OoZL3Z
1?nW_n/00ol0003oYko[ojNoj`08ojJok0OoYl3[1_nY`>/2ojW1jaGooooo00?o0000ooooooooool0
6oooool001[ooooo00?o0000ooooooooool03Oooool7ojS1j`KoZ<3[00?oYl3[ojNojonW_n/02onW
_n/?ojS1j`?oYko[1onW_^/00onV_n_oZ<7[ojS1j`04ojS1j`WoZ<7/1_nX`>/7ojNojP;oYkkZ1_nW
_n/6ojO1k0koZ<;/0_nW_NT3o`0000[oYkgY0_nW`>/=ojS0j`;oYl?]2?nW`^d00onX`NcoY/?^ojK3
kP04ojK3kPOoYl;]0_nX`N/5ojK2k@SoZ<7/0_nZ`>X6ojS1j`KoZ/3Y00?oZL7[ojVojOnY_nT01OnY
_nT6ojJoj`;oYkoZ1onU_n`6ojO0k0;oY/3/2?nX`N/7ojW0jPCoYko[00?o0000ojNojonW_n/02?nV
_n`7ojO0j`;oZL3[1_nY`N/Eooooo`03o`000?oooooooooo00Kooooo1Ol0000?ooooo`006_ooool2
o`0000_ooooo1?nX`>/7ojS1j`;oZ<3[1OnW`>/9ojNoj`ooZ<7[1onW_n/5ojNnj`;oYko[1onX`N/6
ojS1k0;oZ<7[1onX`>/5ojNojP?oY[k[1onW_n/2ojO1k0koZ<;/0_nW_NT3o`0000[oYkgY1_nW`>/9
ojS0j`KoYl?]1_nW`^d9ojK3kPGoYl;]0_nU`^h7ojK2k@KoZ<7/0_nV`^d8ojS1j`;oZ/3Y1OnY`N/7
ojVoj@;oY[o[1_nW_nX7ojFok0;oYl3/1_nV`>`6ojS1j`03ojS0jonY`>[oZL3Z00GoZL3Z1OnW_n/0
0ol0003oYko[ojJok007ojJok0SoYl3[2?nY`N/Dooooo`03o`000?oooooooooo00Kooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A00?ooooo`006_ooool00ol0003oooooooooo`06ooooo`;oYko[1onX`>/5
ojS1j`;oZ<3[1onW`>/9ojNoj`[oZ<7[1?nX`>/8ojNoj`03ojNnjonW_n_oYko[00CoYko[1onX`N/2
ojS1k0KoZ<7[1onX`>/00onW_n[oY[k[ojJnj`05ojJnj`GoYko[0_nX`N`=ojS2k004ojRnj_l0003o
0000o`0000[oYkgY0onW_n/7ojO0j`?oZ<3[3?nW`nd2ojO2k@goY/?^00?oYl;]ojG2k_nU`^h01?nU
`^h7ojK2k@;oZ<7/1_nV`^d6ojS1j`03ojK2kOnY`N_oZL7[00KoZL7[1OnY_nT2oj_1jPSoYkoZ1onU
_n`8ojK0k0;oZ<7[1OnX`>/7ojW0jPCoYko[00?o0000ojNojonW_n/02?nV_n`8ojO0j`OoZL7[5Ooo
ool00ol0003oooooooooo`06ooooo`03oiRHV?lQ8B7ok^k^013ooooo000Jooooo`03o`000?oooooo
oooo00?ooooo1_nW_n/7ojS0j`03ojS1jonX`>_oZ<3[00CoZ<3[1onW`>/9ojNoj`OoZ<7[1onX`>/6
ojNoj`03ojJnjonW_n_oYko[00KoYko[1OnX`N/3ojS1k0OoZ<7[0onX`>/4ojJnjPSoY[k[00?oYko[
ojS1k?nX`N`01?nX`N`9ojS2k005ojRnj_l0003o0000o`000?nX_^X02OnW_NT7ojNoj`GoYl3[3onW
`nd2ojK1k@goY/?^0_nU_^/7ojG2kP?oY/;]1?nT`Nh8ojK2k@;oZ<7[1OnV`^d8ojW1j`03ojVojOn[
`N[oZl7Z00CoZl7Z1_nW_nX00onY_n[oYKo/ojFok006ojFok0KoY/3/00?oY[o/ojS0jonX`>/01OnX
`>/6ojW0jP;oZL7Z1?nW_n/00ol0003oYko[ojNoj`08ojJok0SoYl3[1onY`N/Eooooo`03o`000?oo
oooooooo00Kooooo00?oV9RHob4Q8Oo^k^h03oooool001[ooooo00?o0000ooooooooool02_nW_n/5
ojS0j`;oZ<7[1onX`>/5ojO0j`_oYko[1onX`N/7ojS0j`;oYko[1OnV_^/8ojNoj`03ojS1jonX`Nco
Z<7/00GoZ<7/1OnX`N/2ojNoj`OoY[kZ1_nV_^/9ojS1k0GoZ<;/00CoZ<3[o`000?l0003o00001OnX
_^X6ojNmj@;oYkk[2?nW_n/00onW`>_oYl?]ojO3k@0=ojO3k@KoY/7]2OnV`nh6ojFnj`GoYL;^00?o
YKcYojC1k_nT`Nh01_nT`Nh6ojK2k@03ojC1k_nV`^goY/;]00KoY/;]1_nY`N/00onW`NcoZl7Zoj_1
jP06oj_1jP;oYkoZ1OnY_nX8ojFok0;oY/3/1OnV_n`7ojS0j`;oZL3Z1_nY`NX4ojNoj`03o`000?nW
_n_oYko[00SoY[o/1onW`>/7ojW1jaGooooo00?o0000ooooooooool01oooool00omgMgOoIVIVoooo
o`0>ooooo`006Oooool00ol0003oYko[ojNoj`0<ojNoj`03ojS0jonX`N_oZ<7[00CoZ<7[1onX`>/0
0onW`>_oYko[ojNoj`0;ojNoj`WoZ<7[1OnX`>/2ojNoj`OoY[k[1_nW_n/2ojS1j`SoZ<7/00?oZ<7[
ojNojonW_n/01?nW_n/7ojJnjP;oY[k[3OnX`N`00onX`^coZ<3[o`000002o`0000?oZ<3[1_nX_^X2
ojNmj@KoYkk[1_nW_n/>ojO3k@;oYl7/2?nV`Nd3ojK3kPCoY[cX2?nU_^/00onU`^koYKcYojFlj@03
ojFlj@SoY<7^0_nV`^d5ojC1kPSoY/;]0_nY`N/5ojO1k0KoZl7Z00?oZ/7ZojVoj_nY_nX01_nY_nX6
ojFok0WoY[o/1OnX`>/2ojO0j`SoZL7Z0onW_n/01?nW`>_o0000ojO0jonW`>/8ojJok0OoYl3[1onY
`N/Eooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03Oooool001Wooooo00?o0000
ojNojonW_n/02onW_n/2ojS0j`OoZ<7[1OnX`>/<ojNoj`goZ<7[00?oZ<3[ojNojonW_n/01?nW_n/7
ojJnj`;oYko[1_nX`N/6ojS1k003ojS1jonW_n_oYko[00KoYko[1OnV_^X2ojNoj`goZ<7/00?oZ<;/
o`000?l000001onX`>/3ojRnjPCoY[gZ1onW_^/2ojNoj`koYl?]1_nW`N`6ojK1k@03ojRkionV_>So
Y[cX00KoY[cX1_nU_^/00onY_>OoYKcYojFlj@05ojFlj@KoY<7^0_nU_>T7ojC1kPKoY/;]0_nU`Nd7
ojO1k0;oZl7Z1OnZ`NX8ojVojP;oYKo/3OnV_n`00onX`>_oYl3[ojO0j`04ojO0j`KoZL7Z00?oZL7[
ojO0jonW`>/00_nW`>/01?l0003oYl3[ojO0jonW`>/7ojJok0OoYl3[2?nY`N/Dooooo`;o00001?oo
ool01Ol0003o^[ZjoooooonHV9So410@00oooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1_ooool00ol0003oooooojNoj`08ojNoj`KoZ<3[1onX`N/00onX`>_oYko[ojNoj`0<ojNoj`goZ<7[
0_nX`>/7ojNoj`GoY[k[0onW`>/7ojS1j`;oZ<7/1OnX`N/8ojNoj`03ojJnj_nW_n_oYko[00CoYko[
2OnX`N`01?nX`^co0000o`000?l00002ojS2k0KoZ<3[00?oY[gYojJmj_nV_NX01_nV_NX5ojNnj`03
ojO2kOnW`ngoYl?]00coYl?]2OnW`N`2ojK1k@GoZ;_W2?nV_>P2ojFnj`GoZKcW1onU_>T2ojC1kPKo
YKcY1onT`Nh2ojK2k@KoYL7]1OnW`N`00onV`NcoZ/7Zoj[1jP06oj[1jPKoZKoZ0_nZ`>X=ojJok003
ojFok?nW`>_oYl3[00KoYl3[0_nY`NX5ojW1j`CoYl3[00Co0000ojO0jonW`>_oYl3[1onV_n`7ojO0
j`SoZL7[4_ooool00ol0003oooooo`000004ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03oooool0
00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00SoYko[1onX`>/5
ojS1j`?oZ<3[3_nW_n/9ojS1j`KoZ<3[1onW_n/00onV_^_oYl3[ojO0j`05ojO0j`koZ<7[1_nW_n/0
0onV_^_oYko[ojNoj`06ojNoj`GoZ<7/00CoZ<;/o`000?l0003o00001_nX`^`2ojS0j`GoY[gY2?nV
_NX00onW_^_oYl;]ojO2k@03ojO2k@[oYl?]2onW`N`9ojRki`KoY[cX00?oZ[kXojVlionY_>L01_nY
_>L5ojFlj@;oZkkW2?nU_>T3ojC1kPCoY;g[2?nU`Nd00onW`NcoY/7/ojK1k003ojK1k0SoZ/7Z0_nY
_nX6oj[0jPWoY[o/1OnU_n`7ojO0j`SoZL7[1?nW`>/00ol0003oYl3[ojO0j`07ojJok0SoYl3[2?nY
`N/Dooooo`03o`000?oooooooooo01Gooooo000>ooooo`05oa0@4?ooooooooooooooool@41001_oo
ool2o`0000;ooooo2?nW_n/7ojS0j`03ojS1jonX`>_oZ<3[00GoZ<3[1OnW_n/2ojJoj`OoYko[2?nX
`N/7ojS0j`GoYko[0onV_^/7ojO0j`koZ<7[0_nW_n/5ojJnj`SoYko[00?oZ<7/ojS2k?l000000_l0
0008ojS2k0;oYkkZ1onV_NT6ojJmjP03ojO1k?nW`^goYl;]00GoYl;]1_nW`nd2ojS2k0WoYl7/3OnX
^nL2ojJlj0GoZ[kX2?nY_>L00onU_>WoZkkWoj^ni`04oj^ni`KoYKcY00?oZkkWojBmjonT_N/01_nT
_N/6ojG1k@03oj>okOnV`NcoY/7/00GoY/7/1_nZ`NX00onY`N_oZ/3Zoj[0jP07oj[0jP?oY[o/0onV
_n/8ojFok0OoYl3[2?nY`N/4ojO0j`03o`000?nW`>_oYl3[00OoY[o/2?nW`>/7ojW1jaGooooo00?o
0000ooooooooool05?ooool000kooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oo
oooooooo00?ooooo1onW_n/3ojS0j`GoZ<7[1onX`>/00onW_n_oY[o[ojJoj`04ojJoj`OoYko[2?nX
`N/7ojS0j`03ojNojonV_^_oY[k[00GoY[k[1OnW`>/>ojS1j`WoY[k[1_nW_n/3o`0000SoZ<;/1_nW
_^X7ojJmj@;oY[gZ1OnW`N`7ojO2k@;oYl?]1_nX`^`6ojO1k003ojNkionX^nOoZ;_W00_oZ;_W00?o
ZL3ZojZnj?nZ_^P01_nZ_^P6ojVli`03oj_1j_n[_^OoZkkW00KoZkkW0_nU_>T5oj^ni`SoY;g[0_nU
`Nd5oj>ok@OoY/7/0_nZ`NX5ojW1j`OoZ/3Z00?oZl7ZojJojonV_n/01OnV_n/7ojFok0SoYl3[1onY
`N/4ojO0j`03o`000?nW`>_oYl3[00KoY[o/0_nV_n/8ojO0j`OoZL7[5?ooool00ol0003ooooooooo
o`0Dooooo`003_ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool01Ooo
ool5ojNoj`;oZ<3[2?nX`N/5ojS0j`;oYko[1onV_n/5ojNoj`[oZ<7[0onX`>/4ojNoj`SoY[k[00?o
Yl3[ojS1jonX`N/03?nX`N/=ojJnj`;oYko[0ol00003ojS1k0KoZ<;/00?oZ<7[ojNnj_nW_^X01_nW
_^X5ojJmj@03ojNojonW`NcoYl7/00KoYl7/1OnW`^d3ojS3k@OoZ<;/0_nW`N`5ojNki`WoZ;_W1OnY
`>X8ojZnj0;oZKcW1On[`NX6oj^ni`03oj_1j_n[_^OoZkkW00KoZkkW1_nT_N/2ojRnj@KoXko]1_nV
`N`2ojG0k@OoZL7[1?nZ`>X4oj_1jPOoY[o[1onU_n`8ojO0j`OoZL7[1?nW`>/00ol0003oYl3[ojO0
j`02ojJok0KoY[o[1_nW`>/00onX`>_oZL7[ojW1j`05ojW1jaGooooo00?o0000ooooooooool04ooo
ool000kooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo00Kooooo00?o
Yko[ojS0jonX`>/01?nX`>/8ojS1j`03ojS0jonW_n_oYko[00CoYko[1onV_n/00onW_n_oZ<7[ojS1
j`0:ojS1j`;oZ<3[1onW_n/6ojJnj`03ojO0jonX`N_oZ<7[00_oZ<7[0_nX`>/<ojJnj`?o00001onX
`N`2ojS2k0GoZ<7[2?nW_^X00onV_NWoYko[ojNoj`03ojNoj`SoYl7/00?oYl;]ojS3kOnX`nd01OnX
`nd5ojS2k0WoYk_W1_nX^nL00onX`>_oZL3ZojW0jP05ojW0jPKoZ[kX0_nW`>/7oj_1jP?oZkkW1?n[
`NX8oj^ni`;oY;g[1_nX_^T6oj>ok@;oY/7/1_nU`>d7ojW1j`03oj[0j_n[`N[oZl7Z00CoZl7Z1_nV
_n/00onW_n_oYKo/ojFok006ojFok0OoYl3[2?nY`N/4ojO0j`03o`000?nW`>_oYl3[00SoY[o[0_nW
`>/5ojS0j`OoZL7[5Oooool00ol0003oooooooooo`0Booooo`003_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_l00008ooooo`OoZ<3[1_nX`N/2ojS0j`OoYko[1OnV_n/3ojNoj`SoZ<7[1_nX
`>/7ojNoj`;oY[k[1OnW`>/9ojS1j`KoZ<3[2?nV_^/3o`0000CoZ<3[1OnX`N`2ojW2k0OoZ<7[1_nW
_^X2ojJmj`KoYko[1_nW`N`2ojW4k@SoZ<?]00?oZ<;/ojNkionW^nL02onW^nL2ojRki`GoZ<3[1onY
`>X2ojZnj0KoYl3[1on[`NX00on[_^OoZl7Zoj_1jP04oj_1jPKoZkkW00?o[L;YojRnjOnX_^T01onX
_^T3oj>ok@?oY;k/2?nU`>d3ojW1j`CoZ<3[1on[`NX2ojJoj`GoYko[2?nU_n`7ojO0j`OoZL7[1?nW
`>/01?l0003oYl3[ojO0jonW`>/7ojJoj`OoZ<3[1_nY`N/00onX`N_oooooooooo`0Cooooo`03o`00
0?oooooooooo01;ooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003ooooo
ooooo`08ooooo`OoZ<3[0_nX`N/6ojS0j`OoYko[00?oY[o[ojNojonW_n/01OnW_n/7ojS1j`OoZ<3[
1OnW_n/2ojJoj`OoYl3[2?nX`N/7ojS0j`GoY[k[0_l00008ojS0j`03ojS1k?nY`^coZL;/00CoZL;/
1onX`N/2ojNnjPKoY[g[1_nW_n/2ojO1k0KoZLC]1_nX`nd00onW_>SoYk_WojNki`0;ojNki`03ojO0
jonX`>_oZ<3[00KoZ<3[1OnY`>X2ojO2k@SoYl3[0on[`NX4ojO1k0OoZl7Z0_n[_^L5ojg2j@OoZ;kY
00?o[<3XojBnk?nT_^`01OnT_^`6ojG0k@03ojBokOnX`>_oZ<3[00KoZ<3[1on[`NX7ojNoj`OoYKo/
2?nW`>/7ojW1j`CoYl3[00Co0000ojO0jonW`>_oYl3[1onV_n/7ojS0j`;oZL7[1OnX`N/Eooooo`03
o`000?oooooooooo017ooooo000Hooooo`03o`000?oooooooooo00Wooooo1OnX`>/3ojS1j`OoZ<3[
0onW_n/4ojJoj`SoYko[1onX`N/7ojS0j`03ojNojonV_n_oY[o[00CoY[o[1onW`>/8ojS1j`GoZ<3[
0onV_^/3o`0000?oY[k[1_nX`>/2ojS1k0OoZL;/1OnX`N/2ojFmjPSoY[g[0onW_n/4ojS2k@OoZLC]
0_nX`nd5ojNlj0WoYk_W1OnW`>/8ojS0j`03ojW0j_nW`^goYl;]00CoYl;]1_nW`>/00onW_n_oYl7/
ojO1k006ojO1k0GoZl7Z00?oYl3[ojg2jOn]`^T01_n]`^T4ojRnj@Co[<3X1onT_^`2ojG0k@GoY;o]
2?nX`>/7oj_1jPOoYko[1onU_n`7ojO0j`SoZL7[1?nW`>/00ol0003oYl3[ojNoj`07ojJoj`OoZ<3[
2?nX`N/Eooooo`03o`000?oooooooooo013ooooo000Hooooo`03o`000?oooooooooo00[ooooo00?o
Z<3[ojS1jonX`N/01OnX`N/5ojS0j`;oYl3[1onV_n/6ojNoj`WoZ<7[1OnX`>/3ojNoj`KoY[o[1OnW
`>/:ojS1j`04ojS0jonV_^_oY[k[ojJnj`?o00001onV_^/2ojS0j`KoZ<7/1onY`^`00onX`N_oYKgZ
ojFmjP04ojFmjPKoY[g[00?oZ<7/ojS2kOnX`^d01_nX`^d5ojW4k@03ojRoj_nW_>SoYkcX00KoYkcX
1OnW^nL3ojJoj`KoYl3[1_nX`>/9ojO2k@;oYl3[1OnW_n/8ojO1k003oj_1j_nW`>_oYl3[00?oYl3[
2?n]`^T00onX_^Wo[<3Xojc0j005ojc0j0GoY;k/00?oYKk[ojBokOnT_nd01_nT_nd6ojS0j`03ojO0
jon[`N[oZl7Z00KoZl7Z0onW_n/4ojO0k0OoYKo/1onW`>/8ojW1j`;oYl3[0_nW_n/00ol0003oYko[
ojNoj`07ojJoj`OoZ<3[1onX`N/Eooooo`;o00004Oooool001Oooooo0ol0000=ooooo`OoZ<7[00?o
Z<3[ojO0jonW`>/01?nW`>/7ojJoj`;oYko[3OnX`N/00onX`>_oYko[ojNoj`05ojNoj`KoY[o[00?o
Yl3[ojS1jonX`N/02_nX`N/2ojS0j`?o00002OnV_^/3ojS1j`OoZ<7/0onY`^`4ojNoj`OoYKgZ0_nV
_N/5ojS1k0SoZ<;]00?oZLC]ojRoj_nX_nX00onX_nX8ojNlj003ojNkionV_n_oY[o[00GoY[o[1_nW
`>/2ojS0j`_oYl;]00?oY:gNojNojonW_n/01_nW_n/6ojO1k0;oY[gZ1_nW`>/6ojg2j@;oZ/7Z2?n/
`>P00onT_^coYKk[ojFnj`03ojFnj`SoY;o]0_nX`>/5ojO0j`OoZl7Z2?nW`>`5ojFok003ojFojonW
`>_oYl3[00KoYl3[1onY`N/4ojNoj`04o`000?nW_n_oYko[ojNoj`OoY[o[1onX`>/7ojS1ja?ooooo
00?o0000ooooool000004Oooool001Oooooo00?o0000ooooooooool03_ooool5ojS1j`;oZ<3[1onW
`>/5ojJoj`?oYko[3?nX`N/2ojS0j`SoYko[0onV_n/4ojO0j`SoZ<7[0_nX`>/3o`000003ojS0jonV
_^_oY[k[00KoY[k[1onX`N/5ojS1k0;oZL;/1onW_n/5ojFmjP;oY[k[1onX`N`6ojS2k@;oZL?/1_nX
_nX6ojNlj0;oYKgZ2?nV_n/3ojO0j`coYl;]1OnT[Mh8ojNoj`;oYl7/1_nV_NX6ojO0j`;o[L;Y1_nZ
`NX6ojc0j003ojg1j?nU_^_oYKk[00GoYKk[1_nT_nd2ojBnk0OoYl3[1on[`NX8ojO0k003ojFok?nU
_n_oYKo[00?oYKo[2?nW`>/7ojW1j`CoYko[00?o0000ojNojonV_n/02?nV_n/5ojS0j`WoZ<7[5?oo
ool00ol0003oooooooooo`0?ooooo`005oooool00ol0003oooooooooo`0?ooooo`03ojS1jonX`>_o
Z<3[00CoZ<3[1onW`>/00onV_n_oYko[ojNoj`05ojNoj`SoZ<7[1_nX`>/6ojNoj`03ojJojonW`>_o
Yl3[00KoYl3[1_nX`N/3o`0000GoZ<3[1onV_^/8ojS1j`03ojS1k?nY`^coZL;/00CoZL;/1onW_n/0
0onU_N[oY[k[ojJnj`04ojJnj`OoZ<7/0_nX`^d6ojW3k0KoZ;oZ0_nW_>P6ojFmjPKoY[o[3_nW`^d0
0onUXM;oY:gNojB]gP05ojB]gPKoYko[0_nVXm88ojJmjP?oYl3[0onW`^d8oj[1jP;o[<3X1On]`NP7
ojFnj`;oY;o]1_nT_^`6ojO0j`SoZl7Z1_nW`>`00onV_ncoYKo[ojFoj`05ojFoj`KoYl3[00?oZ<3[
ojW1jonY`N/01_nY`N/2ojNoj`;oY[o[00?o0000ojJojonV_n/02?nV_n/00onX`>_oZ<7[ojS1j`0;
ojS1jaCooooo00?o0000ooooooooool03_ooool001Oooooo00?o0000ooooooooool04?ooool7ojS0
j`GoYl3[0onV_n/7ojNoj`OoZ<7[1onX`>/2ojNoj`GoY[o[2?nW`>/2ojS1j`?o00000_nX`N/7ojS0
j`OoY[k[1_nX`N/00onY`N_oZL;/ojW2k006ojW2k0GoYko[00?oYKgZojJnjonV_^/01_nV_^/5ojS1
k0[oZL?/0onX_nX4ojFjj0OoYKgZ0_nV_n/>ojO2k@GoYJ7B1onT[Mh2ojNoj`KoYZ?B1_nV_NX00onW
/MooYl;]ojO2k@05ojO2k@KoZ/7Z0_nX`>/7ojg1j0?oYKk[1?nV_n/8ojBnk0KoYl3[2?n[`NX2ojO0
k0GoY[o/1onU_n/2ojO0j`GoZ<3[1onY`N/5ojJoj`03o`000?nV_n_oY[o[00OoY[o[3OnX`N/00onX
`>_oooooooooo`0Cooooo`03o`000?oooooooooo00gooooo000Gooooo`;o00004_ooool7ojS0j`03
ojO0jonV_n_oY[o[00GoY[o[1OnW_n/9ojS1j`GoZ<3[0_nW_n/7ojJoj`KoYl3[0ol00006ojS1j`?o
Z<3[2onV_^/2ojS1j`GoZL7[2?nY`^`00onW_n_oYKgZojFmjP03ojFmjPSoY[k[00?oZ<7/ojW3k?nY
`n`02_nY`n`00onU_>WoYK[XojFjj006ojFjj0GoYKgZ0_nW`>/<ojO2k@03ojBQd_nUXM;oYJ7B00Ko
YJ7B1OnT[Mh00onXT;goYZ?BojJSdP07ojJSdP;oY[gZ1OnW/Ml7ojO2k@;oZ/7Z1_nX`>/5ojg1j003
ojg2jOnV_n_oY[o[00KoY[o[1onT_^`7ojO0j`KoZl7Z00?oZl;[ojJok?nV_n`01_nV_n`3ojFoj`Co
Y[o[1onX`>/7ojW1j`CoY[o[00?o0000ojJojonV_n/02?nV_n/9ojS1j`GoZ<3[5?ooool00ol0003o
ooooooooo`0=ooooo`005oooool00ol0003oooooooooo`0Booooo`GoZ<3[0onW`>/7ojJoj`03ojNo
jonX`N_oZ<7[00_oZ<7[00?oZ<3[ojNojonW_n/01?nW_n/7ojJoj`;oYl3[00?oZ<7[o`000?l00000
2?nX`N/2ojS0j`coY[k[0_nX`N/7ojW1j`KoZL;/0_nW_n/6ojFmjPKoY[k[0_nX`N`9ojW3k0GoYKcY
2?nU^^P00onU_N[oYl3[ojO0j`04ojO0j`SoYl;]1OnTXM87ojFQdP?oY:gN1?nXT;d7ojJSdP03okFM
`?nW/MooYk7O00KoYk7O1OnW`^d2ojFnk0SoZ<3[00?o[L7Xojg2jOn]`^T00on]`^T8ojJoj`OoY;k/
1onW`>/2oj_1jPGoZl;[1onV_n`8ojJoj`KoZ<3[2?nY`N/4ojJoj`03o`000?nV_n_oY[o[00SoY[o[
0onX`N/3ojW1j`SoZ<3[5?ooool00ol0003oooooooooo`0<ooooo`005oooool00ol0003ooooooooo
o`0Cooooo`03ojS0jonW`>_oYl3[00GoYl3[1OnV_n/2ojNoj`coZ<7[0onX`>/6ojNoj`GoY[o[00Co
Yl3[o`000?l0003o00001onX`N/6ojS0j`SoY[k[1_nX`N/7ojW1j`;oZL;/1_nW_n/6ojFmjP;oY[k[
1_nX`N`5ojW3k0?oZL;/1_nU_>T6ojFjj0WoYl3[0onW`^d3ojJ^g@KoY:7B2?nUXM800onT[MkoZ92m
ojR@_@04ojR@_@GoYZ?B0oneWL08ojNag`03ojO2kOnU_^coYKk/00CoYKk/1_nX`>/00onW`>_o[L;Y
ojg2j@05ojg2j@KoY[o[0_nV`>`6ojBnk0KoYl3[0_nX`>/7oj_2j`OoY[o/2?nV_n/6ojS0j`SoZL7[
1?nV_n/00ol0003oY[o[ojJoj`06ojJoj`03ojNojonY`N_oZL7[00GoZL7[1_nX`>/00onW`>_ooooo
ooooo`0Cooooo`03o`000?oooooooooo00_ooooo000Gooooo`03o`000?oooooooooo01Gooooo1onW
`>/00onV_n_oYko[ojNoj`04ojNoj`SoZ<7[1onX`>/6ojNoj`03ojJojonW`>_o000000;o00000onW
`>/7ojS1j`OoZ<3[2?nV_^/6ojS1j`GoZL7[0onY`^/7ojNoj`?oYKgZ1?nW_n/7ojS1k003ojW3k?nY
`^coZL;/00GoZL;/1_nU_>T2ojFjj0_oYl3[00?oZ/3ZojJ^gOnV[]d01OnV[]d6ojBQdPKoYJ7B00?o
YHNdojR@_OnXT;d01OnXT;d3ojJSdPKo]Ig01_nW/Ml00onf]=OoYKk/ojFnk006ojFnk0;oZ<3[1OnW
`>/7ojg2j@;oY[o[1_nV`>`6ojBnk0;oYl3[1_nX`>/5oj_2j`03oj[2jonV_ncoY[o/00KoY[o/1onV
_n/7ojS0j`KoZL7[00?oZ<7[ojJojonV_n/00onV_n/00ol0003oY[o[ojJoj`02ojJoj`GoYko[1onY
`N/2ojS0j`GoYl3[5?ooool00ol0003oooooooooo`0;ooooo`005_ooool3o`0001Oooooo1OnW`>/9
ojNoj`SoZ<7[1onX`>/3ojNoj`04ojJojol0003o0000o`0000OoYl3[1onX`N/7ojS0j`SoY[k[1_nX
`N/00onY`N_oZL;[ojW2j`05ojW2j`GoYko[00?oYKg[ojNojonW_n/01_nW_n/5ojS1k0;oZl?/2?nY
`^`3ojFlj@?oY;_Z2OnW`>/5oj[0jPOoYZkM1OnTXM84ojFQdPCoYHNd1onXT;d00onVXm;o]Ig0okFM
`005okFM`0CoYk7O1?nf]=L6ojFnk003ojFok?nW`>_oYl3[00KoYl3[1On]`^T2ojk3j@SoY/3/0onT
_^`3ojBnj`SoZ<3[00?oZl;[oj[2jonZ`^/00onZ`^/8ojJok0OoY[o[1onX`>/2ojW1j`GoZ<7[1?nV
_n/00ol0003oY[o[ojJoj`07ojNoj`OoZL7[2?nW`>/Dooooo`03o`000?oooooooooo00[ooooo000F
ooooo`03o`000?oooooooooo01Sooooo00?oYl3[ojNojonW_n/02onW_n/8ojS1j`GoZ<3[00?oYl3[
ojJojol000000_l00004ojJoj`GoYl3[2OnX`N/5ojS0j`[oY[k[0onX`N/3ojW1j`SoZL;[00?oYko[
ojFmjonU_N/00onU_N/8ojNoj`03ojS1k?n[`ncoZl?/00CoZl?/1_nY`^`8ojBkjPKoYl3[00?oYl;/
oj[0j_nZ`>X01OnZ`>X6ojJ^g@KoY:7B00?oYJ7BojF7]?nUQk@01?nUQk@7ojR@_@Wo]Ig000?oYk7O
okJdeonf]=L01Onf]=L2ojFnk0GoYKo/2?nW`>/00on]`^Wo[/?Yojk3j@04ojk3j@KoY/3/00?oYKo/
ojBnjonT_^/01OnT_^/6ojS0j`03ojW0jonZ`^_oZ/;[00GoZ/;[1_nV_n`00onU_^_oY[o[ojJoj`06
ojJoj`?oZ<3[0onY`N/8ojS1j`CoY[o[00?o0000ojJojonV_n/01onW_n/7ojW1j`KoYl3[00?oYko[
ooooooooool04Oooool3o`0000_ooooo0004ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0
003o<S8bonk^kPKooooo00?o0000ooooooooool06_ooool:ojNoj`CoZ<3[1onX`N/00onX`>_oYl3[
ojO0j`03o`0000SoY[o[00?oYl3[ojS1jonX`N/02onX`N/00onX`>_oY[k[ojJnj`0:ojJnj`03ojS0
jonY`N_oZL7[00GoZL7[1_nY`^/2ojNoj`KoYKg[1_nW_n/2ojS1j`OoZl?/0_nY`^`<ojBkjP;oYl3[
1OnW`^`6oj[0jPOoYZkM0onTXM82oib1]POoYHNd1onXT;d00onbRjgo]Ig0okFM`006okFM`0Oo][CG
0_o8bMX7ojFok0OoYl3[2?n^`nT2ojK0k0GoYKo/1onT_^/2ojS0j`GoZL3[1onZ`^/2ojJok0GoYKk[
1_nV_n/00onW_n_oZL7[ojW1j`05ojW1j`KoZ<7[0_nW`>/4ojJoj`03o`000?nV_n_oYko[00GoYko[
0_nX`>/7ojW1j`;oYl3[1OnW_n/?ooooo`?o00000_ooool00ol0003oooooooooo`09ooooo`001_oo
ool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003ooooo
ooooo`0Kooooo`GoYko[00?oY[o[ojS0jonX`>/01_nX`>/5ojS1j`04ojS0jol0003o0000o`0000Co
Yl3[1_nV_n/2ojNoj`koZ<7[2OnV_^/5ojS0j`OoZL7[0_nY`^/6ojNoj`KoYKg[0_nW_n/6ojS1j`Go
Zl?/0_nY`^`<ojBkjP;oYl3[1onW`^`6oj[0jP?oYZkM0onCQ<45oib1]PSoYHNd1OnXT;d2ok:;[@So
]Ig000?obJZjokJdeonf]=L00onf]=L4olS9fPOoYKo/1onW`>/6ojk3j@;o[LCZ1_nU_n`6ojBnj`;o
YKk[1onY`>/3oj[2j`CoZL;[1onU_^/2ojJoj`GoYko[1onY`N/2ojS1j`KoYl3[0onV_n/00ol0003o
Y[o[ojJoj`02ojNoj`KoZ<3[1OnY`N/00onX`N_oYko[ojNoj`06ojNoj`_ooooo0ol00005ooooo`03
o`000?oooooooooo00Wooooo0006ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@4006ooooo`;o00007Oooool00onW_n_oY[o[ojJoj`03ojJoj`SoZ<3[00?oZ<7[ojS0jol0
00000_l00002ojS0j`KoYl3[0_nV_n/6ojNoj`koZ<7[1OnV_^/3ojFnj`KoZ<3[1OnY`N/3ojW2j`Oo
Yko[0onU_N/4ojJnj`OoZ<7[00?oZl?/ojW2k?nY`^`01?nY`^`8ojBkjPKoYl3[1onW`^`3oj[0jP;o
UY_G1_nCQ<46oib1]POoYHNd1?nXT;d3ok:;[@Oo]Ig00oo9Z[X3okJde`Kob<WJ1onU_n`7ojO0j`;o
[/?Y1_n]a>X6ojFok0;oY;k[1_nU_^/5ojW0j`03oj[1jonY`^_oZL;[00KoZL;[1onU_^/7ojNoj`Go
ZL7[0_nY`^/8ojO0j`?oY[o[00?o0000ojJojonV_n/02?nX`>/00onY`N_oZ<7[ojS1j`03ojS1j`So
Yko[1_ooool4o`0000Sooooo00?o0000ooooooooool02Oooool000Kooooo00?o0000ooooooooool0
0_ooool01Ol0003ooooooooooooooooo000000Gooooo0_l0000Nooooo`OoY[o[1_nX`>/00onX`N_o
0000o`000006ojS0j`?oYl3[1?nV_n/7ojNoj`koZ<7[00?oY[k[ojFnjonU_^/01OnU_^/6ojS0j`03
ojW1jonY`^_oZL;[00GoZL;[1OnW_n/00onT_N_oY[k[ojJnj`06ojJnj`GoZ<7[0_n[`n/7ojW2k0Go
Y;_Z0_nS^nX7ojO0j`?oYl;/0onU_N/6oiJKe`KoThC11OnLPKH7ojF7]0?oZ92m1OnbRjd5okFM`0Go
bJZj00?o][CGolS9f_o8bMX01?o8bMX00oo>gNCoYKo/ojFok006ojFok0GoYl3[0_nX`>/8ojg4jP?o
YKo/0onT_N`8ojFnj`03ojW0jonZ`N_oZ/7[00?oZ/7[2?nY`^/7ojFnj`OoYko[00?oZL7[ojW2jonY
`^/01?nY`^/6ojO0j`GoY[o[00?o0000ojJojonV_n/01_nX`>/8ojS1j`OoYko[0oooool3o`0000go
oooo00?o0000ooooooooool02?ooool000Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000Gooooo00?o0000ooooooooool07_ooool7ojJoj`;oZ<3[00CoZ<7[o`000?l0
003o00000_nX`N/5ojS0j`;oYl3[1onV_n/5ojNoj`?oZ<3[2onX`N/3ojJoj`OoYKk[0onX`>/3ojW1
j`SoZL;[00?oYko[ojBmjonT_N/00onT_N/8ojJnj`03ojS1jon[`n_oZl?[00CoZl?[1onY`^`00onT
^n[oXk_Zoj>kjP04oj>kjPGoYl3[0_nY`N/6ojFmj`GoUY_G1_nCQ<45oib1]PSoYHNd00?oZ92mok:;
[OnbRjd01?nbRjd4okFM`0KobJZj00?ohlVmolS9f_o8bMX00oo8bMX3olkMi0SoYKo/00?oYl3[ojS0
jonX`>/01?nX`>/6ojg4jP03ojc4jonT_NcoY;g/00GoY;g/1_nU_^/00onV_n_oZ/7[oj[1j`05oj[1
j`KoZL;[00?oYl7/ojFnjonU_^/01_nU_^/3ojNoj`?oZ<3[2?nY`^/2ojO0j`WoY[o[00?o0000ojJo
jonV_n/00_nX`>/<ojS1j`OoYko[0_l0000@ooooo`03o`000?oooooooooo00Sooooo0006ooooo`03
o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo
01oooooo1OnV_n/01?nW_n_o0000o`000?l00006ojS1j`03ojS0jonW`>_oYl3[00CoYl3[1onV_n/0
0onW_n_oZ<3[ojS0j`05ojS0j`OoZ<7[1onV_n/5ojFnj`03ojNojonY`N_oZL7[00GoZL7[1_nY`^/2
ojS1k0KoY;g[1_nV_^/2ojS0j`OoZl?[0onY`^`4ojBmj`OoXk_Z00?oYl3[ojW1jonY`N/01?nY`N/6
ojFmj`CoUY_G1_nCQ<46oib1]PKoYHNd00?oYgjWok:;[OnbRjd01OnbRjd3okFM`0OobJZj0_oSbKd3
olS9fPGoc]gT1_nU_n`00onU_>[oZ<3[ojS0j`06ojS0j`;o[LCZ1On/a>/7ojBmk0;oYKk[1OnV_n/7
oj[1j`;oZL;[1OnW`N`6ojFnj`03ojJnjonX`>_oZ<3[00GoZ<3[1_nY`^/00onX`NcoY[o[ojJoj`09
ojJoj`03o`000?nV_n_oYko[00_oZ<7[0onW`>/8ojNoja7ooooo00?o0000ooooooooool02?ooool0
00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_l0000Q
ooooo`03ojJojonW_n_o000000;o00000onW_n/8ojS1j`KoYl3[2?nV_n/7ojS0j`KoZ<7[2?nV_n/0
0onU_^_oYko[ojNoj`03ojNoj`OoZL7[0_nY`^/6ojS1k0KoY;g[0_nV_^/6ojS0j`OoZl?[1onT_N/5
oj>kjP;oYl3[1onY`N/5ojFmj`GoUY_G1_nCQ<45oib1]PGoYHNd0_nWOZL8ok:;[@03okFM`?o9Z[[o
bJZj00GobJZj1?oSbKd00oo8bM[oc]gTolkMi005olkMi0;oYKo/1OnU_>X6ojS0j`;oZ/7Z1_n/a>/6
ojBmk0;oY;c[1_nV_n/6oj[1j`03oj_3jonW`NcoYl7/00KoYl7/0_nU_^/5ojJnj`OoZ<3[0_nY`^/5
ojS1k0WoY[o[0_nW_n/00ol0003oYko[ojNoj`06ojS1j`03ojW1jonW`>_oYl3[00GoYl3[1_nW_n/0
0onV_n_oooooooooo`0?ooooo`03o`000?oooooooooo00Sooooo0004ooooo`03oeEEEOmVIVKo0000
00Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo01oooooo0ol00007
ojNoj`SoZ<7[1_nW`>/8ojJoj`GoZ<3[2?nX`N/6ojJoj`;oYKk[1_nW_n/8ojW1j`OoZ<7/0onT_N/4
ojFnj`OoZ<3[1on[`n/7ojBmj`03oj>kj_nW`>_oYl3[00CoYl3[1onY`N/5ojFmj`CoUY_G1_nCQ<45
oib1]PCoYHNd1?nWOZL7ok:;[@OobJZj1OoSbKd2oo?^_PGoc]gT0_nmf>h7ojFljP;oZ<3[1_nZ`NX6
ojc4j`;oY;g/1_nT_>/6ojJoj`;oZ/7[1On[`n/6ojO1k0SoY[k[1_nX`>/2ojW1j`OoZ<7/1_nV_n/5
ojNoj`03o`000?nW_n_oYko[00;oZ<7[1OnY`N/7ojO0j`;oYko[1OnV_n/@ooooo`03o`000?oooooo
oooo00Sooooo000Eooooo`03o`000?oooooooooo01cooooo0ol00004ooooo`GoYko[0onX`>/7ojS1
j`?oYl3[1?nW_n/7ojJoj`03ojS0jonX`N_oZ<7[00[oZ<7[0_nV_n/6ojFnj`KoYko[2?nY`N/5ojS1
k003ojFnk?nU_^_oYKk[00KoYKk[1OnX`>/2oj[1j`OoZl?[0onT_N/4oj:lj`OoYl3[0onY`N/3ojO2
k@GoMi_X0_mULLX2oiJKe`KoThC11_nLPKH2ojF7]0GoYgjW1onbRjd00oo8W:_obJZjolVZ^P04olVZ
^PGohlVm0oock[h00oo>gNCo_MS^okgHkP04okgHkPGoYKcZ0_nW`>/8oj[1jP?o[<C[0onX`^`8ojBl
j`?oY[o[0onX`>/7oj_3j`;oYl7/3?nV_^/2ojS0j`KoZL7[1OnX`N`00onW`>_oY[o[ojJoj`05ojJo
j`GoYko[00?o0000ojNojonY`N/01_nY`N/6ojO0j`03ojNojonV_n_oY[o[00KoY[o[3oooool00ol0
003oooooooooo`08ooooo`005Oooool00ol0003oooooooooo`0Iooooo`?o00002?ooool00onW_n_o
Z<3[ojS0j`05ojS0j`GoZ<7[00?oZ<3[ojNojonW_n/01_nW_n/5ojJoj`;oYko[2onX`N/3ojO0j`Oo
YKk[0onW_n/4ojS0j`OoZL7[00?oZ<7/ojFnk?nU_^`00onU_^`8ojFnj`03ojS0jonZ`N_oZ/7[00Co
Z/7[1On[`n/2ojK1k0OoX[c[1_nW`>/7ojO2k@GoMi_X1?mULLX5oi>4`@KoW86f00?oYHNdojMnYonW
OZL01?nWOZL6ok:;[@;ob9b[1Oo9Z[X5on?9_@Colnjn2?nmf>h00onU_>[oYl3[ojO0j`04ojO0j`Ko
Z/7Z00?o[LG/ojS2k?nX`^`01OnX`^`6ojBlj`03ojFmjonX`>_oZ<3[00GoZ<3[1On[`n/2ojW2k0_o
Y[k[0onV_n/8ojW1j`03ojS1k?nW`>_oYl3[00?oYl3[1onV_n/4ojNoj`03o`000?nW_n_oYko[00Oo
ZL7[0_nW`>/5ojNoj`KoY[o[00?oYko[ooooooooool03Oooool00ol0003oooooooooo`08ooooo`00
5Oooool00ol0003oooooooooo`0Fooooo`?o00003Oooool7ojS0j`03ojS1jonX`>_oZ<3[00?oZ<3[
2?nW_n/00onV_n_oYko[ojNoj`04ojNoj`OoZ<7[1onW`>/5ojFnj`03ojJojonX`>_oZ<3[00KoZ<3[
1onY`N/6ojFnk0KoYKk[0_nW_n/7oj[1j`03oj_3jonV`NcoY/7/00CoY/7/1onR_>/6ojO0j`OoYl;]
1?mgVnP4ofEabP?oOf^c0onCQ<44oib1]P03oiMcZ?nWOZOoYgjW00GoYgjW1_nbRjd3olRLZ`?obJZj
1OoSbKd5oo?^_P03onCma_nmf>ko_MS^00Co_MS^0_nX`^d7ojO0j`;oZ/7Z1On]aN`7ojS2k0;oY;c[
1OnU_N/7ojS0j`03oj_3jonY`^coZL;/00CoZL;/1onV_^/7ojJoj`KoZL7[00?oZL;[ojO0jonW`>/0
1OnW`>/7ojJoj`CoYko[00?o0000ojNojonW_n/00onY`N/4ojS1j`OoYko[0_nV_n/5ojNoj`oooooo
00?o0000ooooooooool01oooool001Cooooo0_l0000Eooooo`?o00004Oooool5ojS0j`;oZ<7[1_nX
`>/6ojNoj`;oY[o[1onW_n/3ojS1j`CoZL7[1onW`>/00onU_^_oY[o[ojJoj`03ojJoj`SoZ<3[1onY
`N/6ojFnk0;oYKk[1_nW_n/5oj[1j`;o[<;Z1onV`N`5oj:lj`;oY;g[1_nW`>/7ojO2k@CoMi_X0omU
LLX6ogm[/`03oib1]_nGLjSoUg>X00;oUg>X2?nWOZL4ok:;[@Cob9b[0oo9Z[X5on?9_@Colnjn0ooT
oLH2okgHkPKoZ<;]1onW`>/7ojg5k0?oZ<;/1?nT_N/7ojFmj`?oZ<3[0onY`^/8ojW2k0OoY[k[1onV
_n/2ojW1j`GoZL;[1onW`>/7ojJoj`CoYko[00?o0000ojS1jonX`N/01onX`N/=ojNoj`oooooo00?o
0000ooooooooool01oooool001Cooooo00?o0000ooooooooool04_ooool2o`0001Gooooo00?oZ<3[
ojS1jonX`N/01?nX`N/6ojS0j`;oYko[1_nV_n/5ojNoj`;oZ<3[1onY`N/5ojO0j`;oY[o/1_nV_n/6
ojS0j`WoZL7[0onU_^`4ojBnk0OoYko[00?oZ/7[ojc2j_n/`^X01?n/`^X7ojK1k003oj:ljonT_N_o
Y;g[00CoY;g[1_nW`>/3ojO2k@?oRkGb0_l>Fm@2ogNKj0CoIG7:1OmoJk<6oiMcZ0OoYgjW1?nbRjd5
olRLZ`03olVZ^_oSbKgohlVm00?ohlVm1?ock[h3onCmaP;oc?3[2?nX`^d7ojO0j`Go[LG/00?oZlG/
ojBmjonT_N/01_nT_N/5ojFmj`03ojNojonY`^_oZL;[00GoZL;[1_nY`^`2ojO0j`KoY[k[1_nV_n/0
0onX`>_oZL;[ojW2j`06ojW2j`?oYl3[2onV_n/01OnW_n_oZ<7[ojS1jonX`N_o000000WoZ<7[3OnW
_n/>ooooo`03o`000?oooooooooo00Oooooo000Dooooo`03o`000?oooooooooo00oooooo0ol0000H
ooooo`OoZ<7[0onX`>/4ojO0j`OoY[o[00?oYko[ojS0jonX`>/01?nX`>/7ojW1j`03ojO0jonV_nco
Y[o/00CoY[o/1_nV_n/2ojS0j`_oZL7[0_nW`>`7ojBnk0GoYko[0_nX`>/7ojc2jP?oY/7/1?nR_^d7
ojBmj`?oYl3[0onZ`NX6oh^elP?o3U_D1?mULLX5ogm[/`KoUg>X1onWOZL3ok:;[@Kob9b[00?okLF[
on?9_OoSbKd00_oSbKd4oo?^_P?oi?g61?o<l>/6ojS2k@03ojJnjonW`>_oYl3[00KoYl3[00?o[LG/
oj_5k?n[aN`00on[aN`8ojBmj`03ojFmjonW_n_oYko[00?oYko[1onY`^/2ojW2k0KoYl3[1_nV_^/2
ojJoj`GoZ<3[1_nY`^/00onX`NcoY[o[ojJoj`0;ojJoj`03ojNojonX`N_oZ<7[00;oZ<7[00?o0000
ojS1jonX`N/01?nX`N/3ojO0j`_oYko[0onX`>/=ooooo`03o`000?oooooooooo00Oooooo000Doooo
o`03o`000?oooooooooo00cooooo0ol0000Looooo`SoZ<7[1_nW`>/8ojJoj`KoZ<3[1OnY`N/2ojS1
j`OoY[o/0onV_n/4ojNoj`SoZL7[1_nW`>`7ojBnk003ojNojonX`>_oZ<3[00CoZ<3[1On/`^X2oj_2
jPOoX[k]1OnT_N/00onV_n_oZ/7Zoj[1jP05oj[1jPKoRkGb0ol>Fm@3ofEabPKoOf^c1OnGLjP7ojMn
Y`?o/X^]1_o8W:/2ong5Z`?ohlVm0oock[h3onCmaPKoc?3[0_nX`^d5ojJnj`KoYl3[2?n[aN`6ojBm
j`03ojBlj_nW_n_oYko[00GoYko[1OnY`^/2oj[3k0SoYl3[1_nV_^/7ojS0j`;oZL;[1OnX`N`9ojJo
j`GoYko[1?nX`N/00ol0003oZ<7[ojS1k007ojO0j`OoYko[1onX`>/<ooooo`03o`000?oooooooooo
00Oooooo000Cooooo`?o00002_ooool3o`00023ooooo2?nX`N/6ojO0j`SoY[o[1_nX`>/00onY`N_o
Z<7[ojS1j`04ojS1j`GoY[o/0onU_n`6ojNoj`OoZL7[1onW`>`3ojBnk0CoYKk/1onX`>/00on/`^[o
Zl;Zoj_2jP04oj_2jPOoX[k]00?oY;g[ojJojonV_n/00onV_n/7oj[1jPKoRkGb0_l>Fm@3ofEabPKo
Of^c1OnGLjP8ojMnY`03ok:;[Oo8W:_ob9b[00Cob9b[1?o]aJ/01?oSbKgolnjnoo?^__ock[h3onCm
aPKoc?3[0_nZ`N/7ojJnj`;oYl3[3?n[aN`2ojBmj`GoY;cZ1onW_n/00onY`^_oZ/?/oj[3k004oj[3
k0KoYl3[2?nV_^/5ojS0j`;oZL;/1onX`N`6ojJoj`SoYko[0_nX`N/2ojS1k003o`000?nX`NcoZ<7/
00OoYl3[1onW_n/7ojS0j`_ooooo00?o0000ooooooooool01oooool001Cooooo00?o0000oooooooo
ool01_ooool3o`0002Gooooo1onX`N/3ojO0j`CoYl3/1onV_n/3ojS0j`?oZL7[1onX`N/00onV_nco
YKo/ojFok005ojFok0KoYko[1onY`N/5ojO0k0;oY[o/1onU_^`5ojS0j`;oZ/7Z1on[`^X3oj:nk@Co
XKg]1_nV_n/7oj[1jPGoHj?d0ol>Fm@3ofEabPGoOf^c1OnGLjP8ojMnY`03ok:;[Oo8W:_ob9b[00Co
b9b[1?o]aJ/3oo3ZR@?o00000on_lJT00oo<l>_oZ/7[oj[1j`04oj[1j`GoY[k[0_nW`>/;oj_5k0?o
YKgZ1onT_>X3ojNoj`?oZ<7[2?nZ`n`2ojO0j`coY[k[00?oZ<3[ojW2k?nY`^`01?nY`^`5ojS1k003
ojNojonV_n_oY[o[00GoY[o[1_nW_n/00onX`>_oZ<7/ojS1k002ojS1k003o`000?nX`NcoZ<7/00Ko
Yl3[2OnW_n/3ojS0j`?oZ<7[2oooool00ol0003oooooooooo`07ooooo`005?ooool00ol0003ooooo
ooooo`03ooooo`?o0000:Oooool5ojS1j`03ojS0jonW`>coYl3/00KoYl3/1OnV_n/2ojNoj`KoZL7[
1OnX`N/3ojS0j`OoYKo/0onW_n/3ojS0j`OoZL7[00?oYl3/ojJok?nV_n`01?nV_n`7ojFnk003ojS0
jonZ`N[oZ/7Z00CoZ/7Z1On[`^X2ojW1j`OoXKg]1_nV_n/7oj[1jPGoHj?d0_l>Fm@00ol06ZSoIG7:
ofEabP05ogm[/`KoUg>X1onWOZL7olRLZ`CokLF[0oo`jXT2o`0000?o[o6Y00?o^M_aoj[1jonZ`N/0
1_nZ`N/00onV_^_oYl3[ojO0j`04ojO0j`OoZlG/1onU_NX5ojBljP;oY[k[1_nX`N/6oj[3k003ojS1
k?nV_^_oY[k[00WoY[k[0onW_n/8ojW2k003ojS1k?nW_n_oYko[00?oYko[1onV_n/2ojNoj`GoZ<3[
1?nX`N`00ol0003oZ<7/ojS1k002ojO0j`coYko[1onX`N/;ooooo`03o`000?oooooooooo00Kooooo
000Cooooo`04o`000?ooooooooooooooo`?o0000;Oooool00onX`N_oZ<3[ojS0j`03ojS0j`SoYl3/
00?oY[o[ojNojonW_n/01?nW_n/6ojW1j`03ojS1jonX`>_oZ<3[00GoZ<3[1_nU_n`7ojS0j`SoZL7[
1_nV_n`5ojFnk0;oY[o[1onZ`NX00on[`^[oZL7[ojW1j`04ojW1j`OoXKg]0onV_n/3ojO0j`OoZ/7Z
1OmSXo@2o`iKe003o`0JZ?mULL[oOf^c00CoOf^c1_nGLjP7ojMnY`Kob9b[1?o]aJ/3oo3ZR@;o0000
00?o[o6YokWKlOnifo400onifo46oj[1j`WoYl3[1on[aN`7ojFmjP03ojBlj_nV_^_oY[k[00CoY[k[
1_nX`N/2oj[3k0GoZ<7/1onV_^/7ojNoj`OoZL;/1onW_n/5ojJoj`;oYko[1onX`>/3ojS1k003ojS0
jol0003oZ<3[00ooYko[1onX`N/:ooooo`03o`000?oooooooooo00Kooooo000Cooooo`Co0000<_oo
ool5ojS0j`KoYl3/0_nV_n`7ojNoj`KoZL7[2?nX`>/6ojFok0OoZ<3[2?nY`N/6ojJok003ojFnk?nV
_n_oY[o[00CoY[o[1OnZ`NX2oj_1jPOoZL7[1OnQ_Nd2oj2nkPKoYl3[1onZ`NX3of>Tm0;oHj?d00?o
3U_Do`0JZ?mULLX01_moJk<5oiMcZ0KoYgjW0_nkT:T5olRLZ`CokLF[0oo`jXT00ol0003o]?7eokCa
m@06okWKl@;oZ/7[2onW`>/2oj_6kPKoZlG/1_nU_NX00onU_>[oY[k[ojJnj`06ojJnj`?oZ<7[0onZ
`n`7ojS1k0OoY[k[1onW_n/7ojW2k0OoYko[00?oY[o[ojNojonW_n/01?nW_n/5ojS0j`;oZ<7/1?nX
`>/00ol0003oZ<3[ojNoj`0=ojNoj`OoZ<7[2_ooool00ol0003oooooooooo`06ooooo`004oooool2
o`0003Gooooo1OnX`>/2ojO0k0KoY[o/1OnW_n/2ojS0j`KoZL7[1_nX`>/2ojO0k0KoYKo/1OnX`>/2
ojW0j`SoZL7[0onV_n`3ojBok0OoY[o[00?oZ/7Zoj_1j_n[`NX01?n[`NX7ojW1j`03oj6mkOnP_^ko
X;k^00CoX;k^1_nW`>/7oj[1jPGoHjCd0_l06ZP00omULL[oOf^cogm[/`03ogm[/`GoUg>X1OnWOZL3
ok^@Z@Gob9b[1?o]aJ/2oo3ZR@03o`000?ndlOGo]?7e00;o]?7e0onifo43ojFljPWoYl3[1_n[a^h6
oj_5k0;oYKgZ1OnU_>X6ojJnj`03ojS1k?nZ`ncoZ/?/00GoZ/?/1OnX`N`8ojJnj`KoYko[2OnY`^`3
ojNoj`?oY[o[2?nW_n/00onX`>_oZ<7/ojS1k004ojS1k0?oZ<3[00?o0000ojS0jonX`>/03_nW_n/7
ojS1j`Wooooo00?o0000ooooooooool01_ooool000Go00000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Sooooo00?o0000ooooooooool0<oooool6ojS0j`OoY[o/00?oYko[ojS0jonX`>/01?nX`>/6
ojW1j`;oZ<3[1_nW`>`6ojFok003ojS0jonY`>_oZL3[00CoZL3[2?nY`N/6ojBok0GoY[o[0_nW_n/7
oj_1jP?oZL7[1?nX`>/7oj2nkP?oYl3[0onW`N`7oj[1jP?oHjCd0_n</o02o`0JZ0GoOf^c1OnGLjP4
ojMnY`Co^i2Y1?o8W:/4ong5Z`?ol>Z91?ndlOD2ojRnj@KoYKcZ1_nW`>/00onW`ngoZlK^oj_6kP06
oj_6kP?oZlG/0onU_>T7ojFljP;oY[k[1OnX`N`7oj[3k003ojS1k?nV_^_oY[k[00[oY[k[0_nW_n/;
ojW2k003ojNojonV_n_oY[o[00GoY[o[1_nW_n/00onW`>_oZ<7/ojS1k006ojS1k0?oZ<3[00?o0000
ojNojonW_n/02_nW_n/;ojS1j`Sooooo00?o0000ooooooooool01_ooool00005oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Wooooo00?o0000ooooooooool0<ooo
ool6ojS0j`OoY[o/1onX`>/7ojW1j`OoYl3/0onU_n`3ojJoj`OoZL3[2?nY`N/6ojBok003ojJojonW
_n_oYko[00CoYko[1On[`NX2oj_1j@OoZ<3[1onP_^h6ojO1k0OoZ/7Z1?n</o02o`0JZ0;oAdfd0omo
Jk<6oiMcZ0?oYgjW1OnkT:T3olRLZ`CokLF[0_o`jXT00ol0003o]?7eojRnj@05ojRnj@KoYKcZ0_nW
`>/5ojO3k@KoZlK^00?oZL7[ojFljOnU_>T01OnU_>T5ojFljP;oYko[1onX`N`3oj[3k0?oZ<7[2onV
_^/3ojNoj`WoZL;/1OnW_n/7ojJoj`;oYko[1OnW`>/6ojS1k003ojS1jonW_n_oYko[00;oYko[00?o
0000ojNojonW_n/01_nW_n/=ojS1j`03ojO0jooooooooooo00Kooooo00?o0000ooooooooool01_oo
ool00004oooooonHV9So8B4Qonk^kPCooooo00Go410@oooooooooooooooooa0@400:ooooo`03o`00
0?oooooooooo03?ooooo1_nX`>/7ojJok0SoZ<3[1_nY`N/5ojO0k0;oY[o/1_nV_n/5ojW0j`[oZL7[
0onT_n`3ojBnk0OoYko[00?oZl7Zoj_1jOn[`NT01?n[`NT7ojS0j`OoX;k^1_nW`N`7oj[1jPCoS;?`
00Co01ZXodM=]?m7CKCoAdfd0_moJk<6oiMcZ0;oYgjW1_nkT:T3olRLZ`CokLF[0_o`jXT00onW_^Wo
Z;kYojRnj@06ojRnj@?oYKcZ0onW`N`7ojO3k@;oZlK^1OnY`N/7ojFlj@03ojFlj_nW_n_oYko[00Co
Yko[1OnX`N`2ojW3k0KoZ<7[1onV_^/7ojNoj`OoZL;/1onW_n/6ojJoj`SoYl3[0_nX`N`5ojS1j`Co
Yko[00?o0000ojNojonW_n/01_nW_n/9ojS1j`GoYl3[1oooool00ol0003oooooooooo`06ooooo`00
0_ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000002oooool2o`0003Co
oooo0onX`>/3ojO0j`OoY[o/2?nX`>/6ojW1j`03ojO0k?nV_ncoY[o/00CoY[o/1_nV_n/00onY`>_o
ZL7[ojW1j`0:ojW1j`;oZL3[1_nT_^`5ojNoj`;oYl3[1on[`NT3ojS0j`CoZ<3Z1onP_^h3ojO1k0?o
Y/7]1onZ`NX3ohbcl0;o01ZX0om7CK@2ogm[/`GoUg>X00?oYgjWok^@ZOnkT:T01OnkT:T2olRLZ`Co
kLF[0_o`jXT3ojNnj@KoZ;kY0_nW`>/6ojO1k0GoYl?]0_nZaNd7ojW1j`?oYKcY0onU_NX8ojNoj`03
ojS1k?nY`ncoZL?/00CoZL?/1_nX`N/7ojJnj`OoYko[1onY`^`5ojNoj`SoY[o[1_nW`>/00onX`Nco
Z<7[ojS1j`06ojS1j`?oYko[00?o0000ojNojonW_n/01onW_n/3ojS1j`?oZ<7/2?nW`>/7ooooo`03
o`000?oooooooooo00Gooooo0003ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03o`000?oooooooooo03;ooooo1_nW`>/5ojJok0?oY[o[1onX`>/3ojW1j`?o
Z<3[1onV_n`3ojJoj`CoYko[2?nY`N/6ojW0j`KoY;k/00?oYko[ojO0jonW`>/01?nW`>/8oj_1j@Ko
Z<3Z1OnP_^h2oj6nkPKoY/7]1OnZ`NX5ojO0j`03o`0JZ?m7CKCoAdfd00;oAdfd00?oOf^coiMcZ?nG
LjP00_nGLjP00onJNjoo^i2Yok^@Z@07ok^@Z@03olRLZoo]aJ_okLF[00;okLF[0_o`jXT4ojNnj@;o
Z;kY1_nW`>/6ojO1k003ojO3kOnZaNgoZ/G]00CoZ/G]1OnY`N/2ojFkj@KoYKgZ1_nW_n/00onX`^co
ZL?/ojW3k006ojW3k0?oZ<7[0onV_^X7ojJnj`?oYko[0onX`^`8ojW2k003ojNojonV_n_oY[o[00[o
Y[o[0_nW`>/5ojS1k0KoZ<7[1OnW_n/00ol0003oYko[ojNoj`05ojNoj`;oZ<7[1_nX`N`6ojO0j`03
ojNojooooooooooo00Gooooo00?o0000ooooooooool01Oooool000Cooooo00Go0000oooooooooooo
oooooa0@4003ooooo`03oa0@4?oooooooooo00cooooo00?o0000ooooooooool0<_ooool6ojO0j`03
ojJok?nV_n_oY[o[00GoY[o[1OnX`>/2ojW0j`KoZ<3[1OnV_n`3ojFok0KoYko[1OnY`N/2ojW1jPOo
ZL3[0onT_^`3ojBok@OoYl3[2?n[`NT6ojS0jP03oj2nk_nQ_^koXKk^00CoXKk^1_nV`Nd00onZ`N[o
Yl3[ojO0j`06ojO0j`03o`0JZ?m7CKCoAdfd00?oAdfd00?oUg>XoiYk[onJNjl00_nJNjl9ok^@Z@03
olRLZoo]aJ_okLF[00;okLF[00?ol>Z9ojNnjOnW_^T00_nW_^T:ojO0j`?oYl7/1?nYa^l6oj[5k@03
ojW1jonU^nWoYK_Y00CoYK_Y1_nU_NX2ojNoj`GoZ<;/1_nY`n`00onW_n_oY[kZojJnjP05ojJnjPGo
Y[k[0_nW_n/6ojS2k0KoZL;/00?oYko[ojJojonV_n/02OnV_n/3ojO0j`OoZ<7/0_nX`N/9ojNoj`04
o`000?nW_n_oYko[ojNoj`KoZ<7[1_nX`N`2ojO0j`GoYko[1_ooool00ol0003oooooooooo`05oooo
o`0000Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03oooool0
0ol0003oooooooooo`0booooo`?oYl3[1?nW`>`7ojJoj`03ojS0jonY`>_oZL3[00CoZL3[1_nX`>/0
0onV_ncoYKo/ojFok005ojFok0KoYko[00?oZL7[ojW1j_nY`NX01?nY`NX5ojW0j`;oZ<3[1_nT_nd7
ojO0j`SoZl7Y0onX`>X3ojVoj@OoXKk^0onV`Nd3ojC1kPWoYl3[00?o01ZXodM=]?m7CK@00_m7CK@6
oiYk[`So^i2Y00Coj<Reong5Zoo]aJ_okLF[0_o`jXT00onW_^WoYl3[ojO0j`0:ojO0j`03ojS6konY
a^ooZLK_00KoZLK_0onZaNd3ojJlj@OoYK_Y0onU_NX3ojO0j`OoZ<;/0_nY`n`5ojNoj`OoY[kZ00?o
Y[k[ojNojonW_n/01?nW_n/6ojS2k0;oZL;/1OnW_n/6ojJoj`03ojNojonW`>_oYl3[00GoYl3[1OnX
`N`00onX`N_oYko[ojNoj`0:ojNoj`03o`000?nW_n_oZ<7[00OoZ<7[0onX`N`2ojO0j`SoYko[1Ooo
ool00ol0003oooooooooo`05ooooo`0000GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h04?ooool2o`0003Cooooo1_nW`>`5ojJoj`;oYko[1onY`>/6ojS0j`SoYKo/
0onW_n/3ojO0j`OoZL7Z00?oZL3[ojS0jonX`>/01?nX`>/6ojBok@OoYl3[1_n[`NT00on[`N[oZKoY
ojVoj@05ojVoj@GoXKk^0_nS_N`6ojC1kPGoYl3[0_nW`nh00onY`>[o01ZXodM=]003odM=]0KoVW^_
2?nkT:T2onS8]@;okLF[00?ol>Z9ojO1k?nW`N`02OnW`>/5ojS6k`KoZLK_00?oZ;kYojJljOnV_>T0
1OnV_>T5ojFkj@;oYko[1_nW`>/5ojS2k0;oZL?/1_nW_n/6ojJnjP03ojJnjonW_n_oYko[00KoYko[
0onX`^`3ojW2k0OoYko[0_nV_n/5ojNoj`OoYl3[00?oZ<7/ojS1jonX`N/00onX`N/;ojNoj`03o`00
0?nW_n_oYko[00KoZ<7[00?oZ<7/ojO0jonW`>/01?nW`>/7ojNoj`Gooooo00?o0000ooooooooool0
1Oooool001oooooo00?o0000ooooooooool0<_ooool6ojO0k003ojJojonW_n_oYko[00CoYko[1onY
`>/6ojS0j`SoYKo/1_nW`>/7ojW1jPOoZ<3[1_nT_nd7ojO0j`;oZl7Y1On[`NX7ojVoj@03oj6nk_nS
_NcoXkg/00CoXkg/1_nT`Nh00onW`>_oYl?^ojO3kP04ojO3kP03ojW0j_m7CKCoAdfd00?oAdfd1OnJ
Njl7ok^@Z@Coj<Re00?okLF[ojO1k?nW`N`00_nW`N`5ojO0j`;oYlK`1onXa^l2ojW6k`GoZ;kY1onV
_>T00onU^nWoYko[ojNoj`04ojNoj`KoYl3[00?oZ<;/ojW3k?nY`n`01?nY`n`6ojNoj`;oY[kZ1OnV
_^/6ojNoj`03ojS2k?nY`^coZL;/00GoZL;/1OnW_n/2ojNnj`OoYko[0onW`>/3ojS1k0OoZ<7[2onW
_n/00ol0003oYko[ojNoj`02ojS1j`GoZ<7/1_nW`>/7ojNoj`Cooooo00?o0000ooooooooool01Ooo
ool0023ooooo00?o0000ooooooooool0<_ooool3ojO0k0?oY[o/1onW_n/7ojW0j`KoZ<3[2?nU_n`6
ojO0j`OoZL7Z1onX`>/6ojBok@GoYl3[0_nW`>`7oj_1jPGoZKoY0_n[`>T7oj>mk0?oY<7^0onQ`>l7
ojO3kP03o`0JZ?m7CKCoAdfd00;oAdfd1OnJNjl7ok^@Z@Coj<Re00?o0000ojO1k?nW`N`00onW`N`0
0onW`>_oYlK`ojO6l004ojO6l0GoZ<K_0_nX_nX6ojRnj@KoY[cY00?oY[gZojNojonW_n/01_nW_n/3
ojO0j`?oZL?]1onY`n`3ojNoj`?oY[kZ1onV_^/2ojNoj`GoZ<;/1onY`^`00onW_n_oYkk[ojNnj`04
ojNnj`GoYko[00?oYl3[ojS1k?nX`N`01OnX`N`5ojS1j`goYko[00?o0000ojS0jonX`N`01onX`N`3
ojO0j`[oYko[0oooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`0boooo
o`KoY[o/1OnW_n/3ojO0j`KoZL3[1onX`>/7ojFok0KoYl3[1onY`NX7ojS0j`KoY;o]00?oYl3[ojO0
k?nW`>`01?nW`>`7oj_1jP03ojVojOn[`>WoZl3Y00CoZl3Y1OnS_N`2ojNnjPKoXL3_1OnW`nh2oj?2
k`CoAdfd1_nJNjl5ok^@Z@Goj<Re00CoYl?]ojO1k?nW`NcoYl7/1?nVaO06ojO6l003ojS6konX_n[o
Z;oZ00CoZ;oZ1_nX_^T2ojJlj@GoY[gZ1_nW_n/00onX`^goZL?]ojW3k@05ojW3k@GoZL?/00?oYkkZ
ojJnj_nV_^X01OnV_^X5ojJnj`;oYl3[1onX`^`3ojW2k0?oYko[2?nW_^/00onW_n_oYl3[ojO0j`03
ojO0j`OoZ<7/00?oZ<7[ojNojonW_n/03?nW_n/2ojS0j`03o`000?nX`>_oZ<3[00KoZ<7/00?oZ<3[
ojNojonW_n/02onW_n/4ooooo`03o`000?oooooooooo00Cooooo000Rooooo`03o`000?oooooooooo
03;ooooo1_nV_n`00onW_n_oYl3[ojO0j`05ojO0j`OoZL3[1_nX`>/7ojFok0KoYl3[1OnY`NX2ojW0
jPOoZ<3[1_nT_nd7ojO0k0?oZl7Z1?nZ`NX7oj_0j@03oj>mk?nW_^[oYkkZ00CoYkkZ1_nQ`>l00onW
`nkoXl;_oj?2k`03oj?2k`CoAdfd1_nJNjl5ok^@Z@Coj<Re00?oYl?]ojG4konVaO001onVaO03ojO6
l0?oYko[1onX_nX3ojRnj@?oY[cY1onV_NX2ojNoj`GoZ<;]1onY`nd00onY`ncoYkkZojNnjP03ojNn
jPOoY[kZ00?oY[k[ojO0jonW`>/01?nW`>/5ojS2k0;oZ<7/1_nW_n/6ojNnj`03ojNojonW`>_oYl3[
00GoYl3[0onX`N`3ojS1j`goYko[1OnX`>/00ol0003oZ<3[ojS0j`02ojS1k0GoZ<3[3OnW_n/3oooo
o`03o`000?oooooooooo00Cooooo000Sooooo`;o0000<oooool7ojJok0OoYl3[1onY`>/6ojS0j`Oo
YKo/1_nW`>/00onY`N[oZL3ZojW0jP04ojW0jPGoZ<3[0_nY`>X6ojBok@GoYl3/0onV`>`6oj[1jPOo
Zl3Y1onW_^X3oj70k`CoY;g[1OnS`^l4odM=]0GoVW^_1?nkT:T5onS8]@?oYLC_1_nVaO000onW_^[o
Yko[ojNoj`05ojNoj`GoZ;oZ0_nW_>T6ojJlj@GoY[gZ0_nW`N`7ojS2k@?oZL?]0onX`>/7ojNnjP?o
Y[kZ0onW_n/8ojO0j`03ojS2k?nX`NcoZ<7/00CoZ<7/1_nW_n/2ojNnj`GoYko[1OnW`>/2ojS2k0Ko
Z<7[3OnW_n/5ojS0j`03o`000?nX`NcoZ<3[00OoZ<3[3OnW_n/2ooooo`03o`000?oooooooooo00Co
oooo000Uooooo`03o`000?oooooooooo03;ooooo1_nV_n`7ojO0j`OoZL3[1_nX`>/7ojFok0KoYl3[
1onY`>X00onX`>_oZL3ZojW0jP04ojW0jPKoY;o]00?oYl3/ojK0k?nV`>`01OnV`>`6oj[1jPOoZl3Y
1OnW_^X2oj^oj0OoY;g[0onS`^l2ojBmj`?oAdfd1OnJNjl3ok^@Z@Goj<Re1OnUa>l2ojK5l0GoYkkZ
1onW_n/00onX_n[oYkcYojNlj@04ojNlj@KoY[cY00?oY[gZojO1k?nW`N`01?nW`N`5ojS2k@;oZ<;/
1_nX`>/5ojNnjP;oY[kZ1_nW_n/6ojO0j`03ojS2k?nX`NcoZ<7/00KoZ<7/0onW_n/2ojNnj`SoYko[
00?oYl3[ojS2k?nX`^`01?nX`^`6ojS1j`goYko[0_nX`>/3ojS1k003o`000?nX`NcoZ<3[00GoZ<3[
3OnW_n/01?nX`N_oooooooooool00006ooooo`009_ooool00ol0003oooooooooo`0booooo`KoY[o/
1onW`>/7ojW0j`KoZ<3[1onU_n`6ojO0j`koZL3Z0onT_nd3ojBok0SoY/3/0onZ`NX3ojS1j`OoZl3Y
00?oYkkZoj^oj?n[_nP01?n[_nP5ojBmj`;oZKkX1OnT_N/2odM=]0GoVW^_0onkT:T5onS8]@?oYLC_
0onW_>T7ojNnjP?oYko[0onW_NP8ojNlj@?oY[cY0onW`>`7ojO1k003ojS2kOnX`^coZ<;/00CoZ<;/
1_nX`>/00onW_^[oY[kZojJnjP04ojJnjPKoYko[0_nW`>/5ojS2k0KoZ<7/00?oYko[ojNnjonW_^/0
1?nW_^/6ojNoj`03ojO1k?nX`^coZ<;/00KoZ<;/0onX`N/=ojNoj`CoZ<7[0onX`N`00ol0003oZ<7/
ojS1k002ojS0j`goYko[1OnX`N/00ooooooo0000ooooo`05ooooo`009oooool00ol0003ooooooooo
o`0booooo`KoY[o/1onW`>/7ojW0j`KoZ<3[1onU_n`6ojO0j`koZL3Z1_nT_n`6ojK0k0;oYL3]1_nX
`N/5oj_0j@;oZ/3Z1on[_nP00onT_N_oZKkXojVnj004ojVnj0CoY;g[0_m7CK@6oiYk[`03ok^@ZOoX
b;Goj<Re00?oj<Re00?oZ;gXojNljOnW_>T01OnW_>T5ojNnjP;oZ;gY1_nW_NP6ojNlj@03ojO0jonW
`>coYl3/00GoYl3/1OnW`N`00onX`ngoZ<;/ojS2k006ojS2k0?oZ<3[0onW_^X7ojJnjP?oYko[2_nX
`^`2ojS1k0GoYko[1_nW_^/2ojNoj`GoYl7/1_nX`^`00onX`>_oYko[ojNoj`0;ojNoj`SoZ<7[0onX
`N`00ol0003oYl3[ojNoj`0=ojNoj`OoZ<7[00?o0000ooooooooool01?ooool002Sooooo0_l0000c
ooooo`KoY[o/1onW`>/7ojW0j`KoZ<3[1onU_n`6ojO0j`koZL3Z1_nT_n`2ojK0k0KoYL3]1_nX`N/0
0on[`>WoZ/3Zoj[0jP04oj[0jPGoZkoX0_n[`>T7ojVnj0?oY;g[00?oZKgXodM=]?nJNjl01OnJNjl0
0onkT:Woj<ReonS8]@02onS8]@?oZ;gX1onW_>T00onW_^[oZ;gYojRmj@04ojRmj@KoYkgX0_nW_>T5
ojO0j`OoYl3/00?oYl7/ojS3kOnX`nd00onX`nd6ojS2k0SoYkkZ1OnV_^X00onW`>_oZ<;/ojS2k009
ojS2k0?oZ<3[1onW_n/3ojNnj`?oYko[1onW`N`2ojS2k0GoZ<3[3OnW_n/6ojS1j`03ojS1k?nW`>_o
Yl3[00;oYl3[00?o0000ojO0jonW_n/03OnW_n/5ojS1j`03ooooool0003ooooo00Gooooo000Zoooo
o`03o`000?oooooooooo037ooooo1_nV_n`7ojO0j`OoZL3[1_nX`>/7ojFok0KoYl3[3_nY`>X3ojBo
k0CoY[o[1onU`>d3ojS1j`CoYl7/1_nZ`>X00on[_nSoZl3Yoj_0j@04oj_0j@GoZKkX0_n[`>T4ojVm
j003odM=]?nJNjooVW^_00;oVW^_0_nU`^h4onS8]@CoZ;gX1OnW_>T2ojRnj@OoZ;gY0onW_NP:ojO0
j`?oYl3/2_nX`nd2ojS2k0coYkkZ00?oY[kZojO0jonW`>/00onW`>/7ojS2k0OoZ<3[1OnW_n/00onW
_^_oYko[ojNoj`05ojNoj`GoYl7/00?oZ<;/ojS0jonX`>/01_nX`>/=ojNoj`;oZ<7[1OnX`N`4ojO0
j`03o`000?nW`>_oYko[00goYko[00?oZ<7[ooooooooool00oooool00ol0003oooooooooo`03oooo
o`00:oooool00ol0003oooooooooo`0aooooo`KoY[o/1onW`>/7ojW0j`KoZ<3[1onU_n`6ojO0j`ko
ZL3Z1onV_n/3ojG0k@CoY;o]1onW`N`3oj[0jP?oZ<7/1on[`>T00onY_^SoZl3Yoj_0j@04oj_0j@Co
ZKgX00?oVW^_ojG2k_nU`^h01?nU`^h2onS8]@KoZ;gX00?oYkcYojRnjOnX_^T01?nX_^T5ojRmj@go
Yl3[0_nW`nh:ojS3k@goYkkZ0onW_n/7ojO0j`OoZ<;/1onX`>/00onW_n_oYkk[ojNnj`03ojNnj`Oo
Yko[00?oYl7/ojS2k?nX`^`00onX`^`6ojS0j`goYko[2OnX`N`3ojO0j`03o`000?nW_n_oYko[00[o
Yko[2Oooool00ol0003oooooooooo`03ooooo`00;?ooool00ol0003oooooooooo`0aooooo`KoY[o/
1onW`>/7ojW0j`KoZ<3[1onU_n`3ojO0j`CoYl3/3OnY`>X5ojJoj`;oYko[1onT_nd5ojO1k0;oYL7]
1_nX`N`5oj_0j@;oZ<7[1on[`>T3ojVmj003ojW0j_nU`^koYL;^00GoYL;^00?oj<ReojVnj?nX_NP0
0_nX_NP3ojVojPOoZ;kY00?oZ;gYojO0jonW`>/02onW`>/6ojO3kPGoZ<?]0_nX_nX=ojNnjPKoYko[
1OnW`>/9ojS2k0?oZ<3[2_nW_^/3ojNoj`CoZ<7/1_nX`^`2ojS0j`goYko[2onX`N`00onW`>_oYko[
ojNoj`02ojNoj`03o`000?nW_n_oYko[00GoYko[3Oooool00ol0003oooooooooo`03ooooo`00;Ooo
ool2o`0003;ooooo1_nV_n`7ojO0j`OoZL3[1_nX`>/7ojFok0OoYl3/0onY`>X3ojW0j`OoZL3Z00?o
Y[o[ojNojonW_n/01?nW_n/7ojBok@03ojO1k?nU`NgoYL7]00CoYL7]1_nX`N`00on[`>WoZ<7[ojS1
j`04ojS1j`GoZl3Y00?oZ<7/ojW0j_nY`>X00onY`>X5ojG2kP;oZKkX0_nX`>/6ojVojPGoZ;kY0_nW
`N`:ojO0j`[oYl?^00?oZ<?]ojRoj_nX_nX01?nX_nX=ojNnjPKoYko[00?oYl3[ojS2k?nX`^`02OnX
`^`2ojNoj`_oYkk[0_nW`>/7ojS1k0?oZ<;/0onW`>/>ojNoj`SoZ<7/1OnW`>/4ojNoj`04o`000?nW
_n_oYko[ojNoja3ooooo00?o0000ooooooooool00oooool002oooooo00?o0000ooooooooool0<?oo
ool7ojJok0KoYl3[1onY`>/6ojS0j`OoYKo/1OnW`>`2ojK0k0KoZL3[1onY`>X7ojNoj`?oY;o]0onU
_^`8ojG1k@?oZ<7/0_nV`^d8ojS1j`03oj_0jOnX`NcoZ<7/00?oZ<7/1OnY`>X00onU`^koZL3ZojVn
j006ojS0j`KoZKoZ00?oZ;kYojO1k?nW`N`01?nW`N`5ojO0j`coYl?^0_nX_n/8ojRojPgoYkkZ0onW
_n/;ojS2k0KoYko[1onW_^/6ojO0j`KoZ<7/1onW`>/>ojNoj`GoZ<7/2?nW`>/3ojNoj`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool00oooool0033ooooo00?o0000ooooooooool0<Oooool6
ojJok0OoYl3[1_nY`>/7ojS0j`KoYKo/00?oYl3/ojK0k?nV`>`01?nV`>`6ojW0j`OoZL3Z1OnW_n/2
ojVojPKoYKk/1_nU`Nd00onT_ncoY/;]ojK2k@04ojK2k@KoZ<7[00?oY/;]ojS1k?nX`N`01OnX`N`3
ojW0jP?oYl;]2?nX`>/3ojVojP?oYl;]1onW`N`00onW`>_oYl?^ojO3kP09ojO3kP03ojNojonX_n_o
Z;o[00CoZ;o[1_nX_nX=ojNnjP03ojO1k?nX`^coZ<;/00SoZ<;/2onW_n/3ojNnj`;oYko[2?nW`>/6
ojS1k0OoYl3[3?nW_n/7ojS1k0KoYl3[1Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo00?ooooo000aooooo`03o`000?oooooooooo037ooooo1onV_n`6ojO0j`OoZL3[1onX`>/2ojFo
k0CoY[o/1_nV`>`3ojW0j`?oZ<7[1onY`>X00onW_n_oZKoZojVojP04ojVojPKoYKk/0_nU`Nd5ojBo
k0KoY/;]0_nX`N/5ojK2k@GoZ<7/0_nV`^h6ojO2k@KoZ<3[00?oYl?^ojO2kOnW`^d01OnW`^d3ojO1
k0?oY/;^2OnW`nh5ojNoj`KoZ;o[0_nX_nX=ojNnjPGoYl7/1OnX`^`2ojS1j`coYko[00?oYkk[ojNo
jonW_n/01?nW_n/6ojO0j`03ojS2k?nX`NcoZ<7/00GoZ<7/0onW`>/<ojNoj`_oZ<7/0_nW`>/9oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool00oooool003;ooooo0_l0000booooo`Oo
Y[o/1_nW`>/7ojW0j`OoZ<3[1_nV_n`4ojK0k0?oYL3/1OnX`N/7ojW0jPOoZKoZ0onU_^`4ojRojPKo
Y;o/0onV`^d4ojG0k@KoY/;]00?oZ<7/ojK2k_nV`^h01?nV`^h6ojO2k@;oZ<3[1OnW`nh5ojO2k@;o
Y/7]1_nV`^h5ojO3kP;oYkoZ1onW_n/3ojRoj`goYkkZ1?nW`>`6ojO1k003ojS2k?nX`N_oZ<7[00Co
Z<7[2?nW_n/5ojNnj`KoYko[0_nW`>/5ojS2k0GoZ<7/3OnW_n/00onW`>_oZ<7/ojS1k009ojS1k0ko
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`00=?ooool00ol0003ooooo
ooooo`0`ooooo`OoY[o/1_nW`>/7ojW0j`OoZ<3[1_nV_n`00onV`>coYL3/ojG0k004ojG0k0GoZ<7[
1onY`>X5ojVojP;oZL3Z1onX_nX3ojBok0?oYkkZ1onU`>d3ojK2k@?oYL3]1onV`^h3ojO2k@CoYL7]
1_nW`nh00onW`^goY/7]ojK1k@04ojK1k@KoY/;^00?oYl?^ojNoj_nW_nX01?nW_nX5ojNoj`goYkkZ
0_nW`>/7ojO0k0?oYl7/0onX`^`7ojS1j`?oYko[0onW_^X7ojNnj`?oYko[1?nX`N`6ojS2k003ojS1
k?nW_n_oYko[00_oYko[1OnW`>/6ojS1k1;ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`02ooooo`00=Oooool00ol0003oooooooooo`0`ooooo`OoY[o/1_nW`>/7ojW0j`OoZ<3[0onV
_n`3ojNoj`OoYL3/0_nX`N/4ojO1k0KoZL3Z00?oZKoZojW0j_nY`>X01?nY`>X5ojRojP;oZKoZ1_nW
_^X5ojG0k@;oYkkZ1_nU`>d5ojK2kP;oYKo/1onU`Nd3ojO3kP?oY[o/1onV`Nd3ojK2kPCoYkkZ1_nW
_nX00onW_n_oYkkZojNnjP0;ojNnjPKoYl3[1OnW`>`8ojS2k0GoZ<7[2?nW_^X5ojNnj`03ojO0k?nX
`NcoZ<7/00KoZ<7/0onX`^`2ojO0j`koYko[1_nW`>/2ojS1k1Kooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`02ooooo`00=_ooool00ol0003oooooooooo`0`ooooo`OoY[o/1_nW`>/7
ojW0j`GoZ<3[0_nY`>X6ojNoj`GoYL3/0_nU_n`6ojO1k0?oZL3Z0onX`N/7ojW0jP03ojRoj_nY_n[o
ZKoZ00CoZKoZ1_nW_^X00onU`>goYkkZojNnjP04ojNnjPKoYL3]00?oY/;^ojFok?nU_n`01?nU_n`5
ojG1k@;oYkkZ1_nV_n`5ojK1k@;oZ;kY1onW_^X3ojNojP?oZ;kZ2_nW_^X:ojO0j`03ojO0k?nX`^co
Z<;/00[oZ<;/00?oZ<7[ojNnj_nW_^X02_nW_^X00onW_^_oYl3/ojO0k003ojO0k0OoZ<7/1_nW`>/>
ojNoj`?oYl3[6oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo000goooo
o`;o0000<Oooool7ojJok0?oYl3[1?nW`>`6ojW0j`03ojS0jonY`>[oZL3Z00CoZL3Z1_nW_n/00onU
`>coYKo/ojFok004ojFok0CoYl7/0_nV`>d6ojS1j`GoZL3Z0_nY`>/7ojVojP?oYkkZ0onY_nT7ojNn
jP?oYL3]1?nW_^X6ojFok003ojG1kOnW_^[oYkkZ00CoYkkZ1_nV_n`00onV`NgoZ;kYojRnj@04ojRn
j@GoYkkZ2?nX_^X5ojNnjPgoYl3[00?oYl;]ojS2k?nX`^`02?nX`^`3ojNojP[oYkkZ1?nW_n/6ojO0
k0OoZ<7/1_nW`>/<ojNojb3ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`02oooo
o`00>Oooool00ol0003oooooooooo`0_ooooo`OoY[o/1onW`>`3ojW0j`?oZ<3[1onY`>X3ojNoj`Co
Z;o[1_nU_n`00onW`NcoY/3]ojK0k@03ojK0k@KoZ<7[00?oZL3ZojW0jonY`>/01?nY`>/5ojVojP;o
ZL3Z1_nY_nT5ojNnjP;oZKoY1onW_^X3ojFok0?oZ;kY1onW_^X3ojJok0[oZ;kY00?oYkkZojRnj_nX
_^X02_nX_^X00onW_^[oYl3[ojO0j`0;ojO0j`GoYl;]1OnX`^`2ojNoj`KoYkoZ1OnW_^X9ojNoj`?o
Yl3/2_nX`N`3ojO0j`_oYko[8oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;o
oooo000jooooo`03o`000?oooooooooo02oooooo1onV_n`5ojO0k0;oY/3/1_nX`>/7ojW0jPOoZ;o[
0onU_n`3ojJoj`KoY/3]0onX`N/4ojO1k0KoZL3[00?oZKoZojW0j_nY`>X01?nY`>X6ojVoj@03ojNn
j_nY_nWoZKoY00CoZKoY1OnW_^X2ojVojPKoZ;kY1OnW_^X00onX_nWoZ;kYojRnj@09ojRnj@;oZ;oZ
2_nX_^X=ojO0j`[oYl;]00?oZ<;/ojNojonW_n/01?nW_n/6ojNojP03ojNnj_nW_n_oYko[00WoYko[
00?oZ<;/ojS1k?nX`N`02_nX`N`;ojNojbSooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`02ooooo`00>oooool00ol0003oooooooooo`0`ooooo`KoY[o/00?oYl3/ojK0k?nV`>`01?nV
`>`6ojS0j`OoZL3Z1OnX_n/2ojRojPKoY[o[1?nV`>d2ojFok0OoYl7/0onY`>/3ojS1k0OoZL3Z0onY
_nT4ojW0jPKoZKoY00?oYkkZojVoj_nY_nX01?nY_nX6ojRnj@03ojNnj_nX_nWoZ;oY00?oZ;oY1_nX
_^T7ojRojPGoZ;kZ0_nW`N`;ojO0j`coYl;]2_nW_n/6ojNojPSoYko[1OnX`^`8ojS1k0[oYko[;Ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo007ooooo000looooo`03o`000?oooooo
oooo033ooooo0onV_n`3ojNoj`OoY/3/0onX`>/4ojS1j`KoZL3Z00?oZ;o[ojRoj_nX_nX01?nX_nX6
ojJoj`03ojK0kOnU_ncoYKo/00?oYKo/1OnW`N`2ojG0k@KoZ<7/1OnY`>X2ojS1k0OoZL3Z0onY_nT3
ojS0jPOoZKoZ0onX_^T2ojRojPOoZ;oY0_nX_^T;ojRojP03ojRnj_nW`NcoYl7/00CoYl7/1onW`>/;
ojO2k@goYko[00?oYkkZojNoj_nW_nX01OnW_nX3ojNoj`?oYl7/1onX`^`3ojS1k0_oYko[<Oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo007ooooo000mooooo`;o0000<Oooool6ojNo
j`OoY/3/1onX`N/3ojW0jP?oZL3[1onX_nX3ojJoj`?oYko[1_nU_n`00onW`NcoYL3]ojG0k@04ojG0
k@KoZ<7/00?oZL3ZojS1k?nX`N`01?nX`N`5ojW0jP;oZ<7/1_nX`>X5ojVojP03ojS0jonX_n[oZ;oZ
00CoZ;oZ1OnX_nT2ojS0j`[oZ;oZ2_nW`N`3ojO0j`_oYl;]3OnW_n/5ojNnjPGoYkoZ2?nW`N`5ojS2
k0;oZ<3[2_nW_n/dooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00Oooool003oo
oooo00?o0000ooooooooool0;oooool6ojNoj`OoY/3/1OnX`N/2ojO0k0KoZL3[1OnX_nX2ojW0jPKo
Yko[0onU_n`3ojJoj`OoYL3]0onX`N`4ojK1k@KoZ<7/00?oZL3ZojS1k?nX`N`01?nX`N`6ojS0jP03
ojVoj_nX`>_oZ<3[00?oZ<3[1_nX_nX00onX_nWoZ<3[ojS0j`04ojS0j`GoZ;oZ0_nW`^d;ojO1k0co
Yl;]3?nW_n/:ojNnjP03ojNoj_nW`NcoYl7/00[oYl7/00?oZ<;/ojS0jonX`>/01?nX`>/5ojNojcWo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`01ooooo`00@?ooool00ol0003ooooo
ooooo`0_ooooo`?oYko[1?nW`>/6ojK0k003ojS1jonW`>coYl3/00CoYl3/1_nY`>/00onX_n[oZL3Z
ojW0jP04ojW0jPCoYko[0_nX_nX6ojJoj`GoYL3]0_nV_n`7ojK1k@?oZ<7/0onV`Nd7ojS1k0?oZ<3Z
0onW`^`6ojS0j`?oZ;oZ1?nX`N`6ojS0j`03ojRoj_nW`^goYl;]00CoYl;]1onW`N`;ojO2k@_oYko[
3OnW_^X3ojO0j`[oYl7/0onX`N`7ojS0j`03ojNojooooooooooo03_ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`01ooooo`00@Oooool00ol0003oooooooooo`0_ooooo`OoYl3[0onV
`>`3ojJok0OoYl3/0onY`>/4ojS1j`KoZL3Z00?oYko[ojRoj_nX_nX00onX_nX6ojJoj`03ojG0kOnV
_ncoY[o/00CoY[o/1OnV`Nd2ojJok0KoY/7]1OnX`N`00onV`NgoYl;/ojO2k005ojO2k0?oZ<3[0onW
`^d7ojS1k0?oZ<3[2_nW`^d6ojO1k0SoYl;]2_nW_n/=ojNnjPSoYl3[1OnW`N`8ojS1k0?oZ<3[@Ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo007ooooo0012ooooo`;o0000<?ooool5
ojO0j`;oZ<3[1_nV_n`5ojO0k0;oY/3/1onX`N/3ojW0jP?oZ<3Z1_nX_nX3ojJoj`CoZ;oZ1_nV_n`0
0onV`NgoY[o/ojJok004ojJok0KoY/7]00?oZ<7/ojK1kOnV`Nd00onV`Nd5ojO2k0;oY/3/1_nW`^d5
ojS1k0;oY/7/2_nW`^d2ojO0k0OoYl7/0onW`^d;ojNoj`goYkkZ3?nW`>/00onW`NcoZ<7/ojS1k008
ojS1k4Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`01ooooo`00A?ooool00ol0
003oooooooooo`0^ooooo`03ojO0jonX`>_oZ<3[00CoZ<3[1_nV_n`00onW`>coY/3/ojK0k004ojK0
k0GoZ<7[0_nW`N`6ojS0jPCoZ;oZ0_nY_nX7ojRojP?oY[o/0onX_nX7ojJok0?oY/7]1?nV_n`5ojK1
k@03ojO2k?nV`>coY/3/00CoY/3/1_nW`^d00onX`NcoY/7/ojK1k004ojK1k0GoYl;]00?oYko[ojO0
k?nW`>`01?nW`>`5ojO1k0;oYkoZ2_nW_n/3ojRojP[oYkkZ3?nW`>/4ojO1k0OoZ<7/B_ooool00ol0
003oooooooooo`07ooooo`7o00000Oooool1ooooo`00AOooool00ol0003oooooooooo`0_ooooo`Ko
Z<3[0onV_n`4ojNoj`KoY/3/00?oZ<7[ojO1k?nW`N`01?nW`N`6ojS0jP03ojRoj_nY_n[oZKoZ00?o
ZKoZ3OnX_nX5ojJok0;oZ;oZ1onV_n`2ojK1k@?oY[o[1onV`>`3ojO2k@CoY[o/1_nV`N`00onW`^go
Yko[ojNoj`03ojNoj`KoYl3/00?oYl7/ojNoj_nW_nX01?nW_nX5ojNoj`SoZ;oZ1OnW_^X;ojO0j`[o
Yl7/0onX`Na>ooooo`03o`000?oooooooooo00Kooooo0Ol00001ooooo`7ooooo0016ooooo`03o`00
0?oooooooooo033ooooo0_nX`>/3ojRoj`OoYko[0onV`>`4ojJok0KoYl7/0onX`>X3ojS1j`KoZKoZ
3OnX_nX00onV_ncoZ;oZojRojP04ojRojPGoY[o/00?oZ;oZojJojonV_n/01?nV_n/5ojK0k0;oYko[
1onV_n`3ojK1k0WoYko[0onW`>`4ojRojPKoYkoZ00?oYko[ojRoj_nX_nX02_nX_nX00onW_^[oYl3[
ojO0j`08ojO0j`goYl7/D_ooool00ol0003oooooooooo`06ooooo`7o00000Oooool1ooooo`00Aooo
ool2o`00037ooooo1OnX_n/7ojNoj`OoY[o/0onW`N`3ojK0k0KoZ<7[0onY_nX4ojS0ja?oZ;oZ00?o
Y[o/ojRoj_nX_nX00onX_nX6ojJoj`03ojK0k?nW_n_oYko[00CoYko[1OnV_n`00onX_n[oYko[ojNo
j`09ojNoj`WoZ;oZ0onW_nX=ojRojP[oYl3[3OnW`NaFooooo`03o`000?oooooooooo00Gooooo0Ol0
0001ooooo`7ooooo0019ooooo`03o`000?oooooooooo02oooooo1OnX_n/7ojNoj`GoY[o/0_nW_n/6
ojK0k0CoZ<7[0_nW`N`7ojS0j`?oZ;oZ0onX`>/CojRojP?oY[o[1?nX_nX6ojNoj`03ojJok?nX_n[o
Z;oZ00?oZ;oZ1onW_n/HojRojP_oYl3[3OnW`NaJooooo`03o`000?oooooooooo00Cooooo0Ol00001
ooooo`7ooooo001:ooooo`03o`000?oooooooooo02oooooo0_nX_n/4ojS0jPKoYko[00?oY[o/ojNo
jonW_n/01?nW_n/6ojK0k003ojS1jonW`NcoYl7/00?oYl7/1OnX`>/2ojO1k0KoZ<3[1OnX_nX00onX
`>_oZ;oZojRojP0BojRojP?oYko[2OnX_nX3ojNojaSoZ;oZ2_nW`>/=ojO1k5oooooo00?o0000oooo
ooooool00oooool1o`00007ooooo0Oooool004_ooooo00?o0000ooooooooool0;oooool6ojS0jP?o
Yko[1?nX_n/6ojNoj`?oY/3/1?nV_n`5ojO1k003ojS0jonW`NcoYl7/00CoYl7/1_nX`>/00onX_n[o
Z<3[ojS0j`03ojS0j`GoZ;oZ0_nX`>/SojRojPCoZ;o[2OnX_nX3ojO1k0OoYl3[3OnW`NaRooooo`03
o`000?oooooooooo00?ooooo0Ol00001ooooo`7ooooo001<ooooo`;o0000<?ooool4ojS0jP;oZ<3[
1onX_n/3ojNoj`?oZ;o[1onV_n`2ojO1k0CoY/3/1_nW`N`3ojS0j`CoYl7/1OnX`>/00onX_n[oZ<3[
ojS0j`04ojS0ja7oZ;oZ0_nX`>/;ojRojP;oZ<3[1onX_n/3ojRojPWoYl7/0onW`>/=ojO1k6Kooooo
00?o0000ooooooooool00oooool1o`00007ooooo001>ooooo`03o`000?oooooooooo02kooooo00?o
Z<3ZojS0jonX`>/00onX`>/5ojRoj`;oZ;oZ1_nX_n/5ojJok003ojNojonV`>coY/3/00GoY/3/0onW
`N`3ojK0k0OoYl7/0_nX`>/3ojO1k0OoZ<3[0onX_nX4ojS1j`OoZ;oZ1OnX`>/7ojRojPKoZ<3[1OnX
_n/HojO1k6cooooo00?o0000ooooooooool00_ooool1o`00007ooooo001?ooooo`03o`000?oooooo
oooo02oooooo1OnX`>/00onX_n_oZ;oZojRojP04ojRojPKoZ;o[00?oY[o/ojNojonW_n/00onW_n/5
ojK0k0;oYko[1_nV`>`5ojO1k003ojK0k?nW`NcoYl7/00CoYl7/1OnX`>/2ojO1k0OoZ<7[0onX_nX3
ojS1k0KoZ<3[0onX_nX4ojO1k0KoZ<3[00?oZ;o[ojO1k?nW`N`05OnW`Naaooooo`05o`000?oooooo
ooooooooool000000Oooool0053ooooo00?o0000ooooooooool0;oooool2ojS0j`?oZ<7[1onX_nX3
ojRoj`CoZ;oZ1OnW_n/00onV`>coYko[ojNoj`04ojNoj`KoY/3/00?oYl7/ojK0k?nV`>`00onV`>`6
ojO1k003ojS0jonW`NcoYl7/00CoYl7/1OnX`N/00onV`NcoZ<7/ojS1k005ojS1k0?oZ<3[2_nW`N`3
ojS0jaOoYl7/M?ooool01Ol0003ooooooooooooooooo0000007ooooo001Aooooo`;o0000<?ooool5
ojS1j`GoZ;oZ0_nX`>/7ojRojP;oYko[1?nX_n/6ojNoj`?oY/3/1?nW_n/5ojK0k0?oYl7/1?nV`>`6
ojO1k003ojS1jonV`NcoY/7/00?oY/7/1OnX`N`2ojK0k0_oYl7/00?oYl3/ojO1k?nW`N`02?nW`N`3
ojO0k0[oYl7/N?ooool01?l0003oooooooooool00001ooooo`00Doooool00ol0003oooooooooo`0^
ooooo`GoZ<7[00?oZ;oZojS0jonX`>/01?nX`>/5ojRojP03ojS0j_nX_n_oZ;o[00GoZ;o[0onW_n/3
ojRoj`OoYko[0_nV`>`4ojNoj`KoY/3/0onW`N`3ojK0k0KoY/7/00?oZ<7/ojK0k?nV`>`01?nV`>`7
ojO1k0GoYl3/1OnW`N`2ojNoj`KoYl3/1OnW`Namooooo`03o`000?oooooo0000007ooooo001Doooo
o`03o`000?oooooooooo02kooooo0_nX`N/4ojO0k0KoZ<3[00?oZ;oZojS0j_nX`>X00onX`>X5ojRo
j`;oZ;oZ1_nX_n/5ojNoj`03ojRojonW_n_oYko[00GoYko[0onV`>`3ojNoj`KoY/3/0onV`N`4ojNo
j`KoY/3/0onW`N`3ojNoj`KoYl3/00?oYl7/ojNojonW_n/01?nW_n/6ojO0k003ojO1k?oooooooooo
07kooooo00?o0000ooooool000000Oooool005Gooooo00?o0000ooooooooool0;_ooool6ojO0k0?o
Z<3[1?nX`N/5ojS0jP03ojRojonX_n[oZ;oZ00CoZ;oZ1_nX_n/00onW_n_oZ;o[ojRoj`03ojRoj`Go
Yko[0_nX_nX6ojNoj`CoY/3/2OnW_n/3ojK0k0WoYko[0onW`>`:ojNoj`?oYl3/Q?ooool1o`00007o
oooo0Ol0000005Kooooo0_l0000_ooooo`?oYl3/0onV`>`7ojS1j`;oZ<3Z1?nX`N/6ojRojP?oZ;o[
1?nX_nX5ojRoj`03ojNojonX_n[oZ;oZ00CoZ;oZ1_nW_n/00onV`>coYko[ojNoj`08ojNoj`;oZ;o[
2_nW_n/2ojRojP[oYko[R_ooool2o`000000F?ooool00ol0003oooooooooo`0]ooooo`KoY/3/1OnX
`N/2ojK0k0KoZ<7[0onX_nX3ojS1j`OoZ;oZ0_nX_n/:ojRojP?oYko[0onX_nX7ojNoj`KoZ;o[1_nW
_n/6ojRojPGoYko[SOooool3o`000000FOooool00ol0003oooooooooo`0]ooooo`KoY/3/00?oZ<7[
ojK0k?nV`>`01?nV`>`4ojS1j`;oYl7/1_nX`N/5ojRojP03ojS0jonX_n[oZ;oZ017oZ;oZ0onW_n/4
ojRojPKoZ;o[0_nW_n/:ojRojP03ojNojooooooooooo08[ooooo1?l00003ooooo`00F_ooool00ol0
003oooooooooo`0]ooooo`?oY/3/1?nW`>`6ojK0k003ojS1jonW`NcoYl7/00?oYl7/1_nX`N/00onX
_n[oZ<3[ojS0j`03ojS0j`GoZ;oZ0_nX`N/:ojRojP;oZ<3[1onX_nX3ojRoj`coZ;oZS?ooool3o`00
00Oooooo001Kooooo`03o`000?oooooooooo02gooooo1onW`>`6ojK0k0KoYl7/0onX`N/4ojO1k0Go
Z<3[00?oZ;oZojS1jonX`N/01?nX`N/7ojRojPGoZ<3[1OnX_nX00onX`>_oZ;oZojRojP09ojRojXco
oooo1?l0000:ooooo`00G?ooool2o`0002kooooo1OnW`>`2ojNoj`KoY/3/0onW`N`4ojK0k0KoYl7/
0_nX`>/4ojO1k0KoZ<7[0onX_nX3ojS1k0KoZ<3[00?oZ;oZojS0jonX`>/00onX`>/7ojRojX_ooooo
1?l0000>ooooo`00G_ooool00ol0003oooooooooo`0/ooooo`03ojO0k?nW_n_oYko[00CoYko[1?nV
`>`2ojNoj`OoY/3/0onW`N`2ojK0k0OoYl7/0onX`N/3ojO1k0KoZ<7/0onX`>/4ojO1k0GoZ<3[0onX
_nZ:ooooo`Co00004_ooool005oooooo00?o0000ooooooooool0;Oooool6ojNoj`03ojK0k?nW_n_o
Yko[00?oYko[1OnV`>`2ojNoj`GoY/3/1OnW`N`2ojO0k0KoYl7/0onX`N`3ojO0k0OoYl7/0_nX`>^;
ooooo`Co00005_ooool0063ooooo00?o0000ooooooooool0;Oooool3ojNoj`CoZ;o[1OnW_n/00onV
`>coYko[ojNoj`04ojNoj`GoY/3/00?oYl7/ojO0k?nW`>`01?nW`>`4ojO1k0SoYl3/1OnW`Nb;oooo
o`?o00006_ooool0067ooooo0_l0000^ooooo`OoZ;o[0_nW_n/4ojRoj`KoYko[0_nV`>`4ojNoj`Ko
Yl3/00?oYl7/ojO0k?nW`>`02OnW`>`00onW`Ncoooooooooo`28ooooo`Co00007Oooool006?ooooo
00?o0000ooooooooool0;?ooool5ojRoj`03ojS0jonX_n_oZ;o[00GoZ;o[0onW_n/3ojRoj`KoYko[
0onW`>`3ojNoj`WoYl3/ROooool4o`00027ooooo001Tooooo`03o`000?oooooooooo02cooooo00?o
Z;o[ojS0jonX`>/00onX`>/5ojRoj`;oZ<3[1_nX_n/3ojNoj`?oZ;o[1_nW_n/3ojO0k8[ooooo1?l0
000Uooooo`00IOooool00ol0003oooooooooo`0]ooooo`GoZ<3[00?oZ;o[ojS0jonX`>/01?nX`>/4
ojRoj`;oZ<3[1_nX_n/4ojNojh[ooooo1?l0000Yooooo`00I_ooool2o`0002kooooo3?nX`>/00onX
_n_oZ<3[ojS0j`03ojS0j`KoZ;o[00?oYko[ooooooooool0Qoooool3o`0002gooooo001Xooooo`03
o`000?oooooooooo02cooooo2OnX`>/3ojS1j`KoZ<3[0onX_n^8ooooo`Co0000<?ooool006Wooooo
00?o0000ooooooooool0;?ooool3ojS0j`CoYl3/1OnX`N/3ojS0jhWooooo1?l0000dooooo`00J_oo
ool00ol0003oooooooooo`0/ooooo`OoYl3/0_nX`N^:ooooo`Co0000>?ooool006_ooooo0_l0000]
ooooo`GoYl3/ROooool4o`0003cooooo001]ooooo`03o`000?oooooooooo02_ooooo00?oYl3/oooo
ooooool0Qoooool3o`00043ooooo001^ooooo`03o`000?oooooooooo02[ooooo00?o0000oooooooo
ool0Poooool4o`0004?ooooo001_ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0
Ooooool4o`0004Oooooo001`ooooo`;o0000:Oooool00ol0003oooooooooo`1kooooo`Co0000Booo
ool007;ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1gooooo`Co0000Coooool0
07?ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1dooooo`?o0000Doooool007Co
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1`ooooo`Co0000E_ooool007Gooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`1/ooooo`Co0000F_ooool007Kooooo0_l0
000Sooooo`03o`000?oooooooooo06Sooooo1?l0001Nooooo`00N?ooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo06Cooooo1?l0001Rooooo`00NOooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo067ooooo0ol0001Vooooo`00N_ooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo05gooooo1?l0001Yooooo`00Noooool2o`0001kooooo00?o0000ooooooooool0
FOooool4o`0006gooooo001mooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0EOoo
ool4o`00077ooooo001nooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0DOooool4
o`0007Gooooo001oooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0C_ooool3o`00
07Wooooo0020ooooo`;o00006Oooool00ol0003oooooooooo`1:ooooo`Co0000O?ooool008;ooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`16ooooo`Co0000P?ooool008?ooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`12ooooo`Co0000Q?ooool008Cooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`0nooooo`Co0000R?ooool008Gooooo0_l0000Coooo
o`03o`000?oooooooooo03cooooo0ol0002<ooooo`00Qoooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo03Sooooo1?l0002?ooooo`00R?ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo03Cooooo1?l0002Cooooo`00ROooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo033ooooo1?l0002Gooooo`00R_ooool2o`0000kooooo00?o0000ooooooooool0;?ooool4
o`0009_ooooo002<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0:Oooool3o`00
09oooooo002=ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool09Oooool4o`000:;o
oooo002>ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08Oooool4o`000:Kooooo
002?ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07Oooool4o`000:[ooooo002@
ooooo`;o00002?ooool00ol0003oooooooooo`0Iooooo`Co0000[_ooool009;ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Fooooo`?o0000/_ooool009?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0Booooo`Co0000]Oooool009Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0>ooooo`Co0000^Oooool009Gooooo0_l00003ooooo`03o`000?oo
oooooooo00[ooooo1?l0002mooooo`00Uoooool01?l0003oooooooooool00008ooooo`Co0000`Ooo
ool009Sooooo00?o0000ooooool000001Oooool3o`000<Gooooo002Iooooo`;o000000?oooooo`00
0?l000000_l00038ooooo`00V_ooool2o`000<cooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000
\
\>"],
  ImageRangeCache->{{{0, 359}, {290.875, 0}} -> {-0.0538698, 0.0433414, \
0.0035044, 0.0035044}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[.12586 .2075 -12 -8.99448 ]
[.12586 .2075 0 .00552 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.56094 .0364 -5.16972 -9 ]
[.56094 .0364 .83028 0 ]
[.75679 .08071 0 -6.17777 ]
[.75679 .08071 12 2.82223 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.9429 .3657 0 -5.9083 ]
[.9429 .3657 6 3.0917 ]
[.02494 .25992 -18 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.01611 .31527 -18 -2.78472 ]
[.01611 .31527 0 6.21528 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00254 .43215 -12 -2.88407 ]
[-0.00254 .43215 0 6.11593 ]
[-0.0124 .49393 -12 -2.93688 ]
[-0.0124 .49393 0 6.06312 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
[(-2)] .12586 .2075 1 .99877 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.56863 .04703 m
.57247 .05235 L
s
[(2)] .56094 .0364 .72324 1 Mshowa
.125 Mabswid
.18558 .19702 m
.18832 .19985 L
s
.23703 .17687 m
.23971 .17975 L
s
.28951 .15632 m
.29214 .15925 L
s
.39772 .11395 m
.40023 .11699 L
s
.4535 .09211 m
.45595 .0952 L
s
.51046 .06981 m
.51284 .07294 L
s
.08568 .23614 m
.08851 .23887 L
s
.62804 .02377 m
.63027 .02701 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.7445 .0853 m
.73835 .08759 L
s
[(-2)] .75679 .08071 -1 .37284 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.93037 .36962 m
.92411 .37158 L
s
[(2)] .9429 .3657 -1 .31296 Mshowa
.125 Mabswid
.7708 .12553 m
.7671 .12688 L
s
.79613 .16428 m
.79242 .1656 L
s
.82054 .20161 m
.81682 .20291 L
s
.86679 .27235 m
.86305 .2736 L
s
.88871 .30589 m
.88497 .30711 L
s
.9099 .3383 m
.90615 .3395 L
s
.71716 .04348 m
.71349 .04489 L
s
.95018 .39992 m
.94642 .40107 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(-20)] .02494 .25992 1 -0.39157 Mshowa
.02837 .31059 m
.0345 .30825 L
s
[(-10)] .01611 .31527 1 -0.38117 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.00981 .42772 m
.01599 .4255 L
s
[(10)] -0.00254 .43215 1 -0.3591 Mshowa
0 .48963 m
.0062 .48748 L
s
[(20)] -0.0124 .49393 1 -0.34736 Mshowa
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.655 .752 .921 r
.39362 .69482 .40169 .70183 .4152 .69806 .40717 .69101 Mtetra
.657 .753 .921 r
.40717 .69101 .4152 .69806 .42878 .69426 .42079 .68712 Mtetra
.657 .751 .919 r
.42079 .68712 .42878 .69426 .44242 .69039 .43448 .68318 Mtetra
.656 .75 .919 r
.43448 .68318 .44242 .69039 .45614 .68648 .44824 .67926 Mtetra
.655 .751 .92 r
.44824 .67926 .45614 .68648 .46992 .68257 .46207 .67535 Mtetra
.654 .751 .921 r
.46207 .67535 .46992 .68257 .48378 .67867 .47597 .67146 Mtetra
.654 .752 .922 r
.47597 .67146 .48378 .67867 .4977 .67477 .48994 .66754 Mtetra
.656 .753 .922 r
.48994 .66754 .4977 .67477 .5117 .67087 .50398 .66355 Mtetra
.657 .752 .92 r
.50398 .66355 .5117 .67087 .52577 .66694 .5181 .65951 Mtetra
.657 .75 .919 r
.5181 .65951 .52577 .66694 .53991 .66293 .53229 .65544 Mtetra
.657 .75 .918 r
.53229 .65544 .53991 .66293 .55412 .65889 .54655 .65137 Mtetra
.656 .75 .919 r
.54655 .65137 .55412 .65889 .56841 .65482 .56088 .64729 Mtetra
.56088 .64729 .56841 .65482 .58277 .65075 .57529 .64321 Mtetra
.655 .751 .92 r
.57529 .64321 .58277 .65075 .59721 .64667 .58978 .63912 Mtetra
.655 .752 .921 r
.58978 .63912 .59721 .64667 .61172 .64258 .60434 .63503 Mtetra
.655 .753 .922 r
.60434 .63503 .61172 .64258 .6263 .63846 .61898 .6309 Mtetra
.655 .754 .922 r
.61898 .6309 .6263 .63846 .64096 .63433 .6337 .62675 Mtetra
.655 .754 .923 r
.6337 .62675 .64096 .63433 .6557 .63018 .64849 .62256 Mtetra
.64849 .62256 .6557 .63018 .67052 .626 .66336 .61835 Mtetra
.655 .755 .923 r
.66336 .61835 .67052 .626 .68542 .6218 .67831 .61411 Mtetra
.656 .755 .923 r
.67831 .61411 .68542 .6218 .70039 .61758 .69334 .60984 Mtetra
.69334 .60984 .70039 .61758 .71545 .61333 .70845 .60554 Mtetra
.656 .754 .922 r
.70845 .60554 .71545 .61333 .73058 .60906 .72364 .60121 Mtetra
.72364 .60121 .73058 .60906 .74579 .60477 .73891 .59685 Mtetra
.657 .753 .921 r
.73891 .59685 .74579 .60477 .76109 .60046 .75426 .59247 Mtetra
.656 .752 .92 r
.75426 .59247 .76109 .60046 .77647 .59614 .76969 .58806 Mtetra
.656 .751 .92 r
.76969 .58806 .77647 .59614 .79193 .5918 .78521 .58365 Mtetra
.656 .75 .92 r
.78521 .58365 .79193 .5918 .80748 .58746 .80082 .57924 Mtetra
.655 .749 .919 r
.80082 .57924 .80748 .58746 .82311 .58309 .81651 .57481 Mtetra
.81651 .57481 .82311 .58309 .83882 .57868 .83228 .57038 Mtetra
.83228 .57038 .83882 .57868 .85462 .57419 .84815 .56593 Mtetra
.656 .752 .921 r
.84815 .56593 .85462 .57419 .8705 .56967 .8641 .56141 Mtetra
.657 .754 .921 r
.8641 .56141 .8705 .56967 .88647 .56513 .88013 .55681 Mtetra
.657 .753 .921 r
.88013 .55681 .88647 .56513 .90253 .5606 .89624 .55219 Mtetra
.656 .752 .92 r
.89624 .55219 .90253 .5606 .91868 .55607 .91245 .54758 Mtetra
.655 .751 .92 r
.91245 .54758 .91868 .55607 .93492 .55155 .92876 .54297 Mtetra
.655 .749 .919 r
.92876 .54297 .93492 .55155 .95125 .54697 .94516 .53837 Mtetra
.655 .75 .92 r
.94516 .53837 .95125 .54697 .96766 .5423 .96164 .53373 Mtetra
.657 .753 .921 r
.96164 .53373 .96766 .5423 .98416 .53761 .97821 .52899 Mtetra
.657 .752 .921 r
.38547 .68774 .39362 .69482 .40717 .69101 .39906 .68383 Mtetra
.657 .751 .919 r
.39906 .68383 .40717 .69101 .42079 .68712 .41273 .67988 Mtetra
.656 .75 .919 r
.41273 .67988 .42079 .68712 .43448 .68318 .42646 .67595 Mtetra
.655 .751 .92 r
.42646 .67595 .43448 .68318 .44824 .67926 .44026 .67202 Mtetra
.654 .751 .921 r
.44026 .67202 .44824 .67926 .46207 .67535 .45414 .66812 Mtetra
.654 .753 .922 r
.45414 .66812 .46207 .67535 .47597 .67146 .46808 .66418 Mtetra
.657 .753 .921 r
.46808 .66418 .47597 .67146 .48994 .66754 .4821 .66014 Mtetra
.657 .751 .919 r
.4821 .66014 .48994 .66754 .50398 .66355 .49619 .65607 Mtetra
.657 .75 .918 r
.49619 .65607 .50398 .66355 .5181 .65951 .51035 .65199 Mtetra
.656 .75 .919 r
.51035 .65199 .5181 .65951 .53229 .65544 .52459 .64792 Mtetra
.656 .75 .92 r
.52459 .64792 .53229 .65544 .54655 .65137 .5389 .64385 Mtetra
.654 .751 .921 r
.5389 .64385 .54655 .65137 .56088 .64729 .55328 .63979 Mtetra
.654 .753 .922 r
.55328 .63979 .56088 .64729 .57529 .64321 .56775 .63571 Mtetra
.655 .754 .923 r
.56775 .63571 .57529 .64321 .58978 .63912 .58228 .6316 Mtetra
.58228 .6316 .58978 .63912 .60434 .63503 .5969 .62743 Mtetra
.656 .754 .922 r
.5969 .62743 .60434 .63503 .61898 .6309 .61159 .62323 Mtetra
.656 .753 .921 r
.61159 .62323 .61898 .6309 .6337 .62675 .62635 .619 Mtetra
.656 .752 .921 r
.62635 .619 .6337 .62675 .64849 .62256 .6412 .61475 Mtetra
.656 .751 .92 r
.6412 .61475 .64849 .62256 .66336 .61835 .65612 .61049 Mtetra
.65612 .61049 .66336 .61835 .67831 .61411 .67113 .60621 Mtetra
.67113 .60621 .67831 .61411 .69334 .60984 .68621 .60191 Mtetra
.68621 .60191 .69334 .60984 .70845 .60554 .70138 .59759 Mtetra
.655 .752 .921 r
.70138 .59759 .70845 .60554 .72364 .60121 .71662 .59325 Mtetra
.655 .753 .921 r
.71662 .59325 .72364 .60121 .73891 .59685 .73195 .58889 Mtetra
.656 .754 .922 r
.73195 .58889 .73891 .59685 .75426 .59247 .74736 .58448 Mtetra
.656 .755 .922 r
.74736 .58448 .75426 .59247 .76969 .58806 .76286 .58002 Mtetra
.657 .755 .922 r
.76286 .58002 .76969 .58806 .78521 .58365 .77843 .57553 Mtetra
.657 .753 .921 r
.77843 .57553 .78521 .58365 .80082 .57924 .79409 .571 Mtetra
.656 .752 .92 r
.79409 .571 .80082 .57924 .81651 .57481 .80984 .5665 Mtetra
.656 .75 .92 r
.80984 .5665 .81651 .57481 .83228 .57038 .82568 .56199 Mtetra
.655 .749 .919 r
.82568 .56199 .83228 .57038 .84815 .56593 .8416 .55748 Mtetra
.8416 .55748 .84815 .56593 .8641 .56141 .85762 .55296 Mtetra
.655 .75 .92 r
.85762 .55296 .8641 .56141 .88013 .55681 .87372 .54841 Mtetra
.657 .753 .921 r
.87372 .54841 .88013 .55681 .89624 .55219 .8899 .54374 Mtetra
.657 .754 .921 r
.8899 .54374 .89624 .55219 .91245 .54758 .90617 .53904 Mtetra
.656 .752 .92 r
.90617 .53904 .91245 .54758 .92876 .54297 .92254 .53435 Mtetra
.656 .751 .92 r
.92254 .53435 .92876 .54297 .94516 .53837 .939 .52966 Mtetra
.654 .749 .92 r
.939 .52966 .94516 .53837 .96164 .53373 .95556 .52499 Mtetra
.655 .75 .92 r
.95556 .52499 .96164 .53373 .97821 .52899 .97221 .52027 Mtetra
.658 .751 .919 r
.37724 .68054 .38547 .68774 .39906 .68383 .39088 .67657 Mtetra
.656 .75 .919 r
.39088 .67657 .39906 .68383 .41273 .67988 .40459 .67261 Mtetra
.655 .751 .92 r
.40459 .67261 .41273 .67988 .42646 .67595 .41837 .66868 Mtetra
.654 .751 .921 r
.41837 .66868 .42646 .67595 .44026 .67202 .43221 .66476 Mtetra
.655 .753 .922 r
.43221 .66476 .44026 .67202 .45414 .66812 .44613 .66079 Mtetra
.657 .753 .92 r
.44613 .66079 .45414 .66812 .46808 .66418 .46012 .65673 Mtetra
.657 .75 .919 r
.46012 .65673 .46808 .66418 .4821 .66014 .47419 .65263 Mtetra
.47419 .65263 .4821 .66014 .49619 .65607 .48833 .64855 Mtetra
.656 .75 .919 r
.48833 .64855 .49619 .65607 .51035 .65199 .50254 .64447 Mtetra
.654 .751 .921 r
.50254 .64447 .51035 .65199 .52459 .64792 .51682 .64042 Mtetra
.654 .752 .922 r
.51682 .64042 .52459 .64792 .5389 .64385 .53118 .63636 Mtetra
.655 .754 .923 r
.53118 .63636 .5389 .64385 .55328 .63979 .54561 .63225 Mtetra
.656 .754 .922 r
.54561 .63225 .55328 .63979 .56775 .63571 .56012 .62806 Mtetra
.657 .752 .92 r
.56012 .62806 .56775 .63571 .58228 .6316 .57471 .62383 Mtetra
.657 .75 .919 r
.57471 .62383 .58228 .6316 .5969 .62743 .58937 .61959 Mtetra
.657 .749 .918 r
.58937 .61959 .5969 .62743 .61159 .62323 .60411 .61533 Mtetra
.60411 .61533 .61159 .62323 .62635 .619 .61893 .61106 Mtetra
.656 .749 .918 r
.61893 .61106 .62635 .619 .6412 .61475 .63383 .60676 Mtetra
.63383 .60676 .6412 .61475 .65612 .61049 .64881 .60246 Mtetra
.64881 .60246 .65612 .61049 .67113 .60621 .66387 .59813 Mtetra
.66387 .59813 .67113 .60621 .68621 .60191 .67901 .59379 Mtetra
.67901 .59379 .68621 .60191 .70138 .59759 .69423 .58943 Mtetra
.69423 .58943 .70138 .59759 .71662 .59325 .70953 .58505 Mtetra
.655 .749 .919 r
.70953 .58505 .71662 .59325 .73195 .58889 .72492 .58066 Mtetra
.72492 .58066 .73195 .58889 .74736 .58448 .74039 .57625 Mtetra
.655 .75 .92 r
.74039 .57625 .74736 .58448 .76286 .58002 .75595 .57182 Mtetra
.655 .752 .921 r
.75595 .57182 .76286 .58002 .77843 .57553 .77159 .56735 Mtetra
.656 .754 .922 r
.77159 .56735 .77843 .57553 .79409 .571 .78731 .5628 Mtetra
.657 .755 .922 r
.78731 .5628 .79409 .571 .80984 .5665 .80312 .5582 Mtetra
.657 .754 .921 r
.80312 .5582 .80984 .5665 .82568 .56199 .81901 .55357 Mtetra
.656 .751 .92 r
.81901 .55357 .82568 .56199 .8416 .55748 .83499 .54898 Mtetra
.655 .75 .92 r
.83499 .54898 .8416 .55748 .85762 .55296 .85107 .54439 Mtetra
.655 .749 .919 r
.85107 .54439 .85762 .55296 .87372 .54841 .86724 .5398 Mtetra
.655 .749 .92 r
.86724 .5398 .87372 .54841 .8899 .54374 .88349 .53518 Mtetra
.656 .753 .921 r
.88349 .53518 .8899 .54374 .90617 .53904 .89983 .53046 Mtetra
.657 .754 .921 r
.89983 .53046 .90617 .53904 .92254 .53435 .91626 .52567 Mtetra
.656 .752 .921 r
.91626 .52567 .92254 .53435 .939 .52966 .93279 .52091 Mtetra
.655 .751 .92 r
.93279 .52091 .939 .52966 .95556 .52499 .94941 .51615 Mtetra
.654 .749 .92 r
.94941 .51615 .95556 .52499 .97221 .52027 .96613 .51141 Mtetra
.657 .75 .919 r
.36894 .67324 .37724 .68054 .39088 .67657 .38262 .66927 Mtetra
.655 .751 .92 r
.38262 .66927 .39088 .67657 .40459 .67261 .39637 .66531 Mtetra
.654 .751 .921 r
.39637 .66531 .40459 .67261 .41837 .66868 .41019 .66138 Mtetra
.655 .753 .922 r
.41019 .66138 .41837 .66868 .43221 .66476 .42408 .65739 Mtetra
.657 .752 .92 r
.42408 .65739 .43221 .66476 .44613 .66079 .43805 .6533 Mtetra
.657 .75 .918 r
.43805 .6533 .44613 .66079 .46012 .65673 .45209 .64919 Mtetra
.656 .75 .919 r
.45209 .64919 .46012 .65673 .47419 .65263 .4662 .64509 Mtetra
.655 .751 .92 r
.4662 .64509 .47419 .65263 .48833 .64855 .48038 .64102 Mtetra
.654 .751 .922 r
.48038 .64102 .48833 .64855 .50254 .64447 .49464 .63698 Mtetra
.654 .753 .923 r
.49464 .63698 .50254 .64447 .51682 .64042 .50897 .63289 Mtetra
.656 .754 .922 r
.50897 .63289 .51682 .64042 .53118 .63636 .52338 .62869 Mtetra
.657 .752 .92 r
.52338 .62869 .53118 .63636 .54561 .63225 .53787 .62446 Mtetra
.657 .75 .918 r
.53787 .62446 .54561 .63225 .56012 .62806 .55243 .62021 Mtetra
.657 .749 .918 r
.55243 .62021 .56012 .62806 .57471 .62383 .56706 .61594 Mtetra
.56706 .61594 .57471 .62383 .58937 .61959 .58178 .61167 Mtetra
.656 .749 .918 r
.58178 .61167 .58937 .61959 .60411 .61533 .59657 .60738 Mtetra
.656 .75 .919 r
.59657 .60738 .60411 .61533 .61893 .61106 .61144 .60308 Mtetra
.61144 .60308 .61893 .61106 .63383 .60676 .6264 .59876 Mtetra
.656 .75 .92 r
.6264 .59876 .63383 .60676 .64881 .60246 .64143 .59443 Mtetra
.656 .751 .92 r
.64143 .59443 .64881 .60246 .66387 .59813 .65654 .59006 Mtetra
.65654 .59006 .66387 .59813 .67901 .59379 .67173 .58566 Mtetra
.656 .75 .919 r
.67173 .58566 .67901 .59379 .69423 .58943 .68701 .58124 Mtetra
.68701 .58124 .69423 .58943 .70953 .58505 .70237 .5768 Mtetra
.656 .749 .919 r
.70237 .5768 .70953 .58505 .72492 .58066 .71782 .57235 Mtetra
.655 .749 .919 r
.71782 .57235 .72492 .58066 .74039 .57625 .73334 .56788 Mtetra
.73334 .56788 .74039 .57625 .75595 .57182 .74896 .56341 Mtetra
.74896 .56341 .75595 .57182 .77159 .56735 .76466 .55892 Mtetra
.76466 .55892 .77159 .56735 .78731 .5628 .78045 .5544 Mtetra
.655 .751 .921 r
.78045 .5544 .78731 .5628 .80312 .5582 .79632 .54984 Mtetra
.657 .754 .922 r
.79632 .54984 .80312 .5582 .81901 .55357 .81228 .54518 Mtetra
.658 .755 .922 r
.81228 .54518 .81901 .55357 .83499 .54898 .82832 .54046 Mtetra
.656 .752 .921 r
.82832 .54046 .83499 .54898 .85107 .54439 .84446 .53577 Mtetra
.655 .751 .92 r
.84446 .53577 .85107 .54439 .86724 .5398 .86068 .5311 Mtetra
.655 .749 .919 r
.86068 .5311 .86724 .5398 .88349 .53518 .87701 .52644 Mtetra
.654 .749 .92 r
.87701 .52644 .88349 .53518 .89983 .53046 .89342 .52175 Mtetra
.656 .752 .921 r
.89342 .52175 .89983 .53046 .91626 .52567 .90992 .51696 Mtetra
.657 .754 .921 r
.90992 .51696 .91626 .52567 .93279 .52091 .92651 .51209 Mtetra
.656 .752 .92 r
.92651 .51209 .93279 .52091 .94941 .51615 .9432 .50725 Mtetra
.655 .751 .92 r
.9432 .50725 .94941 .51615 .96613 .51141 .95998 .50242 Mtetra
.36056 .66591 .36894 .67324 .38262 .66927 .37428 .66193 Mtetra
.654 .751 .921 r
.37428 .66193 .38262 .66927 .39637 .66531 .38808 .65798 Mtetra
.655 .753 .922 r
.38808 .65798 .39637 .66531 .41019 .66138 .40194 .65398 Mtetra
.657 .753 .92 r
.40194 .65398 .41019 .66138 .42408 .65739 .41588 .64987 Mtetra
.657 .75 .919 r
.41588 .64987 .42408 .65739 .43805 .6533 .42989 .64574 Mtetra
.656 .75 .919 r
.42989 .64574 .43805 .6533 .45209 .64919 .44398 .64163 Mtetra
.654 .751 .92 r
.44398 .64163 .45209 .64919 .4662 .64509 .45813 .63756 Mtetra
.653 .752 .922 r
.45813 .63756 .4662 .64509 .48038 .64102 .47236 .6335 Mtetra
.655 .754 .922 r
.47236 .6335 .48038 .64102 .49464 .63698 .48667 .62935 Mtetra
.657 .753 .921 r
.48667 .62935 .49464 .63698 .50897 .63289 .50105 .62512 Mtetra
.658 .75 .918 r
.50105 .62512 .50897 .63289 .52338 .62869 .51551 .62086 Mtetra
.657 .749 .918 r
.51551 .62086 .52338 .62869 .53787 .62446 .53004 .61658 Mtetra
.53004 .61658 .53787 .62446 .55243 .62021 .54465 .61231 Mtetra
.656 .75 .919 r
.54465 .61231 .55243 .62021 .56706 .61594 .55934 .60805 Mtetra
.654 .75 .92 r
.55934 .60805 .56706 .61594 .58178 .61167 .57411 .60381 Mtetra
.654 .752 .922 r
.57411 .60381 .58178 .61167 .59657 .60738 .58896 .59955 Mtetra
.654 .754 .923 r
.58896 .59955 .59657 .60738 .61144 .60308 .60388 .59524 Mtetra
.655 .755 .924 r
.60388 .59524 .61144 .60308 .6264 .59876 .61889 .5909 Mtetra
.655 .756 .924 r
.61889 .5909 .6264 .59876 .64143 .59443 .63398 .58652 Mtetra
.63398 .58652 .64143 .59443 .65654 .59006 .64915 .58211 Mtetra
.656 .756 .924 r
.64915 .58211 .65654 .59006 .67173 .58566 .6644 .57767 Mtetra
.6644 .57767 .67173 .58566 .68701 .58124 .67973 .57318 Mtetra
.656 .756 .923 r
.67973 .57318 .68701 .58124 .70237 .5768 .69515 .56866 Mtetra
.657 .755 .922 r
.69515 .56866 .70237 .5768 .71782 .57235 .71065 .5641 Mtetra
.657 .753 .921 r
.71065 .5641 .71782 .57235 .73334 .56788 .72623 .55951 Mtetra
.656 .751 .92 r
.72623 .55951 .73334 .56788 .74896 .56341 .7419 .55494 Mtetra
.655 .749 .919 r
.7419 .55494 .74896 .56341 .76466 .55892 .75766 .55038 Mtetra
.75766 .55038 .76466 .55892 .78045 .5544 .77351 .54582 Mtetra
.654 .749 .919 r
.77351 .54582 .78045 .5544 .79632 .54984 .78945 .54124 Mtetra
.655 .749 .919 r
.78945 .54124 .79632 .54984 .81228 .54518 .80548 .53664 Mtetra
.656 .753 .921 r
.80548 .53664 .81228 .54518 .82832 .54046 .82159 .53194 Mtetra
.658 .755 .922 r
.82159 .53194 .82832 .54046 .84446 .53577 .83778 .52714 Mtetra
.657 .753 .921 r
.83778 .52714 .84446 .53577 .86068 .5311 .85407 .52235 Mtetra
.655 .751 .92 r
.85407 .52235 .86068 .5311 .87701 .52644 .87046 .5176 Mtetra
.654 .749 .92 r
.87046 .5176 .87701 .52644 .89342 .52175 .88694 .51287 Mtetra
.88694 .51287 .89342 .52175 .90992 .51696 .90352 .50811 Mtetra
.657 .753 .921 r
.90352 .50811 .90992 .51696 .92651 .51209 .92018 .50323 Mtetra
.657 .754 .921 r
.92018 .50323 .92651 .51209 .9432 .50725 .93693 .49828 Mtetra
.656 .752 .92 r
.93693 .49828 .9432 .50725 .95998 .50242 .95378 .49337 Mtetra
.654 .751 .921 r
.3521 .65853 .36056 .66591 .37428 .66193 .36586 .65455 Mtetra
.654 .752 .922 r
.36586 .65455 .37428 .66193 .38808 .65798 .3797 .65056 Mtetra
.657 .753 .92 r
.3797 .65056 .38808 .65798 .40194 .65398 .39361 .64643 Mtetra
.658 .751 .919 r
.39361 .64643 .40194 .65398 .41588 .64987 .4076 .64228 Mtetra
.656 .75 .919 r
.4076 .64228 .41588 .64987 .42989 .64574 .42166 .63814 Mtetra
.654 .751 .921 r
.42166 .63814 .42989 .64574 .44398 .64163 .43578 .63406 Mtetra
.653 .752 .922 r
.43578 .63406 .44398 .64163 .45813 .63756 .44999 .62999 Mtetra
.656 .754 .922 r
.44999 .62999 .45813 .63756 .47236 .6335 .46427 .6258 Mtetra
.658 .752 .92 r
.46427 .6258 .47236 .6335 .48667 .62935 .47862 .62154 Mtetra
.658 .75 .918 r
.47862 .62154 .48667 .62935 .50105 .62512 .49305 .61725 Mtetra
.657 .749 .918 r
.49305 .61725 .50105 .62512 .51551 .62086 .50756 .61297 Mtetra
.655 .75 .919 r
.50756 .61297 .51551 .62086 .53004 .61658 .52214 .60872 Mtetra
.653 .751 .921 r
.52214 .60872 .53004 .61658 .54465 .61231 .53681 .60451 Mtetra
.653 .753 .923 r
.53681 .60451 .54465 .61231 .55934 .60805 .55155 .60027 Mtetra
.654 .755 .924 r
.55155 .60027 .55934 .60805 .57411 .60381 .56637 .59598 Mtetra
.656 .755 .923 r
.56637 .59598 .57411 .60381 .58896 .59955 .58127 .5916 Mtetra
.656 .754 .922 r
.58127 .5916 .58896 .59955 .60388 .59524 .59625 .5872 Mtetra
.656 .752 .921 r
.59625 .5872 .60388 .59524 .61889 .5909 .61131 .58278 Mtetra
.656 .751 .92 r
.61131 .58278 .61889 .5909 .63398 .58652 .62645 .57834 Mtetra
.62645 .57834 .63398 .58652 .64915 .58211 .64167 .57389 Mtetra
.64167 .57389 .64915 .58211 .6644 .57767 .65698 .56941 Mtetra
.655 .751 .92 r
.65698 .56941 .6644 .57767 .67973 .57318 .67237 .56492 Mtetra
.655 .752 .921 r
.67237 .56492 .67973 .57318 .69515 .56866 .68785 .56041 Mtetra
.655 .754 .922 r
.68785 .56041 .69515 .56866 .71065 .5641 .70341 .55587 Mtetra
.657 .756 .923 r
.70341 .55587 .71065 .5641 .72623 .55951 .71906 .55125 Mtetra
.71906 .55125 .72623 .55951 .7419 .55494 .73478 .54657 Mtetra
.658 .755 .922 r
.73478 .54657 .7419 .55494 .75766 .55038 .7506 .54185 Mtetra
.656 .752 .92 r
.7506 .54185 .75766 .55038 .77351 .54582 .7665 .53717 Mtetra
.655 .749 .919 r
.7665 .53717 .77351 .54582 .78945 .54124 .7825 .53253 Mtetra
.654 .749 .919 r
.7825 .53253 .78945 .54124 .80548 .53664 .79859 .52789 Mtetra
.79859 .52789 .80548 .53664 .82159 .53194 .81478 .52322 Mtetra
.656 .751 .92 r
.81478 .52322 .82159 .53194 .83778 .52714 .83104 .51847 Mtetra
.658 .755 .921 r
.83104 .51847 .83778 .52714 .85407 .52235 .84739 .51359 Mtetra
.657 .753 .921 r
.84739 .51359 .85407 .52235 .87046 .5176 .86384 .50872 Mtetra
.655 .751 .92 r
.86384 .50872 .87046 .5176 .88694 .51287 .88039 .50389 Mtetra
.654 .749 .92 r
.88039 .50389 .88694 .51287 .90352 .50811 .89703 .49909 Mtetra
.654 .75 .92 r
.89703 .49909 .90352 .50811 .92018 .50323 .91377 .49425 Mtetra
.657 .753 .921 r
.91377 .49425 .92018 .50323 .93693 .49828 .93059 .48926 Mtetra
.93059 .48926 .93693 .49828 .95378 .49337 .94751 .48425 Mtetra
.654 .752 .922 r
.34355 .6511 .3521 .65853 .36586 .65455 .35736 .6471 Mtetra
.656 .753 .921 r
.35736 .6471 .36586 .65455 .3797 .65056 .37125 .64299 Mtetra
.658 .751 .919 r
.37125 .64299 .3797 .65056 .39361 .64643 .38521 .6388 Mtetra
.657 .75 .919 r
.38521 .6388 .39361 .64643 .4076 .64228 .39924 .63465 Mtetra
.654 .751 .92 r
.39924 .63465 .4076 .64228 .42166 .63814 .41334 .63054 Mtetra
.653 .752 .922 r
.41334 .63054 .42166 .63814 .43578 .63406 .42751 .62646 Mtetra
.656 .754 .922 r
.42751 .62646 .43578 .63406 .44999 .62999 .44176 .62225 Mtetra
.658 .752 .919 r
.44176 .62225 .44999 .62999 .46427 .6258 .45609 .61795 Mtetra
.658 .75 .918 r
.45609 .61795 .46427 .6258 .47862 .62154 .4705 .61365 Mtetra
.657 .75 .918 r
.4705 .61365 .47862 .62154 .49305 .61725 .48498 .60935 Mtetra
.654 .75 .92 r
.48498 .60935 .49305 .61725 .50756 .61297 .49953 .60515 Mtetra
.653 .753 .923 r
.49953 .60515 .50756 .61297 .52214 .60872 .51417 .60094 Mtetra
.654 .755 .924 r
.51417 .60094 .52214 .60872 .53681 .60451 .52888 .59664 Mtetra
.656 .754 .922 r
.52888 .59664 .53681 .60451 .55155 .60027 .54367 .59225 Mtetra
.657 .752 .92 r
.54367 .59225 .55155 .60027 .56637 .59598 .55854 .58783 Mtetra
.657 .75 .918 r
.55854 .58783 .56637 .59598 .58127 .5916 .5735 .58338 Mtetra
.657 .749 .918 r
.5735 .58338 .58127 .5916 .59625 .5872 .58853 .57891 Mtetra
.657 .748 .917 r
.58853 .57891 .59625 .5872 .61131 .58278 .60364 .57443 Mtetra
.656 .748 .917 r
.60364 .57443 .61131 .58278 .62645 .57834 .61884 .56994 Mtetra
.61884 .56994 .62645 .57834 .64167 .57389 .63412 .56544 Mtetra
.656 .747 .917 r
.63412 .56544 .64167 .57389 .65698 .56941 .64948 .56092 Mtetra
.655 .747 .918 r
.64948 .56092 .65698 .56941 .67237 .56492 .66493 .5564 Mtetra
.655 .748 .918 r
.66493 .5564 .67237 .56492 .68785 .56041 .68047 .55187 Mtetra
.655 .748 .919 r
.68047 .55187 .68785 .56041 .70341 .55587 .69609 .54731 Mtetra
.655 .749 .919 r
.69609 .54731 .70341 .55587 .71906 .55125 .7118 .54273 Mtetra
.655 .751 .921 r
.7118 .54273 .71906 .55125 .73478 .54657 .72759 .53811 Mtetra
.657 .755 .922 r
.72759 .53811 .73478 .54657 .7506 .54185 .74347 .5334 Mtetra
.658 .756 .922 r
.74347 .5334 .7506 .54185 .7665 .53717 .75944 .52859 Mtetra
.658 .754 .921 r
.75944 .52859 .7665 .53717 .7825 .53253 .77549 .52378 Mtetra
.655 .75 .92 r
.77549 .52378 .7825 .53253 .79859 .52789 .79164 .51904 Mtetra
.654 .749 .919 r
.79164 .51904 .79859 .52789 .81478 .52322 .80789 .51433 Mtetra
.80789 .51433 .81478 .52322 .83104 .51847 .82423 .50959 Mtetra
.655 .751 .92 r
.82423 .50959 .83104 .51847 .84739 .51359 .84065 .50477 Mtetra
.658 .754 .921 r
.84065 .50477 .84739 .51359 .86384 .50872 .85716 .49981 Mtetra
.657 .753 .921 r
.85716 .49981 .86384 .50872 .88039 .50389 .87377 .49486 Mtetra
.655 .751 .92 r
.87377 .49486 .88039 .50389 .89703 .49909 .89048 .48997 Mtetra
.654 .749 .92 r
.89048 .48997 .89703 .49909 .91377 .49425 .90729 .48509 Mtetra
.655 .75 .92 r
.90729 .48509 .91377 .49425 .93059 .48926 .92419 .48015 Mtetra
.657 .753 .921 r
.92419 .48015 .93059 .48926 .94751 .48425 .94118 .47506 Mtetra
.655 .752 .921 r
.33493 .64362 .34355 .6511 .35736 .6471 .34878 .63953 Mtetra
.658 .752 .919 r
.34878 .63953 .35736 .6471 .37125 .64299 .36271 .63533 Mtetra
.657 .75 .919 r
.36271 .63533 .37125 .64299 .38521 .6388 .37672 .63114 Mtetra
.655 .751 .92 r
.37672 .63114 .38521 .6388 .39924 .63465 .39079 .62699 Mtetra
.653 .751 .922 r
.39079 .62699 .39924 .63465 .41334 .63054 .40494 .62289 Mtetra
.656 .753 .922 r
.40494 .62289 .41334 .63054 .42751 .62646 .41916 .61868 Mtetra
.658 .752 .919 r
.41916 .61868 .42751 .62646 .44176 .62225 .43346 .61436 Mtetra
.658 .75 .918 r
.43346 .61436 .44176 .62225 .45609 .61795 .44784 .61003 Mtetra
.656 .75 .919 r
.44784 .61003 .45609 .61795 .4705 .61365 .46229 .60573 Mtetra
.653 .75 .921 r
.46229 .60573 .4705 .61365 .48498 .60935 .47682 .60154 Mtetra
.653 .754 .924 r
.47682 .60154 .48498 .60935 .49953 .60515 .49142 .59731 Mtetra
.656 .755 .923 r
.49142 .59731 .49953 .60515 .51417 .60094 .50611 .59293 Mtetra
.657 .752 .92 r
.50611 .59293 .51417 .60094 .52888 .59664 .52087 .58849 Mtetra
.658 .75 .918 r
.52087 .58849 .52888 .59664 .54367 .59225 .53572 .58402 Mtetra
.658 .749 .917 r
.53572 .58402 .54367 .59225 .55854 .58783 .55064 .57952 Mtetra
.657 .748 .917 r
.55064 .57952 .55854 .58783 .5735 .58338 .56565 .57503 Mtetra
.656 .748 .917 r
.56565 .57503 .5735 .58338 .58853 .57891 .58073 .57055 Mtetra
.655 .748 .918 r
.58073 .57055 .58853 .57891 .60364 .57443 .5959 .56607 Mtetra
.655 .749 .919 r
.5959 .56607 .60364 .57443 .61884 .56994 .61116 .56157 Mtetra
.656 .75 .919 r
.61116 .56157 .61884 .56994 .63412 .56544 .62649 .55702 Mtetra
.656 .751 .919 r
.62649 .55702 .63412 .56544 .64948 .56092 .64191 .55243 Mtetra
.656 .75 .919 r
.64191 .55243 .64948 .56092 .66493 .5564 .65742 .54781 Mtetra
.656 .748 .918 r
.65742 .54781 .66493 .5564 .68047 .55187 .67301 .5432 Mtetra
.655 .747 .918 r
.67301 .5432 .68047 .55187 .69609 .54731 .68869 .5386 Mtetra
.654 .747 .918 r
.68869 .5386 .69609 .54731 .7118 .54273 .70446 .53399 Mtetra
.70446 .53399 .7118 .54273 .72759 .53811 .72032 .52937 Mtetra
.654 .749 .919 r
.72032 .52937 .72759 .53811 .74347 .5334 .73626 .52471 Mtetra
.655 .751 .921 r
.73626 .52471 .74347 .5334 .75944 .52859 .7523 .51998 Mtetra
.658 .756 .922 r
.7523 .51998 .75944 .52859 .77549 .52378 .76841 .5151 Mtetra
.659 .756 .922 r
.76841 .5151 .77549 .52378 .79164 .51904 .78462 .51017 Mtetra
.655 .751 .92 r
.78462 .51017 .79164 .51904 .80789 .51433 .80093 .50535 Mtetra
.654 .749 .919 r
.80093 .50535 .80789 .51433 .82423 .50959 .81733 .50056 Mtetra
.81733 .50056 .82423 .50959 .84065 .50477 .83383 .49575 Mtetra
.656 .751 .92 r
.83383 .49575 .84065 .50477 .85716 .49981 .85041 .49084 Mtetra
.658 .754 .921 r
.85041 .49084 .85716 .49981 .87377 .49486 .86708 .48579 Mtetra
.656 .752 .921 r
.86708 .48579 .87377 .49486 .89048 .48997 .88386 .48078 Mtetra
.655 .75 .92 r
.88386 .48078 .89048 .48997 .90729 .48509 .90074 .47583 Mtetra
.654 .749 .92 r
.90074 .47583 .90729 .48509 .92419 .48015 .91772 .47087 Mtetra
.656 .751 .92 r
.91772 .47087 .92419 .48015 .94118 .47506 .93478 .4658 Mtetra
.657 .753 .92 r
.32622 .63605 .33493 .64362 .34878 .63953 .34012 .63185 Mtetra
.658 .751 .919 r
.34012 .63185 .34878 .63953 .36271 .63533 .3541 .62761 Mtetra
.656 .751 .92 r
.3541 .62761 .36271 .63533 .37672 .63114 .36814 .62342 Mtetra
.653 .751 .921 r
.36814 .62342 .37672 .63114 .39079 .62699 .38226 .6193 Mtetra
.654 .753 .922 r
.38226 .6193 .39079 .62699 .40494 .62289 .39645 .61511 Mtetra
.658 .752 .92 r
.39645 .61511 .40494 .62289 .41916 .61868 .41073 .61077 Mtetra
.658 .75 .918 r
.41073 .61077 .41916 .61868 .43346 .61436 .42508 .60641 Mtetra
.656 .75 .919 r
.42508 .60641 .43346 .61436 .44784 .61003 .4395 .60209 Mtetra
.652 .75 .921 r
.4395 .60209 .44784 .61003 .46229 .60573 .454 .59789 Mtetra
.653 .754 .924 r
.454 .59789 .46229 .60573 .47682 .60154 .46858 .59363 Mtetra
.657 .754 .922 r
.46858 .59363 .47682 .60154 .49142 .59731 .48324 .58921 Mtetra
.658 .751 .918 r
.48324 .58921 .49142 .59731 .50611 .59293 .49797 .58472 Mtetra
.659 .749 .917 r
.49797 .58472 .50611 .59293 .52087 .58849 .51279 .58021 Mtetra
.657 .748 .917 r
.51279 .58021 .52087 .58849 .53572 .58402 .52769 .57571 Mtetra
.654 .748 .919 r
.52769 .57571 .53572 .58402 .55064 .57952 .54266 .5713 Mtetra
.653 .751 .921 r
.54266 .5713 .55064 .57952 .56565 .57503 .55772 .5669 Mtetra
.653 .754 .924 r
.55772 .5669 .56565 .57503 .58073 .57055 .57287 .56247 Mtetra
.654 .757 .925 r
.57287 .56247 .58073 .57055 .5959 .56607 .58809 .55797 Mtetra
.655 .758 .926 r
.58809 .55797 .5959 .56607 .61116 .56157 .6034 .55343 Mtetra
.6034 .55343 .61116 .56157 .62649 .55702 .6188 .54884 Mtetra
.656 .758 .925 r
.6188 .54884 .62649 .55702 .64191 .55243 .63428 .5442 Mtetra
.657 .759 .925 r
.63428 .5442 .64191 .55243 .65742 .54781 .64984 .5395 Mtetra
.657 .758 .924 r
.64984 .5395 .65742 .54781 .67301 .5432 .66549 .53475 Mtetra
.658 .756 .922 r
.66549 .53475 .67301 .5432 .68869 .5386 .68122 .52995 Mtetra
.657 .752 .92 r
.68122 .52995 .68869 .5386 .70446 .53399 .69704 .52517 Mtetra
.655 .748 .918 r
.69704 .52517 .70446 .53399 .72032 .52937 .71296 .52047 Mtetra
.653 .747 .918 r
.71296 .52047 .72032 .52937 .73626 .52471 .72897 .5158 Mtetra
.654 .748 .919 r
.72897 .5158 .73626 .52471 .7523 .51998 .74507 .51108 Mtetra
.655 .75 .92 r
.74507 .51108 .7523 .51998 .76841 .5151 .76126 .5063 Mtetra
.658 .755 .921 r
.76126 .5063 .76841 .5151 .78462 .51017 .77754 .50136 Mtetra
.659 .756 .922 r
.77754 .50136 .78462 .51017 .80093 .50535 .7939 .49634 Mtetra
.655 .751 .92 r
.7939 .49634 .80093 .50535 .81733 .50056 .81036 .49145 Mtetra
.654 .749 .92 r
.81036 .49145 .81733 .50056 .83383 .49575 .82693 .48659 Mtetra
.82693 .48659 .83383 .49575 .85041 .49084 .84359 .4817 Mtetra
.657 .752 .92 r
.84359 .4817 .85041 .49084 .86708 .48579 .86034 .47666 Mtetra
.658 .754 .921 r
.86034 .47666 .86708 .48579 .88386 .48078 .87717 .47153 Mtetra
.656 .751 .92 r
.87717 .47153 .88386 .48078 .90074 .47583 .89412 .46648 Mtetra
.654 .75 .92 r
.89412 .46648 .90074 .47583 .91772 .47087 .91116 .46146 Mtetra
.91116 .46146 .91772 .47087 .93478 .4658 .92831 .45641 Mtetra
.658 .751 .919 r
.31743 .62836 .32622 .63605 .34012 .63185 .33137 .62409 Mtetra
.657 .751 .919 r
.33137 .62409 .34012 .63185 .3541 .62761 .34539 .61985 Mtetra
.654 .751 .921 r
.34539 .61985 .3541 .62761 .36814 .62342 .35948 .61568 Mtetra
.653 .752 .922 r
.35948 .61568 .36814 .62342 .38226 .6193 .37365 .61152 Mtetra
.657 .753 .921 r
.37365 .61152 .38226 .6193 .39645 .61511 .38789 .60718 Mtetra
.658 .751 .918 r
.38789 .60718 .39645 .61511 .41073 .61077 .40221 .60279 Mtetra
.657 .75 .919 r
.40221 .60279 .41073 .61077 .42508 .60641 .41661 .59842 Mtetra
.652 .75 .921 r
.41661 .59842 .42508 .60641 .4395 .60209 .43108 .5942 Mtetra
.653 .753 .924 r
.43108 .5942 .4395 .60209 .454 .59789 .44563 .58993 Mtetra
.657 .754 .921 r
.44563 .58993 .454 .59789 .46858 .59363 .46026 .58548 Mtetra
.659 .751 .918 r
.46026 .58548 .46858 .59363 .48324 .58921 .47497 .58096 Mtetra
.659 .749 .917 r
.47497 .58096 .48324 .58921 .49797 .58472 .48976 .57641 Mtetra
.656 .748 .918 r
.48976 .57641 .49797 .58472 .51279 .58021 .50462 .57196 Mtetra
.652 .75 .921 r
.50462 .57196 .51279 .58021 .52769 .57571 .51957 .56762 Mtetra
.652 .755 .925 r
.51957 .56762 .52769 .57571 .54266 .5713 .5346 .56324 Mtetra
.654 .757 .925 r
.5346 .56324 .54266 .5713 .55772 .5669 .54972 .55873 Mtetra
.656 .756 .924 r
.54972 .55873 .55772 .5669 .57287 .56247 .56492 .55414 Mtetra
.656 .754 .922 r
.56492 .55414 .57287 .56247 .58809 .55797 .5802 .54953 Mtetra
.656 .752 .92 r
.5802 .54953 .58809 .55797 .6034 .55343 .59556 .5449 Mtetra
.656 .751 .92 r
.59556 .5449 .6034 .55343 .6188 .54884 .61101 .54026 Mtetra
.655 .751 .92 r
.61101 .54026 .6188 .54884 .63428 .5442 .62655 .53561 Mtetra
.655 .751 .921 r
.62655 .53561 .63428 .5442 .64984 .5395 .64218 .53094 Mtetra
.655 .753 .922 r
.64218 .53094 .64984 .5395 .66549 .53475 .65789 .52624 Mtetra
.656 .756 .923 r
.65789 .52624 .66549 .53475 .68122 .52995 .67369 .52147 Mtetra
.659 .759 .924 r
.67369 .52147 .68122 .52995 .69704 .52517 .68957 .51657 Mtetra
.659 .757 .922 r
.68957 .51657 .69704 .52517 .71296 .52047 .70554 .51162 Mtetra
.656 .751 .92 r
.70554 .51162 .71296 .52047 .72897 .5158 .7216 .50678 Mtetra
.653 .747 .919 r
.7216 .50678 .72897 .5158 .74507 .51108 .73777 .50203 Mtetra
.653 .748 .919 r
.73777 .50203 .74507 .51108 .76126 .5063 .75403 .49726 Mtetra
.654 .749 .92 r
.75403 .49726 .76126 .5063 .77754 .50136 .77038 .49241 Mtetra
.658 .755 .921 r
.77038 .49241 .77754 .50136 .7939 .49634 .7868 .48737 Mtetra
.659 .755 .921 r
.7868 .48737 .7939 .49634 .81036 .49145 .80333 .48228 Mtetra
.655 .75 .92 r
.80333 .48228 .81036 .49145 .82693 .48659 .81995 .47733 Mtetra
.654 .749 .92 r
.81995 .47733 .82693 .48659 .84359 .4817 .83669 .4724 Mtetra
.83669 .4724 .84359 .4817 .86034 .47666 .85351 .46741 Mtetra
.658 .754 .921 r
.85351 .46741 .86034 .47666 .87717 .47153 .87042 .46223 Mtetra
.657 .753 .921 r
.87042 .46223 .87717 .47153 .89412 .46648 .88743 .45706 Mtetra
.655 .751 .92 r
.88743 .45706 .89412 .46648 .91116 .46146 .90454 .45195 Mtetra
.654 .749 .92 r
.90454 .45195 .91116 .46146 .92831 .45641 .92177 .44687 Mtetra
.658 .751 .919 r
.30855 .62057 .31743 .62836 .33137 .62409 .32254 .61628 Mtetra
.656 .751 .92 r
.32254 .61628 .33137 .62409 .34539 .61985 .33661 .61203 Mtetra
.653 .751 .922 r
.33661 .61203 .34539 .61985 .35948 .61568 .35074 .60787 Mtetra
.656 .753 .921 r
.35074 .60787 .35948 .61568 .37365 .61152 .36495 .60357 Mtetra
.658 .751 .919 r
.36495 .60357 .37365 .61152 .38789 .60718 .37925 .59916 Mtetra
.658 .75 .918 r
.37925 .59916 .38789 .60718 .40221 .60279 .39361 .59475 Mtetra
.654 .75 .92 r
.39361 .59475 .40221 .60279 .41661 .59842 .40805 .59046 Mtetra
.652 .752 .923 r
.40805 .59046 .41661 .59842 .43108 .5942 .42257 .58622 Mtetra
.657 .754 .922 r
.42257 .58622 .43108 .5942 .44563 .58993 .43717 .58175 Mtetra
.659 .751 .918 r
.43717 .58175 .44563 .58993 .46026 .58548 .45186 .5772 Mtetra
.659 .75 .917 r
.45186 .5772 .46026 .58548 .47497 .58096 .46662 .57263 Mtetra
.654 .748 .919 r
.46662 .57263 .47497 .58096 .48976 .57641 .48145 .56821 Mtetra
.651 .751 .923 r
.48145 .56821 .48976 .57641 .50462 .57196 .49637 .56389 Mtetra
.653 .756 .925 r
.49637 .56389 .50462 .57196 .51957 .56762 .51138 .55943 Mtetra
.657 .756 .923 r
.51138 .55943 .51957 .56762 .5346 .56324 .52646 .55482 Mtetra
.658 .752 .919 r
.52646 .55482 .5346 .56324 .54972 .55873 .54163 .55017 Mtetra
.659 .749 .917 r
.54163 .55017 .54972 .55873 .56492 .55414 .55688 .54545 Mtetra
.658 .747 .916 r
.55688 .54545 .56492 .55414 .5802 .54953 .57222 .54074 Mtetra
.657 .746 .915 r
.57222 .54074 .5802 .54953 .59556 .5449 .58764 .53604 Mtetra
.656 .745 .915 r
.58764 .53604 .59556 .5449 .61101 .54026 .60315 .53135 Mtetra
.655 .744 .915 r
.60315 .53135 .61101 .54026 .62655 .53561 .61874 .52667 Mtetra
.654 .745 .916 r
.61874 .52667 .62655 .53561 .64218 .53094 .63442 .52201 Mtetra
.653 .746 .917 r
.63442 .52201 .64218 .53094 .65789 .52624 .6502 .51735 Mtetra
.654 .748 .919 r
.6502 .51735 .65789 .52624 .67369 .52147 .66606 .51263 Mtetra
.655 .751 .92 r
.66606 .51263 .67369 .52147 .68957 .51657 .68201 .50785 Mtetra
.658 .756 .923 r
.68201 .50785 .68957 .51657 .70554 .51162 .69805 .50292 Mtetra
.66 .759 .923 r
.69805 .50292 .70554 .51162 .7216 .50678 .71417 .49786 Mtetra
.658 .754 .921 r
.71417 .49786 .7216 .50678 .73777 .50203 .73039 .49288 Mtetra
.653 .748 .919 r
.73039 .49288 .73777 .50203 .75403 .49726 .74671 .48806 Mtetra
.74671 .48806 .75403 .49726 .77038 .49241 .76313 .48322 Mtetra
.655 .75 .92 r
.76313 .48322 .77038 .49241 .7868 .48737 .77964 .47829 Mtetra
.659 .755 .921 r
.77964 .47829 .7868 .48737 .80333 .48228 .79622 .47312 Mtetra
.658 .754 .921 r
.79622 .47312 .80333 .48228 .81995 .47733 .81291 .468 Mtetra
.654 .75 .92 r
.81291 .468 .81995 .47733 .83669 .4724 .82971 .46299 Mtetra
.653 .749 .92 r
.82971 .46299 .83669 .4724 .85351 .46741 .84661 .45798 Mtetra
.656 .751 .92 r
.84661 .45798 .85351 .46741 .87042 .46223 .86359 .45284 Mtetra
.659 .754 .921 r
.86359 .45284 .87042 .46223 .88743 .45706 .88067 .44756 Mtetra
.656 .752 .92 r
.88067 .44756 .88743 .45706 .90454 .45195 .89785 .44236 Mtetra
.654 .75 .92 r
.89785 .44236 .90454 .45195 .92177 .44687 .91515 .4372 Mtetra
.657 .751 .919 r
.29959 .61271 .30855 .62057 .32254 .61628 .31362 .6084 Mtetra
.654 .751 .921 r
.31362 .6084 .32254 .61628 .33661 .61203 .32773 .60417 Mtetra
.653 .752 .922 r
.32773 .60417 .33661 .61203 .35074 .60787 .34191 .59995 Mtetra
.658 .753 .92 r
.34191 .59995 .35074 .60787 .36495 .60357 .35617 .59554 Mtetra
.658 .751 .918 r
.35617 .59554 .36495 .60357 .37925 .59916 .37051 .59108 Mtetra
.656 .75 .919 r
.37051 .59108 .37925 .59916 .39361 .59475 .38493 .58669 Mtetra
.651 .751 .922 r
.38493 .58669 .39361 .59475 .40805 .59046 .39941 .58244 Mtetra
.655 .754 .922 r
.39941 .58244 .40805 .59046 .42257 .58622 .41398 .57802 Mtetra
.659 .752 .919 r
.41398 .57802 .42257 .58622 .43717 .58175 .42864 .57345 Mtetra
.659 .75 .917 r
.42864 .57345 .43717 .58175 .45186 .5772 .44337 .56884 Mtetra
.654 .748 .919 r
.44337 .56884 .45186 .5772 .46662 .57263 .45818 .5644 Mtetra
.65 .751 .924 r
.45818 .5644 .46662 .57263 .48145 .56821 .47307 .56007 Mtetra
.654 .756 .925 r
.47307 .56007 .48145 .56821 .49637 .56389 .48804 .55556 Mtetra
.658 .754 .921 r
.48804 .55556 .49637 .56389 .51138 .55943 .5031 .55089 Mtetra
.66 .75 .917 r
.5031 .55089 .51138 .55943 .52646 .55482 .51824 .54612 Mtetra
.66 .747 .915 r
.51824 .54612 .52646 .55482 .54163 .55017 .53346 .54134 Mtetra
.658 .745 .914 r
.53346 .54134 .54163 .55017 .55688 .54545 .54877 .53662 Mtetra
.655 .745 .916 r
.54877 .53662 .55688 .54545 .57222 .54074 .56416 .53197 Mtetra
.655 .748 .918 r
.56416 .53197 .57222 .54074 .58764 .53604 .57964 .52732 Mtetra
.656 .75 .919 r
.57964 .52732 .58764 .53604 .60315 .53135 .5952 .52258 Mtetra
.657 .751 .919 r
.5952 .52258 .60315 .53135 .61874 .52667 .61085 .51776 Mtetra
.657 .749 .917 r
.61085 .51776 .61874 .52667 .63442 .52201 .62659 .51293 Mtetra
.654 .745 .916 r
.62659 .51293 .63442 .52201 .6502 .51735 .64242 .50818 Mtetra
.652 .743 .916 r
.64242 .50818 .6502 .51735 .66606 .51263 .65835 .50349 Mtetra
.652 .745 .918 r
.65835 .50349 .66606 .51263 .68201 .50785 .67437 .49878 Mtetra
.654 .748 .919 r
.67437 .49878 .68201 .50785 .69805 .50292 .69047 .49397 Mtetra
.657 .753 .921 r
.69047 .49397 .69805 .50292 .71417 .49786 .70667 .489 Mtetra
.661 .758 .922 r
.70667 .489 .71417 .49786 .73039 .49288 .72294 .48383 Mtetra
.657 .754 .921 r
.72294 .48383 .73039 .49288 .74671 .48806 .73932 .47878 Mtetra
.653 .748 .919 r
.73932 .47878 .74671 .48806 .76313 .48322 .7558 .4739 Mtetra
.653 .748 .92 r
.7558 .4739 .76313 .48322 .77964 .47829 .77238 .46897 Mtetra
.656 .751 .92 r
.77238 .46897 .77964 .47829 .79622 .47312 .78904 .46389 Mtetra
.66 .755 .921 r
.78904 .46389 .79622 .47312 .81291 .468 .80579 .45862 Mtetra
.656 .752 .921 r
.80579 .45862 .81291 .468 .82971 .46299 .82265 .45349 Mtetra
.653 .749 .92 r
.82265 .45349 .82971 .46299 .84661 .45798 .83962 .44843 Mtetra
.654 .749 .92 r
.83962 .44843 .84661 .45798 .86359 .45284 .85669 .44331 Mtetra
.658 .753 .92 r
.85669 .44331 .86359 .45284 .88067 .44756 .87384 .438 Mtetra
.657 .753 .921 r
.87384 .438 .88067 .44756 .89785 .44236 .89109 .43268 Mtetra
.655 .751 .92 r
.89109 .43268 .89785 .44236 .91515 .4372 .90846 .42744 Mtetra
.656 .751 .92 r
.29054 .60479 .29959 .61271 .31362 .6084 .30461 .60046 Mtetra
.653 .751 .922 r
.30461 .60046 .31362 .6084 .32773 .60417 .31876 .59623 Mtetra
.655 .752 .921 r
.31876 .59623 .32773 .60417 .34191 .59995 .33299 .5919 Mtetra
.659 .752 .919 r
.33299 .5919 .34191 .59995 .35617 .59554 .3473 .58742 Mtetra
.658 .751 .919 r
.3473 .58742 .35617 .59554 .37051 .59108 .36169 .58294 Mtetra
.653 .75 .921 r
.36169 .58294 .37051 .59108 .38493 .58669 .37615 .57862 Mtetra
.652 .753 .923 r
.37615 .57862 .38493 .58669 .39941 .58244 .39069 .57428 Mtetra
.658 .753 .92 r
.39069 .57428 .39941 .58244 .41398 .57802 .40531 .56971 Mtetra
.66 .751 .918 r
.40531 .56971 .41398 .57802 .42864 .57345 .42001 .56506 Mtetra
.656 .749 .918 r
.42001 .56506 .42864 .57345 .44337 .56884 .4348 .56052 Mtetra
.649 .75 .923 r
.4348 .56052 .44337 .56884 .45818 .5644 .44965 .5562 Mtetra
.654 .755 .924 r
.44965 .5562 .45818 .5644 .47307 .56007 .4646 .55169 Mtetra
.659 .753 .92 r
.4646 .55169 .47307 .56007 .48804 .55556 .47962 .54698 Mtetra
.662 .751 .916 r
.47962 .54698 .48804 .55556 .5031 .55089 .49474 .54213 Mtetra
.66 .747 .914 r
.49474 .54213 .5031 .55089 .51824 .54612 .50993 .53733 Mtetra
.652 .745 .918 r
.50993 .53733 .51824 .54612 .53346 .54134 .52521 .53281 Mtetra
.65 .752 .924 r
.52521 .53281 .53346 .54134 .54877 .53662 .54057 .52833 Mtetra
.65 .759 .929 r
.54057 .52833 .54877 .53662 .56416 .53197 .55602 .52376 Mtetra
.652 .763 .93 r
.55602 .52376 .56416 .53197 .57964 .52732 .57156 .51909 Mtetra
.655 .764 .93 r
.57156 .51909 .57964 .52732 .5952 .52258 .58719 .5143 Mtetra
.657 .765 .929 r
.58719 .5143 .5952 .52258 .61085 .51776 .6029 .50941 Mtetra
.659 .765 .928 r
.6029 .50941 .61085 .51776 .62659 .51293 .6187 .5044 Mtetra
.661 .762 .925 r
.6187 .5044 .62659 .51293 .64242 .50818 .63458 .4993 Mtetra
.66 .755 .92 r
.63458 .4993 .64242 .50818 .65835 .50349 .65055 .49425 Mtetra
.653 .745 .917 r
.65055 .49425 .65835 .50349 .67437 .49878 .66663 .48947 Mtetra
.65 .744 .918 r
.66663 .48947 .67437 .49878 .69047 .49397 .68281 .48474 Mtetra
.653 .748 .919 r
.68281 .48474 .69047 .49397 .70667 .489 .69907 .47987 Mtetra
.657 .753 .92 r
.69907 .47987 .70667 .489 .72294 .48383 .71542 .47479 Mtetra
.661 .758 .922 r
.71542 .47479 .72294 .48383 .73932 .47878 .73185 .46952 Mtetra
.655 .752 .921 r
.73185 .46952 .73932 .47878 .7558 .4739 .74839 .46447 Mtetra
.652 .748 .92 r
.74839 .46447 .7558 .4739 .77238 .46897 .76504 .45952 Mtetra
.654 .749 .92 r
.76504 .45952 .77238 .46897 .78904 .46389 .78178 .45449 Mtetra
.659 .753 .92 r
.78178 .45449 .78904 .46389 .80579 .45862 .79861 .44921 Mtetra
.658 .754 .921 r
.79861 .44921 .80579 .45862 .82265 .45349 .81553 .44392 Mtetra
.654 .75 .92 r
.81553 .44392 .82265 .45349 .83962 .44843 .83257 .43877 Mtetra
.653 .749 .92 r
.83257 .43877 .83962 .44843 .85669 .44331 .84971 .43363 Mtetra
.656 .751 .92 r
.84971 .43363 .85669 .44331 .87384 .438 .86694 .42833 Mtetra
.658 .754 .92 r
.86694 .42833 .87384 .438 .89109 .43268 .88426 .4229 Mtetra
.655 .751 .92 r
.88426 .4229 .89109 .43268 .90846 .42744 .9017 .41758 Mtetra
.28139 .5968 .29054 .60479 .30461 .60046 .29552 .59247 Mtetra
.652 .751 .922 r
.29552 .59247 .30461 .60046 .31876 .59623 .30971 .5882 Mtetra
.657 .753 .92 r
.30971 .5882 .31876 .59623 .33299 .5919 .32399 .58376 Mtetra
.659 .751 .918 r
.32399 .58376 .33299 .5919 .3473 .58742 .33835 .57923 Mtetra
.656 .751 .919 r
.33835 .57923 .3473 .58742 .36169 .58294 .35278 .57476 Mtetra
.651 .75 .922 r
.35278 .57476 .36169 .58294 .37615 .57862 .36728 .57045 Mtetra
.655 .753 .922 r
.36728 .57045 .37615 .57862 .39069 .57428 .38187 .56596 Mtetra
.659 .752 .918 r
.38187 .56596 .39069 .57428 .40531 .56971 .39655 .5613 Mtetra
.659 .75 .918 r
.39655 .5613 .40531 .56971 .42001 .56506 .4113 .55663 Mtetra
.651 .749 .921 r
.4113 .55663 .42001 .56506 .4348 .56052 .42613 .55224 Mtetra
.651 .754 .925 r
.42613 .55224 .4348 .56052 .44965 .5562 .44104 .5478 Mtetra
.658 .754 .921 r
.44104 .5478 .44965 .5562 .4646 .55169 .45604 .54308 Mtetra
.662 .751 .916 r
.45604 .54308 .4646 .55169 .47962 .54698 .47112 .53819 Mtetra
.66 .747 .915 r
.47112 .53819 .47962 .54698 .49474 .54213 .48629 .53337 Mtetra
.648 .746 .921 r
.48629 .53337 .49474 .54213 .50993 .53733 .50153 .52897 Mtetra
.646 .756 .929 r
.50153 .52897 .50993 .53733 .52521 .53281 .51687 .52458 Mtetra
.656 .763 .928 r
.51687 .52458 .52521 .53281 .54057 .52833 .53229 .51977 Mtetra
.654 .756 .924 r
.53229 .51977 .54057 .52833 .55602 .52376 .5478 .51503 Mtetra
.654 .752 .922 r
.5478 .51503 .55602 .52376 .57156 .51909 .56339 .51029 Mtetra
.656 .753 .921 r
.56339 .51029 .57156 .51909 .58719 .5143 .57908 .50546 Mtetra
.658 .754 .921 r
.57908 .50546 .58719 .5143 .6029 .50941 .59485 .50052 Mtetra
.657 .753 .921 r
.59485 .50052 .6029 .50941 .6187 .5044 .61071 .49559 Mtetra
.654 .756 .924 r
.61071 .49559 .6187 .5044 .63458 .4993 .62667 .49073 Mtetra
.664 .766 .926 r
.62667 .49073 .63458 .4993 .65055 .49425 .6427 .48544 Mtetra
.663 .761 .923 r
.6427 .48544 .65055 .49425 .66663 .48947 .65882 .48016 Mtetra
.652 .747 .919 r
.65882 .48016 .66663 .48947 .68281 .48474 .67506 .4753 Mtetra
.65 .744 .918 r
.67506 .4753 .68281 .48474 .69907 .47987 .69139 .47051 Mtetra
.653 .749 .92 r
.69139 .47051 .69907 .47987 .71542 .47479 .70781 .46555 Mtetra
.66 .755 .92 r
.70781 .46555 .71542 .47479 .73185 .46952 .72432 .4603 Mtetra
.66 .757 .921 r
.72432 .4603 .73185 .46952 .74839 .46447 .74091 .45498 Mtetra
.653 .749 .92 r
.74091 .45498 .74839 .46447 .76504 .45952 .75762 .44996 Mtetra
.652 .748 .92 r
.75762 .44996 .76504 .45952 .78178 .45449 .77444 .44491 Mtetra
.656 .751 .92 r
.77444 .44491 .78178 .45449 .79861 .44921 .79134 .43969 Mtetra
.66 .755 .92 r
.79134 .43969 .79861 .44921 .81553 .44392 .80833 .43427 Mtetra
.655 .751 .921 r
.80833 .43427 .81553 .44392 .83257 .43877 .82543 .42902 Mtetra
.653 .749 .92 r
.82543 .42902 .83257 .43877 .84971 .43363 .84265 .42382 Mtetra
.655 .75 .92 r
.84265 .42382 .84971 .43363 .86694 .42833 .85996 .41854 Mtetra
.659 .753 .92 r
.85996 .41854 .86694 .42833 .88426 .4229 .87735 .41304 Mtetra
.656 .752 .921 r
.87735 .41304 .88426 .4229 .9017 .41758 .89487 .40762 Mtetra
.654 .751 .921 r
.27216 .58873 .28139 .5968 .29552 .59247 .28632 .5844 Mtetra
.653 .752 .922 r
.28632 .5844 .29552 .59247 .30971 .5882 .30057 .58007 Mtetra
.658 .752 .919 r
.30057 .58007 .30971 .5882 .32399 .58376 .31489 .57553 Mtetra
.658 .751 .919 r
.31489 .57553 .32399 .58376 .33835 .57923 .3293 .57097 Mtetra
.654 .75 .921 r
.3293 .57097 .33835 .57923 .35278 .57476 .34378 .56653 Mtetra
.651 .752 .923 r
.34378 .56653 .35278 .57476 .36728 .57045 .35833 .56217 Mtetra
.658 .753 .92 r
.35833 .56217 .36728 .57045 .38187 .56596 .37297 .55754 Mtetra
.66 .751 .918 r
.37297 .55754 .38187 .56596 .39655 .5613 .3877 .55282 Mtetra
.656 .75 .919 r
.3877 .55282 .39655 .5613 .4113 .55663 .4025 .54823 Mtetra
.649 .751 .924 r
.4025 .54823 .4113 .55663 .42613 .55224 .41738 .54386 Mtetra
.656 .755 .922 r
.41738 .54386 .42613 .55224 .44104 .5478 .43234 .5392 Mtetra
.662 .752 .917 r
.43234 .5392 .44104 .5478 .45604 .54308 .4474 .53431 Mtetra
.662 .749 .915 r
.4474 .53431 .45604 .54308 .47112 .53819 .46253 .5294 Mtetra
.648 .746 .921 r
.46253 .5294 .47112 .53819 .48629 .53337 .47775 .52497 Mtetra
.646 .756 .929 r
.47775 .52497 .48629 .53337 .50153 .52897 .49305 .52054 Mtetra
.655 .759 .926 r
.49305 .52054 .50153 .52897 .51687 .52458 .50844 .51576 Mtetra
.646 .748 .924 r
.50844 .51576 .51687 .52458 .53229 .51977 .52392 .51133 Mtetra
.645 .758 .931 r
.52392 .51133 .53229 .51977 .5478 .51503 .53949 .50686 Mtetra
.639 .764 .939 r
.53949 .50686 .5478 .51503 .56339 .51029 .55515 .50252 Mtetra
.653 .78 .941 r
.55515 .50252 .56339 .51029 .57908 .50546 .5709 .49763 Mtetra
.667 .784 .936 r
.5709 .49763 .57908 .50546 .59485 .50052 .58673 .49221 Mtetra
.664 .772 .93 r
.58673 .49221 .59485 .50052 .61071 .49559 .60264 .4869 Mtetra
.665 .764 .924 r
.60264 .4869 .61071 .49559 .62667 .49073 .61865 .48155 Mtetra
.656 .751 .92 r
.61865 .48155 .62667 .49073 .6427 .48544 .63476 .47656 Mtetra
.664 .762 .923 r
.63476 .47656 .6427 .48544 .65882 .48016 .65095 .4712 Mtetra
.663 .761 .923 r
.65095 .4712 .65882 .48016 .67506 .4753 .66722 .46584 Mtetra
.65 .746 .92 r
.66722 .46584 .67506 .4753 .69139 .47051 .68362 .46098 Mtetra
.65 .745 .919 r
.68362 .46098 .69139 .47051 .70781 .46555 .70012 .45608 Mtetra
.655 .75 .92 r
.70012 .45608 .70781 .46555 .72432 .4603 .7167 .45095 Mtetra
.662 .757 .92 r
.7167 .45095 .72432 .4603 .74091 .45498 .73336 .44551 Mtetra
.656 .753 .921 r
.73336 .44551 .74091 .45498 .75762 .44996 .75013 .4403 Mtetra
.652 .748 .92 r
.75013 .4403 .75762 .44996 .77444 .44491 .76701 .43522 Mtetra
.654 .75 .92 r
.76701 .43522 .77444 .44491 .79134 .43969 .78399 .43003 Mtetra
.66 .754 .92 r
.78399 .43003 .79134 .43969 .80833 .43427 .80105 .42457 Mtetra
.657 .753 .921 r
.80105 .42457 .80833 .43427 .82543 .42902 .81822 .41918 Mtetra
.653 .75 .921 r
.81822 .41918 .82543 .42902 .84265 .42382 .83551 .41391 Mtetra
.654 .75 .92 r
.83551 .41391 .84265 .42382 .85996 .41854 .8529 .40861 Mtetra
.658 .753 .92 r
.8529 .40861 .85996 .41854 .87735 .41304 .87037 .40308 Mtetra
.657 .753 .92 r
.87037 .40308 .87735 .41304 .89487 .40762 .88796 .39756 Mtetra
.653 .751 .921 r
.26283 .58059 .27216 .58873 .28632 .5844 .27704 .57624 Mtetra
.654 .752 .921 r
.27704 .57624 .28632 .5844 .30057 .58007 .29133 .57182 Mtetra
.659 .752 .919 r
.29133 .57182 .30057 .58007 .31489 .57553 .30571 .56723 Mtetra
.658 .751 .919 r
.30571 .56723 .31489 .57553 .3293 .57097 .32016 .56264 Mtetra
.652 .75 .921 r
.32016 .56264 .3293 .57097 .34378 .56653 .33468 .55822 Mtetra
.653 .752 .922 r
.33468 .55822 .34378 .56653 .35833 .56217 .34929 .55375 Mtetra
.659 .752 .919 r
.34929 .55375 .35833 .56217 .37297 .55754 .36398 .54904 Mtetra
.66 .751 .918 r
.36398 .54904 .37297 .55754 .3877 .55282 .37876 .54427 Mtetra
.652 .749 .921 r
.37876 .54427 .3877 .55282 .4025 .54823 .39361 .53978 Mtetra
.651 .752 .924 r
.39361 .53978 .4025 .54823 .41738 .54386 .40853 .53529 Mtetra
.659 .753 .92 r
.40853 .53529 .41738 .54386 .43234 .5392 .42356 .53048 Mtetra
.664 .752 .916 r
.42356 .53048 .43234 .5392 .4474 .53431 .43867 .52547 Mtetra
.654 .747 .918 r
.43867 .52547 .4474 .53431 .46253 .5294 .45385 .52081 Mtetra
.642 .751 .928 r
.45385 .52081 .46253 .5294 .47775 .52497 .46912 .51652 Mtetra
.656 .759 .926 r
.46912 .51652 .47775 .52497 .49305 .52054 .48448 .5117 Mtetra
.643 .747 .925 r
.48448 .5117 .49305 .52054 .50844 .51576 .49992 .50734 Mtetra
.605 .746 .944 r
.49992 .50734 .50844 .51576 .52392 .51133 .51545 .50413 Mtetra
.513 .744 .979 r
.51545 .50413 .52392 .51133 .53949 .50686 .53109 .50281 Mtetra
.413 .79 .992 r
.53109 .50281 .53949 .50686 .55515 .50252 .54685 .50138 Mtetra
.491 .889 .948 r
.54685 .50138 .55515 .50252 .5709 .49763 .5627 .49645 Mtetra
.679 .957 .947 r
.5627 .49645 .5709 .49763 .58673 .49221 .57858 .48802 Mtetra
.736 .901 .952 r
.57858 .48802 .58673 .49221 .60264 .4869 .59452 .47945 Mtetra
.696 .807 .934 r
.59452 .47945 .60264 .4869 .61865 .48155 .61056 .47278 Mtetra
.667 .767 .924 r
.61056 .47278 .61865 .48155 .63476 .47656 .62672 .46725 Mtetra
.655 .751 .92 r
.62672 .46725 .63476 .47656 .65095 .4712 .64298 .46218 Mtetra
.668 .764 .922 r
.64298 .46218 .65095 .4712 .66722 .46584 .65932 .45659 Mtetra
.658 .756 .922 r
.65932 .45659 .66722 .46584 .68362 .46098 .67577 .45135 Mtetra
.648 .745 .92 r
.67577 .45135 .68362 .46098 .70012 .45608 .69233 .44648 Mtetra
.653 .749 .92 r
.69233 .44648 .70012 .45608 .7167 .45095 .70899 .4414 Mtetra
.66 .754 .919 r
.70899 .4414 .7167 .45095 .73336 .44551 .72572 .43598 Mtetra
.659 .755 .921 r
.72572 .43598 .73336 .44551 .75013 .4403 .74255 .43056 Mtetra
.652 .749 .921 r
.74255 .43056 .75013 .4403 .76701 .43522 .75951 .42542 Mtetra
.653 .749 .92 r
.75951 .42542 .76701 .43522 .78399 .43003 .77656 .42021 Mtetra
.658 .752 .919 r
.77656 .42021 .78399 .43003 .80105 .42457 .7937 .41476 Mtetra
.659 .754 .92 r
.7937 .41476 .80105 .42457 .81822 .41918 .81093 .40924 Mtetra
.654 .75 .921 r
.81093 .40924 .81822 .41918 .83551 .41391 .82829 .4039 Mtetra
.653 .75 .921 r
.82829 .4039 .83551 .41391 .8529 .40861 .84576 .39855 Mtetra
.657 .752 .92 r
.84576 .39855 .8529 .40861 .87037 .40308 .86331 .39301 Mtetra
.658 .753 .92 r
.86331 .39301 .87037 .40308 .88796 .39756 .88097 .38739 Mtetra
.653 .751 .922 r
.25341 .57237 .26283 .58059 .27704 .57624 .26767 .568 Mtetra
.655 .752 .921 r
.26767 .568 .27704 .57624 .29133 .57182 .282 .5635 Mtetra
.659 .752 .919 r
.282 .5635 .29133 .57182 .30571 .56723 .29643 .55886 Mtetra
.657 .751 .919 r
.29643 .55886 .30571 .56723 .32016 .56264 .31093 .55424 Mtetra
.651 .75 .922 r
.31093 .55424 .32016 .56264 .33468 .55822 .3255 .54981 Mtetra
.655 .752 .921 r
.3255 .54981 .33468 .55822 .34929 .55375 .34015 .54523 Mtetra
.66 .752 .918 r
.34015 .54523 .34929 .55375 .36398 .54904 .3549 .54046 Mtetra
.659 .751 .918 r
.3549 .54046 .36398 .54904 .37876 .54427 .36973 .53567 Mtetra
.649 .749 .923 r
.36973 .53567 .37876 .54427 .39361 .53978 .38462 .53122 Mtetra
.653 .753 .923 r
.38462 .53122 .39361 .53978 .40853 .53529 .3996 .52659 Mtetra
.661 .753 .918 r
.3996 .52659 .40853 .53529 .42356 .53048 .41468 .52165 Mtetra
.663 .751 .916 r
.41468 .52165 .42356 .53048 .43867 .52547 .42985 .51662 Mtetra
.645 .747 .923 r
.42985 .51662 .43867 .52547 .45385 .52081 .44508 .5122 Mtetra
.65 .755 .926 r
.44508 .5122 .45385 .52081 .46912 .51652 .4604 .50758 Mtetra
.645 .747 .923 r
.4604 .50758 .46912 .51652 .48448 .5117 .47581 .50314 Mtetra
.602 .743 .943 r
.47581 .50314 .48448 .5117 .49992 .50734 .4913 .5 Mtetra
.321 .648 .969 r
.4913 .5 .49992 .50734 .51545 .50413 .50686 .50213 Mtetra
.316 0 0 r
.50686 .50213 .51545 .50413 .53109 .50281 .52258 .50786 Mtetra
.447 0 0 r
.52258 .50786 .53109 .50281 .54685 .50138 .53848 .51112 Mtetra
.209 0 0 r
.53848 .51112 .54685 .50138 .5627 .49645 .55448 .50617 Mtetra
0 0 0 r
.55448 .50617 .5627 .49645 .57858 .48802 .57045 .49297 Mtetra
.694 .956 .697 r
.57045 .49297 .57858 .48802 .59452 .47945 .5864 .47724 Mtetra
.807 .956 .913 r
.5864 .47724 .59452 .47945 .61056 .47278 .60241 .46509 Mtetra
.699 .805 .931 r
.60241 .46509 .61056 .47278 .62672 .46725 .61861 .45822 Mtetra
.666 .764 .923 r
.61861 .45822 .62672 .46725 .64298 .46218 .63492 .45267 Mtetra
.661 .752 .918 r
.63492 .45267 .64298 .46218 .65932 .45659 .65134 .4473 Mtetra
.665 .76 .921 r
.65134 .4473 .65932 .45659 .67577 .45135 .66784 .44171 Mtetra
.649 .747 .921 r
.66784 .44171 .67577 .45135 .69233 .44648 .68447 .43675 Mtetra
.651 .747 .92 r
.68447 .43675 .69233 .44648 .70899 .4414 .70119 .43169 Mtetra
.658 .752 .919 r
.70119 .43169 .70899 .4414 .72572 .43598 .718 .42632 Mtetra
.662 .756 .92 r
.718 .42632 .72572 .43598 .74255 .43056 .7349 .42074 Mtetra
.653 .75 .921 r
.7349 .42074 .74255 .43056 .75951 .42542 .75192 .41552 Mtetra
.652 .749 .921 r
.75192 .41552 .75951 .42542 .77656 .42021 .76904 .41028 Mtetra
.657 .751 .92 r
.76904 .41028 .77656 .42021 .7937 .41476 .78626 .40482 Mtetra
.66 .754 .92 r
.78626 .40482 .7937 .41476 .81093 .40924 .80356 .3992 Mtetra
.654 .751 .921 r
.80356 .3992 .81093 .40924 .82829 .4039 .82099 .39378 Mtetra
.653 .75 .921 r
.82099 .39378 .82829 .4039 .84576 .39855 .83854 .38837 Mtetra
.656 .751 .92 r
.83854 .38837 .84576 .39855 .86331 .39301 .85617 .38281 Mtetra
.659 .753 .92 r
.85617 .38281 .86331 .39301 .88097 .38739 .8739 .37711 Mtetra
.652 .751 .922 r
.2439 .56407 .25341 .57237 .26767 .568 .2582 .55966 Mtetra
.656 .752 .92 r
.2582 .55966 .26767 .568 .282 .5635 .27258 .55509 Mtetra
.659 .752 .919 r
.27258 .55509 .282 .5635 .29643 .55886 .28706 .5504 Mtetra
.657 .751 .92 r
.28706 .5504 .29643 .55886 .31093 .55424 .3016 .54575 Mtetra
.651 .75 .922 r
.3016 .54575 .31093 .55424 .3255 .54981 .31622 .5413 Mtetra
.656 .752 .921 r
.31622 .5413 .3255 .54981 .34015 .54523 .33093 .53664 Mtetra
.66 .752 .918 r
.33093 .53664 .34015 .54523 .3549 .54046 .34572 .5318 Mtetra
.658 .751 .919 r
.34572 .5318 .3549 .54046 .36973 .53567 .3606 .52701 Mtetra
.648 .75 .924 r
.3606 .52701 .36973 .53567 .38462 .53122 .37554 .52255 Mtetra
.655 .753 .921 r
.37554 .52255 .38462 .53122 .3996 .52659 .39058 .51779 Mtetra
.663 .753 .917 r
.39058 .51779 .3996 .52659 .41468 .52165 .40571 .51274 Mtetra
.659 .751 .917 r
.40571 .51274 .41468 .52165 .42985 .51662 .42093 .50778 Mtetra
.642 .748 .926 r
.42093 .50778 .42985 .51662 .44508 .5122 .43621 .50345 Mtetra
.654 .755 .924 r
.43621 .50345 .44508 .5122 .4604 .50758 .45159 .49864 Mtetra
.635 .746 .928 r
.45159 .49864 .4604 .50758 .47581 .50314 .46705 .49448 Mtetra
.474 .69 .962 r
.46705 .49448 .47581 .50314 .4913 .5 .48255 .4945 Mtetra
0 .218 .633 r
.48255 .4945 .4913 .5 .50686 .50213 .49811 .50368 Mtetra
.733 .23 .032 r
.49811 .50368 .50686 .50213 .52258 .50786 .51388 .51926 Mtetra
.652 .223 .216 r
.51388 .51926 .52258 .50786 .53848 .51112 .52993 .53033 Mtetra
.379 .003 .193 r
.52993 .53033 .53848 .51112 .55448 .50617 .54612 .52536 Mtetra
0 0 0 r
.54612 .52536 .55448 .50617 .57045 .49297 .56224 .50429 Mtetra
.696 .865 .461 r
.56224 .50429 .57045 .49297 .5864 .47724 .57821 .4786 Mtetra
.892 .986 .796 r
.57821 .4786 .5864 .47724 .60241 .46509 .59421 .45925 Mtetra
.772 .869 .919 r
.59421 .45925 .60241 .46509 .61861 .45822 .61041 .44908 Mtetra
.674 .766 .92 r
.61041 .44908 .61861 .45822 .63492 .45267 .62678 .44314 Mtetra
.657 .753 .92 r
.62678 .44314 .63492 .45267 .65134 .4473 .64326 .43785 Mtetra
.669 .76 .919 r
.64326 .43785 .65134 .4473 .66784 .44171 .65983 .43208 Mtetra
.652 .751 .922 r
.65983 .43208 .66784 .44171 .68447 .43675 .67652 .42693 Mtetra
.649 .747 .921 r
.67652 .42693 .68447 .43675 .70119 .43169 .69331 .42188 Mtetra
.656 .751 .92 r
.69331 .42188 .70119 .43169 .718 .42632 .71019 .41652 Mtetra
.663 .755 .919 r
.71019 .41652 .718 .42632 .7349 .42074 .72716 .41085 Mtetra
.654 .751 .921 r
.72716 .41085 .7349 .42074 .75192 .41552 .74425 .40552 Mtetra
.652 .749 .921 r
.74425 .40552 .75192 .41552 .76904 .41028 .76144 .40023 Mtetra
.656 .751 .92 r
.76144 .40023 .76904 .41028 .78626 .40482 .77873 .39476 Mtetra
.66 .754 .919 r
.77873 .39476 .78626 .40482 .80356 .3992 .79611 .38906 Mtetra
.655 .751 .921 r
.79611 .38906 .80356 .3992 .82099 .39378 .81362 .38356 Mtetra
.653 .75 .921 r
.81362 .38356 .82099 .39378 .83854 .38837 .83124 .37809 Mtetra
.656 .751 .92 r
.83124 .37809 .83854 .38837 .85617 .38281 .84895 .37248 Mtetra
.659 .753 .92 r
.84895 .37248 .85617 .38281 .8739 .37711 .86676 .36671 Mtetra
.652 .751 .922 r
.23429 .55568 .2439 .56407 .2582 .55966 .24863 .55123 Mtetra
.656 .752 .92 r
.24863 .55123 .2582 .55966 .27258 .55509 .26307 .54661 Mtetra
.659 .752 .919 r
.26307 .54661 .27258 .55509 .28706 .5504 .27759 .54187 Mtetra
.657 .751 .92 r
.27759 .54187 .28706 .5504 .3016 .54575 .29218 .53719 Mtetra
.651 .75 .922 r
.29218 .53719 .3016 .54575 .31622 .5413 .30684 .53269 Mtetra
.656 .752 .92 r
.30684 .53269 .31622 .5413 .33093 .53664 .3216 .52796 Mtetra
.66 .752 .918 r
.3216 .52796 .33093 .53664 .34572 .5318 .33645 .52306 Mtetra
.657 .751 .92 r
.33645 .52306 .34572 .5318 .3606 .52701 .35138 .51826 Mtetra
.648 .75 .924 r
.35138 .51826 .3606 .52701 .37554 .52255 .36637 .51375 Mtetra
.657 .752 .92 r
.36637 .51375 .37554 .52255 .39058 .51779 .38146 .50891 Mtetra
.663 .753 .917 r
.38146 .50891 .39058 .51779 .40571 .51274 .39665 .50378 Mtetra
.657 .751 .919 r
.39665 .50378 .40571 .51274 .42093 .50778 .41192 .49887 Mtetra
.641 .748 .927 r
.41192 .49887 .42093 .50778 .43621 .50345 .42725 .49451 Mtetra
.654 .753 .922 r
.42725 .49451 .43621 .50345 .45159 .49864 .44269 .48965 Mtetra
.622 .742 .933 r
.44269 .48965 .45159 .49864 .46705 .49448 .45819 .48587 Mtetra
.309 .61 .954 r
.45819 .48587 .46705 .49448 .48255 .4945 .47369 .48882 Mtetra
.58 .03 0 r
.47369 .48882 .48255 .4945 .49811 .50368 .48924 .50273 Mtetra
.818 .345 .082 r
.48924 .50273 .49811 .50368 .51388 .51926 .50501 .52613 Mtetra
.727 .274 .175 r
.50501 .52613 .51388 .51926 .52993 .53033 .52115 .54245 Mtetra
.263 0 0 r
.52115 .54245 .52993 .53033 .54612 .52536 .53751 .53747 Mtetra
.694 .862 .455 r
.53751 .53747 .54612 .52536 .56224 .50429 .55378 .51107 Mtetra
.952 .942 .623 r
.55378 .51107 .56224 .50429 .57821 .4786 .56985 .47743 Mtetra
.939 .924 .768 r
.56985 .47743 .57821 .4786 .59421 .45925 .5859 .45322 Mtetra
.822 .867 .88 r
.5859 .45322 .59421 .45925 .61041 .44908 .60212 .44 Mtetra
.685 .773 .918 r
.60212 .44 .61041 .44908 .62678 .44314 .61854 .43356 Mtetra
.657 .754 .921 r
.61854 .43356 .62678 .44314 .64326 .43785 .6351 .42821 Mtetra
.669 .758 .917 r
.6351 .42821 .64326 .43785 .65983 .43208 .65173 .42235 Mtetra
.655 .752 .922 r
.65173 .42235 .65983 .43208 .67652 .42693 .66848 .41705 Mtetra
.649 .748 .922 r
.66848 .41705 .67652 .42693 .69331 .42188 .68534 .41196 Mtetra
.655 .751 .92 r
.68534 .41196 .69331 .42188 .71019 .41652 .7023 .40658 Mtetra
.663 .755 .918 r
.7023 .40658 .71019 .41652 .72716 .41085 .71933 .40085 Mtetra
.655 .751 .921 r
.71933 .40085 .72716 .41085 .74425 .40552 .73649 .39542 Mtetra
.652 .749 .921 r
.73649 .39542 .74425 .40552 .76144 .40023 .75376 .39009 Mtetra
.655 .751 .92 r
.75376 .39009 .76144 .40023 .77873 .39476 .77113 .38457 Mtetra
.66 .753 .919 r
.77113 .38457 .77873 .39476 .79611 .38906 .78858 .3788 Mtetra
.655 .751 .921 r
.78858 .3788 .79611 .38906 .81362 .38356 .80616 .37322 Mtetra
.653 .75 .921 r
.80616 .37322 .81362 .38356 .83124 .37809 .82385 .3677 Mtetra
.655 .751 .92 r
.82385 .3677 .83124 .37809 .84895 .37248 .84165 .36204 Mtetra
.659 .753 .919 r
.84165 .36204 .84895 .37248 .86676 .36671 .85953 .3562 Mtetra
.652 .751 .922 r
.22458 .54721 .23429 .55568 .24863 .55123 .23897 .54271 Mtetra
.656 .752 .92 r
.23897 .54271 .24863 .55123 .26307 .54661 .25345 .53804 Mtetra
.659 .752 .919 r
.25345 .53804 .26307 .54661 .27759 .54187 .26802 .53325 Mtetra
.657 .752 .92 r
.26802 .53325 .27759 .54187 .29218 .53719 .28266 .52852 Mtetra
.651 .75 .922 r
.28266 .52852 .29218 .53719 .30684 .53269 .29737 .52397 Mtetra
.656 .752 .92 r
.29737 .52397 .30684 .53269 .3216 .52796 .31218 .5192 Mtetra
.66 .753 .918 r
.31218 .5192 .3216 .52796 .33645 .52306 .32708 .51425 Mtetra
.657 .752 .92 r
.32708 .51425 .33645 .52306 .35138 .51826 .34206 .5094 Mtetra
.648 .749 .923 r
.34206 .5094 .35138 .51826 .36637 .51375 .3571 .50484 Mtetra
.657 .752 .92 r
.3571 .50484 .36637 .51375 .38146 .50891 .37225 .49995 Mtetra
.663 .754 .917 r
.37225 .49995 .38146 .50891 .39665 .50378 .38749 .49477 Mtetra
.657 .752 .92 r
.38749 .49477 .39665 .50378 .41192 .49887 .40281 .4898 Mtetra
.641 .747 .926 r
.40281 .4898 .41192 .49887 .42725 .49451 .4182 .4854 Mtetra
.654 .751 .921 r
.4182 .4854 .42725 .49451 .44269 .48965 .43369 .48048 Mtetra
.622 .741 .932 r
.43369 .48048 .44269 .48965 .45819 .48587 .44925 .47666 Mtetra
.327 .607 .949 r
.44925 .47666 .45819 .48587 .47369 .48882 .46479 .47957 Mtetra
0 .088 .595 r
.46479 .47957 .47369 .48882 .48924 .50273 .48034 .49347 Mtetra
.728 .247 0 r
.48034 .49347 .48924 .50273 .50501 .52613 .49609 .51689 Mtetra
0 .002 .508 r
.49609 .51689 .50501 .52613 .52115 .54245 .51223 .53322 Mtetra
.649 .759 .93 r
.51223 .53322 .52115 .54245 .53751 .53747 .52866 .52818 Mtetra
.89 .788 .742 r
.52866 .52818 .53751 .53747 .55378 .51107 .54505 .50167 Mtetra
.913 .78 .7 r
.54505 .50167 .55378 .51107 .56985 .47743 .56125 .4679 Mtetra
.882 .789 .754 r
.56125 .4679 .56985 .47743 .5859 .45322 .57742 .44358 Mtetra
.798 .788 .844 r
.57742 .44358 .5859 .45322 .60212 .44 .59372 .43028 Mtetra
.684 .761 .91 r
.59372 .43028 .60212 .44 .61854 .43356 .61022 .42378 Mtetra
.657 .752 .92 r
.61022 .42378 .61854 .43356 .6351 .42821 .62684 .41838 Mtetra
.669 .756 .916 r
.62684 .41838 .6351 .42821 .65173 .42235 .64354 .41246 Mtetra
.655 .751 .921 r
.64354 .41246 .65173 .42235 .66848 .41705 .66036 .4071 Mtetra
.648 .749 .923 r
.66036 .4071 .66848 .41705 .68534 .41196 .67729 .40195 Mtetra
.655 .751 .921 r
.67729 .40195 .68534 .41196 .7023 .40658 .69431 .39652 Mtetra
.663 .754 .918 r
.69431 .39652 .7023 .40658 .71933 .40085 .71142 .39072 Mtetra
.655 .751 .921 r
.71142 .39072 .71933 .40085 .73649 .39542 .72865 .38523 Mtetra
.652 .75 .922 r
.72865 .38523 .73649 .39542 .75376 .39009 .74599 .37983 Mtetra
.655 .751 .92 r
.74599 .37983 .75376 .39009 .77113 .38457 .76343 .37425 Mtetra
.66 .753 .919 r
.76343 .37425 .77113 .38457 .78858 .3788 .78096 .36842 Mtetra
.655 .751 .92 r
.78096 .36842 .78858 .3788 .80616 .37322 .79861 .36278 Mtetra
.653 .75 .921 r
.79861 .36278 .80616 .37322 .82385 .3677 .81639 .35719 Mtetra
.655 .751 .92 r
.81639 .35719 .82385 .3677 .84165 .36204 .83426 .35147 Mtetra
.659 .753 .919 r
.83426 .35147 .84165 .36204 .85953 .3562 .85223 .34556 Mtetra
.652 .751 .922 r
.21477 .53865 .22458 .54721 .23897 .54271 .22921 .53409 Mtetra
.656 .751 .92 r
.22921 .53409 .23897 .54271 .25345 .53804 .24373 .52939 Mtetra
.659 .752 .919 r
.24373 .52939 .25345 .53804 .26802 .53325 .25835 .52455 Mtetra
.657 .752 .92 r
.25835 .52455 .26802 .53325 .28266 .52852 .27305 .51976 Mtetra
.651 .75 .922 r
.27305 .51976 .28266 .52852 .29737 .52397 .28781 .51516 Mtetra
.656 .751 .92 r
.28781 .51516 .29737 .52397 .31218 .5192 .30266 .51035 Mtetra
.66 .753 .919 r
.30266 .51035 .31218 .5192 .32708 .51425 .31761 .50536 Mtetra
.658 .752 .92 r
.31761 .50536 .32708 .51425 .34206 .5094 .33264 .50042 Mtetra
.648 .749 .923 r
.33264 .50042 .34206 .5094 .3571 .50484 .34774 .49581 Mtetra
.656 .751 .92 r
.34774 .49581 .3571 .50484 .37225 .49995 .36294 .49091 Mtetra
.663 .754 .918 r
.36294 .49091 .37225 .49995 .38749 .49477 .37823 .4857 Mtetra
.659 .753 .919 r
.37823 .4857 .38749 .49477 .40281 .4898 .39361 .48059 Mtetra
.642 .746 .924 r
.39361 .48059 .40281 .4898 .4182 .4854 .40905 .4761 Mtetra
.654 .749 .92 r
.40905 .4761 .4182 .4854 .43369 .48048 .4246 .47114 Mtetra
.635 .743 .926 r
.4246 .47114 .43369 .48048 .44925 .47666 .44023 .46682 Mtetra
.49 .675 .947 r
.44023 .46682 .44925 .47666 .46479 .47957 .45586 .46673 Mtetra
.099 .384 .844 r
.45586 .46673 .46479 .47957 .48034 .49347 .47148 .47585 Mtetra
0 .213 .731 r
.47148 .47585 .48034 .49347 .49609 .51689 .48726 .49143 Mtetra
.329 .362 .745 r
.48726 .49143 .49609 .51689 .51223 .53322 .50336 .50246 Mtetra
.612 .508 .712 r
.50336 .50246 .51223 .53322 .52866 .52818 .51975 .49733 Mtetra
.735 .581 .683 r
.51975 .49733 .52866 .52818 .54505 .50167 .53617 .47597 Mtetra
.783 .627 .687 r
.53617 .47597 .54505 .50167 .56125 .4679 .5525 .44994 Mtetra
.791 .678 .739 r
.5525 .44994 .56125 .4679 .57742 .44358 .5688 .43031 Mtetra
.736 .713 .83 r
.5688 .43031 .57742 .44358 .59372 .43028 .58522 .41994 Mtetra
.674 .746 .905 r
.58522 .41994 .59372 .43028 .61022 .42378 .6018 .41382 Mtetra
.658 .75 .918 r
.6018 .41382 .61022 .42378 .62684 .41838 .61848 .40835 Mtetra
.669 .754 .914 r
.61848 .40835 .62684 .41838 .64354 .41246 .63525 .4024 Mtetra
.652 .749 .92 r
.63525 .4024 .64354 .41246 .66036 .4071 .65214 .39708 Mtetra
.649 .75 .923 r
.65214 .39708 .66036 .4071 .67729 .40195 .66914 .39185 Mtetra
.656 .752 .92 r
.66914 .39185 .67729 .40195 .69431 .39652 .68623 .38631 Mtetra
.663 .753 .918 r
.68623 .38631 .69431 .39652 .71142 .39072 .70341 .38046 Mtetra
.654 .75 .921 r
.70341 .38046 .71142 .39072 .72865 .38523 .72072 .37494 Mtetra
.652 .75 .922 r
.72072 .37494 .72865 .38523 .74599 .37983 .73813 .36947 Mtetra
.656 .752 .92 r
.73813 .36947 .74599 .37983 .76343 .37425 .75565 .36381 Mtetra
.66 .753 .919 r
.75565 .36381 .76343 .37425 .78096 .36842 .77325 .35792 Mtetra
.655 .751 .92 r
.77325 .35792 .78096 .36842 .79861 .36278 .79099 .35223 Mtetra
.653 .75 .921 r
.79099 .35223 .79861 .36278 .81639 .35719 .80883 .34657 Mtetra
.656 .751 .92 r
.80883 .34657 .81639 .35719 .83426 .35147 .82678 .34077 Mtetra
.659 .753 .919 r
.82678 .34077 .83426 .35147 .85223 .34556 .84483 .3348 Mtetra
.653 .751 .922 r
.20486 .52999 .21477 .53865 .22921 .53409 .21934 .52538 Mtetra
.655 .751 .92 r
.21934 .52538 .22921 .53409 .24373 .52939 .23392 .52065 Mtetra
.659 .752 .919 r
.23392 .52065 .24373 .52939 .25835 .52455 .24858 .51577 Mtetra
.657 .752 .92 r
.24858 .51577 .25835 .52455 .27305 .51976 .26333 .51091 Mtetra
.651 .75 .922 r
.26333 .51091 .27305 .51976 .28781 .51516 .27814 .50624 Mtetra
.655 .751 .92 r
.27814 .50624 .28781 .51516 .30266 .51035 .29304 .50142 Mtetra
.66 .753 .919 r
.29304 .50142 .30266 .51035 .31761 .50536 .30805 .49639 Mtetra
.659 .753 .919 r
.30805 .49639 .31761 .50536 .33264 .50042 .32313 .49135 Mtetra
.649 .749 .923 r
.32313 .49135 .33264 .50042 .34774 .49581 .33828 .48666 Mtetra
.653 .75 .92 r
.33828 .48666 .34774 .49581 .36294 .49091 .35353 .48178 Mtetra
.661 .753 .919 r
.35353 .48178 .36294 .49091 .37823 .4857 .36888 .47658 Mtetra
.663 .755 .919 r
.36888 .47658 .37823 .4857 .39361 .48059 .38431 .47129 Mtetra
.645 .747 .923 r
.38431 .47129 .39361 .48059 .40905 .4761 .39982 .46662 Mtetra
.65 .746 .919 r
.39982 .46662 .40905 .4761 .4246 .47114 .41542 .46174 Mtetra
.645 .747 .924 r
.41542 .46174 .4246 .47114 .44023 .46682 .4311 .45704 Mtetra
.606 .726 .93 r
.4311 .45704 .44023 .46682 .45586 .46673 .44685 .45366 Mtetra
.45 .588 .899 r
.44685 .45366 .45586 .46673 .47148 .47585 .46261 .45561 Mtetra
.412 .461 .801 r
.46261 .45561 .47148 .47585 .48726 .49143 .47848 .4612 Mtetra
.508 .445 .722 r
.47848 .4612 .48726 .49143 .50336 .50246 .49457 .4643 Mtetra
.601 .475 .681 r
.49457 .4643 .50336 .50246 .51975 .49733 .51088 .45907 Mtetra
.664 .515 .672 r
.51088 .45907 .51975 .49733 .53617 .47597 .52728 .44548 Mtetra
.705 .564 .694 r
.52728 .44548 .53617 .47597 .5525 .44994 .54368 .42934 Mtetra
.718 .626 .754 r
.54368 .42934 .5525 .44994 .5688 .43031 .5601 .41681 Mtetra
.685 .693 .852 r
.5601 .41681 .5688 .43031 .58522 .41994 .57664 .40964 Mtetra
.666 .747 .911 r
.57664 .40964 .58522 .41994 .6018 .41382 .59329 .40379 Mtetra
.661 .752 .918 r
.59329 .40379 .6018 .41382 .61848 .40835 .61004 .39813 Mtetra
.665 .751 .914 r
.61004 .39813 .61848 .40835 .63525 .4024 .62688 .39224 Mtetra
.649 .748 .922 r
.62688 .39224 .63525 .4024 .65214 .39708 .64384 .38699 Mtetra
.65 .751 .923 r
.64384 .38699 .65214 .39708 .66914 .39185 .66091 .38164 Mtetra
.658 .753 .92 r
.66091 .38164 .66914 .39185 .68623 .38631 .67807 .37596 Mtetra
.662 .753 .917 r
.67807 .37596 .68623 .38631 .70341 .38046 .69532 .37008 Mtetra
.653 .75 .921 r
.69532 .37008 .70341 .38046 .72072 .37494 .7127 .36455 Mtetra
.652 .751 .922 r
.7127 .36455 .72072 .37494 .73813 .36947 .73019 .359 Mtetra
.657 .752 .92 r
.73019 .359 .73813 .36947 .75565 .36381 .74778 .35323 Mtetra
.66 .752 .919 r
.74778 .35323 .75565 .36381 .77325 .35792 .76546 .34729 Mtetra
.654 .751 .921 r
.76546 .34729 .77325 .35792 .79099 .35223 .78327 .34156 Mtetra
.653 .751 .921 r
.78327 .34156 .79099 .35223 .80883 .34657 .8012 .33583 Mtetra
.656 .752 .92 r
.8012 .33583 .80883 .34657 .82678 .34077 .81922 .32994 Mtetra
.659 .752 .919 r
.81922 .32994 .82678 .34077 .84483 .3348 .83735 .32391 Mtetra
.653 .751 .921 r
.19485 .52125 .20486 .52999 .21934 .52538 .20938 .51658 Mtetra
.654 .751 .921 r
.20938 .51658 .21934 .52538 .23392 .52065 .224 .51183 Mtetra
.659 .752 .919 r
.224 .51183 .23392 .52065 .24858 .51577 .23871 .5069 Mtetra
.658 .752 .92 r
.23871 .5069 .24858 .51577 .26333 .51091 .25351 .50197 Mtetra
.652 .751 .922 r
.25351 .50197 .26333 .51091 .27814 .50624 .26837 .49721 Mtetra
.653 .75 .921 r
.26837 .49721 .27814 .50624 .29304 .50142 .28332 .4924 Mtetra
.659 .753 .919 r
.28332 .4924 .29304 .50142 .30805 .49639 .29837 .48735 Mtetra
.66 .754 .919 r
.29837 .48735 .30805 .49639 .32313 .49135 .31351 .48223 Mtetra
.652 .751 .922 r
.31351 .48223 .32313 .49135 .33828 .48666 .32872 .47738 Mtetra
.651 .748 .921 r
.32872 .47738 .33828 .48666 .35353 .48178 .34402 .47255 Mtetra
.659 .753 .919 r
.34402 .47255 .35353 .48178 .36888 .47658 .35942 .46738 Mtetra
.664 .756 .919 r
.35942 .46738 .36888 .47658 .38431 .47129 .37491 .462 Mtetra
.653 .752 .922 r
.37491 .462 .38431 .47129 .39982 .46662 .39048 .45698 Mtetra
.643 .742 .921 r
.39048 .45698 .39982 .46662 .41542 .46174 .40613 .45233 Mtetra
.656 .753 .921 r
.40613 .45233 .41542 .46174 .4311 .45704 .42188 .44714 Mtetra
.643 .739 .919 r
.42188 .44714 .4311 .45704 .44685 .45366 .43772 .44242 Mtetra
.613 .701 .907 r
.43772 .44242 .44685 .45366 .46261 .45561 .45363 .43886 Mtetra
.572 .593 .835 r
.45363 .43886 .46261 .45561 .47848 .4612 .46962 .43723 Mtetra
.575 .524 .76 r
.46962 .43723 .47848 .4612 .49457 .4643 .48573 .43547 Mtetra
.615 .519 .722 r
.48573 .43547 .49457 .4643 .51088 .45907 .50201 .43016 Mtetra
.651 .54 .715 r
.50201 .43016 .51088 .45907 .52728 .44548 .51839 .42128 Mtetra
.667 .575 .742 r
.51839 .42128 .52728 .44548 .54368 .42934 .53483 .41225 Mtetra
.67 .639 .81 r
.53483 .41225 .54368 .42934 .5601 .41681 .55135 .40515 Mtetra
.666 .72 .889 r
.55135 .40515 .5601 .41681 .57664 .40964 .56796 .39922 Mtetra
.655 .743 .914 r
.56796 .39922 .57664 .40964 .59329 .40379 .58468 .39375 Mtetra
.668 .757 .917 r
.58468 .39375 .59329 .40379 .61004 .39813 .60149 .38773 Mtetra
.658 .747 .916 r
.60149 .38773 .61004 .39813 .62688 .39224 .61841 .38209 Mtetra
.648 .75 .924 r
.61841 .38209 .62688 .39224 .64384 .38699 .63545 .37681 Mtetra
.653 .753 .923 r
.63545 .37681 .64384 .38699 .66091 .38164 .65258 .37131 Mtetra
.66 .754 .919 r
.65258 .37131 .66091 .38164 .67807 .37596 .66981 .36546 Mtetra
.66 .751 .918 r
.66981 .36546 .67807 .37596 .69532 .37008 .68714 .35962 Mtetra
.652 .75 .922 r
.68714 .35962 .69532 .37008 .7127 .36455 .70459 .35405 Mtetra
.653 .751 .922 r
.70459 .35405 .7127 .36455 .73019 .359 .72215 .34841 Mtetra
.658 .753 .92 r
.72215 .34841 .73019 .359 .74778 .35323 .73981 .34252 Mtetra
.659 .752 .919 r
.73981 .34252 .74778 .35323 .76546 .34729 .75758 .33656 Mtetra
.654 .751 .921 r
.75758 .33656 .76546 .34729 .78327 .34156 .77547 .33077 Mtetra
.653 .751 .921 r
.77547 .33077 .78327 .34156 .8012 .33583 .79347 .32497 Mtetra
.657 .752 .92 r
.79347 .32497 .8012 .33583 .81922 .32994 .81158 .31898 Mtetra
.658 .752 .919 r
.81158 .31898 .81922 .32994 .83735 .32391 .82979 .3129 Mtetra
.654 .751 .921 r
.18473 .51242 .19485 .52125 .20938 .51658 .19931 .50767 Mtetra
.653 .75 .921 r
.19931 .50767 .20938 .51658 .224 .51183 .21397 .50291 Mtetra
.658 .752 .919 r
.21397 .50291 .224 .51183 .23871 .5069 .22874 .49795 Mtetra
.658 .753 .92 r
.22874 .49795 .23871 .5069 .25351 .50197 .24358 .49295 Mtetra
.654 .751 .921 r
.24358 .49295 .25351 .50197 .26837 .49721 .2585 .48808 Mtetra
.651 .749 .921 r
.2585 .48808 .26837 .49721 .28332 .4924 .2735 .48327 Mtetra
.658 .752 .92 r
.2735 .48327 .28332 .4924 .29837 .48735 .2886 .47821 Mtetra
.66 .754 .919 r
.2886 .47821 .29837 .48735 .31351 .48223 .30379 .47303 Mtetra
.656 .752 .921 r
.30379 .47303 .31351 .48223 .32872 .47738 .31906 .46799 Mtetra
.649 .747 .921 r
.31906 .46799 .32872 .47738 .34402 .47255 .33441 .46317 Mtetra
.656 .751 .92 r
.33441 .46317 .34402 .47255 .35942 .46738 .34985 .45805 Mtetra
.662 .755 .919 r
.34985 .45805 .35942 .46738 .37491 .462 .3654 .4527 Mtetra
.662 .756 .92 r
.3654 .4527 .37491 .462 .39048 .45698 .38104 .44731 Mtetra
.648 .745 .921 r
.38104 .44731 .39048 .45698 .40613 .45233 .39675 .44242 Mtetra
.647 .741 .918 r
.39675 .44242 .40613 .45233 .42188 .44714 .41255 .43752 Mtetra
.656 .752 .92 r
.41255 .43752 .42188 .44714 .43772 .44242 .42846 .43226 Mtetra
.646 .738 .916 r
.42846 .43226 .43772 .44242 .45363 .43886 .44445 .42735 Mtetra
.646 .711 .895 r
.44445 .42735 .45363 .43886 .46962 .43723 .46055 .42241 Mtetra
.638 .653 .848 r
.46055 .42241 .46962 .43723 .48573 .43547 .47674 .41758 Mtetra
.64 .615 .809 r
.47674 .41758 .48573 .43547 .50201 .43016 .49303 .4122 Mtetra
.649 .619 .806 r
.49303 .4122 .50201 .43016 .51839 .42128 .50943 .40626 Mtetra
.655 .66 .843 r
.50943 .40626 .51839 .42128 .53483 .41225 .52592 .40044 Mtetra
.663 .717 .889 r
.52592 .40044 .53483 .41225 .55135 .40515 .54251 .39458 Mtetra
.656 .741 .912 r
.54251 .39458 .55135 .40515 .56796 .39922 .55919 .38907 Mtetra
.664 .754 .917 r
.55919 .38907 .56796 .39922 .58468 .39375 .57597 .38319 Mtetra
.663 .747 .912 r
.57597 .38319 .58468 .39375 .60149 .38773 .59286 .37729 Mtetra
.65 .746 .919 r
.59286 .37729 .60149 .38773 .61841 .38209 .60985 .3719 Mtetra
.65 .753 .925 r
.60985 .3719 .61841 .38209 .63545 .37681 .62695 .36648 Mtetra
.655 .753 .922 r
.62695 .36648 .63545 .37681 .65258 .37131 .64415 .36081 Mtetra
.662 .753 .918 r
.64415 .36081 .65258 .37131 .66981 .36546 .66145 .35482 Mtetra
.656 .749 .918 r
.66145 .35482 .66981 .36546 .68714 .35962 .67886 .34906 Mtetra
.652 .751 .922 r
.67886 .34906 .68714 .35962 .70459 .35405 .69639 .34344 Mtetra
.654 .752 .922 r
.69639 .34344 .70459 .35405 .72215 .34841 .71403 .33769 Mtetra
.66 .753 .919 r
.71403 .33769 .72215 .34841 .73981 .34252 .73176 .33167 Mtetra
.657 .751 .919 r
.73176 .33167 .73981 .34252 .75758 .33656 .7496 .32571 Mtetra
.653 .751 .921 r
.7496 .32571 .75758 .33656 .77547 .33077 .76757 .31987 Mtetra
.654 .751 .921 r
.76757 .31987 .77547 .33077 .79347 .32497 .78566 .31399 Mtetra
.658 .753 .92 r
.78566 .31399 .79347 .32497 .81158 .31898 .80384 .30788 Mtetra
.657 .751 .919 r
.80384 .30788 .81158 .31898 .82979 .3129 .82214 .30176 Mtetra
.655 .751 .921 r
.17451 .50351 .18473 .51242 .19931 .50767 .18914 .49866 Mtetra
.652 .75 .921 r
.18914 .49866 .19931 .50767 .21397 .50291 .20385 .49388 Mtetra
.657 .752 .92 r
.20385 .49388 .21397 .50291 .22874 .49795 .21866 .48891 Mtetra
.659 .753 .92 r
.21866 .48891 .22874 .49795 .24358 .49295 .23355 .48385 Mtetra
.656 .752 .92 r
.23355 .48385 .24358 .49295 .2585 .48808 .24853 .47884 Mtetra
.651 .749 .921 r
.24853 .47884 .2585 .48808 .2735 .48327 .26357 .474 Mtetra
.656 .75 .92 r
.26357 .474 .2735 .48327 .2886 .47821 .27872 .46897 Mtetra
.659 .753 .92 r
.27872 .46897 .2886 .47821 .30379 .47303 .29397 .46376 Mtetra
.659 .754 .92 r
.29397 .46376 .30379 .47303 .31906 .46799 .3093 .45853 Mtetra
.651 .749 .921 r
.3093 .45853 .31906 .46799 .33441 .46317 .3247 .45359 Mtetra
.652 .747 .92 r
.3247 .45359 .33441 .46317 .34985 .45805 .34019 .44859 Mtetra
.658 .753 .92 r
.34019 .44859 .34985 .45805 .3654 .4527 .35579 .44331 Mtetra
.662 .757 .92 r
.35579 .44331 .3654 .4527 .38104 .44731 .37149 .43783 Mtetra
.659 .756 .921 r
.37149 .43783 .38104 .44731 .39675 .44242 .38727 .43244 Mtetra
.648 .742 .918 r
.38727 .43244 .39675 .44242 .41255 .43752 .40313 .42746 Mtetra
.647 .741 .918 r
.40313 .42746 .41255 .43752 .42846 .43226 .41909 .42249 Mtetra
.657 .752 .92 r
.41909 .42249 .42846 .43226 .44445 .42735 .43515 .41709 Mtetra
.655 .742 .914 r
.43515 .41709 .44445 .42735 .46055 .42241 .45131 .41175 Mtetra
.654 .735 .909 r
.45131 .41175 .46055 .42241 .47674 .41758 .46756 .40642 Mtetra
.655 .726 .901 r
.46756 .40642 .47674 .41758 .49303 .4122 .48392 .40098 Mtetra
.657 .727 .9 r
.48392 .40098 .49303 .4122 .50943 .40626 .50037 .39542 Mtetra
.657 .736 .908 r
.50037 .39542 .50943 .40626 .52592 .40044 .51692 .38987 Mtetra
.654 .742 .914 r
.51692 .38987 .52592 .40044 .54251 .39458 .53357 .38439 Mtetra
.664 .755 .918 r
.53357 .38439 .54251 .39458 .55919 .38907 .55032 .37847 Mtetra
.663 .747 .912 r
.55032 .37847 .55919 .38907 .57597 .38319 .56717 .37254 Mtetra
.652 .743 .916 r
.56717 .37254 .57597 .38319 .59286 .37729 .58413 .36704 Mtetra
.649 .752 .925 r
.58413 .36704 .59286 .37729 .60985 .3719 .60119 .36162 Mtetra
.653 .754 .924 r
.60119 .36162 .60985 .3719 .62695 .36648 .61836 .356 Mtetra
.66 .754 .92 r
.61836 .356 .62695 .36648 .64415 .36081 .63563 .35009 Mtetra
.661 .75 .917 r
.63563 .35009 .64415 .36081 .66145 .35482 .653 .34411 Mtetra
.653 .749 .92 r
.653 .34411 .66145 .35482 .67886 .34906 .67049 .33842 Mtetra
.652 .752 .922 r
.67049 .33842 .67886 .34906 .69639 .34344 .6881 .3327 Mtetra
.656 .752 .921 r
.6881 .3327 .69639 .34344 .71403 .33769 .7058 .3268 Mtetra
.66 .752 .918 r
.7058 .3268 .71403 .33769 .73176 .33167 .72361 .32069 Mtetra
.655 .75 .919 r
.72361 .32069 .73176 .33167 .7496 .32571 .74154 .31474 Mtetra
.653 .751 .921 r
.74154 .31474 .7496 .32571 .76757 .31987 .75959 .30884 Mtetra
.655 .752 .921 r
.75959 .30884 .76757 .31987 .78566 .31399 .77775 .30285 Mtetra
.659 .752 .919 r
.77775 .30285 .78566 .31399 .80384 .30788 .79601 .29664 Mtetra
.656 .751 .92 r
.79601 .29664 .80384 .30788 .82214 .30176 .81439 .2905 Mtetra
.656 .752 .92 r
.16418 .4945 .17451 .50351 .18914 .49866 .17886 .48957 Mtetra
.653 .75 .921 r
.17886 .48957 .18914 .49866 .20385 .49388 .19362 .48473 Mtetra
.655 .75 .92 r
.19362 .48473 .20385 .49388 .21866 .48891 .20847 .47977 Mtetra
.659 .753 .92 r
.20847 .47977 .21866 .48891 .23355 .48385 .22341 .47466 Mtetra
.658 .753 .92 r
.22341 .47466 .23355 .48385 .24853 .47884 .23844 .46955 Mtetra
.653 .75 .921 r
.23844 .46955 .24853 .47884 .26357 .474 .25355 .46459 Mtetra
.653 .749 .92 r
.25355 .46459 .26357 .474 .27872 .46897 .26874 .45961 Mtetra
.658 .753 .92 r
.26874 .45961 .27872 .46897 .29397 .46376 .28403 .4544 Mtetra
.66 .754 .92 r
.28403 .4544 .29397 .46376 .3093 .45853 .29942 .44909 Mtetra
.656 .753 .921 r
.29942 .44909 .3093 .45853 .3247 .45359 .31489 .44389 Mtetra
.65 .746 .92 r
.31489 .44389 .3247 .45359 .34019 .44859 .33043 .43891 Mtetra
.654 .749 .92 r
.33043 .43891 .34019 .44859 .35579 .44331 .34608 .43373 Mtetra
.659 .754 .921 r
.34608 .43373 .35579 .44331 .37149 .43783 .36183 .42834 Mtetra
.662 .758 .922 r
.36183 .42834 .37149 .43783 .38727 .43244 .37767 .4228 Mtetra
.659 .756 .921 r
.37767 .4228 .38727 .43244 .40313 .42746 .39361 .41732 Mtetra
.652 .743 .917 r
.39361 .41732 .40313 .42746 .41909 .42249 .40963 .4121 Mtetra
.65 .739 .914 r
.40963 .4121 .41909 .42249 .43515 .41709 .42574 .40693 Mtetra
.651 .746 .919 r
.42574 .40693 .43515 .41709 .45131 .41175 .44196 .40167 Mtetra
.654 .749 .92 r
.44196 .40167 .45131 .41175 .46756 .40642 .45827 .39628 Mtetra
.656 .75 .919 r
.45827 .39628 .46756 .40642 .48392 .40098 .47469 .39078 Mtetra
.658 .751 .919 r
.47469 .39078 .48392 .40098 .50037 .39542 .4912 .38515 Mtetra
.66 .751 .918 r
.4912 .38515 .50037 .39542 .51692 .38987 .50782 .37941 Mtetra
.662 .749 .915 r
.50782 .37941 .51692 .38987 .53357 .38439 .52454 .37357 Mtetra
.66 .742 .911 r
.52454 .37357 .53357 .38439 .55032 .37847 .54135 .36777 Mtetra
.652 .743 .916 r
.54135 .36777 .55032 .37847 .56717 .37254 .55828 .36224 Mtetra
.65 .752 .925 r
.55828 .36224 .56717 .37254 .58413 .36704 .5753 .35676 Mtetra
.653 .755 .925 r
.5753 .35676 .58413 .36704 .60119 .36162 .59244 .35113 Mtetra
.657 .754 .921 r
.59244 .35113 .60119 .36162 .61836 .356 .60967 .34528 Mtetra
.662 .752 .917 r
.60967 .34528 .61836 .356 .63563 .35009 .62701 .33922 Mtetra
.655 .748 .918 r
.62701 .33922 .63563 .35009 .653 .34411 .64446 .33339 Mtetra
.652 .751 .922 r
.64446 .33339 .653 .34411 .67049 .33842 .66203 .32766 Mtetra
.654 .752 .922 r
.66203 .32766 .67049 .33842 .6881 .3327 .6797 .32182 Mtetra
.659 .753 .92 r
.6797 .32182 .6881 .3327 .7058 .3268 .69748 .31574 Mtetra
.659 .751 .918 r
.69748 .31574 .7058 .3268 .72361 .32069 .71537 .30963 Mtetra
.654 .75 .921 r
.71537 .30963 .72361 .32069 .74154 .31474 .73338 .30366 Mtetra
.653 .751 .922 r
.73338 .30366 .74154 .31474 .75959 .30884 .75151 .29769 Mtetra
.656 .752 .921 r
.75151 .29769 .75959 .30884 .77775 .30285 .76974 .29155 Mtetra
.659 .752 .919 r
.76974 .29155 .77775 .30285 .79601 .29664 .78809 .28528 Mtetra
.655 .751 .92 r
.78809 .28528 .79601 .29664 .81439 .2905 .80656 .2791 Mtetra
.657 .752 .92 r
.15373 .48542 .16418 .4945 .17886 .48957 .16847 .4804 Mtetra
.654 .751 .921 r
.16847 .4804 .17886 .48957 .19362 .48473 .18328 .47546 Mtetra
.653 .75 .921 r
.18328 .47546 .19362 .48473 .20847 .47977 .19817 .47052 Mtetra
.658 .752 .92 r
.19817 .47052 .20847 .47977 .22341 .47466 .21317 .46538 Mtetra
.658 .753 .92 r
.21317 .46538 .22341 .47466 .23844 .46955 .22825 .4602 Mtetra
.656 .752 .921 r
.22825 .4602 .23844 .46955 .25355 .46459 .24341 .45507 Mtetra
.651 .748 .921 r
.24341 .45507 .25355 .46459 .26874 .45961 .25865 .45009 Mtetra
.655 .75 .92 r
.25865 .45009 .26874 .45961 .28403 .4544 .27399 .44492 Mtetra
.659 .754 .92 r
.27399 .44492 .28403 .4544 .29942 .44909 .28943 .43959 Mtetra
.659 .755 .92 r
.28943 .43959 .29942 .44909 .31489 .44389 .30496 .43421 Mtetra
.654 .751 .921 r
.30496 .43421 .31489 .44389 .33043 .43891 .32057 .429 Mtetra
.65 .746 .919 r
.32057 .429 .33043 .43891 .34608 .43373 .33626 .42392 Mtetra
.655 .75 .92 r
.33626 .42392 .34608 .43373 .36183 .42834 .35206 .41862 Mtetra
.658 .754 .921 r
.35206 .41862 .36183 .42834 .37767 .4228 .36796 .41317 Mtetra
.66 .758 .923 r
.36796 .41317 .37767 .4228 .39361 .41732 .38396 .4076 Mtetra
.66 .757 .922 r
.38396 .4076 .39361 .41732 .40963 .4121 .40005 .40201 Mtetra
.658 .75 .918 r
.40005 .40201 .40963 .4121 .42574 .40693 .41623 .39647 Mtetra
.655 .743 .914 r
.41623 .39647 .42574 .40693 .44196 .40167 .43251 .39102 Mtetra
.654 .74 .912 r
.43251 .39102 .44196 .40167 .45827 .39628 .44889 .38554 Mtetra
.656 .74 .911 r
.44889 .38554 .45827 .39628 .47469 .39078 .46536 .37997 Mtetra
.657 .74 .911 r
.46536 .37997 .47469 .39078 .4912 .38515 .48194 .37432 Mtetra
.657 .741 .912 r
.48194 .37432 .4912 .38515 .50782 .37941 .49862 .36864 Mtetra
.654 .742 .915 r
.49862 .36864 .50782 .37941 .52454 .37357 .5154 .36304 Mtetra
.652 .748 .92 r
.5154 .36304 .52454 .37357 .54135 .36777 .53229 .35749 Mtetra
.651 .755 .925 r
.53229 .35749 .54135 .36777 .55828 .36224 .54928 .35193 Mtetra
.653 .756 .925 r
.54928 .35193 .55828 .36224 .5753 .35676 .56637 .34624 Mtetra
.657 .754 .922 r
.56637 .34624 .5753 .35676 .59244 .35113 .58357 .34039 Mtetra
.661 .752 .918 r
.58357 .34039 .59244 .35113 .60967 .34528 .60088 .33432 Mtetra
.657 .748 .917 r
.60088 .33432 .60967 .34528 .62701 .33922 .61829 .32837 Mtetra
.652 .75 .921 r
.61829 .32837 .62701 .33922 .64446 .33339 .63582 .32259 Mtetra
.653 .753 .923 r
.63582 .32259 .64446 .33339 .66203 .32766 .65346 .31675 Mtetra
.656 .753 .921 r
.65346 .31675 .66203 .32766 .6797 .32182 .67121 .31075 Mtetra
.66 .752 .918 r
.67121 .31075 .6797 .32182 .69748 .31574 .68906 .30454 Mtetra
.656 .749 .919 r
.68906 .30454 .69748 .31574 .71537 .30963 .70703 .29847 Mtetra
.653 .751 .921 r
.70703 .29847 .71537 .30963 .73338 .30366 .72512 .29246 Mtetra
.654 .752 .922 r
.72512 .29246 .73338 .30366 .75151 .29769 .74333 .2864 Mtetra
.658 .753 .92 r
.74333 .2864 .75151 .29769 .76974 .29155 .76164 .28011 Mtetra
.657 .751 .919 r
.76164 .28011 .76974 .29155 .78809 .28528 .78007 .27381 Mtetra
.655 .751 .921 r
.78007 .27381 .78809 .28528 .80656 .2791 .79863 .26759 Mtetra
.658 .753 .92 r
.14318 .47625 .15373 .48542 .16847 .4804 .15797 .47115 Mtetra
.656 .752 .92 r
.15797 .47115 .16847 .4804 .18328 .47546 .17283 .46609 Mtetra
.653 .749 .921 r
.17283 .46609 .18328 .47546 .19817 .47052 .18777 .46112 Mtetra
.656 .751 .92 r
.18777 .46112 .19817 .47052 .21317 .46538 .20281 .45601 Mtetra
.658 .753 .92 r
.20281 .45601 .21317 .46538 .22825 .4602 .21794 .45076 Mtetra
.21794 .45076 .22825 .4602 .24341 .45507 .23316 .44552 Mtetra
.654 .75 .921 r
.23316 .44552 .24341 .45507 .25865 .45009 .24846 .44039 Mtetra
.652 .748 .92 r
.24846 .44039 .25865 .45009 .27399 .44492 .26384 .4353 Mtetra
.657 .752 .92 r
.26384 .4353 .27399 .44492 .28943 .43959 .27933 .42998 Mtetra
.659 .754 .92 r
.27933 .42998 .28943 .43959 .30496 .43421 .29492 .42456 Mtetra
.659 .755 .921 r
.29492 .42456 .30496 .43421 .32057 .429 .3106 .41911 Mtetra
.654 .749 .92 r
.3106 .41911 .32057 .429 .33626 .42392 .32635 .41382 Mtetra
.651 .745 .919 r
.32635 .41382 .33626 .42392 .35206 .41862 .3422 .40862 Mtetra
.654 .749 .92 r
.3422 .40862 .35206 .41862 .36796 .41317 .35815 .40327 Mtetra
.657 .754 .921 r
.35815 .40327 .36796 .41317 .38396 .4076 .3742 .39777 Mtetra
.658 .757 .923 r
.3742 .39777 .38396 .4076 .40005 .40201 .39035 .3922 Mtetra
.658 .759 .924 r
.39035 .3922 .40005 .40201 .41623 .39647 .4066 .38656 Mtetra
.658 .758 .924 r
.4066 .38656 .41623 .39647 .43251 .39102 .42294 .38092 Mtetra
.657 .755 .922 r
.42294 .38092 .43251 .39102 .44889 .38554 .43939 .37528 Mtetra
.656 .752 .921 r
.43939 .37528 .44889 .38554 .46536 .37997 .45593 .36965 Mtetra
.655 .752 .921 r
.45593 .36965 .46536 .37997 .48194 .37432 .47257 .36403 Mtetra
.654 .754 .923 r
.47257 .36403 .48194 .37432 .49862 .36864 .48931 .35842 Mtetra
.653 .756 .925 r
.48931 .35842 .49862 .36864 .5154 .36304 .50616 .35279 Mtetra
.654 .757 .926 r
.50616 .35279 .5154 .36304 .53229 .35749 .52311 .3471 Mtetra
.655 .756 .924 r
.52311 .3471 .53229 .35749 .54928 .35193 .54017 .34134 Mtetra
.658 .754 .921 r
.54017 .34134 .54928 .35193 .56637 .34624 .55734 .33542 Mtetra
.661 .752 .918 r
.55734 .33542 .56637 .34624 .58357 .34039 .57461 .32935 Mtetra
.658 .747 .916 r
.57461 .32935 .58357 .34039 .60088 .33432 .59199 .32336 Mtetra
.653 .749 .92 r
.59199 .32336 .60088 .33432 .61829 .32837 .60948 .31752 Mtetra
.653 .753 .923 r
.60948 .31752 .61829 .32837 .63582 .32259 .62708 .31166 Mtetra
.654 .753 .922 r
.62708 .31166 .63582 .32259 .65346 .31675 .64479 .30569 Mtetra
.659 .753 .92 r
.64479 .30569 .65346 .31675 .67121 .31075 .66261 .29947 Mtetra
.658 .75 .918 r
.66261 .29947 .67121 .31075 .68906 .30454 .68054 .29328 Mtetra
.654 .75 .92 r
.68054 .29328 .68906 .30454 .70703 .29847 .6986 .28721 Mtetra
.653 .751 .922 r
.6986 .28721 .70703 .29847 .72512 .29246 .71677 .28113 Mtetra
.656 .753 .921 r
.71677 .28113 .72512 .29246 .74333 .2864 .73505 .27491 Mtetra
.659 .752 .919 r
.73505 .27491 .74333 .2864 .76164 .28011 .75345 .26852 Mtetra
.656 .75 .919 r
.75345 .26852 .76164 .28011 .78007 .27381 .77197 .26222 Mtetra
.654 .751 .921 r
.77197 .26222 .78007 .27381 .79863 .26759 .79061 .25595 Mtetra
.658 .753 .92 r
.13251 .46698 .14318 .47625 .15797 .47115 .14735 .46181 Mtetra
.657 .752 .92 r
.14735 .46181 .15797 .47115 .17283 .46609 .16227 .45666 Mtetra
.654 .751 .921 r
.16227 .45666 .17283 .46609 .18777 .46112 .17726 .45159 Mtetra
.653 .749 .92 r
.17726 .45159 .18777 .46112 .20281 .45601 .19234 .44651 Mtetra
.658 .753 .92 r
.19234 .44651 .20281 .45601 .21794 .45076 .20752 .44124 Mtetra
.20752 .44124 .21794 .45076 .23316 .44552 .2228 .43592 Mtetra
.657 .753 .92 r
.2228 .43592 .23316 .44552 .24846 .44039 .23816 .43061 Mtetra
.652 .749 .92 r
.23816 .43061 .24846 .44039 .26384 .4353 .2536 .42544 Mtetra
.653 .748 .92 r
.2536 .42544 .26384 .4353 .27933 .42998 .26913 .42022 Mtetra
.657 .753 .92 r
.26913 .42022 .27933 .42998 .29492 .42456 .28477 .4148 Mtetra
.659 .755 .921 r
.28477 .4148 .29492 .42456 .3106 .41911 .3005 .4093 Mtetra
.3005 .4093 .3106 .41911 .32635 .41382 .31633 .40377 Mtetra
.655 .75 .919 r
.31633 .40377 .32635 .41382 .3422 .40862 .33224 .39833 Mtetra
.652 .745 .918 r
.33224 .39833 .3422 .40862 .35815 .40327 .34824 .393 Mtetra
.652 .747 .919 r
.34824 .393 .35815 .40327 .3742 .39777 .36434 .38761 Mtetra
.655 .751 .921 r
.36434 .38761 .3742 .39777 .39035 .3922 .38055 .38209 Mtetra
.656 .754 .922 r
.38055 .38209 .39035 .3922 .4066 .38656 .39686 .37648 Mtetra
.656 .756 .923 r
.39686 .37648 .4066 .38656 .42294 .38092 .41326 .37083 Mtetra
.656 .757 .924 r
.41326 .37083 .42294 .38092 .43939 .37528 .42977 .36516 Mtetra
.656 .758 .925 r
.42977 .36516 .43939 .37528 .45593 .36965 .44638 .35946 Mtetra
.655 .758 .925 r
.44638 .35946 .45593 .36965 .47257 .36403 .46308 .35375 Mtetra
.655 .757 .925 r
.46308 .35375 .47257 .36403 .48931 .35842 .4799 .34802 Mtetra
.655 .756 .924 r
.4799 .34802 .48931 .35842 .50616 .35279 .49681 .34224 Mtetra
.656 .754 .922 r
.49681 .34224 .50616 .35279 .52311 .3471 .51384 .33637 Mtetra
.659 .753 .919 r
.51384 .33637 .52311 .3471 .54017 .34134 .53097 .33036 Mtetra
.66 .749 .916 r
.53097 .33036 .54017 .34134 .55734 .33542 .5482 .3243 Mtetra
.656 .746 .916 r
.5482 .3243 .55734 .33542 .57461 .32935 .56554 .31834 Mtetra
.653 .749 .92 r
.56554 .31834 .57461 .32935 .59199 .32336 .583 .31246 Mtetra
.653 .753 .923 r
.583 .31246 .59199 .32336 .60948 .31752 .60056 .30655 Mtetra
.654 .753 .923 r
.60056 .30655 .60948 .31752 .62708 .31166 .61824 .30056 Mtetra
.658 .753 .92 r
.61824 .30056 .62708 .31166 .64479 .30569 .63602 .29435 Mtetra
.659 .75 .918 r
.63602 .29435 .64479 .30569 .66261 .29947 .65392 .28809 Mtetra
.655 .749 .919 r
.65392 .28809 .66261 .29947 .68054 .29328 .67193 .28195 Mtetra
.653 .751 .922 r
.67193 .28195 .68054 .29328 .6986 .28721 .69007 .27584 Mtetra
.654 .752 .922 r
.69007 .27584 .6986 .28721 .71677 .28113 .70832 .26965 Mtetra
.658 .753 .92 r
.70832 .26965 .71677 .28113 .73505 .27491 .72668 .26325 Mtetra
.657 .751 .919 r
.72668 .26325 .73505 .27491 .75345 .26852 .74516 .25685 Mtetra
.655 .751 .92 r
.74516 .25685 .75345 .26852 .77197 .26222 .76376 .2505 Mtetra
.654 .751 .921 r
.76376 .2505 .77197 .26222 .79061 .25595 .7825 .24417 Mtetra
.657 .752 .92 r
.12173 .45759 .13251 .46698 .14735 .46181 .13661 .45239 Mtetra
.658 .753 .92 r
.13661 .45239 .14735 .46181 .16227 .45666 .15158 .44716 Mtetra
.656 .752 .92 r
.15158 .44716 .16227 .45666 .17726 .45159 .16664 .44195 Mtetra
.653 .749 .92 r
.16664 .44195 .17726 .45159 .19234 .44651 .18176 .43683 Mtetra
.655 .75 .92 r
.18176 .43683 .19234 .44651 .20752 .44124 .19699 .43161 Mtetra
.658 .753 .92 r
.19699 .43161 .20752 .44124 .2228 .43592 .21232 .42624 Mtetra
.21232 .42624 .2228 .43592 .23816 .43061 .22773 .42084 Mtetra
.656 .752 .92 r
.22773 .42084 .23816 .43061 .2536 .42544 .24324 .41546 Mtetra
.652 .748 .92 r
.24324 .41546 .2536 .42544 .26913 .42022 .25882 .41021 Mtetra
.653 .749 .92 r
.25882 .41021 .26913 .42022 .28477 .4148 .2745 .40489 Mtetra
.657 .753 .921 r
.2745 .40489 .28477 .4148 .3005 .4093 .29029 .39938 Mtetra
.658 .755 .921 r
.29029 .39938 .3005 .4093 .31633 .40377 .30617 .39381 Mtetra
.30617 .39381 .31633 .40377 .33224 .39833 .32215 .38819 Mtetra
.657 .752 .92 r
.32215 .38819 .33224 .39833 .34824 .393 .33823 .38258 Mtetra
.654 .747 .918 r
.33823 .38258 .34824 .393 .36434 .38761 .35439 .37706 Mtetra
.653 .745 .917 r
.35439 .37706 .36434 .38761 .38055 .38209 .37065 .37155 Mtetra
.654 .747 .918 r
.37065 .37155 .38055 .38209 .39686 .37648 .38701 .36598 Mtetra
.654 .749 .919 r
.38701 .36598 .39686 .37648 .41326 .37083 .40348 .36035 Mtetra
.655 .751 .92 r
.40348 .36035 .41326 .37083 .42977 .36516 .42005 .35465 Mtetra
.656 .752 .921 r
.42005 .35465 .42977 .36516 .44638 .35946 .43672 .34889 Mtetra
.43672 .34889 .44638 .35946 .46308 .35375 .4535 .34308 Mtetra
.657 .752 .92 r
.4535 .34308 .46308 .35375 .4799 .34802 .47038 .33719 Mtetra
.658 .75 .918 r
.47038 .33719 .4799 .34802 .49681 .34224 .48736 .33124 Mtetra
.658 .748 .916 r
.48736 .33124 .49681 .34224 .51384 .33637 .50445 .32523 Mtetra
.657 .746 .916 r
.50445 .32523 .51384 .33637 .53097 .33036 .52165 .31923 Mtetra
.654 .747 .918 r
.52165 .31923 .53097 .33036 .5482 .3243 .53896 .31331 Mtetra
.653 .751 .921 r
.53896 .31331 .5482 .3243 .56554 .31834 .55637 .3074 Mtetra
.653 .753 .923 r
.55637 .3074 .56554 .31834 .583 .31246 .5739 .30144 Mtetra
.654 .754 .923 r
.5739 .30144 .583 .31246 .60056 .30655 .59154 .2954 Mtetra
.658 .754 .92 r
.59154 .2954 .60056 .30655 .61824 .30056 .60928 .28918 Mtetra
.659 .751 .918 r
.60928 .28918 .61824 .30056 .63602 .29435 .62714 .28287 Mtetra
.655 .749 .919 r
.62714 .28287 .63602 .29435 .65392 .28809 .64512 .27668 Mtetra
.654 .751 .921 r
.64512 .27668 .65392 .28809 .67193 .28195 .66322 .27052 Mtetra
.654 .752 .922 r
.66322 .27052 .67193 .28195 .69007 .27584 .68143 .26431 Mtetra
.657 .753 .921 r
.68143 .26431 .69007 .27584 .70832 .26965 .69976 .25794 Mtetra
.658 .751 .919 r
.69976 .25794 .70832 .26965 .72668 .26325 .7182 .25146 Mtetra
.656 .75 .919 r
.7182 .25146 .72668 .26325 .74516 .25685 .73677 .24505 Mtetra
.654 .751 .921 r
.73677 .24505 .74516 .25685 .76376 .2505 .75546 .23867 Mtetra
.654 .752 .921 r
.75546 .23867 .76376 .2505 .7825 .24417 .77428 .23224 Mtetra
.655 .751 .92 r
.11084 .44805 .12173 .45759 .13661 .45239 .12576 .44288 Mtetra
.658 .753 .92 r
.12576 .44288 .13661 .45239 .15158 .44716 .14078 .43757 Mtetra
.657 .752 .92 r
.14078 .43757 .15158 .44716 .16664 .44195 .15589 .43227 Mtetra
.655 .751 .921 r
.15589 .43227 .16664 .44195 .18176 .43683 .17108 .42702 Mtetra
.653 .749 .92 r
.17108 .42702 .18176 .43683 .19699 .43161 .18635 .42181 Mtetra
.656 .751 .92 r
.18635 .42181 .19699 .43161 .21232 .42624 .20172 .41646 Mtetra
.658 .753 .92 r
.20172 .41646 .21232 .42624 .22773 .42084 .21719 .411 Mtetra
.658 .753 .921 r
.21719 .411 .22773 .42084 .24324 .41546 .23275 .40551 Mtetra
.656 .752 .92 r
.23275 .40551 .24324 .41546 .25882 .41021 .2484 .40005 Mtetra
.653 .748 .919 r
.2484 .40005 .25882 .41021 .2745 .40489 .26414 .39469 Mtetra
.653 .748 .92 r
.26414 .39469 .2745 .40489 .29029 .39938 .27997 .38929 Mtetra
.657 .753 .921 r
.27997 .38929 .29029 .39938 .30617 .39381 .29591 .38371 Mtetra
.657 .754 .921 r
.29591 .38371 .30617 .39381 .32215 .38819 .31194 .37807 Mtetra
.658 .755 .922 r
.31194 .37807 .32215 .38819 .33823 .38258 .32808 .37238 Mtetra
.32808 .37238 .33823 .38258 .35439 .37706 .34431 .36666 Mtetra
.657 .752 .92 r
.34431 .36666 .35439 .37706 .37065 .37155 .36064 .36093 Mtetra
.656 .748 .918 r
.36064 .36093 .37065 .37155 .38701 .36598 .37707 .3552 Mtetra
.655 .746 .917 r
.37707 .3552 .38701 .36598 .40348 .36035 .3936 .34947 Mtetra
.655 .745 .916 r
.3936 .34947 .40348 .36035 .42005 .35465 .41023 .3437 Mtetra
.656 .745 .916 r
.41023 .3437 .42005 .35465 .43672 .34889 .42697 .33788 Mtetra
.42697 .33788 .43672 .34889 .4535 .34308 .44381 .33199 Mtetra
.656 .746 .916 r
.44381 .33199 .4535 .34308 .47038 .33719 .46075 .32608 Mtetra
.655 .746 .916 r
.46075 .32608 .47038 .33719 .48736 .33124 .4778 .32016 Mtetra
.655 .748 .918 r
.4778 .32016 .48736 .33124 .50445 .32523 .49496 .31423 Mtetra
.654 .751 .921 r
.49496 .31423 .50445 .32523 .52165 .31923 .51223 .3083 Mtetra
.654 .753 .923 r
.51223 .3083 .52165 .31923 .53896 .31331 .5296 .30233 Mtetra
.654 .754 .923 r
.5296 .30233 .53896 .31331 .55637 .3074 .54709 .29631 Mtetra
.655 .754 .922 r
.54709 .29631 .55637 .3074 .5739 .30144 .56469 .29022 Mtetra
.658 .754 .92 r
.56469 .29022 .5739 .30144 .59154 .2954 .5824 .28395 Mtetra
.659 .75 .918 r
.5824 .28395 .59154 .2954 .60928 .28918 .60023 .27762 Mtetra
.655 .748 .918 r
.60023 .27762 .60928 .28918 .62714 .28287 .61817 .27139 Mtetra
.654 .751 .921 r
.61817 .27139 .62714 .28287 .64512 .27668 .63622 .26518 Mtetra
.654 .752 .922 r
.63622 .26518 .64512 .27668 .66322 .27052 .6544 .25895 Mtetra
.656 .753 .921 r
.6544 .25895 .66322 .27052 .68143 .26431 .67269 .25258 Mtetra
.658 .752 .919 r
.67269 .25258 .68143 .26431 .69976 .25794 .6911 .24606 Mtetra
.656 .75 .919 r
.6911 .24606 .69976 .25794 .7182 .25146 .70962 .23958 Mtetra
.655 .751 .921 r
.70962 .23958 .7182 .25146 .73677 .24505 .72828 .23314 Mtetra
.654 .751 .921 r
.72828 .23314 .73677 .24505 .75546 .23867 .74706 .22669 Mtetra
.656 .753 .921 r
.74706 .22669 .75546 .23867 .77428 .23224 .76596 .22009 Mtetra
.654 .75 .92 r
.09983 .43839 .11084 .44805 .12576 .44288 .1148 .43321 Mtetra
.657 .752 .92 r
.1148 .43321 .12576 .44288 .14078 .43757 .12986 .4279 Mtetra
.658 .753 .92 r
.12986 .4279 .14078 .43757 .15589 .43227 .14502 .42252 Mtetra
.657 .752 .92 r
.14502 .42252 .15589 .43227 .17108 .42702 .16027 .41714 Mtetra
.654 .75 .92 r
.16027 .41714 .17108 .42702 .18635 .42181 .1756 .41182 Mtetra
.653 .749 .92 r
.1756 .41182 .18635 .42181 .20172 .41646 .19101 .40651 Mtetra
.656 .752 .92 r
.19101 .40651 .20172 .41646 .21719 .411 .20653 .40106 Mtetra
.658 .754 .921 r
.20653 .40106 .21719 .411 .23275 .40551 .22215 .3955 Mtetra
.658 .753 .921 r
.22215 .3955 .23275 .40551 .2484 .40005 .23786 .38993 Mtetra
.656 .752 .92 r
.23786 .38993 .2484 .40005 .26414 .39469 .25366 .38436 Mtetra
.653 .748 .919 r
.25366 .38436 .26414 .39469 .27997 .38929 .26955 .37888 Mtetra
.653 .747 .919 r
.26955 .37888 .27997 .38929 .29591 .38371 .28553 .37337 Mtetra
.655 .751 .92 r
.28553 .37337 .29591 .38371 .31194 .37807 .30162 .36777 Mtetra
.657 .754 .921 r
.30162 .36777 .31194 .37807 .32808 .37238 .31781 .36206 Mtetra
.657 .755 .922 r
.31781 .36206 .32808 .37238 .34431 .36666 .33411 .35631 Mtetra
.33411 .35631 .34431 .36666 .36064 .36093 .3505 .35051 Mtetra
.3505 .35051 .36064 .36093 .37707 .3552 .36699 .34468 Mtetra
.657 .754 .922 r
.36699 .34468 .37707 .3552 .3936 .34947 .38359 .33883 Mtetra
.656 .753 .921 r
.38359 .33883 .3936 .34947 .41023 .3437 .40029 .33296 Mtetra
.656 .752 .921 r
.40029 .33296 .41023 .3437 .42697 .33788 .41709 .32707 Mtetra
.655 .752 .921 r
.41709 .32707 .42697 .33788 .44381 .33199 .43399 .32116 Mtetra
.655 .753 .922 r
.43399 .32116 .44381 .33199 .46075 .32608 .45101 .31523 Mtetra
.655 .754 .923 r
.45101 .31523 .46075 .32608 .4778 .32016 .46813 .30927 Mtetra
.46813 .30927 .4778 .32016 .49496 .31423 .48535 .30328 Mtetra
.48535 .30328 .49496 .31423 .51223 .3083 .50269 .29724 Mtetra
.50269 .29724 .51223 .3083 .5296 .30233 .52014 .29116 Mtetra
.657 .754 .921 r
.52014 .29116 .5296 .30233 .54709 .29631 .5377 .28496 Mtetra
.658 .752 .919 r
.5377 .28496 .54709 .29631 .56469 .29022 .55538 .27866 Mtetra
.658 .749 .917 r
.55538 .27866 .56469 .29022 .5824 .28395 .57316 .27233 Mtetra
.655 .748 .919 r
.57316 .27233 .5824 .28395 .60023 .27762 .59106 .26608 Mtetra
.654 .751 .921 r
.59106 .26608 .60023 .27762 .61817 .27139 .60908 .25984 Mtetra
.654 .752 .922 r
.60908 .25984 .61817 .27139 .63622 .26518 .62722 .25356 Mtetra
.655 .753 .922 r
.62722 .25356 .63622 .26518 .6544 .25895 .64547 .24717 Mtetra
.658 .753 .92 r
.64547 .24717 .6544 .25895 .67269 .25258 .66384 .24063 Mtetra
.657 .75 .919 r
.66384 .24063 .67269 .25258 .6911 .24606 .68233 .23409 Mtetra
.655 .75 .92 r
.68233 .23409 .6911 .24606 .70962 .23958 .70095 .22759 Mtetra
.654 .751 .921 r
.70095 .22759 .70962 .23958 .72828 .23314 .71969 .2211 Mtetra
.655 .752 .921 r
.71969 .2211 .72828 .23314 .74706 .22669 .73855 .21452 Mtetra
.658 .752 .92 r
.73855 .21452 .74706 .22669 .76596 .22009 .75753 .20779 Mtetra
.654 .75 .92 r
.08871 .42864 .09983 .43839 .1148 .43321 .10372 .42339 Mtetra
.10372 .42339 .1148 .43321 .12986 .4279 .11882 .41811 Mtetra
.657 .753 .92 r
.11882 .41811 .12986 .4279 .14502 .42252 .13403 .41268 Mtetra
.658 .753 .92 r
.13403 .41268 .14502 .42252 .16027 .41714 .14933 .40721 Mtetra
.656 .752 .92 r
.14933 .40721 .16027 .41714 .1756 .41182 .16472 .40176 Mtetra
.654 .75 .92 r
.16472 .40176 .1756 .41182 .19101 .40651 .18019 .39635 Mtetra
.653 .749 .92 r
.18019 .39635 .19101 .40651 .20653 .40106 .19575 .39094 Mtetra
.656 .752 .92 r
.19575 .39094 .20653 .40106 .22215 .3955 .21142 .3854 Mtetra
.658 .754 .921 r
.21142 .3854 .22215 .3955 .23786 .38993 .22719 .37976 Mtetra
.22719 .37976 .23786 .38993 .25366 .38436 .24305 .37409 Mtetra
.657 .753 .921 r
.24305 .37409 .25366 .38436 .26955 .37888 .25901 .36841 Mtetra
.655 .749 .919 r
.25901 .36841 .26955 .37888 .28553 .37337 .27505 .36276 Mtetra
.653 .747 .919 r
.27505 .36276 .28553 .37337 .30162 .36777 .2912 .35715 Mtetra
.654 .748 .919 r
.2912 .35715 .30162 .36777 .31781 .36206 .30744 .35148 Mtetra
.655 .751 .921 r
.30744 .35148 .31781 .36206 .33411 .35631 .32379 .34575 Mtetra
.656 .753 .921 r
.32379 .34575 .33411 .35631 .3505 .35051 .34024 .33993 Mtetra
.656 .754 .922 r
.34024 .33993 .3505 .35051 .36699 .34468 .3568 .33406 Mtetra
.656 .755 .922 r
.3568 .33406 .36699 .34468 .38359 .33883 .37346 .32816 Mtetra
.656 .755 .923 r
.37346 .32816 .38359 .33883 .40029 .33296 .39022 .32223 Mtetra
.39022 .32223 .40029 .33296 .41709 .32707 .40709 .31627 Mtetra
.40709 .31627 .41709 .32707 .43399 .32116 .42406 .31028 Mtetra
.655 .755 .923 r
.42406 .31028 .43399 .32116 .45101 .31523 .44114 .30426 Mtetra
.655 .754 .923 r
.44114 .30426 .45101 .31523 .46813 .30927 .45833 .29821 Mtetra
.656 .754 .922 r
.45833 .29821 .46813 .30927 .48535 .30328 .47563 .29211 Mtetra
.657 .754 .921 r
.47563 .29211 .48535 .30328 .50269 .29724 .49305 .28591 Mtetra
.658 .752 .92 r
.49305 .28591 .50269 .29724 .52014 .29116 .51057 .27964 Mtetra
.658 .75 .918 r
.51057 .27964 .52014 .29116 .5377 .28496 .5282 .27332 Mtetra
.656 .748 .918 r
.5282 .27332 .5377 .28496 .55538 .27866 .54595 .26703 Mtetra
.655 .749 .919 r
.54595 .26703 .55538 .27866 .57316 .27233 .56381 .26076 Mtetra
.654 .752 .921 r
.56381 .26076 .57316 .27233 .59106 .26608 .58179 .25447 Mtetra
.654 .752 .922 r
.58179 .25447 .59106 .26608 .60908 .25984 .59989 .24815 Mtetra
.656 .753 .922 r
.59989 .24815 .60908 .25984 .62722 .25356 .6181 .24172 Mtetra
.658 .753 .92 r
.6181 .24172 .62722 .25356 .64547 .24717 .63643 .23515 Mtetra
.657 .75 .918 r
.63643 .23515 .64547 .24717 .66384 .24063 .65488 .22857 Mtetra
.655 .75 .92 r
.65488 .22857 .66384 .24063 .68233 .23409 .67346 .22203 Mtetra
.654 .751 .921 r
.67346 .22203 .68233 .23409 .70095 .22759 .69216 .21549 Mtetra
.654 .752 .922 r
.69216 .21549 .70095 .22759 .71969 .2211 .71099 .2089 Mtetra
.657 .753 .92 r
.71099 .2089 .71969 .2211 .73855 .21452 .72993 .20214 Mtetra
.657 .751 .919 r
.72993 .20214 .73855 .21452 .75753 .20779 .749 .19534 Mtetra
.655 .751 .92 r
.07745 .41881 .08871 .42864 .10372 .42339 .09252 .41346 Mtetra
.654 .75 .92 r
.09252 .41346 .10372 .42339 .11882 .41811 .10767 .40813 Mtetra
.655 .75 .92 r
.10767 .40813 .11882 .41811 .13403 .41268 .12292 .40274 Mtetra
.657 .753 .92 r
.12292 .40274 .13403 .41268 .14933 .40721 .13827 .39721 Mtetra
.13827 .39721 .14933 .40721 .16472 .40176 .15372 .39165 Mtetra
.656 .752 .92 r
.15372 .39165 .16472 .40176 .18019 .39635 .16925 .38611 Mtetra
.654 .75 .92 r
.16925 .38611 .18019 .39635 .19575 .39094 .18487 .3806 Mtetra
.653 .749 .92 r
.18487 .3806 .19575 .39094 .21142 .3854 .20058 .37509 Mtetra
.655 .751 .92 r
.20058 .37509 .21142 .3854 .22719 .37976 .2164 .36947 Mtetra
.657 .754 .921 r
.2164 .36947 .22719 .37976 .24305 .37409 .23231 .36375 Mtetra
.23231 .36375 .24305 .37409 .25901 .36841 .24833 .35799 Mtetra
.657 .753 .921 r
.24833 .35799 .25901 .36841 .27505 .36276 .26444 .3522 Mtetra
.656 .752 .92 r
.26444 .3522 .27505 .36276 .2912 .35715 .28066 .34641 Mtetra
.655 .749 .919 r
.28066 .34641 .2912 .35715 .30744 .35148 .29696 .34061 Mtetra
.654 .747 .918 r
.29696 .34061 .30744 .35148 .32379 .34575 .31337 .33483 Mtetra
.654 .748 .918 r
.31337 .33483 .32379 .34575 .34024 .33993 .32988 .329 Mtetra
.655 .749 .919 r
.32988 .329 .34024 .33993 .3568 .33406 .3465 .32313 Mtetra
.655 .75 .92 r
.3465 .32313 .3568 .33406 .37346 .32816 .36322 .3172 Mtetra
.655 .751 .92 r
.36322 .3172 .37346 .32816 .39022 .32223 .38005 .31122 Mtetra
.656 .752 .921 r
.38005 .31122 .39022 .32223 .40709 .31627 .39698 .30519 Mtetra
.656 .752 .92 r
.39698 .30519 .40709 .31627 .42406 .31028 .41402 .29911 Mtetra
.41402 .29911 .42406 .31028 .44114 .30426 .43117 .29298 Mtetra
.657 .751 .919 r
.43117 .29298 .44114 .30426 .45833 .29821 .44843 .28679 Mtetra
.657 .75 .918 r
.44843 .28679 .45833 .29821 .47563 .29211 .4658 .28056 Mtetra
.657 .749 .917 r
.4658 .28056 .47563 .29211 .49305 .28591 .48329 .27427 Mtetra
.656 .748 .917 r
.48329 .27427 .49305 .28591 .51057 .27964 .50088 .26799 Mtetra
.655 .749 .919 r
.50088 .26799 .51057 .27964 .5282 .27332 .51859 .26171 Mtetra
.655 .751 .921 r
.51859 .26171 .5282 .27332 .54595 .26703 .53641 .25542 Mtetra
.654 .752 .922 r
.53641 .25542 .54595 .26703 .56381 .26076 .55435 .24909 Mtetra
.654 .753 .922 r
.55435 .24909 .56381 .26076 .58179 .25447 .57241 .24272 Mtetra
.656 .753 .921 r
.57241 .24272 .58179 .25447 .59989 .24815 .59058 .23623 Mtetra
.658 .752 .92 r
.59058 .23623 .59989 .24815 .6181 .24172 .60887 .22963 Mtetra
.657 .75 .918 r
.60887 .22963 .6181 .24172 .63643 .23515 .62729 .22302 Mtetra
.655 .75 .919 r
.62729 .22302 .63643 .23515 .65488 .22857 .64582 .21644 Mtetra
.654 .751 .921 r
.64582 .21644 .65488 .22857 .67346 .22203 .66448 .20986 Mtetra
.654 .752 .922 r
.66448 .20986 .67346 .22203 .69216 .21549 .68327 .20324 Mtetra
.657 .753 .921 r
.68327 .20324 .69216 .21549 .71099 .2089 .70218 .19646 Mtetra
.657 .751 .919 r
.70218 .19646 .71099 .2089 .72993 .20214 .72121 .18961 Mtetra
.656 .75 .919 r
.72121 .18961 .72993 .20214 .749 .19534 .74037 .18278 Mtetra
.656 .752 .92 r
.06607 .4089 .07745 .41881 .09252 .41346 .08119 .40345 Mtetra
.655 .751 .92 r
.08119 .40345 .09252 .41346 .10767 .40813 .0964 .39801 Mtetra
.654 .75 .92 r
.0964 .39801 .10767 .40813 .12292 .40274 .1117 .39259 Mtetra
.655 .751 .92 r
.1117 .39259 .12292 .40274 .13827 .39721 .12709 .3871 Mtetra
.657 .753 .921 r
.12709 .3871 .13827 .39721 .15372 .39165 .14259 .38148 Mtetra
.14259 .38148 .15372 .39165 .16925 .38611 .15818 .37583 Mtetra
.656 .752 .92 r
.15818 .37583 .16925 .38611 .18487 .3806 .17386 .37018 Mtetra
.655 .75 .92 r
.17386 .37018 .18487 .3806 .20058 .37509 .18963 .36456 Mtetra
.654 .749 .919 r
.18963 .36456 .20058 .37509 .2164 .36947 .20549 .35894 Mtetra
.654 .75 .92 r
.20549 .35894 .2164 .36947 .23231 .36375 .22146 .35327 Mtetra
.657 .753 .921 r
.22146 .35327 .23231 .36375 .24833 .35799 .23753 .34747 Mtetra
.657 .754 .921 r
.23753 .34747 .24833 .35799 .26444 .3522 .2537 .34162 Mtetra
.2537 .34162 .26444 .3522 .28066 .34641 .26998 .33573 Mtetra
.657 .753 .921 r
.26998 .33573 .28066 .34641 .29696 .34061 .28635 .32982 Mtetra
.656 .752 .92 r
.28635 .32982 .29696 .34061 .31337 .33483 .30283 .32388 Mtetra
.656 .75 .919 r
.30283 .32388 .31337 .33483 .32988 .329 .3194 .31792 Mtetra
.656 .749 .918 r
.3194 .31792 .32988 .329 .3465 .32313 .33608 .31194 Mtetra
.656 .748 .918 r
.33608 .31194 .3465 .32313 .36322 .3172 .35287 .30592 Mtetra
.655 .747 .918 r
.35287 .30592 .36322 .3172 .38005 .31122 .36976 .29987 Mtetra
.656 .747 .917 r
.36976 .29987 .38005 .31122 .39698 .30519 .38676 .29377 Mtetra
.656 .748 .917 r
.38676 .29377 .39698 .30519 .41402 .29911 .40387 .28762 Mtetra
.40387 .28762 .41402 .29911 .43117 .29298 .42109 .28143 Mtetra
.656 .748 .918 r
.42109 .28143 .43117 .29298 .44843 .28679 .43842 .27522 Mtetra
.655 .749 .918 r
.43842 .27522 .44843 .28679 .4658 .28056 .45586 .26897 Mtetra
.655 .75 .92 r
.45586 .26897 .4658 .28056 .48329 .27427 .47341 .2627 Mtetra
.655 .752 .921 r
.47341 .2627 .48329 .27427 .50088 .26799 .49108 .2564 Mtetra
.655 .752 .922 r
.49108 .2564 .50088 .26799 .51859 .26171 .50886 .25007 Mtetra
.655 .753 .922 r
.50886 .25007 .51859 .26171 .53641 .25542 .52676 .24369 Mtetra
.52676 .24369 .53641 .25542 .55435 .24909 .54477 .23726 Mtetra
.657 .753 .921 r
.54477 .23726 .55435 .24909 .57241 .24272 .56291 .2307 Mtetra
.658 .751 .919 r
.56291 .2307 .57241 .24272 .59058 .23623 .58116 .22407 Mtetra
.656 .749 .918 r
.58116 .22407 .59058 .23623 .60887 .22963 .59953 .21744 Mtetra
.655 .75 .92 r
.59953 .21744 .60887 .22963 .62729 .22302 .61803 .21082 Mtetra
.654 .751 .921 r
.61803 .21082 .62729 .22302 .64582 .21644 .63665 .2042 Mtetra
.654 .752 .922 r
.63665 .2042 .64582 .21644 .66448 .20986 .6554 .19754 Mtetra
.656 .753 .921 r
.6554 .19754 .66448 .20986 .68327 .20324 .67427 .19074 Mtetra
.657 .751 .919 r
.67427 .19074 .68327 .20324 .70218 .19646 .69326 .18385 Mtetra
.656 .75 .919 r
.69326 .18385 .70218 .19646 .72121 .18961 .71238 .17697 Mtetra
.655 .751 .92 r
.71238 .17697 .72121 .18961 .74037 .18278 .73164 .17008 Mtetra
.658 .753 .92 r
.05455 .39892 .06607 .4089 .08119 .40345 .06973 .39337 Mtetra
.656 .752 .92 r
.06973 .39337 .08119 .40345 .0964 .39801 .085 .38783 Mtetra
.655 .751 .92 r
.085 .38783 .0964 .39801 .1117 .39259 .10035 .3823 Mtetra
.654 .75 .92 r
.10035 .3823 .1117 .39259 .12709 .3871 .11579 .37678 Mtetra
.655 .751 .92 r
.11579 .37678 .12709 .3871 .14259 .38148 .13133 .37119 Mtetra
.657 .753 .921 r
.13133 .37119 .14259 .38148 .15818 .37583 .14697 .36548 Mtetra
.14697 .36548 .15818 .37583 .17386 .37018 .16271 .35974 Mtetra
.656 .752 .92 r
.16271 .35974 .17386 .37018 .18963 .36456 .17855 .35398 Mtetra
.656 .751 .92 r
.17855 .35398 .18963 .36456 .20549 .35894 .19447 .34823 Mtetra
.654 .749 .919 r
.19447 .34823 .20549 .35894 .22146 .35327 .21049 .34249 Mtetra
.21049 .34249 .22146 .35327 .23753 .34747 .22662 .33673 Mtetra
.655 .751 .921 r
.22662 .33673 .23753 .34747 .2537 .34162 .24284 .33089 Mtetra
.656 .753 .921 r
.24284 .33089 .2537 .34162 .26998 .33573 .25917 .32496 Mtetra
.657 .754 .921 r
.25917 .32496 .26998 .33573 .28635 .32982 .27561 .31899 Mtetra
.657 .754 .922 r
.27561 .31899 .28635 .32982 .30283 .32388 .29215 .31297 Mtetra
.657 .754 .921 r
.29215 .31297 .30283 .32388 .3194 .31792 .30879 .30693 Mtetra
.656 .753 .921 r
.30879 .30693 .3194 .31792 .33608 .31194 .32553 .30085 Mtetra
.32553 .30085 .33608 .31194 .35287 .30592 .34239 .29474 Mtetra
.656 .752 .921 r
.34239 .29474 .35287 .30592 .36976 .29987 .35934 .2886 Mtetra
.35934 .2886 .36976 .29987 .38676 .29377 .37641 .28243 Mtetra
.37641 .28243 .38676 .29377 .40387 .28762 .39359 .27622 Mtetra
.655 .752 .921 r
.39359 .27622 .40387 .28762 .42109 .28143 .41088 .26999 Mtetra
.655 .753 .921 r
.41088 .26999 .42109 .28143 .43842 .27522 .42827 .26371 Mtetra
.655 .753 .922 r
.42827 .26371 .43842 .27522 .45586 .26897 .44579 .25741 Mtetra
.44579 .25741 .45586 .26897 .47341 .2627 .46341 .25107 Mtetra
.46341 .25107 .47341 .2627 .49108 .2564 .48115 .24469 Mtetra
.48115 .24469 .49108 .2564 .50886 .25007 .49901 .23826 Mtetra
.657 .753 .921 r
.49901 .23826 .50886 .25007 .52676 .24369 .51699 .23172 Mtetra
.657 .752 .92 r
.51699 .23172 .52676 .24369 .54477 .23726 .53508 .22511 Mtetra
.657 .75 .918 r
.53508 .22511 .54477 .23726 .56291 .2307 .55329 .21846 Mtetra
.656 .749 .919 r
.55329 .21846 .56291 .2307 .58116 .22407 .57162 .21183 Mtetra
.655 .751 .92 r
.57162 .21183 .58116 .22407 .59953 .21744 .59008 .20518 Mtetra
.654 .751 .921 r
.59008 .20518 .59953 .21744 .61803 .21082 .60866 .19852 Mtetra
.654 .752 .922 r
.60866 .19852 .61803 .21082 .63665 .2042 .62737 .19182 Mtetra
.657 .753 .921 r
.62737 .19182 .63665 .2042 .6554 .19754 .64619 .18497 Mtetra
.657 .751 .919 r
.64619 .18497 .6554 .19754 .67427 .19074 .66515 .17805 Mtetra
.656 .75 .919 r
.66515 .17805 .67427 .19074 .69326 .18385 .68423 .17112 Mtetra
.655 .751 .92 r
.68423 .17112 .69326 .18385 .71238 .17697 .70344 .16419 Mtetra
.654 .751 .921 r
.70344 .16419 .71238 .17697 .73164 .17008 .72279 .15726 Mtetra
.657 .752 .92 r
.04292 .38879 .05455 .39892 .06973 .39337 .05814 .38321 Mtetra
.657 .753 .92 r
.05814 .38321 .06973 .39337 .085 .38783 .07346 .37757 Mtetra
.656 .752 .92 r
.07346 .37757 .085 .38783 .10035 .3823 .08887 .37194 Mtetra
.655 .751 .92 r
.08887 .37194 .10035 .3823 .11579 .37678 .10437 .36631 Mtetra
.654 .749 .92 r
.10437 .36631 .11579 .37678 .13133 .37119 .11995 .36069 Mtetra
.655 .75 .92 r
.11995 .36069 .13133 .37119 .14697 .36548 .13564 .35501 Mtetra
.657 .753 .921 r
.13564 .35501 .14697 .36548 .16271 .35974 .15143 .34922 Mtetra
.15143 .34922 .16271 .35974 .17855 .35398 .16733 .34337 Mtetra
.16733 .34337 .17855 .35398 .19447 .34823 .18332 .33751 Mtetra
.656 .752 .92 r
.18332 .33751 .19447 .34823 .21049 .34249 .1994 .33163 Mtetra
.655 .75 .919 r
.1994 .33163 .21049 .34249 .22662 .33673 .21559 .32574 Mtetra
.654 .749 .919 r
.21559 .32574 .22662 .33673 .24284 .33089 .23187 .31986 Mtetra
.23187 .31986 .24284 .33089 .25917 .32496 .24825 .31394 Mtetra
.655 .751 .92 r
.24825 .31394 .25917 .32496 .27561 .31899 .26474 .30797 Mtetra
.656 .752 .921 r
.26474 .30797 .27561 .31899 .29215 .31297 .28134 .30193 Mtetra
.656 .753 .921 r
.28134 .30193 .29215 .31297 .30879 .30693 .29804 .29582 Mtetra
.656 .754 .922 r
.29804 .29582 .30879 .30693 .32553 .30085 .31486 .28968 Mtetra
.31486 .28968 .32553 .30085 .34239 .29474 .33177 .2835 Mtetra
.33177 .2835 .34239 .29474 .35934 .2886 .3488 .27729 Mtetra
.3488 .27729 .35934 .2886 .37641 .28243 .36594 .27105 Mtetra
.36594 .27105 .37641 .28243 .39359 .27622 .38318 .26477 Mtetra
.38318 .26477 .39359 .27622 .41088 .26999 .40054 .25845 Mtetra
.655 .754 .922 r
.40054 .25845 .41088 .26999 .42827 .26371 .41801 .2521 Mtetra
.655 .753 .922 r
.41801 .2521 .42827 .26371 .44579 .25741 .43559 .2457 Mtetra
.656 .753 .922 r
.43559 .2457 .44579 .25741 .46341 .25107 .45329 .23924 Mtetra
.657 .753 .921 r
.45329 .23924 .46341 .25107 .48115 .24469 .47111 .23271 Mtetra
.657 .751 .92 r
.47111 .23271 .48115 .24469 .49901 .23826 .48904 .22612 Mtetra
.657 .75 .918 r
.48904 .22612 .49901 .23826 .51699 .23172 .5071 .21949 Mtetra
.656 .749 .918 r
.5071 .21949 .51699 .23172 .53508 .22511 .52527 .21285 Mtetra
.655 .75 .919 r
.52527 .21285 .53508 .22511 .55329 .21846 .54356 .2062 Mtetra
.655 .751 .921 r
.54356 .2062 .55329 .21846 .57162 .21183 .56197 .19952 Mtetra
.654 .752 .921 r
.56197 .19952 .57162 .21183 .59008 .20518 .58051 .19282 Mtetra
.655 .753 .922 r
.58051 .19282 .59008 .20518 .60866 .19852 .59917 .18606 Mtetra
.657 .753 .921 r
.59917 .18606 .60866 .19852 .62737 .19182 .61796 .17917 Mtetra
.657 .751 .919 r
.61796 .17917 .62737 .19182 .64619 .18497 .63687 .17221 Mtetra
.656 .75 .919 r
.63687 .17221 .64619 .18497 .66515 .17805 .65591 .16525 Mtetra
.655 .751 .92 r
.65591 .16525 .66515 .17805 .68423 .17112 .67509 .15827 Mtetra
.654 .751 .921 r
.67509 .15827 .68423 .17112 .70344 .16419 .69439 .1513 Mtetra
.655 .752 .921 r
.69439 .1513 .70344 .16419 .72279 .15726 .71383 .14425 Mtetra
.655 .75 .92 r
.03116 .37848 .04292 .38879 .05814 .38321 .04642 .37291 Mtetra
.657 .752 .92 r
.04642 .37291 .05814 .38321 .07346 .37757 .06179 .36723 Mtetra
.657 .753 .921 r
.06179 .36723 .07346 .37757 .08887 .37194 .07725 .3615 Mtetra
.656 .752 .92 r
.07725 .3615 .08887 .37194 .10437 .36631 .09281 .35577 Mtetra
.655 .751 .92 r
.09281 .35577 .10437 .36631 .11995 .36069 .10846 .35003 Mtetra
.654 .75 .92 r
.10846 .35003 .11995 .36069 .13564 .35501 .1242 .3443 Mtetra
.1242 .3443 .13564 .35501 .15143 .34922 .14003 .33853 Mtetra
.656 .752 .921 r
.14003 .33853 .15143 .34922 .16733 .34337 .15598 .33266 Mtetra
.657 .753 .921 r
.15598 .33266 .16733 .34337 .18332 .33751 .17202 .32672 Mtetra
.17202 .32672 .18332 .33751 .1994 .33163 .18817 .32074 Mtetra
.656 .752 .921 r
.18817 .32074 .1994 .33163 .21559 .32574 .20442 .31475 Mtetra
.656 .751 .92 r
.20442 .31475 .21559 .32574 .23187 .31986 .22076 .30874 Mtetra
.656 .75 .919 r
.22076 .30874 .23187 .31986 .24825 .31394 .23721 .3027 Mtetra
.655 .749 .919 r
.23721 .3027 .24825 .31394 .26474 .30797 .25377 .29664 Mtetra
.25377 .29664 .26474 .30797 .28134 .30193 .27042 .29056 Mtetra
.27042 .29056 .28134 .30193 .29804 .29582 .28719 .28443 Mtetra
.655 .75 .92 r
.28719 .28443 .29804 .29582 .31486 .28968 .30406 .27825 Mtetra
.655 .751 .92 r
.30406 .27825 .31486 .28968 .33177 .2835 .32104 .27202 Mtetra
.656 .751 .92 r
.32104 .27202 .33177 .2835 .3488 .27729 .33813 .26575 Mtetra
.656 .752 .921 r
.33813 .26575 .3488 .27729 .36594 .27105 .35534 .25943 Mtetra
.656 .752 .92 r
.35534 .25943 .36594 .27105 .38318 .26477 .37265 .25306 Mtetra
.37265 .25306 .38318 .26477 .40054 .25845 .39008 .24665 Mtetra
.656 .751 .92 r
.39008 .24665 .40054 .25845 .41801 .2521 .40763 .24018 Mtetra
.656 .751 .919 r
.40763 .24018 .41801 .2521 .43559 .2457 .42528 .23366 Mtetra
.657 .75 .919 r
.42528 .23366 .43559 .2457 .45329 .23924 .44306 .22709 Mtetra
.656 .749 .918 r
.44306 .22709 .45329 .23924 .47111 .23271 .46095 .22049 Mtetra
.656 .749 .919 r
.46095 .22049 .47111 .23271 .48904 .22612 .47896 .21387 Mtetra
.655 .75 .919 r
.47896 .21387 .48904 .22612 .5071 .21949 .49708 .20722 Mtetra
.655 .751 .92 r
.49708 .20722 .5071 .21949 .52527 .21285 .51533 .20054 Mtetra
.655 .752 .921 r
.51533 .20054 .52527 .21285 .54356 .2062 .53371 .19384 Mtetra
.655 .752 .922 r
.53371 .19384 .54356 .2062 .56197 .19952 .5522 .18709 Mtetra
.656 .753 .921 r
.5522 .18709 .56197 .19952 .58051 .19282 .57082 .18026 Mtetra
.657 .752 .92 r
.57082 .18026 .58051 .19282 .59917 .18606 .58957 .17332 Mtetra
.657 .751 .919 r
.58957 .17332 .59917 .18606 .61796 .17917 .60844 .16633 Mtetra
.656 .75 .919 r
.60844 .16633 .61796 .17917 .63687 .17221 .62744 .15934 Mtetra
.655 .751 .92 r
.62744 .15934 .63687 .17221 .65591 .16525 .64657 .15233 Mtetra
.654 .751 .921 r
.64657 .15233 .65591 .16525 .67509 .15827 .66583 .14531 Mtetra
.655 .752 .921 r
.66583 .14531 .67509 .15827 .69439 .1513 .68523 .13822 Mtetra
.657 .752 .92 r
.68523 .13822 .69439 .1513 .71383 .14425 .70476 .131 Mtetra
.655 .75 .92 r
.01927 .36806 .03116 .37848 .04642 .37291 .03458 .36242 Mtetra
.03458 .36242 .04642 .37291 .06179 .36723 .04999 .35675 Mtetra
.656 .752 .92 r
.04999 .35675 .06179 .36723 .07725 .3615 .0655 .35098 Mtetra
.657 .753 .921 r
.0655 .35098 .07725 .3615 .09281 .35577 .08111 .34515 Mtetra
.656 .752 .92 r
.08111 .34515 .09281 .35577 .10846 .35003 .09682 .33931 Mtetra
.656 .751 .92 r
.09682 .33931 .10846 .35003 .1242 .3443 .11262 .33346 Mtetra
.655 .75 .92 r
.11262 .33346 .1242 .3443 .14003 .33853 .12851 .32761 Mtetra
.654 .749 .92 r
.12851 .32761 .14003 .33853 .15598 .33266 .1445 .32174 Mtetra
.655 .751 .92 r
.1445 .32174 .15598 .33266 .17202 .32672 .1606 .31581 Mtetra
.656 .753 .921 r
.1606 .31581 .17202 .32672 .18817 .32074 .1768 .30978 Mtetra
.657 .753 .921 r
.1768 .30978 .18817 .32074 .20442 .31475 .19311 .30371 Mtetra
.19311 .30371 .20442 .31475 .22076 .30874 .20952 .29759 Mtetra
.656 .752 .921 r
.20952 .29759 .22076 .30874 .23721 .3027 .22603 .29145 Mtetra
.656 .752 .92 r
.22603 .29145 .23721 .3027 .25377 .29664 .24265 .28529 Mtetra
.656 .751 .92 r
.24265 .28529 .25377 .29664 .27042 .29056 .25937 .27909 Mtetra
.656 .75 .919 r
.25937 .27909 .27042 .29056 .28719 .28443 .27621 .27285 Mtetra
.656 .749 .919 r
.27621 .27285 .28719 .28443 .30406 .27825 .29314 .26658 Mtetra
.29314 .26658 .30406 .27825 .32104 .27202 .31019 .26027 Mtetra
.656 .749 .918 r
.31019 .26027 .32104 .27202 .33813 .26575 .32735 .25392 Mtetra
.32735 .25392 .33813 .26575 .35534 .25943 .34462 .24752 Mtetra
.34462 .24752 .35534 .25943 .37265 .25306 .36201 .24108 Mtetra
.36201 .24108 .37265 .25306 .39008 .24665 .3795 .23459 Mtetra
.656 .749 .919 r
.3795 .23459 .39008 .24665 .40763 .24018 .39712 .22807 Mtetra
.39712 .22807 .40763 .24018 .42528 .23366 .41485 .2215 Mtetra
.656 .75 .919 r
.41485 .2215 .42528 .23366 .44306 .22709 .43269 .2149 Mtetra
.655 .751 .92 r
.43269 .2149 .44306 .22709 .46095 .22049 .45066 .20826 Mtetra
.655 .752 .921 r
.45066 .20826 .46095 .22049 .47896 .21387 .46874 .20159 Mtetra
.46874 .20159 .47896 .21387 .49708 .20722 .48695 .19488 Mtetra
.655 .752 .922 r
.48695 .19488 .49708 .20722 .51533 .20054 .50528 .18814 Mtetra
.655 .753 .922 r
.50528 .18814 .51533 .20054 .53371 .19384 .52373 .18133 Mtetra
.657 .753 .921 r
.52373 .18133 .53371 .19384 .5522 .18709 .54231 .17441 Mtetra
.657 .751 .92 r
.54231 .17441 .5522 .18709 .57082 .18026 .56101 .16743 Mtetra
.657 .75 .919 r
.56101 .16743 .57082 .18026 .58957 .17332 .57984 .16042 Mtetra
.656 .75 .919 r
.57984 .16042 .58957 .17332 .60844 .16633 .5988 .15339 Mtetra
.655 .751 .92 r
.5988 .15339 .60844 .16633 .62744 .15934 .61788 .14635 Mtetra
.654 .751 .921 r
.61788 .14635 .62744 .15934 .64657 .15233 .63711 .13929 Mtetra
.655 .752 .921 r
.63711 .13929 .64657 .15233 .66583 .14531 .65646 .13215 Mtetra
.657 .752 .92 r
.65646 .13215 .66583 .14531 .68523 .13822 .67594 .12489 Mtetra
.657 .751 .919 r
.67594 .12489 .68523 .13822 .70476 .131 .69556 .11758 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
[(-2)] .12586 .2075 1 .99877 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.56863 .04703 m
.57247 .05235 L
s
[(2)] .56094 .0364 .72324 1 Mshowa
.125 Mabswid
.18558 .19702 m
.18832 .19985 L
s
.23703 .17687 m
.23971 .17975 L
s
.28951 .15632 m
.29214 .15925 L
s
.39772 .11395 m
.40023 .11699 L
s
.4535 .09211 m
.45595 .0952 L
s
.51046 .06981 m
.51284 .07294 L
s
.08568 .23614 m
.08851 .23887 L
s
.62804 .02377 m
.63027 .02701 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 233.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00o?ooool2o`0006[ooooo003iooooo`?o000000?oooooo`000?ooool0
JOooool00?Oooooo0_l00004ooooo`;o0000JOooool00?Cooooo0ol00006ooooo`03o`000?oooooo
000006Sooooo003;ooooo`Go00008_ooool2o`0000Wooooo00?o0000ooooool00000J?ooool00<_o
oooo00GoV9RHob4Q8Oo^k^koooooodA4A00Oooooo`?o00002oooool01?l0003oooooooooool0001W
ooooo`00c?ooool00onHV9So8B4Qonk^kP0Mooooo`?o00003_ooool01Ol0003ooooooooooooooooo
000006Kooooo003=ooooo`03oiRHV?lQ8B7ok^k^01[ooooo0_l0000Aooooo`05o`000?oooooooooo
ooooool00000I_ooool00<kooooo00?oMgMgofIVI_ooool05_ooool3o`0001?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1Sooooo`00coooool00ol0003oooooooooo`0Cooooo`;o
00000_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0H_ooool00<_ooooo00Go0000okZj^_ooooooV9RHoa0@400Booooo`?o00006Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo06;ooooo003;ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`04?ooool2o`0001cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Qooooo`00
gOooool3o`0001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Qooooo`00fooo
ool2o`00027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Pooooo`00f?ooool3
o`0002?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Oooooo`00eOooool3o`00
02Kooooo00?o0000ooooooooool01?ooool2o`00067ooooo003Cooooo`;o0000:Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo05kooooo003@ooooo`?o000000?oooooo`000?ooool0
:?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05gooooo003>ooooo`;o00001Ooo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0GOoo
ool00<_ooooo0ol0000`ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0G?ooool0
0<Wooooo0_l0000cooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Foooool00<Ko
oooo0ol0000eooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Foooool00<Cooooo
0_l0000hooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0F_ooool00<7ooooo0ol0
000jooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03_ooool5o`0004Kooooo002n
ooooo`?o0000?Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00kooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A016ooooo`00_?ooool2o`0000?ooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo1_l00003ooooo`03oiRHV?lQ8B7o
k^k^04Oooooo002iooooo`?o0000@oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00kooooo00?oV9RHob4Q8Oo^k^h0A_ooool00;Oooooo0_l00016ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03oooool00omgMgOoIVIVooooo`15ooooo`00]?ooool3o`0004Sooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Cooooo
002booooo`;o0000Boooool00ol0003oooooooooo`0=ooooo`;o00003?ooool01Ol0003o^[Zjoooo
oonHV9So410@04Kooooo002_ooooo`?o0000COooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c016ooooo`00[Oooool2o`00053ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`1Dooooo`00Z_ooool4o`00057ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1Dooooo`00Z?ooool2o`0000Cooooo00?o0000oooo
ooooool0C_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05?ooooo001nooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h08_ooool3o`0005Oooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`1Booooo`00O_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01oooooo0ol0001Joooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool0D_ooool007kooooo00Go410@oooooooo
oooooooooa0@400Mooooo`;o0000GOooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
057ooooo001nooooo`05o`000?ooooooooooooooool000006_ooool3o`0005oooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`1@ooooo`00O_ooool01Ol0003ooooooooooooooooo0000
01Sooooo0_l0001Rooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0D?ooool007ko
oooo00Go410@oooooooooooooooooa0@400Eooooo`?o0000I?ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo04oooooo001nooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool2o`00
00?ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
04kooooo001nooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04?ooool3o`0006Sooooo00?oZ<3[o`00
0?ooool05_ooool00ol0003oooooooooo`1>ooooo`00TOooool2o`0006Sooooo1?nX`>/00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo04gooooo002>ooooo`?o0000J?ooool7ojS0j`03o`00
0?oooooooooo01Cooooo0ol0001>ooooo`00Roooool3o`0006Wooooo2OnX`>/00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo04cooooo0029ooooo`;o0000JOooool<ojS0j`03o`000?nX`>_o
oooo01Oooooo00?o0000ooooooooool0Boooool008Kooooo0ol0001Xooooo`03ojO0jonX`>_oZ<3[
00coZ<3[00?o0000ojS0joooool06?ooool00ol0003oooooooooo`1:ooooo`00Q?ooool2o`0000;o
oooo00?o0000ooooooooool0Hoooool5ojO0j`goZ<3[00?o0000ojS0jonX`>/06?ooool00ol0003o
ooooooooo`1:ooooo`00POooool3o`0000Gooooo00?o0000ooooooooool0H?ooool8ojO0j`OoZ<3[
00?oYl3[ojS0jonX`>/00_nX`>/01?l0003oZ<3[ojS0jonX`>/Hooooo`03o`000?oooooooooo04Wo
oooo001oooooo`;o0000JOooool:ojO0j`CoZ<3[1OnW`>/3ojS0j`03o`000?nX`>_oZ<3[00;oZ<3[
6?ooool00ol0003oooooooooo`18ooooo`00O?ooool3o`0006Sooooo3_nW`>/00onX`>_oYl3[ojO0
j`06ojO0j`;oZ<3[00Go0000ojS0jonX`>_oZ<3[ojO0j`0Hooooo`03o`000?oooooooooo04Sooooo
001jooooo`;o0000IooooolKojO0j`;oZ<3[00?o0000ojS0jonW`>/00onW`>/Hooooo`03o`000?oo
oooooooo04Oooooo001gooooo`?o0000I_oooolOojO0j`03ojS0jol0003oYl3[00GoYl3[6?ooool0
0ol0003oooooooooo`16ooooo`00M?ooool3o`0006Kooooo00?oYko[ojO0jonW`>/08?nW`>/00ol0
003oYl3[ojO0j`04ojO0jaSooooo00?o0000ooooooooool0A_ooool007;ooooo0_l00002ooooo`03
o`000?oooooooooo06;ooooo1?nW_n/QojO0j`03o`000?nW`>_oYl3[00GoYl3[6?ooool00ol0003o
ooooooooo`15ooooo`00Koooool3o`0006Oooooo1onW_n/7ojO0j`03ojNojonW`>_oYl3[01KoYl3[
00?o0000ojO0jonW`>/01OnW`>/Hooooo`03o`000?oooooooooo04Gooooo001]ooooo`;o0000Iooo
ool2ojRoj`SoYko[1?nW`>/5ojNojaOoYl3[00?o0000ojO0jonW`>/01_nW`>/Gooooo`;o0000A_oo
ool006[ooooo0ol0001Vooooo`KoZ;o[2?nW_n/00onW`>_oYko[ojNoj`06ojNoj`OoYl3[00?oYko[
ojO0jonW`>/03?nW`>/00ol0003oYl3[ojO0j`07ojO0jaSooooo00?o0000ooooooooool0@oooool0
06Sooooo0_l0001Vooooo`;oZ<3[2?nX_n/6ojNoj`;oZ<3[2?nW_n/4ojO0j`GoYko[3OnW`>/00ol0
003oYl3[ojO0j`08ojO0jaOooooo00?o0000ooooooooool0@oooool006Gooooo0ol0001Uooooo`Ko
Z<3[2?nX_n/2ojNoj`KoZ<3[2?nW_n/00onW`>_oYko[ojNoj`06ojNoj`KoYl3[00?oYko[ojO0jonW
`>/00onW`>/00ol0003oYl3[ojO0j`08ojO0jaSooooo00?o0000ooooooooool0@_ooool006?ooooo
0_l0001Uooooo`[oZ<3[1_nX_n/:ojS0j`KoYko[00?oZ<3[ojNojonW_n/01onW_n/4ojO0j`CoYko[
1OnW`>/00ol0003oYl3[ojO0j`08ojO0jaSooooo00?o0000ooooooooool0@Oooool0063ooooo0ol0
00000ooooooo0000ooooo`1Rooooo`goZ<3[0_nX_n/>ojS0j`;oYko[1OnX`>/9ojNoj`03ojO0jonW
_n_oYko[00GoYko[1?nW`>/01?l0003oYl3[ojO0jonW_n/8ojO0jaOooooo00?o0000ooooooooool0
@Oooool003Kooooo1Ol0000Sooooo`;o0000I_ooool>ojS0j`03ojO0jonX`>_oZ<3[01KoZ<3[1_nW
_n/2ojS0j`SoYko[1?nW`>/00ol0003oYko[ojNoj`02ojNoj`SoYl3[5oooool00ol0003ooooooooo
o`10ooooo`00=_ooool01OnHV9So8B4Qonk^k_ooooooA4A4023ooooo0ol0001Uooooo`;oYl3/3?nX
`>/5ojO0jaSoZ<3[0_nW_n/6ojS0j`SoYko[00CoYl3[ojNojonW_n_o00001OnW_n/6ojO0j`03ojNo
jooooooooooo01Kooooo00?o0000ooooooooool0?oooool002kooooo1_l00003ooooo`03oiRHV?lQ
8B7ok^k^01kooooo0ol0001Uooooo`KoYl3/2OnX`>/8ojO0j`KoZ<3[00?oYl3/ojS0jonX`>/05onX
`>/6ojNoj`05ojS0jonW_n_oYko[ojNojol000001OnW_n/4ojO0j`CoYko[5oooool00ol0003ooooo
ooooo`0oooooo`00>?ooool00onHV9So8B4Qonk^kP0Kooooo`;o0000IOooool:ojO0k0KoZ<3[0_nW
`>`8ojO0j`CoZ<3[1?nW`>`IojS0j`;oYko[1OnX`>/2ojNoj`03o`000?nW_n_oYko[00CoYko[00?o
Yl3[ojNojonW_n/01OnW_n/Gooooo`03o`000?oooooooooo03kooooo000iooooo`03ogMgMomVIVKo
oooo01Oooooo0ol0001Tooooo`koYl3/0_nX`>/6ojO0k0SoYl3[00?oZ<3[ojO0k?nW`>`01OnW`>`7
ojS0j`03ojO0k?nX`>_oZ<3[00coZ<3[0_nW`>/8ojS0j`03ojNojol0003oYko[00?oYko[0_nX`>/8
ojNojaSooooo00?o0000ooooooooool0?Oooool003[ooooo00?o0000ooooooooool05?ooool2o`00
06Cooooo00?oYl3[ojO0k?nW`>`03OnW`>`00onW`>_oYl3/ojO0k007ojO0k0OoYl3[2OnW`>`4ojS0
j`CoYl3/2_nX`>/6ojO0j`SoZ<3[00?o0000ojNojonX`>/01OnX`>/8ojNojaOooooo00?o0000oooo
ooooool0?Oooool003Kooooo00Go0000okZj^_ooooooV9RHoa0@400Cooooo`?o00000_ooool00ol0
003oooooooooo`1Oooooo`CoYl3[2onW`>`5ojO0j`WoYl3/1onW`>/9ojO0k003ojS0jonW`>coYl3/
00GoYl3/1_nX`>/00onW`>coYl3[ojO0j`07ojO0j`OoZ<3[00?o0000ojS0jonX`>/01_nX`>/6ojNo
j`03ojS0jooooooooooo01Kooooo00?o0000ooooooooool0??ooool003Kooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c00Aooooo`;o0000IOooool7ojO0j`OoYl3/2OnW`>/6ojO0k0[oYl3[1_nW`>`2ojO0
j`SoYl3/1?nX`>/4ojO0k0WoYl3[1_nX`>/00ol0003oZ<3[ojS0j`07ojS0j`;oYko[1OnX`>/Foooo
o`?o0000?Oooool004Wooooo0ol0001Uooooo`[oYl3[1?nW`>`<ojO0j`;oYl3/3_nW`>/2ojO0k0Ko
Yl3[2?nW`>`00onX`>_oYl3/ojO0k005ojO0k0OoYl3[00?oYl3/ojS0jonX`>/01?nX`>/00ol0003o
Z<3[ojS0j`0?ojS0jaOooooo00?o0000ooooooooool0>oooool004Oooooo0_l0001Uooooo`koYl3[
00?oYl3/ojO0jonW`>/02onW`>/2ojNojaSoYl3[1_nW`>`00onW`>_oYl3/ojO0k006ojO0k0CoYl3[
1OnW`>`5ojS0j`03o`000?nX`>_oZ<3[013oZ<3[5oooool00ol0003oooooooooo`0jooooo`00A?oo
ool3o`0006Cooooo3onW`>/2ojNoj`coYl3[1OnW_n/HojO0j`;oYl3/1OnW`>/8ojO0k003ojO0jonW
`>coYl3/00KoYl3/1?nX`>/00ol0003oZ<3[ojO0k00@ojS0jaSooooo00?o0000ooooooooool0>Ooo
ool0047ooooo0ol0001Tooooo`ooYl3[1_nW_n/9ojO0j`SoYko[1_nW`>/00onW_n_oYl3[ojO0j`0<
ojO0j`;oYko[2?nW`>/6ojO0k0;oYl3[2OnW`>`2ojS0j`03ojO0k?l0003oYl3/00;oYl3/4?nX`>/G
ooooo`03o`000?oooooooooo03Wooooo000oooooo`?o0000Hoooool00onW_n_oYl3[ojO0j`0<ojO0
j`[oYko[1_nW`>/;ojNoj`;oYl3[1OnW_n/:ojO0j`KoYko[2?nW`>/2ojO0k0KoYl3[1onW`>`01OnW
`>_oYl3/ojO0k?nW`>co000000CoYl3/1_nX`>/2ojO0j`SoZ<3[5oooool00ol0003oooooooooo`0h
ooooo`00??ooool3o`0000?ooooo00?o0000ooooooooool0GOooool5ojNoj`[oYl3[3_nW_n/2ojO0
j`goYko[00?oZ;o[ojNojonW_n/01_nW_n/6ojO0j`[oYko[1_nW`>/00onW_n_oYl3[ojO0j`07ojO0
j`CoYl3/1?nW`>/2ojO0k003o`000?nW`>coYl3/00?oYl3/0_nX`>/6ojO0j`SoZ<3[5_ooool00ol0
003oooooooooo`07ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0;?ooool003[ooooo0_l0001Soooo
o`WoYko[1_nW`>/@ojNoj`03ojRojonW_n_oYko[00_oYko[1?nX_n/8ojNoj`;oYl3[3_nW_n/2ojO0
j`GoYko[2OnW`>/00onW`>coYl3[ojO0j`05ojO0j`03ojO0k?l0003oYl3/00?oYl3/2_nW`>/6ojS0
j`03ojO0jooooooooooo01Gooooo00?o0000ooooooooool01_ooool01OmgMgOoV9RHoooooonHV9So
MgMg02cooooo000gooooo`?o0000Hoooool<ojNoj`;oYl3[4?nW_n/5ojRoj`[oYko[1onX_n/6ojNo
j`03ojS0jonW_n_oYko[00goYko[00?oZ;o[ojNojonW_n/01_nW_n/6ojO0j`;oYko[2?nW`>/2ojO0
k003o`000?nW`>coYl3[00coYl3[0_nX`>/5ojO0jaOooooo00?o0000ooooooooool01Oooool01Ol@
413ooooooooooooooooo410@02cooooo000eooooo`;o0000I?ooool=ojNoj`03ojRojonW_n_oYko[
00goYko[00?oZ<3[ojRojonX_n/01_nX_n/6ojNoj`;oZ<3[2?nX_n/4ojNoj`CoZ<3[2onW_n/5ojRo
j`SoYko[0_nW`>/6ojNoj`SoYl3[00?oYl3/o`000?nW`>/05OnW`>/Fooooo`03o`000?oooooooooo
00Gooooo00Go0000ooooooooooooooooo`00000/ooooo`00<_ooool3o`0006Cooooo3OnW_n/4ojRo
j`_oYko[1OnX`>/8ojRoj`;oYko[1_nX`>/8ojRoj`03ojNojonX`>_oZ<3[00GoZ<3[1_nW_n/2ojS0
j`SoZ;o[1_nW_n/00onX_n_oYko[ojNoj`07ojNoj`KoYl3[00?oYko[ojO0jol000005onW`>/Foooo
o`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000/ooooo`00<?ooool2o`00
06Cooooo3_nW_n/7ojRoj`OoYko[2OnX`>/6ojRoj`[oZ<3[1_nX_n/:ojS0j`;oYko[1_nX`>/8ojRo
j`;oYko[1OnX_n/9ojNoj`;oYl3[1OnW_n/00ol0003oYl3[ojO0j`0EojO0jaOooooo00?o0000oooo
ooooool00oooool01Ol@413ooooooooooooooooo410@02cooooo000]ooooo`?o000000?oooooo`00
0?ooool0H?ooool?ojNoj`;oYl3[2?nX_n/4ojNoj`coZ<3[0_nX_n/>ojS0j`;oZ;o[3?nX`>/00onW
`>_oZ<3[ojS0j`07ojS0j`KoZ;o[00?oZ<3[ojRojonX_n/01_nX_n/6ojNoj`;oZ;o[1onW_n/00ol0
003oYl3[ojO0j`0FojO0jaKooooo0_l00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0;?ooool0
02[ooooo0ol0001Sooooo`ooYko[1_nW`>/8ojRoj`03ojNojonX`>_oZ<3[00_oZ<3[0_nW`>`>ojS0
j`03ojO0k?nX`>_oZ<3[00[oZ<3[1?nW`>/9ojS0j`;oZ;o[1OnX`>/8ojRoj`;oYko[1_nX_n/6ojNo
j`03o`000?nW_n_oYl3[01OoYl3[4oooool2o`000003ooooool0003ooooo00?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0/ooooo`00:?ooool2o`0006?ooooo3onW_n/:ojO0j`KoZ;o[00?oYl3/ojS0
jonX`>/02OnX`>/6ojO0k0[oZ<3[1OnW`>`9ojS0j`OoYl3[1onX`>/00onW`>coZ<3[ojS0j`06ojS0
j`KoZ;o[00?oZ<3[ojRojonX_n/01onX_n/5ojNoj`03o`000?nW_n_oYl3[01SoYl3[5_ooool00ol0
003oooooooooo`0booooo`009Oooool3o`0006;ooooo3onW_n/>ojO0j`;oZ;o[1OnW`>`7ojS0j`[o
Yl3/1_nX`>/9ojO0k0KoZ<3[00?oYl3/ojO0jonW`>/01onW`>/4ojS0j`CoYl3/2?nX`>/2ojRoj`Go
Z<3[2OnX_n/3ojNoj`;o00000_nW_n/7ojO0j`03ojNojonW`>_oYl3[00koYl3[5_ooool00ol0003o
ooooooooo`0booooo`008oooool2o`0006;ooooo3onW_n/@ojO0j`WoYl3/1?nX`>/=ojO0k0;oZ<3[
3OnW`>`2ojS0j`GoYl3/2OnW`>/00onX`>_oYl3/ojO0k005ojO0k0KoZ<3[00?oYl3/ojS0jonX`>/0
1_nX`>/6ojRoj`;oZ<3[0ol000000onW_n_o0000ojNoj`02ojNoj`CoYl3[1?nW_n/@ojO0jaKooooo
00?o0000ooooooooool0<Oooool0023ooooo0ol0001Rooooo`koYko[4?nW`>/=ojO0k003ojS0jonW
`>coYl3/02CoYl3/1_nW`>/;ojO0k0;oZ<3[1OnW`>`8ojS0j`;oZ;o[0_nX`>/3o`000003ojS0jonW
_n_oYko[00;oYko[00Go0000ojNojonW_n_oYko[ojO0j`07ojNoj`ooYl3[5oooool00ol0003ooooo
ooooo`0`ooooo`007oooool2o`0006;ooooo3OnW_n/@ojO0j`03ojO1k?nW`>coYl3/03GoYl3/0_nW
`>/FojO0k0KoZ<3[00?oYl3[ojS0jol000000_l00004ojS0j`GoYko[00?o0000ojS0jonX`>/02OnW
_n/?ojO0jaKooooo00?o0000ooooooooool0<?ooool001oooooo00?o0000ooooool00000Goooool<
ojNoja3oYl3[1OnW`N`GojO0k003ojO0jonW`>coYl3/00coYl3/00?oYl3[ojO0k?nW`>`03?nW`>`2
ojO0jaSoYl3/0_nX`>/2ojO0j`?o00002?nX`>/2ojNoj`?oZ<3[00?o0000ojS0jonX`>/01onW_n/0
0onX`>_oYl3[ojO0j`0=ojO0jaOooooo00?o0000ooooooooool0;oooool000cooooo1Ol00003oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool01?l0003oooooooooool0001Kooooo`coYko[4?nW
`>/9ojO1k1?oYl3/1OnW`>/:ojO0k0GoYl3[2_nW`>`6ojO0jaOoYl3/00CoYl3[o`000?l0003o0000
1?nW`>/<ojS0j`04o`000?nX`>_oZ<3[ojS0j`CoYko[1?nX`>/?ojO0jaOooooo00?o0000oooooooo
ool0;_ooool000cooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01_ooool2o`0000;ooooo00?o0000ooooooooool0EOooool=ojNoj`ooYl3[3OnW`N`?ojO0
k003ojNojonW`>_oYl3[00KoYl3[1_nW`>`00onW_n_oYl3[ojO0j`06ojO0j`KoYl3/00?oYko[ojO0
jonW`>/01onW`>/6ojO0k0;oYl3[3?nW`>`3o`0000SoYl3[3?nX`>/01Ol0003oZ<3[ojS0jonX`>_o
Yko[00OoZ<3[1_nW`>/00onW_n_oYl3[ojO0j`06ojO0jaKooooo00?o0000ooooooooool0;_ooool0
00Cooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4005
ooooo`;o00001?ooool00ol0003oooooooooo`1Aooooo`ooYko[3OnW`>/?ojO1k0;oYl3[3?nW`>`4
ojNoj`SoYl3[0_nW`>`5ojNoj`SoYl3[0_nW`>`5ojNoj`WoYl3[0_nW`>`6ojO0j`KoYl3/00?oYl3[
ojO0k?l000000_l00004ojO0k0KoYl3[00?oYl3/ojS0jonX`>/02onX`>/00ol0003oZ<3[ojS0j`09
ojS0j`;oYl3[1OnW_n/8ojO0jaKooooo00?o0000ooooooooool0;Oooool000kooooo00?oV9RHob4Q
8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`1=oooooa3oYko[3?nW`>/?ojO1k0KoYl3[2OnW`>`7ojNoj`KoYl3[00?oYkoZ
ojNojonW_n/01_nW_n/6ojO0j`WoYko[1_nW`>/2ojNoj`WoYl3[0_nW`>`3ojO0j`;o00002?nW`>`2
ojO0j`GoYl3/3?nX`>/00ol0003oZ<3[ojS0j`09ojS0j`SoYko[1onW`>/Gooooo`03o`000?oooooo
oooo02cooooo000?ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000005
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0BOooool@ojNoj`coYl3[3onW`N`:
ojO0j`KoYl3/2_nW_n/2ojO0j`GoYkoZ2?nW_n/2ojO0j`goYko[0_nW`>/6ojNoj`OoYl3[00?oYko[
ojO0jonW`>/00ol00003ojO0j`KoYl3/00?oYl3[ojO0k?nW`>`01_nW`>`6ojS0j`03ojO0k?nX`>_o
Z<3[00?oZ<3[00?o0000ojS0jonX`>/02OnX`>/8ojNoj`OoYl3[5Oooool2o`0002kooooo000@oooo
o`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`03ooooo`;o00001oooool0
0ol0003oooooooooo`16ooooo`ooYko[3?nW`>/?ojO1k0koYl3[0_nW`>`<ojNoj`03ojRoj_nW_n[o
YkoZ00KoYkoZ1_nW_n/00onX_n_oYko[ojNoj`0<ojNoj`;oZ;oZ2?nW_n/4ojO0j`;oYko[0ol00007
ojO0j`;oYl3/1OnW`>/8ojO0k0;oZ<3[1OnW`>`5ojS0j`03o`000?nX`>_oZ<3[00WoZ<3[1_nW_n/0
0onX`>_oYl3[ojO0j`06ojO0jaKooooo00?o0000ooooooooool0:oooool000cooooo00Go0000okZj
^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo04;ooooo3onW_n/<ojO0j`ooYl7/4?nW`>/=ojNoj`CoZ;oZ2?nW
_nX2ojNoj`GoZ;o[2_nW_n/6ojRojPSoYko[00?oYl3[ojNojol000000_l00003ojNoj`KoYl3[00?o
Yko[ojO0jonW`>/01_nW`>/?ojO0k0GoZ<3[00?o0000ojO0jonX`>/02OnX`>/2ojNoj`GoZ<3[2?nW
`>/Eooooo`03o`000?oooooooooo02_ooooo000<ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0nooooo`;oYl3[3onW_n/;ojO0j`koYl7/4?nW`>/>ojNoj`OoZ;oZ1_nW_nX00onX`>_oZ;o[
ojRoj`06ojRoj`KoYko[0_nX`>/8ojRojPKoYko[0ol00007ojNoj`;oYl3[1OnW_n/8ojO0j`ooYl3/
0_nX`>/2ojO0j`03o`000?nW`>_oYl3[013oZ<3[2?nW`>/Fooooo`03o`000?oooooooooo02[ooooo
000Nooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0>_ooool6ojO0j`ooYko[2?nW
`>/>ojO1k0ooYl3[00?oYkoZojNojonW_n/03?nW_n/2ojRoj`SoZ;oZ0_nW_nX5ojS0j`SoZ;o[0_nW
_n/6ojS0j`SoZ;oZ0_nW_n/3o`0000?oZ;o[1_nW_n/00onX`>_oYko[ojNoj`06ojNoj`KoYl3[00?o
Yko[ojO0k?nW`>`03OnW`>`5ojO0j`03o`000?nW`>_oYl3[013oZ<3[2?nW`>/Fooooo`03o`000?oo
oooooooo02Wooooo000Mooooo`?o00002oooool00ol0003oooooooooo`0fooooo`[oYl3[3onW_n/5
ojO0j`goYl7/3onW`>/5ojNojP[oYko[1_nX_n/6ojRojP;oZ<7[1onX`>/6ojRoj`;oZ<7[2?nX`>/6
ojRojP?o00001onX_n/2ojNoj`GoZ<3[2?nW_n/2ojO0j`GoYko[3onW`>`5ojO0j`03o`000?nW`>_o
Yl3[00ooZ<3[2?nW`>/Fooooo`03o`000?oooooooooo02Wooooo000Mooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool0<_ooool>ojO0j`ooYko[00?oYl3[ojO1k?nW`N`02onW`N`?ojO0
j`WoYkoZ1_nW_n/00onX`>_oZ;o[ojRoj`07ojRoj`;oZ;oZ1_nX`N/7ojS0j`;oZ;o[1_nX`N/8ojS0
j`;oZ;oZ0ol00002ojS1j`OoZ;o[00?oZ<7[ojS0jonX`>/01_nX`>/6ojNoj`03ojRojonW_n_oYko[
00KoYko[1_nW`>`00onW_n_oYl3/ojO0k006ojO0k0GoYl3[00?o0000ojO0k?nW`>`03onX`>/8ojO0
jaKooooo00?o0000ooooooooool0:?ooool001gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0_ooooo`ooYl3[3onW_n/<ojO1k0ooYl3[3OnW_nX2ojNoj`GoZ<3[1onX_n/2ojO1k0So
Z<7[1OnX`>/2ojO1k0SoZ<7[1_nX`>/3o`0000KoZ<7[1?nX_n/4ojS1j`SoZ<3[0_nW_n/5ojRoj`So
Yko[0_nW`>`5ojNoj`SoYl3/0_nW`>/2ojO0k004o`000?nW`>coYl3/ojO0k0KoZ<3[00?oYl3[ojS0
jonX`>/01_nX`>/7ojO0jaOooooo00?o0000ooooooooool09oooool001gooooo0_l0000?ooooo`03
o`000?oooooooooo02_ooooo3onW`>/?ojNoj`coYl7/3onW`>/?ojNojP;oYl3[1onX`>/4ojRoj`Go
Yl7/2?nX`N/00onX`>_oYl7/ojO1k004ojO1k0SoZ<7[0_nX`>/00onW`Nco0000o`000002ojO1k0So
Z<7[00?oZ;o[ojS1jonX`N/01OnX`N/7ojS0j`SoZ;o[1_nW_n/00onX_n_oYko[ojNoj`06ojNoj`Ko
Yl3/0_nW`>/4ojO0k004o`000?nW`>coYl3/ojO0k0;oZ<3[1OnW`>/8ojS0j`OoYl3[5_ooool00ol0
003oooooooooo`0Wooooo`007Oooool00ol0003oooooooooo`0?ooooo`;o0000:?ooool2ojS0j`go
Yl3[3onW_n/2ojO0j`[oYl7/3onW`>/?ojNojPKoYl3[1onX`>/00onX_n_oYl7/ojO1k006ojO1k0Ko
Z<7[2OnW`N`6ojS1j`04ojO1k?l0003o0000o`0000GoYl7/1_nX`N/2ojO1k0SoZ<7[1onX`>/8ojRo
j`;oYko[1OnX_n/8ojNoj`;oYl3/1_nW`>/4ojO0k003o`000?nW`>coYl3/00SoYl3[1onX`>/8ojO0
jaKooooo00?o0000ooooooooool09_ooool001gooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Rooooo`KoZ<3[2OnW`>/?ojNoj`KoYl3[1_nW`N`?ojO0j`;oYko[3OnW_nX:ojO0j`Go
Z<3[2onW`N`2ojS1j`goYl7/0_nX`N/01?nW`Nco0000o`000?l00009ojO1k0;oZ<7[1_nW`N`6ojS1
j`03ojO0k?nX`>_oZ<3[00KoZ<3[1_nX_n/00onX`>_oZ;o[ojRoj`06ojRoj`SoYko[2?nW`>/4ojO0
k003o`000?nW`>coYl3/00SoYl3[1onX`>/8ojO0jaKooooo00?o0000ooooooooool09Oooool001go
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Nooooo`[oZ<3[1OnW`>/?ojNoj`[o
Yl3[0onW`N`>ojO0j`KoYko[2OnW_nX>ojO0j`03ojS0jonW`NcoYl7/01[oYl7/00CoYl3/o`000?l0
003o00002onW`N`2ojO0k0SoYl7/0_nX`N/5ojO0k0SoZ<3[0_nX_n/5ojS0j`SoZ;o[2?nW_n/6ojO0
j`03ojNojonW`>coYl3/00;oYl3/00Co0000ojO0k?nW`>coYl3/1onW`>/8ojS0j`KoYl3[00?oZ<3[
ooooooooool05?ooool2o`0002Kooooo000Looooo`?o00005?ooool00ol0003oooooooooo`0Joooo
o`koZ<3[00?oYl3[ojNojonW_n/03OnW_n/>ojO0j`03ojO1k?nW`>_oYl3[00_oYl3[2OnW_n/6ojNo
jPooYl3[6onW`N`01OnW`>co0000o`000?l0003oYl3/00[oYl7/1_nW`>`6ojO1k0WoYl3/1_nX`>/0
0onW`>coZ<3[ojS0j`06ojS0j`KoZ;o[00?oZ<3[ojNojonW_n/01onW_n/2ojO0j`GoYko[1?nW`>`0
1?l0003oYl3/ojO0k?nW`>`7ojO0j`SoZ<3[0_nW`>/5ojS0jaCooooo00?o0000ooooool000009_oo
ool001cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Gooooo`;oYl3[3OnX`>/2
ojO0j`goYko[3onW`>/2ojS1j`[oYl3[3OnW_n/2ojNojPooYl3[6onW`N`01?nW`>_o0000o`000?l0
0005ojO0k0KoYl7/0_nW`>/8ojO0k0;oYl7/3OnW`>`2ojS0j`GoYl3/2?nX`>/2ojRoj`GoZ<3[1onW
_n/00onX`>_oYko[ojNoj`06ojNoj`CoYl3/00?o0000ojO0k?nW`>/02?nW`>/?ojS0jaKooooo00?o
0000ooooooooool08oooool000[ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;o
k^k^1_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01Cooooo1OnW`>/9ojS0j`Ko
Yl3[2OnW_n/?ojO0j`KoZ<7[1_nW`>/?ojNoj`ooYl3[6onW`N`01OnW`>_o0000o`000?l0003oYl3[
00SoYl3/0_nW`N`6ojO0j`KoYl3/00?oYko[ojO0k?nW`>`05OnW`>`6ojS0j`03ojO0jonX`>_oZ<3[
00KoZ<3[1?nW_n/4ojS0j`SoYko[0_nW`>`00onW`>_o0000ojO0j`0:ojO0j`ooZ<3[5Oooool00ol0
003oooooooooo`0Sooooo`003?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo017ooooo2?nW`>/5ojS0
j`[oYl3[1onW_n/=ojO0j`?oZ<7/1onX`N/2ojO0j`ooYko[3onW`>/<ojO1k003ojO0k?nW`NcoYl7/
00coYl7/00CoYko[o`000?l0003o00001OnW`>/6ojO0k0;oYko[2?nW`>/2ojO0k0GoYko[5onW`>`2
ojS0j`GoYl3[2?nX`>/00onW_n_oZ<3[ojS0j`05ojS0j`OoYko[1?nW`>/00ol0003oYl3[ojO0j`08
ojO0j`ooZ<3[5_ooool00ol0003oooooooooo`0Rooooo`0000?oooooo`000?l000001?l00005oooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`;o00006Oooool0
0ol0003oooooooooo`0>ooooo`_oYl3[00?oZ<3[ojO0jonW`>/03?nW`>/7ojNoj`WoYl3[1onX`N`5
ojS1ja7oYko[3OnW`>/<ojO1k0GoYl3/2_nW`N`2ojNoj`;o000000?oYko[ojO0jonW`>/01_nW`>/2
ojO0k0KoYko[1_nW`>/00onW_^[oYko[ojNoj`06ojNoj`KoYl3/00?oYko[ojO0k?nW`>`03OnW`>`8
ojO0ja3oZ<3[1onW_n/4ojO0j`03o`000?nW`>_oYl3[00SoYl3[3onX`>/Fooooo`03o`000?oooooo
oooo027ooooo000<ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02_ooool=ojO0j`03ojS0jonW`>_o
Yl3[00coYl3[2OnW_n/5ojO0j`?oZ<7[2?nX`N`00onX`N_oYko[ojNoj`0CojNoj`WoYl3[3?nW`N`2
ojO0j`OoYl3/1_nW`N`00onW_^[oYko[o`000002o`0000CoYko[1_nW`>/2ojRnjPSoYko[0_nW`>/5
ojNnjPSoYko[0_nW`>`5ojNoj`ooYl3/2?nW`>/?ojS0j`OoYko[1OnW`>/00ol0003oYl3[ojO0j`07
ojO0ja3oZ<3[5Oooool00ol0003oooooooooo`0Qooooo`003?ooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00Oooooo0onW_n/9ojO0j`GoZ<3[2_nW`>/=ojNoj`03ojO0jonX`N_oZ<7[00GoZ<7[1_nX`N`0
0onW`>_oYko[ojNoj`0EojNoj`GoYl3[3?nW`N`6ojO0j`OoYl3/0_nW`N`2ojNnjP?o00002?nW_n/2
ojO0j`KoZ;kZ1_nW_n/00onX_n[oYkkZojNnjP06ojNnjPKoYko[00?oZ;oZojNojonW_n/01_nW_n/6
ojO0k003ojJojonW`>coYl3/00KoYl3/1_nW`>/2ojO0k0ooZ<3[1onW_n/4ojO0j`03o`000?nW`>_o
Yl3[00SoYl3[3onX`>/Fooooo`03o`000?oooooooooo023ooooo000<ooooo`03o`000?oooooooooo
00;ooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool00oooool7ojNoj`GoYl3[2OnX`>/6ojO0j`ooYko[0_nW`>/8ojS1j`;oZ<7/1OnW`>/G
ojNoj`03ojO0jonW`NcoYl7/00[oYl7/2_nW`>/5ojO0k0;oYkkZ0ol00004ojNnjPKoYko[00?oZ;oZ
ojRnj_nX_^X01onX_^X2ojNoj`GoZ;oZ2?nW_^X2ojNoj`GoZ;oZ2?nW_n/2ojO0k0GoY[o[2?nW`>`2
ojO0j`KoYl3/1_nX`>/00onW`>_oZ<3[ojS0j`05ojS0j`KoYko[00?oZ<3[ojO0jonW`>/00onW`>/0
0ol0003oYl3[ojO0j`08ojO0j`ooZ<3[5_ooool00ol0003oooooooooo`0Oooooo`003?ooool00ol0
003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2o`0001kooooo00?o0000
oooooonW_n/02_nW_n/00onW`>_oZ<3[ojS0j`0;ojS0j`;oYl3[3onW_n/6ojO0j`KoZ<7[0_nX`>/7
ojO0jaGoYko[2onW`N`>ojO0j`03ojO0k?nW_^[oYkkZ00?o00002?nW_^X2ojNoj`GoZ;oZ1onX_^X0
0onX`>_oZ;oZojRojP06ojRojPKoYkkZ00?oZL3[ojRoj_nX_nX01_nX_nX6ojNoj`;oZ;oZ1onV_n/6
ojO0k0;oY/3/2?nW`>`2ojS0j`GoYl3[1onX`>/2ojNoj`GoZ<3[1OnW`>/00ol0003oYl3[ojO0j`08
ojO0j`KoZ<3[00?oYl3[ojS0jonX`>/01_nX`>/Eooooo`03o`000?oooooooooo01oooooo000:oooo
o`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooo
oooo01cooooo3OnW_n/2ojO0j`coZ<3[0_nW`>/=ojNoj`[oYl3[0_nX`N/6ojS0j`OoYl3[4OnW_n/<
ojO1k0ooYl3[00CoYkkZo`000?l0003o00002_nW_^X2ojRoj`OoZ;oZ1?nX_^X4ojS0j`SoZ;oZ0_nW
_^X5ojW0j`SoZ;oZ0_nW_n/6ojRojPOoY[o[0_nW`>`6ojK0k0KoYl3/00?oY/3/ojO0jonW`>/01OnW
`>/?ojS0j`GoYl3[00?o0000ojO0jonW`>/02?nW`>/2ojS0j`GoYl3[2?nX`>/Eooooo`03o`000?oo
oooooooo01kooooo000Kooooo`03o`000?oooooooooo01[ooooo0onW`>/9ojNoj`KoYl3[2?nX`>/6
ojO0j`WoYko[3?nW`>/2ojS1j`SoZ<3[1OnW`>/?ojNoj`coYl7/3onW`>/01?nW_^[o0000o`000?l0
000:ojNnjPKoZ;o[1onX_nX00onX_^[oZ<3[ojS0j`05ojS0j`KoZ;oZ00?oZ<7[ojW0jonY`>/01_nY
`>/6ojRojP03ojW0jonX_n[oZ;oZ00OoZ;oZ0onV_n/4ojNoj`SoY/3/0_nW`>`5ojK0k0OoYl3[3onX
`>/4ojO0j`03o`000?nW`>_oYl3[013oYl3[1onX`>/Fooooo`03o`000?oooooooooo01gooooo000K
ooooo`03o`000?oooooooooo01Oooooo1onW`>/7ojNoj`SoYl3[1onX`>/7ojO0j`SoYko[2OnW`>/6
ojS1j`SoZ<3[00?oYl3[ojNojonW_n/03OnW_n/<ojO1k003ojS1k?nW`>_oYl3[00coYl3[00CoYkkZ
o`000?l0003o00002onW_^X2ojS0j`OoZ;o[1OnX_nX2ojO1k0SoZ<3[0_nX_nX5ojS1j`SoZL3[0_nX
_nX5ojW0j`OoZ;oZ00?oZL3ZojNojonW_n/01_nW_n/6ojK0k003ojNojonV`>coY/3/00GoY/3/1_nW
`>/00onW`>coZ<3[ojS0j`0>ojS0j`CoYl3[00?o0000ojO0jonW`>/04?nW`>/7ojS0jaCooooo0_l0
000Oooooo`006oooool2o`0001Cooooo3?nW`>/7ojNoj`SoYl3[1onX`>/7ojO0j`SoYko[1_nW`>/9
ojS1j`KoZ<3[3_nW_n/3ojO0j`WoYl7/1OnX`N`:ojO0j`;oYkkZ0_l0000;ojNnjPKoZ<3[1onX_n/0
0onX_n[oYl7/ojO1k004ojO1k0KoZ<3[00?oYl7/ojS1jonX`N/01_nX`N/6ojW0j`03ojS1k?nY`>_o
ZL3[00KoZL3[1?nX_nX4ojW0jPSoYko[0_nV`>`5ojNoj`OoY/3/0_nW`>/5ojO0k13oZ<3[1?nW`>/0
0ol0003oYl3[ojO0j`0?ojO0j`OoZ<3[5_ooool00ol0003oooooooooo`0Looooo`006_ooool00ol0
003oooooooooo`0@ooooo`;oZ<3[3OnW`>/9ojNoj`KoYl3[2OnX`>/5ojO0j`[oYko[0_nW`>/=ojS1
j`;oZ<3[3_nW_n/7ojO0j`GoYl7/2OnX`N`6ojO0j`;oYkkZ0ol0000:ojNnjP;oYl3[2?nX`>/3ojRo
j`_oYl7/0_nX`>/5ojO1k0SoZ<7[0_nY`>/5ojS1k0SoZL3[00?oZ;oZojW0j_nY`>X01OnY`>X6ojNo
j`03ojVoj_nW_n_oYko[00GoYko[1onV`>`8ojO0k13oZ<3[1?nW`>/00ol0003oYl3[ojO0j`0?ojO0
j`OoZ<3[5Oooool00ol0003oooooooooo`0Looooo`006_ooool00ol0003oooooooooo`0=ooooo`Ko
Z<3[2OnW`>/=ojNoj`;oYl3[3OnX`>/00onW`>_oYko[ojNoj`0:ojNoj`;oZ<3[3OnX`N/2ojO0j`go
Yko[2_nW`>/00onW`NcoZ<7/ojS1k00;ojS1k0;oYl3[0_nW_^X3o`0000[oYkkZ1_nW`>/6ojS0j`ko
Yl7/0_nW`Nd7ojO1k0KoZ<7[0_nW`N`7ojS1k0KoZL3[0_nX`N/8ojW0jP;oYko[1OnY_nX7ojNoj`Oo
Y/3/2?nW`>`?ojS0j`CoYl3[00?o0000ojO0jonW`>/01_nW`>/2ojNoj`OoYl3[2?nX`>/Eooooo`03
o`000?oooooooooo01_ooooo000Jooooo`03o`000?oooooooooo00_ooooo0_nW`>/7ojS0j`OoYl3[
3OnW_n/=ojS0j`GoYl3[2?nW_n/6ojS0j`WoZ<7[1_nW`>/9ojNoj`coYl3[3_nX`N`2ojNnjP?o0000
2_nW_^X:ojO0j`;oZ<3[3_nW`N`6ojO1k@OoYl7/0_nX`N/6ojO1k0OoZ<7/0_nY`>/6ojS1j`KoZL3Z
00?oZ<7[ojVoj_nY_nX01OnY_nX8ojNoj`OoY/3/2?nW`>`?ojS0j`CoYl3[00?o0000ojO0jonW`>/0
0_nW`>/6ojNoj`OoYl3[2?nX`>/Eooooo`03o`000?oooooooooo00Kooooo1Ol0000?ooooo`006_oo
ool2o`0000Wooooo1_nW`>/7ojS0j`OoYl3[2OnW_n/<ojS0j`[oYl3[1onW_n/7ojS0j`KoZ<7[0_nX
`>/7ojO0j`SoYko[2OnW`>/>ojS1k0;oYkkZ0ol0000:ojNnjPcoYl3[00?oYl;/ojO1k?nW`N`03OnW
`N`8ojO1k@GoYl7/0_nV`N`8ojO1k0?oZ<7/1?nW`N`8ojS1j`;oZL3Z1OnX`N/7ojVojPSoYko[1onV
`>`8ojO0k0koZ<3[1OnW`>/00ol0003oYl3[ojO0j`07ojNoj`SoYl3[2?nX`>/Dooooo`03o`000?oo
oooooooo00Kooooo00GoV9RHob4Q8Oo^k^koooooodA4A00?ooooo`006_ooool00ol0003ooooooooo
o`06ooooo`;oYko[1onW`>/5ojS0j`WoYl3[2OnW_n/8ojS0j`koYl3[1onW_n/7ojS0j`;oZ<7[1_nX
`>/7ojO0j`SoYko[1OnW`>/?ojS1k004ojNojol0003o0000o`0000[oYkkZ3?nW`>/5ojO2k0ooYl7/
2?nW`Nd00onW`NcoY/7/ojK1k004ojK1k0KoYl7/00?oY/3/ojO1k?nW`N`01_nW`N`6ojS1j`03ojO1
k?nX`N_oZ<7[00KoZ<7[1OnY_nX2ojW0j`SoYko[0onV`>`4ojJok0SoYl3/3_nX`>/4ojO0j`04o`00
0?nW`>_oYl3[ojO0j`OoYko[2?nW`>/7ojS0jaGooooo00?o0000ooooooooool01_ooool00onHV9So
8B4Qonk^kP0@ooooo`006_ooool00ol0003oooooooooo`03ooooo`KoYko[1onW`>/00onX`>_oYl3[
ojO0j`0;ojO0j`WoYko[1onX`>/=ojO0j`WoYko[1OnX`>/3ojS1j`OoZ<3[0onW`>/<ojNoj`03ojO0
jonX`NcoZ<7/00goZ<7/00GoYko[o`000?l0003o0000ojNoj`09ojNnjPcoYl3[2OnW`^`?ojO1k0Ko
Yl7]0_nV_n/7ojK1k0;oYl7/1OnV`>`8ojO1k0;oZ<7[1OnW`N`8ojS1j`03ojVoj_nY`>_oZL3[00Co
ZL3[1_nW_n/00onX`>_oY[o/ojJok006ojJok0KoYl3/00?oY/3/ojS0jonX`>/03OnX`>/4ojO0j`04
o`000?nW`>_oYl3[ojO0j`OoYko[2?nW`>/7ojS0jaGooooo00?o0000ooooooooool01_ooool00onH
V9So8B4Qonk^kP0?ooooo`006_ooool00ol0003oooooooooo`0:ojNoj`GoYl3[0_nX`>/<ojO0j`_o
Yko[1onX`>/9ojO0j`goYko[00?oZ<3[ojS1jonX`N/01OnX`N/5ojS0j`ooYko[00?oZ<7[ojS1k?nX
`N`02onX`N`01?nX`>_o0000o`000?l00005ojNoj`KoYkkZ0_nW_n/9ojO0j`goYl;/3onW`N`2ojO1
k@KoY[o[1OnV`N`00onV_^[oY/3/ojK0k006ojK0k0KoYl7/00?oY/3/ojO1k?nW`N`01_nW`N`6ojS1
j`03ojO0k?nY`>_oZL3[00KoZL3[0_nW_n/5ojS0j`SoY[o/0_nW`>`5ojK0k0ooZ<3[1?nW`>/00ol0
003oYl3[ojO0j`08ojNoj`OoYl3[1onX`>/Eooooo`03o`000?oooooooooo00Oooooo00?oMgMgofIV
I_ooool03_ooool001Wooooo00?o0000ojNojonW_n/03?nW_n/00onW`>_oZ<3[ojS0j`04ojS0j`So
Yl3[3OnW_n/9ojS0j`GoYl3[3onW_n/:ojS1j`03ojS0jonW_n_oYko[00goYko[1OnX`N/9ojS1k004
ojS0jol0003o0000o`0000?oZ<3[1_nW_n/2ojNnjPKoYko[1_nW`>/00onW`NcoYl;/ojO2k00;ojO2
k0;oYl3[2onW`N`4ojNmjPSoY[o[00?oY/7/ojJnj_nV_^X00onV_^X8ojK0k0;oYl7/1OnV`>`8ojO1
k0;oZ<7[1OnW`>`6ojW0j`03ojS1jonX`>_oZ<3[00KoZ<3[1_nV_n`00onW_n_oY/3/ojK0k006ojK0
k0GoZ<3[0_nW`>/8ojS0j`CoYl3[00?o0000ojO0jonW`>/02?nW_n/7ojO0j`OoZ<3[5Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00gooooo000Iooooo`03o`000?nW_n_oYko[00_o
Yko[2OnX`>/8ojO0j`WoYko[3OnX`>/00onW`>_oYko[ojNoj`0=ojNoj`coZ<7[00?oZ<3[ojNojonW
_n/02onW_n/2ojO0j`OoZ<7[1onX`N`2o`0000OoZ<3[3_nW_n/2ojO0j`GoYl7/2OnW`^`6ojO0j`Ko
Yl7/00?oZ;gYojNmj_nW_NX01_nW_NX6ojJoj`03ojRmjOnV_^[oY[kZ00GoY[kZ1_nV`>`2ojJnjPOo
Y/3/1_nW`N`2ojK0k0OoYl3/0_nY`>/5ojS1j`SoZ<3[0_nV_n`5ojNoj`SoY/3/00?oZ<3[ojO0jonW
`>/01?nW`>/7ojS0j`CoYl3[00Co0000ojO0jonW`>_oYl3[1onW_n/7ojO0j`SoZ<3[4oooool3o`00
00Cooooo00Go0000okZj^_ooooooV9RHoa0@400?ooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Kooooo00?o0000oooooonW_n/02?nW_n/=ojS0j`SoYl3[1OnW_n/2ojO0j`goZ<3[0_nW`>/<
ojNoj`?oYl3[2OnX`N/5ojS0j`WoYko[1_nW`>/7ojS1j`?oZ<7/0ol00002ojS1k0KoZ<3[00?oYkkZ
ojNojonW_n/02onW_n/9ojO1k0KoYl;/2OnW`>/2ojO1k0GoZ;gY2?nW_NX2ojJoj`GoZ;gY1onV_^X2
ojK0k0KoY[kZ1onV`>`2ojO1k0KoY/3/1_nW`>`8ojS1j`KoZ<3[0_nY`>X7ojNoj`KoY/3/00?oY[o/
ojO0jonW`>/01_nW`>/7ojS0j`CoYl3[00Co0000ojO0jonW`>_oYl3[1onW_n/7ojO0j`SoZ<3[5?oo
ool00ol0003oooooooooo`02ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03oooool000kooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00SoYko[3?nX`>/:ojO0j`03ojNo
jonW`>_oYl3[00CoYl3[2OnX`>/6ojO0j`SoYko[1onW`>/7ojS1j`OoZ<3[1onW_n/8ojO0j`GoZ<7[
00CoZ<7/o`000?l0003o00001_nX`N`2ojS0j`GoYkkZ2OnW_n/=ojO1k0;oYl;/2onW`>/9ojRmj@Ko
YkgZ00?oZKoZojRmjOnX_NT01_nX_NT5ojJnjP;oZKoY2?nV_^X3ojK0k0CoY[k[2?nV`>`6ojO0k0So
Z<7[0_nX`>/6ojW0jPOoYko[0_nV`>`5ojJok0OoYl3[2?nX`>/4ojO0j`03o`000?nW`>_oYl3[00Oo
Yko[2?nW`>/8ojS0jaCooooo00?o0000ooooooooool05Oooool000kooooo00Go410@oooooooooooo
oooooa0@4006ooooo`;o00000_ooool8ojNoj`SoZ<3[3?nW`>/2ojNoj`OoYl3[2?nX`>/7ojO0j`So
Yko[1onW`>/7ojS1j`OoZ<3[1onW_n/8ojO0j`03ojS1jonX`Nco000000;o00002?nX`N`2ojNoj`Oo
YkkZ1_nW_n/>ojO1k0;oZ<7/2OnW`>/=ojRmj@;oYkgZ1OnY_nX8ojRmj@03ojJnj_nY_nWoZKoY00Co
ZKoY1_nV_^X00onY_nWoY[k[ojJnj`06ojJnj`KoY/3/00?oYKo/ojO0k?nW`>`01OnW`>`6ojS1j`;o
Z<3[2?nY`>X6ojNoj`SoY[o/1onW`>/8ojS0j`CoYl3[00?o0000ojO0jonW`>/01onW_n/8ojO0j`Oo
Z<3[5Oooool00ol0003oooooooooo`0Dooooo`003_ooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooooooool00oooool7ojNoj`SoZ<3[2?nW`>/6ojNoj`OoYl3[2?nX`>/7ojO0j`So
Yko[1OnW`>/9ojS1j`GoZ<3[2OnW_n/6ojO0j`?o00002?nX`N`6ojNoj`OoYkkZ0_nW_n/>ojO1k0Ko
Z<7/1_nW`>/00onW_NWoZ;gYojRmj@0;ojRmj@03ojS0jonY_n[oZKoZ00KoZKoZ1_nX_NT2ojW1j`Oo
ZKoY0_nV_^X5ojVoj@SoY[k[0_nV`>`5ojFok0OoYl3/0_nX`N/6ojS0j`KoZL3Z00?oZL3[ojNojonW
_n/01OnW_n/7ojJok0SoYl3[1onX`>/4ojO0j`03o`000?nW`>_oYl3[00SoYko[2?nW`>/7ojS0jaCo
oooo00?o0000ooooooooool05?ooool000kooooo00Go0000ooooooooooooooooo`000005ooooo`03
o`000?oooooooooo00Gooooo1OnW_n/:ojS0j`OoYl3[1onW_n/5ojO0j`[oZ<3[0onW`>/<ojNoj`03
ojO0jonX`N_oZ<7[00_oZ<7[00?oZ<3[ojNojonW_n/02onW_n/2ojO0j`?o00000onX`N/6ojS1k003
ojS0jonW_n_oYko[00KoYko[1OnW_^X2ojO0j`coYl7/0onX`^`7ojS1k0;oYl3[1OnW_NT9ojRmj@Go
Z<3[2?nY_nX2ojRmj@KoZL7[1OnY_nT00onY`N[oZKoYojVoj@06ojVoj@KoY[k[0_nX_nX6ojFok0Ko
Yl3/0_nV`>`8ojS0j`;oZL3Z1OnY`>/7ojNoj`OoY[o/2?nW`>/7ojS0j`CoYl3[00?o0000ojO0jonW
`>/02?nW_n/7ojO0j`OoZ<3[5Oooool00ol0003oooooooooo`0Cooooo`003_ooool01Ol@413ooooo
oooooooooooo410@00Gooooo00?o0000ooooooooool01_ooool00onW_n_oZ<3[ojS0j`0<ojS0j`Oo
Yl3[1onW_n/00onW`>_oZ<3[ojS0j`0:ojS0j`;oYl3[3OnW_n/00onW`>_oZ<7[ojS1j`0;ojS1j`;o
Yl3[2onW_n/01?nX`>_o0000o`000?l00007ojS1j`;oZ<7/1OnX`>/8ojNoj`03ojNnj_nW`>_oYl3[
00CoYl3[2?nW`N`7ojS2k0GoZ<7/2OnW_NT6ojRmj@SoZ<3[1_nY_nX2ojNmj@SoZL7[00?oZKoYojW1
j_nY`NX00onY`NX8ojVoj@;oY[k[1_nX_nX6ojFok0;oYl3/1_nV`>`6ojS0j`03ojO0jonY`>_oZL3[
00GoZL3[1_nW_n/00onW`>_oY[o/ojJok006ojJok0OoYl3[2?nX`>/4ojO0j`03o`000?nW`>_oYl3[
00SoYko[1onW`>/7ojS0jaGooooo00?o0000ooooooooool04_ooool000kooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o00002?ooool=ojS0j`WoYl3[1OnW_n/3ojO0j`SoZ<3[1_nW`>/9ojNo
j`GoYl3[2OnX`N/6ojO0j`OoYko[00CoZ<3[o`000?l0003o00001?nX`>/7ojS1j`OoZ<3[1_nW_n/2
ojJoj`OoYl3[0onW`N`<ojS2k003ojS1k?nW_NWoYkgY00_oYkgY0_nX_NT<ojS0j`;oZKoZ1_nW_NT6
ojW1j`03ojNmjOnY`N[oZL7Z00GoZL7Z1_nY_nT00on[`N[oZ;oZojRojP07ojRojP?oYKo/0onV_n`8
ojK0k0;oZ<3[1OnW`>/7ojW0j`;oYko[1OnW`>/8ojJok0OoYl3[1_nX`>/00onX`N_oYl3[ojO0j`02
ojO0j`04o`000?nW`>_oYl3[ojO0j`OoYko[1onW`>/7ojS0jaGooooo00?o0000ooooooooool04_oo
ool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo00Sooooo2OnX
`>/=ojO0j`03ojNojonW`>_oYl3[00GoYl3[1onX`>/7ojO0j`SoYko[1_nW`>/6ojS1j`;oZ<3[1onW
`>/5ojNoj`;o00002?nX`>/7ojS1j`OoZ<3[0_nW_n/6ojJoj`GoYl3[0_nX`N`=ojS2k003ojNnjOnW
_NWoYkgY00_oYkgY0_nW_n/<ojS0j`;oZ;cX2?nW_NT2ojW1j`GoYkgY1onY`NX2ojVoj@GoZl7Z1onX
_nX00onZ`>WoY[o/ojJok005ojJok0KoY/3/00?oY[o/ojO0jonW`>/01_nW`>/5ojW0j`;oZL7[1onW
`>/6ojJok003ojJojonW`>_oYl3[00KoYl3[0_nX`>/5ojS1j`CoYl3[00Co0000ojO0jonW`>_oYl3[
1onW_n/7ojO0j`OoZ<3[5Oooool00ol0003oooooooooo`0Aooooo`006?ooool00ol0003ooooooooo
o`09ooooo`SoZ<3[2_nW`>/4ojNoj`SoYl3[1onX`>/7ojO0j`SoYko[1_nW`>/2ojS1j`KoZ<3[1OnW
`>/3ojNoj`?o00000onW_n/6ojS0j`WoZ<7[1OnX`>/2ojJnj`SoY[o[00?oYl3[ojS1k?nX`N`01?nX
`N`9ojS2k0GoYkkY2OnW_NT6ojNoj`SoZ<3[1_nX_>P6ojNmj@03ojVghonW_NWoYkgY00KoYkgY1OnY
`NX2ojNnj@OoZl7Z1?nX_nX4oj[0j@OoY[o/0_nV`>`5ojJok0SoYl3[00?oZL3[ojW1jonY`N/01?nY
`N/7ojO0j`;oY[o/1OnV_n/7ojO0j`SoZ<7[1?nW`>/00ol0003oYl3[ojO0j`07ojNoj`KoYl3[2OnX
`>/Eooooo`03o`000?oooooooooo013ooooo000Hooooo`03o`000?oooooooooo00[ooooo2?nX`>/7
ojO0j`OoYko[1_nW`>/9ojS0j`GoYl3[2_nW_n/3ojO0j`CoZ<7[1onX`>/01?nW`>_oYko[ojNojonW
_n/3o`0000OoYko[0_nX`>/=ojS1j`03ojS0jonV_^_oY[k[00CoY[k[1_nV_n/00onX`N_oZ<7/ojS1
k006ojS1k0GoZ<;/0_nX_n/7ojNnj@GoYkgY2_nW_n/3ojS0j`CoZ;[V1onX_>P2ojNmj@GoZKOS2?nW
_NT00onY`N[oYkkYojNnj@04ojNnj@OoZl7Z00?oZ;oZoj[0jOnZ`>T01OnZ`>T5ojJok003ojJojonV
_ncoY[o/00KoY[o/1onW`>/8ojW1j`OoYl3[1onV_n/7ojO0j`SoZ<7[1?nW`>/00ol0003oYl3[ojO0
j`07ojNoj`;oYl3[3?nX`>/Eooooo`;o00004Oooool001Oooooo0ol0000=ooooo`OoZ<3[1onW`>/7
ojNoj`;oYl3[3OnX`>/00onW`>_oYko[ojNoj`0:ojNoj`;oYl3[1onX`N/5ojS0j`;oYl3[0ol00009
ojNoj`?oZ<3[2_nX`N/4ojNoj`OoY[k[0_nV_n/5ojS1j`SoZ<7/00?oZ<;/ojRojonX_n/01?nX_n/7
ojNnj@03ojNmjOnW_n_oYko[00[oYko[00?oYkWVojRji_nX^^H01_nX^^H5ojRlj003ojNXeonY]n?o
ZKOS00KoZKOS1_nW_NT2ojZhh`OoYkkY0on[`NX4ojW0j`SoZ/3Y00?oY[o/ojJojonV_n/00onV_n/8
ojJok0OoYl3[1onY`N/8ojO0j`KoY[o[2?nW`>/7ojS1j`CoYl3[00Co0000ojO0jonW`>_oYl3[1onW
_n/>ojS0ja?ooooo00?o0000ooooool000004Oooool001Oooooo00?o0000ooooooooool03_ooool5
ojS0j`WoYl3[2?nW_n/<ojS0j`;oYl3[2OnW_n/6ojO0j`OoZ<7[00?oZ<3[ojO0jonW`>/00ol00000
0onW`>_oYko[ojNoj`06ojNoj`OoZ<3[1onX`N/7ojNoj`GoY[k[0_nW_n/7ojS1j`SoZ<7/1onX_n/3
ojNnj@CoY[k[2OnW_n/5ojNiiPSoZ;[V00?oZ;cXojNXeonWZ=L00onWZ=L8ojVgh`;oYkgY1_nZ^><5
ojNnj@03ojZojOnY`>_oZL3[00KoZL3[1_nZ`>T00on[`NWoY[o[ojJoj`05ojJoj`KoY[o/0_nU_n`7
ojO0j`OoZL7[2?nW`>/6ojJoj`SoYl3[1onX`N/4ojO0j`03o`000?nW`>_oYko[00SoYko[3_nX`>/D
ooooo`03o`000?oooooooooo00oooooo000Gooooo`03o`000?oooooooooo00oooooo00?oZ<3[ojO0
jonW`>/02onW`>/8ojNoj`SoZ<3[1_nW`>/7ojNoj`SoYl3[1OnX`N/01?nX`>_o0000o`000?l00005
ojO0j`OoYko[2?nX`>/7ojS1j`OoYko[00?oY[k[ojNojonW_n/01?nW_n/7ojS1j`SoZ<7/1OnX_n/2
ojJmj@OoY[k[1_nW_n/00onW_>SoYkWVojNiiP05ojNiiPKoZ;[V00?oYYk>ojNXeonWZ=L01OnWZ=L6
ojVgh`03oj^SconZ^>?oZ[SS00OoZ[SS00?oYkkYojZojOnZ_nT00onZ_nT8ojW0j`;oZ/3Y1On[`NT7
ojJoj`;oY[o/1_nU_n`6ojO0j`SoZL7[1onW`>/7ojJoj`KoYl3[00?oZ<3[ojS1jonX`N/01_nX`N/2
ojO0j`;oYko[00?o0000ojNojonW_n/02?nW_n/>ojS0jaCooooo00?o0000ooooooooool03_ooool0
01Oooooo00?o0000ooooooooool04?ooool<ojO0j`[oYko[1onX`>/7ojO0j`OoYko[2?nW`>/00onX
`N_oZ<3[o`000002o`0000;oZ<3[1onW`>/7ojNoj`KoZ<3[2OnX`N/5ojNoj`;oY[k[1onW_n/5ojS1
j`;oZ<;/2?nX`N`00onX_n_oY[gYojJmj@04ojJmj@OoY[k[0_nW_n/5ojNlj0OoYkWV0_nX^^H5ojJN
cPOoYjSG0_nY]n<5oj^Sc`OoZ[SS00?o[k7JojZojOnZ_nT01OnZ_nT6ojW0j`;oZ;o[1on[`NT3ojJo
j`CoYl3[2?nU_n`6ojO0j`SoZL7[1onW`>/7ojJoj`;oYl3[1OnX`>/7ojS1j`GoYko[00?o0000ojNo
jonW_n/01onW_n/=ojS0j`03ojO0jooooooooooo01?ooooo00?o0000ooooooooool03Oooool001Oo
oooo0_l0000Booooo`SoYl3[3?nW_n/9ojS0j`GoYl3[2OnW_n/6ojO0j`?o00001_nX`>/3ojO0j`Co
Y[o[1onW_n/2ojS0j`goZ<7[00?oYko[ojJnjonV_^/01?nV_^/7ojNoj`03ojS1jonX`^coZ<;/00Co
Z<;/1_nX`N`00onV_^[oY[gYojJmj@06ojJmj@GoY[k[00?oYkgYojNlj?nW_>P01_nW_>P5ojNiiP03
oj>MconVW/koYYk>00KoYYk>1OnWZ=L00onZTkgoZj??oj^Sc`06oj^Sc`CoZ[SS1?n_/MX7ojZoj@;o
ZL3[1_nX_n/5oj_1j@03oj_1j_nW`>_oYl3[00KoYl3[1_nU_n`00onV_ncoYl3[ojO0j`05ojO0j`Oo
ZL7[2?nW`>/7ojJoj`OoZ<3[1onX`N/4ojNoj`03o`000?nW_n_oYko[00SoYko[2OnX`>/5ojO0jaCo
oooo00?o0000ooooooooool03Oooool001Oooooo00?o0000ooooooooool04_ooool8ojO0j`SoYko[
3OnX`>/00onW`>_oYko[ojNoj`0;ojNoj`;oYl3[00?oZ<3[o`000?l000002?nX`>/2ojO0j`OoY[o[
1OnW_n/3ojS0j`coZ<7[0_nW_n/7ojJnj`?oYko[1?nX`N/7ojS2k0;oZ<7/1OnV_^X8ojJmj@03ojJn
jonW_NWoYkgY00?oYkgY2?nW_>P00onW^NKoXig?oj>Mc`03oj>Mc`OoYYk>0onWZ=L4ojZC_@SoZj??
00?oZ[SSojnaf_n_/MX01On_/MX5ojZoj@;o[;kW2?nX_n/00on[`NWoZl7Zoj_1jP03oj_1jPSoYl3[
0_nU_n`5ojJok0OoYl3[1onY`N/6ojO0j`03ojNojonV_n_oY[o[00KoY[o[1onX`>/7ojS1j`CoYko[
00?o0000ojNojonW_n/02?nW_n/6ojS0j`SoYl3[5?ooool00ol0003oooooooooo`0<ooooo`005ooo
ool00ol0003oooooooooo`0Cooooo`SoYl3[1onW_n/?ojS0j`_oYko[00CoYl3[o`000?l0003o0000
1onX`>/6ojO0j`OoY[o[00?oYko[ojS0jonX`>/01OnX`>/8ojS1j`KoYko[1OnV_^/2ojNoj`OoZ<7[
1OnX`^`3ojS1j`KoY[kZ1_nV_NT2ojS0j`KoYkgY1_nW_>P00onSYmWoXig?oj>Mc`04oj>Mc`SoYYk>
00?oYjSGojZC_OnZTkd00onZTkd7oj^Sc`03okNP`On_/M[o[k7J00Oo[k7J00?oZ[oYojbnion/_^L0
1?n/_^L6ojRoj`03ojS0jon[`N[oZl7Z00GoZl7Z1_nW`>/2ojO0k0KoY[o/2?nW`>/7ojW1j`;oYl3[
1OnW_n/8ojJoj`OoZ<3[1onX`N/4ojNoj`03o`000?nW_n_oYko[00OoYko[1onX`>/7ojO0jaGooooo
00?o0000ooooooooool02oooool001Oooooo00?o0000ooooooooool05Oooool7ojO0j`OoYko[3onX
`>/7ojNoj`04ojO0jol0003o0000o`0000?oYl3[1onX`>/7ojO0j`GoY[o[0onW_n/7ojS0j`OoZ<7[
1onW_n/00onV_^_oYko[ojNoj`04ojNoj`OoZ<7[00?oZ<;/ojS1jonX`N/01OnX`N/6ojJnjP;oY[gY
1_nX`>/6ojNmj@;oYkcX1OnSYmT6oj>Mc`KoYYk>00?oYXZgojZC_OnZTkd01OnZTkd5oj^Sc`?o]j31
1on_/MX00onl]]Co[;kWojbni`06ojbni`;oZ;o[1OnX`>/7oj_1jP;oYl3[1_nW`>`6ojJok0SoYl3[
1_nY`N/8ojNoj`KoY[o[00?oYko[ojS0jonX`>/01_nX`>/3ojS1j`?oZ<3[1OnW_n/00ol0003oYko[
ojNoj`07ojNoj`OoZ<3[1onW`>/Dooooo`03o`000?oooooooooo00_ooooo000Fooooo`?o00005ooo
ool5ojO0j`WoYko[3onX`>/4ojNoj`?o00001onW`>/7ojS0j`OoYl3[00?oY[o[ojNojonW_n/01OnW
_n/5ojS0j`WoZ<7[1OnW_n/00onV_^_oYko[ojNoj`06ojNoj`GoZ<7[0_nY`^`8ojS1j`?oY[kZ0onU
_N/8ojS0j`?oYkgY0_nU]^D7oj>Wf@KoXig?1?nVW/h4ojJ:]`KoZY>m0on[Xll6okNP`@Co[k7J1?nl
]]@6ojbni`03ojo2j?nX`>_oZ<3[00KoZ<3[1On[`NX2oj_2jPSoYl3/0onV_n`3ojJoj`SoYl3[1_nY
`N/8ojNoj`;oY[o[1OnW_n/6ojS0j`03ojS1jonX`>_oZ<3[00GoZ<3[1?nW_n/00ol0003oYko[ojNo
j`07ojNoj`KoZ<3[00?oZ<7[ojO0jonW`>/01_nW`>/Dooooo`03o`000?oooooooooo00[ooooo000F
ooooo`03o`000?oooooooooo01Sooooo00?oYl3[ojNojonW_n/02onW_n/=ojS0j`03ojO0jonW_n_o
000000;o00001?nW_n/5ojO0j`WoZ<3[1OnW`>/2ojJoj`SoYko[00?oZ<3[ojS1jonX`N/02onX`N/0
0onW_n_oY[k[ojJnj`03ojJnj`SoYko[00?oZ<7[ojW2k?nY`^`01?nY`^`6ojS1j`SoYKg[1_nX`>/0
0onU_>[oYKKUojFfi@04ojFfi@OoXjOI1_nSWLl00onVW/koYXZgojJ:]`04ojJ:]`OoZY>m00?oZj??
okNP`OngX<401_ngX<400on_/M[o_;KDokbfe005okbfe0;o[;kW1On_`^P8ojS0j`03oj_1j_n[`^[o
Zl;Z00CoZl;Z1_nW`>`00onV`>coY[o[ojJoj`05ojJoj`KoYl3[00?oZ<3[ojW1jonY`N/01OnY`N/6
ojNoj`03ojJojonW_n_oYko[00KoYko[0_nX`>/5ojS1j`OoZ<3[1?nW_n/00ol0003oYko[ojNoj`07
ojNoj`;oZ<3[1OnX`N/7ojO0ja?ooooo0ol0000;ooooo`001?ooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^h6ooooo`03o`000?oooooooooo01[ooooo2_nW_n/<ojS0j`;oYl3[
0ol00008ojNoj`03ojO0jonX`>_oZ<3[00_oZ<3[00?oYl3[ojJojonV_n/01?nV_n/6ojNoj`03ojS0
jonX`N_oZ<7[00_oZ<7[0_nW`>/6ojJnj`KoYko[0_nX`N/7ojW2k0;oZ<7[3?nU_N/2ojS0j`GoYKcZ
1_nU]^D6oj>Wf@GoXig?00?oWHBhojJ:]onVR[L01OnVR[L7ojZC_@Wo]j312?nl]]@8ojo2j0KoZ<3[
00?oZ<7[oj_2j_n[`^X01_n[`^X2ojO0k0GoY/3/1onV_n/2ojO0j`GoZ<3[1onY`N/2ojNoj`GoY[o[
1onW_n/7ojS1j`KoZ<3[0_nW`>/4ojNoj`03o`000?nW_n_oYko[00GoYko[0_nW`>/7ojS1j`OoYl3[
3oooool3o`0000;ooooo00?o0000ooooooooool02Oooool000Kooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool06oooool6ojNoj`koZ<3[
0ol00004ojO0j`SoYko[3_nX`>/7ojJoj`;oYko[1OnX`>/9ojS1j`KoYl3[1_nV_^/2ojNoj`KoZ<7[
1OnY`^`2ojS1j`coYKg[00?oYl3[ojFlj_nU_>X01_nU_>X5ojFfi@OoXjOI00?oXig?oif4^?nMQ;P0
0_nMQ;P8ojJ:]`KoZY>m00?o]92aokNP`OngX<401_ngX<400oo:[Kgo_;KDokbfe004okbfe0;oc<WH
2?n_`^P2ojS0j`GoZ<7[1_n[`^X2oj_2j`KoY/3/2?nV_n/7ojS0j`?oZL7[1?nX`N/7ojJoj`OoYko[
1onX`N/2ojS0j`KoYl3[0onW_n/00ol0003oYko[ojNoj`02ojNoj`KoYl3[1OnX`N/00onX`>_oYl3[
ojO0j`06ojO0j`_ooooo0ol00005ooooo`03o`000?oooooooooo00Wooooo0006ooooo`03o`000?oo
oooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`;o00007Oooool6ojNoj`[oZ<3[
0ol00002ojS0j`KoYl3[2?nW_n/>ojS0j`SoY[o[1_nX`>/8ojS1j`OoYl3[0onV_^/4ojNoj`OoZ<7[
00?oZL;/ojS1jonX`N/01?nX`N/8ojFmj`GoYl3[2?nU_>X5ojFfi@?oXjOI0onCQ/86oif4^0OoYXZg
1OnZTkd2okB@/@Oo]j310oo:[Kd4okbfe0Coc<WH1_n_`^P2ojo5j`OoZ<7[0_n[`^X6oj_2j`KoY/3/
2?nV_n/5ojS0j`WoZ<7[1onV_n/7ojNoj`OoZ<7[2?nW`>/3ojNoj`03o`000?nW_n_oYko[00SoYl3[
00?oZ<7[ojS0jonX`>/00onX`>/8ojO0j`Kooooo1?l00008ooooo`03o`000?oooooooooo00Wooooo
0006ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000005ooooo`;o0000
7oooool6ojNoj`OoZ<3[0_l00006ojS0j`?oYl3[2onW_n/>ojS0j`SoY[o[1_nX`>/8ojS1j`GoYl3[
00?oY[k[ojNojonW_n/01_nW_n/5ojS1j`;oZL7[1onX`N/7ojFmj`KoYl3[1_nU_>X00onL/nSoTYOE
oi:Ge@03oi:Ge@KoThK21_nMQ;P7ojJ:]`CoZY>m1?ndT;45okNP`@CobZfm0onl]]@6olc9f0;o[l;X
1_n_aN/5ojS1j`;oZ<3[2?n[`^/3ojK0k0_oY[o[00?oZ<3[ojS1jonX`N/02onX`N/7ojJoj`OoYko[
1onX`N/6ojO0j`GoYko[00?o0000ojNojonW_n/01_nW`>/8ojS0j`KoYl3[00CoYko[oooooooooooo
oooo0ol0000=ooooo`03o`000?oooooooooo00Sooooo0006ooooo`03o`000?oooooooooo00;ooooo
00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo01oooooo1_nW_n/3ojS0j`?o
00001onX`>/2ojO0j`coYko[3_nX`>/3ojNoj`OoY[o[0onX`>/;ojS1j`03ojO0jonV_^_oY[k[00?o
Y[k[2?nW_n/00onX`N_oZL7[ojW1j`04ojW1j`OoZ<7[1onU_N/6ojO0j`;oYKcZ1OnL/nP5oi:Ge@Ko
ThK21OnMQ;P8ojJ:]`;oZY>m1OndT;44okNP`@KobZfm00?o_;KDolc9f?o<bMP01?o<bMP2om;Mh@So
[lG[00?oZ<7[ojS0jonX`>/01?nX`>/6oj_2j`03oj[2jonV_n_oY[o[00_oY[o[00?oYko[ojS1jonX
`N/02onX`N/00onW`>_oY[o[ojJoj`06ojJoj`?oYko[0onW`>/8ojS1j`;oYl3[2OnW_n/00ol0003o
Yko[ojNoj`02ojO0j`coZ<3[0_nW`>/5ojNoj`;o00004?ooool00ol0003oooooooooo`08ooooo`00
1_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003o
ooooooooo`0Pooooo`?oYko[0_nW`>/3o`0000OoZ<3[1_nW`>/8ojNoj`koZ<3[1onW_n/5ojJoj`03
ojNojonX`N_oZ<7[00_oZ<7[0_nW`>/6ojJnj`KoYko[0_nX`>/7ojW1j`?oZ<7[1?nU_^/7ojFmj`?o
Yl3[1?nT_N/5oibcj0GoTYOE1_nCQ/86oif4^0OoYXZg00?oZY>mokB@/OndT;401?ndT;43okNP`@Oo
bZfm00?ohLW1olc9f?o<bMP00oo<bMP4om;Mh@Ko[lG[00?o[<C[ojS0jonX`>/01_nX`>/2oj_2j`Go
Z/;[2OnV_n/5ojNoj`WoZ<7[1OnW`>/7ojJoj`OoYl3[1onX`N/;ojNoj`03o`000?nW_n_oYko[00_o
Z<3[0onW`>/8ojNoja7ooooo00?o0000ooooooooool02?ooool000Kooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_l0000Rooooo`04ojO0jol0003o0000o`00
00?oYl3[2?nX`>/6ojO0j`SoYko[3OnX`>/8ojNoj`03ojJojonW_n_oYko[00?oYko[2OnX`N/6ojO0
j`KoY[k[0_nW_n/6ojS0j`OoZL7[1onU_^/5ojFmj`03ojO0jonT_N_oY;g[00KoY;g[1OnL/nP4oi:G
e@KoThK21_nMQ;P6ojJ:]`03ojV3[?ndT;7o]92a00Ko]92a00?o]j31olZ]_Oo:[Kd01_o:[Kd2on79
`@?oc<WH1_oBgN42ojo5j`Go[<C[1_nX`>/2ojW0j`KoZ/;[1_nV_n/2ojFnj`OoYko[0onX`N/3ojW1
j`SoYl3[1onV_n/7ojO0j`OoZ<7[2onW_n/00ol0003oYko[ojNoj`06ojS0j`03ojS1jonW`>_oYl3[
00GoYl3[1onW_n/Aooooo`03o`000?oooooooooo00Sooooo0004ooooo`03oeEEEOmVIVKo000000Co
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo01oooooo0ol00007ojO0
j`SoZ<3[1_nW`>/8ojNoj`goZ<3[1_nW_n/2ojJoj`KoYko[2?nX`N/7ojO0j`?oY[k[1?nV_n/7ojS0
j`OoZL7[1onU_^/00onU_N_oYl3[ojO0j`03ojO0j`SoY;g[1?nL/nP5oi:Ge@KoThK21OnMQ;P5ojJ:
]`;oZH>/2?ndT;48olZ]_@CohLW100?oc<WHom;MhOoBgN401?oBgN42olGNj`Oo[<C[0_nX`>/6ojW0
j`KoZ/;[0_nV_n/6ojFnj`KoYko[1onY`N/6ojO0j`;oYko[1_nV_n/6ojO0j`;oZ<3[1onX`N/;ojNo
j`03o`000?nW_n_oYko[00;oZ<3[1OnX`N/7ojO0j`OoYko[4?ooool00ol0003oooooooooo`08oooo
o`005Oooool00ol0003oooooooooo`0Looooo`?o00001?ooool5ojO0j`[oZ<3[1onW`>/7ojNoj`go
Z<3[0_nW_n/6ojJoj`KoYko[2?nX`N/5ojO0j`WoY[o[1OnX`>/9ojW1j`?oYKk[1?nT_N/6ojO0j`Ko
Y;g[00?oVkW^og>Fi_mcU^H00_mcU^H00onL/nSoTYOEoi:Ge@02oi:Ge@KoThK21_nMQ;P2ojJ:]`Go
ZH>/1ondT;400oo8X:oobZfmolZ]_@04olZ]_@GohLW10_o`k<@3om;Mh@GoaMk[1On/a>/2oj[3k0So
ZL3[0onZ`^/3ojS1k0SoYKk[1_nW_n/7ojW1j`;oYl3[1_nW_n/6ojJoj`;oYl3[1_nX`>/5ojS1j`03
ojO0jonW_n_oYko[00[oYko[00?o0000ojO0jonX`N/01_nX`N/7ojO0j`SoYko[3oooool00ol0003o
ooooooooo`08ooooo`005Oooool00ol0003oooooooooo`0Iooooo`?o00002?ooool00onW`>_oZ<3[
ojS0j`0;ojS0j`SoYl3[1OnW_n/2ojO0j`_oZ<3[0onW`>/7ojJoj`?oYko[1?nX`>/7ojS1j`03ojO0
jonV_n_oY[o[00_oY[o[00?oZ<3[ojW1jonY`N/02OnY`N/2ojO0k0OoY;g[1_nW`>/2ojBmj`GoVkW^
1?mcU^H2ofUfc@;oTYOE1_nCQ/86oif4^003ojJ:]onYPjcoZH>/00CoZH>/1_ndT;42olRP[`GobZfm
1_oQbL43oo3/a003om;MhOo5g^_oaMk[00GoaMk[00?o[<C[oj[3k?nZ`n`01?nZ`n`6ojW0j`03oj_3
k?nX`NcoZ<7/00GoZ<7/1_nU_^/00onV_^_oYko[ojNoj`05ojNoj`GoZL7[0_nX`N/8ojNoj`?oY[o[
0onW_n/8ojS0j`03ojS1jonW`>_oYl3[00?oYl3[2OnW_n/2ojO0j`03o`000?nW`>_oYl3[00OoZ<7[
1onW`>/7ojNoj`oooooo00?o0000ooooooooool02?ooool001Gooooo00?o0000ooooooooool05_oo
ool3o`0000gooooo3OnX`>/8ojO0j`03ojNojonW`>_oYl3[00CoYl3[1onX`>/7ojO0j`GoY[o[00?o
Yko[ojS0jonX`>/01_nX`>/7ojS1j`coY[o[0_nW`>/8ojW1j`KoYl3/1onT_N/3ojO0j`?oYKo/1onK
^Nh4og>FiPCoJGK=1_nCQ/84oif4^003oiUi[_nYPjcoZH>/00GoZH>/1_ndT;43olRP[`CobZfm1OoQ
bL44oo3/a003onClboo5g^_oaMk[00CoaMk[0_nbc^h7oj[3k0;oZL3[1On[`n`7ojS1k0;oYKk[1OnV
_^/7ojNoj`03ojW1jonX`N_oZ<7[00CoZ<7[1_nW_n/00onV_n_oYko[ojNoj`05ojNoj`KoZ<3[00?o
Z<7[ojO0jonW`>/01OnW`>/7ojNoj`CoYl3[00?o0000ojO0jonW`>/00onX`N/4ojS0j`OoYl3[1onW
_n/?ooooo`03o`000?oooooooooo00Oooooo000Dooooo`;o00005Oooool3o`00017ooooo3OnX`>/6
ojO0j`;oYko[1onW`>/7ojS0j`OoYl3[00?oY[o[ojNojonW_n/00onW_n/8ojS0j`OoZ<7[2?nV_n/6
ojO0j`OoZL7[1onW`>`5ojBmj`;oY[k[1_nU_n`6oi^ikPCoLiKV1?mYM/d4oh9a^0;oThK200?oWHBh
oiUi[_nINJh00_nINJh8ojV3[0Co]92a1?o8X:l3olZ]_@GohLW11Oo`k<@2onClb`;oaMk[1_nbc^h5
oj[3k0;oYl3[1_n[`n`6ojS1k0WoY[k[0onW_n/;ojS1j`;oYko[1OnV_n/7ojNoj`;oZ<3[1OnX`N/7
ojO0j`OoYko[1?nW`>/00ol0003oZ<7[ojS1j`07ojS0j`GoYl3[2OnW_n/>ooooo`03o`000?oooooo
oooo00Oooooo000Dooooo`03o`000?oooooooooo01;ooooo0_l0000Eooooo`goZ<3[0_nW`>/6ojNo
j`GoYl3[2OnX`>/5ojO0j`SoYko[2?nX`>/7ojS1j`OoY[o[1onW`>/7ojW1j`OoYl3/00?oY;g[ojJn
jonV_^/01?nV_^/6ojFok0KoVkW^1?mcU^H3ofUfc@KoPW6h1_nINJh7ojV3[0?o]92a1_o8X:l00oo:
[KgohLW1on79`@03on79`@Gol>c40_oTo</2olkdj@So//k^00?oZ/?/ojO0jonW`>/01?nW`>/6oj_3
k0;oZ<7/2onV_^/00onW_n_oZ<7[ojS1j`0;ojS1j`;oYl3[1_nV_n/6ojNoj`03ojO0jonX`N_oZ<7[
00KoZ<7[0onW`>/;ojNoj`05ojO0jonX`N_oZ<7[ojS1jol000000_nX`N/7ojS0j`03ojO0jonW_n_o
Yko[00WoYko[00?oYl3[ooooooooool03?ooool00ol0003oooooooooo`07ooooo`005?ooool00ol0
003oooooooooo`0?ooooo`?o00006?ooool:ojS0j`CoYl3[1onW_n/00onW`>_oZ<3[ojS0j`0;ojS0
j`03ojO0jonW_n_oYko[00[oYko[2?nX`>/5ojS1j`;oYl3[1onV_n/5ojO0j`;oZ<3[1onY`N/3ojO0
k0CoYKo/1onV_^/3ojFok0?oX[k]1Omm[?82oaURf0;oLiKV1?mYM/d5oh9a^0KoVGV^1onYPj`3okB@
/@Kob:2_00?ojLNcon79`OoQbL400ooQbL44oo3/a0;oi?c;1?o>m>T6ok;>kP03oj[4k?nW`>_oYl3[
00KoYl3[0on[`n`3ojW2k0WoY[k[1OnW_n/9ojS1j`KoYl3[1_nV_n/2ojNoj`GoYl3[1onX`N/>ojNo
j`CoZ<7[00Co0000ojS1jonX`N_oZ<7[0onX`>/3ojO0j`WoYko[1OnW`>/=ooooo`03o`000?oooooo
oooo00Oooooo000Dooooo`03o`000?oooooooooo00cooooo0ol0000Looooo`SoZ<3[1_nW`>/8ojNo
j`goZ<3[3_nW_n/7ojS0j`03ojS1jonW`>_oYl3[00CoYl3[1onV_n/00onW`>_oZ<3[ojS0j`04ojS0
j`KoZL7[2?nU_n`5ojJnj`;oYko[1_nR_^d5ogf/lP?o6F;H1?mYM/d6oh9a^0GoVGV^2?nYPj`00ond
T;7ob:2_olRP[`05olRP[`;ojLNc0ooQbL44oo3/a0;oi?c;1_o>m>T2ok;>kPGoZ/C/1_nW`>/2ojW3
k0KoZL;/1onV_^/7ojNoj`GoZ<7[0_nY`^`8ojO0j`?oY[o[0onW_n/7ojO0j`OoZ<7[3_nW_n/4ojS1
j`03o`000?nX`N_oZ<7[00OoYl3[1onW_n/7ojO0j`cooooo00?o0000ooooooooool01oooool001?o
oooo0ol0000:ooooo`?o00008?ooool8ojS0j`KoYl3[2?nW_n/=ojS0j`GoYko[0onV_n/6ojNoj`Go
Z<3[0_nX`N/7ojO0j`OoY[o[1onX`>/6ojW1j`SoYKo/00?oY[k[ojNojonW_n/01?nW_n/6oj:nk@Go
OJcb0olIH]P3ofUfc@KoPW6h1OnINJh8ojV3[003okB@/Oo8X:oob:2_00Cob:2_1?oYak<00ooQbL7o
l>c4oo3/a002oo3/a0;oi?c;1_o>m>T2ok;>k`OoZ/C/0_nW`>/6ojW3k0KoZL;/1onV_^/7ojNoj`03
ojS1jonY`^coZL;/00CoZL;/1_nW`>/8ojNoj`GoYl3[2OnX`N/>ojNoj`CoZ<7[00?o0000ojS1jonX
`N/01onW`>/7ojNoj`OoYl3[2oooool00ol0003oooooooooo`07ooooo`005?ooool00ol0003ooooo
ooooo`06ooooo`?o00009Oooool7ojS0j`OoYl3[1onW_n/=ojS0j`03ojNojonV_n_oY[o[00GoY[o[
1_nW_n/00onX`>_oZ<7[ojS1j`04ojS1j`GoYl3[0_nV`>`7ojJoj`GoZ<3[0_nY`>/6ojW1j`KoYKo/
0_nT_^`7ojNoj`?oX[k]0onO_Nh3oe>KlP;oOJcb0_lIH]P01?l0=[_oJGK=ofUfcOmYM/d5oh9a^0Ko
VGV^1onYPj`7olRP[`CojLNc0ooclIl00oo`k<Coi?c;ok;MMP03ok7d/P03olkdjOnbc^oo//k_00Co
//k_1OnZa>`2ojO0j`SoZL?/0onY`^`3ojJoj`OoY[k[0onW_n/3ojS0j`SoZL;/0_nW`>/<ojNoj`03
ojO0jonX`N_oZ<7[00WoZ<7[3_nW_n/00onX`>_oZ<7[ojS1j`02ojS1j`03o`000?nX`N_oZ<7[00Ko
Yl3[2OnW_n/3ojO0j`?oZ<3[2oooool00ol0003oooooooooo`07ooooo`005?ooool00ol0003ooooo
ooooo`03ooooo`?o0000:Oooool6ojS0j`SoYl3[1onW_n/;ojS0j`?oYl3[1onV_n/3ojNoj`?oZ<3[
1onX`N/00onW`>_oY/3/ojK0k004ojK0k0OoY[o[00?oZ<3[ojW0jonY`>/01?nY`>/6ojW1j`;oYKo/
1_nT_^`5ojNoj`03ojO0jonO_NkoWkg^00GoWkg^1OmCVo82oaURf003o`0f^omYM/goJGK=00GoPW6h
1_nINJh7ojV3[003okbD[_o8X:oob:2_00Cob:2_1?oYak<3oo?aW`?o/]ef0_nam;800onli_?o//k_
ok;>k`06ok;>k`03oj[4k?nW`>_oYl3[00CoYl3[1_nY`n`00onY`^coY[o[ojJoj`05ojJoj`GoY[k[
0_nW_n/6ojS0j`KoZL;/00?oZ<7[ojNojonW_n/03?nW_n/9ojS1j`koYko[1OnX`>/4ojS1j`03o`00
0?nX`N_oZ<7[00;oYl3[3?nW_n/7ojS0j`_ooooo00?o0000ooooooooool01_ooool001?ooooo00Co
0000oooooooooooooooo0ol0000]ooooo`KoZ<3[2?nW`>/7ojNoj`OoZ<3[1onW`>/6ojJoj`OoZ<3[
2?nX`N/6ojK0k0GoY[o[0_nW_n/7ojW0j`?oZL7[1?nX`>/7ojBnk003ojNojonW`>_oYl3[00?oYl3[
1onO_Nh5oe>KlP04oaURf?l0=[_o03JkofUfc@KoPW6h1OnINJh6ojV3[0;o_9B^1Oo8X:l4onW7/`Co
lo6O0_nbgGH00onam;;o_>KcokcVl`02okcVl`Ko//k_0_nZ`n`7ojO0j`;oZL?/1OnY`^`7ojJoj`03
ojJnjonW_n_oYko[00CoYko[1_nX`>/2ojW2k0GoZ<7[3_nW_n/7ojS1j`koYko[1onX`>/3ojS1j`03
ojO0jol0003oYl3[00ooYko[1onX`>/:ooooo`03o`000?oooooooooo00Kooooo000Cooooo`Co0000
<_ooool5ojS0j`KoYl3[2OnW_n/6ojS0j`SoYl3[1_nV_n/7ojS0j`SoZ<7[1_nV`>`00onV_n_oYko[
ojNoj`04ojNoj`GoZL3[0_nY`N/7ojS0j`GoY;k/0_nT_nd6ojO0j`OoWkg^0om?W?@2oe>KlP04oaUR
f?l0=[_o03JkofUfc@GoPW6h1OnINJh5ojV3[0?o_9B^1Oo8X:l4onW7/`?olo6O0_nbgGH7okcVl`;o
//k_1_nZ`n`5ojO0j`;oZLC]1_nY`^`6ojJoj`03ojJnjonW_n_oYko[00KoYko[0onX`>/3ojW2k0Oo
Z<7[3_nW_n/7ojS1j`koYko[1OnX`>/2ojS1j`CoYl3[00?o0000ojO0jonW_n/03_nW_n/6ojS0j`[o
oooo00?o0000ooooooooool01_ooool001?ooooo0_l0000eooooo`GoZ<3[0_nW`>/;ojNoj`SoZ<3[
2?nW`>/6ojJoj`OoZ<3[2?nX`N/3ojK0k0?oY[o/1onW_n/00onY`>_oZL7[ojW1j`04ojW1j`OoZ<3[
00?oY;k/ojBokOnT_nd01?nT_nd6ojO0j`OoWkg^1Om?W?@3o`0f^`GoPW6h1OnINJh4ojV3[0Go_9B^
0oo8X:l5onW7/`?olo6O00Co/]efojgdl_n]m?;o[OCb0onli_<3ojW5kPSoZ/?/00?oYl3[ojW4kOnY
a>d01?nYa>d6ojW2k0;oY[o[1OnV_^/6ojNoj`03ojS0jonY`^coZL;/00GoZL;/1OnX`N/>ojNoj`Wo
Z<7[3_nW_n/00onX`>_oZ<7[ojS1j`04ojS1j`?oYl3[00?o0000ojO0jonW`>/03OnW_n/8ojS0j`Wo
oooo00?o0000ooooooooool01_ooool000Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00So
oooo00?o0000ooooooooool0<oooool2ojS0j`CoYl3[2?nW_n/<ojS0j`SoYl3[1_nV_n/7ojS0j`Ko
Z<7[0_nX`>/6ojJok0GoYko[0_nW`>/7ojW1j`OoZ<3[1onT_nd3ojO0j`?oYl3/1onO_Nh5odnLm0;o
03Jk0_mDG;h3oh9a^0KoVGV^0_nYPj`6okbD[P?ob:2_1?oYak<3oo?aW`04ok;MM_n]m?;o[OCbojgd
lP;oZ/S_1_nYaNh6oj[3k003ojO1k?nYa>goZLC]00KoZLC]0onY`^`3ojNnjPOoY[k[0_nW_n/5ojS0
j`OoZL;/00?oZ<7[ojNojonW_n/03?nW_n/;ojS1j`03ojO0jonW_n_oYko[00_oYko[00?oYl3[ojS1
jonX`N/01_nX`N/3ojO0j`03o`000?nW`>_oYl3[00WoYko[3?nX`>/8ooooo`03o`000?oooooooooo
00Kooooo00001OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`09
ooooo`03o`000?oooooooooo03?ooooo1_nW`>/5ojNoj`;oY[o[3_nX`>/7ojO0j`?oY[o[0onW_n/7
ojS0j`;oZ<7[1_nX`>/6ojJok003ojNojonW`>_oYl3[00CoYl3[1OnY`N/2ojW1jPOoZ<3[1onT_nd6
ojO0k0GoWkg^0_nR_^d4ogV`mP?o03Jk0_mDG;h2oh9a^0KoVGV^00?oZH>/okbD[_nlU:h01OnlU:h2
olRP[`GojLNc0_oclIl00onbgGKo[OCboj[8k`05oj[8k`KoZLG^0_nZ`n`5ojO1k0KoZLC]00?oZ<7[
ojNnj_nW_^X01OnW_^X5ojJnj`;oYko[1onX`>/3ojW2k0?oZ<7[3_nW_n/9ojS1j`GoYl3[2OnW_n/5
ojO0j`KoZ<7[00?oZ<3[ojO0jonW`>/00_nW`>/00ol0003oYl3[ojO0j`06ojNoj`goZ<3[00?oYl3[
ooooooooool01_ooool00ol0003oooooooooo`06ooooo`0000CooooooiRHV?lQ8B7ok^k^1?ooool0
1Ol@413ooooooooooooooooo410@00[ooooo00?o0000ooooooooool0<oooool6ojO0j`03ojNojonV
_n_oY[o[00CoY[o[3_nX`>/5ojO0j`;oY/3/1_nW_n/?ojS0j`?oY[o/0onU_n`7ojO0j`03ojW1jonY
`N[oZL7Z00CoZL7Z1onX`>/7ojBok@KoYl3/00?oWkg^oj:nkOnR_^d01?nR_^d4ogV`mP;o03Jk1?mD
G;h00on2LKSoVGV^oiUi[P02oiUi[P03oib2]_nlU:ko_9B^00Oo_9B^00?ob:2_onW7/ooYak<00_oY
ak<3oo?aW`03ok;MM_nZb>ooZ/S_00KoZ/S_0onYaNh3ojS0j`OoYl7/0_nYa>d5ojS1j`OoYkkZ00?o
Y[k[ojNojonW_n/01?nW_n/5ojS0j`;oZ<;/1_nX`N/>ojNoj`GoZ<7[0_nX`N`7ojO0j`KoYko[2?nW
`>/2ojS1j`GoZ<3[1?nW`>/00ol0003oYl3[ojO0j`06ojNoj`WoZ<3[1OnW`>/7ooooo`03o`000?oo
oooooooo00Kooooo0002ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00
000;ooooo`;o0000=?ooool6ojO0j`OoY[o[3_nX`>/00onW`>_oY/3/ojK0k004ojK0k0KoYko[3onX
`>/6ojFok0GoYl3[0_nX`>/7ojW1jPOoZ<3[1onT_nd3ojO0k0?oYl7/1onR_^d3ogV`mP03oiZnlOl0
=[_oE5bn00CoE5bn00?oVGV^oib2]_nLP[H00_nLP[H9okbD[P03olRP[ooYak?ojLNc00;ojLNc0_oc
lIl00onbgGKoYlO`ojO7l006oj[8k`;oZ<7[1_nX`>/5ojO1k0;oZL?/1onX`N/3ojNnjP?oY[k[2?nW
_n/00onX`>_oZ<;/ojS2k004ojS2k0KoZ<7[3_nW_n/00onX`N_oZ<7/ojS1k004ojS1k0GoYl3[2?nW
_n/6ojO0j`03ojS1jonX`>_oZ<3[00KoZ<3[0onW`>/00ol0003oYko[ojNoj`07ojNoj`?oZ<3[0onX
`N/8ojO0j`Oooooo00?o0000ooooooooool01Oooool000?ooooo00?oMgMgofIVI_ooool00_ooool0
1Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool0<_ooool6ojO0j`GoY[o[0onW
_n/=ojS0j`OoY/3/0onW_n/4ojO0j`koZ<3[1_nU_n`00onW`>_oZ<3[ojS0j`04ojS0j`GoZL7Z0onY
`>X6ojS0j`OoY;o]1_nW`N`5oj:nk@;oYKo/0onJ__42o`0f^`CoE5bn1_nLP[H8okbD[P04on?9_OoY
ak?ojLNconW7/`?olo6O1?nWao02oj[8k`KoZ<7[1_nX`>/00onW`NcoZL?/ojW3k004ojW3k0GoZ<7[
0_nV_^X6ojJnj`KoYko[00?oZ<7/ojS2k?nX`^`01_nX`^`3ojS1j`goYko[0onX`N/8ojS1k003ojO0
jonW_n_oYko[00[oYko[0_nW`>/5ojS1j`KoZ<3[00?oYl3[ojNojonW_n/00_nW_n/00ol0003oYko[
ojNoj`05ojNoj`;oZ<3[1_nX`N/7ojO0j`Oooooo00?o0000ooooooooool01Oooool000Cooooo00Go
0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00cooooo00?o0000ooooooooool0
<_ooool6ojO0j`03ojJojonW_n_oYko[00GoYko[3OnX`>/5ojK0k0?oY[o/1_nW`>/>ojS0j`KoYKo/
1onX`>/00onY`N[oZL3ZojW0jP05ojW0jPKoZ<3[1onT_nd6ojO1k003oj:nkOnU_ncoYKo/00CoYKo/
0onJ__400ol0=[_oE5bnoeAL_P02oeAL_PKoW8:f2?nlU:h2on?9_@;ojLNc00?olo6Ook7LM?nWao00
0onWao02ojO0j`SoZ<7[0onX`>/3ojS3k@OoZL?/00?oZ<7[ojJnj_nV_^X01?nV_^X6ojJnj`;oYko[
1OnX`N`6ojS2k003ojO0jonW_n_oYko[00coYko[1_nX`N/6ojS1k003ojO0jonW_n_oYko[00WoYko[
0onW`>/7ojS1j`;oZ<3[1OnW`>/4ojNoj`04o`000?nW_n_oYko[ojNoj`KoZ<3[1_nX`N/7ojO0j`Ko
oooo00?o0000ooooooooool01Oooool00005o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00oooooo00?o0000ooooooooool0<_ooool7ojO0j`OoYko[3OnX`>/00onV
`>coY[o/ojJok005ojJok0KoYl3[3_nX`>/6ojFok0OoZ<3[2?nY`>X3ojS0j`?oZ<3Z1onT_nd3ojO1
k0?oY/7]1onU_n`2oiZnl@03o`0f^omDG;koE5bn00?oE5bn1OnLP[H7okbD[PCohlVm00CojLNcok7L
M?nag7CoYlO`1_nW`>/6ojS1j`SoZ<?]1OnY`n`2ojNnjPOoY[kZ0onV_^/3ojO0j`OoZ<7/0_nX`^`5
ojO0j`koYko[1_nX`N/2ojS1k0GoYl3[1onW_n/7ojO0j`GoZ<7[00?oZ<3[ojO0jonW`>/01_nW`>/4
ojNoj`03o`000?nW_n_oZ<3[00OoZ<3[0onX`N/:ojO0j`Gooooo00?o0000ooooooooool01Oooool0
0005oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^013ooooo0_l0
000dooooo`KoYl3[1OnW_n/2ojO0j`goZ<3[2?nV_n`6ojO0j`koZ<3[1_nU_n`7ojS0j`SoZL3Z1_nX
`>X5ojBok@;oYKo/1_nV`Nd5ojFok0;oYl;]0_nT_n`00ol0=[_oE5bnoeAL_P02oeAL_PKoW8:f1Onl
U:h5on?9_@;o/Mad0_nW`>`7ojO0j`;oZ<7[3?nX`nd00onY`ncoYkkZojNnjP04ojNnjPGoY[kZ0_nW
_n/6ojO0j`OoZ<7/1onW`>/>ojNoj`?oZ<7[0onX`N`7ojO0j`OoYko[1onW`>/00onX`N_oZ<3[ojS0
j`03ojS0j`KoYl3[1OnW_n/00ol0003oYko[ojNoj`06ojS0j`03ojS1jonW`>_oYl3[00[oYl3[00?o
Yko[ooooooooool00oooool00ol0003oooooooooo`05ooooo`007oooool00ol0003oooooooooo`0b
ooooo`KoYl3[00?oYko[ojO0jonW`>/01?nW`>/=ojS0j`SoY[o/1_nW`>/>ojS0j`KoYKo/1onX`>/8
ojW0jPKoZ<3Z00?oY;o]ojFok?nU_n`01?nU_n`6ojK1k@03ojFok?nW`^goYl;]00CoYl;]0_nT_n`4
oeAL_PKoW8:f1OnlU:h5on?9_@03ok7LM?nW`>coYl3/00;oYl3/1OnW`>/2ojO3kP[oZ<?]0onX_nX8
ojNnjP03ojJnj_nW_n_oYko[00CoYko[1_nW`>/7ojS1k0GoYl3[3_nW_n/8ojS1k0GoYl3[2OnW_n/3
ojO0j`?oZ<7[1onX`>/2ojO0j`WoYko[00?o0000ojNojonW_n/00_nX`>/5ojS1j`SoYl3[1OnW_n/4
ooooo`03o`000?oooooooooo00Gooooo000Pooooo`03o`000?oooooooooo03;ooooo3OnW`>/=ojS0
j`SoY[o/1_nW`>/>ojS0j`KoYKo/1OnX`>/2ojO0j`SoZL3Z0onX`>X3ojW0jPOoYKo/0onV`Nd3ojC0
k@OoYl;]00?oY;o/ojO2kOl008800omDG;h5oib2]PCo_9B^1OoSbKd00onag7CoYl3/ojO0k004ojO0
k003ojO0jonW`nkoYl?^00CoYl?^1OnX`nd2ojS0j`KoZ;oZ1onW_^X8ojNoj`?oYl3[0onX`^`7ojS1
k003ojO0jonW_n_oYko[00coYko[3?nX`N`00onW`>_oYko[ojNoj`09ojNoj`03ojO0jonX`N_oZ<7[
00GoZ<7[1OnX`>/2ojO0j`_oYko[00?o0000ojO0jonX`N/01onX`N/5ojO0j`SoYko[0oooool00ol0
003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`0booooo`koYl3[3OnX`>/7ojJok0Ko
Yl3[3_nX`>/6ojFok003ojS0jonW`>_oYl3[00CoYl3[1_nY`>X2ojW0j`KoZL3Z1OnU_n`2ojNoj`Ko
Y<3]1OnW`^d2ojG1k@;oYl;]00?o0022oeAL__mDG;h01OnLP[H3okbD[PGohlVm00?o/MadojO1k?nW
`N`00onW`>`4ojK3kPKoYl?^00?oZ<?]ojS0jonX`>/01?nX`>/6ojRojPOoYkkZ1_nW_n/00onW`Nco
Z<;/ojS2k005ojS2k0GoZ<7/3OnW_n/2ojO0j`[oZ<7/3?nW_n/5ojO0j`OoZ<7[00?oZ<3[ojO0jonW
`>/01?nW`>/8ojNoj`;oYl3[00?o0000ojO0jonW`>/01_nX`N/7ojO0j`OoYko[1?ooool00ol0003o
ooooooooo`04ooooo`008_ooool00ol0003oooooooooo`0booooo`koYl3[3OnX`>/7ojJok0KoYl3[
3_nX`>/6ojFok0OoYl3[0_nY`>X6ojW0j`KoZL3Z00?oYKo/ojNojonW_n/01?nW_n/6ojC0k@03ojO2
kOnU`NgoYL7]00CoYL7]0_nW`^d00ol008;oE5bnoib2]P05oib2]P;o_9B^1OoSbKd2ojO1k003ojK2
kOnV`nkoY/?^00KoY/?^0onW`nh3ojNoj`OoZ<3[0onX_nX:ojNnjP;oYko[1OnW`N`7ojS2k003ojS1
k?nW_n_oYko[00_oYko[1_nW`>/5ojS1k0;oZ<7[3OnW_n/7ojO0j`?oZ<7[0onX`>/8ojO0j`KoYko[
1?nW`>/00ol0003oYl3[ojO0j`02ojS1j`_oYl3[1onW_n/3ooooo`03o`000?oooooooooo00Cooooo
000Sooooo`;o0000<oooool3ojO0j`CoYl3/1onW`>/=ojS0j`OoY[o/1_nW`>/>ojS0j`KoYKo/1OnW
`>/3ojO0k0OoZL3[1_nY`>X7ojNoj`?oY<3]1?nU_^/6ojG1k@04ojO2kOnU`Ngo0022oeAL_PGoW8:f
00?o_9B^on?9_OoSbKd00ooSbKd5ojK2k@KoY/?^2?nW_n/5ojS0j`goYkkZ0_nW`>`7ojO1k0?oZ<;/
0onX`>/>ojNoj`OoYl3[00?oZ<7/ojS1jonX`N/01?nX`N/=ojNoj`GoYl3[0_nX`N`6ojS0j`KoYl3[
2?nW_n/3ojO0j`03ojS1jol0003oZ<7[00_oYl3[2_nW_n/2ooooo`03o`000?oooooooooo00Cooooo
000Uooooo`03o`000?oooooooooo03;ooooo1_nW`>`7ojO0j`goZ<3[1onV_n`6ojO0j`koZ<3[1_nU
_n`00onW`>_oYl3/ojO0k005ojO0k0GoZL3[0_nX`>/6ojW0jPGoYko[0_nY_nX7ojFnj`?oYL7]0onU
_^/2ojG1k@04o`00P_nLP[KoW8:foib2]P?oY/;^1?oSbKd00onag7CoY/;]ojK2k@04ojK2k@;oY/?^
3?nW_n/00onX`>_oYkkZojNnjP0;ojNnjPKoYl3/1OnW`N`2ojS1k0KoZ<3[3_nW_n/3ojO0j`?oZ<7/
2?nX`N/=ojNoj`03ojO0jonX`NcoZ<7/00CoZ<7/1_nX`>/2ojO0j`[oYko[0_nW`>/4ojS1j`03o`00
0?nX`N_oYl3[00KoYl3[3?nW_n/01?nX`>_oooooooooool00006ooooo`009_ooool00ol0003ooooo
ooooo`0booooo`KoYl3/1onW`>/=ojS0j`OoY[o/1_nW`>/>ojS0j`?oYKo/0onV_n`8ojO0k003ojW0
jonX`>_oZ<3[00CoZ<3[1_nY`>X00onW_n_oZKoZojVojP04ojVojPGoYKk[0_nX_nX6ojFnj`;oYL7]
1onV`^h3on?9_@03ojK0k?nV`^goY/;]00?oY/;]0_nW_^X:ojNoj`koYkkZ0onW`>/7ojO0k003ojO1
k?nX`NcoZ<7/00CoZ<7/1_nX`>/<ojNoj`SoZ<7/1_nX`N/=ojNoj`03ojO0jonX`NcoZ<7/00KoZ<7/
0onX`>/2ojO0j`WoYko[1_nW`>/3ojS1j`03o`000?nX`N_oZ<7[00OoYl3[2?nW_n/5ojS0j`03oooo
ool0003ooooo00Gooooo000Wooooo`03o`000?oooooooooo03;ooooo0onW`>`3ojK0k0OoYl3[3OnX
`>/7ojJok0KoYl3[3_nX`>/6ojJok0KoYl3/0_nV`>`7ojS0j`KoZL3Z1onY_nX00onU_^_oZ;oZojRo
jP04ojRojPKoYKk[00?oYL7]ojJnjonV`^h01_nV`^h01OoSbKgoY/3/ojK0k?nV`>coY/;]00KoYkkZ
1OnW_n/2ojRnjPcoYkkZ2?nW`>/5ojO0k003ojS2k?nX`NcoZ<7/00KoZ<7/0onX`>/;ojNoj`coZ<7/
0_nX`N/=ojNoj`GoYl3[1_nX`N`7ojO0j`OoYko[2?nW`>/3ojS1j`03o`000?nW`>_oYl3[00OoYl3[
1onW_n/6ojS0j`03o`000?oooooooooo00Cooooo000Xooooo`;o0000<oooool6ojK0k0OoYl3[3OnX
`>/7ojJok0OoYl3[3OnX`>/6ojJok0;oYl3/1_nV`>`5ojS0j`;oYl7/1_nY`>X5ojVojP;oZL3Z1onX
_nX3ojFnj`?oZ;oY0_nV_^/5ojK2kP?oY/3/0onX_^T7ojNnjP03ojNojonX_^[oZ;kZ00CoZ;kZ2?nW
_^X<ojO0j`03ojO0k?nX`^coZ<;/00?oZ<;/1_nX`N`=ojNoj`03ojO0jonX`NcoZ<7/00WoZ<7/0onW
`>/>ojNoj`KoYl3[0_nX`N`;ojO0j`OoYko[1_nW`>/00onX`N_oYl3[ojO0j`02ojO0j`03o`000?nW
`>_oYl3[00GoYl3[2OnW_n/3ojS0j`;ooooo00?o0000ooooooooool01?ooool002[ooooo00?o0000
ooooooooool0<Oooool6ojK0k0OoYl3[3OnX`>/7ojJok0OoYl3[3OnX`>/3ojJok0?oY[o[2?nV`>`0
0onX`>_oYl7/ojO1k004ojO1k0KoZL3Z00?oZKoZojW0j_nY`>X01?nY`>X5ojRojP;oZL3Z1_nX_nT2
ojJnj`03ojK2k_nV_^_oY[k[00;oZ;oZ1_nX_^T5ojNnjP;oZ;oZ1onX_^X3ojNnjPgoYl3[2_nX`^`2
ojS1k0goYko[1OnW`>/7ojS1k0OoYl3[3_nW_n/3ojO0j`;oZ<7/2onW`>/:ojNoj`;oYl3[1OnX`N/4
ojO0j`04o`000?nW`>_oYl3[ojO0j`_oYko[1oooool00ol0003oooooooooo`03ooooo`00:oooool0
0ol0003oooooooooo`0aooooo`KoY/3/1onW`>/=ojS0j`OoY[o/1onW`>/=ojS0j`KoY[o[2?nV`>`7
ojO1k0?oZL3Z0onX`N/7ojW0jP03ojRoj_nY`>[oZL3Z00CoZL3Z1_nX_nT00onV_^_oZ;oZojRojP04
ojRojPKoZ;kY00?oYkkZojRoj_nX_nX01?nX_nX5ojRnjPgoYl3[0_nW`^`:ojS2k13oYko[1onW`>/7
ojS1k0OoYl3[3?nW_n/7ojS1k0KoYl3[3OnW_n/00onX`>_oZ<7[ojS1j`06ojS1j`?oYl3[00?o0000
ojO0jonW_n/02OnW_n/:ooooo`03o`000?oooooooooo00?ooooo000/ooooo`03o`000?oooooooooo
037ooooo1_nV`>`7ojO0j`goZ<3[1onV_n`7ojO0j`goZ<3[1_nV_n/8ojK0k0GoYl7/0_nV`N`6ojS1
j`GoZL3Z0_nX`>/7ojW0jP?oZ;oY2_nX_nX3ojRnj@[oZ;oZ00?oZ;kZojO0jonW`>/02onW`>/6ojO2
k0GoZ<;/5OnW_n/5ojO0j`WoZ<7/0onW`>/<ojNoj`_oZ<7/0_nW`>/=ojNoj`GoZ<3[1_nX`N/5ojO0
j`03o`000?nW`>_oYko[00GoYko[3Oooool00ol0003oooooooooo`03ooooo`00;Oooool2o`0003;o
oooo1_nV`>`7ojO0j`goZ<3[1onV_n`7ojO0j`goZ<3[0onV_n/4ojNoj`OoY/3/00?oYl7/ojK1k?nV
`N`01?nV`N`6ojS1j`03ojW0j_nX`>_oZ<3[00CoZ<3[1OnY`>X00onX`N_oZ;oZojRojP0:ojRojP;o
Z<3[2onX_nX2ojO1k0[oYl3[1?nW`^d6ojO2k003ojS2k?nW_n_oYko[01OoYko[00?oYl3[ojS1k?nX
`N`02OnX`N`=ojNoj`;oYl3[2_nX`N`3ojO0j`koYko[1_nX`>/2ojS1j`WoYl3[00Co0000ojO0jonW
_n_oYko[4?ooool00ol0003oooooooooo`03ooooo`00;oooool00ol0003oooooooooo`0`ooooo`Oo
Y/3/1_nW`>/=ojS0j`OoY[o/1OnW`>/2ojO0k0goZ<3[1onW_n/3ojK0k0?oY[o[2?nV`N`3ojS1j`;o
Yl7/2?nX`>/00onY`>[oZ<7[ojS1j`03ojS1j`SoZ;oZ1_nX`>/7ojRojPKoYl7/1OnW`>/9ojO2k@?o
Yl;/0_nW`>/HojNoj`_oZ<7/3OnW_n/6ojO0j`GoZ<7/00?oZ<7[ojO0jonW`>/01OnW`>/>ojNoj`Go
Z<3[2onW`>/00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00?ooooo000`ooooo`03o`00
0?oooooooooo037ooooo1_nV`>`7ojO0j`goZ<3[1_nV_n`00onW`>_oYl3/ojO0k004ojO0k0goZ<3[
1OnW_n/2ojRoj`KoY[o[1_nV`N`00onV_ncoYl7/ojO1k004ojO1k0KoZ<3[00?oYl7/ojS1jonX`N/0
1OnX`N/3ojRojP?oZ<7/2?nX`>/3ojRojP[oYl7/00?oYl3[ojO2kOnW`^d02OnW`^d00onW_n_oYl3[
ojO0j`04ojO0ja?oYko[00?oYl7/ojS1k?nX`N`02?nX`N`3ojO0j`koYko[1onW`>/00onX`NcoZ<7[
ojS1j`03ojS1j`OoYl3[3?nW_n/00onX`N_oZ<3[ojS0j`04ojS0j`KoYl3[1Oooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo00?ooooo000aooooo`03o`000?oooooooooo037ooooo1onV
`>`6ojO0j`koZ<3[0_nV_n`4ojJoj`KoYl3/3OnX`>/00onW_n_oZ;o[ojRoj`04ojRoj`KoY[o[0_nV
`N`5ojJok0KoYl7/0_nX`>/5ojO1k0GoZ<7[0_nW`N`6ojS1k0KoZ<3[3_nW`N`9ojO2k@GoYko[1_nW
`>/?ojNoj`GoYl7/1OnX`N`2ojS0j`KoYl3[3_nW_n/3ojO0j`?oZ<7/1onX`N/3ojO0j`coYko[1OnX
`N/6ojS0j`;oYl3[2Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo000b
ooooo`;o0000<_ooool7ojK0k0KoYl3[3_nX`>/6ojJoj`CoYl3/0onV`>`<ojS0j`OoZ;o[0onV_n/3
ojNoj`OoY[o/0onW`N`4ojK0k0KoYl7/00?oZ<7[ojO1k?nW`N`01?nW`N`6ojS1k0;oZ<3[4_nW`N`5
ojO2k@WoYko[0onW`>/3ojNojP[oYko[1?nW`>/6ojO1k003ojS1k?nX`>_oZ<3[00CoZ<3[1_nW`>/<
ojNoj`;oYl7/1_nX`N`5ojS1j`goYko[00?oYl3[ojS1jonX`N/01_nX`N/3ojS0j`kooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`02ooooo`00=?ooool00ol0003oooooooooo`0`oooo
o`OoY/3/1_nW`>/>ojS0j`KoY[o[00?oYl3/ojK0k?nV`>`01?nV`>`<ojS0j`GoZ;o[0_nX`>/6ojNo
j`GoY[o/0_nW_n/7ojK0k0?oYl7/0onV`>`7ojO1k0?oZ<7/1?nV`N`CojO1k003ojO2kOnW_n_oYko[
00WoYko[2?nW_nX5ojNoj`WoYl3[0onW`N`3ojS1k0OoZ<3[0onW`>/;ojNoj`KoYl7/1_nX`N`00onX
`N_oYko[ojNoj`0;ojNoj`GoYl3[1_nX`N/Booooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool00_ooool003Gooooo00?o0000ooooooooool0<?ooool5ojK0k0;oYl3/1_nW`>/>ojS0j`?o
Y[o[0onW_n/7ojK0k0;oZ<3[1?nW`>`6ojS0j`03ojRojonX`>_oZ<3[00CoZ<3[1_nW_n/00onV_nco
Yko[ojNoj`04ojNoj`GoY/3/0_nW_n/6ojK0k0GoYl7/0_nV_n/7ojK1k0?oYl7/0onW`>/:ojO1k0_o
Yko[3?nW_nX00onW_n_oYl3[ojO0j`09ojO0j`03ojO1k?nX`NcoZ<7/00GoZ<7/1OnX`>/=ojNoj`03
ojO0jonW`NcoYl7/00KoYl7/0onX`N`2ojO0j`koYko[1_nW`>/2ojS1jaKooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`02ooooo`00=_ooool00ol0003oooooooooo`0`ooooo`03ojK0
k?nW`>coYl3/00CoYl3/1_nW`>/>ojS0j`KoYko[1OnV`>`2ojJok0KoYl3/3OnX`>/3ojNoj`CoZ;oZ
1_nW_n/00onV`>coYko[ojNoj`04ojNoj`KoY/3/00?oYl7/ojJojonV_n/01?nV_n/5ojK1k0;oYko[
1_nW`>/5ojO1k0;oYkoZ2_nW_n/=ojNojP_oYl3[1OnW`N`7ojS1k003ojS0jonW_n_oYko[00_oYko[
1OnW`>/6ojO1k003ojS0jonW`>_oYl3[00CoYl3[3_nW_n/3ojO0ja_ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`02ooooo`00=oooool2o`0003;ooooo1_nW`>`7ojO0j`goZ<3[1_nW
_n/00onV`>coY[o/ojJok004ojJok0CoYl3/0_nV`>`=ojS0j`OoZ;oZ0onW_n/3ojRojPOoYko[0onV
`>`4ojNoj`KoY[o[00?oY/7/ojNojonW_n/01?nW_n/6ojO0j`03ojO1k?nW_n[oYkoZ00CoYkoZ1OnW
_n/00onX_n[oYkoZojNojP0:ojNojPgoYl3[2?nW`N`3ojS1k17oYko[1_nW`>/2ojO1k0GoZ<3[1_nW
`>/<ojNojb3ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`02ooooo`00>Oooool0
0ol0003oooooooooo`0`ooooo`?oYl3/2_nW`>/=ojS0j`?oYko[1?nW`>/6ojJok003ojO0k?nV`>co
Y/3/00?oY/3/3OnX`>/5ojRojP;oZ<3[1_nX_nX5ojNoj`;oZ;oZ1onW_n/3ojJoj`?oZ;oZ1onW_n/3
ojO0j`CoZ;oZ1_nW_nX00onW_n_oZ;oZojRojP03ojRojPSoYkoZ3OnW`>/:ojO1k1KoYko[0onW`>/3
ojS1k0OoZ<3[0onW`>/;ojNojb?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`02
ooooo`00>_ooool00ol0003oooooooooo`0`ooooo`_oYl3[0_nW`>`=ojS0j`OoYl3[0onV_n`3ojNo
j`KoY/3/0onX`>/4ojO1k0KoZ<3[00?oZ;oZojS0jonX`>/01?nX`>/6ojRojP03ojNojonX_n[oZ;oZ
00CoZ;oZ1OnW_n/8ojRojPGoYko[2OnX_nX3ojNojP;oZ;o[1onX_nX3ojNojPgoYl3[2onW`N`HojNo
j`03ojO1k?nX`NcoZ<7/00GoZ<7/1OnX`>/;ojNojbSooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`02ooooo`00>oooool00ol0003oooooooooo`0`ooooo`OoYl3[1_nW`>`=ojS0j`Go
Yl3[0_nX`>/6ojNoj`KoY/3/1onW`N`3ojS0j`?oZ<7/1onX`>/3ojRojPCoZ<3[1_nX_nX00onW_n_o
Z;oZojRojP0:ojRojP03ojNojonX_n[oZ;oZ00WoZ;oZ1onX_n/5ojRojPgoYl3[3?nW`N`HojNoj`Go
Yl7/1onX`N`00onX`>_oYko[ojNoj`08ojNojbgooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`01ooooo`00??ooool00ol0003oooooooooo`0`ooooo`KoYl3[1onW`>`=ojS0j`03ojO0
jonX`>_oZ<3[00CoZ<3[1_nW_n/6ojK0k0GoYl7/0_nV`>`6ojS1k0GoZ<3[0_nX`N/7ojS0j`?oZ;oZ
0onX`>/:ojRojP?oZ;o[2?nX_nX;ojRoj`03ojRoj_nW`>_oYl3[00_oYl3[2onW`N`00onW`>_oYko[
ojNoj`0EojNoj`[oYl7/0onX`N`4ojO0j`OoYko[<Oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo007ooooo000mooooo`;o0000<Oooool6ojO0j`GoYl3/0_nV`>`DojS0j`KoYko[1_nV
`>`00onW`NcoY/3/ojK0k004ojK0k0KoZ<7/00?oZ<3[ojS1jonX`N/01?nX`N/5ojS0j`;oZ<7/1_nX
`>/5ojRojP03ojS0jonX_n_oZ;o[00GoZ;o[0onX_nX3ojS0j`[oZ;o[1?nW`N`9ojO0j`_oYl7/1OnW
`>/BojNoj`;oYl3[2onW`N`9ojO0j`?oYko[=?ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo007ooooo000oooooo`03o`000?oooooooooo02oooooo1_nW`>/00onW`>coY/3/ojK0k004
ojK0k0GoZ<3[0_nW`>/=ojS0j`KoYko[0onV`>`3ojNoj`OoY/3/0onX`N`4ojO0k0KoZ<7[00?oZ<3[
ojS1k?nX`N`01?nX`N`6ojS0j`03ojRoj_nX`>_oZ<3[00?oZ<3[1OnX_n/2ojO1k0KoZ<3[1OnX_n/9
ojO1k0?oYl3[3OnW`N`9ojO0j`koYko[1_nW`>/7ojO1k0_oYl3[>Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo007ooooo0010ooooo`03o`000?oooooooooo02oooooo1onW`>/6ojK0
k003ojS0jonW`>_oYl3[00CoYl3[3OnX`>/4ojNoj`;oZ;o[1_nW_n/5ojK0k0;oY[o[1onW`>`3ojS1
j`?oYl7/1onX`N`3ojS0j`?oYl7/1_nX`>/00onX_n_oYl7/ojO1k004ojO1k0KoZ<3[00?oZ;o[ojO1
k?nW`N`05_nW`N`00onW_n_oYl3[ojO0j`08ojO0j`goYko[2_nW`>/3ojO1k0?oZ<3[2?nW`>/moooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00Oooool0047ooooo00?o0000oooooooo
ool0;oooool7ojO0j`?oY/3/0onW`>`7ojO0j`goZ<3[00?oYko[ojRojonX_n/00onX_n/6ojNoj`03
ojK0k?nV_n_oY[o[00CoY[o[1OnW`>`2ojJoj`KoYl7/1OnX`N`8ojO1k0?oZ<3[2_nW`N`3ojS0jaSo
Yl7/1OnW_n/5ojO0j`goYko[3OnW`>/00onW`NcoZ<3[ojS0j`05ojS0j`?oYl3[@Oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo007ooooo0012ooooo`;o0000<?ooool7ojO0j`KoYl3/
1OnW`>/2ojO0k0goZ<3[1_nX_n/3ojNoj`CoZ;o[1_nV_n/00onW`>coY[o[ojJoj`04ojJoj`KoYl7/
00?oZ<7/ojO1k?nW`N`02?nW`N`2ojO0k0_oYl7/0_nW`>`:ojO1k0;oYl3/2_nW`N`:ojNoj`03ojO0
jonW_n_oYko[00_oYko[3OnW`>/5ojO1k0GoZ<3[A_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo007ooooo0014ooooo`03o`000?oooooooooo02kooooo1onW`>/6ojO0k003ojO0jonW
`>coYl3/00CoYl3/1OnX`>/2ojO0j`KoZ<3[1?nX_n/2ojS0j`OoZ;o[0onV_n/3ojNoj`OoY[o[0onW
`N`4ojNoj`KoYl7/1_nW`>`7ojO1k0KoYl3/1OnW`N`00onW_n_oYl3/ojO0k004ojO0k0GoYl7/6OnW
_n/<ojO0j`[oYl7/00?oZ<3[ooooooooool0B?ooool00ol0003oooooooooo`07ooooo`7o00000Ooo
ool1ooooo`00AOooool00ol0003oooooooooo`0_ooooo`KoYl3[0onW`>`4ojO0j`KoYl3/00?oZ<3[
ojO0jonW`>/01?nW`>/6ojS0j`03ojRojonX`>_oZ<3[00?oZ<3[1onX_n/6ojNoj`GoY[o[2OnW_n/2
ojO1k0?oYko[1onW`>`3ojO1k0CoYl3[1_nW`>`00onW`NcoYko[ojNoj`03ojNoj`KoYl3/00?oYl7/
ojNojonW_n/05_nW_n/;ojO0j`goYl7/C_ooool00ol0003oooooooooo`06ooooo`7o00000Oooool1
ooooo`00A_ooool00ol0003oooooooooo`0`ooooo`;oYl3[0onX`>/7ojO0j`OoYl3/1_nW`>/<ojS0
j`OoZ;o[1_nW_n/00onV_n_oYko[ojNoj`09ojNoj`03ojRojonW_n_oYko[00CoYko[1OnW`>`2ojNo
j`OoYl3[0onW`>`9ojNoj`?oYl3/6?nW_n/:ojO0j`goYl7/D_ooool00ol0003oooooooooo`06oooo
o`7o00000Oooool1ooooo`00Aoooool2o`00037ooooo1OnX`>/7ojO0j`OoYl3/0onW`>/3ojO0k0go
Z<3[1_nX_n/3ojNoj`CoZ;o[1onW_n/5ojRoj`KoYko[00?oYl3/ojNojonW_n/01?nW_n/5ojO0j`03
ojRojonW_n_oYko[00WoYko[0_nX_n/:ojNoj`?oZ;o[2_nW_n/:ojO0j`goYl7/E_ooool00ol0003o
ooooooooo`05ooooo`7o00000Oooool1ooooo`00BOooool00ol0003oooooooooo`0_ooooo`GoZ<3[
1onW`>/5ojO0k0;oYl3[1_nW`>`4ojS0j`;oYl3/1onX`>/3ojRoj`?oZ<3[1onX_n/3ojNoj`WoZ;o[
0onW_n/4ojRoj`KoYko[00?oYl3[ojRojonX_n/00onX_n/7ojNoj`KoZ;o[1OnW_n/8ojRoj`GoYko[
2onW`>/=ojO1k5[ooooo00?o0000ooooooooool01?ooool1o`00007ooooo0Oooool004[ooooo00?o
0000ooooooooool0;oooool6ojS0j`KoYl3[00?oYl3/ojO0jonW`>/01?nW`>/6ojO0k003ojS0jonW
`>coYl3/00?oYl3/1OnX`>/2ojO0k0KoZ<3[1OnX_n/00onX`>_oZ;o[ojRoj`0BojRoj`?oYko[2OnX
_n/3ojNoj`[oZ;o[00?oYko[ojRojonX_n/02_nX_n/00onW_n_oYl3[ojO0j`08ojO0j`goYl7/Gooo
ool00ol0003oooooooooo`03ooooo`7o00000Oooool1ooooo`00Boooool00ol0003oooooooooo`0_
ooooo`KoZ<3[0onW`>/4ojS0j`KoYl3[0onW`>`4ojO0j`GoYl3/00?oZ<3[ojO0k?nW`>`01?nW`>`6
ojS0j`03ojRojonX`>_oZ<3[00?oZ<3[1OnX_n/2ojS0jc3oZ;o[2_nW`>/=ojO1k6;ooooo00?o0000
ooooooooool00oooool1o`00007ooooo0Oooool004cooooo0_l0000`ooooo`goZ<3[3OnW`>/<ojO0
k0?oZ<3[1?nW`N`5ojS0j`03ojRojonX`>_oZ<3[00CoZ<3[4OnX_n/2ojS0j`_oZ;o[0_nX`>/:ojRo
j`;oYl7/2_nW`>/=ojO1k6Kooooo00?o0000ooooooooool00oooool1o`00007ooooo001>ooooo`03
o`000?oooooooooo02kooooo3OnX`>/<ojO0j`goYl3/1onW`N`2ojS0j`CoYl7/1_nX`>/3ojRoj`Co
Z<3[1onX_n/5ojS0j`OoZ;o[1_nX`>/5ojRoj`OoYl7/1OnW`>/<ojO1k6cooooo00?o0000oooooooo
ool00_ooool1o`00007ooooo001?ooooo`03o`000?oooooooooo02oooooo3?nX`>/<ojO0j`GoYl3/
0_nW`>/6ojO0k0GoYl7/00?oYl3/ojO1k?nW`N`01OnW`N`3ojS0j`?oYl7/1onX`>/3ojRoj`?oYl7/
1_nX`>/3ojRoj`CoYl7/1_nX`>/00onX_n_oYl7/ojO1k009ojO1k003ojO0jonW`NcoYl7/00WoYl7/
LOooool01Ol0003ooooooooooooooooo0000007ooooo001@ooooo`03o`000?oooooooooo02oooooo
3?nX`>/3ojO0j`CoZ;o[1OnW`>/00onW`>coYl3[ojO0j`04ojO0j`KoYl3/00?oYl7/ojO0k?nW`>`0
0onW`>`5ojO1k0;oYl3/1_nW`N`5ojS0j`03ojO0k?nW`NcoYl7/00GoYl7/0onX`>/:ojO1k0?oZ<3[
3?nW`N`4ojO0k0OoYl7/M?ooool01Ol0003ooooooooooooooooo0000007ooooo001Aooooo`;o0000
<?ooool<ojS0j`OoZ;o[0_nW`>/4ojRoj`KoYl3[0onW`>`4ojO0j`GoYl3/00?oYl7/ojO0k?nW`>`0
1?nW`>`6ojO1k003ojS0jonW`>coYl3/00?oYl3/1OnW`N`2ojO0k0_oYl7/00?oYl3/ojO1k?nW`N`0
2?nW`N`3ojO0j`OoYl3/0onW`Nahooooo`04o`000?ooooooooooo`00007ooooo001Cooooo`03o`00
0?oooooooooo02kooooo3?nX`>/5ojRoj`03ojS0jonX_n_oZ;o[00GoZ;o[0onW`>/3ojNoj`OoYl3[
0_nW`>`4ojO0j`KoYl3/0onW`N`9ojO0k003ojO1k?nW`>coYl3/00CoYl3/1onW`N`5ojO0k0GoYl7/
2?nW`>/5ojO0k7gooooo00?o0000ooooool000000Oooool005Cooooo00?o0000ooooooooool0;_oo
ool2ojS0j`CoYl3[1_nX`>/00onX_n_oZ<3[ojS0j`03ojS0j`GoZ;o[0_nX`>/6ojNoj`GoYl3[00?o
Yko[ojO0jonW`>/01OnW`>/3ojO0k0?oYl3[2OnW`>`4ojO0j`KoYl3/0onW`N`3ojO0j`KoYl3/00?o
Yl7/ojO0jonW`>/02_nW`>/00onW`>coooooooooo`1nooooo`03o`000?oooooo0000007ooooo001E
ooooo`03o`000?oooooooooo02kooooo1_nW`>/3ojS0j`CoYl3[1OnX`>/00onX_n_oZ<3[ojS0j`04
ojS0j`KoYko[00?oYl3[ojNojonW_n/00onW_n/5ojO0j`;oYko[1_nW`>/4ojO0k0;oYko[1onW`>/3
ojO0k0;oYko[1onW`>/3ojO0k0CoYko[2OnW`>^4ooooo`7o00000Oooool1o`000000E_ooool2o`00
02oooooo0onW`>/3ojO0k0OoYl3[3?nX`>/3ojNoj`CoZ;o[1OnW_n/00onW`>_oYko[ojNoj`04ojNo
j`KoYl3[00?oYl3/ojNojonW_n/00onW_n/5ojO0j`OoYko[1OnW`>/9ojNoj`?oYl3[R_ooool2o`00
0000F?ooool00ol0003oooooooooo`0]ooooo`KoYl3/1OnW`>/2ojO0k0coZ<3[1onX_n/2ojNoj`Co
Z;o[1_nW_n/3ojO0j`?oZ;o[1_nW_n/00onW`>_oYko[ojNoj`09ojNoj`03ojO0jonW_n_oYko[00Wo
Yko[SOooool3o`000000FOooool00ol0003oooooooooo`0]ooooo`KoYl3/00?oYl3[ojO0k?nW`>`0
1?nW`>`4ojS0j`;oYl3/1_nX`>/5ojRoj`03ojS0jonX_n_oZ;o[00GoZ;o[0onW_n/9ojRoj`?oYko[
1?nX_n/8ojNoj`CoZ;o[1onW_n^<ooooo`Co00000oooool005[ooooo00?o0000ooooooooool0;Ooo
ool3ojO0k0CoYl3[1_nW`>`00onX`>_oYl3/ojO0k003ojO0k0KoZ<3[00?oZ;o[ojS0jonX`>/00onX
`>/5ojRoj`;oZ<3[2_nX_n/2ojS0j`OoZ;o[0onW_n/9ojRoj`?oYko[S?ooool3o`0000Oooooo001K
ooooo`03o`000?oooooooooo02kooooo1_nW`>/3ojO0k0?oYl3[1_nW`>`3ojS0j`CoYl3/1OnX`>/0
0onX_n_oZ<3[ojS0j`04ojS0j`OoZ;o[1OnX`>/5ojRoj`03ojS0jonX_n_oZ;o[00SoZ;o[SOooool4
o`0000[ooooo001Looooo`;o0000;oooool<ojO0j`?oYl3/1?nW`>/6ojO0k0;oZ<3[1?nW`>`6ojS0
j`?oZ;o[2OnX`>/00onX_n_oZ<3[ojS0j`03ojS0j`GoZ;o[SOooool4o`0000kooooo001Nooooo`03
o`000?oooooooooo02gooooo4onW`>/3ojO0k0;oYl3[1onW`>`3ojS0j`?oYl3/2OnX`>/4ojO0k0Go
Z<3[00?oZ;o[ooooooooool0R_ooool4o`0001;ooooo001Oooooo`03o`000?oooooooooo02gooooo
6?nW`>/5ojO0k0;oYl3[1_nW`>`3ojS0j`[oYl3/0_nX`>^;ooooo`Co00005_ooool0063ooooo00?o
0000ooooooooool0;Oooool3ojO0j`CoZ;o[4OnW`>/00onW`>coYl3[ojO0j`04ojO0j`CoYl3/0_nW
`>/:ojO0k8cooooo0ol0000Jooooo`00HOooool2o`0002oooooo1_nX_n/2ojO0j`CoYko[4_nW`>/0
0onW`>coYl3[ojO0j`03ojO0j`GoYl3/S?ooool4o`0001gooooo001Sooooo`03o`000?oooooooooo
02gooooo0onX_n/2ojS0j`OoYko[0onW`>/3ojNoja;oYl3[00?oYl3/ooooooooool0ROooool4o`00
027ooooo001Tooooo`03o`000?oooooooooo02gooooo1OnX`>/5ojNoj`;oZ<3[1_nW_n/3ojO0j`Co
Yko[2?nW`>^:ooooo`Co00009Oooool006Gooooo00?o0000ooooooooool0;Oooool5ojS0j`03ojNo
jonX`>_oZ<3[00CoZ<3[1?nW_n/2ojS0j`OoYko[0_nW`>^;ooooo`Co0000:Oooool006Kooooo0_l0
000^ooooo`coZ<3[00?oYko[ojS0jonX`>/00onX`>/5ojNojh_ooooo0ol0000]ooooo`00J?ooool0
0ol0003oooooooooo`0/oooooa;oZ<3[00?oYko[ooooooooool0R?ooool4o`00033ooooo001Yoooo
o`03o`000?oooooooooo02cooooo0onX`>/4ojO0j`SoZ<3[ROooool4o`0003Cooooo001Zooooo`03
o`000?oooooooooo02cooooo1onW`>/2ojS0jh[ooooo1?l0000hooooo`00Joooool2o`0002gooooo
1OnW`>^9ooooo`Co0000??ooool006gooooo00?o0000ooooooooool0:oooool00onW`>_ooooooooo
o`27ooooo`?o0000@?ooool006kooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`23
ooooo`Co0000@oooool006oooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1ooooo
o`Co0000Aoooool0073ooooo0_l0000Yooooo`03o`000?oooooooooo07_ooooo1?l0001;ooooo`00
L_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo07Oooooo1?l0001?ooooo`00Looo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo07Cooooo0ol0001Cooooo`00M?ooool0
0ol0003oooooooooo`0Tooooo`03o`000?oooooooooo073ooooo1?l0001Fooooo`00MOooool00ol0
003oooooooooo`0Sooooo`03o`000?oooooooooo06cooooo1?l0001Jooooo`00M_ooool2o`0002?o
oooo00?o0000ooooooooool0J?ooool4o`0005kooooo001hooooo`03o`000?oooooooooo023ooooo
00?o0000ooooooooool0I?ooool4o`0006;ooooo001iooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool0HOooool3o`0006Kooooo001jooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool0GOooool4o`0006Wooooo001kooooo`;o00007_ooool00ol0003oooooooooo`1Ioooo
o`Co0000KOooool007gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Eooooo`Co
0000LOooool007kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1Aooooo`Co0000
MOooool007oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1>ooooo`?o0000NOoo
ool0083ooooo0_l0000Iooooo`03o`000?oooooooooo04[ooooo1?l0001looooo`00P_ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo04Kooooo1?l00020ooooo`00Poooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo04;ooooo1?l00024ooooo`00Q?ooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo03kooooo1?l00028ooooo`00QOooool2o`0001?ooooo00?o
0000ooooooooool0??ooool3o`0008cooooo0027ooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool0>?ooool4o`0008oooooo0028ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0=?ooool4o`0009?ooooo0029ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool0<?ooool4o`0009Oooooo002:ooooo`;o00003_ooool00ol0003oooooooooo`0/ooooo`Co0000
Voooool008cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Yooooo`?o0000Wooo
ool008gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Uooooo`Co0000X_ooool0
08kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Qooooo`Co0000Y_ooool008oo
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Mooooo`Co0000Z_ooool0093ooooo
0_l00008ooooo`03o`000?oooooooooo01Wooooo1?l0002^ooooo`00T_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo01Kooooo0ol0002booooo`00Toooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo01;ooooo1?l0002eooooo`00U?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00kooooo1?l0002iooooo`00UOooool2o`0000?ooooo00?o0000oooooooo
ool02_ooool4o`000;gooooo002Gooooo`04o`000?ooooooooooo`0000Sooooo1?l00031ooooo`00
V?ooool00ol0003oooooo`000005ooooo`?o0000aOooool009Wooooo0_l000000ooooooo0000o`00
0002o`000<Sooooo002Jooooo`;o0000c?ooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0538698, 0.0432538, \
0.0035044, 0.0035044}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[.12586 .2075 -12 -8.99448 ]
[.12586 .2075 0 .00552 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.56094 .0364 -5.16972 -9 ]
[.56094 .0364 .83028 0 ]
[.75679 .08071 0 -6.17777 ]
[.75679 .08071 12 2.82223 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.9429 .3657 0 -5.9083 ]
[.9429 .3657 6 3.0917 ]
[.02494 .25992 -18 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.01611 .31527 -18 -2.78472 ]
[.01611 .31527 0 6.21528 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00254 .43215 -12 -2.88407 ]
[-0.00254 .43215 0 6.11593 ]
[-0.0124 .49393 -12 -2.93688 ]
[-0.0124 .49393 0 6.06312 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
[(-2)] .12586 .2075 1 .99877 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.56863 .04703 m
.57247 .05235 L
s
[(2)] .56094 .0364 .72324 1 Mshowa
.125 Mabswid
.18558 .19702 m
.18832 .19985 L
s
.23703 .17687 m
.23971 .17975 L
s
.28951 .15632 m
.29214 .15925 L
s
.39772 .11395 m
.40023 .11699 L
s
.4535 .09211 m
.45595 .0952 L
s
.51046 .06981 m
.51284 .07294 L
s
.08568 .23614 m
.08851 .23887 L
s
.62804 .02377 m
.63027 .02701 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.7445 .0853 m
.73835 .08759 L
s
[(-2)] .75679 .08071 -1 .37284 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.93037 .36962 m
.92411 .37158 L
s
[(2)] .9429 .3657 -1 .31296 Mshowa
.125 Mabswid
.7708 .12553 m
.7671 .12688 L
s
.79613 .16428 m
.79242 .1656 L
s
.82054 .20161 m
.81682 .20291 L
s
.86679 .27235 m
.86305 .2736 L
s
.88871 .30589 m
.88497 .30711 L
s
.9099 .3383 m
.90615 .3395 L
s
.71716 .04348 m
.71349 .04489 L
s
.95018 .39992 m
.94642 .40107 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(-20)] .02494 .25992 1 -0.39157 Mshowa
.02837 .31059 m
.0345 .30825 L
s
[(-10)] .01611 .31527 1 -0.38117 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.00981 .42772 m
.01599 .4255 L
s
[(10)] -0.00254 .43215 1 -0.3591 Mshowa
0 .48963 m
.0062 .48748 L
s
[(20)] -0.0124 .49393 1 -0.34736 Mshowa
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.657 .751 .919 r
.39362 .6948 .40169 .70187 .4152 .69804 .40717 .69092 Mtetra
.655 .75 .92 r
.40717 .69092 .4152 .69804 .42878 .69418 .42079 .68708 Mtetra
.655 .752 .921 r
.42079 .68708 .42878 .69418 .44242 .69034 .43448 .68323 Mtetra
.43448 .68323 .44242 .69034 .45614 .68651 .44824 .67935 Mtetra
.656 .752 .921 r
.44824 .67935 .45614 .68651 .46992 .68265 .46207 .67542 Mtetra
.657 .752 .92 r
.46207 .67542 .46992 .68265 .48378 .67874 .47597 .67144 Mtetra
.657 .751 .919 r
.47597 .67144 .48378 .67874 .4977 .6748 .48994 .66744 Mtetra
.656 .75 .919 r
.48994 .66744 .4977 .6748 .5117 .67081 .50398 .66345 Mtetra
.655 .751 .92 r
.50398 .66345 .5117 .67081 .52577 .66682 .5181 .65948 Mtetra
.655 .752 .921 r
.5181 .65948 .52577 .66682 .53991 .66284 .53229 .65548 Mtetra
.655 .753 .922 r
.53229 .65548 .53991 .66284 .55412 .65886 .54655 .65146 Mtetra
.54655 .65146 .55412 .65886 .56841 .65486 .56088 .64741 Mtetra
.656 .753 .921 r
.56088 .64741 .56841 .65486 .58277 .65083 .57529 .64332 Mtetra
.656 .752 .921 r
.57529 .64332 .58277 .65083 .59721 .64677 .58978 .6392 Mtetra
.657 .751 .92 r
.58978 .6392 .59721 .64677 .61172 .64269 .60434 .63504 Mtetra
.657 .751 .919 r
.60434 .63504 .61172 .64269 .62631 .63858 .61898 .63086 Mtetra
.656 .75 .919 r
.61898 .63086 .62631 .63858 .64097 .63445 .63369 .62667 Mtetra
.656 .749 .918 r
.63369 .62667 .64097 .63445 .65571 .63029 .64849 .62247 Mtetra
.64849 .62247 .65571 .63029 .67053 .62611 .66336 .61824 Mtetra
.66336 .61824 .67053 .62611 .68542 .62191 .67831 .614 Mtetra
.67831 .614 .68542 .62191 .7004 .61769 .69333 .60974 Mtetra
.69333 .60974 .7004 .61769 .71545 .61345 .70844 .60547 Mtetra
.656 .749 .919 r
.70844 .60547 .71545 .61345 .73059 .60918 .72363 .60118 Mtetra
.655 .749 .919 r
.72363 .60118 .73059 .60918 .7458 .60489 .73891 .59687 Mtetra
.655 .75 .92 r
.73891 .59687 .7458 .60489 .7611 .60057 .75426 .59254 Mtetra
.655 .751 .92 r
.75426 .59254 .7611 .60057 .77647 .59622 .7697 .58818 Mtetra
.656 .752 .921 r
.7697 .58818 .77647 .59622 .79193 .59184 .78522 .58377 Mtetra
.656 .753 .921 r
.78522 .58377 .79193 .59184 .80748 .58743 .80082 .57933 Mtetra
.80082 .57933 .80748 .58743 .8231 .583 .81651 .57486 Mtetra
.81651 .57486 .8231 .583 .83881 .57855 .83228 .57035 Mtetra
.83228 .57035 .83881 .57855 .85461 .57413 .84814 .56582 Mtetra
.656 .751 .92 r
.84814 .56582 .85461 .57413 .8705 .56969 .86409 .5613 Mtetra
.655 .749 .919 r
.86409 .5613 .8705 .56969 .88648 .56521 .88012 .55679 Mtetra
.655 .75 .92 r
.88012 .55679 .88648 .56521 .90253 .56068 .89625 .55226 Mtetra
.656 .751 .92 r
.89625 .55226 .90253 .56068 .91868 .55611 .91246 .54766 Mtetra
.656 .752 .921 r
.91246 .54766 .91868 .55611 .93491 .55149 .92876 .54302 Mtetra
.657 .753 .921 r
.92876 .54302 .93491 .55149 .95123 .54687 .94515 .53833 Mtetra
.656 .752 .92 r
.94515 .53833 .95123 .54687 .96765 .54228 .96163 .53363 Mtetra
.655 .75 .92 r
.96163 .53363 .96765 .54228 .98417 .53765 .97821 .52896 Mtetra
.38547 .68765 .39362 .6948 .40717 .69092 .39906 .68379 Mtetra
.654 .752 .921 r
.39906 .68379 .40717 .69092 .42079 .68708 .41273 .67993 Mtetra
.655 .752 .921 r
.41273 .67993 .42079 .68708 .43448 .68323 .42646 .67603 Mtetra
.656 .752 .921 r
.42646 .67603 .43448 .68323 .44824 .67935 .44026 .67208 Mtetra
.657 .752 .92 r
.44026 .67208 .44824 .67935 .46207 .67542 .45414 .66807 Mtetra
.657 .75 .919 r
.45414 .66807 .46207 .67542 .47597 .67144 .46808 .66406 Mtetra
.655 .75 .919 r
.46808 .66406 .47597 .67144 .48994 .66744 .4821 .66008 Mtetra
.655 .751 .921 r
.4821 .66008 .48994 .66744 .50398 .66345 .49619 .65609 Mtetra
.655 .752 .922 r
.49619 .65609 .50398 .66345 .5181 .65948 .51035 .65208 Mtetra
.655 .753 .922 r
.51035 .65208 .5181 .65948 .53229 .65548 .52459 .64804 Mtetra
.656 .752 .921 r
.52459 .64804 .53229 .65548 .54655 .65146 .5389 .64395 Mtetra
.657 .752 .92 r
.5389 .64395 .54655 .65146 .56088 .64741 .55328 .6398 Mtetra
.657 .751 .919 r
.55328 .6398 .56088 .64741 .57529 .64332 .56774 .63564 Mtetra
.657 .749 .918 r
.56774 .63564 .57529 .64332 .58978 .6392 .58228 .63146 Mtetra
.656 .749 .918 r
.58228 .63146 .58978 .6392 .60434 .63504 .59689 .62728 Mtetra
.656 .749 .919 r
.59689 .62728 .60434 .63504 .61898 .63086 .61158 .62309 Mtetra
.656 .75 .919 r
.61158 .62309 .61898 .63086 .63369 .62667 .62635 .61888 Mtetra
.656 .751 .92 r
.62635 .61888 .63369 .62667 .64849 .62247 .64119 .61465 Mtetra
.64119 .61465 .64849 .62247 .66336 .61824 .65612 .61039 Mtetra
.65612 .61039 .66336 .61824 .67831 .614 .67112 .60611 Mtetra
.67112 .60611 .67831 .614 .69333 .60974 .68621 .6018 Mtetra
.68621 .6018 .69333 .60974 .70844 .60547 .70137 .59747 Mtetra
.70137 .59747 .70844 .60547 .72363 .60118 .71662 .59311 Mtetra
.656 .75 .919 r
.71662 .59311 .72363 .60118 .73891 .59687 .73194 .58873 Mtetra
.656 .749 .919 r
.73194 .58873 .73891 .59687 .75426 .59254 .74736 .58434 Mtetra
.655 .749 .919 r
.74736 .58434 .75426 .59254 .7697 .58818 .76285 .57995 Mtetra
.76285 .57995 .7697 .58818 .78522 .58377 .77843 .57554 Mtetra
.655 .75 .92 r
.77843 .57554 .78522 .58377 .80082 .57933 .7941 .57111 Mtetra
.656 .752 .921 r
.7941 .57111 .80082 .57933 .81651 .57486 .80985 .56662 Mtetra
.656 .753 .921 r
.80985 .56662 .81651 .57486 .83228 .57035 .82568 .56208 Mtetra
.82568 .56208 .83228 .57035 .84814 .56582 .8416 .5575 Mtetra
.657 .753 .921 r
.8416 .5575 .84814 .56582 .86409 .5613 .85761 .55289 Mtetra
.656 .752 .92 r
.85761 .55289 .86409 .5613 .88012 .55679 .87371 .54827 Mtetra
.655 .75 .92 r
.87371 .54827 .88012 .55679 .89625 .55226 .8899 .54369 Mtetra
.8899 .54369 .89625 .55226 .91246 .54766 .90618 .5391 Mtetra
.656 .751 .92 r
.90618 .5391 .91246 .54766 .92876 .54302 .92255 .53443 Mtetra
.656 .752 .921 r
.92255 .53443 .92876 .54302 .94515 .53833 .93901 .52972 Mtetra
.657 .753 .921 r
.93901 .52972 .94515 .53833 .96163 .53363 .95555 .52495 Mtetra
.656 .752 .921 r
.95555 .52495 .96163 .53363 .97821 .52896 .97219 .52018 Mtetra
.654 .751 .921 r
.37724 .68049 .38547 .68765 .39906 .68379 .39088 .67662 Mtetra
.655 .752 .921 r
.39088 .67662 .39906 .68379 .41273 .67993 .40459 .6727 Mtetra
.656 .752 .92 r
.40459 .6727 .41273 .67993 .42646 .67603 .41836 .66873 Mtetra
.657 .752 .919 r
.41836 .66873 .42646 .67603 .44026 .67208 .43221 .6647 Mtetra
.657 .75 .919 r
.43221 .6647 .44026 .67208 .45414 .66807 .44613 .66067 Mtetra
.655 .75 .92 r
.44613 .66067 .45414 .66807 .46808 .66406 .46012 .65669 Mtetra
.655 .752 .921 r
.46012 .65669 .46808 .66406 .4821 .66008 .47419 .65269 Mtetra
.655 .753 .922 r
.47419 .65269 .4821 .66008 .49619 .65609 .48832 .64866 Mtetra
.655 .752 .921 r
.48832 .64866 .49619 .65609 .51035 .65208 .50253 .64458 Mtetra
.657 .752 .92 r
.50253 .64458 .51035 .65208 .52459 .64804 .51682 .64044 Mtetra
.657 .751 .919 r
.51682 .64044 .52459 .64804 .5389 .64395 .53118 .63626 Mtetra
.657 .749 .918 r
.53118 .63626 .5389 .64395 .55328 .6398 .54561 .63209 Mtetra
.656 .749 .919 r
.54561 .63209 .55328 .6398 .56774 .63564 .56012 .62793 Mtetra
.655 .75 .92 r
.56012 .62793 .56774 .63564 .58228 .63146 .57471 .62376 Mtetra
.655 .752 .921 r
.57471 .62376 .58228 .63146 .59689 .62728 .58937 .61957 Mtetra
.58937 .61957 .59689 .62728 .61158 .62309 .60411 .61535 Mtetra
.655 .753 .922 r
.60411 .61535 .61158 .62309 .62635 .61888 .61894 .61112 Mtetra
.61894 .61112 .62635 .61888 .64119 .61465 .63383 .60685 Mtetra
.63383 .60685 .64119 .61465 .65612 .61039 .64881 .60255 Mtetra
.656 .754 .922 r
.64881 .60255 .65612 .61039 .67112 .60611 .66387 .59823 Mtetra
.66387 .59823 .67112 .60611 .68621 .6018 .67901 .59387 Mtetra
.67901 .59387 .68621 .6018 .70137 .59747 .69423 .58949 Mtetra
.656 .753 .922 r
.69423 .58949 .70137 .59747 .71662 .59311 .70953 .58508 Mtetra
.656 .753 .921 r
.70953 .58508 .71662 .59311 .73194 .58873 .72492 .58064 Mtetra
.72492 .58064 .73194 .58873 .74736 .58434 .74039 .57617 Mtetra
.656 .752 .92 r
.74039 .57617 .74736 .58434 .76285 .57995 .75594 .57169 Mtetra
.656 .751 .92 r
.75594 .57169 .76285 .57995 .77843 .57554 .77158 .56718 Mtetra
.655 .749 .919 r
.77158 .56718 .77843 .57554 .7941 .57111 .7873 .5627 Mtetra
.7873 .5627 .7941 .57111 .80985 .56662 .80312 .55821 Mtetra
.655 .75 .92 r
.80312 .55821 .80985 .56662 .82568 .56208 .81902 .55369 Mtetra
.656 .752 .921 r
.81902 .55369 .82568 .56208 .8416 .5575 .835 .54909 Mtetra
.656 .753 .921 r
.835 .54909 .8416 .5575 .85761 .55289 .85107 .54445 Mtetra
.657 .753 .921 r
.85107 .54445 .85761 .55289 .87371 .54827 .86723 .53976 Mtetra
.86723 .53976 .87371 .54827 .8899 .54369 .88348 .53506 Mtetra
.655 .75 .92 r
.88348 .53506 .8899 .54369 .90618 .5391 .89983 .53039 Mtetra
.655 .749 .92 r
.89983 .53039 .90618 .5391 .92255 .53443 .91627 .52573 Mtetra
.656 .751 .92 r
.91627 .52573 .92255 .53443 .93901 .52972 .9328 .52099 Mtetra
.656 .752 .92 r
.9328 .52099 .93901 .52972 .95555 .52495 .94941 .5162 Mtetra
.657 .753 .921 r
.94941 .5162 .95555 .52495 .97219 .52018 .96612 .51135 Mtetra
.655 .752 .921 r
.36894 .67328 .37724 .68049 .39088 .67662 .38262 .66935 Mtetra
.656 .752 .921 r
.38262 .66935 .39088 .67662 .40459 .6727 .39637 .66537 Mtetra
.657 .752 .919 r
.39637 .66537 .40459 .6727 .41836 .66873 .41019 .66132 Mtetra
.657 .75 .919 r
.41019 .66132 .41836 .66873 .43221 .6647 .42409 .65728 Mtetra
.655 .75 .92 r
.42409 .65728 .43221 .6647 .44613 .66067 .43805 .65328 Mtetra
.654 .752 .922 r
.43805 .65328 .44613 .66067 .46012 .65669 .45209 .64926 Mtetra
.655 .752 .922 r
.45209 .64926 .46012 .65669 .47419 .65269 .4662 .64521 Mtetra
.656 .752 .921 r
.4662 .64521 .47419 .65269 .48832 .64866 .48038 .6411 Mtetra
.658 .752 .919 r
.48038 .6411 .48832 .64866 .50253 .64458 .49464 .63692 Mtetra
.657 .75 .918 r
.49464 .63692 .50253 .64458 .51682 .64044 .50897 .63273 Mtetra
.656 .749 .919 r
.50897 .63273 .51682 .64044 .53118 .63626 .52338 .62857 Mtetra
.655 .751 .92 r
.52338 .62857 .53118 .63626 .54561 .63209 .53787 .62442 Mtetra
.655 .752 .921 r
.53787 .62442 .54561 .63209 .56012 .62793 .55243 .62024 Mtetra
.655 .753 .922 r
.55243 .62024 .56012 .62793 .57471 .62376 .56706 .61605 Mtetra
.56706 .61605 .57471 .62376 .58937 .61957 .58178 .61182 Mtetra
.655 .754 .922 r
.58178 .61182 .58937 .61957 .60411 .61535 .59657 .60756 Mtetra
.655 .753 .922 r
.59657 .60756 .60411 .61535 .61894 .61112 .61145 .60327 Mtetra
.656 .753 .922 r
.61145 .60327 .61894 .61112 .63383 .60685 .6264 .59895 Mtetra
.656 .753 .921 r
.6264 .59895 .63383 .60685 .64881 .60255 .64143 .5946 Mtetra
.64143 .5946 .64881 .60255 .66387 .59823 .65655 .59023 Mtetra
.655 .753 .921 r
.65655 .59023 .66387 .59823 .67901 .59387 .67174 .58584 Mtetra
.656 .753 .921 r
.67174 .58584 .67901 .59387 .69423 .58949 .68702 .58143 Mtetra
.656 .753 .922 r
.68702 .58143 .69423 .58949 .70953 .58508 .70238 .57698 Mtetra
.656 .754 .922 r
.70238 .57698 .70953 .58508 .72492 .58064 .71782 .57251 Mtetra
.71782 .57251 .72492 .58064 .74039 .57617 .73335 .56799 Mtetra
.657 .754 .922 r
.73335 .56799 .74039 .57617 .75594 .57169 .74896 .56344 Mtetra
.657 .753 .921 r
.74896 .56344 .75594 .57169 .77158 .56718 .76466 .55887 Mtetra
.656 .753 .921 r
.76466 .55887 .77158 .56718 .7873 .5627 .78044 .55428 Mtetra
.656 .751 .92 r
.78044 .55428 .7873 .5627 .80312 .55821 .79631 .54968 Mtetra
.655 .749 .919 r
.79631 .54968 .80312 .55821 .81902 .55369 .81227 .54511 Mtetra
.654 .749 .919 r
.81227 .54511 .81902 .55369 .835 .54909 .82833 .54054 Mtetra
.655 .751 .92 r
.82833 .54054 .835 .54909 .85107 .54445 .84447 .53589 Mtetra
.656 .753 .921 r
.84447 .53589 .85107 .54445 .86723 .53976 .86069 .53117 Mtetra
.657 .753 .921 r
.86069 .53117 .86723 .53976 .88348 .53506 .87701 .52641 Mtetra
.87701 .52641 .88348 .53506 .89983 .53039 .89341 .52163 Mtetra
.655 .75 .92 r
.89341 .52163 .89983 .53039 .91627 .52573 .90992 .51689 Mtetra
.654 .749 .92 r
.90992 .51689 .91627 .52573 .9328 .52099 .92652 .51215 Mtetra
.656 .751 .92 r
.92652 .51215 .9328 .52099 .94941 .5162 .94321 .50734 Mtetra
.656 .752 .92 r
.94321 .50734 .94941 .5162 .96612 .51135 .95999 .50246 Mtetra
.656 .752 .921 r
.36056 .66599 .36894 .67328 .38262 .66935 .37428 .66199 Mtetra
.657 .752 .92 r
.37428 .66199 .38262 .66935 .39637 .66537 .38808 .65793 Mtetra
.657 .75 .919 r
.38808 .65793 .39637 .66537 .41019 .66132 .40195 .65386 Mtetra
.655 .75 .92 r
.40195 .65386 .41019 .66132 .42409 .65728 .41588 .64985 Mtetra
.654 .752 .922 r
.41588 .64985 .42409 .65728 .43805 .65328 .42989 .64582 Mtetra
.655 .752 .921 r
.42989 .64582 .43805 .65328 .45209 .64926 .44397 .64175 Mtetra
.657 .752 .92 r
.44397 .64175 .45209 .64926 .4662 .64521 .45813 .6376 Mtetra
.658 .751 .919 r
.45813 .6376 .4662 .64521 .48038 .6411 .47236 .63339 Mtetra
.657 .749 .918 r
.47236 .63339 .48038 .6411 .49464 .63692 .48667 .62921 Mtetra
.655 .75 .92 r
.48667 .62921 .49464 .63692 .50897 .63273 .50105 .62505 Mtetra
.654 .752 .921 r
.50105 .62505 .50897 .63273 .52338 .62857 .51551 .62089 Mtetra
.654 .753 .922 r
.51551 .62089 .52338 .62857 .53787 .62442 .53004 .61671 Mtetra
.655 .753 .922 r
.53004 .61671 .53787 .62442 .55243 .62024 .54465 .61249 Mtetra
.656 .753 .922 r
.54465 .61249 .55243 .62024 .56706 .61605 .55934 .60822 Mtetra
.657 .753 .921 r
.55934 .60822 .56706 .61605 .58178 .61182 .57411 .60388 Mtetra
.657 .751 .919 r
.57411 .60388 .58178 .61182 .59657 .60756 .58896 .59953 Mtetra
.657 .75 .918 r
.58896 .59953 .59657 .60756 .61145 .60327 .60388 .59515 Mtetra
.657 .749 .918 r
.60388 .59515 .61145 .60327 .6264 .59895 .61889 .59077 Mtetra
.656 .748 .917 r
.61889 .59077 .6264 .59895 .64143 .5946 .63397 .58637 Mtetra
.63397 .58637 .64143 .5946 .65655 .59023 .64914 .58196 Mtetra
.656 .748 .918 r
.64914 .58196 .65655 .59023 .67174 .58584 .66439 .57753 Mtetra
.66439 .57753 .67174 .58584 .68702 .58143 .67973 .57309 Mtetra
.655 .748 .918 r
.67973 .57309 .68702 .58143 .70238 .57698 .69515 .56864 Mtetra
.655 .749 .919 r
.69515 .56864 .70238 .57698 .71782 .57251 .71065 .56417 Mtetra
.655 .75 .92 r
.71065 .56417 .71782 .57251 .73335 .56799 .72624 .55968 Mtetra
.656 .752 .921 r
.72624 .55968 .73335 .56799 .74896 .56344 .74191 .55513 Mtetra
.656 .754 .922 r
.74191 .55513 .74896 .56344 .76466 .55887 .75767 .55051 Mtetra
.657 .754 .921 r
.75767 .55051 .76466 .55887 .78044 .55428 .77351 .54585 Mtetra
.657 .753 .921 r
.77351 .54585 .78044 .55428 .79631 .54968 .78944 .54118 Mtetra
.656 .753 .921 r
.78944 .54118 .79631 .54968 .81227 .54511 .80546 .53649 Mtetra
.655 .75 .92 r
.80546 .53649 .81227 .54511 .82833 .54054 .82158 .53182 Mtetra
.654 .749 .919 r
.82158 .53182 .82833 .54054 .84447 .53589 .83779 .52718 Mtetra
.655 .75 .92 r
.83779 .52718 .84447 .53589 .86069 .53117 .85408 .52247 Mtetra
.656 .752 .921 r
.85408 .52247 .86069 .53117 .87701 .52641 .87046 .51768 Mtetra
.657 .753 .921 r
.87046 .51768 .87701 .52641 .89341 .52163 .88694 .51284 Mtetra
.88694 .51284 .89341 .52163 .90992 .51689 .9035 .50799 Mtetra
.655 .75 .92 r
.9035 .50799 .90992 .51689 .92652 .51215 .92017 .50317 Mtetra
.92017 .50317 .92652 .51215 .94321 .50734 .93693 .49836 Mtetra
.656 .751 .92 r
.93693 .49836 .94321 .50734 .95999 .50246 .95379 .49345 Mtetra
.657 .752 .92 r
.35209 .6586 .36056 .66599 .37428 .66199 .36586 .65453 Mtetra
.657 .751 .919 r
.36586 .65453 .37428 .66199 .38808 .65793 .37971 .65043 Mtetra
.655 .75 .92 r
.37971 .65043 .38808 .65793 .40195 .65386 .39361 .64639 Mtetra
.654 .752 .921 r
.39361 .64639 .40195 .65386 .41588 .64985 .4076 .64235 Mtetra
.655 .752 .921 r
.4076 .64235 .41588 .64985 .42989 .64582 .42165 .63826 Mtetra
.657 .752 .92 r
.42165 .63826 .42989 .64582 .44397 .64175 .43578 .63409 Mtetra
.658 .751 .919 r
.43578 .63409 .44397 .64175 .45813 .6376 .44999 .62986 Mtetra
.656 .75 .919 r
.44999 .62986 .45813 .6376 .47236 .63339 .46427 .62568 Mtetra
.655 .751 .92 r
.46427 .62568 .47236 .63339 .48667 .62921 .47862 .62151 Mtetra
.654 .752 .922 r
.47862 .62151 .48667 .62921 .50105 .62505 .49305 .61735 Mtetra
.654 .753 .922 r
.49305 .61735 .50105 .62505 .51551 .62089 .50756 .61315 Mtetra
.656 .753 .922 r
.50756 .61315 .51551 .62089 .53004 .61671 .52214 .60887 Mtetra
.658 .752 .92 r
.52214 .60887 .53004 .61671 .54465 .61249 .53681 .60452 Mtetra
.658 .75 .918 r
.53681 .60452 .54465 .61249 .55934 .60822 .55155 .60014 Mtetra
.657 .748 .917 r
.55155 .60014 .55934 .60822 .57411 .60388 .56636 .59576 Mtetra
.656 .748 .918 r
.56636 .59576 .57411 .60388 .58896 .59953 .58126 .5914 Mtetra
.656 .749 .918 r
.58126 .5914 .58896 .59953 .60388 .59515 .59624 .58702 Mtetra
.656 .75 .919 r
.59624 .58702 .60388 .59515 .61889 .59077 .6113 .58262 Mtetra
.656 .751 .92 r
.6113 .58262 .61889 .59077 .63397 .58637 .62644 .57819 Mtetra
.62644 .57819 .63397 .58637 .64914 .58196 .64167 .57373 Mtetra
.64167 .57373 .64914 .58196 .66439 .57753 .65698 .56925 Mtetra
.65698 .56925 .66439 .57753 .67973 .57309 .67237 .56474 Mtetra
.656 .75 .919 r
.67237 .56474 .67973 .57309 .69515 .56864 .68784 .5602 Mtetra
.656 .749 .918 r
.68784 .5602 .69515 .56864 .71065 .56417 .7034 .55565 Mtetra
.655 .748 .918 r
.7034 .55565 .71065 .56417 .72624 .55968 .71905 .55111 Mtetra
.654 .748 .918 r
.71905 .55111 .72624 .55968 .74191 .55513 .73479 .54657 Mtetra
.654 .749 .919 r
.73479 .54657 .74191 .55513 .75767 .55051 .75061 .54201 Mtetra
.656 .752 .921 r
.75061 .54201 .75767 .55051 .77351 .54585 .76652 .53736 Mtetra
.657 .754 .921 r
.76652 .53736 .77351 .54585 .78944 .54118 .78251 .53263 Mtetra
.78251 .53263 .78944 .54118 .80546 .53649 .79859 .52786 Mtetra
.657 .753 .921 r
.79859 .52786 .80546 .53649 .82158 .53182 .81476 .52309 Mtetra
.656 .751 .92 r
.81476 .52309 .82158 .53182 .83779 .52718 .83103 .51833 Mtetra
.654 .749 .919 r
.83103 .51833 .83779 .52718 .85408 .52247 .8474 .51362 Mtetra
.655 .75 .92 r
.8474 .51362 .85408 .52247 .87046 .51768 .86385 .50884 Mtetra
.656 .752 .921 r
.86385 .50884 .87046 .51768 .88694 .51284 .88039 .50397 Mtetra
.657 .753 .921 r
.88039 .50397 .88694 .51284 .9035 .50799 .89703 .49905 Mtetra
.89703 .49905 .9035 .50799 .92017 .50317 .91375 .49412 Mtetra
.655 .75 .92 r
.91375 .49412 .92017 .50317 .93693 .49836 .93059 .48924 Mtetra
.93059 .48924 .93693 .49836 .95379 .49345 .94752 .48433 Mtetra
.658 .751 .919 r
.34355 .65113 .35209 .6586 .36586 .65453 .35737 .647 Mtetra
.655 .75 .92 r
.35737 .647 .36586 .65453 .37971 .65043 .37125 .64292 Mtetra
.654 .752 .921 r
.37125 .64292 .37971 .65043 .39361 .64639 .3852 .63886 Mtetra
.655 .752 .921 r
.3852 .63886 .39361 .64639 .4076 .64235 .39923 .63476 Mtetra
.657 .752 .92 r
.39923 .63476 .4076 .64235 .42165 .63826 .41334 .63058 Mtetra
.658 .751 .919 r
.41334 .63058 .42165 .63826 .43578 .63409 .42751 .62633 Mtetra
.656 .75 .919 r
.42751 .62633 .43578 .63409 .44999 .62986 .44177 .62212 Mtetra
.654 .751 .921 r
.44177 .62212 .44999 .62986 .46427 .62568 .45609 .61795 Mtetra
.654 .752 .922 r
.45609 .61795 .46427 .62568 .47862 .62151 .47049 .61377 Mtetra
.655 .753 .922 r
.47049 .61377 .47862 .62151 .49305 .61735 .48497 .60955 Mtetra
.657 .753 .921 r
.48497 .60955 .49305 .61735 .50756 .61315 .49953 .6052 Mtetra
.658 .751 .918 r
.49953 .6052 .50756 .61315 .52214 .60887 .51417 .60081 Mtetra
.657 .749 .917 r
.51417 .60081 .52214 .60887 .53681 .60452 .52888 .59643 Mtetra
.656 .749 .918 r
.52888 .59643 .53681 .60452 .55155 .60014 .54367 .59208 Mtetra
.655 .75 .92 r
.54367 .59208 .55155 .60014 .56636 .59576 .55854 .58772 Mtetra
.655 .752 .921 r
.55854 .58772 .56636 .59576 .58126 .5914 .5735 .58334 Mtetra
.654 .752 .922 r
.5735 .58334 .58126 .5914 .59624 .58702 .58853 .57896 Mtetra
.655 .754 .922 r
.58853 .57896 .59624 .58702 .6113 .58262 .60365 .57454 Mtetra
.655 .754 .923 r
.60365 .57454 .6113 .58262 .62644 .57819 .61884 .57007 Mtetra
.656 .755 .923 r
.61884 .57007 .62644 .57819 .64167 .57373 .63412 .56557 Mtetra
.63412 .56557 .64167 .57373 .65698 .56925 .64949 .56103 Mtetra
.656 .755 .922 r
.64949 .56103 .65698 .56925 .67237 .56474 .66494 .55645 Mtetra
.657 .754 .922 r
.66494 .55645 .67237 .56474 .68784 .5602 .68047 .55183 Mtetra
.656 .753 .921 r
.68047 .55183 .68784 .5602 .7034 .55565 .69608 .5472 Mtetra
.656 .752 .921 r
.69608 .5472 .7034 .55565 .71905 .55111 .71179 .54255 Mtetra
.656 .751 .919 r
.71179 .54255 .71905 .55111 .73479 .54657 .72758 .5379 Mtetra
.655 .748 .919 r
.72758 .5379 .73479 .54657 .75061 .54201 .74346 .53326 Mtetra
.654 .747 .919 r
.74346 .53326 .75061 .54201 .76652 .53736 .75944 .52864 Mtetra
.654 .75 .92 r
.75944 .52864 .76652 .53736 .78251 .53263 .7755 .52397 Mtetra
.657 .753 .921 r
.7755 .52397 .78251 .53263 .79859 .52786 .79165 .51918 Mtetra
.657 .754 .921 r
.79165 .51918 .79859 .52786 .81476 .52309 .80789 .51433 Mtetra
.657 .753 .921 r
.80789 .51433 .81476 .52309 .83103 .51833 .82421 .50947 Mtetra
.656 .751 .92 r
.82421 .50947 .83103 .51833 .8474 .51362 .84064 .50463 Mtetra
.654 .749 .919 r
.84064 .50463 .8474 .51362 .86385 .50884 .85716 .49985 Mtetra
.655 .75 .92 r
.85716 .49985 .86385 .50884 .88039 .50397 .87378 .49499 Mtetra
.657 .752 .921 r
.87378 .49499 .88039 .50397 .89703 .49905 .89048 .49003 Mtetra
.657 .753 .921 r
.89048 .49003 .89703 .49905 .91375 .49412 .90728 .48503 Mtetra
.656 .752 .921 r
.90728 .48503 .91375 .49412 .93059 .48924 .92418 .48003 Mtetra
.654 .75 .92 r
.92418 .48003 .93059 .48924 .94752 .48433 .94118 .47509 Mtetra
.656 .751 .919 r
.33493 .64356 .34355 .65113 .35737 .647 .34879 .63943 Mtetra
.654 .751 .921 r
.34879 .63943 .35737 .647 .37125 .64292 .36271 .63535 Mtetra
.654 .752 .922 r
.36271 .63535 .37125 .64292 .3852 .63886 .37671 .63125 Mtetra
.656 .752 .921 r
.37671 .63125 .3852 .63886 .39923 .63476 .39079 .62706 Mtetra
.658 .752 .919 r
.39079 .62706 .39923 .63476 .41334 .63058 .40494 .62278 Mtetra
.656 .75 .919 r
.40494 .62278 .41334 .63058 .42751 .62633 .41916 .61855 Mtetra
.654 .751 .921 r
.41916 .61855 .42751 .62633 .44177 .62212 .43346 .61436 Mtetra
.654 .752 .922 r
.43346 .61436 .44177 .62212 .45609 .61795 .44783 .61017 Mtetra
.655 .753 .922 r
.44783 .61017 .45609 .61795 .47049 .61377 .46229 .60592 Mtetra
.658 .753 .92 r
.46229 .60592 .47049 .61377 .48497 .60955 .47682 .60152 Mtetra
.658 .75 .918 r
.47682 .60152 .48497 .60955 .49953 .6052 .49143 .5971 Mtetra
.656 .749 .918 r
.49143 .5971 .49953 .6052 .51417 .60081 .50611 .59275 Mtetra
.655 .75 .92 r
.50611 .59275 .51417 .60081 .52888 .59643 .52087 .5884 Mtetra
.654 .752 .922 r
.52087 .5884 .52888 .59643 .54367 .59208 .53572 .58407 Mtetra
.654 .753 .923 r
.53572 .58407 .54367 .59208 .55854 .58772 .55064 .57971 Mtetra
.654 .755 .924 r
.55064 .57971 .55854 .58772 .5735 .58334 .56565 .57532 Mtetra
.655 .755 .924 r
.56565 .57532 .5735 .58334 .58853 .57896 .58074 .57087 Mtetra
.656 .755 .923 r
.58074 .57087 .58853 .57896 .60365 .57454 .59591 .56636 Mtetra
.656 .754 .922 r
.59591 .56636 .60365 .57454 .61884 .57007 .61116 .56183 Mtetra
.656 .753 .922 r
.61116 .56183 .61884 .57007 .63412 .56557 .6265 .55728 Mtetra
.655 .753 .922 r
.6265 .55728 .63412 .56557 .64949 .56103 .64192 .55272 Mtetra
.655 .754 .922 r
.64192 .55272 .64949 .56103 .66494 .55645 .65743 .54814 Mtetra
.656 .755 .923 r
.65743 .54814 .66494 .55645 .68047 .55183 .67302 .54349 Mtetra
.657 .756 .923 r
.67302 .54349 .68047 .55183 .69608 .5472 .6887 .53879 Mtetra
.657 .756 .922 r
.6887 .53879 .69608 .5472 .71179 .54255 .70446 .53404 Mtetra
.657 .754 .921 r
.70446 .53404 .71179 .54255 .72758 .5379 .72031 .52927 Mtetra
.657 .752 .921 r
.72031 .52927 .72758 .5379 .74346 .53326 .73625 .52452 Mtetra
.656 .75 .92 r
.73625 .52452 .74346 .53326 .75944 .52864 .75228 .51977 Mtetra
.654 .748 .919 r
.75228 .51977 .75944 .52864 .7755 .52397 .76841 .51508 Mtetra
.76841 .51508 .7755 .52397 .79165 .51918 .78463 .51036 Mtetra
.657 .753 .921 r
.78463 .51036 .79165 .51918 .80789 .51433 .80094 .5055 Mtetra
.657 .754 .921 r
.80094 .5055 .80789 .51433 .82421 .50947 .81733 .50056 Mtetra
.657 .753 .921 r
.81733 .50056 .82421 .50947 .84064 .50463 .83382 .49562 Mtetra
.655 .751 .92 r
.83382 .49562 .84064 .50463 .85716 .49985 .8504 .49072 Mtetra
.654 .749 .92 r
.8504 .49072 .85716 .49985 .87378 .49499 .86709 .48586 Mtetra
.656 .751 .92 r
.86709 .48586 .87378 .49499 .89048 .49003 .88387 .4809 Mtetra
.657 .753 .92 r
.88387 .4809 .89048 .49003 .90728 .48503 .90074 .47585 Mtetra
.657 .753 .921 r
.90074 .47585 .90728 .48503 .92418 .48003 .9177 .47077 Mtetra
.655 .751 .92 r
.9177 .47077 .92418 .48003 .94118 .47509 .93477 .46573 Mtetra
.655 .75 .92 r
.32622 .63593 .33493 .64356 .34879 .63943 .34012 .63182 Mtetra
.654 .752 .921 r
.34012 .63182 .34879 .63943 .36271 .63535 .35409 .6277 Mtetra
.655 .752 .921 r
.35409 .6277 .36271 .63535 .37671 .63125 .36814 .62353 Mtetra
.658 .752 .919 r
.36814 .62353 .37671 .63125 .39079 .62706 .38226 .61924 Mtetra
.657 .75 .919 r
.38226 .61924 .39079 .62706 .40494 .62278 .39646 .61496 Mtetra
.655 .751 .92 r
.39646 .61496 .40494 .62278 .41916 .61855 .41073 .61075 Mtetra
.654 .752 .922 r
.41073 .61075 .41916 .61855 .43346 .61436 .42507 .60654 Mtetra
.655 .753 .922 r
.42507 .60654 .43346 .61436 .44783 .61017 .4395 .60227 Mtetra
.658 .753 .92 r
.4395 .60227 .44783 .61017 .46229 .60592 .454 .59785 Mtetra
.658 .75 .917 r
.454 .59785 .46229 .60592 .47682 .60152 .46858 .59342 Mtetra
.656 .749 .919 r
.46858 .59342 .47682 .60152 .49143 .5971 .48324 .58905 Mtetra
.654 .751 .921 r
.48324 .58905 .49143 .5971 .50611 .59275 .49797 .58471 Mtetra
.653 .752 .923 r
.49797 .58471 .50611 .59275 .52087 .5884 .51279 .5804 Mtetra
.654 .754 .924 r
.51279 .5804 .52087 .5884 .53572 .58407 .52769 .57602 Mtetra
.656 .755 .923 r
.52769 .57602 .53572 .58407 .55064 .57971 .54266 .57152 Mtetra
.658 .753 .92 r
.54266 .57152 .55064 .57971 .56565 .57532 .55772 .56695 Mtetra
.658 .75 .918 r
.55772 .56695 .56565 .57532 .58074 .57087 .57287 .56237 Mtetra
.657 .747 .916 r
.57287 .56237 .58074 .57087 .59591 .56636 .58809 .55778 Mtetra
.657 .746 .916 r
.58809 .55778 .59591 .56636 .61116 .56183 .6034 .55319 Mtetra
.656 .746 .916 r
.6034 .55319 .61116 .56183 .6265 .55728 .61879 .5486 Mtetra
.61879 .5486 .6265 .55728 .64192 .55272 .63427 .544 Mtetra
.655 .746 .917 r
.63427 .544 .64192 .55272 .65743 .54814 .64984 .5394 Mtetra
.654 .746 .917 r
.64984 .5394 .65743 .54814 .67302 .54349 .66549 .5348 Mtetra
.654 .749 .919 r
.66549 .5348 .67302 .54349 .6887 .53879 .68123 .53018 Mtetra
.655 .752 .921 r
.68123 .53018 .6887 .53879 .70446 .53404 .69706 .52549 Mtetra
.657 .756 .922 r
.69706 .52549 .70446 .53404 .72031 .52927 .71297 .52067 Mtetra
.658 .756 .922 r
.71297 .52067 .72031 .52927 .73625 .52452 .72897 .51579 Mtetra
.657 .754 .921 r
.72897 .51579 .73625 .52452 .75228 .51977 .74506 .51093 Mtetra
.656 .752 .92 r
.74506 .51093 .75228 .51977 .76841 .51508 .76125 .50609 Mtetra
.654 .748 .919 r
.76125 .50609 .76841 .51508 .78463 .51036 .77753 .50131 Mtetra
.653 .748 .919 r
.77753 .50131 .78463 .51036 .80094 .5055 .79391 .49653 Mtetra
.657 .753 .921 r
.79391 .49653 .80094 .5055 .81733 .50056 .81037 .49158 Mtetra
.658 .754 .921 r
.81037 .49158 .81733 .50056 .83382 .49562 .82693 .48656 Mtetra
.657 .753 .921 r
.82693 .48656 .83382 .49562 .8504 .49072 .84357 .48155 Mtetra
.655 .75 .92 r
.84357 .48155 .8504 .49072 .86709 .48586 .86033 .47659 Mtetra
.654 .749 .92 r
.86033 .47659 .86709 .48586 .88387 .4809 .87718 .47165 Mtetra
.656 .752 .92 r
.87718 .47165 .88387 .4809 .90074 .47585 .89413 .46657 Mtetra
.657 .753 .92 r
.89413 .46657 .90074 .47585 .9177 .47077 .91116 .46143 Mtetra
.657 .753 .921 r
.91116 .46143 .9177 .47077 .93477 .46573 .9283 .45628 Mtetra
.654 .751 .921 r
.31743 .62827 .32622 .63593 .34012 .63182 .33137 .62414 Mtetra
.655 .752 .921 r
.33137 .62414 .34012 .63182 .35409 .6277 .34539 .61997 Mtetra
.657 .752 .92 r
.34539 .61997 .35409 .6277 .36814 .62353 .35948 .61569 Mtetra
.658 .751 .918 r
.35948 .61569 .36814 .62353 .38226 .61924 .37365 .61136 Mtetra
.655 .75 .92 r
.37365 .61136 .38226 .61924 .39646 .61496 .38789 .60711 Mtetra
.654 .752 .922 r
.38789 .60711 .39646 .61496 .41073 .61075 .40221 .60288 Mtetra
.40221 .60288 .41073 .61075 .42507 .60654 .4166 .59862 Mtetra
.658 .753 .92 r
.4166 .59862 .42507 .60654 .4395 .60227 .43108 .59418 Mtetra
.658 .75 .918 r
.43108 .59418 .4395 .60227 .454 .59785 .44563 .58972 Mtetra
.656 .749 .919 r
.44563 .58972 .454 .59785 .46858 .59342 .46026 .58534 Mtetra
.653 .751 .921 r
.46026 .58534 .46858 .59342 .48324 .58905 .47497 .581 Mtetra
.652 .753 .923 r
.47497 .581 .48324 .58905 .49797 .58471 .48975 .57668 Mtetra
.655 .755 .923 r
.48975 .57668 .49797 .58471 .51279 .5804 .50462 .57222 Mtetra
.659 .754 .92 r
.50462 .57222 .51279 .5804 .52769 .57602 .51957 .56762 Mtetra
.659 .749 .917 r
.51957 .56762 .52769 .57602 .54266 .57152 .5346 .563 Mtetra
.658 .747 .916 r
.5346 .563 .54266 .57152 .55772 .56695 .54972 .55841 Mtetra
.657 .747 .917 r
.54972 .55841 .55772 .56695 .57287 .56237 .56491 .55383 Mtetra
.656 .748 .918 r
.56491 .55383 .57287 .56237 .58809 .55778 .58019 .54924 Mtetra
.656 .749 .919 r
.58019 .54924 .58809 .55778 .6034 .55319 .59556 .54462 Mtetra
.656 .75 .919 r
.59556 .54462 .6034 .55319 .61879 .5486 .61101 .53998 Mtetra
.61101 .53998 .61879 .5486 .63427 .544 .62654 .53531 Mtetra
.656 .749 .919 r
.62654 .53531 .63427 .544 .64984 .5394 .64217 .53062 Mtetra
.656 .748 .918 r
.64217 .53062 .64984 .5394 .66549 .5348 .65788 .52592 Mtetra
.655 .746 .917 r
.65788 .52592 .66549 .5348 .68123 .53018 .67368 .52123 Mtetra
.653 .745 .917 r
.67368 .52123 .68123 .53018 .69706 .52549 .68957 .51657 Mtetra
.653 .747 .919 r
.68957 .51657 .69706 .52549 .71297 .52067 .70555 .51189 Mtetra
.656 .753 .921 r
.70555 .51189 .71297 .52067 .72897 .51579 .72162 .50705 Mtetra
.658 .756 .922 r
.72162 .50705 .72897 .51579 .74506 .51093 .73777 .50208 Mtetra
.658 .754 .921 r
.73777 .50208 .74506 .51093 .76125 .50609 .75402 .49711 Mtetra
.656 .752 .92 r
.75402 .49711 .76125 .50609 .77753 .50131 .77036 .49219 Mtetra
.654 .748 .919 r
.77036 .49219 .77753 .50131 .79391 .49653 .7868 .48735 Mtetra
.7868 .48735 .79391 .49653 .81037 .49158 .80334 .48248 Mtetra
.657 .753 .921 r
.80334 .48248 .81037 .49158 .82693 .48656 .81996 .47743 Mtetra
.658 .754 .921 r
.81996 .47743 .82693 .48656 .84357 .48155 .83668 .47233 Mtetra
.657 .752 .921 r
.83668 .47233 .84357 .48155 .86033 .47659 .85349 .46724 Mtetra
.654 .749 .92 r
.85349 .46724 .86033 .47659 .87718 .47165 .87042 .46225 Mtetra
.655 .75 .92 r
.87042 .46225 .87718 .47165 .89413 .46657 .88744 .45718 Mtetra
.657 .752 .92 r
.88744 .45718 .89413 .46657 .91116 .46143 .90455 .452 Mtetra
.657 .753 .92 r
.90455 .452 .91116 .46143 .9283 .45628 .92176 .44677 Mtetra
.654 .752 .921 r
.30855 .62054 .31743 .62827 .33137 .62414 .32254 .61637 Mtetra
.655 .752 .921 r
.32254 .61637 .33137 .62414 .34539 .61997 .3366 .61213 Mtetra
.658 .752 .919 r
.3366 .61213 .34539 .61997 .35948 .61569 .35074 .60777 Mtetra
.656 .75 .919 r
.35074 .60777 .35948 .61569 .37365 .61136 .36496 .60345 Mtetra
.654 .751 .921 r
.36496 .60345 .37365 .61136 .38789 .60711 .37924 .5992 Mtetra
.654 .752 .922 r
.37924 .5992 .38789 .60711 .40221 .60288 .39361 .59493 Mtetra
.657 .753 .921 r
.39361 .59493 .40221 .60288 .4166 .59862 .40805 .59051 Mtetra
.659 .751 .918 r
.40805 .59051 .4166 .59862 .43108 .59418 .42258 .58601 Mtetra
.656 .749 .919 r
.42258 .58601 .43108 .59418 .44563 .58972 .43718 .5816 Mtetra
.653 .751 .921 r
.43718 .5816 .44563 .58972 .46026 .58534 .45185 .57725 Mtetra
.652 .752 .923 r
.45185 .57725 .46026 .58534 .47497 .581 .46661 .57291 Mtetra
.656 .755 .922 r
.46661 .57291 .47497 .581 .48975 .57668 .48145 .56839 Mtetra
.66 .752 .918 r
.48145 .56839 .48975 .57668 .50462 .57222 .49637 .56374 Mtetra
.659 .748 .916 r
.49637 .56374 .50462 .57222 .51957 .56762 .51138 .55911 Mtetra
.657 .748 .917 r
.51138 .55911 .51957 .56762 .5346 .563 .52646 .55453 Mtetra
.655 .749 .919 r
.52646 .55453 .5346 .563 .54972 .55841 .54163 .54997 Mtetra
.653 .751 .921 r
.54163 .54997 .54972 .55841 .56491 .55383 .55688 .54546 Mtetra
.653 .754 .923 r
.55688 .54546 .56491 .55383 .58019 .54924 .57222 .54091 Mtetra
.654 .756 .925 r
.57222 .54091 .58019 .54924 .59556 .54462 .58764 .5363 Mtetra
.655 .758 .925 r
.58764 .5363 .59556 .54462 .61101 .53998 .60315 .53161 Mtetra
.657 .758 .925 r
.60315 .53161 .61101 .53998 .62654 .53531 .61875 .52685 Mtetra
.658 .757 .923 r
.61875 .52685 .62654 .53531 .64217 .53062 .63443 .52202 Mtetra
.658 .755 .922 r
.63443 .52202 .64217 .53062 .65788 .52592 .65019 .51715 Mtetra
.657 .752 .92 r
.65019 .51715 .65788 .52592 .67368 .52123 .66605 .51233 Mtetra
.655 .749 .919 r
.66605 .51233 .67368 .52123 .68957 .51657 .682 .50753 Mtetra
.654 .747 .918 r
.682 .50753 .68957 .51657 .70555 .51189 .69804 .50277 Mtetra
.652 .746 .918 r
.69804 .50277 .70555 .51189 .72162 .50705 .71418 .49805 Mtetra
.655 .751 .92 r
.71418 .49805 .72162 .50705 .73777 .50208 .73041 .49317 Mtetra
.659 .756 .922 r
.73041 .49317 .73777 .50208 .75402 .49711 .74671 .48811 Mtetra
.658 .754 .921 r
.74671 .48811 .75402 .49711 .77036 .49219 .76312 .48307 Mtetra
.656 .752 .92 r
.76312 .48307 .77036 .49219 .7868 .48735 .77962 .47807 Mtetra
.653 .748 .92 r
.77962 .47807 .7868 .48735 .80334 .48248 .79623 .47317 Mtetra
.655 .749 .92 r
.79623 .47317 .80334 .48248 .81996 .47743 .81293 .46818 Mtetra
.658 .753 .921 r
.81293 .46818 .81996 .47743 .83668 .47233 .82971 .46303 Mtetra
.657 .753 .921 r
.82971 .46303 .83668 .47233 .85349 .46724 .84659 .45785 Mtetra
.655 .752 .921 r
.84659 .45785 .85349 .46724 .87042 .46225 .86358 .45274 Mtetra
.654 .749 .92 r
.86358 .45274 .87042 .46225 .88744 .45718 .88068 .44767 Mtetra
.656 .751 .92 r
.88068 .44767 .88744 .45718 .90455 .452 .89787 .44246 Mtetra
.657 .753 .92 r
.89787 .44246 .90455 .452 .92176 .44677 .91515 .43717 Mtetra
.654 .752 .921 r
.29958 .61275 .30855 .62054 .32254 .61637 .31362 .60852 Mtetra
.657 .752 .92 r
.31362 .60852 .32254 .61637 .3366 .61213 .32773 .60419 Mtetra
.658 .751 .919 r
.32773 .60419 .3366 .61213 .35074 .60777 .34192 .59979 Mtetra
.655 .75 .92 r
.34192 .59979 .35074 .60777 .36496 .60345 .35617 .59549 Mtetra
.653 .751 .922 r
.35617 .59549 .36496 .60345 .37924 .5992 .37051 .59121 Mtetra
.655 .752 .921 r
.37051 .59121 .37924 .5992 .39361 .59493 .38492 .58685 Mtetra
.659 .752 .919 r
.38492 .58685 .39361 .59493 .40805 .59051 .39942 .58231 Mtetra
.657 .75 .918 r
.39942 .58231 .40805 .59051 .42258 .58601 .41399 .57784 Mtetra
.654 .751 .921 r
.41399 .57784 .42258 .58601 .43718 .5816 .42864 .57345 Mtetra
.652 .752 .923 r
.42864 .57345 .43718 .5816 .45185 .57725 .44336 .56911 Mtetra
.656 .754 .922 r
.44336 .56911 .45185 .57725 .46661 .57291 .45817 .56458 Mtetra
.66 .752 .918 r
.45817 .56458 .46661 .57291 .48145 .56839 .47307 .55988 Mtetra
.658 .748 .916 r
.47307 .55988 .48145 .56839 .49637 .56374 .48804 .55524 Mtetra
.656 .749 .918 r
.48804 .55524 .49637 .56374 .51138 .55911 .5031 .55067 Mtetra
.652 .75 .922 r
.5031 .55067 .51138 .55911 .52646 .55453 .51824 .54621 Mtetra
.651 .754 .925 r
.51824 .54621 .52646 .55453 .54163 .54997 .53346 .54176 Mtetra
.652 .758 .927 r
.53346 .54176 .54163 .54997 .55688 .54546 .54877 .53722 Mtetra
.656 .76 .926 r
.54877 .53722 .55688 .54546 .57222 .54091 .56416 .5325 Mtetra
.657 .757 .924 r
.56416 .5325 .57222 .54091 .58764 .5363 .57964 .52774 Mtetra
.656 .754 .922 r
.57964 .52774 .58764 .5363 .60315 .53161 .59521 .523 Mtetra
.654 .754 .923 r
.59521 .523 .60315 .53161 .61875 .52685 .61087 .51829 Mtetra
.655 .756 .925 r
.61087 .51829 .61875 .52685 .63443 .52202 .62661 .51353 Mtetra
.658 .761 .925 r
.62661 .51353 .63443 .52202 .65019 .51715 .64244 .5086 Mtetra
.66 .761 .925 r
.64244 .5086 .65019 .51715 .66605 .51233 .65835 .50358 Mtetra
.66 .757 .922 r
.65835 .50358 .66605 .51233 .682 .50753 .67436 .49855 Mtetra
.656 .751 .92 r
.67436 .49855 .682 .50753 .69804 .50277 .69046 .49364 Mtetra
.654 .748 .919 r
.69046 .49364 .69804 .50277 .71418 .49805 .70665 .4888 Mtetra
.652 .746 .919 r
.70665 .4888 .71418 .49805 .73041 .49317 .72295 .48402 Mtetra
.655 .75 .92 r
.72295 .48402 .73041 .49317 .74671 .48811 .73933 .47905 Mtetra
.659 .756 .921 r
.73933 .47905 .74671 .48811 .76312 .48307 .7558 .47389 Mtetra
.657 .753 .921 r
.7558 .47389 .76312 .48307 .77962 .47807 .77236 .46878 Mtetra
.655 .751 .921 r
.77236 .46878 .77962 .47807 .79623 .47317 .78903 .46375 Mtetra
.653 .748 .92 r
.78903 .46375 .79623 .47317 .81293 .46818 .80581 .45878 Mtetra
.656 .752 .92 r
.80581 .45878 .81293 .46818 .82971 .46303 .82267 .45363 Mtetra
.658 .753 .921 r
.82267 .45363 .82971 .46303 .84659 .45785 .83962 .44838 Mtetra
.657 .753 .92 r
.83962 .44838 .84659 .45785 .86358 .45274 .85667 .44314 Mtetra
.654 .75 .92 r
.85667 .44314 .86358 .45274 .88068 .44767 .87384 .43801 Mtetra
.655 .75 .92 r
.87384 .43801 .88068 .44767 .89787 .44246 .89111 .4328 Mtetra
.657 .752 .92 r
.89111 .4328 .89787 .44246 .91515 .43717 .90847 .42747 Mtetra
.655 .752 .921 r
.29053 .60486 .29958 .61275 .31362 .60852 .30461 .60058 Mtetra
.658 .752 .919 r
.30461 .60058 .31362 .60852 .32773 .60419 .31877 .59616 Mtetra
.657 .751 .919 r
.31877 .59616 .32773 .60419 .34192 .59979 .333 .59177 Mtetra
.654 .751 .921 r
.333 .59177 .34192 .59979 .35617 .59549 .3473 .58745 Mtetra
.653 .752 .922 r
.3473 .58745 .35617 .59549 .37051 .59121 .36168 .58312 Mtetra
.658 .753 .92 r
.36168 .58312 .37051 .59121 .38492 .58685 .37615 .57862 Mtetra
.659 .751 .918 r
.37615 .57862 .38492 .58685 .39942 .58231 .39069 .57406 Mtetra
.655 .75 .92 r
.39069 .57406 .39942 .58231 .41399 .57784 .40531 .56962 Mtetra
.652 .751 .922 r
.40531 .56962 .41399 .57784 .42864 .57345 .42001 .56525 Mtetra
.654 .753 .923 r
.42001 .56525 .42864 .57345 .44336 .56911 .43479 .56078 Mtetra
.661 .753 .919 r
.43479 .56078 .44336 .56911 .45817 .56458 .44966 .55605 Mtetra
.659 .749 .916 r
.44966 .55605 .45817 .56458 .47307 .55988 .4646 .55136 Mtetra
.655 .749 .919 r
.4646 .55136 .47307 .55988 .48804 .55524 .47963 .54678 Mtetra
.649 .75 .923 r
.47963 .54678 .48804 .55524 .5031 .55067 .49473 .54239 Mtetra
.65 .756 .927 r
.49473 .54239 .5031 .55067 .51824 .54621 .50993 .53793 Mtetra
.659 .76 .924 r
.50993 .53793 .51824 .54621 .53346 .54176 .52521 .53311 Mtetra
.66 .752 .918 r
.52521 .53311 .53346 .54176 .54877 .53722 .54057 .52825 Mtetra
.658 .745 .914 r
.54057 .52825 .54877 .53722 .56416 .5325 .55602 .52346 Mtetra
.656 .744 .914 r
.55602 .52346 .56416 .5325 .57964 .52774 .57155 .51869 Mtetra
.656 .745 .915 r
.57155 .51869 .57964 .52774 .59521 .523 .58718 .51391 Mtetra
.58718 .51391 .59521 .523 .61087 .51829 .60289 .5091 Mtetra
.655 .743 .915 r
.60289 .5091 .61087 .51829 .62661 .51353 .61869 .50432 Mtetra
.652 .743 .916 r
.61869 .50432 .62661 .51353 .64244 .5086 .63459 .49961 Mtetra
.652 .749 .921 r
.63459 .49961 .64244 .5086 .65835 .50358 .65058 .49486 Mtetra
.661 .76 .924 r
.65058 .49486 .65835 .50358 .67436 .49855 .66664 .48973 Mtetra
.661 .759 .923 r
.66664 .48973 .67436 .49855 .69046 .49364 .6828 .48454 Mtetra
.656 .752 .92 r
.6828 .48454 .69046 .49364 .70665 .4888 .69905 .47954 Mtetra
.653 .748 .92 r
.69905 .47954 .70665 .4888 .72295 .48402 .71541 .47464 Mtetra
.651 .746 .919 r
.71541 .47464 .72295 .48402 .73933 .47905 .73187 .46979 Mtetra
.657 .752 .92 r
.73187 .46979 .73933 .47905 .7558 .47389 .74841 .46467 Mtetra
.659 .755 .921 r
.74841 .46467 .7558 .47389 .77236 .46878 .76503 .45943 Mtetra
.657 .752 .921 r
.76503 .45943 .77236 .46878 .78903 .46375 .78177 .45427 Mtetra
.653 .749 .92 r
.78177 .45427 .78903 .46375 .80581 .45878 .79861 .44922 Mtetra
.654 .749 .92 r
.79861 .44922 .80581 .45878 .82267 .45363 .81555 .44411 Mtetra
.658 .753 .92 r
.81555 .44411 .82267 .45363 .83962 .44838 .83257 .43881 Mtetra
.657 .753 .92 r
.83257 .43881 .83962 .44838 .85667 .44314 .84969 .43349 Mtetra
.655 .751 .921 r
.84969 .43349 .85667 .44314 .87384 .43801 .86693 .42825 Mtetra
.654 .75 .92 r
.86693 .42825 .87384 .43801 .89111 .4328 .88427 .42303 Mtetra
.656 .752 .92 r
.88427 .42303 .89111 .4328 .90847 .42747 .90171 .41766 Mtetra
.28139 .5969 .29053 .60486 .30461 .60058 .29551 .59254 Mtetra
.659 .752 .919 r
.29551 .59254 .30461 .60058 .31877 .59616 .30972 .58806 Mtetra
.655 .751 .92 r
.30972 .58806 .31877 .59616 .333 .59177 .32399 .58368 Mtetra
.653 .751 .922 r
.32399 .58368 .333 .59177 .3473 .58745 .33834 .57934 Mtetra
.655 .752 .921 r
.33834 .57934 .3473 .58745 .36168 .58312 .35277 .57493 Mtetra
.66 .752 .919 r
.35277 .57493 .36168 .58312 .37615 .57862 .36729 .57032 Mtetra
.657 .75 .919 r
.36729 .57032 .37615 .57862 .39069 .57406 .38188 .56578 Mtetra
.653 .751 .921 r
.38188 .56578 .39069 .57406 .40531 .56962 .39655 .56135 Mtetra
.652 .752 .923 r
.39655 .56135 .40531 .56962 .42001 .56525 .41129 .55695 Mtetra
.659 .754 .92 r
.41129 .55695 .42001 .56525 .43479 .56078 .42613 .55224 Mtetra
.66 .75 .917 r
.42613 .55224 .43479 .56078 .44966 .55605 .44105 .54748 Mtetra
.656 .749 .918 r
.44105 .54748 .44966 .55605 .4646 .55136 .45604 .54286 Mtetra
.649 .75 .923 r
.45604 .54286 .4646 .55136 .47963 .54678 .47112 .53845 Mtetra
.649 .755 .927 r
.47112 .53845 .47963 .54678 .49473 .54239 .48628 .53399 Mtetra
.663 .759 .921 r
.48628 .53399 .49473 .54239 .50993 .53793 .50153 .52902 Mtetra
.659 .746 .915 r
.50153 .52902 .50993 .53793 .52521 .53311 .51687 .52418 Mtetra
.656 .746 .916 r
.51687 .52418 .52521 .53311 .54057 .52825 .53229 .51943 Mtetra
.648 .747 .922 r
.53229 .51943 .54057 .52825 .55602 .52346 .54779 .51496 Mtetra
.647 .756 .929 r
.54779 .51496 .55602 .52346 .57155 .51869 .56339 .51046 Mtetra
.655 .766 .932 r
.56339 .51046 .57155 .51869 .58718 .51391 .57908 .50562 Mtetra
.663 .769 .928 r
.57908 .50562 .58718 .51391 .60289 .5091 .59485 .50045 Mtetra
.663 .761 .923 r
.59485 .50045 .60289 .5091 .61869 .50432 .6107 .49525 Mtetra
.656 .75 .919 r
.6107 .49525 .61869 .50432 .63459 .49961 .62665 .49033 Mtetra
.653 .745 .917 r
.62665 .49033 .63459 .49961 .65058 .49486 .6427 .48549 Mtetra
.649 .743 .918 r
.6427 .48549 .65058 .49486 .66664 .48973 .65885 .48079 Mtetra
.661 .759 .922 r
.65885 .48079 .66664 .48973 .6828 .48454 .67507 .47556 Mtetra
.662 .759 .922 r
.67507 .47556 .6828 .48454 .69905 .47954 .69138 .47028 Mtetra
.656 .752 .92 r
.69138 .47028 .69905 .47954 .71541 .47464 .70779 .46522 Mtetra
.652 .748 .92 r
.70779 .46522 .71541 .47464 .73187 .46979 .72432 .46029 Mtetra
.653 .747 .919 r
.72432 .46029 .73187 .46979 .74841 .46467 .74093 .45531 Mtetra
.659 .754 .92 r
.74093 .45531 .74841 .46467 .76503 .45943 .75763 .45001 Mtetra
.658 .754 .921 r
.75763 .45001 .76503 .45943 .78177 .45427 .77442 .44473 Mtetra
.655 .751 .921 r
.77442 .44473 .78177 .45427 .79861 .44922 .79133 .43955 Mtetra
.652 .749 .92 r
.79133 .43955 .79861 .44922 .81555 .44411 .80834 .43445 Mtetra
.657 .752 .92 r
.80834 .43445 .81555 .44411 .83257 .43881 .82544 .42913 Mtetra
.658 .753 .92 r
.82544 .42913 .83257 .43881 .84969 .43349 .84264 .42374 Mtetra
.656 .752 .92 r
.84264 .42374 .84969 .43349 .86693 .42825 .85994 .41839 Mtetra
.653 .75 .92 r
.85994 .41839 .86693 .42825 .88427 .42303 .87736 .41312 Mtetra
.656 .751 .92 r
.87736 .41312 .88427 .42303 .90171 .41766 .89488 .40773 Mtetra
.657 .752 .92 r
.27215 .58885 .28139 .5969 .29551 .59254 .28632 .58441 Mtetra
.658 .751 .919 r
.28632 .58441 .29551 .59254 .30972 .58806 .30058 .5799 Mtetra
.654 .751 .921 r
.30058 .5799 .30972 .58806 .32399 .58368 .3149 .57551 Mtetra
.653 .751 .922 r
.3149 .57551 .32399 .58368 .33834 .57934 .32929 .57113 Mtetra
.657 .752 .92 r
.32929 .57113 .33834 .57934 .35277 .57493 .34377 .5666 Mtetra
.659 .751 .918 r
.34377 .5666 .35277 .57493 .36729 .57032 .35834 .56195 Mtetra
.655 .75 .92 r
.35834 .56195 .36729 .57032 .38188 .56578 .37298 .55743 Mtetra
.652 .751 .922 r
.37298 .55743 .38188 .56578 .39655 .56135 .38769 .55301 Mtetra
.655 .753 .922 r
.38769 .55301 .39655 .56135 .41129 .55695 .40249 .54845 Mtetra
.661 .752 .917 r
.40249 .54845 .41129 .55695 .42613 .55224 .41738 .54362 Mtetra
.658 .749 .918 r
.41738 .54362 .42613 .55224 .44105 .54748 .43235 .53891 Mtetra
.651 .75 .922 r
.43235 .53891 .44105 .54748 .45604 .54286 .4474 .5344 Mtetra
.647 .753 .926 r
.4474 .5344 .45604 .54286 .47112 .53845 .46252 .53 Mtetra
.662 .758 .921 r
.46252 .53 .47112 .53845 .48628 .53399 .47775 .52502 Mtetra
.66 .746 .914 r
.47775 .52502 .48628 .53399 .50153 .52902 .49305 .52012 Mtetra
.647 .745 .921 r
.49305 .52012 .50153 .52902 .51687 .52418 .50844 .51569 Mtetra
.613 .745 .939 r
.50844 .51569 .51687 .52418 .53229 .51943 .52392 .51232 Mtetra
.57 .767 .972 r
.52392 .51232 .53229 .51943 .54779 .51496 .5395 .50974 Mtetra
.567 .822 .993 r
.5395 .50974 .54779 .51496 .56339 .51046 .55518 .5064 Mtetra
.609 .87 .991 r
.55518 .5064 .56339 .51046 .57908 .50562 .57095 .50152 Mtetra
.67 .888 .977 r
.57095 .50152 .57908 .50562 .59485 .50045 .58678 .49509 Mtetra
.707 .863 .956 r
.58678 .49509 .59485 .50045 .6107 .49525 .60267 .48789 Mtetra
.691 .806 .936 r
.60267 .48789 .6107 .49525 .62665 .49033 .61865 .48148 Mtetra
.664 .762 .923 r
.61865 .48148 .62665 .49033 .6427 .48549 .63474 .47613 Mtetra
.652 .747 .919 r
.63474 .47613 .6427 .48549 .65885 .48079 .65095 .47126 Mtetra
.65 .743 .918 r
.65095 .47126 .65885 .48079 .67507 .47556 .66725 .46645 Mtetra
.663 .759 .921 r
.66725 .46645 .67507 .47556 .69138 .47028 .68363 .46107 Mtetra
.66 .757 .922 r
.68363 .46107 .69138 .47028 .70779 .46522 .7001 .45578 Mtetra
.654 .75 .921 r
.7001 .45578 .70779 .46522 .72432 .46029 .71668 .4507 Mtetra
.651 .747 .92 r
.71668 .4507 .72432 .46029 .74093 .45531 .73337 .44574 Mtetra
.657 .751 .919 r
.73337 .44574 .74093 .45531 .75763 .45001 .75014 .44049 Mtetra
.659 .755 .92 r
.75014 .44049 .75763 .45001 .77442 .44473 .767 .4351 Mtetra
.656 .752 .92 r
.767 .4351 .77442 .44473 .79133 .43955 .78397 .42981 Mtetra
.652 .749 .921 r
.78397 .42981 .79133 .43955 .80834 .43445 .80106 .42465 Mtetra
.655 .75 .92 r
.80106 .42465 .80834 .43445 .82544 .42913 .81824 .41934 Mtetra
.658 .753 .92 r
.81824 .41934 .82544 .42913 .84264 .42374 .83551 .41389 Mtetra
.657 .752 .92 r
.83551 .41389 .84264 .42374 .85994 .41839 .85288 .40844 Mtetra
.654 .75 .921 r
.85288 .40844 .85994 .41839 .87736 .41312 .87037 .4031 Mtetra
.655 .75 .92 r
.87037 .4031 .87736 .41312 .89488 .40773 .88797 .39768 Mtetra
.658 .752 .92 r
.26282 .58071 .27215 .58885 .28632 .58441 .27705 .5762 Mtetra
.657 .751 .919 r
.27705 .5762 .28632 .58441 .30058 .5799 .29134 .57168 Mtetra
.654 .751 .921 r
.29134 .57168 .30058 .5799 .3149 .57551 .30571 .56726 Mtetra
.653 .751 .922 r
.30571 .56726 .3149 .57551 .32929 .57113 .32015 .56283 Mtetra
.658 .752 .92 r
.32015 .56283 .32929 .57113 .34377 .5666 .33469 .5582 Mtetra
.658 .751 .918 r
.33469 .5582 .34377 .5666 .35834 .56195 .3493 .55354 Mtetra
.654 .751 .921 r
.3493 .55354 .35834 .56195 .37298 .55743 .36399 .549 Mtetra
.651 .751 .923 r
.36399 .549 .37298 .55743 .38769 .55301 .37875 .54456 Mtetra
.658 .753 .92 r
.37875 .54456 .38769 .55301 .40249 .54845 .3936 .53982 Mtetra
.661 .751 .917 r
.3936 .53982 .40249 .54845 .41738 .54362 .40855 .53497 Mtetra
.656 .75 .919 r
.40855 .53497 .41738 .54362 .43235 .53891 .42356 .53029 Mtetra
.647 .749 .924 r
.42356 .53029 .43235 .53891 .4474 .5344 .43866 .52589 Mtetra
.656 .756 .923 r
.43866 .52589 .4474 .5344 .46252 .53 .45385 .52112 Mtetra
.662 .75 .916 r
.45385 .52112 .46252 .53 .47775 .52502 .46912 .51612 Mtetra
.648 .746 .921 r
.46912 .51612 .47775 .52502 .49305 .52012 .48448 .51163 Mtetra
.578 .733 .949 r
.48448 .51163 .49305 .52012 .50844 .51569 .49991 .50924 Mtetra
.44 .733 .989 r
.49991 .50924 .50844 .51569 .52392 .51232 .51544 .50896 Mtetra
.267 .727 .952 r
.51544 .50896 .52392 .51232 .5395 .50974 .5311 .50893 Mtetra
.205 .727 .852 r
.5311 .50893 .5395 .50974 .55518 .5064 .54689 .50738 Mtetra
.341 .821 .819 r
.54689 .50738 .55518 .5064 .57095 .50152 .56277 .50246 Mtetra
.574 .941 .876 r
.56277 .50246 .57095 .50152 .58678 .49509 .57868 .49417 Mtetra
.724 .971 .931 r
.57868 .49417 .58678 .49509 .60267 .48789 .59462 .48432 Mtetra
.758 .922 .944 r
.59462 .48432 .60267 .48789 .61865 .48148 .61061 .47469 Mtetra
.715 .831 .936 r
.61061 .47469 .61865 .48148 .63474 .47613 .62672 .46718 Mtetra
.663 .762 .924 r
.62672 .46718 .63474 .47613 .65095 .47126 .64297 .46178 Mtetra
.65 .747 .92 r
.64297 .46178 .65095 .47126 .66725 .46645 .65934 .4569 Mtetra
.655 .748 .918 r
.65934 .4569 .66725 .46645 .68363 .46107 .67579 .45178 Mtetra
.664 .759 .921 r
.67579 .45178 .68363 .46107 .7001 .45578 .69232 .44628 Mtetra
.656 .752 .921 r
.69232 .44628 .7001 .45578 .71668 .4507 .70897 .44107 Mtetra
.651 .748 .921 r
.70897 .44107 .71668 .4507 .73337 .44574 .72572 .43602 Mtetra
.654 .749 .92 r
.72572 .43602 .73337 .44574 .75014 .44049 .74257 .43085 Mtetra
.66 .754 .92 r
.74257 .43085 .75014 .44049 .767 .4351 .7595 .42538 Mtetra
.657 .753 .92 r
.7595 .42538 .767 .4351 .78397 .42981 .77654 .42 Mtetra
.653 .75 .921 r
.77654 .42 .78397 .42981 .80106 .42465 .79369 .41474 Mtetra
.654 .75 .92 r
.79369 .41474 .80106 .42465 .81824 .41934 .81095 .40943 Mtetra
.658 .753 .92 r
.81095 .40943 .81824 .41934 .83551 .41389 .82829 .40392 Mtetra
.657 .753 .92 r
.82829 .40392 .83551 .41389 .85288 .40844 .84574 .3984 Mtetra
.654 .751 .921 r
.84574 .3984 .85288 .40844 .87037 .4031 .86331 .39296 Mtetra
.654 .75 .92 r
.86331 .39296 .87037 .4031 .88797 .39768 .88098 .38751 Mtetra
.658 .752 .919 r
.2534 .57249 .26282 .58071 .27705 .5762 .26767 .56792 Mtetra
.657 .751 .92 r
.26767 .56792 .27705 .5762 .29134 .57168 .28201 .56338 Mtetra
.654 .751 .921 r
.28201 .56338 .29134 .57168 .30571 .56726 .29643 .55892 Mtetra
.29643 .55892 .30571 .56726 .32015 .56283 .31092 .55443 Mtetra
.659 .752 .919 r
.31092 .55443 .32015 .56283 .33469 .5582 .3255 .54972 Mtetra
.657 .751 .919 r
.3255 .54972 .33469 .5582 .3493 .55354 .34016 .54505 Mtetra
.653 .751 .921 r
.34016 .54505 .3493 .55354 .36399 .549 .3549 .54051 Mtetra
.652 .751 .923 r
.3549 .54051 .36399 .549 .37875 .54456 .36971 .53599 Mtetra
.661 .753 .919 r
.36971 .53599 .37875 .54456 .3936 .53982 .38462 .53112 Mtetra
.66 .751 .918 r
.38462 .53112 .3936 .53982 .40855 .53497 .39962 .52627 Mtetra
.652 .75 .921 r
.39962 .52627 .40855 .53497 .42356 .53029 .41468 .52165 Mtetra
.646 .751 .926 r
.41468 .52165 .42356 .53029 .43866 .52589 .42983 .51722 Mtetra
.664 .756 .919 r
.42983 .51722 .43866 .52589 .45385 .52112 .44508 .51212 Mtetra
.658 .748 .917 r
.44508 .51212 .45385 .52112 .46912 .51612 .46041 .50724 Mtetra
.604 .734 .937 r
.46041 .50724 .46912 .51612 .48448 .51163 .4758 .50413 Mtetra
.413 .691 .977 r
.4758 .50413 .48448 .51163 .49991 .50924 .49125 .50484 Mtetra
.053 .561 .88 r
.49125 .50484 .49991 .50924 .51544 .50896 .50683 .50813 Mtetra
.218 0 0 r
.50683 .50813 .51544 .50896 .5311 .50893 .52258 .51149 Mtetra
.182 0 0 r
.52258 .51149 .5311 .50893 .54689 .50738 .53848 .51154 Mtetra
0 0 0 r
.53848 .51154 .54689 .50738 .56277 .50246 .55448 .50659 Mtetra
.454 .859 .685 r
.55448 .50659 .56277 .50246 .57868 .49417 .5705 .49661 Mtetra
.727 .988 .813 r
.5705 .49661 .57868 .49417 .59462 .48432 .58651 .48328 Mtetra
.819 .977 .892 r
.58651 .48328 .59462 .48432 .61061 .47469 .60253 .46997 Mtetra
.786 .897 .922 r
.60253 .46997 .61061 .47469 .62672 .46718 .61864 .45922 Mtetra
.699 .8 .928 r
.61864 .45922 .62672 .46718 .64297 .46178 .63491 .45232 Mtetra
.654 .751 .921 r
.63491 .45232 .64297 .46178 .65934 .4569 .65134 .44722 Mtetra
.648 .745 .92 r
.65134 .44722 .65934 .4569 .67579 .45178 .66787 .44233 Mtetra
.664 .757 .919 r
.66787 .44233 .67579 .45178 .69232 .44628 .68447 .43675 Mtetra
.659 .755 .921 r
.68447 .43675 .69232 .44628 .70897 .44107 .70117 .43136 Mtetra
.652 .75 .921 r
.70117 .43136 .70897 .44107 .72572 .43602 .71799 .42621 Mtetra
.651 .748 .921 r
.71799 .42621 .72572 .43602 .74257 .43085 .73492 .42108 Mtetra
.66 .753 .92 r
.73492 .42108 .74257 .43085 .7595 .42538 .75192 .41557 Mtetra
.658 .753 .92 r
.75192 .41557 .7595 .42538 .77654 .42 .76903 .41008 Mtetra
.654 .751 .921 r
.76903 .41008 .77654 .42 .79369 .41474 .78625 .40473 Mtetra
.653 .749 .921 r
.78625 .40473 .79369 .41474 .81095 .40943 .80358 .3994 Mtetra
.658 .752 .92 r
.80358 .3994 .81095 .40943 .82829 .40392 .821 .39384 Mtetra
.658 .753 .92 r
.821 .39384 .82829 .40392 .84574 .3984 .83852 .38825 Mtetra
.655 .751 .921 r
.83852 .38825 .84574 .3984 .86331 .39296 .85616 .38273 Mtetra
.654 .75 .921 r
.85616 .38273 .86331 .39296 .88098 .38751 .87392 .37723 Mtetra
.659 .752 .919 r
.24389 .56419 .2534 .57249 .26767 .56792 .2582 .55956 Mtetra
.656 .751 .92 r
.2582 .55956 .26767 .56792 .28201 .56338 .27259 .55499 Mtetra
.653 .751 .921 r
.27259 .55499 .28201 .56338 .29643 .55892 .28705 .55049 Mtetra
.654 .751 .921 r
.28705 .55049 .29643 .55892 .31092 .55443 .30159 .54594 Mtetra
.66 .752 .919 r
.30159 .54594 .31092 .55443 .3255 .54972 .31623 .54116 Mtetra
.657 .751 .92 r
.31623 .54116 .3255 .54972 .34016 .54505 .33094 .53647 Mtetra
.652 .751 .922 r
.33094 .53647 .34016 .54505 .3549 .54051 .34572 .5319 Mtetra
.653 .751 .922 r
.34572 .5319 .3549 .54051 .36971 .53599 .36058 .5273 Mtetra
.662 .753 .918 r
.36058 .5273 .36971 .53599 .38462 .53112 .37555 .52235 Mtetra
.658 .751 .918 r
.37555 .52235 .38462 .53112 .39962 .52627 .39059 .51749 Mtetra
.65 .75 .922 r
.39059 .51749 .39962 .52627 .41468 .52165 .40571 .51292 Mtetra
.65 .752 .924 r
.40571 .51292 .41468 .52165 .42983 .51722 .42091 .50831 Mtetra
.664 .753 .916 r
.42091 .50831 .42983 .51722 .44508 .51212 .43622 .50314 Mtetra
.647 .747 .922 r
.43622 .50314 .44508 .51212 .46041 .50724 .45159 .49857 Mtetra
.53 .714 .956 r
.45159 .49857 .46041 .50724 .4758 .50413 .467 .49736 Mtetra
.205 .6 .947 r
.467 .49736 .4758 .50413 .49125 .50484 .48247 .50063 Mtetra
0 .324 .685 r
.48247 .50063 .49125 .50484 .50683 .50813 .49808 .50732 Mtetra
.369 0 0 r
.49808 .50732 .50683 .50813 .52258 .51149 .5139 .51288 Mtetra
.196 0 0 r
.5139 .51288 .52258 .51149 .53848 .51154 .5299 .51413 Mtetra
.215 .727 .682 r
.5299 .51413 .53848 .51154 .55448 .50659 .54602 .50914 Mtetra
.635 .961 .812 r
.54602 .50914 .55448 .50659 .5705 .49661 .56216 .49789 Mtetra
.83 .998 .837 r
.56216 .49789 .5705 .49661 .58651 .48328 .57827 .48226 Mtetra
.878 .965 .848 r
.57827 .48226 .58651 .48328 .60253 .46997 .59434 .46544 Mtetra
.832 .902 .889 r
.59434 .46544 .60253 .46997 .61864 .45922 .61048 .452 Mtetra
.744 .831 .918 r
.61048 .452 .61864 .45922 .63491 .45232 .62678 .44307 Mtetra
.663 .761 .923 r
.62678 .44307 .63491 .45232 .65134 .44722 .64325 .43753 Mtetra
.647 .747 .922 r
.64325 .43753 .65134 .44722 .66787 .44233 .65985 .43262 Mtetra
.661 .753 .918 r
.65985 .43262 .66787 .44233 .68447 .43675 .67652 .42711 Mtetra
.661 .756 .92 r
.67652 .42711 .68447 .43675 .70117 .43136 .69329 .42157 Mtetra
.653 .75 .921 r
.69329 .42157 .70117 .43136 .71799 .42621 .71018 .41632 Mtetra
.65 .748 .921 r
.71018 .41632 .71799 .42621 .73492 .42108 .72718 .41116 Mtetra
.659 .752 .919 r
.72718 .41116 .73492 .42108 .75192 .41557 .74425 .40563 Mtetra
.659 .753 .92 r
.74425 .40563 .75192 .41557 .76903 .41008 .76143 .40006 Mtetra
.655 .751 .921 r
.76143 .40006 .76903 .41008 .78625 .40473 .77872 .39462 Mtetra
.652 .749 .921 r
.77872 .39462 .78625 .40473 .80358 .3994 .79613 .38925 Mtetra
.657 .752 .92 r
.79613 .38925 .80358 .3994 .821 .39384 .81363 .38365 Mtetra
.658 .753 .92 r
.81363 .38365 .821 .39384 .83852 .38825 .83122 .37798 Mtetra
.655 .751 .92 r
.83122 .37798 .83852 .38825 .85616 .38273 .84894 .37238 Mtetra
.653 .75 .921 r
.84894 .37238 .85616 .38273 .87392 .37723 .86677 .36683 Mtetra
.659 .752 .919 r
.23428 .5558 .24389 .56419 .2582 .55956 .24864 .55112 Mtetra
.656 .751 .92 r
.24864 .55112 .2582 .55956 .27259 .55499 .26307 .54651 Mtetra
.653 .751 .921 r
.26307 .54651 .27259 .55499 .28705 .55049 .27758 .54197 Mtetra
.654 .751 .921 r
.27758 .54197 .28705 .55049 .30159 .54594 .29217 .53736 Mtetra
.66 .752 .919 r
.29217 .53736 .30159 .54594 .31623 .54116 .30685 .53253 Mtetra
.656 .751 .92 r
.30685 .53253 .31623 .54116 .33094 .53647 .32161 .5278 Mtetra
.652 .75 .922 r
.32161 .5278 .33094 .53647 .34572 .5319 .33644 .5232 Mtetra
.653 .751 .921 r
.33644 .5232 .34572 .5319 .36058 .5273 .35136 .51852 Mtetra
.662 .753 .918 r
.35136 .51852 .36058 .5273 .37555 .52235 .36638 .51351 Mtetra
.658 .751 .919 r
.36638 .51351 .37555 .52235 .39059 .51749 .38148 .50863 Mtetra
.649 .749 .923 r
.38148 .50863 .39059 .51749 .40571 .51292 .39664 .50404 Mtetra
.653 .752 .922 r
.39664 .50404 .40571 .51292 .42091 .50831 .4119 .49929 Mtetra
.663 .752 .916 r
.4119 .49929 .42091 .50831 .43622 .50314 .42726 .49411 Mtetra
.639 .746 .926 r
.42726 .49411 .43622 .50314 .45159 .49857 .44268 .48981 Mtetra
.477 .69 .961 r
.44268 .48981 .45159 .49857 .467 .49736 .45811 .48977 Mtetra
.11 .519 .91 r
.45811 .48977 .467 .49736 .48247 .50063 .4736 .49484 Mtetra
0 .283 .698 r
.4736 .49484 .48247 .50063 .49808 .50732 .48924 .50315 Mtetra
0 .323 .681 r
.48924 .50315 .49808 .50732 .5139 .51288 .5051 .50991 Mtetra
.056 .595 .851 r
.5051 .50991 .5139 .51288 .5299 .51413 .52118 .51188 Mtetra
.54 .894 .977 r
.52118 .51188 .5299 .51413 .54602 .50914 .53739 .50685 Mtetra
.802 .952 .916 r
.53739 .50685 .54602 .50914 .56216 .49789 .55364 .49478 Mtetra
.878 .921 .85 r
.55364 .49478 .56216 .49789 .57827 .48226 .56985 .47785 Mtetra
.888 .89 .827 r
.56985 .47785 .57827 .48226 .59434 .46544 .58601 .4593 Mtetra
.847 .863 .854 r
.58601 .4593 .59434 .46544 .61048 .452 .60221 .44394 Mtetra
.764 .817 .894 r
.60221 .44394 .61048 .452 .62678 .44307 .61855 .43372 Mtetra
.671 .764 .92 r
.61855 .43372 .62678 .44307 .64325 .43753 .63508 .42781 Mtetra
.648 .749 .923 r
.63508 .42781 .64325 .43753 .65985 .43262 .65174 .42278 Mtetra
.659 .751 .918 r
.65174 .42278 .65985 .43262 .67652 .42711 .66849 .41732 Mtetra
.662 .755 .919 r
.66849 .41732 .67652 .42711 .69329 .42157 .68533 .41167 Mtetra
.654 .751 .921 r
.68533 .41167 .69329 .42157 .71018 .41632 .70228 .40634 Mtetra
.65 .749 .922 r
.70228 .40634 .71018 .41632 .72718 .41116 .71935 .40113 Mtetra
.658 .752 .919 r
.71935 .40113 .72718 .41116 .74425 .40563 .7365 .39557 Mtetra
.659 .753 .919 r
.7365 .39557 .74425 .40563 .76143 .40006 .75375 .38992 Mtetra
.655 .751 .92 r
.75375 .38992 .76143 .40006 .77872 .39462 .77111 .3844 Mtetra
.652 .75 .921 r
.77111 .3844 .77872 .39462 .79613 .38925 .7886 .37898 Mtetra
.657 .752 .92 r
.7886 .37898 .79613 .38925 .81363 .38365 .80617 .37333 Mtetra
.658 .752 .92 r
.80617 .37333 .81363 .38365 .83122 .37798 .82384 .36759 Mtetra
.656 .751 .92 r
.82384 .36759 .83122 .37798 .84894 .37238 .84163 .36192 Mtetra
.653 .75 .921 r
.84163 .36192 .84894 .37238 .86677 .36683 .85955 .35632 Mtetra
.659 .752 .919 r
.22457 .54733 .23428 .5558 .24864 .55112 .23898 .5426 Mtetra
.656 .751 .92 r
.23898 .5426 .24864 .55112 .26307 .54651 .25346 .53794 Mtetra
.653 .751 .921 r
.25346 .53794 .26307 .54651 .27758 .54197 .26801 .53335 Mtetra
.654 .751 .921 r
.26801 .53335 .27758 .54197 .29217 .53736 .28265 .52869 Mtetra
.66 .752 .919 r
.28265 .52869 .29217 .53736 .30685 .53253 .29738 .52382 Mtetra
.656 .752 .92 r
.29738 .52382 .30685 .53253 .32161 .5278 .31219 .51904 Mtetra
.652 .75 .922 r
.31219 .51904 .32161 .5278 .33644 .5232 .32707 .51439 Mtetra
.654 .751 .921 r
.32707 .51439 .33644 .5232 .35136 .51852 .34204 .50966 Mtetra
.662 .753 .918 r
.34204 .50966 .35136 .51852 .36638 .51351 .35711 .5046 Mtetra
.658 .752 .92 r
.35711 .5046 .36638 .51351 .38148 .50863 .37226 .49966 Mtetra
.649 .749 .923 r
.37226 .49966 .38148 .50863 .39664 .50404 .38748 .49503 Mtetra
.653 .75 .922 r
.38748 .49503 .39664 .50404 .4119 .49929 .4028 .49023 Mtetra
.663 .754 .917 r
.4028 .49023 .4119 .49929 .42726 .49411 .41821 .485 Mtetra
.639 .746 .926 r
.41821 .485 .42726 .49411 .44268 .48981 .43369 .48065 Mtetra
.482 .685 .956 r
.43369 .48065 .44268 .48981 .45811 .48977 .44916 .48056 Mtetra
.192 .529 .922 r
.44916 .48056 .45811 .48977 .4736 .49484 .46468 .48561 Mtetra
0 .382 .837 r
.46468 .48561 .4736 .49484 .48924 .50315 .48034 .49389 Mtetra
.086 .461 .887 r
.48034 .49389 .48924 .50315 .5051 .50991 .49623 .50063 Mtetra
.384 .639 .956 r
.49623 .50063 .5051 .50991 .52118 .51188 .51235 .50257 Mtetra
.652 .756 .926 r
.51235 .50257 .52118 .51188 .53739 .50685 .52863 .49748 Mtetra
.784 .788 .856 r
.52863 .49748 .53739 .50685 .55364 .49478 .54496 .48534 Mtetra
.835 .792 .811 r
.54496 .48534 .55364 .49478 .56985 .47785 .56126 .46832 Mtetra
.848 .792 .797 r
.56126 .46832 .56985 .47785 .58601 .4593 .57752 .44968 Mtetra
.821 .791 .824 r
.57752 .44968 .58601 .4593 .60221 .44394 .5938 .43424 Mtetra
.756 .781 .874 r
.5938 .43424 .60221 .44394 .61855 .43372 .61022 .42395 Mtetra
.671 .757 .915 r
.61022 .42395 .61855 .43372 .63508 .42781 .62682 .41797 Mtetra
.648 .749 .923 r
.62682 .41797 .63508 .42781 .65174 .42278 .64355 .41289 Mtetra
.659 .753 .919 r
.64355 .41289 .65174 .42278 .66849 .41732 .66037 .40737 Mtetra
.662 .754 .918 r
.66037 .40737 .66849 .41732 .68533 .41167 .67727 .40166 Mtetra
.654 .751 .921 r
.67727 .40166 .68533 .41167 .70228 .40634 .6943 .39627 Mtetra
.65 .749 .922 r
.6943 .39627 .70228 .40634 .71935 .40113 .71143 .391 Mtetra
.658 .752 .92 r
.71143 .391 .71935 .40113 .7365 .39557 .72866 .38538 Mtetra
.659 .753 .919 r
.72866 .38538 .7365 .39557 .75375 .38992 .74598 .37967 Mtetra
.655 .751 .92 r
.74598 .37967 .75375 .38992 .77111 .3844 .76342 .37409 Mtetra
.652 .75 .921 r
.76342 .37409 .77111 .3844 .7886 .37898 .78098 .3686 Mtetra
.657 .752 .92 r
.78098 .3686 .7886 .37898 .80617 .37333 .79862 .36288 Mtetra
.658 .752 .92 r
.79862 .36288 .80617 .37333 .82384 .36759 .81638 .35709 Mtetra
.656 .751 .92 r
.81638 .35709 .82384 .36759 .84163 .36192 .83425 .35135 Mtetra
.653 .75 .921 r
.83425 .35135 .84163 .36192 .85955 .35632 .85224 .34568 Mtetra
.659 .752 .919 r
.21476 .53877 .22457 .54733 .23898 .5426 .22921 .53399 Mtetra
.656 .752 .92 r
.22921 .53399 .23898 .5426 .25346 .53794 .24374 .52928 Mtetra
.653 .751 .921 r
.24374 .52928 .25346 .53794 .26801 .53335 .25834 .52464 Mtetra
.654 .751 .921 r
.25834 .52464 .26801 .53335 .28265 .52869 .27303 .51995 Mtetra
.66 .753 .919 r
.27303 .51995 .28265 .52869 .29738 .52382 .28781 .51502 Mtetra
.657 .752 .92 r
.28781 .51502 .29738 .52382 .31219 .51904 .30267 .51018 Mtetra
.652 .75 .922 r
.30267 .51018 .31219 .51904 .32707 .51439 .31761 .50547 Mtetra
.653 .75 .921 r
.31761 .50547 .32707 .51439 .34204 .50966 .33263 .50072 Mtetra
.662 .753 .918 r
.33263 .50072 .34204 .50966 .35711 .5046 .34775 .49562 Mtetra
.658 .753 .92 r
.34775 .49562 .35711 .5046 .37226 .49966 .36295 .4906 Mtetra
.65 .75 .922 r
.36295 .4906 .37226 .49966 .38748 .49503 .37823 .48588 Mtetra
.65 .749 .922 r
.37823 .48588 .38748 .49503 .4028 .49023 .39359 .48112 Mtetra
.664 .755 .918 r
.39359 .48112 .4028 .49023 .41821 .485 .40906 .47579 Mtetra
.647 .749 .923 r
.40906 .47579 .41821 .485 .43369 .48065 .42461 .47107 Mtetra
.538 .701 .945 r
.42461 .47107 .43369 .48065 .44916 .48056 .44015 .46973 Mtetra
.357 .584 .929 r
.44015 .46973 .44916 .48056 .46468 .48561 .45573 .4729 Mtetra
.234 .472 .882 r
.45573 .4729 .46468 .48561 .48034 .49389 .47142 .47952 Mtetra
.335 .5 .873 r
.47142 .47952 .48034 .49389 .49623 .50063 .48733 .48499 Mtetra
.503 .572 .858 r
.48733 .48499 .49623 .50063 .51235 .50257 .50347 .48613 Mtetra
.643 .631 .823 r
.50347 .48613 .51235 .50257 .52863 .49748 .51977 .48098 Mtetra
.729 .668 .789 r
.51977 .48098 .52863 .49748 .54496 .48534 .53615 .46951 Mtetra
.777 .693 .771 r
.53615 .46951 .54496 .48534 .56126 .46832 .55253 .45363 Mtetra
.795 .712 .772 r
.55253 .45363 .56126 .46832 .57752 .44968 .56888 .43655 Mtetra
.776 .728 .808 r
.56888 .43655 .57752 .44968 .5938 .43424 .58528 .42288 Mtetra
.728 .744 .864 r
.58528 .42288 .5938 .43424 .61022 .42395 .6018 .41375 Mtetra
.664 .747 .912 r
.6018 .41375 .61022 .42395 .62682 .41797 .61847 .40804 Mtetra
.647 .748 .923 r
.61847 .40804 .62682 .41797 .64355 .41289 .63527 .40295 Mtetra
.661 .755 .919 r
.63527 .40295 .64355 .41289 .66037 .40737 .65215 .39726 Mtetra
.661 .752 .918 r
.65215 .39726 .66037 .40737 .67727 .40166 .66913 .39154 Mtetra
.653 .75 .921 r
.66913 .39154 .67727 .40166 .6943 .39627 .68622 .38611 Mtetra
.65 .75 .922 r
.68622 .38611 .6943 .39627 .71143 .391 .70343 .38077 Mtetra
.659 .753 .92 r
.70343 .38077 .71143 .391 .72866 .38538 .72073 .37505 Mtetra
.659 .752 .919 r
.72073 .37505 .72866 .38538 .74598 .37967 .73812 .3693 Mtetra
.655 .751 .92 r
.73812 .3693 .74598 .37967 .76342 .37409 .75564 .36367 Mtetra
.652 .75 .922 r
.75564 .36367 .76342 .37409 .78098 .3686 .77327 .35811 Mtetra
.657 .752 .92 r
.77327 .35811 .78098 .3686 .79862 .36288 .79099 .35232 Mtetra
.658 .752 .92 r
.79099 .35232 .79862 .36288 .81638 .35709 .80882 .34646 Mtetra
.655 .751 .92 r
.80882 .34646 .81638 .35709 .83425 .35135 .82677 .34066 Mtetra
.653 .75 .921 r
.82677 .34066 .83425 .35135 .85224 .34568 .84485 .33492 Mtetra
.658 .752 .919 r
.20485 .53012 .21476 .53877 .22921 .53399 .21935 .52531 Mtetra
.657 .752 .92 r
.21935 .52531 .22921 .53399 .24374 .52928 .23393 .52053 Mtetra
.654 .751 .921 r
.23393 .52053 .24374 .52928 .25834 .52464 .24858 .51583 Mtetra
.24858 .51583 .25834 .52464 .27303 .51995 .26331 .5111 Mtetra
.659 .752 .919 r
.26331 .5111 .27303 .51995 .28781 .51502 .27814 .50615 Mtetra
.657 .752 .92 r
.27814 .50615 .28781 .51502 .30267 .51018 .29306 .50123 Mtetra
.653 .751 .921 r
.29306 .50123 .30267 .51018 .31761 .50547 .30804 .49644 Mtetra
.652 .75 .921 r
.30804 .49644 .31761 .50547 .33263 .50072 .32311 .49169 Mtetra
.661 .753 .918 r
.32311 .49169 .33263 .50072 .34775 .49562 .33829 .48656 Mtetra
.659 .753 .92 r
.33829 .48656 .34775 .49562 .36295 .4906 .35354 .48145 Mtetra
.652 .75 .922 r
.35354 .48145 .36295 .4906 .37823 .48588 .36888 .47658 Mtetra
.647 .747 .922 r
.36888 .47658 .37823 .48588 .39359 .48112 .38429 .4719 Mtetra
.664 .754 .918 r
.38429 .4719 .39359 .48112 .40906 .47579 .39982 .46654 Mtetra
.657 .753 .921 r
.39982 .46654 .40906 .47579 .42461 .47107 .41543 .46139 Mtetra
.606 .728 .931 r
.41543 .46139 .42461 .47107 .44015 .46973 .43107 .45804 Mtetra
.487 .634 .918 r
.43107 .45804 .44015 .46973 .45573 .4729 .44674 .45855 Mtetra
.423 .55 .879 r
.44674 .45855 .45573 .4729 .47142 .47952 .4625 .46168 Mtetra
.458 .517 .831 r
.4625 .46168 .47142 .47952 .48733 .48499 .47843 .46488 Mtetra
.547 .541 .8 r
.47843 .46488 .48733 .48499 .50347 .48613 .49457 .46472 Mtetra
.631 .575 .773 r
.49457 .46472 .50347 .48613 .51977 .48098 .51088 .4595 Mtetra
.692 .606 .756 r
.51088 .4595 .51977 .48098 .53615 .46951 .52728 .44918 Mtetra
.731 .634 .751 r
.52728 .44918 .53615 .46951 .55253 .45363 .54371 .43546 Mtetra
.743 .658 .766 r
.54371 .43546 .55253 .45363 .56888 .43655 .56016 .42175 Mtetra
.736 .693 .811 r
.56016 .42175 .56888 .43655 .58528 .42288 .57666 .41065 Mtetra
.69 .717 .87 r
.57666 .41065 .58528 .42288 .6018 .41375 .59328 .40344 Mtetra
.654 .744 .916 r
.59328 .40344 .6018 .41375 .61847 .40804 .61003 .39805 Mtetra
.648 .75 .924 r
.61003 .39805 .61847 .40804 .63527 .40295 .6269 .39287 Mtetra
.664 .755 .918 r
.6269 .39287 .63527 .40295 .65215 .39726 .64384 .38699 Mtetra
.659 .751 .918 r
.64384 .38699 .65215 .39726 .66913 .39154 .66089 .3813 Mtetra
.652 .75 .921 r
.66089 .3813 .66913 .39154 .68622 .38611 .67806 .37585 Mtetra
.651 .751 .922 r
.67806 .37585 .68622 .38611 .70343 .38077 .69534 .37042 Mtetra
.66 .753 .919 r
.69534 .37042 .70343 .38077 .72073 .37505 .7127 .3646 Mtetra
.658 .752 .919 r
.7127 .3646 .72073 .37505 .73812 .3693 .73018 .3588 Mtetra
.654 .751 .921 r
.73018 .3588 .73812 .3693 .75564 .36367 .74777 .35314 Mtetra
.653 .751 .922 r
.74777 .35314 .75564 .36367 .77327 .35811 .76547 .3475 Mtetra
.658 .752 .92 r
.76547 .3475 .77327 .35811 .79099 .35232 .78328 .34162 Mtetra
.658 .752 .919 r
.78328 .34162 .79099 .35232 .80882 .34646 .80119 .3357 Mtetra
.655 .751 .92 r
.80119 .3357 .80882 .34646 .82677 .34066 .81922 .32986 Mtetra
.654 .751 .921 r
.81922 .32986 .82677 .34066 .84485 .33492 .83737 .32404 Mtetra
.658 .752 .919 r
.19484 .52138 .20485 .53012 .21935 .52531 .20938 .51654 Mtetra
.657 .752 .92 r
.20938 .51654 .21935 .52531 .23393 .52053 .22401 .51168 Mtetra
.654 .751 .921 r
.22401 .51168 .23393 .52053 .24858 .51583 .23871 .50692 Mtetra
.653 .75 .921 r
.23871 .50692 .24858 .51583 .26331 .5111 .25349 .50216 Mtetra
.658 .752 .919 r
.25349 .50216 .26331 .5111 .27814 .50615 .26837 .49719 Mtetra
.658 .753 .92 r
.26837 .49719 .27814 .50615 .29306 .50123 .28334 .49219 Mtetra
.654 .751 .921 r
.28334 .49219 .29306 .50123 .30804 .49644 .29838 .48731 Mtetra
.651 .749 .921 r
.29838 .48731 .30804 .49644 .32311 .49169 .3135 .48252 Mtetra
.658 .751 .919 r
.3135 .48252 .32311 .49169 .33829 .48656 .32872 .47743 Mtetra
.661 .754 .919 r
.32872 .47743 .33829 .48656 .35354 .48145 .34403 .47222 Mtetra
.656 .752 .921 r
.34403 .47222 .35354 .48145 .36888 .47658 .35943 .46718 Mtetra
.647 .747 .922 r
.35943 .46718 .36888 .47658 .38429 .4719 .37489 .46243 Mtetra
.657 .749 .918 r
.37489 .46243 .38429 .4719 .39982 .46654 .39047 .45729 Mtetra
.662 .757 .921 r
.39047 .45729 .39982 .46654 .41543 .46139 .40614 .45192 Mtetra
.647 .749 .923 r
.40614 .45192 .41543 .46139 .43107 .45804 .42189 .44707 Mtetra
.589 .696 .917 r
.42189 .44707 .43107 .45804 .44674 .45855 .43767 .44435 Mtetra
.539 .614 .875 r
.43767 .44435 .44674 .45855 .4625 .46168 .45352 .44377 Mtetra
.545 .564 .825 r
.45352 .44377 .4625 .46168 .47843 .46488 .46951 .44345 Mtetra
.578 .546 .783 r
.46951 .44345 .47843 .46488 .49457 .46472 .48566 .44158 Mtetra
.627 .56 .76 r
.48566 .44158 .49457 .46472 .51088 .4595 .50196 .43627 Mtetra
.668 .582 .75 r
.50196 .43627 .51088 .4595 .52728 .44918 .51837 .42753 Mtetra
.691 .606 .756 r
.51837 .42753 .52728 .44918 .54371 .43546 .53484 .4172 Mtetra
.704 .642 .784 r
.53484 .4172 .54371 .43546 .56016 .42175 .55136 .4071 Mtetra
.692 .681 .834 r
.55136 .4071 .56016 .42175 .57666 .41065 .56796 .39914 Mtetra
.663 .723 .894 r
.56796 .39914 .57666 .41065 .59328 .40344 .58467 .39334 Mtetra
.65 .749 .922 r
.58467 .39334 .59328 .40344 .61003 .39805 .6015 .38805 Mtetra
.655 .755 .923 r
.6015 .38805 .61003 .39805 .6269 .39287 .61842 .38253 Mtetra
.664 .752 .916 r
.61842 .38253 .6269 .39287 .64384 .38699 .63544 .3766 Mtetra
.656 .749 .918 r
.63544 .3766 .64384 .38699 .66089 .3813 .65257 .37097 Mtetra
.651 .75 .922 r
.65257 .37097 .66089 .3813 .67806 .37585 .66981 .36551 Mtetra
.653 .752 .922 r
.66981 .36551 .67806 .37585 .69534 .37042 .68715 .35991 Mtetra
.66 .752 .918 r
.68715 .35991 .69534 .37042 .7127 .3646 .70459 .35401 Mtetra
.657 .751 .919 r
.70459 .35401 .7127 .3646 .73018 .3588 .72214 .34819 Mtetra
.653 .75 .921 r
.72214 .34819 .73018 .3588 .74777 .35314 .73981 .3425 Mtetra
.654 .751 .921 r
.73981 .3425 .74777 .35314 .76547 .3475 .75759 .33675 Mtetra
.658 .752 .92 r
.75759 .33675 .76547 .3475 .78328 .34162 .77547 .33079 Mtetra
.657 .752 .919 r
.77547 .33079 .78328 .34162 .80119 .3357 .79346 .32482 Mtetra
.654 .751 .921 r
.79346 .32482 .80119 .3357 .81922 .32986 .81157 .31893 Mtetra
.81157 .31893 .81922 .32986 .83737 .32404 .8298 .31303 Mtetra
.657 .752 .92 r
.18472 .51254 .19484 .52138 .20938 .51654 .19931 .50768 Mtetra
.658 .752 .92 r
.19931 .50768 .20938 .51654 .22401 .51168 .21399 .50275 Mtetra
.654 .751 .921 r
.21399 .50275 .22401 .51168 .23871 .50692 .22874 .49792 Mtetra
.653 .75 .921 r
.22874 .49792 .23871 .50692 .25349 .50216 .24357 .49311 Mtetra
.657 .751 .92 r
.24357 .49311 .25349 .50216 .26837 .49719 .2585 .48815 Mtetra
.659 .753 .919 r
.2585 .48815 .26837 .49719 .28334 .49219 .27351 .48306 Mtetra
.655 .751 .921 r
.27351 .48306 .28334 .49219 .29838 .48731 .28861 .47809 Mtetra
.652 .75 .921 r
.28861 .47809 .29838 .48731 .3135 .48252 .30378 .47322 Mtetra
.655 .75 .92 r
.30378 .47322 .3135 .48252 .32872 .47743 .31905 .46822 Mtetra
.661 .755 .919 r
.31905 .46822 .32872 .47743 .34403 .47222 .33442 .46293 Mtetra
.658 .753 .92 r
.33442 .46293 .34403 .47222 .35943 .46718 .34987 .45775 Mtetra
.651 .749 .922 r
.34987 .45775 .35943 .46718 .37489 .46243 .3654 .45279 Mtetra
.648 .745 .92 r
.3654 .45279 .37489 .46243 .39047 .45729 .38102 .44792 Mtetra
.662 .757 .92 r
.38102 .44792 .39047 .45729 .40614 .45192 .39675 .44247 Mtetra
.66 .755 .921 r
.39675 .44247 .40614 .45192 .42189 .44707 .41257 .43709 Mtetra
.647 .741 .918 r
.41257 .43709 .42189 .44707 .43767 .44435 .42846 .43219 Mtetra
.62 .688 .892 r
.42846 .43219 .43767 .44435 .45352 .44377 .44443 .42836 Mtetra
.601 .627 .849 r
.44443 .42836 .45352 .44377 .46951 .44345 .46049 .42535 Mtetra
.613 .599 .813 r
.46049 .42535 .46951 .44345 .48566 .44158 .47668 .42155 Mtetra
.635 .591 .787 r
.47668 .42155 .48566 .44158 .50196 .43627 .49299 .41617 Mtetra
.657 .602 .781 r
.49299 .41617 .50196 .43627 .51837 .42753 .50942 .40921 Mtetra
.674 .628 .795 r
.50942 .40921 .51837 .42753 .53484 .4172 .52592 .40146 Mtetra
.672 .658 .828 r
.52592 .40146 .53484 .4172 .55136 .4071 .54251 .3945 Mtetra
.661 .704 .878 r
.54251 .3945 .55136 .4071 .56796 .39914 .55919 .38863 Mtetra
.652 .742 .916 r
.55919 .38863 .56796 .39914 .58467 .39334 .57598 .38324 Mtetra
.649 .752 .924 r
.57598 .38324 .58467 .39334 .6015 .38805 .59287 .37792 Mtetra
.663 .757 .92 r
.59287 .37792 .6015 .38805 .61842 .38253 .60985 .372 Mtetra
.66 .749 .916 r
.60985 .372 .61842 .38253 .63544 .3766 .62694 .36617 Mtetra
.654 .75 .92 r
.62694 .36617 .63544 .3766 .65257 .37097 .64415 .36056 Mtetra
.65 .751 .923 r
.64415 .36056 .65257 .37097 .66981 .36551 .66146 .35506 Mtetra
.657 .753 .921 r
.66146 .35506 .66981 .36551 .68715 .35991 .67887 .34926 Mtetra
.66 .752 .918 r
.67887 .34926 .68715 .35991 .70459 .35401 .69638 .34332 Mtetra
.656 .751 .92 r
.69638 .34332 .70459 .35401 .72214 .34819 .71401 .33747 Mtetra
.652 .75 .921 r
.71401 .33747 .72214 .34819 .73981 .3425 .73176 .33174 Mtetra
.655 .752 .921 r
.73176 .33174 .73981 .3425 .75759 .33675 .74961 .32587 Mtetra
.658 .752 .919 r
.74961 .32587 .75759 .33675 .77547 .33079 .76757 .31984 Mtetra
.657 .751 .92 r
.76757 .31984 .77547 .33079 .79346 .32482 .78564 .31381 Mtetra
.654 .75 .921 r
.78564 .31381 .79346 .32482 .81157 .31893 .80384 .30789 Mtetra
.655 .751 .921 r
.80384 .30789 .81157 .31893 .8298 .31303 .82215 .30188 Mtetra
.656 .751 .92 r
.1745 .50361 .18472 .51254 .19931 .50768 .18913 .49874 Mtetra
.659 .753 .92 r
.18913 .49874 .19931 .50768 .21399 .50275 .20386 .49374 Mtetra
.655 .751 .921 r
.20386 .49374 .21399 .50275 .22874 .49792 .21866 .48883 Mtetra
.653 .75 .921 r
.21866 .48883 .22874 .49792 .24357 .49311 .23354 .48396 Mtetra
.655 .75 .92 r
.23354 .48396 .24357 .49311 .2585 .48815 .24851 .47902 Mtetra
.659 .753 .919 r
.24851 .47902 .2585 .48815 .27351 .48306 .26358 .47386 Mtetra
.657 .753 .921 r
.26358 .47386 .27351 .48306 .28861 .47809 .27873 .46878 Mtetra
.653 .75 .921 r
.27873 .46878 .28861 .47809 .30378 .47322 .29396 .46381 Mtetra
.652 .749 .921 r
.29396 .46381 .30378 .47322 .31905 .46822 .30928 .45885 Mtetra
.659 .753 .919 r
.30928 .45885 .31905 .46822 .33442 .46293 .3247 .45359 Mtetra
.66 .755 .92 r
.3247 .45359 .33442 .46293 .34987 .45775 .34021 .44826 Mtetra
.656 .752 .921 r
.34021 .44826 .34987 .45775 .3654 .45279 .3558 .44307 Mtetra
.649 .746 .92 r
.3558 .44307 .3654 .45279 .38102 .44792 .37148 .4381 Mtetra
.65 .745 .919 r
.37148 .4381 .38102 .44792 .39675 .44247 .38725 .43307 Mtetra
.663 .76 .922 r
.38725 .43307 .39675 .44247 .41257 .43709 .40313 .42751 Mtetra
.659 .756 .922 r
.40313 .42751 .41257 .43709 .42846 .43219 .4191 .42208 Mtetra
.656 .744 .915 r
.4191 .42208 .42846 .43219 .44443 .42836 .43516 .41674 Mtetra
.647 .712 .894 r
.43516 .41674 .44443 .42836 .46049 .42535 .45131 .41168 Mtetra
.645 .675 .865 r
.45131 .41168 .46049 .42535 .47668 .42155 .46756 .40659 Mtetra
.648 .658 .846 r
.46756 .40659 .47668 .42155 .49299 .41617 .48391 .40114 Mtetra
.654 .661 .844 r
.48391 .40114 .49299 .41617 .50942 .40921 .50037 .39535 Mtetra
.657 .681 .86 r
.50037 .39535 .50942 .40921 .52592 .40146 .51692 .38952 Mtetra
.655 .714 .892 r
.51692 .38952 .52592 .40146 .54251 .3945 .53357 .38398 Mtetra
.653 .743 .916 r
.53357 .38398 .54251 .3945 .55919 .38863 .55032 .37852 Mtetra
.649 .752 .925 r
.55032 .37852 .55919 .38863 .57598 .38324 .56718 .37319 Mtetra
.661 .759 .923 r
.56718 .37319 .57598 .38324 .59287 .37792 .58413 .36732 Mtetra
.662 .749 .915 r
.58413 .36732 .59287 .37792 .60985 .372 .60119 .36138 Mtetra
.656 .748 .918 r
.60119 .36138 .60985 .372 .62694 .36617 .61835 .35567 Mtetra
.652 .75 .922 r
.61835 .35567 .62694 .36617 .64415 .36056 .63563 .35009 Mtetra
.652 .753 .923 r
.63563 .35009 .64415 .36056 .66146 .35506 .65301 .34444 Mtetra
.659 .754 .92 r
.65301 .34444 .66146 .35506 .67887 .34926 .6705 .33847 Mtetra
.658 .751 .918 r
.6705 .33847 .67887 .34926 .69638 .34332 .68809 .33251 Mtetra
.655 .751 .92 r
.68809 .33251 .69638 .34332 .71401 .33747 .70579 .32666 Mtetra
.652 .751 .922 r
.70579 .32666 .71401 .33747 .73176 .33174 .72362 .32087 Mtetra
.657 .753 .921 r
.72362 .32087 .73176 .33174 .74961 .32587 .74154 .31486 Mtetra
.658 .752 .919 r
.74154 .31486 .74961 .32587 .76757 .31984 .75958 .30876 Mtetra
.656 .751 .92 r
.75958 .30876 .76757 .31984 .78564 .31381 .77773 .3027 Mtetra
.653 .751 .921 r
.77773 .3027 .78564 .31381 .80384 .30789 .79601 .29672 Mtetra
.656 .752 .921 r
.79601 .29672 .80384 .30789 .82215 .30188 .8144 .29061 Mtetra
.655 .751 .92 r
.16417 .49458 .1745 .50361 .18913 .49874 .17885 .48969 Mtetra
.658 .752 .92 r
.17885 .48969 .18913 .49874 .20386 .49374 .19362 .48465 Mtetra
.657 .752 .92 r
.19362 .48465 .20386 .49374 .21866 .48883 .20848 .47963 Mtetra
.654 .75 .921 r
.20848 .47963 .21866 .48883 .23354 .48396 .22341 .47469 Mtetra
.22341 .47469 .23354 .48396 .24851 .47902 .23843 .46974 Mtetra
.658 .752 .919 r
.23843 .46974 .24851 .47902 .26358 .47386 .25355 .4646 Mtetra
.659 .754 .92 r
.25355 .4646 .26358 .47386 .27873 .46878 .26875 .45939 Mtetra
.655 .751 .921 r
.26875 .45939 .27873 .46878 .29396 .46381 .28404 .4543 Mtetra
.652 .749 .921 r
.28404 .4543 .29396 .46381 .30928 .45885 .29941 .44929 Mtetra
.654 .749 .92 r
.29941 .44929 .30928 .45885 .3247 .45359 .31487 .44416 Mtetra
.661 .755 .92 r
.31487 .44416 .3247 .45359 .34021 .44826 .33044 .43876 Mtetra
.659 .754 .921 r
.33044 .43876 .34021 .44826 .3558 .44307 .3461 .43339 Mtetra
.655 .751 .92 r
.3461 .43339 .3558 .44307 .37148 .4381 .36184 .42814 Mtetra
.65 .744 .919 r
.36184 .42814 .37148 .4381 .38725 .43307 .37766 .42307 Mtetra
.65 .745 .919 r
.37766 .42307 .38725 .43307 .40313 .42751 .39358 .41794 Mtetra
.659 .758 .923 r
.39358 .41794 .40313 .42751 .4191 .42208 .40962 .41242 Mtetra
.66 .758 .922 r
.40962 .41242 .4191 .42208 .43516 .41674 .42574 .40685 Mtetra
.657 .753 .921 r
.42574 .40685 .43516 .41674 .45131 .41168 .44196 .40135 Mtetra
.656 .745 .915 r
.44196 .40135 .45131 .41168 .46756 .40659 .45828 .39587 Mtetra
.656 .738 .91 r
.45828 .39587 .46756 .40659 .48391 .40114 .47469 .39037 Mtetra
.47469 .39037 .48391 .40114 .50037 .39535 .49121 .38484 Mtetra
.654 .744 .916 r
.49121 .38484 .50037 .39535 .51692 .38952 .50782 .37933 Mtetra
.652 .751 .923 r
.50782 .37933 .51692 .38952 .53357 .38398 .52454 .37389 Mtetra
.652 .755 .925 r
.52454 .37389 .53357 .38398 .55032 .37852 .54136 .3684 Mtetra
.661 .759 .923 r
.54136 .3684 .55032 .37852 .56718 .37319 .55828 .36251 Mtetra
.662 .749 .915 r
.55828 .36251 .56718 .37319 .58413 .36732 .5753 .35656 Mtetra
.656 .746 .916 r
.5753 .35656 .58413 .36732 .60119 .36138 .59243 .35079 Mtetra
.653 .75 .921 r
.59243 .35079 .60119 .36138 .61835 .35567 .60967 .34513 Mtetra
.651 .752 .923 r
.60967 .34513 .61835 .35567 .63563 .35009 .62702 .3395 Mtetra
.657 .754 .922 r
.62702 .3395 .63563 .35009 .65301 .34444 .64447 .33359 Mtetra
.659 .751 .918 r
.64447 .33359 .65301 .34444 .6705 .33847 .66202 .32756 Mtetra
.657 .75 .919 r
.66202 .32756 .6705 .33847 .68809 .33251 .67969 .3216 Mtetra
.653 .75 .921 r
.67969 .3216 .68809 .33251 .70579 .32666 .69748 .31574 Mtetra
.654 .752 .922 r
.69748 .31574 .70579 .32666 .72362 .32087 .71538 .30982 Mtetra
.658 .752 .92 r
.71538 .30982 .72362 .32087 .74154 .31486 .73338 .3037 Mtetra
.657 .751 .919 r
.73338 .3037 .74154 .31486 .75958 .30876 .7515 .29755 Mtetra
.655 .751 .92 r
.7515 .29755 .75958 .30876 .77773 .3027 .76974 .29147 Mtetra
.654 .751 .921 r
.76974 .29147 .77773 .3027 .79601 .29672 .7881 .28541 Mtetra
.656 .752 .92 r
.7881 .28541 .79601 .29672 .8144 .29061 .80657 .27919 Mtetra
.654 .751 .92 r
.15373 .48545 .16417 .49458 .17885 .48969 .16846 .48052 Mtetra
.657 .752 .92 r
.16846 .48052 .17885 .48969 .19362 .48465 .18328 .47547 Mtetra
.658 .753 .92 r
.18328 .47547 .19362 .48465 .20848 .47963 .19819 .47035 Mtetra
.655 .751 .921 r
.19819 .47035 .20848 .47963 .22341 .47469 .21317 .46534 Mtetra
.653 .75 .921 r
.21317 .46534 .22341 .47469 .23843 .46974 .22824 .46033 Mtetra
.655 .751 .92 r
.22824 .46033 .23843 .46974 .25355 .4646 .2434 .45523 Mtetra
.659 .754 .92 r
.2434 .45523 .25355 .4646 .26875 .45939 .25866 .44995 Mtetra
.657 .753 .921 r
.25866 .44995 .26875 .45939 .28404 .4543 .27401 .44473 Mtetra
.654 .75 .92 r
.27401 .44473 .28404 .4543 .29941 .44929 .28943 .43958 Mtetra
.652 .748 .92 r
.28943 .43958 .29941 .44929 .31487 .44416 .30494 .43449 Mtetra
.656 .751 .92 r
.30494 .43449 .31487 .44416 .33044 .43876 .32056 .42919 Mtetra
.66 .756 .921 r
.32056 .42919 .33044 .43876 .3461 .43339 .33628 .42372 Mtetra
.658 .754 .921 r
.33628 .42372 .3461 .43339 .36184 .42814 .35208 .41829 Mtetra
.655 .751 .92 r
.35208 .41829 .36184 .42814 .37766 .42307 .36797 .41293 Mtetra
.652 .745 .918 r
.36797 .41293 .37766 .42307 .39358 .41794 .38396 .40769 Mtetra
.651 .743 .917 r
.38396 .40769 .39358 .41794 .40962 .41242 .40003 .40244 Mtetra
.653 .751 .922 r
.40003 .40244 .40962 .41242 .42574 .40685 .41621 .39709 Mtetra
.656 .758 .925 r
.41621 .39709 .42574 .40685 .44196 .40135 .4325 .39156 Mtetra
.657 .759 .925 r
.4325 .39156 .44196 .40135 .45828 .39587 .44888 .38598 Mtetra
.656 .758 .925 r
.44888 .38598 .45828 .39587 .47469 .39037 .46536 .38041 Mtetra
.654 .757 .925 r
.46536 .38041 .47469 .39037 .49121 .38484 .48194 .37487 Mtetra
.655 .759 .926 r
.48194 .37487 .49121 .38484 .50782 .37933 .49862 .36927 Mtetra
.659 .759 .924 r
.49862 .36927 .50782 .37933 .52454 .37389 .5154 .36348 Mtetra
.66 .754 .919 r
.5154 .36348 .52454 .37389 .54136 .3684 .53229 .35759 Mtetra
.66 .746 .914 r
.53229 .35759 .54136 .3684 .55828 .36251 .54928 .35169 Mtetra
.656 .746 .916 r
.54928 .35169 .55828 .36251 .5753 .35656 .56637 .3459 Mtetra
.654 .75 .921 r
.56637 .3459 .5753 .35656 .59243 .35079 .58357 .34019 Mtetra
.651 .752 .923 r
.58357 .34019 .59243 .35079 .60967 .34513 .60088 .33452 Mtetra
.655 .755 .923 r
.60088 .33452 .60967 .34513 .62702 .3395 .6183 .32865 Mtetra
.659 .752 .919 r
.6183 .32865 .62702 .3395 .64447 .33359 .63582 .32258 Mtetra
.658 .75 .918 r
.63582 .32258 .64447 .33359 .66202 .32756 .65345 .31656 Mtetra
.655 .75 .92 r
.65345 .31656 .66202 .32756 .67969 .3216 .6712 .3106 Mtetra
.652 .751 .922 r
.6712 .3106 .67969 .3216 .69748 .31574 .68907 .30471 Mtetra
.656 .753 .921 r
.68907 .30471 .69748 .31574 .71538 .30982 .70704 .29861 Mtetra
.658 .752 .919 r
.70704 .29861 .71538 .30982 .73338 .3037 .72512 .29241 Mtetra
.657 .751 .919 r
.72512 .29241 .73338 .3037 .7515 .29755 .74332 .28622 Mtetra
.654 .75 .921 r
.74332 .28622 .7515 .29755 .76974 .29147 .76164 .28012 Mtetra
.655 .752 .921 r
.76164 .28012 .76974 .29147 .7881 .28541 .78008 .27394 Mtetra
.657 .752 .92 r
.78008 .27394 .7881 .28541 .80657 .27919 .79864 .26762 Mtetra
.654 .75 .921 r
.14318 .47621 .15373 .48545 .16846 .48052 .15796 .47124 Mtetra
.655 .751 .92 r
.15796 .47124 .16846 .48052 .18328 .47547 .17282 .4662 Mtetra
.658 .753 .92 r
.17282 .4662 .18328 .47547 .19819 .47035 .18778 .46102 Mtetra
.656 .752 .921 r
.18778 .46102 .19819 .47035 .21317 .46534 .20282 .45588 Mtetra
.654 .75 .921 r
.20282 .45588 .21317 .46534 .22824 .46033 .21794 .4508 Mtetra
.654 .75 .92 r
.21794 .4508 .22824 .46033 .2434 .45523 .23315 .4457 Mtetra
.657 .752 .92 r
.23315 .4457 .2434 .45523 .25866 .44995 .24846 .44044 Mtetra
.659 .754 .92 r
.24846 .44044 .25866 .44995 .27401 .44473 .26386 .43508 Mtetra
.656 .751 .92 r
.26386 .43508 .27401 .44473 .28943 .43958 .27935 .42982 Mtetra
.653 .749 .92 r
.27935 .42982 .28943 .43958 .30494 .43449 .29492 .42461 Mtetra
.652 .748 .92 r
.29492 .42461 .30494 .43449 .32056 .42919 .31058 .41941 Mtetra
.657 .752 .92 r
.31058 .41941 .32056 .42919 .33628 .42372 .32634 .41401 Mtetra
.66 .756 .922 r
.32634 .41401 .33628 .42372 .35208 .41829 .34221 .40847 Mtetra
.658 .755 .921 r
.34221 .40847 .35208 .41829 .36797 .41293 .35817 .40294 Mtetra
.656 .752 .92 r
.35817 .40294 .36797 .41293 .38396 .40769 .37422 .39746 Mtetra
.655 .747 .918 r
.37422 .39746 .38396 .40769 .40003 .40244 .39036 .39199 Mtetra
.653 .743 .916 r
.39036 .39199 .40003 .40244 .41621 .39709 .4066 .38657 Mtetra
.4066 .38657 .41621 .39709 .4325 .39156 .42294 .3811 Mtetra
.655 .746 .917 r
.42294 .3811 .4325 .39156 .44888 .38598 .43938 .37555 Mtetra
.656 .749 .918 r
.43938 .37555 .44888 .38598 .46536 .38041 .45592 .36992 Mtetra
.657 .749 .918 r
.45592 .36992 .46536 .38041 .48194 .37487 .47257 .36421 Mtetra
.658 .747 .916 r
.47257 .36421 .48194 .37487 .49862 .36927 .48931 .35842 Mtetra
.658 .745 .914 r
.48931 .35842 .49862 .36927 .5154 .36348 .50616 .35259 Mtetra
.657 .745 .915 r
.50616 .35259 .5154 .36348 .53229 .35759 .52311 .34679 Mtetra
.655 .747 .918 r
.52311 .34679 .53229 .35759 .54928 .35169 .54017 .341 Mtetra
.653 .751 .921 r
.54017 .341 .54928 .35169 .56637 .3459 .55734 .33526 Mtetra
.652 .752 .923 r
.55734 .33526 .56637 .3459 .58357 .34019 .57461 .32954 Mtetra
.655 .755 .923 r
.57461 .32954 .58357 .34019 .60088 .33452 .59199 .32366 Mtetra
.659 .753 .92 r
.59199 .32366 .60088 .33452 .6183 .32865 .60948 .31758 Mtetra
.658 .75 .918 r
.60948 .31758 .6183 .32865 .63582 .32258 .62708 .3115 Mtetra
.656 .75 .919 r
.62708 .3115 .63582 .32258 .65345 .31656 .64479 .30546 Mtetra
.653 .75 .921 r
.64479 .30546 .65345 .31656 .6712 .3106 .66261 .29953 Mtetra
.654 .753 .922 r
.66261 .29953 .6712 .3106 .68907 .30471 .68055 .29348 Mtetra
.658 .752 .92 r
.68055 .29348 .68907 .30471 .70704 .29861 .6986 .28725 Mtetra
.657 .751 .919 r
.6986 .28725 .70704 .29861 .72512 .29241 .71676 .281 Mtetra
.655 .751 .92 r
.71676 .281 .72512 .29241 .74332 .28622 .73505 .2748 Mtetra
.653 .751 .921 r
.73505 .2748 .74332 .28622 .76164 .28012 .75346 .26864 Mtetra
.656 .752 .921 r
.75346 .26864 .76164 .28012 .78008 .27394 .77197 .26232 Mtetra
.657 .752 .92 r
.77197 .26232 .78008 .27394 .79864 .26762 .79061 .25592 Mtetra
.654 .75 .921 r
.13252 .46688 .14318 .47621 .15796 .47124 .14734 .46186 Mtetra
.655 .751 .92 r
.14734 .46186 .15796 .47124 .17282 .4662 .16225 .45679 Mtetra
.657 .752 .92 r
.16225 .45679 .17282 .4662 .18778 .46102 .17726 .4516 Mtetra
.658 .753 .92 r
.17726 .4516 .18778 .46102 .20282 .45588 .19236 .44634 Mtetra
.655 .751 .92 r
.19236 .44634 .20282 .45588 .21794 .4508 .20753 .44117 Mtetra
.654 .75 .92 r
.20753 .44117 .21794 .4508 .23315 .4457 .22279 .43602 Mtetra
.22279 .43602 .23315 .4457 .24846 .44044 .23814 .43081 Mtetra
.658 .753 .92 r
.23814 .43081 .24846 .44044 .26386 .43508 .2536 .42542 Mtetra
.658 .754 .921 r
.2536 .42542 .26386 .43508 .27935 .42982 .26915 .42 Mtetra
.655 .751 .92 r
.26915 .42 .27935 .42982 .29492 .42461 .28478 .41466 Mtetra
.654 .749 .92 r
.28478 .41466 .29492 .42461 .31058 .41941 .3005 .40935 Mtetra
.653 .748 .919 r
.3005 .40935 .31058 .41941 .32634 .41401 .31631 .40405 Mtetra
.655 .752 .921 r
.31631 .40405 .32634 .41401 .34221 .40847 .33222 .3986 Mtetra
.659 .756 .922 r
.33222 .3986 .34221 .40847 .35817 .40294 .34824 .393 Mtetra
.34824 .393 .35817 .40294 .37422 .39746 .36436 .38736 Mtetra
.657 .753 .921 r
.36436 .38736 .37422 .39746 .39036 .39199 .38056 .38175 Mtetra
.656 .751 .92 r
.38056 .38175 .39036 .39199 .4066 .38657 .39687 .37614 Mtetra
.656 .749 .918 r
.39687 .37614 .4066 .38657 .42294 .3811 .41327 .37052 Mtetra
.656 .747 .917 r
.41327 .37052 .42294 .3811 .43938 .37555 .42978 .36486 Mtetra
.656 .746 .916 r
.42978 .36486 .43938 .37555 .45592 .36992 .44638 .35917 Mtetra
.44638 .35917 .45592 .36992 .47257 .36421 .46309 .35344 Mtetra
.656 .747 .917 r
.46309 .35344 .47257 .36421 .48931 .35842 .4799 .34768 Mtetra
.655 .748 .918 r
.4799 .34768 .48931 .35842 .50616 .35259 .49682 .3419 Mtetra
.654 .751 .921 r
.49682 .3419 .50616 .35259 .52311 .34679 .51384 .33612 Mtetra
.653 .752 .922 r
.51384 .33612 .52311 .34679 .54017 .341 .53097 .33036 Mtetra
.653 .754 .924 r
.53097 .33036 .54017 .341 .55734 .33526 .5482 .32457 Mtetra
.656 .756 .923 r
.5482 .32457 .55734 .33526 .57461 .32954 .56555 .31862 Mtetra
.659 .753 .92 r
.56555 .31862 .57461 .32954 .59199 .32366 .583 .31251 Mtetra
.658 .749 .918 r
.583 .31251 .59199 .32366 .60948 .31758 .60056 .3064 Mtetra
.656 .75 .919 r
.60056 .3064 .60948 .31758 .62708 .3115 .61823 .30033 Mtetra
.653 .75 .921 r
.61823 .30033 .62708 .3115 .64479 .30546 .63602 .29433 Mtetra
.653 .752 .922 r
.63602 .29433 .64479 .30546 .66261 .29953 .65392 .28829 Mtetra
.657 .753 .921 r
.65392 .28829 .66261 .29953 .68055 .29348 .67194 .28206 Mtetra
.658 .751 .919 r
.67194 .28206 .68055 .29348 .6986 .28725 .69006 .27576 Mtetra
.657 .751 .919 r
.69006 .27576 .6986 .28725 .71676 .281 .70831 .26947 Mtetra
.654 .75 .921 r
.70831 .26947 .71676 .281 .73505 .2748 .72668 .26327 Mtetra
.655 .752 .921 r
.72668 .26327 .73505 .2748 .75346 .26864 .74517 .25698 Mtetra
.657 .752 .92 r
.74517 .25698 .75346 .26864 .77197 .26232 .76377 .25056 Mtetra
.657 .751 .919 r
.76377 .25056 .77197 .26232 .79061 .25592 .78249 .24407 Mtetra
.655 .751 .921 r
.12175 .45746 .13252 .46688 .14734 .46186 .13662 .45236 Mtetra
.654 .75 .92 r
.13662 .45236 .14734 .46186 .16225 .45679 .15157 .44725 Mtetra
.655 .751 .92 r
.15157 .44725 .16225 .45679 .17726 .4516 .16662 .44208 Mtetra
.658 .753 .92 r
.16662 .44208 .17726 .4516 .19236 .44634 .18177 .43676 Mtetra
.657 .753 .921 r
.18177 .43676 .19236 .44634 .20753 .44117 .197 .43146 Mtetra
.654 .75 .92 r
.197 .43146 .20753 .44117 .22279 .43602 .21232 .42622 Mtetra
.21232 .42622 .22279 .43602 .23814 .43081 .22772 .42097 Mtetra
.655 .75 .92 r
.22772 .42097 .23814 .43081 .2536 .42542 .24322 .41566 Mtetra
.659 .754 .921 r
.24322 .41566 .2536 .42542 .26915 .42 .25882 .41017 Mtetra
.658 .754 .921 r
.25882 .41017 .26915 .42 .28478 .41466 .27452 .40466 Mtetra
.655 .751 .92 r
.27452 .40466 .28478 .41466 .3005 .40935 .2903 .39922 Mtetra
.654 .749 .919 r
.2903 .39922 .3005 .40935 .31631 .40405 .30617 .3938 Mtetra
.653 .747 .919 r
.30617 .3938 .31631 .40405 .33222 .3986 .32214 .38839 Mtetra
.654 .75 .92 r
.32214 .38839 .33222 .3986 .34824 .393 .33821 .38291 Mtetra
.657 .755 .922 r
.33821 .38291 .34824 .393 .36436 .38736 .35438 .3773 Mtetra
.658 .757 .923 r
.35438 .3773 .36436 .38736 .38056 .38175 .37065 .3716 Mtetra
.658 .756 .923 r
.37065 .3716 .38056 .38175 .39687 .37614 .38702 .36588 Mtetra
.657 .755 .922 r
.38702 .36588 .39687 .37614 .41327 .37052 .40349 .36014 Mtetra
.656 .754 .922 r
.40349 .36014 .41327 .37052 .42978 .36486 .42006 .3544 Mtetra
.656 .753 .921 r
.42006 .3544 .42978 .36486 .44638 .35917 .43673 .34864 Mtetra
.655 .753 .922 r
.43673 .34864 .44638 .35917 .46309 .35344 .4535 .34287 Mtetra
.4535 .34287 .46309 .35344 .4799 .34768 .47038 .33709 Mtetra
.654 .754 .923 r
.47038 .33709 .4799 .34768 .49682 .3419 .48736 .33129 Mtetra
.654 .755 .924 r
.48736 .33129 .49682 .3419 .51384 .33612 .50445 .32547 Mtetra
.655 .756 .924 r
.50445 .32547 .51384 .33612 .53097 .33036 .52165 .31956 Mtetra
.658 .755 .922 r
.52165 .31956 .53097 .33036 .5482 .32457 .53896 .31351 Mtetra
.658 .751 .919 r
.53896 .31351 .5482 .32457 .56555 .31862 .55637 .30739 Mtetra
.657 .749 .917 r
.55637 .30739 .56555 .31862 .583 .31251 .5739 .30128 Mtetra
.656 .75 .919 r
.5739 .30128 .583 .31251 .60056 .3064 .59153 .29517 Mtetra
.654 .75 .921 r
.59153 .29517 .60056 .3064 .61823 .30033 .60928 .28913 Mtetra
.653 .752 .922 r
.60928 .28913 .61823 .30033 .63602 .29433 .62715 .28307 Mtetra
.657 .754 .921 r
.62715 .28307 .63602 .29433 .65392 .28829 .64513 .27682 Mtetra
.658 .751 .919 r
.64513 .27682 .65392 .28829 .67194 .28206 .66322 .27049 Mtetra
.657 .751 .919 r
.66322 .27049 .67194 .28206 .69006 .27576 .68142 .26415 Mtetra
.655 .75 .92 r
.68142 .26415 .69006 .27576 .70831 .26947 .69975 .25787 Mtetra
.654 .752 .922 r
.69975 .25787 .70831 .26947 .72668 .26327 .71821 .25159 Mtetra
.656 .753 .921 r
.71821 .25159 .72668 .26327 .74517 .25698 .73677 .24515 Mtetra
.657 .752 .92 r
.73677 .24515 .74517 .25698 .76377 .25056 .75546 .23864 Mtetra
.657 .751 .919 r
.75546 .23864 .76377 .25056 .78249 .24407 .77427 .2321 Mtetra
.656 .752 .92 r
.11085 .44798 .12175 .45746 .13662 .45236 .12578 .44277 Mtetra
.654 .75 .92 r
.12578 .44277 .13662 .45236 .15157 .44725 .14078 .4376 Mtetra
.655 .75 .92 r
.14078 .4376 .15157 .44725 .16662 .44208 .15588 .43239 Mtetra
.656 .751 .92 r
.15588 .43239 .16662 .44208 .18177 .43676 .17107 .42709 Mtetra
.658 .753 .92 r
.17107 .42709 .18177 .43676 .197 .43146 .18636 .42169 Mtetra
.656 .752 .92 r
.18636 .42169 .197 .43146 .21232 .42622 .20173 .41632 Mtetra
.654 .75 .92 r
.20173 .41632 .21232 .42622 .22772 .42097 .21719 .411 Mtetra
.654 .749 .92 r
.21719 .411 .22772 .42097 .24322 .41566 .23274 .40566 Mtetra
.655 .75 .92 r
.23274 .40566 .24322 .41566 .25882 .41017 .24839 .40024 Mtetra
.658 .754 .921 r
.24839 .40024 .25882 .41017 .27452 .40466 .26414 .39467 Mtetra
.26414 .39467 .27452 .40466 .2903 .39922 .27999 .38907 Mtetra
.656 .751 .92 r
.27999 .38907 .2903 .39922 .30617 .3938 .29592 .38352 Mtetra
.655 .75 .919 r
.29592 .38352 .30617 .3938 .32214 .38839 .31195 .37797 Mtetra
.654 .748 .919 r
.31195 .37797 .32214 .38839 .33821 .38291 .32808 .37243 Mtetra
.32808 .37243 .33821 .38291 .35438 .3773 .3443 .36686 Mtetra
.654 .75 .92 r
.3443 .36686 .35438 .3773 .37065 .3716 .36063 .36123 Mtetra
.655 .753 .922 r
.36063 .36123 .37065 .3716 .38702 .36588 .37705 .35554 Mtetra
.656 .755 .923 r
.37705 .35554 .38702 .36588 .40349 .36014 .39359 .34978 Mtetra
.656 .756 .924 r
.39359 .34978 .40349 .36014 .42006 .3544 .41022 .34398 Mtetra
.41022 .34398 .42006 .3544 .43673 .34864 .42696 .33815 Mtetra
.655 .756 .924 r
.42696 .33815 .43673 .34864 .4535 .34287 .4438 .33231 Mtetra
.4438 .33231 .4535 .34287 .47038 .33709 .46074 .32642 Mtetra
.656 .756 .923 r
.46074 .32642 .47038 .33709 .48736 .33129 .4778 .32046 Mtetra
.657 .754 .921 r
.4778 .32046 .48736 .33129 .50445 .32547 .49496 .31444 Mtetra
.658 .751 .919 r
.49496 .31444 .50445 .32547 .52165 .31956 .51223 .30835 Mtetra
.657 .749 .917 r
.51223 .30835 .52165 .31956 .53896 .31351 .5296 .30223 Mtetra
.657 .749 .918 r
.5296 .30223 .53896 .31351 .55637 .30739 .54709 .29611 Mtetra
.656 .75 .919 r
.54709 .29611 .55637 .30739 .5739 .30128 .56469 .28999 Mtetra
.653 .75 .921 r
.56469 .28999 .5739 .30128 .59153 .29517 .5824 .28392 Mtetra
.653 .753 .923 r
.5824 .28392 .59153 .29517 .60928 .28913 .60023 .27782 Mtetra
.657 .754 .922 r
.60023 .27782 .60928 .28913 .62715 .28307 .61817 .27154 Mtetra
.658 .751 .919 r
.61817 .27154 .62715 .28307 .64513 .27682 .63622 .26518 Mtetra
.657 .75 .919 r
.63622 .26518 .64513 .27682 .66322 .27049 .65439 .25881 Mtetra
.655 .75 .92 r
.65439 .25881 .66322 .27049 .68142 .26415 .67268 .25246 Mtetra
.654 .751 .921 r
.67268 .25246 .68142 .26415 .69975 .25787 .6911 .24614 Mtetra
.655 .753 .921 r
.6911 .24614 .69975 .25787 .71821 .25159 .70963 .23971 Mtetra
.657 .752 .92 r
.70963 .23971 .71821 .25159 .73677 .24515 .72828 .23317 Mtetra
.657 .751 .919 r
.72828 .23317 .73677 .24515 .75546 .23864 .74705 .22658 Mtetra
.655 .75 .92 r
.74705 .22658 .75546 .23864 .77427 .2321 .76595 .22002 Mtetra
.658 .753 .92 r
.09983 .43842 .11085 .44798 .12578 .44277 .11481 .4331 Mtetra
.655 .751 .92 r
.11481 .4331 .12578 .44277 .14078 .4376 .12987 .42783 Mtetra
.654 .75 .92 r
.12987 .42783 .14078 .4376 .15588 .43239 .14502 .42258 Mtetra
.655 .751 .92 r
.14502 .42258 .15588 .43239 .17107 .42709 .16025 .41727 Mtetra
.657 .752 .92 r
.16025 .41727 .17107 .42709 .18636 .42169 .17559 .41186 Mtetra
.658 .753 .92 r
.17559 .41186 .18636 .42169 .20173 .41632 .19102 .40637 Mtetra
.656 .752 .92 r
.19102 .40637 .20173 .41632 .21719 .411 .20654 .40093 Mtetra
.654 .75 .92 r
.20654 .40093 .21719 .411 .23274 .40566 .22215 .3955 Mtetra
.654 .749 .92 r
.22215 .3955 .23274 .40566 .24839 .40024 .23785 .39006 Mtetra
.655 .75 .92 r
.23785 .39006 .24839 .40024 .26414 .39467 .25364 .38457 Mtetra
.657 .754 .921 r
.25364 .38457 .26414 .39467 .27999 .38907 .26954 .37893 Mtetra
.658 .755 .921 r
.26954 .37893 .27999 .38907 .29592 .38352 .28554 .37323 Mtetra
.657 .753 .92 r
.28554 .37323 .29592 .38352 .31195 .37797 .30164 .36755 Mtetra
.656 .751 .92 r
.30164 .36755 .31195 .37797 .32808 .37243 .31783 .36188 Mtetra
.655 .749 .919 r
.31783 .36188 .32808 .37243 .3443 .36686 .33411 .35619 Mtetra
.655 .748 .918 r
.33411 .35619 .3443 .36686 .36063 .36123 .3505 .35047 Mtetra
.655 .747 .918 r
.3505 .35047 .36063 .36123 .37705 .35554 .36699 .34474 Mtetra
.655 .748 .918 r
.36699 .34474 .37705 .35554 .39359 .34978 .38358 .33895 Mtetra
.655 .749 .919 r
.38358 .33895 .39359 .34978 .41022 .34398 .40028 .33311 Mtetra
.656 .75 .919 r
.40028 .33311 .41022 .34398 .42696 .33815 .41708 .32722 Mtetra
.41708 .32722 .42696 .33815 .4438 .33231 .43399 .32128 Mtetra
.657 .749 .918 r
.43399 .32128 .4438 .33231 .46074 .32642 .451 .31528 Mtetra
.657 .748 .917 r
.451 .31528 .46074 .32642 .4778 .32046 .46813 .30923 Mtetra
.46813 .30923 .4778 .32046 .49496 .31444 .48536 .30316 Mtetra
.656 .748 .918 r
.48536 .30316 .49496 .31444 .51223 .30835 .50269 .29705 Mtetra
.656 .749 .919 r
.50269 .29705 .51223 .30835 .5296 .30223 .52014 .29093 Mtetra
.655 .75 .92 r
.52014 .29093 .5296 .30223 .54709 .29611 .5377 .28482 Mtetra
.654 .751 .922 r
.5377 .28482 .54709 .29611 .56469 .28999 .55538 .27871 Mtetra
.654 .753 .923 r
.55538 .27871 .56469 .28999 .5824 .28392 .57316 .27254 Mtetra
.657 .754 .921 r
.57316 .27254 .5824 .28392 .60023 .27782 .59107 .26622 Mtetra
.657 .751 .919 r
.59107 .26622 .60023 .27782 .61817 .27154 .60908 .25983 Mtetra
.657 .75 .919 r
.60908 .25983 .61817 .27154 .63622 .26518 .62721 .25343 Mtetra
.656 .75 .92 r
.62721 .25343 .63622 .26518 .65439 .25881 .64547 .24703 Mtetra
.654 .751 .921 r
.64547 .24703 .65439 .25881 .67268 .25246 .66384 .24067 Mtetra
.655 .753 .922 r
.66384 .24067 .67268 .25246 .6911 .24614 .68234 .23422 Mtetra
.657 .752 .92 r
.68234 .23422 .6911 .24614 .70963 .23971 .70095 .22766 Mtetra
.657 .751 .919 r
.70095 .22766 .70963 .23971 .72828 .23317 .71968 .22103 Mtetra
.656 .751 .92 r
.71968 .22103 .72828 .23317 .74705 .22658 .73854 .2144 Mtetra
.654 .751 .921 r
.73854 .2144 .74705 .22658 .76595 .22002 .75753 .20781 Mtetra
.657 .752 .92 r
.08869 .42872 .09983 .43842 .11481 .4331 .10372 .42337 Mtetra
.657 .753 .92 r
.10372 .42337 .11481 .4331 .12987 .42783 .11884 .41798 Mtetra
.655 .751 .92 r
.11884 .41798 .12987 .42783 .14502 .42258 .13404 .41264 Mtetra
.654 .75 .92 r
.13404 .41264 .14502 .42258 .16025 .41727 .14932 .40729 Mtetra
.655 .751 .92 r
.14932 .40729 .16025 .41727 .17559 .41186 .16471 .40189 Mtetra
.657 .752 .92 r
.16471 .40189 .17559 .41186 .19102 .40637 .18019 .39638 Mtetra
.658 .754 .921 r
.18019 .39638 .19102 .40637 .20654 .40093 .19577 .3908 Mtetra
.656 .751 .92 r
.19577 .3908 .20654 .40093 .22215 .3955 .21143 .38526 Mtetra
.655 .75 .92 r
.21143 .38526 .22215 .3955 .23785 .39006 .22719 .37973 Mtetra
.654 .749 .92 r
.22719 .37973 .23785 .39006 .25364 .38457 .24304 .37419 Mtetra
.655 .75 .92 r
.24304 .37419 .25364 .38457 .26954 .37893 .25899 .3686 Mtetra
.656 .753 .921 r
.25899 .3686 .26954 .37893 .28554 .37323 .27504 .36293 Mtetra
.658 .755 .922 r
.27504 .36293 .28554 .37323 .30164 .36755 .2912 .35715 Mtetra
.657 .754 .921 r
.2912 .35715 .30164 .36755 .31783 .36188 .30745 .35134 Mtetra
.657 .753 .92 r
.30745 .35134 .31783 .36188 .33411 .35619 .3238 .34553 Mtetra
.656 .751 .92 r
.3238 .34553 .33411 .35619 .3505 .35047 .34026 .33971 Mtetra
.656 .75 .919 r
.34026 .33971 .3505 .35047 .36699 .34474 .35681 .33386 Mtetra
.656 .749 .919 r
.35681 .33386 .36699 .34474 .38358 .33895 .37347 .32798 Mtetra
.656 .749 .918 r
.37347 .32798 .38358 .33895 .40028 .33311 .39023 .32207 Mtetra
.656 .748 .918 r
.39023 .32207 .40028 .33311 .41708 .32722 .4071 .31611 Mtetra
.656 .749 .918 r
.4071 .31611 .41708 .32722 .43399 .32128 .42407 .3101 Mtetra
.42407 .3101 .43399 .32128 .451 .31528 .44115 .30406 Mtetra
.656 .749 .919 r
.44115 .30406 .451 .31528 .46813 .30923 .45834 .29799 Mtetra
.656 .75 .919 r
.45834 .29799 .46813 .30923 .48536 .30316 .47564 .29188 Mtetra
.655 .751 .92 r
.47564 .29188 .48536 .30316 .50269 .29705 .49305 .28577 Mtetra
.654 .752 .921 r
.49305 .28577 .50269 .29705 .52014 .29093 .51057 .27965 Mtetra
.654 .753 .923 r
.51057 .27965 .52014 .29093 .5377 .28482 .5282 .27349 Mtetra
.656 .754 .922 r
.5282 .27349 .5377 .28482 .55538 .27871 .54595 .26722 Mtetra
.657 .753 .921 r
.54595 .26722 .55538 .27871 .57316 .27254 .56381 .26086 Mtetra
.657 .751 .919 r
.56381 .26086 .57316 .27254 .59107 .26622 .58179 .25445 Mtetra
.657 .75 .919 r
.58179 .25445 .59107 .26622 .60908 .25983 .59988 .24801 Mtetra
.656 .75 .92 r
.59988 .24801 .60908 .25983 .62721 .25343 .6181 .24158 Mtetra
.654 .751 .921 r
.6181 .24158 .62721 .25343 .64547 .24703 .63643 .23518 Mtetra
.655 .753 .922 r
.63643 .23518 .64547 .24703 .66384 .24067 .65489 .2287 Mtetra
.656 .752 .921 r
.65489 .2287 .66384 .24067 .68234 .23422 .67346 .22211 Mtetra
.657 .751 .919 r
.67346 .22211 .68234 .23422 .70095 .22766 .69216 .21545 Mtetra
.69216 .21545 .70095 .22766 .71968 .22103 .71098 .20876 Mtetra
.654 .75 .92 r
.71098 .20876 .71968 .22103 .73854 .2144 .72993 .20212 Mtetra
.655 .752 .921 r
.72993 .20212 .73854 .2144 .75753 .20781 .74901 .19543 Mtetra
.656 .751 .92 r
.07744 .4189 .08869 .42872 .10372 .42337 .09251 .41353 Mtetra
.657 .753 .92 r
.09251 .41353 .10372 .42337 .11884 .41798 .10768 .40808 Mtetra
.657 .752 .92 r
.10768 .40808 .11884 .41798 .13404 .41264 .12294 .40261 Mtetra
.655 .75 .92 r
.12294 .40261 .13404 .41264 .14932 .40729 .13828 .39719 Mtetra
.654 .75 .92 r
.13828 .39719 .14932 .40729 .16471 .40189 .15371 .39174 Mtetra
.655 .751 .92 r
.15371 .39174 .16471 .40189 .18019 .39638 .16924 .38624 Mtetra
.657 .753 .921 r
.16924 .38624 .18019 .39638 .19577 .3908 .18486 .38064 Mtetra
.658 .754 .921 r
.18486 .38064 .19577 .3908 .21143 .38526 .20059 .37497 Mtetra
.656 .752 .92 r
.20059 .37497 .21143 .38526 .22719 .37973 .21641 .36931 Mtetra
.655 .75 .92 r
.21641 .36931 .22719 .37973 .24304 .37419 .23232 .36368 Mtetra
.655 .749 .92 r
.23232 .36368 .24304 .37419 .25899 .3686 .24833 .35802 Mtetra
.654 .749 .92 r
.24833 .35802 .25899 .3686 .27504 .36293 .26443 .35234 Mtetra
.655 .751 .92 r
.26443 .35234 .27504 .36293 .2912 .35715 .28064 .3466 Mtetra
.656 .753 .921 r
.28064 .3466 .2912 .35715 .30745 .35134 .29695 .34079 Mtetra
.657 .755 .922 r
.29695 .34079 .30745 .35134 .3238 .34553 .31337 .33491 Mtetra
.31337 .33491 .3238 .34553 .34026 .33971 .32988 .32898 Mtetra
.657 .754 .921 r
.32988 .32898 .34026 .33971 .35681 .33386 .3465 .32303 Mtetra
.656 .753 .921 r
.3465 .32303 .35681 .33386 .37347 .32798 .36323 .31706 Mtetra
.656 .752 .921 r
.36323 .31706 .37347 .32798 .39023 .32207 .38005 .31106 Mtetra
.38005 .31106 .39023 .32207 .4071 .31611 .39699 .30503 Mtetra
.39699 .30503 .4071 .31611 .42407 .3101 .41403 .29897 Mtetra
.655 .752 .921 r
.41403 .29897 .42407 .3101 .44115 .30406 .43118 .29289 Mtetra
.655 .752 .922 r
.43118 .29289 .44115 .30406 .45834 .29799 .44843 .28677 Mtetra
.655 .753 .922 r
.44843 .28677 .45834 .29799 .47564 .29188 .4658 .28063 Mtetra
.655 .754 .923 r
.4658 .28063 .47564 .29188 .49305 .28577 .48328 .27445 Mtetra
.656 .754 .922 r
.48328 .27445 .49305 .28577 .51057 .27965 .50088 .26819 Mtetra
.657 .753 .921 r
.50088 .26819 .51057 .27965 .5282 .27349 .51859 .26185 Mtetra
.657 .751 .92 r
.51859 .26185 .5282 .27349 .54595 .26722 .53641 .25546 Mtetra
.657 .75 .919 r
.53641 .25546 .54595 .26722 .56381 .26086 .55435 .24902 Mtetra
.55435 .24902 .56381 .26086 .58179 .25445 .5724 .24256 Mtetra
.655 .75 .92 r
.5724 .24256 .58179 .25445 .59988 .24801 .59058 .23611 Mtetra
.654 .751 .921 r
.59058 .23611 .59988 .24801 .6181 .24158 .60887 .22967 Mtetra
.655 .753 .922 r
.60887 .22967 .6181 .24158 .63643 .23518 .62729 .22315 Mtetra
.656 .753 .921 r
.62729 .22315 .63643 .23518 .65489 .2287 .64583 .21653 Mtetra
.657 .751 .92 r
.64583 .21653 .65489 .2287 .67346 .22211 .66448 .20983 Mtetra
.657 .751 .919 r
.66448 .20983 .67346 .22211 .69216 .21545 .68326 .2031 Mtetra
.655 .75 .92 r
.68326 .2031 .69216 .21545 .71098 .20876 .70218 .19641 Mtetra
.654 .752 .921 r
.70218 .19641 .71098 .20876 .72993 .20212 .72122 .18969 Mtetra
.656 .752 .921 r
.72122 .18969 .72993 .20212 .74901 .19543 .74038 .18287 Mtetra
.655 .751 .92 r
.06606 .40894 .07744 .4189 .09251 .41353 .08118 .40354 Mtetra
.656 .752 .92 r
.08118 .40354 .09251 .41353 .10768 .40808 .09639 .39808 Mtetra
.657 .753 .92 r
.09639 .39808 .10768 .40808 .12294 .40261 .1117 .39253 Mtetra
.657 .752 .92 r
.1117 .39253 .12294 .40261 .13828 .39719 .1271 .38697 Mtetra
.655 .75 .92 r
.1271 .38697 .13828 .39719 .15371 .39174 .14259 .38146 Mtetra
.14259 .38146 .15371 .39174 .16924 .38624 .15817 .37591 Mtetra
.655 .751 .92 r
.15817 .37591 .16924 .38624 .18486 .38064 .17384 .37031 Mtetra
.656 .752 .921 r
.17384 .37031 .18486 .38064 .20059 .37497 .18962 .36463 Mtetra
.658 .754 .921 r
.18962 .36463 .20059 .37497 .21641 .36931 .2055 .35887 Mtetra
.657 .753 .92 r
.2055 .35887 .21641 .36931 .23232 .36368 .22148 .35309 Mtetra
.655 .751 .92 r
.22148 .35309 .23232 .36368 .24833 .35802 .23754 .34734 Mtetra
.655 .75 .92 r
.23754 .34734 .24833 .35802 .26443 .35234 .25371 .34157 Mtetra
.655 .749 .919 r
.25371 .34157 .26443 .35234 .28064 .3466 .26997 .33577 Mtetra
.26997 .33577 .28064 .3466 .29695 .34079 .28634 .32993 Mtetra
.655 .75 .92 r
.28634 .32993 .29695 .34079 .31337 .33491 .30281 .32405 Mtetra
.655 .752 .921 r
.30281 .32405 .31337 .33491 .32988 .32898 .31939 .31812 Mtetra
.656 .753 .922 r
.31939 .31812 .32988 .32898 .3465 .32303 .33607 .31214 Mtetra
.656 .754 .922 r
.33607 .31214 .3465 .32303 .36323 .31706 .35286 .30612 Mtetra
.656 .755 .922 r
.35286 .30612 .36323 .31706 .38005 .31106 .36975 .30005 Mtetra
.656 .755 .923 r
.36975 .30005 .38005 .31106 .39699 .30503 .38675 .29395 Mtetra
.656 .754 .923 r
.38675 .29395 .39699 .30503 .41403 .29897 .40386 .28782 Mtetra
.40386 .28782 .41403 .29897 .43118 .29289 .42108 .28164 Mtetra
.656 .754 .922 r
.42108 .28164 .43118 .29289 .44843 .28677 .43841 .27542 Mtetra
.656 .753 .921 r
.43841 .27542 .44843 .28677 .4658 .28063 .45585 .26914 Mtetra
.656 .752 .92 r
.45585 .26914 .4658 .28063 .48328 .27445 .47341 .26281 Mtetra
.657 .751 .919 r
.47341 .26281 .48328 .27445 .50088 .26819 .49108 .25643 Mtetra
.657 .75 .919 r
.49108 .25643 .50088 .26819 .51859 .26185 .50886 .25002 Mtetra
.50886 .25002 .51859 .26185 .53641 .25546 .52676 .24356 Mtetra
.656 .75 .919 r
.52676 .24356 .53641 .25546 .55435 .24902 .54477 .23708 Mtetra
.655 .75 .92 r
.54477 .23708 .55435 .24902 .5724 .24256 .56291 .23063 Mtetra
.654 .752 .921 r
.56291 .23063 .5724 .24256 .59058 .23611 .58116 .22415 Mtetra
.655 .753 .922 r
.58116 .22415 .59058 .23611 .60887 .22967 .59954 .21757 Mtetra
.656 .752 .921 r
.59954 .21757 .60887 .22967 .62729 .22315 .61803 .21091 Mtetra
.657 .751 .919 r
.61803 .21091 .62729 .22315 .64583 .21653 .63665 .20418 Mtetra
.63665 .20418 .64583 .21653 .66448 .20983 .65539 .19741 Mtetra
.655 .75 .92 r
.65539 .19741 .66448 .20983 .68326 .2031 .67426 .19067 Mtetra
.654 .751 .921 r
.67426 .19067 .68326 .2031 .70218 .19641 .69326 .18391 Mtetra
.656 .752 .921 r
.69326 .18391 .70218 .19641 .72122 .18969 .71239 .17706 Mtetra
.656 .752 .92 r
.71239 .17706 .72122 .18969 .74038 .18287 .73164 .17012 Mtetra
.654 .75 .92 r
.05456 .39886 .06606 .40894 .08118 .40354 .06973 .39342 Mtetra
.655 .751 .92 r
.06973 .39342 .08118 .40354 .09639 .39808 .08499 .38792 Mtetra
.656 .752 .92 r
.08499 .38792 .09639 .39808 .1117 .39253 .10034 .38236 Mtetra
.657 .753 .92 r
.10034 .38236 .1117 .39253 .1271 .38697 .1158 .37671 Mtetra
.657 .752 .92 r
.1158 .37671 .1271 .38697 .14259 .38146 .13134 .37106 Mtetra
.655 .75 .92 r
.13134 .37106 .14259 .38146 .15817 .37591 .14698 .36544 Mtetra
.14698 .36544 .15817 .37591 .17384 .37031 .16271 .3598 Mtetra
.16271 .3598 .17384 .37031 .18962 .36463 .17853 .3541 Mtetra
.656 .752 .921 r
.17853 .3541 .18962 .36463 .2055 .35887 .19446 .34835 Mtetra
.657 .753 .921 r
.19446 .34835 .2055 .35887 .22148 .35309 .21049 .34251 Mtetra
.657 .754 .921 r
.21049 .34251 .22148 .35309 .23754 .34734 .22663 .33662 Mtetra
.657 .752 .92 r
.22663 .33662 .23754 .34734 .25371 .34157 .24286 .33072 Mtetra
.655 .75 .92 r
.24286 .33072 .25371 .34157 .26997 .33577 .25918 .32482 Mtetra
.655 .75 .919 r
.25918 .32482 .26997 .33577 .28634 .32993 .27561 .3189 Mtetra
.655 .749 .919 r
.27561 .3189 .28634 .32993 .30281 .32405 .29215 .31295 Mtetra
.29215 .31295 .30281 .32405 .31939 .31812 .30879 .30695 Mtetra
.30879 .30695 .31939 .31812 .33607 .31214 .32553 .30091 Mtetra
.655 .75 .919 r
.32553 .30091 .33607 .31214 .35286 .30612 .34238 .29483 Mtetra
.656 .75 .919 r
.34238 .29483 .35286 .30612 .36975 .30005 .35934 .28871 Mtetra
.656 .75 .92 r
.35934 .28871 .36975 .30005 .38675 .29395 .37641 .28253 Mtetra
.656 .75 .919 r
.37641 .28253 .38675 .29395 .40386 .28782 .39358 .27632 Mtetra
.39358 .27632 .40386 .28782 .42108 .28164 .41087 .27005 Mtetra
.41087 .27005 .42108 .28164 .43841 .27542 .42827 .26374 Mtetra
.42827 .26374 .43841 .27542 .45585 .26914 .44579 .25738 Mtetra
.44579 .25738 .45585 .26914 .47341 .26281 .46341 .25099 Mtetra
.46341 .25099 .47341 .26281 .49108 .25643 .48115 .24455 Mtetra
.48115 .24455 .49108 .25643 .50886 .25002 .49901 .23808 Mtetra
.655 .75 .92 r
.49901 .23808 .50886 .25002 .52676 .24356 .51699 .23161 Mtetra
.654 .751 .921 r
.51699 .23161 .52676 .24356 .54477 .23708 .53508 .22513 Mtetra
.655 .753 .922 r
.53508 .22513 .54477 .23708 .56291 .23063 .55329 .21859 Mtetra
.656 .753 .921 r
.55329 .21859 .56291 .23063 .58116 .22415 .57163 .21195 Mtetra
.657 .752 .92 r
.57163 .21195 .58116 .22415 .59954 .21757 .59008 .20525 Mtetra
.657 .751 .919 r
.59008 .20525 .59954 .21757 .61803 .21091 .60866 .19848 Mtetra
.60866 .19848 .61803 .21091 .63665 .20418 .62736 .19168 Mtetra
.655 .75 .92 r
.62736 .19168 .63665 .20418 .65539 .19741 .64619 .1849 Mtetra
.654 .751 .921 r
.64619 .1849 .65539 .19741 .67426 .19067 .66515 .17811 Mtetra
.656 .752 .921 r
.66515 .17811 .67426 .19067 .69326 .18391 .68423 .17122 Mtetra
.656 .752 .92 r
.68423 .17122 .69326 .18391 .71239 .17706 .70345 .16425 Mtetra
.657 .751 .92 r
.70345 .16425 .71239 .17706 .73164 .17012 .72279 .1572 Mtetra
.655 .751 .92 r
.04293 .38869 .05456 .39886 .06973 .39342 .05815 .38316 Mtetra
.655 .75 .92 r
.05815 .38316 .06973 .39342 .08499 .38792 .07345 .37763 Mtetra
.655 .751 .92 r
.07345 .37763 .08499 .38792 .10034 .38236 .08886 .37203 Mtetra
.656 .752 .92 r
.08886 .37203 .10034 .38236 .1158 .37671 .10436 .36637 Mtetra
.657 .753 .921 r
.10436 .36637 .1158 .37671 .13134 .37106 .11996 .36063 Mtetra
.657 .752 .92 r
.11996 .36063 .13134 .37106 .14698 .36544 .13566 .35487 Mtetra
.655 .75 .92 r
.13566 .35487 .14698 .36544 .16271 .3598 .15144 .34914 Mtetra
.15144 .34914 .16271 .3598 .17853 .3541 .16732 .34339 Mtetra
.16732 .34339 .17853 .3541 .19446 .34835 .18331 .3376 Mtetra
.655 .751 .92 r
.18331 .3376 .19446 .34835 .21049 .34251 .19939 .33176 Mtetra
.656 .752 .921 r
.19939 .33176 .21049 .34251 .22663 .33662 .21558 .32586 Mtetra
.657 .754 .921 r
.21558 .32586 .22663 .33662 .24286 .33072 .23187 .31988 Mtetra
.23187 .31988 .24286 .33072 .25918 .32482 .24826 .31386 Mtetra
.657 .752 .92 r
.24826 .31386 .25918 .32482 .27561 .3189 .26476 .30781 Mtetra
.656 .751 .92 r
.26476 .30781 .27561 .3189 .29215 .31295 .28135 .30175 Mtetra
.656 .75 .92 r
.28135 .30175 .29215 .31295 .30879 .30695 .29806 .29567 Mtetra
.656 .75 .919 r
.29806 .29567 .30879 .30695 .32553 .30091 .31486 .28955 Mtetra
.31486 .28955 .32553 .30091 .34238 .29483 .33178 .28339 Mtetra
.33178 .28339 .34238 .29483 .35934 .28871 .34881 .27719 Mtetra
.34881 .27719 .35934 .28871 .37641 .28253 .36594 .27094 Mtetra
.36594 .27094 .37641 .28253 .39358 .27632 .38319 .26465 Mtetra
.38319 .26465 .39358 .27632 .41087 .27005 .40054 .25832 Mtetra
.40054 .25832 .41087 .27005 .42827 .26374 .41801 .25194 Mtetra
.41801 .25194 .42827 .26374 .44579 .25738 .4356 .24553 Mtetra
.655 .75 .92 r
.4356 .24553 .44579 .25738 .46341 .25099 .4533 .23909 Mtetra
.655 .751 .92 r
.4533 .23909 .46341 .25099 .48115 .24455 .47111 .23263 Mtetra
.655 .752 .921 r
.47111 .23263 .48115 .24455 .49901 .23808 .48904 .22614 Mtetra
.655 .753 .922 r
.48904 .22614 .49901 .23808 .51699 .23161 .5071 .2196 Mtetra
.656 .753 .922 r
.5071 .2196 .51699 .23161 .53508 .22513 .52527 .21298 Mtetra
.656 .753 .921 r
.52527 .21298 .53508 .22513 .55329 .21859 .54356 .20629 Mtetra
.657 .751 .92 r
.54356 .20629 .55329 .21859 .57163 .21195 .56197 .19955 Mtetra
.657 .751 .919 r
.56197 .19955 .57163 .21195 .59008 .20525 .58051 .19275 Mtetra
.656 .75 .919 r
.58051 .19275 .59008 .20525 .60866 .19848 .59917 .18592 Mtetra
.655 .75 .92 r
.59917 .18592 .60866 .19848 .62736 .19168 .61796 .17911 Mtetra
.655 .752 .921 r
.61796 .17911 .62736 .19168 .64619 .1849 .63688 .17227 Mtetra
.656 .753 .921 r
.63688 .17227 .64619 .1849 .66515 .17811 .65592 .16534 Mtetra
.656 .752 .92 r
.65592 .16534 .66515 .17811 .68423 .17122 .67509 .15833 Mtetra
.657 .751 .92 r
.67509 .15833 .68423 .17122 .70345 .16425 .69439 .15125 Mtetra
.656 .751 .919 r
.69439 .15125 .70345 .16425 .72279 .1572 .71383 .14415 Mtetra
.657 .752 .92 r
.03116 .37846 .04293 .38869 .05815 .38316 .04644 .37281 Mtetra
.655 .751 .92 r
.04644 .37281 .05815 .38316 .07345 .37763 .0618 .36719 Mtetra
.655 .75 .92 r
.0618 .36719 .07345 .37763 .08886 .37203 .07725 .36155 Mtetra
.655 .751 .92 r
.07725 .36155 .08886 .37203 .10436 .36637 .0928 .35586 Mtetra
.656 .752 .92 r
.0928 .35586 .10436 .36637 .11996 .36063 .10845 .3501 Mtetra
.657 .753 .921 r
.10845 .3501 .11996 .36063 .13566 .35487 .1242 .34428 Mtetra
.1242 .34428 .13566 .35487 .15144 .34914 .14005 .33841 Mtetra
.656 .751 .92 r
.14005 .33841 .15144 .34914 .16732 .34339 .15599 .33255 Mtetra
.655 .75 .92 r
.15599 .33255 .16732 .34339 .18331 .3376 .17203 .32669 Mtetra
.17203 .32669 .18331 .3376 .19939 .33176 .18817 .3208 Mtetra
.18817 .3208 .19939 .33176 .21558 .32586 .20441 .31485 Mtetra
.655 .751 .92 r
.20441 .31485 .21558 .32586 .23187 .31988 .22075 .30886 Mtetra
.656 .752 .921 r
.22075 .30886 .23187 .31988 .24826 .31386 .2372 .30282 Mtetra
.656 .753 .921 r
.2372 .30282 .24826 .31386 .26476 .30781 .25376 .29672 Mtetra
.657 .754 .922 r
.25376 .29672 .26476 .30781 .28135 .30175 .27042 .29057 Mtetra
.656 .753 .921 r
.27042 .29057 .28135 .30175 .29806 .29567 .28719 .28439 Mtetra
.28719 .28439 .29806 .29567 .31486 .28955 .30407 .27817 Mtetra
.656 .752 .921 r
.30407 .27817 .31486 .28955 .33178 .28339 .32105 .27192 Mtetra
.656 .752 .92 r
.32105 .27192 .33178 .28339 .34881 .27719 .33814 .26563 Mtetra
.656 .751 .92 r
.33814 .26563 .34881 .27719 .36594 .27094 .35534 .25931 Mtetra
.35534 .25931 .36594 .27094 .38319 .26465 .37266 .25295 Mtetra
.655 .752 .921 r
.37266 .25295 .38319 .26465 .40054 .25832 .39009 .24656 Mtetra
.39009 .24656 .40054 .25832 .41801 .25194 .40763 .24014 Mtetra
.40763 .24014 .41801 .25194 .4356 .24553 .42528 .23367 Mtetra
.655 .753 .922 r
.42528 .23367 .4356 .24553 .4533 .23909 .44306 .22717 Mtetra
.44306 .22717 .4533 .23909 .47111 .23263 .46095 .22062 Mtetra
.656 .753 .922 r
.46095 .22062 .47111 .23263 .48904 .22614 .47895 .214 Mtetra
.656 .752 .921 r
.47895 .214 .48904 .22614 .5071 .2196 .49708 .20733 Mtetra
.656 .751 .92 r
.49708 .20733 .5071 .2196 .52527 .21298 .51533 .20059 Mtetra
.657 .751 .919 r
.51533 .20059 .52527 .21298 .54356 .20629 .53371 .19381 Mtetra
.657 .75 .919 r
.53371 .19381 .54356 .20629 .56197 .19955 .5522 .18698 Mtetra
.656 .75 .919 r
.5522 .18698 .56197 .19955 .58051 .19275 .57082 .18014 Mtetra
.655 .751 .92 r
.57082 .18014 .58051 .19275 .59917 .18592 .58957 .1733 Mtetra
.655 .752 .921 r
.58957 .1733 .59917 .18592 .61796 .17911 .60844 .16641 Mtetra
.656 .753 .921 r
.60844 .16641 .61796 .17911 .63688 .17227 .62744 .15943 Mtetra
.656 .752 .92 r
.62744 .15943 .63688 .17227 .65592 .16534 .64657 .15238 Mtetra
.657 .751 .92 r
.64657 .15238 .65592 .16534 .67509 .15833 .66583 .14526 Mtetra
.656 .751 .919 r
.66583 .14526 .67509 .15833 .69439 .15125 .68522 .13811 Mtetra
.655 .751 .92 r
.68522 .13811 .69439 .15125 .71383 .14415 .70475 .13097 Mtetra
.657 .752 .92 r
.01926 .3681 .03116 .37846 .04644 .37281 .03458 .3624 Mtetra
.03458 .3624 .04644 .37281 .0618 .36719 .05 .35665 Mtetra
.655 .751 .92 r
.05 .35665 .0618 .36719 .07725 .36155 .06551 .35093 Mtetra
.655 .75 .92 r
.06551 .35093 .07725 .36155 .0928 .35586 .08111 .34519 Mtetra
.655 .751 .92 r
.08111 .34519 .0928 .35586 .10845 .3501 .09681 .3394 Mtetra
.656 .751 .92 r
.09681 .3394 .10845 .3501 .1242 .34428 .11261 .33355 Mtetra
.656 .752 .921 r
.11261 .33355 .1242 .34428 .14005 .33841 .12851 .32764 Mtetra
.657 .753 .921 r
.12851 .32764 .14005 .33841 .15599 .33255 .14451 .32167 Mtetra
.657 .752 .92 r
.14451 .32167 .15599 .33255 .17203 .32669 .16061 .31567 Mtetra
.655 .75 .92 r
.16061 .31567 .17203 .32669 .18817 .3208 .17681 .30969 Mtetra
.17681 .30969 .18817 .3208 .20441 .31485 .19311 .30367 Mtetra
.19311 .30367 .20441 .31485 .22075 .30886 .20952 .29763 Mtetra
.20952 .29763 .22075 .30886 .2372 .30282 .22603 .29153 Mtetra
.655 .751 .92 r
.22603 .29153 .2372 .30282 .25376 .29672 .24264 .2854 Mtetra
.656 .751 .92 r
.24264 .2854 .25376 .29672 .27042 .29057 .25936 .27921 Mtetra
.656 .752 .921 r
.25936 .27921 .27042 .29057 .28719 .28439 .27619 .27298 Mtetra
.656 .753 .921 r
.27619 .27298 .28719 .28439 .30407 .27817 .29313 .26671 Mtetra
.656 .753 .922 r
.29313 .26671 .30407 .27817 .32105 .27192 .31018 .2604 Mtetra
.31018 .2604 .32105 .27192 .33814 .26563 .32734 .25404 Mtetra
.656 .754 .922 r
.32734 .25404 .33814 .26563 .35534 .25931 .34462 .24764 Mtetra
.34462 .24764 .35534 .25931 .37266 .25295 .362 .24121 Mtetra
.656 .753 .922 r
.362 .24121 .37266 .25295 .39009 .24656 .3795 .23473 Mtetra
.3795 .23473 .39009 .24656 .40763 .24014 .39711 .2282 Mtetra
.656 .753 .921 r
.39711 .2282 .40763 .24014 .42528 .23367 .41484 .22163 Mtetra
.656 .752 .921 r
.41484 .22163 .42528 .23367 .44306 .22717 .43269 .21501 Mtetra
.656 .752 .92 r
.43269 .21501 .44306 .22717 .46095 .22062 .45066 .20834 Mtetra
.656 .751 .92 r
.45066 .20834 .46095 .22062 .47895 .214 .46874 .20162 Mtetra
.656 .751 .919 r
.46874 .20162 .47895 .214 .49708 .20733 .48695 .19485 Mtetra
.656 .75 .919 r
.48695 .19485 .49708 .20733 .51533 .20059 .50528 .18803 Mtetra
.50528 .18803 .51533 .20059 .53371 .19381 .52373 .18119 Mtetra
.655 .75 .92 r
.52373 .18119 .53371 .19381 .5522 .18698 .54231 .17434 Mtetra
.655 .751 .921 r
.54231 .17434 .5522 .18698 .57082 .18014 .56101 .16746 Mtetra
.655 .752 .921 r
.56101 .16746 .57082 .18014 .58957 .1733 .57984 .16051 Mtetra
.656 .752 .921 r
.57984 .16051 .58957 .1733 .60844 .16641 .5988 .15348 Mtetra
.656 .752 .92 r
.5988 .15348 .60844 .16641 .62744 .15943 .61789 .14639 Mtetra
.657 .751 .92 r
.61789 .14639 .62744 .15943 .64657 .15238 .6371 .13923 Mtetra
.656 .751 .919 r
.6371 .13923 .64657 .15238 .66583 .14526 .65645 .13205 Mtetra
.655 .751 .92 r
.65645 .13205 .66583 .14526 .68522 .13811 .67594 .12486 Mtetra
.655 .752 .921 r
.67594 .12486 .68522 .13811 .70475 .13097 .69557 .11763 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
[(-2)] .12586 .2075 1 .99877 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.56863 .04703 m
.57247 .05235 L
s
[(2)] .56094 .0364 .72324 1 Mshowa
.125 Mabswid
.18558 .19702 m
.18832 .19985 L
s
.23703 .17687 m
.23971 .17975 L
s
.28951 .15632 m
.29214 .15925 L
s
.39772 .11395 m
.40023 .11699 L
s
.4535 .09211 m
.45595 .0952 L
s
.51046 .06981 m
.51284 .07294 L
s
.08568 .23614 m
.08851 .23887 L
s
.62804 .02377 m
.63027 .02701 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 233.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00o?ooool2o`0006[ooooo003iooooo`?o000000?oooooo`000?ooool0
JOooool00?Oooooo0_l00004ooooo`;o0000JOooool00?Cooooo0ol00006ooooo`03o`000?oooooo
000006Sooooo003;ooooo`Go00008_ooool2o`0000Wooooo00?o0000ooooool00000J?ooool00<_o
oooo00GoV9RHob4Q8Oo^k^koooooodA4A00Oooooo`?o00002oooool01?l0003oooooooooool0001W
ooooo`00c?ooool00onHV9So8B4Qonk^kP0Mooooo`?o00003_ooool01Ol0003ooooooooooooooooo
000006Kooooo003=ooooo`03oiRHV?lQ8B7ok^k^01[ooooo0_l0000Aooooo`05o`000?oooooooooo
ooooool00000I_ooool00<kooooo00?oMgMgofIVI_ooool05_ooool3o`0001?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1Sooooo`00coooool00ol0003oooooooooo`0Cooooo`;o
00000_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0H_ooool00<_ooooo00Go0000okZj^_ooooooV9RHoa0@400Booooo`?o00006Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo06;ooooo003;ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`04?ooool2o`0001cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Qooooo`00
gOooool3o`0001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Qooooo`00fooo
ool2o`00027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Pooooo`00f?ooool3
o`0002?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Oooooo`00eOooool3o`00
02Kooooo00?o0000ooooooooool01?ooool2o`00067ooooo003Cooooo`;o0000:Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo05kooooo003@ooooo`?o000000?oooooo`000?ooool0
:?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05gooooo003>ooooo`;o00001Ooo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0GOoo
ool00<_ooooo0ol0000`ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0G?ooool0
0<Wooooo0_l0000cooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Foooool00<Ko
oooo0ol0000eooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Foooool00<Cooooo
0_l0000hooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0F_ooool00<7ooooo0ol0
000jooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03_ooool5o`0004Kooooo002n
ooooo`?o0000?Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00kooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A016ooooo`00_?ooool2o`0000?ooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo1_l00003ooooo`03oiRHV?lQ8B7o
k^k^04Oooooo002iooooo`?o0000@oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00kooooo00?oV9RHob4Q8Oo^k^h0A_ooool00;Oooooo0_l00016ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03oooool00omgMgOoIVIVooooo`15ooooo`00]?ooool3o`0004Sooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Cooooo
002booooo`;o0000Boooool00ol0003oooooooooo`0=ooooo`;o00003?ooool01Ol0003o^[Zjoooo
oonHV9So410@04Kooooo002_ooooo`?o0000COooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c016ooooo`00[Oooool2o`00053ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`1Dooooo`00Z_ooool4o`00057ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1Dooooo`00Z?ooool2o`0000Cooooo00?o0000oooo
ooooool0C_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05?ooooo001nooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h08_ooool3o`0005Oooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`1Booooo`00O_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01oooooo0ol0001Joooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool0D_ooool007kooooo00Go410@oooooooo
oooooooooa0@400Mooooo`;o0000GOooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
057ooooo001nooooo`05o`000?ooooooooooooooool000006_ooool3o`0005oooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`1@ooooo`00O_ooool01Ol0003ooooooooooooooooo0000
01Sooooo0_l0001Rooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0D?ooool007ko
oooo00Go410@oooooooooooooooooa0@400Eooooo`?o0000I?ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo04oooooo001nooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool2o`00
00?ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
04kooooo001nooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04?ooool3o`0006Sooooo00?oYl3[o`00
0?ooool05_ooool00ol0003oooooooooo`1>ooooo`00TOooool2o`0006Sooooo1?nW`>/00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo04gooooo002>ooooo`?o0000J?ooool7ojO0j`03o`00
0?oooooooooo01Cooooo0ol0001>ooooo`00Roooool3o`0006Wooooo2OnW`>/00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo04cooooo0029ooooo`;o0000JOooool<ojO0j`03o`000?nW`>_o
oooo01Oooooo00?o0000ooooooooool0Boooool008Kooooo0ol0001Xooooo`ooYl3[00?o0000ojO0
joooool06?ooool00ol0003oooooooooo`1:ooooo`00Q?ooool2o`0000;ooooo00?o0000oooooooo
ool0HooooolBojO0j`03o`000?nW`>_oYl3[01Sooooo00?o0000ooooooooool0B_ooool0087ooooo
0ol00005ooooo`03o`000?oooooooooo063ooooo5?nW`>/01?l0003oYl3[ojO0jonW`>/Hooooo`03
o`000?oooooooooo04Wooooo001oooooo`;o0000JOooool00onX`>_oYl3[ojO0j`0CojO0j`03o`00
0?nW`>_oYl3[00;oYl3[6?ooool00ol0003oooooooooo`18ooooo`00O?ooool3o`0006Sooooo1OnX
`>/DojO0j`03o`000?nW`>_oYl3[00;oYl3[6?ooool00ol0003oooooooooo`18ooooo`00N_ooool2
o`0006Oooooo0_nW`>/8ojS0j`KoYl3[0_nX`>/;ojO0j`03o`000?nW`>_oYl3[00?oYl3[6?ooool0
0ol0003oooooooooo`17ooooo`00Moooool3o`0006Kooooo1_nW`>/8ojS0j`;oYl3[1_nX`>/:ojO0
j`03o`000?nW`>_oYl3[00CoYl3[6?ooool00ol0003oooooooooo`16ooooo`00M?ooool3o`0006Ko
oooo2_nW`>/6ojS0j`;oYl3[2?nX`>/6ojO0j`;oZ<3[00?oYl3[o`000?nW`>/01OnW`>/Hooooo`03
o`000?oooooooooo04Kooooo001booooo`;o00000_ooool00ol0003oooooooooo`1Rooooo`goYl3[
0_nX`>/6ojO0j`SoZ<3[0_nW`>/6ojS0j`03o`000?nW`>_oYl3[00GoYl3[6?ooool00ol0003ooooo
ooooo`15ooooo`00Koooool3o`0006Oooooo6?nW`>/6ojS0j`03ojO0jonX`>_oZ<3[00KoZ<3[00?o
0000ojO0jonW`>/01?nW`>/00onX`>_oooooooooo`0Fooooo`03o`000?oooooooooo04Gooooo001]
ooooo`;o0000IooooolLojO0j`;oZ<3[1OnW`>/7ojS0j`04o`000?nX`>_oYl3[ojO0j`GoZ<3[5ooo
ool2o`0004Kooooo001Zooooo`?o0000I_oooolWojO0j`KoZ<3[00?o0000ojO0jonX`>/01onX`>/H
ooooo`03o`000?oooooooooo04?ooooo001Xooooo`;o0000I_ooool[ojO0j`;oZ<3[0onW`>/00ol0
003oYl3[ojO0j`08ojS0jaOooooo00?o0000ooooooooool0@oooool006Gooooo0ol0001Uoooooc?o
Yl3[00Co0000ojO0jonW`>_oYl3[1_nX`>/00onW`>_oooooooooo`0Fooooo`03o`000?oooooooooo
04;ooooo001Sooooo`;o0000IOooool00onW_n_oYl3[ojO0j`0dojO0j`04o`000?nW`>_oYl3[ojO0
j`;oZ<3[1OnW`>/Hooooo`03o`000?oooooooooo047ooooo001Pooooo`?o000000?oooooo`000?oo
ool0H_ooool4ojNojcGoYl3[00?o0000ojO0jonW`>/02OnW`>/Gooooo`03o`000?oooooooooo047o
oooo000fooooo`Go00008oooool2o`0006Kooooo1onW_n/7ojO0j`03ojNojonW`>_oYl3[00coYl3[
0_nW_n/LojO0j`03o`000?nW`>_oYl3[00[oYl3[5oooool00ol0003oooooooooo`10ooooo`00=_oo
ool01OnHV9So8B4Qonk^k_ooooooA4A4023ooooo0ol0001Uooooo`[oYko[1?nW`>/5ojNoj`[oYl3[
1_nW_n/KojO0j`03o`000?nW`>_oYl3[00[oYl3[6?ooool00ol0003oooooooooo`0oooooo`00;_oo
ool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h07_ooool3o`0006Gooooo3_nW_n/00onW`>_oYko[ojNo
j`06ojNoj`KoYl3[2_nW_n/6ojO0j`03ojNojonW`>_oYl3[017oYl3[00?o0000ojO0jonW`>/02onW
`>/Gooooo`03o`000?oooooooooo03oooooo000hooooo`03oiRHV?lQ8B7ok^k^01_ooooo0_l0001U
oooooa3oYko[0_nX_n/8ojNoj`CoYl3[3OnW_n/2ojO0j`GoYko[4_nW`>/00ol0003oYl3[ojO0j`0<
ojO0jaOooooo00?o0000ooooooooool0?_ooool003Wooooo00?oMgMgofIVI_ooool05oooool3o`00
06Cooooo4?nW_n/6ojRoj`SoYko[00?oYl3[ojNojonW_n/03?nW_n/00onX`>_oYko[ojNoj`06ojNo
j`KoYl3[0_nW_n/9ojO0j`03o`000?nW`>_oYl3[00coYl3[6?ooool00ol0003oooooooooo`0moooo
o`00>_ooool00ol0003oooooooooo`0Dooooo`;o0000I?ooool00onW`>_oYko[ojNoj`0=ojNoj`03
ojS0jonX_n_oZ;o[00OoZ;o[1_nW_n/00onX`>_oYko[ojNoj`0;ojNoj`CoZ<3[2?nW_n/2ojO0j`Ko
Yko[2?nW`>/00ol0003oYl3[ojO0j`0=ojO0jaOooooo00?o0000ooooooooool0?Oooool003Kooooo
00Go0000okZj^_ooooooV9RHoa0@400Cooooo`?o00000_ooool00ol0003oooooooooo`1Oooooo`Co
Yl3[2onW_n/5ojS0j`WoZ;o[0_nW_n/5ojS0j`[oYko[1onX`>/6ojNoj`03ojS0jonW_n_oYko[00Oo
Yko[1_nW`>/00onW_n_o0000ojO0j`0>ojO0jaSooooo00?o0000ooooooooool0??ooool003Kooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c00Aooooo`;o0000IOooool7ojO0j`OoYko[00?oYl3[ojS0jonX
`>/01_nX`>/6ojRoj`[oZ<3[1_nW_n/:ojS0j`CoYko[1?nX`>/9ojNoj`;oYl3[1?nW_n/00ol0003o
Yl3[ojO0j`0>ojO0jaKooooo0ol0000mooooo`00BOooool3o`0006Gooooo2_nW`>/4ojNoj`CoYl3[
2?nX`>/2ojRoj`koZ<3[0_nW_n/>ojS0j`03ojNojonX`>_oZ<3[00GoZ<3[1onW_n/00onX`>_oYko[
ojNoj`04ojNoj`03o`000?nW_n_oYl3[00GoYl3[0_nW_n/8ojO0jaOooooo00?o0000ooooooooool0
>oooool004Oooooo0_l0001Uooooo`koYl3[00?oYko[ojO0jonW`>/01OnW`>/6ojS0j`;oYl3[9onX
`>/4ojNoj`GoZ<3[1OnW_n/00ol0003oYko[ojNoj`02ojO0j`KoYko[2?nW`>/Gooooo`03o`000?oo
oooooooo03[ooooo0014ooooo`?o0000I?oooolIojO0j`CoZ<3[1OnW`>/WojS0j`03ojNojonX`>_o
Z<3[00KoZ<3[1?nW_n/00ol0003oYko[ojS0j`09ojNoj`OoYl3[6?ooool00ol0003oooooooooo`0i
ooooo`00@Oooool3o`0006Cooooo7OnW`>/00onX`>_oYl3[ojO0j`06ojO0j`KoZ<3[00?oYl3[ojS0
jonX`>/03?nX`>/2ojO0jaWoZ<3[0_nW_n/00onX`>_o0000ojS0j`02ojS0j`WoYko[1onW`>/Goooo
o`03o`000?oooooooooo03Wooooo000oooooo`?o0000Hoooool?ojO0j`;oYl3/3_nW`>/2ojO0k0Wo
Yl3[0_nX`>/5ojO0j`[oZ<3[1_nW`>/KojS0j`03o`000?nX`>_oZ<3[00;oZ<3[1_nW_n/:ojO0jaOo
oooo00?o0000ooooooooool0>?ooool003cooooo0ol00003ooooo`03o`000?oooooooooo05kooooo
3_nW`>/6ojO0k0[oYl3[1_nW`>`7ojO0j`03ojO0k?nW`>_oYl3[00KoYl3[1_nX`>/2ojO0k0SoYl3[
1_nX`>/00onW`>_oZ<3[ojS0j`0AojS0j`03o`000?nX`>_oZ<3[00?oZ<3[0_nW_n/>ojO0jaKooooo
00?o0000ooooooooool01oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02cooooo000jooooo`;o0000
IOooool=ojO0j`[oYl3/1_nW`>/:ojO0k0CoYl3[1?nW`>`8ojO0j`;oZ<3[1_nW`>`8ojO0j`;oZ<3[
1OnW`>/BojS0j`03o`000?nX`>_oZ<3[00?oZ<3[3onW`>/00onW_n_oooooooooo`0Eooooo`03o`00
0?oooooooooo00Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0/ooooo`00=oooool3o`0006Gooooo
3?nW`>/>ojO0k0;oYl3[3_nW`>`00onW`>_oYl3/ojO0k005ojO0k0OoYl3[2OnW`>`6ojO0j`03ojO0
k?nW`>_oYl3[00KoYl3[1_nX`>/2ojO0j`[oZ<3[00?o0000ojS0jonX`>/00onX`>/;ojO0j`GoYko[
5oooool00ol0003oooooooooo`05ooooo`05oa0@4?ooooooooooooooool@4100;?ooool003Gooooo
0_l0001Uooooo`coYl3[4?nW`>`00onW`>_oYl3/ojO0k00<ojO0k0;oYl3[2?nW`>`8ojO0j`WoYl3/
0_nW`>/5ojO0k0SoYl3[0_nX`>/6ojO0j`WoZ<3[00?o0000ojS0jonX`>/01?nX`>/6ojO0j`;oZ<3[
2?nW_n/Fooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`00000/ooooo`00
<_ooool3o`0006Cooooo00?oYl3/ojO0jonW`>/02_nW`>/?ojO0k0GoYl3[2_nW`>`6ojO0j`SoYl3/
2?nW`>/6ojO0k0;oYl3[2?nW`>`6ojO0j`03ojO0k?nW`>_oYl3[00OoYl3[2?nX`>/00ol0003oZ<3[
ojS0j`05ojS0j`;oYl3[1_nX`>/8ojNojaKooooo00?o0000ooooooooool01?ooool01Ol0003ooooo
oooooooooooo000002cooooo000`ooooo`;o0000I?ooool5ojO0k0WoYl3[3_nW`>`9ojO0j`KoYl3/
0_nW_n/8ojO0j`KoYl3/00?oYko[ojO0jonW`>/01onW`>/2ojO0k0KoYl3[2?nW`>`2ojO0j`GoYl3/
2OnW`>/7ojS0j`03o`000?nX`>_oZ<3[00goZ<3[1_nW_n/2ojS0jaOooooo00?o0000ooooooooool0
0oooool01Ol@413ooooooooooooooooo410@02cooooo000]ooooo`?o000000?oooooo`000?ooool0
H?ooool9ojO0k0SoYl3[2onW`>`=ojO0j`;oYl3/1_nW_n/8ojO0j`;oYl3/1OnW_n/7ojO0j`;oYko[
2?nW`>/6ojO0k003ojO0jonW`>coYl3/00KoYl3/1_nW`>/2ojO0k0OoZ<3[00?o0000ojS0jonX`>/0
3_nX`>/2ojNoj`KoZ<3[5_ooool2o`0000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0/ooooo`00
:_ooool3o`0006?ooooo3OnW`>`8ojO0j`OoYl3/00?oYko[ojO0jonW`>/03?nW`>/:ojNoj`KoYl3[
2OnW_n/4ojO0j`GoYko[2?nW`>/2ojO0k0GoYl3[2?nW`>`2ojO0j`KoYl3/1_nX`>/00ol0003oZ<3[
ojS0j`0GojS0ja?ooooo0_l000000ooooooo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h0;?ooool002Sooooo0_l0001Sooooo`03ojO1k?nW`>coYl3/00coYl3/2_nW`>/4ojO0k0CoYko[
2_nW`>/>ojNoj`;oYl3[3OnW_n/00onW`>_oYko[ojNoj`06ojNoj`KoYl3[00?oYko[ojO0jonW`>/0
1_nW`>/6ojO0k003ojO0jonW`>coYl3/00OoYl3/1OnX`>/00ol0003oYl3[ojS0j`0HojS0jaKooooo
00?o0000ooooooooool0<_ooool002Gooooo0ol0001Rooooo`GoYl7/2_nW`>`>ojO0j`03ojO0k?nW
_n_oYko[00GoYko[1_nW`>/@ojNoj`03ojRojonW_n_oYko[00coYko[00?oZ;o[ojNojonW_n/02?nW
_n/2ojO0j`GoYko[2?nW`>/2ojO0k0GoYl3[2OnW`>`2ojS0j`03ojO0jol0003o000000;oYl3[6?nX
`>/Fooooo`03o`000?oooooooooo03;ooooo000Sooooo`;o0000H_ooool9ojO1k0KoYl3/4?nW`>/9
ojNoj`CoYl3[3onW_n/5ojRoj`[oYko[1OnX_n/8ojNoj`03ojRojonW_n_oYko[00KoYko[1_nW`>/0
0onW_n_oYl3[ojO0j`06ojO0j`KoYl3/0_nW`>/3o`000003ojO0jol0003oYl3[00;oYl3[1_nX`>/0
0onW`>_oZ<3[ojS0j`0?ojS0jaKooooo00?o0000ooooooooool0<Oooool0023ooooo0ol0001Roooo
o`coYl7/0_nW`>`@ojO0j`goYko[00?oYl3[ojNojonW_n/03?nW_n/9ojRoj`KoYko[2OnX_n/4ojNo
j`GoZ;o[2?nW_n/2ojO0j`GoYko[2?nW`>/2ojO0k0;oYl3[0ol00005ojO0j`04o`000?nW`>_oYl3[
ojO0j`;oZ<3[1OnW`>/@ojS0jaOooooo00?o0000ooooooooool0<?ooool001oooooo0_l0001Roooo
o`goYl7/4?nW`>/LojNoj`goZ;o[0_nW_n/=ojRoj`03ojNojonX_n_oZ;o[00KoZ;o[1_nW_n/00onX
_n_oYko[ojNoj`06ojNoj`KoYl3[00?oYko[ojO0jol000000_l00009ojO0j`03o`000?nW`>coYl3/
00SoYl3[4?nX`>/Fooooo`03o`000?oooooooooo033ooooo000Oooooo`03o`000?oooooo000005oo
oooo0onW`>`9ojO1k13oYl3[7?nW_n/00onX`>_oZ;o[ojRoj`0<ojRoj`03ojS0jonX_n_oZ;o[00co
Z;o[0_nX`>/8ojRoj`CoYko[1?nX_n/8ojNoj`;oYl3[0_nW_n/3o`0000[oYl3[0onW`>`00ol0003o
Yl3/ojO0k008ojO0j`ooZ<3[5oooool00ol0003oooooooooo`0_ooooo`003?ooool5o`0000?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`04o`000?ooooooooooo`0005_ooooo1onW`>`5ojO1
k13oYl3[7OnW_n/4ojS0j`[oZ;o[1OnX`>/:ojRoj`KoZ<3[2?nX_n/00onW_n_oZ;o[ojRoj`05ojRo
j`KoYko[00?oZ;o[ojNojol000000_l00004ojNoj`KoYl3[00?oYko[ojO0k?nW`>`00onW`>`01?l0
003oYl3/ojO0k?nW`>`7ojO0ja3oZ<3[5oooool00ol0003oooooooooo`0^ooooo`003?ooool01OnH
V9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`;o00000_oo
ool00ol0003oooooooooo`1Eooooo`_oYl3/00?oYl7/ojO0jonW`>/03_nW`>/NojNoj`OoZ<3[1_nX
_n/9ojS0j`KoZ;o[2_nX`>/6ojRoj`;oZ<3[2?nX_n/2ojNoj`;oZ;o[0ol00008ojNoj`;oYl3[1OnW
_n/5ojO0k004o`000?nW`>coYl3/ojO0k0OoYl3[1onX`>/00onW`>_oZ<3[ojS0j`06ojS0jaKooooo
00?o0000ooooooooool0;_ooool000Cooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go
410@oooooooooooooooooa0@4005ooooo`;o00001?ooool00ol0003oooooooooo`1Aooooo`goYl3/
3onW`>/OojNoj`;oYl3[2?nX`>/2ojRoj`goZ<3[0_nX_n/>ojS0j`;oZ;o[1_nX`>/6ojRoj`03ojS0
jonX_n_o000000;o00001?nX_n/6ojNoj`03ojS0jonW_n_oYko[00KoYko[1OnW`>`00ol0003oYko[
ojNoj`08ojO0j`CoZ<3[1?nW`>/8ojS0jaKooooo00?o0000ooooooooool0;Oooool000kooooo00?o
V9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`1=ooooo`;oYl3[3?nW`>`>ojO0jaooYko[1_nW`>/6ojS0j`03ojO1
k?nX`>_oZ<3[00coZ<3[00?oYl7/ojS0jonX`>/03?nX`>/2ojS1j`WoZ<3[0_nX_n/3ojS0j`;o0000
2?nX_n/2ojNoj`GoZ<3[2?nW_n/2ojO0k0;oYko[00Co0000ojNojonW_n_oYko[2?nW`>/00onX`>_o
Yl3[ojO0j`05ojO0j`OoZ<3[5oooool00ol0003oooooooooo`0/ooooo`003oooool00omgMgOoIVIV
ooooo`02ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo04Wooooo1_nW`>/9ojO0k0goYl3[7onW_n/:ojO0j`;oZ<3[1OnW`N`:ojS0j`Go
Yl7/2_nX`>/6ojS1j`OoZ<3[00?oZ<7/ojS0jonX`>/00ol00003ojS0j`KoZ;o[2OnX`>/6ojNoj`03
ojS0jonW_n_oYko[00?oYko[00?o0000ojNojonW_n/04OnW`>/7ojS0jaGooooo0_l0000^ooooo`00
4?ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool00oooool2o`0000Oo
oooo00?o0000ooooooooool0A_ooool9ojO0j`KoYl3/3?nW`>/OojNoj`coYl3[2OnW`N`6ojS0j`03
ojO0k?nW`NcoYl7/00KoYl7/1_nX`>/2ojO0k0SoZ<7[1?nX`>/2ojS1k0?o00001onX`>/2ojRoj`go
Z<3[0_nW_n/5ojS0j`GoYko[00?o0000ojNojonW_n/04?nW`>/8ojS0jaKooooo00?o0000oooooooo
ool0:oooool000cooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04;ooooo3OnW`>/2ojO0
k0coYl3[7onW_n/00onW`NcoYl3[ojO0j`0:ojO0j`coYl7/0_nX`>/5ojO0k0SoYl7/0_nX`>/6ojO0
k0SoZ<7[00?oZ<3[ojS1k?l000000_l00003ojS1k0KoZ<3[00?oZ<7[ojS0jonX`>/05OnX`>/5ojNo
j`03o`000?nW`>_oYl3[013oYl3[2?nX`>/Eooooo`03o`000?oooooooooo02_ooooo000<ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0noooooacoYl3[7_nW_n/5ojO1k0WoYl3[3OnW`N`0
0onW`>_oYl3/ojO0k006ojO0k0KoYl7/2_nW`>`6ojS1j`?o00001onX`N`2ojS0j`GoZ<7[5onX`>/2
ojNoj`;oYl3[00?o0000ojO0jonW`>/01onW`>/2ojNoj`SoYl3[1_nX`>/00onW`>_oooooooooo`0D
ooooo`03o`000?oooooooooo02[ooooo000Nooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool0>_oooolMojO0jagoYko[2OnW`N`6ojO0j`;oYl3/2_nW`N`5ojO0j`SoYl3/0_nW`N`>ojO0
k0;oZ<7[0ol00003ojO0k0KoZ<7/00?oYl3/ojS1jonX`N/01_nX`N/FojS0j`GoYl3[00?o0000ojO0
jonW`>/00onW`>/6ojNoj`SoYl3[0_nX`>/5ojO0jaKooooo00?o0000ooooooooool0:Oooool001go
oooo0ol0000;ooooo`03o`000?oooooooooo03Kooooo7_nW`>/LojNoj`goYl7/0_nW`>/6ojO0k0Ko
Yl7/2OnW`>/6ojO0k0;oYko[3_nW`>`3o`0000OoYl3/0_nX`N`5ojO0k0SoZ<7[5_nX`>/5ojO0j`03
o`000?nW`>_oZ<3[00SoYko[3onW`>/Fooooo`03o`000?oooooooooo02Wooooo000Mooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool0<_oooolNojO0jacoYko[3onW`N`:ojO0k0;oYl7/
3OnW`>/2ojO0k0KoYko[2_nW`>`3o`0000;oYko[1onW`>`00onW_n_oYl3/ojO0k006ojO0k0KoZ<7[
00?oYl3/ojS0jonX`>/05OnX`>/4ojO0j`04ojS0jol0003oZ<3[ojS0j`SoYko[3onW`>/Fooooo`03
o`000?oooooooooo02Sooooo000Mooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
;oooool00onW_n_oYl3[ojO0j`0<ojO0j`03ojS1k?nW`>_oYl3[00coYl3[6onW_n/?ojO1k0coYl3/
0_nW_n/=ojO0j`[oYko[1_nW`>`3o`0000KoYko[1?nW`>`4ojNoj`SoYl3/0_nX`N/5ojO0k1OoZ<3[
00GoYl3[ojS0jonX`>_oZ<3[o`000003ojS0j`KoYko[4?nW`>/Gooooo`03o`000?oooooooooo02Oo
oooo000Mooooo`;o00003oooool00ol0003oooooooooo`0[ooooo`GoYko[2_nW`>/5ojS1k0[oYl3[
6onW_n/?ojO1k0;oYl3[2_nW`>`6ojNoj`WoYl3[3_nW_n/2ojO0k003ojNojol0003o000000[oYko[
00?oYl3/ojNojonW_n/01OnW_n/6ojO0k003ojNojonW`>coYl3/00KoYl3/1_nX`>/00onW`>coZ<3[
ojS0j`0BojS0j`04o`000?nX`>_oZ<3[ojS0j`;oYko[5?nW`>/Fooooo`03o`000?oooooooooo02Oo
oooo000Mooooo`03o`000?oooooooooo00oooooo0_l0000Xooooo`WoYko[2?nW`>/7ojS1k0KoYl3[
6onW_n/?ojO1k0KoYl3[1_nW`>`:ojNoj`KoYl3[3onW_n/01?nX_n_o0000o`000?l0000EojNoj`;o
Yl3/1OnW_n/8ojO0k0;oZ<3[1OnW`>`DojS0j`03o`000?nX`>_oZ<3[01OoYl3[5_ooool00ol0003o
ooooooooo`0Vooooo`007Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02;ooooo
3OnW_n/8ojO0j`OoZ<7/0_nW`>/KojNoj`ooYl7/2_nW`>/3ojO0k0goYko[0_nW`>/?ojNoj`05ojRo
jol0003o0000o`000?nX_n/07onW_n/6ojO0k003ojNojonW`>coYl3/00KoYl3/1_nX`>/2ojO0j`co
Z<3[00?o0000ojS0jonX`>/05onW`>/Fooooo`03o`000?oooooooooo02Gooooo000Mooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool07_ooool?ojNoj`[oYl3[1OnX`N`2ojO0jaWoYko[
3onW`N`>ojO0j`03ojO0k?nW_n_oYko[00_oYko[00?oZ;oZojNojonW_n/03?nW_n/01?nX_n[o0000
o`000?l00005ojRoj`KoYko[0_nX_nXGojNoj`;oYl3/1OnW_n/8ojO0k0;oZ<3[1_nW`>/;ojS0j`04
o`000?nX`>_oZ<3[ojS0jaKoYl3[5_ooool2o`0002Kooooo000Looooo`?o00005?ooool00ol0003o
ooooooooo`0Jooooo`ooYko[3_nW`>/00onX`NcoYl3[ojO0j`04ojO0jaKoYko[3onW`N`?ojO0j`co
Yko[1OnX_nX:ojNoj`05ojRoj_l0003o0000o`000?nX_nX02?nX_n/2ojNoj`KoZ;oZ1_nW_n/00onX
_n_oYko[ojNoj`0EojNoj`KoYl3/00?oY/3/ojO0jonW`>/01onW`>/;ojS0j`04o`000?nX`>_oZ<3[
ojS0jaKoYl3[5?ooool00ol0003oooooo`00000Vooooo`007?ooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo01Oooooo3onW_n/?ojO0j`03ojS0jonW`>_oYl3[00KoYl3[4_nW_n/?ojO1
k0ooYl3[3?nW_n/9ojRojPKoYko[00CoZ<3[o`000?l0003o00001OnX_nX6ojRoj`;oZ<3[2?nX_nX2
ojNoj`GoZ;o[5onW_n/2ojO0k0GoY/3/1onW`>/00onW`>coZ<3[ojS0j`0:ojS0j`03o`000?nX`>_o
Z<3[00koYl3[00?oYko[ojO0jonW`>/01_nW`>/Fooooo`03o`000?oooooooooo02?ooooo000:oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`0Cooooo`ooYko[3onW`>/5ojS0j`SoYl3[3_nW_n/00onW`>coYl7/
ojO1k00<ojO1k0ooYl3[3?nW_n/=ojRojP;oYko[00GoZ<3[o`000?l0003o0000ojS0j`08ojRojP;o
Z;o[1_nX`>/6ojRojP03ojS0jonX_n_oZ;o[00KoZ;o[1_nW_n/00onX_n_oYko[ojNoj`0>ojNoj`Oo
Y/3/1?nW`>/4ojO0k0_oZ<3[00Co0000ojS0jonX`>_oZ<3[2_nW`>/5ojNoj`SoYl3[5Oooool00ol0
003oooooooooo`0Sooooo`003?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00oooooo0_nX`>/?ojNo
j`goYl3[0_nX`N/7ojS0j`KoYl3[3?nW_n/5ojO0k0[oYl7/3onW`>/<ojNoj`03ojRojonX_n[oZ;oZ
00coZ;oZ00CoZ<7[o`000?l0003o00001OnX`>/6ojRojP03ojS1k?nX`>_oZ<3[00OoZ<3[0_nX_nX5
ojS0j`SoZ;o[0_nW_n/5ojRoja3oYko[1onV`>`00onW`>_oYl3/ojO0k005ojO0k0_oZ<3[00Co0000
ojS0jonX`>_oZ<3[1_nW`>/00onX`>_oYko[ojNoj`05ojNoj`SoYl3[5_ooool00ol0003ooooooooo
o`0Rooooo`0000?oooooo`000?l000001?l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@4006ooooo`;o00006Oooool00ol0003oooooooooo`0<ooooo`GoZ<3[3onW
_n/9ojO0j`KoZ<7[1onX`>/2ojO0j`coYko[0_nW`>/7ojO0k0KoYl7/3onW`>/<ojNoj`GoZ;o[2_nX
_nX2ojS1j`;o000000?oZ<7[ojS0jonX`>/01_nX`>/2ojRojPGoZ<7/1onX`>/00onW`NcoZ<3[ojS0
j`06ojS0j`KoZ;o[00?oZ<3[ojRojonX_n/01_nX_n/6ojNoj`03ojRojonW_n_oYko[00OoYko[0onV
`>`4ojNoj`SoYl3/2onX`>/01?l0003oZ<3[ojS0jonX`>/2ojO0j`GoZ<3[1onW_n/8ojO0jaKooooo
00?o0000ooooooooool08Oooool000cooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0:ooooo`OoZ<3[
3onW_n/6ojO0j`WoZ<7[1OnX`>/<ojNoj`KoYl3[1onW`>`2ojO1k0ooYl3[3_nW_n/7ojRoj`KoZ;oZ
00?oYl7/ojS1jol000000_l00004ojS1j`KoZ<3[0_nW`N`7ojS1k0CoZ<3[1?nW`N`8ojS0j`;oZ;o[
1OnX`>/8ojRoj`;oYko[1OnX_n/7ojNoj`03ojRojonW_n_oYko[00KoYko[1_nW`>`00onV`>coZ<3[
ojS0j`0:ojS0j`03o`000?nX`>_oZ<3[00OoZ<3[1_nW_n/:ojO0jaGooooo00?o0000ooooooooool0
8Oooool000cooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Gooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`07ooooo`[oZ<3[3onW_n/2ojO0j`goZ<7[
00?oZ<3[ojNojonW_n/03?nW_n/8ojO0j`GoYl3/0_nX`N/=ojO0ja;oYko[1onX_n/2ojRojP;oYl7/
0ol00008ojS1j`;oZ<3[1_nW`N`7ojS1k003ojS0jonW`NcoYl7/00GoYl7/1_nX`>/00onW`NcoZ<3[
ojS0j`06ojS0j`KoZ;o[00?oZ<3[ojRojonX_n/01_nX_n/4ojNoj`CoZ;o[2?nW_n/2ojO0k0GoY/3/
2onX`>/00ol0003oZ<3[ojS0j`08ojS0j`;oYko[3OnW`>/Fooooo`03o`000?oooooooooo023ooooo
000<ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool00oooool<ojS0j`ooYko[0_nW`>/=ojS1ja7oYko[
2?nW`>/00onW`>coZ<7[ojS1j`04ojS1j`WoYl3[5_nW_n/5ojRoj`;oYl7/0ol00004ojO1k0KoZ<7[
2_nW`N`3ojS1k0coYl7/0_nX`>/5ojO1k0SoZ<3[0_nX_n/5ojS0j`SoZ;o[00?oYko[ojRojonX_n/0
1OnX_n/6ojNoj`03ojO0jonV`>coY/3/00GoY/3/1_nX`>/00onW`>_oZ<3[ojS0j`03ojS0j`03o`00
0?nX`>_oZ<3[00SoZ<3[3onW`>/Fooooo`03o`000?oooooooooo01oooooo000<ooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o00007_ooool00ol0003ooooo
ojO0j`02ojO0j`WoZ<3[3onW_n/6ojO0j`WoZ<7[5OnW_n/6ojO0j`03ojS1k?nX`N_oZ<7[00KoZ<7[
1_nW`>/IojNoj`03ojRojonW`NcoYl7/00?o00002?nW`N`2ojS1j`coYl7/00?oYl3/ojO1k?nW`N`0
3?nW`N`00onV`>coYl7/ojO1k006ojO1k0KoZ<3[00?oYl7/ojS0jonX`>/01_nX`>/6ojRoj`;oZ<3[
2?nX_n/2ojNoj`GoYl3[1onV`>`2ojS0j`GoYl3[1OnX`>/00ol0003oZ<3[ojS0j`08ojS0j`ooYl3[
5Oooool00ol0003oooooooooo`0Oooooo`002_ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`0Looooo`OoYl3[1_nX`>/2ojO0j`coYko[
2_nW`>/5ojS1j`?oZ<3[5_nW_n/2ojO0j`GoZ<7/2?nX`N/2ojO0ja_oYko[00CoYl7/o`000?l0003o
00005_nW`N`5ojO0k0[oYl7/1OnV`>`8ojO1k0;oZ<3[1OnW`N`8ojS0j`;oZ;o[1_nX`>/6ojRoj`03
ojS0jonW`>_oYl3[00GoYl3[1_nV`>`00onV_n_oYl3[ojO0j`06ojO0j`GoZ<3[00?o0000ojS0jonX
`>/02?nX`>/?ojO0jaGooooo00?o0000ooooooooool07_ooool001_ooooo00?o0000ooooooooool0
6_ooool:ojO0j`;oZ<3[1_nW`>/8ojNoj`koYl3[00?oZ<7[ojS0jonX`>/01OnX`>/DojNoj`WoZ<7/
1_nX`N/KojNoj`04ojO1k?l0003o0000o`0001KoYl7/00?oYl3[ojO0k?nW`>`01_nW`>`6ojO1k003
ojO0jonV`>coY/3/00KoY/3/1_nW`N`2ojK0k0OoYl7/1_nX`>/2ojS1k0SoZ<3[0_nX_n/5ojS0j`Oo
Yl3[0_nV`>`5ojJoj`SoYl3[1?nX`>/00ol0003oZ<3[ojS0j`08ojS0j`koYl3[00?oYko[oooooooo
ool05?ooool00ol0003oooooooooo`0Mooooo`006oooool00ol0003oooooooooo`0Gooooo`coYl3[
0_nX`>/8ojO0j`OoYko[3OnW`>/2ojS1j`SoZ<3[4?nW_n/=ojS1k0;oZ<7[6onW_n/01?nW`Nco0000
o`000?l0000;ojO1k0;oYl3/2OnW`N`5ojO0j`SoYl3/0_nW`N`5ojO0j`SoY/3/0_nW`N`6ojK0k0Oo
Yl7/0_nX`>/6ojS1k0KoZ<3[00?oZ<7[ojS0jonX`>/01OnX`>/7ojO0j`SoY[o[2?nW`>/4ojS0j`03
o`000?nX`>_oZ<3[00SoZ<3[2_nW`>/5ojNojaCooooo0_l0000Oooooo`006oooool2o`0001Kooooo
2onW`>/6ojS0j`SoYl3[1onW_n/9ojO0j`KoZ<7[1_nX`>/?ojNoj`03ojO0jonX`NcoZ<7/00_oZ<7/
0onW`>/HojNoj`;oYl7/0_l0000;ojO1k0KoYl3/1_nW`N`00onW_n_oYl3[ojO0j`05ojO0j`KoYl3/
00?oYko[ojO0jonW`>/01_nW`>/6ojK0k0;oYko[2?nV`>`3ojO1k0CoY/3/2?nX`N`2ojS0j`GoZ<7[
1onX`>/7ojO0j`SoY[o[2?nW`>/4ojS0j`03o`000?nX`>_oZ<3[00SoZ<3[1onW`>/7ojNojaKooooo
00?o0000ooooooooool07?ooool001[ooooo00?o0000ooooooooool04oooool<ojO0j`WoZ<3[1_nW
`>/9ojNoj`GoYl3[0onX`>/7ojS1j`;oZ<3[3onW_n/5ojO0j`WoZ<7/1onW`>/DojNoj`;oYl7/0ol0
000:ojO1k0[oYl3/0_nW`N`5ojNoj`OoYl3[0_nW`>`5ojNoj`SoYl3[0_nV`>`6ojNoj`KoY/3/00?o
Yko[ojK0k?nV`>`01_nV`>`6ojS1k003ojK0k?nX`N_oZ<7[00GoZ<7[1onX`>/8ojO0j`KoY[o[0_nW
_n/8ojO0j`CoZ<3[00?o0000ojS0jonX`>/02?nX`>/7ojO0j`OoYko[5Oooool00ol0003ooooooooo
o`0Looooo`006_ooool00ol0003oooooooooo`0?ooooo`CoYko[2OnW`>/=ojS0j`;oYl3[3OnW_n/0
0onW`>_oZ<3[ojS0j`05ojS0j`GoZ<7[0_nW`>/=ojNoj`WoYl3[1_nX`N`2ojS0j`SoYl3[4?nW_n/2
ojO1k0?o00002_nW`N`<ojO0k003ojNoj_nW_n_oYko[00KoYko[1OnW`>/2ojRnjPOoYko[1_nW`>/2
ojNnjPSoYko[0_nV`>`5ojNoj`SoY/3/0_nX`N`5ojK0k0OoZ<7[1onX`>/8ojO0j`;oY[o[1_nW_n/6
ojO0j`03ojO0k?nX`>_oZ<3[00;oZ<3[00?o0000ojS0jonX`>/02?nX`>/7ojO0j`SoYko[5Oooool0
0ol0003oooooooooo`0Kooooo`006_ooool00ol0003oooooooooo`0;ooooo`;oYl3[1onW_n/7ojO0
j`goZ<3[3onW_n/3ojO0j`OoZ<3[00?oZ<7[ojO0jonW`>/01?nW`>/9ojNoj`goYl3[0_nX`N`6ojS0
j`KoYl3[3_nW_n/2ojO1k0?o00002_nW`N`2ojO0j`[oYl3/1OnW_nX8ojNoj`03ojO0jonX_^[oZ;kZ
00CoZ;kZ1onW_n/2ojO0j`KoYkkZ1_nW_n/00onW_^[oYko[ojNoj`06ojNoj`KoY/3/00?oY[o/ojK0
k?nV`>`01OnV`>`6ojS1j`WoZ<3[1_nW`>/2ojS0j`SoYko[0_nW`>/5ojO0k0CoZ<3[00?o0000ojS0
jonX`>/02?nX`>/7ojO0j`SoYko[5Oooool00ol0003oooooooooo`06ooooo`Go00003oooool001[o
oooo0_l00009ooooo`KoYl3[1onW_n/7ojO0j`WoZ<3[3onW_n/7ojO0j`OoZ<3[1onW`>/7ojNoj`go
Yl3[0onX`N/7ojS0j`;oYl3[3_nW_n/2ojO1k0?o00002_nW`N`6ojO0j`KoYl3/00?oYkkZojNoj_nW
_nX01_nW_nX6ojNoj`03ojRnjOnX_^[oZ;kZ00KoZ;kZ1OnW_n/2ojRnj@SoYkkZ0_nW_n/5ojNnjPSo
Yko[0_nV`>`5ojJok0OoY/3/0_nX`N/=ojS0j`;oYl3[1_nX`>/6ojNoj`03ojO0jonW`>coYl3/00Go
Yl3/1OnX`>/00ol0003oZ<3[ojS0j`07ojS0j`SoYl3[2?nW_n/Dooooo`03o`000?oooooooooo00Ko
oooo00GoV9RHob4Q8Oo^k^koooooodA4A00?ooooo`006_ooool00ol0003oooooooooo`06ooooo`;o
Z<3[1onW`>/5ojNoj`WoYl3[2OnX`>/>ojNoj`SoYl3[1onX`>/7ojO0j`OoYko[2OnW`>/7ojS1j`Go
Z<3[3onW_n/01?nW`>co0000o`000?l0000=ojO1k0OoYl3[0_nW`>`5ojNnjPSoYkoZ0_nW_n/5ojRn
j@SoZ;kZ00?oYko[ojRnjOnX_^T01?nX_^T6ojNnjP03ojVoj_nW_^[oYkkZ00KoYkkZ1onW_n/8ojJo
k0OoY/3/5onX`>/2ojNoj`GoYl3[1onW`>`4ojS0j`03o`000?nX`>_oZ<3[00SoZ<3[2?nW`>/7ojNo
jaGooooo00?o0000ooooooooool01_ooool00onHV9So8B4Qonk^kP0@ooooo`006_ooool00ol0003o
ooooooooo`03ooooo`KoZ<3[1onW`>/00onW_n_oYl3[ojO0j`0;ojO0j`WoZ<3[3_nW_n/6ojO0j`03
ojS1jonX`>_oZ<3[00KoZ<3[1OnW`>/9ojNoj`KoYl3[0_nX`N`8ojS1j`03ojS0jonW_n_oYko[00go
Yko[00GoYl3/o`000?l0003o0000ojO0k00@ojO1k0GoYl3[2OnW_^X6ojNojP03ojRoj_nX_^WoZ;kY
00KoZ;kY1_nX_^X2ojS1j`OoZ;kY0_nW_^X5ojVojPSoYkkZ1onW_n/8ojJok0OoY/3/5_nX`>/7ojO0
j`KoYl3/0_nV_n`4ojS0j`03o`000?nX`>_oZ<3[00SoZ<3[2?nW`>/7ojNojaGooooo00?o0000oooo
ooooool01_ooool00onHV9So8B4Qonk^kP0?ooooo`006_ooool00ol0003oooooooooo`0:ojS0j`Go
Yl3[0_nW_n/<ojO0j`_oZ<3[3_nW_n/2ojO0j`GoZ<7[2?nX`>/00onW`>_oYko[ojNoj`0;ojNoj`;o
Yl3[1_nX`N`6ojS1j`03ojO0jonW_n_oYko[00coYko[0ol00005ojO0k0KoYl7/0_nX`N`8ojO1k003
ojO0jonW_^[oYkkZ00_oYkkZ0_nW_nX5ojRojPSoZ;kY0_nX_^X6ojS1j`GoZ;kY00?oZL;/ojVoj_nY
_nX01_nY_nX6ojNnjP03ojVoj_nW_n_oYko[00KoYko[1_nV_n`00onW_n_oY/3/ojK0k006ojK0k0?o
Z<3[1?nW`>`?ojS0j`OoYl3[0_nW`>`6ojJok0CoZ<3[00?o0000ojS0jonX`>/02?nX`>/7ojO0j`Oo
Yko[5Oooool00ol0003oooooooooo`07ooooo`03ogMgMomVIVKooooo00kooooo000Iooooo`03o`00
0?nX`>_oZ<3[00coZ<3[00?oYl3[ojNojonW_n/01?nW_n/8ojO0j`goZ<3[3_nW_n/2ojO0j`OoZ<7[
1_nX`>/=ojNoj`CoYl3[1onX`N`2ojS1j`GoYl3[2_nW_n/3o`0000?oYko[1_nW`>`2ojO1k0KoZ<7/
1_nW`N`00onW_n[oYkkZojNnjP0;ojNnjP03ojRojonX_n[oZ;oZ00KoZ;oZ1_nX_^T2ojS2k0SoZ<7[
00?oZ;kYojW2k?nY`^`00onY`^`8ojVojP;oYkkZ1OnY_nX8ojNoj`;oY[o/1OnW_n/6ojK0k003ojJo
k?nW`>coYl3/00KoYl3/3onX`>/7ojO0j`SoY[o/1?nX`>/00ol0003oZ<3[ojS0j`08ojS0j`OoYl3[
1onW_n/Eooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03Oooool001Wooooo00?o
0000ojS0jonX`>/02onX`>/2ojO0j`OoYko[2?nW`>/9ojS0j`koYko[1_nW`>/7ojS1j`;oZ<3[3OnW
_n/8ojO0j`GoZ<7/0_nX`>/7ojO0j`OoYko[0_l00007ojNoj`?oYl3/2onX`N`2ojO1k0GoYkoZ2OnW
_^X5ojRoj`SoZ;oZ0_nX_^T6ojS2k0KoZ<7[00?oY/7/ojW2k?nY`^`01OnY`^`6ojVojP03ojW2k?nY
_n[oZKoZ00KoZKoZ1_nW_n/2ojRojPOoYko[0_nV`>`5ojJok0SoYl3/3onX`>/7ojO0j`KoY[o/00?o
Y[o[ojS0jonX`>/00_nX`>/00ol0003oZ<3[ojS0j`08ojS0j`OoYl3[2?nW_n/Cooooo`?o00001?oo
ool01Ol0003o^[ZjoooooonHV9So410@00oooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1_ooool00ol0003oooooojS0j`08ojS0j`KoYl3[1onW_n/8ojO0j`OoZ<3[3OnW_n/9ojO0j`GoZ<7[
0onW`>/>ojNoj`SoYl3[00?oZ<7/ojS0jonX`>/01?nX`>/7ojO0j`?oYko[0ol00008ojNoj`koZ<7/
00?oYko[ojNoj_nW_nX01_nW_nX6ojNnjP;oYko[1_nX_n/6ojRojP;oYl;]2?nX`^`2ojS1j`GoY/7/
1onY`^`2ojVojPGoZL;/2?nY_nX2ojNoj`KoZ;oZ1_nW_n/8ojJok0KoYl3/00?oY/3/ojS0jonX`>/0
3OnX`>/8ojO0j`;oY[o/1OnV_n/4ojS0j`03o`000?nX`>_oZ<3[00SoZ<3[1onW`>/8ojNojaCooooo
00?o0000ooooooooool00_ooool01OnHV9So410@o`000?lQ8B7oc<c<00oooooo000>ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`08ojS0j`OoYl3[1OnW_n/:ojO0j`Oo
Z<3[2OnW_n/=ojO0j`03ojS1jonW`>_oYl3[00GoYl3[3_nW_n/6ojO0j`03ojS1jonX`>_oZ<3[00Ko
Z<3[1OnW`>/01?nW_n_o0000o`000?l00008ojNoj`koZ<7/1OnW_n/8ojNojP;oYkkZ1_nW_n/6ojRo
j`;oZ;oZ1_nW`^d6ojS2k003ojK0k?nV`NcoY/7/00KoY/7/1OnY`^`2ojK0k0OoZL;/1_nY_nX2ojW1
j`SoZ;oZ1_nW_n/8ojJok0;oYl3/1OnV`>`?ojS0j`OoYl3[2?nV_n/4ojS0j`03o`000?nX`>_oZ<3[
00OoZ<3[2?nW`>/8ojNojaCooooo00?o0000ooooooooool05Oooool000kooooo00Go410@oooooooo
oooooooooa0@4006ooooo`;o00000_ooool8ojS0j`OoYl3[00?oYko[ojO0jonW`>/02_nW`>/9ojS0
j`SoYko[3?nW`>/3ojS1j`OoYl3[3_nW_n/2ojO0j`GoZ<7[2?nX`>/00onW`>_oYko[o`000002o`00
00SoYko[3onX`N`00onW`>_oYko[ojNoj`05ojNoj`KoYkoZ0_nW_^X8ojNoj`?oZ;o[1?nW`N`7ojO2
k@;oZ<;/1OnV`>`8ojK1k003ojW2k?nV`>coY/3/00CoY/3/1onY`^`2ojVojPKoZL7[1_nX_nX00onY
`>[oYko[ojNoj`05ojNoj`KoY[o/0_nV_n/7ojK0k0ooZ<3[1onW`>/8ojJoj`CoZ<3[00?o0000ojS0
jonX`>/01onX`>/8ojO0j`OoYko[5Oooool00ol0003oooooooooo`0Dooooo`003_ooool01Ol0003o
oooooooooooooooo000000Kooooo00?o0000ooooooooool00oooool7ojS0j`?oYl3[1OnW_n/8ojO0
j`goZ<3[2?nW_n/8ojO0j`OoZ<7[1OnW`>/>ojNoj`WoZ<7[1_nX`>/3o`0000SoYko[3onX`N`5ojO0
j`OoYko[0_nW_nX6ojNnjPKoYko[00?oYl;/ojO1k?nW`N`01_nW`N`5ojO2k@03ojNnj_nV`>coY/3/
00KoY/3/1_nV`N`2ojNnjPOoY/3/0onY`^`4ojK0k0SoZL7[0_nX_nX5ojW0jPOoYko[0_nV_n`6ojJo
j`OoY/3/3_nX`>/8ojO0j`OoY[o[1?nX`>/00ol0003oZ<3[ojS0j`08ojS0j`SoYl3[1onW_n/Doooo
o`03o`000?oooooooooo01Cooooo000>ooooo`05o`000?ooooooooooooooool000001Oooool00ol0
003oooooooooo`05ooooo`GoZ<3[0_nW`>/8ojNoj`OoYl3[3?nX`>/:ojNoj`?oYl3[1?nX`>/8ojS1
j`03ojO0jonW_n_oYko[00coYko[3OnX`N/2ojS0j`?o00002_nW_n/=ojS1k0;oZ<3[1onW`>/5ojNo
j`[oYkkZ0_nW_n/5ojO2k0SoYl7/00?oYl;]ojNnj_nW_^X00onW_^X8ojK0k0;oY/7/1_nW_^X5ojK0
k003ojJmj_nV`>coY/3/00KoY/3/1_nY`N/00onW`NcoZL3ZojW0jP05ojW0jPKoYko[0_nX`>/8ojJo
j`?oY/3/0onV_n`?ojS0j`SoYl3[1onV_n/4ojS0j`03o`000?nX`>_oZ<3[00SoZ<3[1onW`>/7ojNo
jaGooooo00?o0000ooooooooool04oooool000kooooo00Go410@oooooooooooooooooa0@4005oooo
o`03o`000?oooooooooo00Kooooo00?oZ<3[ojO0jonW`>/01?nW`>/8ojNoj`OoYl3[2?nX`>/<ojNo
j`;oYl3[1onX`>/6ojS1j`03ojO0jonW_n_oYko[00goYko[2onX`N/01?nW`>_o0000o`000?l0000>
ojNoj`WoZ<7/1_nX`>/7ojO0j`03ojNojonW_^[oYkkZ00[oYkkZ00?oZ<;/ojO2k?nW`^`01_nW`^`6
ojO1k003ojNlj?nW_^[oYkkZ00GoYkkZ1_nV`>`2ojNfi0SoYkkZ00?oY/3/ojJmj_nV_NX00onV_NX8
ojK0k0;oZL7[1OnW`N`7ojW0jP;oYko[1_nX`>/6ojJoj`03ojNojonV_ncoY[o/00GoY[o/3onX`>/7
ojO0j`SoY[o[1?nX`>/00ol0003oZ<3[ojS0j`08ojS0j`OoYl3[1onW_n/Eooooo`03o`000?oooooo
oooo01;ooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2o`0000Sooooo1onW`>/6
ojNoj`WoYl3[2?nX`>/8ojNoj`KoYl3[1onX`>/2ojS1j`GoYl3[3onW_n/7ojS1j`04ojO0jol0003o
0000o`0000CoYl3[3_nW_n/8ojS1k0OoZ<3[0onW`>/=ojNnjPGoZ<;/2?nW`^`2ojO1k0GoYkcX1onW
_^X2ojK0k0KoYkKT1_nW_^X00onY]>3oY[gZojJmjP05ojJmjPKoY/3/0_nV_n`7ojO1k0GoZL3Z0_nY
`N/8ojS0j`;oY[o[1OnW_n/7ojJok0ooZ<3[1onW`>/7ojJoj`CoZ<3[00?o0000ojS0jonX`>/02?nX
`>/7ojO0j`OoYko[5Oooool00ol0003oooooooooo`0Booooo`003_ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo00?o0000ooooooooool02?ooool7ojO0j`;oYko[3OnW`>/8ojS0j`OoYko[1onW
`>/5ojS0j`?oZ<7[1_nW`>/?ojNoj`GoZ<7[0_l00008ojO0j`koYko[2?nX`N`5ojS0j`;oYko[3OnW
_^X00onW`^coZ<;/ojS2k005ojS2k0KoYl;/2OnW_>P5ojNnjP03ojR^g?nW]^CoYkKT00OoYkKT0_nW
_^X5ojVdh0OoY[gZ0_nV`>`6ojJok0OoYl7/00?oZL3ZojW1jonY`N/01?nY`N/6ojS0j`03ojW0jonW
_n_oYko[00KoYko[1_nV_n`?ojS0j`SoYl3[1onV_n/4ojS0j`03o`000?nX`>_oZ<3[00SoZ<3[1onW
`>/7ojNojaGooooo00?o0000ooooooooool04Oooool001Sooooo00?o0000ooooooooool02Oooool5
ojO0j`?oYko[2_nW`>/<ojS0j`OoYko[1onW`>/00onX`>_oZ<7[ojS1j`05ojS1j`KoYl3[3OnW_n/3
ojS1j`?o00000onX`N/6ojO0j`koYko[2_nX`N`00onX`>_oYko[ojNoj`04ojNoj`WoYkkZ1OnW`^`7
ojS2k0;oYl;/3OnW_>P00onW_^[oZ:kLojR^g003ojR^g0OoYkKT00?o[:SCojVdh?nY]>001_nY]>05
ojJmjP;oZKWT2?nV_n`3ojO1k0CoYKo/1onY`N/2ojS0j`GoZL3[2?nW_n/6ojJok0ooZ<3[1onW`>/8
ojJoj`CoZ<3[00?o0000ojS0jonX`>/01onX`>/7ojO0j`SoYko[5Oooool00ol0003oooooooooo`0@
ooooo`006?ooool00ol0003oooooooooo`0:ooooo`03ojO0jonW_n_oYko[00GoYko[1onW`>/=ojS0
j`WoYko[1OnW`>/3ojS0j`OoZ<7[0onW`>/<ojNoj`?oZ<7[0ol00007ojS1j`;oYl3[3_nW_n/<ojS1
k003ojO0jonW_n_oYko[00KoYko[1OnW_^X2ojO0k0OoYl;/1OnX`^`3ojNnjPcoYkcX00?oYjWHojR^
g?nX[]`01OnX[]`4ojNfi0Co[:SC2?nY]>000onV_N[oZKWTojVii004ojVii0KoY[o/00?oYkkZojFo
k?nU_n`01_nU_n`6ojW1j`SoZL3[1_nW_n/00onW`>_oY[o/ojJok005ojJok0ooZ<3[1onW`>/8ojJo
j`CoZ<3[00?o0000ojS0jonX`>/01onX`>/7ojO0j`OoYko[5Oooool2o`00017ooooo000Gooooo`?o
00003Oooool7ojNoj`OoYl3[2OnX`>/=ojNoj`03ojO0jonX`>_oZ<3[00GoZ<3[1OnX`N/2ojO0j`ko
Yko[0ol00009ojS1j`?oYl3[3?nW_n/2ojO0j`WoZ<7/1OnW`>/8ojNoj`03ojNnj_nW`>coYl3/00Co
Yl3/1onW`^`00onX`^coYkkZojNnjP05ojNnjPSoYkcX1OnWZMP7ojR^g003ojNfi?n/Z=?o[:SC00Go
[:SC1_nY]>000ona[]GoZKWTojVii006ojVii0;oY[o/1OnW_^X8ojFok0KoZL7[2?nY`>/2ojNoj`Go
Yl3[1onV_n`>ojS0j`SoYl3[1_nV_n/00onW_n_oZ<3[ojS0j`02ojS0j`03o`000?nX`>_oZ<3[00So
Z<3[1onW`>/7ojNoja?ooooo00?o0000ooooool000004Oooool001Oooooo00?o0000ooooooooool0
3_ooool5ojNoj`WoYl3[2?nX`>/<ojNoj`;oYl3[2?nX`>/00onX`N_oYl3[ojO0j`04ojO0j`[oYko[
0ol000000onW_n_oZ<7[ojS1j`06ojS1j`OoYl3[2?nW_n/6ojO0j`GoZ<7/0_nX`N/7ojO0j`KoYko[
0_nV_^X7ojO0k0?oYl;/1?nX`>/8ojNnjP?oYkcX0_nUZ=P8ojNYf0GoZ:kL00?o[:3;ojbXdon/Z=<0
1_n/Z=<4ojVdh0Co/JkE1_nY^N@00on`]mkoYkkZojNnjP06ojNnjPOoYKo/1onY`N/6ojW0j`;oZL7[
1onW`>/7ojJok0koZ<3[2?nW`>/2ojJoj`GoYko[1?nX`>/00ol0003oZ<3[ojS0j`08ojS0j`GoYl3[
2OnW_n/Dooooo`03o`000?oooooooooo00oooooo000Gooooo`03o`000?oooooooooo00oooooo00?o
Yko[ojO0jonW`>/02onW`>/8ojS0j`SoYko[1_nW`>/7ojS0j`SoYl3[1_nW_n/3o`0000GoYko[1onX
`N/8ojO0j`OoYko[1onW`>/00onX`NcoZ<7[ojS1j`04ojS1j`OoYl3[0_nW_n/6ojJnjPGoYl3/0_nX
`^`7ojS0j`KoYkkZ00?oYJcMojFXf?nUZ=P01?nUZ=P8ojNYf003ojR^g?n/X<_o[:3;00?o[:3;2?n/
Z=<00onY]>3o/JkEok6^e@05ok6^e@?oZKWT1?n`]mh8ojNnjPOoYKo/1onY`N/2ojW0j`KoZL7[1_nW
`>/8ojJok0koZ<3[1onW`>/8ojNoj`CoZ<3[00?o0000ojS0jonX`>/02?nX`>/00onW`>_oYko[ojNo
j`0;ojNojaCooooo00?o0000ooooooooool03_ooool001Oooooo00?o0000ooooooooool04?ooool<
ojO0j`[oZ<3[1onW_n/7ojO0j`OoZ<3[2?nW`>/2ojNoj`?o00002OnW_n/7ojS1j`KoYl3[2OnW_n/5
ojO0j`;oZ<7/1onX`N/5ojO0j`;oY[k[2?nV_^X00onW`>coZ<;/ojS2k004ojS2k0OoZ<3[0_nW_^X5
ojF/g@KoYJSH1_nWZMP00onXV/Oo[:3;ojbPb`05ojbPb`Ko[:SC00?o]:C8ok6^eOna[]D01ona[]D0
0onY^NCo/;ONok2ggP04ok2ggPKoYkkZ0_nY_nT6ojFok0KoZL7[0_nX`>/8ojW1j`KoYl3[2?nV_n`>
ojS0j`OoYl3[1onW_n/5ojS0j`03o`000?nX`>_oZ<3[00OoZ<3[3OnW_n/00onW`>_oooooooooo`0C
ooooo`03o`000?oooooooooo00gooooo000Gooooo`;o00004_ooool8ojO0j`coZ<3[0_nW`>/7ojNo
j`GoYl3[2OnX`>/6ojO0j`?o00002OnW_n/;ojS1j`;oYl3[3OnW_n/00onW`>_oZ<7/ojS1k004ojS1
k0OoZ<7[00?oYl3[ojJnjonV_^/01?nV_^/6ojJnjPWoZ<;/1OnX`>/00onU]^CoYJcMojF/g@06ojF/
g@GoYJSH1?nWZMP4ojRJa`Ko[:3;1?n/Z=<4okBTb0Oo/JkE00?o_;7?ok2gg_n`]mh01_n`]mh2ojNn
jPKoZKoY1_nU_n`2ojW1j`KoZ<3[1onY`N/7ojO0j`KoY[o/00?oY[o[ojS0jonX`>/03OnX`>/7ojO0
j`OoYko[1?nX`>/00ol0003oZ<3[ojS0j`08ojS0j`WoYko[1OnW`>/Dooooo`03o`000?oooooooooo
00gooooo000Gooooo`03o`000?oooooooooo01;ooooo2?nW`>/8ojS0j`KoYl3[1onW_n/00onW`>_o
Z<3[ojS0j`0;ojS0j`;oYl3[00?oYko[o`000?l000002_nW_n/<ojS1j`?oYl3[3?nW_n/2ojS0j`Oo
Z<7/0onX`N/4ojO0j`OoY[k[0_nV_^X=ojS2k003ojS0jonU]^CoYKKT00?oYKKT1onU[=d6ojFXf003
ojNYf?nXV/OoZ9[700CoZ9[71on/X</00on/Z=?o]:C8okBTb005okBTb0Go/JkE0onl/Ll6ok2ggP;o
^[kM2?nY_nT6ojFok0SoZ<3[1onY`N/7ojO0j`;oY[o/1OnV_n/?ojS0j`GoYl3[2OnW_n/4ojS0j`03
o`000?nX`>_oZ<3[00SoZ<3[1_nW_n/8ojO0jaCooooo00?o0000ooooooooool03?ooool001Oooooo
00?o0000ooooooooool04oooool8ojO0j`OoZ<3[1onW`>/5ojNoj`?oYl3[2onX`>/01?nW`>_o0000
o`000?l0000=ojNoj`SoZ<7[1onW`>/8ojNoj`KoZ<3[1OnX`N`2ojS1j`OoYl3[2?nV_^/<ojS2k003
ojNnj_nU]^CoYKKT00GoYKKT1onU[=d3ojFXf0;oXYO92?nXV/L5ojbPb`03ok2K`OndY<So]:C800Ko
]:C80ona[]D6okbac`?o/;ON1Onj_]d6ojVoj@03oj_1j_nU_ncoYKo/00GoYKo/2?nX`>/7ojW1j`?o
Yl3[1?nW_n/7ojJoj`ooZ<3[00?oYl3[ojNojonW_n/02onW_n/4ojS0j`03o`000?nX`>_oZ<3[00Ko
Z<3[00?oYl3[ojNojonW_n/01OnW_n/7ojO0jaGooooo00?o0000ooooooooool02oooool001Oooooo
00?o0000ooooooooool05Oooool7ojO0j`OoZ<3[1onW`>/00onW_n_oYl3[ojO0j`05ojO0j`OoZ<3[
00CoYl3[o`000?l0003o00000onW`>/>ojNoj`SoZ<7[1onW`>/3ojNoj`CoY[o[1onX`>/00onX`Nco
Z<7[ojS1j`04ojS1j`OoYl3[2?nV_^/8ojS2k0GoYkkZ1_nU]^@6ojF/g@03oibId?nRUlWoXYO900Co
XYO91onXV/L3ojbPb`Co/9_12?ndY<P00ona[]Go_;7?okbac`06okbac`03ok2gg_nj_]go^[kM00Go
^[kM0_nY_nT5oj_1jPOoYKo/2?nX`>/6ojW1j`SoYko[1_nV_n/?ojS0j`koYko[1OnX`>/00ol0003o
Z<3[ojS0j`02ojS0j`GoYl3[1onW_n/7ojO0jaCooooo00?o0000ooooooooool02oooool001Kooooo
0ol0000Gooooo`GoYl3[2OnX`>/5ojO0j`?oYko[1onW`>/4ojS0j`?o00001onW`>/>ojNoj`SoZ<7[
1OnW`>/00onW_n_oY[o[ojJoj`06ojJoj`GoZ<3[2OnX`N/5ojO0j`[oY[k[0onX`^`3ojS1k0OoYkkZ
1_nU]^@2ojF/g@GoW9W@1OnRUlT8ojRJa`03ojbPbon`Vl7o/9_100?o/9_11ondY<P00onnZ<Co_;7?
okbac`06okbac`03olJjc_nj_]go^[kM00Go^[kM00?o`LOOoj_1j_n[`NX01_n[`NX7ojFok0SoZ<3[
1_nY`N/8ojNoj`KoY[o[3onX`>/>ojNoj`CoZ<3[00?o0000ojS0jonX`>/01onW`>/8ojNoj`OoYl3[
5?ooool00ol0003oooooooooo`0:ooooo`005_ooool00ol0003oooooooooo`0Hooooo`03ojO0jonX
`>_oZ<3[00_oZ<3[00?oYl3[ojNojonW_n/01OnW_n/6ojO0j`04ojS0jol0003o0000o`0000CoZ<3[
1OnW`>/>ojNoj`;oZ<3[2?nX`N/00onW`>_oYko[ojNoj`03ojNoj`SoY[o[00?oZ<3[ojS1jonX`N/0
2onX`N/00onW`>_oY[k[ojJnj`0:ojJnj`03ojW2k?nX`NcoZ<7/00GoZ<7/1onW_^X3ojFfi0;oVJ3I
1onLVM06oj:Gb@KoZ9[700?oZiBook2K`On`Vl401On`Vl45okBTb0?o_ZS41_nl/Ll3olJjcPGo^[kM
0oo1aml8oj_1jPOoYKo/1_nX`>/00onY`>_oZL7[ojW1j`05ojW1j`KoYko[2?nV_n/6ojS0j`03ojS1
jonX`>_oZ<3[00KoZ<3[0onW_n/3ojJoj`SoYko[1?nX`>/00ol0003oZ<3[ojS0j`07ojO0j`SoYko[
1OnW`>/00onX`>_oooooooooo`0Aooooo`?o00002oooool000Cooooo1?l000002?l@413ooooooooo
ooo^k^ko<S8bo`000?lb<S;ok^k^1_ooool00ol0003oooooooooo`0Jooooo`[oZ<3[1?nW`>/7ojNo
j`?oYl3[0ol00008ojS0j`03ojO0jonW_n_oYko[00coYko[1_nX`>/6ojS1j`03ojO0jonW_n_oYko[
00GoYko[1_nV_n/2ojO0j`[oZ<7[1?nW`>/9ojJnj`GoZL;/1onX`N`3ojNnjP?oW[3T1_nIX=T7oibI
d0GoXYO91?nXV/L4oj^D_`Ko/9_10ondY<P6okjXa0Co_;7?1?o6^/h3okZng@Ko`LOO1_n[`NX00on[
`n_oYKo/ojFok006ojFok0;oZ<3[1OnY`>/7ojW1j`;oYko[3?nV_n/2ojS0j`GoZ<7[1_nX`>/00onW
`>_oY[o[ojJoj`05ojJoj`KoYko[1_nX`>/00ol0003oZ<3[ojO0j`07ojO0j`SoYko[00?oYl3[ojS0
jonX`>/00onX`>/?ooooo`?o00000_ooool00ol0003oooooooooo`09ooooo`001_ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`0Koooo
o`KoZ<3[2?nW`>/6ojNoj`?o00001?nW`>/8ojS0j`koYko[1onX`>/2ojS1j`GoYl3[1onW_n/2ojJo
j`KoYl3[1onX`N/7ojO0j`OoY[k[1onY`^`5ojS1k003ojFmjonN/>CoW[3T00GoW[3T1OnIX=T7oibI
d0KoXYO900?oZ9[7oj^D_on[U;l01?n[U;l7ok2K`@03okBTb?nnZ<Co_ZS400Go_ZS40onl/Ll6olJj
cP03okZngOo1amoo`LOO00Ko`LOO0_n[`NX5oj_3j`OoYKo/1onY`>/6ojW1j`;oZ<7[2_nV_n/4ojNo
j`OoZ<7[0_nX`>/5ojO0j`OoY[o[0_nW_n/9ojS0j`03o`000?nX`>_oZ<3[00SoYl3[1onW_n/7ojS0
j`_ooooo0ol00005ooooo`03o`000?oooooooooo00Wooooo0006ooooo`03o`000?oooooooooo00;o
oooo00Go410@oooooooooooooooooa0@4006ooooo`;o00007Oooool6ojS0j`SoYl3[0_nW_n/3o`00
00;oYko[1_nW`>/8ojS0j`koYko[1OnX`>/3ojS1j`KoYl3[1OnW_n/3ojJoj`OoYl3[1onX`N/7ojO0
j`OoY[k[1onY`^`00onX`NcoYKg[ojFmj`03ojFmj`OoW[3T1OnIX=T6oibId0GoXYO900?oX8o2oj^D
_on[U;l01On[U;l7ok2K`@Wo_ZS400?o_;7?olJjc_o6^/h01Oo6^/h00ooBb];o`LOOol77g`05ol77
g`;o`m7T1on[`n/7ojFok0OoZL3[0_nY`N/6ojS1j`KoY[o[2?nW_n/7ojS1j`OoYl3[1onV_n/;ojS0
j`03o`000?nX`>_oZ<3[00SoYl3[1onW_n/7ojS0j`Kooooo1?l00008ooooo`03o`000?oooooooooo
00Wooooo0006ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000005oooo
o`;o00007oooool6ojS0j`KoYl3[00?oYko[o`000?l000001_nW_n/3ojO0j`_oZ<3[3_nW_n/00onX
`>_oZ<7[ojS1j`05ojS1j`KoYl3[00?oYko[ojJojonV_n/01OnV_n/5ojO0j`03ojW1jonX`N_oZ<7[
00KoZ<7[1OnW`>/9ojJnj`GoZL;/0_nX`N/6ojFmj`KoW[3T1OnIX=T7oibId003oj:GbOnPSl;oX8o2
00?oX8o21on[U;l5ok2K`@;o^j;01onnZ<@00oo;]/Goa[[>olJjcP05olJjcP?od/[B1?o1aml5ol?A
i0GoZl?[0_nY`^`7ojFok0GoZL3[0_nY`N/8ojS1j`KoY[o[2?nW_n/7ojS1j`OoYl3[1onV_n/;ojS0
j`03o`000?nX`>_oZ<3[00KoYl3[2?nW_n/7ojS0j`?ooooo0ol0000=ooooo`03o`000?oooooooooo
00Sooooo0006ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000005oooo
o`03o`000?oooooooooo01oooooo1_nX`>/2ojO0j`04ojNojol0003o0000o`0000OoYko[0_nW`>/<
ojS0j`?oYl3[2onW_n/3ojS0j`OoZ<7[0onW`>/3ojNoj`SoY[o[00?oYl3[ojW1jonY`N/00onY`N/8
ojS1j`03ojO0jonV_^_oY[k[00_oY[k[00?oZL;/ojS1jonX`N/01?nX`N/6ojFmj`KoW[3T1OnIX=T3
oibId0?oTh_81_nPSl87oj^D_`Co/9_10onkX/06okjXa0?obkK51Oo6^/h5om;:dP03ol77goo3dNCo
`m7T00Ko`m7T00?oZl?[ojW2k?nY`^`01?nY`^`7ojFok003ojW0jonY`N_oZL7[00CoZL7[1_nX`N/0
0onW`>_oY[o[ojJoj`05ojJoj`KoYko[00?oZ<3[ojS1jonX`N/01_nX`N/6ojO0j`SoY[o[2onX`>/0
0ol0003oZ<3[ojS0j`02ojO0j`coYko[1onX`>/2o`00013ooooo00?o0000ooooooooool02?ooool0
00Kooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000
ooooooooool08?ooool3ojS0j`;oYl3[0ol00007ojNoj`KoYl3[2?nX`>/7ojO0j`OoYko[1onX`>/5
ojS1j`03ojS0jonW_n_oYko[00GoYko[1_nV_n/2ojNoj`KoZL7[1_nX`N/2ojO0j`[oY[k[1?nY`N/7
ojS1j`?oYKg[0_nF/^X6ohVMg`GoRi3C1onCRlP5oj2?`POoZiBo0on`Vl45ok^R`0Co_ZS41Oo;]/D3
olJjcPKod/[B00?of=cJol?Ai?o3dN@01Oo3dN@00onne>_oZL;/ojW2k006ojW2k0?oYKo/0onU_^/8
ojW1j`;oZ<7[1OnW`>/7ojJoj`;oYko[1OnX`>/7ojS1j`OoYl3[1_nV_n/00onW_n_oZ<3[ojS0j`09
ojS0j`03o`000?nX`>_oZ<3[00_oYko[0onW`>/8ojS0ja7ooooo00?o0000ooooooooool02?ooool0
00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_l0000R
ooooo`04ojO0jol0003o0000o`0000?oYl3[2?nW_n/6ojO0j`SoZ<3[1onW`>/6ojNoj`SoZ<3[00?o
Z<7[ojS0jonX`>/00onX`>/7ojNoj`;oY[o[1_nW_n/6ojW1j`;oZ<7[1_nW`>/5ojJnj`03ojFnjonY
`N_oZL7[00KoZL7[1OnX`N/00onU_ncoU[;ZoiJbjP04oiJbjPKoRIgO1On;T=<6oi>;b0KoX8o21on[
U;l00on`Vl7o^j;0ok^R`004ok^R`0?o_ZS41oo;]/D00oo6^/kod/[Bom;:dP04om;:dP?of=cJ1?o3
dN@4okkDj`KoZL;/0_nW`>/6ojFnj`KoZL7[0_nY`^/7ojO0j`KoY[o[2?nX`>/7ojS1j`OoYl3[0_nV
_n/5ojNoj`_oZ<3[00?o0000ojS0jonX`>/01onW_n/7ojO0j`OoZ<3[4Oooool00ol0003ooooooooo
o`08ooooo`001?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool00ol0003oooooooooo`0Oooooo`?o00001onW`>/8ojNoj`KoYl3[2?nX`>/5ojO0j`SoYko[1_nX
`>/2ojS1j`KoZ<3[1OnW_n/3ojJoj`OoYko[0onY`N/4ojS1j`OoYl3[00?oY[k[ojFnjonU_^/00onU
_^/8ojW1j`03ojS1jonU_ncoYKo/00?oYKo/1_nF/^X5ohVMg`GoRi3C1_nCRlP6oj2?`PKoZiBo00?o
/I_1ok^R`?nkX/001_nkX/000onnZ<CobkK5ol^fa@06ol^fa@03omW:c?oBb];od/[B00?od/[B1OoH
g=X00oo3dNCo_]C[okkDj`05okkDj`;oZL;/1_nW`>/6ojFnj`;oZL7[1_nY`^/5ojO0j`03ojNojonV
_n_oY[o[00GoY[o[1_nX`>/8ojS1j`KoYl3[2OnW_n/;ojS0j`03o`000?nX`>_oZ<3[00OoYko[1onW
`>/7ojS0ja3ooooo00?o0000ooooooooool02?ooool001Gooooo00?o0000ooooooooool07?ooool3
o`0000Cooooo2?nW`>/7ojNoj`?oYl3[2onX`>/00onW`>_oYko[ojNoj`0:ojNoj`;oZ<3[1_nX`N/6
ojS0j`03ojNojonV_n_oY[o[00GoY[o[1OnW_n/00onX`>_oZ<7[ojS1j`06ojS1j`GoYl3[0_nV_n`6
ojFnj`SoZL7[1_nU_n`6oiJbjPGoRIgO1On;T=<6oi>;b0GoX8o21?n[U;l4ok6K`@Oo^j;02?o;]/D3
omW:c0?od/[B1OoHg=X3omCVh`Go_]C[0_nbc>d8ojO0j`?oYKk[0onW_n/8ojW2j`03ojO0jonW_n_o
Yko[00?oYko[1onV_n/2ojS0j`coZ<7[0_nW`>/;ojNoj`03ojO0jonX`>_oZ<3[00[oZ<3[00?o0000
ojO0jonW_n/01_nW_n/6ojO0j`WoZ<3[3oooool00ol0003oooooooooo`08ooooo`005Oooool00ol0
003oooooooooo`0Iooooo`?o00002?ooool8ojO0j`GoYko[00?oYl3[ojS0jonX`>/02onX`>/2ojO0
j`_oYko[0onW`>/7ojS1j`?oZ<3[1?nW`>/7ojJoj`03ojNojonX`>_oZ<3[00?oZ<3[2?nX`N/00onW
`>_oY[o/ojJok004ojJok0KoYKk[2?nY`N/6ojFok0KoU[;Z1?n9WMl5oh^@d`KoTh_81_nPSl800on[
U;oo/I_1ok6K`@04ok6K`@Oo^j;000?oa[75ol^faOo;]/D01?o;]/D5omW:c003om;:d_oHg=[of=cJ
00?of=cJ1OoDi^<00onne>_o//c]ok;<k@04ok;<k@KoYl3[00?oY[o[ojNojonW_n/01OnW_n/6ojW2
j`03ojS1k?nW_n_oYko[00GoYko[1OnV_n/2ojNoj`_oZ<7[0onX`>/9ojNoj`GoYl3[2OnX`>/2ojO0
j`03o`000?nW`>_oYl3[00OoYko[0_nW`>/<ojS0j`oooooo00?o0000ooooooooool02?ooool001Go
oooo00?o0000ooooooooool05_ooool3o`0000gooooo1onW`>/00onW_n_oYl3[ojO0j`03ojO0j`Wo
Z<3[1_nW`>/7ojNoj`OoYl3[1_nX`N/8ojO0j`OoY[o[1_nX`>/6ojS1j`;oZ<3[1onV_n`3ojFnj`Co
Z;o[1onY`N/3ojFok0;oVk[^1_mlX^/4ofb<h@03ohVMgon;T=?oRi3C00;oRi3C1_nCRlP5oj2?`P03
oj6CaOnaVl7o/I_100Ko/I_11OnkX/03olJaa@CobkK51_oIb/`2on?Sd`?of=cJ1OoDi^<2olWUk0Oo
//c]0_nW`>/5ojJoj`OoYko[0_nY`^/5ojS1k0OoYko[00?oY[o[ojNojonW_n/01?nW_n/7ojS1j`Oo
Z<3[1onW_n/7ojO0j`OoZ<3[1?nW`>/00ol0003oYl3[ojO0j`07ojNoj`koZ<3[3oooool00ol0003o
ooooooooo`07ooooo`005?ooool2o`0001Gooooo0ol0000Aooooo`GoYl3[0_nW_n/6ojO0j`SoZ<3[
1onW`>/7ojNoj`OoYl3[1_nX`N/8ojO0j`OoY[o[1_nX`>/2ojS1j`KoZ<3[1OnV_n`00onU_ncoZ;o[
ojRoj`06ojRoj`GoZL7[0_nX`>/5oi^jkPKoO:;[1?m/S>44ogF4e003oh^@donCRlSoTh_800CoTh_8
00?oX8o2oj6CaOnQTlD00onQTlD7ok6K`@Co^j;01?o6/LD3ol^fa@OofL[<0ooShm<00ooHg=[oe>KS
omCVh`03omCVh`CobNG/1Onbc>d2ojW3k0KoY[o[1_nW_n/2ojW2j`OoZ<7/0onW_n/3ojJoj`SoYko[
1onX`N/7ojS0j`OoYko[1onW`>/7ojS0j`CoYl3[00?o0000ojNojonW_n/01onW_n/>ojS0j`kooooo
00?o0000ooooooooool01oooool001Cooooo00?o0000ooooooooool04_ooool2o`0001Gooooo00?o
Yl3[ojNojonW_n/01?nW_n/6ojO0j`SoZ<3[1onW`>/7ojNoj`GoYl3[0_nX`>/6ojS1j`KoYl3[0_nW
_n/7ojJoj`?oZ<3[1?nY`N/7ojS0j`03ojJok?nU_ncoYKo/00?oYKo/2?nX_n/00onY`N_oZ<3[ojS0
j`04ojS0j`GoVk[^1_mlX^/4ofb<h@CoMHCD1_n<R/`6oj6Ca@Oo/I_10onkX/06olJaa@03ol^faOoI
b/cofL[<00GofL[<1?oShm<01?oPmmWoe>KSomCVhooDi^<7olWUk003ok;<kOnY`ncoZL?/00CoZL?/
1_nV_n/2ojNoj`KoZL;[1OnX`N`2ojO0j`KoY[o[1_nW_n/2ojS0j`KoZ<7[1_nX`>/00onW`>_oYko[
ojNoj`06ojNoj`?oYl3[2onX`>/01OnW`>_oYko[ojNojonW_n_o000000WoYko[3?nX`>/00onW`>_o
ooooooooo`0<ooooo`03o`000?oooooooooo00Oooooo000Dooooo`03o`000?oooooooooo00oooooo
0ol0000Hooooo`OoYko[1onW`>/7ojS0j`OoYl3[1onW_n/00onW`>_oZ<3[ojS0j`04ojS0j`KoZ<7[
0_nW`>/6ojNoj`GoY[o[0_nW_n/7ojW1j`GoZ<3[0_nW`>/6ojFok0KoZ;o[0_nY`N/7ojS0j`GoVk[^
1OmlX^/4ofb<h@GoMHCD1_n<R/`5oj6Ca@So/I_100?o^j;0olJaaOo6/LD01Oo6/LD7omW:c0Cohn?C
0ooPmmT00ooDi^?obNG/olWUk005olWUk003okODkonY`ncoZL?/00KoZL?/0onV_n/3ojJnj`SoZL;[
00?oZ<7/ojO0jonW`>/01?nW`>/6ojJoj`;oYko[1_nX`>/6ojS1j`;oZ<3[1OnW`>/7ojNoj`koZ<3[
1?nW_n/00ol0003oYko[ojNoj`04ojNoj`?oYl3[2OnX`>/5ojO0j`gooooo00?o0000ooooooooool0
1oooool001Cooooo00?o0000ooooooooool03?ooool3o`0001cooooo2?nW_n/6ojO0j`SoZ<3[1_nW
`>/7ojNoj`OoZ<3[0onX`N/4ojS0j`OoYko[00?oY[o[ojNojonW_n/01?nW_n/7ojW1j`03ojS0jonW
`>_oYl3[00CoYl3[1_nU_n`2ojRoj`KoZL7[1OnX`>/00onU_ncoRK?aohVcl@03ohVcl@CoFiG]0_ml
X^/4ofb<h@CoMHCD1_n<R/`6oj6Ca@Ko/I_100?o^Z_9olJaaOo6/LD01_o6/LD00ooEb/oofL[<omW:
c003omW:c0Cohn?C0ooPmmT3om7ji0CobNG/1?nge>l6ojW3k003ojJojonV_^_oY[k[00GoY[k[1_nY
`^/00onY`^coYl3[ojO0j`06ojO0j`?oY[o[0onV_^/8ojS0j`?oZ<7[0onX`>/7ojO0j`OoYko[3_nX
`>/4ojNoj`03o`000?nW_n_oYko[00OoYl3[1onX`>/7ojO0j`cooooo00?o0000ooooooooool01ooo
ool001?ooooo0ol0000:ooooo`?o00008?ooool8ojNoj`KoYl3[2?nX`>/6ojO0j`OoYko[3_nX`>/5
ojNoj`;oY[o[1onW_n/7ojW1j`OoYl3[1_nU_n`8ojW1j`03ojS0jonU_ncoYKo/00?oYKo/1On9/o45
oe^Ek@;o>gSQ0_m/S>45ogF4e0KoS8[<1OnQTlD5ok6K`@?o^Z_91_o6/LD3omG:c`?ofL[<1?oShm<3
on3gf@GodO[T00?obNG/okODkonge>l01Onge>l2ojW3k0GoY[o[1onV_^/2ojW2j`GoZL;/1_nW`>/0
0onW_n_oY[k[ojJnj`05ojJnj`KoZ<3[00?oZ<7[ojS0jonX`>/01OnX`>/5ojO0j`WoYko[0onX`>/3
ojS1j`SoZ<3[1?nW_n/00ol0003oYko[ojNoj`07ojO0j`OoZ<3[1onW`>/;ooooo`03o`000?oooooo
oooo00Oooooo000Dooooo`03o`000?oooooooooo00Kooooo0ol0000Uooooo`OoYko[0onW`>/;ojS0
j`?oYl3[2_nW_n/>ojS0j`03ojNojonV_n_oY[o[00CoY[o[1OnW_n/2ojS0j`OoZL7[1OnW`>/2ojJo
k0KoYKo/2?nY`N/6ojFok0GoRK?a1OmKUNd4oc]hh@CoMHCD1_n<R/`5oj6Ca@?o/I_11_njZlT4olJa
a@GoeL[?00?ofL[<on?SdooShm<00_oShm<3on3gf@GodO[T0oo2k?45okODk`;oZL?/1onV_n/5ojJn
j`WoZL;/0_nW`>/5ojNoj`OoY[k[0_nX`>/5ojS1j`OoZ<3[00?oYl3[ojNojonW_n/02OnW_n/00onX
`>_oZ<7[ojS1j`05ojS1j`KoZ<3[1OnW_n/00ol0003oYko[ojNoj`06ojO0j`WoZ<3[0onW`>/3ojNo
j`_ooooo00?o0000ooooooooool01oooool001Cooooo00?o0000ooooooooool00oooool3o`0002Wo
oooo1OnW_n/00onW`>_oZ<3[ojS0j`0=ojS0j`koYko[2_nX`>/3ojO0j`OoY[o[00?oYko[ojS0jonX
`>/01?nX`>/7ojW1j`03ojO0jonV_ncoY[o/00CoY[o/1_nU_n`8ojW1j`KoYKo/1On9/o45oe^Ek@?o
>gSQ0_mEOml2ogF4e0KoS8[<1_nQTlD00onaVl7o^Z_9okZ[b@05okZ[b@?oa[751_oEb/l3on3[f@04
on?SdooPmmWoh?OIon3gf@CodO[T1_o2k?400onge>ooZL?/ojW3k004ojW3k0OoY[o[00?oY[k[ojW2
k?nY`^`02OnY`^`2ojO0j`KoYko[1_nV_^/00onW_n_oZ<7[ojS1j`06ojS1j`?oZ<3[0onW`>/9ojNo
j`GoZ<3[1onX`N/2ojS0j`WoYko[00?o0000ojNojonW_n/00_nW`>/;ojS0j`03ojO0jonW_n_oYko[
00GoYko[2oooool00ol0003oooooooooo`06ooooo`004oooool01?l0003oooooooooooooool3o`00
02gooooo00?oYko[ojO0jonW`>/00onW`>/?ojS0j`koYko[1onX`>/6ojO0j`SoY[o[1_nX`>/5ojW1
j`;oZ<3[1onV_n`3ojFok0CoY[o/1onY`N/3ojFok0?oXkk]1Omk[o@3oc67k0;oFiG]0olkN>44oeEo
g`KoS8[<0onQTlD2ojBQdPWo^Z_900?oa[75omG:cooEb/l01?oEb/l4on3[f@?oe?oF0onjo=000ooA
n^Co`^caol;/l@04ol;/l@;o/<k_1onY`n`3ojJoj`?oY[k[2OnY`^`6ojO0j`KoYko[0_nV_^/5ojNo
j`OoZ<7[1onW`>/7ojNoj`OoZ<3[1OnX`N/2ojS0j`[oYko[00?oYl3[o`000?nW`>/02_nX`>/5ojO0
j`OoYko[2_ooool00ol0003oooooooooo`06ooooo`004oooool4o`00037ooooo1_nW`>/?ojS0j`ko
Yko[1onX`>/6ojO0j`SoY[o[1_nX`>/00onY`N_oZ<3[ojS0j`04ojS0j`koY[o/1OnY`N/2ojW1jPKo
Xkk]1Omk[o@5oc67k003o`1Qe_lkN>7o>gSQ00?oEGoO1_n0T]/6ojBQdPOo^Z_90_o8bM/5omG:c`Co
h>_I0ooDomH3ok[ld0?o^OS^0_o2k?46ok3>k`GoZL?/0_nW_^X6ojJnj`OoZL;/2?nW`>/3ojNoj`?o
Y[k[1onW_n/7ojS1j`OoYl3[1onW_n/7ojS0j`03ojS1jonX`>_oZ<3[00CoZ<3[1onW_n/4ojO0j`03
o`000?nW`>_oZ<3[00KoZ<3[2?nW`>/6ojNoj`[ooooo00?o0000ooooooooool01_ooool001?ooooo
0_l0000dooooo`KoYl3[3OnX`>/2ojO0j`coYko[2OnX`>/6ojO0j`SoY[o[0onX`>/3ojW0j`OoZ<3[
3_nV_n`00onY`N_oZL7ZojW1jP04ojW1jPKoXkk]1Omk[o@5oc67k0;o067F1?mEOml6oh2Bf`KoY:7B
1OnjZlT4olS9f`?oeL[?1?oPjmT3omCoeP;o^_c@1?nin>h2okCLm0So/<k_00?oZL?/ojNnj_nW_^X0
1?nW_^X6ojJnj`OoZL;/1_nW`>/00onW_n_oY[k[ojJnj`05ojJnj`GoYko[0_nX`N`7ojS1j`?oYl3[
2onW_n/3ojS0j`?oZ<7[2?nX`>/7ojNoj`?oYl3[00?o0000ojO0jonW`>/01onX`>/6ojO0j`SoYko[
2Oooool00ol0003oooooooooo`06ooooo`001Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2?ooool00ol0003oooooooooo`0booooo`OoYl3[2?nX`>/6ojO0j`SoYko[3?nX`>/7ojO0j`SoY[o[
1_nY`>/7ojS0j`[oY[o/1?nW_n`7ojW1jPKoXkk]1_mj/?H2oab4j0;o<HO/0_l0HMH4oeEog`GoP9;K
1_nTXM83okZ[b@Oob<WK00?oeL[?on3[fOoPjmT00_oPjmT3omCoeP04ok[ld?nin>ko^OS^okWhkPKo
]=cd1_n`c^l00onW_n_oYkkZojNnjP06ojNnjP?oY[k[2_nY`^`2ojO0j`GoYko[1onV_^/00onW_n_o
Z<7/ojS1k004ojS1k0GoZ<7[00?oYl3[ojNojonW_n/02onW_n/00onX`>_oZ<7[ojS1j`05ojS1j`Ko
Z<3[00?oYl3[ojNojonW_n/01_nW_n/3ojO0j`03o`000?nX`>_oZ<3[00OoZ<3[0_nW`>/<ojNoj`So
oooo00?o0000ooooooooool01_ooool00005oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Wooooo00?o0000ooooooooool0<oooool6ojO0j`OoZ<3[1onW`>/7ojNo
j`goZ<3[1onW`>/8ojJoj`KoZL3[1onX`>/7ojJok0OoYko/1OnY`NX2ojW0jPKoXkk]1_mj/?H5oab4
j004o`1Qe_lFM^?oEGoOoeEog`KoP9;K1_nTXM800onjZlWob<WKolS9f`05olS9f`CocO?Z00Coh>_I
omCoe_oDomKoe?oF0onBl>03oj_SnPKo]=cd0_n`c^l5ojNoj`KoYkkZ00?oY[o[ojW2k?nY`^`02_nY
`^`2ojO0j`OoYko[0onV_^/3ojO0j`SoZ<7/00?oZ<7[ojO0jonW`>/00onW`>/9ojNoj`GoZ<3[1onX
`N/2ojS0j`GoYl3[1onW_n/4ojS0j`03o`000?nX`>_oZ<3[00KoZ<3[3OnW_n/00onW`>_ooooooooo
o`06ooooo`03o`000?oooooooooo00Kooooo00001?ooooooV9RHob4Q8Oo^k^h4ooooo`05oa0@4?oo
ooooooooooooool@41002_ooool00ol0003oooooooooo`0cooooo`KoYl3[1onX`>/8ojO0j`KoYko[
3OnX`>/8ojO0j`OoY[o[1_nY`>/7ojS0j`OoY[o/1onW_n`00onY`N[oZL3ZojW0jP04ojW0jPKoXkk]
0omj/?H3ohNfm0?o=9Wb0_lLQ>P01?l0B;;o5WKSoaIfholFM^<5oh2Bf`GoY:7B0_nV`Nd6olS9f`Co
cO?Z0onRm/l3oi;`h0KoZn?j0ondg?@3ojW2k0OoYko[0_nW_^X5ojJoj`SoZL;/1_nW`>/5ojNoj`03
ojJnjonW`>_oYl3[00GoYl3[1_nX`N`00onX`N_oYl3[ojO0j`05ojO0j`OoYko[1onX`>/3ojS1j`?o
Z<3[2?nW`>/7ojNoj`CoZ<3[00?o0000ojS0jonX`>/01_nX`>/9ojNoj`GoYl3[1oooool00ol0003o
ooooooooo`06ooooo`000_ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool0
00002oooool2o`0003Cooooo1_nW`>/7ojS0j`SoYl3[1_nW_n/=ojS0j`SoYl3[1OnV_n/2ojNoj`Ko
ZL3[1onX`>/7ojJok0?oYko/1?nW`>`7ojW0jP?oXkk]0onU_n`6ohNfm0Ko=9Wb0olFM^<3of:Sm0;o
P9;K00?oY:7BojK1kOnV`Nd01?nV`Nd3olS9f`GocO?Z0_nRm/l01?mdfjooT_3Poi;`h?nBl>06oj_S
nP;oZLC]1_nY`^`5ojNoj`;oY[kZ1onV_n/3ojW2k0?oZ<7/2?nW`>/00onW_n_oY[k[ojJnj`03ojJn
j`OoYl3[0_nX`N`5ojS1j`OoYl3[1onW_n/5ojS0j`;oZ<7[1_nX`>/6ojO0j`WoYko[0onX`>/00ol0
003oZ<3[ojS0j`07ojS0j`KoYko[2?nW`>/7ooooo`03o`000?oooooooooo00Gooooo0003ooooo`03
ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`00000=ooooo`03o`000?oooooooooo
03;ooooo1_nW`>/8ojS0j`OoYl3[1_nW_n/>ojS0j`OoYl3[00?oY[o[ojNojonW_n/01?nW_n/6ojW0
j`OoZ<3[1onV_n`7ojO0k0OoZL3Z1_nU_n`6ohNfm0Ko=9Wb00?o05:_oaIfholFM^<01OmRXo@7ojK1
k@03olS9foo=ln[ocO?Z00;ocO?Z0_nRm/l00omdfjooEm;Aoi_No@04oi_No@;oZn?j1_nYa>d6ojW2
k003ojNojonV_^[oY[kZ00CoY[kZ1OnV_n/2ojS2k0KoZ<7/1_nW`>/00onW_n_oY[k[ojJnj`05ojJn
j`GoYl3[0_nX`N`7ojS1j`?oYl3[2onW_n/00onX`>_oZ<7[ojS1j`04ojS1j`KoZ<3[0_nW`>/;ojNo
j`03ojO0jonX`>_oZ<3[00;oZ<3[00?o0000ojS0jonX`>/01OnX`>/8ojNoj`OoYl3[1oooool00ol0
003oooooooooo`05ooooo`001?ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@oooo
ooooool03?ooool00ol0003oooooooooo`0booooo`KoYl3[2?nX`>/7ojO0j`KoYko[3_nX`>/5ojO0
j`;oY[o/1onW_n/6ojW0j`OoZ<3[1onV_n`7ojO0k0OoZL3Z1_nU_n`3ohNfm0CoV[__1_mY/?X2o`1B
[PGoHZ?d1OnV`Nd4oh[TnP03olgcj_nRm/ooTM;n00;oTM;n1OnKg_d2ojO4kPSoZLC]0onY`^`3ojNn
jPOoY[kZ00?oY[o[ojS2k?nX`^`01?nX`^`6ojS1k0;oYl3[1OnW_n/7ojJnj`03ojO0jonX`NcoZ<7/
00CoZ<7/1OnX`N/2ojO0j`coYko[00?oZ<3[ojS1jonX`N/01_nX`N/3ojS0j`?oYl3[2OnW_n/5ojO0
j`CoZ<3[00Co0000ojS0jonX`>_oZ<3[3?nW_n/7ojO0j`Kooooo00?o0000ooooooooool01Oooool0
0005o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00oooooo00?o
0000ooooooooool0<_ooool3ojO0j`_oZ<3[1onW`>/6ojNoj`koZ<3[00?oYl3[ojJok?nV_n`01?nV
_n`5ojNoj`;oYl3[1_nY`>/7ojS0j`OoY[o/1OnW`>`2ojK0k0OoZL3Z0onU_n`3ojRojPOoV[__0omY
/?X4oi>klP;oL;_m00Go05:^o`jHfOmRXoCoHZ?dojK1k@06oh[TnP03o`000?nAd_koTM;n00CoTM;n
00?oVmkmojO4k_nWa>h01?nWa>h6ojW4k@SoYkkZ1OnV_^X9ojS2k0?oZ<7/2_nW_n/3ojJnj`CoYl3[
1onX`N`00onX`N_oYl3[ojO0j`04ojO0j`SoYko[1OnX`>/6ojS1j`03ojS0jonW`>_oYl3[00GoYl3[
1_nW_n/8ojO0j`CoZ<3[00?o0000ojS0jonW_n/02_nW_n/:ojO0j`Gooooo00?o0000ooooooooool0
1Oooool00005oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^013o
oooo0_l0000dooooo`goZ<3[1onW`>/3ojNoj`?oYl3[3_nX`>/7ojJok003ojNojonW`>_oYl3[00Co
Yl3[1_nY`>/7ojS0j`OoY[o/00?oYl3/ojK0k?nV`>`01?nV`>`5ojW0jP;oZL7[1_nX_nX5oiZkk`;o
YKk[1onC^o83og2ko@?oW;k`0_l>V=T00on:i?[o=kZ^oi74n003oi74n0?oTM;n1?nU`Nd6ojO4kP;o
ZLC]3?nW_^X00onV_^[oZ<;/ojS2k009ojS2k0;oZ<3[3OnW_n/7ojO0j`?oZ<7/0onX`N/8ojO0j`Ko
Yko[1onX`>/2ojS1j`GoZ<3[1onW`>/6ojNoj`KoYl3[1OnX`>/00ol0003oZ<3[ojS0j`07ojNoj`co
Yl3[00?oZ<3[ooooooooool00oooool00ol0003oooooooooo`05ooooo`007oooool00ol0003ooooo
ooooo`0booooo`goZ<3[3OnW`>/>ojS0j`OoY[o/1onW`>/6ojW0j`OoZ<3[2?nV_n`6ojK0k003ojW0
j_nY`N_oZL7[00CoZL7[1_nX_nX00onJ^nooYKk[ojFnj`04ojFnj`GoTk_b0_nU_^/7oibnl0GoTLCh
0_nU_n`7ojG1k@?oYlC^3OnW_^X3ojO1k0WoZ<;/1_nX`>/=ojNoj`GoYl3[0_nX`N`6ojS1j`KoYl3[
2?nW_n/5ojS0j`;oZ<7[1onX`>/3ojO0j`[oYko[0_nW`>/9ojS0j`03o`000?nX`>_oZ<3[00OoYko[
2?nW`>/5ojS0j`Cooooo00?o0000ooooooooool01Oooool0023ooooo00?o0000ooooooooool0<_oo
ool=ojS0j`goYl3[3_nX`>/7ojJok0OoYl3[1_nY`>/8ojS0j`OoY[o/0onV`>`3ojG0k@OoZL7[0onX
_nX3ojVojPOoYKk[00?oTk_bojFnjonU_^/01?nU_^/7oibnl003oi74n?nU_ncoYKo/00CoYKo/1OnU
`Nd00onW_^WoYkkZojNnjP0:ojNnjPSoYl7/1_nX`^`00onX`NcoZ<3[ojS0j`06ojS0j`?oYko[0onW
_^X7ojNoj`03ojO0jonX`NcoZ<7/00CoZ<7/1_nX`N/2ojO0j`coYko[00?oZ<3[ojS1jonX`N/01?nX
`N/5ojS0j`03ojO0jonW_n_oYko[00[oYko[0_nW`>/:ojS0j`03ojNojol0003oYko[00SoYko[1OnW
`>/8ojS0j`?ooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool0<_ooool>
ojS0j`goYl3[2_nX`>/3ojO0j`OoY[o/1onW`>/6ojW0j`SoZ<3[1OnV_n`2ojJoj`KoYL3]1OnY`N/2
ojO1k0KoZKoZ1OnU_^/2ojRnj@OoYKk[0onL__03ojNnjPSoYKo/00?oYL7]ojNnjOnW_^T00onW_^T8
ojNnjPcoYl7/0_nX`^`5ojS1k0KoZ<3[2?nW_^X5ojNoj`WoZ<7/0onX`N/=ojNoj`?oZ<3[2?nX`N/0
0onX`>_oYl3[ojO0j`03ojO0j`SoYko[1_nW`>/6ojS0j`CoYko[00?o0000ojNojonW_n/01_nW_n/7
ojO0j`KoZ<3[00?oYl3[ooooooooool00_ooool00ol0003oooooooooo`04ooooo`008_ooool00ol0
003oooooooooo`0booooo`koZ<3[3OnW`>/7ojS0j`KoYl3[1onV_n`7ojO0j`KoZL3[2?nX`>/00onV
_ncoY[o[ojJoj`04ojJoj`KoYL3]00?oZL7[ojO1k?nW`N`01?nW`N`6ojVojP03ojFnjonX_^WoZ;kY
00CoZ;kY1OnU_^/2ojRnjPKoYkkZ1_nU_n`00onX_^WoYkkYojNnj@05ojNnj@GoYkkZ3?nW`N`:ojS1
k0;oZ<3[3?nW_^X00onW_n_oZ<7/ojS1k009ojS1k003ojS0jonW_n_oYko[00coYko[1_nX`>/6ojS1
j`03ojS0jonW`>_oYl3[00GoYl3[1_nW_n/8ojO0j`KoZ<3[1?nW_n/00ol0003oYko[ojNoj`02ojNo
j`_oYl3[0_nX`>/5ojO0j`?ooooo00?o0000ooooooooool01?ooool002?ooooo0_l0000cooooo`ko
Z<3[3OnW`>/7ojS0j`KoYl3[1onV_n`5ojO0j`;oYl3/1_nY`>/8ojS0j`OoY[o[0onU`>d3ojFok0Oo
Yl7/0onY_nX3ojW2j`OoZ;kY00?oYKk[ojRnj_nX_^X01?nX_^X6ojNnjP;oYKo/1OnX_^T7ojNnj@03
ojNnj_nW`NcoYl7/00WoYl7/0_nX`^`;ojS1k0;oYko[2_nW_^X3ojO0j`WoZ<7/1OnX`>/>ojNoj`Ko
Z<3[0_nX`N/5ojS0j`GoYl3[2?nW_n/6ojO0j`SoZ<3[1?nW_n/00ol0003oYko[ojO0j`0:ojO0j`;o
Z<3[2?nW`>/2ooooo`03o`000?oooooooooo00Cooooo000Uooooo`03o`000?oooooooooo03;ooooo
2onX`>/?ojO0j`OoZ<3[1_nW`>/7ojJok003ojO0jonW`>coYl3/00CoYl3/1_nY`>/8ojS0j`GoY[o[
0_nW_n/6ojFok0GoYl7/0_nU`>d6ojW2j`GoZ;kY0_nY`^/7ojRnjP?oYkkZ0onX`>/7ojRnj@?oYkkY
1?nX`N`8ojO1k0KoZ<;/1onX`N`6ojNoj`GoYkkZ0_nW_n/6ojO0j`GoZ<7/0_nX`N/7ojS0j`koYko[
0onX`>/2ojS1j`SoZ<3[00?oYl3[ojNojonW_n/02_nW_n/2ojO0j`[oZ<3[1_nW_n/00ol0003oYko[
ojO0j`06ojO0j`KoZ<3[1_nW`>/01?nW_n_oooooooooool00006ooooo`009_ooool00ol0003ooooo
ooooo`0booooo`OoZ<3[4onW`>/7ojS0j`KoYl3[1OnV_n`2ojK0k0OoYl3/1_nY`>/8ojS0j`03ojJo
jonW_n_oYko[00CoYko[1_nU_n`00onW`NcoYL3]ojG0k@04ojG0k@KoZL;[00?oZ;kYojW2jonY`^/0
1?nY`^/5ojRnjP;oZ<;/1_nX`>/5ojRnj@;oYl;]1onX`N`3ojO1k0?oYl;/2?nX`^`3ojS1k0[oYko[
00?oYkkZojNojonW_n/01?nW_n/6ojO0j`03ojS1k?nX`N_oZ<7[00CoZ<7[1OnX`>/>ojNoj`OoZ<7[
1_nX`>/<ojNoj`;oYl3[2OnX`>/9ojNoj`03o`000?nW_n_oYko[00OoYl3[1_nX`>/2ojO0j`GoYko[
00?oooooo`000?ooool01Oooool002Oooooo00?o0000ooooooooool0<_ooool6ojS0jaCoYl3[1onX
`>/6ojO0j`03ojJok?nV`>coY/3/00CoY/3/1OnW`>`2ojK0k0KoZL3[1_nX`>/2ojW0jPOoYko[0onU
_n`3ojJok0OoYL3]0onY`^/3ojK1k@OoZL;[00?oZ;kZojS2k?nX`^`01?nX`^`6ojS0j`03ojRnjOnW
`^goYl;]00CoYl;]1OnX`N`2ojO1k0KoYl;/1_nX`^`=ojNoj`03ojNnj_nW_n_oYko[00KoYko[0onW
`>/3ojS1k0OoZ<7[00?oZ<3[ojNojonW_n/03?nW_n/;ojS1j`;oZ<3[2onW_n/7ojO0j`OoZ<3[2onW
_n/00ol0003oYl3[ojO0j`07ojO0j`?oZ<3[1?nW`>/6ojNoj`03o`000?oooooooooo00Cooooo000X
ooooo`;o0000<oooool6ojS0jaCoYl3[1onX`>/3ojO0j`CoZ<3[1_nV`>`00onW`>coY/3/ojK0k004
ojK0k0KoZL3[0_nX`>/6ojW0jPGoYko[0_nX_n/6ojJok0GoYL3]0_nV_n`6ojK1k@GoZL;[0_nV`Nd7
ojS2k0?oZ<3[0onV`^d7ojO2k@03ojS1k?nW`NcoYl7/00CoYl7/1_nW`^`2ojS2k0goYko[1OnW_^X6
ojNoj`SoZ<7/1OnX`N/00onW`>_oYko[ojNoj`09ojNoj`?oYl3[2_nX`N/4ojO0j`SoYko[2onW`>/7
ojS0j`OoYko[1?nW`>/00ol0003oYl3[ojO0j`05ojO0j`03ojS0jonW`>_oYl3[00KoYl3[0onW_n/2
ooooo`03o`000?oooooooooo00Cooooo000Zooooo`03o`000?oooooooooo037ooooo1_nX`>/DojO0
j`koZ<3[0onV`>`3ojO0j`OoY/3/0onY`>/3ojS0j`SoZL3Z00?oYko[ojRojonX_n/01?nX_n/6ojJo
k003ojG0kOnV_ncoY[o/00CoY[o/1_nV`Nd00onY`^_oY/7]ojK1k@04ojK1k@GoZ<;/0_nV`N`6ojK2
k@GoYl;]2OnW`N`3ojO2k0goYko[2_nW_^X2ojNoj`coZ<7/00?oZ<7[ojO0jonW`>/00onW`>/7ojNo
j`OoYl3[1OnX`N/00onX`>_oYl3[ojO0j`06ojO0j`GoYko[2onW`>/:ojS0j`OoYko[1?nW`>/01?l0
003oYl3[ojO0jonW`>/5ojS0j`KoYl3[1oooool00ol0003oooooooooo`03ooooo`00:oooool00ol0
003oooooooooo`0aooooo`OoZ<3[4onW`>/>ojS0j`KoYl3[1onV`>`6ojS0j`SoZL3Z1onX_n/3ojJo
k0?oYko[1onV_n`3ojK1k@CoY[o/1_nV`Nd00onX`^coY/7/ojK1k004ojK1k0KoY/;]00?oYl;]ojO1
k?nW`N`02OnW`N`=ojNoj`coYkkZ0onW`N`:ojS1k0[oYl3[1onW_n/7ojO0j`03ojS1jonX`>_oZ<3[
00?oZ<3[1_nW`>/7ojNoj`OoYl3[3?nX`>/9ojNoj`?oYl3[00?o0000ojO0jonX`>/01onX`>/2ojO0
j`[ooooo00?o0000ooooooooool00oooool002cooooo00?o0000ooooooooool0<Oooool7ojS0ja?o
Yl3[3_nX`>/6ojO0j`OoY/3/1_nX`>/8ojW0jPGoZ;o[0_nX_nX6ojNoj`GoY[o/0_nW_n/7ojJok0?o
Y/7]0onV_n`7ojK1k0?oY/;]1?nW`>/7ojO1k0goYko[2onW_^X8ojO1k0GoZ<7/3?nW`>/:ojNoj`?o
Yl3[0onX`N/7ojS0j`;oYl3[2onW_n/7ojO0j`SoZ<3[2onW_n/5ojO0j`03o`000?nW`>_oZ<3[00Go
Z<3[3Oooool00ol0003oooooooooo`03ooooo`00;Oooool2o`0003;ooooo1onX`>/CojO0j`koZ<3[
1_nW`>/7ojK0k0?oZ<3[1?nW`>`7ojW0jP03ojRojonX_n[oZ;oZ00CoZ;oZ1_nW_n/00onV_ncoYko[
ojNoj`04ojNoj`GoY[o/00?oYko[ojJok?nV_n`01OnV_n`5ojK1k0;oYko[1onW`>/3ojO1k0goYko[
2onW_^X<ojO1k003ojS1k?nW`>_oYl3[00WoYl3[3OnW_n/2ojO1k0KoZ<7[1OnX`>/2ojO0j`[oYko[
2_nW`>/3ojS0j`CoYl3[2?nW_n/9ojO0j`04o`000?nW`>_oZ<3[ojS0ja3ooooo00?o0000oooooooo
ool00oooool002oooooo00?o0000ooooooooool0<?ooool7ojS0ja?oYl3[3_nX`>/6ojO0j`OoY/3/
1onW`>`3ojW0jP?oZ<7[2?nX_nX3ojNoj`?oZ;oZ1onW_n/00onV_ncoYko[ojNoj`03ojNoj`OoY[o/
00?oY/7/ojNojonW_n/01?nW_n/5ojO0j`03ojRoj_nW_n_oYko[00[oYko[00?oZ;kZojNnj_nW_^X0
2_nW_^X00onW`>coYl7/ojO1k009ojO1k0;oZ<7/2OnW`>/=ojNoj`KoYl7/1_nX`N/00onX`>_oYl3[
ojO0j`04ojO0j`KoYko[3?nW`>/00onX`>_oYl3[ojO0j`06ojO0j`GoYko[2onW`>/00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo00?ooooo000`ooooo`03o`000?oooooooooo037ooooo1_nX
`>/DojO0j`goZ<3[1_nW`>/7ojK0k0GoYl3/0_nV`>`6ojS1j`KoZ;oZ00?oZL3[ojRoj_nX_nX01OnX
_nX3ojNoj`?oZ;oZ1onW_n/3ojJok0?oZ;oZ2?nW_n/00onW`>_oZ;oZojRojP03ojRojPSoYko[1OnX
_^X8ojNnjPGoYl3/1onW`N`6ojS1k0KoYl3[2onW_n/3ojO0j`SoYl7/0onX`N/:ojO0j`KoYko[2?nW
`>/5ojS0j`KoYl3[1onW_n/6ojO0j`Gooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`03ooooo`00<Oooool00ol0003oooooooooo`0aooooo`OoZ<3[4onW`>/=ojS0j`?oYl3[1?nW_n/6
ojK0k003ojO0k?nV`>coY/3/00CoY/3/1_nX`N/2ojRojPGoZL3[1OnX_nX2ojS0j`KoZ;oZ1OnW_n/8
ojRojPKoYko[2?nX_nX3ojNoj`?oZ;oZ1onX_^X3ojNnjP[oYl3/1onW`N`6ojS1k0;oYl3[3?nW_n/6
ojO0j`KoYl7/00?oZ<3[ojO0jonW`>/02?nW`>/:ojNoj`OoYl3[1_nX`>/2ojO0j`_oYko[0_nW`>/9
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00oooool003;ooooo0_l0000boooo
o`OoZ<3[4OnW`>/3ojO0k0goZ<3[1_nW_n/3ojK0k0?oYl3[1onV`>`3ojS1j`?oYl3/1onY`>/00onX
_n[oZ<3[ojS0j`04ojS0j`KoZ;oZ00?oYko[ojRoj_nX_nX02_nX_nX2ojNoj`[oZ;oZ0_nX_n/6ojRo
jPGoZ;kZ0_nW`N`:ojO0k0[oYl7/0onX`N`AojNoj`KoYl3[0_nW`N`5ojS0j`GoYl3[3OnW_n/9ojO0
j`?oZ<3[0_nW`>/;ojNoj`kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02oooo
o`00=?ooool00ol0003oooooooooo`0`ooooo`OoZ<3[0onW`>/4ojS0j`OoYl3[1_nW`>`=ojS0j`Co
Yko[0_nX_n/6ojO0j`OoY/3/1_nW`>`5ojW0j`;oYl7/1onX`>/3ojRojP?oZ<3[5OnX_nX6ojRoj`Ko
Z;oZ00?oZ;kZojO1k?nW`N`01?nW`N`5ojO0k0goYl7/0_nW`>/DojNoj`?oYl3[1?nX`N`6ojS0j`03
ojO0jonW_n_oYko[00_oYko[4_nW`>/6ojNoja;ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`02ooooo`00=Oooool00ol0003oooooooooo`0`ooooo`koZ<3[1_nW`>/7ojO0k0goZ<3[
00?oYko[ojRojonX_n/00onX_n/6ojO0j`OoY/3/1_nW`>`00onY`>_oYl7/ojO1k004ojO1k0GoZ<3[
0_nW`N`6ojS0j`GoZ;oZ0_nX`N/:ojRojP?oZ<3[1onX_n/3ojRojP[oYl7/00?oYl3/ojO1k?nW`N`0
2onW`N`6ojO0ja;oYko[00?oYl7/ojS1k?nX`N`01_nX`N`3ojS0j`;oYl3[2onW_n/FojO0j`;oYko[
5_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo000fooooo`03o`000?oo
oooooooo033ooooo3_nX`>/6ojO0j`OoYl3/3OnX`>/6ojRoj`?oYl3[0onW_n/7ojK0k0?oYl3/1?nV
`>`6ojO1k003ojS0jonW`NcoYl7/00CoYl7/1_nX`>/00onX_n[oZ<7[ojS1j`04ojS1j`GoZ;oZ0_nW
`N`6ojS0j`GoZ;o[6OnW`N`:ojO0j`koYko[1OnW`N`6ojS1k0OoYl3[1onW_n/GojO0ja_ooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`00=oooool2o`00037ooooo3_nX`>/6
ojO0j`OoYl3/3OnX`>/4ojRoj`;oZ<3[1_nW_n/5ojK0k0;oYl3[1onV`>`3ojO1k0?oY/3/1onW`N`3
ojS0j`CoYl7/1_nX`N/00onX_n[oYl7/ojO1k004ojO1k0KoZ<3[00?oZ;o[ojO1k?nW`N`05_nW`N`;
ojO0j`goYko[2_nW`N`2ojS1k0_oYl3[1onW_n/BojO0jb3ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`02ooooo`00>Oooool00ol0003oooooooooo`0_ooooo`koZ<3[1_nW`>/7ojO0
k0?oZ<3[1?nW`>/6ojS0j`03ojRojonX`>_oZ<3[00?oZ<3[1_nW_n/00onV`>coYl3[ojO0j`04ojO0
j`GoY/3/0_nW`>/6ojK0k0GoYl7/0_nV`>`7ojO1k0?oZ<7[2_nW`N`3ojS0jaSoYl7/2_nW`>/=ojNo
j`;oYl3/2onW`N`<ojO0j`[oYko[3_nW`>/Sooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool00_ooool003[ooooo00?o0000ooooooooool0;oooool>ojS0j`KoYl3[1onW`>`7ojO0j`co
Z<3[0onW_n/4ojRoj`KoYl3[00?oY/3/ojO0jonW`>/01?nW`>/6ojK0k003ojO1k?nV`>coY/3/00Co
Y/3/1OnW`N`2ojO0k0_oYl7/00?oYl3/ojO1k?nW`N`02OnW`N`2ojO0k0[oYl7/2onW`>/=ojNoj`Ko
Yl3/1onW`N`;ojO0j`goYko[2onW`>/Xooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool00_ooool003_ooooo00?o0000ooooooooool0<?ooool=ojS0j`KoYl3[1onW`>`5ojO0j`;oYl3/
3?nX`>/7ojRoj`?oYl3[0onW_n/7ojO0j`?oY/3/1?nW`>/6ojK0k003ojO1k?nW`>coYl3/00CoYl3/
1onW`N`5ojO0k0KoYl7/00?oYl3[ojO0k?nW`>`01?nW`>`5ojO1k0;oYko[2_nW`>/3ojNojP[oYko[
0onW`>/7ojO0k0?oYl7/2onW`>/=ojNoj`[oYl3[;Oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo007ooooo000looooo`03o`000?oooooooooo033ooooo3OnX`>/7ojO0j`KoYl3/00?o
Yl3[ojO0k?nW`>`01?nW`>`<ojS0j`GoZ;o[0_nX`>/6ojNoj`GoYl3[0_nW_n/7ojO0j`?oY/3/0onW
`>/7ojO0k0?oYl7/2OnW`>`2ojO1k0GoYl3[1_nW`>`00onW`NcoYko[ojNoj`04ojNoj`GoYl3[2?nW
_nX5ojNoj`SoYl3[1_nW`>`:ojO0j`goYko[2onW`>/aooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool00Oooool003gooooo0_l0000aooooo`goZ<3[1onW`>/3ojO0k0?oYl3[1onW`>`3
ojS0j`?oYl3[1_nX`>/00onX_n_oZ<3[ojS0j`04ojS0j`KoYko[00?oYl3[ojNojonW_n/01?nW_n/5
ojO0j`;oYko[1_nW`>/5ojO0k003ojNojonW`>coYl3/00SoYl3/0onW_n/7ojO0j`?oYl3/2_nW_n/0
0onW`>_oYkoZojNojP0:ojNojP03ojNojonW`>_oYl3[00[oYl3[1_nW`>`5ojO0j`goYko[3?nW`>/d
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00Oooool003oooooo00?o0000oooo
ooooool0;oooool=ojS0j`GoYl3[0_nX`>/6ojO0j`OoYl3/1_nW`>/=ojS0j`?oYko[1?nX_n/6ojNo
j`03ojO0jonW_n_oYko[00CoYko[1_nW`>/00onW`>coYko[ojNoj`03ojNoj`GoYl3/2?nW_n/5ojO0
j`coYko[0onX_n/:ojNojPcoYl3[1?nW`N`6ojO0k003ojO0jonW_n_oYko[00_oYko[2onW`>/ioooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00Oooool0043ooooo00?o0000oooooooo
ool0;oooool3ojS0j`CoYl3[1_nX`>/00onW`>_oZ<3[ojS0j`04ojS0j`KoYl3[1onW`>`4ojO0j`;o
Yl3/3OnX`>/7ojRoj`?oYko[0onX_nX7ojNoj`?oYl3[2OnW_n/00onW`>coYko[ojNoj`0:ojNoj`03
ojO0jonW_n_oYko[00WoYko[2?nX_n/5ojNojP_oYl3[2_nW`N`3ojO0k0CoYl3[3?nW_n/8ojO0jcgo
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`01ooooo`00@Oooool00ol0003ooooo
ooooo`0_ooooo`OoYl3[3OnX`>/3ojO0j`CoYko[1_nW`>`00onW`>_oYl3/ojO0k003ojO0k0goZ<3[
1OnX_n/2ojS0j`KoZ;oZ1OnW_n/00onX_n_oYko[ojNoj`08ojNoj`?oZ;oZ2_nW_n/4ojRojPOoYko[
3?nX_n/00onW_n[oYl3[ojO0j`08ojO0j`goYl7/2OnW`>/<ojNoj`?oYl3[@Oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo007ooooo0012ooooo`;o0000<?ooool7ojO0j`goZ<3[1onW
_n/3ojO0k0?oYl3[1_nW`>`3ojS0j`CoYl3/1_nX`>/00onX_n_oZ<3[ojS0j`04ojS0j`KoZ;oZ00?o
Yko[ojRojonX_n/00onX_n/5ojNoj`;oZ<3[1_nX_nX5ojNoj`;oZ;o[1onX_nX3ojNoj`;oZ<3[2_nX
_n/4ojO0k0OoYl3[3OnW`N`;ojO0j`coYko[A_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo007ooooo0014ooooo`03o`000?oooooooooo02kooooo1onW`>/=ojS0j`OoYko[1_nW`>/=
ojO0k0?oZ<3[0onW`>`7ojS0j`?oZ;oZ1?nX`>/5ojRoj`03ojNojonX`>_oZ<3[00CoZ<3[1_nX_nX0
0onW_n_oZ;o[ojRoj`04ojRoj`GoZ;oZ1onX`>/5ojRoj`WoYl3/0onW`>/3ojO0k0[oYl7/2onW`>/<
ojNojd[ooooo00?o0000ooooooooool01oooool1o`00007ooooo0Oooool004Gooooo00?o0000oooo
ooooool0;oooool6ojO0j`goZ<3[1onW_n/6ojO0ja?oYl3/1OnX`>/2ojO0k0OoZ<3[0_nX_n/:ojS0
j`?oZ;oZ1?nX`>/6ojRoj`03ojRoj_nX`>_oZ<3[00WoZ<3[00?oZ;o[ojO0k?nW`>`04OnW`>`5ojO1
k0_oYl3[3OnW_n]>ooooo`03o`000?oooooooooo00Kooooo0Ol00001ooooo`7ooooo0016ooooo`03
o`000?oooooooooo033ooooo1OnW`>/>ojS0j`KoYko[0onW`>/3ojNoja?oYl3/00?oZ<3[ojO0k?nW
`>`01?nW`>`5ojS0j`03ojO0k?nX`>_oZ<3[00WoZ<3[0_nW`>`7ojS0j`?oZ;o[0_nW`>`:ojS0j`Co
Yl7/4onW`>`00onW`NcoYl3[ojO0j`08ojO0j`goYko[D_ooool00ol0003oooooooooo`06ooooo`7o
00000Oooool1ooooo`00Aoooool2o`00037ooooo1OnW`>/5ojS0j`;oYl3[1onX`>/3ojNoj`?oZ<3[
1_nW_n/3ojO0k0CoYl3[4onW`>`00onX`>_oYl3/ojO0k003ojO0k0OoZ<3[1_nW`>`5ojS0j`OoYl3/
1OnX`>/2ojO0k0OoYl7/4?nW`>`:ojO0j`goYko[E_ooool00ol0003oooooooooo`05ooooo`7o0000
0Oooool1ooooo`00BOooool00ol0003oooooooooo`0_ooooo`GoYl3[00?oZ<3[ojO0jonW`>/01?nW
`>/=ojS0j`CoYko[0_nX_n/7ojO0j`?oYl3/0onW`>/CojO0k0?oZ<3[2_nW`>`00onX`>_oYl3/ojO0
k009ojO0k003ojS0jonW`>coYl3/00CoYl3/1OnW`N`2ojO0j`_oYl3/2onW`>/=ojNoje[ooooo00?o
0000ooooooooool01?ooool1o`00007ooooo0Oooool004[ooooo00?o0000ooooooooool0;oooool<
ojO0j`goZ<3[00?oYko[ojRojonX_n/00onX_n/5ojO0j`;oYko[1_nW`>/5ojO0k003ojO0jonW`>co
Yl3/02_oYl3/00?oYl7/ojO0jonW`>/01?nW`>/7ojO0k0[oYl3[3OnW_n]Oooooo`03o`000?oooooo
oooo00?ooooo0Ol00001ooooo`7ooooo001;ooooo`03o`000?oooooooooo02oooooo3?nW`>/>ojS0
j`GoZ;o[00?oYl3[ojNojonW_n/01?nW_n/6ojO0j`03ojO0k?nW`>_oYl3[00?oYl3[1OnW`>`2ojO0
j`_oYl3/0_nW`>/9ojO0k0?oYl3[2_nW`>`:ojO0j`?oYl3/0onW_n/7ojO0j`goYko[H_ooool00ol0
003oooooooooo`03ooooo`7o00000Oooool1ooooo`00C?ooool2o`00033ooooo3?nW`>/5ojS0j`;o
Yl3[1onX`>/2ojRoj`CoZ<3[1_nW_n/3ojO0j`CoYko[1OnW`>/00onW`>coYl3[ojO0j`04ojO0j`Oo
Yl3/1_nW`>/4ojO0k0SoYl3[1OnW`>`2ojNoj`[oYl3[2OnW_n/3ojO0j`goYko[I_ooool00ol0003o
ooooooooo`03ooooo`7o00000Oooool004kooooo00?o0000ooooooooool0;_ooool<ojO0j`03ojS0
jonW`>_oYl3[00CoYl3[1OnX`>/00onW`>_oZ<3[ojS0j`05ojS0j`?oYko[0onX`>/7ojNoj`;oYl3[
1?nW_n/6ojO0j`?oYl3/1?nW_n/6ojO0j`03ojO0k?nW`>_oYl3[00WoYl3[00?oYl3/ojNojonW_n/0
1?nW_n/5ojO0jaSoYko[K?ooool00ol0003oooooooooo`02ooooo`7o00000Oooool004oooooo00?o
0000ooooooooool0;ooooolBojO0j`03ojS0jonW`>_oYl3[00?oYl3[3OnX`>/5ojNoj`03ojS0jonW
_n_oYko[00GoYko[0onW`>/3ojRoj`OoYko[0onW`>/3ojNoj`WoYl3[2_nW_n/00onW`>_oYko[ojNo
j`0EojNojg7ooooo00Go0000ooooooooooooooooo`000001ooooo`00D?ooool00ol0003ooooooooo
o`0_ooooo`;oYl3[1?nW_n/9ojO0j`CoYl3/1OnW`>/=ojS0j`03ojNojonX`>_oZ<3[00?oZ<3[1OnW
_n/2ojS0j`KoZ;o[1OnW_n/00onX_n_oYko[ojNoj`05ojNoj`?oYl3[0onX_n/:ojNoj`?oZ;o[2OnW
_n/4ojS0j`OoYko[M?ooool01Ol0003ooooooooooooooooo0000007ooooo001Aooooo`;o0000<?oo
ool6ojNoj`KoYl3[1onW`>`6ojO0ja;oZ<3[00?oYko[ojS0jonX`>/01?nX`>/6ojRoj`03ojNojonX
_n_oZ;o[00?oZ;o[1OnW_n/2ojS0j`KoZ;o[1OnW_n/00onX`>_oZ;o[ojRoj`05ojRoj`?oYko[2_nX
`>/3ojNojgSooooo00Co0000oooooooooooo00000Oooool005?ooooo00?o0000ooooooooool0;_oo
ool4ojNoj`SoYl3[1OnW`>`8ojO0j`?oZ<3[0onW`>/CojS0j`?oZ;o[0onX`>/6ojRoj`03ojNojonX
`>_oZ<3[00CoZ<3[1_nX_n/00onW_n_oZ<3[ojS0j`03ojS0j`GoZ;o[0_nW`>/;ojS0jggooooo00?o
0000ooooool000000Oooool005Cooooo00?o0000ooooooooool0;_ooool00onW_n_oYl3[ojO0j`09
ojO0j`03ojO0k?nW`>_oYl3[013oYl3[1OnX`>/00onW`>_oZ<3[ojS0j`08ojS0j`?oYl3[1_nX`>/3
ojRoj`[oZ<3[0onX_n/9ojS0j`03ojRojonW`>_oYl3[00CoYl3[1onX`>^0ooooo`03o`000?oooooo
0000007ooooo001Eooooo`03o`000?oooooooooo02kooooo2OnW`>/4ojNoja;oYl3[00?oZ<3[ojO0
jonW`>/00onW`>/5ojS0j`;oYl3/1_nW`>/4ojS0j`;oYl3[2_nX`>/2ojO0j`[oZ<3[2_nW`>/3ojS0
jhCooooo0Ol00001ooooo`7o0000001Fooooo`;o0000;oooool3ojO0j`?oZ<3[1onW_n/2ojO0j`Co
Yko[2OnW`>/4ojO0k0GoYl3[00?oZ<3[ojO0k?nW`>`01?nW`>`6ojO0j`03ojS0jonW`>_oYl3[00?o
Yl3[1OnX`>/2ojO0k0GoYl3[1OnX`>/2ojO0k0[oYl3[R_ooool2o`000000F?ooool00ol0003ooooo
ooooo`0]ooooo`KoZ<3[1OnW_n/2ojS0j`KoYko[0onW`>/3ojNoj`OoYl3/0_nW`>/:ojO0k0?oYl3[
0onW`>`6ojO0j`03ojS0jonW`>coYl3/00CoYl3/1OnW`>/00onX`>_oYl3/ojO0k004ojO0k0GoYl3[
SOooool3o`000000FOooool00ol0003oooooooooo`0]ooooo`KoZ<3[00?oYko[ojS0jonX`>/01?nX
`>/4ojNoj`;oZ;o[1_nW_n/5ojO0k003ojNojonW`>coYl3/00SoYl3/0onW`>/6ojO0k0?oYl3[2_nW
`>`2ojO0j`[oYl3/00?oYl3[ooooooooool0R_ooool4o`0000?ooooo001Jooooo`03o`000?oooooo
oooo02gooooo3OnX`>/00onW_n_oZ;o[ojRoj`03ojRoj`KoYko[00?oYl3/ojNojonW_n/00onW_n/5
ojO0k0;oYko[1_nW`>/4ojO0k0;oYl3[2_nW`>`3ojO0j`WoYl3/S?ooool3o`0000Oooooo001Koooo
o`03o`000?oooooooooo02gooooo3OnX`>/6ojRoj`?oYko[1?nX_n/5ojNoj`03ojO0k?nW_n_oYko[
00CoYko[1_nW`>/00onW`>coYl3[ojO0j`03ojO0j`GoYl3/2?nW`>/3ojO0k8gooooo1?l0000:oooo
o`00G?ooool2o`0002kooooo1OnX`>/2ojO0j`KoZ<3[0onX_n/4ojS0j`KoZ;o[0_nW_n/4ojRoj`Ko
Yko[0onW`>/3ojNoj`KoYl3[00?oYl3/ojO0jonW`>/02?nW`>^=ooooo`Co00003_ooool005kooooo
00?o0000ooooooooool0;?ooool00onX`>_oYl3[ojO0j`04ojO0j`CoZ<3[0_nW`>/7ojS0j`?oZ;o[
0_nX`>/7ojRoj`?oYko[0onX_n/6ojNoj`?oYl3[1?nW_n/6ojO0jhcooooo1?l0000Booooo`00Gooo
ool00ol0003oooooooooo`0]ooooo`KoYl3[00?oZ<3[ojO0jonW`>/00onW`>/5ojS0j`;oYl3[1OnX
`>/5ojRoj`;oZ<3[1_nX_n/3ojNoj`?oZ<3[1onW_n/2ojO0jh_ooooo1?l0000Fooooo`00H?ooool0
0ol0003oooooooooo`0]ooooo`coYl3[00?oZ<3[ojO0jonW`>/01?nW`>/5ojS0j`03ojRojonX`>_o
Z<3[00CoZ<3[1?nX_n/8ojS0j`GoYko[Roooool3o`0001[ooooo001Qooooo`;o0000;ooooolBojO0
j`;oZ<3[1?nW`>/6ojS0j`03ojRojonX`>_oZ<3[00WoZ<3[00?oYko[ooooooooool0R?ooool4o`00
01gooooo001Sooooo`03o`000?oooooooooo02gooooo6?nW`>/3ojS0j`?oYl3[2OnX`>^9ooooo`Co
00008Oooool006Cooooo00?o0000ooooooooool0;OoooolNojO0j`?oZ<3[R_ooool4o`0002Gooooo
001Uooooo`03o`000?oooooooooo02gooooo6onW`>^;ooooo`Co0000:Oooool006Kooooo0_l0000^
ooooo`;oYl3[1?nW_n/AojO0jh_ooooo0ol0000]ooooo`00J?ooool00ol0003oooooooooo`0/oooo
o`KoYko[0onW`>/3ojNoj`OoYl3[R_ooool4o`00033ooooo001Yooooo`03o`000?oooooooooo02co
oooo0onW_n/4ojS0j`GoYko[0onW`>^9ooooo`Co0000=?ooool006[ooooo00?o0000ooooooooool0
;?ooool7ojS0j`;oYko[R_ooool4o`0003Sooooo001[ooooo`;o0000;Oooool5ojS0jhWooooo1?l0
000looooo`00KOooool00ol0003oooooooooo`0[ooooo`03ojS0jooooooooooo08Oooooo0ol00010
ooooo`00K_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo08?ooooo1?l00013oooo
o`00Koooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo07oooooo1?l00017ooooo`00
L?ooool2o`0002Wooooo00?o0000ooooooooool0Noooool4o`0004_ooooo001booooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool0Moooool4o`0004oooooo001cooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0M?ooool3o`0005?ooooo001dooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool0L?ooool4o`0005Kooooo001eooooo`03o`000?oooooooooo02?o
oooo00?o0000ooooooooool0K?ooool4o`0005[ooooo001fooooo`;o00008oooool00ol0003ooooo
ooooo`1Xooooo`Co0000G_ooool007Sooooo00?o0000ooooooooool08?ooool00ol0003ooooooooo
o`1Tooooo`Co0000H_ooool007Wooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`1Q
ooooo`?o0000I_ooool007[ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1Moooo
o`Co0000JOooool007_ooooo0_l0000Nooooo`03o`000?oooooooooo05Wooooo1?l0001]ooooo`00
OOooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo05Gooooo1?l0001aooooo`00O_oo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo057ooooo1?l0001eooooo`00Ooooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04kooooo0ol0001iooooo`00P?ooool2o`00
01Wooooo00?o0000ooooooooool0B_ooool4o`0007cooooo0022ooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool0A_ooool4o`00083ooooo0023ooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool0@_ooool4o`0008Cooooo0024ooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0?_ooool4o`0008Sooooo0025ooooo`;o00004oooool00ol0003oooooooooo`0l
ooooo`?o0000S?ooool008Oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0hoooo
o`Co0000Soooool008Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0dooooo`Co
0000Toooool008Wooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0`ooooo`Co0000
Uoooool008[ooooo0_l0000>ooooo`03o`000?oooooooooo02cooooo1?l0002Kooooo`00S?ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Wooooo0ol0002Oooooo`00SOooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo02Gooooo1?l0002Rooooo`00S_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo027ooooo1?l0002Vooooo`00Soooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo01gooooo1?l0002Zooooo`00T?ooool2o`0000Sooooo00?o
0000ooooooooool06Oooool4o`000:kooooo002Booooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool05_ooool3o`000;;ooooo002Cooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool04_ooool4o`000;Gooooo002Dooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool03_ooool4o`000;Wooooo002Eooooo`;o00000oooool00ol0003oooooooooo`0:ooooo`Co0000
_Oooool009Oooooo00Co0000oooooooooooo00002?ooool4o`000<7ooooo002Hooooo`03o`000?oo
oooo000000Gooooo0ol00035ooooo`00VOooool2o`000003ooooool0003o000000;o0000b?ooool0
09[ooooo0_l0003<ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0538698, 0.0432538, \
0.0035044, 0.0035044}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[.12586 .2075 -12 -8.99448 ]
[.12586 .2075 0 .00552 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.56094 .0364 -5.16972 -9 ]
[.56094 .0364 .83028 0 ]
[.75679 .08071 0 -6.17777 ]
[.75679 .08071 12 2.82223 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.9429 .3657 0 -5.9083 ]
[.9429 .3657 6 3.0917 ]
[.02494 .25992 -18 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.01611 .31527 -18 -2.78472 ]
[.01611 .31527 0 6.21528 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00254 .43215 -12 -2.88407 ]
[-0.00254 .43215 0 6.11593 ]
[-0.0124 .49393 -12 -2.93688 ]
[-0.0124 .49393 0 6.06312 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
[(-2)] .12586 .2075 1 .99877 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.56863 .04703 m
.57247 .05235 L
s
[(2)] .56094 .0364 .72324 1 Mshowa
.125 Mabswid
.18558 .19702 m
.18832 .19985 L
s
.23703 .17687 m
.23971 .17975 L
s
.28951 .15632 m
.29214 .15925 L
s
.39772 .11395 m
.40023 .11699 L
s
.4535 .09211 m
.45595 .0952 L
s
.51046 .06981 m
.51284 .07294 L
s
.08568 .23614 m
.08851 .23887 L
s
.62804 .02377 m
.63027 .02701 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.7445 .0853 m
.73835 .08759 L
s
[(-2)] .75679 .08071 -1 .37284 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.93037 .36962 m
.92411 .37158 L
s
[(2)] .9429 .3657 -1 .31296 Mshowa
.125 Mabswid
.7708 .12553 m
.7671 .12688 L
s
.79613 .16428 m
.79242 .1656 L
s
.82054 .20161 m
.81682 .20291 L
s
.86679 .27235 m
.86305 .2736 L
s
.88871 .30589 m
.88497 .30711 L
s
.9099 .3383 m
.90615 .3395 L
s
.71716 .04348 m
.71349 .04489 L
s
.95018 .39992 m
.94642 .40107 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(-20)] .02494 .25992 1 -0.39157 Mshowa
.02837 .31059 m
.0345 .30825 L
s
[(-10)] .01611 .31527 1 -0.38117 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.00981 .42772 m
.01599 .4255 L
s
[(10)] -0.00254 .43215 1 -0.3591 Mshowa
0 .48963 m
.0062 .48748 L
s
[(20)] -0.0124 .49393 1 -0.34736 Mshowa
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.658 .75 .918 r
.39362 .69478 .40169 .7019 .4152 .69802 .40717 .69087 Mtetra
.654 .749 .919 r
.40717 .69087 .4152 .69802 .42878 .69412 .42079 .68705 Mtetra
.653 .752 .922 r
.42079 .68705 .42878 .69412 .44243 .69031 .43448 .68327 Mtetra
.655 .754 .923 r
.43448 .68327 .44243 .69031 .45614 .68654 .44824 .6794 Mtetra
.656 .753 .921 r
.44824 .6794 .45614 .68654 .46992 .6827 .46207 .67546 Mtetra
.658 .752 .919 r
.46207 .67546 .46992 .6827 .48378 .67879 .47597 .67142 Mtetra
.659 .749 .917 r
.47597 .67142 .48378 .67879 .4977 .67481 .48994 .66737 Mtetra
.656 .748 .918 r
.48994 .66737 .4977 .67481 .5117 .67077 .50398 .66339 Mtetra
.654 .75 .92 r
.50398 .66339 .5117 .67077 .52577 .66674 .5181 .65947 Mtetra
.653 .753 .923 r
.5181 .65947 .52577 .66674 .53991 .66279 .53229 .65552 Mtetra
.654 .755 .924 r
.53229 .65552 .53991 .66279 .55412 .65885 .54655 .65152 Mtetra
.655 .754 .923 r
.54655 .65152 .55412 .65885 .56841 .65488 .56088 .64748 Mtetra
.656 .754 .922 r
.56088 .64748 .56841 .65488 .58277 .65088 .5753 .64339 Mtetra
.657 .753 .921 r
.5753 .64339 .58277 .65088 .59721 .64683 .58978 .63923 Mtetra
.658 .751 .919 r
.58978 .63923 .59721 .64683 .61172 .64276 .60434 .63504 Mtetra
.657 .749 .918 r
.60434 .63504 .61172 .64276 .62631 .63865 .61898 .63083 Mtetra
.657 .748 .917 r
.61898 .63083 .62631 .63865 .64097 .63451 .63369 .62662 Mtetra
.657 .746 .916 r
.63369 .62662 .64097 .63451 .65571 .63035 .64848 .6224 Mtetra
.64848 .6224 .65571 .63035 .67053 .62617 .66335 .61817 Mtetra
.656 .746 .916 r
.66335 .61817 .67053 .62617 .68543 .62197 .6783 .61393 Mtetra
.656 .745 .916 r
.6783 .61393 .68543 .62197 .7004 .61775 .69333 .60968 Mtetra
.656 .746 .916 r
.69333 .60968 .7004 .61775 .71546 .61351 .70844 .60542 Mtetra
.655 .746 .917 r
.70844 .60542 .71546 .61351 .73059 .60925 .72363 .60115 Mtetra
.655 .747 .917 r
.72363 .60115 .73059 .60925 .74581 .60496 .73891 .59687 Mtetra
.654 .748 .919 r
.73891 .59687 .74581 .60496 .7611 .60063 .75427 .59257 Mtetra
.655 .75 .92 r
.75427 .59257 .7611 .60063 .77648 .59627 .76971 .58824 Mtetra
.656 .752 .921 r
.76971 .58824 .77648 .59627 .79194 .59186 .78523 .58384 Mtetra
.656 .754 .922 r
.78523 .58384 .79194 .59186 .80747 .58742 .80083 .57939 Mtetra
.657 .755 .922 r
.80083 .57939 .80747 .58742 .8231 .58294 .81651 .57489 Mtetra
.658 .756 .923 r
.81651 .57489 .8231 .58294 .83881 .57848 .83228 .57034 Mtetra
.658 .755 .922 r
.83228 .57034 .83881 .57848 .85461 .57409 .84813 .56576 Mtetra
.656 .75 .919 r
.84813 .56576 .85461 .57409 .8705 .5697 .86408 .56123 Mtetra
.654 .747 .918 r
.86408 .56123 .8705 .5697 .88648 .56526 .88012 .55677 Mtetra
.654 .748 .919 r
.88012 .55677 .88648 .56526 .90254 .56073 .89626 .55229 Mtetra
.655 .751 .92 r
.89626 .55229 .90254 .56073 .91868 .55613 .91247 .54771 Mtetra
.656 .753 .921 r
.91247 .54771 .91868 .55613 .93491 .55146 .92877 .54305 Mtetra
.658 .755 .922 r
.92877 .54305 .93491 .55146 .95123 .54682 .94515 .5383 Mtetra
.657 .753 .921 r
.94515 .5383 .95123 .54682 .96765 .54226 .96162 .53357 Mtetra
.654 .749 .919 r
.96162 .53357 .96765 .54226 .98417 .53768 .97821 .52894 Mtetra
.38547 .6876 .39362 .69478 .40717 .69087 .39906 .68377 Mtetra
.653 .752 .923 r
.39906 .68377 .40717 .69087 .42079 .68705 .41272 .67997 Mtetra
.655 .754 .923 r
.41272 .67997 .42079 .68705 .43448 .68327 .42646 .67608 Mtetra
.657 .752 .921 r
.42646 .67608 .43448 .68327 .44824 .6794 .44026 .67211 Mtetra
.659 .751 .918 r
.44026 .67211 .44824 .6794 .46207 .67546 .45414 .66804 Mtetra
.658 .749 .917 r
.45414 .66804 .46207 .67546 .47597 .67142 .46809 .66398 Mtetra
.654 .748 .919 r
.46809 .66398 .47597 .67142 .48994 .66737 .4821 .66005 Mtetra
.653 .752 .922 r
.4821 .66005 .48994 .66737 .50398 .66339 .49619 .65612 Mtetra
.654 .754 .924 r
.49619 .65612 .50398 .66339 .5181 .65947 .51035 .65214 Mtetra
.655 .754 .923 r
.51035 .65214 .5181 .65947 .53229 .65552 .52459 .6481 Mtetra
.656 .753 .922 r
.52459 .6481 .53229 .65552 .54655 .65152 .5389 .644 Mtetra
.658 .752 .919 r
.5389 .644 .54655 .65152 .56088 .64748 .55328 .6398 Mtetra
.659 .749 .917 r
.55328 .6398 .56088 .64748 .5753 .64339 .56774 .63559 Mtetra
.658 .747 .916 r
.56774 .63559 .5753 .64339 .58978 .63923 .58228 .63137 Mtetra
.657 .746 .916 r
.58228 .63137 .58978 .63923 .60434 .63504 .59689 .62718 Mtetra
.656 .747 .917 r
.59689 .62718 .60434 .63504 .61898 .63083 .61158 .62301 Mtetra
.655 .749 .918 r
.61158 .62301 .61898 .63083 .63369 .62662 .62635 .61881 Mtetra
.655 .75 .92 r
.62635 .61881 .63369 .62662 .64848 .6224 .64119 .61459 Mtetra
.656 .751 .92 r
.64119 .61459 .64848 .6224 .66335 .61817 .65612 .61034 Mtetra
.656 .752 .921 r
.65612 .61034 .66335 .61817 .6783 .61393 .67112 .60606 Mtetra
.67112 .60606 .6783 .61393 .69333 .60968 .6862 .60175 Mtetra
.656 .752 .92 r
.6862 .60175 .69333 .60968 .70844 .60542 .70137 .5974 Mtetra
.656 .75 .919 r
.70137 .5974 .70844 .60542 .72363 .60115 .71661 .59303 Mtetra
.657 .749 .918 r
.71661 .59303 .72363 .60115 .73891 .59687 .73194 .58863 Mtetra
.656 .747 .917 r
.73194 .58863 .73891 .59687 .75427 .59257 .74735 .58425 Mtetra
.654 .745 .916 r
.74735 .58425 .75427 .59257 .76971 .58824 .76285 .57989 Mtetra
.654 .745 .917 r
.76285 .57989 .76971 .58824 .78523 .58384 .77843 .57554 Mtetra
.654 .748 .919 r
.77843 .57554 .78523 .58384 .80083 .57939 .79411 .57117 Mtetra
.655 .751 .921 r
.79411 .57117 .80083 .57939 .81651 .57489 .80986 .56669 Mtetra
.656 .753 .921 r
.80986 .56669 .81651 .57489 .83228 .57034 .82569 .56214 Mtetra
.657 .755 .922 r
.82569 .56214 .83228 .57034 .84813 .56576 .84161 .55753 Mtetra
.658 .756 .922 r
.84161 .55753 .84813 .56576 .86408 .56123 .85761 .55286 Mtetra
.657 .753 .921 r
.85761 .55286 .86408 .56123 .88012 .55677 .8737 .54819 Mtetra
.654 .748 .919 r
.8737 .54819 .88012 .55677 .89626 .55229 .88989 .54366 Mtetra
.653 .747 .919 r
.88989 .54366 .89626 .55229 .91247 .54771 .90618 .53913 Mtetra
.655 .75 .92 r
.90618 .53913 .91247 .54771 .92877 .54305 .92256 .53448 Mtetra
.656 .753 .921 r
.92256 .53448 .92877 .54305 .94515 .5383 .93901 .52976 Mtetra
.658 .755 .922 r
.93901 .52976 .94515 .5383 .96162 .53357 .95555 .52493 Mtetra
.657 .753 .921 r
.95555 .52493 .96162 .53357 .97821 .52894 .97219 .52012 Mtetra
.653 .752 .922 r
.37725 .68046 .38547 .6876 .39906 .68377 .39088 .67665 Mtetra
.655 .754 .923 r
.39088 .67665 .39906 .68377 .41272 .67997 .40458 .67275 Mtetra
.657 .752 .92 r
.40458 .67275 .41272 .67997 .42646 .67608 .41836 .66875 Mtetra
.659 .751 .918 r
.41836 .66875 .42646 .67608 .44026 .67211 .43222 .66466 Mtetra
.658 .749 .917 r
.43222 .66466 .44026 .67211 .45414 .66804 .44614 .6606 Mtetra
.653 .749 .92 r
.44614 .6606 .45414 .66804 .46809 .66398 .46012 .65667 Mtetra
.653 .753 .923 r
.46012 .65667 .46809 .66398 .4821 .66005 .47419 .65273 Mtetra
.654 .754 .923 r
.47419 .65273 .4821 .66005 .49619 .65612 .48832 .64872 Mtetra
.655 .754 .922 r
.48832 .64872 .49619 .65612 .51035 .65214 .50253 .64465 Mtetra
.659 .753 .92 r
.50253 .64465 .51035 .65214 .52459 .6481 .51682 .64044 Mtetra
.659 .749 .917 r
.51682 .64044 .52459 .6481 .5389 .644 .53118 .6362 Mtetra
.658 .747 .915 r
.53118 .6362 .5389 .644 .55328 .6398 .54561 .63199 Mtetra
.655 .747 .917 r
.54561 .63199 .55328 .6398 .56774 .63559 .56012 .62786 Mtetra
.654 .75 .92 r
.56012 .62786 .56774 .63559 .58228 .63137 .57471 .62372 Mtetra
.654 .753 .922 r
.57471 .62372 .58228 .63137 .59689 .62718 .58937 .61957 Mtetra
.654 .755 .924 r
.58937 .61957 .59689 .62718 .61158 .62301 .60412 .61538 Mtetra
.654 .756 .924 r
.60412 .61538 .61158 .62301 .62635 .61881 .61894 .61116 Mtetra
.655 .756 .924 r
.61894 .61116 .62635 .61881 .64119 .61459 .63384 .60691 Mtetra
.63384 .60691 .64119 .61459 .65612 .61034 .64882 .60262 Mtetra
.64882 .60262 .65612 .61034 .67112 .60606 .66387 .59829 Mtetra
.656 .757 .924 r
.66387 .59829 .67112 .60606 .6862 .60175 .67901 .59393 Mtetra
.67901 .59393 .6862 .60175 .70137 .5974 .69423 .58954 Mtetra
.69423 .58954 .70137 .5974 .71661 .59303 .70953 .58511 Mtetra
.657 .756 .923 r
.70953 .58511 .71661 .59303 .73194 .58863 .72492 .58064 Mtetra
.72492 .58064 .73194 .58863 .74735 .58425 .74038 .57614 Mtetra
.657 .754 .921 r
.74038 .57614 .74735 .58425 .76285 .57989 .75593 .57161 Mtetra
.657 .75 .919 r
.75593 .57161 .76285 .57989 .77843 .57554 .77157 .56708 Mtetra
.655 .746 .917 r
.77157 .56708 .77843 .57554 .79411 .57117 .7873 .56263 Mtetra
.653 .745 .917 r
.7873 .56263 .79411 .57117 .80986 .56669 .80312 .55821 Mtetra
.653 .748 .919 r
.80312 .55821 .80986 .56669 .82569 .56214 .81902 .55375 Mtetra
.656 .752 .921 r
.81902 .55375 .82569 .56214 .84161 .55753 .83501 .54916 Mtetra
.657 .754 .922 r
.83501 .54916 .84161 .55753 .85761 .55286 .85108 .54449 Mtetra
.658 .756 .922 r
.85108 .54449 .85761 .55286 .8737 .54819 .86723 .53975 Mtetra
.658 .755 .922 r
.86723 .53975 .8737 .54819 .88989 .54366 .88347 .53499 Mtetra
.654 .749 .919 r
.88347 .53499 .88989 .54366 .90618 .53913 .89982 .53035 Mtetra
.653 .747 .919 r
.89982 .53035 .90618 .53913 .92256 .53448 .91627 .52575 Mtetra
.655 .75 .92 r
.91627 .52575 .92256 .53448 .93901 .52976 .9328 .52104 Mtetra
.657 .752 .921 r
.9328 .52104 .93901 .52976 .95555 .52493 .94942 .51624 Mtetra
.658 .755 .921 r
.94942 .51624 .95555 .52493 .97219 .52012 .96612 .51132 Mtetra
.654 .753 .923 r
.36894 .6733 .37725 .68046 .39088 .67665 .38262 .6694 Mtetra
.657 .752 .921 r
.38262 .6694 .39088 .67665 .40458 .67275 .39637 .6654 Mtetra
.659 .752 .918 r
.39637 .6654 .40458 .67275 .41836 .66875 .4102 .66128 Mtetra
.658 .749 .917 r
.4102 .66128 .41836 .66875 .43222 .66466 .42409 .65721 Mtetra
.653 .749 .92 r
.42409 .65721 .43222 .66466 .44614 .6606 .43805 .65327 Mtetra
.653 .753 .923 r
.43805 .65327 .44614 .6606 .46012 .65667 .45209 .64931 Mtetra
.654 .754 .923 r
.45209 .64931 .46012 .65667 .47419 .65273 .4662 .64528 Mtetra
.657 .753 .921 r
.4662 .64528 .47419 .65273 .48832 .64872 .48038 .64113 Mtetra
.66 .751 .918 r
.48038 .64113 .48832 .64872 .50253 .64465 .49464 .63687 Mtetra
.659 .748 .915 r
.49464 .63687 .50253 .64465 .51682 .64044 .50897 .63263 Mtetra
.655 .746 .917 r
.50897 .63263 .51682 .64044 .53118 .6362 .52338 .62851 Mtetra
.654 .75 .921 r
.52338 .62851 .53118 .6362 .54561 .63199 .53787 .6244 Mtetra
.653 .754 .924 r
.53787 .6244 .54561 .63199 .56012 .62786 .55243 .62028 Mtetra
.653 .755 .924 r
.55243 .62028 .56012 .62786 .57471 .62372 .56707 .61612 Mtetra
.654 .756 .925 r
.56707 .61612 .57471 .62372 .58937 .61957 .58178 .61192 Mtetra
.655 .756 .924 r
.58178 .61192 .58937 .61957 .60412 .61538 .59658 .60767 Mtetra
.655 .755 .924 r
.59658 .60767 .60412 .61538 .61894 .61116 .61145 .60338 Mtetra
.656 .755 .923 r
.61145 .60338 .61894 .61116 .63384 .60691 .6264 .59905 Mtetra
.656 .754 .922 r
.6264 .59905 .63384 .60691 .64882 .60262 .64144 .59469 Mtetra
.656 .753 .922 r
.64144 .59469 .64882 .60262 .66387 .59829 .65655 .59032 Mtetra
.655 .753 .922 r
.65655 .59032 .66387 .59829 .67901 .59393 .67175 .58594 Mtetra
.655 .754 .922 r
.67175 .58594 .67901 .59393 .69423 .58954 .68703 .58154 Mtetra
.656 .755 .923 r
.68703 .58154 .69423 .58954 .70953 .58511 .70239 .57709 Mtetra
.656 .756 .923 r
.70239 .57709 .70953 .58511 .72492 .58064 .71783 .5726 Mtetra
.657 .756 .923 r
.71783 .5726 .72492 .58064 .74038 .57614 .73336 .56806 Mtetra
.657 .757 .923 r
.73336 .56806 .74038 .57614 .75593 .57161 .74896 .56348 Mtetra
.658 .757 .923 r
.74896 .56348 .75593 .57161 .77157 .56708 .76466 .55885 Mtetra
.658 .755 .922 r
.76466 .55885 .77157 .56708 .7873 .56263 .78043 .55421 Mtetra
.657 .751 .919 r
.78043 .55421 .7873 .56263 .80312 .55821 .7963 .54957 Mtetra
.653 .746 .918 r
.7963 .54957 .80312 .55821 .81902 .55375 .81227 .54507 Mtetra
.653 .745 .918 r
.81227 .54507 .81902 .55375 .83501 .54916 .82833 .54057 Mtetra
.655 .75 .92 r
.82833 .54057 .83501 .54916 .85108 .54449 .84447 .53596 Mtetra
.657 .753 .921 r
.84447 .53596 .85108 .54449 .86723 .53975 .8607 .53123 Mtetra
.658 .755 .922 r
.8607 .53123 .86723 .53975 .88347 .53499 .87701 .52641 Mtetra
.87701 .52641 .88347 .53499 .89982 .53035 .8934 .52156 Mtetra
.655 .749 .92 r
.8934 .52156 .89982 .53035 .91627 .52575 .90991 .51685 Mtetra
.653 .747 .919 r
.90991 .51685 .91627 .52575 .9328 .52104 .92652 .51218 Mtetra
.655 .75 .92 r
.92652 .51218 .9328 .52104 .94942 .51624 .94321 .50739 Mtetra
.657 .753 .921 r
.94321 .50739 .94942 .51624 .96612 .51132 .95999 .50249 Mtetra
.656 .753 .921 r
.36055 .66603 .36894 .6733 .38262 .6694 .37428 .66203 Mtetra
.659 .752 .918 r
.37428 .66203 .38262 .6694 .39637 .6654 .38808 .6579 Mtetra
.658 .749 .917 r
.38808 .6579 .39637 .6654 .4102 .66128 .40195 .65379 Mtetra
.653 .749 .92 r
.40195 .65379 .4102 .66128 .42409 .65721 .41588 .64984 Mtetra
.653 .753 .923 r
.41588 .64984 .42409 .65721 .43805 .65327 .42989 .64587 Mtetra
.654 .754 .923 r
.42989 .64587 .43805 .65327 .45209 .64931 .44397 .64181 Mtetra
.658 .753 .92 r
.44397 .64181 .45209 .64931 .4662 .64528 .45813 .63761 Mtetra
.66 .75 .917 r
.45813 .63761 .4662 .64528 .48038 .64113 .47237 .63332 Mtetra
.657 .747 .916 r
.47237 .63332 .48038 .64113 .49464 .63687 .48667 .62912 Mtetra
.654 .749 .92 r
.48667 .62912 .49464 .63687 .50897 .63263 .50105 .62503 Mtetra
.653 .753 .924 r
.50105 .62503 .50897 .63263 .52338 .62851 .51551 .62093 Mtetra
.653 .755 .925 r
.51551 .62093 .52338 .62851 .53787 .6244 .53004 .61679 Mtetra
.654 .755 .924 r
.53004 .61679 .53787 .6244 .55243 .62028 .54466 .6126 Mtetra
.656 .755 .923 r
.54466 .6126 .55243 .62028 .56707 .61612 .55934 .60831 Mtetra
.658 .754 .92 r
.55934 .60831 .56707 .61612 .58178 .61192 .57411 .60391 Mtetra
.659 .75 .917 r
.57411 .60391 .58178 .61192 .59658 .60767 .58896 .5995 Mtetra
.658 .747 .915 r
.58896 .5995 .59658 .60767 .61145 .60338 .60388 .59509 Mtetra
.658 .744 .914 r
.60388 .59509 .61145 .60338 .6264 .59905 .61888 .59068 Mtetra
.657 .743 .914 r
.61888 .59068 .6264 .59905 .64144 .59469 .63397 .58627 Mtetra
.656 .743 .914 r
.63397 .58627 .64144 .59469 .65655 .59032 .64914 .58185 Mtetra
.64914 .58185 .65655 .59032 .67175 .58594 .66439 .57744 Mtetra
.655 .743 .914 r
.66439 .57744 .67175 .58594 .68703 .58154 .67973 .57303 Mtetra
.654 .743 .915 r
.67973 .57303 .68703 .58154 .70239 .57709 .69515 .56861 Mtetra
.654 .745 .917 r
.69515 .56861 .70239 .57709 .71783 .5726 .71065 .5642 Mtetra
.653 .748 .919 r
.71065 .5642 .71783 .5726 .73336 .56806 .72625 .55977 Mtetra
.655 .753 .922 r
.72625 .55977 .73336 .56806 .74896 .56348 .74192 .55523 Mtetra
.657 .756 .923 r
.74192 .55523 .74896 .56348 .76466 .55885 .75768 .55059 Mtetra
.658 .757 .923 r
.75768 .55059 .76466 .55885 .78043 .55421 .77352 .54589 Mtetra
.77352 .54589 .78043 .55421 .7963 .54957 .78944 .54115 Mtetra
.658 .755 .922 r
.78944 .54115 .7963 .54957 .81227 .54507 .80546 .5364 Mtetra
.655 .749 .919 r
.80546 .5364 .81227 .54507 .82833 .54057 .82157 .53175 Mtetra
.652 .745 .918 r
.82157 .53175 .82833 .54057 .84447 .53596 .83779 .52719 Mtetra
.654 .748 .919 r
.83779 .52719 .84447 .53596 .8607 .53123 .85409 .52254 Mtetra
.657 .753 .921 r
.85409 .52254 .8607 .53123 .87701 .52641 .87047 .51774 Mtetra
.658 .755 .922 r
.87047 .51774 .87701 .52641 .8934 .52156 .88694 .51284 Mtetra
.658 .755 .921 r
.88694 .51284 .8934 .52156 .90991 .51685 .90349 .50791 Mtetra
.654 .749 .92 r
.90349 .50791 .90991 .51685 .92652 .51218 .92016 .50314 Mtetra
.653 .747 .919 r
.92016 .50314 .92652 .51218 .94321 .50739 .93694 .49839 Mtetra
.655 .751 .92 r
.93694 .49839 .94321 .50739 .95999 .50249 .9538 .49351 Mtetra
.659 .752 .919 r
.35209 .65865 .36055 .66603 .37428 .66203 .36587 .65452 Mtetra
.659 .75 .917 r
.36587 .65452 .37428 .66203 .38808 .6579 .37971 .65035 Mtetra
.653 .749 .92 r
.37971 .65035 .38808 .6579 .40195 .65379 .39362 .64638 Mtetra
.652 .753 .923 r
.39362 .64638 .40195 .65379 .41588 .64984 .40759 .6424 Mtetra
.654 .754 .923 r
.40759 .6424 .41588 .64984 .42989 .64587 .42165 .63833 Mtetra
.659 .753 .92 r
.42165 .63833 .42989 .64587 .44397 .64181 .43578 .6341 Mtetra
.66 .75 .916 r
.43578 .6341 .44397 .64181 .45813 .63761 .44999 .62978 Mtetra
.656 .747 .917 r
.44999 .62978 .45813 .63761 .47237 .63332 .46427 .6256 Mtetra
.653 .75 .921 r
.46427 .6256 .47237 .63332 .48667 .62912 .47862 .62151 Mtetra
.652 .754 .924 r
.47862 .62151 .48667 .62912 .50105 .62503 .49305 .61741 Mtetra
.653 .755 .924 r
.49305 .61741 .50105 .62503 .51551 .62093 .50756 .61325 Mtetra
.656 .755 .923 r
.50756 .61325 .51551 .62093 .53004 .61679 .52214 .60895 Mtetra
.66 .753 .919 r
.52214 .60895 .53004 .61679 .54466 .6126 .53681 .6045 Mtetra
.66 .748 .915 r
.53681 .6045 .54466 .6126 .55934 .60831 .55154 .60005 Mtetra
.658 .744 .913 r
.55154 .60005 .55934 .60831 .57411 .60391 .56636 .59563 Mtetra
.656 .744 .915 r
.56636 .59563 .57411 .60391 .58896 .5995 .58126 .59128 Mtetra
.656 .747 .917 r
.58126 .59128 .58896 .5995 .60388 .59509 .59624 .58692 Mtetra
.655 .749 .919 r
.59624 .58692 .60388 .59509 .61888 .59068 .6113 .58253 Mtetra
.655 .751 .92 r
.6113 .58253 .61888 .59068 .63397 .58627 .62644 .57811 Mtetra
.656 .752 .92 r
.62644 .57811 .63397 .58627 .64914 .58185 .64167 .57366 Mtetra
.64167 .57366 .64914 .58185 .66439 .57744 .65697 .56916 Mtetra
.656 .751 .92 r
.65697 .56916 .66439 .57744 .67973 .57303 .67236 .56464 Mtetra
.657 .749 .918 r
.67236 .56464 .67973 .57303 .69515 .56861 .68783 .56008 Mtetra
.656 .747 .917 r
.68783 .56008 .69515 .56861 .71065 .5642 .70339 .55552 Mtetra
.654 .743 .915 r
.70339 .55552 .71065 .5642 .72625 .55977 .71904 .55102 Mtetra
.653 .742 .915 r
.71904 .55102 .72625 .55977 .74192 .55523 .73478 .54656 Mtetra
.652 .745 .918 r
.73478 .54656 .74192 .55523 .75768 .55059 .75061 .54208 Mtetra
.655 .752 .921 r
.75061 .54208 .75768 .55059 .77352 .54589 .76653 .53746 Mtetra
.658 .756 .922 r
.76653 .53746 .77352 .54589 .78944 .54115 .78252 .5327 Mtetra
.659 .757 .923 r
.78252 .5327 .78944 .54115 .80546 .5364 .79859 .52786 Mtetra
.658 .756 .922 r
.79859 .52786 .80546 .5364 .82157 .53175 .81476 .52301 Mtetra
.656 .751 .92 r
.81476 .52301 .82157 .53175 .83779 .52719 .83102 .51824 Mtetra
.652 .745 .918 r
.83102 .51824 .83779 .52719 .85409 .52254 .8474 .51362 Mtetra
.653 .748 .919 r
.8474 .51362 .85409 .52254 .87047 .51774 .86386 .50891 Mtetra
.657 .753 .921 r
.86386 .50891 .87047 .51774 .88694 .51284 .8804 .50402 Mtetra
.659 .755 .921 r
.8804 .50402 .88694 .51284 .90349 .50791 .89702 .49903 Mtetra
.658 .755 .921 r
.89702 .49903 .90349 .50791 .92016 .50314 .91375 .49403 Mtetra
.653 .748 .919 r
.91375 .49403 .92016 .50314 .93694 .49839 .93059 .48923 Mtetra
.93059 .48923 .93694 .49839 .9538 .49351 .94753 .48438 Mtetra
.66 .751 .918 r
.34355 .65113 .35209 .65865 .36587 .65452 .35737 .64693 Mtetra
.655 .749 .919 r
.35737 .64693 .36587 .65452 .37971 .65035 .37125 .64289 Mtetra
.652 .752 .923 r
.37125 .64289 .37971 .65035 .39362 .64638 .3852 .63891 Mtetra
.654 .753 .923 r
.3852 .63891 .39362 .64638 .40759 .6424 .39923 .63483 Mtetra
.658 .753 .92 r
.39923 .63483 .40759 .6424 .42165 .63833 .41334 .63059 Mtetra
.661 .751 .917 r
.41334 .63059 .42165 .63833 .43578 .6341 .42752 .62624 Mtetra
.656 .747 .917 r
.42752 .62624 .43578 .6341 .44999 .62978 .44177 .62206 Mtetra
.652 .751 .922 r
.44177 .62206 .44999 .62978 .46427 .6256 .45609 .61797 Mtetra
.652 .754 .924 r
.45609 .61797 .46427 .6256 .47862 .62151 .47049 .61385 Mtetra
.654 .755 .924 r
.47049 .61385 .47862 .62151 .49305 .61741 .48497 .60965 Mtetra
.66 .755 .92 r
.48497 .60965 .49305 .61741 .50756 .61325 .49953 .60521 Mtetra
.661 .749 .916 r
.49953 .60521 .50756 .61325 .52214 .60895 .51417 .60071 Mtetra
.658 .745 .914 r
.51417 .60071 .52214 .60895 .53681 .6045 .52888 .5963 Mtetra
.655 .746 .916 r
.52888 .5963 .53681 .6045 .55154 .60005 .54367 .59199 Mtetra
.654 .75 .92 r
.54367 .59199 .55154 .60005 .56636 .59563 .55854 .58768 Mtetra
.653 .754 .923 r
.55854 .58768 .56636 .59563 .58126 .59128 .5735 .58335 Mtetra
.653 .755 .925 r
.5735 .58335 .58126 .59128 .59624 .58692 .58853 .57901 Mtetra
.654 .757 .926 r
.58853 .57901 .59624 .58692 .6113 .58253 .60365 .57462 Mtetra
.654 .758 .926 r
.60365 .57462 .6113 .58253 .62644 .57811 .61885 .57017 Mtetra
.655 .759 .926 r
.61885 .57017 .62644 .57811 .64167 .57366 .63413 .56567 Mtetra
.656 .759 .926 r
.63413 .56567 .64167 .57366 .65697 .56916 .64949 .56112 Mtetra
.657 .759 .925 r
.64949 .56112 .65697 .56916 .67236 .56464 .66494 .55651 Mtetra
.658 .758 .924 r
.66494 .55651 .67236 .56464 .68783 .56008 .68047 .55184 Mtetra
.658 .757 .923 r
.68047 .55184 .68783 .56008 .70339 .55552 .69608 .54716 Mtetra
.657 .755 .922 r
.69608 .54716 .70339 .55552 .71904 .55102 .71178 .54246 Mtetra
.657 .751 .919 r
.71178 .54246 .71904 .55102 .73478 .54656 .72757 .53776 Mtetra
.654 .745 .917 r
.72757 .53776 .73478 .54656 .75061 .54208 .74346 .53317 Mtetra
.651 .742 .916 r
.74346 .53317 .75061 .54208 .76653 .53746 .75944 .52866 Mtetra
.652 .747 .919 r
.75944 .52866 .76653 .53746 .78252 .5327 .77551 .52408 Mtetra
.657 .754 .922 r
.77551 .52408 .78252 .5327 .79859 .52786 .79166 .51926 Mtetra
.659 .757 .922 r
.79166 .51926 .79859 .52786 .81476 .52301 .80789 .51434 Mtetra
.659 .756 .922 r
.80789 .51434 .81476 .52301 .83102 .51824 .82421 .5094 Mtetra
.656 .752 .92 r
.82421 .5094 .83102 .51824 .8474 .51362 .84063 .50455 Mtetra
.652 .746 .918 r
.84063 .50455 .8474 .51362 .86386 .50891 .85717 .49986 Mtetra
.654 .748 .919 r
.85717 .49986 .86386 .50891 .8804 .50402 .87379 .49506 Mtetra
.657 .753 .921 r
.87379 .49506 .8804 .50402 .89702 .49903 .89049 .49007 Mtetra
.659 .755 .921 r
.89049 .49007 .89702 .49903 .91375 .49403 .90728 .48499 Mtetra
.657 .754 .921 r
.90728 .48499 .91375 .49403 .93059 .48923 .92417 .47996 Mtetra
.652 .748 .919 r
.92417 .47996 .93059 .48923 .94753 .48438 .94118 .4751 Mtetra
.657 .749 .918 r
.33493 .64352 .34355 .65113 .35737 .64693 .34879 .63937 Mtetra
.652 .751 .922 r
.34879 .63937 .35737 .64693 .37125 .64289 .36271 .63538 Mtetra
.653 .753 .923 r
.36271 .63538 .37125 .64289 .3852 .63891 .37671 .63131 Mtetra
.657 .753 .921 r
.37671 .63131 .3852 .63891 .39923 .63483 .39079 .6271 Mtetra
.661 .752 .917 r
.39079 .6271 .39923 .63483 .41334 .63059 .40494 .62271 Mtetra
.656 .748 .917 r
.40494 .62271 .41334 .63059 .42752 .62624 .41917 .61848 Mtetra
.652 .751 .922 r
.41917 .61848 .42752 .62624 .44177 .62206 .43346 .61438 Mtetra
.651 .753 .924 r
.43346 .61438 .44177 .62206 .45609 .61797 .44783 .61026 Mtetra
.654 .755 .923 r
.44783 .61026 .45609 .61797 .47049 .61385 .46228 .60602 Mtetra
.662 .754 .919 r
.46228 .60602 .47049 .61385 .48497 .60965 .47682 .60149 Mtetra
.661 .747 .914 r
.47682 .60149 .48497 .60965 .49953 .60521 .49143 .59697 Mtetra
.655 .745 .915 r
.49143 .59697 .49953 .60521 .51417 .60071 .50611 .59265 Mtetra
.653 .749 .92 r
.50611 .59265 .51417 .60071 .52888 .5963 .52087 .58837 Mtetra
.651 .753 .924 r
.52087 .58837 .52888 .5963 .54367 .59199 .53572 .58412 Mtetra
.651 .756 .926 r
.53572 .58412 .54367 .59199 .55854 .58768 .55065 .57984 Mtetra
.653 .758 .927 r
.55065 .57984 .55854 .58768 .5735 .58335 .56565 .57548 Mtetra
.654 .759 .927 r
.56565 .57548 .5735 .58335 .58853 .57901 .58074 .57105 Mtetra
.656 .758 .925 r
.58074 .57105 .58853 .57901 .60365 .57462 .59591 .56651 Mtetra
.656 .756 .923 r
.59591 .56651 .60365 .57462 .61885 .57017 .61117 .56196 Mtetra
.656 .754 .922 r
.61117 .56196 .61885 .57017 .63413 .56567 .6265 .55741 Mtetra
.655 .754 .923 r
.6265 .55741 .63413 .56567 .64949 .56112 .64193 .55288 Mtetra
.654 .756 .924 r
.64193 .55288 .64949 .56112 .66494 .55651 .65744 .54831 Mtetra
.656 .759 .925 r
.65744 .54831 .66494 .55651 .68047 .55184 .67303 .54365 Mtetra
.657 .76 .926 r
.67303 .54365 .68047 .55184 .69608 .54716 .68871 .53891 Mtetra
.659 .76 .925 r
.68871 .53891 .69608 .54716 .71178 .54246 .70446 .5341 Mtetra
.659 .759 .924 r
.70446 .5341 .71178 .54246 .72757 .53776 .72031 .52924 Mtetra
.658 .756 .922 r
.72031 .52924 .72757 .53776 .74346 .53317 .73625 .52441 Mtetra
.657 .751 .919 r
.73625 .52441 .74346 .53317 .75944 .52866 .75228 .51963 Mtetra
.651 .743 .917 r
.75228 .51963 .75944 .52866 .77551 .52408 .76841 .51505 Mtetra
.651 .744 .918 r
.76841 .51505 .77551 .52408 .79166 .51926 .78464 .51046 Mtetra
.657 .753 .921 r
.78464 .51046 .79166 .51926 .80789 .51434 .80094 .50558 Mtetra
.659 .756 .922 r
.80094 .50558 .80789 .51434 .82421 .5094 .81733 .50058 Mtetra
.81733 .50058 .82421 .5094 .84063 .50455 .83381 .49555 Mtetra
.655 .751 .921 r
.83381 .49555 .84063 .50455 .85717 .49986 .8504 .49065 Mtetra
.651 .746 .919 r
.8504 .49065 .85717 .49986 .87379 .49506 .8671 .4859 Mtetra
.655 .75 .92 r
.8671 .4859 .87379 .49506 .89049 .49007 .88388 .48097 Mtetra
.658 .754 .921 r
.88388 .48097 .89049 .49007 .90728 .48499 .90074 .47588 Mtetra
.659 .755 .921 r
.90074 .47588 .90728 .48499 .92417 .47996 .91769 .47071 Mtetra
.655 .751 .921 r
.91769 .47071 .92417 .47996 .94118 .4751 .93477 .46569 Mtetra
.653 .749 .92 r
.32623 .63585 .33493 .64352 .34879 .63937 .34012 .63181 Mtetra
.652 .752 .923 r
.34012 .63181 .34879 .63937 .36271 .63538 .35409 .62776 Mtetra
.655 .753 .922 r
.35409 .62776 .36271 .63538 .37671 .63131 .36814 .62359 Mtetra
.661 .753 .918 r
.36814 .62359 .37671 .63131 .39079 .6271 .38226 .61919 Mtetra
.658 .749 .917 r
.38226 .61919 .39079 .6271 .40494 .62271 .39646 .61488 Mtetra
.652 .75 .921 r
.39646 .61488 .40494 .62271 .41917 .61848 .41073 .61075 Mtetra
.651 .753 .924 r
.41073 .61075 .41917 .61848 .43346 .61438 .42507 .60662 Mtetra
.654 .754 .923 r
.42507 .60662 .43346 .61438 .44783 .61026 .43949 .60237 Mtetra
.662 .754 .918 r
.43949 .60237 .44783 .61026 .46228 .60602 .454 .59781 Mtetra
.661 .747 .914 r
.454 .59781 .46228 .60602 .47682 .60149 .46858 .59328 Mtetra
.654 .746 .917 r
.46858 .59328 .47682 .60149 .49143 .59697 .48324 .58898 Mtetra
.651 .752 .923 r
.48324 .58898 .49143 .59697 .50611 .59265 .49797 .58474 Mtetra
.65 .754 .926 r
.49797 .58474 .50611 .59265 .52087 .58837 .51279 .58052 Mtetra
.652 .758 .927 r
.51279 .58052 .52087 .58837 .53572 .58412 .52769 .57619 Mtetra
.658 .759 .924 r
.52769 .57619 .53572 .58412 .55065 .57984 .54267 .57162 Mtetra
.661 .753 .919 r
.54267 .57162 .55065 .57984 .56565 .57548 .55772 .56694 Mtetra
.66 .746 .914 r
.55772 .56694 .56565 .57548 .58074 .57105 .57286 .56227 Mtetra
.659 .741 .911 r
.57286 .56227 .58074 .57105 .59591 .56651 .58809 .55763 Mtetra
.658 .739 .91 r
.58809 .55763 .59591 .56651 .61117 .56196 .60339 .55302 Mtetra
.656 .739 .91 r
.60339 .55302 .61117 .56196 .6265 .55741 .61879 .54842 Mtetra
.655 .738 .911 r
.61879 .54842 .6265 .55741 .64193 .55288 .63427 .54385 Mtetra
.654 .738 .911 r
.63427 .54385 .64193 .55288 .65744 .54831 .64983 .53931 Mtetra
.652 .739 .913 r
.64983 .53931 .65744 .54831 .67303 .54365 .66549 .53479 Mtetra
.651 .743 .917 r
.66549 .53479 .67303 .54365 .68871 .53891 .68124 .53028 Mtetra
.653 .751 .922 r
.68124 .53028 .68871 .53891 .70446 .5341 .69707 .52566 Mtetra
.658 .759 .924 r
.69707 .52566 .70446 .5341 .72031 .52924 .71298 .52079 Mtetra
.661 .761 .924 r
.71298 .52079 .72031 .52924 .73625 .52441 .72897 .51581 Mtetra
.66 .758 .923 r
.72897 .51581 .73625 .52441 .75228 .51963 .74506 .51085 Mtetra
.658 .754 .921 r
.74506 .51085 .75228 .51963 .76841 .51505 .76124 .50595 Mtetra
.652 .745 .918 r
.76124 .50595 .76841 .51505 .78464 .51046 .77753 .50127 Mtetra
.65 .743 .918 r
.77753 .50127 .78464 .51046 .80094 .50558 .79392 .49663 Mtetra
.657 .753 .921 r
.79392 .49663 .80094 .50558 .81733 .50058 .81038 .49167 Mtetra
.66 .756 .922 r
.81038 .49167 .81733 .50058 .83381 .49555 .82693 .48656 Mtetra
.659 .756 .921 r
.82693 .48656 .83381 .49555 .8504 .49065 .84357 .48146 Mtetra
.654 .75 .92 r
.84357 .48146 .8504 .49065 .8671 .4859 .86032 .47655 Mtetra
.651 .746 .919 r
.86032 .47655 .8671 .4859 .88388 .48097 .87719 .47171 Mtetra
.656 .752 .92 r
.87719 .47171 .88388 .48097 .90074 .47588 .89413 .46663 Mtetra
.659 .754 .921 r
.89413 .46663 .90074 .47588 .91769 .47071 .91116 .46142 Mtetra
.658 .754 .921 r
.91116 .46142 .91769 .47071 .93477 .46569 .92829 .4562 Mtetra
.651 .751 .923 r
.31743 .62822 .32623 .63585 .34012 .63181 .33137 .62417 Mtetra
.654 .753 .923 r
.33137 .62417 .34012 .63181 .35409 .62776 .34538 .62003 Mtetra
.659 .753 .919 r
.34538 .62003 .35409 .62776 .36814 .62359 .35948 .61569 Mtetra
.661 .75 .916 r
.35948 .61569 .36814 .62359 .38226 .61919 .37366 .61125 Mtetra
.653 .748 .919 r
.37366 .61125 .38226 .61919 .39646 .61488 .3879 .60708 Mtetra
.651 .752 .924 r
.3879 .60708 .39646 .61488 .41073 .61075 .40221 .60295 Mtetra
.653 .754 .924 r
.40221 .60295 .41073 .61075 .42507 .60662 .4166 .59872 Mtetra
.662 .755 .919 r
.4166 .59872 .42507 .60662 .43949 .60237 .43108 .59415 Mtetra
.661 .748 .914 r
.43108 .59415 .43949 .60237 .454 .59781 .44563 .58958 Mtetra
.654 .746 .918 r
.44563 .58958 .454 .59781 .46858 .59328 .46026 .58528 Mtetra
.65 .752 .924 r
.46026 .58528 .46858 .59328 .48324 .58898 .47497 .58106 Mtetra
.649 .755 .927 r
.47497 .58106 .48324 .58898 .49797 .58474 .48975 .57683 Mtetra
.656 .758 .925 r
.48975 .57683 .49797 .58474 .51279 .58052 .50462 .57235 Mtetra
.663 .755 .918 r
.50462 .57235 .51279 .58052 .52769 .57619 .51957 .56759 Mtetra
.663 .745 .911 r
.51957 .56759 .52769 .57619 .54267 .57162 .5346 .56282 Mtetra
.658 .74 .91 r
.5346 .56282 .54267 .57162 .55772 .56694 .54972 .55821 Mtetra
.656 .742 .913 r
.54972 .55821 .55772 .56694 .57286 .56227 .56491 .55366 Mtetra
.655 .746 .917 r
.56491 .55366 .57286 .56227 .58809 .55763 .58019 .5491 Mtetra
.655 .749 .919 r
.58019 .5491 .58809 .55763 .60339 .55302 .59556 .54451 Mtetra
.656 .751 .92 r
.59556 .54451 .60339 .55302 .61879 .54842 .611 .53987 Mtetra
.611 .53987 .61879 .54842 .63427 .54385 .62654 .53518 Mtetra
.657 .75 .919 r
.62654 .53518 .63427 .54385 .64983 .53931 .64216 .53045 Mtetra
.656 .747 .916 r
.64216 .53045 .64983 .53931 .66549 .53479 .65787 .52572 Mtetra
.654 .742 .914 r
.65787 .52572 .66549 .53479 .68124 .53028 .67367 .52105 Mtetra
.65 .738 .913 r
.67367 .52105 .68124 .53028 .69707 .52566 .68957 .51653 Mtetra
.649 .741 .916 r
.68957 .51653 .69707 .52566 .71298 .52079 .70556 .51202 Mtetra
.655 .753 .922 r
.70556 .51202 .71298 .52079 .72897 .51581 .72163 .50721 Mtetra
.661 .76 .924 r
.72163 .50721 .72897 .51581 .74506 .51085 .73778 .50213 Mtetra
.661 .759 .923 r
.73778 .50213 .74506 .51085 .76124 .50595 .75401 .49705 Mtetra
.658 .754 .921 r
.75401 .49705 .76124 .50595 .77753 .50127 .77035 .49205 Mtetra
.651 .745 .919 r
.77035 .49205 .77753 .50127 .79392 .49663 .7868 .48732 Mtetra
.65 .744 .918 r
.7868 .48732 .79392 .49663 .81038 .49167 .80335 .48259 Mtetra
.658 .754 .921 r
.80335 .48259 .81038 .49167 .82693 .48656 .81997 .4775 Mtetra
.66 .756 .921 r
.81997 .4775 .82693 .48656 .84357 .48146 .83668 .4723 Mtetra
.658 .755 .921 r
.83668 .4723 .84357 .48146 .86032 .47655 .85348 .46714 Mtetra
.651 .747 .92 r
.85348 .46714 .86032 .47655 .87719 .47171 .87042 .46225 Mtetra
.653 .748 .919 r
.87042 .46225 .87719 .47171 .89413 .46663 .88745 .45725 Mtetra
.658 .753 .92 r
.88745 .45725 .89413 .46663 .91116 .46142 .90455 .45204 Mtetra
.659 .755 .921 r
.90455 .45204 .91116 .46142 .92829 .4562 .92175 .44672 Mtetra
.652 .752 .923 r
.30855 .62053 .31743 .62822 .33137 .62417 .32253 .61643 Mtetra
.655 .752 .921 r
.32253 .61643 .33137 .62417 .34538 .62003 .3366 .61219 Mtetra
.662 .752 .917 r
.3366 .61219 .34538 .62003 .35948 .61569 .35075 .6077 Mtetra
.656 .749 .918 r
.35075 .6077 .35948 .61569 .37366 .61125 .36496 .60339 Mtetra
.651 .751 .923 r
.36496 .60339 .37366 .61125 .3879 .60708 .37924 .59923 Mtetra
.652 .753 .924 r
.37924 .59923 .3879 .60708 .40221 .60295 .3936 .59503 Mtetra
.659 .754 .92 r
.3936 .59503 .40221 .60295 .4166 .59872 .40805 .59053 Mtetra
.663 .75 .914 r
.40805 .59053 .4166 .59872 .43108 .59415 .42258 .58587 Mtetra
.654 .746 .917 r
.42258 .58587 .43108 .59415 .44563 .58958 .43718 .58153 Mtetra
.65 .751 .924 r
.43718 .58153 .44563 .58958 .46026 .58528 .45185 .5773 Mtetra
.649 .754 .927 r
.45185 .5773 .46026 .58528 .47497 .58106 .46661 .57307 Mtetra
.659 .758 .923 r
.46661 .57307 .47497 .58106 .48975 .57683 .48145 .56847 Mtetra
.665 .752 .915 r
.48145 .56847 .48975 .57683 .50462 .57235 .49638 .56362 Mtetra
.661 .742 .911 r
.49638 .56362 .50462 .57235 .51957 .56759 .51138 .55891 Mtetra
.655 .743 .915 r
.51138 .55891 .51957 .56759 .5346 .56282 .52646 .55439 Mtetra
.653 .75 .921 r
.52646 .55439 .5346 .56282 .54972 .55821 .54163 .54993 Mtetra
.65 .754 .925 r
.54163 .54993 .54972 .55821 .56491 .55366 .55688 .54552 Mtetra
.65 .759 .928 r
.55688 .54552 .56491 .55366 .58019 .5491 .57222 .54105 Mtetra
.652 .763 .93 r
.57222 .54105 .58019 .5491 .59556 .54451 .58765 .53647 Mtetra
.655 .765 .93 r
.58765 .53647 .59556 .54451 .611 .53987 .60316 .53178 Mtetra
.657 .766 .93 r
.60316 .53178 .611 .53987 .62654 .53518 .61875 .52699 Mtetra
.659 .765 .928 r
.61875 .52699 .62654 .53518 .64216 .53045 .63443 .52208 Mtetra
.66 .762 .925 r
.63443 .52208 .64216 .53045 .65787 .52572 .65019 .51711 Mtetra
.659 .756 .922 r
.65019 .51711 .65787 .52572 .67367 .52105 .66604 .51219 Mtetra
.657 .751 .919 r
.66604 .51219 .67367 .52105 .68957 .51653 .68199 .50733 Mtetra
.652 .742 .916 r
.68199 .50733 .68957 .51653 .70556 .51202 .69804 .50265 Mtetra
.647 .738 .915 r
.69804 .50265 .70556 .51202 .72163 .50721 .71419 .49813 Mtetra
.653 .748 .919 r
.71419 .49813 .72163 .50721 .73778 .50213 .73042 .49334 Mtetra
.661 .759 .923 r
.73042 .49334 .73778 .50213 .75401 .49705 .74672 .48817 Mtetra
.661 .758 .922 r
.74672 .48817 .75401 .49705 .77035 .49205 .76311 .48299 Mtetra
.657 .754 .921 r
.76311 .48299 .77035 .49205 .7868 .48732 .77961 .47793 Mtetra
.649 .744 .919 r
.77961 .47793 .7868 .48732 .80335 .48259 .79623 .47319 Mtetra
.652 .746 .919 r
.79623 .47319 .80335 .48259 .81997 .4775 .81294 .46829 Mtetra
.659 .755 .921 r
.81294 .46829 .81997 .4775 .83668 .4723 .82971 .46306 Mtetra
.66 .756 .921 r
.82971 .46306 .83668 .4723 .85348 .46714 .84659 .45778 Mtetra
.655 .752 .921 r
.84659 .45778 .85348 .46714 .87042 .46225 .86358 .45267 Mtetra
.651 .746 .92 r
.86358 .45267 .87042 .46225 .88745 .45725 .88069 .44772 Mtetra
.656 .751 .92 r
.88069 .44772 .88745 .45725 .90455 .45204 .89787 .44252 Mtetra
.659 .754 .92 r
.89787 .44252 .90455 .45204 .92175 .44672 .91515 .43716 Mtetra
.653 .752 .923 r
.29958 .61277 .30855 .62053 .32253 .61643 .31361 .60859 Mtetra
.659 .753 .919 r
.31361 .60859 .32253 .61643 .3366 .61219 .32773 .60418 Mtetra
.661 .75 .916 r
.32773 .60418 .3366 .61219 .35075 .6077 .34192 .59969 Mtetra
.652 .749 .921 r
.34192 .59969 .35075 .6077 .36496 .60339 .35617 .59547 Mtetra
.65 .752 .924 r
.35617 .59547 .36496 .60339 .37924 .59923 .3705 .59129 Mtetra
.655 .754 .922 r
.3705 .59129 .37924 .59923 .3936 .59503 .38492 .58692 Mtetra
.664 .753 .916 r
.38492 .58692 .3936 .59503 .40805 .59053 .39942 .58222 Mtetra
.657 .747 .916 r
.39942 .58222 .40805 .59053 .42258 .58587 .41399 .57774 Mtetra
.65 .751 .923 r
.41399 .57774 .42258 .58587 .43718 .58153 .42864 .57347 Mtetra
.648 .753 .926 r
.42864 .57347 .43718 .58153 .45185 .5773 .44336 .56926 Mtetra
.658 .757 .923 r
.44336 .56926 .45185 .5773 .46661 .57307 .45817 .56466 Mtetra
.666 .752 .914 r
.45817 .56466 .46661 .57307 .48145 .56847 .47307 .55973 Mtetra
.659 .743 .912 r
.47307 .55973 .48145 .56847 .49638 .56362 .48805 .55506 Mtetra
.653 .746 .918 r
.48805 .55506 .49638 .56362 .51138 .55891 .5031 .5506 Mtetra
.647 .752 .926 r
.5031 .5506 .51138 .55891 .52646 .55439 .51824 .54631 Mtetra
.646 .758 .931 r
.51824 .54631 .52646 .55439 .54163 .54993 .53346 .54201 Mtetra
.649 .765 .934 r
.53346 .54201 .54163 .54993 .55688 .54552 .54877 .53754 Mtetra
.657 .767 .93 r
.54877 .53754 .55688 .54552 .57222 .54105 .56417 .53277 Mtetra
.658 .761 .925 r
.56417 .53277 .57222 .54105 .58765 .53647 .57965 .52794 Mtetra
.656 .755 .923 r
.57965 .52794 .58765 .53647 .60316 .53178 .59521 .5232 Mtetra
.652 .754 .924 r
.59521 .5232 .60316 .53178 .61875 .52699 .61087 .51856 Mtetra
.653 .759 .928 r
.61087 .51856 .61875 .52699 .63443 .52208 .62662 .51386 Mtetra
.66 .768 .93 r
.62662 .51386 .63443 .52208 .65019 .51711 .64245 .50885 Mtetra
.663 .769 .928 r
.64245 .50885 .65019 .51711 .66604 .51219 .65836 .50368 Mtetra
.664 .764 .925 r
.65836 .50368 .66604 .51219 .68199 .50733 .67435 .49848 Mtetra
.659 .756 .921 r
.67435 .49848 .68199 .50733 .69804 .50265 .69045 .49346 Mtetra
.653 .746 .918 r
.69045 .49346 .69804 .50265 .71419 .49813 .70665 .48865 Mtetra
.646 .738 .916 r
.70665 .48865 .71419 .49813 .73042 .49334 .72296 .4841 Mtetra
.653 .748 .919 r
.72296 .4841 .73042 .49334 .74672 .48817 .73934 .47921 Mtetra
.663 .759 .922 r
.73934 .47921 .74672 .48817 .76311 .48299 .7558 .47392 Mtetra
.661 .757 .922 r
.7558 .47392 .76311 .48299 .77961 .47793 .77236 .46868 Mtetra
.655 .752 .921 r
.77236 .46868 .77961 .47793 .79623 .47319 .78903 .46365 Mtetra
.648 .744 .919 r
.78903 .46365 .79623 .47319 .81294 .46829 .80581 .45886 Mtetra
.656 .751 .92 r
.80581 .45886 .81294 .46829 .82971 .46306 .82267 .45371 Mtetra
.66 .756 .921 r
.82267 .45371 .82971 .46306 .84659 .45778 .83962 .44836 Mtetra
.659 .755 .921 r
.83962 .44836 .84659 .45778 .86358 .45267 .85666 .44304 Mtetra
.651 .748 .92 r
.85666 .44304 .86358 .45267 .88069 .44772 .87384 .43801 Mtetra
.653 .748 .919 r
.87384 .43801 .88069 .44772 .89787 .44252 .89112 .43287 Mtetra
.658 .753 .92 r
.89112 .43287 .89787 .44252 .91515 .43716 .90847 .4275 Mtetra
.655 .752 .922 r
.29053 .60492 .29958 .61277 .31361 .60859 .3046 .60064 Mtetra
.661 .753 .918 r
.3046 .60064 .31361 .60859 .32773 .60418 .31877 .59611 Mtetra
.657 .75 .918 r
.31877 .59611 .32773 .60418 .34192 .59969 .333 .5917 Mtetra
.651 .751 .923 r
.333 .5917 .34192 .59969 .35617 .59547 .3473 .58749 Mtetra
.651 .752 .924 r
.3473 .58749 .35617 .59547 .3705 .59129 .36168 .58323 Mtetra
.661 .754 .919 r
.36168 .58323 .3705 .59129 .38492 .58692 .37615 .57861 Mtetra
.662 .749 .915 r
.37615 .57861 .38492 .58692 .39942 .58222 .3907 .57393 Mtetra
.652 .748 .92 r
.3907 .57393 .39942 .58222 .41399 .57774 .40531 .56959 Mtetra
.647 .752 .925 r
.40531 .56959 .41399 .57774 .42864 .57347 .42001 .56538 Mtetra
.654 .756 .925 r
.42001 .56538 .42864 .57347 .44336 .56926 .43479 .56091 Mtetra
.667 .754 .915 r
.43479 .56091 .44336 .56926 .45817 .56466 .44966 .55593 Mtetra
.661 .744 .912 r
.44966 .55593 .45817 .56466 .47307 .55973 .4646 .55118 Mtetra
.652 .747 .92 r
.4646 .55118 .47307 .55973 .48805 .55506 .47963 .54674 Mtetra
.643 .751 .928 r
.47963 .54674 .48805 .55506 .5031 .5506 .49473 .54256 Mtetra
.645 .76 .933 r
.49473 .54256 .5031 .5506 .51824 .54631 .50992 .53826 Mtetra
.664 .767 .926 r
.50992 .53826 .51824 .54631 .53346 .54201 .52521 .53325 Mtetra
.664 .751 .915 r
.52521 .53325 .53346 .54201 .54877 .53754 .54057 .52822 Mtetra
.658 .737 .908 r
.54057 .52822 .54877 .53754 .56417 .53277 .55602 .5234 Mtetra
.656 .736 .909 r
.55602 .5234 .56417 .53277 .57965 .52794 .57155 .51868 Mtetra
.656 .74 .911 r
.57155 .51868 .57965 .52794 .59521 .5232 .58718 .51389 Mtetra
.657 .74 .911 r
.58718 .51389 .59521 .5232 .61087 .51856 .60289 .50904 Mtetra
.654 .736 .909 r
.60289 .50904 .61087 .51856 .62662 .51386 .61869 .50429 Mtetra
.648 .733 .911 r
.61869 .50429 .62662 .51386 .64245 .50885 .63459 .49974 Mtetra
.647 .745 .921 r
.63459 .49974 .64245 .50885 .65836 .50368 .65059 .49519 Mtetra
.664 .767 .927 r
.65059 .49519 .65836 .50368 .67435 .49848 .66665 .48991 Mtetra
.667 .767 .925 r
.66665 .48991 .67435 .49848 .69045 .49346 .6828 .4845 Mtetra
.66 .757 .922 r
.6828 .4845 .69045 .49346 .70665 .48865 .69904 .47936 Mtetra
.652 .747 .919 r
.69904 .47936 .70665 .48865 .72296 .4841 .7154 .47452 Mtetra
.645 .739 .917 r
.7154 .47452 .72296 .4841 .73934 .47921 .73188 .46992 Mtetra
.657 .752 .92 r
.73188 .46992 .73934 .47921 .7558 .47392 .74842 .46479 Mtetra
.663 .759 .922 r
.74842 .46479 .7558 .47392 .77236 .46868 .76503 .4594 Mtetra
.659 .755 .921 r
.76503 .4594 .77236 .46868 .78903 .46365 .78176 .45413 Mtetra
.65 .747 .921 r
.78176 .45413 .78903 .46365 .80581 .45886 .79861 .4492 Mtetra
.651 .746 .919 r
.79861 .4492 .80581 .45886 .82267 .45371 .81556 .44422 Mtetra
.659 .754 .92 r
.81556 .44422 .82267 .45371 .83962 .44836 .83257 .43885 Mtetra
.66 .755 .92 r
.83257 .43885 .83962 .44836 .85666 .44304 .84969 .43342 Mtetra
.654 .752 .921 r
.84969 .43342 .85666 .44304 .87384 .43801 .86692 .42819 Mtetra
.651 .747 .92 r
.86692 .42819 .87384 .43801 .89112 .43287 .88428 .42309 Mtetra
.657 .752 .92 r
.88428 .42309 .89112 .43287 .90847 .4275 .90172 .41771 Mtetra
.28138 .59696 .29053 .60492 .3046 .60064 .29551 .59257 Mtetra
.662 .752 .917 r
.29551 .59257 .3046 .60064 .31877 .59611 .30972 .58797 Mtetra
.654 .749 .92 r
.30972 .58797 .31877 .59611 .333 .5917 .32399 .58364 Mtetra
.65 .751 .924 r
.32399 .58364 .333 .5917 .3473 .58749 .33834 .57941 Mtetra
.654 .753 .922 r
.33834 .57941 .3473 .58749 .36168 .58323 .35277 .57502 Mtetra
.664 .753 .916 r
.35277 .57502 .36168 .58323 .37615 .57861 .36729 .57022 Mtetra
.657 .748 .917 r
.36729 .57022 .37615 .57861 .3907 .57393 .38189 .56569 Mtetra
.649 .751 .924 r
.38189 .56569 .3907 .57393 .40531 .56959 .39655 .56141 Mtetra
.648 .753 .926 r
.39655 .56141 .40531 .56959 .42001 .56538 .41129 .55712 Mtetra
.665 .757 .919 r
.41129 .55712 .42001 .56538 .43479 .56091 .42613 .55221 Mtetra
.665 .747 .912 r
.42613 .55221 .43479 .56091 .44966 .55593 .44105 .54728 Mtetra
.653 .746 .918 r
.44105 .54728 .44966 .55593 .4646 .55118 .45605 .54279 Mtetra
.642 .75 .928 r
.45605 .54279 .4646 .55118 .47963 .54674 .47112 .53863 Mtetra
.644 .759 .932 r
.47112 .53863 .47963 .54674 .49473 .54256 .48628 .53432 Mtetra
.671 .765 .921 r
.48628 .53432 .49473 .54256 .50992 .53826 .50153 .52903 Mtetra
.66 .739 .909 r
.50153 .52903 .50992 .53826 .52521 .53325 .51687 .52416 Mtetra
.639 .737 .92 r
.51687 .52416 .52521 .53325 .54057 .52822 .53229 .52006 Mtetra
.625 .756 .941 r
.53229 .52006 .54057 .52822 .55602 .5234 .5478 .51628 Mtetra
.627 .786 .958 r
.5478 .51628 .55602 .5234 .57155 .51868 .56341 .5122 Mtetra
.645 .811 .963 r
.56341 .5122 .57155 .51868 .58718 .51389 .57911 .50737 Mtetra
.669 .818 .955 r
.57911 .50737 .58718 .51389 .60289 .50904 .59487 .50178 Mtetra
.679 .801 .94 r
.59487 .50178 .60289 .50904 .61869 .50429 .61072 .49589 Mtetra
.672 .772 .925 r
.61072 .49589 .61869 .50429 .63459 .49974 .62665 .49031 Mtetra
.653 .741 .915 r
.62665 .49031 .63459 .49974 .65059 .49519 .6427 .4855 Mtetra
.641 .733 .915 r
.6427 .4855 .65059 .49519 .66665 .48991 .65886 .48112 Mtetra
.665 .764 .924 r
.65886 .48112 .66665 .48991 .6828 .4845 .67508 .47574 Mtetra
.668 .767 .924 r
.67508 .47574 .6828 .4845 .69904 .47936 .69137 .47021 Mtetra
.659 .756 .921 r
.69137 .47021 .69904 .47936 .7154 .47452 .70778 .46502 Mtetra
.648 .744 .92 r
.70778 .46502 .7154 .47452 .73188 .46992 .72431 .46026 Mtetra
.647 .741 .918 r
.72431 .46026 .73188 .46992 .74842 .46479 .74094 .45549 Mtetra
.662 .757 .92 r
.74094 .45549 .74842 .46479 .76503 .4594 .75763 .45006 Mtetra
.662 .757 .921 r
.75763 .45006 .76503 .4594 .78176 .45413 .77442 .44463 Mtetra
.655 .752 .921 r
.77442 .44463 .78176 .45413 .79861 .4492 .79132 .43946 Mtetra
.648 .745 .92 r
.79132 .43946 .79861 .4492 .81556 .44422 .80835 .43454 Mtetra
.657 .752 .92 r
.80835 .43454 .81556 .44422 .83257 .43885 .82545 .42921 Mtetra
.661 .755 .92 r
.82545 .42921 .83257 .43885 .84969 .43342 .84263 .4237 Mtetra
.658 .753 .921 r
.84263 .4237 .84969 .43342 .86692 .42819 .85993 .41829 Mtetra
.65 .747 .921 r
.85993 .41829 .86692 .42819 .88428 .42309 .87737 .41316 Mtetra
.655 .75 .92 r
.87737 .41316 .88428 .42309 .90172 .41771 .89489 .40779 Mtetra
.659 .752 .919 r
.27215 .58892 .28138 .59696 .29551 .59257 .28632 .58441 Mtetra
.661 .751 .917 r
.28632 .58441 .29551 .59257 .30972 .58797 .30058 .57981 Mtetra
.652 .75 .922 r
.30058 .57981 .30972 .58797 .32399 .58364 .3149 .57551 Mtetra
.65 .751 .923 r
.3149 .57551 .32399 .58364 .33834 .57941 .32929 .57122 Mtetra
.658 .753 .92 r
.32929 .57122 .33834 .57941 .35277 .57502 .34377 .56663 Mtetra
.664 .751 .915 r
.34377 .56663 .35277 .57502 .36729 .57022 .35835 .56182 Mtetra
.653 .749 .92 r
.35835 .56182 .36729 .57022 .38189 .56569 .37298 .55739 Mtetra
.647 .751 .925 r
.37298 .55739 .38189 .56569 .39655 .56141 .38769 .55313 Mtetra
.655 .755 .923 r
.38769 .55313 .39655 .56141 .41129 .55712 .40249 .54856 Mtetra
.669 .753 .913 r
.40249 .54856 .41129 .55712 .42613 .55221 .41739 .54345 Mtetra
.657 .746 .915 r
.41739 .54345 .42613 .55221 .44105 .54728 .43236 .53877 Mtetra
.644 .749 .925 r
.43236 .53877 .44105 .54728 .45605 .54279 .44739 .5345 Mtetra
.64 .755 .931 r
.44739 .5345 .45605 .54279 .47112 .53863 .46252 .53033 Mtetra
.67 .764 .921 r
.46252 .53033 .47112 .53863 .48628 .53432 .47775 .52503 Mtetra
.657 .738 .91 r
.47775 .52503 .48628 .53432 .50153 .52903 .49305 .52027 Mtetra
.612 .737 .934 r
.49305 .52027 .50153 .52903 .51687 .52416 .50843 .51702 Mtetra
.541 .754 .975 r
.50843 .51702 .51687 .52416 .53229 .52006 .52392 .51514 Mtetra
.415 .765 .995 r
.52392 .51514 .53229 .52006 .5478 .51628 .53952 .51437 Mtetra
.368 .814 .948 r
.53952 .51437 .5478 .51628 .56341 .5122 .55523 .51189 Mtetra
.437 .872 .908 r
.55523 .51189 .56341 .5122 .57911 .50737 .57103 .50702 Mtetra
.591 .941 .929 r
.57103 .50702 .57911 .50737 .59487 .50178 .58687 .49974 Mtetra
.723 .951 .951 r
.58687 .49974 .59487 .50178 .61072 .49589 .60273 .49074 Mtetra
.724 .874 .951 r
.60273 .49074 .61072 .49589 .62665 .49031 .61869 .48282 Mtetra
.693 .805 .934 r
.61869 .48282 .62665 .49031 .6427 .4855 .63475 .47628 Mtetra
.655 .751 .92 r
.63475 .47628 .6427 .4855 .65886 .48112 .65095 .47127 Mtetra
.642 .732 .914 r
.65095 .47127 .65886 .48112 .67508 .47574 .66727 .46679 Mtetra
.669 .765 .922 r
.66727 .46679 .67508 .47574 .69137 .47021 .68363 .46117 Mtetra
.666 .763 .922 r
.68363 .46117 .69137 .47021 .70778 .46502 .70009 .45564 Mtetra
.655 .752 .921 r
.70009 .45564 .70778 .46502 .72431 .46026 .71667 .45052 Mtetra
.643 .741 .92 r
.71667 .45052 .72431 .46026 .74094 .45549 .73338 .44585 Mtetra
.656 .749 .918 r
.73338 .44585 .74094 .45549 .75763 .45006 .75015 .44062 Mtetra
.664 .758 .92 r
.75015 .44062 .75763 .45006 .77442 .44463 .767 .43506 Mtetra
.659 .754 .921 r
.767 .43506 .77442 .44463 .79132 .43946 .78396 .42967 Mtetra
.648 .746 .921 r
.78396 .42967 .79132 .43946 .80835 .43454 .80106 .42468 Mtetra
.653 .748 .919 r
.80106 .42468 .80835 .43454 .82545 .42921 .81825 .41944 Mtetra
.66 .754 .92 r
.81825 .41944 .82545 .42921 .84263 .4237 .83551 .41389 Mtetra
.659 .754 .92 r
.83551 .41389 .84263 .4237 .85993 .41829 .85287 .40834 Mtetra
.651 .749 .921 r
.85287 .40834 .85993 .41829 .87737 .41316 .87037 .4031 Mtetra
.653 .749 .92 r
.87037 .4031 .87737 .41316 .89489 .40779 .88798 .39775 Mtetra
.66 .753 .918 r
.26282 .58078 .27215 .58892 .28632 .58441 .27705 .57617 Mtetra
.659 .751 .918 r
.27705 .57617 .28632 .58441 .30058 .57981 .29135 .5716 Mtetra
.651 .751 .923 r
.29135 .5716 .30058 .57981 .3149 .57551 .30571 .56728 Mtetra
.30571 .56728 .3149 .57551 .32929 .57122 .32015 .56293 Mtetra
.662 .754 .918 r
.32015 .56293 .32929 .57122 .34377 .56663 .33469 .55817 Mtetra
.661 .75 .916 r
.33469 .55817 .34377 .56663 .35835 .56182 .34931 .55342 Mtetra
.65 .75 .923 r
.34931 .55342 .35835 .56182 .37298 .55739 .36398 .54901 Mtetra
.647 .751 .925 r
.36398 .54901 .37298 .55739 .38769 .55313 .37874 .54472 Mtetra
.663 .755 .919 r
.37874 .54472 .38769 .55313 .40249 .54856 .3936 .53982 Mtetra
.666 .75 .913 r
.3936 .53982 .40249 .54856 .41739 .54345 .40855 .53477 Mtetra
.651 .748 .921 r
.40855 .53477 .41739 .54345 .43236 .53877 .42356 .53025 Mtetra
.638 .749 .929 r
.42356 .53025 .43236 .53877 .44739 .5345 .43865 .52614 Mtetra
.659 .76 .925 r
.43865 .52614 .44739 .5345 .46252 .53033 .45384 .52125 Mtetra
.666 .746 .911 r
.45384 .52125 .46252 .53033 .47775 .52503 .46912 .5161 Mtetra
.608 .732 .933 r
.46912 .5161 .47775 .52503 .49305 .52027 .48446 .51295 Mtetra
.451 .712 .979 r
.48446 .51295 .49305 .52027 .50843 .51702 .49988 .51296 Mtetra
.125 .619 .909 r
.49988 .51296 .50843 .51702 .52392 .51514 .51542 .51518 Mtetra
.045 0 0 r
.51542 .51518 .52392 .51514 .53952 .51437 .53112 .51566 Mtetra
0 0 0 r
.53112 .51566 .53952 .51437 .55523 .51189 .54693 .5133 Mtetra
.305 .797 .783 r
.54693 .5133 .55523 .51189 .57103 .50702 .56284 .50839 Mtetra
.494 .905 .841 r
.56284 .50839 .57103 .50702 .58687 .49974 .57879 .50092 Mtetra
.662 .973 .868 r
.57879 .50092 .58687 .49974 .60273 .49074 .59475 .49058 Mtetra
.775 .988 .894 r
.59475 .49058 .60273 .49074 .61869 .48282 .61071 .47845 Mtetra
.769 .904 .935 r
.61071 .47845 .61869 .48282 .63475 .47628 .62676 .46852 Mtetra
.697 .802 .931 r
.62676 .46852 .63475 .47628 .65095 .47127 .64297 .46176 Mtetra
.646 .745 .921 r
.64297 .46176 .65095 .47127 .66727 .46679 .65934 .45703 Mtetra
.652 .742 .916 r
.65934 .45703 .66727 .46679 .68363 .46117 .6758 .45203 Mtetra
.671 .765 .921 r
.6758 .45203 .68363 .46117 .70009 .45564 .69232 .44624 Mtetra
.66 .756 .921 r
.69232 .44624 .70009 .45564 .71667 .45052 .70896 .44086 Mtetra
.646 .746 .922 r
.70896 .44086 .71667 .45052 .73338 .44585 .72572 .43602 Mtetra
.649 .744 .919 r
.72572 .43602 .73338 .44585 .75015 .44062 .74258 .43102 Mtetra
.664 .757 .919 r
.74258 .43102 .75015 .44062 .767 .43506 .7595 .42539 Mtetra
.66 .755 .92 r
.7595 .42539 .767 .43506 .78396 .42967 .77653 .41987 Mtetra
.651 .75 .922 r
.77653 .41987 .78396 .42967 .80106 .42468 .79369 .41471 Mtetra
.65 .747 .92 r
.79369 .41471 .80106 .42468 .81825 .41944 .81096 .40954 Mtetra
.66 .754 .92 r
.81096 .40954 .81825 .41944 .83551 .41389 .8283 .40395 Mtetra
.8283 .40395 .83551 .41389 .85287 .40834 .84573 .39831 Mtetra
.653 .751 .921 r
.84573 .39831 .85287 .40834 .87037 .4031 .8633 .39293 Mtetra
.652 .748 .921 r
.8633 .39293 .87037 .4031 .88798 .39775 .88099 .38759 Mtetra
.661 .753 .918 r
.2534 .57256 .26282 .58078 .27705 .57617 .26768 .56787 Mtetra
.657 .751 .919 r
.26768 .56787 .27705 .57617 .29135 .5716 .28202 .56331 Mtetra
.65 .751 .923 r
.28202 .56331 .29135 .5716 .30571 .56728 .29642 .55897 Mtetra
.652 .751 .922 r
.29642 .55897 .30571 .56728 .32015 .56293 .31091 .55454 Mtetra
.664 .754 .917 r
.31091 .55454 .32015 .56293 .33469 .55817 .32551 .54965 Mtetra
.658 .75 .918 r
.32551 .54965 .33469 .55817 .34931 .55342 .34017 .54494 Mtetra
.649 .75 .923 r
.34017 .54494 .34931 .55342 .36398 .54901 .3549 .54056 Mtetra
.648 .751 .925 r
.3549 .54056 .36398 .54901 .37874 .54472 .3697 .53617 Mtetra
.668 .756 .916 r
.3697 .53617 .37874 .54472 .3936 .53982 .38463 .53103 Mtetra
.661 .749 .915 r
.38463 .53103 .3936 .53982 .40855 .53477 .39962 .5261 Mtetra
.646 .749 .924 r
.39962 .5261 .40855 .53477 .42356 .53025 .41468 .52171 Mtetra
.638 .751 .93 r
.41468 .52171 .42356 .53025 .43865 .52614 .42982 .51755 Mtetra
.673 .761 .917 r
.42982 .51755 .43865 .52614 .45384 .52125 .44508 .51209 Mtetra
.64 .739 .92 r
.44508 .51209 .45384 .52125 .46912 .5161 .46039 .50788 Mtetra
.513 .716 .964 r
.46039 .50788 .46912 .5161 .48446 .51295 .47575 .50696 Mtetra
.096 .55 .91 r
.47575 .50696 .48446 .51295 .49988 .51296 .49119 .51107 Mtetra
0 .472 .716 r
.49119 .51107 .49988 .51296 .51542 .51518 .5068 .51406 Mtetra
.16 .694 .845 r
.5068 .51406 .51542 .51518 .53112 .51566 .52258 .51328 Mtetra
.507 .875 .98 r
.52258 .51328 .53112 .51566 .54693 .5133 .53847 .5091 Mtetra
.608 .87 .992 r
.53847 .5091 .54693 .5133 .56284 .50839 .55446 .50414 Mtetra
.639 .879 .986 r
.55446 .50414 .56284 .50839 .57879 .50092 .57053 .49841 Mtetra
.731 .943 .952 r
.57053 .49841 .57879 .50092 .59475 .49058 .58662 .48925 Mtetra
.815 .972 .899 r
.58662 .48925 .59475 .49058 .61071 .47845 .60268 .47626 Mtetra
.844 .954 .886 r
.60268 .47626 .61071 .47845 .62676 .46852 .61872 .46209 Mtetra
.75 .851 .925 r
.61872 .46209 .62676 .46852 .64297 .46176 .63493 .45297 Mtetra
.671 .772 .926 r
.63493 .45297 .64297 .46176 .65934 .45703 .65133 .44718 Mtetra
.639 .738 .92 r
.65133 .44718 .65934 .45703 .6758 .45203 .66788 .44266 Mtetra
.671 .761 .918 r
.66788 .44266 .6758 .45203 .69232 .44624 .68447 .43682 Mtetra
.665 .759 .921 r
.68447 .43682 .69232 .44624 .70896 .44086 .70116 .43119 Mtetra
.65 .75 .922 r
.70116 .43119 .70896 .44086 .72572 .43602 .71799 .42611 Mtetra
.644 .743 .921 r
.71799 .42611 .72572 .43602 .74258 .43102 .73493 .42126 Mtetra
.663 .755 .919 r
.73493 .42126 .74258 .43102 .7595 .42539 .75192 .41563 Mtetra
.662 .756 .92 r
.75192 .41563 .7595 .42539 .77653 .41987 .76902 .40998 Mtetra
.653 .751 .921 r
.76902 .40998 .77653 .41987 .79369 .41471 .78624 .40465 Mtetra
.648 .747 .921 r
.78624 .40465 .79369 .41471 .81096 .40954 .80359 .39952 Mtetra
.659 .753 .919 r
.80359 .39952 .81096 .40954 .8283 .40395 .82101 .39389 Mtetra
.661 .754 .919 r
.82101 .39389 .8283 .40395 .84573 .39831 .83852 .38818 Mtetra
.655 .751 .921 r
.83852 .38818 .84573 .39831 .8633 .39293 .85616 .38267 Mtetra
.651 .748 .921 r
.85616 .38267 .8633 .39293 .88099 .38759 .87393 .3773 Mtetra
.662 .753 .918 r
.24388 .56425 .2534 .57256 .26768 .56787 .25821 .55949 Mtetra
.656 .751 .92 r
.25821 .55949 .26768 .56787 .28202 .56331 .2726 .55493 Mtetra
.65 .75 .923 r
.2726 .55493 .28202 .56331 .29642 .55897 .28705 .55055 Mtetra
.653 .751 .922 r
.28705 .55055 .29642 .55897 .31091 .55454 .30159 .54604 Mtetra
.665 .754 .916 r
.30159 .54604 .31091 .55454 .32551 .54965 .31623 .54107 Mtetra
.656 .75 .919 r
.31623 .54107 .32551 .54965 .34017 .54494 .33094 .53638 Mtetra
.648 .75 .924 r
.33094 .53638 .34017 .54494 .3549 .54056 .34571 .53199 Mtetra
.651 .751 .923 r
.34571 .53199 .3549 .54056 .3697 .53617 .36058 .52746 Mtetra
.67 .754 .914 r
.36058 .52746 .3697 .53617 .38463 .53103 .37556 .5222 Mtetra
.658 .75 .918 r
.37556 .5222 .38463 .53103 .39962 .5261 .3906 .51735 Mtetra
.642 .748 .926 r
.3906 .51735 .39962 .5261 .41468 .52171 .4057 .51305 Mtetra
.646 .752 .927 r
.4057 .51305 .41468 .52171 .42982 .51755 .4209 .50858 Mtetra
.673 .754 .912 r
.4209 .50858 .42982 .51755 .44508 .51209 .43622 .50308 Mtetra
.606 .733 .935 r
.43622 .50308 .44508 .51209 .46039 .50788 .45156 .4999 Mtetra
.341 .643 .965 r
.45156 .4999 .46039 .50788 .47575 .50696 .46692 .50201 Mtetra
0 .44 .805 r
.46692 .50201 .47575 .50696 .49119 .51107 .48239 .50737 Mtetra
.131 .634 .905 r
.48239 .50737 .49119 .51107 .5068 .51406 .49807 .50911 Mtetra
.678 .867 .971 r
.49807 .50911 .5068 .51406 .52258 .51328 .51393 .5027 Mtetra
.739 .747 .859 r
.51393 .5027 .52258 .51328 .53847 .5091 .52987 .4933 Mtetra
.645 .633 .824 r
.52987 .4933 .53847 .5091 .55446 .50414 .54589 .48829 Mtetra
.556 .59 .843 r
.54589 .48829 .55446 .50414 .57053 .49841 .56205 .48767 Mtetra
.618 .708 .91 r
.56205 .48767 .57053 .49841 .58662 .48925 .5783 .48407 Mtetra
.804 .886 .904 r
.5783 .48407 .58662 .48925 .60268 .47626 .59449 .47224 Mtetra
.861 .91 .864 r
.59449 .47224 .60268 .47626 .61872 .46209 .6106 .45671 Mtetra
.811 .884 .898 r
.6106 .45671 .61872 .46209 .63493 .45297 .62682 .44442 Mtetra
.697 .789 .921 r
.62682 .44442 .63493 .45297 .65133 .44718 .64325 .43748 Mtetra
.639 .743 .924 r
.64325 .43748 .65133 .44718 .66788 .44266 .65986 .43289 Mtetra
.665 .752 .916 r
.65986 .43289 .66788 .44266 .68447 .43682 .67653 .42725 Mtetra
.668 .76 .919 r
.67653 .42725 .68447 .43682 .70116 .43119 .69329 .42143 Mtetra
.654 .751 .921 r
.69329 .42143 .70116 .43119 .71799 .42611 .71017 .41616 Mtetra
.642 .744 .923 r
.71017 .41616 .71799 .42611 .73493 .42126 .72719 .41132 Mtetra
.66 .752 .918 r
.72719 .41132 .73493 .42126 .75192 .41563 .74426 .40572 Mtetra
.663 .756 .919 r
.74426 .40572 .75192 .41563 .76902 .40998 .76142 .39997 Mtetra
.655 .752 .921 r
.76142 .39997 .76902 .40998 .78624 .40465 .77872 .39452 Mtetra
.647 .747 .922 r
.77872 .39452 .78624 .40465 .80359 .39952 .79614 .38936 Mtetra
.658 .752 .919 r
.79614 .38936 .80359 .39952 .82101 .39389 .81363 .38371 Mtetra
.661 .754 .919 r
.81363 .38371 .82101 .39389 .83852 .38818 .83122 .37792 Mtetra
.656 .752 .921 r
.83122 .37792 .83852 .38818 .85616 .38267 .84893 .37231 Mtetra
.65 .748 .921 r
.84893 .37231 .85616 .38267 .87393 .3773 .86678 .3669 Mtetra
.662 .753 .917 r
.23427 .55586 .24388 .56425 .25821 .55949 .24865 .55104 Mtetra
.655 .751 .92 r
.24865 .55104 .25821 .55949 .2726 .55493 .26308 .54646 Mtetra
.65 .75 .923 r
.26308 .54646 .2726 .55493 .28705 .55055 .27757 .54203 Mtetra
.654 .751 .921 r
.27757 .54203 .28705 .55055 .30159 .54604 .29216 .53745 Mtetra
.665 .753 .916 r
.29216 .53745 .30159 .54604 .31623 .54107 .30686 .53242 Mtetra
.655 .751 .92 r
.30686 .53242 .31623 .54107 .33094 .53638 .32162 .52773 Mtetra
.647 .749 .924 r
.32162 .52773 .33094 .53638 .34571 .53199 .33644 .5233 Mtetra
.653 .751 .922 r
.33644 .5233 .34571 .53199 .36058 .52746 .35136 .51865 Mtetra
.67 .754 .914 r
.35136 .51865 .36058 .52746 .37556 .5222 .36639 .51333 Mtetra
.656 .75 .919 r
.36639 .51333 .37556 .5222 .3906 .51735 .38148 .50851 Mtetra
.64 .747 .926 r
.38148 .50851 .3906 .51735 .4057 .51305 .39664 .50422 Mtetra
.652 .752 .923 r
.39664 .50422 .4057 .51305 .4209 .50858 .4119 .49949 Mtetra
.669 .752 .913 r
.4119 .49949 .4209 .50858 .43622 .50308 .42726 .4941 Mtetra
.582 .727 .943 r
.42726 .4941 .43622 .50308 .45156 .4999 .44264 .49157 Mtetra
.245 .581 .944 r
.44264 .49157 .45156 .4999 .46692 .50201 .458 .49529 Mtetra
.02 .482 .876 r
.458 .49529 .46692 .50201 .48239 .50737 .47351 .50079 Mtetra
.42 .727 .989 r
.47351 .50079 .48239 .50737 .49807 .50911 .48926 .50069 Mtetra
.785 .799 .864 r
.48926 .50069 .49807 .50911 .51393 .5027 .50523 .48906 Mtetra
.763 .707 .8 r
.50523 .48906 .51393 .5027 .52987 .4933 .52122 .47619 Mtetra
.642 .617 .809 r
.52122 .47619 .52987 .4933 .54589 .48829 .53726 .4711 Mtetra
.476 .531 .835 r
.53726 .4711 .54589 .48829 .56205 .48767 .55346 .47384 Mtetra
.483 .588 .883 r
.55346 .47384 .56205 .48767 .5783 .48407 .56982 .47538 Mtetra
.759 .799 .885 r
.56982 .47538 .5783 .48407 .59449 .47224 .58612 .4653 Mtetra
.846 .845 .843 r
.58612 .4653 .59449 .47224 .6106 .45671 .60234 .44953 Mtetra
.825 .843 .861 r
.60234 .44953 .6106 .45671 .62682 .44442 .6186 .4355 Mtetra
.713 .787 .91 r
.6186 .4355 .62682 .44442 .64325 .43748 .63508 .42779 Mtetra
.643 .747 .925 r
.63508 .42779 .64325 .43748 .65986 .43289 .65175 .42299 Mtetra
.659 .75 .917 r
.65175 .42299 .65986 .43289 .67653 .42725 .6685 .4175 Mtetra
.67 .758 .917 r
.6685 .4175 .67653 .42725 .69329 .42143 .68532 .41155 Mtetra
.656 .752 .921 r
.68532 .41155 .69329 .42143 .71017 .41616 .70227 .40615 Mtetra
.642 .745 .924 r
.70227 .40615 .71017 .41616 .72719 .41132 .71936 .40126 Mtetra
.659 .752 .919 r
.71936 .40126 .72719 .41132 .74426 .40572 .73651 .39567 Mtetra
.663 .755 .918 r
.73651 .39567 .74426 .40572 .76142 .39997 .75374 .38985 Mtetra
.656 .752 .92 r
.75374 .38985 .76142 .39997 .77872 .39452 .7711 .38429 Mtetra
.647 .747 .922 r
.7711 .38429 .77872 .39452 .79614 .38936 .7886 .37908 Mtetra
.658 .752 .919 r
.7886 .37908 .79614 .38936 .81363 .38371 .80617 .3734 Mtetra
.661 .754 .919 r
.80617 .3734 .81363 .38371 .83122 .37792 .82384 .36754 Mtetra
.656 .752 .92 r
.82384 .36754 .83122 .37792 .84893 .37231 .84163 .36184 Mtetra
.65 .749 .922 r
.84163 .36184 .84893 .37231 .86678 .3669 .85955 .35638 Mtetra
.662 .753 .917 r
.22456 .54739 .23427 .55586 .24865 .55104 .23898 .54252 Mtetra
.655 .751 .92 r
.23898 .54252 .24865 .55104 .26308 .54646 .25346 .53789 Mtetra
.65 .75 .923 r
.25346 .53789 .26308 .54646 .27757 .54203 .26801 .53342 Mtetra
.654 .751 .921 r
.26801 .53342 .27757 .54203 .29216 .53745 .28264 .52878 Mtetra
.665 .754 .916 r
.28264 .52878 .29216 .53745 .30686 .53242 .29739 .52371 Mtetra
.655 .751 .92 r
.29739 .52371 .30686 .53242 .32162 .52773 .3122 .51896 Mtetra
.647 .749 .924 r
.3122 .51896 .32162 .52773 .33644 .5233 .32707 .51449 Mtetra
.653 .751 .922 r
.32707 .51449 .33644 .5233 .35136 .51865 .34204 .50979 Mtetra
.67 .755 .914 r
.34204 .50979 .35136 .51865 .36639 .51333 .35712 .50442 Mtetra
.656 .751 .92 r
.35712 .50442 .36639 .51333 .38148 .50851 .37227 .49955 Mtetra
.64 .747 .926 r
.37227 .49955 .38148 .50851 .39664 .50422 .38747 .49521 Mtetra
.652 .75 .922 r
.38747 .49521 .39664 .50422 .4119 .49949 .40279 .49043 Mtetra
.669 .755 .915 r
.40279 .49043 .4119 .49949 .42726 .4941 .41821 .48498 Mtetra
.582 .727 .942 r
.41821 .48498 .42726 .4941 .44264 .49157 .43364 .48241 Mtetra
.277 .58 .942 r
.43364 .48241 .44264 .49157 .458 .49529 .44903 .4861 Mtetra
.162 .511 .913 r
.44903 .4861 .458 .49529 .47351 .50079 .46457 .49157 Mtetra
.483 .687 .957 r
.46457 .49157 .47351 .50079 .48926 .50069 .48037 .49143 Mtetra
.78 .783 .856 r
.48037 .49143 .48926 .50069 .50523 .48906 .49641 .47973 Mtetra
.795 .785 .844 r
.49641 .47973 .50523 .48906 .52122 .47619 .51248 .46678 Mtetra
.655 .753 .922 r
.51248 .46678 .52122 .47619 .53726 .4711 .52858 .46164 Mtetra
.351 .615 .95 r
.52858 .46164 .53726 .4711 .55346 .47384 .54483 .46435 Mtetra
.413 .648 .955 r
.54483 .46435 .55346 .47384 .56982 .47538 .56123 .46585 Mtetra
.755 .782 .875 r
.56123 .46585 .56982 .47538 .58612 .4653 .57761 .45569 Mtetra
.825 .792 .821 r
.57761 .45569 .58612 .4653 .60234 .44953 .59392 .43984 Mtetra
.807 .791 .837 r
.59392 .43984 .60234 .44953 .6186 .4355 .61027 .42573 Mtetra
.711 .77 .898 r
.61027 .42573 .6186 .4355 .63508 .42779 .62682 .41796 Mtetra
.643 .747 .924 r
.62682 .41796 .63508 .42779 .65175 .42299 .64356 .4131 Mtetra
.659 .753 .919 r
.64356 .4131 .65175 .42299 .6685 .4175 .66037 .40755 Mtetra
.67 .756 .916 r
.66037 .40755 .6685 .4175 .68532 .41155 .67727 .40154 Mtetra
.656 .751 .92 r
.67727 .40154 .68532 .41155 .70227 .40615 .69429 .39608 Mtetra
.642 .746 .924 r
.69429 .39608 .70227 .40615 .71936 .40126 .71144 .39113 Mtetra
.659 .753 .919 r
.71144 .39113 .71936 .40126 .73651 .39567 .72866 .38548 Mtetra
.663 .754 .918 r
.72866 .38548 .73651 .39567 .75374 .38985 .74597 .37959 Mtetra
.656 .751 .92 r
.74597 .37959 .75374 .38985 .7711 .38429 .76341 .37398 Mtetra
.647 .748 .923 r
.76341 .37398 .7711 .38429 .7886 .37908 .78098 .3687 Mtetra
.658 .752 .92 r
.78098 .3687 .7886 .37908 .80617 .3734 .79863 .36295 Mtetra
.661 .753 .919 r
.79863 .36295 .80617 .3734 .82384 .36754 .81637 .35703 Mtetra
.656 .752 .92 r
.81637 .35703 .82384 .36754 .84163 .36184 .83424 .35127 Mtetra
.65 .749 .922 r
.83424 .35127 .84163 .36184 .85955 .35638 .85224 .34574 Mtetra
.662 .753 .918 r
.21475 .53883 .22456 .54739 .23898 .54252 .22922 .53393 Mtetra
.656 .752 .92 r
.22922 .53393 .23898 .54252 .25346 .53789 .24375 .52922 Mtetra
.65 .75 .922 r
.24375 .52922 .25346 .53789 .26801 .53342 .25834 .5247 Mtetra
.653 .75 .921 r
.25834 .5247 .26801 .53342 .28264 .52878 .27302 .52005 Mtetra
.665 .754 .917 r
.27302 .52005 .28264 .52878 .29739 .52371 .28782 .51493 Mtetra
.656 .752 .92 r
.28782 .51493 .29739 .52371 .3122 .51896 .30268 .5101 Mtetra
.648 .749 .923 r
.30268 .5101 .3122 .51896 .32707 .51449 .3176 .50556 Mtetra
.651 .749 .922 r
.3176 .50556 .32707 .51449 .34204 .50979 .33262 .50088 Mtetra
.67 .756 .915 r
.33262 .50088 .34204 .50979 .35712 .50442 .34776 .49546 Mtetra
.658 .753 .92 r
.34776 .49546 .35712 .50442 .37227 .49955 .36296 .49047 Mtetra
.642 .747 .925 r
.36296 .49047 .37227 .49955 .38747 .49521 .37822 .48602 Mtetra
.646 .747 .922 r
.37822 .48602 .38747 .49521 .40279 .49043 .39358 .4814 Mtetra
.673 .759 .916 r
.39358 .4814 .40279 .49043 .41821 .48498 .40907 .47573 Mtetra
.606 .734 .936 r
.40907 .47573 .41821 .48498 .43364 .48241 .42456 .47241 Mtetra
.395 .624 .945 r
.42456 .47241 .43364 .48241 .44903 .4861 .44003 .47441 Mtetra
.269 .516 .905 r
.44003 .47441 .44903 .4861 .46457 .49157 .45559 .4797 Mtetra
.448 .61 .917 r
.45559 .4797 .46457 .49157 .48037 .49143 .47139 .48133 Mtetra
.688 .748 .897 r
.47139 .48133 .48037 .49143 .49641 .47973 .48745 .47474 Mtetra
.76 .885 .935 r
.48745 .47474 .49641 .47973 .51248 .46678 .5036 .46514 Mtetra
.518 .896 .962 r
.5036 .46514 .51248 .46678 .52858 .46164 .5198 .45996 Mtetra
.188 .709 .874 r
.5198 .45996 .52858 .46164 .54483 .46435 .53612 .45921 Mtetra
.558 .835 .997 r
.53612 .45921 .54483 .46435 .56123 .46585 .55255 .45545 Mtetra
.776 .772 .849 r
.55255 .45545 .56123 .46585 .57761 .45569 .56898 .44341 Mtetra
.803 .747 .8 r
.56898 .44341 .57761 .45569 .59392 .43984 .58537 .42762 Mtetra
.77 .741 .827 r
.58537 .42762 .59392 .43984 .61027 .42573 .60183 .41511 Mtetra
.694 .749 .893 r
.60183 .41511 .61027 .42573 .62682 .41796 .61847 .40798 Mtetra
.639 .744 .925 r
.61847 .40798 .62682 .41796 .64356 .4131 .63528 .40322 Mtetra
.665 .757 .919 r
.63528 .40322 .64356 .4131 .66037 .40755 .65216 .3974 Mtetra
.668 .754 .915 r
.65216 .3974 .66037 .40755 .67727 .40154 .66912 .3914 Mtetra
.654 .75 .92 r
.66912 .3914 .67727 .40154 .69429 .39608 .68622 .38595 Mtetra
.642 .747 .925 r
.68622 .38595 .69429 .39608 .71144 .39113 .70344 .38093 Mtetra
.66 .754 .919 r
.70344 .38093 .71144 .39113 .72866 .38548 .72073 .37514 Mtetra
.663 .754 .917 r
.72073 .37514 .72866 .38548 .74597 .37959 .73812 .36921 Mtetra
.655 .751 .92 r
.73812 .36921 .74597 .37959 .76341 .37398 .75563 .36357 Mtetra
.647 .748 .923 r
.75563 .36357 .76341 .37398 .78098 .3687 .77328 .35822 Mtetra
.658 .753 .92 r
.77328 .35822 .78098 .3687 .79863 .36295 .791 .35238 Mtetra
.661 .753 .919 r
.791 .35238 .79863 .36295 .81637 .35703 .80882 .3464 Mtetra
.656 .751 .92 r
.80882 .3464 .81637 .35703 .83424 .35127 .82677 .34059 Mtetra
.65 .749 .922 r
.82677 .34059 .83424 .35127 .85224 .34574 .84485 .33499 Mtetra
.661 .753 .918 r
.20484 .53018 .21475 .53883 .22922 .53393 .21936 .52525 Mtetra
.657 .752 .92 r
.21936 .52525 .22922 .53393 .24375 .52922 .23393 .52046 Mtetra
.65 .75 .922 r
.23393 .52046 .24375 .52922 .25834 .5247 .24857 .51588 Mtetra
.652 .75 .921 r
.24857 .51588 .25834 .5247 .27302 .52005 .2633 .51121 Mtetra
.664 .754 .917 r
.2633 .51121 .27302 .52005 .28782 .51493 .27815 .50608 Mtetra
.658 .753 .92 r
.27815 .50608 .28782 .51493 .30268 .5101 .29306 .50113 Mtetra
.649 .749 .923 r
.29306 .50113 .30268 .5101 .3176 .50556 .30804 .4965 Mtetra
.648 .748 .922 r
.30804 .4965 .3176 .50556 .33262 .50088 .3231 .49187 Mtetra
.668 .755 .916 r
.3231 .49187 .33262 .50088 .34776 .49546 .33829 .48646 Mtetra
.661 .755 .92 r
.33829 .48646 .34776 .49546 .36296 .49047 .35355 .48128 Mtetra
.646 .748 .923 r
.35355 .48128 .36296 .49047 .37822 .48602 .36887 .47665 Mtetra
.639 .743 .924 r
.36887 .47665 .37822 .48602 .39358 .4814 .38427 .47223 Mtetra
.673 .758 .915 r
.38427 .47223 .39358 .4814 .40907 .47573 .39982 .46651 Mtetra
.639 .748 .928 r
.39982 .46651 .40907 .47573 .42456 .47241 .41541 .46204 Mtetra
.535 .684 .934 r
.41541 .46204 .42456 .47241 .44003 .47441 .43099 .46091 Mtetra
.375 .539 .89 r
.43099 .46091 .44003 .47441 .45559 .4797 .44659 .46487 Mtetra
.44 .551 .872 r
.44659 .46487 .45559 .4797 .47139 .48133 .46238 .46768 Mtetra
.55 .629 .882 r
.46238 .46768 .47139 .48133 .48745 .47474 .4784 .46669 Mtetra
.627 .781 .955 r
.4784 .46669 .48745 .47474 .5036 .46514 .49459 .46224 Mtetra
.568 .893 .986 r
.49459 .46224 .5036 .46514 .5198 .45996 .51089 .45701 Mtetra
.606 .906 .984 r
.51089 .45701 .5198 .45996 .53612 .45921 .52728 .451 Mtetra
.749 .812 .903 r
.52728 .451 .53612 .45921 .55255 .45545 .54375 .4415 Mtetra
.767 .714 .803 r
.54375 .4415 .55255 .45545 .56898 .44341 .56023 .42812 Mtetra
.77 .7 .785 r
.56023 .42812 .56898 .44341 .58537 .42762 .5767 .41356 Mtetra
.718 .698 .83 r
.5767 .41356 .58537 .42762 .60183 .41511 .59329 .4041 Mtetra
.67 .735 .899 r
.59329 .4041 .60183 .41511 .61847 .40798 .61003 .39801 Mtetra
.638 .747 .927 r
.61003 .39801 .61847 .40798 .63528 .40322 .62691 .39321 Mtetra
.671 .759 .917 r
.62691 .39321 .63528 .40322 .65216 .3974 .64384 .38706 Mtetra
.665 .751 .914 r
.64384 .38706 .65216 .3974 .66912 .3914 .66089 .38113 Mtetra
.65 .749 .921 r
.66089 .38113 .66912 .3914 .68622 .38595 .67806 .37575 Mtetra
.644 .749 .926 r
.67806 .37575 .68622 .38595 .70344 .38093 .69535 .3706 Mtetra
.663 .755 .919 r
.69535 .3706 .70344 .38093 .72073 .37514 .71271 .36466 Mtetra
.662 .753 .917 r
.71271 .36466 .72073 .37514 .73812 .36921 .73017 .3587 Mtetra
.653 .75 .921 r
.73017 .3587 .73812 .36921 .75563 .36357 .74776 .35306 Mtetra
.648 .749 .923 r
.74776 .35306 .75563 .36357 .77328 .35822 .76548 .34761 Mtetra
.659 .753 .919 r
.76548 .34761 .77328 .35822 .791 .35238 .78328 .34167 Mtetra
.661 .753 .918 r
.78328 .34167 .791 .35238 .80882 .3464 .80118 .33563 Mtetra
.655 .751 .92 r
.80118 .33563 .80882 .3464 .82677 .34059 .81921 .3298 Mtetra
.651 .75 .922 r
.81921 .3298 .82677 .34059 .84485 .33499 .83737 .32411 Mtetra
.66 .753 .918 r
.19483 .52145 .20484 .53018 .21936 .52525 .20939 .51651 Mtetra
.659 .753 .92 r
.20939 .51651 .21936 .52525 .23393 .52046 .22402 .5116 Mtetra
.651 .75 .922 r
.22402 .5116 .23393 .52046 .24857 .51588 .23871 .50695 Mtetra
.651 .749 .921 r
.23871 .50695 .24857 .51588 .2633 .51121 .25348 .50227 Mtetra
.662 .753 .918 r
.25348 .50227 .2633 .51121 .27815 .50608 .26837 .49717 Mtetra
.661 .754 .919 r
.26837 .49717 .27815 .50608 .29306 .50113 .28335 .49206 Mtetra
.651 .749 .922 r
.28335 .49206 .29306 .50113 .30804 .4965 .29838 .48732 Mtetra
.647 .747 .922 r
.29838 .48732 .30804 .4965 .3231 .49187 .31348 .48268 Mtetra
.663 .752 .917 r
.31348 .48268 .3231 .49187 .33829 .48646 .32872 .47742 Mtetra
.666 .758 .919 r
.32872 .47742 .33829 .48646 .35355 .48128 .34404 .47202 Mtetra
.651 .75 .922 r
.34404 .47202 .35355 .48128 .36887 .47665 .35943 .46714 Mtetra
.639 .742 .923 r
.35943 .46714 .36887 .47665 .38427 .47223 .37488 .46268 Mtetra
.66 .748 .916 r
.37488 .46268 .38427 .47223 .39982 .46651 .39046 .45743 Mtetra
.666 .762 .922 r
.39046 .45743 .39982 .46651 .41541 .46204 .40614 .45191 Mtetra
.61 .721 .924 r
.40614 .45191 .41541 .46204 .43099 .46091 .42184 .44842 Mtetra
.52 .635 .904 r
.42184 .44842 .43099 .46091 .44659 .46487 .43757 .44814 Mtetra
.481 .545 .845 r
.43757 .44814 .44659 .46487 .46238 .46768 .45338 .45011 Mtetra
.532 .562 .831 r
.45338 .45011 .46238 .46768 .4784 .46669 .46939 .4503 Mtetra
.594 .61 .837 r
.46939 .4503 .4784 .46669 .49459 .46224 .48559 .44761 Mtetra
.648 .66 .848 r
.48559 .44761 .49459 .46224 .51089 .45701 .50192 .44231 Mtetra
.692 .678 .832 r
.50192 .44231 .51089 .45701 .52728 .451 .51836 .4344 Mtetra
.722 .667 .795 r
.51836 .4344 .52728 .451 .54375 .4415 .53486 .42358 Mtetra
.734 .658 .775 r
.53486 .42358 .54375 .4415 .56023 .42812 .55139 .41093 Mtetra
.713 .658 .793 r
.55139 .41093 .56023 .42812 .5767 .41356 .56798 .40051 Mtetra
.686 .704 .861 r
.56798 .40051 .5767 .41356 .59329 .4041 .58467 .39332 Mtetra
.647 .733 .912 r
.58467 .39332 .59329 .4041 .61003 .39801 .6015 .38819 Mtetra
.652 .757 .927 r
.6015 .38819 .61003 .39801 .62691 .39321 .61843 .38278 Mtetra
.671 .752 .912 r
.61843 .38278 .62691 .39321 .64384 .38706 .63544 .37656 Mtetra
.66 .748 .915 r
.63544 .37656 .64384 .38706 .66089 .38113 .65256 .37077 Mtetra
.646 .747 .923 r
.65256 .37077 .66089 .38113 .67806 .37575 .66981 .3655 Mtetra
.649 .752 .925 r
.66981 .3655 .67806 .37575 .69535 .3706 .68716 .36009 Mtetra
.664 .754 .917 r
.68716 .36009 .69535 .3706 .71271 .36466 .70459 .35402 Mtetra
.661 .751 .917 r
.70459 .35402 .71271 .36466 .73017 .3587 .72213 .34806 Mtetra
.651 .749 .921 r
.72213 .34806 .73017 .3587 .74776 .35306 .73981 .34247 Mtetra
.65 .751 .923 r
.73981 .34247 .74776 .35306 .76548 .34761 .7576 .33687 Mtetra
.66 .753 .919 r
.7576 .33687 .76548 .34761 .78328 .34167 .77547 .33083 Mtetra
.66 .752 .918 r
.77547 .33083 .78328 .34167 .80118 .33563 .79345 .32473 Mtetra
.653 .75 .921 r
.79345 .32473 .80118 .33563 .81921 .3298 .81157 .3189 Mtetra
.651 .75 .922 r
.81157 .3189 .81921 .3298 .83737 .32411 .82981 .3131 Mtetra
.659 .752 .919 r
.18471 .51261 .19483 .52145 .20939 .51651 .19931 .50768 Mtetra
.661 .754 .919 r
.19931 .50768 .20939 .51651 .22402 .5116 .214 .50265 Mtetra
.652 .75 .922 r
.214 .50265 .22402 .5116 .23871 .50695 .22874 .49792 Mtetra
.651 .749 .922 r
.22874 .49792 .23871 .50695 .25348 .50227 .24356 .49321 Mtetra
.658 .751 .919 r
.24356 .49321 .25348 .50227 .26837 .49717 .25849 .48818 Mtetra
.664 .756 .919 r
.25849 .48818 .26837 .49717 .28335 .49206 .27353 .48292 Mtetra
.652 .75 .921 r
.27353 .48292 .28335 .49206 .29838 .48732 .28861 .47805 Mtetra
.647 .747 .922 r
.28861 .47805 .29838 .48732 .31348 .48268 .30377 .47335 Mtetra
.655 .749 .919 r
.30377 .47335 .31348 .48268 .32872 .47742 .31904 .46832 Mtetra
.669 .759 .918 r
.31904 .46832 .32872 .47742 .34404 .47202 .33443 .46275 Mtetra
.657 .753 .921 r
.33443 .46275 .34404 .47202 .35943 .46714 .34988 .45761 Mtetra
.645 .745 .922 r
.34988 .45761 .35943 .46714 .37488 .46268 .36539 .45289 Mtetra
.642 .74 .92 r
.36539 .45289 .37488 .46268 .39046 .45743 .381 .44826 Mtetra
.671 .763 .92 r
.381 .44826 .39046 .45743 .40614 .45191 .39675 .44248 Mtetra
.656 .755 .923 r
.39675 .44248 .40614 .45191 .42184 .44842 .41256 .43724 Mtetra
.616 .705 .908 r
.41256 .43724 .42184 .44842 .43757 .44814 .42842 .43354 Mtetra
.584 .63 .864 r
.42842 .43354 .43757 .44814 .45338 .45011 .44436 .43125 Mtetra
.563 .564 .813 r
.44436 .43125 .45338 .45011 .46939 .4503 .46039 .43008 Mtetra
.595 .568 .794 r
.46039 .43008 .46939 .4503 .48559 .44761 .47659 .42717 Mtetra
.633 .586 .784 r
.47659 .42717 .48559 .44761 .50192 .44231 .49294 .4218 Mtetra
.666 .603 .775 r
.49294 .4218 .50192 .44231 .51836 .4344 .50939 .41397 Mtetra
.688 .615 .769 r
.50939 .41397 .51836 .4344 .53486 .42358 .52592 .40437 Mtetra
.68 .623 .785 r
.52592 .40437 .53486 .42358 .55139 .41093 .54251 .39587 Mtetra
.676 .67 .837 r
.54251 .39587 .55139 .41093 .56798 .40051 .55919 .38878 Mtetra
.655 .719 .895 r
.55919 .38878 .56798 .40051 .58467 .39332 .57598 .38325 Mtetra
.64 .749 .928 r
.57598 .38325 .58467 .39332 .6015 .38819 .59288 .37826 Mtetra
.669 .764 .921 r
.59288 .37826 .6015 .38819 .61843 .38278 .60986 .3721 Mtetra
.666 .748 .911 r
.60986 .3721 .61843 .38278 .63544 .37656 .62694 .36603 Mtetra
.655 .748 .918 r
.62694 .36603 .63544 .37656 .65256 .37077 .64414 .36038 Mtetra
.643 .748 .925 r
.64414 .36038 .65256 .37077 .66981 .3655 .66146 .35517 Mtetra
.656 .756 .923 r
.66146 .35517 .66981 .3655 .68716 .36009 .67888 .3494 Mtetra
.664 .752 .916 r
.67888 .3494 .68716 .36009 .70459 .35402 .69638 .34328 Mtetra
.659 .751 .918 r
.69638 .34328 .70459 .35402 .72213 .34806 .714 .33732 Mtetra
.648 .748 .922 r
.714 .33732 .72213 .34806 .73981 .34247 .73176 .33177 Mtetra
.653 .753 .923 r
.73176 .33177 .73981 .34247 .7576 .33687 .74962 .32598 Mtetra
.66 .753 .918 r
.74962 .32598 .7576 .33687 .77547 .33083 .76757 .31984 Mtetra
.66 .752 .918 r
.76757 .31984 .77547 .33083 .79345 .32473 .78563 .31371 Mtetra
.651 .749 .921 r
.78563 .31371 .79345 .32473 .81157 .3189 .80384 .30789 Mtetra
.653 .751 .922 r
.80384 .30789 .81157 .3189 .82981 .3131 .82215 .30196 Mtetra
.657 .751 .92 r
.17449 .50368 .18471 .51261 .19931 .50768 .18913 .49877 Mtetra
.662 .754 .919 r
.18913 .49877 .19931 .50768 .214 .50265 .20387 .49364 Mtetra
.654 .751 .921 r
.20387 .49364 .214 .50265 .22874 .49792 .21867 .48879 Mtetra
.65 .749 .921 r
.21867 .48879 .22874 .49792 .24356 .49321 .23354 .48403 Mtetra
.654 .75 .92 r
.23354 .48403 .24356 .49321 .25849 .48818 .24851 .47911 Mtetra
.664 .756 .918 r
.24851 .47911 .25849 .48818 .27353 .48292 .26359 .47377 Mtetra
.657 .754 .921 r
.26359 .47377 .27353 .48292 .28861 .47805 .27874 .46869 Mtetra
.649 .748 .922 r
.27874 .46869 .28861 .47805 .30377 .47335 .29396 .46386 Mtetra
.649 .746 .921 r
.29396 .46386 .30377 .47335 .31904 .46832 .30926 .45903 Mtetra
.665 .756 .918 r
.30926 .45903 .31904 .46832 .33443 .46275 .3247 .45355 Mtetra
.664 .759 .921 r
.3247 .45355 .33443 .46275 .34988 .45761 .34022 .44806 Mtetra
.652 .749 .921 r
.34022 .44806 .34988 .45761 .36539 .45289 .35581 .443 Mtetra
.643 .74 .92 r
.35581 .443 .36539 .45289 .381 .44826 .37147 .43828 Mtetra
.646 .74 .918 r
.37147 .43828 .381 .44826 .39675 .44248 .38723 .43341 Mtetra
.671 .769 .924 r
.38723 .43341 .39675 .44248 .41256 .43724 .40313 .42752 Mtetra
.659 .753 .919 r
.40313 .42752 .41256 .43724 .42842 .43354 .4191 .42207 Mtetra
.639 .71 .899 r
.4191 .42207 .42842 .43354 .44436 .43125 .43514 .41739 Mtetra
.629 .665 .866 r
.43514 .41739 .44436 .43125 .46039 .43008 .45128 .41304 Mtetra
.629 .621 .823 r
.45128 .41304 .46039 .43008 .47659 .42717 .46753 .40838 Mtetra
.638 .606 .801 r
.46753 .40838 .47659 .42717 .49294 .4218 .48389 .40294 Mtetra
.649 .612 .798 r
.48389 .40294 .49294 .4218 .50939 .41397 .50036 .39672 Mtetra
.659 .635 .814 r
.50036 .39672 .50939 .41397 .52592 .40437 .51692 .39018 Mtetra
.664 .679 .855 r
.51692 .39018 .52592 .40437 .54251 .39587 .53357 .38396 Mtetra
.652 .715 .894 r
.53357 .38396 .54251 .39587 .55919 .38878 .55032 .37853 Mtetra
.64 .746 .926 r
.55032 .37853 .55919 .38878 .57598 .38325 .56718 .37353 Mtetra
.665 .768 .927 r
.56718 .37353 .57598 .38325 .59288 .37826 .58414 .3675 Mtetra
.668 .748 .91 r
.58414 .3675 .59288 .37826 .60986 .3721 .60119 .36131 Mtetra
.659 .745 .914 r
.60119 .36131 .60986 .3721 .62694 .36603 .61835 .35546 Mtetra
.647 .747 .922 r
.61835 .35546 .62694 .36603 .64414 .36038 .63563 .35005 Mtetra
.647 .754 .927 r
.63563 .35005 .64414 .36038 .66146 .35517 .65302 .34463 Mtetra
.662 .756 .92 r
.65302 .34463 .66146 .35517 .67888 .3494 .6705 .33853 Mtetra
.662 .75 .916 r
.6705 .33853 .67888 .3494 .69638 .34328 .68808 .33241 Mtetra
.655 .749 .919 r
.68808 .33241 .69638 .34328 .714 .33732 .70579 .32656 Mtetra
.647 .75 .924 r
.70579 .32656 .714 .33732 .73176 .33177 .72362 .32096 Mtetra
.657 .754 .922 r
.72362 .32096 .73176 .33177 .74962 .32598 .74155 .31493 Mtetra
.661 .752 .918 r
.74155 .31493 .74962 .32598 .76757 .31984 .75958 .30872 Mtetra
.658 .751 .919 r
.75958 .30872 .76757 .31984 .78563 .31371 .77773 .3026 Mtetra
.65 .749 .922 r
.77773 .3026 .78563 .31371 .80384 .30789 .79602 .29676 Mtetra
.655 .752 .922 r
.79602 .29676 .80384 .30789 .82215 .30196 .81441 .29067 Mtetra
.655 .751 .92 r
.16416 .49463 .17449 .50368 .18913 .49877 .17884 .48975 Mtetra
.661 .754 .919 r
.17884 .48975 .18913 .49877 .20387 .49364 .19363 .48459 Mtetra
.657 .753 .921 r
.19363 .48459 .20387 .49364 .21867 .48879 .20849 .47956 Mtetra
.651 .749 .921 r
.20849 .47956 .21867 .48879 .23354 .48403 .22341 .47473 Mtetra
.652 .749 .921 r
.22341 .47473 .23354 .48403 .24851 .47911 .23842 .46985 Mtetra
.661 .753 .918 r
.23842 .46985 .24851 .47911 .26359 .47377 .25355 .46458 Mtetra
.662 .756 .92 r
.25355 .46458 .26359 .47377 .27874 .46869 .26876 .45926 Mtetra
.652 .749 .921 r
.26876 .45926 .27874 .46869 .29396 .46386 .28404 .45427 Mtetra
.648 .746 .921 r
.28404 .45427 .29396 .46386 .30926 .45903 .2994 .44942 Mtetra
.654 .748 .919 r
.2994 .44942 .30926 .45903 .3247 .45355 .31486 .44429 Mtetra
.667 .761 .92 r
.31486 .44429 .3247 .45355 .34022 .44806 .33045 .43863 Mtetra
.66 .757 .921 r
.33045 .43863 .34022 .44806 .35581 .443 .34611 .43321 Mtetra
.651 .747 .92 r
.34611 .43321 .35581 .443 .37147 .43828 .36184 .4281 Mtetra
.644 .738 .917 r
.36184 .4281 .37147 .43828 .38723 .43341 .37765 .42325 Mtetra
.646 .74 .918 r
.37765 .42325 .38723 .43341 .40313 .42752 .39357 .41827 Mtetra
.665 .767 .926 r
.39357 .41827 .40313 .42752 .4191 .42207 .40961 .41255 Mtetra
.664 .762 .923 r
.40961 .41255 .4191 .42207 .43514 .41739 .42574 .40682 Mtetra
.658 .739 .91 r
.42574 .40682 .43514 .41739 .45128 .41304 .44197 .40129 Mtetra
.654 .715 .893 r
.44197 .40129 .45128 .41304 .46753 .40838 .45828 .39586 Mtetra
.654 .702 .882 r
.45828 .39586 .46753 .40838 .48389 .40294 .47469 .39035 Mtetra
.47469 .39035 .48389 .40294 .50036 .39672 .49121 .38478 Mtetra
.653 .715 .894 r
.49121 .38478 .50036 .39672 .51692 .39018 .50782 .37929 Mtetra
.648 .735 .913 r
.50782 .37929 .51692 .39018 .53357 .38396 .52454 .37403 Mtetra
.646 .757 .93 r
.52454 .37403 .53357 .38396 .55032 .37853 .54136 .36874 Mtetra
.665 .768 .927 r
.54136 .36874 .55032 .37853 .56718 .37353 .55828 .3627 Mtetra
.667 .747 .91 r
.55828 .3627 .56718 .37353 .58414 .3675 .5753 .35652 Mtetra
.66 .743 .911 r
.5753 .35652 .58414 .3675 .60119 .36131 .59243 .3506 Mtetra
.652 .747 .92 r
.59243 .3506 .60119 .36131 .61835 .35546 .60966 .345 Mtetra
.644 .751 .927 r
.60966 .345 .61835 .35546 .63563 .35005 .62702 .33964 Mtetra
.657 .758 .924 r
.62702 .33964 .63563 .35005 .65302 .34463 .64447 .33372 Mtetra
.663 .752 .916 r
.64447 .33372 .65302 .34463 .6705 .33853 .66202 .32752 Mtetra
.659 .749 .917 r
.66202 .32752 .6705 .33853 .68808 .33241 .67968 .32146 Mtetra
.65 .748 .921 r
.67968 .32146 .68808 .33241 .70579 .32656 .69748 .31573 Mtetra
.651 .753 .924 r
.69748 .31573 .70579 .32656 .72362 .32096 .71538 .30994 Mtetra
.66 .753 .919 r
.71538 .30994 .72362 .32096 .74155 .31493 .73338 .30374 Mtetra
.66 .752 .918 r
.73338 .30374 .74155 .31493 .75958 .30872 .75149 .29747 Mtetra
.654 .75 .92 r
.75149 .29747 .75958 .30872 .77773 .3026 .76973 .29141 Mtetra
.651 .751 .923 r
.76973 .29141 .77773 .3026 .79602 .29676 .7881 .28548 Mtetra
.657 .753 .921 r
.7881 .28548 .79602 .29676 .81441 .29067 .80657 .27924 Mtetra
.653 .75 .921 r
.15373 .48548 .16416 .49463 .17884 .48975 .16845 .48059 Mtetra
.659 .752 .919 r
.16845 .48059 .17884 .48975 .19363 .48459 .18328 .47547 Mtetra
.661 .755 .92 r
.18328 .47547 .19363 .48459 .20849 .47956 .1982 .47025 Mtetra
.652 .75 .921 r
.1982 .47025 .20849 .47956 .22341 .47473 .21317 .46532 Mtetra
.651 .748 .921 r
.21317 .46532 .22341 .47473 .23842 .46985 .22823 .46041 Mtetra
.655 .75 .92 r
.22823 .46041 .23842 .46985 .25355 .46458 .24339 .45531 Mtetra
.664 .757 .919 r
.24339 .45531 .25355 .46458 .26876 .45926 .25867 .44985 Mtetra
.657 .754 .921 r
.25867 .44985 .26876 .45926 .28404 .45427 .27401 .44462 Mtetra
.65 .748 .921 r
.27401 .44462 .28404 .45427 .2994 .44942 .28943 .43961 Mtetra
.648 .745 .92 r
.28943 .43961 .2994 .44942 .31486 .44429 .30493 .43465 Mtetra
.658 .752 .919 r
.30493 .43465 .31486 .44429 .33045 .43863 .32055 .42928 Mtetra
.666 .762 .922 r
.32055 .42928 .33045 .43863 .34611 .43321 .33629 .42356 Mtetra
.659 .755 .921 r
.33629 .42356 .34611 .43321 .36184 .4281 .35209 .4181 Mtetra
.652 .747 .919 r
.35209 .4181 .36184 .4281 .37765 .42325 .36798 .41286 Mtetra
.647 .738 .915 r
.36798 .41286 .37765 .42325 .39357 .41827 .38395 .40779 Mtetra
.647 .737 .915 r
.38395 .40779 .39357 .41827 .40961 .41255 .40002 .4027 Mtetra
.65 .753 .925 r
.40002 .4027 .40961 .41255 .42574 .40682 .4162 .39743 Mtetra
.658 .767 .93 r
.4162 .39743 .42574 .40682 .44197 .40129 .43249 .39184 Mtetra
.659 .767 .93 r
.43249 .39184 .44197 .40129 .45828 .39586 .44887 .38618 Mtetra
.655 .763 .929 r
.44887 .38618 .45828 .39586 .47469 .39035 .46535 .38062 Mtetra
.652 .762 .93 r
.46535 .38062 .47469 .39035 .49121 .38478 .48193 .37515 Mtetra
.653 .765 .932 r
.48193 .37515 .49121 .38478 .50782 .37929 .49861 .36961 Mtetra
.661 .768 .929 r
.49861 .36961 .50782 .37929 .52454 .37403 .5154 .36374 Mtetra
.664 .758 .92 r
.5154 .36374 .52454 .37403 .54136 .36874 .53229 .35769 Mtetra
.664 .743 .909 r
.53229 .35769 .54136 .36874 .55828 .3627 .54927 .35162 Mtetra
.659 .742 .911 r
.54927 .35162 .55828 .3627 .5753 .35652 .56637 .34571 Mtetra
.653 .747 .919 r
.56637 .34571 .5753 .35652 .59243 .3506 .58357 .34003 Mtetra
.645 .75 .926 r
.58357 .34003 .59243 .3506 .60966 .345 .60088 .3346 Mtetra
.653 .758 .927 r
.60088 .3346 .60966 .345 .62702 .33964 .61831 .32882 Mtetra
.663 .754 .918 r
.61831 .32882 .62702 .33964 .64447 .33372 .63582 .32261 Mtetra
.661 .749 .915 r
.63582 .32261 .64447 .33372 .66202 .32752 .65345 .31645 Mtetra
.655 .749 .919 r
.65345 .31645 .66202 .32752 .67968 .32146 .6712 .3105 Mtetra
.648 .75 .924 r
.6712 .3105 .67968 .32146 .69748 .31573 .68907 .30479 Mtetra
.656 .755 .923 r
.68907 .30479 .69748 .31573 .71538 .30994 .70704 .2987 Mtetra
.66 .752 .918 r
.70704 .2987 .71538 .30994 .73338 .30374 .72512 .2924 Mtetra
.659 .751 .918 r
.72512 .2924 .73338 .30374 .75149 .29747 .74331 .28611 Mtetra
.651 .749 .921 r
.74331 .28611 .75149 .29747 .76973 .29141 .76164 .28012 Mtetra
.653 .752 .923 r
.76164 .28012 .76973 .29141 .7881 .28548 .78009 .27402 Mtetra
.658 .752 .92 r
.78009 .27402 .7881 .28548 .80657 .27924 .79864 .26766 Mtetra
.652 .749 .921 r
.14318 .4762 .15373 .48548 .16845 .48059 .15795 .47131 Mtetra
.656 .751 .92 r
.15795 .47131 .16845 .48059 .18328 .47547 .17281 .46626 Mtetra
.662 .755 .919 r
.17281 .46626 .18328 .47547 .1982 .47025 .18779 .46095 Mtetra
.656 .753 .921 r
.18779 .46095 .1982 .47025 .21317 .46532 .20283 .45581 Mtetra
.651 .748 .921 r
.20283 .45581 .21317 .46532 .22823 .46041 .21794 .45084 Mtetra
.652 .748 .92 r
.21794 .45084 .22823 .46041 .24339 .45531 .23314 .44581 Mtetra
.66 .753 .919 r
.23314 .44581 .24339 .45531 .25867 .44985 .24846 .44046 Mtetra
.663 .758 .92 r
.24846 .44046 .25867 .44985 .27401 .44462 .26387 .43494 Mtetra
.654 .75 .92 r
.26387 .43494 .27401 .44462 .28943 .43961 .27935 .42974 Mtetra
.65 .746 .92 r
.27935 .42974 .28943 .43961 .30493 .43465 .29491 .42467 Mtetra
.649 .745 .919 r
.29491 .42467 .30493 .43465 .32055 .42928 .31057 .41958 Mtetra
.659 .755 .921 r
.31057 .41958 .32055 .42928 .33629 .42356 .32634 .41409 Mtetra
.665 .763 .923 r
.32634 .41409 .33629 .42356 .35209 .4181 .34222 .40834 Mtetra
.66 .756 .921 r
.34222 .40834 .35209 .4181 .36798 .41286 .35818 .40273 Mtetra
.655 .748 .919 r
.35818 .40273 .36798 .41286 .38395 .40779 .37422 .39732 Mtetra
.653 .741 .915 r
.37422 .39732 .38395 .40779 .40002 .4027 .39036 .39195 Mtetra
.65 .736 .912 r
.39036 .39195 .40002 .4027 .4162 .39743 .4066 .38663 Mtetra
.651 .737 .912 r
.4066 .38663 .4162 .39743 .43249 .39184 .42293 .38124 Mtetra
.654 .743 .915 r
.42293 .38124 .43249 .39184 .44887 .38618 .43937 .37574 Mtetra
.656 .748 .918 r
.43937 .37574 .44887 .38618 .46535 .38062 .45592 .37011 Mtetra
.658 .749 .917 r
.45592 .37011 .46535 .38062 .48193 .37515 .47256 .36436 Mtetra
.66 .745 .913 r
.47256 .36436 .48193 .37515 .49861 .36961 .48931 .35849 Mtetra
.661 .74 .909 r
.48931 .35849 .49861 .36961 .5154 .36374 .50616 .35254 Mtetra
.659 .739 .909 r
.50616 .35254 .5154 .36374 .53229 .35769 .52312 .34665 Mtetra
.657 .743 .913 r
.52312 .34665 .53229 .35769 .54927 .35162 .54017 .34079 Mtetra
.651 .747 .92 r
.54017 .34079 .54927 .35162 .56637 .34571 .55734 .33513 Mtetra
.646 .752 .926 r
.55734 .33513 .56637 .34571 .58357 .34003 .57461 .32963 Mtetra
.652 .759 .928 r
.57461 .32963 .58357 .34003 .60088 .3346 .592 .32383 Mtetra
.662 .756 .92 r
.592 .32383 .60088 .3346 .61831 .32882 .60948 .31764 Mtetra
.661 .749 .915 r
.60948 .31764 .61831 .32882 .63582 .32261 .62707 .31142 Mtetra
.658 .749 .917 r
.62707 .31142 .63582 .32261 .65345 .31645 .64478 .30532 Mtetra
.649 .748 .922 r
.64478 .30532 .65345 .31645 .6712 .3105 .66261 .29954 Mtetra
.652 .754 .925 r
.66261 .29954 .6712 .3105 .68907 .30479 .68056 .29359 Mtetra
.659 .754 .92 r
.68056 .29359 .68907 .30479 .70704 .2987 .6986 .28729 Mtetra
.66 .751 .917 r
.6986 .28729 .70704 .2987 .72512 .2924 .71676 .28093 Mtetra
.655 .749 .919 r
.71676 .28093 .72512 .2924 .74331 .28611 .73504 .27473 Mtetra
.65 .751 .923 r
.73504 .27473 .74331 .28611 .76164 .28012 .75346 .2687 Mtetra
.656 .754 .922 r
.75346 .2687 .76164 .28012 .78009 .27402 .77198 .26239 Mtetra
.659 .752 .919 r
.77198 .26239 .78009 .27402 .79864 .26766 .79061 .25591 Mtetra
.652 .749 .921 r
.13253 .46683 .14318 .4762 .15795 .47131 .14734 .4619 Mtetra
.654 .75 .92 r
.14734 .4619 .15795 .47131 .17281 .46626 .16224 .45686 Mtetra
.659 .753 .919 r
.16224 .45686 .17281 .46626 .18779 .46095 .17726 .4516 Mtetra
.661 .755 .92 r
.17726 .4516 .18779 .46095 .20283 .45581 .19237 .44624 Mtetra
.653 .75 .921 r
.19237 .44624 .20283 .45581 .21794 .45084 .20753 .44114 Mtetra
.651 .748 .92 r
.20753 .44114 .21794 .45084 .23314 .44581 .22278 .43609 Mtetra
.653 .749 .92 r
.22278 .43609 .23314 .44581 .24846 .44046 .23813 .43092 Mtetra
.662 .756 .92 r
.23813 .43092 .24846 .44046 .26387 .43494 .2536 .42539 Mtetra
.661 .757 .921 r
.2536 .42539 .26387 .43494 .27935 .42974 .26916 .41986 Mtetra
.653 .749 .92 r
.26916 .41986 .27935 .42974 .29491 .42467 .28478 .41459 Mtetra
.65 .745 .919 r
.28478 .41459 .29491 .42467 .31057 .41958 .30049 .40941 Mtetra
.65 .744 .919 r
.30049 .40941 .31057 .41958 .32634 .41409 .3163 .40421 Mtetra
.656 .754 .922 r
.3163 .40421 .32634 .41409 .34222 .40834 .33222 .39874 Mtetra
.663 .763 .924 r
.33222 .39874 .34222 .40834 .35818 .40273 .34824 .39296 Mtetra
.662 .761 .923 r
.34824 .39296 .35818 .40273 .37422 .39732 .36437 .38718 Mtetra
.658 .753 .92 r
.36437 .38718 .37422 .39732 .39036 .39195 .38057 .38154 Mtetra
.655 .748 .918 r
.38057 .38154 .39036 .39195 .4066 .38663 .39688 .37597 Mtetra
.655 .743 .915 r
.39688 .37597 .4066 .38663 .42293 .38124 .41328 .37038 Mtetra
.655 .74 .913 r
.41328 .37038 .42293 .38124 .43937 .37574 .42978 .36474 Mtetra
.656 .739 .911 r
.42978 .36474 .43937 .37574 .45592 .37011 .44639 .35905 Mtetra
.656 .74 .911 r
.44639 .35905 .45592 .37011 .47256 .36436 .46309 .3533 Mtetra
.657 .741 .912 r
.46309 .3533 .47256 .36436 .48931 .35849 .4799 .3475 Mtetra
.656 .744 .914 r
.4799 .3475 .48931 .35849 .50616 .35254 .49682 .34169 Mtetra
.654 .747 .918 r
.49682 .34169 .50616 .35254 .52312 .34665 .51384 .33593 Mtetra
.649 .75 .923 r
.51384 .33593 .52312 .34665 .54017 .34079 .53097 .33032 Mtetra
.648 .756 .928 r
.53097 .33032 .54017 .34079 .55734 .33513 .5482 .32471 Mtetra
.655 .761 .927 r
.5482 .32471 .55734 .33513 .57461 .32963 .56555 .31878 Mtetra
.661 .756 .92 r
.56555 .31878 .57461 .32963 .592 .32383 .583 .31257 Mtetra
.661 .748 .915 r
.583 .31257 .592 .32383 .60948 .31764 .60056 .30634 Mtetra
.658 .748 .916 r
.60056 .30634 .60948 .31764 .62707 .31142 .61823 .30019 Mtetra
.651 .748 .921 r
.61823 .30019 .62707 .31142 .64478 .30532 .63602 .2943 Mtetra
.65 .754 .925 r
.63602 .2943 .64478 .30532 .66261 .29954 .65393 .28841 Mtetra
.658 .756 .922 r
.65393 .28841 .66261 .29954 .68056 .29359 .67194 .28213 Mtetra
.66 .751 .918 r
.67194 .28213 .68056 .29359 .6986 .28729 .69006 .27573 Mtetra
.658 .75 .918 r
.69006 .27573 .6986 .28729 .71676 .28093 .7083 .26936 Mtetra
.651 .748 .921 r
.7083 .26936 .71676 .28093 .73504 .27473 .72668 .26326 Mtetra
.653 .753 .923 r
.72668 .26326 .73504 .27473 .75346 .2687 .74517 .25705 Mtetra
.658 .753 .92 r
.74517 .25705 .75346 .2687 .77198 .26239 .76377 .2506 Mtetra
.659 .752 .918 r
.76377 .2506 .77198 .26239 .79061 .25591 .78248 .24402 Mtetra
.653 .75 .921 r
.12176 .45738 .13253 .46683 .14734 .4619 .13662 .45235 Mtetra
.652 .749 .92 r
.13662 .45235 .14734 .4619 .16224 .45686 .15157 .44731 Mtetra
.655 .751 .92 r
.15157 .44731 .16224 .45686 .17726 .4516 .16662 .44214 Mtetra
.661 .755 .92 r
.16662 .44214 .17726 .4516 .19237 .44624 .18178 .43672 Mtetra
.658 .754 .921 r
.18178 .43672 .19237 .44624 .20753 .44114 .19701 .43137 Mtetra
.652 .748 .92 r
.19701 .43137 .20753 .44114 .22278 .43609 .21232 .42622 Mtetra
.651 .747 .92 r
.21232 .42622 .22278 .43609 .23813 .43092 .22771 .42106 Mtetra
.654 .75 .92 r
.22771 .42106 .23813 .43092 .2536 .42539 .24321 .41576 Mtetra
.662 .758 .921 r
.24321 .41576 .2536 .42539 .26916 .41986 .25883 .41012 Mtetra
.661 .757 .921 r
.25883 .41012 .26916 .41986 .28478 .41459 .27453 .40452 Mtetra
.654 .749 .92 r
.27453 .40452 .28478 .41459 .30049 .40941 .29031 .39915 Mtetra
.652 .745 .918 r
.29031 .39915 .30049 .40941 .3163 .40421 .30617 .39383 Mtetra
.65 .744 .918 r
.30617 .39383 .3163 .40421 .33222 .39874 .32213 .38852 Mtetra
.653 .749 .921 r
.32213 .38852 .33222 .39874 .34824 .39296 .3382 .3831 Mtetra
.658 .76 .925 r
.3382 .3831 .34824 .39296 .36437 .38718 .35437 .37741 Mtetra
.661 .764 .926 r
.35437 .37741 .36437 .38718 .38057 .38154 .37065 .37159 Mtetra
.66 .761 .925 r
.37065 .37159 .38057 .38154 .39688 .37597 .38702 .36578 Mtetra
.658 .757 .923 r
.38702 .36578 .39688 .37597 .41328 .37038 .40349 .35999 Mtetra
.657 .753 .921 r
.40349 .35999 .41328 .37038 .42978 .36474 .42006 .35421 Mtetra
.656 .752 .92 r
.42006 .35421 .42978 .36474 .44639 .35905 .43673 .34846 Mtetra
.655 .751 .921 r
.43673 .34846 .44639 .35905 .46309 .3533 .4535 .34271 Mtetra
.653 .752 .922 r
.4535 .34271 .46309 .3533 .4799 .3475 .47038 .33699 Mtetra
.652 .755 .925 r
.47038 .33699 .4799 .3475 .49682 .34169 .48736 .33128 Mtetra
.651 .758 .928 r
.48736 .33128 .49682 .34169 .51384 .33593 .50445 .32558 Mtetra
.653 .761 .929 r
.50445 .32558 .51384 .33593 .53097 .33032 .52165 .31975 Mtetra
.659 .76 .925 r
.52165 .31975 .53097 .33032 .5482 .32471 .53896 .31365 Mtetra
.661 .752 .918 r
.53896 .31365 .5482 .32471 .56555 .31878 .55637 .30742 Mtetra
.66 .747 .914 r
.55637 .30742 .56555 .31878 .583 .31257 .57389 .3012 Mtetra
.658 .747 .916 r
.57389 .3012 .583 .31257 .60056 .30634 .59153 .29503 Mtetra
.651 .748 .92 r
.59153 .29503 .60056 .30634 .61823 .30019 .60928 .28909 Mtetra
.649 .753 .925 r
.60928 .28909 .61823 .30019 .63602 .2943 .62715 .28318 Mtetra
.657 .757 .923 r
.62715 .28318 .63602 .2943 .65393 .28841 .64513 .27691 Mtetra
.66 .752 .918 r
.64513 .27691 .65393 .28841 .67194 .28213 .66322 .27049 Mtetra
.659 .75 .917 r
.66322 .27049 .67194 .28213 .69006 .27573 .68142 .26406 Mtetra
.654 .749 .919 r
.68142 .26406 .69006 .27573 .7083 .26936 .69975 .25782 Mtetra
.651 .752 .923 r
.69975 .25782 .7083 .26936 .72668 .26326 .71821 .25165 Mtetra
.656 .754 .922 r
.71821 .25165 .72668 .26326 .74517 .25705 .73678 .24521 Mtetra
.659 .752 .919 r
.73678 .24521 .74517 .25705 .76377 .2506 .75546 .23862 Mtetra
.658 .751 .918 r
.75546 .23862 .76377 .2506 .78248 .24402 .77426 .23201 Mtetra
.657 .753 .921 r
.11085 .44794 .12176 .45738 .13662 .45235 .12578 .44271 Mtetra
.652 .749 .921 r
.12578 .44271 .13662 .45235 .15157 .44731 .14078 .43762 Mtetra
.653 .749 .92 r
.14078 .43762 .15157 .44731 .16662 .44214 .15587 .43246 Mtetra
.657 .752 .92 r
.15587 .43246 .16662 .44214 .18178 .43672 .17107 .42713 Mtetra
.661 .756 .92 r
.17107 .42713 .18178 .43672 .19701 .43137 .18637 .42161 Mtetra
.656 .752 .921 r
.18637 .42161 .19701 .43137 .21232 .42622 .20174 .41625 Mtetra
.652 .748 .92 r
.20174 .41625 .21232 .42622 .22771 .42106 .21719 .41101 Mtetra
.652 .747 .92 r
.21719 .41101 .22771 .42106 .24321 .41576 .23273 .40575 Mtetra
.655 .75 .92 r
.23273 .40575 .24321 .41576 .25883 .41012 .24838 .40035 Mtetra
.662 .758 .922 r
.24838 .40035 .25883 .41012 .27453 .40452 .26414 .39464 Mtetra
.661 .757 .921 r
.26414 .39464 .27453 .40452 .29031 .39915 .28 .38892 Mtetra
.655 .75 .919 r
.28 .38892 .29031 .39915 .30617 .39383 .29593 .38341 Mtetra
.653 .746 .918 r
.29593 .38341 .30617 .39383 .32213 .38852 .31195 .37794 Mtetra
.652 .744 .917 r
.31195 .37794 .32213 .38852 .3382 .3831 .32807 .37249 Mtetra
.32807 .37249 .3382 .3831 .35437 .37741 .34429 .36699 Mtetra
.653 .75 .921 r
.34429 .36699 .35437 .37741 .37065 .37159 .36062 .3614 Mtetra
.655 .757 .925 r
.36062 .3614 .37065 .37159 .38702 .36578 .37705 .35573 Mtetra
.657 .762 .927 r
.37705 .35573 .38702 .36578 .40349 .35999 .39358 .34994 Mtetra
.657 .763 .928 r
.39358 .34994 .40349 .35999 .42006 .35421 .41021 .34411 Mtetra
.656 .763 .929 r
.41021 .34411 .42006 .35421 .43673 .34846 .42695 .33829 Mtetra
.655 .763 .929 r
.42695 .33829 .43673 .34846 .4535 .34271 .44379 .33247 Mtetra
.44379 .33247 .4535 .34271 .47038 .33699 .46074 .32661 Mtetra
.657 .762 .927 r
.46074 .32661 .47038 .33699 .48736 .33128 .47779 .32064 Mtetra
.658 .758 .924 r
.47779 .32064 .48736 .33128 .50445 .32558 .49496 .31457 Mtetra
.66 .752 .919 r
.49496 .31457 .50445 .32558 .52165 .31975 .51223 .30841 Mtetra
.66 .747 .915 r
.51223 .30841 .52165 .31975 .53896 .31365 .5296 .3022 Mtetra
.658 .746 .915 r
.5296 .3022 .53896 .31365 .55637 .30742 .54709 .29601 Mtetra
.657 .747 .917 r
.54709 .29601 .55637 .30742 .57389 .3012 .56469 .28985 Mtetra
.651 .748 .921 r
.56469 .28985 .57389 .3012 .59153 .29503 .5824 .28389 Mtetra
.65 .754 .925 r
.5824 .28389 .59153 .29503 .60928 .28909 .60023 .27793 Mtetra
.657 .757 .924 r
.60023 .27793 .60928 .28909 .62715 .28318 .61817 .27164 Mtetra
.659 .752 .918 r
.61817 .27164 .62715 .28318 .64513 .27691 .63622 .2652 Mtetra
.659 .75 .917 r
.63622 .2652 .64513 .27691 .66322 .27049 .65439 .25873 Mtetra
.655 .749 .919 r
.65439 .25873 .66322 .27049 .68142 .26406 .67268 .25238 Mtetra
.651 .75 .922 r
.67268 .25238 .68142 .26406 .69975 .25782 .6911 .24618 Mtetra
.655 .754 .923 r
.6911 .24618 .69975 .25782 .71821 .25165 .70964 .23978 Mtetra
.658 .752 .92 r
.70964 .23978 .71821 .25165 .73678 .24521 .72828 .23319 Mtetra
.659 .751 .918 r
.72828 .23319 .73678 .24521 .75546 .23862 .74705 .22651 Mtetra
.655 .749 .919 r
.74705 .22651 .75546 .23862 .77426 .23201 .76595 .21998 Mtetra
.66 .754 .92 r
.09983 .43842 .11085 .44794 .12578 .44271 .11482 .43303 Mtetra
.654 .751 .921 r
.11482 .43303 .12578 .44271 .14078 .43762 .12988 .4278 Mtetra
.652 .748 .92 r
.12988 .4278 .14078 .43762 .15587 .43246 .14501 .42262 Mtetra
.654 .75 .92 r
.14501 .42262 .15587 .43246 .17107 .42713 .16025 .41734 Mtetra
.658 .753 .92 r
.16025 .41734 .17107 .42713 .18637 .42161 .17559 .41187 Mtetra
.661 .756 .921 r
.17559 .41187 .18637 .42161 .20174 .41625 .19103 .40628 Mtetra
.655 .751 .92 r
.19103 .40628 .20174 .41625 .21719 .41101 .20655 .40086 Mtetra
.652 .748 .92 r
.20655 .40086 .21719 .41101 .23273 .40575 .22214 .39552 Mtetra
.652 .747 .919 r
.22214 .39552 .23273 .40575 .24838 .40035 .23784 .39015 Mtetra
.654 .75 .92 r
.23784 .39015 .24838 .40035 .26414 .39464 .25363 .38468 Mtetra
.66 .758 .922 r
.25363 .38468 .26414 .39464 .28 .38892 .26954 .37894 Mtetra
.661 .759 .923 r
.26954 .37894 .28 .38892 .29593 .38341 .28555 .37313 Mtetra
.658 .753 .92 r
.28555 .37313 .29593 .38341 .31195 .37794 .30165 .36741 Mtetra
.655 .748 .919 r
.30165 .36741 .31195 .37794 .32807 .37249 .31783 .36178 Mtetra
.654 .745 .917 r
.31783 .36178 .32807 .37249 .34429 .36699 .33412 .35614 Mtetra
.654 .744 .916 r
.33412 .35614 .34429 .36699 .36062 .3614 .3505 .35048 Mtetra
.653 .744 .916 r
.3505 .35048 .36062 .3614 .37705 .35573 .36699 .34479 Mtetra
.654 .745 .916 r
.36699 .34479 .37705 .35573 .39358 .34994 .38358 .33904 Mtetra
.655 .747 .918 r
.38358 .33904 .39358 .34994 .41021 .34411 .40028 .33321 Mtetra
.656 .749 .918 r
.40028 .33321 .41021 .34411 .42695 .33829 .41708 .32732 Mtetra
.657 .749 .918 r
.41708 .32732 .42695 .33829 .44379 .33247 .43399 .32137 Mtetra
.657 .748 .917 r
.43399 .32137 .44379 .33247 .46074 .32661 .451 .31534 Mtetra
.658 .746 .915 r
.451 .31534 .46074 .32661 .47779 .32064 .46813 .30924 Mtetra
.658 .745 .914 r
.46813 .30924 .47779 .32064 .49496 .31457 .48536 .30311 Mtetra
.658 .745 .915 r
.48536 .30311 .49496 .31457 .51223 .30841 .50269 .29696 Mtetra
.657 .746 .916 r
.50269 .29696 .51223 .30841 .5296 .3022 .52014 .29079 Mtetra
.654 .748 .919 r
.52014 .29079 .5296 .3022 .54709 .29601 .5377 .28472 Mtetra
.651 .751 .923 r
.5377 .28472 .54709 .29601 .56469 .28985 .55538 .27873 Mtetra
.652 .756 .926 r
.55538 .27873 .56469 .28985 .5824 .28389 .57317 .27265 Mtetra
.657 .757 .923 r
.57317 .27265 .5824 .28389 .60023 .27793 .59107 .26631 Mtetra
.659 .751 .918 r
.59107 .26631 .60023 .27793 .61817 .27164 .60908 .25985 Mtetra
.659 .75 .917 r
.60908 .25985 .61817 .27164 .63622 .2652 .62721 .25335 Mtetra
.656 .749 .918 r
.62721 .25335 .63622 .2652 .65439 .25873 .64546 .24694 Mtetra
.651 .749 .922 r
.64546 .24694 .65439 .25873 .67268 .25238 .66384 .24069 Mtetra
.654 .754 .923 r
.66384 .24069 .67268 .25238 .6911 .24618 .68234 .2343 Mtetra
.657 .753 .921 r
.68234 .2343 .6911 .24618 .70964 .23978 .70095 .22771 Mtetra
.659 .752 .918 r
.70095 .22771 .70964 .23978 .72828 .23319 .71968 .22099 Mtetra
.657 .75 .918 r
.71968 .22099 .72828 .23319 .74705 .22651 .73854 .21433 Mtetra
.652 .75 .921 r
.73854 .21433 .74705 .22651 .76595 .21998 .75753 .20782 Mtetra
.659 .753 .92 r
.08869 .42877 .09983 .43842 .11482 .43303 .10372 .42335 Mtetra
.659 .754 .92 r
.10372 .42335 .11482 .43303 .12988 .4278 .11885 .41789 Mtetra
.653 .749 .92 r
.11885 .41789 .12988 .4278 .14501 .42262 .13404 .41263 Mtetra
.652 .748 .92 r
.13404 .41263 .14501 .42262 .16025 .41734 .14932 .40735 Mtetra
.655 .75 .92 r
.14932 .40735 .16025 .41734 .17559 .41187 .1647 .40196 Mtetra
.659 .754 .921 r
.1647 .40196 .17559 .41187 .19103 .40628 .18019 .39638 Mtetra
.66 .756 .921 r
.18019 .39638 .19103 .40628 .20655 .40086 .19578 .39071 Mtetra
.656 .751 .92 r
.19578 .39071 .20655 .40086 .22214 .39552 .21144 .38518 Mtetra
.653 .747 .919 r
.21144 .38518 .22214 .39552 .23784 .39015 .22719 .37973 Mtetra
.652 .747 .919 r
.22719 .37973 .23784 .39015 .25363 .38468 .24303 .37426 Mtetra
.654 .749 .92 r
.24303 .37426 .25363 .38468 .26954 .37894 .25898 .36871 Mtetra
.657 .755 .922 r
.25898 .36871 .26954 .37894 .28555 .37313 .27504 .36301 Mtetra
.66 .759 .923 r
.27504 .36301 .28555 .37313 .30165 .36741 .2912 .35714 Mtetra
.66 .757 .922 r
.2912 .35714 .30165 .36741 .31783 .36178 .30746 .35124 Mtetra
.658 .753 .92 r
.30746 .35124 .31783 .36178 .33412 .35614 .32381 .34538 Mtetra
.655 .749 .918 r
.32381 .34538 .33412 .35614 .3505 .35048 .34026 .33958 Mtetra
.655 .747 .917 r
.34026 .33958 .3505 .35048 .36699 .34479 .35682 .33376 Mtetra
.655 .746 .916 r
.35682 .33376 .36699 .34479 .38358 .33904 .37347 .32789 Mtetra
.655 .745 .916 r
.37347 .32789 .38358 .33904 .40028 .33321 .39023 .32199 Mtetra
.656 .745 .915 r
.39023 .32199 .40028 .33321 .41708 .32732 .4071 .31603 Mtetra
.4071 .31603 .41708 .32732 .43399 .32137 .42407 .31002 Mtetra
.42407 .31002 .43399 .32137 .451 .31534 .44115 .30396 Mtetra
.656 .746 .916 r
.44115 .30396 .451 .31534 .46813 .30924 .45834 .29786 Mtetra
.656 .747 .917 r
.45834 .29786 .46813 .30924 .48536 .30311 .47564 .29173 Mtetra
.654 .748 .919 r
.47564 .29173 .48536 .30311 .50269 .29696 .49305 .28567 Mtetra
.652 .751 .922 r
.49305 .28567 .50269 .29696 .52014 .29079 .51057 .27963 Mtetra
.652 .755 .925 r
.51057 .27963 .52014 .29079 .5377 .28472 .5282 .27357 Mtetra
.655 .758 .925 r
.5282 .27357 .5377 .28472 .55538 .27873 .54595 .26733 Mtetra
.658 .755 .922 r
.54595 .26733 .55538 .27873 .57317 .27265 .56381 .26093 Mtetra
.659 .751 .918 r
.56381 .26093 .57317 .27265 .59107 .26631 .58179 .25445 Mtetra
.659 .749 .917 r
.58179 .25445 .59107 .26631 .60908 .25985 .59988 .24793 Mtetra
.656 .748 .918 r
.59988 .24793 .60908 .25985 .62721 .25335 .6181 .24149 Mtetra
.652 .749 .921 r
.6181 .24149 .62721 .25335 .64546 .24694 .63643 .23519 Mtetra
.653 .754 .924 r
.63643 .23519 .64546 .24694 .66384 .24069 .65489 .22878 Mtetra
.657 .754 .921 r
.65489 .22878 .66384 .24069 .68234 .2343 .67347 .22217 Mtetra
.659 .752 .919 r
.67347 .22217 .68234 .2343 .70095 .22771 .69216 .21543 Mtetra
.658 .75 .918 r
.69216 .21543 .70095 .22771 .71968 .22099 .71098 .20867 Mtetra
.653 .749 .92 r
.71098 .20867 .71968 .22099 .73854 .21433 .72993 .2021 Mtetra
.653 .752 .922 r
.72993 .2021 .73854 .21433 .75753 .20782 .74901 .19548 Mtetra
.656 .752 .92 r
.07743 .41895 .08869 .42877 .10372 .42335 .09251 .41357 Mtetra
.659 .754 .92 r
.09251 .41357 .10372 .42335 .11885 .41789 .10768 .40804 Mtetra
.658 .754 .921 r
.10768 .40804 .11885 .41789 .13404 .41263 .12295 .40253 Mtetra
.653 .749 .92 r
.12295 .40253 .13404 .41263 .14932 .40735 .13828 .39718 Mtetra
.653 .748 .92 r
.13828 .39718 .14932 .40735 .1647 .40196 .1537 .3918 Mtetra
.655 .75 .92 r
.1537 .3918 .1647 .40196 .18019 .39638 .16923 .38631 Mtetra
.658 .754 .921 r
.16923 .38631 .18019 .39638 .19578 .39071 .18486 .38065 Mtetra
.66 .756 .921 r
.18486 .38065 .19578 .39071 .21144 .38518 .2006 .37489 Mtetra
.657 .752 .92 r
.2006 .37489 .21144 .38518 .22719 .37973 .21642 .36922 Mtetra
.653 .748 .919 r
.21642 .36922 .22719 .37973 .24303 .37426 .23232 .36365 Mtetra
.653 .747 .919 r
.23232 .36365 .24303 .37426 .25898 .36871 .24832 .35806 Mtetra
.653 .748 .919 r
.24832 .35806 .25898 .36871 .27504 .36301 .26443 .35243 Mtetra
.654 .751 .921 r
.26443 .35243 .27504 .36301 .2912 .35714 .28063 .34671 Mtetra
.656 .756 .923 r
.28063 .34671 .2912 .35714 .30746 .35124 .29694 .34089 Mtetra
.659 .759 .924 r
.29694 .34089 .30746 .35124 .32381 .34538 .31336 .33494 Mtetra
.658 .759 .924 r
.31336 .33494 .32381 .34538 .34026 .33958 .32988 .32895 Mtetra
.658 .756 .923 r
.32988 .32895 .34026 .33958 .35682 .33376 .34651 .32296 Mtetra
.657 .754 .921 r
.34651 .32296 .35682 .33376 .37347 .32789 .36323 .31696 Mtetra
.656 .752 .92 r
.36323 .31696 .37347 .32789 .39023 .32199 .38006 .31094 Mtetra
.656 .751 .92 r
.38006 .31094 .39023 .32199 .4071 .31603 .39699 .30491 Mtetra
.655 .751 .92 r
.39699 .30491 .4071 .31603 .42407 .31002 .41403 .29887 Mtetra
.655 .751 .921 r
.41403 .29887 .42407 .31002 .44115 .30396 .43118 .29281 Mtetra
.654 .753 .922 r
.43118 .29281 .44115 .30396 .45834 .29786 .44844 .28674 Mtetra
.653 .755 .924 r
.44844 .28674 .45834 .29786 .47564 .29173 .4658 .28066 Mtetra
.653 .757 .926 r
.4658 .28066 .47564 .29173 .49305 .28567 .48328 .27455 Mtetra
.655 .758 .925 r
.48328 .27455 .49305 .28567 .51057 .27963 .50088 .2683 Mtetra
.657 .756 .923 r
.50088 .2683 .51057 .27963 .5282 .27357 .51859 .26194 Mtetra
.658 .752 .919 r
.51859 .26194 .5282 .27357 .54595 .26733 .53641 .25549 Mtetra
.659 .749 .917 r
.53641 .25549 .54595 .26733 .56381 .26093 .55435 .24899 Mtetra
.658 .749 .917 r
.55435 .24899 .56381 .26093 .58179 .25445 .5724 .24247 Mtetra
.655 .748 .918 r
.5724 .24247 .58179 .25445 .59988 .24793 .59058 .23603 Mtetra
.652 .75 .922 r
.59058 .23603 .59988 .24793 .6181 .24149 .60887 .22969 Mtetra
.654 .754 .924 r
.60887 .22969 .6181 .24149 .63643 .23519 .62729 .22323 Mtetra
.657 .754 .922 r
.62729 .22323 .63643 .23519 .65489 .22878 .64583 .21659 Mtetra
.658 .752 .919 r
.64583 .21659 .65489 .22878 .67347 .22217 .66448 .20983 Mtetra
.658 .75 .918 r
.66448 .20983 .67347 .22217 .69216 .21543 .68326 .20302 Mtetra
.654 .749 .919 r
.68326 .20302 .69216 .21543 .71098 .20867 .70217 .19637 Mtetra
.653 .752 .923 r
.70217 .19637 .71098 .20867 .72993 .2021 .72122 .18973 Mtetra
.655 .753 .922 r
.72122 .18973 .72993 .2021 .74901 .19548 .74038 .18292 Mtetra
.654 .75 .92 r
.06606 .40897 .07743 .41895 .09251 .41357 .08117 .4036 Mtetra
.657 .752 .92 r
.08117 .4036 .09251 .41357 .10768 .40804 .09639 .39811 Mtetra
.659 .755 .921 r
.09639 .39811 .10768 .40804 .12295 .40253 .11171 .39248 Mtetra
.657 .753 .921 r
.11171 .39248 .12295 .40253 .13828 .39718 .12711 .3869 Mtetra
.653 .748 .92 r
.12711 .3869 .13828 .39718 .1537 .3918 .14259 .38145 Mtetra
.14259 .38145 .1537 .3918 .16923 .38631 .15816 .37596 Mtetra
.655 .75 .92 r
.15816 .37596 .16923 .38631 .18486 .38065 .17384 .37038 Mtetra
.657 .754 .921 r
.17384 .37038 .18486 .38065 .2006 .37489 .18962 .36467 Mtetra
.66 .757 .922 r
.18962 .36467 .2006 .37489 .21642 .36922 .2055 .35882 Mtetra
.659 .754 .92 r
.2055 .35882 .21642 .36922 .23232 .36365 .22149 .35298 Mtetra
.654 .749 .919 r
.22149 .35298 .23232 .36365 .24832 .35806 .23755 .34727 Mtetra
.653 .747 .918 r
.23755 .34727 .24832 .35806 .26443 .35243 .25371 .34155 Mtetra
.25371 .34155 .26443 .35243 .28063 .34671 .26997 .33581 Mtetra
.654 .748 .919 r
.26997 .33581 .28063 .34671 .29694 .34089 .28634 .33001 Mtetra
.654 .75 .92 r
.28634 .33001 .29694 .34089 .31336 .33494 .30281 .32415 Mtetra
.655 .753 .922 r
.30281 .32415 .31336 .33494 .32988 .32895 .31938 .31823 Mtetra
.656 .756 .924 r
.31938 .31823 .32988 .32895 .34651 .32296 .33606 .31226 Mtetra
.656 .758 .925 r
.33606 .31226 .34651 .32296 .36323 .31696 .35285 .30623 Mtetra
.656 .759 .925 r
.35285 .30623 .36323 .31696 .38006 .31094 .36975 .30015 Mtetra
.656 .759 .926 r
.36975 .30015 .38006 .31094 .39699 .30491 .38675 .29405 Mtetra
.655 .759 .926 r
.38675 .29405 .39699 .30491 .41403 .29887 .40386 .28793 Mtetra
.656 .759 .926 r
.40386 .28793 .41403 .29887 .43118 .29281 .42108 .28176 Mtetra
.656 .758 .925 r
.42108 .28176 .43118 .29281 .44844 .28674 .43841 .27553 Mtetra
.657 .756 .923 r
.43841 .27553 .44844 .28674 .4658 .28066 .45585 .26924 Mtetra
.657 .754 .921 r
.45585 .26924 .4658 .28066 .48328 .27455 .47341 .26289 Mtetra
.658 .751 .919 r
.47341 .26289 .48328 .27455 .50088 .2683 .49108 .25647 Mtetra
.658 .749 .917 r
.49108 .25647 .50088 .2683 .51859 .26194 .50886 .25 Mtetra
.658 .748 .917 r
.50886 .25 .51859 .26194 .53641 .25549 .52676 .24349 Mtetra
.657 .748 .917 r
.52676 .24349 .53641 .25549 .55435 .24899 .54477 .23697 Mtetra
.653 .748 .919 r
.54477 .23697 .55435 .24899 .5724 .24247 .56291 .23058 Mtetra
.652 .752 .923 r
.56291 .23058 .5724 .24247 .59058 .23603 .58116 .22418 Mtetra
.655 .755 .924 r
.58116 .22418 .59058 .23603 .60887 .22969 .59954 .21765 Mtetra
.657 .754 .921 r
.59954 .21765 .60887 .22969 .62729 .22323 .61803 .21096 Mtetra
.658 .751 .919 r
.61803 .21096 .62729 .22323 .64583 .21659 .63665 .20417 Mtetra
.658 .75 .918 r
.63665 .20417 .64583 .21659 .66448 .20983 .65539 .19733 Mtetra
.654 .749 .919 r
.65539 .19733 .66448 .20983 .68326 .20302 .67426 .19062 Mtetra
.653 .751 .922 r
.67426 .19062 .68326 .20302 .70217 .19637 .69326 .18395 Mtetra
.655 .754 .922 r
.69326 .18395 .70217 .19637 .72122 .18973 .71239 .17712 Mtetra
.657 .752 .92 r
.71239 .17712 .72122 .18973 .74038 .18292 .73164 .17015 Mtetra
.653 .749 .92 r
.05457 .39883 .06606 .40897 .08117 .4036 .06972 .39346 Mtetra
.655 .75 .92 r
.06972 .39346 .08117 .4036 .09639 .39811 .08498 .38797 Mtetra
.657 .752 .92 r
.08498 .38797 .09639 .39811 .11171 .39248 .10034 .38238 Mtetra
.659 .755 .921 r
.10034 .38238 .11171 .39248 .12711 .3869 .1158 .37667 Mtetra
.657 .753 .92 r
.1158 .37667 .12711 .3869 .14259 .38145 .13135 .37099 Mtetra
.653 .748 .92 r
.13135 .37099 .14259 .38145 .15816 .37596 .14698 .36543 Mtetra
.14698 .36543 .15816 .37596 .17384 .37038 .1627 .35984 Mtetra
.654 .75 .92 r
.1627 .35984 .17384 .37038 .18962 .36467 .17853 .35417 Mtetra
.656 .752 .921 r
.17853 .35417 .18962 .36467 .2055 .35882 .19445 .34842 Mtetra
.659 .756 .922 r
.19445 .34842 .2055 .35882 .22149 .35298 .21049 .34251 Mtetra
.21049 .34251 .22149 .35298 .23755 .34727 .22663 .33655 Mtetra
.658 .752 .92 r
.22663 .33655 .23755 .34727 .25371 .34155 .24287 .33061 Mtetra
.655 .748 .919 r
.24287 .33061 .25371 .34155 .26997 .33581 .25919 .32475 Mtetra
.654 .747 .918 r
.25919 .32475 .26997 .33581 .28634 .33001 .27562 .31886 Mtetra
.27562 .31886 .28634 .33001 .30281 .32415 .29215 .31295 Mtetra
.29215 .31295 .30281 .32415 .31938 .31823 .30878 .30698 Mtetra
.655 .748 .918 r
.30878 .30698 .31938 .31823 .33606 .31226 .32553 .30097 Mtetra
.32553 .30097 .33606 .31226 .35285 .30623 .34238 .2949 Mtetra
.655 .749 .919 r
.34238 .2949 .35285 .30623 .36975 .30015 .35934 .28878 Mtetra
.656 .75 .919 r
.35934 .28878 .36975 .30015 .38675 .29405 .3764 .28261 Mtetra
.3764 .28261 .38675 .29405 .40386 .28793 .39358 .27638 Mtetra
.656 .749 .919 r
.39358 .27638 .40386 .28793 .42108 .28176 .41087 .2701 Mtetra
.657 .749 .918 r
.41087 .2701 .42108 .28176 .43841 .27553 .42827 .26377 Mtetra
.657 .748 .917 r
.42827 .26377 .43841 .27553 .45585 .26924 .44579 .25738 Mtetra
.44579 .25738 .45585 .26924 .47341 .26289 .46341 .25095 Mtetra
.46341 .25095 .47341 .26289 .49108 .25647 .48116 .24447 Mtetra
.48116 .24447 .49108 .25647 .50886 .25 .49901 .23797 Mtetra
.654 .748 .919 r
.49901 .23797 .50886 .25 .52676 .24349 .51699 .23154 Mtetra
.653 .751 .922 r
.51699 .23154 .52676 .24349 .54477 .23697 .53508 .22513 Mtetra
.653 .754 .924 r
.53508 .22513 .54477 .23697 .56291 .23058 .55329 .21866 Mtetra
.656 .756 .923 r
.55329 .21866 .56291 .23058 .58116 .22418 .57163 .21203 Mtetra
.657 .753 .921 r
.57163 .21203 .58116 .22418 .59954 .21765 .59008 .20529 Mtetra
.658 .751 .919 r
.59008 .20529 .59954 .21765 .61803 .21096 .60866 .19846 Mtetra
.658 .75 .918 r
.60866 .19846 .61803 .21096 .63665 .20417 .62736 .1916 Mtetra
.654 .748 .919 r
.62736 .1916 .63665 .20417 .65539 .19733 .64619 .18486 Mtetra
.653 .751 .922 r
.64619 .18486 .65539 .19733 .67426 .19062 .66515 .17814 Mtetra
.655 .754 .922 r
.66515 .17814 .67426 .19062 .69326 .18395 .68424 .17127 Mtetra
.657 .752 .92 r
.68424 .17127 .69326 .18395 .71239 .17712 .70345 .16429 Mtetra
.659 .752 .919 r
.70345 .16429 .71239 .17712 .73164 .17015 .72279 .15717 Mtetra
.654 .75 .92 r
.04294 .38863 .05457 .39883 .06972 .39346 .05815 .38314 Mtetra
.653 .748 .92 r
.05815 .38314 .06972 .39346 .08498 .38797 .07345 .37767 Mtetra
.655 .751 .92 r
.07345 .37767 .08498 .38797 .10034 .38238 .08885 .37208 Mtetra
.657 .752 .92 r
.08885 .37208 .10034 .38238 .1158 .37667 .10436 .3664 Mtetra
.659 .755 .921 r
.10436 .3664 .1158 .37667 .13135 .37099 .11997 .3606 Mtetra
.658 .754 .92 r
.11997 .3606 .13135 .37099 .14698 .36543 .13567 .35479 Mtetra
.654 .749 .919 r
.13567 .35479 .14698 .36543 .1627 .35984 .15145 .34911 Mtetra
.653 .748 .919 r
.15145 .34911 .1627 .35984 .17853 .35417 .16732 .34342 Mtetra
.654 .749 .92 r
.16732 .34342 .17853 .35417 .19445 .34842 .1833 .33766 Mtetra
.655 .751 .92 r
.1833 .33766 .19445 .34842 .21049 .34251 .19938 .33183 Mtetra
.656 .754 .922 r
.19938 .33183 .21049 .34251 .22663 .33655 .21557 .32591 Mtetra
.659 .757 .923 r
.21557 .32591 .22663 .33655 .24287 .33061 .23187 .31988 Mtetra
.658 .756 .922 r
.23187 .31988 .24287 .33061 .25919 .32475 .24826 .3138 Mtetra
.658 .753 .92 r
.24826 .3138 .25919 .32475 .27562 .31886 .26476 .30772 Mtetra
.656 .75 .919 r
.26476 .30772 .27562 .31886 .29215 .31295 .28136 .30165 Mtetra
.655 .748 .918 r
.28136 .30165 .29215 .31295 .30878 .30698 .29806 .29558 Mtetra
.655 .747 .918 r
.29806 .29558 .30878 .30698 .32553 .30097 .31487 .28948 Mtetra
.655 .747 .917 r
.31487 .28948 .32553 .30097 .34238 .2949 .33178 .28333 Mtetra
.33178 .28333 .34238 .2949 .35934 .28878 .34881 .27714 Mtetra
.656 .747 .917 r
.34881 .27714 .35934 .28878 .3764 .28261 .36594 .27089 Mtetra
.36594 .27089 .3764 .28261 .39358 .27638 .38319 .26459 Mtetra
.38319 .26459 .39358 .27638 .41087 .2701 .40055 .25825 Mtetra
.40055 .25825 .41087 .2701 .42827 .26377 .41802 .25185 Mtetra
.656 .748 .917 r
.41802 .25185 .42827 .26377 .44579 .25738 .4356 .24542 Mtetra
.655 .748 .918 r
.4356 .24542 .44579 .25738 .46341 .25095 .4533 .23899 Mtetra
.654 .749 .92 r
.4533 .23899 .46341 .25095 .48116 .24447 .47111 .23257 Mtetra
.653 .752 .922 r
.47111 .23257 .48116 .24447 .49901 .23797 .48904 .22614 Mtetra
.653 .754 .924 r
.48904 .22614 .49901 .23797 .51699 .23154 .50709 .21966 Mtetra
.655 .756 .924 r
.50709 .21966 .51699 .23154 .53508 .22513 .52527 .21306 Mtetra
.657 .754 .922 r
.52527 .21306 .53508 .22513 .55329 .21866 .54356 .20636 Mtetra
.657 .752 .919 r
.54356 .20636 .55329 .21866 .57163 .21203 .56197 .19957 Mtetra
.658 .75 .918 r
.56197 .19957 .57163 .21203 .59008 .20529 .58051 .19271 Mtetra
.657 .749 .918 r
.58051 .19271 .59008 .20529 .60866 .19846 .59917 .18583 Mtetra
.654 .748 .919 r
.59917 .18583 .60866 .19846 .62736 .1916 .61796 .17908 Mtetra
.653 .752 .922 r
.61796 .17908 .62736 .1916 .64619 .18486 .63688 .17231 Mtetra
.655 .754 .922 r
.63688 .17231 .64619 .18486 .66515 .17814 .65592 .1654 Mtetra
.656 .752 .921 r
.65592 .1654 .66515 .17814 .68424 .17127 .67509 .15838 Mtetra
.658 .752 .919 r
.67509 .15838 .68424 .17127 .70345 .16429 .69439 .15123 Mtetra
.657 .75 .918 r
.69439 .15123 .70345 .16429 .72279 .15717 .71382 .14409 Mtetra
.658 .753 .92 r
.03116 .37844 .04294 .38863 .05815 .38314 .04644 .37275 Mtetra
.654 .75 .92 r
.04644 .37275 .05815 .38314 .07345 .37767 .0618 .36716 Mtetra
.653 .748 .92 r
.0618 .36716 .07345 .37767 .08885 .37208 .07724 .36159 Mtetra
.655 .75 .92 r
.07724 .36159 .08885 .37208 .10436 .3664 .09279 .35591 Mtetra
.656 .752 .921 r
.09279 .35591 .10436 .3664 .11997 .3606 .10844 .35014 Mtetra
.658 .755 .921 r
.10844 .35014 .11997 .3606 .13567 .35479 .1242 .34426 Mtetra
.1242 .34426 .13567 .35479 .15145 .34911 .14006 .33834 Mtetra
.656 .75 .92 r
.14006 .33834 .15145 .34911 .16732 .34342 .156 .33249 Mtetra
.654 .748 .919 r
.156 .33249 .16732 .34342 .1833 .33766 .17203 .32668 Mtetra
.653 .748 .919 r
.17203 .32668 .1833 .33766 .19938 .33183 .18816 .32084 Mtetra
.654 .75 .92 r
.18816 .32084 .19938 .33183 .21557 .32591 .2044 .31492 Mtetra
.655 .751 .92 r
.2044 .31492 .21557 .32591 .23187 .31988 .22075 .30894 Mtetra
.656 .754 .922 r
.22075 .30894 .23187 .31988 .24826 .3138 .2372 .30289 Mtetra
.657 .756 .923 r
.2372 .30289 .24826 .3138 .26476 .30772 .25376 .29676 Mtetra
.658 .757 .923 r
.25376 .29676 .26476 .30772 .28136 .30165 .27042 .29057 Mtetra
.657 .756 .922 r
.27042 .29057 .28136 .30165 .29806 .29558 .28719 .28435 Mtetra
.657 .754 .921 r
.28719 .28435 .29806 .29558 .31487 .28948 .30407 .27811 Mtetra
.656 .753 .921 r
.30407 .27811 .31487 .28948 .33178 .28333 .32105 .27184 Mtetra
.656 .752 .92 r
.32105 .27184 .33178 .28333 .34881 .27714 .33815 .26555 Mtetra
.656 .751 .92 r
.33815 .26555 .34881 .27714 .36594 .27089 .35535 .25923 Mtetra
.655 .751 .92 r
.35535 .25923 .36594 .27089 .38319 .26459 .37266 .25288 Mtetra
.655 .751 .921 r
.37266 .25288 .38319 .26459 .40055 .25825 .39009 .24651 Mtetra
.655 .752 .921 r
.39009 .24651 .40055 .25825 .41802 .25185 .40763 .2401 Mtetra
.654 .753 .922 r
.40763 .2401 .41802 .25185 .4356 .24542 .42528 .23367 Mtetra
.654 .755 .924 r
.42528 .23367 .4356 .24542 .4533 .23899 .44305 .22721 Mtetra
.655 .756 .924 r
.44305 .22721 .4533 .23899 .47111 .23257 .46094 .22069 Mtetra
.656 .756 .923 r
.46094 .22069 .47111 .23257 .48904 .22614 .47895 .21408 Mtetra
.656 .754 .922 r
.47895 .21408 .48904 .22614 .50709 .21966 .49708 .20739 Mtetra
.657 .752 .92 r
.49708 .20739 .50709 .21966 .52527 .21306 .51533 .20063 Mtetra
.658 .751 .918 r
.51533 .20063 .52527 .21306 .54356 .20636 .53371 .1938 Mtetra
.658 .749 .918 r
.53371 .1938 .54356 .20636 .56197 .19957 .5522 .18692 Mtetra
.656 .749 .918 r
.5522 .18692 .56197 .19957 .58051 .19271 .57082 .18007 Mtetra
.653 .749 .92 r
.57082 .18007 .58051 .19271 .59917 .18583 .58956 .17328 Mtetra
.653 .753 .923 r
.58956 .17328 .59917 .18583 .61796 .17908 .60844 .16645 Mtetra
.655 .754 .922 r
.60844 .16645 .61796 .17908 .63688 .17231 .62744 .15949 Mtetra
.657 .752 .92 r
.62744 .15949 .63688 .17231 .65592 .1654 .64657 .15242 Mtetra
.658 .752 .919 r
.64657 .15242 .65592 .1654 .67509 .15838 .66583 .14523 Mtetra
.657 .75 .918 r
.66583 .14523 .67509 .15838 .69439 .15123 .68522 .13805 Mtetra
.654 .749 .92 r
.68522 .13805 .69439 .15123 .71382 .14409 .70475 .13095 Mtetra
.658 .753 .921 r
.01925 .36813 .03116 .37844 .04644 .37275 .03459 .36238 Mtetra
.03459 .36238 .04644 .37275 .0618 .36716 .05001 .3566 Mtetra
.655 .75 .92 r
.05001 .3566 .0618 .36716 .07724 .36159 .06551 .3509 Mtetra
.653 .748 .92 r
.06551 .3509 .07724 .36159 .09279 .35591 .0811 .34522 Mtetra
.654 .75 .92 r
.0811 .34522 .09279 .35591 .10844 .35014 .0968 .33945 Mtetra
.656 .752 .92 r
.0968 .33945 .10844 .35014 .1242 .34426 .1126 .33359 Mtetra
.657 .754 .921 r
.1126 .33359 .1242 .34426 .14006 .33834 .12851 .32764 Mtetra
.658 .755 .921 r
.12851 .32764 .14006 .33834 .156 .33249 .14452 .32162 Mtetra
.658 .753 .92 r
.14452 .32162 .156 .33249 .17203 .32668 .16062 .31559 Mtetra
.655 .749 .919 r
.16062 .31559 .17203 .32668 .18816 .32084 .17682 .30963 Mtetra
.654 .748 .919 r
.17682 .30963 .18816 .32084 .2044 .31492 .19311 .30366 Mtetra
.19311 .30366 .2044 .31492 .22075 .30894 .20951 .29766 Mtetra
.655 .749 .919 r
.20951 .29766 .22075 .30894 .2372 .30289 .22602 .29159 Mtetra
.655 .75 .92 r
.22602 .29159 .2372 .30289 .25376 .29676 .24264 .28546 Mtetra
.655 .752 .921 r
.24264 .28546 .25376 .29676 .27042 .29057 .25936 .27928 Mtetra
.656 .754 .922 r
.25936 .27928 .27042 .29057 .28719 .28435 .27619 .27306 Mtetra
.656 .755 .923 r
.27619 .27306 .28719 .28435 .30407 .27811 .29313 .26678 Mtetra
.656 .756 .923 r
.29313 .26678 .30407 .27811 .32105 .27184 .31018 .26046 Mtetra
.656 .756 .924 r
.31018 .26046 .32105 .27184 .33815 .26555 .32734 .25411 Mtetra
.32734 .25411 .33815 .26555 .35535 .25923 .34461 .24771 Mtetra
.34461 .24771 .35535 .25923 .37266 .25288 .362 .24127 Mtetra
.362 .24127 .37266 .25288 .39009 .24651 .3795 .2348 Mtetra
.656 .756 .923 r
.3795 .2348 .39009 .24651 .40763 .2401 .39711 .22828 Mtetra
.656 .755 .923 r
.39711 .22828 .40763 .2401 .42528 .23367 .41484 .2217 Mtetra
.656 .754 .922 r
.41484 .2217 .42528 .23367 .44305 .22721 .43269 .21508 Mtetra
.656 .752 .921 r
.43269 .21508 .44305 .22721 .46094 .22069 .45065 .2084 Mtetra
.657 .751 .919 r
.45065 .2084 .46094 .22069 .47895 .21408 .46874 .20165 Mtetra
.657 .75 .918 r
.46874 .20165 .47895 .21408 .49708 .20739 .48695 .19484 Mtetra
.657 .749 .918 r
.48695 .19484 .49708 .20739 .51533 .20063 .50528 .18798 Mtetra
.50528 .18798 .51533 .20063 .53371 .1938 .52373 .1811 Mtetra
.654 .749 .919 r
.52373 .1811 .53371 .1938 .5522 .18692 .54231 .17429 Mtetra
.653 .751 .922 r
.54231 .17429 .5522 .18692 .57082 .18007 .56101 .16747 Mtetra
.654 .754 .923 r
.56101 .16747 .57082 .18007 .58956 .17328 .57984 .16056 Mtetra
.656 .754 .922 r
.57984 .16056 .58956 .17328 .60844 .16645 .5988 .15354 Mtetra
.657 .752 .92 r
.5988 .15354 .60844 .16645 .62744 .15949 .61789 .14642 Mtetra
.658 .751 .919 r
.61789 .14642 .62744 .15949 .64657 .15242 .6371 .1392 Mtetra
.657 .749 .918 r
.6371 .1392 .64657 .15242 .66583 .14523 .65645 .13198 Mtetra
.654 .75 .92 r
.65645 .13198 .66583 .14523 .68522 .13805 .67594 .12484 Mtetra
.654 .752 .922 r
.67594 .12484 .68522 .13805 .70475 .13095 .69557 .11766 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
[(-2)] .12586 .2075 1 .99877 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.56863 .04703 m
.57247 .05235 L
s
[(2)] .56094 .0364 .72324 1 Mshowa
.125 Mabswid
.18558 .19702 m
.18832 .19985 L
s
.23703 .17687 m
.23971 .17975 L
s
.28951 .15632 m
.29214 .15925 L
s
.39772 .11395 m
.40023 .11699 L
s
.4535 .09211 m
.45595 .0952 L
s
.51046 .06981 m
.51284 .07294 L
s
.08568 .23614 m
.08851 .23887 L
s
.62804 .02377 m
.63027 .02701 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 233.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00o?ooool2o`0006[ooooo003iooooo`?o000000?oooooo`000?ooool0
JOooool00?Oooooo0_l00004ooooo`;o0000JOooool00?Cooooo0ol00006ooooo`03o`000?oooooo
000006Sooooo003;ooooo`Go00008_ooool2o`0000Wooooo00?o0000ooooool00000J?ooool00<_o
oooo00GoV9RHob4Q8Oo^k^koooooodA4A00Oooooo`?o00002oooool01?l0003oooooooooool0001W
ooooo`00c?ooool00onHV9So8B4Qonk^kP0Mooooo`?o00003_ooool01Ol0003ooooooooooooooooo
000006Kooooo003=ooooo`03oiRHV?lQ8B7ok^k^01[ooooo0_l0000Aooooo`05o`000?oooooooooo
ooooool00000I_ooool00<kooooo00?oMgMgofIVI_ooool05_ooool3o`0001?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1Sooooo`00coooool00ol0003oooooooooo`0Cooooo`;o
00000_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0H_ooool00<_ooooo00Go0000okZj^_ooooooV9RHoa0@400Booooo`?o00006Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo06;ooooo003;ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`04?ooool2o`0001cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Qooooo`00
gOooool3o`0001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Qooooo`00fooo
ool2o`00027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Pooooo`00f?ooool3
o`0002?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Oooooo`00eOooool3o`00
02Kooooo00?o0000ooooooooool01?ooool2o`00067ooooo003Cooooo`;o0000:Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo05kooooo003@ooooo`?o000000?oooooo`000?ooool0
:?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05gooooo003>ooooo`;o00001Ooo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0GOoo
ool00<_ooooo0ol0000`ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0G?ooool0
0<Wooooo0_l0000cooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Foooool00<Ko
oooo0ol0000eooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Foooool00<Cooooo
0_l0000hooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0F_ooool00<7ooooo0ol0
000jooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03_ooool5o`0004Kooooo002n
ooooo`?o0000?Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00kooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A016ooooo`00_?ooool2o`0000?ooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo1_l00003ooooo`03oiRHV?lQ8B7o
k^k^04Oooooo002iooooo`?o0000@oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00kooooo00?oV9RHob4Q8Oo^k^h0A_ooool00;Oooooo0_l00016ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03oooool00omgMgOoIVIVooooo`15ooooo`00]?ooool3o`0004Sooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Cooooo
002booooo`;o0000Boooool00ol0003oooooooooo`0=ooooo`;o00003?ooool01Ol0003o^[Zjoooo
oonHV9So410@04Kooooo002_ooooo`?o0000COooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c016ooooo`00[Oooool2o`00053ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`1Dooooo`00Z_ooool4o`00057ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1Dooooo`00Z?ooool2o`0000Cooooo00?o0000oooo
ooooool0C_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05?ooooo001nooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h08_ooool3o`0005Oooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`1Booooo`00O_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01oooooo0ol0001Joooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool0D_ooool007kooooo00Go410@oooooooo
oooooooooa0@400Mooooo`;o0000GOooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
057ooooo001nooooo`05o`000?ooooooooooooooool000006_ooool3o`0005oooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`1@ooooo`00O_ooool01Ol0003ooooooooooooooooo0000
01Sooooo0_l0001Rooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0D?ooool007ko
oooo00Go410@oooooooooooooooooa0@400Eooooo`?o0000I?ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo04oooooo001nooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool2o`00
00?ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
04kooooo001nooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04?ooool3o`0006Sooooo00?oYl3/o`00
0?ooool05_ooool00ol0003oooooooooo`1>ooooo`00TOooool2o`0006Sooooo1?nW`>`00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo04gooooo002>ooooo`?o0000J?ooool7ojO0k003o`00
0?oooooooooo01Cooooo0ol0001>ooooo`00Roooool3o`0006Wooooo0_nW_n/7ojO0k003o`000?oo
oooooooo01Kooooo00?o0000ooooooooool0C?ooool008Wooooo0_l0001Yooooo`KoYko[1_nW`>`0
0ol0003oYl3/ooooo`0Gooooo`03o`000?oooooooooo04_ooooo0026ooooo`?o0000J?ooool00onX
_n_oYko[ojNoj`07ojNoj`GoYl3/00?o0000ojNojoooool06?ooool00ol0003oooooooooo`1:oooo
o`00Q?ooool2o`0000;ooooo00?o0000ooooooooool0Hoooool5ojRoj`WoYko[0_nW`>`2ojNoj`03
o`000?nW_n_oYko[01Sooooo00?o0000ooooooooool0B_ooool0087ooooo0ol00005ooooo`03o`00
0?oooooooooo063ooooo2?nX_n/7ojNoj`03ojRojonW_n_oYko[00;oYko[00Co0000ojNojonW_n_o
Yko[6?ooool00ol0003oooooooooo`19ooooo`00Ooooool2o`0006Wooooo00?oZ<3[ojRojonX_n/0
1onX_n/4ojNoj`GoZ;o[0onW_n/00ol0003oYko[ojNoj`02ojNojaSooooo00?o0000ooooooooool0
B?ooool007cooooo0ol0001Xooooo`GoZ<3[2OnX_n/00onW_n_oZ;o[ojRoj`06ojRoj`;oYko[00Go
0000ojNojonW_n_oYko[ojRoj`0Hooooo`03o`000?oooooooooo04Sooooo001jooooo`;o0000Iooo
ool:ojS0j`KoZ;o[0_nX`>/9ojRoj`;oYko[00?o0000ojNojonX_n/00onX_n/Hooooo`03o`000?oo
oooooooo04Oooooo001gooooo`?o0000I_ooool>ojS0j`;oZ;o[1_nX`>/9ojRoj`03ojNojol0003o
Z;o[00GoZ;o[6?ooool00ol0003oooooooooo`16ooooo`00M?ooool3o`0006Kooooo00?oYl7/ojS0
jonX`>/05onX`>/6ojRoj`;oZ<3[00?oZ;o[o`000?nX_n/01OnX_n/Hooooo`03o`000?oooooooooo
04Kooooo001booooo`;o00000_ooool00ol0003oooooooooo`1Rooooo`CoYl7/6OnX`>/2ojRoj`Ko
Z<3[00?o0000ojRojonX_n/01OnX_n/Hooooo`03o`000?oooooooooo04Gooooo001_ooooo`?o0000
Ioooool7ojO1k0OoZ<3[00?oYl7/ojS0jonX`>/03OnX`>/00onW`>_oZ<3[ojS0j`06ojS0j`03o`00
0?nX_n_oZ;o[00CoZ;o[00?oZ<3[ooooooooool05_ooool00ol0003oooooooooo`15ooooo`00KOoo
ool2o`0006Oooooo2_nW`N`4ojS0j`GoYl7/2onX`>/5ojO0j`OoZ<3[00Co0000ojS0jonX_n_oZ;o[
1OnX`>/Gooooo`;o0000A_ooool006[ooooo0ol0001Vooooo`koYl7/00?oZ<3[ojO1k?nW`N`01_nW
`N`7ojS0j`03ojO1k?nW`>_oYl3[00KoYl3[1_nX`>/00ol0003oZ<3[ojS0j`07ojS0jaSooooo00?o
0000ooooooooool0@oooool006Sooooo0_l0001Vooooo`;oYl3/3_nW`N`2ojO0k0SoYl7/1?nX`>/5
ojO1k0SoYl3[1OnX`>/00ol0003oZ<3[ojS0j`08ojS0jaOooooo00?o0000ooooooooool0@oooool0
06Gooooo0ol0001Uooooo`KoYl3/2_nW`N`6ojO0k0SoYl7/00?oZ<3[ojO1k?nW`N`01_nW`N`6ojO0
j`03ojO1k?nX`>_oZ<3[00?oZ<3[00?o0000ojS0jonX`>/02?nX`>/Hooooo`03o`000?oooooooooo
04;ooooo001Sooooo`;o0000IOooool00onW_n_oYl3/ojO0k007ojO0k0KoYl7/00?oYko[ojO0k?nW
`>`01onW`>`6ojO1k003ojO0k?nW`NcoYl7/00OoYl7/1?nW`>/4ojO1k0GoZ<3[00?o0000ojS0jonX
`>/02?nX`>/Hooooo`03o`000?oooooooooo047ooooo001Pooooo`?o000000?oooooo`000?ooool0
H_ooool4ojNoj`WoYl3/0_nW`N`5ojNoj`WoYl3/0_nW`N`5ojO0k0WoYl7/00?oYl3[ojO1k?nW`N`0
1OnW`N`4ojS0j`04o`000?nX`>_oZ<3[ojO1k0SoZ<3[5oooool00ol0003oooooooooo`11ooooo`00
=_ooool5o`0002?ooooo0_l0001Vooooo`OoYko[1onW`>`9ojNoj`KoYl3/0_nW_n/8ojO0k0KoYl7/
0_nW`>`8ojO1k0CoZ<3[00?o0000ojO1k?nW`N`00_nW`N`8ojS0jaOooooo00?o0000ooooooooool0
@?ooool003Kooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Pooooo`?o0000IOooool2ojRoj`SoYko[
1?nW`>`=ojNoj`;oYl3/1_nW_n/8ojO0k0;oYl7/1_nW`>`8ojO1k004ojS0jonW`NcoYl7/o`0000Go
Yl7/1_nX`>/00onW`>coooooooooo`0Fooooo`03o`000?oooooooooo03oooooo000^ooooo`Ko0000
0oooool00onHV9So8B4Qonk^kP0Nooooo`?o0000IOooool6ojRoj`SoYko[00?oYl3/ojNojonW_n/0
3?nW_n/00onX_n_oYko[ojNoj`07ojNoj`KoYl3/00?oYko[ojO0k?nW`>`01onW`>`6ojO1k005ojO0
k?nW`NcoYl7/ojO1k?l000001OnW`N`4ojS0j`CoYl3/5oooool00ol0003oooooooooo`0oooooo`00
>?ooool00onHV9So8B4Qonk^kP0Kooooo`;o0000IOooool:ojRoj`KoYko[0_nX_n/<ojNoj`CoZ;o[
2OnW_n/2ojO0k0GoYko[2OnW`>`2ojO1k0GoYl3/0_nW`N`00ol0003oYl7/ojO1k004ojO1k003ojS0
jonW`>coYl3/00GoYl3/5oooool00ol0003oooooooooo`0nooooo`00>Oooool00omgMgOoIVIVoooo
o`0Gooooo`?o0000I?ooool>ojRoj`;oYko[1_nX_n/9ojNoj`OoZ;o[1onW_n/00onX_n_oYko[ojNo
j`06ojNoj`KoYl3/0_nW_n/8ojO0k003ojO1k?l0003oYl7/00?oYl7/2_nW`>`Hooooo`03o`000?oo
oooooooo03gooooo000jooooo`03o`000?oooooooooo01Cooooo0_l0001Toooooa3oZ;o[00?oZ<3[
ojRojonX_n/01onX_n/6ojNoj`[oZ;o[1?nW_n/4ojRoj`SoYko[0_nW`>`6ojNoj`SoYl3/00?o0000
ojO1k?nW`>`03OnW`>`Gooooo`03o`000?oooooooooo03gooooo000fooooo`05o`000?nj^[[ooooo
oiRHV?l@41004oooool3o`0000;ooooo00?o0000ooooooooool0Goooool?ojRoj`GoZ<3[2OnX_n/2
ojNoj`koZ;o[00?oYko[ojRojonX_n/01OnX_n/6ojNoj`03ojRojonW_n_oYko[00OoYko[1_nW`>`0
0onW_n_o0000ojO0k00>ojO0k1Sooooo00?o0000ooooooooool0??ooool003Kooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00Aooooo`;o0000IOooool>ojRoj`WoZ<3[1_nX_n/2ojS0j`koZ;o[0_nX`>/8
ojRoj`CoYko[1?nX_n/9ojNoj`;oYl3/1?nW_n/00ol0003oYl3/ojO0k00>ojO0k1Kooooo0ol0000m
ooooo`00BOooool3o`0006Gooooo00?oZ<3[ojRojonX_n/02onX_n/<ojS0j`;oZ;o[1_nX`>/:ojRo
j`KoZ<3[2?nX_n/00onW_n_oZ;o[ojRoj`05ojRoj`OoYko[00?oZ;o[ojNojonW_n/01?nW_n/00ol0
003oYko[ojO0k005ojO0k0;oYko[2?nW`>`Gooooo`03o`000?oooooooooo03_ooooo0017ooooo`;o
0000IOooool5ojS0j`[oZ;o[3OnX`>/00onX`NcoZ<3[ojS0j`07ojS0j`KoZ;o[2_nX`>/6ojRoj`03
ojS0jonX_n_oZ;o[00KoZ;o[1?nW_n/5ojRoj`GoYko[00?o0000ojNojonW_n/00_nW`>`6ojNoj`So
Yl3/5oooool00ol0003oooooooooo`0jooooo`00A?ooool3o`0006Cooooo00?oYl3[ojS0jonX`>/0
1_nX`>/6ojRoj`;oYl7/3?nX`>/4ojS1k0WoZ<3[0_nX_n/>ojS0j`;oZ;o[1OnX`>/8ojRoj`03ojNo
jonX_n_oZ;o[00KoZ;o[1?nW_n/00ol0003oYko[ojRoj`09ojNoj`KoYl3/00?oY[o[ooooooooool0
5_ooool00ol0003oooooooooo`0iooooo`00@Oooool3o`0006Cooooo1OnW`>/8ojS0j`;oZ;o[1_nW
`N`9ojS0j`OoZ<7/1onX`>/00onW`NcoZ<3[ojS0j`0<ojS0j`;oZ<7[2?nX`>/6ojRoj`;oZ<3[2OnX
_n/2ojNoj`03ojRojol0003oZ;o[00;oZ;o[2OnW_n/2ojO0k0GoY[o[5oooool00ol0003ooooooooo
o`0iooooo`00?oooool3o`0006?ooooo00?oYl7/ojO0jonW`>/01_nW`>/6ojS0j`[oYl7/1_nX`>/2
ojO1k0SoZ<7/1?nX`>/4ojO1k0[oZ<3[1_nX`N/8ojS0j`;oZ;o[1_nX`>/7ojRoj`05ojS0jonX_n_o
Z;o[ojRojol000001?nX_n/6ojNoj`;oZ;o[2?nV_n/Gooooo`03o`000?oooooooooo03Sooooo000l
ooooo`?o00000oooool00ol0003oooooooooo`1Nooooo`CoYl7/2?nW`>/2ojS0j`koYl7/0_nX`>/6
ojO1k0SoZ<7/00?oZ<3[ojO1k?nW`N`01OnW`N`6ojS0j`;oYl7/2?nX`N/6ojS0j`03ojS1k?nX`>_o
Z<3[00OoZ<3[1?nX_n/4ojS0j`;oZ;o[00?o0000ojRojonX_n/00onX_n/2ojNoj`KoZ;o[2?nV_n/F
ooooo`03o`000?oooooooooo00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0/ooooo`00>_ooool2
o`0006Gooooo1onW`N`6ojO0ja[oYl7/1_nX`N`:ojO1k0;oZ<3[1_nW`N`8ojS1j`;oZ<3[1OnX`N`9
ojS0j`03ojRojonX`>_oZ<3[00GoZ<3[00?oZ;o[o`000?nX_n/00onX_n/00onX`>_oZ;o[ojRoj`07
ojRoj`KoY[o[00?oYko[ooooooooool05Oooool00ol0003oooooooooo`06ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL0;?ooool003Oooooo0ol0001Uooooo`[oYl7/0_nW`>/NojO1k0;oZ<7/3?nW`N`0
0onV`>coYl7/ojO1k007ojO1k0KoZ<7[00?oYl7/ojS1k?nX`N`01_nX`N`6ojS0j`;oZ<7[2?nX`>/2
ojRoj`03o`000?nX_n_oZ<3[00?oZ<3[2OnX_n/2ojJoj`GoYko[5oooool00ol0003oooooooooo`05
ooooo`05oa0@4?ooooooooooooooool@4100;?ooool003Gooooo0_l0001UoooooacoYl7/00?oYl3/
ojO1k?nW`N`03?nW`N`2ojO0k0coYl7/1?nV`>`9ojO1k0;oZ<7[1OnW`N`8ojS1k0;oZ<3[1_nX`N/8
ojS0j`03ojRojol0003oZ<3[00GoZ<3[1_nX_n/2ojS0j`SoYko[5_ooool00ol0003oooooooooo`05
ooooo`05o`000?ooooooooooooooool00000;?ooool003;ooooo0ol0001ToooooacoYl7/1OnW`>`:
ojO1k0KoYl3/2OnW`N`7ojK0k0KoYl7/0_nV_n`8ojO1k0KoZ<7/00?oYl7/ojS1jonX`N/01onX`N/8
ojS0j`03o`000?nX`>_oZ<3[00GoZ<3[0_nX_n/6ojS0j`SoYko[5_ooool00ol0003oooooooooo`04
ooooo`05o`000?ooooooooooooooool00000;?ooool0033ooooo0_l0001ToooooacoYl7/00?oYko[
ojO0k?nW`>`01_nW`>`6ojO1k0;oYko[2?nW`>`6ojO1k003ojNojonV`>coY/3/00OoY/3/0_nW`N`6
ojJok0SoYl7/0_nX`N`5ojO1k0WoZ<7[1onX`>/00ol0003oZ<3[ojS0j`0=ojS0j`KoYko[0_nX`>/G
ooooo`03o`000?oooooooooo00?ooooo00Go410@oooooooooooooooooa0@400/ooooo`00;Oooool3
o`000003ooooool0003ooooo063ooooo3onW`N`2ojO0k0_oYl7/1OnW_n/8ojO0k0;oYl7/1_nW_n/8
ojO0k0;oYl7/1OnW_n/7ojK0k0;oYko[2?nV_n`6ojO1k003ojJojonW`NcoYl7/00KoYl7/1_nX`N/2
ojO1k0OoZ<3[00?o0000ojS0jonX`>/03_nX`>/2ojNoj`KoZ<3[5_ooool2o`0000Cooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0/ooooo`00:_ooool3o`0006?ooooo3onW`N`6ojO0k0OoYl7/2OnW_n/6
ojO0k0;oZ;oZ2?nW_n/6ojO0k003ojRoj_nW_n_oYko[00KoYko[1?nV`>`5ojNoj`SoY[o/0_nW`N`5
ojJoj`SoYl7/0_nX`N/6ojO1k0KoZ<3[00?o0000ojS0jonX`>/05onX`>/Cooooo`;o000000?ooooo
o`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02cooooo000Xooooo`;o0000Hoooool?
ojO1k0;oYl3[2?nW`>`4ojO1k0coYko[0_nW`>`6ojRojPSoYko[0_nW`>`5ojRojPSoYko[00?oY/3/
ojNojonW_n/01_nW_n/6ojJok003ojNojonV_n_oY[o[00KoY[o[1_nW`N`00onV_ncoYl7/ojO1k007
ojO1k0GoZ<3[00?o0000ojO1k?nX`>/06?nX`>/Fooooo`03o`000?oooooooooo03;ooooo000Uoooo
o`?o0000H_ooool?ojO1k0KoYl3[2?nW`>`00onW`NcoYko[ojNoj`0;ojNoj`[oZ;oZ1_nW_n/9ojRo
jPKoYko[00?oZ;oZojNojonW_n/02?nW_n/2ojJok0GoYko[2?nV_n/2ojO1k0GoY[o/2OnW`N`2ojS0
j`03ojO1k?l0003o000000;oYl7/6?nX`>/Fooooo`03o`000?oooooooooo03;ooooo000Sooooo`;o
0000H_ooool?ojO1k0[oYl3[1_nW`>`00onW_n[oYko[ojNoj`09ojNoj`koZ;oZ0_nW_n/=ojRojP;o
Yko[1OnX_nX8ojNoj`03ojRoj_nW_n_oYko[00KoYko[1_nV_n/00onW_n_oY[o/ojJok006ojJok0Ko
Yl7/0_nV_n`3o`000003ojO1k?l0003oYl7/00;oYl7/1_nX`>/00onW`NcoZ<3[ojS0j`0?ojS0jaKo
oooo00?o0000ooooooooool0<Oooool0023ooooo0ol0001Rooooo`koYl7/3_nW`>/2ojO0k0GoYkoZ
1onW_n/XojRojPCoYko[1OnX_nX8ojNoj`;oY[o[1OnW_n/8ojJok0;oYl7/0_nV_n`3o`000003ojJo
k?nW`NcoYl7/00;oYl7/00Co0000ojO1k?nW`NcoYl7/0_nX`>/5ojO1k13oZ<3[5oooool00ol0003o
ooooooooo`0`ooooo`007oooool2o`0006;ooooo3OnW`N`@ojO0j`WoYkoZ1?nW_n/[ojRojP03ojNo
jonX_n[oZ;oZ00KoZ;oZ1_nW_n/00onX_n[oYko[ojNoj`06ojNoj`KoY[o/00?oYko[ojJok?l00000
0_l00004ojJok0GoYl7/00?o0000ojK0k?nV`>`02?nW`N`@ojS0jaKooooo00?o0000ooooooooool0
<?ooool001oooooo00?o0000ooooool00000Goooool<ojO1k13oYl3[3OnW_nX00onW_n_oZ;oZojRo
jP0<ojRojP03ojS0jonX_n[oZ;oZ00coZ;oZ00?oZ<3[ojRoj_nX_nX03?nX_nX2ojS0j`SoZ;oZ1?nW
_n/4ojRojPSoYko[0_nV_n`2ojNoj`?o00002?nV_n`2ojO1k0?oY/3/00?o0000ojK0k?nV`>`02?nW
`N`?ojS0jaOooooo00?o0000ooooooooool0;oooool000cooooo1Ol00003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01_ooool01?l0003oooooooooool0001Kooooo`coYl7/4?nW`>/?ojNojPkoZ;oZ
1?nX`>/:ojRojPGoZ<3[2_nX_nX6ojS0j`SoZ;oZ00?oYko[ojRoj_nX_nX01OnX_nX6ojNoj`03ojRo
j_nW_n_o000000;o00001?nW_n/6ojJok003ojNojonV`>coY/3/00?oY/3/00Co0000ojK0k?nV`>co
Y/3/1_nW`N`00onW`>coZ<3[ojS0j`0>ojS0jaOooooo00?o0000ooooooooool0;_ooool000cooooo
00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool2o`00
00;ooooo00?o0000ooooooooool0EOooool<ojO1k13oYl3[3onW_nX?ojRojPOoZ<3[1_nX_nX00onX
`NcoZ<3[ojS0j`06ojS0j`KoZ;oZ00?oZ<7/ojS0jonX`>/01onX`>/6ojRojP03ojS0jonX_n[oZ;oZ
00OoZ;oZ0_nW_n/2ojRojP?o00002?nW_n/2ojJok0GoYko[1OnV`>`01?l0003oY/3/ojK0k?nV`>`2
ojO1k0GoYl3/1onX`>/00onW`NcoZ<3[ojS0j`06ojS0jaKooooo00?o0000ooooooooool0;_ooool0
00Cooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4005
ooooo`;o00001?ooool00ol0003oooooooooo`1Aooooo`goYl7/3onW`>/?ojNojP;oZ;o[3_nX_nX0
0onX`N_oZ<3[ojS0j`07ojS0j`;oZ;oZ1OnX`N`8ojS0j`;oZ;oZ1OnX`N`9ojS0j`;oZ;oZ1OnX`>/7
ojRojP03ojS0jonX_n[o000000;o00001?nX_nX6ojNoj`03ojRoj_nW_n_oYko[00KoYko[1OnV`>`0
0ol0003oY[o[ojJoj`08ojO0k0CoZ<3[1?nW`N`8ojS0jaKooooo00?o0000ooooooooool0;Oooool0
00kooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`1=ooooo`koYl7/3_nW`>/?ojNojPKoZ;o[2_nX_nX5
ojS1j`OoZ<3[00?oYl;/ojS1k?nX`N`01_nX`N`6ojS0j`03ojO2k?nX`NcoZ<7/00KoZ<7/1_nX`>/2
ojS1k0SoZ<3[1?nX_nX2ojS0j`;o00002?nX_nX2ojNoj`GoZ;oZ2?nW_n/2ojK0k0;oY[o[00Co0000
ojJojonV_n_oY[o[2?nW`>`00onX`>_oYl7/ojO1k005ojO1k0OoZ<3[5oooool00ol0003ooooooooo
o`0/ooooo`003oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000001Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04Wooooo3onW`N`=ojO0j`ooYkoZ0_nW
_n/8ojRoj`KoZ;oZ00?oZ<7/ojS1jonX`N/01_nX`N/4ojS0j`CoYl;/2?nX`N`2ojS0j`GoYl;/2?nX
`N`2ojS0j`KoZ<7/2?nX`>/00onX_n[oZ<3[o`000002o`0000?oZ<3[1_nX_nX00onX`>_oZ;oZojRo
jP06ojRojPKoYko[00?oZ;o[ojJojonV_n/00onV_n/00ol0003oY[o[ojJoj`06ojO0k0?oY/3/2?nW
`N`7ojS0jaGooooo0_l0000^ooooo`004?ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o
410@ooooooooool00oooool2o`0000Oooooo00?o0000ooooooooool0A_ooool?ojO1k0coYl3[3onW
_nX6ojNoj`SoZ;o[0_nX_nX5ojS1k0SoZ<7[00?oZ<3[ojO2k?nW`^`01OnW`^`6ojS1k003ojK1k?nW
`^coYl;/00KoYl;/1_nX`N`2ojK1k@SoZ<7/1_nX`>/3o`0000OoZ<3[0_nX_nX5ojS0j`SoZ;oZ0_nW
_n/5ojRoj`GoY[o[00?o0000ojJojonV_n/00_nW`>`7ojK0k0KoYl7/00?oYl3/ojS0jonX`>/01_nX
`>/Fooooo`03o`000?oooooooooo02_ooooo000<ooooo`05o`000?nj^[[ooooooiRHV?l@41000ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`12ooooo`ooYl7/3?nW`>/?ojNojP[oYko[1_nX_n/00onW`^coZ<7/ojS1k006ojS1k0KoZ<7[
0_nW`Nd8ojO2k0;oZ<7/1OnV`N`8ojO2k0;oZ<7/1_nV`Nd8ojS1k0;oZ<3[0ol00003ojS1k0KoZ<3[
00?oZ<7/ojS0jonX`>/01_nX`>/6ojRojP03ojS0jonX_n_oZ;o[00KoZ;o[1OnV_n/00ol0003oYko[
ojNoj`09ojK0k0;oYl7/1OnW`>`8ojS0jaGooooo00?o0000ooooooooool0:oooool000cooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo03kooooo0_nW`>/=ojO1k0;oZ<7[2_nW`>/?ojNojPko
Yko[0_nX_n/5ojO2k0SoZ<7/0_nX`N/6ojO1k@KoYl;/00?oY/3/ojK1k?nV`N`01_nV`N`6ojO2k0;o
Y/3/2?nV`Nd6ojS1k0?o00001onX`N`2ojS0j`GoZ<7/2?nX`>/2ojRojPGoZ<3[2?nX_n/2ojJoj`;o
Yko[00Co0000ojNojonW_n_oYko[1_nV`>`2ojJoj`SoYl3/1onX`>/Fooooo`03o`000?oooooooooo
02[ooooo000Nooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0>_ooool6ojO0j`Wo
Yl7/1_nX`N/6ojO0ja3oYkoZ3onW_n/00onW`^goYl;/ojO2k006ojO2k0KoZ<7/0_nW`N`8ojO1k@;o
Yl;/1OnV`>`8ojK1k0;oYl;/1_nV`>`8ojK1k@;oZ<7/0ol00003ojK1k0KoZ<7/00?oY/3/ojS1k?nX
`N`01_nX`N`6ojS0j`03ojS1k?nX`>_oZ<3[00KoZ<3[1_nX_n/00onX`>[oYko[ojNoj`03ojNoj`04
o`000?nW_n_oYko[ojNoj`;oY/3/1_nV_n/8ojO0k0OoZ<3[5_ooool00ol0003oooooooooo`0Yoooo
o`007Oooool3o`0000_ooooo00?o0000ooooooooool0=_ooool2ojNoj`SoYl3[1OnW`N`2ojS1k0So
Z<7[0onW`>/?ojNojPooYko[1OnW`^d8ojO2k0;oZ<7/1_nW`N`6ojO1k@;oYko[1onV`>`6ojK1k0;o
Yko[2?nV`>`6ojK1k@?o00001onV`N`2ojS1k0GoY/3/2?nX`N`2ojS0j`GoZ<7/2?nX`>/2ojRoj`Go
Z<3Z1OnW_n/00ol0003oYko[ojS0j`08ojJoj`KoYl3/0_nV`>`7ojS0jaKooooo00?o0000oooooooo
ool0:Oooool001gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0booooo`KoYko[
2?nW`>/00onW`NcoZ<7/ojS1k004ojS1k0SoZ<7[00?oYl3[ojNoj_nW_nX02onW_nX?ojNoj`WoYl;]
1_nW`^`2ojO0k0SoYl7/0_nW`Nd6ojNoj`OoY/3/0_nV`N`6ojNoj`SoY/3/0_nV`Nd3o`0000?oY[o[
1_nV`N`00onV_n_oY/3/ojK0k006ojK0k0KoZ<7/00?oY/7/ojS1k?nX`N`01_nX`N`6ojS0j`03ojS1
jonX`>[oZ<3Z00KoZ<3Z1?nW_n/01?nX`>_o0000ojS0jonX`>/8ojJoj`;oYl3/1_nV`>`7ojS0jaKo
oooo00?o0000ooooooooool0:?ooool001gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0_ooooo`WoYko[1_nW`>/9ojS1k0KoZ<7[0_nW_n/:ojNojPooYko[3OnW`^d2ojO2k0KoYl3/
1_nW`N`2ojNojPSoYko[1OnV`>`2ojRnjPSoYko[1_nV`>`3o`0000OoY[o[0_nV`N`5ojJoj`SoY/3/
0_nX`N`5ojK1k0SoZ<7/0_nX`>/5ojS1j`SoZ<3Z00GoYko[ojS0jonX`>_oZ<3[o`000003ojS0j`Ko
Y[o[00?oYko[ojK0k?nV`>`01_nV`>`6ojS0j`03ojO0k?oooooooooo01Gooooo00?o0000oooooooo
ool09oooool001gooooo0_l0000?ooooo`03o`000?oooooooooo02_ooooo3OnW_n/2ojO0j`goZ<7/
0_nX`N/6ojNoj`KoYkoZ3onW_n/?ojO2k@;oYl3[2?nW`>`2ojO1k0KoYkoZ2?nW_n/00onV`>coZ;kZ
ojRnjP04ojRnjPSoYko[0_nV`>`00onX_n[o0000o`000002ojRojPOoY[o[00?oZ;oZojJojonV_n/0
1_nV_n/6ojK0k003ojJojonV`NcoY/7/00KoY/7/1_nX`N`00onV`NcoZ<7[ojS1j`06ojS1j`KoZ<3Z
1_nX`>/01?l0003oZ<3[ojS0jonX`>/2ojJoj`GoYko[2?nV`>`2ojS0j`GoYl3/5_ooool00ol0003o
ooooooooo`0Wooooo`007Oooool00ol0003oooooooooo`0?ooooo`;o0000:?ooool?ojNoj`ooZ<7/
2_nW_n/2ojNojPooYko[3onW`^d6ojO0j`KoYl3/0_nW_^X8ojNojPKoYko[2OnX_^X6ojNoj`04ojRn
j_l0003o0000o`0000GoZ;oZ1?nV_n/4ojRojPSoY[o[0_nV`>`5ojJoj`SoY/7/0_nX`N`5ojK1k0So
Z<7[0_nX`>X:ojS0j`03o`000?nX`>_oZ<3[00SoYko[1_nV`>`00onV_ncoYl3/ojO0k006ojO0k1Ko
oooo00?o0000ooooooooool09_ooool001gooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0Rooooo`ooYko[3onX`N`KojNoj`;oYl;/3OnW`^d:ojO0j`?oYl3/1OnW_^X8ojNojP;oYko[
3OnX_^X2ojNoj`05ojRnj_l0003o0000o`000?nX_^X02?nX_nX00onV_n_oZ;oZojRojP05ojRojPKo
Y[o[00?oZ;oZojJojonV_n/01_nV_n/6ojK1k003ojJok?nV`NcoY/7/00KoY/7/1_nX`N/00onW`Nco
Z<3[ojS0j`0;ojS0j`03o`000?nX`>_oZ<3[00SoYko[0_nV`>`5ojJok0SoYl3/5_ooool00ol0003o
ooooooooo`0Uooooo`007Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01kooooo
3onW_n/2ojO1k0goZ<7/6onW_n/6ojO2k0WoYl;]3_nW`>/00onW`>coYkkZojNnjP05ojNnjPKoYkoZ
00?oZ;kYojRnj_nX_^X03?nX_^X01?nX_n[o0000o`000?l00005ojRnjPKoZ;oZ0_nX_nT8ojRojP;o
Y[o[1OnX_nX8ojJoj`;oY/7/1OnV_n`8ojK1k0;oZ<7[1OnW`N`<ojS0j`04o`000?nX`>_oZ<3[ojS0
j`KoYko[00?oZ<3[ojJok?nV_n`01_nV_n`7ojO0k1Kooooo0_l0000Vooooo`007?ooool3o`0001Co
oooo00?o0000ooooooooool06_ooool?ojNoj`KoYl7/2OnX`N`LojNoj`WoYl;/1_nW`^d?ojO0j`[o
YkkZ0_nW_nX5ojRnj@[oZ;kZ00GoZ;oZo`000?l0003o0000ojRojP08ojRnjP;oZ;oZ1_nX_nT6ojRo
jP03ojVoj_nX_n[oZ;oZ00KoZ;oZ1_nV_n/00onX_n[oY[o/ojJok006ojJok0KoY/7/00?oYKo/ojO1
k?nW`N`01_nW`N`<ojS0j`04o`000?nX`>_oZ<3[ojS0j`;oYko[1OnX`>/8ojJok0OoYl3/5?ooool0
0ol0003oooooo`00000Vooooo`007?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
01Oooooo3onW_n/2ojO0j`OoYl7/1_nX`N`00onX`>_oYko[ojNoj`0HojNoj`goYl;/0_nW`^d?ojO0
j`coYkkZ00?oZ;kZojRnjOnX_^T01_nX_^T6ojRnjP04ojS0jol0003o0000o`0000GoZ;oZ1_nX_^X0
0onY`>_oZ;oYojRoj@07ojRoj@;oZ;oZ1OnY_nX8ojRojP;oY[o[1OnX_nX8ojJok0;oY/7/1OnU_n`8
ojO1k0coZ<3[00?o0000ojS0jonY`>/02?nX`>/6ojJok003ojJojonW`>coYl3/00KoYl3/5_ooool0
0ol0003oooooooooo`0Sooooo`002_ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b
<_o^k^h6ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool04oooool?ojNoj`KoYl3[
1onW`N`2ojS1k0GoZ<3[5_nW_n/00onW`NcoYl;/ojO2k00<ojO2k0ooYl3[3?nW_^X5ojRnjPSoZ;kY
0_nX_^X01OnX`>_o0000o`000?l0003oZ<3[00SoZ;oZ0_nX_^X5ojW0j`OoZ;oY00?oZL7[ojVoj_nY
_nX01_nY_nX6ojRojP03ojVoj_nX_n[oZ;oZ00KoZ;oZ1_nV_n`2ojNoj`OoYKo/1_nW`N`2ojK0k0[o
Z<3[00?oZL3[o`000?nY`>/00_nY`>/8ojS0j`;oY[o/1OnV_n/8ojO0k1Gooooo00?o0000oooooooo
ool08oooool000cooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Ko
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0?ooooo`;oZ<3[3onW_n/8ojO0j`Go
Yl7/0_nX`N`7ojS0ja;oYko[1OnW`N`:ojO2k0ooYl3[3?nW_^X00onX_n[oZ;kZojRnjP06ojRnjPKo
Z;kY00CoZ<;/o`000?l0003o00001OnX`>/6ojRojP03ojS2k?nY`>_oZL3[00KoZL3[1?nX_nT4ojW1
j`SoZKoZ0_nX_nX5ojVojPSoZ;oZ0_nV_n`6ojNoj`OoYKo/0_nW`N`6ojK0k0KoZ<3[00?oZ<7/ojW0
jonY`>/00_nY`>/01?l0003oZL3[ojW0jonY`>/7ojS0j`OoY[o[1_nW`>`2ojJok1Kooooo00?o0000
ooooooooool08_ooool00003ooooool0003o000000Co00001Oooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@41001_ooool2o`0001Wooooo00?o0000ooooooooool03?ooool5
ojS0j`ooYko[2?nW`>/00onW`NcoZ<7/ojS1k004ojS1k0OoZ<3[3_nW_n/2ojO0k0OoYl7/1_nW`^`2
ojS1j`goYl3[3?nW_^X5ojRojPSoZ;kZ0_nX_^T2ojS2k0;o000000?oZ<;/ojS0jonX`>/01_nX`>/2
ojRojPGoZ<;/2?nY`>/00onX_nWoZL7[ojW1j`05ojW1j`KoZKoZ00?oZL7[ojVoj_nY_nX01_nY_nX6
ojRojP03ojVoj_nW_n_oYko[00OoYko[0onU_n`4ojJoj`SoY/3/0_nX`>/5ojS1k0CoZL3[00Co0000
ojW0jonY`>_oZL3[1onX`>/7ojJoj`;oYl3/1_nV_n`Fooooo`03o`000?oooooooooo027ooooo000<
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool02_ooool7ojS0j`ooYko[1_nW`>/9ojS1k0GoZ<3[3?nW
_n/6ojO0k0OoYl7/0_nW`^`6ojS1j`WoYl3[3?nW_^X2ojRoj`OoZ;oZ1_nX_^X00onX`ngoZ<;/o`00
0002o`0000CoZ<;/1_nX`>/2ojO2k@OoZ<;/1_nY`>/2ojO2k@SoZL7[0_nY_nX5ojW1j`SoZKoZ0_nX
_nX5ojVojPOoYko[00?oZ;oZojJojonV_n/01_nV_n/6ojK0k003ojFok?nX`NcoZ<7/00GoZ<7/1OnY
`>/00ol0003oZ<3[ojS0j`07ojS0j`KoY[o[0_nW_n/8ojJok1Gooooo00?o0000ooooooooool08Ooo
ool000cooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Gooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`07ooooo`?oZ<7[1onX`>/?ojNoj`;oYl3[3OnX
`N`00onX`>_oYko[ojNoj`0<ojNoj`SoYl3/1OnW`N`2ojS1k0SoZ<7[1OnW`>/<ojNnjPKoZ;o[1onX
_nX2ojRnjP;oZ<?]0ol00008ojS2k0;oZ<3[1_nW`^d7ojS2k0;oZL3[1_nW`^d6ojW1j`03ojK2kOnY
`N_oZL7[00KoZL7[1_nY_nX00onY`N_oZKoZojVojP06ojVojPCoYko[1?nX_nX8ojJoj`;oY/3/1OnU
_n`7ojS1k0;oZL3[0_nX`>/00ol0003oZ<3[ojS0j`08ojS0j`;oY[o[1_nW_n/7ojJok1Kooooo00?o
0000ooooooooool08?ooool000cooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@00Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`03ooooo`OoZ<7[1OnX
`>/?ojNoj`;oYl7/3OnX`N`AojNoj`SoYl3/00?oYl7/ojS1k?nX`N`01?nX`N`8ojS1j`03ojO0jonW
_^[oYkkZ00[oYkkZ0_nW_n/8ojRoj`GoZ;oZ0_nW`nd3o`0000CoZ<?]1_nX`^`2ojK2k@SoYl;]0onX
`^`4ojG1k@SoYl;]0_nY`N/5ojK2k@SoZL7[0_nY_nX5ojW1j`SoZKoZ00?oYko[ojRoj_nX_nX01OnX
_nX6ojJoj`03ojNojonU_ncoYKo/00GoYKo/1_nX`N`00onW`>coZ<3[ojS0j`03ojS0j`03o`000?nX
`>_oZ<3[00SoZ<3[2?nW_n/7ojJok1Kooooo00?o0000ooooooooool07oooool000cooooo00?o0000
ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_l0000Nooooo`03o`000?oo
ooooZ<7[00[oZ<7[00?oZ<3[ojNojonW_n/03OnW_n/6ojO1k0WoZ<7/5OnW_n/6ojO0k003ojS2k?nX
`NcoZ<7/00KoZ<7/1_nX`N/;ojNnjPKoYko[2?nX_n/00onX_n[oYl?]ojO3k@03o`000003ojO3kOnX
`ngoZ<?]00GoZ<?]0_nX`^`6ojK2k@KoYl;]00?oY[o/ojG1kOnU`Nd01_nU`Nd6ojO2k@03ojG0kOnV
`^goY/;]00KoY/;]1_nY`N/00onW`^goZL7[ojW1j`06ojW1j`KoZKoZ0_nY`>X8ojRojP;oY[o[1OnW
_n/7ojFok0;oZ<7/1OnW`>`5ojS0j`03o`000?nX`>_oZ<3[00SoZ<3[1_nW_n/00onW`>_oY[o/ojJo
k006ojJok1Gooooo00?o0000ooooooooool07oooool000[ooooo00?oEEEEofIVI_l000001?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool07?ooool=ojS1j`koYko[0_nW
`>/8ojO1k0GoZ<7/0onX`>/FojNoj`;oYl3/1OnX`^`8ojS1k0;oZ<7[3?nW_^X9ojNoj`KoZ;o[00Co
Yl?]o`000?l0003o00001OnW`nd5ojS3k@?oY/7/1onV`^d2ojO2k@GoY[o/2?nU`Nd2ojO2k@GoYL3]
2?nV`^d2ojW1j`GoYl;]2?nY`N/2ojVojPKoZL3Z1_nX_nX00onY_n[oYko[ojNoj`05ojNoj`OoYKo/
2?nW`>`5ojS0j`03o`000?nX`>_oZ<3[00SoZ<3[0_nW_n/5ojO0j`SoY[o/5Oooool00ol0003ooooo
ooooo`0Nooooo`006oooool00ol0003oooooooooo`0Jooooo`?oYl3[2OnX`N/>ojNoj`KoYl3[2?nW
`N`00onX`NcoZ<3[ojS0j`05ojS0jaCoYko[2OnX`^`6ojS1k0;oYkoZ2_nW_^X=ojNoj`;oZ;o[00Co
Yl?]o`000?l0003o00002OnW`nd00onX`ngoY/7/ojK1k005ojK1k0GoY/;]00?oYko[ojJok?nV_n`0
1_nV_n`6ojG1k@03ojJojonU`>goYL3]00KoYL3]1_nV`^d2ojFok@OoYl;]1_nY`N/2ojS2k0SoZL3Z
0_nX_nX5ojVojPOoYko[1onU_n`8ojO0k0CoZ<3[00?o0000ojS0jonX`>/01onX`>/00onY`>_oYl3[
ojO0j`06ojO0j`OoY[o/5_ooool00ol0003oooooooooo`0Mooooo`006oooool00ol0003ooooooooo
o`0Gooooo`OoYl3[1onX`N/?ojNoj`OoYl3[1_nW`N`2ojS1k0SoZ<3[4?nW_n/=ojS2k0;oZ<7/1_nW
_nX7ojNnjPkoYko[00CoYl?]o`000?l0003o00002onW`nd2ojO0k0SoY/7/00?oY/;]ojNojonW_n/0
0onW_n/8ojJok0;oYL7]1OnV_n/8ojG0k@;oY/;]1_nU_nd7ojO2k@;oZL7[1_nX`^`6ojW0jP03ojW1
jonY_n[oZKoZ00GoZKoZ1_nW_n/2ojS0j`OoYKo/1_nW`>`2ojK0k0CoZ<3[00?o0000ojS0jonX`>/0
0onX`>/5ojW0j`SoYl3[1onV_n`Dooooo`;o00007oooool001_ooooo0_l0000Fooooo`?oYko[1onW
`>/7ojS1j`ooYko[1onW`>/2ojO1k0KoZ<7/1_nX`>/?ojNoj`03ojO1k?nX`^coZ<;/00_oZ<;/0onW
_n/7ojNojPOoYkkZ2_nW_n/2ojO3k@;o00002onW`nd6ojO0k0KoY/7/00?oYkkYojNojonW_n/01OnW
_n/6ojJok003ojRnjOnV_n_oY[o[00KoY[o[1_nU`>d2ojNoj`SoYKo]0onW`^d4ojC0k@SoZ<;/0_nY
`>X5ojW1j`OoZKoZ0_nW_n/6ojS0j`OoYKo/0_nW`>`6ojK0k0CoZ<3[00?o0000ojS0jonX`>/02?nY
`>/7ojO0j`OoY[o/5_ooool00ol0003oooooooooo`0Looooo`006_ooool00ol0003oooooooooo`0C
ooooo`OoYko[1OnW`>/9ojS1j`ooYko[1OnW`>/:ojS1k0;oZ<3[3onW_n/5ojO1k0WoZ<;/1onW_n/5
ojNojPWoYkkZ1_nW_n/00onX`ngoYl?]o`000002o`0000[oYl?]0_nW`>/8ojO0k0;oY/7/1OnW_^T7
ojNoj`;oY[o/1OnX_^T8ojJoj`;oYL3]1_nW_n/6ojFok@03ojJojonT`>goY<3]00KoY<3]1_nX`^`0
0onU`NgoZL7[ojW1j`05ojW1j`KoZKoZ00?oZL3ZojS0jonX`>/01onX`>/3ojFok0CoY[o[2?nV`>`4
ojS0j`03o`000?nX`>_oZ<3[00SoZL3[1onW`>/7ojJok1Gooooo00?o0000ooooooooool07?ooool0
01[ooooo00?o0000ooooooooool03oooool<ojNoj`03ojO0jonX`N_oZ<7[00_oZ<7[3onW_n/00onW
`>_oZ<7/ojS1k00:ojS1k0ooYko[0_nW`>/7ojO1k0KoZ<;/0_nX`>/8ojNoj`03ojNoj_nW_^[oYkkZ
00_oYkkZ0_nW_n/2ojS3k@?o00002_nW`nd6ojO0j`KoYl3/00?oZ;gYojNnjOnW_^T01_nW_^T5ojNo
j`;oZ;gX1onX_^T6ojJoj`;oZ;gY2?nW_n/2ojFok@GoY[o[2?nT`>d2ojS2k0GoYL7]1onY`N/2ojVo
jPGoZL3Z1onX`>/00onY`>[oY[o[ojJoj`06ojJoj`KoY/3/00?oYKo/ojS0jonX`>/00_nX`>/00ol0
003oZ<3[ojS0j`08ojW0j`OoYl3[2?nV_n`Eooooo`03o`000?oooooooooo01_ooooo000Jooooo`03
o`000?oooooooooo00_ooooo3onW_n/00onW`>_oZ<7[ojS1j`0;ojS1j`ooYko[0onW`>/8ojS1k0oo
Yko[1_nW`>/7ojO1k0;oZ<;/1_nX`>/6ojNoj`koYkkZ0_nX`nd3o`0000CoZ<?]1_nW`nd:ojO0j`;o
Yl3/1OnX_NT8ojNnj@03ojNojonX_NSoZ;gX00CoZ;gX1onX_^T2ojJoj`KoZ;gY1_nW_n/00onX_^Wo
Y[o[ojJoj`06ojJoj`KoY<3]00?oYKo/ojG1kOnU`Nd01OnU`Nd6ojW1j`03ojO1k?nY`>[oZL3Z00Ko
ZL3Z1?nX`>/4ojW0jPSoY[o[0_nV`>`5ojFok0CoZ<3[00?o0000ojS0jonX`>/02?nY`>/7ojO0j`So
Y[o/5Oooool00ol0003oooooooooo`06ooooo`Go00003oooool001[ooooo0_l00009ooooo`ooYko[
1OnW`>/9ojS1j`ooYko[1onW`>/5ojS1k0;oZ<7[3_nW_n/8ojO0j`GoYl7/0onX`N`7ojS0j`;oYko[
3_nW_^X2ojS3k@?o00002?nX`nd2ojO3k@coYl3[00?oYkgYojRmjOnX_NT01_nX_NT6ojNnj@03ojVm
j?nX_NSoZ;gX00KoZ;gX1OnX_^T2ojVnj0SoZ;gY0_nW_n/5ojRnj@SoY[o[0_nT`>d5ojFok0OoYL7]
0_nY`N/5ojO1k0SoZL3Z00?oZ<3[ojW0j_nY`>X01OnY`>X6ojJoj`03ojNojonU_ncoYKo/00GoYKo/
1OnX`>/00ol0003oZ<3[ojW0j`07ojW0j`SoYl3[2?nV_n`Dooooo`03o`000?oooooooooo00Kooooo
00GoV9RHob4Q8Oo^k^koooooodA4A00?ooooo`006_ooool00ol0003oooooooooo`06ooooo`;oZ<3[
3_nW_n/7ojO0j`WoZ<7[3_nW_n/8ojO0j`03ojS1k?nX`N_oZ<7[00CoZ<7[3_nW_n/8ojO0j`03ojO1
k?nX`NcoZ<7/00GoZ<7/1OnX`>/?ojNnjP04ojO1k?l0003o0000o`0000[oZ<?]0onX`>/9ojO0j`Go
YkgY2?nX_NT2ojNnj@GoZKgX2?nX_NP00onX_^WoZKkXojVnj004ojVnj0KoZ;gY00?oZ[oXojRnjOnX
_^T01_nX_^T6ojJoj`03ojRnjOnU_ncoYKo/00KoYKo/1OnU`Nd2ojBok0OoYl7/1_nY`>X2ojW1jPSo
ZL3Z0_nV_n/5ojNoj`OoYKo/1?nX`>/00ol0003oZ<3[ojS0j`08ojW0j`SoYl3[1onV_n`Eooooo`03
o`000?oooooooooo00Kooooo00?oV9RHob4Q8Oo^k^h04?ooool001[ooooo00?o0000ooooooooool0
0oooool6ojS0j`koYko[1onW`>/9ojS1j`koYko[1_nW`>/00onX`NcoZ<7[ojS1j`06ojS1j`koYko[
1_nW`>/2ojS2k0SoZ<7/00?oZ<3[ojNnj_nW_^X03OnW_^X01OnW`Nco0000o`000?l0003oYl7/00Wo
Z<?]1onX`>/5ojO0j`WoYkgY1_nX_NT00onX_^WoZKgXojVmj006ojVmj0KoZ;gX00?oZL;[ojVnj?nY
_^P01_nY_^P2ojRmj@GoZ[oX2?nX_^T2ojJoj`GoZ;kY2?nU_n`00onU`NgoY;o/ojBok004ojBok0Oo
Yl7/0_nY`>X6ojW1jPOoZL3Z1onW_n/7ojFok0GoZ<3[00?o0000ojS0jonX`>/02?nY`>/8ojO0j`Oo
Y[o/5Oooool00ol0003oooooooooo`06ooooo`03oiRHV?lQ8B7ok^k^00oooooo000Jooooo`03o`00
0?oooooooooo00[oZ<3[3_nW_n/5ojO0j`_oZ<7[3_nW_n/2ojO0j`GoZ<7/2?nX`N/>ojNoj`;oYl3[
1_nX`^`6ojS1k003ojNojonW_^[oYkkZ00_oYkkZ00CoYko[o`000?l0003o00001OnW`N`6ojS3k@;o
Z<7/2?nX`>/00onW`>_oYkgYojNmj@0;ojNmj@;oZ;gY1OnX_^T8ojVmj0;oZ;gX1OnY`^/6ojVnj003
oj[4kOnZ_nSoZ[oX00KoZ[oX1_nX_^T00on[_nSoZ;kYojRnj@06ojRnj@KoYKo/00?oYko[ojBok?nT
_n`01_nT_n`3ojO1k0CoY/3/2?nY`NX7ojW0jPOoYko[1onU_n`5ojS0j`03o`000?nX`>_oZ<3[00So
ZL3[1onW`>/7ojJok1Gooooo00?o0000ooooooooool01oooool00omgMgOoIVIVooooo`0>ooooo`00
6Oooool00ol0003oZ<3[ojS0j`0<ojS0j`koYko[00?oYl3[ojS1jonX`N/02onX`N/>ojNoj`;oZ<7[
1onX`N`6ojS1j`koYko[0onX`N`7ojS2k0;oZ<7/1OnW_n/9ojNnjP04ojNojol0003o0000o`0000?o
Yko[1_nW`N`2ojS3k@KoZ<7/1_nX`>/>ojNmj@03ojRoj_nX_^WoZ;kY00KoZ;kY1_nY_NP2ojW4k@Oo
ZL;[0onY_^P4oj[4k@SoZ[oX0_nX_^T5oj^oj0SoZ;kY0_nU_n`5ojNoj`KoY;o/00?oYKo/ojK0k?nV
`>`01_nV`>`6ojW1jP03ojW1jonY`>[oZL3Z00KoZL3Z1OnW_n/2ojO0j`OoYKo/1OnX`>/00ol0003o
Z<3[ojS0j`08ojW0j`OoYl3[1onV_n`Eooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool03Oooool001Wooooo00?o0000ojS0jonX`>/02onX`>/>ojNoj`?oZ<3[2OnX`N/>ojNoj`KoZ<7[
1onX`N`2ojS1j`koYko[1onX`N`5ojS2k0;oZ<3[1onW_n/6ojNnjP03ojJnj_l0003o000000OoYko[
0onW`N`4ojS2k0OoZ<7/0_nX`>/>ojNmj@GoZ;oZ2?nX_^T2ojVmj0KoZLC]1onY`^/00onY_^SoZ/C]
oj[4k@04oj[4k@KoZ[oX00?oZ/C]oj^oj?n[_nP01_n[_nP6ojRnj@;oZ[oY1onW_n/2ojBok0GoYKo/
2?nV`>`2ojW1jPGoZL7[2?nY`>X00onW_n_oYl3[ojO0j`04ojO0j`OoYKo/1?nX`>/01?l0003oZ<3[
ojS0jonX`>/6ojW0j`03ojW1jonW`>_oYl3[00GoYl3[1_nV_n`2ojJoja?ooooo0ol00004ooooo`05
o`000?nj^[[ooooooiRHV?l@41003oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06oooo
o`03o`000?ooooooZ<3[00SoZ<3[3_nW_n/7ojS0j`GoZ<7[0_nX`>/?ojNoj`OoZ<7[1OnX`N`3ojS0
j`koYko[2?nX`N`00onX`^coZ<3[ojS0j`04ojS0j`OoYko[0_nW_^X01?nV_^[o0000o`000?l00002
ojJnjPKoYko[00?oZL?]ojS2k?nX`^`01_nX`^`5ojS1k003ojNnj_nW_NWoYkgY00coYkgY00?oYko[
ojRoj_nX_nX01OnX_nX6ojRnj@;oYl?^2?nYa>d3ojW2j`CoYL7^1onZa>d2ojZoj0GoZ/C]2?n[_nP2
ojRnj@KoZ[oY1OnW_n/00onX_n[oYKo/ojFok006ojFok0KoY/3/00?oY;o]ojW1jonY`N/01_nY`N/6
ojW0jP03ojW1j_nW`>_oYl3[00KoYl3[1onU_n`4ojS0j`04o`000?nX`>_oZ<3[ojS0j`;oZL3[1OnY
`N/7ojO0j`;oY[o/1_nV_n/Dooooo`03o`000?oooooooooo00;ooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c00?ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0
2?nX`>/<ojNoj`?oYl3[1onX`>/00onX`N_oZ<3[ojS0j`04ojS0j`ooYko[1onX`N/00onX`NcoZ<3[
ojS0j`05ojS0j`GoYko[0_nV_n/7ojNoj`KoZ<7/0_nY`^`7ojS0j`GoYko[00CoY[kZo`000?l0003o
00001_nV_^X2ojNoj`GoZL?]2?nX`^`00onX`NcoYkkZojNnjP03ojNnjP[oYkgY1OnW_n/7ojRojP;o
Z;kY1_nW`nh6ojW4k@03ojFljOnU`NkoYL7^00KoYL7^1OnZa>d2oj>nk@OoZ/C]1_n[_nP2oj_3j`So
Z[oY00?oYko[ojRoj_nX_nX00onX_nX8ojFok0;oY/3/1OnT_nd8ojW1j`;oZL3Z1OnY`NX7ojO0j`So
YKo/1?nX`>/00ol0003oZ<3[ojS0j`07ojW1j`SoYl3[2?nV_n/Dooooo`03o`000?oooooooooo01Go
oooo000>ooooo`05oa0@4?ooooooooooooooool@41001_ooool2o`0000;ooooo2?nX`>/8ojNoj`Oo
Yl3[1OnX`>/2ojS1j`OoZ<3[3onW_n/8ojS1j`OoZ<3[00?oYko[ojJojonV_n/01?nV_n/7ojNoj`;o
Z<7/1_nY`^`7ojS0j`03ojNojonV_^[o000000;o00002?nV_^X2ojS2k0OoZL?]1_nX`^`00onW_n_o
YkkZojNnjP05ojNnjPKoYkgY0_nW_^X7ojNoj`GoZ;oZ0onV`nh7ojO3kP;oZLC]1OnU_>T8ojG1kP03
oj[4kOnS_^goXkk]00CoXkk]1onZa>d2oj^oj0KoZl?[1_nZ_nT00on[`>WoZ;oZojRojP05ojRojPKo
YKo/0_nV_n/7ojBok@KoZL7[00?oZ<7[ojW1j_nY`NX01_nY`NX7ojO0j`SoYKo/1?nX`>/00ol0003o
Z<3[ojS0j`07ojW1j`SoYl3[1onV_n/Eooooo`03o`000?oooooooooo01Cooooo000>ooooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooooooo`03ooooo`OoZ<3[2?nW_n/7ojO0j`03
ojS0jonX`N_oZ<7[00CoZ<7[1onX`>/?ojNoj`SoZ<7[1OnX`>/2ojNoj`OoY[o[1OnW_n/3ojS2k0Oo
ZL;/0onX`>/2ojNnj`?o00002?nV_^X6ojS2k0OoZL?]0_nX`^`5ojNoj`OoYkkZ0_nW_NT6ojNnjPOo
Yko[00?oZ;oZojK3k_nV`nh01OnV`nh5ojO3kP03ojNgi?nU_>WoYKcY00KoYKcY1_nU`Nh2ojJgi0Oo
Xkk]0onZa>d4oj>ok@SoZl?[0_nZ_nT5oj_0j@OoZ;oZ0_nU_n`6ojJoj`OoY;o]0_nY`N/5ojS1j`Ko
ZL7Z00?oZL7[ojO0jonW`>/01_nW`>/7ojFok0CoZ<3[00?o0000ojS0jonX`>/02?nY`N/8ojO0j`Oo
Y[o[5?ooool00ol0003oooooooooo`0Dooooo`003_ooool01Ol0003ooooooooooooooooo000000Go
oooo00?o0000ooooooooool01Oooool5ojS0j`[oYko[1OnW`>/2ojS0j`OoZ<7[1OnX`>/=ojNoj`co
Z<7[00?oZ<3[ojNojonW_n/01?nW_n/7ojJoj`03ojNojonX`^coZ<;/00GoZ<;/1OnY`^`2ojNoj`04
ojNnjol0003o0000o`0000?oYkk[1_nV_^X00onW_n_oZ<;/ojS2k006ojS2k0GoZL?]0_nX`>/7ojNo
j`GoYkkZ0onV_>T7ojNnjP?oYko[1?nW`nd8ojK3kP03ojO3k_nW]nCoYkOT00?oYkOT2?nU_>T2ojG1
kPKoY[OT1OnS_^d00onW^>GoXko]oj>ok@06oj>ok@KoZl?[00?oY/7]oj_0jOn[`>T01On[`>T6ojRo
jP;oZ/3Y2?nV_n/3ojBok@?oY;o/2?nX`N/2ojW1jPGoZL7[2?nW`>/7ojFok0CoZ<3[00?o0000ojS0
jonX`>/02?nY`N/7ojO0j`OoY[o[5Oooool00ol0003oooooooooo`0Cooooo`003_ooool01Ol@413o
oooooooooooooooo410@00Gooooo00?o0000ooooooooool01_ooool00onX`>_oYko[ojNoj`0<ojNo
j`03ojO0jonX`>_oZ<3[00CoZ<3[1onX`N/00onX`>_oYko[ojNoj`0<ojNoj`goZ<7[00?oYl3[ojNo
jonW_n/01_nW_n/5ojJoj`;oYko[2?nX`^`01?nY`^coYko[ojNojonW_n/3o`0000OoYkk[0_nV_^X5
ojNoj`SoZ<;/00?oZL?]ojS0jonX`>/01?nX`>/7ojNoj`03ojNnj_nV_>WoY[cY00GoY[cY1OnW_^X0
0onXa>koYl?]ojO3k@06ojO3k@KoY/?^00?oYk?QojNgi?nW]n@01OnW]n@6ojFlj@03ojV]f_nV]nCo
Y[OT00OoY[OT00?oXkk]ojNhiOnW^>D00onW^>D8oj>ok@;oZl?[1OnV`Nd7oj_0j@;oZ;oZ1_nZ`>T6
ojJoj`03ojNojonT_ncoY;o/00GoY;o/1_nX`N/00onX`>_oZL7[ojW1j`06ojW1j`OoYl3[1onU_n`5
ojS0j`03o`000?nX`>_oZ<3[00SoZL7[1onW`>/7ojJojaGooooo00?o0000ooooooooool04_ooool0
00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o00002?ooool?ojNoj`OoZ<3[1OnX`N/3
ojS0j`koYko[2OnX`N/5ojO0j`SoYko[00?oY[o[ojNojonW_n/01?nW_n/6ojS2k003ojW1jonW_n_o
000000;o00001?nW_n/5ojNnj`;oY[k[1onW_n/6ojS2k0;oZL;/1onX`>/3ojNoj`coY[cY00?oYkkZ
ojS4k_nXa>h00onXa>h8ojO3k@;oY/?^1OnW/n47ojNgi0;oYKcY1OnY[MX7ojJgi003ojf[e_nW^>Go
YkSU00GoYkSU1_nS_nd2ojFkj@OoY/7]1On[`>T2oj_2jPSoZ/3Y0_nV_n/5ojNoj`OoY;o/0_nX`N/5
ojS0j`SoZL7[1onW`>/7ojFok0CoZ<3[00Co0000ojS0jonX`>_oZ<3[1onY`N/7ojO0j`OoY[o[5Ooo
ool00ol0003oooooooooo`0Booooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o
0000ooooooooool02?ooool?ojNoj`OoZ<3[00?oZ<7[ojS0jonX`>/01OnX`>/>ojNoj`SoZ<7[1_nW
`>/6ojNoj`;oY[o[1onW_n/2ojS2k0?oZL7[0_l00008ojNoj`03ojNnjonV_^_oY[k[00CoY[k[1onW
_n/2ojS2k0KoZL;/1OnX`>/2ojNmjPgoY[cY2?nXa>h6ojO3k@WoYk?Q1OnW]n@00onXX]3oZJgJojV]
fP06ojV]fPCoY[OT1?n]ZmH7ojNhi@;oXko]1_nU^nT7ojK1k@03oj_0jOn[`^[oZl;Z00CoZl;Z1_nZ
`>T00on[`N[oYko[ojNoj`06ojNoj`GoY;o/00?oY;k/ojS0jonX`>/01_nX`>/7ojW1j`SoYl3[1onU
_n`4ojS0j`04o`000?nX`>_oZ<3[ojS0j`OoZL7[1onW`>/7ojJojaGooooo00?o0000ooooooooool0
4Oooool001Sooooo00?o0000ooooooooool02Oooool?ojNoj`?oZ<3[1?nX`N/8ojS0j`koYko[2?nX
`N/6ojO0j`;oYko[1_nV_n/5ojNoj`;oZL;/00CoZL7[o`000?l0003o00000onY`N/6ojNoj`WoY[k[
1OnW_n/2ojW3k0SoZL;/00?oZ<3[ojNmj_nW_NX01?nW_NX9ojJlj@coZ<C^0_nW`nd=ojNch@03ojNg
i?nXX]3oZ:;@00?oZ:;@2?nY[MX00onV]nCo[J_Fojf[eP05ojf[ePGoYkSU00?o[kCLojFkjOnU^nT0
1onU^nT3ojK1k@CoXko]1on[`^X2oj[0j@GoZl7Z2?nW_n/00onT_ncoY;k/ojBnk003ojBnk0SoZ<3[
1onY`N/7ojO0j`SoYKo/1?nX`>/00ol0003oZ<3[ojS0j`07ojW1j`OoYl3[2?nV_n/Eooooo`03o`00
0?oooooooooo013ooooo000Hooooo`03o`000?oooooooooo00[ooooo3OnW_n/2ojS0j`OoZ<7[1_nX
`>/>ojNoj`[oZ<7[0onW`>/;ojJoj`04ojNojonY`^coZL;/ojW2k0?o00001onY`N/2ojNoj`goY[k[
00?oYko[ojW3k?nY`n`01?nY`n`6ojW2k003ojNojonW_N[oYkgZ00KoYkgZ1OnV_>T2ojK0k0coZ<C^
0_nW]n@=ojNch@03ojJLc?nXX]3oZ:;@00GoZ:;@1_nY[MX00on^WlSo[J_Fojf[eP07ojf[eP03ojNh
iOn_]=co[kCL00?o[kCL1onU^nT00on[_>KoXko]oj>ok@06oj>ok@GoZl;Z00?oZ/7[oj_1j_n[`NX0
1_n[`NX6ojNoj`03ojO0jonT_^coY;k/00GoY;k/2?nX`>/7ojW1j`OoYl3[2?nU_n`4ojS0j`03o`00
0?nX`>_oZ<3[00OoZL7[1onW`>/6ojJoj`03ojNojooooooooooo01?ooooo0_l0000Aooooo`005ooo
ool3o`0000gooooo2?nW_n/6ojS0j`OoZ<7[0_nX`>/>ojNoj`coZ<7[0_nW`>/<ojJoj`;oYko[0ol0
0004ojW2k0GoZL7[0onW_n/<ojJnj`;oYl7/1onY`n`2ojW2k0GoYko[2?nW_NX00onV_>WoY/3/ojK0
k004ojK0k0SoZ<C^1_nW]n@9ojNch@GoYYc<1_nXX]04ojV]fPCo[Yo81on]ZmH00onfZ<_o[kCLojnd
g005ojndg0CoYK_Y1?n[_>H8oj>ok@03oj_2j_nZ`N_oZ/7[00?oZ/7[2?n[`NX2ojNoj`GoYl3[1onT
_^`8ojS0j`KoZL7[2?nW`>/6ojFok003ojFojonX`>_oZ<3[00;oZ<3[00Co0000ojS0jonX`>_oZ<3[
0onY`N/4ojS1j`OoYl3[0_nV_n/5ojNoja?ooooo00?o0000ooooool000004Oooool001Oooooo00?o
0000ooooooooool03_ooool7ojNoj`OoZ<3[2?nX`N/>ojNoj`WoZ<7[1_nW`>/8ojJoj`;oYko[0ol0
00000onW_n_oZL;/ojW2k005ojW2k003ojW1jonW_n_oYko[00GoYko[2?nV_^/6ojO1k0GoZL?/0_nX
`N/7ojNoj`KoYkgZ0_nU_>X7ojK0k0?oZ<C^0onX_NP8ojNgi0GoYk?Q00?oXi_=ojJLc?nVW<`01OnV
W<`7ojRRd003ojV]f_n^WlSo[Yo800Go[Yo81On]ZmH3okJXb`Oo[kCL00?oYK_Yoj^li_n[_>H01On[
_>H6oj>ok@03oj>nk?nZ`N_oZ/7[00GoZ/7[2?n[`NX7ojO0j`OoY;k/2?nX`>/6ojW1j`SoYl3[0_nU
_n`5ojFoj`CoZ<3[00?o0000ojS0jonX`N/02?nX`N/5ojO0j`03ojJojonW_n_oYko[00KoYko[5?oo
ool00ol0003oooooooooo`0?ooooo`005oooool00ol0003oooooooooo`0?ooooo`OoYko[1onX`>/8
ojS1j`koYko[1_nX`N/00onY`N_oYl3[ojO0j`06ojO0j`KoY[o[0ol00005ojNoj`GoZL;/0_nY`N/8
ojNoj`OoY[k[1onW`N`00onY`ncoZ<7[ojS1j`04ojS1j`OoYko[0_nW_NX6ojFljPGoY/3/0_nY`n`6
ojRmj0SoYkOT00?oYk?Qoj>KcOnSVld00onSVld7ojJLc0GoZ:;@00?o/9g4ojjOb?n^WlP01_n^WlP3
ojf[ePKo]ZS;1On_]=`2okNbe0SoZkcV0_nS_nd5oj>nk0OoZ/7[2?n[`NX6ojO0j`SoY;k/1onX`>/7
ojW1j`OoYl3[2?nU_n/2ojS0j`;oZ<7[00?o0000ojS1jonX`N/02?nX`N/00onW`>_oY[o[ojJoj`03
ojJoj`SoYko[5?ooool00ol0003oooooooooo`0>ooooo`005oooool00ol0003oooooooooo`0@oooo
o`OoYko[1OnX`>/:ojS1j`?oYko[1?nV_n/7ojNoj`;oZ<7[1OnY`N/8ojO0j`;oY[o[0ol00002ojJo
j`OoYko[00?oZL;/ojW1jonY`N/01?nY`N/6ojNoj`WoY[k[1OnW`N`2oj[3k0OoZ<7[1OnW_n/:ojFl
jP03ojK0k?nY`ncoZL?/00CoZL?/1_nX_NP6ojNgi003oj6Nd_nSVlgoXi_=00CoXi_=1onVW<`3ojRR
d0Co/9g42?n^WlP00on]ZmKo]ZS;okJXb`05okJXb`?o[kCL1Ong/]@6oj^liP;o/KoT1_nS_^`6oj[1
j`;oZ<3[2?n[`NX6ojO0j`SoY;k/1onX`>/7ojW1j`OoYl3[1_nU_n/00onV_n_oZ<7[ojS1j`03ojS1
j`03o`000?nX`N_oZ<7[00OoZ<7[1onV_n/7ojNojaGooooo00?o0000ooooooooool03Oooool001Oo
oooo0_l0000Booooo`OoYko[00?oZ<3[ojS1jonX`N/02_nX`N/2ojNoj`OoY[o[1OnW_n/3ojS0j`Ko
ZL7[1_nW`>/3o`0000KoY[o[0onW_n/4ojW2j`OoZL7[0_nW_n/=ojJnj`03ojO1k?nZ`ncoZ/?/00Co
Z/?/1onX`N/00onW_n_oYKcZojFljP0:ojFljP03oj[4kOnY`ncoZL?/00KoZL?/1_nX_NP2ojNgi0Go
XIkB1_nSVld7ojJLc003ojRRd?n`WLCo/9g400?o/9g41on^WlP00onkZ<Ko]ZS;okJXb`07okJXb`03
ojndg?ng/]Co]k;D00Go]k;D0_n[_>H6ok6oi0KoXkk/0_nZ`N/6ojS0j`KoZl7Z00?oZl;ZojO0jonW
`>/01OnW`>/7ojBnk0SoZ<3[1onY`N/7ojO0j`;oYKo[1OnV_n/4ojS1j`03o`000?nX`N_oZ<7[00So
Z<7[1onV_n/7ojNojaCooooo00?o0000ooooooooool03Oooool001Oooooo00?o0000ooooooooool0
4_ooool5ojNoj`?oYl3[2?nX`N/6ojNoj`OoY[o[00?oYko[ojS0jonX`>/01OnX`>/6ojW1j`;oYl3[
00?oY[o[o`000?l000002?nV_n/2ojNoj`OoZL;[1OnY`N/2ojNoj`goY[k[0_nX`N/7oj[3k0?oZ<7[
1?nV_n/9ojFljPGoZ/C]2?nY`n`3ojRmj0;oXJ[M1onQW]86oj>Kc@KoYYc<00?oZY[6ok2Ma?n`WL@0
1On`WL@5ojjOb0?o^jS61onfZ</00oo5/lSo]k;DokNbe006okNbe0Wo/KoT0onS_^`3ojBok0SoZ<3[
0_n[`NX5oj_2jPOoYl3[1onT_^`6ojS0j`WoZL7[1OnW`>/00onV_ncoY[o[ojJoj`06ojJoj`CoZ<7[
00?o0000ojS1jonX`N/02?nX`N/6ojJoj`SoYko[5?ooool00ol0003oooooooooo`0<ooooo`005ooo
ool00ol0003oooooooooo`0Cooooo`03ojNojonW`>_oYl3[00GoYl3[1onX`N/7ojNoj`GoY[o[0onW
_n/7ojS0j`?oZL7[0_nW`>/3o`0000OoY[o[1_nW_n/7ojW2j`03ojW1jonW_n_oYko[00CoYko[2OnV
_^/6ojS1j`GoZ/?/0_nX`N/7ojJoj`GoYKcZ0onU_N/6oj[4k@KoZL?/00?oXkGVoj6ZgOnQZ]d01?nQ
Z]d7oj6NdPGoXi_=1?nVW<`4ojZJaPKo/9g40on^WlP5ok^XaPKo]ZS;0oo5/lP6okNbe0;oaKgC1ona
_n@00onfaNGoY;o/ojBok005ojBok0KoZ<3[0_nX_nX7oj_2jPOoYl3[1onT_^`2ojS0j`goZL7[00?o
Yl3[ojJok?nV_n`00onV_n`8ojJoj`CoZ<7[00?o0000ojS1jonX`N/01_nX`N/00onX`>_oY[o[ojJo
j`05ojJoj`KoYko[00?oZ<3[ooooooooool04oooool00ol0003oooooooooo`0;ooooo`005oooool0
0ol0003oooooooooo`0Eooooo`OoYl3[1onX`N/7ojNoj`03ojJojonW_n_oYko[00GoYko[1OnX`>/2
ojW1j`04ojO0jol0003o0000o`0000?oYl3[1onV_n/7ojNoj`GoZL;[0onY`N/6ojNoj`SoY[k[1onX
`N/00onZ`ncoZ<7[ojS1j`04ojS1j`OoY[o[00?oYKcZojFmjonU_N/01OnU_N/6oj[4k@;oZL?/1OnS
]NH6oj6Zg@KoXIkB1_nSVld00onVW<coZY[6ojZJaP04ojZJaPOo/9g400?o[Yo8ok^Xa_nkZ<H01Onk
Z<H4okJXb`GoaK?81?ng/]@4olFmd`Co/KoT1?nfaND7ojBok0;oZ<3[1_nX_nX5oj_2jP03oj_2jonW
`>_oYl3[00KoYl3[1OnT_^`00onT_^_oZL7[ojW1j`0<ojW1j`03ojS1jonV_ncoY[o/00GoY[o/1_nV
_n/00onW_n_oZ<7[ojS1j`03ojS1j`03o`000?nX`N_oZ<7[00;oZ<7[1OnX`>/7ojJoj`;oYko[1OnX
`>/Dooooo`03o`000?oooooooooo00_ooooo000Fooooo`?o00005oooool5ojO0j`?oZ<3[1_nX`N/5
ojNoj`?oY[o[1onW_n/01?nX`>_oZL7[ojW1jonY`N/3o`0000OoYl3[1onV_n/7ojNoj`03ojW2jonY
`N_oZL7[00GoZL7[1_nW_n/8ojJnj`GoZ<7[0_nZ`n`7ojS1j`GoY[o[0_nT_>X8ojFmj`?oZ/C]0_nX
`>/8oj>eiPGoXJ[M1onQW]83oj>Kc@;oXYK82?nZV/H5ok2Ma003okRZbonkZ<Ko^jS600Ko^jS60onf
Z</6olFcb0?o]k;D1_o5_M<00ona_nCo]/GUokK5i@05okK5i@OoY;o/2?nX_nX00on[`^[oZl;[oj_2
j`03oj_2j`SoYl3[00?oY;k/ojBnjonT_^/00onT_^/:ojW1j`GoZ<7[1onV_n`2ojJoj`GoYko[1?nX
`N/00ol0003oZ<7[ojW1j`07ojS0j`SoY[o[1onX`>/Dooooo`03o`000?oooooooooo00[ooooo000F
ooooo`03o`000?oooooooooo01Sooooo00?oYl3[ojS0jonX`>/01OnX`>/6ojS1j`03ojNojonV_n_o
Y[o[00GoY[o[1OnW_n/00onX`>_oZL7[o`000002o`0000CoZL7[1OnW`>/9ojJoj`GoYko[2_nY`N/3
ojNoj`_oY[k[00?oZ<7[oj[3k?nZ`n`01?nZ`n`7ojS1j`03ojJojonT_>[oY;cZ00CoY;cZ1_nU_N/0
0on[a>coZ<3[ojS0j`04ojS0j`OoXkGV1_nQZ]d3oj6NdP?oV97;1_nRU/P7ojZJaPCo/9g40onhZ//8
ok^XaP03okJXboo5/lSoaK?800KoaK?800?o]k;DolFmdoo5_M<01Oo5_M<00oo>b]Ko]/GUokK5i@06
okK5i@OoY;o/1_nX_nX00onZ`>[oZl;[oj_2j`05oj_2j`KoYl3[00?oY[o/ojBnjonT_^/01OnT_^/7
ojW1j`SoZ<7[0onV_n`3ojFnj`SoYko[0_nX`N/2ojW1j`03o`000?nY`N_oZL7[00OoZ<3[2?nV_n/6
ojS0ja?ooooo0ol0000;ooooo`001?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b
<_o^k^h6ooooo`03o`000?oooooooooo01[ooooo1onX`>/3ojS1j`CoYl3[1onV_n/00onW_n_oZ<3[
ojS0j`03o`0000SoZL7[00?oYl3[ojJojonV_n/02onV_n/00onW_n_oZL7[ojW1j`0:ojW1j`03ojNo
jonV_^_oY[k[00_oY[k[0_nX`>/7oj[3k0?oZ<7[1?nV_n/7ojBljP;oYKg[1On[a>`6ojS0j`OoXkGV
0onQZ]d2oi2@d0OoV97;1OnRU/P7ojZJaP?o/9g41?nhZ//7ok^XaP03olBfcOo5/lSoaK?800KoaK?8
00?ocKo<olFmdoo5_M<01Oo5_M<3olk:ePKo]/GU00?o]/WXojBok?nT_n`01_nT_n`2ojRojPGoZ/3Z
1on[`^/2ojO0j`GoY[o/1onT_^/7ojW1j`OoZ<7[1onU_^/6ojNoj`;oZ<3[1?nY`N/00ol0003oZL7[
ojW1j`03ojS0j`CoYl3[2?nV_n/6ojS0j`oooooo0ol00002ooooo`03o`000?oooooooooo00Wooooo
0006ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`00
0?oooooooooo01_ooooo1OnX`>/00onX`N_oYl3[ojO0j`06ojO0j`GoY[o[00CoYko[o`000?l0003o
00001?nX`>/6ojW1j`;oZ<7[2_nV_n/4ojNoj`WoZL7[1OnW_n/9ojJnj`KoZ<3[1OnZ`n`2ojS1j`Oo
Y[o[1OnT_>X2ojFmj`OoZlC/1_nX`>/3oj>eiP?oUJ7M1_n@T=06oiRAb`KoXYK81onZV/H00on`WLCo
^:[;okRZb`04okRZb`Go^jS60oo4]/d6olFcb0?ocKo<1Oo5_M<5olk:eP;o]/GU1OnfbNP6ojBok003
oj>nk?nZ`>[oZ/3Z00GoZ/3Z1_n[`^/2oj[2j`OoY[o/0onT_^/4ojJnj`OoZL7[1onX`N/7ojFnj`;o
Yko[1_nX`>/3ojW1j`03o`000?nY`N_oZ<7[00SoYl3[1_nV_n/00onW_n_oZ<3[ojS0j`05ojS0j`_o
oooo0ol00005ooooo`03o`000?oooooooooo00Wooooo0006ooooo`03o`000?oooooooooo00;ooooo
00Go410@oooooooooooooooooa0@4006ooooo`;o00007Oooool00onX`>_oZ<7[ojS1j`03ojS1j`So
Yl3[00?oY[o[ojNojol000000_l00002ojNoj`KoZ<3[0_nY`N/6ojS1j`OoY[o[1onW_n/5ojW1j`?o
ZL;[1_nW_n/5ojJnj`?oYKk[1onX`>/00onZ`ncoZ<7[ojS1j`04ojS1j`OoY[o[00?oY;cZojFmjonU
_N/01?nU_N/7oj_4k0?oZ<3[0_nM]>P7oiFQg@GoT93@1onHTL/5oj:Fb0KoZY[600?o/JgDokRZbonh
Z//01OnhZ//3ok^XaPKoa;K=1?o5/lP5olfoc0?oaKgC1Oo>b]H2om?Gg0Oo]/WX0_nT_n`5oj>nk0Oo
Z/3Z0_n[`^/6oj[2j`GoY[o/00?oYKk/ojJnjonV_^/01_nV_^/5ojW1j`;oZL;[1onX`N/7ojFnj`So
Z<3[00CoZL7[ojS1jonX`N_o00000_nX`N/8ojO0j`;oY[o[1OnW_n/7ojS0j`Kooooo1?l00008oooo
o`03o`000?oooooooooo00Wooooo0006ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`000005ooooo`;o00007oooool6ojS1j`KoYl3[00?oY[o[o`000?l000001_nW_n/3ojS0
j`CoZL7[1onX`N/7ojJoj`OoYko[00?oZL7[ojW2jonY`^/01OnY`^/6ojNoj`03ojJnjonU_^_oYKk[
00GoYKk[1OnX`>/2oj[2j`OoZ<7[1OnV_n/00onT_N_oYKg[ojFmj`06ojFmj`GoZlC/00?oYl7/oifd
j?nM]>P01?nM]>P6oiFQg@KoT93@1_nHTL/5oj:Fb0CoZY[61?na[M@7okRZb`03ok^Xa_o4]/goa;K=
00Goa;K=0oo5/lP7olfoc003olFmdoo>b]Koc/[F00?oc/[F1?oCem`5okK9j0;o//W[1onS_^`5oj[0
jP;oZl;[2?nZ`^/00onV_ncoYKk/ojFnk003ojFnk0SoY[k[00?oZL7[ojW2jonY`^/01?nY`^/7ojS1
j`OoYKk[1_nX`>/5ojS1j`03o`000?nX`N_oZ<7[00KoYl3[00?oY[o[ojNojonW_n/01OnW_n/6ojS0
j`04ojS1joooooooooooooooo`?o00003Oooool00ol0003oooooooooo`08ooooo`001_ooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`0O
ooooo`KoZ<7[0_nW`>/01?nV_n_o0000o`000?l00002ojJoj`GoYko[0_nW`>/7ojW1j`GoZ<7[0onW
_n/6ojJoj`GoYko[0onX`>/7ojW2j`?oYko[0onV_n/8ojFnj`03ojS0jonZ`^_oZ/;[00CoZ/;[1onX
`N/00onV_n_oY;g[ojBmj`03ojBmj`SoYKg[00?oZlC/ojO1k?nW`N`00onW`N`6oifdj0KoUJ7M1On@
T=06oiRAb`KoXYK800?oZY[6ok6]e?na[M@01Ona[M@5okRZb`03oko?ioo4]/goa;K=00Ooa;K=00?o
aK?8olfoc?o=_l`01Oo=_l`00ooCb];oc/[Folk:eP03olk:ePKodmOL00?o]/WXok;9jonbbN/01?nb
bN/7oj>nk003oj[0j_n[`^_oZl;[00CoZl;[1_nZ`^/00onX`N_oYKk/ojFnk005ojFnk0KoY[k[00?o
Yko[ojW2jonY`^/01_nY`^/3ojS1j`?oYl3[2?nU_^/2ojS0j`WoZ<7[00?o0000ojS1jonX`N/00_nW
`>/5ojJoj`OoYko[0_nX`>/5ojS1j`;o00004?ooool00ol0003oooooooooo`08ooooo`001_ooool0
0ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003ooooooooo
o`0Pooooo`?oZ<7[0_nX`>/3o`0000KoY[o[00?oYko[ojO0jonW`>/01?nW`>/7ojW1j`03ojS1jonW
_n_oYko[00GoYko[1_nV_n/00onW_n_oZ<3[ojS0j`05ojS0j`GoZL;[00?oZ<7[ojJojonV_n/01OnV
_n/6ojFnj`;oYko[1onZ`^/3ojS1j`CoY[o[1_nT_N/6ojFmj`;oZl?[1_nW`N`6oifdj0GoUJ7M1On@
T=07oiRAb`?oXYK80_nUZ=T8ok6]e0?o^:[;1?nocnL7olBfc@03olK5fOo=_lcocKo<00GocKo<0ooC
b]83olk:ePKodmOL00?ocn;Uok;9jonbbN/01_nbbN/3oj>nk0?oXkc[2?n[`^/2oj[2j`GoZ<7[1onU
_^`2ojJnj`GoYko[1_nY`^/00onY`N_oYl3[ojO0j`05ojO0j`KoYKk[00?oY[k[ojS1jonX`N/02OnX
`N/00ol0003oZ<7[ojS1j`08ojJoj`?oYko[0onW`>/8ojS1ja7ooooo00?o0000ooooooooool02?oo
ool000Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_l0
000Rooooo`04ojS0jol0003o0000o`0000?oZ<3[2?nV_n/6ojO0j`SoZL7[1onW_n/6ojJoj`SoZ<3[
00?oZL;[ojS1jonX`N/00onX`N/7ojJoj`;oYKk[1_nW_n/5oj[2j`;oZL;[1onV_n/6ojBmj`;oYKg[
1_n[`n/6ojO1k0?oWKCX0_n5X^L4og^;f0;oUJ7M1On@T=03oiRAb`?oV9cF1_nUZ=T8ok6]e003okRZ
bonocnOo_loW00Co_loW1Oo4]/d3olK5f@GocKo<1OoCb]800oo>b]KodmOLom?Gg004om?Gg0?ocn;U
1_nbbN/00on[aNgoXkc[oj>lj`05oj>lj`KoZl;[0_n[`n/7ojS1j`?oYKk/0onT_N/8ojNoj`;oZL;[
1OnY`N/7ojO0j`;oYKk[1OnV_^/;ojS1j`03o`000?nX`N_oZ<7[00KoY[o[00?oY[k[ojO0jonW`>/0
1OnW`>/7ojS1ja7ooooo00?o0000ooooooooool02?ooool000Cooooo00?oEEEEofIVI_l000001?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool07oooool3o`0000OoZ<3[
2?nV_n/6ojO0j`SoZL7[1OnW_n/8ojJoj`KoZ<3[0_nY`N/6ojS1j`GoY[o[0onU_^/7ojNoj`03oj[2
jonY`^_oZL;[00CoZL;[1onV_n/6ojBmj`SoZl?[0onW`N`2oibhk0KoQJ;W1OmkRmP5ohR?e0OoV9cF
1_nUZ=T6ok6]e0;oVnOk1_nocnL3olBfc@Koa/GI0oo=_l`6om?:dP;of=SG0ooCem`6oloRi@;o//W[
1On[aNd7oj>lj`;oZl;[1_n[`n/5ojS1j`03ojO0jonT_N_oY;g[00GoY;g[1_nW_n/8ojW1j`KoYl3[
0_nV_n/7ojJnj`_oZ<7[00?o0000ojS1jonX`N/00_nV_n/5ojJnj`OoYl3[1onX`N/@ooooo`03o`00
0?oooooooooo00Sooooo000Eooooo`03o`000?oooooooooo01cooooo0ol00004ooooo`GoZ<3[0onW
_n/7ojJoj`?oYl3[1?nX`>/7ojW1j`03ojNojonV_n_oY[o[00[oY[o[0_nX`>/6ojW1j`KoZ<7[00?o
Y[o[ojFnjonU_^/01OnU_^/5ojNoj`;oZ/7[1onY`^/5ojJoj`;oYKk/1_nT_N/6oj_3j`;oZ/?/1OnL
^>`5ohFRi`KoNh_H1On8Sm@7oiRLePGoYJSI1?na[M@5oi_Wn`Ko_loW00?oa;K=olK5fOo6aMT01_o6
aMT00oo=_lcodl[Bom?:dP04om?:dPCof=SG00?odmOLoloRiOo?h^D01?o?h^D2okoIk0OoZlG]1OnS
_>/2ojJmjPSoZl?[00?oZ<7[ojO0jonW`>/00onW`>/7ojBmj`;oYko[3?nY`N/2ojO0j`KoY[o[1OnV
_^/00onW`>_oZ<7[ojS1j`0:ojS1j`03o`000?nW`>_oY[k[00KoY[k[1_nW`>/00onX`>_oZ<7[ojS1
j`06ojS1j`oooooo00?o0000ooooooooool02?ooool001Gooooo00?o0000ooooooooool06Oooool3
o`0000Sooooo00?oZ<3[ojNojonW_n/01OnW_n/5ojJoj`03ojNojonX`>_oZ<3[00KoZ<3[1OnY`N/2
ojO0j`_oY[o[0onW_n/7ojW1j`?oZ<7[1?nV_n/7ojFnj`03ojNojonZ`N_oZ/7[00CoZ/7[1onY`^/0
0onV_n_oYKk/ojFnk004ojFnk0KoY;g[0_n[`n/6oj[3k0GoW;S/1On5X^L5og^;f0GoR8oD1onHW=H6
ojFXf@03ok6]e?nKio_oVnOk00KoVnOk0onocnL2ohkEo`Soa/GI0_o1b=l5om?:dPGof=SG0_oLj=d3
oloRi@Go_mW/1on[aNd00onS_>_oY[gZojJmjP04ojJmjPKoZl?[00?oZ/?/ojO0jonW`>/01OnW`>/5
ojBmj`;oYKg[2onY`N/3ojS1j`SoY[o[00?oY[k[ojO0jonW`>/00onW`>/9ojS1j`;oYl3[00?o0000
ojO0jonW`>/01onV_^/2ojO0j`GoZ<3[1onX`N/?ooooo`03o`000?oooooooooo00Sooooo000Eoooo
o`03o`000?oooooooooo01Kooooo0ol0000=ooooo`OoYko[00?oY[o[ojNojonW_n/00onW_n/8ojS0
j`03ojW1jonW`>_oYl3[00CoYl3[1onV_n/7ojNoj`OoZL7[1onV_n/5ojFnj`;oY[k[1onZ`N/3ojW2
j`CoZ<3[1onU_^`3ojBmj`CoZ;oZ1onZ`n`5oibhk0CoQJ;W1_mkRmP5ohR?e0OoV9cF0onUZ=T5oi7T
o0?oVnOk1Ol`]Ml4ohkEo`Koa/GI1?o1b=l3om?:dPKof=SG0ooLj=d00oo?h^Go_mW/okoIk005okoI
k0?oZlG]0onU_^/8ojJmjP;oZl?[1OnZ`n`7ojO0j`03ojBmjonU_N_oYKg[00CoYKg[1_nY`N/00onY
`^coZ<7[ojS1j`05ojS1j`KoY[o[00?oYKk[ojO0jonW`>/01OnW`>/7ojS1j`CoYl3[00?o0000ojO0
jonW`>/00onV_^/4ojNoj`OoZ<3[1onX`N/?ooooo`03o`000?oooooooooo00Oooooo000Dooooo`;o
00005Oooool3o`00017ooooo1OnW_n/2ojJoj`KoYko[1_nX`>/2ojW1j`OoYl3[1onV_n/7ojNoj`Oo
ZL7[1onV_n/00onU_^_oY[k[ojJnj`04ojJnj`GoZ/7[0_n[`^/7ojS0j`GoYKk/00?oXkg/ojRoj_nX
_nX01_nX_nX5oj[3k003oj>okOn8[nooR:o_00?oR:o_1?mORN<00on5X^OoNh_Hog^;f003og^;f0Go
R8oD1_nHW=H4oj37m0?oTNCl1?n4iOH2ojO0k0?oFIgc0_l`]Ml4ohkEo`?oa/GI1oo1b=l00ooCb];o
f=SGomSHe`04omSHe`?og>SM0ooHm>85okoIk0;o//g^1_nU_^/6ojJmjP;oZl?/1onZ`n`3ojO0j`?o
YKk[2?nU_N/2ojW1j`GoZL;/1onX`N/2ojJoj`GoYKk[1onW`>/7ojS1j`CoYl3[00?o0000ojJojonW
_n/01onW_n/5ojS0j`WoZ<7[3_ooool00ol0003oooooooooo`07ooooo`005?ooool00ol0003ooooo
ooooo`0Booooo`;o00005Oooool00onW_n_oY[o[ojJoj`04ojJoj`KoYko[0_nX`>/6ojW1j`GoYl3[
2OnV_n/5ojNoj`;oZL3[1onY`N/3ojJoj`CoY[o/1onV_^/00onZ`N_oZl;[oj_2j`04oj_2j`OoZ<3[
00?oYKk/oj>mk?nS_N`00onS_N`8ojRojP03oj[3k?nS_ngoXko]00?oXko]1On8[nl4oen9h`CoL8gO
0_mkRmP5ohR?e0;oV9cF1_nPao@4ol;Rk`03ohCUm_nW`>coYl3/00CoYl3/1OmIWO<3ofVUm003ohkE
ooo6aMWo`LSO00Ko`LSO0_o2c>85omSHe`?og>SM1OoHm>800onofNco//g^ok;=kP04ok;=kPKoYKk[
0_nV_NX6oj_3k0GoZ/?/0_nX`N/6ojFnj`KoYKg[0_nX`>/7ojW2k0?oZ<7[0onW`>/8ojFnj`?oYl3[
2onX`N/01_nW`>_oY[o[ojJojonV_n_o0000ojJoj`SoYko[00?oZ<3[ojS1jonX`N/02OnX`N/00onW
`>_oooooooooo`0<ooooo`03o`000?oooooooooo00Oooooo000Dooooo`03o`000?oooooooooo00oo
oooo0ol0000Hooooo`OoY[o[0onW_n/4ojO0j`OoZL7[00?oYl3[ojJojonV_n/02onV_n/00onW_n_o
ZL3[ojW0j`04ojW0j`GoZL7[0_nX`N/7ojJok0GoY[k[0_nW_n/7oj_2j`GoZ<3[0_nV_n`6oj>mk0Ko
Z;oZ0_n/`^X6oj>ok@GoR:o_1?mORN<5og2=g`KoS:7Q1_nPao@4ol;Rk`;oblSH1onW`>`5oeVMl`Co
JJGd1_o1b=l4ol;<hP?of=SG0ooLj=d5omSdhP03olCWkonbcNko//g^00Ko//g^0onU_^/3ojBkj@So
Zl?/00?oZ/?/ojS1jonX`N/01?nX`N/6ojFnj`;oYKg[1_nX`>/5ojW2k003ojW1k?nW`>_oYl3[00Go
Yl3[1_nU_^/00onV_^_oZ<7[ojS1j`0<ojS1j`CoY[o[00?o0000ojJojonV_n/01_nW_n/00onW`>_o
Z<7[ojS1j`07ojS1j`GoYl3[3Oooool00ol0003oooooooooo`07ooooo`005?ooool00ol0003ooooo
ooooo`0<ooooo`?o00007?ooool7ojJoj`OoYl3[2?nY`N/=ojJoj`OoZL3[00?oZL7[ojS1jonX`N/0
1?nX`N/7ojJok003ojJnjonW_n_oYko[00CoYko[1on[`^/00onX`>_oY[o/ojJok004ojJok0KoXkg/
0_nX_nX6ojc2jPKoXko]1On8[nl4oen9h`GoL8gO1_n<XN43oj37m0Go`^;_1?o;b=P5ojO0k003ojBM
comiQmGoNHOE00;oNHOE0_mIWO<4ofVUm0?o`LSO1oo2c>801?oHf=Oog>SMomcXgOoLj=d5omSdhP?o
a>O_1_nbcNh00onW`>_oY;_YojBkj@05ojBkj@KoZl?/00?oZlC/ojS1jonX`N/01_nX`N/3ojFnj`?o
YKgZ2?nX`>/00onY`^coZL7/ojW1k003ojW1k0OoYl3[0_nU_^/5ojJnj`koZ<7[1?nV_n/00ol0003o
Y[o[ojJoj`02ojNoj`GoYl3[1onX`N/7ojO0j`cooooo00?o0000ooooooooool01oooool001?ooooo
0ol0000:ooooo`?o00008?ooool7ojJoj`OoYl3[2?nY`N/=ojJoj`GoZL3[0onY`N/6ojS1j`GoY[o/
0_nU_n`7ojNoj`?oZl;[1?nZ`^/7ojJok0?oXkg/0onS_^`8ojc2jP?oXko]0onK^nl4ofFOl@?oA8CW
0_mORN<5og2=g`KoS:7Q00?oX<Odol;Rkoo2h^l00_o2h^l7ol_8f003ojO0k?nTWLooY9g?00?oY9g?
1OmiQmD4og^FhP03ofVUm?o1b=oo`/cR00Ko`/cR0oo=h^L00ooLj=gof?CRomSdhP02omSdhPKoa>O_
0_nbcNh5ojO0j`OoY;_Y0_n[`n`5oj_4k0KoZ<7[00?oY[o[ojFmj_nU_NX01OnU_NX6ojS0j`03ojW2
k?nY`NcoZL7/00GoZL7/1OnW`>/9ojJnj`koZ<7[0onV_n/00onV_^_o0000ojJnj`08ojO0j`OoZ<7[
1onW`>/;ooooo`03o`000?oooooooooo00Oooooo000Dooooo`03o`000?oooooooooo00Kooooo0ol0
000Uooooo`KoY[o[1OnW`>/3ojS0j`OoZL7[3OnV_n/00onY`>_oZL7[ojW1j`05ojW1j`KoZ<7[00?o
Y[o/ojFok?nU_n`01?nU_n`5ojNoj`;oZL3Z1onZ`^/5ojJok0;oYKo/1_nS_^`8ojc2jPKoVk__1?mU
Wo45odB4i`CoL8gO1On<XN44ok2oi@03ol;Rkoo;b=SoblSH00GoblSH00?o`kC<ojBMconTWLl01?nT
WLl6ogV7e@GoNiKR1_o2c>83olgRi`Cod?SV00?of?CRolCWkoo4inl01?o4inl2ok7>k`OoYl3[1OnT
^nT2oj[3k0OoZlC/0_nX`N/5ojJoj`OoYKgZ0_nX`>/5ojW2k0OoZL7/00?oYl3[ojJnjonV_^/02OnV
_^/>ojS1j`03ojNojonV_^_oY[k[00;oY[k[00?o0000ojJnjonV_^/01_nW`>/9ojS1j`?oYl3[0onV
_n/;ooooo`03o`000?oooooooooo00Oooooo000Dooooo`03o`000?oooooooooo00?ooooo0ol0000Y
ooooo`KoY[o[00?oYl3[ojS0jonX`>/01OnX`>/5ojW1j`;oZ<3[2onV_n/3ojNoj`OoZL7[0onX`N/3
ojJoj`OoYKo/00?oYko[ojW0j_nY`>X01?nY`>X7oj[2j`03ojJok?nU_ncoYKo/00CoYKo/1_nS_^`8
ojc2jPKoVk__1?mUWo44odB4i`CoLYcZ00?oL8gOohbQhOn`_nD01On`_nD2olO8f`KoblSH0oo3]<`6
ojBMc`KoNHOE1OmkU^83ol;<hPCocN;W1?o@n>H4olKli003olCWkonac^oo/Lk_00Co/Lk_1onW`>/0
0onT^nWoZ/?/oj[3k004oj[3k0GoZlC/0_nX`N`6ojJoj`KoYKgZ00?oYko[ojW2k?nY`^`01_nY`^`3
ojW1k0?oZ<7[2OnV_^/>ojS1j`GoYko[1?nV_^/00ol0003oY[k[ojJnj`02ojO0j`coZ<7[1onV_n/;
ooooo`03o`000?oooooooooo00Kooooo000Cooooo`04o`000?ooooooooooooooo`?o0000;Oooool3
ojJoj`?oYko[2?nX`>/00onY`N_oZ<3[ojS0j`04ojS0j`OoY[o[1onW_n/7ojW1j`KoY[o[2?nU_n`6
ojW0jPGoZ/;[0_nY`N/7ojFok0?oXkk/1?nU_n`7ojc2jP?oVk__0onD^_43odJDl@03ofFOlOm4Q>Oo
A8CW00;oA8CW1OmbW>X5ok2oi@CoalSK0oo;b=P5ol>dc0KoY9g?1_miQmD6og^FhP03ol;<h_o=h^Oo
cN;W00;ocN;W1?o@n>H4olKli0;o^Moc1onac^l3ojO0j`?oY;_Z2?nZ`n`00on[a>coZ<7/ojS1k004
ojS1k0KoY[o[0_nU_NX5ojNoj`OoZL;/1onX`N/7ojJnj`koZ<7[1onW_n/3ojJnj`03ojNojol0003o
Yko[00ooZ<7[1onV_n/:ooooo`03o`000?oooooooooo00Kooooo000Cooooo`Co0000<Oooool6ojNo
j`KoZ<3[0_nY`N/7ojS0j`KoY[o[2?nW_n/7ojW1j`KoY[o[2?nU_n`6ojW0jP03oj[2jonY`N_oZL7[
00CoZL7[1OnU_n`2ojBok0OoYKo/1On/`^X2oj_1jPKoU;[a0om6U?43obV2j@;oA8CW1OmbW>X3ok2o
i@KoalSK00?oblSHol>dc?o3]<`01Oo3]<`6ojBMc`KoNHOE0omkU^85oijej003olgRioo@n>Kod?SV
00;od?SV0oo6o>@5okWOl`Go/Lk_0_nW_NX6ojBkjPKoZ/?/00?oZ/C/ojS1k?nX`N`01_nX`N`3ojJo
j`?oYKcZ1onW_n/7ojW2k0OoZ<7[1onV_^/>ojS1j`GoYko[0_nV_^/4ojNoj`03o`000?nW_n_oZ<7[
00koZ<7[0onV_n/3ojNoj`[ooooo00?o0000ooooooooool01_ooool001?ooooo0_l0000dooooo`Ko
Yko[0_nX`>/6ojW1j`GoZ<3[0_nW`>/6ojJoj`KoYko[0_nX`>/7ojW1j`?oY[o[0onV_n`8ojFok0?o
ZL3Z0on[`NX7ojW1j`03ojFok?nT_ncoY;o/00CoY;o/1onU_n`00on/`^[oZl7Zoj_1jP04oj_1jPKo
U;[a0om6U?45obV2j@GoLYcZ00?o/;oUolO8foo7b=/01?o7b=/00oo8c=go`kC<ol>dc006ol>dc0Go
Y9g?00?oYJ;BohjGeon>UmL01?n>UmL7oijej0Co^o7c00Cod?SVolKli?o6o>Coa_cT1onigo<00ona
c^ooYkgZojNmjP04ojNmjPKoY;_Z0_nZ`n`5oj[4k0KoZ<7/00?oYkk[ojFlj_nU_>X01OnU_>X5ojNo
j`WoZL;/0onX`N/;ojJnj`?oZ<7[0onX`N`8ojS1j`03ojNojonV_^_oY[k[00CoY[k[0onW_n/00ol0
003oYko[ojNoj`0=ojS1j`SoYko[2Oooool00ol0003oooooooooo`06ooooo`001Ol00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`0booooo`?oYko[1?nW`>/7ojW1
j`03ojS0jonW`>_oYl3[00CoYl3[1_nV_n/2ojNoj`KoZ<3[1onY`N/6ojJok0SoYKo/1_n[`NX5ojW1
j`;oZ<3[1onT_n`3ojFok0CoY[o/1on[`NX6oiBjl@03ocjDlOm6U?7oAYCa00Go:H;Y1Omk[o@5olO8
f`?ob<cM2?o3]<`00onTWLooYJ;BojFRdP03ojFRdPKoSYOG1OnN]NP4ok_al`?oZOWN0_nilo<6okWO
l`03ojc5k?nW_N[oYkgZ00KoYkgZ0onT^nX3ojW4k@OoZ/C/0_nX`N`5ojNnj`OoYKcZ00?oYko[ojW2
k?nY`^`02OnY`^`00onX`N_oY[k[ojJnj`0;ojJnj`03ojS0jonX`NcoZ<7/00GoZ<7/1_nX`N/00onW
`>_oY[k[ojJnj`06ojJnj`?oYko[00?o0000ojS0jonX`>/02OnX`N/<ojNoj`Sooooo00?o0000oooo
ooooool01_ooool00005oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Wooooo00?o0000ooooooooool0<oooool6ojO0j`OoZL7[1onW`>/3ojJoj`CoY[o/1onX`>/7
ojW1j`KoY[o/2?nU_n`6oj_1jP03ojW1jonX`>_oZ<3[00CoZ<3[1OnT_n`00onS_ngoY[o/ojJok006
ojJok0GoZl7Z0_n[`>T6oiBjl@?o?YCa1OlYP^T5og^_m0?oalSK1Oo8c=d6ol>dc003okfofonUX];o
YJ;B00CoYJ;B1on>UmL3oijej0?o^o7c0onYnMh5okWcl`;o^Moc1On/aN`6ojNmjP03ojFnjonYa>go
ZLC]00GoZLC]1OnZa>`2ojS1j`OoYkk[0onU_>X3ojNoj`WoZL;/1OnX`N/9ojJnj`GoZ<3[1onX`N`2
ojS1j`GoYl3[1_nV_^/00onW_n_oZ<3[ojS0j`02ojS0j`03o`000?nX`>_oZ<3[00KoZ<7[3OnW_n/0
0onW`>_oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00001?ooooooV9RHob4Q8Oo^k^h4
ooooo`05oa0@4?ooooooooooooooool@41002_ooool00ol0003oooooooooo`0cooooo`KoYl3[1onY
`N/5ojO0j`WoY[o/1OnX`>/2ojW0j`OoZL7[1onV_n`7ojFok0KoZl7Z1onX`>/00onT_ncoXko]oj>o
k@03oj>ok@SoY[o/00?oZl7Zoj_0jOn[`>T01?n[`>T6oiBjl@Co?YCa0_l5Nn02obV2j@GoNjod00?o
alSKolS<gOo8c=d01?o8c=d4ol>dc0Co_KoK1_nUX]87ohjGe`03oijej?nklO?o^o7c00?oZOWN1_ni
lo<2ojg=l0Oo[<G/0_nW_NX5ojFnj`OoZLC]00?oZ/C/ojS1jonX`N/01?nX`N/5ojNnj`03ojFlj_nW
_n_oYko[00GoYko[1onY`^`7ojS1j`OoY[k[1onX`>/6ojS1k0SoYl3[0_nV_^/5ojNoj`CoZ<3[00?o
0000ojS0jonX`>/01_nX`N/9ojNoj`GoYl3[1oooool00ol0003oooooooooo`06ooooo`000_ooool0
0onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000002oooool2o`0003Cooooo0onW
`>/3ojS0j`OoZL7[00?oYl3[ojJok?nV_n`02onV_n`00onX`>_oZL3[ojW0j`04ojW0j`GoZL7[0_nX
`>/7ojJok0GoYKo/0_nV_n`6oj_1jPGoZ<3[0_nW`>/6oj>ok@KoY[o/0_nV`>`7oj_0j@?oU;[a0onK
^nl3oeNTm`03ocjDlOl5Nn3o1G_P00;o1G_P1Om[^_d7olS<g@03ol>dc?nm_m_o_KoK00Go_KoK1OnU
X]86ohjGe`;oXn7l0omnimL4oiO`k@03okWclon]cO3o[Lg`00Co[Lg`1On/aN`2ojFkj@OoYKk[0onY
a>d3ojW3k0SoZ<7[00?oYkk[ojFlj_nU_>X00onU_>X7ojNoj`OoZL;/1onX`N/7ojJnj`GoZ<3[2?nX
`N`6ojO0j`03ojJnjonW_n_oYko[00KoYko[0onX`>/00ol0003oZ<7[ojS1j`07ojS1j`KoYko[2?nW
`>/7ooooo`03o`000?oooooooooo00Gooooo0003ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000
ooooooooooooooooo`00000=ooooo`03o`000?oooooooooo03;ooooo1_nX`>/8ojW1j`[oY[o/0onV
_n/7ojW0j`03ojW1jonX`>_oZ<3[00CoZ<3[1onV_n`00onU_ncoY[o/ojJok004ojJok0KoZl7Z00?o
Z<3[ojO0jonW`>/01?nW`>/6oj>ok@;oY[o/1_nV`>`5oj_0j@;o[<7Y1_nK^nl6oeNTm`;o1G_P1Om[
^_d5olS<g@03ojgMn?nm_m_o_KoK00Ko_KoK1_nUX]82ohjGe`?oXn7l0omnimL5oiO`k@?oZm7d1_n]
cO000on/aNcoYK_YojFkj@04ojFkj@GoYKk[0_nYa>d6ojW3k0KoZ<7[00?oY[gZojFlj_nU_>X01OnU
_>X5ojNoj`WoZL;/0onX`N/;ojJnj`03ojS0jonX`NcoZ<7/00[oZ<7/0_nW`>/5ojJnj`KoYko[00?o
Z<3[ojS1jonX`N/00_nX`N/00ol0003oZ<7[ojS1j`05ojS1j`SoYko[1_nW`>/00onX`>_ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo0004ooooo`05o`000?ooooooooooooooool@41000ooo
ool00ol@413oooooooooo`0<ooooo`03o`000?oooooooooo03;ooooo1_nX`>/8ojW1j`KoY[o/1onV
_n/5ojW0j`?oZL7Z1_nX`>/5ojJok0;oYKo/1onV_n`3oj_1jP?oZl7Y1onW`>/7oj>ok@OoY/3/00?o
Zl3Yojc1jOn/`NT01?n/`NT6oi^kk`?oEjCg0on3]oH2oaR<j0GoJk[m00?ob<cMojgMn?n]gOP00on]
gOP8okfof`?oYJ;B1OnKg_d01?nShOcoO^OGogkWeomnimL3oiO`k@OoZm7d0on]cO03ojNlj0OoYK_Y
00?oYKk[ojW4kOnYa>d01?nYa>d6ojW3k0;oZ<7[1OnV_NX7ojFljP03ojNojonY`^coZL;/00WoZL;/
0_nX`N/<ojJnj`03ojS0jonX`NcoZ<7/00WoZ<7/0onW`>/7ojJnj`;oYko[1OnX`>/4ojS1j`04o`00
0?nX`N_oZ<7[ojS1j`coYko[0_nW`>/5ojS0j`Kooooo00?o0000ooooooooool01Oooool00005o`00
0?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00oooooo00?o0000oooo
ooooool0<_ooool7ojS0j`OoZL7[1_nV_n`7ojJoj`03ojW0jonY`N[oZL7Z00GoZL7Z1_nX`>/00onV
_ncoYKo/ojFok004ojFok0GoY[o/0_nW`>`6oj_1j@GoYl3[0_nW_n/7oj>ok@GoY/3/0_nU`>d7ojc1
j@?oVk__0onS_N/6oh>gmPCo68cX1?lQX^L5ojgMn0Ko_KoK0on1goX5oi_No@04odk<b?m_gnSoKmoX
ofoOj0CoYLof1_n[dO@00onX_NWoYkcXojNlj005ojNlj0GoYK_Y0_nXa>h7ojW4k@?oZL?/0onX`>/7
ojJmjP?oYKcZ1?nW`>`8ojW2k0KoZ<7[2?nV_^/5ojS0j`OoZ<7/1onW`>/5ojJnj`03ojNojonX`>_o
Z<3[00KoZ<3[1?nX`N/00ol0003oZ<7[ojNoj`0<ojNoj`SoZ<3[1Oooool00ol0003oooooooooo`05
ooooo`0000GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04?oo
ool2o`0003Cooooo1_nX`>/5ojW1j`;oZ<3[1_nV_n`7ojJoj`SoZL7Z0onX`>/3ojO0j`OoYKo/00?o
Y[o/ojO0k?nW`>`01?nW`>`6oj_1j@03ojO0jonW_n_oYko[00CoYko[1onS_nd00onV`>coYL3]ojG0
k@04ojG0k@Go[<7Y0_n/`^X6oj>mj`KoPkOf1_lHS>P00ol0N;Oo8J;WojgMn004ojgMn0;o_KoK1on1
goX01?nKg_goG]3boek@l_mNd?83oj39m@KoYLof0_n[dO@5ojRmj@OoYkcX00?oYK_YojS4k_nXa>h0
1?nXa>h5ojW4k@;oZ<7/1_nX`>/7ojJmjPOoYl3/0onY`^`3ojS2k0SoZ<7[1_nV_^/7ojS0j`OoZ<7/
1onW`>/00onV_^_oYko[ojNoj`03ojNoj`KoZ<3[00?oZ<7/ojS1jonX`N/00_nX`N/00ol0003oZ<7[
ojS1j`0=ojNoj`KoZ<3[00?oZ<7[ooooooooool00oooool00ol0003oooooooooo`05ooooo`007ooo
ool00ol0003oooooooooo`0booooo`KoZ<3[00?oZL7[ojS0jonX`>/01?nX`>/6ojJok0OoY[o[1_nY
`NX2oj[1jPKoYl3[1onU_n`7ojO0k0KoZl7Y1onW_n/3oj>ok@GoY;o]1_nU`>d00on/`NWo[<;Zojc2
jP04ojc2jPKoXkg[0on3]oH4oi^kkPKoLkKj0olOW^P5oh[1n@KoJ/?n00?oG]3boj39mOnPbOD01OnP
bOD3ojG?mP?oYkgY1onX_NT3ojNlj0?oYl;]2?nXa>h00onYa>goZ<7/ojS1k004ojS1k0KoZ<3[1onV
_NX5ojO0k0;oZL;/1_nX`^`6ojS1j`03ojJnj_nV_^_oY[k[00GoY[k[1OnX`>/9ojS1k0?oYl3[0onV
_^/7ojNoj`;oZ<3[1OnX`N`4ojS1j`03o`000?nX`N_oZ<7[00goYko[0_nX`>/5ojS1j`Cooooo00?o
0000ooooooooool01Oooool0023ooooo00?o0000ooooooooool0<_ooool=ojS0j`KoY[o/1onV_n/2
ojW1jPKoZ/7Z1_nW`>/7ojFok0OoYl3/1_n[`NT5ojNoj`?oZ;o[1onT_nd3ojG0k@?oXl3^1on/`^X3
oj>mj`?oZ[kY1onK^nh3og>fnPCoW;c_1on:`OT3of[3oPCoWl7`1OnPbOD00onW_>SoYkgYojNmj@05
ojNmj@GoZ;gY0_nV`N`6ojO2k@KoZ<C^00?oZ<?/ojS1k?nX`N`01_nX`N`3ojS0j`?oY[cY1onV_NX0
0onW`>coZL;/ojW2k004ojW2k0KoZ<;/0_nX`N/5ojJnjPOoY[k[00?oZ<3[ojS1k?nX`N`02OnX`N`0
0onW`>_oY[k[ojJnj`05ojJnj`GoYko[0_nX`>/7ojS1k0?oZ<7[00?oYko[o`000?nW_n/02onW_n/2
ojS0j`SoZ<7[0oooool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`0boooo
o`koZ<3[1OnV_n`5ojJoj`?oYko[1onZ`NX6ojO0j`OoYKo/1onW`>`6oj_1j@03ojNojonX_n_oZ;o[
00GoZ;o[1OnT_nd2ojFok0KoXl3^1On/`^X2ojS2k0KoZ[kY1OnK^nh2ojRlj0OoW;c_0on:`OT3oj>l
j`SoWl7`00?oX<WeojNlj?nW_>P00onW_>P7ojNmj@03ojRmjOnV`NcoY/7/00CoY/7/1_nW`^d2ojS4
kPGoZ<?/1_nX`N`00onW_NWoY[cYojJlj@05ojJlj@GoY[gZ00?oZ<;/ojW2k?nY`^`01_nY`^`3ojS2
k0?oZ<3[1onV_^X3ojJnj`coZ<7/1OnW`>/7ojJnj`03ojNojonX`>_oZ<3[00CoZ<3[1_nX`N`4ojNo
j`03o`000?nW_n_oYko[00OoYko[1_nX`>/6ojS1j`03ojS0jooooooooooo00;ooooo00?o0000oooo
ooooool01?ooool002;ooooo00?o0000ooooooooool0<_ooool>ojS0j`GoY[o/00?oY[o[ojNojonW
_n/01OnW_n/7oj[1jPKoYl3[1onU_n`7ojO0k0KoZl7Y2?nX_n/00onT_ngoYKo/ojFok004ojFok0Ko
Xl3^00?o[<;ZojS2k?nX`^`01?nX`^`6ojZnj@03oi^kk_nX_>SoZ;cX00CoZ;cX1OnL_>l2ojRmj0Ko
Xkc[1_nO`O000onX_>SoYkcXojNlj005ojNlj0GoYkgY0_nW`N`7ojK1k0?oYl;]1?nX`nd6ojS3k0;o
Z<7/1OnW_NT7ojJlj@03ojJmj_nX`^coZ<;/00?oZ<;/1_nY`^`00onX`NcoZ<3[ojS0j`05ojS0j`Go
Y[kZ0_nV_n/=ojS1k0OoYl3[0onV_^/3ojNoj`SoZ<3[1_nX`N`4ojNoj`03o`000?nW_n_oYko[00Oo
Yko[1_nX`>/2ojS1j`GoZ<3[0oooool00ol0003oooooooooo`04ooooo`008oooool2o`0003?ooooo
0onX`>/4ojW0j`OoZ<3[1_nV_n`7ojNoj`OoZ/7Z1_nW`>/7ojFok0GoYl3/0_nV`>`6oj_1j@KoZ;o[
0_nY_nX7ojFok0?oXl3^0onS_nd7ojS2k0?oZ[kY0on[`n/7ojRlj003oiblkonX_NSoZ;gX00CoZ;gX
1_nS_>/2oio1l0GoZ;cX1onW_>P00onW_NWoYl7/ojO1k004ojO1k0GoY/7/0_nXa>h7ojS3k@?oZ<?/
0onW_nX7ojNmj@?oY[cY0onW`>`7ojS2k0;oZL;/1OnX`N`7ojS0j`03ojJnj_nV_n_oY[o[00CoY[o[
3OnX`N`5ojO0j`;oY[k[1_nW_n/6ojS0j`SoZ<7/1?nW_n/00ol0003oYko[ojNoj`07ojNoj`?oZ<3[
0_nX`N`8ojS0j`;ooooo00?o0000ooooooooool01?ooool002Gooooo00?o0000ooooooooool0<_oo
ool6ojW0j`GoZ<3[0_nW`>/7ojJok0?oYko[0onW`>/7oj[1jPOoYl3[1_nU_n`00onW`>coY/3/ojK0
k004ojK0k0KoZl7Y0_nX_n/6ojVojPGoYKo/0_nV_n/6oj>ok@GoZ<;/0_nS`Nh6oj_3j`GoZ;cX0_n[
`n/7ojRmj0?oXkc[0onY`>X7ojRlj0?oYkcX0onX`^`8ojO1k003ojK1k?nXa>koZ<C^00CoZ<C^1OnX
`nd2ojRoj`KoYkoZ1OnW_NT2ojJnjPKoYl3/1onX`^`7ojS1k0?oZ<3[0onV_NX8ojJoj`goZ<7/00?o
Yl3[ojJnjonV_^/01?nV_^/6ojNoj`;oZ<3[2_nX`N`6ojNoj`03o`000?nW_n_oYko[00GoYko[00?o
Yl3[ojS1k?nX`N`01?nX`N`6ojS0j`04ojNojoooooooooooo`0000Kooooo000Vooooo`03o`000?oo
oooooooo03;ooooo1_nY`>/00onX`>_oYl3[ojO0j`04ojO0j`OoY[o/1_nW`>/5oj[1jP;oZ/3Z1onW
`>/6ojFok0OoY/3/0on[`NT3oj_1jPSoZKoZ00?oYKo/ojJojonV_n/01?nV_n/6oj>ok@03ojS2k?nS
`NkoXl7^00CoXl7^1_n[`n/00onX_>SoZl?[oj_3j`04oj_3j`GoZ;gX0_nYa>d6ojW0jPGoZ;cX0_nX
a>h6ojS2k0KoYl7/00?oYl?^ojS4k_nXa>h01_nXa>h00onX`ngoZ;o[ojRoj`04ojRoj`KoYkoZ00?o
YkgYojJnj_nV_^X01?nV_^X6ojO0k0OoZ<;/1OnX`N`2ojNnjPKoY[gZ1_nV_n/;ojS1k0?oYko[2?nV
_^/3ojNoj`;oZ<3[2OnX`N`9ojNoj`03o`000?nW_n_oYko[00;oYko[1OnW`>/6ojS1k0;oZ<3[1OnW
_n/00ooooooo0000ooooo`05ooooo`009oooool00ol0003oooooooooo`0booooo`KoZL3[1onW`>/7
ojJok0KoYl3[00?oZ/7Zoj[0j_nZ`>X01?nZ`>X5ojO0j`;oYko[1_nU_n`5ojK0k0;oYL3/1_n[`NX6
ojVojP;oZ[oY1onV_n/3oj>ok@?oY;o/1onS`Nh3oj_3j`?oY<;^1on[`n/00onX_NSoZLC]ojW4k@04
ojW4k@KoZL3Z00?oZ;cXojS4k_nXa>h01?nXa>h6ojS2k0;oYl7/1OnW`nh6ojS4kP03ojO0jonX_n_o
Z;o[00KoZ;o[0onW_nX2ojJmj@SoY[kZ0onW`>`:ojS2k003ojS1k?nW_^[oYkkZ00CoYkkZ1_nV_NX2
ojJoj`coZ<7/1_nW_n/6ojJnj`03ojNojonX`>_oZ<3[00CoZ<3[1onX`N`;ojNoj`03o`000?nW_n_o
Yl3[00OoYl3[0onX`N`4ojS0j`KoYko[00?o0000ooooooooool01?ooool002Sooooo0_l0000coooo
o`KoZL3[1onW`>/7ojJok0KoYl3[1onZ`>X00onW`>_oYko[ojNoj`04ojNoj`KoYKo/00?oY/3/ojG0
k?nU`>`01?nU`>`6oj_1jP;oZKoZ1_nZ_nT5ojJoj`;oZ;kZ1_nT_n`5oj?1kP;oY;o]1_nT`^h5oj_3
j`;oYL;^1onYa>d3ojW0jP?oY/?_1onXa>h3ojS2k0CoY/?^1_nW`nh2ojS4kPGoYl3[1_nX_n/00onW
_>WoY[gYojJmj@04ojJmj@KoY[kZ00?oZ<;]ojS2k?nX`^`02_nX`^`00onX`>_oYkkZojNnjP06ojNn
jP?oY[gZ0onW`>/>ojS1k0KoYko[0_nV_^/5ojNoj`KoZ<3[1onX`N`;ojNoj`03o`000?nW_n_oYl3[
00GoYl3[00?oZ<7/ojS0jonX`>/01_nX`>/3ojNoj`;ooooo00?o0000ooooooooool01?ooool002[o
oooo00?o0000ooooooooool0<Oooool6ojW0j`OoYl3[1onV_n`6ojO0j`GoZ/3Z0_nZ`NX7ojNoj`?o
YKo/0onV_n`7ojG0k0?oZl7Z0onY`N/8ojZoj@03ojJojonX_^[oZ;kZ00CoZ;kZ1_nT_n`00onS`Nko
Y;o]ojBok@04ojBok@KoY<;^00?oZl?[ojG2k_nU`^h01?nU`^h5ojW4k@;oYL;^1_nV`nl5ojS4kP;o
Y/;]1onV`nh3ojO3kP[oYl3[0_nX_n/5ojNlj@KoY[gY0_nV_^X5ojS2k@SoZ<;/1OnX`>/6ojNnjP03
ojJnjonW`>_oYl3[00GoYl3[3_nX`N`3ojNoj`;oYkk[2?nW_n/3ojS0j`[oZ<7/2onW_n/01?l0003o
Yko[ojO0jonW`>/5ojS1k0KoZ<3[1oooool00ol0003oooooooooo`03ooooo`00:oooool00ol0003o
ooooooooo`0aooooo`?oZL3[1?nY`>X6ojO0j`OoY[o/1_nW`>/00onZ`>[oZ/7Zoj[1jP04oj[1jPGo
Yko[0_nX_n/6ojJok0OoYL3/1_nY`N/6ojZoj@;oZl3Y1onX_^X3ojBok0?oYkk[1onT_nd3ojC2kPCo
Y<3]1_nU`^h00onYa>goYL;^ojG2kP04ojG2kPKoY/?_00?oZ<C^ojK2kOnV`^d01?nV`^d5ojK3kP;o
Yko[2onW`>/8ojNlj@GoY[gY0_nW`^`7ojS2k@?oZ<;/1?nX`N`6ojS0j`;oYkkZ1OnV_^/7ojO0j`co
Z<7/1onW_^/6ojNoj`coZ<7/3OnW_n/00ol0003oYl3[ojS1k007ojS1k0;oZ<3[2_ooool00ol0003o
ooooooooo`03ooooo`00;?ooool00ol0003oooooooooo`0aooooo`OoZL3Z1_nW`>/7ojJok0?oYl3[
0onW`>`7oj[1jP03ojNojonX_n_oZ;o[00CoZ;o[1_nV_n`7ojG0k0KoZL7[0_nZ_nT6oj_0j@GoZ;kZ
0_nZ_nT6ojNnj`GoY;o]0_nV_n/7ojC0k@?oYL;^0onU`>d7ojG2kP?oY/?_1?nV`N`6ojK2k@03ojK3
k_nW_n_oYko[00CoYko[1onW`>/<ojNlj@03ojJmjOnW`^coYl;/00CoYl;/1OnX`^d9ojS1k0?oZ<3[
0onW_NX7ojJnj`?oYl3[3?nX`N`;ojNnj`;oYko[2onX`N`00onX`>_oYko[ojNoj`0:ojNoj`GoYl3[
00?o0000ojO0jonX`N`01OnX`N`=ooooo`03o`000?oooooooooo00?ooooo000]ooooo`;o0000<_oo
ool7ojW0jPKoYl3[1onV_n`6ojO0k0GoZ/7Z0_nY`NX7ojRoj`KoY[o/1onU`>`3ojW1j`?oYl7/2?n[
`>T00onX_^[oZ[oYojZoj@04ojZoj@KoYkk[00?oY;o]ojJojonV_n/01?nV_n/5ojC0k@03ojNnjonU
`>goYL3]00GoYL3]1OnU`^h2ojNoj`OoY/7/0onV`^d3ojNnjPOoYko[0onW`>/3ojNmj0[oYkcY1?nW
`N`6ojO2k003ojS2kOnX`NcoZ<7/00WoZ<7/00?oYkkZojNmj_nW_NX01OnW_NX5ojJnj`goZ<7/0_nX
`>/:ojNnj`?oYl3[2OnX`N`5ojS0j`SoYko[2OnW`>/01?l0003oYl3[ojS1k?nX`N`@ooooo`03o`00
0?oooooooooo00?ooooo000_ooooo`03o`000?oooooooooo033ooooo1onY`>X6ojO0j`OoY[o/1_nW
`>`00onZ`N[oZL7ZojW1jP04ojW1jPGoZ;o[0_nY_nX6ojJok0OoYL3/1_nW`N`6oj_0j@03oj[1jonZ
_nWoZ[oY00KoZ[oY0onW_^/3ojVnj@OoY[o[00?oY<3]ojNnjonW_^/00onW_^/7ojG0k@03ojG2k_nW
_n_oYko[00CoYko[1OnV`N`00onW_NWoYkkZojNnjP05ojNnjPGoYko[00?oZ;gXojNmj?nW_NP01OnW
_NP5ojNlj@WoYl7/0onW`^`2ojS2k0WoZ<7/1OnW_^X7ojNmjP03ojJnjonX`NcoZ<7/00_oZ<7/1_nX
`>/5ojNnj`03ojNojonW`>_oYl3[00GoYl3[1_nX`N`8ojS0j`GoYko[2onW`>/00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo00?ooooo000`ooooo`03o`000?oooooooooo037ooooo1_nY`>X7
ojO0j`KoY[o/0onW`>`4ojK0k0KoZL7Z00?oZ;o[ojVoj_nY_nX01?nY_nX6ojJok0OoYL3/1_nW`N`2
oj_0j@GoZ/7[1_nZ_nT00onZ`N[oZKkYojVnj@05ojVnj@?oY[o[0onX_^T7ojNnj`?oYL3]1?nW_^X7
ojNoj`03ojK1k?nW_NWoYkgY00?oYkgY1onW_^X00onW_n_oZ;gXojRmj003ojRmj0OoYkgX00?oYkcY
ojO1k?nW`N`02OnW`N`7ojS2k0KoZ<7/00?oYkoZojNnj_nW_^X01OnW_^X3ojNmjP?oYl3/3_nX`N`7
ojS0j`03ojNnjonW_n_oYko[00?oYko[1onW`>/6ojS1k0KoZ<3[1onW_n/6ojO0j`Gooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`03ooooo`00<Oooool00ol0003oooooooooo`0aoooo
o`CoZL3Z0onY`>/6ojO0j`CoY[o/2OnV`>`3ojW1jPCoZL7[1_nY_nX3ojJok0CoYko[1_nU`>`3ojO1
k0CoYL3]1_nZ`N/2ojZoj@GoZ/7Z1OnY_^T2oj[0j@KoZ;kY1OnW_^/2ojVmj@OoYkkZ0onW_n/3ojRm
j0OoYkgY0onW_^X3ojRmj@OoZ;gX0onW_NP<ojO1k0_oZ<;/0_nX`N`5ojNojPGoYkkZ0_nW_n/6ojO0
k0koZ<7/0onX`>/3ojNnjPOoYko[0onW`>/:ojS1k0;oZ<3[2onW_n/2ojO0j`Wooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`03ooooo`00<_ooool2o`0003;ooooo00?oZL3ZojW0jonY
`>/01?nY`>/6ojO0j`03ojJok?nV`>coY/3/00_oY/3/1_nY`N/4ojVojP?oZL3Z1_nW_n/3ojG0k0?o
Y/3/1onU`>d3oj[1j`?oYl7/1onZ`NX00onY_^WoZ/3Yoj[0j@04oj[0j@KoZ;kY00?oYkk[ojVmjOnY
_NT01?nY_NT5ojNnjP;oZKkY1_nX_NP5ojNmj@;oZ;kY1_nX_NT5ojRmj0coYl7/0onW`^d:ojS2k0Co
Z;o[1_nW_nX00onW_^[oYko[ojNoj`04ojNoj`KoYl3/3?nX`N`8ojNnjPGoYko[0_nW`>/:ojS1k0go
Yko[3_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo000dooooo`03o`00
0?oooooooooo033ooooo1onY`>/3ojO0j`CoZ<3[3OnV`>`6ojW1j`03ojVoj_nY`>[oZL3Z00CoZL3Z
1?nW_n/2ojRojPKoY/3/1OnU`>d2ojG0k0KoYl7/1OnZ`NX2ojS1k0OoZ/3Y0onX_^T3oj[0jPOoZKgY
00?oYkkZojVnjOnY_^T01?nY_^T6ojRmj003ojNmjOnX_^WoZ;kY00CoZ;kY1_nX_NT00onX_NSoYl7/
ojO1k009ojO1k0SoYl;]1OnX`^`2ojO0j`OoZ;o[0onW_nX3ojNnjPOoYko[0onW`>`;ojS1k0coYkkZ
00?oYko[ojO0jonW`>/01?nW`>/6ojS1k0coYko[4_ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo00;ooooo000eooooo`03o`000?oooooooooo033ooooo1onY`>/7ojS0j`goY/3/0onY
`N/3ojS0j`OoZL3Z00?oYko[ojRoj_nX_nX00onX_nX6ojK0k003ojG0kOnU`>coYL3/00CoYL3/1_nW
`N`00onZ`N[oZ<7/ojS1k004ojS1k0GoZ/3Y0_nX`^`6oj[0jPGoZKgY0_nY`N/7ojVnj@?oZ;gX0onY
`>/7ojRnj@?oZ;gY1?nW`^`7ojO1k0coYl;]00?oZ<;/ojO0jonW`>/01?nW`>/5ojRoj`SoYkkZ1OnW
_n/<ojS1k0;oZ;o[2onW_^X:ojO0j`KoZ<7/2?nW_n/Fooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool00_ooool003Kooooo00?o0000ooooooooool0<?ooool7ojW0j`OoZ<3[3OnV`>`6
ojS0j`OoZL3Z1_nX_nX3ojK0k0?oY[o[1onU`>`3ojO1k0CoYL3]1_nX`N`00onZ`>WoZ<;/ojS2k004
ojS2k0KoZ/3Z00?oZKgYojW1jonY`N/01?nY`N/5ojVnj@;oZ<;/1_nY`>/5ojRnj@;oYl;]1onW`^`3
ojO1k0goYl;]2_nW`>/00onX_n_oYkkZojNnjP0:ojNnjP03ojNojonX`NcoZ<7/00WoZ<7/00?oZ<7[
ojRojonX_n/01?nX_n/6ojNnjP03ojNojonW`>_oYl3[00[oYl3[2?nX`N`3ojNoja_ooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`02ooooo`00=oooool2o`00037ooooo1onY`>/7ojS0
j`goY/3/1_nX`>/7ojW0jPCoZ;oZ0_nY_nX6ojJoj`GoYL3/0_nV`>`7ojG0k@?oZ<7/0onV`Nd7ojS2
k0?oZ/3Z1?nW`^`6ojW1j`03ojVnjOnX`^coZ<;/00CoZ<;/1_nY`>/00onX_^WoYl;]ojO2k@04ojO2
k@GoYl;/00?oYl7]ojO2kOnW`^d02_nW`^d;ojO0j`?oYkkY2_nW_^X3ojO1k0WoZ<7/1OnX`N/6ojRo
j`;oYkkZ1OnW_n/8ojO0j`[oZ<7/8?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00;ooooo000iooooo`03o`000?oooooooooo02oooooo1OnY`>/9ojS0j`?oY/3/0onV_n`7ojK0k0?o
Z<3[1?nW`>`6ojW0jP03ojRoj_nY_n[oZKoZ00?oZKoZ1_nV_n/00onU`>coY/3/ojK0k004ojK0k0Go
YL3]0_nV`>`6ojK1k@GoZ<;/0_nV`Nd7ojO2k0?oZL7[0onV`^d7ojS2k0?oZL3[2_nW`^d00onW`^co
Yl7]ojO1k@03ojO1k@SoYl;]2_nW`>/8ojNnj@GoYkkZ2?nW`N`7ojS1k0OoZ<7[0onX_n/3ojNnjPOo
Yko[0onW`>/;ojS1k2?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`02ooooo`00
>_ooool00ol0003oooooooooo`0_ooooo`03ojW0jonX`>_oZ<3[00WoZ<3[0_nY`>X6ojJok0OoY/3/
1onW`>`3ojW0jP?oZL7[1_nY_nX3ojJoj`CoZ;oZ1_nV`>`00onU`>goY/3/ojK0k004ojK0k0KoY/7]
00?oZ<;/ojK1kOnV`Nd01?nV`Nd5ojO2k0;oY/7]1_nV`^d5ojS2k003ojK1kOnW`^goYl;]00WoYl;]
0_nW`N`7ojO1k@?oYl;]2onW`>/<ojNnj@03ojNnj_nW`NcoYl7/00[oYl7/1onX`N`5ojS1j`SoYkkZ
1OnW_n/00onW`NcoZ<7/ojS1k008ojS1k2Sooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`02ooooo`00>oooool00ol0003oooooooooo`0`ooooo`OoZ<3[1_nY`>X6ojJok0OoY/3/1OnW
`>`2ojK0k0KoZL7[1?nY_nX2ojW0jPOoZ;oZ0onV`>`3ojNnjPOoY/3/0onV`Nd4ojK0k0KoY/7]00?o
Yl;/ojK1kOnV`Nd01?nV`Nd6ojK2k@03ojS2k?nV`NgoY/7]00?oY/7]1_nW`^d7ojO1k0GoYl7]0_nW
_n/:ojO0j`goYkkY3OnW`N`:ojS1k003ojS1jonW_^[oYkkZ00[oYkkZ00?oYko[ojO1k?nW`N`00onW
`N`5ojS1k2gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`01ooooo`00??ooool0
0ol0003oooooooooo`0`ooooo`KoZ<3[1onY`>X3ojJok0CoYko[1_nV`>`00onW`>coY/3/ojK0k004
ojK0k0KoZL7[00?oZKoZojW0j_nY`>X00onY`>X5ojRojP;oZKoY1_nW_^X5ojK0k0;oYkk[1onV`>`3
ojK1k@?oY/3/1onV`Nd3ojK2k@?oY/3/1_nV`Nd2ojO2k@_oYl7/00?oYl7]ojNojonW_n/01?nW_n/5
ojO0j`;oZ;kY2onW_^T00onW`>coYl7/ojO1k00;ojO1k0[oZ<7/0onW_nX:ojNnjPCoYl3[1_nW`N`0
0onX`Ncoooooooooo`0_ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00Oooool0
03gooooo0_l0000aooooo`KoZ<3[1onY`>X7ojNoj`goY/3/0onY`N/3ojO1k0KoZL3Z00?oZ;oZojVo
jOnY_nT01?nY_nT6ojNnjP03ojK0k?nW_^_oYkk[00CoYkk[1OnV`>`2ojNnjPKoY/3/1OnV`Nd00onW
_n_oY/3/ojK0k005ojK0k0?oY/7]0onW_n/:ojO1k0CoYkoZ1_nW_n/00onW`>_oZ;kYojRnj@04ojRn
j@OoYkkY1OnW`>`=ojO1k0GoZ<7/0_nX_n/6ojNojPGoYkkZ0_nW_n/7ojO0j`?oYl7/=?ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo007ooooo000oooooo`03o`000?oooooooooo02oo
oooo1_nX`>/7ojW0jPGoYko[0_nX_n/=ojK0k0KoYl7/0onY`>X3ojS1j`OoZKoY0onW_^X4ojVoj@Ko
Ykk[00?oY/3/ojNnj_nW_^X01?nW_^X6ojK0k003ojK1kOnW_n_oYko[00?oYko[1OnV`>`2ojNnjPKo
Yko[1OnW`N`2ojNnjPOoYkoZ0onW_n/:ojRnj@?oYkkY2OnW`>`=ojO1k003ojS1k?nX_n_oZ;o[00Co
Z;o[1_nW_nX00onW_^[oYko[ojNoj`04ojNoj`GoYl3[>Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo007ooooo0010ooooo`03o`000?oooooooooo02oooooo1onX`>/6ojW0jP03ojNo
jonX_n_oZ;o[00CoZ;o[3OnV`>`4ojO1k0;oY/3/1_nX`N/5ojVoj@;oZL7[1onY_nT3ojNnj`?oZKoY
1onW_^X3ojK0k0?oYkkZ1_nW_n/00onV`>coYkkZojNnjP04ojNnjPKoYko[00?oYl7/ojNnj_nW_^X0
1?nW_^X5ojNojP03ojRoj_nX_^WoZ;kY00[oZ;kY00?oYl7/ojO0k?nW`>`02OnW`>`<ojO1k0CoYko[
1_nX_n/3ojNojP[oYko[00?oYl3[ooooooooool0>oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo007ooooo0011ooooo`03o`000?oooooooooo02oooooo1onX`>/3ojW0jP?oZL3[1onX
_n/3ojK0k0CoY[o[1_nV`>`00onW`NcoY/3/ojK0k003ojK0k0KoZ<7[00?oZKoYojW1jonY`N/01?nY
`N/5ojVoj@;oZL7[1_nY_nT5ojNnjP03ojVojOnW_^[oYkkZ00GoYkkZ0onW_n/3ojRnj@OoYkkZ0onW
_n/4ojRnj@KoYkkZ00?oYkoZojRoj_nX_nX00onX_nX8ojRnj@GoYl7/1onW`>`;ojO1k003ojO0jonW
_n_oYko[00KoYko[0onX_n/2ojNojP[oYko[@Oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo007ooooo0012ooooo`;o0000<?ooool5ojS0j`;oYl3/1_nY`>/5ojRoj`;oZKoZ1onV_n/<
ojK0k0?oZ<7[1?nW`N`6ojW1j`03ojVojOnY`N_oZL7[00CoZL7[1_nY_nT00onW_^[oZKoYojVoj@03
ojVoj@GoYkkZ0_nY_nX6ojRnj@GoYkkZ0_nX_nX7ojRnj@?oYkkZ2OnX_nX3ojRnj@[oYl7/0onW`>`;
ojO1k0GoYl3[1_nW_n/00onW_^[oYkoZojNojP04ojNojPGoYko[A_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo007ooooo0014ooooo`03o`000?oooooooooo02kooooo00?oZ<3[ojO0
k?nW`>`01?nW`>`6ojW0j`03ojRojonY_n[oZKoZ00CoZKoZ1OnV_n/2ojNoj`coY/3/1onW`N`3ojW1
j`?oYl7/1onY`N/3ojVoj@CoZL7[1OnY_nT00onW_^[oZKoZojVojP04ojVojPKoZ;kY00?oYkkZojRo
j_nX_nX01?nX_nX5ojRnj@03ojS1jonX_n[oZ;oZ00WoZ;oZ6OnW`N`9ojO0j`;oYko[1OnW_^X6ojNo
jP03ojNojooooooooooo04Sooooo00?o0000ooooooooool01oooool1o`00007ooooo0Oooool004Go
oooo00?o0000ooooooooool0;oooool6ojO0k0?oZL3[1?nX`>/6ojVojP03ojJojonW_n_oYko[00Co
Yko[1OnV`>`00onW_n_oY/3/ojK0k004ojK0k0GoYl7/0_nV`>`6ojO1k0GoZL7[0_nW`N`7ojW1j`;o
ZKoY0onX`N/7ojVojP?oZ;kY1?nX`>/6ojRojP03ojRnjOnX`N_oZ<7[00?oZ<7[1onX_nXHojO1k0_o
Yl3[2_nW_^X3ojNojTkooooo00?o0000ooooooooool01_ooool1o`00007ooooo0Oooool004Kooooo
00?o0000ooooooooool0<?ooool5ojO0k0OoZ<3[0onY_nX4ojW0jPKoYko[00?oY/3/ojNojonW_n/0
0onW_n/6ojK0k003ojO1k?nV`>coY/3/00CoY/3/1_nW`N`00onY`N_oYl7/ojO1k004ojO1k0GoZL7[
00?oYl7/ojS1jonX`N/01?nX`N/5ojVojP;oYl7/1onX`>/3ojRojP;oYl7/1onX`N/3ojRojQSoYl7/
2_nW`>/=ojNnjU;ooooo00?o0000ooooooooool01_ooool1o`00007ooooo0Oooool004Oooooo0_l0
000aooooo`GoYl3/1OnX`>/2ojO0j`OoZL3Z0onW_n/3ojVojPKoYko[0onV`>`4ojJoj`KoY/3/0onW
`N`4ojK0k0KoYl7/00?oZL7[ojO1k?nW`N`00onW`N`6ojS1j`03ojVoj_nW`NcoYl7/00CoYl7/1OnX
`>/7ojO1k0GoZ<7[6OnW`N`:ojO0j`goYkkZE_ooool00ol0003oooooooooo`05ooooo`7o00000Ooo
ool1ooooo`00BOooool00ol0003oooooooooo`0_ooooo`GoYl3/00?oZ<3[ojO0jonW`>/01?nW`>/5
ojW0jP;oZ<3[1_nY_nX4ojNoj`;oZ;oZ1onV_n/=ojK0k0?oYl7/0onV`N`6ojO1k0?oZ<7[2_nW`N`0
0onX`>_oYl7/ojO1k009ojO1k003ojS1jonW`NcoYl7/01GoYl7/0_nW_n/:ojO0j`goYkkZF_ooool0
0ol0003oooooooooo`04ooooo`7o00000Oooool1ooooo`00B_ooool00ol0003oooooooooo`0_oooo
o`;oYl3/1?nV`>`6ojO0j`03ojW0j_nX`>_oZ<3[00CoZ<3[1_nY_nX00onW_n_oZ;oZojRojP03ojRo
jPGoY[o[0_nW_nX<ojK0k0OoY/7/0onW`N`3ojK1k2coYl7/1onW_n/5ojO0j`;oZ;kZ2onW_^YOoooo
o`03o`000?oooooooooo00?ooooo0Ol00001ooooo`7ooooo001;ooooo`03o`000?oooooooooo02oo
oooo1_nV`>`3ojO0j`?oYl3/1onX`>/3ojVojPCoZL3[1OnX_nX00onV_n_oYkoZojNojP04ojNojPco
Y/3/1OnV`N`2ojNoj`KoY/7/1OnW`N`2ojO0k1KoYl7/1?nW`>`7ojO1k0_oYko[00?oYl3[ojRnj_nX
_^X01?nX_^X7ojNnjV;ooooo00?o0000ooooooooool00oooool1o`00007ooooo0Oooool004cooooo
0_l0000`ooooo`KoY/3/1_nW`>`5ojS0j`;oYl3/1onY`>/2ojRojPCoZL3Z1_nW_nX3ojK0k0CoYkoZ
1OnV`>`00onV`NcoYko[ojNoj`04ojNoj`KoY/7/00?oYl7/ojO0k?nW`>`01?nW`>`4ojO1k0;oYko[
2onW`N`2ojNoj`OoYl3/0onW`N`2ojNojP[oYko[2_nX_^X3ojNnjVKooooo00?o0000ooooooooool0
0oooool1o`00007ooooo001>ooooo`03o`000?oooooooooo02kooooo1_nV`>`6ojO0k003ojS0jonW
`>coYl3/00CoYl3/1OnY`>/00onX`>_oZL3ZojW0jP05ojW0jP?oYkoZ0onY`>X7ojNojP;oY/3/1?nW
_nX6ojNoj`?oY/7/1?nW_n/6ojO0k003ojO1k?nW_n_oYko[00?oYko[1onW`N`6ojNoj`GoYl3/00?o
Z;kZojNoj_nW_nX01?nW_nX5ojNoj`;oZ;oZ2_nX_^Y/ooooo`03o`000?oooooooooo00;ooooo0Ol0
0001ooooo`00Coooool00ol0003oooooooooo`0_ooooo`GoY/3/0onW`>`4ojK0k0KoYl3/00?oZL3[
ojS0jonX`>/00onX`>/5ojW0jP;oZ<3[1_nY`>X5ojNojP03ojRoj_nW_n[oYkoZ00GoYkoZ0onW_n/3
ojRojPOoYko[0onW`>`3ojNnjPKoYko[0onW`N`4ojNojPKoYko[00?oYl3/ojRnj_nX_^X00onX_^X6
ojNojP03ojNojonX_n[oZ;oZ00CoZ;oZ1OnX_^Yaooooo`05o`000?ooooooooooooooool000000Ooo
ool0053ooooo00?o0000ooooooooool0;oooool2ojK0k0CoYko[1_nV`>`7ojO0k0GoZ<3[00?oZL3Z
ojS0jonX`>/01?nX`>/6ojW0jP03ojNoj_nX_n[oZ;oZ00?oZ;oZ1OnW_nX8ojRojPGoYko[00?oZ;oZ
ojNnj_nW_^X01OnW_^X3ojNoj`?oZ;oZ1onW_nX3ojNoj`?oZ;oZ1_nX_^X3ojNojPCoZ;o[1_nX_nX0
0onX_^[oooooooooo`1booooo`05o`000?ooooooooooooooool000000Oooool0057ooooo0_l0000`
ooooo`KoYko[1_nV`>`7ojO0k0;oZ<3[0onW`>`7ojS0j`?oZL3Z1?nX`>/5ojRojP03ojNoj_nX_n[o
Z;oZ00[oZ;oZ00?oYko[ojRoj_nX_nX00onX_nX5ojNnjPSoZ;oZ1OnW_nX8ojRojP?oZ;kZ0onX`>/7
ojRoj`?oZ;oZN?ooool01?l0003oooooooooool00001ooooo`00Doooool00ol0003oooooooooo`0^
ooooo`CoYko[0_nX_n/6ojK0k0GoYl3/00?oY/3/ojO0k?nW`>`01?nW`>`5ojS0j`;oYl7/1onX`>/2
ojRojPCoZ<3[2OnX_nX3ojS0j`KoZ;oZ00?oYkkZojRoj_nX_nX02_nX_nX00onW_n[oZ;oZojRojP08
ojRojPSoZ<3[1OnX_n]mooooo`03o`000?oooooo0000007ooooo001Dooooo`03o`000?oooooooooo
02kooooo00?oYko[ojRojonX_n/00onX_n/6ojK0k003ojO0k?nV`>coY/3/00?oY/3/1_nW`>`00onX
`>_oYl7/ojO1k004ojO1k0GoZ<3[00?oYl7/ojS0jonX`>/01OnX`>/3ojRojPWoZ<3[0onX_nX4ojS0
j`WoZ;oZ0onX`>/7ojRojPcoZ<3[00?oZ;o[ooooooooool0O_ooool00ol0003oooooo`000001oooo
o`00EOooool00ol0003oooooooooo`0^ooooo`KoZ;o[0onV`>`4ojNoj`GoY/3/0onW`>`4ojK0k0Ko
Yl7/00?oZ<3[ojO1k?nW`N`00onW`N`5ojS0j`;oYl7/2_nX`>/2ojO1k0OoZ<3[0onX_nX2ojO0k0Oo
Z<3[0onX_nX4ojO1k0WoZ<3[Q?ooool1o`00007ooooo0Ol0000005Kooooo0_l0000_ooooo`?oZ;o[
0onX`>/7ojNoj`;oY/3/1?nW_n/6ojK0k0?oYl7/1?nW`>`5ojO1k003ojS0jonW`NcoYl7/00CoYl7/
1onX`>/5ojO1k0GoZ<3[0_nW`N`5ojO0k0GoZ<3[2OnW`N`3ojS0jh[ooooo0_l0000005Sooooo00?o
0000ooooooooool0;Oooool6ojS0j`GoYko[0_nX_nX6ojNoj`?oY/3/0onW_n/7ojO0k0;oYl7/1?nW
`>`6ojO1k0?oZ<3[2OnW`N`00onX`>_oYl7/ojO1k004ojO1k0GoYl3/00?oZ<3[ojO1k?nW`N`02OnW
`Nb=ooooo`?o0000001Iooooo`03o`000?oooooooooo02gooooo1_nX`>/00onW_n_oZ;oZojRojP04
ojRojPCoYko[0_nX_nX6ojNoj`GoYl3/00?oYko[ojO0k?nW`>`01OnW`>`3ojO1k0CoYl3/4_nW`N`2
ojO0k0_oYl7/S?ooool4o`0000?ooooo001Jooooo`03o`000?oooooooooo02gooooo1onX`>/6ojRo
jP03ojNojonX_n[oZ;oZ00?oZ;oZ1_nW_n/00onW`>coYko[ojNoj`03ojNoj`GoYl3/0_nW_n/7ojO0
k0;oYl7/0onW`>`:ojO1k0?oYl3/2OnW`Nb<ooooo`?o00001oooool005_ooooo00?o0000oooooooo
ool0;Oooool7ojS0j`?oZ;oZ0onX`>/6ojRojP?oYko[1?nX_nX5ojNoj`03ojO0k?nW_n_oYko[00Co
Yko[1OnW`>`00onW_n_oYl3/ojO0k004ojO0k0GoYl7/00?oYko[ojO0k?nW`>`01OnW`>`3ojO1k8go
oooo1?l0000:ooooo`00G?ooool2o`0002kooooo1OnX`>/2ojO0j`KoZ<3[0onX_nX4ojS0j`KoZ;oZ
0_nW_n/4ojRojPKoYko[00?oYl3/ojNojonW_n/00onW_n/6ojO0k003ojO1k?nW_n_oYko[00?oYko[
1OnW`>b=ooooo`Co00003_ooool005kooooo00?o0000ooooooooool0;?ooool00onX`>_oYl3[ojO0
j`04ojO0j`goZ<3[0onX_nX2ojS0j`OoZ;oZ0onW_n/3ojRojPKoYko[0onW`>`9ojNoj`03ojO0k?oo
oooooooo08[ooooo1?l0000Booooo`00Goooool00ol0003oooooooooo`0]ooooo`KoYl3[4_nX`>/5
ojRojP;oZ<3[1_nX_nX3ojNoj`?oZ;oZ2OnW_n^;ooooo`Co00005_ooool0063ooooo00?o0000oooo
ooooool0;Oooool3ojO0j`CoYl3/4OnX`>/00onX_n[oZ<3[ojS0j`04ojS0j`CoZ;oZ0_nX`>/6ojRo
jPGoYko[Roooool3o`0001[ooooo001Qooooo`;o0000;oooool6ojO0k0;oZ<3[1?nW`N`BojS0j`03
ojRoj_nX`>_oZ<3[00?oZ<3[1_nX_nX00onW_n_oooooooooo`28ooooo`Co00007Oooool006?ooooo
00?o0000ooooooooool0;Oooool5ojO0k0OoYl7/0onX`>/3ojO1k0WoZ<3[0onW`>/6ojS0j`?oZ;oZ
ROooool4o`00027ooooo001Tooooo`03o`000?oooooooooo02gooooo1OnW`>`5ojO1k0;oYl3/1_nW
`N`3ojS0j`CoYl7/1OnW`>/3ojS0jh[ooooo1?l0000Uooooo`00IOooool00ol0003oooooooooo`0]
ooooo`GoYl3/00?oYl7/ojO0k?nW`>`01?nW`>`4ojO1k0;oYl3/1onW`N`2ojO0jh_ooooo1?l0000Y
ooooo`00I_ooool2o`0002kooooo0_nW`>`4ojNoj`KoYl3/00?oYl7/ojO0k?nW`>`00onW`>`5ojO1
k8_ooooo0ol0000]ooooo`00J?ooool00ol0003oooooooooo`0/ooooo`KoYko[0onW`>`3ojNoj`Ko
Yl3/00?oYl7/ooooooooool0R?ooool4o`00033ooooo001Yooooo`03o`000?oooooooooo02cooooo
0onW_n/4ojRoj`GoYko[0onW`>b9ooooo`Co0000=?ooool006[ooooo00?o0000ooooooooool0;?oo
ool7ojRoj`;oYko[R_ooool4o`0003Sooooo001[ooooo`;o0000;Oooool5ojRojhWooooo1?l0000l
ooooo`00KOooool00ol0003oooooooooo`0[ooooo`03ojRojooooooooooo08Oooooo0ol00010oooo
o`00K_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo08?ooooo1?l00013ooooo`00
Koooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo07oooooo1?l00017ooooo`00L?oo
ool2o`0002Wooooo00?o0000ooooooooool0Noooool4o`0004_ooooo001booooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool0Moooool4o`0004oooooo001cooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0M?ooool3o`0005?ooooo001dooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool0L?ooool4o`0005Kooooo001eooooo`03o`000?oooooooooo02?ooooo
00?o0000ooooooooool0K?ooool4o`0005[ooooo001fooooo`;o00008oooool00ol0003ooooooooo
o`1Xooooo`Co0000G_ooool007Sooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1T
ooooo`Co0000H_ooool007Wooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`1Qoooo
o`?o0000I_ooool007[ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1Mooooo`Co
0000JOooool007_ooooo0_l0000Nooooo`03o`000?oooooooooo05Wooooo1?l0001]ooooo`00OOoo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo05Gooooo1?l0001aooooo`00O_ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo057ooooo1?l0001eooooo`00Ooooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo04kooooo0ol0001iooooo`00P?ooool2o`0001Wo
oooo00?o0000ooooooooool0B_ooool4o`0007cooooo0022ooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool0A_ooool4o`00083ooooo0023ooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool0@_ooool4o`0008Cooooo0024ooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0?_ooool4o`0008Sooooo0025ooooo`;o00004oooool00ol0003oooooooooo`0loooo
o`?o0000S?ooool008Oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0hooooo`Co
0000Soooool008Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0dooooo`Co0000
Toooool008Wooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0`ooooo`Co0000Uooo
ool008[ooooo0_l0000>ooooo`03o`000?oooooooooo02cooooo1?l0002Kooooo`00S?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo02Wooooo0ol0002Oooooo`00SOooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo02Gooooo1?l0002Rooooo`00S_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo027ooooo1?l0002Vooooo`00Soooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo01gooooo1?l0002Zooooo`00T?ooool2o`0000Sooooo00?o0000
ooooooooool06Oooool4o`000:kooooo002Booooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool05_ooool3o`000;;ooooo002Cooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool04_ooool4o`000;Gooooo002Dooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
3_ooool4o`000;Wooooo002Eooooo`;o00000oooool00ol0003oooooooooo`0:ooooo`Co0000_Ooo
ool009Oooooo00Co0000oooooooooooo00002?ooool4o`000<7ooooo002Hooooo`03o`000?oooooo
000000Gooooo0ol00035ooooo`00VOooool2o`000003ooooool0003o000000;o0000b?ooool009[o
oooo0_l0003<ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0538698, 0.0432538, \
0.0035044, 0.0035044}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[.12586 .2075 -12 -8.99448 ]
[.12586 .2075 0 .00552 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.56094 .0364 -5.16972 -9 ]
[.56094 .0364 .83028 0 ]
[.75679 .08071 0 -6.17777 ]
[.75679 .08071 12 2.82223 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.9429 .3657 0 -5.9083 ]
[.9429 .3657 6 3.0917 ]
[.02494 .25992 -18 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.01611 .31527 -18 -2.78472 ]
[.01611 .31527 0 6.21528 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00254 .43215 -12 -2.88407 ]
[-0.00254 .43215 0 6.11593 ]
[-0.0124 .49393 -12 -2.93688 ]
[-0.0124 .49393 0 6.06312 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
[(-2)] .12586 .2075 1 .99877 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.56863 .04703 m
.57247 .05235 L
s
[(2)] .56094 .0364 .72324 1 Mshowa
.125 Mabswid
.18558 .19702 m
.18832 .19985 L
s
.23703 .17687 m
.23971 .17975 L
s
.28951 .15632 m
.29214 .15925 L
s
.39772 .11395 m
.40023 .11699 L
s
.4535 .09211 m
.45595 .0952 L
s
.51046 .06981 m
.51284 .07294 L
s
.08568 .23614 m
.08851 .23887 L
s
.62804 .02377 m
.63027 .02701 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.7445 .0853 m
.73835 .08759 L
s
[(-2)] .75679 .08071 -1 .37284 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.93037 .36962 m
.92411 .37158 L
s
[(2)] .9429 .3657 -1 .31296 Mshowa
.125 Mabswid
.7708 .12553 m
.7671 .12688 L
s
.79613 .16428 m
.79242 .1656 L
s
.82054 .20161 m
.81682 .20291 L
s
.86679 .27235 m
.86305 .2736 L
s
.88871 .30589 m
.88497 .30711 L
s
.9099 .3383 m
.90615 .3395 L
s
.71716 .04348 m
.71349 .04489 L
s
.95018 .39992 m
.94642 .40107 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(-20)] .02494 .25992 1 -0.39157 Mshowa
.02837 .31059 m
.0345 .30825 L
s
[(-10)] .01611 .31527 1 -0.38117 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.00981 .42772 m
.01599 .4255 L
s
[(10)] -0.00254 .43215 1 -0.3591 Mshowa
0 .48963 m
.0062 .48748 L
s
[(20)] -0.0124 .49393 1 -0.34736 Mshowa
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.657 .75 .919 r
.39362 .69478 .40169 .70188 .4152 .69802 .40717 .6909 Mtetra
.655 .75 .92 r
.40717 .6909 .4152 .69802 .42878 .69415 .42079 .68708 Mtetra
.654 .752 .922 r
.42079 .68708 .42878 .69415 .44242 .69034 .43448 .68326 Mtetra
.655 .753 .922 r
.43448 .68326 .44242 .69034 .45614 .68653 .44824 .67937 Mtetra
.656 .752 .921 r
.44824 .67937 .45614 .68653 .46992 .68267 .46207 .67542 Mtetra
.657 .751 .919 r
.46207 .67542 .46992 .68267 .48378 .67875 .47597 .67142 Mtetra
.657 .75 .918 r
.47597 .67142 .48378 .67875 .4977 .67479 .48994 .66741 Mtetra
.656 .749 .919 r
.48994 .66741 .4977 .67479 .5117 .67079 .50398 .66343 Mtetra
.654 .751 .921 r
.50398 .66343 .5117 .67079 .52577 .66678 .5181 .65949 Mtetra
.654 .753 .922 r
.5181 .65949 .52577 .66678 .53991 .66283 .53229 .65552 Mtetra
.655 .754 .923 r
.53229 .65552 .53991 .66283 .55412 .65887 .54655 .65149 Mtetra
.655 .753 .922 r
.54655 .65149 .55412 .65887 .56841 .65488 .56088 .64743 Mtetra
.656 .752 .921 r
.56088 .64743 .56841 .65488 .58277 .65086 .57529 .64333 Mtetra
.657 .752 .92 r
.57529 .64333 .58277 .65086 .59721 .6468 .58978 .63919 Mtetra
.657 .751 .919 r
.58978 .63919 .59721 .6468 .61172 .64271 .60434 .63502 Mtetra
.657 .75 .918 r
.60434 .63502 .61172 .64271 .62631 .6386 .61898 .63084 Mtetra
.657 .749 .918 r
.61898 .63084 .62631 .6386 .64097 .63446 .63369 .62664 Mtetra
.656 .748 .917 r
.63369 .62664 .64097 .63446 .65571 .6303 .64848 .62243 Mtetra
.64848 .62243 .65571 .6303 .67053 .62612 .66335 .6182 Mtetra
.66335 .6182 .67053 .62612 .68542 .62192 .6783 .61396 Mtetra
.6783 .61396 .68542 .62192 .7004 .6177 .69333 .6097 Mtetra
.656 .748 .918 r
.69333 .6097 .7004 .6177 .71545 .61346 .70844 .60543 Mtetra
.655 .748 .918 r
.70844 .60543 .71545 .61346 .73059 .6092 .72363 .60115 Mtetra
.72363 .60115 .73059 .6092 .7458 .60491 .73891 .59685 Mtetra
.655 .749 .919 r
.73891 .59685 .7458 .60491 .7611 .6006 .75426 .59253 Mtetra
.655 .75 .92 r
.75426 .59253 .7611 .6006 .77648 .59625 .7697 .58819 Mtetra
.656 .751 .92 r
.7697 .58819 .77648 .59625 .79194 .59187 .78522 .58379 Mtetra
.656 .752 .921 r
.78522 .58379 .79194 .59187 .80748 .58744 .80083 .57936 Mtetra
.656 .754 .922 r
.80083 .57936 .80748 .58744 .8231 .58298 .81651 .57489 Mtetra
.657 .755 .922 r
.81651 .57489 .8231 .58298 .83881 .57852 .83228 .57036 Mtetra
.657 .754 .921 r
.83228 .57036 .83881 .57852 .85461 .5741 .84814 .5658 Mtetra
.656 .751 .92 r
.84814 .5658 .85461 .5741 .8705 .56968 .86408 .56127 Mtetra
.655 .749 .919 r
.86408 .56127 .8705 .56968 .88648 .56522 .88012 .55677 Mtetra
.654 .749 .919 r
.88012 .55677 .88648 .56522 .90254 .56071 .89625 .55226 Mtetra
.655 .751 .92 r
.89625 .55226 .90254 .56071 .91868 .55613 .91247 .54768 Mtetra
.656 .752 .921 r
.91247 .54768 .91868 .55613 .93491 .55149 .92877 .54304 Mtetra
.657 .754 .921 r
.92877 .54304 .93491 .55149 .95123 .54685 .94515 .53833 Mtetra
.657 .753 .921 r
.94515 .53833 .95123 .54685 .96765 .54226 .96163 .53361 Mtetra
.655 .75 .92 r
.96163 .53361 .96765 .54226 .98417 .53766 .97821 .52895 Mtetra
.38547 .68763 .39362 .69478 .40717 .6909 .39906 .68379 Mtetra
.654 .752 .922 r
.39906 .68379 .40717 .6909 .42079 .68708 .41273 .67996 Mtetra
.655 .753 .922 r
.41273 .67996 .42079 .68708 .43448 .68326 .42646 .67605 Mtetra
.657 .752 .92 r
.42646 .67605 .43448 .68326 .44824 .67937 .44026 .67208 Mtetra
.658 .751 .919 r
.44026 .67208 .44824 .67937 .46207 .67542 .45414 .66805 Mtetra
.657 .75 .918 r
.45414 .66805 .46207 .67542 .47597 .67142 .46808 .66402 Mtetra
.654 .749 .92 r
.46808 .66402 .47597 .67142 .48994 .66741 .4821 .66008 Mtetra
.654 .752 .922 r
.4821 .66008 .48994 .66741 .50398 .66343 .49619 .65612 Mtetra
.655 .754 .923 r
.49619 .65612 .50398 .66343 .5181 .65949 .51035 .65211 Mtetra
.655 .753 .922 r
.51035 .65211 .5181 .65949 .53229 .65552 .52459 .64806 Mtetra
.656 .752 .921 r
.52459 .64806 .53229 .65552 .54655 .65149 .5389 .64395 Mtetra
.658 .752 .919 r
.5389 .64395 .54655 .65149 .56088 .64743 .55328 .63979 Mtetra
.658 .75 .918 r
.55328 .63979 .56088 .64743 .57529 .64333 .56774 .6356 Mtetra
.657 .748 .917 r
.56774 .6356 .57529 .64333 .58978 .63919 .58228 .63141 Mtetra
.656 .748 .917 r
.58228 .63141 .58978 .63919 .60434 .63502 .59689 .62724 Mtetra
.655 .749 .918 r
.59689 .62724 .60434 .63502 .61898 .63084 .61158 .62306 Mtetra
.655 .75 .919 r
.61158 .62306 .61898 .63084 .63369 .62664 .62635 .61887 Mtetra
.655 .751 .92 r
.62635 .61887 .63369 .62664 .64848 .62243 .64119 .61464 Mtetra
.656 .752 .921 r
.64119 .61464 .64848 .62243 .66335 .6182 .65612 .61039 Mtetra
.65612 .61039 .66335 .6182 .6783 .61396 .67112 .60611 Mtetra
.67112 .60611 .6783 .61396 .69333 .6097 .68621 .6018 Mtetra
.68621 .6018 .69333 .6097 .70844 .60543 .70137 .59745 Mtetra
.656 .751 .92 r
.70137 .59745 .70844 .60543 .72363 .60115 .71661 .59308 Mtetra
.656 .75 .919 r
.71661 .59308 .72363 .60115 .73891 .59685 .73194 .58869 Mtetra
.656 .749 .918 r
.73194 .58869 .73891 .59685 .75426 .59253 .74735 .58429 Mtetra
.655 .748 .918 r
.74735 .58429 .75426 .59253 .7697 .58819 .76285 .57991 Mtetra
.76285 .57991 .7697 .58819 .78522 .58379 .77843 .57552 Mtetra
.654 .749 .919 r
.77843 .57552 .78522 .58379 .80083 .57936 .7941 .57111 Mtetra
.655 .751 .92 r
.7941 .57111 .80083 .57936 .81651 .57489 .80985 .56664 Mtetra
.656 .752 .921 r
.80985 .56664 .81651 .57489 .83228 .57036 .82569 .56211 Mtetra
.657 .754 .921 r
.82569 .56211 .83228 .57036 .84814 .5658 .84161 .55753 Mtetra
.657 .755 .922 r
.84161 .55753 .84814 .5658 .86408 .56127 .85761 .55289 Mtetra
.657 .753 .921 r
.85761 .55289 .86408 .56127 .88012 .55677 .8737 .54824 Mtetra
.655 .749 .919 r
.8737 .54824 .88012 .55677 .89625 .55226 .8899 .54367 Mtetra
.654 .749 .919 r
.8899 .54367 .89625 .55226 .91247 .54768 .90618 .5391 Mtetra
.655 .75 .92 r
.90618 .5391 .91247 .54768 .92877 .54304 .92255 .53445 Mtetra
.656 .752 .92 r
.92255 .53445 .92877 .54304 .94515 .53833 .93901 .52974 Mtetra
.657 .754 .921 r
.93901 .52974 .94515 .53833 .96163 .53361 .95555 .52495 Mtetra
.657 .753 .921 r
.95555 .52495 .96163 .53361 .97821 .52895 .97219 .52016 Mtetra
.654 .752 .922 r
.37724 .68048 .38547 .68763 .39906 .68379 .39088 .67664 Mtetra
.655 .753 .922 r
.39088 .67664 .39906 .68379 .41273 .67996 .40459 .67271 Mtetra
.657 .752 .92 r
.40459 .67271 .41273 .67996 .42646 .67605 .41836 .66873 Mtetra
.658 .751 .919 r
.41836 .66873 .42646 .67605 .44026 .67208 .43221 .66468 Mtetra
.657 .75 .918 r
.43221 .66468 .44026 .67208 .45414 .66805 .44613 .66065 Mtetra
.654 .75 .92 r
.44613 .66065 .45414 .66805 .46808 .66402 .46012 .6567 Mtetra
.654 .753 .923 r
.46012 .6567 .46808 .66402 .4821 .66008 .47419 .65272 Mtetra
.655 .754 .922 r
.47419 .65272 .4821 .66008 .49619 .65612 .48832 .64868 Mtetra
.656 .753 .921 r
.48832 .64868 .49619 .65612 .51035 .65211 .50253 .64459 Mtetra
.658 .752 .919 r
.50253 .64459 .51035 .65211 .52459 .64806 .51682 .64042 Mtetra
.658 .75 .918 r
.51682 .64042 .52459 .64806 .5389 .64395 .53118 .63622 Mtetra
.657 .748 .917 r
.53118 .63622 .5389 .64395 .55328 .63979 .54561 .63204 Mtetra
.655 .748 .919 r
.54561 .63204 .55328 .63979 .56774 .6356 .56012 .62791 Mtetra
.655 .751 .92 r
.56012 .62791 .56774 .6356 .58228 .63141 .57471 .62377 Mtetra
.654 .753 .922 r
.57471 .62377 .58228 .63141 .59689 .62724 .58937 .6196 Mtetra
.655 .754 .923 r
.58937 .6196 .59689 .62724 .61158 .62306 .60412 .6154 Mtetra
.655 .755 .923 r
.60412 .6154 .61158 .62306 .62635 .61887 .61894 .61116 Mtetra
.61894 .61116 .62635 .61887 .64119 .61464 .63384 .60689 Mtetra
.63384 .60689 .64119 .61464 .65612 .61039 .64881 .6026 Mtetra
.64881 .6026 .65612 .61039 .67112 .60611 .66387 .59827 Mtetra
.656 .755 .923 r
.66387 .59827 .67112 .60611 .68621 .6018 .67901 .59392 Mtetra
.67901 .59392 .68621 .6018 .70137 .59745 .69423 .58954 Mtetra
.69423 .58954 .70137 .59745 .71661 .59308 .70954 .58512 Mtetra
.70954 .58512 .71661 .59308 .73194 .58869 .72492 .58067 Mtetra
.657 .755 .922 r
.72492 .58067 .73194 .58869 .74735 .58429 .74039 .57618 Mtetra
.657 .754 .921 r
.74039 .57618 .74735 .58429 .76285 .57991 .75594 .57167 Mtetra
.657 .751 .92 r
.75594 .57167 .76285 .57991 .77843 .57552 .77157 .56714 Mtetra
.655 .748 .918 r
.77157 .56714 .77843 .57552 .7941 .57111 .7873 .56266 Mtetra
.654 .747 .918 r
.7873 .56266 .7941 .57111 .80985 .56664 .80311 .55819 Mtetra
.654 .749 .919 r
.80311 .55819 .80985 .56664 .82569 .56211 .81902 .5537 Mtetra
.656 .751 .92 r
.81902 .5537 .82569 .56211 .84161 .55753 .835 .54912 Mtetra
.656 .753 .921 r
.835 .54912 .84161 .55753 .85761 .55289 .85108 .54448 Mtetra
.657 .754 .922 r
.85108 .54448 .85761 .55289 .8737 .54824 .86723 .53977 Mtetra
.657 .754 .921 r
.86723 .53977 .8737 .54824 .8899 .54367 .88348 .53503 Mtetra
.655 .75 .92 r
.88348 .53503 .8899 .54367 .90618 .5391 .89982 .53037 Mtetra
.654 .749 .919 r
.89982 .53037 .90618 .5391 .92255 .53445 .91627 .52572 Mtetra
.655 .75 .92 r
.91627 .52572 .92255 .53445 .93901 .52974 .9328 .52101 Mtetra
.656 .752 .92 r
.9328 .52101 .93901 .52974 .95555 .52495 .94942 .51623 Mtetra
.658 .754 .921 r
.94942 .51623 .95555 .52495 .97219 .52016 .96612 .51135 Mtetra
.655 .753 .922 r
.36894 .6733 .37724 .68048 .39088 .67664 .38262 .66937 Mtetra
.657 .752 .92 r
.38262 .66937 .39088 .67664 .40459 .67271 .39637 .66537 Mtetra
.658 .751 .919 r
.39637 .66537 .40459 .67271 .41836 .66873 .41019 .66129 Mtetra
.657 .75 .918 r
.41019 .66129 .41836 .66873 .43221 .66468 .42409 .65725 Mtetra
.654 .75 .921 r
.42409 .65725 .43221 .66468 .44613 .66065 .43805 .65329 Mtetra
.654 .753 .923 r
.43805 .65329 .44613 .66065 .46012 .6567 .45209 .6493 Mtetra
.655 .753 .922 r
.45209 .6493 .46012 .6567 .47419 .65272 .4662 .64523 Mtetra
.657 .752 .92 r
.4662 .64523 .47419 .65272 .48832 .64868 .48038 .64109 Mtetra
.658 .751 .918 r
.48038 .64109 .48832 .64868 .50253 .64459 .49464 .63688 Mtetra
.658 .749 .917 r
.49464 .63688 .50253 .64459 .51682 .64042 .50897 .63268 Mtetra
.655 .748 .919 r
.50897 .63268 .51682 .64042 .53118 .63622 .52338 .62856 Mtetra
.654 .751 .921 r
.52338 .62856 .53118 .63622 .54561 .63204 .53787 .62444 Mtetra
.654 .754 .923 r
.53787 .62444 .54561 .63204 .56012 .62791 .55243 .62029 Mtetra
.55243 .62029 .56012 .62791 .57471 .62377 .56706 .61609 Mtetra
.655 .754 .923 r
.56706 .61609 .57471 .62377 .58937 .6196 .58178 .61186 Mtetra
.655 .754 .922 r
.58178 .61186 .58937 .6196 .60412 .6154 .59658 .60759 Mtetra
.656 .753 .922 r
.59658 .60759 .60412 .6154 .61894 .61116 .61145 .60329 Mtetra
.656 .753 .921 r
.61145 .60329 .61894 .61116 .63384 .60689 .6264 .59896 Mtetra
.656 .752 .921 r
.6264 .59896 .63384 .60689 .64881 .6026 .64143 .5946 Mtetra
.656 .752 .92 r
.64143 .5946 .64881 .6026 .66387 .59827 .65655 .59024 Mtetra
.655 .752 .921 r
.65655 .59024 .66387 .59827 .67901 .59392 .67174 .58586 Mtetra
.67174 .58586 .67901 .59392 .69423 .58954 .68702 .58145 Mtetra
.656 .753 .921 r
.68702 .58145 .69423 .58954 .70954 .58512 .70238 .57701 Mtetra
.656 .753 .922 r
.70238 .57701 .70954 .58512 .72492 .58067 .71783 .57254 Mtetra
.656 .754 .922 r
.71783 .57254 .72492 .58067 .74039 .57618 .73335 .56804 Mtetra
.656 .755 .922 r
.73335 .56804 .74039 .57618 .75594 .57167 .74896 .56349 Mtetra
.657 .755 .922 r
.74896 .56349 .75594 .57167 .77157 .56714 .76466 .55889 Mtetra
.76466 .55889 .77157 .56714 .7873 .56266 .78044 .55426 Mtetra
.657 .752 .92 r
.78044 .55426 .7873 .56266 .80311 .55819 .79631 .54963 Mtetra
.654 .748 .919 r
.79631 .54963 .80311 .55819 .81902 .5537 .81227 .54508 Mtetra
.654 .747 .919 r
.81227 .54508 .81902 .5537 .835 .54912 .82833 .54053 Mtetra
.655 .75 .92 r
.82833 .54053 .835 .54912 .85108 .54448 .84447 .53591 Mtetra
.656 .752 .921 r
.84447 .53591 .85108 .54448 .86723 .53977 .8607 .53121 Mtetra
.657 .754 .921 r
.8607 .53121 .86723 .53977 .88348 .53503 .87701 .52643 Mtetra
.658 .754 .921 r
.87701 .52643 .88348 .53503 .89982 .53037 .89341 .52161 Mtetra
.655 .75 .92 r
.89341 .52161 .89982 .53037 .91627 .52572 .90991 .51686 Mtetra
.654 .749 .919 r
.90991 .51686 .91627 .52572 .9328 .52101 .92652 .51215 Mtetra
.655 .75 .92 r
.92652 .51215 .9328 .52101 .94942 .51623 .94321 .50736 Mtetra
.656 .752 .92 r
.94321 .50736 .94942 .51623 .96612 .51135 .95999 .50248 Mtetra
.656 .752 .921 r
.36056 .66601 .36894 .6733 .38262 .66937 .37428 .662 Mtetra
.658 .751 .919 r
.37428 .662 .38262 .66937 .39637 .66537 .38808 .65791 Mtetra
.657 .75 .918 r
.38808 .65791 .39637 .66537 .41019 .66129 .40195 .65384 Mtetra
.654 .75 .921 r
.40195 .65384 .41019 .66129 .42409 .65725 .41588 .64986 Mtetra
.654 .753 .923 r
.41588 .64986 .42409 .65725 .43805 .65329 .42989 .64585 Mtetra
.655 .753 .922 r
.42989 .64585 .43805 .65329 .45209 .6493 .44397 .64176 Mtetra
.658 .752 .92 r
.44397 .64176 .45209 .6493 .4662 .64523 .45813 .63758 Mtetra
.659 .75 .918 r
.45813 .63758 .4662 .64523 .48038 .64109 .47237 .63335 Mtetra
.656 .748 .918 r
.47237 .63335 .48038 .64109 .49464 .63688 .48667 .62918 Mtetra
.654 .75 .92 r
.48667 .62918 .49464 .63688 .50897 .63268 .50105 .62507 Mtetra
.653 .753 .923 r
.50105 .62507 .50897 .63268 .52338 .62856 .51551 .62094 Mtetra
.654 .754 .923 r
.51551 .62094 .52338 .62856 .53787 .62444 .53004 .61675 Mtetra
.655 .754 .922 r
.53004 .61675 .53787 .62444 .55243 .62029 .54465 .61252 Mtetra
.656 .753 .921 r
.54465 .61252 .55243 .62029 .56706 .61609 .55934 .60823 Mtetra
.658 .752 .92 r
.55934 .60823 .56706 .61609 .58178 .61186 .57411 .60386 Mtetra
.658 .75 .918 r
.57411 .60386 .58178 .61186 .59658 .60759 .58896 .59948 Mtetra
.657 .748 .917 r
.58896 .59948 .59658 .60759 .61145 .60329 .60388 .5951 Mtetra
.657 .747 .916 r
.60388 .5951 .61145 .60329 .6264 .59896 .61889 .5907 Mtetra
.657 .746 .916 r
.61889 .5907 .6264 .59896 .64143 .5946 .63397 .5863 Mtetra
.656 .746 .916 r
.63397 .5863 .64143 .5946 .65655 .59024 .64914 .58189 Mtetra
.64914 .58189 .65655 .59024 .67174 .58586 .66439 .57747 Mtetra
.655 .746 .916 r
.66439 .57747 .67174 .58586 .68702 .58145 .67973 .57304 Mtetra
.655 .746 .917 r
.67973 .57304 .68702 .58145 .70238 .57701 .69515 .5686 Mtetra
.654 .747 .918 r
.69515 .5686 .70238 .57701 .71783 .57254 .71065 .56415 Mtetra
.654 .749 .919 r
.71065 .56415 .71783 .57254 .73335 .56804 .72624 .55969 Mtetra
.655 .751 .921 r
.72624 .55969 .73335 .56804 .74896 .56349 .74192 .55515 Mtetra
.656 .753 .921 r
.74192 .55515 .74896 .56349 .76466 .55889 .75767 .55055 Mtetra
.657 .754 .922 r
.75767 .55055 .76466 .55889 .78044 .55426 .77352 .5459 Mtetra
.657 .755 .922 r
.77352 .5459 .78044 .55426 .79631 .54963 .78945 .54119 Mtetra
.657 .754 .921 r
.78945 .54119 .79631 .54963 .81227 .54508 .80546 .53646 Mtetra
.656 .75 .92 r
.80546 .53646 .81227 .54508 .82833 .54053 .82157 .53178 Mtetra
.654 .747 .919 r
.82157 .53178 .82833 .54053 .84447 .53591 .83778 .52717 Mtetra
.654 .749 .919 r
.83778 .52717 .84447 .53591 .8607 .53121 .85408 .52249 Mtetra
.656 .752 .92 r
.85408 .52249 .8607 .53121 .87701 .52643 .87047 .51772 Mtetra
.657 .754 .921 r
.87047 .51772 .87701 .52643 .89341 .52161 .88694 .51286 Mtetra
.658 .754 .921 r
.88694 .51286 .89341 .52161 .90991 .51686 .9035 .50796 Mtetra
.655 .75 .92 r
.9035 .50796 .90991 .51686 .92652 .51215 .92017 .50315 Mtetra
.654 .749 .919 r
.92017 .50315 .92652 .51215 .94321 .50736 .93693 .49836 Mtetra
.655 .751 .92 r
.93693 .49836 .94321 .50736 .95999 .50248 .95379 .49348 Mtetra
.658 .752 .919 r
.35209 .65861 .36056 .66601 .37428 .662 .36587 .65451 Mtetra
.658 .75 .918 r
.36587 .65451 .37428 .662 .38808 .65791 .37971 .6504 Mtetra
.654 .75 .92 r
.37971 .6504 .38808 .65791 .40195 .65384 .39361 .6464 Mtetra
.653 .753 .922 r
.39361 .6464 .40195 .65384 .41588 .64986 .4076 .64238 Mtetra
.655 .753 .922 r
.4076 .64238 .41588 .64986 .42989 .64585 .42165 .63828 Mtetra
.658 .752 .92 r
.42165 .63828 .42989 .64585 .44397 .64176 .43578 .63407 Mtetra
.659 .75 .918 r
.43578 .63407 .44397 .64176 .45813 .63758 .44999 .62982 Mtetra
.655 .749 .918 r
.44999 .62982 .45813 .63758 .47237 .63335 .46427 .62566 Mtetra
.653 .751 .921 r
.46427 .62566 .47237 .63335 .48667 .62918 .47862 .62154 Mtetra
.654 .754 .923 r
.47862 .62154 .48667 .62918 .50105 .62507 .49305 .61739 Mtetra
.655 .754 .923 r
.49305 .61739 .50105 .62507 .51551 .62094 .50756 .61318 Mtetra
.657 .753 .921 r
.50756 .61318 .51551 .62094 .53004 .61675 .52214 .60887 Mtetra
.659 .752 .919 r
.52214 .60887 .53004 .61675 .54465 .61252 .53681 .60448 Mtetra
.658 .749 .917 r
.53681 .60448 .54465 .61252 .55934 .60823 .55155 .60008 Mtetra
.657 .747 .916 r
.55155 .60008 .55934 .60823 .57411 .60386 .56636 .59569 Mtetra
.655 .747 .917 r
.56636 .59569 .57411 .60386 .58896 .59948 .58126 .59136 Mtetra
.655 .749 .919 r
.58126 .59136 .58896 .59948 .60388 .5951 .59624 .587 Mtetra
.655 .751 .92 r
.59624 .587 .60388 .5951 .61889 .5907 .6113 .58262 Mtetra
.655 .752 .921 r
.6113 .58262 .61889 .5907 .63397 .5863 .62644 .5782 Mtetra
.656 .753 .921 r
.62644 .5782 .63397 .5863 .64914 .58189 .64167 .57374 Mtetra
.64167 .57374 .64914 .58189 .66439 .57747 .65698 .56925 Mtetra
.656 .752 .921 r
.65698 .56925 .66439 .57747 .67973 .57304 .67236 .56472 Mtetra
.657 .751 .92 r
.67236 .56472 .67973 .57304 .69515 .5686 .68784 .56016 Mtetra
.657 .749 .918 r
.68784 .56016 .69515 .5686 .71065 .56415 .7034 .55558 Mtetra
.655 .747 .917 r
.7034 .55558 .71065 .56415 .72624 .55969 .71904 .55105 Mtetra
.654 .745 .917 r
.71904 .55105 .72624 .55969 .74192 .55515 .73478 .54653 Mtetra
.653 .747 .918 r
.73478 .54653 .74192 .55515 .75767 .55055 .75061 .54201 Mtetra
.655 .751 .92 r
.75061 .54201 .75767 .55055 .77352 .5459 .76652 .53739 Mtetra
.656 .753 .921 r
.76652 .53739 .77352 .5459 .78945 .54119 .78251 .53267 Mtetra
.657 .755 .922 r
.78251 .53267 .78945 .54119 .80546 .53646 .7986 .52789 Mtetra
.658 .755 .922 r
.7986 .52789 .80546 .53646 .82157 .53178 .81476 .52307 Mtetra
.656 .752 .92 r
.81476 .52307 .82157 .53178 .83778 .52717 .83103 .51829 Mtetra
.653 .748 .919 r
.83103 .51829 .83778 .52717 .85408 .52249 .8474 .5136 Mtetra
.654 .749 .919 r
.8474 .5136 .85408 .52249 .87047 .51772 .86385 .50886 Mtetra
.656 .752 .92 r
.86385 .50886 .87047 .51772 .88694 .51286 .8804 .50401 Mtetra
.658 .754 .921 r
.8804 .50401 .88694 .51286 .9035 .50796 .89703 .49906 Mtetra
.89703 .49906 .9035 .50796 .92017 .50315 .91375 .49408 Mtetra
.654 .75 .92 r
.91375 .49408 .92017 .50315 .93693 .49836 .93059 .48922 Mtetra
.654 .749 .92 r
.93059 .48922 .93693 .49836 .95379 .49348 .94752 .48434 Mtetra
.658 .751 .918 r
.34355 .65112 .35209 .65861 .36587 .65451 .35737 .64697 Mtetra
.655 .75 .92 r
.35737 .64697 .36587 .65451 .37971 .6504 .37125 .64292 Mtetra
.653 .752 .922 r
.37125 .64292 .37971 .6504 .39361 .6464 .3852 .6389 Mtetra
.655 .753 .922 r
.3852 .6389 .39361 .6464 .4076 .64238 .39923 .63478 Mtetra
.658 .752 .92 r
.39923 .63478 .4076 .64238 .42165 .63828 .41334 .63056 Mtetra
.659 .751 .918 r
.41334 .63056 .42165 .63828 .43578 .63407 .42752 .62628 Mtetra
.655 .749 .919 r
.42752 .62628 .43578 .63407 .44999 .62982 .44177 .62211 Mtetra
.653 .751 .922 r
.44177 .62211 .44999 .62982 .46427 .62566 .45609 .61799 Mtetra
.654 .754 .923 r
.45609 .61799 .46427 .62566 .47862 .62154 .47049 .61381 Mtetra
.655 .753 .922 r
.47049 .61381 .47862 .62154 .49305 .61739 .48497 .60957 Mtetra
.659 .753 .92 r
.48497 .60957 .49305 .61739 .50756 .61318 .49953 .60517 Mtetra
.659 .75 .917 r
.49953 .60517 .50756 .61318 .52214 .60887 .51417 .60074 Mtetra
.657 .747 .916 r
.51417 .60074 .52214 .60887 .53681 .60448 .52888 .59637 Mtetra
.655 .748 .918 r
.52888 .59637 .53681 .60448 .55155 .60008 .54367 .59207 Mtetra
.654 .751 .921 r
.54367 .59207 .55155 .60008 .56636 .59569 .55854 .58776 Mtetra
.654 .754 .923 r
.55854 .58776 .56636 .59569 .58126 .59136 .5735 .58341 Mtetra
.654 .755 .924 r
.5735 .58341 .58126 .59136 .59624 .587 .58853 .57903 Mtetra
.655 .756 .924 r
.58853 .57903 .59624 .587 .6113 .58262 .60365 .57461 Mtetra
.60365 .57461 .6113 .58262 .62644 .5782 .61885 .57014 Mtetra
.61885 .57014 .62644 .5782 .64167 .57374 .63413 .56564 Mtetra
.656 .756 .924 r
.63413 .56564 .64167 .57374 .65698 .56925 .64949 .5611 Mtetra
.64949 .5611 .65698 .56925 .67236 .56472 .66494 .55652 Mtetra
.657 .756 .923 r
.66494 .55652 .67236 .56472 .68784 .56016 .68047 .5519 Mtetra
.68047 .5519 .68784 .56016 .7034 .55558 .69609 .54724 Mtetra
.657 .755 .922 r
.69609 .54724 .7034 .55558 .71904 .55105 .71179 .54255 Mtetra
.657 .752 .92 r
.71179 .54255 .71904 .55105 .73478 .54653 .72758 .53784 Mtetra
.655 .748 .918 r
.72758 .53784 .73478 .54653 .75061 .54201 .74346 .53319 Mtetra
.653 .745 .918 r
.74346 .53319 .75061 .54201 .76652 .53739 .75944 .52861 Mtetra
.653 .748 .919 r
.75944 .52861 .76652 .53739 .78251 .53267 .77551 .52399 Mtetra
.656 .752 .921 r
.77551 .52399 .78251 .53267 .7986 .52789 .79165 .51922 Mtetra
.657 .754 .921 r
.79165 .51922 .7986 .52789 .81476 .52307 .80789 .51437 Mtetra
.658 .755 .921 r
.80789 .51437 .81476 .52307 .83103 .51829 .82421 .50945 Mtetra
.656 .752 .921 r
.82421 .50945 .83103 .51829 .8474 .5136 .84063 .50459 Mtetra
.653 .748 .919 r
.84063 .50459 .8474 .5136 .86385 .50886 .85716 .49983 Mtetra
.654 .749 .92 r
.85716 .49983 .86385 .50886 .8804 .50401 .87378 .49501 Mtetra
.656 .752 .92 r
.87378 .49501 .8804 .50401 .89703 .49906 .89049 .49006 Mtetra
.658 .754 .921 r
.89049 .49006 .89703 .49906 .91375 .49408 .90728 .48502 Mtetra
.657 .753 .921 r
.90728 .48502 .91375 .49408 .93059 .48922 .92417 .48 Mtetra
.654 .749 .92 r
.92417 .48 .93059 .48922 .94752 .48434 .94118 .47508 Mtetra
.656 .75 .919 r
.33493 .64353 .34355 .65112 .35737 .64697 .34879 .63941 Mtetra
.653 .751 .922 r
.34879 .63941 .35737 .64697 .37125 .64292 .36271 .63538 Mtetra
.654 .753 .922 r
.36271 .63538 .37125 .64292 .3852 .6389 .37671 .63127 Mtetra
.657 .752 .92 r
.37671 .63127 .3852 .6389 .39923 .63478 .39079 .62706 Mtetra
.659 .751 .918 r
.39079 .62706 .39923 .63478 .41334 .63056 .40494 .62274 Mtetra
.656 .749 .919 r
.40494 .62274 .41334 .63056 .42752 .62628 .41916 .61854 Mtetra
.653 .751 .922 r
.41916 .61854 .42752 .62628 .44177 .62211 .43346 .6144 Mtetra
.654 .753 .923 r
.43346 .6144 .44177 .62211 .45609 .61799 .44783 .61021 Mtetra
.656 .753 .922 r
.44783 .61021 .45609 .61799 .47049 .61381 .46229 .60593 Mtetra
.66 .753 .919 r
.46229 .60593 .47049 .61381 .48497 .60957 .47682 .60148 Mtetra
.659 .749 .916 r
.47682 .60148 .48497 .60957 .49953 .60517 .49143 .59703 Mtetra
.655 .747 .918 r
.49143 .59703 .49953 .60517 .51417 .60074 .50611 .59273 Mtetra
.653 .751 .921 r
.50611 .59273 .51417 .60074 .52888 .59637 .52087 .58845 Mtetra
.653 .754 .924 r
.52087 .58845 .52888 .59637 .54367 .59207 .53572 .58414 Mtetra
.654 .755 .924 r
.53572 .58414 .54367 .59207 .55854 .58776 .55064 .57978 Mtetra
.55064 .57978 .55854 .58776 .5735 .58341 .56565 .57536 Mtetra
.655 .755 .923 r
.56565 .57536 .5735 .58341 .58853 .57903 .58074 .5709 Mtetra
.656 .754 .922 r
.58074 .5709 .58853 .57903 .60365 .57461 .59591 .56637 Mtetra
.656 .753 .921 r
.59591 .56637 .60365 .57461 .61885 .57014 .61116 .56182 Mtetra
.656 .752 .92 r
.61116 .56182 .61885 .57014 .63413 .56564 .6265 .55727 Mtetra
.655 .751 .921 r
.6265 .55727 .63413 .56564 .64949 .5611 .64192 .55273 Mtetra
.655 .752 .921 r
.64192 .55273 .64949 .5611 .66494 .55652 .65743 .54816 Mtetra
.656 .754 .922 r
.65743 .54816 .66494 .55652 .68047 .5519 .67302 .54354 Mtetra
.656 .755 .923 r
.67302 .54354 .68047 .5519 .69609 .54724 .6887 .53885 Mtetra
.657 .756 .923 r
.6887 .53885 .69609 .54724 .71179 .54255 .70447 .53411 Mtetra
.658 .757 .923 r
.70447 .53411 .71179 .54255 .72758 .53784 .72031 .52932 Mtetra
.658 .756 .922 r
.72031 .52932 .72758 .53784 .74346 .53319 .73625 .5245 Mtetra
.657 .752 .92 r
.73625 .5245 .74346 .53319 .75944 .52861 .75228 .51969 Mtetra
.653 .746 .918 r
.75228 .51969 .75944 .52861 .77551 .52399 .76841 .51503 Mtetra
.652 .746 .919 r
.76841 .51503 .77551 .52399 .79165 .51922 .78464 .51037 Mtetra
.656 .752 .92 r
.78464 .51037 .79165 .51922 .80789 .51437 .80094 .50554 Mtetra
.658 .754 .921 r
.80094 .50554 .80789 .51437 .82421 .50945 .81733 .5006 Mtetra
.658 .755 .921 r
.81733 .5006 .82421 .50945 .84063 .50459 .83381 .4956 Mtetra
.656 .752 .921 r
.83381 .4956 .84063 .50459 .85716 .49983 .8504 .49068 Mtetra
.653 .748 .919 r
.8504 .49068 .85716 .49983 .87378 .49501 .86709 .48586 Mtetra
.655 .75 .92 r
.86709 .48586 .87378 .49501 .89049 .49006 .88387 .48093 Mtetra
.657 .752 .92 r
.88387 .48093 .89049 .49006 .90728 .48502 .90074 .47588 Mtetra
.658 .754 .921 r
.90074 .47588 .90728 .48502 .92417 .48 .9177 .47075 Mtetra
.655 .752 .921 r
.9177 .47075 .92417 .48 .94118 .47508 .93477 .4657 Mtetra
.654 .75 .921 r
.32623 .6359 .33493 .64353 .34879 .63941 .34012 .63183 Mtetra
.653 .752 .922 r
.34012 .63183 .34879 .63941 .36271 .63538 .35409 .62773 Mtetra
.656 .752 .921 r
.35409 .62773 .36271 .63538 .37671 .63127 .36814 .62354 Mtetra
.659 .752 .919 r
.36814 .62354 .37671 .63127 .39079 .62706 .38226 .61921 Mtetra
.657 .749 .918 r
.38226 .61921 .39079 .62706 .40494 .62274 .39646 .61493 Mtetra
.653 .75 .921 r
.39646 .61493 .40494 .62274 .41916 .61854 .41073 .61078 Mtetra
.653 .753 .923 r
.41073 .61078 .41916 .61854 .43346 .6144 .42507 .60658 Mtetra
.655 .753 .922 r
.42507 .60658 .43346 .6144 .44783 .61021 .4395 .60229 Mtetra
.66 .753 .919 r
.4395 .60229 .44783 .61021 .46229 .60593 .454 .5978 Mtetra
.659 .748 .916 r
.454 .5978 .46229 .60593 .47682 .60148 .46858 .59335 Mtetra
.654 .748 .919 r
.46858 .59335 .47682 .60148 .49143 .59703 .48324 .58907 Mtetra
.652 .753 .923 r
.48324 .58907 .49143 .59703 .50611 .59273 .49797 .58479 Mtetra
.653 .754 .924 r
.49797 .58479 .50611 .59273 .52087 .58845 .51279 .58046 Mtetra
.654 .755 .924 r
.51279 .58046 .52087 .58845 .53572 .58414 .52769 .57606 Mtetra
.658 .755 .921 r
.52769 .57606 .53572 .58414 .55064 .57978 .54266 .5715 Mtetra
.659 .751 .918 r
.54266 .5715 .55064 .57978 .56565 .57536 .55772 .56688 Mtetra
.659 .747 .915 r
.55772 .56688 .56565 .57536 .58074 .5709 .57286 .56226 Mtetra
.658 .744 .914 r
.57286 .56226 .58074 .5709 .59591 .56637 .58809 .55765 Mtetra
.657 .743 .913 r
.58809 .55765 .59591 .56637 .61116 .56182 .60339 .55306 Mtetra
.656 .743 .914 r
.60339 .55306 .61116 .56182 .6265 .55727 .61879 .54847 Mtetra
.61879 .54847 .6265 .55727 .64192 .55273 .63427 .54387 Mtetra
.655 .742 .914 r
.63427 .54387 .64192 .55273 .65743 .54816 .64983 .53929 Mtetra
.654 .743 .915 r
.64983 .53929 .65743 .54816 .67302 .54354 .66549 .53472 Mtetra
.653 .745 .917 r
.66549 .53472 .67302 .54354 .6887 .53885 .68123 .53016 Mtetra
.654 .749 .92 r
.68123 .53016 .6887 .53885 .70447 .53411 .69706 .52552 Mtetra
.657 .754 .922 r
.69706 .52552 .70447 .53411 .72031 .52932 .71298 .52074 Mtetra
.658 .756 .922 r
.71298 .52074 .72031 .52932 .73625 .5245 .72898 .51586 Mtetra
.659 .756 .922 r
.72898 .51586 .73625 .5245 .75228 .51969 .74506 .51094 Mtetra
.658 .755 .921 r
.74506 .51094 .75228 .51969 .76841 .51503 .76124 .50602 Mtetra
.653 .748 .919 r
.76124 .50602 .76841 .51503 .78464 .51037 .77753 .50126 Mtetra
.652 .746 .919 r
.77753 .50126 .78464 .51037 .80094 .50554 .79391 .49654 Mtetra
.656 .752 .92 r
.79391 .49654 .80094 .50554 .81733 .5006 .81038 .49162 Mtetra
.658 .754 .921 r
.81038 .49162 .81733 .5006 .83381 .4956 .82693 .4866 Mtetra
.658 .755 .921 r
.82693 .4866 .83381 .4956 .8504 .49068 .84357 .48152 Mtetra
.655 .751 .92 r
.84357 .48152 .8504 .49068 .86709 .48586 .86033 .47656 Mtetra
.653 .748 .919 r
.86033 .47656 .86709 .48586 .88387 .48093 .87718 .47166 Mtetra
.656 .751 .92 r
.87718 .47166 .88387 .48093 .90074 .47588 .89413 .46661 Mtetra
.658 .753 .92 r
.89413 .46661 .90074 .47588 .9177 .47075 .91116 .46144 Mtetra
.658 .754 .921 r
.91116 .46144 .9177 .47075 .93477 .4657 .92829 .45625 Mtetra
.653 .751 .922 r
.31743 .62825 .32623 .6359 .34012 .63183 .33137 .62417 Mtetra
.655 .753 .922 r
.33137 .62417 .34012 .63183 .35409 .62773 .34539 .61999 Mtetra
.658 .752 .919 r
.34539 .61999 .35409 .62773 .36814 .62354 .35948 .61567 Mtetra
.659 .75 .918 r
.35948 .61567 .36814 .62354 .38226 .61921 .37366 .61131 Mtetra
.653 .749 .92 r
.37366 .61131 .38226 .61921 .39646 .61493 .38789 .60712 Mtetra
.653 .752 .923 r
.38789 .60712 .39646 .61493 .41073 .61078 .40221 .60293 Mtetra
.655 .753 .922 r
.40221 .60293 .41073 .61078 .42507 .60658 .4166 .59864 Mtetra
.66 .753 .919 r
.4166 .59864 .42507 .60658 .4395 .60229 .43108 .59414 Mtetra
.659 .749 .916 r
.43108 .59414 .4395 .60229 .454 .5978 .44563 .58965 Mtetra
.653 .748 .919 r
.44563 .58965 .454 .5978 .46858 .59335 .46026 .58536 Mtetra
.652 .753 .924 r
.46026 .58536 .46858 .59335 .48324 .58907 .47497 .58108 Mtetra
.653 .754 .924 r
.47497 .58108 .48324 .58907 .49797 .58479 .48975 .57673 Mtetra
.657 .755 .922 r
.48975 .57673 .49797 .58479 .51279 .58046 .50462 .57222 Mtetra
.661 .752 .918 r
.50462 .57222 .51279 .58046 .52769 .57606 .51957 .56753 Mtetra
.66 .747 .914 r
.51957 .56753 .52769 .57606 .54266 .5715 .5346 .56287 Mtetra
.656 .744 .914 r
.5346 .56287 .54266 .5715 .55772 .56688 .54972 .55832 Mtetra
.655 .746 .917 r
.54972 .55832 .55772 .56688 .57286 .56226 .56491 .55381 Mtetra
.654 .75 .92 r
.56491 .55381 .57286 .56226 .58809 .55765 .58019 .54928 Mtetra
.655 .753 .922 r
.58019 .54928 .58809 .55765 .60339 .55306 .59556 .54469 Mtetra
.656 .755 .923 r
.59556 .54469 .60339 .55306 .61879 .54847 .61101 .54005 Mtetra
.656 .755 .922 r
.61101 .54005 .61879 .54847 .63427 .54387 .62654 .53535 Mtetra
.657 .754 .921 r
.62654 .53535 .63427 .54387 .64983 .53929 .64217 .53061 Mtetra
.657 .751 .919 r
.64217 .53061 .64983 .53929 .66549 .53472 .65787 .52584 Mtetra
.656 .747 .917 r
.65787 .52584 .66549 .53472 .68123 .53016 .67367 .5211 Mtetra
.652 .742 .916 r
.67367 .5211 .68123 .53016 .69706 .52552 .68956 .51648 Mtetra
.651 .744 .917 r
.68956 .51648 .69706 .52552 .71298 .52074 .70555 .51188 Mtetra
.655 .751 .92 r
.70555 .51188 .71298 .52074 .72898 .51586 .72162 .5071 Mtetra
.658 .755 .922 r
.72162 .5071 .72898 .51586 .74506 .51094 .73778 .50215 Mtetra
.659 .756 .922 r
.73778 .50215 .74506 .51094 .76124 .50602 .75402 .49713 Mtetra
.658 .755 .921 r
.75402 .49713 .76124 .50602 .77753 .50126 .77035 .49212 Mtetra
.653 .748 .919 r
.77035 .49212 .77753 .50126 .79391 .49654 .7868 .4873 Mtetra
.652 .746 .919 r
.7868 .4873 .79391 .49654 .81038 .49162 .80334 .4825 Mtetra
.657 .752 .92 r
.80334 .4825 .81038 .49162 .82693 .4866 .81997 .47747 Mtetra
.658 .754 .921 r
.81997 .47747 .82693 .4866 .84357 .48152 .83668 .47234 Mtetra
.83668 .47234 .84357 .48152 .86033 .47656 .85349 .46719 Mtetra
.653 .749 .92 r
.85349 .46719 .86033 .47656 .87718 .47166 .87042 .46223 Mtetra
.654 .749 .92 r
.87042 .46223 .87718 .47166 .89413 .46661 .88744 .4572 Mtetra
.656 .752 .92 r
.88744 .4572 .89413 .46661 .91116 .46144 .90455 .45204 Mtetra
.658 .754 .921 r
.90455 .45204 .91116 .46144 .92829 .45625 .92176 .44676 Mtetra
.653 .752 .922 r
.30855 .62055 .31743 .62825 .33137 .62417 .32254 .6164 Mtetra
.656 .752 .921 r
.32254 .6164 .33137 .62417 .34539 .61999 .3366 .61214 Mtetra
.66 .752 .918 r
.3366 .61214 .34539 .61999 .35948 .61567 .35074 .60773 Mtetra
.656 .75 .919 r
.35074 .60773 .35948 .61567 .37366 .61131 .36496 .60344 Mtetra
.652 .752 .923 r
.36496 .60344 .37366 .61131 .38789 .60712 .37924 .59924 Mtetra
.654 .753 .922 r
.37924 .59924 .38789 .60712 .40221 .60293 .39361 .59496 Mtetra
.659 .753 .92 r
.39361 .59496 .40221 .60293 .4166 .59864 .40805 .59049 Mtetra
.66 .75 .916 r
.40805 .59049 .4166 .59864 .43108 .59414 .42258 .58593 Mtetra
.653 .748 .919 r
.42258 .58593 .43108 .59414 .44563 .58965 .43718 .58161 Mtetra
.651 .752 .923 r
.43718 .58161 .44563 .58965 .46026 .58536 .45185 .57732 Mtetra
.653 .754 .924 r
.45185 .57732 .46026 .58536 .47497 .58108 .46661 .57296 Mtetra
.659 .755 .921 r
.46661 .57296 .47497 .58108 .48975 .57673 .48145 .56836 Mtetra
.662 .751 .916 r
.48145 .56836 .48975 .57673 .50462 .57222 .49638 .56362 Mtetra
.658 .745 .914 r
.49638 .56362 .50462 .57222 .51957 .56753 .51138 .55902 Mtetra
.653 .747 .918 r
.51138 .55902 .51957 .56753 .5346 .56287 .52646 .55457 Mtetra
.652 .753 .923 r
.52646 .55457 .5346 .56287 .54972 .55832 .54163 .55011 Mtetra
.653 .756 .926 r
.54163 .55011 .54972 .55832 .56491 .55381 .55688 .54559 Mtetra
.654 .758 .926 r
.55688 .54559 .56491 .55381 .58019 .54928 .57222 .54102 Mtetra
.57222 .54102 .58019 .54928 .59556 .54469 .58765 .53639 Mtetra
.655 .758 .926 r
.58765 .53639 .59556 .54469 .61101 .54005 .60315 .5317 Mtetra
.656 .759 .925 r
.60315 .5317 .61101 .54005 .62654 .53535 .61875 .52696 Mtetra
.657 .759 .925 r
.61875 .52696 .62654 .53535 .64217 .53061 .63443 .52215 Mtetra
.658 .759 .925 r
.63443 .52215 .64217 .53061 .65787 .52584 .6502 .5173 Mtetra
.659 .758 .923 r
.6502 .5173 .65787 .52584 .67367 .5211 .66605 .51237 Mtetra
.658 .755 .921 r
.66605 .51237 .67367 .5211 .68956 .51648 .68199 .50744 Mtetra
.654 .747 .918 r
.68199 .50744 .68956 .51648 .70555 .51188 .69804 .50265 Mtetra
.65 .742 .917 r
.69804 .50265 .70555 .51188 .72162 .5071 .71418 .49801 Mtetra
.653 .748 .919 r
.71418 .49801 .72162 .5071 .73778 .50215 .73041 .49322 Mtetra
.658 .755 .921 r
.73041 .49322 .73778 .50215 .75402 .49713 .74672 .48819 Mtetra
.659 .756 .922 r
.74672 .48819 .75402 .49713 .77035 .49212 .76312 .48308 Mtetra
.658 .754 .921 r
.76312 .48308 .77035 .49212 .7868 .4873 .77961 .47799 Mtetra
.652 .747 .919 r
.77961 .47799 .7868 .4873 .80334 .4825 .79622 .47315 Mtetra
.653 .748 .919 r
.79622 .47315 .80334 .4825 .81997 .47747 .81293 .46821 Mtetra
.657 .753 .92 r
.81293 .46821 .81997 .47747 .83668 .47234 .82971 .46307 Mtetra
.659 .754 .921 r
.82971 .46307 .83668 .47234 .85349 .46719 .84659 .45784 Mtetra
.656 .753 .921 r
.84659 .45784 .85349 .46719 .87042 .46223 .86358 .4527 Mtetra
.652 .748 .92 r
.86358 .4527 .87042 .46223 .88744 .4572 .88068 .44767 Mtetra
.655 .751 .92 r
.88068 .44767 .88744 .4572 .90455 .45204 .89787 .44249 Mtetra
.658 .753 .92 r
.89787 .44249 .90455 .45204 .92176 .44676 .91515 .43718 Mtetra
.655 .752 .922 r
.29958 .61277 .30855 .62055 .32254 .6164 .31361 .60854 Mtetra
.658 .752 .919 r
.31361 .60854 .32254 .6164 .3366 .61214 .32773 .60417 Mtetra
.659 .751 .918 r
.32773 .60417 .3366 .61214 .35074 .60773 .34192 .59974 Mtetra
.653 .75 .921 r
.34192 .59974 .35074 .60773 .36496 .60344 .35617 .59551 Mtetra
.653 .752 .923 r
.35617 .59551 .36496 .60344 .37924 .59924 .3705 .59125 Mtetra
.656 .753 .921 r
.3705 .59125 .37924 .59924 .39361 .59496 .38492 .58685 Mtetra
.661 .752 .917 r
.38492 .58685 .39361 .59496 .40805 .59049 .39942 .58224 Mtetra
.656 .748 .918 r
.39942 .58224 .40805 .59049 .42258 .58593 .41399 .57782 Mtetra
.651 .752 .923 r
.41399 .57782 .42258 .58593 .43718 .58161 .42864 .57352 Mtetra
.652 .753 .924 r
.42864 .57352 .43718 .58161 .45185 .57732 .44336 .56916 Mtetra
.659 .754 .921 r
.44336 .56916 .45185 .57732 .46661 .57296 .45818 .56455 Mtetra
.663 .751 .915 r
.45818 .56455 .46661 .57296 .48145 .56836 .47307 .55975 Mtetra
.656 .745 .915 r
.47307 .55975 .48145 .56836 .49638 .56362 .48804 .5552 Mtetra
.651 .749 .921 r
.48804 .5552 .49638 .56362 .51138 .55902 .5031 .55079 Mtetra
.651 .755 .926 r
.5031 .55079 .51138 .55902 .52646 .55457 .51824 .54634 Mtetra
.652 .756 .926 r
.51824 .54634 .52646 .55457 .54163 .55011 .53346 .54184 Mtetra
.652 .757 .926 r
.53346 .54184 .54163 .55011 .55688 .54559 .54877 .53731 Mtetra
.656 .759 .925 r
.54877 .53731 .55688 .54559 .57222 .54102 .56417 .5326 Mtetra
.657 .757 .924 r
.56417 .5326 .57222 .54102 .58765 .53639 .57965 .52784 Mtetra
.656 .754 .923 r
.57965 .52784 .58765 .53639 .60315 .5317 .59521 .5231 Mtetra
.654 .754 .923 r
.59521 .5231 .60315 .5317 .61875 .52696 .61087 .51839 Mtetra
.655 .756 .924 r
.61087 .51839 .61875 .52696 .63443 .52215 .62661 .51363 Mtetra
.659 .76 .924 r
.62661 .51363 .63443 .52215 .6502 .5173 .64244 .50868 Mtetra
.659 .759 .924 r
.64244 .50868 .6502 .5173 .66605 .51237 .65836 .5037 Mtetra
.659 .759 .923 r
.65836 .5037 .66605 .51237 .68199 .50744 .67436 .49867 Mtetra
.66 .758 .922 r
.67436 .49867 .68199 .50744 .69804 .50265 .69045 .4936 Mtetra
.656 .751 .92 r
.69045 .4936 .69804 .50265 .71418 .49801 .70665 .48867 Mtetra
.649 .743 .918 r
.70665 .48867 .71418 .49801 .73041 .49322 .72295 .48398 Mtetra
.653 .748 .919 r
.72295 .48398 .73041 .49322 .74672 .48819 .73934 .47911 Mtetra
.659 .755 .921 r
.73934 .47911 .74672 .48819 .76312 .48308 .7558 .47397 Mtetra
.66 .756 .921 r
.7558 .47397 .76312 .48308 .77961 .47799 .77236 .46876 Mtetra
.656 .753 .921 r
.77236 .46876 .77961 .47799 .79622 .47315 .78903 .46368 Mtetra
.651 .747 .92 r
.78903 .46368 .79622 .47315 .81293 .46821 .80581 .45878 Mtetra
.655 .75 .92 r
.80581 .45878 .81293 .46821 .82971 .46307 .82267 .45367 Mtetra
.658 .754 .92 r
.82267 .45367 .82971 .46307 .84659 .45784 .83962 .4484 Mtetra
.658 .754 .921 r
.83962 .4484 .84659 .45784 .86358 .4527 .85667 .4431 Mtetra
.653 .749 .92 r
.85667 .4431 .86358 .4527 .88068 .44767 .87384 .43799 Mtetra
.654 .749 .92 r
.87384 .43799 .88068 .44767 .89787 .44249 .89111 .43282 Mtetra
.657 .752 .92 r
.89111 .43282 .89787 .44249 .91515 .43718 .90847 .4275 Mtetra
.656 .752 .921 r
.29053 .6049 .29958 .61277 .31361 .60854 .30461 .60059 Mtetra
.659 .752 .919 r
.30461 .60059 .31361 .60854 .32773 .60417 .31877 .59612 Mtetra
.656 .75 .919 r
.31877 .59612 .32773 .60417 .34192 .59974 .333 .59175 Mtetra
.652 .751 .922 r
.333 .59175 .34192 .59974 .35617 .59551 .3473 .5875 Mtetra
.654 .752 .922 r
.3473 .5875 .35617 .59551 .3705 .59125 .36168 .58315 Mtetra
.66 .753 .919 r
.36168 .58315 .3705 .59125 .38492 .58685 .37615 .57858 Mtetra
.659 .75 .917 r
.37615 .57858 .38492 .58685 .39942 .58224 .3907 .57401 Mtetra
.652 .75 .921 r
.3907 .57401 .39942 .58224 .41399 .57782 .40531 .56966 Mtetra
.651 .752 .924 r
.40531 .56966 .41399 .57782 .42864 .57352 .42001 .56532 Mtetra
.656 .754 .922 r
.42001 .56532 .42864 .57352 .44336 .56916 .43479 .56077 Mtetra
.664 .752 .916 r
.43479 .56077 .44336 .56916 .45818 .56455 .44966 .55593 Mtetra
.657 .746 .916 r
.44966 .55593 .45818 .56455 .47307 .55975 .4646 .55132 Mtetra
.65 .75 .922 r
.4646 .55132 .47307 .55975 .48804 .5552 .47962 .54693 Mtetra
.65 .755 .926 r
.47962 .54693 .48804 .5552 .5031 .55079 .49473 .54248 Mtetra
.49473 .54248 .5031 .55079 .51824 .54634 .50993 .53802 Mtetra
.658 .759 .924 r
.50993 .53802 .51824 .54634 .53346 .54184 .52521 .53324 Mtetra
.653 .751 .922 r
.52521 .53324 .53346 .54184 .54877 .53731 .54057 .52864 Mtetra
.646 .748 .924 r
.54057 .52864 .54877 .53731 .56417 .5326 .55603 .52426 Mtetra
.647 .758 .93 r
.55603 .52426 .56417 .5326 .57965 .52784 .57157 .5198 Mtetra
.654 .769 .934 r
.57157 .5198 .57965 .52784 .59521 .5231 .5872 .51502 Mtetra
.662 .772 .931 r
.5872 .51502 .59521 .5231 .61087 .51839 .60291 .50991 Mtetra
.664 .764 .924 r
.60291 .50991 .61087 .51839 .62661 .51363 .6187 .50472 Mtetra
.659 .753 .919 r
.6187 .50472 .62661 .51363 .64244 .50868 .63459 .49974 Mtetra
.653 .751 .922 r
.63459 .49974 .64244 .50868 .65836 .5037 .65058 .49495 Mtetra
.661 .759 .923 r
.65058 .49495 .65836 .5037 .67436 .49867 .66665 .48983 Mtetra
.66 .758 .923 r
.66665 .48983 .67436 .49867 .69045 .4936 .6828 .48469 Mtetra
.661 .758 .922 r
.6828 .48469 .69045 .4936 .70665 .48867 .69905 .4795 Mtetra
.655 .751 .921 r
.69905 .4795 .70665 .48867 .72295 .48398 .7154 .47452 Mtetra
.649 .743 .918 r
.7154 .47452 .72295 .48398 .73934 .47911 .73187 .46978 Mtetra
.655 .75 .92 r
.73187 .46978 .73934 .47911 .7558 .47397 .74841 .46473 Mtetra
.66 .755 .921 r
.74841 .46473 .7558 .47397 .77236 .46876 .76504 .45947 Mtetra
.659 .755 .921 r
.76504 .45947 .77236 .46876 .78903 .46368 .78176 .45421 Mtetra
.653 .749 .921 r
.78176 .45421 .78903 .46368 .80581 .45878 .7986 .44918 Mtetra
.652 .747 .919 r
.7986 .44918 .80581 .45878 .82267 .45367 .81555 .44414 Mtetra
.657 .752 .92 r
.81555 .44414 .82267 .45367 .83962 .4484 .83257 .43886 Mtetra
.659 .754 .92 r
.83257 .43886 .83962 .4484 .85667 .4431 .84969 .43347 Mtetra
.655 .752 .921 r
.84969 .43347 .85667 .4431 .87384 .43799 .86693 .42821 Mtetra
.653 .749 .92 r
.86693 .42821 .87384 .43799 .89111 .43282 .88428 .42304 Mtetra
.656 .751 .92 r
.88428 .42304 .89111 .43282 .90847 .4275 .90171 .41769 Mtetra
.657 .752 .92 r
.28138 .59693 .29053 .6049 .30461 .60059 .29551 .59253 Mtetra
.66 .752 .918 r
.29551 .59253 .30461 .60059 .31877 .59612 .30972 .58802 Mtetra
.654 .75 .92 r
.30972 .58802 .31877 .59612 .333 .59175 .32399 .58369 Mtetra
.652 .752 .922 r
.32399 .58369 .333 .59175 .3473 .5875 .33834 .57938 Mtetra
.656 .752 .921 r
.33834 .57938 .3473 .5875 .36168 .58315 .35277 .57493 Mtetra
.662 .752 .918 r
.35277 .57493 .36168 .58315 .37615 .57858 .36729 .57025 Mtetra
.655 .749 .919 r
.36729 .57025 .37615 .57858 .3907 .57401 .38188 .56577 Mtetra
.651 .751 .923 r
.38188 .56577 .3907 .57401 .40531 .56966 .39655 .56142 Mtetra
.653 .753 .923 r
.39655 .56142 .40531 .56966 .42001 .56532 .41129 .55698 Mtetra
.663 .754 .918 r
.41129 .55698 .42001 .56532 .43479 .56077 .42613 .55216 Mtetra
.66 .748 .915 r
.42613 .55216 .43479 .56077 .44966 .55593 .44105 .5474 Mtetra
.65 .748 .921 r
.44105 .5474 .44966 .55593 .4646 .55132 .45604 .54298 Mtetra
.649 .754 .926 r
.45604 .54298 .4646 .55132 .47962 .54693 .47112 .53855 Mtetra
.47112 .53855 .47962 .54693 .49473 .54248 .48628 .5341 Mtetra
.658 .758 .923 r
.48628 .5341 .49473 .54248 .50993 .53802 .50153 .52929 Mtetra
.636 .743 .926 r
.50153 .52929 .50993 .53802 .52521 .53324 .51686 .52529 Mtetra
.588 .748 .953 r
.51686 .52529 .52521 .53324 .54057 .52864 .53229 .5226 Mtetra
.562 .793 .986 r
.53229 .5226 .54057 .52864 .55603 .52426 .54783 .51985 Mtetra
.56 .841 .997 r
.54783 .51985 .55603 .52426 .57157 .5198 .56346 .51628 Mtetra
.595 .879 .992 r
.56346 .51628 .57157 .5198 .5872 .51502 .57917 .51145 Mtetra
.65 .896 .983 r
.57917 .51145 .5872 .51502 .60291 .50991 .59495 .50536 Mtetra
.694 .881 .968 r
.59495 .50536 .60291 .50991 .6187 .50472 .61078 .49844 Mtetra
.705 .836 .945 r
.61078 .49844 .6187 .50472 .63459 .49974 .62669 .49145 Mtetra
.674 .776 .927 r
.62669 .49145 .63459 .49974 .65058 .49495 .64271 .48576 Mtetra
.653 .749 .92 r
.64271 .48576 .65058 .49495 .66665 .48983 .65885 .48089 Mtetra
.661 .759 .922 r
.65885 .48089 .66665 .48983 .6828 .48469 .67507 .47566 Mtetra
.661 .758 .922 r
.67507 .47566 .6828 .48469 .69905 .4795 .69138 .4704 Mtetra
.661 .757 .922 r
.69138 .4704 .69905 .4795 .7154 .47452 .70779 .46513 Mtetra
.652 .748 .92 r
.70779 .46513 .7154 .47452 .73187 .46978 .72431 .4602 Mtetra
.65 .744 .919 r
.72431 .4602 .73187 .46978 .74841 .46473 .74094 .45534 Mtetra
.658 .753 .92 r
.74094 .45534 .74841 .46473 .76504 .45947 .75763 .45008 Mtetra
.66 .755 .921 r
.75763 .45008 .76504 .45947 .78176 .45421 .77442 .44472 Mtetra
.656 .753 .921 r
.77442 .44472 .78176 .45421 .7986 .44918 .79132 .43949 Mtetra
.651 .747 .92 r
.79132 .43949 .7986 .44918 .81555 .44414 .80834 .43446 Mtetra
.656 .751 .92 r
.80834 .43446 .81555 .44414 .83257 .43886 .82545 .42918 Mtetra
.659 .753 .92 r
.82545 .42918 .83257 .43886 .84969 .43347 .84264 .42375 Mtetra
.658 .753 .921 r
.84264 .42375 .84969 .43347 .86693 .42821 .85994 .41834 Mtetra
.652 .749 .921 r
.85994 .41834 .86693 .42821 .88428 .42304 .87736 .41311 Mtetra
.655 .75 .92 r
.87736 .41311 .88428 .42304 .90171 .41769 .89488 .40776 Mtetra
.658 .752 .919 r
.27215 .58887 .28138 .59693 .29551 .59253 .28633 .58439 Mtetra
.659 .751 .918 r
.28633 .58439 .29551 .59253 .30972 .58802 .30058 .57986 Mtetra
.652 .75 .922 r
.30058 .57986 .30972 .58802 .32399 .58369 .31489 .57554 Mtetra
.653 .752 .922 r
.31489 .57554 .32399 .58369 .33834 .57938 .32929 .57116 Mtetra
.658 .753 .92 r
.32929 .57116 .33834 .57938 .35277 .57493 .34378 .56658 Mtetra
.661 .751 .917 r
.34378 .56658 .35277 .57493 .36729 .57025 .35834 .56188 Mtetra
.652 .749 .921 r
.35834 .56188 .36729 .57025 .38188 .56577 .37298 .55747 Mtetra
.651 .752 .923 r
.37298 .55747 .38188 .56577 .39655 .56142 .38769 .55307 Mtetra
.657 .753 .921 r
.38769 .55307 .39655 .56142 .41129 .55698 .40249 .54843 Mtetra
.664 .752 .915 r
.40249 .54843 .41129 .55698 .42613 .55216 .41739 .54349 Mtetra
.653 .747 .919 r
.41739 .54349 .42613 .55216 .44105 .5474 .43235 .53895 Mtetra
.649 .752 .925 r
.43235 .53895 .44105 .5474 .45604 .54298 .44739 .53453 Mtetra
.648 .753 .926 r
.44739 .53453 .45604 .54298 .47112 .53855 .46252 .53009 Mtetra
.658 .757 .923 r
.46252 .53009 .47112 .53855 .48628 .5341 .47774 .52529 Mtetra
.619 .737 .931 r
.47774 .52529 .48628 .5341 .50153 .52929 .49304 .52182 Mtetra
.52 .736 .973 r
.49304 .52182 .50153 .52929 .51686 .52529 .50841 .52058 Mtetra
.387 .756 .992 r
.50841 .52058 .51686 .52529 .53229 .5226 .52391 .52009 Mtetra
.229 .72 .921 r
.52391 .52009 .53229 .5226 .54783 .51985 .53954 .51983 Mtetra
.219 .741 .822 r
.53954 .51983 .54783 .51985 .56346 .51628 .55528 .51739 Mtetra
.326 .811 .806 r
.55528 .51739 .56346 .51628 .57917 .51145 .5711 .51253 Mtetra
.505 .91 .857 r
.5711 .51253 .57917 .51145 .59495 .50536 .58697 .50523 Mtetra
.686 .973 .916 r
.58697 .50523 .59495 .50536 .61078 .49844 .60285 .49572 Mtetra
.742 .94 .949 r
.60285 .49572 .61078 .49844 .62669 .49145 .61879 .48642 Mtetra
.739 .881 .945 r
.61879 .48642 .62669 .49145 .64271 .48576 .6348 .47786 Mtetra
.687 .794 .931 r
.6348 .47786 .64271 .48576 .65885 .48089 .65096 .47153 Mtetra
.654 .748 .919 r
.65096 .47153 .65885 .48089 .67507 .47566 .66726 .46655 Mtetra
.662 .759 .922 r
.66726 .46655 .67507 .47566 .69138 .4704 .68363 .46119 Mtetra
.662 .757 .921 r
.68363 .46119 .69138 .4704 .70779 .46513 .7001 .45582 Mtetra
.658 .755 .921 r
.7001 .45582 .70779 .46513 .72431 .4602 .71667 .45057 Mtetra
.648 .745 .92 r
.71667 .45057 .72431 .4602 .74094 .45534 .73337 .44572 Mtetra
.655 .749 .919 r
.73337 .44572 .74094 .45534 .75763 .45008 .75015 .44056 Mtetra
.66 .755 .92 r
.75015 .44056 .75763 .45008 .77442 .44472 .76701 .43514 Mtetra
.659 .754 .92 r
.76701 .43514 .77442 .44472 .79132 .43949 .78397 .42974 Mtetra
.651 .749 .921 r
.78397 .42974 .79132 .43949 .80834 .43446 .80106 .42462 Mtetra
.654 .749 .92 r
.80106 .42462 .80834 .43446 .82545 .42918 .81824 .41938 Mtetra
.658 .753 .92 r
.81824 .41938 .82545 .42918 .84264 .42375 .83551 .41392 Mtetra
.659 .754 .92 r
.83551 .41392 .84264 .42375 .85994 .41834 .85288 .4084 Mtetra
.653 .75 .921 r
.85288 .4084 .85994 .41834 .87736 .41311 .87037 .40308 Mtetra
.654 .75 .92 r
.87037 .40308 .87736 .41311 .89488 .40776 .88797 .3977 Mtetra
.659 .752 .919 r
.26282 .58073 .27215 .58887 .28633 .58439 .27705 .57617 Mtetra
.657 .751 .919 r
.27705 .57617 .28633 .58439 .30058 .57986 .29134 .57166 Mtetra
.652 .751 .922 r
.29134 .57166 .30058 .57986 .31489 .57554 .3057 .5673 Mtetra
.654 .752 .922 r
.3057 .5673 .31489 .57554 .32929 .57116 .32015 .56285 Mtetra
.66 .753 .919 r
.32015 .56285 .32929 .57116 .34378 .56658 .33469 .55816 Mtetra
.658 .751 .918 r
.33469 .55816 .34378 .56658 .35834 .56188 .3493 .5535 Mtetra
.651 .751 .923 r
.3493 .5535 .35834 .56188 .37298 .55747 .36398 .54907 Mtetra
.652 .752 .923 r
.36398 .54907 .37298 .55747 .38769 .55307 .37875 .54461 Mtetra
.662 .754 .919 r
.37875 .54461 .38769 .55307 .40249 .54843 .39361 .53975 Mtetra
.661 .75 .916 r
.39361 .53975 .40249 .54843 .41739 .54349 .40855 .53489 Mtetra
.649 .749 .923 r
.40855 .53489 .41739 .54349 .43235 .53895 .42356 .53043 Mtetra
.648 .752 .925 r
.42356 .53043 .43235 .53895 .44739 .53453 .43866 .52597 Mtetra
.655 .754 .923 r
.43866 .52597 .44739 .53453 .46252 .53009 .45384 .52124 Mtetra
.635 .742 .926 r
.45384 .52124 .46252 .53009 .47774 .52529 .4691 .51723 Mtetra
.504 .714 .966 r
.4691 .51723 .47774 .52529 .49304 .52182 .48442 .51653 Mtetra
.251 .666 .964 r
.48442 .51653 .49304 .52182 .50841 .52058 .49984 .51823 Mtetra
0 .55 .798 r
.49984 .51823 .50841 .52058 .52391 .52009 .51541 .5205 Mtetra
.056 .622 .719 r
.51541 .5205 .52391 .52009 .53954 .51983 .53112 .5195 Mtetra
.381 .841 .896 r
.53112 .5195 .53954 .51983 .55528 .51739 .54695 .51539 Mtetra
.533 .894 .974 r
.54695 .51539 .55528 .51739 .5711 .51253 .56286 .51049 Mtetra
.578 .911 .975 r
.56286 .51049 .5711 .51253 .58697 .50523 .57885 .50477 Mtetra
.666 .964 .928 r
.57885 .50477 .58697 .50523 .60285 .49572 .59487 .49593 Mtetra
.766 .991 .887 r
.59487 .49593 .60285 .49572 .61879 .48642 .61085 .48377 Mtetra
.798 .948 .92 r
.61085 .48377 .61879 .48642 .6348 .47786 .62687 .47214 Mtetra
.754 .868 .931 r
.62687 .47214 .6348 .47786 .65096 .47153 .64301 .46291 Mtetra
.675 .776 .926 r
.64301 .46291 .65096 .47153 .66726 .46655 .65934 .45703 Mtetra
.656 .749 .918 r
.65934 .45703 .66726 .46655 .68363 .46119 .67579 .45186 Mtetra
.662 .757 .92 r
.67579 .45186 .68363 .46119 .7001 .45582 .69233 .44643 Mtetra
.662 .757 .921 r
.69233 .44643 .7001 .45582 .71667 .45057 .70896 .44098 Mtetra
.651 .749 .922 r
.70896 .44098 .71667 .45057 .73337 .44572 .72572 .43595 Mtetra
.65 .746 .92 r
.72572 .43595 .73337 .44572 .75015 .44056 .74258 .4309 Mtetra
.659 .754 .92 r
.74258 .4309 .75015 .44056 .76701 .43514 .75951 .42546 Mtetra
.66 .754 .92 r
.75951 .42546 .76701 .43514 .78397 .42974 .77654 .41995 Mtetra
.653 .751 .921 r
.77654 .41995 .78397 .42974 .80106 .42462 .79369 .41469 Mtetra
.652 .748 .92 r
.79369 .41469 .80106 .42462 .81824 .41938 .81095 .40946 Mtetra
.658 .752 .92 r
.81095 .40946 .81824 .41938 .83551 .41392 .8283 .40397 Mtetra
.659 .754 .92 r
.8283 .40397 .83551 .41392 .85288 .4084 .84574 .39837 Mtetra
.654 .751 .921 r
.84574 .39837 .85288 .4084 .87037 .40308 .86331 .39293 Mtetra
.653 .749 .92 r
.86331 .39293 .87037 .40308 .88797 .3977 .88099 .38753 Mtetra
.66 .752 .919 r
.2534 .57251 .26282 .58073 .27705 .57617 .26768 .56788 Mtetra
.656 .751 .92 r
.26768 .56788 .27705 .57617 .29134 .57166 .28201 .56336 Mtetra
.652 .751 .922 r
.28201 .56336 .29134 .57166 .3057 .5673 .29642 .55896 Mtetra
.654 .752 .921 r
.29642 .55896 .3057 .5673 .32015 .56285 .31092 .55445 Mtetra
.661 .753 .918 r
.31092 .55445 .32015 .56285 .33469 .55816 .32551 .54966 Mtetra
.656 .75 .919 r
.32551 .54966 .33469 .55816 .3493 .5535 .34017 .54503 Mtetra
.651 .751 .923 r
.34017 .54503 .3493 .5535 .36398 .54907 .35489 .54058 Mtetra
.653 .752 .922 r
.35489 .54058 .36398 .54907 .37875 .54461 .36971 .53602 Mtetra
.664 .754 .917 r
.36971 .53602 .37875 .54461 .39361 .53975 .38463 .53101 Mtetra
.657 .749 .918 r
.38463 .53101 .39361 .53975 .40855 .53489 .39962 .52626 Mtetra
.648 .75 .924 r
.39962 .52626 .40855 .53489 .42356 .53043 .41468 .52179 Mtetra
.648 .751 .925 r
.41468 .52179 .42356 .53043 .43866 .52597 .42983 .51731 Mtetra
.655 .754 .923 r
.42983 .51731 .43866 .52597 .45384 .52124 .44507 .51252 Mtetra
.569 .725 .947 r
.44507 .51252 .45384 .52124 .4691 .51723 .46035 .51042 Mtetra
.338 .673 .976 r
.46035 .51042 .4691 .51723 .48442 .51653 .47568 .51192 Mtetra
0 .49 .834 r
.47568 .51192 .48442 .51653 .49984 .51823 .49113 .51639 Mtetra
.17 .693 .876 r
.49113 .51639 .49984 .51823 .51541 .5205 .50679 .51615 Mtetra
.664 .879 .978 r
.50679 .51615 .51541 .5205 .53112 .5195 .52258 .50999 Mtetra
.724 .763 .884 r
.52258 .50999 .53112 .5195 .54695 .51539 .53844 .50186 Mtetra
.65 .665 .851 r
.53844 .50186 .54695 .51539 .56286 .51049 .55439 .4969 Mtetra
.58 .635 .87 r
.55439 .4969 .56286 .51049 .57885 .50477 .57048 .49511 Mtetra
.621 .731 .925 r
.57048 .49511 .57885 .50477 .59487 .49593 .58666 .49135 Mtetra
.763 .898 .937 r
.58666 .49135 .59487 .49593 .61085 .48377 .6028 .48163 Mtetra
.849 .954 .881 r
.6028 .48163 .61085 .48377 .62687 .47214 .61886 .46711 Mtetra
.8 .892 .91 r
.61886 .46711 .62687 .47214 .64301 .46291 .63502 .45555 Mtetra
.722 .823 .927 r
.63502 .45555 .64301 .46291 .65934 .45703 .65135 .44762 Mtetra
.656 .754 .922 r
.65135 .44762 .65934 .45703 .67579 .45186 .66787 .44242 Mtetra
.663 .757 .92 r
.66787 .44242 .67579 .45186 .69233 .44643 .68447 .43689 Mtetra
.663 .756 .92 r
.68447 .43689 .69233 .44643 .70896 .44098 .70117 .43135 Mtetra
.655 .752 .922 r
.70117 .43135 .70896 .44098 .72572 .43595 .71799 .4261 Mtetra
.648 .746 .921 r
.71799 .4261 .72572 .43595 .74258 .4309 .73492 .42111 Mtetra
.658 .753 .92 r
.73492 .42111 .74258 .4309 .75951 .42546 .75193 .41564 Mtetra
.66 .754 .92 r
.75193 .41564 .75951 .42546 .77654 .41995 .76903 .41007 Mtetra
.655 .752 .921 r
.76903 .41007 .77654 .41995 .79369 .41469 .78625 .40467 Mtetra
.651 .748 .921 r
.78625 .40467 .79369 .41469 .81095 .40946 .80358 .39942 Mtetra
.657 .752 .92 r
.80358 .39942 .81095 .40946 .8283 .40397 .82101 .39389 Mtetra
.659 .753 .92 r
.82101 .39389 .8283 .40397 .84574 .39837 .83852 .38823 Mtetra
.656 .752 .921 r
.83852 .38823 .84574 .39837 .86331 .39293 .85616 .38269 Mtetra
.652 .749 .921 r
.85616 .38269 .86331 .39293 .88099 .38753 .87392 .37725 Mtetra
.66 .752 .918 r
.24389 .5642 .2534 .57251 .26768 .56788 .25821 .55952 Mtetra
.655 .751 .92 r
.25821 .55952 .26768 .56788 .28201 .56336 .27259 .55498 Mtetra
.652 .751 .922 r
.27259 .55498 .28201 .56336 .29642 .55896 .28705 .55053 Mtetra
.655 .751 .921 r
.28705 .55053 .29642 .55896 .31092 .55445 .30159 .54595 Mtetra
.662 .753 .918 r
.30159 .54595 .31092 .55445 .32551 .54966 .31623 .5411 Mtetra
.655 .75 .92 r
.31623 .5411 .32551 .54966 .34017 .54503 .33094 .53647 Mtetra
.65 .751 .923 r
.33094 .53647 .34017 .54503 .35489 .54058 .34571 .53198 Mtetra
.654 .752 .921 r
.34571 .53198 .35489 .54058 .36971 .53602 .36058 .52731 Mtetra
.665 .753 .916 r
.36058 .52731 .36971 .53602 .38463 .53101 .37556 .52222 Mtetra
.654 .749 .92 r
.37556 .52222 .38463 .53101 .39962 .52626 .39059 .51753 Mtetra
.648 .75 .924 r
.39059 .51753 .39962 .52626 .41468 .52179 .4057 .51302 Mtetra
.65 .751 .923 r
.4057 .51302 .41468 .52179 .42983 .51731 .42091 .50841 Mtetra
.645 .748 .924 r
.42091 .50841 .42983 .51731 .44507 .51252 .4362 .50395 Mtetra
.497 .701 .961 r
.4362 .50395 .44507 .51252 .46035 .51042 .45148 .50348 Mtetra
.155 .565 .93 r
.45148 .50348 .46035 .51042 .47568 .51192 .46682 .50749 Mtetra
.009 .53 .857 r
.46682 .50749 .47568 .51192 .49113 .51639 .48234 .51122 Mtetra
.646 .852 .979 r
.48234 .51122 .49113 .51639 .50679 .51615 .4981 .50582 Mtetra
.815 .764 .805 r
.4981 .50582 .50679 .51615 .52258 .50999 .51398 .49009 Mtetra
.752 .64 .736 r
.51398 .49009 .52258 .50999 .53844 .50186 .52984 .47399 Mtetra
.619 .522 .722 r
.52984 .47399 .53844 .50186 .55439 .4969 .54577 .46895 Mtetra
.466 .428 .732 r
.54577 .46895 .55439 .4969 .57048 .49511 .56191 .475 Mtetra
.426 .466 .799 r
.56191 .475 .57048 .49511 .58666 .49135 .57825 .48075 Mtetra
.643 .722 .905 r
.57825 .48075 .58666 .49135 .6028 .48163 .59457 .47613 Mtetra
.833 .878 .876 r
.59457 .47613 .6028 .48163 .61886 .46711 .61075 .46226 Mtetra
.841 .896 .878 r
.61075 .46226 .61886 .46711 .63502 .45555 .62693 .44806 Mtetra
.758 .829 .907 r
.62693 .44806 .63502 .45555 .65135 .44762 .64328 .43836 Mtetra
.665 .763 .923 r
.64328 .43836 .65135 .44762 .66787 .44242 .65985 .43272 Mtetra
.661 .753 .918 r
.65985 .43272 .66787 .44242 .68447 .43689 .67653 .42722 Mtetra
.663 .755 .919 r
.67653 .42722 .68447 .43689 .70117 .43135 .6933 .42161 Mtetra
.658 .753 .921 r
.6933 .42161 .70117 .43135 .71799 .4261 .71017 .41619 Mtetra
.647 .746 .922 r
.71017 .41619 .71799 .4261 .73492 .42111 .72718 .41117 Mtetra
.657 .751 .919 r
.72718 .41117 .73492 .42111 .75193 .41564 .74426 .40571 Mtetra
.661 .754 .919 r
.74426 .40571 .75193 .41564 .76903 .41007 .76143 .40006 Mtetra
.657 .752 .92 r
.76143 .40006 .76903 .41007 .78625 .40467 .77872 .39455 Mtetra
.65 .748 .921 r
.77872 .39455 .78625 .40467 .80358 .39942 .79613 .38927 Mtetra
.656 .751 .92 r
.79613 .38927 .80358 .39942 .82101 .39389 .81363 .38369 Mtetra
.659 .753 .919 r
.81363 .38369 .82101 .39389 .83852 .38823 .83122 .37797 Mtetra
.656 .752 .92 r
.83122 .37797 .83852 .38823 .85616 .38269 .84894 .37234 Mtetra
.652 .749 .921 r
.84894 .37234 .85616 .38269 .87392 .37725 .86677 .36684 Mtetra
.66 .752 .918 r
.23428 .55581 .24389 .5642 .25821 .55952 .24864 .55108 Mtetra
.655 .751 .921 r
.24864 .55108 .25821 .55952 .27259 .55498 .26307 .54651 Mtetra
.652 .751 .922 r
.26307 .54651 .27259 .55498 .28705 .55053 .27758 .54201 Mtetra
.656 .751 .92 r
.27758 .54201 .28705 .55053 .30159 .54595 .29217 .53736 Mtetra
.662 .753 .918 r
.29217 .53736 .30159 .54595 .31623 .5411 .30686 .53246 Mtetra
.654 .751 .921 r
.30686 .53246 .31623 .5411 .33094 .53647 .32161 .52781 Mtetra
.65 .75 .923 r
.32161 .52781 .33094 .53647 .34571 .53198 .33644 .52327 Mtetra
.656 .752 .921 r
.33644 .52327 .34571 .53198 .36058 .52731 .35136 .51852 Mtetra
.665 .753 .916 r
.35136 .51852 .36058 .52731 .37556 .52222 .36639 .51338 Mtetra
.652 .75 .921 r
.36639 .51338 .37556 .52222 .39059 .51753 .38147 .50869 Mtetra
.648 .75 .924 r
.38147 .50869 .39059 .51753 .4057 .51302 .39664 .50414 Mtetra
.652 .751 .922 r
.39664 .50414 .4057 .51302 .42091 .50841 .4119 .49939 Mtetra
.635 .744 .927 r
.4119 .49939 .42091 .50841 .4362 .50395 .42723 .49523 Mtetra
.453 .68 .962 r
.42723 .49523 .4362 .50395 .45148 .50348 .44254 .49566 Mtetra
.113 .515 .91 r
.44254 .49566 .45148 .50348 .46682 .50749 .45789 .50082 Mtetra
.282 .651 .968 r
.45789 .50082 .46682 .50749 .48234 .51122 .47348 .50289 Mtetra
.752 .795 .888 r
.47348 .50289 .48234 .51122 .4981 .50582 .48934 .49344 Mtetra
.85 .739 .74 r
.48934 .49344 .4981 .50582 .51398 .49009 .50534 .46973 Mtetra
.783 .651 .716 r
.50534 .46973 .51398 .49009 .52984 .47399 .52125 .44851 Mtetra
.623 .537 .736 r
.52125 .44851 .52984 .47399 .54577 .46895 .53715 .44339 Mtetra
.344 .367 .741 r
.53715 .44339 .54577 .46895 .56191 .475 .55329 .45443 Mtetra
.19 .315 .762 r
.55329 .45443 .56191 .475 .57825 .48075 .56972 .46808 Mtetra
.541 .638 .896 r
.56972 .46808 .57825 .48075 .59457 .47613 .58616 .46742 Mtetra
.792 .805 .863 r
.58616 .46742 .59457 .47613 .61075 .46226 .60247 .45512 Mtetra
.842 .843 .846 r
.60247 .45512 .61075 .46226 .62693 .44806 .61872 .43966 Mtetra
.771 .812 .886 r
.61872 .43966 .62693 .44806 .64328 .43836 .63512 .42895 Mtetra
.674 .765 .919 r
.63512 .42895 .64328 .43836 .65985 .43272 .65175 .42288 Mtetra
.659 .751 .918 r
.65175 .42288 .65985 .43272 .67653 .42722 .6685 .41741 Mtetra
.663 .755 .918 r
.6685 .41741 .67653 .42722 .6933 .42161 .68533 .41174 Mtetra
.659 .753 .92 r
.68533 .41174 .6933 .42161 .71017 .41619 .70227 .4062 Mtetra
.647 .747 .923 r
.70227 .4062 .71017 .41619 .72718 .41117 .71935 .40112 Mtetra
.656 .751 .92 r
.71935 .40112 .72718 .41117 .74426 .40571 .7365 .39564 Mtetra
.661 .754 .919 r
.7365 .39564 .74426 .40571 .76143 .40006 .75375 .38994 Mtetra
.657 .752 .92 r
.75375 .38994 .76143 .40006 .77872 .39455 .77111 .38433 Mtetra
.65 .749 .922 r
.77111 .38433 .77872 .39455 .79613 .38927 .7886 .37899 Mtetra
.656 .751 .92 r
.7886 .37899 .79613 .38927 .81363 .38369 .80617 .37337 Mtetra
.659 .753 .919 r
.80617 .37337 .81363 .38369 .83122 .37797 .82384 .36759 Mtetra
.657 .752 .92 r
.82384 .36759 .83122 .37797 .84894 .37234 .84163 .36188 Mtetra
.652 .75 .921 r
.84163 .36188 .84894 .37234 .86677 .36684 .85955 .35632 Mtetra
.66 .752 .918 r
.22457 .54733 .23428 .55581 .24864 .55108 .23898 .54255 Mtetra
.655 .751 .921 r
.23898 .54255 .24864 .55108 .26307 .54651 .25346 .53794 Mtetra
.652 .75 .922 r
.25346 .53794 .26307 .54651 .27758 .54201 .26801 .5334 Mtetra
.656 .751 .92 r
.26801 .5334 .27758 .54201 .29217 .53736 .28265 .5287 Mtetra
.662 .753 .918 r
.28265 .5287 .29217 .53736 .30686 .53246 .29739 .52375 Mtetra
.654 .751 .921 r
.29739 .52375 .30686 .53246 .32161 .52781 .31219 .51905 Mtetra
.65 .75 .922 r
.31219 .51905 .32161 .52781 .33644 .52327 .32707 .51446 Mtetra
.656 .751 .92 r
.32707 .51446 .33644 .52327 .35136 .51852 .34204 .50966 Mtetra
.665 .754 .916 r
.34204 .50966 .35136 .51852 .36639 .51338 .35712 .50446 Mtetra
.652 .75 .922 r
.35712 .50446 .36639 .51338 .38147 .50869 .37226 .49973 Mtetra
.648 .749 .923 r
.37226 .49973 .38147 .50869 .39664 .50414 .38748 .49513 Mtetra
.652 .75 .922 r
.38748 .49513 .39664 .50414 .4119 .49939 .40279 .49033 Mtetra
.635 .745 .928 r
.40279 .49033 .4119 .49939 .42723 .49523 .41818 .48612 Mtetra
.459 .675 .957 r
.41818 .48612 .42723 .49523 .44254 .49566 .43353 .48651 Mtetra
.181 .523 .919 r
.43353 .48651 .44254 .49566 .45789 .50082 .44891 .49164 Mtetra
.375 .634 .956 r
.44891 .49164 .45789 .50082 .47348 .50289 .46453 .49367 Mtetra
.748 .777 .877 r
.46453 .49367 .47348 .50289 .48934 .49344 .48047 .48416 Mtetra
.875 .781 .754 r
.48047 .48416 .48934 .49344 .50534 .46973 .49658 .46035 Mtetra
.863 .783 .771 r
.49658 .46035 .50534 .46973 .52125 .44851 .51259 .43903 Mtetra
.657 .75 .918 r
.51259 .43903 .52125 .44851 .53715 .44339 .52855 .43386 Mtetra
0 .27 .76 r
.52855 .43386 .53715 .44339 .55329 .45443 .54471 .44489 Mtetra
0 .155 .665 r
.54471 .44489 .55329 .45443 .56972 .46808 .56115 .45853 Mtetra
.509 .695 .952 r
.56115 .45853 .56972 .46808 .58616 .46742 .57765 .45782 Mtetra
.786 .788 .854 r
.57765 .45782 .58616 .46742 .60247 .45512 .59404 .44545 Mtetra
.822 .793 .824 r
.59404 .44545 .60247 .45512 .61872 .43966 .61038 .4299 Mtetra
.763 .783 .87 r
.61038 .4299 .61872 .43966 .63512 .42895 .62686 .41912 Mtetra
.674 .758 .914 r
.62686 .41912 .63512 .42895 .65175 .42288 .64356 .41299 Mtetra
.659 .753 .919 r
.64356 .41299 .65175 .42288 .6685 .41741 .66037 .40747 Mtetra
.663 .754 .918 r
.66037 .40747 .6685 .41741 .68533 .41174 .67728 .40173 Mtetra
.659 .753 .919 r
.67728 .40173 .68533 .41174 .70227 .4062 .69429 .39613 Mtetra
.647 .748 .923 r
.69429 .39613 .70227 .4062 .71935 .40112 .71143 .39099 Mtetra
.656 .751 .92 r
.71143 .39099 .71935 .40112 .7365 .39564 .72866 .38545 Mtetra
.661 .753 .919 r
.72866 .38545 .7365 .39564 .75375 .38994 .74598 .37968 Mtetra
.657 .752 .92 r
.74598 .37968 .75375 .38994 .77111 .38433 .76341 .37402 Mtetra
.65 .749 .922 r
.76341 .37402 .77111 .38433 .7886 .37899 .78098 .36861 Mtetra
.656 .751 .92 r
.78098 .36861 .7886 .37899 .80617 .37337 .79863 .36293 Mtetra
.659 .753 .919 r
.79863 .36293 .80617 .37337 .82384 .36759 .81638 .35709 Mtetra
.657 .752 .92 r
.81638 .35709 .82384 .36759 .84163 .36188 .83424 .3513 Mtetra
.652 .75 .921 r
.83424 .3513 .84163 .36188 .85955 .35632 .85224 .34569 Mtetra
.66 .752 .919 r
.21476 .53877 .22457 .54733 .23898 .54255 .22922 .53395 Mtetra
.655 .751 .921 r
.22922 .53395 .23898 .54255 .25346 .53794 .24374 .52928 Mtetra
.652 .75 .922 r
.24374 .52928 .25346 .53794 .26801 .5334 .25834 .52469 Mtetra
.655 .751 .92 r
.25834 .52469 .26801 .5334 .28265 .5287 .27303 .51996 Mtetra
.662 .753 .918 r
.27303 .51996 .28265 .5287 .29739 .52375 .28782 .51496 Mtetra
.655 .751 .921 r
.28782 .51496 .29739 .52375 .31219 .51905 .30267 .51018 Mtetra
.65 .75 .922 r
.30267 .51018 .31219 .51905 .32707 .51446 .3176 .50554 Mtetra
.655 .751 .921 r
.3176 .50554 .32707 .51446 .34204 .50966 .33263 .50073 Mtetra
.665 .755 .917 r
.33263 .50073 .34204 .50966 .35712 .50446 .34776 .49549 Mtetra
.654 .751 .922 r
.34776 .49549 .35712 .50446 .37226 .49973 .36295 .49065 Mtetra
.648 .748 .923 r
.36295 .49065 .37226 .49973 .38748 .49513 .37822 .48599 Mtetra
.65 .749 .922 r
.37822 .48599 .38748 .49513 .40279 .49033 .39359 .48122 Mtetra
.645 .749 .925 r
.39359 .48122 .40279 .49033 .41818 .48612 .40904 .47661 Mtetra
.507 .689 .949 r
.40904 .47661 .41818 .48612 .43353 .48651 .42445 .47602 Mtetra
.305 .564 .929 r
.42445 .47602 .43353 .48651 .44891 .49164 .43989 .47994 Mtetra
.355 .564 .916 r
.43989 .47994 .44891 .49164 .46453 .49367 .4555 .48357 Mtetra
.666 .74 .905 r
.4555 .48357 .46453 .49367 .48047 .48416 .47144 .47801 Mtetra
.85 .849 .842 r
.47144 .47801 .48047 .48416 .49658 .46035 .48759 .46203 Mtetra
.846 .996 .831 r
.48759 .46203 .49658 .46035 .51259 .43903 .50373 .44569 Mtetra
.039 0 0 r
.50373 .44569 .51259 .43903 .52855 .43386 .51983 .44048 Mtetra
.541 .033 0 r
.51983 .44048 .52855 .43386 .54471 .44489 .53607 .44645 Mtetra
.444 0 0 r
.53607 .44645 .54471 .44489 .56115 .45853 .55252 .45211 Mtetra
.621 .825 .978 r
.55252 .45211 .56115 .45853 .57765 .45782 .56903 .44732 Mtetra
.8 .776 .83 r
.56903 .44732 .57765 .45782 .59404 .44545 .58547 .43321 Mtetra
.791 .746 .812 r
.58547 .43321 .59404 .44545 .61038 .4299 .60192 .41878 Mtetra
.741 .753 .862 r
.60192 .41878 .61038 .4299 .62686 .41912 .6185 .40887 Mtetra
.665 .748 .912 r
.6185 .40887 .62686 .41912 .64356 .41299 .63527 .40304 Mtetra
.661 .754 .919 r
.63527 .40304 .64356 .41299 .66037 .40747 .65215 .39737 Mtetra
.663 .753 .917 r
.65215 .39737 .66037 .40747 .67728 .40173 .66913 .39158 Mtetra
.658 .751 .919 r
.66913 .39158 .67728 .40173 .69429 .39613 .68622 .38597 Mtetra
.647 .748 .924 r
.68622 .38597 .69429 .39613 .71143 .39099 .70343 .38078 Mtetra
.657 .753 .92 r
.70343 .38078 .71143 .39099 .72866 .38545 .72073 .37513 Mtetra
.661 .753 .919 r
.72073 .37513 .72866 .38545 .74598 .37968 .73812 .3693 Mtetra
.657 .751 .92 r
.73812 .3693 .74598 .37968 .76341 .37402 .75563 .3636 Mtetra
.65 .749 .922 r
.75563 .3636 .76341 .37402 .78098 .36861 .77327 .35813 Mtetra
.656 .752 .92 r
.77327 .35813 .78098 .36861 .79863 .36293 .791 .35236 Mtetra
.659 .753 .919 r
.791 .35236 .79863 .36293 .81638 .35709 .80882 .34645 Mtetra
.656 .751 .92 r
.80882 .34645 .81638 .35709 .83424 .3513 .82677 .34062 Mtetra
.652 .75 .921 r
.82677 .34062 .83424 .3513 .85224 .34569 .84485 .33493 Mtetra
.66 .752 .919 r
.20485 .53013 .21476 .53877 .22922 .53395 .21935 .52527 Mtetra
.656 .752 .92 r
.21935 .52527 .22922 .53395 .24374 .52928 .23393 .52051 Mtetra
.652 .75 .922 r
.23393 .52051 .24374 .52928 .25834 .52469 .24857 .51588 Mtetra
.654 .751 .921 r
.24857 .51588 .25834 .52469 .27303 .51996 .26331 .51112 Mtetra
.661 .753 .918 r
.26331 .51112 .27303 .51996 .28782 .51496 .27815 .50609 Mtetra
.656 .752 .921 r
.27815 .50609 .28782 .51496 .30267 .51018 .29306 .50121 Mtetra
.651 .749 .922 r
.29306 .50121 .30267 .51018 .3176 .50554 .30804 .49652 Mtetra
.653 .75 .921 r
.30804 .49652 .3176 .50554 .33263 .50073 .32311 .49172 Mtetra
.664 .754 .917 r
.32311 .49172 .33263 .50073 .34776 .49549 .33829 .48645 Mtetra
.657 .753 .921 r
.33829 .48645 .34776 .49549 .36295 .49065 .35354 .48144 Mtetra
.648 .748 .922 r
.35354 .48144 .36295 .49065 .37822 .48599 .36887 .47672 Mtetra
.36887 .47672 .37822 .48599 .39359 .48122 .38428 .47199 Mtetra
.656 .752 .921 r
.38428 .47199 .39359 .48122 .40904 .47661 .3998 .46694 Mtetra
.573 .715 .938 r
.3998 .46694 .40904 .47661 .42445 .47602 .41532 .46461 Mtetra
.451 .622 .925 r
.41532 .46461 .42445 .47602 .43989 .47994 .43085 .46593 Mtetra
.369 .526 .882 r
.43085 .46593 .43989 .47994 .4555 .48357 .44646 .47025 Mtetra
.533 .625 .889 r
.44646 .47025 .4555 .48357 .47144 .47801 .46234 .4698 Mtetra
.686 .792 .931 r
.46234 .4698 .47144 .47801 .48759 .46203 .47845 .46336 Mtetra
.563 .937 .867 r
.47845 .46336 .48759 .46203 .50373 .44569 .49466 .45492 Mtetra
.149 0 0 r
.49466 .45492 .50373 .44569 .51983 .44048 .51092 .44968 Mtetra
.3 0 0 r
.51092 .44968 .51983 .44048 .53607 .44645 .52728 .44765 Mtetra
.238 .754 .768 r
.52728 .44765 .53607 .44645 .55252 .45211 .54376 .44363 Mtetra
.758 .81 .894 r
.54376 .44363 .55252 .45211 .56903 .44732 .56028 .43356 Mtetra
.784 .723 .796 r
.56028 .43356 .56903 .44732 .58547 .43321 .57678 .41864 Mtetra
.747 .702 .809 r
.57678 .41864 .58547 .43321 .60192 .41878 .59335 .40671 Mtetra
.709 .728 .866 r
.59335 .40671 .60192 .41878 .6185 .40887 .61004 .39846 Mtetra
.656 .744 .914 r
.61004 .39846 .6185 .40887 .63527 .40304 .6269 .39296 Mtetra
.663 .755 .918 r
.6269 .39296 .63527 .40304 .65215 .39737 .64385 .38714 Mtetra
.663 .753 .917 r
.64385 .38714 .65215 .39737 .66913 .39158 .66089 .38129 Mtetra
.655 .75 .92 r
.66089 .38129 .66913 .39158 .68622 .38597 .67806 .37574 Mtetra
.647 .75 .924 r
.67806 .37574 .68622 .38597 .70343 .38078 .69534 .37045 Mtetra
.658 .753 .92 r
.69534 .37045 .70343 .38078 .72073 .37513 .71271 .36468 Mtetra
.661 .753 .918 r
.71271 .36468 .72073 .37513 .73812 .3693 .73018 .35879 Mtetra
.655 .751 .92 r
.73018 .35879 .73812 .3693 .75563 .3636 .74776 .35307 Mtetra
.651 .75 .922 r
.74776 .35307 .75563 .3636 .77327 .35813 .76548 .34752 Mtetra
.657 .752 .92 r
.76548 .34752 .77327 .35813 .791 .35236 .78328 .34167 Mtetra
.659 .753 .919 r
.78328 .34167 .791 .35236 .80882 .34645 .80118 .33569 Mtetra
.656 .751 .92 r
.80118 .33569 .80882 .34645 .82677 .34062 .81921 .32982 Mtetra
.652 .75 .921 r
.81921 .32982 .82677 .34062 .84485 .33493 .83737 .32405 Mtetra
.659 .752 .919 r
.19483 .52139 .20485 .53013 .21935 .52527 .20939 .51651 Mtetra
.657 .752 .92 r
.20939 .51651 .21935 .52527 .23393 .52051 .22401 .51166 Mtetra
.652 .75 .921 r
.22401 .51166 .23393 .52051 .24857 .51588 .23871 .50697 Mtetra
.654 .75 .921 r
.23871 .50697 .24857 .51588 .26331 .51112 .25349 .50219 Mtetra
.66 .753 .919 r
.25349 .50219 .26331 .51112 .27815 .50609 .26838 .49715 Mtetra
.658 .753 .92 r
.26838 .49715 .27815 .50609 .29306 .50121 .28334 .49214 Mtetra
.651 .749 .922 r
.28334 .49214 .29306 .50121 .30804 .49652 .29837 .48738 Mtetra
.652 .749 .921 r
.29837 .48738 .30804 .49652 .32311 .49172 .31349 .48257 Mtetra
.662 .753 .918 r
.31349 .48257 .32311 .49172 .33829 .48645 .32872 .47735 Mtetra
.661 .755 .92 r
.32872 .47735 .33829 .48645 .35354 .48144 .34404 .47214 Mtetra
.649 .748 .922 r
.34404 .47214 .35354 .48144 .36887 .47672 .35942 .46733 Mtetra
.649 .747 .921 r
.35942 .46733 .36887 .47672 .38428 .47199 .37489 .46251 Mtetra
.655 .748 .918 r
.37489 .46251 .38428 .47199 .3998 .46694 .39046 .45742 Mtetra
.635 .742 .926 r
.39046 .45742 .3998 .46694 .41532 .46461 .4061 .45306 Mtetra
.538 .662 .916 r
.4061 .45306 .41532 .46461 .43085 .46593 .42173 .45205 Mtetra
.473 .586 .887 r
.42173 .45205 .43085 .46593 .44646 .47025 .43742 .4535 Mtetra
.48 .545 .846 r
.43742 .4535 .44646 .47025 .46234 .4698 .45326 .45552 Mtetra
.559 .624 .873 r
.45326 .45552 .46234 .4698 .47845 .46336 .46933 .45421 Mtetra
.631 .757 .938 r
.46933 .45421 .47845 .46336 .49466 .45492 .48556 .44974 Mtetra
.624 .858 .987 r
.48556 .44974 .49466 .45492 .51092 .44968 .50191 .44445 Mtetra
.654 .867 .98 r
.50191 .44445 .51092 .44968 .52728 .44765 .51835 .43833 Mtetra
.74 .788 .891 r
.51835 .43833 .52728 .44765 .54376 .44363 .53488 .42902 Mtetra
.755 .704 .804 r
.53488 .42902 .54376 .44363 .56028 .43356 .55144 .41634 Mtetra
.733 .666 .784 r
.55144 .41634 .56028 .43356 .57678 .41864 .56803 .40419 Mtetra
.719 .695 .826 r
.56803 .40419 .57678 .41864 .59335 .40671 .5847 .39449 Mtetra
.671 .714 .881 r
.5847 .39449 .59335 .40671 .61004 .39846 .6015 .38818 Mtetra
.656 .749 .918 r
.6015 .38818 .61004 .39846 .6269 .39296 .61843 .38261 Mtetra
.662 .751 .916 r
.61843 .38261 .6269 .39296 .64385 .38714 .63544 .37675 Mtetra
.662 .752 .917 r
.63544 .37675 .64385 .38714 .66089 .38129 .65256 .37088 Mtetra
.651 .748 .921 r
.65256 .37088 .66089 .38129 .67806 .37574 .6698 .36543 Mtetra
.65 .752 .924 r
.6698 .36543 .67806 .37574 .69534 .37045 .68716 .35997 Mtetra
.659 .753 .919 r
.68716 .35997 .69534 .37045 .71271 .36468 .70459 .35409 Mtetra
.66 .752 .918 r
.70459 .35409 .71271 .36468 .73018 .35879 .72214 .34815 Mtetra
.653 .75 .92 r
.72214 .34815 .73018 .35879 .74776 .35307 .73981 .34245 Mtetra
.652 .751 .922 r
.73981 .34245 .74776 .35307 .76548 .34752 .75759 .33678 Mtetra
.658 .752 .92 r
.75759 .33678 .76548 .34752 .78328 .34167 .77547 .33084 Mtetra
.659 .752 .919 r
.77547 .33084 .78328 .34167 .80118 .33569 .79346 .32479 Mtetra
.655 .75 .92 r
.79346 .32479 .80118 .33569 .81921 .32982 .81157 .3189 Mtetra
.653 .751 .922 r
.81157 .3189 .81921 .32982 .83737 .32405 .8298 .31305 Mtetra
.658 .752 .919 r
.18472 .51257 .19483 .52139 .20939 .51651 .19931 .50766 Mtetra
.659 .753 .92 r
.19931 .50766 .20939 .51651 .22401 .51166 .21399 .50271 Mtetra
.652 .75 .921 r
.21399 .50271 .22401 .51166 .23871 .50697 .22874 .49796 Mtetra
.653 .75 .921 r
.22874 .49796 .23871 .50697 .25349 .50219 .24357 .49315 Mtetra
.658 .752 .919 r
.24357 .49315 .25349 .50219 .26838 .49715 .2585 .48813 Mtetra
.661 .754 .919 r
.2585 .48813 .26838 .49715 .28334 .49214 .27352 .48298 Mtetra
.652 .75 .921 r
.27352 .48298 .28334 .49214 .29837 .48738 .28861 .47813 Mtetra
.651 .749 .921 r
.28861 .47813 .29837 .48738 .31349 .48257 .30378 .47329 Mtetra
.657 .751 .919 r
.30378 .47329 .31349 .48257 .32872 .47735 .31905 .46819 Mtetra
.664 .757 .919 r
.31905 .46819 .32872 .47735 .34404 .47214 .33443 .46279 Mtetra
.653 .751 .921 r
.33443 .46279 .34404 .47214 .35942 .46733 .34987 .45779 Mtetra
.649 .746 .921 r
.34987 .45779 .35942 .46733 .37489 .46251 .36539 .45291 Mtetra
.36539 .45291 .37489 .46251 .39046 .45742 .38101 .44802 Mtetra
.658 .754 .921 r
.38101 .44802 .39046 .45742 .4061 .45306 .39674 .44274 Mtetra
.621 .724 .92 r
.39674 .44274 .4061 .45306 .42173 .45205 .41251 .43883 Mtetra
.564 .644 .888 r
.41251 .43883 .42173 .45205 .43742 .4535 .42832 .43719 Mtetra
.552 .59 .846 r
.42832 .43719 .43742 .4535 .45326 .45552 .44423 .43632 Mtetra
.552 .555 .811 r
.44423 .43632 .45326 .45552 .46933 .45421 .46028 .43567 Mtetra
.596 .586 .812 r
.46028 .43567 .46933 .45421 .48556 .44974 .47651 .43279 Mtetra
.642 .628 .821 r
.47651 .43279 .48556 .44974 .50191 .44445 .49288 .42743 Mtetra
.681 .645 .808 r
.49288 .42743 .50191 .44445 .51835 .43833 .50937 .41958 Mtetra
.702 .637 .781 r
.50937 .41958 .51835 .43833 .53488 .42902 .52592 .40946 Mtetra
.695 .627 .776 r
.52592 .40946 .53488 .42902 .55144 .41634 .54253 .39955 Mtetra
.699 .658 .806 r
.54253 .39955 .55144 .41634 .56803 .40419 .55921 .39039 Mtetra
.677 .691 .856 r
.55921 .39039 .56803 .40419 .5847 .39449 .57598 .38352 Mtetra
.654 .735 .909 r
.57598 .38352 .5847 .39449 .6015 .38818 .59287 .37801 Mtetra
.662 .756 .92 r
.59287 .37801 .6015 .38818 .61843 .38261 .60986 .37213 Mtetra
.662 .751 .916 r
.60986 .37213 .61843 .38261 .63544 .37675 .62694 .36621 Mtetra
.658 .749 .917 r
.62694 .36621 .63544 .37675 .65256 .37088 .64414 .36042 Mtetra
.647 .748 .923 r
.64414 .36042 .65256 .37088 .6698 .36543 .66146 .35504 Mtetra
.654 .754 .923 r
.66146 .35504 .6698 .36543 .68716 .35997 .67888 .34933 Mtetra
.66 .752 .918 r
.67888 .34933 .68716 .35997 .70459 .35409 .69639 .34336 Mtetra
.659 .751 .918 r
.69639 .34336 .70459 .35409 .72214 .34815 .71401 .33739 Mtetra
.651 .749 .921 r
.71401 .33739 .72214 .34815 .73981 .34245 .73176 .33172 Mtetra
.653 .752 .922 r
.73176 .33172 .73981 .34245 .75759 .33678 .74962 .32591 Mtetra
.658 .752 .919 r
.74962 .32591 .75759 .33678 .77547 .33084 .76757 .31988 Mtetra
.659 .752 .919 r
.76757 .31988 .77547 .33084 .79346 .32479 .78564 .31377 Mtetra
.653 .75 .921 r
.78564 .31377 .79346 .32479 .81157 .3189 .80384 .30787 Mtetra
.654 .751 .921 r
.80384 .30787 .81157 .3189 .8298 .31305 .82215 .30191 Mtetra
.657 .752 .92 r
.17449 .50364 .18472 .51257 .19931 .50766 .18913 .49873 Mtetra
.66 .753 .919 r
.18913 .49873 .19931 .50766 .21399 .50271 .20387 .49369 Mtetra
.654 .751 .921 r
.20387 .49369 .21399 .50271 .22874 .49796 .21866 .48884 Mtetra
.652 .75 .921 r
.21866 .48884 .22874 .49796 .24357 .49315 .23354 .484 Mtetra
.656 .751 .92 r
.23354 .484 .24357 .49315 .2585 .48813 .24851 .47902 Mtetra
.661 .755 .919 r
.24851 .47902 .2585 .48813 .27352 .48298 .26359 .4738 Mtetra
.655 .752 .921 r
.26359 .4738 .27352 .48298 .28861 .47813 .27874 .46878 Mtetra
.651 .749 .921 r
.27874 .46878 .28861 .47813 .30378 .47329 .29396 .46388 Mtetra
.653 .749 .92 r
.29396 .46388 .30378 .47329 .31905 .46819 .30927 .45889 Mtetra
.663 .755 .919 r
.30927 .45889 .31905 .46819 .33443 .46279 .3247 .4535 Mtetra
.66 .756 .921 r
.3247 .4535 .33443 .46279 .34987 .45779 .34022 .44818 Mtetra
.65 .747 .921 r
.34022 .44818 .34987 .45779 .36539 .45291 .3558 .44319 Mtetra
.65 .746 .92 r
.3558 .44319 .36539 .45291 .38101 .44802 .37147 .4382 Mtetra
.65 .745 .919 r
.37147 .4382 .38101 .44802 .39674 .44274 .38724 .43318 Mtetra
.658 .755 .921 r
.38724 .43318 .39674 .44274 .41251 .43883 .40312 .42779 Mtetra
.637 .717 .906 r
.40312 .42779 .41251 .43883 .42832 .43719 .41906 .42322 Mtetra
.604 .652 .87 r
.41906 .42322 .42832 .43719 .44423 .43632 .43507 .41999 Mtetra
.604 .618 .838 r
.43507 .41999 .44423 .43632 .46028 .43567 .4512 .41671 Mtetra
.616 .593 .804 r
.4512 .41671 .46028 .43567 .47651 .43279 .46745 .41257 Mtetra
.634 .59 .787 r
.46745 .41257 .47651 .43279 .49288 .42743 .48384 .40713 Mtetra
.652 .599 .782 r
.48384 .40713 .49288 .42743 .50937 .41958 .50033 .4004 Mtetra
.668 .618 .79 r
.50033 .4004 .50937 .41958 .52592 .40946 .51691 .3928 Mtetra
.679 .651 .816 r
.51691 .3928 .52592 .40946 .54253 .39955 .53357 .38513 Mtetra
.664 .677 .852 r
.53357 .38513 .54253 .39955 .55921 .39039 .55032 .3788 Mtetra
.653 .723 .9 r
.55032 .3788 .55921 .39039 .57598 .38352 .56718 .3733 Mtetra
.662 .756 .92 r
.56718 .3733 .57598 .38352 .59287 .37801 .58414 .36741 Mtetra
.661 .749 .915 r
.58414 .36741 .59287 .37801 .60986 .37213 .60119 .36151 Mtetra
.661 .75 .916 r
.60119 .36151 .60986 .37213 .62694 .36621 .61835 .35558 Mtetra
.652 .747 .92 r
.61835 .35558 .62694 .36621 .64414 .36042 .63563 .35 Mtetra
.649 .752 .925 r
.63563 .35 .64414 .36042 .66146 .35504 .65302 .34448 Mtetra
.658 .754 .921 r
.65302 .34448 .66146 .35504 .67888 .34933 .6705 .33855 Mtetra
.66 .752 .918 r
.6705 .33855 .67888 .34933 .69639 .34336 .68809 .3325 Mtetra
.656 .75 .919 r
.68809 .3325 .69639 .34336 .71401 .33739 .70579 .32659 Mtetra
.65 .75 .923 r
.70579 .32659 .71401 .33739 .73176 .33172 .72362 .32088 Mtetra
.656 .753 .921 r
.72362 .32088 .73176 .33172 .74962 .32591 .74155 .3149 Mtetra
.659 .752 .919 r
.74155 .3149 .74962 .32591 .76757 .31988 .75958 .30877 Mtetra
.658 .751 .919 r
.75958 .30877 .76757 .31988 .78564 .31377 .77773 .30265 Mtetra
.652 .75 .921 r
.77773 .30265 .78564 .31377 .80384 .30787 .79601 .29672 Mtetra
.655 .752 .921 r
.79601 .29672 .80384 .30787 .82215 .30191 .81441 .29064 Mtetra
.656 .751 .92 r
.16416 .49462 .17449 .50364 .18913 .49873 .17885 .4897 Mtetra
.659 .753 .919 r
.17885 .4897 .18913 .49873 .20387 .49369 .19363 .48461 Mtetra
.656 .752 .921 r
.19363 .48461 .20387 .49369 .21866 .48884 .20848 .47962 Mtetra
.652 .749 .921 r
.20848 .47962 .21866 .48884 .23354 .484 .22341 .47474 Mtetra
.654 .75 .92 r
.22341 .47474 .23354 .484 .24851 .47902 .23843 .46977 Mtetra
.66 .753 .919 r
.23843 .46977 .24851 .47902 .26359 .4738 .25355 .46456 Mtetra
.659 .754 .92 r
.25355 .46456 .26359 .4738 .27874 .46878 .26876 .45933 Mtetra
.652 .749 .921 r
.26876 .45933 .27874 .46878 .29396 .46388 .28404 .45435 Mtetra
.651 .748 .92 r
.28404 .45435 .29396 .46388 .30927 .45889 .2994 .44936 Mtetra
.656 .751 .919 r
.2994 .44936 .30927 .45889 .3247 .4535 .31487 .44415 Mtetra
.664 .758 .92 r
.31487 .44415 .3247 .4535 .34022 .44818 .33045 .43863 Mtetra
.657 .753 .921 r
.33045 .43863 .34022 .44818 .3558 .44319 .3461 .43336 Mtetra
.65 .746 .92 r
.3461 .43336 .3558 .44319 .37147 .4382 .36183 .42829 Mtetra
.651 .746 .919 r
.36183 .42829 .37147 .4382 .38724 .43318 .37766 .42317 Mtetra
.651 .745 .918 r
.37766 .42317 .38724 .43318 .40312 .42779 .39358 .41803 Mtetra
.659 .754 .921 r
.39358 .41803 .40312 .42779 .41906 .42322 .40961 .41255 Mtetra
.653 .734 .909 r
.40961 .41255 .41906 .42322 .43507 .41999 .42573 .40726 Mtetra
.645 .693 .88 r
.42573 .40726 .43507 .41999 .4512 .41671 .44194 .40218 Mtetra
.643 .664 .855 r
.44194 .40218 .4512 .41671 .46745 .41257 .45826 .39702 Mtetra
.647 .651 .84 r
.45826 .39702 .46745 .41257 .48384 .40713 .47468 .39152 Mtetra
.652 .654 .838 r
.47468 .39152 .48384 .40713 .50033 .4004 .4912 .38567 Mtetra
.656 .669 .85 r
.4912 .38567 .50033 .4004 .51691 .3928 .50782 .37974 Mtetra
.655 .697 .876 r
.50782 .37974 .51691 .3928 .53357 .38513 .52454 .37402 Mtetra
.653 .734 .909 r
.52454 .37402 .53357 .38513 .55032 .3788 .54136 .36849 Mtetra
.661 .755 .92 r
.54136 .36849 .55032 .3788 .56718 .3733 .55828 .36261 Mtetra
.66 .748 .915 r
.55828 .36261 .56718 .3733 .58414 .36741 .5753 .35671 Mtetra
.661 .749 .915 r
.5753 .35671 .58414 .36741 .60119 .36151 .59243 .35075 Mtetra
.655 .747 .918 r
.59243 .35075 .60119 .36151 .61835 .35558 .60966 .345 Mtetra
.648 .75 .924 r
.60966 .345 .61835 .35558 .63563 .35 .62702 .33949 Mtetra
.655 .756 .924 r
.62702 .33949 .63563 .35 .65302 .34448 .64447 .33366 Mtetra
.66 .752 .918 r
.64447 .33366 .65302 .34448 .6705 .33855 .66202 .32761 Mtetra
.659 .751 .918 r
.66202 .32761 .6705 .33855 .68809 .3325 .67969 .32153 Mtetra
.653 .749 .92 r
.67969 .32153 .68809 .3325 .70579 .32659 .69748 .3157 Mtetra
.652 .752 .923 r
.69748 .3157 .70579 .32659 .72362 .32088 .71538 .30985 Mtetra
.657 .753 .92 r
.71538 .30985 .72362 .32088 .74155 .3149 .73338 .30375 Mtetra
.659 .752 .919 r
.73338 .30375 .74155 .3149 .75958 .30877 .7515 .29753 Mtetra
.655 .75 .92 r
.7515 .29753 .75958 .30877 .77773 .30265 .76973 .29143 Mtetra
.652 .751 .922 r
.76973 .29143 .77773 .30265 .79601 .29672 .7881 .28542 Mtetra
.656 .752 .921 r
.7881 .28542 .79601 .29672 .81441 .29064 .80657 .27922 Mtetra
.655 .751 .92 r
.15373 .48548 .16416 .49462 .17885 .4897 .16845 .48054 Mtetra
.658 .752 .919 r
.16845 .48054 .17885 .4897 .19363 .48461 .18328 .47545 Mtetra
.659 .753 .92 r
.18328 .47545 .19363 .48461 .20848 .47962 .19819 .47031 Mtetra
.653 .75 .921 r
.19819 .47031 .20848 .47962 .22341 .47474 .21317 .46536 Mtetra
.653 .749 .92 r
.21317 .46536 .22341 .47474 .23843 .46977 .22823 .46037 Mtetra
.656 .751 .92 r
.22823 .46037 .23843 .46977 .25355 .46456 .2434 .45523 Mtetra
.661 .755 .92 r
.2434 .45523 .25355 .46456 .26876 .45933 .25867 .44988 Mtetra
.655 .752 .921 r
.25867 .44988 .26876 .45933 .28404 .45435 .27401 .44471 Mtetra
.652 .748 .92 r
.27401 .44471 .28404 .45435 .2994 .44936 .28943 .43966 Mtetra
.28943 .43966 .2994 .44936 .31487 .44415 .30494 .43454 Mtetra
.659 .753 .92 r
.30494 .43454 .31487 .44415 .33045 .43863 .32056 .42916 Mtetra
.663 .759 .921 r
.32056 .42916 .33045 .43863 .3461 .43336 .33628 .42358 Mtetra
.656 .751 .92 r
.33628 .42358 .3461 .43336 .36183 .42829 .35208 .41825 Mtetra
.651 .745 .919 r
.35208 .41825 .36183 .42829 .37766 .42317 .36797 .41305 Mtetra
.652 .745 .918 r
.36797 .41305 .37766 .42317 .39358 .41803 .38395 .40782 Mtetra
.652 .744 .917 r
.38395 .40782 .39358 .41803 .40961 .41255 .40003 .40252 Mtetra
.652 .75 .921 r
.40003 .40252 .40961 .41255 .42573 .40726 .41621 .39719 Mtetra
.656 .752 .92 r
.41621 .39719 .42573 .40726 .44194 .40218 .43249 .39166 Mtetra
.657 .743 .914 r
.43249 .39166 .44194 .40218 .45826 .39702 .44887 .38608 Mtetra
.656 .735 .908 r
.44887 .38608 .45826 .39702 .47468 .39152 .46535 .38052 Mtetra
.654 .735 .909 r
.46535 .38052 .47468 .39152 .4912 .38567 .48193 .37497 Mtetra
.655 .743 .914 r
.48193 .37497 .4912 .38567 .50782 .37974 .49862 .36936 Mtetra
.659 .752 .919 r
.49862 .36936 .50782 .37974 .52454 .37402 .5154 .36356 Mtetra
.5154 .36356 .52454 .37402 .54136 .36849 .53229 .35772 Mtetra
.66 .747 .915 r
.53229 .35772 .54136 .36849 .55828 .36261 .54928 .35181 Mtetra
.66 .748 .915 r
.54928 .35181 .55828 .36261 .5753 .35671 .56637 .34586 Mtetra
.656 .747 .917 r
.56637 .34586 .5753 .35671 .59243 .35075 .58357 .34005 Mtetra
.649 .749 .922 r
.58357 .34005 .59243 .35075 .60966 .345 .60088 .33448 Mtetra
.653 .756 .925 r
.60088 .33448 .60966 .345 .62702 .33949 .6183 .32871 Mtetra
.659 .754 .92 r
.6183 .32871 .62702 .33949 .64447 .33366 .63582 .32266 Mtetra
.66 .751 .917 r
.63582 .32266 .64447 .33366 .66202 .32761 .65345 .31654 Mtetra
.656 .749 .919 r
.65345 .31654 .66202 .32761 .67969 .32153 .6712 .31053 Mtetra
.651 .75 .922 r
.6712 .31053 .67969 .32153 .69748 .3157 .68907 .30471 Mtetra
.655 .754 .922 r
.68907 .30471 .69748 .3157 .71538 .30985 .70704 .29866 Mtetra
.658 .752 .919 r
.70704 .29866 .71538 .30985 .73338 .30375 .72512 .29244 Mtetra
.659 .751 .918 r
.72512 .29244 .73338 .30375 .7515 .29753 .74332 .28617 Mtetra
.653 .749 .92 r
.74332 .28617 .7515 .29753 .76973 .29143 .76164 .2801 Mtetra
.654 .752 .922 r
.76164 .2801 .76973 .29143 .7881 .28542 .78009 .27396 Mtetra
.657 .752 .92 r
.78009 .27396 .7881 .28542 .80657 .27922 .79864 .26766 Mtetra
.654 .75 .92 r
.14318 .47622 .15373 .48548 .16845 .48054 .15795 .47128 Mtetra
.656 .751 .92 r
.15795 .47128 .16845 .48054 .18328 .47545 .17282 .4662 Mtetra
.66 .754 .92 r
.17282 .4662 .18328 .47545 .19819 .47031 .18778 .46098 Mtetra
.656 .752 .921 r
.18778 .46098 .19819 .47031 .21317 .46536 .20282 .45587 Mtetra
.652 .749 .921 r
.20282 .45587 .21317 .46536 .22823 .46037 .21794 .45085 Mtetra
.654 .75 .92 r
.21794 .45085 .22823 .46037 .2434 .45523 .23314 .44574 Mtetra
.659 .753 .92 r
.23314 .44574 .2434 .45523 .25867 .44988 .24846 .44042 Mtetra
.66 .755 .92 r
.24846 .44042 .25867 .44988 .27401 .44471 .26387 .435 Mtetra
.653 .749 .92 r
.26387 .435 .27401 .44471 .28943 .43966 .27934 .42983 Mtetra
.652 .748 .92 r
.27934 .42983 .28943 .43966 .30494 .43454 .29491 .42469 Mtetra
.653 .749 .92 r
.29491 .42469 .30494 .43454 .32056 .42916 .31057 .41946 Mtetra
.659 .755 .921 r
.31057 .41946 .32056 .42916 .33628 .42358 .32635 .41398 Mtetra
.662 .759 .922 r
.32635 .41398 .33628 .42358 .35208 .41825 .34222 .40834 Mtetra
.657 .752 .92 r
.34222 .40834 .35208 .41825 .36797 .41305 .35817 .40285 Mtetra
.653 .746 .918 r
.35817 .40285 .36797 .41305 .38395 .40782 .37421 .3975 Mtetra
.652 .745 .917 r
.37421 .3975 .38395 .40782 .40003 .40252 .39035 .39214 Mtetra
.653 .745 .917 r
.39035 .39214 .40003 .40252 .41621 .39719 .40659 .38671 Mtetra
.654 .744 .916 r
.40659 .38671 .41621 .39719 .43249 .39166 .42293 .38121 Mtetra
.655 .747 .917 r
.42293 .38121 .43249 .39166 .44887 .38608 .43938 .37565 Mtetra
.656 .749 .918 r
.43938 .37565 .44887 .38608 .46535 .38052 .45592 .37002 Mtetra
.657 .749 .918 r
.45592 .37002 .46535 .38052 .48193 .37497 .47256 .36433 Mtetra
.657 .747 .916 r
.47256 .36433 .48193 .37497 .49862 .36936 .48931 .35857 Mtetra
.658 .746 .915 r
.48931 .35857 .49862 .36936 .5154 .36356 .50616 .35274 Mtetra
.659 .747 .915 r
.50616 .35274 .5154 .36356 .53229 .35772 .52311 .34683 Mtetra
.52311 .34683 .53229 .35772 .54928 .35181 .54017 .34091 Mtetra
.654 .746 .917 r
.54017 .34091 .54928 .35181 .56637 .34586 .55734 .33514 Mtetra
.65 .75 .923 r
.55734 .33514 .56637 .34586 .58357 .34005 .57461 .32951 Mtetra
.653 .756 .926 r
.57461 .32951 .58357 .34005 .60088 .33448 .59199 .32371 Mtetra
.658 .755 .921 r
.59199 .32371 .60088 .33448 .6183 .32871 .60948 .31766 Mtetra
.66 .751 .917 r
.60948 .31766 .6183 .32871 .63582 .32266 .62708 .31151 Mtetra
.658 .75 .918 r
.62708 .31151 .63582 .32266 .65345 .31654 .64478 .30538 Mtetra
.651 .748 .921 r
.64478 .30538 .65345 .31654 .6712 .31053 .66261 .2995 Mtetra
.653 .753 .923 r
.66261 .2995 .6712 .31053 .68907 .30471 .68056 .29351 Mtetra
.657 .753 .92 r
.68056 .29351 .68907 .30471 .70704 .29866 .6986 .2873 Mtetra
.659 .752 .919 r
.6986 .2873 .70704 .29866 .72512 .29244 .71676 .28099 Mtetra
.656 .75 .919 r
.71676 .28099 .72512 .29244 .74332 .28617 .73504 .27476 Mtetra
.652 .751 .922 r
.73504 .27476 .74332 .28617 .76164 .2801 .75346 .26864 Mtetra
.655 .753 .921 r
.75346 .26864 .76164 .2801 .78009 .27396 .77198 .26236 Mtetra
.658 .752 .92 r
.77198 .26236 .78009 .27396 .79864 .26766 .79061 .25593 Mtetra
.653 .75 .921 r
.13252 .46687 .14318 .47622 .15795 .47128 .14734 .46189 Mtetra
.655 .751 .92 r
.14734 .46189 .15795 .47128 .17282 .4662 .16225 .45681 Mtetra
.658 .752 .92 r
.16225 .45681 .17282 .4662 .18778 .46098 .17726 .45158 Mtetra
.659 .754 .92 r
.17726 .45158 .18778 .46098 .20282 .45587 .19236 .44629 Mtetra
.653 .75 .921 r
.19236 .44629 .20282 .45587 .21794 .45085 .20753 .44119 Mtetra
.653 .749 .92 r
.20753 .44119 .21794 .45085 .23314 .44574 .22278 .43607 Mtetra
.655 .75 .92 r
.22278 .43607 .23314 .44574 .24846 .44042 .23814 .43083 Mtetra
.66 .755 .92 r
.23814 .43083 .24846 .44042 .26387 .435 .2536 .42538 Mtetra
.659 .755 .921 r
.2536 .42538 .26387 .435 .27934 .42983 .26915 .41993 Mtetra
.653 .749 .92 r
.26915 .41993 .27934 .42983 .29491 .42469 .28477 .41468 Mtetra
.652 .747 .919 r
.28477 .41468 .29491 .42469 .31057 .41946 .30049 .40943 Mtetra
.653 .748 .92 r
.30049 .40943 .31057 .41946 .32635 .41398 .3163 .4041 Mtetra
.657 .754 .922 r
.3163 .4041 .32635 .41398 .34222 .40834 .33222 .3986 Mtetra
.661 .759 .923 r
.33222 .3986 .34222 .40834 .35817 .40285 .34825 .39291 Mtetra
.66 .756 .921 r
.34825 .39291 .35817 .40285 .37421 .3975 .36436 .38722 Mtetra
.656 .749 .919 r
.36436 .38722 .37421 .3975 .39035 .39214 .38057 .38166 Mtetra
.654 .746 .917 r
.38057 .38166 .39035 .39214 .40659 .38671 .39687 .37613 Mtetra
.654 .745 .916 r
.39687 .37613 .40659 .38671 .42293 .38121 .41327 .37056 Mtetra
.655 .745 .916 r
.41327 .37056 .42293 .38121 .43938 .37565 .42978 .36494 Mtetra
.656 .745 .916 r
.42978 .36494 .43938 .37565 .45592 .37002 .44638 .35924 Mtetra
.657 .745 .915 r
.44638 .35924 .45592 .37002 .47256 .36433 .46309 .35348 Mtetra
.657 .746 .915 r
.46309 .35348 .47256 .36433 .48931 .35857 .4799 .34767 Mtetra
.4799 .34767 .48931 .35857 .50616 .35274 .49682 .34181 Mtetra
.656 .746 .916 r
.49682 .34181 .50616 .35274 .52311 .34683 .51384 .33598 Mtetra
.652 .748 .92 r
.51384 .33598 .52311 .34683 .54017 .34091 .53097 .33027 Mtetra
.651 .753 .925 r
.53097 .33027 .54017 .34091 .55734 .33514 .5482 .32457 Mtetra
.654 .758 .925 r
.5482 .32457 .55734 .33514 .57461 .32951 .56555 .31867 Mtetra
.658 .755 .921 r
.56555 .31867 .57461 .32951 .59199 .32371 .583 .31259 Mtetra
.659 .75 .917 r
.583 .31259 .59199 .32371 .60948 .31766 .60056 .30643 Mtetra
.658 .749 .917 r
.60056 .30643 .60948 .31766 .62708 .31151 .61823 .30026 Mtetra
.653 .748 .92 r
.61823 .30026 .62708 .31151 .64478 .30538 .63602 .29428 Mtetra
.652 .753 .923 r
.63602 .29428 .64478 .30538 .66261 .2995 .65392 .28831 Mtetra
.657 .754 .922 r
.65392 .28831 .66261 .2995 .68056 .29351 .67194 .28211 Mtetra
.658 .752 .919 r
.67194 .28211 .68056 .29351 .6986 .2873 .69006 .27578 Mtetra
.658 .751 .918 r
.69006 .27578 .6986 .2873 .71676 .28099 .7083 .26942 Mtetra
.653 .749 .92 r
.7083 .26942 .71676 .28099 .73504 .27476 .72668 .26324 Mtetra
.654 .752 .922 r
.72668 .26324 .73504 .27476 .75346 .26864 .74517 .257 Mtetra
.656 .752 .92 r
.74517 .257 .75346 .26864 .77198 .26236 .76377 .25059 Mtetra
.658 .752 .919 r
.76377 .25059 .77198 .26236 .79061 .25593 .78249 .24406 Mtetra
.653 .75 .921 r
.12175 .45743 .13252 .46687 .14734 .46189 .13662 .45237 Mtetra
.654 .75 .92 r
.13662 .45237 .14734 .46189 .16225 .45681 .15157 .44729 Mtetra
.656 .751 .92 r
.15157 .44729 .16225 .45681 .17726 .45158 .16662 .44208 Mtetra
.659 .754 .92 r
.16662 .44208 .17726 .45158 .19236 .44629 .18178 .43673 Mtetra
.657 .753 .921 r
.18178 .43673 .19236 .44629 .20753 .44119 .19701 .43143 Mtetra
.653 .749 .92 r
.19701 .43143 .20753 .44119 .22278 .43607 .21232 .42625 Mtetra
.21232 .42625 .22278 .43607 .23814 .43083 .22772 .42102 Mtetra
.656 .751 .92 r
.22772 .42102 .23814 .43083 .2536 .42538 .24322 .41567 Mtetra
.66 .756 .921 r
.24322 .41567 .2536 .42538 .26915 .41993 .25883 .41012 Mtetra
.658 .754 .921 r
.25883 .41012 .26915 .41993 .28477 .41468 .27452 .4046 Mtetra
.653 .748 .92 r
.27452 .4046 .28477 .41468 .30049 .40943 .2903 .39923 Mtetra
.653 .747 .919 r
.2903 .39923 .30049 .40943 .3163 .4041 .30617 .39387 Mtetra
.653 .748 .919 r
.30617 .39387 .3163 .4041 .33222 .3986 .32214 .38846 Mtetra
.655 .752 .921 r
.32214 .38846 .33222 .3986 .34825 .39291 .3382 .38295 Mtetra
.658 .758 .923 r
.3382 .38295 .34825 .39291 .36436 .38722 .35438 .37727 Mtetra
.659 .76 .924 r
.35438 .37727 .36436 .38722 .38057 .38166 .37065 .37152 Mtetra
.658 .757 .922 r
.37065 .37152 .38057 .38166 .39687 .37613 .38702 .36576 Mtetra
.657 .753 .92 r
.38702 .36576 .39687 .37613 .41327 .37056 .40349 .36001 Mtetra
.657 .75 .919 r
.40349 .36001 .41327 .37056 .42978 .36494 .42006 .35426 Mtetra
.656 .748 .918 r
.42006 .35426 .42978 .36494 .44638 .35924 .43673 .3485 Mtetra
.655 .748 .918 r
.43673 .3485 .44638 .35924 .46309 .35348 .4535 .34274 Mtetra
.654 .749 .92 r
.4535 .34274 .46309 .35348 .4799 .34767 .47038 .33697 Mtetra
.653 .751 .922 r
.47038 .33697 .4799 .34767 .49682 .34181 .48736 .33121 Mtetra
.652 .754 .925 r
.48736 .33121 .49682 .34181 .51384 .33598 .50445 .32545 Mtetra
.653 .758 .926 r
.50445 .32545 .51384 .33598 .53097 .33027 .52165 .3196 Mtetra
.657 .757 .924 r
.52165 .3196 .53097 .33027 .5482 .32457 .53896 .31358 Mtetra
.658 .753 .92 r
.53896 .31358 .5482 .32457 .56555 .31867 .55637 .30747 Mtetra
.659 .75 .917 r
.55637 .30747 .56555 .31867 .583 .31259 .5739 .30129 Mtetra
.658 .749 .917 r
.5739 .30129 .583 .31259 .60056 .30643 .59153 .2951 Mtetra
.653 .748 .919 r
.59153 .2951 .60056 .30643 .61823 .30026 .60928 .28908 Mtetra
.652 .752 .923 r
.60928 .28908 .61823 .30026 .63602 .29428 .62715 .28308 Mtetra
.656 .755 .923 r
.62715 .28308 .63602 .29428 .65392 .28831 .64513 .27687 Mtetra
.658 .752 .919 r
.64513 .27687 .65392 .28831 .67194 .28211 .66322 .27052 Mtetra
.659 .751 .918 r
.66322 .27052 .67194 .28211 .69006 .27578 .68142 .26412 Mtetra
.655 .749 .919 r
.68142 .26412 .69006 .27578 .7083 .26942 .69975 .25783 Mtetra
.653 .751 .922 r
.69975 .25783 .7083 .26942 .72668 .26324 .71821 .25159 Mtetra
.656 .753 .921 r
.71821 .25159 .72668 .26324 .74517 .257 .73678 .24519 Mtetra
.658 .752 .92 r
.73678 .24519 .74517 .257 .76377 .25059 .75546 .23865 Mtetra
.658 .751 .919 r
.75546 .23865 .76377 .25059 .78249 .24406 .77426 .23206 Mtetra
.656 .752 .921 r
.11085 .44796 .12175 .45743 .13662 .45237 .12578 .44275 Mtetra
.653 .749 .92 r
.12578 .44275 .13662 .45237 .15157 .44729 .14078 .43763 Mtetra
.655 .75 .92 r
.14078 .43763 .15157 .44729 .16662 .44208 .15587 .43242 Mtetra
.657 .752 .92 r
.15587 .43242 .16662 .44208 .18178 .43673 .17107 .42709 Mtetra
.659 .754 .92 r
.17107 .42709 .18178 .43673 .19701 .43143 .18636 .42165 Mtetra
.656 .752 .921 r
.18636 .42165 .19701 .43143 .21232 .42625 .20173 .41631 Mtetra
.653 .749 .92 r
.20173 .41631 .21232 .42625 .22772 .42102 .21719 .41104 Mtetra
.654 .749 .92 r
.21719 .41104 .22772 .42102 .24322 .41567 .23274 .4057 Mtetra
.656 .751 .92 r
.23274 .4057 .24322 .41567 .25883 .41012 .24839 .40026 Mtetra
.66 .756 .921 r
.24839 .40026 .25883 .41012 .27452 .4046 .26414 .39462 Mtetra
.659 .755 .921 r
.26414 .39462 .27452 .4046 .2903 .39923 .27999 .38899 Mtetra
.654 .749 .919 r
.27999 .38899 .2903 .39923 .30617 .39387 .29592 .3835 Mtetra
.653 .747 .919 r
.29592 .3835 .30617 .39387 .32214 .38846 .31195 .37802 Mtetra
.31195 .37802 .32214 .38846 .3382 .38295 .32807 .3725 Mtetra
.654 .749 .919 r
.32807 .3725 .3382 .38295 .35438 .37727 .3443 .36693 Mtetra
.655 .752 .921 r
.3443 .36693 .35438 .37727 .37065 .37152 .36062 .36128 Mtetra
.656 .756 .924 r
.36062 .36128 .37065 .37152 .38702 .36576 .37705 .35557 Mtetra
.657 .759 .925 r
.37705 .35557 .38702 .36576 .40349 .36001 .39359 .34979 Mtetra
.656 .759 .926 r
.39359 .34979 .40349 .36001 .42006 .35426 .41022 .34397 Mtetra
.41022 .34397 .42006 .35426 .43673 .3485 .42696 .33815 Mtetra
.655 .759 .926 r
.42696 .33815 .43673 .3485 .4535 .34274 .4438 .33232 Mtetra
.4438 .33232 .4535 .34274 .47038 .33697 .46074 .32645 Mtetra
.656 .759 .925 r
.46074 .32645 .47038 .33697 .48736 .33121 .4778 .32051 Mtetra
.657 .756 .923 r
.4778 .32051 .48736 .33121 .50445 .32545 .49496 .31451 Mtetra
.658 .753 .92 r
.49496 .31451 .50445 .32545 .52165 .3196 .51223 .30843 Mtetra
.658 .75 .918 r
.51223 .30843 .52165 .3196 .53896 .31358 .5296 .30228 Mtetra
.658 .749 .917 r
.5296 .30228 .53896 .31358 .55637 .30747 .54709 .2961 Mtetra
.657 .748 .917 r
.54709 .2961 .55637 .30747 .5739 .30129 .56469 .28991 Mtetra
.653 .748 .92 r
.56469 .28991 .5739 .30129 .59153 .2951 .5824 .28388 Mtetra
.652 .752 .923 r
.5824 .28388 .59153 .2951 .60928 .28908 .60023 .27783 Mtetra
.656 .755 .923 r
.60023 .27783 .60928 .28908 .62715 .28308 .61817 .27159 Mtetra
.658 .752 .92 r
.61817 .27159 .62715 .28308 .64513 .27687 .63622 .26522 Mtetra
.658 .751 .918 r
.63622 .26522 .64513 .27687 .66322 .27052 .65439 .25879 Mtetra
.656 .749 .919 r
.65439 .25879 .66322 .27052 .68142 .26412 .67268 .25241 Mtetra
.653 .75 .921 r
.67268 .25241 .68142 .26412 .69975 .25783 .6911 .24614 Mtetra
.655 .753 .922 r
.6911 .24614 .69975 .25783 .71821 .25159 .70963 .23973 Mtetra
.657 .752 .92 r
.70963 .23973 .71821 .25159 .73678 .24519 .72828 .2332 Mtetra
.658 .752 .919 r
.72828 .2332 .73678 .24519 .75546 .23865 .74705 .22656 Mtetra
.655 .75 .919 r
.74705 .22656 .75546 .23865 .77426 .23206 .76595 .22 Mtetra
.658 .753 .92 r
.09983 .43841 .11085 .44796 .12578 .44275 .11482 .43307 Mtetra
.655 .751 .921 r
.11482 .43307 .12578 .44275 .14078 .43763 .12987 .42783 Mtetra
.653 .749 .92 r
.12987 .42783 .14078 .43763 .15587 .43242 .14501 .42261 Mtetra
.655 .751 .92 r
.14501 .42261 .15587 .43242 .17107 .42709 .16025 .41729 Mtetra
.658 .753 .92 r
.16025 .41729 .17107 .42709 .18636 .42165 .17559 .41185 Mtetra
.659 .754 .921 r
.17559 .41185 .18636 .42165 .20173 .41631 .19103 .40632 Mtetra
.655 .751 .92 r
.19103 .40632 .20173 .41631 .21719 .41104 .20654 .40091 Mtetra
.653 .748 .92 r
.20654 .40091 .21719 .41104 .23274 .4057 .22214 .39554 Mtetra
.654 .749 .92 r
.22214 .39554 .23274 .4057 .24839 .40026 .23784 .39011 Mtetra
.655 .751 .92 r
.23784 .39011 .24839 .40026 .26414 .39462 .25364 .38459 Mtetra
.659 .756 .922 r
.25364 .38459 .26414 .39462 .27999 .38899 .26955 .3789 Mtetra
.26955 .3789 .27999 .38899 .29592 .3835 .28555 .37316 Mtetra
.657 .751 .92 r
.28555 .37316 .29592 .3835 .31195 .37802 .30164 .36749 Mtetra
.654 .748 .919 r
.30164 .36749 .31195 .37802 .32807 .3725 .31783 .36187 Mtetra
.654 .747 .918 r
.31783 .36187 .32807 .3725 .3443 .36693 .33411 .35623 Mtetra
.33411 .35623 .3443 .36693 .36062 .36128 .3505 .35055 Mtetra
.655 .748 .918 r
.3505 .35055 .36062 .36128 .37705 .35557 .36699 .34481 Mtetra
.655 .749 .919 r
.36699 .34481 .37705 .35557 .39359 .34979 .38358 .33903 Mtetra
.655 .75 .92 r
.38358 .33903 .39359 .34979 .41022 .34397 .40028 .33319 Mtetra
.656 .751 .92 r
.40028 .33319 .41022 .34397 .42696 .33815 .41708 .32729 Mtetra
.41708 .32729 .42696 .33815 .4438 .33232 .43399 .32135 Mtetra
.657 .751 .919 r
.43399 .32135 .4438 .33232 .46074 .32645 .451 .31536 Mtetra
.657 .749 .918 r
.451 .31536 .46074 .32645 .4778 .32051 .46812 .3093 Mtetra
.657 .749 .917 r
.46812 .3093 .4778 .32051 .49496 .31451 .48535 .3032 Mtetra
.657 .748 .917 r
.48535 .3032 .49496 .31451 .51223 .30843 .50269 .29705 Mtetra
.50269 .29705 .51223 .30843 .5296 .30228 .52014 .29087 Mtetra
.655 .748 .918 r
.52014 .29087 .5296 .30228 .54709 .2961 .5377 .28475 Mtetra
.653 .75 .921 r
.5377 .28475 .54709 .2961 .56469 .28991 .55538 .27868 Mtetra
.653 .754 .924 r
.55538 .27868 .56469 .28991 .5824 .28388 .57316 .27256 Mtetra
.656 .755 .923 r
.57316 .27256 .5824 .28388 .60023 .27783 .59107 .26627 Mtetra
.658 .752 .92 r
.59107 .26627 .60023 .27783 .61817 .27159 .60908 .25988 Mtetra
.658 .751 .918 r
.60908 .25988 .61817 .27159 .63622 .26522 .62721 .25341 Mtetra
.656 .749 .918 r
.62721 .25341 .63622 .26522 .65439 .25879 .64546 .24698 Mtetra
.653 .75 .921 r
.64546 .24698 .65439 .25879 .67268 .25241 .66384 .24066 Mtetra
.654 .753 .922 r
.66384 .24066 .67268 .25241 .6911 .24614 .68234 .23424 Mtetra
.656 .753 .921 r
.68234 .23424 .6911 .24614 .70963 .23973 .70095 .2277 Mtetra
.658 .752 .919 r
.70095 .2277 .70963 .23973 .72828 .2332 .71968 .22103 Mtetra
.657 .75 .919 r
.71968 .22103 .72828 .2332 .74705 .22656 .73854 .21437 Mtetra
.654 .75 .921 r
.73854 .21437 .74705 .22656 .76595 .22 .75753 .2078 Mtetra
.658 .753 .92 r
.08869 .42873 .09983 .43841 .11482 .43307 .10373 .42335 Mtetra
.10373 .42335 .11482 .43307 .12987 .42783 .11885 .41794 Mtetra
.654 .75 .92 r
.11885 .41794 .12987 .42783 .14501 .42261 .13404 .41265 Mtetra
.654 .749 .92 r
.13404 .41265 .14501 .42261 .16025 .41729 .14932 .40733 Mtetra
.655 .751 .92 r
.14932 .40733 .16025 .41729 .17559 .41185 .1647 .4019 Mtetra
.658 .753 .92 r
.1647 .4019 .17559 .41185 .19103 .40632 .18019 .39636 Mtetra
.659 .754 .921 r
.18019 .39636 .19103 .40632 .20654 .40091 .19577 .39075 Mtetra
.655 .751 .92 r
.19577 .39075 .20654 .40091 .22214 .39554 .21143 .38524 Mtetra
.653 .748 .92 r
.21143 .38524 .22214 .39554 .23784 .39011 .22719 .37977 Mtetra
.654 .749 .92 r
.22719 .37977 .23784 .39011 .25364 .38459 .24304 .37424 Mtetra
.655 .75 .92 r
.24304 .37424 .25364 .38459 .26955 .3789 .25899 .36863 Mtetra
.657 .754 .922 r
.25899 .36863 .26955 .3789 .28555 .37316 .27504 .36293 Mtetra
.659 .757 .922 r
.27504 .36293 .28555 .37316 .30164 .36749 .2912 .35711 Mtetra
.658 .755 .921 r
.2912 .35711 .30164 .36749 .31783 .36187 .30746 .35127 Mtetra
.657 .751 .919 r
.30746 .35127 .31783 .36187 .33411 .35623 .32381 .34545 Mtetra
.655 .748 .918 r
.32381 .34545 .33411 .35623 .3505 .35055 .34026 .33966 Mtetra
.655 .747 .918 r
.34026 .33966 .3505 .35055 .36699 .34481 .35681 .33385 Mtetra
.35681 .33385 .36699 .34481 .38358 .33903 .37347 .32799 Mtetra
.655 .747 .917 r
.37347 .32799 .38358 .33903 .40028 .33319 .39023 .32208 Mtetra
.656 .747 .917 r
.39023 .32208 .40028 .33319 .41708 .32729 .4071 .31612 Mtetra
.4071 .31612 .41708 .32729 .43399 .32135 .42407 .31011 Mtetra
.42407 .31011 .43399 .32135 .451 .31536 .44115 .30405 Mtetra
.656 .748 .917 r
.44115 .30405 .451 .31536 .46812 .3093 .45834 .29794 Mtetra
.45834 .29794 .46812 .3093 .48535 .3032 .47564 .2918 Mtetra
.655 .748 .919 r
.47564 .2918 .48535 .3032 .50269 .29705 .49305 .2857 Mtetra
.653 .75 .921 r
.49305 .2857 .50269 .29705 .52014 .29087 .51057 .2796 Mtetra
.653 .753 .923 r
.51057 .2796 .52014 .29087 .5377 .28475 .5282 .27349 Mtetra
.655 .755 .924 r
.5282 .27349 .5377 .28475 .55538 .27868 .54595 .26725 Mtetra
.657 .754 .922 r
.54595 .26725 .55538 .27868 .57316 .27256 .56381 .26091 Mtetra
.658 .751 .919 r
.56381 .26091 .57316 .27256 .59107 .26627 .58179 .25448 Mtetra
.658 .75 .918 r
.58179 .25448 .59107 .26627 .60908 .25988 .59988 .24799 Mtetra
.656 .749 .918 r
.59988 .24799 .60908 .25988 .62721 .25341 .6181 .24153 Mtetra
.653 .75 .921 r
.6181 .24153 .62721 .25341 .64546 .24698 .63643 .23516 Mtetra
.654 .753 .922 r
.63643 .23516 .64546 .24698 .66384 .24066 .65489 .22872 Mtetra
.656 .753 .921 r
.65489 .22872 .66384 .24066 .68234 .23424 .67347 .22215 Mtetra
.658 .752 .919 r
.67347 .22215 .68234 .23424 .70095 .2277 .69216 .21546 Mtetra
.658 .751 .919 r
.69216 .21546 .70095 .2277 .71968 .22103 .71098 .20873 Mtetra
.654 .749 .92 r
.71098 .20873 .71968 .22103 .73854 .21437 .72993 .2021 Mtetra
.654 .752 .922 r
.72993 .2021 .73854 .21437 .75753 .2078 .74901 .19544 Mtetra
.656 .752 .92 r
.07744 .41892 .08869 .42873 .10373 .42335 .09251 .41353 Mtetra
.658 .753 .92 r
.09251 .41353 .10373 .42335 .11885 .41794 .10768 .40805 Mtetra
.657 .753 .921 r
.10768 .40805 .11885 .41794 .13404 .41265 .12294 .40258 Mtetra
.654 .749 .92 r
.12294 .40258 .13404 .41265 .14932 .40733 .13827 .3972 Mtetra
.13827 .3972 .14932 .40733 .1647 .4019 .1537 .39177 Mtetra
.656 .751 .92 r
.1537 .39177 .1647 .4019 .18019 .39636 .16923 .38625 Mtetra
.658 .753 .921 r
.16923 .38625 .18019 .39636 .19577 .39075 .18487 .38062 Mtetra
.658 .755 .921 r
.18487 .38062 .19577 .39075 .21143 .38524 .2006 .37492 Mtetra
.656 .751 .92 r
.2006 .37492 .21143 .38524 .22719 .37977 .21641 .36928 Mtetra
.654 .748 .919 r
.21641 .36928 .22719 .37977 .24304 .37424 .23232 .36369 Mtetra
.23232 .36369 .24304 .37424 .25899 .36863 .24832 .35807 Mtetra
.655 .75 .92 r
.24832 .35807 .25899 .36863 .27504 .36293 .26443 .35239 Mtetra
.655 .752 .921 r
.26443 .35239 .27504 .36293 .2912 .35711 .28064 .34663 Mtetra
.656 .755 .922 r
.28064 .34663 .2912 .35711 .30746 .35127 .29695 .3408 Mtetra
.658 .757 .923 r
.29695 .3408 .30746 .35127 .32381 .34545 .31337 .33488 Mtetra
.658 .756 .922 r
.31337 .33488 .32381 .34545 .34026 .33966 .32989 .32894 Mtetra
.657 .754 .921 r
.32989 .32894 .34026 .33966 .35681 .33385 .34651 .32297 Mtetra
.657 .752 .92 r
.34651 .32297 .35681 .33385 .37347 .32799 .36323 .31699 Mtetra
.656 .751 .92 r
.36323 .31699 .37347 .32799 .39023 .32208 .38006 .31098 Mtetra
.656 .75 .919 r
.38006 .31098 .39023 .32208 .4071 .31612 .39699 .30495 Mtetra
.655 .75 .919 r
.39699 .30495 .4071 .31612 .42407 .31011 .41403 .2989 Mtetra
.655 .75 .92 r
.41403 .2989 .42407 .31011 .44115 .30405 .43118 .29282 Mtetra
.655 .751 .921 r
.43118 .29282 .44115 .30405 .45834 .29794 .44844 .28673 Mtetra
.654 .753 .922 r
.44844 .28673 .45834 .29794 .47564 .2918 .4658 .28061 Mtetra
.654 .755 .924 r
.4658 .28061 .47564 .2918 .49305 .2857 .48328 .27446 Mtetra
.655 .756 .924 r
.48328 .27446 .49305 .2857 .51057 .2796 .50088 .26822 Mtetra
.656 .755 .922 r
.50088 .26822 .51057 .2796 .5282 .27349 .51859 .2619 Mtetra
.657 .752 .92 r
.51859 .2619 .5282 .27349 .54595 .26725 .53641 .2555 Mtetra
.658 .751 .919 r
.53641 .2555 .54595 .26725 .56381 .26091 .55435 .24904 Mtetra
.658 .75 .918 r
.55435 .24904 .56381 .26091 .58179 .25448 .5724 .24253 Mtetra
.655 .749 .919 r
.5724 .24253 .58179 .25448 .59988 .24799 .59058 .23607 Mtetra
.653 .75 .921 r
.59058 .23607 .59988 .24799 .6181 .24153 .60887 .22966 Mtetra
.654 .753 .923 r
.60887 .22966 .6181 .24153 .63643 .23516 .62729 .22317 Mtetra
.656 .753 .921 r
.62729 .22317 .63643 .23516 .65489 .22872 .64583 .21656 Mtetra
.657 .752 .92 r
.64583 .21656 .65489 .22872 .67347 .22215 .66448 .20985 Mtetra
.658 .751 .919 r
.66448 .20985 .67347 .22215 .69216 .21546 .68326 .20307 Mtetra
.655 .749 .919 r
.68326 .20307 .69216 .21546 .71098 .20873 .70217 .19638 Mtetra
.654 .752 .922 r
.70217 .19638 .71098 .20873 .72993 .2021 .72122 .18969 Mtetra
.655 .752 .921 r
.72122 .18969 .72993 .2021 .74901 .19544 .74038 .18289 Mtetra
.655 .751 .92 r
.06606 .40896 .07744 .41892 .09251 .41353 .08118 .40356 Mtetra
.657 .752 .92 r
.08118 .40356 .09251 .41353 .10768 .40805 .09639 .39807 Mtetra
.658 .753 .92 r
.09639 .39807 .10768 .40805 .12294 .40258 .11171 .3925 Mtetra
.657 .752 .92 r
.11171 .3925 .12294 .40258 .13827 .3972 .12711 .38695 Mtetra
.654 .749 .92 r
.12711 .38695 .13827 .3972 .1537 .39177 .14259 .38147 Mtetra
.14259 .38147 .1537 .39177 .16923 .38625 .15816 .37595 Mtetra
.655 .751 .92 r
.15816 .37595 .16923 .38625 .18487 .38062 .17384 .37033 Mtetra
.657 .753 .921 r
.17384 .37033 .18487 .38062 .2006 .37492 .18962 .36463 Mtetra
.658 .755 .921 r
.18962 .36463 .2006 .37492 .21641 .36928 .2055 .35884 Mtetra
.657 .753 .92 r
.2055 .35884 .21641 .36928 .23232 .36369 .22148 .35304 Mtetra
.654 .749 .919 r
.22148 .35304 .23232 .36369 .24832 .35807 .23754 .34733 Mtetra
.654 .748 .919 r
.23754 .34733 .24832 .35807 .26443 .35239 .25371 .34159 Mtetra
.654 .749 .919 r
.25371 .34159 .26443 .35239 .28064 .34663 .26997 .33582 Mtetra
.655 .75 .92 r
.26997 .33582 .28064 .34663 .29695 .3408 .28634 .32998 Mtetra
.655 .751 .92 r
.28634 .32998 .29695 .3408 .31337 .33488 .30281 .32409 Mtetra
.656 .753 .922 r
.30281 .32409 .31337 .33488 .32989 .32894 .31939 .31815 Mtetra
.656 .755 .923 r
.31939 .31815 .32989 .32894 .34651 .32297 .33607 .31216 Mtetra
.656 .756 .923 r
.33607 .31216 .34651 .32297 .36323 .31699 .35286 .30613 Mtetra
.656 .756 .924 r
.35286 .30613 .36323 .31699 .38006 .31098 .36975 .30006 Mtetra
.36975 .30006 .38006 .31098 .39699 .30495 .38675 .29396 Mtetra
.655 .756 .924 r
.38675 .29396 .39699 .30495 .41403 .2989 .40386 .28783 Mtetra
.656 .756 .924 r
.40386 .28783 .41403 .2989 .43118 .29282 .42108 .28166 Mtetra
.656 .756 .923 r
.42108 .28166 .43118 .29282 .44844 .28673 .43841 .27545 Mtetra
.656 .755 .923 r
.43841 .27545 .44844 .28673 .4658 .28061 .45585 .26918 Mtetra
.656 .753 .921 r
.45585 .26918 .4658 .28061 .48328 .27446 .47341 .26286 Mtetra
.657 .752 .92 r
.47341 .26286 .48328 .27446 .50088 .26822 .49108 .25648 Mtetra
.657 .751 .919 r
.49108 .25648 .50088 .26822 .51859 .2619 .50886 .25004 Mtetra
.657 .75 .918 r
.50886 .25004 .51859 .2619 .53641 .2555 .52676 .24355 Mtetra
.657 .749 .918 r
.52676 .24355 .53641 .2555 .55435 .24904 .54477 .23703 Mtetra
.654 .749 .919 r
.54477 .23703 .55435 .24904 .5724 .24253 .56291 .23059 Mtetra
.653 .751 .922 r
.56291 .23059 .5724 .24253 .59058 .23607 .58116 .22414 Mtetra
.655 .754 .923 r
.58116 .22414 .59058 .23607 .60887 .22966 .59954 .21759 Mtetra
.656 .753 .921 r
.59954 .21759 .60887 .22966 .62729 .22317 .61803 .21094 Mtetra
.657 .752 .92 r
.61803 .21094 .62729 .22317 .64583 .21656 .63665 .20419 Mtetra
.658 .751 .919 r
.63665 .20419 .64583 .21656 .66448 .20985 .65539 .19738 Mtetra
.655 .749 .919 r
.65539 .19738 .66448 .20985 .68326 .20307 .67426 .19064 Mtetra
.654 .751 .921 r
.67426 .19064 .68326 .20307 .70217 .19638 .69326 .18391 Mtetra
.655 .753 .922 r
.69326 .18391 .70217 .19638 .72122 .18969 .71239 .17708 Mtetra
.656 .752 .92 r
.71239 .17708 .72122 .18969 .74038 .18289 .73164 .17015 Mtetra
.654 .749 .92 r
.05456 .39885 .06606 .40896 .08118 .40356 .06972 .39345 Mtetra
.655 .751 .92 r
.06972 .39345 .08118 .40356 .09639 .39807 .08498 .38794 Mtetra
.657 .752 .92 r
.08498 .38794 .09639 .39807 .11171 .3925 .10034 .38235 Mtetra
.658 .754 .921 r
.10034 .38235 .11171 .3925 .12711 .38695 .1158 .37669 Mtetra
.657 .752 .92 r
.1158 .37669 .12711 .38695 .14259 .38147 .13135 .37104 Mtetra
.654 .749 .92 r
.13135 .37104 .14259 .38147 .15816 .37595 .14698 .36545 Mtetra
.14698 .36545 .15816 .37595 .17384 .37033 .1627 .35983 Mtetra
.655 .751 .92 r
.1627 .35983 .17384 .37033 .18962 .36463 .17853 .35413 Mtetra
.656 .752 .921 r
.17853 .35413 .18962 .36463 .2055 .35884 .19446 .34836 Mtetra
.658 .755 .921 r
.19446 .34836 .2055 .35884 .22148 .35304 .2105 .34249 Mtetra
.658 .754 .921 r
.2105 .34249 .22148 .35304 .23754 .34733 .22663 .33658 Mtetra
.657 .751 .92 r
.22663 .33658 .23754 .34733 .25371 .34159 .24286 .33067 Mtetra
.655 .749 .919 r
.24286 .33067 .25371 .34159 .26997 .33582 .25919 .32481 Mtetra
.654 .748 .919 r
.25919 .32481 .26997 .33582 .28634 .32998 .27561 .31891 Mtetra
.655 .748 .919 r
.27561 .31891 .28634 .32998 .30281 .32409 .29214 .31298 Mtetra
.655 .749 .919 r
.29214 .31298 .30281 .32409 .31939 .31815 .30878 .307 Mtetra
.655 .75 .919 r
.30878 .307 .31939 .31815 .33607 .31216 .32553 .30096 Mtetra
.655 .75 .92 r
.32553 .30096 .33607 .31216 .35286 .30613 .34238 .29488 Mtetra
.656 .751 .92 r
.34238 .29488 .35286 .30613 .36975 .30006 .35934 .28876 Mtetra
.35934 .28876 .36975 .30006 .38675 .29396 .3764 .28258 Mtetra
.3764 .28258 .38675 .29396 .40386 .28783 .39358 .27637 Mtetra
.39358 .27637 .40386 .28783 .42108 .28166 .41087 .2701 Mtetra
.656 .751 .919 r
.41087 .2701 .42108 .28166 .43841 .27545 .42827 .26379 Mtetra
.657 .75 .919 r
.42827 .26379 .43841 .27545 .45585 .26918 .44579 .25742 Mtetra
.657 .75 .918 r
.44579 .25742 .45585 .26918 .47341 .26286 .46341 .251 Mtetra
.657 .749 .918 r
.46341 .251 .47341 .26286 .49108 .25648 .48115 .24453 Mtetra
.48115 .24453 .49108 .25648 .50886 .25004 .49901 .23803 Mtetra
.655 .749 .919 r
.49901 .23803 .50886 .25004 .52676 .24355 .51699 .23157 Mtetra
.654 .75 .921 r
.51699 .23157 .52676 .24355 .54477 .23703 .53508 .22511 Mtetra
.654 .753 .923 r
.53508 .22511 .54477 .23703 .56291 .23059 .55329 .2186 Mtetra
.656 .754 .922 r
.55329 .2186 .56291 .23059 .58116 .22414 .57163 .21198 Mtetra
.656 .753 .921 r
.57163 .21198 .58116 .22414 .59954 .21759 .59008 .20528 Mtetra
.658 .752 .919 r
.59008 .20528 .59954 .21759 .61803 .21094 .60866 .19849 Mtetra
.657 .75 .919 r
.60866 .19849 .61803 .21094 .63665 .20419 .62736 .19165 Mtetra
.655 .749 .919 r
.62736 .19165 .63665 .20419 .65539 .19738 .64619 .18488 Mtetra
.654 .751 .921 r
.64619 .18488 .65539 .19738 .67426 .19064 .66515 .1781 Mtetra
.655 .753 .922 r
.66515 .1781 .67426 .19064 .69326 .18391 .68423 .17124 Mtetra
.656 .752 .921 r
.68423 .17124 .69326 .18391 .71239 .17708 .70345 .16428 Mtetra
.658 .752 .92 r
.70345 .16428 .71239 .17708 .73164 .17015 .72279 .1572 Mtetra
.655 .75 .92 r
.04293 .38867 .05456 .39885 .06972 .39345 .05815 .38316 Mtetra
.654 .749 .92 r
.05815 .38316 .06972 .39345 .08498 .38794 .07345 .37765 Mtetra
.656 .751 .92 r
.07345 .37765 .08498 .38794 .10034 .38235 .08886 .37205 Mtetra
.657 .752 .92 r
.08886 .37205 .10034 .38235 .1158 .37669 .10436 .36637 Mtetra
.658 .754 .921 r
.10436 .36637 .1158 .37669 .13135 .37104 .11996 .36061 Mtetra
.657 .753 .92 r
.11996 .36061 .13135 .37104 .14698 .36545 .13566 .35484 Mtetra
.654 .749 .92 r
.13566 .35484 .14698 .36545 .1627 .35983 .15144 .34914 Mtetra
.15144 .34914 .1627 .35983 .17853 .35413 .16732 .34342 Mtetra
.655 .75 .92 r
.16732 .34342 .17853 .35413 .19446 .34836 .1833 .33764 Mtetra
.656 .751 .92 r
.1833 .33764 .19446 .34836 .2105 .34249 .19939 .33178 Mtetra
.656 .753 .921 r
.19939 .33178 .2105 .34249 .22663 .33658 .21557 .32586 Mtetra
.658 .755 .922 r
.21557 .32586 .22663 .33658 .24286 .33067 .23187 .31986 Mtetra
.657 .754 .921 r
.23187 .31986 .24286 .33067 .25919 .32481 .24826 .31382 Mtetra
.657 .752 .92 r
.24826 .31382 .25919 .32481 .27561 .31891 .26476 .30776 Mtetra
.656 .75 .919 r
.26476 .30776 .27561 .31891 .29214 .31298 .28136 .30171 Mtetra
.655 .749 .919 r
.28136 .30171 .29214 .31298 .30878 .307 .29806 .29564 Mtetra
.655 .748 .918 r
.29806 .29564 .30878 .307 .32553 .30096 .31487 .28954 Mtetra
.31487 .28954 .32553 .30096 .34238 .29488 .33178 .28339 Mtetra
.33178 .28339 .34238 .29488 .35934 .28876 .34881 .27719 Mtetra
.656 .749 .918 r
.34881 .27719 .35934 .28876 .3764 .28258 .36594 .27094 Mtetra
.36594 .27094 .3764 .28258 .39358 .27637 .38319 .26465 Mtetra
.38319 .26465 .39358 .27637 .41087 .2701 .40054 .25831 Mtetra
.40054 .25831 .41087 .2701 .42827 .26379 .41802 .25192 Mtetra
.41802 .25192 .42827 .26379 .44579 .25742 .4356 .24548 Mtetra
.4356 .24548 .44579 .25742 .46341 .251 .4533 .23904 Mtetra
.655 .749 .919 r
.4533 .23904 .46341 .251 .48115 .24453 .47111 .23259 Mtetra
.654 .751 .921 r
.47111 .23259 .48115 .24453 .49901 .23803 .48904 .22612 Mtetra
.654 .753 .922 r
.48904 .22612 .49901 .23803 .51699 .23157 .5071 .21961 Mtetra
.655 .754 .923 r
.5071 .21961 .51699 .23157 .53508 .22511 .52527 .213 Mtetra
.656 .753 .922 r
.52527 .213 .53508 .22511 .55329 .2186 .54356 .20633 Mtetra
.657 .752 .92 r
.54356 .20633 .55329 .2186 .57163 .21198 .56197 .19958 Mtetra
.658 .751 .919 r
.56197 .19958 .57163 .21198 .59008 .20528 .58051 .19275 Mtetra
.657 .75 .918 r
.58051 .19275 .59008 .20528 .60866 .19849 .59917 .18588 Mtetra
.655 .749 .919 r
.59917 .18588 .60866 .19849 .62736 .19165 .61796 .17909 Mtetra
.654 .752 .921 r
.61796 .17909 .62736 .19165 .64619 .18488 .63688 .17227 Mtetra
.655 .753 .922 r
.63688 .17227 .64619 .18488 .66515 .1781 .65592 .16536 Mtetra
.656 .752 .921 r
.65592 .16536 .66515 .1781 .68423 .17124 .67509 .15836 Mtetra
.658 .752 .92 r
.67509 .15836 .68423 .17124 .70345 .16428 .69439 .15125 Mtetra
.657 .75 .919 r
.69439 .15125 .70345 .16428 .72279 .1572 .71383 .14412 Mtetra
.657 .753 .92 r
.03116 .37844 .04293 .38867 .05815 .38316 .04644 .37279 Mtetra
.655 .75 .92 r
.04644 .37279 .05815 .38316 .07345 .37765 .0618 .36719 Mtetra
.654 .749 .92 r
.0618 .36719 .07345 .37765 .08886 .37205 .07724 .36158 Mtetra
.655 .751 .92 r
.07724 .36158 .08886 .37205 .10436 .36637 .09279 .35588 Mtetra
.656 .752 .92 r
.09279 .35588 .10436 .36637 .11996 .36061 .10845 .35011 Mtetra
.658 .754 .921 r
.10845 .35011 .11996 .36061 .13566 .35484 .1242 .34426 Mtetra
.657 .753 .921 r
.1242 .34426 .13566 .35484 .15144 .34914 .14005 .33838 Mtetra
.655 .75 .92 r
.14005 .33838 .15144 .34914 .16732 .34342 .15599 .33253 Mtetra
.654 .749 .919 r
.15599 .33253 .16732 .34342 .1833 .33764 .17203 .3267 Mtetra
.654 .749 .92 r
.17203 .3267 .1833 .33764 .19939 .33178 .18816 .32083 Mtetra
.655 .751 .92 r
.18816 .32083 .19939 .33178 .21557 .32586 .2044 .31489 Mtetra
.656 .752 .921 r
.2044 .31489 .21557 .32586 .23187 .31986 .22075 .30889 Mtetra
.656 .753 .921 r
.22075 .30889 .23187 .31986 .24826 .31382 .2372 .30283 Mtetra
.657 .755 .922 r
.2372 .30283 .24826 .31382 .26476 .30776 .25376 .29672 Mtetra
.25376 .29672 .26476 .30776 .28136 .30171 .27042 .29055 Mtetra
.657 .754 .922 r
.27042 .29055 .28136 .30171 .29806 .29564 .28719 .28435 Mtetra
.656 .753 .921 r
.28719 .28435 .29806 .29564 .31487 .28954 .30407 .27813 Mtetra
.656 .752 .92 r
.30407 .27813 .31487 .28954 .33178 .28339 .32105 .27187 Mtetra
.656 .751 .92 r
.32105 .27187 .33178 .28339 .34881 .27719 .33814 .26559 Mtetra
.33814 .26559 .34881 .27719 .36594 .27094 .35535 .25926 Mtetra
.35535 .25926 .36594 .27094 .38319 .26465 .37266 .25291 Mtetra
.655 .751 .92 r
.37266 .25291 .38319 .26465 .40054 .25831 .39009 .24652 Mtetra
.655 .751 .921 r
.39009 .24652 .40054 .25831 .41802 .25192 .40763 .2401 Mtetra
.655 .752 .921 r
.40763 .2401 .41802 .25192 .4356 .24548 .42528 .23365 Mtetra
.655 .753 .922 r
.42528 .23365 .4356 .24548 .4533 .23904 .44306 .22717 Mtetra
.655 .754 .923 r
.44306 .22717 .4533 .23904 .47111 .23259 .46095 .22063 Mtetra
.656 .754 .922 r
.46095 .22063 .47111 .23259 .48904 .22612 .47895 .21403 Mtetra
.656 .753 .922 r
.47895 .21403 .48904 .22612 .5071 .21961 .49708 .20736 Mtetra
.656 .752 .92 r
.49708 .20736 .5071 .21961 .52527 .213 .51533 .20063 Mtetra
.657 .751 .919 r
.51533 .20063 .52527 .213 .54356 .20633 .53371 .19382 Mtetra
.657 .75 .919 r
.53371 .19382 .54356 .20633 .56197 .19958 .5522 .18696 Mtetra
.656 .749 .919 r
.5522 .18696 .56197 .19958 .58051 .19275 .57082 .18011 Mtetra
.654 .75 .92 r
.57082 .18011 .58051 .19275 .59917 .18588 .58956 .17328 Mtetra
.654 .752 .922 r
.58956 .17328 .59917 .18588 .61796 .17909 .60844 .16641 Mtetra
.655 .753 .922 r
.60844 .16641 .61796 .17909 .63688 .17227 .62744 .15945 Mtetra
.656 .752 .921 r
.62744 .15945 .63688 .17227 .65592 .16536 .64657 .15241 Mtetra
.657 .752 .92 r
.64657 .15241 .65592 .16536 .67509 .15836 .66583 .14526 Mtetra
.657 .75 .919 r
.66583 .14526 .67509 .15836 .69439 .15125 .68522 .13809 Mtetra
.655 .75 .92 r
.68522 .13809 .69439 .15125 .71383 .14412 .70475 .13096 Mtetra
.657 .753 .92 r
.01926 .36811 .03116 .37844 .04644 .37279 .03459 .36238 Mtetra
.03459 .36238 .04644 .37279 .0618 .36719 .05001 .35663 Mtetra
.655 .75 .92 r
.05001 .35663 .0618 .36719 .07724 .36158 .06551 .35092 Mtetra
.654 .749 .92 r
.06551 .35092 .07724 .36158 .09279 .35588 .0811 .34521 Mtetra
.655 .751 .92 r
.0811 .34521 .09279 .35588 .10845 .35011 .0968 .33942 Mtetra
.656 .752 .92 r
.0968 .33942 .10845 .35011 .1242 .34426 .11261 .33356 Mtetra
.657 .753 .921 r
.11261 .33356 .1242 .34426 .14005 .33838 .12851 .32763 Mtetra
.657 .754 .921 r
.12851 .32763 .14005 .33838 .15599 .33253 .14452 .32164 Mtetra
.657 .752 .92 r
.14452 .32164 .15599 .33253 .17203 .3267 .16062 .31564 Mtetra
.655 .749 .919 r
.16062 .31564 .17203 .3267 .18816 .32083 .17682 .30967 Mtetra
.654 .749 .919 r
.17682 .30967 .18816 .32083 .2044 .31489 .19311 .30369 Mtetra
.654 .749 .92 r
.19311 .30369 .2044 .31489 .22075 .30889 .20951 .29766 Mtetra
.655 .75 .92 r
.20951 .29766 .22075 .30889 .2372 .30283 .22602 .29157 Mtetra
.655 .751 .92 r
.22602 .29157 .2372 .30283 .25376 .29672 .24264 .28543 Mtetra
.656 .752 .921 r
.24264 .28543 .25376 .29672 .27042 .29055 .25936 .27924 Mtetra
.656 .753 .922 r
.25936 .27924 .27042 .29055 .28719 .28435 .27619 .273 Mtetra
.656 .754 .922 r
.27619 .273 .28719 .28435 .30407 .27813 .29313 .26672 Mtetra
.29313 .26672 .30407 .27813 .32105 .27187 .31018 .2604 Mtetra
.656 .755 .922 r
.31018 .2604 .32105 .27187 .33814 .26559 .32734 .25405 Mtetra
.656 .755 .923 r
.32734 .25405 .33814 .26559 .35535 .25926 .34461 .24765 Mtetra
.34461 .24765 .35535 .25926 .37266 .25291 .362 .24121 Mtetra
.656 .754 .923 r
.362 .24121 .37266 .25291 .39009 .24652 .3795 .23474 Mtetra
.656 .754 .922 r
.3795 .23474 .39009 .24652 .40763 .2401 .39711 .22822 Mtetra
.39711 .22822 .40763 .2401 .42528 .23365 .41484 .22166 Mtetra
.656 .753 .922 r
.41484 .22166 .42528 .23365 .44306 .22717 .43269 .21504 Mtetra
.656 .752 .921 r
.43269 .21504 .44306 .22717 .46095 .22063 .45066 .20838 Mtetra
.656 .752 .92 r
.45066 .20838 .46095 .22063 .47895 .21403 .46874 .20165 Mtetra
.657 .751 .919 r
.46874 .20165 .47895 .21403 .49708 .20736 .48695 .19486 Mtetra
.657 .75 .919 r
.48695 .19486 .49708 .20736 .51533 .20063 .50528 .18802 Mtetra
.657 .749 .918 r
.50528 .18802 .51533 .20063 .53371 .19382 .52373 .18115 Mtetra
.655 .749 .919 r
.52373 .18115 .53371 .19382 .5522 .18696 .54231 .17431 Mtetra
.654 .751 .921 r
.54231 .17431 .5522 .18696 .57082 .18011 .56101 .16745 Mtetra
.655 .753 .922 r
.56101 .16745 .57082 .18011 .58956 .17328 .57984 .16052 Mtetra
.656 .753 .921 r
.57984 .16052 .58956 .17328 .60844 .16641 .5988 .15351 Mtetra
.656 .752 .92 r
.5988 .15351 .60844 .16641 .62744 .15945 .61789 .14641 Mtetra
.657 .752 .919 r
.61789 .14641 .62744 .15945 .64657 .15241 .6371 .13922 Mtetra
.657 .75 .919 r
.6371 .13922 .64657 .15241 .66583 .14526 .65645 .13202 Mtetra
.655 .75 .92 r
.65645 .13202 .66583 .14526 .68522 .13809 .67594 .12485 Mtetra
.655 .752 .921 r
.67594 .12485 .68522 .13809 .70475 .13096 .69557 .11763 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
[(-2)] .12586 .2075 1 .99877 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.56863 .04703 m
.57247 .05235 L
s
[(2)] .56094 .0364 .72324 1 Mshowa
.125 Mabswid
.18558 .19702 m
.18832 .19985 L
s
.23703 .17687 m
.23971 .17975 L
s
.28951 .15632 m
.29214 .15925 L
s
.39772 .11395 m
.40023 .11699 L
s
.4535 .09211 m
.45595 .0952 L
s
.51046 .06981 m
.51284 .07294 L
s
.08568 .23614 m
.08851 .23887 L
s
.62804 .02377 m
.63027 .02701 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 233.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00o?ooool2o`0006[ooooo003iooooo`?o000000?oooooo`000?ooool0
JOooool00?Oooooo0_l00004ooooo`;o0000JOooool00?Cooooo0ol00006ooooo`03o`000?oooooo
000006Sooooo003;ooooo`Go00008_ooool2o`0000Wooooo00?o0000ooooool00000J?ooool00<_o
oooo00GoV9RHob4Q8Oo^k^koooooodA4A00Oooooo`?o00002oooool01?l0003oooooooooool0001W
ooooo`00c?ooool00onHV9So8B4Qonk^kP0Mooooo`?o00003_ooool01Ol0003ooooooooooooooooo
000006Kooooo003=ooooo`03oiRHV?lQ8B7ok^k^01[ooooo0_l0000Aooooo`05o`000?oooooooooo
ooooool00000I_ooool00<kooooo00?oMgMgofIVI_ooool05_ooool3o`0001?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1Sooooo`00coooool00ol0003oooooooooo`0Cooooo`;o
00000_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0H_ooool00<_ooooo00Go0000okZj^_ooooooV9RHoa0@400Booooo`?o00006Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo06;ooooo003;ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`04?ooool2o`0001cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Qooooo`00
gOooool3o`0001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Qooooo`00fooo
ool2o`00027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Pooooo`00f?ooool3
o`0002?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Oooooo`00eOooool3o`00
02Kooooo00?o0000ooooooooool01?ooool2o`00067ooooo003Cooooo`;o0000:Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo05kooooo003@ooooo`?o000000?oooooo`000?ooool0
:?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05gooooo003>ooooo`;o00001Ooo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0GOoo
ool00<_ooooo0ol0000`ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0G?ooool0
0<Wooooo0_l0000cooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Foooool00<Ko
oooo0ol0000eooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Foooool00<Cooooo
0_l0000hooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0F_ooool00<7ooooo0ol0
000jooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03_ooool5o`0004Kooooo002n
ooooo`?o0000?Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00kooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A016ooooo`00_?ooool2o`0000?ooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo1_l00003ooooo`03oiRHV?lQ8B7o
k^k^04Oooooo002iooooo`?o0000@oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00kooooo00?oV9RHob4Q8Oo^k^h0A_ooool00;Oooooo0_l00016ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03oooool00omgMgOoIVIVooooo`15ooooo`00]?ooool3o`0004Sooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Cooooo
002booooo`;o0000Boooool00ol0003oooooooooo`0=ooooo`;o00003?ooool01Ol0003o^[Zjoooo
oonHV9So410@04Kooooo002_ooooo`?o0000COooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c016ooooo`00[Oooool2o`00053ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`1Dooooo`00Z_ooool4o`00057ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1Dooooo`00Z?ooool2o`0000Cooooo00?o0000oooo
ooooool0C_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05?ooooo001nooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h08_ooool3o`0005Oooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`1Booooo`00O_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01oooooo0ol0001Joooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool0D_ooool007kooooo00Go410@oooooooo
oooooooooa0@400Mooooo`;o0000GOooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
057ooooo001nooooo`05o`000?ooooooooooooooool000006_ooool3o`0005oooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`1@ooooo`00O_ooool01Ol0003ooooooooooooooooo0000
01Sooooo0_l0001Rooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0D?ooool007ko
oooo00Go410@oooooooooooooooooa0@400Eooooo`?o0000I?ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo04oooooo001nooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool2o`00
00?ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
04kooooo001nooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04?ooool3o`0006Sooooo00?oYl3[o`00
0?ooool05_ooool00ol0003oooooooooo`1>ooooo`00TOooool2o`0006Sooooo1?nW`>/00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo04gooooo002>ooooo`?o0000J?ooool7ojO0j`03o`00
0?oooooooooo01Cooooo0ol0001>ooooo`00Roooool3o`0006Wooooo0_nW_n/7ojO0j`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool0C?ooool008Wooooo0_l0001Yooooo`KoYko[1_nW`>/0
0ol0003oYl3[ooooo`0Gooooo`03o`000?oooooooooo04_ooooo0026ooooo`?o0000J?ooool00onX
_n_oYko[ojNoj`07ojNoj`GoYl3[00?o0000ojNojoooool06?ooool00ol0003oooooooooo`1:oooo
o`00Q?ooool2o`0000;ooooo00?o0000ooooooooool0Hoooool5ojRoj`WoYko[0_nW`>/2ojNoj`03
o`000?nW_n_oYko[01Sooooo00?o0000ooooooooool0B_ooool0087ooooo0ol00005ooooo`03o`00
0?oooooooooo063ooooo2?nX_n/7ojNoj`03ojRojonW_n_oYko[00;oYko[00Co0000ojNojonW_n_o
Yko[6?ooool00ol0003oooooooooo`19ooooo`00Ooooool2o`0006Wooooo00?oZ<3[ojRojonX_n/0
1onX_n/4ojNoj`GoZ;o[0onW_n/00ol0003oYko[ojNoj`02ojNojaSooooo00?o0000ooooooooool0
B?ooool007cooooo0ol0001Xooooo`GoZ<3[2OnX_n/00onW_n_oZ;o[ojRoj`06ojRoj`;oYko[00Go
0000ojNojonW_n_oYko[ojRoj`0Hooooo`03o`000?oooooooooo04Sooooo001jooooo`;o0000Iooo
ool2ojO0j`SoZ<3[1_nX_n/2ojS0j`WoZ;o[0_nW_n/00ol0003oYko[ojRoj`03ojRojaSooooo00?o
0000ooooooooool0Aoooool007Oooooo0ol0001Vooooo`KoYl3[2?nX`>/2ojRoj`KoZ<3[2OnX_n/0
0onW_n_o0000ojRoj`05ojRojaSooooo00?o0000ooooooooool0A_ooool007Cooooo0ol0001Voooo
o`[oYl3[1_nX`>/2ojO0j`SoZ<3[1_nX_n/2ojS0j`03ojRojol0003oZ;o[00GoZ;o[6?ooool00ol0
003oooooooooo`16ooooo`00L_ooool2o`0000;ooooo00?o0000ooooooooool0H_ooool=ojO0j`;o
Z<3[1_nW`>/8ojS0j`;oZ;o[1_nX`>/00ol0003oZ;o[ojRoj`05ojRojaSooooo00?o0000oooooooo
ool0AOooool006oooooo0ol0001Wooooo`koYl3[00?oYl3/ojO0jonW`>/01onW`>/6ojS0j`03ojO0
jonX`>_oZ<3[00KoZ<3[00?o0000ojRojonX_n/01?nX_n/00onX`>_oooooooooo`0Fooooo`03o`00
0?oooooooooo04Gooooo001]ooooo`;o0000Ioooool2ojO0k0coYl3[1OnW`>`9ojO0j`;oZ<3[1OnW
`>/7ojS0j`04o`000?nX`>_oZ;o[ojRoj`GoZ<3[5oooool2o`0004Kooooo001Zooooo`?o0000I_oo
ool6ojO0k0WoYl3[2?nW`>`7ojO0j`03ojO0k?nW`>_oYl3[00KoYl3[1_nX`>/00ol0003oYl3[ojS0
j`07ojS0jaSooooo00?o0000ooooooooool0@oooool006Sooooo0_l0001Vooooo`;oYl3[2?nW`>`6
ojO0j`[oYl3/1?nW`>/5ojO0k0SoYl3[0_nX`>/3ojO0j`03o`000?nW`>_oYl3[00SoZ<3[5oooool0
0ol0003oooooooooo`13ooooo`00IOooool3o`0006Gooooo1_nW`>/8ojO0k0;oYl3[3_nW`>`00onW
`>_oYl3/ojO0k006ojO0k0KoYl3[00?oYl3/ojO0jonW`>/00onW`>/01?l0003oYl3[ojO0jonW`>/6
ojS0j`03ojO0jooooooooooo01Kooooo00?o0000ooooooooool0@_ooool006?ooooo0_l0001Uoooo
o`03ojNojonW`>_oYl3[00OoYl3[1_nW`>`00onW_n_oYl3/ojO0k00=ojO0k003ojO0jonW`>coYl3/
00OoYl3/1?nW`>/4ojO0k0GoYl3[00Co0000ojO0jonW`>_oYl3[0_nX`>/5ojO0jaSooooo00?o0000
ooooooooool0@Oooool0063ooooo0ol000000ooooooo0000ooooo`1Rooooo`CoYko[2OnW`>/2ojO0
k0GoYko[2onW`>`5ojO0j`WoYl3/00?oYl3[ojO0k?nW`>`01OnW`>`4ojO0j`04o`000?nW`>_oYl3[
ojO0k0SoYl3[5oooool00ol0003oooooooooo`11ooooo`00=_ooool5o`0002?ooooo0_l0001Voooo
o`OoYko[1onW`>/9ojNoj`KoYl3/0_nW_n/8ojO0j`KoYl3/0_nW`>/8ojO0k0CoYl3[00?o0000ojO0
k?nW`>`00_nW`>`8ojO0jaOooooo00?o0000ooooooooool0@?ooool003Kooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00Pooooo`?o0000IOooool2ojRoj`SoYko[1?nW`>/=ojNoj`;oYl3/1_nW_n/8ojO0
j`;oYl3/1_nW`>/8ojO0k004ojO0jonW`>coYl3/o`0000GoYl3/1onW`>/Hooooo`03o`000?oooooo
oooo03oooooo000^ooooo`Ko00000oooool00onHV9So8B4Qonk^kP0Nooooo`?o0000IOooool6ojRo
j`SoYko[00?oYl3[ojNojonW_n/03?nW_n/00onX_n_oYko[ojNoj`07ojNoj`KoYl3[00?oYko[ojO0
jonW`>/01onW`>/6ojO0k005ojO0jonW`>coYl3/ojO0k?l000001OnW`>`8ojO0jaOooooo00?o0000
ooooooooool0?oooool003Sooooo00?oV9RHob4Q8Oo^k^h06oooool2o`0006Gooooo2_nX_n/6ojNo
j`;oZ;o[3?nW_n/4ojRoj`WoYko[0_nW`>/5ojNoj`WoYl3[0_nW`>`5ojO0j`;oYl3/00?o0000ojO0
k?nW`>`01?nW`>`8ojO0jaOooooo00?o0000ooooooooool0?_ooool003Wooooo00?oMgMgofIVI_oo
ool05oooool3o`0006Cooooo3_nX_n/2ojNoj`KoZ;o[2OnW_n/7ojRoj`OoYko[00?oZ;o[ojNojonW
_n/01_nW_n/6ojO0j`;oYko[2?nW`>/00onW`>co0000ojO0k005ojO0k0SoYl3[6?ooool00ol0003o
ooooooooo`0mooooo`00>_ooool00ol0003oooooooooo`0Dooooo`;o0000I?ooool00onX`>_oZ;o[
ojRoj`0=ojRoj`03ojS0jonX_n_oZ;o[00OoZ;o[1_nW_n/00onX`>_oZ;o[ojRoj`07ojRoj`CoYko[
1?nX_n/8ojNoj`;oYl3[1_nW_n/8ojO0j`03o`000?nW`>coYl3/00GoYl3/2?nW`>/Gooooo`03o`00
0?oooooooooo03gooooo000fooooo`05o`000?nj^[[ooooooiRHV?l@41004oooool3o`0000;ooooo
00?o0000ooooooooool0Goooool4ojS0j`_oZ;o[1OnX`>/9ojRoj`;oYko[1OnX`>/9ojRoj`03ojNo
jonX_n_oZ;o[00GoZ;o[1_nW_n/00onX`>_oYko[ojNoj`07ojNoj`KoYl3[00?oYko[o`000?nW`>`0
1onW`>`6ojO0j`03ojO0k?oooooooooo01Kooooo00?o0000ooooooooool0??ooool003Kooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c00Aooooo`;o0000IOooool7ojS0j`OoZ;o[00?oYl3[ojS0jonX`>/0
1_nX`>/6ojRoj`[oZ<3[1_nX_n/2ojS0j`SoZ;o[1?nW_n/4ojS0j`WoYko[0_nW`>/4ojNoj`03o`00
0?nW`>coYl3/00OoYl3/0_nW`>/5ojO0k1Kooooo0ol0000mooooo`00BOooool3o`0006Gooooo00?o
Yl3[ojS0jonX`>/01onX`>/4ojRoj`CoYl3[2?nX`>/2ojRoj`koZ<3[0_nX_n/6ojS0j`SoZ;o[00?o
Yko[ojS0jonX`>/01OnX`>/7ojNoj`03ojS0jonW_n_oYko[00CoYko[00?o0000ojNojonW`>`01OnW
`>`2ojNoj`SoYl3/5oooool00ol0003oooooooooo`0kooooo`00Aoooool2o`0006Gooooo1OnW`>/9
ojS0j`03ojRojonW`>_oYl3[00GoYl3[1_nX`>/00onW`>coZ<3[ojS0j`0=ojS0j`03ojO0jonX`>_o
Z<3[00OoZ<3[1_nX_n/9ojS0j`CoYko[1OnX`>/5ojNoj`03o`000?nW_n_oYko[00;oYl3/1_nW_n/8
ojO0k1Oooooo00?o0000ooooooooool0>_ooool004Cooooo0ol0001Tooooo`WoYl3[1_nX`>/2ojO0
k0SoYl3[1?nX`>/4ojO0k0_oZ<3[1OnW`>/9ojS0j`;oZ;o[3OnX`>/00onW_n_oZ<3[ojS0j`06ojS0
j`CoYko[00?o0000ojNojonX`>/02OnW_n/6ojO0k003ojNojooooooooooo01Kooooo00?o0000oooo
ooooool0>Oooool0047ooooo0ol0001Tooooo`goYl3[0_nX`>/6ojO0k0SoYl3[00?oZ<3[ojO0k?nW
`>`01OnW`>`7ojS0j`03ojO1k?nW`>_oYl3[00KoYl3[1_nX`>/2ojO0jaWoZ<3[0_nW_n/00onX`>_o
0000ojS0j`02ojS0j`WoYko[0_nW`>`5ojNojaOooooo00?o0000ooooooooool0>Oooool003oooooo
0ol0001Sooooo`03ojO0k?nW`>_oYl3[00coYl3[0_nW`N`8ojO0k0KoYl3[0_nW`N`8ojO0k0CoZ<3[
1?nW`N`8ojO0j`;oZ<3[1_nW`>/KojS0j`03o`000?nX`>_oZ<3[00;oZ<3[1_nW_n/2ojRoj`SoYko[
5oooool00ol0003oooooooooo`0hooooo`00??ooool3o`0000?ooooo00?o0000ooooooooool0G_oo
ool4ojO0k0[oYl3[1_nW`N`8ojO0k0;oYl3[1_nW`N`8ojO0k003ojS0jonW`NcoYl7/00GoYl7/1_nW
`>/2ojO1k0SoYl3[1_nX`>/00onW`>_oZ<3[ojS0j`0AojS0j`03o`000?nX`>_oZ<3[00?oZ<3[0_nW
_n/6ojRoj`SoYko[5_ooool00ol0003oooooooooo`07ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
;?ooool003[ooooo0_l0001Uooooo`OoYl3/1_nW`>/:ojO1k0OoYl3/2OnW`N`7ojO0k0WoYl7/0_nW
`>/6ojO1k0SoYl3[0_nX`>/5ojO0ja;oZ<3[00?o0000ojS0jonX`>/00onX`>/9ojRoj`OoYko[5ooo
ool00ol0003oooooooooo`06ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0;?ooool003Oooooo0ol0
001Uooooo`03ojO1k?nW`>coYl3/00OoYl3/0_nW`>/>ojO1k0OoYl3/2OnW`N`7ojO0k0OoYl7/00?o
Yl3/ojO1k?nW`N`01onW`N`6ojO0j`03ojO0k?nW`>_oYl3[00KoYl3[1_nX`>/2ojO0j`[oZ<3[00?o
0000ojS0jonX`>/00onX`>/9ojRoj`OoYko[5oooool00ol0003oooooooooo`05ooooo`05oa0@4?oo
ooooooooooooool@4100;?ooool003Gooooo0_l0001Uooooo`GoYl7/2OnW`>`>ojO1k003ojO0jonW
`>coYl3/00KoYl3/1_nW`N`2ojNoj`SoYl3/1?nW`N`4ojO0k0WoYl7/0_nW`>/5ojO0k0SoYl3[0_nX
`>/6ojO0j`WoZ<3[00?o0000ojS0jonX`>/01?nX`>/6ojRoj`;oZ<3[2?nW_n/Fooooo`03o`000?oo
oooooooo00Gooooo00Go0000ooooooooooooooooo`00000/ooooo`00<_ooool3o`0006Cooooo2OnW
`N`9ojO0k0[oYl7/1OnW`>/8ojO0k0;oYl7/1_nW_n/8ojO0k003ojO1k?nW`>coYl3/00GoYl3/1_nW
`N`2ojNoj`SoYl3/1_nW`>/00onW`>coYl3[ojO0j`07ojO0j`KoZ<3[00?oYl3[ojS0jol000001onX
`>/2ojRoj`KoZ<3[2?nW_n/Fooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooooooo
o`00000/ooooo`00<?ooool2o`0006Cooooo3OnW`N`9ojO0k0KoYl7/00?oYko[ojO0jonW`>/01_nW
`>/6ojO0k0[oYko[1_nW`>`00onW_n_oYl3/ojO0k007ojO0k0;oYl7/1_nW_n/8ojO0k0;oYl3[1OnW
`>`9ojO0j`;oZ<3[1OnW`>/00ol0003oZ<3[ojS0j`0=ojS0j`KoYko[0_nX`>/Gooooo`03o`000?oo
oooooooo00?ooooo00Go410@oooooooooooooooooa0@400/ooooo`00;Oooool3o`000003ooooool0
003ooooo063ooooo3onW`N`2ojO0j`WoYl3/0_nW`N`5ojNoj`SoYl3[0_nW`>`>ojNoj`;oYl3/1OnW
_n/7ojO0k0[oYko[1_nW`>`00onW_n_oYl3/ojO0k006ojO0k0KoYl3[0_nW`>`7ojO0j`03o`000?nX
`>_oZ<3[00koZ<3[0_nW_n/6ojS0jaKooooo0_l00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
;?ooool002[ooooo0ol0001Sooooo`ooYl7/1_nW`>/7ojO0k0WoYko[1_nW`>/2ojRoj`koYko[00?o
Z;o[ojNojonW_n/01_nW_n/4ojO0k0goYko[0_nW`>`5ojNoj`SoYl3/0_nW`>/6ojO0k0KoYl3[00?o
0000ojO0jonX`>/05onX`>/Cooooo`;o000000?oooooo`000?ooool00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^02cooooo000Xooooo`;o0000Hoooool?ojO1k0[oYl3[1?nW`>`<ojNoj`;oYl3[1_nX
_n/:ojNoj`GoZ;o[2?nW_n/00onW`>coYko[ojNoj`0EojNoj`KoYl3/00?oYko[ojO0k?nW`>`01onW
`>`5ojO0j`03o`000?nW`>coZ<3[01SoZ<3[5_ooool00ol0003oooooooooo`0booooo`009Oooool3
o`0006;ooooo3onW`N`>ojO0j`03ojO0k?nW_n_oYko[00_oYko[2_nX_n/6ojNoj`WoZ;o[1_nW_n/0
0onX_n_oYko[ojNoj`0GojNoj`;oYl3/1OnW_n/9ojO0k0;oYl3[00?oYl3/o`000?l000000_nW`>`H
ojS0jaKooooo00?o0000ooooooooool0<_ooool002?ooooo0_l0001Rooooo`ooYl7/4?nW`>/=ojNo
j`goZ;o[0_nW_n/=ojRoj`;oYko[1OnX_n/8ojNoj`03ojRojonW_n_oYko[01GoYko[1_nW`>`2ojNo
j`?o000000?oYl3/o`000?nW`>`00_nW`>`6ojS0j`03ojO0jonX`>_oZ<3[00ooZ<3[5_ooool00ol0
003oooooooooo`0aooooo`008?ooool3o`0006;ooooo3_nW`N`@ojO0j`koYko[3_nX_n/00onX`>_o
Z;o[ojRoj`0<ojRoj`03ojS0jonX_n_oZ;o[00KoZ;o[1?nW_n/5ojRojaOoYko[0_nW`>`2ojNoj`?o
000000?oYko[ojO0k?nW`>`00_nW`>`01?l0003oYl3/ojO0k?nW`>`2ojS0j`GoYl3[1onX`>/00onW
`>_oZ<3[ojS0j`06ojS0jaOooooo00?o0000ooooooooool0<?ooool001oooooo0_l0001Rooooo`go
Yl7/4?nW`>/?ojNoj`goZ;o[1OnX`>/:ojRoj`GoZ<3[2?nX_n/00onW_n_oZ;o[ojRoj`06ojRoj`Ko
Yko[00?oZ<3[ojNojonW_n/03_nW_n/3o`0000CoYko[1OnW`>`00ol0003oYl3/ojO0k008ojO0j`Co
Z<3[1?nW`>/8ojS0jaKooooo00?o0000ooooooooool0<?ooool001oooooo00?o0000ooooool00000
Goooool<ojO1k13oYl3[3onW_n/=ojRoj`WoZ<3[1_nX_n/9ojS0j`KoZ;o[0_nX`>/8ojRoj`CoYko[
1?nX`>/<ojNoj`?o00002?nW_n/5ojO0k003o`000?nW`>coYl3/00SoYl3[00?oZ<3[ojO0jonW`>/0
1OnW`>/7ojS0jaOooooo00?o0000ooooooooool0;oooool000cooooo1Ol00003ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01_ooool01?l0003oooooooooool0001Kooooo`coYl7/4?nW`>/?ojNoj`ko
Z;o[3?nX`>/2ojRoj`goZ<3[0_nX_n/6ojS0j`SoZ;o[00?oYko[ojS0jonX`>/01OnX`>/6ojNoj`03
ojS0jonW_n_o000000;o00002onW_n/5ojO0k004o`000?nW`>coYl3/ojO0k0KoYl3[00?oYl3/ojO0
jonW`>/01onW`>/7ojS0jaOooooo00?o0000ooooooooool0;_ooool000cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool2o`0000;ooooo00?o0000
ooooooooool0EOooool<ojO1k13oYl3[3onW_n/?ojRoj`goZ<3[00?oYl7/ojS0jonX`>/03?nX`>/0
0onX`NcoZ<3[ojS0j`07ojS0j`KoZ;o[2_nX`>/2ojNoj`;oZ<3[0ol0000?ojNoj`GoYl3/00Co0000
ojO0k?nW`>coYl3/0_nW`>/5ojO0k0SoYl3[2?nX`>/Fooooo`03o`000?oooooooooo02kooooo0004
ooooo`Ko00000oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41001Ooo
ool2o`0000Cooooo00?o0000ooooooooool0DOooool=ojO1k0ooYl3[3onW_n/2ojO0j`koZ;o[0_nW
`>/:ojS0j`GoYl7/2_nX`>/5ojS1k0WoZ<3[0_nX_n/>ojS0j`?o00001?nX`>/6ojNoj`03ojS0jonW
_n_oYko[00KoYko[1OnW`>`00ol0003oYko[ojNoj`08ojO0k0SoYl3[2?nX`>/Fooooo`03o`000?oo
oooooooo02gooooo000>ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00
0005ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0COooool>ojO1k0koYl3[3onW
_n/6ojO0j`[oZ;o[1_nW`>/6ojS0j`WoYl7/1_nX`>/00onW`NcoZ<7/ojS1k006ojS1k0KoZ<3[0_nW
`N`>ojS0j`;o00002?nX`>/2ojNoj`GoZ<3[2?nW_n/2ojO0k0;oYko[00Co0000ojNojonW_n_oYko[
2?nW`>`8ojO0j`OoZ<3[5oooool00ol0003oooooooooo`0/ooooo`003oooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo04Wooooo3onW`N`=ojO0j`ooYko[2_nW`>/6ojRoj`03ojO1k?nW`>_oYl3[00OoYl3[
0_nX`>/=ojO1k0;oZ<3[1OnW`N`8ojS1k0;oZ<3[1_nW`N`:ojS0j`?o00004_nX`>/6ojNoj`03ojS0
jonW_n_oYko[00?oYko[00?o0000ojNojonW_n/01_nW`>`3ojK0k0SoYl3[1onX`>/Eooooo`;o0000
;_ooool0013ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00?ooooo
0_l00007ooooo`03o`000?oooooooooo04Kooooo00?oYl3/ojO1k?nW`N`03?nW`N`<ojO0j`ooYko[
3_nW`>/2ojRoj`GoYl7/1onW`>/?ojO1k003ojO0k?nW`NcoYl7/00KoYl7/1_nX`N`:ojO1k0KoZ<3[
0ol0000FojS0j`;oYko[1OnX`>/5ojNoj`03o`000?nW_n_oYko[00;oYl3/1onV`>`6ojO0j`03ojO0
k?nX`>_oZ<3[00KoZ<3[5_ooool00ol0003oooooooooo`0[ooooo`003?ooool01Ol0003o^[Zjoooo
oonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0@_ooool5ojO0k0[oYl7/3?nW`>/?ojNoja3oYl3[2OnW`N`4ojO0j`ko
Yl7/1OnW`>`8ojO1k0;oZ<7/3_nW`N`2ojS0j`?o00000onW`N`6ojS0j`03ojO1k?nX`>_oZ<3[01Go
Z<3[1OnW_n/00ol0003oYko[ojNoj`09ojK0k0;oYl3[1OnW`>`8ojS0jaGooooo00?o0000oooooooo
ool0:oooool000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03kooooo0_nW`>/7ojO0
k0KoYl7/3OnW`>/>ojNoja3oYl3[3OnW`N`00onW`>_oYl7/ojO1k00;ojO1k003ojNojonW`>coYl3/
00KoYl3/1_nW`N`2ojNoj`koYl7/0ol00007ojO1k0;oZ<3[1OnW`N`GojS0j`CoYko[00Co0000ojNo
jonW_n_oYko[1_nV`>`2ojNoj`SoYl3/1_nX`>/00onW`>_oooooooooo`0Dooooo`03o`000?oooooo
oooo02[ooooo000Nooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0>_ooool6ojO0
j`OoYl3/0_nW`N`>ojO0j`koYko[3onW`>/?ojO1k0;oYl3/2_nW`N`5ojNoj`SoYl3/0_nW`N`6ojNo
j`[oYl7/0ol00003ojK0k0KoYl7/00?oY/3/ojO1k?nW`N`01_nW`N`6ojS0j`03ojS1k?nX`>_oZ<3[
00goZ<3[1OnW_n/01?l0003oYko[ojNojonW_n/2ojK0k0KoYko[2?nW`>`2ojS0j`GoYl3[5_ooool0
0ol0003oooooooooo`0Yooooo`007Oooool3o`0000_ooooo00?o0000ooooooooool0=_ooool:ojO0
j`GoYl3/0_nX`N`=ojO0j`goYko[3onW`>/?ojO1k0KoYl3/1_nW`N`9ojNoj`KoYl3/2_nW_n/6ojO1
k0?o00001onV`>`2ojO1k0GoY/3/2?nW`N`2ojS0j`GoZ<7/3onX`>/5ojNoj`03o`000?nW_n_oZ<3[
00SoYko[1_nW`>`2ojK0k0OoYl3[5_ooool00ol0003oooooooooo`0Yooooo`007Oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo03;ooooo3_nW`>/00onW`>coZ<7/ojS1k004ojS1k0Wo
Yl3[3OnW_n/?ojO0j`ooYl7/0_nW`>/8ojO0k0;oYl7/3OnW_n/2ojO0k0koYko[0_nW`N`3o`0000?o
Yko[1_nV`>`00onW_n_oY/3/ojK0k006ojK0k0KoYl7/00?oY/3/ojS1k?nX`N`01_nX`N`?ojS0j`Co
Yko[00CoZ<3[o`000?nX`>_oZ<3[2?nW_n/2ojO0k0KoY/3/1onW`>/Fooooo`03o`000?oooooooooo
02Sooooo000Mooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0;oooool00onW_n_o
Yl3[ojO0j`0<ojO0j`WoZ<7/1_nW`>/<ojNoj`ooYl3[3onW`N`6ojO0j`KoYl3/0_nW_nX=ojNoj`;o
Z;oZ3_nW_n/3o`0000OoYko[0_nV`>`5ojNoj`SoY/3/0_nW`N`5ojK0k0SoZ<7/3onX`>/01OnW_n_o
Z<3[ojS0jonX`>_o000000?oZ<3[1onW_n/8ojK0k0OoYl3[5oooool00ol0003oooooooooo`0Woooo
o`007Oooool2o`0000oooooo00?o0000ooooooooool0:oooool5ojNoj`[oYl3[3OnX`N`2ojO0j`ko
Yko[3OnW`>/?ojO1k0;oYko[2?nW`>/2ojO0k0KoYkoZ2OnW_n/6ojRojP[oYko[00?oZ;oZo`000?l0
00000_nX_nX7ojNoj`03ojRoj_nW_n_oYko[00KoYko[1_nV`>`00onW_n_oY/3/ojK0k006ojK0k0Ko
Z<7/00?oYl3/ojS0jonX`>/04_nX`>/01?l0003oZ<3[ojS0jonX`>/7ojNoj`SoY/3/1onW`>/Foooo
o`03o`000?oooooooooo02Oooooo000Mooooo`03o`000?oooooooooo00oooooo0_l0000Xooooo`Wo
Yko[1_nW`>/?ojS1k1;oYko[2OnW`>/?ojO1k0KoYko[1_nW`>/:ojNojPKoYko[2OnX_nX6ojNoj`04
ojRoj_l0003o0000o`0000GoZ;oZ1?nW_n/4ojRojPSoYko[0_nV`>`5ojNoj`SoY/3/0_nX`N`5ojO0
k1CoZ<3[00?o0000ojS0jonX`>/02?nW_n/6ojK0k003ojJojonW`>_oYl3[00KoYl3[5_ooool00ol0
003oooooooooo`0Vooooo`007Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02;o
oooo3OnW_n/2ojO0j`ooZ<7/5_nW_n/5ojO0j`ooYl7/2_nW_n/3ojO0j`goYkoZ0_nW_n/=ojRojP;o
Yko[00CoZ;oZo`000?l0003o00002OnX_nX00onW_n_oZ;oZojRojP05ojRojPKoYko[00?oZ;oZojNo
jonW_n/01_nW_n/6ojK0k003ojJojonW`>coYl3/00KoYl3/1_nX`>/00onW`NcoZ<3[ojS0j`0;ojS0
j`03o`000?nX`>_oZ<3[00SoYko[0_nV`>`5ojJoj`SoYl3[5_ooool00ol0003oooooooooo`0Uoooo
o`007Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01kooooo3onW_n/2ojO0j`go
Z<7/6_nW_n/00onW`>_oYl7/ojO1k00=ojO1k0koYko[00?oYl3[ojNoj_nW_nX02onW_nX?ojRojP04
ojRojol0003o0000o`0001GoZ;oZ0_nW_n/5ojRojPSoYko[0_nV`>`5ojJoj`SoYl3/0_nX`>/5ojO1
k0coZ<3[00Co0000ojS0jonX`>_oZ<3[1_nW_n/00onX`>_oY[o[ojJoj`06ojJoj`OoYl3[5_ooool2
o`0002Kooooo000Looooo`?o00005?ooool00ol0003oooooooooo`0Jooooo`ooYko[1_nW`>/9ojS1
k1coYko[3onW`N`?ojNoj`coYkoZ3onX_nX01OnX_n_o0000o`000?l0003oZ;o[01ooZ;oZ1_nW_n/0
0onX_n_oY[o[ojJoj`06ojJoj`KoYl3/0_nV_n`7ojO1k0coZ<3[00Co0000ojS0jonX`>_oZ<3[0_nW
_n/5ojS0j`SoY[o[1onW`>/Dooooo`03o`000?oooooo000002Kooooo000Looooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool05oooool?ojNoj`WoYl3[1_nX`N`00onX`>_oYko[ojNoj`0H
ojNoj`ooYl7/3onW_n/<ojNojP03ojRojonX_n[oZ;oZ00coZ;oZ00CoZ<3[o`000?l0003o00001OnX
_n/6ojRojP03ojS0jonX_n[oZ;oZ01KoZ;oZ0_nW_n/5ojRoj`SoY[o[0_nW`>`6ojJok0OoYl7/3?nX
`>/00ol0003oZ<3[ojS0j`08ojS0j`KoY[o[00?oYko[ojO0jonW`>/01_nW`>/Fooooo`03o`000?oo
oooooooo02?ooooo000:ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKo
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Cooooo`ooYko[3OnW`>/2ojS1k0Go
Z<3[5_nW_n/?ojO1k003ojO0jonW_n_oYko[00coYko[3?nW_nX5ojRoj`[oZ;oZ00GoZ<3[o`000?l0
003o0000ojS0j`08ojRoj`;oZ;oZ1OnX`>/7ojRojP03ojS1jonX_n[oZ;oZ00coZ;oZ00?oZ<3ZojRo
jonX_n/01_nX_n/6ojJoj`;oYko[2?nV_n`3ojO1k0CoY/3/2onX`>/00ol0003oZ<3[ojS0j`09ojS0
j`;oY[o[1OnW_n/8ojO0jaGooooo00?o0000ooooooooool08oooool000cooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`0?ooooo`;oZ<3[3OnW_n/?ojO0j`;oZ<7[1onX`>/BojNoj`ooYl7/1OnW`>/:ojNo
j`coYkoZ00?oZ<3[ojRojonX_n/01_nX_n/6ojRojP04ojS1k?l0003o0000o`0000GoZ<3[1_nX_n/0
0onX`NcoZ<3[ojS0j`06ojS0j`CoZ;oZ1?nX`N/:ojRojPGoZ<3Z2?nX_n/2ojJoj`KoYko[1_nV_n`0
0onW_n_oY/3/ojK0k006ojK0k0KoZ<3[00?oYl3[ojS0jonX`>/00_nX`>/00ol0003oZ<3[ojS0j`08
ojS0j`OoYko[1_nW`>/2ojO0k1Kooooo00?o0000ooooooooool08_ooool00003ooooool0003o0000
00Co00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool2
o`0001Wooooo00?o0000ooooooooool03?ooool5ojS0j`WoYko[3onW`>/6ojS1j`OoZ<3[3_nW_n/2
ojO0k0goYl7/0_nX`>/7ojO0j`KoYko[3?nW_nX5ojS0j`SoZ;o[0_nX_nX2ojS1k0;o000000?oZ<7/
ojS0jonX`>/01_nX`>/2ojRoj`GoZ<7/2?nX`>/00onX_n[oZ<7[ojS1j`05ojS1j`KoZ;oZ00?oZ<7[
ojS0j_nX`>X01_nX`>X6ojRoj`03ojS0j_nW_n_oYko[00OoYko[0_nV_n`5ojNoj`SoY/3/0_nX`>/5
ojO0j`CoZ<3[00?o0000ojS0jonX`>/02?nX`>/7ojNoj`;oYl3[1_nW`>`Fooooo`03o`000?oooooo
oooo027ooooo000<ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02_ooool7ojS0j`OoYko[3_nW`>/0
0onX`NcoZ<7[ojS1j`06ojS1j`GoZ<3[3?nW_n/6ojO0k0WoYl7/1_nX`>/7ojO0j`;oYko[3?nW_nX2
ojO0j`OoZ<3[1_nX_n/00onW`^coZ<7/o`000002o`0000CoZ<7/1_nX`>/2ojO2k@OoZ<7/1_nX`>/2
ojO2k0SoZ<7[0_nX_nX5ojS1j`SoZ<3Z0_nX_n/5ojS0jPOoYko[00?oZ<3[ojNojonW_n/01_nW_n/6
ojK0k003ojJok?nW`>_oYl3[00GoYl3[1OnX`>/00ol0003oZ<3[ojS0j`07ojS0j`SoYko[2?nW`>`E
ooooo`03o`000?oooooooooo027ooooo000<ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`000005ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool01oooool3
ojS1j`OoZ<3[1onW_n/:ojO0j`GoZ<7/2?nX`N/00onX`>_oYko[ojNoj`0;ojNoj`03ojO0jonW`>co
Yl3/00KoYl3/1OnW`N`2ojS1j`SoZ<3[1OnW`>/<ojNojPKoYl3[1onX`>/2ojRoj`;oYl;/0ol00008
ojS1k0;oZ<3[1_nW`^d7ojS1k0;oZ<3[1_nW`^`6ojS1j`03ojO1kOnX`N_oZ<7[00KoZ<7[1_nX`>X0
0onX`N_oZ<3ZojS0jP06ojS0jPCoYko[1?nX`>/8ojNoj`;oY/3/1OnV_n`7ojO0j`CoZ<3[00?o0000
ojS0jonX`>/02?nX`>/8ojNoj`KoYl3/00?oY[o[ooooooooool05?ooool00ol0003oooooooooo`0P
ooooo`003?ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41001Oooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo00?ooooo1onX`N/5ojS0j`WoYko[2?nW`>/7
ojS1k0KoZ<7[3?nW_n/5ojO0j`SoYl3/00?oYl7/ojS1jonX`N/01?nX`N/8ojS0j`03ojO0jonW_n[o
YkoZ00[oYkoZ2_nW`>/5ojS0j`;oYl;]0ol00004ojO2k0KoZ<7/0_nV`N`8ojO2k@?oZ<7/1?nV`>`8
ojO2k0;oZ<7[1OnW`Nd8ojS1j`;oZ<3Z1OnX`N/8ojS0jP03ojNojonX`>_oZ<3[00GoZ<3[1onW_n/7
ojJok0KoYl3[00?oYl3/ojS0jonX`>/00onX`>/00ol0003oZ<3[ojS0j`08ojS0j`SoYko[0_nW`>`5
ojJojaKooooo00?o0000ooooooooool07oooool000cooooo00?o0000ooooooooool00_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_l0000Nooooo`03o`000?ooooooZ<3[00;oZ<3[2?nX`N/0
0onX`>_oYko[ojNoj`0;ojNoj`SoYl3[1onX`N`2ojS1j`koYko[1onW`>/6ojO0k003ojS1k?nX`N_o
Z<7[00KoZ<7[1_nX`>/2ojNoj`WoYkoZ3_nW`>/00onX`>_oYl;]ojO2k@03o`000003ojO2kOnW`^co
Yl;/00GoYl;/0_nX`N`6ojK1k0KoYl;]00?oY[o[ojK0k?nV`>`01_nV`>`6ojO2k003ojJok?nW`Ngo
Yl7]00KoYl7]1_nX`N/00onW`NcoZ<7[ojS1j`06ojS1j`KoZ<3Z2_nX`>/7ojNoj`OoY[o/0_nW`>/5
ojO0k0GoZ<3[00?o0000ojS0jonX`>/02?nX`>/6ojNoj`03ojO0jonV_n_oY[o[00KoY[o[5Oooool0
0ol0003oooooooooo`0Oooooo`002_ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool00ol0003oooooooooo`0Looooo`OoZ<3[1_nX`N/>ojNoj`[oYl3[1OnX`N`3
ojS0j`ooYko[1onW`>/2ojO0k0GoZ<7/2?nX`N/2ojS0j`KoYko[1_nW_nX00onW_n_oYl3[ojO0j`0<
ojO0j`04ojO2kOl0003o0000o`0000GoYl;]1OnW`^`3ojO0k0OoY/7/0_nW`^d5ojJoj`SoY/3/0_nW
`^`5ojJok0SoYl7]0_nX`N/5ojO1k0SoZ<7[0_nX`>X=ojS0j`OoYko[1_nV_n`00onV_n_oYl3/ojO0
k006ojO0k0GoZ<3[00?o0000ojS0jonX`>/02?nX`>/2ojNoj`GoYl3[2?nV_n/Eooooo`03o`000?oo
oooooooo01kooooo000Kooooo`03o`000?oooooooooo01[ooooo0onW`>/7ojS0j`;oZ<7[3_nW_n/>
ojO0j`03ojS1k?nX`>_oZ<3[00GoZ<3[3onW_n/5ojO0j`WoZ<7/1_nX`N/:ojNoj`;oYkoZ1OnW_n/:
ojO0j`04ojO2kOl0003o0000o`0000WoYl;]00?oYl;/ojO0k?nW`>`01OnW`>`5ojK1k003ojNnj_nV
_n_oY[o[00KoY[o[1_nV`>`00onW_^[oY[o/ojJok006ojJok0KoYl7]0_nV_n`7ojO1k0KoZ<7[0_nW
`N`?ojS0j`OoYko[0_nV_n`5ojJoj`SoYl3/1?nX`>/00ol0003oZ<3[ojS0j`08ojS0j`SoYl3[1onV
_n/Fooooo`03o`000?oooooooooo01gooooo000Kooooo`03o`000?oooooooooo01Oooooo1onW`>/7
ojS0j`ooYko[3OnW`>/2ojS1j`SoZ<3[3onW_n/00onW`>_oZ<7/ojS1k00;ojS1k0;oZ<7[5OnW_n/6
ojO0j`04ojO2kOl0003o0000o`0000_oYl;]0_nW_n/8ojO0k003ojK1k?nW_^[oYkkZ00?oYkkZ2?nV
_n/2ojK0k0GoYkkZ2?nV_n`2ojO1k@KoY[o/1onW`N`2ojS1j`KoYl7/1_nX`>/00onX`N_oZ<3[ojS0
j`05ojS0j`KoYko[00?oZ<3[ojJojonV_n/01_nV_n/6ojO0k0;oY/3/1?nX`>/00ol0003oZ<3[ojS0
j`08ojS0j`SoYl3[1onV_n/Dooooo`;o00007oooool001_ooooo0_l0000Fooooo`[oYl3[1onX`>/?
ojNoj`WoYl3[1_nX`N/6ojS0j`ooYko[00?oYl7/ojS1k?nX`N`02onX`N`IojNoj`;oYl3[0_nW`^d2
o`0000_oYl;]1_nW_n/6ojO0k003ojRnj_nW_^[oYkkZ00GoYkkZ1_nV_n/00onX_n[oYkkZojNnjP06
ojNnjPKoY[o/0_nW_nX8ojJok0?oYl7/1?nU_n`8ojO1k0;oZ<3[1OnX`N/7ojS0j`;oYko[1OnX`>/8
ojJoj`;oYl3/1_nV`>`4ojS0j`03o`000?nX`>_oZ<3[00SoZ<3[1onW`>/7ojJojaKooooo00?o0000
ooooooooool07?ooool001[ooooo00?o0000ooooooooool04oooool<ojO0j`;oZ<7[1onX`>/?ojNo
j`GoYl3[2_nX`N/2ojS0j`ooYko[1OnW`N`9ojS1k1_oYko[0_nW`^d3o`0000[oYl;]2_nW_n/2ojO0
k0GoZ;kZ1onW_^X2ojJoj`GoZ;oZ2?nW_^X2ojJok0KoYkoZ1_nV_n`00onW_n_oYKo/ojFok006ojFo
k0KoYl7/00?oY/3/ojS1jonX`N/01OnX`N/?ojS0j`KoY[o[0_nW_n/8ojK0k0CoZ<3[00?o0000ojS0
jonX`>/02?nX`>/7ojO0j`OoY[o[5Oooool00ol0003oooooooooo`0Looooo`006_ooool00ol0003o
ooooooooo`0?ooooo`CoYko[2OnW`>/6ojS1j`OoZ<3[3onW_n/00onW`>_oZ<7[ojS1j`0:ojS1j`oo
Yko[0_nW`>/7ojO1k0KoZ<7/0_nX`>/HojNoj`;oYl;]0ol0000:ojO2k@coYko[2OnX_^X5ojNnjPWo
Z;oZ1_nW_^X2ojRojPSoYkoZ0_nV_n`5ojNoj`SoYKo/0_nW`N`5ojK0k0OoZ<7[3onX`>/2ojJoj`Ko
Yko[1_nV`>`00onV_ncoZ<3[ojS0j`02ojS0j`03o`000?nX`>_oZ<3[00SoZ<3[1onW`>/8ojJojaGo
oooo00?o0000ooooooooool06oooool001[ooooo00?o0000ooooooooool02oooool9ojNoj`OoYl3[
2?nX`N/5ojS0j`ooYko[0onW`>/8ojS1j`ooYko[1_nW`>/7ojO1k0;oZ<7/1_nX`>/DojNoj`;oZ<;/
0ol0000:ojO2k@coYko[3OnX_^X00onW_^[oZ;oZojRojP0;ojRojP;oYkkZ1_nX_nX6ojNojP03ojVo
j_nW_n_oYko[00KoYko[1_nU_n`00onV_n_oY/3/ojK0k005ojK0k0KoZ<7[00?oYl7/ojS0jonX`>/0
3_nX`>/8ojNoj`;oY/3/1OnV_n`4ojS0j`03o`000?nX`>_oZ<3[00SoZ<3[1onW`>/8ojJojaGooooo
00?o0000ooooooooool01_ooool5o`0000oooooo000Jooooo`;o00002Oooool=ojNoj`OoYl3[2?nX
`N/00onX`>_oYko[ojNoj`0=ojNoj`OoYl3[1OnX`N/2ojS0j`koYko[2?nW`>/5ojO1k0?oZ<7[1onX
`>/@ojNoj`;oZ<;/0ol000000onX`^coYl;]ojO2k@07ojO2k@coYko[4?nX_^XGojRojP;oYkoZ1OnY
_nX8ojNoj`;oYKo/1OnV_n/7ojK0k0;oZ<7[1OnW`N`@ojS0j`KoYko[00?oYl3[ojJok?nV_n`01OnV
_n`5ojS0j`03o`000?nW`>_oZ<3[00OoZ<3[1_nW`>/2ojS0j`SoY[o[5?ooool00ol0003ooooooooo
o`06ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@03oooool001[ooooo00?o0000ooooooooool01_oo
ool2ojS0j`coYko[2OnW`>/6ojS1j`?oZ<3[2_nW_n/<ojO0j`03ojS1jonX`>_oZ<3[00CoZ<3[3_nW
_n/8ojO0j`03ojO1k?nX`N_oZ<7[00GoZ<7[1OnX`>/?ojNoj`04ojO1k?l0003o0000o`0000GoZ<;/
1OnW`^d3ojRoj`WoYko[5?nX_^XFojRojPSoZKoZ1_nW_n/00onY_n[oY[o[ojJoj`06ojJoj`GoY/3/
0_nU_n`7ojO1k13oZ<3[0_nW_n/5ojO0j`OoY[o/0_nX`>/2ojO0j`03o`000?nW`>_oYl3[00SoZ<3[
0_nW`>/6ojS0j`OoY[o[5Oooool00ol0003oooooooooo`06ooooo`03oiRHV?lQ8B7ok^k^013ooooo
000Jooooo`03o`000?oooooooooo00?ooooo1_nX`>/8ojNoj`goYl3[0_nX`N/7ojS0j`OoYko[3OnW
`>/00onX`N_oZ<3[ojS0j`06ojS0j`koYko[1_nW`>/2ojS1k0SoZ<7[00?oZ<3[ojNojonW_n/03OnW
_n/01OnW`Nco0000o`000?l0003oYl7/00SoZ<;/00?oYl;]ojRojonX_n/01OnX_n/5ojNoj`;oYkkZ
3OnX_^X00onX_n[oZ;kZojRnjP06ojRnjPKoZ;oZ0_nX`>/>ojRojPSoZKoZ0_nW_n/5ojVojPSoY[o[
00?oY/3/ojFok?nU_n`01?nU_n`7ojO1k0koZ<3[00?oZL3[ojO0jonW`>/01OnW`>/8ojJok0CoYl3[
00?o0000ojO0jonW`>/04?nX`>/7ojJojaGooooo00?o0000ooooooooool01_ooool00onHV9So8B4Q
onk^kP0?ooooo`006_ooool00ol0003oooooooooo`0:ojS0j`OoYko[3?nW`>/3ojS1j`SoZ<3[1onW
_n/9ojO0j`GoZ<7[2?nX`>/>ojNoj`;oYl3[1_nX`N`6ojS1j`koYko[00CoYl3[o`000?l0003o0000
1OnW`N`6ojS2k0;oZ<3[2?nX_n/00onW_n_oYkkZojNnjP04ojNnjPWoZ;kZ1OnX_nX8ojRnjP;oZ;oZ
1_nX`>/5ojRojP03ojW1jonX_n[oZ;oZ00KoZ;oZ3onY_nX6ojJoj`03ojRoj_nU_ncoYKo/00KoYKo/
0onW`N`4ojK0k0[oZ<3[1OnY`>/7ojO0j`SoY[o/1?nW`>/00ol0003oYl3[ojO0j`0?ojS0j`OoY[o[
5Oooool00ol0003oooooooooo`07ooooo`03ogMgMomVIVKooooo00kooooo000Iooooo`03o`000?nX
`>_oZ<3[00coZ<3[1onW_n/8ojO0j`OoZ<7[1_nX`>/9ojNoj`GoYl3[0_nX`>/7ojS1j`KoZ<3[3OnW
_n/;ojS1k0;oZ<7[3_nW_n/01?nW`>_o0000o`000?l00003ojO0j`KoYl7/0_nX`^`6ojS0j`KoZ;o[
2OnW_^X5ojRnjP03ojRojonX_n[oZ;oZ00KoZ;oZ1_nX_^X:ojS0j`03ojRoj_nY`N_oZL7[00?oZL7[
2?nX_nX?ojVojP;oY[o[1OnX_nX6ojFok003ojJojonV`>coY/3/00KoY/3/1onX`>/8ojW0j`GoYl3[
0_nX`>/8ojJok0CoYl3[00?o0000ojO0jonW`>/03onX`>/7ojJojaGooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0=ooooo`006Oooool00ol0003oZ<3[ojS0j`0;ojS0j`WoYko[1OnW
`>/3ojS0j`OoZ<7[0_nX`>/=ojNoj`03ojO0jonX`>_oZ<3[00CoZ<3[1onX`N/2ojS0j`goYko[3OnX
`N`2ojS0j`koYko[0_l00007ojO0j`?oYl7/1?nX`N`7ojS0j`;oZ;o[3OnW_^X00onX_^[oZ;o[ojRo
j`03ojRoj`SoZ;oZ0_nX_^X<ojS0j`03ojNkj?nY`N_oZL7[00GoZL7[1_nX_nX00onY`N_oZKoZojVo
jP0<ojVojP;oZL3Z1onX_nX2ojFok0GoY[o[2?nV`>`7ojS0j`SoZL3[00?oYl3[ojS0jonX`>/01?nX
`>/7ojJok0CoYl3[00Co0000ojO0jonW`>_oYl3[3_nX`>/8ojJoja?ooooo0ol00004ooooo`05o`00
0?nj^[[ooooooiRHV?l@41003oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03
o`000?ooooooZ<3[00SoZ<3[3OnW_n/00onW`>_oZ<3[ojS0j`05ojS0j`GoZ<7[0_nX`>/=ojNoj`;o
Yl3[1onX`>/5ojS1j`?oYl3[3_nW_n/9ojS1k0KoZ<3[2_nW_n/3o`0000;oYko[1_nW`>/00onX`^co
Z<7/ojS1k006ojS1k0GoZ<3[3onW_^X00onW_n_oZ;o[ojRoj`05ojRoj`KoZ;oZ0_nW_^T:ojS0j`Go
Yk_X1onY`N/2ojRojPGoZL7[2_nY_nX6ojW0jPGoZ;oZ00?oZL3ZojJojonV_n/01_nV_n/6ojK0k003
ojFok?nX`>_oZ<3[00KoZ<3[1onY`>/8ojS0j`OoY[o/1?nW`>/01?l0003oYl3[ojO0jonW`>/>ojS0
j`SoY[o[5?ooool00ol0003oooooooooo`02ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03oooool0
00kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00SoZ<3[3?nW_n/3
ojO0j`OoZ<3[00?oZ<7[ojS0jonX`>/01?nX`>/9ojNoj`KoYl3[1onX`>/00onX`N_oYl3[ojO0j`05
ojO0j`koYko[1onX`N`8ojS0j`KoYko[0ol00006ojNoj`;oYl3[1OnX`^`8ojS1k003ojS0jonW_^[o
YkkZ00goYkkZ1OnW_n/7ojRoj`;oZ;oZ1_nW_^T6ojS0j`03ojNbh?nW^nSoYk_X00KoYk_X1OnY`N/0
0onW^NKoZL7[ojW1j`06ojW1j`KoZKoZ0_nY`N/8ojW0jP03ojRoj_nY`>[oZL3Z00?oZL3Z2?nV_n/2
ojK0k0GoYKo/2?nX`>/7ojW0j`OoZ<3[2?nV_n`4ojO0j`03o`000?nW`>_oYl3[00goZ<3[0_nW`>/8
ojJojaCooooo00?o0000ooooooooool05Oooool000kooooo00Go410@oooooooooooooooooa0@4006
ooooo`;o00000_ooool8ojS0j`SoYko[1onW`>/5ojS0j`;oZ<7[1onX`>/8ojNoj`OoYl3[1OnX`>/3
ojS1j`OoYl3[3_nW_n/7ojS1k0SoZ<3[0_nW_n/3o`0000SoYko[2OnX`^`6ojS1k0koYkkZ0_nW_nX7
ojNoj`GoZ;o[0onW_>P7ojNnj@;oZ<3[1OnW/^08ojNkj003ojW1jonW^NKoYkWV00?oYkWV2?nY`N/2
ojVojPKoZL7[3_nY`>X6ojJoj`;oYko[1onU_n`7ojS0j`SoZL3[1onX`>/8ojJok0CoYl3[00?o0000
ojO0jonW`>/02OnX`>/6ojO0j`OoY[o[5Oooool00ol0003oooooooooo`0Dooooo`003_ooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00oooool7ojS0j`SoYko[1onW`>/0
0onX`>_oZ<7[ojS1j`04ojS1j`OoZ<3[2?nW_n/7ojO0j`03ojS0jonX`N_oZ<7[00GoZ<7[1OnW`>/>
ojNoj`WoZ<7/1_nX`>/3o`0000SoYko[3OnX`^`2ojS1k0koYkkZ1_nW_nX7ojNoj`03ojRojonW_>So
YkcX00GoYkcX1OnW_^T00onWZmWoYk;PojNbh006ojNbh0KoYk_X00?oZJgJojNii_nW^NH01OnW^NH6
ojW1j`;oYkcX2?nY`N/>ojW0jP;oY[o[1_nW_n/7ojFok0OoZ<3[1onY`>/8ojS0j`OoY[o/1?nW`>/0
0ol0003oYl3[ojO0j`08ojS0j`SoYl3[1onV_n/Dooooo`03o`000?oooooooooo01Cooooo000>oooo
o`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`05ooooo`GoZ<3[2_nW_n/5
ojO0j`;oZ<3[1onX`N/5ojS0j`[oYko[0onW`>/4ojS0j`SoZ<7[00?oYl3[ojNojonW_n/03?nW_n/=
ojS1k0;oZ<3[0ol00009ojNoj`03ojO0jonX`^coZ<;/00_oZ<;/0_nW_n/?ojNnjPOoYkoZ0onW_n/<
ojNlj003ojNnjOnWZmWoYj_I00?oYj_I2?nW/^02ojNkj0GoZJgJ1onW^NH2ojW1j`KoYkcX1_nY`N/0
0onW_n_oZL3ZojW0jP0=ojW0jPSoYko[1_nU_n`8ojS0j`OoZL3[2?nX`>/7ojJok0CoYl3[00?o0000
ojO0jonW`>/02?nX`>/7ojO0j`OoY[o[5Oooool00ol0003oooooooooo`0Cooooo`003_ooool01Ol@
413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool01_ooool00onX`>_oYko[ojNoj`0<
ojNoj`03ojO0jonX`>_oZ<3[00CoZ<3[1onX`N/00onX`>_oYko[ojNoj`0:ojNoj`;oYl3[1onX`>/6
ojS1j`03ojO0jonW_n_oYko[00_oYko[0_nW`>/;ojS1k004ojNojol0003o0000o`0000WoYko[1OnW
`>/9ojS2k0KoYko[3onW_^X5ojNojP03ojRnjOnW_>SoYkcX00coYkcX00?oYZOFojN[fOnWZmT01OnW
ZmT6ojNbh003ojfVd?nY[M[oZJgJ00KoZJgJ1OnW^NH2ojf`f`SoYkcX0_nY`N/5ojNoj`ooZL3Z1_nW
_n/00onX`>_oYKo/ojFok005ojFok0KoZ<3[00?oYl3[ojW0jonY`>/01_nY`>/7ojS0j`SoY[o/1?nW
`>/00ol0003oYl3[ojO0j`08ojS0j`OoYl3[1onV_n/Eooooo`03o`000?oooooooooo01;ooooo000>
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2o`0000Sooooo3OnW_n/2ojO0j`OoZ<3[1OnX
`N/3ojS0j`SoYko[1_nW`>/7ojS0j`;oZ<7[1OnW`>/9ojNoj`KoYl3[1_nX`N`00onX`N_oYko[o`00
0002o`0000_oYko[1onW`>/6ojS2k0;oZ<7[1onW_n/?ojNnjP03ojNoj_nX_^WoZ;kY00?oZ;kY2_nW
_>P5ojJWePKoYj_I1?nW/^04ojfVd0SoZJgJ00?oYkWVojf`fon]/=/01?n]/=/6ojNlj003oj^fhOnW
_n_oYko[00KoYko[1OnY`>X2ojW1j`SoZL3Z0_nW_n/5ojS0j`OoYKo/0_nX`>/5ojO0j`SoZL3[1onX
`>/6ojJok003ojJojonW`>_oYl3[00;oYl3[00Co0000ojO0jonW`>_oYl3[1onX`>/7ojO0j`KoY[o[
00?oYko[ooooooooool04oooool00ol0003oooooooooo`0Booooo`003_ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo00?o0000ooooooooool02?ooool9ojNoj`KoYl3[1onX`>/00onX`N_oZ<3[
ojS0j`05ojS0j`OoYko[1onW`>/5ojS0j`?oZ<7[1_nW`>/8ojNoj`OoYl3[0_nX`N`3ojS1j`;o0000
3onW_n/7ojO0j`;oZ<;/1_nX`N/5ojNoj`;oY[kZ3OnW_^X00onW`>_oZ;kYojRnj@05ojRnj@KoYkcX
00?oYJKGojJWe_nVYmH01_nVYmH6ojN[f@03ojNbh?n]Y]3o[JK@00Go[JK@1_nY[MX00onbZ<ko[K3K
ojf`f`06ojf`f`;oYkcX1On[]^48ojNoj`03ojW0j_nY`N_oZL7[00CoZL7[1onY`>X8ojS0j`KoYKo/
2?nW`>/6ojW0j`03ojW1jonX`>_oZ<3[00KoZ<3[0_nV_n`5ojJoj`CoYl3[00Co0000ojO0jonW`>_o
Yl3[1onX`>/7ojO0j`;oY[o[1OnW_n/Eooooo`03o`000?oooooooooo017ooooo000Hooooo`03o`00
0?oooooooooo00Wooooo2?nW_n/7ojO0j`ooZ<3[1onW_n/7ojO0j`03ojS0jonX`N_oZ<7[00GoZ<7[
1_nW`>/8ojNoj`GoYl3[0onX`N/3o`0000?oZ<7[3onW_n/5ojO0j`;oZL;/2?nX`N/00onW_n_oY[kZ
ojJnjP04ojJnjPWoYkkZ1OnW`>/7ojRnj@;oYkcX1OnUY]L7ojJWePGoYj_I00?oZik:ojfVd?n]Y]00
1_n]Y]04ojV]fPCo/ZS>1_n]/=/00onh/M?oZkKQoj^fh@06oj^fh@KoYko[0_nW_^T7ojW1j`OoZL3Z
2?nX`>/6ojFok0SoYl3[0_nY`>/5ojW1j`OoZ<3[2?nV_n/4ojO0j`03o`000?nW`>_oZ<3[00OoZ<3[
1onW`>/8ojNojaGooooo00?o0000ooooooooool04?ooool001Sooooo00?o0000ooooooooool02_oo
ool8ojNoj`GoYl3[3onX`>/9ojNoj`GoYl3[0onX`>/7ojS1j`?oYl3[2onW_n/01?nW`>_oZ<7[ojS1
jonX`N/3o`0000OoZ<7[3onW_n/00onW`>_oZL;/ojW2k004ojW2k0KoZ<7[00?oYkk[ojJnj_nV_^X0
1_nV_^X5ojNnjP03ojJojonW`>_oYl3[00KoYl3[1OnX_^T00onTZM[oYJKGojFVe`05ojFVe`SoYZOF
00?oYj_Ioj^Nb_n[W/X00on[W/X8ojfVd003ojV]f_nbZ<ko/ZS>00Go/ZS>1?n]/=/3okRad`SoZkKQ
0_nW_n/6ojNnj@KoZL7[2?nY`>X7ojS0j`OoYKo/2?nW`>/7ojW1j`OoZ<3[2?nV_n/2ojO0j`;oZ<3[
00?o0000ojS0jonX`>/01onX`>/7ojO0j`OoYko[5Oooool2o`00017ooooo000Gooooo`?o00003Ooo
ool7ojNoj`03ojO0jonX`>_oZ<3[00goZ<3[3OnW_n/00onW`>_oZ<3[ojS0j`05ojS0j`GoZ<7[0_nW
`>/<ojNoj`;oYl3[0ol00009ojS1j`ooYko[0_nX`N`7ojW2k0;oZ<7[1OnW_^/8ojJnjP03ojNnj_nV
_n_oY[o[00?oY[o[2?nW`>/00onX_^WoY:WJojBYfP03ojBYfPOoYJKG1_nVYmH00onVVLSoZik:oj^N
bP05oj^NbPKo[JK@00?o/J36ok:Xc_nbZ<h01_nbZ<h3ojf`f`Go^;7C1_n[]^42okFjg@SoYkkY1_nY
`N/8ojW0jPOoZ<3[1onU_n`8ojO0j`KoZL7[2?nX`>/7ojJoj`CoZ<3[00?o0000ojS0jonX`>/01?nX
`>/4ojS1j`OoYl3[1onW_n/Cooooo`03o`000?oooooo0000017ooooo000Gooooo`03o`000?oooooo
oooo00kooooo1OnW_n/2ojO0j`ooZ<3[3?nW_n/2ojO0j`SoZ<3[00?oZ<7[ojO0jonW`>/01?nW`>/8
ojNoj`;oYl3[0ol000000onW`>_oZ<7[ojS1j`06ojS1j`ooYko[1_nX`N`5ojW2k0;oZ<3[1onW_^/8
ojJnjPKoY[o[1_nW`>/00onU/N7oY:WJojBYfP05ojBYfPKoYJKG1?nVYmH4ojJIb0KoZik:1?n]Y]04
ok6PaPSo/ZS>00?o[K3KokRadonh/M<01Onh/M<2oj^fh@Ko]K[M1_nW_^T00onZ_nWoZL7[ojW1j`05
ojW1j`KoZL3Z0_nY`N/7ojS0j`OoYKo/2?nW`>/6ojW1j`SoZ<3[1onV_n/4ojS0j`03o`000?nX`>_o
Z<3[00SoZ<7[1OnW`>/9ojNojaCooooo00?o0000ooooooooool03oooool001Oooooo00?o0000oooo
ooooool03oooool00onW_n_oYl3[ojO0j`04ojO0j`ooZ<3[2?nW_n/6ojO0j`KoZ<3[00?oZ<7[ojO0
jonW`>/01_nW`>/6ojNoj`?o00001OnW`>/7ojS1j`ooYko[1onX`N`00onY`^coZ<3[ojS0j`04ojS0
j`OoYkk[2?nV_^X6ojJoj`;oYl3[1OnU/N47ojBYfPKoYJKG00?oYZOFojJIb?nVVLP01?nVVLP7oj^N
bP03ojfVd?naX<Ko/J3600Co/J361onbZ<h00onkZ/So^;7CokRad`05okRad`03oknccone^]go]K[M
00Oo]K[M0_nW_^T5ojZoj@OoZL7[0_nY`>X6ojW1j`KoZ<3[2?nU_n`6ojO0j`03ojS0jonY`N_oZL7[
00GoZL7[1_nX`>/00onW`>_oY[o[ojJoj`06ojJoj`CoZ<3[00?o0000ojS0jonX`>/02?nX`N/00onW
`>_oYko[ojNoj`0;ojNojaCooooo00?o0000ooooooooool03_ooool001Oooooo00?o0000oooooooo
ool04?ooool7ojO0j`ooZ<3[1onW_n/7ojO0j`;oZ<3[1OnX`N/8ojO0j`;oYko[0ol00002ojNoj`Oo
Yl3[1onX`N/6ojNoj`03ojJojonW_n_oYko[00KoYko[1OnX`N`2ojW2k0OoZ<3[1OnW_^/2ojJnj`So
Y[kZ0onV_n/3ojNkj0OoYK7Q1onTZMX3ojFVe`;oXYO92?nVVLP5oj^NbP03ok>SaonaX<Ko/J3600Ko
/J361OnbZ<h3ok^Zb0Go^;7C0ono/ll7okFjg@03okg0g?nZ_nWoZ[oY00GoZ[oY1_nY`N/2ojS0j`So
ZL7[1_nX`>/8ojFok0;oYl3[1OnX`>/7ojW1j`;oZ<3[1OnW`>/7ojJoj`GoZ<3[00?o0000ojS0jonX
`>/01onX`N/>ojNojaGooooo00?o0000ooooooooool03Oooool001Oooooo0_l0000Booooo`OoYl3[
3OnX`>/9ojNoj`GoYl3[0onX`>/6ojS1j`KoYl3[0ol00006ojNoj`?oYl3[2onX`N/2ojNoj`GoY[o[
2?nW_n/00onX`NcoZL;/ojW2k004ojW2k0OoZ<3[00?oYkk[ojJnjonV_^/01?nV_^/6ojJnjP03ojS1
jonW^nSoYk_X00GoYk_X1_nU/N46ojBYfP03oifGcOnRUlWoXYO900CoXYO91onVVLP4oj^NbP?o/j?7
1onaX<H3ok:XcPKo^j[80onh/M<5okncc`Go]K[M0onm`=`7ojZoj@;oZL7[1_nX`>/7ojW1j`OoZ<3[
1_nU_n`00onU_^coZ<3[ojS0j`06ojS0j`?oZL7[1?nX`N/7ojO0j`OoY[o[1?nX`>/01?l0003oZ<3[
ojS0jonX`>/7ojS1j`koYko[5?ooool00ol0003oooooooooo`0=ooooo`005oooool00ol0003ooooo
ooooo`0Booooo`SoYl3[2?nX`>/=ojNoj`03ojO0jonX`>_oZ<3[00GoZ<3[1_nX`N/2ojO0j`03ojNo
jol0003o000000SoYko[0_nW`>/<ojS1j`;oYko[1onV_n/6ojNoj`;oZ<7[1onY`^`3ojS0j`_oY[k[
0_nV_^X5ojS1j`OoYk_X1_nU/N42ojBYfPGoWIO=1OnRUlT7ojJIb0?oZik:1?ncXlL8ok6PaP03ok:X
c_nkZ/So^j[800Ko^j[800?o^;7Coknccono/ll01?no/ll3okFjg@Ko_L3L1OnZ_nT2ojc2j@SoZ<3[
1onY`N/7ojS0j`;oYKo/1OnU_^`7ojS0j`SoZ<7[1_nW`>/8ojJoj`CoZ<3[00?o0000ojS0jonX`>/0
2?nX`N/3ojNoj`?oY[o[2?nW_n/Dooooo`03o`000?oooooooooo00cooooo000Gooooo`03o`000?oo
oooooooo01?ooooo2?nW`>/7ojS0j`coYko[0onW`>/7ojS0j`?oZ<7[0_nW`>/3o`0000OoYko[1_nW
`>/8ojS1j`KoYko[1onV_n/2ojNoj`KoZ<7[1OnY`^`2ojO0j`koY[k[1onX`N/7ojNkj0?oYK7Q0_nJ
W]H7oifGc@KoXYO91onVVLP00on[W/[o/j?7ok>Sa`04ok>Sa`Ko/J3600?o`KC=ok^Zb?nkZ/P01onk
Z/P8okncc`03okFjgOnm`=co_L3L00Ko_L3L00?oZ[oYojc2jOn/`^T01?n/`^T8ojS0j`OoZL7[1onX
`>/7ojFnk0OoZ<3[2?nX`N/6ojO0j`SoY[o[1?nX`>/00ol0003oZ<3[ojS0j`06ojS1j`03ojS0jonV
_n_oY[o[00GoY[o[1_nW_n/00onW`>_oooooooooo`0Cooooo`03o`000?oooooooooo00_ooooo000G
ooooo`03o`000?oooooooooo01Gooooo1onW`>/7ojS0j`SoYko[1onW`>/5ojS0j`;oZ<7[00CoYl3[
o`000?l0003o00000onW`>/7ojNoj`OoYl3[2?nX`N/6ojNoj`GoY[o[0onW_n/7ojS1j`03ojW2k?nW
`>_oYl3[00CoYl3[3_nV_^/7ojS1j`?oYk_X0onJY]h6oiZNePOoWIO=1OnRUlT6ojJIb003ojjUc_nc
XlOo/j?700Go/j?71OnaX<H3ol6dc@Oo^j[80_o8^L/6okncc`;ob[k?1onm`=`2ol?8gPOo[<;Y2?nX
`>/6ojW1j`SoZ<3[1OnU_^`00onU_^_oZ<3[ojS0j`06ojS0j`OoZ<7[1onW`>/6ojJoj`03ojNojonX
`>_oZ<3[00?oZ<3[00?o0000ojS0jonX`>/00_nX`N/5ojS0j`OoY[o[0_nW_n/5ojO0jaCooooo00?o
0000ooooooooool02oooool001Kooooo0ol0000Gooooo`GoYl3[2OnX`>/8ojNoj`OoYl3[00CoZ<3[
ojS1jonX`N_oZ<7[0ol00007ojO0j`OoYko[1onW`>/8ojS1j`KoYko[00?oY[o[ojNojonW_n/01OnW
_n/5ojS1j`;oZL;[1onW`>/>ojJnj`GoZ<7[00?oXkOWoiZVg_nJY]h01OnJY]h5oiZNePOoWIO=1_nR
UlT2ojJIb0Go[ZG>1_ncXlL3ok6PaPGo`KC=1_nkZ/P4olRib`Co_k??1?o:_/l4okg0g0Go`lSN1On/
`^T2ojc3j`SoZ<3[1_nY`N/8ojS0j`03ojFnk?nU_^_oYKk[00?oYKk[2?nX`>/7ojS1j`OoYl3[0_nV
_n/5ojNoj`CoZ<3[00?o0000ojS0jonX`>/01onX`>/6ojJoj`;oYko[1onW`>/Dooooo`03o`000?oo
oooooooo00[ooooo000Fooooo`03o`000?oooooooooo01Sooooo00?oYl3[ojS0jonX`>/02onX`>/8
ojNoj`GoYl3[00?oZ<3[ojS1jol000000_l00004ojS1j`GoYl3[2OnW_n/5ojO0j`[oZ<7[0onW_n/3
ojJoj`SoYko[00?oZ<7[ojW2jonY`^/01?nY`^/7ojO0j`koY[k[00?oZ<7[oj>gionS]nL00onS]nL7
oiZVgPGoVYkF1_nMUld5oj:Gb@03ojBPd_n^YLko[ZG>00Go[ZG>1oncXlL00onaX<Ko`KC=ol6dc@05
ol6dc@Co^j[81Oo8^L/3okncc`Kob[k?00?o_L3Lol?8g_o3b=h01_o3b=h00on/`^Wo[<?[ojc3j`04
ojc3j`KoZ<3[00?oZL3[ojW1jonY`N/01OnY`N/6ojS0j`03ojO0k?nU_^_oYKk[00GoYKk[1_nX`>/9
ojS1j`?oYl3[0onV_n/8ojNoj`CoZ<3[00?o0000ojS0jonX`>/01onX`>/2ojJoj`KoYko[1OnW`>/0
0onX`>_oooooooooo`0Aooooo`?o00002oooool000Cooooo1?l000002?l@413oooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^1_ooool00ol0003oooooooooo`0Jooooo`[oZ<3[1?nW`>/7ojNoj`03ojO0
jonX`>_oZ<3[00?o00002?nX`N/00onW`>_oYko[ojNoj`0;ojNoj`03ojO0jonX`N_oZ<7[00[oZ<7[
00?oYko[ojJojonV_n/01OnV_n/6ojNoj`;oZ<3[1onY`^/3ojO0j`koY[k[1?nX`N/6oj>gi`KoVZKN
1OnJW]H7oifGc@03oj:GbOnTX=;oY:3B00?oY:3B1on^YLh5ok>Sa`03okg9i?o1]<go`KC=00Ko`KC=
0onkZ/P7olRib`03oknccoo:_/oob[k?00Gob[k?2?o3b=h00oo5cn;o[<?[ojc3j`06ojc3j`;oZ<3[
1OnY`>/7ojW1j`;oZ<3[1OnW`>`7ojFnj`;oZ<3[3?nX`N/7ojJoj`KoYko[0_nW`>/4ojS0j`03o`00
0?nX`>_oZ<3[00GoZ<3[0_nW`>/8ojNoj`03ojO0jonX`>_oZ<3[00?oZ<3[3oooool3o`0000;ooooo
00?o0000ooooooooool02Oooool000Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Kooooo00?o0000ooooooooool06oooool6ojS0j`SoYl3[1_nW_n/3o`0000CoZ<3[
1_nX`N/2ojS0j`koYko[2OnX`N/5ojNoj`OoY[o[0_nW_n/6ojS0j`GoZL;[0_nX`>/>ojJnj`OoZ<7[
1OnS]nL7oiZVgPGoVYkF0onMUld3oiRFc`KoY:3B1on^YLh3ok>Sa`Co_LWT2?o1]<d00onkZ/Sob;W;
olRib`05olRib`03olc6e?o:_/oob[k?00Kob[k?00?od/_Bol?8g_o3b=h01?o3b=h3olG?hPKo[<?[
00?oZ/?/ojW0jonY`>/01OnY`>/8ojW1j`OoYl3/0onU_^/4ojJnj`koZ<7[1onV_n/2ojNoj`KoYl3[
0onX`>/00ol0003oZ<3[ojS0j`02ojS0j`KoYl3[1onW_n/7ojS0j`_ooooo0ol00005ooooo`03o`00
0?oooooooooo00Wooooo0006ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooo
oa0@4006ooooo`;o00007Oooool6ojS0j`SoYl3[0_nW_n/3o`0000;oYko[1_nX`>/2ojS1j`KoZ<3[
3_nW_n/8ojS1j`KoYko[2?nV_n/7ojS0j`03ojW2jonX`>_oZ<3[00CoZ<3[3_nV_^/7ojS1j`GoXkOW
0onJY]h3ohfGf0GoSHk?1onHU/l6ojBPdPOo[ZG>00?o/j?7okg9i?nmbN@01?nmbN@6ol6dc@03ol;?
i?o8^L_ob;W;00Gob;W;0oo<a]@6olZnc`?od/_B0oo3b=h6olG?hP;o[<?[1OnZ`n`7ojW0j`SoZL7[
1OnW`>`00onV_ncoY[k[ojJnj`06ojJnj`koZ<7[1onV_n/8ojO0j`?oZ<3[00?o0000ojS1jonX`N/0
2?nW`>/7ojNoj`OoZ<3[1_ooool4o`0000Sooooo00?o0000ooooooooool02Oooool000Kooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Gooooo0_l0000Oooooo`KoZ<3[
1_nW`>/00onW_n_o0000o`000006ojNoj`?oZ<3[1?nX`N/7ojS0j`koYko[2?nX`N/6ojNoj`SoY[o[
1OnX`>/00onY`^_oZ<3[ojS0j`06ojS0j`koY[k[1OnX`N/00onN^N_oT:CSoi2Th`03oi2Th`OoSIOH
1On=S/l6oiRFc`KoY:3B1_n^YLh2ojOMnPKo_LWT1?o1]<d4ol;?i0Gob;W;1Oo<a]@4olZnc`God/_B
00?o`lSNolG?h_o5cn801?o5cn82ol;Dj0OoZ/?/1OnY`>/:ojW1j`03ojO0k?nV_ncoY[o/00?oY[o/
2?nV_^/>ojS1j`OoY[o[1_nW`>/00onX`>_oZ<7[ojS1j`02ojS1j`03o`000?nX`N_oZ<7[00KoYl3[
2?nW_n/7ojS0j`?ooooo0ol0000=ooooo`03o`000?oooooooooo00Sooooo0006ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo01oooooo
1_nX`>/2ojO0j`04ojNojol0003o0000o`0000OoYko[0_nW`>/7ojS1j`GoZ<3[3_nW_n/3ojS0j`Oo
Z<7[0onW_n/;ojJoj`03ojS0jonY`^_oZL;[00?oZL;[2?nX`>/>ojJnj`03ojS1jonN^N_oW[W[00?o
W[W[1On@Y><6ohfGf0GoSHk?1onHU/l6ojBPdP;o[ZG>1_nWgOX6okg9i003ol6dcOo2cnCo`/oT00Go
`/oT0oo8^L/6olc6e0?ob[k?1OoBbm83omOGf0?oaLoR1Oo2e>P7oj[3k003ojW0jonY`N_oZL7[00_o
ZL7[1onV_n`6ojJnj`03ojNojonX`N_oZ<7[00WoZ<7[0onW`>/8ojJoj`;oYl3[1OnX`>/4ojS1j`03
o`000?nX`N_oZ<7[00;oYl3[3?nW_n/7ojS0j`;o00004?ooool00ol0003oooooooooo`08ooooo`00
1_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003o
ooooooooo`0Pooooo`?oZ<3[0_nW`>/3o`0000OoYko[1_nW`>/7ojS1j`03ojS0jonW_n_oYko[00co
Yko[1onX`>/5ojS1j`03ojO0jonV_n_oY[o[00_oY[o[0_nW`>/6ojW2j`KoZ<3[0_nV_n/:ojJnj`Co
Z<7[1_nN^N/5oi2Th`KoSIOH1On=S/l6oiRFc`GoY:3B0onOfo`7ojOMnP?o_LWT0oll`L@8ol;?i003
olRiboo<a]Coc<KD00Koc<KD00?ob[k?om;;d_oBbm800ooBbm85omOGf003olG?h_o2e>So`]CX00Go
`]CX0onZ`n`3ojO1k0ooZL7[1onV_n`2ojJnj`GoYko[1onX`N/7ojO0j`OoY[o[1onX`>/4ojS1j`03
o`000?nX`N_oZ<7[00_oYko[0onW`>/8ojS0ja7ooooo00?o0000ooooooooool02?ooool000Kooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_l0000Rooooo`04
ojO0jol0003o0000o`0000?oYl3[2?nW_n/6ojO0j`SoZ<7[3OnW_n/8ojS0j`03ojS1jonW`>_oYl3[
00?oYl3[2OnV_n/6ojO0j`KoZL;[0_nX`>/6ojJoj`KoY[k[2?nX`N/5oijij`GoT:CS1_n=UmP5ohf>
c`OoV9K?00?oY:3BoioKo?nOfo`01OnOfo`3ojOMnP03omc8aOnX_n_oWhVl00CoWhVl00?oF5fmocc1
a?ll`L@01_o2cn@00onNdo[oc<KDolc6e006olc6e003olW9f_oBbm;od/_B00?od/_B1OoGemP00ooG
iN3o`]CXol;Dj005ol;Dj003okSBkOnW`NcoYl7/00GoYl7/3onY`N/3ojJok0?oYKk[2?nW_n/7ojS1
j`OoYl3[1onV_n/7ojS0j`CoZ<7[00?o0000ojS1jonX`N/01_nW_n/00onV_n_oYl3[ojO0j`05ojO0
j`KoZ<3[00?oZ<7[ooooooooool03oooool00ol0003oooooooooo`08ooooo`001?ooool00omEEEGo
IVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`0Ooooo
o`?o00001onW`>/8ojNoj`KoYl3[2?nX`N/5ojNoj`03ojJojonW_n_oYko[00GoYko[1_nX`>/2ojW1
j`KoYl3[2?nV_n/7ojO0j`?oZL;[1?nX`N/7ojJoj`KoY[k[2?nX`N/5oijij`GoT:CS1On=UmP5ohf>
c`KoV9K?0onQ`O05oioKo0Gog<S51_nORK`4oeQM_@;o`/oT1OnNdoX6olc6e0?obLWJ0ooBbm85omOG
f0?oenGP1?o2e>P4okSBk@OoYl7/3OnY`N/00onX`N_oYKk[ojFnj`05ojFnj`KoYko[0_nX`>/6ojS1
j`KoYl3[0_nW_n/7ojJoj`?oZ<3[2?nX`N/00ol0003oZ<7[ojS1j`02ojNoj`GoY[o[1onW`>/2ojS0
j`GoZ<7[4?ooool00ol0003oooooooooo`08ooooo`005Oooool00ol0003oooooooooo`0Looooo`?o
00001?ooool5ojO0j`[oYko[0onW`>/4ojS0j`OoZ<7[00?oYko[ojJojonV_n/00onV_n/7ojNoj`;o
Z<3[1_nY`N/6ojO0j`SoY[o[1OnW`>/2ojW1j`OoZ<7[1OnV_n/8ojJnj`KoZ<7[00?oX[g]ohVYj_n9
ZNX00on9ZNX5ogVFh`CoNX_H0_n=UmP5ohf>c`;oV9K?1onQ`O000onOfocof?kDomSne006omc8a@03
olRV]onORKcoWhVl00?oWhVl1OmHGKd00ol09j[oW]?joikCnP04oikCnP?oc<KD1_o9bMX00ooBbm;o
emOHomOGf003omOGf0GoenGP00?o`]CXokSBkOnhd^d01Onhd^d5ojO1k0;oYko[2OnY`N/5ojS1j`Oo
YKk[0_nW_n/6ojS0j`KoZ<7[0_nW`>/6ojNoj`GoY[o[00?oYko[ojS1jonX`N/02_nX`N/00ol0003o
Yl3[ojJoj`06ojJoj`OoYl3[2?nX`N/?ooooo`03o`000?oooooooooo00Sooooo000Eooooo`03o`00
0?oooooooooo01Wooooo0ol00008ooooo`03ojO0jonW_n_oYko[00[oYko[00?oYl3[ojS0jonX`>/0
1_nX`>/5ojS1j`;oYl3[1_nV_n/5ojNoj`?oYl3[1onY`N/3ojO0j`_oY[o[00?oYl3[ojW1jonY`N/0
1?nY`N/7ojS1j`03ojJojonV_^_oY[k[00[oY[k[0_nX`N/5oj:mk@GoRJWZ1OmiU^<5ogZ;f0KoSioO
1onQ`O03omSne0Kog<S50_o8Y[L6oin9_0CoF5fm0_l`D<<6oikCnP03olc6e?o9bM[obLWJ00CobLWJ
0oo:c]`3omOGf0GoenGP0_o<i>P8okSBk@03ojO1k?nW_n_oYko[00CoYko[1onY`N/7ojS1j`GoYKk[
0_nV_^/8ojS0j`KoZ<7[2?nW_n/00onV_n_oYko[ojNoj`03ojNoj`WoZ<7[0_nW`>/00ol0003oYl3[
ojO0j`07ojJoj`OoYl3[1onX`N/?ooooo`03o`000?oooooooooo00Sooooo000Eooooo`03o`000?oo
oooooooo01Kooooo0ol0000=ooooo`SoYko[1OnW`>/8ojS0j`03ojS1jonW`>_oYl3[00CoYl3[1_nV
_n/00onW_n_oYl3[ojO0j`05ojO0j`GoZL7[00?oZ<7[ojJojonV_n/02onV_n/2ojNoj`OoZL7[0onX
`N/4ojO0j`[oY[k[1?nW_n/6oj:mk@GoRJWZ1?miU^<6ogZ;f0KoSioO1?nQ`O001?n@kmgof?kDomSn
e?oHo]@6omc8a@?ob:Jg1_nORK`5oeQM_@;o<5331_n2/O<5olW9fPGob/kL00?oemOHomOUh?oGiN00
0ooGiN04olcTj0Ko^=;]00?o[<K]ojNojonW_n/01_nW_n/7ojW1j`OoZ<7[00?oYKk[ojJnjonV_^/0
1?nV_^/6ojS0j`SoZ<7[1_nW_n/00onV_n_oYko[ojNoj`05ojNoj`OoZ<7[1?nW`>/00ol0003oYl3[
ojO0j`03ojJoj`CoYko[1onW`>/7ojS1j`oooooo00?o0000ooooooooool01oooool001Cooooo0_l0
000Eooooo`?o00004Oooool7ojNoj`KoYl3[1_nX`>/2ojS1j`OoYl3[0onV_n/4ojNoj`OoYl3[00?o
ZL7[ojS1jonX`N/00onX`N/9ojJoj`KoYko[1onY`N/7ojO0j`GoY[k[00?oY[o[ojNojonW_n/01_nW
_n/6oj:mk@CoRJWZ1OmiU^<6ogZ;f0KoSioO00?oXL7`oi3_gOn_b^h00ooIfML00ooOal7og<S5omc8
a@03omc8a@Gob:Jg1OnORK`5oeQM_@?o<5331_n2/O<3olW9fPKob/kL0_oEh>03omOUh0Koc>CX0_nh
d^d5ojc6k@KoYko[0_nY`^`7ojW1j`?oZ<7[0onV_n/8ojJnj`;oZ<3[3?nX`N/2ojNoj`GoY[o[1onW
_n/7ojS1j`CoYl3[00?o0000ojNojonW_n/01onW_n/5ojO0j`;oZ<3[1onX`N/>ooooo`03o`000?oo
oooooooo00Oooooo000Dooooo`03o`000?oooooooooo01;ooooo0_l0000Eooooo`OoYko[1_nW`>/2
ojS0j`KoZ<7[1OnW`>/9ojNoj`GoYl3[0_nX`>/6ojS1j`SoY[o[1onW_n/7ojW1j`OoYl3[00?oY[k[
ojJojonV_n/00onV_n/8ojNoj`?oX[g]0_nB]o04og>Ok003ohVYj_miU^?oNIKS00;oNIKS1_mjRmP5
ohnOg`Co[l[^0ooIfML2omo7`@?og<S51_o8Y[L6oin9_0GoF5fm0ol`D<<6oh:al`03olW9f_o:c]co
b/kL00Cob/kL1?oEh>000ooGiN3oc>CXolcTj004olcTj0?o`Mk^1_n/a^d2ojNoj`KoZL;/1OnY`N/2
ojW1k0KoY[o[1_nV_^/2ojNoj`coZ<7[00?oYl3[ojJojonV_n/01_nV_n/3ojNoj`?oZ<3[2?nX`N/0
1OnW`>_oYko[ojNojonW_n_o000000WoYko[00?oYl3[ojS0jonX`>/01?nX`>/5ojS1j`03ojO0jooo
oooooooo00cooooo00?o0000ooooooooool01oooool001Cooooo00?o0000ooooooooool03oooool3
o`0001Sooooo1onW_n/7ojO0j`OoZ<7[00?oYl3[ojNojonW_n/02onW_n/00onW`>_oZ<3[ojS0j`04
ojS0j`KoZ<7[2?nV_n/5ojNoj`;oZ<3[1onY`N/5ojO0j`;oY[o/1_nV_n/6ojNoj`;oYl3[1OnB]o04
og>Ok0CoGXKQ00?oNIKSogZ;f?mjRmP01?mjRmP00on?Wmoo[l[^ojo:kP04ojo:kP?ofMWG1?oOal40
0ooLb<Gob:JgolRV]`05olRV]`KoWhVl1OmHGKd3oc1@``OoRZ?U1Oo:c]`5omGPh0;ofOCQ0oo<i>P6
ol7NkP?o[<K]0onW_n/8ojW2k003ojW1jonY`NcoZL7/00CoZL7/1_nV_n/2ojJnj`KoYko[2?nX`N/5
ojO0j`KoY[o[00?oYko[ojS0jonX`>/01OnX`>/7ojS1j`CoYko[00?o0000ojNojonW_n/01?nW_n/3
ojO0j`SoZ<3[00?oZ<7[ojO0jonW`>/00onW`>/=ooooo`03o`000?oooooooooo00Oooooo000Doooo
o`03o`000?oooooooooo00cooooo0ol0000Looooo`OoYko[1onW`>/5ojS1j`?oZ<3[3OnW_n/7ojS0
j`?oZ<7[1?nW`>/7ojJoj`03ojNojonX`>_oZ<3[00CoZ<3[1onY`N/00onW`>_oY[o/ojJok004ojJo
k0KoY[o[0_nW_n/6ojO0j`GoT[O`1?mcWn`4oej6h@OoR9oS1On_b^h3omWIe`GoglO12Oo8Y[L3oin9
_0;oWXFh0omgKK/2oeQM_@Co<5331on:XnD3ol[>g0GoeN3P1?oIm>400oo<i>So`Mk^ol7NkP04ol7N
kP03ojo;k_nW_n_oYko[00GoYko[1onY`^`8ojW1k0?oY[o[0onV_^/8ojNoj`KoZ<7[1onW`>/2ojJo
j`GoYko[1onX`>/7ojS1j`CoYko[00?o0000ojNojonW_n/01onW`>/6ojS0j`03ojS1jonW`>_oYl3[
00GoYl3[3?ooool00ol0003oooooooooo`07ooooo`004oooool3o`0000[ooooo0ol0000Pooooo`Oo
Yko[1onW`>/00onX`N_oZ<3[ojS0j`05ojS0j`goYko[1OnX`>/3ojW1j`KoYl3[1onV_n/7ojS0j`Oo
ZL7[1onV_n`3ojJoj`?oYKo/2?nW`>/5oi:gl0CoLio/1?mNQ^47ohROh`?o[l[^1?oIfML5omo7`@03
omVm_Oo8Y[Oob:Jg00Kob:Jg1_nNQKP5ogM]^`Co<5331on:XnD00oo:c]coeN3PomGPh003omGPh0Co
fOCQ0_o<l^/4ol7NkPCo[l_^1onW_n/7ojW2k0KoZL7/00?oYl3[ojJnjonV_^/01OnV_^/6ojNoj`So
Z<7[1OnW`>/2ojJoj`OoYko[0onX`>/;ojS1j`CoYko[00?o0000ojNojonW_n/01onW`>/2ojS0j`Go
Z<7[1onW`>/;ooooo`03o`000?oooooooooo00Oooooo000Dooooo`03o`000?oooooooooo00Kooooo
0ol0000Uooooo`KoYko[1OnW`>/:ojS0j`?oYko[0onV_n/7ojNoj`03ojS0jonY`N_oZL7[00GoZL7[
1_nW`>/7ojJoj`GoZ<3[0_nY`>/7ojW1j`GoY[o/2?nU_n`6ojO0j`;oYKo/1?n1/?84odj@k@03og>O
k?mNQ^7oGXKQ00;oGXKQ1on8Wn<00on_b^kofMWGomWIe`02omWIe`GoglO10_oI_Kd7olRV]`03ol2S
_?nNQKSoWXFh00CoWXFh1OmgKK/2ofegc0;o<5331_n:XnD3ojBhi`?oeN3P1?oIm>44olcbj`03ol7N
k_n_bnko[l_^00Go[l_^1OnW_n/9ojW2k0;oZL7/1OnW`>/7ojJnj`;oYko[3?nX`N/00onW`>_oY[o[
ojJoj`04ojJoj`GoYko[00?oZ<3[ojS1jonX`N/02onX`N/00onW`>_oYko[ojNoj`02ojNoj`03o`00
0?nW_n_oYko[00KoYl3[00?oZ<3[ojS1jonX`N/01_nX`N/3ojO0j`?oYko[2oooool00ol0003ooooo
ooooo`07ooooo`005?ooool00ol0003oooooooooo`03ooooo`?o0000:Oooool6ojNoj`03ojO0jonX
`>_oZ<3[00[oZ<3[0_nW`>/6ojJoj`GoYko[0onW`>/7ojW1j`?oYl3[2_nV_n/00onX`>_oZL3[ojW0
j`04ojW0j`OoZL7[00?oY[o/ojFok?nU_n`02_nU_n`2ojO0j`KoYKo/1?n1/?84odj@k@;oFY3Z0_mN
Q^46ohROh`?oZ[gW0ooIfML4omo7`@CofKfm1Oo8Y[L3ol2S_0GoWXFh1_mgKK/4ofegc0;oRZ?U1onT
^>L01?oEh>3ofOCQomWdhOoIm>45olcbj`?o_N7a1on_bnh00onW_n_oZL;/ojW2k00;ojW2k0KoYl3[
1_nV_^/00onW_n_oZ<7[ojS1j`0<ojS1j`SoY[o[00?oYko[ojS0jonX`>/00onX`>/9ojS1j`GoYl3[
1?nW_n/00ol0003oYko[ojNoj`02ojO0j`GoZ<3[1_nX`N/00onX`>_oYko[ojNoj`05ojNoj`_ooooo
00?o0000ooooooooool01_ooool001?ooooo00Co0000oooooooooooooooo0ol0000]ooooo`?oYko[
0onW`>/9ojS0j`KoYl3[1_nV_n/00onW_n_oYl3[ojO0j`05ojO0j`OoZL7[3_nV_n/6ojW0j`GoZL7[
0_nX`>/:ojFok0CoY[o/1onU_n`4oh6`lPCoCY3]1?mJT>X2ohROh`OoZ[gW00?ofMWGomo7`OoOal40
0ooOal44omVm_@Cob:Jg1?o0Xk`6oij5^0GoMffk1Om]Ml`7ojBhi`?o`nG_00?ofOCQolcbjoo<l^/0
0_o<l^/6okgQl@?o[l_^0onW_n/?ojW2k0KoYl3[0_nV_^/5ojNoj`KoZ<7[00?oZ<7/ojS1jonX`N/0
1OnX`N/6ojJoj`03ojJnjonX`>_oZ<3[00GoZ<3[1onX`N/7ojO0j`CoYko[00?o0000ojNojonX`>/0
1onX`>/2ojS1j`GoZ<3[1onW_n/:ooooo`03o`000?oooooooooo00Kooooo000Cooooo`Co0000<Ooo
ool6ojO0j`SoZ<3[1onW`>/6ojJoj`SoYl3[1onY`N/>ojJoj`KoZL3[00?oZL7[ojS0jonX`>/01?nX
`>/7ojFok0OoY[o/1OnU_n`2oj:nk@?oMJcd00?oPK3bodj@kOm>T>d00_m>T>d5oeZ@jPKoZ[gW0_no
a^04omo7`@GofKfm0oo8Y[L5ol2S_0KoWXFh1_mgKK/5ofegc0CoY;SW1?o3iNl4olCmh`03olcbjonm
hO7o_N7a00Co_N7a0_n/a^d6ojNoj`KoZL;/00?oZ<;/ojW2k?nY`^`01_nY`^`3ojO0j`?oY[k[1onW
_n/2ojS1j`GoZ<7/1onX`N/2ojJoj`GoY[k[1onX`>/7ojS1j`GoYl3[1_nW_n/00ol0003oYko[ojS0
j`05ojS0j`03ojS1jonX`>_oZ<3[00KoZ<3[1_nW_n/:ooooo`03o`000?oooooooooo00Kooooo000C
ooooo`;o0000=?ooool6ojO0j`SoZ<3[1onW`>/6ojJoj`KoYl3[0_nX`>/7ojW1j`?oY[o[0onV_n`8
ojJoj`?oZL3[0onY`NX7ojS0j`OoYKo/1onV_n`00onU_ncoX[k]oj:nk@04oj:nk@CoMJcd0ol^QN/0
0om>T>goFY3ZoeZ@jP03oeZ@jP?oZ[gW1Onoa^03omo7`@KofKfm00?ob:Jgol2S_?o0Xk`01Oo0Xk`5
oij5^0KoMffk1_m]Ml`00onT^>Oo`nG_ol?Uk`03ol?Uk`Coa?gS1?nml?800onmhO7o[<K]ojc6k@04
ojc6k@KoYko[0_nY`^`5ojS2k0KoZL;/00?oYl3[ojJnjonV_^/01OnV_^/5ojNoj`;oZ<7[1onX`N`3
ojS1j`?oYko[2?nV_^/3ojS0j`_oZ<7[00?oYl3[ojNojonW_n/01onW_n/00ol0003oYko[ojNoj`02
ojS0j`GoZ<7[1_nX`>/8ojNoj`Wooooo00?o0000ooooooooool01_ooool000Go00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0<_ooool7ojO0j`OoZ<3[1onW`>/6
ojJoj`;oYl3[1_nX`>/5ojW1j`03ojS0jonV_ncoY[o/00GoY[o/1_nV_n/2ojNoj`KoZL7Z1OnX`>/2
ojO0k0OoYKo/1onV_n`7oj:nk@CoMJcd1?l^QN/3oenRm0;oFY3Z00?oZ[gWoko6h?noa^001Onoa^00
0ooOal7ofKfmomVm_@05omVm_@So`:>l1_nNQKP6ogM]^`?oKGO<1?nN^n`3ol?Uk`?oa?gS1Onml?80
0onde_7o[<K]ojc6k@06ojc6k@?oYko[0onY`^`7ojS2k0;oZL;/1OnW`>/7ojJnj`03ojNojonX`N_o
Z<7[00CoZ<7[1OnX`N`00onX`N_oYko[ojNoj`05ojNoj`KoY[k[00?oYl3[ojS1jonX`N/02onX`N/0
0onW`>_oYko[ojNoj`09ojNoj`03o`000?nW`>_oYl3[00OoZ<7[0_nX`>/<ojNoj`Sooooo00?o0000
ooooooooool01_ooool00005oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Wooooo00?o0000ooooooooool0<oooool6ojO0j`OoZ<3[1onW`>/3ojJoj`CoYko[1onX
`>/00onY`N_oZ<3[ojS0j`03ojS0j`OoY[o/0_nV_n/6ojNoj`KoZL7Z00?oZ<3[ojO0k?nW`>`01?nW
`>`6ojFok0SoY[o/1onR_^d3og>^mP03ogF/m?l^QN_o;XG[00;o;XG[1OmOX_@6oko6h003ol3;hooI
_KgofKfm00GofKfm0_o@`lh7ol2S_0KoWXFh0omgKK/3oiBRgPSoW[_/00Co`nG_olCmhoo4oN?oa?gS
1?nml?84okCFl@Ko[<K]00?oYl3/ojW2k?nY`^`01OnY`^`7ojS2k0OoYl3[0onV_^/3ojNoj`SoZ<7[
00?oZ<7/ojS1jonX`N/00onX`N/7ojNoj`;oY[k[1OnW`>/9ojS1j`GoYl3[1onW_n/4ojO0j`03o`00
0?nW`>_oYl3[00KoZ<7[3OnW_n/00onW`>_oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00001?ooooooV9RHob4Q8Oo^k^h4ooooo`05oa0@4?ooooooooooooooool@41002_ooool00ol0003o
ooooooooo`0cooooo`KoYl3[1onX`>/5ojO0j`?oY[o[1_nW_n/=ojS0j`SoY[o/1onW_n/3ojW1jP?o
Z/7Z1onW`>`6ojFok0SoY[o/1onR_^d5og>^mP;o78?X00?o;XG[oenRm?mOX_@00omOX_@3oko6h0Co
`<_S1OoI_Kd3om33cPSo`:>l1?nNQKP00onVZ]WoU:;NoiBRgP05oiBRgPKoW[_/0onZm^d3ojoijP03
okg`l_nde_7o]=Ka00Go]=Ka0_n/a^d5ojO0k0OoZL;/1onX`^`5ojO0j`03ojJmj_nW_n_oYko[00Go
Yko[1_nX`N/00onX`NcoZ<7[ojS1j`05ojS1j`GoYko[0_nV_^/7ojO0j`KoZ<7[2?nW`>/7ojNoj`Co
Yl3[00?o0000ojO0jonW`>/01_nX`N/9ojNoj`GoYl3[1oooool00ol0003oooooooooo`06ooooo`00
0_ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000002oooool2o`0003Co
oooo0onW`>/:ojS0j`03ojO0jonV_n_oY[o[00GoY[o[1_nW_n/=ojS0j`SoY[o/1OnW_n/2ojO0j`Ko
Z/7Z1OnW`>`2ojJok0KoYKo/1_nV_n`2ojK0k0OoX[k]1Omc[_H3oab3j0?oB:Kg0_mOX_@00onoa^3o
`<_Sol3;h`04ol3;h`?ofKfm1Oo@`lh7ol2S_003oij5^?nVZ]WoYZ[I00?oYZ[I1_nDX]h4oijkk0?o
Z_K]1?n_nNX3ok7Qm`Go]=Ka0_nX`>/7ojO0k0?oZL;/2onX`^`00onW`>_oY[gZojJmjP03ojJmjPOo
Yko[0_nX`N/5ojS1k0OoZ<7[00?oYko[ojJnjonV_^/01?nV_^/5ojO0j`SoZ<7[1_nW`>/9ojNoj`?o
Yl3[00?o0000ojS1jonX`N/01onX`N/6ojNoj`SoYl3[1oooool00ol0003oooooooooo`05ooooo`00
0oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000003Oooool00ol0003o
ooooooooo`0booooo`koZ<3[1onV_n/6ojNoj`[oZ<3[1?nW`>/7ojJok003ojNojonW`>_oYl3[00Co
Yl3[1_nZ`NX00onW`>coY[o/ojJok004ojJok0KoYKo/0_nV_n`6ojK0k0GoX[k]0_nU_n`5ogncmP03
obN@k_lLPnSo78?X00GoB:Kg1oo0bn<00ooI_Kgod<?>om33cP04om33cPKo`:>l00?o^L?RojJZfOnV
Z]T01OnVZ]T6oiBRgP04oijkk?nZm^goZ_K]oj[fk@?o[oWZ1onahOL00onde_7oZ<3[ojS0j`04ojS0
j`GoYl3/3_nX`^`00onW_n_oY[gZojJmjP05ojJmjPGoYko[2OnX`N`3ojS1j`?oYko[2?nV_^/00onW
`>_oZ<7[ojS1j`0:ojS1j`;oYl3[2onW_n/00onW`>_oZ<7[ojS1j`02ojS1j`03o`000?nX`N_oZ<7[
00GoZ<7[2?nW_n/7ojO0j`Oooooo00?o0000ooooooooool01Oooool000Cooooo00Go0000oooooooo
oooooooooa0@4003ooooo`03oa0@4?oooooooooo00cooooo00?o0000ooooooooool0<_ooool>ojS0
j`KoY[o[1onW_n/5ojS0j`?oZL3[1_nW`>/7ojJok0OoYl3[1_nZ`NX7ojJok0OoYKo/1onV`>`00onR
_^goYKo/ojFok004ojFok0GoOk?f0olWT>h5odRVm`Go`<_S00?oYM[jom33c_o@`lh01Oo@`lh4ol2S
_0Co^L?R1_nVZ]T5oiBRgP?oTnWi0on1j=/4ojKUn`?o/N7g0onY`n`7ojS0j`03ojO0k?nX`^coZ<;/
00coZ<;/1OnW_n/7ojJmjP03ojNojonX`NcoZ<7/00WoZ<7/0_nX`N/6ojNoj`KoY[k[00?oYl3[ojS1
jonX`N/02OnX`N/3ojO0j`WoYko[1OnW`>/4ojS1j`04o`000?nX`N_oZ<7[ojS1j`coYko[1onW`>/6
ooooo`03o`000?oooooooooo00Gooooo00001Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0?ooooo`03o`000?oooooooooo03;ooooo3_nX`>/6ojJoj`OoYko[00?o
Z<3[ojW0jonY`>/01OnY`>/6ojO0j`OoY[o/1onW`>/6oj[1jPGoY[o/0_nV_n/7ojFok0OoY/3/1onU
_n`5ogncmPGo9i3^00Co0XOKodRVmom8Y_Oo`<_S1OnUf_X7om33cP03ol2S_?ni`n;o^L?R00Go^L?R
1_nVZ]T01?nDX]koTnWioi?YnOnCjOT3oh7Xf`KoY^Gk00?oZLG^ojW3k?nY`n`01OnY`n`5ojS0j`co
Z<;/0onX`N/7ojNoj`?oY[gZ0onW`>/9ojS1k0KoZ<7[1_nW_n/2ojJnj`GoYl3[1onX`N/7ojO0j`Ko
Yko[2?nW`>/4ojS1j`03o`000?nX`N_oYko[00coYko[2?nW`>/5ooooo`03o`000?oooooooooo00Go
oooo00001OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0@oooo
o`;o0000=?ooool=ojS0j`KoY[o[1OnW_n/2ojO0j`SoZL3[1_nW`>/7ojJok0OoYl3[1_nZ`NX00onV
_ncoY[o[ojJoj`04ojJoj`OoYKo/1onV`>`5ojFok0;oYl7/1_nA^O85oeJ/n@03o`1meOl2Qm_o0XOK
00GoYM[j1Oo@`lh2ojWQnPSo^L?R0onVZ]T4ohSTn@?oDlo>0onHhOd2ojKUn`GoZLG^1onY`n`00onX
`>_oZ<;/ojS2k00;ojS2k0KoZ<7[1OnW_n/2ojJnjPKoYl3[1onX`N`8ojS1j`?oYko[0onV_^/7ojO0
j`OoZ<7[1onW`>/6ojNoj`KoYl3[1OnX`N/00ol0003oZ<7[ojS1j`0=ojNoj`KoYl3[00?oZ<7[oooo
ooooool00oooool00ol0003oooooooooo`05ooooo`007oooool00ol0003oooooooooo`0booooo`go
Z<3[1_nV_n/00onW_n_oYl3[ojO0j`04ojO0j`SoZL3[1_nW`>/7ojJok0OoYl3[0onZ`NX3oj[0jPOo
Y[o[1onU_n`7ojK0k003ojFok?nW`NcoYl7/00CoYl7/1_nA^O85oeJ/n@?o07gE1OnUf_X00oo@`lko
ZN7jojWQnP04ojWQnPKo^L?R0omQenD2ohSTn@?oDlo>1OnHhOd2ojO4k`OoZLG^0onY`n`3ojO1k0oo
Z<;/1_nX`N/00onW_n_oY[kZojJnjP04ojJnjPKoYl3[1onX`N`6ojS1j`03ojNnjonV_^_oY[k[00Go
Y[k[1OnW`>/9ojS1j`?oYl3[2_nW_n/2ojO0j`WoZ<7[00?o0000ojS1jonX`N/03OnW_n/2ojO0j`Go
Z<7[1?ooool00ol0003oooooooooo`05ooooo`008?ooool00ol0003oooooooooo`0booooo`goZ<3[
0onV_n/3ojJok0OoYl3[2?nY`>/6ojO0j`OoY[o/1onW`>/6oj[0jPGoY[o[0onW_n/6ojFok0GoY/3/
0_nU`>`7ojO1k0?oTKWb0onR_Nd6oh6fm`Ko@:[f0_l0S<`00ol[/N3oZN7jojWQnP03ojWQnP;o^L?R
1?mQenD3ocRmdPGoSmOo00?oV>7mojO4konWa>l01?nWa>l5ojW5kPSoYl7/3onX`^`3ojS1j`?oY[gZ
1onV_^X3ojO0j`[oZ<7/0_nX`N/5ojNnj`OoY[k[00?oYl3[ojS1jonX`N/02OnX`N/00onW`>_oYko[
ojNoj`0:ojNoj`;oYl3[2_nX`N/00onW_n_o0000ojNoj`0;ojNoj`;oYl3[2?nX`N/3ooooo`03o`00
0?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo03;ooooo2onX`>/3ojO0j`GoY[o/2?nW
`>/7ojW0j`KoYl3[1onV_n`7ojO0j`KoZ/3Z00?oY[o[ojNojonW_n/01OnW_n/6ojFok003ojK0k?nU
`>coYL3/00CoYL3/1onW`N`6oj:mk@KoPKKg0om0Z_H4ohFln@OoHl7m0olj^>/5oho;o0?oSmOo0onU
`^h7ojO4k`03ojW5k_nW`NcoYl7/00[oYl7/3OnX`^`00onW_n[oY[gZojJmjP05ojJmjPGoY[kZ3?nX
`N`3ojS0j`OoYkk[0onV_^/3ojO0j`WoZ<7[1OnW`>/8ojNoj`KoYl3[1_nX`N/4ojNoj`03o`000?nW
_n_oYko[00OoYko[1_nW`>/6ojS1j`03ojS0jooooooooooo00;ooooo00?o0000ooooooooool01?oo
ool002;ooooo00?o0000ooooooooool0<_ooool7ojS0j`OoYl3[1OnV_n`8ojO0j`OoZL3[1_nW`>/7
ojJok0OoYl3[1_nZ`>X8ojNoj`OoYKo/1_nU`>`7ojO1k0KoX[g]0on1]_L4oijlkPKoQKci0omS`Od4
oiJol`KoSl_l00?oYKo/ojG2k_nU`^h01OnU`^h5ojO4k`coYl7/3?nX`^`5ojNojPOoY[gZ00?oY[kZ
ojS1k?nX`N`02_nX`N`7ojS0j`GoYkk[0_nW_n/6ojO0j`KoZ<7[00?oZ<7/ojO0jonW`>/01OnW`>/6
ojNoj`SoYl3[1_nX`N/4ojNoj`03o`000?nW_n_oYko[00OoYko[1_nW`>/2ojS1j`GoZ<3[0oooool0
0ol0003oooooooooo`04ooooo`008oooool2o`0003?ooooo1onX`>/7ojO0j`KoY[o/1onW`>/7ojW0
j`KoYl3[1onV_n`7ojO0j`KoZ/3Z1_nW_n/2ojRoj`OoYKo/1_nU`>`7ojO1k0?oX[g]0onX`N`7oijl
kP?oQKci1?nR_^d6oiJol`;oSl_l1OnU_n`7ojG2kP03ojO4konW`NcoYl7/00WoYl7/0_nW`^`;ojS2
k0;oZ<3[1onW_nX3ojJmjP?oYko[3_nX`N`7ojS0j`03ojNnjonW_n_oYko[00CoYko[1_nW`>/2ojS1
j`GoZ<7/1OnW`>/8ojNoj`KoYl3[2?nX`N/4ojNoj`03o`000?nW_n_oYko[00OoYko[0onW`>/2ojS1
j`SoZ<3[0_ooool00ol0003oooooooooo`04ooooo`009Oooool00ol0003oooooooooo`0booooo`Ko
Z<3[1onW`>/7ojJok0KoYl3[1onY`>/6ojO0j`OoY[o/1onW`>/6oj[0jP;oYko[1_nX_n/5ojFok0;o
Y[o/1_nU`>`5ojO1k0;oYL3]1_nX`N`5oijlkP;oZ<;/1onR_^d3oiJol`?oYl3/1onU_n`3ojG2kPCo
Z<7/2?nW`N`6ojO2k0OoZ<;/1_nX`>/5ojNojP;oYkkZ1_nW_n/>ojS1k0?oZ<3[0onW_^/8ojNoj`?o
Yl3[2_nX`N`00onW`>_oYko[ojNoj`0:ojNoj`;oYl3[2_nX`N/6ojNoj`03o`000?nW_n_oYko[00Go
Yko[00?oYl3[ojS1jonX`N/01?nX`N/6ojS0j`04ojNojoooooooooooo`0000Kooooo000Vooooo`03
o`000?oooooooooo03;ooooo1_nX`>/7ojO0j`OoY[o/1_nW`>/7ojW0j`KoYl3[1OnV_n`2ojK0k0Oo
Yl3[0onZ`>X3ojW1jPSoZ;o[00?oYKo/ojJok?nV_n`01?nV_n`6ojG0k003ojO1k?nU`>goYL3]00Co
YL3]1_nX`N`00onN_>koZ<;/ojS2k004ojS2k0GoX[k]0_nX`^`6ojO0k0GoYKo/0_nW`^`7ojS1k0?o
Yl7/0onW`^d8ojO2k0?oZ<;/1?nX`N/6ojS0j`03ojNoj_nW_^[oYkkZ00CoYkkZ1_nW_n/<ojS1k0;o
Yko[1_nW_^/6ojNoj`03ojO0jonX`NcoZ<7/00[oZ<7/3?nW_n/2ojO0j`WoZ<7[2OnW_n/00ol0003o
Yko[ojNoj`02ojNoj`GoYl3[1_nX`N/2ojS0j`GoYko[00?oooooo`000?ooool01Oooool002Oooooo
00?o0000ooooooooool0<_ooool6ojS0j`OoYl3[1onV_n`6ojO0j`OoZL3[1_nW`>/00onV_ncoY/3/
ojK0k004ojK0k0GoYl3[0_nW`>`6ojW1jPKoZ;o[0_nY_nX7ojJok0?oYL3/0onV`>`7ojG0k@?oZ<7/
0onV`Nd7ojS2k003oj:nkOnX`^coZ<;/00CoZ<;/1_nW`>`00onU_ncoYl;/ojO2k004ojO2k0GoZ<7/
2?nW`^d6ojO2k003ojO1k?nX`N_oZ<7[00KoZ<7[0onX`>/:ojNnjP?oYko[2onX`N`6ojNoj`KoYkk[
0_nW_n/5ojO0j`SoZ<7/3?nW_n/6ojO0j`OoZ<7[2onW_n/00ol0003oYko[ojO0j`07ojO0j`?oZ<7[
1?nX`>/6ojNoj`03o`000?oooooooooo00Cooooo000Xooooo`;o0000<oooool6ojS0j`OoYl3[1onV
_n`6ojO0j`OoZL3[0onW`>/4ojNoj`KoY/3/00?oYl3[ojO0k?nW`>`01?nW`>`6ojW1jP;oZ;o[1_nY
_nX5ojJok0;oYko[1_nV`>`5ojG0k@SoY/7]1OnX`^`2ojK1k@OoZ<;/0onW`>`3ojK1k@OoYl;/00?o
Z<7/ojO2kOnW`^d02_nW`^d2ojO2k0GoYl7/1_nX`N/00onW_NWoYkkZojNnjP0:ojNnjP03ojO1k?nX
`NcoZ<7/00[oZ<7/00?oZ<3[ojNojonW_n/01_nW_n/3ojNnj`[oYl3[0onX`N`4ojS1j`goYko[1_nW
`>/7ojS1j`_oYko[00?o0000ojNojonW`>/01OnW`>/00onX`N_oZ<3[ojS0j`06ojS0j`?oYko[0_oo
ool00ol0003oooooooooo`04ooooo`00:_ooool00ol0003oooooooooo`0aooooo`KoZ<3[1onW`>/5
ojJok0;oY/3/1_nW`>/7ojW0j`OoYko[1_nV`>`7ojO0k0?oZL7Z0onY`N/8ojVojP03ojJok?nW_n_o
Yko[00CoYko[1_nV`>`00onU`>goY/7]ojK1k@0:ojK1k@03ojS2k?nV`NgoY/7]00CoY/7]1OnX`^`8
ojK1k@GoYl;/3?nW`^d:ojO1k0;oZ<7[1OnW_NT8ojNnjPGoYl7/2?nX`N`5ojS0j`OoYko[3?nW`>/0
0onX`NcoZ<7[ojS1j`06ojS1j`goYko[0onW`>/3ojS1k0OoZ<7[2onW_n/01?l0003oYko[ojO0jonW
`>/5ojS1j`KoZ<3[1oooool00ol0003oooooooooo`03ooooo`00:oooool00ol0003oooooooooo`0a
ooooo`OoZ<3[1_nW`>/00onV_ncoY/3/ojK0k004ojK0k0KoYl3[1onY`>/7ojNoj`KoY/3/1OnW`>`2
ojK0k0KoZL7[1_nY_nX2ojW0jPOoYko[0onV`>`3ojJojaCoY/7]00?oZ<;/ojK1kOnV`Nd02_nV`Nd0
0onW`^coYl;]ojO2k@09ojO2k@;oYl3/2onW`N`2ojNnj@OoYkgY0onW_^X:ojO1k0OoZ<7/1_nX`>/7
ojNoj`SoYl3[1OnX`N`6ojS1j`goYko[00?oYl3[ojS1k?nX`N`01OnX`N`5ojS1j`coYko[00?o0000
ojO0jonX`N/01onX`N/2ojS0j`[ooooo00?o0000ooooooooool00oooool002cooooo00?o0000oooo
ooooool0<Oooool7ojS0j`KoYl3[1onV`>`6ojO0j`OoZL3[1onW_n/6ojK0k003ojO0k?nV`>coY/3/
00CoY/3/1_nY`N/2ojVojPKoZL3Z1OnW_n/2ojRojPKoY[o[1OnV`Nd2ojJok1OoY/7]1?nW`Nd7ojO2
k@KoYl3/1onW`N`6ojNnj@GoYkgY0_nW`>/;ojO1k0WoZ<7/0onX`>/3ojNnjPOoYko[0onW`>/:ojS1
k0;oZ<7[3OnW_n/5ojO0j`OoZ<7/00?oZ<7[ojNojonW_n/02OnW_n/5ojO0j`03o`000?nW`>_oZ<7[
00GoZ<7[3Oooool00ol0003oooooooooo`03ooooo`00;Oooool2o`0003;ooooo1onX`>/6ojO0j`Oo
Y/3/1_nW`>/7ojW0j`OoYko[3OnV`>`3ojW1j`CoZ<3[1onY`>X00onW_n_oZ;oZojRojP04ojRojPKo
Y[o[00?oY/7]ojJok?nV_n`01?nV_n`5ojK1k@03ojJojonV`NgoY/7]00[oY/7]0_nV`>`7ojO1k@?o
Yl;]0onW_n/7ojO0k0?oYl7/2_nW_^T00onW_NWoYl3[ojO0j`04ojO0j`OoYl7/2onX`N`00onW_n[o
YkkZojNnjP05ojNnjPGoYko[0_nW`>/;ojS1k0;oZ<3[2_nW_n/:ojO0j`?oZ<7/1?nX`>/8ojNoj`Wo
Yl3[00Co0000ojO0jonX`N_oZ<7[4?ooool00ol0003oooooooooo`03ooooo`00;oooool00ol0003o
ooooooooo`0`ooooo`OoZ<3[1_nW`>/7ojK0k0KoYl3[1onY`>/5ojNoj`;oZ<3[3OnV`>`7ojS0j`?o
ZL3Z0onY`N/8ojRojP?oY[o[0onX_^X7ojJok003ojK1kOnV_n_oY[o[00?oY[o[2?nV`Nd6ojK0k0Go
Yl7]00?oYkkZojNojonW_n/01OnW_n/5ojO0k003ojRnjOnW_^WoYkkY00[oYkkY2OnW`>/3ojO1k0_o
Z<7/1OnW_nX7ojNnjP03ojNojonW`>_oYl3[00CoYl3[1onX`N`6ojS0j`KoYko[3?nW`>/00onX`Nco
Z<3[ojS0j`06ojS0j`GoYko[2onW`>/00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00?o
oooo000`ooooo`03o`000?oooooooooo037ooooo1_nX`>/7ojO0j`KoY/3/1onW`>/6ojW0j`03ojNo
jonX`>_oZ<3[00CoZ<3[3OnV`>`5ojS0j`;oYl3/1_nY`N/6ojRojP03ojW0j_nX_^[oZ;kZ00GoZ;kZ
0onV_n`3ojNnjPOoY[o[0onV`Nd4ojNoj`OoY/3/00?oYl7]ojNnj_nW_^X00onW_^X7ojNoj`03ojO0
k?nX_^WoZ;kY00?oZ;kY2?nW_^T;ojO0j`03ojO1k?nX`NcoZ<7/00[oZ<7/00?oZ;o[ojNoj_nW_nX0
1OnW_nX3ojNnjP_oYl3[1_nX`N`7ojS0j`KoYko[2?nW`>/5ojS1k0KoZ<3[1onW_n/6ojO0j`Gooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`03ooooo`00<Oooool00ol0003ooooooooo
o`0aooooo`OoZ<3[1_nW`>/7ojK0k0KoYl3[0onY`>/:ojS0j`?oY/3/1?nV_n/6ojK0k003ojS0jonW
`>coYl3/00CoYl3/1_nY`N/2ojRojPGoZL3Z1OnX_^X2ojW0jPKoYkkZ1OnV_n/2ojRnj@OoYko[0onV
`>`3ojNnj@OoYkkZ0onW_n/:ojRnj@?oYkkY3?nW`>/5ojO1k0SoZ<7/1OnX_n/5ojNojP;oYko[3?nW
`>/8ojS1k0?oZ<3[2_nW_n/3ojO0j`CoZ<7[1_nX`N`2ojS0j`_oYko[0_nW`>/9ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool00oooool003;ooooo0_l0000booooo`OoZ<3[1_nW`>/7
ojK0k0CoYl3[0onW`>`:ojS0j`?oZL3Z1_nV_n/6ojK0k0OoYl3/0onY`N/3ojO1k0OoZL3Z00?oZ;kZ
ojW0j_nY`>X01?nY`>X6ojNnjP03ojJojonX_^WoZ;kY00CoZ;kY1OnW_n/2ojRoj@KoYkkY1OnW_^X2
ojRojP_oZ;kY3?nW`>/:ojO1k0?oZ<7/1?nX`>/6ojRoj`03ojNoj_nW_n_oYko[00CoYko[2?nW`>/:
ojS1k0goYko[0_nW`>/7ojS1j`?oZ<7/0_nW`>/;ojNoj`kooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`02ooooo`00=?ooool00ol0003oooooooooo`0`ooooo`OoZ<3[1onW`>/6ojK0
k003ojO0jonW`>coYl3/00CoYl3/1onX`>/6ojW0jPCoY[o[0_nW_n/6ojK0k0GoYl3/0_nV`>`6ojO1
k0GoZL3Z0_nX`N/7ojW0jP?oYkkZ0onY`>X7ojRnj@03ojNojonX_nWoZ;oY00CoZ;oY1_nW_^T00onW
_^[oZ;oZojRojP04ojRojPOoZ;kY2onW`>/=ojO1k0;oYl3[1onX`>/3ojRoj`[oYko[0onW`>/4ojO1
k0OoZ<7/3OnW_n/6ojO0j`KoZ<7[1_nW`>/6ojNoja;ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`02ooooo`00=Oooool00ol0003oooooooooo`0`ooooo`OoZ<3[1onW`>/6ojK0k0Oo
Yl3/1_nX`>/7ojW0jP03ojJojonW_n_oYko[00?oYko[1_nV`>`00onW`>coY/3/ojK0k004ojK0k0Ko
Yl7/00?oZL3ZojS1jonX`N/01?nX`N/5ojW0jP;oZ<7[1_nY`>X5ojRnj@;oZL3[1onX_nT3ojNnj@?o
Z<3[1onX_nX3ojRnj@CoYl7/1onW`>/=ojO1k0KoYl3[1OnX`>/00onW_^[oYko[ojNoj`0:ojNoj`Wo
Yl7/0onX`N`2ojS0j`_oYko[2_nW`>/6ojS1j`KoYl3[0_nW_n/Fooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool00_ooool003Kooooo00?o0000ooooooooool0<?ooool7ojS0j`GoYl3[
0_nX`>/6ojK0k0OoYl3/1_nX`>/5ojW0jP;oZL3[1_nW_n/3ojK0k0?oY[o[1onV`>`3ojO1k0CoY/3/
1_nX`N/00onY`>[oZ<7[ojS1j`04ojS1j`KoZL3Z00?oZ;kYojW0jonY`>/01?nY`>/5ojRoj@;oZ<7[
1_nX`>/5ojRojPWoYl7/0onW`>/=ojO1k0[oYl3[00?oZ<3[ojNnj_nW_^X00onW_^X8ojNoj`_oYl7/
00?oZ<7[ojS0jonX`>/01?nX`>/7ojNoj`coYl3[00?oZ<7/ojS1jonX`N/01OnX`N/3ojO0ja_ooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`00=oooool2o`00037ooooo1onX
`>/00onW`>_oZ<3[ojS0j`04ojS0j`KoY/3/1onW`>`6ojS0j`03ojW0j_nY`>_oZL3[00CoZL3[1?nW
_n/2ojRojPKoY[o[3_nV`>`3ojS1j`?oYl7/1onX`N/3ojW0jPCoZ<7/1_nY`>/00onX_nWoZ<7[ojS1
j`04ojS1j`KoZ<3[00?oZ;oZojO1k?nW`N`05_nW`N`;ojO0j`[oYkkZ0onW_n/3ojO0k0WoYl7/1OnX
`N/6ojS0j`OoYko[2?nW`>/5ojS1k0GoZ<7[8?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00;ooooo000iooooo`03o`000?oooooooooo02oooooo3_nX`>/3ojK0k0?oY[o/1onW`>`3
ojS0j`CoYl3[1_nY`>/00onW_n_oZ;oZojRojP03ojRojPKoY[o[3_nV`>`6ojO1k0GoZ<7[0_nW`N`7
ojS1k0?oZL3[0onW`N`7ojS1j`?oZ<3[6?nW`N`:ojO0j`goYkkZ0_nW`>/6ojO0k0GoYl7/0_nX`N`7
ojS1j`?oZ<3[2_nW_n/3ojO0j`?oYl7/1onX`N`00onX`N_oooooooooo`0Qooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool00_ooool003[ooooo00?o0000ooooooooool0;oooool>ojS0
j`KoY[o/1OnW`>`2ojK0k0OoYl3[0onY`>/3ojS0j`KoZ;oZ0onV_n/4ojNoj`goY/3/1_nW`N`00onX
`N_oYl7/ojO1k004ojO1k0GoZ<7/2?nW`N`5ojS1jaSoYl7/2onW`>/=ojNnjPKoYl3[1_nW`>`00onW
`NcoZ<7/ojS1k004ojS1k0GoZ<7[3OnW_n/00onW`>_oYl7/ojO1k005ojO1k0?oZ<7/:?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00;ooooo000kooooo`03o`000?oooooooooo033o
oooo3OnX`>/6ojJok003ojO0k?nV`>coY/3/00CoY/3/1OnW`>/2ojO0k0KoZ<3[1?nX_nX2ojW0jPOo
Yko[0onV`>`3ojNoj`OoY/3/0onW`N`4ojK0k0KoYl7/00?oZ<7/ojO1k?nW`N`02_nW`N`00onX`N_o
Yl7/ojO1k00EojO1k0coYl3[3OnW_^X:ojO0j`?oYl3/0onW`N`7ojS1k003ojS1jonW_n_oYko[00_o
Yko[1OnW`>/5ojO1k2gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`01ooooo`00
??ooool00ol0003oooooooooo`0`ooooo`goZ<3[0onV_n`4ojNoj`KoY/3/00?oYl3[ojO0k?nW`>`0
1?nW`>`6ojS0j`03ojRoj_nY`>[oZL3Z00?oZL3Z1OnW_n/2ojRojPKoYko[1OnV`>`2ojNoj`OoY/3/
0onW`N`3ojK0k27oYl7/2onW`>/2ojRnjP_oYkkZ3OnW`>/8ojO1k0?oZ<7/3OnW_n/:ojO0j`03ojO1
k?oooooooooo02oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`01ooooo`00?Ooo
ool2o`00037ooooo3OnX`>/7ojNoj`KoY/3/1onW`>`3ojS0j`?oYl3[1_nY`>X00onW_n_oZ;oZojRo
jP04ojRojPKoYko[00?oY/3/ojNojonW_n/01?nW_n/5ojK0k0;oYko[1_nV`>`5ojO1k003ojO0jonW
`NcoYl7/00SoYl7/0onW`>/:ojO1k0CoYko[1onW`>/6ojRnjPOoYkkZ3OnW`>/:ojO1k0ooYko[2_nW
`>/dooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00Oooool003oooooo00?o0000
ooooooooool0;oooool=ojS0j`OoYko[1_nV`>`7ojO0k0KoYl3[0onY`>X3ojS0j`OoZ;oZ0onW_n/4
ojRojPKoYko[00?oY/3/ojNojonW_n/01?nW_n/6ojK0k003ojO1k?nW`>_oYl3[00?oYl3[1OnW`N`2
ojNoj`KoYl3[1OnW`N`2ojNojPOoYko[0onW`>/3ojRojPOoZ;kZ0onW_^X<ojO0j`_oYl7/4onW_n/5
ojO0jcWooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`01ooooo`00@?ooool00ol0
003oooooooooo`0_ooooo`goZ<3[1onW_n/6ojK0k0OoYl3/1?nW`>/2ojO0k0KoZ<3[1OnX_nX2ojS0
j`OoZ;oZ0onW_n/3ojRojPOoYko[0onV`>`3ojNoj`KoYl3[00?oYl7/ojNojonW_n/01?nW_n/6ojO0
j`03ojO1k?nW_n[oYkoZ00CoYkoZ1OnW_n/8ojRojPGoZ;kZ3?nW`>/<ojO1k0CoYl3[4onW_n/00onW
`>_oooooooooo`0kooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00Oooool0047o
oooo00?o0000ooooooooool0;oooool=ojS0j`OoYko[0onV`>`4ojNoj`KoYl3/00?oYl3[ojO0k?nW
`>`00onW`>`6ojS0j`03ojRoj_nX`>_oZ<3[00CoZ<3[1OnX_nX2ojS0j`KoZ;oZ1OnW_n/00onX_n[o
Yko[ojNoj`05ojNoj`?oYl3[0onX_nX7ojNoj`?oYl3[1?nX_nX6ojNojP03ojNojonX_n[oZ;oZ00[o
Z;oZ00?oZ;kZojO0jonW`>/02_nW`>/;ojO1k0WoYl3[3onW_n]1ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool00Oooool004;ooooo0_l0000`ooooo`GoZ<3[0_nW`>/6ojS0j`GoYko[
0_nX`>/7ojNoj`?oYl3/0onV`>`6ojO0k0?oZ<3[1?nW`>`6ojS0j`03ojRoj_nX`>_oZ<3[00CoZ<3[
1_nX_nX00onW_n_oZ;oZojRojP03ojRojPGoYko[2?nX_nX5ojNoj`WoZ;oZ0onW_nX2ojRoj`[oZ;oZ
3OnW`>/;ojO1k0_oYl3[3?nW_n]6ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
0Oooool004Cooooo00?o0000ooooooooool0;_ooool00onX`>_oYl3[ojO0j`04ojO0j`KoZ<3[00?o
Yko[ojS0jonX`>/01?nX`>/7ojNoj`KoY/3/3OnW`>`3ojS0j`?oYl3/1onX`>/3ojRojPCoZ<3[1OnX
_nX00onW_n_oZ;oZojRojP0:ojRojP03ojNojonX_n[oZ;oZ00WoZ;oZ00?oZ<3[ojRojonX_n/01?nX
_n/5ojRojP;oYl3/2_nW`>/=ojO1k0_oYl3[3?nW_n]:ooooo`03o`000?oooooooooo00Oooooo0Ol0
0001ooooo`7ooooo0015ooooo`03o`000?oooooooooo02oooooo1_nW`>/=ojS0j`OoYko[1_nV`>`C
ojO0k0GoZ<3[0_nW`>`7ojS0j`;oZ;oZ0onX`>/:ojRojPCoZ<3[1onX_nX5ojS0j`KoZ;o[00?oZ;oZ
ojO0k?nW`>`01?nW`>`5ojO0j`goYl7/2onW`>/=ojNojdkooooo00?o0000ooooooooool01_ooool1
o`00007ooooo0Oooool004Kooooo00?o0000ooooooooool0<?ooool2ojO0j`?oYl3/3_nX`>/6ojNo
j`?oY/3/0onW_n/CojO0k003ojS0jonW`>coYl3/00CoYl3/1OnX`>/00onW`>coZ<3[ojS0j`04ojS0
j`GoZ;oZ2OnX`>/3ojRojP;oYl3[1onX`>/3ojRoj`CoYl7/1_nW`>`00onW`>_oYl7/ojO1k00;ojO1
k0[oYl3[0_nW_nX;ojNoje;ooooo00?o0000ooooooooool01_ooool1o`00007ooooo0Oooool004Oo
oooo0_l0000aooooo`GoYl3/1OnX`>/2ojO0j`OoZ<3[0onW_n/3ojRoj`KoYko[0onW`>`4ojNoja?o
Yl3/00?oZ<3[ojO0k?nW`>`00onW`>`6ojS0j`03ojRoj_nX`>_oZ<3[00WoZ<3[00?oYl7/ojO0jonW
`>/01?nW`>/5ojS0j`WoYl7/0onW`>`=ojO1k0[oYl3[1_nW_nX7ojNojeKooooo00?o0000oooooooo
ool01Oooool1o`00007ooooo0Oooool004Wooooo00?o0000ooooooooool0;oooool5ojO0k003ojS0
jonW`>_oYl3[00CoYl3[1onX`>/6ojRoj`CoYko[0_nX_n/7ojNoja3oYl3/0onW`N`6ojO0k0?oZ<3[
1?nW`N`7ojS0j`GoYl7/1_nW`>/00onX`>_oYl7/ojO1k00FojO1k0_oYl3[2_nW_nX3ojNoje[ooooo
00?o0000ooooooooool01?ooool1o`00007ooooo0Oooool004[ooooo00?o0000ooooooooool0;ooo
ool6ojO0k0KoYl3[1onX`>/6ojRoj`03ojNojonX_n_oZ;o[00?oZ;o[1onW_n/<ojO0k0OoYl7/0onW
`>`:ojO1k0?oZ<3[2OnW`N`3ojO0jaSoYl7/2_nW`>/=ojNojUoooooo00?o0000ooooooooool00ooo
ool1o`00007ooooo0Oooool004_ooooo00?o0000ooooooooool0;oooool6ojO0k0?oYl3[0onW`>`7
ojS0j`?oZ;o[1?nX`>/5ojRoj`OoYko[3?nW`>`5ojO1k0;oYl3[2onW`N`2ojO0k1KoYl7/1?nW`>`9
ojO1k0?oYko[1onW`>/=ojNojV;ooooo00?o0000ooooooooool00oooool1o`00007ooooo0Oooool0
04cooooo0_l0000`ooooo`coYl3/1OnX`>/2ojO0j`OoZ<3[0_nX_n/4ojS0j`KoYko[0onW`>`4ojNo
j`GoYl3/00?oYl7/ojO0jonW`>/01?nW`>/7ojO1k0KoYl3/1?nW`N`2ojO0j`_oYl7/0_nW`>/7ojO0
k0?oYl7/2OnW_n/3ojO0j`goYkoZI_ooool00ol0003oooooooooo`03ooooo`7o00000Oooool004ko
oooo00?o0000ooooooooool0;_ooool<ojO0k003ojS0jonW`>_oYl3[00CoYl3[3OnX`>/3ojNoj`?o
Z<3[1onW_n/2ojO0k0CoYko[1_nW`>/3ojO1k0CoYko[1_nW`>`00onW`NcoYl3[ojO0j`03ojO0j`Oo
Yl7/1_nW`>/5ojO0k003ojNoj_nW_n_oYko[00WoYko[0_nX_n/:ojNojVcooooo00?o0000oooooooo
ool00_ooool1o`00007ooooo001?ooooo`03o`000?oooooooooo02oooooo3?nW`>`6ojO0ja?oZ<3[
1OnW_n/00onX_n_oYko[ojNoj`05ojNoj`?oYl3[2_nW_n/3ojO0k0?oYko[1_nW`>/3ojO1k0CoYko[
1_nW`>/00onW`>coYkoZojNojP03ojNojPOoYko[1_nX_n/5ojNojW7ooooo00Go0000oooooooooooo
ooooo`000001ooooo`00D?ooool00ol0003oooooooooo`0_ooooo`;oYl3/1?nW_n/6ojO0k0?oYl3[
1?nW`>`BojS0j`03ojNojonX_n_oZ;o[00?oZ;o[1OnW_n/2ojRoj`_oYko[00?oZ;oZojNojonW_n/0
1OnW_n/3ojO0j`?oZ;oZ1onW_n/3ojO0j`?oZ;oZ1_nW_nX3ojNoj`[oZ;o[00?oYkoZooooooooool0
L_ooool01Ol0003ooooooooooooooooo0000007ooooo001Aooooo`;o0000<?ooool6ojNoj`goYl3/
0_nX`>/4ojO0k0goZ<3[1OnX_n/00onW_n_oZ;o[ojRoj`04ojRoj`OoYko[1OnX_nX5ojNoj`;oZ;o[
1_nX_nX5ojNoj`03ojRojonX_n[oZ;oZ00GoZ;oZ0onW_nX3ojS0j`[oZ;o[N?ooool01?l0003ooooo
ooooool00001ooooo`00Doooool00ol0003oooooooooo`0^ooooo`KoYko[4onW`>`3ojS0j`?oYl3/
1onX`>/2ojRoj`CoZ<3[1_nX_n/3ojNoj`?oZ<3[1_nX_nX00onW_n_oZ;o[ojRoj`04ojRoj`KoZ;oZ
00?oYko[ojRojonX_n/00onX_n/5ojRojPSoZ<3[1OnX_n]mooooo`03o`000?oooooo0000007ooooo
001Dooooo`03o`000?oooooooooo02kooooo1_nW_n/IojO0k0GoZ<3[00?oYl3/ojS0jonX`>/01OnX
`>/3ojRoj`WoZ<3[0onX_nX4ojS0j`KoZ;o[0onX_nX3ojS0j`KoZ;o[00?oZ;oZojS0jonX`>/02_nX
`>/00onX_n_oooooooooo`1nooooo`03o`000?oooooo0000007ooooo001Eooooo`03o`000?oooooo
oooo02kooooo1_nW_n/3ojO0k0CoYko[4_nW`>`00onX`>_oYl3/ojO0k003ojO0k0GoZ<3[0_nW`>`:
ojS0j`;oYl3[1onX`>/3ojRoj`;oYl3[1onX`>/3ojRoj`CoYl3[2OnX`>^4ooooo`7o00000Oooool1
o`000000E_ooool2o`0002oooooo0onW_n/3ojS0j`OoYko[0_nW`>`4ojNoja;oYl3/00?oZ<3[ojO0
k?nW`>`01?nW`>`7ojS0j`GoYl3[1OnX`>/2ojO0k0GoYl3[1OnX`>/2ojO0k0OoYl3[0onX`>^:oooo
o`;o0000001Hooooo`03o`000?oooooooooo02gooooo1_nX`>/5ojNoj`;oZ;o[1_nW_n/3ojO0k0?o
Yko[4onW`>`3ojS0j`?oYl7/1_nW`>/00onX`>_oYl3/ojO0k004ojO0k0GoYl3[00?oZ<3[ojO0k?nW
`>`01?nW`>`5ojO0jhgooooo0ol0000005Wooooo00?o0000ooooooooool0;Oooool6ojS0j`03ojNo
jonX_n_oZ;o[00CoZ;o[1?nW_n/2ojRoj`KoYko[1OnW`>`00onW_n_oYl3/ojO0k00;ojO0k0KoYl7/
0onW`>/4ojO1k0KoYl3/0_nW`>/4ojO1k0KoYl3/00?oYl3[ooooooooool0R_ooool4o`0000?ooooo
001Jooooo`03o`000?oooooooooo02gooooo1onX`>/6ojRoj`03ojNojonX_n_oZ;o[00?oZ;o[1_nW
_n/00onW`>coYko[ojNoj`03ojNoj`GoYl3/0_nW_n/6ojO0k0CoYl7/0_nW`>`7ojO1k0KoYl3/1_nW
`N`3ojO0k8cooooo0ol00007ooooo`00Foooool00ol0003oooooooooo`0]ooooo`OoZ<3[0onX_n/3
ojS0j`KoZ;o[0onW_n/4ojRoj`GoYko[00?oYl3/ojNojonW_n/01?nW_n/6ojO0k003ojO1k?nW`>co
Yl3/00?oYl3/1OnW`N`00onW`>_oYl3/ojO0k005ojO0k0?oYl7/SOooool4o`0000[ooooo001Loooo
o`;o0000;_ooool5ojS0j`;oYl3[1_nX`>/3ojRoj`CoZ<3[1_nX_n/2ojNoj`CoZ;o[1_nW_n/3ojO0
k0?oYko[1_nW`>`00onW`NcoYl3[ojO0j`03ojO0j`GoYl3/SOooool4o`0000kooooo001Nooooo`03
o`000?oooooooooo02cooooo00?oZ<3[ojO0jonW`>/01?nW`>/=ojS0j`?oZ;o[0_nX`>/7ojRoj`?o
Yko[0onX_n/6ojNoj`?oYl3/1?nW_n/5ojO0j`03ojO0k?oooooooooo08[ooooo1?l0000Booooo`00
Goooool00ol0003oooooooooo`0]ooooo`KoYl3[4_nX`>/5ojRoj`;oZ<3[1_nX_n/3ojNoj`?oZ;o[
1onW_n/2ojO0jh_ooooo1?l0000Fooooo`00H?ooool00ol0003oooooooooo`0]ooooo`?oYl3[1?nW
`>`AojS0j`03ojRojonX`>_oZ<3[00CoZ<3[1?nX_n/2ojS0j`KoZ;o[1OnW_n^;ooooo`?o00006_oo
ool0067ooooo0_l0000_ooooo`KoYl3/0_nX`>/4ojO0k1;oZ<3[00?oZ;o[ojS0jonX`>/00onX`>/6
ojRoj`03ojNojooooooooooo08Sooooo1?l0000Mooooo`00Hoooool00ol0003oooooooooo`0]oooo
o`coYl3/0onX`>/3ojO0k0WoZ<3[0onW`>/6ojS0j`?oZ;o[ROooool4o`00027ooooo001Tooooo`03
o`000?oooooooooo02gooooo4_nW`>`3ojS0j`CoYl3/1OnW`>/3ojS0jh[ooooo1?l0000Uooooo`00
IOooool00ol0003oooooooooo`0]oooooaWoYl3/0_nW`>^;ooooo`Co0000:Oooool006Kooooo0_l0
000^ooooo`;oYl3/1?nW_n/AojO0k8_ooooo0ol0000]ooooo`00J?ooool00ol0003oooooooooo`0/
ooooo`KoYko[0onW`>`3ojNoj`OoYl3/R_ooool4o`00033ooooo001Yooooo`03o`000?oooooooooo
02cooooo0onW_n/4ojRoj`GoYko[0onW`>b9ooooo`Co0000=?ooool006[ooooo00?o0000oooooooo
ool0;?ooool7ojRoj`;oYko[R_ooool4o`0003Sooooo001[ooooo`;o0000;Oooool5ojRojhWooooo
1?l0000looooo`00KOooool00ol0003oooooooooo`0[ooooo`03ojRojooooooooooo08Oooooo0ol0
0010ooooo`00K_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo08?ooooo1?l00013
ooooo`00Koooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo07oooooo1?l00017oooo
o`00L?ooool2o`0002Wooooo00?o0000ooooooooool0Noooool4o`0004_ooooo001booooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool0Moooool4o`0004oooooo001cooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0M?ooool3o`0005?ooooo001dooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool0L?ooool4o`0005Kooooo001eooooo`03o`000?oooooooooo
02?ooooo00?o0000ooooooooool0K?ooool4o`0005[ooooo001fooooo`;o00008oooool00ol0003o
ooooooooo`1Xooooo`Co0000G_ooool007Sooooo00?o0000ooooooooool08?ooool00ol0003ooooo
ooooo`1Tooooo`Co0000H_ooool007Wooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`1Qooooo`?o0000I_ooool007[ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1M
ooooo`Co0000JOooool007_ooooo0_l0000Nooooo`03o`000?oooooooooo05Wooooo1?l0001]oooo
o`00OOooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo05Gooooo1?l0001aooooo`00
O_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo057ooooo1?l0001eooooo`00Oooo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04kooooo0ol0001iooooo`00P?ooool2
o`0001Wooooo00?o0000ooooooooool0B_ooool4o`0007cooooo0022ooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool0A_ooool4o`00083ooooo0023ooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool0@_ooool4o`0008Cooooo0024ooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool0?_ooool4o`0008Sooooo0025ooooo`;o00004oooool00ol0003ooooooooo
o`0looooo`?o0000S?ooool008Oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0h
ooooo`Co0000Soooool008Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0doooo
o`Co0000Toooool008Wooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0`ooooo`Co
0000Uoooool008[ooooo0_l0000>ooooo`03o`000?oooooooooo02cooooo1?l0002Kooooo`00S?oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Wooooo0ol0002Oooooo`00SOooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Gooooo1?l0002Rooooo`00S_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo027ooooo1?l0002Vooooo`00Soooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo01gooooo1?l0002Zooooo`00T?ooool2o`0000Sooooo
00?o0000ooooooooool06Oooool4o`000:kooooo002Booooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool05_ooool3o`000;;ooooo002Cooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool04_ooool4o`000;Gooooo002Dooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool03_ooool4o`000;Wooooo002Eooooo`;o00000oooool00ol0003oooooooooo`0:ooooo`Co
0000_Oooool009Oooooo00Co0000oooooooooooo00002?ooool4o`000<7ooooo002Hooooo`03o`00
0?oooooo000000Gooooo0ol00035ooooo`00VOooool2o`000003ooooool0003o000000;o0000b?oo
ool009[ooooo0_l0003<ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0538698, 0.0432538, \
0.0035044, 0.0035044}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[.12586 .2075 -12 -8.99448 ]
[.12586 .2075 0 .00552 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.56094 .0364 -5.16972 -9 ]
[.56094 .0364 .83028 0 ]
[.75679 .08071 0 -6.17777 ]
[.75679 .08071 12 2.82223 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.9429 .3657 0 -5.9083 ]
[.9429 .3657 6 3.0917 ]
[.02494 .25992 -18 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.01611 .31527 -18 -2.78472 ]
[.01611 .31527 0 6.21528 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00254 .43215 -12 -2.88407 ]
[-0.00254 .43215 0 6.11593 ]
[-0.0124 .49393 -12 -2.93688 ]
[-0.0124 .49393 0 6.06312 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
[(-2)] .12586 .2075 1 .99877 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.56863 .04703 m
.57247 .05235 L
s
[(2)] .56094 .0364 .72324 1 Mshowa
.125 Mabswid
.18558 .19702 m
.18832 .19985 L
s
.23703 .17687 m
.23971 .17975 L
s
.28951 .15632 m
.29214 .15925 L
s
.39772 .11395 m
.40023 .11699 L
s
.4535 .09211 m
.45595 .0952 L
s
.51046 .06981 m
.51284 .07294 L
s
.08568 .23614 m
.08851 .23887 L
s
.62804 .02377 m
.63027 .02701 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.7445 .0853 m
.73835 .08759 L
s
[(-2)] .75679 .08071 -1 .37284 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.93037 .36962 m
.92411 .37158 L
s
[(2)] .9429 .3657 -1 .31296 Mshowa
.125 Mabswid
.7708 .12553 m
.7671 .12688 L
s
.79613 .16428 m
.79242 .1656 L
s
.82054 .20161 m
.81682 .20291 L
s
.86679 .27235 m
.86305 .2736 L
s
.88871 .30589 m
.88497 .30711 L
s
.9099 .3383 m
.90615 .3395 L
s
.71716 .04348 m
.71349 .04489 L
s
.95018 .39992 m
.94642 .40107 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(-20)] .02494 .25992 1 -0.39157 Mshowa
.02837 .31059 m
.0345 .30825 L
s
[(-10)] .01611 .31527 1 -0.38117 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.00981 .42772 m
.01599 .4255 L
s
[(10)] -0.00254 .43215 1 -0.3591 Mshowa
0 .48963 m
.0062 .48748 L
s
[(20)] -0.0124 .49393 1 -0.34736 Mshowa
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.655 .752 .921 r
.39362 .69481 .40169 .70183 .4152 .69804 .40717 .69099 Mtetra
.656 .752 .921 r
.40717 .69099 .4152 .69804 .42878 .69424 .42079 .68712 Mtetra
.657 .751 .92 r
.42079 .68712 .42878 .69424 .44242 .69039 .43448 .68321 Mtetra
.656 .751 .919 r
.43448 .68321 .44242 .69039 .45614 .6865 .44824 .67928 Mtetra
.656 .751 .92 r
.44824 .67928 .45614 .6865 .46992 .68259 .46207 .67535 Mtetra
.655 .751 .92 r
.46207 .67535 .46992 .68259 .48378 .67868 .47597 .67144 Mtetra
.655 .752 .921 r
.47597 .67144 .48378 .67868 .4977 .67476 .48994 .66751 Mtetra
.655 .753 .921 r
.48994 .66751 .4977 .67476 .5117 .67085 .50398 .66354 Mtetra
.656 .752 .921 r
.50398 .66354 .5117 .67085 .52577 .66691 .5181 .65952 Mtetra
.656 .751 .92 r
.5181 .65952 .52577 .66691 .53991 .66292 .53229 .65547 Mtetra
.657 .751 .919 r
.53229 .65547 .53991 .66292 .55412 .6589 .54655 .6514 Mtetra
.656 .75 .919 r
.54655 .6514 .55412 .6589 .56841 .65486 .56088 .64731 Mtetra
.56088 .64731 .56841 .65486 .58277 .65079 .57529 .64322 Mtetra
.656 .75 .92 r
.57529 .64322 .58277 .65079 .59721 .6467 .58978 .63912 Mtetra
.655 .751 .92 r
.58978 .63912 .59721 .6467 .61172 .6426 .60434 .63501 Mtetra
.655 .752 .921 r
.60434 .63501 .61172 .6426 .6263 .63848 .61898 .63087 Mtetra
.61898 .63087 .6263 .63848 .64097 .63434 .63369 .62671 Mtetra
.655 .753 .922 r
.63369 .62671 .64097 .63434 .6557 .63018 .64849 .62252 Mtetra
.64849 .62252 .6557 .63018 .67052 .626 .66336 .61831 Mtetra
.656 .753 .922 r
.66336 .61831 .67052 .626 .68542 .6218 .67831 .61407 Mtetra
.67831 .61407 .68542 .6218 .70039 .61758 .69334 .6098 Mtetra
.69334 .6098 .70039 .61758 .71545 .61334 .70845 .60551 Mtetra
.656 .753 .921 r
.70845 .60551 .71545 .61334 .73058 .60908 .72364 .60118 Mtetra
.72364 .60118 .73058 .60908 .7458 .60479 .73891 .59683 Mtetra
.656 .752 .92 r
.73891 .59683 .7458 .60479 .76109 .60049 .75426 .59246 Mtetra
.656 .751 .92 r
.75426 .59246 .76109 .60049 .77647 .59618 .76969 .58807 Mtetra
.656 .75 .919 r
.76969 .58807 .77647 .59618 .79193 .59184 .78521 .58368 Mtetra
.655 .75 .919 r
.78521 .58368 .79193 .59184 .80748 .58747 .80082 .57927 Mtetra
.655 .75 .92 r
.80082 .57927 .80748 .58747 .82311 .58308 .81651 .57485 Mtetra
.81651 .57485 .82311 .58308 .83882 .57865 .83229 .57039 Mtetra
.655 .751 .92 r
.83229 .57039 .83882 .57865 .85462 .57417 .84815 .56591 Mtetra
.656 .752 .921 r
.84815 .56591 .85462 .57417 .8705 .56966 .86409 .56138 Mtetra
.657 .753 .921 r
.86409 .56138 .8705 .56966 .88647 .56514 .88012 .55679 Mtetra
.656 .752 .921 r
.88012 .55679 .88647 .56514 .90253 .56062 .89624 .55219 Mtetra
.656 .751 .92 r
.89624 .55219 .90253 .56062 .91868 .55609 .91246 .5476 Mtetra
.655 .75 .92 r
.91246 .5476 .91868 .55609 .93492 .55154 .92876 .54299 Mtetra
.92876 .54299 .93492 .55154 .95124 .54694 .94516 .53837 Mtetra
.656 .751 .92 r
.94516 .53837 .95124 .54694 .96766 .54229 .96164 .5337 Mtetra
.656 .752 .921 r
.96164 .5337 .96766 .54229 .98416 .53761 .97821 .52897 Mtetra
.38547 .68772 .39362 .69481 .40717 .69099 .39906 .68383 Mtetra
.657 .751 .92 r
.39906 .68383 .40717 .69099 .42079 .68712 .41273 .67991 Mtetra
.656 .751 .919 r
.41273 .67991 .42079 .68712 .43448 .68321 .42646 .67596 Mtetra
.656 .751 .92 r
.42646 .67596 .43448 .68321 .44824 .67928 .44026 .67202 Mtetra
.655 .751 .921 r
.44026 .67202 .44824 .67928 .46207 .67535 .45414 .6681 Mtetra
.655 .752 .921 r
.45414 .6681 .46207 .67535 .47597 .67144 .46808 .66415 Mtetra
.656 .753 .921 r
.46808 .66415 .47597 .67144 .48994 .66751 .4821 .66014 Mtetra
.656 .752 .92 r
.4821 .66014 .48994 .66751 .50398 .66354 .49619 .6561 Mtetra
.657 .751 .919 r
.49619 .6561 .50398 .66354 .5181 .65952 .51035 .65203 Mtetra
.657 .75 .919 r
.51035 .65203 .5181 .65952 .53229 .65547 .52459 .64794 Mtetra
.656 .75 .919 r
.52459 .64794 .53229 .65547 .54655 .6514 .5389 .64385 Mtetra
.655 .75 .92 r
.5389 .64385 .54655 .6514 .56088 .64731 .55328 .63977 Mtetra
.655 .752 .921 r
.55328 .63977 .56088 .64731 .57529 .64322 .56775 .63567 Mtetra
.655 .753 .922 r
.56775 .63567 .57529 .64322 .58978 .63912 .58228 .63155 Mtetra
.58228 .63155 .58978 .63912 .60434 .63501 .59689 .62739 Mtetra
.656 .753 .922 r
.59689 .62739 .60434 .63501 .61898 .63087 .61158 .62321 Mtetra
.656 .753 .921 r
.61158 .62321 .61898 .63087 .63369 .62671 .62635 .61899 Mtetra
.62635 .61899 .63369 .62671 .64849 .62252 .6412 .61475 Mtetra
.656 .752 .921 r
.6412 .61475 .64849 .62252 .66336 .61831 .65612 .61049 Mtetra
.65612 .61049 .66336 .61831 .67831 .61407 .67113 .60621 Mtetra
.67113 .60621 .67831 .61407 .69334 .6098 .68621 .6019 Mtetra
.68621 .6019 .69334 .6098 .70845 .60551 .70138 .59758 Mtetra
.656 .753 .921 r
.70138 .59758 .70845 .60551 .72364 .60118 .71662 .59322 Mtetra
.71662 .59322 .72364 .60118 .73891 .59683 .73195 .58885 Mtetra
.656 .753 .922 r
.73195 .58885 .73891 .59683 .75426 .59246 .74736 .58443 Mtetra
.656 .754 .922 r
.74736 .58443 .75426 .59246 .76969 .58807 .76285 .57998 Mtetra
.656 .753 .921 r
.76285 .57998 .76969 .58807 .78521 .58368 .77843 .57551 Mtetra
.657 .752 .92 r
.77843 .57551 .78521 .58368 .80082 .57927 .79409 .571 Mtetra
.656 .751 .92 r
.79409 .571 .80082 .57927 .81651 .57485 .80984 .56652 Mtetra
.655 .75 .919 r
.80984 .56652 .81651 .57485 .83229 .57039 .82568 .56202 Mtetra
.655 .75 .92 r
.82568 .56202 .83229 .57039 .84815 .56591 .8416 .55751 Mtetra
.8416 .55751 .84815 .56591 .86409 .56138 .85762 .55296 Mtetra
.656 .751 .92 r
.85762 .55296 .86409 .56138 .88012 .55679 .87372 .54837 Mtetra
.657 .753 .921 r
.87372 .54837 .88012 .55679 .89624 .55219 .8899 .54372 Mtetra
.8899 .54372 .89624 .55219 .91246 .5476 .90617 .53903 Mtetra
.656 .751 .92 r
.90617 .53903 .91246 .5476 .92876 .54299 .92254 .53437 Mtetra
.655 .751 .92 r
.92254 .53437 .92876 .54299 .94516 .53837 .939 .52969 Mtetra
.655 .75 .92 r
.939 .52969 .94516 .53837 .96164 .5337 .95556 .52499 Mtetra
.656 .751 .92 r
.95556 .52499 .96164 .5337 .97821 .52897 .9722 .52025 Mtetra
.657 .751 .92 r
.37724 .68054 .38547 .68772 .39906 .68383 .39088 .67659 Mtetra
.657 .751 .919 r
.39088 .67659 .39906 .68383 .41273 .67991 .40459 .67263 Mtetra
.656 .751 .92 r
.40459 .67263 .41273 .67991 .42646 .67596 .41837 .66867 Mtetra
.655 .751 .921 r
.41837 .66867 .42646 .67596 .44026 .67202 .43221 .66474 Mtetra
.655 .752 .921 r
.43221 .66474 .44026 .67202 .45414 .6681 .44613 .66077 Mtetra
.656 .752 .921 r
.44613 .66077 .45414 .6681 .46808 .66415 .46012 .65674 Mtetra
.657 .751 .92 r
.46012 .65674 .46808 .66415 .4821 .66014 .47419 .65267 Mtetra
.657 .751 .919 r
.47419 .65267 .4821 .66014 .49619 .6561 .48832 .64857 Mtetra
.656 .75 .919 r
.48832 .64857 .49619 .6561 .51035 .65203 .50254 .64447 Mtetra
.655 .75 .92 r
.50254 .64447 .51035 .65203 .52459 .64794 .51682 .6404 Mtetra
.655 .752 .921 r
.51682 .6404 .52459 .64794 .5389 .64385 .53118 .63632 Mtetra
.655 .753 .922 r
.53118 .63632 .5389 .64385 .55328 .63977 .54561 .6322 Mtetra
.54561 .6322 .55328 .63977 .56775 .63567 .56012 .62804 Mtetra
.656 .753 .921 r
.56012 .62804 .56775 .63567 .58228 .63155 .57471 .62385 Mtetra
.656 .752 .92 r
.57471 .62385 .58228 .63155 .59689 .62739 .58937 .61963 Mtetra
.656 .751 .92 r
.58937 .61963 .59689 .62739 .61158 .62321 .60412 .61538 Mtetra
.60412 .61538 .61158 .62321 .62635 .61899 .61893 .6111 Mtetra
.656 .75 .919 r
.61893 .6111 .62635 .61899 .6412 .61475 .63383 .60681 Mtetra
.63383 .60681 .6412 .61475 .65612 .61049 .64881 .6025 Mtetra
.64881 .6025 .65612 .61049 .67113 .60621 .66387 .59818 Mtetra
.66387 .59818 .67113 .60621 .68621 .6019 .67901 .59384 Mtetra
.67901 .59384 .68621 .6019 .70138 .59758 .69423 .58948 Mtetra
.655 .75 .92 r
.69423 .58948 .70138 .59758 .71662 .59322 .70953 .5851 Mtetra
.655 .751 .92 r
.70953 .5851 .71662 .59322 .73195 .58885 .72492 .5807 Mtetra
.656 .751 .92 r
.72492 .5807 .73195 .58885 .74736 .58443 .74039 .57626 Mtetra
.656 .752 .921 r
.74039 .57626 .74736 .58443 .76285 .57998 .75595 .5718 Mtetra
.656 .753 .921 r
.75595 .5718 .76285 .57998 .77843 .57551 .77158 .5673 Mtetra
.656 .754 .921 r
.77158 .5673 .77843 .57551 .79409 .571 .78731 .56276 Mtetra
.657 .754 .921 r
.78731 .56276 .79409 .571 .80984 .56652 .80311 .55817 Mtetra
.657 .752 .92 r
.80311 .55817 .80984 .56652 .82568 .56202 .81901 .55358 Mtetra
.655 .75 .92 r
.81901 .55358 .82568 .56202 .8416 .55751 .83499 .549 Mtetra
.83499 .549 .8416 .55751 .85762 .55296 .85107 .54442 Mtetra
.85107 .54442 .85762 .55296 .87372 .54837 .86724 .53981 Mtetra
.655 .751 .92 r
.86724 .53981 .87372 .54837 .8899 .54372 .88349 .53516 Mtetra
.656 .753 .921 r
.88349 .53516 .8899 .54372 .90617 .53903 .89983 .53043 Mtetra
.657 .753 .921 r
.89983 .53043 .90617 .53903 .92254 .53437 .91626 .52567 Mtetra
.656 .751 .92 r
.91626 .52567 .92254 .53437 .939 .52969 .93279 .52092 Mtetra
.655 .751 .92 r
.93279 .52092 .939 .52969 .95556 .52499 .94941 .51618 Mtetra
.655 .75 .92 r
.94941 .51618 .95556 .52499 .9722 .52025 .96613 .51141 Mtetra
.657 .751 .919 r
.36894 .67327 .37724 .68054 .39088 .67659 .38262 .66929 Mtetra
.656 .751 .92 r
.38262 .66929 .39088 .67659 .40459 .67263 .39637 .66531 Mtetra
.655 .751 .921 r
.39637 .66531 .40459 .67263 .41837 .66867 .41019 .66136 Mtetra
.655 .752 .921 r
.41019 .66136 .41837 .66867 .43221 .66474 .42409 .65737 Mtetra
.656 .752 .921 r
.42409 .65737 .43221 .66474 .44613 .66077 .43805 .65332 Mtetra
.657 .751 .92 r
.43805 .65332 .44613 .66077 .46012 .65674 .45209 .64923 Mtetra
.657 .751 .919 r
.45209 .64923 .46012 .65674 .47419 .65267 .4662 .64511 Mtetra
.656 .75 .919 r
.4662 .64511 .47419 .65267 .48832 .64857 .48038 .64102 Mtetra
.654 .751 .921 r
.48038 .64102 .48832 .64857 .50254 .64447 .49464 .63694 Mtetra
.654 .753 .922 r
.49464 .63694 .50254 .64447 .51682 .6404 .50897 .63284 Mtetra
.655 .753 .922 r
.50897 .63284 .51682 .6404 .53118 .63632 .52338 .62868 Mtetra
.656 .752 .921 r
.52338 .62868 .53118 .63632 .54561 .6322 .53787 .62449 Mtetra
.656 .751 .92 r
.53787 .62449 .54561 .6322 .56012 .62804 .55243 .62026 Mtetra
.657 .751 .919 r
.55243 .62026 .56012 .62804 .57471 .62385 .56706 .61599 Mtetra
.657 .75 .919 r
.56706 .61599 .57471 .62385 .58937 .61963 .58178 .6117 Mtetra
.657 .749 .918 r
.58178 .6117 .58937 .61963 .60412 .61538 .59657 .6074 Mtetra
.656 .749 .918 r
.59657 .6074 .60412 .61538 .61893 .6111 .61144 .60309 Mtetra
.61144 .60309 .61893 .6111 .63383 .60681 .6264 .59877 Mtetra
.656 .749 .919 r
.6264 .59877 .63383 .60681 .64881 .6025 .64143 .59443 Mtetra
.656 .75 .919 r
.64143 .59443 .64881 .6025 .66387 .59818 .65654 .59006 Mtetra
.65654 .59006 .66387 .59818 .67901 .59384 .67174 .58566 Mtetra
.656 .749 .919 r
.67174 .58566 .67901 .59384 .69423 .58948 .68701 .58125 Mtetra
.68701 .58125 .69423 .58948 .70953 .5851 .70237 .57683 Mtetra
.655 .749 .919 r
.70237 .57683 .70953 .5851 .72492 .5807 .71782 .57238 Mtetra
.71782 .57238 .72492 .5807 .74039 .57626 .73335 .56793 Mtetra
.73335 .56793 .74039 .57626 .75595 .5718 .74896 .56346 Mtetra
.655 .75 .92 r
.74896 .56346 .75595 .5718 .77158 .5673 .76466 .55894 Mtetra
.656 .751 .92 r
.76466 .55894 .77158 .5673 .78731 .56276 .78045 .55439 Mtetra
.656 .752 .921 r
.78045 .55439 .78731 .56276 .80311 .55817 .79632 .5498 Mtetra
.657 .754 .921 r
.79632 .5498 .80311 .55817 .81901 .55358 .81228 .54514 Mtetra
.657 .753 .921 r
.81228 .54514 .81901 .55358 .83499 .549 .82832 .54045 Mtetra
.656 .751 .92 r
.82832 .54045 .83499 .549 .85107 .54442 .84446 .53579 Mtetra
.655 .75 .92 r
.84446 .53579 .85107 .54442 .86724 .53981 .86069 .53113 Mtetra
.86069 .53113 .86724 .53981 .88349 .53516 .87701 .52645 Mtetra
.655 .751 .92 r
.87701 .52645 .88349 .53516 .89983 .53043 .89342 .52173 Mtetra
.656 .752 .921 r
.89342 .52173 .89983 .53043 .91626 .52567 .90992 .51693 Mtetra
.657 .753 .921 r
.90992 .51693 .91626 .52567 .93279 .52092 .92651 .51209 Mtetra
.656 .751 .92 r
.92651 .51209 .93279 .52092 .94941 .51618 .9432 .50727 Mtetra
.655 .751 .92 r
.9432 .50727 .94941 .51618 .96613 .51141 .95999 .50245 Mtetra
.656 .751 .92 r
.36056 .66593 .36894 .67327 .38262 .66929 .37428 .66193 Mtetra
.655 .751 .921 r
.37428 .66193 .38262 .66929 .39637 .66531 .38808 .65795 Mtetra
.655 .752 .921 r
.38808 .65795 .39637 .66531 .41019 .66136 .40194 .65396 Mtetra
.656 .752 .921 r
.40194 .65396 .41019 .66136 .42409 .65737 .41588 .64988 Mtetra
.657 .751 .919 r
.41588 .64988 .42409 .65737 .43805 .65332 .42989 .64577 Mtetra
.42989 .64577 .43805 .65332 .45209 .64923 .44398 .64164 Mtetra
.655 .75 .92 r
.44398 .64164 .45209 .64923 .4662 .64511 .45813 .63754 Mtetra
.654 .751 .921 r
.45813 .63754 .4662 .64511 .48038 .64102 .47236 .63346 Mtetra
.655 .753 .922 r
.47236 .63346 .48038 .64102 .49464 .63694 .48667 .62933 Mtetra
.656 .753 .921 r
.48667 .62933 .49464 .63694 .50897 .63284 .50105 .62514 Mtetra
.657 .752 .92 r
.50105 .62514 .50897 .63284 .52338 .62868 .51551 .62091 Mtetra
.657 .751 .919 r
.51551 .62091 .52338 .62868 .53787 .62449 .53004 .61663 Mtetra
.657 .75 .918 r
.53004 .61663 .53787 .62449 .55243 .62026 .54465 .61234 Mtetra
.656 .749 .918 r
.54465 .61234 .55243 .62026 .56706 .61599 .55934 .60805 Mtetra
.655 .75 .919 r
.55934 .60805 .56706 .61599 .58178 .6117 .57411 .60379 Mtetra
.655 .751 .92 r
.57411 .60379 .58178 .6117 .59657 .6074 .58896 .5995 Mtetra
.655 .752 .921 r
.58896 .5995 .59657 .6074 .61144 .60309 .60388 .59518 Mtetra
.655 .753 .922 r
.60388 .59518 .61144 .60309 .6264 .59877 .61889 .59084 Mtetra
.655 .754 .922 r
.61889 .59084 .6264 .59877 .64143 .59443 .63398 .58646 Mtetra
.656 .754 .922 r
.63398 .58646 .64143 .59443 .65654 .59006 .64915 .58204 Mtetra
.64915 .58204 .65654 .59006 .67174 .58566 .6644 .5776 Mtetra
.6644 .5776 .67174 .58566 .68701 .58125 .67973 .57312 Mtetra
.67973 .57312 .68701 .58125 .70237 .57683 .69515 .56861 Mtetra
.656 .753 .921 r
.69515 .56861 .70237 .57683 .71782 .57238 .71065 .56407 Mtetra
.657 .752 .92 r
.71065 .56407 .71782 .57238 .73335 .56793 .72623 .55951 Mtetra
.656 .75 .919 r
.72623 .55951 .73335 .56793 .74896 .56346 .7419 .55497 Mtetra
.655 .749 .919 r
.7419 .55497 .74896 .56346 .76466 .55894 .75767 .55042 Mtetra
.75767 .55042 .76466 .55894 .78045 .55439 .77352 .54587 Mtetra
.655 .75 .92 r
.77352 .54587 .78045 .55439 .79632 .5498 .78945 .54126 Mtetra
.656 .751 .92 r
.78945 .54126 .79632 .5498 .81228 .54514 .80547 .53661 Mtetra
.656 .753 .921 r
.80547 .53661 .81228 .54514 .82832 .54045 .82158 .53189 Mtetra
.657 .754 .921 r
.82158 .53189 .82832 .54045 .84446 .53579 .83778 .52712 Mtetra
.656 .752 .92 r
.83778 .52712 .84446 .53579 .86069 .53113 .85407 .52237 Mtetra
.655 .75 .92 r
.85407 .52237 .86069 .53113 .87701 .52645 .87046 .51764 Mtetra
.87046 .51764 .87701 .52645 .89342 .52173 .88694 .51288 Mtetra
.655 .751 .92 r
.88694 .51288 .89342 .52173 .90992 .51693 .90351 .50808 Mtetra
.657 .752 .921 r
.90351 .50808 .90992 .51693 .92651 .51209 .92017 .5032 Mtetra
.657 .753 .921 r
.92017 .5032 .92651 .51209 .9432 .50727 .93693 .49829 Mtetra
.655 .751 .92 r
.93693 .49829 .9432 .50727 .95999 .50245 .95378 .4934 Mtetra
.3521 .65853 .36056 .66593 .37428 .66193 .36586 .65453 Mtetra
.654 .752 .921 r
.36586 .65453 .37428 .66193 .38808 .65795 .3797 .65053 Mtetra
.656 .752 .921 r
.3797 .65053 .38808 .65795 .40194 .65396 .39361 .64644 Mtetra
.657 .751 .92 r
.39361 .64644 .40194 .65396 .41588 .64988 .4076 .64231 Mtetra
.657 .751 .919 r
.4076 .64231 .41588 .64988 .42989 .64577 .42166 .63816 Mtetra
.655 .75 .92 r
.42166 .63816 .42989 .64577 .44398 .64164 .43578 .63405 Mtetra
.654 .751 .921 r
.43578 .63405 .44398 .64164 .45813 .63754 .44999 .62995 Mtetra
.655 .753 .922 r
.44999 .62995 .45813 .63754 .47236 .63346 .46427 .62579 Mtetra
.656 .752 .921 r
.46427 .62579 .47236 .63346 .48667 .62933 .47862 .62157 Mtetra
.657 .751 .919 r
.47862 .62157 .48667 .62933 .50105 .62514 .49305 .6173 Mtetra
.657 .75 .919 r
.49305 .6173 .50105 .62514 .51551 .62091 .50756 .613 Mtetra
.656 .749 .918 r
.50756 .613 .51551 .62091 .53004 .61663 .52214 .60872 Mtetra
.655 .75 .92 r
.52214 .60872 .53004 .61663 .54465 .61234 .53681 .60447 Mtetra
.654 .752 .922 r
.53681 .60447 .54465 .61234 .55934 .60805 .55155 .60021 Mtetra
.654 .754 .923 r
.55155 .60021 .55934 .60805 .57411 .60379 .56637 .59591 Mtetra
.655 .754 .923 r
.56637 .59591 .57411 .60379 .58896 .5995 .58127 .59157 Mtetra
.655 .754 .922 r
.58127 .59157 .58896 .5995 .60388 .59518 .59625 .58719 Mtetra
.59625 .58719 .60388 .59518 .61889 .59084 .61131 .58279 Mtetra
.656 .753 .922 r
.61131 .58279 .61889 .59084 .63398 .58646 .62645 .57836 Mtetra
.62645 .57836 .63398 .58646 .64915 .58204 .64167 .5739 Mtetra
.64167 .5739 .64915 .58204 .6644 .5776 .65698 .56942 Mtetra
.65698 .56942 .6644 .5776 .67973 .57312 .67237 .56491 Mtetra
.656 .754 .922 r
.67237 .56491 .67973 .57312 .69515 .56861 .68785 .56037 Mtetra
.68785 .56037 .69515 .56861 .71065 .56407 .70341 .5558 Mtetra
.657 .755 .922 r
.70341 .5558 .71065 .56407 .72623 .55951 .71905 .55118 Mtetra
.657 .754 .922 r
.71905 .55118 .72623 .55951 .7419 .55497 .73478 .54652 Mtetra
.657 .753 .921 r
.73478 .54652 .7419 .55497 .75767 .55042 .7506 .54185 Mtetra
.656 .75 .919 r
.7506 .54185 .75767 .55042 .77352 .54587 .76651 .5372 Mtetra
.655 .749 .919 r
.76651 .5372 .77352 .54587 .78945 .54126 .78251 .53258 Mtetra
.655 .749 .92 r
.78251 .53258 .78945 .54126 .80547 .53661 .7986 .52792 Mtetra
.655 .751 .92 r
.7986 .52792 .80547 .53661 .82158 .53189 .81477 .5232 Mtetra
.656 .752 .921 r
.81477 .5232 .82158 .53189 .83778 .52712 .83104 .51842 Mtetra
.657 .754 .921 r
.83104 .51842 .83778 .52712 .85407 .52237 .84739 .51357 Mtetra
.656 .752 .921 r
.84739 .51357 .85407 .52237 .87046 .51764 .86384 .50873 Mtetra
.655 .75 .92 r
.86384 .50873 .87046 .51764 .88694 .51288 .88039 .50393 Mtetra
.88039 .50393 .88694 .51288 .90351 .50808 .89703 .4991 Mtetra
.655 .751 .92 r
.89703 .4991 .90351 .50808 .92017 .5032 .91377 .49422 Mtetra
.657 .753 .921 r
.91377 .49422 .92017 .5032 .93693 .49829 .93059 .48924 Mtetra
.656 .752 .921 r
.93059 .48924 .93693 .49829 .95378 .4934 .94751 .48426 Mtetra
.654 .751 .921 r
.34355 .65109 .3521 .65853 .36586 .65453 .35736 .64707 Mtetra
.656 .752 .921 r
.35736 .64707 .36586 .65453 .3797 .65053 .37125 .64299 Mtetra
.657 .751 .92 r
.37125 .64299 .3797 .65053 .39361 .64644 .3852 .63884 Mtetra
.657 .751 .919 r
.3852 .63884 .39361 .64644 .4076 .64231 .39924 .63467 Mtetra
.655 .75 .92 r
.39924 .63467 .4076 .64231 .42166 .63816 .41334 .63052 Mtetra
.654 .751 .921 r
.41334 .63052 .42166 .63816 .43578 .63405 .42751 .62641 Mtetra
.655 .753 .922 r
.42751 .62641 .43578 .63405 .44999 .62995 .44176 .62223 Mtetra
.656 .752 .92 r
.44176 .62223 .44999 .62995 .46427 .62579 .45609 .61799 Mtetra
.658 .751 .919 r
.45609 .61799 .46427 .62579 .47862 .62157 .4705 .61369 Mtetra
.657 .75 .918 r
.4705 .61369 .47862 .62157 .49305 .6173 .48498 .60937 Mtetra
.655 .749 .919 r
.48498 .60937 .49305 .6173 .50756 .613 .49953 .60512 Mtetra
.654 .751 .921 r
.49953 .60512 .50756 .613 .52214 .60872 .51417 .60087 Mtetra
.654 .753 .923 r
.51417 .60087 .52214 .60872 .53681 .60447 .52888 .59659 Mtetra
.655 .754 .922 r
.52888 .59659 .53681 .60447 .55155 .60021 .54367 .59225 Mtetra
.656 .753 .922 r
.54367 .59225 .55155 .60021 .56637 .59591 .55854 .58788 Mtetra
.656 .752 .921 r
.55854 .58788 .56637 .59591 .58127 .59157 .5735 .58346 Mtetra
.657 .752 .92 r
.5735 .58346 .58127 .59157 .59625 .58719 .58853 .57898 Mtetra
.657 .75 .919 r
.58853 .57898 .59625 .58719 .61131 .58279 .60364 .5745 Mtetra
.656 .749 .918 r
.60364 .5745 .61131 .58279 .62645 .57836 .61884 .57 Mtetra
.61884 .57 .62645 .57836 .64167 .5739 .63412 .5655 Mtetra
.63412 .5655 .64167 .5739 .65698 .56942 .64949 .56099 Mtetra
.655 .749 .919 r
.64949 .56099 .65698 .56942 .67237 .56491 .66494 .55648 Mtetra
.655 .75 .92 r
.66494 .55648 .67237 .56491 .68785 .56037 .68047 .55195 Mtetra
.655 .751 .92 r
.68047 .55195 .68785 .56037 .70341 .5558 .69609 .54736 Mtetra
.656 .752 .921 r
.69609 .54736 .70341 .5558 .71905 .55118 .7118 .54273 Mtetra
.656 .753 .921 r
.7118 .54273 .71905 .55118 .73478 .54652 .72759 .53806 Mtetra
.657 .754 .922 r
.72759 .53806 .73478 .54652 .7506 .54185 .74347 .53333 Mtetra
.74347 .53333 .7506 .54185 .76651 .5372 .75943 .52856 Mtetra
.657 .752 .92 r
.75943 .52856 .76651 .5372 .78251 .53258 .77549 .52379 Mtetra
.655 .749 .919 r
.77549 .52379 .78251 .53258 .7986 .52792 .79164 .51909 Mtetra
.654 .749 .919 r
.79164 .51909 .7986 .52792 .81477 .5232 .80789 .51437 Mtetra
.655 .751 .92 r
.80789 .51437 .81477 .5232 .83104 .51842 .82422 .50958 Mtetra
.656 .752 .921 r
.82422 .50958 .83104 .51842 .84739 .51357 .84065 .50472 Mtetra
.657 .754 .921 r
.84065 .50472 .84739 .51357 .86384 .50873 .85716 .49979 Mtetra
.656 .752 .92 r
.85716 .49979 .86384 .50873 .88039 .50393 .87377 .49488 Mtetra
.655 .75 .92 r
.87377 .49488 .88039 .50393 .89703 .4991 .89048 .49001 Mtetra
.89048 .49001 .89703 .4991 .91377 .49422 .90729 .48509 Mtetra
.656 .751 .92 r
.90729 .48509 .91377 .49422 .93059 .48924 .92419 .48011 Mtetra
.657 .753 .921 r
.92419 .48011 .93059 .48924 .94751 .48426 .94118 .47505 Mtetra
.655 .752 .921 r
.33493 .6436 .34355 .65109 .35736 .64707 .34878 .63951 Mtetra
.657 .752 .92 r
.34878 .63951 .35736 .64707 .37125 .64299 .36271 .63536 Mtetra
.657 .751 .919 r
.36271 .63536 .37125 .64299 .3852 .63884 .37672 .63116 Mtetra
.656 .751 .92 r
.37672 .63116 .3852 .63884 .39924 .63467 .39079 .62698 Mtetra
.654 .751 .921 r
.39079 .62698 .39924 .63467 .41334 .63052 .40494 .62285 Mtetra
.655 .753 .922 r
.40494 .62285 .41334 .63052 .42751 .62641 .41916 .61867 Mtetra
.656 .752 .92 r
.41916 .61867 .42751 .62641 .44176 .62223 .43346 .61441 Mtetra
.658 .751 .919 r
.43346 .61441 .44176 .62223 .45609 .61799 .44784 .61007 Mtetra
.657 .75 .918 r
.44784 .61007 .45609 .61799 .4705 .61369 .46229 .60574 Mtetra
.654 .75 .92 r
.46229 .60574 .4705 .61369 .48498 .60937 .47682 .60149 Mtetra
.654 .752 .922 r
.47682 .60149 .48498 .60937 .49953 .60512 .49142 .59724 Mtetra
.655 .754 .923 r
.49142 .59724 .49953 .60512 .51417 .60087 .50611 .59292 Mtetra
.656 .753 .922 r
.50611 .59292 .51417 .60087 .52888 .59659 .52087 .58855 Mtetra
.657 .752 .92 r
.52087 .58855 .52888 .59659 .54367 .59225 .53572 .58409 Mtetra
.658 .751 .918 r
.53572 .58409 .54367 .59225 .55854 .58788 .55064 .57958 Mtetra
.658 .748 .917 r
.55064 .57958 .55854 .58788 .5735 .58346 .56565 .57507 Mtetra
.657 .747 .916 r
.56565 .57507 .5735 .58346 .58853 .57898 .58073 .57056 Mtetra
.656 .747 .917 r
.58073 .57056 .58853 .57898 .60364 .5745 .5959 .56606 Mtetra
.656 .748 .917 r
.5959 .56606 .60364 .5745 .61884 .57 .61116 .56155 Mtetra
.656 .748 .918 r
.61116 .56155 .61884 .57 .63412 .5655 .62649 .557 Mtetra
.62649 .557 .63412 .5655 .64949 .56099 .64191 .55242 Mtetra
.656 .748 .917 r
.64191 .55242 .64949 .56099 .66494 .55648 .65742 .54782 Mtetra
.655 .747 .917 r
.65742 .54782 .66494 .55648 .68047 .55195 .67301 .54324 Mtetra
.654 .746 .917 r
.67301 .54324 .68047 .55195 .69609 .54736 .68869 .53866 Mtetra
.654 .747 .918 r
.68869 .53866 .69609 .54736 .7118 .54273 .70446 .53407 Mtetra
.654 .749 .92 r
.70446 .53407 .7118 .54273 .72759 .53806 .72032 .52943 Mtetra
.656 .752 .921 r
.72032 .52943 .72759 .53806 .74347 .53333 .73626 .5247 Mtetra
.657 .753 .921 r
.73626 .5247 .74347 .53333 .75943 .52856 .75229 .51991 Mtetra
.658 .755 .922 r
.75229 .51991 .75943 .52856 .77549 .52379 .76841 .51505 Mtetra
.657 .753 .921 r
.76841 .51505 .77549 .52379 .79164 .51909 .78462 .51018 Mtetra
.655 .75 .92 r
.78462 .51018 .79164 .51909 .80789 .51437 .80093 .50539 Mtetra
.654 .749 .919 r
.80093 .50539 .80789 .51437 .82422 .50958 .81733 .50061 Mtetra
.655 .751 .92 r
.81733 .50061 .82422 .50958 .84065 .50472 .83383 .49574 Mtetra
.657 .752 .92 r
.83383 .49574 .84065 .50472 .85716 .49979 .85041 .49079 Mtetra
.657 .753 .921 r
.85041 .49079 .85716 .49979 .87377 .49488 .86708 .48578 Mtetra
.656 .751 .92 r
.86708 .48578 .87377 .49488 .89048 .49001 .88386 .48081 Mtetra
.655 .75 .92 r
.88386 .48081 .89048 .49001 .90729 .48509 .90074 .47586 Mtetra
.655 .751 .92 r
.90074 .47586 .90729 .48509 .92419 .48011 .91771 .47086 Mtetra
.656 .752 .92 r
.91771 .47086 .92419 .48011 .94118 .47505 .93478 .46577 Mtetra
.656 .752 .921 r
.32622 .63602 .33493 .6436 .34878 .63951 .34012 .63186 Mtetra
.657 .751 .919 r
.34012 .63186 .34878 .63951 .36271 .63536 .35409 .62765 Mtetra
.35409 .62765 .36271 .63536 .37672 .63116 .36814 .62342 Mtetra
.654 .751 .921 r
.36814 .62342 .37672 .63116 .39079 .62698 .38226 .61927 Mtetra
.654 .752 .922 r
.38226 .61927 .39079 .62698 .40494 .62285 .39646 .61508 Mtetra
.656 .752 .921 r
.39646 .61508 .40494 .62285 .41916 .61867 .41073 .61081 Mtetra
.658 .752 .919 r
.41073 .61081 .41916 .61867 .43346 .61441 .42508 .60646 Mtetra
.657 .75 .918 r
.42508 .60646 .43346 .61441 .44784 .61007 .4395 .6021 Mtetra
.654 .75 .92 r
.4395 .6021 .44784 .61007 .46229 .60574 .454 .59784 Mtetra
.653 .753 .922 r
.454 .59784 .46229 .60574 .47682 .60149 .46858 .59357 Mtetra
.655 .753 .922 r
.46858 .59357 .47682 .60149 .49142 .59724 .48324 .58923 Mtetra
.656 .753 .921 r
.48324 .58923 .49142 .59724 .50611 .59292 .49797 .5848 Mtetra
.659 .752 .919 r
.49797 .5848 .50611 .59292 .52087 .58855 .51279 .58026 Mtetra
.658 .749 .917 r
.51279 .58026 .52087 .58855 .53572 .58409 .52769 .57573 Mtetra
.656 .747 .917 r
.52769 .57573 .53572 .58409 .55064 .57958 .54266 .57127 Mtetra
.654 .749 .919 r
.54266 .57127 .55064 .57958 .56565 .57507 .55772 .56683 Mtetra
.654 .752 .921 r
.55772 .56683 .56565 .57507 .58073 .57056 .57287 .56236 Mtetra
.654 .754 .923 r
.57287 .56236 .58073 .57056 .5959 .56606 .58809 .55786 Mtetra
.655 .755 .924 r
.58809 .55786 .5959 .56606 .61116 .56155 .6034 .55331 Mtetra
.655 .756 .924 r
.6034 .55331 .61116 .56155 .62649 .557 .61879 .54872 Mtetra
.656 .756 .923 r
.61879 .54872 .62649 .557 .64191 .55242 .63427 .54408 Mtetra
.657 .756 .923 r
.63427 .54408 .64191 .55242 .65742 .54782 .64984 .53939 Mtetra
.657 .755 .922 r
.64984 .53939 .65742 .54782 .67301 .54324 .66548 .53467 Mtetra
.657 .753 .92 r
.66548 .53467 .67301 .54324 .68869 .53866 .68122 .52992 Mtetra
.656 .749 .919 r
.68122 .52992 .68869 .53866 .70446 .53407 .69705 .52519 Mtetra
.654 .746 .918 r
.69705 .52519 .70446 .53407 .72032 .52943 .71297 .52053 Mtetra
.653 .747 .919 r
.71297 .52053 .72032 .52943 .73626 .5247 .72898 .51588 Mtetra
.655 .751 .92 r
.72898 .51588 .73626 .5247 .75229 .51991 .74508 .5111 Mtetra
.656 .753 .921 r
.74508 .5111 .75229 .51991 .76841 .51505 .76126 .50624 Mtetra
.658 .754 .921 r
.76126 .50624 .76841 .51505 .78462 .51018 .77753 .5013 Mtetra
.77753 .5013 .78462 .51018 .80093 .50539 .7939 .49635 Mtetra
.654 .75 .92 r
.7939 .49635 .80093 .50539 .81733 .50061 .81037 .49149 Mtetra
.654 .749 .92 r
.81037 .49149 .81733 .50061 .83383 .49574 .82693 .48662 Mtetra
.655 .751 .92 r
.82693 .48662 .83383 .49574 .85041 .49079 .84359 .48167 Mtetra
.657 .753 .92 r
.84359 .48167 .85041 .49079 .86708 .48578 .86033 .47662 Mtetra
.657 .753 .921 r
.86033 .47662 .86708 .48578 .88386 .48081 .87717 .47153 Mtetra
.655 .751 .92 r
.87717 .47153 .88386 .48081 .90074 .47586 .89412 .46652 Mtetra
.655 .75 .92 r
.89412 .46652 .90074 .47586 .91771 .47086 .91117 .46148 Mtetra
.655 .751 .92 r
.91117 .46148 .91771 .47086 .93478 .46577 .92831 .45638 Mtetra
.657 .752 .92 r
.31743 .62835 .32622 .63602 .34012 .63186 .33137 .62413 Mtetra
.657 .751 .919 r
.33137 .62413 .34012 .63186 .35409 .62765 .34539 .61987 Mtetra
.655 .751 .92 r
.34539 .61987 .35409 .62765 .36814 .62342 .35948 .61566 Mtetra
.654 .752 .922 r
.35948 .61566 .36814 .62342 .38226 .61927 .37365 .61147 Mtetra
.656 .752 .921 r
.37365 .61147 .38226 .61927 .39646 .61508 .38789 .60719 Mtetra
.657 .752 .919 r
.38789 .60719 .39646 .61508 .41073 .61081 .40221 .60283 Mtetra
.658 .751 .918 r
.40221 .60283 .41073 .61081 .42508 .60646 .41661 .59844 Mtetra
.654 .75 .92 r
.41661 .59844 .42508 .60646 .4395 .6021 .43108 .59415 Mtetra
.653 .752 .922 r
.43108 .59415 .4395 .6021 .454 .59784 .44563 .58987 Mtetra
.655 .753 .922 r
.44563 .58987 .454 .59784 .46858 .59357 .46026 .58551 Mtetra
.657 .753 .92 r
.46026 .58551 .46858 .59357 .48324 .58923 .47497 .58103 Mtetra
.659 .751 .918 r
.47497 .58103 .48324 .58923 .49797 .5848 .48976 .57646 Mtetra
.657 .748 .917 r
.48976 .57646 .49797 .5848 .51279 .58026 .50462 .57194 Mtetra
.654 .748 .919 r
.50462 .57194 .51279 .58026 .52769 .57573 .51957 .56754 Mtetra
.653 .752 .923 r
.51957 .56754 .52769 .57573 .54266 .57127 .5346 .56312 Mtetra
.653 .755 .924 r
.5346 .56312 .54266 .57127 .55772 .56683 .54972 .55865 Mtetra
.654 .756 .924 r
.54972 .55865 .55772 .56683 .57287 .56236 .56492 .55414 Mtetra
.655 .756 .924 r
.56492 .55414 .57287 .56236 .58809 .55786 .5802 .54958 Mtetra
.5802 .54958 .58809 .55786 .6034 .55331 .59557 .54498 Mtetra
.655 .755 .923 r
.59557 .54498 .6034 .55331 .61879 .54872 .61102 .54034 Mtetra
.656 .756 .923 r
.61102 .54034 .61879 .54872 .63427 .54408 .62655 .53566 Mtetra
.62655 .53566 .63427 .54408 .64984 .53939 .64218 .53094 Mtetra
.657 .756 .923 r
.64218 .53094 .64984 .53939 .66548 .53467 .65789 .52617 Mtetra
.657 .757 .923 r
.65789 .52617 .66548 .53467 .68122 .52992 .67368 .52135 Mtetra
.658 .756 .923 r
.67368 .52135 .68122 .52992 .69705 .52519 .68956 .51648 Mtetra
.658 .754 .921 r
.68956 .51648 .69705 .52519 .71297 .52053 .70554 .5116 Mtetra
.655 .749 .919 r
.70554 .5116 .71297 .52053 .72898 .51588 .72161 .50682 Mtetra
.653 .746 .918 r
.72161 .50682 .72898 .51588 .74508 .5111 .73777 .50211 Mtetra
.654 .749 .92 r
.73777 .50211 .74508 .5111 .76126 .50624 .75403 .49729 Mtetra
.657 .752 .921 r
.75403 .49729 .76126 .50624 .77753 .5013 .77037 .49235 Mtetra
.658 .754 .921 r
.77037 .49235 .77753 .5013 .7939 .49635 .7868 .48732 Mtetra
.657 .754 .921 r
.7868 .48732 .7939 .49635 .81037 .49149 .80333 .48229 Mtetra
.654 .749 .92 r
.80333 .48229 .81037 .49149 .82693 .48662 .81996 .47738 Mtetra
.654 .75 .92 r
.81996 .47738 .82693 .48662 .84359 .48167 .83669 .47242 Mtetra
.656 .751 .92 r
.83669 .47242 .84359 .48167 .86033 .47662 .85351 .46736 Mtetra
.658 .753 .921 r
.85351 .46736 .86033 .47662 .87717 .47153 .87042 .46221 Mtetra
.656 .752 .921 r
.87042 .46221 .87717 .47153 .89412 .46652 .88743 .45708 Mtetra
.655 .75 .92 r
.88743 .45708 .89412 .46652 .91117 .46148 .90455 .45199 Mtetra
.655 .751 .92 r
.90455 .45199 .91117 .46148 .92831 .45638 .92177 .44685 Mtetra
.657 .751 .919 r
.30855 .62059 .31743 .62835 .33137 .62413 .32254 .61631 Mtetra
.32254 .61631 .33137 .62413 .34539 .61987 .33661 .61203 Mtetra
.654 .751 .921 r
.33661 .61203 .34539 .61987 .35948 .61566 .35074 .60783 Mtetra
.655 .752 .921 r
.35074 .60783 .35948 .61566 .37365 .61147 .36495 .60356 Mtetra
.657 .752 .92 r
.36495 .60356 .37365 .61147 .38789 .60719 .37924 .59921 Mtetra
.658 .751 .919 r
.37924 .59921 .38789 .60719 .40221 .60283 .39361 .59478 Mtetra
.655 .75 .919 r
.39361 .59478 .40221 .60283 .41661 .59844 .40806 .59043 Mtetra
.653 .752 .922 r
.40806 .59043 .41661 .59844 .43108 .59415 .42257 .58614 Mtetra
.654 .753 .922 r
.42257 .58614 .43108 .59415 .44563 .58987 .43717 .58177 Mtetra
.657 .753 .92 r
.43717 .58177 .44563 .58987 .46026 .58551 .45185 .57727 Mtetra
.66 .751 .918 r
.45185 .57727 .46026 .58551 .47497 .58103 .46662 .57266 Mtetra
.656 .748 .917 r
.46662 .57266 .47497 .58103 .48976 .57646 .48146 .56817 Mtetra
.653 .75 .921 r
.48146 .56817 .48976 .57646 .50462 .57194 .49637 .56377 Mtetra
.652 .754 .924 r
.49637 .56377 .50462 .57194 .51957 .56754 .51138 .55935 Mtetra
.653 .755 .924 r
.51138 .55935 .51957 .56754 .5346 .56312 .52646 .55487 Mtetra
.654 .755 .924 r
.52646 .55487 .5346 .56312 .54972 .55865 .54163 .55033 Mtetra
.659 .755 .921 r
.54163 .55033 .54972 .55865 .56492 .55414 .55688 .5456 Mtetra
.659 .751 .918 r
.55688 .5456 .56492 .55414 .5802 .54958 .57222 .54085 Mtetra
.657 .747 .916 r
.57222 .54085 .5802 .54958 .59557 .54498 .58764 .53615 Mtetra
.656 .746 .916 r
.58764 .53615 .59557 .54498 .61102 .54034 .60315 .53146 Mtetra
.655 .745 .916 r
.60315 .53146 .61102 .54034 .62655 .53566 .61874 .52679 Mtetra
.653 .746 .918 r
.61874 .52679 .62655 .53566 .64218 .53094 .63443 .52216 Mtetra
.653 .749 .92 r
.63443 .52216 .64218 .53094 .65789 .52617 .65021 .51752 Mtetra
.657 .755 .922 r
.65021 .51752 .65789 .52617 .67368 .52135 .66606 .51268 Mtetra
.658 .756 .922 r
.66606 .51268 .67368 .52135 .68956 .51648 .68201 .50778 Mtetra
.659 .757 .922 r
.68201 .50778 .68956 .51648 .70554 .5116 .69804 .50281 Mtetra
.659 .756 .922 r
.69804 .50281 .70554 .5116 .72161 .50682 .71417 .49782 Mtetra
.656 .751 .92 r
.71417 .49782 .72161 .50682 .73777 .50211 .73039 .49292 Mtetra
.652 .746 .919 r
.73039 .49292 .73777 .50211 .75403 .49729 .74672 .48814 Mtetra
.654 .749 .92 r
.74672 .48814 .75403 .49729 .77037 .49235 .76313 .48324 Mtetra
.657 .753 .921 r
.76313 .48324 .77037 .49235 .7868 .48732 .77963 .47821 Mtetra
.658 .754 .921 r
.77963 .47821 .7868 .48732 .80333 .48229 .79622 .47309 Mtetra
.656 .752 .921 r
.79622 .47309 .80333 .48229 .81996 .47738 .81291 .46802 Mtetra
.654 .749 .92 r
.81291 .46802 .81996 .47738 .83669 .47242 .82971 .46304 Mtetra
.655 .75 .92 r
.82971 .46304 .83669 .47242 .85351 .46736 .8466 .45797 Mtetra
.657 .752 .92 r
.8466 .45797 .85351 .46736 .87042 .46221 .86359 .4528 Mtetra
.658 .753 .921 r
.86359 .4528 .87042 .46221 .88743 .45708 .88067 .44756 Mtetra
.655 .751 .92 r
.88067 .44756 .88743 .45708 .90455 .45199 .89786 .44239 Mtetra
.655 .75 .92 r
.89786 .44239 .90455 .45199 .92177 .44685 .91515 .43722 Mtetra
.657 .751 .919 r
.29958 .61275 .30855 .62059 .32254 .61631 .31362 .60842 Mtetra
.655 .751 .92 r
.31362 .60842 .32254 .61631 .33661 .61203 .32773 .60415 Mtetra
.654 .752 .922 r
.32773 .60415 .33661 .61203 .35074 .60783 .34191 .59991 Mtetra
.656 .752 .921 r
.34191 .59991 .35074 .60783 .36495 .60356 .35617 .59556 Mtetra
.658 .752 .919 r
.35617 .59556 .36495 .60356 .37924 .59921 .37051 .59112 Mtetra
.657 .75 .919 r
.37051 .59112 .37924 .59921 .39361 .59478 .38493 .58669 Mtetra
.653 .75 .921 r
.38493 .58669 .39361 .59478 .40806 .59043 .39942 .58238 Mtetra
.654 .752 .922 r
.39942 .58238 .40806 .59043 .42257 .58614 .41398 .57801 Mtetra
.656 .752 .921 r
.41398 .57801 .42257 .58614 .43717 .58177 .42863 .57353 Mtetra
.66 .752 .918 r
.42863 .57353 .43717 .58177 .45185 .57727 .44337 .56888 Mtetra
.657 .748 .918 r
.44337 .56888 .45185 .57727 .46662 .57266 .45818 .56435 Mtetra
.652 .75 .922 r
.45818 .56435 .46662 .57266 .48146 .56817 .47307 .55996 Mtetra
.652 .754 .924 r
.47307 .55996 .48146 .56817 .49637 .56377 .48804 .55553 Mtetra
.653 .754 .924 r
.48804 .55553 .49637 .56377 .51138 .55935 .5031 .55103 Mtetra
.66 .756 .921 r
.5031 .55103 .51138 .55935 .52646 .55487 .51824 .54625 Mtetra
.66 .749 .916 r
.51824 .54625 .52646 .55487 .54163 .55033 .53346 .54148 Mtetra
.653 .743 .915 r
.53346 .54148 .54163 .55033 .55688 .5456 .54877 .53693 Mtetra
.649 .747 .921 r
.54877 .53693 .55688 .5456 .57222 .54085 .56416 .53252 Mtetra
.649 .757 .928 r
.56416 .53252 .57222 .54085 .58764 .53615 .57965 .52802 Mtetra
.655 .765 .93 r
.57965 .52802 .58764 .53615 .60315 .53146 .59522 .52329 Mtetra
.661 .767 .928 r
.59522 .52329 .60315 .53146 .61874 .52679 .61087 .51831 Mtetra
.663 .761 .923 r
.61087 .51831 .61874 .52679 .63443 .52216 .6266 .51324 Mtetra
.659 .75 .918 r
.6266 .51324 .63443 .52216 .65021 .51752 .64243 .50832 Mtetra
.653 .743 .916 r
.64243 .50832 .65021 .51752 .66606 .51268 .65835 .50362 Mtetra
.651 .746 .919 r
.65835 .50362 .66606 .51268 .68201 .50778 .67437 .49892 Mtetra
.658 .755 .922 r
.67437 .49892 .68201 .50778 .69804 .50281 .69047 .49394 Mtetra
.659 .756 .922 r
.69047 .49394 .69804 .50281 .71417 .49782 .70666 .48888 Mtetra
.70666 .48888 .71417 .49782 .73039 .49292 .72294 .48378 Mtetra
.655 .751 .92 r
.72294 .48378 .73039 .49292 .74672 .48814 .73932 .47882 Mtetra
.652 .747 .919 r
.73932 .47882 .74672 .48814 .76313 .48324 .75581 .47398 Mtetra
.655 .75 .92 r
.75581 .47398 .76313 .48324 .77963 .47821 .77238 .46896 Mtetra
.658 .753 .92 r
.77238 .46896 .77963 .47821 .79622 .47309 .78904 .46382 Mtetra
.658 .754 .921 r
.78904 .46382 .79622 .47309 .81291 .46802 .80579 .45862 Mtetra
.655 .751 .92 r
.80579 .45862 .81291 .46802 .82971 .46304 .82266 .45354 Mtetra
.654 .749 .92 r
.82266 .45354 .82971 .46304 .8466 .45797 .83963 .44845 Mtetra
.656 .751 .92 r
.83963 .44845 .8466 .45797 .86359 .4528 .85669 .44327 Mtetra
.658 .753 .92 r
.85669 .44327 .86359 .4528 .88067 .44756 .87384 .43797 Mtetra
.656 .752 .921 r
.87384 .43797 .88067 .44756 .89786 .44239 .8911 .4327 Mtetra
.655 .75 .92 r
.8911 .4327 .89786 .44239 .91515 .43722 .90847 .42747 Mtetra
.657 .751 .919 r
.29053 .60482 .29958 .61275 .31362 .60842 .30461 .60047 Mtetra
.654 .751 .921 r
.30461 .60047 .31362 .60842 .32773 .60415 .31876 .5962 Mtetra
.654 .752 .921 r
.31876 .5962 .32773 .60415 .34191 .59991 .33299 .59188 Mtetra
.657 .752 .92 r
.33299 .59188 .34191 .59991 .35617 .59556 .3473 .58747 Mtetra
.658 .751 .919 r
.3473 .58747 .35617 .59556 .37051 .59112 .36169 .58297 Mtetra
.655 .75 .92 r
.36169 .58297 .37051 .59112 .38493 .58669 .37615 .57858 Mtetra
.653 .752 .922 r
.37615 .57858 .38493 .58669 .39942 .58238 .39069 .57422 Mtetra
.655 .752 .921 r
.39069 .57422 .39942 .58238 .41398 .57801 .40531 .56977 Mtetra
.66 .753 .919 r
.40531 .56977 .41398 .57801 .42863 .57353 .42001 .56512 Mtetra
.659 .749 .917 r
.42001 .56512 .42863 .57353 .44337 .56888 .4348 .5605 Mtetra
.652 .749 .921 r
.4348 .5605 .44337 .56888 .45818 .56435 .44965 .55608 Mtetra
.651 .753 .924 r
.44965 .55608 .45818 .56435 .47307 .55996 .4646 .55166 Mtetra
.653 .754 .924 r
.4646 .55166 .47307 .55996 .48804 .55553 .47962 .54714 Mtetra
.663 .756 .919 r
.47962 .54714 .48804 .55553 .5031 .55103 .49473 .54224 Mtetra
.654 .745 .916 r
.49473 .54224 .5031 .55103 .51824 .54625 .50993 .53765 Mtetra
.635 .744 .927 r
.50993 .53765 .51824 .54625 .53346 .54148 .52521 .53372 Mtetra
.617 .761 .948 r
.52521 .53372 .53346 .54148 .54877 .53693 .54058 .53021 Mtetra
.607 .787 .967 r
.54058 .53021 .54877 .53693 .56416 .53252 .55605 .52667 Mtetra
.613 .816 .978 r
.55605 .52667 .56416 .53252 .57965 .52802 .57161 .52265 Mtetra
.634 .837 .979 r
.57161 .52265 .57965 .52802 .59522 .52329 .58725 .51787 Mtetra
.661 .845 .971 r
.58725 .51787 .59522 .52329 .61087 .51831 .60297 .51232 Mtetra
.679 .835 .958 r
.60297 .51232 .61087 .51831 .6266 .51324 .61875 .50629 Mtetra
.684 .81 .943 r
.61875 .50629 .6266 .51324 .64243 .50832 .63461 .50023 Mtetra
.674 .779 .929 r
.63461 .50023 .64243 .50832 .65835 .50362 .65057 .49457 Mtetra
.657 .751 .919 r
.65057 .49457 .65835 .50362 .67437 .49892 .66664 .48958 Mtetra
.649 .742 .918 r
.66664 .48958 .67437 .49892 .69047 .49394 .68282 .48491 Mtetra
.658 .754 .921 r
.68282 .48491 .69047 .49394 .70666 .48888 .69907 .47984 Mtetra
.659 .756 .921 r
.69907 .47984 .70666 .48888 .72294 .48378 .71541 .47468 Mtetra
.659 .755 .921 r
.71541 .47468 .72294 .48378 .73932 .47882 .73185 .4695 Mtetra
.653 .749 .92 r
.73185 .4695 .73932 .47882 .75581 .47398 .7484 .46453 Mtetra
.652 .747 .919 r
.7484 .46453 .75581 .47398 .77238 .46896 .76505 .45958 Mtetra
.656 .752 .92 r
.76505 .45958 .77238 .46896 .78904 .46382 .78178 .45443 Mtetra
.658 .754 .92 r
.78178 .45443 .78904 .46382 .80579 .45862 .7986 .44917 Mtetra
.657 .753 .921 r
.7986 .44917 .80579 .45862 .82266 .45354 .81553 .44394 Mtetra
.653 .749 .92 r
.81553 .44394 .82266 .45354 .83963 .44845 .83257 .43882 Mtetra
.655 .75 .92 r
.83257 .43882 .83963 .44845 .85669 .44327 .84971 .43361 Mtetra
.657 .752 .92 r
.84971 .43361 .85669 .44327 .87384 .43797 .86693 .42829 Mtetra
.657 .753 .92 r
.86693 .42829 .87384 .43797 .8911 .4327 .88426 .42291 Mtetra
.655 .751 .92 r
.88426 .42291 .8911 .4327 .90847 .42747 .9017 .41761 Mtetra
.656 .751 .92 r
.28139 .59683 .29053 .60482 .30461 .60047 .29552 .59246 Mtetra
.653 .751 .921 r
.29552 .59246 .30461 .60047 .31876 .5962 .30971 .58816 Mtetra
.655 .752 .921 r
.30971 .58816 .31876 .5962 .33299 .59188 .32399 .58377 Mtetra
.658 .752 .919 r
.32399 .58377 .33299 .59188 .3473 .58747 .33835 .57927 Mtetra
.658 .751 .919 r
.33835 .57927 .3473 .58747 .36169 .58297 .35278 .57476 Mtetra
.653 .75 .921 r
.35278 .57476 .36169 .58297 .37615 .57858 .36729 .57038 Mtetra
.654 .752 .922 r
.36729 .57038 .37615 .57858 .39069 .57422 .38187 .56596 Mtetra
.657 .752 .92 r
.38187 .56596 .39069 .57422 .40531 .56977 .39655 .56138 Mtetra
.661 .751 .917 r
.39655 .56138 .40531 .56977 .42001 .56512 .4113 .55665 Mtetra
.654 .749 .919 r
.4113 .55665 .42001 .56512 .4348 .5605 .42613 .55216 Mtetra
.651 .752 .924 r
.42613 .55216 .4348 .5605 .44965 .55608 .44104 .54773 Mtetra
.652 .753 .924 r
.44104 .54773 .44965 .55608 .4646 .55166 .45604 .54322 Mtetra
.663 .755 .919 r
.45604 .54322 .4646 .55166 .47962 .54714 .47112 .5383 Mtetra
.652 .744 .917 r
.47112 .5383 .47962 .54714 .49473 .54224 .48628 .53379 Mtetra
.615 .742 .937 r
.48628 .53379 .49473 .54224 .50993 .53765 .50152 .53047 Mtetra
.565 .76 .969 r
.50152 .53047 .50993 .53765 .52521 .53372 .51686 .52813 Mtetra
.466 .766 .996 r
.51686 .52813 .52521 .53372 .54058 .53021 .5323 .52704 Mtetra
.405 .806 .983 r
.5323 .52704 .54058 .53021 .55605 .52667 .54786 .52519 Mtetra
.401 .839 .944 r
.54786 .52519 .55605 .52667 .57161 .52265 .56353 .52195 Mtetra
.462 .881 .929 r
.56353 .52195 .57161 .52265 .58725 .51787 .57927 .51713 Mtetra
.563 .926 .941 r
.57927 .51713 .58725 .51787 .60297 .51232 .59506 .51073 Mtetra
.667 .948 .957 r
.59506 .51073 .60297 .51232 .61875 .50629 .6109 .50291 Mtetra
.731 .921 .956 r
.6109 .50291 .61875 .50629 .63461 .50023 .62678 .49432 Mtetra
.713 .85 .948 r
.62678 .49432 .63461 .50023 .65057 .49457 .64275 .48695 Mtetra
.69 .8 .933 r
.64275 .48695 .65057 .49457 .66664 .48958 .65884 .48059 Mtetra
.66 .757 .922 r
.65884 .48059 .66664 .48958 .68282 .48491 .67506 .47541 Mtetra
.649 .742 .918 r
.67506 .47541 .68282 .48491 .69907 .47984 .6914 .47065 Mtetra
.659 .754 .921 r
.6914 .47065 .69907 .47984 .71541 .47468 .70781 .46547 Mtetra
.66 .756 .921 r
.70781 .46547 .71541 .47468 .73185 .4695 .72431 .46021 Mtetra
.658 .754 .921 r
.72431 .46021 .73185 .4695 .7484 .46453 .74091 .455 Mtetra
.651 .747 .92 r
.74091 .455 .7484 .46453 .76505 .45958 .75763 .45003 Mtetra
.654 .749 .92 r
.75763 .45003 .76505 .45958 .78178 .45443 .77444 .44491 Mtetra
.658 .753 .92 r
.77444 .44491 .78178 .45443 .7986 .44917 .79134 .43962 Mtetra
.658 .754 .92 r
.79134 .43962 .7986 .44917 .81553 .44394 .80833 .43428 Mtetra
.654 .75 .921 r
.80833 .43428 .81553 .44394 .83257 .43882 .82544 .42907 Mtetra
.654 .75 .92 r
.82544 .42907 .83257 .43882 .84971 .43361 .84265 .42384 Mtetra
.656 .751 .92 r
.84265 .42384 .84971 .43361 .86693 .42829 .85995 .41849 Mtetra
.658 .753 .92 r
.85995 .41849 .86693 .42829 .88426 .42291 .87735 .41303 Mtetra
.655 .751 .921 r
.87735 .41303 .88426 .42291 .9017 .41761 .89487 .40765 Mtetra
.655 .751 .92 r
.27216 .58876 .28139 .59683 .29552 .59246 .28633 .58437 Mtetra
.654 .751 .922 r
.28633 .58437 .29552 .59246 .30971 .58816 .30057 .58003 Mtetra
.656 .752 .92 r
.30057 .58003 .30971 .58816 .32399 .58377 .31489 .57557 Mtetra
.658 .752 .919 r
.31489 .57557 .32399 .58377 .33835 .57927 .3293 .57101 Mtetra
.656 .751 .92 r
.3293 .57101 .33835 .57927 .35278 .57476 .34378 .56651 Mtetra
.653 .751 .922 r
.34378 .56651 .35278 .57476 .36729 .57038 .35833 .5621 Mtetra
.655 .752 .921 r
.35833 .5621 .36729 .57038 .38187 .56596 .37297 .55759 Mtetra
.66 .753 .919 r
.37297 .55759 .38187 .56596 .39655 .56138 .3877 .55288 Mtetra
.658 .75 .918 r
.3877 .55288 .39655 .56138 .4113 .55665 .4025 .54819 Mtetra
.651 .75 .922 r
.4025 .54819 .4113 .55665 .42613 .55216 .41738 .54374 Mtetra
.651 .752 .924 r
.41738 .54374 .42613 .55216 .44104 .54773 .43234 .53925 Mtetra
.659 .754 .92 r
.43234 .53925 .44104 .54773 .45604 .54322 .4474 .53444 Mtetra
.657 .748 .917 r
.4474 .53444 .45604 .54322 .47112 .5383 .46253 .52971 Mtetra
.612 .739 .936 r
.46253 .52971 .47112 .5383 .48628 .53379 .47773 .52647 Mtetra
.519 .739 .974 r
.47773 .52647 .48628 .53379 .50152 .53047 .493 .52521 Mtetra
.329 .709 .982 r
.493 .52521 .50152 .53047 .51686 .52813 .50839 .52593 Mtetra
.189 .699 .897 r
.50839 .52593 .51686 .52813 .5323 .52704 .52391 .52587 Mtetra
.242 .749 .883 r
.52391 .52587 .5323 .52704 .54786 .52519 .53956 .52427 Mtetra
.376 .833 .918 r
.53956 .52427 .54786 .52519 .56353 .52195 .55531 .52081 Mtetra
.489 .888 .948 r
.55531 .52081 .56353 .52195 .57927 .51713 .57115 .51595 Mtetra
.573 .924 .955 r
.57115 .51595 .57927 .51713 .59506 .51073 .58705 .50969 Mtetra
.659 .955 .945 r
.58705 .50969 .59506 .51073 .6109 .50291 .60299 .50154 Mtetra
.729 .966 .937 r
.60299 .50154 .6109 .50291 .62678 .49432 .61894 .49182 Mtetra
.772 .95 .934 r
.61894 .49182 .62678 .49432 .64275 .48695 .63491 .48128 Mtetra
.74 .865 .939 r
.63491 .48128 .64275 .48695 .65884 .48059 .651 .47272 Mtetra
.692 .798 .93 r
.651 .47272 .65884 .48059 .67506 .47541 .66724 .46616 Mtetra
.655 .753 .922 r
.66724 .46616 .67506 .47541 .6914 .47065 .68363 .46111 Mtetra
.652 .746 .918 r
.68363 .46111 .6914 .47065 .70781 .46547 .70012 .45613 Mtetra
.66 .755 .92 r
.70012 .45613 .70781 .46547 .72431 .46021 .71669 .45083 Mtetra
.66 .755 .921 r
.71669 .45083 .72431 .46021 .74091 .455 .73335 .44548 Mtetra
.654 .751 .921 r
.73335 .44548 .74091 .455 .75763 .45003 .75013 .44036 Mtetra
.652 .748 .92 r
.75013 .44036 .75763 .45003 .77444 .44491 .76702 .43527 Mtetra
.657 .752 .92 r
.76702 .43527 .77444 .44491 .79134 .43962 .78399 .42996 Mtetra
.659 .753 .92 r
.78399 .42996 .79134 .43962 .80833 .43428 .80105 .42454 Mtetra
.656 .752 .921 r
.80105 .42454 .80833 .43428 .82544 .42907 .81823 .41922 Mtetra
.654 .75 .92 r
.81823 .41922 .82544 .42907 .84265 .42384 .83551 .41395 Mtetra
.656 .751 .92 r
.83551 .41395 .84265 .42384 .85995 .41849 .85289 .40856 Mtetra
.658 .753 .92 r
.85289 .40856 .85995 .41849 .87735 .41303 .87037 .40306 Mtetra
.656 .752 .92 r
.87037 .40306 .87735 .41303 .89487 .40765 .88796 .39758 Mtetra
.655 .751 .921 r
.26283 .58061 .27216 .58876 .28633 .58437 .27704 .57621 Mtetra
.654 .751 .921 r
.27704 .57621 .28633 .58437 .30057 .58003 .29133 .5718 Mtetra
.657 .752 .92 r
.29133 .5718 .30057 .58003 .31489 .57557 .30571 .56728 Mtetra
.659 .752 .919 r
.30571 .56728 .31489 .57557 .3293 .57101 .32016 .56266 Mtetra
.654 .751 .92 r
.32016 .56266 .3293 .57101 .34378 .56651 .33469 .55817 Mtetra
.653 .751 .922 r
.33469 .55817 .34378 .56651 .35833 .5621 .34929 .55371 Mtetra
.656 .752 .921 r
.34929 .55371 .35833 .5621 .37297 .55759 .36398 .54912 Mtetra
.661 .752 .918 r
.36398 .54912 .37297 .55759 .3877 .55288 .37876 .54431 Mtetra
.655 .75 .919 r
.37876 .54431 .3877 .55288 .4025 .54819 .39361 .5397 Mtetra
.65 .751 .923 r
.39361 .5397 .4025 .54819 .41738 .54374 .40854 .53522 Mtetra
.652 .752 .923 r
.40854 .53522 .41738 .54374 .43234 .53925 .42355 .53065 Mtetra
.664 .755 .918 r
.42355 .53065 .43234 .53925 .4474 .53444 .43866 .52561 Mtetra
.632 .741 .926 r
.43866 .52561 .4474 .53444 .46253 .52971 .45383 .52173 Mtetra
.545 .732 .962 r
.45383 .52173 .46253 .52971 .47773 .52647 .46906 .52008 Mtetra
.303 .664 .973 r
.46906 .52008 .47773 .52647 .493 .52521 .48435 .52188 Mtetra
.125 .635 .897 r
.48435 .52188 .493 .52521 .50839 .52593 .4998 .52346 Mtetra
.273 .749 .935 r
.4998 .52346 .50839 .52593 .52391 .52587 .5154 .52263 Mtetra
.564 .876 .993 r
.5154 .52263 .52391 .52587 .53956 .52427 .53112 .51818 Mtetra
.689 .836 .954 r
.53112 .51818 .53956 .52427 .55531 .52081 .54692 .51177 Mtetra
.654 .752 .922 r
.54692 .51177 .55531 .52081 .57115 .51595 .56282 .50686 Mtetra
.611 .737 .935 r
.56282 .50686 .57115 .51595 .58705 .50969 .57883 .50346 Mtetra
.653 .828 .967 r
.57883 .50346 .58705 .50969 .60299 .50154 .59491 .49808 Mtetra
.74 .923 .953 r
.59491 .49808 .60299 .50154 .61894 .49182 .61099 .48905 Mtetra
.796 .945 .922 r
.61099 .48905 .61894 .49182 .63491 .48128 .62704 .47755 Mtetra
.805 .924 .915 r
.62704 .47755 .63491 .48128 .651 .47272 .64312 .4658 Mtetra
.732 .834 .928 r
.64312 .4658 .651 .47272 .66724 .46616 .65936 .45752 Mtetra
.677 .777 .926 r
.65936 .45752 .66724 .46616 .68363 .46111 .67578 .4515 Mtetra
.648 .745 .92 r
.67578 .4515 .68363 .46111 .70012 .45613 .69234 .44665 Mtetra
.659 .754 .92 r
.69234 .44665 .70012 .45613 .71669 .45083 .70898 .44132 Mtetra
.661 .755 .92 r
.70898 .44132 .71669 .45083 .73335 .44548 .72572 .43589 Mtetra
.657 .753 .921 r
.72572 .43589 .73335 .44548 .75013 .44036 .74256 .4306 Mtetra
.651 .748 .921 r
.74256 .4306 .75013 .44036 .76702 .43527 .75951 .4255 Mtetra
.656 .751 .92 r
.75951 .4255 .76702 .43527 .78399 .42996 .77656 .42017 Mtetra
.658 .753 .92 r
.77656 .42017 .78399 .42996 .80105 .42454 .79369 .41471 Mtetra
.657 .753 .92 r
.79369 .41471 .80105 .42454 .81823 .41922 .81094 .40927 Mtetra
.653 .75 .921 r
.81094 .40927 .81823 .41922 .83551 .41395 .8283 .40395 Mtetra
.655 .751 .92 r
.8283 .40395 .83551 .41395 .85289 .40856 .84575 .39852 Mtetra
.657 .752 .92 r
.84575 .39852 .85289 .40856 .87037 .40306 .86331 .39297 Mtetra
.86331 .39297 .87037 .40306 .88796 .39758 .88097 .3874 Mtetra
.654 .751 .921 r
.25341 .57238 .26283 .58061 .27704 .57621 .26767 .56796 Mtetra
.655 .751 .921 r
.26767 .56796 .27704 .57621 .29133 .5718 .28201 .56349 Mtetra
.657 .752 .92 r
.28201 .56349 .29133 .5718 .30571 .56728 .29643 .55891 Mtetra
.658 .752 .919 r
.29643 .55891 .30571 .56728 .32016 .56266 .31093 .55425 Mtetra
.653 .75 .921 r
.31093 .55425 .32016 .56266 .33469 .55817 .3255 .54975 Mtetra
.653 .751 .922 r
.3255 .54975 .33469 .55817 .34929 .55371 .34015 .54522 Mtetra
.657 .752 .92 r
.34015 .54522 .34929 .55371 .36398 .54912 .3549 .54053 Mtetra
.661 .752 .917 r
.3549 .54053 .36398 .54912 .37876 .54431 .36973 .53568 Mtetra
.652 .75 .921 r
.36973 .53568 .37876 .54431 .39361 .5397 .38462 .53111 Mtetra
.651 .751 .923 r
.38462 .53111 .39361 .5397 .40854 .53522 .3996 .52659 Mtetra
.657 .753 .921 r
.3996 .52659 .40854 .53522 .42355 .53065 .41468 .52179 Mtetra
.658 .749 .917 r
.41468 .52179 .42355 .53065 .43866 .52561 .42984 .51693 Mtetra
.596 .735 .941 r
.42984 .51693 .43866 .52561 .45383 .52173 .44503 .51409 Mtetra
.413 .686 .975 r
.44503 .51409 .45383 .52173 .46906 .52008 .46026 .51488 Mtetra
.145 .605 .928 r
.46026 .51488 .46906 .52008 .48435 .52188 .47559 .51771 Mtetra
.247 .696 .956 r
.47559 .51771 .48435 .52188 .4998 .52346 .49111 .51852 Mtetra
.668 .862 .973 r
.49111 .51852 .4998 .52346 .5154 .52263 .50681 .51252 Mtetra
.77 .759 .843 r
.50681 .51252 .5154 .52263 .53112 .51818 .52258 .50118 Mtetra
.718 .649 .779 r
.52258 .50118 .53112 .51818 .54692 .51177 .53839 .49056 Mtetra
.632 .57 .767 r
.53839 .49056 .54692 .51177 .56282 .50686 .55429 .48558 Mtetra
.543 .521 .781 r
.55429 .48558 .56282 .50686 .57883 .50346 .57036 .48626 Mtetra
.515 .549 .829 r
.57036 .48626 .57883 .50346 .59491 .49808 .58659 .4877 Mtetra
.627 .718 .912 r
.58659 .4877 .59491 .49808 .61099 .48905 .60286 .48378 Mtetra
.786 .883 .917 r
.60286 .48378 .61099 .48905 .62704 .47755 .61903 .47298 Mtetra
.824 .903 .896 r
.61903 .47298 .62704 .47755 .64312 .4658 .63517 .46008 Mtetra
.785 .875 .913 r
.63517 .46008 .64312 .4658 .65936 .45752 .65141 .44922 Mtetra
.704 .796 .922 r
.65141 .44922 .65936 .45752 .67578 .4515 .66785 .44203 Mtetra
.653 .753 .923 r
.66785 .44203 .67578 .4515 .69234 .44665 .68447 .4369 Mtetra
.655 .748 .918 r
.68447 .4369 .69234 .44665 .70898 .44132 .70119 .43169 Mtetra
.66 .754 .92 r
.70119 .43169 .70898 .44132 .72572 .43589 .71799 .42621 Mtetra
.659 .754 .92 r
.71799 .42621 .72572 .43589 .74256 .4306 .7349 .42075 Mtetra
.651 .749 .921 r
.7349 .42075 .74256 .4306 .75951 .4255 .75192 .4156 Mtetra
.654 .75 .92 r
.75192 .4156 .75951 .4255 .77656 .42017 .76904 .41027 Mtetra
.658 .753 .92 r
.76904 .41027 .77656 .42017 .79369 .41471 .78625 .40476 Mtetra
.78625 .40476 .79369 .41471 .81094 .40927 .80357 .39922 Mtetra
.653 .75 .921 r
.80357 .39922 .81094 .40927 .8283 .40395 .821 .39383 Mtetra
.655 .75 .92 r
.821 .39383 .8283 .40395 .84575 .39852 .83854 .38836 Mtetra
.657 .752 .92 r
.83854 .38836 .84575 .39852 .86331 .39297 .85617 .38277 Mtetra
.85617 .38277 .86331 .39297 .88097 .3874 .87391 .37712 Mtetra
.654 .751 .921 r
.2439 .56408 .25341 .57238 .26767 .56796 .2582 .55962 Mtetra
.655 .751 .921 r
.2582 .55962 .26767 .56796 .28201 .56349 .27258 .55509 Mtetra
.657 .752 .92 r
.27258 .55509 .28201 .56349 .29643 .55891 .28705 .55045 Mtetra
.658 .752 .919 r
.28705 .55045 .29643 .55891 .31093 .55425 .3016 .54576 Mtetra
.653 .751 .921 r
.3016 .54576 .31093 .55425 .3255 .54975 .31622 .54123 Mtetra
.654 .751 .921 r
.31622 .54123 .3255 .54975 .34015 .54522 .33093 .53665 Mtetra
.658 .752 .919 r
.33093 .53665 .34015 .54522 .3549 .54053 .34572 .53187 Mtetra
.66 .752 .918 r
.34572 .53187 .3549 .54053 .36973 .53568 .3606 .527 Mtetra
.651 .75 .922 r
.3606 .527 .36973 .53568 .38462 .53111 .37555 .52243 Mtetra
.651 .751 .923 r
.37555 .52243 .38462 .53111 .3996 .52659 .39058 .51784 Mtetra
.661 .754 .919 r
.39058 .51784 .3996 .52659 .41468 .52179 .40571 .51286 Mtetra
.648 .746 .921 r
.40571 .51286 .41468 .52179 .42984 .51693 .42091 .50833 Mtetra
.561 .726 .951 r
.42091 .50833 .42984 .51693 .44503 .51409 .43613 .50636 Mtetra
.305 .63 .963 r
.43613 .50636 .44503 .51409 .46026 .51488 .45137 .50886 Mtetra
.172 .601 .939 r
.45137 .50886 .46026 .51488 .47559 .51771 .46675 .51195 Mtetra
.509 .787 .995 r
.46675 .51195 .47559 .51771 .49111 .51852 .48235 .50991 Mtetra
.8 .792 .845 r
.48235 .50991 .49111 .51852 .50681 .51252 .49817 .497 Mtetra
.803 .695 .745 r
.49817 .497 .50681 .51252 .52258 .50118 .51402 .47741 Mtetra
.737 .608 .714 r
.51402 .47741 .52258 .50118 .53839 .49056 .52982 .4606 Mtetra
.615 .509 .71 r
.52982 .4606 .53839 .49056 .55429 .48558 .54568 .45553 Mtetra
.463 .415 .718 r
.54568 .45553 .55429 .48558 .57036 .48626 .56176 .46227 Mtetra
.369 .395 .757 r
.56176 .46227 .57036 .48626 .58659 .4877 .5781 .47187 Mtetra
.464 .543 .852 r
.5781 .47187 .58659 .4877 .60286 .48378 .59454 .4748 Mtetra
.721 .783 .902 r
.59454 .4748 .60286 .48378 .61903 .47298 .61087 .46677 Mtetra
.821 .864 .878 r
.61087 .46677 .61903 .47298 .63517 .46008 .6271 .45351 Mtetra
.812 .858 .883 r
.6271 .45351 .63517 .46008 .65141 .44922 .64337 .44082 Mtetra
.724 .802 .912 r
.64337 .44082 .65141 .44922 .66785 .44203 .65985 .43264 Mtetra
.663 .761 .923 r
.65985 .43264 .66785 .44203 .68447 .4369 .67652 .42705 Mtetra
.651 .747 .92 r
.67652 .42705 .68447 .4369 .70119 .43169 .69331 .42193 Mtetra
.66 .754 .919 r
.69331 .42193 .70119 .43169 .71799 .42621 .71018 .4164 Mtetra
.66 .754 .92 r
.71018 .4164 .71799 .42621 .7349 .42075 .72716 .41084 Mtetra
.652 .75 .921 r
.72716 .41084 .7349 .42075 .75192 .4156 .74425 .40559 Mtetra
.653 .75 .92 r
.74425 .40559 .75192 .4156 .76904 .41027 .76144 .40024 Mtetra
.658 .752 .92 r
.76144 .40024 .76904 .41027 .78625 .40476 .77873 .39469 Mtetra
.658 .753 .92 r
.77873 .39469 .78625 .40476 .80357 .39922 .79611 .38906 Mtetra
.654 .75 .921 r
.79611 .38906 .80357 .39922 .821 .39383 .81362 .38361 Mtetra
.654 .75 .92 r
.81362 .38361 .821 .39383 .83854 .38836 .83123 .37809 Mtetra
.657 .752 .92 r
.83123 .37809 .83854 .38836 .85617 .38277 .84895 .37244 Mtetra
.658 .752 .92 r
.84895 .37244 .85617 .38277 .87391 .37712 .86676 .36672 Mtetra
.654 .751 .921 r
.23429 .55569 .2439 .56408 .2582 .55962 .24863 .55119 Mtetra
.655 .751 .921 r
.24863 .55119 .2582 .55962 .27258 .55509 .26307 .54661 Mtetra
.658 .752 .92 r
.26307 .54661 .27258 .55509 .28705 .55045 .27758 .54192 Mtetra
.658 .752 .919 r
.27758 .54192 .28705 .55045 .3016 .54576 .29218 .53719 Mtetra
.653 .751 .922 r
.29218 .53719 .3016 .54576 .31622 .54123 .30685 .53262 Mtetra
.654 .751 .921 r
.30685 .53262 .31622 .54123 .33093 .53665 .3216 .52798 Mtetra
.659 .752 .919 r
.3216 .52798 .33093 .53665 .34572 .53187 .33645 .52313 Mtetra
.33645 .52313 .34572 .53187 .3606 .527 .35138 .51824 Mtetra
.651 .75 .922 r
.35138 .51824 .3606 .527 .37555 .52243 .36638 .51363 Mtetra
.651 .751 .922 r
.36638 .51363 .37555 .52243 .39058 .51784 .38146 .50899 Mtetra
.662 .754 .918 r
.38146 .50899 .39058 .51784 .40571 .51286 .39665 .50389 Mtetra
.64 .746 .925 r
.39665 .50389 .40571 .51286 .42091 .50833 .41189 .49958 Mtetra
.541 .717 .954 r
.41189 .49958 .42091 .50833 .43613 .50636 .42714 .4981 Mtetra
.271 .598 .951 r
.42714 .4981 .43613 .50636 .45137 .50886 .4424 .50137 Mtetra
.263 .617 .958 r
.4424 .50137 .45137 .50886 .46675 .51195 .45782 .50425 Mtetra
.652 .786 .946 r
.45782 .50425 .46675 .51195 .48235 .50991 .47353 .49925 Mtetra
.823 .759 .792 r
.47353 .49925 .48235 .50991 .49817 .497 .48946 .48212 Mtetra
.841 .711 .719 r
.48946 .48212 .49817 .497 .51402 .47741 .50542 .45632 Mtetra
.776 .642 .714 r
.50542 .45632 .51402 .47741 .52982 .4606 .52126 .43561 Mtetra
.624 .54 .739 r
.52126 .43561 .52982 .4606 .54568 .45553 .53711 .43047 Mtetra
.352 .375 .745 r
.53711 .43047 .54568 .45553 .56176 .46227 .55318 .44097 Mtetra
.137 .271 .74 r
.55318 .44097 .56176 .46227 .5781 .47187 .56956 .45668 Mtetra
.31 .466 .854 r
.56956 .45668 .5781 .47187 .59454 .4748 .58609 .46374 Mtetra
.653 .72 .897 r
.58609 .46374 .59454 .4748 .61087 .46677 .60256 .4586 Mtetra
.807 .82 .861 r
.60256 .4586 .61087 .46677 .6271 .45351 .61889 .44545 Mtetra
.814 .825 .859 r
.61889 .44545 .6271 .45351 .64337 .44082 .63522 .43186 Mtetra
.734 .793 .9 r
.63522 .43186 .64337 .44082 .65985 .43264 .65176 .42308 Mtetra
.67 .761 .919 r
.65176 .42308 .65985 .43264 .67652 .42705 .66848 .41716 Mtetra
.649 .748 .922 r
.66848 .41716 .67652 .42705 .69331 .42193 .68535 .41204 Mtetra
.66 .753 .919 r
.68535 .41204 .69331 .42193 .71018 .4164 .70229 .40646 Mtetra
.66 .754 .919 r
.70229 .40646 .71018 .4164 .72716 .41084 .71933 .40083 Mtetra
.652 .75 .921 r
.71933 .40083 .72716 .41084 .74425 .40559 .73649 .3955 Mtetra
.653 .75 .921 r
.73649 .3955 .74425 .40559 .76144 .40024 .75376 .3901 Mtetra
.657 .752 .92 r
.75376 .3901 .76144 .40024 .77873 .39469 .77112 .38449 Mtetra
.659 .753 .92 r
.77112 .38449 .77873 .39469 .79611 .38906 .78858 .3788 Mtetra
.654 .751 .921 r
.78858 .3788 .79611 .38906 .81362 .38361 .80616 .37327 Mtetra
.80616 .37327 .81362 .38361 .83123 .37809 .82385 .3677 Mtetra
.656 .752 .92 r
.82385 .3677 .83123 .37809 .84895 .37244 .84164 .36199 Mtetra
.658 .752 .92 r
.84164 .36199 .84895 .37244 .86676 .36672 .85953 .3562 Mtetra
.654 .751 .921 r
.22458 .54721 .23429 .55569 .24863 .55119 .23897 .54267 Mtetra
.655 .751 .921 r
.23897 .54267 .24863 .55119 .26307 .54661 .25345 .53804 Mtetra
.658 .752 .92 r
.25345 .53804 .26307 .54661 .27758 .54192 .26801 .5333 Mtetra
.658 .752 .919 r
.26801 .5333 .27758 .54192 .29218 .53719 .28266 .52852 Mtetra
.653 .751 .922 r
.28266 .52852 .29218 .53719 .30685 .53262 .29738 .5239 Mtetra
.654 .751 .921 r
.29738 .5239 .30685 .53262 .3216 .52798 .31218 .51921 Mtetra
.659 .752 .919 r
.31218 .51921 .3216 .52798 .33645 .52313 .32708 .51432 Mtetra
.32708 .51432 .33645 .52313 .35138 .51824 .34206 .50938 Mtetra
.651 .75 .922 r
.34206 .50938 .35138 .51824 .36638 .51363 .35711 .50472 Mtetra
.35711 .50472 .36638 .51363 .38146 .50899 .37225 .50002 Mtetra
.662 .753 .918 r
.37225 .50002 .38146 .50899 .39665 .50389 .38749 .49488 Mtetra
.64 .747 .926 r
.38749 .49488 .39665 .50389 .41189 .49958 .40279 .49052 Mtetra
.543 .712 .95 r
.40279 .49052 .41189 .49958 .42714 .4981 .41808 .48899 Mtetra
.301 .595 .947 r
.41808 .48899 .42714 .4981 .4424 .50137 .43337 .49223 Mtetra
.327 .609 .951 r
.43337 .49223 .4424 .50137 .45782 .50425 .44883 .49508 Mtetra
.655 .754 .922 r
.44883 .49508 .45782 .50425 .47353 .49925 .4646 .49002 Mtetra
.836 .785 .803 r
.4646 .49002 .47353 .49925 .48946 .48212 .48062 .47281 Mtetra
.884 .778 .74 r
.48062 .47281 .48946 .48212 .50542 .45632 .49669 .4469 Mtetra
.86 .782 .773 r
.49669 .4469 .50542 .45632 .52126 .43561 .51264 .4261 Mtetra
.658 .749 .917 r
.51264 .4261 .52126 .43561 .53711 .43047 .52854 .42091 Mtetra
0 .296 .781 r
.52854 .42091 .53711 .43047 .55318 .44097 .54463 .43139 Mtetra
0 .062 .58 r
.54463 .43139 .55318 .44097 .56956 .45668 .56103 .44709 Mtetra
.108 .465 .89 r
.56103 .44709 .56956 .45668 .58609 .46374 .57759 .45414 Mtetra
.653 .753 .923 r
.57759 .45414 .58609 .46374 .60256 .4586 .59412 .44893 Mtetra
.797 .79 .846 r
.59412 .44893 .60256 .4586 .61889 .44545 .61053 .43571 Mtetra
.802 .791 .842 r
.61053 .43571 .61889 .44545 .63522 .43186 .62695 .42204 Mtetra
.731 .776 .889 r
.62695 .42204 .63522 .43186 .65176 .42308 .64356 .41319 Mtetra
.67 .756 .916 r
.64356 .41319 .65176 .42308 .66848 .41716 .66036 .40721 Mtetra
.649 .749 .922 r
.66036 .40721 .66848 .41716 .68535 .41204 .67729 .40203 Mtetra
.66 .753 .919 r
.67729 .40203 .68535 .41204 .70229 .40646 .6943 .39639 Mtetra
.6943 .39639 .70229 .40646 .71933 .40083 .71142 .3907 Mtetra
.652 .75 .921 r
.71142 .3907 .71933 .40083 .73649 .3955 .72865 .3853 Mtetra
.653 .75 .921 r
.72865 .3853 .73649 .3955 .75376 .3901 .74599 .37985 Mtetra
.657 .752 .92 r
.74599 .37985 .75376 .3901 .77112 .38449 .76343 .37418 Mtetra
.659 .753 .919 r
.76343 .37418 .77112 .38449 .78858 .3788 .78096 .36843 Mtetra
.654 .751 .921 r
.78096 .36843 .78858 .3788 .80616 .37327 .79862 .36283 Mtetra
.79862 .36283 .80616 .37327 .82385 .3677 .81639 .35719 Mtetra
.656 .752 .92 r
.81639 .35719 .82385 .3677 .84164 .36199 .83425 .35142 Mtetra
.658 .752 .92 r
.83425 .35142 .84164 .36199 .85953 .3562 .85223 .34556 Mtetra
.654 .751 .921 r
.21477 .53865 .22458 .54721 .23897 .54267 .22921 .53405 Mtetra
.655 .751 .921 r
.22921 .53405 .23897 .54267 .25345 .53804 .24373 .52939 Mtetra
.657 .752 .92 r
.24373 .52939 .25345 .53804 .26801 .5333 .25835 .5246 Mtetra
.658 .752 .919 r
.25835 .5246 .26801 .5333 .28266 .52852 .27304 .51976 Mtetra
.653 .751 .921 r
.27304 .51976 .28266 .52852 .29738 .5239 .28781 .51509 Mtetra
.654 .751 .921 r
.28781 .51509 .29738 .5239 .31218 .51921 .30266 .51036 Mtetra
.658 .752 .919 r
.30266 .51036 .31218 .51921 .32708 .51432 .31761 .50543 Mtetra
.66 .753 .919 r
.31761 .50543 .32708 .51432 .34206 .50938 .33264 .50042 Mtetra
.651 .75 .922 r
.33264 .50042 .34206 .50938 .35711 .50472 .34775 .49569 Mtetra
.34775 .49569 .35711 .50472 .37225 .50002 .36294 .49096 Mtetra
.661 .753 .918 r
.36294 .49096 .37225 .50002 .38749 .49488 .37823 .48582 Mtetra
.648 .75 .924 r
.37823 .48582 .38749 .49488 .40279 .49052 .39359 .48114 Mtetra
.566 .716 .942 r
.39359 .48114 .40279 .49052 .41808 .48899 .40895 .47904 Mtetra
.373 .614 .944 r
.40895 .47904 .41808 .48899 .43337 .49223 .42429 .48143 Mtetra
.364 .589 .931 r
.42429 .48143 .43337 .49223 .44883 .49508 .43977 .48443 Mtetra
.574 .694 .922 r
.43977 .48443 .44883 .49508 .4646 .49002 .45553 .48225 Mtetra
.808 .815 .857 r
.45553 .48225 .4646 .49002 .48062 .47281 .47159 .46912 Mtetra
.898 .886 .812 r
.47159 .46912 .48062 .47281 .49669 .4469 .48774 .44926 Mtetra
.849 .998 .812 r
.48774 .44926 .49669 .4469 .51264 .4261 .50382 .43219 Mtetra
.005 0 0 r
.50382 .43219 .51264 .4261 .52854 .42091 .51986 .42696 Mtetra
.556 .044 0 r
.51986 .42696 .52854 .42091 .54463 .43139 .53603 .43362 Mtetra
.596 .045 0 r
.53603 .43362 .54463 .43139 .56103 .44709 .55244 .44316 Mtetra
.058 .579 .873 r
.55244 .44316 .56103 .44709 .57759 .45414 .56901 .44598 Mtetra
.723 .81 .918 r
.56901 .44598 .57759 .45414 .59412 .44893 .58556 .43776 Mtetra
.789 .763 .83 r
.58556 .43776 .59412 .44893 .61053 .43571 .60205 .42427 Mtetra
.78 .758 .833 r
.60205 .42427 .61053 .43571 .62695 .42204 .61857 .41135 Mtetra
.717 .756 .883 r
.61857 .41135 .62695 .42204 .64356 .41319 .63527 .40296 Mtetra
.663 .749 .914 r
.63527 .40296 .64356 .41319 .66036 .40721 .65215 .3972 Mtetra
.651 .751 .923 r
.65215 .3972 .66036 .40721 .67729 .40203 .66915 .3919 Mtetra
.66 .753 .919 r
.66915 .3919 .67729 .40203 .6943 .39639 .68623 .38619 Mtetra
.68623 .38619 .6943 .39639 .71142 .3907 .70341 .38045 Mtetra
.652 .75 .921 r
.70341 .38045 .71142 .3907 .72865 .3853 .72072 .37502 Mtetra
.653 .751 .921 r
.72072 .37502 .72865 .3853 .74599 .37985 .73814 .36948 Mtetra
.658 .752 .92 r
.73814 .36948 .74599 .37985 .76343 .37418 .75564 .36374 Mtetra
.658 .752 .919 r
.75564 .36374 .76343 .37418 .78096 .36843 .77325 .35792 Mtetra
.654 .75 .921 r
.77325 .35792 .78096 .36843 .79862 .36283 .79099 .35228 Mtetra
.654 .751 .921 r
.79099 .35228 .79862 .36283 .81639 .35719 .80883 .34657 Mtetra
.657 .752 .92 r
.80883 .34657 .81639 .35719 .83425 .35142 .82678 .34072 Mtetra
.658 .752 .92 r
.82678 .34072 .83425 .35142 .85223 .34556 .84483 .3348 Mtetra
.654 .751 .921 r
.20486 .53 .21477 .53865 .22921 .53405 .21935 .52535 Mtetra
.655 .751 .921 r
.21935 .52535 .22921 .53405 .24373 .52939 .23392 .52064 Mtetra
.657 .752 .92 r
.23392 .52064 .24373 .52939 .25835 .5246 .24858 .51582 Mtetra
.658 .752 .919 r
.24858 .51582 .25835 .5246 .27304 .51976 .26333 .51092 Mtetra
.653 .751 .921 r
.26333 .51092 .27304 .51976 .28781 .51509 .27814 .50618 Mtetra
.653 .75 .921 r
.27814 .50618 .28781 .51509 .30266 .51036 .29304 .50141 Mtetra
.657 .752 .92 r
.29304 .50141 .30266 .51036 .31761 .50543 .30804 .49647 Mtetra
.661 .754 .919 r
.30804 .49647 .31761 .50543 .33264 .50042 .32313 .49137 Mtetra
.652 .75 .922 r
.32313 .49137 .33264 .50042 .34775 .49569 .33829 .48655 Mtetra
.651 .749 .922 r
.33829 .48655 .34775 .49569 .36294 .49096 .35353 .48178 Mtetra
.657 .751 .919 r
.35353 .48178 .36294 .49096 .37823 .48582 .36887 .47672 Mtetra
.658 .755 .921 r
.36887 .47672 .37823 .48582 .39359 .48114 .3843 .47161 Mtetra
.598 .726 .934 r
.3843 .47161 .39359 .48114 .40895 .47904 .39974 .46853 Mtetra
.468 .65 .938 r
.39974 .46853 .40895 .47904 .42429 .48143 .41517 .46913 Mtetra
.407 .581 .91 r
.41517 .46913 .42429 .48143 .43977 .48443 .43068 .4718 Mtetra
.493 .618 .904 r
.43068 .4718 .43977 .48443 .45553 .48225 .44641 .47241 Mtetra
.682 .753 .905 r
.44641 .47241 .45553 .48225 .47159 .46912 .46241 .46613 Mtetra
.8 .932 .919 r
.46241 .46613 .47159 .46912 .48774 .44926 .47858 .45444 Mtetra
.47 .86 .662 r
.47858 .45444 .48774 .44926 .50382 .43219 .49477 .44347 Mtetra
.216 0 0 r
.49477 .44347 .50382 .43219 .51986 .42696 .51097 .43822 Mtetra
.424 0 .05 r
.51097 .43822 .51986 .42696 .53603 .43362 .52727 .43869 Mtetra
.337 0 0 r
.52727 .43869 .53603 .43362 .55244 .44316 .54374 .43993 Mtetra
.514 .867 .989 r
.54374 .43993 .55244 .44316 .56901 .44598 .56031 .43575 Mtetra
.765 .776 .862 r
.56031 .43575 .56901 .44598 .58556 .43776 .57688 .42458 Mtetra
.772 .729 .813 r
.57688 .42458 .58556 .43776 .60205 .42427 .59345 .41129 Mtetra
.748 .726 .832 r
.59345 .41129 .60205 .42427 .61857 .41135 .61009 .40008 Mtetra
.698 .741 .884 r
.61009 .40008 .61857 .41135 .63527 .40296 .62689 .39257 Mtetra
.654 .744 .916 r
.62689 .39257 .63527 .40296 .65215 .3972 .64385 .38714 Mtetra
.654 .753 .923 r
.64385 .38714 .65215 .3972 .66915 .3919 .66091 .38163 Mtetra
.661 .753 .918 r
.66091 .38163 .66915 .3919 .68623 .38619 .67806 .37585 Mtetra
.659 .752 .919 r
.67806 .37585 .68623 .38619 .70341 .38045 .69532 .37009 Mtetra
.651 .75 .922 r
.69532 .37009 .70341 .38045 .72072 .37502 .71271 .36463 Mtetra
.654 .752 .921 r
.71271 .36463 .72072 .37502 .73814 .36948 .73019 .35899 Mtetra
.658 .752 .92 r
.73019 .35899 .73814 .36948 .75564 .36374 .74777 .35317 Mtetra
.658 .752 .919 r
.74777 .35317 .75564 .36374 .77325 .35792 .76546 .34731 Mtetra
.653 .75 .921 r
.76546 .34731 .77325 .35792 .79099 .35228 .78327 .34161 Mtetra
.655 .751 .921 r
.78327 .34161 .79099 .35228 .80883 .34657 .8012 .33582 Mtetra
.657 .752 .92 r
.8012 .33582 .80883 .34657 .82678 .34072 .81922 .3299 Mtetra
.81922 .3299 .82678 .34072 .84483 .3348 .83736 .32392 Mtetra
.655 .751 .921 r
.19485 .52127 .20486 .53 .21935 .52535 .20938 .51654 Mtetra
.654 .751 .921 r
.20938 .51654 .21935 .52535 .23392 .52064 .224 .5118 Mtetra
.657 .752 .92 r
.224 .5118 .23392 .52064 .24858 .51582 .23871 .50695 Mtetra
.659 .753 .919 r
.23871 .50695 .24858 .51582 .26333 .51092 .25351 .502 Mtetra
.654 .751 .921 r
.25351 .502 .26333 .51092 .27814 .50618 .26837 .49716 Mtetra
.653 .75 .921 r
.26837 .49716 .27814 .50618 .29304 .50141 .28332 .49236 Mtetra
.656 .751 .92 r
.28332 .49236 .29304 .50141 .30804 .49647 .29837 .48743 Mtetra
.661 .754 .919 r
.29837 .48743 .30804 .49647 .32313 .49137 .31351 .48226 Mtetra
.655 .752 .921 r
.31351 .48226 .32313 .49137 .33829 .48655 .32873 .4773 Mtetra
.651 .749 .921 r
.32873 .4773 .33829 .48655 .35353 .48178 .34402 .47248 Mtetra
.652 .749 .921 r
.34402 .47248 .35353 .48178 .36887 .47672 .35941 .46755 Mtetra
.664 .757 .919 r
.35941 .46755 .36887 .47672 .3843 .47161 .37491 .46214 Mtetra
.631 .741 .927 r
.37491 .46214 .3843 .47161 .39974 .46853 .39044 .45791 Mtetra
.564 .692 .926 r
.39044 .45791 .39974 .46853 .41517 .46913 .40599 .45596 Mtetra
.462 .593 .898 r
.40599 .45596 .41517 .46913 .43068 .4718 .42156 .4575 Mtetra
.482 .584 .88 r
.42156 .4575 .43068 .4718 .44641 .47241 .43728 .45882 Mtetra
.552 .632 .884 r
.43728 .45882 .44641 .47241 .46241 .46613 .45322 .45769 Mtetra
.64 .776 .946 r
.45322 .45769 .46241 .46613 .47858 .45444 .46935 .45287 Mtetra
.605 .93 .963 r
.46935 .45287 .47858 .45444 .49477 .44347 .48561 .44605 Mtetra
.248 .752 .707 r
.48561 .44605 .49477 .44347 .51097 .43822 .50193 .44075 Mtetra
0 0 0 r
.50193 .44075 .51097 .43822 .52727 .43869 .51835 .43699 Mtetra
.542 .907 .962 r
.51835 .43699 .52727 .43869 .54374 .43993 .53489 .43121 Mtetra
.746 .804 .899 r
.53489 .43121 .54374 .43993 .56031 .43575 .55148 .42171 Mtetra
.751 .711 .815 r
.55148 .42171 .56031 .43575 .57688 .42458 .5681 .4097 Mtetra
.749 .7 .806 r
.5681 .4097 .57688 .42458 .59345 .41129 .58475 .39743 Mtetra
.708 .701 .841 r
.58475 .39743 .59345 .41129 .61009 .40008 .60152 .38868 Mtetra
.675 .733 .893 r
.60152 .38868 .61009 .40008 .62689 .39257 .61842 .38223 Mtetra
.648 .746 .921 r
.61842 .38223 .62689 .39257 .64385 .38714 .63545 .37698 Mtetra
.659 .755 .921 r
.63545 .37698 .64385 .38714 .66091 .38163 .65258 .37123 Mtetra
.661 .752 .918 r
.65258 .37123 .66091 .38163 .67806 .37585 .6698 .36538 Mtetra
.657 .75 .919 r
.6698 .36538 .67806 .37585 .69532 .37009 .68714 .35965 Mtetra
.651 .75 .922 r
.68714 .35965 .69532 .37009 .71271 .36463 .7046 .35413 Mtetra
.656 .752 .921 r
.7046 .35413 .71271 .36463 .73019 .35899 .72215 .34837 Mtetra
.658 .752 .919 r
.72215 .34837 .73019 .35899 .74777 .35317 .73981 .34247 Mtetra
.657 .751 .919 r
.73981 .34247 .74777 .35317 .76546 .34731 .75758 .33658 Mtetra
.653 .751 .921 r
.75758 .33658 .76546 .34731 .78327 .34161 .77547 .33082 Mtetra
.655 .752 .921 r
.77547 .33082 .78327 .34161 .8012 .33582 .79347 .32495 Mtetra
.657 .752 .92 r
.79347 .32495 .8012 .33582 .81922 .3299 .81157 .31894 Mtetra
.81157 .31894 .81922 .3299 .83736 .32392 .82979 .31291 Mtetra
.655 .751 .921 r
.18473 .51245 .19485 .52127 .20938 .51654 .19931 .50765 Mtetra
.654 .75 .921 r
.19931 .50765 .20938 .51654 .224 .5118 .21398 .50287 Mtetra
.656 .751 .92 r
.21398 .50287 .224 .5118 .23871 .50695 .22873 .49798 Mtetra
.658 .752 .919 r
.22873 .49798 .23871 .50695 .25351 .502 .24358 .49299 Mtetra
.656 .752 .921 r
.24358 .49299 .25351 .502 .26837 .49716 .2585 .48805 Mtetra
.653 .75 .921 r
.2585 .48805 .26837 .49716 .28332 .49236 .2735 .48321 Mtetra
.655 .751 .92 r
.2735 .48321 .28332 .49236 .29837 .48743 .2886 .47825 Mtetra
.66 .753 .919 r
.2886 .47825 .29837 .48743 .31351 .48226 .30379 .47309 Mtetra
.658 .754 .92 r
.30379 .47309 .31351 .48226 .32873 .4773 .31906 .46795 Mtetra
.651 .749 .921 r
.31906 .46795 .32873 .4773 .34402 .47248 .33441 .46305 Mtetra
.652 .748 .921 r
.33441 .46305 .34402 .47248 .35941 .46755 .34985 .4581 Mtetra
.66 .752 .918 r
.34985 .4581 .35941 .46755 .37491 .46214 .3654 .45283 Mtetra
.657 .755 .922 r
.3654 .45283 .37491 .46214 .39044 .45791 .38103 .44763 Mtetra
.615 .721 .921 r
.38103 .44763 .39044 .45791 .40599 .45596 .39669 .44395 Mtetra
.56 .664 .907 r
.39669 .44395 .40599 .45596 .42156 .4575 .41239 .44229 Mtetra
.515 .587 .865 r
.41239 .44229 .42156 .4575 .43728 .45882 .42815 .44266 Mtetra
.541 .587 .85 r
.42815 .44266 .43728 .45882 .45322 .45769 .44409 .44223 Mtetra
.577 .616 .854 r
.44409 .44223 .45322 .45769 .46935 .45287 .46019 .44021 Mtetra
.62 .682 .887 r
.46019 .44021 .46935 .45287 .48561 .44605 .47646 .43629 Mtetra
.654 .754 .923 r
.47646 .43629 .48561 .44605 .50193 .44075 .49285 .43093 Mtetra
.688 .765 .91 r
.49285 .43093 .50193 .44075 .51835 .43699 .50934 .42414 Mtetra
.713 .716 .852 r
.50934 .42414 .51835 .43699 .53489 .43121 .52593 .41541 Mtetra
.72 .678 .808 r
.52593 .41541 .53489 .43121 .55148 .42171 .54256 .40507 Mtetra
.725 .671 .796 r
.54256 .40507 .55148 .42171 .5681 .4097 .55924 .39389 Mtetra
.704 .673 .817 r
.55924 .39389 .5681 .4097 .58475 .39743 .576 .38474 Mtetra
.685 .713 .87 r
.576 .38474 .58475 .39743 .60152 .38868 .59286 .37762 Mtetra
.655 .734 .908 r
.59286 .37762 .60152 .38868 .61842 .38223 .60986 .37204 Mtetra
.652 .753 .924 r
.60986 .37204 .61842 .38223 .63545 .37698 .62696 .36653 Mtetra
.66 .752 .918 r
.62696 .36653 .63545 .37698 .65258 .37123 .64415 .36069 Mtetra
.66 .751 .918 r
.64415 .36069 .65258 .37123 .6698 .36538 .66145 .35479 Mtetra
.654 .749 .92 r
.66145 .35479 .6698 .36538 .68714 .35965 .67887 .34912 Mtetra
.652 .751 .923 r
.67887 .34912 .68714 .35965 .7046 .35413 .69639 .34349 Mtetra
.657 .752 .92 r
.69639 .34349 .7046 .35413 .72215 .34837 .71402 .33762 Mtetra
.659 .752 .919 r
.71402 .33762 .72215 .34837 .73981 .34247 .73175 .33164 Mtetra
.656 .751 .92 r
.73175 .33164 .73981 .34247 .75758 .33658 .7496 .32574 Mtetra
.653 .751 .921 r
.7496 .32574 .75758 .33658 .77547 .33082 .76757 .31991 Mtetra
.655 .752 .921 r
.76757 .31991 .77547 .33082 .79347 .32495 .78565 .31394 Mtetra
.658 .752 .92 r
.78565 .31394 .79347 .32495 .81157 .31894 .80383 .30785 Mtetra
.656 .751 .92 r
.80383 .30785 .81157 .31894 .82979 .31291 .82214 .30178 Mtetra
.656 .752 .92 r
.1745 .50354 .18473 .51245 .19931 .50765 .18914 .49865 Mtetra
.654 .75 .921 r
.18914 .49865 .19931 .50765 .21398 .50287 .20385 .49383 Mtetra
.655 .751 .92 r
.20385 .49383 .21398 .50287 .22873 .49798 .21865 .48892 Mtetra
.658 .752 .92 r
.21865 .48892 .22873 .49798 .24358 .49299 .23355 .48389 Mtetra
.658 .753 .92 r
.23355 .48389 .24358 .49299 .2585 .48805 .24853 .47884 Mtetra
.653 .75 .921 r
.24853 .47884 .2585 .48805 .2735 .48321 .26358 .47393 Mtetra
.654 .75 .92 r
.26358 .47393 .2735 .48321 .2886 .47825 .27872 .46897 Mtetra
.657 .752 .92 r
.27872 .46897 .2886 .47825 .30379 .47309 .29396 .46384 Mtetra
.661 .755 .92 r
.29396 .46384 .30379 .47309 .31906 .46795 .3093 .45855 Mtetra
.654 .751 .921 r
.3093 .45855 .31906 .46795 .33441 .46305 .3247 .4535 Mtetra
.651 .748 .92 r
.3247 .4535 .33441 .46305 .34985 .4581 .3402 .44852 Mtetra
.653 .749 .92 r
.3402 .44852 .34985 .4581 .3654 .45283 .35578 .44345 Mtetra
.663 .757 .92 r
.35578 .44345 .3654 .45283 .38103 .44763 .37148 .43795 Mtetra
.651 .749 .921 r
.37148 .43795 .38103 .44763 .39669 .44395 .38726 .43287 Mtetra
.619 .709 .91 r
.38726 .43287 .39669 .44395 .41239 .44229 .40307 .429 Mtetra
.595 .658 .882 r
.40307 .429 .41239 .44229 .42815 .44266 .41897 .42615 Mtetra
.567 .597 .842 r
.41897 .42615 .42815 .44266 .44409 .44223 .43494 .42457 Mtetra
.585 .591 .825 r
.43494 .42457 .44409 .44223 .46019 .44021 .45107 .4222 Mtetra
.612 .602 .816 r
.45107 .4222 .46019 .44021 .47646 .43629 .46735 .4184 Mtetra
.64 .617 .811 r
.46735 .4184 .47646 .43629 .49285 .43093 .48376 .41297 Mtetra
.665 .629 .804 r
.48376 .41297 .49285 .43093 .50934 .42414 .50029 .40591 Mtetra
.684 .636 .795 r
.50029 .40591 .50934 .42414 .52593 .41541 .5169 .3974 Mtetra
.695 .644 .794 r
.5169 .3974 .52593 .41541 .54256 .40507 .53358 .38808 Mtetra
.683 .65 .811 r
.53358 .38808 .54256 .40507 .55924 .39389 .55033 .38002 Mtetra
.679 .692 .856 r
.55033 .38002 .55924 .39389 .576 .38474 .56718 .37298 Mtetra
.659 .723 .896 r
.56718 .37298 .576 .38474 .59286 .37762 .58413 .36716 Mtetra
.649 .747 .922 r
.58413 .36716 .59286 .37762 .60986 .37204 .6012 .36176 Mtetra
.659 .756 .922 r
.6012 .36176 .60986 .37204 .62696 .36653 .61836 .35593 Mtetra
.66 .751 .917 r
.61836 .35593 .62696 .36653 .64415 .36069 .63563 .35 Mtetra
.658 .75 .918 r
.63563 .35 .64415 .36069 .66145 .35479 .653 .34413 Mtetra
.651 .75 .922 r
.653 .34413 .66145 .35479 .67887 .34912 .6705 .3385 Mtetra
.654 .753 .922 r
.6705 .3385 .67887 .34912 .69639 .34349 .6881 .3327 Mtetra
.658 .752 .92 r
.6881 .3327 .69639 .34349 .71402 .33762 .7058 .32673 Mtetra
.658 .752 .919 r
.7058 .32673 .71402 .33762 .73175 .33164 .72361 .32069 Mtetra
.654 .75 .92 r
.72361 .32069 .73175 .33164 .7496 .32574 .74154 .31479 Mtetra
.654 .751 .921 r
.74154 .31479 .7496 .32574 .76757 .31991 .75959 .30886 Mtetra
.656 .752 .92 r
.75959 .30886 .76757 .31991 .78565 .31394 .77774 .3028 Mtetra
.658 .752 .919 r
.77774 .3028 .78565 .31394 .80383 .30785 .79601 .29663 Mtetra
.655 .751 .92 r
.79601 .29663 .80383 .30785 .82214 .30178 .8144 .29053 Mtetra
.657 .752 .92 r
.16417 .49454 .1745 .50354 .18914 .49865 .17886 .48957 Mtetra
.654 .751 .921 r
.17886 .48957 .18914 .49865 .20385 .49383 .19362 .48469 Mtetra
.655 .75 .92 r
.19362 .48469 .20385 .49383 .21865 .48892 .20847 .47975 Mtetra
.657 .752 .92 r
.20847 .47975 .21865 .48892 .23355 .48389 .22341 .47471 Mtetra
.658 .753 .92 r
.22341 .47471 .23355 .48389 .24853 .47884 .23844 .46957 Mtetra
.655 .751 .921 r
.23844 .46957 .24853 .47884 .26358 .47393 .25355 .46455 Mtetra
.653 .749 .921 r
.25355 .46455 .26358 .47393 .27872 .46897 .26874 .45956 Mtetra
.655 .751 .92 r
.26874 .45956 .27872 .46897 .29396 .46384 .28403 .45445 Mtetra
.66 .754 .92 r
.28403 .45445 .29396 .46384 .3093 .45855 .29942 .44915 Mtetra
.658 .754 .921 r
.29942 .44915 .3093 .45855 .3247 .4535 .31489 .44387 Mtetra
.652 .748 .92 r
.31489 .44387 .3247 .4535 .3402 .44852 .33044 .43879 Mtetra
.33044 .43879 .3402 .44852 .35578 .44345 .34608 .4337 Mtetra
.653 .749 .92 r
.34608 .4337 .35578 .44345 .37148 .43795 .36182 .42851 Mtetra
.663 .76 .922 r
.36182 .42851 .37148 .43795 .38726 .43287 .37767 .42292 Mtetra
.654 .747 .918 r
.37767 .42292 .38726 .43287 .40307 .429 .3936 .41764 Mtetra
.636 .713 .903 r
.3936 .41764 .40307 .429 .41897 .42615 .40959 .41305 Mtetra
.625 .677 .88 r
.40959 .41305 .41897 .42615 .43494 .42457 .42568 .40887 Mtetra
.622 .637 .844 r
.42568 .40887 .43494 .42457 .45107 .4222 .44188 .40466 Mtetra
.628 .616 .819 r
.44188 .40466 .45107 .4222 .46735 .4184 .4582 .39996 Mtetra
.639 .612 .807 r
.4582 .39996 .46735 .4184 .48376 .41297 .47463 .39446 Mtetra
.651 .618 .803 r
.47463 .39446 .48376 .41297 .50029 .40591 .49117 .38816 Mtetra
.661 .632 .81 r
.49117 .38816 .50029 .40591 .5169 .3974 .50781 .38136 Mtetra
.667 .656 .83 r
.50781 .38136 .5169 .3974 .53358 .38808 .52454 .37453 Mtetra
.668 .694 .865 r
.52454 .37453 .53358 .38808 .55033 .38002 .54136 .3681 Mtetra
.657 .72 .896 r
.54136 .3681 .55033 .38002 .56718 .37298 .55828 .36236 Mtetra
.649 .745 .92 r
.55828 .36236 .56718 .37298 .58413 .36716 .57531 .35694 Mtetra
.658 .759 .924 r
.57531 .35694 .58413 .36716 .6012 .36176 .59244 .3511 Mtetra
.66 .751 .918 r
.59244 .3511 .6012 .36176 .61836 .35593 .60967 .34516 Mtetra
.659 .75 .917 r
.60967 .34516 .61836 .35593 .63563 .35 .62701 .3392 Mtetra
.653 .749 .92 r
.62701 .3392 .63563 .35 .653 .34413 .64446 .33345 Mtetra
.652 .752 .923 r
.64446 .33345 .653 .34413 .6705 .3385 .66203 .32772 Mtetra
.656 .753 .921 r
.66203 .32772 .6705 .3385 .6881 .3327 .6797 .32177 Mtetra
.658 .752 .919 r
.6797 .32177 .6881 .3327 .7058 .32673 .69748 .3157 Mtetra
.657 .751 .919 r
.69748 .3157 .7058 .32673 .72361 .32069 .71537 .30965 Mtetra
.653 .751 .921 r
.71537 .30965 .72361 .32069 .74154 .31479 .73338 .30371 Mtetra
.655 .752 .921 r
.73338 .30371 .74154 .31479 .75959 .30886 .75151 .29767 Mtetra
.657 .752 .92 r
.75151 .29767 .75959 .30886 .77774 .3028 .76974 .29151 Mtetra
.657 .751 .919 r
.76974 .29151 .77774 .3028 .79601 .29663 .78809 .28529 Mtetra
.655 .751 .92 r
.78809 .28529 .79601 .29663 .8144 .29053 .80656 .27914 Mtetra
.657 .752 .92 r
.15373 .48545 .16417 .49454 .17886 .48957 .16847 .48042 Mtetra
.655 .751 .921 r
.16847 .48042 .17886 .48957 .19362 .48469 .18328 .47544 Mtetra
.654 .75 .921 r
.18328 .47544 .19362 .48469 .20847 .47975 .19818 .47048 Mtetra
.656 .751 .92 r
.19818 .47048 .20847 .47975 .22341 .47471 .21316 .46541 Mtetra
.658 .752 .92 r
.21316 .46541 .22341 .47471 .23844 .46957 .22825 .46024 Mtetra
.657 .753 .92 r
.22825 .46024 .23844 .46957 .25355 .46455 .24341 .45507 Mtetra
.653 .75 .921 r
.24341 .45507 .25355 .46455 .26874 .45956 .25866 .45002 Mtetra
.654 .75 .92 r
.25866 .45002 .26874 .45956 .28403 .45445 .27399 .44491 Mtetra
.656 .752 .92 r
.27399 .44491 .28403 .45445 .29942 .44915 .28943 .43967 Mtetra
.66 .755 .92 r
.28943 .43967 .29942 .44915 .31489 .44387 .30496 .43426 Mtetra
.656 .753 .921 r
.30496 .43426 .31489 .44387 .33044 .43879 .32057 .42896 Mtetra
.652 .748 .92 r
.32057 .42896 .33044 .43879 .34608 .4337 .33627 .4238 Mtetra
.652 .747 .919 r
.33627 .4238 .34608 .4337 .36182 .42851 .35206 .41859 Mtetra
.654 .749 .92 r
.35206 .41859 .36182 .42851 .37767 .42292 .36796 .41331 Mtetra
.66 .759 .923 r
.36796 .41331 .37767 .42292 .3936 .41764 .38395 .40773 Mtetra
.659 .753 .919 r
.38395 .40773 .3936 .41764 .40959 .41305 .40005 .40215 Mtetra
.653 .732 .907 r
.40005 .40215 .40959 .41305 .42568 .40887 .41622 .3968 Mtetra
.648 .708 .891 r
.41622 .3968 .42568 .40887 .44188 .40466 .4325 .39158 Mtetra
.648 .691 .877 r
.4325 .39158 .44188 .40466 .4582 .39996 .44887 .38627 Mtetra
.651 .683 .867 r
.44887 .38627 .4582 .39996 .47463 .39446 .46535 .38071 Mtetra
.656 .685 .866 r
.46535 .38071 .47463 .39446 .49117 .38816 .48194 .37488 Mtetra
.658 .695 .873 r
.48194 .37488 .49117 .38816 .50781 .38136 .49862 .36897 Mtetra
.657 .711 .888 r
.49862 .36897 .50781 .38136 .52454 .37453 .5154 .36319 Mtetra
.652 .731 .907 r
.5154 .36319 .52454 .37453 .54136 .3681 .53229 .35763 Mtetra
.651 .75 .922 r
.53229 .35763 .54136 .3681 .55828 .36236 .54928 .35207 Mtetra
.658 .758 .924 r
.54928 .35207 .55828 .36236 .57531 .35694 .56637 .34621 Mtetra
.659 .751 .918 r
.56637 .34621 .57531 .35694 .59244 .3511 .58357 .34027 Mtetra
.659 .75 .917 r
.58357 .34027 .59244 .3511 .60967 .34516 .60088 .33428 Mtetra
.655 .749 .919 r
.60088 .33428 .60967 .34516 .62701 .3392 .61829 .32842 Mtetra
.651 .751 .922 r
.61829 .32842 .62701 .3392 .64446 .33345 .63582 .32268 Mtetra
.655 .754 .922 r
.63582 .32268 .64446 .33345 .66203 .32772 .65346 .31674 Mtetra
.658 .752 .92 r
.65346 .31674 .66203 .32772 .6797 .32177 .6712 .31067 Mtetra
.658 .751 .919 r
.6712 .31067 .6797 .32177 .69748 .3157 .68906 .30454 Mtetra
.655 .75 .92 r
.68906 .30454 .69748 .3157 .71537 .30965 .70703 .29852 Mtetra
.654 .752 .922 r
.70703 .29852 .71537 .30965 .73338 .30371 .72512 .29249 Mtetra
.656 .752 .921 r
.72512 .29249 .73338 .30371 .75151 .29767 .74333 .28635 Mtetra
.658 .752 .92 r
.74333 .28635 .75151 .29767 .76974 .29151 .76164 .28009 Mtetra
.656 .751 .92 r
.76164 .28009 .76974 .29151 .78809 .28529 .78008 .27384 Mtetra
.654 .751 .921 r
.78008 .27384 .78809 .28529 .80656 .27914 .79864 .26762 Mtetra
.657 .752 .92 r
.14318 .47626 .15373 .48545 .16847 .48042 .15796 .47118 Mtetra
.15796 .47118 .16847 .48042 .18328 .47544 .17283 .46609 Mtetra
.654 .75 .921 r
.17283 .46609 .18328 .47544 .19818 .47048 .18777 .46108 Mtetra
.655 .75 .92 r
.18777 .46108 .19818 .47048 .21316 .46541 .20281 .456 Mtetra
.657 .752 .92 r
.20281 .456 .21316 .46541 .22825 .46024 .21794 .45082 Mtetra
.658 .753 .92 r
.21794 .45082 .22825 .46024 .24341 .45507 .23316 .44555 Mtetra
.655 .751 .921 r
.23316 .44555 .24341 .45507 .25866 .45002 .24846 .44036 Mtetra
.653 .749 .92 r
.24846 .44036 .25866 .45002 .27399 .44491 .26385 .43522 Mtetra
.655 .75 .92 r
.26385 .43522 .27399 .44491 .28943 .43967 .27933 .43 Mtetra
.657 .753 .92 r
.27933 .43 .28943 .43967 .30496 .43426 .29491 .42464 Mtetra
.66 .756 .921 r
.29491 .42464 .30496 .43426 .32057 .42896 .31059 .41915 Mtetra
.656 .752 .92 r
.31059 .41915 .32057 .42896 .33627 .4238 .32636 .41378 Mtetra
.653 .747 .919 r
.32636 .41378 .33627 .4238 .35206 .41859 .34221 .4085 Mtetra
.34221 .4085 .35206 .41859 .36796 .41331 .35815 .40319 Mtetra
.654 .748 .919 r
.35815 .40319 .36796 .41331 .38395 .40773 .3742 .39782 Mtetra
.655 .754 .923 r
.3742 .39782 .38395 .40773 .40005 .40215 .39034 .39237 Mtetra
.659 .76 .924 r
.39034 .39237 .40005 .40215 .41622 .3968 .40659 .38671 Mtetra
.659 .754 .921 r
.40659 .38671 .41622 .3968 .4325 .39158 .42294 .38104 Mtetra
.657 .745 .915 r
.42294 .38104 .4325 .39158 .44887 .38627 .43938 .3754 Mtetra
.656 .739 .911 r
.43938 .3754 .44887 .38627 .46535 .38071 .45592 .36977 Mtetra
.655 .739 .912 r
.45592 .36977 .46535 .38071 .48194 .37488 .47257 .36415 Mtetra
.653 .744 .916 r
.47257 .36415 .48194 .37488 .49862 .36897 .48931 .35857 Mtetra
.652 .752 .923 r
.48931 .35857 .49862 .36897 .5154 .36319 .50616 .35297 Mtetra
.657 .759 .925 r
.50616 .35297 .5154 .36319 .53229 .35763 .52311 .34715 Mtetra
.658 .755 .922 r
.52311 .34715 .53229 .35763 .54928 .35207 .54017 .34126 Mtetra
.659 .75 .917 r
.54017 .34126 .54928 .35207 .56637 .34621 .55734 .3353 Mtetra
.659 .749 .917 r
.55734 .3353 .56637 .34621 .58357 .34027 .57461 .3293 Mtetra
.656 .748 .918 r
.57461 .3293 .58357 .34027 .60088 .33428 .59199 .3234 Mtetra
.652 .75 .922 r
.59199 .3234 .60088 .33428 .61829 .32842 .60948 .3176 Mtetra
.654 .754 .923 r
.60948 .3176 .61829 .32842 .63582 .32268 .62708 .31168 Mtetra
.657 .752 .92 r
.62708 .31168 .63582 .32268 .65346 .31674 .64479 .30561 Mtetra
.658 .752 .919 r
.64479 .30561 .65346 .31674 .6712 .31067 .66261 .29944 Mtetra
.656 .75 .919 r
.66261 .29944 .6712 .31067 .68906 .30454 .68055 .29331 Mtetra
.653 .751 .921 r
.68055 .29331 .68906 .30454 .70703 .29852 .6986 .28727 Mtetra
.655 .752 .921 r
.6986 .28727 .70703 .29852 .72512 .29249 .71677 .28112 Mtetra
.657 .752 .92 r
.71677 .28112 .72512 .29249 .74333 .28635 .73505 .27486 Mtetra
.658 .751 .919 r
.73505 .27486 .74333 .28635 .76164 .28009 .75345 .26852 Mtetra
.655 .75 .92 r
.75345 .26852 .76164 .28009 .78008 .27384 .77197 .26226 Mtetra
.655 .751 .921 r
.77197 .26226 .78008 .27384 .79864 .26762 .79061 .25597 Mtetra
.657 .752 .92 r
.13251 .46696 .14318 .47626 .15796 .47118 .14734 .46185 Mtetra
.14734 .46185 .15796 .47118 .17283 .46609 .16226 .45668 Mtetra
.655 .751 .921 r
.16226 .45668 .17283 .46609 .18777 .46108 .17726 .45156 Mtetra
.654 .75 .92 r
.17726 .45156 .18777 .46108 .20281 .456 .19234 .44647 Mtetra
.656 .751 .92 r
.19234 .44647 .20281 .456 .21794 .45082 .20752 .44126 Mtetra
.657 .752 .92 r
.20752 .44126 .21794 .45082 .23316 .44555 .22279 .43597 Mtetra
.658 .753 .92 r
.22279 .43597 .23316 .44555 .24846 .44036 .23816 .43063 Mtetra
.654 .75 .92 r
.23816 .43063 .24846 .44036 .26385 .43522 .2536 .42539 Mtetra
.653 .749 .92 r
.2536 .42539 .26385 .43522 .27933 .43 .26913 .42016 Mtetra
.655 .75 .92 r
.26913 .42016 .27933 .43 .29491 .42464 .28476 .41483 Mtetra
.657 .753 .921 r
.28476 .41483 .29491 .42464 .31059 .41915 .30049 .40938 Mtetra
.659 .756 .921 r
.30049 .40938 .31059 .41915 .32636 .41378 .31632 .40382 Mtetra
.657 .752 .92 r
.31632 .40382 .32636 .41378 .34221 .4085 .33224 .39831 Mtetra
.654 .748 .919 r
.33224 .39831 .34221 .4085 .35815 .40319 .34825 .39291 Mtetra
.653 .747 .918 r
.34825 .39291 .35815 .40319 .3742 .39782 .36435 .38749 Mtetra
.654 .747 .918 r
.36435 .38749 .3742 .39782 .39034 .39237 .38055 .38201 Mtetra
.654 .748 .919 r
.38055 .38201 .39034 .39237 .40659 .38671 .39686 .37647 Mtetra
.655 .752 .921 r
.39686 .37647 .40659 .38671 .42294 .38104 .41326 .37088 Mtetra
.655 .756 .924 r
.41326 .37088 .42294 .38104 .43938 .3754 .42977 .36524 Mtetra
.656 .757 .924 r
.42977 .36524 .43938 .3754 .45592 .36977 .44637 .35955 Mtetra
.44637 .35955 .45592 .36977 .47257 .36415 .46308 .35381 Mtetra
.657 .756 .923 r
.46308 .35381 .47257 .36415 .48931 .35857 .4799 .34801 Mtetra
.657 .753 .921 r
.4799 .34801 .48931 .35857 .50616 .35297 .49681 .34216 Mtetra
.658 .749 .918 r
.49681 .34216 .50616 .35297 .52311 .34715 .51384 .33625 Mtetra
.658 .749 .917 r
.51384 .33625 .52311 .34715 .54017 .34126 .53097 .33027 Mtetra
.658 .748 .917 r
.53097 .33027 .54017 .34126 .55734 .3353 .5482 .32428 Mtetra
.655 .748 .918 r
.5482 .32428 .55734 .3353 .57461 .3293 .56554 .31838 Mtetra
.652 .751 .922 r
.56554 .31838 .57461 .3293 .59199 .3234 .583 .31254 Mtetra
.654 .754 .923 r
.583 .31254 .59199 .3234 .60948 .3176 .60056 .30658 Mtetra
.657 .753 .921 r
.60056 .30658 .60948 .3176 .62708 .31168 .61824 .30049 Mtetra
.658 .752 .919 r
.61824 .30049 .62708 .31168 .64479 .30561 .63602 .2943 Mtetra
.657 .75 .919 r
.63602 .2943 .64479 .30561 .66261 .29944 .65392 .2881 Mtetra
.654 .75 .92 r
.65392 .2881 .66261 .29944 .68055 .29331 .67193 .282 Mtetra
.654 .752 .922 r
.67193 .282 .68055 .29331 .6986 .28727 .69007 .27585 Mtetra
.656 .752 .921 r
.69007 .27585 .6986 .28727 .71677 .28112 .70831 .2696 Mtetra
.658 .752 .92 r
.70831 .2696 .71677 .28112 .73505 .27486 .72668 .26323 Mtetra
.656 .751 .919 r
.72668 .26323 .73505 .27486 .75345 .26852 .74516 .25687 Mtetra
.655 .751 .921 r
.74516 .25687 .75345 .26852 .77197 .26226 .76377 .25054 Mtetra
.655 .752 .921 r
.76377 .25054 .77197 .26226 .79061 .25597 .78249 .24416 Mtetra
.656 .752 .92 r
.12173 .45756 .13251 .46696 .14734 .46185 .13661 .45241 Mtetra
.657 .752 .92 r
.13661 .45241 .14734 .46185 .16226 .45668 .15158 .44719 Mtetra
.15158 .44719 .16226 .45668 .17726 .45156 .16664 .44196 Mtetra
.654 .75 .92 r
.16664 .44196 .17726 .45156 .19234 .44647 .18177 .43679 Mtetra
.18177 .43679 .19234 .44647 .20752 .44126 .19699 .43158 Mtetra
.656 .752 .92 r
.19699 .43158 .20752 .44126 .22279 .43597 .21231 .42628 Mtetra
.658 .753 .92 r
.21231 .42628 .22279 .43597 .23816 .43063 .22773 .42088 Mtetra
.657 .753 .921 r
.22773 .42088 .23816 .43063 .2536 .42539 .24324 .41547 Mtetra
.654 .749 .92 r
.24324 .41547 .2536 .42539 .26913 .42016 .25883 .41016 Mtetra
.25883 .41016 .26913 .42016 .28476 .41483 .27451 .40482 Mtetra
.655 .75 .92 r
.27451 .40482 .28476 .41483 .30049 .40938 .29029 .3994 Mtetra
.657 .753 .921 r
.29029 .3994 .30049 .40938 .31632 .40382 .30617 .39389 Mtetra
.659 .756 .922 r
.30617 .39389 .31632 .40382 .33224 .39831 .32215 .38825 Mtetra
.658 .754 .921 r
.32215 .38825 .33224 .39831 .34825 .39291 .33822 .38261 Mtetra
.656 .75 .919 r
.33822 .38261 .34825 .39291 .36435 .38749 .35439 .37703 Mtetra
.654 .747 .918 r
.35439 .37703 .36435 .38749 .38055 .38201 .37066 .37147 Mtetra
.37066 .37147 .38055 .38201 .39686 .37647 .38702 .36587 Mtetra
.655 .747 .918 r
.38702 .36587 .39686 .37647 .41326 .37088 .40348 .36023 Mtetra
.40348 .36023 .41326 .37088 .42977 .36524 .42005 .35453 Mtetra
.656 .748 .918 r
.42005 .35453 .42977 .36524 .44637 .35955 .43672 .34877 Mtetra
.656 .748 .917 r
.43672 .34877 .44637 .35955 .46308 .35381 .4535 .34295 Mtetra
.657 .748 .917 r
.4535 .34295 .46308 .35381 .4799 .34801 .47038 .33708 Mtetra
.47038 .33708 .4799 .34801 .49681 .34216 .48736 .33116 Mtetra
.48736 .33116 .49681 .34216 .51384 .33625 .50445 .3252 Mtetra
.656 .748 .917 r
.50445 .3252 .51384 .33625 .53097 .33027 .52165 .31925 Mtetra
.653 .749 .92 r
.52165 .31925 .53097 .33027 .5482 .32428 .53896 .31337 Mtetra
.653 .752 .923 r
.53896 .31337 .5482 .32428 .56554 .31838 .55637 .30748 Mtetra
.655 .755 .923 r
.55637 .30748 .56554 .31838 .583 .31254 .5739 .30146 Mtetra
.657 .753 .921 r
.5739 .30146 .583 .31254 .60056 .30658 .59154 .29534 Mtetra
.658 .751 .919 r
.59154 .29534 .60056 .30658 .61824 .30049 .60928 .28912 Mtetra
.658 .75 .918 r
.60928 .28912 .61824 .30049 .63602 .2943 .62714 .28287 Mtetra
.654 .749 .92 r
.62714 .28287 .63602 .2943 .65392 .2881 .64512 .27673 Mtetra
.654 .752 .922 r
.64512 .27673 .65392 .2881 .67193 .282 .66322 .27056 Mtetra
.655 .752 .921 r
.66322 .27056 .67193 .282 .69007 .27585 .68143 .26428 Mtetra
.657 .752 .92 r
.68143 .26428 .69007 .27585 .70831 .2696 .69976 .2579 Mtetra
.657 .751 .919 r
.69976 .2579 .70831 .2696 .72668 .26323 .7182 .25146 Mtetra
.655 .75 .92 r
.7182 .25146 .72668 .26323 .74516 .25687 .73677 .24509 Mtetra
.655 .751 .921 r
.73677 .24509 .74516 .25687 .76377 .25054 .75546 .23868 Mtetra
.655 .752 .921 r
.75546 .23868 .76377 .25054 .78249 .24416 .77428 .2322 Mtetra
.655 .751 .92 r
.11084 .44802 .12173 .45756 .13661 .45241 .12576 .44286 Mtetra
.657 .752 .92 r
.12576 .44286 .13661 .45241 .15158 .44719 .14078 .43761 Mtetra
.14078 .43761 .15158 .44719 .16664 .44196 .15589 .4323 Mtetra
.656 .752 .92 r
.15589 .4323 .16664 .44196 .18177 .43679 .17108 .42701 Mtetra
.654 .75 .92 r
.17108 .42701 .18177 .43679 .19699 .43158 .18635 .42176 Mtetra
.655 .751 .92 r
.18635 .42176 .19699 .43158 .21231 .42628 .20172 .41644 Mtetra
.656 .752 .92 r
.20172 .41644 .21231 .42628 .22773 .42088 .21719 .41104 Mtetra
.658 .753 .921 r
.21719 .41104 .22773 .42088 .24324 .41547 .23275 .40555 Mtetra
.657 .753 .921 r
.23275 .40555 .24324 .41547 .25883 .41016 .2484 .40005 Mtetra
.654 .749 .92 r
.2484 .40005 .25883 .41016 .27451 .40482 .26414 .39464 Mtetra
.26414 .39464 .27451 .40482 .29029 .3994 .27997 .38921 Mtetra
.655 .75 .92 r
.27997 .38921 .29029 .3994 .30617 .39389 .29591 .3837 Mtetra
.656 .752 .921 r
.29591 .3837 .30617 .39389 .32215 .38825 .31194 .37813 Mtetra
.657 .755 .922 r
.31194 .37813 .32215 .38825 .33822 .38261 .32807 .37246 Mtetra
.658 .756 .922 r
.32807 .37246 .33822 .38261 .35439 .37703 .34431 .36672 Mtetra
.658 .754 .921 r
.34431 .36672 .35439 .37703 .37066 .37147 .36064 .36097 Mtetra
.657 .751 .919 r
.36064 .36097 .37066 .37147 .38702 .36587 .37707 .35521 Mtetra
.656 .749 .918 r
.37707 .35521 .38702 .36587 .40348 .36023 .3936 .34946 Mtetra
.656 .748 .918 r
.3936 .34946 .40348 .36023 .42005 .35453 .41023 .34368 Mtetra
.656 .747 .917 r
.41023 .34368 .42005 .35453 .43672 .34877 .42697 .33786 Mtetra
.656 .748 .917 r
.42697 .33786 .43672 .34877 .4535 .34295 .44381 .33199 Mtetra
.656 .748 .918 r
.44381 .33199 .4535 .34295 .47038 .33708 .46075 .32609 Mtetra
.655 .748 .919 r
.46075 .32609 .47038 .33708 .48736 .33116 .4778 .3202 Mtetra
.654 .75 .92 r
.4778 .3202 .48736 .33116 .50445 .3252 .49496 .31429 Mtetra
.654 .752 .922 r
.49496 .31429 .50445 .3252 .52165 .31925 .51223 .30838 Mtetra
.654 .755 .924 r
.51223 .30838 .52165 .31925 .53896 .31337 .5296 .30239 Mtetra
.656 .755 .923 r
.5296 .30239 .53896 .31337 .55637 .30748 .54709 .2963 Mtetra
.657 .752 .92 r
.54709 .2963 .55637 .30748 .5739 .30146 .56469 .29014 Mtetra
.658 .751 .919 r
.56469 .29014 .5739 .30146 .59154 .29534 .5824 .28389 Mtetra
.657 .75 .918 r
.5824 .28389 .59154 .29534 .60928 .28912 .60023 .27762 Mtetra
.654 .749 .919 r
.60023 .27762 .60928 .28912 .62714 .28287 .61817 .27143 Mtetra
.654 .752 .922 r
.61817 .27143 .62714 .28287 .64512 .27673 .63622 .26523 Mtetra
.655 .753 .922 r
.63622 .26523 .64512 .27673 .66322 .27056 .6544 .25893 Mtetra
.657 .752 .92 r
.6544 .25893 .66322 .27056 .68143 .26428 .67269 .25253 Mtetra
.657 .751 .919 r
.67269 .25253 .68143 .26428 .69976 .2579 .69109 .24605 Mtetra
.656 .75 .92 r
.69109 .24605 .69976 .2579 .7182 .25146 .70963 .23961 Mtetra
.655 .751 .921 r
.70963 .23961 .7182 .25146 .73677 .24509 .72828 .23317 Mtetra
.655 .752 .921 r
.72828 .23317 .73677 .24509 .75546 .23868 .74706 .22667 Mtetra
.656 .752 .92 r
.74706 .22667 .75546 .23868 .77428 .2322 .76595 .22006 Mtetra
.654 .75 .92 r
.09984 .43838 .11084 .44802 .12576 .44286 .1148 .43318 Mtetra
.656 .751 .92 r
.1148 .43318 .12576 .44286 .14078 .43761 .12986 .4279 Mtetra
.657 .752 .92 r
.12986 .4279 .14078 .43761 .15589 .4323 .14502 .42255 Mtetra
.14502 .42255 .15589 .4323 .17108 .42701 .16027 .41716 Mtetra
.655 .751 .92 r
.16027 .41716 .17108 .42701 .18635 .42176 .1756 .4118 Mtetra
.654 .75 .92 r
.1756 .4118 .18635 .42176 .20172 .41644 .19101 .40646 Mtetra
.655 .751 .92 r
.19101 .40646 .20172 .41644 .21719 .41104 .20653 .40104 Mtetra
.656 .752 .92 r
.20653 .40104 .21719 .41104 .23275 .40555 .22214 .39555 Mtetra
.658 .754 .921 r
.22214 .39555 .23275 .40555 .2484 .40005 .23785 .38997 Mtetra
.657 .753 .921 r
.23785 .38997 .2484 .40005 .26414 .39464 .25366 .38438 Mtetra
.655 .75 .92 r
.25366 .38438 .26414 .39464 .27997 .38921 .26955 .37884 Mtetra
.654 .749 .919 r
.26955 .37884 .27997 .38921 .29591 .3837 .28554 .3733 Mtetra
.654 .749 .92 r
.28554 .3733 .29591 .3837 .31194 .37813 .30163 .36772 Mtetra
.655 .751 .92 r
.30163 .36772 .31194 .37813 .32807 .37246 .31781 .36206 Mtetra
.656 .753 .921 r
.31781 .36206 .32807 .37246 .34431 .36672 .3341 .35635 Mtetra
.656 .755 .922 r
.3341 .35635 .34431 .36672 .36064 .36097 .3505 .35059 Mtetra
.657 .756 .923 r
.3505 .35059 .36064 .36097 .37707 .35521 .36699 .34476 Mtetra
.36699 .34476 .37707 .35521 .3936 .34946 .38358 .33891 Mtetra
.656 .755 .923 r
.38358 .33891 .3936 .34946 .41023 .34368 .40028 .33304 Mtetra
.656 .754 .922 r
.40028 .33304 .41023 .34368 .42697 .33786 .41708 .32715 Mtetra
.655 .754 .923 r
.41708 .32715 .42697 .33786 .44381 .33199 .43399 .32124 Mtetra
.655 .755 .923 r
.43399 .32124 .44381 .33199 .46075 .32609 .451 .31531 Mtetra
.655 .755 .924 r
.451 .31531 .46075 .32609 .4778 .3202 .46812 .30935 Mtetra
.655 .756 .924 r
.46812 .30935 .4778 .3202 .49496 .31429 .48535 .30333 Mtetra
.656 .755 .923 r
.48535 .30333 .49496 .31429 .51223 .30838 .50269 .29724 Mtetra
.656 .753 .921 r
.50269 .29724 .51223 .30838 .5296 .30239 .52014 .2911 Mtetra
.657 .751 .919 r
.52014 .2911 .5296 .30239 .54709 .2963 .5377 .28489 Mtetra
.657 .75 .919 r
.5377 .28489 .54709 .2963 .56469 .29014 .55538 .27862 Mtetra
.657 .75 .918 r
.55538 .27862 .56469 .29014 .5824 .28389 .57316 .27235 Mtetra
.654 .75 .92 r
.57316 .27235 .5824 .28389 .60023 .27762 .59106 .26613 Mtetra
.654 .752 .922 r
.59106 .26613 .60023 .27762 .61817 .27143 .60908 .25988 Mtetra
.655 .753 .922 r
.60908 .25988 .61817 .27143 .63622 .26523 .62722 .25355 Mtetra
.656 .752 .92 r
.62722 .25355 .63622 .26523 .6544 .25893 .64547 .24712 Mtetra
.657 .752 .919 r
.64547 .24712 .6544 .25893 .67269 .25253 .66384 .24061 Mtetra
.656 .75 .919 r
.66384 .24061 .67269 .25253 .69109 .24605 .68233 .23411 Mtetra
.655 .751 .921 r
.68233 .23411 .69109 .24605 .70963 .23961 .70095 .22763 Mtetra
.655 .752 .921 r
.70095 .22763 .70963 .23961 .72828 .23317 .71969 .2211 Mtetra
.656 .752 .921 r
.71969 .2211 .72828 .23317 .74706 .22667 .73855 .21449 Mtetra
.657 .752 .92 r
.73855 .21449 .74706 .22667 .76595 .22006 .75753 .20777 Mtetra
.655 .751 .92 r
.0887 .42865 .09984 .43838 .1148 .43318 .10372 .42337 Mtetra
.654 .75 .92 r
.10372 .42337 .1148 .43318 .12986 .4279 .11883 .41808 Mtetra
.656 .752 .92 r
.11883 .41808 .12986 .4279 .14502 .42255 .13403 .41269 Mtetra
.657 .752 .92 r
.13403 .41269 .14502 .42255 .16027 .41716 .14933 .40725 Mtetra
.14933 .40725 .16027 .41716 .1756 .4118 .16472 .40178 Mtetra
.655 .751 .92 r
.16472 .40178 .1756 .4118 .19101 .40646 .18019 .39633 Mtetra
.654 .75 .92 r
.18019 .39633 .19101 .40646 .20653 .40104 .19576 .39089 Mtetra
.655 .751 .92 r
.19576 .39089 .20653 .40104 .22214 .39555 .21142 .38538 Mtetra
.656 .752 .92 r
.21142 .38538 .22214 .39555 .23785 .38997 .22718 .3798 Mtetra
.657 .753 .921 r
.22718 .3798 .23785 .38997 .25366 .38438 .24304 .37414 Mtetra
.24304 .37414 .25366 .38438 .26955 .37884 .259 .36844 Mtetra
.656 .751 .92 r
.259 .36844 .26955 .37884 .28554 .3733 .27506 .36276 Mtetra
.654 .749 .919 r
.27506 .36276 .28554 .3733 .30163 .36772 .2912 .3571 Mtetra
.2912 .3571 .30163 .36772 .31781 .36206 .30745 .35141 Mtetra
.655 .749 .92 r
.30745 .35141 .31781 .36206 .3341 .35635 .32379 .34568 Mtetra
.655 .75 .92 r
.32379 .34568 .3341 .35635 .3505 .35059 .34025 .33989 Mtetra
.655 .751 .92 r
.34025 .33989 .3505 .35059 .36699 .34476 .3568 .33405 Mtetra
.656 .753 .921 r
.3568 .33405 .36699 .34476 .38358 .33891 .37346 .32817 Mtetra
.656 .753 .922 r
.37346 .32817 .38358 .33891 .40028 .33304 .39022 .32225 Mtetra
.656 .754 .922 r
.39022 .32225 .40028 .33304 .41708 .32715 .40709 .31629 Mtetra
.40709 .31629 .41708 .32715 .43399 .32124 .42406 .31029 Mtetra
.656 .753 .922 r
.42406 .31029 .43399 .32124 .451 .31531 .44115 .30425 Mtetra
.656 .753 .921 r
.44115 .30425 .451 .31531 .46812 .30935 .45834 .29817 Mtetra
.656 .752 .92 r
.45834 .29817 .46812 .30935 .48535 .30333 .47564 .29203 Mtetra
.657 .751 .919 r
.47564 .29203 .48535 .30333 .50269 .29724 .49305 .28584 Mtetra
.657 .75 .919 r
.49305 .28584 .50269 .29724 .52014 .2911 .51057 .2796 Mtetra
.657 .75 .918 r
.51057 .2796 .52014 .2911 .5377 .28489 .5282 .27332 Mtetra
.655 .749 .919 r
.5282 .27332 .5377 .28489 .55538 .27862 .54595 .26706 Mtetra
.654 .75 .92 r
.54595 .26706 .55538 .27862 .57316 .27235 .56381 .26081 Mtetra
.654 .753 .922 r
.56381 .26081 .57316 .27235 .59106 .26613 .58179 .25451 Mtetra
.655 .753 .922 r
.58179 .25451 .59106 .26613 .60908 .25988 .59989 .24813 Mtetra
.656 .752 .92 r
.59989 .24813 .60908 .25988 .62722 .25355 .6181 .24168 Mtetra
.657 .752 .919 r
.6181 .24168 .62722 .25355 .64547 .24712 .63643 .23513 Mtetra
.656 .75 .919 r
.63643 .23513 .64547 .24712 .66384 .24061 .65489 .22859 Mtetra
.655 .751 .92 r
.65489 .22859 .66384 .24061 .68233 .23411 .67346 .22207 Mtetra
.655 .752 .921 r
.67346 .22207 .68233 .23411 .70095 .22763 .69216 .2155 Mtetra
.69216 .2155 .70095 .22763 .71969 .2211 .71099 .20887 Mtetra
.657 .752 .92 r
.71099 .20887 .71969 .2211 .73855 .21449 .72993 .20212 Mtetra
.656 .751 .919 r
.72993 .20212 .73855 .21449 .75753 .20777 .74901 .19535 Mtetra
.656 .752 .92 r
.07745 .41884 .0887 .42865 .10372 .42337 .09252 .41346 Mtetra
.655 .75 .92 r
.09252 .41346 .10372 .42337 .11883 .41808 .10768 .4081 Mtetra
.10768 .4081 .11883 .41808 .13403 .41269 .12292 .40271 Mtetra
.656 .752 .92 r
.12292 .40271 .13403 .41269 .14933 .40725 .13827 .39723 Mtetra
.657 .752 .92 r
.13827 .39723 .14933 .40725 .16472 .40178 .15371 .39169 Mtetra
.15371 .39169 .16472 .40178 .18019 .39633 .16925 .38612 Mtetra
.655 .751 .92 r
.16925 .38612 .18019 .39633 .19576 .39089 .18487 .38058 Mtetra
.654 .75 .92 r
.18487 .38058 .19576 .39089 .21142 .38538 .20058 .37504 Mtetra
.655 .751 .92 r
.20058 .37504 .21142 .38538 .22718 .3798 .2164 .36944 Mtetra
.656 .752 .92 r
.2164 .36944 .22718 .3798 .24304 .37414 .23231 .36377 Mtetra
.657 .753 .921 r
.23231 .36377 .24304 .37414 .259 .36844 .24833 .35804 Mtetra
.657 .754 .921 r
.24833 .35804 .259 .36844 .27506 .36276 .26444 .35225 Mtetra
.657 .753 .921 r
.26444 .35225 .27506 .36276 .2912 .3571 .28065 .34643 Mtetra
.656 .751 .92 r
.28065 .34643 .2912 .3571 .30745 .35141 .29696 .34061 Mtetra
.655 .749 .919 r
.29696 .34061 .30745 .35141 .32379 .34568 .31337 .3348 Mtetra
.31337 .3348 .32379 .34568 .34025 .33989 .32988 .32895 Mtetra
.32988 .32895 .34025 .33989 .3568 .33405 .3465 .32306 Mtetra
.3465 .32306 .3568 .33405 .37346 .32817 .36322 .31713 Mtetra
.656 .75 .919 r
.36322 .31713 .37346 .32817 .39022 .32225 .38005 .31115 Mtetra
.38005 .31115 .39022 .32225 .40709 .31629 .39698 .30512 Mtetra
.39698 .30512 .40709 .31629 .42406 .31029 .41402 .29904 Mtetra
.41402 .29904 .42406 .31029 .44115 .30425 .43118 .29292 Mtetra
.43118 .29292 .44115 .30425 .45834 .29817 .44844 .28674 Mtetra
.657 .749 .918 r
.44844 .28674 .45834 .29817 .47564 .29203 .46581 .28053 Mtetra
.46581 .28053 .47564 .29203 .49305 .28584 .48329 .27427 Mtetra
.655 .749 .919 r
.48329 .27427 .49305 .28584 .51057 .2796 .50088 .26802 Mtetra
.655 .75 .92 r
.50088 .26802 .51057 .2796 .5282 .27332 .51859 .26176 Mtetra
.654 .752 .921 r
.51859 .26176 .5282 .27332 .54595 .26706 .53641 .25547 Mtetra
.655 .753 .922 r
.53641 .25547 .54595 .26706 .56381 .26081 .55435 .24911 Mtetra
.656 .753 .921 r
.55435 .24911 .56381 .26081 .58179 .25451 .57241 .24269 Mtetra
.657 .752 .92 r
.57241 .24269 .58179 .25451 .59989 .24813 .59058 .23619 Mtetra
.657 .751 .919 r
.59058 .23619 .59989 .24813 .6181 .24168 .60887 .22961 Mtetra
.656 .75 .919 r
.60887 .22961 .6181 .24168 .63643 .23513 .62729 .22304 Mtetra
.655 .751 .92 r
.62729 .22304 .63643 .23513 .65489 .22859 .64582 .21648 Mtetra
.655 .752 .921 r
.64582 .21648 .65489 .22859 .67346 .22207 .66449 .20987 Mtetra
.66449 .20987 .67346 .22207 .69216 .2155 .68327 .20321 Mtetra
.657 .752 .92 r
.68327 .20321 .69216 .2155 .71099 .20887 .70218 .19644 Mtetra
.657 .751 .919 r
.70218 .19644 .71099 .20887 .72993 .20212 .72121 .18961 Mtetra
.655 .751 .92 r
.72121 .18961 .72993 .20212 .74901 .19535 .74038 .1828 Mtetra
.657 .752 .92 r
.06606 .40893 .07745 .41884 .09252 .41346 .08119 .40347 Mtetra
.656 .752 .92 r
.08119 .40347 .09252 .41346 .10768 .4081 .0964 .39801 Mtetra
.655 .75 .92 r
.0964 .39801 .10768 .4081 .12292 .40271 .1117 .39257 Mtetra
.655 .751 .92 r
.1117 .39257 .12292 .40271 .13827 .39723 .12709 .38707 Mtetra
.656 .752 .92 r
.12709 .38707 .13827 .39723 .15371 .39169 .14258 .3815 Mtetra
.657 .752 .92 r
.14258 .3815 .15371 .39169 .16925 .38612 .15817 .37587 Mtetra
.15817 .37587 .16925 .38612 .18487 .38058 .17386 .37021 Mtetra
.656 .751 .92 r
.17386 .37021 .18487 .38058 .20058 .37504 .18963 .36455 Mtetra
.654 .75 .92 r
.18963 .36455 .20058 .37504 .2164 .36944 .2055 .3589 Mtetra
.655 .75 .92 r
.2055 .3589 .2164 .36944 .23231 .36377 .22146 .35322 Mtetra
.656 .751 .92 r
.22146 .35322 .23231 .36377 .24833 .35804 .23753 .34746 Mtetra
.656 .752 .921 r
.23753 .34746 .24833 .35804 .26444 .35225 .2537 .34165 Mtetra
.656 .753 .921 r
.2537 .34165 .26444 .35225 .28065 .34643 .26997 .33578 Mtetra
.657 .754 .921 r
.26997 .33578 .28065 .34643 .29696 .34061 .28635 .32987 Mtetra
.657 .753 .921 r
.28635 .32987 .29696 .34061 .31337 .3348 .30282 .32392 Mtetra
.656 .752 .92 r
.30282 .32392 .31337 .3348 .32988 .32895 .3194 .31795 Mtetra
.656 .75 .919 r
.3194 .31795 .32988 .32895 .3465 .32306 .33608 .31195 Mtetra
.33608 .31195 .3465 .32306 .36322 .31713 .35287 .30592 Mtetra
.656 .749 .919 r
.35287 .30592 .36322 .31713 .38005 .31115 .36976 .29987 Mtetra
.36976 .29987 .38005 .31115 .39698 .30512 .38676 .29377 Mtetra
.656 .749 .918 r
.38676 .29377 .39698 .30512 .41402 .29904 .40387 .28762 Mtetra
.656 .749 .919 r
.40387 .28762 .41402 .29904 .43118 .29292 .42109 .28145 Mtetra
.655 .749 .919 r
.42109 .28145 .43118 .29292 .44844 .28674 .43842 .27524 Mtetra
.655 .75 .92 r
.43842 .27524 .44844 .28674 .46581 .28053 .45586 .26901 Mtetra
.655 .751 .921 r
.45586 .26901 .46581 .28053 .48329 .27427 .47341 .26275 Mtetra
.655 .752 .922 r
.47341 .26275 .48329 .27427 .50088 .26802 .49108 .25645 Mtetra
.655 .753 .922 r
.49108 .25645 .50088 .26802 .51859 .26176 .50886 .25009 Mtetra
.656 .753 .922 r
.50886 .25009 .51859 .26176 .53641 .25547 .52676 .24368 Mtetra
.656 .752 .921 r
.52676 .24368 .53641 .25547 .55435 .24911 .54477 .23721 Mtetra
.657 .752 .92 r
.54477 .23721 .55435 .24911 .57241 .24269 .56291 .23066 Mtetra
.657 .751 .919 r
.56291 .23066 .57241 .24269 .59058 .23619 .58116 .22406 Mtetra
.656 .75 .919 r
.58116 .22406 .59058 .23619 .60887 .22961 .59953 .21746 Mtetra
.655 .751 .92 r
.59953 .21746 .60887 .22961 .62729 .22304 .61803 .21086 Mtetra
.655 .752 .921 r
.61803 .21086 .62729 .22304 .64582 .21648 .63665 .20422 Mtetra
.63665 .20422 .64582 .21648 .66449 .20987 .6554 .19751 Mtetra
.657 .752 .92 r
.6554 .19751 .66449 .20987 .68327 .20321 .67426 .19071 Mtetra
.657 .751 .919 r
.67426 .19071 .68327 .20321 .70218 .19644 .69326 .18385 Mtetra
.656 .75 .92 r
.69326 .18385 .70218 .19644 .72121 .18961 .71238 .17699 Mtetra
.655 .751 .921 r
.71238 .17699 .72121 .18961 .74038 .1828 .73164 .17011 Mtetra
.657 .752 .92 r
.05456 .39891 .06606 .40893 .08119 .40347 .06973 .39339 Mtetra
.656 .752 .92 r
.06973 .39339 .08119 .40347 .0964 .39801 .085 .38785 Mtetra
.656 .751 .92 r
.085 .38785 .0964 .39801 .1117 .39257 .10035 .3823 Mtetra
.655 .75 .92 r
.10035 .3823 .1117 .39257 .12709 .38707 .11579 .37675 Mtetra
.655 .751 .92 r
.11579 .37675 .12709 .38707 .14258 .3815 .13133 .37116 Mtetra
.656 .752 .92 r
.13133 .37116 .14258 .3815 .15817 .37587 .14697 .36549 Mtetra
.657 .752 .921 r
.14697 .36549 .15817 .37587 .17386 .37021 .16271 .35977 Mtetra
.657 .753 .921 r
.16271 .35977 .17386 .37021 .18963 .36455 .17854 .35401 Mtetra
.656 .752 .92 r
.17854 .35401 .18963 .36455 .2055 .3589 .19447 .34823 Mtetra
.655 .75 .92 r
.19447 .34823 .2055 .3589 .22146 .35322 .2105 .34247 Mtetra
.2105 .34247 .22146 .35322 .23753 .34746 .22662 .33668 Mtetra
.22662 .33668 .23753 .34746 .2537 .34165 .24284 .33085 Mtetra
.656 .751 .92 r
.24284 .33085 .2537 .34165 .26997 .33578 .25917 .32495 Mtetra
.656 .752 .921 r
.25917 .32495 .26997 .33578 .28635 .32987 .27561 .319 Mtetra
.656 .753 .921 r
.27561 .319 .28635 .32987 .30282 .32392 .29214 .31301 Mtetra
.656 .753 .922 r
.29214 .31301 .30282 .32392 .3194 .31795 .30878 .30698 Mtetra
.656 .754 .922 r
.30878 .30698 .3194 .31795 .33608 .31195 .32553 .3009 Mtetra
.32553 .3009 .33608 .31195 .35287 .30592 .34238 .29479 Mtetra
.656 .753 .921 r
.34238 .29479 .35287 .30592 .36976 .29987 .35934 .28865 Mtetra
.35934 .28865 .36976 .29987 .38676 .29377 .37641 .28248 Mtetra
.37641 .28248 .38676 .29377 .40387 .28762 .39359 .27628 Mtetra
.655 .753 .922 r
.39359 .27628 .40387 .28762 .42109 .28145 .41087 .27004 Mtetra
.41087 .27004 .42109 .28145 .43842 .27524 .42827 .26377 Mtetra
.42827 .26377 .43842 .27524 .45586 .26901 .44579 .25745 Mtetra
.656 .753 .922 r
.44579 .25745 .45586 .26901 .47341 .26275 .46341 .25108 Mtetra
.656 .753 .921 r
.46341 .25108 .47341 .26275 .49108 .25645 .48115 .24467 Mtetra
.656 .752 .921 r
.48115 .24467 .49108 .25645 .50886 .25009 .49901 .23821 Mtetra
.657 .752 .92 r
.49901 .23821 .50886 .25009 .52676 .24368 .51699 .23168 Mtetra
.657 .751 .919 r
.51699 .23168 .52676 .24368 .54477 .23721 .53508 .22509 Mtetra
.657 .75 .919 r
.53508 .22509 .54477 .23721 .56291 .23066 .55329 .21847 Mtetra
.655 .75 .919 r
.55329 .21847 .56291 .23066 .58116 .22406 .57162 .21186 Mtetra
.655 .751 .921 r
.57162 .21186 .58116 .22406 .59953 .21746 .59008 .20522 Mtetra
.655 .752 .921 r
.59008 .20522 .59953 .21746 .61803 .21086 .60866 .19853 Mtetra
.60866 .19853 .61803 .21086 .63665 .20422 .62736 .19179 Mtetra
.657 .752 .92 r
.62736 .19179 .63665 .20422 .6554 .19751 .64619 .18495 Mtetra
.657 .751 .919 r
.64619 .18495 .6554 .19751 .67426 .19071 .66515 .17804 Mtetra
.656 .75 .92 r
.66515 .17804 .67426 .19071 .69326 .18385 .68423 .17114 Mtetra
.655 .751 .92 r
.68423 .17114 .69326 .18385 .71238 .17699 .70345 .16422 Mtetra
.655 .752 .921 r
.70345 .16422 .71238 .17699 .73164 .17011 .72279 .15726 Mtetra
.656 .752 .92 r
.04292 .38876 .05456 .39891 .06973 .39339 .05814 .38321 Mtetra
.657 .752 .92 r
.05814 .38321 .06973 .39339 .085 .38785 .07346 .3776 Mtetra
.656 .752 .92 r
.07346 .3776 .085 .38785 .10035 .3823 .08887 .37196 Mtetra
.656 .751 .92 r
.08887 .37196 .10035 .3823 .11579 .37675 .10437 .3663 Mtetra
.655 .75 .92 r
.10437 .3663 .11579 .37675 .13133 .37116 .11996 .36066 Mtetra
.11996 .36066 .13133 .37116 .14697 .36549 .13565 .35498 Mtetra
.656 .752 .92 r
.13565 .35498 .14697 .36549 .16271 .35977 .15143 .34921 Mtetra
.656 .752 .921 r
.15143 .34921 .16271 .35977 .17854 .35401 .16732 .3434 Mtetra
.657 .753 .921 r
.16732 .3434 .17854 .35401 .19447 .34823 .18331 .33754 Mtetra
.657 .752 .921 r
.18331 .33754 .19447 .34823 .2105 .34247 .1994 .33165 Mtetra
.656 .751 .92 r
.1994 .33165 .2105 .34247 .22662 .33668 .21559 .32574 Mtetra
.655 .75 .919 r
.21559 .32574 .22662 .33668 .24284 .33085 .23187 .31984 Mtetra
.23187 .31984 .24284 .33085 .25917 .32495 .24826 .3139 Mtetra
.655 .75 .92 r
.24826 .3139 .25917 .32495 .27561 .319 .26475 .30792 Mtetra
.655 .751 .92 r
.26475 .30792 .27561 .319 .29214 .31301 .28134 .30188 Mtetra
.656 .752 .92 r
.28134 .30188 .29214 .31301 .30878 .30698 .29805 .2958 Mtetra
.656 .752 .921 r
.29805 .2958 .30878 .30698 .32553 .3009 .31486 .28967 Mtetra
.31486 .28967 .32553 .3009 .34238 .29479 .33177 .2835 Mtetra
.656 .753 .921 r
.33177 .2835 .34238 .29479 .35934 .28865 .3488 .2773 Mtetra
.3488 .2773 .35934 .28865 .37641 .28248 .36594 .27105 Mtetra
.36594 .27105 .37641 .28248 .39359 .27628 .38318 .26477 Mtetra
.38318 .26477 .39359 .27628 .41087 .27004 .40054 .25844 Mtetra
.656 .752 .921 r
.40054 .25844 .41087 .27004 .42827 .26377 .41801 .25207 Mtetra
.41801 .25207 .42827 .26377 .44579 .25745 .43559 .24566 Mtetra
.656 .752 .92 r
.43559 .24566 .44579 .25745 .46341 .25108 .45329 .23919 Mtetra
.656 .751 .92 r
.45329 .23919 .46341 .25108 .48115 .24467 .47111 .23267 Mtetra
.657 .751 .919 r
.47111 .23267 .48115 .24467 .49901 .23821 .48904 .2261 Mtetra
.657 .75 .919 r
.48904 .2261 .49901 .23821 .51699 .23168 .5071 .21949 Mtetra
.656 .75 .919 r
.5071 .21949 .51699 .23168 .53508 .22509 .52527 .21287 Mtetra
.655 .751 .92 r
.52527 .21287 .53508 .22509 .55329 .21847 .54356 .20623 Mtetra
.655 .752 .921 r
.54356 .20623 .55329 .21847 .57162 .21186 .56197 .19955 Mtetra
.56197 .19955 .57162 .21186 .59008 .20522 .58051 .19282 Mtetra
.656 .752 .921 r
.58051 .19282 .59008 .20522 .60866 .19853 .59917 .18603 Mtetra
.657 .752 .92 r
.59917 .18603 .60866 .19853 .62736 .19179 .61796 .17914 Mtetra
.657 .751 .919 r
.61796 .17914 .62736 .19179 .64619 .18495 .63687 .1722 Mtetra
.656 .75 .92 r
.63687 .1722 .64619 .18495 .66515 .17804 .65592 .16527 Mtetra
.655 .751 .92 r
.65592 .16527 .66515 .17804 .68423 .17114 .67509 .1583 Mtetra
.655 .752 .921 r
.67509 .1583 .68423 .17114 .70345 .16422 .69439 .1513 Mtetra
.656 .752 .921 r
.69439 .1513 .70345 .16422 .72279 .15726 .71383 .14422 Mtetra
.655 .751 .92 r
.03116 .37846 .04292 .38876 .05814 .38321 .04642 .37289 Mtetra
.656 .752 .92 r
.04642 .37289 .05814 .38321 .07346 .3776 .06179 .36723 Mtetra
.657 .752 .92 r
.06179 .36723 .07346 .3776 .08887 .37196 .07725 .36153 Mtetra
.656 .752 .92 r
.07725 .36153 .08887 .37196 .10437 .3663 .09281 .35579 Mtetra
.09281 .35579 .10437 .3663 .11996 .36066 .10846 .35003 Mtetra
.655 .75 .92 r
.10846 .35003 .11996 .36066 .13565 .35498 .1242 .34428 Mtetra
.1242 .34428 .13565 .35498 .15143 .34921 .14004 .33849 Mtetra
.656 .751 .92 r
.14004 .33849 .15143 .34921 .16732 .3434 .15598 .33265 Mtetra
.656 .752 .921 r
.15598 .33265 .16732 .3434 .18331 .33754 .17202 .32674 Mtetra
.656 .753 .921 r
.17202 .32674 .18331 .33754 .1994 .33165 .18817 .32078 Mtetra
.657 .753 .921 r
.18817 .32078 .1994 .33165 .21559 .32574 .20441 .31479 Mtetra
.656 .752 .921 r
.20441 .31479 .21559 .32574 .23187 .31984 .22076 .30876 Mtetra
.656 .751 .92 r
.22076 .30876 .23187 .31984 .24826 .3139 .23721 .3027 Mtetra
.655 .75 .919 r
.23721 .3027 .24826 .3139 .26475 .30792 .25377 .29663 Mtetra
.25377 .29663 .26475 .30792 .28134 .30188 .27043 .29053 Mtetra
.27043 .29053 .28134 .30188 .29805 .2958 .28719 .28439 Mtetra
.655 .75 .92 r
.28719 .28439 .29805 .2958 .31486 .28967 .30406 .27821 Mtetra
.30406 .27821 .31486 .28967 .33177 .2835 .32105 .27198 Mtetra
.656 .751 .92 r
.32105 .27198 .33177 .2835 .3488 .2773 .33814 .2657 Mtetra
.33814 .2657 .3488 .2773 .36594 .27105 .35534 .25938 Mtetra
.35534 .25938 .36594 .27105 .38318 .26477 .37266 .25302 Mtetra
.37266 .25302 .38318 .26477 .40054 .25844 .39008 .2466 Mtetra
.656 .751 .919 r
.39008 .2466 .40054 .25844 .41801 .25207 .40763 .24014 Mtetra
.656 .75 .919 r
.40763 .24014 .41801 .25207 .43559 .24566 .42528 .23364 Mtetra
.42528 .23364 .43559 .24566 .45329 .23919 .44306 .22708 Mtetra
.44306 .22708 .45329 .23919 .47111 .23267 .46095 .2205 Mtetra
.655 .75 .919 r
.46095 .2205 .47111 .23267 .48904 .2261 .47896 .2139 Mtetra
.655 .751 .92 r
.47896 .2139 .48904 .2261 .5071 .21949 .49708 .20726 Mtetra
.655 .752 .921 r
.49708 .20726 .5071 .21949 .52527 .21287 .51533 .20058 Mtetra
.51533 .20058 .52527 .21287 .54356 .20623 .53371 .19385 Mtetra
.53371 .19385 .54356 .20623 .56197 .19955 .5522 .18708 Mtetra
.656 .752 .921 r
.5522 .18708 .56197 .19955 .58051 .19282 .57082 .18022 Mtetra
.657 .752 .92 r
.57082 .18022 .58051 .19282 .59917 .18603 .58957 .1733 Mtetra
.656 .751 .919 r
.58957 .1733 .59917 .18603 .61796 .17914 .60844 .16633 Mtetra
.656 .75 .92 r
.60844 .16633 .61796 .17914 .63687 .1722 .62744 .15936 Mtetra
.655 .751 .921 r
.62744 .15936 .63687 .1722 .65592 .16527 .64657 .15236 Mtetra
.655 .752 .921 r
.64657 .15236 .65592 .16527 .67509 .1583 .66583 .14531 Mtetra
.656 .752 .921 r
.66583 .14531 .67509 .1583 .69439 .1513 .68523 .13819 Mtetra
.657 .752 .92 r
.68523 .13819 .69439 .1513 .71383 .14422 .70475 .13098 Mtetra
.655 .751 .92 r
.01927 .36806 .03116 .37846 .04642 .37289 .03458 .36241 Mtetra
.03458 .36241 .04642 .37289 .06179 .36723 .04999 .35673 Mtetra
.656 .752 .92 r
.04999 .35673 .06179 .36723 .07725 .36153 .0655 .35098 Mtetra
.0655 .35098 .07725 .36153 .09281 .35579 .08111 .34517 Mtetra
.08111 .34517 .09281 .35579 .10846 .35003 .09682 .33934 Mtetra
.09682 .33934 .10846 .35003 .1242 .34428 .11262 .33347 Mtetra
.655 .751 .92 r
.11262 .33347 .1242 .34428 .14004 .33849 .12851 .3276 Mtetra
.655 .75 .92 r
.12851 .3276 .14004 .33849 .15598 .33265 .14451 .32171 Mtetra
.655 .751 .92 r
.14451 .32171 .15598 .33265 .17202 .32674 .1606 .31577 Mtetra
.656 .752 .92 r
.1606 .31577 .17202 .32674 .18817 .32078 .1768 .30977 Mtetra
.656 .752 .921 r
.1768 .30977 .18817 .32078 .20441 .31479 .19311 .30372 Mtetra
.656 .753 .921 r
.19311 .30372 .20441 .31479 .22076 .30876 .20952 .29763 Mtetra
.20952 .29763 .22076 .30876 .23721 .3027 .22603 .29149 Mtetra
.656 .752 .921 r
.22603 .29149 .23721 .3027 .25377 .29663 .24265 .28532 Mtetra
.656 .752 .92 r
.24265 .28532 .25377 .29663 .27043 .29053 .25937 .27911 Mtetra
.656 .751 .92 r
.25937 .27911 .27043 .29053 .28719 .28439 .2762 .27287 Mtetra
.656 .75 .92 r
.2762 .27287 .28719 .28439 .30406 .27821 .29314 .26659 Mtetra
.656 .75 .919 r
.29314 .26659 .30406 .27821 .32105 .27198 .31019 .26027 Mtetra
.31019 .26027 .32105 .27198 .33814 .2657 .32735 .25392 Mtetra
.32735 .25392 .33814 .2657 .35534 .25938 .34462 .24752 Mtetra
.34462 .24752 .35534 .25938 .37266 .25302 .36201 .24108 Mtetra
.36201 .24108 .37266 .25302 .39008 .2466 .3795 .2346 Mtetra
.3795 .2346 .39008 .2466 .40763 .24014 .39712 .22809 Mtetra
.656 .75 .92 r
.39712 .22809 .40763 .24014 .42528 .23364 .41485 .22153 Mtetra
.655 .751 .92 r
.41485 .22153 .42528 .23364 .44306 .22708 .43269 .21493 Mtetra
.655 .752 .921 r
.43269 .21493 .44306 .22708 .46095 .2205 .45066 .2083 Mtetra
.45066 .2083 .46095 .2205 .47896 .2139 .46874 .20162 Mtetra
.46874 .20162 .47896 .2139 .49708 .20726 .48695 .1949 Mtetra
.48695 .1949 .49708 .20726 .51533 .20058 .50528 .18812 Mtetra
.656 .752 .921 r
.50528 .18812 .51533 .20058 .53371 .19385 .52373 .18129 Mtetra
.657 .752 .92 r
.52373 .18129 .53371 .19385 .5522 .18708 .54231 .17438 Mtetra
.657 .751 .92 r
.54231 .17438 .5522 .18708 .57082 .18022 .56101 .16742 Mtetra
.656 .75 .919 r
.56101 .16742 .57082 .18022 .58957 .1733 .57984 .16043 Mtetra
.655 .751 .92 r
.57984 .16043 .58957 .1733 .60844 .16633 .5988 .15342 Mtetra
.655 .751 .921 r
.5988 .15342 .60844 .16633 .62744 .15936 .61789 .14638 Mtetra
.655 .752 .921 r
.61789 .14638 .62744 .15936 .64657 .15236 .63711 .13928 Mtetra
.656 .752 .921 r
.63711 .13928 .64657 .15236 .66583 .14531 .65646 .13212 Mtetra
.657 .752 .92 r
.65646 .13212 .66583 .14531 .68523 .13819 .67594 .12487 Mtetra
.656 .751 .92 r
.67594 .12487 .68523 .13819 .70475 .13098 .69556 .11758 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
[(-2)] .12586 .2075 1 .99877 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.56863 .04703 m
.57247 .05235 L
s
[(2)] .56094 .0364 .72324 1 Mshowa
.125 Mabswid
.18558 .19702 m
.18832 .19985 L
s
.23703 .17687 m
.23971 .17975 L
s
.28951 .15632 m
.29214 .15925 L
s
.39772 .11395 m
.40023 .11699 L
s
.4535 .09211 m
.45595 .0952 L
s
.51046 .06981 m
.51284 .07294 L
s
.08568 .23614 m
.08851 .23887 L
s
.62804 .02377 m
.63027 .02701 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 233.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00o?ooool2o`0006[ooooo003iooooo`?o000000?oooooo`000?ooool0
JOooool00?Oooooo0_l00004ooooo`;o0000JOooool00?Cooooo0ol00006ooooo`03o`000?oooooo
000006Sooooo003;ooooo`Go00008_ooool2o`0000Wooooo00?o0000ooooool00000J?ooool00<_o
oooo00GoV9RHob4Q8Oo^k^koooooodA4A00Oooooo`?o00002oooool01?l0003oooooooooool0001W
ooooo`00c?ooool00onHV9So8B4Qonk^kP0Mooooo`?o00003_ooool01Ol0003ooooooooooooooooo
000006Kooooo003=ooooo`03oiRHV?lQ8B7ok^k^01[ooooo0_l0000Aooooo`05o`000?oooooooooo
ooooool00000I_ooool00<kooooo00?oMgMgofIVI_ooool05_ooool3o`0001?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1Sooooo`00coooool00ol0003oooooooooo`0Cooooo`;o
00000_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0H_ooool00<_ooooo00Go0000okZj^_ooooooV9RHoa0@400Booooo`?o00006Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo06;ooooo003;ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`04?ooool2o`0001cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Qooooo`00
gOooool3o`0001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Qooooo`00fooo
ool2o`00027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Pooooo`00f?ooool3
o`0002?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Oooooo`00eOooool3o`00
02Kooooo00?o0000ooooooooool01?ooool2o`00067ooooo003Cooooo`;o0000:Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo05kooooo003@ooooo`?o000000?oooooo`000?ooool0
:?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05gooooo003>ooooo`;o00001Ooo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0GOoo
ool00<_ooooo0ol0000`ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0G?ooool0
0<Wooooo0_l0000cooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Foooool00<Ko
oooo0ol0000eooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Foooool00<Cooooo
0_l0000hooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0F_ooool00<7ooooo0ol0
000jooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03_ooool5o`0004Kooooo002n
ooooo`?o0000?Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00kooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A016ooooo`00_?ooool2o`0000?ooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo1_l00003ooooo`03oiRHV?lQ8B7o
k^k^04Oooooo002iooooo`?o0000@oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00kooooo00?oV9RHob4Q8Oo^k^h0A_ooool00;Oooooo0_l00016ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03oooool00omgMgOoIVIVooooo`15ooooo`00]?ooool3o`0004Sooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Cooooo
002booooo`;o0000Boooool00ol0003oooooooooo`0=ooooo`;o00003?ooool01Ol0003o^[Zjoooo
oonHV9So410@04Kooooo002_ooooo`?o0000COooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c016ooooo`00[Oooool2o`00053ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`1Dooooo`00Z_ooool4o`00057ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1Dooooo`00Z?ooool2o`0000Cooooo00?o0000oooo
ooooool0C_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05?ooooo001nooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h08_ooool3o`0005Oooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`1Booooo`00O_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01oooooo0ol0001Joooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool0D_ooool007kooooo00Go410@oooooooo
oooooooooa0@400Mooooo`;o0000GOooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
057ooooo001nooooo`05o`000?ooooooooooooooool000006_ooool3o`0005oooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`1@ooooo`00O_ooool01Ol0003ooooooooooooooooo0000
01Sooooo0_l0001Rooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0D?ooool007ko
oooo00Go410@oooooooooooooooooa0@400Eooooo`?o0000I?ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo04oooooo001nooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool2o`00
00?ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
04kooooo001nooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04?ooool3o`0006Sooooo00?oYl3[o`00
0?ooool05_ooool00ol0003oooooooooo`1>ooooo`00TOooool2o`0006Sooooo1?nW`>/00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo04gooooo002>ooooo`?o0000J?ooool7ojO0j`03o`00
0?oooooooooo01Cooooo0ol0001>ooooo`00Roooool3o`0006Wooooo0_nX`>/7ojO0j`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool0C?ooool008Wooooo0_l0001Yooooo`KoZ<3[1_nW`>/0
0ol0003oYl3[ooooo`0Gooooo`03o`000?oooooooooo04_ooooo0026ooooo`?o0000J?ooool00onW
`>_oZ<3[ojS0j`07ojS0j`GoYl3[00?o0000ojS0joooool06?ooool00ol0003oooooooooo`1:oooo
o`00Q?ooool2o`0000;ooooo00?o0000ooooooooool0Hoooool5ojO0j`WoZ<3[0_nW`>/2ojS0j`03
o`000?nX`>_oZ<3[01Sooooo00?o0000ooooooooool0B_ooool0087ooooo0ol00005ooooo`03o`00
0?oooooooooo063ooooo2?nW`>/7ojS0j`03ojO0jonX`>_oZ<3[00;oZ<3[00Co0000ojS0jonX`>_o
Z<3[6?ooool00ol0003oooooooooo`19ooooo`00Ooooool2o`0006Wooooo2_nW`>/4ojS0j`GoYl3[
0onX`>/00ol0003oZ<3[ojS0j`02ojS0jaSooooo00?o0000ooooooooool0B?ooool007cooooo0ol0
001Xooooo`koYl3[00?oZ<3[ojO0jonW`>/01_nW`>/2ojS0j`05o`000?nX`>_oZ<3[ojS0jonW`>/0
6?ooool00ol0003oooooooooo`18ooooo`00N_ooool2o`0006Oooooo6onW`>/2ojS0j`03o`000?nX
`>_oYl3[00?oYl3[6?ooool00ol0003oooooooooo`17ooooo`00Moooool3o`0006Kooooo7onW`>/0
0onX`>_o0000ojO0j`05ojO0jaSooooo00?o0000ooooooooool0A_ooool007Cooooo0ol0001Voooo
ob?oYl3[00?o0000ojO0jonW`>/01?nW`>/Hooooo`03o`000?oooooooooo04Kooooo001booooo`;o
00000_ooool00ol0003oooooooooo`1RooooobGoYl3[00?o0000ojO0jonW`>/01OnW`>/Hooooo`03
o`000?oooooooooo04Gooooo001_ooooo`?o0000Ioooool>ojO0j`03ojNojonW`>_oYl3[01KoYl3[
00?o0000ojO0jonW`>/01OnW`>/Hooooo`03o`000?oooooooooo04Gooooo001]ooooo`;o0000Iooo
ool2ojNoj`coYl3[1OnW_n/GojO0j`03o`000?nW`>_oYl3[00KoYl3[5oooool2o`0004Kooooo001Z
ooooo`?o0000I_ooool6ojNoj`WoYl3[2?nW_n/7ojO0j`03ojNojonW`>_oYl3[00coYl3[00?o0000
ojO0jonW`>/01onW`>/Hooooo`03o`000?oooooooooo04?ooooo001Xooooo`;o0000I_ooool2ojS0
j`SoYko[2?nW`>/8ojNoj`CoYl3[1OnW_n/=ojO0j`03o`000?nW`>_oYl3[00SoYl3[5oooool00ol0
003oooooooooo`13ooooo`00IOooool3o`0006Gooooo1_nX`>/8ojNoj`SoYl3[2?nW_n/00onW`>_o
Yko[ojNoj`06ojNoj`KoYl3[00?oYko[ojO0jonW`>/00onW`>/00ol0003oYl3[ojO0j`08ojO0jaSo
oooo00?o0000ooooooooool0@_ooool006?ooooo0_l0001Uooooo`[oZ<3[1_nW_n/00onX`>_oYl3[
ojO0j`07ojO0j`KoYko[00?oZ<3[ojNojonW_n/01onW_n/4ojO0j`CoYko[1OnW`>/00ol0003oYl3[
ojO0j`08ojO0jaSooooo00?o0000ooooooooool0@Oooool0063ooooo0ol000000ooooooo0000oooo
o`1Rooooo`goZ<3[0_nW_n/5ojS0j`WoYl3[0_nW_n/5ojS0j`WoYko[00?oYl3[ojNojonW_n/01OnW
_n/4ojO0j`04o`000?nW`>_oYl3[ojNoj`SoYl3[5oooool00ol0003oooooooooo`11ooooo`00=_oo
ool5o`0002?ooooo0_l0001Vooooo`koZ<3[00?oYl3[ojS0jonX`>/01_nX`>/6ojO0j`[oZ<3[1_nW
_n/2ojS0j`SoYko[1?nW`>/00ol0003oYko[ojNoj`02ojNoj`SoYl3[5oooool00ol0003ooooooooo
o`10ooooo`00=_ooool01OnHV9So8B4Qonk^k_ooooooA4A4023ooooo0ol0001Uooooo`;oYl3[3?nX
`>/5ojO0j`SoZ<3[0_nW`>/>ojS0j`;oYko[1_nX`>/8ojNoj`04ojO0jonW_n_oYko[o`0000GoYko[
1onW`>/Hooooo`03o`000?oooooooooo03oooooo000^ooooo`Ko00000oooool00onHV9So8B4Qonk^
kP0Nooooo`?o0000IOooool6ojO0j`WoZ<3[2?nW`>/6ojS0j`03ojO0jonX`>_oZ<3[01OoZ<3[1_nW
_n/01OnX`>_oYko[ojNojonW_n_o000000GoYko[2?nW`>/Gooooo`03o`000?oooooooooo03oooooo
000hooooo`03oiRHV?lQ8B7ok^k^01_ooooo0_l0001Uooooo`[oYl3[1_nX`>/:ojO0j`CoZ<3[1?nW
`>/IojS0j`;oYko[1OnX`>/2ojNoj`03o`000?nW_n_oYko[00CoYko[2?nW`>/Gooooo`03o`000?oo
oooooooo03kooooo000iooooo`03ogMgMomVIVKooooo01Oooooo0ol0001Tooooo`koYl3[0_nX`>/>
ojO0j`03ojS0jonW`>_oYl3[00GoYl3[1onX`>/00onW`>_oZ<3[ojS0j`0FojS0j`03ojNojol0003o
Yko[00?oYko[0_nX`>/8ojO0jaSooooo00?o0000ooooooooool0?Oooool003[ooooo00?o0000oooo
ooooool05?ooool2o`0006Cooooo:_nW`>/4ojS0j`CoYl3[6?nX`>/00ol0003oYko[ojS0j`05ojS0
j`SoYl3[5oooool00ol0003oooooooooo`0mooooo`00=_ooool01Ol0003o^[ZjoooooonHV9So410@
01?ooooo0ol00002ooooo`03o`000?oooooooooo05oooooo;OnW`>/00onX`>_oYl3[ojO0j`05ojO0
j`KoZ<3[00?oYl3[ojS0jonX`>/03_nX`>/00ol0003oZ<3[ojS0j`06ojS0j`OoYl3[6?ooool00ol0
003oooooooooo`0looooo`00=_ooool01OnHV9So410@o`000?lQ8B7oc<c<017ooooo0_l0001Uoooo
ocOoYl3[1?nX`>/4ojO0j`ooZ<3[00?o0000ojS0jonX`>/01onX`>/7ojO0jaKooooo0ol0000moooo
o`00BOooool3o`0006Gooooo>_nW`>/00onX`>_oYl3[ojO0j`05ojO0j`OoZ<3[00?oYl3[ojS0jonX
`>/01?nX`>/00ol0003oZ<3[ojS0j`07ojS0j`SoYl3[5oooool00ol0003oooooooooo`0kooooo`00
Aoooool2o`0006GoooooAOnW`>/4ojS0j`GoYl3[1OnX`>/00ol0003oZ<3[ojS0j`08ojS0j`SoYl3[
5oooool00ol0003oooooooooo`0jooooo`00A?ooool3o`0006CoooooBOnW`>/00onX`>_oYl3[ojO0
j`06ojO0j`CoZ<3[00?o0000ojS0jonW`>/02OnX`>/6ojO0j`03ojS0jooooooooooo01Kooooo00?o
0000ooooooooool0>Oooool0047ooooo0ol0001TooooobcoYl3[00?oYko[ojO0jonW`>/09onW`>/2
ojS0j`03ojO0jol0003oYl3[00;oYl3[2OnX`>/2ojO0j`GoZ<3[5oooool00ol0003oooooooooo`0i
ooooo`00?oooool3o`0006?ooooo3onW`>/2ojNoj`koYl3[0_nW_n/;ojO0j`GoYko[:onW`>/00ol0
003oYl3[ojO0j`02ojO0j`KoZ<3[0_nW`>/8ojS0jaOooooo00?o0000ooooooooool0>?ooool003co
oooo0ol00003ooooo`03o`000?oooooooooo05gooooo3onW`>/6ojNoj`[oYl3[1_nW_n/7ojO0j`03
ojRojonW_n_oYko[00KoYko[1_nW`>/2ojNojb;oYl3[00?o0000ojO0jonW`>/00onW`>/2ojS0j`Ko
Yl3[2?nX`>/Fooooo`03o`000?oooooooooo00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0/oooo
o`00>_ooool2o`0006?ooooo00?oYko[ojO0jonW`>/03?nW`>/:ojNoj`KoYl3[00?oZ;o[ojNojonW
_n/01onW_n/4ojO0j`CoZ;o[2?nW_n/2ojO0j`KoYko[8OnW`>/00ol0003oYl3[ojO0j`0<ojO0j`Ko
Z<3[00?oYl3[ooooooooool05Oooool00ol0003oooooooooo`06ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL0;?ooool003Oooooo0ol0001Sooooo`CoYko[2_nW`>/>ojNoj`;oYl3[1OnX_n/9ojNoj`03
ojO0jonX_n_oZ;o[00GoZ;o[1_nW_n/00onX`>_oYko[ojNoj`07ojNoj`KoYl3[00?oYko[ojO0jonW
`>/06?nW`>/00ol0003oYl3[ojO0j`0<ojO0j`;oZ<3[1OnW`>/Gooooo`03o`000?oooooooooo00Go
oooo00Go410@oooooooooooooooooa0@400/ooooo`00=Oooool2o`0006Cooooo1onW_n/6ojO0ja3o
Yko[00?oZ<3[ojRojonX_n/01_nX_n/6ojNoj`;oZ<3[2?nX_n/4ojNoj`CoZ<3[2OnW_n/2ojO0j`Go
Yko[6OnW`>/00ol0003oYl3[ojO0j`0DojO0jaKooooo00?o0000ooooooooool01Oooool01Ol0003o
oooooooooooooooo000002cooooo000booooo`?o0000I?ooool9ojNoj`CoYl3[3onW_n/5ojS0j`So
Z;o[0_nW_n/6ojS0j`SoZ;o[00?oYko[ojS0jonX`>/01OnX`>/6ojNoj`;oZ<3[2?nW_n/6ojO0j`03
ojNojonW`>_oYl3[00ooYl3[00?o0000ojO0jonW`>/05OnW`>/Fooooo`03o`000?oooooooooo00Co
oooo00Go0000ooooooooooooooooo`00000/ooooo`00<?ooool2o`0006Cooooo3OnW_n/00onW`>_o
Yko[ojNoj`0<ojNoj`03ojO0jonX`>_oZ<3[00KoZ<3[1_nX_n/:ojS0j`KoZ;o[2_nX`>/2ojNoj`Ko
Z<3[2?nW_n/2ojO0j`GoYko[4?nW`>/00ol0003oYl3[ojO0j`0EojO0jaOooooo00?o0000oooooooo
ool00oooool01Ol@413ooooooooooooooooo410@02cooooo000]ooooo`?o000000?oooooo`000?oo
ool0H?oooolLojNoj`GoYl3[2?nX`>/2ojRoj`koZ<3[0_nX_n/FojS0j`KoYko[00?oZ<3[ojNojonW
_n/01_nW_n/6ojO0j`;oYko[1onW`>/00ol0003oYl3[ojO0j`0FojO0jaKooooo0_l00004ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL0;?ooool002[ooooo0ol0001SoooooacoYko[2OnW`>/6ojS0j`;o
Yl3[3_nX`>/00onW`>_oZ<3[ojS0j`0GojS0j`;oYko[1OnX`>/8ojNoj`;oYl3[1_nW_n/6ojO0j`03
o`000?nW`>_oYl3[01OoYl3[4oooool2o`000003ooooool0003ooooo00?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0/ooooo`00:?ooool2o`0006?ooooo3onW_n/2ojO0j`coYko[3?nW`>/2ojS0j`Ko
Yl3[2_nX`>/5ojO0jaOoZ<3[00?oYl3[ojS0jonX`>/01_nX`>/6ojNoj`03ojS0jonW_n_oYko[00Oo
Yko[1OnW`>/00ol0003oYko[ojO0j`0HojO0jaKooooo00?o0000ooooooooool0<_ooool002Gooooo
0ol0001Rooooo`ooYko[1_nW`>/9ojNojaOoYl3[1_nX`>/00onW`>coYl3[ojO0j`06ojO0j`KoZ<3[
00?oYl3[ojS0jonX`>/02onX`>/4ojO0j`SoZ<3[0_nW_n/5ojS0j`WoYko[0_nW`>/00onW_n_o0000
o`000002ojNojaSoYl3[5_ooool00ol0003oooooooooo`0booooo`008oooool2o`0006;ooooo3onW
_n/:ojO0j`KoYko[6_nW`>/2ojS0j`GoYl3/2?nW`>/2ojS0j`GoYl3[2_nX`>/7ojO0j`KoZ<3[00?o
Yl3[ojS0jonX`>/01_nX`>/6ojNoj`;oZ<3[0ol000000onW_n_o0000ojNoj`02ojNoj`KoYl3[00?o
Yko[ojO0jonW`>/03onW`>/Fooooo`03o`000?oooooooooo037ooooo000Pooooo`?o0000H_ooool>
ojNoj`koYl3[0_nW_n/LojO0j`WoYl3/1_nW`>/00onW`>coYl3[ojO0j`06ojO0j`KoZ<3[0_nW`>`9
ojO0j`;oZ<3[1OnW`>/8ojS0j`;oYko[0_nX`>/3o`000003ojS0jonW_n_oYko[00;oYko[00Co0000
ojNojonW_n_oYko[0_nW`>/5ojNoja3oYl3[5oooool00ol0003oooooooooo`0`ooooo`007oooool2
o`0006;ooooo3OnW_n/OojO0j`;oYl3/2onW`>/=ojO0k0;oYl3[1OnW`>`8ojO0j`;oZ<3[1_nW`>`7
ojO0j`03ojO0k?nW`>_oYl3[00KoYl3[2?nX`>/3o`0000CoZ<3[1OnW_n/00ol0003oZ<3[ojS0j`08
ojNoja3oYl3[5_ooool00ol0003oooooooooo`0`ooooo`007oooool00ol0003oooooo`00001Ooooo
o`coYko[7onW`>/6ojO0k0OoYl3[3onW`>`00onW`>_oYl3/ojO0k006ojO0k0KoYl3[2_nW`>`4ojO0
j`CoYl3/2?nW`>/4ojS0j`?o00002?nX`>/2ojNoj`?oZ<3[00?o0000ojS0jonX`>/02?nW_n/?ojO0
jaOooooo00?o0000ooooooooool0;oooool000cooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01_ooool01?l0003oooooooooool0001Kooooo`coYko[7onW`>/:ojO0k0CoYl3[3_nW`>`5
ojO0j`SoYl3/0_nW`>/>ojO0k003ojO0jonW`>coYl3/00GoYl3/1_nW`>/00onW`>coZ<3[o`000002
o`00013oZ<3[00Co0000ojS0jonX`>_oZ<3[1_nW_n/AojO0jaOooooo00?o0000ooooooooool0;_oo
ool000cooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1_ooool2o`0000;ooooo00?o0000ooooooooool0EOooool=ojNojakoYl3[3_nW`>`00onW`>_oYl3/
ojO0k00;ojO0k003ojNojonW`>_oYl3[00KoYl3[1_nW`>`00onW_n_oYl3/ojO0k00GojO0k0;oYl3[
0_nW`>`3o`0001CoZ<3[00Co0000ojS0jonX`>_oZ<3[0_nW_n/<ojO0j`03ojNojonW`>_oYl3[00Ko
Yl3[5_ooool00ol0003oooooooooo`0^ooooo`001?ooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h0
1?ooool01Ol@413ooooooooooooooooo410@00Gooooo0_l00004ooooo`03o`000?oooooooooo057o
oooo3onW_n/LojO0ja3oYl3/0_nW`>/:ojO0k0GoYko[2?nW`>/2ojO0k0GoYko[6OnW`>`3o`0000Co
Yl3/1_nX`>/00onW`>_oZ<3[ojS0j`0;ojS0j`03o`000?nX`>_oZ<3[00_oYl3[1OnW_n/8ojO0jaKo
oooo00?o0000ooooooooool0;Oooool000kooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooo
oooooooooooo000000Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1=oooooa3o
Yko[6onW`>/@ojO0k0KoYl3[1_nW`>`9ojNoj`KoYl3[2OnW_n/6ojO0k0;oYko[3_nW`>`2o`0000So
Yl3/0_nX`>/5ojO0j`coZ<3[00Co0000ojS0jonX`>_oZ<3[1onW`>/00onX`>_oYko[ojNoj`06ojNo
j`OoYl3[5oooool00ol0003oooooooooo`0/ooooo`003oooool00omgMgOoIVIVooooo`02ooooo`05
o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
04Wooooo4?nW_n/KojO0ja3oYl3/00?oYko[ojO0jonW`>/01onW`>/2ojO0k0goYko[0_nW`>/=ojNo
j`;oYl3/1_nW_n/7ojO0k003ojNojonW`>coYl3/00?o00002_nW`>`8ojO0j`KoZ<3[00?oYl3[ojS0
jonX`>/00onX`>/00ol0003oZ<3[ojS0j`04ojO0j`GoZ<3[2?nW_n/7ojO0jaGooooo0_l0000^oooo
o`004?ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool00oooool2o`00
00Oooooo00?o0000ooooooooool0A_ooool00onW`>_oYko[ojNoj`0=ojNoja[oYl3[4?nW`>`5ojNo
j`OoYl3[00?oZ;o[ojNojonW_n/03?nW_n/00onX_n_oYko[ojNoj`0<ojNoj`;oZ;o[2?nW_n/4ojO0
k0;oYko[0ol0000>ojO0k0SoYl3[0_nX`>/5ojO0j`GoZ<3[00Co0000ojS0jonX`>_oYl3[2?nX`>/6
ojNoj`WoYl3[5_ooool00ol0003oooooooooo`0[ooooo`003?ooool01Ol0003o^[ZjoooooonHV9So
410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0@_ooool5ojO0j`ooYko[6?nW`>/>ojO0k0WoYko[1?nW`>/4ojRoj`[oYko[1OnX
_n/:ojNoj`KoZ;o[2?nW_n/00onW`>coYko[o`000002o`0000?oYko[1_nW`>`00onW_n_oYl3/ojO0
k006ojO0k0KoYl3[00?oYl3/ojO0jonW`>/01_nW`>/5ojS0j`03o`000?nX`>_oZ<3[00WoZ<3[0_nW
_n/=ojO0jaGooooo00?o0000ooooooooool0:oooool000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo03kooooo2OnW`>/?ojNojaSoYl3[2_nW`>`=ojNoj`03ojO0jonX_n_oZ;o[00GoZ;o[
1_nW_n/9ojRoj`KoYko[2_nX_n/6ojNoj`?o00001onW_n/2ojO0k0GoYko[2?nW`>`2ojO0j`GoYl3/
2?nW`>/4ojS0j`03o`000?nX`>_oZ<3[00WoZ<3[3onW`>/Fooooo`03o`000?oooooooooo02[ooooo
000Nooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0>_ooool=ojO0j`ooYko[6?nW
`>/6ojO0k0ooYko[2_nX_n/2ojNoj`goZ;o[0_nW_n/>ojRoj`;oYko[0ol00003ojRoj`KoYko[00?o
Z;o[ojNojonW_n/01_nW_n/6ojO0k003ojNojonW`>coYl3/00KoYl3/1onW`>/5ojS0j`03o`000?nX
`>_oZ<3[00WoZ<3[3onW`>/Fooooo`03o`000?oooooooooo02Wooooo000Mooooo`?o00002oooool0
0ol0003oooooooooo`0fooooo`ooYl3[3onW_n/JojO0j`;oYl3/3onW_n/<ojRoj`;oZ<3[3OnX_n/2
ojS0j`koZ;o[0ol00007ojRoj`;oYko[1OnX_n/8ojNoj`;oYl3/1OnW_n/8ojO0k0OoYl3[1OnX`>/0
0ol0003oZ<3[ojS0j`08ojS0j`KoYl3[00?oZ<3[ojO0jonW`>/01_nW`>/Fooooo`03o`000?oooooo
oooo02Wooooo000Mooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0<_ooool?ojO0
j`ooYko[7?nW`>/@ojNoj`_oZ;o[1_nX`>/9ojRoj`KoZ<3[2_nX_n/3o`0000;oZ<3[1onX_n/00onX
`>_oZ;o[ojRoj`06ojRoj`KoYko[00?oZ;o[ojNojonW_n/01_nW_n/6ojO0k0WoYl3[1OnX`>/00ol0
003oYl3[ojO0j`08ojS0j`;oYl3[1OnX`>/8ojO0jaKooooo00?o0000ooooooooool0:?ooool001go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0_ooooo`ooYl3[3onW_n/KojO0jaCo
Yko[1onX_n/2ojO0j`SoZ<3[1OnX_n/2ojO0j`SoZ<3[1_nX_n/3o`0000KoZ<3[1?nX_n/4ojS0j`So
Z;o[0_nW_n/5ojRoj`SoYko[0_nW`>`=ojO0j`;oZ<3[0_nW`>/01?l0003oYl3[ojO0jonW`>/?ojS0
j`OoYl3[5oooool00ol0003oooooooooo`0Wooooo`007Oooool2o`0000oooooo00?o0000oooooooo
ool0:oooool?ojO0j`ooYko[3?nW`>/2ojO1k0goYl3[6?nW_n/4ojRoj`GoYl3[2?nX`>/00onX_n_o
Yl3[ojO0j`04ojO0j`SoZ<3[0_nX_n/00onX`>_o0000o`00000:ojS0j`03ojRojonX`>_oZ<3[00Go
Z<3[1_nX_n/00onX`>_oZ;o[ojRoj`06ojRoj`OoYko[3_nW`>/2ojO0k0CoYl3[00Co0000ojO0jonW
`>_oYl3[3onX`>/7ojO0jaKooooo00?o0000ooooooooool09oooool001gooooo00?o0000oooooooo
ool03oooool2o`0002Sooooo3onW`>/?ojNoj`coYl3[1_nW`N`9ojO0jacoYko[00?oZ;o[ojO0jonW
`>/01_nW`>/6ojS0j`03ojO1k?nW`>_oYl3[00KoYl3[1_nX`>/01?nW`Nco0000o`000?l0000EojS0
j`;oZ;o[1OnX`>/8ojRoj`OoYko[2_nW`>/6ojO0k0CoYl3[00?o0000ojO0jonW`>/03onX`>/8ojO0
jaKooooo00?o0000ooooooooool09_ooool001gooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Rooooo`ooYl3[3onW_n/<ojO0j`[oYl7/1OnW`>/NojNoj`_oYl3[0_nX`>/5ojO1k0So
Yl3[0_nX`>/01OnW`Nco0000o`000?l0003oYl7/01ooZ<3[1_nX_n/00onX`>_oYko[ojNoj`06ojNo
j`KoYl3[0_nW_n/8ojO0k0CoYl3[00?o0000ojO0jonW`>/03onX`>/8ojO0jaKooooo00?o0000oooo
ooooool09Oooool001gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Noooooa7o
Yl3[3OnW_n/=ojO0j`goYl7/00?oYl3[ojNojonW_n/07?nW_n/=ojO0j`WoYl7/1_nW`>/01?nW`Nco
0000o`000?l00005ojO1k0KoZ<3[0_nW`N`GojS0j`;oZ;o[1OnX`>/8ojNoj`;oYl3[1_nW_n/6ojO0
k0GoYl3[00Co0000ojO0jonW`>_oYl3[1_nX`>/00onW`>_oZ<3[ojS0j`06ojS0j`OoYl3[5_ooool2
o`0002Kooooo000Looooo`?o00005?ooool00ol0003oooooooooo`0JoooooaGoYl3[2OnW_n/?ojO0
j`goYl7/7_nW_n/2ojO0k0[oYl3[3OnW`N`2ojO0j`04ojO1k?l0003o0000o`0000WoYl7/0_nX`>/6
ojO1k0KoZ<3[00?oYl7/ojS0jonX`>/05OnX`>/6ojNoj`;oZ<3[2?nW_n/2ojO0k0WoYl3[00Co0000
ojO0jonW`>_oYl3[0_nX`>/5ojO0j`SoZ<3[1onW`>/Dooooo`03o`000?oooooo000002Kooooo000L
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool05ooooolHojO0j`OoYko[3_nW`>/2
ojO0k0[oYl7/7_nW_n/6ojO0k0KoYl3[3onW`N`01?nW`>co0000o`000?l0000;ojO1k0;oYl3/2?nW
`N`2ojS0j`GoYl7/5onX`>/2ojNoj`KoZ<3[1_nW_n/00onX`>_oYl3[ojO0j`0:ojO0j`03o`000?nW
`>_oYl3[00SoYl3[1onX`>/8ojO0jaKooooo00?o0000ooooooooool08oooool000[ooooo1?l00000
2?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^1_ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo01Cooooo6onW`>/7ojNoj`[oYl3[1_nW`>`6ojO1k1koYko[0_nW`N`8ojO0k0;o
Yl3[3onW`N`01OnW`>co0000o`000?l0003oYl3/00[oYl7/1_nW`>`6ojO1k003ojK0k?nW`NcoYl7/
00KoYl7/1_nX`>/00onW`NcoZ<3[ojS0j`0FojS0j`;oYko[1OnX`>/;ojO0j`03o`000?nW`>_oYl3[
00WoYl3[1onX`>/8ojO0jaGooooo00?o0000ooooooooool08oooool000cooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`0Aooooo`goYl3[0_nX`>/=ojO0j`WoYko[2OnW`>/7ojO0k0;oYl7/7_nW_n/6ojO1
k0KoYl3/3onW`N`01?nW_n_o0000o`000?l00005ojO0k0KoYl7/0_nW_n/8ojO0k0;oYl7/1OnV`>`8
ojO1k0;oZ<3[1OnW`N`OojS0j`KoYl3[00?oYko[ojO0jonW`>/00_nW`>/00ol0003oYl3[ojO0j`08
ojO0j`OoZ<3[1_nW`>/2ojS0jaKooooo00?o0000ooooooooool08_ooool00003ooooool0003o0000
00Co00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool2
o`0001Wooooo00?o0000ooooooooool03_ooool<ojO0j`KoZ<3[2OnW`>/=ojNoj`WoYl3[1OnW`>`2
ojO0jacoYko[2_nW`N`2ojO0k0ooYl7/0_nW_n/2o`000003ojNojonW`>coYl3/00KoYl3/0_nW`N`6
ojNoj`KoYl3/00?oYko[ojK0k?nV`>`01_nV`>`6ojO1k003ojJok?nW`NcoYl7/00KoYl7/1_nX`>/0
0onW`NcoZ<3[ojS0j`0FojS0j`;oYl3[1OnW_n/4ojO0j`03o`000?nW`>_oYl3[00SoYl3[1onX`>/2
ojO0j`KoZ<3[5_ooool00ol0003oooooooooo`0Qooooo`003?ooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo00[ooooo3_nW`>/8ojS0j`KoYl3[3_nW_n/;ojO0j`03ojO0k?nW`>_oYl3[00CoYl3[6?nW_n/K
ojO1k0;oYko[0ol00004ojNoj`KoYl3/0_nW_nX8ojNoj`;oYl3/1OnW_n/8ojK0k0;oYl7/1OnV_n`8
ojO1k0;oZ<3[1OnW`N`GojS0j`OoYko[1OnW`>/00ol0003oYl3[ojO0j`07ojO0ja3oZ<3[5Oooool0
0ol0003oooooooooo`0Qooooo`003?ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool000001Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Oooooo0onW_n/>
ojO0j`SoZ<3[0_nW`>/>ojNoj`goYl3[00?oZ<3[ojO0jonW`>/01_nW`>/DojNoj`?oYl3/6?nW`N`2
ojNoj`?o00002?nW_n/2ojO0k0KoYkoZ1_nW_n/00onX_n[oYko[ojNoj`06ojNoj`KoY/3/00?oYko[
ojJok?nV_n`01_nV_n`6ojO1k003ojK0k?nW`NcoYl7/00KoYl7/1_nX`>/2ojO0j`ooZ<3[1onW_n/4
ojO0j`03o`000?nW`>_oYl3[00SoYl3[3onX`>/Fooooo`03o`000?oooooooooo023ooooo000<oooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool00oooool7ojNoj`koYl3[1_nX`>/2ojO0j`goYko[3?nW`>/5
ojS0j`SoYl3[4?nW_n/7ojO0k1CoYl7/0_nW_n/3o`0000[oYko[0_nX_nX8ojNojP;oYko[1OnX_nX8
ojNoj`;oY/3/1OnW_n/8ojJok0;oYl7/1OnV`>`8ojO1k0;oZ<3[1_nW`>/>ojS0j`KoYko[1_nW`>/0
0ol0003oYl3[ojO0j`08ojO0j`ooZ<3[5_ooool00ol0003oooooooooo`0Oooooo`003?ooool00ol0
003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2o`0001kooooo00?o0000
oooooonW`>/00_nW`>/8ojNoj`koYl3[0_nX`>/6ojO0j`WoYko[3?nW`>/2ojS1j`OoZ<3[1_nW`>/?
ojNoj`;oYl3[2?nW`>`@ojO1k0;oYko[0ol0000:ojNoj`KoZ;oZ1_nW_nX9ojRojPKoYko[00?oZ;oZ
ojNojonW_n/01_nW_n/6ojJok0;oYko[1onV`>`6ojO1k0;oY/3/2?nW`>/>ojS0j`;oYko[2_nW`>/0
0ol0003oYl3[ojO0j`08ojO0j`ooZ<3[5Oooool00ol0003oooooooooo`0Oooooo`002_ooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`0L
ooooo`OoYl3[1_nW_n/>ojO0j`;oZ<3[2?nW`>/8ojNoj`WoYl3[1_nX`N/7ojS0j`;oYl3[3onW_n/6
ojO0j`KoYl3/3onW`N`01?nW_n[o0000o`000?l0000:ojNoj`[oZ;oZ0_nW_nX=ojRojP;oYko[1OnX
_nX8ojNoj`;oY[o/1_nW_n/7ojK0k0;oYl7/1_nV`>`6ojO0j`03ojO0k?nX`>_oZ<3[00coZ<3[3OnW
`>/00ol0003oYl3[ojO0j`08ojO0j`ooZ<3[5Oooool00ol0003oooooooooo`0Nooooo`006oooool0
0ol0003oooooooooo`0Jooooo`[oYl3[0_nW_n/>ojO0j`KoZ<3[2?nW`>/8ojNoj`OoYl3[2?nX`N/5
ojS0j`ooYko[2_nW`>/2ojO0k0ooYl7/00GoYkoZo`000?l0003o0000ojNojP09ojNoj`coZ;oZ00?o
Z;o[ojRoj_nX_nX05OnX_nX6ojNoj`03ojRoj_nW_n_oYko[00OoYko[0onV`>`4ojNoj`SoY/3/0_nW
`>/5ojO0k0koZ<3[3?nW`>/00ol0003oYl3[ojO0j`08ojO0j`ooZ<3[5_ooool00ol0003ooooooooo
o`0Mooooo`006oooool00ol0003oooooooooo`0Gooooo`coYl3[0_nW_n/=ojO0j`WoZ<3[1_nW`>/:
ojNoj`OoYl3[2?nX`N/00onX`>_oYko[ojNoj`0=ojNoj`coYl3[00?oZ<7/ojO1k?nW`N`03?nW`N`0
1?nW_n[o0000o`000?l00005ojNojPKoYko[2onX_nX5ojRojaOoZ;oZ0_nW_n/5ojRojPOoYko[00?o
Z;oZojNojonW_n/01_nW_n/6ojK0k003ojJok?nW`>coYl3/00GoYl3/3onX`>/6ojO0j`;oZ<3[1?nW
`>/00ol0003oYl3[ojO0j`08ojO0j`ooZ<3[5?ooool2o`0001oooooo000Kooooo`;o00005_ooool;
ojO0j`KoYko[2OnW`>/=ojS0j`;oYl3[3?nW_n/9ojO0j`KoZ<7[00?oYl3[ojNojonW_n/03_nW_n/9
ojO0j`GoZ<7/2_nW`N`2ojNojP;o00002OnW_nX2ojNoj`coZ;oZ00?oZ<3[ojRojonX_n/01OnX_n/6
ojRojP03ojS1k?nX_n[oZ;oZ00coZ;oZ00?oZ<3[ojRoj_nX_nX01_nX_nX4ojNoj`CoZ;oZ2?nW_n/2
ojK0k0GoY[o/1onW`>`?ojS0j`;oYl3[1_nX`>/4ojO0j`03o`000?nW`>_oYko[00SoYl3[3_nX`>/F
ooooo`03o`000?oooooooooo01cooooo000Jooooo`03o`000?oooooooooo01?ooooo3?nW`>/9ojNo
j`OoYl3[3OnX`>/<ojNoj`goYl3[0_nX`N/5ojO0ja3oYko[1OnW`>/9ojS1k0KoYl7/00?oYko[ojNo
j_l000000_l0000<ojNojP[oZ;oZ1OnX`>/7ojRoj`;oZ;oZ1OnX`N`:ojRojPGoZ<3[2?nX_nX00onW
_n_oZ;oZojRojP05ojRojPKoYko[00?oZ;o[ojJok?nV_n`01OnV_n`6ojO0k003ojK0k?nX`>_oZ<3[
01KoZ<3[0_nW`>/2ojNoj`03o`000?nW_n_oYko[00SoYl3[3_nX`>/Eooooo`03o`000?oooooooooo
01cooooo000Jooooo`03o`000?oooooooooo00oooooo3OnW`>/=ojNoj`OoYl3[2OnX`>/<ojNoj`oo
Yl3[0_nX`>/7ojO0ja3oYko[00?oYl3[ojS1k?nX`N`02onX`N`2ojO1k0;oYko[0ol0000@ojNojPKo
Z;oZ00?oZ<7/ojS0jonX`>/01_nX`>/5ojRoj`;oZ<;/1onX`N`6ojRojP03ojS2k?nX`>_oZ<3[00Ko
Z<3[1_nX_nX2ojS0j`SoZ;oZ0_nW_n/5ojRoj`OoY[o/0_nW`>`5ojK0k1OoZ<3[1?nW_n/00ol0003o
Yko[ojNoj`08ojO0j`ooZ<3[5Oooool00ol0003oooooooooo`0Kooooo`006_ooool00ol0003ooooo
ooooo`0;oooooa3oYl3[3OnW_n/9ojO0j`KoZ<3[0onW`>/8ojNoj`ooYl3[1_nX`>/7ojO0j`koYko[
00?oYl7/ojS1k?nX`N`02onX`N`2ojNoj`?o00001?nW_n/6ojNojP;oYko[2?nW_nX2ojRojPGoZ<7/
2?nX`>/00onX_n_oZ<;/ojS2k004ojS2k0OoZ<7/0_nX_nX5ojS2k0SoZ<3[0_nX_nX6ojS0j`KoZ;oZ
00?oZ<3ZojRojonX_n/01OnX_n/6ojJok0;oYko[1onV`>`6ojS0j`;oYl3[3onX`>/4ojNoj`03o`00
0?nW_n_oYko[00SoYl3[3onX`>/Eooooo`03o`000?oooooooooo00Kooooo1Ol0000?ooooo`006_oo
ool2o`0000Wooooo5?nW`>/9ojNoj`goYl3[0_nX`>/7ojO0j`OoYko[3OnW`>/2ojS1j`OoZ<3[1OnW
`>/<ojNoj`GoYl7/2OnX`N`2ojNoj`?o00002?nW_n/2ojNojPKoYko[1_nW_nX00onW`NcoZ<7/ojS1
k006ojS1k0KoZ<3[00?oY/3/ojS2k?nX`^`01_nX`^`5ojS1k0;oY[o/1onX`^`6ojS0j`;oZ<;/2?nX
`>/2ojRojPGoZ<3Z1onX_n/2ojJok0KoYko[1onV`>`2ojS0j`KoYl3[3_nX`>/5ojNoj`03o`000?nW
_n_oYl3[00OoYl3[1_nX`>/2ojO0j`SoZ<3[5?ooool00ol0003oooooooooo`06ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@03oooool001[ooooo00?o0000ooooooooool01_oooolGojO0j`WoYko[2_nW
`>/4ojS0j`SoYl3[1onW_n/9ojO0j`KoZ<7[1onX`>/00onW`>_oYko[ojNoj`0:ojNoj`;oYl3[1onW
`N`6ojS1k004ojS0jol0003o0000o`0001CoYko[0_nW_nX5ojO1k0SoZ<7/0_nX`>/5ojK0k0SoZ<;/
00?oZ<7/ojJok?nV_n`01?nV_n`7ojS2k0;oZ<3[1_nX`^`6ojS0j`03ojS1k?nX`>[oZ<3Z00KoZ<3Z
1OnX_n/2ojS0j`SoYko[0onV`>`4ojJok0SoYl3[3_nX`>/4ojNoj`03o`000?nW_n_oYko[00SoYl3[
0_nX`>/6ojO0j`OoZ<3[5Oooool00ol0003oooooooooo`06ooooo`03oiRHV?lQ8B7ok^k^013ooooo
000Jooooo`03o`000?oooooooooo00?ooooo6onW`>/9ojNoj`GoYl3[2OnX`>/6ojO0j`WoYko[1OnW
`>/3ojS0j`OoZ<7[0onX`>/=ojNoj`KoYl3[1onW`N`2ojS1k005ojS0jol0003o0000o`000?nX`>/0
5OnW_n/9ojO1k0KoZ<7/00?oYkkZojK0k?nV`>`01_nV`>`6ojS2k0;oY[_X1onV_n`3ojS2k0CoY[k[
2?nX`^`2ojS0j`GoZ<7/2?nX`>X00onX_n_oZ<3[ojS0j`04ojS0j`KoYko[00?oZ;o[ojJok?nV_n`0
1_nV_n`7ojO0j`ooZ<3[1?nW_n/00ol0003oYko[ojNoj`0@ojO0j`OoZ<3[5Oooool00ol0003ooooo
ooooo`06ooooo`03oiRHV?lQ8B7ok^k^00oooooo000Jooooo`03o`000?oooooooooo00ooYl3[0_nX
`>/<ojO0j`_oYko[00?oYl3[ojS0jonX`>/02onX`>/2ojO0j`goYko[00?oYl3[ojS0jonX`>/01OnX
`>/5ojS1j`;oYl3[3OnW_n/9ojO0j`GoYl7/00CoZ<7[o`000?l0003o00001OnX`>/AojNoj`goYl7/
0_nX`N`5ojNnjPSoY/3/0_nX`^`6ojJkj0GoY[o/00?oZ;SUojJnjonV_^/01_nV_^/6ojS2k003ojJo
k?nX`NcoZ<7/00KoZ<7/1_nX`>X9ojS0j`;oYko[1OnX_n/8ojJok0OoYl3[3onX`>/4ojNoj`03o`00
0?nW_n_oYko[00ooYl3[1onX`>/Eooooo`03o`000?oooooooooo00Oooooo00?oMgMgofIVI_ooool0
3_ooool001Wooooo00?o0000ojO0jonW`>/03OnW`>/6ojS0j`SoYl3[3OnW_n/00onW`>_oZ<3[ojS0
j`0;ojS0j`;oYl3[3OnW_n/2ojO0j`SoZ<3[00?oZ<7[ojO0jonW`>/01?nW`>/9ojNoj`goYl3[00?o
Yl7/ojS1jol000000_l00003ojS1j`KoZ<3[3_nW_n/>ojO1k003ojNmjOnW_^[oYkkZ00KoYkkZ1_nV
`>`2ojRfh`SoY[_X00?oY[o/ojRhiOnX^>D00onX^>D8ojJnj`;oZ<;/1OnV_n`8ojS1k0;oZ<3Z2onX
`>/00onY`>_oZ;o[ojRoj`06ojRoj`OoY[o/2?nW`>/?ojS0j`?oYko[00?oYl3[o`000?nW`>/04?nW
`>/7ojS0jaGooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0=ooooo`006Oooool0
0ol0003oYl3[ojO0j`0=ojO0j`OoZ<3[2?nW`>/9ojNoj`GoYl3[2OnX`>/6ojO0j`WoYko[1_nW`>/7
ojS0j`SoYl3[1onW_n/=ojO0j`03ojS1k?l0003o000000OoZ<7[0onX`>/=ojNoj`koYl7/1OnW_NT8
ojNnjP;oY/3/1_nX]^<6ojJkj003oj^agOnX^>GoZ;SU00GoZ;SU1_nV_^/00onX^NGoY[o/ojJok006
ojJok0KoZ<7/0_nV`>`9ojS0j`GoZL3[2?nX_n/7ojJok0SoYl3[3_nX`>/4ojO0j`03o`000?nW`>_o
Yl3[00ooYl3[2?nX`>/Cooooo`?o00001?ooool01Ol0003o^[ZjoooooonHV9So410@00oooooo000>
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooojO0j`0>ojO0j`OoZ<3[2?nW
`>/5ojNoj`WoYl3[2?nX`>/7ojO0j`GoYko[2_nW`>/7ojS0j`SoYl3[1onW_n/9ojO0j`04ojS1k?l0
003o0000o`0000;oZ<7/1_nX`N/>ojNoj`03ojO0jonW`NcoYl7/00coYl7/2?nW_NT6ojNnjP03ojRa
gonX]^?oZ;KS00OoZ;KS0_nV^nP5oj^ag@OoZ;SU0_nV_^/5ojRii@SoY[o/0_nX`N`6ojK0k0GoZ<3[
00?oZ<7[ojW0jonY`>/01_nY`>/6ojRoj`;oZ<3[1onV_n`7ojO0j`ooZ<3[1?nW`>/00ol0003oYl3[
ojO0j`0?ojO0j`SoZ<3[5?ooool00ol0003oooooooooo`02ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`03oooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00oo
Yl3[1OnX`>/:ojO0j`03ojNojonW`>_oYl3[00_oYl3[2?nX`>/7ojO0j`03ojNojonW`>_oYl3[00[o
Yl3[2OnX`>/6ojO0j`WoYko[1OnW`>/01?nX`Nco0000o`000?l00006ojS1k0;oZ<7[3_nW_n/5ojO0
j`[oYl7/3?nW_NT2ojNnjPGoZ;7O1onX]^<00onZYmCoZk7Moj^ag@06oj^ag@GoZ;SU00?o[K7KojRi
iOnX^ND01_nX^ND6ojJok0;oYk_X2?nV`>`00onX`>_oZ<7[ojS1j`03ojS1j`SoZL3[0_nX_n/6ojS0
j`OoY[o/1onW`>/?ojS0j`CoYl3[00?o0000ojO0jonW`>/03OnW`>/:ojS0jaCooooo00?o0000oooo
ooooool05Oooool000kooooo00Go410@oooooooooooooooooa0@4006ooooo`;o00000_ooool?ojO0
j`03ojS0jonW`>_oYl3[00[oYl3[0_nW_n/<ojO0j`[oZ<3[1OnW`>/3ojNoj`SoYl3[3OnX`>/2ojO0
j`goYko[00?oYl3[ojS1k?l000000_l00008ojS1k13oYko[1onW`>/6ojO1k0;oZ;kZ3?nW_NT2ojN_
g@OoZ;7O1?nX]^<4ojZWe0SoZk7M00?oZ;SUojfafon]/M/00on]/M/8ojRii@;oY[o/1_nW^nP6ojK0
k003ojFnjonX`N_oZ<7[00GoZ<7[2?nY`>/8ojS0j`?oY[o/0onV_n/8ojO0j`ooZ<3[1?nW`>/00ol0
003oYl3[ojO0j`09ojO0j`goZ<3[5Oooool00ol0003oooooooooo`0Dooooo`003_ooool01Ol0003o
oooooooooooooooo000000Kooooo00?o0000ooooooooool00oooool:ojO0j`GoZ<3[2?nW`>/6ojNo
j`SoYl3[3_nX`>/00onW`>_oYko[ojNoj`05ojNoj`OoYl3[3?nX`>/?ojNoj`?o00002?nX`N`DojNo
j`OoYl3[0_nW`N`6ojRnjPSoYkgY1_nW[md7ojRag`03ojRfhonZYmCoZZOD00GoZZOD1_n[/Md00on^
Y/oo[K7Kojfaf`05ojfaf`KoZ;WU0_n_]]h8ojNkj0;oY/3/1OnU_^/7ojS1j`SoZL3[1onX`>/7ojJo
j`KoYl3[00?oYko[ojS0jonX`>/03OnX`>/4ojO0j`03o`000?nW`>_oYl3[00KoYl3[0_nW_n/?ojS0
jaCooooo00?o0000ooooooooool05?ooool000kooooo00Go0000ooooooooooooooooo`000005oooo
o`03o`000?oooooooooo00Gooooo1onW`>/8ojS0j`OoYl3[1onW_n/8ojO0j`[oZ<3[1?nW`>/8ojNo
j`OoYl3[2?nX`>/?ojNoj`?o00000onW`>/6ojS1k003ojS1jonW_n_oYko[01CoYko[1OnW`>/3ojS1
j`OoZ;kZ0onW_NT3ojJ^g@SoYjoM1OnX/Ml00onYXLooZZODojZWe006ojZWe0CoZk7M1?n^Y/l7ojfa
f`;oZ;WU1_n_]]h6ojNkj003ojbki?nU_^_oYKk[00GoYKk[1_nX`N/2ojO0k0SoZL3[1onX`>/7ojJo
j`;oYl3[1OnW_n/?ojS0j`CoYl3[00?o0000ojO0jonW`>/00_nW`>/6ojNoj`koZ<3[5Oooool00ol0
003oooooooooo`0Cooooo`003_ooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000oooo
ooooool01_ooool7ojO0j`SoZ<3[1onW`>/7ojNoj`SoYl3[1onX`>/7ojO0j`KoYko[2OnW`>/7ojS0
j`coYko[0ol00007ojO0j`;oZ<7/1OnX`N/FojNoj`03ojO0jonX`N_oZ<7[00GoZ<7[1OnX_^X00onU
/>3oYZkMojJ^g@05ojJ^g@SoYjoM00?oZ;7OojVQconYXLl00onYXLl8ojZWe003oj^agOn^Y/oo[ZK?
00Go[ZK?1On]/M/00ond[=7o[kKNojnfgP07ojnfgP;oYk_X1On/^n@7ojFnj`;oZ<7[1_nW`>`6ojW0
j`SoZ<3[1onV_n/8ojNoj`ooZ<3[0onW`>/00onW_n_o0000ojNoj`09ojNoj`koZ<3[5Oooool00ol0
003oooooooooo`0Booooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_l00008oooo
o`OoYl3[1_nX`>/9ojO0j`GoYko[2_nW`>/7ojS0j`OoYl3[0_nW_n/=ojO0j`OoZ<3[2?nW_n/3o`00
00CoYko[1OnW`>/2ojS1k0OoZ<7[5?nW_n/2ojS2k0SoZ<7[00?oZ;kZojF`h?nU/>000onU/>07ojJ^
g@KoYjoM00?oYYk=ojVQconYXLl01OnYXLl6ojZWe003ok6Tbon^Y/oo[ZK?00Ko[ZK?0on]/M/4okB/
d@Oo[kKN00?o]K?Gojbki?n/^n@01_n/^n@5ojFnj`;oYkkZ2?nW`>`2ojW0j`coZ<3[1onV_n/8ojNo
j`koZ<3[1?nW_n/00ol0003oYko[ojNoj`08ojNoj`koZ<3[5Oooool00ol0003oooooooooo`0Boooo
o`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool02?ooool7ojO0
j`;oZ<3[3OnW`>/00onW_n_oYl3[ojO0j`0:ojO0j`WoZ<3[1OnW`>/3ojNoj`coYl3[0_nX`N/7ojS0
j`GoYko[0_l00008ojNoj`03ojO0jonX`NcoZ<7/00CoZ<7/1onX`N/@ojNoj`KoZ<;/1_nX`N/00onU
]NCoYK3PojF`h005ojF`h0OoYZkM0_nW[md5ojJNc@KoZJ7?1?nZYm@4ok6Tb`So[ZK?00?o[K7KokB/
dOnd[=401?nd[=44ojnfgPCo]K?G2?n/^n@00onU_^_oYkkZojNnjP04ojNnjPKoYl3/00?oY/3/ojS0
jonX`>/03OnX`>/7ojJoj`OoYko[3onX`>/4ojNoj`03o`000?nW_n_oYko[00SoYko[3_nX`>/Eoooo
o`03o`000?oooooooooo017ooooo000Hooooo`03o`000?oooooooooo00Wooooo1OnW`>/3ojS0j`[o
Yl3[1?nW_n/9ojO0j`goZ<3[00?oYl3[ojNojonW_n/01OnW_n/8ojO0j`KoZ<7[1OnX`>/3ojNoj`?o
00002OnW_n/2ojS0j`OoZ<7/1OnX`N/=ojNoj`CoYl7/1onX`^`2ojS1j`GoYKGT1_nU/>06ojJ^g@03
oj>Lc_nVW/goYYk=00GoYYk=1onYXLl00onZYmCo/JC;ok6Tb`04ok6Tb`Oo[ZK?00?o^J_;okB/dOnd
[=401_nd[=400on_]]ko]K?GokFce`05okFce`Ko[;_T0_nb_N87ojNnjP;oYl3/1OnV`>`?ojS0j`Oo
Y[o[1onW_n/?ojS0j`CoYko[00?o0000ojNojonW_n/01onW_n/?ojS0jaGooooo00?o0000oooooooo
ool04?ooool001Sooooo00?o0000ooooooooool02_ooool00onW`>_oZ<3[ojS0j`05ojS0j`OoYl3[
1onW_n/7ojO0j`goZ<3[0onW`>/7ojNoj`OoYl3[1onX`N/01?nX`>_oYko[ojNojonW_n/3o`0000Wo
Yko[1_nX`>/7ojS1k003ojS1jonW_n_oYko[00_oYko[2?nW`N`5ojS2k003ojNkj?nU]NCoYKGT00Ko
YKGT1_nU/>02ojJ^g@GoXic>1onVW/d5ojVQc`03ojnRbonaY<_o/JC;00Ko/JC;1On^Y/l3okV[b`Ko
]:cA00?o_k?>okFceone/mL01one/mL2ojbki0Ko/[gR1OnW_^X00onY_nWoY/3/ojK0k006ojK0k0oo
Z<3[1onV_n/7ojNoj`ooZ<3[1?nW_n/00ol0003oYko[ojNoj`07ojNoj`goZ<3[00?oYl3[oooooooo
ool04oooool2o`00017ooooo000Gooooo`?o00003Oooool7ojS0j`OoYl3[1onW_n/7ojO0j`WoZ<3[
1onW`>/5ojNoj`WoYl3[1OnX`N/2ojS0j`?o00003?nW_n/7ojS0j`?oZ<7/1?nX`>/>ojNoj`SoYl7/
00?oZ<;/ojNkj?nW^nP00onW^nP7ojFei0GoYK3P00?oX9gAoj>Lc_nSW<h01OnSW<h7ojJNc@?oZJ7?
1?n_X//7ok6Tb`?o[ZK?1_niZl/4okB/d@?o_k?>1one/mL00ono^MCo/[gRok:mhP07ok:mhP03ojNn
j_nY_nWoZKoY00?oZKoY2?nV`>`=ojS0j`03ojS1jonV_n_oY[o[00KoY[o[1_nW_n/?ojS0j`CoYko[
00?o0000ojNojonW_n/01?nW_n/4ojO0j`WoZ<3[1OnW`>/Cooooo`03o`000?oooooo0000017ooooo
000Gooooo`03o`000?oooooooooo00kooooo1onX`>/7ojO0j`SoYko[1_nW`>/8ojS0j`SoYl3[00?o
Yko[ojO0jonW`>/02onW`>/00onX`N_oZ<3[ojS0j`03o`000003ojS0jonW_n_oYko[00goYko[1OnX
`>/2ojS1j`OoZ<3[3_nW_n/6ojO1k003ojS0jonW^nSoYk_X00GoYk_X1onU]N@00onU/>3oX9gAoj2M
d@03oj2Md@OoXic>1onVW/d00onYXLoo[j;;ojnRb`03ojnRb`So/JC;00?o[ZK?okV[boniZl/01Oni
Zl/3okB/d@Go_k?>1One/mL3oknie0Oo/[gR00?o]l7RojVojOnY_nT01OnY_nT6ojK0k0;oY[o/2OnX
`>/5ojS1j`SoY[o[1_nW_n/?ojS0j`CoYko[00?o0000ojNojonW_n/02?nW`>/6ojS0j`SoYl3[5?oo
ool00ol0003oooooooooo`0?ooooo`005oooool00ol0003oooooooooo`0?ooooo`OoZ<3[1onW`>/8
ojNoj`KoYl3[2?nX`>/6ojO0j`03ojNojonW`>_oYl3[00_oYl3[00CoZ<3[o`000?l0003o00001OnX
`>/?ojNoj`03ojS0jonX`N_oZ<7[00CoZ<7[1onX`>/>ojNoj`;oYl7/1OnX`>/7ojNkj0?oYKGT0onO
XmP7oj2Md@KoXic>1_nVW/d00onZXLgo[j;;ojnRb`05ojnRb`Ko/JC;00?o^:g>okV[boniZl/01oni
Zl/00ond[=7o_k?>oknccP04oknccP?o]K?G1_no^M@4ok:mhPCo]l7R1onY_nT2ojK0k0KoY[o/1_nX
`>/8ojS1j`OoY[o[1onW_n/?ojS0j`CoYko[00?o0000ojNojonW_n/02?nW`>/6ojS0j`SoYl3[5?oo
ool00ol0003oooooooooo`0>ooooo`005oooool00ol0003oooooooooo`0@ooooo`OoZ<3[1OnW`>/:
ojNoj`?oYl3[2onX`>/2ojO0j`GoYko[2OnW`>/01?nX`>_o0000o`000?l00009ojS0j`goYko[00?o
Z<3[ojS1jonX`N/01_nX`N/5ojS0j`koYko[0_nX`^`7ojS0j`GoYk_X00?oWjgQoinSf?nOXmP01OnO
XmP6oj2Md@KoXic>1?nVW/d4ojZQc@Ko[j;;1?naY</4okR]cPOo^J_;00?o`;K@okncc_no/lh01_no
/lh00one/mOo_kWDoknie006oknie003ok:mh_ng`N;o]l7R00Co]l7R1_nY_nT2oj_1jPSoY[o/1_nX
`>/8ojS1j`OoY[o[1onW_n/>ojS0j`GoYko[00?o0000ojNojonW_n/01onW`>/7ojS0j`OoYl3[5Ooo
ool00ol0003oooooooooo`0=ooooo`005oooool2o`0001;ooooo1onX`>/00onW`>_oYko[ojNoj`0:
ojNoj`;oYl3[3?nX`>/2ojO0j`OoYko[1_nW`>/3o`0000WoZ<3[3OnW_n/5ojS0j`SoZ<7[00?oZ<3[
ojNojonW_n/03?nW_n/6ojS2k0OoZ<3[00?oYk_Xoin]hOnO[N400onO[N46oinSf0OoX9gA1_nSW<h0
0onVW/goZZ7=ojZQc@04ojZQc@Oo[j;;00?o/JC;okR]c_nh[Lh01?nh[Lh6okV[b`?o`;K@1_no/lh0
0oo5^]3o_kWDoknie006oknie003olO2eOng`N;o]l7R00Ko]l7R0_nY_nT6oj_1jPOoY[o/1onX`>/7
ojS1j`SoY[o[1onW_n/>ojS0j`CoYko[00Co0000ojNojonW_n_oYko[1onW`>/7ojS0j`OoYl3[5?oo
ool00ol0003oooooooooo`0=ooooo`005oooool00ol0003oooooooooo`0Booooo`GoZ<3[0onW`>/8
ojNoj`KoYl3[2?nX`>/6ojO0j`OoYko[0onW`>/2o`0000?oYl3[1onX`>/>ojNoj`OoZ<3[1_nX`N/2
ojO0j`koYko[1onX`^`3ojS0j`?oX[KW1onO[N46oinSf0OoX9gA0onSW<h2oj>Mc`SoZZ7=1On_X//0
0onf]m[o^:g>okR]cP06okR]cPCo^J_;1Oo0]]04oknccP?oaK[@1_no^M@3olO2e@Ko]l7R0_nka^<8
oj_1jPOoY[o/1onX`>/7ojS1j`OoY[o[2?nW_n/>ojS0j`CoYko[00?o0000ojNojonW_n/02?nW`>/6
ojS0j`SoYl3[5?ooool00ol0003oooooooooo`0<ooooo`005oooool00ol0003oooooooooo`0Coooo
o`03ojS0jonW`>_oYl3[00GoYl3[1onW_n/7ojO0j`SoZ<3[1_nW`>/5ojNoj`04ojO0jol0003o0000
o`0000KoYl3[1onX`>/>ojNoj`OoZ<3[0_nX`N/6ojO0j`GoYko[0_nV_n/7ojNoj`GoZ<;/0_nW_n/6
oj:fi`OoWjgQ1OnOXmP6oj2Md@03oibJd?nSWLooXig?00CoXig?1onZXLd3ojnRb`Co][OJ1onh[Lh3
okV[b`Ko`;K@0ono/lh5olFjd0?o_kWD1_o7`]D3okO1hPGo^lKS1_n[`NX2oj_2j`KoY[o/1_nX`>/9
ojS1j`OoY[o[2?nW_n/>ojS0j`CoYko[00?o0000ojNojonW_n/01onW`>/7ojS0j`OoYl3[5Oooool0
0ol0003oooooooooo`0;ooooo`005oooool00ol0003oooooooooo`0Eooooo`OoYl3[1onW_n/7ojO0
j`SoZ<3[1_nW`>/00onW_n_oYl3[o`000002o`0000SoYl3[2OnX`>/>ojNoj`GoZ<3[0onX`N/7ojO0
j`03ojNojonV_n_oY[o[00CoY[o[1onW_n/00onX`^coYko[ojNoj`04ojNoj`KoX[KW1onO[N45oinS
f0;oX9gA1OnLV]05oj>Mc`SoZZ7=00?o[j;;okJgf_nf]mX00onf]mX8okR]cP03okV[boo0]]3o`;K@
00Ko`;K@00?o_k?>olFjd?o5^]001Oo5^]000ono^MCoal;EolO2e@06olO2e@03okO1h_nka^?o^lKS
00Go^lKS0_n[`NX6oj_2j`KoY[o/0_nX`>/<ojS1j`SoY[o[1_nW_n/00onW`>_oZ<3[ojS0j`09ojS0
j`?oYl3[1OnW_n/00ol0003oYko[ojNoj`07ojO0j`OoZ<3[1onW`>/Dooooo`03o`000?oooooooooo
00_ooooo000Fooooo`?o00005oooool8ojO0j`KoYko[1OnW`>/:ojS0j`?oYl3[00CoYko[o`000?l0
003o00002?nW`>/=ojS0j`koYko[00?oZ<3[ojS1jonX`N/01OnX`N/5ojO0j`WoY[o[1OnW_n/2ojW2
k0OoYko[1_nR]^L3oin]h@?oTISG1OnEUm<7oibJd0KoXig?1_nZXLd00on``nSo][OJokJgfP05okJg
fPKo^:g>00?o_/gVol2fd?o0]]001_o0]]000oo3a]coaK[@olFjd006olFjd0Soal;E0_o=b]L6ok_6
h`;o^l_V2?n[`^/3ojJok0?oY[o[3_nX`N/8ojJoj`;oYko[1OnW`>/7ojS0j`OoYl3[1?nW_n/00ol0
003oYko[ojNoj`07ojO0j`OoZ<3[2?nW`>/Dooooo`03o`000?oooooooooo00[ooooo000Fooooo`03
o`000?oooooooooo01Sooooo2?nW`>/6ojNoj`03ojO0jonX`>_oZ<3[00[oZ<3[00?oYl3[ojNojol0
00000_l00004ojNoj`OoYl3[3?nX`>/=ojNoj`?oZ<3[2?nX`N/00onW`>_oY[o[ojJoj`0;ojJoj`03
ojNojonY`^coZL;/00CoZL;/1onW_n/3oj:fi`;oV:SQ1onAV=L5oiFGd`OoW9[@1OnSWLl4ojZQc@Co
/<?X1_nf]mX4okR]cPCo_/gV1_o0]]03ol?6g0KoaK[@0_o9`m@6olO2e@CocL[G0onka^<5ok_;iPKo
Zl;[00?oZL;/ojJojonV_n/01OnV_n/>ojS1j`OoY[o[2?nW`>/7ojS0j`OoYl3[1?nW_n/00ol0003o
Yko[ojNoj`07ojO0j`OoZ<3[1_nW`>/00onW_n_oooooooooo`0Aooooo`?o00002oooool000Cooooo
1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^1_ooool00ol0003oooooooooo`0J
ooooo`OoYl3[0onW_n/4ojO0j`SoZ<3[0_nW`>/3o`0000SoYko[1onW`>/8ojS0j`goYko[1onX`>/6
ojS1j`;oYl3[3?nV_n/2ojNoj`OoZL;/0onW_n/3oijej0KoV:SQ1_nAV=L5oiFGd`OoW9[@1_nSWLl0
0onZXLgo/<?Xok33j005ok33j0Ko][OJ00?o^:g>okk=i_nncNH01OnncNH3ol2fd0Ko`lKL1?o5^]04
olW3e0?oal;E1oo=b]L00onka^?o^l_Vok_;iP05ok_;iP;oZl;[1OnY`^`7ojJoj`koZ<7[1onV_n/6
ojO0j`SoZ<3[1_nW`>/6ojNoj`03o`000?nW_n_oYl3[00GoYl3[2OnX`>/2ojO0j`GoYko[3oooool3
o`0000;ooooo00?o0000ooooooooool02Oooool000Kooooo00?o0000ooooooooool00_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool06oooool5ojO0j`03ojNojonW`>_o
Yl3[00KoYl3[1_nX`>/3o`0000CoYl3[2?nW_n/7ojO0j`OoZ<3[3_nW_n/7ojS0j`;oZ<7[1_nW`>/8
ojJoj`KoYko[1OnY`^`2ojJoj`KoW[GX1OnHZ>47oi6He`GoUIOC1onLV]03oj>Mc`?oYl7/1on``nP5
okJgfP;oR^Sf2?nncNH00oo0]]3o`lKLol?6g005ol?6g0?oaK[@1_o9`m@00oo7`]GocL[Golg:e`05
olg:e`03om3CfonkbnKo^l_V00Go^l_V0_nicNT6ojW2k0KoY[o[0_nW_n/:ojS1j`CoZ<3[1onV_n/2
ojO0j`coZ<3[0_nW`>/9ojNoj`03o`000?nW_n_oYko[00;oYl3[2onX`>/00onW`>_oYko[ojNoj`06
ojNoj`_ooooo0ol00005ooooo`03o`000?oooooooooo00Wooooo0006ooooo`03o`000?oooooooooo
00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`;o00007Oooool00onW`>_oYko[ojNoj`03
ojNoj`SoYl3[0_nX`>/3o`0000;oZ<3[1_nW`>/8ojNoj`GoYl3[2OnX`>/>ojNoj`GoZ<3[0onX`N/7
ojO0j`OoY[o[1onW_n/00onY`^coY[o[ojJoj`04ojJoj`KoW[GX1OnHZ>46oi6He`GoUIOC1_nLV]00
0onN[^?oYl7/ojO1k005ojO1k0Oo/<?X00?o][OJoh[Xm_n:j?H01?n:j?H6okk=iP03oh?MoOo3a]co
`lKL00Oo`lKL00?oaK[@olW3e?o9`m@01Oo9`m@7olg:e`?od=?K1?nkbnH5okW=j@KoZL;/0_nV_n/6
ojNoj`GoZ<7[00?oZL7[ojS0jonX`>/01_nX`>/7ojJoj`coZ<3[0_nX`N/;ojNoj`03o`000?nW_n_o
Yko[00WoZ<3[1OnW`>/8ojNoj`Kooooo1?l00008ooooo`03o`000?oooooooooo00Wooooo0006oooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000005ooooo`;o00007oooool6
ojNoj`KoYl3[00?oZ<3[o`000?l000001_nX`>/3ojO0j`_oYko[00?oYl3[ojS0jonX`>/02onX`>/>
ojNoj`03ojS0jonX`N_oZ<7[00GoZ<7[1OnW`>/9ojJoj`GoYko[0_nY`N/7ojJoj`GoW[GX1OnHZ>47
oi6He`GoUIOC0_nLV]05oij^h`OoYl7/0on``nP4omc8a@03olJT]_nOR[goWhZm00?oWhZm00?oR^Sf
okk=i_nncNH01On3gOd7ol?6g003okW?joo9`mCobL?D00GobL?D0_o<b]P5olg:e`God=?K00?o^l_V
okW=jOnicNT01_nicNT3ojW2k0?oYl3/2?nW_n/00onX`N_oZL7[ojW1j`03ojW1j`SoZ<3[1onV_n/8
ojS0j`KoZ<7[2onW_n/00ol0003oYko[ojNoj`07ojS0j`OoYl3[1onW_n/3ooooo`?o00003Oooool0
0ol0003oooooooooo`08ooooo`001_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool000001Oooool00ol0003oooooooooo`0Oooooo`KoYko[0_nW`>/01?nX`>_o0000o`000?l0
0009ojS0j`coYko[0onW`>/;ojS0j`?oYl3[2_nW_n/3ojO0j`SoZ<7[00?oYl3[ojJojonV_n/02onV
_n/00onW_n_oZL7[ojW1j`04ojW1j`OoY[o[1OnN]NP5oiRXh@?oTISG0on:U]T5oi>MfPSoWZkS1OnW
`N`00ooIoloog<S5omc8a@04omc8a@;oaZBf1_nOR[d3oeYO_PGoPmgm1?o3a]`4okW?j`GobL?D1?o<
b]P3olg:e`God=?K0_o?fn87okW=j@03okC;k?nW`>coYl3/00GoYl3/1_nW_n/00onX`N_oZL7[ojW1
j`05ojW1j`KoZ<3[00?oYl3[ojJojonV_n/01_nV_n/6ojS0j`SoZ<7[2onW_n/00ol0003oYko[ojNo
j`07ojS0j`OoYl3[1onW_n/2o`00013ooooo00?o0000ooooooooool02?ooool000Kooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool08?oo
ool3ojNoj`;oYl3[0ol0000=ojS0j`SoYko[1onW`>/7ojS0j`OoYl3[1_nW_n/7ojO0j`SoZ<7[3?nV
_n/2ojNoj`OoZL7[0onV_n/3oifhj`GoSjWX1On3U]d7ohZFf@GoTigJ2?nN[^<01?nW`Nco?l2domWo
cooIoll6omc8a@?oaZBf1_nOR[d5oeYO_P05ob=5_Ol>U=ooPmgmoh?MoOo3a]`01onicn/3olW3e0Ko
c<[H00?ocL[Gom3Cfoo@dm/00oo@dm/4oloKhPCo^LgY1?ndbn`7ojO0k0;oYko[1OnX`N/7ojW1j`;o
Z<3[1OnW`>/6ojJoj`03ojNojonX`>_oZ<3[00GoZ<3[1_nX`N/00onX`>_oYko[ojNoj`09ojNoj`03
o`000?nW_n_oYl3[00SoZ<3[1_nW`>/8ojNoja7ooooo00?o0000ooooooooool02?ooool000Kooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_l0000Rooooo`04
ojO0jol0003o0000o`0000?oYl3[3_nX`>/8ojNoj`OoYl3[1_nX`>/8ojO0j`KoYko[1onW`>/8ojS1
j`SoY[o[1_nW_n/5ojW1j`03ojS1k?nM^>_oWKS[00GoWKS[1On?ZNP5oh>Fg@KoRYKI1_nCWMX6oij^
h`;oV^kf00?ofOo?onGRcooRakd01OoLb<D5olJT]PGoWhZm1OmJGkh2ob=5_@03oa]ghol>U=oo3YCO
00So^Lo[00?obL?Dolc:f?o<b]P01?o<b]P3olkAg0?od=?K1_o?fn800onicNWo]<_/okC;k004okC;
k0KoYl3/0_nU_^/7ojS1j`?oZL7[0onX`N/8ojO0j`;oY[o[1OnW_n/7ojS0j`;oZ<7[1OnX`>/9ojNo
j`;oYl3[00?o0000ojO0jonW`>/01onX`>/7ojO0j`KoYko[00?oYl3[ooooooooool03oooool00ol0
003oooooooooo`08ooooo`001?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool00ol0003oooooooooo`0Oooooo`?o00001onW`>/>ojS0j`SoYko[1OnW`>/8ojS0
j`KoYl3[2?nW_n/5ojO0j`[oZ<7[1onV_n/7ojNoj`03ojW1jonX`NcoZ<7/00?oZ<7/1onM^>/5ohnY
j0GoPiKM1_n:U]T6oi>MfP;oWZkS0onJk_H01?o<k^_oiN;?onGRcooUh/l2on;7_@?og<S51_o6Y;H6
oin:_@GoFUnn0_lSAKd2oa]gh`03o`jDgonicn_o^Lo[00Co^Lo[00?oYl3/olc:f?o<b]P01?o<b]P5
olkAg003om3Cfoo?fn;ocm_R00Cocm_R0_o8gnT7okC;k0;oYl3/1_nU_^/=ojS1j`KoYl3[0_nV_n/6
ojNoj`KoZ<3[0_nX`N/7ojS0j`KoYko[1OnW`>/00ol0003oYl3[ojO0j`07ojS0j`OoYl3[0_nW_n/5
ojO0ja3ooooo00?o0000ooooooooool02?ooool001Gooooo00?o0000ooooooooool07?ooool3o`00
00Cooooo2?nW`>/:ojS0j`CoYl3[1onW_n/00onW`>_oZ<3[ojS0j`0:ojS0j`;oYl3[3?nW_n/00onW
`>_oZ<7[ojS1j`0:ojS1j`03ojO0jonV_n_oY[o[00KoY[o[1OnW_n/2ojS0j`KoZ<7/1onM^>/4ohnY
j0GoPiKM1_n:U]T5oi>MfPCoXlKb00?oV^kfolc^joo<k^/00_oUh/l4on;7_@03omc8aOo6Y;KoaZBf
00GoaZBf1_nOR[d5oeYO_P?o8dFm0olKMn<2okW?j`GoYl3/0oo<b]P6olkAg0;od]gP1Oo?fn84olSO
j@Go]<_/0_n]a^d8ojFnj`goZ<7[0_nW`>/6ojJoj`KoYko[0_nX`>/6ojS1j`GoZ<3[00?oYl3[ojNo
jonW_n/01OnW_n/5ojO0j`03o`000?nX`>_oZ<3[00KoZ<3[1_nW`>/00onW_n_oYl3[ojO0j`06ojO0
j`oooooo00?o0000ooooooooool02?ooool001Gooooo00?o0000ooooooooool06Oooool3o`0000So
oooo2?nW`>/6ojS0j`SoYl3[1onW_n/>ojS0j`[oYko[1?nW`>/8ojS1j`GoYl3[2?nV_n/00onW_n_o
Z<3[ojS0j`04ojS0j`KoZ<7/0onM^>/3oi2ak@CoMYOU00?oSjWXoh>FgOn3U]d00on3U]d6ohZFf@03
oi>Mf_nSa_;oXlKb00CoXlKb0oo<k^/3onGRc`Coh/Nm2Oo6Y;H4oin:_@04oif2]OmfJ[OoMVZgogIZ
]`;oFUnn0olSAKd2odmgfP;o6gOS1onW`>`00oo<b]Soc]7LolkAg004olkAg0Cod]gP0oo?fn86olSO
j@03okC;k?n]a^go[LK]00Co[LK]1_nU_^/00onV_^_oZ<7[ojS1j`0<ojS1j`SoY[o[0onW_n/3ojO0
j`SoZ<7[00?oZ<3[ojO0jonW`>/00onW`>/7ojNoj`;oYl3[0_nX`>/00ol0003oZ<3[ojS0j`07ojS0
j`;oYl3[1OnW_n/7ojO0j`oooooo00?o0000ooooooooool02?ooool001Gooooo00?o0000oooooooo
ool05_ooool3o`0000gooooo1onW`>/6ojS0j`SoYl3[1onW_n/>ojS0j`KoYko[2?nW`>/5ojS1j`;o
ZL7[1_nW`>/8ojJoj`OoZ<3[0onX`N`4oj6mk@GoT;7]1?mfUnD5og^Eh@OoSJ7R1OnSa_83olc^j`?o
iN;?1OoRakd00ooG][SoaZBfolJT]P06olJT]P03oin:_OnMP[GoWH:e00;oWH:e1_mfJ[L3ob=5_@?o
CgOJ00?o6gOSojO0k?nW`>`00onW`>`2ojNhi@Goc]7L1_oBgN000oo?fn;ob=oYolSOj@04olSOj@03
ok_EkOn]a^go[LK]00Ko[LK]0_nU_^/5ojJnj`koZ<7[1onV_n/7ojO0j`OoZ<7[1onW`>/7ojNoj`Co
Z<3[00?o0000ojS0jonX`>/00onX`>/4ojO0j`OoYko[1onW`>/?ooooo`03o`000?oooooooooo00Oo
oooo000Dooooo`;o00005Oooool3o`00017ooooo1OnW`>/8ojS0j`KoYl3[2OnW_n/>ojS0j`KoYko[
2?nW`>/00onX`N_oZL7[ojW1j`04ojW1j`KoYl3[2?nV_n/5ojS0j`;oZL7[1onQ_Nd5oi2ak@CoMYOU
1OmkUN47ohfQhP?oXlKb0oo<k^/3onGRc`Goh/Nm0_oG][P7olJT]P03okbK]_nMP[GoWH:e00CoWH:e
1OmfJ[L2oeiU`@03ob=5_Om?Mm[oCgOJ00?oCgOJ00?oYl3/ojNhiOnW^>D01?nW^>D3olkAg0Kod]gP
0ooBinD2olSOj@Go^mG]1_n]a^d2ojO0k0OoY[k[3_nX`N/7ojJoj`OoYl3[1onX`N/7ojO0j`OoYko[
1?nX`>/00ol0003oZ<3[ojS0j`07ojO0j`OoYko[1onW`>/>ooooo`03o`000?oooooooooo00Oooooo
000Dooooo`03o`000?oooooooooo01;ooooo0_l0000Eooooo`03ojO0jonX`>_oZ<3[00[oZ<3[0_nW
`>/;ojNoj`;oYl3[3?nX`>/2ojO0j`KoYko[1_nW`>/2ojS0j`OoZL7[0onW`>/;ojJoj`03ojS0jonY
`N_oZL7[00CoZL7[1onQ_Nd4oi2ak@GoMYOU1OmkUN47ohfQhP03oj?6l_o<k^_oc>k[00;oc>k[0ooU
h/l5on;7_@?oekJh1Oo6Y;H2okbK]PKoWH:e1_mfJ[L2oeiU`@03ob=5_Om?Mm[oCgOJ00;oCgOJ2?nW
^>D00oo>dMcod]gPom;Mh004om;Mh0?od^OU0_o>k>X7ok_Ek@;o[LK]1_nW`>`5ojJnj`koZ<7[0_nW
_n/6ojJoj`KoYl3[00?oZ<3[ojS1jonX`N/01_nX`N/3ojO0j`_oYko[1?nX`>/00ol0003oZ<3[ojS0
j`07ojO0j`OoYko[1_nW`>/>ooooo`03o`000?oooooooooo00Oooooo000Dooooo`03o`000?oooooo
oooo00oooooo0ol0000Hooooo`koZ<3[2?nW_n/6ojO0j`SoZ<3[1_nW`>/6ojNoj`;oYl3[1_nX`>/5
ojW1j`;oZ<7[3_nV_n/7ojW1j`?oXKg]0onI^Nl4ogNVl003oi2akOmfUnGoMYOU00;oMYOU1OmkUN46
ohfQhPCo[/3W00Coc>k[onGRcooUh/ooiN;?1OoRakd4omNf^0CoaZBf1?nlVkH5oif2]@KoMVZg0omN
IL45odmgfPKoYkSU0onhb>H3om;Mh0Cod^OU1?o>k>X5ok_Ek@;o/Lc^2?nW`>`00onV_^_oZ<7[ojS1
j`0<ojS1j`KoYko[1_nV_n/2ojO0j`GoZ<3[1_nX`N/00onW`>_oYko[ojNoj`0;ojNoj`03ojO0jonX
`>_oZ<3[00;oZ<3[00Co0000ojS0jonX`>_oZ<3[1_nW`>/8ojNoj`KoYl3[3Oooool00ol0003ooooo
ooooo`07ooooo`005?ooool00ol0003oooooooooo`0<ooooo`?o00007?ooool>ojS0j`SoYko[1_nW
`>/7ojS0j`OoYl3[1onW_n/7ojS0j`03ojW1jonX`N_oZ<7[00CoZ<7[3_nV_n/5ojW1j`03ojS1jonI
^NooVKW_00GoVKW_1?mgY_04ofRDj003ogJGiOmkUN7oNiGQ00?oNiGQ0_n=XN86ojk0i`Coc]3K00?o
iN;?on;7_OoRakd00_oRakd5omNf^0?oaZBf1OnlVkH6oif2]@GoMVZg1?mNIL45odmgfP?oYkSU1_nh
b>H00ooBgN3od^OUom;Wi@02om;Wi@Koc^cZ00?o^mG]ok7<k_nac>h01?nac>h6ojO0k003ojJmjonX
`N_oZ<7[00coZ<7[2?nW_n/3ojJoj`?oYko[1onX`>/2ojS1j`GoYl3[2OnW_n/5ojO0j`CoZ<3[00?o
0000ojS0jonX`>/01onW`>/6ojNoj`SoYl3[3?ooool00ol0003oooooooooo`07ooooo`004oooool3
o`0000[ooooo0ol0000Pooooo`koZ<3[2?nW_n/6ojO0j`OoZ<3[1OnW`>/9ojNoj`OoZ<3[1onX`N/>
ojJoj`03ojW1jonX`N_oZ<7[00?oZ<7[1onI^Nl4ogNVl0CoJ9CX1_mnW^L6ojk0i`Goc]3K00?oe/S=
on;7_OoRakd00_oRakd6omNf^003olJT]_nlVkKo_9^f00Co_9^f1_nMP[D6ogIZ]`?oGVG11?mfRmX2
odmgfP03ojNhiOnhb>Ko^<SV00Co^<SV1?o9h^X00ooBinGoc^cZolk/jP04olk/jP;o_Mg`1onac>h2
ojO0k0GoY[g[3_nX`N/6ojNoj`03ojJojonW_n_oYko[00GoYko[1OnX`>/2ojS1j`OoYl3[1_nW_n/8
ojO0j`CoZ<3[00?o0000ojS0jonX`>/01onW`>/2ojNoj`coYl3[2oooool00ol0003oooooooooo`07
ooooo`005?ooool00ol0003oooooooooo`06ooooo`?o00009Oooool:ojS0j`CoYl3[1onW_n/3ojO0
j`[oZ<3[00?oYl3[ojNojonW_n/02onW_n/7ojS0j`GoZ<7[0_nW`>/<ojJoj`;oZ<3[1_nX`N/7oiVi
k`CoMjK`1?mXU>P6ogjNi`?o[/3W1oo>d=/2omK8c@;oh/Nm1ooG][P8okbK]PGoWH:e1_mfJ[L4oeiU
`@KoMX_J1Onhb>H4olWRjP;obo7/1?o>k>X5okgMl0Go/Lc^0_nX`N`7ojJmj`koZ<7[0_nW_n/5ojJo
j`OoYko[00?oZ<3[ojS1jonX`N/01?nX`N/5ojO0j`SoYko[1_nW`>/5ojS0j`03o`000?nX`>_oZ<3[
00KoYl3[00?oYko[ojO0jonW`>/02OnW`>/3ojS0j`_ooooo00?o0000ooooooooool01oooool001Co
oooo00?o0000ooooooooool00oooool3o`0002Wooooo1_nX`>/8ojO0j`OoYko[3_nX`>/:ojNoj`?o
Yl3[1onX`>/00onX`N_oYl3[ojO0j`04ojO0j`SoY[o[1_nX`>/6ojS1j`?oVKW_1?n@]o43oenMl@03
ogNVl?mXU>SoJ9CX00;oJ9CX1_mnW^L00on^`>Ooc]3Kolk@f`05olk@f`Coe/S=00?oh/NmomNf^?oG
][P01OoG][P00oo=/Kko_9^fokbK]P05okbK]PKoWH:e1OmfJ[L5oeiU`@KoMX_J0onhb>H4olWRjPCo
bo7/00?oc^cZokgMl?nmgO001_nmgO000onac>koZ<7/ojS1k004ojS1k0GoY[g[3_nX`N/00onW`>_o
Y[o[ojJoj`06ojJoj`?oYko[0onX`>/8ojS1j`03ojO0jonW_n_oYko[00[oYko[0_nW`>/9ojS0j`03
o`000?nX`>_oZ<3[00;oYl3[1OnW_n/7ojO0j`OoZ<3[2oooool00ol0003oooooooooo`06ooooo`00
4oooool01?l0003oooooooooooooool3o`0002gooooo1_nX`>/8ojO0j`OoYko[3_nX`>/6ojNoj`Oo
Yl3[1OnX`>/3ojW1j`KoYl3[1OnV_n/2ojJok0OoZ<3[0onX`N/4ojFok0KoT;Oa1?mOWO43oefFkP04
ofRDj?mnW^OoOYkWogjNi`CoT[7/1Oo>d=/5omK8c@OoekJh0_o=/Kh7okbK]PKoWH:e1_mfJ[L4oeiU
`@OoMX_J00Co^<SVolWRj_o9h^[obN;Z1Oo;lN`3olGck`Ko_Mg`00?o/<c^ojS1k?nX`N`01_nX`N`0
0onV_N_oZ<7[ojS1j`0<ojS1j`GoYl3[1_nV_n/00onW_n_oZ<3[ojS0j`05ojS0j`OoZ<7[3?nW_n/2
ojO0j`[oZ<3[00?oYl3[o`000?nW`>/02?nW_n/7ojO0j`OoZ<3[2_ooool00ol0003oooooooooo`06
ooooo`004oooool4o`00037ooooo1_nX`>/8ojO0j`OoYko[3_nX`>/6ojNoj`OoYl3[00?oZ<3[ojW1
jonY`N/01OnY`N/6ojO0j`03ojJojonV_ncoY[o/00CoY[o/1OnX`>/2ojW0j`OoYKo/1_n@]o44oenM
l@CoGIK^1onB/N`3olk@f`Koe/S=00?od/;:omNf^?oG][P00ooG][P3olfa_PSo_9^f1?nMP[D00onQ
TLCoRhG7oh^5a`04oh^5a`CoPhcD00CoGVG1ogJ;f_mfRm[oMX_J1OnP]nT00oo9h^[obo7/ol_ak002
ol_ak0KoaO?_0_nmgO05ok3<kPKoZ<7/00?oY[g[ojS1jonX`N/02OnX`N/3ojS1k0OoYl3[0_nV_n/5
ojNoj`OoZ<3[1onX`N/8ojNoj`KoYl3[1onX`>/4ojO0j`03o`000?nW`>_oYko[00KoYko[2?nW`>/3
ojS0j`?oYl3[2_ooool00ol0003oooooooooo`06ooooo`004oooool2o`0003Cooooo1_nX`>/8ojO0
j`GoYko[0_nW`>/<ojS0j`;oYl3[1_nW_n/7ojO0j`SoZL7[0onW`>/:ojJok003ojS0jonY`>_oZL3[
00CoZL3[1onU_n`3oi2gl@?oRkKc0om=V?800omOWO7oGIK^oefFkP02oefFkPOoT[7/00?oc]3KomK8
cOoFb<d01?oFb<d3om;2bP?oekJh1Oo=/Kh7okbK]P03oif2]OnQTLCoXI7400?oXI741_n;QLL5oh><
e0KoX;OY1?nmk?<00oo;lNcoaO?_olGck`04olGck`?o]]Wb1_n`c>h2ojS1k0GoY[g[1_nX`N/8ojS1
k0GoYl3[0_nV_^/6ojNoj`KoZ<3[2OnX`N/6ojNoj`SoYl3[1onX`>/3ojO0j`03o`000?nW`>_oYl3[
00OoYko[1_nW`>/00onX`>_oYl3[ojO0j`05ojO0j`Wooooo00?o0000ooooooooool01_ooool000Go
00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0<_ooool7ojS0
j`OoYl3[00?oYko[ojO0jonW`>/01?nW`>/8ojS0j`KoYl3[1_nW_n/7ojO0j`SoZL7[3OnV_n`7ojW0
j`?oYKo/1?nS_nd6oh^fl`?oCISb1?mCVo<01?mMU^koT[7/oi:ak?nB/N`4ojO1k0Goe/S=1?oB`/X3
omNf^0GocK6n1_nlVkH00ongY/OoXI74oj6Aa004oj6Aa0KoRhG71_n3S=@3oj2gj@Go_Ncc1?njmnl0
0oo5lnoo]]WbokKIlP05okKIlP?o/<c^0onX`>/7ojJmj`;oZ<7[3?nX`N`00onW`>_oY[k[ojJnj`04
ojJnj`KoYko[0_nX`>/;ojS1j`SoYko[1_nW`>/9ojS0j`?oYl3[00?o0000ojNojonW_n/01onW_n/2
ojO0j`GoZ<3[1onW`>/8ooooo`03o`000?oooooooooo00Kooooo00001OnHV9So8B4Qonk^k_oooooo
A4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`09ooooo`03o`000?oooooooooo03?ooooo1_nX
`>/5ojO0j`;oYko[1onW`>/7ojS0j`OoYl3[1_nW_n/7ojO0j`SoZL7[3OnV_n`7ojW0j`OoXko]1_n;
]_<3odfHlPCoDi_c2?nW`N`3omK8c@Kod/;:00?oekJholfa__o=/Kh01?o=/Kh5okbK]P?o]jK71_nQ
TL@5oh^5a`OoPhcD00?oX;OYokg/lonmk?<00onmk?<4ok[gk`;o^n_d1_nffO800on/angoZ<3[ojS0
j`05ojS0j`GoY[g[3?nX`N`3ojO0j`SoY[k[0onW_n/3ojS0j`WoZ<7[3?nW_n/2ojO0j`_oZ<3[00?o
Yl3[ojNojonW_n/00_nW_n/00ol0003oYko[ojNoj`05ojNoj`03ojO0jonX`>_oZ<3[00GoZ<3[1onW
`>/8ooooo`03o`000?oooooooooo00Kooooo00001?ooooooV9RHob4Q8Oo^k^h4ooooo`05oa0@4?oo
ooooooooooooool@41002_ooool00ol0003oooooooooo`0cooooo`KoZ<3[00?oYl3[ojNojonW_n/0
1?nW_n/8ojO0j`KoZ<3[1onW`>/6ojNoj`GoYl3[0onX`>/7ojW1j`goY[o/1onY`>/7oj>ok@?oRkKc
0on:]o@00om5VO?oCISbodfHlP04oe>Kl`SoYl7/00?oe/S=om;2b_oB`/X01?oB`/X00oo<b]SocK6n
olfa_P06olfa_P;o_9^f1OngY/L6oj6Aa0KoRhG71On3S=@3ojOCm`?o_Ncc0onjmnl5ok_[m0;o]]Wb
1On/and7ojS0j`03ojJmjonX`NcoZ<7/00_oZ<7/1_nW`>/6ojJnj`03ojNojonX`>_oZ<3[00GoZ<3[
1onX`N/:ojNoj`?oYl3[2_nX`>/5ojO0j`CoYko[00Co0000ojNojonW_n_oYko[1OnW`>/7ojS0j`Oo
Yl3[1oooool00ol0003oooooooooo`06ooooo`000_ooool00onHV9So8B4Qonk^kP03ooooo`05o`00
0?ooooooooooooooool000002oooool2o`0003Cooooo0onX`>/3ojO0j`OoYko[2?nW`>/6ojS0j`Oo
Yl3[1_nW_n/00onW`>_oZ<3[ojS0j`05ojS0j`GoZL7[0_nX`>/=ojJok0OoZL3[0onS_nd4oj>nk0Ko
R[Od0om5VO<4oe>Kl`KoYl7/0_nVbO85om;2bP?oc<[H1oo=/Kh00onlVkKo]jK7okNVa`05okNVa`Go
XI741_n;QLL2oh><e0OoYm?g00?o_Nccok[gkonjmnl01_nkjo@2ojo?l@Oo[<O]0onX`>/3ojJnj`oo
Z<7/1_nW`>/2ojJnj`GoYko[1onX`>/7ojS1j`OoYko[1_nW`>/6ojS0j`03ojS1jonW`>_oYl3[00Ko
Yl3[0onW_n/00ol0003oYko[ojNoj`07ojO0j`KoZ<3[2?nW`>/7ooooo`03o`000?oooooooooo00Go
oooo0003ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`00000=ooooo`03
o`000?oooooooooo03;ooooo1_nW`>/8ojNoj`OoYl3[1_nX`>/7ojO0j`OoYko[1onX`>/00onY`N_o
Z<3[ojS0j`04ojS0j`goY[o/1OnY`>/3ojW1j`KoXkk/1_n:]o@4odFIl`;o@ige00?oDi_cojO1k?nW
`N`01_nVbO83om;2bPGoc<[H1Oo=/Kh00oo5`]Oo]jK7okNVa`06okNVa`KoXI740on;QLL4oiblk`Ko
Ym?g0_nXm?44oj[bm003ok_[m?n_co7o[loa00Co[loa1On/and2ojNnjPKoY[k[3onX`N`3ojO0j`?o
Ykk[1onW_n/3ojS0j`_oZ<7[1onW_n/6ojO0j`;oZ<3[1OnX`N/6ojO0j`GoYko[00?o0000ojNojonW
_n/01OnW`>/8ojS0j`OoYl3[1oooool00ol0003oooooooooo`05ooooo`001?ooool01Ol0003ooooo
oooooooooooo410@00?ooooo00?o410@ooooooooool03?ooool00ol0003oooooooooo`0booooo`Ko
Yl3[2?nW_n/5ojO0j`SoZ<3[2?nW`>/6ojNoj`koZ<3[3OnV_n`00onY`>_oZL7[ojW1j`05ojW1j`Ko
Xkk/0on:]o@3ohnil`?oCZ7f00?oAIWcod>MmOm3WOD00_m3WOD7ojK9lP03om;2b_o<b]Soc<[H00Co
c<[H0oo=/Kh4olG2e`Oo]jK71OnQTL@00onW`>coW;c_oiblk`06oiblk`;oYm?g0onXm?45oj[bm0;o
[MGe1on_co400on/angoYkkZojNnjP04ojNnjPKoY[k[3OnX`N`00onW_n_oYkk[ojNnj`05ojNnj`Go
Yko[0_nW`>/<ojS1j`WoYko[1_nW`>/7ojS1j`;oYl3[2OnW_n/01?l0003oYko[ojNojonW`>/<ojS0
j`OoYl3[1_ooool00ol0003oooooooooo`05ooooo`0000Go0000okZj^_ooooooV9RHoa0@4003oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03oooool00ol0003oooooooooo`0booooo`OoYl3[1onW_n/0
0onW`>_oZ<3[ojS0j`0:ojS0j`SoYl3[1_nW_n/>ojS0j`_oY[o/0_nV`>`8ojW1j`?oXkk/0onU_^/6
ohnil`GoCZ7f0_l/VO001?m3WOGoY/WbojK9l_nVbO84oh;9oPOoc<[H00?ocK6nolG2eoo5`]L01?o5
`]L7okNVa`03oj6Aa?nW`>coYl3/00?oYl3/1_nL_>l4oi;/m004ojSdlOnZl_CoZ_;doj[bm0Ko[MGe
1On_co42ojRoj`OoYkkZ0onV_^/<ojS1k0GoYko[1onW_^/00onW_n_oYl3[ojO0j`04ojO0j`SoZ<7[
2onW_n/8ojO0j`GoZ<7[00?oYl3[ojNojonW_n/02OnW_n/00onW`>_o0000ojO0j`0;ojS0j`[oYl3[
1Oooool00ol0003oooooooooo`05ooooo`0000GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h04?ooool2o`0003Cooooo1_nW`>/5ojNoj`;oYl3[3OnX`>/8ojO0j`?o
Yko[0onW`>/>ojS0j`OoY[o/1_nV`>`7ojW1j`OoYKk[1_n?^O<5odjQmPCo;9W`1_n2bOh5olc:f003
oj_LnOo5`]OoaL;G00GoaL;G1_ngY/L00on`e_CoYl3/ojO0k005ojO0k0?oW;c_1OnBk?@3oi3]l0;o
ZMSh1on]eOD00on_co7oZ;o[ojRoj`04ojRoj`GoYkkZ3OnX`N`2ojS1j`KoYko[1_nW_^/9ojO0j`?o
Z<7[0onX`>/9ojNoj`coYl3[00?oZ<7[ojO0jonW`>/00onW`>/7ojNoj`CoYl3[00?o0000ojO0jonW
`>/01onX`>/<ojO0j`03ojNojooooooooooo00?ooooo00?o0000ooooooooool01Oooool001oooooo
00?o0000ooooooooool0<_ooool6ojO0j`03ojNojonW`>_oYl3[00CoYl3[3OnX`>/>ojO0j`koZ<3[
1_nV_n`7ojK0k0OoZL7[1onU_^/3ohnil`CoV;c`1OmY[oT2obFJk@03obbIl?n2bOkoP/Wn00CoP/Wn
00?oc<[Hoj_LnOn[g?T00on[g?T7olG2e`;o]jK71On`e_@7ojO0k004oiblkonBk?CoT^cdoi;/m0?o
T>g`1_nYf?P3ojgEm@?oZL;/2?nX_n/00onW_^[oZ<7/ojS1k00;ojS1k0KoZ<7[1_nW_n/2ojNnj`_o
Yl3[00?oZ<7/ojS0jonX`>/01OnX`>/7ojNoj`[oYl3[0onX`N/7ojO0j`OoYko[1?nW`>/00ol0003o
Yl3[ojO0j`07ojS0j`SoYl3[1OnW_n/4ooooo`03o`000?oooooooooo00Gooooo000Pooooo`03o`00
0?oooooooooo03;ooooo3OnW`>/=ojS0j`koYl3[3_nX`>/6ojJok0OoY/3/1onY`N/5ojFnj`;oZ;oZ
1onH_?05ofV_n@Co9I[]1_lo/_@5oj_Ln@GoaL;G0on@h?h6ok3Fm0?oYl3/1Ommho82ogKQk@?oX]Kj
1OnYf?P2ojW4k@KoZL;/1_nX_n/00onW_n_oZ<7/ojS1k00<ojS1k0OoZ<7[1_nW_n/9ojO0j`GoZ<7/
1onX`>/7ojNoj`KoYl3[1onX`N/5ojO0j`WoYko[1?nW`>/00ol0003oYl3[ojS0j`07ojS0j`GoYl3[
2?nW_n/3ooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo03;ooooo3_nW
`>/=ojS0j`goYl3[3_nX`>/6ojJok0OoY/3/1onY`N/00onU_^_oZ;oZojRojP04ojRojPGoV;c`0_nQ
_Nd6oh^kmP;oCJWi00?o9I[]ocnbm?lo/_@01?lo/_@5oj_Ln@03olG2eon@h?koT>3n00GoT>3n0on`
e_@5of3Ej`;oON?b0_mfhNd7oj;FnP03ojWHn?nYa>goZLC]00CoZLC]1_nY`^`2ojRoj`GoYko[3_nX
`N`5ojS1j`03ojNnjonW_n_oYko[00GoYko[1OnW`>/2ojS0j`OoZ<7/0onX`>/;ojNoj`KoYl3[1onX
`N/00onW`>_oYko[ojNoj`09ojNoj`GoYl3[00?o0000ojO0jonW`>/01_nX`>/7ojO0j`KoYko[00?o
Yl3[ooooooooool00_ooool00ol0003oooooooooo`04ooooo`008_ooool00ol0003oooooooooo`0b
ooooo`koYl3[3OnX`>/5ojO0j`;oYl3/1_nW`>/>ojS0j`KoY[o/1onV`>`3ojW1j`CoZ<3[1onX_nX0
0onH_?3oXKg]oj6mk@04oj6mk@KoRk_f1Om=ZOT5oanRi@KoAKo_0on@h?h5ocfohP?oH=G[0omVe_44
oic@nPGoX]Kj0_nW`nh7ojW4k@?oZL;/0onW_^/7ojNoj`koZ<7/00?oZ<7[ojNnjonW_^/00onW_^/7
ojNoj`03ojO0jonX`>_oZ<3[00CoZ<3[1OnX`N`2ojS0j`coYko[2?nW`>/3ojS1j`?oYl3[2OnW_n/9
ojO0j`03o`000?nW`>_oYl3[00;oZ<3[2onW`>/2ojNoj`GoYl3[0oooool00ol0003oooooooooo`04
ooooo`008oooool2o`0003?ooooo3_nW`>/=ojS0j`03ojO0jonW`>coYl3/00CoYl3/1_nW`>/>ojS0
j`KoY[o/2?nV`>`6ojS0j`GoZ;oZ0_nY`N/7oj6mk@?oRk_f0onL_Nl7ohBmn@GoE;Gk0ol`/^D5ogO4
oP?oIlkk1?nKbOL7oic@nP03oj;Fn_nW`nkoYl?^00CoYl?^1OnYa>d2ojNnjPKoYkk[1OnW_n/<ojS1
k0?oYko[1onW_^/3ojNoj`CoYl3[1onX`>/00onX`NcoZ<3[ojS0j`04ojS0j`SoYko[2_nW`>/2ojS1
j`KoYl3[1onW_n/:ojO0j`03ojS0jol0003oZ<3[00_oYl3[0_nW_n/8ojO0j`;ooooo00?o0000oooo
ooooool01?ooool002Gooooo00?o0000ooooooooool0<_ooool=ojO0j`goZ<3[1onW`>`6ojO0j`ko
Z<3[1_nV_n`8ojK0k0KoZ<3[00?oZ;oZojW1jonY`N/01?nY`N/5oj6mk@;oZ;oZ1_nL_Nl5ohBmn@;o
WKg_1_n@`_P5ogO4oP;oWL;b1onKbOL3oic@nPCoY/7]1onW`nh00onYa>goYkkZojNnjP04ojNnjPKo
Ykk[00?oYko[ojS1k?nX`N`02OnX`N`2ojS0j`KoYko[1OnW_^/2ojNoj`OoYl3[0onX`>/3ojS1k0So
Z<3[1OnW_n/9ojO0j`KoZ<7[1_nW`>/7ojNoj`OoYl3[1?nX`>/00ol0003oZ<3[ojO0j`06ojO0j`Ko
Yko[1onW`>/2ooooo`03o`000?oooooooooo00Cooooo000Vooooo`03o`000?oooooooooo03;ooooo
3OnW`>/=ojS0j`OoYl3/1_nW`>/>ojS0j`?oY[o/0onV_n/8ojK0k0?oZ<3[1?nV`>`6ojW1j`03oj6m
kOnX_n[oZ;oZ00CoZ;oZ1_nL_Nl00on4_OWoWKg_oifmk`04oifmk`KoT<;h00?oMlCnoig2l_nM`_80
1?nM`_85oi_9m`;oY[o[1onV`Nd3ojO3kP_oYkkZ0onW_^/4ojO1k0OoZ<7/1_nX`>/6ojNoj`03ojNn
jonW_n_oYko[00CoYko[1OnW`>/8ojS1k0KoZ<3[1onW_n/7ojO0j`SoZ<7[0onW`>/:ojNoj`OoYl3[
0onX`>/00ol0003oZ<3[ojS0j`07ojO0j`KoYko[1onW`>/00ooooooo0000ooooo`05ooooo`009ooo
ool00ol0003oooooooooo`0booooo`goYl3[3OnX`>/7ojO0k0KoYl3[3?nX`>/2ojW0jPKoY[o[3onV
`>`3ojW1j`?oZ<7[1onX_nX3oibmk`CoY[kZ1_nM_Nl3oi32n0CoX[k]1_nM`_800onKbOOoY[o[ojJo
j`04ojJoj`GoY/7]0_nX_nX<ojNnjPWoYl7/1OnX`N`8ojS0j`goYko[00?oYl3[ojS1k?nX`N`02_nX
`N`2ojS0j`_oYko[1onW`>/6ojS1j`03ojO0jonW_n_oYko[00[oYko[2OnW`>/3ojS0j`03o`000?nW
`>_oYl3[00OoYl3[0onW_n/:ojO0j`03o`000?oooooooooo00Cooooo000Xooooo`;o0000<oooool=
ojO0j`goZ<3[1onW`>`7ojO0j`OoZ<3[1_nY`>X6ojJoj`ooY/3/1_nX`N/5ojRojP;oZL7[1onV_^X3
oifmk`?oYkkZ1onR_^d3oig2lP?oYkkZ1onV_n/00onV`NgoZ;oZojRojP04ojRojPSoYkkZ2onW`N`7
ojS1k0KoZ<3[00?oYkkZojNojonW_n/02_nW_n/00onW`>_oZ<7/ojS1k009ojS1k0goYko[2_nW`>/2
ojS1j`GoYl3[2?nW_n/;ojO0j`03ojS0jonW`>_oYl3[00;oYl3[00?o0000ojO0jonW`>/01OnW`>/0
0onW_n_oYl3[ojO0j`09ojO0j`;ooooo00?o0000ooooooooool01?ooool002[ooooo00?o0000oooo
ooooool0<Oooool=ojO0j`goZ<3[1OnW`>`9ojO0j`KoZ<3[1onY`>X3ojJoj`CoYko[3_nV`>`6ojS1
j`03ojRoj_nY`N_oZL7[00CoZL7[1OnV_^X2ojW1j`KoYkkZ1OnR_^d2ojRojPKoYkkZ1OnV_n/2ojS0
j`OoZ;oZ0onW_^X<ojO1k0_oZ<7/0_nX`>/5ojNnjPSoYko[1OnW`>/6ojS1k003ojS0jonW_n_oYko[
00_oYko[2onW`>/2ojS0j`SoYl3[1_nW_n/9ojO0j`GoZ<3[1?nW`>/01?l0003oYl3[ojO0jonW`>/5
ojNoj`KoYl3[1oooool00ol0003oooooooooo`03ooooo`00:oooool00ol0003oooooooooo`0aoooo
o`goYl3[3OnX`>/00onW`>coYl3[ojO0j`09ojO0j`;oYl3/1_nX`>/5ojW0jP;oZL3[1onW_n/3ojK0
k0CoY[o/1onV`>`3ojS1j`?oY/3/1onY`N/00onV_^[oZL7[ojW1j`04ojW1j`KoYkkZ00?oX[k]ojRo
j_nX_nX01?nX_nX6ojNnjP03ojJojonX`>_oZ<3[00CoZ<3[1OnX_nX?ojO1k0[oZ<7/0onW_nX7ojNn
jP?oYko[2_nW`>/2ojS1k0GoZ<3[3OnW_n/6ojO0j`03ojS1jonX`>_oZ<3[00CoZ<3[1_nW`>/8ojNo
j`GoYl3[2OnX`>/3ojO0j`03o`000?nW_n_oYko[00OoYko[0_nW`>/:ooooo`03o`000?oooooooooo
00?ooooo000/ooooo`03o`000?oooooooooo037ooooo3OnW`>/=ojS0j`SoYl3[1_nW`>`6ojS0j`03
ojW0j_nY`>_oZL3[00CoZL3[1OnW_n/2ojRoj`OoY[o/3OnV`>`5ojW1j`;oYl7/1onY`N/3ojNnjP?o
Z<7[1onX_nX3ojNnjP?oZ<7[1onX`>/00onX_n[oYl7/ojO1k00AojO1k0GoZ<7/2?nW_nX5ojNnjPgo
Yl3[0_nX`N`7ojS0j`goYko[0_nW`>/5ojS1j`KoZ<3[0_nW`>/<ojNoj`03ojO0jonX`>_oZ<3[00Wo
Z<3[00?oYl3[ojNojonW_n/00_nW_n/00ol0003oYko[ojNoj`05ojNoj`gooooo00?o0000oooooooo
ool00oooool002gooooo0_l0000booooo`goYl3[3OnX`>/5ojO0j`;oYko[1onW`>`3ojS0j`?oYl3[
1onY`>/00onW_n_oZ;o[ojRoj`04ojRoj`OoY[o/3OnV`>`00onY`N_oYl7/ojO1k004ojO1k0GoZL7[
00?oYl7/ojS1jonX`N/01OnX`N/5ojRojP;oYl7/1_nX`N/5ojS0jaKoYl7/00?oZ<7/ojNoj_nW_nX0
2_nW_nX00onW_^[oYl3[ojO0j`0;ojO0j`KoZ<7/1OnX`>/=ojNoj`;oYl3[1onX`N/3ojS0j`goYko[
1?nW`>/8ojS0j`GoYl3[1?nW_n/01?l0003oYko[ojNojonW_n/@ooooo`03o`000?oooooooooo00?o
oooo000_ooooo`03o`000?oooooooooo033ooooo3OnW`>/=ojS0j`03ojO0jonW_n_oYko[00CoYko[
1onW`>`6ojO0j`GoZL3[0_nX`>/7ojRoj`?oY[o/0onW_n/>ojK0k0OoYl7/00?oZL7[ojO1k?nW`N`0
0onW`N`7ojS1j`03ojRoj_nW`NcoYl7/00CoYl7/1_nX`N/00onX`>_oYl7/ojO1k00EojO1k0;oYko[
2onW_nX2ojNoj`_oYl3[2_nX`N`00onX`>_oYko[ojNoj`0;ojNoj`KoYl3[1OnX`N/00onX`>_oYko[
ojNoj`0;ojNoj`SoYl3[0onX`>/:ojO0j`?oYko[00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`03ooooo`00<?ooool00ol0003oooooooooo`0aooooo`goYl3[3OnX`>/6ojNoj`OoYl3/1_nW
`>/00onY`>_oZ<3[ojS0j`04ojS0j`GoZ;o[0_nY`>X6ojNoj`KoY/3/00?oY[o[ojK0k?nV`>`01OnV
`>`3ojO1k0?oY/7/1onW`N`3ojS1j`_oYl7/0onX`N/FojO1k0OoYko[1_nW_nX7ojNoj`KoYl3[00?o
Yl7/ojS1k?nX`N`02?nX`N`>ojNoj`[oYl3[00?oZ<7[ojS0jonX`>/00onX`>/=ojNoj`KoYl3[00?o
Z<3[ojO0jonW`>/02_nW`>/5ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00ooo
ool0037ooooo00?o0000ooooooooool0<Oooool=ojO0j`koZ<3[0_nW_n/4ojO0j`KoYl3/1_nW`>/7
ojS0j`03ojRojonY`>[oZL3Z00CoZL3Z1_nW_n/2ojK0k0GoY[o[1OnV`>`2ojJok0KoY/7/1OnW`N`2
ojK1k2?oYl7/2onW_n/2ojNojP_oYko[0_nW`>/5ojO1k0GoZ<7/0_nX`>/=ojNoj`[oYl3[0onX`N/7
ojS0j`goYko[0_nW`>/5ojS0j`SoYl3[2Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo00?ooooo000booooo`;o0000<_ooool=ojO0j`koZ<3[1_nW`>/7ojO0k0GoYl3[1onX`>/7ojW0
jP?oYko[0onX_nX7ojJoj`03ojK0k?nV_ncoY[o/00CoY[o/1_nV`N`00onW`NcoY/7/ojK1k004ojK1
k1;oYl7/0_nW`>/;ojO1k0;oYkoZ5onW_n/:ojO1k003ojS1k?nX`>_oZ<3[00CoZ<3[3OnW_n/5ojO0
j`;oYl7[1_nX`N/5ojS0j`goYko[00?oYl3[ojS0jonX`>/01_nX`>/3ojO0j`kooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`02ooooo`00=?ooool00ol0003oooooooooo`0`ooooo`go
Yl3[3_nX`>/6ojO0j`OoYl3/1OnW`>/7ojS0j`GoZL3Z0_nX`>/6ojRojPGoY[o[0_nX_n/7ojJok0?o
Y/7/0onW_n/7ojK1k0?oYl7/1?nW`>`7ojO1k0KoYl3[1onW`N`6ojNojQ;oYko[0_nW`>`:ojO1k0?o
Yl3[1onX`>/=ojNoj`03ojO0jonW`N_oYl7[00CoYl7[1_nX`N/00onX`>_oYko[ojNoj`0;ojNoj`Go
Yl3[1_nX`>/Booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool003Gooooo
00?o0000ooooooooool0<?ooool=ojO0j`koZ<3[1_nW`>/7ojO0k0;oYl3[1?nW`>`6ojS0j`03ojW0
j_nX`>_oZ<3[00CoZ<3[1_nX_nX00onV_n_oZ;o[ojRoj`04ojRoj`GoY[o/0_nW_nX6ojNoj`GoY/7/
0_nW_n/7ojO0k0?oYl7/0onW_n/7ojO0j`?oYl7/2_nW_nX>ojNoj`KoYl3/1_nW`N`7ojO0j`GoZ<3[
3OnW_n/00onW`>_oYl7[ojO1j`06ojO1j`?oZ<7[0_nW`>/;ojNoj`WoYl3[0_nX`>/Fooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool00_ooool003Kooooo00?o0000ooooooooool0<?oo
ool=ojO0j`koZ<3[1_nW`>/5ojO0k0;oYko[1_nW`>`3ojS0j`?oYl3[1onX`>/3ojRojPCoZ<3[1_nX
_n/00onV_ncoYkoZojNojP04ojNojPKoYko[00?oY/7/ojNojonW_n/01?nW_n/5ojO0k0;oYkoZ1_nW
_n/5ojO0j`;oZ;oZ2_nW_nX=ojNoj`[oYl3/1_nW`N`7ojO0j`03ojS0jonW_n_oYko[00_oYko[1OnW
`>/6ojO1j`03ojS0jonW`>_oYl3[00CoYl3[1onW_n/:ojO0ja_ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`02ooooo`00=oooool2o`00037ooooo3_nW`>/=ojS0j`KoYl3[00?oYl3/
ojNojonW_n/01?nW_n/6ojO0k0KoYl3[1OnX`>/2ojO0j`OoZ<3[0onX_n/3ojS0j`OoYkoZ0onW_n/4
ojRojPKoYko[00?oYl3/ojNoj_nW_nX01?nW_nX6ojNoj`03ojO0jonX_n[oZ;oZ00CoZ;oZ1OnW_nX0
0onX_n_oYko[ojNoj`0:ojNoj`_oYl3/2_nW`N`3ojO0j`goYko[2_nW`>/2ojO1j`GoZ<3[1_nW`>/7
ojNoj`GoYl3[8?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo000ioooo
o`03o`000?oooooooooo02oooooo3_nW`>/3ojS0j`?oYl3[1onX`>/3ojO0j`CoZ<3[1_nW_n/6ojO0
k0KoYl3[00?oZ<3[ojO0jonW`>/01?nW`>/=ojS0j`GoYkoZ0_nX`>/7ojRojP?oYko[0onX_nX7ojNo
jP?oYko[2_nX_nX00onW_n[oZ;o[ojRoj`03ojRoj`SoYko[2_nW`>`=ojO1k0goYko[3onW`>/7ojS0
j`?oYl3[2_nW_n/00onW`>_oooooooooo`0Qooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool00_ooool003[ooooo00?o0000ooooooooool0;oooool<ojO0j`;oYl3/1_nW`>/>ojS0j`Ko
Yko[1_nW`>`3ojO0j`CoYl3/1_nW`>/=ojS0j`03ojNoj_nX`>_oZ<3[00CoZ<3[1OnX_nX2ojS0j`Ko
Z;oZ1OnW_nX00onX`>_oZ;oZojRojP09ojRojP;oZ<3[1onX_n/3ojNoj`_oYl3/3OnW`N`=ojNoj`_o
Yl3[00?oYl7/ojO0jonW`>/01OnW`>/5ojS0j`_oYko[:?ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00;ooooo000kooooo`03o`000?oooooooooo033ooooo1onW`>/6ojO0k0KoYl3[
3_nX`>/6ojNoj`CoYl3/0_nW_n/7ojO0k0?oYl3[0onW`>`DojS0j`03ojRoj_nX`>_oZ<3[00CoZ<3[
1_nX_nX00onW_n[oZ<3[ojS0j`03ojS0j`KoZ;oZ00?oYl3[ojS0jonX`>/01?nX`>/5ojRoj`;oYl7/
2_nW`>`=ojO1k0goYko[2onW`>/5ojO1k0OoYl3[00?oZ<3[ojNojonW_n/02?nW_n/]ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool00Oooool003cooooo00?o0000ooooooooool0<?oo
ool6ojO0j`OoYl3/1onW`>/=ojS0j`KoYko[00?oYl3/ojNojonW_n/00onW_n/=ojO0k0GoZ<3[0_nW
`>`:ojS0j`?oYl3[1onX`>/3ojRojPWoZ<3[0_nX_nX5ojO0j`KoZ<3[00?oZ;o[ojO1k?nW`N`01?nW
`N`5ojO0k0goYl7/3_nW_n/:ojO0j`?oYl3/1onW`N`3ojO0j`_oYko[<Oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo007ooooo000mooooo`;o0000<Oooool6ojO0j`GoYl3/2OnW`>/=
ojS0j`?oYko[0onX_n/6ojNoj`goYl3/00?oZ<3[ojO0k?nW`>`01?nW`>`5ojS0j`;oYl3/1_nW`>/5
ojS0j`03ojO0k?nX`>_oZ<3[00SoZ<3[0onW`>`7ojO0j`?oZ<3[2_nW`N`00onW`>coYl7/ojO1k00;
ojO1k1;oYko[1onW`>/6ojO0k0GoYl7/0_nW`>/:ojNojcCooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`01ooooo`00?oooool00ol0003oooooooooo`0_ooooo`KoYl3[00?oYl3/ojO0
jonW`>/02onW`>/=ojS0j`KoZ;o[1_nW_n/DojO0k003ojS0jonW`>coYl3/00CoYl3/1_nW`>/00onX
`>_oYl3/ojO0k003ojO0k0GoZ<3[0_nW`N`6ojO0k0GoYl3[3?nW`N`3ojO0k0[oYl7/5_nW_n/7ojO0
j`KoYl3/00?oYl7/ojO0jonW`>/01?nW`>/5ojNojcWooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`01ooooo`00@?ooool00ol0003oooooooooo`0_oooooaCoYl3[3OnX`>/4ojRoj`;o
Z<3[1_nW_n/5ojO0k0;oYko[5?nW`>`3ojO0j`?oYl7/1_nW`>`00onX`>_oYl7/ojO1k004ojO1k0Ko
Yl3/00?oYl3[ojO1k?nW`N`02OnW`N`00onW`>_oYl3/ojO0k005ojO0k0GoYl7/6?nW_n/:ojO0j`?o
Yl3/2_nW`>/00onW_n_oooooooooo`0kooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool00Oooool0047ooooo00?o0000ooooooooool0;ooooolDojO0j`?oZ<3[1?nW`>/6ojS0j`03ojRo
jonX`>_oZ<3[00?oZ<3[1_nW_n/00onW`>coYko[ojNoj`04ojNoj`GoYl3/0_nW_n/<ojO0k0OoYl7/
1_nW`>`7ojO1k0?oYl3/2onW`N`5ojO0j`OoYl3/00?oYl7/ojNojonW_n/05OnW_n/HojO0jd7ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`01ooooo`00@_ooool2o`00033ooooo1OnW
`>/2ojS0j`_oYl3[0_nW`>`7ojO0j`coZ<3[0onW_n/4ojS0j`KoYko[00?oYl3/ojNojonW_n/01?nW
_n/<ojO0k0GoYl7/0_nW`>/6ojO0k0GoYl7/0_nW`>`:ojO1k0WoYl3[0onW`>`HojNojaOoYl3[A_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo007ooooo0014ooooo`03o`000?oooooo
oooo02kooooo00?oYl3[ojS0jonX`>/01?nX`>/7ojO0j`KoYl3/1onW`>/CojS0j`?oYko[0onX_n/7
ojNoj`?oYl3/1?nW_n/5ojO0k003ojO1k?nW`>_oYl3[00CoYl3[1_nW`>`00onW`NcoYl3/ojO0k004
ojO0k0GoYl7/00?oYko[ojO0jonW`>/02OnW`>/IojNojaOoYl3[B_ooool00ol0003oooooooooo`07
ooooo`7o00000Oooool1ooooo`00AOooool00ol0003oooooooooo`0_ooooo`KoZ<3[1onW`>/6ojO0
k0OoYl3[4onX`>/6ojRoj`GoYko[0_nX_n/7ojNoj`;oYl3/0onW_n/7ojO0j`?oYl3/1?nW_n/6ojO0
k003ojO1k?nW_n_oYko[00?oYko[1onW`>/HojNoj`_oYl3[0onW`>`:ojO0jdkooooo00?o0000oooo
ooooool01_ooool1o`00007ooooo0Oooool004Kooooo00?o0000ooooooooool0<?ooool5ojS0j`Oo
Yl3[0onW`>`:ojO0j`?oZ<3[0onW`>/=ojS0j`KoZ;o[00?oYko[ojRojonX_n/01?nX_n/5ojNoj`03
ojRojonW_n_oYko[00CoYko[1OnW`>/9ojNoj`?oYl3/2OnW_n/3ojO0j`CoZ;o[5?nW_n/:ojO0j`So
Yl3/1OnW`>]Booooo`03o`000?oooooooooo00Kooooo0Ol00001ooooo`7ooooo0017ooooo`;o0000
<Oooool5ojS0j`GoYl3[0_nX`>/:ojO0j`?oYl3/1_nW`>/3ojS0j`CoYl3[1_nX`>/3ojRoj`CoZ<3[
1_nX_n/00onW_n_oZ;o[ojRoj`03ojRoj`KoYko[00?oYl3[ojNojonW_n/02OnW_n/00onX_n_oYko[
ojNoj`09ojNoj`WoZ;o[0onW_n/3ojO0j`[oYko[2_nW`>/<ojO0k003ojO0jooooooooooo05Cooooo
00?o0000ooooooooool01Oooool1o`00007ooooo0Oooool004Wooooo00?o0000ooooooooool0;ooo
ool5ojS0j`03ojO0jonX`>_oZ<3[00CoZ<3[1onW`>/6ojO0k0CoYl3[0_nW`>`7ojO0j`?oZ<3[0onW
`>/7ojS0j`?oZ;o[0onX`>/6ojRoj`?oYko[1?nX_n/7ojNoj`GoZ;o[1onW_n/;ojRoj`SoYl3[1OnW
_n/;ojO0j`goYl3/F_ooool00ol0003oooooooooo`04ooooo`7o00000Oooool1ooooo`00B_ooool0
0ol0003oooooooooo`0_ooooo`coZ<3[1onW`>/6ojO0k003ojO0jonW`>coYl3/00?oYl3/1OnW`>/2
ojO0k0KoYl3[1OnX`>/00onW`>_oZ<3[ojS0j`05ojS0j`?oZ;o[0onX`>/7ojRoj`?oYko[0onX`>/6
ojRoj`?oYko[1?nX`>/7ojRoj`coYl3[00?oYko[ojO0jonW`>/02?nW`>/=ojO0k5oooooo00?o0000
ooooooooool00oooool1o`00007ooooo0Oooool004_ooooo00?o0000ooooooooool0;oooool=ojS0
j`KoYl3[0onW`>`4ojO0j`GoYl3/00?oYl3[ojO0k?nW`>`01?nW`>`6ojO0j`03ojS0jonW`>_oYl3[
00?oYl3[1OnX`>/2ojO0j`KoZ<3[1OnX_n/8ojS0j`?oZ;o[0onW`>/7ojS0j`?oZ;o[5onW`>/=ojO0
k6;ooooo00?o0000ooooooooool00oooool1o`00007ooooo0Oooool004cooooo0_l0000`ooooo`go
Z<3[0onW`>/3ojS0j`OoYl3[0_nW`>`4ojO0j`KoYl3/0onW`>/4ojO0k0GoYl3[00?oZ<3[ojO0jonW
`>/01?nW`>/6ojS0j`03ojRojonX`>_oZ<3[00SoZ<3[2?nW`>/5ojS0j`coYl3[0_nW`>`:ojO0j`go
Yl3/I_ooool00ol0003oooooooooo`03ooooo`7o00000Oooool004kooooo00?o0000ooooooooool0
;_oooolCojS0j`goYl3[0onW`>`3ojO0j`OoYl3/0_nW`>/4ojO0k0KoYl3[0onX`>/4ojO0j`OoZ<3[
2onW`>/00onX`>_oYl3[ojO0j`09ojO0j`OoYl3/1onW`>/:ojO0k6cooooo00?o0000ooooooooool0
0_ooool1o`00007ooooo001?ooooo`03o`000?oooooooooo02oooooo4_nX`>/;ojO0j`;oYko[1_nW
`>/5ojO0k003ojO0jonW`>coYl3/00GoYl3/0onW`>/3ojO0k0OoYl3[0onX`>/3ojO0k0WoYl3[1?nW
`>`7ojO0j`_oYl3/1onW`>/5ojO0k77ooooo00Go0000ooooooooooooooooo`000001ooooo`00D?oo
ool00ol0003oooooooooo`0_ooooo`;oZ<3[0onW`>/>ojS0j`KoYl3[1_nW_n/6ojO0j`03ojO0k?nW
`>_oYl3[00?oYl3[1OnW`>`2ojO0j`KoYl3/1OnW`>/8ojO0k0?oYl3[2_nW`>`3ojO0j`coYl3/2_nW
`>/00onW`>coooooooooo`1booooo`05o`000?ooooooooooooooool000000Oooool0057ooooo0_l0
000`ooooo`GoYl3[3_nX`>/2ojO0j`CoZ<3[1_nW_n/3ojO0j`CoYko[1OnW`>/00onW`>coYl3[ojO0
j`04ojO0j`KoYl3/00?oYl3[ojO0k?nW`>`02?nW`>`2ojO0j`_oYl3/00?oYl3[ojO0k?nW`>`02?nW
`>`=ojO0jgSooooo00Co0000oooooooooooo00000Oooool005?ooooo00?o0000ooooooooool0;_oo
ool5ojO0jaCoZ<3[0onW_n/3ojS0j`OoYko[0_nW`>/4ojNoj`KoYl3[0onW`>`3ojO0j`OoYl3/1_nW
`>/7ojO0k0GoYl3[1OnW`>`2ojNoj`_oYl3[OOooool00ol0003oooooo`000001ooooo`00E?ooool0
0ol0003oooooooooo`0^ooooo`KoYl3[6OnX`>/5ojNoj`03ojS0jonW_n_oYko[00GoYko[0onW`>/3
ojNoj`KoYl3[0onW`>`4ojNoj`KoYl3[0onW`>`3ojNoj`KoYl3[00?oYl3/ojNojonW_n/01?nW_n/7
ojO0jh3ooooo00?o0000ooooool000000Oooool005Gooooo00?o0000ooooooooool0;_ooool6ojO0
j`?oZ<3[1?nW`>/BojS0j`03ojNojonX`>_oZ<3[00?oZ<3[1OnW_n/2ojS0j`KoYko[1?nW`>/9ojNo
j`?oYl3[2OnW_n/3ojO0j`[oYko[0onW`>^4ooooo`7o00000Oooool1o`000000E_ooool2o`0002oo
oooo3OnW`>/2ojS0j`CoYl3[4_nX`>/00onW_n_oZ<3[ojS0j`04ojS0j`KoYko[00?oYl3[ojNojonW
_n/02?nW_n/2ojRojaKoYko[R_ooool2o`000000F?ooool00ol0003oooooooooo`0]oooooa?oYl3[
0onX`>/3ojO0ja?oZ<3[0onW_n/3ojS0j`OoYko[1_nX_n/AojNojhgooooo0ol0000005Wooooo00?o
0000ooooooooool0;OoooolIojO0j`GoZ<3[00?oYl3[ojS0jonX`>/04OnX`>/3ojNoj`CoZ<3[1_nX
_n/2ojNoj`CoZ<3[1onW_n^<ooooo`Co00000oooool005[ooooo00?o0000ooooooooool0;OoooolI
ojO0j`03ojS0jonW`>_oYl3[00?oYl3[1OnX`>/2ojO0j`[oZ<3[0_nW`>/7ojS0j`?oZ;o[0onW`>/6
ojS0j`?oYko[S?ooool3o`0000Oooooo001Kooooo`03o`000?oooooooooo02kooooo7_nW`>/00onX
`>_oYl3[ojO0j`04ojO0j`OoZ<3[1OnW`>/5ojS0j`SoYl3[0onX`>^=ooooo`Co00002_ooool005co
oooo0_l0000_ooooobGoYl3[0onX`>/9ojO0j`03ojS0jonW`>_oYl3[00SoYl3[SOooool4o`0000ko
oooo001Nooooo`03o`000?oooooooooo02gooooo>?nW`>^<ooooo`Co00004_ooool005oooooo00?o
0000ooooooooool0;OooooldojO0jh_ooooo1?l0000Fooooo`00H?ooool00ol0003oooooooooo`0]
ooooo`?oYl3[1?nX`>/XojO0jhcooooo0ol0000Jooooo`00HOooool2o`0002oooooo1_nX`>/2ojO0
j`CoZ<3[7OnW`>^<ooooo`Co00007Oooool006?ooooo00?o0000ooooooooool0;Oooool<ojS0jaWo
Yl3[Roooool4o`00027ooooo001Tooooo`03o`000?oooooooooo02gooooo3?nX`>/EojO0jh[ooooo
1?l0000Uooooo`00IOooool00ol0003oooooooooo`0]ooooo`coZ<3[1?nW`>/2ojS0j`WoYl3[Rooo
ool4o`0002Wooooo001Vooooo`;o0000;_ooool2ojS0j`CoYl3[1_nX`>/00onW`>_oZ<3[ojS0j`03
ojS0j`GoYl3[Roooool3o`0002gooooo001Xooooo`03o`000?oooooooooo02cooooo1_nW`>/3ojS0
j`?oYl3[1_nX`>/00onW`>_oooooooooo`28ooooo`Co0000<?ooool006Wooooo00?o0000oooooooo
ool0;?ooool<ojO0j`?oZ<3[ROooool4o`0003Cooooo001Zooooo`03o`000?oooooooooo02cooooo
2OnW`>^:ooooo`Co0000>?ooool006_ooooo0_l0000]ooooo`GoYl3[ROooool4o`0003cooooo001]
ooooo`03o`000?oooooooooo02_ooooo00?oYl3[ooooooooool0Qoooool3o`00043ooooo001^oooo
o`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0Poooool4o`0004?ooooo001_ooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool0Ooooool4o`0004Oooooo001`ooooo`;o0000
:Oooool00ol0003oooooooooo`1kooooo`Co0000Boooool007;ooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`1gooooo`Co0000Coooool007?ooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`1dooooo`?o0000Doooool007Cooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`1`ooooo`Co0000E_ooool007Gooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`1/ooooo`Co0000F_ooool007Kooooo0_l0000Sooooo`03o`000?oooooooooo06Sooooo
1?l0001Nooooo`00N?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo06Cooooo1?l0
001Rooooo`00NOooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo067ooooo0ol0001V
ooooo`00N_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo05gooooo1?l0001Yoooo
o`00Noooool2o`0001kooooo00?o0000ooooooooool0FOooool4o`0006gooooo001mooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool0EOooool4o`00077ooooo001nooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool0DOooool4o`0007Gooooo001oooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool0C_ooool3o`0007Wooooo0020ooooo`;o00006Oooool00ol0
003oooooooooo`1:ooooo`Co0000O?ooool008;ooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`16ooooo`Co0000P?ooool008?ooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`12ooooo`Co0000Q?ooool008Cooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`0nooooo`Co0000R?ooool008Gooooo0_l0000Cooooo`03o`000?oooooooooo03cooooo0ol0002<
ooooo`00Qoooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03Sooooo1?l0002?oooo
o`00R?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03Cooooo1?l0002Cooooo`00
ROooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo033ooooo1?l0002Gooooo`00R_oo
ool2o`0000kooooo00?o0000ooooooooool0;?ooool4o`0009_ooooo002<ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool0:Oooool3o`0009oooooo002=ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool09Oooool4o`000:;ooooo002>ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool08Oooool4o`000:Kooooo002?ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool07Oooool4o`000:[ooooo002@ooooo`;o00002?ooool00ol0003ooooooooo
o`0Iooooo`Co0000[_ooool009;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0F
ooooo`?o0000/_ooool009?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Boooo
o`Co0000]Oooool009Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0>ooooo`Co
0000^Oooool009Gooooo0_l00003ooooo`03o`000?oooooooooo00[ooooo1?l0002mooooo`00Uooo
ool01?l0003oooooooooool00008ooooo`Co0000`Oooool009Sooooo00?o0000ooooool000001Ooo
ool3o`000<Gooooo002Iooooo`;o000000?oooooo`000?l000000_l00038ooooo`00V_ooool2o`00
0<cooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0538698, 0.0432538, \
0.0035044, 0.0035044}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[.12586 .2075 -12 -8.99448 ]
[.12586 .2075 0 .00552 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.56094 .0364 -5.16972 -9 ]
[.56094 .0364 .83028 0 ]
[.75679 .08071 0 -6.17777 ]
[.75679 .08071 12 2.82223 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.9429 .3657 0 -5.9083 ]
[.9429 .3657 6 3.0917 ]
[.02494 .25992 -18 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.01611 .31527 -18 -2.78472 ]
[.01611 .31527 0 6.21528 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00254 .43215 -12 -2.88407 ]
[-0.00254 .43215 0 6.11593 ]
[-0.0124 .49393 -12 -2.93688 ]
[-0.0124 .49393 0 6.06312 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
[(-2)] .12586 .2075 1 .99877 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.56863 .04703 m
.57247 .05235 L
s
[(2)] .56094 .0364 .72324 1 Mshowa
.125 Mabswid
.18558 .19702 m
.18832 .19985 L
s
.23703 .17687 m
.23971 .17975 L
s
.28951 .15632 m
.29214 .15925 L
s
.39772 .11395 m
.40023 .11699 L
s
.4535 .09211 m
.45595 .0952 L
s
.51046 .06981 m
.51284 .07294 L
s
.08568 .23614 m
.08851 .23887 L
s
.62804 .02377 m
.63027 .02701 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.7445 .0853 m
.73835 .08759 L
s
[(-2)] .75679 .08071 -1 .37284 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.93037 .36962 m
.92411 .37158 L
s
[(2)] .9429 .3657 -1 .31296 Mshowa
.125 Mabswid
.7708 .12553 m
.7671 .12688 L
s
.79613 .16428 m
.79242 .1656 L
s
.82054 .20161 m
.81682 .20291 L
s
.86679 .27235 m
.86305 .2736 L
s
.88871 .30589 m
.88497 .30711 L
s
.9099 .3383 m
.90615 .3395 L
s
.71716 .04348 m
.71349 .04489 L
s
.95018 .39992 m
.94642 .40107 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(-20)] .02494 .25992 1 -0.39157 Mshowa
.02837 .31059 m
.0345 .30825 L
s
[(-10)] .01611 .31527 1 -0.38117 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.00981 .42772 m
.01599 .4255 L
s
[(10)] -0.00254 .43215 1 -0.3591 Mshowa
0 .48963 m
.0062 .48748 L
s
[(20)] -0.0124 .49393 1 -0.34736 Mshowa
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.653 .753 .923 r
.39362 .69483 .40169 .70181 .4152 .69807 .40717 .69105 Mtetra
.657 .754 .921 r
.40717 .69105 .4152 .69807 .42878 .69431 .42079 .68714 Mtetra
.659 .751 .918 r
.42079 .68714 .42878 .69431 .44242 .69042 .43448 .68316 Mtetra
.657 .749 .918 r
.43448 .68316 .44242 .69042 .45614 .68647 .44824 .67923 Mtetra
.656 .75 .919 r
.44824 .67923 .45614 .68647 .46992 .68253 .46207 .67532 Mtetra
.653 .751 .922 r
.46207 .67532 .46992 .68253 .48378 .67863 .47597 .67146 Mtetra
.653 .753 .923 r
.47597 .67146 .48378 .67863 .4977 .67476 .48994 .66759 Mtetra
.656 .755 .923 r
.48994 .66759 .4977 .67476 .5117 .6709 .50398 .6636 Mtetra
.658 .753 .92 r
.50398 .6636 .5117 .6709 .52577 .667 .5181 .65953 Mtetra
.658 .75 .917 r
.5181 .65953 .52577 .667 .53991 .66298 .53229 .65542 Mtetra
.657 .748 .917 r
.53229 .65542 .53991 .66298 .55412 .65891 .54655 .65133 Mtetra
.54655 .65133 .55412 .65891 .56841 .65482 .56088 .64724 Mtetra
.656 .749 .918 r
.56088 .64724 .56841 .65482 .58277 .65072 .57529 .64315 Mtetra
.655 .75 .92 r
.57529 .64315 .58277 .65072 .5972 .64662 .58978 .63908 Mtetra
.654 .752 .921 r
.58978 .63908 .5972 .64662 .61171 .64252 .60434 .63501 Mtetra
.654 .754 .923 r
.60434 .63501 .61171 .64252 .6263 .6384 .61898 .63091 Mtetra
.654 .755 .924 r
.61898 .63091 .6263 .6384 .64096 .63427 .6337 .62678 Mtetra
.655 .756 .925 r
.6337 .62678 .64096 .63427 .6557 .63011 .64849 .62261 Mtetra
.655 .757 .925 r
.64849 .62261 .6557 .63011 .67052 .62594 .66336 .6184 Mtetra
.66336 .6184 .67052 .62594 .68541 .62174 .67831 .61416 Mtetra
.655 .758 .925 r
.67831 .61416 .68541 .62174 .70039 .61751 .69334 .60989 Mtetra
.656 .757 .925 r
.69334 .60989 .70039 .61751 .71544 .61327 .70845 .60558 Mtetra
.656 .757 .924 r
.70845 .60558 .71544 .61327 .73058 .609 .72364 .60123 Mtetra
.657 .756 .923 r
.72364 .60123 .73058 .609 .74579 .60471 .73891 .59684 Mtetra
.657 .755 .922 r
.73891 .59684 .74579 .60471 .76109 .60042 .75426 .59242 Mtetra
.657 .753 .92 r
.75426 .59242 .76109 .60042 .77647 .59611 .76969 .588 Mtetra
.656 .75 .919 r
.76969 .588 .77647 .59611 .79193 .5918 .78521 .5836 Mtetra
.655 .749 .919 r
.78521 .5836 .79193 .5918 .80748 .58748 .80081 .57919 Mtetra
.655 .748 .918 r
.80081 .57919 .80748 .58748 .82311 .58314 .8165 .57479 Mtetra
.654 .747 .918 r
.8165 .57479 .82311 .58314 .83883 .57874 .83229 .5704 Mtetra
.654 .748 .919 r
.83229 .5704 .83883 .57874 .85462 .57422 .84815 .56598 Mtetra
.656 .752 .921 r
.84815 .56598 .85462 .57422 .8705 .56965 .8641 .56146 Mtetra
.658 .756 .922 r
.8641 .56146 .8705 .56965 .88646 .56509 .88013 .55682 Mtetra
.658 .755 .922 r
.88013 .55682 .88646 .56509 .90252 .56056 .89624 .55215 Mtetra
.656 .752 .92 r
.89624 .55215 .90252 .56056 .91867 .55606 .91245 .54754 Mtetra
.655 .75 .919 r
.91245 .54754 .91867 .55606 .93492 .55157 .92875 .54295 Mtetra
.654 .748 .919 r
.92875 .54295 .93492 .55157 .95125 .54701 .94516 .5384 Mtetra
.655 .75 .92 r
.94516 .5384 .95125 .54701 .96766 .54231 .96165 .53377 Mtetra
.657 .754 .921 r
.96165 .53377 .96766 .54231 .98416 .53758 .97822 .529 Mtetra
.38546 .68778 .39362 .69483 .40717 .69105 .39906 .68386 Mtetra
.659 .751 .918 r
.39906 .68386 .40717 .69105 .42079 .68714 .41273 .67986 Mtetra
.657 .749 .918 r
.41273 .67986 .42079 .68714 .43448 .68316 .42646 .67591 Mtetra
.655 .75 .92 r
.42646 .67591 .43448 .68316 .44824 .67923 .44027 .67199 Mtetra
.653 .751 .922 r
.44027 .67199 .44824 .67923 .46207 .67532 .45414 .66814 Mtetra
.653 .754 .924 r
.45414 .66814 .46207 .67532 .47597 .67146 .46808 .66424 Mtetra
.657 .755 .922 r
.46808 .66424 .47597 .67146 .48994 .66759 .4821 .66018 Mtetra
.658 .751 .918 r
.4821 .66018 .48994 .66759 .50398 .6636 .49619 .65607 Mtetra
.658 .749 .917 r
.49619 .65607 .50398 .6636 .5181 .65953 .51035 .65196 Mtetra
.657 .748 .917 r
.51035 .65196 .5181 .65953 .53229 .65542 .52459 .64786 Mtetra
.656 .749 .919 r
.52459 .64786 .53229 .65542 .54655 .65133 .5389 .64379 Mtetra
.653 .75 .921 r
.5389 .64379 .54655 .65133 .56088 .64724 .55328 .63978 Mtetra
.653 .753 .923 r
.55328 .63978 .56088 .64724 .57529 .64315 .56775 .63574 Mtetra
.653 .756 .925 r
.56775 .63574 .57529 .64315 .58978 .63908 .58228 .63166 Mtetra
.655 .757 .925 r
.58228 .63166 .58978 .63908 .60434 .63501 .5969 .62751 Mtetra
.656 .756 .924 r
.5969 .62751 .60434 .63501 .61898 .63091 .61159 .6233 Mtetra
.656 .754 .922 r
.61159 .6233 .61898 .63091 .6337 .62678 .62635 .61906 Mtetra
.656 .753 .921 r
.62635 .61906 .6337 .62678 .64849 .62261 .6412 .61481 Mtetra
.656 .752 .92 r
.6412 .61481 .64849 .62261 .66336 .6184 .65612 .61054 Mtetra
.656 .751 .92 r
.65612 .61054 .66336 .6184 .67831 .61416 .67113 .60626 Mtetra
.67113 .60626 .67831 .61416 .69334 .60989 .68621 .60196 Mtetra
.655 .751 .921 r
.68621 .60196 .69334 .60989 .70845 .60558 .70138 .59765 Mtetra
.655 .752 .921 r
.70138 .59765 .70845 .60558 .72364 .60123 .71663 .59332 Mtetra
.655 .754 .923 r
.71663 .59332 .72364 .60123 .73891 .59684 .73196 .58897 Mtetra
.656 .756 .924 r
.73196 .58897 .73891 .59684 .75426 .59242 .74737 .58455 Mtetra
.657 .758 .924 r
.74737 .58455 .75426 .59242 .76969 .588 .76286 .58005 Mtetra
.658 .757 .924 r
.76286 .58005 .76969 .588 .78521 .5836 .77843 .57551 Mtetra
.658 .755 .922 r
.77843 .57551 .78521 .5836 .80081 .57919 .79409 .57095 Mtetra
.656 .751 .92 r
.79409 .57095 .80081 .57919 .8165 .57479 .80984 .56644 Mtetra
.655 .749 .919 r
.80984 .56644 .8165 .57479 .83229 .5704 .82567 .56195 Mtetra
.654 .748 .918 r
.82567 .56195 .83229 .5704 .84815 .56598 .8416 .55747 Mtetra
.654 .747 .918 r
.8416 .55747 .84815 .56598 .8641 .56146 .85762 .553 Mtetra
.654 .75 .92 r
.85762 .553 .8641 .56146 .88013 .55682 .87373 .54847 Mtetra
.658 .755 .922 r
.87373 .54847 .88013 .55682 .89624 .55215 .88991 .54376 Mtetra
.658 .756 .922 r
.88991 .54376 .89624 .55215 .91245 .54754 .90617 .539 Mtetra
.656 .752 .921 r
.90617 .539 .91245 .54754 .92875 .54295 .92253 .53431 Mtetra
.655 .75 .92 r
.92253 .53431 .92875 .54295 .94516 .5384 .939 .52964 Mtetra
.653 .748 .919 r
.939 .52964 .94516 .5384 .96165 .53377 .95556 .52502 Mtetra
.655 .75 .92 r
.95556 .52502 .96165 .53377 .97822 .529 .97221 .52032 Mtetra
.659 .751 .918 r
.37724 .68057 .38546 .68778 .39906 .68386 .39088 .67655 Mtetra
.657 .749 .918 r
.39088 .67655 .39906 .68386 .41273 .67986 .40459 .67257 Mtetra
.655 .75 .92 r
.40459 .67257 .41273 .67986 .42646 .67591 .41837 .66865 Mtetra
.652 .751 .922 r
.41837 .66865 .42646 .67591 .44027 .67199 .43221 .66479 Mtetra
.654 .754 .924 r
.43221 .66479 .44027 .67199 .45414 .66814 .44613 .66085 Mtetra
.658 .754 .921 r
.44613 .66085 .45414 .66814 .46808 .66424 .46012 .65675 Mtetra
.659 .75 .917 r
.46012 .65675 .46808 .66424 .4821 .66018 .47419 .65261 Mtetra
.658 .749 .917 r
.47419 .65261 .4821 .66018 .49619 .65607 .48833 .6485 Mtetra
.656 .749 .918 r
.48833 .6485 .49619 .65607 .51035 .65196 .50254 .64441 Mtetra
.653 .75 .921 r
.50254 .64441 .51035 .65196 .52459 .64786 .51682 .64041 Mtetra
.652 .753 .924 r
.51682 .64041 .52459 .64786 .5389 .64379 .53118 .6364 Mtetra
.653 .756 .925 r
.53118 .6364 .5389 .64379 .55328 .63978 .54561 .63232 Mtetra
.656 .756 .924 r
.54561 .63232 .55328 .63978 .56775 .63574 .56012 .62812 Mtetra
.657 .753 .921 r
.56012 .62812 .56775 .63574 .58228 .63166 .57471 .62388 Mtetra
.657 .75 .918 r
.57471 .62388 .58228 .63166 .5969 .62751 .58937 .61961 Mtetra
.657 .748 .917 r
.58937 .61961 .5969 .62751 .61159 .6233 .60411 .61533 Mtetra
.657 .747 .916 r
.60411 .61533 .61159 .6233 .62635 .61906 .61893 .61103 Mtetra
.61893 .61103 .62635 .61906 .6412 .61481 .63383 .60673 Mtetra
.657 .746 .916 r
.63383 .60673 .6412 .61481 .65612 .61054 .64881 .60241 Mtetra
.656 .746 .916 r
.64881 .60241 .65612 .61054 .67113 .60626 .66387 .59809 Mtetra
.66387 .59809 .67113 .60626 .68621 .60196 .67901 .59375 Mtetra
.656 .746 .917 r
.67901 .59375 .68621 .60196 .70138 .59765 .69423 .58941 Mtetra
.655 .746 .917 r
.69423 .58941 .70138 .59765 .71663 .59332 .70953 .58505 Mtetra
.655 .747 .917 r
.70953 .58505 .71663 .59332 .73196 .58897 .72492 .58068 Mtetra
.655 .747 .918 r
.72492 .58068 .73196 .58897 .74737 .58455 .74039 .5763 Mtetra
.655 .749 .919 r
.74039 .5763 .74737 .58455 .76286 .58005 .75595 .57188 Mtetra
.655 .753 .922 r
.75595 .57188 .76286 .58005 .77843 .57551 .77159 .56743 Mtetra
.657 .757 .923 r
.77159 .56743 .77843 .57551 .79409 .57095 .78731 .56284 Mtetra
.658 .758 .924 r
.78731 .56284 .79409 .57095 .80984 .56644 .80311 .55818 Mtetra
.658 .755 .922 r
.80311 .55818 .80984 .56644 .82567 .56195 .819 .55351 Mtetra
.656 .751 .92 r
.819 .55351 .82567 .56195 .8416 .55747 .83499 .54892 Mtetra
.655 .749 .919 r
.83499 .54892 .8416 .55747 .85762 .553 .85107 .54436 Mtetra
.653 .747 .918 r
.85107 .54436 .85762 .553 .87373 .54847 .86724 .53982 Mtetra
.654 .748 .919 r
.86724 .53982 .87373 .54847 .88991 .54376 .8835 .53524 Mtetra
.657 .754 .921 r
.8835 .53524 .88991 .54376 .90617 .539 .89984 .53049 Mtetra
.659 .756 .922 r
.89984 .53049 .90617 .539 .92253 .53431 .91626 .52564 Mtetra
.657 .753 .921 r
.91626 .52564 .92253 .53431 .939 .52964 .93278 .52086 Mtetra
.655 .75 .92 r
.93278 .52086 .939 .52964 .95556 .52502 .9494 .51613 Mtetra
.653 .748 .919 r
.9494 .51613 .95556 .52502 .97221 .52032 .96613 .51144 Mtetra
.657 .749 .918 r
.36894 .67323 .37724 .68057 .39088 .67655 .38262 .66923 Mtetra
.655 .75 .92 r
.38262 .66923 .39088 .67655 .40459 .67257 .39637 .66528 Mtetra
.652 .751 .922 r
.39637 .66528 .40459 .67257 .41837 .66865 .41019 .66141 Mtetra
.654 .754 .923 r
.41019 .66141 .41837 .66865 .43221 .66479 .42408 .65745 Mtetra
.658 .754 .92 r
.42408 .65745 .43221 .66479 .44613 .66085 .43805 .65332 Mtetra
.659 .75 .917 r
.43805 .65332 .44613 .66085 .46012 .65675 .45209 .64916 Mtetra
.657 .749 .917 r
.45209 .64916 .46012 .65675 .47419 .65261 .4662 .64504 Mtetra
.655 .749 .92 r
.4662 .64504 .47419 .65261 .48833 .6485 .48038 .64098 Mtetra
.652 .751 .923 r
.48038 .64098 .48833 .6485 .50254 .64441 .49464 .637 Mtetra
.652 .755 .925 r
.49464 .637 .50254 .64441 .51682 .64041 .50897 .63297 Mtetra
.657 .756 .923 r
.50897 .63297 .51682 .64041 .53118 .6364 .52338 .62876 Mtetra
.658 .753 .92 r
.52338 .62876 .53118 .6364 .54561 .63232 .53787 .62449 Mtetra
.658 .749 .917 r
.53787 .62449 .54561 .63232 .56012 .62812 .55243 .6202 Mtetra
.658 .748 .916 r
.55243 .6202 .56012 .62812 .57471 .62388 .56706 .61589 Mtetra
.658 .747 .916 r
.56706 .61589 .57471 .62388 .58937 .61961 .58178 .61159 Mtetra
.657 .747 .916 r
.58178 .61159 .58937 .61961 .60411 .61533 .59657 .60728 Mtetra
.656 .747 .917 r
.59657 .60728 .60411 .61533 .61893 .61103 .61144 .60297 Mtetra
.656 .748 .918 r
.61144 .60297 .61893 .61103 .63383 .60673 .62639 .59866 Mtetra
.62639 .59866 .63383 .60673 .64881 .60241 .64142 .59433 Mtetra
.656 .749 .919 r
.64142 .59433 .64881 .60241 .66387 .59809 .65654 .58996 Mtetra
.656 .75 .919 r
.65654 .58996 .66387 .59809 .67901 .59375 .67173 .58555 Mtetra
.656 .749 .918 r
.67173 .58555 .67901 .59375 .69423 .58941 .68701 .58113 Mtetra
.656 .748 .918 r
.68701 .58113 .69423 .58941 .70953 .58505 .70237 .5767 Mtetra
.655 .747 .917 r
.70237 .5767 .70953 .58505 .72492 .58068 .71781 .57227 Mtetra
.655 .746 .917 r
.71781 .57227 .72492 .58068 .74039 .5763 .73334 .56783 Mtetra
.654 .746 .917 r
.73334 .56783 .74039 .5763 .75595 .57188 .74896 .5634 Mtetra
.654 .746 .918 r
.74896 .5634 .75595 .57188 .77159 .56743 .76466 .55895 Mtetra
.654 .748 .919 r
.76466 .55895 .77159 .56743 .78731 .56284 .78045 .55447 Mtetra
.655 .752 .921 r
.78045 .55447 .78731 .56284 .80311 .55818 .79633 .54992 Mtetra
.658 .757 .923 r
.79633 .54992 .80311 .55818 .819 .55351 .81228 .5452 Mtetra
.659 .758 .923 r
.81228 .5452 .819 .55351 .83499 .54892 .82832 .54042 Mtetra
.657 .753 .921 r
.82832 .54042 .83499 .54892 .85107 .54436 .84445 .53571 Mtetra
.655 .749 .919 r
.84445 .53571 .85107 .54436 .86724 .53982 .86068 .53107 Mtetra
.653 .747 .919 r
.86068 .53107 .86724 .53982 .8835 .53524 .87701 .52645 Mtetra
.653 .748 .919 r
.87701 .52645 .8835 .53524 .89984 .53049 .89343 .52181 Mtetra
.657 .753 .921 r
.89343 .52181 .89984 .53049 .91626 .52564 .90993 .51698 Mtetra
.659 .756 .922 r
.90993 .51698 .91626 .52564 .93278 .52086 .92651 .51206 Mtetra
.656 .752 .921 r
.92651 .51206 .93278 .52086 .9494 .51613 .94319 .50721 Mtetra
.655 .75 .92 r
.94319 .50721 .9494 .51613 .96613 .51144 .95998 .50241 Mtetra
.656 .75 .919 r
.36056 .66587 .36894 .67323 .38262 .66923 .37429 .66189 Mtetra
.652 .751 .922 r
.37429 .66189 .38262 .66923 .39637 .66528 .38808 .658 Mtetra
.653 .754 .923 r
.38808 .658 .39637 .66528 .41019 .66141 .40194 .65404 Mtetra
.659 .754 .92 r
.40194 .65404 .41019 .66141 .42408 .65745 .41588 .64989 Mtetra
.659 .75 .917 r
.41588 .64989 .42408 .65745 .43805 .65332 .42989 .64571 Mtetra
.657 .749 .918 r
.42989 .64571 .43805 .65332 .45209 .64916 .44398 .64157 Mtetra
.653 .75 .92 r
.44398 .64157 .45209 .64916 .4662 .64504 .45813 .63753 Mtetra
.651 .752 .924 r
.45813 .63753 .4662 .64504 .48038 .64098 .47236 .63355 Mtetra
.654 .756 .925 r
.47236 .63355 .48038 .64098 .49464 .637 .48667 .62943 Mtetra
.658 .754 .921 r
.48667 .62943 .49464 .637 .50897 .63297 .50105 .62516 Mtetra
.659 .75 .917 r
.50105 .62516 .50897 .63297 .52338 .62876 .51551 .62085 Mtetra
.659 .748 .916 r
.51551 .62085 .52338 .62876 .53787 .62449 .53004 .61652 Mtetra
.658 .747 .916 r
.53004 .61652 .53787 .62449 .55243 .6202 .54465 .61222 Mtetra
.656 .747 .917 r
.54465 .61222 .55243 .6202 .56706 .61589 .55934 .60796 Mtetra
.653 .749 .92 r
.55934 .60796 .56706 .61589 .58178 .61159 .57411 .60377 Mtetra
.653 .753 .923 r
.57411 .60377 .58178 .61159 .59657 .60728 .58896 .59955 Mtetra
.653 .756 .925 r
.58896 .59955 .59657 .60728 .61144 .60297 .60388 .59528 Mtetra
.654 .759 .927 r
.60388 .59528 .61144 .60297 .62639 .59866 .61889 .59096 Mtetra
.654 .76 .927 r
.61889 .59096 .62639 .59866 .64142 .59433 .63398 .5866 Mtetra
.655 .76 .927 r
.63398 .5866 .64142 .59433 .65654 .58996 .64915 .58219 Mtetra
.656 .76 .927 r
.64915 .58219 .65654 .58996 .67173 .58555 .6644 .57773 Mtetra
.656 .761 .927 r
.6644 .57773 .67173 .58555 .68701 .58113 .67973 .57322 Mtetra
.657 .76 .925 r
.67973 .57322 .68701 .58113 .70237 .5767 .69515 .56866 Mtetra
.658 .758 .924 r
.69515 .56866 .70237 .5767 .71781 .57227 .71064 .56406 Mtetra
.658 .755 .921 r
.71064 .56406 .71781 .57227 .73334 .56783 .72623 .55942 Mtetra
.656 .75 .919 r
.72623 .55942 .73334 .56783 .74896 .5634 .7419 .55484 Mtetra
.655 .747 .918 r
.7419 .55484 .74896 .5634 .76466 .55895 .75766 .55032 Mtetra
.654 .746 .917 r
.75766 .55032 .76466 .55895 .78045 .55447 .77351 .54581 Mtetra
.653 .746 .918 r
.77351 .54581 .78045 .55447 .79633 .54992 .78945 .54129 Mtetra
.654 .748 .919 r
.78945 .54129 .79633 .54992 .81228 .5452 .80548 .53671 Mtetra
.657 .754 .922 r
.80548 .53671 .81228 .5452 .82832 .54042 .82159 .53199 Mtetra
.659 .758 .923 r
.82159 .53199 .82832 .54042 .84445 .53571 .83778 .52711 Mtetra
.658 .754 .921 r
.83778 .52711 .84445 .53571 .86068 .53107 .85406 .52229 Mtetra
.655 .75 .92 r
.85406 .52229 .86068 .53107 .87701 .52645 .87045 .51757 Mtetra
.653 .748 .919 r
.87045 .51757 .87701 .52645 .89343 .52181 .88694 .51288 Mtetra
.88694 .51288 .89343 .52181 .90993 .51698 .90352 .50817 Mtetra
.658 .754 .921 r
.90352 .50817 .90993 .51698 .92651 .51206 .92018 .50325 Mtetra
.659 .756 .922 r
.92018 .50325 .92651 .51206 .94319 .50721 .93692 .49825 Mtetra
.656 .752 .92 r
.93692 .49825 .94319 .50721 .95998 .50241 .95377 .49333 Mtetra
.653 .751 .921 r
.3521 .65849 .36056 .66587 .37429 .66189 .36586 .65456 Mtetra
.652 .753 .923 r
.36586 .65456 .37429 .66189 .38808 .658 .3797 .65062 Mtetra
.658 .754 .921 r
.3797 .65062 .38808 .658 .40194 .65404 .39361 .64645 Mtetra
.659 .75 .917 r
.39361 .64645 .40194 .65404 .41588 .64989 .4076 .64225 Mtetra
.657 .749 .918 r
.4076 .64225 .41588 .64989 .42989 .64571 .42166 .63808 Mtetra
.653 .75 .921 r
.42166 .63808 .42989 .64571 .44398 .64157 .43578 .63404 Mtetra
.651 .753 .924 r
.43578 .63404 .44398 .64157 .45813 .63753 .44999 .63005 Mtetra
.655 .756 .924 r
.44999 .63005 .45813 .63753 .47236 .63355 .46427 .62587 Mtetra
.659 .753 .919 r
.46427 .62587 .47236 .63355 .48667 .62943 .47862 .62156 Mtetra
.659 .749 .916 r
.47862 .62156 .48667 .62943 .50105 .62516 .49305 .61721 Mtetra
.658 .748 .916 r
.49305 .61721 .50105 .62516 .51551 .62085 .50756 .61288 Mtetra
.655 .747 .918 r
.50756 .61288 .51551 .62085 .53004 .61652 .52214 .60863 Mtetra
.651 .749 .921 r
.52214 .60863 .53004 .61652 .54465 .61222 .53681 .6045 Mtetra
.651 .755 .926 r
.53681 .6045 .54465 .61222 .55934 .60796 .55155 .60033 Mtetra
.653 .759 .928 r
.55155 .60033 .55934 .60796 .57411 .60377 .56637 .59608 Mtetra
.655 .759 .926 r
.56637 .59608 .57411 .60377 .58896 .59955 .58127 .59171 Mtetra
.656 .757 .924 r
.58127 .59171 .58896 .59955 .60388 .59528 .59625 .58731 Mtetra
.656 .754 .922 r
.59625 .58731 .60388 .59528 .61889 .59096 .61131 .58288 Mtetra
.656 .752 .921 r
.61131 .58288 .61889 .59096 .63398 .5866 .62645 .57843 Mtetra
.656 .751 .92 r
.62645 .57843 .63398 .5866 .64915 .58219 .64168 .57398 Mtetra
.655 .751 .92 r
.64168 .57398 .64915 .58219 .6644 .57773 .65699 .56951 Mtetra
.655 .752 .921 r
.65699 .56951 .6644 .57773 .67973 .57322 .67238 .56503 Mtetra
.655 .754 .922 r
.67238 .56503 .67973 .57322 .69515 .56866 .68786 .56052 Mtetra
.655 .756 .924 r
.68786 .56052 .69515 .56866 .71064 .56406 .70342 .55597 Mtetra
.657 .76 .925 r
.70342 .55597 .71064 .56406 .72623 .55942 .71906 .55131 Mtetra
.659 .761 .925 r
.71906 .55131 .72623 .55942 .7419 .55484 .73478 .54656 Mtetra
.66 .758 .923 r
.73478 .54656 .7419 .55484 .75766 .55032 .75059 .54176 Mtetra
.657 .751 .92 r
.75059 .54176 .75766 .55032 .77351 .54581 .7665 .53708 Mtetra
.654 .747 .918 r
.7665 .53708 .77351 .54581 .78945 .54129 .7825 .53249 Mtetra
.653 .746 .918 r
.7825 .53249 .78945 .54129 .80548 .53671 .7986 .52791 Mtetra
.653 .747 .919 r
.7986 .52791 .80548 .53671 .82159 .53199 .81478 .52329 Mtetra
.656 .752 .921 r
.81478 .52329 .82159 .53199 .83778 .52711 .83105 .51853 Mtetra
.66 .758 .922 r
.83105 .51853 .83778 .52711 .85406 .52229 .84739 .51357 Mtetra
.658 .755 .921 r
.84739 .51357 .85406 .52229 .87045 .51757 .86383 .50865 Mtetra
.655 .75 .92 r
.86383 .50865 .87045 .51757 .88694 .51288 .88038 .50386 Mtetra
.653 .748 .919 r
.88038 .50386 .88694 .51288 .90352 .50817 .89703 .49911 Mtetra
.654 .748 .919 r
.89703 .49911 .90352 .50817 .92018 .50325 .91378 .49431 Mtetra
.659 .755 .921 r
.91378 .49431 .92018 .50325 .93692 .49825 .93059 .48927 Mtetra
.658 .755 .921 r
.93059 .48927 .93692 .49825 .95377 .49333 .9475 .48421 Mtetra
.652 .752 .923 r
.34356 .65108 .3521 .65849 .36586 .65456 .35736 .64715 Mtetra
.657 .754 .922 r
.35736 .64715 .36586 .65456 .3797 .65062 .37125 .64302 Mtetra
.66 .751 .917 r
.37125 .64302 .3797 .65062 .39361 .64645 .38521 .63878 Mtetra
.658 .749 .918 r
.38521 .63878 .39361 .64645 .4076 .64225 .39924 .63459 Mtetra
.654 .75 .92 r
.39924 .63459 .4076 .64225 .42166 .63808 .41334 .63052 Mtetra
.65 .752 .924 r
.41334 .63052 .42166 .63808 .43578 .63404 .42751 .62652 Mtetra
.656 .756 .923 r
.42751 .62652 .43578 .63404 .44999 .63005 .44176 .62231 Mtetra
.659 .752 .919 r
.44176 .62231 .44999 .63005 .46427 .62587 .45609 .61796 Mtetra
.66 .749 .916 r
.45609 .61796 .46427 .62587 .47862 .62156 .4705 .61358 Mtetra
.658 .748 .916 r
.4705 .61358 .47862 .62156 .49305 .61721 .48498 .60925 Mtetra
.652 .748 .92 r
.48498 .60925 .49305 .61721 .50756 .61288 .49953 .60512 Mtetra
.65 .753 .925 r
.49953 .60512 .50756 .61288 .52214 .60863 .51417 .601 Mtetra
.653 .758 .927 r
.51417 .601 .52214 .60863 .53681 .6045 .52888 .59675 Mtetra
.656 .758 .924 r
.52888 .59675 .53681 .6045 .55155 .60033 .54367 .59235 Mtetra
.658 .753 .92 r
.54367 .59235 .55155 .60033 .56637 .59608 .55854 .5879 Mtetra
.658 .749 .917 r
.55854 .5879 .56637 .59608 .58127 .59171 .5735 .58342 Mtetra
.659 .748 .916 r
.5735 .58342 .58127 .59171 .59625 .58731 .58853 .57889 Mtetra
.658 .746 .915 r
.58853 .57889 .59625 .58731 .61131 .58288 .60364 .57438 Mtetra
.657 .744 .914 r
.60364 .57438 .61131 .58288 .62645 .57843 .61884 .56987 Mtetra
.656 .744 .914 r
.61884 .56987 .62645 .57843 .64168 .57398 .63412 .56537 Mtetra
.656 .743 .914 r
.63412 .56537 .64168 .57398 .65699 .56951 .64948 .56087 Mtetra
.655 .743 .915 r
.64948 .56087 .65699 .56951 .67238 .56503 .66493 .55639 Mtetra
.654 .744 .916 r
.66493 .55639 .67238 .56503 .68786 .56052 .68047 .55191 Mtetra
.654 .746 .917 r
.68047 .55191 .68786 .56052 .70342 .55597 .69609 .54739 Mtetra
.654 .748 .919 r
.69609 .54739 .70342 .55597 .71906 .55131 .7118 .54283 Mtetra
.655 .752 .921 r
.7118 .54283 .71906 .55131 .73478 .54656 .7276 .53822 Mtetra
.658 .758 .924 r
.7276 .53822 .73478 .54656 .75059 .54176 .74348 .53346 Mtetra
.66 .761 .924 r
.74348 .53346 .75059 .54176 .7665 .53708 .75943 .52856 Mtetra
.66 .756 .922 r
.75943 .52856 .7665 .53708 .7825 .53249 .77548 .52367 Mtetra
.654 .748 .919 r
.77548 .52367 .7825 .53249 .7986 .52791 .79164 .51898 Mtetra
.653 .746 .918 r
.79164 .51898 .7986 .52791 .81478 .52329 .80789 .51434 Mtetra
.653 .747 .919 r
.80789 .51434 .81478 .52329 .83105 .51853 .82423 .50966 Mtetra
.656 .751 .92 r
.82423 .50966 .83105 .51853 .84739 .51357 .84066 .50483 Mtetra
.66 .757 .922 r
.84066 .50483 .84739 .51357 .86383 .50865 .85716 .49978 Mtetra
.658 .754 .921 r
.85716 .49978 .86383 .50865 .88038 .50386 .87376 .4948 Mtetra
.654 .75 .92 r
.87376 .4948 .88038 .50386 .89703 .49911 .89047 .48995 Mtetra
.653 .748 .919 r
.89047 .48995 .89703 .49911 .91378 .49431 .90729 .48513 Mtetra
.655 .749 .919 r
.90729 .48513 .91378 .49431 .93059 .48927 .9242 .4802 Mtetra
.659 .755 .921 r
.9242 .4802 .93059 .48927 .9475 .48421 .94118 .47505 Mtetra
.654 .753 .923 r
.33493 .64365 .34356 .65108 .35736 .64715 .34878 .63958 Mtetra
.659 .752 .919 r
.34878 .63958 .35736 .64715 .37125 .64302 .36271 .63532 Mtetra
.659 .75 .917 r
.36271 .63532 .37125 .64302 .38521 .63878 .37672 .63108 Mtetra
.655 .75 .92 r
.37672 .63108 .38521 .63878 .39924 .63459 .39079 .62695 Mtetra
.65 .751 .923 r
.39079 .62695 .39924 .63459 .41334 .63052 .40493 .62294 Mtetra
.655 .755 .924 r
.40493 .62294 .41334 .63052 .42751 .62652 .41916 .61875 Mtetra
.659 .752 .919 r
.41916 .61875 .42751 .62652 .44176 .62231 .43346 .61438 Mtetra
.66 .749 .916 r
.43346 .61438 .44176 .62231 .45609 .61796 .44784 .60997 Mtetra
.657 .748 .917 r
.44784 .60997 .45609 .61796 .4705 .61358 .46229 .60563 Mtetra
.65 .748 .921 r
.46229 .60563 .4705 .61358 .48498 .60925 .47682 .60154 Mtetra
.649 .755 .927 r
.47682 .60154 .48498 .60925 .49953 .60512 .49142 .59742 Mtetra
.656 .759 .925 r
.49142 .59742 .49953 .60512 .51417 .601 .50611 .59303 Mtetra
.658 .754 .92 r
.50611 .59303 .51417 .601 .52888 .59675 .52087 .58856 Mtetra
.66 .749 .916 r
.52087 .58856 .52888 .59675 .54367 .59235 .53572 .584 Mtetra
.66 .747 .914 r
.53572 .584 .54367 .59235 .55854 .5879 .55064 .57942 Mtetra
.659 .744 .913 r
.55064 .57942 .55854 .5879 .5735 .58342 .56565 .57487 Mtetra
.657 .743 .913 r
.56565 .57487 .5735 .58342 .58853 .57889 .58073 .57036 Mtetra
.655 .744 .915 r
.58073 .57036 .58853 .57889 .60364 .57438 .5959 .56589 Mtetra
.655 .746 .917 r
.5959 .56589 .60364 .57438 .61884 .56987 .61115 .56141 Mtetra
.656 .748 .918 r
.61115 .56141 .61884 .56987 .63412 .56537 .62649 .55686 Mtetra
.657 .749 .917 r
.62649 .55686 .63412 .56537 .64948 .56087 .64191 .55225 Mtetra
.657 .747 .916 r
.64191 .55225 .64948 .56087 .66493 .55639 .65741 .54762 Mtetra
.655 .744 .915 r
.65741 .54762 .66493 .55639 .68047 .55191 .673 .54304 Mtetra
.654 .742 .914 r
.673 .54304 .68047 .55191 .69609 .54739 .68868 .53849 Mtetra
.652 .742 .915 r
.68868 .53849 .69609 .54739 .7118 .54283 .70446 .53397 Mtetra
.652 .744 .917 r
.70446 .53397 .7118 .54283 .7276 .53822 .72032 .52943 Mtetra
.653 .747 .919 r
.72032 .52943 .7276 .53822 .74348 .53346 .73627 .52481 Mtetra
.655 .752 .922 r
.73627 .52481 .74348 .53346 .75943 .52856 .75231 .52009 Mtetra
.661 .76 .924 r
.75231 .52009 .75943 .52856 .77548 .52367 .76842 .5151 Mtetra
.661 .759 .923 r
.76842 .5151 .77548 .52367 .79164 .51898 .78461 .51006 Mtetra
.655 .749 .919 r
.78461 .51006 .79164 .51898 .80789 .51434 .80092 .50528 Mtetra
.652 .746 .919 r
.80092 .50528 .80789 .51434 .82423 .50966 .81733 .50058 Mtetra
.653 .747 .919 r
.81733 .50058 .82423 .50966 .84066 .50483 .83384 .49582 Mtetra
.656 .752 .92 r
.83384 .49582 .84066 .50483 .85716 .49978 .85042 .49089 Mtetra
.66 .757 .922 r
.85042 .49089 .85716 .49978 .87376 .4948 .86708 .48574 Mtetra
.657 .753 .921 r
.86708 .48574 .87376 .4948 .89047 .48995 .88385 .48073 Mtetra
.654 .749 .92 r
.88385 .48073 .89047 .48995 .90729 .48513 .90073 .47582 Mtetra
.653 .748 .919 r
.90073 .47582 .90729 .48513 .9242 .4802 .91772 .47093 Mtetra
.657 .752 .92 r
.91772 .47093 .9242 .4802 .94118 .47505 .93479 .46582 Mtetra
.658 .754 .92 r
.32621 .63611 .33493 .64365 .34878 .63958 .34012 .63187 Mtetra
.659 .75 .917 r
.34012 .63187 .34878 .63958 .36271 .63532 .3541 .62758 Mtetra
.657 .75 .919 r
.3541 .62758 .36271 .63532 .37672 .63108 .36815 .62335 Mtetra
.65 .75 .922 r
.36815 .62335 .37672 .63108 .39079 .62695 .38226 .61933 Mtetra
.653 .754 .924 r
.38226 .61933 .39079 .62695 .40493 .62294 .39645 .61518 Mtetra
.659 .753 .92 r
.39645 .61518 .40493 .62294 .41916 .61875 .41073 .61079 Mtetra
.66 .75 .916 r
.41073 .61079 .41916 .61875 .43346 .61438 .42508 .60635 Mtetra
.658 .748 .917 r
.42508 .60635 .43346 .61438 .44784 .60997 .4395 .60199 Mtetra
.649 .748 .922 r
.4395 .60199 .44784 .60997 .46229 .60563 .454 .5979 Mtetra
.65 .756 .927 r
.454 .5979 .46229 .60563 .47682 .60154 .46858 .59374 Mtetra
.657 .757 .924 r
.46858 .59374 .47682 .60154 .49142 .59742 .48323 .5893 Mtetra
.66 .751 .917 r
.48323 .5893 .49142 .59742 .50611 .59303 .49797 .58474 Mtetra
.662 .748 .914 r
.49797 .58474 .50611 .59303 .52087 .58856 .51279 .5801 Mtetra
.66 .745 .913 r
.51279 .5801 .52087 .58856 .53572 .584 .52769 .57553 Mtetra
.653 .744 .916 r
.52769 .57553 .53572 .584 .55064 .57942 .54266 .57116 Mtetra
.65 .749 .922 r
.54266 .57116 .55064 .57942 .56565 .57487 .55772 .56687 Mtetra
.651 .757 .927 r
.55772 .56687 .56565 .57487 .58073 .57036 .57287 .56252 Mtetra
.652 .762 .931 r
.57287 .56252 .58073 .57036 .5959 .56589 .5881 .55809 Mtetra
.653 .765 .931 r
.5881 .55809 .5959 .56589 .61115 .56141 .60341 .55357 Mtetra
.654 .766 .931 r
.60341 .55357 .61115 .56141 .62649 .55686 .6188 .54898 Mtetra
.656 .766 .931 r
.6188 .54898 .62649 .55686 .64191 .55225 .63428 .54431 Mtetra
.657 .766 .93 r
.63428 .54431 .64191 .55225 .65741 .54762 .64984 .53955 Mtetra
.659 .765 .928 r
.64984 .53955 .65741 .54762 .673 .54304 .66549 .53472 Mtetra
.661 .76 .924 r
.66549 .53472 .673 .54304 .68868 .53849 .68122 .52982 Mtetra
.659 .752 .919 r
.68122 .52982 .68868 .53849 .70446 .53397 .69704 .52499 Mtetra
.653 .743 .916 r
.69704 .52499 .70446 .53397 .72032 .52943 .71296 .52037 Mtetra
.651 .742 .916 r
.71296 .52037 .72032 .52943 .73627 .52481 .72897 .51582 Mtetra
.652 .745 .918 r
.72897 .51582 .73627 .52481 .75231 .52009 .74508 .51118 Mtetra
.654 .749 .92 r
.74508 .51118 .75231 .52009 .76842 .5151 .76127 .50642 Mtetra
.66 .758 .923 r
.76127 .50642 .76842 .5151 .78461 .51006 .77754 .50137 Mtetra
.662 .76 .923 r
.77754 .50137 .78461 .51006 .80092 .50528 .79389 .49623 Mtetra
.654 .749 .92 r
.79389 .49623 .80092 .50528 .81733 .50058 .81036 .49138 Mtetra
.652 .746 .919 r
.81036 .49138 .81733 .50058 .83384 .49582 .82693 .48661 Mtetra
.653 .747 .919 r
.82693 .48661 .83384 .49582 .85042 .49089 .8436 .48178 Mtetra
.658 .753 .92 r
.8436 .48178 .85042 .49089 .86708 .48574 .86034 .47669 Mtetra
.66 .757 .922 r
.86034 .47669 .86708 .48574 .88385 .48073 .87716 .47146 Mtetra
.655 .751 .92 r
.87716 .47146 .88385 .48073 .90073 .47582 .89411 .46644 Mtetra
.653 .748 .92 r
.89411 .46644 .90073 .47582 .91772 .47093 .91117 .46148 Mtetra
.91117 .46148 .91772 .47093 .93479 .46582 .92832 .45647 Mtetra
.66 .752 .918 r
.31742 .62841 .32621 .63611 .34012 .63187 .33138 .62407 Mtetra
.658 .75 .918 r
.33138 .62407 .34012 .63187 .3541 .62758 .3454 .61979 Mtetra
.653 .75 .921 r
.3454 .61979 .3541 .62758 .36815 .62335 .35948 .61567 Mtetra
.65 .753 .925 r
.35948 .61567 .36815 .62335 .38226 .61933 .37364 .6116 Mtetra
.658 .755 .921 r
.37364 .6116 .38226 .61933 .39645 .61518 .38789 .60722 Mtetra
.661 .751 .917 r
.38789 .60722 .39645 .61518 .41073 .61079 .40221 .60275 Mtetra
.659 .749 .917 r
.40221 .60275 .41073 .61079 .42508 .60635 .41661 .59832 Mtetra
.649 .748 .921 r
.41661 .59832 .42508 .60635 .4395 .60199 .43108 .5942 Mtetra
.649 .755 .927 r
.43108 .5942 .4395 .60199 .454 .5979 .44562 .59004 Mtetra
.658 .757 .923 r
.44562 .59004 .454 .5979 .46858 .59374 .46026 .58556 Mtetra
.662 .751 .917 r
.46026 .58556 .46858 .59374 .48323 .5893 .47497 .58094 Mtetra
.662 .748 .914 r
.47497 .58094 .48323 .5893 .49797 .58474 .48976 .57627 Mtetra
.656 .744 .915 r
.48976 .57627 .49797 .58474 .51279 .5801 .50462 .57181 Mtetra
.648 .747 .922 r
.50462 .57181 .51279 .5801 .52769 .57553 .51957 .56762 Mtetra
.647 .758 .93 r
.51957 .56762 .52769 .57553 .54266 .57116 .5346 .56338 Mtetra
.653 .764 .931 r
.5346 .56338 .54266 .57116 .55772 .56687 .54972 .5589 Mtetra
.656 .761 .927 r
.54972 .5589 .55772 .56687 .57287 .56252 .56492 .55431 Mtetra
.656 .756 .924 r
.56492 .55431 .57287 .56252 .5881 .55809 .5802 .5497 Mtetra
.656 .753 .921 r
.5802 .5497 .5881 .55809 .60341 .55357 .59557 .54507 Mtetra
.656 .751 .92 r
.59557 .54507 .60341 .55357 .6188 .54898 .61102 .54043 Mtetra
.655 .751 .92 r
.61102 .54043 .6188 .54898 .63428 .54431 .62656 .53578 Mtetra
.655 .753 .922 r
.62656 .53578 .63428 .54431 .64984 .53955 .64218 .53111 Mtetra
.655 .756 .924 r
.64218 .53111 .64984 .53955 .66549 .53472 .6579 .52642 Mtetra
.657 .761 .927 r
.6579 .52642 .66549 .53472 .68122 .52982 .67369 .52161 Mtetra
.662 .767 .928 r
.67369 .52161 .68122 .52982 .69704 .52499 .68957 .51657 Mtetra
.663 .763 .924 r
.68957 .51657 .69704 .52499 .71296 .52037 .70553 .51146 Mtetra
.656 .75 .919 r
.70553 .51146 .71296 .52037 .72897 .51582 .7216 .50663 Mtetra
.65 .742 .917 r
.7216 .50663 .72897 .51582 .74508 .51118 .73777 .50201 Mtetra
.651 .744 .918 r
.73777 .50201 .74508 .51118 .76127 .50642 .75403 .49734 Mtetra
.654 .749 .919 r
.75403 .49734 .76127 .50642 .77754 .50137 .77038 .49252 Mtetra
.661 .758 .922 r
.77038 .49252 .77754 .50137 .79389 .49623 .7868 .48737 Mtetra
.661 .759 .923 r
.7868 .48737 .79389 .49623 .81036 .49138 .80332 .48217 Mtetra
.653 .749 .92 r
.80332 .48217 .81036 .49138 .82693 .48661 .81995 .47728 Mtetra
.652 .747 .919 r
.81995 .47728 .82693 .48661 .8436 .48178 .83669 .47244 Mtetra
.653 .748 .919 r
.83669 .47244 .8436 .48178 .86034 .47669 .85352 .4675 Mtetra
.66 .756 .921 r
.85352 .4675 .86034 .47669 .87716 .47146 .87042 .46222 Mtetra
.658 .755 .921 r
.87042 .46222 .87716 .47146 .89411 .46644 .88742 .457 Mtetra
.654 .75 .92 r
.88742 .457 .89411 .46644 .91117 .46148 .90454 .45194 Mtetra
.652 .748 .92 r
.90454 .45194 .91117 .46148 .92832 .45647 .92178 .44692 Mtetra
.66 .751 .918 r
.30855 .62059 .31742 .62841 .33138 .62407 .32255 .61624 Mtetra
.656 .75 .919 r
.32255 .61624 .33138 .62407 .3454 .61979 .33661 .61197 Mtetra
.65 .75 .923 r
.33661 .61197 .3454 .61979 .35948 .61567 .35074 .60791 Mtetra
.655 .754 .923 r
.35074 .60791 .35948 .61567 .37364 .6116 .36495 .60364 Mtetra
.66 .751 .918 r
.36495 .60364 .37364 .6116 .38789 .60722 .37925 .59915 Mtetra
.66 .75 .917 r
.37925 .59915 .38789 .60722 .40221 .60275 .39362 .59466 Mtetra
.652 .748 .92 r
.39362 .59466 .40221 .60275 .41661 .59832 .40806 .59043 Mtetra
.647 .753 .926 r
.40806 .59043 .41661 .59832 .43108 .5942 .42257 .58632 Mtetra
.657 .757 .923 r
.42257 .58632 .43108 .5942 .44562 .59004 .43717 .58184 Mtetra
.662 .751 .917 r
.43717 .58184 .44562 .59004 .46026 .58556 .45186 .57718 Mtetra
.663 .748 .914 r
.45186 .57718 .46026 .58556 .47497 .58094 .46662 .57247 Mtetra
.653 .744 .917 r
.46662 .57247 .47497 .58094 .48976 .57627 .48146 .5681 Mtetra
.645 .751 .926 r
.48146 .5681 .48976 .57627 .50462 .57181 .49637 .56397 Mtetra
.65 .761 .931 r
.49637 .56397 .50462 .57181 .51957 .56762 .51138 .5596 Mtetra
.656 .76 .926 r
.51138 .5596 .51957 .56762 .5346 .56338 .52646 .55499 Mtetra
.657 .752 .92 r
.52646 .55499 .5346 .56338 .54972 .5589 .54163 .55036 Mtetra
.66 .751 .917 r
.54163 .55036 .54972 .5589 .56492 .55431 .55688 .54559 Mtetra
.658 .747 .915 r
.55688 .54559 .56492 .55431 .5802 .5497 .57222 .54086 Mtetra
.657 .745 .915 r
.57222 .54086 .5802 .5497 .59557 .54507 .58764 .53619 Mtetra
.656 .744 .915 r
.58764 .53619 .59557 .54507 .61102 .54043 .60315 .5315 Mtetra
.60315 .5315 .61102 .54043 .62656 .53578 .61874 .5268 Mtetra
.654 .744 .916 r
.61874 .5268 .62656 .53578 .64218 .53111 .63443 .52215 Mtetra
.652 .745 .918 r
.63443 .52215 .64218 .53111 .6579 .52642 .65021 .51754 Mtetra
.655 .749 .919 r
.65021 .51754 .6579 .52642 .67369 .52161 .66607 .51279 Mtetra
.654 .751 .921 r
.66607 .51279 .67369 .52161 .68957 .51657 .68202 .50802 Mtetra
.659 .761 .925 r
.68202 .50802 .68957 .51657 .70553 .51146 .69805 .50301 Mtetra
.665 .766 .926 r
.69805 .50301 .70553 .51146 .7216 .50663 .71416 .49775 Mtetra
.659 .755 .921 r
.71416 .49775 .7216 .50663 .73777 .50201 .73038 .49272 Mtetra
.65 .743 .918 r
.73038 .49272 .73777 .50201 .75403 .49734 .74671 .48805 Mtetra
.65 .744 .918 r
.74671 .48805 .75403 .49734 .77038 .49252 .76313 .48332 Mtetra
.654 .749 .92 r
.76313 .48332 .77038 .49252 .7868 .48737 .77964 .47839 Mtetra
.663 .759 .922 r
.77964 .47839 .7868 .48737 .80332 .48217 .79622 .47309 Mtetra
.659 .757 .922 r
.79622 .47309 .80332 .48217 .81995 .47728 .8129 .4679 Mtetra
.652 .748 .92 r
.8129 .4679 .81995 .47728 .83669 .47244 .82971 .46298 Mtetra
.652 .747 .92 r
.82971 .46298 .83669 .47244 .85352 .4675 .84661 .45805 Mtetra
.656 .751 .919 r
.84661 .45805 .85352 .4675 .87042 .46222 .8636 .45289 Mtetra
.661 .757 .921 r
.8636 .45289 .87042 .46222 .88742 .457 .88066 .4475 Mtetra
.655 .752 .921 r
.88066 .4475 .88742 .457 .90454 .45194 .89785 .44232 Mtetra
.653 .749 .92 r
.89785 .44232 .90454 .45194 .92178 .44692 .91515 .43722 Mtetra
.658 .75 .918 r
.29959 .6127 .30855 .62059 .32255 .61624 .31363 .60834 Mtetra
.653 .75 .921 r
.31363 .60834 .32255 .61624 .33661 .61197 .32773 .60416 Mtetra
.65 .752 .924 r
.32773 .60416 .33661 .61197 .35074 .60791 .3419 .60003 Mtetra
.659 .754 .92 r
.3419 .60003 .35074 .60791 .36495 .60364 .35617 .59557 Mtetra
.661 .751 .917 r
.35617 .59557 .36495 .60364 .37925 .59915 .37052 .59102 Mtetra
.657 .749 .918 r
.37052 .59102 .37925 .59915 .39362 .59466 .38493 .58661 Mtetra
.647 .75 .924 r
.38493 .58661 .39362 .59466 .40806 .59043 .39941 .5825 Mtetra
.654 .756 .925 r
.39941 .5825 .40806 .59043 .42257 .58632 .41398 .57813 Mtetra
.661 .752 .918 r
.41398 .57813 .42257 .58632 .43717 .58184 .42864 .57347 Mtetra
.664 .75 .914 r
.42864 .57347 .43717 .58184 .45186 .57718 .44337 .56869 Mtetra
.653 .745 .917 r
.44337 .56869 .45186 .57718 .46662 .57247 .45818 .56429 Mtetra
.643 .751 .927 r
.45818 .56429 .46662 .57247 .48146 .5681 .47306 .56019 Mtetra
.652 .761 .929 r
.47306 .56019 .48146 .5681 .49637 .56397 .48804 .55573 Mtetra
.657 .756 .922 r
.48804 .55573 .49637 .56397 .51138 .5596 .5031 .55108 Mtetra
.662 .751 .917 r
.5031 .55108 .51138 .5596 .52646 .55499 .51824 .54625 Mtetra
.656 .745 .916 r
.51824 .54625 .52646 .55499 .54163 .55036 .53346 .54163 Mtetra
.644 .743 .921 r
.53346 .54163 .54163 .55036 .55688 .54559 .54877 .53741 Mtetra
.631 .753 .936 r
.54877 .53741 .55688 .54559 .57222 .54086 .56418 .53356 Mtetra
.633 .778 .951 r
.56418 .53356 .57222 .54086 .58764 .53619 .57967 .52946 Mtetra
.648 .8 .956 r
.57967 .52946 .58764 .53619 .60315 .5315 .59525 .52473 Mtetra
.667 .806 .95 r
.59525 .52473 .60315 .5315 .61874 .5268 .61089 .51936 Mtetra
.675 .791 .936 r
.61089 .51936 .61874 .5268 .63443 .52215 .62662 .51373 Mtetra
.667 .765 .924 r
.62662 .51373 .63443 .52215 .65021 .51754 .64243 .50847 Mtetra
.656 .747 .917 r
.64243 .50847 .65021 .51754 .66607 .51279 .65835 .50361 Mtetra
.65 .743 .918 r
.65835 .50361 .66607 .51279 .68202 .50802 .67437 .49897 Mtetra
.654 .749 .919 r
.67437 .49897 .68202 .50802 .69805 .50301 .69048 .49414 Mtetra
.658 .756 .922 r
.69048 .49414 .69805 .50301 .71416 .49775 .70667 .48911 Mtetra
.666 .766 .924 r
.70667 .48911 .71416 .49775 .73038 .49272 .72293 .48371 Mtetra
.658 .755 .922 r
.72293 .48371 .73038 .49272 .74671 .48805 .73931 .47863 Mtetra
.648 .743 .918 r
.73931 .47863 .74671 .48805 .76313 .48332 .7558 .47392 Mtetra
.651 .746 .919 r
.7558 .47392 .76313 .48332 .77964 .47839 .77239 .46908 Mtetra
.657 .751 .919 r
.77239 .46908 .77964 .47839 .79622 .47309 .78905 .46395 Mtetra
.663 .759 .921 r
.78905 .46395 .79622 .47309 .8129 .4679 .80579 .45853 Mtetra
.655 .752 .921 r
.80579 .45853 .8129 .4679 .82971 .46298 .82265 .45343 Mtetra
.651 .747 .92 r
.82265 .45343 .82971 .46298 .84661 .45805 .83963 .44846 Mtetra
.653 .748 .92 r
.83963 .44846 .84661 .45805 .8636 .45289 .8567 .4434 Mtetra
.66 .755 .92 r
.8567 .4434 .8636 .45289 .88066 .4475 .87384 .43798 Mtetra
.658 .755 .921 r
.87384 .43798 .88066 .4475 .89785 .44232 .89109 .43262 Mtetra
.654 .75 .92 r
.89109 .43262 .89785 .44232 .91515 .43722 .90846 .42743 Mtetra
.657 .751 .919 r
.29054 .60476 .29959 .6127 .31363 .60834 .30462 .6004 Mtetra
.65 .75 .923 r
.30462 .6004 .31363 .60834 .32773 .60416 .31876 .59627 Mtetra
.654 .753 .923 r
.31876 .59627 .32773 .60416 .3419 .60003 .33299 .59196 Mtetra
.661 .752 .918 r
.33299 .59196 .3419 .60003 .35617 .59557 .3473 .58741 Mtetra
.66 .75 .917 r
.3473 .58741 .35617 .59557 .37052 .59102 .3617 .58284 Mtetra
.65 .749 .921 r
.3617 .58284 .37052 .59102 .38493 .58661 .37615 .57861 Mtetra
.649 .753 .926 r
.37615 .57861 .38493 .58661 .39941 .5825 .39068 .57439 Mtetra
.659 .754 .92 r
.39068 .57439 .39941 .5825 .41398 .57813 .40531 .56978 Mtetra
.664 .751 .915 r
.40531 .56978 .41398 .57813 .42864 .57347 .42002 .56496 Mtetra
.658 .747 .915 r
.42002 .56496 .42864 .57347 .44337 .56869 .4348 .56036 Mtetra
.643 .748 .925 r
.4348 .56036 .44337 .56869 .45818 .56429 .44965 .55628 Mtetra
.651 .759 .929 r
.44965 .55628 .45818 .56429 .47306 .56019 .46459 .55185 Mtetra
.658 .754 .921 r
.46459 .55185 .47306 .56019 .48804 .55573 .47962 .54717 Mtetra
.663 .752 .916 r
.47962 .54717 .48804 .55573 .5031 .55108 .49473 .54228 Mtetra
.642 .741 .92 r
.49473 .54228 .5031 .55108 .51824 .54625 .50993 .53813 Mtetra
.588 .74 .948 r
.50993 .53813 .51824 .54625 .53346 .54163 .52521 .53558 Mtetra
.54 .782 .987 r
.52521 .53558 .53346 .54163 .54877 .53741 .54059 .53339 Mtetra
.504 .828 1 r
.54059 .53339 .54877 .53741 .56418 .53356 .55609 .53071 Mtetra
.509 .862 .99 r
.55609 .53071 .56418 .53356 .57967 .52946 .57167 .5271 Mtetra
.553 .892 .983 r
.57167 .5271 .57967 .52946 .59525 .52473 .58734 .52232 Mtetra
.614 .914 .98 r
.58734 .52232 .59525 .52473 .61089 .51936 .60306 .51639 Mtetra
.669 .917 .976 r
.60306 .51639 .61089 .51936 .62662 .51373 .61884 .5095 Mtetra
.706 .892 .965 r
.61884 .5095 .62662 .51373 .64243 .50847 .63467 .5021 Mtetra
.707 .834 .943 r
.63467 .5021 .64243 .50847 .65835 .50361 .65059 .49506 Mtetra
.668 .767 .924 r
.65059 .49506 .65835 .50361 .67437 .49897 .66664 .48962 Mtetra
.649 .743 .918 r
.66664 .48962 .67437 .49897 .69048 .49414 .68282 .48494 Mtetra
.654 .749 .92 r
.68282 .48494 .69048 .49414 .70667 .48911 .69908 .48004 Mtetra
.66 .755 .921 r
.69908 .48004 .70667 .48911 .72293 .48371 .71542 .47488 Mtetra
.667 .765 .923 r
.71542 .47488 .72293 .48371 .73931 .47863 .73184 .46936 Mtetra
.654 .751 .921 r
.73184 .46936 .73931 .47863 .7558 .47392 .74839 .46436 Mtetra
.648 .743 .919 r
.74839 .46436 .7558 .47392 .77239 .46908 .76505 .45959 Mtetra
.653 .748 .919 r
.76505 .45959 .77239 .46908 .78905 .46395 .78179 .4546 Mtetra
.662 .756 .92 r
.78179 .4546 .78905 .46395 .80579 .45853 .79861 .4492 Mtetra
.661 .757 .922 r
.79861 .4492 .80579 .45853 .82265 .45343 .81552 .44382 Mtetra
.652 .748 .92 r
.81552 .44382 .82265 .45343 .83963 .44846 .83257 .43876 Mtetra
.651 .748 .92 r
.83257 .43876 .83963 .44846 .8567 .4434 .84971 .4337 Mtetra
.657 .751 .919 r
.84971 .4337 .8567 .4434 .87384 .43798 .86694 .42836 Mtetra
.661 .756 .92 r
.86694 .42836 .87384 .43798 .89109 .43262 .88425 .42284 Mtetra
.655 .751 .921 r
.88425 .42284 .89109 .43262 .90846 .42743 .9017 .41754 Mtetra
.655 .751 .92 r
.2814 .59675 .29054 .60476 .30462 .6004 .29552 .59242 Mtetra
.649 .751 .924 r
.29552 .59242 .30462 .6004 .31876 .59627 .3097 .58827 Mtetra
.658 .754 .921 r
.3097 .58827 .31876 .59627 .33299 .59196 .32399 .5838 Mtetra
.661 .751 .917 r
.32399 .5838 .33299 .59196 .3473 .58741 .33835 .57918 Mtetra
.658 .75 .918 r
.33835 .57918 .3473 .58741 .3617 .58284 .35279 .57466 Mtetra
.646 .749 .924 r
.35279 .57466 .3617 .58284 .37615 .57861 .36728 .57051 Mtetra
.654 .755 .923 r
.36728 .57051 .37615 .57861 .39068 .57439 .38187 .56606 Mtetra
.663 .752 .917 r
.38187 .56606 .39068 .57439 .40531 .56978 .39655 .56129 Mtetra
.664 .75 .914 r
.39655 .56129 .40531 .56978 .42002 .56496 .41131 .55645 Mtetra
.646 .745 .922 r
.41131 .55645 .42002 .56496 .4348 .56036 .42613 .55224 Mtetra
.646 .756 .929 r
.42613 .55224 .4348 .56036 .44965 .55628 .44104 .54797 Mtetra
.658 .756 .922 r
.44104 .54797 .44965 .55628 .46459 .55185 .45604 .54327 Mtetra
.663 .752 .916 r
.45604 .54327 .46459 .55185 .47962 .54717 .47112 .53834 Mtetra
.634 .738 .923 r
.47112 .53834 .47962 .54717 .49473 .54228 .48628 .53448 Mtetra
.531 .728 .964 r
.48628 .53448 .49473 .54228 .50993 .53813 .5015 .5332 Mtetra
.412 .76 .995 r
.5015 .5332 .50993 .53813 .52521 .53558 .51685 .53257 Mtetra
.277 .739 .95 r
.51685 .53257 .52521 .53558 .54059 .53339 .53231 .53224 Mtetra
.26 .76 .89 r
.53231 .53224 .54059 .53339 .55609 .53071 .5479 .53045 Mtetra
.325 .808 .875 r
.5479 .53045 .55609 .53071 .57167 .5271 .56359 .52703 Mtetra
.416 .862 .893 r
.56359 .52703 .57167 .5271 .58734 .52232 .57935 .52222 Mtetra
.514 .911 .912 r
.57935 .52222 .58734 .52232 .60306 .51639 .59517 .516 Mtetra
.62 .951 .928 r
.59517 .516 .60306 .51639 .61884 .5095 .61103 .50815 Mtetra
.718 .964 .94 r
.61103 .50815 .61884 .5095 .63467 .5021 .62691 .4988 Mtetra
.743 .927 .951 r
.62691 .4988 .63467 .5021 .65059 .49506 .64285 .48972 Mtetra
.738 .873 .943 r
.64285 .48972 .65059 .49506 .66664 .48962 .65887 .48128 Mtetra
.676 .778 .927 r
.65887 .48128 .66664 .48962 .68282 .48494 .67506 .47546 Mtetra
.649 .743 .918 r
.67506 .47546 .68282 .48494 .69908 .48004 .6914 .4707 Mtetra
.654 .749 .92 r
.6914 .4707 .69908 .48004 .71542 .47488 .70782 .46572 Mtetra
.664 .758 .92 r
.70782 .46572 .71542 .47488 .73184 .46936 .72432 .46029 Mtetra
.665 .762 .923 r
.72432 .46029 .73184 .46936 .74839 .46436 .7409 .45479 Mtetra
.649 .745 .92 r
.7409 .45479 .74839 .46436 .76505 .45959 .75762 .44994 Mtetra
.65 .745 .919 r
.75762 .44994 .76505 .45959 .78179 .4546 .77445 .44502 Mtetra
.657 .751 .919 r
.77445 .44502 .78179 .4546 .79861 .4492 .79135 .43976 Mtetra
.664 .758 .92 r
.79135 .43976 .79861 .4492 .81552 .44382 .80832 .43417 Mtetra
.654 .751 .921 r
.80832 .43417 .81552 .44382 .83257 .43876 .82543 .42897 Mtetra
.651 .747 .92 r
.82543 .42897 .83257 .43876 .84971 .4337 .84265 .42387 Mtetra
.654 .749 .92 r
.84265 .42387 .84971 .4337 .86694 .42836 .85997 .4186 Mtetra
.661 .755 .92 r
.85997 .4186 .86694 .42836 .88425 .42284 .87735 .413 Mtetra
.656 .753 .921 r
.87735 .413 .88425 .42284 .9017 .41754 .89486 .40757 Mtetra
.653 .75 .921 r
.27216 .58868 .2814 .59675 .29552 .59242 .28633 .58438 Mtetra
.65 .752 .924 r
.28633 .58438 .29552 .59242 .3097 .58827 .30056 .58014 Mtetra
.66 .753 .919 r
.30056 .58014 .3097 .58827 .32399 .5838 .31489 .57555 Mtetra
.661 .751 .917 r
.31489 .57555 .32399 .5838 .33835 .57918 .32931 .57089 Mtetra
.653 .749 .92 r
.32931 .57089 .33835 .57918 .35279 .57466 .34378 .56649 Mtetra
.647 .752 .926 r
.34378 .56649 .35279 .57466 .36728 .57051 .35833 .56227 Mtetra
.659 .754 .921 r
.35833 .56227 .36728 .57051 .38187 .56606 .37297 .55761 Mtetra
.665 .752 .915 r
.37297 .55761 .38187 .56606 .39655 .56129 .3877 .55271 Mtetra
.657 .748 .917 r
.3877 .55271 .39655 .56129 .41131 .55645 .40251 .54809 Mtetra
.64 .75 .928 r
.40251 .54809 .41131 .55645 .42613 .55224 .41737 .544 Mtetra
.655 .758 .925 r
.41737 .544 .42613 .55224 .44104 .54797 .43234 .53937 Mtetra
.663 .752 .917 r
.43234 .53937 .44104 .54797 .45604 .54327 .4474 .53444 Mtetra
.644 .742 .921 r
.4474 .53444 .45604 .54327 .47112 .53834 .46252 .5302 Mtetra
.522 .717 .961 r
.46252 .5302 .47112 .53834 .48628 .53448 .47769 .52921 Mtetra
.326 .708 .982 r
.47769 .52921 .48628 .53448 .5015 .5332 .49296 .52997 Mtetra
.155 .657 .909 r
.49296 .52997 .5015 .5332 .51685 .53257 .50836 .53118 Mtetra
.232 .739 .888 r
.50836 .53118 .51685 .53257 .53231 .53224 .52391 .52992 Mtetra
.527 .883 .982 r
.52391 .52992 .53231 .53224 .5479 .53045 .53957 .52553 Mtetra
.639 .855 .982 r
.53957 .52553 .5479 .53045 .56359 .52703 .55531 .52034 Mtetra
.645 .808 .961 r
.55531 .52034 .56359 .52703 .57935 .52222 .57114 .51548 Mtetra
.633 .804 .965 r
.57114 .51548 .57935 .52222 .59517 .516 .58708 .51095 Mtetra
.641 .856 .981 r
.58708 .51095 .59517 .516 .61103 .50815 .60308 .50562 Mtetra
.711 .94 .959 r
.60308 .50562 .61103 .50815 .62691 .4988 .61909 .49712 Mtetra
.773 .967 .925 r
.61909 .49712 .62691 .4988 .64285 .48972 .63508 .4861 Mtetra
.781 .925 .931 r
.63508 .4861 .64285 .48972 .65887 .48128 .65111 .4755 Mtetra
.746 .866 .935 r
.65111 .4755 .65887 .48128 .67506 .47546 .66726 .46666 Mtetra
.667 .768 .925 r
.66726 .46666 .67506 .47546 .6914 .4707 .68363 .4611 Mtetra
.649 .744 .918 r
.68363 .4611 .6914 .4707 .70782 .46572 .70012 .45625 Mtetra
.656 .75 .919 r
.70012 .45625 .70782 .46572 .72432 .46029 .7167 .45109 Mtetra
.669 .763 .921 r
.7167 .45109 .72432 .46029 .7409 .45479 .73335 .44537 Mtetra
.655 .754 .922 r
.73335 .44537 .7409 .45479 .75762 .44994 .75012 .44019 Mtetra
.647 .744 .92 r
.75012 .44019 .75762 .44994 .77445 .44502 .76702 .43529 Mtetra
.653 .749 .92 r
.76702 .43529 .77445 .44502 .79135 .43976 .784 .43014 Mtetra
.663 .757 .919 r
.784 .43014 .79135 .43976 .80832 .43417 .80105 .42452 Mtetra
.658 .755 .921 r
.80105 .42452 .80832 .43417 .82543 .42897 .81821 .4191 Mtetra
.651 .748 .921 r
.81821 .4191 .82543 .42897 .84265 .42387 .83551 .41394 Mtetra
.652 .749 .92 r
.83551 .41394 .84265 .42387 .85997 .4186 .85291 .40869 Mtetra
.66 .754 .919 r
.85291 .40869 .85997 .4186 .87735 .413 .87037 .40307 Mtetra
.658 .754 .921 r
.87037 .40307 .87735 .413 .89486 .40757 .88795 .3975 Mtetra
.651 .75 .922 r
.26284 .58053 .27216 .58868 .28633 .58438 .27704 .57625 Mtetra
.653 .752 .923 r
.27704 .57625 .28633 .58438 .30056 .58014 .29133 .5719 Mtetra
.661 .752 .918 r
.29133 .5719 .30056 .58014 .31489 .57555 .30571 .56723 Mtetra
.661 .751 .917 r
.30571 .56723 .31489 .57555 .32931 .57089 .32017 .56254 Mtetra
.65 .749 .922 r
.32017 .56254 .32931 .57089 .34378 .56649 .33468 .55822 Mtetra
.65 .752 .924 r
.33468 .55822 .34378 .56649 .35833 .56227 .34928 .55386 Mtetra
.661 .753 .918 r
.34928 .55386 .35833 .56227 .37297 .55761 .36398 .54908 Mtetra
.665 .752 .915 r
.36398 .54908 .37297 .55761 .3877 .55271 .37877 .54411 Mtetra
.648 .747 .921 r
.37877 .54411 .3877 .55271 .40251 .54809 .39361 .53974 Mtetra
.644 .753 .928 r
.39361 .53974 .40251 .54809 .41737 .544 .40853 .53547 Mtetra
.658 .754 .92 r
.40853 .53547 .41737 .544 .43234 .53937 .42355 .53068 Mtetra
.661 .752 .917 r
.42355 .53068 .43234 .53937 .4474 .53444 .43866 .52576 Mtetra
.575 .725 .944 r
.43866 .52576 .4474 .53444 .46252 .5302 .45379 .52359 Mtetra
.372 .693 .982 r
.45379 .52359 .46252 .5302 .47769 .52921 .46898 .52453 Mtetra
.133 .609 .92 r
.46898 .52453 .47769 .52921 .49296 .52997 .48429 .52714 Mtetra
.306 .761 .954 r
.48429 .52714 .49296 .52997 .50836 .53118 .49978 .52623 Mtetra
.669 .86 .972 r
.49978 .52623 .50836 .53118 .52391 .52992 .51541 .52026 Mtetra
.731 .758 .874 r
.51541 .52026 .52391 .52992 .53957 .52553 .53111 .51173 Mtetra
.707 .681 .822 r
.53111 .51173 .53957 .52553 .55531 .52034 .54687 .50335 Mtetra
.642 .614 .806 r
.54687 .50335 .55531 .52034 .57114 .51548 .56272 .49842 Mtetra
.58 .583 .82 r
.56272 .49842 .57114 .51548 .58708 .51095 .57873 .49698 Mtetra
.571 .622 .864 r
.57873 .49698 .58708 .51095 .60308 .50562 .59486 .49569 Mtetra
.625 .725 .918 r
.59486 .49569 .60308 .50562 .61909 .49712 .61106 .49185 Mtetra
.748 .878 .939 r
.61106 .49185 .61909 .49712 .63508 .4861 .6272 .48288 Mtetra
.819 .936 .907 r
.6272 .48288 .63508 .4861 .65111 .4755 .64328 .47032 Mtetra
.788 .888 .917 r
.64328 .47032 .65111 .4755 .66726 .46666 .65944 .45941 Mtetra
.719 .825 .931 r
.65944 .45941 .66726 .46666 .68363 .4611 .67578 .45165 Mtetra
.651 .75 .922 r
.67578 .45165 .68363 .4611 .70012 .45625 .69234 .44668 Mtetra
.653 .75 .92 r
.69234 .44668 .70012 .45625 .7167 .45109 .709 .44157 Mtetra
.666 .756 .918 r
.709 .44157 .7167 .45109 .73335 .44537 .72572 .43594 Mtetra
.663 .759 .922 r
.72572 .43594 .73335 .44537 .75012 .44019 .74254 .43039 Mtetra
.647 .746 .921 r
.74254 .43039 .75012 .44019 .76702 .43529 .75951 .42546 Mtetra
.651 .748 .92 r
.75951 .42546 .76702 .43529 .784 .43014 .77657 .42033 Mtetra
.661 .753 .919 r
.77657 .42033 .784 .43014 .80105 .42452 .7937 .41476 Mtetra
.661 .756 .92 r
.7937 .41476 .80105 .42452 .81821 .4191 .81092 .40914 Mtetra
.651 .749 .921 r
.81092 .40914 .81821 .4191 .83551 .41394 .82829 .4039 Mtetra
.651 .748 .921 r
.82829 .4039 .83551 .41394 .85291 .40869 .84576 .39862 Mtetra
.659 .752 .919 r
.84576 .39862 .85291 .40869 .87037 .40307 .86331 .39302 Mtetra
.66 .754 .92 r
.86331 .39302 .87037 .40307 .88795 .3975 .88096 .38732 Mtetra
.65 .75 .923 r
.25342 .57231 .26284 .58053 .27704 .57625 .26766 .56803 Mtetra
.654 .752 .922 r
.26766 .56803 .27704 .57625 .29133 .5719 .282 .56357 Mtetra
.661 .752 .918 r
.282 .56357 .29133 .5719 .30571 .56723 .29643 .55883 Mtetra
.66 .751 .918 r
.29643 .55883 .30571 .56723 .32017 .56254 .31094 .55413 Mtetra
.647 .749 .924 r
.31094 .55413 .32017 .56254 .33468 .55822 .3255 .54985 Mtetra
.653 .752 .923 r
.3255 .54985 .33468 .55822 .34928 .55386 .34015 .54534 Mtetra
.663 .753 .917 r
.34015 .54534 .34928 .55386 .36398 .54908 .3549 .54044 Mtetra
.664 .751 .915 r
.3549 .54044 .36398 .54908 .37877 .54411 .36974 .53547 Mtetra
.642 .746 .925 r
.36974 .53547 .37877 .54411 .39361 .53974 .38462 .53127 Mtetra
.65 .754 .925 r
.38462 .53127 .39361 .53974 .40853 .53547 .3996 .52675 Mtetra
.662 .753 .917 r
.3996 .52675 .40853 .53547 .42355 .53068 .41468 .52179 Mtetra
.645 .744 .922 r
.41468 .52179 .42355 .53068 .43866 .52576 .42982 .51742 Mtetra
.481 .697 .964 r
.42982 .51742 .43866 .52576 .45379 .52359 .44495 .51729 Mtetra
.216 .618 .952 r
.44495 .51729 .45379 .52359 .46898 .52453 .46016 .52009 Mtetra
.192 .655 .94 r
.46016 .52009 .46898 .52453 .48429 .52714 .47554 .52177 Mtetra
.661 .847 .972 r
.47554 .52177 .48429 .52714 .49978 .52623 .49113 .51615 Mtetra
.779 .76 .836 r
.49113 .51615 .49978 .52623 .51541 .52026 .50685 .5041 Mtetra
.761 .673 .765 r
.50685 .5041 .51541 .52026 .53111 .51173 .52259 .48958 Mtetra
.698 .597 .739 r
.52259 .48958 .53111 .51173 .54687 .50335 .53835 .47849 Mtetra
.625 .54 .739 r
.53835 .47849 .54687 .50335 .56272 .49842 .55418 .47349 Mtetra
.541 .492 .75 r
.55418 .47349 .56272 .49842 .57873 .49698 .5702 .47461 Mtetra
.471 .47 .775 r
.5702 .47461 .57873 .49698 .59486 .49569 .58643 .47922 Mtetra
.493 .547 .84 r
.58643 .47922 .59486 .49569 .61106 .49185 .6028 .48139 Mtetra
.636 .721 .909 r
.6028 .48139 .61106 .49185 .6272 .48288 .61915 .47709 Mtetra
.8 .873 .901 r
.61915 .47709 .6272 .48288 .64328 .47032 .63535 .46537 Mtetra
.822 .896 .894 r
.63535 .46537 .64328 .47032 .65944 .45941 .65154 .45248 Mtetra
.765 .844 .911 r
.65154 .45248 .65944 .45941 .67578 .45165 .66788 .44253 Mtetra
.666 .766 .925 r
.66788 .44253 .67578 .45165 .69234 .44668 .68447 .43689 Mtetra
.65 .746 .919 r
.68447 .43689 .69234 .44668 .709 .44157 .7012 .43186 Mtetra
.661 .753 .918 r
.7012 .43186 .709 .44157 .72572 .43594 .718 .42637 Mtetra
.668 .76 .919 r
.718 .42637 .72572 .43594 .74254 .43039 .73488 .42054 Mtetra
.648 .747 .922 r
.73488 .42054 .74254 .43039 .75951 .42546 .75192 .4155 Mtetra
.649 .747 .921 r
.75192 .4155 .75951 .42546 .77657 .42033 .76905 .41038 Mtetra
.658 .752 .919 r
.76905 .41038 .77657 .42033 .7937 .41476 .78626 .40486 Mtetra
.663 .756 .919 r
.78626 .40486 .7937 .41476 .81092 .40914 .80355 .39909 Mtetra
.652 .75 .921 r
.80355 .39909 .81092 .40914 .82829 .4039 .82099 .39376 Mtetra
.651 .748 .921 r
.82099 .39376 .82829 .4039 .84576 .39862 .83854 .38844 Mtetra
.657 .751 .92 r
.83854 .38844 .84576 .39862 .86331 .39302 .85618 .38284 Mtetra
.661 .755 .919 r
.85618 .38284 .86331 .39302 .88096 .38732 .8739 .37704 Mtetra
.649 .75 .923 r
.2439 .56401 .25342 .57231 .26766 .56803 .25819 .5597 Mtetra
.656 .752 .921 r
.25819 .5597 .26766 .56803 .282 .56357 .27258 .55515 Mtetra
.661 .752 .918 r
.27258 .55515 .282 .56357 .29643 .55883 .28706 .55037 Mtetra
.659 .752 .919 r
.28706 .55037 .29643 .55883 .31094 .55413 .30161 .54565 Mtetra
.646 .749 .924 r
.30161 .54565 .31094 .55413 .3255 .54985 .31621 .54136 Mtetra
.655 .752 .922 r
.31621 .54136 .3255 .54985 .34015 .54534 .33092 .53673 Mtetra
.664 .753 .917 r
.33092 .53673 .34015 .54534 .3549 .54044 .34573 .53174 Mtetra
.661 .751 .917 r
.34573 .53174 .3549 .54044 .36974 .53547 .36061 .52683 Mtetra
.64 .748 .927 r
.36061 .52683 .36974 .53547 .38462 .53127 .37554 .52266 Mtetra
.654 .754 .923 r
.37554 .52266 .38462 .53127 .3996 .52675 .39057 .51796 Mtetra
.664 .753 .917 r
.39057 .51796 .3996 .52675 .41468 .52179 .40571 .51287 Mtetra
.617 .737 .932 r
.40571 .51287 .41468 .52179 .42982 .51742 .42088 .50938 Mtetra
.406 .673 .97 r
.42088 .50938 .42982 .51742 .44495 .51729 .43602 .51044 Mtetra
.172 .578 .937 r
.43602 .51044 .44495 .51729 .46016 .52009 .45125 .51413 Mtetra
.454 .757 .994 r
.45125 .51413 .46016 .52009 .47554 .52177 .46672 .51321 Mtetra
.757 .787 .877 r
.46672 .51321 .47554 .52177 .49113 .51615 .48244 .50344 Mtetra
.813 .727 .769 r
.48244 .50344 .49113 .51615 .50685 .5041 .49826 .48538 Mtetra
.772 .656 .734 r
.49826 .48538 .50685 .5041 .52259 .48958 .51405 .46741 Mtetra
.714 .605 .734 r
.51405 .46741 .52259 .48958 .53835 .47849 .52981 .45454 Mtetra
.627 .547 .745 r
.52981 .45454 .53835 .47849 .55418 .47349 .54564 .44947 Mtetra
.51 .48 .759 r
.54564 .44947 .55418 .47349 .5702 .47461 .56165 .45224 Mtetra
.392 .423 .773 r
.56165 .45224 .5702 .47461 .58643 .47922 .57791 .46017 Mtetra
.349 .432 .806 r
.57791 .46017 .58643 .47922 .6028 .48139 .5944 .46827 Mtetra
.533 .625 .888 r
.5944 .46827 .6028 .48139 .61915 .47709 .6109 .46805 Mtetra
.742 .789 .891 r
.6109 .46805 .61915 .47709 .63535 .46537 .62727 .45887 Mtetra
.828 .859 .869 r
.62727 .45887 .63535 .46537 .65154 .45248 .64352 .44497 Mtetra
.784 .835 .891 r
.64352 .44497 .65154 .45248 .66788 .44253 .6599 .43371 Mtetra
.689 .783 .923 r
.6599 .43371 .66788 .44253 .68447 .43689 .67652 .42706 Mtetra
.648 .746 .921 r
.67652 .42706 .68447 .43689 .7012 .43186 .69332 .42205 Mtetra
.657 .751 .919 r
.69332 .42205 .7012 .43186 .718 .42637 .7102 .41663 Mtetra
.67 .759 .917 r
.7102 .41663 .718 .42637 .73488 .42054 .72715 .41067 Mtetra
.651 .75 .922 r
.72715 .41067 .73488 .42054 .75192 .4155 .74424 .40546 Mtetra
.648 .747 .921 r
.74424 .40546 .75192 .4155 .76905 .41038 .76145 .40033 Mtetra
.657 .751 .92 r
.76145 .40033 .76905 .41038 .78626 .40486 .77874 .39482 Mtetra
.664 .756 .918 r
.77874 .39482 .78626 .40486 .80355 .39909 .7961 .38895 Mtetra
.653 .75 .921 r
.7961 .38895 .80355 .39909 .82099 .39376 .81361 .38352 Mtetra
.651 .749 .921 r
.81361 .38352 .82099 .39376 .83854 .38844 .83124 .37815 Mtetra
.656 .751 .92 r
.83124 .37815 .83854 .38844 .85618 .38284 .84896 .37253 Mtetra
.661 .754 .919 r
.84896 .37253 .85618 .38284 .8739 .37704 .86675 .36664 Mtetra
.649 .75 .923 r
.23429 .55562 .2439 .56401 .25819 .5597 .24863 .55128 Mtetra
.656 .752 .92 r
.24863 .55128 .25819 .5597 .27258 .55515 .26306 .54666 Mtetra
.661 .753 .918 r
.26306 .54666 .27258 .55515 .28706 .55037 .27759 .54183 Mtetra
.658 .752 .919 r
.27759 .54183 .28706 .55037 .30161 .54565 .29219 .53709 Mtetra
.646 .749 .925 r
.29219 .53709 .30161 .54565 .31621 .54136 .30684 .53276 Mtetra
.656 .752 .921 r
.30684 .53276 .31621 .54136 .33092 .53673 .3216 .52805 Mtetra
.664 .753 .916 r
.3216 .52805 .33092 .53673 .34573 .53174 .33646 .52299 Mtetra
.659 .752 .918 r
.33646 .52299 .34573 .53174 .36061 .52683 .35138 .5181 Mtetra
.639 .748 .927 r
.35138 .5181 .36061 .52683 .37554 .52266 .36636 .51389 Mtetra
.656 .753 .921 r
.36636 .51389 .37554 .52266 .39057 .51796 .38146 .50908 Mtetra
.664 .753 .917 r
.38146 .50908 .39057 .51796 .40571 .51287 .39665 .50394 Mtetra
.596 .732 .939 r
.39665 .50394 .40571 .51287 .42088 .50938 .41184 .50103 Mtetra
.383 .656 .965 r
.41184 .50103 .42088 .50938 .43602 .51044 .42701 .50258 Mtetra
.206 .572 .94 r
.42701 .50258 .43602 .51044 .45125 .51413 .44227 .50649 Mtetra
.574 .761 .967 r
.44227 .50649 .45125 .51413 .46672 .51321 .45783 .50378 Mtetra
.794 .776 .836 r
.45783 .50378 .46672 .51321 .48244 .50344 .47366 .49079 Mtetra
.832 .732 .754 r
.47366 .49079 .48244 .50344 .49826 .48538 .48959 .47002 Mtetra
.806 .697 .745 r
.48959 .47002 .49826 .48538 .51405 .46741 .50546 .45025 Mtetra
.75 .661 .763 r
.50546 .45025 .51405 .46741 .52981 .45454 .52126 .43634 Mtetra
.64 .602 .795 r
.52126 .43634 .52981 .45454 .54564 .44947 .53711 .43121 Mtetra
.46 .506 .819 r
.53711 .43121 .54564 .44947 .56165 .45224 .55312 .43488 Mtetra
.259 .399 .814 r
.55312 .43488 .56165 .45224 .57791 .46017 .5694 .4445 Mtetra
.172 .372 .819 r
.5694 .4445 .57791 .46017 .5944 .46827 .58593 .45521 Mtetra
.428 .573 .896 r
.58593 .45521 .5944 .46827 .6109 .46805 .60254 .45812 Mtetra
.705 .762 .896 r
.60254 .45812 .6109 .46805 .62727 .45887 .61904 .45065 Mtetra
.82 .822 .851 r
.61904 .45065 .62727 .45887 .64352 .44497 .63538 .43642 Mtetra
.787 .813 .873 r
.63538 .43642 .64352 .44497 .6599 .43371 .65181 .42456 Mtetra
.703 .782 .913 r
.65181 .42456 .6599 .43371 .67652 .42706 .66849 .41721 Mtetra
.648 .748 .922 r
.66849 .41721 .67652 .42706 .69332 .42205 .68535 .41214 Mtetra
.656 .751 .92 r
.68535 .41214 .69332 .42205 .7102 .41663 .7023 .40673 Mtetra
.67 .758 .916 r
.7023 .40673 .7102 .41663 .72715 .41067 .71932 .40069 Mtetra
.652 .751 .922 r
.71932 .40069 .72715 .41067 .74424 .40546 .73648 .39535 Mtetra
.648 .747 .922 r
.73648 .39535 .74424 .40546 .76145 .40033 .75377 .39018 Mtetra
.656 .751 .92 r
.75377 .39018 .76145 .40033 .77874 .39482 .77113 .38464 Mtetra
.665 .755 .918 r
.77113 .38464 .77874 .39482 .7961 .38895 .78857 .3787 Mtetra
.654 .751 .921 r
.78857 .3787 .7961 .38895 .81361 .38352 .80615 .37318 Mtetra
.651 .749 .922 r
.80615 .37318 .81361 .38352 .83124 .37815 .82386 .36775 Mtetra
.655 .751 .92 r
.82386 .36775 .83124 .37815 .84896 .37253 .84165 .36209 Mtetra
.662 .754 .919 r
.84165 .36209 .84896 .37253 .86675 .36664 .85953 .35613 Mtetra
.649 .75 .923 r
.22458 .54715 .23429 .55562 .24863 .55128 .23896 .54276 Mtetra
.656 .752 .92 r
.23896 .54276 .24863 .55128 .26306 .54666 .25344 .53809 Mtetra
.661 .753 .918 r
.25344 .53809 .26306 .54666 .27759 .54183 .26802 .53321 Mtetra
.658 .752 .919 r
.26802 .53321 .27759 .54183 .29219 .53709 .28267 .52842 Mtetra
.646 .749 .924 r
.28267 .52842 .29219 .53709 .30684 .53276 .29737 .52405 Mtetra
.656 .751 .92 r
.29737 .52405 .30684 .53276 .3216 .52805 .31218 .51929 Mtetra
.664 .754 .917 r
.31218 .51929 .3216 .52805 .33646 .52299 .32709 .51418 Mtetra
.659 .752 .919 r
.32709 .51418 .33646 .52299 .35138 .5181 .34207 .50924 Mtetra
.639 .747 .926 r
.34207 .50924 .35138 .5181 .36636 .51389 .3571 .50498 Mtetra
.656 .751 .92 r
.3571 .50498 .36636 .51389 .38146 .50908 .37224 .50011 Mtetra
.664 .754 .917 r
.37224 .50011 .38146 .50908 .39665 .50394 .38749 .49492 Mtetra
.596 .732 .939 r
.38749 .49492 .39665 .50394 .41184 .50103 .40273 .49197 Mtetra
.401 .648 .958 r
.40273 .49197 .41184 .50103 .42701 .50258 .41794 .49348 Mtetra
.26 .572 .939 r
.41794 .49348 .42701 .50258 .44227 .50649 .43323 .49736 Mtetra
.587 .73 .942 r
.43323 .49736 .44227 .50649 .45783 .50378 .44884 .49461 Mtetra
.797 .783 .84 r
.44884 .49461 .45783 .50378 .47366 .49079 .46475 .48155 Mtetra
.86 .782 .774 r
.46475 .48155 .47366 .49079 .48959 .47002 .48078 .46068 Mtetra
.854 .782 .781 r
.48078 .46068 .48959 .47002 .50546 .45025 .49675 .44082 Mtetra
.807 .782 .83 r
.49675 .44082 .50546 .45025 .52126 .43634 .51263 .42684 Mtetra
.658 .749 .917 r
.51263 .42684 .52126 .43634 .53711 .43121 .52854 .42165 Mtetra
.305 .584 .94 r
.52854 .42165 .53711 .43121 .55312 .43488 .54459 .42528 Mtetra
0 .346 .817 r
.54459 .42528 .55312 .43488 .5694 .4445 .56089 .43488 Mtetra
0 .301 .785 r
.56089 .43488 .5694 .4445 .58593 .45521 .57745 .44558 Mtetra
.35 .611 .948 r
.57745 .44558 .58593 .45521 .60254 .45812 .59411 .44846 Mtetra
.706 .77 .902 r
.59411 .44846 .60254 .45812 .61904 .45065 .61067 .44092 Mtetra
.809 .792 .837 r
.61067 .44092 .61904 .45065 .63538 .43642 .6271 .42661 Mtetra
.78 .788 .859 r
.6271 .42661 .63538 .43642 .65181 .42456 .64362 .41467 Mtetra
.702 .767 .903 r
.64362 .41467 .65181 .42456 .66849 .41721 .66036 .40726 Mtetra
.648 .749 .923 r
.66036 .40726 .66849 .41721 .68535 .41214 .6773 .40213 Mtetra
.656 .751 .92 r
.6773 .40213 .68535 .41214 .7023 .40673 .69432 .39666 Mtetra
.67 .757 .915 r
.69432 .39666 .7023 .40673 .71932 .40069 .71141 .39056 Mtetra
.653 .75 .921 r
.71141 .39056 .71932 .40069 .73648 .39535 .72864 .38516 Mtetra
.647 .748 .923 r
.72864 .38516 .73648 .39535 .75377 .39018 .746 .37993 Mtetra
.656 .751 .92 r
.746 .37993 .75377 .39018 .77113 .38464 .76344 .37433 Mtetra
.665 .755 .918 r
.76344 .37433 .77113 .38464 .78857 .3787 .78095 .36832 Mtetra
.654 .751 .921 r
.78095 .36832 .78857 .3787 .80615 .37318 .79861 .36274 Mtetra
.651 .749 .922 r
.79861 .36274 .80615 .37318 .82386 .36775 .81639 .35725 Mtetra
.655 .751 .92 r
.81639 .35725 .82386 .36775 .84165 .36209 .83426 .35152 Mtetra
.662 .754 .919 r
.83426 .35152 .84165 .36209 .85953 .35613 .85222 .34549 Mtetra
.649 .75 .923 r
.21478 .53858 .22458 .54715 .23896 .54276 .2292 .53414 Mtetra
.656 .751 .92 r
.2292 .53414 .23896 .54276 .25344 .53809 .24373 .52945 Mtetra
.661 .753 .918 r
.24373 .52945 .25344 .53809 .26802 .53321 .25835 .52452 Mtetra
.659 .752 .919 r
.25835 .52452 .26802 .53321 .28267 .52842 .27305 .51965 Mtetra
.646 .748 .924 r
.27305 .51965 .28267 .52842 .29737 .52405 .2878 .51522 Mtetra
.655 .751 .92 r
.2878 .51522 .29737 .52405 .31218 .51929 .30266 .51045 Mtetra
.664 .754 .917 r
.30266 .51045 .31218 .51929 .32709 .51418 .31762 .50531 Mtetra
.661 .754 .919 r
.31762 .50531 .32709 .51418 .34207 .50924 .33265 .50025 Mtetra
.64 .746 .926 r
.33265 .50025 .34207 .50924 .3571 .50498 .34773 .49593 Mtetra
.654 .75 .92 r
.34773 .49593 .3571 .50498 .37224 .50011 .36293 .49107 Mtetra
.664 .754 .917 r
.36293 .49107 .37224 .50011 .38749 .49492 .37823 .48583 Mtetra
.617 .74 .934 r
.37823 .48583 .38749 .49492 .40273 .49197 .39355 .4822 Mtetra
.442 .652 .949 r
.39355 .4822 .40273 .49197 .41794 .49348 .40881 .48315 Mtetra
.316 .574 .933 r
.40881 .48315 .41794 .49348 .43323 .49736 .42413 .48675 Mtetra
.537 .678 .929 r
.42413 .48675 .43323 .49736 .44884 .49461 .43974 .4857 Mtetra
.757 .785 .876 r
.43974 .4857 .44884 .49461 .46475 .48155 .45567 .47573 Mtetra
.872 .848 .817 r
.45567 .47573 .46475 .48155 .48078 .46068 .47178 .45742 Mtetra
.889 .901 .831 r
.47178 .45742 .48078 .46068 .49675 .44082 .48785 .43918 Mtetra
.824 .959 .9 r
.48785 .43918 .49675 .44082 .51263 .42684 .50386 .42609 Mtetra
.48 .889 .932 r
.50386 .42609 .51263 .42684 .52854 .42165 .51986 .42085 Mtetra
.158 0 0 r
.51986 .42085 .52854 .42165 .54459 .42528 .53599 .42351 Mtetra
.432 0 0 r
.53599 .42351 .54459 .42528 .56089 .43488 .55234 .43138 Mtetra
.346 0 0 r
.55234 .43138 .56089 .43488 .57745 .44558 .56892 .43941 Mtetra
.407 .74 .992 r
.56892 .43941 .57745 .44558 .59411 .44846 .58558 .43905 Mtetra
.741 .787 .89 r
.58558 .43905 .59411 .44846 .61067 .44092 .60218 .42967 Mtetra
.796 .765 .825 r
.60218 .42967 .61067 .44092 .6271 .42661 .61869 .41552 Mtetra
.764 .762 .85 r
.61869 .41552 .6271 .42661 .64362 .41467 .63531 .40404 Mtetra
.687 .749 .899 r
.63531 .40404 .64362 .41467 .66036 .40726 .65215 .39721 Mtetra
.648 .749 .923 r
.65215 .39721 .66036 .40726 .6773 .40213 .66915 .39202 Mtetra
.657 .752 .92 r
.66915 .39202 .6773 .40213 .69432 .39666 .68624 .38643 Mtetra
.67 .755 .915 r
.68624 .38643 .69432 .39666 .71141 .39056 .7034 .38028 Mtetra
.651 .748 .921 r
.7034 .38028 .71141 .39056 .72864 .38516 .72072 .37489 Mtetra
.648 .749 .923 r
.72072 .37489 .72864 .38516 .746 .37993 .73814 .36957 Mtetra
.657 .752 .92 r
.73814 .36957 .746 .37993 .76344 .37433 .75565 .36387 Mtetra
.664 .754 .917 r
.75565 .36387 .76344 .37433 .78095 .36832 .77325 .35781 Mtetra
.653 .75 .921 r
.77325 .35781 .78095 .36832 .79861 .36274 .79098 .35219 Mtetra
.651 .75 .922 r
.79098 .35219 .79861 .36274 .81639 .35725 .80884 .34663 Mtetra
.656 .752 .92 r
.80884 .34663 .81639 .35725 .83426 .35152 .82679 .34082 Mtetra
.661 .754 .918 r
.82679 .34082 .83426 .35152 .85222 .34549 .84483 .33473 Mtetra
.65 .75 .923 r
.20487 .52993 .21478 .53858 .2292 .53414 .21934 .52542 Mtetra
.654 .75 .92 r
.21934 .52542 .2292 .53414 .24373 .52945 .23391 .52072 Mtetra
.661 .753 .918 r
.23391 .52072 .24373 .52945 .25835 .52452 .24859 .51575 Mtetra
.66 .753 .919 r
.24859 .51575 .25835 .52452 .27305 .51965 .26334 .5108 Mtetra
.647 .749 .924 r
.26334 .5108 .27305 .51965 .2878 .51522 .27814 .50628 Mtetra
.653 .75 .921 r
.27814 .50628 .2878 .51522 .30266 .51045 .29304 .50153 Mtetra
.663 .754 .918 r
.29304 .50153 .30266 .51045 .31762 .50531 .30805 .49638 Mtetra
.664 .755 .918 r
.30805 .49638 .31762 .50531 .33265 .50025 .32314 .49116 Mtetra
.642 .747 .925 r
.32314 .49116 .33265 .50025 .34773 .49593 .33828 .48672 Mtetra
.65 .747 .92 r
.33828 .48672 .34773 .49593 .36293 .49107 .35352 .48195 Mtetra
.662 .754 .918 r
.35352 .48195 .36293 .49107 .37823 .48583 .36887 .47672 Mtetra
.644 .75 .926 r
.36887 .47672 .37823 .48583 .39355 .4822 .38428 .4721 Mtetra
.502 .674 .942 r
.38428 .4721 .39355 .4822 .40881 .48315 .39962 .47177 Mtetra
.39 .591 .924 r
.39962 .47177 .40881 .48315 .42413 .48675 .41499 .47441 Mtetra
.457 .605 .91 r
.41499 .47441 .42413 .48675 .43974 .4857 .43056 .47591 Mtetra
.674 .75 .908 r
.43056 .47591 .43974 .4857 .45567 .47573 .44646 .47001 Mtetra
.81 .864 .888 r
.44646 .47001 .45567 .47573 .47178 .45742 .46257 .4576 Mtetra
.841 .983 .869 r
.46257 .4576 .47178 .45742 .48785 .43918 .47874 .44269 Mtetra
.608 .946 .779 r
.47874 .44269 .48785 .43918 .50386 .42609 .49488 .43125 Mtetra
0 0 0 r
.49488 .43125 .50386 .42609 .51986 .42085 .51102 .42598 Mtetra
.325 0 0 r
.51102 .42598 .51986 .42085 .53599 .42351 .52727 .42689 Mtetra
.437 0 0 r
.52727 .42689 .53599 .42351 .55234 .43138 .54369 .43134 Mtetra
.149 0 0 r
.54369 .43134 .55234 .43138 .56892 .43941 .56028 .43332 Mtetra
.605 .831 .986 r
.56028 .43332 .56892 .43941 .58558 .43905 .57695 .42874 Mtetra
.777 .779 .854 r
.57695 .42874 .58558 .43905 .60218 .42967 .59356 .41666 Mtetra
.773 .733 .816 r
.59356 .41666 .60218 .42967 .61869 .41552 .61017 .40337 Mtetra
.741 .739 .85 r
.61017 .40337 .61869 .41552 .63531 .40404 .6269 .39307 Mtetra
.665 .737 .903 r
.6269 .39307 .63531 .40404 .65215 .39721 .64385 .38713 Mtetra
.65 .751 .924 r
.64385 .38713 .65215 .39721 .66915 .39202 .66092 .38181 Mtetra
.661 .754 .919 r
.66092 .38181 .66915 .39202 .68624 .38643 .67807 .37601 Mtetra
.668 .753 .914 r
.67807 .37601 .68624 .38643 .7034 .38028 .69531 .36988 Mtetra
.648 .748 .922 r
.69531 .36988 .7034 .38028 .72072 .37489 .7127 .36453 Mtetra
.649 .75 .923 r
.7127 .36453 .72072 .37489 .73814 .36957 .7302 .35911 Mtetra
.658 .753 .92 r
.7302 .35911 .73814 .36957 .75565 .36387 .74778 .35327 Mtetra
.663 .753 .917 r
.74778 .35327 .75565 .36387 .77325 .35781 .76545 .34718 Mtetra
.652 .75 .921 r
.76545 .34718 .77325 .35781 .79098 .35219 .78327 .34153 Mtetra
.651 .75 .922 r
.78327 .34153 .79098 .35219 .80884 .34663 .8012 .3359 Mtetra
.657 .752 .92 r
.8012 .3359 .80884 .34663 .82679 .34082 .81923 .32997 Mtetra
.661 .753 .918 r
.81923 .32997 .82679 .34082 .84483 .33473 .83735 .32384 Mtetra
.651 .75 .922 r
.19485 .52119 .20487 .52993 .21934 .52542 .20938 .51659 Mtetra
.653 .75 .921 r
.20938 .51659 .21934 .52542 .23391 .52072 .22399 .5119 Mtetra
.661 .753 .919 r
.22399 .5119 .23391 .52072 .24859 .51575 .23871 .5069 Mtetra
.661 .754 .919 r
.23871 .5069 .24859 .51575 .26334 .5108 .25352 .50187 Mtetra
.65 .75 .923 r
.25352 .50187 .26334 .5108 .27814 .50628 .26837 .49721 Mtetra
.65 .748 .921 r
.26837 .49721 .27814 .50628 .29304 .50153 .28331 .49251 Mtetra
.661 .753 .919 r
.28331 .49251 .29304 .50153 .30805 .49638 .29837 .48738 Mtetra
.665 .756 .918 r
.29837 .48738 .30805 .49638 .32314 .49116 .31352 .48206 Mtetra
.648 .75 .924 r
.31352 .48206 .32314 .49116 .33828 .48672 .32872 .47735 Mtetra
.645 .744 .921 r
.32872 .47735 .33828 .48672 .35352 .48195 .34401 .47272 Mtetra
.658 .753 .92 r
.34401 .47272 .35352 .48195 .36887 .47672 .35941 .46758 Mtetra
.661 .757 .921 r
.35941 .46758 .36887 .47672 .38428 .4721 .3749 .4623 Mtetra
.578 .715 .936 r
.3749 .4623 .38428 .4721 .39962 .47177 .39036 .45981 Mtetra
.481 .626 .915 r
.39036 .45981 .39962 .47177 .41499 .47441 .40583 .46048 Mtetra
.441 .568 .887 r
.40583 .46048 .41499 .47441 .43056 .47591 .42139 .46285 Mtetra
.552 .64 .891 r
.42139 .46285 .43056 .47591 .44646 .47001 .43721 .46165 Mtetra
.684 .788 .93 r
.43721 .46165 .44646 .47001 .46257 .4576 .45327 .45528 Mtetra
.719 .943 .956 r
.45327 .45528 .46257 .4576 .47874 .44269 .46946 .44631 Mtetra
.441 .864 .732 r
.46946 .44631 .47874 .44269 .49488 .43125 .48571 .43747 Mtetra
0 0 0 r
.48571 .43747 .49488 .43125 .51102 .42598 .50199 .43216 Mtetra
.216 0 0 r
.50199 .43216 .51102 .42598 .52727 .42689 .51837 .43039 Mtetra
.101 0 0 r
.51837 .43039 .52727 .42689 .54369 .43134 .53488 .42878 Mtetra
.485 .868 .975 r
.53488 .42878 .54369 .43134 .56028 .43332 .5515 .42456 Mtetra
.744 .805 .901 r
.5515 .42456 .56028 .43332 .57695 .42874 .56817 .41512 Mtetra
.766 .723 .812 r
.56817 .41512 .57695 .42874 .59356 .41666 .58484 .40203 Mtetra
.74 .702 .815 r
.58484 .40203 .59356 .41666 .61017 .40337 .60156 .39061 Mtetra
.704 .718 .86 r
.60156 .39061 .61017 .40337 .6269 .39307 .61842 .38239 Mtetra
.651 .74 .914 r
.61842 .38239 .6269 .39307 .64385 .38713 .63545 .37701 Mtetra
.653 .754 .924 r
.63545 .37701 .64385 .38713 .66092 .38181 .65259 .37149 Mtetra
.666 .756 .917 r
.65259 .37149 .66092 .38181 .67807 .37601 .6698 .36543 Mtetra
.663 .75 .915 r
.6698 .36543 .67807 .37601 .69531 .36988 .68713 .35944 Mtetra
.647 .749 .924 r
.68713 .35944 .69531 .36988 .7127 .36453 .70459 .35409 Mtetra
.651 .752 .923 r
.70459 .35409 .7127 .36453 .7302 .35911 .72216 .34853 Mtetra
.661 .754 .919 r
.72216 .34853 .7302 .35911 .74778 .35327 .73981 .34252 Mtetra
.661 .752 .917 r
.73981 .34252 .74778 .35327 .76545 .34718 .75757 .33645 Mtetra
.651 .75 .922 r
.75757 .33645 .76545 .34718 .78327 .34153 .77547 .33077 Mtetra
.77547 .33077 .78327 .34153 .8012 .3359 .79348 .32505 Mtetra
.659 .753 .92 r
.79348 .32505 .8012 .3359 .81923 .32997 .81158 .31899 Mtetra
.66 .752 .918 r
.81158 .31899 .81923 .32997 .83735 .32384 .82978 .31283 Mtetra
.653 .751 .922 r
.18474 .51237 .19485 .52119 .20938 .51659 .19931 .50765 Mtetra
.651 .749 .921 r
.19931 .50765 .20938 .51659 .22399 .5119 .21397 .50299 Mtetra
.66 .753 .919 r
.21397 .50299 .22399 .5119 .23871 .5069 .22874 .49797 Mtetra
.661 .754 .919 r
.22874 .49797 .23871 .5069 .25352 .50187 .24359 .49287 Mtetra
.653 .751 .922 r
.24359 .49287 .25352 .50187 .26837 .49721 .25851 .48803 Mtetra
.647 .747 .922 r
.25851 .48803 .26837 .49721 .28331 .49251 .27349 .48338 Mtetra
.659 .752 .919 r
.27349 .48338 .28331 .49251 .29837 .48738 .28859 .47828 Mtetra
.665 .756 .918 r
.28859 .47828 .29837 .48738 .31352 .48206 .3038 .47292 Mtetra
.656 .754 .922 r
.3038 .47292 .31352 .48206 .32872 .47735 .31907 .46785 Mtetra
.641 .742 .922 r
.31907 .46785 .32872 .47735 .34401 .47272 .3344 .46332 Mtetra
.656 .75 .919 r
.3344 .46332 .34401 .47272 .35941 .46758 .34985 .45822 Mtetra
.663 .754 .918 r
.34985 .45822 .35941 .46758 .3749 .4623 .3654 .45282 Mtetra
.643 .747 .925 r
.3654 .45282 .3749 .4623 .39036 .45981 .38101 .44813 Mtetra
.549 .665 .914 r
.38101 .44813 .39036 .45981 .40583 .46048 .39658 .44675 Mtetra
.504 .606 .888 r
.39658 .44675 .40583 .46048 .42139 .46285 .41222 .44716 Mtetra
.503 .574 .86 r
.41222 .44716 .42139 .46285 .43721 .46165 .42799 .44803 Mtetra
.565 .639 .883 r
.42799 .44803 .43721 .46165 .45327 .45528 .44398 .44637 Mtetra
.641 .767 .939 r
.44398 .44637 .45327 .45528 .46946 .44631 .46017 .4415 Mtetra
.633 .87 .986 r
.46017 .4415 .46946 .44631 .48571 .43747 .47647 .43581 Mtetra
.521 .897 .961 r
.47647 .43581 .48571 .43747 .50199 .43216 .49285 .43045 Mtetra
.498 .887 .959 r
.49285 .43045 .50199 .43216 .51837 .43039 .50934 .42543 Mtetra
.635 .871 .986 r
.50934 .42543 .51837 .43039 .53488 .42878 .52593 .41958 Mtetra
.735 .794 .899 r
.52593 .41958 .53488 .42878 .5515 .42456 .54259 .4105 Mtetra
.747 .711 .819 r
.54259 .4105 .5515 .42456 .56817 .41512 .5593 .39882 Mtetra
.728 .677 .8 r
.5593 .39882 .56817 .41512 .58484 .40203 .57604 .38758 Mtetra
.715 .697 .831 r
.57604 .38758 .58484 .40203 .60156 .39061 .59287 .37813 Mtetra
.664 .71 .882 r
.59287 .37813 .60156 .39061 .61842 .38239 .60986 .37203 Mtetra
.649 .749 .922 r
.60986 .37203 .61842 .38239 .63545 .37701 .62696 .36665 Mtetra
.656 .752 .921 r
.62696 .36665 .63545 .37701 .65259 .37149 .64416 .36096 Mtetra
.669 .755 .915 r
.64416 .36096 .65259 .37149 .6698 .36543 .66144 .35468 Mtetra
.655 .747 .917 r
.66144 .35468 .6698 .36543 .68713 .35944 .67886 .34895 Mtetra
.647 .75 .925 r
.67886 .34895 .68713 .35944 .70459 .35409 .6964 .34351 Mtetra
.653 .752 .923 r
.6964 .34351 .70459 .35409 .72216 .34853 .71403 .33781 Mtetra
.664 .755 .918 r
.71403 .33781 .72216 .34853 .73981 .34252 .73175 .33162 Mtetra
.658 .75 .918 r
.73175 .33162 .73981 .34252 .75757 .33645 .7496 .32562 Mtetra
.651 .75 .922 r
.7496 .32562 .75757 .33645 .77547 .33077 .76757 .31989 Mtetra
.652 .751 .922 r
.76757 .31989 .77547 .33077 .79348 .32505 .78566 .31407 Mtetra
.66 .754 .919 r
.78566 .31407 .79348 .32505 .81158 .31899 .80384 .30786 Mtetra
.658 .751 .919 r
.80384 .30786 .81158 .31899 .82978 .31283 .82213 .3017 Mtetra
.655 .752 .921 r
.17451 .50346 .18474 .51237 .19931 .50765 .18915 .49862 Mtetra
.649 .748 .922 r
.18915 .49862 .19931 .50765 .21397 .50299 .20384 .49395 Mtetra
.658 .751 .919 r
.20384 .49395 .21397 .50299 .22874 .49797 .21865 .48895 Mtetra
.661 .754 .919 r
.21865 .48895 .22874 .49797 .24359 .49287 .23356 .4838 Mtetra
.658 .753 .92 r
.23356 .4838 .24359 .49287 .25851 .48803 .24854 .47874 Mtetra
.647 .746 .922 r
.24854 .47874 .25851 .48803 .27349 .48338 .26357 .47406 Mtetra
.655 .749 .919 r
.26357 .47406 .27349 .48338 .28859 .47828 .27871 .46907 Mtetra
.663 .755 .919 r
.27871 .46907 .28859 .47828 .3038 .47292 .29397 .46374 Mtetra
.664 .757 .92 r
.29397 .46374 .3038 .47292 .31907 .46785 .30931 .45834 Mtetra
.646 .746 .922 r
.30931 .45834 .31907 .46785 .3344 .46332 .3247 .45359 Mtetra
.647 .743 .919 r
.3247 .45359 .3344 .46332 .34985 .45822 .34018 .44877 Mtetra
.658 .753 .92 r
.34018 .44877 .34985 .45822 .3654 .45282 .35578 .44349 Mtetra
.663 .759 .921 r
.35578 .44349 .3654 .45282 .38101 .44813 .37148 .43799 Mtetra
.634 .733 .92 r
.37148 .43799 .38101 .44813 .39658 .44675 .38723 .43357 Mtetra
.565 .647 .889 r
.38723 .43357 .39658 .44675 .41222 .44716 .40297 .43181 Mtetra
.553 .606 .86 r
.40297 .43181 .41222 .44716 .42799 .44803 .41882 .43071 Mtetra
.55 .578 .835 r
.41882 .43071 .42799 .44803 .44398 .44637 .4348 .42991 Mtetra
.583 .606 .841 r
.4348 .42991 .44398 .44637 .46017 .4415 .45095 .4276 Mtetra
.62 .663 .87 r
.45095 .4276 .46017 .4415 .47647 .43581 .46726 .42363 Mtetra
.653 .707 .887 r
.46726 .42363 .47647 .43581 .49285 .43045 .4837 .41821 Mtetra
.682 .717 .875 r
.4837 .41821 .49285 .43045 .50934 .42543 .50025 .41134 Mtetra
.704 .696 .84 r
.50025 .41134 .50934 .42543 .52593 .41958 .51689 .40278 Mtetra
.711 .664 .802 r
.51689 .40278 .52593 .41958 .54259 .4105 .53359 .39268 Mtetra
.702 .65 .794 r
.53359 .39268 .54259 .4105 .5593 .39882 .55036 .38287 Mtetra
.703 .672 .817 r
.55036 .38287 .5593 .39882 .57604 .38758 .56719 .37369 Mtetra
.668 .689 .86 r
.56719 .37369 .57604 .38758 .59287 .37813 .58413 .3672 Mtetra
.649 .738 .914 r
.58413 .3672 .59287 .37813 .60986 .37203 .6012 .36181 Mtetra
.653 .756 .925 r
.6012 .36181 .60986 .37203 .62696 .36665 .61837 .35618 Mtetra
.664 .756 .918 r
.61837 .35618 .62696 .36665 .64416 .36096 .63563 .35008 Mtetra
.665 .749 .913 r
.63563 .35008 .64416 .36096 .66144 .35468 .65299 .34392 Mtetra
.648 .746 .921 r
.65299 .34392 .66144 .35468 .67886 .34895 .67049 .3384 Mtetra
.649 .752 .925 r
.67049 .3384 .67886 .34895 .6964 .34351 .6881 .33281 Mtetra
.657 .754 .921 r
.6881 .33281 .6964 .34351 .71403 .33781 .7058 .32686 Mtetra
.664 .753 .916 r
.7058 .32686 .71403 .33781 .73175 .33162 .7236 .32058 Mtetra
.654 .748 .919 r
.7236 .32058 .73175 .33162 .7496 .32562 .74153 .31469 Mtetra
.651 .751 .923 r
.74153 .31469 .7496 .32562 .76757 .31989 .75959 .30889 Mtetra
.654 .752 .922 r
.75959 .30889 .76757 .31989 .78566 .31407 .77775 .30292 Mtetra
.661 .753 .918 r
.77775 .30292 .78566 .31407 .80384 .30786 .796 .2966 Mtetra
.657 .75 .919 r
.796 .2966 .80384 .30786 .82213 .3017 .81439 .29044 Mtetra
.657 .752 .92 r
.16418 .49447 .17451 .50346 .18915 .49862 .17887 .4895 Mtetra
.65 .749 .922 r
.17887 .4895 .18915 .49862 .20384 .49395 .19361 .48476 Mtetra
.654 .749 .92 r
.19361 .48476 .20384 .49395 .21865 .48895 .20846 .47984 Mtetra
.661 .754 .919 r
.20846 .47984 .21865 .48895 .23356 .4838 .22342 .47465 Mtetra
.66 .754 .92 r
.22342 .47465 .23356 .4838 .24854 .47874 .23845 .46945 Mtetra
.65 .75 .922 r
.23845 .46945 .24854 .47874 .26357 .47406 .25355 .46458 Mtetra
.649 .746 .92 r
.25355 .46458 .26357 .47406 .27871 .46907 .26873 .45972 Mtetra
.659 .753 .92 r
.26873 .45972 .27871 .46907 .29397 .46374 .28403 .45446 Mtetra
.664 .757 .919 r
.28403 .45446 .29397 .46374 .30931 .45834 .29943 .44898 Mtetra
.658 .755 .922 r
.29943 .44898 .30931 .45834 .3247 .45359 .3149 .44373 Mtetra
.643 .741 .92 r
.3149 .44373 .3247 .45359 .34018 .44877 .33043 .43899 Mtetra
.652 .747 .919 r
.33043 .43899 .34018 .44877 .35578 .44349 .34607 .4339 Mtetra
.658 .754 .921 r
.34607 .4339 .35578 .44349 .37148 .43799 .36182 .42854 Mtetra
.663 .759 .922 r
.36182 .42854 .37148 .43799 .38723 .43357 .37767 .42296 Mtetra
.642 .729 .912 r
.37767 .42296 .38723 .43357 .40297 .43181 .39358 .41814 Mtetra
.602 .657 .877 r
.39358 .41814 .40297 .43181 .41882 .43071 .40953 .41496 Mtetra
.593 .622 .849 r
.40953 .41496 .41882 .43071 .4348 .42991 .42558 .41216 Mtetra
.602 .601 .822 r
.42558 .41216 .4348 .42991 .45095 .4276 .44177 .40885 Mtetra
.618 .598 .808 r
.44177 .40885 .45095 .4276 .46726 .42363 .4581 .40456 Mtetra
.637 .605 .8 r
.4581 .40456 .46726 .42363 .4837 .41821 .47456 .39906 Mtetra
.655 .613 .795 r
.47456 .39906 .4837 .41821 .50025 .41134 .49113 .39236 Mtetra
.669 .622 .794 r
.49113 .39236 .50025 .41134 .51689 .40278 .50779 .38467 Mtetra
.68 .637 .8 r
.50779 .38467 .51689 .40278 .53359 .39268 .52454 .37646 Mtetra
.682 .661 .823 r
.52454 .37646 .53359 .39268 .55036 .38287 .54136 .3686 Mtetra
.661 .681 .858 r
.54136 .3686 .55036 .38287 .56719 .37369 .55828 .3624 Mtetra
.649 .731 .909 r
.55828 .3624 .56719 .37369 .58413 .3672 .57531 .35697 Mtetra
.654 .757 .925 r
.57531 .35697 .58413 .3672 .6012 .36181 .59244 .35131 Mtetra
.66 .754 .92 r
.59244 .35131 .6012 .36181 .61837 .35618 .60967 .34537 Mtetra
.668 .752 .914 r
.60967 .34537 .61837 .35618 .63563 .35008 .627 .33906 Mtetra
.654 .744 .916 r
.627 .33906 .63563 .35008 .65299 .34392 .64446 .33328 Mtetra
.647 .751 .925 r
.64446 .33328 .65299 .34392 .67049 .3384 .66203 .32772 Mtetra
.652 .754 .924 r
.66203 .32772 .67049 .3384 .6881 .33281 .67971 .32194 Mtetra
.662 .755 .919 r
.67971 .32194 .6881 .33281 .7058 .32686 .69748 .31573 Mtetra
.661 .75 .916 r
.69748 .31573 .7058 .32686 .7236 .32058 .71536 .30952 Mtetra
.652 .749 .921 r
.71536 .30952 .7236 .32058 .74153 .31469 .73338 .30365 Mtetra
.651 .751 .923 r
.73338 .30365 .74153 .31469 .75959 .30889 .75151 .29776 Mtetra
.657 .753 .921 r
.75151 .29776 .75959 .30889 .77775 .30292 .76975 .29159 Mtetra
.661 .752 .918 r
.76975 .29159 .77775 .30292 .796 .2966 .78808 .28521 Mtetra
.655 .75 .92 r
.78808 .28521 .796 .2966 .81439 .29044 .80656 .27907 Mtetra
.658 .753 .92 r
.15374 .48541 .16418 .49447 .17887 .4895 .16848 .48034 Mtetra
.653 .751 .922 r
.16848 .48034 .17887 .4895 .19361 .48476 .18328 .47545 Mtetra
.651 .748 .921 r
.18328 .47545 .19361 .48476 .20846 .47984 .19816 .4706 Mtetra
.659 .753 .919 r
.19816 .4706 .20846 .47984 .22342 .47465 .21316 .46542 Mtetra
.661 .755 .92 r
.21316 .46542 .22342 .47465 .23845 .46945 .22826 .46013 Mtetra
.656 .753 .921 r
.22826 .46013 .23845 .46945 .25355 .46458 .24342 .45498 Mtetra
.647 .745 .921 r
.24342 .45498 .25355 .46458 .26873 .45972 .25865 .45015 Mtetra
.654 .749 .919 r
.25865 .45015 .26873 .45972 .28403 .45446 .27398 .44503 Mtetra
.661 .755 .92 r
.27398 .44503 .28403 .45446 .29943 .44898 .28943 .43961 Mtetra
.664 .759 .921 r
.28943 .43961 .29943 .44898 .3149 .44373 .30497 .43406 Mtetra
.653 .75 .921 r
.30497 .43406 .3149 .44373 .33043 .43899 .32058 .42889 Mtetra
.644 .739 .918 r
.32058 .42889 .33043 .43899 .34607 .4339 .33626 .42403 Mtetra
.653 .748 .92 r
.33626 .42403 .34607 .4339 .36182 .42854 .35205 .4188 Mtetra
.658 .754 .921 r
.35205 .4188 .36182 .42854 .37767 .42296 .36795 .41336 Mtetra
.662 .759 .923 r
.36795 .41336 .37767 .42296 .39358 .41814 .38395 .40773 Mtetra
.655 .741 .913 r
.38395 .40773 .39358 .41814 .40953 .41496 .40004 .40231 Mtetra
.643 .695 .883 r
.40004 .40231 .40953 .41496 .42558 .41216 .41621 .3973 Mtetra
.631 .655 .855 r
.41621 .3973 .42558 .41216 .44177 .40885 .43246 .39266 Mtetra
.633 .638 .837 r
.43246 .39266 .44177 .40885 .4581 .40456 .44883 .38777 Mtetra
.643 .635 .827 r
.44883 .38777 .4581 .40456 .47456 .39906 .46532 .3822 Mtetra
.654 .64 .824 r
.46532 .3822 .47456 .39906 .49113 .39236 .48192 .37597 Mtetra
.66 .649 .829 r
.48192 .37597 .49113 .39236 .50779 .38467 .49862 .36947 Mtetra
.657 .665 .847 r
.49862 .36947 .50779 .38467 .52454 .37646 .5154 .36335 Mtetra
.654 .698 .879 r
.5154 .36335 .52454 .37646 .54136 .3686 .53229 .35763 Mtetra
.65 .739 .915 r
.53229 .35763 .54136 .3686 .55828 .3624 .54928 .35212 Mtetra
.654 .757 .925 r
.54928 .35212 .55828 .3624 .57531 .35697 .56638 .34642 Mtetra
.658 .754 .921 r
.56638 .34642 .57531 .35697 .59244 .35131 .58358 .34051 Mtetra
.667 .753 .915 r
.58358 .34051 .59244 .35131 .60967 .34537 .60088 .3342 Mtetra
.658 .744 .913 r
.60088 .3342 .60967 .34537 .627 .33906 .61829 .32822 Mtetra
.648 .748 .923 r
.61829 .32822 .627 .33906 .64446 .33328 .63582 .32261 Mtetra
.651 .754 .926 r
.63582 .32261 .64446 .33328 .66203 .32772 .65347 .31686 Mtetra
.657 .754 .922 r
.65347 .31686 .66203 .32772 .67971 .32194 .67121 .31081 Mtetra
.664 .753 .916 r
.67121 .31081 .67971 .32194 .69748 .31573 .68905 .30445 Mtetra
.655 .747 .918 r
.68905 .30445 .69748 .31573 .71536 .30952 .70703 .29841 Mtetra
.651 .751 .923 r
.70703 .29841 .71536 .30952 .73338 .30365 .72513 .2925 Mtetra
.653 .752 .923 r
.72513 .2925 .73338 .30365 .75151 .29776 .74334 .28648 Mtetra
.66 .754 .919 r
.74334 .28648 .75151 .29776 .76975 .29159 .76164 .28009 Mtetra
.659 .75 .918 r
.76164 .28009 .76975 .29159 .78808 .28521 .78007 .27375 Mtetra
.653 .75 .921 r
.78007 .27375 .78808 .28521 .80656 .27907 .79863 .26758 Mtetra
.659 .754 .92 r
.14318 .47627 .15374 .48541 .16848 .48034 .15797 .4711 Mtetra
.656 .752 .921 r
.15797 .4711 .16848 .48034 .18328 .47545 .17284 .46603 Mtetra
.65 .748 .921 r
.17284 .46603 .18328 .47545 .19816 .4706 .18777 .46117 Mtetra
.655 .75 .919 r
.18777 .46117 .19816 .4706 .21316 .46542 .2028 .45608 Mtetra
.66 .754 .92 r
.2028 .45608 .21316 .46542 .22826 .46013 .21794 .45076 Mtetra
.66 .755 .92 r
.21794 .45076 .22826 .46013 .24342 .45498 .23317 .44542 Mtetra
.652 .75 .921 r
.23317 .44542 .24342 .45498 .25865 .45015 .24846 .44036 Mtetra
.648 .745 .92 r
.24846 .44036 .25865 .45015 .27398 .44503 .26383 .43541 Mtetra
.658 .753 .92 r
.26383 .43541 .27398 .44503 .28943 .43961 .27933 .43007 Mtetra
.662 .757 .92 r
.27933 .43007 .28943 .43961 .30497 .43406 .29492 .42454 Mtetra
.663 .759 .921 r
.29492 .42454 .30497 .43406 .32058 .42889 .31061 .41894 Mtetra
.653 .748 .919 r
.31061 .41894 .32058 .42889 .33626 .42403 .32636 .41371 Mtetra
.646 .739 .917 r
.32636 .41371 .33626 .42403 .35205 .4188 .3422 .4087 Mtetra
.651 .747 .919 r
.3422 .4087 .35205 .4188 .36795 .41336 .35814 .40345 Mtetra
.657 .754 .921 r
.35814 .40345 .36795 .41336 .38395 .40773 .37419 .39794 Mtetra
.657 .758 .924 r
.37419 .39794 .38395 .40773 .40004 .40231 .39034 .3924 Mtetra
.66 .757 .922 r
.39034 .3924 .40004 .40231 .41621 .3973 .40659 .38671 Mtetra
.658 .743 .913 r
.40659 .38671 .41621 .3973 .43246 .39266 .42294 .38105 Mtetra
.655 .723 .899 r
.42294 .38105 .43246 .39266 .44883 .38777 .43938 .37544 Mtetra
.654 .71 .889 r
.43938 .37544 .44883 .38777 .46532 .3822 .45592 .36981 Mtetra
.45592 .36981 .46532 .3822 .48192 .37597 .47257 .36416 Mtetra
.653 .722 .9 r
.47257 .36416 .48192 .37597 .49862 .36947 .48931 .35856 Mtetra
.652 .741 .915 r
.48931 .35856 .49862 .36947 .5154 .36335 .50616 .353 Mtetra
.655 .755 .924 r
.50616 .353 .5154 .36335 .53229 .35763 .52311 .34727 Mtetra
.654 .757 .925 r
.52311 .34727 .53229 .35763 .54928 .35212 .54018 .34152 Mtetra
.66 .755 .92 r
.54018 .34152 .54928 .35212 .56638 .34642 .55734 .33551 Mtetra
.665 .751 .915 r
.55734 .33551 .56638 .34642 .58358 .34051 .57461 .32923 Mtetra
.659 .743 .912 r
.57461 .32923 .58358 .34051 .60088 .3342 .59198 .32319 Mtetra
.649 .746 .92 r
.59198 .32319 .60088 .3342 .61829 .32822 .60948 .31751 Mtetra
.65 .754 .926 r
.60948 .31751 .61829 .32822 .63582 .32261 .62708 .31176 Mtetra
.654 .754 .923 r
.62708 .31176 .63582 .32261 .65347 .31686 .6448 .3058 Mtetra
.663 .755 .918 r
.6448 .3058 .65347 .31686 .67121 .31081 .66261 .29944 Mtetra
.659 .748 .916 r
.66261 .29944 .67121 .31081 .68905 .30445 .68054 .29318 Mtetra
.652 .749 .921 r
.68054 .29318 .68905 .30445 .70703 .29841 .6986 .28721 Mtetra
.651 .752 .923 r
.6986 .28721 .70703 .29841 .72513 .2925 .71678 .2812 Mtetra
.656 .753 .921 r
.71678 .2812 .72513 .2925 .74334 .28648 .73506 .27496 Mtetra
.661 .752 .918 r
.73506 .27496 .74334 .28648 .76164 .28009 .75344 .26846 Mtetra
.655 .749 .919 r
.75344 .26846 .76164 .28009 .78007 .27375 .77196 .26217 Mtetra
.652 .751 .922 r
.77196 .26217 .78007 .27375 .79863 .26758 .79061 .25597 Mtetra
.66 .754 .92 r
.13251 .46703 .14318 .47627 .15797 .4711 .14735 .46179 Mtetra
.658 .753 .92 r
.14735 .46179 .15797 .4711 .17284 .46603 .16227 .4566 Mtetra
.653 .75 .921 r
.16227 .4566 .17284 .46603 .18777 .46117 .17726 .45157 Mtetra
.65 .747 .92 r
.17726 .45157 .18777 .46117 .2028 .45608 .19233 .4466 Mtetra
.659 .753 .92 r
.19233 .4466 .2028 .45608 .21794 .45076 .20752 .44129 Mtetra
.661 .755 .92 r
.20752 .44129 .21794 .45076 .23317 .44542 .2228 .43587 Mtetra
.659 .754 .921 r
.2228 .43587 .23317 .44542 .24846 .44036 .23817 .4305 Mtetra
.649 .746 .92 r
.23817 .4305 .24846 .44036 .26383 .43541 .2536 .42544 Mtetra
.65 .745 .919 r
.2536 .42544 .26383 .43541 .27933 .43007 .26912 .42033 Mtetra
.658 .754 .921 r
.26912 .42033 .27933 .43007 .29492 .42454 .28476 .41489 Mtetra
.661 .758 .921 r
.28476 .41489 .29492 .42454 .31061 .41894 .3005 .40928 Mtetra
.662 .759 .922 r
.3005 .40928 .31061 .41894 .32636 .41371 .31634 .40362 Mtetra
.656 .749 .919 r
.31634 .40362 .32636 .41371 .3422 .4087 .33225 .39817 Mtetra
.648 .739 .916 r
.33225 .39817 .3422 .4087 .35814 .40345 .34824 .39299 Mtetra
.648 .742 .918 r
.34824 .39299 .35814 .40345 .37419 .39794 .36434 .38776 Mtetra
.654 .751 .921 r
.36434 .38776 .37419 .39794 .39034 .3924 .38054 .38226 Mtetra
.656 .754 .922 r
.38054 .38226 .39034 .3924 .40659 .38671 .39685 .37665 Mtetra
.656 .757 .924 r
.39685 .37665 .40659 .38671 .42294 .38105 .41326 .371 Mtetra
.656 .758 .925 r
.41326 .371 .42294 .38105 .43938 .37544 .42976 .36533 Mtetra
.42976 .36533 .43938 .37544 .45592 .36981 .44637 .35964 Mtetra
.655 .758 .925 r
.44637 .35964 .45592 .36981 .47257 .36416 .46308 .35393 Mtetra
.46308 .35393 .47257 .36416 .48931 .35856 .47989 .34819 Mtetra
.655 .756 .924 r
.47989 .34819 .48931 .35856 .50616 .353 .49681 .34242 Mtetra
.657 .754 .921 r
.49681 .34242 .50616 .353 .52311 .34727 .51384 .33652 Mtetra
.663 .754 .918 r
.51384 .33652 .52311 .34727 .54018 .34152 .53097 .33036 Mtetra
.663 .747 .912 r
.53097 .33036 .54018 .34152 .55734 .33551 .5482 .32413 Mtetra
.656 .741 .913 r
.5482 .32413 .55734 .33551 .57461 .32923 .56554 .31818 Mtetra
.65 .747 .921 r
.56554 .31818 .57461 .32923 .59198 .32319 .58299 .31244 Mtetra
.65 .755 .926 r
.58299 .31244 .59198 .32319 .60948 .31751 .60056 .30665 Mtetra
.654 .755 .924 r
.60056 .30665 .60948 .31751 .62708 .31176 .61824 .30067 Mtetra
.661 .755 .92 r
.61824 .30067 .62708 .31176 .6448 .3058 .63602 .29435 Mtetra
.662 .749 .915 r
.63602 .29435 .6448 .3058 .66261 .29944 .65391 .28797 Mtetra
.653 .747 .919 r
.65391 .28797 .66261 .29944 .68054 .29318 .67193 .28191 Mtetra
.651 .752 .923 r
.67193 .28191 .68054 .29318 .6986 .28721 .69007 .27588 Mtetra
.653 .753 .923 r
.69007 .27588 .6986 .28721 .71678 .2812 .70832 .26974 Mtetra
.661 .754 .92 r
.70832 .26974 .71678 .2812 .73506 .27496 .72668 .26324 Mtetra
.659 .75 .917 r
.72668 .26324 .73506 .27496 .75344 .26846 .74515 .25678 Mtetra
.654 .75 .921 r
.74515 .25678 .75344 .26846 .77196 .26217 .76376 .25049 Mtetra
.652 .751 .922 r
.76376 .25049 .77196 .26217 .79061 .25597 .7825 .24423 Mtetra
.659 .753 .92 r
.12172 .45766 .13251 .46703 .14735 .46179 .13661 .45242 Mtetra
.659 .754 .92 r
.13661 .45242 .14735 .46179 .16227 .4566 .15159 .44712 Mtetra
.657 .752 .92 r
.15159 .44712 .16227 .4566 .17726 .45157 .16664 .44189 Mtetra
.65 .748 .921 r
.16664 .44189 .17726 .45157 .19233 .4466 .18176 .43686 Mtetra
.653 .748 .92 r
.18176 .43686 .19233 .4466 .20752 .44129 .19698 .43169 Mtetra
.659 .754 .92 r
.19698 .43169 .20752 .44129 .2228 .43587 .21231 .42626 Mtetra
.66 .755 .921 r
.21231 .42626 .2228 .43587 .23817 .4305 .22774 .42077 Mtetra
.658 .753 .921 r
.22774 .42077 .23817 .4305 .2536 .42544 .24325 .41535 Mtetra
.649 .744 .919 r
.24325 .41535 .2536 .42544 .26912 .42033 .25882 .41023 Mtetra
.651 .746 .919 r
.25882 .41023 .26912 .42033 .28476 .41489 .27449 .405 Mtetra
.658 .754 .921 r
.27449 .405 .28476 .41489 .3005 .40928 .29028 .39948 Mtetra
.66 .758 .922 r
.29028 .39948 .3005 .40928 .31634 .40362 .30617 .39383 Mtetra
.662 .76 .923 r
.30617 .39383 .31634 .40362 .33225 .39817 .32216 .38808 Mtetra
.659 .754 .92 r
.32216 .38808 .33225 .39817 .34824 .39299 .33824 .38239 Mtetra
.653 .742 .915 r
.33824 .38239 .34824 .39299 .36434 .38776 .3544 .37692 Mtetra
.65 .738 .914 r
.3544 .37692 .36434 .38776 .38054 .38226 .37065 .37151 Mtetra
.651 .741 .916 r
.37065 .37151 .38054 .38226 .39685 .37665 .38701 .36604 Mtetra
.653 .746 .918 r
.38701 .36604 .39685 .37665 .41326 .371 .40348 .36047 Mtetra
.654 .75 .92 r
.40348 .36047 .41326 .371 .42976 .36533 .42004 .3548 Mtetra
.656 .751 .92 r
.42004 .3548 .42976 .36533 .44637 .35964 .43672 .34904 Mtetra
.657 .752 .92 r
.43672 .34904 .44637 .35964 .46308 .35393 .45349 .34319 Mtetra
.659 .751 .918 r
.45349 .34319 .46308 .35393 .47989 .34819 .47038 .33725 Mtetra
.66 .749 .916 r
.47038 .33725 .47989 .34819 .49681 .34242 .48736 .33121 Mtetra
.661 .745 .912 r
.48736 .33121 .49681 .34242 .51384 .33652 .50445 .32509 Mtetra
.658 .741 .911 r
.50445 .32509 .51384 .33652 .53097 .33036 .52165 .31904 Mtetra
.652 .742 .915 r
.52165 .31904 .53097 .33036 .5482 .32413 .53896 .3132 Mtetra
.65 .751 .923 r
.53896 .3132 .5482 .32413 .56554 .31818 .55637 .30742 Mtetra
.651 .757 .927 r
.55637 .30742 .56554 .31818 .58299 .31244 .5739 .30154 Mtetra
.654 .756 .925 r
.5739 .30154 .58299 .31244 .60056 .30665 .59154 .29552 Mtetra
.66 .755 .92 r
.59154 .29552 .60056 .30665 .61824 .30067 .60928 .28919 Mtetra
.662 .75 .915 r
.60928 .28919 .61824 .30067 .63602 .29435 .62714 .28276 Mtetra
.654 .746 .917 r
.62714 .28276 .63602 .29435 .65391 .28797 .64512 .27661 Mtetra
.652 .751 .923 r
.64512 .27661 .65391 .28797 .67193 .28191 .66322 .27054 Mtetra
.652 .753 .923 r
.66322 .27054 .67193 .28191 .69007 .27588 .68144 .26439 Mtetra
.658 .754 .921 r
.68144 .26439 .69007 .27588 .70832 .26974 .69976 .25797 Mtetra
.661 .751 .917 r
.69976 .25797 .70832 .26974 .72668 .26324 .7182 .25139 Mtetra
.655 .749 .919 r
.7182 .25139 .72668 .26324 .74515 .25678 .73676 .24501 Mtetra
.653 .751 .922 r
.73676 .24501 .74515 .25678 .76376 .25049 .75546 .23869 Mtetra
.653 .752 .922 r
.75546 .23869 .76376 .25049 .7825 .24423 .77428 .2323 Mtetra
.655 .75 .92 r
.11084 .44808 .12172 .45766 .13661 .45242 .12576 .44293 Mtetra
.66 .754 .92 r
.12576 .44293 .13661 .45242 .15159 .44712 .14079 .43757 Mtetra
.658 .754 .92 r
.14079 .43757 .15159 .44712 .16664 .44189 .1559 .43222 Mtetra
.655 .751 .921 r
.1559 .43222 .16664 .44189 .18176 .43686 .17108 .42697 Mtetra
.65 .747 .92 r
.17108 .42697 .18176 .43686 .19698 .43169 .18634 .42186 Mtetra
.655 .75 .92 r
.18634 .42186 .19698 .43169 .21231 .42626 .20171 .41653 Mtetra
.66 .755 .921 r
.20171 .41653 .21231 .42626 .22774 .42077 .21719 .41101 Mtetra
.66 .756 .921 r
.21719 .41101 .22774 .42077 .24325 .41535 .23276 .40544 Mtetra
.657 .753 .921 r
.23276 .40544 .24325 .41535 .25882 .41023 .24841 .39994 Mtetra
.65 .744 .919 r
.24841 .39994 .25882 .41023 .27449 .405 .26414 .39469 Mtetra
.65 .745 .919 r
.26414 .39469 .27449 .405 .29028 .39948 .27996 .3894 Mtetra
.657 .753 .921 r
.27996 .3894 .29028 .39948 .30617 .39383 .2959 .38382 Mtetra
.659 .757 .922 r
.2959 .38382 .30617 .39383 .32216 .38808 .31194 .37814 Mtetra
.66 .76 .924 r
.31194 .37814 .32216 .38808 .33824 .38239 .32808 .37236 Mtetra
.66 .759 .923 r
.32808 .37236 .33824 .38239 .3544 .37692 .34432 .36655 Mtetra
.658 .753 .92 r
.34432 .36655 .3544 .37692 .37065 .37151 .36065 .36076 Mtetra
.657 .746 .915 r
.36065 .36076 .37065 .37151 .38701 .36604 .37708 .355 Mtetra
.655 .74 .913 r
.37708 .355 .38701 .36604 .40348 .36047 .39361 .34928 Mtetra
.655 .739 .912 r
.39361 .34928 .40348 .36047 .42004 .3548 .41024 .34354 Mtetra
.656 .739 .911 r
.41024 .34354 .42004 .3548 .43672 .34904 .42697 .33771 Mtetra
.657 .739 .911 r
.42697 .33771 .43672 .34904 .45349 .34319 .44381 .33181 Mtetra
.656 .739 .911 r
.44381 .33181 .45349 .34319 .47038 .33725 .46075 .32588 Mtetra
.655 .74 .913 r
.46075 .32588 .47038 .33725 .48736 .33121 .4778 .31999 Mtetra
.653 .744 .917 r
.4778 .31999 .48736 .33121 .50445 .32509 .49496 .31412 Mtetra
.652 .75 .922 r
.49496 .31412 .50445 .32509 .52165 .31904 .51223 .30828 Mtetra
.651 .756 .926 r
.51223 .30828 .52165 .31904 .53896 .3132 .5296 .3024 Mtetra
.653 .757 .926 r
.5296 .3024 .53896 .3132 .55637 .30742 .54709 .29642 Mtetra
.655 .755 .924 r
.54709 .29642 .55637 .30742 .5739 .30154 .56469 .29033 Mtetra
.661 .755 .92 r
.56469 .29033 .5739 .30154 .59154 .29552 .5824 .28395 Mtetra
.661 .749 .915 r
.5824 .28395 .59154 .29552 .60928 .28919 .60022 .2775 Mtetra
.654 .745 .917 r
.60022 .2775 .60928 .28919 .62714 .28276 .61816 .27132 Mtetra
.652 .751 .922 r
.61816 .27132 .62714 .28276 .64512 .27661 .63622 .2652 Mtetra
.652 .753 .924 r
.63622 .2652 .64512 .27661 .66322 .27054 .6544 .25902 Mtetra
.656 .754 .922 r
.6544 .25902 .66322 .27054 .68144 .26439 .67269 .25263 Mtetra
.661 .752 .918 r
.67269 .25263 .68144 .26439 .69976 .25797 .69109 .24601 Mtetra
.657 .749 .918 r
.69109 .24601 .69976 .25797 .7182 .25139 .70962 .23953 Mtetra
.653 .751 .921 r
.70962 .23953 .7182 .25139 .73676 .24501 .72828 .23313 Mtetra
.652 .752 .922 r
.72828 .23313 .73676 .24501 .75546 .23869 .74706 .22675 Mtetra
.657 .754 .921 r
.74706 .22675 .75546 .23869 .77428 .2323 .76596 .22012 Mtetra
.652 .748 .92 r
.09984 .43837 .11084 .44808 .12576 .44293 .11479 .43327 Mtetra
.657 .752 .92 r
.11479 .43327 .12576 .44293 .14079 .43757 .12986 .42794 Mtetra
.659 .754 .92 r
.12986 .42794 .14079 .43757 .1559 .43222 .14503 .42249 Mtetra
.658 .753 .92 r
.14503 .42249 .1559 .43222 .17108 .42697 .16028 .41708 Mtetra
.653 .75 .92 r
.16028 .41708 .17108 .42697 .18634 .42186 .1756 .41179 Mtetra
.651 .747 .92 r
.1756 .41179 .18634 .42186 .20171 .41653 .191 .40657 Mtetra
.656 .752 .92 r
.191 .40657 .20171 .41653 .21719 .41101 .20652 .40112 Mtetra
.659 .755 .921 r
.20652 .40112 .21719 .41101 .23276 .40544 .22215 .39552 Mtetra
.66 .756 .921 r
.22215 .39552 .23276 .40544 .24841 .39994 .23786 .38986 Mtetra
.658 .753 .921 r
.23786 .38986 .24841 .39994 .26414 .39469 .25367 .38425 Mtetra
.652 .745 .918 r
.25367 .38425 .26414 .39469 .27996 .3894 .26955 .37884 Mtetra
.65 .744 .918 r
.26955 .37884 .27996 .3894 .2959 .38382 .28553 .37344 Mtetra
.653 .75 .92 r
.28553 .37344 .2959 .38382 .31194 .37814 .30161 .36789 Mtetra
.657 .755 .922 r
.30161 .36789 .31194 .37814 .32808 .37236 .31781 .36217 Mtetra
.658 .758 .924 r
.31781 .36217 .32808 .37236 .34432 .36655 .3341 .35638 Mtetra
.658 .759 .925 r
.3341 .35638 .34432 .36655 .36065 .36076 .3505 .35055 Mtetra
.658 .76 .925 r
.3505 .35055 .36065 .36076 .37708 .355 .36699 .34467 Mtetra
.658 .759 .924 r
.36699 .34467 .37708 .355 .39361 .34928 .38359 .33878 Mtetra
.657 .756 .923 r
.38359 .33878 .39361 .34928 .41024 .34354 .40029 .33289 Mtetra
.656 .754 .922 r
.40029 .33289 .41024 .34354 .42697 .33771 .41709 .327 Mtetra
.655 .754 .923 r
.41709 .327 .42697 .33771 .44381 .33181 .43399 .3211 Mtetra
.654 .755 .924 r
.43399 .3211 .44381 .33181 .46075 .32588 .45101 .31521 Mtetra
.653 .757 .926 r
.45101 .31521 .46075 .32588 .4778 .31999 .46812 .30931 Mtetra
.654 .758 .927 r
.46812 .30931 .4778 .31999 .49496 .31412 .48535 .30335 Mtetra
.654 .758 .926 r
.48535 .30335 .49496 .31412 .51223 .30828 .50269 .29735 Mtetra
.655 .757 .925 r
.50269 .29735 .51223 .30828 .5296 .3024 .52014 .29128 Mtetra
.658 .755 .922 r
.52014 .29128 .5296 .3024 .54709 .29642 .5377 .28503 Mtetra
.661 .752 .918 r
.5377 .28503 .54709 .29642 .56469 .29033 .55538 .27862 Mtetra
.66 .747 .914 r
.55538 .27862 .56469 .29033 .5824 .28395 .57316 .27222 Mtetra
.654 .746 .917 r
.57316 .27222 .5824 .28395 .60022 .2775 .59106 .26602 Mtetra
.652 .751 .922 r
.59106 .26602 .60022 .2775 .61816 .27132 .60908 .25985 Mtetra
.652 .753 .924 r
.60908 .25985 .61816 .27132 .63622 .2652 .62722 .25363 Mtetra
.656 .754 .922 r
.62722 .25363 .63622 .2652 .6544 .25902 .64547 .24724 Mtetra
.66 .753 .919 r
.64547 .24724 .6544 .25902 .67269 .25263 .66384 .2406 Mtetra
.658 .749 .917 r
.66384 .2406 .67269 .25263 .69109 .24601 .68233 .23403 Mtetra
.654 .75 .92 r
.68233 .23403 .69109 .24601 .70962 .23953 .70094 .22757 Mtetra
.652 .751 .922 r
.70094 .22757 .70962 .23953 .72828 .23313 .71969 .22114 Mtetra
.655 .753 .922 r
.71969 .22114 .72828 .23313 .74706 .22675 .73855 .21458 Mtetra
.659 .753 .919 r
.73855 .21458 .74706 .22675 .76596 .22012 .75753 .20777 Mtetra
.653 .749 .921 r
.08871 .4286 .09984 .43837 .11479 .43327 .10372 .4234 Mtetra
.652 .749 .92 r
.10372 .4234 .11479 .43327 .12986 .42794 .11882 .41818 Mtetra
.658 .754 .92 r
.11882 .41818 .12986 .42794 .14503 .42249 .13403 .41271 Mtetra
.659 .754 .921 r
.13403 .41271 .14503 .42249 .16028 .41708 .14934 .40718 Mtetra
.657 .753 .92 r
.14934 .40718 .16028 .41708 .1756 .41179 .16473 .40169 Mtetra
.653 .749 .92 r
.16473 .40169 .1756 .41179 .191 .40657 .18019 .39633 Mtetra
.651 .746 .919 r
.18019 .39633 .191 .40657 .20652 .40112 .19575 .391 Mtetra
.656 .752 .92 r
.19575 .391 .20652 .40112 .22215 .39552 .21141 .38547 Mtetra
.659 .755 .921 r
.21141 .38547 .22215 .39552 .23786 .38986 .22718 .37978 Mtetra
.659 .756 .921 r
.22718 .37978 .23786 .38986 .25367 .38425 .24305 .37404 Mtetra
.658 .754 .921 r
.24305 .37404 .25367 .38425 .26955 .37884 .25901 .36831 Mtetra
.655 .748 .918 r
.25901 .36831 .26955 .37884 .28553 .37344 .27506 .36267 Mtetra
.651 .743 .917 r
.27506 .36267 .28553 .37344 .30161 .36789 .2912 .35714 Mtetra
.652 .745 .918 r
.2912 .35714 .30161 .36789 .31781 .36217 .30744 .35155 Mtetra
.653 .75 .92 r
.30744 .35155 .31781 .36217 .3341 .35638 .32378 .34586 Mtetra
.656 .754 .922 r
.32378 .34586 .3341 .35638 .3505 .35055 .34024 .34004 Mtetra
.656 .756 .923 r
.34024 .34004 .3505 .35055 .36699 .34467 .35679 .33417 Mtetra
.656 .757 .924 r
.35679 .33417 .36699 .34467 .38359 .33878 .37345 .32826 Mtetra
.656 .758 .925 r
.37345 .32826 .38359 .33878 .40029 .33289 .39022 .32233 Mtetra
.39022 .32233 .40029 .33289 .41709 .327 .40709 .31637 Mtetra
.655 .758 .926 r
.40709 .31637 .41709 .327 .43399 .3211 .42406 .31038 Mtetra
.655 .758 .925 r
.42406 .31038 .43399 .3211 .45101 .31521 .44114 .30437 Mtetra
.655 .757 .925 r
.44114 .30437 .45101 .31521 .46812 .30931 .45833 .29832 Mtetra
.656 .755 .923 r
.45833 .29832 .46812 .30931 .48535 .30335 .47563 .29222 Mtetra
.658 .755 .921 r
.47563 .29222 .48535 .30335 .50269 .29735 .49304 .28598 Mtetra
.66 .752 .918 r
.49304 .28598 .50269 .29735 .52014 .29128 .51057 .27963 Mtetra
.66 .748 .915 r
.51057 .27963 .52014 .29128 .5377 .28503 .5282 .27323 Mtetra
.656 .745 .915 r
.5282 .27323 .5377 .28503 .55538 .27862 .54595 .26693 Mtetra
.653 .747 .919 r
.54595 .26693 .55538 .27862 .57316 .27222 .56381 .26071 Mtetra
.652 .752 .923 r
.56381 .26071 .57316 .27222 .59106 .26602 .58179 .2545 Mtetra
.653 .754 .924 r
.58179 .2545 .59106 .26602 .60908 .25985 .59989 .24822 Mtetra
.656 .754 .922 r
.59989 .24822 .60908 .25985 .62722 .25363 .6181 .24179 Mtetra
.66 .753 .919 r
.6181 .24179 .62722 .25363 .64547 .24724 .63643 .23513 Mtetra
.658 .749 .917 r
.63643 .23513 .64547 .24724 .66384 .2406 .65488 .2285 Mtetra
.655 .749 .919 r
.65488 .2285 .66384 .2406 .68233 .23403 .67346 .222 Mtetra
.653 .751 .922 r
.67346 .222 .68233 .23403 .70094 .22757 .69216 .21552 Mtetra
.653 .753 .923 r
.69216 .21552 .70094 .22757 .71969 .22114 .71099 .20897 Mtetra
.659 .754 .92 r
.71099 .20897 .71969 .22114 .73855 .21458 .72993 .20215 Mtetra
.658 .75 .918 r
.72993 .20215 .73855 .21458 .75753 .20777 .749 .1953 Mtetra
.655 .751 .92 r
.07746 .41877 .08871 .4286 .10372 .4234 .09253 .41342 Mtetra
.652 .748 .92 r
.09253 .41342 .10372 .4234 .11882 .41818 .10767 .40815 Mtetra
.654 .749 .92 r
.10767 .40815 .11882 .41818 .13403 .41271 .12291 .4028 Mtetra
.659 .754 .92 r
.12291 .4028 .13403 .41271 .14934 .40718 .13827 .39723 Mtetra
.659 .754 .921 r
.13827 .39723 .14934 .40718 .16473 .40169 .15372 .39162 Mtetra
.657 .753 .92 r
.15372 .39162 .16473 .40169 .18019 .39633 .16926 .38604 Mtetra
.653 .749 .92 r
.16926 .38604 .18019 .39633 .19575 .391 .18487 .38057 Mtetra
.651 .746 .919 r
.18487 .38057 .19575 .391 .21141 .38547 .20057 .37514 Mtetra
.655 .751 .92 r
.20057 .37514 .21141 .38547 .22718 .37978 .21639 .36955 Mtetra
.658 .755 .921 r
.21639 .36955 .22718 .37978 .24305 .37404 .23231 .36379 Mtetra
.659 .756 .922 r
.23231 .36379 .24305 .37404 .25901 .36831 .24833 .35798 Mtetra
.24833 .35798 .25901 .36831 .27506 .36267 .26445 .35214 Mtetra
.657 .752 .92 r
.26445 .35214 .27506 .36267 .2912 .35714 .28066 .3463 Mtetra
.655 .747 .917 r
.28066 .3463 .2912 .35714 .30744 .35155 .29697 .34051 Mtetra
.653 .743 .916 r
.29697 .34051 .30744 .35155 .32378 .34586 .31337 .33478 Mtetra
.653 .744 .916 r
.31337 .33478 .32378 .34586 .34024 .34004 .32988 .32901 Mtetra
.654 .746 .918 r
.32988 .32901 .34024 .34004 .35679 .33417 .34649 .32317 Mtetra
.654 .749 .919 r
.34649 .32317 .35679 .33417 .37345 .32826 .36321 .31727 Mtetra
.655 .751 .92 r
.36321 .31727 .37345 .32826 .39022 .32233 .38004 .3113 Mtetra
.656 .751 .92 r
.38004 .3113 .39022 .32233 .40709 .31637 .39698 .30527 Mtetra
.656 .752 .92 r
.39698 .30527 .40709 .31637 .42406 .31038 .41402 .29918 Mtetra
.657 .751 .919 r
.41402 .29918 .42406 .31038 .44114 .30437 .43117 .29302 Mtetra
.658 .75 .918 r
.43117 .29302 .44114 .30437 .45833 .29832 .44843 .2868 Mtetra
.658 .748 .916 r
.44843 .2868 .45833 .29832 .47563 .29222 .46581 .28051 Mtetra
.658 .746 .914 r
.46581 .28051 .47563 .29222 .49304 .28598 .48329 .27417 Mtetra
.656 .744 .915 r
.48329 .27417 .49304 .28598 .51057 .27963 .50088 .26789 Mtetra
.654 .747 .918 r
.50088 .26789 .51057 .27963 .5282 .27323 .51859 .26165 Mtetra
.653 .751 .922 r
.51859 .26165 .5282 .27323 .54595 .26693 .53641 .25541 Mtetra
.653 .754 .924 r
.53641 .25541 .54595 .26693 .56381 .26071 .55435 .24914 Mtetra
.654 .754 .924 r
.55435 .24914 .56381 .26071 .58179 .2545 .57241 .2428 Mtetra
.657 .755 .922 r
.57241 .2428 .58179 .2545 .59989 .24822 .59058 .23629 Mtetra
.66 .753 .919 r
.59058 .23629 .59989 .24822 .6181 .24179 .60887 .2296 Mtetra
.658 .748 .917 r
.60887 .2296 .6181 .24179 .63643 .23513 .62728 .22295 Mtetra
.655 .749 .919 r
.62728 .22295 .63643 .23513 .65488 .2285 .64582 .2164 Mtetra
.653 .751 .922 r
.64582 .2164 .65488 .2285 .67346 .222 .66449 .20988 Mtetra
.653 .753 .923 r
.66449 .20988 .67346 .222 .69216 .21552 .68328 .2033 Mtetra
.658 .754 .921 r
.68328 .2033 .69216 .21552 .71099 .20897 .70218 .19648 Mtetra
.659 .751 .918 r
.70218 .19648 .71099 .20897 .72993 .20215 .72121 .18957 Mtetra
.656 .749 .919 r
.72121 .18957 .72993 .20215 .749 .1953 .74037 .18274 Mtetra
.657 .753 .92 r
.06607 .40889 .07746 .41877 .09253 .41342 .0812 .40341 Mtetra
.655 .751 .92 r
.0812 .40341 .09253 .41342 .10767 .40815 .09641 .39798 Mtetra
.652 .748 .92 r
.09641 .39798 .10767 .40815 .12291 .4028 .11169 .39262 Mtetra
.654 .75 .92 r
.11169 .39262 .12291 .4028 .13827 .39723 .12708 .38716 Mtetra
.659 .754 .921 r
.12708 .38716 .13827 .39723 .15372 .39162 .14258 .3815 Mtetra
.14258 .3815 .15372 .39162 .16926 .38604 .15818 .3758 Mtetra
.657 .753 .92 r
.15818 .3758 .16926 .38604 .18487 .38057 .17386 .37012 Mtetra
.654 .749 .919 r
.17386 .37012 .18487 .38057 .20057 .37514 .18963 .36451 Mtetra
.652 .746 .919 r
.18963 .36451 .20057 .37514 .21639 .36955 .20549 .35897 Mtetra
.653 .749 .92 r
.20549 .35897 .21639 .36955 .23231 .36379 .22145 .35335 Mtetra
.657 .754 .921 r
.22145 .35335 .23231 .36379 .24833 .35798 .23752 .34754 Mtetra
.658 .756 .922 r
.23752 .34754 .24833 .35798 .26445 .35214 .2537 .34165 Mtetra
.2537 .34165 .26445 .35214 .28066 .3463 .26998 .33572 Mtetra
.26998 .33572 .28066 .3463 .29697 .34051 .28635 .32977 Mtetra
.657 .753 .921 r
.28635 .32977 .29697 .34051 .31337 .33478 .30283 .3238 Mtetra
.657 .75 .919 r
.30283 .3238 .31337 .33478 .32988 .32901 .31941 .31782 Mtetra
.656 .747 .917 r
.31941 .31782 .32988 .32901 .34649 .32317 .33609 .31182 Mtetra
.655 .745 .916 r
.33609 .31182 .34649 .32317 .36321 .31727 .35287 .30581 Mtetra
.655 .744 .915 r
.35287 .30581 .36321 .31727 .38004 .3113 .36977 .29976 Mtetra
.656 .744 .915 r
.36977 .29976 .38004 .3113 .39698 .30527 .38677 .29366 Mtetra
.38677 .29366 .39698 .30527 .41402 .29918 .40387 .2875 Mtetra
.40387 .2875 .41402 .29918 .43117 .29302 .42109 .28132 Mtetra
.655 .745 .916 r
.42109 .28132 .43117 .29302 .44843 .2868 .43842 .27511 Mtetra
.655 .746 .917 r
.43842 .27511 .44843 .2868 .46581 .28051 .45586 .26888 Mtetra
.654 .749 .919 r
.45586 .26888 .46581 .28051 .48329 .27417 .47341 .26264 Mtetra
.654 .752 .922 r
.47341 .26264 .48329 .27417 .50088 .26789 .49108 .25639 Mtetra
.654 .754 .924 r
.49108 .25639 .50088 .26789 .51859 .26165 .50886 .2501 Mtetra
.654 .755 .924 r
.50886 .2501 .51859 .26165 .53641 .25541 .52676 .24376 Mtetra
.655 .755 .923 r
.52676 .24376 .53641 .25541 .55435 .24914 .54477 .23735 Mtetra
.659 .755 .921 r
.54477 .23735 .55435 .24914 .57241 .2428 .56291 .23073 Mtetra
.659 .751 .918 r
.56291 .23073 .57241 .2428 .59058 .23629 .58116 .22402 Mtetra
.657 .748 .917 r
.58116 .22402 .59058 .23629 .60887 .2296 .59953 .21737 Mtetra
.655 .749 .919 r
.59953 .21737 .60887 .2296 .62728 .22295 .61803 .21079 Mtetra
.653 .751 .922 r
.61803 .21079 .62728 .22295 .64582 .2164 .63665 .20422 Mtetra
.653 .753 .923 r
.63665 .20422 .64582 .2164 .66449 .20988 .6554 .1976 Mtetra
.657 .754 .921 r
.6554 .1976 .66449 .20988 .68328 .2033 .67427 .19077 Mtetra
.659 .751 .918 r
.67427 .19077 .68328 .2033 .70218 .19648 .69326 .18381 Mtetra
.656 .749 .918 r
.69326 .18381 .70218 .19648 .72121 .18957 .71238 .17692 Mtetra
.654 .751 .92 r
.71238 .17692 .72121 .18957 .74037 .18274 .73164 .17007 Mtetra
.659 .754 .92 r
.05455 .39895 .06607 .40889 .0812 .40341 .06974 .39335 Mtetra
.657 .752 .92 r
.06974 .39335 .0812 .40341 .09641 .39798 .085 .38779 Mtetra
.655 .751 .92 r
.085 .38779 .09641 .39798 .11169 .39262 .10035 .38227 Mtetra
.652 .748 .92 r
.10035 .38227 .11169 .39262 .12708 .38716 .11579 .37681 Mtetra
.654 .75 .92 r
.11579 .37681 .12708 .38716 .14258 .3815 .13132 .37126 Mtetra
.658 .754 .921 r
.13132 .37126 .14258 .3815 .15818 .3758 .14697 .36551 Mtetra
.659 .755 .921 r
.14697 .36551 .15818 .3758 .17386 .37012 .16272 .35971 Mtetra
.657 .753 .921 r
.16272 .35971 .17386 .37012 .18963 .36451 .17855 .35393 Mtetra
.656 .751 .92 r
.17855 .35393 .18963 .36451 .20549 .35897 .19448 .34816 Mtetra
.653 .746 .918 r
.19448 .34816 .20549 .35897 .22145 .35335 .2105 .34248 Mtetra
.652 .746 .919 r
.2105 .34248 .22145 .35335 .23752 .34754 .22661 .33677 Mtetra
.654 .75 .921 r
.22661 .33677 .23752 .34754 .2537 .34165 .24283 .33098 Mtetra
.657 .754 .922 r
.24283 .33098 .2537 .34165 .26998 .33572 .25917 .32504 Mtetra
.657 .756 .922 r
.25917 .32504 .26998 .33572 .28635 .32977 .2756 .31904 Mtetra
.657 .756 .923 r
.2756 .31904 .28635 .32977 .30283 .3238 .29214 .313 Mtetra
.29214 .313 .30283 .3238 .31941 .31782 .30879 .30692 Mtetra
.30879 .30692 .31941 .31782 .33609 .31182 .32553 .30083 Mtetra
.657 .755 .922 r
.32553 .30083 .33609 .31182 .35287 .30581 .34239 .2947 Mtetra
.656 .754 .922 r
.34239 .2947 .35287 .30581 .36977 .29976 .35935 .28856 Mtetra
.656 .753 .922 r
.35935 .28856 .36977 .29976 .38677 .29366 .37641 .28238 Mtetra
.655 .753 .922 r
.37641 .28238 .38677 .29366 .40387 .2875 .39359 .27619 Mtetra
.655 .754 .922 r
.39359 .27619 .40387 .2875 .42109 .28132 .41088 .26996 Mtetra
.655 .754 .923 r
.41088 .26996 .42109 .28132 .43842 .27511 .42827 .26371 Mtetra
.655 .755 .923 r
.42827 .26371 .43842 .27511 .45586 .26888 .44579 .25743 Mtetra
.654 .755 .924 r
.44579 .25743 .45586 .26888 .47341 .26264 .46341 .25112 Mtetra
.46341 .25112 .47341 .26264 .49108 .25639 .48115 .24476 Mtetra
.655 .755 .923 r
.48115 .24476 .49108 .25639 .50886 .2501 .49901 .23834 Mtetra
.658 .755 .922 r
.49901 .23834 .50886 .2501 .52676 .24376 .51699 .23177 Mtetra
.659 .752 .919 r
.51699 .23177 .52676 .24376 .54477 .23735 .53508 .2251 Mtetra
.658 .748 .916 r
.53508 .2251 .54477 .23735 .56291 .23073 .55329 .21839 Mtetra
.656 .747 .917 r
.55329 .21839 .56291 .23073 .58116 .22402 .57162 .21177 Mtetra
.654 .75 .92 r
.57162 .21177 .58116 .22402 .59953 .21737 .59008 .20516 Mtetra
.653 .752 .922 r
.59008 .20516 .59953 .21737 .61803 .21079 .60866 .19855 Mtetra
.654 .753 .923 r
.60866 .19855 .61803 .21079 .63665 .20422 .62737 .19188 Mtetra
.657 .754 .921 r
.62737 .19188 .63665 .20422 .6554 .1976 .64619 .185 Mtetra
.659 .751 .918 r
.64619 .185 .6554 .1976 .67427 .19077 .66514 .17802 Mtetra
.657 .749 .918 r
.66514 .17802 .67427 .19077 .69326 .18381 .68423 .17108 Mtetra
.655 .75 .92 r
.68423 .17108 .69326 .18381 .71238 .17692 .70344 .16417 Mtetra
.653 .751 .922 r
.70344 .16417 .71238 .17692 .73164 .17007 .72279 .15729 Mtetra
.657 .753 .92 r
.04291 .38883 .05455 .39895 .06974 .39335 .05814 .38323 Mtetra
.659 .754 .921 r
.05814 .38323 .06974 .39335 .085 .38779 .07347 .37754 Mtetra
.657 .752 .92 r
.07347 .37754 .085 .38779 .10035 .38227 .08888 .3719 Mtetra
.655 .751 .92 r
.08888 .3719 .10035 .38227 .11579 .37681 .10437 .36627 Mtetra
.653 .748 .92 r
.10437 .36627 .11579 .37681 .13132 .37126 .11995 .36071 Mtetra
.653 .749 .92 r
.11995 .36071 .13132 .37126 .14697 .36551 .13563 .35508 Mtetra
.658 .754 .921 r
.13563 .35508 .14697 .36551 .16272 .35971 .15143 .34925 Mtetra
.658 .755 .921 r
.15143 .34925 .16272 .35971 .17855 .35393 .16733 .34336 Mtetra
.658 .754 .921 r
.16733 .34336 .17855 .35393 .19448 .34816 .18332 .33746 Mtetra
.657 .752 .92 r
.18332 .33746 .19448 .34816 .2105 .34248 .19941 .33157 Mtetra
.655 .749 .919 r
.19941 .33157 .2105 .34248 .22661 .33677 .21559 .32568 Mtetra
.653 .746 .918 r
.21559 .32568 .22661 .33677 .24283 .33098 .23187 .31985 Mtetra
.653 .747 .918 r
.23187 .31985 .24283 .33098 .25917 .32504 .24825 .31397 Mtetra
.654 .75 .92 r
.24825 .31397 .25917 .32504 .2756 .31904 .26474 .30804 Mtetra
.655 .753 .922 r
.26474 .30804 .2756 .31904 .29214 .313 .28133 .30201 Mtetra
.656 .755 .922 r
.28133 .30201 .29214 .313 .30879 .30692 .29804 .2959 Mtetra
.656 .755 .923 r
.29804 .2959 .30879 .30692 .32553 .30083 .31485 .28975 Mtetra
.656 .756 .923 r
.31485 .28975 .32553 .30083 .34239 .2947 .33177 .28357 Mtetra
.33177 .28357 .34239 .2947 .35935 .28856 .3488 .27735 Mtetra
.3488 .27735 .35935 .28856 .37641 .28238 .36593 .27111 Mtetra
.656 .756 .924 r
.36593 .27111 .37641 .28238 .39359 .27619 .38318 .26483 Mtetra
.655 .756 .924 r
.38318 .26483 .39359 .27619 .41088 .26996 .40054 .25852 Mtetra
.655 .755 .923 r
.40054 .25852 .41088 .26996 .42827 .26371 .41801 .25218 Mtetra
.41801 .25218 .42827 .26371 .44579 .25743 .43559 .24579 Mtetra
.656 .755 .922 r
.43559 .24579 .44579 .25743 .46341 .25112 .45329 .23932 Mtetra
.658 .754 .921 r
.45329 .23932 .46341 .25112 .48115 .24476 .47111 .23275 Mtetra
.658 .751 .919 r
.47111 .23275 .48115 .24476 .49901 .23834 .48904 .22611 Mtetra
.658 .748 .917 r
.48904 .22611 .49901 .23834 .51699 .23177 .5071 .21942 Mtetra
.656 .747 .917 r
.5071 .21942 .51699 .23177 .53508 .2251 .52527 .21278 Mtetra
.655 .749 .919 r
.52527 .21278 .53508 .2251 .55329 .21839 .54356 .20615 Mtetra
.654 .751 .921 r
.54356 .20615 .55329 .21839 .57162 .21177 .56197 .19952 Mtetra
.653 .752 .922 r
.56197 .19952 .57162 .21177 .59008 .20516 .58051 .19286 Mtetra
.654 .754 .923 r
.58051 .19286 .59008 .20516 .60866 .19855 .59918 .18613 Mtetra
.658 .754 .921 r
.59918 .18613 .60866 .19855 .62737 .19188 .61796 .17919 Mtetra
.659 .751 .918 r
.61796 .17919 .62737 .19188 .64619 .185 .63687 .17217 Mtetra
.656 .749 .918 r
.63687 .17217 .64619 .185 .66514 .17802 .65591 .1652 Mtetra
.655 .75 .92 r
.65591 .1652 .66514 .17802 .68423 .17108 .67509 .15825 Mtetra
.653 .751 .921 r
.67509 .15825 .68423 .17108 .70344 .16417 .6944 .15133 Mtetra
.655 .753 .922 r
.6944 .15133 .70344 .16417 .72279 .15729 .71384 .1443 Mtetra
.654 .749 .92 r
.03116 .37849 .04291 .38883 .05814 .38323 .04641 .37296 Mtetra
.657 .753 .92 r
.04641 .37296 .05814 .38323 .07347 .37754 .06179 .36726 Mtetra
.659 .754 .921 r
.06179 .36726 .07347 .37754 .08888 .3719 .07726 .36148 Mtetra
.657 .752 .92 r
.07726 .36148 .08888 .3719 .10437 .36627 .09282 .35572 Mtetra
.655 .751 .92 r
.09282 .35572 .10437 .36627 .11995 .36071 .10846 .34999 Mtetra
.653 .748 .919 r
.10846 .34999 .11995 .36071 .13563 .35508 .12419 .3443 Mtetra
.653 .748 .92 r
.12419 .3443 .13563 .35508 .15143 .34925 .14003 .33858 Mtetra
.656 .752 .921 r
.14003 .33858 .15143 .34925 .16733 .34336 .15597 .33272 Mtetra
.658 .755 .921 r
.15597 .33272 .16733 .34336 .18332 .33746 .17202 .32674 Mtetra
.17202 .32674 .18332 .33746 .19941 .33157 .18817 .32073 Mtetra
.657 .753 .921 r
.18817 .32073 .19941 .33157 .21559 .32568 .20442 .31471 Mtetra
.657 .752 .92 r
.20442 .31471 .21559 .32568 .23187 .31985 .22077 .30867 Mtetra
.656 .749 .919 r
.22077 .30867 .23187 .31985 .24825 .31397 .23722 .30263 Mtetra
.654 .747 .918 r
.23722 .30263 .24825 .31397 .26474 .30804 .25377 .2966 Mtetra
.654 .746 .917 r
.25377 .2966 .26474 .30804 .28133 .30201 .27042 .29054 Mtetra
.654 .747 .918 r
.27042 .29054 .28133 .30201 .29804 .2959 .28719 .28444 Mtetra
.655 .749 .919 r
.28719 .28444 .29804 .2959 .31485 .28975 .30406 .27828 Mtetra
.655 .75 .92 r
.30406 .27828 .31485 .28975 .33177 .28357 .32104 .27207 Mtetra
.655 .751 .92 r
.32104 .27207 .33177 .28357 .3488 .27735 .33813 .26581 Mtetra
.656 .752 .92 r
.33813 .26581 .3488 .27735 .36593 .27111 .35534 .25948 Mtetra
.35534 .25948 .36593 .27111 .38318 .26483 .37265 .25311 Mtetra
.656 .751 .92 r
.37265 .25311 .38318 .26483 .40054 .25852 .39008 .24668 Mtetra
.657 .751 .919 r
.39008 .24668 .40054 .25852 .41801 .25218 .40762 .24019 Mtetra
.657 .75 .918 r
.40762 .24019 .41801 .25218 .43559 .24579 .42528 .23365 Mtetra
.657 .748 .917 r
.42528 .23365 .43559 .24579 .45329 .23932 .44306 .22705 Mtetra
.657 .747 .916 r
.44306 .22705 .45329 .23932 .47111 .23275 .46095 .22042 Mtetra
.656 .747 .917 r
.46095 .22042 .47111 .23275 .48904 .22611 .47896 .21381 Mtetra
.655 .749 .919 r
.47896 .21381 .48904 .22611 .5071 .21942 .49709 .20718 Mtetra
.654 .751 .921 r
.49709 .20718 .5071 .21942 .52527 .21278 .51533 .20052 Mtetra
.654 .752 .922 r
.51533 .20052 .52527 .21278 .54356 .20615 .53371 .19386 Mtetra
.654 .753 .923 r
.53371 .19386 .54356 .20615 .56197 .19952 .5522 .18715 Mtetra
.656 .754 .922 r
.5522 .18715 .56197 .19952 .58051 .19286 .57082 .18031 Mtetra
.658 .753 .92 r
.57082 .18031 .58051 .19286 .59918 .18613 .58957 .17333 Mtetra
.658 .75 .918 r
.58957 .17333 .59918 .18613 .61796 .17919 .60844 .16629 Mtetra
.656 .749 .918 r
.60844 .16629 .61796 .17919 .63687 .17217 .62744 .15929 Mtetra
.655 .75 .92 r
.62744 .15929 .63687 .17217 .65591 .1652 .64657 .1523 Mtetra
.653 .751 .922 r
.64657 .1523 .65591 .1652 .67509 .15825 .66583 .14533 Mtetra
.655 .753 .922 r
.66583 .14533 .67509 .15825 .6944 .15133 .68523 .13827 Mtetra
.658 .753 .921 r
.68523 .13827 .6944 .15133 .71384 .1443 .70476 .13101 Mtetra
.654 .749 .92 r
.01927 .36803 .03116 .37849 .04641 .37296 .03458 .36243 Mtetra
.03458 .36243 .04641 .37296 .06179 .36726 .04998 .3568 Mtetra
.657 .753 .921 r
.04998 .3568 .06179 .36726 .07726 .36148 .0655 .35101 Mtetra
.658 .754 .921 r
.0655 .35101 .07726 .36148 .09282 .35572 .08112 .34514 Mtetra
.657 .753 .92 r
.08112 .34514 .09282 .35572 .10846 .34999 .09682 .33927 Mtetra
.656 .751 .92 r
.09682 .33927 .10846 .34999 .12419 .3443 .11262 .33342 Mtetra
.654 .749 .919 r
.11262 .33342 .12419 .3443 .14003 .33858 .12851 .32759 Mtetra
.653 .748 .919 r
.12851 .32759 .14003 .33858 .15597 .33272 .1445 .32176 Mtetra
.654 .75 .92 r
.1445 .32176 .15597 .33272 .17202 .32674 .16059 .31587 Mtetra
.657 .754 .921 r
.16059 .31587 .17202 .32674 .18817 .32073 .1768 .30984 Mtetra
.658 .755 .922 r
.1768 .30984 .18817 .32073 .20442 .31471 .19311 .30373 Mtetra
.19311 .30373 .20442 .31471 .22077 .30867 .20952 .29758 Mtetra
.657 .754 .921 r
.20952 .29758 .22077 .30867 .23722 .30263 .22604 .29142 Mtetra
.657 .753 .921 r
.22604 .29142 .23722 .30263 .25377 .2966 .24266 .28523 Mtetra
.656 .751 .92 r
.24266 .28523 .25377 .2966 .27042 .29054 .25938 .27902 Mtetra
.656 .749 .919 r
.25938 .27902 .27042 .29054 .28719 .28444 .27621 .27278 Mtetra
.656 .748 .918 r
.27621 .27278 .28719 .28444 .30406 .27828 .29315 .26651 Mtetra
.656 .747 .917 r
.29315 .26651 .30406 .27828 .32104 .27207 .3102 .2602 Mtetra
.656 .746 .917 r
.3102 .2602 .32104 .27207 .33813 .26581 .32736 .25385 Mtetra
.32736 .25385 .33813 .26581 .35534 .25948 .34463 .24745 Mtetra
.34463 .24745 .35534 .25948 .37265 .25311 .36201 .24101 Mtetra
.656 .747 .917 r
.36201 .24101 .37265 .25311 .39008 .24668 .37951 .23453 Mtetra
.37951 .23453 .39008 .24668 .40762 .24019 .39712 .228 Mtetra
.656 .748 .918 r
.39712 .228 .40762 .24019 .42528 .23365 .41485 .22144 Mtetra
.655 .749 .919 r
.41485 .22144 .42528 .23365 .44306 .22705 .43269 .21485 Mtetra
.655 .751 .92 r
.43269 .21485 .44306 .22705 .46095 .22042 .45066 .20822 Mtetra
.655 .752 .921 r
.45066 .20822 .46095 .22042 .47896 .21381 .46874 .20158 Mtetra
.654 .753 .922 r
.46874 .20158 .47896 .21381 .49709 .20718 .48695 .1949 Mtetra
.654 .754 .923 r
.48695 .1949 .49709 .20718 .51533 .20052 .50528 .18819 Mtetra
.655 .754 .923 r
.50528 .18819 .51533 .20052 .53371 .19386 .52373 .18139 Mtetra
.658 .754 .921 r
.52373 .18139 .53371 .19386 .5522 .18715 .54231 .17444 Mtetra
.658 .751 .919 r
.54231 .17444 .5522 .18715 .57082 .18031 .56101 .16741 Mtetra
.657 .749 .918 r
.56101 .16741 .57082 .18031 .58957 .17333 .57984 .16038 Mtetra
.656 .749 .919 r
.57984 .16038 .58957 .17333 .60844 .16629 .59879 .15335 Mtetra
.655 .751 .92 r
.59879 .15335 .60844 .16629 .62744 .15929 .61788 .14634 Mtetra
.653 .752 .922 r
.61788 .14634 .62744 .15929 .64657 .1523 .63711 .13932 Mtetra
.655 .753 .922 r
.63711 .13932 .64657 .1523 .66583 .14533 .65646 .1322 Mtetra
.658 .753 .92 r
.65646 .1322 .66583 .14533 .68523 .13827 .67594 .1249 Mtetra
.658 .751 .919 r
.67594 .1249 .68523 .13827 .70476 .13101 .69556 .11755 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
[(-2)] .12586 .2075 1 .99877 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.56863 .04703 m
.57247 .05235 L
s
[(2)] .56094 .0364 .72324 1 Mshowa
.125 Mabswid
.18558 .19702 m
.18832 .19985 L
s
.23703 .17687 m
.23971 .17975 L
s
.28951 .15632 m
.29214 .15925 L
s
.39772 .11395 m
.40023 .11699 L
s
.4535 .09211 m
.45595 .0952 L
s
.51046 .06981 m
.51284 .07294 L
s
.08568 .23614 m
.08851 .23887 L
s
.62804 .02377 m
.63027 .02701 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 233.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00o?ooool2o`0006[ooooo003iooooo`?o000000?oooooo`000?ooool0
JOooool00?Oooooo0_l00004ooooo`;o0000JOooool00?Cooooo0ol00006ooooo`03o`000?oooooo
000006Sooooo003;ooooo`Go00008_ooool2o`0000Wooooo00?o0000ooooool00000J?ooool00<_o
oooo00GoV9RHob4Q8Oo^k^koooooodA4A00Oooooo`?o00002oooool01?l0003oooooooooool0001W
ooooo`00c?ooool00onHV9So8B4Qonk^kP0Mooooo`?o00003_ooool01Ol0003ooooooooooooooooo
000006Kooooo003=ooooo`03oiRHV?lQ8B7ok^k^01[ooooo0_l0000Aooooo`05o`000?oooooooooo
ooooool00000I_ooool00<kooooo00?oMgMgofIVI_ooool05_ooool3o`0001?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1Sooooo`00coooool00ol0003oooooooooo`0Cooooo`;o
00000_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0H_ooool00<_ooooo00Go0000okZj^_ooooooV9RHoa0@400Booooo`?o00006Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo06;ooooo003;ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`04?ooool2o`0001cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Qooooo`00
gOooool3o`0001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Qooooo`00fooo
ool2o`00027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Pooooo`00f?ooool3
o`0002?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Oooooo`00eOooool3o`00
02Kooooo00?o0000ooooooooool01?ooool2o`00067ooooo003Cooooo`;o0000:Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo05kooooo003@ooooo`?o000000?oooooo`000?ooool0
:?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05gooooo003>ooooo`;o00001Ooo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0GOoo
ool00<_ooooo0ol0000`ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0G?ooool0
0<Wooooo0_l0000cooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Foooool00<Ko
oooo0ol0000eooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Foooool00<Cooooo
0_l0000hooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0F_ooool00<7ooooo0ol0
000jooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03_ooool5o`0004Kooooo002n
ooooo`?o0000?Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00kooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A016ooooo`00_?ooool2o`0000?ooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo1_l00003ooooo`03oiRHV?lQ8B7o
k^k^04Oooooo002iooooo`?o0000@oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00kooooo00?oV9RHob4Q8Oo^k^h0A_ooool00;Oooooo0_l00016ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03oooool00omgMgOoIVIVooooo`15ooooo`00]?ooool3o`0004Sooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Cooooo
002booooo`;o0000Boooool00ol0003oooooooooo`0=ooooo`;o00003?ooool01Ol0003o^[Zjoooo
oonHV9So410@04Kooooo002_ooooo`?o0000COooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c016ooooo`00[Oooool2o`00053ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`1Dooooo`00Z_ooool4o`00057ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1Dooooo`00Z?ooool2o`0000Cooooo00?o0000oooo
ooooool0C_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05?ooooo001nooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h08_ooool3o`0005Oooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`1Booooo`00O_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01oooooo0ol0001Joooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool0D_ooool007kooooo00Go410@oooooooo
oooooooooa0@400Mooooo`;o0000GOooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
057ooooo001nooooo`05o`000?ooooooooooooooool000006_ooool3o`0005oooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`1@ooooo`00O_ooool01Ol0003ooooooooooooooooo0000
01Sooooo0_l0001Rooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0D?ooool007ko
oooo00Go410@oooooooooooooooooa0@400Eooooo`?o0000I?ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo04oooooo001nooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool2o`00
00?ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
04kooooo001nooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04?ooool3o`0006Sooooo00?oZ<3[o`00
0?ooool05_ooool00ol0003oooooooooo`1>ooooo`00TOooool2o`0006Sooooo1?nX`>/00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo04gooooo002>ooooo`?o0000J?ooool7ojS0j`03o`00
0?oooooooooo01Cooooo0ol0001>ooooo`00Roooool3o`0006Wooooo2OnX`>/00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo04cooooo0029ooooo`;o0000JOooool<ojS0j`03o`000?nX`>_o
oooo01Oooooo00?o0000ooooooooool0Boooool008Kooooo0ol0001Xooooo`03ojO0k?nX`>_oZ<3[
00coZ<3[00?o0000ojS0joooool06?ooool00ol0003oooooooooo`1:ooooo`00Q?ooool2o`0000;o
oooo00?o0000ooooooooool0Hoooool5ojO0k0goZ<3[00?o0000ojS0jonX`>/06?ooool00ol0003o
ooooooooo`1:ooooo`00POooool3o`0000Gooooo00?o0000ooooooooool0H?ooool8ojO0k0OoZ<3[
00?oYl3/ojS0jonX`>/00_nX`>/01?l0003oZ<3[ojS0jonX`>/Hooooo`03o`000?oooooooooo04Wo
oooo001oooooo`;o0000JOooool:ojO0k0CoZ<3[1OnW`>`3ojS0j`03o`000?nX`>_oZ<3[00;oZ<3[
6?ooool00ol0003oooooooooo`18ooooo`00O?ooool3o`0006Sooooo3_nW`>`00onX`>_oYl3/ojO0
k006ojO0k0;oZ<3[00Go0000ojS0jonX`>_oZ<3[ojO0k00Hooooo`03o`000?oooooooooo04Sooooo
001jooooo`;o0000Ioooool2ojO0jaWoYl3/0_nX`>/00ol0003oZ<3[ojO0k003ojO0k1Sooooo00?o
0000ooooooooool0Aoooool007Oooooo0ol0001Vooooo`KoYl3[6OnW`>`00onX`>_o0000ojO0k005
ojO0k1Sooooo00?o0000ooooooooool0A_ooool007Cooooo0ol0001Vooooo`03ojNojonW`>_oYl3[
00OoYl3[1_nW`>`2ojNoj`koYl3/0_nW`>/00onW`>co0000ojO0k005ojO0k1Sooooo00?o0000oooo
ooooool0A_ooool007;ooooo0_l00002ooooo`03o`000?oooooooooo06;ooooo1?nW_n/9ojO0j`;o
Yl3/1_nW_n/:ojO0k0KoYl3[00?o0000ojO0k?nW`>`01OnW`>`Hooooo`03o`000?oooooooooo04Go
oooo001_ooooo`?o0000Ioooool7ojNoj`OoYl3[2_nW_n/6ojO0k003ojNojonW`>_oYl3[00KoYl3[
00?o0000ojO0k?nW`>`01OnW`>`Hooooo`03o`000?oooooooooo04Gooooo001]ooooo`;o0000Iooo
ool2ojRoj`SoYko[1?nW`>/>ojNoj`;oYl3/1OnW_n/7ojO0j`03o`000?nW`>_oYl3/00KoYl3/5ooo
ool2o`0004Kooooo001Zooooo`?o0000I_ooool6ojRoj`SoYko[00?oYl3[ojNojonW_n/05_nW_n/6
ojO0j`03o`000?nW_n_oYl3/00OoYl3/6?ooool00ol0003oooooooooo`13ooooo`00J?ooool2o`00
06Kooooo0_nX`>/8ojRoj`KoYko[0_nX_n/IojNoj`;oYl3[0onW_n/00ol0003oYko[ojNoj`08ojO0
k1Oooooo00?o0000ooooooooool0@oooool006Gooooo0ol0001Uooooo`KoZ<3[2?nX_n/2ojNoj`Ko
Z;o[5onW_n/00onX_n_oYko[ojNoj`03ojNoj`04o`000?nW_n_oYko[ojNoj`KoYl3/00?oYl3[oooo
ooooool05_ooool00ol0003oooooooooo`12ooooo`00Hoooool2o`0006Gooooo00?oZ<7[ojS0jonX
`>/01onX`>/6ojRoj`03ojS0jonX_n_oZ;o[00OoZ;o[1_nW_n/00onX`>_oYko[ojNoj`0;ojNoj`Co
Z;o[1OnW_n/01?l0003oYko[ojNojonW_n/2ojO0k0GoYl3[6?ooool00ol0003oooooooooo`11oooo
o`00H?ooool3o`000003ooooool0003ooooo06;ooooo1?nX`N/9ojS0j`;oZ;o[1OnX`>/9ojRoj`;o
Yko[1OnX`>/:ojNoj`OoZ;o[1?nW_n/01?l0003oYko[ojNojonW_n/8ojO0jaOooooo00?o0000oooo
ooooool0@Oooool003Kooooo1Ol0000Sooooo`;o0000I_ooool7ojS1j`OoZ<3[00?oYl7/ojS0jonX
`>/01_nX`>/6ojRoj`;oZ<7[2?nX`>/6ojNoj`;oZ<3[2?nX_n/4ojNoj`03o`000?nW_n_oYko[00;o
Yko[2?nW`>/Gooooo`03o`000?oooooooooo043ooooo000fooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@08?ooool3o`0006Gooooo0_nW`N`8ojS1j`CoZ<3[1OnW`N`8ojS0j`;oZ;o[1_nX`N/8ojS0j`;o
Yko[1_nX`>/8ojRoj`?oYko[00?o0000ojNojonW_n/00onW_n/6ojO0j`03ojNojooooooooooo01Ko
oooo00?o0000ooooooooool0?oooool002kooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^01kooooo
0ol0001Uooooo`KoYl7/2?nX`N/00onX`>_oYl7/ojO1k006ojO1k0KoZ<3[00?oYl7/ojS1jonX`N/0
1onX`N/6ojS0j`03ojS1jonX`>_oZ<3[00OoZ<3[1_nX_n/01OnX`>_oYko[ojNojonW_n_o000000Go
Yko[1?nW`>/4ojNojaOooooo00?o0000ooooooooool0?oooool003Sooooo00?oV9RHob4Q8Oo^k^h0
6oooool2o`0006Gooooo2_nW`N`6ojS1j`;oYl3/2?nW`N`4ojS0j`CoYl7/2OnX`N/2ojS0j`GoZ<7[
2OnX`>/2ojRoj`GoZ<3[0_nW_n/00ol0003oYko[ojNoj`04ojNoj`03ojO0jonW_n_oYko[00GoYko[
5oooool00ol0003oooooooooo`0nooooo`00>Oooool00omgMgOoIVIVooooo`0Gooooo`?o0000I?oo
ool>ojO1k0;oZ<7[1_nW`>`8ojO1k003ojS0jonW`NcoYl7/00GoYl7/1onX`N/00onW`>coZ<7[ojS1
j`06ojS1j`KoZ<3[0_nX`N/8ojS0j`03ojNojol0003oYko[00?oYko[0_nX`>/8ojNojaSooooo00?o
0000ooooooooool0?Oooool003[ooooo00?o0000ooooooooool05?ooool2o`0006Cooooo00?oYl3/
ojO1k?nW`N`03OnW`N`:ojO0k0KoYl7/00?oYl3/ojO1k?nW`N`01onW`N`4ojS1j`CoYl3/2?nX`N/2
ojS0j`KoZ<7[2?nX`>/00ol0003oYko[ojS0j`05ojS0j`SoYko[5oooool00ol0003oooooooooo`0m
ooooo`00=_ooool01Ol0003o^[ZjoooooonHV9So410@01?ooooo0ol00002ooooo`03o`000?oooooo
oooo05oooooo1?nW`>`;ojO1k0koYl3/0_nW`N`5ojO0k0WoYl7/00?oZ<7[ojO0k?nW`>`01OnW`>`6
ojS1j`03ojO0k?nX`N_oZ<7[00OoZ<7[1_nX`>/00onX`N_o0000ojS0j`07ojS0j`KoYko[00?oZ;o[
ooooooooool05_ooool00ol0003oooooooooo`0looooo`00=_ooool01OnHV9So410@o`000?lQ8B7o
c<c<017ooooo0_l0001Uooooo`OoYl3/1onW`N`00onW`>_oYl3/ojO0k00<ojO0k0;oYl3[2?nW`>`6
ojO1k0[oYl3/1?nX`N/4ojO0k0WoZ<7[0_nX`>/4ojS1j`03o`000?nX`>_oZ<3[00OoZ<3[0_nW_n/5
ojRojaKooooo0ol0000mooooo`00BOooool3o`0006Gooooo00?oYl3[ojO0k?nW`>`01onW`>`4ojO1
k0CoYl3[2_nW`>`6ojO0j`SoYl3/0_nW`N`>ojO0k003ojS1jonW`>coYl3/00GoYl3/1onX`N/00onW
`>coZ<7[ojS1j`04ojS1j`03o`000?nX`N_oZ<3[00GoZ<3[0_nX`N/8ojRojaOooooo00?o0000oooo
ooooool0>oooool004Oooooo0_l0001Uooooo`GoYl3[2OnW`>`00onW`NcoYl3[ojO0j`05ojO0j`Ko
Yl3/0_nW_n/8ojO0j`KoYl3/00?oYko[ojO0k?nW`>`05_nW`>`4ojS1j`GoYl3/1OnX`N/00ol0003o
Z<7[ojS1j`02ojS0j`KoZ<7[2?nX_n/Gooooo`03o`000?oooooooooo03[ooooo0014ooooo`?o0000
I?ooool9ojO0j`KoYl3/0_nW_n/8ojO0j`CoYl3/1OnW_n/8ojO0j`;oYl3/1OnW_n/HojO0k003ojS1
jonW`>coYl3/00KoYl3/1?nX`N/00ol0003oZ<7[ojO0k009ojS1j`KoZ;o[00?oZ<3[ooooooooool0
5_ooool00ol0003oooooooooo`0iooooo`00@Oooool3o`0006Cooooo3OnW`>/2ojO0k0KoYko[2?nW
`>/00onW`>coYko[ojNoj`06ojNoj`KoYl3[00?oYkoZojNojonW_n/01_nW_n/6ojO0k0;oYko[6OnW
`>`2ojS1j`03ojO0k?l0003oYl3/00;oYl3/2OnX`N/2ojRoj`GoZ<3[5oooool00ol0003ooooooooo
o`0iooooo`00?oooool3o`0006?ooooo00?oYko[ojO0jonW`>/03?nW`>/2ojNojPSoYko[1_nW`>/2
ojNojPWoYko[0_nW`>/5ojNojPSoYko[0_nW`>`6ojNoja_oYl3/00?o0000ojO0k?nW`>`00_nW`>`6
ojS1j`;oYl3/2?nX`>/Gooooo`03o`000?oooooooooo03Sooooo000looooo`?o00000oooool00ol0
003oooooooooo`1Mooooo`GoYko[2_nW`>/6ojNojPSoYko[0_nW`>/6ojNojPOoYko[00?oZ;oZojNo
j_nW_nX01_nW_nX6ojNoj`;oZ;oZ2?nW_n/6ojO0k003ojNojonW`>coYl3/017oYl3/00?o0000ojO0
k?nW`>`00onW`>`2ojS1j`KoYl3/2?nX`>/Fooooo`03o`000?oooooooooo00Oooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0/ooooo`00>_ooool2o`0006?ooooo2OnW_n/6ojO0j`;oZ;oZ2?nW_nX6ojNo
j`03ojRoj_nW_n[oYkoZ00OoYkoZ1?nW_n/4ojRojPSoYkoZ0_nW_n/6ojRojPSoYko[0_nW`>`5ojNo
ja;oYl3/00?o0000ojO0k?nW`>`00_nW`>`00onV`>coYl3/ojO0k007ojO0k0KoZ<3[00?oZ<7[oooo
ooooool05Oooool00ol0003oooooooooo`06ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0;?ooool0
03Oooooo0ol0001Sooooo`coYko[0_nW`>/6ojRojPSoYkoZ0_nW_n/5ojRojPWoYkoZ00?oYko[ojRo
j_nX_nX01OnX_nX6ojNojP03ojS0jonX_n[oZ;oZ00OoZ;oZ1_nW_n/00onX_n[oYko[ojNoj`06ojNo
j`KoYl3/0_nW_n/:ojO0k003o`000?nW`>coY/3/00?oY/3/2OnW`>`2ojS0j`GoZ<7[5oooool00ol0
003oooooooooo`05ooooo`05oa0@4?ooooooooooooooool@4100;?ooool003Gooooo0_l0001Toooo
o`goYko[2_nX_nX6ojNojP03ojS0jonX_n[oZ;oZ00KoZ;oZ1_nW_nX2ojS0j`SoZ;oZ1?nW_nX4ojS0
j`WoZ;oZ0_nW_n/5ojRojPSoYko[0_nW`>`6ojNoj`WoYl3/00?o0000ojK0k?nV`>`01?nV`>`6ojO0
k0;oY/3/2?nX`N/Fooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`00000/
ooooo`00<_ooool3o`0006Cooooo00?oYkoZojNojonW_n/02_nW_n/=ojRojP;oYkoZ1OnX`>/8ojRo
jP;oYkoZ1_nX`>/8ojRojP03ojNoj_nX`>_oZ<3[00GoZ<3[1onX_nX00onX`>_oZ;oZojRojP06ojRo
jPKoYko[00?oZ;oZojNojonW_n/01onW_n/6ojO0k003ojNojonV`>co000000OoY/3/0_nW`>`6ojK0
k0SoZ<7[5_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000;?ooool0
033ooooo0_l0001Tooooo`GoYkoZ2OnW_n/>ojRojP03ojS1jonX`>_oZ<3[00KoZ<3[1_nX_nX2ojS1
k0SoZ<3[1_nX_nX00onX`N_oZ<3[ojS0j`06ojS0j`CoZ;oZ1OnX`>/8ojRojP;oYko[1OnX_nX9ojNo
j`;oYl3/1OnW_n/00ol0003oY/3/ojK0k004ojK0k003ojO0jonV`>coY/3/00KoY/3/1_nX`N/2ojO0
k1Oooooo00?o0000ooooooooool00oooool01Ol@413ooooooooooooooooo410@02cooooo000]oooo
o`?o000000?oooooo`000?ooool0H?ooool9ojNojPKoYko[0_nX_n/<ojRojPCoZ<7[2?nX`>/2ojRo
jPKoZ<7/2?nX`>/2ojRojPGoZ<7[2?nX`>/00onX_n[oZ<3[ojS0j`06ojS0j`KoZ;oZ00?oZ<3[ojRo
j_nX_nX01_nX_nX6ojNoj`;oZ;oZ1onW_n/00ol0003oY/3/ojK0k002ojK0k0CoYl3[2?nV`>`2ojS1
j`KoYl3/5_ooool2o`0000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0/ooooo`00:_ooool3o`00
06?ooooo3OnW_nX2ojNoj`KoZ;o[2OnX_nX7ojS1j`KoZ<3[0_nW`N`8ojS1k0KoZ<3[00?oYl7/ojS1
jonX`N/01_nX`N/6ojS0j`;oZ<7/2OnX`>/2ojRojPGoZ<3[2?nX_nX2ojNoj`KoZ;oZ1_nW_n/00ol0
003oYko[ojK0k007ojO0j`KoY/3/2_nW`>`Cooooo`;o000000?oooooo`000?ooool00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02cooooo000Xooooo`;o0000Hoooool00onW_^[oYkoZojNojP0<ojNo
jP;oZ<3[2?nX_n/6ojRojP03ojO1k?nX`N_oZ<7[00OoZ<7[0_nX`>/6ojO1k0SoZ<7/0_nX`>/5ojO1
k0SoZ<7[0_nX`>/6ojS1k0OoZ<3[00?oYl7/ojS0jonX`>/01_nX`>/6ojRojP03ojS0jonX_n[oZ;oZ
00OoZ;oZ1OnW_n/00ol0003oZ;o[ojO0j`08ojO0j`;oY/3/3_nW`>`Fooooo`03o`000?oooooooooo
03;ooooo000Uooooo`?o0000H_ooool5ojNnjP[oYkoZ1_nX`>/8ojRoj`;oZ;oZ1OnW`N`7ojS1j`[o
Yl7/1_nX`N`9ojO1k0KoZ<7[00?oYl7/ojS1k?nX`N`01onX`N`4ojS0j`CoYl7/2?nX`>/2ojRojPGo
Z<3[2OnX_nX2ojNoj`03ojRojol0003o000000;oZ;o[1onW`>/00onW_n_oYl3/ojO0k00<ojO0k0;o
Y/3/5_ooool00ol0003oooooooooo`0booooo`008oooool2o`0006;ooooo2OnW_^X6ojNojP;oYl3[
2?nX`>/6ojRoj`WoYl7/1?nX`N/=ojO1k0;oZ<7/3OnW`N`2ojS1j`GoYl7/2OnX`N`00onX`>_oYl7/
ojO1k005ojO1k0KoZ<3[00?oYl7/ojS0jonX`>/01_nX`>/6ojRojP;oZL3[0ol000000onX_n_o0000
ojRoj`02ojRoj`CoYl3[1?nW_n/:ojO0k0KoY/3/5_ooool00ol0003oooooooooo`0aooooo`008?oo
ool3o`00067ooooo3OnW_^X2ojNojPKoYl3[2?nX`>/2ojRoj`goYl7/00?oZ<7[ojO1k?nW`N`09?nW
`N`6ojS1k0_oYl7/0_nX`>/5ojO1k0SoZ<3[0_nX_nX2ojW0j`?o000000?oZL3[ojRojonX_n/00_nX
_n/01Ol0003oZ;o[ojRojonX_n_oYl3[00OoYko[1_nW`>`00onW_n_oY/3/ojK0k006ojK0k1Oooooo
00?o0000ooooooooool0<?ooool001oooooo0_l0001Pooooo`ooYkkZ2_nW`>/6ojS0jcSoYl7/0_nX
`N`=ojO1k003ojK0k?nW`NcoYl7/00KoYl7/1_nX`>/00onW`NcoZL3[o`000002o`0000CoZL3[1OnX
_n/00ol0003oZL3ZojW0jP09ojNoj`;oYl3/1OnW_n/8ojK0k1Kooooo00?o0000ooooooooool0<?oo
ool001oooooo00?o0000ooooool00000GOooool>ojNnjPkoYl3[0_nX`>/LojO1k003ojO0k?nW`Nco
Yl7/00coYl7/00?oYl3/ojO1k?nW`N`03?nW`N`2ojK0k0coYl7/1?nV`>`8ojO1k0;oZ<3[0_nW`N`3
o`0000SoZL3[0_nX_n/3ojW0jP03o`000?nY`>[oZL3Z00OoYko[00?oZ;oZojNojonW_n/01_nW_n/7
ojK0k1Oooooo00?o0000ooooooooool0;oooool000cooooo1Ol00003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01_ooool01?l0003oooooooooool0001Jooooo`goYkkZ4?nW`>/LojO1k0GoYl3/2_nW
`N`5ojO0k0[oYl7/1_nV`>`9ojO1k0OoY/3/1_nW`N`00onV`>coYl7/o`000002o`0000CoYl7/1_nY
`>/00onX`N_oZL3ZojW0jP03ojW0jP04o`000?nY`>[oZL3ZojW0jPCoYko[1?nX_nX8ojNoj`OoY/3/
5oooool00ol0003oooooooooo`0^ooooo`003?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`;o00000_ooool00ol0003oooooooooo`1Eooooo`;o
YkoZ2onW_^X?ojO0jacoYl7/00?oYko[ojO0k?nW`>`01_nW`>`6ojO1k003ojNojonW`>coYl3/00Ko
Yl3/1_nW`N`00onW_n_oY/3/ojK0k007ojK0k0KoYl7/2_nV`>`2ojO1k0;oY/3/0ol00008ojO1k0;o
ZL3[1OnX`N/5ojW0jP05o`000?nY`>[oZL3ZojW0j_nW_n/01onX_nX7ojNoj`SoY/3/5_ooool00ol0
003oooooooooo`0^ooooo`001?ooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413o
oooooooooooooooo410@00Gooooo0_l00004ooooo`03o`000?oooooooooo057ooooo1_nW_nX9ojNn
jPgoYl3[7OnW`N`4ojNoj`SoYl3/0_nW`N`5ojNoj`SoYl3/0_nW`N`5ojNoj`WoY/3/0_nW`N`>ojK0
k0?o00001?nV`>`6ojO1k003ojK0k?nX`N_oZ<7[00KoZ<7[1OnY`>X00ol0003oZL7[ojW1j`09ojRo
jPOoYko[2?nV`>`Fooooo`03o`000?oooooooooo02gooooo000>ooooo`03oiRHV?lQ8B7ok^k^00?o
oooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0COooool2ojNoj`SoYkoZ1_nW_^X<ojO0jakoYl7/1onW_n/6ojO0k003ojNnj_nW_n_oYko[
00KoYko[1_nW`>`00onW_^[oYko[ojNoj`06ojNoj`KoY/3/0_nW_^X>ojK0k0;o00002?nV`>`2ojO1
k0GoY/3/2?nX`N/2ojW0jP;oZL7[00Co0000ojW1jonY`N_oZL7[1onX_nX00onY`>_oYko[ojNoj`06
ojNoj`KoY/3/00?oYko[ooooooooool05Oooool00ol0003oooooooooo`0/ooooo`003oooool00omg
MgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo04Wooooo1_nW_n/8ojNojP;oYkkZ3?nW`>/OojO1k003ojNnj_nW_n_o
Yko[00OoYko[0_nW`>`5ojNnjPSoYko[0_nW`>`5ojNnjPSoYko[0_nV`>`6ojNnjPOoY/3/00?oYkkZ
ojK0k?nV`>`00ol0000BojK0k0KoZ<7[00?oYl3/ojW1jonY`N/00onY`N/00ol0003oZL7[ojW1j`04
ojRojPGoZL3[2?nW_n/2ojK0k0GoYko[5Oooool2o`0002kooooo000@ooooo`05o`000?oooooooooo
ooooool@41000oooool00ol@413oooooooooo`03ooooo`;o00001oooool00ol0003oooooooooo`16
ooooo`WoYko[1_nW_nX00onW_n_oYl3[ojO0j`09ojO0jaooYl7/1OnW_^X7ojNoj`03ojRnjOnW_^[o
YkkZ00KoYkkZ1_nW_n/00onX_n[oYkkZojNnjP06ojNnjPKoYko[0_nX_nT8ojNnjPCoY/3/0_nW_^X3
o`0001KoY/3/0_nX`N/5ojO0k0GoZL7[00Co0000ojW1jonY`N_oZ;oZ2?nY`>/6ojNoj`03ojRojonW
_n_oYko[00KoYko[5_ooool00ol0003oooooooooo`0[ooooo`003?ooool01Ol0003o^[ZjoooooonH
V9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0@_ooool=ojNoj`;oYkoZ1OnW_n/7ojO0j`ooYl7/0_nW`>`>ojO1k0WoYkkZ
1?nW_n/4ojRnj@SoYkkZ0_nW_n/5ojRojPSoYkkZ0_nW_n/6ojRoj@SoYkkZ00?oY/3/ojNnj_l00000
0_l00003ojNnjPKoY/3/00?oYkkZojK0k?nV`>`03OnV`>`8ojO0k0GoZL7[00?o0000ojO0jonY`>/0
2OnY`>/2ojNoj`GoZ;o[2?nW_n/Eooooo`03o`000?oooooooooo02_ooooo000<ooooo`05oiRHV?l@
413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0nooooo`;oYl3[5_nW_n/4ojO0j`koYl7/1_nW`>`:ojO1k0go
YkkZ00?oYko[ojRnjOnX_^T01OnX_^T6ojNnjP03ojS0jonX_n[oZ;oZ00KoZ;oZ1_nW_^X2ojW0j`So
Z;oY1_nW_^X3o`0000OoYkkZ0_nV`>`5ojNnjPooY/3/2?nW`>`2ojW1j`;oYl3[00?o0000ojO0jonW
`>/02?nY`>/00onX`N_oZ;o[ojRoj`05ojRoj`SoYko[5_ooool00ol0003oooooooooo`0Zooooo`00
7_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03[ooooo1_nW`>/FojNoj`03ojO0
jonW`NcoYl7/00coYl7/2OnW`>`6ojO1k0ooYkkZ00?oZ;oZojRnjOnX_^T01onX_^T2ojNnjPGoZ<3[
2?nX_nX2ojNnjPKoZL3[2?nX_nT2ojNnjP?o00000onY_nX6ojNnjP03ojVoj_nW_^[oYkkZ00KoYkkZ
1_nV`>`00onW_n_oY/3/ojK0k006ojK0k0KoYl3/00?oY/3/ojO0jonW`>/00onW`>/00ol0003oYl3[
ojO0j`04ojW0j`GoZ<7[1onX_n/8ojNojaKooooo00?o0000ooooooooool0:Oooool001gooooo0ol0
000;ooooo`03o`000?oooooooooo03Kooooo0_nX`>/8ojO0jaCoYko[3OnW`N`=ojO0k0;oYl7/3onW
_^X5ojRojPOoZ;kY0_nX`N/7ojS0j`KoZ;oZ0_nX`N`8ojW0j`KoZ;oY0ol00007ojVojP;oYkkZ1OnY
_nX8ojNnjP;oY/3/1OnW_n/8ojK0k0;oYl3/1OnV`>`5ojO0j`04o`000?nW`>_oYl3[ojW0j`OoZ<7[
1_nX_n/00onY`>_oYko[ojNoj`06ojNojaKooooo00?o0000ooooooooool0:Oooool001gooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0booooo`KoZ<3[2?nW`>/@ojNoj`koYl7/3_nW
`>`?ojNnjP03ojRojonX_n[oZ;oZ00KoZ;oZ1?nX_^T5ojS1j`OoZ<3[0_nX_nX6ojS1k0SoZL3[0_nX
_nT3o`0000;oZL7[1onY_nX00onX`N_oZKoZojVojP06ojVojPKoYkkZ00?oZKoZojNojonW_n/01_nW
_n/6ojK0k003ojJojonV`>coY/3/00KoY/3/1OnW`>/00ol0003oYl3/ojO0k008ojS1j`;oZ;o[1OnY
`>/8ojNojaKooooo00?o0000ooooooooool0:?ooool001gooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0_ooooo`03ojS1jonX`>_oZ<3[00KoZ<3[1_nW`>/00onW_^[oYko[ojNoj`0<
ojNoja7oYl7/2_nW`>`?ojNnjPGoZ;o[2?nX_nX00onX_^WoZ<7[ojS1j`06ojS1j`GoZ<3[0_nW`N`8
ojS1k0KoZL3[0ol00006ojW1j`CoZKoZ1?nX`N/8ojVojP;oYkkZ1OnY_nX8ojNoj`;oY/3/1OnV_n/8
ojK0k0;oYl3[0_nW`>`01?l0003oYl3/ojO0k?nW`>`6ojS1j`03ojS0jonY`>_oZL3[00KoZL3[1_nW
_n/00onX_n_oooooooooo`0Eooooo`03o`000?oooooooooo02Oooooo000Mooooo`;o00003oooool0
0ol0003oooooooooo`0[ooooo`GoZ<7[2?nX`>/2ojO0j`GoYkkZ2_nW_n/<ojO1k0;oZ<7/1onW`N`6
ojO0k0ooYkkZ0_nX`>/7ojRoj`KoZ;oZ0onW`N`8ojS1j`03ojS0jonW`NcoYl7/00CoYl7/2?nX`N`2
ojW0j`03ojO1k?l0003o000000;oYl7/2?nY`N/00onY_n[oZ<7[ojS1j`05ojS1j`KoZKoZ00?oZL7[
ojVoj_nY_nX01_nY_nX6ojNoj`03ojRoj_nV_n_oY[o[00KoY[o[2?nV`>`4ojO0k004o`000?nW`>co
Yl3/ojO0k0;oZ<7[1OnX`>/8ojW0j`;oYko[1OnX_n/Fooooo`03o`000?oooooooooo02Oooooo000M
ooooo`03o`000?oooooooooo00oooooo0_l0000Xooooo`;oZ<7/1onX`N/6ojS0j`;oYko[1onW_^X6
ojNoj`coYl7/1_nX`N`7ojO1k0;oYl3/3onW_^X6ojS0j`OoZ;o[0_nX_nX7ojO1k0KoZ<7[00?oYl;]
ojO1k?nW`N`01_nW`N`6ojS1k004ojO1kOl0003o0000o`0000GoYl7/1_nY`N/2ojO1k0SoZ<7[0_nY
_nX5ojW1j`SoZKoZ0_nW_n/5ojRojPSoY[o[2?nV`>`4ojO0k003o`000?nW`>coY/3/00SoZ<3[1onY
`>/8ojRojaKooooo00?o0000ooooooooool09_ooool001gooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`0Rooooo`KoZ<7/1onX`N/2ojS0j`KoYko[1onW_^X2ojNoj`coYl7/2_nX`N`5
ojO1k0ooYkkZ0_nW`>/8ojS0j`GoZ;o[2onW`N`2ojS1j`GoYl;]2?nW`N`2ojS1k005ojO1kOl0003o
0000o`000?nW`Nd02?nW`N`2ojW1j`KoYl7/1_nX`N/00onW`NcoZL7[ojW1j`06ojW1j`KoZKoZ00?o
ZL7[ojRoj_nX_nX01_nX_nX6ojJoj`;oYko[2?nV`>`2ojO0k0;oY/3/00?o0000ojK0k?nV`>`02?nX
`>/7ojW0j`SoZ;o[5_ooool00ol0003oooooooooo`0Uooooo`007Oooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo01kooooo2_nX`N`5ojS1j`[oYko[1OnW_^X2ojO0k0_oYl7/3OnX`N`0
0onW`NcoYkkZojNnjP0=ojNnjPKoYl3[2?nX`>/00onX_n_oYl7/ojO1k00;ojO1k0WoYl;]1_nW`N`0
1?nV`Ngo0000o`000?l00005ojO1k@KoYl7/0_nV`Nd8ojO1k0;oZ<7[1OnW`N`8ojW1j`;oZKoZ1OnY
`N/8ojRojP;oY[o[1_nW_n/6ojK0k003ojJojonV`>coY/3/00;oY/3/00Co0000ojK0k?nV`>coY/3/
1_nX`>/00onW`>coZL3[ojW0j`06ojW0j`KoZ;o[00?oZ<3[ooooooooool05?ooool2o`0002Kooooo
000Looooo`?o00005?ooool00ol0003oooooooooo`0Kooooo`goZ<7/00?oZ<7[ojNojonW_n/03?nW
_n/00onW_^[oYl3/ojO0k004ojO0k0WoYl7/3OnX`N`?ojNnjPWoYl3[1_nX`>/2ojO2k0[oYl7/3OnW
`^d2ojO1k005ojK1kOl0003o0000o`000?nV`Nd02?nW`Nd2ojO1k0KoY/7]1_nW`N`00onV`NgoYl7/
ojO1k006ojO1k0KoZL7[00?oYl7/ojW1jonY`N/01_nY`N/6ojRojP03ojW0j_nW_n_oYko[00OoYko[
0_nV`>`5ojJoj`CoY/3/00Co0000ojK0k?nV`>coY/3/0_nX`>/5ojO0k0SoZL3[0_nX_n/5ojS0jaCo
oooo00?o0000ooooool000009_ooool001cooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`0Iooooo`goZ<7/0_nX`>/>ojNoj`SoYl3/1_nW`N`<ojS1k0ooYkkZ3OnW`>/2ojS0j`KoYl;/
1_nW`N`00onW`NgoYl;]ojO2k@0<ojO2k@04ojJok?l0003o0000o`0000GoY/7]1_nW`Nd2ojK0k0So
Y/7]0_nW`N`5ojK1k@SoYl7/0_nY`N/5ojO1k0SoZL7[0_nX_nX5ojW0jPOoYko[00?oZKoZojJojonV
_n/01_nV_n/4ojK0k003o`000?nV`>coY/3/00SoYl3/1_nY`>/00onX`N_oZ<3[ojS0j`06ojS0jaKo
oooo00?o0000ooooooooool08oooool000[ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`00
0?lb<S;ok^k^1_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01Kooooo0onX`N/9
ojS1k0KoZ<3[3_nW_n/8ojO0k0;oYl7/3?nX`N`00onW_n[oYkkZojNnjP0<ojNnjPooYl3[0_nW`^d8
ojO2k0;oYl7/1OnW`Nd:ojO2k@05ojJok?l0003o0000o`000?nV_n`02?nV`Nd2ojO1k@KoY/3/1_nV
`Nd00onV_n_oY/7]ojK1k@06ojK1k@KoYl7/00?oY/7]ojO1k?nW`N`01_nW`N`6ojW1j`03ojS1k?nY
`>[oZL3Z00KoZL3Z1?nW_n/4ojVojPSoY[o[0onV`>`01?l0003oY/3/ojK0k?nV`>`8ojO0k0;oZL3[
1OnX`N/8ojS0jaGooooo00?o0000ooooooooool08oooool000cooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`0Booooo`OoZ<7[1OnX`N`:ojS0j`koYko[1_nW`>`<ojS1k0GoYkoZ2_nW_^X?ojO0j`KoYl;]
1_nW`^`00onW`NcoYl7]ojO1k@06ojO1k@KoYl;]00CoYkkZo`000?l0003o00001OnV_n`6ojK1k@;o
Y[gZ2?nV`>`2ojK1k@GoY[o[2?nV`Nd2ojO1k0GoY/7]2?nW`N`2ojW1j`GoZ<7/2?nY`>X00onW_n_o
ZKoZojVojP05ojVojPKoY[o[00?oYko[ojK0k?nV`>`00_nV`>`01?l0003oY/3/ojK0k?nV`>`6ojO0
k003ojK0k?nX`N_oZ<7[00GoZ<7[2?nX`>/Fooooo`03o`000?oooooooooo02;ooooo00000ooooooo
0000o`000004o`0000Gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@
00Kooooo0_l0000Iooooo`03o`000?oooooooooo00kooooo0onW_n/8ojS1j`03ojS1k?nX`>_oZ<3[
00coZ<3[3_nW_n/2ojO0k0coZ<7/0_nX_n/7ojNojPKoYkkZ0_nW_n/=ojO0j`;oYl;/2?nW`^d2ojO2
k0GoYl7/2?nW`Nd2ojO2k@;oYkkZ0_l000000onW_^[oY[o/ojJok006ojJok0;oY/7]1_nV_NX6ojK0
k003ojNmjOnV_n_oY[o[00KoY[o[1_nV`Nd00onV_^_oY/7]ojK1k@06ojK1k@KoYl7/00?oY/7]ojS1
k?nX`N`01_nX`N`6ojW0jP;oZL7[2?nY_nX2ojJoj`GoYko[1?nV`>`01?l0003oY/3/ojK0k?nV`>`2
ojO0k0GoY/3/1onX`N/8ojS0jaKooooo00?o0000ooooooooool08Oooool000cooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0:ooooo`OoYko[1onX`N/>ojS0j`03ojNnjonW_n_oYko[00_oYko[3?nX`N`6
ojRoj`OoYkoZ0_nW_^X6ojNoj`WoYl3[1_nW`^`6ojO2k@WoYl7/1_nW`Nd00onW_NWoYkkZo`000002
o`0000CoYkkZ1_nV_n`2ojRmj@SoY[gZ0_nV`>`5ojNmj@SoY[o[0_nV`Nd5ojJnj`SoY/7]0_nW`N`5
ojK1k@SoZ<7/0_nY`>X6ojW1j`KoZKoZ00?oZL3ZojNojonW_n/01OnW_n/5ojK0k003o`000?nV_nco
Y[o/00OoY/3/1_nX`N/:ojS0jaGooooo00?o0000ooooooooool08Oooool000cooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`07ooooo`[oYko[1onX`N/:ojS0j`GoYkk[2OnW_n/=ojS1k003ojS0jonX_n_o
Z;o[00KoZ;o[1OnW_nX2ojNnj`SoYko[1OnW`>/:ojO2k0;oYl;]3OnW`N`2ojO1k@;oYkgY0ol00008
ojNnjP;oY[o/1_nX_NT6ojJmjP03ojVojOnW_NWoYkgY00KoYkgY1_nV_n/00onX_^WoY[k[ojJnj`06
ojJnj`KoY/7]0_nU_n`7ojK1k@KoZ<7/0_nV`N`8ojW1j`;oZKoZ1OnY`>X7ojNoj`;oY/3/0_nV_n`0
1?l0003oY[o/ojJok?nV_n`7ojK0k0;oZ<7[3?nX`>/00onY`>_oooooooooo`0Dooooo`03o`000?oo
oooooooo023ooooo000<ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4005ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool00oooool<ojNoj`WoZ<7[1_nX
`>/2ojNoj`OoYkk[1_nW_n/<ojS1k0GoZ<3[2?nX_n/00onW_n[oYkk[ojNnj`04ojNnj`SoYko[00?o
Yl3[ojO2k?nW`^`02_nW`^`?ojO1k0;oYkgY0ol00004ojNmj@KoYkkZ00?oZKkYojRmjOnX_NT01onX
_NT2ojJmjPGoZKoY2?nW_NT2ojJoj`GoZ;kY2?nV_^/2ojK1k@KoYKo/1onV`Nd2ojS1k0KoY/7/1_nY
`N/00onX`N_oZL3ZojW0jP05ojW0jPKoYko[00?oZ;o[ojJok?nV_n`00onV_n`00ol0003oY[o/ojJo
k006ojK0k0;oY[o/2_nX`>/5ojW0jaKooooo00?o0000ooooooooool07oooool000cooooo00?o0000
ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_l0000Nooooo`03o`000?oo
ooooYko[00_oYko[3OnX`N/2ojS0j`KoYko[1onW_^/2ojNoj`koZ<7/1onX`>/6ojRoj`03ojNnj_nW
_^_oYkk[00KoYkk[1_nW_n/2ojO1k0WoYl;/3onW`N`2ojNmj@?o00002?nW_NT2ojNnjPGoZKkY1onX
_NT00onY`N_oZKoYojVoj@06ojVoj@KoYkgY00?oZ/3ZojRnjOnX_^T01_nX_^T6ojJnj`;oZ;kY2?nU
_n`3ojK1k@CoYL3/2?nV`N`2ojW1j`GoZ<7[1onY`>X2ojNoj`GoZ;o[1OnV_n`00ol0003oY[o/ojJo
k002ojK0k0KoY[o/1onX`>/8ojW0jaGooooo00?o0000ooooooooool07oooool000[ooooo00?oEEEE
ofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool07?oo
ool=ojNoj`;oYl3[3?nX`N/2ojS0j`SoYko[1OnW_^/3ojNoj`ooZ<7/1onX`>/2ojRoj`GoYkkZ2?nW
_^/2ojNoj`KoYl7/1_nW`^`00onX`NcoYl7/ojO1k00<ojO1k004ojRmjOl0003o0000o`0000[oYkgY
0_nX_nX7ojVnj@CoZ;gY1?nY`N/8ojVoj@;oYkgY1OnZ`>X8ojRnj@;oY[k[1_nX_^T6ojFok003ojNn
j_nU`>coYL3/00KoYL3/1_nV`N`00onV`>coZ<7[ojS1j`05ojS1j`KoZL3Z00?oZL7[ojRojonX_n/0
1_nX_n/5ojJok003o`000?nV_ncoY[o/00SoY[o/1onX`>/8ojW0jaGooooo00?o0000ooooooooool0
7_ooool001_ooooo00?o0000ooooooooool06_ooool3ojO0j`WoYko[1_nW`>/8ojS1j`KoZ<3[2?nW
_n/00onW_^_oYko[ojNoj`05ojNoj`ooZ<7/1OnX`>/9ojNnjPKoYkk[2_nW`N`2ojO2k0GoZ<7/2_nW
`N`01OnX_NWo0000o`000?l0003oZ;gY00WoYkgY1_nX_nX7ojVnj@03ojRmjOnY`N_oZL7[00GoZL7[
1_nY_nT00onX`N_oZ/3Zoj[0jP06oj[0jPKoZ;kY00?oZ/3ZojRnjOnX_^T01onX_^T2ojFok0GoYkkZ
2?nU`>`2ojK1k0GoY/3/1onX`N/2ojW0jPGoZL7[2?nX_n/4ojJok003o`000?nV_ncoY[o/00SoY[o/
2?nX`>/6ojW0j`03ojW1jooooooooooo01Cooooo00?o0000ooooooooool07Oooool001_ooooo00?o
0000ooooooooool05oooool7ojO0j`OoYko[2?nW`>/7ojS1j`OoZ<3[1_nW_n/2ojJnj`SoYko[3onX
`N`00onX`>_oYkkZojNnjP0;ojNnjP;oYkk[3?nW`N`00onX`^coZ<7/ojS1k006ojS1k0KoYl7/00Co
YkgYo`000?l0003o00001OnX_NT6ojNmj@03ojS0jonX_n[oZ;oZ00KoZ;oZ1OnY_^T2ojS1j`SoZL7[
0_nY_nT5ojS1j`SoZ/3Z0_nX_^T5oj[0jPOoZ;kY00?oZl3YojNnj_nW_^X01_nW_^X6ojG0k003ojFn
jonV`>coY/3/00GoY/3/1_nX`N/00onW`>coZL7[ojW1j`06ojW1j`KoZ;o[0_nY`>X4ojJok003o`00
0?nV_ncoY[o/00SoY[o/2?nX`>/2ojW0j`GoZL7[5?ooool2o`0001oooooo000Kooooo`;o00005?oo
ool5ojS0j`OoYl3[1onW_n/8ojO0j`OoZ<7[1onX`>/2ojNoj`KoY[k[1_nW_n/?ojS1k003ojNoj_nW
_^[oYkkZ00_oYkkZ3?nW`N`5ojS2k0SoZ<7/0_nW`N`2ojNmj@;o000000?oYkgYojRmjOnX_NT01_nX
_NT2ojNmj@GoZ<3[2?nX_nX00onY_^WoZ<7[ojS1j`04ojS1j`KoZL7[00?oYl7/ojS1jonX`N/01_nX
`N/6oj[0jP03ojS1jonZ`>[oZ/3Z00KoZ/3Z1?nX_^T4oj_0j@SoYkkZ0_nU`>`5ojFnj`OoY/3/0_nX
`N/5ojO0k0SoZL7[0_nX_n/6ojW0jPCoY[o/00?o0000ojJok?nV_n/02?nV_n`6ojS0j`03ojO0jonY
`N_oZL7[00GoZL7[5_ooool00ol0003oooooooooo`0Looooo`006_ooool00ol0003oooooooooo`0@
ooooo`;oZ<7[2?nX`>/5ojO0j`WoYko[1_nW`>/9ojS1j`GoZ<3[0onW_^/7ojJnj`;oYko[3onX`N`5
ojNojPWoYkkZ3?nW`N`9ojS2k0KoZ<7/0_nW_NT3o`0000CoYkgY1_nX_NT9ojS0j`KoZ;oZ0_nW`N`7
ojS1j`;oZL7[1OnW`N`8ojS1j`;oZ/3Z1OnX`N/8oj[0jP03ojRnjOn[`>WoZl3Y00GoZl3Y1_nW_^X0
0onZ_nWoYKk[ojFnj`05ojFnj`KoY/3/00?oYKo/ojO0k?nW`>`01_nW`>`8ojW1j`SoZL3Z0_nV_n`2
ojJoj`03o`000?nV_n_oY[o[00SoY[o/0_nX`>/5ojO0j`OoZL7[5Oooool00ol0003oooooooooo`0L
ooooo`006_ooool00ol0003oooooooooo`0=ooooo`KoZ<7[2?nX`>/00onW`>_oYko[ojNoj`0;ojNo
j`;oYl3[3OnX`N/00onX`>_oYkk[ojNnj`05ojNnj`GoY[k[0_nX`N/=ojS1k0;oZ<3[1onW_nX6ojNn
jP;oYko[2OnW`N`=ojS2k0;oZ<7/0_nW_NT3o`0000SoYkgY0_nX_NT=ojS0j`;oZ;oZ1_nW`N`5ojS1
j`WoYl7/1_nX`N/00onW`NcoZ<7[ojS1j`06ojS1j`KoZ/3Z0_nX`N/8oj_0j@;oYkkZ1OnZ_nT7ojFn
j`;oY/3/1OnU_n`8ojO0k0SoZL7[1onY`>X4ojJoj`03o`000?nV_n_oY[o[00SoY[o/1onW`>/8ojW1
jaGooooo00?o0000ooooooooool06oooool001[ooooo00?o0000ooooooooool02oooool2ojS0j`Oo
Z<7[1_nX`>/00onW`>_oYko[ojNoj`0;ojNoj`goZ<7[1OnW`>/7ojNnj`03ojJnjonX`N_oZ<7[00Co
Z<7[2OnX`N`6ojS0j`OoYkoZ0_nW_^X6ojNoj`KoYl7/3_nX`^`2ojNmj@?o00002_nW_NT2ojO0j`_o
Z<3[1?nW`^`8ojO1k003ojS1jonW`NcoYl7/00_oYl7/0_nX`N/5ojO1k0SoZ<7[0_nZ`>X6ojS1j`Ko
Zl3Y00?oZL7[ojZojOnZ_nT01OnZ_nT6ojFnj`;oYkoZ1onU_n`6ojO0k0;oY/3/2?nY`N/7ojW0jPCo
Y[o[00?o0000ojJojonV_n/02?nV_n`7ojO0j`SoZL7[5Oooool00ol0003oooooooooo`06ooooo`Go
00003oooool001[ooooo0_l00009ooooo`KoZ<3[1onX`N/2ojS0j`GoYl3[2OnW_n/<ojS1j`;oZ<3[
2?nW`>/5ojNnj`;oYko[1onX`N/8ojS1k0OoZ<3[1OnW_nX3ojJnj`OoYko[0_nW`N`>ojS2k0;oYkgY
0ol0000:ojNmj@KoYl3[1_nX`>/9ojO2k0KoYl7/00?oY[gZojO1k?nW`N`02onW`N`2ojJmjPOoYl7/
1_nX`N/2ojO1k0SoZ<7[0_n[`>T5ojW1j`OoZ[oY0_nU_^/6ojNojPOoYKo/0_nW`>`6ojK0k0KoZL7[
00?oZ<3[ojW0j_nY`>X01OnY`>X5ojJoj`03o`000?nW_n_oYko[00OoY[o/2?nW`>/8ojW1jaCooooo
00?o0000ooooooooool01_ooool01OnHV9So8B4Qonk^k_ooooooA4A400oooooo000Jooooo`03o`00
0?oooooooooo00Kooooo0_nW_n/7ojS0j`GoZ<7[0_nX`>/7ojO0j`WoYko[2?nX`N/6ojS0j`SoYl3[
00?oYkk[ojNojonW_n/01?nW_n/7ojS1j`SoZ<7/1onX`>/00onW_n[oY[k[ojJnj`05ojJnj`GoYko[
3onX`^`01?nX_^[o0000o`000?l0000:ojNmj@?oYko[1onW`>/2ojS0j`goYl;/0_nW`N`5ojJmjPWo
Yl7/1_nV_NX7ojO1k0;oZ<7[1_nW`N`6ojS1j`03ojO1k?nY`N_oZL7[00KoZL7[1OnZ_nT2oj_1jPSo
YkoZ1onU_n`8ojK0k0;oZL7[1OnX`>/7ojW0jP;oY[o[0_nW_n/01?l0003oYko[ojNojonW_n/7ojJo
k0SoYl3[1onY`N/Eooooo`03o`000?oooooooooo00Kooooo00?oV9RHob4Q8Oo^k^h04?ooool001[o
oooo00?o0000ooooooooool00oooool6ojNoj`OoZ<3[00?oZ<7[ojS0jonX`>/01?nX`>/7ojO0j`Wo
Yko[1onX`N/7ojS0j`KoYl3[00?oY[k[ojNojonW_n/01_nW_n/5ojS1j`[oZ<7/0onX`>/4ojJnjPSo
Y[k[00?oYko[ojS2k?nX`^`03OnX`^`01OnX_^[o0000o`000?l0003oZ;kZ00WoYkgY1onW_n/5ojO0
j`ooYl;/00?oYkSVojJmj_nV_NX01_nV_NX6ojO1k0;oYk;Q1onV_NX3ojO1k0CoY[_X2?nW`N`2ojS1
j`GoYl7/2?nY`N/00onZ_nWoZl7Zoj_1jP04oj_1jPKoYkoZ00?oZKoZojFok?nU_n`01_nU_n`6ojK0
k003ojJok?nX`>_oZ<3[00GoZ<3[1_nY`>X2ojW1jPCoYko[00Co0000ojNojonW_n_oYko[1onV_n`8
ojO0j`OoZL7[5Oooool00ol0003oooooooooo`06ooooo`03oiRHV?lQ8B7ok^k^00oooooo000Joooo
o`03o`000?oooooooooo00[oYko[1OnX`>/2ojS1j`OoZ<3[1OnW`>/;ojNoj`OoZ<7[1onX`>/2ojO0
j`GoY[k[2?nW_n/00onX`N_oZ<7/ojS1k00:ojS1k0;oYko[1onV_^X6ojJnj`03ojS1k?nX`^coZ<;/
00_oZ<;/00CoZ<3[o`000?l0003o00001OnX_^X6ojNmj@;oYkk[2?nW_n/00onW`>_oYl;/ojO2k00=
ojO2k0GoYkSV2?nV_NX2ojO1k0KoYk;Q1OnV_NX00onY[]_oY[_XojJkj006ojJkj0KoYl7/00?oY[cY
ojO1k?nW`N`01_nW`N`6ojW1j`03ojO0jon[`N[oZl7Z00KoZl7Z0_nW_nX5ojVojPSoYKo/0_nV`>`5
ojJok0OoZ<3[0_nY`>X6ojW1jPCoYko[00?o0000ojNojonW`>/02?nV_n`7ojO0j`OoZL7[5Oooool0
0ol0003oooooooooo`07ooooo`03ogMgMomVIVKooooo00kooooo000Iooooo`03o`000?nW_n_oYko[
00coYko[00?oZ<3[ojS1jonX`N/01?nX`N/7ojS0j`03ojO0jonW_n_oYko[00_oYko[2OnX`N/5ojS0
j`;oYko[1onV_^/6ojNoj`;oZ<7[2OnX`N`6ojNoj`OoY[kZ0_nV_^/5ojS1k0WoZ<;/00CoZ<3[o`00
0?l0003o00000onX`>/6ojRnjP;oYkgY1_nW_^/6ojNoj`koYl;/00?oYkGSojNhi_nW^>H01_nW^>H6
ojJmjP03ojRZf?nW/^7oYk;Q00OoYk;Q00?oY[gZojV^fonY[]/00onY[]/8ojJkj0;oYl7/1OnV_>T8
ojO1k0;oZL7[1OnW`>/6oj_1jP03oj[1j_nY_n[oZKoZ00KoZKoZ1onU_n`8ojJok0OoZ<3[2?nY`NX2
ojNoj`;oYl3[00?o0000ojO0jonW`>/02?nV_n`7ojO0j`OoZL7[5Oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00gooooo000Iooooo`03o`000?nW_n_oYko[00_oYko[0_nX`>/7ojS1
j`GoZ<3[0onW`>/9ojNoj`goZ<7[00?oZ<3[ojNojonW_n/01?nW_n/7ojJnj`;oYko[1_nX`N/6ojS1
k003ojS1jonW_n_oYko[00KoYko[1OnV_^X2ojNoj`OoZ<7/1onX`^`2o`0000OoZ<3[0onX_^X4ojJm
jPOoYkk[0_nW_n/>ojO2k0GoYkGS2?nW^>H2ojJmjPGoZ:[H1onW/^400on^ZM;oZJkKojV^f`05ojV^
f`KoY[_X00?oZk3LojJljOnV_>T01_nV_>T6ojO1k0;oY[o/1onW`>/2oj_1jPGoZ/7Z2?nY_nX7ojFo
k0SoY[o/1onX`>/6ojW1jP03oj[1jonW`>_oYl3[00;oYl3[00Co0000ojO0jonW`>_oYl3[1onV_n`7
ojO0j`SoZL7[4oooool3o`0000Cooooo00Go0000okZj^_ooooooV9RHoa0@400?ooooo`003_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooooonW_n/02?nW_n/6ojS0j`OoZ<7[00?o
Z<3[ojO0jonW`>/01OnW`>/7ojNoj`goZ<7[0_nX`>/7ojNoj`GoY[k[0onW`>/7ojS1j`;oZ<7/1OnX
`N/8ojNoj`03ojJnj_nW_n_oYko[00CoYko[1onX`N`3ojS2k0?o00000_nX`^`6ojS0j`03ojJljOnV
_N[oY[gZ00KoY[gZ1OnW_^/00onW`NcoYl;/ojO2k00<ojO2k0SoYkGS1_nW^>H00onXY]CoZ:[HojRZ
f006ojRZf0CoYk;Q1?n^ZM87ojV^f`;oY[_X1On[/=`8ojJlj@;oYl7/1_nV_n`5ojO0j`03ojO1k?nZ
`N[oZ/7Z00KoZ/7Z1_nY_nX2oj_0j@OoYKo/1_nV_n`00onU_ncoZ<3[ojS0j`06ojS0j`;oZL7Z1OnZ
`N/4ojO0j`04o`000?nW`>_oYl3[ojO0j`OoY[o/1onW`>/8ojW1jaCooooo00?o0000ooooooooool0
0_ooool01OnHV9So410@o`000?lQ8B7oc<c<00oooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01_ooool00ol0003oooooooooo`08ojNoj`OoZ<3[1OnX`N/3ojS0j`OoYl3[1onW_n/9ojS1j`Ko
Z<3[1onW_n/00onV_^_oYl3[ojO0j`05ojO0j`koZ<7[1_nW_n/00onV_^_oYko[ojNoj`06ojNoj`Go
Z<7/00CoZ<;/o`000?l0003o00001_nX`^`2ojS0j`GoY[cY2?nV_NX00onW_^_oYl7/ojO1k003ojO1
k0[oYl;/3?nW]N<2ojNhiPGoZ:KD2?nXZ]P00onW/^7o[ZWBojjYdP05ojjYdPGoZJkK00?o/jcAoj^`
g?n[/=`01_n[/=`6ojJlj@;oZKGQ2?nV_n`00onW`>_oYl7/ojO1k003ojO1k0SoZ/7Z0_nY_nX6oj_0
j@OoYKo/0_nV_n`5ojFok0KoZ<3[00?oYl3[oj[1jonZ`N/01_nZ`N/4ojO0j`03o`000?nW`>_oYl3[
00OoY[o/2?nW`>/8ojW1jaCooooo00?o0000ooooooooool05Oooool000kooooo00Go410@oooooooo
oooooooooa0@4006ooooo`;o00000_ooool8ojNoj`OoZ<3[00?oZ<7[ojS0jonX`>/01OnX`>/5ojO0
j`;oY[o[1onW_n/8ojS1j`OoZ<3[1OnW_n/3ojJnj`OoYl3[3_nX`N/2ojNoj`GoY[k[2?nW_n/00onX
`NcoZ<;/o`000002o`0000SoZ<;/0_nW_NX7ojJlj@KoY[gZ2?nW`N`6ojO2k003ojNii_nW]N?oYkGS
00_oYkGS00?oYj?BojRVe?nXY]@01_nXY]@6ojRZf003ojjSc?n^ZM;o[ZWB00Ko[ZWB0onY[]/4ok>/
d@SoZk3L0_nV_>T6ojVeh@KoY[o/00?oY[gYojO1k?nW`N`01OnW`N`6oj[1jP03ojW1jon[`>WoZl3Y
00OoZl3Y0onU_n`3ojJoj`SoYKo/0_nX`>/5ojO0j`SoZ/7[1?nW`>/00ol0003oYl3[ojO0j`07ojJo
k0SoYl3[1onY`N/Eooooo`03o`000?oooooooooo01Cooooo000>ooooo`05o`000?oooooooooooooo
ool000001_ooool00ol0003oooooooooo`03ooooo`OoYko[0onX`>/5ojS1j`OoZ<3[00?oYl3[ojJo
jonV_n/01?nV_n/7ojNoj`SoZ<7[1onX`>/00onW_n_oY[k[ojJnj`05ojJnj`GoYl3[3_nX`N/9ojJn
j`KoYko[0ol00008ojS2k0KoYkgZ1onV_>T2ojJmjPcoYl7/0_nW`^`5ojNiiPWoYkGS1OnWXm87ojRV
e0CoZ:[H1?n^Xl`8ojjYdP03ojV^fonc[=7o/jcA00Co/jcA1_n[/=`00ong/]CoZKGQojVeh@07ojVe
h@;oY[o/1OnV_NT7ojO1k0;oZ/7Z1OnY`N/7oj_0j@03oj_1j_nV_n_oY[o[00GoY[o[1onU_n`8ojO0
j`OoZ/7[1?nW`>/00ol0003oYl3[ojO0j`06ojJok0;oY[o[2?nW`>/7ojW1jaCooooo00?o0000oooo
ooooool05?ooool000kooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo
00Gooooo1OnW_n/2ojS0j`SoZ<7[1OnX`>/2ojO0j`OoY[o[1OnW_n/:ojS1j`?oZ<3[1?nW_n/8ojJn
j`03ojO0jonX`N_oZ<7[00coZ<7[3OnV_^/2ojNoj`?o00000onX`N`6ojS2k003ojS1jonW_N[oYkgZ
00KoYkgZ1OnV_>T00onW`>_oYl7/ojO1k00;ojO1k0;oZ;kY1onW^NH6ojNeh`03ojBRdonWXm;oYj?B
00GoYj?B1onXY]@00onXZ]So[Z?<ojjSc004ojjSc0Oo[ZWB00?o/jK;ok>/dOnc[=401Onc[=44oj^`
g0Co]k;D1onY]N400ond]mcoY[gYojJmj@05ojJmj@KoYl7/0_nV`>`7ojW1j`CoZl3Y1?n[`NX7ojJo
j`OoYKo/2?nW`>/7oj[1j`CoYl3[00?o0000ojO0jonW`>/00_nV_n`6ojJoj`KoYl3[00?oZ<3[ojW1
jonY`N/01OnY`N/Eooooo`03o`000?oooooooooo01?ooooo000>ooooo`05oa0@4?oooooooooooooo
ool@41001Oooool00ol0003oooooooooo`06ooooo`03ojNojonX`>_oZ<3[00CoZ<3[2?nX`N/00onX
`>_oYl3[ojO0j`04ojO0j`OoY[o[00?oYko[ojS1jonX`N/02_nX`N/2ojS0j`OoYko[1_nV_^/00onW
`>_oZ<7[ojS1j`0;ojS1j`;oZ<3[3?nV_^/3o`0000OoZ<7/0_nX`^`5ojS1j`SoYkgZ00?oY[cYojO0
jonW`>/00onW`>/9ojO1k0KoZ;kY1onW^NH2ojNeh`GoY:;C1_nWXm86ojRVe003oj^Obon^Xlco[Z?<
00Ko[Z?<1On^ZM83ok>Vb`Oo/jcA00?oZk3LokNbe?ng/]@01Ong/]@4ojVeh@Co];OL1onV_NT2ojO1
k0KoY/3/1onY`N/00on[`>WoZl7Zoj_1jP04oj_1jPKoY[o[00?oYko[ojFok?nU_n`01_nU_n`7ojO0
j`SoZ/7[0onW`>/01?nW_n_o0000ojNojonW_n/8ojJoj`;oYl3[1OnX`>/7ojW1jaGooooo00?o0000
ooooooooool04_ooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o00002?ooool7
ojS0j`KoZ<7[0_nX`>/7ojO0j`GoY[o[0onW_n/8ojS1j`KoZ<3[1onW_n/2ojJnj`GoYl3[2OnX`N/6
ojS0j`SoY[k[0ol00004ojS0j`GoZ<7/0_nY`^`7ojS1j`KoYkgZ0_nU_N/6ojO0j`KoYl7/0_nX`N`7
ojRnj@GoYkWV00?oXZ?FojBRdonTX]<01OnTX]<7ojNSdP?oZ:KD1?n[Wl/7ojjSc0?o[ZWB1OncY//6
ok>/d@03okZ]c?ng/]Co]k;D00Oo]k;D00?oZKGQokBgg?nd]m`01Ond]m`5ojJmj@;oZ[cW2?nV`>`3
ojW1j`CoZ<3[1on[`NX2ojJoj`GoYko[2?nU_n`7ojO0j`KoZ/7[00?oZL7[ojNojonW_n/00_nW_n/0
1?l0003oYko[ojNojonW_n/7ojJoj`OoZ<3[1_nY`N/00onX`N_oooooooooo`0Cooooo`03o`000?oo
oooooooo01;ooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003ooooooooo
o`08ooooo`OoZ<3[0_nX`N/6ojS0j`OoYl3[00?oY[o[ojNojonW_n/01OnW_n/7ojS1j`OoZ<3[1OnW
_n/2ojJnj`OoYl3[2?nX`N/7ojS0j`GoY[k[0_l00008ojS0j`03ojS1k?nY`^coZL;/00CoZL;/1onX
`N/2ojNmjPKoYKg[1_nW`>/2ojO1k0KoZ<7/1onX_^T00onW^NKoXZ?Foj:SeP03oj:SePOoY:;C1onW
Xm800onXY]CoZio;oj^Ob`03oj^Ob`So[Z?<00?o[ZWBok>VboncY//01OncY//4ok>/d@?o^Zg<1ong
/]@00onm/m3o];OLokBgg007okBgg003ojJmjOnZ_>OoZ[cW00CoZ[cW1_nV`>`00onU_ncoZ<3[ojS0
j`06ojS0j`OoZl7Z1onW_n/7ojFok0SoYl3[0_nZ`N/5ojW1j`CoYko[00Co0000ojNojonW_n_oYko[
1onV_n/7ojS0j`;oZL7[1OnX`N/Eooooo`03o`000?oooooooooo017ooooo000Hooooo`03o`000?oo
oooooooo00Wooooo1OnX`>/3ojS1j`OoZ<3[0onW`>/4ojJoj`SoYko[1onX`N/7ojS0j`03ojNojonV
_^_oY[k[00CoY[k[1onW`>/8ojS1j`GoZ<3[0onV_^/3o`0000?oY[k[1_nX`>/2ojS2k0OoZL;/1OnX
`N/2ojFmjPSoYKg[0onW`>/4ojS2k0OoZ<7/0onX_^T3oj6WfPKoXZ?F1onTX]<6ojNSdP03ojNLbon[
Wl_oZio;00GoZio;1_n^Xl`00onfZLgo/jK;ok>Vb`06ok>Vb`?o/jcA1Onj[L`5okNbe0?o_K?@1ond
]m`00onm_MWoZ[cWojZli`06ojZli`;oY/3/1OnU_n`8ojS0j`OoZl7Z1onW_n/7ojFok0KoYl3[00?o
Z<3[ojW1jonY`N/01_nY`N/4ojNoj`03o`000?nW_n_oY[o[00OoY[o[1onX`>/8ojS1jaGooooo00?o
0000ooooooooool04?ooool001Sooooo00?o0000ooooooooool02_ooool00onX`>_oZ<7[ojS1j`05
ojS1j`GoZ<3[0_nW`>/7ojJoj`KoYko[2OnX`N/5ojS0j`?oYko[1_nV_^/5ojO0j`[oZ<7[00CoZ<3[
ojJnjonV_^_oY[k[0ol00007ojJnj`;oZ<3[1_nX`^`7ojW2k003ojS1jonU_N[oYKgZ00CoYKgZ1_nU
_N/00onX`N_oZ<;/ojS2k006ojS2k0GoZ<7/00?oY;7Roj6Wf_nQYmX01OnQYmX6oj:SePOoY:;C0_nW
Xm85ojNLb`KoZio;1?n^Xl`4okJYc@So/jK;00?o/jcAokZ]c?nj[L`01?nj[L`3okNbe0Ko_K?@1?nd
]m`4okfmf@KoZ[cW00?o[koVojFok?nU_n`01_nU_n`6ojS0j`03ojO0jon[`N[oZl7Z00KoZl7Z0onW
_n/4ojK0k0OoYKo/0_nW`>/5ojS0j`SoZL7[0_nW_n/2ojJoj`03o`000?nV_n_oY[o[00OoY[o[1onX
`>/7ojS1jaGooooo0_l0000Aooooo`005oooool3o`0000gooooo1onX`N/00onX`>_oYl3[ojO0j`04
ojO0j`OoY[o[0_nW_n/=ojS1j`03ojS0jonW_n_oYko[00GoYko[1_nV_^/00onW`>_oZ<7[ojS1j`0:
ojS1j`;oZ<3[0ol00009ojJnj`?oZ<7[1onX`^`3ojW2k0CoYko[1onU_NX2ojFmj`GoZ<7[2?nX`^`0
0onX`NcoY;7RojBahP03ojBahPOoXJOJ1OnRXmH6ojBRd`03oj>Jc?nWW<_oYic;00GoYic;1on[Wl/0
0on^Xlco]ZW=okJYc@04okJYc@Oo/jK;00?o_kKAokZ]c?nj[L`01_nj[L`00ong/]Co_K?@okfcd006
okfcd003okBgg?nm_MWo_KgI00Go_KgI0onZ_>L4ojnoiPSoYKo/0_nX`>/5ojO0j`KoZl7Z00?oZl;Z
ojK0k?nV`>`01_nV`>`5ojFok003ojFojonX`>_oZ<3[00KoZ<3[1onY`N/4ojJoj`03o`000?nV_n_o
Y[o[00SoY[o[1onX`>/7ojS1ja?ooooo00?o0000ooooool000004Oooool001Oooooo00?o0000oooo
ooooool03_ooool5ojS1j`;oZ<3[1onW`>/5ojJoj`?oYko[3?nX`N/2ojS0j`SoYko[0onV_^/4ojO0
j`SoZ<7[0_nX`>/3o`000003ojS0jonV_^_oY[k[00KoY[k[1onX`N/5ojS2k0;oZL;/1onW_n/5ojFm
jP;oY[o[1onX`N/6ojS2k003ojNmjOnT/N;oY;7R00GoY;7R1_nQYmX6oj:SeP;oY:;C1OnSV/`7ojNL
b`GoZio;00?o];;GokJYcOnfZLd01_nfZLd5ok>Vb`?o_kKA1_nj[L`00oo4^Loo_K?@okfcd006okfc
d003olFkd?nm_MWo_KgI00Oo_KgI00?oZ[cWojnoi_n__nH01?n__nH8ojFok0OoYl3[0_n[`NX5oj_2
jPSoY/3/00?oYKo/ojFojonU_n/00onU_n/8ojS0j`OoZL7[1?nV_n/00ol0003oY[o[ojJoj`08ojJo
j`GoZ<3[2OnX`N/Dooooo`03o`000?oooooooooo00oooooo000Gooooo`03o`000?oooooooooo00oo
oooo00?oZ<7[ojS0jonX`>/01?nX`>/7ojO0j`03ojJojonW_n_oYko[00GoYko[2?nX`N/6ojS0j`Ko
Yko[00?oY[o[ojO0jonW`>/01_nW`>/6ojS1j`?o00001OnX`>/7ojJnj`SoZ<7[00?oZ<;/ojW2k?nY
`^`01?nY`^`7ojNoj`03ojFmj_nV_n_oY[o[00CoY[o[1onX`N/2ojS2k0GoYkgY1_nT/N87oj6WfP?o
XZ?F0_nNVLh7oj>Jc0OoYic;0on[Wl/4okBbe`Oo]ZW=0oncY//6oknfd@Co^Zg<0oo4^Ll6okfcd0?o
aK_@1onm_MT00oo3`mWo[koVojnoiP06ojnoiPSoYKo/1_nW`>/8oj_2jPKoY/3/00?oY[o/ojFojonU
_n/01OnU_n/7ojS0j`SoZL7[1?nV_n/00ol0003oY[o[ojJoj`08ojJoj`03ojS0jonX`N_oZ<7[00_o
Z<7[5?ooool00ol0003oooooooooo`0>ooooo`005oooool00ol0003oooooooooo`0@ooooo`OoZ<3[
1OnW`>/3ojJoj`OoYko[1onX`N/7ojS0j`;oYko[1OnV_n/8ojO0j`;oZ<7[0ol00002ojS1j`OoZ<3[
1onV_^/6ojS1j`03ojW2jonY`^coZL;/00KoZL;/1OnW_n/00onU_N[oY[o[ojJoj`06ojJoj`GoZ<7[
0_nY`^`7ojNmj@KoY;7R0onQYmX3oiZIdPKoWYW>1onSV/`7ojNLb`03oj^Obond/]Oo];;G00?o];;G
2?nfZLd00oncY/_o_kKAoknfd@05oknfd@?o^Zg<1Oo4^Ll4okfcd0GoaK_@1?nm_MT4ol?3f@Ko[koV
0_nca>L8ojFok0KoYl3[2?n[`^X2ojK0k0GoY[o/1onU_n/7ojS0j`OoZL7[1OnV_n/00ol0003oY[o[
ojJoj`07ojJoj`goZ<7[00?oYl3[ooooooooool04oooool00ol0003oooooooooo`0=ooooo`005ooo
ool2o`0001;ooooo1onX`>/00onW`>_oY[o[ojJoj`05ojJoj`GoYko[2OnX`N/5ojS0j`;oYko[1onV
_n/6ojO0j`?o00001_nX`N/3ojS0j`_oY[k[0_nX`N/5ojW2j`SoZL;/00?oYko[ojFmj_nU_NX00onU
_NX8ojJoj`03ojS1jonY`^coZL;/00CoZL;/1onW_NT3ojBahP;oUioI1onJVM85oijIcPOoXi[<1_nW
W</00on^]moo];;GokBbe`05okBbe`Ko]ZW=00?o_<_VoknfdOno]]401ono]]400onj[Lcoa;W?olBi
c`04olBic`?o_K?@1oo5^m000onm_MWo`l?Iol?3f@05ol?3f@;o[koV1_nca>L7ojFok0OoYl3[1on[
`^X8ojJok0?oYKo[1?nV_n/7ojS0j`OoZL7[1?nV_n/00ol0003oY[o[ojJoj`08ojJoj`WoZ<7[1OnW
`>/Dooooo`03o`000?oooooooooo00gooooo000Gooooo`03o`000?oooooooooo01;ooooo1OnX`>/3
ojO0j`OoY[o[00?oYko[ojS1jonX`N/02onX`N/00onX`>_oYko[ojNoj`04ojNoj`OoY[o[0_nW`>/0
0onX`N_o0000o`000008ojS1j`;oZ<3[3?nV_^/3ojS1j`KoZL;[1_nY`^`2ojNoj`KoYKgZ1_nV_n/2
ojS1j`OoZL;/0onW_NT3oiZXh0KoUioI1_nJVM86oijIcPOoXi[<0_nWW</5ojjgg`Ko];;G1?nfZLd4
okc;iPOo_kKA00?o_/kVolBicoo4^Ll01_o4^Ll00onm/m3oaK_@olFkd005olFkd003ol_3doo3`mWo
`l?I00Go`l?I0_o7bM/8ok?4i`OoYKo/1onW`>/7oj_2jPKoY[o/00?oYKo/ojJojonV_n/01_nV_n/5
ojS0j`;oZL3[1onY`N/4ojJoj`03o`000?nV_n_oY[o[00SoY[o[0onX`N/3ojW1j`SoYl3[5?ooool0
0ol0003oooooooooo`0<ooooo`005oooool00ol0003oooooooooo`0Cooooo`03ojS0jonW`>_oYl3[
00GoYl3[1onV_n/<ojS1j`?oZ<3[1_nW_n/5ojJoj`04ojNojol0003o0000o`0000OoZ<7[1_nX`>/8
ojJnj`OoZ<7[1_nY`^/2ojW2k0KoYko[1_nU_NX2ojJoj`KoZ<7[1OnY`^`00onT^^WoVZSPoiZXh005
oiZXh0GoUioI1onJVM85oijIcPKoXi[<00?oYkCSojjggon^]ml01_n^]ml6okBbe`03okJYcOnlbnKo
_<_V00Go_<_V1?no]]44okk>iPKoa;W?00?oa/OJolFkd?o5^m001Oo5^m03ol_3d`Go`l?I1?o7bM/6
ok?4i`;o/lSY1_nU_n`6ojO0j`;oZ<3[1on[`^X2ojJok0GoYKo/2?nV_n/00onX`>_oZL3[ojW0j`04
ojW0j`OoZL7[1?nV_n/00ol0003oY[o[ojJoj`06ojJoj`03ojNojonY`N_oZL7[00GoZL7[1onW`>/E
ooooo`03o`000?oooooooooo00_ooooo000Gooooo`03o`000?oooooooooo01Gooooo1onW`>/7ojJo
j`SoZ<7[1onX`>/6ojNoj`03ojJojonW_n_o000000;o00000onW_n/7ojS1j`OoZ<3[2?nV_^/7ojS1
j`OoZL;[1onW_n/3ojFmjPCoYko[1onX`N/00onY`^coY;[YojBjj@03ojBjj@KoVZSP1_nGWmT6oiZI
dPKoWYW>0_nSV/`5ojNdh`Oo[[OO1Ond/]L2oj;No0So_<_V00?o_kKAokk>i_nnc^H01Onnc^H4olBi
c`?oa/OJ1Oo5^m05ol_3d`?o`l?I1_o7bM/2ok?4i`Ko/lSY1_nU_n`2ojO0j`KoZ<3[1On[`^X2oj_2
j`OoYKo/1onV_n/8ojW0j`?oZL7[0onX`N/5ojJoj`03o`000?nV_n_oY[o[00;oY[o[1OnW_n/7ojW1
j`OoYl3[5?ooool00ol0003oooooooooo`0;ooooo`005_ooool3o`0001Oooooo1OnW`>/3ojNoj`Ko
Y[o[2?nX`N/7ojS0j`?oYko[00CoY[o[o`000?l0003o00001onW_n/7ojS1j`OoZ<3[2?nV_^/5ojS1
j`03ojW1jonY`^_oZL;[00KoZL;[1OnW_n/00onT_N_oYko[ojNoj`06ojNoj`GoZ<7[00?oZL;/ojBj
jOnT^^T01OnT^^T6oiZXh0GoUioI1_nJVM85oijIcP;oWZWN1onW]><7ojjgg`03okBbeonRg_coX]kl
00CoX]kl1_nlbnH2ogcNn@Oo_/kV0oo4^Ll5olK7fP?oaK_@1oo;`m<00oo3`mWoalWKolO9f`05olO9
f`Wo/lSY0onU_n`3ojFnj`SoZ<3[00?oZl;Zoj_2jon[`^/01?n[`^/7ojFok0OoY[o[1_nY`>/00onY
`N_oZ<7[ojS1j`05ojS1j`CoY[o[00?o0000ojJojonV_n/01onW_n/7ojW1j`SoYl3[5?ooool00ol0
003oooooooooo`0:ooooo`005_ooool00ol0003oooooooooo`0Hooooo`03ojO0jonW_n_oYko[00Go
Yko[1_nV_n/8ojS1j`GoZ<3[00?oYl3[ojJojol000000_l00004ojJoj`GoYko[2OnX`N/5ojS0j`[o
Y[k[00?oZ<7[ojW1jonY`N/00onY`N/8ojW2j`03ojNojonT_N_oY;g[00?oY;g[2?nW_n/00onX`N_o
ZL;/ojW2k003ojW2k0OoY;[Y1OnJZ>06oiNOf@KoVYWB00?oWYW>oijYg_nNZMh01?nNZMh7ojNdh`?o
[[OO1_mohoD5oj;No0;o_<_V1_mlg_T7okk>iP03olBicoo6am[oa/OJ00Goa/OJ00?oaK_@ol_3doo;
`m<01Oo;`m<00oo?b]KoalWKolO9f`05olO9f`;obM3O1oncb>T00on`b>coYKk[ojFnj`05ojFnj`Ko
Z<3[00?oZL3[oj_2jon[`^/01_n[`^/3ojFok0?oYKk[2?nV_n/2ojW0j`GoZL7[1onX`N/4ojJoj`03
o`000?nV_n_oY[o[00OoYko[1onY`N/6ojO0j`03ojNojooooooooooo017ooooo0ol0000;ooooo`00
1?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h6ooooo`03o`000?oooooo
oooo01[ooooo1onW_n/3ojJoj`CoZ<3[1onX`N/00onX`>_oYl3[ojO0j`03o`0000SoY[o[00?oYko[
ojS1jonX`N/02onX`N/00onX`>_oY[k[ojJnj`0:ojJnj`03ojS0jonY`N_oZL7[00GoZL7[1_nY`^/2
ojNoj`KoY;g[1_nW_n/2ojS1j`KoZL;/1onT^^T5oiZXh0?oUioI0_n<TmD6oiFKe`SoWZWN1OnW]><4
ohGUmP?oOn?e0oo>b=@6ojRojP;oCYG`1_mlg_T3okk>iPCoV]Cl1_o6amX00onmbN?obl?Col_3d`05
ol_3d`?ocl[F1Oo7bM/4olW@g`Co/lSY1?n`b>`7ojFnj`;oZ<3[1OnY`>/6oj_2j`03ojW2k?nU_^_o
YKk[00GoYKk[1_nV_n/00onW_n_oZL7[ojW1j`05ojW1j`KoZ<7[0_nW`>/4ojJoj`03o`000?nV_n_o
Yko[00GoYko[0_nX`>/7ojW1j`;oYl3[1OnW_n/?ooooo`?o00000_ooool00ol0003oooooooooo`09
ooooo`001_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool0
0ol0003oooooooooo`0Kooooo`GoYko[00?oY[o[ojS0jonX`>/01_nX`>/6ojS1j`?o00001?nW`>/6
ojJoj`;oYko[3_nX`N/9ojJnj`GoZ<3[1onY`N/2ojW2j`KoYko[1_nT_N/2ojNoj`KoZ<7[1_nY`^`3
ojBjj@?oT:GS1On=Vm`6ohbCe@KoUI_G2?nNZMh00onW]>?oQNGfohGUmP04ohGUmP?od_GV1Oo>b=@3
ojRojP;oXi[;1?mePM42odjEl003o`1HdOlV003o9P0000OoV]Cl0oo6amX4okg9h`Gobl?C1Oo?b]H3
olO9f`KobM3O00?o/lSYok38k?n`b>`01?n`b>`6ojFnj`;oY[k[1onY`>/2oj_2j`GoZL;/1onU_^/2
ojJoj`GoYko[1onY`N/2ojS1j`KoYl3[0onV_n/00ol0003oY[o[ojJoj`02ojNoj`KoZ<3[1OnY`N/0
0onX`N_oYko[ojNoj`06ojNoj`_ooooo0ol00005ooooo`03o`000?oooooooooo00Wooooo0006oooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`;o00007Oooool0
0onW_n_oY[o[ojJoj`03ojJoj`SoZ<3[0_nX`N/3o`0000;oZ<7[1_nW`>/2ojJoj`KoYko[1OnX`N/2
ojW1j`OoZ<7[1OnV_^/3ojFnj`KoZ<3[1OnY`N/3ojW2j`OoYko[0onT_N/4ojJoj`OoZ<7[0onY`^`2
oj:kj`OoT:GS1On=Vm`6ohbCe@KoUI_G1_nNZMh4oj;No003ohGUm_oBmNKod_GV00?od_GV1Oo>b=@0
0onoZL?oXi[;oj>Jb`04oj>Jb`GoMH7A0_m2I]000ol0F=7o9P00oi[Do006oi[Do003olK7f_nmbN?o
_LWS00Co_LWS0oo;`m<7olo:eP03olO9foo9d=oobM3O00CobM3O0_o8eN@7ok38k0;oYKk[1_nV_^/5
ojW0j`03oj[1jonY`^coZL;/00KoZL;/1onU_^/7ojNoj`GoZL7[0_nY`^/8ojO0j`?oY[o[00?o0000
ojJojonV_n/02?nX`>/00onY`N_oZ<7[ojS1j`03ojS1j`SoYko[1_ooool4o`0000Sooooo00?o0000
ooooooooool02Oooool000Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo
000000Gooooo0_l0000Oooooo`KoY[o[1_nX`>/00onX`N_o0000o`000006ojS1j`?oYl3[1?nV_n/7
ojNoj`03ojS1jonY`N_oZL7[00CoZL7[1onX`N/00onV_^_oYKk[ojFnj`05ojFnj`KoZ<3[00?oZL7[
ojW2jonY`^/01OnY`^/5ojNoj`03ojBmjonV_n_oY[o[00KoY[o[1OnX`N/2ojW2j`GoX[_[1on@YN<5
ohfKg0GoS9?E1onEVmL2oijYgPKoX]kl00Coeo_Non?Ve?oSi]CohnKD0_oBmNH5olk8e0?o_jW31OnS
V//6ogF1d@?o@VK@00Co04g8oi[Do?nJe?coV]Cl0omX_Od8okg9h`03ol_3doo?b]Kocl[F00Gocl[F
0_oAd]T4olW@g`Gob=GT1On`b>`2oj[4k0SoY[k[00?oZL3[oj[1jonZ`N/00onZ`N/8ojW2k0OoYKk[
1onW_n/00onY`N_oZL;[ojW2j`04ojW2j`KoYl3[1OnV_n/00ol0003oY[o[ojJoj`06ojS0j`SoZ<7[
1onW_n/3ooooo`?o00003Oooool00ol0003oooooooooo`08ooooo`001_ooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`0Oooooo`KoY[o[
0_nX`>/01?nX`N_o0000o`000?l00007ojS1j`;oZ<3[1onV_n/5ojNoj`?oZ<3[1_nY`N/5ojS1j`?o
Y[o[1onU_^/3ojS0j`?oZL7[2?nY`^/00onW_n_oY;g[ojBmj`03ojBmj`SoY[o[00?oZ<7[ojW2jonY
`^/01?nY`^/5oj:kj`KoT:GS1On=Vm`6ohbCe@GoUI_G0onTa?04oj;No003og3M^ooGnmkoeo_N00Co
hnKD1Oo>b=@4oknY``KoXi[;1OmePM44od9Vd0;o04g81OmX_Od6okg9h`;o]<GV1_o?b]H4om7Bf@03
olW@goo8eNCob=GT00Kob=GT00?o/<S/oj[4k?nZa>`01?nZa>`6ojJnj`03ojNojonZ`N_oZ/7[00Go
Z/7[1_nY`^`00onW`NcoYKk[ojFnj`06ojFnj`?oYko[0onX`>/8ojW2j`;oYl3[2OnV_n/00ol0003o
Y[o[ojJoj`02ojS0j`coZ<7[1onW_n/2o`00013ooooo00?o0000ooooooooool02?ooool000Kooooo
00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000oooooooo
ool08?ooool3ojJoj`;oYko[0ol00007ojS1j`KoZ<3[1onV_n/00onW_n_oZ<3[ojS0j`05ojS0j`Ko
ZL7[00?oZ<7[ojJojonV_n/01OnV_n/5ojFnj`03ojNojonY`N_oZL7[00GoZL7[1_nY`^/2ojS1k0Ko
Y;g[1_nV_n/2ojS0j`OoZL;[1OnR^n/6oi2Uh`GoSI_L1_n<TmD00onEVmOoY<C`ojC4l005ojC4l003
oj;No?m`gK_o^?7d00;oeo_N1OoSi]@01?oJb<Ooc/SDolk8e?o>b=@6oknY``GoXi[;1_mePM43od9V
d0;o;5oA00?o04g8ofRmoOmX_Od00omX_Od3okg9h`Go]<GV0oo?b]H6om7Bf@03om?Kg_o8eNCob=GT
00Gob=GT00?o`mSYoj[4k?nZa>`01_nZa>`2ojJnj`GoYko[1onZ`N/2ojW2k0GoYl7/1_nU_^/00onV
_^_oZ<3[ojS0j`05ojS0j`KoZL;[00?oZL7/ojJojonV_n/02OnV_n/00ol0003oY[o[ojNoj`0;ojS1
j`?oYl3[2?nW_n/Aooooo`03o`000?oooooooooo00Sooooo0006ooooo`03o`000?oooooooooo00;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o00008_ooool01?nW_n_o0000o`000?l00003
ojNoj`SoZ<7[1_nX`>/8ojJoj`OoZ<3[0onY`N/3ojS1j`SoY[o[00?oYKk[ojNojonW_n/00onW_n/7
ojW1j`;oZL;[1_nX`N`6ojBmj`;oY[o[1_nX`>/5ojW2j`03ojBok?n<Z^WoS:[Y00?oS:[Y1_n1Vn<5
oh2Bg0OoT:?R1_nTa?03okSam0;oeo_N1OoSi]@3om[8a`03olk8e?noZL?o_jW300Go_jW31_nSV//5
ogF1d@Co@VK@0_l/Gm401?l0CLSoFIcboeVLl_mIW?82ofRmo@03okg9hondaNKo]<GV00Go]<GV00?o
cl[Fom7BfOoAd]T01?oAd]T3om?KgPCob=GT1?o3f>T6oj[4k0;oY[o/1onW_n/3oj[1j`?oZl?[2?nW
`N`2ojFnj`GoY[k[1onX`>/2ojW2j`GoZL7/2OnV_n/2ojNoj`03o`000?nW_n_oYko[00KoZ<7[00?o
ZL7[ojO0jonW`>/01OnW`>/6ojNoj`03ojJojooooooooooo00oooooo00?o0000ooooooooool02?oo
ool000Cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o
0000ooooooooool07oooool3o`0000OoYko[2?nX`N/6ojS0j`SoY[o[1OnX`>/8ojS1j`KoY[o[0_nU
_^/6ojNoj`SoZL7[1onX`N`3ojBmj`CoYKk[1onX`>/00onY`^_oY;o/ojBok003ojBok0GoS:[Y1_n1
Vn<5oh2Bg0OoT:?R0onTa?04okSam0;oeo_N1OoSi]@4om[8a`So_jW31OnSV//00onPS;koPW[2oh9j
`P02oh9j`P;oMH7A0om2I]04obaOd@CoFIcb1ondaNH2okC3i@GodM;I1OoCfmh00oo8eNCo`mSYol?H
j@05ol?Hj@;oZ/C/1_nV_n`6ojNoj`OoZl?[1_nW`N`8ojJnj`KoZ<3[0_nY`N/7ojW1k0KoY[o[1OnW
_n/00ol0003oYko[ojNoj`02ojS1j`GoZL7[1onW`>/2ojNoj`GoY[o[4?ooool00ol0003ooooooooo
o`08ooooo`005Oooool00ol0003oooooooooo`0Looooo`?o00001?ooool5ojNoj`?oZ<3[1onX`N/3
ojS0j`CoYko[1onV_n/00onX`>_oZ<7[ojS1j`0:ojS1j`;oY[o[1_nU_^/6ojNoj`SoZL7[1OnX`N`0
0onU_^coYKk[ojFnj`06ojFnj`GoZ<3[0_nY`N/6ojBok0GoS:[Y1_n1Vn<5oh2Bg0OoT:?R00?oY<C`
okSam?nhlO@00_nhlO@3omOkgPCohnKD1OoJb<L00oo>/[ko_jW3oknY``06oknY``03oj>JbonPS;ko
X8bn00?oX8bn1On2N/82ofA/a@;o@VK@1?l/Gm44oeVLlPCo]<GV1Ond`nD3om7Bf@Godm_N0ooBiN@5
ol?Hj@;o^=?^2?nV_n`6ojNoj`OoZl?[0_nW`N`<ojJnj`;oZ<3[1_nY`N/5ojW1k003ojO0jonV_n_o
Y[o[00GoY[o[1OnW_n/00ol0003oYl3[ojW1j`06ojW1j`KoYl3[00?oYko[ojJojonV_n/01_nV_n/?
ooooo`03o`000?oooooooooo00Sooooo000Eooooo`03o`000?oooooooooo01Wooooo0ol00008oooo
o`03ojNojonX`>_oZ<3[00GoZ<3[1OnX`N/00onX`>_oYko[ojNoj`06ojNoj`GoY[o[0_nW_n/;ojS1
j`?oYl3[1onU_^/3ojNoj`CoZ<3[1onY`N/00onX`NcoYKk/ojFnk003ojFnk0SoYKk[00?oZ<3[ojW1
jonY`N/01?nY`N/6ojBok0GoS:[Y1On1Vn<5oh2Bg0KoT:?R1?n_bNh01?nhlOCoeo_NomOkg_oGnmh4
on?Ve0Gof/S70_o>/[h7oknY``03okJJ^onPS;koX8bn00CoX8bn1On2N/84ofA/a@Co;5oA1?m]T^D0
0omIW?;o]<GVokC3i@07okC3i@03om7BfOoCfmkodm_N00?odm_N1OoBiN@00oo3f>Wo^=?^okSCkP04
okSCkPKoY[o/00?oY[k[ojNojonW_n/01OnW_n/5oj_3j`;oZ/?/2onV_^/3ojNoj`SoZL7[00?oZL7/
ojO0jonW`>/00onW`>/7ojJoj`;oYko[0_nW`>/00ol0003oYl3[ojO0j`07ojW1j`;oYl3[1OnW_n/6
ojJoj`03ojNojooooooooooo00gooooo00?o0000ooooooooool02?ooool001Gooooo00?o0000oooo
ooooool05_ooool3o`0000gooooo1onX`>/00onX`N_oZ<3[ojS0j`03ojS0j`SoYko[00?oY[o[ojNo
jonW_n/01?nW_n/7ojS1j`OoYl3[1OnU_^/00onV_^_oZ<3[ojS0j`06ojS0j`OoZL7[1_nU_^`6ojFn
j`;oYko[1onY`N/3ojBok0;oTkO_1?mkX>X2ohbZj@GoPI_S1On0T]`2oi2ShPKo[lW^1?o?gN<3omoI
d@03on?Ve?oJb<Oof/S700?of/S71?o>/[h5oknY``?o]YZk1OnPS;h6oh9j`PCoI6c51?l/Gm45offB
i@Oo]<?U0onmbN@3om?KgPGod^GT00?obN?ZokSCk_nhdnh01_nhdnh2ojJok0GoY[k[1onW_n/00on[
`n_oZ/?/oj[3k004oj[3k0KoY[k[00?oYKk[ojNojonW_n/01OnW_n/6ojW1j`03ojW2jonW`>_oYl3[
00GoYl3[1onV_n/4ojO0j`03o`000?nW`>_oYl3[00?oZL7[1?nX`N/7ojNoj`;oY[o[1OnW_n/?oooo
o`03o`000?oooooooooo00Oooooo000Dooooo`;o00005Oooool3o`00017ooooo1OnX`>/2ojS1j`Ko
Z<3[1_nW_n/2ojJoj`OoYko[0onX`N/4ojW1j`OoYl3[00?oYKk[ojJnjonV_^/00onV_^/8ojS0j`Oo
ZL7[1_nU_^`2ojFnj`KoYko[1_nY`N/6oi>gk`GoNj3Z1Om`TN<6ohfSi0Ko[lW^1Oo?gN<3omoId@03
omc8a_oJb<Oof/S700;of/S71Oo>/[h3oknY``Go]YZk1_nPS;h5oh9j`PCoI6c50omIK/h2obaOd@Go
KI;U1?nd`nD6okg9i003om?Kg_oBiNCod^GT00?od^GT0oo9hnX6okSCkP;oZ/C/1onV_^/3ojNoj`?o
ZL;[2?nZ`n`2ojJnj`GoYKk[1onW_n/2ojW1j`GoZL;[1onW`>/7ojJoj`CoYl3[00?o0000ojS1jonX
`N/01onX`N/=ojNoj`oooooo00?o0000ooooooooool01oooool001Cooooo00?o0000ooooooooool0
4_ooool2o`0001Gooooo00?oZ<3[ojS1jonX`N/01?nX`N/6ojS0j`;oYko[1_nV_n/5ojNoj`;oZ<3[
1onY`N/5ojO0j`;oY[o/1_nV_^/6ojS0j`WoZL7[0onU_^`4ojBmk0OoYko[1_nY`N/6oi>gk`GoNj3Z
1Om`TN<6ohfSi0?o[lW^1_o?gN<4omoId@;og<S60ooJb<L6oljb_P03oknY`onfV[_o]YZk00Co]YZk
1_nPS;h5oh9j`PGoI6c51OmIK/h5offBi@03okC3iOnmbNCo_LWT00Go_LWT0_o<gnH3om;Ui0KobN?Z
0_nhdnh6oj[4k0GoY[k[00?oYko[ojW2jonY`^/01OnY`^/6oj[3k0;oYl3[1_nU_^/6ojNoj`03ojS0
jonY`^_oZL;[00KoZL;[0onW`>/;ojJoj`05ojO0jonX`N_oZ<7[ojS1jol000002OnX`N/=ojNoj`ko
oooo00?o0000ooooooooool01oooool001Cooooo00?o0000ooooooooool03oooool3o`0001Sooooo
1onX`N/3ojS0j`CoYl3[1onV_n/00onW_n_oZ<3[ojS0j`04ojS0j`OoZL7[00?oYl3[ojJok?nV_n`0
1?nV_n`6ojJnj`;oZ<3[2onY`N/2ojO1k0OoY;g/1OnW_n/2ojS0j`KoZL7[1_nC]nl5og^PjPGoL97S
1_n=Xn@00on_bNkocmgSoloMh`04oloMh`CogmWA1?oLb<H00ooJb<Ooc[:noljb_P05oljb_PSo]YZk
1OnPS;h6oh9j`PCoI6c51OmIK/h6ohROh`Ko_LWT1?o<gnH00ooBiNCobN?ZolWSjP04olWSjP;o_]g_
2?nZa>`00onV_^_oYko[ojNoj`03ojNoj`OoZL;[0_nZ`n`6ojO0j`KoYKk[0_nW_n/5ojS0j`KoZL;[
00?oZ<7/ojJojonV_n/02onV_n/00onW_n_oZ<7[ojS1j`02ojS1j`03o`000?nX`N_oZ<7[00CoZ<7[
0onW`>/;ojNoj`?oZ<3[3Oooool00ol0003oooooooooo`07ooooo`005?ooool00ol0003ooooooooo
o`0<ooooo`?o00007?ooool8ojS1j`KoYl3[2?nV_n/6ojS0j`GoZL7[0_nX`N/7ojJok0?oY[k[1?nW
_n/8ojW1j`KoYl7/1onT_N`00onW_n_oZ<3[ojS0j`04ojS0j`KoZL7[1_nC]nl5og^PjPCoL97S1On=
Xn@3ojboj0CocmgS1?oOfM45omc8aPSoc[:n00?oaJNkokJJ^onfV[/01OnfV[/6oj2<_PGoPW[21OmT
K<D5oeU^cPKoR9oS0onmbN@5olcOiP?odNoX0oo9hnX5okkMk`KoZ/C/00?oY[k[ojNojonW_n/01OnW
_n/5ojW2j`;oZ/?/2?nW`>/3ojFnj`?oY[k[1onX`>/2ojW2j`GoZ<7/2OnV_n/5ojNoj`CoZ<7[00?o
0000ojS1jonX`N`01onW`>/7ojNoj`OoZ<3[3?ooool00ol0003oooooooooo`07ooooo`004oooool3
o`0000[ooooo0ol0000Pooooo`SoZ<7[1_nW`>/8ojJoj`KoZ<3[00?oZL7[ojS1jonX`N/01?nX`N/5
ojJok0?oYKk/1_nW_n/5ojW1j`;oZ/7[1onW`N`3ojBmk0CoYKk[1onX`>/3ojW1j`?oY;o]1_n0[?44
of>Gk0CoM9[X00?oL97SohfSi?n/_nP01on/_nP00oo?gN?ogmWAomoId@02omoId@Kog<S600?oe;_1
oljb__o>/[h01?o>/[h2olFW^`Oo]YZk1OnPS;h00onOR[goRWfoohYm_`03ohYm_`?oN7S60_mTK<D6
oeU^cPKoR9oS00?o_LWTolcOi_o<gnH00oo<gnH5om7_j003olWSj_nngNoo_]g_00Go_]g_0_nZa>`5
ojJnj`OoYko[00?oZL;[oj[3k?nZ`n`01?nZ`n`6ojO0j`03ojFnjonV_^_oY[k[00GoY[k[1OnX`>/2
ojW2k0OoZ<7/1_nV_n/8ojNoj`;oZ<7[0_nX`N`00ol0003oZ<7/ojS1k007ojO0j`OoYko[1onX`>/;
ooooo`03o`000?oooooooooo00Oooooo000Dooooo`03o`000?oooooooooo00Kooooo0ol0000Uoooo
o`OoZ<7[0onW`>/4ojO0k0OoY[o[0onX`>/3ojW1j`OoZ<7[00?oY[o/ojFnk?nU_^`01OnU_^`6ojNo
j`03ojW1jonZ`N_oZ/7[00CoZ/7[1OnW`N`2ojFok0OoYKk[1OnX`>/2ojW1j`KoY;o]1_n0[?44of>G
k0GoM9[X1on/_nP3ol78h0?ogmWA1OoLb<H3omBk`@Coc[:n0oo5Yk/8okJJ^`03oj2<__nOR[goWhZm
00?oWhZm1On:OKl5ogQhaPGoFFk>1On8Wn<3oj:hj0?oc=oV1OoAknP3olO/kPGo_]g_0_n]and7ojJn
j`?oYko[0onX`N/8oj[3k0;oYl3[1OnU_^/7ojJnj`03ojS0jonY`^coZL;/00CoZL;/1OnX`N`00onW
_n_oY[o[ojJoj`05ojJoj`KoYko[00?oZ<3[ojS1k?nX`N`00_nX`N`00ol0003oZ<7/ojS1k006ojO0
j`WoYko[0onX`>/3ojS1j`_ooooo00?o0000ooooooooool01oooool001Cooooo00?o0000oooooooo
ool00oooool3o`0002Wooooo1OnX`N/00onX`>_oYl3/ojO0k006ojO0k0GoY[o[0_nW_n/6ojW1j`Go
Z<7[0onX`>/7ojFnk0?oYko[0onX`>/7oj[1j`03ojO1k?nU_ncoYKo/00CoYKo/1onU_^/00onX`>_o
ZL7[ojW1j`04ojW1j`KoY;o]1_n0[?44of>Gk0GoM9[X1?n/_nP6ol78h003omoIdOoLb<Kog<S600?o
g<S61?oD^l43oljb_PGoaJNk1_nfV[/00onbV;goWhZmoin:_@04oin:_@GoRWfo1OmhN<H4ogj<e`;o
FFk>00?oR9oSoj:hj?nR^>P01OnR^>P00oo<gnKodNoXom7_j002om7_j0Koanc^00?o_]g_ojg7kOn]
and01?n]and5ojJnj`;oYko[1_nX`N/6oj[3k003ojS1k?nU_^_oYKk[00KoYKk[0onV_^/3ojNoj`So
ZL;/00?oZ<7/ojNojonW_n/00onW_n/7ojJoj`;oYko[1OnX`>/4ojS1k003o`000?nX`NcoZ<7/00;o
Yl3[3?nW_n/7ojS1j`_ooooo00?o0000ooooooooool01_ooool001?ooooo00Co0000oooooooooooo
oooo0ol0000]ooooo`03ojS1jonX`>_oZ<3[00?oZ<3[2?nW`>`00onV_n_oYko[ojNoj`04ojNoj`Ko
ZL7[00?oZ<7[ojS0jonX`>/01OnX`>/5ojFnk003ojFok?nX`>_oZ<3[00GoZ<3[2?nZ`N/6ojFok0Go
YKk[0_nV_n/7ojW1j`?oY;o]1?nM_Nl4og6VlP;oD9;^0_mSUn`6ogBJj003ojboj?o1b>3o`LSP00Go
`LSP0_o<b=L4omc8aPKoe;_100?oc[:nolFW^oo5Yk/01?o5Yk/5okJJ^`?o/YRm1OnOR[d5ohYm_`Ko
N7S61OmnS=L7oj:hj0Co_n3`00?odNoXolO/k_o7k>h01?o7k>h00onlgo7o[LO]ojg7k@06ojg7k@03
ojJnjonW_n_oYko[00CoYko[1_nX`N/2oj[3k0GoZ<7/1_nU_^/00onV_^_oYko[ojNoj`05ojNoj`Oo
ZL;/1onW_n/5ojJoj`;oYko[1onX`>/3ojS1k003ojS0jol0003oZ<3[00ooYko[1onX`N/:ooooo`03
o`000?oooooooooo00Kooooo000Cooooo`Co0000<_ooool5ojS0j`KoYl3/0_nV_n`7ojNoj`KoZL7[
2?nX`>/00onU_^coYKo/ojFok003ojFok0OoZ<3[2?nZ`N/6ojFok003ojFnjonV_n_oY[o[00CoY[o[
1OnY`N/2ojW1jPOoWKg_1?maY_84oe2BkP?oM9[X0on9[Nd6ol78h0Coc<SG0ooLb<H6omBk`@OoaJNk
0onfV[/5ok:H_@KoWhZm1On:OKl5ogQhaPKoOXcG1?nR^>P5okoPl0;oaOO/1?o7k>h4okcOl@Ko[LO]
00?oY[k[ojNojonW_n/01_nW_n/3ojS1j`?oZ/C/1onX`N`2ojFnj`GoY[k[1onW_n/7ojW2k0OoYko[
00?oY[o[ojNojonW_n/01?nW_n/5ojS0j`;oZ<7/1?nX`>/00ol0003oZ<3[ojNoj`0>ojNoj`KoZ<7[
2_ooool00ol0003oooooooooo`06ooooo`004oooool2o`0003Gooooo1OnX`>/2ojO0k0KoY[o/1OnW
_n/2ojS0j`KoZL7[1_nX`>/2ojO0k0KoYKo/1OnX`>/2ojW0j`SoZ/7[0onU_n`3ojBok0OoY[o[00?o
ZL7[ojW1j_nY`NX01?nY`NX7oifmk`CoLJKb1?m@T^h6ohV]k@?o`LSP1oo<b=L00ooLb<Koe;_1omBk
`@05omBk`@03om2ja?o5Yk_oaJNk00GoaJNk00?o]YZkok:H_OnbV;d01?nbV;d6oin:_@GoRWfo1_mh
N<H6ogj<e`03oj:hj?noh?3o_n3`00Co_n3`1?o5mn`00oo7k>ko_=oaokcOl@05okcOl@;o[LO]1OnV
_^/6ojNoj`03ojS1k?nZa>coZ/C/00GoZ/C/1OnX`N`8ojJnj`KoYko[2OnY`^`3ojNoj`?oY[k[2?nW
_n/00onX`>_oZ<7/ojS1k004ojS1k0?oZ<3[00?o0000ojS0jonX`>/03OnW_n/8ojS1j`Wooooo00?o
0000ooooooooool01_ooool000Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o
0000ooooooooool0<oooool6ojS0j`OoY[o/00?oYko[ojS0jonX`>/01?nX`>/6ojW1j`;oZ<3[1_nW
`>`6ojFok003ojS0jonY`>_oZL3[00CoZL3[1_nZ`N/2ojW1j`KoY;o/1OnV_n/2ojNoj`OoZL7Z0onM
_Nl4oiRkl0?oIZGe00?oLJKboe2Bk_m@T^h00_m@T^h6ohV]k@03ol78h?o<b=Ooc<SG00Goc<SG00?o
blKFomBk`OoD^l401OoD^l42om2ja0OoaJNk2?nbV;d5oin:_@GoRWfo1_mhN<H5ogj<e`?oWkW[0ono
h?05olGgk0Co_^gc0onlgo43oj_4k0OoY[k[0_nW_n/5ojS1k0OoZ/C/00?oZ<7/ojJnjonV_^/02_nV
_^/2ojNoj`_oZL;/00?oYko[ojJnjonV_^/01OnV_^/6ojNoj`03ojO0jonX`NcoZ<7/00KoZ<7/0onX
`>/00ol0003oYko[ojNoj`09ojNoj`coZ<7[2?ooool00ol0003oooooooooo`06ooooo`0000GoV9RH
ob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02Oooool00ol0003ooooo
ooooo`0cooooo`KoZ<3[1onV_n`7ojS0j`OoZL7[1onW`>`3ojFok0?oY[o[1onY`>/2oj[1j`KoZL7[
1_nT_n`00onV_n_oYko[ojNoj`04ojNoj`OoZL7Z1onH^o04ofJUm@?o@Y;`00CoD9;^ohV]kOn9[Ngo
RJg]0onF^_46olc8e`?oblKF1OoD^l44om2ja0GoaJNk0_o2[<<7ok:H_@KoWhZm1On:OKl6ogQhaP03
ogj<eonO^N_oWkW[00GoWkW[00?o_n3`olGgk?o5mn`00_o5mn`5okk]l`03okCElOn[a>coZlC/00Go
ZlC/1OnV_^/2ojNoj`OoZ<7/0onZa>`3ojS1j`_oY[k[0onW_n/9ojW2k0GoYko[1onV_^/2ojNoj`Go
Yl3[1_nX`N`00onX`N_oYko[ojNoj`02ojNoj`03o`000?nW_n_oYko[00KoYko[3OnX`N/00onW`>_o
ooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00001?ooooooV9RHob4Q8Oo^k^h4ooooo`05
oa0@4?ooooooooooooooool@41002_ooool00ol0003oooooooooo`0cooooo`KoZ<3[1onV_n`8ojS0
j`KoZL7[1OnW`>`2ojJok0KoY[o[1OnY`>/:ojW1j`?oY;o/0onS_^d7ojNoj`OoZL7Z1onH^o04ofJU
m@Co@Y;`1_nF^_43olc8e`KoblKF0ooD^l45om2ja0CoaJNk0oo2[<<7ok:H_@KoWhZm0on:OKl2oiBE
d@OoTYoM1_nO^N/4okK`m@03olGgk?nnkO?o_^gc00;o_^gc1?ndeO47oj_4k003ojJnjonW_n_oYko[
00CoYko[1OnX`N`2oj[4k@KoZ<7[1onV_^/7ojNoj`OoZL;/1onW_n/3ojJnj`?oYko[2?nW`>/2ojS1
k0GoZ<7[1?nW_n/00ol0003oYko[ojNoj`06ojNoj`WoZ<7[1OnW`>/7ooooo`03o`000?oooooooooo
00Kooooo0002ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000;oooo
o`;o0000=?ooool3ojS0j`?oYl3[1onV_n`8ojS0j`KoZL7[00?oYl3/ojJok?nV_n`01?nV_n`6ojJo
j`03ojW0jonY`N_oZL7[00coZL7[1_nS_^d5ojNoj`;oYl3[1onY`NX7oiRkl0?oHZOg00?oIZGeod:B
l?m2T_000_m2T_06oiJjl@03olc8eoo;a]KoblKF00KoblKF00?oe;_1om2ja?o@^/@01?o@^/@3olFW
^`Go`Zc31onbV;d3oin:_@;oY9g>1_nDUM47oi:Og@?oWkW[1Onfl?D3okOfl003okk]londeO7o]=Ga
00Go]=Ga0on[a>`3ojJnj`SoYko[00?oZ<7/oj[4kOnZa>d01?nZa>d6ojS1j`OoY[k[1onW_n/7ojW2
k0GoYko[0_nV_^/6ojNoj`KoYl3[00?oZ<7/ojS1jonX`N/01_nX`N/3ojNoj`03o`000?nW_n_oYko[
00OoYko[0onX`N/3ojS1k0SoYl3[1oooool00ol0003oooooooooo`05ooooo`000oooool00omgMgOo
IVIVooooo`02ooooo`05o`000?ooooooooooooooool000003Oooool00ol0003oooooooooo`0boooo
o`KoYl3[1OnV_n`3ojJoj`OoZ<3[1_nY`N/7ojJok0?oY[o[1?nW_n/>ojW1j`KoXkk]00?oYko[ojO0
jonW`>/01?nW`>/5ojW1jP?oZL3Z1_nH^o04of:Wm`?o=9;`00Co@Y;`oiJjlOnF^_7oU[[a0_nB`_L8
ol_6eP03ol79h?o@^/Cod;[400Kod;[400?oaJNkol:/`oo2[<<01?o2[<<6ok:H_@03okB^d_nTWLko
Y9g>00CoY9g>1_nDUM47oi:Og@03oinijonfl?Go]_3e00;o]_3e1?ngm_03okCTm`Go]=Ga0_nW_nX6
ojJnj`KoYko[00?oZ<;/oj[4kOnZa>d01_nZa>d3ojS1j`?oY[gZ1onV_^/3ojNoj`?oZ<;/2?nY`^`0
0onW_n_oY[k[ojJnj`04ojJnj`KoYko[0_nW`>/5ojS1k0KoZ<7[1OnW_n/00ol0003oYko[ojNoj`05
ojNoj`;oZ<7[1_nX`N`6ojO0j`03ojNojooooooooooo00Gooooo00?o0000ooooooooool01Oooool0
00Cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00cooooo00?o0000
ooooooooool0<_ooool6ojO0j`03ojJok?nV_n_oY[o[00GoY[o[1OnX`>/2ojW0j`KoZL7[1OnV_n`3
ojFok0KoYko[1OnY`N/2ojW1jPOoZL7[0onS_^d3oj>ok@OoYl3[00?oZL7ZojW0j_nY`>X01OnY`>X6
oiRkl0CoHZOg1?ldT_05oi;2m`KoblKF0oo1bN06om2ja003olO2e_o2[<?o`Zc300Go`Zc31?nbV;d4
okB^dPKoY9g>1OnDUM46oi:Og@?oY=_k00Co]_3eokOfl?ngm_3o]oK`1ondi?L00ondeO7oYkoZojNo
jP04ojNojPKoY[k[0_nW_n/5ojS2k0KoZ/C]00?oYko[ojJmj_nV_NX01OnV_NX5ojJnj`;oYko[1_nX
`^`6ojW2k003ojNojonV_^_oY[k[00KoY[k[0onW_n/3ojO0j`OoZ<7/0_nX`N/9ojNoj`04o`000?nW
_n_oYko[ojNoj`KoZ<7[1_nX`N`2ojO0j`GoYko[1_ooool00ol0003oooooooooo`05ooooo`0000Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03oooool00ol0003o
ooooooooo`0booooo`?oYl3[1?nW`>`7ojJoj`03ojS0jonY`>_oZL3[00CoZL3[1_nY`N/00onV_nco
YKo/ojFok005ojFok0KoYko[00?oZL7[ojW1j_nY`NX01?nY`NX5ojW1j`;oZ<3[1_nS_nd7ojO0j`So
ZL3Z0onH^o03oiflkP?oIjch00?oHZOgocBBl?ldT_000_ldT_05oi;2m`?oblKF1_o1bN04om2ja0?o
al;F1oo2[<<00onbV;go]:kBokB^dP04okB^dPKoY9g>1_nDUM42oi:Og@GoY=_k0onNlnd3oj_Zn@Go
]>Cg0_nZ`n`7ojNojP?oY[k[0onW`>/7ojS2k0;oZ/C]1OnW_n/7ojJmjP03ojJnjonW_n_oYko[00Co
Yko[1_nX`^`2ojW2k0GoYko[1_nV_^/00onW_n_oYl3[ojO0j`05ojO0j`GoZ<7/00?oZ<7[ojNojonW
_n/02_nW_n/00ol0003oYko[ojS1j`07ojS1j`?oZ<7/0_nW`>/8ojNoj`Gooooo00?o0000oooooooo
ool01Oooool00005oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
013ooooo0_l0000dooooo`KoYl3/1OnV_n/2ojNoj`OoZL3[0onY`N/3ojS0j`SoYKo/0onW_n/3ojO0
j`OoZL7Z00?oZL7[ojS0jonX`>/01?nX`>/6oj>ok@OoYl3[1onY`>X7oiflkPGoIjch0_l/Tnl00old
T_3oT/;goi;2m`03oi;2m`03ol_6e_o1bN3o`LWP00Go`LWP0oo@^/@5olO2ePGo`Zc300?o^l;OokB^
d_nd[]801Ond[]87ojBMcP?oU9GA1?nRcOL3ojCKn`?oW_?]1_n[j_T00ondi?OoZ/?/oj[3k004oj[3
k0GoYkoZ0_nW_n/6ojO0j`GoZ<;/0_nY`n`7ojNoj`?oY[gZ0onV_^/8ojNoj`?oZ<;/0onY`^`7ojNo
j`;oY[k[1OnW_n/7ojO0j`03ojS1k?nX`N_oZ<7[00?oZ<7[2onW_n/00ol0003oYko[ojNoj`06ojS1
j`03ojS1k?nW`>_oYl3[00CoYl3[1onW_n/5ooooo`03o`000?oooooooooo00Gooooo000Oooooo`03
o`000?oooooooooo03;ooooo1_nW`>`00onV_n_oYko[ojNoj`04ojNoj`OoZL3[1_nX`>/8ojFok0Ko
Yl3[1onY`NX7ojS0j`KoXko]1onW`>/7ojW0jPOoWKc^1OmW[?P4obbCk`CoM<7n2?o1bN000oo@^/Co
al;FolO2eP04olO2eP?o`Zc31?nk`]l7okB^dPGoY9g>0_nUc_H7oj;=m`04ojCKnonNlngoW_?]oikc
k@KoZn[i00?o[<[_oj[3k?nZ`n`01_nZ`n`00onW_n[oYko[ojNoj`04ojNoj`KoYl3[00?oZ<;/ojW3
k?nY`n`01?nY`n`5ojNoj`03ojJmj_nV_^_oY[k[00GoY[k[1_nW_n/8ojW2k0GoYko[0_nW_^/7ojNo
j`?oYl3[0onX`^`7ojS1j`_oYko[00?o0000ojNojonW_n/00_nX`N/5ojS1k0KoYl3[1onW_n/4oooo
o`03o`000?oooooooooo00Gooooo000Pooooo`03o`000?oooooooooo03;ooooo0onW`>`3ojJok0Oo
Yko[1onY`>/6ojS0j`SoYKo/1_nW`>/7ojW1jPOoZ<3[1_nS_nd5ojO0j`;oYl7/1onY`>X5oiflkP;o
YKk/1_mk/_H2ocNNl`03obbCkomd`OkoM<7n00;oM<7n1_o1bN02ojWHn0Ooal;F00?o`Zc3ok_2gonk
`]l01?nk`]l6okB^dP;oY9g>1_nUc_H5oj;=m`?oPnWY0onMjOX2oj_Zn@Go[<[_1_nZ`n`00onV_^_o
Yko[ojNoj`06ojNoj`?oYl3[0onYa>d7ojW3k003ojNojonV_N[oY[gZ00?oY[gZ1onV_^/2ojNoj`co
ZL;/00?oYko[ojNnjonW_^/01?nW_^/5ojNoj`03ojO0jonX`^coZ<;/00GoZ<;/1OnX`N/=ojNoj`03
o`000?nX`>_oZ<7/00OoZ<7/0onW`>/:ojNoj`?ooooo00?o0000ooooooooool01Oooool0027ooooo
00?o0000ooooooooool0<_ooool6ojJok0SoYko[1_nY`>/7ojS0j`OoYKo/1_nW`>/7ojW1jPOoZ<3[
1_nS_nd00onW`>_oYl7/ojO1k004ojO1k0OoZL3Z00?oWKc^ojFnk?nU_^`01?nU_^`6og^bmPGo=ikc
00Co<JO`ogC1o_o1bN3o`LWP1_nYf?P5olO2eP;oZmch1_nk`]l5okB^dP?oXm[k1onUc_H01?nRcOOo
PnWYoh?YjOn3jNT5oigYnP?oZ/kc1_n/b^l2oj[3k0GoY[k[1_nW_n/00onX`^goZLC]ojW4k@05ojW4
k@GoZL?/00?oYkkZojJmj_nV_NX01OnV_NX5ojJnj`;oYl3/2_nY`^`3ojNoj`SoYkk[00?oYko[ojO0
jonW`>/00onW`>/7ojS2k003ojS1jonW_n_oYko[00coYko[0_nX`>/00ol0003oZ<3[ojS0j`06ojS1
k003ojS0jonW_n_oYko[00_oYko[1?ooool00ol0003oooooooooo`04ooooo`008_ooool00ol0003o
ooooooooo`0booooo`KoY[o/2?nW_n/7ojW0j`KoZ<3[1onU_n`6ojO0j`GoZL7Z0_nY`>X7ojS0j`Ko
Xko]1onW`N`7ojW0jPOoYKk/0omk/_H4oi>il@GoGk7k0_lRVn/00olaYo3oZMShojWHn004ojWHn003
olO2e_n[g?SoZmch00CoZmch1_nk`]l00ond[];oXm[koj?Jn`05oj?Jn`?oYLkf0omZg>@5ohgTn`03
oigYn_nZc_?oZ/kc00GoZ/kc0on/b^l3ojNnjPOoY[k[0_nW_n/5ojS2k@OoZLC]00?oZL?/ojNnj_nW
_^X00onW_^X7ojJmjP03ojJnjonW`>coYl3/00CoYl3/1OnY`^`2ojS1k0KoYko[1_nW_^/00onW_n_o
Yl3[ojO0j`05ojO0j`?oZ<;/0onX`N/>ojNoj`CoZ<3[00?o0000ojS0jonX`>/00_nX`N`5ojS0j`go
Yko[0oooool00ol0003oooooooooo`04ooooo`008oooool2o`0003?ooooo1onV_n`7ojNoj`OoZL3[
1_nX`>/7ojFok0KoYl3[00?oZL7ZojW0j_nY`>X01?nY`>X5ojS0j`;oZL3Z1_nS_nd5ojO1k0?oY/7/
1_nY`>X5ojFnk0;oZL3Z1onC^O45oenan`Go8Y_[1?m>`_@7oj_Ln0?o^l;O1On6h_/3oj?Jn`CoDlkO
1?n2g?d3ohgTn`CoYLcd1OnZc_<8ojNnjPGoY[k[0_nW`N`7ojS2k@?oZLC]0onX`>/7ojNnjP?oY[gZ
1?nW_n/7ojO0k003ojW2k?nX`NcoZ<7/00CoZ<7/1_nW_n/2ojNnj`GoYko[1OnW`>/2ojS2k0KoZ<7[
3_nW_n/3ojS0j`03ojS1k?l0003oZ<7/00SoZ<3[3OnW_n/2ooooo`03o`000?oooooooooo00Cooooo
000Uooooo`03o`000?oooooooooo03;ooooo1_nV_n`5ojNoj`;oYl3[1onY`>/6ojS0j`OoYKo/1_nW
`>/7ojW0jP03ojS0jonY`>[oZL3Z00CoZL3Z1_nS_nd00onW`NcoY/7/ojK1k005ojK1k0KoZL3Z00?o
YKk/ojW0j_nY`>X01?nY`>X5oi>il@;oY;g[1_n5]oH6oe>en`03obNXj?m>`_CoZmch00;oZmch1_lk
_N<3ohKRn`Go@/;S00?oDlkOoh;LoOn2g?d01?n2g?d2oj;7l`OoYLcd00?oZ/kcojNnj_nW_^X02_nW
_^X00onV_^_oYl7/ojO1k004ojO1k0GoZ<;]0_nY`^`6ojS0j`GoYkkZ0_nV_^X7ojNoj`?oYl3/0onX
`^`8ojS1k0?oYko[0_nW_^/8ojNoj`03ojO0jonX`^coZ<;/00CoZ<;/1_nX`N/<ojNoj`;oZ<7[1?nX
`N`00ol0003oZ<7/ojS0j`05ojS0j`goYko[00CoZ<7[oooooooooooo00001_ooool002Kooooo00?o
0000ooooooooool0<_ooool6ojJok003ojNojonW`>_oYl3[00CoYl3[1onY`>/6ojS0j`OoYKo/1_nW
`>/>ojW0jP?oXko]0onT_^`8ojK1k0?oZL3Z1?nX`N/6ojW0jP03oi>ilOnT_N_oY;g[00CoY;g[1_n5
]oH3oe>en`CoQk[f1_mY`_h3odJml`CoR/Sl1_n1dol2oh;Lo@KoX/Oc0onUc?@>ojNnjP?oYl3/1onW
`N`00onX`^goZL;/ojW2k004ojW2k0KoZ<3[00?oYkkZojJnj_nV_^X01?nV_^X5ojNoj`SoZ<;/1_nX
`N`00onW_n_oYkk[ojNnj`04ojNnj`KoYko[00?oZ<7/ojS2k?nX`^`01_nX`^`3ojS1j`_oYko[1_nX
`N/3ojS1k003o`000?nX`NcoZ<7/00;oZ<3[3OnW_n/5ojS1j`03ooooool0003ooooo00Gooooo000W
ooooo`03o`000?oooooooooo03;ooooo1_nV_n`7ojO0j`OoZL3[1_nX`>/7ojFok0KoYl3[3_nY`>X6
ojBnk0KoY/7/0_nT`>d7ojS1j`KoZL3Z1onT_N/3ohFgmPCoX[c/1_n7^_H3ofW2oPCoU[gb1_n:b?`3
oh7Co`CoXL3_1OnRao<2ojRnjPcoYkkZ00?oYl3[ojO0k?nW`>`01OnW`>`5ojO1k003ojS3kOnY`^co
ZL;/00KoZL;/0onX`>/3ojJmjPOoY[kZ00?oYko[ojS2k?nX`^`02_nX`^`2ojS1k0GoYko[1_nW_^/2
ojNoj`GoZ<7/1_nX`^`00onX`>_oYko[ojNoj`0;ojNoj`SoZ<7[0onX`N`00ol0003oYl3[ojNoj`0>
ojNoj`KoZ<7[00?o0000ooooooooool01?ooool002Sooooo0_l0000cooooo`KoY[o/1onW`>/7ojW0
j`KoZ<3[1onU_n`3ojO0j`?oYl3/3_nY`>X6ojBnk0;oY/7/1_nT`>d5ojS1j`;oYl;/1_nY`>X5ojBm
j`;oZL3Z1onR_>`3ohNjmP?oY;g[1onF_O83oh[8o0?oY;k[1onQ`>l00onRao?oZ;kZojRnjP04ojRn
jPSoYkkZ1OnW`>/7ojO0k003ojO1k?nX`ngoZ<?]00?oZ<?]1_nY`^`00onW_NWoY[gZojJmjP05ojJm
jPGoY[kZ00?oYl3[ojS2k?nX`^`02OnX`^`3ojS0j`OoYko[0onW_^/4ojNoj`KoZ<7/0_nX`^`5ojS0
j`goYko[1_nX`N/00onX`NcoYl3[ojO0j`02ojO0j`03o`000?nW`>_oYko[00koYko[0onX`N/2oooo
o`03o`000?oooooooooo00Cooooo000Zooooo`03o`000?oooooooooo037ooooo1_nV_n`7ojO0j`Oo
ZL3[1_nX`>/7ojFok0KoYl3/3_nY`>X3ojBnk0CoYKo[1onT`>d00onX`N_oYl;/ojO2k004ojO2k0Ko
ZL3Z00?oY;g[ojW0j_nY`>X01?nY`>X5oj:lk0;oZL3Z1_nT_N/5oiJmlP;oYkkZ1_nT_^/5oj70k`;o
Z;oZ1onX_^X3ojNnjP[oYl3[0onW`>`4ojS4kPKoZ<?]0_nY`^`5ojNmj@OoY[gZ00?oY[kZojO0jonW
`>/00onW`>/7ojS2k0OoZ<3[1OnW_n/00onW_^_oYko[ojNoj`06ojNoj`?oZ<7/0_nX`^`8ojS0j`go
Yko[0_nX`N/5ojS1k0CoYl3[00?o0000ojO0jonW_n/03?nW_n/7ooooo`03o`000?oooooooooo00?o
oooo000[ooooo`03o`000?oooooooooo037ooooo1_nV_n`7ojO0j`OoZL3[1_nX`>/7ojFok0KoYl3/
3?nY`>X2oj[0jPOoYKo[0onT`>d4oj>ok@OoYl;/0onY`>X3ojS1k0OoZL3Z00?oX[c/ojW0j_nY`>X0
1?nY`>X6ojBmj`03oiJml_nW_^[oYkkZ00CoYkkZ1_nT_^/00onQ`>ooZ;oZojRojP04ojRojPGoZ;kZ
3OnW`>/2ojO4kPOoZ<C^0onX`nd3ojNnjPOoYkgY0onV_NX3ojNoj`OoYl3[1onX`^`7ojS0j`03ojNo
jonW_^_oYkk[00?oYkk[1_nW_n/00onX`NcoZ<;/ojS2k004ojS2k0KoZ<3[3OnW_n/9ojS1k0?oYl3[
00?o0000ojNojonW_n/02OnW_n/:ooooo`03o`000?oooooooooo00?ooooo000/ooooo`03o`000?oo
oooooooo037ooooo1_nV_n`7ojO0j`OoZL3[1_nX`>/7ojFok0OoYl3/1onY`>X6oj[0jPGoYKo[0_nX
_nX7oj>ok@GoYl;/0_nU`Nd6ojS1k0GoZL3Z0_nX`N/7ojW0jP?oY;g[0onY`>X7ojNnjP?oY;k[0onX
`>X7ojRojP03ojRnj_nW`>_oYl3[00_oYl3[1_nWa>h5ojS4kP;oZ;oZ1_nW_^X5ojNmj@;oYkkZ1_nW
_n/5ojO0j`WoZ<;/0onX`>/3ojNnjPOoYkk[0_nW_n/5ojS1k0KoZ<;/0_nX`>/=ojNoj`_oZ<7/00?o
Yl3[ojNojonW_n/00_nW_n/00ol0003oYko[ojNoj`05ojNoj`gooooo00?o0000ooooooooool00ooo
ool002gooooo0_l0000booooo`KoY[o/1onW`>/7ojW0j`KoZ<3[1onU_n`7ojO0k0?oZL3Z0onY`>/7
oj[0jP03ojFojonX_n[oZ;oZ00CoZ;oZ1onS_nd00onW`^coYL7]ojG1k@04ojG1k@KoZ<7/00?oZL3Z
ojS1jonX`N/01?nX`N/5ojW0jP03ojS1k?nY`>[oZL3Z00GoZL3Z1OnW_^X2ojS0j`KoZ<3Z1OnX_nX2
ojO1k0[oYl3[2_nWa>h00onXa>koZ;oZojRojP04ojRojPKoYkkZ00?oYkgYojNnj_nW_^X01?nW_^X6
ojNoj`03ojO0jonX`^coZ<;/00WoZ<;/0_nW_n/6ojNnjPGoYkk[0_nW`>/7ojS1k0?oZ<;/0onW`>/>
ojNoj`SoZ<7/1OnW`>/4ojNoj`04o`000?nW_n_oYko[ojNoja3ooooo00?o0000ooooooooool00ooo
ool002oooooo00?o0000ooooooooool0<?ooool7ojJok0KoYl3[1onY`>/6ojS0j`OoYKo/1OnW`>`2
ojK0k0KoZL3[1onZ`>X7ojRojP?oXko]0onU_^`8ojG1k@?oZ<7/0_nV`^d8ojS1j`03ojW0j_nX`Nco
Z<7/00?oZ<7/1onY`>X00onW_^[oZ<3[ojS0j`04ojS0j`KoZ<3Z00?oZ;oZojO1k?nW`N`01?nW`N`5
ojO0j`03ojO3k_nWa>koYlC^00WoYlC^2_nX_nX=ojNnjP?oYko[2onX`^`6ojNoj`KoYkkZ00?oYkk[
ojO0jonW`>/01?nW`>/6ojS1k0OoYl3[3_nW_n/5ojS1k0SoYl3[0onW_n/00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo00?ooooo000`ooooo`03o`000?oooooooooo037ooooo1_nV_n`7ojO0
j`KoZL3[1onX`>/6ojFok003ojO0k?nV`>coY/3/00CoY/3/1_nY`>/7oj[0jPGoZ;oZ0_nY_nT6ojFn
k0KoYL7]00?oY;o/ojK2kOnV`^d01?nV`^d6ojS1j`03ojK2kOnX`NcoZ<7/00GoZ<7/0onY`>X3ojO2
k@SoZ<3[0onX`>X3ojO2k@OoYl7/00?oYl3[ojO3k_nW`nh00onW`nh6ojO4kP03ojNojonX_n[oZ;oZ
00[oZ;oZ3OnW_^X00onW`NcoZ<;/ojS2k008ojS2k0_oYko[0onW_^X3ojNoj`OoYl3[1_nX`N`7ojO0
j`coYko[1onX`N`6ojO0j`Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`03oooo
o`00<Oooool00ol0003oooooooooo`0aooooo`OoY[o/1_nW`>/7ojW0j`OoZ<3[0_nU_n`4ojJok0Ko
Y/3/0onY`>/3ojS1j`OoZ/3Z00?oZ;oZojVojOnY_nT01?nY_nT6ojFnk0;oYL7]1OnT_n`6ojK2k@;o
Z<7[1OnV`^d5ojS1k0;oY/;^1_nW`^d6ojS0j`03ojO3k_nW`^goYl;]00GoYl;]0onW`N`3ojK3kPOo
Yl?^0_nWa>h5ojNoj`SoZ;oZ3OnW_^X5ojO1k0GoZ<;/0_nX`N/<ojNoj`03ojNnjonW_n_oYko[00Go
Yko[0onW`>/3ojS2k0OoZ<7/0onW`>/<ojNoj`_oZ<7/0_nW`>/9ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool00oooool003;ooooo0_l0000booooo`OoY[o/1_nW`>/7ojW0j`GoZ<3[
0_nY`>X6ojJok0CoY/3/0onU`>d5ojS1j`GoZ/3Z0_nY`>X7ojVoj@?oYKk/1?nX_nX6ojBok0?oY/;]
1?nT`>d6ojK2k@03ojS1k?nV`^koY/;^00CoY/;^1_nW`^d2ojS0j`GoYl?^1OnW`^d2ojK1k@KoY/?^
1OnW`nh2ojNnjPOoYko[0onX_nX3ojNnj@[oYkkZ2_nW`N`00onX`^coZ<7[ojS1j`04ojS1j`SoYko[
1OnW_^/5ojNoj`;oZ<7/1_nX`^`5ojS1k0goYko[00?oYl3[ojS1k?nX`N`02OnX`N`>ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool00_ooool003Cooooo00?o0000ooooooooool0<?oo
ool7ojJok0?oYl3[0onW`>`7ojW0j`03ojS0jonY`>[oZL3Z00CoZL3Z1_nV_n`00onV`>coYL3]ojG0
k@04ojG0k@GoZ<7[00?oZ/3ZojW0j_nY`>X01?nY`>X5ojVoj@;oZL3Z1onX_nX3ojBok0?oYkkZ1onT
`>d3ojK2k@?oYL3]1onV`^h3ojO2k@CoYL;^1_nW`nh00onW`^goY/7]ojK1k@04ojK1k@KoY/?^00?o
Yl?^ojNnj_nW_^X01?nW_^X5ojNoj`SoYkkY1OnW_^X2ojO0j`[oYl7/0onX`^`7ojS1j`?oYko[0onW
_^X7ojNnj`03ojNojonX`NcoZ<7/00CoZ<7/1_nX`^`00onX`NcoYko[ojNoj`0;ojNoj`GoYl3[1_nX
`N`Booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool003Gooooo00?o0000
ooooooooool0<?ooool7ojJok0KoYl3/1onY`>/7ojW0jP?oY[o/1?nW_n/6ojG0k@;oZ<7[1?nW`N`6
ojW0jP03ojVojOnY`>[oZL3Z00CoZL3Z1OnX_nX2ojVoj@KoYkkZ1OnT`>d2ojNnjPKoYL3]1OnV`^h2
ojFok0OoYL;^0onW`nh3ojJok0OoY/7]0onV`nh:ojNnjP03ojNojonW_^WoYkkY00[oYkkY00?oYkkZ
ojO0jonW`>/01?nW`>/5ojO1k0SoZ<;/1OnX`N/8ojNnjPGoYkk[00?oYl3/ojS1k?nX`N`01_nX`N`3
ojS2k0;oYl3[3_nW_n/6ojO0j`;oZ<7/5_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00;ooooo000fooooo`03o`000?oooooooooo033ooooo1onV_n`6ojO0k0OoZL3[1onY`>X7ojNo
j`?oYL3]0onU_n`6ojO1k0?oZL3Z0onX`N/7ojW0jP03ojRoj_nY_nWoZKoY00CoZKoY1_nW_^X00onT
`>goYkkZojNnjP04ojNnjPKoYL3]00?oY/;^ojFok?nU_n`01?nU_n`5ojG2kP;oYkkZ1_nV_n`5ojK1
k@;oZ;kY2_nW_^X3ojRnj@[oYkkY2_nW`>/00onW`NcoZ<;/ojS2k00:ojS2k003ojS1jonW_^[oYkkZ
00[oYkkZ00?oYkk[ojO0k?nW`>`00onW`>`7ojS1k0KoYl3[3_nW_n/3ojO0ja_ooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`02ooooo`00=oooool2o`0003;ooooo1_nV_n`7ojO0k0Ko
ZL3[1onY`>X5ojNoj`;oZ;o[1_nU_n`4ojO1k0;oY/3]1_nX`N/5ojW0jP;oZL3[1onY_nT3ojNnjP?o
ZKoY1onW_^X3ojG0k@CoYkkZ1_nU_n`00onU`^koYkkZojNnjP04ojNnjPKoY[o/00?oY/7]ojRnjOnX
_^T01?nX_^T5ojNnjP03ojRnj_nX_^WoZ;kY00GoZ;kY1OnW_^T=ojO0j`03ojO2kOnX`^coZ<;/00So
Z<;/0onW_nX:ojNnjPCoYko[1_nW`>`7ojS1k0KoYl3[3?nW_n/Pooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool00_ooool003Wooooo00?o0000ooooooooool0<?ooool6ojJok0OoYl3/
0onY`>/3ojS0j`OoZL3Z00?oYko[ojRojonX_n/01?nX_n/6ojFok003ojO1k?nV`>goY/3]00?oY/3]
1_nX`N/00onY`>[oZL3[ojW0j`04ojW0j`GoZKoY0_nY`>X6ojVoj@GoYkkZ0_nY_nT7ojNnjP?oYKo/
0onX_^T7ojNnjP?oY[o/2_nX_^T00onW_^[oZ;kZojRnjP03ojRnjPOoZ;kY00?oYkkYojO0jonW`>/0
2onW`>/5ojO2k@GoZ<;/0_nW_n/6ojNojPGoYkkZ2OnW_n/3ojO0k0[oZ<7/0onW`>/;ojNojb?ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`02ooooo`00>_ooool00ol0003ooooooooo
o`0`ooooo`KoY[o/1OnW`>`2ojK0k0KoZ<3[1onY`>X7ojRoj`?oYKo/0onV_n/6ojK0k@?oZ<7[1?nW
`N`6ojW0j`03ojVojOnY`>[oZL3Z00CoZL3Z1_nY_nT00onW_^[oZKoYojVoj@04ojVoj@GoYkkZ0_nY
_nT6ojRnj@GoYkkZ00?oZ;oYojRnjOnX_^T02OnX_^T2ojRojPOoZ;kZ0onX_^T=ojO0j`[oYl;]00?o
Z<;/ojNojonW_n/01?nW_n/6ojNojP03ojNnj_nW_n_oYko[00WoYko[00?oZ<;/ojS1k?nX`N`02_nX
`N`;ojNojbSooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`00>oooool0
0ol0003oooooooooo`0`ooooo`KoY[o/00?oYl3/ojK0k?nV`>`01?nV`>`6ojS0j`OoZL3Z1OnX_n/2
ojRojPKoY[o[1?nV`>d2ojFok0OoYl7/0onY`>/3ojS1k0OoZL3Z0onY_nT4ojW0jPKoZKoY00?oYkkZ
ojVojOnY_nT01?nY_nT6ojRnj@03ojNnj_nX_nWoZ;oY00?oZ;oY1_nX_^T7ojRojPGoZ;kZ0_nW`N`;
ojO0j`coYl;]2_nW_n/6ojNojPSoYko[1OnX`^`8ojS1k0[oYko[;Oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo007ooooo000looooo`03o`000?oooooooooo033ooooo0onV_n`3ojNo
j`OoY/3/0onX`>/4ojS1j`KoZL3Z00?oZ;o[ojRoj_nX_nX01?nX_nX6ojJoj`03ojK0kOnU_ncoYKo/
00?oYKo/1OnW`N`2ojG0k@KoZ<7/1OnY`>X2ojS1k0OoZL3Z0onY_nT3ojS0jPOoZKoY0onX_^T3ojRo
jPKoZ;oY0_nX_^T;ojRojP03ojRnj_nW`NcoYl7/00CoYl7/1onW`>/;ojO2k@coYko[0_nW_^X7ojNo
jP?oYko[0onW`N`7ojS2k0?oZ<7/2onW_n/aooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool00Oooool003gooooo0_l0000aooooo`KoYko[1onV`>`7ojS1j`?oZL3Z0onY`>/7ojRojP?o
Y[o[0onX_n/6ojFok003ojO1k?nU`>goYL3]00CoYL3]1_nX`N`00onY`>[oZ<7/ojS1k004ojS1k0Go
ZL3Z0_nX`N`6ojS0jPGoZKoY00?oZ<7[ojRoj_nX_nX01OnX_nX3ojRoj@?oZ<3[2_nX_nX:ojO1k0?o
Yl3[2onW`^d;ojNoj`OoYkkZ1OnW_nX8ojO1k0GoZ<;/0_nX`>/:ojNojcCooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`01ooooo`00?oooool00ol0003oooooooooo`0_ooooo`KoYko[
1onV`>`5ojS1j`;oYl3/1_nY`>/5ojRojP;oZL3Z1_nX_n/3ojFok0?oY[o[1onU`>d3ojS1k0CoY/7]
1_nX`N`00onY`>[oZ<7/ojS1k004ojS1k0KoZ<3Z00?oZKoYojS1jonX`N/00onX`N/5ojRojP;oYl;/
1_nX`>/5ojRojP;oYl;]2_nW`N`=ojO2k@_oYko[2onW_^X00onW_n[oYl7/ojO1k00:ojO1k003ojS2
k?nX`>_oZ<3[00CoZ<3[1OnW_n/iooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
0Oooool0043ooooo00?o0000ooooooooool0;oooool3ojNoj`CoYl3[1_nV`>`00onX`N_oYl3/ojO0
k004ojO0k0KoZL3[00?oZ;oZojW0j_nY`>X01?nY`>X4ojRoj`;oZ;oZ1_nV_n/5ojG0k@;oY[o[1onV
`Nd3ojS1k0?oY/7]1onX`N`3ojS0jP?oYl;/1_nX`N/00onX_n[oYl;/ojO2k004ojO2k0KoZ<3[00?o
Z;oZojO2kOnW`^d01?nW`^d6ojO1k0coYl;]2onW_n/=ojNnjP?oYl3[2_nW`N`3ojS1k0OoZ<3[00?o
Yko[ooooooooool0>oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo007ooooo0011
ooooo`03o`000?oooooooooo02oooooo1onW`>/3ojK0k0?oY[o/1onW`>`3ojW0j`CoZ<7[1_nY`>X0
0onX_n_oZ;oZojRojP03ojRojPKoY[o[00?oYL3]ojJojonV_n/01?nV_n/5ojK1k@;oY[o/1_nV`Nd5
ojS1k003ojK1kOnW`^coYl;/00GoYl;/0onX`N/3ojO2k@OoYl;/0onX`>/:ojO2k@KoYl7/2?nW`^d:
ojNoj`goYkkZ2?nW`>/5ojO1k0SoZ<7/0onX`>]1ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool00Oooool004;ooooo0_l0000`ooooo`GoYl3[0_nX`>/6ojJok0GoYl3/0_nV`>`7ojS1
j`?oZL3Z0onX`>/6ojRojP?oY[o[1?nX_nX6ojJoj`03ojK1kOnV_ncoY[o/00CoY[o/1_nV`Nd00onX
`NcoY/7]ojK1k@03ojK1k@GoYl;/0_nV`>`6ojO2k@GoYl;/0_nV`Nd:ojO2k@;oYl3/1onW`N`3ojO2
k@_oYko[3OnW_^X<ojO0j`03ojO1k?nX`NcoZ<7/00SoZ<7/A_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo007ooooo0014ooooo`03o`000?oooooooooo02kooooo00?oYl3[ojS0jonX
`>/01?nX`>/6ojJok003ojO0k?nV`>coY/3/00CoY/3/1OnX`N/2ojO1k0KoZ<3[1?nX_nX2ojW0jPOo
Z;oZ0onV_n/4ojRojPKoY[o/0onV`Nd4ojJoj`GoY/7]00?oYl;/ojK0k?nV`>`01?nV`>`6ojO2k@03
ojO2k?nV`NgoY/7]00CoY/7]1OnW`^d00onW_n_oYl3/ojO0k004ojO0k0GoYl7/0_nW_nX:ojNoj`?o
Z;kZ2_nW_^X<ojO0j`CoYl7/1onX`Na:ooooo`03o`000?oooooooooo00Oooooo0Ol00001ooooo`7o
oooo0015ooooo`03o`000?oooooooooo02oooooo1_nX`>/3ojJok0CoYko[1_nV`>`00onX`N_oYl7/
ojO1k004ojO1k0KoZ<3[00?oZ;oZojW0j_nY`>X00onY`>X>ojRojP?oY[o/0onX_nX7ojJoj`;oY/7]
1?nV_n/6ojK0k0?oYl;]1?nV_n/6ojK1k@03ojO2kOnW_n_oYko[00?oYko[1_nW`>`00onW`NcoYkoZ
ojNojP04ojNojPGoYko[0_nX_nX6ojRnjPGoYkkZ2onW`>/:ojO1k0?oZ<7/C_ooool00ol0003ooooo
ooooo`06ooooo`7o00000Oooool1ooooo`00A_ooool00ol0003oooooooooo`0`ooooo`;oZ<3[0onX
_n/7ojNoj`?oY/3/1?nV_n`6ojO1k0?oZ<3[0onX`N/6ojW0jQCoZ;oZ1OnV_n/00onX_n[oY[o[ojJo
j`05ojJoj`?oY/3/0onW_n/7ojJoj`?oY/7]0onW_nX6ojNoj`?oYl3/1?nX_nX6ojNojP03ojNojonX
_n[oZ;oZ00CoZ;oZ1_nX_^X00onW_^[oYl3[ojO0j`08ojO0j`;oYl;/2onW`NaBooooo`03o`000?oo
oooooooo00Kooooo0Ol00001ooooo`7ooooo0017ooooo`;o0000<Oooool5ojRoj`OoYko[1onV_n`3
ojO1k0?oY/3/1_nX`N/3ojW0jPCoZ<3[4onX_nX00onV_n_oZ;oZojRojP03ojRojPGoY[o[0_nX_nX6
ojNoj`GoY[o[00?oZ;oZojNoj_nW_nX01OnW_nX3ojNoj`[oZ;oZ0onW_nX:ojRojP?oZ;kZ2_nW`>/6
ojO2k0OoYl7/E_ooool00ol0003oooooooooo`05ooooo`7o00000Oooool1ooooo`00BOooool00ol0
003oooooooooo`0_ooooo`GoZ;o[1onW_n/5ojJok0;oYko[1_nV`>`4ojS1j`;oYl7/1onX`>/3ojRo
jP?oZ<3[4onX_nX00onV_n_oZ;oZojRojP04ojRojPKoYko[00?oY[o[ojRoj_nX_nX00onX_nX5ojNo
jQ[oZ;oZ2onW`>/4ojO1k0KoYl;/0onW`NaJooooo`03o`000?oooooooooo00Cooooo0Ol00001oooo
o`7ooooo001:ooooo`03o`000?oooooooooo02oooooo0_nX_n/4ojS0j`KoYko[00?oY[o/ojNojonW
_n/01?nW_n/6ojK0k003ojS1jonW`NcoYl7/00?oYl7/1OnX`>/2ojO1k0KoZ<3[1OnX_nX00onX`>_o
Z;oZojRojP0BojRojP?oYko[2OnX_nX00onW_n[oZ;oZojRojP0HojRojP[oYl3[2OnW`N`3ojO2k63o
oooo00?o0000ooooooooool00oooool1o`00007ooooo0Oooool004_ooooo00?o0000ooooooooool0
;oooool6ojS0j`?oYko[1?nX_n/6ojNoj`?oY/3/1?nV_n`5ojO1k003ojS0jonW`NcoYl7/00CoYl7/
1_nX`>/00onX_n[oZ<3[ojS0j`03ojS0j`GoZ;oZ0_nX`>/SojRojPCoZ;o[2OnX_nX3ojO1k0OoYl3[
2onW`NaTooooo`03o`000?oooooooooo00?ooooo0Ol00001ooooo`7ooooo001<ooooo`;o0000<?oo
ool6ojS0j`OoZ;o[0onW_n/3ojRoj`OoY[o/0_nW`N`4ojK0k0KoYl7/0onX`>/4ojO1k0GoZ<3[00?o
Z;oZojS0jonX`>/01?nX`>/AojRojP;oZ<3[2onX_nX2ojS0j`OoZ;o[0onX_nX9ojO1k0?oYl3[2onW
`NaXooooo`03o`000?oooooooooo00?ooooo0Ol00001ooooo`00C_ooool00ol0003oooooooooo`0^
ooooo`KoZ<3[1OnX_n/2ojRojPKoZ;o[1OnV_n`00onW_n_oY/3/ojK0k005ojK0k0?oYl7/0onV`>`7
ojO1k0;oZ<3[1?nW`N`6ojS0j`?oZ;oZ1?nX`N/7ojRojPGoZ<3[1onX_nX6ojS0j`GoZ;o[6?nW`Na/
ooooo`03o`000?oooooooooo00;ooooo0Ol00001ooooo`00Coooool00ol0003oooooooooo`0_oooo
o`GoZ<3[00?oZ;o[ojRoj_nX_nX01?nX_nX6ojRoj`03ojJok?nW_n_oYko[00?oYko[1OnV`>`2ojNo
j`KoY/3/1OnW`N`00onV`>coYl7/ojO1k005ojO1k0?oZ<3[0onW`N`7ojS1j`?oZ;oZ0onX`N`6ojS0
j`?oZ;oZ1?nW`N`6ojS0j`03ojRojonW`NcoYl7/01GoYl7/LOooool01Ol0003ooooooooooooooooo
0000007ooooo001@ooooo`03o`000?oooooooooo02oooooo0_nX`>/3ojS1j`OoZ;oZ0onX_n/4ojRo
jPGoYko[00?oY/3/ojNojonW_n/01?nW_n/6ojK0k003ojO1k?nV`>coY/3/00?oY/3/1OnW`N`2ojK0
k0KoYl7/1OnX`N/00onV`NcoZ<7/ojS1k005ojS1k0?oZ<3[2_nW`N`3ojS0jaOoYl7/M?ooool01Ol0
003ooooooooooooooooo0000007ooooo001Aooooo`;o0000<?ooool5ojS1j`GoZ;oZ0_nX`>/7ojRo
jP;oYko[1?nX_n/6ojNoj`?oY/3/1?nW_n/5ojK0k003ojO1k?nV`>coY/3/00CoY/3/1_nW`N`00onX
`N_oY/7/ojK1k003ojK1k0GoZ<7/0_nV`>`;ojO1k003ojO0k?nW`NcoYl7/00SoYl7/0onW`>/:ojO1
k7Sooooo00Co0000oooooooooooo00000Oooool005?ooooo00?o0000ooooooooool0;_ooool5ojS1
j`03ojRoj_nX`>_oZ<3[00CoZ<3[1OnX_nX00onX`>[oZ;o[ojRoj`05ojRoj`?oYko[0onX_n/7ojNo
j`;oY/3/1?nW_n/6ojK0k0?oYl7/0onV`>`6ojK1k003ojS1k?nV`>coY/3/00CoY/3/1onW`N`5ojO0
k0GoYl7/0_nW_n/6ojO0j`GoYl7/OOooool00ol0003oooooo`000001ooooo`00E?ooool00ol0003o
ooooooooo`0^ooooo`;oZ<7[1?nW`>`6ojS0j`03ojRoj_nX`>[oZ<3Z00?oZ<3Z1OnX_n/2ojRojPKo
Z;o[1OnW_n/00onX_n_oYko[ojNoj`05ojNoj`?oY/3/0onW_n/6ojK0k0?oY/7/1?nW_n/6ojK0k0?o
Yl7/0onW_n/6ojO0k003ojO1k?nW_n_oYko[00CoYko[1_nW`>/00onW`Ncoooooooooo`1nooooo`03
o`000?oooooo0000007ooooo001Eooooo`03o`000?oooooooooo02kooooo1_nW`>`3ojS0j`CoZ<7/
1OnX`>X00onX_n_oZ;oZojRojP04ojRojPKoZ;o[00?oYko[ojRojonX_n/00onX_n/5ojNoj`;oZ;oZ
1_nW_n/4ojK0k0WoYko[0onV`>`9ojNoj`?oYl3/2_nW_n/3ojO0jhCooooo0Ol00001ooooo`7o0000
001Fooooo`;o0000;oooool3ojO0k0?oY/3/1onX`N`2ojS0jPCoZ<7[1_nX_nX3ojRoj`CoZ;oZ1OnX
_n/00onW_n_oZ;oZojRojP04ojRojPKoYko[00?oY/3/ojNojonW_n/02?nW_n/2ojRojP[oYko[0_nX
_nX:ojNojh[ooooo0_l0000005Sooooo00?o0000ooooooooool0;Oooool6ojK0k0GoZ<7/0_nV`>`6
ojS1j`?oZ;oZ0onX`N/7ojRojP;oZ;o[2_nX_nX3ojNoj`?oZ;oZ1onW_n/6ojRojPKoYko[1_nX_nX5
ojNojhgooooo0ol0000005Wooooo00?o0000ooooooooool0;Oooool6ojK0k003ojS1k?nV`>coY/3/
00CoY/3/1?nX`N/2ojO1k0KoZ<7[1OnX_nX00onX`N_oZ;oZojRojP0AojRojP?oYko[2_nX_nX2ojNo
j`[oZ;oZ00?oYko[ooooooooool0R_ooool4o`0000?ooooo001Jooooo`03o`000?oooooooooo02go
oooo0onV`>`4ojO0j`KoY/3/00?oZ<7[ojO1k?nW`N`00onW`N`6ojS1j`03ojRoj_nX`N_oZ<7[00?o
Z<7[1OnX_nX2ojS1j`[oZ;oZ0_nX`>/FojRojXcooooo0ol00007ooooo`00Foooool00ol0003ooooo
ooooo`0^ooooo`KoYl3[1_nV`>`6ojO1k0?oZ<7[1?nW`N`5ojS1j`03ojRoj_nX`N_oZ<7[00CoZ<7[
1onX_nX5ojS0j`GoZ;oZ00?oZ<3[ojRoj_nX_nX02?nX_nZ=ooooo`Co00002_ooool005cooooo0_l0
000_ooooo`?oYl3[0onW_n/6ojK0k0?oYl7/1?nV`>`6ojO1k0;oZ<7[1?nW`N`6ojS1j`?oZ;oZ0onX
`N`6ojS0j`03ojRoj_nX`>_oZ<3[00?oZ<3[1OnX_nZ=ooooo`Co00003_ooool005kooooo00?o0000
ooooooooool0;Oooool6ojNoj`CoY/3/0_nW_n/7ojK0k0?oYl7/0_nV`>`7ojO1k0?oZ<7[0onW`N`6
ojS1k0?oZ<3[1?nW`N`5ojS0j`03ojRoj_oooooooooo08[ooooo1?l0000Booooo`00Goooool00ol0
003oooooooooo`0]ooooo`KoYko[00?oY/3/ojNojonW_n/00onW_n/5ojK0k0;oYko[1OnV`>`5ojO1
k0;oYl3/1_nW`N`3ojS1k0CoYl3/1_nW`N`2ojS0jh_ooooo1?l0000Fooooo`00H?ooool00ol0003o
ooooooooo`0]ooooo`?oYko[1?nX_n/5ojNoj`03ojK0k?nW_n_oYko[00CoYko[1OnV`>`00onW`Nco
Yl3/ojO0k004ojO0k0CoYl7/2OnW`>`3ojO1k8cooooo0ol0000Jooooo`00HOooool2o`0002oooooo
1_nX_n/2ojNoj`CoZ;o[1_nW_n/2ojK0k0CoYko[1_nW`>`00onW`NcoYl3/ojO0k008ojO0k8cooooo
1?l0000Mooooo`00Hoooool00ol0003oooooooooo`0]ooooo`?oZ;o[0_nX`>/7ojRoj`?oYko[0onX
_n/6ojNoj`?oYl3/0onW_n/7ojO0k8_ooooo1?l0000Qooooo`00I?ooool00ol0003oooooooooo`0]
ooooo`GoZ<3[1OnX_n/2ojS0j`KoZ;o[0onW_n/4ojRoj`GoYko[0onW`>b:ooooo`Co00009Oooool0
06Gooooo00?o0000ooooooooool0;Oooool5ojS0j`03ojRojonX`>_oZ<3[00CoZ<3[1?nX_n/2ojS0
j`OoZ;o[0_nW_n^;ooooo`Co0000:Oooool006Kooooo0_l0000^ooooo`;oZ<3[1?nX`N/6ojS0j`03
ojRojonX`>_oZ<3[00?oZ<3[1OnX_n^;ooooo`?o0000;Oooool006Sooooo00?o0000ooooooooool0
;?ooool6ojS1j`?oZ<3[0onX`N/6ojS0j`03ojRojooooooooooo08Sooooo1?l0000`ooooo`00JOoo
ool00ol0003oooooooooo`0/ooooo`?oZ<7[1?nW`>`5ojS1j`?oZ<3[ROooool4o`0003Cooooo001Z
ooooo`03o`000?oooooooooo02cooooo1onW`>`2ojS1jh[ooooo1?l0000hooooo`00Joooool2o`00
02gooooo1OnW`>b9ooooo`Co0000??ooool006gooooo00?o0000ooooooooool0:oooool00onW`>co
ooooooooo`27ooooo`?o0000@?ooool006kooooo00?o0000ooooooooool0:_ooool00ol0003ooooo
ooooo`23ooooo`Co0000@oooool006oooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`1oooooo`Co0000Aoooool0073ooooo0_l0000Yooooo`03o`000?oooooooooo07_ooooo1?l0001;
ooooo`00L_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo07Oooooo1?l0001?oooo
o`00Loooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo07Cooooo0ol0001Cooooo`00
M?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo073ooooo1?l0001Fooooo`00MOoo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo06cooooo1?l0001Jooooo`00M_ooool2
o`0002?ooooo00?o0000ooooooooool0J?ooool4o`0005kooooo001hooooo`03o`000?oooooooooo
023ooooo00?o0000ooooooooool0I?ooool4o`0006;ooooo001iooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool0HOooool3o`0006Kooooo001jooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool0GOooool4o`0006Wooooo001kooooo`;o00007_ooool00ol0003ooooooooo
o`1Iooooo`Co0000KOooool007gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1E
ooooo`Co0000LOooool007kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1Aoooo
o`Co0000MOooool007oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1>ooooo`?o
0000NOooool0083ooooo0_l0000Iooooo`03o`000?oooooooooo04[ooooo1?l0001looooo`00P_oo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Kooooo1?l00020ooooo`00Poooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04;ooooo1?l00024ooooo`00Q?ooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo03kooooo1?l00028ooooo`00QOooool2o`0001?o
oooo00?o0000ooooooooool0??ooool3o`0008cooooo0027ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool0>?ooool4o`0008oooooo0028ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0=?ooool4o`0009?ooooo0029ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool0<?ooool4o`0009Oooooo002:ooooo`;o00003_ooool00ol0003oooooooooo`0/oooo
o`Co0000Voooool008cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Yooooo`?o
0000Woooool008gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Uooooo`Co0000
X_ooool008kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Qooooo`Co0000Y_oo
ool008oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Mooooo`Co0000Z_ooool0
093ooooo0_l00008ooooo`03o`000?oooooooooo01Wooooo1?l0002^ooooo`00T_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo01Kooooo0ol0002booooo`00Toooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo01;ooooo1?l0002eooooo`00U?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00kooooo1?l0002iooooo`00UOooool2o`0000?ooooo00?o0000
ooooooooool02_ooool4o`000;gooooo002Gooooo`04o`000?ooooooooooo`0000Sooooo1?l00031
ooooo`00V?ooool00ol0003oooooo`000005ooooo`?o0000aOooool009Wooooo0_l000000ooooooo
0000o`000002o`000<Sooooo002Jooooo`;o0000c?ooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0001\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0538698, 0.0432538, \
0.0035044, 0.0035044}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[.12586 .2075 -12 -8.99448 ]
[.12586 .2075 0 .00552 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.56094 .0364 -5.16972 -9 ]
[.56094 .0364 .83028 0 ]
[.75679 .08071 0 -6.17777 ]
[.75679 .08071 12 2.82223 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.9429 .3657 0 -5.9083 ]
[.9429 .3657 6 3.0917 ]
[.02494 .25992 -18 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.01611 .31527 -18 -2.78472 ]
[.01611 .31527 0 6.21528 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00254 .43215 -12 -2.88407 ]
[-0.00254 .43215 0 6.11593 ]
[-0.0124 .49393 -12 -2.93688 ]
[-0.0124 .49393 0 6.06312 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
[(-2)] .12586 .2075 1 .99877 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.56863 .04703 m
.57247 .05235 L
s
[(2)] .56094 .0364 .72324 1 Mshowa
.125 Mabswid
.18558 .19702 m
.18832 .19985 L
s
.23703 .17687 m
.23971 .17975 L
s
.28951 .15632 m
.29214 .15925 L
s
.39772 .11395 m
.40023 .11699 L
s
.4535 .09211 m
.45595 .0952 L
s
.51046 .06981 m
.51284 .07294 L
s
.08568 .23614 m
.08851 .23887 L
s
.62804 .02377 m
.63027 .02701 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.7445 .0853 m
.73835 .08759 L
s
[(-2)] .75679 .08071 -1 .37284 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.93037 .36962 m
.92411 .37158 L
s
[(2)] .9429 .3657 -1 .31296 Mshowa
.125 Mabswid
.7708 .12553 m
.7671 .12688 L
s
.79613 .16428 m
.79242 .1656 L
s
.82054 .20161 m
.81682 .20291 L
s
.86679 .27235 m
.86305 .2736 L
s
.88871 .30589 m
.88497 .30711 L
s
.9099 .3383 m
.90615 .3395 L
s
.71716 .04348 m
.71349 .04489 L
s
.95018 .39992 m
.94642 .40107 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(-20)] .02494 .25992 1 -0.39157 Mshowa
.02837 .31059 m
.0345 .30825 L
s
[(-10)] .01611 .31527 1 -0.38117 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.00981 .42772 m
.01599 .4255 L
s
[(10)] -0.00254 .43215 1 -0.3591 Mshowa
0 .48963 m
.0062 .48748 L
s
[(20)] -0.0124 .49393 1 -0.34736 Mshowa
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.654 .752 .922 r
.39362 .69483 .40169 .70183 .4152 .69807 .40717 .69103 Mtetra
.657 .753 .921 r
.40717 .69103 .4152 .69807 .42878 .69429 .42079 .68712 Mtetra
.658 .751 .918 r
.42079 .68712 .42878 .69429 .44242 .6904 .43448 .68316 Mtetra
.656 .749 .918 r
.43448 .68316 .44242 .6904 .45614 .68646 .44824 .67925 Mtetra
.655 .751 .92 r
.44824 .67925 .45614 .68646 .46992 .68255 .46207 .67535 Mtetra
.654 .752 .922 r
.46207 .67535 .46992 .68255 .48378 .67866 .47597 .67147 Mtetra
.654 .753 .923 r
.47597 .67147 .48378 .67866 .4977 .67478 .48994 .66757 Mtetra
.656 .754 .922 r
.48994 .66757 .4977 .67478 .5117 .6709 .50398 .66357 Mtetra
.658 .752 .92 r
.50398 .66357 .5117 .6709 .52577 .66697 .5181 .6595 Mtetra
.658 .749 .918 r
.5181 .6595 .52577 .66697 .53991 .66294 .53229 .65541 Mtetra
.657 .748 .917 r
.53229 .65541 .53991 .66294 .55412 .65888 .54655 .65134 Mtetra
.656 .749 .918 r
.54655 .65134 .55412 .65888 .56841 .6548 .56088 .64727 Mtetra
.656 .75 .92 r
.56088 .64727 .56841 .6548 .58277 .65072 .57529 .6432 Mtetra
.655 .751 .921 r
.57529 .6432 .58277 .65072 .5972 .64664 .58978 .63913 Mtetra
.654 .752 .922 r
.58978 .63913 .5972 .64664 .61172 .64255 .60434 .63504 Mtetra
.654 .754 .923 r
.60434 .63504 .61172 .64255 .6263 .63844 .61898 .63093 Mtetra
.655 .755 .923 r
.61898 .63093 .6263 .63844 .64096 .63432 .6337 .62678 Mtetra
.655 .755 .924 r
.6337 .62678 .64096 .63432 .6557 .63017 .64849 .6226 Mtetra
.655 .756 .924 r
.64849 .6226 .6557 .63017 .67052 .62599 .66336 .61839 Mtetra
.66336 .61839 .67052 .62599 .68542 .62179 .67831 .61415 Mtetra
.656 .756 .924 r
.67831 .61415 .68542 .62179 .70039 .61757 .69334 .60988 Mtetra
.69334 .60988 .70039 .61757 .71544 .61332 .70845 .60558 Mtetra
.656 .756 .923 r
.70845 .60558 .71544 .61332 .73058 .60904 .72364 .60124 Mtetra
.656 .755 .923 r
.72364 .60124 .73058 .60904 .74579 .60475 .73891 .59687 Mtetra
.657 .754 .922 r
.73891 .59687 .74579 .60475 .76109 .60044 .75426 .59247 Mtetra
.657 .753 .921 r
.75426 .59247 .76109 .60044 .77647 .59611 .76969 .58805 Mtetra
.656 .752 .92 r
.76969 .58805 .77647 .59611 .79193 .59178 .78521 .58363 Mtetra
.656 .75 .92 r
.78521 .58363 .79193 .59178 .80748 .58745 .80081 .57921 Mtetra
.655 .749 .919 r
.80081 .57921 .80748 .58745 .82311 .5831 .8165 .57478 Mtetra
.654 .748 .918 r
.8165 .57478 .82311 .5831 .83883 .57871 .83228 .57037 Mtetra
.654 .748 .919 r
.83228 .57037 .83883 .57871 .85462 .57422 .84815 .56594 Mtetra
.655 .752 .921 r
.84815 .56594 .85462 .57422 .8705 .56967 .8641 .56144 Mtetra
.657 .754 .922 r
.8641 .56144 .8705 .56967 .88647 .56512 .88013 .55683 Mtetra
.657 .754 .921 r
.88013 .55683 .88647 .56512 .90252 .56058 .89624 .55218 Mtetra
.656 .752 .921 r
.89624 .55218 .90252 .56058 .91867 .55605 .91245 .54756 Mtetra
.656 .751 .92 r
.91245 .54756 .91867 .55605 .93492 .55155 .92875 .54294 Mtetra
.654 .748 .919 r
.92875 .54294 .93492 .55155 .95125 .54699 .94516 .53837 Mtetra
.655 .75 .92 r
.94516 .53837 .95125 .54699 .96766 .54232 .96165 .53375 Mtetra
.657 .753 .921 r
.96165 .53375 .96766 .54232 .98416 .5376 .97822 .529 Mtetra
.38547 .68776 .39362 .69483 .40717 .69103 .39906 .68384 Mtetra
.658 .751 .918 r
.39906 .68384 .40717 .69103 .42079 .68712 .41273 .67986 Mtetra
.656 .749 .919 r
.41273 .67986 .42079 .68712 .43448 .68316 .42646 .67593 Mtetra
.655 .751 .92 r
.42646 .67593 .43448 .68316 .44824 .67925 .44026 .67202 Mtetra
.653 .752 .922 r
.44026 .67202 .44824 .67925 .46207 .67535 .45414 .66814 Mtetra
.654 .753 .923 r
.45414 .66814 .46207 .67535 .47597 .67147 .46808 .66422 Mtetra
.657 .754 .921 r
.46808 .66422 .47597 .67147 .48994 .66757 .4821 .66015 Mtetra
.658 .751 .918 r
.4821 .66015 .48994 .66757 .50398 .66357 .49619 .65605 Mtetra
.657 .749 .917 r
.49619 .65605 .50398 .66357 .5181 .6595 .51035 .65196 Mtetra
.656 .749 .918 r
.51035 .65196 .5181 .6595 .53229 .65541 .52459 .6479 Mtetra
.655 .751 .92 r
.52459 .6479 .53229 .65541 .54655 .65134 .5389 .64384 Mtetra
.654 .751 .922 r
.5389 .64384 .54655 .65134 .56088 .64727 .55328 .63981 Mtetra
.654 .753 .923 r
.55328 .63981 .56088 .64727 .57529 .6432 .56775 .63575 Mtetra
.654 .755 .924 r
.56775 .63575 .57529 .6432 .58978 .63913 .58228 .63164 Mtetra
.655 .755 .924 r
.58228 .63164 .58978 .63913 .60434 .63504 .5969 .62748 Mtetra
.656 .755 .922 r
.5969 .62748 .60434 .63504 .61898 .63093 .61159 .62326 Mtetra
.656 .753 .921 r
.61159 .62326 .61898 .63093 .6337 .62678 .62635 .61902 Mtetra
.656 .751 .92 r
.62635 .61902 .6337 .62678 .64849 .6226 .6412 .61476 Mtetra
.656 .75 .919 r
.6412 .61476 .64849 .6226 .66336 .61839 .65612 .61049 Mtetra
.65612 .61049 .66336 .61839 .67831 .61415 .67113 .60621 Mtetra
.67113 .60621 .67831 .61415 .69334 .60988 .68621 .60191 Mtetra
.655 .75 .92 r
.68621 .60191 .69334 .60988 .70845 .60558 .70138 .5976 Mtetra
.655 .751 .92 r
.70138 .5976 .70845 .60558 .72364 .60124 .71663 .59328 Mtetra
.655 .752 .922 r
.71663 .59328 .72364 .60124 .73891 .59687 .73196 .58893 Mtetra
.656 .754 .923 r
.73196 .58893 .73891 .59687 .75426 .59247 .74737 .58453 Mtetra
.657 .756 .923 r
.74737 .58453 .75426 .59247 .76969 .58805 .76286 .58006 Mtetra
.76286 .58006 .76969 .58805 .78521 .58363 .77843 .57554 Mtetra
.658 .755 .922 r
.77843 .57554 .78521 .58363 .80081 .57921 .79409 .571 Mtetra
.656 .752 .921 r
.79409 .571 .80081 .57921 .8165 .57478 .80984 .56648 Mtetra
.656 .751 .92 r
.80984 .56648 .8165 .57478 .83228 .57037 .82567 .56196 Mtetra
.655 .749 .919 r
.82567 .56196 .83228 .57037 .84815 .56594 .8416 .55745 Mtetra
.654 .748 .919 r
.8416 .55745 .84815 .56594 .8641 .56144 .85762 .55297 Mtetra
.654 .749 .92 r
.85762 .55297 .8641 .56144 .88013 .55683 .87372 .54844 Mtetra
.657 .754 .921 r
.87372 .54844 .88013 .55683 .89624 .55218 .88991 .54377 Mtetra
.658 .755 .921 r
.88991 .54377 .89624 .55218 .91245 .54756 .90617 .53904 Mtetra
.657 .753 .921 r
.90617 .53904 .91245 .54756 .92875 .54294 .92254 .53433 Mtetra
.656 .751 .92 r
.92254 .53433 .92875 .54294 .94516 .53837 .939 .52964 Mtetra
.654 .748 .919 r
.939 .52964 .94516 .53837 .96165 .53375 .95556 .525 Mtetra
.655 .75 .92 r
.95556 .525 .96165 .53375 .97822 .529 .97221 .5203 Mtetra
.658 .751 .918 r
.37724 .68055 .38547 .68776 .39906 .68384 .39088 .67654 Mtetra
.656 .749 .919 r
.39088 .67654 .39906 .68384 .41273 .67986 .40459 .6726 Mtetra
.655 .751 .921 r
.40459 .6726 .41273 .67986 .42646 .67593 .41837 .66868 Mtetra
.653 .752 .922 r
.41837 .66868 .42646 .67593 .44026 .67202 .43221 .66479 Mtetra
.655 .753 .922 r
.43221 .66479 .44026 .67202 .45414 .66814 .44613 .66082 Mtetra
.658 .753 .92 r
.44613 .66082 .45414 .66814 .46808 .66422 .46012 .65672 Mtetra
.658 .75 .917 r
.46012 .65672 .46808 .66422 .4821 .66015 .47419 .6526 Mtetra
.657 .749 .918 r
.47419 .6526 .4821 .66015 .49619 .65605 .48833 .64852 Mtetra
.655 .75 .92 r
.48833 .64852 .49619 .65605 .51035 .65196 .50254 .64446 Mtetra
.653 .751 .921 r
.50254 .64446 .51035 .65196 .52459 .6479 .51682 .64044 Mtetra
.653 .753 .923 r
.51682 .64044 .52459 .6479 .5389 .64384 .53118 .6364 Mtetra
.654 .755 .924 r
.53118 .6364 .5389 .64384 .55328 .63981 .54561 .63229 Mtetra
.657 .755 .922 r
.54561 .63229 .55328 .63981 .56775 .63575 .56012 .62808 Mtetra
.657 .752 .92 r
.56012 .62808 .56775 .63575 .58228 .63164 .57471 .62383 Mtetra
.657 .749 .918 r
.57471 .62383 .58228 .63164 .5969 .62748 .58937 .61956 Mtetra
.657 .748 .917 r
.58937 .61956 .5969 .62748 .61159 .62326 .60411 .61529 Mtetra
.657 .747 .917 r
.60411 .61529 .61159 .62326 .62635 .61902 .61893 .61101 Mtetra
.656 .747 .917 r
.61893 .61101 .62635 .61902 .6412 .61476 .63383 .60672 Mtetra
.63383 .60672 .6412 .61476 .65612 .61049 .64881 .60241 Mtetra
.656 .748 .917 r
.64881 .60241 .65612 .61049 .67113 .60621 .66387 .59809 Mtetra
.656 .747 .917 r
.66387 .59809 .67113 .60621 .68621 .60191 .679 .59374 Mtetra
.679 .59374 .68621 .60191 .70138 .5976 .69423 .58938 Mtetra
.69423 .58938 .70138 .5976 .71663 .59328 .70953 .58501 Mtetra
.655 .747 .917 r
.70953 .58501 .71663 .59328 .73196 .58893 .72492 .58063 Mtetra
.655 .747 .918 r
.72492 .58063 .73196 .58893 .74737 .58453 .74039 .57624 Mtetra
.654 .748 .919 r
.74039 .57624 .74737 .58453 .76286 .58006 .75595 .57184 Mtetra
.654 .751 .921 r
.75595 .57184 .76286 .58006 .77843 .57554 .77159 .56739 Mtetra
.656 .755 .922 r
.77159 .56739 .77843 .57554 .79409 .571 .78731 .56284 Mtetra
.658 .756 .923 r
.78731 .56284 .79409 .571 .80984 .56648 .80312 .55821 Mtetra
.658 .755 .922 r
.80312 .55821 .80984 .56648 .82567 .56196 .81901 .55356 Mtetra
.656 .752 .92 r
.81901 .55356 .82567 .56196 .8416 .55745 .83499 .54895 Mtetra
.655 .75 .92 r
.83499 .54895 .8416 .55745 .85762 .55297 .85106 .54435 Mtetra
.654 .748 .919 r
.85106 .54435 .85762 .55297 .87372 .54844 .86724 .53979 Mtetra
.86724 .53979 .87372 .54844 .88991 .54377 .8835 .53521 Mtetra
.656 .753 .921 r
.8835 .53521 .88991 .54377 .90617 .53904 .89984 .53048 Mtetra
.658 .755 .921 r
.89984 .53048 .90617 .53904 .92254 .53433 .91626 .52568 Mtetra
.657 .753 .921 r
.91626 .52568 .92254 .53433 .939 .52964 .93278 .52089 Mtetra
.656 .751 .92 r
.93278 .52089 .939 .52964 .95556 .525 .9494 .51612 Mtetra
.654 .748 .919 r
.9494 .51612 .95556 .525 .97221 .5203 .96613 .51141 Mtetra
.657 .75 .918 r
.36894 .67323 .37724 .68055 .39088 .67654 .38262 .66925 Mtetra
.655 .751 .92 r
.38262 .66925 .39088 .67654 .40459 .6726 .39637 .66531 Mtetra
.653 .752 .922 r
.39637 .66531 .40459 .6726 .41837 .66868 .41019 .66141 Mtetra
.655 .753 .922 r
.41019 .66141 .41837 .66868 .43221 .66479 .42408 .65742 Mtetra
.658 .753 .92 r
.42408 .65742 .43221 .66479 .44613 .66082 .43805 .65329 Mtetra
.658 .749 .918 r
.43805 .65329 .44613 .66082 .46012 .65672 .45209 .64916 Mtetra
.656 .749 .918 r
.45209 .64916 .46012 .65672 .47419 .6526 .4662 .64507 Mtetra
.654 .751 .921 r
.4662 .64507 .47419 .6526 .48833 .64852 .48038 .64103 Mtetra
.653 .752 .923 r
.48038 .64103 .48833 .64852 .50254 .64446 .49464 .63701 Mtetra
.653 .755 .924 r
.49464 .63701 .50254 .64446 .51682 .64044 .50897 .63294 Mtetra
.657 .755 .922 r
.50897 .63294 .51682 .64044 .53118 .6364 .52338 .62871 Mtetra
.658 .752 .919 r
.52338 .62871 .53118 .6364 .54561 .63229 .53787 .62444 Mtetra
.658 .748 .917 r
.53787 .62444 .54561 .63229 .56012 .62808 .55243 .62017 Mtetra
.657 .748 .917 r
.55243 .62017 .56012 .62808 .57471 .62383 .56706 .6159 Mtetra
.56706 .6159 .57471 .62383 .58937 .61956 .58178 .61163 Mtetra
.656 .749 .918 r
.58178 .61163 .58937 .61956 .60411 .61529 .59657 .60735 Mtetra
.656 .75 .919 r
.59657 .60735 .60411 .61529 .61893 .61101 .61144 .60305 Mtetra
.656 .75 .92 r
.61144 .60305 .61893 .61101 .63383 .60672 .62639 .59875 Mtetra
.655 .751 .92 r
.62639 .59875 .63383 .60672 .64881 .60241 .64143 .59442 Mtetra
.656 .752 .92 r
.64143 .59442 .64881 .60241 .66387 .59809 .65654 .59005 Mtetra
.65654 .59005 .66387 .59809 .679 .59374 .67173 .58564 Mtetra
.656 .751 .92 r
.67173 .58564 .679 .59374 .69423 .58938 .68701 .58121 Mtetra
.656 .75 .919 r
.68701 .58121 .69423 .58938 .70953 .58501 .70237 .57677 Mtetra
.70237 .57677 .70953 .58501 .72492 .58063 .71781 .57231 Mtetra
.656 .749 .918 r
.71781 .57231 .72492 .58063 .74039 .57624 .73334 .56784 Mtetra
.655 .748 .918 r
.73334 .56784 .74039 .57624 .75595 .57184 .74896 .56336 Mtetra
.654 .747 .918 r
.74896 .56336 .75595 .57184 .77159 .56739 .76466 .5589 Mtetra
.76466 .5589 .77159 .56739 .78731 .56284 .78045 .55442 Mtetra
.654 .75 .92 r
.78045 .55442 .78731 .56284 .80312 .55821 .79633 .54989 Mtetra
.657 .755 .922 r
.79633 .54989 .80312 .55821 .81901 .55356 .81228 .54521 Mtetra
.658 .756 .922 r
.81228 .54521 .81901 .55356 .83499 .54895 .82832 .54047 Mtetra
.657 .753 .921 r
.82832 .54047 .83499 .54895 .85106 .54435 .84445 .53575 Mtetra
.656 .751 .92 r
.84445 .53575 .85106 .54435 .86724 .53979 .86068 .53107 Mtetra
.654 .748 .919 r
.86068 .53107 .86724 .53979 .8835 .53521 .87701 .52643 Mtetra
.87701 .52643 .8835 .53521 .89984 .53048 .89343 .52178 Mtetra
.656 .752 .921 r
.89343 .52178 .89984 .53048 .91626 .52568 .90993 .51698 Mtetra
.658 .755 .921 r
.90993 .51698 .91626 .52568 .93278 .52089 .92651 .51209 Mtetra
.657 .753 .921 r
.92651 .51209 .93278 .52089 .9494 .51612 .94319 .50723 Mtetra
.655 .751 .92 r
.94319 .50723 .9494 .51612 .96613 .51141 .95998 .5024 Mtetra
.36056 .66588 .36894 .67323 .38262 .66925 .37428 .66192 Mtetra
.653 .751 .922 r
.37428 .66192 .38262 .66925 .39637 .66531 .38807 .658 Mtetra
.654 .753 .922 r
.38807 .658 .39637 .66531 .41019 .66141 .40194 .65401 Mtetra
.658 .753 .92 r
.40194 .65401 .41019 .66141 .42408 .65742 .41588 .64986 Mtetra
.658 .75 .918 r
.41588 .64986 .42408 .65742 .43805 .65329 .42989 .64571 Mtetra
.656 .749 .919 r
.42989 .64571 .43805 .65329 .45209 .64916 .44398 .64161 Mtetra
.654 .751 .921 r
.44398 .64161 .45209 .64916 .4662 .64507 .45813 .63757 Mtetra
.652 .753 .923 r
.45813 .63757 .4662 .64507 .48038 .64103 .47236 .63354 Mtetra
.655 .755 .923 r
.47236 .63354 .48038 .64103 .49464 .63701 .48667 .62938 Mtetra
.658 .753 .92 r
.48667 .62938 .49464 .63701 .50897 .63294 .50105 .62511 Mtetra
.659 .749 .917 r
.50105 .62511 .50897 .63294 .52338 .62871 .51551 .62081 Mtetra
.657 .748 .917 r
.51551 .62081 .52338 .62871 .53787 .62444 .53004 .61654 Mtetra
.656 .749 .918 r
.53004 .61654 .53787 .62444 .55243 .62017 .54465 .61228 Mtetra
.655 .75 .919 r
.54465 .61228 .55243 .62017 .56706 .6159 .55934 .60804 Mtetra
.653 .751 .921 r
.55934 .60804 .56706 .6159 .58178 .61163 .57411 .60383 Mtetra
.653 .754 .923 r
.57411 .60383 .58178 .61163 .59657 .60735 .58896 .59959 Mtetra
.654 .756 .925 r
.58896 .59959 .59657 .60735 .61144 .60305 .60389 .5953 Mtetra
.654 .757 .925 r
.60389 .5953 .61144 .60305 .62639 .59875 .61889 .59097 Mtetra
.655 .758 .926 r
.61889 .59097 .62639 .59875 .64143 .59442 .63398 .5866 Mtetra
.655 .758 .925 r
.63398 .5866 .64143 .59442 .65654 .59005 .64915 .58219 Mtetra
.656 .758 .925 r
.64915 .58219 .65654 .59005 .67173 .58564 .6644 .57774 Mtetra
.6644 .57774 .67173 .58564 .68701 .58121 .67974 .57324 Mtetra
.657 .758 .925 r
.67974 .57324 .68701 .58121 .70237 .57677 .69515 .56871 Mtetra
.657 .757 .923 r
.69515 .56871 .70237 .57677 .71781 .57231 .71065 .56412 Mtetra
.658 .755 .922 r
.71065 .56412 .71781 .57231 .73334 .56784 .72623 .5595 Mtetra
.657 .752 .92 r
.72623 .5595 .73334 .56784 .74896 .56336 .7419 .55491 Mtetra
.656 .75 .919 r
.7419 .55491 .74896 .56336 .76466 .5589 .75766 .55034 Mtetra
.655 .748 .918 r
.75766 .55034 .76466 .5589 .78045 .55442 .77351 .54577 Mtetra
.654 .747 .918 r
.77351 .54577 .78045 .55442 .79633 .54989 .78945 .54123 Mtetra
.654 .747 .919 r
.78945 .54123 .79633 .54989 .81228 .54521 .80548 .53667 Mtetra
.656 .752 .921 r
.80548 .53667 .81228 .54521 .82832 .54047 .82159 .53198 Mtetra
.658 .756 .922 r
.82159 .53198 .82832 .54047 .84445 .53575 .83778 .52715 Mtetra
.658 .754 .921 r
.83778 .52715 .84445 .53575 .86068 .53107 .85407 .52233 Mtetra
.656 .751 .92 r
.85407 .52233 .86068 .53107 .87701 .52643 .87045 .51757 Mtetra
.654 .749 .919 r
.87045 .51757 .87701 .52643 .89343 .52178 .88694 .51286 Mtetra
.653 .748 .919 r
.88694 .51286 .89343 .52178 .90993 .51698 .90352 .50814 Mtetra
.657 .753 .921 r
.90352 .50814 .90993 .51698 .92651 .51209 .92018 .50325 Mtetra
.658 .754 .921 r
.92018 .50325 .92651 .51209 .94319 .50723 .93692 .49828 Mtetra
.656 .752 .921 r
.93692 .49828 .94319 .50723 .95998 .5024 .95377 .49335 Mtetra
.653 .751 .922 r
.3521 .65852 .36056 .66588 .37428 .66192 .36586 .65457 Mtetra
.653 .753 .923 r
.36586 .65457 .37428 .66192 .38807 .658 .3797 .65059 Mtetra
.658 .753 .92 r
.3797 .65059 .38807 .658 .40194 .65401 .39361 .64643 Mtetra
.658 .75 .918 r
.39361 .64643 .40194 .65401 .41588 .64986 .4076 .64225 Mtetra
.656 .75 .919 r
.4076 .64225 .41588 .64986 .42989 .64571 .42166 .63813 Mtetra
.653 .751 .921 r
.42166 .63813 .42989 .64571 .44398 .64161 .43578 .63408 Mtetra
.652 .753 .923 r
.43578 .63408 .44398 .64161 .45813 .63757 .44999 .63004 Mtetra
.656 .755 .922 r
.44999 .63004 .45813 .63757 .47236 .63354 .46427 .62582 Mtetra
.659 .752 .919 r
.46427 .62582 .47236 .63354 .48667 .62938 .47862 .62151 Mtetra
.658 .749 .917 r
.47862 .62151 .48667 .62938 .50105 .62511 .49305 .61721 Mtetra
.657 .749 .918 r
.49305 .61721 .50105 .62511 .51551 .62081 .50756 .61293 Mtetra
.655 .75 .92 r
.50756 .61293 .51551 .62081 .53004 .61654 .52214 .60872 Mtetra
.652 .751 .922 r
.52214 .60872 .53004 .61654 .54465 .61228 .53681 .60455 Mtetra
.652 .755 .925 r
.53681 .60455 .54465 .61228 .55934 .60804 .55155 .60034 Mtetra
.654 .757 .926 r
.55155 .60034 .55934 .60804 .57411 .60383 .56637 .59605 Mtetra
.656 .757 .924 r
.56637 .59605 .57411 .60383 .58896 .59959 .58127 .59165 Mtetra
.657 .754 .922 r
.58127 .59165 .58896 .59959 .60389 .5953 .59625 .58722 Mtetra
.657 .752 .92 r
.59625 .58722 .60389 .5953 .61889 .59097 .61131 .58278 Mtetra
.656 .75 .919 r
.61131 .58278 .61889 .59097 .63398 .5866 .62645 .57833 Mtetra
.656 .749 .918 r
.62645 .57833 .63398 .5866 .64915 .58219 .64167 .57388 Mtetra
.655 .749 .918 r
.64167 .57388 .64915 .58219 .6644 .57774 .65698 .56941 Mtetra
.655 .749 .919 r
.65698 .56941 .6644 .57774 .67974 .57324 .67237 .56494 Mtetra
.655 .751 .921 r
.67237 .56494 .67974 .57324 .69515 .56871 .68785 .56046 Mtetra
.655 .753 .922 r
.68785 .56046 .69515 .56871 .71065 .56412 .70342 .55594 Mtetra
.657 .757 .924 r
.70342 .55594 .71065 .56412 .72623 .5595 .71906 .55132 Mtetra
.658 .759 .924 r
.71906 .55132 .72623 .5595 .7419 .55491 .73479 .54661 Mtetra
.659 .757 .923 r
.73479 .54661 .7419 .55491 .75766 .55034 .7506 .54185 Mtetra
.657 .753 .921 r
.7506 .54185 .75766 .55034 .77351 .54577 .7665 .53714 Mtetra
.655 .75 .919 r
.7665 .53714 .77351 .54577 .78945 .54123 .7825 .53248 Mtetra
.654 .748 .919 r
.7825 .53248 .78945 .54123 .80548 .53667 .79859 .52786 Mtetra
.653 .747 .919 r
.79859 .52786 .80548 .53667 .82159 .53198 .81478 .52324 Mtetra
.655 .751 .92 r
.81478 .52324 .82159 .53198 .83778 .52715 .83105 .51851 Mtetra
.659 .756 .922 r
.83105 .51851 .83778 .52715 .85407 .52233 .8474 .5136 Mtetra
.658 .755 .921 r
.8474 .5136 .85407 .52233 .87045 .51757 .86384 .5087 Mtetra
.656 .751 .92 r
.86384 .5087 .87045 .51757 .88694 .51286 .88038 .50386 Mtetra
.654 .749 .919 r
.88038 .50386 .88694 .51286 .90352 .50814 .89703 .49908 Mtetra
.654 .748 .919 r
.89703 .49908 .90352 .50814 .92018 .50325 .91377 .49428 Mtetra
.658 .754 .921 r
.91377 .49428 .92018 .50325 .93692 .49828 .93059 .48928 Mtetra
.93059 .48928 .93692 .49828 .95377 .49335 .94751 .48424 Mtetra
.653 .752 .922 r
.34355 .65111 .3521 .65852 .36586 .65457 .35736 .64713 Mtetra
.657 .753 .921 r
.35736 .64713 .36586 .65457 .3797 .65059 .37125 .64299 Mtetra
.659 .75 .918 r
.37125 .64299 .3797 .65059 .39361 .64643 .38521 .63877 Mtetra
.656 .75 .919 r
.38521 .63877 .39361 .64643 .4076 .64225 .39924 .63462 Mtetra
.653 .751 .921 r
.39924 .63462 .4076 .64225 .42166 .63813 .41334 .63055 Mtetra
.652 .752 .923 r
.41334 .63055 .42166 .63813 .43578 .63408 .42751 .6265 Mtetra
.657 .755 .922 r
.42751 .6265 .43578 .63408 .44999 .63004 .44176 .62226 Mtetra
.659 .751 .918 r
.44176 .62226 .44999 .63004 .46427 .62582 .45609 .61792 Mtetra
.658 .749 .917 r
.45609 .61792 .46427 .62582 .47862 .62151 .4705 .6136 Mtetra
.656 .749 .918 r
.4705 .6136 .47862 .62151 .49305 .61721 .48498 .60933 Mtetra
.652 .75 .921 r
.48498 .60933 .49305 .61721 .50756 .61293 .49953 .60517 Mtetra
.651 .754 .925 r
.49953 .60517 .50756 .61293 .52214 .60872 .51417 .60101 Mtetra
.654 .757 .925 r
.51417 .60101 .52214 .60872 .53681 .60455 .52888 .5967 Mtetra
.658 .755 .922 r
.52888 .5967 .53681 .60455 .55155 .60034 .54367 .59226 Mtetra
.658 .751 .918 r
.54367 .59226 .55155 .60034 .56637 .59605 .55854 .58779 Mtetra
.658 .747 .916 r
.55854 .58779 .56637 .59605 .58127 .59165 .57349 .58331 Mtetra
.657 .746 .915 r
.57349 .58331 .58127 .59165 .59625 .58722 .58853 .57883 Mtetra
.58853 .57883 .59625 .58722 .61131 .58278 .60364 .57435 Mtetra
.657 .746 .916 r
.60364 .57435 .61131 .58278 .62645 .57833 .61884 .56986 Mtetra
.656 .746 .916 r
.61884 .56986 .62645 .57833 .64167 .57388 .63412 .56536 Mtetra
.63412 .56536 .64167 .57388 .65698 .56941 .64948 .56085 Mtetra
.655 .745 .916 r
.64948 .56085 .65698 .56941 .67237 .56494 .66493 .55632 Mtetra
.66493 .55632 .67237 .56494 .68785 .56046 .68047 .5518 Mtetra
.654 .745 .917 r
.68047 .5518 .68785 .56046 .70342 .55594 .69609 .54728 Mtetra
.654 .746 .917 r
.69609 .54728 .70342 .55594 .71906 .55132 .7118 .54274 Mtetra
.654 .749 .92 r
.7118 .54274 .71906 .55132 .73479 .54661 .7276 .53818 Mtetra
.656 .755 .923 r
.7276 .53818 .73479 .54661 .7506 .54185 .74348 .53347 Mtetra
.659 .759 .924 r
.74348 .53347 .7506 .54185 .7665 .53714 .75944 .52862 Mtetra
.659 .756 .922 r
.75944 .52862 .7665 .53714 .7825 .53248 .77549 .52375 Mtetra
.656 .751 .92 r
.77549 .52375 .7825 .53248 .79859 .52786 .79164 .519 Mtetra
.654 .748 .919 r
.79164 .519 .79859 .52786 .81478 .52324 .80788 .51429 Mtetra
.653 .747 .919 r
.80788 .51429 .81478 .52324 .83105 .51851 .82423 .50961 Mtetra
.655 .75 .92 r
.82423 .50961 .83105 .51851 .8474 .5136 .84066 .50481 Mtetra
.659 .756 .922 r
.84066 .50481 .8474 .5136 .86384 .5087 .85716 .49982 Mtetra
.658 .754 .921 r
.85716 .49982 .86384 .5087 .88038 .50386 .87376 .49484 Mtetra
.655 .751 .92 r
.87376 .49484 .88038 .50386 .89703 .49908 .89047 .48994 Mtetra
.653 .748 .92 r
.89047 .48994 .89703 .49908 .91377 .49428 .90729 .4851 Mtetra
.655 .749 .919 r
.90729 .4851 .91377 .49428 .93059 .48928 .92419 .48018 Mtetra
.658 .754 .921 r
.92419 .48018 .93059 .48928 .94751 .48424 .94118 .47507 Mtetra
.655 .753 .922 r
.33493 .64365 .34355 .65111 .35736 .64713 .34878 .63955 Mtetra
.659 .752 .919 r
.34878 .63955 .35736 .64713 .37125 .64299 .36271 .6353 Mtetra
.657 .75 .918 r
.36271 .6353 .37125 .64299 .38521 .63877 .37672 .63111 Mtetra
.654 .751 .921 r
.37672 .63111 .38521 .63877 .39924 .63462 .39079 .62699 Mtetra
.652 .752 .923 r
.39079 .62699 .39924 .63462 .41334 .63055 .40493 .62294 Mtetra
.656 .754 .922 r
.40493 .62294 .41334 .63055 .42751 .6265 .41916 .6187 Mtetra
.66 .752 .918 r
.41916 .6187 .42751 .6265 .44176 .62226 .43346 .61433 Mtetra
.658 .749 .917 r
.43346 .61433 .44176 .62226 .45609 .61792 .44784 .60999 Mtetra
.656 .749 .919 r
.44784 .60999 .45609 .61792 .4705 .6136 .46229 .60571 Mtetra
.651 .75 .922 r
.46229 .60571 .4705 .6136 .48498 .60933 .47682 .60159 Mtetra
.651 .755 .925 r
.47682 .60159 .48498 .60933 .49953 .60517 .49142 .59739 Mtetra
.658 .757 .923 r
.49142 .59739 .49953 .60517 .51417 .60101 .50611 .59295 Mtetra
.659 .752 .918 r
.50611 .59295 .51417 .60101 .52888 .5967 .52087 .58845 Mtetra
.659 .747 .915 r
.52087 .58845 .52888 .5967 .54367 .59226 .53572 .58394 Mtetra
.658 .747 .915 r
.53572 .58394 .54367 .59226 .55854 .58779 .55064 .57945 Mtetra
.657 .747 .916 r
.55064 .57945 .55854 .58779 .57349 .58331 .56565 .57498 Mtetra
.656 .748 .918 r
.56565 .57498 .57349 .58331 .58853 .57883 .58073 .57051 Mtetra
.655 .749 .919 r
.58073 .57051 .58853 .57883 .60364 .57435 .5959 .56605 Mtetra
.655 .751 .92 r
.5959 .56605 .60364 .57435 .61884 .56986 .61116 .56156 Mtetra
.656 .752 .921 r
.61116 .56156 .61884 .56986 .63412 .56536 .62649 .55702 Mtetra
.657 .752 .921 r
.62649 .55702 .63412 .56536 .64948 .56085 .64191 .55241 Mtetra
.657 .751 .92 r
.64191 .55241 .64948 .56085 .66493 .55632 .65742 .54777 Mtetra
.656 .749 .919 r
.65742 .54777 .66493 .55632 .68047 .5518 .67301 .54314 Mtetra
.655 .748 .918 r
.67301 .54314 .68047 .5518 .69609 .54728 .68869 .53852 Mtetra
.654 .746 .917 r
.68869 .53852 .69609 .54728 .7118 .54274 .70445 .53391 Mtetra
.653 .745 .917 r
.70445 .53391 .7118 .54274 .7276 .53818 .72031 .52932 Mtetra
.653 .745 .918 r
.72031 .52932 .7276 .53818 .74348 .53347 .73627 .52473 Mtetra
.654 .75 .92 r
.73627 .52473 .74348 .53347 .75944 .52862 .75231 .52006 Mtetra
.659 .758 .923 r
.75231 .52006 .75944 .52862 .77549 .52375 .76842 .51514 Mtetra
.66 .758 .922 r
.76842 .51514 .77549 .52375 .79164 .519 .78462 .51015 Mtetra
.656 .752 .92 r
.78462 .51015 .79164 .519 .80788 .51429 .80092 .50531 Mtetra
.654 .749 .919 r
.80092 .50531 .80788 .51429 .82423 .50961 .81733 .50053 Mtetra
.653 .747 .919 r
.81733 .50053 .82423 .50961 .84066 .50481 .83383 .49578 Mtetra
.655 .75 .92 r
.83383 .49578 .84066 .50481 .85716 .49982 .85042 .49088 Mtetra
.659 .756 .921 r
.85042 .49088 .85716 .49982 .87376 .49484 .86708 .48579 Mtetra
.657 .753 .921 r
.86708 .48579 .87376 .49484 .89047 .48994 .88385 .48076 Mtetra
.655 .75 .92 r
.88385 .48076 .89047 .48994 .90729 .4851 .90073 .4758 Mtetra
.653 .748 .92 r
.90073 .4758 .90729 .4851 .92419 .48018 .91772 .47089 Mtetra
.656 .751 .92 r
.91772 .47089 .92419 .48018 .94118 .47507 .93479 .46582 Mtetra
.659 .753 .92 r
.32622 .63609 .33493 .64365 .34878 .63955 .34012 .63184 Mtetra
.658 .75 .918 r
.34012 .63184 .34878 .63955 .36271 .6353 .3541 .62758 Mtetra
.655 .75 .92 r
.3541 .62758 .36271 .6353 .37672 .63111 .36814 .62341 Mtetra
.652 .751 .922 r
.36814 .62341 .37672 .63111 .39079 .62699 .38226 .61934 Mtetra
.654 .754 .923 r
.38226 .61934 .39079 .62699 .40493 .62294 .39645 .61514 Mtetra
.66 .753 .919 r
.39645 .61514 .40493 .62294 .41916 .6187 .41073 .61074 Mtetra
.659 .749 .917 r
.41073 .61074 .41916 .6187 .43346 .61433 .42508 .60637 Mtetra
.656 .75 .919 r
.42508 .60637 .43346 .61433 .44784 .60999 .4395 .60207 Mtetra
.65 .75 .923 r
.4395 .60207 .44784 .60999 .46229 .60571 .454 .59794 Mtetra
.652 .755 .925 r
.454 .59794 .46229 .60571 .47682 .60159 .46858 .5937 Mtetra
.659 .756 .921 r
.46858 .5937 .47682 .60159 .49142 .59739 .48324 .5892 Mtetra
.66 .749 .916 r
.48324 .5892 .49142 .59739 .50611 .59295 .49797 .58465 Mtetra
.659 .747 .915 r
.49797 .58465 .50611 .59295 .52087 .58845 .51279 .58013 Mtetra
.657 .747 .917 r
.51279 .58013 .52087 .58845 .53572 .58394 .52769 .57566 Mtetra
.653 .748 .92 r
.52769 .57566 .53572 .58394 .55064 .57945 .54266 .57131 Mtetra
.651 .752 .924 r
.54266 .57131 .55064 .57945 .56565 .57498 .55772 .56698 Mtetra
.652 .757 .927 r
.55772 .56698 .56565 .57498 .58073 .57051 .57287 .56259 Mtetra
.653 .761 .929 r
.57287 .56259 .58073 .57051 .5959 .56605 .5881 .55813 Mtetra
.654 .762 .929 r
.5881 .55813 .5959 .56605 .61116 .56156 .60341 .5536 Mtetra
.655 .763 .929 r
.60341 .5536 .61116 .56156 .62649 .55702 .6188 .54901 Mtetra
.656 .763 .928 r
.6188 .54901 .62649 .55702 .64191 .55241 .63428 .54435 Mtetra
.657 .763 .928 r
.63428 .54435 .64191 .55241 .65742 .54777 .64984 .53962 Mtetra
.658 .763 .927 r
.64984 .53962 .65742 .54777 .67301 .54314 .66549 .53482 Mtetra
.66 .76 .924 r
.66549 .53482 .67301 .54314 .68869 .53852 .68122 .52996 Mtetra
.659 .755 .921 r
.68122 .52996 .68869 .53852 .70445 .53391 .69704 .52512 Mtetra
.655 .749 .919 r
.69704 .52512 .70445 .53391 .72031 .52932 .71296 .5204 Mtetra
.654 .746 .918 r
.71296 .5204 .72031 .52932 .73627 .52473 .72897 .51572 Mtetra
.652 .745 .918 r
.72897 .51572 .73627 .52473 .75231 .52006 .74507 .51108 Mtetra
.653 .747 .919 r
.74507 .51108 .75231 .52006 .76842 .51514 .76127 .50638 Mtetra
.658 .756 .922 r
.76127 .50638 .76842 .51514 .78462 .51015 .77754 .50141 Mtetra
.661 .758 .922 r
.77754 .50141 .78462 .51015 .80092 .50531 .7939 .49632 Mtetra
.656 .752 .92 r
.7939 .49632 .80092 .50531 .81733 .50053 .81036 .4914 Mtetra
.653 .749 .92 r
.81036 .4914 .81733 .50053 .83383 .49578 .82693 .48656 Mtetra
.652 .747 .919 r
.82693 .48656 .83383 .49578 .85042 .49088 .84359 .48173 Mtetra
.657 .752 .92 r
.84359 .48173 .85042 .49088 .86708 .48579 .86034 .47669 Mtetra
.659 .756 .921 r
.86034 .47669 .86708 .48579 .88385 .48076 .87717 .47152 Mtetra
.656 .752 .921 r
.87717 .47152 .88385 .48076 .90073 .4758 .89411 .46645 Mtetra
.654 .749 .92 r
.89411 .46645 .90073 .4758 .91772 .47089 .91116 .46146 Mtetra
.653 .749 .92 r
.91116 .46146 .91772 .47089 .93479 .46582 .92832 .45644 Mtetra
.659 .751 .918 r
.31742 .62837 .32622 .63609 .34012 .63184 .33138 .62406 Mtetra
.657 .75 .919 r
.33138 .62406 .34012 .63184 .3541 .62758 .3454 .61983 Mtetra
.653 .751 .921 r
.3454 .61983 .3541 .62758 .36814 .62341 .35948 .6157 Mtetra
.652 .753 .923 r
.35948 .6157 .36814 .62341 .38226 .61934 .37364 .61157 Mtetra
.659 .754 .92 r
.37364 .61157 .38226 .61934 .39645 .61514 .38789 .60717 Mtetra
.659 .75 .917 r
.38789 .60717 .39645 .61514 .41073 .61074 .40222 .60274 Mtetra
.656 .75 .919 r
.40222 .60274 .41073 .61074 .42508 .60637 .41661 .5984 Mtetra
.65 .75 .922 r
.41661 .5984 .42508 .60637 .4395 .60207 .43108 .59424 Mtetra
.652 .755 .925 r
.43108 .59424 .4395 .60207 .454 .59794 .44563 .59 Mtetra
.66 .755 .921 r
.44563 .59 .454 .59794 .46858 .5937 .46026 .58546 Mtetra
.66 .749 .916 r
.46026 .58546 .46858 .5937 .48324 .5892 .47497 .58088 Mtetra
.658 .748 .916 r
.47497 .58088 .48324 .5892 .49797 .58465 .48976 .57635 Mtetra
.654 .748 .919 r
.48976 .57635 .49797 .58465 .51279 .58013 .50462 .57196 Mtetra
.649 .751 .924 r
.50462 .57196 .51279 .58013 .52769 .57566 .51957 .56771 Mtetra
.649 .758 .928 r
.51957 .56771 .52769 .57566 .54266 .57131 .5346 .56341 Mtetra
.656 .762 .928 r
.5346 .56341 .54266 .57131 .55772 .56698 .54972 .55882 Mtetra
.658 .757 .923 r
.54972 .55882 .55772 .56698 .57287 .56259 .56492 .55417 Mtetra
.657 .752 .92 r
.56492 .55417 .57287 .56259 .5881 .55813 .5802 .54955 Mtetra
.656 .749 .918 r
.5802 .54955 .5881 .55813 .60341 .5536 .59556 .54494 Mtetra
.656 .748 .917 r
.59556 .54494 .60341 .5536 .6188 .54901 .61102 .5403 Mtetra
.61102 .5403 .6188 .54901 .63428 .54435 .62655 .53563 Mtetra
.655 .748 .918 r
.62655 .53563 .63428 .54435 .64984 .53962 .64218 .53097 Mtetra
.654 .75 .921 r
.64218 .53097 .64984 .53962 .66549 .53482 .65789 .52634 Mtetra
.654 .756 .925 r
.65789 .52634 .66549 .53482 .68122 .52996 .67369 .52164 Mtetra
.66 .763 .926 r
.67369 .52164 .68122 .52996 .69704 .52512 .68957 .51666 Mtetra
.662 .761 .924 r
.68957 .51666 .69704 .52512 .71296 .5204 .70554 .51162 Mtetra
.658 .753 .921 r
.70554 .51162 .71296 .5204 .72897 .51572 .7216 .50671 Mtetra
.654 .748 .919 r
.7216 .50671 .72897 .51572 .74507 .51108 .73776 .50195 Mtetra
.652 .745 .918 r
.73776 .50195 .74507 .51108 .76127 .50638 .75403 .49724 Mtetra
.652 .746 .919 r
.75403 .49724 .76127 .50638 .77754 .50141 .77038 .49248 Mtetra
.659 .755 .921 r
.77038 .49248 .77754 .50141 .7939 .49632 .78681 .48741 Mtetra
.66 .758 .922 r
.78681 .48741 .7939 .49632 .81036 .4914 .80332 .48225 Mtetra
.655 .751 .92 r
.80332 .48225 .81036 .4914 .82693 .48656 .81995 .47728 Mtetra
.653 .748 .92 r
.81995 .47728 .82693 .48656 .84359 .48173 .83668 .47239 Mtetra
.653 .748 .919 r
.83668 .47239 .84359 .48173 .86034 .47669 .85352 .46746 Mtetra
.659 .754 .921 r
.85352 .46746 .86034 .47669 .87717 .47152 .87042 .46225 Mtetra
.658 .755 .921 r
.87042 .46225 .87717 .47152 .89411 .46645 .88742 .45704 Mtetra
.655 .751 .92 r
.88742 .45704 .89411 .46645 .91116 .46146 .90454 .45192 Mtetra
.653 .748 .92 r
.90454 .45192 .91116 .46146 .92832 .45644 .92177 .44688 Mtetra
.658 .751 .918 r
.30855 .62057 .31742 .62837 .33138 .62406 .32254 .61625 Mtetra
.655 .751 .92 r
.32254 .61625 .33138 .62406 .3454 .61983 .33661 .61202 Mtetra
.651 .751 .923 r
.33661 .61202 .3454 .61983 .35948 .6157 .35074 .60791 Mtetra
.656 .754 .922 r
.35074 .60791 .35948 .6157 .37364 .61157 .36495 .60359 Mtetra
.66 .751 .917 r
.36495 .60359 .37364 .61157 .38789 .60717 .37925 .59912 Mtetra
.658 .75 .918 r
.37925 .59912 .38789 .60717 .40222 .60274 .39362 .59472 Mtetra
.652 .75 .921 r
.39362 .59472 .40222 .60274 .41661 .5984 .40805 .59049 Mtetra
.65 .753 .925 r
.40805 .59049 .41661 .5984 .43108 .59424 .42257 .5863 Mtetra
.659 .756 .921 r
.42257 .5863 .43108 .59424 .44563 .59 .43717 .58174 Mtetra
.661 .75 .916 r
.43717 .58174 .44563 .59 .46026 .58546 .45186 .57712 Mtetra
.658 .748 .916 r
.45186 .57712 .46026 .58546 .47497 .58088 .46662 .57257 Mtetra
.652 .748 .92 r
.46662 .57257 .47497 .58088 .48976 .57635 .48145 .56824 Mtetra
.647 .753 .926 r
.48145 .56824 .48976 .57635 .50462 .57196 .49637 .56402 Mtetra
.654 .76 .928 r
.49637 .56402 .50462 .57196 .51957 .56771 .51138 .55952 Mtetra
.659 .756 .922 r
.51138 .55952 .51957 .56771 .5346 .56341 .52646 .55485 Mtetra
.654 .747 .918 r
.52646 .55485 .5346 .56341 .54972 .55882 .54163 .55034 Mtetra
.649 .748 .922 r
.54163 .55034 .54972 .55882 .56492 .55417 .55689 .54597 Mtetra
.647 .756 .929 r
.55689 .54597 .56492 .55417 .5802 .54955 .57223 .54164 Mtetra
.648 .765 .934 r
.57223 .54164 .5802 .54955 .59556 .54494 .58766 .53718 Mtetra
.654 .772 .936 r
.58766 .53718 .59556 .54494 .61102 .5403 .60317 .5325 Mtetra
.659 .774 .934 r
.60317 .5325 .61102 .5403 .62655 .53563 .61877 .52758 Mtetra
.663 .769 .929 r
.61877 .52758 .62655 .53563 .64218 .53097 .63444 .52253 Mtetra
.662 .761 .923 r
.63444 .52253 .64218 .53097 .65789 .52634 .65021 .51752 Mtetra
.658 .751 .919 r
.65021 .51752 .65789 .52634 .67369 .52164 .66606 .51265 Mtetra
.653 .747 .918 r
.66606 .51265 .67369 .52164 .68957 .51666 .68202 .50795 Mtetra
.656 .756 .923 r
.68202 .50795 .68957 .51666 .70554 .51162 .69806 .50306 Mtetra
.663 .763 .925 r
.69806 .50306 .70554 .51162 .7216 .50671 .71417 .49789 Mtetra
.66 .757 .922 r
.71417 .49789 .7216 .50671 .73776 .50195 .73038 .49282 Mtetra
.654 .748 .919 r
.73038 .49282 .73776 .50195 .75403 .49724 .7467 .48798 Mtetra
.651 .746 .919 r
.7467 .48798 .75403 .49724 .77038 .49248 .76313 .48321 Mtetra
.652 .747 .919 r
.76313 .48321 .77038 .49248 .78681 .48741 .77964 .47837 Mtetra
.661 .757 .921 r
.77964 .47837 .78681 .48741 .80332 .48225 .79622 .47315 Mtetra
.659 .756 .922 r
.79622 .47315 .80332 .48225 .81995 .47728 .81291 .46796 Mtetra
.654 .75 .92 r
.81291 .46796 .81995 .47728 .83668 .47239 .8297 .46294 Mtetra
.652 .748 .92 r
.8297 .46294 .83668 .47239 .85352 .46746 .84661 .458 Mtetra
.655 .75 .919 r
.84661 .458 .85352 .46746 .87042 .46225 .8636 .45288 Mtetra
.66 .755 .921 r
.8636 .45288 .87042 .46225 .88742 .45704 .88067 .44755 Mtetra
.656 .752 .921 r
.88067 .44755 .88742 .45704 .90454 .45192 .89785 .44233 Mtetra
.654 .75 .92 r
.89785 .44233 .90454 .45192 .92177 .44688 .91515 .43719 Mtetra
.657 .75 .919 r
.29959 .61269 .30855 .62057 .32254 .61625 .31362 .60838 Mtetra
.653 .751 .921 r
.31362 .60838 .32254 .61625 .33661 .61202 .32773 .60419 Mtetra
.652 .752 .923 r
.32773 .60419 .33661 .61202 .35074 .60791 .3419 .59999 Mtetra
.66 .753 .919 r
.3419 .59999 .35074 .60791 .36495 .60359 .35617 .59552 Mtetra
.659 .75 .917 r
.35617 .59552 .36495 .60359 .37925 .59912 .37051 .59104 Mtetra
.655 .75 .92 r
.37051 .59104 .37925 .59912 .39362 .59472 .38493 .58669 Mtetra
.649 .751 .924 r
.38493 .58669 .39362 .59472 .40805 .59049 .39941 .58251 Mtetra
.657 .755 .923 r
.39941 .58251 .40805 .59049 .42257 .5863 .41398 .57804 Mtetra
.661 .751 .916 r
.41398 .57804 .42257 .5863 .43717 .58174 .42864 .57338 Mtetra
.659 .749 .916 r
.42864 .57338 .43717 .58174 .45186 .57712 .44337 .56878 Mtetra
.652 .748 .92 r
.44337 .56878 .45186 .57712 .46662 .57257 .45818 .56442 Mtetra
.646 .752 .927 r
.45818 .56442 .46662 .57257 .48145 .56824 .47306 .56023 Mtetra
.657 .76 .926 r
.47306 .56023 .48145 .56824 .49637 .56402 .48804 .55561 Mtetra
.656 .751 .92 r
.48804 .55561 .49637 .56402 .51138 .55952 .5031 .551 Mtetra
.644 .746 .923 r
.5031 .551 .51138 .55952 .52646 .55485 .51824 .54682 Mtetra
.628 .754 .938 r
.51824 .54682 .52646 .55485 .54163 .55034 .53346 .5431 Mtetra
.611 .771 .957 r
.53346 .5431 .54163 .55034 .55689 .54597 .54879 .53969 Mtetra
.59 .792 .976 r
.54879 .53969 .55689 .54597 .57223 .54164 .56421 .53648 Mtetra
.592 .828 .989 r
.56421 .53648 .57223 .54164 .58766 .53718 .57973 .53274 Mtetra
.619 .859 .988 r
.57973 .53274 .58766 .53718 .60317 .5325 .59532 .52801 Mtetra
.657 .87 .979 r
.59532 .52801 .60317 .5325 .61877 .52758 .61097 .52229 Mtetra
.684 .854 .964 r
.61097 .52229 .61877 .52758 .63444 .52253 .62669 .51602 Mtetra
.684 .821 .949 r
.62669 .51602 .63444 .52253 .65021 .51752 .64249 .50996 Mtetra
.678 .792 .935 r
.64249 .50996 .65021 .51752 .66606 .51265 .65838 .50419 Mtetra
.666 .766 .925 r
.65838 .50419 .66606 .51265 .68202 .50795 .67437 .49889 Mtetra
.655 .749 .919 r
.67437 .49889 .68202 .50795 .69806 .50306 .69048 .49402 Mtetra
.654 .75 .92 r
.69048 .49402 .69806 .50306 .71417 .49789 .70667 .48915 Mtetra
.664 .763 .924 r
.70667 .48915 .71417 .49789 .73038 .49282 .72294 .48385 Mtetra
.659 .757 .922 r
.72294 .48385 .73038 .49282 .7467 .48798 .73931 .47872 Mtetra
.653 .748 .92 r
.73931 .47872 .7467 .48798 .76313 .48321 .75579 .47382 Mtetra
.651 .746 .919 r
.75579 .47382 .76313 .48321 .77964 .47837 .77238 .46899 Mtetra
.655 .749 .919 r
.77238 .46899 .77964 .47837 .79622 .47315 .78905 .46396 Mtetra
.662 .757 .921 r
.78905 .46396 .79622 .47315 .81291 .46796 .80579 .45862 Mtetra
.657 .753 .921 r
.80579 .45862 .81291 .46796 .8297 .46294 .82265 .45345 Mtetra
.653 .749 .92 r
.82265 .45345 .8297 .46294 .84661 .458 .83962 .44841 Mtetra
.652 .748 .92 r
.83962 .44841 .84661 .458 .8636 .45288 .8567 .44336 Mtetra
.659 .754 .92 r
.8567 .44336 .8636 .45288 .88067 .44755 .87384 .43801 Mtetra
.658 .754 .921 r
.87384 .43801 .88067 .44755 .89785 .44233 .89109 .43265 Mtetra
.655 .751 .92 r
.89109 .43265 .89785 .44233 .91515 .43719 .90846 .42741 Mtetra
.656 .751 .92 r
.29054 .60476 .29959 .61269 .31362 .60838 .30462 .60045 Mtetra
.651 .751 .922 r
.30462 .60045 .31362 .60838 .32773 .60419 .31876 .59627 Mtetra
.655 .753 .922 r
.31876 .59627 .32773 .60419 .3419 .59999 .33299 .59192 Mtetra
.66 .751 .918 r
.33299 .59192 .3419 .59999 .35617 .59552 .34731 .58737 Mtetra
.658 .75 .918 r
.34731 .58737 .35617 .59552 .37051 .59104 .36169 .58291 Mtetra
.651 .75 .922 r
.36169 .58291 .37051 .59104 .38493 .58669 .37615 .57866 Mtetra
.652 .753 .924 r
.37615 .57866 .38493 .58669 .39941 .58251 .39068 .57434 Mtetra
.661 .754 .919 r
.39068 .57434 .39941 .58251 .41398 .57804 .40531 .56966 Mtetra
.661 .75 .916 r
.40531 .56966 .41398 .57804 .42864 .57338 .42002 .56499 Mtetra
.654 .749 .919 r
.42002 .56499 .42864 .57338 .44337 .56878 .4348 .56052 Mtetra
.645 .75 .926 r
.4348 .56052 .44337 .56878 .45818 .56442 .44965 .55633 Mtetra
.656 .759 .925 r
.44965 .55633 .45818 .56442 .47306 .56023 .46459 .55173 Mtetra
.655 .75 .919 r
.46459 .55173 .47306 .56023 .48804 .55561 .47962 .54715 Mtetra
.634 .745 .928 r
.47962 .54715 .48804 .55561 .5031 .551 .49473 .54327 Mtetra
.596 .752 .952 r
.49473 .54327 .5031 .551 .51824 .54682 .50992 .5404 Mtetra
.501 .755 .986 r
.50992 .5404 .51824 .54682 .53346 .5431 .52521 .53919 Mtetra
.412 .789 .993 r
.52521 .53919 .53346 .5431 .54879 .53969 .54061 .53789 Mtetra
.357 .809 .944 r
.54061 .53789 .54879 .53969 .56421 .53648 .55613 .53556 Mtetra
.388 .839 .922 r
.55613 .53556 .56421 .53648 .57973 .53274 .57174 .53202 Mtetra
.462 .88 .93 r
.57174 .53202 .57973 .53274 .59532 .52801 .58743 .52725 Mtetra
.542 .917 .941 r
.58743 .52725 .59532 .52801 .61097 .52229 .60318 .52126 Mtetra
.621 .943 .949 r
.60318 .52126 .61097 .52229 .62669 .51602 .61897 .51402 Mtetra
.697 .947 .958 r
.61897 .51402 .62669 .51602 .64249 .50996 .63479 .50575 Mtetra
.734 .9 .953 r
.63479 .50575 .64249 .50996 .65838 .50419 .65067 .49736 Mtetra
.699 .821 .94 r
.65067 .49736 .65838 .50419 .67437 .49889 .66668 .49063 Mtetra
.674 .778 .928 r
.66668 .49063 .67437 .49889 .69048 .49402 .68282 .48492 Mtetra
.656 .752 .92 r
.68282 .48492 .69048 .49402 .70667 .48915 .69907 .47992 Mtetra
.655 .75 .919 r
.69907 .47992 .70667 .48915 .72294 .48385 .71543 .47493 Mtetra
.665 .762 .922 r
.71543 .47493 .72294 .48385 .73931 .47872 .73185 .46952 Mtetra
.657 .754 .921 r
.73185 .46952 .73931 .47872 .75579 .47382 .74839 .46439 Mtetra
.651 .747 .92 r
.74839 .46439 .75579 .47382 .77238 .46899 .76504 .45947 Mtetra
.651 .746 .919 r
.76504 .45947 .77238 .46899 .78905 .46396 .78179 .45455 Mtetra
.659 .753 .92 r
.78179 .45455 .78905 .46396 .80579 .45862 .79861 .44925 Mtetra
.66 .756 .921 r
.79861 .44925 .80579 .45862 .82265 .45345 .81553 .44388 Mtetra
.654 .75 .92 r
.81553 .44388 .82265 .45345 .83962 .44841 .83256 .43873 Mtetra
.652 .748 .92 r
.83256 .43873 .83962 .44841 .8567 .44336 .84971 .43365 Mtetra
.656 .75 .919 r
.84971 .43365 .8567 .44336 .87384 .43801 .86694 .42836 Mtetra
.66 .755 .92 r
.86694 .42836 .87384 .43801 .89109 .43265 .88426 .42289 Mtetra
.656 .752 .92 r
.88426 .42289 .89109 .43265 .90846 .42741 .9017 .41754 Mtetra
.654 .751 .921 r
.2814 .59677 .29054 .60476 .30462 .60045 .29552 .59247 Mtetra
.651 .751 .923 r
.29552 .59247 .30462 .60045 .31876 .59627 .30971 .58825 Mtetra
.659 .753 .92 r
.30971 .58825 .31876 .59627 .33299 .59192 .32399 .58375 Mtetra
.66 .751 .918 r
.32399 .58375 .33299 .59192 .34731 .58737 .33835 .57918 Mtetra
.655 .75 .92 r
.33835 .57918 .34731 .58737 .36169 .58291 .35278 .57474 Mtetra
.649 .75 .924 r
.35278 .57474 .36169 .58291 .37615 .57866 .36728 .57052 Mtetra
.657 .754 .922 r
.36728 .57052 .37615 .57866 .39068 .57434 .38187 .56597 Mtetra
.662 .751 .916 r
.38187 .56597 .39068 .57434 .40531 .56966 .39655 .56122 Mtetra
.658 .749 .917 r
.39655 .56122 .40531 .56966 .42002 .56499 .41131 .55659 Mtetra
.647 .748 .923 r
.41131 .55659 .42002 .56499 .4348 .56052 .42613 .55233 Mtetra
.651 .756 .926 r
.42613 .55233 .4348 .56052 .44965 .55633 .44104 .5479 Mtetra
.658 .753 .92 r
.44104 .5479 .44965 .55633 .46459 .55173 .45604 .54319 Mtetra
.633 .744 .928 r
.45604 .54319 .46459 .55173 .47962 .54715 .4711 .53934 Mtetra
.574 .744 .957 r
.4711 .53934 .47962 .54715 .49473 .54327 .48625 .53704 Mtetra
.4 .715 .987 r
.48625 .53704 .49473 .54327 .50992 .5404 .50147 .53744 Mtetra
.242 .718 .938 r
.50147 .53744 .50992 .5404 .52521 .53919 .51683 .53749 Mtetra
.261 .754 .911 r
.51683 .53749 .52521 .53919 .54061 .53789 .53232 .5362 Mtetra
.4 .834 .951 r
.53232 .5362 .54061 .53789 .55613 .53556 .54792 .53319 Mtetra
.519 .878 .983 r
.54792 .53319 .55613 .53556 .57174 .53202 .56361 .52898 Mtetra
.577 .886 .991 r
.56361 .52898 .57174 .53202 .58743 .52725 .57938 .52417 Mtetra
.606 .896 .988 r
.57938 .52417 .58743 .52725 .60318 .52126 .59523 .51876 Mtetra
.642 .922 .976 r
.59523 .51876 .60318 .52126 .61897 .51402 .61114 .51214 Mtetra
.695 .95 .956 r
.61114 .51214 .61897 .51402 .63479 .50575 .62707 .50376 Mtetra
.743 .957 .942 r
.62707 .50376 .63479 .50575 .65067 .49736 .643 .49402 Mtetra
.77 .93 .938 r
.643 .49402 .65067 .49736 .66668 .49063 .65897 .48389 Mtetra
.714 .831 .937 r
.65897 .48389 .66668 .49063 .68282 .48492 .67511 .47647 Mtetra
.675 .777 .927 r
.67511 .47647 .68282 .48492 .69907 .47992 .69139 .47062 Mtetra
.654 .75 .921 r
.69139 .47062 .69907 .47992 .71543 .47493 .70782 .46565 Mtetra
.66 .754 .92 r
.70782 .46565 .71543 .47493 .73185 .46952 .72432 .46039 Mtetra
.664 .76 .922 r
.72432 .46039 .73185 .46952 .74839 .46439 .74091 .45493 Mtetra
.654 .75 .921 r
.74091 .45493 .74839 .46439 .76504 .45947 .75762 .44988 Mtetra
.65 .747 .92 r
.75762 .44988 .76504 .45947 .78179 .45455 .77444 .44492 Mtetra
.655 .749 .919 r
.77444 .44492 .78179 .45455 .79861 .44925 .79135 .43977 Mtetra
.662 .756 .92 r
.79135 .43977 .79861 .44925 .81553 .44388 .80833 .43426 Mtetra
.656 .752 .921 r
.80833 .43426 .81553 .44388 .83256 .43873 .82543 .42898 Mtetra
.652 .749 .921 r
.82543 .42898 .83256 .43873 .84971 .43365 .84265 .42382 Mtetra
.653 .749 .92 r
.84265 .42382 .84971 .43365 .86694 .42836 .85996 .41858 Mtetra
.66 .754 .92 r
.85996 .41858 .86694 .42836 .88426 .42289 .87735 .41305 Mtetra
.657 .753 .921 r
.87735 .41305 .88426 .42289 .9017 .41754 .89486 .40759 Mtetra
.653 .751 .921 r
.27216 .58871 .2814 .59677 .29552 .59247 .28632 .58441 Mtetra
.652 .752 .923 r
.28632 .58441 .29552 .59247 .30971 .58825 .30056 .58011 Mtetra
.66 .753 .918 r
.30056 .58011 .30971 .58825 .32399 .58375 .3149 .5755 Mtetra
.659 .751 .918 r
.3149 .5755 .32399 .58375 .33835 .57918 .3293 .57093 Mtetra
.652 .75 .921 r
.3293 .57093 .33835 .57918 .35278 .57474 .34378 .56655 Mtetra
.65 .752 .924 r
.34378 .56655 .35278 .57474 .36728 .57052 .35833 .56224 Mtetra
.661 .754 .919 r
.35833 .56224 .36728 .57052 .38187 .56597 .37298 .5575 Mtetra
.661 .751 .916 r
.37298 .5575 .38187 .56597 .39655 .56122 .3877 .55274 Mtetra
.653 .749 .92 r
.3877 .55274 .39655 .56122 .41131 .55659 .4025 .54824 Mtetra
.644 .751 .927 r
.4025 .54824 .41131 .55659 .42613 .55233 .41737 .54403 Mtetra
.66 .758 .922 r
.41737 .54403 .42613 .55233 .44104 .5479 .43234 .53923 Mtetra
.643 .745 .923 r
.43234 .53923 .44104 .5479 .45604 .54319 .44738 .53501 Mtetra
.586 .739 .949 r
.44738 .53501 .45604 .54319 .4711 .53934 .46248 .53248 Mtetra
.384 .69 .98 r
.46248 .53248 .4711 .53934 .48625 .53704 .47763 .53345 Mtetra
.179 .665 .925 r
.47763 .53345 .48625 .53704 .50147 .53744 .49291 .53469 Mtetra
.292 .754 .949 r
.49291 .53469 .50147 .53744 .51683 .53749 .50835 .53392 Mtetra
.564 .866 .996 r
.50835 .53392 .51683 .53749 .53232 .5362 .52391 .5298 Mtetra
.72 .831 .933 r
.52391 .5298 .53232 .5362 .54792 .53319 .53955 .52233 Mtetra
.696 .723 .871 r
.53955 .52233 .54792 .53319 .56361 .52898 .55527 .51547 Mtetra
.651 .662 .848 r
.55527 .51547 .56361 .52898 .57938 .52417 .57108 .5106 Mtetra
.609 .644 .86 r
.57108 .5106 .57938 .52417 .59523 .51876 .58702 .50773 Mtetra
.587 .682 .906 r
.58702 .50773 .59523 .51876 .61114 .51214 .60308 .5055 Mtetra
.664 .819 .958 r
.60308 .5055 .61114 .51214 .62707 .50376 .61917 .49989 Mtetra
.743 .914 .951 r
.61917 .49989 .62707 .50376 .643 .49402 .63523 .49088 Mtetra
.789 .938 .927 r
.63523 .49088 .643 .49402 .65897 .48389 .65128 .47981 Mtetra
.787 .916 .926 r
.65128 .47981 .65897 .48389 .67511 .47647 .66736 .46898 Mtetra
.709 .814 .93 r
.66736 .46898 .67511 .47647 .69139 .47062 .68366 .46169 Mtetra
.667 .766 .924 r
.68366 .46169 .69139 .47062 .70782 .46565 .70012 .45611 Mtetra
.652 .747 .92 r
.70012 .45611 .70782 .46565 .72432 .46039 .71671 .45112 Mtetra
.666 .76 .921 r
.71671 .45112 .72432 .46039 .74091 .45493 .73336 .44552 Mtetra
.658 .755 .922 r
.73336 .44552 .74091 .45493 .75762 .44988 .75012 .44022 Mtetra
.651 .748 .921 r
.75012 .44022 .75762 .44988 .77444 .44492 .76701 .43518 Mtetra
.651 .747 .92 r
.76701 .43518 .77444 .44492 .79135 .43977 .784 .43011 Mtetra
.661 .755 .919 r
.784 .43011 .79135 .43977 .80833 .43426 .80105 .42459 Mtetra
.659 .755 .921 r
.80105 .42459 .80833 .43426 .82543 .42898 .81822 .41914 Mtetra
.653 .75 .921 r
.81822 .41914 .82543 .42898 .84265 .42382 .83551 .41388 Mtetra
.652 .748 .92 r
.83551 .41388 .84265 .42382 .85996 .41858 .8529 .40865 Mtetra
.659 .753 .919 r
.8529 .40865 .85996 .41858 .87735 .41305 .87037 .4031 Mtetra
.658 .754 .92 r
.87037 .4031 .87735 .41305 .89486 .40759 .88795 .39753 Mtetra
.652 .751 .922 r
.26284 .58057 .27216 .58871 .28632 .58441 .27704 .57627 Mtetra
.654 .752 .922 r
.27704 .57627 .28632 .58441 .30056 .58011 .29133 .57185 Mtetra
.661 .752 .918 r
.29133 .57185 .30056 .58011 .3149 .5755 .30571 .56719 Mtetra
.658 .751 .919 r
.30571 .56719 .3149 .5755 .3293 .57093 .32016 .56261 Mtetra
.65 .75 .922 r
.32016 .56261 .3293 .57093 .34378 .56655 .33468 .55826 Mtetra
.653 .752 .923 r
.33468 .55826 .34378 .56655 .35833 .56224 .34929 .55379 Mtetra
.662 .752 .917 r
.34929 .55379 .35833 .56224 .37298 .5575 .36399 .54897 Mtetra
.66 .751 .917 r
.36399 .54897 .37298 .5575 .3877 .55274 .37876 .54421 Mtetra
.648 .749 .923 r
.37876 .54421 .3877 .55274 .4025 .54824 .3936 .53985 Mtetra
.65 .754 .925 r
.3936 .53985 .4025 .54824 .41737 .54403 .40853 .53539 Mtetra
.657 .751 .919 r
.40853 .53539 .41737 .54403 .43234 .53923 .42355 .53066 Mtetra
.617 .741 .935 r
.42355 .53066 .43234 .53923 .44738 .53501 .43862 .52724 Mtetra
.466 .704 .972 r
.43862 .52724 .44738 .53501 .46248 .53248 .45372 .52722 Mtetra
.203 .638 .949 r
.45372 .52722 .46248 .53248 .47763 .53345 .4689 .52945 Mtetra
.273 .714 .962 r
.4689 .52945 .47763 .53345 .49291 .53469 .48426 .52988 Mtetra
.643 .857 .981 r
.48426 .52988 .49291 .53469 .50835 .53392 .49979 .52462 Mtetra
.77 .771 .854 r
.49979 .52462 .50835 .53392 .52391 .5298 .51543 .51373 Mtetra
.732 .662 .781 r
.51543 .51373 .52391 .5298 .53955 .52233 .53109 .50231 Mtetra
.688 .606 .76 r
.53109 .50231 .53955 .52233 .55527 .51547 .5468 .49316 Mtetra
.63 .559 .756 r
.5468 .49316 .55527 .51547 .57108 .5106 .56261 .48822 Mtetra
.57 .526 .766 r
.56261 .48822 .57108 .5106 .58702 .50773 .57857 .48752 Mtetra
.526 .52 .792 r
.57857 .48752 .58702 .50773 .60308 .5055 .59472 .48911 Mtetra
.521 .562 .838 r
.59472 .48911 .60308 .5055 .61917 .49989 .61102 .49023 Mtetra
.643 .738 .918 r
.61102 .49023 .61917 .49989 .63523 .49088 .62729 .48566 Mtetra
.777 .885 .923 r
.62729 .48566 .63523 .49088 .65128 .47981 .64346 .47532 Mtetra
.813 .907 .905 r
.64346 .47532 .65128 .47981 .66736 .46898 .65959 .46311 Mtetra
.768 .87 .923 r
.65959 .46311 .66736 .46898 .68366 .46169 .67585 .45316 Mtetra
.688 .785 .925 r
.67585 .45316 .68366 .46169 .70012 .45611 .69234 .44666 Mtetra
.655 .753 .922 r
.69234 .44666 .70012 .45611 .71671 .45112 .70899 .4415 Mtetra
.661 .752 .918 r
.70899 .4415 .71671 .45112 .73336 .44552 .72572 .43605 Mtetra
.663 .758 .921 r
.72572 .43605 .73336 .44552 .75012 .44022 .74255 .4305 Mtetra
.652 .749 .921 r
.74255 .4305 .75012 .44022 .76701 .43518 .7595 .42535 Mtetra
.65 .747 .921 r
.7595 .42535 .76701 .43518 .784 .43011 .77656 .42026 Mtetra
.658 .751 .919 r
.77656 .42026 .784 .43011 .80105 .42459 .7937 .4148 Mtetra
.661 .755 .92 r
.7937 .4148 .80105 .42459 .81822 .41914 .81093 .40921 Mtetra
.654 .751 .921 r
.81093 .40921 .81822 .41914 .83551 .41388 .82829 .40385 Mtetra
.651 .749 .921 r
.82829 .40385 .83551 .41388 .8529 .40865 .84576 .39858 Mtetra
.657 .751 .919 r
.84576 .39858 .8529 .40865 .87037 .4031 .86332 .39303 Mtetra
.659 .754 .92 r
.86332 .39303 .87037 .4031 .88795 .39753 .88097 .38737 Mtetra
.651 .75 .922 r
.25342 .57236 .26284 .58057 .27704 .57627 .26766 .56803 Mtetra
.656 .752 .921 r
.26766 .56803 .27704 .57627 .29133 .57185 .282 .56352 Mtetra
.66 .752 .918 r
.282 .56352 .29133 .57185 .30571 .56719 .29643 .55881 Mtetra
.657 .751 .919 r
.29643 .55881 .30571 .56719 .32016 .56261 .31093 .55421 Mtetra
.649 .75 .923 r
.31093 .55421 .32016 .56261 .33468 .55826 .32549 .54987 Mtetra
.656 .753 .921 r
.32549 .54987 .33468 .55826 .34929 .55379 .34015 .54525 Mtetra
.662 .752 .917 r
.34015 .54525 .34929 .55379 .36399 .54897 .3549 .54038 Mtetra
.658 .751 .918 r
.3549 .54038 .36399 .54897 .37876 .54421 .36973 .53563 Mtetra
.644 .748 .925 r
.36973 .53563 .37876 .54421 .3936 .53985 .38461 .53134 Mtetra
.656 .755 .923 r
.38461 .53134 .3936 .53985 .40853 .53539 .3996 .52662 Mtetra
.648 .747 .922 r
.3996 .52662 .40853 .53539 .42355 .53066 .41467 .52217 Mtetra
.582 .733 .947 r
.41467 .52217 .42355 .53066 .43862 .52724 .42976 .51971 Mtetra
.328 .646 .967 r
.42976 .51971 .43862 .52724 .45372 .52722 .44485 .52181 Mtetra
.206 .637 .95 r
.44485 .52181 .45372 .52722 .4689 .52945 .46008 .52407 Mtetra
.524 .802 .996 r
.46008 .52407 .4689 .52945 .48426 .52988 .47554 .52165 Mtetra
.792 .796 .855 r
.47554 .52165 .48426 .52988 .49979 .52462 .4912 .50961 Mtetra
.778 .69 .766 r
.4912 .50961 .49979 .52462 .51543 .51373 .50691 .49391 Mtetra
.74 .633 .741 r
.50691 .49391 .51543 .51373 .53109 .50231 .5226 .47937 Mtetra
.682 .583 .738 r
.5226 .47937 .53109 .50231 .5468 .49316 .53831 .46959 Mtetra
.627 .55 .747 r
.53831 .46959 .5468 .49316 .56261 .48822 .55411 .46459 Mtetra
.561 .512 .758 r
.55411 .46459 .56261 .48822 .57857 .48752 .57006 .46436 Mtetra
.475 .465 .767 r
.57006 .46436 .57857 .48752 .59472 .48911 .58624 .46897 Mtetra
.429 .466 .797 r
.58624 .46897 .59472 .48911 .61102 .49023 .60264 .47478 Mtetra
.485 .559 .855 r
.60264 .47478 .61102 .49023 .62729 .48566 .61914 .47696 Mtetra
.712 .787 .91 r
.61914 .47696 .62729 .48566 .64346 .47532 .63549 .46941 Mtetra
.81 .872 .893 r
.63549 .46941 .64346 .47532 .65959 .46311 .65172 .45707 Mtetra
.807 .871 .894 r
.65172 .45707 .65959 .46311 .67585 .45316 .66798 .44486 Mtetra
.712 .8 .92 r
.66798 .44486 .67585 .45316 .69234 .44666 .68449 .43728 Mtetra
.663 .76 .922 r
.68449 .43728 .69234 .44666 .70899 .4415 .70119 .43173 Mtetra
.656 .749 .919 r
.70119 .43173 .70899 .4415 .72572 .43605 .71801 .42644 Mtetra
.666 .758 .919 r
.71801 .42644 .72572 .43605 .74255 .4305 .73489 .4207 Mtetra
.654 .751 .921 r
.73489 .4207 .74255 .4305 .7595 .42535 .75191 .41544 Mtetra
.65 .748 .921 r
.75191 .41544 .7595 .42535 .77656 .42026 .76904 .4103 Mtetra
.656 .75 .92 r
.76904 .4103 .77656 .42026 .7937 .4148 .78626 .40488 Mtetra
.662 .755 .919 r
.78626 .40488 .7937 .4148 .81093 .40921 .80356 .39917 Mtetra
.655 .751 .921 r
.80356 .39917 .81093 .40921 .82829 .40385 .82099 .39373 Mtetra
.652 .749 .921 r
.82099 .39373 .82829 .40385 .84576 .39858 .83854 .38839 Mtetra
.656 .751 .92 r
.83854 .38839 .84576 .39858 .86332 .39303 .85618 .38284 Mtetra
.66 .754 .92 r
.85618 .38284 .86332 .39303 .88097 .38737 .8739 .37709 Mtetra
.651 .75 .922 r
.2439 .56406 .25342 .57236 .26766 .56803 .25819 .5597 Mtetra
.657 .752 .92 r
.25819 .5597 .26766 .56803 .282 .56352 .27258 .5551 Mtetra
.66 .752 .918 r
.27258 .5551 .282 .56352 .29643 .55881 .28706 .55036 Mtetra
.656 .751 .92 r
.28706 .55036 .29643 .55881 .31093 .55421 .30161 .54573 Mtetra
.648 .75 .924 r
.30161 .54573 .31093 .55421 .32549 .54987 .31621 .54137 Mtetra
.658 .753 .92 r
.31621 .54137 .32549 .54987 .34015 .54525 .33093 .53664 Mtetra
.662 .752 .917 r
.33093 .53664 .34015 .54525 .3549 .54038 .34573 .53172 Mtetra
.656 .751 .92 r
.34573 .53172 .3549 .54038 .36973 .53563 .3606 .52699 Mtetra
.643 .749 .926 r
.3606 .52699 .36973 .53563 .38461 .53134 .37553 .5227 Mtetra
.659 .754 .92 r
.37553 .5227 .38461 .53134 .3996 .52662 .39058 .51781 Mtetra
.638 .746 .926 r
.39058 .51781 .3996 .52662 .41467 .52217 .40568 .51365 Mtetra
.535 .717 .957 r
.40568 .51365 .41467 .52217 .42976 .51971 .42079 .51233 Mtetra
.253 .611 .955 r
.42079 .51233 .42976 .51971 .44485 .52181 .43589 .51532 Mtetra
.313 .671 .975 r
.43589 .51532 .44485 .52181 .46008 .52407 .45119 .51689 Mtetra
.705 .809 .929 r
.45119 .51689 .46008 .52407 .47554 .52165 .46678 .50999 Mtetra
.805 .738 .79 r
.46678 .50999 .47554 .52165 .4912 .50961 .48256 .49399 Mtetra
.797 .691 .747 r
.48256 .49399 .4912 .50961 .50691 .49391 .49834 .47516 Mtetra
.733 .639 .754 r
.49834 .47516 .50691 .49391 .5226 .47937 .51407 .46207 Mtetra
.679 .628 .791 r
.51407 .46207 .5226 .47937 .53831 .46959 .52981 .45454 Mtetra
.648 .642 .83 r
.52981 .45454 .53831 .46959 .55411 .46459 .54564 .44947 Mtetra
.6 .62 .843 r
.54564 .44947 .55411 .46459 .57006 .46436 .56159 .44687 Mtetra
.475 .523 .827 r
.56159 .44687 .57006 .46436 .58624 .46897 .57775 .44988 Mtetra
.327 .418 .802 r
.57775 .44988 .58624 .46897 .60264 .47478 .5942 .45873 Mtetra
.369 .486 .846 r
.5942 .45873 .60264 .47478 .61914 .47696 .61082 .46479 Mtetra
.607 .677 .891 r
.61082 .46479 .61914 .47696 .63549 .46941 .62736 .46167 Mtetra
.79 .829 .881 r
.62736 .46167 .63549 .46941 .65172 .45707 .6437 .44993 Mtetra
.816 .846 .872 r
.6437 .44993 .65172 .45707 .66798 .44486 .66002 .43671 Mtetra
.738 .813 .911 r
.66002 .43671 .66798 .44486 .68449 .43728 .67656 .42786 Mtetra
.671 .764 .92 r
.67656 .42786 .68449 .43728 .70119 .43173 .69331 .4219 Mtetra
.653 .75 .921 r
.69331 .4219 .70119 .43173 .71801 .42644 .7102 .41668 Mtetra
.667 .758 .918 r
.7102 .41668 .71801 .42644 .73489 .4207 .72716 .41083 Mtetra
.655 .752 .921 r
.72716 .41083 .73489 .4207 .75191 .41544 .74424 .40544 Mtetra
.65 .748 .922 r
.74424 .40544 .75191 .41544 .76904 .4103 .76144 .40023 Mtetra
.654 .75 .92 r
.76144 .40023 .76904 .4103 .78626 .40488 .77874 .39483 Mtetra
.662 .755 .919 r
.77874 .39483 .78626 .40488 .80356 .39917 .79611 .38904 Mtetra
.655 .752 .921 r
.79611 .38904 .80356 .39917 .82099 .39373 .81361 .38351 Mtetra
.652 .749 .921 r
.81361 .38351 .82099 .39373 .83854 .38839 .83124 .3781 Mtetra
.655 .751 .92 r
.83124 .3781 .83854 .38839 .85618 .38284 .84895 .37253 Mtetra
.66 .754 .919 r
.84895 .37253 .85618 .38284 .8739 .37709 .86676 .3667 Mtetra
.651 .75 .922 r
.23429 .55567 .2439 .56406 .25819 .5597 .24863 .55127 Mtetra
.657 .752 .92 r
.24863 .55127 .25819 .5597 .27258 .5551 .26307 .54661 Mtetra
.66 .752 .918 r
.26307 .54661 .27258 .5551 .28706 .55036 .27759 .54182 Mtetra
.656 .751 .92 r
.27759 .54182 .28706 .55036 .30161 .54573 .29218 .53717 Mtetra
.648 .75 .924 r
.29218 .53717 .30161 .54573 .31621 .54137 .30684 .53276 Mtetra
.659 .753 .919 r
.30684 .53276 .31621 .54137 .33093 .53664 .3216 .52795 Mtetra
.662 .753 .917 r
.3216 .52795 .33093 .53664 .34573 .53172 .33646 .52298 Mtetra
.655 .751 .92 r
.33646 .52298 .34573 .53172 .3606 .52699 .35138 .51825 Mtetra
.643 .749 .926 r
.35138 .51825 .3606 .52699 .37553 .5227 .36636 .51392 Mtetra
.66 .754 .919 r
.36636 .51392 .37553 .5227 .39058 .51781 .38146 .50894 Mtetra
.632 .744 .929 r
.38146 .50894 .39058 .51781 .40568 .51365 .39661 .50494 Mtetra
.503 .701 .959 r
.39661 .50494 .40568 .51365 .42079 .51233 .41173 .50434 Mtetra
.262 .601 .952 r
.41173 .50434 .42079 .51233 .43589 .51532 .42687 .50753 Mtetra
.401 .682 .974 r
.42687 .50753 .43589 .51532 .45119 .51689 .44222 .50845 Mtetra
.754 .789 .882 r
.44222 .50845 .45119 .51689 .46678 .50999 .45793 .49888 Mtetra
.827 .75 .778 r
.45793 .49888 .46678 .50999 .48256 .49399 .47382 .48057 Mtetra
.818 .72 .757 r
.47382 .48057 .48256 .49399 .49834 .47516 .48969 .4611 Mtetra
.738 .691 .806 r
.48969 .4611 .49834 .47516 .51407 .46207 .50546 .45025 Mtetra
.674 .704 .87 r
.50546 .45025 .51407 .46207 .52981 .45454 .52125 .44427 Mtetra
.657 .73 .903 r
.52125 .44427 .52981 .45454 .54564 .44947 .53714 .43915 Mtetra
.635 .722 .91 r
.53714 .43915 .54564 .44947 .56159 .44687 .55312 .43488 Mtetra
.495 .626 .909 r
.55312 .43488 .56159 .44687 .57775 .44988 .56927 .43552 Mtetra
.19 .405 .842 r
.56927 .43552 .57775 .44988 .5942 .45873 .58574 .44489 Mtetra
.226 .439 .859 r
.58574 .44489 .5942 .45873 .61082 .46479 .60243 .45317 Mtetra
.528 .655 .916 r
.60243 .45317 .61082 .46479 .62736 .46167 .61909 .45264 Mtetra
.774 .799 .874 r
.61909 .45264 .62736 .46167 .6437 .44993 .63555 .44146 Mtetra
.81 .818 .857 r
.63555 .44146 .6437 .44993 .66002 .43671 .65195 .42793 Mtetra
.751 .803 .895 r
.65195 .42793 .66002 .43671 .67656 .42786 .66853 .41823 Mtetra
.676 .764 .917 r
.66853 .41823 .67656 .42786 .69331 .4219 .68534 .412 Mtetra
.652 .75 .922 r
.68534 .412 .69331 .4219 .7102 .41668 .70231 .40676 Mtetra
.667 .757 .917 r
.70231 .40676 .7102 .41668 .72716 .41083 .71933 .40085 Mtetra
.657 .752 .921 r
.71933 .40085 .72716 .41083 .74424 .40544 .73648 .39534 Mtetra
.65 .749 .922 r
.73648 .39534 .74424 .40544 .76144 .40023 .75376 .39008 Mtetra
.653 .75 .921 r
.75376 .39008 .76144 .40023 .77874 .39483 .77113 .38464 Mtetra
.662 .754 .918 r
.77113 .38464 .77874 .39483 .79611 .38904 .78858 .37879 Mtetra
.656 .752 .92 r
.78858 .37879 .79611 .38904 .81361 .38351 .80615 .37318 Mtetra
.652 .75 .921 r
.80615 .37318 .81361 .38351 .83124 .3781 .82385 .3677 Mtetra
.654 .751 .921 r
.82385 .3677 .83124 .3781 .84895 .37253 .84165 .36208 Mtetra
.66 .753 .919 r
.84165 .36208 .84895 .37253 .86676 .3667 .85953 .35619 Mtetra
.651 .75 .922 r
.22458 .5472 .23429 .55567 .24863 .55127 .23896 .54275 Mtetra
.657 .752 .92 r
.23896 .54275 .24863 .55127 .26307 .54661 .25345 .53804 Mtetra
.66 .752 .918 r
.25345 .53804 .26307 .54661 .27759 .54182 .26802 .53321 Mtetra
.656 .751 .92 r
.26802 .53321 .27759 .54182 .29218 .53717 .28266 .52851 Mtetra
.648 .749 .923 r
.28266 .52851 .29218 .53717 .30684 .53276 .29737 .52405 Mtetra
.659 .752 .919 r
.29737 .52405 .30684 .53276 .3216 .52795 .31218 .51919 Mtetra
.662 .753 .918 r
.31218 .51919 .3216 .52795 .33646 .52298 .32709 .51417 Mtetra
.655 .751 .921 r
.32709 .51417 .33646 .52298 .35138 .51825 .34206 .50939 Mtetra
.643 .748 .925 r
.34206 .50939 .35138 .51825 .36636 .51392 .35709 .50501 Mtetra
.66 .753 .919 r
.35709 .50501 .36636 .51392 .38146 .50894 .37225 .49998 Mtetra
.632 .744 .929 r
.37225 .49998 .38146 .50894 .39661 .50494 .38744 .49593 Mtetra
.507 .698 .955 r
.38744 .49593 .39661 .50494 .41173 .50434 .40261 .49529 Mtetra
.303 .597 .948 r
.40261 .49529 .41173 .50434 .42687 .50753 .41778 .49845 Mtetra
.434 .665 .959 r
.41778 .49845 .42687 .50753 .44222 .50845 .43317 .49933 Mtetra
.751 .776 .874 r
.43317 .49933 .44222 .50845 .45793 .49888 .44895 .4897 Mtetra
.844 .782 .792 r
.44895 .4897 .45793 .49888 .47382 .48057 .46494 .4713 Mtetra
.852 .782 .783 r
.46494 .4713 .47382 .48057 .48969 .4611 .4809 .45174 Mtetra
.769 .777 .86 r
.4809 .45174 .48969 .4611 .50546 .45025 .49675 .44082 Mtetra
.679 .756 .909 r
.49675 .44082 .50546 .45025 .52125 .44427 .5126 .43479 Mtetra
.657 .749 .918 r
.5126 .43479 .52125 .44427 .53714 .43915 .52855 .42961 Mtetra
.634 .741 .926 r
.52855 .42961 .53714 .43915 .55312 .43488 .54459 .42529 Mtetra
.458 .666 .952 r
.54459 .42529 .55312 .43488 .56927 .43552 .56079 .42588 Mtetra
0 .363 .829 r
.56079 .42588 .56927 .43552 .58574 .44489 .57728 .43523 Mtetra
.042 .417 .864 r
.57728 .43523 .58574 .44489 .60243 .45317 .594 .44349 Mtetra
.505 .691 .951 r
.594 .44349 .60243 .45317 .61909 .45264 .61072 .44291 Mtetra
.77 .786 .866 r
.61072 .44291 .61909 .45264 .63555 .44146 .62726 .43167 Mtetra
.801 .792 .844 r
.62726 .43167 .63555 .44146 .65195 .42793 .64374 .41805 Mtetra
.746 .78 .881 r
.64374 .41805 .65195 .42793 .66853 .41823 .66041 .40829 Mtetra
.676 .759 .913 r
.66041 .40829 .66853 .41823 .68534 .412 .67729 .40199 Mtetra
.652 .75 .922 r
.67729 .40199 .68534 .412 .70231 .40676 .69432 .39669 Mtetra
.667 .756 .917 r
.69432 .39669 .70231 .40676 .71933 .40085 .71142 .39072 Mtetra
.657 .752 .92 r
.71142 .39072 .71933 .40085 .73648 .39534 .72864 .38515 Mtetra
.65 .749 .922 r
.72864 .38515 .73648 .39534 .75376 .39008 .74599 .37982 Mtetra
.653 .75 .921 r
.74599 .37982 .75376 .39008 .77113 .38464 .76344 .37433 Mtetra
.662 .754 .918 r
.76344 .37433 .77113 .38464 .78858 .37879 .78096 .36841 Mtetra
.656 .751 .92 r
.78096 .36841 .78858 .37879 .80615 .37318 .79861 .36273 Mtetra
.652 .75 .921 r
.79861 .36273 .80615 .37318 .82385 .3677 .81639 .35719 Mtetra
.654 .751 .921 r
.81639 .35719 .82385 .3677 .84165 .36208 .83426 .35151 Mtetra
.66 .753 .919 r
.83426 .35151 .84165 .36208 .85953 .35619 .85222 .34555 Mtetra
.651 .75 .922 r
.21477 .53864 .22458 .5472 .23896 .54275 .2292 .53414 Mtetra
.657 .751 .92 r
.2292 .53414 .23896 .54275 .25345 .53804 .24373 .5294 Mtetra
.66 .753 .919 r
.24373 .5294 .25345 .53804 .26802 .53321 .25836 .52451 Mtetra
.656 .752 .92 r
.25836 .52451 .26802 .53321 .28266 .52851 .27305 .51974 Mtetra
.648 .749 .923 r
.27305 .51974 .28266 .52851 .29737 .52405 .2878 .51523 Mtetra
.658 .752 .919 r
.2878 .51523 .29737 .52405 .31218 .51919 .30266 .51035 Mtetra
.662 .753 .918 r
.30266 .51035 .31218 .51919 .32709 .51417 .31762 .50528 Mtetra
.656 .752 .92 r
.31762 .50528 .32709 .51417 .34206 .50939 .33264 .50041 Mtetra
.643 .747 .924 r
.33264 .50041 .34206 .50939 .35709 .50501 .34773 .49597 Mtetra
.659 .751 .918 r
.34773 .49597 .35709 .50501 .37225 .49998 .36294 .49093 Mtetra
.638 .746 .927 r
.36294 .49093 .37225 .49998 .38744 .49593 .37819 .48662 Mtetra
.541 .707 .947 r
.37819 .48662 .38744 .49593 .40261 .49529 .39343 .48517 Mtetra
.349 .597 .939 r
.39343 .48517 .40261 .49529 .41778 .49845 .40863 .48806 Mtetra
.429 .632 .94 r
.40863 .48806 .41778 .49845 .43317 .49933 .42404 .48953 Mtetra
.701 .754 .893 r
.42404 .48953 .43317 .49933 .44895 .4897 .43982 .48246 Mtetra
.843 .821 .827 r
.43982 .48246 .44895 .4897 .46494 .4713 .45587 .46621 Mtetra
.883 .859 .813 r
.45587 .46621 .46494 .4713 .4809 .45174 .47194 .44712 Mtetra
.83 .888 .884 r
.47194 .44712 .4809 .45174 .49675 .44082 .48791 .4338 Mtetra
.719 .826 .931 r
.48791 .4338 .49675 .44082 .5126 .43479 .50386 .42609 Mtetra
.656 .77 .933 r
.50386 .42609 .5126 .43479 .52855 .42961 .51986 .42086 Mtetra
.577 .742 .954 r
.51986 .42086 .52855 .42961 .54459 .42529 .53598 .4181 Mtetra
.247 .619 .957 r
.53598 .4181 .54459 .42529 .56079 .42588 .55226 .42101 Mtetra
0 .253 .648 r
.55226 .42101 .56079 .42588 .57728 .43523 .56879 .42979 Mtetra
0 .444 .821 r
.56879 .42979 .57728 .43523 .594 .44349 .58552 .43577 Mtetra
.579 .776 .973 r
.58552 .43577 .594 .44349 .61072 .44291 .60224 .43249 Mtetra
.775 .776 .853 r
.60224 .43249 .61072 .44291 .62726 .43167 .61884 .42053 Mtetra
.789 .767 .833 r
.61884 .42053 .62726 .43167 .64374 .41805 .63541 .40707 Mtetra
.728 .755 .874 r
.63541 .40707 .64374 .41805 .66041 .40829 .65218 .39801 Mtetra
.671 .752 .912 r
.65218 .39801 .66041 .40829 .67729 .40199 .66914 .39187 Mtetra
.653 .75 .921 r
.66914 .39187 .67729 .40199 .69432 .39669 .68624 .38647 Mtetra
.667 .755 .916 r
.68624 .38647 .69432 .39669 .71142 .39072 .70341 .38044 Mtetra
.655 .75 .92 r
.70341 .38044 .71142 .39072 .72864 .38515 .72071 .37486 Mtetra
.65 .749 .922 r
.72071 .37486 .72864 .38515 .74599 .37982 .73813 .36947 Mtetra
.654 .751 .921 r
.73813 .36947 .74599 .37982 .76344 .37433 .75565 .36388 Mtetra
.663 .754 .918 r
.75565 .36388 .76344 .37433 .78096 .36841 .77325 .3579 Mtetra
.655 .751 .92 r
.77325 .3579 .78096 .36841 .79861 .36273 .79098 .35218 Mtetra
.652 .75 .922 r
.79098 .35218 .79861 .36273 .81639 .35719 .80883 .34658 Mtetra
.655 .751 .921 r
.80883 .34658 .81639 .35719 .83426 .35151 .82679 .34081 Mtetra
.66 .753 .919 r
.82679 .34081 .83426 .35151 .85222 .34555 .84483 .33479 Mtetra
.651 .75 .922 r
.20486 .52998 .21477 .53864 .2292 .53414 .21934 .52542 Mtetra
.656 .751 .92 r
.21934 .52542 .2292 .53414 .24373 .5294 .23392 .52067 Mtetra
.66 .753 .919 r
.23392 .52067 .24373 .5294 .25836 .52451 .24859 .51572 Mtetra
.657 .752 .92 r
.24859 .51572 .25836 .52451 .27305 .51974 .26333 .51088 Mtetra
.649 .749 .923 r
.26333 .51088 .27305 .51974 .2878 .51523 .27813 .5063 Mtetra
.656 .751 .92 r
.27813 .5063 .2878 .51523 .30266 .51035 .29304 .50144 Mtetra
.662 .754 .918 r
.29304 .50144 .30266 .51035 .31762 .50528 .30805 .49631 Mtetra
.658 .753 .92 r
.30805 .49631 .31762 .50528 .33264 .50041 .32313 .49131 Mtetra
.644 .747 .924 r
.32313 .49131 .33264 .50041 .34773 .49597 .33827 .48679 Mtetra
.656 .75 .919 r
.33827 .48679 .34773 .49597 .36294 .49093 .35352 .48181 Mtetra
.648 .75 .924 r
.35352 .48181 .36294 .49093 .37819 .48662 .36885 .47711 Mtetra
.586 .721 .937 r
.36885 .47711 .37819 .48662 .39343 .48517 .38418 .47442 Mtetra
.411 .616 .935 r
.38418 .47442 .39343 .48517 .40863 .48806 .39945 .47635 Mtetra
.422 .6 .92 r
.39945 .47635 .40863 .48806 .42404 .48953 .41486 .47844 Mtetra
.59 .692 .913 r
.41486 .47844 .42404 .48953 .43982 .48246 .43057 .47579 Mtetra
.805 .84 .877 r
.43057 .47579 .43982 .48246 .45587 .46621 .44662 .46339 Mtetra
.869 .919 .859 r
.44662 .46339 .45587 .46621 .47194 .44712 .46277 .44728 Mtetra
.843 .983 .868 r
.46277 .44728 .47194 .44712 .48791 .4338 .47889 .43235 Mtetra
.743 .963 .937 r
.47889 .43235 .48791 .4338 .50386 .42609 .49496 .42224 Mtetra
.603 .883 .991 r
.49496 .42224 .50386 .42609 .51986 .42086 .51106 .41696 Mtetra
.307 .745 .967 r
.51106 .41696 .51986 .42086 .53598 .4181 .52726 .41652 Mtetra
.234 0 0 r
.52726 .41652 .53598 .4181 .55226 .42101 .54363 .42096 Mtetra
.382 0 0 r
.54363 .42096 .55226 .42101 .56879 .42979 .56021 .42663 Mtetra
.068 .602 .861 r
.56021 .42663 .56879 .42979 .58552 .43577 .57694 .42862 Mtetra
.714 .836 .94 r
.57694 .42862 .58552 .43577 .60224 .43249 .59365 .42074 Mtetra
.775 .754 .834 r
.59365 .42074 .60224 .43249 .61884 .42053 .6103 .40803 Mtetra
.769 .741 .828 r
.6103 .40803 .61884 .42053 .63541 .40707 .62698 .39544 Mtetra
.704 .737 .877 r
.62698 .39544 .63541 .40707 .65218 .39801 .64386 .38753 Mtetra
.663 .747 .913 r
.64386 .38753 .65218 .39801 .66914 .39187 .66091 .38167 Mtetra
.656 .752 .921 r
.66091 .38167 .66914 .39187 .68624 .38647 .67807 .37609 Mtetra
.666 .753 .916 r
.67807 .37609 .68624 .38647 .70341 .38044 .69532 .37004 Mtetra
.654 .75 .92 r
.69532 .37004 .70341 .38044 .72071 .37486 .7127 .36447 Mtetra
.65 .75 .923 r
.7127 .36447 .72071 .37486 .73813 .36947 .73019 .35902 Mtetra
.656 .752 .921 r
.73019 .35902 .73813 .36947 .75565 .36388 .74778 .35329 Mtetra
.662 .753 .918 r
.74778 .35329 .75565 .36388 .77325 .3579 .76546 .34727 Mtetra
.655 .751 .92 r
.76546 .34727 .77325 .3579 .79098 .35218 .78327 .34151 Mtetra
.652 .75 .922 r
.78327 .34151 .79098 .35218 .80883 .34658 .8012 .33585 Mtetra
.656 .752 .921 r
.8012 .33585 .80883 .34658 .82679 .34081 .81923 .32998 Mtetra
.66 .753 .919 r
.81923 .32998 .82679 .34081 .84483 .33479 .83735 .32389 Mtetra
.652 .75 .922 r
.19485 .52123 .20486 .52998 .21934 .52542 .20938 .5166 Mtetra
.654 .75 .92 r
.20938 .5166 .21934 .52542 .23392 .52067 .224 .51186 Mtetra
.661 .753 .919 r
.224 .51186 .23392 .52067 .24859 .51572 .23872 .50686 Mtetra
.658 .752 .92 r
.23872 .50686 .24859 .51572 .26333 .51088 .25351 .50194 Mtetra
.65 .75 .922 r
.25351 .50194 .26333 .51088 .27813 .5063 .26837 .49726 Mtetra
.653 .749 .92 r
.26837 .49726 .27813 .5063 .29304 .50144 .28332 .49245 Mtetra
.662 .754 .918 r
.28332 .49245 .29304 .50144 .30805 .49631 .29838 .48727 Mtetra
.66 .754 .92 r
.29838 .48727 .30805 .49631 .32313 .49131 .31352 .48217 Mtetra
.648 .749 .923 r
.31352 .48217 .32313 .49131 .33827 .48679 .32872 .47746 Mtetra
.65 .747 .92 r
.32872 .47746 .33827 .48679 .35352 .48181 .34401 .47265 Mtetra
.657 .754 .921 r
.34401 .47265 .35352 .48181 .36885 .47711 .35941 .46756 Mtetra
.618 .734 .929 r
.35941 .46756 .36885 .47711 .38418 .47442 .37483 .4638 Mtetra
.504 .666 .935 r
.37483 .4638 .38418 .47442 .39945 .47635 .39021 .4635 Mtetra
.44 .588 .903 r
.39021 .4635 .39945 .47635 .41486 .47844 .40565 .4655 Mtetra
.509 .622 .898 r
.40565 .4655 .41486 .47844 .43057 .47579 .4213 .46565 Mtetra
.666 .742 .907 r
.4213 .46565 .43057 .47579 .44662 .46339 .43725 .46001 Mtetra
.795 .923 .922 r
.43725 .46001 .44662 .46339 .46277 .44728 .45342 .44863 Mtetra
.733 .99 .876 r
.45342 .44863 .46277 .44728 .47889 .43235 .46962 .43671 Mtetra
.442 .856 .695 r
.46962 .43671 .47889 .43235 .49496 .42224 .48583 .4271 Mtetra
0 0 0 r
.48583 .4271 .49496 .42224 .51106 .41696 .50207 .42178 Mtetra
.204 0 0 r
.50207 .42178 .51106 .41696 .52726 .41652 .51839 .42076 Mtetra
.312 0 0 r
.51839 .42076 .52726 .41652 .54363 .42096 .53486 .42208 Mtetra
.135 0 0 r
.53486 .42208 .54363 .42096 .56021 .42663 .55149 .42291 Mtetra
.566 .879 .992 r
.55149 .42291 .56021 .42663 .57694 .42862 .56821 .41795 Mtetra
.757 .77 .863 r
.56821 .41795 .57694 .42862 .59365 .42074 .58493 .40711 Mtetra
.763 .723 .816 r
.58493 .40711 .59365 .42074 .6103 .40803 .60165 .39437 Mtetra
.733 .714 .833 r
.60165 .39437 .6103 .40803 .62698 .39544 .61846 .38393 Mtetra
.685 .735 .889 r
.61846 .38393 .62698 .39544 .64386 .38753 .63545 .37699 Mtetra
.655 .746 .917 r
.63545 .37699 .64386 .38753 .66091 .38167 .65258 .37141 Mtetra
.661 .755 .92 r
.65258 .37141 .66091 .38167 .67807 .37609 .66981 .36554 Mtetra
.663 .751 .916 r
.66981 .36554 .67807 .37609 .69532 .37004 .68713 .35955 Mtetra
.652 .75 .921 r
.68713 .35955 .69532 .37004 .7127 .36447 .70459 .35398 Mtetra
.65 .75 .923 r
.70459 .35398 .7127 .36447 .73019 .35902 .72216 .34846 Mtetra
.658 .753 .92 r
.72216 .34846 .73019 .35902 .74778 .35329 .73982 .34256 Mtetra
.661 .752 .918 r
.73982 .34256 .74778 .35329 .76546 .34727 .75757 .33652 Mtetra
.654 .751 .921 r
.75757 .33652 .76546 .34727 .78327 .34151 .77546 .33072 Mtetra
.651 .75 .922 r
.77546 .33072 .78327 .34151 .8012 .33585 .79347 .325 Mtetra
.657 .753 .92 r
.79347 .325 .8012 .33585 .81923 .32998 .81158 .31901 Mtetra
.659 .752 .919 r
.81158 .31901 .81923 .32998 .83735 .32389 .82979 .31288 Mtetra
.653 .751 .921 r
.18473 .5124 .19485 .52123 .20938 .5166 .19931 .50769 Mtetra
.652 .75 .921 r
.19931 .50769 .20938 .5166 .224 .51186 .21397 .50296 Mtetra
.66 .753 .919 r
.21397 .50296 .224 .51186 .23872 .50686 .22874 .49792 Mtetra
.659 .753 .92 r
.22874 .49792 .23872 .50686 .25351 .50194 .24359 .49291 Mtetra
.652 .751 .922 r
.24359 .49291 .25351 .50194 .26837 .49726 .2585 .4881 Mtetra
.65 .748 .921 r
.2585 .4881 .26837 .49726 .28332 .49245 .27349 .48335 Mtetra
.661 .754 .919 r
.27349 .48335 .28332 .49245 .29838 .48727 .2886 .47817 Mtetra
.661 .755 .919 r
.2886 .47817 .29838 .48727 .31352 .48217 .3038 .47295 Mtetra
.653 .751 .922 r
.3038 .47295 .31352 .48217 .32872 .47746 .31906 .468 Mtetra
.644 .744 .922 r
.31906 .468 .32872 .47746 .34401 .47265 .3344 .46335 Mtetra
.66 .754 .919 r
.3344 .46335 .34401 .47265 .35941 .46756 .34985 .45808 Mtetra
.643 .746 .924 r
.34985 .45808 .35941 .46756 .37483 .4638 .36537 .45341 Mtetra
.594 .71 .924 r
.36537 .45341 .37483 .4638 .39021 .4635 .3809 .45046 Mtetra
.491 .612 .899 r
.3809 .45046 .39021 .4635 .40565 .4655 .39641 .45109 Mtetra
.493 .589 .879 r
.39641 .45109 .40565 .4655 .4213 .46565 .41205 .45199 Mtetra
.551 .631 .884 r
.41205 .45199 .4213 .46565 .43725 .46001 .42791 .45084 Mtetra
.635 .758 .937 r
.42791 .45084 .43725 .46001 .45342 .44863 .44399 .44625 Mtetra
.683 .936 .966 r
.44399 .44625 .45342 .44863 .46962 .43671 .46023 .43822 Mtetra
.484 .9 .846 r
.46023 .43822 .46962 .43671 .48583 .4271 .47654 .43083 Mtetra
0 0 0 r
.47654 .43083 .48583 .4271 .50207 .42178 .4929 .42546 Mtetra
.4929 .42546 .50207 .42178 .51839 .42076 .50935 .42214 Mtetra
.119 .667 .705 r
.50935 .42214 .51839 .42076 .53486 .42208 .52593 .41946 Mtetra
.589 .91 .978 r
.52593 .41946 .53486 .42208 .55149 .42291 .54261 .41333 Mtetra
.743 .789 .89 r
.54261 .41333 .55149 .42291 .56821 .41795 .55935 .40371 Mtetra
.746 .71 .818 r
.55935 .40371 .56821 .41795 .58493 .40711 .57612 .39199 Mtetra
.738 .696 .811 r
.57612 .39199 .58493 .40711 .60165 .39437 .59292 .3805 Mtetra
.693 .698 .85 r
.59292 .3805 .60165 .39437 .61846 .38393 .60987 .37263 Mtetra
.666 .735 .901 r
.60987 .37263 .61846 .38393 .63545 .37699 .62695 .36651 Mtetra
.652 .748 .92 r
.62695 .36651 .63545 .37699 .65258 .37141 .64416 .36099 Mtetra
.666 .756 .918 r
.64416 .36099 .65258 .37141 .66981 .36554 .66145 .35483 Mtetra
.658 .749 .917 r
.66145 .35483 .66981 .36554 .68713 .35955 .67886 .34898 Mtetra
.651 .75 .922 r
.67886 .34898 .68713 .35955 .70459 .35398 .69639 .3434 Mtetra
.651 .751 .923 r
.69639 .3434 .70459 .35398 .72216 .34846 .71403 .33777 Mtetra
.661 .754 .919 r
.71403 .33777 .72216 .34846 .73982 .34256 .73176 .33169 Mtetra
.659 .751 .918 r
.73176 .33169 .73982 .34256 .75757 .33652 .7496 .32566 Mtetra
.653 .75 .921 r
.7496 .32566 .75757 .33652 .77546 .33072 .76757 .31984 Mtetra
.652 .751 .922 r
.76757 .31984 .77546 .33072 .79347 .325 .78566 .31403 Mtetra
.659 .753 .92 r
.78566 .31403 .79347 .325 .81158 .31901 .80384 .30789 Mtetra
.658 .752 .919 r
.80384 .30789 .81158 .31901 .82979 .31288 .82213 .30173 Mtetra
.654 .751 .921 r
.17451 .50348 .18473 .5124 .19931 .50769 .18914 .49866 Mtetra
.651 .749 .921 r
.18914 .49866 .19931 .50769 .21397 .50296 .20384 .49393 Mtetra
.659 .752 .919 r
.20384 .49393 .21397 .50296 .22874 .49792 .21866 .4889 Mtetra
.66 .754 .92 r
.21866 .4889 .22874 .49792 .24359 .49291 .23356 .4838 Mtetra
.655 .752 .921 r
.23356 .4838 .24359 .49291 .2585 .4881 .24853 .47883 Mtetra
.649 .747 .922 r
.24853 .47883 .2585 .4881 .27349 .48335 .26357 .47407 Mtetra
.657 .751 .919 r
.26357 .47407 .27349 .48335 .2886 .47817 .27872 .46898 Mtetra
.662 .755 .919 r
.27872 .46898 .2886 .47817 .3038 .47295 .29397 .46368 Mtetra
.658 .754 .92 r
.29397 .46368 .3038 .47295 .31906 .468 .3093 .45848 Mtetra
.647 .746 .922 r
.3093 .45848 .31906 .468 .3344 .46335 .32469 .45368 Mtetra
.651 .745 .919 r
.32469 .45368 .3344 .46335 .34985 .45808 .34019 .44869 Mtetra
.658 .755 .921 r
.34019 .44869 .34985 .45808 .36537 .45341 .35579 .44342 Mtetra
.634 .735 .921 r
.35579 .44342 .36537 .45341 .3809 .45046 .37143 .43901 Mtetra
.591 .69 .911 r
.37143 .43901 .3809 .45046 .39641 .45109 .38711 .43621 Mtetra
.523 .598 .87 r
.38711 .43621 .39641 .45109 .41205 .45199 .40281 .43617 Mtetra
.537 .591 .856 r
.40281 .43617 .41205 .45199 .42791 .45084 .41865 .43576 Mtetra
.57 .619 .862 r
.41865 .43576 .42791 .45084 .44399 .44625 .43468 .43398 Mtetra
.61 .687 .897 r
.43468 .43398 .44399 .44625 .46023 .43822 .45088 .43043 Mtetra
.63 .794 .961 r
.45088 .43043 .46023 .43822 .47654 .43083 .46722 .42563 Mtetra
.624 .861 .987 r
.46722 .42563 .47654 .43083 .4929 .42546 .48367 .42022 Mtetra
.646 .867 .982 r
.48367 .42022 .4929 .42546 .50935 .42214 .50023 .41417 Mtetra
.699 .814 .937 r
.50023 .41417 .50935 .42214 .52593 .41946 .51688 .40688 Mtetra
.719 .726 .856 r
.51688 .40688 .52593 .41946 .54261 .41333 .53361 .39778 Mtetra
.723 .685 .813 r
.53361 .39778 .54261 .41333 .55935 .40371 .55039 .38728 Mtetra
.723 .675 .803 r
.55039 .38728 .55935 .40371 .57612 .39199 .56722 .37637 Mtetra
.689 .672 .829 r
.56722 .37637 .57612 .39199 .59292 .3805 .58415 .36824 Mtetra
.672 .72 .885 r
.58415 .36824 .59292 .3805 .60987 .37263 .6012 .36173 Mtetra
.654 .741 .914 r
.6012 .36173 .60987 .37263 .62695 .36651 .61837 .35611 Mtetra
.66 .756 .921 r
.61837 .35611 .62695 .36651 .64416 .36099 .63563 .35018 Mtetra
.664 .75 .914 r
.63563 .35018 .64416 .36099 .66145 .35483 .653 .34406 Mtetra
.654 .748 .919 r
.653 .34406 .66145 .35483 .67886 .34898 .67049 .33833 Mtetra
.65 .751 .923 r
.67049 .33833 .67886 .34898 .69639 .3434 .6881 .33271 Mtetra
.654 .753 .922 r
.6881 .33271 .69639 .3434 .71403 .33777 .70581 .32687 Mtetra
.662 .753 .917 r
.70581 .32687 .71403 .33777 .73176 .33169 .72361 .32067 Mtetra
.656 .75 .919 r
.72361 .32067 .73176 .33169 .7496 .32566 .74153 .31469 Mtetra
.652 .75 .922 r
.74153 .31469 .7496 .32566 .76757 .31984 .75959 .30884 Mtetra
.653 .752 .922 r
.75959 .30884 .76757 .31984 .78566 .31403 .77775 .3029 Mtetra
.66 .753 .919 r
.77775 .3029 .78566 .31403 .80384 .30789 .79601 .29664 Mtetra
.657 .751 .919 r
.79601 .29664 .80384 .30789 .82213 .30173 .81439 .29046 Mtetra
.656 .752 .92 r
.16418 .49447 .17451 .50348 .18914 .49866 .17886 .48955 Mtetra
.651 .749 .921 r
.17886 .48955 .18914 .49866 .20384 .49393 .19361 .48476 Mtetra
.656 .75 .92 r
.19361 .48476 .20384 .49393 .21866 .4889 .20847 .47979 Mtetra
.66 .754 .919 r
.20847 .47979 .21866 .4889 .23356 .4838 .22342 .47461 Mtetra
.657 .753 .92 r
.22342 .47461 .23356 .4838 .24853 .47883 .23845 .46951 Mtetra
.651 .749 .922 r
.23845 .46951 .24853 .47883 .26357 .47407 .25354 .46463 Mtetra
.652 .748 .92 r
.25354 .46463 .26357 .47407 .27872 .46898 .26873 .45968 Mtetra
.661 .755 .919 r
.26873 .45968 .27872 .46898 .29397 .46368 .28404 .45435 Mtetra
.661 .755 .92 r
.28404 .45435 .29397 .46368 .3093 .45848 .29942 .44901 Mtetra
.654 .752 .921 r
.29942 .44901 .3093 .45848 .32469 .45368 .31489 .44388 Mtetra
.646 .743 .92 r
.31489 .44388 .32469 .45368 .34019 .44869 .33042 .43905 Mtetra
.656 .751 .919 r
.33042 .43905 .34019 .44869 .35579 .44342 .34608 .43378 Mtetra
.655 .752 .921 r
.34608 .43378 .35579 .44342 .37143 .43901 .36182 .42852 Mtetra
.636 .728 .915 r
.36182 .42852 .37143 .43901 .38711 .43621 .37762 .42399 Mtetra
.609 .685 .896 r
.37762 .42399 .38711 .43621 .40281 .43617 .39348 .42049 Mtetra
.57 .611 .854 r
.39348 .42049 .40281 .43617 .41865 .43576 .40939 .4187 Mtetra
.573 .594 .836 r
.40939 .4187 .41865 .43576 .43468 .43398 .42544 .41681 Mtetra
.595 .605 .831 r
.42544 .41681 .43468 .43398 .45088 .43043 .44164 .41386 Mtetra
.621 .626 .834 r
.44164 .41386 .45088 .43043 .46722 .42563 .45799 .40964 Mtetra
.645 .645 .836 r
.45799 .40964 .46722 .42563 .48367 .42022 .47448 .40415 Mtetra
.666 .654 .829 r
.47448 .40415 .48367 .42022 .50023 .41417 .49108 .3974 Mtetra
.683 .653 .814 r
.49108 .3974 .50023 .41417 .51688 .40688 .50777 .38935 Mtetra
.695 .65 .802 r
.50777 .38935 .51688 .40688 .53361 .39778 .52454 .38023 Mtetra
.696 .651 .802 r
.52454 .38023 .53361 .39778 .55039 .38728 .54137 .37098 Mtetra
.677 .659 .825 r
.54137 .37098 .55039 .38728 .56722 .37637 .55829 .36344 Mtetra
.67 .708 .876 r
.55829 .36344 .56722 .37637 .58415 .36824 .57531 .35694 Mtetra
.656 .735 .908 r
.57531 .35694 .58415 .36824 .6012 .36173 .59244 .35118 Mtetra
.655 .752 .921 r
.59244 .35118 .6012 .36173 .61837 .35611 .60968 .34543 Mtetra
.665 .754 .917 r
.60968 .34543 .61837 .35611 .63563 .35018 .62701 .33922 Mtetra
.657 .746 .916 r
.62701 .33922 .63563 .35018 .653 .34406 .64446 .33331 Mtetra
.651 .75 .922 r
.64446 .33331 .653 .34406 .67049 .33833 .66202 .32761 Mtetra
.651 .752 .924 r
.66202 .32761 .67049 .33833 .6881 .33271 .67971 .32189 Mtetra
.659 .755 .921 r
.67971 .32189 .6881 .33271 .70581 .32687 .69748 .31578 Mtetra
.66 .751 .917 r
.69748 .31578 .70581 .32687 .72361 .32067 .71536 .30959 Mtetra
.654 .75 .92 r
.71536 .30959 .72361 .32067 .74153 .31469 .73337 .30362 Mtetra
.652 .751 .922 r
.73337 .30362 .74153 .31469 .75959 .30884 .75151 .29771 Mtetra
.656 .753 .921 r
.75151 .29771 .75959 .30884 .77775 .3029 .76975 .29159 Mtetra
.66 .752 .918 r
.76975 .29159 .77775 .3029 .79601 .29664 .78809 .28527 Mtetra
.656 .75 .92 r
.78809 .28527 .79601 .29664 .81439 .29046 .80656 .27907 Mtetra
.657 .752 .92 r
.15374 .48539 .16418 .49447 .17886 .48955 .16847 .48037 Mtetra
.653 .75 .921 r
.16847 .48037 .17886 .48955 .19361 .48476 .18328 .47548 Mtetra
.652 .749 .921 r
.18328 .47548 .19361 .48476 .20847 .47979 .19817 .47057 Mtetra
.66 .754 .919 r
.19817 .47057 .20847 .47979 .22342 .47461 .21317 .46536 Mtetra
.659 .754 .92 r
.21317 .46536 .22342 .47461 .23845 .46951 .22825 .46015 Mtetra
.655 .751 .921 r
.22825 .46015 .23845 .46951 .25354 .46463 .24341 .45507 Mtetra
.649 .747 .921 r
.24341 .45507 .25354 .46463 .26873 .45968 .25864 .45016 Mtetra
.657 .751 .919 r
.25864 .45016 .26873 .45968 .28404 .45435 .27399 .44494 Mtetra
.661 .756 .92 r
.27399 .44494 .28404 .45435 .29942 .44901 .28944 .43952 Mtetra
.659 .755 .921 r
.28944 .43952 .29942 .44901 .31489 .44388 .30497 .43415 Mtetra
.652 .748 .921 r
.30497 .43415 .31489 .44388 .33042 .43905 .32057 .42903 Mtetra
.647 .742 .919 r
.32057 .42903 .33042 .43905 .34608 .43378 .33626 .42408 Mtetra
.657 .753 .921 r
.33626 .42408 .34608 .43378 .36182 .42852 .35206 .41867 Mtetra
.656 .751 .92 r
.35206 .41867 .36182 .42852 .37762 .42399 .36796 .41328 Mtetra
.645 .73 .911 r
.36796 .41328 .37762 .42399 .39348 .42049 .38393 .40831 Mtetra
.632 .698 .893 r
.38393 .40831 .39348 .42049 .40939 .4187 .39998 .40384 Mtetra
.622 .65 .856 r
.39998 .40384 .40939 .4187 .42544 .41681 .41613 .39966 Mtetra
.614 .615 .829 r
.41613 .39966 .42544 .41681 .44164 .41386 .43238 .3957 Mtetra
.622 .608 .815 r
.43238 .3957 .44164 .41386 .45799 .40964 .44875 .39117 Mtetra
.639 .613 .808 r
.44875 .39117 .45799 .40964 .47448 .40415 .46526 .38561 Mtetra
.654 .621 .804 r
.46526 .38561 .47448 .40415 .49108 .3974 .48188 .37902 Mtetra
.663 .628 .804 r
.48188 .37902 .49108 .3974 .50777 .38935 .4986 .37185 Mtetra
.663 .638 .815 r
.4986 .37185 .50777 .38935 .52454 .38023 .5154 .36489 Mtetra
.666 .668 .843 r
.5154 .36489 .52454 .38023 .54137 .37098 .53229 .35822 Mtetra
.663 .71 .882 r
.53229 .35822 .54137 .37098 .55829 .36344 .54928 .35204 Mtetra
.655 .734 .907 r
.54928 .35204 .55829 .36344 .57531 .35694 .56637 .34629 Mtetra
.654 .75 .921 r
.56637 .34629 .57531 .35694 .59244 .35118 .58358 .34055 Mtetra
.664 .756 .918 r
.58358 .34055 .59244 .35118 .60968 .34543 .60088 .33435 Mtetra
.66 .746 .914 r
.60088 .33435 .60968 .34543 .62701 .33922 .61829 .32831 Mtetra
.653 .748 .92 r
.61829 .32831 .62701 .33922 .64446 .33331 .63582 .32251 Mtetra
.65 .752 .924 r
.63582 .32251 .64446 .33331 .66202 .32761 .65346 .31678 Mtetra
.655 .754 .923 r
.65346 .31678 .66202 .32761 .67971 .32189 .67121 .31082 Mtetra
.662 .753 .918 r
.67121 .31082 .67971 .32189 .69748 .31578 .68906 .30454 Mtetra
.657 .749 .918 r
.68906 .30454 .69748 .31578 .71536 .30959 .70703 .29843 Mtetra
.653 .75 .921 r
.70703 .29843 .71536 .30959 .73337 .30362 .72512 .29244 Mtetra
.652 .752 .923 r
.72512 .29244 .73337 .30362 .75151 .29771 .74333 .28645 Mtetra
.659 .754 .92 r
.74333 .28645 .75151 .29771 .76975 .29159 .76164 .28013 Mtetra
.658 .751 .918 r
.76164 .28013 .76975 .29159 .78809 .28527 .78007 .27379 Mtetra
.655 .751 .92 r
.78007 .27379 .78809 .28527 .80656 .27907 .79863 .26756 Mtetra
.658 .753 .92 r
.14318 .47624 .15374 .48539 .16847 .48037 .15797 .47112 Mtetra
.655 .751 .921 r
.15797 .47112 .16847 .48037 .18328 .47548 .17283 .46608 Mtetra
.651 .749 .921 r
.17283 .46608 .18328 .47548 .19817 .47057 .18777 .46116 Mtetra
.656 .751 .919 r
.18777 .46116 .19817 .47057 .21317 .46536 .20281 .45602 Mtetra
.66 .754 .92 r
.20281 .45602 .21317 .46536 .22825 .46015 .21795 .45072 Mtetra
.657 .753 .92 r
.21795 .45072 .22825 .46015 .24341 .45507 .23317 .44548 Mtetra
.652 .749 .921 r
.23317 .44548 .24341 .45507 .25864 .45016 .24846 .44042 Mtetra
.65 .747 .92 r
.24846 .44042 .25864 .45016 .27399 .44494 .26384 .43539 Mtetra
.66 .754 .92 r
.26384 .43539 .27399 .44494 .28944 .43952 .27933 .42997 Mtetra
.661 .756 .921 r
.27933 .42997 .28944 .43952 .30497 .43415 .29493 .42448 Mtetra
.658 .754 .921 r
.29493 .42448 .30497 .43415 .32057 .42903 .3106 .41905 Mtetra
.652 .747 .919 r
.3106 .41905 .32057 .42903 .33626 .42408 .32635 .41385 Mtetra
.648 .741 .918 r
.32635 .41385 .33626 .42408 .35206 .41867 .34219 .40876 Mtetra
.655 .752 .921 r
.34219 .40876 .35206 .41867 .36796 .41328 .35814 .40337 Mtetra
.659 .754 .92 r
.35814 .40337 .36796 .41328 .38393 .40831 .3742 .39779 Mtetra
.654 .741 .914 r
.3742 .39779 .38393 .40831 .39998 .40384 .39034 .39237 Mtetra
.649 .721 .901 r
.39034 .39237 .39998 .40384 .41613 .39966 .40658 .3871 Mtetra
.647 .701 .886 r
.40658 .3871 .41613 .39966 .43238 .3957 .42291 .38186 Mtetra
.647 .68 .868 r
.42291 .38186 .43238 .3957 .44875 .39117 .43935 .37648 Mtetra
.649 .669 .855 r
.43935 .37648 .44875 .39117 .46526 .38561 .4559 .37085 Mtetra
.653 .671 .854 r
.4559 .37085 .46526 .38561 .48188 .37902 .47255 .36497 Mtetra
.657 .684 .864 r
.47255 .36497 .48188 .37902 .4986 .37185 .48931 .35896 Mtetra
.659 .706 .882 r
.48931 .35896 .4986 .37185 .5154 .36489 .50616 .35297 Mtetra
.657 .724 .899 r
.50616 .35297 .5154 .36489 .53229 .35822 .52311 .34712 Mtetra
.653 .74 .914 r
.52311 .34712 .53229 .35822 .54928 .35204 .54017 .34144 Mtetra
.657 .754 .921 r
.54017 .34144 .54928 .35204 .56637 .34629 .55734 .33556 Mtetra
.663 .755 .918 r
.55734 .33556 .56637 .34629 .58358 .34055 .57461 .32937 Mtetra
.66 .745 .913 r
.57461 .32937 .58358 .34055 .60088 .33435 .59199 .3233 Mtetra
.653 .747 .918 r
.59199 .3233 .60088 .33435 .61829 .32831 .60948 .31744 Mtetra
.651 .752 .923 r
.60948 .31744 .61829 .32831 .63582 .32251 .62708 .31165 Mtetra
.652 .753 .924 r
.62708 .31165 .63582 .32251 .65346 .31678 .6448 .30578 Mtetra
.661 .755 .92 r
.6448 .30578 .65346 .31678 .67121 .31082 .66261 .2995 Mtetra
.659 .75 .917 r
.66261 .2995 .67121 .31082 .68906 .30454 .68054 .29325 Mtetra
.654 .75 .92 r
.68054 .29325 .68906 .30454 .70703 .29843 .6986 .28717 Mtetra
.652 .751 .922 r
.6986 .28717 .70703 .29843 .72512 .29244 .71677 .28115 Mtetra
.655 .753 .922 r
.71677 .28115 .72512 .29244 .74333 .28645 .73506 .27495 Mtetra
.66 .752 .918 r
.73506 .27495 .74333 .28645 .76164 .28013 .75345 .26852 Mtetra
.656 .75 .919 r
.75345 .26852 .76164 .28013 .78007 .27379 .77196 .26219 Mtetra
.654 .75 .921 r
.77196 .26219 .78007 .27379 .79863 .26756 .79061 .25594 Mtetra
.659 .754 .92 r
.13251 .46699 .14318 .47624 .15797 .47112 .14735 .46178 Mtetra
.656 .752 .92 r
.14735 .46178 .15797 .47112 .17283 .46608 .16227 .45664 Mtetra
.653 .75 .921 r
.16227 .45664 .17283 .46608 .18777 .46116 .17726 .45161 Mtetra
.652 .749 .92 r
.17726 .45161 .18777 .46116 .20281 .45602 .19233 .44656 Mtetra
.659 .754 .92 r
.19233 .44656 .20281 .45602 .21795 .45072 .20752 .44123 Mtetra
.20752 .44123 .21795 .45072 .23317 .44548 .2228 .43587 Mtetra
.656 .752 .92 r
.2228 .43587 .23317 .44548 .24846 .44042 .23816 .43058 Mtetra
.65 .747 .92 r
.23816 .43058 .24846 .44042 .26384 .43539 .25359 .42549 Mtetra
.652 .747 .919 r
.25359 .42549 .26384 .43539 .27933 .42997 .26912 .42029 Mtetra
.66 .755 .921 r
.26912 .42029 .27933 .42997 .29493 .42448 .28477 .41478 Mtetra
.66 .756 .921 r
.28477 .41478 .29493 .42448 .3106 .41905 .3005 .40922 Mtetra
.658 .754 .921 r
.3005 .40922 .3106 .41905 .32635 .41385 .31633 .4037 Mtetra
.654 .747 .919 r
.31633 .4037 .32635 .41385 .34219 .40876 .33224 .39833 Mtetra
.649 .741 .917 r
.33224 .39833 .34219 .40876 .35814 .40337 .34824 .39309 Mtetra
.65 .746 .92 r
.34824 .39309 .35814 .40337 .3742 .39779 .36434 .38779 Mtetra
.657 .755 .922 r
.36434 .38779 .3742 .39779 .39034 .39237 .38054 .38219 Mtetra
.658 .753 .92 r
.38054 .38219 .39034 .39237 .40658 .3871 .39685 .37651 Mtetra
.657 .745 .915 r
.39685 .37651 .40658 .3871 .42291 .38186 .41326 .37085 Mtetra
.656 .738 .91 r
.41326 .37085 .42291 .38186 .43935 .37648 .42977 .3652 Mtetra
.655 .733 .907 r
.42977 .3652 .43935 .37648 .4559 .37085 .44637 .3595 Mtetra
.44637 .3595 .4559 .37085 .47255 .36497 .46308 .35378 Mtetra
.655 .738 .91 r
.46308 .35378 .47255 .36497 .48931 .35896 .4799 .34805 Mtetra
.654 .744 .916 r
.4799 .34805 .48931 .35896 .50616 .35297 .49681 .34234 Mtetra
.655 .752 .921 r
.49681 .34234 .50616 .35297 .52311 .34712 .51384 .33655 Mtetra
.661 .757 .921 r
.51384 .33655 .52311 .34712 .54017 .34144 .53097 .33046 Mtetra
.662 .75 .915 r
.53097 .33046 .54017 .34144 .55734 .33556 .5482 .32429 Mtetra
.658 .744 .914 r
.5482 .32429 .55734 .33556 .57461 .32937 .56554 .31827 Mtetra
.654 .747 .918 r
.56554 .31827 .57461 .32937 .59199 .3233 .58299 .31238 Mtetra
.651 .752 .923 r
.58299 .31238 .59199 .3233 .60948 .31744 .60056 .30653 Mtetra
.652 .754 .924 r
.60056 .30653 .60948 .31744 .62708 .31165 .61824 .30063 Mtetra
.659 .756 .921 r
.61824 .30063 .62708 .31165 .6448 .30578 .63602 .2944 Mtetra
.661 .75 .916 r
.63602 .2944 .6448 .30578 .66261 .2995 .65391 .28806 Mtetra
.655 .748 .918 r
.65391 .28806 .66261 .2995 .68054 .29325 .67193 .28191 Mtetra
.653 .751 .922 r
.67193 .28191 .68054 .29325 .6986 .28717 .69007 .27582 Mtetra
.653 .752 .923 r
.69007 .27582 .6986 .28717 .71677 .28115 .70832 .2697 Mtetra
.659 .754 .92 r
.70832 .2697 .71677 .28115 .73506 .27495 .72668 .26327 Mtetra
.658 .751 .918 r
.72668 .26327 .73506 .27495 .75345 .26852 .74515 .25682 Mtetra
.655 .751 .92 r
.74515 .25682 .75345 .26852 .77196 .26219 .76376 .25047 Mtetra
.653 .751 .922 r
.76376 .25047 .77196 .26219 .79061 .25594 .7825 .24419 Mtetra
.659 .753 .92 r
.12173 .45763 .13251 .46699 .14735 .46178 .13662 .45239 Mtetra
.658 .754 .92 r
.13662 .45239 .14735 .46178 .16227 .45664 .15159 .44713 Mtetra
.655 .751 .92 r
.15159 .44713 .16227 .45664 .17726 .45161 .16664 .44194 Mtetra
.652 .748 .921 r
.16664 .44194 .17726 .45161 .19233 .44656 .18176 .43686 Mtetra
.655 .75 .92 r
.18176 .43686 .19233 .44656 .20752 .44123 .19699 .43165 Mtetra
.66 .755 .92 r
.19699 .43165 .20752 .44123 .2228 .43587 .21232 .42621 Mtetra
.658 .754 .921 r
.21232 .42621 .2228 .43587 .23816 .43058 .22774 .42079 Mtetra
.656 .751 .92 r
.22774 .42079 .23816 .43058 .25359 .42549 .24324 .41544 Mtetra
.65 .746 .919 r
.24324 .41544 .25359 .42549 .26912 .42029 .25882 .41026 Mtetra
.653 .748 .92 r
.25882 .41026 .26912 .42029 .28477 .41478 .2745 .40496 Mtetra
.659 .756 .921 r
.2745 .40496 .28477 .41478 .3005 .40922 .29029 .39937 Mtetra
.66 .757 .922 r
.29029 .39937 .3005 .40922 .31633 .4037 .30618 .39373 Mtetra
.658 .755 .921 r
.30618 .39373 .31633 .4037 .33224 .39833 .32216 .38811 Mtetra
.656 .75 .919 r
.32216 .38811 .33224 .39833 .34824 .39309 .33823 .38254 Mtetra
.653 .743 .916 r
.33823 .38254 .34824 .39309 .36434 .38779 .35439 .37707 Mtetra
.651 .741 .915 r
.35439 .37707 .36434 .38779 .38054 .38219 .37065 .37163 Mtetra
.652 .746 .918 r
.37065 .37163 .38054 .38219 .39685 .37651 .38701 .36611 Mtetra
.654 .751 .921 r
.38701 .36611 .39685 .37651 .41326 .37085 .40347 .36051 Mtetra
.655 .754 .923 r
.40347 .36051 .41326 .37085 .42977 .3652 .42004 .35483 Mtetra
.656 .755 .923 r
.42004 .35483 .42977 .3652 .44637 .3595 .43672 .34907 Mtetra
.657 .755 .923 r
.43672 .34907 .44637 .3595 .46308 .35378 .45349 .34324 Mtetra
.658 .755 .921 r
.45349 .34324 .46308 .35378 .4799 .34805 .47037 .33732 Mtetra
.659 .753 .919 r
.47037 .33732 .4799 .34805 .49681 .34234 .48736 .33132 Mtetra
.66 .748 .915 r
.48736 .33132 .49681 .34234 .51384 .33655 .50445 .32524 Mtetra
.659 .743 .913 r
.50445 .32524 .51384 .33655 .53097 .33046 .52165 .31918 Mtetra
.655 .744 .915 r
.52165 .31918 .53097 .33046 .5482 .32429 .53896 .31323 Mtetra
.653 .749 .92 r
.53896 .31323 .5482 .32429 .56554 .31827 .55637 .30732 Mtetra
.652 .753 .924 r
.55637 .30732 .56554 .31827 .58299 .31238 .5739 .30143 Mtetra
.652 .754 .924 r
.5739 .30143 .58299 .31238 .60056 .30653 .59154 .29548 Mtetra
.659 .756 .922 r
.59154 .29548 .60056 .30653 .61824 .30063 .60929 .28923 Mtetra
.661 .751 .917 r
.60929 .28923 .61824 .30063 .63602 .2944 .62714 .28285 Mtetra
.656 .747 .917 r
.62714 .28285 .63602 .2944 .65391 .28806 .64512 .27663 Mtetra
.653 .751 .921 r
.64512 .27663 .65391 .28806 .67193 .28191 .66322 .27049 Mtetra
.652 .752 .923 r
.66322 .27049 .67193 .28191 .69007 .27582 .68143 .26435 Mtetra
.657 .754 .922 r
.68143 .26435 .69007 .27582 .70832 .2697 .69976 .25797 Mtetra
.659 .751 .918 r
.69976 .25797 .70832 .2697 .72668 .26327 .7182 .25145 Mtetra
.656 .75 .919 r
.7182 .25145 .72668 .26327 .74515 .25682 .73676 .24502 Mtetra
.654 .751 .921 r
.73676 .24502 .74515 .25682 .76376 .25047 .75546 .23866 Mtetra
.653 .752 .922 r
.75546 .23866 .76376 .25047 .7825 .24419 .77428 .23227 Mtetra
.655 .75 .92 r
.11084 .44808 .12173 .45763 .13662 .45239 .12576 .4429 Mtetra
.659 .754 .92 r
.12576 .4429 .13662 .45239 .15159 .44713 .14079 .43755 Mtetra
.657 .753 .92 r
.14079 .43755 .15159 .44713 .16664 .44194 .15589 .43225 Mtetra
.654 .751 .921 r
.15589 .43225 .16664 .44194 .18176 .43686 .17108 .42702 Mtetra
.652 .748 .92 r
.17108 .42702 .18176 .43686 .19699 .43165 .18634 .42185 Mtetra
.656 .751 .92 r
.18634 .42185 .19699 .43165 .21232 .42621 .20172 .41648 Mtetra
.66 .755 .921 r
.20172 .41648 .21232 .42621 .22774 .42079 .21719 .41096 Mtetra
.658 .754 .921 r
.21719 .41096 .22774 .42079 .24324 .41544 .23276 .40546 Mtetra
.656 .751 .92 r
.23276 .40546 .24324 .41544 .25882 .41026 .24841 .40003 Mtetra
.651 .746 .919 r
.24841 .40003 .25882 .41026 .2745 .40496 .26413 .39474 Mtetra
.652 .747 .92 r
.26413 .39474 .2745 .40496 .29029 .39937 .27996 .38937 Mtetra
.658 .755 .922 r
.27996 .38937 .29029 .39937 .30618 .39373 .2959 .38374 Mtetra
.659 .757 .922 r
.2959 .38374 .30618 .39373 .32216 .38811 .31195 .37802 Mtetra
.659 .756 .922 r
.31195 .37802 .32216 .38811 .33823 .38254 .32808 .37229 Mtetra
.658 .754 .921 r
.32808 .37229 .33823 .38254 .35439 .37707 .34432 .36658 Mtetra
.656 .75 .919 r
.34432 .36658 .35439 .37707 .37065 .37163 .36064 .36087 Mtetra
.656 .745 .916 r
.36064 .36087 .37065 .37163 .38701 .36611 .37707 .35516 Mtetra
.655 .742 .914 r
.37707 .35516 .38701 .36611 .40347 .36051 .3936 .34945 Mtetra
.655 .741 .913 r
.3936 .34945 .40347 .36051 .42004 .35483 .41023 .3437 Mtetra
.656 .742 .913 r
.41023 .3437 .42004 .35483 .43672 .34907 .42697 .33787 Mtetra
.657 .742 .913 r
.42697 .33787 .43672 .34907 .45349 .34324 .44381 .33198 Mtetra
.44381 .33198 .45349 .34324 .47037 .33732 .46075 .32604 Mtetra
.656 .743 .914 r
.46075 .32604 .47037 .33732 .48736 .33132 .4778 .3201 Mtetra
.655 .745 .916 r
.4778 .3201 .48736 .33132 .50445 .32524 .49496 .31415 Mtetra
.654 .749 .919 r
.49496 .31415 .50445 .32524 .52165 .31918 .51223 .30821 Mtetra
.653 .752 .923 r
.51223 .30821 .52165 .31918 .53896 .31323 .5296 .30228 Mtetra
.652 .754 .924 r
.5296 .30228 .53896 .31323 .55637 .30732 .54709 .29633 Mtetra
.653 .755 .924 r
.54709 .29633 .55637 .30732 .5739 .30143 .56469 .29031 Mtetra
.659 .756 .921 r
.56469 .29031 .5739 .30143 .59154 .29548 .5824 .28399 Mtetra
.66 .75 .917 r
.5824 .28399 .59154 .29548 .60929 .28923 .60022 .2776 Mtetra
.656 .747 .917 r
.60022 .2776 .60929 .28923 .62714 .28285 .61816 .27134 Mtetra
.654 .75 .921 r
.61816 .27134 .62714 .28285 .64512 .27663 .63622 .26514 Mtetra
.652 .752 .923 r
.63622 .26514 .64512 .27663 .66322 .27049 .6544 .25897 Mtetra
.655 .754 .922 r
.6544 .25897 .66322 .27049 .68143 .26435 .67269 .25262 Mtetra
.659 .753 .919 r
.67269 .25262 .68143 .26435 .69976 .25797 .6911 .24606 Mtetra
.657 .75 .918 r
.6911 .24606 .69976 .25797 .7182 .25145 .70962 .23955 Mtetra
.655 .751 .92 r
.70962 .23955 .7182 .25145 .73676 .24502 .72828 .23311 Mtetra
.653 .751 .922 r
.72828 .23311 .73676 .24502 .75546 .23866 .74706 .22671 Mtetra
.656 .753 .921 r
.74706 .22671 .75546 .23866 .77428 .23227 .76596 .22012 Mtetra
.653 .749 .92 r
.09983 .4384 .11084 .44808 .12576 .4429 .11479 .43325 Mtetra
.657 .752 .92 r
.11479 .43325 .12576 .4429 .14079 .43755 .12986 .42791 Mtetra
.659 .754 .92 r
.12986 .42791 .14079 .43755 .15589 .43225 .14503 .42248 Mtetra
.656 .752 .92 r
.14503 .42248 .15589 .43225 .17108 .42702 .16027 .41712 Mtetra
.653 .75 .92 r
.16027 .41712 .17108 .42702 .18634 .42185 .17559 .41183 Mtetra
.652 .748 .92 r
.17559 .41183 .18634 .42185 .20172 .41648 .191 .40656 Mtetra
.657 .752 .92 r
.191 .40656 .20172 .41648 .21719 .41096 .20653 .40107 Mtetra
.659 .755 .921 r
.20653 .40107 .21719 .41096 .23276 .40546 .22215 .39547 Mtetra
.658 .754 .921 r
.22215 .39547 .23276 .40546 .24841 .40003 .23786 .38988 Mtetra
.656 .751 .92 r
.23786 .38988 .24841 .40003 .26413 .39474 .25366 .38434 Mtetra
.652 .746 .919 r
.25366 .38434 .26413 .39474 .27996 .38937 .26955 .3789 Mtetra
.26955 .3789 .27996 .38937 .2959 .38374 .28553 .37345 Mtetra
.655 .752 .921 r
.28553 .37345 .2959 .38374 .31195 .37802 .30162 .36784 Mtetra
.658 .756 .923 r
.30162 .36784 .31195 .37802 .32808 .37229 .31781 .36207 Mtetra
.658 .757 .923 r
.31781 .36207 .32808 .37229 .34432 .36658 .33411 .35626 Mtetra
.658 .756 .923 r
.33411 .35626 .34432 .36658 .36064 .36087 .3505 .35044 Mtetra
.657 .755 .922 r
.3505 .35044 .36064 .36087 .37707 .35516 .367 .3446 Mtetra
.657 .754 .921 r
.367 .3446 .37707 .35516 .3936 .34945 .38359 .33875 Mtetra
.656 .752 .92 r
.38359 .33875 .3936 .34945 .41023 .3437 .40029 .33288 Mtetra
.656 .751 .92 r
.40029 .33288 .41023 .3437 .42697 .33787 .41709 .32699 Mtetra
.655 .751 .92 r
.41709 .32699 .42697 .33787 .44381 .33198 .434 .32108 Mtetra
.655 .751 .921 r
.434 .32108 .44381 .33198 .46075 .32604 .45101 .31514 Mtetra
.654 .753 .922 r
.45101 .31514 .46075 .32604 .4778 .3201 .46813 .30919 Mtetra
.654 .754 .923 r
.46813 .30919 .4778 .3201 .49496 .31415 .48535 .30324 Mtetra
.653 .755 .924 r
.48535 .30324 .49496 .31415 .51223 .30821 .50269 .29726 Mtetra
.654 .756 .925 r
.50269 .29726 .51223 .30821 .5296 .30228 .52014 .29123 Mtetra
.657 .756 .923 r
.52014 .29123 .5296 .30228 .54709 .29633 .5377 .28504 Mtetra
.66 .754 .92 r
.5377 .28504 .54709 .29633 .56469 .29031 .55538 .27869 Mtetra
.659 .748 .916 r
.55538 .27869 .56469 .29031 .5824 .28399 .57316 .2723 Mtetra
.656 .747 .917 r
.57316 .2723 .5824 .28399 .60022 .2776 .59106 .26603 Mtetra
.654 .751 .921 r
.59106 .26603 .60022 .2776 .61816 .27134 .60908 .2598 Mtetra
.652 .752 .923 r
.60908 .2598 .61816 .27134 .63622 .26514 .62722 .25357 Mtetra
.655 .754 .923 r
.62722 .25357 .63622 .26514 .6544 .25897 .64547 .24722 Mtetra
.659 .753 .92 r
.64547 .24722 .6544 .25897 .67269 .25262 .66384 .24064 Mtetra
.658 .75 .918 r
.66384 .24064 .67269 .25262 .6911 .24606 .68233 .23407 Mtetra
.655 .75 .92 r
.68233 .23407 .6911 .24606 .70962 .23955 .70094 .22756 Mtetra
.653 .751 .921 r
.70094 .22756 .70962 .23955 .72828 .23311 .71969 .22111 Mtetra
.654 .753 .922 r
.71969 .22111 .72828 .23311 .74706 .22671 .73855 .21455 Mtetra
.658 .753 .92 r
.73855 .21455 .74706 .22671 .76596 .22012 .75753 .20779 Mtetra
.653 .75 .92 r
.08871 .42863 .09983 .4384 .11479 .43325 .10372 .42341 Mtetra
.654 .75 .92 r
.10372 .42341 .11479 .43325 .12986 .42791 .11882 .41815 Mtetra
.658 .754 .92 r
.11882 .41815 .12986 .42791 .14503 .42248 .13403 .41268 Mtetra
.658 .754 .921 r
.13403 .41268 .14503 .42248 .16027 .41712 .14934 .40718 Mtetra
.656 .752 .92 r
.14934 .40718 .16027 .41712 .17559 .41183 .16472 .40174 Mtetra
.653 .749 .92 r
.16472 .40174 .17559 .41183 .191 .40656 .18019 .39636 Mtetra
.652 .748 .92 r
.18019 .39636 .191 .40656 .20653 .40107 .19575 .39099 Mtetra
.657 .753 .921 r
.19575 .39099 .20653 .40107 .22215 .39547 .21142 .38542 Mtetra
.659 .755 .921 r
.21142 .38542 .22215 .39547 .23786 .38988 .22719 .37973 Mtetra
.658 .754 .921 r
.22719 .37973 .23786 .38988 .25366 .38434 .24305 .37404 Mtetra
.657 .752 .92 r
.24305 .37404 .25366 .38434 .26955 .3789 .25901 .36838 Mtetra
.654 .748 .919 r
.25901 .36838 .26955 .3789 .28553 .37345 .27506 .36276 Mtetra
.652 .745 .918 r
.27506 .36276 .28553 .37345 .30162 .36784 .29119 .35719 Mtetra
.653 .748 .919 r
.29119 .35719 .30162 .36784 .31781 .36207 .30744 .35156 Mtetra
.654 .752 .922 r
.30744 .35156 .31781 .36207 .33411 .35626 .32378 .34583 Mtetra
.657 .756 .923 r
.32378 .34583 .33411 .35626 .3505 .35044 .34024 .33998 Mtetra
.657 .757 .924 r
.34024 .33998 .3505 .35044 .367 .3446 .3568 .33408 Mtetra
.3568 .33408 .367 .3446 .38359 .33875 .37346 .32816 Mtetra
.656 .757 .924 r
.37346 .32816 .38359 .33875 .40029 .33288 .39022 .32222 Mtetra
.656 .756 .924 r
.39022 .32222 .40029 .33288 .41709 .32699 .40709 .31626 Mtetra
.655 .756 .924 r
.40709 .31626 .41709 .32699 .434 .32108 .42406 .31028 Mtetra
.42406 .31028 .434 .32108 .45101 .31514 .44114 .30428 Mtetra
.44114 .30428 .45101 .31514 .46813 .30919 .45833 .29826 Mtetra
.45833 .29826 .46813 .30919 .48535 .30324 .47563 .29219 Mtetra
.657 .756 .923 r
.47563 .29219 .48535 .30324 .50269 .29726 .49304 .28599 Mtetra
.659 .754 .92 r
.49304 .28599 .50269 .29726 .52014 .29123 .51057 .27968 Mtetra
.659 .75 .917 r
.51057 .27968 .52014 .29123 .5377 .28504 .5282 .27331 Mtetra
.657 .747 .916 r
.5282 .27331 .5377 .28504 .55538 .27869 .54595 .26699 Mtetra
.655 .748 .918 r
.54595 .26699 .55538 .27869 .57316 .2723 .56381 .26071 Mtetra
.654 .751 .921 r
.56381 .26071 .57316 .2723 .59106 .26603 .58179 .25444 Mtetra
.653 .752 .923 r
.58179 .25444 .59106 .26603 .60908 .2598 .59989 .24817 Mtetra
.655 .754 .923 r
.59989 .24817 .60908 .2598 .62722 .25357 .6181 .24177 Mtetra
.659 .754 .92 r
.6181 .24177 .62722 .25357 .64547 .24722 .63643 .23517 Mtetra
.658 .75 .918 r
.63643 .23517 .64547 .24722 .66384 .24064 .65488 .22855 Mtetra
.656 .75 .919 r
.65488 .22855 .66384 .24064 .68233 .23407 .67346 .22199 Mtetra
.654 .751 .921 r
.67346 .22199 .68233 .23407 .70094 .22756 .69216 .21549 Mtetra
.653 .752 .922 r
.69216 .21549 .70094 .22756 .71969 .22111 .71099 .20894 Mtetra
.658 .754 .921 r
.71099 .20894 .71969 .22111 .73855 .21455 .72994 .20216 Mtetra
.658 .751 .919 r
.72994 .20216 .73855 .21455 .75753 .20779 .749 .19533 Mtetra
.655 .751 .92 r
.07745 .41879 .08871 .42863 .10372 .42341 .09252 .41345 Mtetra
.653 .749 .92 r
.09252 .41345 .10372 .42341 .11882 .41815 .10767 .40815 Mtetra
.655 .75 .92 r
.10767 .40815 .11882 .41815 .13403 .41268 .12292 .40276 Mtetra
.659 .754 .92 r
.12292 .40276 .13403 .41268 .14934 .40718 .13827 .3972 Mtetra
.658 .754 .921 r
.13827 .3972 .14934 .40718 .16472 .40174 .15372 .39162 Mtetra
.656 .751 .92 r
.15372 .39162 .16472 .40174 .18019 .39636 .16925 .38609 Mtetra
.654 .749 .92 r
.16925 .38609 .18019 .39636 .19575 .39099 .18487 .38061 Mtetra
.653 .748 .919 r
.18487 .38061 .19575 .39099 .21142 .38542 .20058 .37513 Mtetra
.656 .752 .921 r
.20058 .37513 .21142 .38542 .22719 .37973 .21639 .3695 Mtetra
.658 .755 .921 r
.21639 .3695 .22719 .37973 .24305 .37404 .23231 .36374 Mtetra
.23231 .36374 .24305 .37404 .25901 .36838 .24833 .35794 Mtetra
.657 .753 .921 r
.24833 .35794 .25901 .36838 .27506 .36276 .26445 .35216 Mtetra
.656 .751 .92 r
.26445 .35216 .27506 .36276 .29119 .35719 .28066 .34637 Mtetra
.655 .747 .918 r
.28066 .34637 .29119 .35719 .30744 .35156 .29696 .3406 Mtetra
.653 .745 .917 r
.29696 .3406 .30744 .35156 .32378 .34583 .31337 .33485 Mtetra
.654 .746 .918 r
.31337 .33485 .32378 .34583 .34024 .33998 .32988 .32905 Mtetra
.654 .749 .919 r
.32988 .32905 .34024 .33998 .3568 .33408 .34649 .32319 Mtetra
.655 .751 .921 r
.34649 .32319 .3568 .33408 .37346 .32816 .36321 .31727 Mtetra
.655 .753 .922 r
.36321 .31727 .37346 .32816 .39022 .32222 .38004 .3113 Mtetra
.656 .754 .922 r
.38004 .3113 .39022 .32222 .40709 .31626 .39698 .30527 Mtetra
.39698 .30527 .40709 .31626 .42406 .31028 .41402 .29919 Mtetra
.657 .753 .921 r
.41402 .29919 .42406 .31028 .44114 .30428 .43117 .29305 Mtetra
.657 .752 .92 r
.43117 .29305 .44114 .30428 .45833 .29826 .44843 .28684 Mtetra
.658 .75 .918 r
.44843 .28684 .45833 .29826 .47563 .29219 .4658 .28058 Mtetra
.658 .748 .916 r
.4658 .28058 .47563 .29219 .49304 .28599 .48329 .27426 Mtetra
.657 .746 .916 r
.48329 .27426 .49304 .28599 .51057 .27968 .50088 .26796 Mtetra
.655 .747 .918 r
.50088 .26796 .51057 .27968 .5282 .27331 .51859 .26167 Mtetra
.655 .75 .92 r
.51859 .26167 .5282 .27331 .54595 .26699 .53641 .25537 Mtetra
.653 .752 .922 r
.53641 .25537 .54595 .26699 .56381 .26071 .55435 .24908 Mtetra
.653 .753 .923 r
.55435 .24908 .56381 .26071 .58179 .25444 .57241 .24276 Mtetra
.656 .754 .922 r
.57241 .24276 .58179 .25444 .59989 .24817 .59058 .23628 Mtetra
.659 .753 .92 r
.59058 .23628 .59989 .24817 .6181 .24177 .60887 .22964 Mtetra
.658 .749 .918 r
.60887 .22964 .6181 .24177 .63643 .23517 .62729 .223 Mtetra
.656 .749 .919 r
.62729 .223 .63643 .23517 .65488 .22855 .64582 .2164 Mtetra
.654 .751 .921 r
.64582 .2164 .65488 .22855 .67346 .22199 .66448 .20985 Mtetra
.653 .752 .922 r
.66448 .20985 .67346 .22199 .69216 .21549 .68327 .20327 Mtetra
.657 .754 .921 r
.68327 .20327 .69216 .21549 .71099 .20894 .70218 .19649 Mtetra
.658 .751 .919 r
.70218 .19649 .71099 .20894 .72994 .20216 .72121 .18961 Mtetra
.657 .75 .919 r
.72121 .18961 .72994 .20216 .749 .19533 .74037 .18275 Mtetra
.657 .752 .92 r
.06607 .40888 .07745 .41879 .09252 .41345 .0812 .40343 Mtetra
.655 .751 .92 r
.0812 .40343 .09252 .41345 .10767 .40815 .0964 .39801 Mtetra
.653 .749 .92 r
.0964 .39801 .10767 .40815 .12292 .40276 .11169 .39262 Mtetra
.655 .75 .92 r
.11169 .39262 .12292 .40276 .13827 .3972 .12709 .38712 Mtetra
.658 .754 .921 r
.12709 .38712 .13827 .3972 .15372 .39162 .14259 .38147 Mtetra
.14259 .38147 .15372 .39162 .16925 .38609 .15818 .3758 Mtetra
.656 .752 .92 r
.15818 .3758 .16925 .38609 .18487 .38061 .17386 .37016 Mtetra
.654 .749 .92 r
.17386 .37016 .18487 .38061 .20058 .37513 .18963 .36456 Mtetra
.653 .747 .919 r
.18963 .36456 .20058 .37513 .21639 .3695 .20549 .35898 Mtetra
.654 .75 .92 r
.20549 .35898 .21639 .3695 .23231 .36374 .22145 .35332 Mtetra
.658 .755 .922 r
.22145 .35332 .23231 .36374 .24833 .35794 .23753 .34749 Mtetra
.23753 .34749 .24833 .35794 .26445 .35216 .25371 .3416 Mtetra
.658 .755 .921 r
.25371 .3416 .26445 .35216 .28066 .34637 .26998 .33568 Mtetra
.657 .753 .921 r
.26998 .33568 .28066 .34637 .29696 .3406 .28635 .32977 Mtetra
.656 .751 .92 r
.28635 .32977 .29696 .3406 .31337 .33485 .30283 .32384 Mtetra
.656 .749 .918 r
.30283 .32384 .31337 .33485 .32988 .32905 .3194 .31789 Mtetra
.656 .747 .917 r
.3194 .31789 .32988 .32905 .34649 .32319 .33608 .31191 Mtetra
.655 .746 .917 r
.33608 .31191 .34649 .32319 .36321 .31727 .35287 .3059 Mtetra
.655 .745 .916 r
.35287 .3059 .36321 .31727 .38004 .3113 .36976 .29985 Mtetra
.656 .746 .916 r
.36976 .29985 .38004 .3113 .39698 .30527 .38676 .29375 Mtetra
.38676 .29375 .39698 .30527 .41402 .29919 .40387 .2876 Mtetra
.40387 .2876 .41402 .29919 .43117 .29305 .42109 .28141 Mtetra
.42109 .28141 .43117 .29305 .44843 .28684 .43842 .27518 Mtetra
.656 .747 .917 r
.43842 .27518 .44843 .28684 .4658 .28058 .45586 .26893 Mtetra
.655 .749 .919 r
.45586 .26893 .4658 .28058 .48329 .27426 .47341 .26265 Mtetra
.655 .751 .92 r
.47341 .26265 .48329 .27426 .50088 .26796 .49108 .25635 Mtetra
.654 .752 .922 r
.49108 .25635 .50088 .26796 .51859 .26167 .50886 .25004 Mtetra
.654 .753 .923 r
.50886 .25004 .51859 .26167 .53641 .25537 .52676 .24371 Mtetra
.654 .754 .923 r
.52676 .24371 .53641 .25537 .55435 .24908 .54477 .23732 Mtetra
.658 .755 .922 r
.54477 .23732 .55435 .24908 .57241 .24276 .56291 .23073 Mtetra
.659 .752 .919 r
.56291 .23073 .57241 .24276 .59058 .23628 .58116 .22407 Mtetra
.657 .749 .918 r
.58116 .22407 .59058 .23628 .60887 .22964 .59953 .21742 Mtetra
.656 .749 .919 r
.59953 .21742 .60887 .22964 .62729 .223 .61803 .21079 Mtetra
.654 .751 .921 r
.61803 .21079 .62729 .223 .64582 .2164 .63665 .20419 Mtetra
.653 .752 .922 r
.63665 .20419 .64582 .2164 .66448 .20985 .6554 .19757 Mtetra
.657 .754 .922 r
.6554 .19757 .66448 .20985 .68327 .20327 .67427 .19077 Mtetra
.658 .752 .919 r
.67427 .19077 .68327 .20327 .70218 .19649 .69326 .18385 Mtetra
.657 .75 .919 r
.69326 .18385 .70218 .19649 .72121 .18961 .71238 .17694 Mtetra
.655 .751 .92 r
.71238 .17694 .72121 .18961 .74037 .18275 .73164 .17006 Mtetra
.658 .754 .92 r
.05455 .39892 .06607 .40888 .0812 .40343 .06974 .39334 Mtetra
.656 .752 .92 r
.06974 .39334 .0812 .40343 .0964 .39801 .085 .38781 Mtetra
.655 .75 .92 r
.085 .38781 .0964 .39801 .11169 .39262 .10035 .3823 Mtetra
.653 .749 .92 r
.10035 .3823 .11169 .39262 .12709 .38712 .11579 .37681 Mtetra
.655 .751 .92 r
.11579 .37681 .12709 .38712 .14259 .38147 .13132 .37122 Mtetra
.658 .754 .921 r
.13132 .37122 .14259 .38147 .15818 .3758 .14697 .36548 Mtetra
.14697 .36548 .15818 .3758 .17386 .37016 .16272 .3597 Mtetra
.656 .752 .92 r
.16272 .3597 .17386 .37016 .18963 .36456 .17855 .35396 Mtetra
.655 .75 .92 r
.17855 .35396 .18963 .36456 .20549 .35898 .19448 .34822 Mtetra
.653 .748 .919 r
.19448 .34822 .20549 .35898 .22145 .35332 .21049 .34251 Mtetra
.21049 .34251 .22145 .35332 .23753 .34749 .22661 .33677 Mtetra
.655 .752 .921 r
.22661 .33677 .23753 .34749 .25371 .3416 .24284 .33094 Mtetra
.657 .755 .922 r
.24284 .33094 .25371 .3416 .26998 .33568 .25917 .32498 Mtetra
.25917 .32498 .26998 .33568 .28635 .32977 .27561 .31898 Mtetra
.27561 .31898 .28635 .32977 .30283 .32384 .29215 .31294 Mtetra
.657 .754 .921 r
.29215 .31294 .30283 .32384 .3194 .31789 .30879 .30688 Mtetra
.656 .753 .921 r
.30879 .30688 .3194 .31789 .33608 .31191 .32554 .3008 Mtetra
.656 .752 .921 r
.32554 .3008 .33608 .31191 .35287 .3059 .34239 .29469 Mtetra
.656 .752 .92 r
.34239 .29469 .35287 .3059 .36976 .29985 .35935 .28855 Mtetra
.656 .751 .92 r
.35935 .28855 .36976 .29985 .38676 .29375 .37641 .28238 Mtetra
.37641 .28238 .38676 .29375 .40387 .2876 .39359 .27618 Mtetra
.655 .752 .921 r
.39359 .27618 .40387 .2876 .42109 .28141 .41088 .26994 Mtetra
.41088 .26994 .42109 .28141 .43842 .27518 .42828 .26367 Mtetra
.655 .752 .922 r
.42828 .26367 .43842 .27518 .45586 .26893 .44579 .25738 Mtetra
.654 .753 .922 r
.44579 .25738 .45586 .26893 .47341 .26265 .46341 .25106 Mtetra
.654 .754 .923 r
.46341 .25106 .47341 .26265 .49108 .25635 .48115 .24471 Mtetra
.655 .754 .923 r
.48115 .24471 .49108 .25635 .50886 .25004 .49901 .23831 Mtetra
.657 .755 .922 r
.49901 .23831 .50886 .25004 .52676 .24371 .51699 .23177 Mtetra
.658 .753 .92 r
.51699 .23177 .52676 .24371 .54477 .23732 .53508 .22513 Mtetra
.658 .749 .918 r
.53508 .22513 .54477 .23732 .56291 .23073 .55329 .21845 Mtetra
.656 .748 .918 r
.55329 .21845 .56291 .23073 .58116 .22407 .57162 .2118 Mtetra
.655 .75 .92 r
.57162 .2118 .58116 .22407 .59953 .21742 .59008 .20515 Mtetra
.654 .751 .921 r
.59008 .20515 .59953 .21742 .61803 .21079 .60866 .19852 Mtetra
.654 .752 .922 r
.60866 .19852 .61803 .21079 .63665 .20419 .62737 .19185 Mtetra
.657 .754 .922 r
.62737 .19185 .63665 .20419 .6554 .19757 .64619 .185 Mtetra
.658 .752 .919 r
.64619 .185 .6554 .19757 .67427 .19077 .66515 .17805 Mtetra
.657 .75 .919 r
.66515 .17805 .67427 .19077 .69326 .18385 .68423 .1711 Mtetra
.656 .75 .92 r
.68423 .1711 .69326 .18385 .71238 .17694 .70344 .16417 Mtetra
.654 .751 .921 r
.70344 .16417 .71238 .17694 .73164 .17006 .72279 .15727 Mtetra
.657 .753 .92 r
.04291 .38881 .05455 .39892 .06974 .39334 .05814 .38321 Mtetra
.658 .754 .921 r
.05814 .38321 .06974 .39334 .085 .38781 .07347 .37754 Mtetra
.656 .752 .92 r
.07347 .37754 .085 .38781 .10035 .3823 .08887 .37192 Mtetra
.655 .75 .92 r
.08887 .37192 .10035 .3823 .11579 .37681 .10437 .36631 Mtetra
.653 .749 .92 r
.10437 .36631 .11579 .37681 .13132 .37122 .11995 .36071 Mtetra
.654 .75 .92 r
.11995 .36071 .13132 .37122 .14697 .36548 .13564 .35505 Mtetra
.658 .754 .921 r
.13564 .35505 .14697 .36548 .16272 .3597 .15143 .34922 Mtetra
.15143 .34922 .16272 .3597 .17855 .35396 .16733 .34334 Mtetra
.657 .753 .921 r
.16733 .34334 .17855 .35396 .19448 .34822 .18332 .33747 Mtetra
.656 .751 .92 r
.18332 .33747 .19448 .34822 .21049 .34251 .1994 .33161 Mtetra
.655 .749 .919 r
.1994 .33161 .21049 .34251 .22661 .33677 .21559 .32574 Mtetra
.654 .747 .919 r
.21559 .32574 .22661 .33677 .24284 .33094 .23187 .31988 Mtetra
.654 .748 .919 r
.23187 .31988 .24284 .33094 .25917 .32498 .24825 .31398 Mtetra
.654 .751 .921 r
.24825 .31398 .25917 .32498 .27561 .31898 .26474 .30802 Mtetra
.656 .754 .922 r
.26474 .30802 .27561 .31898 .29215 .31294 .28134 .30197 Mtetra
.657 .755 .922 r
.28134 .30197 .29215 .31294 .30879 .30688 .29804 .29585 Mtetra
.657 .755 .923 r
.29804 .29585 .30879 .30688 .32554 .3008 .31485 .2897 Mtetra
.656 .755 .923 r
.31485 .2897 .32554 .3008 .34239 .29469 .33177 .28351 Mtetra
.33177 .28351 .34239 .29469 .35935 .28855 .3488 .2773 Mtetra
.3488 .2773 .35935 .28855 .37641 .28238 .36594 .27105 Mtetra
.36594 .27105 .37641 .28238 .39359 .27618 .38318 .26478 Mtetra
.655 .755 .923 r
.38318 .26478 .39359 .27618 .41088 .26994 .40054 .25847 Mtetra
.40054 .25847 .41088 .26994 .42828 .26367 .41801 .25213 Mtetra
.41801 .25213 .42828 .26367 .44579 .25738 .43559 .24575 Mtetra
.656 .755 .923 r
.43559 .24575 .44579 .25738 .46341 .25106 .45329 .23929 Mtetra
.657 .754 .921 r
.45329 .23929 .46341 .25106 .48115 .24471 .47111 .23275 Mtetra
.658 .752 .92 r
.47111 .23275 .48115 .24471 .49901 .23831 .48904 .22614 Mtetra
.658 .749 .918 r
.48904 .22614 .49901 .23831 .51699 .23177 .5071 .21948 Mtetra
.656 .748 .918 r
.5071 .21948 .51699 .23177 .53508 .22513 .52527 .21283 Mtetra
.656 .749 .919 r
.52527 .21283 .53508 .22513 .55329 .21845 .54356 .20616 Mtetra
.655 .751 .92 r
.54356 .20616 .55329 .21845 .57162 .2118 .56197 .19949 Mtetra
.654 .752 .922 r
.56197 .19949 .57162 .2118 .59008 .20515 .58051 .19283 Mtetra
.654 .753 .922 r
.58051 .19283 .59008 .20515 .60866 .19852 .59917 .1861 Mtetra
.657 .754 .921 r
.59917 .1861 .60866 .19852 .62737 .19185 .61796 .17919 Mtetra
.658 .751 .919 r
.61796 .17919 .62737 .19185 .64619 .185 .63687 .17221 Mtetra
.657 .75 .919 r
.63687 .17221 .64619 .185 .66515 .17805 .65591 .16523 Mtetra
.656 .75 .92 r
.65591 .16523 .66515 .17805 .68423 .1711 .67509 .15825 Mtetra
.654 .751 .921 r
.67509 .15825 .68423 .1711 .70344 .16417 .69439 .1513 Mtetra
.655 .753 .922 r
.69439 .1513 .70344 .16417 .72279 .15727 .71383 .14427 Mtetra
.654 .75 .92 r
.03115 .3785 .04291 .38881 .05814 .38321 .04642 .37293 Mtetra
.657 .753 .92 r
.04642 .37293 .05814 .38321 .07347 .37754 .06179 .36724 Mtetra
.658 .754 .921 r
.06179 .36724 .07347 .37754 .08887 .37192 .07726 .36147 Mtetra
.656 .752 .92 r
.07726 .36147 .08887 .37192 .10437 .36631 .09281 .35574 Mtetra
.655 .75 .92 r
.09281 .35574 .10437 .36631 .11995 .36071 .10846 .35003 Mtetra
.654 .749 .92 r
.10846 .35003 .11995 .36071 .13564 .35505 .12419 .34432 Mtetra
.12419 .34432 .13564 .35505 .15143 .34922 .14003 .33856 Mtetra
.656 .753 .921 r
.14003 .33856 .15143 .34922 .16733 .34334 .15597 .33268 Mtetra
.658 .755 .921 r
.15597 .33268 .16733 .34334 .18332 .33747 .17202 .32671 Mtetra
.658 .754 .921 r
.17202 .32671 .18332 .33747 .1994 .33161 .18817 .32071 Mtetra
.656 .752 .92 r
.18817 .32071 .1994 .33161 .21559 .32574 .20442 .31472 Mtetra
.656 .751 .92 r
.20442 .31472 .21559 .32574 .23187 .31988 .22077 .30871 Mtetra
.655 .749 .919 r
.22077 .30871 .23187 .31988 .24825 .31398 .23722 .30268 Mtetra
.655 .748 .918 r
.23722 .30268 .24825 .31398 .26474 .30802 .25377 .29664 Mtetra
.654 .748 .918 r
.25377 .29664 .26474 .30802 .28134 .30197 .27042 .29058 Mtetra
.655 .749 .919 r
.27042 .29058 .28134 .30197 .29804 .29585 .28719 .28446 Mtetra
.655 .75 .92 r
.28719 .28446 .29804 .29585 .31485 .2897 .30406 .27829 Mtetra
.655 .751 .92 r
.30406 .27829 .31485 .2897 .33177 .28351 .32104 .27207 Mtetra
.656 .752 .921 r
.32104 .27207 .33177 .28351 .3488 .2773 .33813 .2658 Mtetra
.656 .753 .921 r
.33813 .2658 .3488 .2773 .36594 .27105 .35534 .25948 Mtetra
.35534 .25948 .36594 .27105 .38318 .26478 .37265 .25311 Mtetra
.656 .752 .921 r
.37265 .25311 .38318 .26478 .40054 .25847 .39008 .24668 Mtetra
.657 .752 .92 r
.39008 .24668 .40054 .25847 .41801 .25213 .40762 .24021 Mtetra
.657 .751 .919 r
.40762 .24021 .41801 .25213 .43559 .24575 .42528 .23368 Mtetra
.657 .749 .918 r
.42528 .23368 .43559 .24575 .45329 .23929 .44306 .2271 Mtetra
.657 .748 .917 r
.44306 .2271 .45329 .23929 .47111 .23275 .46095 .22048 Mtetra
.656 .748 .918 r
.46095 .22048 .47111 .23275 .48904 .22614 .47896 .21385 Mtetra
.656 .749 .919 r
.47896 .21385 .48904 .22614 .5071 .21948 .49708 .20719 Mtetra
.655 .751 .92 r
.49708 .20719 .5071 .21948 .52527 .21283 .51533 .20051 Mtetra
.654 .751 .921 r
.51533 .20051 .52527 .21283 .54356 .20616 .53371 .19383 Mtetra
.654 .753 .922 r
.53371 .19383 .54356 .20616 .56197 .19949 .5522 .18711 Mtetra
.655 .754 .922 r
.5522 .18711 .56197 .19949 .58051 .19283 .57082 .18029 Mtetra
.657 .753 .921 r
.57082 .18029 .58051 .19283 .59917 .1861 .58957 .17334 Mtetra
.658 .75 .919 r
.58957 .17334 .59917 .1861 .61796 .17919 .60844 .16633 Mtetra
.656 .75 .919 r
.60844 .16633 .61796 .17919 .63687 .17221 .62744 .15932 Mtetra
.655 .75 .92 r
.62744 .15932 .63687 .17221 .65591 .16523 .64657 .1523 Mtetra
.654 .751 .921 r
.64657 .1523 .65591 .16523 .67509 .15825 .66583 .14531 Mtetra
.655 .753 .922 r
.66583 .14531 .67509 .15825 .69439 .1513 .68523 .13824 Mtetra
.657 .753 .921 r
.68523 .13824 .69439 .1513 .71383 .14427 .70476 .13102 Mtetra
.654 .75 .92 r
.01927 .36805 .03115 .3785 .04642 .37293 .03458 .36244 Mtetra
.03458 .36244 .04642 .37293 .06179 .36724 .04998 .35678 Mtetra
.657 .753 .921 r
.04998 .35678 .06179 .36724 .07726 .36147 .0655 .35099 Mtetra
.658 .754 .921 r
.0655 .35099 .07726 .36147 .09281 .35574 .08112 .34513 Mtetra
.657 .752 .92 r
.08112 .34513 .09281 .35574 .10846 .35003 .09682 .33928 Mtetra
.655 .751 .92 r
.09682 .33928 .10846 .35003 .12419 .34432 .11262 .33345 Mtetra
.654 .749 .92 r
.11262 .33345 .12419 .34432 .14003 .33856 .12851 .32762 Mtetra
.12851 .32762 .14003 .33856 .15597 .33268 .1445 .32176 Mtetra
.655 .751 .921 r
.1445 .32176 .15597 .33268 .17202 .32671 .1606 .31584 Mtetra
.657 .754 .921 r
.1606 .31584 .17202 .32671 .18817 .32071 .1768 .3098 Mtetra
.658 .755 .922 r
.1768 .3098 .18817 .32071 .20442 .31472 .19311 .3037 Mtetra
.657 .754 .921 r
.19311 .3037 .20442 .31472 .22077 .30871 .20952 .29756 Mtetra
.657 .752 .921 r
.20952 .29756 .22077 .30871 .23722 .30268 .22604 .29142 Mtetra
.656 .751 .92 r
.22604 .29142 .23722 .30268 .25377 .29664 .24265 .28525 Mtetra
.656 .75 .919 r
.24265 .28525 .25377 .29664 .27042 .29058 .25938 .27906 Mtetra
.656 .749 .919 r
.25938 .27906 .27042 .29058 .28719 .28446 .27621 .27283 Mtetra
.655 .748 .918 r
.27621 .27283 .28719 .28446 .30406 .27829 .29315 .26656 Mtetra
.29315 .26656 .30406 .27829 .32104 .27207 .31019 .26026 Mtetra
.656 .748 .918 r
.31019 .26026 .32104 .27207 .33813 .2658 .32735 .25391 Mtetra
.32735 .25391 .33813 .2658 .35534 .25948 .34462 .24751 Mtetra
.34462 .24751 .35534 .25948 .37265 .25311 .36201 .24107 Mtetra
.36201 .24107 .37265 .25311 .39008 .24668 .37951 .23458 Mtetra
.37951 .23458 .39008 .24668 .40762 .24021 .39712 .22805 Mtetra
.39712 .22805 .40762 .24021 .42528 .23368 .41485 .22148 Mtetra
.656 .749 .919 r
.41485 .22148 .42528 .23368 .44306 .2271 .43269 .21487 Mtetra
.655 .75 .919 r
.43269 .21487 .44306 .2271 .46095 .22048 .45066 .20822 Mtetra
.655 .751 .92 r
.45066 .20822 .46095 .22048 .47896 .21385 .46874 .20156 Mtetra
.654 .752 .921 r
.46874 .20156 .47896 .21385 .49708 .20719 .48695 .19487 Mtetra
.654 .753 .922 r
.48695 .19487 .49708 .20719 .51533 .20051 .50528 .18815 Mtetra
.655 .754 .923 r
.50528 .18815 .51533 .20051 .53371 .19383 .52373 .18136 Mtetra
.657 .754 .921 r
.52373 .18136 .53371 .19383 .5522 .18711 .54231 .17444 Mtetra
.657 .752 .92 r
.54231 .17444 .5522 .18711 .57082 .18029 .56101 .16744 Mtetra
.657 .75 .918 r
.56101 .16744 .57082 .18029 .58957 .17334 .57984 .16041 Mtetra
.656 .75 .919 r
.57984 .16041 .58957 .17334 .60844 .16633 .5988 .15337 Mtetra
.655 .75 .92 r
.5988 .15337 .60844 .16633 .62744 .15932 .61788 .14633 Mtetra
.654 .751 .921 r
.61788 .14633 .62744 .15932 .64657 .1523 .63711 .13929 Mtetra
.655 .753 .922 r
.63711 .13929 .64657 .1523 .66583 .14531 .65646 .13217 Mtetra
.657 .753 .921 r
.65646 .13217 .66583 .14531 .68523 .13824 .67594 .12491 Mtetra
.657 .751 .919 r
.67594 .12491 .68523 .13824 .70476 .13102 .69556 .11758 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
[(-2)] .12586 .2075 1 .99877 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.56863 .04703 m
.57247 .05235 L
s
[(2)] .56094 .0364 .72324 1 Mshowa
.125 Mabswid
.18558 .19702 m
.18832 .19985 L
s
.23703 .17687 m
.23971 .17975 L
s
.28951 .15632 m
.29214 .15925 L
s
.39772 .11395 m
.40023 .11699 L
s
.4535 .09211 m
.45595 .0952 L
s
.51046 .06981 m
.51284 .07294 L
s
.08568 .23614 m
.08851 .23887 L
s
.62804 .02377 m
.63027 .02701 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 233.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00o?ooool2o`0006[ooooo003iooooo`?o000000?oooooo`000?ooool0
JOooool00?Oooooo0_l00004ooooo`;o0000JOooool00?Cooooo0ol00006ooooo`03o`000?oooooo
000006Sooooo003;ooooo`Go00008_ooool2o`0000Wooooo00?o0000ooooool00000J?ooool00<_o
oooo00GoV9RHob4Q8Oo^k^koooooodA4A00Oooooo`?o00002oooool01?l0003oooooooooool0001W
ooooo`00c?ooool00onHV9So8B4Qonk^kP0Mooooo`?o00003_ooool01Ol0003ooooooooooooooooo
000006Kooooo003=ooooo`03oiRHV?lQ8B7ok^k^01[ooooo0_l0000Aooooo`05o`000?oooooooooo
ooooool00000I_ooool00<kooooo00?oMgMgofIVI_ooool05_ooool3o`0001?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1Sooooo`00coooool00ol0003oooooooooo`0Cooooo`;o
00000_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0H_ooool00<_ooooo00Go0000okZj^_ooooooV9RHoa0@400Booooo`?o00006Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo06;ooooo003;ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`04?ooool2o`0001cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Qooooo`00
gOooool3o`0001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Qooooo`00fooo
ool2o`00027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Pooooo`00f?ooool3
o`0002?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Oooooo`00eOooool3o`00
02Kooooo00?o0000ooooooooool01?ooool2o`00067ooooo003Cooooo`;o0000:Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo05kooooo003@ooooo`?o000000?oooooo`000?ooool0
:?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05gooooo003>ooooo`;o00001Ooo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0GOoo
ool00<_ooooo0ol0000`ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0G?ooool0
0<Wooooo0_l0000cooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Foooool00<Ko
oooo0ol0000eooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Foooool00<Cooooo
0_l0000hooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0F_ooool00<7ooooo0ol0
000jooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03_ooool5o`0004Kooooo002n
ooooo`?o0000?Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00kooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A016ooooo`00_?ooool2o`0000?ooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo1_l00003ooooo`03oiRHV?lQ8B7o
k^k^04Oooooo002iooooo`?o0000@oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00kooooo00?oV9RHob4Q8Oo^k^h0A_ooool00;Oooooo0_l00016ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03oooool00omgMgOoIVIVooooo`15ooooo`00]?ooool3o`0004Sooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Cooooo
002booooo`;o0000Boooool00ol0003oooooooooo`0=ooooo`;o00003?ooool01Ol0003o^[Zjoooo
oonHV9So410@04Kooooo002_ooooo`?o0000COooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c016ooooo`00[Oooool2o`00053ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`1Dooooo`00Z_ooool4o`00057ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1Dooooo`00Z?ooool2o`0000Cooooo00?o0000oooo
ooooool0C_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05?ooooo001nooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h08_ooool3o`0005Oooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`1Booooo`00O_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01oooooo0ol0001Joooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool0D_ooool007kooooo00Go410@oooooooo
oooooooooa0@400Mooooo`;o0000GOooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
057ooooo001nooooo`05o`000?ooooooooooooooool000006_ooool3o`0005oooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`1@ooooo`00O_ooool01Ol0003ooooooooooooooooo0000
01Sooooo0_l0001Rooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0D?ooool007ko
oooo00Go410@oooooooooooooooooa0@400Eooooo`?o0000I?ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo04oooooo001nooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool2o`00
00?ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
04kooooo001nooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04?ooool3o`0006Sooooo00?oZ<3[o`00
0?ooool05_ooool00ol0003oooooooooo`1>ooooo`00TOooool2o`0006Sooooo1?nX`>/00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo04gooooo002>ooooo`?o0000J?ooool7ojS0j`03o`00
0?oooooooooo01Cooooo0ol0001>ooooo`00Roooool3o`0006Wooooo2OnX`>/00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo04cooooo0029ooooo`;o0000JOooool<ojS0j`03o`000?nX`>_o
oooo01Oooooo00?o0000ooooooooool0Boooool008Kooooo0ol0001Xooooo`03ojO0k?nX`>_oZ<3[
00coZ<3[00?o0000ojS0joooool06?ooool00ol0003oooooooooo`1:ooooo`00Q?ooool2o`0000;o
oooo00?o0000ooooooooool0Hoooool5ojO0k0goZ<3[00?o0000ojS0jonX`>/06?ooool00ol0003o
ooooooooo`1:ooooo`00POooool3o`0000Gooooo00?o0000ooooooooool0H?ooool8ojO0k0OoZ<3[
00?oYl3/ojS0jonX`>/00_nX`>/01?l0003oZ<3[ojS0jonX`>/Hooooo`03o`000?oooooooooo04Wo
oooo001oooooo`;o0000JOooool00onW`>_oYl3/ojO0k007ojO0k0CoZ<3[1OnW`>`3ojS0j`03o`00
0?nX`>_oZ<3[00;oZ<3[6?ooool00ol0003oooooooooo`18ooooo`00O?ooool3o`0006Sooooo1OnW
`>/9ojO0k003ojS0jonW`>coYl3/00KoYl3/0_nX`>/01Ol0003oZ<3[ojS0jonX`>_oYl3/01Sooooo
00?o0000ooooooooool0B?ooool007[ooooo0_l0001Wooooo`;oYko[2?nW`>/6ojO0k0;oYl3[2OnW
`>`2ojS0j`03o`000?nX`>_oYl3/00?oYl3/6?ooool00ol0003oooooooooo`17ooooo`00Moooool3
o`0006Kooooo1_nW_n/8ojO0j`;oYl3/1_nW`>/9ojO0k003ojS0jol0003oYl3/00GoYl3/6?ooool0
0ol0003oooooooooo`16ooooo`00M?ooool3o`0006Kooooo2_nW_n/6ojO0j`;oYko[2?nW`>/6ojO0
k0;oYl3[00?oYl3/o`000?nW`>`01OnW`>`Hooooo`03o`000?oooooooooo04Kooooo001booooo`;o
00000_ooool00ol0003oooooooooo`1Rooooo`goYko[0_nW`>/6ojNoj`SoYl3[0_nW`>`6ojO0j`03
o`000?nW`>coYl3/00GoYl3/6?ooool00ol0003oooooooooo`15ooooo`00Koooool3o`0006Oooooo
6?nW_n/6ojO0j`03ojNojonW`>_oYl3[00KoYl3[00?o0000ojO0k?nW`>`01?nW`>`00onW`>_ooooo
ooooo`0Fooooo`03o`000?oooooooooo04Gooooo001]ooooo`;o0000Ioooool2ojRoja[oYko[0_nW
`>/5ojNoj`OoYl3[00Co0000ojO0jonW`>coYl3/1OnW`>/Gooooo`;o0000A_ooool006[ooooo0ol0
001Vooooo`KoZ;o[6?nW_n/00onX_n_oYko[ojNoj`06ojNoj`KoYl3[00?o0000ojNojonW`>/01onW
`>/Hooooo`03o`000?oooooooooo04?ooooo001Xooooo`;o0000I_ooool2ojS0j`SoZ;o[1_nW_n/2
ojRoj`coYko[1OnX_n/8ojNoj`;oYl3[0onW_n/00ol0003oYko[ojNoj`08ojO0jaOooooo00?o0000
ooooooooool0@oooool006Gooooo0ol0001Uooooo`KoZ<3[2?nX_n/2ojNoj`KoZ;o[2OnW_n/8ojRo
j`KoYko[00?oZ;o[ojNojonW_n/00onW_n/01?l0003oYko[ojNojonW_n/7ojO0jaSooooo00?o0000
ooooooooool0@_ooool006?ooooo0_l0001Uooooo`03ojS1jonX`>_oZ<3[00OoZ<3[1_nX_n/00onX
`>_oZ;o[ojRoj`07ojRoj`KoYko[00?oZ<3[ojRojonX_n/01onX_n/4ojNoj`CoZ;o[1OnW_n/01?l0
003oYko[ojNojonW_n/7ojO0jaSooooo00?o0000ooooooooool0@Oooool0063ooooo0ol000000ooo
oooo0000ooooo`1Rooooo`CoZ<7[2OnX`>/2ojRoj`GoZ<3[2OnX_n/2ojNoj`GoZ<3[2OnX_n/00onW
_n_oZ;o[ojRoj`05ojRoj`CoYko[00Co0000ojNojonW_n_oZ;o[2?nW`>/Gooooo`03o`000?oooooo
oooo047ooooo000fooooo`Go00008oooool2o`0006Kooooo1onX`N/7ojS0j`03ojO1k?nX`>_oZ<3[
00KoZ<3[1_nX_n/2ojS1j`SoZ<3[1_nX_n/2ojS0j`SoZ;o[1?nW_n/00ol0003oZ;o[ojRoj`02ojRo
j`SoYl3[5oooool00ol0003oooooooooo`10ooooo`00=_ooool01OnHV9So8B4Qonk^k_ooooooA4A4
023ooooo0ol0001Uooooo`;oYl7/2?nX`N/4ojS0j`GoYl7/2?nX`>/2ojRoj`KoZ<7[2?nX`>/2ojRo
j`KoZ<3[2?nX_n/01?nW_n_oZ;o[ojRojol00005ojRoj`KoYl3[00?oZ;o[ooooooooool05_ooool0
0ol0003oooooooooo`0oooooo`00;_ooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h07_ooool3o`00
06Gooooo1_nW`N`8ojS1j`03ojS0jonW`NcoYl7/00KoYl7/1_nX`>/00onW`>coZ<7[ojS1j`07ojS1
j`KoZ<3[00?oZ<7/ojS0jonX`>/01onX`>/6ojRoj`05ojS0jonX_n_oZ;o[ojRojol000001OnX_n/4
ojO0j`CoZ;o[5oooool00ol0003oooooooooo`0oooooo`00>?ooool00onHV9So8B4Qonk^kP0Koooo
o`;o0000IOooool2ojO0k0SoYl7/1_nX`N/2ojO0k0SoYl7/1?nX`>/4ojO0k0WoZ<7[0_nX`>/5ojS1
k0WoZ<3[0_nX_n/5ojS0j`;oZ;o[00?o0000ojRojonX_n/01?nX_n/00onW`>_oZ;o[ojRoj`05ojRo
jaOooooo00?o0000ooooooooool0?_ooool003Wooooo00?oMgMgofIVI_ooool05oooool3o`0006Co
oooo1_nW`>`8ojO1k0;oZ<7[1_nW`>`8ojO1k003ojS0jonW`>coYl3/00GoYl3/1onX`N/00onW`>co
Z<7/ojS1k006ojS1k0KoZ<3[0_nX`N`8ojS0j`03ojRojol0003oZ;o[00?oZ;o[0_nX`>/8ojRojaSo
oooo00?o0000ooooooooool0?Oooool003[ooooo00?o0000ooooooooool05?ooool2o`0006Cooooo
00?oYl3[ojO0k?nW`>`01onW`>`6ojO1k003ojO0jonW`>coYl3/00OoYl3/1_nW`N`:ojO0k0CoZ<7[
1?nW`>`8ojS1k0;oZ<3[1_nX`N`8ojS0j`03o`000?nX_n_oZ<3[00GoZ<3[2?nX_n/Gooooo`03o`00
0?oooooooooo03gooooo000fooooo`05o`000?nj^[[ooooooiRHV?l@41004oooool3o`0000;ooooo
00?o0000ooooooooool0Goooool4ojO0j`WoYl3/0_nW`N`5ojO0j`WoYl3/0_nW`N`>ojO0k003ojS1
jonW`>coYl3/00GoYl3/1_nX`N`00onW`>coZ<7/ojS1k007ojS1k0KoZ<3[00?oZ<7[o`000?nX`>/0
1onX`>/6ojRoj`03ojS0jooooooooooo01Kooooo00?o0000ooooooooool0??ooool003Kooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c00Aooooo`;o0000IOooool7ojO0j`OoYl3/2OnW`>/6ojO0k0;oYl3[
3_nW`>`2ojO0j`SoYl3/1?nX`N`4ojO0k0WoZ<7/0_nX`>/4ojS1j`03o`000?nX`>_oZ<3[00OoZ<3[
0_nX_n/5ojS0jaKooooo0ol0000mooooo`00BOooool3o`0006Gooooo2_nW`>/4ojO0k0coYl3[0_nW
`>`6ojO0j`[oYl3/1_nW`>/8ojO0k003ojS1k?nW`>coYl3/00GoYl3/1onX`N`00onW`>coZ<7[ojS1
j`04ojS1j`03o`000?nX`N_oZ<3[00GoZ<3[0_nX`N/8ojS0jaOooooo00?o0000ooooooooool0>ooo
ool004Oooooo0_l0001Uooooo`koYl3[00?oYl3/ojO0jonW`>/02onW`>/2ojNoj`SoYl3[1_nW`>`0
0onW_n_oYl3[ojO0j`07ojO0j`KoYl3/00?oYl3[ojO0k?nW`>`01_nW`>`4ojS1k0GoYl3/1OnX`N/0
0ol0003oZ<7[ojS1j`02ojS0j`KoZ<7[2?nX`>/Gooooo`03o`000?oooooooooo03[ooooo0014oooo
o`?o0000I?ooool00onW_n_oYl3[ojO0j`0<ojO0j`;oYko[3?nW`>/5ojNoj`SoYl3[0_nW`>`5ojNo
j`WoYl3[0_nW`>`5ojO0j`SoYl3/00?oZ<7/ojO0k?nW`>`01_nW`>`4ojS1j`03o`000?nX`N_oYl3/
00WoZ<7[1onX`>/Hooooo`03o`000?oooooooooo03Wooooo0011ooooo`?o0000I?ooool5ojNoj`[o
Yl3[1_nW_n/9ojO0j`SoYko[1_nW`>/9ojNoj`KoYl3[0_nW_n/8ojO0j`KoYl3/0_nW`>/9ojO0k0;o
Z<7[00?oYl3/o`000?nW`>`00_nW`>`9ojS1j`OoZ<3[5oooool00ol0003oooooooooo`0iooooo`00
?oooool3o`0006?ooooo2OnW_n/6ojO0j`[oYko[1_nW`>/;ojNoj`;oYl3[3OnW_n/2ojO0j`KoYko[
2?nW`>/2ojO0k0KoYl3[1onW`>`01OnW`>_oYl3/ojO0k?nW`>co000000CoYl3/1_nX`N/2ojO0k0So
Z<3[5oooool00ol0003oooooooooo`0hooooo`00??ooool3o`0000?ooooo00?o0000ooooooooool0
GOooool=ojNoj`;oYl3[3_nW_n/2ojO0j`goYko[00?oZ;o[ojNojonW_n/03?nW_n/2ojRoj`SoYko[
1_nW`>/00onW_n_oYl3[ojO0j`07ojO0j`CoYl3/1?nW`>/2ojO0k003o`000?nW`>coYl3/00?oYl3/
0_nX`N/6ojO0k0SoZ<3[5_ooool00ol0003oooooooooo`07ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h0;?ooool003[ooooo0_l0001Sooooo`ooYko[0_nX_nX>ojNoj`03ojRojonW_n_oYko[00_oYko[
1?nX_n/:ojNoj`KoZ;o[2?nW_n/2ojO0j`GoYko[2OnW`>/00onW`>coYl3[ojO0j`05ojO0j`03ojO0
k?l0003oYl3/00?oYl3/00?oYl3[ojO0k?nW`>`01onW`>`6ojS0j`03ojO0jooooooooooo01Gooooo
00?o0000ooooooooool01_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02cooooo000gooooo`?o0000
Hoooool>ojNoj`KoZ;oZ2_nW_n/5ojRoj`[oYko[1onX_n/6ojNoj`03ojS0jonX_n_oZ;o[00OoZ;o[
1_nW_n/00onX_n_oYko[ojNoj`06ojNoj`KoYl3[0_nW_n/8ojO0j`;oYl3/00?o0000ojO0k?nW`>/0
0onW`>/9ojO0k0;oZ<3[1OnW`>/Gooooo`03o`000?oooooooooo00Gooooo00Go410@oooooooooooo
oooooa0@400/ooooo`00=Oooool2o`0006Cooooo3OnW_n/00onX_n_oZ;oZojRojP07ojRojPKoYko[
00?oZ<3[ojRojonX_n/01_nX_n/6ojNoj`;oZ<3[2?nX_n/4ojNoj`CoZ<3[2OnX_n/2ojNoj`GoZ;o[
2?nW_n/2ojO0j`KoYko[2?nW`>/00onW`>co0000ojO0j`05ojO0j`SoYl3/2?nW`>/Fooooo`03o`00
0?oooooooooo00Gooooo00Go0000ooooooooooooooooo`00000/ooooo`00<_ooool3o`0006Cooooo
3OnW_n/4ojRoj`WoZ;oZ0_nW_n/5ojS0j`SoZ;o[0_nW_n/6ojS0j`SoZ;o[00?oYko[ojS0jonX`>/0
1OnX`>/7ojRoj`03ojS0jonX_n_oZ;o[00KoZ;o[1_nW_n/00onX_n_oYko[ojNoj`07ojNoj`KoYl3[
00?oYko[ojO0jol000001onW`>/8ojO0k0SoYl3[5_ooool00ol0003oooooooooo`04ooooo`05o`00
0?ooooooooooooooool00000;?ooool0033ooooo0_l0001Tooooo`koYko[1onX_n/7ojRojP03ojS1
jonX`>_oZ<3[00KoZ<3[1_nX_n/2ojS1k0SoZ<3[1_nX_n/00onX`NcoZ<3[ojS0j`06ojS0j`CoZ;o[
1OnX`>/8ojRoj`;oYko[1OnX_n/9ojNoj`;oYl3[1OnW_n/00ol0003oYl3[ojO0j`05ojO0j`SoYl3/
1_nW`>/2ojO0k1Oooooo00?o0000ooooooooool00oooool01Ol@413ooooooooooooooooo410@02co
oooo000]ooooo`?o000000?oooooo`000?ooool0H?ooool?ojNoj`;oZ<3[2?nX_n/4ojRojPCoZ<7[
2?nX`>/2ojRoj`KoZ<7/2?nX`>/2ojRoj`GoZ<7/2?nX`>/00onX_n_oZ<3[ojS0j`06ojS0j`KoZ;o[
00?oZ<7[ojRojonX_n/01_nX_n/6ojNoj`;oZ;o[1onW_n/00ol0003oYl3[ojO0j`06ojO0j`SoYl3/
0_nW`>/6ojO0k1Kooooo0_l00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0;?ooool002[ooooo
0ol0001Sooooo`ooYko[1_nX`>/8ojRoj`03ojRoj_nX`N_oZ<7[00GoZ<7[1_nX`>/2ojO1k0SoZ<7/
1_nX`>/00onW`NcoZ<7/ojS1k006ojS1k0KoZ<3[0_nW`N`9ojS0j`;oZ;o[1OnX`N/8ojRoj`;oYko[
1_nX_n/6ojNoj`03o`000?nW_n_oYl3[00OoYl3[1_nW`>`00onW`>_oYl3/ojO0k007ojO0k1?ooooo
0_l000000ooooooo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0;?ooool002Sooooo
0_l0001Sooooo`ooYko[2_nX`>/6ojRoj`03ojO1k?nX`N_oZ<7[00OoZ<7[0_nX`>/6ojO1k0SoZ<7/
0_nX`>/5ojO1k0SoZ<7/0_nX`>/6ojO1k0OoZ<3[00?oYl7/ojS1jonX`N/01_nX`N/6ojRoj`03ojS0
jonX_n_oZ;o[00OoZ;o[1OnW_n/00ol0003oZ;o[ojO0j`08ojO0j`;oYl3/1OnW`>/9ojO0k1Kooooo
00?o0000ooooooooool0<_ooool002Gooooo0ol0001Rooooo`ooYko[3_nX`>/2ojRoj`GoYl7/1onX
`N/:ojO1k0KoZ<7/00?oYl3/ojO1k?nW`N`01_nW`N`6ojS1k003ojO0k?nW`NcoYl7/00OoYl7/1?nX
`>/4ojO1k0SoZ<7[0_nX_n/5ojS0j`WoZ;o[0_nW_n/00onX_n_o0000o`000002ojRoj`OoYl3[00?o
Yko[ojO0jonW`>/01_nW`>/8ojO0k1Kooooo00?o0000ooooooooool0<_ooool002?ooooo0_l0001R
ooooo`ooYko[0_nW`>/>ojS0j`WoYl7/1?nX`N/=ojO1k0;oZ<7/1OnW`>`8ojO1k0;oZ<7/1OnW`>`9
ojO1k003ojS0jonW`NcoYl7/00GoYl7/1_nX`N/00onW`NcoZ<3[ojS0j`06ojS0j`KoZ;o[0_nX`>/3
o`000003ojRojol0003oZ;o[00;oZ;o[1?nW`>/4ojNoj`SoYl3[2?nW`>`Fooooo`03o`000?oooooo
oooo037ooooo000Pooooo`?o0000HOooool?ojNoj`KoYl3[2_nX`>/=ojO1k003ojS1jonW`NcoYl7/
00coYl7/2OnW`>`6ojO1k0WoYl3/1_nW`N`3ojO0k0SoYl7/0_nX`N/5ojO1k0SoZ<3[0_nX_n/2ojS0
j`?o000000?oZ<3[ojRojonX_n/00_nX_n/01Ol0003oZ;o[ojRojonX_n_oYl3[00OoYko[1onW`>/8
ojO0k1Oooooo00?o0000ooooooooool0<?ooool001oooooo0_l0001Pooooo`ooYko[2_nW`>/6ojS0
j`ooYl7/0onW`>`:ojO1k0goYl3/0_nW`N`=ojO0k0;oYl7/1onW`>`6ojO1k003ojK0k?nW`NcoYl7/
00KoYl7/1_nX`>/00onW`NcoZ<3[o`000002o`0000CoZ<3[1OnX_n/00ol0003oZ<3[ojS0j`09ojNo
j`OoYl3[2?nW`>`Fooooo`03o`000?oooooooooo033ooooo000Oooooo`03o`000?oooooo000005go
oooo3_nW_n/>ojO0j`;oZ<3[3onW`N`7ojO0k0KoYl7/00?oYl3[ojO0k?nW`>`03?nW`>`00onW_n_o
Yl3/ojO0k00<ojO0k0;oYl3[2OnW`>`2ojO1k0GoY/3/2?nW`N`2ojS0j`;oYl7/0ol00008ojS0j`;o
Z;o[0onX`>/00ol0003oZ<3[ojS0j`07ojNoj`03ojS0jonW`>_oYl3[00KoYl3[1_nW`>`00onW_n_o
ooooooooo`0Eooooo`03o`000?oooooooooo02oooooo000<ooooo`Go00000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Kooooo00Co0000oooooooooooo0000F_ooool=ojNoja3oYl3[3onW`N`;ojO0
k0;oYl7/1OnW`>/:ojO0k0GoYko[2_nW`>`6ojO0j`OoYl3/00?oYl3[ojK0k?nV`>`01_nV`>`6ojO1
k003ojK0k?nW`Nco000000;o00001?nW`N`6ojS0j`03ojS1k?nX`>_oZ<3[00?oZ<3[00Co0000ojS0
jonX`>_oZ<3[1?nW_n/4ojS0j`SoYl3[0_nW`>`5ojNojaOooooo00?o0000ooooooooool0;_ooool0
00cooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_oo
ool2o`0000;ooooo00?o0000ooooooooool0EOooool=ojNoj`ooYl3[3onW`N`=ojO0k003ojNojonW
`>_oYl3[00KoYl3[1_nW`>`9ojNoj`KoYl3/00?oYko[ojO0jonW`>/01onW`>/4ojO0k0CoYl3[2?nV
`>`2ojO1k0;oY/3/0ol00008ojO1k0;oZ<3[1OnX`N`5ojS0j`05o`000?nX`>_oZ<3[ojS0jonW_n/0
1onX`>/6ojO0j`WoYko[5_ooool00ol0003oooooooooo`0^ooooo`001?ooool6o`0000?ooooo00?o
V9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00Gooooo0_l00004ooooo`03o`00
0?oooooooooo057ooooo3onW_n/=ojO0j`ooYl7/0_nW`>/<ojO0k0CoYko[2?nW`>/2ojO0k0goYko[
0_nW`>`5ojNoj`WoYl3[00?oYl3/ojO0jonW`>/01OnW`>/6ojK0k003ojNojonV`>co000000;o0000
1?nV`>`6ojO1k003ojK0k?nX`NcoZ<7/00KoZ<7/1OnX`>/00ol0003oZ<7[ojS1j`09ojS0j`;oYl3[
3OnW_n/Fooooo`03o`000?oooooooooo02gooooo000>ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go
0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
COooool@ojNoj`coYl3[3onW`N`6ojO0j`WoYl3/1onW_n/6ojO0j`03ojRnj_nW_n_oYko[00coYko[
00?oZ;oZojNojonW_n/01_nW_n/6ojO0j`;oYkoZ2OnW`>/2ojK0k0?oYko[0_l00008ojK0k0;oYl7/
1OnV`>`8ojS1k0;oZ<3[0_nX`N/01?l0003oZ<7[ojS1jonX`N/8ojS0j`koYko[00?oYl3[oooooooo
ool05Oooool00ol0003oooooooooo`0/ooooo`003oooool00omgMgOoIVIVooooo`02ooooo`05o`00
0?ooooooooooooooool000001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04Wo
oooo4?nW_n/<ojO0j`ooYl7/2_nW`>/6ojO0k003ojNoj_nW_n_oYko[00OoYko[0_nW`>/5ojRnjP[o
Yko[1OnX_nX8ojNoj`;oYl3[1_nW_nX7ojO0j`03ojNoj_nW_n_oYko[00?o00000onW_n/6ojK0k003
ojO0jonV`>coY/3/00KoY/3/1_nX`N`00onW`>coZ<7[ojS1j`03ojS1j`03o`000?nX`N_oZ<7[00Wo
Z<3[2_nW_n/5ojO0jaGooooo0_l0000^ooooo`004?ooool01Ol0003ooooooooooooooooo410@00?o
oooo00?o410@ooooooooool00oooool2o`0000Oooooo00?o0000ooooooooool0A_ooool?ojNoj`co
Yl3[3onW`N`>ojO0j`;oYl3/1OnW_nX7ojNoj`03ojRoj_nX_^[oZ;kZ00KoZ;kZ1_nW_n/9ojRojPKo
Yko[0_nX_nX8ojNojPCoYl3[0_nW_nX3o`0000OoYko[0_nV`>`5ojO0j`SoY/3/0_nX`N`5ojO0k0Go
Z<7[00?o0000ojS1jonX`N/02OnX`>/6ojNoj`03ojS0jonW`>_oYl3[00KoYl3[5_ooool00ol0003o
ooooooooo`0[ooooo`003?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0@_ooool?ojNo
j`coYl3[3onW`N`@ojO0j`03ojNnj_nW_n[oYkoZ00KoYkoZ1?nW_n/4ojRojPSoZ;kZ0_nW_n/=ojRo
jP;oYko[1_nX_nX8ojNojP03ojO0jonW_n[o000000;o00000onW_nX6ojNoj`03ojNoj_nW`>_oYl3[
00KoYl3[1_nV`>`9ojO0k0GoZ<7[00?o0000ojO0k?nX`>/02OnX`>/2ojNoj`GoZ<3[2?nW`>/Eoooo
o`03o`000?oooooooooo02_ooooo000<ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0n
oooooa7oYko[2onW`>/>ojO1k13oYl3[1OnW_^X8ojNojP03ojNojonX_n[oZ;oZ00GoZ;oZ1_nX_^X0
0onX`N_oZ;oZojRojP0<ojRojP;oZ<7[2?nX_nX6ojNojP?o00001onW_nX2ojNoj`GoYkoZ2?nW`>/2
ojK0k0goYl3/0_nX`N/2ojO0k003o`000?nW`>coYl3/00SoZ<3[00?oZ<7[ojS0jonX`>/01OnX`>/6
ojO0j`;oYko[5_ooool00ol0003oooooooooo`0Zooooo`007_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo03[ooooo5OnW_n/8ojO0j`koYl7/3onW`>/9ojNnjPKoYkoZ00?oZ;o[ojRo
j_nX_nX01onX_nX2ojRnjPGoZ<7[2_nX_nX6ojS1j`SoZ;oZ0_nW_nX3o`0000?oZ;oZ1_nW_nX00onY
`>[oYkoZojNojP06ojNojPKoYl3[00?oYko[ojO0k?nW`>`03?nW`>`00onV`>coYl3/ojO0k003ojO0
k003o`000?nW`>coYl3/00CoZ<3[1OnX`N/7ojS0j`;oYl3[1_nW_n/Fooooo`03o`000?oooooooooo
02Wooooo000Mooooo`?o00002oooool00ol0003oooooooooo`0fooooo`;oYl3[5onW_n/5ojO0j`go
Yl7/3onW`>/=ojNnjP;oYkoZ1OnX_n/7ojRojP;oZ<7/1onX`N/6ojRojP;oZ<7/2?nX`N/6ojRojP?o
00001onX_nX2ojNojPGoZL3Z2?nW_nX2ojO0j`GoYko[2_nW`>`5ojK0k0GoYl3/00Co0000ojO0k?nW
`>coZ<3[1onX`N/7ojS0j`SoYko[5_ooool00ol0003oooooooooo`0Yooooo`007Oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo03;ooooo1_nW`>/GojNoj`03ojO0jonW`NcoYl7/00_o
Yl7/3onW`>/?ojNnjP03ojS0jonX_n_oZ;o[00KoZ;o[1?nX_nX5ojS1k0OoZ<7[0_nX_nX6ojS1k0So
Z<7[0_nX_nX3o`0000;oZ<7[1onX_nX00onX`NcoZL3ZojW0jP06ojW0jPKoYkoZ00?oZKoZojNojonW
_n/01_nW_n/6ojO0k003ojNojonV`>coY/3/00KoY/3/1OnW`>`00ol0003oY/3/ojK0k008ojS1j`Oo
Z<3[2?nW_n/Fooooo`03o`000?oooooooooo02Sooooo000Mooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool0;oooool00onX`>_oYl3[ojO0j`06ojO0jaGoYko[0_nX`N`:ojO1k0ooYl3[
3onW_^X5ojS0j`SoZ;o[00?oZ;oZojS1k?nX`N`01_nX`N`5ojS1j`;oYl7/2?nX`N`6ojS1j`?o0000
1_nX`N/4ojRojPCoZ<7/2?nY`>X2ojNojPGoZKoZ2?nW_n/2ojO0k0GoYko[2?nV`>`2ojO0k0;oY/3/
00Co0000ojK0k?nV`>coY/3/1_nX`N/00onW`>_oZ<3[ojS0j`06ojS0j`KoYko[00?oZ<3[oooooooo
ool05Oooool00ol0003oooooooooo`0Wooooo`007Oooool2o`0000oooooo00?o0000ooooooooool0
:oooool5ojS0j`SoYl3[4OnW_n/6ojS1k0KoYl7/3onW`>/?ojNnjPWoZ<3[1_nX_n/3ojO1k0SoZ<7/
00?oZ<7[ojO1k?nW`N`01?nW`N`8ojS1k0;oZ<7[00?oYl7/o`000?l000000_nW`N`8ojS1j`03ojRo
j_nX`NcoZ<7/00GoZ<7/1_nY`>X00onX`N_oZKoZojVojP06ojVojPKoYko[00?oZ;oZojNojonW_n/0
1_nW_n/6ojK0k0;oYko[1?nV`>`01?l0003oY/3/ojK0k?nV`>`2ojS1j`GoYl3[2?nX`>/2ojNoj`Go
Z<3[5_ooool00ol0003oooooooooo`0Wooooo`007Oooool00ol0003oooooooooo`0?ooooo`;o0000
:?ooool2ojS1j`OoZ<3[1_nW`>/?ojNoj`[oZ<7/0_nW`N`?ojO0j`ooYkkZ3OnX`>/2ojRoj`OoYl7/
1_nX`N`9ojO1k0KoZ<7/00CoY/7/o`000?l0003o00001OnW`N`6ojS1j`;oY/7/2?nX`N`2ojW0jPGo
Z<7[2?nY_nX2ojNoj`GoZ;oZ2?nW_n/2ojK0k0KoYko[1?nV`>`00ol0003oY/3/ojK0k008ojO0j`oo
Z<3[5_ooool00ol0003oooooooooo`0Vooooo`007Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo02;ooooo1_nX`N/7ojS0j`;oYl3[3onW_n/<ojS1k0ooYl3[3onW_^X2ojO1k0goZ<3[
2onW`N`2ojS1k0goYl7/0_nX`N`01OnV`Nco0000o`000?l0003oY/7/00SoYl7/0_nX`N/6ojK1k0Ko
Z<7/00?oY/7/ojS1jonX`N/01_nX`N/6ojVojP03ojW1jonX_n[oZ;oZ00KoZ;oZ1_nW_n/2ojRoj`So
Yko[1?nV`>`00ol0003oY/3/ojK0k008ojO0j`ooZ<3[5_ooool00ol0003oooooooooo`0Uooooo`00
7Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01kooooo0_nX`N`8ojS1j`GoZ<3[
3onW_n/2ojO1k0[oZ<7/3onW`>/?ojNnjPKoYl7/2OnX`>/LojO1k004ojO0k?l0003o0000o`0000Go
Y/7/1_nW`N`2ojK0k0SoY/7/0_nX`N`5ojK1k0SoZ<7[0_nY_nX5ojW1j`SoZ;oZ0_nW_n/6ojRoj`Oo
Yko[1?nV`>`01?l0003oY/3/ojK0k?nV`>`6ojO0j`03ojO0k?nX`>_oZ<3[00goZ<3[5_ooool2o`00
02Kooooo000Looooo`?o00005?ooool00ol0003oooooooooo`0Jooooo`KoZ<7/2?nX`N/00onX`>_o
Yko[ojNoj`0=ojNoj`KoYl7/1onX`N`00onX`N_oYl3[ojO0j`0<ojO0j`ooYkkZ2OnW`N`6ojS0ja_o
Yl7/00GoYl3/o`000?l0003o0000ojO0k008ojK1k0;oYl7/1_nV`>`6ojK1k003ojK0k?nV`NcoY/7/
00KoY/7/1_nX`N/00onV`>coZL7[ojW1j`06ojW1j`KoZ;oZ00?oZL3[ojRojonX_n/01onX_n/7ojNo
j`CoY/3/00Co0000ojK0k?nV`>coY/3/0_nW`>/5ojO0k0ooZ<3[5?ooool00ol0003oooooo`00000V
ooooo`007?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Oooooo0_nX`N/7ojS1
k0KoZ<7[0_nW`>/=ojNoj`03ojO0jonW`NcoYl7/00KoYl7/1?nX`N`4ojS1j`[oYl3[3onW_^X=ojO1
k0;oZ<3[3?nW`N`00onW`>coYl7/ojO1k00<ojO1k004ojNojol0003o0000o`0000GoYl3/1_nV`N`2
ojNoj`SoY/3/0_nV`N`5ojK0k0SoY/7/0_nX`N/5ojK0k0SoZL7[0_nX_nX5ojW0j`OoZ;o[00?oZ<3Z
ojNojonW_n/01_nW_n/4ojK0k003o`000?nV`>coY[o/00SoYl3/3onX`>/Fooooo`03o`000?oooooo
oooo02?ooooo000:ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Dooooo`GoZ<7[1onX`N`2ojS1j`KoYl3[
2OnW_n/5ojO0j`SoYl7/00?oZ<7/ojS1jonX`N/01OnX`N/6ojO0j`03ojNoj_nW_^[oYkkZ00coYkkZ
00?oYl3/ojO1k?nW`N`06?nW`N`5ojO0k0[oYl7/00GoYko[o`000?l0003o0000ojNoj`08ojO0k0;o
Y/7/1_nW_n/6ojK0k003ojNojonV`>coY/3/00KoY/3/1_nV`N`9ojK0k0KoZL7[00?oYl7/ojW0jonY
`>/01_nY`>/4ojRoj`CoZ<3Z2?nW_n/2ojK0k003ojJok?l0003oY[o/00;oY[o/2?nW`>`?ojS0jaGo
oooo00?o0000ooooooooool08oooool000cooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Aooooo`So
Z<7[1OnX`N`:ojO0j`OoYko[1onW`>/6ojO1k0?oZ<7/1onX`N/2ojO0j`GoYkoZ2_nW_^X5ojO0k1Ko
Yl7/00?oYl3[ojO0k?nW`>`01_nW`>`6ojO1k004ojNnj_l0003o0000o`0000GoYko[1_nW`>`2ojNn
jPSoYko[0_nV`>`5ojNoj`SoY/3/0_nV`N`=ojK0k0;oZL7[1OnW`N`8ojW0j`03ojRojonX`>[oZ<3Z
00GoZ<3Z1onW_n/4ojJok004o`000?nV_ncoY[o/ojJok0KoYl3/00?oY/3/ojS0jonX`>/03OnX`>/F
ooooo`03o`000?oooooooooo02;ooooo00000ooooooo0000o`000004o`0000Gooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@00Kooooo0_l0000Iooooo`03o`000?oooooo
oooo00kooooo0onW`>/8ojS1j`03ojS1k?nW`>_oYl3[00coYl3[1onW_n/7ojO0j`;oYl7/1onX`N`5
ojS1j`;oYko[1onW_nX6ojNnjP;oYl3[1onW`>`BojO1k0GoYl3[2?nW`>`2ojO1k0;oYkkZ0_l00000
0onW_^[oYko[ojNoj`06ojNoj`;oYl3/1_nW_^X6ojNoj`03ojRnjOnW_n_oYko[00KoYko[1_nV`>`0
0onW_n_oY/3/ojK0k00=ojK0k0SoYl7/1_nY`>/2ojS1j`SoZ<3Z1onW_n/4ojJok004o`000?nV_nco
Y[o/ojJok0;oYl3/1OnV`>`?ojS0jaKooooo00?o0000ooooooooool08Oooool000cooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0:ooooo`OoYl3[1onX`N/>ojO0j`WoYko[1OnW`>/;ojS1k003ojS1jonW
_n_oYko[00CoYko[1onW_nX2ojNnjPKoYl3[1onW`>`>ojO1k0WoYl3[1_nW`>`00onW_^WoYkkZo`00
0002o`0000CoYkkZ1_nW_n/00onX_^WoYkkZojNnjP07ojNnjP;oYko[1OnX_^T8ojNoj`;oY/3/1OnW
_n/?ojK0k0SoYl7/0_nY`>/6ojS1j`KoZ<3Z00?oZL3ZojNojonW_n/01OnW_n/5ojJok003o`000?nW
_n_oYko[00OoY/3/4?nX`>/Eooooo`03o`000?oooooooooo027ooooo000<ooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool01oooool3ojNoj`OoYl3[1onX`N/:ojO0j`goYko[00?oYl3[ojS1k?nX`N`02onX
`N`00onW`>_oYko[ojNoj`06ojNoj`GoYkoZ0_nW_n/8ojO0j`GoYl3/3?nW`N`=ojO0j`;oYl3/0_nW
_^T3o`0000SoYkkZ0_nW_n/5ojRnj@OoYkkZ00?oZKoZojRnjOnX_^T01_nX_^T6ojNoj`03ojRnjOnW
_n_oYko[00KoYko[1_nV`>`2ojNoj`OoY/3/1_nW`N`2ojK0k0SoZ<7[0_nX`>X5ojW0jPOoYko[0_nV
_n`2ojNoj`04o`000?nW_n_oYko[ojNoj`OoY/3/3onX`>/Fooooo`03o`000?oooooooooo023ooooo
000<ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool00oooool7ojNoj`GoYl3[2OnX`N/6ojO0j`ooYko[
3?nX`N`5ojO0j`SoYko[00?oYkoZojNojonW_n/01?nW_n/8ojO0j`03ojO0k?nW`NcoYl7/00[oYl7/
3onW`>/2ojRmj@?o00001?nW_^T6ojNnjP03ojRoj_nX_^WoZ;kY00KoZ;kY1?nW_^X4ojVojPSoZ;kY
0_nW_n/5ojRnj@SoYko[0_nV`>`6ojNoj`OoY/3/0_nW`N`6ojK0k0KoZ<7[00?oYl3/ojW0j_nY`>X0
1OnY`>X6ojNoj`03ojS0jonW_n_oYko[00?oYko[00?o0000ojNojonW_n/01_nV`>`2ojJok0ooZ<3[
5_ooool00ol0003oooooooooo`0Oooooo`003?ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2o`0001kooooo00?o0000oooooonW_n/02_nW_n/00onW`>_oZ<7[
ojS1j`0;ojS1j`;oYl3[3onW_n/<ojS1k0;oZ<3[1onW`>/6ojNoj`03ojNnjonW_n_oYko[00KoYko[
1_nW`>/2ojS1k0WoYl7/3onW`>/2ojRmj@?o000000?oZ;gYojNnjOnW_^T01OnW_^T2ojNnjPGoZ;oZ
2?nX_^T00onW_^[oZKoZojVojP05ojVojPKoZ;kY00?oZL7[ojRnjOnX_^T01_nX_^T6ojNoj`;oZ;kY
2?nW_n/3ojK0k0CoY[o/2?nV`>`2ojS1j`GoYl3/1onY`>X2ojNoj`GoZ<3[1OnW_n/00ol0003oYko[
ojNoj`02ojK0k0KoY[o/1_nX`>/00onW`>_oZ<3[ojS0j`06ojS0jaGooooo00?o0000ooooooooool0
7oooool000[ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
00?o0000ooooooooool07?ooool=ojNoj`;oYl3[3?nX`N/2ojO0j`goYko[0onW`>/9ojS1k0KoZ<3[
1onW`>/2ojNoj`GoYkk[2?nW_n/2ojO0j`KoZ<7/1_nW`N`?ojO0j`04ojRmjOl0003o0000o`0000Go
Z;gY1OnW_^T2ojS0j`OoZ;oZ1_nX_^T2ojW1j`SoZKoZ0_nX_^T5ojW1j`SoZ;kY0_nW_n/6ojRnj@Ko
Yko[00?oZ;kZojJok?nV_n`01_nV_n`7ojK0k0OoYl3/1_nY`>X00onY`N_oZ<3[ojS0j`06ojS0j`Go
Yko[00?o0000ojO0jonW`>/02?nV_n`2ojS0j`GoYl3[2?nX`>/Eooooo`03o`000?oooooooooo01ko
oooo000Kooooo`03o`000?oooooooooo01[ooooo0onW`>/9ojNoj`KoYl3[2?nX`N/6ojO0j`WoYko[
1onW`>/5ojS1k0;oZ<7[2?nX`>/5ojO0j`;oYkkZ1onW_^/6ojNoj`[oZ<7/0_nW`N`?ojO0j`04ojRm
jOl0003o0000o`0000WoZ;gY00?oYkkYojS0jonX`>/01?nX`>/7ojRojP;oZ;kY1_nY`N/6ojVojP03
ojS1jonY`N_oZL7[00KoZL7[1_nX_^T00onY`N_oZ;kYojRnj@07ojRnj@;oYko[1OnX_^X8ojJok0Oo
Y/3/1onW`>`2ojW0jPGoZL7[2?nX`>/2ojNoj`;oYl3[00Co0000ojO0jonW`>_oYl3[1onV_n`8ojO0
j`OoZ<3[5_ooool00ol0003oooooooooo`0Mooooo`006oooool00ol0003oooooooooo`0Gooooo`Oo
Yl3[1onW_n/8ojO0j`GoZ<7[0_nX`>/7ojO0j`SoYko[2?nW`>/00onX`NcoZ<7[ojS1j`04ojS1j`So
Z<3[00?oYl3[ojNnj_nW_^X01?nW_^X7ojNnj`;oYko[3?nX`N`00onX`N_oYl3[ojO0j`0<ojO0j`04
ojNmjOl0003o0000o`0000_oZ;gY0_nX`N/7ojS0j`GoZ;oZ0_nW`>/8ojW1j`;oZKoZ1OnX`N/8ojW1
j`;oZ;kY1OnY`N/7ojRnj@03oj[1j_nX_^[oZ;kZ00KoZ;kZ1_nV_n`00onW_n_oY/3/ojK0k005ojK0
k0KoYl3/00?oY/3/ojW1jonY`N/01_nY`N/6ojS0j`;oZL3[1?nW`>/01?l0003oYl3[ojO0jonW`>/7
ojJok0SoYl3[1onX`>/Dooooo`;o00007oooool001_ooooo0_l0000Dooooo`GoZ<3[1onW`>/7ojNo
j`SoYl3[00?oZ<7[ojS0jonX`>/01?nX`>/7ojO0j`SoYko[1_nW`>/2ojS1k0OoZ<7[1_nX`>/00onW
_n_oYkkZojNnjP06ojNnjPGoYkk[3?nX`N`5ojS1j`[oYl3[0_nW_NT2o`000003ojNmjOnX_NWoZ;gY
00SoZ;gY1_nX`N/7ojS0j`03ojRoj_nW`>_oYl3[00CoYl3[1_nY`N/00onW_NWoZ<7[ojS1j`06ojS1
j`KoZL7[00?oYko[ojW1jonY`N/01_nY`N/4ojRnj@CoZ/7Z2?nX_^X2ojJok0GoYko[1onV`>`2ojO0
k0GoY/3/2?nY`N/2ojS0j`KoZL3[1?nW`>/00ol0003oYl3[ojO0j`08ojJok0OoYl3[1onX`>/Foooo
o`03o`000?oooooooooo01cooooo000Jooooo`03o`000?oooooooooo013ooooo0_nX`N/8ojS0j`Go
Yl3[2OnW_n/6ojO0j`;oZ<7[1onX`>/5ojO0j`[oYko[0_nW`>/6ojS1k0OoZ<7[0_nX`>/5ojNoj`So
YkkZ00?oYkk[ojS1k?nX`N`03?nX`N`7ojS1j`KoYl3[0_nW_NT3o`0000CoYkgY1_nX_NT2ojS1k0So
Z<7[0onX`>/4ojNnjPOoYl3[0_nY`N/5ojNmj@SoZ<7[0_nY`N/5ojNoj`SoZL7[00?oZ;kYoj[1j_nZ
`NX01OnZ`NX6ojRnjP03ojVojOnW_n_oYko[00GoYko[1_nV`>`2ojJok0OoY/3/1_nY`N/2ojS0j`So
ZL3[1?nW`>/00ol0003oYl3[ojO0j`08ojJok0OoYl3[1onX`>/Eooooo`03o`000?oooooooooo01co
oooo000Jooooo`03o`000?oooooooooo00gooooo1_nX`N/8ojS0j`03ojO0jonW_n_oYko[00_oYko[
0_nW`>/6ojS1j`OoZ<3[00?oYl3[ojNojonW_n/02_nW_n/:ojS1k0GoZ<7[0_nW`>/7ojNoj`KoYkkZ
0_nW`>`?ojS1k0OoZ<7[0_nW`>/2ojNmj@?o00002?nW_NT2ojRmj@KoZ<7/1_nX`N/00onW_>SoYkkZ
ojNnjP06ojNnjPGoYl3[0_nX^NH7ojNmj@KoZ<7[00?oYk_XojNojonW_n/01_nW_n/6ojW1j`;oYl3[
2?nZ`NX2ojRnjPGoZKoY1onW_n/2ojK0k0KoY[o/1onV`>`2ojW1j`KoZ<3[1onY`>/4ojO0j`03o`00
0?nW`>_oYl3[00SoY[o/1onW`>/8ojS0jaGooooo00?o0000ooooooooool06oooool001[ooooo00?o
0000ooooooooool02oooool2ojS0j`OoZ<7[1_nX`>/>ojNoj`[oZ<7[0onX`>/=ojNoj`koZ<7/00?o
Z<7[ojO0jonW`>/01?nW`>/7ojNoj`;oYkkZ1_nW`>`?ojS1k0GoZ<7[0_nW_NT3o`0000[oYkgY0_nW
`N`8ojS1k0;oZ<7[1OnW_>P8ojNnjP03ojO0jonX^NKoZ;WV00CoZ;WV1onW_NT2ojS1j`GoYk_X2?nW
_n/2ojW1j`KoYl3[1_nZ`NX00onX`N_oZKoYojVoj@05ojVoj@KoYko[0_nX_nX8ojJok0?oY/3/1?nV
_n`8ojS0j`OoZL3[1?nW`>/00ol0003oYl3[ojO0j`08ojJok0OoYl3[2?nX`>/Eooooo`03o`000?oo
oooooooo00Kooooo1Ol0000?ooooo`006_ooool2o`0000Wooooo1_nX`>/7ojS1j`;oZ<3[3_nW_n/<
ojS1j`;oYl3[3onW_n/=ojS1k0;oZ<3[1onW`>/8ojNoj`OoYl3/3onX`N`00onX`N_oYkgYojNmj@03
o`0000[oYkgY1_nW`N`6ojS1k003ojNkj?nW_>SoYkcX00KoYkcX1_nW_^X00onX]>7oZ;WVojRiiP06
ojRiiPGoYkgY00?oZKGQojNkj?nW^nP01_nW^nP6ojNoj`;oYkcX2?nW`>/2oj[1jPGoZ<7[1onY_nT2
ojNoj`KoZ;oZ1_nV_n`00onV_n_oY[o/ojJok006ojJok0KoZ<3[00?oYl3[ojW0jonY`>/01OnY`>/5
ojO0j`03o`000?nW`>_oYl3[00OoY[o/2?nW`>/8ojS0jaCooooo00?o0000ooooooooool01_ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400oooooo000Jooooo`03o`000?oooooooooo00Kooooo0_nW_n/7
ojS0j`GoZ<7[0_nW`>/@ojNoj`SoZ<7[1_nW`>/?ojNoj`WoZ<7/1_nX`>/7ojO0j`SoYko[1OnW`>`?
ojS1k004ojNnj_l0003o0000o`0000[oYkgY2_nW`N`2ojS1k0GoYk_X2?nW_>P2ojNnjPGoZ;CQ2?nX
^NH00onW_NWoZKGQojVeh@03ojVeh@SoYk_X0_nW_n/6ojNlj0KoYl3[00?oYkgYojS1jonX`N/01_nX
`N/5ojVoj@;oZ/7[2?nX_nX2ojJok0GoY[o[2?nV_n`2ojS0j`GoYl3[1onY`>/4ojO0j`04o`000?nW
`>_oYl3[ojO0j`OoY[o/2?nW`>/7ojS0jaGooooo00?o0000ooooooooool01_ooool00onHV9So8B4Q
onk^kP0@ooooo`006_ooool00ol0003oooooooooo`03ooooo`KoYko[1onX`>/00onX`N_oYl3[ojO0
j`04ojO0ja3oYko[1onX`N/7ojO0j`ooYko[1OnX`N`3ojS1j`OoZ<3[0onW`>/4ojJnj`SoYko[00?o
Yl3/ojS1k?nX`N`03OnX`N`01OnW_^[o0000o`000?l0003oYkkZ00WoYkgY3?nW`N`9ojNkj0KoYkcX
00?oZ:oMojRdhOnX]>401_nX]>46ojRiiP03ojZ[eonY]N7oZKGQ00GoZKGQ1_nW^nP2oj^eh0SoYkcX
0_nW`>/5ojNmj@SoZ<7[00?oZKoYoj[1jonZ`N/01?nZ`N/6ojRojP03ojW0j_nV_n_oY[o[00KoY[o[
1onV_n`7ojO0j`KoZL3[0_nY`N/4ojO0j`04o`000?nW`>_oYl3[ojO0j`?oY[o/1?nV_n/8ojO0j`Oo
Z<3[5Oooool00ol0003oooooooooo`06ooooo`03oiRHV?lQ8B7ok^k^00oooooo000Jooooo`03o`00
0?oooooooooo00[oYko[1OnX`>/2ojS1j`OoYl3[4?nW_n/7ojS1j`OoYl3[3onW_n/00onX`NcoZ<7[
ojS1j`05ojS1j`GoZ<3[0_nW_n/7ojJnj`KoYko[3_nX`N`01?nW_n_o0000o`000?l00005ojNnjPKo
YkgY0_nW`>/9ojO1k0goYk_X0_nW_>P5ojR_g@SoZ;CQ0_nX^NH5ojZ[e`OoZKGQ0_nW^nP6oj^eh0Ko
YkcX00?o[;SRojNmjOnW_NT01_nW_NT6ojS1j`03ojJojonZ`N_oZ/7[00KoZ/7[0_nX_nX5ojW0jPSo
Y[o[1onV_n`7ojO0j`;oZL3[1_nY`N/4ojO0j`03o`000?nW`>_oYl3[00SoY[o[1onW`>/7ojS0jaGo
oooo00?o0000ooooooooool01oooool00omgMgOoIVIVooooo`0>ooooo`006Oooool00ol0003oYko[
ojNoj`0<ojNoj`03ojS0jonX`N_oZ<7[00CoZ<7[1onW`>/>ojNoj`WoZ<7[1OnW`>/?ojNoj`[oZ<7[
00?oZ<3[ojNojonW_n/01?nW_n/7ojJnj`;oYko[3_nX`N`01?nW_n_o0000o`000?l00003ojNoj`Ko
YkkZ0_nW_NT6ojO0j`KoYl7/00?oYkcXojNkj?nW^nP02onW^nP00onWZm[oZ:oMojR_g@06ojR_g@Ko
Z;CQ00?oZJ?@ojZ[eonZZmL01_nZZmL5ojVeh@03ojfXdon[]N3oZkGP00OoZkGP0_nW_>P5ojbhhPSo
YkgY0_nX`N/5ojJoj`KoZ/7[00?oZL7[ojW0j_nY`>X01_nY`>X6ojJoj`03ojNojonV_ncoY[o/00Ko
Y[o/1onW`>/8ojW1j`CoYl3[00?o0000ojO0jonW`>/02?nV_n/7ojO0j`OoZ<3[5Oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00gooooo000Iooooo`03o`000?nW_n_oYko[00_oYko[
0_nX`>/7ojS1j`GoYl3[3?nW_n/=ojS1j`03ojO0jonW_n_oYko[00goYko[3?nX`N/00onX`>_oYko[
ojNoj`06ojNoj`GoY[k[0_nW`>/=ojS1k003ojS1jol0003o000000OoYko[0onW_^X4ojJnj`OoYl3[
0_nW`N`5ojNlj0WoYk_X1OnWZmX7ojR_g@CoZ;CQ1?nYXm08ojZ[e`03ojVehOn]Z=?o[JSC00?o[JSC
1on[]N000on`[=Co[;SRojbhhP06ojbhhPKoYkgY0_nZ_>H7ojJoj`;oZ/7[1OnY`N/8ojW0jP;oY[o[
1OnW_n/8ojJok0OoYl3[1onY`N/4ojO0j`04o`000?nW`>_oYl3[ojO0j`OoY[o[1onW`>/6ojS0j`;o
Z<7[4oooool3o`0000Cooooo00Go0000okZj^_ooooooV9RHoa0@400?ooooo`003_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooooonW_n/02?nW_n/6ojS0j`OoZ<7[00?oYl3[ojNo
jonW_n/02_nW_n/2ojO0j`goZ<7[0_nW`>/<ojNoj`?oYl3[2OnX`N/5ojS0j`SoYko[00?oY[k[ojO0
jonW`>/01?nW`>/9ojS1k004ojS1jol0003o0000o`0000;oZ<7[1_nW_n/00onV_N[oY[k[ojJnj`06
ojJnj`GoYl3[00?oZ;kZojNlj?nW_>P01_nW_>P6ojNkj003ojJ[f_nWZm[oYj_J00GoYj_J1onX[md0
0onX]>7oZJ?@ojVSd005ojVSd0KoZZ_G00?o/ZK=ojfXdon]Z=<01On]Z=<4oj^eh0Co/:cD2?n/^>82
ojNmj@KoZ[cV1OnV_n/00onW_^[oZL7[ojW1j`06ojW1j`KoZL3Z0_nZ`>X7ojNoj`OoY[o/2?nW`>/7
ojW1j`CoYl3[00Co0000ojO0jonW`>_oYl3[1onV_n/7ojO0j`;oZ<3[1_nX`N/Dooooo`03o`000?oo
oooooooo00;ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00?ooooo`003_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Kooooo00?o0000ooooooooool02?nW_n/7ojS0j`GoZ<7[0onW`>/8ojNoj`KoYl3[
2OnX`N/6ojO0j`SoYko[1onW`>/7ojS1j`OoZ<3[1_nW_n/00onV_^_oYl3[ojO0j`06ojO0j`KoZ<7/
0ol00006ojS1j`;oYko[1OnV_NX8ojJnj`03ojO0jonX_^[oZ;kZ00?oZ;kZ2?nW_>P2ojNkj0GoYZ_J
1_nWZmX6ojR_g@03ojVPcOnYXm3oZJ?@00KoZJ?@1?nZZmL4ok:Vc@Oo[JSC00?oZkGPok2/e?n`[=@0
1On`[=@6ojbhhP03ok6bfOnZ_>KoZ[cV00OoZ[cV00?oY[o[ojNnj_nW_^X00onW_^X8ojW1j`;oZL3Z
1_nZ`>X7ojNoj`OoY[o/1_nW`>/00onW_n_oZL7[ojW1j`06ojW1j`CoYl3[00?o0000ojO0jonW`>/0
1onV_n/8ojO0j`SoZ<7[5?ooool00ol0003oooooooooo`0Eooooo`003_ooool01Ol@413ooooooooo
oooooooo410@00Kooooo0_l00002ooooo`SoYko[1onX`>/00onX`N_oYl3[ojO0j`05ojO0j`OoYko[
1onW`>/8ojS1j`OoYl3[2?nW_n/7ojO0j`OoZ<7[1onX`>/2ojNoj`GoY[k[2?nW`>/2ojS1k0?o0000
0onX`N`5ojS1j`;oYkkZ1onV_NX6ojJnj`03ojS0jonX_^[oZ;kZ00GoZ;kZ1_nW_>P00onU[]koYZ_J
ojJ[fP06ojJ[fPKoYj_J0_nX[md5ojVPc@SoZJ?@00?oZZ_Gok:VcOnbY/d01?nbY/d6ojfXd`03okV/
cOn`[=Co/:cD00Ko/:cD1?n/^>84ok6bf@OoZ[cV00?o[kcSojNnj_nW_^X01OnW_^X6ojW1j`03ojO0
jonZ`>[oZ/3Z00OoZ/3Z1_nW_n/8ojJok0;oYl3[1OnW_n/8ojW1j`CoYl3[00?o0000ojO0jonW`>/0
1onV_n/8ojO0j`OoZ<7[5Oooool00ol0003oooooooooo`0Dooooo`003_ooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooooooool00oooool7ojNoj`?oZ<3[1OnX`N/7ojO0j`OoYko[
1onW`>/8ojS1j`OoYl3[2?nW_n/5ojO0j`WoZ<7[1OnX`>/9ojJnj`KoYl3[0ol00007ojS1k003ojS1
jonW_^[oYkkZ00CoYkkZ1onV_NX2ojJnj`GoZ<3[1onX_^X2ojNlj0GoYJkN1onVZmX5ojN[fP03ojNN
cOnYX<goZJ3=00GoZJ3=1onYXm000onaY/go/ZK=ok:Vc@06ok:Vc@Co[JSC0oni[<d8ok2/e003ojbh
h_na/]Wo/K;I00Go/K;I1?nZ_>H4ojnlh`OoYkkZ0_nY`N/5ojO0j`OoZ/3Z00?oZ/7ZojNojonW_n/0
1OnW_n/7ojJok0SoYko[1onY`N/4ojO0j`03o`000?nW`>_oYl3[00SoY[o[2?nW`>/7ojS1jaCooooo
00?o0000ooooooooool05?ooool000kooooo00Go0000ooooooooooooooooo`000005ooooo`03o`00
0?oooooooooo00Gooooo1OnW_n/2ojS0j`SoZ<7[1OnW`>/9ojNoj`GoYl3[2_nX`N/3ojO0j`coYko[
00?oYl3[ojS1jonX`N/02onX`N/00onX`>_oY[k[ojJnj`0;ojJnj`;oYl3[0ol00009ojS1k003ojNo
jonW_^[oYkkZ00KoYkkZ1OnV_NX00onX`NcoZ<3[ojS0j`06ojS0j`GoZ;kZ00?oYK?RojF^g_nU[]h0
1_nU[]h7ojJ[fP03ojN[f_nWW/goYik=00?oYik=1onYX<d5ojVSd0?o/JK=1onbY/d3ojfXd`Go^Jc=
1_n`[=@00onl//oo/K;Iok6bf@07ok6bf@03ojZli_n__>?o[kcS00Co[kcS1_nW_^X2ojVoj@OoYl3[
1?nZ`>X4oj[1jPOoYko[1onV_n`8ojNoj`OoZL7[1?nW`>/00ol0003oYl3[ojO0j`08ojJoj`OoYl3[
1onX`N/Eooooo`03o`000?oooooooooo01?ooooo000>ooooo`05oa0@4?ooooooooooooooool@4100
1Oooool00ol0003oooooooooo`06ooooo`03ojNojonX`>_oZ<3[00CoZ<3[2?nX`N/00onW`>_oYko[
ojNoj`0;ojNoj`03ojO0jonX`N_oZ<7[00[oZ<7[0_nW`>/=ojNoj`03ojS0jonX`N_oZ<7[00_oZ<7[
0_nW`>/<ojJnj`?o00002OnX`N`5ojNoj`SoYkkZ00?oY[gZojS1k?nX`N`00onX`N`8ojS0j`03ojRn
j_nU/n;oYK?R00?oYK?R1onU[]h6ojJ[fP03oj>Lc_nWW/goYik=00GoYik=1_nYX<d3ojVSd0Go/JK=
2?nbY/d00on]Z=?o^Jc=okV/c@04okV/c@Co/:cD1?nl//l7ok6bf@03ok^feOn__>?o[kcS00Ko[kcS
0_nW_^X6ojVoj@OoYl3[00?oZ/3Zoj[1j_nZ`NX01?nZ`NX6ojNoj`03ojS0jonV_ncoY[o/00KoY[o/
1onW_n/8ojW1j`CoYl3[00?o0000ojO0jonW`>/02?nV_n/7ojO0j`OoZ<7[5Oooool00ol0003ooooo
ooooo`0Booooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_l00008ooooo`OoZ<3[
1_nX`N/2ojO0j`ooYko[2?nX`N/6ojO0j`WoYko[1OnX`>/9ojS1j`KoYl3[2?nV_^/3o`0000WoZ<7/
0_nX`N/7ojNoj`KoYkkZ0_nV_^/6ojS1k0KoZ<3[00?oY[SVojFch_nU/n801OnU/n87ojF^gP;oYZ_J
1OnSW<h6ojNNc@OoZJ3=00?oZJ?@ok6VcOnaY/d01OnaY/d6ok:Vc@03okV_d?ni[<go^Jc=00Ko^Jc=
00?o/:cDokbbconl//l01Onl//l4ok6bf@Co^kKE1_n__><2okBlh0SoZKoY0onW`>/4ojNoj`OoZ/7Z
0_nW_n/5ojS0j`SoY[o/1onW_n/7ojW1j`CoYl3[00Co0000ojO0jonW`>_oYl3[1onV_n/7ojO0j`Oo
Z<7[5Oooool00ol0003oooooooooo`0Booooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo00?o0000ooooooooool02?ooool7ojS0j`;oZ<7[1_nW`>/?ojNoj`OoZ<7[1onW`>/5ojNoj`;o
Y[o[1onX`>/8ojS1j`OoYl3[0onV_^/2ojJoj`;o00002OnX`N`6ojS1j`OoYko[0_nW_^X6ojJnj`Ko
Z<7/0_nX`>/5ojJhiPOoYK?R1OnU[]h00onOVm3oXic>oj>LcP05oj>LcPOoYik=1OnYX<d00on^Ym3o
/JK=ok6Vc@06ok6Vc@Co/ZK=1?ni[m06okV/c@03okjedOnl//oo_;;?00Oo_;;?00?o/K;Iok^feOnk
]]D01Onk]]D3ojnlh`Go];cP1_nY_nT00on[`>WoYko[ojNoj`06ojNoj`OoZ/7Z1onX`>/7ojJok0So
Yko[1onY`N/4ojO0j`04o`000?nW`>_oYl3[ojO0j`OoY[o[1onW`>/7ojS1jaGooooo00?o0000oooo
ooooool04Oooool001Sooooo00?o0000ooooooooool02Oooool5ojS0j`?oZ<7[1onW`>/?ojNoj`Oo
Z<7[1onW`>/00onW_n_oY[o[ojJoj`04ojJoj`OoZ<3[2?nX`N/5ojO0j`;oY[k[00CoY[o[o`000?l0
003o00000onV_n/8ojS1k0OoZ<7[1OnW_n/2ojJmjPSoY[k[0onX`N`4ojNmj@KoY[SV1onU/n800onU
[]koWi_@oinKd003oinKd0OoXic>1onWW/d00onYX<go[ZO@ojjWd003ojjWd0So/JK=00?o/ZK=okV_
d?ni[m001Oni[m04okV/c@?o_[GA1onl//l00oo3^M3o^kKEok^fe@07ok^fe@03ojnlhond_>3o];cP
00Go];cP0_nY_nT5oj_0j@SoYko[1onZ`NX7ojS0j`OoY[o/1onW_n/8ojW1j`CoYl3[00?o0000ojO0
jonW`>/01onV_n/6ojO0j`03ojS0jonX`N_oZ<7[00KoZ<7[5Oooool00ol0003oooooooooo`0@oooo
o`006?ooool00ol0003oooooooooo`0:ooooo`03ojS0jonX`N_oZ<7[00GoZ<7[1onW`>/=ojNoj`Wo
Z<7[1OnW`>/3ojNoj`KoY[o[1OnX`>/:ojS1j`04ojO0jonV_^_oY[k[ojJnj`?o00001onV_n/8ojS1
k0OoZ<7[00?oYko[ojJmj_nV_NX01?nV_NX6ojJnj`03ojS1jonW_NWoYkgY00KoYkgY1_nV^>H3ojFc
hP?oWIgD1_nOVm07oj>LcPKoYik=00?oZZODojjWd?n^Ym001On^Ym06ok6Vc@03okRifoni[m3o^Jo@
00Ko^Jo@0oni[<d4okjed@Ko_;;?0oo3^M07ok^fe@03olBmdond_>3o];cP00Go];cP00?o^/7Ooj_0
jOn[`>T01_n[`>T6ojNoj`03ojJok?nZ`N[oZ/7Z00KoZ/7Z1onX`>/7ojJok0OoYko[2?nY`N/4ojO0
j`03o`000?nW`>_oYl3[00OoY[o[0_nW`>/5ojS0j`OoZ<7[5Oooool2o`00017ooooo000Gooooo`?o
00003Oooool7ojS1j`OoYl3[2OnW_n/=ojS1j`03ojO0jonW_n_oYko[00GoYko[1_nV_n/00onX`>_o
Z<7[ojS1j`0:ojS1j`;oYl3[0ol00004ojJnj`GoY[o[0onX`N/7ojS1k0?oZ<7[1?nW_n/7ojJmjP;o
Y[k[1OnX`N/8ojNmj@?oY[SV0_nOY]/7oifMe0KoWi_@1_nSW<h4ojNNc@CoZZOD1_n^Ym04ok6Vc@Co
^;WK2?ni[m000oni[<go_[GAokjed@04okjed@Co_;;?1Oo3^M05ok^fe@?oa;gC1Ond_>03ok[1g`So
Zl3Y0_nW_n/5ojJok0OoZ/7Z2?nX`>/6ojJok0SoYko[1onY`N/4ojO0j`04o`000?nW`>_oYl3[ojO0
j`OoY[o[1onX`>/7ojS1ja?ooooo00?o0000ooooool000004Oooool001Oooooo00?o0000oooooooo
ool03_ooool5ojS1j`;oZ<3[1onW`>/8ojNoj`coZ<7[0_nW`>/8ojNoj`?oY[o[1?nX`>/8ojS1j`;o
Yl3[0ol000000onW`>_oY[k[ojJnj`05ojJnj`03ojJojonX`N_oZ<7[00GoZ<7[1OnX`N`2ojS1j`Oo
Yko[1OnV_NX2ojO0j`OoZ<7[1_nW_NT00onQ/^CoWjKKoinVf`04oinVf`KoWIgD1_nOVm07oj>LcP03
ojNNcOnZYmCoZZOD00CoZZOD1on^Ym000onaY/go^;WKokRif`04okRif`Oo^Jo@00?o_/WSokjedOnn
]M401Onn]M43okbbc`Ko`kW@0onk]]D6olBmd`?o];cP1Onj`Ml6oj_0j@;o[L;Y1onV_n`7oj[1jPSo
Z<3[1_nV_n`8ojNoj`OoZL7[1?nW`>/00ol0003oYl3[ojO0j`08ojJoj`KoZ<3[2?nX`N/Dooooo`03
o`000?oooooooooo00oooooo000Gooooo`03o`000?oooooooooo00oooooo00?oZ<7[ojS0jonX`>/0
1?nX`>/7ojO0j`SoYko[2?nX`N/6ojO0j`KoYko[00?oY[o[ojS0jonX`>/01_nX`>/6ojS1j`?o0000
1OnW`>/5ojJnj`;oYko[2?nX`N/00onX`NcoZ<7[ojS1j`04ojS1j`OoYko[00?oY[gZojO0jonW`>/0
1?nW`>/7ojS1j`;oYkgY1OnQ/^@5oinVf`OoWIgD1_nOVm03oj>LcP?oYJGF2?nZYm@5ojjWd003ok;@
konh^M_o^;WK00Ko^;WK1Oni[m03okk9h`Oo_[GA00?o_;;?ol>id?o3^M001_o3^M000onk]]Goa;gC
olBmd`06olBmd`03okBlh?nj`Moo^/7O00Go^/7O0_n[`>T6ojg2j@KoY[o/2?nZ`NX6ojS0j`03ojO0
jonV_ncoY[o/00GoY[o/1onW_n/8ojW1j`CoYl3[00?o0000ojO0jonW`>/02?nV_n/6ojS0j`SoZ<7[
5?ooool00ol0003oooooooooo`0>ooooo`005oooool00ol0003oooooooooo`0@ooooo`OoZ<3[1OnW
`>/:ojNoj`OoZ<7[1onW`>/2ojNoj`GoY[o[2?nX`>/2ojS1j`?o00000_nX`N/7ojO0j`03ojJnjonW
_n_oYko[00CoYko[3onX`N/5ojNoj`;oYKg[1onW`>/5ojS1j`03ojFjjOnQ/^CoXK;T00KoXK;T1OnO
Y]/6oifMe0GoWi_@00?oWZ3EojFUe_nUYMH01OnUYMH7ojZWe0?o[ZO@1?nbd>l7okRif`?o^Jo@1_nn
bN<5okjed@03ol75g?o3^M3o`kW@00Ko`kW@00?oa/7EolBmdoo4_M<01_o4_M<00oo9a=Go^/7Ook[1
g`05ok[1g`;o_/OQ2?n]`^T6ojJok0SoZ/7Z0_nX`>/5ojO0j`OoY[o/1onW_n/7ojW1j`GoYl3[00?o
0000ojO0jonW`>/01onV_n/7ojS0j`KoZ<7[00?oZ<3[ooooooooool04oooool00ol0003ooooooooo
o`0=ooooo`005oooool2o`0001;ooooo1onX`>/00onW`>_oYko[ojNoj`0:ojNoj`WoZ<7[1OnW`>/2
ojNoj`OoY[o[1_nX`>/3o`0000KoZ<7[0onW`>/4ojJnj`OoYko[3onX`N/00onW_n_oYKg[ojFmj`04
ojFmj`OoYl3[00?oZ<7[ojFjjOnU^^T00onU^^T7oj6bi0GoWjKK1onMWM@00onOVm3oWZ3EoijPe@03
oijPe@OoYJGF1onZYm@00on^Ym3o/]3_ok;@k`04ok;@k`Oo^;WK00?o^Jo@okk9honnbN<01OnnbN<3
okjed@Co`LGL1_o3^M03olK1e@Koa;gC0oo9a=D4ok[1g`Go_/OQ1_n]`^T00on]`n[oY[o/ojJok005
ojJok0KoZ/7Z00?oZ/;[ojO0jonW`>/01_nW`>/3ojJok0CoY[o[1onW_n/7ojW1j`CoYl3[00Co0000
ojO0jonW`>_oYl3[1onV_n/7ojS0j`;oZ<7[1OnX`>/Dooooo`03o`000?oooooooooo00gooooo000G
ooooo`03o`000?oooooooooo01;ooooo1OnX`>/3ojO0j`SoYko[3OnX`N/00onW`>_oYko[ojNoj`04
ojNoj`OoY[o[0_nX`>/00onX`N_o0000o`000008ojS1j`;oYl3[1onV_^/5ojNoj`ooZ<7[0_nV_n/7
ojFmj`OoYl3[1_nU^^T7oj6bi0GoWjKK0onMWM@3oiRJe0KoWZ3E1onUYMH6ojZWe0;oYMgk1_nbd>l6
okRif`;oU^Sj2?nnbN<00onn]M7o`LGLol75g004ol75g0?o`kW@1_o6`MD3olBmd`KobLCE00?o^/7O
okk7hOnnan401_nnan42ojg2j@Go[L?Z1onV_n`2oj[1jPGoZ/;[1onW`>/8ojJoj`GoYko[0_nX`>/7
ojW1j`CoYl3[00?o0000ojO0jonW_n/02?nV_n/3ojS0j`?oZ<7[2?nX`>/Dooooo`03o`000?oooooo
oooo00cooooo000Gooooo`03o`000?oooooooooo01?ooooo00?oZ<3[ojO0jonW`>/01OnW`>/7ojNo
j`coZ<7[0onW`>/6ojNoj`GoY[o[00CoYl3[o`000?l0003o00001onX`N/6ojO0j`OoY[k[00?oYko[
ojS1jonX`N/03OnX`N/6ojJoj`GoYKg[0_nX`>/7ojO0j`KoYK[Y0onQ/^@3oi6LfPGoTYSF1onHV]@6
oijPe@OoYJGF0_nZYm@6ojGMn`Ko/]3_0_nh^M/6oiKXnPKo_/WS00?oT>7mol75g?o1aM`01_o1aM`0
0oo3^M3oa/7EolK1e@06olK1e@03olBmdoo9a=GobLCE00GobLCE2?nnan400oo0cNGo[L?Zojg3jP05
ojg3jPKoY[o/0_nW_n/7oj[2j`OoYl3[2?nV_n/00onW_n_oZ<3[ojS0j`04ojS0j`OoZL7[0_nW`>/2
ojNoj`03o`000?nW_n_oYko[00KoY[o[00?oYko[ojS1jonX`N/01OnX`N/6ojS0j`03ojO0jooooooo
oooo01?ooooo00?o0000ooooooooool02oooool001Oooooo00?o0000ooooooooool05Oooool7ojO0
j`OoYko[2?nX`N/7ojO0j`KoYko[00?oY[o[ojO0jol000000_l00003ojO0j`OoZ<7[1onW`>/5ojJn
j`?oY[o[3_nX`N/7ojJoj`03ojFmjonX`>_oZ<3[00CoZ<3[1onW`>/3ojFjj@;oVjoU1onAW=X5oi:H
ePOoV9[D1OnNX=D6ojFUeP?oWmcl1onUgO/3ok;@k`05ojO5k_nC_OCoTkgdoi>mm?lNZ[@01_nFj?X2
okk9h`GoT>7m1_o1aM`00onfe_3oa/7EolK1e@06olK1e@03olK6f_o9a=GobLCE00GobLCE0_o=b]P6
okk7h@?o`<gU1on]`nX2ojJok0KoYko[1_nZ`^/8ojO0j`OoY[o[2?nX`>/3ojW1j`?oZ<7[1OnW_n/0
0ol0003oYko[ojNoj`02ojJoj`GoYko[1onX`N/2ojS0j`GoYl3[5?ooool00ol0003oooooooooo`0;
ooooo`005_ooool3o`0001Oooooo1OnW`>/9ojNoj`SoZ<7[1onW`>/3ojNoj`04ojJojol0003o0000
o`0000OoYl3[1onX`N/7ojO0j`03ojJnjonV_n_oY[o[00GoY[o[1OnX`N/00onY`N_oZ<7[ojS1j`06
ojS1j`GoY[o[00?oYKg[ojS0jonX`>/01_nX`>/5ojO0j`03oj:jj_nK[nGoVjoU00CoVjoU1_nAW=X5
oi:HePOoV9[D1_nNX=D2ojFUePOoWmcl0onUgO/00onnm^ooV^;mojO5kP05ojO5kPOoTkgd1OloW_@5
oi3Qo@?o`LGL1?nfe_06olK1e@?oa/KJ1Oo9a=D4olg:f0?o_/OQ1_o0cND5ojg3jP;oZl?[2?nW_n/6
oj[2j`SoYl3[1onV_n/6ojS0j`03ojW1jonX`N_oZ<7[00GoZ<7[1?nW_n/00ol0003oYko[ojJoj`07
ojNoj`OoZ<7[2?nW`>/Dooooo`03o`000?oooooooooo00[ooooo000Fooooo`03o`000?oooooooooo
01Sooooo00?oYl3[ojNojonW_n/02onW_n/8ojS1j`KoYl3[00CoY[o[o`000?l0003o00001?nV_n/5
ojO0j`WoZ<7[1OnW`>/:ojJoj`03ojS1jonY`N_oZL7[00?oZL7[2?nX`N/00onV_n_oYKg[ojFmj`03
ojFmj`SoZ<3[00?oYl3[oj:jj_nR^^X00onR^^X6oi^_i@KoTIcJ1OnBV=H7oiRJe0?oWZ3E1?nQboH6
oioLo0Co__K_0_nhdnh7ojO5kP?oTkgd1?nR_Nd5ogFZl`03o`1Le?l0@:Go4I[L00;oT>7m00?o`LGL
okKFl?nfe_001?nfe_03olK1e@Koa/KJ0oo9a=D6olg:f003okk7hOo0cNGo`<gU00Ko`<gU00?o[L?Z
oj_3jon[`n/01?n[`n/7ojNoj`OoZ/;[1_nW`>/9ojJoj`;oZ<3[1OnY`N/7ojS1j`;oYko[0_nV_n/0
0ol0003oY[o[ojJoj`07ojNoj`OoZ<7[1onW`>/Cooooo`?o00002oooool000Cooooo1?l000002?l@
413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^1_ooool00ol0003oooooooooo`0Jooooo`[oYko[
1?nX`>/7ojS1j`?oYl3[0ol00008ojJoj`03ojO0jonX`N_oZ<7[00_oZ<7[00?oYl3[ojJojonV_n/0
2_nV_n/00onX`N_oZL7[ojW1j`05ojW1j`KoZ<7[0_nV_n/6ojFmj`KoZ<3[0_nW`>/6oj:jjPKoVjoU
1OnAW=X5oi:HePKoV9[D0_nL[nD8oj7;mP03oioLo?nnm^oo__K_00?o__K_1Onhdnh5ojO5kP;oZ;o[
1onR_Nd5ogFZl`;o05cD00Co042Uo`1ad_lAV]co4I[L1_nfe_000oo6`MGoa/KJolK6fP06olK6fP03
olW4eOo=b]SocL[H00CocL[H0_o?dM/7ol3=i@03okc@jOn[`n_oZl?[00KoZl?[1onW_n/7oj[2j`;o
Yl3[3?nV_n/7ojW1j`KoZ<7[0_nW`>/4ojJoj`03o`000?nV_n_oYko[00OoYko[1onX`N/7ojO0j`oo
oooo0ol00002ooooo`03o`000?oooooooooo00Wooooo0006ooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo01_ooooo1_nW_n/8ojS0j`Go
Z<7[00CoZ<3[o`000?l0003o00001?nW`>/6ojJoj`;oYko[2_nX`N/4ojO0j`WoY[o[1OnX`N/7ojW1
j`;oZ<7[1_nV_n/6ojFmj`;oZ<3[1_nW`>/6oj:jjPKoVjoU1OnAW=X5oi:HeP;oV9[D1_nL[nD6oj7;
mP04ok_mh?oGnmkoeo_NomOkgP;o__K_1onhdnh00onWaNkoZ;o[ojRoj`04ojRoj`OoX[g]1OmeZ_<3
o`1Le0?o077B0onfe_02oiC6n@Soa/KJ0_o5bMd5olg:f0Cocm7K1?o0cND4okc@j@KoZl?[0_nY`^`7
ojNoj`?oZ/;[1?nY`^/>ojJoj`OoZL7[0_nX`N/6ojO0j`?oY[o[00?o0000ojJojonV_n/02?nW_n/6
ojS1j`SoYl3[2oooool3o`0000Gooooo00?o0000ooooooooool02Oooool000Kooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@00Kooooo0_l0000Mooooo`KoYko[2?nX`>/0
0onX`N_oZ<3[o`000002o`0000;oZ<3[1_nW`>/2ojJoj`KoYko[1onX`N/7ojO0j`SoY[o[1_nX`N/5
ojW1j`?oZ<7[1onV_n/3ojFmj`_oYl3[0onR^^X2oiN`j@KoQIWN1On9Um/6oi6Ng0SoW:oU0_nQboH2
og_Vf003ok_mh?oGnmkoeo_N00;oeo_N0ooDhn85okSCkP;o[L7X1onX_n/3oj:mk@?oX[SX1OmnX>P2
oc1We`;o05cD00?o2V[Mo`1ad_l0LM801OnDa_T6olK6fPCoaLWM0oo=b]P6oloAf`03ol3=iOnld>Wo
_=3Y00Go_=3Y0_n[`n/6ojW2k0GoYko[00?oZL3[ojW2jonY`^/01_nY`^/>ojJoj`OoZL7[2?nW`>/3
ojJoj`03o`000?nV_n_oY[o[00SoYko[1_nX`N/8ojO0j`Kooooo1?l00008ooooo`03o`000?oooooo
oooo00Wooooo0006ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000005
ooooo`;o00007oooool6ojNoj`KoZ<3[00?oZ<7[o`000?l000001_nX`>/3ojO0j`CoY[o[1onW_n/7
ojS1j`OoYl3[2?nV_n/6ojS1j`03ojW1jonX`N_oZ<7[00GoZ<7[1OnV_n/00onU_^_oYl3[ojO0j`0;
ojO0j`03oj:ljonG/>WoUk3Y00CoUk3Y1_n5VMh5ohVGf`KoTIkL1_nL[nD3ojk_m`;o^ogP1?oGnmh5
omCShP03okSCk_n]`NSo[L7X00Co[L7X1OnX_n/00onX^^OoX[SXoj:hj005oj:hj0GoOZ3X0ol`ImL0
1?l0G=Co2V[Mo`YZgOl0LM85oiC6n@?oa/KJ1oo5bMd00oo=b]Socm7KoloAf`04oloAf`?od=SO1Onl
d>T2okK<j`SoZL;/00?oYko[ojW0jonY`>/00onY`>/8ojW2j`koY[o[1onY`N/6ojO0j`03ojNojonV
_n_oY[o[00;oY[o[00?o0000ojJojonV_n/01_nW_n/8ojS1j`KoYl3[00CoYko[oooooooooooooooo
0ol0000=ooooo`03o`000?oooooooooo00Sooooo0006ooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo01oooooo1_nW_n/2ojS0j`04ojS1
jol0003o0000o`0000;oZ<7[1OnX`>/2ojO0j`OoY[o[1OnW_n/9ojS1j`GoYl3[2_nV_n/3ojS1j`?o
ZL7[2?nX`N/00onV_n_oYKk[ojFnj`03ojFnj`WoYl3[1OnR_>/6oiN`j@GoQIWN1_n9Um/6oi6Ng0?o
W:oU1?n^koL2ok_mh0?oeo_N1_oDhn800oo4a]co[L7Xojg1j006ojg1j003ojRojonX^^OoZ;[W00?o
Z;[W1onR^>P5ogjPj0Co<6OG0ol:J]d5oiC6n@03olK6f_o5bMgoaLWM00GoaLWM00?oa/cOoloAfoo?
dM/01?o?dM/5om3Hg`03okc@jOnfc>_o]/c[00Co]/c[1_nY`^`00onW`>coZL3[ojW0j`05ojW0j`Ko
ZL;[00?oZ<7/ojJojonV_n/02OnV_n/3ojNoj`SoZL7[0_nW`>/5ojNoj`CoY[o[00?o0000ojJojonV
_n/00_nW_n/<ojS1j`;oYl3[1OnW_n/2o`00013ooooo00?o0000ooooooooool02?ooool000Kooooo
00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000oooooooo
ool08?ooool5ojNoj`?o00001_nX`N/00onX`>_oYl3[ojO0j`04ojO0j`OoY[o[00?oYko[ojS1jonX
`N/02onX`N/00onW`>_oY[o[ojJoj`0:ojJoj`03ojS0jonY`N_oZL7[00GoZL7[1_nX`N/2ojO0j`Ko
YKk[1_nW`>/2ojS1j`KoX[c[1OnG/>T6ohFIgPGoRIOK1onAW]`00onL[nGo[^ogojk_m`02ojk_m`;o
^ogP0ooGnmh6omCShP?oa<KL1_n]`NP00on/]=koZ;[WojRji`05ojRji`OoX[SX1?mnX>P4oc1We`;o
>G3K00?o2V[Moh6`lon1/?<01?n1/?<6olG9g@?oa/cO0oo?dM/6om3Hg`03olkNi?nfc>_o]/c[00Ko
]/c[0_nY`^`5ojO0k0OoZL3[0_nY`^/5ojS1k0OoY[o[1onW_n/6ojW1j`03ojS1jonW_n_oYko[00Go
Yko[1?nV_n/00ol0003oY[o[ojJoj`0;ojS1j`?oYl3[2?nW_n/Aooooo`03o`000?oooooooooo00So
oooo0006ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
00008_ooool01?nW_n_o0000o`000?l00003ojNoj`SoZ<7[1_nW`>/8ojJoj`[oZ<7[0onX`>/9ojJo
j`GoZ<3[1onY`N/2ojS1j`KoYl3[1_nU_^/2ojO0j`KoZ<7[1_nR_>/5oiN`j@GoQIWN1_n9Um/3oi6N
g0KoX/;_00?o[^ogok_mh?o;k>`00ooNjm/2on;Kd0?oe>?R1_o4a]`2ojg1j0Go[;CN1onX^^L3oj:h
j0?oVIkG1?miQM<00omnX>So<6OGoc1We`02oc1We`?o>G3K1_n1/?<3olG9g@Koa/cO00?ocm7Kom3H
goo@f=l01?o@f=l3olkNi0Ko]/c[0_n`b>`6ojO0k0KoZL3[00?oZ/;[ojS1k?nX`N`01_nX`N`7ojJo
j`OoYko[0_nY`N/5ojS1j`OoYko[1?nV_n/00ol0003oY[o[ojJoj`07ojS1j`OoYl3[1onW_n/Aoooo
o`03o`000?oooooooooo00Sooooo0004ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`03o`000?oooooooooo01oooooo0ol00007ojNoj`SoZ<7[1_nW`>/8ojJo
j`KoZ<7[1onX`>/8ojJoj`KoZ<3[2?nY`N/7ojO0j`?oYKk[1?nV_^/7ojS1j`?oX[c[0_nH]N`5ogfL
iPCoOYKQ0_n5VMh3ohVGf`;oSJ7R2?nR`^l3ol_/k0Cog^_K0ooRfm000ooDhn;oa<KLolC6g004olC6
g003okb`c_n/]=ko[;CN00Ko[;CN1OnX^^L00onUY=CoVIkGoiVNe`05oiVNe`CoNHGC0_mCJld3oc1W
e`?o>G3K1_n1/?<00oo5bMgoa/cOolK<g`04olK<g`;ob]CQ1Oo@f=l5olkNi0;o]/c[1_n`b>`6ojO0
k0;oZL3[1OnZ`^/6ojS1k0;oYko[1_nV_n/6ojNoj`;oZ<3[1onX`N/6ojNoj`GoY[o[00?o0000ojJo
jonV_n/01onX`N/7ojO0j`OoYko[4?ooool00ol0003oooooooooo`08ooooo`005Oooool00ol0003o
ooooooooo`0Looooo`?o00001?ooool5ojNoj`?oZ<3[1onX`N/3ojO0j`CoYko[1onV_n/6ojS1j`Oo
Z<3[2?nV_n/6ojS0j`SoZL7[1OnW`>/00onU_^coY[k[ojJnj`06ojJnj`GoZ<7[00?oY;k/oiRek?nH
]N`01?nH]N`5ogfLiPGoOYKQ1_n=XN86oj;2k`?obnc/1?oNjm/4on;Kd003om[8b?o4a]coa<KL00?o
a<KL0onl/<h8ojbdgP03ojRjionUY=CoYJCD00?oYJCD1_nIW]L5ogV5d`?oDf_=00Co<6OGocU`foli
L=_o>G3K1on7YnX5olK<g`Cob]CQ0oo@f=l5olkNi0;oa=k/2?n`b>`3ojO0k0?oY[o[1onZ`^/2ojS1
k0KoYko[1_nV_n/2ojNoj`KoZ<3[1OnX`N/00onX`>_oYko[ojNoj`05ojNoj`GoY[o[00?o0000ojNo
jonX`N/01_nX`N/7ojO0j`SoYko[3oooool00ol0003oooooooooo`08ooooo`005Oooool00ol0003o
ooooooooo`0Iooooo`?o00002?ooool00onW_n_oZ<3[ojS0j`05ojS0j`GoZ<7[00?oYl3[ojNojonW
_n/01_nW_n/5ojJoj`;oYl3[1_nX`N/5ojS0j`?oYl3[1onV_n/3ojS0j`_oZL7[00?oYl3[ojFnk?nU
_^`00onU_^`8ojJnj`03ojS1jonT_^coY;k/00?oY;k/1_nH]N`5ogfLiPGoOYKQ1_n=XN83oj;2k`Co
bnc/1?oNjm/5on;Kd0;of/S80oo4a]`5okb`cPKo[;CN00?o[J3:ojFTe?nUY=@01OnUY=@5oiVNe`Go
NHGC1OmCJld3ocU`f`OoQjOZ0oo6c=l6ol[Dh@03om3Hgoo>g^Coc]kT00?oc]kT1?o4g^`6ok38k003
oj[4k?nV_n_oY[o[00GoY[o[1OnZ`^/2ojW2k0SoYko[0onV_n/3ojJnj`SoZ<3[00?oZ<7[ojS0jonX
`>/00onX`>/7ojNoj`;oY[o[0_nW_n/00ol0003oYko[ojNoj`07ojS1j`OoYl3[1onW_n/?ooooo`03
o`000?oooooooooo00Sooooo000Eooooo`03o`000?oooooooooo01Kooooo0ol0000=ooooo`OoZ<3[
00?oZ<7[ojO0jonW`>/00onW`>/8ojNoj`03ojJojonW`>_oYl3[00CoYl3[1_nX`N/00onX`>_oYl3[
ojO0j`05ojO0j`KoY[o[3OnY`N/2ojS1j`KoYKk/1_nV_^/2ojS1j`KoY;k/1OnH]N`6ogfLiPGoOYKQ
1_n=XN800onR`^oobnc/ol_/k002ol_/k0Cog^_K1OoRfm04om[8b003olC6g?nl/<ko_;3>00Go_;3>
0_n/]=h5ojfPbPKoYJCD1_nIW]L5ogV5d`CoDf_=0_mNO=P2ocU`f`OoQjOZ00?oa/cOol[DhOo:e>40
1?o:e>43oloOi0?oc]kT1_o4g^`2ok38k0GoZ/C/1onV_n/00onZ`^_oZL;/ojW2k004ojW2k0KoYko[
00?oY[o[ojJnjonV_^/01OnV_^/6ojS0j`03ojW1jonX`>_oZ<3[00GoZ<3[1OnW_n/2ojJoj`CoYko[
00?o0000ojNojonW_n/01onX`N/7ojO0j`OoYko[3oooool00ol0003oooooooooo`07ooooo`005?oo
ool2o`0001Gooooo0ol0000Aooooo`GoZ<3[0_nX`N/6ojO0j`KoYko[0_nV_n/7ojO0j`OoZ<7[1onW
`>/6ojJoj`WoZL7[1_nX`N/6ojFnk0;oY[k[1_nX`N/6ojBnk0GoV;G/1_mmW>H5ogjFh@?oSJ7R1OnZ
_NP00oo;k>cog^_Komk[f`03omk[f`Coh]_@1OoJb<P8okb`cPSo[J3:1_nUY=@5oiVNe`GoNHGC1OmC
Jld4oeilf0?oQjOZ1?nK[N@5ol[Dh@GocmoT00?oc]kTolCNk?o4g^`01?o4g^`2okG@kPOoZ/C/0onV
_n/3ojS1j`SoZL;/0_nW_n/5ojJoj`OoY[k[0_nX`>/5ojW1j`OoZ<3[00?oYko[ojJojonV_n/01?nV
_n/4ojNoj`03o`000?nX`N_oZ<7[00OoZ<7[1OnW`>/8ojNoj`oooooo00?o0000ooooooooool01ooo
ool001Cooooo00?o0000ooooooooool04_ooool2o`0001Gooooo00?oZ<3[ojS1jonX`N/01?nX`N/6
ojO0j`;oYko[1_nV_n/5ojO0j`WoZ<7[1OnW`>/2ojJok0KoY[o[2?nY`N/7ojS1j`?oYKk/1?nT_^`7
ojS1j`?oY;k/0onN^nd4oh6Zk`KoL9KW1On2WnD7ojZmj0Coc]OP0_oNjm/4on;Kd0Kof/S800?odKS1
okb`c_nl/<h01?nl/<h2ok^S`@Oo[J3:1OnUY=@00onPS;ooSh?2ohn3`P03ohn3`P?oNGO40_miQM<5
oe=[c@CoGWcH2?nK[N@3ol[Dh@GocmoT0_o@j>L4olCNk0Go]M3^1OnZa>`00onW_n_oZ<7[ojS1j`05
ojS1j`KoZL;/0_nX`N/6ojJoj`KoY[k[00?oYko[ojW1jonY`N/01_nY`N/3ojS0j`?oYko[2?nV_n/0
1OnW_n_oZ<7[ojS1jonX`N_o000000WoZ<7[00?oYl3[ojNojonW_n/02_nW_n/>ooooo`03o`000?oo
oooooooo00Oooooo000Dooooo`03o`000?oooooooooo00oooooo0ol0000Hooooo`OoZ<7[1onW`>/7
ojJoj`03ojO0jonX`N_oZ<7[00_oZ<7[00?oYl3[ojJok?nV_n`01?nV_n`6ojJoj`SoZL7[1OnX`N/2
ojO0k0OoY;k/1onX`N/6oijkk@CoPJ[_1_m`U^L5oh:Oi@GoZ[gX1Oo>en04omOBd`03on;Kd?oJb<So
f/S800Cof/S80ooA^<44okb`cP?o^j?12?n]X<X00onUY=CoX8booj2<_`03oj2<_`GoSh?21OmiMl@4
oe=[c@GoGWcH2?nK[N@00oo:e>7ocmoToloOi003oloOi0Cod>SW00?oa=k/okG@k_ned>h01_ned>h0
0onZa>coYko[ojNoj`03ojNoj`OoZ<7[0_nY`^`6ojS1j`KoY[o[0_nV_^/5ojNoj`KoZL7[00?oZ<7/
ojNojonW_n/01OnW_n/6ojJoj`03ojNojonX`N_oZ<7[00;oZ<7[00?o0000ojS1jonX`N/01?nX`N/3
ojO0j`_oYko[0onW`>/=ooooo`03o`000?oooooooooo00Oooooo000Dooooo`03o`000?oooooooooo
00cooooo0ol0000Looooo`GoZ<7[0onX`>/6ojO0j`SoY[o[2_nX`N/3ojS0j`OoY[o/0onV_n/4ojS0
j`OoZL7[00?oZ<7[ojO0k?nW`>`01?nW`>`7ojBnk0OoZ<7[1_nN^nd4oh6Zk`KoL9KW1On2WnD3ojZm
j0Goc]OP1OoGd]<6om[8b0CodKS10onl/<h5ok^S`@Ko[J3:00?o[YFloj2<_onPS;l01?nPS;l5ohn3
`PGoNGO40_m]Ml`3oe=[c@GoGWcH1_nK[N@2okK9j0?ocmoT1Oo@j>L3olWZk@Ko]M3^00?o[<K]ojNo
jonW_n/01OnW_n/5ojS1j`;oZ/?/2?nX`N/3ojJoj`?oY[k[1onW_n/2ojW1j`GoZ<7/1onW_n/2ojJo
j`GoYko[1?nX`N/00ol0003oZ<7[ojS1j`07ojO0j`OoYko[1onW`>/<ooooo`03o`000?oooooooooo
00Oooooo000Cooooo`?o00002_ooool3o`00023ooooo00?oZ<7[ojS0jonX`>/01OnX`>/6ojO0j`So
Y[o[1_nX`N/7ojS0j`SoY[o/1_nX`>/7ojW1j`OoYl3/0onT_^`4ojJoj`OoZ<7[0onN^nd2oiJhk`Co
JIg_00?oPJ[_og2Fiom`U^L00om`U^L6oh:Oi@03ojZmj?o>en3oc]OP00?oc]OP1_oGd]<00ooHb<[o
f/S8om[8b002om[8b0KodKS100?o_;3>ok^S`OnkXl401?nkXl44ojfPbPCo[YFl1OnPS;l5ohn3`PKo
NGO41?m]Ml`6oeilf0;oVjgT1_nfbNP00oo?gnCod>SWom3Xi`02om3Xi`KobN[]0_ned>h5ojc6k@Oo
Yko[00?oZ<7[oj[3k?nZ`n`01?nZ`n`6ojS1j`03ojNojonV_^_oY[k[00GoY[k[1OnW_n/2ojW1j`Oo
Z<7/3_nW_n/4ojS1j`03o`000?nX`N_oZ<7[00OoYl3[1onW_n/7ojO0j`_ooooo00?o0000oooooooo
ool01oooool001Cooooo00?o0000ooooooooool01_ooool3o`0002Gooooo1onX`>/3ojO0j`CoYko[
1onV_n/6ojS1j`OoZ<3[2?nV_n`6ojS0j`OoZL7[1OnW`>`2ojFok0OoY[o[1OnX`N/00onU_ncoU[S_
oiJhk`04oiJhk`GoJIg_0om/VN/2og2Fi`?oPYoU1?nG/NT3olkGh0Koem;C0ooHb<X3om[8b0KodKS1
2?nkXl400on]X<[o[YFlojjE_004ojjE_0KoX8bo1On?Pl85ogUga0CoKGO<1omlSmX6okK9j0Coa^;/
00?od>SWolWZkOo9j^d01?o9j^d2okKDk`Oo[<K]1_nW_n/8oj[3k0;oZ<7[1OnW_n/7ojJnj`03ojNo
jonY`N_oZL7[00CoZL7[1OnX`N`00onW`>_oYko[ojNoj`0;ojNoj`03ojS0jonX`N_oZ<7[00;oZ<7[
00?o0000ojS1jonX`N/01_nW`>/9ojNoj`?oYl3[0onX`N/;ooooo`03o`000?oooooooooo00Oooooo
000Dooooo`03o`000?oooooooooo00?ooooo0ol0000Yooooo`KoZ<3[2?nW_n/5ojJoj`;oYko[1_nX
`N/5ojS0j`?oYl3[1onV_n`3ojS0j`[oZL7[00?oYl3/ojFok?nU_n`01?nU_n`7ojJoj`03ojS1jonU
_ncoYKo/00?oYKo/1_nF^>l5ofVMk`CoK9W[2?nG/NT00oo>en3oem;ComOBd`04omOBd`Gof<S:00?o
f/S8om6h`OoA^<401OoA^<400oo</;oo^j?1ok^S`@05ok^S`@Oo[YFl1_nPS;l5ohn3`PKoNGO41?m]
Ml`7ogb?fP?o]/WX1Oo6h^`3olW`k@?obN[]1Onfe>l5ojc6k@;oYl3[1_nW_n/6oj[3k003ojS1k?nW
_n_oYko[00KoYko[0onV_^/3ojJoj`SoZL7[00?oZ<7/ojO0jonW`>/00onW`>/9ojNoj`GoZ<3[1?nX
`N/00ol0003oZ<7[ojS1j`02ojO0j`coYko[1onX`N/;ooooo`03o`000?oooooooooo00Kooooo000C
ooooo`04o`000?ooooooooooooooo`?o0000;Oooool6ojS0j`SoYko[00?oY[o[ojNojonW_n/01?nW
_n/6ojS1j`03ojS0jonW`>_oYl3[00GoYl3[1OnV_n`00onV_n_oZL7[ojW1j`0:ojW1j`?oZ<7[1_nU
_n`5ojJoj`;oYko[1_nU_n`6oiJhk`GoJIg_1?m/VN/6oiNaj@;o/l7T1OoGd]<6omS8bPOodKS10_o<
/;l6ok^S`@;o_J:m1on^UK`5oj2<_`GoSh?21_miMl@5ofegc0OoO8oJ00?o]/WXolKRk?o6h^`00oo6
h^`5olW`k@03olWZkOnfe>oo]]C_00Go]]C_00?o[<K]ojO0jonW`>/01?nW`>/6ojNoj`;oZ/?/1OnX
`N`6ojNoj`03ojJnjonV_n_oY[o[00GoY[o[1_nY`N/00onX`^coYl3[ojO0j`05ojO0j`GoYko[0_nV
_n/7ojS0j`?oZ<7[00?oZ<3[o`000?nX`>/03onW_n/7ojS1j`[ooooo00?o0000ooooooooool01_oo
ool001?ooooo1?l0000booooo`GoZ<3[1_nW_n/2ojJoj`OoYko[1_nX`N/8ojO0j`03ojJok?nV_n_o
Y[o[00?oY[o[2?nY`N/7ojS1j`KoYKo/00?oY[o[ojNojonW_n/01?nW_n/6ojFok0?oU[S_0on:]?83
oeVHl0;oJIg_1?m/VN/3oiNaj@Go/l7T0ooGd]<6omS8bP;odko71OoA^<44olb`_`Co^j?10onmX[d7
ojjE_0KoX8bo1On?Pl86ogUga0CoKGO<1_mlSmX3ojBlj`?oa^;/1Oo9l>d2olG^l0Ko]]C_00?o[<O]
ojO0jonW`>/01_nW`>/3ojNoj`?oZL?/1onX`N`2ojNoj`GoY[k[1onV_n/2ojW1j`GoZ<;/1onW`>/0
0onW_n_oY[o[ojJoj`04ojJoj`GoZ<3[0_nX`N/4ojS0j`03o`000?nX`>_oYko[00koYko[1_nX`N/:
ooooo`03o`000?oooooooooo00Kooooo000Cooooo`;o0000=Oooool5ojS0j`;oYko[1_nV_n/5ojNo
j`;oZ<3[1_nX`N/6ojO0j`;oY/3/1_nV_n/7ojW1j`SoZ<7[0onU_n`3ojBok0OoYko[0onU_n`3oj>n
k@KoR[Cb1?mIV?04offQl003ofbIjonG/NWo/l7T00Ko/l7T00?oem;ComS8b_oHb<X01?oHb<X4om>o
a`?odKS11Oo</;l3ok^S`@Co_J:m1on^UK`5oj2<_`03oj6?`OnAQ/CoTHK400?oTHK41_n6QLX4ohF?
eP03ofegc?mlSm[oO8oJ00OoY;c[00?oa^;/olW`kOo9l>d00_o9l>d5olG^l0;o]]C_1On/and6ojO0
j`03ojNojonY`ncoZL?/00GoZL?/1OnX`N`2ojNoj`KoY[k[1_nV_n/00onX`N_oZ<;/ojS2k006ojS2
k0?oYl3[0onW_n/8ojJoj`03ojS0jonX`N_oZ<7[00CoZ<7[0onX`>/00ol0003oZ<3[ojS0j`0=ojNo
j`SoZ<7[2Oooool00ol0003oooooooooo`06ooooo`001Ol00003ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02?ooool00ol0003oooooooooo`0cooooo`;oZ<3[1?nW`>/7ojJoj`03ojNojonX`>_oZ<3[
00CoZ<3[1_nX`N/2ojO0j`KoY/3/1_nV_n/7ojW1j`KoZ<7[0_nX`>/6ojBok0GoYko[0_nX`>/6oj>n
k@KoR[Cb1?mIV?05offQl0Ko/l7T0_o0a]l5omS8bPKodko700?odKS1olb`_oo</;l01Oo</;l00onk
Xl7o_J:mokfR_@04okfR_@Oo[YFl00?oX8booj6?`OnQSl400onQSl45oi66a0KoQXG:1On5SmH7ojBl
j`?o_^Wc00?obO3]olG^l?o5k_001?o5k_02ok;Bl0Oo[<O]0_nW`>/5ojNoj`OoZL?/00?oZ<7/ojNo
jonW_n/01?nW_n/6ojJnj`;oY[o[1OnX`N/6ojS2k003ojO0jonW_n_oYko[00GoYko[1_nV_n/00onW
_n_oZ<7[ojS1j`06ojS1j`?oZ<3[00?o0000ojO0jonW`>/02OnW_n/<ojS1j`Sooooo00?o0000oooo
ooooool01_ooool00005oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Wooooo00?o0000ooooooooool0<oooool6ojO0j`OoY[o[1onX`>/3ojS1j`CoZ<3[1onV`>`3
ojJoj`?oYko[1onY`N/2ojS1j`KoZ<3[1_nT_n`00onW_n_oZ<3[ojS0j`04ojS0j`KoXkk]1_n:]?84
oeVHl0GoKJ7`0onc`N@5ol36g`?of<S:1ooC_lL8olb`_`Oo_J:m1_n^UK`00on`Vl;oXHo1oj6?`@04
oj6?`@GoTHK41_n6QLX6ohF?ePCoY;c[1?nnjO<4okkdl@03olG^l?nbd_3o/];`00Co/];`1On/and9
ojNoj`?oZL?/0onX`N`8ojNoj`KoY[k[1onX`N/2ojS2k0GoYl3[1onW_n/2ojJoj`GoYko[1onX`N/4
ojO0j`03o`000?nW`>_oYl3[00KoYko[3OnX`N/00onW`>_oooooooooo`06ooooo`03o`000?oooooo
oooo00Kooooo00001?ooooooV9RHob4Q8Oo^k^h4ooooo`05oa0@4?ooooooooooooooool@41002_oo
ool00ol0003oooooooooo`0cooooo`KoYl3[1onV_n/>ojS0j`GoY/3/0_nV_n`6ojNoj`SoZL7[1onX
`>/6ojBok0OoZ<3[0onS_^d3oj6nk@KoPK;d0om=V?800omIV?3oKJ7`offQl003offQl003ok?1i?o0
a]oo`<KO00Go`<KO00?of<S:om>oaooC_lL01OoC_lL2oljlbPKoc;2o0_o7/<@6okfR_@Co[YFl0on`
Vl86oj6?`@KoTHK41_n6QLX6ohF?eP03ojBljonnjO?o_^Wc00;o_^Wc1Onnm?400onki_?o/];`ok;B
l006ok;Bl003ojc7kOnW_n_oYko[00WoYko[0_nY`n`6ojS1k0KoYko[2?nV_^/5ojS1j`;oZL;/1onW
`>/>ojNoj`OoZ<7[1?nW`>/00ol0003oYl3[ojO0j`06ojNoj`WoZ<7[1OnW`>/7ooooo`03o`000?oo
oooooooo00Kooooo0002ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00
000;ooooo`;o0000=?ooool6ojO0j`OoY[o[3_nX`>/00onV`>coY[o/ojJok004ojJok0KoYko[2?nY
`N/5ojS0j`;oYl3[1_nT_n`7ojS0j`KoXKk]1_n1/_@4odfHlPGoKj[e1_o0a]l00oo1bN7odko7om>o
a`05om>oa`Coc[c:1?o</;l3olN`a0Oo_J:m00?o[YFlok2K`_n`Vl801?n`Vl86oj6?`@GoTHK41_n6
QLX5ohF?ePCoZM7e00?o_^WcokkdlOnnm?400_nnm?44ok_Vl`Ko/];`00?oZ/C/ojNojonW_n/01onW
_n/6ojW3k0KoZ<7/0_nW_n/<ojJnj`03ojS1jonY`^coZL;/00CoZL;/1OnW`>/>ojNoj`03ojS1k?nX
`N_oZ<7[00KoZ<7[0onW`>/00ol0003oYko[ojNoj`07ojNoj`KoZ<7[2?nW`>/7ooooo`03o`000?oo
oooooooo00Gooooo0003ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`00
000=ooooo`03o`000?oooooooooo03;ooooo1_nW`>/8ojJoj`goZ<3[1onV_n`3ojNoj`CoYl3[1onY
`N/00onX`>_oYl3[ojO0j`04ojO0j`KoY;o/1onX`>/6oj6nk@KoPK;d1?m=V?85ofnZm@?o`<KO1?o1
bN45om>oa`Goc[c:0oo</;l5olN`a0Go_J:m00?o^jW7ok2K`_n`Vl801On`Vl86oj6?`@GoTHK41on6
QLX00on5SmKoZM7eojWAm@04ojWAm@?o/O?d00?o__Caok_Vlonki_<01Onki_<2ok;Bl0GoZ/C/1_nW
_n/00onW`NcoZL?/ojW3k006ojW3k0?oZ<7/0onW_n/:ojJnj`?oZ<7/2?nY`^`00onW`>_oYko[ojNo
j`0<ojNoj`GoZ<7/1_nX`N/00onW`>_oYko[ojNoj`02ojNoj`03o`000?nW_n_oYko[00GoYko[0_nX
`>/6ojS1j`OoYl3[1oooool00ol0003oooooooooo`05ooooo`001?ooool01Ol0003ooooooooooooo
oooo410@00?ooooo00?o410@ooooooooool03?ooool00ol0003oooooooooo`0booooo`KoYl3[2?nV
_n/5ojS0j`;oZL3[1_nX`>/8ojJok0KoYl3[1OnY`N/2ojW0j`OoYl3[1_nT_n`7ojS0j`OoXKk]1_n0
/oD2od>Il`03odfHl_m_Z_GoKj[e00?oKj[e00?o`<KOol79hOo1bN401?o1bN43om>oa`Ooc[c:00?o
c;2oolN`a?o7/<@01?o7/<@4okfR_@?o^jW71_n`Vl86oj6?`@KoTHK40on6QLX4oiJ^i`CoZM7e1?na
lo@4ok;bm@?o^nKc1?n]b^l6oj[4k0;oYko[1OnW`N`6ojW3k003ojS0jonW_n_oYko[00GoYko[1OnV
_^/2ojNoj`KoZ<7/1_nY`^`00onW`>_oYko[ojNoj`0<ojNoj`OoZ<7/0_nX`N/5ojO0j`CoYko[00Co
0000ojNojonW_n_oYko[1_nX`>/6ojS1j`OoYl3[1_ooool00ol0003oooooooooo`05ooooo`0000Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03oooool00ol0003o
ooooooooo`0booooo`OoYl3[1onV_n/00onX`>_oZL3[ojW0j`04ojW0j`KoZ<3[2?nV_n`6ojO0j`03
ojW1jonY`>_oZL3[00CoZL3[1onW`>/6ojBok0GoZ<3[0_nX`N/7oj6nk@KoP;?e1?m3VO<4ofJ^n@Oo
`LWQ00?odko7oljlb_o>_<X01Oo>_<X00oo:bm[oak34olN`a005olN`a0?o_J:m1?nkZLL7ok2K`PKo
XHo10onAQ/@3oi^Tg0OoUZkW00?oZM7eok7cm?nalo@00_nalo@5ok;bm@;o[m;b1on]b^l3oj[4k0?o
Yko[1onW`N`2ojW3k0GoZ<3[1onW_n/00onV_^_oYko[ojNoj`04ojNoj`KoZ<7/0_nY`^`5ojO0j`ko
Yko[1OnX`N`00onX`N_oYl3[ojO0j`06ojO0j`CoYko[00?o0000ojNojonX`>/01onX`>/3ojS1j`;o
Z<3[2?nW`>/5ooooo`03o`000?oooooooooo00Gooooo00001OnHV9So410@o`000?lQ8B7oc<c<00?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0@ooooo`;o0000=?ooool6ojO0j`GoY[o[0_nW_n/7ojW0
j`KoZ<3[2?nV_n`3ojO0j`?oZ<3[1onY`>/7ojO0j`KoY;o/00?oZ<3[ojS1jonX`N/01?nX`N/7oj6n
k@?oP;?e0on8]o@3od2Lm003od>IlomV[_WoIZki00;oIZki1Oo1bN42okC?k@Koc[c:0oo:bmX7olN`
a003okfR_OnkZLOo^jW700Co^jW71_n`Vl83oj6?`@?oYZWI1onKY=`5oiJ^i`CoY>ci00?o/O?dok;b
mOnbl_D00_nbl_D5ojoBlPGo[L[_0_nX`>/6ojNoj`GoYl7/0_nY`^`7ojS0j`?oYko[0onV_^/8ojNo
j`?oZ<7/0onX`^`7ojO0j`koYko[00?oZ<7/ojS1jonX`N/00onX`N/6ojO0j`GoYko[00?o0000ojNo
jonW_n/01_nX`>/00onX`N_oZ<3[ojS0j`04ojS0j`KoYl3[00?oYko[ooooooooool00oooool00ol0
003oooooooooo`05ooooo`007oooool00ol0003oooooooooo`0booooo`KoYl3[00?oY[o[ojNojonW
_n/01?nW_n/5ojW0j`SoZ<3[1_nV_n`2ojFok0KoZ<3[1onY`>/7ojO0j`?oY;o/0onT_nd7ojS1j`?o
XKk]1?nS_^d6ohRgm0Co@9cd0om@ZoT00omV[_Wo`LWQokC?k@05okC?k@?oc[c:1_o:bmX5olN`a003
olG5f_nkZLOo^jW700Go^jW71On`Vl800onb^MkoYZWIojJYf@05ojJYf@OoVjCL00?oUZkWojC/nOnT
k?T01?nTk?T4oikalP03ok;bmOn_d_;o[m;b00Go[m;b00?o[L[_ojS0jonX`>/01?nX`>/6ojNoj`03
ojO1k?nY`^coZL;/00CoZL;/1OnX`>/00onW_^_oY[k[ojJnj`05ojJnj`KoYko[2?nX`^`5ojO0j`co
Yko[0onX`N`7ojS1j`;oYl3[2OnW_n/00ol0003oYko[ojNoj`02ojS0j`GoZ<7[1_nX`>/2ojO0j`Go
Yko[1?ooool00ol0003oooooooooo`05ooooo`008?ooool00ol0003oooooooooo`0booooo`?oYl3[
0onV_n`7ojNoj`03ojW0jonX`>_oZ<3[00[oZ<3[0_nV_n`6ojFok0KoZ<3[1onY`>/7ojO0j`KoY;o]
1onX`N/7oj>nk@KoR;Od1?m0W?@5oe2[n@Ko]<o]00?oc[c:ol[;f_o:bmX01Oo:bmX3olN`a0CoaLGJ
1_nkZLL3ok2K`PCo/[WN1onVZMT5oi^Tg0CoVnGl00?oY>cioikal_nNlO801?nNlO82ojoJmPKo[m;b
00?oZL;/ojS0jonX`>/01_nX`>/3ojNoj`?oZ<?]1onY`^`00onX`>_oYkk[ojNnj`03ojNnj`OoY[k[
0_nW_n/<ojS2k003ojO0jonW_n_oYko[00WoYko[00?oYl3[ojS1k?nX`N`01OnX`N`5ojS1j`;oYl3[
2onW_n/00ol0003oYl3[ojS1j`07ojS1j`?oZ<3[0_nW`>/8ojNoj`?ooooo00?o0000ooooooooool0
1Oooool0027ooooo00?o0000ooooooooool0<_ooool6ojJok0GoYko[0onW`>/9ojS0j`CoYl3[1onU
_n`6ojS0j`OoZL3[1onW`>/6ojBok@OoZ<7[1onS_^d3ohRgm0CoU;_b0_mCYOL00om0W?CoD:_ioe2[
n@03oe2[n@?o]<o]0on6cOh8ol[;fP03olN`a?o5aM[oaLGJ00CoaLGJ1_nkZLL00on`Vl;o/[WNok:i
gP04ok:igPOoYZWI00?oVjCLoi_Uo?nKiO`01?nKiO`3oh[Zl0;oW_7b1_n_f_H2ojoBlPGoZL;/1_nX
`>/00onW`NcoZ<?]ojS3k@05ojS3k@GoZL;/00?oYko[ojNnjonW_^/01OnW_^/5ojJnj`;oYko[2_nX
`^`3ojO0j`WoYko[1OnW`>/7ojS1k003ojS1jonW`>_oYl3[00CoYl3[2?nW_n/2ojO0j`03o`000?nW
`>_oYl3[00KoZ<7[00?oZ<3[ojO0jonW`>/01?nW`>/7ojNoj`Cooooo00?o0000ooooooooool01?oo
ool002;ooooo00?o0000ooooooooool0<_ooool6ojJok003ojNojonW`>_oYl3[00GoYl3[1onX`>/6
ojO0j`OoYKo/1_nX`>/5ojW0j`;oZL3Z1onW`>/6ojBok@OoZ<7[0onS_^d4ojFok0OoU;_b1OmCYOL4
ocBSl`GoQ/gn1_o:bmX00onTfo_oaLGJolG5fP05olG5fPGo^jW70_nhe>h6ok:igPKoYZWI0onCh_d2
oi_Uo0GoR^[`1?nXg_X3ojoJmP?oZLC]1onY`^`2ojS0j`GoYl7/1onX`nd00onY`^coYko[ojNoj`03
ojNoj`OoYkk[00?oY[k[ojNojonW_n/01?nW_n/5ojS2k0;oZ<7/1_nW`>/7ojNoj`OoYl3[0onX`N`3
ojS1j`SoYl3[1_nW_n/4ojO0j`03o`000?nW`>_oYl3[00;oZ<7[1OnX`>/6ojO0j`OoYko[0oooool0
0ol0003oooooooooo`04ooooo`008oooool2o`0003?ooooo1onV_n`7ojO0j`OoZ<3[1_nW`>/7ojFo
k0KoZ<3[00?oZL3[ojW0j_nY`>X01?nY`>X7ojO0j`KoY;o]1OnX`N/3ojO1k0KoYKo/1OnD^o82oifm
k`KoMkCh0_lcXo800oldXo?oQ/gnohK=oP03ohK=oP;ob/_J1OnTfo/7olG5fP03ok^Yaonhe>ko^=C^
00Co^=C^1_nb^Mh2ojJYf@GoTn;m1?mfhNh00on:j_3oZ=kjojSNnP04ojSNnP;oZ<K_1_nYa>d5ojW2
k0;oYko[1onW`N`3ojS3k@?oZ<7[1onW_n/7ojNnj`OoYko[00?oZ<;/ojS1k?nX`N`01?nX`N`6ojO0
j`OoYko[1OnW`>/2ojS1k0KoZ<7[1_nW`>/8ojNoj`?oYl3[00?oZ<7[o`000?nX`N/02?nX`>/3ojO0
j`[oYko[0_ooool00ol0003oooooooooo`04ooooo`009Oooool00ol0003oooooooooo`0booooo`Ko
Y[o/1OnW`>/9ojS0j`KoYl3[1onU_n`6ojS0j`OoZL3Z1onW`>/6ojBok@03ojS1jonW`NcoYl7/00Go
Yl7/1_nU_n`00onD^o;oWKg_oifmk`04oifmk`KoMkCh1OlcXo84odFfmPGoY=_k1_o5aMX3oi3MoPKo
^=C^0onb^Mh5ohCPn`03oi?RoOmfhNkoM^7^00?oM^7^1OnNfo`00onXg_[oZ<K_ojS6k`04ojS6k`Ko
ZLC]00?oZL;/ojNojonW_n/01?nW_n/5ojO1k0;oZ<;/1_nX`N/5ojNoj`;oYkkZ1onW_^/3ojNoj`?o
Z<;/2?nX`N`3ojO0j`[oYko[00?oYl3[ojS1k?nX`N`01?nX`N`6ojS1j`;oYl3[2_nW_n/2ojO0j`Co
Z<7[00?o0000ojS1jonX`>/01OnX`>/00onW`>_oYko[ojNoj`0:ojNoj`04ojS0joooooooooooo`00
00Kooooo000Vooooo`03o`000?oooooooooo03;ooooo1_nV_n`00onW`>_oZ<3[ojS0j`0;ojS0j`Ko
Yl3[1onU_n`6ojS0j`OoZL3Z1onW`>/3ojBok@?oY;o/2?nW`N`3ojFok0CoZ<3[1_nM_Nl3ogNdn0Co
U[gb1OmR/?X2obfZk003odFfm_nTfo_oY=_k00?oY=_k0_o5aMX7oi3MoP?o^=C^1OmVeO<3ohCPn`Co
HmK/0_nGdod6oikKo003ojO5konXa^ooZ<K_00KoZ<K_0onYa>d:ojNoj`03ojO1k?nX`^coZ<;/00Co
Z<;/1_nX`N/00onW_n_oYkkZojNnjP04ojNnjPGoYkk[0_nW`N`6ojS2k0KoZ<7/3OnW_n/00onW`>_o
Z<7/ojS1k006ojS1k0?oZ<7[0_nW`>/9ojNoj`KoYl3[0onX`N/00ol0003oZ<7[ojS1j`02ojS0j`Go
Yl3[2?nW_n/5ojS0j`03ooooool0003ooooo00Gooooo000Wooooo`03o`000?oooooooooo03;ooooo
1_nV_n`>ojS0j`KoYl3[1onU_n`6ojS0j`OoZL3Z1OnW`>/2ojS0j`KoY;o/1_nW`N`2ojK1k0OoZ<3[
0onM_Nl3ojBnk0OoU[gb1OmR/?X5obfZk0GoB/7b0on@gOh5od;1j@?oI]Gc1OmKco42of?Fk0KoUm?m
0_nNfo`5ojO5k`KoZ<K_00?oYkoZojNojonW_n/02_nW_n/00onX`ngoZ<;/ojS2k006ojS2k0?oZ<7[
2_nW_^X00onW_^_oYl7/ojO1k004ojO1k0KoZ<;/0_nX`N`=ojNoj`GoYl3[1_nX`N`00onX`>_oYl3[
ojO0j`04ojO0j`OoYko[2?nW`>/3ojS1j`03o`000?nX`>_oYl3[00OoYl3[1onW_n/6ojS0j`03o`00
0?oooooooooo00Cooooo000Xooooo`;o0000<oooool6ojJok0koZ<3[1_nW`>/7ojFok0OoZ<3[1_nY
`>X00onW`>_oZ<3[ojS0j`04ojS0j`KoY;o/0_nW`N`6ojK1k0GoZ<3[0_nX`^`6ojBnk0GoU[gb0_nR
_^d6oi:nm0KoI[Ol0olm]o04oh31o0KoJLWn0omKco45oiO:n@?oUm?m1?nU`nl6ojO5k`;oZ<K_1OnW
_nX8ojNoj`GoZ<?]1_nX`^`00onW_n_oYkkZojNnjP0:ojNnjP03ojNojonW`NcoYl7/00KoYl7/0onX
`^`3ojS0j`koYko[1_nW`>/2ojS1k0GoZ<3[1_nW`>/7ojNoj`KoYl3[00?oZ<7[ojS0jonX`>/00_nX
`>/00ol0003oZ<3[ojO0j`05ojO0j`WoYko[0onX`>/2ooooo`03o`000?oooooooooo00Cooooo000Z
ooooo`03o`000?oooooooooo037ooooo1_nV_n`>ojS0j`KoYl3[1onU_n`7ojS0j`KoZL3Z1onX`>/3
ojBok0?oYKo/2?nV`N`00onX`>_oZ<;/ojS2k004ojS2k0KoY;k/00?oU[gboj:nkOnR_^d01?nR_^d6
oi:nm0?oI[Ol1?nH`?<6oh31o0?oJLWn1?nLaO@5oiO:n@;oYL7]1onU`nl3ojO5k`[oYkoZ0onW_n/:
ojS3k@;oZ<;/1OnW_n/8ojNnjPGoYko[1_nW`N`00onX`NcoZ<3[ojS0j`05ojS0j`koYko[0onW`>/2
ojS1k0SoZ<3[0onW`>/:ojNoj`;oYl3[1OnX`N/4ojS0j`04o`000?nX`>_oYl3[ojO0j`_oYko[1ooo
ool00ol0003oooooooooo`03ooooo`00:oooool00ol0003oooooooooo`0aooooo`KoY[o/3_nX`>/6
ojO0j`OoYKo/1OnX`>/2ojO0j`KoZL3Z1OnX`>/2ojS0jPKoYKo/1_nV`N`2ojC0k@OoZ<;/0onT_^`3
ojS0j`OoX[k]0onB__@4oj:nk@KoV<3c0on0`O`4oj31l0KoW<Gd00?oUl[iojG1kOnU`Nd01?nU`Nd5
ojG3k`;oYko[2onW_nX2ojO3k@[oZ<?]2_nW_n/6ojNnjPOoYko[0_nW`N`5ojS1k0OoZ<3[3?nW_n/7
ojS1k0KoZ<3[3OnW_n/9ojS1j`?oZ<3[00?o0000ojO0jonW_n/02OnW_n/:ooooo`03o`000?oooooo
oooo00?ooooo000/ooooo`03o`000?oooooooooo037ooooo1_nV_n`>ojS0j`KoYl3[1onU_n`00onX
`>_oYl3[ojO0j`04ojO0j`KoZL3Z00?oZ<3[ojS0j_nX`>X01?nX`>X6ojFok0;oY/7/1_nT`>d5ojS2
k0;oY/7]1_nX`>/5oj:nk@;oYko[1onR_^d3oiS0l`?oY;k/1onP`O03oic5m0?oY[o/1onU`Nd00onU
`nooYko[ojNoj`04ojNoj`OoYkoZ1_nW`nd5ojS3k@;oZ<3[2onW_n/8ojNnjPGoYko[0_nX`^`7ojS1
k0?oZ<3[3?nW_n/;ojS1k0;oZ<3[3OnW_n/;ojS1j`GoYl3[00?o0000ojO0jonW_n/01OnW_n/=oooo
o`03o`000?oooooooooo00?ooooo000]ooooo`;o0000<_ooool6ojJok0koZ<3[1_nW`>/5ojFok0;o
Y[o/1onW`>/6ojW0jPOoZ<3Z0onU_n`4ojNoj`OoY<3]00?oZ<;/ojK1kOnV`Nd01?nV`Nd6ojS0j`03
oj:nkOnW_n_oYko[00CoYko[1OnR_^d00onW`>_oY;k/ojBnk005ojBnk0GoX<7`0_nW_n/6ojJok0Go
YL7]0_nX`>/7ojNoj`?oYkoZ2_nW`nd00onX`ngoZ<3[ojS0j`04ojS0j`OoYko[3?nW_^X00onW_n_o
Z<;/ojS2k004ojS2k0GoZ<7/3onW_n/:ojS1k0?oYl3[3_nW_n/8ojS1j`WoYl3[00Co0000ojO0jonW
_n_oYko[4?ooool00ol0003oooooooooo`03ooooo`00;oooool00ol0003oooooooooo`0`ooooo`Oo
Y[o/3OnX`>/6ojO0j`03ojFok?nV_ncoY[o/00CoY[o/1OnW`>/2ojO0k0KoZL3Z1OnX`>X2ojW0jPOo
Yko[0onT`>d3ojFok0SoY/7]0onX`>/2ojO2k0SoYko[00?oX[k]ojO0jonW`>/00onW`>/7ojBnk003
oj31l?nW_n_oYko[00CoYko[1_nV_n`00onU`NgoZ<3[ojS0j`04ojS0j`GoYko[3?nW`nd:ojS0j`?o
Yko[3OnW_^X3ojS1k0OoZ<;/00?oZ<7/ojNojonW_n/04OnW_n/6ojS1k0OoYl3[3_nW_n/5ojS1j`_o
Yl3[00?o0000ooooooooool04Oooool00ol0003oooooooooo`03ooooo`00<?ooool00ol0003ooooo
ooooo`0aooooo`KoY[o/3OnX`>/3ojO0j`CoZ<3[1_nV_n`00onW`>_oYl3/ojO0k004ojO0k0KoZL3Z
00?oZ<3ZojW0j_nY`>X01?nY`>X5ojNoj`;oZ;oZ1_nU_n`6ojK1k@03ojFokOnW`^coYl;/00CoYl;/
1_nW_n/00onX`^goYl3[ojO0j`05ojO0j`?oY;k/0onX`N`8ojNoj`?oY[o/0onX`N`7ojS0j`03ojNo
jonW`ngoYl?]00WoYl?]00?oYl3[ojS0jonX`>/02_nX`>/=ojNnjP03ojO0k?nX`NcoZ<7/00GoZ<7/
0onX`^`3ojS0jaGoYko[1_nX`N`7ojO0j`coYko[00?oZ<7/ojS1jonX`N/01?nX`N/6ojO0j`Gooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`03ooooo`00<Oooool00ol0003ooooooooo
o`0aooooo`OoY[o/5?nX`>/6ojJok0KoYl3/0onY`>X3ojW1j`OoZL3Z00?oYko[ojRoj_nX_nX01?nX
_nX6ojFok0;oY/7]1OnU_nd6ojO2k0;oYko[1OnX`^d5ojO0j`;oYl;]1_nX`N`6ojNoj`03ojO3kOnX
`NcoZ<7/00GoZ<7/0onX`>/3ojO2k@WoYl?]1OnW`>/8ojS0j`goYkkZ1OnW`>`7ojS1k0KoZ<3[4OnW
_n/:ojS1k0?oYl3[3?nW_n/5ojS1k0KoZ<7[0_nW`>/9ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool00oooool003;ooooo0_l0000booooo`OoY[o/5?nX`>/6ojJok0CoYl3/0onV`>`5
ojW1j`OoZL3Z1onX_nX3ojFok0CoYko[1_nU_nd3ojO2k0CoYL3]1_nX`^d00onW`>_oYl;]ojO2k@04
ojO2k@KoZ<7/0_nW_n/5ojO3k@GoZ<7/0_nV`Nd6ojO2k@GoYl?]2OnW`>/3ojS0j`goYkkZ1?nW`>/6
ojO0k0OoZ<7/1_nX`>/<ojNoj`;oYl7/2onX`N`2ojO0j`_oYko[00?oYl3[ojS1k?nX`N`01_nX`N`3
ojS1j`kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`00=?ooool00ol0
003oooooooooo`0`ooooo`OoY[o/0onX`>/3ojO0j`koZ<3[1_nV_n`00onW`>coY/3/ojK0k004ojK0
k0GoZL7[1onY`>X5ojRojP;oZKoZ1onW_n/3ojFok@?oY[o[1onU`>d3ojS2k@?oYL3]1onW`^d3ojS1
k0CoY/;]1_nW`nd00onX`NcoY/7]ojK1k@04ojK1k@KoYl;]00?oYl?]ojO0jonW`>/02OnW`>/=ojNn
jP;oYko[1onW`>/3ojO0k0[oZ<7/0onX`>/;ojNoj`KoYl7/1onX`N`6ojO0j`OoYko[1OnW`>/6ojS1
k1;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`00=Oooool00ol0003o
ooooooooo`0`ooooo`OoY[o/1_nW`>/5ojS0j`;oZL3[1onX`>/3ojJok0?oY[o[1onV`>`2ojW1j`Co
Z<7/1_nY`>X00onX_n[oZKoZojVojP04ojVojPGoYko[0_nX_nX6ojJoj`GoYL3]0_nV_n/6ojG0k@Go
Yl;]0_nV`>`7ojK2k@?oYl?]0onV`>`7ojK1k@?oYl;]1?nW_n/7ojO0j`goYkkZ1_nW_n/5ojO0j`03
ojS2k?nX`NcoZ<7/00[oZ<7/3OnW_n/00onW`>_oYl7/ojO1k006ojO1k0?oZ<7/2_nW`>/6ojNoj`Ko
Yl3[0_nX`N`Fooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool003Kooooo
00?o0000ooooooooool0<?ooool7ojJok0KoYl3[00?oZ<3[ojW0jonY`>/01?nY`>/7ojS0j`KoY[o[
1OnV`>`2ojJok0KoZ<7/0onY`>X3ojW1j`OoZKoZ00?oYko[ojRoj_nX_nX01?nX_nX6ojJoj`03ojG0
kOnV_n_oY[o[00CoY[o[1_nU`>d00onW`^goY/3/ojK0k004ojK0k0GoY/;]0_nW_n/6ojK0k0GoY/7]
2OnW_n/3ojO0j`?oZ;kZ2_nW_^X:ojNoj`03ojO0jonX`^coZ<;/00?oZ<;/2?nX`N`=ojNoj`GoYl3[
1_nW`N`00onX`NcoYl3[ojO0j`0:ojO0j`SoYko[0onW`>/Kooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool00_ooool003Oooooo0_l0000booooo`KoY[o/0onW`>/4ojO0k0KoZL3[1onX
`>/6ojJoj`03ojK0k?nV_ncoY[o/00CoY[o/1?nX`N`2ojK0k0KoZL7[1OnY_nX2ojW0jPOoZ;oZ0onV
_n/3ojRojPOoY[o[0onU`>d4ojNoj`KoY/3/00?oY/;]ojNojonW_n/01?nW_n/6ojK0k003ojK1kOnW
_n_oYko[00WoYko[2?nX_^X5ojNnjPgoYko[00?oYl;/ojS2k?nX`^`01OnX`^`3ojS1k17oYko[1_nW
`>/2ojO1k0GoZ<7/2?nW`>/:ojNojb3ooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`02ooooo`00>Oooool00ol0003oooooooooo`0`ooooo`?oY[o/0onV`>`7ojO0k0?oZL3[2_nX`>/3
ojJoj`CoYko[1_nV_n`00onX`NcoY/3/ojK0k003ojK0k0KoZL7[00?oZKoZojW0j_nY`>X01?nY`>X5
ojRojP;oZKoZ1_nX_nX5ojJoj`;oZ;oZ1onW_n/3ojK0k0?oZ;oZ1onW_n/3ojK0k0CoZ;oZ1onW_n/<
ojRnjP03ojNnj_nW_n_oYko[00_oYko[1OnW`^`5ojS2k1KoYko[0onW`>/:ojS1k0?oYl3[2onW_n/S
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool003[ooooo00?o0000oooo
ooooool0<?ooool6ojK0k0GoYl3/0_nV`>`=ojS0j`OoYko[1_nV_n`6ojK0k0?oZL7[1?nX`N`6ojW0
jP03ojRoj_nY_n[oZKoZ00CoZKoZ1_nX_nX00onV_n_oZ;oZojRojP04ojRojPGoYko[2?nX_nX5ojNo
j`WoZ;oZ0onW_n/<ojRnjPgoYko[2_nW`^`00onX`^coYko[ojNoj`0FojNoj`goZ<7/2onW_n/Xoooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00_ooool003_ooooo00?o0000oooooooo
ool0<?ooool6ojK0k003ojO0k?nV`>coY/3/00CoY/3/3OnX`>/5ojNoj`;oZ;o[1_nV_n`6ojK0k0Oo
Z<7/0onY`>X3ojS1j`OoZKoZ3OnX_nX00onW_n_oZ;oZojRojP0:ojRojP03ojNojonX_n[oZ;oZ00[o
Z;oZ2onX_^X2ojS0j`_oYko[3?nW`^`4ojO0j`WoYko[0onW_nX8ojNoj`goZ<7/2_nW_n/]ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool00Oooool003cooooo00?o0000ooooooooool0
<?ooool3ojK0k0?oYl3[1onV`>`=ojS0j`03ojNojonX_n_oZ;o[00CoZ;o[1_nV_n`6ojK0k0GoZ<7/
0_nV`>`6ojS1j`GoZKoZ0_nX`N/WojRojPOoZ;kZ1_nX`>/7ojNoj`_oYl;/2OnW`>/3ojNoj`WoYkoZ
0onW_n/3ojO1k0[oZ<7/1?nW`>/7ojNojc7ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`01ooooo`00?Oooool2o`00037ooooo1_nW`>/7ojK0k0goZ<3[1onX_n/3ojJok0?oYko[1_nV
`>`00onX`NcoY/3/ojK0k004ojK0k0KoZ<7[00?oZKoZojS1jonX`N/01?nX`N/5ojRojP;oZ<7[2onX
_nX00onX`>_oZ;oZojRojP08ojRojP?oZ<3[1onX_nX3ojRnjPCoZ<7/1_nX`>/3ojNoj`CoYl;]1onW
`^`;ojO0j`coYkoZ0_nW`>`6ojO1k0GoZ<7/0_nX`>/7ojO0j`?oYko[=?ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo007ooooo000oooooo`03o`000?oooooooooo02oooooo1_nW`>/7
ojK0k0GoZ<3[0_nW`>`6ojS0j`GoZ;o[0_nX_nX6ojNoj`?oY/3/0onV_n/7ojK0k0?oZ<7[1?nV`N`6
ojS1j`03ojRoj_nX`N_oZ<7[00CoZ<7[1onX_nX5ojS0j`GoZ;oZ0_nX`N`6ojS0j`GoZ;oZ0_nW`N`7
ojS1k0?oZ<3[0onW`N`7ojO2k@?oYl;/2onW`>/<ojNojPKoYl3/1_nW`N`00onX`NcoZ<3[ojS0j`04
ojS0j`GoYl3[>Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo007ooooo0010oooo
o`03o`000?oooooooooo02oooooo1onW`>/6ojK0k003ojS0jonW`>coYl3/00CoYl3/1_nX`>/00onX
_n_oZ;oZojRojP04ojRojPCoYko[0_nX_n/6ojJoj`GoY/3/0_nV_n`7ojK1k0?oZ<7[0onV`N`7ojS1
j`?oZ;oZ0onX`N`6ojS0j`03ojRoj_nX`NcoZ<7/00CoZ<7/1_nX`>/00onX_n[oYl7/ojO1k004ojO1
k0GoZ<7/2?nW`N`5ojO2k@_oYl3[3OnW_nX3ojO0j`OoYl3/0onW`N`3ojS1k0OoZ<3[00?oYl3[oooo
ooooool0>oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo007ooooo0011ooooo`03
o`000?oooooooooo02oooooo1onW`>/6ojK0k0OoYl3/1onX`>/6ojRojP03ojNojonX_n_oZ;o[00?o
Z;o[1_nV_n/00onV`>coY[o/ojJok004ojJok0GoY/7/0_nV_n`6ojK1k0GoZ<7[00?oY/7/ojS1k?nX
`N`01OnX`N`3ojS0j`?oYl7/1onX`N`3ojS0j`CoYl7]1_nW`N`00onX`NcoYl7/ojO1k00:ojO1k003
ojO2kOnW`>_oYl3[00SoYl3[3OnW_nX00onW_n_oYl3[ojO0j`05ojO0j`GoYl3/00?oYl7/ojS1k?nX
`N`01OnX`N`3ojS0jd7ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`01ooooo`00
@_ooool2o`00033ooooo1onW`>/6ojK0k0GoYl3/0_nV`>`7ojS0j`?oZ;oZ0onX`>X6ojRoj`?oY[o[
1?nW_n/6ojJok003ojK1k?nV_ncoY[o/00CoY[o/1_nV`N`00onX`N_oY/7/ojK1k003ojK1k0GoZ<7/
0_nV`N`6ojO1k0GoZ<7/0_nV`N`7ojO1k@ooYl7/1?nW_n/7ojO0j`goYkoZ1OnW_n/7ojO0j`03ojO0
k?nW`NcoYl7/00?oYl7/1OnX`Na6ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
0Oooool004Cooooo00?o0000ooooooooool0;_ooool7ojO0j`KoY/3/00?oYl3/ojK0k?nV`>`01?nV
`>`5ojS0j`;oYl7/1_nX`>X4ojRoj`;oZ;oZ1onW_n/3ojJok0CoYko[1_nV_n`3ojK1k0CoY[o/1OnV
`N`00onX`NcoY/7/ojK1k004ojK1k0KoYl7/00?oZ<7/ojK1k?nV`N`01?nV`N`5ojO1k@03ojO0jonW
`NcoYl7/00WoYl7/2OnW_n/3ojO0j`goYkoZ2OnW_n/3ojO0j`[oYl7/00?oZ<7/ooooooooool0B?oo
ool00ol0003oooooooooo`07ooooo`7o00000Oooool1ooooo`00AOooool00ol0003oooooooooo`0_
ooooo`KoYl3[0onV`>`4ojO0j`KoY/3/00?oZ<3[ojO1k?nW`N`01?nW`N`6ojS0jP03ojRojonX_n[o
Z;oZ00?oZ;oZ1OnW_n/2ojRojPOoYko[0onV_n`3ojNoj`OoY[o/0_nV`N`4ojJoj`KoY/7/0onW`N`4
ojK0k0KoY/7/00?oYl7]ojO0jonW`>/00onW`>/7ojO1k0_oYko[3OnW_nX;ojNoj`goYl7/C_ooool0
0ol0003oooooooooo`06ooooo`7o00000Oooool1ooooo`00A_ooool00ol0003oooooooooo`0`oooo
o`;oYl3[0onX_n/7ojO0j`OoY/3/1_nW`N`3ojS0jP?oZ<7[1_nX_nX00onW_n_oZ;oZojRojP04ojRo
jPGoYko[0_nX_nX6ojNoj`GoY[o/00?oYko[ojJojonV_n/01OnV_n/3ojK1k0?oYko[1onV`>`3ojK1
k0?oYko[1_nW`>/3ojO1k0_oYko[3OnW_nX:ojNoj`goYl7/D_ooool00ol0003oooooooooo`06oooo
o`7o00000Oooool1ooooo`00Aoooool2o`00037ooooo1OnX_n/7ojO0j`OoY/3/0onW`N`3ojK0k0Ko
Z<7[0onX_nX4ojS0j`KoZ;oZ00?oYko[ojRoj_nX_nX01?nX_nX6ojNoj`03ojJok?nW_n_oYko[00?o
Yko[1OnV_n/2ojRoj`KoYko[1OnV`>`8ojNoj`?oYl3[0onX_nX:ojNoj`?oZ;oZ2_nW_nX:ojNoj`go
Yl7/E_ooool00ol0003oooooooooo`05ooooo`7o00000Oooool1ooooo`00BOooool00ol0003ooooo
ooooo`0_ooooo`GoZ;o[1onW`>/5ojK0k0;oYl3[1_nV`>`4ojS1j`;oYl7/1onX`>/3ojRojP?oZ<3[
1onX_nX3ojNoj`?oZ;oZ1_nW_n/00onV_n_oZ;o[ojRoj`04ojRoj`KoYko[00?oY/3/ojNojonW_n/0
2?nW_n/8ojRojPGoYko[2?nX_nX5ojNojP03ojO0jonW_n_oYko[00SoYko[3OnW`NaJooooo`03o`00
0?oooooooooo00Cooooo0Ol00001ooooo`7ooooo001:ooooo`03o`000?oooooooooo02oooooo0_nX
_n/4ojS0j`KoYl3[00?oY/3/ojO0jonW`>/01?nW`>/6ojK0k003ojS1jonW`NcoYl7/00?oYl7/1OnX
`>/2ojO1k0KoZ<3[1OnX_nX00onX`>_oZ;oZojRojP05ojRojP?oYko[0onX_nX7ojRoj`?oYko[0onX
_nX7ojNoj`coZ;oZ00?oYko[ojRoj_nX_nX02_nX_nX00onW_n[oYl3[ojO0j`03ojO0j`GoYko[3?nW
`NaPooooo`03o`000?oooooooooo00?ooooo0Ol00001ooooo`7ooooo001;ooooo`03o`000?oooooo
oooo02oooooo1_nX`>/3ojO0j`CoZ;o[1_nW`>/7ojK0k0GoYl7/00?oZ<3[ojO1k?nW`N`01?nW`N`6
ojS0j`03ojRoj_nX`>_oZ<3[00?oZ<3[1OnX_nX2ojS0j`KoZ;oZ1OnX_n/8ojRojP?oYko[3OnX_nX4
ojRoj`WoZ;oZ2OnW`>/00onW_n_oYl7/ojO1k009ojO1k6Cooooo00?o0000ooooooooool00oooool1
o`00007ooooo0Oooool004cooooo0_l0000`ooooo`KoZ<3[1onX_n/3ojO0j`?oYko[1onV`>`2ojO1
k0CoY/3/1_nW`N`3ojS0j`CoZ<7/1OnX`>/00onX_n[oZ<3[ojS0j`04ojS0j`KoZ;oZ00?oZ;o[ojRo
j_nX_nX02?nX_nX2ojS0j`_oZ;oZ0_nX`>/7ojRoj`?oZ;oZ0_nW`N`:ojO0j`_oYl7/J?ooool00ol0
003oooooooooo`03ooooo`7o00000Oooool004kooooo00?o0000ooooooooool0;_ooool6ojS0j`Oo
Z;o[1_nW_n/5ojK0k003ojO0jonV`>coY/3/00GoY/3/0onW`N`3ojK0k0OoZ<7/0_nX`>/4ojO1k0Ko
Z<3[0onX_nX4ojS0j`OoZ;oZ1OnX`>/7ojRojPKoZ<3[1OnX_n/7ojO1k0GoYl3[3?nW`Na/ooooo`03
o`000?oooooooooo00;ooooo0Ol00001ooooo`00Coooool00ol0003oooooooooo`0_ooooo`GoZ<3[
1onX_n/6ojNoj`03ojK0k?nW`>_oYl3[00?oYl3[1OnV`>`2ojO0j`KoY/3/1OnX`N`00onV`>coYl7/
ojO1k005ojO1k0?oZ<3[0onW`N`7ojS0j`?oZ;oZ0onX`N`6ojS0j`?oZ;oZ1?nX`N`6ojS0j`03ojRo
jonW`NcoYl7/00WoYl7/00?oYl3[ojO1k?nW`N`02OnW`Naaooooo`05o`000?ooooooooooooooool0
00000Oooool0053ooooo00?o0000ooooooooool0;oooool5ojS0j`OoZ;o[0onW_n/4ojRoj`GoYl3[
00?oY/3/ojO0jonW`>/01?nW`>/6ojK0k003ojS1k?nV`>coY/3/00?oY/3/1OnW`N`2ojK0k0KoYl7/
1OnX`>/00onW`NcoZ<7/ojS1k005ojS1k0?oZ<3[0onW`N`7ojS1k0?oZ<3[5onW`Nadooooo`05o`00
0?ooooooooooooooool000000Oooool0057ooooo0_l0000`ooooo`GoZ<3[1OnX_n/2ojS0j`OoZ;o[
0_nW`>/4ojNoj`KoYl3[0onV`>`4ojO0j`GoY/3/00?oYl7/ojK0k?nV`>`01?nV`>`6ojO1k003ojS0
jonW`NcoYl7/00?oYl7/1OnX`N`2ojO0k0KoYl7/1OnX`N`00onW`>coYl7/ojO1k008ojO1k0?oYl3/
2_nW`Nahooooo`04o`000?ooooooooooo`00007ooooo001Cooooo`03o`000?oooooooooo02kooooo
1OnX`>/00onX_n_oZ<3[ojS0j`04ojS0j`KoZ;o[1onW_n/3ojO0j`?oYko[1onW`>/2ojK0k0CoYl3[
1_nV`>`3ojO1k0?oYl3/1_nW`N`00onX`NcoYl3/ojO0k004ojO0k0KoYl7/00?oZ<7/ojO0k?nW`>`0
0onW`>`5ojO1k0;oYl3[1_nW`>`5ojO1k7gooooo00?o0000ooooool000000Oooool005Cooooo00?o
0000ooooooooool0;_ooool2ojS0j`CoYl3/1_nX`>/6ojRoj`GoYko[0_nX_n/6ojNoj`GoYl3[00?o
Yko[ojO0jonW`>/01OnW`>/3ojK0k0?oYl3[1_nW`>`3ojO1k0CoYl3[1_nW`>`3ojO1k0WoYl3/00?o
Yl7/ojO0jonW`>/01?nW`>/6ojO0k003ojO1k?oooooooooo07kooooo00?o0000ooooool000000Ooo
ool005Gooooo00?o0000ooooooooool0;_ooool6ojO0k0OoZ<3[1OnX_n/00onW_n_oZ;o[ojRoj`04
ojRoj`KoYko[00?oYl3[ojNojonW_n/00onW_n/5ojO0j`;oYko[1_nW`>/4ojO0k0;oYko[1onW`>/3
ojO0k0;oYl3[2_nW`>`4ojNoj`KoYl3[0onW`>b4ooooo`7o00000Oooool1o`000000E_ooool2o`00
02oooooo1_nW`>`7ojS0j`;oZ;o[1?nX`>/6ojRoj`?oYko[1?nX_n/5ojNoj`03ojO0jonW_n_oYko[
00CoYko[1_nW`>/00onW`>coYko[ojNoj`03ojNoj`GoYl3[0_nW_n/5ojO0j`GoYl3/2OnW_n/3ojO0
jh[ooooo0_l0000005Sooooo00?o0000ooooooooool0;Oooool6ojO0k0GoZ<3[0_nW`>`6ojS0j`?o
Z;o[0onX`>/7ojRoj`;oYko[1?nX_n/6ojNoj`?oYl3[0onX_n/6ojNoj`03ojO0jonW_n_oYko[00Co
Yko[1OnW`>/00onW`>coYko[ojNoj`09ojNojhgooooo0ol0000005Wooooo00?o0000ooooooooool0
;Oooool6ojO0k003ojS0jonW`>coYl3/00CoYl3/1?nX`>/2ojO0k0KoZ<3[1OnX_n/00onX`>_oZ;o[
ojRoj`05ojRoj`?oYko[0onX_nX6ojRoj`?oYko[1?nX_nX6ojNoj`;oYl3[1?nX_nX7ojNojhcooooo
1?l00003ooooo`00F_ooool00ol0003oooooooooo`0]ooooo`goYl3/00?oZ<3[ojO0k?nW`>`00onW
`>`6ojS0j`03ojRojonX`>_oZ<3[00?oZ<3[1OnX_n/2ojS0j`KoZ;oZ1?nX_n/2ojS0j`OoZ;oZ0onW
_n/3ojRoj`KoZ;oZ0onW_n^<ooooo`?o00001oooool005_ooooo00?o0000ooooooooool0;_oooolB
ojO0k0?oZ<3[1?nW`>`5ojS0j`03ojRojonX`>_oZ<3[00CoZ<3[1_nX_nX00onX_n_oZ<3[ojS0j`03
ojS0j`GoZ;oZ00?oZ<3[ojRojonX_n/01OnX_n/3ojRojXgooooo1?l0000:ooooo`00G?ooool2o`00
02oooooo0onW`>`3ojO0ja?oYl3/0_nX`>/4ojO0k0KoZ<3[0onX_nX3ojS1j`KoZ<3[00?oZ;oZojS0
jonX`>/00onX`>/5ojRojhgooooo1?l0000>ooooo`00G_ooool00ol0003oooooooooo`0]ooooo`Ko
Yl3[1?nW`>`2ojO0ja?oYl3/0onX`>/3ojO0k0KoZ<7[0onX`>/4ojO1k0GoZ<3[00?oZ;o[oooooooo
ool0R_ooool4o`0001;ooooo001Oooooo`03o`000?oooooooooo02gooooo1_nW`>/00onW`>coYl3[
ojO0j`03ojO0j`GoYl3/0_nW`>/BojO0k0?oZ<7[0onW`>`7ojO1k0;oZ<3[Roooool4o`0001Kooooo
001Pooooo`03o`000?oooooooooo02gooooo0onW`>/4ojRoj`GoYl3[00?oYl3/ojO0jonW`>/01?nW
`>/HojO0k0GoYl7/Roooool3o`0001[ooooo001Qooooo`;o0000;oooool6ojRoj`;oYl3[1?nW_n/6
ojO0j`;oYl3/1?nW`>/BojO0k003ojO1k?oooooooooo08Sooooo1?l0000Mooooo`00Hoooool00ol0
003oooooooooo`0]ooooo`?oZ;o[0_nX`>/7ojNoj`?oYl3[0onW_n/6ojO0j`?oYl3/0onW`>/9ojO0
k8Wooooo1?l0000Qooooo`00I?ooool00ol0003oooooooooo`0]ooooo`GoZ<3[1OnW_n/2ojS0j`Ko
Yko[0onW`>/4ojNoj`GoYl3[0onW`>b:ooooo`Co00009Oooool006Gooooo00?o0000ooooooooool0
;Oooool5ojS0j`03ojNojonX`>_oZ<3[00CoZ<3[1?nW_n/2ojS0j`OoYko[0_nW`>^;ooooo`Co0000
:Oooool006Kooooo0_l0000^ooooo`coZ<3[00?oYko[ojS0jonX`>/00onX`>/5ojNojh_ooooo0ol0
000]ooooo`00J?ooool00ol0003oooooooooo`0/oooooa;oZ<3[00?oYko[ooooooooool0R?ooool4
o`00033ooooo001Yooooo`03o`000?oooooooooo02cooooo0onX`>/4ojO0k0SoZ<3[ROooool4o`00
03Cooooo001Zooooo`03o`000?oooooooooo02cooooo1onW`>`2ojS0jh[ooooo1?l0000hooooo`00
Joooool2o`0002gooooo1OnW`>b9ooooo`Co0000??ooool006gooooo00?o0000ooooooooool0:ooo
ool00onW`>coooooooooo`27ooooo`?o0000@?ooool006kooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`23ooooo`Co0000@oooool006oooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`1oooooo`Co0000Aoooool0073ooooo0_l0000Yooooo`03o`000?oooooooooo07_o
oooo1?l0001;ooooo`00L_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo07Oooooo
1?l0001?ooooo`00Loooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo07Cooooo0ol0
001Cooooo`00M?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo073ooooo1?l0001F
ooooo`00MOooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo06cooooo1?l0001Joooo
o`00M_ooool2o`0002?ooooo00?o0000ooooooooool0J?ooool4o`0005kooooo001hooooo`03o`00
0?oooooooooo023ooooo00?o0000ooooooooool0I?ooool4o`0006;ooooo001iooooo`03o`000?oo
oooooooo01oooooo00?o0000ooooooooool0HOooool3o`0006Kooooo001jooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool0GOooool4o`0006Wooooo001kooooo`;o00007_ooool00ol0
003oooooooooo`1Iooooo`Co0000KOooool007gooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`1Eooooo`Co0000LOooool007kooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`1Aooooo`Co0000MOooool007oooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`1>ooooo`?o0000NOooool0083ooooo0_l0000Iooooo`03o`000?oooooooooo04[ooooo1?l0001l
ooooo`00P_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Kooooo1?l00020oooo
o`00Poooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04;ooooo1?l00024ooooo`00
Q?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo03kooooo1?l00028ooooo`00QOoo
ool2o`0001?ooooo00?o0000ooooooooool0??ooool3o`0008cooooo0027ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool0>?ooool4o`0008oooooo0028ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0=?ooool4o`0009?ooooo0029ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool0<?ooool4o`0009Oooooo002:ooooo`;o00003_ooool00ol0003ooooo
ooooo`0/ooooo`Co0000Voooool008cooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0Yooooo`?o0000Woooool008gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0U
ooooo`Co0000X_ooool008kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Qoooo
o`Co0000Y_ooool008oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Mooooo`Co
0000Z_ooool0093ooooo0_l00008ooooo`03o`000?oooooooooo01Wooooo1?l0002^ooooo`00T_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Kooooo0ol0002booooo`00Toooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo01;ooooo1?l0002eooooo`00U?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00kooooo1?l0002iooooo`00UOooool2o`0000?o
oooo00?o0000ooooooooool02_ooool4o`000;gooooo002Gooooo`04o`000?ooooooooooo`0000So
oooo1?l00031ooooo`00V?ooool00ol0003oooooo`000005ooooo`?o0000aOooool009Wooooo0_l0
00000ooooooo0000o`000002o`000<Sooooo002Jooooo`;o0000c?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0538698, 0.0432538, \
0.0035044, 0.0035044}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[.12586 .2075 -12 -8.99448 ]
[.12586 .2075 0 .00552 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.56094 .0364 -5.16972 -9 ]
[.56094 .0364 .83028 0 ]
[.75679 .08071 0 -6.17777 ]
[.75679 .08071 12 2.82223 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.9429 .3657 0 -5.9083 ]
[.9429 .3657 6 3.0917 ]
[.02494 .25992 -18 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.01611 .31527 -18 -2.78472 ]
[.01611 .31527 0 6.21528 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00254 .43215 -12 -2.88407 ]
[-0.00254 .43215 0 6.11593 ]
[-0.0124 .49393 -12 -2.93688 ]
[-0.0124 .49393 0 6.06312 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
[(-2)] .12586 .2075 1 .99877 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.56863 .04703 m
.57247 .05235 L
s
[(2)] .56094 .0364 .72324 1 Mshowa
.125 Mabswid
.18558 .19702 m
.18832 .19985 L
s
.23703 .17687 m
.23971 .17975 L
s
.28951 .15632 m
.29214 .15925 L
s
.39772 .11395 m
.40023 .11699 L
s
.4535 .09211 m
.45595 .0952 L
s
.51046 .06981 m
.51284 .07294 L
s
.08568 .23614 m
.08851 .23887 L
s
.62804 .02377 m
.63027 .02701 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.7445 .0853 m
.73835 .08759 L
s
[(-2)] .75679 .08071 -1 .37284 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.93037 .36962 m
.92411 .37158 L
s
[(2)] .9429 .3657 -1 .31296 Mshowa
.125 Mabswid
.7708 .12553 m
.7671 .12688 L
s
.79613 .16428 m
.79242 .1656 L
s
.82054 .20161 m
.81682 .20291 L
s
.86679 .27235 m
.86305 .2736 L
s
.88871 .30589 m
.88497 .30711 L
s
.9099 .3383 m
.90615 .3395 L
s
.71716 .04348 m
.71349 .04489 L
s
.95018 .39992 m
.94642 .40107 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(-20)] .02494 .25992 1 -0.39157 Mshowa
.02837 .31059 m
.0345 .30825 L
s
[(-10)] .01611 .31527 1 -0.38117 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.00981 .42772 m
.01599 .4255 L
s
[(10)] -0.00254 .43215 1 -0.3591 Mshowa
0 .48963 m
.0062 .48748 L
s
[(20)] -0.0124 .49393 1 -0.34736 Mshowa
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.657 .751 .92 r
.39362 .69481 .40169 .70187 .4152 .69805 .40717 .69094 Mtetra
.656 .751 .92 r
.40717 .69094 .4152 .69805 .42878 .6942 .42079 .68708 Mtetra
.655 .751 .92 r
.42079 .68708 .42878 .6942 .44242 .69035 .43448 .6832 Mtetra
.655 .752 .921 r
.43448 .6832 .44242 .69035 .45614 .68649 .44824 .67933 Mtetra
.44824 .67933 .45614 .68649 .46992 .68262 .46207 .67542 Mtetra
.656 .752 .921 r
.46207 .67542 .46992 .68262 .48378 .67874 .47597 .67146 Mtetra
.657 .751 .92 r
.47597 .67146 .48378 .67874 .4977 .67481 .48994 .66747 Mtetra
.656 .75 .919 r
.48994 .66747 .4977 .67481 .5117 .67084 .50398 .66347 Mtetra
.656 .751 .92 r
.50398 .66347 .5117 .67084 .52577 .66685 .5181 .65946 Mtetra
.5181 .65946 .52577 .66685 .53991 .66285 .53229 .65544 Mtetra
.655 .751 .921 r
.53229 .65544 .53991 .66285 .55412 .65884 .54655 .65143 Mtetra
.655 .752 .921 r
.54655 .65143 .55412 .65884 .56841 .65482 .56088 .64739 Mtetra
.655 .753 .922 r
.56088 .64739 .56841 .65482 .58277 .65079 .57529 .64332 Mtetra
.656 .753 .921 r
.57529 .64332 .58277 .65079 .59721 .64674 .58978 .63921 Mtetra
.656 .752 .921 r
.58978 .63921 .59721 .64674 .61172 .64267 .60434 .63506 Mtetra
.656 .752 .92 r
.60434 .63506 .61172 .64267 .62631 .63857 .61898 .6309 Mtetra
.656 .751 .92 r
.61898 .6309 .62631 .63857 .64097 .63444 .63369 .62671 Mtetra
.656 .75 .919 r
.63369 .62671 .64097 .63444 .65571 .63029 .64849 .62251 Mtetra
.64849 .62251 .65571 .63029 .67053 .62611 .66336 .61829 Mtetra
.66336 .61829 .67053 .62611 .68542 .62191 .67831 .61405 Mtetra
.67831 .61405 .68542 .62191 .7004 .61769 .69334 .60979 Mtetra
.69334 .60979 .7004 .61769 .71545 .61344 .70845 .60551 Mtetra
.656 .75 .92 r
.70845 .60551 .71545 .61344 .73059 .60917 .72364 .60121 Mtetra
.655 .751 .92 r
.72364 .60121 .73059 .60917 .7458 .60487 .73891 .59689 Mtetra
.655 .751 .921 r
.73891 .59689 .7458 .60487 .76109 .60054 .75426 .59255 Mtetra
.656 .752 .921 r
.75426 .59255 .76109 .60054 .77647 .59618 .7697 .58817 Mtetra
.656 .753 .921 r
.7697 .58817 .77647 .59618 .79193 .5918 .78522 .58375 Mtetra
.78522 .58375 .79193 .5918 .80747 .58741 .80082 .5793 Mtetra
.80082 .5793 .80747 .58741 .8231 .58301 .81651 .57482 Mtetra
.656 .752 .92 r
.81651 .57482 .8231 .58301 .83882 .57859 .83228 .57033 Mtetra
.656 .751 .92 r
.83228 .57033 .83882 .57859 .85462 .57416 .84814 .56584 Mtetra
.655 .75 .92 r
.84814 .56584 .85462 .57416 .8705 .56971 .86409 .56133 Mtetra
.86409 .56133 .8705 .56971 .88648 .5652 .88013 .55681 Mtetra
.655 .751 .92 r
.88013 .55681 .88648 .5652 .90253 .56066 .89625 .55226 Mtetra
.656 .752 .921 r
.89625 .55226 .90253 .56066 .91868 .55608 .91246 .54764 Mtetra
.91246 .54764 .91868 .55608 .93491 .55149 .92876 .54299 Mtetra
.656 .752 .92 r
.92876 .54299 .93491 .55149 .95124 .5469 .94515 .53833 Mtetra
.656 .751 .92 r
.94515 .53833 .95124 .5469 .96766 .54229 .96163 .53366 Mtetra
.655 .75 .92 r
.96163 .53366 .96766 .54229 .98417 .53765 .97821 .52898 Mtetra
.656 .751 .92 r
.38547 .68768 .39362 .69481 .40717 .69094 .39906 .68379 Mtetra
.655 .751 .92 r
.39906 .68379 .40717 .69094 .42079 .68708 .41273 .6799 Mtetra
.655 .752 .921 r
.41273 .6799 .42079 .68708 .43448 .6832 .42646 .67601 Mtetra
.42646 .67601 .43448 .6832 .44824 .67933 .44026 .67209 Mtetra
.657 .752 .92 r
.44026 .67209 .44824 .67933 .46207 .67542 .45414 .6681 Mtetra
.657 .751 .919 r
.45414 .6681 .46207 .67542 .47597 .67146 .46808 .66409 Mtetra
.656 .75 .919 r
.46808 .66409 .47597 .67146 .48994 .66747 .4821 .66008 Mtetra
.656 .751 .92 r
.4821 .66008 .48994 .66747 .50398 .66347 .49619 .65606 Mtetra
.655 .751 .921 r
.49619 .65606 .50398 .66347 .5181 .65946 .51035 .65205 Mtetra
.655 .752 .921 r
.51035 .65205 .5181 .65946 .53229 .65544 .52459 .64802 Mtetra
.655 .753 .922 r
.52459 .64802 .53229 .65544 .54655 .65143 .5389 .64395 Mtetra
.656 .753 .921 r
.5389 .64395 .54655 .65143 .56088 .64739 .55329 .63983 Mtetra
.656 .752 .92 r
.55329 .63983 .56088 .64739 .57529 .64332 .56775 .63568 Mtetra
.657 .751 .919 r
.56775 .63568 .57529 .64332 .58978 .63921 .58228 .63151 Mtetra
.656 .75 .919 r
.58228 .63151 .58978 .63921 .60434 .63506 .59689 .62732 Mtetra
.59689 .62732 .60434 .63506 .61898 .6309 .61158 .62311 Mtetra
.61158 .62311 .61898 .6309 .63369 .62671 .62635 .61889 Mtetra
.62635 .61889 .63369 .62671 .64849 .62251 .64119 .61465 Mtetra
.64119 .61465 .64849 .62251 .66336 .61829 .65612 .61039 Mtetra
.65612 .61039 .66336 .61829 .67831 .61405 .67112 .6061 Mtetra
.67112 .6061 .67831 .61405 .69334 .60979 .68621 .6018 Mtetra
.68621 .6018 .69334 .60979 .70845 .60551 .70137 .59747 Mtetra
.70137 .59747 .70845 .60551 .72364 .60121 .71662 .59313 Mtetra
.71662 .59313 .72364 .60121 .73891 .59689 .73195 .58877 Mtetra
.655 .75 .919 r
.73195 .58877 .73891 .59689 .75426 .59255 .74736 .58439 Mtetra
.74736 .58439 .75426 .59255 .7697 .58817 .76285 .57999 Mtetra
.655 .75 .92 r
.76285 .57999 .7697 .58817 .78522 .58375 .77844 .57557 Mtetra
.655 .751 .921 r
.77844 .57557 .78522 .58375 .80082 .5793 .7941 .57111 Mtetra
.656 .753 .921 r
.7941 .57111 .80082 .5793 .81651 .57482 .80985 .5666 Mtetra
.657 .753 .921 r
.80985 .5666 .81651 .57482 .83228 .57033 .82568 .56204 Mtetra
.656 .753 .921 r
.82568 .56204 .83228 .57033 .84814 .56584 .8416 .55747 Mtetra
.656 .751 .92 r
.8416 .55747 .84814 .56584 .86409 .56133 .85761 .55289 Mtetra
.85761 .55289 .86409 .56133 .88013 .55681 .87371 .54831 Mtetra
.655 .75 .92 r
.87371 .54831 .88013 .55681 .89625 .55226 .8899 .54372 Mtetra
.8899 .54372 .89625 .55226 .91246 .54764 .90618 .5391 Mtetra
.656 .752 .921 r
.90618 .5391 .91246 .54764 .92876 .54299 .92255 .53441 Mtetra
.92255 .53441 .92876 .54299 .94515 .53833 .939 .52969 Mtetra
.656 .752 .92 r
.939 .52969 .94515 .53833 .96163 .53366 .95555 .52495 Mtetra
.656 .751 .92 r
.95555 .52495 .96163 .53366 .97821 .52898 .9722 .5202 Mtetra
.655 .751 .92 r
.37724 .68049 .38547 .68768 .39906 .68379 .39088 .67659 Mtetra
.655 .751 .921 r
.39088 .67659 .39906 .68379 .41273 .6799 .40459 .67268 Mtetra
.655 .752 .921 r
.40459 .67268 .41273 .6799 .42646 .67601 .41836 .66874 Mtetra
.657 .752 .92 r
.41836 .66874 .42646 .67601 .44026 .67209 .43221 .66473 Mtetra
.657 .751 .919 r
.43221 .66473 .44026 .67209 .45414 .6681 .44613 .6607 Mtetra
.656 .751 .92 r
.44613 .6607 .45414 .6681 .46808 .66409 .46012 .65668 Mtetra
.655 .751 .92 r
.46012 .65668 .46808 .66409 .4821 .66008 .47419 .65265 Mtetra
.655 .751 .921 r
.47419 .65265 .4821 .66008 .49619 .65606 .48832 .64863 Mtetra
.655 .752 .922 r
.48832 .64863 .49619 .65606 .51035 .65205 .50253 .64458 Mtetra
.656 .753 .921 r
.50253 .64458 .51035 .65205 .52459 .64802 .51682 .64046 Mtetra
.657 .752 .92 r
.51682 .64046 .52459 .64802 .5389 .64395 .53118 .63631 Mtetra
.657 .75 .919 r
.53118 .63631 .5389 .64395 .55329 .63983 .54561 .63213 Mtetra
.656 .75 .919 r
.54561 .63213 .55329 .63983 .56775 .63568 .56012 .62794 Mtetra
.56012 .62794 .56775 .63568 .58228 .63151 .57471 .62374 Mtetra
.57471 .62374 .58228 .63151 .59689 .62732 .58937 .61953 Mtetra
.656 .751 .92 r
.58937 .61953 .59689 .62732 .61158 .62311 .60411 .6153 Mtetra
.655 .751 .92 r
.60411 .6153 .61158 .62311 .62635 .61889 .61893 .61106 Mtetra
.655 .752 .921 r
.61893 .61106 .62635 .61889 .64119 .61465 .63383 .6068 Mtetra
.63383 .6068 .64119 .61465 .65612 .61039 .64881 .6025 Mtetra
.656 .752 .921 r
.64881 .6025 .65612 .61039 .67112 .6061 .66387 .59818 Mtetra
.656 .753 .921 r
.66387 .59818 .67112 .6061 .68621 .6018 .67901 .59382 Mtetra
.656 .752 .921 r
.67901 .59382 .68621 .6018 .70137 .59747 .69423 .58944 Mtetra
.656 .752 .92 r
.69423 .58944 .70137 .59747 .71662 .59313 .70953 .58502 Mtetra
.656 .751 .92 r
.70953 .58502 .71662 .59313 .73195 .58877 .72492 .5806 Mtetra
.72492 .5806 .73195 .58877 .74736 .58439 .74038 .57616 Mtetra
.656 .75 .919 r
.74038 .57616 .74736 .58439 .76285 .57999 .75594 .5717 Mtetra
.655 .75 .919 r
.75594 .5717 .76285 .57999 .77844 .57557 .77158 .56723 Mtetra
.77158 .56723 .77844 .57557 .7941 .57111 .78731 .56274 Mtetra
.655 .75 .92 r
.78731 .56274 .7941 .57111 .80985 .5666 .80312 .55824 Mtetra
.655 .751 .92 r
.80312 .55824 .80985 .5666 .82568 .56204 .81902 .55369 Mtetra
.656 .753 .921 r
.81902 .55369 .82568 .56204 .8416 .55747 .835 .54907 Mtetra
.657 .753 .921 r
.835 .54907 .8416 .55747 .85761 .55289 .85107 .54441 Mtetra
.656 .752 .92 r
.85107 .54441 .85761 .55289 .87371 .54831 .86723 .53975 Mtetra
.656 .751 .92 r
.86723 .53975 .87371 .54831 .8899 .54372 .88348 .53509 Mtetra
.655 .75 .92 r
.88348 .53509 .8899 .54372 .90618 .5391 .89983 .53042 Mtetra
.89983 .53042 .90618 .5391 .92255 .53441 .91627 .52574 Mtetra
.656 .752 .92 r
.91627 .52574 .92255 .53441 .939 .52969 .93279 .52097 Mtetra
.656 .752 .921 r
.93279 .52097 .939 .52969 .95555 .52495 .94941 .51617 Mtetra
.656 .752 .92 r
.94941 .51617 .95555 .52495 .9722 .5202 .96612 .51136 Mtetra
.655 .751 .921 r
.36894 .67325 .37724 .68049 .39088 .67659 .38262 .66933 Mtetra
.655 .752 .921 r
.38262 .66933 .39088 .67659 .40459 .67268 .39637 .66537 Mtetra
.657 .752 .92 r
.39637 .66537 .40459 .67268 .41836 .66874 .41019 .66135 Mtetra
.657 .751 .919 r
.41019 .66135 .41836 .66874 .43221 .66473 .42409 .6573 Mtetra
.656 .751 .92 r
.42409 .6573 .43221 .66473 .44613 .6607 .43805 .65326 Mtetra
.655 .751 .92 r
.43805 .65326 .44613 .6607 .46012 .65668 .45209 .64923 Mtetra
.654 .752 .921 r
.45209 .64923 .46012 .65668 .47419 .65265 .4662 .64519 Mtetra
.655 .753 .922 r
.4662 .64519 .47419 .65265 .48832 .64863 .48038 .64111 Mtetra
.657 .752 .92 r
.48038 .64111 .48832 .64863 .50253 .64458 .49464 .63695 Mtetra
.657 .751 .919 r
.49464 .63695 .50253 .64458 .51682 .64046 .50897 .63277 Mtetra
.657 .75 .919 r
.50897 .63277 .51682 .64046 .53118 .63631 .52338 .62858 Mtetra
.656 .75 .919 r
.52338 .62858 .53118 .63631 .54561 .63213 .53787 .62438 Mtetra
.656 .75 .92 r
.53787 .62438 .54561 .63213 .56012 .62794 .55243 .62019 Mtetra
.655 .751 .921 r
.55243 .62019 .56012 .62794 .57471 .62374 .56706 .616 Mtetra
.655 .752 .922 r
.56706 .616 .57471 .62374 .58937 .61953 .58178 .61179 Mtetra
.655 .754 .922 r
.58178 .61179 .58937 .61953 .60411 .6153 .59657 .60754 Mtetra
.655 .754 .923 r
.59657 .60754 .60411 .6153 .61893 .61106 .61145 .60326 Mtetra
.61145 .60326 .61893 .61106 .63383 .6068 .6264 .59895 Mtetra
.656 .754 .922 r
.6264 .59895 .63383 .6068 .64881 .6025 .64143 .5946 Mtetra
.64143 .5946 .64881 .6025 .66387 .59818 .65655 .59024 Mtetra
.655 .754 .922 r
.65655 .59024 .66387 .59818 .67901 .59382 .67174 .58585 Mtetra
.656 .754 .922 r
.67174 .58585 .67901 .59382 .69423 .58944 .68702 .58142 Mtetra
.656 .755 .922 r
.68702 .58142 .69423 .58944 .70953 .58502 .70238 .57696 Mtetra
.70238 .57696 .70953 .58502 .72492 .5806 .71782 .57247 Mtetra
.657 .754 .922 r
.71782 .57247 .72492 .5806 .74038 .57616 .73335 .56794 Mtetra
.657 .753 .921 r
.73335 .56794 .74038 .57616 .75594 .5717 .74896 .56339 Mtetra
.656 .751 .92 r
.74896 .56339 .75594 .5717 .77158 .56723 .76466 .55884 Mtetra
.656 .75 .92 r
.76466 .55884 .77158 .56723 .78731 .56274 .78044 .55429 Mtetra
.655 .75 .919 r
.78044 .55429 .78731 .56274 .80312 .55824 .79631 .54973 Mtetra
.79631 .54973 .80312 .55824 .81902 .55369 .81228 .54515 Mtetra
.655 .75 .92 r
.81228 .54515 .81902 .55369 .835 .54907 .82833 .54055 Mtetra
.656 .752 .921 r
.82833 .54055 .835 .54907 .85107 .54441 .84447 .53587 Mtetra
.657 .753 .921 r
.84447 .53587 .85107 .54441 .86723 .53975 .86069 .53114 Mtetra
.656 .752 .921 r
.86069 .53114 .86723 .53975 .88348 .53509 .877 .5264 Mtetra
.656 .751 .92 r
.877 .5264 .88348 .53509 .89983 .53042 .89341 .52166 Mtetra
.655 .75 .92 r
.89341 .52166 .89983 .53042 .91627 .52574 .90992 .51692 Mtetra
.90992 .51692 .91627 .52574 .93279 .52097 .92652 .51216 Mtetra
.656 .752 .92 r
.92652 .51216 .93279 .52097 .94941 .51617 .94321 .50731 Mtetra
.656 .752 .921 r
.94321 .50731 .94941 .51617 .96612 .51136 .95999 .50243 Mtetra
.655 .752 .921 r
.36056 .66596 .36894 .67325 .38262 .66933 .37428 .66199 Mtetra
.657 .752 .92 r
.37428 .66199 .38262 .66933 .39637 .66537 .38808 .65796 Mtetra
.657 .751 .919 r
.38808 .65796 .39637 .66537 .41019 .66135 .40194 .65389 Mtetra
.656 .751 .92 r
.40194 .65389 .41019 .66135 .42409 .6573 .41588 .64983 Mtetra
.655 .751 .92 r
.41588 .64983 .42409 .6573 .43805 .65326 .42989 .64578 Mtetra
.654 .752 .921 r
.42989 .64578 .43805 .65326 .45209 .64923 .44397 .64173 Mtetra
.656 .753 .921 r
.44397 .64173 .45209 .64923 .4662 .64519 .45813 .63762 Mtetra
.657 .752 .92 r
.45813 .63762 .4662 .64519 .48038 .64111 .47236 .63343 Mtetra
.657 .75 .919 r
.47236 .63343 .48038 .64111 .49464 .63695 .48667 .62923 Mtetra
.656 .75 .919 r
.48667 .62923 .49464 .63695 .50897 .63277 .50105 .62503 Mtetra
.656 .75 .92 r
.50105 .62503 .50897 .63277 .52338 .62858 .51551 .62084 Mtetra
.654 .751 .921 r
.51551 .62084 .52338 .62858 .53787 .62438 .53004 .61667 Mtetra
.654 .753 .922 r
.53004 .61667 .53787 .62438 .55243 .62019 .54465 .61247 Mtetra
.655 .754 .923 r
.54465 .61247 .55243 .62019 .56706 .616 .55934 .60823 Mtetra
.656 .754 .922 r
.55934 .60823 .56706 .616 .58178 .61179 .57411 .60392 Mtetra
.656 .753 .921 r
.57411 .60392 .58178 .61179 .59657 .60754 .58896 .59958 Mtetra
.656 .751 .92 r
.58896 .59958 .59657 .60754 .61145 .60326 .60388 .59522 Mtetra
.656 .75 .919 r
.60388 .59522 .61145 .60326 .6264 .59895 .61889 .59084 Mtetra
.61889 .59084 .6264 .59895 .64143 .5946 .63398 .58644 Mtetra
.656 .749 .919 r
.63398 .58644 .64143 .5946 .65655 .59024 .64915 .58203 Mtetra
.64915 .58203 .65655 .59024 .67174 .58585 .6644 .5776 Mtetra
.6644 .5776 .67174 .58585 .68702 .58142 .67973 .57316 Mtetra
.655 .75 .919 r
.67973 .57316 .68702 .58142 .70238 .57696 .69515 .56869 Mtetra
.655 .751 .92 r
.69515 .56869 .70238 .57696 .71782 .57247 .71065 .56421 Mtetra
.655 .752 .921 r
.71065 .56421 .71782 .57247 .73335 .56794 .72624 .55969 Mtetra
.656 .754 .922 r
.72624 .55969 .73335 .56794 .74896 .56339 .74191 .55511 Mtetra
.657 .755 .922 r
.74191 .55511 .74896 .56339 .76466 .55884 .75767 .55047 Mtetra
.657 .754 .921 r
.75767 .55047 .76466 .55884 .78044 .55429 .77351 .5458 Mtetra
.656 .752 .92 r
.77351 .5458 .78044 .55429 .79631 .54973 .78944 .54115 Mtetra
.655 .75 .92 r
.78944 .54115 .79631 .54973 .81228 .54515 .80547 .53651 Mtetra
.80547 .53651 .81228 .54515 .82833 .54055 .82158 .53187 Mtetra
.82158 .53187 .82833 .54055 .84447 .53587 .83779 .5272 Mtetra
.656 .752 .92 r
.83779 .5272 .84447 .53587 .86069 .53114 .85408 .52246 Mtetra
.657 .753 .921 r
.85408 .52246 .86069 .53114 .877 .5264 .87046 .51765 Mtetra
.656 .752 .921 r
.87046 .51765 .877 .5264 .89341 .52166 .88693 .51283 Mtetra
.656 .751 .92 r
.88693 .51283 .89341 .52166 .90992 .51692 .9035 .50801 Mtetra
.655 .75 .92 r
.9035 .50801 .90992 .51692 .92652 .51216 .92017 .5032 Mtetra
.92017 .5032 .92652 .51216 .94321 .50731 .93693 .49836 Mtetra
.656 .752 .92 r
.93693 .49836 .94321 .50731 .95999 .50243 .95379 .49343 Mtetra
.656 .752 .921 r
.35209 .6586 .36056 .66596 .37428 .66199 .36586 .65455 Mtetra
.657 .751 .919 r
.36586 .65455 .37428 .66199 .38808 .65796 .3797 .65046 Mtetra
.656 .751 .92 r
.3797 .65046 .38808 .65796 .40194 .65389 .39362 .64638 Mtetra
.655 .751 .92 r
.39362 .64638 .40194 .65389 .41588 .64983 .4076 .64231 Mtetra
.654 .752 .921 r
.4076 .64231 .41588 .64983 .42989 .64578 .42165 .63825 Mtetra
.656 .753 .921 r
.42165 .63825 .42989 .64578 .44397 .64173 .43578 .63411 Mtetra
.657 .752 .92 r
.43578 .63411 .44397 .64173 .45813 .63762 .44999 .62991 Mtetra
.657 .75 .919 r
.44999 .62991 .45813 .63762 .47236 .63343 .46427 .62569 Mtetra
.656 .75 .919 r
.46427 .62569 .47236 .63343 .48667 .62923 .47862 .62147 Mtetra
.654 .75 .92 r
.47862 .62147 .48667 .62923 .50105 .62503 .49305 .6173 Mtetra
.654 .752 .922 r
.49305 .6173 .50105 .62503 .51551 .62084 .50756 .61312 Mtetra
.655 .754 .923 r
.50756 .61312 .51551 .62084 .53004 .61667 .52214 .60888 Mtetra
.656 .754 .921 r
.52214 .60888 .53004 .61667 .54465 .61247 .53681 .60456 Mtetra
.657 .752 .92 r
.53681 .60456 .54465 .61247 .55934 .60823 .55155 .60021 Mtetra
.657 .75 .918 r
.55155 .60021 .55934 .60823 .57411 .60392 .56637 .59583 Mtetra
.657 .749 .918 r
.56637 .59583 .57411 .60392 .58896 .59958 .58126 .59143 Mtetra
.58126 .59143 .58896 .59958 .60388 .59522 .59624 .58702 Mtetra
.656 .748 .918 r
.59624 .58702 .60388 .59522 .61889 .59084 .6113 .58259 Mtetra
.6113 .58259 .61889 .59084 .63398 .58644 .62644 .57816 Mtetra
.62644 .57816 .63398 .58644 .64915 .58203 .64167 .5737 Mtetra
.64167 .5737 .64915 .58203 .6644 .5776 .65697 .56923 Mtetra
.65697 .56923 .6644 .5776 .67973 .57316 .67237 .56474 Mtetra
.655 .748 .918 r
.67237 .56474 .67973 .57316 .69515 .56869 .68784 .56023 Mtetra
.68784 .56023 .69515 .56869 .71065 .56421 .7034 .55572 Mtetra
.655 .749 .919 r
.7034 .55572 .71065 .56421 .72624 .55969 .71905 .55118 Mtetra
.71905 .55118 .72624 .55969 .74191 .55511 .73479 .54662 Mtetra
.655 .751 .92 r
.73479 .54662 .74191 .55511 .75767 .55047 .75061 .54202 Mtetra
.656 .754 .922 r
.75061 .54202 .75767 .55047 .77351 .5458 .76652 .53733 Mtetra
.657 .755 .922 r
.76652 .53733 .77351 .5458 .78944 .54115 .78251 .53258 Mtetra
.657 .753 .921 r
.78251 .53258 .78944 .54115 .80547 .53651 .79859 .52782 Mtetra
.655 .751 .92 r
.79859 .52782 .80547 .53651 .82158 .53187 .81477 .5231 Mtetra
.655 .75 .92 r
.81477 .5231 .82158 .53187 .83779 .5272 .83104 .51838 Mtetra
.83104 .51838 .83779 .5272 .85408 .52246 .8474 .51364 Mtetra
.656 .751 .92 r
.8474 .51364 .85408 .52246 .87046 .51765 .86385 .50883 Mtetra
.657 .753 .921 r
.86385 .50883 .87046 .51765 .88693 .51283 .88039 .50393 Mtetra
.656 .752 .921 r
.88039 .50393 .88693 .51283 .9035 .50801 .89702 .49904 Mtetra
.656 .751 .92 r
.89702 .49904 .9035 .50801 .92017 .5032 .91376 .49415 Mtetra
.655 .75 .92 r
.91376 .49415 .92017 .5032 .93693 .49836 .93059 .48927 Mtetra
.655 .751 .92 r
.93059 .48927 .93693 .49836 .95379 .49343 .94752 .48433 Mtetra
.657 .752 .92 r
.34355 .65114 .35209 .6586 .36586 .65455 .35737 .64703 Mtetra
.656 .751 .919 r
.35737 .64703 .36586 .65455 .3797 .65046 .37125 .64292 Mtetra
.655 .751 .92 r
.37125 .64292 .3797 .65046 .39362 .64638 .38521 .63882 Mtetra
.654 .751 .921 r
.38521 .63882 .39362 .64638 .4076 .64231 .39923 .63475 Mtetra
.656 .752 .921 r
.39923 .63475 .4076 .64231 .42165 .63825 .41334 .6306 Mtetra
.657 .752 .92 r
.41334 .6306 .42165 .63825 .43578 .63411 .42751 .62637 Mtetra
.657 .751 .919 r
.42751 .62637 .43578 .63411 .44999 .62991 .44177 .62213 Mtetra
.656 .75 .919 r
.44177 .62213 .44999 .62991 .46427 .62569 .45609 .6179 Mtetra
.654 .751 .921 r
.45609 .6179 .46427 .62569 .47862 .62147 .47049 .61373 Mtetra
.654 .753 .922 r
.47049 .61373 .47862 .62147 .49305 .6173 .48497 .60954 Mtetra
.656 .754 .922 r
.48497 .60954 .49305 .6173 .50756 .61312 .49953 .60524 Mtetra
.657 .752 .92 r
.49953 .60524 .50756 .61312 .52214 .60888 .51417 .60088 Mtetra
.658 .75 .918 r
.51417 .60088 .52214 .60888 .53681 .60456 .52888 .59648 Mtetra
.657 .749 .918 r
.52888 .59648 .53681 .60456 .55155 .60021 .54367 .59207 Mtetra
.54367 .59207 .55155 .60021 .56637 .59583 .55854 .58766 Mtetra
.656 .749 .918 r
.55854 .58766 .56637 .59583 .58126 .59143 .57349 .58325 Mtetra
.655 .749 .919 r
.57349 .58325 .58126 .59143 .59624 .58702 .58853 .57887 Mtetra
.655 .751 .921 r
.58853 .57887 .59624 .58702 .6113 .58259 .60364 .57446 Mtetra
.655 .753 .922 r
.60364 .57446 .6113 .58259 .62644 .57816 .61884 .57 Mtetra
.656 .754 .922 r
.61884 .57 .62644 .57816 .64167 .5737 .63412 .5655 Mtetra
.63412 .5655 .64167 .5737 .65697 .56923 .64948 .56096 Mtetra
.657 .753 .921 r
.64948 .56096 .65697 .56923 .67237 .56474 .66493 .55637 Mtetra
.657 .752 .92 r
.66493 .55637 .67237 .56474 .68784 .56023 .68046 .55174 Mtetra
.656 .75 .919 r
.68046 .55174 .68784 .56023 .7034 .55572 .69608 .54714 Mtetra
.655 .749 .918 r
.69608 .54714 .7034 .55572 .71905 .55118 .71179 .54254 Mtetra
.655 .748 .918 r
.71179 .54254 .71905 .55118 .73479 .54662 .72758 .53795 Mtetra
.654 .748 .919 r
.72758 .53795 .73479 .54662 .75061 .54202 .74347 .53333 Mtetra
.655 .749 .919 r
.74347 .53333 .75061 .54202 .76652 .53733 .75944 .52868 Mtetra
.655 .752 .921 r
.75944 .52868 .76652 .53733 .78251 .53258 .7755 .52396 Mtetra
.657 .755 .922 r
.7755 .52396 .78251 .53258 .79859 .52782 .79165 .51913 Mtetra
.658 .754 .921 r
.79165 .51913 .79859 .52782 .81477 .5231 .80788 .51428 Mtetra
.656 .751 .92 r
.80788 .51428 .81477 .5231 .83104 .51838 .82421 .50948 Mtetra
.655 .75 .92 r
.82421 .50948 .83104 .51838 .8474 .51364 .84064 .50468 Mtetra
.84064 .50468 .8474 .51364 .86385 .50883 .85717 .49987 Mtetra
.656 .751 .92 r
.85717 .49987 .86385 .50883 .88039 .50393 .87378 .49497 Mtetra
.657 .753 .921 r
.87378 .49497 .88039 .50393 .89702 .49904 .89048 .48999 Mtetra
.656 .752 .92 r
.89048 .48999 .89702 .49904 .91376 .49415 .90728 .48502 Mtetra
.655 .751 .92 r
.90728 .48502 .91376 .49415 .93059 .48927 .92418 .48007 Mtetra
.655 .75 .92 r
.92418 .48007 .93059 .48927 .94752 .48433 .94118 .4751 Mtetra
.657 .751 .919 r
.33493 .64359 .34355 .65114 .35737 .64703 .34879 .63945 Mtetra
.656 .751 .92 r
.34879 .63945 .35737 .64703 .37125 .64292 .36271 .63532 Mtetra
.654 .751 .921 r
.36271 .63532 .37125 .64292 .38521 .63882 .37671 .63122 Mtetra
.655 .752 .921 r
.37671 .63122 .38521 .63882 .39923 .63475 .39079 .62707 Mtetra
.657 .752 .92 r
.39079 .62707 .39923 .63475 .41334 .6306 .40494 .62283 Mtetra
.657 .751 .919 r
.40494 .62283 .41334 .6306 .42751 .62637 .41916 .61857 Mtetra
.656 .751 .919 r
.41916 .61857 .42751 .62637 .44177 .62213 .43346 .61431 Mtetra
.654 .751 .921 r
.43346 .61431 .44177 .62213 .45609 .6179 .44784 .61013 Mtetra
.654 .753 .923 r
.44784 .61013 .45609 .6179 .47049 .61373 .46229 .60592 Mtetra
.657 .754 .921 r
.46229 .60592 .47049 .61373 .48497 .60954 .47682 .60157 Mtetra
.658 .751 .919 r
.47682 .60157 .48497 .60954 .49953 .60524 .49142 .59718 Mtetra
.658 .75 .918 r
.49142 .59718 .49953 .60524 .51417 .60088 .50611 .59275 Mtetra
.657 .749 .918 r
.50611 .59275 .51417 .60088 .52888 .59648 .52087 .58833 Mtetra
.655 .749 .919 r
.52087 .58833 .52888 .59648 .54367 .59207 .53572 .58398 Mtetra
.653 .751 .922 r
.53572 .58398 .54367 .59207 .55854 .58766 .55064 .57966 Mtetra
.653 .754 .924 r
.55064 .57966 .55854 .58766 .57349 .58325 .56565 .5753 Mtetra
.654 .757 .926 r
.56565 .5753 .57349 .58325 .58853 .57887 .58074 .57089 Mtetra
.655 .758 .925 r
.58074 .57089 .58853 .57887 .60364 .57446 .59591 .56639 Mtetra
.656 .757 .924 r
.59591 .56639 .60364 .57446 .61884 .57 .61116 .56186 Mtetra
.655 .756 .924 r
.61116 .56186 .61884 .57 .63412 .5655 .6265 .55731 Mtetra
.6265 .55731 .63412 .5655 .64948 .56096 .64192 .55275 Mtetra
.655 .757 .924 r
.64192 .55275 .64948 .56096 .66493 .55637 .65743 .54815 Mtetra
.657 .758 .925 r
.65743 .54815 .66493 .55637 .68046 .55174 .67302 .54347 Mtetra
.658 .758 .924 r
.67302 .54347 .68046 .55174 .69608 .54714 .6887 .53873 Mtetra
.658 .756 .922 r
.6887 .53873 .69608 .54714 .71179 .54254 .70446 .53395 Mtetra
.657 .752 .92 r
.70446 .53395 .71179 .54254 .72758 .53795 .72031 .5292 Mtetra
.655 .749 .919 r
.72031 .5292 .72758 .53795 .74347 .53333 .73625 .52452 Mtetra
.654 .748 .919 r
.73625 .52452 .74347 .53333 .75944 .52868 .75229 .51984 Mtetra
.654 .749 .919 r
.75229 .51984 .75944 .52868 .7755 .52396 .76842 .51513 Mtetra
.655 .75 .92 r
.76842 .51513 .7755 .52396 .79165 .51913 .78463 .51036 Mtetra
.658 .754 .921 r
.78463 .51036 .79165 .51913 .80788 .51428 .80093 .50545 Mtetra
.80093 .50545 .80788 .51428 .82421 .50948 .81733 .50051 Mtetra
.655 .751 .92 r
.81733 .50051 .82421 .50948 .84064 .50468 .83382 .49564 Mtetra
.655 .75 .92 r
.83382 .49564 .84064 .50468 .85717 .49987 .85041 .49077 Mtetra
.85041 .49077 .85717 .49987 .87378 .49497 .86709 .48587 Mtetra
.656 .752 .92 r
.86709 .48587 .87378 .49497 .89048 .48999 .88387 .48087 Mtetra
.657 .753 .921 r
.88387 .48087 .89048 .48999 .90728 .48502 .90073 .47582 Mtetra
.656 .752 .92 r
.90073 .47582 .90728 .48502 .92418 .48007 .9177 .47078 Mtetra
.655 .751 .92 r
.9177 .47078 .92418 .48007 .94118 .4751 .93478 .46576 Mtetra
.656 .751 .92 r
.32622 .63596 .33493 .64359 .34879 .63945 .34012 .6318 Mtetra
.655 .751 .921 r
.34012 .6318 .34879 .63945 .36271 .63532 .35409 .62767 Mtetra
.654 .752 .921 r
.35409 .62767 .36271 .63532 .37671 .63122 .36814 .62353 Mtetra
.657 .752 .92 r
.36814 .62353 .37671 .63122 .39079 .62707 .38226 .61928 Mtetra
.657 .751 .919 r
.38226 .61928 .39079 .62707 .40494 .62283 .39646 .61499 Mtetra
.656 .751 .919 r
.39646 .61499 .40494 .62283 .41916 .61857 .41073 .61071 Mtetra
.654 .75 .921 r
.41073 .61071 .41916 .61857 .43346 .61431 .42507 .6065 Mtetra
.653 .753 .923 r
.42507 .6065 .43346 .61431 .44784 .61013 .4395 .60228 Mtetra
.657 .754 .921 r
.4395 .60228 .44784 .61013 .46229 .60592 .454 .59791 Mtetra
.658 .751 .919 r
.454 .59791 .46229 .60592 .47682 .60157 .46858 .59348 Mtetra
.658 .75 .918 r
.46858 .59348 .47682 .60157 .49142 .59718 .48324 .58902 Mtetra
.656 .749 .918 r
.48324 .58902 .49142 .59718 .50611 .59275 .49797 .58462 Mtetra
.652 .75 .921 r
.49797 .58462 .50611 .59275 .52087 .58833 .51279 .58034 Mtetra
.652 .754 .925 r
.51279 .58034 .52087 .58833 .53572 .58398 .52769 .57603 Mtetra
.655 .757 .925 r
.52769 .57603 .53572 .58398 .55064 .57966 .54266 .57156 Mtetra
.657 .755 .922 r
.54266 .57156 .55064 .57966 .56565 .5753 .55772 .56702 Mtetra
.656 .752 .92 r
.55772 .56702 .56565 .5753 .58074 .57089 .57287 .56248 Mtetra
.656 .749 .919 r
.57287 .56248 .58074 .57089 .59591 .56639 .58809 .55793 Mtetra
.58809 .55793 .59591 .56639 .61116 .56186 .6034 .55337 Mtetra
.6034 .55337 .61116 .56186 .6265 .55731 .6188 .54878 Mtetra
.656 .75 .919 r
.6188 .54878 .6265 .55731 .64192 .55275 .63428 .54415 Mtetra
.656 .749 .919 r
.63428 .54415 .64192 .55275 .65743 .54815 .64984 .53951 Mtetra
.655 .749 .919 r
.64984 .53951 .65743 .54815 .67302 .54347 .66549 .53487 Mtetra
.655 .751 .921 r
.66549 .53487 .67302 .54347 .6887 .53873 .68123 .53022 Mtetra
.656 .755 .923 r
.68123 .53022 .6887 .53873 .70446 .53395 .69706 .52549 Mtetra
.659 .758 .924 r
.69706 .52549 .70446 .53395 .72031 .5292 .71297 .52061 Mtetra
.659 .757 .922 r
.71297 .52061 .72031 .5292 .73625 .52452 .72897 .5157 Mtetra
.656 .751 .92 r
.72897 .5157 .73625 .52452 .75229 .51984 .74506 .51089 Mtetra
.654 .748 .919 r
.74506 .51089 .75229 .51984 .76842 .51513 .76125 .50615 Mtetra
.76125 .50615 .76842 .51513 .78463 .51036 .77754 .50137 Mtetra
.655 .75 .92 r
.77754 .50137 .78463 .51036 .80093 .50545 .79391 .49653 Mtetra
.658 .754 .921 r
.79391 .49653 .80093 .50545 .81733 .50051 .81037 .49154 Mtetra
.81037 .49154 .81733 .50051 .83382 .49564 .82692 .48652 Mtetra
.655 .751 .92 r
.82692 .48652 .83382 .49564 .85041 .49077 .84358 .48158 Mtetra
.654 .75 .92 r
.84358 .48158 .85041 .49077 .86709 .48587 .86033 .47663 Mtetra
.655 .75 .92 r
.86033 .47663 .86709 .48587 .88387 .48087 .87718 .47165 Mtetra
.657 .753 .92 r
.87718 .47165 .88387 .48087 .90073 .47582 .89412 .46654 Mtetra
.657 .753 .921 r
.89412 .46654 .90073 .47582 .9177 .47078 .91116 .46142 Mtetra
.656 .751 .92 r
.91116 .46142 .9177 .47078 .93478 .46576 .9283 .45631 Mtetra
.31743 .62828 .32622 .63596 .34012 .6318 .33137 .6241 Mtetra
.654 .751 .921 r
.33137 .6241 .34012 .6318 .35409 .62767 .34539 .61995 Mtetra
.656 .752 .921 r
.34539 .61995 .35409 .62767 .36814 .62353 .35948 .61572 Mtetra
.657 .751 .919 r
.35948 .61572 .36814 .62353 .38226 .61928 .37365 .6114 Mtetra
.37365 .6114 .38226 .61928 .39646 .61499 .3879 .60709 Mtetra
.654 .751 .92 r
.3879 .60709 .39646 .61499 .41073 .61071 .40221 .60284 Mtetra
.653 .752 .922 r
.40221 .60284 .41073 .61071 .42507 .6065 .4166 .59861 Mtetra
.656 .753 .921 r
.4166 .59861 .42507 .6065 .4395 .60228 .43108 .59423 Mtetra
.658 .751 .919 r
.43108 .59423 .4395 .60228 .454 .59791 .44563 .58978 Mtetra
.658 .75 .918 r
.44563 .58978 .454 .59791 .46858 .59348 .46026 .5853 Mtetra
.655 .749 .919 r
.46026 .5853 .46858 .59348 .48324 .58902 .47497 .58092 Mtetra
.651 .751 .923 r
.47497 .58092 .48324 .58902 .49797 .58462 .48975 .57665 Mtetra
.653 .756 .925 r
.48975 .57665 .49797 .58462 .51279 .58034 .50462 .57226 Mtetra
.657 .755 .922 r
.50462 .57226 .51279 .58034 .52769 .57603 .51957 .5677 Mtetra
.656 .75 .919 r
.51957 .5677 .52769 .57603 .54266 .57156 .5346 .56318 Mtetra
.657 .75 .919 r
.5346 .56318 .54266 .57156 .55772 .56702 .54972 .5586 Mtetra
.655 .75 .92 r
.54972 .5586 .55772 .56702 .57287 .56248 .56492 .55408 Mtetra
.652 .751 .922 r
.56492 .55408 .57287 .56248 .58809 .55793 .5802 .54962 Mtetra
.653 .754 .924 r
.5802 .54962 .58809 .55793 .6034 .55337 .59557 .5451 Mtetra
.655 .757 .925 r
.59557 .5451 .6034 .55337 .6188 .54878 .61102 .54046 Mtetra
.658 .758 .924 r
.61102 .54046 .6188 .54878 .63428 .54415 .62655 .5357 Mtetra
.659 .756 .922 r
.62655 .5357 .63428 .54415 .64984 .53951 .64217 .53088 Mtetra
.657 .752 .92 r
.64217 .53088 .64984 .53951 .66549 .53487 .65788 .52612 Mtetra
.655 .75 .919 r
.65788 .52612 .66549 .53487 .68123 .53022 .67368 .52141 Mtetra
.656 .75 .919 r
.67368 .52141 .68123 .53022 .69706 .52549 .68957 .51665 Mtetra
.654 .749 .92 r
.68957 .51665 .69706 .52549 .71297 .52061 .70555 .51192 Mtetra
.657 .756 .922 r
.70555 .51192 .71297 .52061 .72897 .5157 .72162 .50702 Mtetra
.66 .758 .923 r
.72162 .50702 .72897 .5157 .74506 .51089 .73777 .50199 Mtetra
.657 .753 .921 r
.73777 .50199 .74506 .51089 .76125 .50615 .75401 .49707 Mtetra
.654 .748 .919 r
.75401 .49707 .76125 .50615 .77754 .50137 .77036 .49225 Mtetra
.654 .749 .919 r
.77036 .49225 .77754 .50137 .79391 .49653 .78681 .4874 Mtetra
.655 .75 .92 r
.78681 .4874 .79391 .49653 .81037 .49154 .80334 .48247 Mtetra
.658 .754 .921 r
.80334 .48247 .81037 .49154 .82692 .48652 .81996 .47738 Mtetra
.657 .753 .921 r
.81996 .47738 .82692 .48652 .84358 .48158 .83668 .47231 Mtetra
.655 .751 .92 r
.83668 .47231 .84358 .48158 .86033 .47663 .8535 .46729 Mtetra
.654 .75 .92 r
.8535 .46729 .86033 .47663 .87718 .47165 .87042 .46227 Mtetra
.656 .751 .92 r
.87042 .46227 .87718 .47165 .89412 .46654 .88744 .45716 Mtetra
.657 .753 .92 r
.88744 .45716 .89412 .46654 .91116 .46142 .90455 .45196 Mtetra
.656 .752 .92 r
.90455 .45196 .91116 .46142 .9283 .45631 .92176 .44678 Mtetra
.655 .751 .921 r
.30855 .62053 .31743 .62828 .33137 .6241 .32254 .61634 Mtetra
.654 .752 .921 r
.32254 .61634 .33137 .6241 .34539 .61995 .3366 .61214 Mtetra
.657 .752 .92 r
.3366 .61214 .34539 .61995 .35948 .61572 .35074 .60781 Mtetra
.657 .751 .919 r
.35074 .60781 .35948 .61572 .37365 .6114 .36496 .60346 Mtetra
.656 .751 .92 r
.36496 .60346 .37365 .6114 .3879 .60709 .37925 .59914 Mtetra
.653 .751 .922 r
.37925 .59914 .3879 .60709 .40221 .60284 .39361 .59491 Mtetra
.655 .753 .922 r
.39361 .59491 .40221 .60284 .4166 .59861 .40805 .59055 Mtetra
.658 .752 .919 r
.40805 .59055 .4166 .59861 .43108 .59423 .42258 .58608 Mtetra
.659 .751 .918 r
.42258 .58608 .43108 .59423 .44563 .58978 .43718 .58157 Mtetra
.655 .749 .919 r
.43718 .58157 .44563 .58978 .46026 .5853 .45186 .57716 Mtetra
.65 .751 .923 r
.45186 .57716 .46026 .5853 .47497 .58092 .46661 .57289 Mtetra
.655 .756 .924 r
.46661 .57289 .47497 .58092 .48975 .57665 .48145 .56844 Mtetra
.657 .753 .921 r
.48145 .56844 .48975 .57665 .50462 .57226 .49637 .56387 Mtetra
.657 .75 .918 r
.49637 .56387 .50462 .57226 .51957 .5677 .51138 .5593 Mtetra
.651 .749 .921 r
.51138 .5593 .51957 .5677 .5346 .56318 .52646 .55491 Mtetra
.639 .75 .928 r
.52646 .55491 .5346 .56318 .54972 .5586 .54163 .5509 Mtetra
.621 .76 .945 r
.54163 .5509 .54972 .5586 .56492 .55408 .5569 .54736 Mtetra
.615 .786 .963 r
.5569 .54736 .56492 .55408 .5802 .54962 .57226 .54372 Mtetra
.621 .813 .974 r
.57226 .54372 .5802 .54962 .59557 .5451 .58771 .53963 Mtetra
.636 .832 .976 r
.58771 .53963 .59557 .5451 .61102 .54046 .60323 .53495 Mtetra
.656 .837 .97 r
.60323 .53495 .61102 .54046 .62655 .5357 .61882 .52967 Mtetra
.674 .829 .958 r
.61882 .52967 .62655 .5357 .64217 .53088 .63449 .52393 Mtetra
.681 .806 .942 r
.63449 .52393 .64217 .53088 .65788 .52612 .65023 .51809 Mtetra
.67 .775 .929 r
.65023 .51809 .65788 .52612 .67368 .52141 .66607 .51272 Mtetra
.66 .756 .921 r
.66607 .51272 .67368 .52141 .68957 .51665 .68201 .50772 Mtetra
.655 .75 .92 r
.68201 .50772 .68957 .51665 .70555 .51192 .69805 .50291 Mtetra
.654 .749 .919 r
.69805 .50291 .70555 .51192 .72162 .50702 .71418 .49809 Mtetra
.656 .753 .921 r
.71418 .49809 .72162 .50702 .73777 .50199 .7304 .49316 Mtetra
.66 .758 .922 r
.7304 .49316 .73777 .50199 .75401 .49707 .74671 .48803 Mtetra
.657 .753 .921 r
.74671 .48803 .75401 .49707 .77036 .49225 .76311 .48303 Mtetra
.653 .748 .92 r
.76311 .48303 .77036 .49225 .78681 .4874 .77962 .47815 Mtetra
.654 .749 .92 r
.77962 .47815 .78681 .4874 .80334 .48247 .79623 .47321 Mtetra
.656 .751 .92 r
.79623 .47321 .80334 .48247 .81996 .47738 .81292 .46816 Mtetra
.658 .754 .921 r
.81292 .46816 .81996 .47738 .83668 .47231 .82971 .46297 Mtetra
.656 .752 .92 r
.82971 .46297 .83668 .47231 .8535 .46729 .84659 .45786 Mtetra
.654 .75 .92 r
.84659 .45786 .8535 .46729 .87042 .46227 .86359 .45278 Mtetra
.655 .75 .92 r
.86359 .45278 .87042 .46227 .88744 .45716 .88068 .44767 Mtetra
.657 .752 .92 r
.88068 .44767 .88744 .45716 .90455 .45196 .89786 .44242 Mtetra
.657 .753 .921 r
.89786 .44242 .90455 .45196 .92176 .44678 .91515 .43716 Mtetra
.654 .751 .921 r
.29959 .61271 .30855 .62053 .32254 .61634 .31362 .6085 Mtetra
.656 .752 .921 r
.31362 .6085 .32254 .61634 .3366 .61214 .32773 .60421 Mtetra
.658 .751 .919 r
.32773 .60421 .3366 .61214 .35074 .60781 .34191 .59983 Mtetra
.657 .751 .919 r
.34191 .59983 .35074 .60781 .36496 .60346 .35618 .59546 Mtetra
.654 .751 .921 r
.35618 .59546 .36496 .60346 .37925 .59914 .37051 .59117 Mtetra
.653 .752 .922 r
.37051 .59117 .37925 .59914 .39361 .59491 .38492 .58686 Mtetra
.658 .753 .92 r
.38492 .58686 .39361 .59491 .40805 .59055 .39942 .58238 Mtetra
.659 .751 .918 r
.39942 .58238 .40805 .59055 .42258 .58608 .41399 .57784 Mtetra
.657 .75 .919 r
.41399 .57784 .42258 .58608 .43718 .58157 .42864 .57335 Mtetra
.65 .75 .922 r
.42864 .57335 .43718 .58157 .45186 .57716 .44336 .56908 Mtetra
.654 .755 .924 r
.44336 .56908 .45186 .57716 .46661 .57289 .45817 .56462 Mtetra
.657 .753 .92 r
.45817 .56462 .46661 .57289 .48145 .56844 .47307 .56003 Mtetra
.656 .75 .919 r
.47307 .56003 .48145 .56844 .49637 .56387 .48804 .55546 Mtetra
.641 .746 .925 r
.48804 .55546 .49637 .56387 .51138 .5593 .50309 .55141 Mtetra
.6 .747 .948 r
.50309 .55141 .51138 .5593 .52646 .55491 .51823 .54855 Mtetra
.555 .775 .98 r
.51823 .54855 .52646 .55491 .54163 .5509 .53347 .54626 Mtetra
.518 .814 .999 r
.53347 .54626 .54163 .5509 .5569 .54736 .54882 .5438 Mtetra
.495 .836 .997 r
.54882 .5438 .5569 .54736 .57226 .54372 .56426 .54101 Mtetra
.507 .864 .989 r
.56426 .54101 .57226 .54372 .58771 .53963 .5798 .53737 Mtetra
.548 .892 .982 r
.5798 .53737 .58771 .53963 .60323 .53495 .59541 .53265 Mtetra
.606 .913 .98 r
.59541 .53265 .60323 .53495 .61882 .52967 .61109 .52683 Mtetra
.659 .917 .977 r
.61109 .52683 .61882 .52967 .63449 .52393 .62681 .52017 Mtetra
.689 .901 .972 r
.62681 .52017 .63449 .52393 .65023 .51809 .6426 .51314 Mtetra
.707 .873 .96 r
.6426 .51314 .65023 .51809 .66607 .51272 .65845 .50594 Mtetra
.698 .82 .941 r
.65845 .50594 .66607 .51272 .68201 .50772 .67439 .49931 Mtetra
.669 .77 .926 r
.67439 .49931 .68201 .50772 .69805 .50291 .69047 .49386 Mtetra
.655 .751 .92 r
.69047 .49386 .69805 .50291 .71418 .49809 .70666 .48895 Mtetra
.654 .749 .92 r
.70666 .48895 .71418 .49809 .7304 .49316 .72295 .48406 Mtetra
.657 .753 .92 r
.72295 .48406 .7304 .49316 .74671 .48803 .73933 .47902 Mtetra
.661 .758 .922 r
.73933 .47902 .74671 .48803 .76311 .48303 .75579 .4738 Mtetra
.655 .751 .92 r
.75579 .4738 .76311 .48303 .77962 .47815 .77236 .46878 Mtetra
.653 .748 .92 r
.77236 .46878 .77962 .47815 .79623 .47321 .78904 .46382 Mtetra
.654 .749 .92 r
.78904 .46382 .79623 .47321 .81292 .46816 .80581 .45879 Mtetra
.658 .753 .92 r
.80581 .45879 .81292 .46816 .82971 .46297 .82266 .45358 Mtetra
.658 .754 .921 r
.82266 .45358 .82971 .46297 .84659 .45786 .83962 .44835 Mtetra
.655 .751 .92 r
.83962 .44835 .84659 .45786 .86359 .45278 .85668 .44319 Mtetra
.654 .75 .92 r
.85668 .44319 .86359 .45278 .88068 .44767 .87384 .43804 Mtetra
.656 .751 .92 r
.87384 .43804 .88068 .44767 .89786 .44242 .89111 .43278 Mtetra
.657 .753 .92 r
.89111 .43278 .89786 .44242 .91515 .43716 .90846 .42743 Mtetra
.654 .751 .921 r
.29053 .60483 .29959 .61271 .31362 .6085 .30461 .60058 Mtetra
.657 .752 .92 r
.30461 .60058 .31362 .6085 .32773 .60421 .31876 .5962 Mtetra
.657 .751 .919 r
.31876 .5962 .32773 .60421 .34191 .59983 .333 .59178 Mtetra
.656 .751 .92 r
.333 .59178 .34191 .59983 .35618 .59546 .34731 .5874 Mtetra
.653 .751 .922 r
.34731 .5874 .35618 .59546 .37051 .59117 .36168 .58311 Mtetra
.656 .753 .921 r
.36168 .58311 .37051 .59117 .38492 .58686 .37615 .57867 Mtetra
.659 .751 .919 r
.37615 .57867 .38492 .58686 .39942 .58238 .39069 .57411 Mtetra
.658 .751 .918 r
.39069 .57411 .39942 .58238 .41399 .57784 .40532 .56955 Mtetra
.651 .749 .921 r
.40532 .56955 .41399 .57784 .42864 .57335 .42001 .5652 Mtetra
.652 .754 .924 r
.42001 .5652 .42864 .57335 .44336 .56908 .43479 .56081 Mtetra
.658 .754 .921 r
.43479 .56081 .44336 .56908 .45817 .56462 .44965 .55618 Mtetra
.656 .75 .919 r
.44965 .55618 .45817 .56462 .47307 .56003 .4646 .55158 Mtetra
.635 .745 .927 r
.4646 .55158 .47307 .56003 .48804 .55546 .47961 .54771 Mtetra
.564 .739 .958 r
.47961 .54771 .48804 .55546 .50309 .55141 .4947 .54571 Mtetra
.481 .767 .994 r
.4947 .54571 .50309 .55141 .51823 .54855 .5099 .54452 Mtetra
.372 .765 .987 r
.5099 .54452 .51823 .54855 .53347 .54626 .52521 .54386 Mtetra
.337 .786 .955 r
.52521 .54386 .53347 .54626 .54882 .5438 .54064 .54233 Mtetra
.377 .825 .939 r
.54064 .54233 .54882 .5438 .56426 .54101 .55617 .53947 Mtetra
.46 .868 .958 r
.55617 .53947 .56426 .54101 .5798 .53737 .57179 .53551 Mtetra
.528 .893 .972 r
.57179 .53551 .5798 .53737 .59541 .53265 .58749 .53075 Mtetra
.574 .911 .973 r
.58749 .53075 .59541 .53265 .61109 .52683 .60327 .52518 Mtetra
.618 .932 .965 r
.60327 .52518 .61109 .52683 .62681 .52017 .61909 .5185 Mtetra
.678 .95 .956 r
.61909 .5185 .62681 .52017 .6426 .51314 .63495 .51047 Mtetra
.732 .94 .953 r
.63495 .51047 .6426 .51314 .65845 .50594 .65083 .50153 Mtetra
.734 .896 .952 r
.65083 .50153 .65845 .50594 .67439 .49931 .66679 .49311 Mtetra
.72 .845 .941 r
.66679 .49311 .67439 .49931 .69047 .49386 .68284 .48549 Mtetra
.674 .776 .927 r
.68284 .48549 .69047 .49386 .70666 .48895 .69907 .47977 Mtetra
.655 .751 .92 r
.69907 .47977 .70666 .48895 .72295 .48406 .71542 .47477 Mtetra
.654 .749 .92 r
.71542 .47477 .72295 .48406 .73933 .47902 .73187 .46982 Mtetra
.659 .755 .92 r
.73187 .46982 .73933 .47902 .75579 .4738 .7484 .46461 Mtetra
.66 .756 .922 r
.7484 .46461 .75579 .4738 .77236 .46878 .76503 .45935 Mtetra
.654 .75 .92 r
.76503 .45935 .77236 .46878 .78904 .46382 .78177 .45432 Mtetra
.653 .749 .92 r
.78177 .45432 .78904 .46382 .80581 .45879 .79861 .44927 Mtetra
.656 .751 .92 r
.79861 .44927 .80581 .45879 .82266 .45358 .81554 .44409 Mtetra
.659 .754 .92 r
.81554 .44409 .82266 .45358 .83962 .44835 .83256 .43875 Mtetra
.656 .752 .921 r
.83256 .43875 .83962 .44835 .85668 .44319 .8497 .43351 Mtetra
.654 .75 .92 r
.8497 .43351 .85668 .44319 .87384 .43804 .86693 .42829 Mtetra
.655 .75 .92 r
.86693 .42829 .87384 .43804 .89111 .43278 .88427 .42302 Mtetra
.657 .753 .92 r
.88427 .42302 .89111 .43278 .90846 .42743 .9017 .41762 Mtetra
.655 .752 .921 r
.28139 .59687 .29053 .60483 .30461 .60058 .29551 .59255 Mtetra
.658 .752 .919 r
.29551 .59255 .30461 .60058 .31876 .5962 .30971 .58811 Mtetra
.657 .751 .919 r
.30971 .58811 .31876 .5962 .333 .59178 .32399 .58366 Mtetra
.654 .751 .921 r
.32399 .58366 .333 .59178 .34731 .5874 .33834 .57929 Mtetra
.653 .752 .922 r
.33834 .57929 .34731 .5874 .36168 .58311 .35277 .57493 Mtetra
.658 .753 .92 r
.35277 .57493 .36168 .58311 .37615 .57867 .36729 .57039 Mtetra
.659 .751 .918 r
.36729 .57039 .37615 .57867 .39069 .57411 .38188 .56577 Mtetra
.655 .75 .919 r
.38188 .56577 .39069 .57411 .40532 .56955 .39655 .56127 Mtetra
.649 .751 .924 r
.39655 .56127 .40532 .56955 .42001 .5652 .41129 .55695 Mtetra
.657 .755 .922 r
.41129 .55695 .42001 .5652 .43479 .56081 .42613 .55232 Mtetra
.657 .75 .919 r
.42613 .55232 .43479 .56081 .44965 .55618 .44104 .54767 Mtetra
.64 .746 .925 r
.44104 .54767 .44965 .55618 .4646 .55158 .45603 .54361 Mtetra
.559 .732 .956 r
.45603 .54361 .4646 .55158 .47961 .54771 .47107 .54178 Mtetra
.437 .741 .992 r
.47107 .54178 .47961 .54771 .4947 .54571 .4862 .54142 Mtetra
.286 .711 .97 r
.4862 .54142 .4947 .54571 .5099 .54452 .50144 .54203 Mtetra
.302 .764 .947 r
.50144 .54203 .5099 .54452 .52521 .54386 .51683 .54097 Mtetra
.531 .87 .992 r
.51683 .54097 .52521 .54386 .54064 .54233 .53233 .53704 Mtetra
.65 .844 .975 r
.53233 .53704 .54064 .54233 .55617 .53947 .54791 .53179 Mtetra
.669 .785 .935 r
.54791 .53179 .55617 .53947 .57179 .53551 .56358 .52638 Mtetra
.655 .746 .917 r
.56358 .52638 .57179 .53551 .58749 .53075 .57934 .52157 Mtetra
.638 .74 .922 r
.57934 .52157 .58749 .53075 .60327 .52518 .5952 .51736 Mtetra
.637 .775 .947 r
.5952 .51736 .60327 .52518 .61909 .5185 .61116 .51298 Mtetra
.66 .847 .972 r
.61116 .51298 .61909 .5185 .63495 .51047 .62717 .50728 Mtetra
.726 .928 .958 r
.62717 .50728 .63495 .51047 .65083 .50153 .64317 .49867 Mtetra
.77 .942 .936 r
.64317 .49867 .65083 .50153 .66679 .49311 .65915 .48833 Mtetra
.757 .893 .939 r
.65915 .48833 .66679 .49311 .68284 .48549 .67522 .47896 Mtetra
.725 .841 .936 r
.67522 .47896 .68284 .48549 .69907 .47977 .69142 .47105 Mtetra
.669 .77 .925 r
.69142 .47105 .69907 .47977 .71542 .47477 .7078 .46542 Mtetra
.655 .75 .92 r
.7078 .46542 .71542 .47477 .73187 .46982 .72432 .46038 Mtetra
.654 .749 .92 r
.72432 .46038 .73187 .46982 .7484 .46461 .74093 .45531 Mtetra
.662 .757 .921 r
.74093 .45531 .7484 .46461 .76503 .45935 .75762 .44992 Mtetra
.656 .753 .921 r
.75762 .44992 .76503 .45935 .78177 .45432 .77442 .44472 Mtetra
.653 .749 .92 r
.77442 .44472 .78177 .45432 .79861 .44927 .79134 .43963 Mtetra
.654 .75 .92 r
.79134 .43963 .79861 .44927 .81554 .44409 .80834 .43446 Mtetra
.658 .753 .92 r
.80834 .43446 .81554 .44409 .83256 .43875 .82544 .42909 Mtetra
.657 .753 .921 r
.82544 .42909 .83256 .43875 .8497 .43351 .84264 .42372 Mtetra
.655 .751 .92 r
.84264 .42372 .8497 .43351 .86693 .42829 .85995 .41844 Mtetra
.654 .75 .92 r
.85995 .41844 .86693 .42829 .88427 .42302 .87736 .41313 Mtetra
.657 .752 .92 r
.87736 .41313 .88427 .42302 .9017 .41762 .89487 .40769 Mtetra
.656 .752 .921 r
.27215 .58883 .28139 .59687 .29551 .59255 .28632 .58443 Mtetra
.658 .752 .919 r
.28632 .58443 .29551 .59255 .30971 .58811 .30057 .57995 Mtetra
.657 .751 .92 r
.30057 .57995 .30971 .58811 .32399 .58366 .3149 .57547 Mtetra
.653 .751 .921 r
.3149 .57547 .32399 .58366 .33834 .57929 .32929 .57109 Mtetra
.655 .752 .921 r
.32929 .57109 .33834 .57929 .35277 .57493 .34377 .56664 Mtetra
.659 .752 .919 r
.34377 .56664 .35277 .57493 .36729 .57039 .35834 .56202 Mtetra
.659 .751 .918 r
.35834 .56202 .36729 .57039 .38188 .56577 .37298 .55737 Mtetra
.652 .749 .921 r
.37298 .55737 .38188 .56577 .39655 .56127 .3877 .55295 Mtetra
.652 .753 .924 r
.3877 .55295 .39655 .56127 .41129 .55695 .40249 .54849 Mtetra
.658 .752 .92 r
.40249 .54849 .41129 .55695 .42613 .55232 .41738 .5438 Mtetra
.652 .75 .921 r
.41738 .5438 .42613 .55232 .44104 .54767 .43234 .53929 Mtetra
.589 .734 .944 r
.43234 .53929 .44104 .54767 .45603 .54361 .44734 .53675 Mtetra
.452 .722 .983 r
.44734 .53675 .45603 .54361 .47107 .54178 .4624 .5366 Mtetra
.268 .677 .968 r
.4624 .5366 .47107 .54178 .4862 .54142 .47756 .53805 Mtetra
.323 .757 .969 r
.47756 .53805 .4862 .54142 .50144 .54203 .49289 .53743 Mtetra
.628 .857 .986 r
.49289 .53743 .50144 .54203 .51683 .54097 .50836 .53253 Mtetra
.723 .779 .896 r
.50836 .53253 .51683 .54097 .53233 .53704 .52391 .52478 Mtetra
.733 .709 .829 r
.52391 .52478 .53233 .53704 .54791 .53179 .53952 .51521 Mtetra
.686 .636 .794 r
.53952 .51521 .54791 .53179 .56358 .52638 .55519 .50745 Mtetra
.638 .59 .784 r
.55519 .50745 .56358 .52638 .57934 .52157 .57096 .50257 Mtetra
.592 .566 .794 r
.57096 .50257 .57934 .52157 .5952 .51736 .58688 .50059 Mtetra
.554 .572 .826 r
.58688 .50059 .5952 .51736 .61116 .51298 .60296 .50044 Mtetra
.585 .652 .882 r
.60296 .50044 .61116 .51298 .62717 .50728 .61913 .49848 Mtetra
.65 .759 .929 r
.61913 .49848 .62717 .50728 .64317 .49867 .63533 .49365 Mtetra
.752 .886 .939 r
.63533 .49365 .64317 .49867 .65915 .48833 .65145 .48448 Mtetra
.796 .922 .921 r
.65145 .48448 .65915 .48833 .67522 .47896 .66754 .47318 Mtetra
.764 .87 .926 r
.66754 .47318 .67522 .47896 .69142 .47105 .68374 .46346 Mtetra
.708 .812 .93 r
.68374 .46346 .69142 .47105 .7078 .46542 .70012 .45617 Mtetra
.659 .757 .922 r
.70012 .45617 .7078 .46542 .72432 .46038 .71669 .45089 Mtetra
.654 .75 .921 r
.71669 .45089 .72432 .46038 .74093 .45531 .73337 .44578 Mtetra
.659 .753 .919 r
.73337 .44578 .74093 .45531 .75762 .44992 .75014 .44044 Mtetra
.66 .755 .921 r
.75014 .44044 .75762 .44992 .77442 .44472 .767 .43504 Mtetra
.653 .75 .921 r
.767 .43504 .77442 .44472 .79134 .43963 .78398 .42988 Mtetra
.653 .749 .92 r
.78398 .42988 .79134 .43963 .80834 .43446 .80106 .42468 Mtetra
.657 .751 .92 r
.80106 .42468 .80834 .43446 .82544 .42909 .81823 .41931 Mtetra
.658 .753 .92 r
.81823 .41931 .82544 .42909 .84264 .42372 .8355 .41384 Mtetra
.655 .751 .92 r
.8355 .41384 .84264 .42372 .85995 .41844 .85288 .40848 Mtetra
.654 .75 .92 r
.85288 .40848 .85995 .41844 .87736 .41313 .87038 .40312 Mtetra
.656 .751 .92 r
.87038 .40312 .87736 .41313 .89487 .40769 .88797 .39766 Mtetra
.656 .752 .92 r
.26283 .5807 .27215 .58883 .28632 .58443 .27704 .57624 Mtetra
.658 .752 .919 r
.27704 .57624 .28632 .58443 .30057 .57995 .29134 .5717 Mtetra
.656 .751 .92 r
.29134 .5717 .30057 .57995 .3149 .57547 .30571 .5672 Mtetra
.652 .751 .922 r
.30571 .5672 .3149 .57547 .32929 .57109 .32015 .56281 Mtetra
.656 .752 .921 r
.32015 .56281 .32929 .57109 .34377 .56664 .33468 .55825 Mtetra
.659 .752 .919 r
.33468 .55825 .34377 .56664 .35834 .56202 .3493 .55357 Mtetra
.658 .751 .919 r
.3493 .55357 .35834 .56202 .37298 .55737 .36399 .54891 Mtetra
.649 .749 .923 r
.36399 .54891 .37298 .55737 .3877 .55295 .37875 .54454 Mtetra
.656 .754 .922 r
.37875 .54454 .3877 .55295 .40249 .54849 .3936 .53989 Mtetra
.657 .751 .919 r
.3936 .53989 .40249 .54849 .41738 .5438 .40854 .53517 Mtetra
.634 .744 .927 r
.40854 .53517 .41738 .5438 .43234 .53929 .42354 .53122 Mtetra
.512 .715 .964 r
.42354 .53122 .43234 .53929 .44734 .53675 .43854 .53041 Mtetra
.321 .675 .977 r
.43854 .53041 .44734 .53675 .4624 .5366 .45362 .5319 Mtetra
.266 .692 .966 r
.45362 .5319 .4624 .5366 .47756 .53805 .46884 .53295 Mtetra
.617 .84 .985 r
.46884 .53295 .47756 .53805 .49289 .53743 .48427 .52848 Mtetra
.759 .775 .866 r
.48427 .52848 .49289 .53743 .50836 .53253 .49984 .51851 Mtetra
.766 .696 .785 r
.49984 .51851 .50836 .53253 .52391 .52478 .51545 .50498 Mtetra
.717 .621 .75 r
.51545 .50498 .52391 .52478 .53952 .51521 .53107 .49306 Mtetra
.672 .582 .746 r
.53107 .49306 .53952 .51521 .55519 .50745 .54674 .48462 Mtetra
.629 .555 .752 r
.54674 .48462 .55519 .50745 .57096 .50257 .56251 .47967 Mtetra
.581 .528 .76 r
.56251 .47967 .57096 .50257 .58688 .50059 .57842 .47823 Mtetra
.522 .499 .771 r
.57842 .47823 .58688 .50059 .60296 .50044 .59454 .48031 Mtetra
.481 .495 .796 r
.59454 .48031 .60296 .50044 .61913 .49848 .61086 .48406 Mtetra
.535 .598 .864 r
.61086 .48406 .61913 .49848 .63533 .49365 .62725 .48424 Mtetra
.662 .752 .917 r
.62725 .48424 .63533 .49365 .65145 .48448 .64358 .47887 Mtetra
.789 .877 .912 r
.64358 .47887 .65145 .48448 .66754 .47318 .65979 .46788 Mtetra
.798 .888 .91 r
.65979 .46788 .66754 .47318 .68374 .46346 .676 .45639 Mtetra
.749 .838 .919 r
.676 .45639 .68374 .46346 .70012 .45617 .69237 .44724 Mtetra
.674 .772 .924 r
.69237 .44724 .70012 .45617 .71669 .45089 .70898 .44127 Mtetra
.654 .75 .92 r
.70898 .44127 .71669 .45089 .73337 .44578 .72573 .43609 Mtetra
.656 .75 .919 r
.72573 .43609 .73337 .44578 .75014 .44044 .74257 .43083 Mtetra
.662 .756 .92 r
.74257 .43083 .75014 .44044 .767 .43504 .7595 .42529 Mtetra
.654 .751 .921 r
.7595 .42529 .767 .43504 .78398 .42988 .77654 .42003 Mtetra
.653 .749 .92 r
.77654 .42003 .78398 .42988 .80106 .42468 .7937 .41479 Mtetra
.656 .751 .92 r
.7937 .41479 .80106 .42468 .81823 .41931 .81095 .40941 Mtetra
.659 .753 .92 r
.81095 .40941 .81823 .41931 .8355 .41384 .82829 .40386 Mtetra
.655 .751 .92 r
.82829 .40386 .8355 .41384 .85288 .40848 .84574 .39842 Mtetra
.654 .75 .921 r
.84574 .39842 .85288 .40848 .87038 .40312 .86331 .393 Mtetra
.655 .751 .92 r
.86331 .393 .87038 .40312 .88797 .39766 .88098 .3875 Mtetra
.657 .752 .92 r
.2534 .57249 .26283 .5807 .27704 .57624 .26767 .56796 Mtetra
.658 .752 .919 r
.26767 .56796 .27704 .57624 .29134 .5717 .28201 .56339 Mtetra
.655 .751 .92 r
.28201 .56339 .29134 .5717 .30571 .5672 .29643 .55886 Mtetra
.652 .751 .922 r
.29643 .55886 .30571 .5672 .32015 .56281 .31092 .55442 Mtetra
.657 .752 .92 r
.31092 .55442 .32015 .56281 .33468 .55825 .3255 .54978 Mtetra
.659 .752 .918 r
.3255 .54978 .33468 .55825 .3493 .55357 .34016 .54505 Mtetra
.655 .751 .92 r
.34016 .54505 .3493 .55357 .36399 .54891 .3549 .54042 Mtetra
.649 .751 .924 r
.3549 .54042 .36399 .54891 .37875 .54454 .36971 .53601 Mtetra
.658 .753 .92 r
.36971 .53601 .37875 .54454 .3936 .53989 .38462 .53123 Mtetra
.655 .751 .92 r
.38462 .53123 .3936 .53989 .40854 .53517 .39961 .52653 Mtetra
.602 .736 .939 r
.39961 .52653 .40854 .53517 .42354 .53122 .41462 .52357 Mtetra
.443 .699 .975 r
.41462 .52357 .42354 .53122 .43854 .53041 .42964 .52385 Mtetra
.258 .636 .962 r
.42964 .52385 .43854 .53041 .45362 .5319 .44474 .52627 Mtetra
.474 .773 .996 r
.44474 .52627 .45362 .5319 .46884 .53295 .46006 .52491 Mtetra
.735 .791 .898 r
.46006 .52491 .46884 .53295 .48427 .52848 .47561 .51662 Mtetra
.802 .733 .788 r
.47561 .51662 .48427 .52848 .49984 .51851 .49129 .50086 Mtetra
.759 .657 .749 r
.49129 .50086 .49984 .51851 .51545 .50498 .50695 .48538 Mtetra
.715 .623 .753 r
.50695 .48538 .51545 .50498 .53107 .49306 .5226 .4737 Mtetra
.671 .603 .771 r
.5226 .4737 .53107 .49306 .54674 .48462 .53829 .46619 Mtetra
.64 .597 .79 r
.53829 .46619 .54674 .48462 .56251 .47967 .55408 .46118 Mtetra
.599 .576 .8 r
.55408 .46118 .56251 .47967 .57842 .47823 .56998 .45867 Mtetra
.519 .523 .799 r
.56998 .45867 .57842 .47823 .59454 .48031 .58608 .46037 Mtetra
.433 .47 .799 r
.58608 .46037 .59454 .48031 .61086 .48406 .60243 .46595 Mtetra
.407 .477 .82 r
.60243 .46595 .61086 .48406 .62725 .48424 .619 .47187 Mtetra
.57 .654 .893 r
.619 .47187 .62725 .48424 .64358 .47887 .63551 .47027 Mtetra
.734 .796 .902 r
.63551 .47027 .64358 .47887 .65979 .46788 .65189 .46162 Mtetra
.811 .866 .888 r
.65189 .46162 .65979 .46788 .676 .45639 .66816 .44909 Mtetra
.771 .838 .903 r
.66816 .44909 .676 .45639 .69237 .44724 .68456 .43871 Mtetra
.699 .793 .922 r
.68456 .43871 .69237 .44724 .70898 .44127 .70119 .43163 Mtetra
.656 .753 .921 r
.70119 .43163 .70898 .44127 .72573 .43609 .718 .42633 Mtetra
.654 .75 .921 r
.718 .42633 .72573 .43609 .74257 .43083 .73492 .4211 Mtetra
.662 .755 .919 r
.73492 .4211 .74257 .43083 .7595 .42529 .75191 .41548 Mtetra
.656 .753 .921 r
.75191 .41548 .7595 .42529 .77654 .42003 .76903 .41008 Mtetra
.653 .749 .921 r
.76903 .41008 .77654 .42003 .7937 .41479 .78626 .40479 Mtetra
.655 .75 .92 r
.78626 .40479 .7937 .41479 .81095 .40941 .80358 .3994 Mtetra
.659 .753 .92 r
.80358 .3994 .81095 .40941 .82829 .40386 .821 .39379 Mtetra
.656 .752 .921 r
.821 .39379 .82829 .40386 .84574 .39842 .83852 .38825 Mtetra
.654 .751 .921 r
.83852 .38825 .84574 .39842 .86331 .393 .85617 .38277 Mtetra
.655 .751 .92 r
.85617 .38277 .86331 .393 .88098 .3875 .87392 .37723 Mtetra
.657 .752 .92 r
.24389 .56419 .2534 .57249 .26767 .56796 .2582 .5596 Mtetra
.657 .752 .919 r
.2582 .5596 .26767 .56796 .28201 .56339 .27259 .55499 Mtetra
.655 .751 .921 r
.27259 .55499 .28201 .56339 .29643 .55886 .28705 .55044 Mtetra
.653 .751 .922 r
.28705 .55044 .29643 .55886 .31092 .55442 .30159 .54594 Mtetra
.658 .752 .92 r
.30159 .54594 .31092 .55442 .3255 .54978 .31622 .54123 Mtetra
.659 .752 .919 r
.31622 .54123 .3255 .54978 .34016 .54505 .33094 .53645 Mtetra
.654 .751 .921 r
.33094 .53645 .34016 .54505 .3549 .54042 .34572 .53183 Mtetra
.65 .751 .923 r
.34572 .53183 .3549 .54042 .36971 .53601 .36058 .52734 Mtetra
.658 .752 .919 r
.36058 .52734 .36971 .53601 .38462 .53123 .37554 .5225 Mtetra
.652 .75 .922 r
.37554 .5225 .38462 .53123 .39961 .52653 .39058 .51788 Mtetra
.569 .726 .948 r
.39058 .51788 .39961 .52653 .41462 .52357 .40561 .51575 Mtetra
.395 .674 .972 r
.40561 .51575 .41462 .52357 .42964 .52385 .42064 .51688 Mtetra
.278 .637 .965 r
.42064 .51688 .42964 .52385 .44474 .52627 .43579 .51925 Mtetra
.611 .787 .966 r
.43579 .51925 .44474 .52627 .46006 .52491 .45122 .51549 Mtetra
.79 .772 .836 r
.45122 .51549 .46006 .52491 .47561 .51662 .4669 .50285 Mtetra
.805 .711 .761 r
.4669 .50285 .47561 .51662 .49129 .50086 .48268 .48473 Mtetra
.767 .675 .761 r
.48268 .48473 .49129 .50086 .50695 .48538 .49839 .46949 Mtetra
.689 .648 .803 r
.49839 .46949 .50695 .48538 .5226 .4737 .51407 .46166 Mtetra
.626 .68 .881 r
.51407 .46166 .5226 .4737 .53829 .46619 .52982 .4579 Mtetra
.655 .773 .936 r
.52982 .4579 .53829 .46619 .55408 .46118 .54566 .45284 Mtetra
.689 .783 .922 r
.54566 .45284 .55408 .46118 .56998 .45867 .56159 .44645 Mtetra
.588 .663 .89 r
.56159 .44645 .56998 .45867 .58608 .46037 .57765 .44417 Mtetra
.399 .498 .845 r
.57765 .44417 .58608 .46037 .60243 .46595 .594 .44938 Mtetra
.305 .439 .832 r
.594 .44938 .60243 .46595 .619 .47187 .61063 .45756 Mtetra
.456 .564 .875 r
.61063 .45756 .619 .47187 .63551 .47027 .62731 .46025 Mtetra
.681 .751 .904 r
.62731 .46025 .63551 .47027 .65189 .46162 .64385 .45394 Mtetra
.803 .833 .874 r
.64385 .45394 .65189 .46162 .66816 .44909 .66021 .44136 Mtetra
.784 .832 .889 r
.66021 .44136 .66816 .44909 .68456 .43871 .67666 .43001 Mtetra
.719 .796 .912 r
.67666 .43001 .68456 .43871 .70119 .43163 .69331 .42197 Mtetra
.659 .756 .921 r
.69331 .42197 .70119 .43163 .718 .42633 .71019 .41648 Mtetra
.653 .75 .921 r
.71019 .41648 .718 .42633 .73492 .4211 .72718 .41119 Mtetra
.661 .754 .919 r
.72718 .41119 .73492 .4211 .75191 .41548 .74425 .40555 Mtetra
.657 .753 .92 r
.74425 .40555 .75191 .41548 .76903 .41008 .76143 .40004 Mtetra
.653 .75 .921 r
.76143 .40004 .76903 .41008 .78626 .40479 .77873 .39469 Mtetra
.654 .75 .921 r
.77873 .39469 .78626 .40479 .80358 .3994 .79613 .38926 Mtetra
.659 .753 .92 r
.79613 .38926 .80358 .3994 .821 .39379 .81362 .38359 Mtetra
.657 .752 .92 r
.81362 .38359 .821 .39379 .83852 .38825 .83122 .37798 Mtetra
.654 .751 .921 r
.83122 .37798 .83852 .38825 .85617 .38277 .84894 .37243 Mtetra
.655 .751 .92 r
.84894 .37243 .85617 .38277 .87392 .37723 .86677 .36683 Mtetra
.657 .752 .92 r
.23428 .5558 .24389 .56419 .2582 .5596 .24864 .55116 Mtetra
.24864 .55116 .2582 .5596 .27259 .55499 .26307 .5465 Mtetra
.655 .751 .921 r
.26307 .5465 .27259 .55499 .28705 .55044 .27758 .54192 Mtetra
.653 .751 .922 r
.27758 .54192 .28705 .55044 .30159 .54594 .29217 .53736 Mtetra
.658 .752 .919 r
.29217 .53736 .30159 .54594 .31622 .54123 .30685 .5326 Mtetra
.659 .752 .919 r
.30685 .5326 .31622 .54123 .33094 .53645 .32161 .52777 Mtetra
.653 .751 .921 r
.32161 .52777 .33094 .53645 .34572 .53183 .33645 .52313 Mtetra
.651 .75 .923 r
.33645 .52313 .34572 .53183 .36058 .52734 .35136 .51856 Mtetra
.658 .752 .919 r
.35136 .51856 .36058 .52734 .37554 .5225 .36637 .51369 Mtetra
.649 .75 .923 r
.36637 .51369 .37554 .5225 .39058 .51788 .38145 .50911 Mtetra
.552 .719 .951 r
.38145 .50911 .39058 .51788 .40561 .51575 .39651 .50741 Mtetra
.379 .654 .965 r
.39651 .50741 .40561 .51575 .42064 .51688 .41157 .50901 Mtetra
.335 .645 .966 r
.41157 .50901 .42064 .51688 .43579 .51925 .42676 .51105 Mtetra
.662 .774 .932 r
.42676 .51105 .43579 .51925 .45122 .51549 .44229 .50583 Mtetra
.812 .771 .814 r
.44229 .50583 .45122 .51549 .4669 .50285 .45809 .49083 Mtetra
.824 .737 .769 r
.45809 .49083 .4669 .50285 .48268 .48473 .47395 .472 Mtetra
.783 .721 .794 r
.47395 .472 .48268 .48473 .49839 .46949 .48973 .45769 Mtetra
.633 .688 .884 r
.48973 .45769 .49839 .46949 .51407 .46166 .50544 .45362 Mtetra
.52 .731 .97 r
.50544 .45362 .51407 .46166 .52982 .4579 .52125 .45228 Mtetra
.637 .841 .979 r
.52125 .45228 .52982 .4579 .54566 .45284 .53717 .44716 Mtetra
.748 .865 .934 r
.53717 .44716 .54566 .45284 .56159 .44645 .55315 .43826 Mtetra
.682 .788 .93 r
.55315 .43826 .56159 .44645 .57765 .44417 .56923 .43208 Mtetra
.36 .553 .906 r
.56923 .43208 .57765 .44417 .594 .44938 .58558 .43624 Mtetra
.179 .423 .858 r
.58558 .43624 .594 .44938 .61063 .45756 .60223 .44501 Mtetra
.338 .533 .899 r
.60223 .44501 .61063 .45756 .62731 .46025 .61902 .44998 Mtetra
.647 .736 .914 r
.61902 .44998 .62731 .46025 .64385 .45394 .63567 .44505 Mtetra
.792 .807 .865 r
.63567 .44505 .64385 .45394 .66021 .44136 .65213 .4327 Mtetra
.787 .813 .873 r
.65213 .4327 .66021 .44136 .67666 .43001 .66864 .42076 Mtetra
.728 .788 .901 r
.66864 .42076 .67666 .43001 .69331 .42197 .68535 .41217 Mtetra
.662 .756 .92 r
.68535 .41217 .69331 .42197 .71019 .41648 .70229 .40652 Mtetra
.654 .751 .921 r
.70229 .40652 .71019 .41648 .72718 .41119 .71935 .40116 Mtetra
.661 .753 .919 r
.71935 .40116 .72718 .41119 .74425 .40555 .73649 .3955 Mtetra
.658 .753 .92 r
.73649 .3955 .74425 .40555 .76143 .40004 .75375 .38989 Mtetra
.653 .75 .921 r
.75375 .38989 .76143 .40004 .77873 .39469 .77112 .38448 Mtetra
.654 .75 .921 r
.77112 .38448 .77873 .39469 .79613 .38926 .7886 .37899 Mtetra
.658 .752 .919 r
.7886 .37899 .79613 .38926 .81362 .38359 .80616 .37327 Mtetra
.657 .752 .92 r
.80616 .37327 .81362 .38359 .83122 .37798 .82384 .36759 Mtetra
.654 .751 .921 r
.82384 .36759 .83122 .37798 .84894 .37243 .84164 .36197 Mtetra
.84164 .36197 .84894 .37243 .86677 .36683 .85955 .35632 Mtetra
.657 .752 .92 r
.22457 .54733 .23428 .5558 .24864 .55116 .23897 .54264 Mtetra
.23897 .54264 .24864 .55116 .26307 .5465 .25346 .53793 Mtetra
.655 .751 .921 r
.25346 .53793 .26307 .5465 .27758 .54192 .26801 .5333 Mtetra
.653 .751 .921 r
.26801 .5333 .27758 .54192 .29217 .53736 .28265 .5287 Mtetra
.658 .752 .919 r
.28265 .5287 .29217 .53736 .30685 .5326 .29738 .52389 Mtetra
.659 .752 .919 r
.29738 .52389 .30685 .5326 .32161 .52777 .31219 .51901 Mtetra
.653 .751 .921 r
.31219 .51901 .32161 .52777 .33645 .52313 .32708 .51432 Mtetra
.651 .75 .922 r
.32708 .51432 .33645 .52313 .35136 .51856 .34204 .5097 Mtetra
.658 .752 .919 r
.34204 .5097 .35136 .51856 .36637 .51369 .35711 .50478 Mtetra
.649 .75 .923 r
.35711 .50478 .36637 .51369 .38145 .50911 .37224 .50015 Mtetra
.553 .717 .949 r
.37224 .50015 .38145 .50911 .39651 .50741 .38734 .49841 Mtetra
.396 .647 .958 r
.38734 .49841 .39651 .50741 .41157 .50901 .40244 .49997 Mtetra
.372 .634 .956 r
.40244 .49997 .41157 .50901 .42676 .51105 .41766 .50198 Mtetra
.663 .756 .919 r
.41766 .50198 .42676 .51105 .44229 .50583 .43324 .4967 Mtetra
.817 .782 .82 r
.43324 .4967 .44229 .50583 .45809 .49083 .44914 .48162 Mtetra
.847 .781 .787 r
.44914 .48162 .45809 .49083 .47395 .472 .46509 .46271 Mtetra
.811 .782 .826 r
.46509 .46271 .47395 .472 .48973 .45769 .48095 .44832 Mtetra
.63 .741 .927 r
.48095 .44832 .48973 .45769 .50544 .45362 .49672 .4442 Mtetra
.538 .705 .947 r
.49672 .4442 .50544 .45362 .52125 .45228 .51257 .44281 Mtetra
.657 .75 .919 r
.51257 .44281 .52125 .45228 .53717 .44716 .52856 .43764 Mtetra
.737 .773 .882 r
.52856 .43764 .53717 .44716 .55315 .43826 .54461 .42867 Mtetra
.681 .758 .909 r
.54461 .42867 .55315 .43826 .56923 .43208 .56075 .42244 Mtetra
.284 .571 .936 r
.56075 .42244 .56923 .43208 .58558 .43624 .57715 .42656 Mtetra
.013 .395 .85 r
.57715 .42656 .58558 .43624 .60223 .44501 .59383 .43531 Mtetra
.244 .548 .928 r
.59383 .43531 .60223 .44501 .61902 .44998 .61065 .44025 Mtetra
.646 .75 .925 r
.61065 .44025 .61902 .44998 .63567 .44505 .62737 .43526 Mtetra
.786 .79 .856 r
.62737 .43526 .63567 .44505 .65213 .4327 .64392 .42283 Mtetra
.78 .789 .86 r
.64392 .42283 .65213 .4327 .66864 .42076 .66051 .41082 Mtetra
.725 .775 .892 r
.66051 .41082 .66864 .42076 .68535 .41217 .6773 .40216 Mtetra
.662 .754 .918 r
.6773 .40216 .68535 .41217 .70229 .40652 .69431 .39645 Mtetra
.654 .751 .921 r
.69431 .39645 .70229 .40652 .71935 .40116 .71144 .39103 Mtetra
.661 .753 .919 r
.71144 .39103 .71935 .40116 .73649 .3955 .72865 .3853 Mtetra
.658 .752 .92 r
.72865 .3853 .73649 .3955 .75375 .38989 .74598 .37964 Mtetra
.653 .75 .921 r
.74598 .37964 .75375 .38989 .77112 .38448 .76342 .37416 Mtetra
.654 .751 .921 r
.76342 .37416 .77112 .38448 .7886 .37899 .78098 .36861 Mtetra
.658 .752 .919 r
.78098 .36861 .7886 .37899 .80616 .37327 .79862 .36283 Mtetra
.657 .752 .92 r
.79862 .36283 .80616 .37327 .82384 .36759 .81638 .35708 Mtetra
.654 .751 .921 r
.81638 .35708 .82384 .36759 .84164 .36197 .83425 .3514 Mtetra
.83425 .3514 .84164 .36197 .85955 .35632 .85224 .34568 Mtetra
.657 .752 .92 r
.21476 .53876 .22457 .54733 .23897 .54264 .22921 .53404 Mtetra
.22921 .53404 .23897 .54264 .25346 .53793 .24374 .52928 Mtetra
.655 .751 .921 r
.24374 .52928 .25346 .53793 .26801 .5333 .25835 .52459 Mtetra
.653 .75 .921 r
.25835 .52459 .26801 .5333 .28265 .5287 .27303 .51995 Mtetra
.658 .752 .919 r
.27303 .51995 .28265 .5287 .29738 .52389 .28781 .5151 Mtetra
.659 .752 .919 r
.28781 .5151 .29738 .52389 .31219 .51901 .30268 .51016 Mtetra
.654 .751 .921 r
.30268 .51016 .31219 .51901 .32708 .51432 .31761 .50539 Mtetra
.65 .749 .922 r
.31761 .50539 .32708 .51432 .34204 .5097 .33262 .50075 Mtetra
.658 .752 .919 r
.33262 .50075 .34204 .5097 .35711 .50478 .34774 .49577 Mtetra
.652 .75 .922 r
.34774 .49577 .35711 .50478 .37224 .50015 .36293 .49099 Mtetra
.571 .721 .944 r
.36293 .49099 .37224 .50015 .38734 .49841 .3781 .48873 Mtetra
.437 .652 .95 r
.3781 .48873 .38734 .49841 .40244 .49997 .39325 .48976 Mtetra
.385 .614 .941 r
.39325 .48976 .40244 .49997 .41766 .50198 .40849 .49202 Mtetra
.625 .726 .919 r
.40849 .49202 .41766 .50198 .43324 .4967 .42409 .48812 Mtetra
.798 .794 .848 r
.42409 .48812 .43324 .4967 .44914 .48162 .44001 .47526 Mtetra
.867 .834 .812 r
.44001 .47526 .44914 .48162 .46509 .46271 .45606 .45688 Mtetra
.848 .853 .847 r
.45606 .45688 .46509 .46271 .48095 .44832 .47204 .4414 Mtetra
.727 .828 .928 r
.47204 .4414 .48095 .44832 .49672 .4442 .48792 .43338 Mtetra
.625 .71 .907 r
.48792 .43338 .49672 .4442 .51257 .44281 .50383 .42947 Mtetra
.653 .675 .859 r
.50383 .42947 .51257 .44281 .52856 .43764 .51986 .42424 Mtetra
.677 .685 .85 r
.51986 .42424 .52856 .43764 .54461 .42867 .53597 .41769 Mtetra
.581 .692 .918 r
.53597 .41769 .54461 .42867 .56075 .42244 .55221 .41525 Mtetra
.097 .523 .908 r
.55221 .41525 .56075 .42244 .57715 .42656 .56867 .42037 Mtetra
0 .346 .765 r
.56867 .42037 .57715 .42656 .59383 .43531 .58538 .42848 Mtetra
.255 .636 .962 r
.58538 .42848 .59383 .43531 .61065 .44025 .60221 .43105 Mtetra
.682 .777 .923 r
.60221 .43105 .61065 .44025 .62737 .43526 .61895 .42456 Mtetra
.784 .774 .844 r
.61895 .42456 .62737 .43526 .64392 .42283 .63557 .41176 Mtetra
.766 .764 .851 r
.63557 .41176 .64392 .42283 .66051 .41082 .65227 .40018 Mtetra
.714 .759 .888 r
.65227 .40018 .66051 .41082 .6773 .40216 .66915 .39194 Mtetra
.659 .75 .917 r
.66915 .39194 .6773 .40216 .69431 .39645 .68623 .38626 Mtetra
.653 .75 .921 r
.68623 .38626 .69431 .39645 .71144 .39103 .70343 .3808 Mtetra
.661 .754 .919 r
.70343 .3808 .71144 .39103 .72865 .3853 .72072 .37497 Mtetra
.658 .752 .919 r
.72072 .37497 .72865 .3853 .74598 .37964 .73812 .36927 Mtetra
.653 .75 .921 r
.73812 .36927 .74598 .37964 .76342 .37416 .75564 .36374 Mtetra
.654 .751 .921 r
.75564 .36374 .76342 .37416 .78098 .36861 .77327 .35812 Mtetra
.659 .753 .919 r
.77327 .35812 .78098 .36861 .79862 .36283 .79099 .35226 Mtetra
.657 .752 .92 r
.79099 .35226 .79862 .36283 .81638 .35708 .80882 .34645 Mtetra
.654 .751 .921 r
.80882 .34645 .81638 .35708 .83425 .3514 .82678 .34071 Mtetra
.655 .751 .921 r
.82678 .34071 .83425 .3514 .85224 .34568 .84485 .33492 Mtetra
.657 .752 .92 r
.20485 .53011 .21476 .53876 .22921 .53404 .21935 .52535 Mtetra
.658 .752 .92 r
.21935 .52535 .22921 .53404 .24374 .52928 .23393 .52054 Mtetra
.655 .751 .921 r
.23393 .52054 .24374 .52928 .25835 .52459 .24858 .51578 Mtetra
.652 .75 .921 r
.24858 .51578 .25835 .52459 .27303 .51995 .26331 .5111 Mtetra
.657 .752 .92 r
.26331 .5111 .27303 .51995 .28781 .5151 .27814 .50622 Mtetra
.659 .753 .919 r
.27814 .50622 .28781 .5151 .30268 .51016 .29306 .50123 Mtetra
.655 .752 .921 r
.29306 .50123 .30268 .51016 .31761 .50539 .30805 .49636 Mtetra
.649 .749 .922 r
.30805 .49636 .31761 .50539 .33262 .50075 .32311 .4917 Mtetra
.658 .752 .919 r
.32311 .4917 .33262 .50075 .34774 .49577 .33828 .48667 Mtetra
.655 .751 .92 r
.33828 .48667 .34774 .49577 .36293 .49099 .35353 .48172 Mtetra
.602 .732 .936 r
.35353 .48172 .36293 .49099 .3781 .48873 .36878 .47852 Mtetra
.486 .664 .941 r
.36878 .47852 .3781 .48873 .39325 .48976 .384 .47861 Mtetra
.403 .603 .928 r
.384 .47861 .39325 .48976 .40849 .49202 .39927 .48087 Mtetra
.557 .676 .918 r
.39927 .48087 .40849 .49202 .42409 .48812 .41483 .47929 Mtetra
.734 .784 .893 r
.41483 .47929 .42409 .48812 .44001 .47526 .43071 .47069 Mtetra
.861 .878 .849 r
.43071 .47069 .44001 .47526 .45606 .45688 .44683 .45452 Mtetra
.868 .929 .863 r
.44683 .45452 .45606 .45688 .47204 .4414 .46293 .43864 Mtetra
.808 .936 .914 r
.46293 .43864 .47204 .4414 .48792 .43338 .47897 .42661 Mtetra
.72 .835 .935 r
.47897 .42661 .48792 .43338 .50383 .42947 .49499 .4188 Mtetra
.657 .728 .902 r
.49499 .4188 .50383 .42947 .51986 .42424 .51108 .41351 Mtetra
.588 .702 .922 r
.51108 .41351 .51986 .42424 .53597 .41769 .52725 .41075 Mtetra
.322 .672 .976 r
.52725 .41075 .53597 .41769 .55221 .41525 .54358 .41226 Mtetra
0 .376 .685 r
.54358 .41226 .55221 .41525 .56867 .42037 .56011 .41768 Mtetra
.247 0 0 r
.56011 .41768 .56867 .42037 .58538 .42848 .57686 .42346 Mtetra
.444 .793 .998 r
.57686 .42346 .58538 .42848 .60221 .43105 .59366 .42161 Mtetra
.733 .788 .897 r
.59366 .42161 .60221 .43105 .61895 .42456 .61042 .41263 Mtetra
.777 .753 .831 r
.61042 .41263 .61895 .42456 .63557 .41176 .62711 .39972 Mtetra
.748 .744 .849 r
.62711 .39972 .63557 .41176 .65227 .40018 .64391 .38898 Mtetra
.695 .744 .889 r
.64391 .38898 .65227 .40018 .66915 .39194 .66091 .38157 Mtetra
.656 .749 .918 r
.66091 .38157 .66915 .39194 .68623 .38626 .67807 .37597 Mtetra
.654 .751 .921 r
.67807 .37597 .68623 .38626 .70343 .3808 .69534 .37044 Mtetra
.662 .754 .918 r
.69534 .37044 .70343 .3808 .72072 .37497 .7127 .36451 Mtetra
.656 .751 .919 r
.7127 .36451 .72072 .37497 .73812 .36927 .73018 .3588 Mtetra
.653 .75 .922 r
.73018 .3588 .73812 .36927 .75564 .36374 .74777 .3532 Mtetra
.654 .751 .921 r
.74777 .3532 .75564 .36374 .77327 .35812 .76547 .34749 Mtetra
.659 .752 .919 r
.76547 .34749 .77327 .35812 .79099 .35226 .78327 .34156 Mtetra
.656 .751 .92 r
.78327 .34156 .79099 .35226 .80882 .34645 .80119 .33571 Mtetra
.654 .751 .921 r
.80119 .33571 .80882 .34645 .82678 .34071 .81922 .3299 Mtetra
.655 .751 .921 r
.81922 .3299 .82678 .34071 .84485 .33492 .83737 .32403 Mtetra
.656 .751 .92 r
.19484 .52136 .20485 .53011 .21935 .52535 .20938 .51657 Mtetra
.658 .752 .92 r
.20938 .51657 .21935 .52535 .23393 .52054 .22401 .51171 Mtetra
.656 .752 .92 r
.22401 .51171 .23393 .52054 .24858 .51578 .23872 .50687 Mtetra
.652 .75 .921 r
.23872 .50687 .24858 .51578 .26331 .5111 .25349 .50214 Mtetra
.656 .751 .92 r
.25349 .50214 .26331 .5111 .27814 .50622 .26837 .49725 Mtetra
.659 .753 .919 r
.26837 .49725 .27814 .50622 .29306 .50123 .28334 .49222 Mtetra
.658 .753 .92 r
.28334 .49222 .29306 .50123 .30805 .49636 .29838 .48721 Mtetra
.649 .748 .922 r
.29838 .48721 .30805 .49636 .32311 .4917 .3135 .4825 Mtetra
.656 .75 .919 r
.3135 .4825 .32311 .4917 .33828 .48667 .32871 .4775 Mtetra
.657 .752 .92 r
.32871 .4775 .33828 .48667 .35353 .48172 .34402 .47242 Mtetra
.634 .744 .927 r
.34402 .47242 .35353 .48172 .36878 .47852 .35938 .46813 Mtetra
.533 .683 .934 r
.35938 .46813 .36878 .47852 .384 .47861 .37468 .46703 Mtetra
.453 .62 .923 r
.37468 .46703 .384 .47861 .39927 .48087 .39002 .46827 Mtetra
.484 .615 .905 r
.39002 .46827 .39927 .48087 .41483 .47929 .40552 .46906 Mtetra
.647 .733 .912 r
.40552 .46906 .41483 .47929 .43071 .47069 .42135 .46423 Mtetra
.775 .846 .905 r
.42135 .46423 .43071 .47069 .44683 .45452 .43742 .45379 Mtetra
.834 .97 .887 r
.43742 .45379 .44683 .45452 .46293 .43864 .45361 .43973 Mtetra
.759 .992 .879 r
.45361 .43973 .46293 .43864 .47897 .42661 .46978 .4273 Mtetra
.622 .958 .898 r
.46978 .4273 .47897 .42661 .49499 .4188 .48594 .41841 Mtetra
.458 .882 .914 r
.48594 .41841 .49499 .4188 .51108 .41351 .50213 .41308 Mtetra
.179 .712 .821 r
.50213 .41308 .51108 .41351 .52725 .41075 .51841 .41132 Mtetra
.175 0 0 r
.51841 .41132 .52725 .41075 .54358 .41226 .53483 .41313 Mtetra
.298 0 0 r
.53483 .41313 .54358 .41226 .56011 .41768 .55144 .41663 Mtetra
.084 .64 .8 r
.55144 .41663 .56011 .41768 .57686 .42346 .56819 .41651 Mtetra
.653 .827 .967 r
.56819 .41651 .57686 .42346 .59366 .42161 .585 .41073 Mtetra
.765 .769 .856 r
.585 .41073 .59366 .42161 .61042 .41263 .60177 .39922 Mtetra
.755 .726 .825 r
.60177 .39922 .61042 .41263 .62711 .39972 .61856 .38722 Mtetra
.728 .732 .854 r
.61856 .38722 .62711 .39972 .64391 .38898 .63547 .37758 Mtetra
.673 .734 .896 r
.63547 .37758 .64391 .38898 .66091 .38157 .65257 .37117 Mtetra
.654 .75 .92 r
.65257 .37117 .66091 .38157 .67807 .37597 .66981 .36558 Mtetra
.656 .752 .921 r
.66981 .36558 .67807 .37597 .69534 .37044 .68715 .3599 Mtetra
.662 .752 .917 r
.68715 .3599 .69534 .37044 .7127 .36451 .70458 .35391 Mtetra
.654 .75 .92 r
.70458 .35391 .7127 .36451 .73018 .3588 .72214 .34822 Mtetra
.653 .751 .922 r
.72214 .34822 .73018 .3588 .74777 .3532 .73981 .34255 Mtetra
.655 .752 .921 r
.73981 .34255 .74777 .3532 .76547 .34749 .75759 .33673 Mtetra
.659 .752 .919 r
.75759 .33673 .76547 .34749 .78327 .34156 .77546 .33074 Mtetra
.655 .751 .92 r
.77546 .33074 .78327 .34156 .80119 .33571 .79346 .32484 Mtetra
.654 .751 .921 r
.79346 .32484 .80119 .33571 .81922 .3299 .81158 .31897 Mtetra
.655 .751 .921 r
.81158 .31897 .81922 .3299 .83737 .32403 .8298 .31301 Mtetra
.656 .751 .92 r
.18472 .51252 .19484 .52136 .20938 .51657 .19931 .50771 Mtetra
.658 .752 .92 r
.19931 .50771 .20938 .51657 .22401 .51171 .21399 .50279 Mtetra
.657 .752 .92 r
.21399 .50279 .22401 .51171 .23872 .50687 .22874 .49788 Mtetra
.653 .751 .921 r
.22874 .49788 .23872 .50687 .25349 .50214 .24357 .49308 Mtetra
.655 .75 .92 r
.24357 .49308 .25349 .50214 .26837 .49725 .25849 .48819 Mtetra
.658 .753 .92 r
.25849 .48819 .26837 .49725 .28334 .49222 .27351 .48312 Mtetra
.659 .753 .92 r
.27351 .48312 .28334 .49222 .29838 .48721 .28861 .47803 Mtetra
.651 .75 .922 r
.28861 .47803 .29838 .48721 .3135 .4825 .30378 .47317 Mtetra
.652 .748 .92 r
.30378 .47317 .3135 .4825 .32871 .4775 .31905 .46826 Mtetra
.658 .753 .92 r
.31905 .46826 .32871 .4775 .34402 .47242 .33441 .46311 Mtetra
.652 .751 .922 r
.33441 .46311 .34402 .47242 .35938 .46813 .34985 .45814 Mtetra
.593 .718 .93 r
.34985 .45814 .35938 .46813 .37468 .46703 .36528 .45518 Mtetra
.521 .649 .915 r
.36528 .45518 .37468 .46703 .39002 .46827 .38072 .45468 Mtetra
.479 .596 .892 r
.38072 .45468 .39002 .46827 .40552 .46906 .39623 .4558 Mtetra
.545 .635 .89 r
.39623 .4558 .40552 .46906 .42135 .46423 .41196 .45479 Mtetra
.658 .758 .923 r
.41196 .45479 .42135 .46423 .43742 .45379 .42795 .44941 Mtetra
.722 .897 .958 r
.42795 .44941 .43742 .45379 .45361 .43973 .44411 .44111 Mtetra
.656 .971 .879 r
.44411 .44111 .45361 .43973 .46978 .4273 .46038 .43094 Mtetra
.406 .844 .721 r
.46038 .43094 .46978 .4273 .48594 .41841 .47666 .42262 Mtetra
0 0 0 r
.47666 .42262 .48594 .41841 .50213 .41308 .49298 .41725 Mtetra
.078 0 0 r
.49298 .41725 .50213 .41308 .51841 .41132 .50939 .41483 Mtetra
.17 0 0 r
.50939 .41483 .51841 .41132 .53483 .41313 .52592 .41429 Mtetra
.109 .661 .71 r
.52592 .41429 .53483 .41313 .55144 .41663 .5426 .41189 Mtetra
.606 .87 .992 r
.5426 .41189 .55144 .41663 .56819 .41651 .55938 .40655 Mtetra
.744 .783 .884 r
.55938 .40655 .56819 .41651 .585 .41073 .57619 .39676 Mtetra
.751 .717 .82 r
.57619 .39676 .585 .41073 .60177 .39922 .59302 .38479 Mtetra
.727 .703 .827 r
.59302 .38479 .60177 .39922 .61856 .38722 .60992 .37444 Mtetra
.697 .719 .866 r
.60992 .37444 .61856 .38722 .63547 .37758 .62696 .36657 Mtetra
.659 .74 .909 r
.62696 .36657 .63547 .37758 .65257 .37117 .64415 .36075 Mtetra
.654 .752 .921 r
.64415 .36075 .65257 .37117 .66981 .36558 .66146 .3551 Mtetra
.659 .754 .92 r
.66146 .3551 .66981 .36558 .68715 .3599 .67887 .34921 Mtetra
.66 .751 .918 r
.67887 .34921 .68715 .3599 .70458 .35391 .69638 .34325 Mtetra
.653 .75 .921 r
.69638 .34325 .70458 .35391 .72214 .34822 .71402 .33754 Mtetra
.653 .751 .922 r
.71402 .33754 .72214 .34822 .73981 .34255 .73176 .33178 Mtetra
.657 .752 .92 r
.73176 .33178 .73981 .34255 .75759 .33673 .74961 .32584 Mtetra
.658 .752 .919 r
.74961 .32584 .75759 .33673 .77546 .33074 .76757 .3198 Mtetra
.655 .751 .92 r
.76757 .3198 .77546 .33074 .79346 .32484 .78564 .31386 Mtetra
.654 .751 .921 r
.78564 .31386 .79346 .32484 .81158 .31897 .80384 .30792 Mtetra
.656 .752 .92 r
.80384 .30792 .81158 .31897 .8298 .31301 .82215 .30186 Mtetra
.655 .751 .92 r
.1745 .50358 .18472 .51252 .19931 .50771 .18913 .49875 Mtetra
.658 .752 .92 r
.18913 .49875 .19931 .50771 .21399 .50279 .20386 .49378 Mtetra
.657 .752 .92 r
.20386 .49378 .21399 .50279 .22874 .49788 .21866 .48881 Mtetra
.654 .751 .921 r
.21866 .48881 .22874 .49788 .24357 .49308 .23355 .48391 Mtetra
.653 .75 .921 r
.23355 .48391 .24357 .49308 .25849 .48819 .24851 .47902 Mtetra
.658 .752 .92 r
.24851 .47902 .25849 .48819 .27351 .48312 .26358 .47394 Mtetra
.659 .753 .92 r
.26358 .47394 .27351 .48312 .28861 .47803 .27874 .46877 Mtetra
.655 .752 .921 r
.27874 .46877 .28861 .47803 .30378 .47317 .29397 .46372 Mtetra
.649 .747 .921 r
.29397 .46372 .30378 .47317 .31905 .46826 .30928 .45886 Mtetra
.657 .752 .92 r
.30928 .45886 .31905 .46826 .33441 .46311 .32469 .45367 Mtetra
.32469 .45367 .33441 .46311 .34985 .45814 .3402 .44846 Mtetra
.64 .743 .923 r
.3402 .44846 .34985 .45814 .36528 .45518 .35576 .44384 Mtetra
.576 .685 .915 r
.35576 .44384 .36528 .45518 .38072 .45468 .37132 .44153 Mtetra
.537 .634 .894 r
.37132 .44153 .38072 .45468 .39623 .4558 .38692 .44071 Mtetra
.517 .592 .868 r
.38692 .44071 .39623 .4558 .41196 .45479 .40263 .44089 Mtetra
.561 .634 .881 r
.40263 .44089 .41196 .45479 .42795 .44941 .41854 .43935 Mtetra
.633 .739 .925 r
.41854 .43935 .42795 .44941 .44411 .44111 .43466 .43485 Mtetra
.656 .84 .971 r
.43466 .43485 .44411 .44111 .46038 .43094 .45092 .42899 Mtetra
.572 .913 .97 r
.45092 .42899 .46038 .43094 .47666 .42262 .46727 .42296 Mtetra
.413 .862 .876 r
.46727 .42296 .47666 .42262 .49298 .41725 .48371 .41754 Mtetra
.366 .836 .862 r
.48371 .41754 .49298 .41725 .50939 .41483 .50024 .41273 Mtetra
.507 .886 .967 r
.50024 .41273 .50939 .41483 .52592 .41429 .51688 .40775 Mtetra
.666 .843 .968 r
.51688 .40775 .52592 .41429 .5426 .41189 .53362 .40141 Mtetra
.733 .77 .882 r
.53362 .40141 .5426 .41189 .55938 .40655 .55043 .39205 Mtetra
.737 .705 .821 r
.55043 .39205 .55938 .40655 .57619 .39676 .56728 .38093 Mtetra
.716 .681 .814 r
.56728 .38093 .57619 .39676 .59302 .38479 .5842 .3708 Mtetra
.704 .703 .846 r
.5842 .3708 .59302 .38479 .60992 .37444 .60121 .36217 Mtetra
.667 .719 .887 r
.60121 .36217 .60992 .37444 .62696 .36657 .61836 .35587 Mtetra
.655 .747 .918 r
.61836 .35587 .62696 .36657 .64415 .36075 .63563 .35017 Mtetra
.654 .751 .921 r
.63563 .35017 .64415 .36075 .66146 .3551 .65301 .34445 Mtetra
.662 .754 .918 r
.65301 .34445 .66146 .3551 .67887 .34921 .67049 .33838 Mtetra
.656 .749 .918 r
.67049 .33838 .67887 .34921 .69638 .34325 .68808 .3325 Mtetra
.653 .751 .922 r
.68808 .3325 .69638 .34325 .71402 .33754 .7058 .32673 Mtetra
.654 .752 .922 r
.7058 .32673 .71402 .33754 .73176 .33178 .72362 .32088 Mtetra
.658 .753 .92 r
.72362 .32088 .73176 .33178 .74961 .32584 .74154 .31481 Mtetra
.657 .751 .919 r
.74154 .31481 .74961 .32584 .76757 .3198 .75958 .30874 Mtetra
.655 .751 .921 r
.75958 .30874 .76757 .3198 .78564 .31386 .77774 .30275 Mtetra
.654 .751 .921 r
.77774 .30275 .78564 .31386 .80384 .30792 .79602 .29673 Mtetra
.657 .752 .92 r
.79602 .29673 .80384 .30792 .82215 .30186 .8144 .29057 Mtetra
.654 .75 .921 r
.16417 .49454 .1745 .50358 .18913 .49875 .17885 .48968 Mtetra
.657 .752 .92 r
.17885 .48968 .18913 .49875 .20386 .49378 .19362 .48469 Mtetra
.19362 .48469 .20386 .49378 .21866 .48881 .20848 .47965 Mtetra
.656 .752 .92 r
.20848 .47965 .21866 .48881 .23355 .48391 .22342 .47464 Mtetra
.653 .75 .921 r
.22342 .47464 .23355 .48391 .24851 .47902 .23843 .46972 Mtetra
.656 .751 .92 r
.23843 .46972 .24851 .47902 .26358 .47394 .25354 .46465 Mtetra
.659 .753 .92 r
.25354 .46465 .26358 .47394 .27874 .46877 .26875 .45944 Mtetra
.658 .753 .92 r
.26875 .45944 .27874 .46877 .29397 .46372 .28404 .45423 Mtetra
.651 .749 .921 r
.28404 .45423 .29397 .46372 .30928 .45886 .29941 .44923 Mtetra
.652 .747 .92 r
.29941 .44923 .30928 .45886 .32469 .45367 .31487 .44419 Mtetra
.658 .754 .921 r
.31487 .44419 .32469 .45367 .3402 .44846 .33043 .43889 Mtetra
.656 .752 .921 r
.33043 .43889 .3402 .44846 .35576 .44384 .34608 .43362 Mtetra
.636 .733 .919 r
.34608 .43362 .35576 .44384 .37132 .44153 .36179 .4291 Mtetra
.585 .671 .898 r
.36179 .4291 .37132 .44153 .38692 .44071 .37751 .42651 Mtetra
.566 .632 .876 r
.37751 .42651 .38692 .44071 .40263 .44089 .39331 .42474 Mtetra
.556 .598 .851 r
.39331 .42474 .40263 .44089 .41854 .43935 .40922 .42353 Mtetra
.577 .614 .852 r
.40922 .42353 .41854 .43935 .43466 .43485 .4253 .4214 Mtetra
.608 .666 .881 r
.4253 .4214 .43466 .43485 .45092 .42899 .44154 .4179 Mtetra
.634 .722 .911 r
.44154 .4179 .45092 .42899 .46727 .42296 .45792 .41325 Mtetra
.654 .76 .928 r
.45792 .41325 .46727 .42296 .48371 .41754 .47442 .40777 Mtetra
.674 .767 .92 r
.47442 .40777 .48371 .41754 .50024 .41273 .49103 .40145 Mtetra
.696 .743 .888 r
.49103 .40145 .50024 .41273 .51688 .40775 .50774 .39398 Mtetra
.709 .706 .845 r
.50774 .39398 .51688 .40775 .53362 .40141 .52454 .3851 Mtetra
.71 .672 .811 r
.52454 .3851 .53362 .40141 .55043 .39205 .54139 .37528 Mtetra
.7 .663 .81 r
.54139 .37528 .55043 .39205 .56728 .38093 .55831 .366 Mtetra
.697 .687 .837 r
.55831 .366 .56728 .38093 .5842 .3708 .57532 .35754 Mtetra
.669 .703 .873 r
.57532 .35754 .5842 .3708 .60121 .36217 .59243 .35102 Mtetra
.655 .739 .911 r
.59243 .35102 .60121 .36217 .61836 .35587 .60967 .34526 Mtetra
.654 .751 .922 r
.60967 .34526 .61836 .35587 .63563 .35017 .62702 .33954 Mtetra
.659 .754 .92 r
.62702 .33954 .63563 .35017 .65301 .34445 .64447 .33353 Mtetra
.66 .75 .917 r
.64447 .33353 .65301 .34445 .67049 .33838 .66202 .32748 Mtetra
.654 .749 .92 r
.66202 .32748 .67049 .33838 .68808 .3325 .67969 .32165 Mtetra
.653 .752 .922 r
.67969 .32165 .68808 .3325 .7058 .32673 .69748 .3158 Mtetra
.656 .752 .921 r
.69748 .3158 .7058 .32673 .72362 .32088 .71538 .3098 Mtetra
.659 .752 .919 r
.71538 .3098 .72362 .32088 .74154 .31481 .73338 .30364 Mtetra
.656 .75 .92 r
.73338 .30364 .74154 .31481 .75958 .30874 .7515 .29757 Mtetra
.654 .751 .921 r
.7515 .29757 .75958 .30874 .77774 .30275 .76974 .29152 Mtetra
.655 .752 .921 r
.76974 .29152 .77774 .30275 .79602 .29673 .7881 .28541 Mtetra
.657 .752 .92 r
.7881 .28541 .79602 .29673 .8144 .29057 .80656 .27915 Mtetra
.654 .751 .921 r
.15373 .48541 .16417 .49454 .17885 .48968 .16846 .4805 Mtetra
.656 .751 .92 r
.16846 .4805 .17885 .48968 .19362 .48469 .18327 .4755 Mtetra
.658 .752 .92 r
.18327 .4755 .19362 .48469 .20848 .47965 .19818 .4704 Mtetra
.657 .752 .92 r
.19818 .4704 .20848 .47965 .22342 .47464 .21317 .4653 Mtetra
.654 .751 .921 r
.21317 .4653 .22342 .47464 .23843 .46972 .22824 .46029 Mtetra
.654 .75 .92 r
.22824 .46029 .23843 .46972 .25354 .46465 .2434 .45524 Mtetra
.658 .753 .92 r
.2434 .45524 .25354 .46465 .26875 .45944 .25866 .45002 Mtetra
.659 .754 .92 r
.25866 .45002 .26875 .45944 .28404 .45423 .27401 .44473 Mtetra
.656 .752 .921 r
.27401 .44473 .28404 .45423 .29941 .44923 .28944 .43949 Mtetra
.65 .747 .92 r
.28944 .43949 .29941 .44923 .31487 .44419 .30495 .43446 Mtetra
.654 .749 .92 r
.30495 .43446 .31487 .44419 .33043 .43889 .32056 .42924 Mtetra
.657 .753 .921 r
.32056 .42924 .33043 .43889 .34608 .43362 .33627 .42387 Mtetra
.656 .752 .92 r
.33627 .42387 .34608 .43362 .36179 .4291 .35207 .41852 Mtetra
.641 .731 .913 r
.35207 .41852 .36179 .4291 .37751 .42651 .36794 .41371 Mtetra
.61 .677 .889 r
.36794 .41371 .37751 .42651 .39331 .42474 .38385 .41011 Mtetra
.596 .641 .866 r
.38385 .41011 .39331 .42474 .40922 .42353 .39985 .40711 Mtetra
.599 .617 .841 r
.39985 .40711 .40922 .42353 .4253 .4214 .41598 .40394 Mtetra
.605 .608 .827 r
.41598 .40394 .4253 .4214 .44154 .4179 .43224 .4004 Mtetra
.622 .616 .824 r
.43224 .4004 .44154 .4179 .45792 .41325 .44864 .39598 Mtetra
.642 .629 .822 r
.44864 .39598 .45792 .41325 .47442 .40777 .46517 .39043 Mtetra
.66 .637 .816 r
.46517 .39043 .47442 .40777 .49103 .40145 .48182 .38373 Mtetra
.672 .639 .809 r
.48182 .38373 .49103 .40145 .50774 .39398 .49856 .37615 Mtetra
.677 .641 .807 r
.49856 .37615 .50774 .39398 .52454 .3851 .51539 .36819 Mtetra
.683 .655 .816 r
.51539 .36819 .52454 .3851 .54139 .37528 .53229 .36004 Mtetra
.681 .677 .84 r
.53229 .36004 .54139 .37528 .55831 .366 .54928 .35248 Mtetra
.664 .698 .871 r
.54928 .35248 .55831 .366 .57532 .35754 .56637 .34614 Mtetra
.655 .735 .908 r
.56637 .34614 .57532 .35754 .59243 .35102 .58357 .34035 Mtetra
.654 .751 .921 r
.58357 .34035 .59243 .35102 .60967 .34526 .60088 .33456 Mtetra
.657 .753 .921 r
.60088 .33456 .60967 .34526 .62702 .33954 .6183 .32863 Mtetra
.661 .752 .917 r
.6183 .32863 .62702 .33954 .64447 .33353 .63582 .32249 Mtetra
.655 .748 .918 r
.63582 .32249 .64447 .33353 .66202 .32748 .65345 .31656 Mtetra
.653 .751 .922 r
.65345 .31656 .66202 .32748 .67969 .32165 .6712 .31068 Mtetra
.654 .752 .922 r
.6712 .31068 .67969 .32165 .69748 .3158 .68907 .30472 Mtetra
.658 .753 .92 r
.68907 .30472 .69748 .3158 .71538 .3098 .70704 .29857 Mtetra
.658 .751 .919 r
.70704 .29857 .71538 .3098 .73338 .30364 .72512 .29238 Mtetra
.655 .751 .92 r
.72512 .29238 .73338 .30364 .7515 .29757 .74332 .28627 Mtetra
.654 .751 .921 r
.74332 .28627 .7515 .29757 .76974 .29152 .76165 .28015 Mtetra
.656 .752 .921 r
.76165 .28015 .76974 .29152 .7881 .28541 .78008 .27392 Mtetra
.657 .752 .92 r
.78008 .27392 .7881 .28541 .80656 .27915 .79863 .26759 Mtetra
.655 .751 .921 r
.14318 .4762 .15373 .48541 .16846 .4805 .15796 .47121 Mtetra
.654 .75 .92 r
.15796 .47121 .16846 .4805 .18327 .4755 .17282 .4662 Mtetra
.657 .752 .92 r
.17282 .4662 .18327 .4755 .19818 .4704 .18778 .46106 Mtetra
.18778 .46106 .19818 .4704 .21317 .4653 .20282 .45589 Mtetra
.656 .752 .92 r
.20282 .45589 .21317 .4653 .22824 .46029 .21795 .45074 Mtetra
.653 .749 .92 r
.21795 .45074 .22824 .46029 .2434 .45524 .23315 .44568 Mtetra
.655 .751 .92 r
.23315 .44568 .2434 .45524 .25866 .45002 .24845 .44048 Mtetra
.658 .753 .92 r
.24845 .44048 .25866 .45002 .27401 .44473 .26385 .43516 Mtetra
.659 .754 .92 r
.26385 .43516 .27401 .44473 .28944 .43949 .27935 .42979 Mtetra
.655 .751 .921 r
.27935 .42979 .28944 .43949 .30495 .43446 .29492 .42452 Mtetra
.651 .746 .919 r
.29492 .42452 .30495 .43446 .32056 .42924 .31058 .41939 Mtetra
.655 .75 .92 r
.31058 .41939 .32056 .42924 .33627 .42387 .32634 .41406 Mtetra
.657 .753 .921 r
.32634 .41406 .33627 .42387 .35207 .41852 .3422 .4086 Mtetra
.657 .752 .92 r
.3422 .4086 .35207 .41852 .36794 .41371 .35816 .40314 Mtetra
.651 .738 .913 r
.35816 .40314 .36794 .41371 .38385 .41011 .3742 .39786 Mtetra
.64 .702 .891 r
.3742 .39786 .38385 .41011 .39985 .40711 .39032 .39296 Mtetra
.626 .665 .868 r
.39032 .39296 .39985 .40711 .41598 .40394 .40653 .38855 Mtetra
.627 .647 .851 r
.40653 .38855 .41598 .40394 .43224 .4004 .42284 .38403 Mtetra
.634 .637 .836 r
.42284 .38403 .43224 .4004 .44864 .39598 .43929 .37903 Mtetra
.643 .635 .827 r
.43929 .37903 .44864 .39598 .46517 .39043 .45585 .37341 Mtetra
.653 .64 .824 r
.45585 .37341 .46517 .39043 .48182 .38373 .47252 .36716 Mtetra
.662 .65 .828 r
.47252 .36716 .48182 .38373 .49856 .37615 .48929 .36042 Mtetra
.667 .664 .838 r
.48929 .36042 .49856 .37615 .51539 .36819 .50616 .35357 Mtetra
.662 .679 .856 r
.50616 .35357 .51539 .36819 .53229 .36004 .52311 .34719 Mtetra
.658 .708 .885 r
.52311 .34719 .53229 .36004 .54928 .35248 .54017 .34121 Mtetra
.655 .739 .911 r
.54017 .34121 .54928 .35248 .56637 .34614 .55734 .3354 Mtetra
.654 .751 .921 r
.55734 .3354 .56637 .34614 .58357 .34035 .57461 .32959 Mtetra
.657 .753 .921 r
.57461 .32959 .58357 .34035 .60088 .33456 .59199 .32364 Mtetra
.661 .753 .918 r
.59199 .32364 .60088 .33456 .6183 .32863 .60948 .31749 Mtetra
.657 .748 .917 r
.60948 .31749 .6183 .32863 .63582 .32249 .62707 .31146 Mtetra
.653 .75 .921 r
.62707 .31146 .63582 .32249 .65345 .31656 .64479 .30554 Mtetra
.654 .752 .922 r
.64479 .30554 .65345 .31656 .6712 .31068 .66262 .29957 Mtetra
.656 .753 .921 r
.66262 .29957 .6712 .31068 .68907 .30472 .68055 .29345 Mtetra
.659 .752 .919 r
.68055 .29345 .68907 .30472 .70704 .29857 .6986 .28719 Mtetra
.656 .75 .919 r
.6986 .28719 .70704 .29857 .72512 .29238 .71676 .28101 Mtetra
.654 .751 .921 r
.71676 .28101 .72512 .29238 .74332 .28627 .73505 .27485 Mtetra
.654 .752 .921 r
.73505 .27485 .74332 .28627 .76165 .28015 .75346 .26864 Mtetra
.657 .752 .92 r
.75346 .26864 .76165 .28015 .78008 .27392 .77197 .26229 Mtetra
.657 .751 .92 r
.77197 .26229 .78008 .27392 .79863 .26759 .79061 .2559 Mtetra
.656 .751 .92 r
.13252 .46689 .14318 .4762 .15796 .47121 .14735 .46182 Mtetra
.654 .75 .92 r
.14735 .46182 .15796 .47121 .17282 .4662 .16225 .45677 Mtetra
.656 .751 .92 r
.16225 .45677 .17282 .4662 .18778 .46106 .17726 .45163 Mtetra
.657 .753 .92 r
.17726 .45163 .18778 .46106 .20282 .45589 .19235 .44639 Mtetra
.657 .752 .92 r
.19235 .44639 .20282 .45589 .21795 .45074 .20753 .44115 Mtetra
.654 .751 .921 r
.20753 .44115 .21795 .45074 .23315 .44568 .22279 .43597 Mtetra
.653 .749 .92 r
.22279 .43597 .23315 .44568 .24845 .44048 .23814 .4308 Mtetra
.657 .752 .92 r
.23814 .4308 .24845 .44048 .26385 .43516 .25359 .42548 Mtetra
.658 .754 .92 r
.25359 .42548 .26385 .43516 .27935 .42979 .26914 .42006 Mtetra
.658 .754 .921 r
.26914 .42006 .27935 .42979 .29492 .42452 .28478 .41461 Mtetra
.655 .75 .92 r
.28478 .41461 .29492 .42452 .31058 .41939 .3005 .40926 Mtetra
.651 .746 .919 r
.3005 .40926 .31058 .41939 .32634 .41406 .31631 .40402 Mtetra
.654 .75 .92 r
.31631 .40402 .32634 .41406 .3422 .4086 .33222 .39864 Mtetra
.658 .754 .921 r
.33222 .39864 .3422 .4086 .35816 .40314 .34824 .39308 Mtetra
.656 .753 .921 r
.34824 .39308 .35816 .40314 .3742 .39786 .36435 .38755 Mtetra
.657 .749 .918 r
.36435 .38755 .3742 .39786 .39032 .39296 .38056 .38195 Mtetra
.654 .735 .909 r
.38056 .38195 .39032 .39296 .40653 .38855 .39686 .37641 Mtetra
.651 .713 .893 r
.39686 .37641 .40653 .38855 .42284 .38403 .41326 .37092 Mtetra
.65 .696 .879 r
.41326 .37092 .42284 .38403 .43929 .37903 .42976 .36537 Mtetra
.652 .688 .872 r
.42976 .36537 .43929 .37903 .45585 .37341 .44637 .35967 Mtetra
.654 .689 .871 r
.44637 .35967 .45585 .37341 .47252 .36716 .46308 .35384 Mtetra
.655 .698 .878 r
.46308 .35384 .47252 .36716 .48929 .36042 .4799 .34795 Mtetra
.655 .714 .891 r
.4799 .34795 .48929 .36042 .50616 .35357 .49682 .3421 Mtetra
.655 .735 .908 r
.49682 .3421 .50616 .35357 .52311 .34719 .51384 .33631 Mtetra
.655 .748 .918 r
.51384 .33631 .52311 .34719 .54017 .34121 .53097 .33045 Mtetra
.654 .752 .922 r
.53097 .33045 .54017 .34121 .55734 .3354 .5482 .32461 Mtetra
.658 .754 .921 r
.5482 .32461 .55734 .3354 .57461 .32959 .56554 .31859 Mtetra
.66 .752 .918 r
.56554 .31859 .57461 .32959 .59199 .32364 .58299 .31242 Mtetra
.657 .747 .917 r
.58299 .31242 .59199 .32364 .60948 .31749 .60056 .30636 Mtetra
.654 .75 .92 r
.60056 .30636 .60948 .31749 .62707 .31146 .61823 .30039 Mtetra
.653 .752 .922 r
.61823 .30039 .62707 .31146 .64479 .30554 .63602 .29439 Mtetra
.655 .753 .922 r
.63602 .29439 .64479 .30554 .66262 .29957 .65392 .28828 Mtetra
.658 .753 .92 r
.65392 .28828 .66262 .29957 .68055 .29345 .67193 .282 Mtetra
.657 .75 .919 r
.67193 .282 .68055 .29345 .6986 .28719 .69006 .27574 Mtetra
.655 .751 .92 r
.69006 .27574 .6986 .28719 .71676 .28101 .70831 .26952 Mtetra
.654 .751 .921 r
.70831 .26952 .71676 .28101 .73505 .27485 .72668 .26329 Mtetra
.656 .752 .921 r
.72668 .26329 .73505 .27485 .75346 .26864 .74516 .25696 Mtetra
.657 .752 .92 r
.74516 .25696 .75346 .26864 .77197 .26229 .76376 .25051 Mtetra
.656 .751 .92 r
.76376 .25051 .77197 .26229 .79061 .2559 .78249 .24409 Mtetra
.656 .752 .92 r
.12174 .4575 .13252 .46689 .14735 .46182 .13662 .45235 Mtetra
.655 .751 .921 r
.13662 .45235 .14735 .46182 .16225 .45677 .15158 .44722 Mtetra
.654 .75 .92 r
.15158 .44722 .16225 .45677 .17726 .45163 .16662 .44207 Mtetra
.657 .752 .92 r
.16662 .44207 .17726 .45163 .19235 .44639 .18177 .4368 Mtetra
.657 .753 .92 r
.18177 .4368 .19235 .44639 .20753 .44115 .197 .43149 Mtetra
.656 .752 .92 r
.197 .43149 .20753 .44115 .22279 .43597 .21232 .42617 Mtetra
.654 .75 .92 r
.21232 .42617 .22279 .43597 .23814 .4308 .22773 .42093 Mtetra
.654 .749 .92 r
.22773 .42093 .23814 .4308 .25359 .42548 .24322 .41566 Mtetra
.657 .753 .92 r
.24322 .41566 .25359 .42548 .26914 .42006 .25882 .41023 Mtetra
.658 .754 .921 r
.25882 .41023 .26914 .42006 .28478 .41461 .27451 .40472 Mtetra
.27451 .40472 .28478 .41461 .3005 .40926 .2903 .39919 Mtetra
.656 .751 .92 r
.2903 .39919 .3005 .40926 .31631 .40402 .30618 .3937 Mtetra
.652 .746 .918 r
.30618 .3937 .31631 .40402 .33222 .39864 .32214 .38833 Mtetra
.652 .747 .919 r
.32214 .38833 .33222 .39864 .34824 .39308 .33821 .38292 Mtetra
.656 .753 .921 r
.33821 .38292 .34824 .39308 .36435 .38755 .35438 .37734 Mtetra
.657 .753 .921 r
.35438 .37734 .36435 .38755 .38056 .38195 .37065 .37167 Mtetra
.656 .753 .921 r
.37065 .37167 .38056 .38195 .39686 .37641 .38701 .36599 Mtetra
.656 .751 .92 r
.38701 .36599 .39686 .37641 .41326 .37092 .40348 .3603 Mtetra
.656 .748 .918 r
.40348 .3603 .41326 .37092 .42976 .36537 .42005 .35459 Mtetra
.656 .746 .917 r
.42005 .35459 .42976 .36537 .44637 .35967 .43672 .34883 Mtetra
.656 .746 .916 r
.43672 .34883 .44637 .35967 .46308 .35384 .4535 .34303 Mtetra
.656 .748 .918 r
.4535 .34303 .46308 .35384 .4799 .34795 .47038 .3372 Mtetra
.655 .751 .92 r
.47038 .3372 .4799 .34795 .49682 .3421 .48736 .33136 Mtetra
.655 .752 .922 r
.48736 .33136 .49682 .3421 .51384 .33631 .50445 .32551 Mtetra
.656 .753 .921 r
.50445 .32551 .51384 .33631 .53097 .33045 .52165 .31957 Mtetra
.659 .754 .92 r
.52165 .31957 .53097 .33045 .5482 .32461 .53896 .31346 Mtetra
.659 .75 .917 r
.53896 .31346 .5482 .32461 .56554 .31859 .55637 .30729 Mtetra
.656 .747 .917 r
.55637 .30729 .56554 .31859 .58299 .31242 .5739 .30124 Mtetra
.654 .75 .92 r
.5739 .30124 .58299 .31242 .60056 .30636 .59153 .29524 Mtetra
.654 .753 .922 r
.59153 .29524 .60056 .30636 .61823 .30039 .60928 .28919 Mtetra
.655 .753 .922 r
.60928 .28919 .61823 .30039 .63602 .29439 .62715 .28307 Mtetra
.658 .753 .92 r
.62715 .28307 .63602 .29439 .65392 .28828 .64512 .27677 Mtetra
.658 .75 .918 r
.64512 .27677 .65392 .28828 .67193 .282 .66321 .27045 Mtetra
.655 .75 .92 r
.66321 .27045 .67193 .282 .69006 .27574 .68143 .26418 Mtetra
.654 .751 .921 r
.68143 .26418 .69006 .27574 .70831 .26952 .69976 .25791 Mtetra
.655 .752 .921 r
.69976 .25791 .70831 .26952 .72668 .26329 .71821 .25158 Mtetra
.657 .752 .92 r
.71821 .25158 .72668 .26329 .74516 .25696 .73677 .24511 Mtetra
.657 .751 .919 r
.73677 .24511 .74516 .25696 .76376 .25051 .75546 .23862 Mtetra
.656 .751 .92 r
.75546 .23862 .76376 .25051 .78249 .24409 .77427 .23214 Mtetra
.657 .752 .92 r
.11084 .44801 .12174 .4575 .13662 .45235 .12577 .44279 Mtetra
.656 .751 .92 r
.12577 .44279 .13662 .45235 .15158 .44722 .14079 .43756 Mtetra
.654 .75 .92 r
.14079 .43756 .15158 .44722 .16662 .44207 .15588 .43236 Mtetra
.655 .751 .92 r
.15588 .43236 .16662 .44207 .18177 .4368 .17107 .42711 Mtetra
.657 .753 .92 r
.17107 .42711 .18177 .4368 .197 .43149 .18635 .42174 Mtetra
.18635 .42174 .197 .43149 .21232 .42617 .20173 .41634 Mtetra
.656 .752 .92 r
.20173 .41634 .21232 .42617 .22773 .42093 .2172 .41094 Mtetra
.654 .749 .92 r
.2172 .41094 .22773 .42093 .24322 .41566 .23274 .40561 Mtetra
.23274 .40561 .24322 .41566 .25882 .41023 .24839 .40024 Mtetra
.657 .753 .921 r
.24839 .40024 .25882 .41023 .27451 .40472 .26413 .39473 Mtetra
.658 .754 .921 r
.26413 .39473 .27451 .40472 .2903 .39919 .27998 .38914 Mtetra
.27998 .38914 .2903 .39919 .30618 .3937 .29592 .38352 Mtetra
.657 .752 .92 r
.29592 .38352 .30618 .3937 .32214 .38833 .31195 .3779 Mtetra
.654 .747 .918 r
.31195 .3779 .32214 .38833 .33821 .38292 .32808 .37234 Mtetra
.653 .745 .918 r
.32808 .37234 .33821 .38292 .35438 .37734 .3443 .3668 Mtetra
.653 .748 .919 r
.3443 .3668 .35438 .37734 .37065 .37167 .36063 .36121 Mtetra
.654 .751 .921 r
.36063 .36121 .37065 .37167 .38701 .36599 .37705 .35556 Mtetra
.656 .753 .922 r
.37705 .35556 .38701 .36599 .40348 .3603 .39358 .34981 Mtetra
.656 .754 .922 r
.39358 .34981 .40348 .3603 .42005 .35459 .41022 .34401 Mtetra
.656 .753 .922 r
.41022 .34401 .42005 .35459 .43672 .34883 .42696 .33819 Mtetra
.655 .753 .922 r
.42696 .33819 .43672 .34883 .4535 .34303 .4438 .33234 Mtetra
.656 .754 .922 r
.4438 .33234 .4535 .34303 .47038 .3372 .46074 .32644 Mtetra
.657 .754 .921 r
.46074 .32644 .47038 .3372 .48736 .33136 .4778 .32044 Mtetra
.658 .752 .92 r
.4778 .32044 .48736 .33136 .50445 .32551 .49496 .31438 Mtetra
.658 .749 .917 r
.49496 .31438 .50445 .32551 .52165 .31957 .51223 .30826 Mtetra
.657 .747 .916 r
.51223 .30826 .52165 .31957 .53896 .31346 .5296 .30215 Mtetra
.655 .748 .918 r
.5296 .30215 .53896 .31346 .55637 .30729 .54709 .29611 Mtetra
.654 .751 .921 r
.54709 .29611 .55637 .30729 .5739 .30124 .56469 .29007 Mtetra
.654 .753 .922 r
.56469 .29007 .5739 .30124 .59153 .29524 .5824 .28398 Mtetra
.655 .753 .922 r
.5824 .28398 .59153 .29524 .60928 .28919 .60023 .27782 Mtetra
.658 .753 .92 r
.60023 .27782 .60928 .28919 .62715 .28307 .61817 .2715 Mtetra
.658 .751 .918 r
.61817 .2715 .62715 .28307 .64512 .27677 .63622 .26513 Mtetra
.655 .75 .919 r
.63622 .26513 .64512 .27677 .66321 .27045 .65439 .25882 Mtetra
.655 .751 .921 r
.65439 .25882 .66321 .27045 .68143 .26418 .67269 .25251 Mtetra
.655 .752 .921 r
.67269 .25251 .68143 .26418 .69976 .25791 .6911 .24615 Mtetra
.656 .752 .921 r
.6911 .24615 .69976 .25791 .71821 .25158 .70963 .23968 Mtetra
.657 .751 .919 r
.70963 .23968 .71821 .25158 .73677 .24511 .72828 .23313 Mtetra
.656 .751 .92 r
.72828 .23313 .73677 .24511 .75546 .23862 .74705 .22659 Mtetra
.655 .751 .921 r
.74705 .22659 .75546 .23862 .77427 .23214 .76595 .22006 Mtetra
.657 .752 .92 r
.09983 .43843 .11084 .44801 .12577 .44279 .11481 .43314 Mtetra
.656 .752 .92 r
.11481 .43314 .12577 .44279 .14079 .43756 .12987 .42783 Mtetra
.655 .751 .92 r
.12987 .42783 .14079 .43756 .15588 .43236 .14502 .42254 Mtetra
.654 .75 .92 r
.14502 .42254 .15588 .43236 .17107 .42711 .16026 .41725 Mtetra
.656 .751 .92 r
.16026 .41725 .17107 .42711 .18635 .42174 .17559 .41188 Mtetra
.657 .753 .92 r
.17559 .41188 .18635 .42174 .20173 .41634 .19102 .40642 Mtetra
.19102 .40642 .20173 .41634 .2172 .41094 .20654 .40094 Mtetra
.656 .752 .92 r
.20654 .40094 .2172 .41094 .23274 .40561 .22215 .39545 Mtetra
.654 .749 .92 r
.22215 .39545 .23274 .40561 .24839 .40024 .23785 .39002 Mtetra
.23785 .39002 .24839 .40024 .26413 .39473 .25364 .38456 Mtetra
.656 .752 .921 r
.25364 .38456 .26413 .39473 .27998 .38914 .26954 .37897 Mtetra
.657 .754 .921 r
.26954 .37897 .27998 .38914 .29592 .38352 .28554 .37331 Mtetra
.658 .754 .921 r
.28554 .37331 .29592 .38352 .31195 .3779 .30163 .3676 Mtetra
.657 .754 .921 r
.30163 .3676 .31195 .3779 .32808 .37234 .31783 .36186 Mtetra
.657 .751 .92 r
.31783 .36186 .32808 .37234 .3443 .3668 .33412 .35612 Mtetra
.656 .748 .918 r
.33412 .35612 .3443 .3668 .36063 .36121 .35051 .35037 Mtetra
.654 .746 .917 r
.35051 .35037 .36063 .36121 .37705 .35556 .367 .34464 Mtetra
.655 .746 .917 r
.367 .34464 .37705 .35556 .39358 .34981 .38359 .33887 Mtetra
.38359 .33887 .39358 .34981 .41022 .34401 .40028 .33304 Mtetra
.656 .747 .917 r
.40028 .33304 .41022 .34401 .42696 .33819 .41708 .32715 Mtetra
.656 .748 .917 r
.41708 .32715 .42696 .33819 .4438 .33234 .43399 .32119 Mtetra
.657 .747 .916 r
.43399 .32119 .4438 .33234 .46074 .32644 .45101 .31519 Mtetra
.657 .746 .916 r
.45101 .31519 .46074 .32644 .4778 .32044 .46813 .30913 Mtetra
.656 .746 .916 r
.46813 .30913 .4778 .32044 .49496 .31438 .48536 .30309 Mtetra
.655 .748 .918 r
.48536 .30309 .49496 .31438 .51223 .30826 .50269 .29704 Mtetra
.654 .75 .92 r
.50269 .29704 .51223 .30826 .5296 .30215 .52014 .29098 Mtetra
.654 .753 .922 r
.52014 .29098 .5296 .30215 .54709 .29611 .5377 .28489 Mtetra
.5377 .28489 .54709 .29611 .56469 .29007 .55538 .27875 Mtetra
.655 .753 .922 r
.55538 .27875 .56469 .29007 .5824 .28398 .57316 .27253 Mtetra
.658 .753 .92 r
.57316 .27253 .5824 .28398 .60023 .27782 .59106 .26618 Mtetra
.658 .75 .918 r
.59106 .26618 .60023 .27782 .61817 .2715 .60908 .25978 Mtetra
.655 .75 .919 r
.60908 .25978 .61817 .2715 .63622 .26513 .62721 .25343 Mtetra
.655 .751 .921 r
.62721 .25343 .63622 .26513 .65439 .25882 .64547 .24708 Mtetra
.654 .752 .921 r
.64547 .24708 .65439 .25882 .67269 .25251 .66384 .24069 Mtetra
.656 .752 .921 r
.66384 .24069 .67269 .25251 .6911 .24615 .68234 .2342 Mtetra
.657 .752 .92 r
.68234 .2342 .6911 .24615 .70963 .23968 .70095 .22762 Mtetra
.656 .751 .919 r
.70095 .22762 .70963 .23968 .72828 .23313 .71968 .22103 Mtetra
.655 .751 .92 r
.71968 .22103 .72828 .23313 .74705 .22659 .73855 .21444 Mtetra
.655 .751 .921 r
.73855 .21444 .74705 .22659 .76595 .22006 .75754 .20783 Mtetra
.656 .752 .92 r
.0887 .42871 .09983 .43843 .11481 .43314 .10372 .42339 Mtetra
.657 .752 .92 r
.10372 .42339 .11481 .43314 .12987 .42783 .11884 .41801 Mtetra
.656 .752 .92 r
.11884 .41801 .12987 .42783 .14502 .42254 .13404 .41263 Mtetra
.655 .751 .92 r
.13404 .41263 .14502 .42254 .16026 .41725 .14933 .40725 Mtetra
.654 .75 .92 r
.14933 .40725 .16026 .41725 .17559 .41188 .16471 .40187 Mtetra
.656 .751 .92 r
.16471 .40187 .17559 .41188 .19102 .40642 .18019 .3964 Mtetra
.657 .753 .92 r
.18019 .3964 .19102 .40642 .20654 .40094 .19576 .39085 Mtetra
.19576 .39085 .20654 .40094 .22215 .39545 .21143 .38527 Mtetra
.656 .752 .92 r
.21143 .38527 .22215 .39545 .23785 .39002 .22719 .37969 Mtetra
.654 .749 .92 r
.22719 .37969 .23785 .39002 .25364 .38456 .24304 .37414 Mtetra
.654 .749 .919 r
.24304 .37414 .25364 .38456 .26954 .37897 .25899 .36858 Mtetra
.655 .751 .92 r
.25899 .36858 .26954 .37897 .28554 .37331 .27504 .36294 Mtetra
.657 .753 .921 r
.27504 .36294 .28554 .37331 .30163 .3676 .29119 .3572 Mtetra
.657 .754 .921 r
.29119 .3572 .30163 .3676 .31783 .36186 .30745 .35142 Mtetra
.657 .754 .922 r
.30745 .35142 .31783 .36186 .33412 .35612 .3238 .3456 Mtetra
.3238 .3456 .33412 .35612 .35051 .35037 .34025 .33974 Mtetra
.657 .753 .921 r
.34025 .33974 .35051 .35037 .367 .34464 .35681 .33386 Mtetra
.656 .751 .92 r
.35681 .33386 .367 .34464 .38359 .33887 .37347 .32796 Mtetra
.656 .75 .919 r
.37347 .32796 .38359 .33887 .40028 .33304 .39023 .32203 Mtetra
.656 .749 .919 r
.39023 .32203 .40028 .33304 .41708 .32715 .4071 .31607 Mtetra
.4071 .31607 .41708 .32715 .43399 .32119 .42407 .31008 Mtetra
.655 .75 .919 r
.42407 .31008 .43399 .32119 .45101 .31519 .44115 .30406 Mtetra
.655 .751 .92 r
.44115 .30406 .45101 .31519 .46813 .30913 .45834 .29802 Mtetra
.655 .752 .922 r
.45834 .29802 .46813 .30913 .48536 .30309 .47564 .29195 Mtetra
.655 .753 .922 r
.47564 .29195 .48536 .30309 .50269 .29704 .49305 .28584 Mtetra
.655 .754 .923 r
.49305 .28584 .50269 .29704 .52014 .29098 .51057 .2797 Mtetra
.655 .753 .922 r
.51057 .2797 .52014 .29098 .5377 .28489 .5282 .2735 Mtetra
.657 .753 .921 r
.5282 .2735 .5377 .28489 .55538 .27875 .54595 .2672 Mtetra
.658 .752 .919 r
.54595 .2672 .55538 .27875 .57316 .27253 .56381 .26081 Mtetra
.657 .75 .918 r
.56381 .26081 .57316 .27253 .59106 .26618 .58179 .2544 Mtetra
.655 .75 .919 r
.58179 .2544 .59106 .26618 .60908 .25978 .59989 .24802 Mtetra
.655 .751 .921 r
.59989 .24802 .60908 .25978 .62721 .25343 .6181 .24163 Mtetra
.655 .752 .921 r
.6181 .24163 .62721 .25343 .64547 .24708 .63644 .23521 Mtetra
.656 .752 .921 r
.63644 .23521 .64547 .24708 .66384 .24069 .65489 .22869 Mtetra
.657 .752 .92 r
.65489 .22869 .66384 .24069 .68234 .2342 .67346 .22207 Mtetra
.656 .751 .919 r
.67346 .22207 .68234 .2342 .70095 .22762 .69216 .21544 Mtetra
.656 .751 .92 r
.69216 .21544 .70095 .22762 .71968 .22103 .71098 .2088 Mtetra
.655 .751 .921 r
.71098 .2088 .71968 .22103 .73855 .21444 .72993 .20215 Mtetra
.655 .752 .921 r
.72993 .20215 .73855 .21444 .75754 .20783 .74901 .19542 Mtetra
.655 .751 .92 r
.07744 .41887 .0887 .42871 .10372 .42339 .09251 .41353 Mtetra
.657 .752 .92 r
.09251 .41353 .10372 .42339 .11884 .41801 .10768 .4081 Mtetra
.10768 .4081 .11884 .41801 .13404 .41263 .12293 .40264 Mtetra
.656 .752 .92 r
.12293 .40264 .13404 .41263 .14933 .40725 .13828 .39717 Mtetra
.655 .751 .92 r
.13828 .39717 .14933 .40725 .16471 .40187 .15371 .3917 Mtetra
.654 .75 .92 r
.15371 .3917 .16471 .40187 .18019 .3964 .16924 .38622 Mtetra
.656 .751 .92 r
.16924 .38622 .18019 .3964 .19576 .39085 .18486 .38066 Mtetra
.657 .753 .921 r
.18486 .38066 .19576 .39085 .21143 .38527 .20059 .37502 Mtetra
.20059 .37502 .21143 .38527 .22719 .37969 .21641 .36934 Mtetra
.656 .752 .92 r
.21641 .36934 .22719 .37969 .24304 .37414 .23232 .36366 Mtetra
.655 .75 .92 r
.23232 .36366 .24304 .37414 .25899 .36858 .24833 .35797 Mtetra
.654 .749 .919 r
.24833 .35797 .25899 .36858 .27504 .36294 .26444 .35229 Mtetra
.654 .749 .92 r
.26444 .35229 .27504 .36294 .29119 .3572 .28064 .34658 Mtetra
.655 .751 .921 r
.28064 .34658 .29119 .3572 .30745 .35142 .29695 .3408 Mtetra
.656 .753 .921 r
.29695 .3408 .30745 .35142 .3238 .3456 .31336 .33494 Mtetra
.656 .754 .922 r
.31336 .33494 .3238 .3456 .34025 .33974 .32988 .32904 Mtetra
.32988 .32904 .34025 .33974 .35681 .33386 .3465 .3231 Mtetra
.3465 .3231 .35681 .33386 .37347 .32796 .36322 .31713 Mtetra
.36322 .31713 .37347 .32796 .39023 .32203 .38005 .31113 Mtetra
.38005 .31113 .39023 .32203 .4071 .31607 .39698 .3051 Mtetra
.39698 .3051 .4071 .31607 .42407 .31008 .41402 .29904 Mtetra
.655 .754 .922 r
.41402 .29904 .42407 .31008 .44115 .30406 .43117 .29295 Mtetra
.43117 .29295 .44115 .30406 .45834 .29802 .44843 .28683 Mtetra
.44843 .28683 .45834 .29802 .47564 .29195 .4658 .28067 Mtetra
.655 .753 .922 r
.4658 .28067 .47564 .29195 .49305 .28584 .48328 .27446 Mtetra
.656 .753 .921 r
.48328 .27446 .49305 .28584 .51057 .2797 .50088 .26817 Mtetra
.657 .752 .92 r
.50088 .26817 .51057 .2797 .5282 .2735 .51859 .26181 Mtetra
.657 .75 .919 r
.51859 .26181 .5282 .2735 .54595 .2672 .53641 .2554 Mtetra
.656 .749 .918 r
.53641 .2554 .54595 .2672 .56381 .26081 .55435 .249 Mtetra
.655 .75 .92 r
.55435 .249 .56381 .26081 .58179 .2544 .5724 .24259 Mtetra
.655 .751 .921 r
.5724 .24259 .58179 .2544 .59989 .24802 .59058 .23616 Mtetra
.655 .752 .921 r
.59058 .23616 .59989 .24802 .6181 .24163 .60888 .2297 Mtetra
.656 .753 .921 r
.60888 .2297 .6181 .24163 .63644 .23521 .62729 .22314 Mtetra
.657 .752 .92 r
.62729 .22314 .63644 .23521 .65489 .22869 .64582 .21649 Mtetra
.656 .751 .919 r
.64582 .21649 .65489 .22869 .67346 .22207 .66448 .20981 Mtetra
.656 .751 .92 r
.66448 .20981 .67346 .22207 .69216 .21544 .68327 .20313 Mtetra
.655 .751 .921 r
.68327 .20313 .69216 .21544 .71098 .2088 .70218 .19644 Mtetra
.655 .752 .921 r
.70218 .19644 .71098 .2088 .72993 .20215 .72122 .18969 Mtetra
.656 .752 .92 r
.72122 .18969 .72993 .20215 .74901 .19542 .74038 .18284 Mtetra
.655 .751 .92 r
.06607 .40891 .07744 .41887 .09251 .41353 .08118 .40352 Mtetra
.08118 .40352 .09251 .41353 .10768 .4081 .09639 .39808 Mtetra
.657 .752 .92 r
.09639 .39808 .10768 .4081 .12293 .40264 .1117 .39256 Mtetra
.1117 .39256 .12293 .40264 .13828 .39717 .1271 .387 Mtetra
.656 .752 .92 r
.1271 .387 .13828 .39717 .15371 .3917 .14259 .38144 Mtetra
.655 .751 .92 r
.14259 .38144 .15371 .3917 .16924 .38622 .15817 .37587 Mtetra
.654 .75 .92 r
.15817 .37587 .16924 .38622 .18486 .38066 .17385 .37029 Mtetra
.655 .751 .92 r
.17385 .37029 .18486 .38066 .20059 .37502 .18962 .36465 Mtetra
.657 .753 .921 r
.18962 .36465 .20059 .37502 .21641 .36934 .2055 .35891 Mtetra
.2055 .35891 .21641 .36934 .23232 .36366 .22147 .35314 Mtetra
.657 .752 .921 r
.22147 .35314 .23232 .36366 .24833 .35797 .23754 .34735 Mtetra
.656 .751 .92 r
.23754 .34735 .24833 .35797 .26444 .35229 .25371 .34153 Mtetra
.655 .75 .919 r
.25371 .34153 .26444 .35229 .28064 .34658 .26998 .33571 Mtetra
.655 .749 .919 r
.26998 .33571 .28064 .34658 .29695 .3408 .28635 .32988 Mtetra
.28635 .32988 .29695 .3408 .31336 .33494 .30282 .32402 Mtetra
.655 .75 .92 r
.30282 .32402 .31336 .33494 .32988 .32904 .31939 .3181 Mtetra
.655 .751 .921 r
.31939 .3181 .32988 .32904 .3465 .3231 .33607 .31213 Mtetra
.656 .752 .921 r
.33607 .31213 .3465 .3231 .36322 .31713 .35286 .30612 Mtetra
.656 .753 .921 r
.35286 .30612 .36322 .31713 .38005 .31113 .36975 .30006 Mtetra
.656 .753 .922 r
.36975 .30006 .38005 .31113 .39698 .3051 .38675 .29396 Mtetra
.38675 .29396 .39698 .3051 .41402 .29904 .40386 .28782 Mtetra
.656 .753 .921 r
.40386 .28782 .41402 .29904 .43117 .29295 .42108 .28163 Mtetra
.42108 .28163 .43117 .29295 .44843 .28683 .43841 .27539 Mtetra
.657 .752 .92 r
.43841 .27539 .44843 .28683 .4658 .28067 .45585 .2691 Mtetra
.657 .751 .919 r
.45585 .2691 .4658 .28067 .48328 .27446 .47341 .26276 Mtetra
.657 .75 .918 r
.47341 .26276 .48328 .27446 .50088 .26817 .49108 .25637 Mtetra
.656 .749 .918 r
.49108 .25637 .50088 .26817 .51859 .26181 .50886 .24998 Mtetra
.655 .75 .919 r
.50886 .24998 .51859 .26181 .53641 .2554 .52676 .24357 Mtetra
.655 .751 .92 r
.52676 .24357 .53641 .2554 .55435 .249 .54477 .23714 Mtetra
.655 .752 .921 r
.54477 .23714 .55435 .249 .5724 .24259 .56291 .23067 Mtetra
.56291 .23067 .5724 .24259 .59058 .23616 .58116 .22416 Mtetra
.656 .753 .921 r
.58116 .22416 .59058 .23616 .60888 .2297 .59954 .21755 Mtetra
.657 .752 .92 r
.59954 .21755 .60888 .2297 .62729 .22314 .61803 .21086 Mtetra
.656 .751 .919 r
.61803 .21086 .62729 .22314 .64582 .21649 .63665 .20416 Mtetra
.656 .751 .92 r
.63665 .20416 .64582 .21649 .66448 .20981 .65539 .19744 Mtetra
.655 .751 .921 r
.65539 .19744 .66448 .20981 .68327 .20313 .67426 .1907 Mtetra
.655 .752 .921 r
.67426 .1907 .68327 .20313 .70218 .19644 .69326 .18392 Mtetra
.656 .752 .921 r
.69326 .18392 .70218 .19644 .72122 .18969 .71239 .17704 Mtetra
.656 .751 .92 r
.71239 .17704 .72122 .18969 .74038 .18284 .73164 .1701 Mtetra
.655 .751 .92 r
.05456 .39886 .06607 .40891 .08118 .40352 .06973 .39339 Mtetra
.06973 .39339 .08118 .40352 .09639 .39808 .08499 .3879 Mtetra
.08499 .3879 .09639 .39808 .1117 .39256 .10034 .38236 Mtetra
.657 .752 .92 r
.10034 .38236 .1117 .39256 .1271 .387 .11579 .37675 Mtetra
.11579 .37675 .1271 .387 .14259 .38144 .13134 .37109 Mtetra
.656 .752 .92 r
.13134 .37109 .14259 .38144 .15817 .37587 .14698 .36543 Mtetra
.655 .751 .92 r
.14698 .36543 .15817 .37587 .17385 .37029 .16271 .35976 Mtetra
.655 .75 .92 r
.16271 .35976 .17385 .37029 .18962 .36465 .17854 .35408 Mtetra
.655 .751 .92 r
.17854 .35408 .18962 .36465 .2055 .35891 .19446 .34835 Mtetra
.656 .752 .921 r
.19446 .34835 .2055 .35891 .22147 .35314 .21049 .34253 Mtetra
.657 .753 .921 r
.21049 .34253 .22147 .35314 .23754 .34735 .22662 .33667 Mtetra
.22662 .33667 .23754 .34735 .25371 .34153 .24285 .33077 Mtetra
.656 .752 .921 r
.24285 .33077 .25371 .34153 .26998 .33571 .25918 .32484 Mtetra
.656 .752 .92 r
.25918 .32484 .26998 .33571 .28635 .32988 .27562 .31888 Mtetra
.656 .75 .919 r
.27562 .31888 .28635 .32988 .30282 .32402 .29215 .3129 Mtetra
.656 .749 .919 r
.29215 .3129 .30282 .32402 .31939 .3181 .30879 .30689 Mtetra
.655 .749 .919 r
.30879 .30689 .31939 .3181 .33607 .31213 .32553 .30086 Mtetra
.32553 .30086 .33607 .31213 .35286 .30612 .34238 .29478 Mtetra
.656 .749 .919 r
.34238 .29478 .35286 .30612 .36975 .30006 .35934 .28865 Mtetra
.35934 .28865 .36975 .30006 .38675 .29396 .37641 .28248 Mtetra
.37641 .28248 .38675 .29396 .40386 .28782 .39359 .27626 Mtetra
.656 .749 .918 r
.39359 .27626 .40386 .28782 .42108 .28163 .41088 .26999 Mtetra
.41088 .26999 .42108 .28163 .43841 .27539 .42828 .26368 Mtetra
.42828 .26368 .43841 .27539 .45585 .2691 .44579 .25734 Mtetra
.656 .749 .919 r
.44579 .25734 .45585 .2691 .47341 .26276 .46341 .25097 Mtetra
.655 .75 .92 r
.46341 .25097 .47341 .26276 .49108 .25637 .48115 .24456 Mtetra
.655 .751 .92 r
.48115 .24456 .49108 .25637 .50886 .24998 .49901 .23813 Mtetra
.655 .752 .921 r
.49901 .23813 .50886 .24998 .52676 .24357 .51699 .23166 Mtetra
.51699 .23166 .52676 .24357 .54477 .23714 .53508 .22515 Mtetra
.655 .753 .921 r
.53508 .22515 .54477 .23714 .56291 .23067 .55329 .21859 Mtetra
.657 .753 .921 r
.55329 .21859 .56291 .23067 .58116 .22416 .57163 .21192 Mtetra
.657 .751 .92 r
.57163 .21192 .58116 .22416 .59954 .21755 .59008 .2052 Mtetra
.656 .75 .919 r
.59008 .2052 .59954 .21755 .61803 .21086 .60866 .19847 Mtetra
.656 .751 .92 r
.60866 .19847 .61803 .21086 .63665 .20416 .62736 .19171 Mtetra
.655 .751 .921 r
.62736 .19171 .63665 .20416 .65539 .19744 .64619 .18494 Mtetra
.655 .752 .921 r
.64619 .18494 .65539 .19744 .67426 .1907 .66515 .17812 Mtetra
.656 .752 .921 r
.66515 .17812 .67426 .1907 .69326 .18392 .68423 .1712 Mtetra
.657 .751 .92 r
.68423 .1712 .69326 .18392 .71239 .17704 .70344 .16422 Mtetra
.656 .751 .92 r
.70344 .16422 .71239 .17704 .73164 .1701 .72279 .15721 Mtetra
.656 .752 .92 r
.04293 .38871 .05456 .39886 .06973 .39339 .05815 .38316 Mtetra
.655 .751 .92 r
.05815 .38316 .06973 .39339 .08499 .3879 .07346 .37759 Mtetra
.07346 .37759 .08499 .3879 .10034 .38236 .08886 .37201 Mtetra
.08886 .37201 .10034 .38236 .11579 .37675 .10436 .36638 Mtetra
.657 .752 .92 r
.10436 .36638 .11579 .37675 .13134 .37109 .11996 .36066 Mtetra
.11996 .36066 .13134 .37109 .14698 .36543 .13565 .35491 Mtetra
.656 .752 .92 r
.13565 .35491 .14698 .36543 .16271 .35976 .15144 .34914 Mtetra
.656 .751 .92 r
.15144 .34914 .16271 .35976 .17854 .35408 .16733 .34336 Mtetra
.655 .75 .92 r
.16733 .34336 .17854 .35408 .19446 .34835 .18331 .33756 Mtetra
.18331 .33756 .19446 .34835 .21049 .34253 .19939 .33174 Mtetra
.655 .751 .92 r
.19939 .33174 .21049 .34253 .22662 .33667 .21557 .32586 Mtetra
.656 .753 .921 r
.21557 .32586 .22662 .33667 .24285 .33077 .23186 .3199 Mtetra
.23186 .3199 .24285 .33077 .25918 .32484 .24826 .3139 Mtetra
.24826 .3139 .25918 .32484 .27562 .31888 .26475 .30787 Mtetra
.26475 .30787 .27562 .31888 .29215 .3129 .28135 .3018 Mtetra
.656 .752 .921 r
.28135 .3018 .29215 .3129 .30879 .30689 .29805 .29569 Mtetra
.656 .752 .92 r
.29805 .29569 .30879 .30689 .32553 .30086 .31486 .28956 Mtetra
.656 .751 .92 r
.31486 .28956 .32553 .30086 .34238 .29478 .33178 .28339 Mtetra
.33178 .28339 .34238 .29478 .35934 .28865 .34881 .27718 Mtetra
.656 .75 .92 r
.34881 .27718 .35934 .28865 .37641 .28248 .36594 .27094 Mtetra
.36594 .27094 .37641 .28248 .39359 .27626 .38319 .26465 Mtetra
.656 .751 .92 r
.38319 .26465 .39359 .27626 .41088 .26999 .40054 .25833 Mtetra
.40054 .25833 .41088 .26999 .42828 .26368 .41801 .25197 Mtetra
.655 .752 .921 r
.41801 .25197 .42828 .26368 .44579 .25734 .4356 .24557 Mtetra
.4356 .24557 .44579 .25734 .46341 .25097 .4533 .23914 Mtetra
.4533 .23914 .46341 .25097 .48115 .24456 .47111 .23267 Mtetra
.47111 .23267 .48115 .24456 .49901 .23813 .48904 .22616 Mtetra
.655 .753 .921 r
.48904 .22616 .49901 .23813 .51699 .23166 .5071 .2196 Mtetra
.656 .753 .921 r
.5071 .2196 .51699 .23166 .53508 .22515 .52527 .21296 Mtetra
.657 .752 .92 r
.52527 .21296 .53508 .22515 .55329 .21859 .54356 .20626 Mtetra
.657 .751 .919 r
.54356 .20626 .55329 .21859 .57163 .21192 .56197 .19951 Mtetra
.656 .75 .919 r
.56197 .19951 .57163 .21192 .59008 .2052 .58051 .19275 Mtetra
.656 .751 .92 r
.58051 .19275 .59008 .2052 .60866 .19847 .59917 .18596 Mtetra
.655 .751 .921 r
.59917 .18596 .60866 .19847 .62736 .19171 .61796 .17914 Mtetra
.655 .752 .921 r
.61796 .17914 .62736 .19171 .64619 .18494 .63688 .17228 Mtetra
.656 .752 .921 r
.63688 .17228 .64619 .18494 .66515 .17812 .65592 .16532 Mtetra
.656 .751 .92 r
.65592 .16532 .66515 .17812 .68423 .1712 .67509 .1583 Mtetra
.67509 .1583 .68423 .1712 .70344 .16422 .69439 .15125 Mtetra
.69439 .15125 .70344 .16422 .72279 .15721 .71383 .14417 Mtetra
.657 .752 .92 r
.03116 .37847 .04293 .38871 .05815 .38316 .04643 .37284 Mtetra
.656 .752 .92 r
.04643 .37284 .05815 .38316 .07346 .37759 .0618 .36719 Mtetra
.655 .751 .92 r
.0618 .36719 .07346 .37759 .08886 .37201 .07725 .36152 Mtetra
.07725 .36152 .08886 .37201 .10436 .36638 .0928 .35583 Mtetra
.0928 .35583 .10436 .36638 .11996 .36066 .10845 .3501 Mtetra
.656 .752 .92 r
.10845 .3501 .11996 .36066 .13565 .35491 .12419 .3443 Mtetra
.657 .752 .921 r
.12419 .3443 .13565 .35491 .15144 .34914 .14004 .33845 Mtetra
.656 .752 .92 r
.14004 .33845 .15144 .34914 .16733 .34336 .15599 .33257 Mtetra
.656 .751 .92 r
.15599 .33257 .16733 .34336 .18331 .33756 .17203 .32667 Mtetra
.17203 .32667 .18331 .33756 .19939 .33174 .18817 .32075 Mtetra
.655 .75 .92 r
.18817 .32075 .19939 .33174 .21557 .32586 .20441 .31482 Mtetra
.20441 .31482 .21557 .32586 .23186 .3199 .22075 .30884 Mtetra
.655 .751 .92 r
.22075 .30884 .23186 .3199 .24826 .3139 .2372 .30282 Mtetra
.656 .752 .921 r
.2372 .30282 .24826 .3139 .26475 .30787 .25376 .29673 Mtetra
.656 .753 .921 r
.25376 .29673 .26475 .30787 .28135 .3018 .27042 .2906 Mtetra
.27042 .2906 .28135 .3018 .29805 .29569 .28719 .28442 Mtetra
.28719 .28442 .29805 .29569 .31486 .28956 .30406 .27821 Mtetra
.30406 .27821 .31486 .28956 .33178 .28339 .32105 .27196 Mtetra
.32105 .27196 .33178 .28339 .34881 .27718 .33814 .26568 Mtetra
.33814 .26568 .34881 .27718 .36594 .27094 .35534 .25936 Mtetra
.35534 .25936 .36594 .27094 .38319 .26465 .37266 .253 Mtetra
.37266 .253 .38319 .26465 .40054 .25833 .39008 .24661 Mtetra
.39008 .24661 .40054 .25833 .41801 .25197 .40763 .24017 Mtetra
.655 .753 .921 r
.40763 .24017 .41801 .25197 .4356 .24557 .42528 .2337 Mtetra
.42528 .2337 .4356 .24557 .4533 .23914 .44305 .22719 Mtetra
.656 .753 .921 r
.44305 .22719 .4533 .23914 .47111 .23267 .46095 .22062 Mtetra
.656 .752 .921 r
.46095 .22062 .47111 .23267 .48904 .22616 .47895 .21398 Mtetra
.657 .752 .92 r
.47895 .21398 .48904 .22616 .5071 .2196 .49708 .20729 Mtetra
.657 .751 .919 r
.49708 .20729 .5071 .2196 .52527 .21296 .51533 .20055 Mtetra
.656 .75 .919 r
.51533 .20055 .52527 .21296 .54356 .20626 .53371 .19379 Mtetra
.656 .751 .92 r
.53371 .19379 .54356 .20626 .56197 .19951 .5522 .187 Mtetra
.655 .751 .92 r
.5522 .187 .56197 .19951 .58051 .19275 .57082 .18018 Mtetra
.655 .752 .921 r
.57082 .18018 .58051 .19275 .59917 .18596 .58957 .17332 Mtetra
.58957 .17332 .59917 .18596 .61796 .17914 .60844 .16641 Mtetra
.656 .752 .921 r
.60844 .16641 .61796 .17914 .63688 .17228 .62744 .15941 Mtetra
.656 .751 .92 r
.62744 .15941 .63688 .17228 .65592 .16532 .64657 .15235 Mtetra
.64657 .15235 .65592 .16532 .67509 .1583 .66583 .14526 Mtetra
.66583 .14526 .67509 .1583 .69439 .15125 .68523 .13814 Mtetra
.655 .751 .921 r
.68523 .13814 .69439 .15125 .71383 .14417 .70476 .13099 Mtetra
.656 .752 .92 r
.01926 .3681 .03116 .37847 .04643 .37284 .03458 .36242 Mtetra
.657 .752 .92 r
.03458 .36242 .04643 .37284 .0618 .36719 .05 .35668 Mtetra
.656 .752 .92 r
.05 .35668 .0618 .36719 .07725 .36152 .06551 .35093 Mtetra
.655 .751 .92 r
.06551 .35093 .07725 .36152 .0928 .35583 .08111 .34516 Mtetra
.08111 .34516 .0928 .35583 .10845 .3501 .09681 .33937 Mtetra
.09681 .33937 .10845 .3501 .12419 .3443 .11261 .33354 Mtetra
.656 .752 .92 r
.11261 .33354 .12419 .3443 .14004 .33845 .12851 .32765 Mtetra
.657 .752 .921 r
.12851 .32765 .14004 .33845 .15599 .33257 .14451 .3217 Mtetra
.14451 .3217 .15599 .33257 .17203 .32667 .16061 .31571 Mtetra
.656 .752 .92 r
.16061 .31571 .17203 .32667 .18817 .32075 .17681 .3097 Mtetra
.656 .751 .92 r
.17681 .3097 .18817 .32075 .20441 .31482 .19312 .30366 Mtetra
.19312 .30366 .20441 .31482 .22075 .30884 .20952 .29759 Mtetra
.655 .75 .92 r
.20952 .29759 .22075 .30884 .2372 .30282 .22603 .29149 Mtetra
.22603 .29149 .2372 .30282 .25376 .29673 .24264 .28536 Mtetra
.24264 .28536 .25376 .29673 .27042 .2906 .25937 .27919 Mtetra
.655 .751 .92 r
.25937 .27919 .27042 .2906 .28719 .28442 .2762 .27297 Mtetra
.656 .752 .921 r
.2762 .27297 .28719 .28442 .30406 .27821 .29313 .2667 Mtetra
.29313 .2667 .30406 .27821 .32105 .27196 .31018 .26039 Mtetra
.31018 .26039 .32105 .27196 .33814 .26568 .32734 .25404 Mtetra
.656 .753 .921 r
.32734 .25404 .33814 .26568 .35534 .25936 .34462 .24764 Mtetra
.34462 .24764 .35534 .25936 .37266 .253 .362 .2412 Mtetra
.362 .2412 .37266 .253 .39008 .24661 .3795 .23472 Mtetra
.656 .752 .921 r
.3795 .23472 .39008 .24661 .40763 .24017 .39711 .22819 Mtetra
.656 .752 .92 r
.39711 .22819 .40763 .24017 .42528 .2337 .41484 .22161 Mtetra
.656 .751 .92 r
.41484 .22161 .42528 .2337 .44305 .22719 .43269 .21498 Mtetra
.43269 .21498 .44305 .22719 .46095 .22062 .45066 .2083 Mtetra
.656 .75 .919 r
.45066 .2083 .46095 .22062 .47895 .21398 .46874 .20158 Mtetra
.46874 .20158 .47895 .21398 .49708 .20729 .48695 .19483 Mtetra
.656 .751 .92 r
.48695 .19483 .49708 .20729 .51533 .20055 .50528 .18805 Mtetra
.50528 .18805 .51533 .20055 .53371 .19379 .52373 .18122 Mtetra
.655 .751 .921 r
.52373 .18122 .53371 .19379 .5522 .187 .54231 .17437 Mtetra
.655 .752 .921 r
.54231 .17437 .5522 .187 .57082 .18018 .56101 .16747 Mtetra
.656 .752 .921 r
.56101 .16747 .57082 .18018 .58957 .17332 .57984 .1605 Mtetra
.656 .752 .92 r
.57984 .1605 .58957 .17332 .60844 .16641 .5988 .15346 Mtetra
.656 .751 .92 r
.5988 .15346 .60844 .16641 .62744 .15941 .61788 .14636 Mtetra
.61788 .14636 .62744 .15941 .64657 .15235 .6371 .13923 Mtetra
.6371 .13923 .64657 .15235 .66583 .14526 .65646 .13207 Mtetra
.655 .751 .921 r
.65646 .13207 .66583 .14526 .68523 .13814 .67594 .12488 Mtetra
.655 .752 .921 r
.67594 .12488 .68523 .13814 .70476 .13099 .69557 .11763 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
[(-2)] .12586 .2075 1 .99877 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.56863 .04703 m
.57247 .05235 L
s
[(2)] .56094 .0364 .72324 1 Mshowa
.125 Mabswid
.18558 .19702 m
.18832 .19985 L
s
.23703 .17687 m
.23971 .17975 L
s
.28951 .15632 m
.29214 .15925 L
s
.39772 .11395 m
.40023 .11699 L
s
.4535 .09211 m
.45595 .0952 L
s
.51046 .06981 m
.51284 .07294 L
s
.08568 .23614 m
.08851 .23887 L
s
.62804 .02377 m
.63027 .02701 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 233.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00o?ooool2o`0006[ooooo003iooooo`?o000000?oooooo`000?ooool0
JOooool00?Oooooo0_l00004ooooo`;o0000JOooool00?Cooooo0ol00006ooooo`03o`000?oooooo
000006Sooooo003;ooooo`Go00008_ooool2o`0000Wooooo00?o0000ooooool00000J?ooool00<_o
oooo00GoV9RHob4Q8Oo^k^koooooodA4A00Oooooo`?o00002oooool01?l0003oooooooooool0001W
ooooo`00c?ooool00onHV9So8B4Qonk^kP0Mooooo`?o00003_ooool01Ol0003ooooooooooooooooo
000006Kooooo003=ooooo`03oiRHV?lQ8B7ok^k^01[ooooo0_l0000Aooooo`05o`000?oooooooooo
ooooool00000I_ooool00<kooooo00?oMgMgofIVI_ooool05_ooool3o`0001?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1Sooooo`00coooool00ol0003oooooooooo`0Cooooo`;o
00000_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0H_ooool00<_ooooo00Go0000okZj^_ooooooV9RHoa0@400Booooo`?o00006Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo06;ooooo003;ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`04?ooool2o`0001cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Qooooo`00
gOooool3o`0001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Qooooo`00fooo
ool2o`00027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Pooooo`00f?ooool3
o`0002?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Oooooo`00eOooool3o`00
02Kooooo00?o0000ooooooooool01?ooool2o`00067ooooo003Cooooo`;o0000:Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo05kooooo003@ooooo`?o000000?oooooo`000?ooool0
:?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05gooooo003>ooooo`;o00001Ooo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0GOoo
ool00<_ooooo0ol0000`ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0G?ooool0
0<Wooooo0_l0000cooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Foooool00<Ko
oooo0ol0000eooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Foooool00<Cooooo
0_l0000hooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0F_ooool00<7ooooo0ol0
000jooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03_ooool5o`0004Kooooo002n
ooooo`?o0000?Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00kooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A016ooooo`00_?ooool2o`0000?ooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo1_l00003ooooo`03oiRHV?lQ8B7o
k^k^04Oooooo002iooooo`?o0000@oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00kooooo00?oV9RHob4Q8Oo^k^h0A_ooool00;Oooooo0_l00016ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03oooool00omgMgOoIVIVooooo`15ooooo`00]?ooool3o`0004Sooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Cooooo
002booooo`;o0000Boooool00ol0003oooooooooo`0=ooooo`;o00003?ooool01Ol0003o^[Zjoooo
oonHV9So410@04Kooooo002_ooooo`?o0000COooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c016ooooo`00[Oooool2o`00053ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`1Dooooo`00Z_ooool4o`00057ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1Dooooo`00Z?ooool2o`0000Cooooo00?o0000oooo
ooooool0C_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05?ooooo001nooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h08_ooool3o`0005Oooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`1Booooo`00O_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01oooooo0ol0001Joooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool0D_ooool007kooooo00Go410@oooooooo
oooooooooa0@400Mooooo`;o0000GOooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
057ooooo001nooooo`05o`000?ooooooooooooooool000006_ooool3o`0005oooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`1@ooooo`00O_ooool01Ol0003ooooooooooooooooo0000
01Sooooo0_l0001Rooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0D?ooool007ko
oooo00Go410@oooooooooooooooooa0@400Eooooo`?o0000I?ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo04oooooo001nooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool2o`00
00?ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
04kooooo001nooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04?ooool3o`0006Sooooo00?oYl3[o`00
0?ooool05_ooool00ol0003oooooooooo`1>ooooo`00TOooool2o`0006Sooooo1?nW`>/00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo04gooooo002>ooooo`?o0000J?ooool7ojO0j`03o`00
0?oooooooooo01Cooooo0ol0001>ooooo`00Roooool3o`0006Wooooo2OnW`>/00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo04cooooo0029ooooo`;o0000JOooool<ojO0j`03o`000?nW`>_o
oooo01Oooooo00?o0000ooooooooool0Boooool008Kooooo0ol0001Xooooo`ooYl3[00?o0000ojO0
joooool06?ooool00ol0003oooooooooo`1:ooooo`00Q?ooool2o`0000;ooooo00?o0000oooooooo
ool0HooooolBojO0j`03o`000?nW`>_oYl3[01Sooooo00?o0000ooooooooool0B_ooool0087ooooo
0ol00005ooooo`03o`000?oooooooooo063ooooo5?nW`>/01?l0003oYl3[ojO0jonW`>/Hooooo`03
o`000?oooooooooo04Wooooo001oooooo`;o0000JOoooolFojO0j`03o`000?nW`>_oYl3[00;oYl3[
6?ooool00ol0003oooooooooo`18ooooo`00O?ooool3o`0006Sooooo6OnW`>/00ol0003oYl3[ojO0
j`02ojO0jaSooooo00?o0000ooooooooool0B?ooool007[ooooo0_l0001WoooooagoYl3[00?o0000
ojO0jonW`>/00onW`>/Hooooo`03o`000?oooooooooo04Oooooo001gooooo`?o0000I_oooolPojO0
j`03o`000?nW`>_oYl3[00CoYl3[6?ooool00ol0003oooooooooo`16ooooo`00M?ooool3o`0006Ko
oooo8onW`>/00ol0003oYl3[ojO0j`04ojO0jaSooooo00?o0000ooooooooool0A_ooool007;ooooo
0_l00002ooooo`03o`000?oooooooooo06;ooooo9OnW`>/00ol0003oYl3[ojO0j`05ojO0jaSooooo
00?o0000ooooooooool0AOooool006oooooo0ol0001WooooobOoYl3[00?o0000ojO0jonW`>/01OnW
`>/Hooooo`03o`000?oooooooooo04Gooooo001]ooooo`;o0000IooooolZojO0j`03o`000?nW`>_o
Yl3[00KoYl3[5oooool2o`0004Kooooo001Zooooo`?o0000I_ooool]ojO0j`03o`000?nX`>_oYl3[
00OoYl3[6?ooool00ol0003oooooooooo`13ooooo`00J?ooool2o`0006Kooooo;OnW`>/3ojS0j`03
o`000?nX`>_oZ<3[00SoYl3[5oooool00ol0003oooooooooo`13ooooo`00IOooool3o`0006Gooooo
;_nW`>/5ojS0j`04o`000?nX`>_oZ<3[ojS0j`OoYl3[6?ooool00ol0003oooooooooo`12ooooo`00
Hoooool2o`0006Gooooo<_nW`>/5ojS0j`04o`000?nX`>_oZ<3[ojS0j`OoYl3[6?ooool00ol0003o
ooooooooo`11ooooo`00H?ooool3o`000003ooooool0003ooooo06;ooooo=OnW`>/4ojS0j`03o`00
0?nX`>_oZ<3[00WoYl3[5oooool00ol0003oooooooooo`11ooooo`00=_ooool5o`0002?ooooo0_l0
001VooooocOoYl3[1?nX`>/00ol0003oYl3[ojO0j`0:ojO0jaOooooo00?o0000ooooooooool0@?oo
ool003Kooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Pooooo`?o0000IOoooolkojO0j`04ojS0jonW
`>_oYl3[o`0000coYl3[6?ooool00ol0003oooooooooo`0oooooo`00;_ooool6o`0000?ooooo00?o
V9RHob4Q8Oo^k^h07_ooool3o`0006Gooooo@OnW`>/00ol0003oYl3[ojO0j`0;ojO0jaOooooo00?o
0000ooooooooool0?oooool003Sooooo00?oV9RHob4Q8Oo^k^h06oooool2o`0006GoooooA?nW`>/0
0ol0003oYl3[ojO0j`0<ojO0jaOooooo00?o0000ooooooooool0?_ooool003Wooooo00?oMgMgofIV
I_ooool05oooool3o`0006CoooooAonW`>/00ol0003oYl3[ojO0j`0<ojO0jaSooooo00?o0000oooo
ooooool0?Oooool003[ooooo00?o0000ooooooooool05?ooool2o`0006Cooooo00?oYko[ojO0jonW
`>/03OnW`>/00onW_n_oYl3[ojO0j`0=ojO0j`03ojNojonW`>_oYl3[02OoYl3[00?o0000ojO0jonW
`>/03OnW`>/Gooooo`03o`000?oooooooooo03gooooo000fooooo`05o`000?nj^[[ooooooiRHV?l@
41004oooool3o`0000;ooooo00?o0000ooooooooool0Goooool4ojNoj`_oYl3[1OnW_n/;ojO0j`Go
Yko[:?nW`>/00ol0003oYl3[ojO0j`0=ojO0jaSooooo00?o0000ooooooooool0??ooool003Kooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c00Aooooo`;o0000IOooool7ojNoj`OoYl3[00?oZ<3[ojNojonW
_n/01_nW_n/6ojO0j`;oZ<3[2?nW_n/6ojO0j`;oYko[7onW`>/00ol0003oYl3[ojO0j`0>ojO0jaKo
oooo0ol0000mooooo`00BOooool3o`0006Gooooo2_nW_n/4ojO0j`CoZ<3[2?nW_n/2ojO0j`KoZ<3[
2?nW_n/2ojO0j`KoYko[7_nW`>/00ol0003oYl3[ojO0j`0?ojO0jaOooooo00?o0000ooooooooool0
>oooool004Oooooo0_l0001Uooooo`koYko[00?oYl3[ojS0jonX`>/01OnX`>/6ojNoj`[oZ<3[1_nW
_n/00onX`>_oYko[ojNoj`07ojNojagoYl3[00?o0000ojO0jonW`>/04?nW`>/Gooooo`03o`000?oo
oooooooo03[ooooo0014ooooo`?o0000I?ooool00onW`>_oYko[ojNoj`0<ojNoj`[oZ<3[1?nW_n/=
ojS0j`;oYko[1OnX`>/9ojNojacoYl3[00?o0000ojO0jonW`>/04?nW`>/Hooooo`03o`000?oooooo
oooo03Wooooo0011ooooo`?o0000I?ooool5ojO0j`[oYko[3_nX`>/00onW_n_oZ<3[ojS0j`0EojS0
j`KoYko[0_nX`>/LojO0j`03o`000?nW`>_oYl3[017oYl3[5oooool00ol0003oooooooooo`0ioooo
o`00?oooool3o`0006?ooooo2OnW`>/6ojNoj`;oYl3[3_nX`>/2ojO0jaSoZ<3[0_nW_n/6ojS0ja_o
Yl3[00?o0000ojO0jonW`>/04_nW`>/Gooooo`03o`000?oooooooooo03Sooooo000looooo`?o0000
0oooool00ol0003oooooooooo`1Nooooo`coYl3[0_nW_n/6ojO0j`[oZ<3[1_nW`>/7ojS0j`03ojO0
jonX`>_oZ<3[00coZ<3[0_nW`>/8ojS0j`KoYl3[00?oZ<3[ojO0jonW`>/04OnW`>/00ol0003oYl3[
ojO0j`0CojO0jaKooooo00?o0000ooooooooool01oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02co
oooo000jooooo`;o0000IOoooolGojO0j`KoZ<3[2_nW`>/4ojS0j`CoYl3[2_nX`>/6ojO0j`SoZ<3[
0_nW`>/5ojS0ja;oYl3[00?o0000ojO0jonW`>/04onW`>/Gooooo`03o`000?oooooooooo00Kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0/ooooo`00=oooool3o`0006Gooooo6_nW`>/2ojS0j`koYl3[
00?oZ<3[ojO0jonW`>/01OnW`>/6ojS0j`[oYl3[1_nX`>/00onW`>_oZ<3[ojS0j`06ojS0j`KoYl3[
0_nX`>/:ojO0j`03o`000?nW`>_oYl3[01?oYl3[5oooool00ol0003oooooooooo`05ooooo`05oa0@
4?ooooooooooooooool@4100;?ooool003Gooooo0_l0001UooooocGoYl3[1?nX`>/=ojO0j`;oZ<3[
1OnW`>/8ojS0j`;oYl3[1_nX`>/9ojO0j`03o`000?nW`>_oYl3[01CoYl3[5_ooool00ol0003ooooo
ooooo`05ooooo`05o`000?ooooooooooooooool00000;?ooool003;ooooo0ol0001TooooocWoYl3[
00?oZ<3[ojO0jonW`>/05OnW`>/6ojS0j`03ojO0jonX`>_oZ<3[00OoZ<3[1_nW`>/00onX`>_oYl3[
o`00000GojO0jaKooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000002co
oooo000`ooooo`;o0000I?oooomEojO0j`;oZ<3[1OnW`>/9ojS0j`;oYl3[1OnX`>/00ol0003oYl3[
ojO0j`04ojO0j`03ojS0jonW`>_oYl3[00koYl3[5oooool00ol0003oooooooooo`03ooooo`05oa0@
4?ooooooooooooooool@4100;?ooool002gooooo0ol000000ooooooo0000ooooo`1Pooooof3oYl3[
1_nX`>/2ojO0j`OoZ<3[00?o0000ojO0jonW`>/00_nW`>/4ojS0ja3oYl3[5_ooool2o`0000Cooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0/ooooo`00:_ooool3o`0006?oooooI?nW`>/2ojS0j`KoYl3[
1_nX`>/00ol0003oZ<3[ojO0j`07ojS0j`KoYl3[00?oZ<3[ojO0jonW`>/01onW`>/Cooooo`;o0000
00?oooooo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02cooooo000Xooooo`;o0000
Hooooom`ojO0j`GoZ<3[00?o0000ojO0jonX`>/01onX`>/4ojO0j`CoZ<3[2OnW`>/Fooooo`03o`00
0?oooooooooo03;ooooo000Uooooo`?o0000H_ooool[ojO0j`;oYko[3_nW`>/00onW_n_oYl3[ojO0
j`0<ojO0j`03ojNojonW`>_oYl3[02OoYl3[0_nX`>/00onW`>_o0000o`000002ojO0j`SoZ<3[00?o
Yl3[ojS0jonX`>/01OnX`>/8ojO0jaKooooo00?o0000ooooooooool0<_ooool002?ooooo0_l0001R
ooooob_oYl3[1_nW_n/:ojO0j`GoYko[2_nW`>/5ojNoj`SoYl3[00?oYko[ojO0jonW`>/07OnW`>/3
o`000003ojO0jol0003oYl3[00;oYl3[4?nX`>/8ojO0jaKooooo00?o0000ooooooooool0<Oooool0
023ooooo0ol0001Rooooob[oYl3[2_nW_n/6ojO0j`WoYko[1_nW`>/9ojNoj`CoYl3[1OnW_n/KojO0
j`?o00001OnW`>/01?l0003oYl3[ojO0jonW`>/?ojS0j`SoYl3[5oooool00ol0003oooooooooo`0`
ooooo`007oooool2o`0006;ooooo:_nW`>/=ojNoj`;oYl3[3OnW_n/2ojO0j`goYko[00?oYl3[ojNo
jonW_n/01_nW_n/6ojO0j`03ojNojonW`>_oYl3[00koYl3[0ol00009ojO0j`03o`000?nW`>_oYl3[
013oZ<3[2?nW`>/Fooooo`03o`000?oooooooooo033ooooo000Oooooo`03o`000?oooooo000005oo
oooo:_nW`>/>ojNoj`03ojRojonW_n_oYko[00coYko[00?oZ;o[ojNojonW_n/03?nW_n/2ojRoj`Wo
Yko[0_nW`>/5ojNoj`coYl3[0ol0000=ojO0j`03o`000?nW`>_oYl3[013oZ<3[1_nW`>/00onX`>_o
ooooooooo`0Eooooo`03o`000?oooooooooo02oooooo000<ooooo`Go00000oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Kooooo00Co0000oooooooooooo0000Foooool[ojO0j`koYko[1?nX_n/:ojNo
j`GoZ;o[2_nW_n/6ojRoj`OoYko[00?oZ;o[ojNojonW_n/01_nW_n/6ojO0j`03ojNojonW`>_o0000
00;o00004?nW`>/01?l0003oYl3[ojO0jonW`>/6ojS0j`03ojO0jonX`>_oZ<3[00OoZ<3[0_nW`>/5
ojS0jaOooooo00?o0000ooooooooool0;_ooool000cooooo00GoV9RHob4Q8Oo^k^koooooodA4A003
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool2o`0000;ooooo00?o0000ooooooooool0EOoo
ool[ojO0j`ooYko[1onX_n/6ojNoj`03ojS0jonX_n_oZ;o[00KoZ;o[1_nW_n/00onX`>_oZ;o[ojRo
j`07ojRoj`CoYko[1?nX_n/8ojNoj`;oYl3[0_nW_n/3o`0001CoYl3[00Co0000ojO0jonW`>_oYl3[
0_nX`>/5ojO0ja3oZ<3[5_ooool00ol0003oooooooooo`0^ooooo`001?ooool6o`0000?ooooo00?o
V9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00Gooooo0_l00004ooooo`03o`00
0?oooooooooo057ooooo7?nW`>/00onW_n_oYl3[ojO0j`0<ojO0ja3oYko[0_nX`>/8ojRoj`;oYko[
1OnX`>/8ojRoj`;oYko[1OnX`>/9ojRoj`03ojNojonX_n_oZ;o[00GoZ;o[1_nW_n/00onX`>_oYko[
o`000002o`0000CoYko[1_nW`>/00onW_n_oYl3[ojO0j`0;ojO0j`03o`000?nW`>_oYl3[00SoYl3[
4?nX`>/Fooooo`03o`000?oooooooooo02gooooo000>ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go
0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
COoooolLojO0j`GoYko[2_nW`>/@ojNoj`KoZ<3[1_nX_n/00onW`>_oZ<3[ojS0j`06ojS0j`KoZ;o[
2OnX`>/6ojRoj`;oZ<3[2OnX_n/2ojNoj`?oZ<3[0_l00008ojNoj`;oYl3[1OnW_n/<ojO0j`03o`00
0?nW`>_oYl3[00WoYl3[3onX`>/Gooooo`03o`000?oooooooooo02cooooo000?ooooo`03ogMgMomV
IVKooooo00;ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0BOoooolLojO0j`WoYko[1_nW`>/@ojNoj`[oZ<3[0_nX_n/5ojO0j`SoZ<3[
0_nX_n/=ojS0j`;oZ;o[1_nX`>/7ojRoj`?oZ<3[0ol00003ojS0j`KoYko[00?oZ;o[ojNojonW_n/0
1_nW_n/<ojO0j`03o`000?nW`>_oYl3[00WoYl3[3onX`>/Eooooo`;o0000;_ooool0013ooooo00Go
0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00?ooooo0_l00007ooooo`03o`00
0?oooooooooo04Kooooo6onW`>/=ojNoj`;oYl3[4?nW_n/<ojS0j`03ojO0k?nW`>_oYl3[00KoYl3[
1_nX`>/00onW`>coZ<3[ojS0j`0<ojS0j`;oYl3/2?nX`>/4ojRoj`;oZ<3[0ol00007ojS0j`;oYko[
1OnX_n/8ojNoj`coYl3[00?o0000ojO0jonW`>/02OnW`>/6ojS0j`03ojO0jonX`>_oZ<3[00KoZ<3[
5_ooool00ol0003oooooooooo`0[ooooo`003?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0@_oooolMojO0jagoYko[00?oYl3[ojS0jonX`>/02_nX`>/4ojO0k0SoYl3[0_nX`>/5ojO0k0[o
Z<3[1_nW`>`8ojS0j`03ojRojonX`>_o000000;o00002_nX`>/8ojRoj`KoYko[00?oZ;o[ojO0jonW
`>/02onW`>/00ol0003oYl3[ojO0j`09ojO0j`;oZ<3[1OnW`>/8ojS0jaGooooo00?o0000oooooooo
ool0:oooool000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03kooooo0_nW_n/OojO0
jaWoYko[1OnW`>/9ojS0j`OoYl3/1_nW`>/00onW`NcoYl3/ojO0k006ojO0k0KoZ<3[2_nW`>`6ojS0
j`?o00003_nX`>/8ojRoj`;oYko[1OnX_n/<ojO0j`03o`000?nW`>_oYl3[017oYl3[1onX`>/Foooo
o`03o`000?oooooooooo02[ooooo000Nooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool0>_ooool6ojNojaooYl3[5OnW_n/9ojO0j`KoZ<3[0_nW`N`8ojO0k0;oYl3[1OnW`N`8ojO0k0;o
Z<3[3_nW`>`2ojS0j`?o00000onW`>`6ojS0j`03ojO0k?nX`>_oZ<3[00KoZ<3[1_nX_n/00onX`>_o
Z;o[ojRoj`06ojRoj`KoYl3[00?oYko[ojO0jonW`>/00onW`>/00ol0003oYl3[ojO0j`0AojO0j`Oo
Z<3[5_ooool00ol0003oooooooooo`0Yooooo`007Oooool3o`0000_ooooo00?o0000ooooooooool0
=_ooool:ojNojaooYl3[4OnW_n/=ojO0j`;oZ<3[1_nW`N`8ojO0k0OoYl7/5_nW`>`3o`0000OoYl3/
0_nX`>/5ojO0k0SoZ<3[0_nX_n/5ojS0j`SoZ;o[0_nW`>/5ojNoj`GoYl3[00?o0000ojO0jonW`>/0
4?nW`>/7ojS0jaKooooo00?o0000ooooooooool0:Oooool001gooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0booooo`koYko[7OnW`>/?ojNoj`03ojO0k?nW`>_oYl3[00coYl3[2_nW
`N`8ojO0k0OoYl7/4_nW`>`3o`0001;oYl3/1_nX`>/00onW`>coZ<3[ojS0j`06ojS0j`KoZ;o[00?o
Z<3[ojNojonW_n/01_nW_n/5ojO0j`03o`000?nW`>_oYl3[013oYl3[1onX`>/Fooooo`03o`000?oo
oooooooo02Sooooo000Mooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0;oooool?
ojNoja_oYl3[3onW_n/5ojO0k0[oYl3[3?nW`N`:ojO0k0GoYl7/0_nW_n/>ojO0k0?o00005_nW`>`2
ojS0j`GoYl3/2?nX`>/2ojRoj`GoZ<3[2?nW_n/4ojO0j`03o`000?nW`>_oYl3[013oYl3[1onX`>/G
ooooo`03o`000?oooooooooo02Oooooo000Mooooo`;o00003oooool00ol0003oooooooooo`0[oooo
o`ooYko[6onW`>/?ojNoj`WoYl3/1_nW`>/<ojO1k0koYl3/00?oYl7/ojNojonW_n/01?nW_n/:ojO0
k003ojO0jol0003o000000;oYl3[7onW`>`6ojS0j`03ojO0jonX`>_oZ<3[00KoZ<3[1_nW_n/2ojS0
j`CoYl3[00?o0000ojO0jonW`>/04?nW`>/7ojS0jaKooooo00?o0000ooooooooool09oooool001go
oooo00?o0000ooooooooool03oooool2o`0002Sooooo0_nW`>/=ojNoja_oYl3[3onW_n/=ojO0k0;o
Yl3[3?nW`N`2ojO0j`koYl3/2OnW_n/6ojO0k004ojNojol0003o0000o`0000GoYl3[1_nW`>`2ojNo
jaOoYl3/0_nX`>/5ojO0j`SoZ<3[0_nW_n/6ojS0j`CoYl3[00?o0000ojO0jonW_n/03onW`>/8ojS0
jaKooooo00?o0000ooooooooool09_ooool001gooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Rooooo`KoYl3[2OnW_n/KojO0j`ooYko[0_nW`>/=ojO0k0goYl7/1OnW`>/:ojO0k0go
Yko[0_nW`>`01OnW_n_o0000o`000?l0003oYko[00SoYl3[0_nW`>`6ojNoj`KoYl3/00?oYko[ojO0
k?nW`>`03OnW`>`8ojO0ja3oZ<3[0_nW`>/2ojNoj`03o`000?nW_n_oYko[00ooYl3[2?nX`>/Foooo
o`03o`000?oooooooooo02Gooooo000Mooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool07_ooool:ojO0j`GoYko[6onW`>/?ojNoj`KoYl3[2OnW`>`?ojO1k0OoYl3[1_nW`>`00onW_^[o
Yko[ojNoj`0<ojNoj`04ojRoj_l0003o0000o`0000GoYko[1_nW`>/2ojNojPSoYko[0_nW`>`5ojNo
j`ooYl3/2?nW`>/?ojS0j`CoYko[00Co0000ojNojonW_n_oYko[3onW`>/6ojS0j`03ojO0jooooooo
oooo01Cooooo0_l0000Vooooo`007?ooool3o`0001Cooooo00?o0000ooooooooool06_ooool>ojO0
j`03ojNojonW`>_oYl3[01[oYl3[3onW_n/9ojO0j`KoYl3/3onW`N`2ojNoj`SoYl3[0_nW`>`5ojNn
jP[oYko[00GoZ;oZo`000?l0003o0000ojRojP08ojNoj`;oYl3[1_nW_nX6ojNoj`03ojRoj_nW_n_o
Yko[00KoYko[1_nW`>`00onW_n_oYl3/ojO0k006ojO0k0KoYl3[00?oYl3/ojS0jonX`>/03_nX`>/4
ojNoj`04o`000?nW_n_oYko[ojNoj`ooYl3[0_nX`>/5ojO0jaCooooo00?o0000ooooool000009_oo
ool001cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Gooooo`ooYl3[00?oYko[
ojO0jonW`>/06OnW`>/>ojNoj`goYl3[0_nW`>`?ojO1k0KoYko[1_nW`>/00onX_^[oYkkZojNnjP06
ojNnjPKoYko[00CoZ;oZo`000?l0003o00001OnX_nX6ojNoj`;oZ;oZ2?nW_nX2ojNoj`GoZ;oZ2?nW
_n/2ojO0k0GoYko[2?nW`>`2ojO0j`GoYl3/1onX`>/00onW`>_oZ<3[ojS0j`06ojS0j`CoYko[00?o
0000ojNojonX`>/05onW`>/Fooooo`03o`000?oooooooooo02?ooooo000:ooooo`Co000000So410@
ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`0Cooooo`ooYl3[1OnW_n/HojO0j`goYko[3onW`>/?ojO1k0[oYko[0_nW`>/5ojRnjPSo
YkkZ0_nW_n/01?nX_n[o0000o`000?l00009ojRojP;oYko[1_nX_nX6ojNojP03ojS0jonX_n[oZ;oZ
00KoZ;oZ1_nW_n/00onX_n[oYko[ojNoj`06ojNoj`ooYl3/1?nX`>/4ojO0j`SoZ<3[0_nW_n/00onX
`>_o0000ojS0j`02ojS0jaOoYl3[5Oooool00ol0003oooooooooo`0Sooooo`003?ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo00oooooo0_nX`>/=ojO0j`WoYko[5OnW`>/<ojNoj`ooYl3[3onW`N`<ojNo
j`03ojRoj_nX_^[oZ;kZ00KoZ;kZ1_nW_^X01?nX`>_o0000o`000?l0000;ojRojP03ojS1jonX_n[o
Z;oZ00OoZ;oZ0_nW_nX5ojS0j`SoZ;oZ0_nW_n/5ojRojPSoYko[3onW`>`00onX`>_oYl3[ojO0j`05
ojO0j`_oZ<3[00Co0000ojS0jonX`>_oZ<3[5_nW`>/Fooooo`03o`000?oooooooooo02;ooooo0000
0ooooooo0000o`000004o`0000Gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@00Kooooo0_l0000Iooooo`03o`000?oooooooooo00cooooo1OnX`>/9ojO0j`goYko[4OnW
`>/>ojNoj`goYl3[3onW`N`<ojNoj`GoZ;oZ2?nX_^X2ojNnjP;oZ<3[0_l000000onX`>_oZ;oZojRo
jP08ojRojPGoZ<7[1onX_nX00onX`N_oZ<3[ojS0j`06ojS0j`KoZ;oZ00?oZL3[ojRoj_nX_nX01_nX
_nX8ojNoj`ooYl3/2?nW`>/;ojS0j`04o`000?nX`>_oZ<3[ojS0jaKoYl3[5_ooool00ol0003ooooo
ooooo`0Qooooo`003?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00[ooooo1onX`>/7ojO0j`goYko[
4_nW`>/?ojNoj`WoYl3[3onW`N`<ojNoj`;oYkoZ1onX_nX6ojRnjP03ojS1jonX`>_o000000;o0000
1?nX`>/6ojRojP03ojO0jonX`N_oZ<7[00KoZ<7[1?nX_nX4ojS1j`SoZ<3[0_nX_nX5ojW0j`SoZ;oZ
2?nW_n/?ojO0k0KoYl3[00?oYl3/ojS0jonX`>/02_nX`>/00ol0003oZ<3[ojS0j`0GojO0jaGooooo
00?o0000ooooooooool08Oooool000cooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000Gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`07ooooo`[oZ<3[
1onW`>/9ojNojaKoYl3[3onW_n/5ojO0j`ooYl7/3?nW_n/6ojNojPOoZ;oZ0_nX_^X2ojS1j`?o0000
2?nX`>/2ojRojPGoYl3[2?nX`N/00onX_n[oZ<7[ojS1j`05ojS1j`OoZ<3[2?nY`>/6ojRojP03ojW0
j_nW_n_oYko[00OoYko[0onW`>`4ojNoj`SoYl3/0_nW`>/5ojO0k0_oZ<3[00Co0000ojS0jonX`>_o
Z<3[5_nW`>/Fooooo`03o`000?oooooooooo023ooooo000<ooooo`03o`000?oooooooooo00;ooooo
00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool00oooool<ojS0j`WoYl3[1_nW_n/IojO0j`ooYko[00?oYl3[ojO1k?nW`N`03OnW`N`<ojNoj`[o
YkoZ1OnX_nX2ojO1k0?o00001?nX`N/6ojS0j`;oYl3/1onW`>/6ojS1j`;oYl3/2?nX`N/7ojS0j`So
ZL3[0_nX_nX5ojW0jPOoYko[00?oZ;oZojNojonW_n/01_nW_n/>ojO0k0coZ<3[00?o0000ojS0jonX
`>/05onW`>/Fooooo`03o`000?oooooooooo01oooooo000<ooooo`03o`000?oooooooooo00;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o00007_ooool00ol0003oooooojO0j`02ojO0j`Wo
Z<3[3OnW`>/2ojNoja_oYl3[3onW_n/?ojO1k0;oYl3[2OnW_n/>ojNojP03ojRoj_nW`NcoYl7/00?o
000000?oYl7/ojS1jonX`N/01OnX`N/2ojS0j`KoYl3/1onW`>/2ojS1j`KoYl3/1_nX`N/00onW`>_o
Z<3[ojS0j`06ojS0j`KoZL3[00?oZ<3[ojW0j_nY`>X01_nY`>X4ojNoj`CoZ;oZ2?nW_n/>ojO0k0co
Z<3[00?o0000ojS0jonX`>/05onW`>/Eooooo`03o`000?oooooooooo01oooooo000:ooooo`03oeEE
EOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo01co
oooo1onW`>/6ojS0j`koYl3[0_nW_n/=ojO0j`?oZ<3[2OnW`>/?ojNoj`ooYl7/1_nW`>/6ojNoj`03
ojNnj_nW_n[oYkoZ00coYkoZ00CoYl3/o`000?l0003o00001OnW`N`5ojS1j`?oYl3[1onW`>`3ojO0
j`CoYko[2?nW`>`2ojS1j`GoYl3[2?nX`>/2ojW0j`GoZ<3[2?nY`>X00onW_n_oZ;oZojRojP05ojRo
jPOoYko[3_nW`>`=ojS0j`03o`000?nX`>_oZ<3[01OoYl3[5Oooool00ol0003oooooooooo`0Noooo
o`006oooool00ol0003oooooooooo`0Jooooo`[oYl3[0_nX`>/>ojO0j`KoYko[2OnW`>/7ojS0j`Go
Yl3[3onW_n/2ojO0j`goYl7/0_nX`>/8ojO0j`;oYko[1OnW_^X:ojNojP05ojO0k?l0003o0000o`00
0?nW`>`02?nW`N`00onX`N_oYl3[ojO0j`05ojO0j`GoYl3/00?oYkcXojNojonW_n/01_nW_n/6ojO0
k003ojNmjOnW`>_oYl3[00KoYl3[1_nX`>/00onW`>_oZ<3[ojS0j`06ojS0j`KoZL3Z0_nX`N/8ojRo
jPOoYko[3_nW`>`<ojS0j`04o`000?nX`>_oZ<3[ojS0jaKoYl3[5_ooool00ol0003oooooooooo`0M
ooooo`006oooool00ol0003oooooooooo`0Gooooo`coYl3[0_nX`>/=ojO0j`WoYko[1_nW`>/:ojS0
j`03ojO0jonW_n_oYko[00goYko[1_nW`>/9ojO1k0KoZ<3[1_nW`>/9ojNnjPKoYkoZ00CoYl3/o`00
0?l0003o00001OnW`>`6ojO1k0;oYko[2?nW`>/00onW`>coYkcXojNlj003ojNlj0SoYko[0_nW`>`5
ojNmj@SoYl3[0_nX`>/5ojO0j`SoZ<3[0_nY`>X6ojS1j`KoZ;oZ00?oZL7[ojNojonW_n/01OnW_n/6
ojO0k003ojNojonW`>coYl3/00KoYl3/1_nX`>/2ojO0j`CoZ<3[00Co0000ojS0jonX`>_oZ<3[5_nW
`>/Dooooo`;o00007oooool001_ooooo0_l0000Fooooo`_oYl3[1_nX`>/9ojO0j`goYko[0_nW`>/<
ojS0j`;oYl3[3OnW_n/9ojO0j`GoYl7/0onX`N`7ojS0j`;oYl3[3OnW_^X2ojNojP;oYl3/0_l00009
ojO0k0;oYl7/1_nW_n/6ojO0j`03ojNfi?nW_>SoYkcX00GoYkcX1_nW_n/00onX]N;oYkgYojNmj@06
ojNmj@KoYl3[0_nW_>P7ojO0j`KoZ<3[0_nW`>`8ojS1j`;oZ;oZ1OnY`N/7ojNoj`;oYl3/1OnW_n/8
ojO0k0;oZ<3[1_nW`>/4ojS0j`03o`000?nX`>_oZ<3[01KoYl3[5_ooool00ol0003oooooooooo`0L
ooooo`006_ooool00ol0003oooooooooo`0Cooooo`koYl3[1onX`>/7ojO0j`goYko[0onW`>/9ojS0
j`KoYl3[2OnW_n/=ojO0j`03ojO1k?nX`NcoZ<7/00GoZ<7/1OnX`>/?ojNnjP03ojO1k?nW`>co0000
00;o00002_nW`>`2ojNnjPSoYko[0_nW`>/5ojNfi0OoYkcX0_nW_n/5ojRehPSoYkgY0_nW`>/6ojNl
j0OoYl3[0_nX`>/6ojO0k0KoZ<7[00?oYl3[ojW1jonY`N/01OnY`N/6ojNoj`;oZ<3[1onW_n/8ojO0
k0SoYl3[1?nX`>/00ol0003oZ<3[ojS0j`0FojO0jaGooooo00?o0000ooooooooool07?ooool001[o
oooo00?o0000ooooooooool03ooooolCojO0j`OoZ<3[1onW`>/9ojNoj`OoYl3[1onX`>/8ojO0j`Oo
Yko[3OnW`>/:ojS1k003ojS0jonW_^[oYkkZ00goYkkZ0_nW`N`3o`0000[oYl3/1_nW_^X6ojNoj`03
ojNbh?nW]^CoYkKT00KoYkKT1OnW_>P00onY[M_oZ;GRojRehP06ojRehPKoYkgY00?oZK;NojNlj?nW
_>P01onW_>P3ojO0j`CoYkgY2?nW`>`2ojS1j`GoYl3[1onY`N/2ojNoj`KoZ<3[1onW_n/8ojO0k0Oo
Yl3[1?nX`>/00ol0003oZ<3[ojS0j`06ojO0j`;oZ<3[3onW`>/Eooooo`03o`000?oooooooooo01_o
oooo000Jooooo`03o`000?oooooooooo00_ooooo6?nW`>/5ojS0j`WoYl3[1_nW_n/:ojO0j`OoZ<3[
2?nW`>/7ojNoj`WoYl3[3?nX`N`00onW_n_oYkkZojNnjP0;ojNnjP;oYl3/0ol00004ojO1k0KoYl3/
2_nW_^X2ojNoj`GoYk;P2?nW]^@00onW_>SoZJgKojV]f`03ojV]f`SoZ;GR0_nW_NT5ojVbgPOoYkcX
00?oZk?OojNmjOnW_NT01_nW_NT6ojO0k003ojNojonW`>_oYl3[00GoYl3[1_nY`N/00onX`N_oZ<3[
ojS0j`07ojS0j`OoYko[2?nW`>`7ojO0j`CoZ<3[00?o0000ojS0jonX`>/00_nW`>/6ojS0j`ooYl3[
5Oooool00ol0003oooooooooo`06ooooo`Go00003oooool001[ooooo0_l00009oooooacoYl3[00?o
Z<3[ojO0jonW`>/02onW`>/2ojNoj`coYl3[2OnX`>/6ojO0j`WoYko[1OnW`>/3ojS1j`WoZ<7/1OnW
_n/9ojNnjP;oYl3/0ol000000onW`>coYl7/ojO1k005ojO1k0;oYl3/3?nW_^X00onW/=koYk;PojNb
h006ojNbh0KoYkKT00?oZZWFojV]fonY[M/01OnY[M/6ojRehP03ojj]eonY/]koZK;N00KoZK;N1?nW
_>P4oj^cg`SoYkgY0_nW`>`5ojNoj`OoYl3[0_nY`N/5ojS1j`OoZ<3[00?oZL3ZojNojonW_n/01_nW
_n/6ojO0k003ojNok?nW`>_oYl3[00GoYl3[1OnX`>/00ol0003oZ<3[ojS0j`07ojS0ja3oYl3[5?oo
ool00ol0003oooooooooo`06ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@03oooool001[ooooo00?o
0000ooooooooool01_ooool2ojS0ja_oYl3[0onX`>/:ojO0j`CoYko[2OnW`>/=ojS0j`;oYl3[3OnW
_n/00onW`>_oZ<7[ojS1j`05ojS1j`GoZ<7/0_nX`>/7ojNoj`KoYkkZ00CoYl3[o`000?l0003o0000
1OnW`>`5ojO1k0?oYko[2OnW_^X5ojN`gPOoYk;P1?nW]^@4ojZYePOoZJgK0onX]N84ojj]e`SoZK;N
00?oYkcXoj^cgon[/ml01On[/ml6ojNmj@03ojZhhonW_n_oYko[00KoYko[1onW`>/7ojS1j`CoZ<3[
1?nY`>X8ojNoj`;oYl3/1OnW_n`7ojO0j`CoZ<3[00?o0000ojS0jonX`>/02?nX`>/?ojO0jaGooooo
00?o0000ooooooooool01_ooool00onHV9So8B4Qonk^kP0@ooooo`006_ooool00ol0003ooooooooo
o`03ooooo`KoZ<3[5onW`>/7ojS0j`OoYl3[1onW_n/6ojO0j`koZ<3[3onW_n/2ojS0j`SoZ<7[00?o
Z<7/ojS0jonX`>/01?nX`>/7ojNoj`;oYkkZ00GoYl3[o`000?l0003o0000ojO0j`08ojO0k003ojO1
k?nW_n_oYko[00GoYko[1OnW_^X00onV/=ooYk3NojN`gP06ojN`gPOoYk;P00?oYkKTojZYe_nZZMH0
1OnZZMH7ojV]f`03ojReh_n^[MOo[ZgG00Co[ZgG1_nY/]h00onb[mKoZk?Ooj^cg`07oj^cg`;oYkgY
1OnZ^><8ojNoj`OoYl3[1onX`N/00onX`>_oZL3ZojW0jP05ojW0jPKoYko[00?oYl3[ojNok?nW_n`0
1OnW_n`8ojO0j`CoZ<3[00?o0000ojS0jonX`>/02?nX`>/?ojO0jaGooooo00?o0000ooooooooool0
1_ooool00onHV9So8B4Qonk^kP0?ooooo`006_ooool00ol0003oooooooooo`02ojO0j`SoZ<3[4onW
`>/;ojS0j`OoYl3[1onW_n/2ojO0j`koZ<3[3onW_n/6ojS0j`OoZ<7[2?nX`>/6ojNoj`?o00001OnW
`>/6ojO0k0;oYl3[2?nW_n/00onW_^[oY[3OojJ`g`03ojJ`g`OoYk3N1_nW/^000onYY]?oZZWFojZY
eP06ojZYePKoZJgK00?o[ZO@ojj]eon^[ML01On^[ML4ojVbgPCo/ZoF1on[/ml00ond/mSoZ[SSojZh
h`06ojZhh`KoYko[00?oZ;gXojO0jonW`>/01_nW`>/3ojS1j`CoYl3[2?nY`>X2ojNoj`GoYl3[1onW
_n`8ojO0j`CoZ<3[00?o0000ojS0jonX`>/02?nX`>/>ojO0jaGooooo00?o0000ooooooooool01ooo
ool00omgMgOoIVIVooooo`0>ooooo`006Oooool00ol0003oYl3[ojO0j`04ojO0j`SoZ<3[3onW`>/=
ojS0j`WoYl3[1OnW_n/2ojO0j`goZ<3[0_nW`>/;ojNoj`CoYl3[1onX`>/7ojS1j`SoZ<3[0_nW_n/3
o`0000;oYko[1onW`>/2ojO0k0KoYl3[1_nW_n/00onV/^7oY[3OojJ`g`05ojJ`g`OoYk3N0_nW/^05
ojVVd`SoZZWF0_nY[M/5ojjWd0Oo[ZgG00?oZK;Nok:_e_nb[mH01Onb[mH4oj^cg`Co];?H2?nZ^><2
ojNoj`GoZ;gX1_nW`>/00onW_n_oYl3[ojO0j`06ojO0j`KoZL3Z00?oZL7[ojO0jonW`>/01_nW`>/5
ojNok0;oYko[2?nW`>/4ojS0j`03o`000?nX`>_oZ<3[00SoZ<3[3_nW`>/Eooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool03Oooool001Wooooo00?o0000ojO0jonW`>/01OnW`>/6ojS0
ja7oYl3[2OnX`>/=ojO0j`03ojNojonW`>_oYl3[00CoYl3[2OnX`>/6ojO0j`OoYko[2?nW`>/5ojS0
j`WoZ<7[1_nX`>/00onW_^_o0000o`000006ojNoj`ooYl3[0_nW_n/5ojJbh@OoY[3O1OnW/=h00onW
Xm;oZJKCojVVd`06ojVVd`KoZZWF00?o[JC>ojjWd?n^Ym001_n^Ym05ojj]e`03ok>Yconb[mKo/ZoF
00Oo/ZoF00?oZk?OokBcf?nd/mP01Ond/mP6ojZhh`03ok:hgOnX_NSoZ;gX00KoZ;gX0_nW`>/5ojNo
j`SoYl3[0_nY`>X5ojW1j`SoYl3[00?oYko/ojNojonW_n/01?nW_n/7ojO0j`CoZ<3[00?o0000ojS0
jonX`>/02?nX`>/?ojO0ja?ooooo0ol00004ooooo`05o`000?nj^[[ooooooiRHV?l@41003oooool0
00kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?ooooooYl3[00KoYl3[0_nX`>/E
ojO0j`OoZ<3[3OnW`>/2ojNoj`OoYl3[2?nX`>/7ojO0j`OoYko[2?nW`>/00onX`>_oZ<7[ojS1j`0;
ojS1j`;oZ<3[00CoYkk[o`000?l0003o00000_nW_^/7ojNoj`goYl3[00?oY[KTojJbhOnV/^401_nV
/^47ojJ`g`03ojN`g_nWXm;oYj?B00?oYj?B1onYY]<4ojZYePCo[JC>1on^Ym03ojj]e`Co/jW?1onb
[mH00ong[]3o];?HokBcf007okBcf0;oZ[SS1Onb^=d6ojRmj003ojbkiOnW_n_oYko[00KoYko[1onW
`>/8ojW1j`KoYl3[00?oZ<3[ojNojonW_n/01_nW_n/7ojO0j`CoZ<3[00?o0000ojS0jonX`>/02?nX
`>/?ojO0jaCooooo00?o0000ooooooooool00_ooool01OnHV9So410@o`000?lQ8B7oc<c<00oooooo
000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`05ojO0j`?oZ<3[
5_nW`>/7ojS0j`WoYl3[1_nW_n/7ojO0j`SoZ<3[1OnW`>/9ojNoj`KoYl3[3_nX`N/01?nW_n_o0000
o`000?l00006ojNnj`?oYko[1?nX`>/9ojO0j`GoY[KT1onV/^46ojJ`g`03ojBRdonWXm;oYj?B00Co
Yj?B2?nYY]<00onZZMKo[JC>ojfTcP04ojfTcPSo[ZO@00?o[ZgGok>YconcZLl01?ncZLl5ok:_eP?o
]jk@1ond/mP00onj/m?o/[SMok:hg@06ok:hg@?oZ;gX1?n/^nD8ojNoj`OoYl3[2?nY`N/2ojO0j`Go
Z<3[1onW_n/8ojO0j`CoZ<3[00?o0000ojS0jonX`>/01onX`>/@ojO0jaCooooo00?o0000oooooooo
ool05Oooool000kooooo00Go410@oooooooooooooooooa0@4006ooooo`;o00000_ooool00onW`>_o
Z<3[ojS0j`05ojS0jaCoYl3[2OnX`>/8ojO0j`OoYko[1OnW`>/:ojS0j`03ojO0jonW_n_oYko[00_o
Yko[0_nW`>/>ojS1j`04ojNojol0003o0000o`0000?oYko[1OnW_^/2ojO0j`OoZ<3[1_nW`>/00onW
_>SoY[KTojJfi005ojJfi0OoY[;Q0_nV/=l5ojBRd`KoYj?B1_nYY]<00on/Xloo[JC>ojfTcP06ojfT
cPKo[ZO@00?o]Jc?ok>YconcZLl01OncZLl3ok:_ePKo]jk@1Ond/mP3okZcd`So/[SM00?oZ;gXojbk
iOn/^nD01?n/^nD8ojNoj`OoYl3[1onY`N/8ojS0j`OoYko[2?nW`>/4ojS0j`03o`000?nX`>_oZ<3[
00OoZ<3[3onW`>/Eooooo`03o`000?oooooooooo01Cooooo000>ooooo`05o`000?oooooooooooooo
ool000001_ooool00ol0003oooooooooo`03ooooo`OoZ<3[4?nW`>/=ojS0j`SoYl3[1onW_n/00onW
`>_oZ<3[ojS0j`0:ojS0j`;oYl3[3?nW_n/3ojO0j`coZ<7[0ol00007ojNoj`03ojNnjonW`>_oYl3[
00CoYl3[1onX`>/2ojO0j`GoYkcX1_nV]^@6ojJbh@03oj:Se_nTX]?oY:;C00GoY:;C1_nWXm84ojVV
d`Co[:??1on]Y<h4ojjWd0Co]Jc?1oncZLl00onb[mKo]jk@okN^d005okN^d0?o];?H1_nj/m<6ok:h
g@;o^[_J1on/^nD8ojNoj`OoYl3[1onY`N/7ojS0j`SoYko[1_nW`>/00onW_n_oZ<3[ojS0j`02ojS0
j`03o`000?nX`>_oZ<3[00SoZ<3[3onW`>/Dooooo`03o`000?oooooooooo01Cooooo000>ooooo`05
o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`05ooooo`GoZ<3[4OnW`>/<ojS0
j`[oYl3[0onW_n/4ojO0j`WoZ<3[1_nW`>/8ojNoj`OoYl3[2?nX`N/3o`0000?oZ<3[1_nW_n/00onV
_n_oYl3[ojO0j`06ojO0j`GoZ<3[00?oZ;o[ojNlj?nW_>P01_nW_>P6ojJfi0;oY[;Q1OnRXmH7ojBR
d`KoYj?B00?oZJKCojbScon/Xll01?n/Xll8ojfTcP03ojjWd?ne[<oo]Jc?00Go]Jc?1OncZLl00onl
]=;o]jk@okN^d007okN^d003okBcf?nj/m?o^[?C00Go^[?C1?nb^=d5okZkfPGo[;_U0_na_^<8ojNo
j`?oYl3[0onW_n/8ojW1j`OoZ<3[2?nW_n/2ojO0j`GoYko[1?nX`>/00ol0003oZ<3[ojS0j`08ojS0
j`koYl3[5Oooool00ol0003oooooooooo`0Cooooo`003_ooool01Ol@413ooooooooooooooooo410@
00Gooooo00?o0000ooooooooool01_ooool00onX`>_oYl3[ojO0j`0CojO0j`SoZ<3[3?nW`>/2ojNo
j`OoYl3[1onX`>/8ojO0j`OoYko[2?nW`>/4ojS1j`?o00001onX`>/2ojNoj`GoY[o[2?nW`>/00onX
`>_oZ;o[ojRoj`03ojRoj`SoYkcX0onV]^@2oj2Uf@OoXZ?F1onTX]<5ojNSdP03ojRSd?n/Xloo[:??
00Ko[:??1_n]Y<h00one]=So]Jc?okF/c`06okF/c`?o/jW?1?nl]=87okN^d003ol2gdOnj/m?o^[?C
00Oo^[?C00?o/[SMokZkf_nj^mX01_nj^mX00on/^nGo/KkSok6nh`04ok6nh`KoYko[00?oZ;oZojNo
jonW_n/01OnW_n/6ojW1j`03ojW0jonX`>_oZ<3[00KoZ<3[3onW_n/4ojS0j`03o`000?nX`>_oZ<3[
00SoZ<3[3_nW`>/Eooooo`03o`000?oooooooooo01;ooooo000>ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2o`0000Sooooo5_nW`>/8ojS0j`SoYl3[1_nW_n/7ojO0j`OoZ<3[2?nW`>/7ojNo
j`KoYl3[0_nX`N/3o`0000CoZ<7[1OnX`>/2ojJnj`OoY[o[2?nW`>/6ojRoj`KoYkcX00?oX:[Noj2U
fOnPYMT01?nPYMT7oj:SePOoY:;C00?oYj?BojRSd?nXXm000onXXm07ojbSc`Co[JC>1?ne]=P8okF/
c`03ok>Yconl]=;o_;CB00Co_;CB1Ong[]03ol2gd@Oo^[?C00?o`KWCokZkf_nj^mX01_nj^mX00ono
_]Wo/KkSok6nh`06ok6nh`;oYko[1OnX_nX7ojNoj`;oZL7[1OnY`>/8ojS0j`koYko[1?nX`>/00ol0
003oZ<3[ojS0j`07ojS0j`ooYl3[5Oooool00ol0003oooooooooo`0Booooo`003_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool02?oooolFojO0j`SoZ<3[1onW`>/7ojNo
j`GoYl3[2OnX`>/6ojO0j`WoYko[0_nW`>/3ojS1j`;o00002?nX`N/00onX`>_oY[k[ojJnj`04ojJn
j`OoY[o[2?nW`>/6ojRoj`;oYkcX1OnPZ]h6oj2Uf@KoXZ?F1_nTX]<00onTXM;oZ:?@ojRSd005ojRS
d0Oo[:??00?o[JC>okFdf?ne]=P01?ne]=P7okF/c`03ok_5hOnl]=;o_;CB00Go_;CB0ong[]06ol2g
d@Go^[?C0oo1^M<6okZkfP?o_kkI1_na_^<00onf`^?oZ;oZojRojP06ojRojPGoYko[00?oYl3[ojW0
jonY`>/01_nY`>/7ojS0j`ooYko[1?nX`>/00ol0003oZ<3[ojS0j`03ojS0ja?oYl3[5Oooool00ol0
003oooooooooo`0Aooooo`006?ooool00ol0003oooooooooo`09oooooa;oYl3[3?nX`>/7ojO0j`Oo
Yko[00?oYl3[ojS0jonX`>/02onX`>/2ojO0j`_oYko[0_nX`>/01?nX`N_o0000o`000?l00009ojS1
j`03ojO0jonV_^_oY[k[00KoY[k[1OnV_n/2ojS1j`SoYl3[0onX_n/2oj>ci0SoX:[N1_nPYMT6oj:S
eP;oY:;C1OnTXM86ojRSd0Ko[:??00?o/[kSokFdf?ne]=P01_ne]=P5okF/c`?o^lGQ1onl]=800ong
[]3o`;OAol2gd@05ol2gd@?o^[?C1_o1^M<3okZkfPGo_kkI1?na_^<4okK2h`SoZ;oZ00?oYko[ojO0
jonW`>/00onW`>/8ojW0j`OoZ<3[3onW_n/4ojS0j`03o`000?nX`>_oZ<3[00goYl3[00?oYko[ojO0
jonW`>/01_nW`>/Eooooo`03o`000?oooooooooo013ooooo000Hooooo`03o`000?oooooooooo00[o
oooo3onW`>/=ojS0j`WoYl3[1OnW_n/3ojO0j`[oZ<3[1?nW`>/8ojNoj`?oZ<3[0ol00009ojS1j`Go
Yl3[2?nV_^/00onV_n_oZ<7[ojS1j`04ojS1j`KoYl3[00?oY[cYoj>ci?nS/n@01?nS/n@7oj2ZgPOo
X:GI0onRXmH2oinMdPOoY:7B1onXXm03ojbSc`Co/[kS1one]=P3okF/c`Ko^lGQ1Onl]=800onnb>;o
`;OAol2gd@07ol2gd@03okZcdoo1^M?o`KWC00Ko`KWC00?o^[_JoknnfOno_]T01Ono_]T00ona_^?o
]/;SokK2h`05okK2h`KoZ;oZ00?oZL7[ojO0jonW`>/01OnW`>/8ojW0j`OoZ<3[3onW_n/4ojS0j`03
o`000?nX`>_oZ<3[00WoYl3[1OnW_n/7ojO0jaGooooo0_l0000Aooooo`005oooool3o`0000gooooo
3_nW`>/9ojS0j`goYl3[00?oYko[ojO0jonW`>/01OnW`>/7ojS0j`OoYl3[1onW_n/3o`0000CoZ<3[
2?nX`N/6ojO0j`KoY[k[0_nW_n/7ojS1j`;oYl3[1OnV_>T6oj>ci0OoX:[N0onPYMT3oiZKd`KoWigB
1onTXM87ojRSd003ojbSconb_^?o/[kS00Co/[kS1one]=P00one[<oo^lGQok_5h@05ok_5h@?o_;CB
1?nnb>87ol2gd@03ol?4foo1^M?o`KWC00Ko`KWC00?oa/3DoknnfOno_]T01Ono_]T00oo4`mWo]/;S
okK2h`07okK2h`;oZ;oZ1OnY`N/7ojO0j`SoZL3[1_nX`>/?ojNoj`CoZ<3[00Co0000ojS0jonX`>_o
Z<3[1onW`>/7ojNoj`OoYl3[4oooool00ol0003oooooo`00000Aooooo`005oooool00ol0003ooooo
ooooo`0>ooooo`koYl3[2?nX`>/<ojO0j`;oYko[2?nW`>/7ojS0j`OoYl3[0onW_n/3o`000003ojNo
jonX`>_oZ<3[00GoZ<3[2?nX`N/6ojO0j`;oY[k[1_nW_n/5ojS1j`;oZ<3[1onV_>T6oj>ci0GoX:[N
00?oVIgGoiZKdonJVm<01OnJVm<5oinMdPOoY:7B1_nXXm02ojc4j`Ko/[kS1_ne]=P2oj[Gm`So^lGQ
00?o_;CBokk8h_nnb>801?nnb>85ol2gd@?o`lCK1_o1^M<3olK0e0Go_kkI0oo4`mT7okK2h`;o^LKT
1onY`N/7ojO0j`SoZL3[1_nX`>/?ojNoj`CoZ<3[00?o0000ojS0jonX`>/02?nW`>/6ojNoj`SoYl3[
5?ooool00ol0003oooooooooo`0?ooooo`005oooool00ol0003oooooooooo`0?ooooo`koYl3[2?nX
`>/8ojO0j`KoYko[1_nW`>/9ojS0j`GoYl3[00CoYko[o`000?l0003o00001OnW_n/5ojS0j`[oZ<7[
0onW`>/4ojJnj`OoYko[00?oZ<7[ojS0jonX`>/01?nX`>/6ojJlj@OoXk?T00?oX:[NoiVMeonIWML0
0onIWML6oiZKd`KoWigB1onTXM82ojRSd0Ko[<C[1_nb_^<2okFdf0KoZ]Og1_nkaN400onKg_go_/SR
okk8hP05okk8hP?o`;OA1_o3a=/3ol6id`Koa/3D0ono_]T5olC3f@Co]/;S1Onia^@6ojW1j`SoYl3[
1_nY`>/00onY`N_oZ<3[ojS0j`05ojS0j`ooYko[1?nX`>/00ol0003oZ<3[ojS0j`08ojO0j`KoYko[
2?nW`>/Dooooo`03o`000?oooooooooo00kooooo000Gooooo`03o`000?oooooooooo013ooooo3?nW
`>/:ojS0j`OoYl3[1onW_n/2ojO0j`goZ<3[00?oYl3[ojNojol000000_l00009ojNoj`03ojS0jonX
`N_oZ<7[00[oZ<7[00?oYko[ojJnjonV_^/01_nV_^/5ojNoj`WoZ<3[1_nV_>T3oj>ci0?oV:CM1_nI
WML7oiZKd`GoWigB1_nTXM82ojO2k@So[<C[0onb_^<4oh7Rm`OoZ]Og0_nkaN45oi_No@Oo_/SR00?o
`;OAol?4foo3a=/01_o3a=/00oo1^M?oa/3DolK0e006olK0e003oknnfOo4`mWoa<?I00Goa<?I00?o
]/;SokW6i?nia^@01_nia^@6ojW1j`SoYl3[0_nY`>/5ojW1j`OoZ<3[3OnW_n/00onW`>_oZ<3[ojS0
j`03ojS0j`03o`000?nX`>_oZ<3[00OoYl3[1onW_n/6ojO0j`03ojS0jooooooooooo01?ooooo00?o
0000ooooooooool03Oooool001Oooooo0_l0000Booooo`SoYl3[3?nX`>/9ojO0j`GoYko[0_nW`>/=
ojS0j`?o00002OnW_n/4ojS0j`WoZ<7[1OnW_n/8ojJnj`03ojNojonX`>_oZ<3[00_oZ<3[0onV_>T2
oib]h`OoV:CM1_nIWML6oiZKd`KoWigB0_nTXM86ojO2k@Ko[<C[1?mMe]`5oh7Rm`?oZ]Og1OlKZKD6
oi_No@Go_/SR0_nWdoL7ol?4f`03ok_9iOo6`=Coa/3D00Koa/3D00?ob<KHolC3fOo4`mT01Oo4`mT2
olO9g0Oo^LKT00?o^/WVojW1jonY`N/01OnY`N/6ojO0j`03ojNojonY`N_oZL7[00KoZL7[0onX`>/4
ojO0j`WoYko[1OnW`>/4ojS0j`04o`000?nX`>_oZ<3[ojS0j`OoYl3[1onW_n/2ojO0j`GoZ<3[5?oo
ool00ol0003oooooooooo`0=ooooo`005oooool00ol0003oooooooooo`0Booooo`SoYl3[2?nX`>/=
ojO0j`03ojNojonW`>_oYl3[00CoYl3[2OnX`>/00onW`>_o0000o`000003ojO0j`OoYko[1onX`>/8
ojS1j`KoYko[1_nV_^/2ojNoj`[oZ<3[0onT^nT6oib]h`OoV:CM1OnIWML7oiZKd`?oWigB0onR^>T8
ojO2k@;o[<C[1?mMe]`2ogGQj@;oZ;[V2?nF/n`3oe:/n@;o6jVe1_nKg_d00onnb>;oYm?gojOCm`04
ojOCm`Co`lCK1?nkbND6olK0e0?ob<KH1Oo4`mT4olO9g0Co^LKT1?njbNH7ojW1j`;oYl3[1OnW_n/7
ojW1j`SoYl3[1_nW_n/8ojO0j`CoZ<3[00?o0000ojS0jonX`>/02?nW`>/6ojNoj`SoZ<3[5?ooool0
0ol0003oooooooooo`0<ooooo`005oooool00ol0003oooooooooo`0Cooooo`SoYl3[1onX`>/<ojO0
j`?oYko[1_nW`>/6ojS0j`?o00001_nW`>/7ojNoj`OoZ<3[2?nX`N/6ojNoj`;oY[k[1_nW_n/5ojS0
j`;oYl3[1_nT^nT6oib]h`KoV:CM1_nIWML3oiZKd`?oVj[Q1onR^>T6ojO2k@?oJMcP0_nOmND00ome
hNWoZ;[VojRjiP04ojRjiPKoU[?/00?o[JoIoiBajonD/N/01OnD/N/4oaR5j0;o5J?<1_nWdoL00oo3
a=_o^lWUok_9i@05ok_9i@?oa/3D1_o8a]P3olC3f@KoalWL00?o^LKTok[9i_njbNH01?njbNH6ojW1
j`;oZ<7[1onW_n/7ojW1j`SoYl3[1_nW_n/8ojO0j`CoZ<3[00?o0000ojS0jonX`>/01onW`>/7ojNo
j`OoZ<3[5Oooool00ol0003oooooooooo`0;ooooo`005oooool00ol0003oooooooooo`0Eooooo`Oo
Yl3[1onX`>/8ojO0j`OoYko[1_nW`>/2ojS0j`?o00000onX`>/5ojO0j`WoYko[1OnX`>/:ojS1j`?o
Yko[1?nV_^/7ojNoj`03ojS0jonW`>_oYl3[00CoYl3[1_nT^nT5oib]h`OoV:CM0onIWML2oi>MfPOo
Vj[Q1onR^>T2ojO2k@?oJMcP1?nOmND2okSEk`OoZ;[V0_nF/n`5ojf_f@OoU;7[1OlHQNP01?lo003o
Ym?gojOCmonWdoL2og7;o`Wo^lWU00?oa/3DolS6f?o8a]P01_o8a]P00oo4`mWoalWLolO9g004olO9
g0;obM3O1onjbNH2ojW1j`KoZ<7[1_nW_n/8ojW1j`OoYl3[1onW_n/6ojO0j`KoZ<3[00?o0000ojS0
jonX`>/01onW`>/7ojNoj`OoZ<3[5?ooool00ol0003oooooooooo`0;ooooo`005_ooool3o`0001Oo
oooo2?nW`>/6ojS0j`SoYl3[1onW_n/3ojO0j`04ojS0jol0003o0000o`0000OoZ<3[00?oYl3[ojNo
jonW_n/02onW_n/00onX`>_oZ<7[ojS1j`0:ojS1j`03ojO0jonV_^_oY[k[00KoY[k[1OnW_n/00onX
`>_oYl3[ojO0j`06ojO0j`KoY;_Y1OnL[N<3oiRTg@?oSYWI1_nCWMX7oi^Zh@GoX[SY1?nBjOP3oioe
i@Ko^=G_1OnX^^H00onW[=_o[JoIojf_f@06ojf_f@GoU;7[0_n^`^P3odRBk`;o68GX00?o05S3ocl0
0?mabol00omabol7ok_9i@03ojk6k?o8a]Sob<KH00Kob<KH00?obL[KolO9g?o7bM`01?o7bM`4olW@
g`Go^/WV0_nhbnT8ojS1j`KoYko[2?nY`N/7ojO0j`OoYko[0_nW`>/9ojS0j`03o`000?nX`>_oZ<3[
00OoYl3[2?nW_n/7ojS0jaCooooo00?o0000ooooooooool02_ooool001Kooooo00?o0000oooooooo
ool06?ooool8ojO0j`KoZ<3[2?nW`>/5ojNoj`03ojO0jonX`>_o000000;o00002OnX`>/2ojO0j`co
Yko[0_nX`>/9ojS1j`GoYl3[2?nV_^/00onW_n_oZ<3[ojS0j`03ojS0j`SoYl3[0onT^nT2oiF[i@Go
T:7P1on>VMT6oi>MfPOoVj[Q00?oX[SYoi;Yn?nBjOP00onBjOP2ol;mh@?oc^oY1onheNl00onX^^Ko
YjcKojN/f`03ojN/f`So[JoI00?oU;7[ojk2j?n^`^P01?n^`^P5odRBk`03o`=UfOl0F<?oLL_o00?o
LL_o1?nkbND4ojk6k0Kob<KH0oo9b]/3olO9g0OobM3O00?o^/WVokS;jOnhbnT01?nhbnT6ojS1j`03
ojO0jonW_n_oYko[00GoYko[1onY`N/8ojO0j`KoYko[3?nX`>/00ol0003oZ<3[ojS0j`07ojO0j`So
Yko[1_nX`>/Cooooo`?o00002oooool000Cooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`00
0?lb<S;ok^k^1_ooool00ol0003oooooooooo`0Jooooo`OoYl3[0onX`>/;ojO0j`03ojNojonW`>_o
Yl3[00?o00002OnX`>/6ojO0j`SoYko[1_nX`>/7ojS1j`OoYl3[1_nV_^/2ojNoj`KoZ<3[1_nW`>/0
0onR^n_oUJ_UoiF[i@04oiF[i@GoT:7P1_n>VMT6oi>MfPKoVj[Q1?nWeoP01?nBjOSoYoSQol;mhOo2
oN46olk_j@?o^=G_0_nO]NP7ojN/f`Ko[JoI0_nlaN47ojk2j0GoB9;_0_l3IMT3od6RmP03og7;oonk
bNGo[/K/00Ko[/K/0oo8a]P6olW:f`03olO9g?o9d=oobM3O00GobM3O00?ob=CSokS;jOnhbnT01_nh
bnT2ojS1j`GoYl3[1onW_n/7ojW1j`KoYl3[2?nW_n/<ojS0j`03o`000?nX`>_oYl3[00GoYl3[2_nW
_n/6ojS0j`oooooo0ol00002ooooo`03o`000?oooooooooo00Wooooo0006ooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo01_ooooo1OnW
`>/00onX`>_oYl3[ojO0j`0;ojO0j`04ojNojol0003o0000o`0000CoYl3[2?nX`>/7ojO0j`OoYko[
1onX`>/7ojS1j`OoYl3[0_nV_^/6ojNoj`KoZ<3[0_nW`>/5oj:kj`KoUJ_U1On@XN06ohjIf@KoTigJ
0_nKZ^46ojOGn0;oYoSQ0_o2oN46olk_j@03ok[CkOnO]NSoWkGX00CoWkGX1_nW[=/4ojf_f@Go_<GQ
1On^`^P00on^bNkoG8gWoeb=i`02oeb=i`;oB9;_0_l3IMT4od6RmPSo[/K/00?ob<KHolW:foo9b]/0
1?o9b]/2ol[>g@KobM3O0oo8e><6okS;j@;o//_/1onW`>/7ojNoj`OoZL7[0_nW`>/<ojNoj`_oZ<3[
00?o0000ojS0jonX`>/00_nW`>/<ojNoj`03ojO0jonX`>_oZ<3[00GoZ<3[2oooool3o`0000Gooooo
00?o0000ooooooooool02Oooool000Kooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@00Kooooo0_l0000Mooooo`03ojO0jonX`>_oZ<3[00?oZ<3[2OnW`>/01?nW_n_o0000
o`000?l00002ojNoj`KoYl3[2?nX`>/7ojO0j`OoYko[2?nX`>/6ojS1j`GoYl3[0onV_n/7ojNoj`?o
Z<3[1?nW`>/6oj:kj`GoUJ_U1_n@XN05ohjIf@GoTigJ0onR_N`4ojOGn0?oYoSQ0_o2oN45olk_j@Co
^]?]1_nO]NP6ojN/f`03ojf_fOnlaN7o_<GQ00Ko_<GQ00?o[/;Xojk9k_n^bNh00on^bNh5oeb=i`;o
;FcK00?o0fGIocj<kOlnS>d00_m1X_H6ojk6k0;oYKo/1Oo9b]/4ol[>g@?obM3O1_o8e><2okS;j@Ko
//_/1OnW`>/9ojNoj`GoZL7[0_nX`N/>ojNoj`_oZ<3[00?o0000ojO0jonW`>/02_nW_n/5ojO0j`Oo
Z<3[1_ooool4o`0000Sooooo00?o0000ooooooooool02Oooool000Kooooo00?o0000ooooooooool0
0_ooool01Ol0003ooooooooooooooooo000000Gooooo0_l0000Oooooo`KoZ<3[1onW`>/2o`0000Ko
Yko[0onW`>/;ojS0j`OoYl3[1onW_n/8ojS0j`KoZ<7[00?oYl3[ojJojonV_n/01OnV_n/5ojNoj`03
ojS1jonW`>_oYl3[00KoYl3[1_nR^n/5oiF[i@KoT:7P1On>VMT00onCWM[oX[g/oj:mk006oj:mk006
ojOGn?nWn>7oYoSQojOhhOo2oN7oeOSS0ooNkM`00oo>knWo^]?]ok[Ck@04ok[Ck@KoWkGX1OnW[=/2
ojRoj`Oo_<GQ0_nogNl6ojk9kPGoG8gW0ol]K=/4ocj<k@;o[/K/1_nU_n`3olW:f`Kob/kM00?obM3O
olSDhoo8e><01?o8e><2olGFi`So//_/00?oYl3[ojNojonW_n/02onW_n/00onY`N_oZ<7[ojS1j`04
ojS1j`koYko[1_nX`>/00onX`N_oYl3[ojO0j`02ojO0j`03o`000?nW`>_oYl3[00OoYko[1onW`>/7
ojS0j`?ooooo0ol0000=ooooo`03o`000?oooooooooo00Sooooo0006ooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo01oooooo1_nX`>/3
ojO0j`?o00000_nW`>/7ojNoj`ooZ<3[1_nW`>/5ojNoj`?oYl3[1onX`>/3ojS1j`?oYl3[2?nV_n/0
0onW_n_oZ<7[ojS1j`03ojS1j`SoYl3[0onR^n/2oi>_jPGoRJ;T1_n4Umh6ohnRh@OoX[g/0onhiOD4
omGhh`?og^gL00?ofM[Hok[CkOnjdnd01Onjdnd6oinej003ojN/fonX_n_oZ;o[00CoZ;o[1?nlaN45
okoMk`Ko[/W^1OmLSNL3obe/f`Co?Xc]2?nU_n`00oo9b]_ob/kMol[>g@04ol[>g@;ocMGO1Oo8e><4
olGFi`Ko//_/00?o[<G/ojNojonW_n/02onW_n/00onX`>_oZ<7[ojS1j`06ojS1j`koYko[0_nX`>/5
ojS1j`CoYl3[00?o0000ojO0jonW`>/01onW_n/7ojO0j`OoZ<3[0_l0000@ooooo`03o`000?oooooo
oooo00Sooooo0006ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4005
ooooo`03o`000?oooooooooo023ooooo1OnX`>/3o`0000KoYl3[1onW_n/?ojS0j`KoYl3[00?oYko[
ojO0jonW`>/01OnW`>/5ojS0j`03ojS1jonW`>_oYl3[00GoYl3[2?nV_n/6ojS1j`KoYl3[00?oXkk/
oi>_j_nC[nX01?nC[nX5ohVRi0KoQ9ON1_n?X^44oj:mk0Co^>Ge1?oEn><3omk]g0?ofM[H1Onjdnd2
oj6mk@KoRKCb1onX_n/00onlaN7o_mg_okoMk`06okoMk`?o[/W^0_nFZN<3ofIof0;oG8gW0ol]K=/3
oeJ8iP;o?Xc]1_nU_n`00onU_>Wob/kMol[>g@04ol[>g@CocMGO0oo8e><6olGFi`;o//_/1On/aN`9
ojNoj`GoZ<3[1_nX`N/00onW`>_oYko[ojNoj`0;ojNoj`03ojO0jonX`N_oZ<7[00GoZ<7[1?nW`>/0
0ol0003oYl3[ojO0j`08ojNoj`?oYl3[2onX`>/Aooooo`03o`000?oooooooooo00Sooooo0006oooo
o`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o00008_ooool0
1?nX`>_o0000o`000?l00003ojS0j`SoYl3[1_nW_n/?ojS0j`?oYl3[0onW_n/8ojO0j`03ojS0jonX
`N_oZ<7[00?oZ<7[1onW`>/8ojJoj`KoZ<7[0_nW`>/5oj>nk0KoTjoZ1On9X^@6ohBGgPKoSj;Q00?o
X[g/okSUmOnhiOD00_nhiOD5omGhh`?og^gL1OoIf]P00onjdngoXKg]oj6mk@04oj6mk@KoRKCb1OnX
_n/3oj?GnPKo_mg_00?o/<S/oiJYhonFZN<01?nFZN<5ofIof0?o;FcK1OmFR>H2ojFok0GoYKcY0oo:
c]d7olgEg`03olSDhoo5e^OoaMKW00CoaMKW0_noe^/7ojc5k0KoYko[2?nX`>/2ojS1j`GoYl3[2OnW
_n/5ojO0j`OoZ<7[1?nW`>/00ol0003oYl3[ojO0j`07ojNoj`goZ<3[00?oYl3[ooooooooool03ooo
ool00ol0003oooooooooo`08ooooo`001?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`0Oooooo`?o00001onX`>/8ojO0j`KoYko[3OnX
`>/00onW`>_oYko[ojNoj`05ojNoj`KoYl3[0_nX`>/6ojS1j`GoYl3[2_nV_n/3ojS1j`CoZ<3[1_nS
_^`5oi>_jPGoRJ;T1_n4Umh5ohnRh@CoZ<;/00?o^>GeomGhhooEn><00ooEn><3omk]g0GofM[H0_o?
b=<7oj6mk@KoRKCb00?oZ;o[oj?Gn_nSeoX01OnSeoX2okoMk`Go/<S/1OnFZN<5ofIof0;oCW3D0_l]
K=/4oeJ8iPSoYKcY00?ob/kMolgEgoo=eMl01Oo=eMl2oloMh`CoaMKW1Onoe^/5ojc5k003ojS1k?nW
_n_oYko[00GoYko[1_nX`>/2ojW1j`KoYl3[2?nW_n/7ojO0j`KoZ<7[1OnW`>/00ol0003oYl3[ojO0
j`07ojNoj`WoZ<3[1OnW`>/@ooooo`03o`000?oooooooooo00Sooooo000Eooooo`03o`000?oooooo
oooo01cooooo0ol00004ooooo`GoZ<3[2_nW`>/3ojNoj`CoYl3[2?nX`>/5ojO0j`OoYko[0_nW`>/6
ojS0j`KoZ<7[00?oYl3[ojJojonV_n/02_nV_n/9ojS0j`KoXkk/1OnC[nX5ohVRi0KoQ9ON00?oSj;Q
ojS2k?nX`^`01?nX`^`4olKHi`;oeOSS0ooNkM`5omWJf0CoclSC1OnQ_Nd2oj:`hPOoQK_h1OnSeoX2
ojO5k`Ko/<S/1_nFZN<5ofIof0?oCW3D1OmFR>H6ojFlj@;o[/3W1_o=eMl4oloMh`03olGFionoe^_o
_mK[00Ko_mK[00?o[<G/ojS1k?nX`N`00onX`N`7ojNoj`;oZ<3[1_nY`N/6ojO0j`SoYko[1OnW`>/0
0onX`>_oZ<7[ojS1j`05ojS1j`GoYl3[00?o0000ojNojonW_n/01_nW_n/7ojS0j`SoYl3[3oooool0
0ol0003oooooooooo`08ooooo`005Oooool00ol0003oooooooooo`0Iooooo`?o00002?ooool00onX
`>_oYl3[ojO0j`0:ojO0j`03ojNojonW`>_oYl3[00KoYl3[1onX`>/6ojO0j`SoYko[1onX`>/3ojS1
j`CoZ<3[2?nV_n/=ojS0j`?oXkk/0_nG]nh5ohFVjPGoNYST1on;X^<5ojS2k0Goa]SW1?oLh=T2omgE
c`?ofM[H1_o?b=<00onQ_NgoX[3Roj:`hP04oj:`hPOoQK_h00?oXmOjojO5konWaNl01?nWaNl6ok38
k0GoUZWS1OmVOmP4odi`e0GoEXSV0onU_>T5ojk0i`?ocMGO1Oo?gN<2olcSj0Oo_mK[00?o]Lo^ojS1
k?nX`N`01OnX`N`7ojNoj`SoZL7[0onW`>/;ojNoj`03ojO0jonX`>_oZ<3[00?oZ<3[1onX`N/2ojO0
j`;oYko[00?o0000ojNojonW_n/01onW_n/7ojS0j`OoYl3[3oooool00ol0003oooooooooo`08oooo
o`005Oooool00ol0003oooooooooo`0Fooooo`?o00003Oooool8ojO0j`GoYko[2?nW`>/7ojS0j`Ko
Yl3[2?nW_n/>ojS0j`OoY[o[3?nX`>/2ojK0k0GoUkO^1On5Y^X5ogZHi0OoRj;S0onX`^`5olKHi`Go
g>3I0ooMeLl00ooIf]SoclSColo8d`05olo8d`SoX[3R0on5^oP4oj2^h@OoYlG_0on`b>`2oiVCc0Co
Q8G<0_nFZN<4ofIof0CoCW3D1?mdT=l2oeJ8iP03ojFljOn^`>Oo[/3W00Go[/3W00?ocMGOoloMhoo?
gN<00oo?gN<4olcSj0Co_mK[1?necnh7ojS1k0OoYko[1_nY`N/00onX`NcoYko[ojNoj`0<ojNoj`Oo
Z<3[1OnX`N/2ojO0j`CoYko[00?o0000ojNojonW_n/00onW_n/4ojO0j`OoZ<3[1onW`>/?ooooo`03
o`000?oooooooooo00Oooooo000Dooooo`;o00005Oooool3o`00017ooooo1onW`>/6ojNoj`KoYl3[
2OnX`>/7ojO0j`OoYko[3_nX`>/7ojJoj`SoZ<3[1_nV`>`5oiNgkPGoQJKZ1OmjV>@7oh^Rh`03ojS2
k?o6f>Ooa]SW00?oa]SW1OoLh=T4omgEc`OoclSC0_o8^</6oj:`hP03ok2UcOnP[^7oX:kQ00KoX:kQ
1OnWaNl00onSV<[oVI?<oiVCc004oiVCc0GoQ8G<0_m^N<`3ofIof0CoCW3D1_mdT=l6ojk0i`?o^l_V
0oo?gN<6olcSj003okoFjonecnko]Lo^00Go]Lo^0onX`N`;ojNoj`;oZL7[1OnX`N`>ojNoj`OoZ<3[
00?oZ<7[ojO0jonW`>/01?nW`>/4ojNoj`03o`000?nW_n_oYko[00OoYl3[1onX`>/7ojO0j`kooooo
00?o0000ooooooooool01oooool001Cooooo00?o0000ooooooooool04_ooool2o`0001Gooooo1onW
`>/6ojNoj`;oYl3[3_nX`>/6ojO0j`GoYko[0_nW`>/<ojS0j`;oYl3[1onV_n/7ojS0j`OoY/3/1OnG
]nh5ohFVjPGoNYST1On;X^<3ojFkj@?oa]SW1OoLh=T5omgEc`03omS7bOo?b=?oclSC00?oclSC1?o8
^</3oj:`hPCo/:G=2?nP[^400onWaNooXiS:oj>HbP03oj>HbPGoVI?<1_n4QL`4ofihc0GoCW3D1_md
T=l3ojk0i`Ko^l_V00?ocmgSolcSj?o<hnP01?o<hnP3ol?Nk@Go]Lo^00?oZlG/ojNojonW_n/02onW
_n/2ojS1j`KoZ<7/3onW_n/3ojS0j`?oZ<7[2?nW`>/4ojNoj`03o`000?nW_n_oYko[00OoYl3[1onX
`>/6ojO0j`kooooo00?o0000ooooooooool01oooool001Cooooo00?o0000ooooooooool03oooool3
o`0001Sooooo1onW`>/7ojNoj`ooZ<3[1_nW`>/00onW_n_oYl3[ojO0j`04ojO0j`SoZ<3[1_nW`>/7
ojJoj`OoZ<3[1OnV`>`00onR_^goR:k_ohR^k`03ohR^k`GoLik/1?mkWNL2ogZHi003oh^RhonU^nWo
YK_Y00GoYK_Y00?oa]SWomcPfOoLh=T00ooLh=T5omgEc`?of<O90oo?b=<6olRhb`03oj:`h_n`YLgo
/:G=00Co/:G=1_nP[^400on[V/GoXiS:oj>HbP04oj>HbPKoVI?<1On4QL`4ofihc0?oJ7[A0_m>L=@7
ogB@g`03ojk0ionkbnKo^l_V00Co^l_V0oo9h>T3olcSj0Ko`mk]00?o]Lo^oj_5k?n[aN`00on[aN`9
ojNoj`KoZ<7[1_nX`N`=ojNoj`03ojO0jonX`N_oZ<7[00GoZ<7[1onW`>/4ojNoj`04o`000?nW_n_o
Yko[ojNoj`?oYl3[2onX`>/6ojO0j`gooooo00?o0000ooooooooool01oooool001Cooooo00?o0000
ooooooooool03?ooool3o`0001cooooo2?nW`>/6ojNoj`ooZ<3[0onW`>/3ojNoj`OoYl3[1onX`>/7
ojO0j`OoY[o[1onX`>/00onV`>coX[k]oj:nk@03oj:nk@GoR:k_1OmcW^`6og^Mi`KoYK_Y0onkb>@3
omcPf@GogMG?1OoHalT00oo?b=?ob;S;olRhb`05olRhb`So/:G=0_nP[^45oj^Ja@KoXiS:1OnITl`6
ohB5c0CoKWS<1OmXN]43ogB@g`?oTJOT1_nkbnH5olWPj@03olcSj?o3g^go`mk]00Co`mk]00?o^MO_
oj_5k?n[aN`01On[aN`7ojNoj`SoZ<7[0onX`N`3ojO0j`WoYko[1OnW`>/7ojS1j`OoYl3[1?nW_n/0
0ol0003oYko[ojNoj`0=ojS0j`SoYl3[3?ooool00ol0003oooooooooo`07ooooo`004oooool3o`00
00[ooooo0ol0000Pooooo`SoYl3[1_nW_n/=ojS0j`03ojO0jonW_n_oYko[00GoYko[1OnW`>/9ojS0
j`GoYl3[0_nV_n`7ojJoj`OoZ<3[1_nR_^d5ohR^k`GoLik/1_mkWNL3ojFkj@Ko^lST00?og>3IomgE
cooMeLl00ooMeLl6omS7b@Oob;S;0_o4[<86ok2Uc@03okNO`?n[V/GoZi[500GoZi[51_nSV<X5oiVC
c0KoQ8G<1?m^N<`5ofQjd@OoTJOT0onkbnH6olWPj@;obnc[1?o3g^d4okWGk`OoZlG/1onW_n/6ojS1
j`03ojW2k?nW`>_oYl3[00GoYl3[1onW_n/7ojO0j`?oZ<7[0onX`>/8ojO0j`CoYko[00?o0000ojNo
jonW_n/02OnX`>/<ojO0j`_ooooo00?o0000ooooooooool01oooool001Cooooo00?o0000oooooooo
ool01_ooool3o`0002Gooooo1onW`>/3ojNoj`CoYl3[2?nX`>/5ojO0j`OoYko[00?oYl3[ojS0jonX
`>/02onX`>/00onW`>_oY[o/ojJok004ojJok0GoY[o[0_nW_n/7ojS0j`KoX[k]1On8[^l4og>Nk0Oo
NigW00?oYK_Yok_8i?nkb>@01?nkb>@3olc;f@?ogMG?1_oHalT2om:la0Gob;S;1?o4[<84ok2Uc@?o
]io01_n[V/D7oj>HbPGoVI?<1_n4QL`4ofihc0GoJ7[A1onAYn@00onkbnKobN3YolWPj@04olWPj@Co
bnc[00?o`mk]okWGkonienl01Onienl3oj_5k0?oYl3[2?nW_n/2ojS1j`GoZL;/1onW`>/7ojNoj`Go
Yl3[00?oZ<7[ojS0jonX`>/01OnX`>/6ojO0j`GoYko[00?o0000ojNojonW_n/01onX`>/;ojO0j`?o
Yko[2oooool00ol0003oooooooooo`07ooooo`005?ooool00ol0003oooooooooo`03ooooo`?o0000
:Oooool>ojO0j`OoZ<3[1_nW`>/8ojNoj`goZ<3[1onV_n`00onV_n_oYko[ojNoj`04ojNoj`OoZ<3[
0onR_^d3oiZkk`CoO:W`1?mWV^d01?mcW^coNigWog^MiomkWNL4ohj]j`Go^lST1Oo<bmT00ooMeLoo
f<O9omS7b@04omS7b@Cod[c40oo8^</5olB/`P?o/:G=1?ngWl07oj^Ja@GoXiS:00?oXHk0oiB7`_nD
Ql800onDQl86ohEoa@;oNgk;0_m^N<`6ofQjd@GoTJOT0onY`>X3olWPj@Gobnc[0oo1i?05okWGk`;o
[<K]1_nW`>/6ojNoj`03ojS0jonY`^coZL;/00KoZL;/0onW`>/;ojNoj`03ojO0jonX`N_oZ<7[00?o
Z<7[1onX`>/2ojO0j`WoYko[00?o0000ojNojonW_n/01onX`>/7ojO0j`OoYko[2oooool00ol0003o
ooooooooo`06ooooo`004oooool01?l0003oooooooooooooool3o`0002gooooo3_nW`>/7ojS0j`Ko
Yl3[2?nW_n/=ojS0j`SoY[o/1_nW_n/5ojS0j`;oYl3[1_nJ^nl4ogbYl0KoIi[]1_n>[N/3ok_8i0Ko
c<_I00?odLSAomS7bOoHalT00ooHalT6om:la003olRhboo4[<;oa:c200Goa:c200?o/:G=okNO`?ng
Wl001?ngWl06oj^Ja@;oXiS:1OnQS/05oiB7`PKoQGo51?mkO//6ofQjd@03oi6Wi?nY`>[oZL3Z00Go
ZL3Z00?obN3Yol_/joo;k>/00_o;k>/6ol7Tl003okWGkon/a^go[<K]00Co[<K]1_nW`>/2ojNoj`Go
Z<3[1_nY`^`00onX`>_oYko[ojNoj`0<ojNoj`OoZ<7[1OnX`>/2ojO0j`[oYko[00?oYl3[o`000?nW
`>/02?nX`>/7ojO0j`OoYko[2_ooool00ol0003oooooooooo`06ooooo`004oooool4o`00037ooooo
3?nW`>/9ojS0j`KoYl3[2?nW_n/=ojS0j`SoY[o/1_nW_n/00onX`>_oYl3[ojO0j`04ojO0j`KoV[__
1?mlZO06ofNJk@KoSZg[00?o^lSTolc;fOo<bmT01?o<bmT3om78d@?of<O91ooB_<@8olB/`POo]io0
1On[V/D00on/U;koXHk0oj6>`005oj6>`0GoU8O21_n5OlD4og]nb`OoR9WM1_nY`>X4ol3Rl003ol_/
joo1i?3o`NC`00Co`NC`00?o^=S`ojc6kOn/a^d01_n/a^d3ojO0j`?oYko[1onX`>/2ojW2k0GoZ<3[
3_nW_n/7ojS1j`03ojS0jonW`>_oYl3[00CoYl3[1onW_n/4ojO0j`03o`000?nW`>_oZ<3[00GoZ<3[
2OnW`>/3ojNoj`?oYl3[2_ooool00ol0003oooooooooo`06ooooo`004oooool2o`0003Cooooo2?nW
`>/=ojS0j`KoYl3[2?nW_n/=ojS0j`SoY[o/0onW_n/3ojS0j`OoYl3[0onJ^nl2oi:hl@CoKjKc00?o
O:W`ofNJkOmWV^d01?mWV^d3ohj]j`?oWkW[1Oo<bmT5om78d@03omS7bOoB_<Cod[c400God[c40_o>
]/86olB/`P;o`ZRo1_ngWl03oj^Ja@Co[9Bn1_nQS/06oiB7`PKoQGo51?mkO//7ohRIg@?oZL3Z1Oo0
h_02olGak`Co`NC`1?nhf?06ojc6k@03ojO0jonW_n_oYko[00GoYko[1OnX`>/2ojS2k0OoZ<3[3_nW
_n/6ojS1j`SoYl3[1onW_n/3ojO0j`03o`000?nW`>_oYl3[00;oZ<3[2onW`>/00onW_n_oYl3[ojO0
j`05ojO0j`Wooooo00?o0000ooooooooool01_ooool000Go00000oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Sooooo00?o0000ooooooooool0<_ooool3ojO0j`CoYko[3_nX`>/6ojO0j`SoYko[3OnX
`>/8ojJok0KoZ<3[1OnW`>/2ojJok0GoT[Sa1Om_Y_<5of:Ml0OoWkW[0oo<bmT6om78d@Ood[c41?o>
]/84olB/`P?o`ZRo1ongWl000on[V/Go[9BnojbD_P03ojbD_POoXHk01OnDQl86ohEoa@GoNgk;1on8
VMd00onY`>[o`>;`ol3Rl003ol3Rl0CoaO7_00?o`NC`okSHl?nhf?001Onhf?02ojc6k@GoYl3[1onW
_n/00onX`>_oZ<;/ojS2k004ojS2k0GoZ<3[3_nW_n/8ojS1j`KoYl3[2OnW_n/3ojO0j`03o`000?nX
`>_oZ<3[00WoYl3[1OnW_n/7ojO0j`Sooooo00?o0000ooooooooool01_ooool00005oiRHV?lQ8B7o
k^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Wooooo00?o0000ooooooooool0
<oooool6ojNoj`koZ<3[1onW`>/7ojNoj`goZ<3[2?nV_n`6ojS0j`03ojO0jonV_ncoY[o/00CoY[o/
1OnB^?45ofnVl`GoHYg`1onO^N/00oo<bmWodLSAom78d@04om78d@;oclG@1OoB_<@5oljf`P?oa:c2
1Oo2Z;l5okNO`003okNN_on/U;ko[9Bn00Co[9Bn1onQS/05oiB7`PKoQGo51OmkO//6ohRIg@;oY/;]
0oo0h_05olGak`?o^nGc1Onhf?02oj_5k@OoYl3[0onW_n/3ojO0j`SoZ<;/00?oZ<3[ojNojonW_n/0
3?nW_n/<ojS1j`;oYl3[2onW_n/00onW`>_oZ<3[ojS0j`02ojS0j`03o`000?nX`>_oZ<3[00KoYl3[
1onW_n/7ojO0j`Sooooo00?o0000ooooooooool01_ooool00004oooooonHV9So8B4Qonk^kPCooooo
00Go410@oooooooooooooooooa0@400:ooooo`03o`000?oooooooooo03?ooooo1_nW_n/?ojS0j`Ko
Yl3[1OnW_n/2ojO0j`_oZ<3[0onW`>/7ojJok0KoZ<3[1onV_n`5oi:hl@GoKjKc1OmRWO05oinij`;o
ZL7[1OoAb=44olo5d0?od[c41oo>]/800oo4[<;o`ZRool:X_`04ol:X_`Co]io00ongW[l6ojbD_PKo
XHk01_nDQl86ohEoa@GoNgk;0_n8VMd6ojK2k@03ol3Rl?o5lNooaO7_00;oaO7_1_nkiO<00onhf?3o
ZlG]oj_5k@04oj_5k@GoYl3[00?oYko[ojO0jonW`>/01OnW`>/6ojS2k003ojS0jonW_n_oYko[00co
Yko[2_nX`N/3ojO0j`[oYko[1OnW`>/4ojS0j`03o`000?nX`>_oZ<3[00KoYl3[1onW_n/7ojO0j`Oo
oooo00?o0000ooooooooool01_ooool000;ooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooo
oooooooooooo000000_ooooo0_l0000dooooo`?oYko[0onW`>/?ojS0j`KoYl3[00?oYko[ojO0jonW
`>/01?nW`>/7ojS0j`OoYl3[1onV_n`6ojS0j`OoY[o/1On=]o86ofFUm@;oGj;d0_mRWO000onO^N_o
ZL7[ojW1j`04ojW1j`?odLSA1_o?aM000ooB_<Coc[K2oljf`P06oljf`POo`ZRo0ongWl04okNN_`Ko
[9Bn1onQS/03oiB7`P;oUi3;1_n=T]<6oiFVh@KoY/;]1?nikOD00oo5lNoo^nGcok_Ul`04ok_Ul`03
ok;Al?n[aNgoZlG]00KoZlG]00?oYl3[ojNojonW_n/00onW_n/7ojO0j`;oZ<;/1OnX`>/>ojNoj`Oo
Z<7[1_nW`>/7ojNoj`SoYl3[0onX`>/00ol0003oYl3[ojO0j`07ojO0j`KoYko[2?nW`>/7ooooo`03
o`000?oooooooooo00Gooooo0003ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03o`000?oooooooooo03;ooooo1_nW`>/?ojS0j`?oYl3[0onV_n/7ojO0j`Oo
Z<3[1onW`>/7ojJok0KoZ<3[1onV_n`5ohfglPKoIJGe1?mOX_@7ojW1j`03om78dOo?aM3oclG@00Co
clG@00?ob/GFoljf`_o>]/801_o>]/82olfkb@Oo`ZRo00?o]io0okNN_ongW[l01?ngW[l5ojbD_PKo
XHk000?oXiO8oiN@bonGT</01?nGT</6ohfBd`KoUJKQ0onV`^d5okW]m@?o^o3c0_nkiO<5ok;Al0Ko
ZlG]2?nW_n/5ojO0j`;oZ<;/1onX`>/>ojNoj`OoZ<7[1_nW`>/7ojNoj`KoYl3[00?oZ<3[ojO0jonW
`>/00_nW`>/00ol0003oYl3[ojO0j`05ojO0j`SoYko[1onW`>/7ooooo`03o`000?oooooooooo00Go
oooo0004ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`0<ooooo`03
o`000?oooooooooo03;ooooo1_nW`>/=ojS0j`;oYl3[1_nV_n/5ojO0j`WoZ<3[1onW`>/7ojJok0Ko
Z<3[1onV_n`5ohfglPKoIJGe1?mOX_@5ojW1j`;oZLK^1Oo?aM03ol[5ePKoc[K20oo=^lT6ol:X_`03
olBbb?ngW[oo]ijo00Go]ijo1_n/U;h2oj6>`0GoXiO81OnGT</6ohfBd`OoUJKQ00?oY/;]okW]mOni
kOD00_nikOD4ok_`l`?o]=oe1_nbdO02oj_5k@coYko[00?oYl3[ojS2k?nX`^`01?nX`^`5ojS0j`ko
Yko[2OnX`N/3ojO0j`[oYko[0_nW`>/5ojS0j`CoYl3[00Co0000ojO0jonW`>_oYl3[3?nW_n/7ojO0
j`Kooooo00?o0000ooooooooool01Oooool00005o`000?nj^[[ooooooiRHV?l@41000oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00oooooo00?o0000ooooooooool0<_ooool7ojO0j`SoZ<3[1_nW`>/6
ojJoj`03ojO0jonX`>_oZ<3[00_oZ<3[1onW`>/7ojJok0KoZ<3[1onV_n`6ohfhl`GoHJOg0omEYOL0
0omOX_CoZL7[ojW6kP05ojW6kP?oclG@1Oo:aMH4oljf`PGocK_91?o2Z;l3olBbb0Ko]ijo1On/U;h0
0on_X/_oXiO8oj>Gb005oj>Gb0KoUi3;1On=T]<6oiFVh@?oZ=Sh00?o^Ngeok_`lonkl?<00_nkl?<6
okCOm@?o/]7`0onX`N/:ojNoj`CoZ<7/1onX`^`00onX`>_oYko[ojNoj`0<ojNoj`_oZ<7[00?oYl3[
ojNojonW_n/02_nW_n/00onW`>_oZ<3[ojS0j`06ojS0j`CoYl3[00?o0000ojO0jonW_n/02_nW_n/:
ojO0j`Gooooo00?o0000ooooooooool01Oooool00005oiRHV?l@413o0000ob4Q8Oo<c<`00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^013ooooo0_l0000dooooo`KoYl3[1onX`>/7ojO0j`KoY[o[3_nX
`>/7ojO0j`OoY[o/1_nX`>/7ojJok0OoSKSc1?mQYoL4oeFUm`OoZLK^00?oclG@ol[5e_o:aMH01?o:
aMH3oljf`PKocK_90oo2Z;l4olBbb0Oo]ijo00?o[9BnojnRbon_X//00on_X//7oj>Gb0GoUi3;1_n=
T]<2oiFVh@GoZ=Sh1?n]lo@00onkl??o]=oeokCOm@04okCOm@;oZlK]1_nX`N/7ojNoj`OoZ<7/0onX
`^`3ojO0j`koYko[2OnX`N/5ojO0j`SoYko[1OnW`>/6ojS0j`GoYl3[00?o0000ojO0jonW`>/01onW
_n/=ojO0j`Gooooo00?o0000ooooooooool01Oooool001oooooo00?o0000ooooooooool0<_ooool6
ojO0j`OoZ<3[1onW`>/6ojJoj`koZ<3[1onW`>/7ojJok0KoZ<3[1onV_n`3ohfhl`CoTKWb0omU[?P0
0omQYoOoEJGgoeFUm`02oeFUm`GoZLK^00?oW<Wgol[5e_o:aMH01_o:aMH00oo>]/;ocK_9olfkb@06
olfkb@03ol:X_oo4//Soa;;800Coa;;81OngW[l00onk]MCo[j;;ojnRb`04ojnRb`OoXiO81_nGT</3
ohfBd`GoXlKb00?oZ=Shojgcm?n]lo@01?n]lo@4ok3Vn003okCOmOn[a^goZlK]00CoZlK]1_nX`N/7
ojNoj`OoZ<7/1_nW`>/>ojNoj`OoZ<7[1onW`>/6ojNoj`OoYl3[0_nX`>/9ojO0j`03o`000?nW`>_o
Yl3[00OoYko[3OnW`>/4ooooo`03o`000?oooooooooo00Gooooo000Pooooo`03o`000?oooooooooo
03;ooooo1_nW`>/7ojS0j`OoYl3[1_nV_n/>ojS0j`OoYl3[1onV_n`6ojS0j`OoY[o/1onA^O85ofF/
n0;oAj?g00?oEJGgojW6k_nLbOL01?nLbOL6ol[5eP03okc:iOo=^lWocK_900KocK_900?o`/KMolBb
b?o4//P01Oo4//P4okNN_`?o^kGD1_n_X//7oj>Gb0?oUi3;0onS_N`6oj?6lPCoW^kg00?o[O?dok3V
n?n`i_P01?n`i_P00on^c_7oZlK]oj_6k@06oj_6k@?oZ<7[2_nW_n/7ojS1k0KoYl3[3_nW_n/7ojS1
j`GoYl3[2?nW_n/5ojO0j`;oZ<3[2_nW`>/00onW_n_o0000ojNoj`08ojNoj`goYl3[0oooool00ol0
003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`0booooo`KoYl3[2?nX`>/6ojO0j`?o
Y[o[1?nW_n/=ojS0j`OoYl3[1onV_n`6ojS0j`OoY[o/1onA^O85ofF/n0CoAj?g1OnLbOL3ol[5ePCo
_<[U1_o=^lT3ol;6g@Koa;;80ongW[l4ok^ee0Ko[j;;1_nSUlP00onW_^[oXkg/oj>mk005oj>mk0?o
XlKb1OnNk_L3ojSZnP;o/>Kh1On^c_46oj_6k@goYko[00?oZ<;/ojS1k?nX`N`01_nX`N`3ojO0j`go
Yko[0onX`N`8ojS1j`03ojO0jonW_n_oYko[00[oYko[00?oYl3[ojS0jonX`>/01?nX`>/6ojO0j`Co
Yko[00?o0000ojNojonW_n/01_nW_n/>ojO0j`Cooooo00?o0000ooooooooool01?ooool002;ooooo
00?o0000ooooooooool0<_ooool6ojO0j`SoZ<3[1onW`>/6ojNoj`goZ<3[1onW`>/7ojJok0KoZ<3[
1onV_n`3oi6ilPCoV[c`1_ma/_T2od:RmP03odNSmonLbOOoW<Wg00?oW<Wg00?ob/GFokc:iOnlb^D0
1?nlb^D3olfkb@Go`/KM1oo4//P00ongW[oo^kGDok^ee004ok^ee0Ko[j;;0_nSUlP5ojNnjPOoXkg/
00CoXlKboik^monNk_OoW^kg1OnXj_X2ojcDm@Oo[/ka0_n[a^d=ojNoj`GoZ<;/1_nX`N`=ojNoj`;o
Yl3[1_nX`N`6ojS1j`03ojO0jonW_n_oYko[00SoYko[0onW`>/8ojS0j`KoYl3[1?nW_n/00ol0003o
Yko[ojNoj`02ojNoja;oYl3[0oooool00ol0003oooooooooo`04ooooo`008oooool2o`0003?ooooo
0onW`>/;ojS0j`OoYl3[1_nW_n/=ojS0j`OoYl3[1OnV_n`2ojK0k0KoZ<3[1OnV_n`3ojO0j`KoV[c`
1_ma/_T4od:RmPGoNLGn1_nlb^D00oo=^lWo`/KMol;6g@04ol;6g@Koa;;800?o^LOUok^ee?nk]M@0
1Onk]M@5ojnRb`;oZlS_1_nW_^X6oj>mk0;oT^Wi1?nKjOX00onXj_[o[=CeojcDm@04ojcDm@Go[/ka
0_nX`>/:ojNoj`?oYl7/1onX`^`2ojS1k0goYko[1_nW`>/6ojS1k0;oZ<7[1OnW`>/7ojNoj`KoYl3[
1_nX`>/8ojO0j`CoYko[00?o0000ojNojonW`>/05?nW`>/2ooooo`03o`000?oooooooooo00Cooooo
000Uooooo`03o`000?oooooooooo03;ooooo3OnX`>/7ojO0j`?oYko[0onW`>/=ojS0j`OoYl3[00?o
Y[o/ojK0k?nV`>`01?nV`>`6ojS0j`03ojJok?nW`>_oYl3[00GoYl3[1_nJ_?03og6bn@?oPkOf0omB
[?X00om2X_KoNLGnogW5oP03ogW5oP?o_<[U0onMeo`7ol;6g@;oa;;81OnianD7ok^ee003ojnRbon[
b>ooZlS_00CoZlS_1_nW_^X2oj>mk0;oT^Wi1_nKjOX3ojOFn0Ko[=Ce00?o[/kaojS0jonX`>/01?nX
`>/5ojNoj`;oYl3[1_nW`N`5ojS2k0;oZ<3[3OnW_n/8ojO0j`?oZ<7/0_nX`>/8ojO0j`OoYko[1_nW
`>/2ojS0j`[oYl3[1_nW_n/00ol0003oYko[ojO0j`0BojO0j`04ojNojoooooooooooo`0000Kooooo
000Vooooo`03o`000?oooooooooo03;ooooo3OnX`>/=ojO0j`goZ<3[1onW`>/7ojK0k0KoZ<3[2?nW
`>/3oiZll0CoX[k]1On3]oH5oe:/nPGoA;7g1OnMeo`5ol;6g@;oX=_l1onianD5ok^ee0;oY]Si1on[
b>l3ojNnjPCoQnCh1?n<i?/00onKjO[oYmKhojOFn005ojOFn0?o[=Ce0onX`N`7ojS0j`03ojNojonW
`>_oYl3[00CoYl3[1_nW`N`00onX`^coZ<3[ojS0j`04ojS0j`goYko[1_nW`>/00onX`NcoZ<3[ojS0
j`04ojS0j`KoYl3[2OnW_n/3ojO0j`;oZ<3[2OnW`>/9ojNoj`03o`000?nW_n_oYko[00ooYl3[1OnW
_n/00ooooooo0000ooooo`05ooooo`009oooool00ol0003oooooooooo`0booooo`goZ<3[3OnW`>/=
ojS0j`OoYl3[1onV`>`6ojS0j`KoYl3[0_nX`>/7oj:nk@GoPkOf1OmB[?X5odBam`GoWMOl00?o`/KM
oj3Ko?nPfo`01?nPfo`7okW7i@03ok^ee?nVf?WoY]Si00CoY]Si1On[b>l4ogGNm@03ohOTn?n<i?_o
S>Ck00CoS>Ck0_nRe?T6ojOFn003ojS2k?nX`NcoZ<7/00GoZ<7/1OnX`>/00onW_n_oYl3[ojO0j`06
ojO0j`?oYl7/0onX`N`7ojS0j`goYko[0_nW`>/5ojS1k0KoZ<3[0_nW`>/;ojNoj`03ojO0jonX`>_o
Z<3[00CoZ<3[1onW`>/;ojNoj`03o`000?nW`>_oYl3[00koYl3[1_nW_n/00ol0003oooooooooo`04
ooooo`00:?ooool2o`0003?ooooo3OnX`>/:ojO0j`?oYl3/3_nX`>/6ojO0j`OoY/3/1_nX`>/2ojO0
j`KoZ<3[1OnR_^d2ojJoj`KoU[_a1_mc^?/5odB]m`GoD/7h1OnPfo`3okW7i@GoQmkm1_nVf?T00on[
b>ooMMkeogGNm@02ogGNm@GoPMgm0_n<i?/6oj;Dn@;oYmKh1OnX`^`7ojS1k003ojS0jonW_n_oYko[
00?oYko[1_nW`>/00onX`^coZ<7/ojS1k005ojS1k0GoZ<3[3?nW_n/3ojO1k0OoZ<7/0onX`>/<ojNo
j`GoYl3[1_nX`>/7ojO0j`OoYko[1?nW`>/00ol0003oYl3[ojO0j`0>ojO0j`?oYko[0_ooool00ol0
003oooooooooo`04ooooo`00:_ooool00ol0003oooooooooo`0aooooo`goZ<3[1onW`>/6ojO0k0ko
Z<3[1_nW`>/7ojK0k0?oZ<3[0onW`N`8ojS0j`03oj:nkOnV_n_oY[o[00CoY[o[1_nF^o43og>hn`Co
Sk_d1Om__Od6odVfn0GoCL?b0on7g_d5oeK9m0?oH=?`1Omne_l3oh7Mo@GoW]3i0onRe?T3ojO1k0Oo
Z<;/0onX`N`:ojNoj`;oYl3[1OnX`^`7ojS1k003ojS0jonW_n_oYko[00WoYko[00?oYl3[ojO1k?nW
`N`01OnW`N`5ojS1k003ojO0jonW_n_oYko[00_oYko[2?nW`>/3ojS0j`[oYl3[1onW_n/4ojO0j`03
o`000?nW`>_oYl3[00coYl3[1oooool00ol0003oooooooooo`03ooooo`00:oooool00ol0003ooooo
ooooo`0aooooo`goZ<3[1onW`>/6ojO0k0koZ<3[1_nW`>/5ojK0k0;oY[o/1_nW`N`8ojS0j`OoY[o[
0onF^o43oj>nk0OoSk_d1Om__Od3odVfn0CoNlCn1_mO`o`3oeK9m0GoQ=3o0omne_l4oig9mPGoW]3i
2?nW`N`5ojS2k0coYko[2_nX`^`3ojS1k0coYko[1OnW`>/7ojO1k003ojS1k?nW`>_oYl3[00?oYl3[
3OnW_n/6ojO0j`03ojS0jonW`>_oYl3[00[oYl3[2OnW_n/3ojO0j`03o`000?nW`>_oYl3[00WoYl3[
2_ooool00ol0003oooooooooo`03ooooo`00;?ooool00ol0003oooooooooo`0aooooo`goZ<3[1onW
`>/6ojO0k0koZ<3[1_nW`>/00onV`>coY[o/ojJok004ojJok0KoYl7/2?nX`>/5ojJoj`;oZ;o[1_nS
_^`5ohnkm0;oX[k]1_n@_OD6og_4oP?oGl?l1On>a_X3ohC@o`CoW/;a1_nMbOH00onNd?WoYl7/ojO1
k00:ojO1k003ojS2k?nW_n_oYko[00WoYko[0_nW`N`;ojS2k0ooYko[1onW`>/3ojO1k0?oZ<7[1onW
`>/=ojNoj`;oYl3[1OnX`>/8ojO0j`_oYko[1OnW`>/00ol0003oYl3[ojO0j`05ojO0j`gooooo00?o
0000ooooooooool00oooool002gooooo0_l0000booooo`goZ<3[1onW`>/6ojO0k0koZ<3[0onW`>/3
ojS0j`OoY[o/0onW`N`4ojK0k0OoZ<3[00?oY[o[ojRojonX_n/01?nX_n/6oj>nk003ohnkm?nR_^go
X[k]00CoX[k]1_n@_OD3og_4oPCoVKob1On>a_X2oj>ok@OoW/;a0onMbOH3ojK0k0[oYl7/2onW_n/6
ojO1k0OoZ<;/4onW_n/5ojO0j`;oZ<7/1_nX`N/5ojO0j`coYko[0onW`>/7ojS0j`OoYl3[2?nW_n/9
ojO0j`04o`000?nW`>_oYl3[ojO0ja3ooooo00?o0000ooooooooool00oooool002oooooo00?o0000
ooooooooool0<?ooool=ojS0j`OoYl3[1_nW`>`DojS0j`GoY[o/0_nV_n/7ojK0k0?oZ<3[0onX`N`8
ojRoj`?oXkk/0_nW_n/8oj:nk@?oT;ge0onT_^`7oiVolP03ohk6n_nS_ngoXko]00CoXko]1OnN`_40
0onW_n_oY/3/ojK0k005ojK0k0GoYl7/3OnW_n/9ojO1k0?oZ<;/0_nX`>/EojNoj`03ojO0jonX`Nco
Z<7/00CoZ<7/1_nX`N/00onW`>_oYko[ojNoj`09ojNoj`SoYl3[1OnX`>/9ojO0j`?oYko[3OnW`>/0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00?ooooo000`ooooo`03o`000?oooooooooo
037ooooo3OnX`>/6ojO0j`?oYl3/1?nV`>`CojS0j`03ojJok?nV_n_oY[o[00CoY[o[1onV`>`6ojS1
k0KoZ;o[00?oZ<7[ojNojonW_n/01?nW_n/6oj:nk@03ojNojonT_^coY;k/00GoY;k/0onI_o83ojJo
j`SoXko]00?oW/;aojNojonW_n/00onW_n/7ojK0k003ojO1k?nW_n_oYko[00_oYko[2onW`N`7ojS0
ja7oYko[0onW`N`8ojS1k0?oZ<7[2onW_n/<ojO0j`03ojS0jonW`>_oYl3[00WoYl3[00?oYko[ojO0
jonW`>/02_nW`>/5ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00oooool0037o
oooo00?o0000ooooooooool0<Oooool=ojS0j`OoYl3[1_nV`>`3ojS0j`CoYl3[3OnX`>/6ojJoj`Oo
Y/3/1_nX`N`2ojRoj`GoZ<7[1_nW_n/2oj:nk@GoYko[1OnT_^`2ojRoj`KoY[o[1_nS_nd00onX_n_o
Yko[ojNoj`05ojNoj`?oY/3/3OnW_n/<ojO1k0_oZ<3[3?nW_n/2ojO0j`KoYl7/1_nX`N`00onW`>_o
Yko[ojNoj`0;ojNojaKoYl3[1OnW_n/8ojO0j`Wooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`03ooooo`00<_ooool2o`0003;ooooo3OnX`>/7ojO0j`OoY/3/1_nW`>/=ojS0j`?oY[o[
0onW_n/7ojK0k0?oZ<7/0onV`N`7ojS1j`?oYko[1?nX`>/6ojNoj`03ojBnk?nX_n_oZ;o[00CoZ;o[
1_nV_n/2oj>ok@GoZ;o[1OnW_n/2ojO0j`_oYko[3onW`N`:ojS0j`_oYko[1_nW`>/6ojO1k0;oZ<7/
1OnW`>/=ojNoj`GoYl3[0_nX`>/:ojO0j`[oYko[0onW`>/>ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool00_ooool003Cooooo00?o0000ooooooooool0<?ooool>ojS0j`KoYl3[1onV
`>`6ojO0j`goZ<3[1_nW_n/5ojK0k0;oY[o[1_nV`N`5ojS1j`;oYl7/1onX`>/3ojNoj`?oZ<3[1onX
_n/3ojJoj`CoYko[1_nX_n/00onW_n_oYl3[ojO0j`04ojO0j`OoYko[4onW`N`5ojS0j`coYko[2_nW
`>/3ojO1k0CoZ<3[1_nW`>/=ojNoj`03ojO0jonX`>_oZ<3[00CoZ<3[1_nW`>/<ojNoja;ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`00=Oooool00ol0003oooooooooo`0`
ooooo`koZ<3[1_nW`>/7ojK0k0KoYl3[3OnX`>/6ojNoj`03ojK0k?nV_n_oY[o[00CoY[o[1_nV`N`0
0onX`N_oYl7/ojO1k004ojO1k0GoZ<3[0_nW`N`6ojS0j`GoZ;o[0_nX`N`7ojNoj`?oZ;o[0onX`N`7
ojO0j`?oYko[1?nW`^`CojO1k003ojS0jonW_n_oYko[00[oYko[3?nW`>/00onX`NcoZ<3[ojS0j`06
ojS0j`?oYl3[3OnW_n/2ojO0j`SoZ<3[1_nW`>/8ojNojaKooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`02ooooo`00=_ooool00ol0003oooooooooo`0`ooooo`koZ<3[1_nW`>/5ojK0
k0SoYl3[3OnX`>/3ojNoj`?oZ<3[1onV_n/3ojK1k0CoY[o/1_nW`N`00onX`>_oYl7/ojO1k004ojO1
k0KoZ<3[00?oZ;o[ojS1k?nX`N`01?nX`N`5ojNoj`;oYl7/1_nX`N`5ojO0j`;oYl7]1onW`^`3ojO1
k0?oYl3/2_nW`N`@ojNoj`SoYl3[1OnX`N`6ojS0j`goYko[1onW`>/6ojS0j`SoYl3[0onW_n/Koooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool00_ooool003Oooooo0_l0000aooooo`ko
Z<3[1_nW`>/00onV`>coYl3[ojO0j`0:ojO0ja?oZ<3[1OnV_n/2ojRoj`OoY[o/0onW`N`3ojK0k0Oo
Yl7/0onX`>/4ojO1k0KoZ<7/00?oYko[ojO1k?nW`N`01?nW`N`6ojS1k003ojO0jonW`NgoYl7]00Co
Yl7]1OnW`^`00onW`>_oYl3/ojO0k005ojO0k0GoYl7/5OnW_n/3ojO0j`?oYl7/1onX`N`2ojS0j`go
Yko[2onW`>/2ojS0j`[oYl3[8?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;o
oooo000iooooo`03o`000?oooooooooo02oooooo1OnX`>/2ojO0j`OoZ<3[0onW`>/3ojS0j`[oYl3[
1?nW`>`BojS0j`03ojJojonX_n_oZ;o[00CoZ;o[1OnV_n`2ojNoj`KoY/3/1OnW`N`2ojK0k0OoYl7/
0onX`N`3ojK1k0OoYl7/0onX`N`4ojO1k0KoYl7]00?oYl;/ojO0jonW`>/00onW`>/7ojO0k003ojO1
k?nW_n_oYko[01GoYko[2?nW`N`5ojS1k0;oYl3[3OnW_n/EojO0jb?ooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`02ooooo`00>_ooool00ol0003oooooooooo`0_ooooo`03ojS0jonW
`>_oYl3[00CoYl3[3OnX`>/7ojO0j`OoYl3/0onX`>/3ojO0j`goZ<3[1_nX_n/00onV_ncoYko[ojNo
j`04ojNoj`KoY/3/00?oYl7/ojK0k?nV`>`01?nV`>`5ojO1k0;oY[o[1_nV`N`5ojO1k003ojO0k?nW
`NcoYl7/00KoYl7/0onW`Nd2ojNoj`OoYl3[0onW`>`HojNoj`coYl7/00?oZ<7/ojO0jonW`>/01?nW
`>/=ojNoja3oYl3[:?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00;ooooo000k
ooooo`03o`000?oooooooooo033ooooo1_nW`>/=ojS0j`OoYl3[1onW`>`6ojO0j`goZ<3[0onX_n/3
ojS0j`OoYko[0onV`>`4ojNoj`KoY/3/00?oYl7/ojJojonV_n/01?nV_n/6ojK1k003ojO1k?nW`>co
Yl3/00?oYl3/1_nW`N`7ojNoj`GoYl3[6OnW_n/=ojO1k0[oYl3[3OnW_n/;ojO0jbgooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`01ooooo`00??ooool00ol0003oooooooooo`0`oooo
o`KoYl3[3_nX`>/6ojO0j`OoYl3/1_nW`>/CojS0j`GoYko[0_nX_n/7ojNoj`?oY/3/0onW_n/7ojJo
j`?oY/7/0onW_n/6ojO0k0;oYl7/2onW_n/00onW`>_oYko[ojNoj`0FojNoj`goYl7/2onW`>/=ojNo
j`_oYl3[<Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo007ooooo000mooooo`;o
0000<Oooool6ojO0j`koZ<3[1_nW`>/7ojO0k0?oYl3[0onW`>`CojS0j`03ojNojonX_n_oZ;o[00Co
Z;o[1OnW_n/2ojRoj`KoYko[1OnV_n/00onX_n_oYko[ojNoj`05ojNoj`?oYl3/0onX_n/:ojNoj`Co
Z;o[5?nW_n/=ojO1k0[oYl3[3OnW_n/<ojO0jcCooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`01ooooo`00?oooool00ol0003oooooooooo`0_ooooo`KoYl3[3_nX`>/6ojO0j`GoYl3/
0_nW`>/6ojO0k0?oZ<3[0onW`>`>ojS0j`KoZ;o[00?oYko[ojRojonX_n/01?nX_n/6ojNoj`03ojJo
jonX_n_oZ;o[00?oZ;o[1OnW_n/8ojRoj`GoYko[2OnX_n/@ojNoj`coYl7/2onW`>/=ojNoj`_oYl3[
>Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo007ooooo0010ooooo`03o`000?oo
oooooooo02oooooo1onW`>/=ojS0j`KoYl3[00?oYl3/ojO0jonW`>/01?nW`>/<ojO0k0GoZ<3[0_nW
`>/7ojS0j`?oZ;o[0onX`>/7ojRoj`?oYko[2OnX_n/00onW_n_oZ;o[ojRoj`0:ojRoj`03ojNojonX
_n_oZ;o[00WoZ;o[00?oYl3[ojNojonW_n/02_nW_n/;ojO1k0goYl3[3OnW_n/;ojO0jcgooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`01ooooo`00@Oooool00ol0003oooooooooo`0_
ooooo`OoYl3[3OnX`>/3ojO0j`CoZ<3[1_nW`>/<ojO0k003ojS0jonW`>_oYl3[00CoYl3[1OnX`>/2
ojS1j`KoZ<3[1OnX_n/00onX`>_oZ;o[ojRoj`0PojRoj`GoYl3[2?nW_n/:ojO1k0goYl3[3OnW_n/;
ojO0jd7ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`01ooooo`00@_ooool2o`00
033ooooo1onW`>/DojS0j`KoYl3[3OnW`>`6ojO0j`03ojS0jonX`N_oZ<7[00CoZ<7[1_nX`>/00onX
_n_oZ<3[ojS0j`03ojS0j`GoZ;o[0_nX`>/;ojRoj`;oZ<3[2_nX_n/9ojO0j`?oYko[2onW`N`=ojO0
j`goYko[2_nW`>]6ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00Oooool004Co
oooo00?o0000ooooooooool0;_ooool7ojO0jaCoZ<3[1_nW`>/4ojO0k0;oYl3[1onW`>`3ojO0j`?o
Yl3/1onX`N/3ojS0j`CoZ<7[1OnX`>/00onX_n_oZ<3[ojS0j`04ojS0j`OoZ;o[1_nX`>/5ojRoj`03
ojO1k?nW`>_oYl3[00WoYl3[3?nW`N`=ojO0ja3oYko[1onW`>]:ooooo`03o`000?oooooooooo00Oo
oooo0Ol00001ooooo`7ooooo0015ooooo`03o`000?oooooooooo02oooooo1_nW`>/3ojS0j`CoYl3[
3OnX`>/6ojO0j`03ojO0k?nW`>_oYl3[00?oYl3[1OnW`>`2ojNoj`KoYl3/1OnX`N/2ojO0k0OoZ<7[
0_nX`>/3ojO1k0OoZ<3[0onX_n/4ojO1j`KoZ<3[00?oZ;o[ojO1k?nW`N`00onW`N`7ojO0j`_oYl7/
3OnW`>/EojNoj`?oYl3[C_ooool00ol0003oooooooooo`06ooooo`7o00000Oooool1ooooo`00A_oo
ool00ol0003oooooooooo`0`ooooo`coYl3[3OnX`>/3ojO0j`?oZ<3[1_nW`>/00onW`>coYko[ojNo
j`04ojNoj`KoYl3/00?oZ<7[ojO0k?nW`>`01?nW`>`5ojS1j`03ojO0k?nW`NcoYl7/00CoYl7/1OnX
`>/2ojO1k0OoYl7[0onX`>/9ojO1k0?oYl3[2onW`N`=ojO0jaOoYko[D_ooool00ol0003ooooooooo
o`06ooooo`7o00000Oooool1ooooo`00Aoooool2o`00037ooooo3?nW`>/CojS0j`OoYl3[1_nW_n/3
ojO0k0CoYl3[1_nW`>`00onX`N_oYl3/ojO0k003ojO0k0KoYl7/00?oZ<3[ojO1k?nW`N`01?nW`N`5
ojO1j`03ojO0k?nW`NcoYl7/00WoYl7/0_nW`>`:ojO1k0goYl3[5onW_n]Fooooo`03o`000?oooooo
oooo00Gooooo0Ol00001ooooo`7ooooo0019ooooo`03o`000?oooooooooo02oooooo3?nW`>/5ojS0
j`;oYl3[3?nX`>/7ojO0j`?oYko[2_nW`>/3ojO0k0?oYl3[1_nW`>`3ojO1k0CoYl3/1_nW`N`00onW
`N_oYl3/ojO0k003ojO0k0OoYl7/1_nW`>`5ojO1k0goYl3[6?nW_n]Jooooo`03o`000?oooooooooo
00Cooooo0Ol00001ooooo`7ooooo001:ooooo`03o`000?oooooooooo02oooooo3?nW`>/00onX`>_o
Yl3[ojO0j`04ojO0j`coZ<3[1OnW`>/2ojS0j`_oYl3[00?oYko[ojO0jonW`>/01OnW`>/3ojO0k0?o
Yko[1onW`>`3ojO1k0?oYl3[1_nW`>`3ojO1k0CoYl3[1_nW`>`00onW`NcoYl3[ojO0j`0;ojO0jaOo
Yko[Goooool00ol0003oooooooooo`03ooooo`7o00000Oooool1ooooo`00Boooool00ol0003ooooo
ooooo`0_oooooa?oYl3[3?nX`>/00onW`>_oZ<3[ojS0j`04ojS0j`OoYl3[1OnW_n/5ojO0j`SoYko[
1OnW`>`2ojNoj`KoYl3[0onW`>`3ojNoj`OoYl3[0onW`>`4ojNoj`WoYl3[5onW_n]Rooooo`03o`00
0?oooooooooo00?ooooo0Ol00001ooooo`7ooooo001<ooooo`;o0000<?oooolCojO0ja?oZ<3[0onW
`>/4ojS0j`GoYko[00?oYl3[ojNojonW_n/02_nW_n/00onW`>coYko[ojNoj`04ojNoj`CoYl3[2?nW
_n/5ojO0j`WoYko[0onW`>/IojNojfKooooo00?o0000ooooooooool00oooool1o`00007ooooo001>
ooooo`03o`000?oooooooooo02kooooo4onW`>/5ojS0j`03ojO0jonX`>_oZ<3[01;oZ<3[0_nW_n/4
ojRoja?oYko[00?oYl3[ojNojonW_n/02OnW_n/00onW`>_oYko[ojNoj`0EojNoj`;oYl3[2_nW_n]/
ooooo`03o`000?oooooooooo00;ooooo0Ol00001ooooo`00Coooool00ol0003oooooooooo`0_oooo
oa;oYl3[00?oZ<3[ojO0jonW`>/00onW`>/5ojS0j`;oYl3[3?nX`>/7ojRoj`?oYko[0onX_n/:ojNo
j`?oZ;o[8?nW_n/6ojO0j`GoYko[LOooool01Ol0003ooooooooooooooooo0000007ooooo001@oooo
o`03o`000?oooooooooo02oooooo6?nW`>/00onX`>_oYl3[ojO0j`04ojO0j`coZ<3[1OnX_n/2ojS0
j`KoZ;o[1OnW_n/00onX`>_oZ;o[ojRoj`05ojRoj`?oYko[0onX_n/:ojNoj`?oZ<3[2OnW_n/:ojO0
j`03ojNojooooooooooo07;ooooo00Go0000ooooooooooooooooo`000001ooooo`00DOooool2o`00
033ooooo7onW`>/3ojS0j`CoYl3[1OnX`>/00onX_n_oZ<3[ojS0j`04ojS0j`KoZ;o[00?oYko[ojS0
jonX`>/00onX`>/5ojRoj`;oZ<3[1_nX_n/5ojNoj`03ojO0jonX`>_oZ<3[00GoZ<3[0onW_n/=ojO0
jgSooooo00Co0000oooooooooooo00000Oooool005?ooooo00?o0000ooooooooool0;_ooool4ojO0
j`;oZ<3[8?nW`>/2ojS0j`CoYl3[1_nX`>/3ojRoj`WoZ<3[00?oZ;o[ojS0jonX`>/01?nX`>/6ojRo
j`03ojNojonW`>_oYl3[00?oYl3[1OnX`>/=ojO0jggooooo00?o0000ooooool000000Oooool005Co
oooo00?o0000ooooooooool0;_ooool00onW`>_oZ<3[ojS0j`03ojS0jbKoYl3[0onX`>/3ojO0k0Wo
Z<3[1?nW`>/6ojS0j`?oZ;o[2OnW`>/00onX`>_oYl3[ojO0j`0;ojO0jh3ooooo00?o0000ooooool0
00000Oooool005Gooooo00?o0000ooooooooool0;_ooool6ojS0jbKoYl3[1_nW`>`4ojS0j`;oYl3/
1onW`>/3ojS0j`;oYl3/2_nW`>/4ojO0k0WoYl3[Q?ooool1o`00007ooooo0Ol0000005Kooooo0_l0
000_ooooo`KoZ<3[9_nW`>/6ojO0k003ojS0jonW`>coYl3/00?oYl3/1onW`>/5ojO0k0OoYl3[1onW
`>`3ojO0jh[ooooo0_l0000005Sooooo00?o0000ooooooooool0;Oooool6ojS0j`GoYl3[0_nX`>/O
ojO0j`?oYl3/0onW`>/6ojO0k0OoYl3[1OnW`>`7ojO0j`GoYl3/SOooool3o`000000FOooool00ol0
003oooooooooo`0]ooooo`KoZ<3[00?oYl3[ojS0jonX`>/01?nX`>/4ojO0j`;oZ<3[7onW`>/3ojO0
k0[oYl3[0_nW`>`:ojO0j`03ojO0k?oooooooooo08[ooooo1?l00003ooooo`00F_ooool00ol0003o
ooooooooo`0]ooooo`?oZ<3[1?nW`>/6ojS0j`03ojO0jonX`>_oZ<3[00?oZ<3[=OnW`>^<ooooo`?o
00001oooool005_ooooo00?o0000ooooooooool0;Oooool7ojO0j`coZ<3[0onW`>/4ojS0jbSoYl3[
SOooool4o`0000[ooooo001Looooo`;o0000;_ooool7ojO0ja?oZ<3[0_nW`>/4ojS0j`WoYl3[0onW
_n/AojO0jhgooooo1?l0000>ooooo`00G_ooool00ol0003oooooooooo`0/ooooo`OoYl3[1?nX`>/2
ojO0ja?oZ<3[0onW`>/3ojS0j`KoYko[0onW`>/4ojNoj`KoYl3[S?ooool4o`0001;ooooo001Ooooo
o`03o`000?oooooooooo02gooooo1_nW`>/00onX`>_oYl3[ojO0j`03ojO0j`GoZ<3[0_nW`>/BojS0
j`?oYko[0onX`>/7ojNoj`;oYl3[Roooool4o`0001Kooooo001Pooooo`03o`000?oooooooooo02go
oooo3?nW`>/00onX`>_oYl3[ojO0j`04ojO0ja3oZ<3[0_nW`>/6ojS0j`GoYko[Roooool3o`0001[o
oooo001Qooooo`;o0000;ooooolBojO0j`;oZ<3[1?nW`>/7ojS0j`GoYl3[1_nX`>/00onW_n_ooooo
ooooo`28ooooo`Co00007Oooool006?ooooo00?o0000ooooooooool0;OoooolHojO0j`?oZ<3[2OnW
`>/3ojS0jhWooooo1?l0000Qooooo`00I?ooool00ol0003oooooooooo`0]ooooob7oYl3[R_ooool4
o`0002Gooooo001Uooooo`03o`000?oooooooooo02gooooo6onW`>^;ooooo`Co0000:Oooool006Ko
oooo0_l0000^oooooaOoYl3[Roooool3o`0002gooooo001Xooooo`03o`000?oooooooooo02cooooo
4onW`>^:ooooo`Co0000<?ooool006Wooooo00?o0000ooooooooool0;?ooool3ojO0j`CoZ<3[2?nW
`>^9ooooo`Co0000=?ooool006[ooooo00?o0000ooooooooool0;?ooool7ojS0j`;oYl3[R_ooool4
o`0003Sooooo001[ooooo`;o0000;Oooool5ojS0jhWooooo1?l0000looooo`00KOooool00ol0003o
ooooooooo`0[ooooo`03ojS0jooooooooooo08Oooooo0ol00010ooooo`00K_ooool00ol0003ooooo
ooooo`0Zooooo`03o`000?oooooooooo08?ooooo1?l00013ooooo`00Koooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo07oooooo1?l00017ooooo`00L?ooool2o`0002Wooooo00?o0000
ooooooooool0Noooool4o`0004_ooooo001booooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool0Moooool4o`0004oooooo001cooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool0M?ooool3o`0005?ooooo001dooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
L?ooool4o`0005Kooooo001eooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0K?oo
ool4o`0005[ooooo001fooooo`;o00008oooool00ol0003oooooooooo`1Xooooo`Co0000G_ooool0
07Sooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1Tooooo`Co0000H_ooool007Wo
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`1Qooooo`?o0000I_ooool007[ooooo
00?o0000ooooooooool07_ooool00ol0003oooooooooo`1Mooooo`Co0000JOooool007_ooooo0_l0
000Nooooo`03o`000?oooooooooo05Wooooo1?l0001]ooooo`00OOooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo05Gooooo1?l0001aooooo`00O_ooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo057ooooo1?l0001eooooo`00Ooooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo04kooooo0ol0001iooooo`00P?ooool2o`0001Wooooo00?o0000ooooooooool0
B_ooool4o`0007cooooo0022ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0A_oo
ool4o`00083ooooo0023ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0@_ooool4
o`0008Cooooo0024ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0?_ooool4o`00
08Sooooo0025ooooo`;o00004oooool00ol0003oooooooooo`0looooo`?o0000S?ooool008Oooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0hooooo`Co0000Soooool008Sooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0dooooo`Co0000Toooool008Wooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0`ooooo`Co0000Uoooool008[ooooo0_l0000>oooo
o`03o`000?oooooooooo02cooooo1?l0002Kooooo`00S?ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo02Wooooo0ol0002Oooooo`00SOooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo02Gooooo1?l0002Rooooo`00S_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo027ooooo1?l0002Vooooo`00Soooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo01gooooo1?l0002Zooooo`00T?ooool2o`0000Sooooo00?o0000ooooooooool06Oooool4o`00
0:kooooo002Booooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05_ooool3o`000;;o
oooo002Cooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04_ooool4o`000;Gooooo
002Dooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03_ooool4o`000;Wooooo002E
ooooo`;o00000oooool00ol0003oooooooooo`0:ooooo`Co0000_Oooool009Oooooo00Co0000oooo
oooooooo00002?ooool4o`000<7ooooo002Hooooo`03o`000?oooooo000000Gooooo0ol00035oooo
o`00VOooool2o`000003ooooool0003o000000;o0000b?ooool009[ooooo0_l0003<ooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0538698, 0.0432538, \
0.0035044, 0.0035044}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[.12586 .2075 -12 -8.99448 ]
[.12586 .2075 0 .00552 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.56094 .0364 -5.16972 -9 ]
[.56094 .0364 .83028 0 ]
[.75679 .08071 0 -6.17777 ]
[.75679 .08071 12 2.82223 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.9429 .3657 0 -5.9083 ]
[.9429 .3657 6 3.0917 ]
[.02494 .25992 -18 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.01611 .31527 -18 -2.78472 ]
[.01611 .31527 0 6.21528 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00254 .43215 -12 -2.88407 ]
[-0.00254 .43215 0 6.11593 ]
[-0.0124 .49393 -12 -2.93688 ]
[-0.0124 .49393 0 6.06312 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
[(-2)] .12586 .2075 1 .99877 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.56863 .04703 m
.57247 .05235 L
s
[(2)] .56094 .0364 .72324 1 Mshowa
.125 Mabswid
.18558 .19702 m
.18832 .19985 L
s
.23703 .17687 m
.23971 .17975 L
s
.28951 .15632 m
.29214 .15925 L
s
.39772 .11395 m
.40023 .11699 L
s
.4535 .09211 m
.45595 .0952 L
s
.51046 .06981 m
.51284 .07294 L
s
.08568 .23614 m
.08851 .23887 L
s
.62804 .02377 m
.63027 .02701 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.7445 .0853 m
.73835 .08759 L
s
[(-2)] .75679 .08071 -1 .37284 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.93037 .36962 m
.92411 .37158 L
s
[(2)] .9429 .3657 -1 .31296 Mshowa
.125 Mabswid
.7708 .12553 m
.7671 .12688 L
s
.79613 .16428 m
.79242 .1656 L
s
.82054 .20161 m
.81682 .20291 L
s
.86679 .27235 m
.86305 .2736 L
s
.88871 .30589 m
.88497 .30711 L
s
.9099 .3383 m
.90615 .3395 L
s
.71716 .04348 m
.71349 .04489 L
s
.95018 .39992 m
.94642 .40107 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(-20)] .02494 .25992 1 -0.39157 Mshowa
.02837 .31059 m
.0345 .30825 L
s
[(-10)] .01611 .31527 1 -0.38117 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.00981 .42772 m
.01599 .4255 L
s
[(10)] -0.00254 .43215 1 -0.3591 Mshowa
0 .48963 m
.0062 .48748 L
s
[(20)] -0.0124 .49393 1 -0.34736 Mshowa
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.658 .75 .918 r
.39362 .69479 .40169 .7019 .4152 .69802 .40717 .69087 Mtetra
.655 .749 .919 r
.40717 .69087 .4152 .69802 .42878 .69413 .42079 .68705 Mtetra
.653 .752 .922 r
.42079 .68705 .42878 .69413 .44243 .69031 .43448 .68326 Mtetra
.654 .754 .923 r
.43448 .68326 .44243 .69031 .45614 .68653 .44824 .67939 Mtetra
.656 .753 .921 r
.44824 .67939 .45614 .68653 .46992 .68269 .46207 .67546 Mtetra
.658 .752 .919 r
.46207 .67546 .46992 .68269 .48378 .67879 .47597 .67143 Mtetra
.659 .75 .917 r
.47597 .67143 .48378 .67879 .4977 .67481 .48994 .66737 Mtetra
.656 .748 .917 r
.48994 .66737 .4977 .67481 .5117 .67078 .50398 .66339 Mtetra
.654 .75 .92 r
.50398 .66339 .5117 .67078 .52577 .66674 .5181 .65946 Mtetra
.653 .753 .923 r
.5181 .65946 .52577 .66674 .53991 .66279 .53229 .65551 Mtetra
.654 .755 .924 r
.53229 .65551 .53991 .66279 .55412 .65884 .54655 .65152 Mtetra
.655 .755 .923 r
.54655 .65152 .55412 .65884 .56841 .65487 .56088 .64748 Mtetra
.655 .754 .922 r
.56088 .64748 .56841 .65487 .58277 .65087 .5753 .6434 Mtetra
.657 .753 .921 r
.5753 .6434 .58277 .65087 .59721 .64683 .58978 .63924 Mtetra
.658 .751 .919 r
.58978 .63924 .59721 .64683 .61172 .64276 .60434 .63505 Mtetra
.658 .749 .918 r
.60434 .63505 .61172 .64276 .62631 .63865 .61898 .63084 Mtetra
.657 .748 .917 r
.61898 .63084 .62631 .63865 .64097 .63452 .63369 .62663 Mtetra
.657 .746 .916 r
.63369 .62663 .64097 .63452 .65571 .63036 .64848 .62241 Mtetra
.64848 .62241 .65571 .63036 .67053 .62619 .66335 .61817 Mtetra
.656 .745 .915 r
.66335 .61817 .67053 .62619 .68543 .62199 .6783 .61393 Mtetra
.656 .745 .916 r
.6783 .61393 .68543 .62199 .7004 .61777 .69333 .60968 Mtetra
.69333 .60968 .7004 .61777 .71546 .61352 .70844 .60542 Mtetra
.655 .746 .916 r
.70844 .60542 .71546 .61352 .73059 .60926 .72363 .60115 Mtetra
.655 .747 .917 r
.72363 .60115 .73059 .60926 .74581 .60496 .73891 .59688 Mtetra
.654 .748 .919 r
.73891 .59688 .74581 .60496 .7611 .60063 .75427 .59259 Mtetra
.655 .75 .92 r
.75427 .59259 .7611 .60063 .77648 .59626 .76971 .58825 Mtetra
.656 .753 .921 r
.76971 .58825 .77648 .59626 .79193 .59185 .78523 .58385 Mtetra
.656 .754 .922 r
.78523 .58385 .79193 .59185 .80747 .58741 .80083 .57939 Mtetra
.657 .755 .922 r
.80083 .57939 .80747 .58741 .8231 .58294 .81651 .57488 Mtetra
.657 .756 .922 r
.81651 .57488 .8231 .58294 .83881 .57848 .83228 .57033 Mtetra
.657 .754 .922 r
.83228 .57033 .83881 .57848 .85461 .57409 .84813 .56576 Mtetra
.656 .75 .919 r
.84813 .56576 .85461 .57409 .8705 .56971 .86408 .56123 Mtetra
.654 .747 .918 r
.86408 .56123 .8705 .56971 .88648 .56526 .88012 .55678 Mtetra
.654 .748 .919 r
.88012 .55678 .88648 .56526 .90254 .56073 .89626 .5523 Mtetra
.656 .751 .92 r
.89626 .5523 .90254 .56073 .91868 .55612 .91247 .54771 Mtetra
.657 .753 .921 r
.91247 .54771 .91868 .55612 .93491 .55146 .92877 .54305 Mtetra
.658 .755 .922 r
.92877 .54305 .93491 .55146 .95123 .54682 .94515 .5383 Mtetra
.657 .753 .921 r
.94515 .5383 .95123 .54682 .96765 .54226 .96162 .53358 Mtetra
.654 .749 .919 r
.96162 .53358 .96765 .54226 .98417 .53768 .97821 .52895 Mtetra
.655 .749 .919 r
.38547 .6876 .39362 .69479 .40717 .69087 .39906 .68377 Mtetra
.653 .752 .922 r
.39906 .68377 .40717 .69087 .42079 .68705 .41273 .67996 Mtetra
.655 .754 .923 r
.41273 .67996 .42079 .68705 .43448 .68326 .42646 .67608 Mtetra
.656 .753 .921 r
.42646 .67608 .43448 .68326 .44824 .67939 .44026 .67212 Mtetra
.659 .752 .919 r
.44026 .67212 .44824 .67939 .46207 .67546 .45414 .66805 Mtetra
.659 .749 .917 r
.45414 .66805 .46207 .67546 .47597 .67143 .46809 .66398 Mtetra
.654 .748 .919 r
.46809 .66398 .47597 .67143 .48994 .66737 .4821 .66004 Mtetra
.653 .752 .922 r
.4821 .66004 .48994 .66737 .50398 .66339 .49619 .65611 Mtetra
.653 .754 .924 r
.49619 .65611 .50398 .66339 .5181 .65946 .51035 .65214 Mtetra
.654 .754 .923 r
.51035 .65214 .5181 .65946 .53229 .65551 .52459 .64811 Mtetra
.656 .754 .922 r
.52459 .64811 .53229 .65551 .54655 .65152 .5389 .64402 Mtetra
.658 .753 .92 r
.5389 .64402 .54655 .65152 .56088 .64748 .55328 .63981 Mtetra
.659 .75 .917 r
.55328 .63981 .56088 .64748 .5753 .6434 .56774 .63559 Mtetra
.658 .747 .915 r
.56774 .63559 .5753 .6434 .58978 .63924 .58228 .63137 Mtetra
.657 .746 .915 r
.58228 .63137 .58978 .63924 .60434 .63505 .59689 .62718 Mtetra
.656 .746 .917 r
.59689 .62718 .60434 .63505 .61898 .63084 .61158 .623 Mtetra
.656 .748 .918 r
.61158 .623 .61898 .63084 .63369 .62663 .62635 .6188 Mtetra
.655 .75 .919 r
.62635 .6188 .63369 .62663 .64848 .62241 .64119 .61458 Mtetra
.656 .751 .92 r
.64119 .61458 .64848 .62241 .66335 .61817 .65612 .61033 Mtetra
.65612 .61033 .66335 .61817 .6783 .61393 .67112 .60605 Mtetra
.656 .752 .92 r
.67112 .60605 .6783 .61393 .69333 .60968 .6862 .60173 Mtetra
.656 .751 .92 r
.6862 .60173 .69333 .60968 .70844 .60542 .70137 .59739 Mtetra
.656 .75 .919 r
.70137 .59739 .70844 .60542 .72363 .60115 .71661 .59302 Mtetra
.656 .748 .918 r
.71661 .59302 .72363 .60115 .73891 .59688 .73194 .58863 Mtetra
.656 .746 .917 r
.73194 .58863 .73891 .59688 .75427 .59259 .74735 .58425 Mtetra
.654 .745 .916 r
.74735 .58425 .75427 .59259 .76971 .58825 .76285 .5799 Mtetra
.654 .745 .917 r
.76285 .5799 .76971 .58825 .78523 .58385 .77843 .57555 Mtetra
.653 .748 .919 r
.77843 .57555 .78523 .58385 .80083 .57939 .79411 .57118 Mtetra
.655 .752 .921 r
.79411 .57118 .80083 .57939 .81651 .57488 .80986 .56669 Mtetra
.657 .754 .922 r
.80986 .56669 .81651 .57488 .83228 .57033 .82569 .56213 Mtetra
.657 .755 .922 r
.82569 .56213 .83228 .57033 .84813 .56576 .84161 .55751 Mtetra
.658 .756 .922 r
.84161 .55751 .84813 .56576 .86408 .56123 .85761 .55285 Mtetra
.657 .753 .92 r
.85761 .55285 .86408 .56123 .88012 .55678 .8737 .5482 Mtetra
.654 .747 .919 r
.8737 .5482 .88012 .55678 .89626 .5523 .88989 .54367 Mtetra
.653 .747 .919 r
.88989 .54367 .89626 .5523 .91247 .54771 .90618 .53913 Mtetra
.655 .751 .92 r
.90618 .53913 .91247 .54771 .92877 .54305 .92256 .53448 Mtetra
.657 .753 .921 r
.92256 .53448 .92877 .54305 .94515 .5383 .93901 .52975 Mtetra
.658 .755 .922 r
.93901 .52975 .94515 .5383 .96162 .53358 .95555 .52492 Mtetra
.657 .753 .921 r
.95555 .52492 .96162 .53358 .97821 .52895 .97219 .52013 Mtetra
.653 .752 .922 r
.37725 .68046 .38547 .6876 .39906 .68377 .39088 .67664 Mtetra
.654 .754 .923 r
.39088 .67664 .39906 .68377 .41273 .67996 .40458 .67275 Mtetra
.656 .752 .921 r
.40458 .67275 .41273 .67996 .42646 .67608 .41836 .66876 Mtetra
.659 .752 .918 r
.41836 .66876 .42646 .67608 .44026 .67212 .43221 .66467 Mtetra
.658 .749 .917 r
.43221 .66467 .44026 .67212 .45414 .66805 .44614 .6606 Mtetra
.654 .749 .92 r
.44614 .6606 .45414 .66805 .46809 .66398 .46012 .65666 Mtetra
.653 .753 .923 r
.46012 .65666 .46809 .66398 .4821 .66004 .47419 .65272 Mtetra
.654 .754 .924 r
.47419 .65272 .4821 .66004 .49619 .65611 .48832 .64872 Mtetra
.655 .754 .922 r
.48832 .64872 .49619 .65611 .51035 .65214 .50253 .64466 Mtetra
.659 .753 .92 r
.50253 .64466 .51035 .65214 .52459 .64811 .51682 .64045 Mtetra
.659 .75 .917 r
.51682 .64045 .52459 .64811 .5389 .64402 .53118 .6362 Mtetra
.658 .746 .915 r
.53118 .6362 .5389 .64402 .55328 .63981 .54561 .63199 Mtetra
.655 .746 .917 r
.54561 .63199 .55328 .63981 .56774 .63559 .56012 .62785 Mtetra
.655 .749 .919 r
.56012 .62785 .56774 .63559 .58228 .63137 .57471 .62371 Mtetra
.654 .752 .922 r
.57471 .62371 .58228 .63137 .59689 .62718 .58937 .61955 Mtetra
.654 .754 .923 r
.58937 .61955 .59689 .62718 .61158 .623 .60412 .61537 Mtetra
.654 .755 .924 r
.60412 .61537 .61158 .623 .62635 .6188 .61894 .61115 Mtetra
.654 .756 .924 r
.61894 .61115 .62635 .6188 .64119 .61458 .63384 .6069 Mtetra
.655 .756 .924 r
.63384 .6069 .64119 .61458 .65612 .61033 .64882 .60262 Mtetra
.655 .757 .924 r
.64882 .60262 .65612 .61033 .67112 .60605 .66387 .59829 Mtetra
.656 .757 .924 r
.66387 .59829 .67112 .60605 .6862 .60173 .67901 .59393 Mtetra
.67901 .59393 .6862 .60173 .70137 .59739 .69423 .58953 Mtetra
.69423 .58953 .70137 .59739 .71661 .59302 .70953 .58509 Mtetra
.657 .756 .923 r
.70953 .58509 .71661 .59302 .73194 .58863 .72492 .58062 Mtetra
.657 .755 .922 r
.72492 .58062 .73194 .58863 .74735 .58425 .74038 .57612 Mtetra
.657 .753 .921 r
.74038 .57612 .74735 .58425 .76285 .5799 .75593 .5716 Mtetra
.657 .75 .919 r
.75593 .5716 .76285 .5799 .77843 .57555 .77157 .56708 Mtetra
.654 .746 .917 r
.77157 .56708 .77843 .57555 .79411 .57118 .7873 .56264 Mtetra
.653 .745 .917 r
.7873 .56264 .79411 .57118 .80986 .56669 .80312 .55822 Mtetra
.653 .748 .919 r
.80312 .55822 .80986 .56669 .82569 .56213 .81902 .55376 Mtetra
.656 .753 .921 r
.81902 .55376 .82569 .56213 .84161 .55751 .83501 .54916 Mtetra
.657 .755 .922 r
.83501 .54916 .84161 .55751 .85761 .55285 .85108 .54448 Mtetra
.658 .756 .922 r
.85108 .54448 .85761 .55285 .8737 .5482 .86723 .53974 Mtetra
.658 .754 .921 r
.86723 .53974 .8737 .5482 .88989 .54367 .88347 .53499 Mtetra
.654 .749 .919 r
.88347 .53499 .88989 .54367 .90618 .53913 .89982 .53036 Mtetra
.653 .747 .919 r
.89982 .53036 .90618 .53913 .92256 .53448 .91627 .52576 Mtetra
.655 .75 .92 r
.91627 .52576 .92256 .53448 .93901 .52975 .9328 .52104 Mtetra
.657 .753 .921 r
.9328 .52104 .93901 .52975 .95555 .52492 .94942 .51623 Mtetra
.658 .755 .921 r
.94942 .51623 .95555 .52492 .97219 .52013 .96612 .51132 Mtetra
.654 .753 .923 r
.36894 .6733 .37725 .68046 .39088 .67664 .38262 .6694 Mtetra
.656 .753 .921 r
.38262 .6694 .39088 .67664 .40458 .67275 .39637 .6654 Mtetra
.659 .752 .918 r
.39637 .6654 .40458 .67275 .41836 .66876 .4102 .66128 Mtetra
.658 .749 .917 r
.4102 .66128 .41836 .66876 .43221 .66467 .42409 .65721 Mtetra
.653 .749 .92 r
.42409 .65721 .43221 .66467 .44614 .6606 .43805 .65326 Mtetra
.653 .753 .923 r
.43805 .65326 .44614 .6606 .46012 .65666 .45209 .64931 Mtetra
.654 .754 .923 r
.45209 .64931 .46012 .65666 .47419 .65272 .4662 .64528 Mtetra
.657 .754 .921 r
.4662 .64528 .47419 .65272 .48832 .64872 .48038 .64114 Mtetra
.66 .752 .918 r
.48038 .64114 .48832 .64872 .50253 .64466 .49464 .63688 Mtetra
.659 .747 .915 r
.49464 .63688 .50253 .64466 .51682 .64045 .50897 .63262 Mtetra
.655 .746 .917 r
.50897 .63262 .51682 .64045 .53118 .6362 .52338 .6285 Mtetra
.654 .75 .92 r
.52338 .6285 .53118 .6362 .54561 .63199 .53787 .62439 Mtetra
.653 .754 .923 r
.53787 .62439 .54561 .63199 .56012 .62785 .55243 .62026 Mtetra
.653 .755 .925 r
.55243 .62026 .56012 .62785 .57471 .62371 .56707 .61612 Mtetra
.654 .756 .925 r
.56707 .61612 .57471 .62371 .58937 .61955 .58178 .61193 Mtetra
.58178 .61193 .58937 .61955 .60412 .61537 .59658 .60768 Mtetra
.655 .756 .924 r
.59658 .60768 .60412 .61537 .61894 .61115 .61145 .6034 Mtetra
.656 .756 .923 r
.61145 .6034 .61894 .61115 .63384 .6069 .6264 .59907 Mtetra
.656 .755 .923 r
.6264 .59907 .63384 .6069 .64882 .60262 .64144 .59471 Mtetra
.656 .754 .922 r
.64144 .59471 .64882 .60262 .66387 .59829 .65655 .59034 Mtetra
.655 .754 .922 r
.65655 .59034 .66387 .59829 .67901 .59393 .67175 .58597 Mtetra
.655 .755 .923 r
.67175 .58597 .67901 .59393 .69423 .58953 .68703 .58156 Mtetra
.656 .756 .923 r
.68703 .58156 .69423 .58953 .70953 .58509 .70239 .57711 Mtetra
.656 .757 .924 r
.70239 .57711 .70953 .58509 .72492 .58062 .71783 .57261 Mtetra
.657 .757 .924 r
.71783 .57261 .72492 .58062 .74038 .57612 .73336 .56806 Mtetra
.658 .757 .924 r
.73336 .56806 .74038 .57612 .75593 .5716 .74896 .56346 Mtetra
.658 .757 .923 r
.74896 .56346 .75593 .5716 .77157 .56708 .76466 .55884 Mtetra
.658 .755 .922 r
.76466 .55884 .77157 .56708 .7873 .56264 .78043 .5542 Mtetra
.657 .751 .919 r
.78043 .5542 .7873 .56264 .80312 .55822 .7963 .54957 Mtetra
.653 .745 .917 r
.7963 .54957 .80312 .55822 .81902 .55376 .81227 .54507 Mtetra
.652 .745 .918 r
.81227 .54507 .81902 .55376 .83501 .54916 .82833 .54059 Mtetra
.655 .75 .92 r
.82833 .54059 .83501 .54916 .85108 .54448 .84447 .53597 Mtetra
.657 .754 .921 r
.84447 .53597 .85108 .54448 .86723 .53974 .8607 .53122 Mtetra
.658 .755 .922 r
.8607 .53122 .86723 .53974 .88347 .53499 .877 .5264 Mtetra
.658 .755 .921 r
.877 .5264 .88347 .53499 .89982 .53036 .8934 .52156 Mtetra
.654 .749 .92 r
.8934 .52156 .89982 .53036 .91627 .52576 .90991 .51685 Mtetra
.653 .747 .919 r
.90991 .51685 .91627 .52576 .9328 .52104 .92652 .51219 Mtetra
.655 .751 .92 r
.92652 .51219 .9328 .52104 .94942 .51623 .94321 .50739 Mtetra
.657 .753 .921 r
.94321 .50739 .94942 .51623 .96612 .51132 .95999 .50248 Mtetra
.656 .753 .921 r
.36055 .66603 .36894 .6733 .38262 .6694 .37428 .66204 Mtetra
.659 .752 .919 r
.37428 .66204 .38262 .6694 .39637 .6654 .38808 .6579 Mtetra
.658 .749 .917 r
.38808 .6579 .39637 .6654 .4102 .66128 .40195 .65379 Mtetra
.653 .749 .92 r
.40195 .65379 .4102 .66128 .42409 .65721 .41588 .64983 Mtetra
.652 .753 .923 r
.41588 .64983 .42409 .65721 .43805 .65326 .42989 .64586 Mtetra
.654 .754 .923 r
.42989 .64586 .43805 .65326 .45209 .64931 .44397 .64182 Mtetra
.658 .754 .92 r
.44397 .64182 .45209 .64931 .4662 .64528 .45813 .63762 Mtetra
.66 .751 .917 r
.45813 .63762 .4662 .64528 .48038 .64114 .47237 .63332 Mtetra
.657 .747 .916 r
.47237 .63332 .48038 .64114 .49464 .63688 .48667 .62912 Mtetra
.654 .748 .919 r
.48667 .62912 .49464 .63688 .50897 .63262 .50105 .62501 Mtetra
.653 .753 .923 r
.50105 .62501 .50897 .63262 .52338 .6285 .51551 .62091 Mtetra
.652 .755 .925 r
.51551 .62091 .52338 .6285 .53787 .62439 .53004 .6168 Mtetra
.653 .756 .925 r
.53004 .6168 .53787 .62439 .55243 .62026 .54466 .61262 Mtetra
.656 .756 .924 r
.54466 .61262 .55243 .62026 .56707 .61612 .55935 .60833 Mtetra
.659 .754 .921 r
.55935 .60833 .56707 .61612 .58178 .61193 .57411 .60393 Mtetra
.659 .75 .918 r
.57411 .60393 .58178 .61193 .59658 .60768 .58896 .59951 Mtetra
.658 .746 .915 r
.58896 .59951 .59658 .60768 .61145 .6034 .60388 .59509 Mtetra
.658 .744 .914 r
.60388 .59509 .61145 .6034 .6264 .59907 .61888 .59067 Mtetra
.657 .743 .913 r
.61888 .59067 .6264 .59907 .64144 .59471 .63397 .58626 Mtetra
.656 .742 .913 r
.63397 .58626 .64144 .59471 .65655 .59034 .64914 .58185 Mtetra
.64914 .58185 .65655 .59034 .67175 .58597 .66439 .57744 Mtetra
.655 .742 .914 r
.66439 .57744 .67175 .58597 .68703 .58156 .67973 .57303 Mtetra
.654 .743 .915 r
.67973 .57303 .68703 .58156 .70239 .57711 .69515 .56862 Mtetra
.653 .745 .917 r
.69515 .56862 .70239 .57711 .71783 .57261 .71065 .56422 Mtetra
.653 .748 .92 r
.71065 .56422 .71783 .57261 .73336 .56806 .72625 .5598 Mtetra
.655 .753 .922 r
.72625 .5598 .73336 .56806 .74896 .56346 .74192 .55525 Mtetra
.657 .757 .923 r
.74192 .55525 .74896 .56346 .76466 .55884 .75768 .5506 Mtetra
.658 .757 .923 r
.75768 .5506 .76466 .55884 .78043 .5542 .77352 .54588 Mtetra
.77352 .54588 .78043 .5542 .7963 .54957 .78944 .54113 Mtetra
.658 .754 .921 r
.78944 .54113 .7963 .54957 .81227 .54507 .80546 .53639 Mtetra
.655 .748 .919 r
.80546 .53639 .81227 .54507 .82833 .54059 .82157 .53175 Mtetra
.652 .745 .918 r
.82157 .53175 .82833 .54059 .84447 .53597 .83779 .5272 Mtetra
.654 .749 .919 r
.83779 .5272 .84447 .53597 .8607 .53122 .85409 .52255 Mtetra
.657 .753 .921 r
.85409 .52255 .8607 .53122 .877 .5264 .87047 .51773 Mtetra
.658 .755 .922 r
.87047 .51773 .877 .5264 .8934 .52156 .88693 .51283 Mtetra
.658 .755 .921 r
.88693 .51283 .8934 .52156 .90991 .51685 .90349 .50791 Mtetra
.654 .749 .92 r
.90349 .50791 .90991 .51685 .92652 .51219 .92017 .50315 Mtetra
.653 .747 .919 r
.92017 .50315 .92652 .51219 .94321 .50739 .93694 .4984 Mtetra
.656 .751 .92 r
.93694 .4984 .94321 .50739 .95999 .50248 .95379 .4935 Mtetra
.659 .752 .919 r
.35209 .65865 .36055 .66603 .37428 .66204 .36586 .65452 Mtetra
.659 .75 .917 r
.36586 .65452 .37428 .66204 .38808 .6579 .37971 .65035 Mtetra
.653 .749 .92 r
.37971 .65035 .38808 .6579 .40195 .65379 .39362 .64637 Mtetra
.652 .753 .923 r
.39362 .64637 .40195 .65379 .41588 .64983 .4076 .64239 Mtetra
.654 .754 .923 r
.4076 .64239 .41588 .64983 .42989 .64586 .42165 .63834 Mtetra
.658 .753 .92 r
.42165 .63834 .42989 .64586 .44397 .64182 .43578 .63411 Mtetra
.661 .75 .916 r
.43578 .63411 .44397 .64182 .45813 .63762 .44999 .62978 Mtetra
.656 .747 .917 r
.44999 .62978 .45813 .63762 .47237 .63332 .46427 .62559 Mtetra
.653 .75 .921 r
.46427 .62559 .47237 .63332 .48667 .62912 .47862 .6215 Mtetra
.652 .753 .924 r
.47862 .6215 .48667 .62912 .50105 .62501 .49305 .61741 Mtetra
.652 .755 .925 r
.49305 .61741 .50105 .62501 .51551 .62091 .50756 .61326 Mtetra
.656 .756 .923 r
.50756 .61326 .51551 .62091 .53004 .6168 .52214 .60897 Mtetra
.66 .754 .919 r
.52214 .60897 .53004 .6168 .54466 .61262 .53681 .60451 Mtetra
.66 .748 .915 r
.53681 .60451 .54466 .61262 .55935 .60833 .55154 .60004 Mtetra
.659 .744 .913 r
.55154 .60004 .55935 .60833 .57411 .60393 .56636 .59561 Mtetra
.656 .743 .914 r
.56636 .59561 .57411 .60393 .58896 .59951 .58126 .59126 Mtetra
.656 .746 .916 r
.58126 .59126 .58896 .59951 .60388 .59509 .59624 .58689 Mtetra
.655 .748 .918 r
.59624 .58689 .60388 .59509 .61888 .59067 .6113 .5825 Mtetra
.656 .75 .919 r
.6113 .5825 .61888 .59067 .63397 .58626 .62644 .57809 Mtetra
.656 .751 .92 r
.62644 .57809 .63397 .58626 .64914 .58185 .64166 .57363 Mtetra
.64166 .57363 .64914 .58185 .66439 .57744 .65697 .56914 Mtetra
.656 .75 .919 r
.65697 .56914 .66439 .57744 .67973 .57303 .67236 .56461 Mtetra
.657 .749 .918 r
.67236 .56461 .67973 .57303 .69515 .56862 .68783 .56006 Mtetra
.656 .746 .916 r
.68783 .56006 .69515 .56862 .71065 .56422 .70339 .5555 Mtetra
.654 .742 .915 r
.70339 .5555 .71065 .56422 .72625 .5598 .71904 .55101 Mtetra
.652 .741 .915 r
.71904 .55101 .72625 .5598 .74192 .55525 .73478 .54657 Mtetra
.652 .745 .918 r
.73478 .54657 .74192 .55525 .75768 .5506 .75062 .54211 Mtetra
.655 .752 .921 r
.75062 .54211 .75768 .5506 .77352 .54588 .76653 .53748 Mtetra
.658 .757 .923 r
.76653 .53748 .77352 .54588 .78944 .54113 .78252 .53269 Mtetra
.659 .757 .923 r
.78252 .53269 .78944 .54113 .80546 .53639 .79859 .52785 Mtetra
.658 .756 .922 r
.79859 .52785 .80546 .53639 .82157 .53175 .81476 .523 Mtetra
.656 .751 .92 r
.81476 .523 .82157 .53175 .83779 .5272 .83102 .51825 Mtetra
.652 .745 .918 r
.83102 .51825 .83779 .5272 .85409 .52255 .8474 .51363 Mtetra
.653 .748 .919 r
.8474 .51363 .85409 .52255 .87047 .51773 .86386 .50892 Mtetra
.657 .753 .921 r
.86386 .50892 .87047 .51773 .88693 .51283 .8804 .50402 Mtetra
.659 .755 .921 r
.8804 .50402 .88693 .51283 .90349 .50791 .89702 .49903 Mtetra
.658 .754 .921 r
.89702 .49903 .90349 .50791 .92017 .50315 .91375 .49404 Mtetra
.653 .748 .919 r
.91375 .49404 .92017 .50315 .93694 .4984 .93059 .48923 Mtetra
.93059 .48923 .93694 .4984 .95379 .4935 .94753 .48438 Mtetra
.66 .751 .918 r
.34355 .65114 .35209 .65865 .36586 .65452 .35737 .64694 Mtetra
.655 .749 .919 r
.35737 .64694 .36586 .65452 .37971 .65035 .37125 .64288 Mtetra
.652 .752 .923 r
.37125 .64288 .37971 .65035 .39362 .64637 .3852 .6389 Mtetra
.653 .753 .923 r
.3852 .6389 .39362 .64637 .4076 .64239 .39923 .63484 Mtetra
.658 .753 .92 r
.39923 .63484 .4076 .64239 .42165 .63834 .41333 .6306 Mtetra
.661 .751 .917 r
.41333 .6306 .42165 .63834 .43578 .63411 .42752 .62624 Mtetra
.656 .747 .917 r
.42752 .62624 .43578 .63411 .44999 .62978 .44177 .62205 Mtetra
.652 .75 .922 r
.44177 .62205 .44999 .62978 .46427 .62559 .45609 .61795 Mtetra
.651 .753 .924 r
.45609 .61795 .46427 .62559 .47862 .6215 .47049 .61386 Mtetra
.653 .755 .925 r
.47049 .61386 .47862 .6215 .49305 .61741 .48497 .60967 Mtetra
.66 .756 .921 r
.48497 .60967 .49305 .61741 .50756 .61326 .49953 .60523 Mtetra
.662 .75 .915 r
.49953 .60523 .50756 .61326 .52214 .60897 .51417 .60071 Mtetra
.659 .744 .913 r
.51417 .60071 .52214 .60897 .53681 .60451 .52888 .59628 Mtetra
.655 .745 .916 r
.52888 .59628 .53681 .60451 .55154 .60004 .54367 .59196 Mtetra
.654 .749 .92 r
.54367 .59196 .55154 .60004 .56636 .59561 .55854 .58765 Mtetra
.653 .753 .923 r
.55854 .58765 .56636 .59561 .58126 .59126 .5735 .58333 Mtetra
.653 .755 .925 r
.5735 .58333 .58126 .59126 .59624 .58689 .58853 .579 Mtetra
.653 .758 .926 r
.58853 .579 .59624 .58689 .6113 .5825 .60365 .57462 Mtetra
.654 .759 .927 r
.60365 .57462 .6113 .5825 .62644 .57809 .61885 .57018 Mtetra
.655 .76 .927 r
.61885 .57018 .62644 .57809 .64166 .57363 .63413 .56568 Mtetra
.656 .76 .926 r
.63413 .56568 .64166 .57363 .65697 .56914 .64949 .56112 Mtetra
.657 .76 .926 r
.64949 .56112 .65697 .56914 .67236 .56461 .66494 .5565 Mtetra
.658 .759 .925 r
.66494 .5565 .67236 .56461 .68783 .56006 .68047 .55182 Mtetra
.658 .757 .923 r
.68047 .55182 .68783 .56006 .70339 .5555 .69608 .54713 Mtetra
.658 .755 .922 r
.69608 .54713 .70339 .5555 .71904 .55101 .71178 .54243 Mtetra
.657 .75 .919 r
.71178 .54243 .71904 .55101 .73478 .54657 .72757 .53774 Mtetra
.654 .744 .916 r
.72757 .53774 .73478 .54657 .75062 .54211 .74346 .53316 Mtetra
.651 .741 .916 r
.74346 .53316 .75062 .54211 .76653 .53748 .75944 .52867 Mtetra
.652 .746 .919 r
.75944 .52867 .76653 .53748 .78252 .53269 .77551 .5241 Mtetra
.658 .755 .922 r
.77551 .5241 .78252 .53269 .79859 .52785 .79166 .51926 Mtetra
.659 .757 .922 r
.79166 .51926 .79859 .52785 .81476 .523 .80789 .51432 Mtetra
.659 .756 .922 r
.80789 .51432 .81476 .523 .83102 .51825 .82421 .50939 Mtetra
.656 .751 .92 r
.82421 .50939 .83102 .51825 .8474 .51363 .84063 .50455 Mtetra
.651 .745 .918 r
.84063 .50455 .8474 .51363 .86386 .50892 .85717 .49987 Mtetra
.654 .748 .919 r
.85717 .49987 .86386 .50892 .8804 .50402 .87379 .49506 Mtetra
.658 .754 .921 r
.87379 .49506 .8804 .50402 .89702 .49903 .89049 .49006 Mtetra
.659 .755 .921 r
.89049 .49006 .89702 .49903 .91375 .49404 .90728 .48498 Mtetra
.657 .753 .921 r
.90728 .48498 .91375 .49404 .93059 .48923 .92417 .47997 Mtetra
.652 .748 .919 r
.92417 .47997 .93059 .48923 .94753 .48438 .94118 .47511 Mtetra
.657 .749 .918 r
.33493 .64352 .34355 .65114 .35737 .64694 .34879 .63937 Mtetra
.652 .75 .922 r
.34879 .63937 .35737 .64694 .37125 .64288 .36271 .63536 Mtetra
.653 .753 .923 r
.36271 .63536 .37125 .64288 .3852 .6389 .37671 .63131 Mtetra
.657 .753 .921 r
.37671 .63131 .3852 .6389 .39923 .63484 .39079 .62711 Mtetra
.661 .752 .917 r
.39079 .62711 .39923 .63484 .41333 .6306 .40494 .62272 Mtetra
.657 .748 .917 r
.40494 .62272 .41333 .6306 .42752 .62624 .41917 .61847 Mtetra
.652 .75 .922 r
.41917 .61847 .42752 .62624 .44177 .62205 .43346 .61436 Mtetra
.651 .753 .924 r
.43346 .61436 .44177 .62205 .45609 .61795 .44783 .61026 Mtetra
.654 .755 .924 r
.44783 .61026 .45609 .61795 .47049 .61386 .46228 .60604 Mtetra
.662 .755 .919 r
.46228 .60604 .47049 .61386 .48497 .60967 .47682 .6015 Mtetra
.662 .747 .913 r
.47682 .6015 .48497 .60967 .49953 .60523 .49143 .59695 Mtetra
.656 .744 .915 r
.49143 .59695 .49953 .60523 .51417 .60071 .50611 .59262 Mtetra
.653 .749 .92 r
.50611 .59262 .51417 .60071 .52888 .59628 .52087 .58835 Mtetra
.651 .753 .924 r
.52087 .58835 .52888 .59628 .54367 .59196 .53572 .58411 Mtetra
.65 .756 .927 r
.53572 .58411 .54367 .59196 .55854 .58765 .55065 .57986 Mtetra
.651 .759 .928 r
.55065 .57986 .55854 .58765 .5735 .58333 .56565 .57553 Mtetra
.653 .761 .929 r
.56565 .57553 .5735 .58333 .58853 .579 .58074 .57113 Mtetra
.656 .761 .927 r
.58074 .57113 .58853 .579 .60365 .57462 .59591 .56659 Mtetra
.657 .758 .925 r
.59591 .56659 .60365 .57462 .61885 .57018 .61117 .56201 Mtetra
.655 .755 .923 r
.61117 .56201 .61885 .57018 .63413 .56568 .62651 .55747 Mtetra
.654 .755 .924 r
.62651 .55747 .63413 .56568 .64949 .56112 .64193 .55295 Mtetra
.654 .757 .925 r
.64193 .55295 .64949 .56112 .66494 .5565 .65744 .5484 Mtetra
.657 .761 .927 r
.65744 .5484 .66494 .5565 .68047 .55182 .67303 .54371 Mtetra
.658 .762 .927 r
.67303 .54371 .68047 .55182 .69608 .54713 .68871 .53894 Mtetra
.66 .762 .926 r
.68871 .53894 .69608 .54713 .71178 .54243 .70446 .53409 Mtetra
.66 .759 .924 r
.70446 .53409 .71178 .54243 .72757 .53774 .72031 .52922 Mtetra
.658 .756 .922 r
.72031 .52922 .72757 .53774 .74346 .53316 .73624 .52439 Mtetra
.656 .75 .919 r
.73624 .52439 .74346 .53316 .75944 .52867 .75227 .51961 Mtetra
.651 .742 .916 r
.75227 .51961 .75944 .52867 .77551 .5241 .76841 .51506 Mtetra
.65 .743 .918 r
.76841 .51506 .77551 .5241 .79166 .51926 .78464 .51049 Mtetra
.657 .754 .921 r
.78464 .51049 .79166 .51926 .80789 .51432 .80095 .50559 Mtetra
.66 .757 .922 r
.80095 .50559 .80789 .51432 .82421 .50939 .81733 .50056 Mtetra
.659 .756 .922 r
.81733 .50056 .82421 .50939 .84063 .50455 .83381 .49554 Mtetra
.655 .751 .92 r
.83381 .49554 .84063 .50455 .85717 .49987 .8504 .49065 Mtetra
.651 .745 .919 r
.8504 .49065 .85717 .49987 .87379 .49506 .8671 .48591 Mtetra
.655 .75 .92 r
.8671 .48591 .87379 .49506 .89049 .49006 .88388 .48097 Mtetra
.658 .754 .921 r
.88388 .48097 .89049 .49006 .90728 .48498 .90074 .47586 Mtetra
.659 .755 .921 r
.90074 .47586 .90728 .48498 .92417 .47997 .91769 .4707 Mtetra
.655 .751 .921 r
.91769 .4707 .92417 .47997 .94118 .47511 .93477 .46569 Mtetra
.653 .749 .92 r
.32623 .63585 .33493 .64352 .34879 .63937 .34012 .6318 Mtetra
.652 .752 .923 r
.34012 .6318 .34879 .63937 .36271 .63536 .35409 .62776 Mtetra
.654 .753 .922 r
.35409 .62776 .36271 .63536 .37671 .63131 .36813 .62361 Mtetra
.661 .753 .918 r
.36813 .62361 .37671 .63131 .39079 .62711 .38226 .6192 Mtetra
.659 .748 .916 r
.38226 .6192 .39079 .62711 .40494 .62272 .39646 .61487 Mtetra
.652 .749 .921 r
.39646 .61487 .40494 .62272 .41917 .61847 .41073 .61073 Mtetra
.651 .753 .924 r
.41073 .61073 .41917 .61847 .43346 .61436 .42507 .60663 Mtetra
.653 .755 .924 r
.42507 .60663 .43346 .61436 .44783 .61026 .43949 .6024 Mtetra
.663 .755 .919 r
.43949 .6024 .44783 .61026 .46228 .60604 .454 .59781 Mtetra
.661 .747 .913 r
.454 .59781 .46228 .60604 .47682 .6015 .46858 .59327 Mtetra
.654 .745 .917 r
.46858 .59327 .47682 .6015 .49143 .59695 .48324 .58895 Mtetra
.651 .751 .923 r
.48324 .58895 .49143 .59695 .50611 .59262 .49797 .58472 Mtetra
.649 .754 .927 r
.49797 .58472 .50611 .59262 .52087 .58835 .51279 .58054 Mtetra
.65 .758 .929 r
.51279 .58054 .52087 .58835 .53572 .58411 .52769 .57627 Mtetra
.659 .761 .925 r
.52769 .57627 .53572 .58411 .55065 .57986 .54267 .57167 Mtetra
.661 .754 .919 r
.54267 .57167 .55065 .57986 .56565 .57553 .55772 .56697 Mtetra
.659 .745 .914 r
.55772 .56697 .56565 .57553 .58074 .57113 .57287 .56235 Mtetra
.657 .741 .912 r
.57287 .56235 .58074 .57113 .59591 .56659 .58809 .55779 Mtetra
.656 .741 .912 r
.58809 .55779 .59591 .56659 .61117 .56201 .6034 .55324 Mtetra
.656 .743 .914 r
.6034 .55324 .61117 .56201 .62651 .55747 .61879 .54865 Mtetra
.657 .743 .913 r
.61879 .54865 .62651 .55747 .64193 .55295 .63427 .54401 Mtetra
.656 .741 .912 r
.63427 .54401 .64193 .55295 .65744 .5484 .64984 .53938 Mtetra
.654 .74 .913 r
.64984 .53938 .65744 .5484 .67303 .54371 .66549 .53481 Mtetra
.651 .743 .917 r
.66549 .53481 .67303 .54371 .68871 .53894 .68124 .53033 Mtetra
.652 .751 .922 r
.68124 .53033 .68871 .53894 .70446 .53409 .69707 .52574 Mtetra
.66 .762 .925 r
.69707 .52574 .70446 .53409 .72031 .52922 .71298 .52082 Mtetra
.661 .762 .925 r
.71298 .52082 .72031 .52922 .73624 .52439 .72897 .5158 Mtetra
.66 .758 .923 r
.72897 .5158 .73624 .52439 .75227 .51961 .74506 .51082 Mtetra
.657 .753 .921 r
.74506 .51082 .75227 .51961 .76841 .51506 .76124 .50593 Mtetra
.651 .744 .918 r
.76124 .50593 .76841 .51506 .78464 .51049 .77753 .50128 Mtetra
.649 .742 .917 r
.77753 .50128 .78464 .51049 .80095 .50559 .79392 .49666 Mtetra
.658 .754 .921 r
.79392 .49666 .80095 .50559 .81733 .50056 .81038 .49167 Mtetra
.66 .757 .922 r
.81038 .49167 .81733 .50056 .83381 .49554 .82692 .48655 Mtetra
.659 .755 .921 r
.82692 .48655 .83381 .49554 .8504 .49065 .84357 .48145 Mtetra
.653 .749 .92 r
.84357 .48145 .8504 .49065 .8671 .48591 .86032 .47655 Mtetra
.651 .746 .919 r
.86032 .47655 .8671 .48591 .88388 .48097 .87719 .47173 Mtetra
.657 .752 .92 r
.87719 .47173 .88388 .48097 .90074 .47586 .89413 .46663 Mtetra
.659 .755 .921 r
.89413 .46663 .90074 .47586 .91769 .4707 .91116 .46141 Mtetra
.658 .754 .921 r
.91116 .46141 .91769 .4707 .93477 .46569 .92829 .4562 Mtetra
.652 .751 .923 r
.31743 .62821 .32623 .63585 .34012 .6318 .33137 .62416 Mtetra
.653 .753 .923 r
.33137 .62416 .34012 .6318 .35409 .62776 .34538 .62004 Mtetra
.659 .753 .92 r
.34538 .62004 .35409 .62776 .36813 .62361 .35948 .6157 Mtetra
.661 .75 .916 r
.35948 .6157 .36813 .62361 .38226 .6192 .37366 .61125 Mtetra
.653 .748 .919 r
.37366 .61125 .38226 .6192 .39646 .61487 .3879 .60707 Mtetra
.65 .752 .924 r
.3879 .60707 .39646 .61487 .41073 .61073 .40221 .60295 Mtetra
.652 .754 .924 r
.40221 .60295 .41073 .61073 .42507 .60663 .4166 .59875 Mtetra
.662 .755 .919 r
.4166 .59875 .42507 .60663 .43949 .6024 .43108 .59416 Mtetra
.662 .747 .913 r
.43108 .59416 .43949 .6024 .454 .59781 .44564 .58957 Mtetra
.654 .746 .917 r
.44564 .58957 .454 .59781 .46858 .59327 .46026 .58525 Mtetra
.649 .751 .924 r
.46026 .58525 .46858 .59327 .48324 .58895 .47497 .58105 Mtetra
.648 .755 .928 r
.47497 .58105 .48324 .58895 .49797 .58472 .48975 .57688 Mtetra
.655 .76 .927 r
.48975 .57688 .49797 .58472 .51279 .58054 .50462 .57241 Mtetra
.664 .756 .919 r
.50462 .57241 .51279 .58054 .52769 .57627 .51957 .56762 Mtetra
.658 .743 .913 r
.51957 .56762 .52769 .57627 .54267 .57167 .5346 .56305 Mtetra
.648 .741 .918 r
.5346 .56305 .54267 .57167 .55772 .56697 .54972 .55883 Mtetra
.641 .752 .93 r
.54972 .55883 .55772 .56697 .57287 .56235 .56492 .55478 Mtetra
.639 .768 .941 r
.56492 .55478 .57287 .56235 .58809 .55779 .58022 .55069 Mtetra
.642 .783 .949 r
.58022 .55069 .58809 .55779 .6034 .55324 .59559 .54638 Mtetra
.65 .793 .951 r
.59559 .54638 .6034 .55324 .61879 .54865 .61105 .54174 Mtetra
.659 .796 .948 r
.61105 .54174 .61879 .54865 .63427 .54401 .62659 .53677 Mtetra
.666 .79 .941 r
.62659 .53677 .63427 .54401 .64984 .53938 .6422 .53158 Mtetra
.668 .777 .931 r
.6422 .53158 .64984 .53938 .66549 .53481 .65789 .52635 Mtetra
.664 .76 .921 r
.65789 .52635 .66549 .53481 .68124 .53033 .67368 .52128 Mtetra
.655 .744 .915 r
.67368 .52128 .68124 .53033 .69707 .52574 .68957 .51657 Mtetra
.649 .739 .916 r
.68957 .51657 .69707 .52574 .71298 .52082 .70556 .51207 Mtetra
.656 .754 .922 r
.70556 .51207 .71298 .52082 .72897 .5158 .72163 .50725 Mtetra
.662 .762 .924 r
.72163 .50725 .72897 .5158 .74506 .51082 .73778 .50213 Mtetra
.661 .759 .923 r
.73778 .50213 .74506 .51082 .76124 .50593 .75401 .49702 Mtetra
.658 .754 .921 r
.75401 .49702 .76124 .50593 .77753 .50128 .77035 .49203 Mtetra
.65 .744 .918 r
.77035 .49203 .77753 .50128 .79392 .49666 .7868 .48733 Mtetra
.65 .743 .918 r
.7868 .48733 .79392 .49666 .81038 .49167 .80335 .48261 Mtetra
.659 .755 .921 r
.80335 .48261 .81038 .49167 .82692 .48655 .81997 .47749 Mtetra
.66 .757 .921 r
.81997 .47749 .82692 .48655 .84357 .48145 .83667 .47228 Mtetra
.658 .754 .921 r
.83667 .47228 .84357 .48145 .86032 .47655 .85348 .46714 Mtetra
.651 .747 .92 r
.85348 .46714 .86032 .47655 .87719 .47173 .87042 .46226 Mtetra
.653 .748 .919 r
.87042 .46226 .87719 .47173 .89413 .46663 .88745 .45726 Mtetra
.658 .753 .92 r
.88745 .45726 .89413 .46663 .91116 .46141 .90455 .45203 Mtetra
.659 .755 .921 r
.90455 .45203 .91116 .46141 .92829 .4562 .92175 .44671 Mtetra
.652 .752 .923 r
.30855 .62052 .31743 .62821 .33137 .62416 .32253 .61643 Mtetra
.655 .753 .922 r
.32253 .61643 .33137 .62416 .34538 .62004 .3366 .6122 Mtetra
.662 .753 .918 r
.3366 .6122 .34538 .62004 .35948 .6157 .35075 .60771 Mtetra
.657 .749 .918 r
.35075 .60771 .35948 .6157 .37366 .61125 .36496 .60338 Mtetra
.651 .751 .923 r
.36496 .60338 .37366 .61125 .3879 .60707 .37924 .59922 Mtetra
.651 .753 .924 r
.37924 .59922 .3879 .60707 .40221 .60295 .3936 .59505 Mtetra
.66 .755 .921 r
.3936 .59505 .40221 .60295 .4166 .59875 .40805 .59054 Mtetra
.664 .75 .914 r
.40805 .59054 .4166 .59875 .43108 .59416 .42258 .58586 Mtetra
.655 .746 .917 r
.42258 .58586 .43108 .59416 .44564 .58957 .43718 .5815 Mtetra
.649 .751 .924 r
.43718 .5815 .44564 .58957 .46026 .58525 .45185 .57729 Mtetra
.647 .754 .928 r
.45185 .57729 .46026 .58525 .47497 .58105 .46661 .57313 Mtetra
.659 .76 .924 r
.46661 .57313 .47497 .58105 .48975 .57688 .48145 .5685 Mtetra
.663 .751 .915 r
.48145 .5685 .48975 .57688 .50462 .57241 .49637 .56373 Mtetra
.647 .74 .917 r
.49637 .56373 .50462 .57241 .51957 .56762 .51138 .55953 Mtetra
.625 .748 .935 r
.51138 .55953 .51957 .56762 .5346 .56305 .52646 .55598 Mtetra
.603 .77 .96 r
.52646 .55598 .5346 .56305 .54972 .55883 .54164 .55284 Mtetra
.566 .789 .983 r
.54164 .55284 .54972 .55883 .56492 .55478 .55693 .5502 Mtetra
.547 .826 .997 r
.55693 .5502 .56492 .55478 .58022 .55069 .57231 .5472 Mtetra
.552 .86 .997 r
.57231 .5472 .58022 .55069 .59559 .54638 .58778 .54341 Mtetra
.578 .885 .991 r
.58778 .54341 .59559 .54638 .61105 .54174 .60332 .53873 Mtetra
.621 .9 .986 r
.60332 .53873 .61105 .54174 .62659 .53677 .61892 .53316 Mtetra
.667 .897 .979 r
.61892 .53316 .62659 .53677 .6422 .53158 .63458 .52679 Mtetra
.695 .871 .965 r
.63458 .52679 .6422 .53158 .65789 .52635 .6503 .52005 Mtetra
.689 .827 .95 r
.6503 .52005 .65789 .52635 .67368 .52128 .66611 .5138 Mtetra
.68 .794 .935 r
.66611 .5138 .67368 .52128 .68957 .51657 .68202 .50795 Mtetra
.664 .761 .922 r
.68202 .50795 .68957 .51657 .70556 .51207 .69804 .50277 Mtetra
.649 .74 .916 r
.69804 .50277 .70556 .51207 .72163 .50725 .71419 .49816 Mtetra
.652 .747 .919 r
.71419 .49816 .72163 .50725 .73778 .50213 .73042 .4934 Mtetra
.663 .761 .923 r
.73042 .4934 .73778 .50213 .75401 .49702 .74672 .48816 Mtetra
.662 .759 .922 r
.74672 .48816 .75401 .49702 .77035 .49203 .76311 .48296 Mtetra
.657 .753 .921 r
.76311 .48296 .77035 .49203 .7868 .48733 .77961 .47791 Mtetra
.648 .743 .919 r
.77961 .47791 .7868 .48733 .80335 .48261 .79623 .4732 Mtetra
.652 .746 .918 r
.79623 .4732 .80335 .48261 .81997 .47749 .81294 .4683 Mtetra
.66 .756 .921 r
.81294 .4683 .81997 .47749 .83667 .47228 .82971 .46305 Mtetra
.82971 .46305 .83667 .47228 .85348 .46714 .84659 .45777 Mtetra
.655 .752 .921 r
.84659 .45777 .85348 .46714 .87042 .46226 .86358 .45267 Mtetra
.65 .746 .92 r
.86358 .45267 .87042 .46226 .88745 .45726 .88069 .44774 Mtetra
.656 .751 .92 r
.88069 .44774 .88745 .45726 .90455 .45203 .89787 .44252 Mtetra
.659 .754 .92 r
.89787 .44252 .90455 .45203 .92175 .44671 .91515 .43715 Mtetra
.653 .752 .923 r
.29958 .61276 .30855 .62052 .32253 .61643 .31361 .60859 Mtetra
.659 .753 .92 r
.31361 .60859 .32253 .61643 .3366 .6122 .32773 .60419 Mtetra
.661 .75 .916 r
.32773 .60419 .3366 .6122 .35075 .60771 .34192 .59969 Mtetra
.653 .749 .92 r
.34192 .59969 .35075 .60771 .36496 .60338 .35618 .59546 Mtetra
.65 .752 .924 r
.35618 .59546 .36496 .60338 .37924 .59922 .3705 .5913 Mtetra
.654 .754 .923 r
.3705 .5913 .37924 .59922 .3936 .59505 .38492 .58695 Mtetra
.665 .753 .916 r
.38492 .58695 .3936 .59505 .40805 .59054 .39942 .58221 Mtetra
.658 .747 .916 r
.39942 .58221 .40805 .59054 .42258 .58586 .41399 .57771 Mtetra
.65 .75 .923 r
.41399 .57771 .42258 .58586 .43718 .5815 .42864 .57345 Mtetra
.646 .753 .927 r
.42864 .57345 .43718 .5815 .45185 .57729 .44336 .56931 Mtetra
.658 .759 .924 r
.44336 .56931 .45185 .57729 .46661 .57313 .45817 .56469 Mtetra
.663 .75 .915 r
.45817 .56469 .46661 .57313 .48145 .5685 .47307 .55989 Mtetra
.638 .74 .922 r
.47307 .55989 .48145 .5685 .49637 .56373 .48804 .55599 Mtetra
.599 .75 .949 r
.48804 .55599 .49637 .56373 .51138 .55953 .50308 .55312 Mtetra
.516 .758 .984 r
.50308 .55312 .51138 .55953 .52646 .55598 .51823 .5517 Mtetra
.424 .782 .996 r
.51823 .5517 .52646 .55598 .54164 .55284 .53348 .55056 Mtetra
.366 .804 .96 r
.53348 .55056 .54164 .55284 .55693 .5502 .54885 .54861 Mtetra
.397 .834 .948 r
.54885 .54861 .55693 .5502 .57231 .5472 .56432 .54563 Mtetra
.462 .868 .959 r
.56432 .54563 .57231 .5472 .58778 .54341 .57987 .54171 Mtetra
.52 .892 .968 r
.57987 .54171 .58778 .54341 .60332 .53873 .5955 .537 Mtetra
.566 .911 .97 r
.5955 .537 .60332 .53873 .61892 .53316 .61121 .53148 Mtetra
.612 .929 .967 r
.61121 .53148 .61892 .53316 .63458 .52679 .62696 .52501 Mtetra
.662 .943 .962 r
.62696 .52501 .63458 .52679 .6503 .52005 .64275 .51748 Mtetra
.712 .938 .959 r
.64275 .51748 .6503 .52005 .66611 .5138 .65857 .50914 Mtetra
.729 .887 .953 r
.65857 .50914 .66611 .5138 .68202 .50795 .67447 .50104 Mtetra
.697 .818 .94 r
.67447 .50104 .68202 .50795 .69804 .50277 .69049 .4944 Mtetra
.672 .773 .926 r
.69049 .4944 .69804 .50277 .71419 .49816 .70666 .48881 Mtetra
.649 .743 .918 r
.70666 .48881 .71419 .49816 .73042 .4934 .72296 .48413 Mtetra
.653 .747 .919 r
.72296 .48413 .73042 .4934 .74672 .48816 .73935 .47926 Mtetra
.664 .761 .922 r
.73935 .47926 .74672 .48816 .76311 .48296 .7558 .4739 Mtetra
.661 .757 .922 r
.7558 .4739 .76311 .48296 .77961 .47791 .77235 .46865 Mtetra
.654 .751 .921 r
.77235 .46865 .77961 .47791 .79623 .4732 .78903 .46365 Mtetra
.648 .743 .919 r
.78903 .46365 .79623 .4732 .81294 .4683 .80582 .45889 Mtetra
.657 .751 .92 r
.80582 .45889 .81294 .4683 .82971 .46305 .82268 .45372 Mtetra
.661 .756 .921 r
.82268 .45372 .82971 .46305 .84659 .45777 .83962 .44835 Mtetra
.659 .754 .921 r
.83962 .44835 .84659 .45777 .86358 .45267 .85666 .44304 Mtetra
.651 .748 .92 r
.85666 .44304 .86358 .45267 .88069 .44774 .87384 .43802 Mtetra
.653 .748 .919 r
.87384 .43802 .88069 .44774 .89787 .44252 .89112 .43288 Mtetra
.658 .753 .92 r
.89112 .43288 .89787 .44252 .91515 .43715 .90847 .42749 Mtetra
.654 .752 .922 r
.29053 .60491 .29958 .61276 .31361 .60859 .3046 .60065 Mtetra
.662 .753 .918 r
.3046 .60065 .31361 .60859 .32773 .60419 .31877 .59611 Mtetra
.658 .75 .918 r
.31877 .59611 .32773 .60419 .34192 .59969 .333 .59169 Mtetra
.651 .751 .923 r
.333 .59169 .34192 .59969 .35618 .59546 .3473 .58747 Mtetra
.65 .752 .924 r
.3473 .58747 .35618 .59546 .3705 .5913 .36168 .58325 Mtetra
.661 .755 .919 r
.36168 .58325 .3705 .5913 .38492 .58695 .37615 .57862 Mtetra
.663 .749 .914 r
.37615 .57862 .38492 .58695 .39942 .58221 .3907 .57391 Mtetra
.652 .748 .92 r
.3907 .57391 .39942 .58221 .41399 .57771 .40532 .56956 Mtetra
.646 .751 .926 r
.40532 .56956 .41399 .57771 .42864 .57345 .42 .5654 Mtetra
.653 .757 .926 r
.42 .5654 .42864 .57345 .44336 .56931 .43478 .56097 Mtetra
.666 .754 .916 r
.43478 .56097 .44336 .56931 .45817 .56469 .44966 .55604 Mtetra
.638 .74 .922 r
.44966 .55604 .45817 .56469 .47307 .55989 .46459 .55211 Mtetra
.584 .745 .953 r
.46459 .55211 .47307 .55989 .48804 .55599 .47959 .54965 Mtetra
.443 .73 .987 r
.47959 .54965 .48804 .55599 .50308 .55312 .49467 .54949 Mtetra
.311 .742 .97 r
.49467 .54949 .50308 .55312 .51823 .5517 .50988 .54933 Mtetra
.334 .785 .954 r
.50988 .54933 .51823 .5517 .53348 .55056 .52521 .54783 Mtetra
.472 .848 .987 r
.52521 .54783 .53348 .55056 .54885 .54861 .54065 .54476 Mtetra
.583 .863 .995 r
.54065 .54476 .54885 .54861 .56432 .54563 .55618 .54051 Mtetra
.631 .843 .981 r
.55618 .54051 .56432 .54563 .57987 .54171 .57179 .53574 Mtetra
.64 .822 .97 r
.57179 .53574 .57987 .54171 .5955 .537 .5875 .53098 Mtetra
.638 .822 .971 r
.5875 .53098 .5955 .537 .61121 .53148 .60329 .52622 Mtetra
.646 .848 .977 r
.60329 .52622 .61121 .53148 .62696 .52501 .61916 .52095 Mtetra
.671 .89 .977 r
.61916 .52095 .62696 .52501 .64275 .51748 .63508 .51448 Mtetra
.708 .928 .964 r
.63508 .51448 .64275 .51748 .65857 .50914 .65101 .5064 Mtetra
.746 .942 .947 r
.65101 .5064 .65857 .50914 .67447 .50104 .66695 .49694 Mtetra
.759 .91 .942 r
.66695 .49694 .67447 .50104 .69049 .4944 .68294 .48746 Mtetra
.708 .824 .937 r
.68294 .48746 .69049 .4944 .70666 .48881 .69909 .48031 Mtetra
.672 .773 .926 r
.69909 .48031 .70666 .48881 .72296 .48413 .71541 .47463 Mtetra
.646 .741 .918 r
.71541 .47463 .72296 .48413 .73935 .47926 .73188 .46998 Mtetra
.658 .752 .919 r
.73188 .46998 .73935 .47926 .7558 .4739 .74842 .46482 Mtetra
.664 .761 .922 r
.74842 .46482 .7558 .4739 .77235 .46865 .76503 .45937 Mtetra
.659 .755 .921 r
.76503 .45937 .77235 .46865 .78903 .46365 .78175 .45411 Mtetra
.649 .747 .92 r
.78175 .45411 .78903 .46365 .80582 .45889 .79861 .44921 Mtetra
.651 .745 .919 r
.79861 .44921 .80582 .45889 .82268 .45372 .81556 .44424 Mtetra
.66 .755 .92 r
.81556 .44424 .82268 .45372 .83962 .44835 .83257 .43883 Mtetra
.66 .755 .921 r
.83257 .43883 .83962 .44835 .85666 .44304 .84969 .43341 Mtetra
.654 .751 .921 r
.84969 .43341 .85666 .44304 .87384 .43802 .86692 .4282 Mtetra
.651 .747 .92 r
.86692 .4282 .87384 .43802 .89112 .43288 .88428 .4231 Mtetra
.657 .752 .92 r
.88428 .4231 .89112 .43288 .90847 .42749 .90171 .4177 Mtetra
.656 .752 .921 r
.28138 .59696 .29053 .60491 .3046 .60065 .29551 .59259 Mtetra
.662 .752 .917 r
.29551 .59259 .3046 .60065 .31877 .59611 .30972 .58797 Mtetra
.654 .749 .92 r
.30972 .58797 .31877 .59611 .333 .59169 .324 .58363 Mtetra
.65 .751 .924 r
.324 .58363 .333 .59169 .3473 .58747 .33834 .57941 Mtetra
.653 .753 .923 r
.33834 .57941 .3473 .58747 .36168 .58325 .35277 .57504 Mtetra
.665 .754 .916 r
.35277 .57504 .36168 .58325 .37615 .57862 .36729 .57022 Mtetra
.658 .748 .917 r
.36729 .57022 .37615 .57862 .3907 .57391 .38189 .56566 Mtetra
.648 .75 .924 r
.38189 .56566 .3907 .57391 .40532 .56956 .39655 .5614 Mtetra
.646 .753 .927 r
.39655 .5614 .40532 .56956 .42 .5654 .41129 .55719 Mtetra
.666 .758 .919 r
.41129 .55719 .42 .5654 .43478 .56097 .42613 .55224 Mtetra
.649 .742 .917 r
.42613 .55224 .43478 .56097 .44966 .55604 .44104 .5479 Mtetra
.59 .739 .946 r
.44104 .5479 .44966 .55604 .46459 .55211 .45599 .54532 Mtetra
.431 .712 .983 r
.45599 .54532 .46459 .55211 .47959 .54965 .47101 .54556 Mtetra
.266 .705 .963 r
.47101 .54556 .47959 .54965 .49467 .54949 .48614 .54625 Mtetra
.365 .782 .977 r
.48614 .54625 .49467 .54949 .50988 .54933 .50142 .54505 Mtetra
.576 .848 .996 r
.50142 .54505 .50988 .54933 .52521 .54783 .51683 .5412 Mtetra
.717 .82 .929 r
.51683 .5412 .52521 .54783 .54065 .54476 .53232 .53395 Mtetra
.711 .725 .862 r
.53232 .53395 .54065 .54476 .55618 .54051 .54787 .52637 Mtetra
.679 .661 .826 r
.54787 .52637 .55618 .54051 .57179 .53574 .5635 .51984 Mtetra
.645 .625 .815 r
.5635 .51984 .57179 .53574 .5875 .53098 .57923 .51502 Mtetra
.615 .61 .823 r
.57923 .51502 .5875 .53098 .60329 .52622 .59509 .51191 Mtetra
.593 .623 .851 r
.59509 .51191 .60329 .52622 .61916 .52095 .61108 .50987 Mtetra
.592 .681 .903 r
.61108 .50987 .61916 .52095 .63508 .51448 .62718 .50751 Mtetra
.672 .811 .95 r
.62718 .50751 .63508 .51448 .65101 .5064 .64328 .50172 Mtetra
.735 .891 .951 r
.64328 .50172 .65101 .5064 .66695 .49694 .65935 .49324 Mtetra
.778 .924 .933 r
.65935 .49324 .66695 .49694 .68294 .48746 .6754 .4828 Mtetra
.771 .9 .932 r
.6754 .4828 .68294 .48746 .69909 .48031 .6915 .47279 Mtetra
.706 .812 .931 r
.6915 .47279 .69909 .48031 .71541 .47463 .70782 .46565 Mtetra
.662 .762 .924 r
.70782 .46565 .71541 .47463 .73188 .46998 .72432 .46029 Mtetra
.646 .741 .918 r
.72432 .46029 .73188 .46998 .74842 .46482 .74095 .45556 Mtetra
.664 .759 .921 r
.74095 .45556 .74842 .46482 .76503 .45937 .75763 .45006 Mtetra
.662 .758 .921 r
.75763 .45006 .76503 .45937 .78175 .45411 .77442 .4446 Mtetra
.654 .752 .921 r
.77442 .4446 .78175 .45411 .79861 .44921 .79132 .43945 Mtetra
.647 .744 .92 r
.79132 .43945 .79861 .44921 .81556 .44424 .80835 .43457 Mtetra
.658 .752 .919 r
.80835 .43457 .81556 .44424 .83257 .43883 .82545 .42921 Mtetra
.661 .756 .92 r
.82545 .42921 .83257 .43883 .84969 .43341 .84263 .42369 Mtetra
.657 .753 .921 r
.84263 .42369 .84969 .43341 .86692 .4282 .85993 .41829 Mtetra
.65 .747 .921 r
.85993 .41829 .86692 .4282 .88428 .4231 .87737 .41317 Mtetra
.655 .75 .92 r
.87737 .41317 .88428 .4231 .90171 .4177 .89489 .40779 Mtetra
.659 .753 .919 r
.27215 .58892 .28138 .59696 .29551 .59259 .28632 .58442 Mtetra
.661 .751 .917 r
.28632 .58442 .29551 .59259 .30972 .58797 .30058 .5798 Mtetra
.652 .75 .921 r
.30058 .5798 .30972 .58797 .324 .58363 .3149 .57549 Mtetra
.65 .751 .924 r
.3149 .57549 .324 .58363 .33834 .57941 .32929 .57123 Mtetra
.658 .753 .92 r
.32929 .57123 .33834 .57941 .35277 .57504 .34377 .56665 Mtetra
.665 .751 .915 r
.34377 .56665 .35277 .57504 .36729 .57022 .35835 .5618 Mtetra
.653 .748 .92 r
.35835 .5618 .36729 .57022 .38189 .56566 .37298 .55736 Mtetra
.645 .75 .926 r
.37298 .55736 .38189 .56566 .39655 .5614 .38769 .55316 Mtetra
.654 .755 .924 r
.38769 .55316 .39655 .5614 .41129 .55719 .40249 .5486 Mtetra
.664 .751 .915 r
.40249 .5486 .41129 .55719 .42613 .55224 .41738 .54367 Mtetra
.616 .738 .933 r
.41738 .54367 .42613 .55224 .44104 .5479 .43231 .54036 Mtetra
.487 .717 .973 r
.43231 .54036 .44104 .5479 .45599 .54532 .44727 .53991 Mtetra
.276 .675 .97 r
.44727 .53991 .45599 .54532 .47101 .54556 .46231 .54142 Mtetra
.349 .751 .983 r
.46231 .54142 .47101 .54556 .48614 .54625 .47752 .54107 Mtetra
.621 .837 .983 r
.47752 .54107 .48614 .54625 .50142 .54505 .49289 .53661 Mtetra
.755 .783 .876 r
.49289 .53661 .50142 .54505 .51683 .5412 .50838 .5271 Mtetra
.735 .683 .8 r
.50838 .5271 .51683 .5412 .53232 .53395 .52392 .51645 Mtetra
.708 .636 .774 r
.52392 .51645 .53232 .53395 .54787 .52637 .53948 .50648 Mtetra
.671 .598 .765 r
.53948 .50648 .54787 .52637 .5635 .51984 .55511 .49886 Mtetra
.633 .57 .765 r
.55511 .49886 .5635 .51984 .57923 .51502 .57085 .49397 Mtetra
.594 .548 .773 r
.57085 .49397 .57923 .51502 .59509 .51191 .58672 .49183 Mtetra
.553 .535 .789 r
.58672 .49183 .59509 .51191 .61108 .50987 .60277 .49205 Mtetra
.533 .548 .816 r
.60277 .49205 .61108 .50987 .62718 .50751 .61898 .493 Mtetra
.547 .601 .859 r
.61898 .493 .62718 .50751 .64328 .50172 .6353 .49283 Mtetra
.661 .762 .925 r
.6353 .49283 .64328 .50172 .65935 .49324 .65157 .48755 Mtetra
.759 .871 .929 r
.65157 .48755 .65935 .49324 .6754 .4828 .66775 .47808 Mtetra
.798 .902 .915 r
.66775 .47808 .6754 .4828 .6915 .47279 .6839 .46669 Mtetra
.757 .863 .927 r
.6839 .46669 .6915 .47279 .70782 .46565 .70018 .45727 Mtetra
.689 .788 .926 r
.70018 .45727 .70782 .46565 .72432 .46029 .71668 .45075 Mtetra
.648 .747 .922 r
.71668 .45075 .72432 .46029 .74095 .45556 .73338 .44589 Mtetra
.657 .749 .918 r
.73338 .44589 .74095 .45556 .75763 .45006 .75015 .44065 Mtetra
.665 .759 .92 r
.75015 .44065 .75763 .45006 .77442 .4446 .767 .43503 Mtetra
.658 .754 .921 r
.767 .43503 .77442 .4446 .79132 .43945 .78396 .42965 Mtetra
.647 .746 .921 r
.78396 .42965 .79132 .43945 .80835 .43457 .80106 .42469 Mtetra
.654 .748 .919 r
.80106 .42469 .80835 .43457 .82545 .42921 .81825 .41945 Mtetra
.661 .755 .92 r
.81825 .41945 .82545 .42921 .84263 .42369 .8355 .41387 Mtetra
.659 .754 .92 r
.8355 .41387 .84263 .42369 .85993 .41829 .85287 .40833 Mtetra
.651 .749 .921 r
.85287 .40833 .85993 .41829 .87737 .41317 .87038 .40311 Mtetra
.653 .749 .92 r
.87038 .40311 .87737 .41317 .89489 .40779 .88798 .39775 Mtetra
.66 .753 .918 r
.26282 .58079 .27215 .58892 .28632 .58442 .27705 .57618 Mtetra
.659 .751 .918 r
.27705 .57618 .28632 .58442 .30058 .5798 .29135 .57159 Mtetra
.651 .751 .923 r
.29135 .57159 .30058 .5798 .3149 .57549 .30571 .56727 Mtetra
.65 .751 .923 r
.30571 .56727 .3149 .57549 .32929 .57123 .32014 .56295 Mtetra
.662 .754 .918 r
.32014 .56295 .32929 .57123 .34377 .56665 .33469 .55818 Mtetra
.662 .75 .916 r
.33469 .55818 .34377 .56665 .35835 .5618 .34931 .55339 Mtetra
.65 .75 .922 r
.34931 .55339 .35835 .5618 .37298 .55736 .36399 .54899 Mtetra
.644 .75 .926 r
.36399 .54899 .37298 .55736 .38769 .55316 .37874 .54478 Mtetra
.664 .756 .919 r
.37874 .54478 .38769 .55316 .40249 .5486 .3936 .53984 Mtetra
.65 .745 .919 r
.3936 .53984 .40249 .5486 .41738 .54367 .40853 .5354 Mtetra
.574 .733 .95 r
.40853 .5354 .41738 .54367 .43231 .54036 .42348 .53317 Mtetra
.355 .667 .974 r
.42348 .53317 .43231 .54036 .44727 .53991 .43843 .53473 Mtetra
.286 .689 .973 r
.43843 .53473 .44727 .53991 .46231 .54142 .45353 .53589 Mtetra
.548 .804 .993 r
.45353 .53589 .46231 .54142 .47752 .54107 .46884 .53318 Mtetra
.768 .797 .877 r
.46884 .53318 .47752 .54107 .49289 .53661 .48434 .52305 Mtetra
.766 .7 .79 r
.48434 .52305 .49289 .53661 .50838 .5271 .4999 .50988 Mtetra
.741 .653 .762 r
.4999 .50988 .50838 .5271 .52392 .51645 .51547 .4968 Mtetra
.7 .614 .757 r
.51547 .4968 .52392 .51645 .53948 .50648 .53106 .48666 Mtetra
.661 .593 .769 r
.53106 .48666 .53948 .50648 .55511 .49886 .54671 .47988 Mtetra
.638 .59 .784 r
.54671 .47988 .55511 .49886 .57085 .49397 .56246 .47493 Mtetra
.61 .575 .79 r
.56246 .47493 .57085 .49397 .58672 .49183 .57832 .4718 Mtetra
.551 .535 .79 r
.57832 .4718 .58672 .49183 .60277 .49205 .59436 .47207 Mtetra
.49 .502 .796 r
.59436 .47207 .60277 .49205 .61898 .493 .61063 .47534 Mtetra
.473 .519 .824 r
.61063 .47534 .61898 .493 .6353 .49283 .62708 .47874 Mtetra
.528 .601 .87 r
.62708 .47874 .6353 .49283 .65157 .48755 .64359 .4791 Mtetra
.704 .79 .917 r
.64359 .4791 .65157 .48755 .66775 .47808 .65995 .47194 Mtetra
.789 .866 .905 r
.65995 .47194 .66775 .47808 .6839 .46669 .67621 .4608 Mtetra
.798 .875 .904 r
.67621 .4608 .6839 .46669 .70018 .45727 .69247 .44923 Mtetra
.716 .807 .922 r
.69247 .44923 .70018 .45727 .71668 .45075 .70899 .4415 Mtetra
.661 .761 .924 r
.70899 .4415 .71668 .45075 .73338 .44589 .72572 .43604 Mtetra
.649 .744 .919 r
.72572 .43604 .73338 .44589 .75015 .44065 .74259 .43108 Mtetra
.666 .758 .919 r
.74259 .43108 .75015 .44065 .767 .43503 .7595 .42537 Mtetra
.661 .755 .92 r
.7595 .42537 .767 .43503 .78396 .42965 .77653 .41985 Mtetra
.65 .749 .922 r
.77653 .41985 .78396 .42965 .80106 .42469 .79369 .41472 Mtetra
.65 .747 .92 r
.79369 .41472 .80106 .42469 .81825 .41945 .81096 .40956 Mtetra
.661 .754 .919 r
.81096 .40956 .81825 .41945 .8355 .41387 .82829 .40394 Mtetra
.66 .754 .92 r
.82829 .40394 .8355 .41387 .85287 .40833 .84573 .3983 Mtetra
.653 .75 .921 r
.84573 .3983 .85287 .40833 .87038 .40311 .86331 .39294 Mtetra
.652 .748 .92 r
.86331 .39294 .87038 .40311 .88798 .39775 .88099 .38759 Mtetra
.662 .753 .918 r
.2534 .57257 .26282 .58079 .27705 .57618 .26768 .56787 Mtetra
.658 .751 .919 r
.26768 .56787 .27705 .57618 .29135 .57159 .28202 .5633 Mtetra
.65 .75 .923 r
.28202 .5633 .29135 .57159 .30571 .56727 .29642 .55896 Mtetra
.651 .751 .923 r
.29642 .55896 .30571 .56727 .32014 .56295 .31091 .55456 Mtetra
.665 .754 .917 r
.31091 .55456 .32014 .56295 .33469 .55818 .32551 .54965 Mtetra
.659 .75 .917 r
.32551 .54965 .33469 .55818 .34931 .55339 .34017 .54492 Mtetra
.648 .75 .924 r
.34017 .54492 .34931 .55339 .36399 .54899 .3549 .54055 Mtetra
.645 .751 .926 r
.3549 .54055 .36399 .54899 .37874 .54478 .3697 .53626 Mtetra
.668 .756 .916 r
.3697 .53626 .37874 .54478 .3936 .53984 .38462 .5311 Mtetra
.632 .742 .927 r
.38462 .5311 .3936 .53984 .40853 .5354 .39958 .52723 Mtetra
.51 .714 .963 r
.39958 .52723 .40853 .5354 .42348 .53317 .41453 .52642 Mtetra
.28 .642 .966 r
.41453 .52642 .42348 .53317 .43843 .53473 .4295 .52868 Mtetra
.404 .728 .99 r
.4295 .52868 .43843 .53473 .45353 .53589 .44468 .52872 Mtetra
.708 .806 .926 r
.44468 .52872 .45353 .53589 .46884 .53318 .46012 .52181 Mtetra
.785 .736 .807 r
.46012 .52181 .46884 .53318 .48434 .52305 .47573 .50827 Mtetra
.779 .691 .767 r
.47573 .50827 .48434 .52305 .4999 .50988 .49137 .49266 Mtetra
.731 .65 .768 r
.49137 .49266 .4999 .50988 .51547 .4968 .50698 .48064 Mtetra
.684 .641 .801 r
.50698 .48064 .51547 .4968 .53106 .48666 .5226 .47316 Mtetra
.658 .666 .846 r
.5226 .47316 .53106 .48666 .54671 .47988 .5383 .46785 Mtetra
.655 .69 .871 r
.5383 .46785 .54671 .47988 .56246 .47493 .55409 .46284 Mtetra
.648 .688 .873 r
.55409 .46284 .56246 .47493 .57832 .4718 .56997 .45813 Mtetra
.598 .64 .863 r
.56997 .45813 .57832 .4718 .59436 .47207 .58599 .4556 Mtetra
.496 .547 .839 r
.58599 .4556 .59436 .47207 .61063 .47534 .60224 .45767 Mtetra
.406 .482 .825 r
.60224 .45767 .61063 .47534 .62708 .47874 .61876 .46341 Mtetra
.44 .536 .858 r
.61876 .46341 .62708 .47874 .64359 .4791 .63541 .46711 Mtetra
.605 .678 .893 r
.63541 .46711 .64359 .4791 .65995 .47194 .65199 .46411 Mtetra
.763 .822 .899 r
.65199 .46411 .65995 .47194 .67621 .4608 .66838 .45403 Mtetra
.806 .855 .886 r
.66838 .45403 .67621 .4608 .69247 .44923 .68471 .44164 Mtetra
.748 .828 .913 r
.68471 .44164 .69247 .44923 .70899 .4415 .70123 .43235 Mtetra
.677 .772 .922 r
.70123 .43235 .70899 .4415 .72572 .43604 .71799 .4262 Mtetra
.644 .744 .922 r
.71799 .4262 .72572 .43604 .74259 .43108 .73494 .42135 Mtetra
.665 .757 .919 r
.73494 .42135 .74259 .43108 .7595 .42537 .75192 .41562 Mtetra
.663 .756 .92 r
.75192 .41562 .7595 .42537 .77653 .41985 .76902 .40995 Mtetra
.653 .751 .922 r
.76902 .40995 .77653 .41985 .79369 .41472 .78624 .40466 Mtetra
.648 .746 .921 r
.78624 .40466 .79369 .41472 .81096 .40956 .80359 .39954 Mtetra
.66 .753 .919 r
.80359 .39954 .81096 .40956 .82829 .40394 .821 .39388 Mtetra
.661 .754 .92 r
.821 .39388 .82829 .40394 .84573 .3983 .83852 .38816 Mtetra
.654 .751 .921 r
.83852 .38816 .84573 .3983 .86331 .39294 .85616 .38268 Mtetra
.651 .748 .921 r
.85616 .38268 .86331 .39294 .88099 .38759 .87393 .37731 Mtetra
.662 .753 .917 r
.24388 .56426 .2534 .57257 .26768 .56787 .25821 .5595 Mtetra
.656 .751 .92 r
.25821 .5595 .26768 .56787 .28202 .5633 .2726 .55492 Mtetra
.65 .75 .923 r
.2726 .55492 .28202 .5633 .29642 .55896 .28705 .55054 Mtetra
.652 .751 .922 r
.28705 .55054 .29642 .55896 .31091 .55456 .30158 .54607 Mtetra
.666 .754 .916 r
.30158 .54607 .31091 .55456 .32551 .54965 .31623 .54106 Mtetra
.657 .751 .919 r
.31623 .54106 .32551 .54965 .34017 .54492 .33094 .53636 Mtetra
.647 .749 .924 r
.33094 .53636 .34017 .54492 .3549 .54055 .34571 .53199 Mtetra
.649 .751 .924 r
.34571 .53199 .3549 .54055 .3697 .53626 .36057 .52753 Mtetra
.667 .753 .915 r
.36057 .52753 .3697 .53626 .38462 .5311 .37555 .52236 Mtetra
.616 .739 .934 r
.37555 .52236 .38462 .5311 .39958 .52723 .39053 .51896 Mtetra
.455 .689 .967 r
.39053 .51896 .39958 .52723 .41453 .52642 .40548 .51925 Mtetra
.293 .639 .966 r
.40548 .51925 .41453 .52642 .4295 .52868 .4205 .52154 Mtetra
.506 .744 .981 r
.4205 .52154 .4295 .52868 .44468 .52872 .43576 .52029 Mtetra
.766 .787 .871 r
.43576 .52029 .44468 .52872 .46012 .52181 .45134 .51004 Mtetra
.804 .735 .788 r
.45134 .51004 .46012 .52181 .47573 .50827 .46706 .4941 Mtetra
.785 .701 .771 r
.46706 .4941 .47573 .50827 .49137 .49266 .48276 .47831 Mtetra
.718 .677 .81 r
.48276 .47831 .49137 .49266 .50698 .48064 .49839 .46894 Mtetra
.638 .69 .882 r
.49839 .46894 .50698 .48064 .5226 .47316 .51406 .46472 Mtetra
.583 .743 .953 r
.51406 .46472 .5226 .47316 .5383 .46785 .52983 .46198 Mtetra
.64 .833 .975 r
.52983 .46198 .5383 .46785 .55409 .46284 .54569 .45692 Mtetra
.712 .851 .949 r
.54569 .45692 .55409 .46284 .56997 .45813 .56162 .44953 Mtetra
.676 .775 .925 r
.56162 .44953 .56997 .45813 .58599 .4556 .57765 .44362 Mtetra
.542 .648 .903 r
.57765 .44362 .58599 .4556 .60224 .45767 .59387 .4429 Mtetra
.356 .497 .863 r
.59387 .4429 .60224 .45767 .61876 .46341 .6104 .4487 Mtetra
.349 .495 .864 r
.6104 .4487 .61876 .46341 .63541 .46711 .62714 .45471 Mtetra
.512 .629 .903 r
.62714 .45471 .63541 .46711 .65199 .46411 .64389 .45499 Mtetra
.735 .789 .895 r
.64389 .45499 .65199 .46411 .66838 .45403 .66041 .44612 Mtetra
.801 .83 .874 r
.66041 .44612 .66838 .45403 .68471 .44164 .67683 .4336 Mtetra
.769 .824 .895 r
.67683 .4336 .68471 .44164 .70123 .43235 .69337 .42308 Mtetra
.689 .775 .917 r
.69337 .42308 .70123 .43235 .71799 .4262 .71018 .41633 Mtetra
.645 .747 .923 r
.71018 .41633 .71799 .4262 .73494 .42135 .72719 .41139 Mtetra
.662 .753 .917 r
.72719 .41139 .73494 .42135 .75192 .41562 .74426 .40572 Mtetra
.664 .756 .919 r
.74426 .40572 .75192 .41562 .76902 .40995 .76142 .39994 Mtetra
.655 .751 .921 r
.76142 .39994 .76902 .40995 .78624 .40466 .77872 .39451 Mtetra
.646 .746 .922 r
.77872 .39451 .78624 .40466 .80359 .39954 .79614 .38939 Mtetra
.659 .753 .919 r
.79614 .38939 .80359 .39954 .821 .39388 .81363 .3837 Mtetra
.661 .754 .919 r
.81363 .3837 .821 .39388 .83852 .38816 .83122 .37791 Mtetra
.655 .752 .921 r
.83122 .37791 .83852 .38816 .85616 .38268 .84893 .37231 Mtetra
.65 .748 .921 r
.84893 .37231 .85616 .38268 .87393 .37731 .86678 .36691 Mtetra
.663 .753 .917 r
.23427 .55587 .24388 .56426 .25821 .5595 .24865 .55105 Mtetra
.656 .751 .92 r
.24865 .55105 .25821 .5595 .2726 .55492 .26308 .54645 Mtetra
.65 .75 .923 r
.26308 .54645 .2726 .55492 .28705 .55054 .27757 .54203 Mtetra
.653 .751 .922 r
.27757 .54203 .28705 .55054 .30158 .54607 .29216 .53747 Mtetra
.666 .754 .916 r
.29216 .53747 .30158 .54607 .31623 .54106 .30686 .53242 Mtetra
.656 .751 .92 r
.30686 .53242 .31623 .54106 .33094 .53636 .32162 .5277 Mtetra
.646 .749 .924 r
.32162 .5277 .33094 .53636 .34571 .53199 .33644 .52331 Mtetra
.651 .751 .923 r
.33644 .52331 .34571 .53199 .36057 .52753 .35135 .51871 Mtetra
.665 .753 .915 r
.35135 .51871 .36057 .52753 .37555 .52236 .36638 .51356 Mtetra
.606 .736 .937 r
.36638 .51356 .37555 .52236 .39053 .51896 .3814 .5104 Mtetra
.429 .672 .964 r
.3814 .5104 .39053 .51896 .40548 .51925 .39637 .51122 Mtetra
.333 .639 .964 r
.39637 .51122 .40548 .51925 .4205 .52154 .41142 .51338 Mtetra
.558 .74 .961 r
.41142 .51338 .4205 .52154 .43576 .52029 .42676 .51128 Mtetra
.786 .779 .847 r
.42676 .51128 .43576 .52029 .45134 .51004 .44245 .49925 Mtetra
.82 .753 .788 r
.44245 .49925 .45134 .51004 .46706 .4941 .45827 .4822 Mtetra
.795 .734 .796 r
.45827 .4822 .46706 .4941 .48276 .47831 .47403 .46725 Mtetra
.713 .729 .863 r
.47403 .46725 .48276 .47831 .49839 .46894 .48971 .45936 Mtetra
.554 .704 .94 r
.48971 .45936 .49839 .46894 .51406 .46472 .50541 .4577 Mtetra
.495 .748 .985 r
.50541 .4577 .51406 .46472 .52983 .46198 .52124 .45646 Mtetra
.635 .844 .98 r
.52124 .45646 .52983 .46198 .54569 .45692 .53718 .45135 Mtetra
.749 .868 .934 r
.53718 .45135 .54569 .45692 .56162 .44953 .55319 .44235 Mtetra
.739 .827 .919 r
.55319 .44235 .56162 .44953 .57765 .44362 .56925 .43376 Mtetra
.575 .711 .935 r
.56925 .43376 .57765 .44362 .59387 .4429 .58549 .43144 Mtetra
.314 .541 .912 r
.58549 .43144 .59387 .4429 .6104 .4487 .60203 .43628 Mtetra
.242 .478 .884 r
.60203 .43628 .6104 .4487 .62714 .45471 .61882 .4433 Mtetra
.437 .613 .924 r
.61882 .4433 .62714 .45471 .64389 .45499 .63568 .44528 Mtetra
.717 .773 .896 r
.63568 .44528 .64389 .45499 .66041 .44612 .65231 .43716 Mtetra
.793 .808 .864 r
.65231 .43716 .66041 .44612 .67683 .4336 .66882 .42466 Mtetra
.774 .807 .879 r
.66882 .42466 .67683 .4336 .69337 .42308 .68542 .41349 Mtetra
.695 .773 .911 r
.68542 .41349 .69337 .42308 .71018 .41633 .70228 .40639 Mtetra
.646 .748 .923 r
.70228 .40639 .71018 .41633 .72719 .41139 .71936 .40132 Mtetra
.66 .752 .918 r
.71936 .40132 .72719 .41139 .74426 .40572 .73651 .39568 Mtetra
.664 .756 .918 r
.73651 .39568 .74426 .40572 .76142 .39994 .75374 .38982 Mtetra
.656 .752 .921 r
.75374 .38982 .76142 .39994 .77872 .39451 .7711 .38429 Mtetra
.646 .747 .923 r
.7711 .38429 .77872 .39451 .79614 .38939 .7886 .3791 Mtetra
.658 .752 .919 r
.7886 .3791 .79614 .38939 .81363 .3837 .80617 .37339 Mtetra
.661 .754 .919 r
.80617 .37339 .81363 .3837 .83122 .37791 .82384 .36753 Mtetra
.656 .752 .92 r
.82384 .36753 .83122 .37791 .84893 .37231 .84163 .36185 Mtetra
.65 .748 .922 r
.84163 .36185 .84893 .37231 .86678 .36691 .85956 .35639 Mtetra
.663 .753 .917 r
.22456 .5474 .23427 .55587 .24865 .55105 .23898 .54253 Mtetra
.656 .751 .92 r
.23898 .54253 .24865 .55105 .26308 .54645 .25346 .53788 Mtetra
.65 .75 .923 r
.25346 .53788 .26308 .54645 .27757 .54203 .26801 .53341 Mtetra
.653 .751 .921 r
.26801 .53341 .27757 .54203 .29216 .53747 .28264 .52881 Mtetra
.666 .754 .916 r
.28264 .52881 .29216 .53747 .30686 .53242 .29739 .5237 Mtetra
.656 .751 .92 r
.29739 .5237 .30686 .53242 .32162 .5277 .3122 .51894 Mtetra
.646 .749 .924 r
.3122 .51894 .32162 .5277 .33644 .52331 .32707 .5145 Mtetra
.651 .75 .922 r
.32707 .5145 .33644 .52331 .35135 .51871 .34203 .50985 Mtetra
.665 .754 .916 r
.34203 .50985 .35135 .51871 .36638 .51356 .35711 .50465 Mtetra
.606 .736 .937 r
.35711 .50465 .36638 .51356 .3814 .5104 .37218 .50144 Mtetra
.437 .667 .959 r
.37218 .50144 .3814 .5104 .39637 .51122 .38718 .50223 Mtetra
.363 .631 .956 r
.38718 .50223 .39637 .51122 .41142 .51338 .40228 .50436 Mtetra
.566 .723 .947 r
.40228 .50436 .41142 .51338 .42676 .51128 .41766 .50221 Mtetra
.786 .78 .847 r
.41766 .50221 .42676 .51128 .44245 .49925 .43343 .49011 Mtetra
.834 .781 .801 r
.43343 .49011 .44245 .49925 .45827 .4822 .44934 .47297 Mtetra
.817 .781 .819 r
.44934 .47297 .45827 .4822 .47403 .46725 .46518 .45794 Mtetra
.721 .768 .89 r
.46518 .45794 .47403 .46725 .48971 .45936 .48093 .44999 Mtetra
.55 .711 .946 r
.48093 .44999 .48971 .45936 .50541 .4577 .49668 .44829 Mtetra
.534 .704 .948 r
.49668 .44829 .50541 .4577 .52124 .45646 .51256 .44701 Mtetra
.656 .751 .919 r
.51256 .44701 .52124 .45646 .53718 .45135 .52856 .44184 Mtetra
.739 .774 .881 r
.52856 .44184 .53718 .45135 .55319 .44235 .54464 .43278 Mtetra
.731 .772 .886 r
.54464 .43278 .55319 .44235 .56925 .43376 .56077 .42412 Mtetra
.572 .718 .941 r
.56077 .42412 .56925 .43376 .58549 .43144 .57707 .42175 Mtetra
.25 .55 .929 r
.57707 .42175 .58549 .43144 .60203 .43628 .59364 .42656 Mtetra
.127 .472 .894 r
.59364 .42656 .60203 .43628 .61882 .4433 .61048 .43355 Mtetra
.4 .636 .951 r
.61048 .43355 .61882 .4433 .63568 .44528 .62738 .43549 Mtetra
.717 .774 .897 r
.62738 .43549 .63568 .44528 .65231 .43716 .64408 .42731 Mtetra
.788 .791 .855 r
.64408 .42731 .65231 .43716 .66882 .42466 .66068 .41473 Mtetra
.769 .787 .868 r
.66068 .41473 .66882 .42466 .68542 .41349 .67736 .40349 Mtetra
.695 .765 .906 r
.67736 .40349 .68542 .41349 .70228 .40639 .6943 .39632 Mtetra
.646 .748 .923 r
.6943 .39632 .70228 .40639 .71936 .40132 .71145 .39119 Mtetra
.66 .753 .919 r
.71145 .39119 .71936 .40132 .73651 .39568 .72866 .38549 Mtetra
.664 .755 .918 r
.72866 .38549 .73651 .39568 .75374 .38982 .74597 .37956 Mtetra
.656 .751 .92 r
.74597 .37956 .75374 .38982 .7711 .38429 .76341 .37397 Mtetra
.646 .747 .923 r
.76341 .37397 .7711 .38429 .7886 .3791 .78098 .36873 Mtetra
.658 .752 .92 r
.78098 .36873 .7886 .3791 .80617 .37339 .79863 .36295 Mtetra
.661 .754 .919 r
.79863 .36295 .80617 .37339 .82384 .36753 .81637 .35702 Mtetra
.656 .751 .92 r
.81637 .35702 .82384 .36753 .84163 .36185 .83424 .35128 Mtetra
.65 .749 .922 r
.83424 .35128 .84163 .36185 .85956 .35639 .85225 .34576 Mtetra
.662 .753 .918 r
.21475 .53884 .22456 .5474 .23898 .54253 .22922 .53393 Mtetra
.656 .752 .92 r
.22922 .53393 .23898 .54253 .25346 .53788 .24375 .52921 Mtetra
.65 .75 .922 r
.24375 .52921 .25346 .53788 .26801 .53341 .25834 .5247 Mtetra
.652 .75 .922 r
.25834 .5247 .26801 .53341 .28264 .52881 .27302 .52008 Mtetra
.666 .754 .916 r
.27302 .52008 .28264 .52881 .29739 .5237 .28782 .51492 Mtetra
.657 .752 .92 r
.28782 .51492 .29739 .5237 .3122 .51894 .30268 .51007 Mtetra
.647 .749 .924 r
.30268 .51007 .3122 .51894 .32707 .5145 .3176 .50556 Mtetra
.649 .749 .922 r
.3176 .50556 .32707 .5145 .34203 .50985 .33261 .50095 Mtetra
.667 .756 .917 r
.33261 .50095 .34203 .50985 .35711 .50465 .34775 .49563 Mtetra
.616 .739 .934 r
.34775 .49563 .35711 .50465 .37218 .50144 .36288 .49208 Mtetra
.472 .675 .953 r
.36288 .49208 .37218 .50144 .38718 .50223 .37794 .49226 Mtetra
.383 .618 .944 r
.37794 .49226 .38718 .50223 .40228 .50436 .39306 .49445 Mtetra
.543 .695 .938 r
.39306 .49445 .40228 .50436 .41766 .50221 .40846 .49307 Mtetra
.763 .778 .865 r
.40846 .49307 .41766 .50221 .43343 .49011 .42425 .48262 Mtetra
.84 .814 .824 r
.42425 .48262 .43343 .49011 .44934 .47297 .44024 .46644 Mtetra
.847 .835 .834 r
.44024 .46644 .44934 .47297 .46518 .45794 .4562 .45041 Mtetra
.757 .816 .899 r
.4562 .45041 .46518 .45794 .48093 .44999 .47205 .44085 Mtetra
.635 .75 .931 r
.47205 .44085 .48093 .44999 .49668 .44829 .48788 .43647 Mtetra
.599 .68 .898 r
.48788 .43647 .49668 .44829 .51256 .44701 .50381 .43358 Mtetra
.652 .674 .858 r
.50381 .43358 .51256 .44701 .52856 .44184 .51985 .42836 Mtetra
.694 .69 .842 r
.51985 .42836 .52856 .44184 .54464 .43278 .53599 .42079 Mtetra
.672 .708 .875 r
.53599 .42079 .54464 .43278 .56077 .42412 .5522 .4147 Mtetra
.512 .699 .954 r
.5522 .4147 .56077 .42412 .57707 .42175 .56858 .41384 Mtetra
.102 .507 .906 r
.56858 .41384 .57707 .42175 .59364 .42656 .58522 .41955 Mtetra
.038 .487 .884 r
.58522 .41955 .59364 .42656 .61048 .43355 .60208 .42548 Mtetra
.437 .703 .978 r
.60208 .42548 .61048 .43355 .62738 .43549 .61898 .42563 Mtetra
.733 .779 .889 r
.61898 .42563 .62738 .43549 .64408 .42731 .63574 .41654 Mtetra
.783 .774 .845 r
.63574 .41654 .64408 .42731 .66068 .41473 .65241 .40379 Mtetra
.755 .766 .862 r
.65241 .40379 .66068 .41473 .67736 .40349 .6692 .39306 Mtetra
.688 .756 .904 r
.6692 .39306 .67736 .40349 .6943 .39632 .68623 .38612 Mtetra
.645 .747 .923 r
.68623 .38612 .6943 .39632 .71145 .39119 .70345 .381 Mtetra
.662 .755 .919 r
.70345 .381 .71145 .39119 .72866 .38549 .72073 .37515 Mtetra
.664 .754 .917 r
.72073 .37515 .72866 .38549 .74597 .37956 .73812 .36918 Mtetra
.655 .751 .92 r
.73812 .36918 .74597 .37956 .76341 .37397 .75563 .36356 Mtetra
.646 .748 .923 r
.75563 .36356 .76341 .37397 .78098 .36873 .77328 .35825 Mtetra
.659 .753 .92 r
.77328 .35825 .78098 .36873 .79863 .36295 .791 .35237 Mtetra
.661 .753 .918 r
.791 .35237 .79863 .36295 .81637 .35702 .80882 .34638 Mtetra
.655 .751 .92 r
.80882 .34638 .81637 .35702 .83424 .35128 .82677 .3406 Mtetra
.65 .749 .922 r
.82677 .3406 .83424 .35128 .85225 .34576 .84485 .335 Mtetra
.662 .753 .918 r
.20484 .53019 .21475 .53884 .22922 .53393 .21935 .52526 Mtetra
.657 .752 .92 r
.21935 .52526 .22922 .53393 .24375 .52921 .23393 .52045 Mtetra
.65 .75 .922 r
.23393 .52045 .24375 .52921 .25834 .5247 .24857 .51587 Mtetra
.651 .75 .922 r
.24857 .51587 .25834 .5247 .27302 .52008 .2633 .51124 Mtetra
.665 .754 .917 r
.2633 .51124 .27302 .52008 .28782 .51492 .27815 .50608 Mtetra
.659 .753 .92 r
.27815 .50608 .28782 .51492 .30268 .51007 .29307 .5011 Mtetra
.648 .749 .923 r
.29307 .5011 .30268 .51007 .3176 .50556 .30804 .49649 Mtetra
.646 .747 .923 r
.30804 .49649 .3176 .50556 .33261 .50095 .32309 .49195 Mtetra
.668 .756 .916 r
.32309 .49195 .33261 .50095 .34775 .49563 .33829 .48654 Mtetra
.632 .745 .929 r
.33829 .48654 .34775 .49563 .36288 .49208 .35349 .48243 Mtetra
.525 .693 .945 r
.35349 .48243 .36288 .49208 .37794 .49226 .36865 .48142 Mtetra
.404 .61 .933 r
.36865 .48142 .37794 .49226 .39306 .49445 .38379 .48351 Mtetra
.505 .657 .928 r
.38379 .48351 .39306 .49445 .40846 .49307 .39918 .48335 Mtetra
.704 .756 .893 r
.39918 .48335 .40846 .49307 .42425 .48262 .41494 .47615 Mtetra
.825 .84 .859 r
.41494 .47615 .42425 .48262 .44024 .46644 .43095 .46223 Mtetra
.862 .886 .852 r
.43095 .46223 .44024 .46644 .4562 .45041 .44703 .44622 Mtetra
.816 .9 .9 r
.44703 .44622 .4562 .45041 .47205 .44085 .46303 .43385 Mtetra
.72 .827 .931 r
.46303 .43385 .47205 .44085 .48788 .43647 .47898 .42606 Mtetra
.665 .735 .903 r
.47898 .42606 .48788 .43647 .50381 .43358 .49498 .42048 Mtetra
.653 .682 .864 r
.49498 .42048 .50381 .43358 .51985 .42836 .51107 .41519 Mtetra
.646 .679 .867 r
.51107 .41519 .51985 .42836 .53599 .42079 .52725 .4102 Mtetra
.587 .706 .925 r
.52725 .4102 .53599 .42079 .5522 .4147 .54355 .40743 Mtetra
.313 .658 .972 r
.54355 .40743 .5522 .4147 .56858 .41384 .56002 .40931 Mtetra
0 .434 .787 r
.56002 .40931 .56858 .41384 .58522 .41955 .57672 .4149 Mtetra
.055 .561 .882 r
.57672 .4149 .58522 .41955 .60208 .42548 .5936 .41842 Mtetra
.565 .792 .984 r
.5936 .41842 .60208 .42548 .61898 .42563 .61049 .41515 Mtetra
.752 .773 .87 r
.61049 .41515 .61898 .42563 .63574 .41654 .62727 .40472 Mtetra
.776 .756 .835 r
.62727 .40472 .63574 .41654 .65241 .40379 .64402 .39194 Mtetra
.732 .744 .862 r
.64402 .39194 .65241 .40379 .6692 .39306 .66094 .3823 Mtetra
.676 .748 .905 r
.66094 .3823 .6692 .39306 .68623 .38612 .67806 .37584 Mtetra
.644 .747 .924 r
.67806 .37584 .68623 .38612 .70345 .381 .69535 .37069 Mtetra
.665 .756 .918 r
.69535 .37069 .70345 .381 .72073 .37515 .71271 .36465 Mtetra
.663 .752 .917 r
.71271 .36465 .72073 .37515 .73812 .36918 .73017 .35867 Mtetra
.653 .75 .921 r
.73017 .35867 .73812 .36918 .75563 .36356 .74776 .35306 Mtetra
.647 .749 .924 r
.74776 .35306 .75563 .36356 .77328 .35825 .76549 .34764 Mtetra
.66 .753 .919 r
.76549 .34764 .77328 .35825 .791 .35237 .78328 .34166 Mtetra
.661 .753 .918 r
.78328 .34166 .791 .35237 .80882 .34638 .80118 .33562 Mtetra
.654 .75 .92 r
.80118 .33562 .80882 .34638 .82677 .3406 .81921 .32981 Mtetra
.65 .75 .922 r
.81921 .32981 .82677 .3406 .84485 .335 .83738 .32412 Mtetra
.66 .752 .918 r
.19483 .52145 .20484 .53019 .21935 .52526 .20939 .51651 Mtetra
.659 .753 .92 r
.20939 .51651 .21935 .52526 .23393 .52045 .22402 .51159 Mtetra
.651 .75 .922 r
.22402 .51159 .23393 .52045 .24857 .51587 .23871 .50694 Mtetra
.65 .749 .922 r
.23871 .50694 .24857 .51587 .2633 .51124 .25348 .50229 Mtetra
.662 .753 .917 r
.25348 .50229 .2633 .51124 .27815 .50608 .26837 .49717 Mtetra
.662 .755 .919 r
.26837 .49717 .27815 .50608 .29307 .5011 .28335 .49204 Mtetra
.65 .749 .922 r
.28335 .49204 .29307 .5011 .30804 .49649 .29838 .4873 Mtetra
.645 .746 .923 r
.29838 .4873 .30804 .49649 .32309 .49195 .31348 .48274 Mtetra
.664 .752 .916 r
.31348 .48274 .32309 .49195 .33829 .48654 .32872 .47745 Mtetra
.65 .752 .924 r
.32872 .47745 .33829 .48654 .35349 .48243 .34401 .47265 Mtetra
.581 .715 .935 r
.34401 .47265 .35349 .48243 .36865 .48142 .35928 .47012 Mtetra
.445 .622 .927 r
.35928 .47012 .36865 .48142 .38379 .48351 .37448 .47142 Mtetra
.473 .62 .914 r
.37448 .47142 .38379 .48351 .39918 .48335 .38985 .47233 Mtetra
.6 .698 .912 r
.38985 .47233 .39918 .48335 .41494 .47615 .40551 .46929 Mtetra
.776 .835 .897 r
.40551 .46929 .41494 .47615 .43095 .46223 .42152 .4587 Mtetra
.836 .911 .888 r
.42152 .4587 .43095 .46223 .44703 .44622 .43765 .445 Mtetra
.83 .963 .894 r
.43765 .445 .44703 .44622 .46303 .43385 .45379 .4314 Mtetra
.772 .945 .935 r
.45379 .4314 .46303 .43385 .47898 .42606 .46989 .42079 Mtetra
.696 .871 .964 r
.46989 .42079 .47898 .42606 .49498 .42048 .486 .4136 Mtetra
.647 .818 .965 r
.486 .4136 .49498 .42048 .51107 .41519 .50216 .40826 Mtetra
.578 .795 .982 r
.50216 .40826 .51107 .41519 .52725 .4102 .51842 .40477 Mtetra
.351 .732 .986 r
.51842 .40477 .52725 .4102 .54355 .40743 .5348 .40474 Mtetra
0 .517 .781 r
.5348 .40474 .54355 .40743 .56002 .40931 .55137 .40775 Mtetra
.136 0 0 r
.55137 .40775 .56002 .40931 .57672 .4149 .56812 .41091 Mtetra
.267 .721 .955 r
.56812 .41091 .57672 .4149 .5936 .41842 .585 .41096 Mtetra
.705 .83 .942 r
.585 .41096 .5936 .41842 .61049 .41515 .60187 .40335 Mtetra
.761 .753 .845 r
.60187 .40335 .61049 .41515 .62727 .40472 .61869 .3917 Mtetra
.759 .734 .829 r
.61869 .3917 .62727 .40472 .64402 .39194 .63554 .37961 Mtetra
.705 .729 .869 r
.63554 .37961 .64402 .39194 .66094 .3823 .65258 .37141 Mtetra
.661 .742 .91 r
.65258 .37141 .66094 .3823 .67806 .37584 .66981 .36553 Mtetra
.648 .751 .924 r
.66981 .36553 .67806 .37584 .69535 .37069 .68716 .36014 Mtetra
.666 .754 .916 r
.68716 .36014 .69535 .37069 .71271 .36465 .70459 .354 Mtetra
.661 .751 .917 r
.70459 .354 .71271 .36465 .73017 .35867 .72213 .34804 Mtetra
.65 .749 .922 r
.72213 .34804 .73017 .35867 .74776 .35306 .73981 .34248 Mtetra
.65 .751 .923 r
.73981 .34248 .74776 .35306 .76549 .34764 .7576 .33689 Mtetra
.661 .753 .919 r
.7576 .33689 .76549 .34764 .78328 .34166 .77547 .33081 Mtetra
.66 .752 .918 r
.77547 .33081 .78328 .34166 .80118 .33562 .79345 .32472 Mtetra
.653 .75 .921 r
.79345 .32472 .80118 .33562 .81921 .32981 .81157 .31891 Mtetra
.652 .751 .922 r
.81157 .31891 .81921 .32981 .83738 .32412 .82981 .31311 Mtetra
.659 .752 .919 r
.18471 .51262 .19483 .52145 .20939 .51651 .19931 .50769 Mtetra
.661 .754 .919 r
.19931 .50769 .20939 .51651 .22402 .51159 .214 .50265 Mtetra
.652 .75 .922 r
.214 .50265 .22402 .51159 .23871 .50694 .22874 .49791 Mtetra
.65 .749 .922 r
.22874 .49791 .23871 .50694 .25348 .50229 .24356 .49322 Mtetra
.658 .751 .919 r
.24356 .49322 .25348 .50229 .26837 .49717 .25849 .4882 Mtetra
.665 .756 .918 r
.25849 .4882 .26837 .49717 .28335 .49204 .27353 .4829 Mtetra
.653 .75 .921 r
.27353 .4829 .28335 .49204 .29838 .4873 .28861 .47802 Mtetra
.646 .747 .923 r
.28861 .47802 .29838 .4873 .31348 .48274 .30377 .47337 Mtetra
.655 .748 .919 r
.30377 .47337 .31348 .48274 .32872 .47745 .31904 .46837 Mtetra
.664 .758 .92 r
.31904 .46837 .32872 .47745 .34401 .47265 .33442 .46298 Mtetra
.617 .732 .928 r
.33442 .46298 .34401 .47265 .35928 .47012 .34979 .45924 Mtetra
.524 .67 .929 r
.34979 .45924 .35928 .47012 .37448 .47142 .36513 .45842 Mtetra
.47 .602 .901 r
.36513 .45842 .37448 .47142 .38985 .47233 .3805 .45961 Mtetra
.534 .639 .9 r
.3805 .45961 .38985 .47233 .40551 .46929 .3961 .45889 Mtetra
.648 .732 .911 r
.3961 .45889 .40551 .46929 .42152 .4587 .41199 .45396 Mtetra
.77 .89 .93 r
.41199 .45396 .42152 .4587 .43765 .445 .42812 .44386 Mtetra
.772 .968 .924 r
.42812 .44386 .43765 .445 .45379 .4314 .44432 .43259 Mtetra
.683 .978 .885 r
.44432 .43259 .45379 .4314 .46989 .42079 .46055 .42202 Mtetra
.552 .932 .871 r
.46055 .42202 .46989 .42079 .486 .4136 .47679 .41384 Mtetra
.421 .866 .881 r
.47679 .41384 .486 .4136 .50216 .40826 .49307 .40845 Mtetra
.2 .729 .802 r
.49307 .40845 .50216 .40826 .51842 .40477 .50943 .40587 Mtetra
.06 0 0 r
.50943 .40587 .51842 .40477 .5348 .40474 .52592 .40571 Mtetra
.107 0 0 r
.52592 .40571 .5348 .40474 .55137 .40775 .54257 .40628 Mtetra
.149 .685 .846 r
.54257 .40628 .55137 .40775 .56812 .41091 .55937 .40571 Mtetra
.631 .868 .987 r
.55937 .40571 .56812 .41091 .585 .41096 .57624 .3999 Mtetra
.743 .763 .869 r
.57624 .3999 .585 .41096 .60187 .40335 .59312 .38981 Mtetra
.755 .725 .825 r
.59312 .38981 .60187 .40335 .61869 .3917 .61001 .37775 Mtetra
.726 .71 .836 r
.61001 .37775 .61869 .3917 .63554 .37961 .62699 .3677 Mtetra
.685 .731 .886 r
.62699 .3677 .63554 .37961 .65258 .37141 .64415 .36061 Mtetra
.648 .741 .917 r
.64415 .36061 .65258 .37141 .66981 .36553 .66147 .35521 Mtetra
.657 .757 .923 r
.66147 .35521 .66981 .36553 .68716 .36014 .67888 .34942 Mtetra
.665 .752 .915 r
.67888 .34942 .68716 .36014 .70459 .354 .69638 .34325 Mtetra
.659 .75 .918 r
.69638 .34325 .70459 .354 .72213 .34804 .714 .3373 Mtetra
.647 .748 .923 r
.714 .3373 .72213 .34804 .73981 .34248 .73176 .33179 Mtetra
.653 .753 .923 r
.73176 .33179 .73981 .34248 .7576 .33689 .74962 .32599 Mtetra
.661 .753 .918 r
.74962 .32599 .7576 .33689 .77547 .33081 .76757 .31982 Mtetra
.659 .752 .918 r
.76757 .31982 .77547 .33081 .79345 .32472 .78563 .31371 Mtetra
.651 .749 .921 r
.78563 .31371 .79345 .32472 .81157 .31891 .80384 .3079 Mtetra
.653 .752 .922 r
.80384 .3079 .81157 .31891 .82981 .31311 .82216 .30196 Mtetra
.656 .751 .92 r
.17449 .50368 .18471 .51262 .19931 .50769 .18913 .49878 Mtetra
.662 .754 .919 r
.18913 .49878 .19931 .50769 .214 .50265 .20387 .49364 Mtetra
.654 .751 .921 r
.20387 .49364 .214 .50265 .22874 .49791 .21867 .48877 Mtetra
.65 .749 .922 r
.21867 .48877 .22874 .49791 .24356 .49322 .23354 .48403 Mtetra
.653 .749 .92 r
.23354 .48403 .24356 .49322 .25849 .4882 .2485 .47913 Mtetra
.665 .756 .918 r
.2485 .47913 .25849 .4882 .27353 .4829 .26359 .47376 Mtetra
.657 .754 .921 r
.26359 .47376 .27353 .4829 .28861 .47802 .27874 .46866 Mtetra
.649 .748 .922 r
.27874 .46866 .28861 .47802 .30377 .47337 .29396 .46386 Mtetra
.646 .745 .921 r
.29396 .46386 .30377 .47337 .31904 .46837 .30926 .45911 Mtetra
.666 .757 .918 r
.30926 .45911 .31904 .46837 .33442 .46298 .3247 .45359 Mtetra
.648 .751 .924 r
.3247 .45359 .33442 .46298 .34979 .45924 .34019 .4487 Mtetra
.598 .709 .922 r
.34019 .4487 .34979 .45924 .36513 .45842 .35567 .4456 Mtetra
.515 .629 .902 r
.35567 .4456 .36513 .45842 .3805 .45961 .37113 .44541 Mtetra
.509 .602 .882 r
.37113 .44541 .3805 .45961 .3961 .45889 .38671 .44568 Mtetra
.563 .646 .89 r
.38671 .44568 .3961 .45889 .41199 .45396 .40251 .444 Mtetra
.631 .739 .926 r
.40251 .444 .41199 .45396 .42812 .44386 .41853 .43958 Mtetra
.708 .898 .965 r
.41853 .43958 .42812 .44386 .44432 .43259 .43475 .43167 Mtetra
.652 .953 .947 r
.43475 .43167 .44432 .43259 .46055 .42202 .45104 .42341 Mtetra
.476 .896 .85 r
.45104 .42341 .46055 .42202 .47679 .41384 .46739 .41623 Mtetra
.274 .772 .731 r
.46739 .41623 .47679 .41384 .49307 .40845 .48379 .4108 Mtetra
0 0 0 r
.48379 .4108 .49307 .40845 .50943 .40587 .50028 .40713 Mtetra
.12 .669 .713 r
.50028 .40713 .50943 .40587 .52592 .40571 .51688 .40455 Mtetra
.31 .794 .898 r
.51688 .40455 .52592 .40571 .54257 .40628 .53362 .40164 Mtetra
.646 .886 .984 r
.53362 .40164 .54257 .40628 .55937 .40571 .55046 .3952 Mtetra
.731 .771 .885 r
.55046 .3952 .55937 .40571 .57624 .3999 .56735 .38598 Mtetra
.742 .716 .828 r
.56735 .38598 .57624 .3999 .59312 .38981 .58427 .37475 Mtetra
.729 .697 .82 r
.58427 .37475 .59312 .38981 .61001 .37775 .60125 .36396 Mtetra
.692 .702 .855 r
.60125 .36396 .61001 .37775 .62699 .3677 .61837 .35611 Mtetra
.662 .731 .901 r
.61837 .35611 .62699 .3677 .64415 .36061 .63563 .35009 Mtetra
.646 .749 .924 r
.63563 .35009 .64415 .36061 .66147 .35521 .65303 .3447 Mtetra
.665 .758 .92 r
.65303 .3447 .66147 .35521 .67888 .34942 .6705 .33852 Mtetra
.662 .75 .915 r
.6705 .33852 .67888 .34942 .69638 .34325 .68808 .33238 Mtetra
.654 .749 .919 r
.68808 .33238 .69638 .34325 .714 .3373 .70579 .32655 Mtetra
.647 .75 .925 r
.70579 .32655 .714 .3373 .73176 .33179 .72363 .32099 Mtetra
.658 .755 .922 r
.72363 .32099 .73176 .33179 .74962 .32599 .74155 .31493 Mtetra
.661 .752 .918 r
.74155 .31493 .74962 .32599 .76757 .31982 .75958 .30871 Mtetra
.657 .751 .919 r
.75958 .30871 .76757 .31982 .78563 .31371 .77773 .3026 Mtetra
.65 .749 .922 r
.77773 .3026 .78563 .31371 .80384 .3079 .79602 .29677 Mtetra
.655 .753 .922 r
.79602 .29677 .80384 .3079 .82216 .30196 .81441 .29067 Mtetra
.654 .75 .92 r
.16416 .49463 .17449 .50368 .18913 .49878 .17884 .48976 Mtetra
.662 .754 .919 r
.17884 .48976 .18913 .49878 .20387 .49364 .19363 .4846 Mtetra
.658 .754 .921 r
.19363 .4846 .20387 .49364 .21867 .48877 .20849 .47955 Mtetra
.651 .749 .921 r
.20849 .47955 .21867 .48877 .23354 .48403 .22341 .47472 Mtetra
.651 .748 .921 r
.22341 .47472 .23354 .48403 .2485 .47913 .23842 .46987 Mtetra
.661 .753 .918 r
.23842 .46987 .2485 .47913 .26359 .47376 .25355 .46459 Mtetra
.663 .757 .92 r
.25355 .46459 .26359 .47376 .27874 .46866 .26877 .45924 Mtetra
.652 .75 .921 r
.26877 .45924 .27874 .46866 .29396 .46386 .28404 .45424 Mtetra
.646 .745 .921 r
.28404 .45424 .29396 .46386 .30926 .45911 .2994 .44944 Mtetra
.653 .747 .918 r
.2994 .44944 .30926 .45911 .3247 .45359 .31486 .44435 Mtetra
.666 .761 .921 r
.31486 .44435 .3247 .45359 .34019 .4487 .33044 .43875 Mtetra
.638 .738 .921 r
.33044 .43875 .34019 .4487 .35567 .4456 .34605 .43417 Mtetra
.597 .694 .911 r
.34605 .43417 .35567 .4456 .37113 .44541 .36169 .4311 Mtetra
.537 .616 .878 r
.36169 .4311 .37113 .44541 .38671 .44568 .37733 .43041 Mtetra
.54 .603 .865 r
.37733 .43041 .38671 .44568 .40251 .444 .39311 .42971 Mtetra
.574 .635 .874 r
.39311 .42971 .40251 .444 .41853 .43958 .40907 .42763 Mtetra
.613 .695 .902 r
.40907 .42763 .41853 .43958 .43475 .43167 .42522 .42392 Mtetra
.634 .798 .961 r
.42522 .42392 .43475 .43167 .45104 .42341 .44151 .41897 Mtetra
.612 .876 .991 r
.44151 .41897 .45104 .42341 .46739 .41623 .45792 .41349 Mtetra
.564 .897 .982 r
.45792 .41349 .46739 .41623 .48379 .4108 .47442 .408 Mtetra
.562 .897 .982 r
.47442 .408 .48379 .4108 .50028 .40713 .49102 .40252 Mtetra
.63 .881 .987 r
.49102 .40252 .50028 .40713 .51688 .40455 .50773 .39651 Mtetra
.695 .815 .939 r
.50773 .39651 .51688 .40455 .53362 .40164 .52454 .38924 Mtetra
.717 .732 .863 r
.52454 .38924 .53362 .40164 .55046 .3952 .54142 .38031 Mtetra
.724 .697 .824 r
.54142 .38031 .55046 .3952 .56735 .38598 .55836 .36996 Mtetra
.718 .681 .813 r
.55836 .36996 .56735 .38598 .58427 .37475 .57535 .35958 Mtetra
.688 .681 .838 r
.57535 .35958 .58427 .37475 .60125 .36396 .59245 .35158 Mtetra
.669 .72 .887 r
.59245 .35158 .60125 .36396 .61837 .35611 .60967 .34512 Mtetra
.646 .74 .918 r
.60967 .34512 .61837 .35611 .63563 .35009 .62702 .3397 Mtetra
.658 .759 .925 r
.62702 .3397 .63563 .35009 .65303 .3447 .64447 .33375 Mtetra
.664 .751 .915 r
.64447 .33375 .65303 .3447 .6705 .33852 .66202 .3275 Mtetra
.659 .749 .916 r
.66202 .3275 .6705 .33852 .68808 .33238 .67968 .32143 Mtetra
.649 .748 .922 r
.67968 .32143 .68808 .33238 .70579 .32655 .69748 .31574 Mtetra
.65 .753 .925 r
.69748 .31574 .70579 .32655 .72363 .32099 .71539 .30996 Mtetra
.66 .753 .919 r
.71539 .30996 .72363 .32099 .74155 .31493 .73338 .30372 Mtetra
.66 .751 .918 r
.73338 .30372 .74155 .31493 .75958 .30871 .75149 .29746 Mtetra
.654 .75 .92 r
.75149 .29746 .75958 .30871 .77773 .3026 .76973 .29142 Mtetra
.65 .751 .923 r
.76973 .29142 .77773 .3026 .79602 .29677 .7881 .28549 Mtetra
.657 .753 .921 r
.7881 .28549 .79602 .29677 .81441 .29067 .80657 .27923 Mtetra
.653 .75 .921 r
.15373 .48547 .16416 .49463 .17884 .48976 .16845 .4806 Mtetra
.659 .752 .919 r
.16845 .4806 .17884 .48976 .19363 .4846 .18328 .47548 Mtetra
.661 .755 .92 r
.18328 .47548 .19363 .4846 .20849 .47955 .1982 .47025 Mtetra
.653 .75 .921 r
.1982 .47025 .20849 .47955 .22341 .47472 .21317 .4653 Mtetra
.65 .748 .921 r
.21317 .4653 .22341 .47472 .23842 .46987 .22823 .46042 Mtetra
.655 .75 .92 r
.22823 .46042 .23842 .46987 .25355 .46459 .24339 .45534 Mtetra
.665 .758 .919 r
.24339 .45534 .25355 .46459 .26877 .45924 .25867 .44985 Mtetra
.658 .754 .921 r
.25867 .44985 .26877 .45924 .28404 .45424 .27402 .44459 Mtetra
.65 .747 .921 r
.27402 .44459 .28404 .45424 .2994 .44944 .28943 .43959 Mtetra
.647 .743 .92 r
.28943 .43959 .2994 .44944 .31486 .44435 .30493 .4347 Mtetra
.659 .752 .919 r
.30493 .4347 .31486 .44435 .33044 .43875 .32055 .42931 Mtetra
.663 .759 .922 r
.32055 .42931 .33044 .43875 .34605 .43417 .33628 .42373 Mtetra
.638 .731 .916 r
.33628 .42373 .34605 .43417 .36169 .4311 .35204 .41907 Mtetra
.61 .69 .9 r
.35204 .41907 .36169 .4311 .37733 .43041 .36785 .41548 Mtetra
.574 .626 .865 r
.36785 .41548 .37733 .43041 .39311 .42971 .38371 .41339 Mtetra
.569 .604 .848 r
.38371 .41339 .39311 .42971 .40907 .42763 .39968 .41158 Mtetra
.588 .617 .849 r
.39968 .41158 .40907 .42763 .42522 .42392 .41581 .40893 Mtetra
.611 .645 .859 r
.41581 .40893 .42522 .42392 .44151 .41897 .4321 .4052 Mtetra
.633 .675 .872 r
.4321 .4052 .44151 .41897 .45792 .41349 .44853 .40049 Mtetra
.652 .696 .878 r
.44853 .40049 .45792 .41349 .47442 .408 .46509 .39494 Mtetra
.669 .702 .872 r
.46509 .39494 .47442 .408 .49102 .40252 .48175 .38856 Mtetra
.683 .694 .854 r
.48175 .38856 .49102 .40252 .50773 .39651 .49852 .38118 Mtetra
.695 .68 .831 r
.49852 .38118 .50773 .39651 .52454 .38924 .51537 .3727 Mtetra
.702 .668 .814 r
.51537 .3727 .52454 .38924 .54142 .38031 .5323 .36336 Mtetra
.696 .661 .812 r
.5323 .36336 .54142 .38031 .55836 .36996 .5493 .35427 Mtetra
.679 .671 .835 r
.5493 .35427 .55836 .36996 .57535 .35958 .56638 .34669 Mtetra
.668 .712 .881 r
.56638 .34669 .57535 .35958 .59245 .35158 .58357 .3402 Mtetra
.649 .735 .912 r
.58357 .3402 .59245 .35158 .60967 .34512 .60089 .33463 Mtetra
.653 .756 .926 r
.60089 .33463 .60967 .34512 .62702 .3397 .61831 .32887 Mtetra
.664 .755 .917 r
.61831 .32887 .62702 .3397 .64447 .33375 .63582 .32259 Mtetra
.661 .748 .915 r
.63582 .32259 .64447 .33375 .66202 .3275 .65345 .31642 Mtetra
.654 .748 .919 r
.65345 .31642 .66202 .3275 .67968 .32143 .6712 .3105 Mtetra
.647 .75 .924 r
.6712 .3105 .67968 .32143 .69748 .31574 .68907 .30482 Mtetra
.657 .756 .923 r
.68907 .30482 .69748 .31574 .71539 .30996 .70704 .29871 Mtetra
.661 .752 .918 r
.70704 .29871 .71539 .30996 .73338 .30372 .72512 .29238 Mtetra
.659 .751 .918 r
.72512 .29238 .73338 .30372 .75149 .29746 .74331 .28611 Mtetra
.651 .749 .921 r
.74331 .28611 .75149 .29746 .76973 .29142 .76164 .28013 Mtetra
.653 .752 .923 r
.76164 .28013 .76973 .29142 .7881 .28549 .78009 .27402 Mtetra
.658 .752 .919 r
.78009 .27402 .7881 .28549 .80657 .27923 .79864 .26764 Mtetra
.652 .749 .921 r
.14319 .47619 .15373 .48547 .16845 .4806 .15795 .4713 Mtetra
.655 .751 .92 r
.15795 .4713 .16845 .4806 .18328 .47548 .17281 .46627 Mtetra
.662 .755 .919 r
.17281 .46627 .18328 .47548 .1982 .47025 .18779 .46095 Mtetra
.657 .753 .921 r
.18779 .46095 .1982 .47025 .21317 .4653 .20283 .4558 Mtetra
.651 .748 .921 r
.20283 .4558 .21317 .4653 .22823 .46042 .21794 .45082 Mtetra
.651 .748 .92 r
.21794 .45082 .22823 .46042 .24339 .45534 .23314 .44583 Mtetra
.66 .753 .919 r
.23314 .44583 .24339 .45534 .25867 .44985 .24845 .44047 Mtetra
.664 .758 .92 r
.24845 .44047 .25867 .44985 .27402 .44459 .26387 .43492 Mtetra
.654 .75 .921 r
.26387 .43492 .27402 .44459 .28943 .43959 .27935 .42971 Mtetra
.649 .746 .92 r
.27935 .42971 .28943 .43959 .30493 .4347 .29491 .42466 Mtetra
.648 .743 .919 r
.29491 .42466 .30493 .4347 .32055 .42931 .31056 .41964 Mtetra
.66 .756 .921 r
.31056 .41964 .32055 .42931 .33628 .42373 .32634 .41413 Mtetra
.663 .759 .922 r
.32634 .41413 .33628 .42373 .35204 .41907 .34221 .40846 Mtetra
.647 .734 .913 r
.34221 .40846 .35204 .41907 .36785 .41548 .35814 .40337 Mtetra
.629 .7 .896 r
.35814 .40337 .36785 .41548 .38371 .41339 .37415 .39897 Mtetra
.617 .656 .865 r
.37415 .39897 .38371 .41339 .39968 .41158 .39023 .39498 Mtetra
.604 .619 .84 r
.39023 .39498 .39968 .41158 .41581 .40893 .40642 .39151 Mtetra
.61 .612 .828 r
.40642 .39151 .41581 .40893 .4321 .4052 .42273 .38766 Mtetra
.625 .619 .824 r
.42273 .38766 .4321 .4052 .44853 .40049 .43918 .38297 Mtetra
.641 .628 .821 r
.43918 .38297 .44853 .40049 .46509 .39494 .45576 .37736 Mtetra
.656 .634 .816 r
.45576 .37736 .46509 .39494 .48175 .38856 .47246 .3708 Mtetra
.668 .639 .811 r
.47246 .3708 .48175 .38856 .49852 .38118 .48926 .3634 Mtetra
.674 .642 .81 r
.48926 .3634 .49852 .38118 .51537 .3727 .50614 .3556 Mtetra
.669 .648 .821 r
.50614 .3556 .51537 .3727 .5323 .36336 .52311 .34832 Mtetra
.669 .677 .849 r
.52311 .34832 .5323 .36336 .5493 .35427 .54017 .34145 Mtetra
.661 .711 .885 r
.54017 .34145 .5493 .35427 .56638 .34669 .55734 .33525 Mtetra
.649 .735 .912 r
.55734 .33525 .56638 .34669 .58357 .3402 .57461 .32966 Mtetra
.652 .756 .926 r
.57461 .32966 .58357 .3402 .60089 .33463 .592 .32389 Mtetra
.663 .757 .92 r
.592 .32389 .60089 .33463 .61831 .32887 .60948 .31763 Mtetra
.662 .748 .914 r
.60948 .31763 .61831 .32887 .63582 .32259 .62707 .31139 Mtetra
.657 .748 .917 r
.62707 .31139 .63582 .32259 .65345 .31642 .64478 .3053 Mtetra
.648 .748 .922 r
.64478 .3053 .65345 .31642 .6712 .3105 .66262 .29956 Mtetra
.652 .755 .925 r
.66262 .29956 .6712 .3105 .68907 .30482 .68056 .29361 Mtetra
.66 .754 .919 r
.68056 .29361 .68907 .30482 .70704 .29871 .6986 .28728 Mtetra
.66 .751 .917 r
.6986 .28728 .70704 .29871 .72512 .29238 .71676 .28092 Mtetra
.655 .749 .919 r
.71676 .28092 .72512 .29238 .74331 .28611 .73504 .27473 Mtetra
.65 .751 .923 r
.73504 .27473 .74331 .28611 .76164 .28013 .75346 .26871 Mtetra
.656 .754 .922 r
.75346 .26871 .76164 .28013 .78009 .27402 .77198 .26238 Mtetra
.659 .752 .919 r
.77198 .26238 .78009 .27402 .79864 .26764 .79061 .2559 Mtetra
.652 .749 .921 r
.13253 .46682 .14319 .47619 .15795 .4713 .14734 .46189 Mtetra
.653 .75 .92 r
.14734 .46189 .15795 .4713 .17281 .46627 .16224 .45686 Mtetra
.659 .752 .919 r
.16224 .45686 .17281 .46627 .18779 .46095 .17726 .45161 Mtetra
.661 .756 .92 r
.17726 .45161 .18779 .46095 .20283 .4558 .19237 .44624 Mtetra
.653 .75 .921 r
.19237 .44624 .20283 .4558 .21794 .45082 .20753 .44113 Mtetra
.651 .748 .92 r
.20753 .44113 .21794 .45082 .23314 .44583 .22278 .43608 Mtetra
.652 .748 .92 r
.22278 .43608 .23314 .44583 .24845 .44047 .23813 .43095 Mtetra
.662 .757 .92 r
.23813 .43095 .24845 .44047 .26387 .43492 .2536 .4254 Mtetra
.662 .758 .921 r
.2536 .4254 .26387 .43492 .27935 .42971 .26916 .41984 Mtetra
.654 .749 .92 r
.26916 .41984 .27935 .42971 .29491 .42466 .28478 .41456 Mtetra
.65 .745 .919 r
.28478 .41456 .29491 .42466 .31056 .41964 .30049 .4094 Mtetra
.648 .743 .918 r
.30049 .4094 .31056 .41964 .32634 .41413 .31629 .40426 Mtetra
.656 .754 .922 r
.31629 .40426 .32634 .41413 .34221 .40846 .33221 .3988 Mtetra
.664 .762 .923 r
.33221 .3988 .34221 .40846 .35814 .40337 .34824 .393 Mtetra
.657 .746 .915 r
.34824 .393 .35814 .40337 .37415 .39897 .36435 .38741 Mtetra
.647 .72 .902 r
.36435 .38741 .37415 .39897 .39023 .39498 .38054 .38219 Mtetra
.641 .696 .885 r
.38054 .38219 .39023 .39498 .40642 .39151 .39683 .37715 Mtetra
.639 .67 .863 r
.39683 .37715 .40642 .39151 .42273 .38766 .41322 .37204 Mtetra
.641 .653 .846 r
.41322 .37204 .42273 .38766 .43918 .38297 .42972 .3667 Mtetra
.645 .647 .837 r
.42972 .3667 .43918 .38297 .45576 .37736 .44634 .36101 Mtetra
.651 .649 .835 r
.44634 .36101 .45576 .37736 .47246 .3708 .46306 .35497 Mtetra
.656 .659 .841 r
.46306 .35497 .47246 .3708 .48926 .3634 .47989 .34869 Mtetra
.66 .678 .856 r
.47989 .34869 .48926 .3634 .50614 .3556 .49681 .34234 Mtetra
.66 .703 .879 r
.49681 .34234 .50614 .3556 .52311 .34832 .51384 .33617 Mtetra
.654 .722 .899 r
.51384 .33617 .52311 .34832 .54017 .34145 .53097 .33036 Mtetra
.648 .743 .919 r
.53097 .33036 .54017 .34145 .55734 .33525 .5482 .32477 Mtetra
.656 .76 .926 r
.5482 .32477 .55734 .33525 .57461 .32966 .56555 .31883 Mtetra
.663 .756 .92 r
.56555 .31883 .57461 .32966 .592 .32389 .583 .31256 Mtetra
.661 .747 .914 r
.583 .31256 .592 .32389 .60948 .31763 .60055 .30631 Mtetra
.658 .747 .916 r
.60055 .30631 .60948 .31763 .62707 .31139 .61823 .30017 Mtetra
.65 .748 .921 r
.61823 .30017 .62707 .31139 .64478 .3053 .63602 .29431 Mtetra
.649 .754 .926 r
.63602 .29431 .64478 .3053 .66262 .29956 .65393 .28843 Mtetra
.659 .756 .922 r
.65393 .28843 .66262 .29956 .68056 .29361 .67194 .28213 Mtetra
.66 .751 .917 r
.67194 .28213 .68056 .29361 .6986 .28728 .69006 .27572 Mtetra
.658 .75 .918 r
.69006 .27572 .6986 .28728 .71676 .28092 .7083 .26936 Mtetra
.651 .748 .921 r
.7083 .26936 .71676 .28092 .73504 .27473 .72668 .26328 Mtetra
.653 .753 .923 r
.72668 .26328 .73504 .27473 .75346 .26871 .74517 .25706 Mtetra
.658 .753 .92 r
.74517 .25706 .75346 .26871 .77198 .26238 .76377 .25058 Mtetra
.659 .752 .918 r
.76377 .25058 .77198 .26238 .79061 .2559 .78248 .24401 Mtetra
.653 .75 .921 r
.12176 .45738 .13253 .46682 .14734 .46189 .13662 .45234 Mtetra
.652 .749 .92 r
.13662 .45234 .14734 .46189 .16224 .45686 .15157 .44731 Mtetra
.655 .75 .92 r
.15157 .44731 .16224 .45686 .17726 .45161 .16661 .44215 Mtetra
.661 .755 .92 r
.16661 .44215 .17726 .45161 .19237 .44624 .18178 .43672 Mtetra
.659 .755 .921 r
.18178 .43672 .19237 .44624 .20753 .44113 .19701 .43136 Mtetra
.652 .749 .92 r
.19701 .43136 .20753 .44113 .22278 .43608 .21232 .4262 Mtetra
.651 .747 .92 r
.21232 .4262 .22278 .43608 .23813 .43095 .22771 .42106 Mtetra
.654 .749 .92 r
.22771 .42106 .23813 .43095 .2536 .4254 .24321 .41579 Mtetra
.663 .759 .921 r
.24321 .41579 .2536 .4254 .26916 .41984 .25883 .41013 Mtetra
.661 .757 .921 r
.25883 .41013 .26916 .41984 .28478 .41456 .27453 .4045 Mtetra
.654 .749 .92 r
.27453 .4045 .28478 .41456 .30049 .4094 .29031 .39912 Mtetra
.651 .745 .918 r
.29031 .39912 .30049 .4094 .31629 .40426 .30617 .39381 Mtetra
.649 .742 .917 r
.30617 .39381 .31629 .40426 .33221 .3988 .32213 .38854 Mtetra
.651 .748 .921 r
.32213 .38854 .33221 .3988 .34824 .393 .33819 .38317 Mtetra
.659 .761 .925 r
.33819 .38317 .34824 .393 .36435 .38741 .35437 .37745 Mtetra
.661 .76 .923 r
.35437 .37745 .36435 .38741 .38054 .38219 .37065 .37162 Mtetra
.658 .747 .916 r
.37065 .37162 .38054 .38219 .39683 .37715 .38702 .36586 Mtetra
.656 .733 .907 r
.38702 .36586 .39683 .37715 .41322 .37204 .40349 .36016 Mtetra
.654 .722 .899 r
.40349 .36016 .41322 .37204 .42972 .3667 .42006 .35445 Mtetra
.654 .717 .894 r
.42006 .35445 .42972 .3667 .44634 .36101 .43673 .34869 Mtetra
.655 .717 .894 r
.43673 .34869 .44634 .36101 .46306 .35497 .4535 .34288 Mtetra
.654 .722 .899 r
.4535 .34288 .46306 .35497 .47989 .34869 .47038 .33707 Mtetra
.653 .732 .908 r
.47038 .33707 .47989 .34869 .49681 .34234 .48736 .33131 Mtetra
.65 .745 .919 r
.48736 .33131 .49681 .34234 .51384 .33617 .50445 .32563 Mtetra
.652 .757 .926 r
.50445 .32563 .51384 .33617 .53097 .33036 .52165 .31983 Mtetra
.66 .762 .925 r
.52165 .31983 .53097 .33036 .5482 .32477 .53896 .31367 Mtetra
.662 .752 .917 r
.53896 .31367 .5482 .32477 .56555 .31883 .55637 .3074 Mtetra
.66 .746 .913 r
.55637 .3074 .56555 .31883 .583 .31256 .57389 .30117 Mtetra
.657 .747 .916 r
.57389 .30117 .583 .31256 .60055 .30631 .59153 .29501 Mtetra
.651 .748 .921 r
.59153 .29501 .60055 .30631 .61823 .30017 .60928 .28909 Mtetra
.649 .753 .926 r
.60928 .28909 .61823 .30017 .63602 .29431 .62715 .2832 Mtetra
.658 .757 .924 r
.62715 .2832 .63602 .29431 .65393 .28843 .64513 .27691 Mtetra
.66 .751 .918 r
.64513 .27691 .65393 .28843 .67194 .28213 .66322 .27047 Mtetra
.659 .75 .917 r
.66322 .27047 .67194 .28213 .69006 .27572 .68142 .26405 Mtetra
.653 .749 .92 r
.68142 .26405 .69006 .27572 .7083 .26936 .69975 .25783 Mtetra
.651 .752 .924 r
.69975 .25783 .7083 .26936 .72668 .26328 .71821 .25167 Mtetra
.657 .754 .922 r
.71821 .25167 .72668 .26328 .74517 .25706 .73678 .24521 Mtetra
.659 .752 .919 r
.73678 .24521 .74517 .25706 .76377 .25058 .75546 .23861 Mtetra
.658 .751 .918 r
.75546 .23861 .76377 .25058 .78248 .24401 .77426 .23202 Mtetra
.657 .753 .921 r
.11085 .44795 .12176 .45738 .13662 .45234 .12578 .4427 Mtetra
.652 .749 .921 r
.12578 .4427 .13662 .45234 .15157 .44731 .14078 .43761 Mtetra
.653 .749 .92 r
.14078 .43761 .15157 .44731 .16661 .44215 .15587 .43246 Mtetra
.657 .751 .92 r
.15587 .43246 .16661 .44215 .18178 .43672 .17106 .42714 Mtetra
.661 .756 .92 r
.17106 .42714 .18178 .43672 .19701 .43136 .18637 .42162 Mtetra
.657 .753 .921 r
.18637 .42162 .19701 .43136 .21232 .4262 .20174 .41624 Mtetra
.652 .748 .92 r
.20174 .41624 .21232 .4262 .22771 .42106 .21719 .41099 Mtetra
.651 .747 .92 r
.21719 .41099 .22771 .42106 .24321 .41579 .23273 .40575 Mtetra
.654 .749 .92 r
.23273 .40575 .24321 .41579 .25883 .41013 .24838 .40038 Mtetra
.662 .759 .922 r
.24838 .40038 .25883 .41013 .27453 .4045 .26414 .39465 Mtetra
.662 .758 .922 r
.26414 .39465 .27453 .4045 .29031 .39912 .28 .38891 Mtetra
.655 .75 .92 r
.28 .38891 .29031 .39912 .30617 .39381 .29593 .38338 Mtetra
.653 .746 .918 r
.29593 .38338 .30617 .39381 .32213 .38854 .31195 .37791 Mtetra
.651 .742 .916 r
.31195 .37791 .32213 .38854 .33819 .38317 .32807 .37248 Mtetra
.32807 .37248 .33819 .38317 .35437 .37745 .34429 .36701 Mtetra
.652 .75 .921 r
.34429 .36701 .35437 .37745 .37065 .37162 .36061 .36146 Mtetra
.654 .757 .926 r
.36061 .36146 .37065 .37162 .38702 .36586 .37704 .35582 Mtetra
.657 .762 .927 r
.37704 .35582 .38702 .36586 .40349 .36016 .39358 .35002 Mtetra
.657 .761 .927 r
.39358 .35002 .40349 .36016 .42006 .35445 .41021 .34417 Mtetra
.656 .759 .926 r
.41021 .34417 .42006 .35445 .43673 .34869 .42695 .33835 Mtetra
.654 .759 .927 r
.42695 .33835 .43673 .34869 .4535 .34288 .44379 .33255 Mtetra
.654 .761 .928 r
.44379 .33255 .4535 .34288 .47038 .33707 .46074 .3267 Mtetra
.657 .762 .927 r
.46074 .3267 .47038 .33707 .48736 .33131 .47779 .32069 Mtetra
.659 .759 .924 r
.47779 .32069 .48736 .33131 .50445 .32563 .49496 .31459 Mtetra
.66 .752 .918 r
.49496 .31459 .50445 .32563 .52165 .31983 .51223 .3084 Mtetra
.66 .745 .913 r
.51223 .3084 .52165 .31983 .53896 .31367 .5296 .30217 Mtetra
.658 .745 .914 r
.5296 .30217 .53896 .31367 .55637 .3074 .54709 .29598 Mtetra
.656 .747 .917 r
.54709 .29598 .55637 .3074 .57389 .30117 .56469 .28983 Mtetra
.65 .748 .921 r
.56469 .28983 .57389 .30117 .59153 .29501 .5824 .2839 Mtetra
.649 .754 .926 r
.5824 .2839 .59153 .29501 .60928 .28909 .60023 .27795 Mtetra
.657 .758 .924 r
.60023 .27795 .60928 .28909 .62715 .2832 .61817 .27164 Mtetra
.66 .752 .918 r
.61817 .27164 .62715 .2832 .64513 .27691 .63622 .26518 Mtetra
.659 .749 .917 r
.63622 .26518 .64513 .27691 .66322 .27047 .65439 .25872 Mtetra
.655 .749 .919 r
.65439 .25872 .66322 .27047 .68142 .26405 .67268 .25238 Mtetra
.651 .75 .923 r
.67268 .25238 .68142 .26405 .69975 .25783 .6911 .24619 Mtetra
.655 .754 .923 r
.6911 .24619 .69975 .25783 .71821 .25167 .70964 .23978 Mtetra
.658 .752 .919 r
.70964 .23978 .71821 .25167 .73678 .24521 .72828 .23318 Mtetra
.659 .751 .918 r
.72828 .23318 .73678 .24521 .75546 .23861 .74705 .22651 Mtetra
.655 .749 .919 r
.74705 .22651 .75546 .23861 .77426 .23202 .76595 .21998 Mtetra
.66 .754 .92 r
.09983 .43843 .11085 .44795 .12578 .4427 .11482 .43303 Mtetra
.655 .751 .921 r
.11482 .43303 .12578 .4427 .14078 .43761 .12988 .42779 Mtetra
.652 .748 .92 r
.12988 .42779 .14078 .43761 .15587 .43246 .14501 .42261 Mtetra
.654 .749 .92 r
.14501 .42261 .15587 .43246 .17106 .42714 .16025 .41735 Mtetra
.658 .753 .92 r
.16025 .41735 .17106 .42714 .18637 .42162 .17559 .41189 Mtetra
.661 .756 .921 r
.17559 .41189 .18637 .42162 .20174 .41624 .19103 .40628 Mtetra
.656 .751 .92 r
.19103 .40628 .20174 .41624 .21719 .41099 .20655 .40085 Mtetra
.652 .748 .92 r
.20655 .40085 .21719 .41099 .23273 .40575 .22215 .3955 Mtetra
.652 .747 .919 r
.22215 .3955 .23273 .40575 .24838 .40038 .23784 .39016 Mtetra
.653 .749 .92 r
.23784 .39016 .24838 .40038 .26414 .39465 .25363 .3847 Mtetra
.66 .758 .922 r
.25363 .3847 .26414 .39465 .28 .38891 .26954 .37896 Mtetra
.662 .76 .923 r
.26954 .37896 .28 .38891 .29593 .38338 .28555 .37313 Mtetra
.658 .754 .92 r
.28555 .37313 .29593 .38338 .31195 .37791 .30165 .36739 Mtetra
.655 .748 .919 r
.30165 .36739 .31195 .37791 .32807 .37248 .31783 .36175 Mtetra
.654 .745 .917 r
.31783 .36175 .32807 .37248 .34429 .36701 .33412 .35612 Mtetra
.653 .743 .915 r
.33412 .35612 .34429 .36701 .36061 .36146 .3505 .35046 Mtetra
.653 .742 .915 r
.3505 .35046 .36061 .36146 .37704 .35582 .36699 .34478 Mtetra
.654 .743 .915 r
.36699 .34478 .37704 .35582 .39358 .35002 .38358 .33904 Mtetra
.655 .746 .917 r
.38358 .33904 .39358 .35002 .41021 .34417 .40028 .33322 Mtetra
.656 .748 .918 r
.40028 .33322 .41021 .34417 .42695 .33835 .41708 .32733 Mtetra
.657 .748 .917 r
.41708 .32733 .42695 .33835 .44379 .33255 .43399 .32137 Mtetra
.658 .747 .916 r
.43399 .32137 .44379 .33255 .46074 .3267 .451 .31533 Mtetra
.658 .744 .914 r
.451 .31533 .46074 .3267 .47779 .32069 .46813 .30922 Mtetra
.658 .743 .913 r
.46813 .30922 .47779 .32069 .49496 .31459 .48536 .30308 Mtetra
.658 .744 .914 r
.48536 .30308 .49496 .31459 .51223 .3084 .50269 .29693 Mtetra
.657 .746 .916 r
.50269 .29693 .51223 .3084 .5296 .30217 .52014 .29077 Mtetra
.653 .748 .919 r
.52014 .29077 .5296 .30217 .54709 .29598 .5377 .28471 Mtetra
.65 .751 .923 r
.5377 .28471 .54709 .29598 .56469 .28983 .55538 .27874 Mtetra
.651 .756 .926 r
.55538 .27874 .56469 .28983 .5824 .2839 .57317 .27268 Mtetra
.658 .758 .923 r
.57317 .27268 .5824 .2839 .60023 .27795 .59107 .26632 Mtetra
.66 .751 .918 r
.59107 .26632 .60023 .27795 .61817 .27164 .60908 .25983 Mtetra
.659 .749 .917 r
.60908 .25983 .61817 .27164 .63622 .26518 .62721 .25334 Mtetra
.656 .749 .918 r
.62721 .25334 .63622 .26518 .65439 .25872 .64546 .24694 Mtetra
.651 .75 .922 r
.64546 .24694 .65439 .25872 .67268 .25238 .66384 .2407 Mtetra
.654 .754 .924 r
.66384 .2407 .67268 .25238 .6911 .24619 .68234 .2343 Mtetra
.658 .753 .92 r
.68234 .2343 .6911 .24619 .70964 .23978 .70095 .2277 Mtetra
.659 .751 .918 r
.70095 .2277 .70964 .23978 .72828 .23318 .71968 .22099 Mtetra
.657 .75 .919 r
.71968 .22099 .72828 .23318 .74705 .22651 .73854 .21433 Mtetra
.652 .75 .921 r
.73854 .21433 .74705 .22651 .76595 .21998 .75754 .20783 Mtetra
.659 .753 .92 r
.08869 .42877 .09983 .43843 .11482 .43303 .10372 .42336 Mtetra
.659 .754 .92 r
.10372 .42336 .11482 .43303 .12988 .42779 .11885 .41789 Mtetra
.653 .749 .92 r
.11885 .41789 .12988 .42779 .14501 .42261 .13404 .41262 Mtetra
.652 .748 .92 r
.13404 .41262 .14501 .42261 .16025 .41735 .14932 .40734 Mtetra
.654 .75 .92 r
.14932 .40734 .16025 .41735 .17559 .41189 .1647 .40197 Mtetra
.659 .754 .921 r
.1647 .40197 .17559 .41189 .19103 .40628 .18019 .3964 Mtetra
.661 .756 .921 r
.18019 .3964 .19103 .40628 .20655 .40085 .19578 .39071 Mtetra
.656 .751 .92 r
.19578 .39071 .20655 .40085 .22215 .3955 .21144 .38517 Mtetra
.653 .748 .919 r
.21144 .38517 .22215 .3955 .23784 .39016 .22719 .37972 Mtetra
.652 .746 .919 r
.22719 .37972 .23784 .39016 .25363 .3847 .24303 .37426 Mtetra
.653 .748 .919 r
.24303 .37426 .25363 .3847 .26954 .37896 .25898 .36873 Mtetra
.656 .755 .922 r
.25898 .36873 .26954 .37896 .28555 .37313 .27503 .36303 Mtetra
.66 .76 .924 r
.27503 .36303 .28555 .37313 .30165 .36739 .2912 .35715 Mtetra
.66 .758 .923 r
.2912 .35715 .30165 .36739 .31783 .36175 .30746 .35124 Mtetra
.658 .753 .92 r
.30746 .35124 .31783 .36175 .33412 .35612 .32381 .34536 Mtetra
.656 .749 .919 r
.32381 .34536 .33412 .35612 .3505 .35046 .34027 .33955 Mtetra
.655 .747 .917 r
.34027 .33955 .3505 .35046 .36699 .34478 .35682 .33373 Mtetra
.655 .745 .916 r
.35682 .33373 .36699 .34478 .38358 .33904 .37347 .32787 Mtetra
.655 .744 .915 r
.37347 .32787 .38358 .33904 .40028 .33322 .39023 .32196 Mtetra
.656 .744 .915 r
.39023 .32196 .40028 .33322 .41708 .32733 .4071 .316 Mtetra
.4071 .316 .41708 .32733 .43399 .32137 .42407 .30999 Mtetra
.656 .745 .915 r
.42407 .30999 .43399 .32137 .451 .31533 .44115 .30393 Mtetra
.656 .746 .916 r
.44115 .30393 .451 .31533 .46813 .30922 .45834 .29783 Mtetra
.656 .747 .917 r
.45834 .29783 .46813 .30922 .48536 .30308 .47564 .29171 Mtetra
.653 .748 .919 r
.47564 .29171 .48536 .30308 .50269 .29693 .49305 .28566 Mtetra
.652 .751 .923 r
.49305 .28566 .50269 .29693 .52014 .29077 .51057 .27964 Mtetra
.651 .755 .926 r
.51057 .27964 .52014 .29077 .5377 .28471 .5282 .27359 Mtetra
.655 .758 .926 r
.5282 .27359 .5377 .28471 .55538 .27874 .54595 .26735 Mtetra
.658 .756 .922 r
.54595 .26735 .55538 .27874 .57317 .27268 .56381 .26093 Mtetra
.659 .75 .917 r
.56381 .26093 .57317 .27268 .59107 .26632 .58179 .25443 Mtetra
.658 .749 .917 r
.58179 .25443 .59107 .26632 .60908 .25983 .59988 .24792 Mtetra
.656 .748 .918 r
.59988 .24792 .60908 .25983 .62721 .25334 .6181 .24149 Mtetra
.651 .75 .922 r
.6181 .24149 .62721 .25334 .64546 .24694 .63644 .2352 Mtetra
.653 .754 .924 r
.63644 .2352 .64546 .24694 .66384 .2407 .65489 .22879 Mtetra
.657 .754 .921 r
.65489 .22879 .66384 .2407 .68234 .2343 .67347 .22216 Mtetra
.659 .751 .918 r
.67347 .22216 .68234 .2343 .70095 .2277 .69216 .21542 Mtetra
.658 .75 .918 r
.69216 .21542 .70095 .2277 .71968 .22099 .71098 .20868 Mtetra
.653 .749 .92 r
.71098 .20868 .71968 .22099 .73854 .21433 .72993 .20211 Mtetra
.653 .752 .923 r
.72993 .20211 .73854 .21433 .75754 .20783 .74902 .19548 Mtetra
.656 .751 .92 r
.07743 .41895 .08869 .42877 .10372 .42336 .09251 .41357 Mtetra
.659 .754 .92 r
.09251 .41357 .10372 .42336 .11885 .41789 .10768 .40805 Mtetra
.658 .754 .921 r
.10768 .40805 .11885 .41789 .13404 .41262 .12295 .40253 Mtetra
.653 .749 .92 r
.12295 .40253 .13404 .41262 .14932 .40734 .13828 .39717 Mtetra
.653 .748 .92 r
.13828 .39717 .14932 .40734 .1647 .40197 .1537 .39179 Mtetra
.654 .75 .92 r
.1537 .39179 .1647 .40197 .18019 .3964 .16923 .38632 Mtetra
.658 .754 .921 r
.16923 .38632 .18019 .3964 .19578 .39071 .18486 .38066 Mtetra
.66 .757 .921 r
.18486 .38066 .19578 .39071 .21144 .38517 .2006 .3749 Mtetra
.657 .752 .92 r
.2006 .3749 .21144 .38517 .22719 .37972 .21642 .36922 Mtetra
.654 .748 .919 r
.21642 .36922 .22719 .37972 .24303 .37426 .23232 .36363 Mtetra
.653 .747 .919 r
.23232 .36363 .24303 .37426 .25898 .36873 .24833 .35805 Mtetra
.24833 .35805 .25898 .36873 .27503 .36303 .26443 .35243 Mtetra
.654 .75 .92 r
.26443 .35243 .27503 .36303 .2912 .35715 .28063 .34673 Mtetra
.656 .756 .923 r
.28063 .34673 .2912 .35715 .30746 .35124 .29694 .34092 Mtetra
.659 .76 .925 r
.29694 .34092 .30746 .35124 .32381 .34536 .31336 .33495 Mtetra
.659 .76 .924 r
.31336 .33495 .32381 .34536 .34027 .33955 .32988 .32896 Mtetra
.658 .757 .923 r
.32988 .32896 .34027 .33955 .35682 .33373 .34651 .32296 Mtetra
.657 .754 .922 r
.34651 .32296 .35682 .33373 .37347 .32787 .36323 .31695 Mtetra
.656 .753 .921 r
.36323 .31695 .37347 .32787 .39023 .32196 .38006 .31093 Mtetra
.656 .752 .92 r
.38006 .31093 .39023 .32196 .4071 .316 .39699 .30491 Mtetra
.655 .751 .921 r
.39699 .30491 .4071 .316 .42407 .30999 .41403 .29886 Mtetra
.654 .752 .921 r
.41403 .29886 .42407 .30999 .44115 .30393 .43118 .29281 Mtetra
.654 .753 .923 r
.43118 .29281 .44115 .30393 .45834 .29783 .44843 .28675 Mtetra
.653 .755 .925 r
.44843 .28675 .45834 .29783 .47564 .29171 .4658 .28068 Mtetra
.653 .758 .927 r
.4658 .28068 .47564 .29171 .49305 .28566 .48328 .27458 Mtetra
.655 .759 .926 r
.48328 .27458 .49305 .28566 .51057 .27964 .50088 .26833 Mtetra
.658 .756 .923 r
.50088 .26833 .51057 .27964 .5282 .27359 .51859 .26195 Mtetra
.659 .752 .919 r
.51859 .26195 .5282 .27359 .54595 .26735 .53641 .25548 Mtetra
.659 .749 .917 r
.53641 .25548 .54595 .26735 .56381 .26093 .55435 .24897 Mtetra
.658 .748 .917 r
.55435 .24897 .56381 .26093 .58179 .25443 .5724 .24246 Mtetra
.655 .748 .919 r
.5724 .24246 .58179 .25443 .59988 .24792 .59058 .23604 Mtetra
.652 .75 .922 r
.59058 .23604 .59988 .24792 .6181 .24149 .60888 .2297 Mtetra
.654 .755 .924 r
.60888 .2297 .6181 .24149 .63644 .2352 .62729 .22324 Mtetra
.657 .754 .921 r
.62729 .22324 .63644 .2352 .65489 .22879 .64583 .21658 Mtetra
.659 .751 .919 r
.64583 .21658 .65489 .22879 .67347 .22216 .66448 .20982 Mtetra
.658 .75 .918 r
.66448 .20982 .67347 .22216 .69216 .21542 .68326 .20302 Mtetra
.654 .749 .92 r
.68326 .20302 .69216 .21542 .71098 .20868 .70217 .19638 Mtetra
.653 .752 .923 r
.70217 .19638 .71098 .20868 .72993 .20211 .72122 .18974 Mtetra
.656 .753 .922 r
.72122 .18974 .72993 .20211 .74902 .19548 .74038 .18292 Mtetra
.654 .75 .92 r
.06606 .40896 .07743 .41895 .09251 .41357 .08117 .40359 Mtetra
.656 .752 .92 r
.08117 .40359 .09251 .41357 .10768 .40805 .09639 .39812 Mtetra
.659 .755 .921 r
.09639 .39812 .10768 .40805 .12295 .40253 .11171 .39249 Mtetra
.658 .753 .921 r
.11171 .39249 .12295 .40253 .13828 .39717 .12711 .3869 Mtetra
.653 .749 .92 r
.12711 .3869 .13828 .39717 .1537 .39179 .14259 .38144 Mtetra
.653 .748 .92 r
.14259 .38144 .1537 .39179 .16923 .38632 .15816 .37596 Mtetra
.654 .75 .92 r
.15816 .37596 .16923 .38632 .18486 .38066 .17384 .37039 Mtetra
.657 .754 .921 r
.17384 .37039 .18486 .38066 .2006 .3749 .18962 .36468 Mtetra
.66 .757 .922 r
.18962 .36468 .2006 .3749 .21642 .36922 .2055 .35883 Mtetra
.659 .754 .921 r
.2055 .35883 .21642 .36922 .23232 .36363 .22149 .35298 Mtetra
.655 .749 .919 r
.22149 .35298 .23232 .36363 .24833 .35805 .23755 .34726 Mtetra
.654 .747 .918 r
.23755 .34726 .24833 .35805 .26443 .35243 .25371 .34154 Mtetra
.653 .746 .918 r
.25371 .34154 .26443 .35243 .28063 .34673 .26997 .33579 Mtetra
.653 .747 .918 r
.26997 .33579 .28063 .34673 .29694 .34092 .28634 .33001 Mtetra
.654 .749 .92 r
.28634 .33001 .29694 .34092 .31336 .33495 .30281 .32416 Mtetra
.655 .753 .922 r
.30281 .32416 .31336 .33495 .32988 .32896 .31938 .31825 Mtetra
.655 .756 .924 r
.31938 .31825 .32988 .32896 .34651 .32296 .33606 .31228 Mtetra
.656 .759 .925 r
.33606 .31228 .34651 .32296 .36323 .31695 .35285 .30625 Mtetra
.656 .76 .926 r
.35285 .30625 .36323 .31695 .38006 .31093 .36975 .30017 Mtetra
.36975 .30017 .38006 .31093 .39699 .30491 .38675 .29407 Mtetra
.655 .759 .926 r
.38675 .29407 .39699 .30491 .41403 .29886 .40386 .28795 Mtetra
.656 .759 .926 r
.40386 .28795 .41403 .29886 .43118 .29281 .42108 .28178 Mtetra
.656 .759 .925 r
.42108 .28178 .43118 .29281 .44843 .28675 .43841 .27555 Mtetra
.657 .757 .924 r
.43841 .27555 .44843 .28675 .4658 .28068 .45585 .26925 Mtetra
.657 .754 .921 r
.45585 .26925 .4658 .28068 .48328 .27458 .47341 .26289 Mtetra
.658 .75 .918 r
.47341 .26289 .48328 .27458 .50088 .26833 .49108 .25646 Mtetra
.658 .748 .917 r
.49108 .25646 .50088 .26833 .51859 .26195 .50886 .24998 Mtetra
.658 .748 .916 r
.50886 .24998 .51859 .26195 .53641 .25548 .52676 .24348 Mtetra
.657 .748 .917 r
.52676 .24348 .53641 .25548 .55435 .24897 .54477 .23697 Mtetra
.653 .748 .92 r
.54477 .23697 .55435 .24897 .5724 .24246 .56291 .23059 Mtetra
.652 .752 .923 r
.56291 .23059 .5724 .24246 .59058 .23604 .58116 .2242 Mtetra
.655 .755 .924 r
.58116 .2242 .59058 .23604 .60888 .2297 .59954 .21765 Mtetra
.657 .754 .921 r
.59954 .21765 .60888 .2297 .62729 .22324 .61803 .21095 Mtetra
.658 .751 .919 r
.61803 .21095 .62729 .22324 .64583 .21658 .63665 .20416 Mtetra
.658 .75 .918 r
.63665 .20416 .64583 .21658 .66448 .20982 .65539 .19733 Mtetra
.654 .749 .919 r
.65539 .19733 .66448 .20982 .68326 .20302 .67426 .19063 Mtetra
.652 .751 .922 r
.67426 .19063 .68326 .20302 .70217 .19638 .69326 .18395 Mtetra
.655 .754 .922 r
.69326 .18395 .70217 .19638 .72122 .18974 .71239 .17711 Mtetra
.657 .752 .92 r
.71239 .17711 .72122 .18974 .74038 .18292 .73164 .17014 Mtetra
.653 .749 .92 r
.05457 .39882 .06606 .40896 .08117 .40359 .06972 .39345 Mtetra
.655 .75 .92 r
.06972 .39345 .08117 .40359 .09639 .39812 .08498 .38797 Mtetra
.657 .752 .92 r
.08498 .38797 .09639 .39812 .11171 .39249 .10034 .38239 Mtetra
.659 .755 .921 r
.10034 .38239 .11171 .39249 .12711 .3869 .1158 .37668 Mtetra
.658 .753 .92 r
.1158 .37668 .12711 .3869 .14259 .38144 .13135 .37099 Mtetra
.653 .749 .92 r
.13135 .37099 .14259 .38144 .15816 .37596 .14698 .36542 Mtetra
.653 .748 .92 r
.14698 .36542 .15816 .37596 .17384 .37039 .1627 .35983 Mtetra
.654 .749 .92 r
.1627 .35983 .17384 .37039 .18962 .36468 .17853 .35418 Mtetra
.655 .752 .921 r
.17853 .35418 .18962 .36468 .2055 .35883 .19445 .34843 Mtetra
.659 .756 .922 r
.19445 .34843 .2055 .35883 .22149 .35298 .21049 .34252 Mtetra
.659 .757 .922 r
.21049 .34252 .22149 .35298 .23755 .34726 .22663 .33655 Mtetra
.658 .753 .92 r
.22663 .33655 .23755 .34726 .25371 .34154 .24287 .33061 Mtetra
.655 .749 .919 r
.24287 .33061 .25371 .34154 .26997 .33579 .25919 .32474 Mtetra
.654 .747 .918 r
.25919 .32474 .26997 .33579 .28634 .33001 .27562 .31885 Mtetra
.654 .746 .918 r
.27562 .31885 .28634 .33001 .30281 .32416 .29215 .31293 Mtetra
.654 .746 .917 r
.29215 .31293 .30281 .32416 .31938 .31825 .30878 .30696 Mtetra
.654 .747 .918 r
.30878 .30696 .31938 .31825 .33606 .31228 .32553 .30096 Mtetra
.655 .748 .918 r
.32553 .30096 .33606 .31228 .35285 .30625 .34238 .29489 Mtetra
.34238 .29489 .35285 .30625 .36975 .30017 .35934 .28877 Mtetra
.656 .749 .919 r
.35934 .28877 .36975 .30017 .38675 .29407 .3764 .2826 Mtetra
.3764 .2826 .38675 .29407 .40386 .28795 .39358 .27638 Mtetra
.656 .749 .918 r
.39358 .27638 .40386 .28795 .42108 .28178 .41087 .27009 Mtetra
.657 .748 .917 r
.41087 .27009 .42108 .28178 .43841 .27555 .42827 .26375 Mtetra
.42827 .26375 .43841 .27555 .45585 .26925 .44579 .25737 Mtetra
.657 .747 .916 r
.44579 .25737 .45585 .26925 .47341 .26289 .46341 .25093 Mtetra
.657 .747 .917 r
.46341 .25093 .47341 .26289 .49108 .25646 .48116 .24446 Mtetra
.656 .748 .917 r
.48116 .24446 .49108 .25646 .50886 .24998 .49901 .23797 Mtetra
.654 .748 .919 r
.49901 .23797 .50886 .24998 .52676 .24348 .51699 .23155 Mtetra
.653 .751 .922 r
.51699 .23155 .52676 .24348 .54477 .23697 .53508 .22514 Mtetra
.653 .755 .924 r
.53508 .22514 .54477 .23697 .56291 .23059 .55329 .21867 Mtetra
.656 .756 .923 r
.55329 .21867 .56291 .23059 .58116 .2242 .57163 .21203 Mtetra
.657 .753 .92 r
.57163 .21203 .58116 .2242 .59954 .21765 .59008 .20528 Mtetra
.658 .751 .918 r
.59008 .20528 .59954 .21765 .61803 .21095 .60866 .19846 Mtetra
.658 .75 .918 r
.60866 .19846 .61803 .21095 .63665 .20416 .62736 .1916 Mtetra
.654 .749 .919 r
.62736 .1916 .63665 .20416 .65539 .19733 .64619 .18486 Mtetra
.653 .751 .922 r
.64619 .18486 .65539 .19733 .67426 .19063 .66515 .17814 Mtetra
.655 .754 .922 r
.66515 .17814 .67426 .19063 .69326 .18395 .68424 .17127 Mtetra
.657 .752 .92 r
.68424 .17127 .69326 .18395 .71239 .17711 .70345 .16428 Mtetra
.658 .752 .919 r
.70345 .16428 .71239 .17711 .73164 .17014 .72279 .15717 Mtetra
.654 .75 .92 r
.04294 .38863 .05457 .39882 .06972 .39345 .05815 .38313 Mtetra
.653 .749 .92 r
.05815 .38313 .06972 .39345 .08498 .38797 .07345 .37766 Mtetra
.655 .75 .92 r
.07345 .37766 .08498 .38797 .10034 .38239 .08885 .37208 Mtetra
.656 .752 .92 r
.08885 .37208 .10034 .38239 .1158 .37668 .10435 .36641 Mtetra
.659 .755 .921 r
.10435 .36641 .1158 .37668 .13135 .37099 .11997 .3606 Mtetra
.658 .754 .92 r
.11997 .3606 .13135 .37099 .14698 .36542 .13567 .35479 Mtetra
.654 .749 .92 r
.13567 .35479 .14698 .36542 .1627 .35983 .15145 .3491 Mtetra
.653 .748 .919 r
.15145 .3491 .1627 .35983 .17853 .35418 .16732 .34341 Mtetra
.654 .749 .92 r
.16732 .34341 .17853 .35418 .19445 .34843 .1833 .33766 Mtetra
.655 .75 .92 r
.1833 .33766 .19445 .34843 .21049 .34252 .19938 .33184 Mtetra
.656 .754 .922 r
.19938 .33184 .21049 .34252 .22663 .33655 .21557 .32593 Mtetra
.659 .757 .923 r
.21557 .32593 .22663 .33655 .24287 .33061 .23187 .31989 Mtetra
.659 .756 .922 r
.23187 .31989 .24287 .33061 .25919 .32474 .24826 .31381 Mtetra
.658 .753 .921 r
.24826 .31381 .25919 .32474 .27562 .31885 .26476 .30772 Mtetra
.656 .75 .919 r
.26476 .30772 .27562 .31885 .29215 .31293 .28136 .30164 Mtetra
.655 .748 .918 r
.28136 .30164 .29215 .31293 .30878 .30696 .29806 .29557 Mtetra
.29806 .29557 .30878 .30696 .32553 .30096 .31487 .28947 Mtetra
.655 .747 .917 r
.31487 .28947 .32553 .30096 .34238 .29489 .33179 .28332 Mtetra
.33179 .28332 .34238 .29489 .35934 .28877 .34881 .27712 Mtetra
.656 .747 .917 r
.34881 .27712 .35934 .28877 .3764 .2826 .36594 .27088 Mtetra
.36594 .27088 .3764 .2826 .39358 .27638 .38319 .26458 Mtetra
.38319 .26458 .39358 .27638 .41087 .27009 .40055 .25824 Mtetra
.40055 .25824 .41087 .27009 .42827 .26375 .41802 .25185 Mtetra
.656 .748 .917 r
.41802 .25185 .42827 .26375 .44579 .25737 .4356 .24542 Mtetra
.655 .748 .918 r
.4356 .24542 .44579 .25737 .46341 .25093 .4533 .23899 Mtetra
.654 .749 .92 r
.4533 .23899 .46341 .25093 .48116 .24446 .47111 .23258 Mtetra
.653 .752 .922 r
.47111 .23258 .48116 .24446 .49901 .23797 .48904 .22615 Mtetra
.653 .755 .924 r
.48904 .22615 .49901 .23797 .51699 .23155 .50709 .21968 Mtetra
.656 .756 .924 r
.50709 .21968 .51699 .23155 .53508 .22514 .52527 .21306 Mtetra
.657 .754 .922 r
.52527 .21306 .53508 .22514 .55329 .21867 .54356 .20635 Mtetra
.658 .751 .919 r
.54356 .20635 .55329 .21867 .57163 .21203 .56197 .19956 Mtetra
.658 .75 .918 r
.56197 .19956 .57163 .21203 .59008 .20528 .58051 .1927 Mtetra
.657 .749 .918 r
.58051 .1927 .59008 .20528 .60866 .19846 .59917 .18583 Mtetra
.653 .749 .92 r
.59917 .18583 .60866 .19846 .62736 .1916 .61796 .17908 Mtetra
.653 .752 .922 r
.61796 .17908 .62736 .1916 .64619 .18486 .63688 .17231 Mtetra
.655 .754 .922 r
.63688 .17231 .64619 .18486 .66515 .17814 .65592 .1654 Mtetra
.657 .752 .92 r
.65592 .1654 .66515 .17814 .68424 .17127 .67509 .15837 Mtetra
.658 .752 .919 r
.67509 .15837 .68424 .17127 .70345 .16428 .69439 .15122 Mtetra
.657 .75 .918 r
.69439 .15122 .70345 .16428 .72279 .15717 .71382 .14409 Mtetra
.658 .753 .92 r
.03116 .37844 .04294 .38863 .05815 .38313 .04644 .37275 Mtetra
.654 .75 .92 r
.04644 .37275 .05815 .38313 .07345 .37766 .0618 .36716 Mtetra
.653 .749 .92 r
.0618 .36716 .07345 .37766 .08885 .37208 .07724 .36158 Mtetra
.655 .75 .92 r
.07724 .36158 .08885 .37208 .10435 .36641 .09279 .35591 Mtetra
.656 .752 .92 r
.09279 .35591 .10435 .36641 .11997 .3606 .10844 .35015 Mtetra
.658 .755 .921 r
.10844 .35015 .11997 .3606 .13567 .35479 .1242 .34427 Mtetra
.659 .755 .921 r
.1242 .34427 .13567 .35479 .15145 .3491 .14005 .33834 Mtetra
.656 .751 .92 r
.14005 .33834 .15145 .3491 .16732 .34341 .156 .33249 Mtetra
.654 .748 .919 r
.156 .33249 .16732 .34341 .1833 .33766 .17203 .32667 Mtetra
.17203 .32667 .1833 .33766 .19938 .33184 .18816 .32082 Mtetra
.654 .749 .919 r
.18816 .32082 .19938 .33184 .21557 .32593 .2044 .31491 Mtetra
.655 .751 .92 r
.2044 .31491 .21557 .32593 .23187 .31989 .22074 .30894 Mtetra
.656 .754 .922 r
.22074 .30894 .23187 .31989 .24826 .31381 .2372 .3029 Mtetra
.657 .756 .923 r
.2372 .3029 .24826 .31381 .26476 .30772 .25375 .29677 Mtetra
.658 .757 .923 r
.25375 .29677 .26476 .30772 .28136 .30164 .27042 .29058 Mtetra
.657 .756 .923 r
.27042 .29058 .28136 .30164 .29806 .29557 .28719 .28436 Mtetra
.657 .754 .922 r
.28719 .28436 .29806 .29557 .31487 .28947 .30407 .27812 Mtetra
.657 .753 .921 r
.30407 .27812 .31487 .28947 .33179 .28332 .32105 .27185 Mtetra
.656 .752 .92 r
.32105 .27185 .33179 .28332 .34881 .27712 .33815 .26556 Mtetra
.656 .751 .92 r
.33815 .26556 .34881 .27712 .36594 .27088 .35535 .25924 Mtetra
.655 .751 .92 r
.35535 .25924 .36594 .27088 .38319 .26458 .37266 .25289 Mtetra
.655 .752 .921 r
.37266 .25289 .38319 .26458 .40055 .25824 .39009 .24651 Mtetra
.655 .752 .922 r
.39009 .24651 .40055 .25824 .41802 .25185 .40763 .24011 Mtetra
.654 .753 .923 r
.40763 .24011 .41802 .25185 .4356 .24542 .42528 .23369 Mtetra
.654 .755 .924 r
.42528 .23369 .4356 .24542 .4533 .23899 .44305 .22723 Mtetra
.655 .756 .924 r
.44305 .22723 .4533 .23899 .47111 .23258 .46094 .2207 Mtetra
.656 .756 .923 r
.46094 .2207 .47111 .23258 .48904 .22615 .47895 .21408 Mtetra
.657 .754 .922 r
.47895 .21408 .48904 .22615 .50709 .21968 .49708 .20739 Mtetra
.657 .751 .919 r
.49708 .20739 .50709 .21968 .52527 .21306 .51533 .20062 Mtetra
.658 .75 .918 r
.51533 .20062 .52527 .21306 .54356 .20635 .53371 .19379 Mtetra
.658 .749 .918 r
.53371 .19379 .54356 .20635 .56197 .19956 .5522 .18691 Mtetra
.656 .749 .918 r
.5522 .18691 .56197 .19956 .58051 .1927 .57082 .18007 Mtetra
.653 .75 .92 r
.57082 .18007 .58051 .1927 .59917 .18583 .58957 .17329 Mtetra
.653 .753 .923 r
.58957 .17329 .59917 .18583 .61796 .17908 .60844 .16646 Mtetra
.656 .754 .922 r
.60844 .16646 .61796 .17908 .63688 .17231 .62744 .15948 Mtetra
.657 .752 .92 r
.62744 .15948 .63688 .17231 .65592 .1654 .64657 .15241 Mtetra
.658 .752 .919 r
.64657 .15241 .65592 .1654 .67509 .15837 .66583 .14523 Mtetra
.657 .75 .918 r
.66583 .14523 .67509 .15837 .69439 .15122 .68522 .13805 Mtetra
.654 .75 .92 r
.68522 .13805 .69439 .15122 .71382 .14409 .70475 .13096 Mtetra
.658 .753 .921 r
.01925 .36813 .03116 .37844 .04644 .37275 .03458 .36238 Mtetra
.658 .754 .921 r
.03458 .36238 .04644 .37275 .0618 .36716 .05001 .3566 Mtetra
.655 .75 .92 r
.05001 .3566 .0618 .36716 .07724 .36158 .06551 .35089 Mtetra
.653 .748 .92 r
.06551 .35089 .07724 .36158 .09279 .35591 .08111 .34521 Mtetra
.654 .75 .92 r
.08111 .34521 .09279 .35591 .10844 .35015 .0968 .33945 Mtetra
.656 .751 .92 r
.0968 .33945 .10844 .35015 .1242 .34427 .1126 .3336 Mtetra
.657 .754 .921 r
.1126 .3336 .1242 .34427 .14005 .33834 .12851 .32765 Mtetra
.658 .755 .921 r
.12851 .32765 .14005 .33834 .156 .33249 .14452 .32163 Mtetra
.658 .753 .92 r
.14452 .32163 .156 .33249 .17203 .32667 .16062 .31559 Mtetra
.655 .749 .919 r
.16062 .31559 .17203 .32667 .18816 .32082 .17682 .30963 Mtetra
.654 .748 .919 r
.17682 .30963 .18816 .32082 .2044 .31491 .19312 .30365 Mtetra
.19312 .30365 .2044 .31491 .22074 .30894 .20952 .29764 Mtetra
.654 .749 .919 r
.20952 .29764 .22074 .30894 .2372 .3029 .22602 .29158 Mtetra
.655 .75 .92 r
.22602 .29158 .2372 .3029 .25375 .29677 .24264 .28546 Mtetra
.655 .752 .921 r
.24264 .28546 .25375 .29677 .27042 .29058 .25936 .27929 Mtetra
.656 .754 .922 r
.25936 .27929 .27042 .29058 .28719 .28436 .27619 .27306 Mtetra
.656 .755 .923 r
.27619 .27306 .28719 .28436 .30407 .27812 .29313 .26679 Mtetra
.656 .756 .923 r
.29313 .26679 .30407 .27812 .32105 .27185 .31018 .26048 Mtetra
.656 .756 .924 r
.31018 .26048 .32105 .27185 .33815 .26556 .32734 .25412 Mtetra
.656 .757 .924 r
.32734 .25412 .33815 .26556 .35535 .25924 .34461 .24772 Mtetra
.34461 .24772 .35535 .25924 .37266 .25289 .362 .24129 Mtetra
.656 .756 .924 r
.362 .24129 .37266 .25289 .39009 .24651 .37949 .23481 Mtetra
.656 .756 .923 r
.37949 .23481 .39009 .24651 .40763 .24011 .39711 .22828 Mtetra
.656 .755 .923 r
.39711 .22828 .40763 .24011 .42528 .23369 .41484 .22171 Mtetra
.656 .754 .922 r
.41484 .22171 .42528 .23369 .44305 .22723 .43269 .21508 Mtetra
.657 .752 .92 r
.43269 .21508 .44305 .22723 .46094 .2207 .45066 .20839 Mtetra
.657 .751 .919 r
.45066 .20839 .46094 .2207 .47895 .21408 .46874 .20164 Mtetra
.657 .75 .918 r
.46874 .20164 .47895 .21408 .49708 .20739 .48695 .19483 Mtetra
.657 .749 .918 r
.48695 .19483 .49708 .20739 .51533 .20062 .50528 .18797 Mtetra
.50528 .18797 .51533 .20062 .53371 .19379 .52373 .1811 Mtetra
.654 .749 .919 r
.52373 .1811 .53371 .19379 .5522 .18691 .54231 .1743 Mtetra
.653 .751 .922 r
.54231 .1743 .5522 .18691 .57082 .18007 .56101 .16748 Mtetra
.654 .754 .923 r
.56101 .16748 .57082 .18007 .58957 .17329 .57984 .16056 Mtetra
.656 .754 .922 r
.57984 .16056 .58957 .17329 .60844 .16646 .5988 .15353 Mtetra
.657 .752 .92 r
.5988 .15353 .60844 .16646 .62744 .15948 .61789 .14641 Mtetra
.658 .751 .919 r
.61789 .14641 .62744 .15948 .64657 .15241 .6371 .13919 Mtetra
.657 .749 .918 r
.6371 .13919 .64657 .15241 .66583 .14523 .65645 .13199 Mtetra
.654 .75 .92 r
.65645 .13199 .66583 .14523 .68522 .13805 .67594 .12485 Mtetra
.654 .752 .922 r
.67594 .12485 .68522 .13805 .70475 .13096 .69557 .11766 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
[(-2)] .12586 .2075 1 .99877 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.56863 .04703 m
.57247 .05235 L
s
[(2)] .56094 .0364 .72324 1 Mshowa
.125 Mabswid
.18558 .19702 m
.18832 .19985 L
s
.23703 .17687 m
.23971 .17975 L
s
.28951 .15632 m
.29214 .15925 L
s
.39772 .11395 m
.40023 .11699 L
s
.4535 .09211 m
.45595 .0952 L
s
.51046 .06981 m
.51284 .07294 L
s
.08568 .23614 m
.08851 .23887 L
s
.62804 .02377 m
.63027 .02701 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 233.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00o?ooool2o`0006[ooooo003iooooo`?o000000?oooooo`000?ooool0
JOooool00?Oooooo0_l00004ooooo`;o0000JOooool00?Cooooo0ol00006ooooo`03o`000?oooooo
000006Sooooo003;ooooo`Go00008_ooool2o`0000Wooooo00?o0000ooooool00000J?ooool00<_o
oooo00GoV9RHob4Q8Oo^k^koooooodA4A00Oooooo`?o00002oooool01?l0003oooooooooool0001W
ooooo`00c?ooool00onHV9So8B4Qonk^kP0Mooooo`?o00003_ooool01Ol0003ooooooooooooooooo
000006Kooooo003=ooooo`03oiRHV?lQ8B7ok^k^01[ooooo0_l0000Aooooo`05o`000?oooooooooo
ooooool00000I_ooool00<kooooo00?oMgMgofIVI_ooool05_ooool3o`0001?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1Sooooo`00coooool00ol0003oooooooooo`0Cooooo`;o
00000_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0H_ooool00<_ooooo00Go0000okZj^_ooooooV9RHoa0@400Booooo`?o00006Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo06;ooooo003;ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`04?ooool2o`0001cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Qooooo`00
gOooool3o`0001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Qooooo`00fooo
ool2o`00027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Pooooo`00f?ooool3
o`0002?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Oooooo`00eOooool3o`00
02Kooooo00?o0000ooooooooool01?ooool2o`00067ooooo003Cooooo`;o0000:Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo05kooooo003@ooooo`?o000000?oooooo`000?ooool0
:?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05gooooo003>ooooo`;o00001Ooo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0GOoo
ool00<_ooooo0ol0000`ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0G?ooool0
0<Wooooo0_l0000cooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Foooool00<Ko
oooo0ol0000eooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Foooool00<Cooooo
0_l0000hooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0F_ooool00<7ooooo0ol0
000jooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03_ooool5o`0004Kooooo002n
ooooo`?o0000?Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00kooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A016ooooo`00_?ooool2o`0000?ooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo1_l00003ooooo`03oiRHV?lQ8B7o
k^k^04Oooooo002iooooo`?o0000@oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00kooooo00?oV9RHob4Q8Oo^k^h0A_ooool00;Oooooo0_l00016ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03oooool00omgMgOoIVIVooooo`15ooooo`00]?ooool3o`0004Sooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Cooooo
002booooo`;o0000Boooool00ol0003oooooooooo`0=ooooo`;o00003?ooool01Ol0003o^[Zjoooo
oonHV9So410@04Kooooo002_ooooo`?o0000COooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c016ooooo`00[Oooool2o`00053ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`1Dooooo`00Z_ooool4o`00057ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1Dooooo`00Z?ooool2o`0000Cooooo00?o0000oooo
ooooool0C_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05?ooooo001nooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h08_ooool3o`0005Oooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`1Booooo`00O_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01oooooo0ol0001Joooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool0D_ooool007kooooo00Go410@oooooooo
oooooooooa0@400Mooooo`;o0000GOooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
057ooooo001nooooo`05o`000?ooooooooooooooool000006_ooool3o`0005oooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`1@ooooo`00O_ooool01Ol0003ooooooooooooooooo0000
01Sooooo0_l0001Rooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0D?ooool007ko
oooo00Go410@oooooooooooooooooa0@400Eooooo`?o0000I?ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo04oooooo001nooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool2o`00
00?ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
04kooooo001nooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04?ooool3o`0006Sooooo00?oYl3/o`00
0?ooool05_ooool00ol0003oooooooooo`1>ooooo`00TOooool2o`0006Sooooo1?nW`>`00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo04gooooo002>ooooo`?o0000J?ooool7ojO0k003o`00
0?oooooooooo01Cooooo0ol0001>ooooo`00Roooool3o`0006Wooooo0_nW_n/7ojO0k003o`000?oo
oooooooo01Kooooo00?o0000ooooooooool0C?ooool008Wooooo0_l0001Yooooo`KoYko[1_nW`>`0
0ol0003oYl3/ooooo`0Gooooo`03o`000?oooooooooo04_ooooo0026ooooo`?o0000J?ooool00onX
_n_oYko[ojNoj`07ojNoj`GoYl3/00?o0000ojNojoooool06?ooool00ol0003oooooooooo`1:oooo
o`00Q?ooool2o`0000;ooooo00?o0000ooooooooool0Hoooool5ojRoj`WoYko[0_nW`>`2ojNoj`03
o`000?nW_n_oYko[01Sooooo00?o0000ooooooooool0B_ooool0087ooooo0ol00005ooooo`03o`00
0?oooooooooo063ooooo2?nX_n/7ojNoj`03ojRojonW_n_oYko[00;oYko[00Co0000ojNojonW_n_o
Yko[6?ooool00ol0003oooooooooo`19ooooo`00Ooooool2o`0006Wooooo00?oZ<3[ojRojonX_n/0
1onX_n/4ojNoj`GoZ;o[0onW_n/00ol0003oYko[ojNoj`02ojNojaSooooo00?o0000ooooooooool0
B?ooool007cooooo0ol0001Xooooo`GoZ<3[2OnX_n/00onW_n_oZ;o[ojRoj`06ojRoj`;oYko[00Go
0000ojNojonW_n_oYko[ojRoj`0Hooooo`03o`000?oooooooooo04Sooooo001jooooo`;o0000Iooo
ool:ojS0j`KoZ;o[0_nX`>/9ojRoj`;oYko[00?o0000ojNojonX_n/00onX_n/Hooooo`03o`000?oo
oooooooo04Oooooo001gooooo`?o0000I_ooool>ojS0j`;oZ;o[1_nX`>/9ojRoj`03ojNojol0003o
Z;o[00GoZ;o[6?ooool00ol0003oooooooooo`16ooooo`00M?ooool3o`0006Kooooo00?oYl7/ojS0
jonX`>/05onX`>/6ojRoj`;oZ<3[00?oZ;o[o`000?nX_n/01OnX_n/Hooooo`03o`000?oooooooooo
04Kooooo001booooo`;o00000_ooool00ol0003oooooooooo`1Rooooo`CoYl7/6OnX`>/2ojRoj`Ko
Z<3[00?o0000ojRojonX_n/01OnX_n/Hooooo`03o`000?oooooooooo04Gooooo001_ooooo`?o0000
Ioooool7ojO1k0OoZ<3[00?oYl7/ojS0jonX`>/05_nX`>/00ol0003oZ;o[ojRoj`04ojRoj`03ojS0
jooooooooooo01Kooooo00?o0000ooooooooool0AOooool006gooooo0_l0001Wooooo`[oYl7/1?nX
`>/5ojO1k1OoZ<3[00Co0000ojS0jonX_n_oZ;o[1OnX`>/Gooooo`;o0000A_ooool006[ooooo0ol0
001Vooooo`koYl7/00?oZ<3[ojO1k?nW`N`01_nW`N`7ojS0j`03ojO1k?nX`>_oZ<3[00coZ<3[00?o
0000ojS0jonX`>/01onX`>/Hooooo`03o`000?oooooooooo04?ooooo001Xooooo`;o0000I_ooool2
ojO0k0koYl7/0_nW`>`8ojO1k0CoZ<3[1OnW`N`=ojS0j`03o`000?nX`>_oZ<3[00SoZ<3[5oooool0
0ol0003oooooooooo`13ooooo`00IOooool3o`0006Gooooo1_nW`>`:ojO1k0KoYl3/2?nW`N`00onX
`>_oYl7/ojO1k006ojO1k0KoZ<3[00?oYl7/ojS0jonX`>/00onX`>/00ol0003oZ<3[ojS0j`08ojS0
jaSooooo00?o0000ooooooooool0@_ooool006?ooooo0_l0001Uooooo`03ojNojonW`>coYl3/00Oo
Yl3/1_nW`N`00onW_n_oYl3/ojO0k007ojO0k0KoYl7/00?oYl3/ojO1k?nW`N`01onW`N`4ojS0j`Co
Yl7/1OnX`>/00ol0003oZ<3[ojS0j`08ojS0jaSooooo00?o0000ooooooooool0@Oooool0063ooooo
0ol000000ooooooo0000ooooo`1Rooooo`CoYko[2OnW`>`2ojO1k0GoYko[2OnW`>`2ojO1k0GoYl3/
2OnW`N`00onX`>_oYl7/ojO1k005ojO1k0CoZ<3[00Co0000ojS0jonX`>_oYl7/2?nX`>/Gooooo`03
o`000?oooooooooo047ooooo000fooooo`Go00008oooool2o`0006Kooooo1onW_n/7ojO0k0WoYko[
1_nW`>`2ojNoj`SoYl3/1_nW`N`2ojO0k0SoYl7/1?nX`>/00ol0003oYl7/ojO1k002ojO1k0SoZ<3[
5oooool00ol0003oooooooooo`10ooooo`00=_ooool01OnHV9So8B4Qonk^k_ooooooA4A4023ooooo
0ol0001Uooooo`;oZ;o[2?nW_n/4ojO0k0goYko[0_nW`>`6ojNoj`SoYl3/0_nW`N`6ojO0k0SoYl7/
00CoZ<3[ojO1k?nW`Nco00001OnW`N`6ojS0j`03ojO0k?oooooooooo01Kooooo00?o0000oooooooo
ool0?oooool002kooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^01kooooo0ol0001Uooooo`KoZ;o[
2?nW_n/00onW`>coYko[ojNoj`0<ojNoj`03ojRojonW_n_oYko[00OoYko[1_nW`>`00onW_n_oYl3/
ojO0k007ojO0k0KoYl7/00GoY/3/ojO1k?nW`NcoYl7/o`000005ojO1k0CoZ<3[1?nW`>`Gooooo`03
o`000?oooooooooo03oooooo000hooooo`03oiRHV?lQ8B7ok^k^01_ooooo0_l0001Uooooo`[oZ;o[
1_nW_n/2ojRoj`coYko[1?nX_n/9ojNoj`;oYl3/1OnW_n/9ojO0k0;oYl7/1OnV`>`2ojO1k003o`00
0?nW`NcoYl7/00CoYl7/00?oZ<3[ojO0k?nW`>`01OnW`>`Gooooo`03o`000?oooooooooo03kooooo
000iooooo`03ogMgMomVIVKooooo01Oooooo0ol0001Tooooo`koZ;o[0_nW_n/6ojRoj`WoYko[1onX
_n/7ojNoj`03ojRojonW_n_oYko[00KoYko[1_nW`>`2ojNoj`SoY/3/00?oYl7/o`000?nW`N`00onW
`N`:ojO0k1Sooooo00?o0000ooooooooool0?Oooool003[ooooo00?o0000ooooooooool05?ooool2
o`0006Cooooo6_nX_n/6ojNoj`[oZ;o[1?nW_n/4ojRoj`SoYko[0_nW`>`6ojNoj`SoY/3/00?o0000
ojO1k?nW`>`03OnW`>`Gooooo`03o`000?oooooooooo03gooooo000fooooo`05o`000?nj^[[ooooo
oiRHV?l@41004oooool3o`0000;ooooo00?o0000ooooooooool0GooooolMojRoj`;oYko[3_nX_n/0
0onW_n_oZ;o[ojRoj`05ojRoj`KoYko[00?oZ;o[ojNojonW_n/01onW_n/6ojK0k003ojNojol0003o
Yl3/00koYl3/6?ooool00ol0003oooooooooo`0looooo`00=_ooool01OnHV9So410@o`000?lQ8B7o
c<c<017ooooo0_l0001Uooooo`koZ;o[00?oZ<3[ojRojonX_n/03?nX_n/2ojS0j`koZ;o[0_nX`>/8
ojRoj`CoYko[1?nX_n/9ojNoj`;oY/3/1?nW_n/00ol0003oYl3/ojO0k00>ojO0k1Kooooo0ol0000m
ooooo`00BOooool3o`0006Gooooo00?oZ<3[ojRojonX_n/02onX_n/4ojS0j`[oZ;o[1_nX`>/:ojRo
j`KoZ<3[2?nX_n/00onW_n_oZ;o[ojRoj`05ojRoj`OoYko[00?oZ;o[ojNojonW_n/01?nW_n/00ol0
003oYko[ojO0k005ojO0k0;oYko[2?nW`>`Gooooo`03o`000?oooooooooo03_ooooo0017ooooo`;o
0000IOooool5ojS0j`[oZ;o[1onX`>/6ojRoj`03ojS1k?nX`>_oZ<3[00OoZ<3[1_nX_n/:ojS0j`Ko
Z;o[00?oZ<3[ojRojonX_n/01_nX_n/4ojNoj`GoZ;o[1OnW_n/00ol0003oYko[ojNoj`02ojO0k0Ko
Yko[2?nW`>`Gooooo`03o`000?oooooooooo03[ooooo0014ooooo`?o0000I?ooool9ojS0j`KoZ;o[
0_nX`N`8ojS0j`CoZ;o[1?nX`N`9ojS0j`;oZ;o[3_nX`>/2ojRoj`GoZ<3[2?nX_n/00onW_n_oZ;o[
ojRoj`06ojRoj`CoYko[00?o0000ojNojonX_n/02OnW_n/6ojO0k003ojJojooooooooooo01Kooooo
00?o0000ooooooooool0>Oooool0047ooooo0ol0001Tooooo`goZ<3[0_nX_n/6ojS1k0SoZ<3[00?o
Z;o[ojS1k?nX`N`01OnX`N`7ojS0j`03ojO1k?nX`>_oZ<3[00coZ<3[0_nX`N/8ojS0j`KoZ;o[0_nX
`>/9ojRoj`;oYko[00?oZ;o[o`000?nX_n/00_nX_n/9ojNoj`;oYl3/1OnV_n/Gooooo`03o`000?oo
oooooooo03Wooooo000oooooo`?o0000Hoooool00onW`NcoZ<3[ojS0j`0<ojS0j`;oYl7/2?nX`N`6
ojS0j`;oYl7/2?nX`N`4ojS0j`CoYl7/2_nX`>/6ojS1j`SoZ<3[0_nX_n/6ojS0j`OoZ;o[00GoZ<3[
ojRojonX_n_oZ;o[o`000004ojRoj`KoYko[0_nX_n/8ojJojaOooooo00?o0000ooooooooool0>?oo
ool003cooooo0ol00003ooooo`03o`000?oooooooooo05kooooo1?nW`N`:ojS0j`KoYl7/2?nX`N`2
ojS0j`KoYl7/2?nX`N`00onX`>_oYl7/ojO1k005ojO1k0KoZ<3[0_nW`N`8ojS1j`KoZ<3[00?oZ<7[
ojS0jonX`>/01onX`>/4ojRoj`CoZ<3[0_nX_n/00ol0003oZ;o[ojRoj`03ojRoj`;oYko[1_nX_n/8
ojJojaKooooo00?o0000ooooooooool01oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02cooooo000j
ooooo`;o0000IOooool7ojO1k0KoZ<3[2_nW`N`6ojS1k0[oYl7/1_nX`N`:ojO1k0;oZ<3[1_nW`N`8
ojS1j`;oZ<3[1OnX`N/9ojS0j`03ojRojonX`>_oZ<3[00GoZ<3[00?oZ;o[o`000?nX_n/00onX_n/0
0onX`>_oZ;o[ojRoj`07ojRoj`KoY[o[00?oYko[ooooooooool05Oooool00ol0003oooooooooo`06
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0;?ooool003Oooooo0ol0001Uooooo`[oYl7/0_nX`>/>
ojO1k0;oZ<7/3_nW`N`2ojS1k0coYl7/00?oY/3/ojO1k?nW`N`01onW`N`6ojS1j`03ojO1k?nX`N_o
Z<7[00KoZ<7[1_nX`>/2ojS1j`SoZ<3[0_nX_n/00ol0003oZ;o[ojS0j`03ojS0j`WoZ;o[0_nV_n/5
ojNojaOooooo00?o0000ooooooooool01Oooool01Ol@413ooooooooooooooooo410@02cooooo000e
ooooo`;o0000IOoooolLojO1k003ojO0k?nW`NcoYl7/00coYl7/0_nW`>`<ojO1k0CoY/3/2OnW`N`2
ojS1j`GoYl7/2?nX`N/2ojS0j`KoZ<7[2?nX`>/00onX_n_o0000ojS0j`05ojS0j`KoZ;o[0_nX`>/8
ojNojaKooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000002cooooo000b
ooooo`?o0000I?oooolLojO1k0GoYl3/2_nW`N`6ojO0k0WoYl7/1onV`>`6ojO1k0;oY[o/2?nW`N`6
ojS1j`03ojO1k?nX`N_oZ<7[00OoZ<7[2?nX`>/00ol0003oZ<3[ojS0j`05ojS0j`;oZ;o[1_nX`>/8
ojNojaKooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000002cooooo000`
ooooo`;o0000I?oooolLojO1k003ojNojonW`>coYl3/00KoYl3/1_nW`N`2ojNoj`SoYl3/1_nW`N`0
0onW_n_oY/3/ojK0k007ojK0k0;oYl7/1_nV_n`8ojO1k0;oZ<7[1OnW`N`9ojS1j`OoZ<3[00?o0000
ojS0jonX`>/03OnX`>/6ojNoj`;oZ<3[5oooool00ol0003oooooooooo`03ooooo`05oa0@4?oooooo
ooooooooool@4100;?ooool002gooooo0ol000000ooooooo0000ooooo`1Pooooo`ooYl7/0_nW`>`;
ojO1k0GoYko[2?nW`>`2ojO1k0KoYko[2?nW`>`2ojO1k0GoYko[1onV`>`2ojNoj`SoY[o/1_nW`N`0
0onV_ncoYl7/ojO1k006ojO1k0KoZ<7[0_nW`N`7ojS0j`03o`000?nX`>_oZ<3[00koZ<3[0_nW_n/6
ojS0jaKooooo0_l00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0;?ooool002[ooooo0ol0001S
ooooo`ooYl7/1_nW`>`7ojO1k0WoYko[1_nW`>`2ojNojPSoYko[1_nW`>`00onX_n[oYko[ojNoj`06
ojNoj`CoY/3/1OnW_n/8ojJok0;oYl7/1OnV_n`8ojO1k0;oZ<7[1_nW`N`6ojS0j`03o`000?nX`>_o
Z<3[01OoZ<3[4oooool2o`000003ooooool0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0/ooooo`00:?ooool2o`0006?ooooo3onW`N`:ojO0k0CoYl7/3?nW_n/2ojO0k0KoYkoZ2?nW_n/2
ojO0k0GoZ;oZ2?nW_n/00onV`>coYko[ojNoj`06ojNoj`KoY[o/00?oYko[ojJok?nV_n`01_nV_n`6
ojO1k003ojJok?nW`NcoYl7/00OoYl7/1OnX`>/00ol0003oYl7/ojS0j`0HojS0jaKooooo00?o0000
ooooooooool0<_ooool002Gooooo0ol0001Rooooo`ooYl7/3_nW`>`00onW`NcoYko[ojNoj`0;ojNo
j`;oZ;oZ2?nW_nX6ojNoj`WoZ;oZ1_nW_n/00onX_n[oYko[ojNoj`08ojNoj`;oY[o/1OnW_n/8ojJo
k0;oYl7/1OnV_n`9ojO1k0;oZ<3[00?oYl7/o`000?l000000_nW`N`HojS0jaKooooo00?o0000oooo
ooooool0<_ooool002?ooooo0_l0001Rooooo`ooYl7/0_nW`>/>ojO0k003ojNoj_nW_n_oYko[00Wo
Yko[1_nX_nX8ojNojP;oYko[3OnX_nX2ojNoj`GoZ;oZ2?nW_n/00onX_n[oYko[ojNoj`06ojNoj`Ko
Y[o/00?oYko[ojJok?nV_n`01_nV_n`6ojO1k0;oY[o/0ol000000onW`Nco0000ojO1k002ojO1k0Ko
Z<3[00?oZ<7/ojS0jonX`>/03onX`>/Fooooo`03o`000?oooooooooo037ooooo000Pooooo`?o0000
H_ooool>ojO1k0KoYl3[2_nW`>`5ojNojPOoYko[2_nX_nX6ojNojQSoZ;oZ1?nW_n/5ojRojPSoYko[
0_nV_n`5ojNoj`SoY[o/0_nW`N`2ojJok0?o000000?oY[o/ojO1k?nW`N`00_nW`N`01?l0003oYl7/
ojO1k?nW`N`2ojS0j`GoZ<7/4?nX`>/Gooooo`03o`000?oooooooooo033ooooo000Oooooo`;o0000
H_ooool=ojO1k0[oYl3[1_nW`>`9ojNojPCoYko[3OnX_nX2ojNojQcoZ;oZ00?oYko[ojRoj_nX_nX0
1_nX_nX6ojNoj`03ojRoj_nW_n_oYko[00KoYko[1_nV_n`00onW_n_oY[o/o`000002o`0000CoY[o/
1OnW`N`00ol0003oY/3/ojK0k008ojS1k13oZ<3[5_ooool00ol0003oooooooooo`0`ooooo`007ooo
ool00ol0003oooooo`00001Oooooo`coYl7/3_nW`>/2ojO0k0goYkoZ00?oYko[ojRoj_nX_nX03?nX
_nX00onX_n_oZ;oZojRojP0<ojRojP03ojS0jonX_n[oZ;oZ01KoZ;oZ1?nW_n/4ojRojPSoYko[0_nV
_n`2ojNoj`?o00002?nV_n`2ojO1k0?oY/3/00?o0000ojK0k?nV`>`02?nX`N`?ojS0jaOooooo00?o
0000ooooooooool0;oooool000cooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_oo
ool01?l0003oooooooooool0001Kooooo`coYl7/4?nW`>/?ojNojPkoZ;oZ1?nX_n/:ojRojPGoZ<3[
6?nX_nX00onW_n_oZ;oZojRojP05ojRojPKoYko[00?oZ;oZojNojol000000_l00004ojNoj`KoY[o/
00?oYko[ojK0k?nV`>`00onV`>`01?l0003oY/3/ojK0k?nV`>`6ojS1k003ojO0k?nX`>_oZ<3[00ko
Z<3[5oooool00ol0003oooooooooo`0^ooooo`003?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`;o00000_ooool00ol0003oooooooooo`1Eoooo
o`coYl7/4?nW`>/?ojNojPooZ;oZ1onX_n/6ojRojP03ojS1k?nX`>_oZ<3[00KoZ<3[1_nX_nX00onX
`NcoZ;oZojRojP0=ojRojP03ojS0jonX_n[oZ;oZ00OoZ;oZ0_nW_n/2ojRojP?o00002?nW_n/2ojJo
k0GoYko[1OnV`>`01?l0003oY/3/ojK0k?nV`>`2ojS1k0GoYl3/1onX`>/00onW`NcoZ<3[ojS0j`06
ojS0jaKooooo00?o0000ooooooooool0;_ooool000Cooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^
00Cooooo00Go410@oooooooooooooooooa0@4005ooooo`;o00001?ooool00ol0003oooooooooo`1A
ooooo`goYl7/3onW`>/?ojNojQ3oZ;oZ00?oZ<7[ojRojonX_n/01onX_n/2ojRojPGoZ<7/2?nX`>/2
ojRojPGoZ<7/2onX_nX5ojS0j`OoZ;oZ00?oZ<3[ojRoj_l000000_l00004ojRojPKoYko[00?oZ;oZ
ojNojonW_n/01_nW_n/5ojK0k003o`000?nV_n_oY[o[00SoYl3/1?nX`>/4ojO1k0SoZ<3[5_ooool0
0ol0003oooooooooo`0]ooooo`003_ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooooooo
ooooool000001Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04gooooo3_nW`N`>
ojO0j`ooYkoZ4?nX_nX5ojS1j`OoZ;o[00?oYl;]ojS1k?nX`N`01_nX`N`6ojS0j`03ojO2kOnX`Nco
Z<7/00KoZ<7/1_nX_nX2ojS2k0SoZ<3[1?nX_nX2ojS0j`;o00002?nX_nX2ojNoj`GoZ;oZ2?nW_n/2
ojK0k0;oY[o[00Co0000ojJojonV_n_oY[o[2?nW`>`00onX`>_oYl7/ojO1k005ojO1k0OoZ<3[5ooo
ool00ol0003oooooooooo`0/ooooo`003oooool00omgMgOoIVIVooooo`02ooooo`05o`000?oooooo
ooooooooool000001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04Wooooo3onW
`N`=ojO0j`ooYkoZ0_nW_n/>ojRojP03ojS1k?nX`N_oZ<7[00KoZ<7[1?nX_n/4ojO2k@SoZ<7/0_nX
`>/5ojO2k@SoZ<7/0_nX_nX6ojS2k0SoZ<3[00?oZ;oZojS0jol000000_l00003ojS0j`KoZ;oZ00?o
Z<3[ojRoj_nX_nX01_nX_nX6ojNoj`03ojRojonV_n_oY[o[00?oY[o[00?o0000ojJojonV_n/01_nW
`>`3ojK0k0SoYl7/1onX`>/Eooooo`;o0000;_ooool0013ooooo00Go0000oooooooooooooooooa0@
4003ooooo`03oa0@4?oooooooooo00?ooooo0_l00007ooooo`03o`000?oooooooooo04Kooooo3onW
`N`2ojS0j`[oYl3[3onW_nX6ojNoj`[oZ;oZ1OnX`N`8ojS1j`03ojRojonW`^goYl;]00GoYl;]1_nX
`N`00onV`NgoYl;]ojO2k@06ojO2k@KoZ<7/0_nV`Nd8ojS2k0KoZ<3[0ol00007ojS0j`;oZ;oZ1OnX
`>/8ojRojP;oYko[1OnX_n/5ojJoj`03o`000?nV_n_oY[o[00;oYl3/1onV`>`6ojO1k003ojO0k?nX
`>_oZ<3[00KoZ<3[5_ooool00ol0003oooooooooo`0[ooooo`003?ooool01Ol0003o^[ZjoooooonH
V9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0@_ooool?ojO1k0KoZ<3[1_nW`>/?ojNojP[oYko[1_nX_nX00onW`^coZ<7/
ojS1k006ojS1k0KoZ<7[2_nW`^d2ojS1k0GoY/7]2?nW`^d2ojS1k0KoY/7]2?nX`^`2ojS0j`?o0000
0onX`^`6ojS0j`03ojS1k?nX`>_oZ<3[00KoZ<3[1_nX_nX00onX`>[oZ;o[ojRoj`06ojRoj`GoY[o[
00?o0000ojNojonW_n/02OnV`>`2ojO1k0GoYl3/2?nX`>/Eooooo`03o`000?oooooooooo02_ooooo
000<ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0nooooo`;oYl3[3OnW`N`2ojS1k0So
Z<3[0_nW`>/?ojNojPkoYko[0_nX_nX5ojO2k0SoZ<7/0_nX`N/<ojO2k@03ojK0k?nV`NgoY/7]00Ko
Y/7]1_nW`^d2ojK0k0SoY/7]1_nX`^`3o`0000OoZ<;/0_nX`>/5ojS1k0SoZ<3[0_nX_nX5ojS0jPSo
Z;o[0_nV_n/2ojNoj`04o`000?nW_n_oYko[ojNoj`KoY/3/0_nV_n/8ojO0k0OoZ<3[5_ooool00ol0
003oooooooooo`0Zooooo`007_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03[o
oooo1_nW`>/9ojO1k0KoZ<7/1_nX`>/@ojNojPooYko[00?oYl;]ojO2k?nW`^`01_nW`^`6ojS1k0;o
Yl7/2_nW`^d5ojK0k0SoY/7]0_nW`^d6ojK0k0SoY/7]0_nX`^`3o`0000?oY/7]1_nX`^`00onV`>go
Z<7/ojS1k006ojS1k0KoZ<3[00?oZ<7/ojS0j_nX`>X01_nX`>X6ojRoj`03ojS0j_nW_n_oYko[00?o
Yko[00Co0000ojNojonW_n_oYko[0_nV`>`6ojJoj`SoYl3/1onX`>/Fooooo`03o`000?oooooooooo
02Wooooo000Mooooo`?o00002oooool00ol0003oooooooooo`0fooooo`;oYko[2?nW`>/5ojO1k0[o
Z<7/0onX`>/?ojNojPooYko[1OnW`^d8ojO2k0;oZ<7/1_nW`N`6ojO2k@;oYko[1onV`>`6ojK1k@;o
Yko[2?nV`>`6ojK1k@?o00001onV`Nd2ojS2k0GoY/3]2?nX`N`2ojS0j`GoZ<7/2?nX`>X2ojRoj`Go
Z<3Z1OnW_n/00ol0003oYko[ojS0j`08ojJoj`KoYl3/0_nV`>`7ojS0jaKooooo00?o0000oooooooo
ool0:Oooool001gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0booooo`KoYko[
2?nW`>/00onW`NcoZ<7/ojS1k00<ojS1k003ojS0jonW_n[oYkoZ00_oYkoZ3onW_n/9ojO2k@KoYl;/
0_nW`>`8ojO1k0;oYl;]1_nW_n/7ojK0k0;oY/7]1_nW_n/8ojK0k0;oY/7]0ol00003ojJoj`KoY/7]
00?oY[o[ojK0kOnV`>d01_nV`>d6ojS1k003ojK1kOnX`NcoZ<7/00KoZ<7/1_nX`>X00onX`N_oZ<3Z
ojS0jP06ojS0jPCoYko[00CoZ<3[o`000?nX`>_oZ<3[2?nV_n/2ojO0k0KoY/3/1onX`>/Fooooo`03
o`000?oooooooooo02Sooooo000Mooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
;oooool9ojNoj`KoYl3[3onX`N`2ojNoj`[oYkoZ3onW_n/=ojO2k@;oYl;/1_nW`>`6ojO1k0;oYkoZ
2?nW_n/5ojK0k0;oZ;kZ2?nW_n/6ojK0k0?o00001onV_n/2ojK1k@GoY[o[2?nV`>d2ojS1k0GoY/7]
2?nX`N`2ojS0jPGoZ<7[2?nX`>X01OnW_n_oZ<3[ojS0jonX`>_o000000?oZ<3[1_nV_n/00onW_n_o
Y/3/ojK0k006ojK0k0KoZ<3[00?oYl3/ooooooooool05Oooool00ol0003oooooooooo`0Wooooo`00
7Oooool2o`0000oooooo00?o0000ooooooooool0:oooool=ojNoj`;oYl3[3onX`N`6ojNoj`KoYkoZ
3onW_n/?ojO2k@?oYl3[1onW`>`2ojO1k0KoYkoZ2?nW_n/00onV`>coZ;kZojRnjP04ojRnjPSoYko[
0_nV`>`00onW_n[o0000o`000002ojNojPOoY[o[00?oZ;oZojJojonV_n/01_nV_n/6ojK0k@03ojJo
jonV`NgoY/7]00KoY/7]1_nX`N`00onV`NcoZ<7[ojS1j`06ojS1j`KoZ<3Z0_nY`>/4ojS0j`04o`00
0?nX`>_oZ<3[ojS0j`;oY[o[1OnW_n/8ojK0k0;oZ<3[1OnW`>`Fooooo`03o`000?oooooooooo02Oo
oooo000Mooooo`03o`000?oooooooooo00oooooo0_l0000Xooooo`ooYko[3onX`N`:ojNoj`;oYkoZ
3onW_n/?ojO2k@OoYl3[1OnW`>`2ojNnjPSoYkoZ1_nW_n/00onX_^WoZ;kZojRnjP06ojRnjPKoYko[
00CoZ;kYo`000?l0003o00001OnW_nX4ojJoj`CoZ;oZ2?nV_n/2ojK0k@GoY[o[2?nV`Nd2ojS1k0Go
Y/7/2?nX`N/2ojS0jPKoZL3[1?nX`>/00ol0003oZ<3[ojS0j`08ojNoj`KoY/3/00?oY[o/ojO0k?nW
`>`01_nW`>`Fooooo`03o`000?oooooooooo02Kooooo000Mooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool08_ooool?ojNoj`ooZ<7/6onW_n/?ojO2k@_oYl3[00?oYl3/ojNnj_nW_^X0
1?nW_^X8ojNojP;oYko[1OnX_^T8ojRnjP;oYko[00GoZ;kYo`000?l0003o0000ojRnj@08ojNojP03
ojJojonX_n[oZ;oZ00GoZ;oZ1_nV_n/00onX_n[oY[o[ojJoj`06ojJoj`KoY/7]00?oYKo/ojK1k?nV
`N`01_nV`N`6ojS1j`03ojS1k?nY`>_oZL3[00OoZL3[1?nX`>/00ol0003oZ<3[ojS0j`08ojNoj`;o
Y/3/1OnV_n`8ojO0k1Kooooo00?o0000ooooooooool09Oooool001gooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0Nooooo`ooYko[0_nW`N`=ojS1k1_oYko[3onW`^d=ojO0j`WoYkkZ
1_nW_nX9ojRnj@KoZ;kZ00CoZ;kYo`000?l0003o00001OnX_^T6ojNojP;oZ;kY2?nX_nX2ojJoj`Go
Z;oZ2?nV_n/2ojK1k@GoYKo/2?nV`N`2ojS1j`GoZ<7/1onY`>/5ojS0j`04o`000?nX`>_oZ<3[ojS0
j`KoYko[00?oZ<3[ojJok?nV_n`01_nV_n`7ojO0k1Kooooo0_l0000Vooooo`007?ooool3o`0001Co
oooo00?o0000ooooooooool06_ooool?ojNoj`KoYl7/2OnX`N`LojNoj`03ojO2k?nW`^goYl;]00co
Yl;]3OnW`>/<ojNnjP;oYkoZ3OnX_^T2ojRnjP04ojRnjOl0003o0000o`0000WoZ;kY0_nW_nX6ojRn
j@KoZ;oZ00?oZKoYojRoj_nX_nX01_nX_nX6ojJoj`03ojRoj_nU_ncoYKo/00KoYKo/1_nV`N`00onU
_ncoZ<7/ojS1k006ojS1k0CoZL3[2?nX`>/01?l0003oZ<3[ojS0jonX`>/2ojNoj`GoZ<3[2?nV_n`7
ojO0k1Cooooo00?o0000ooooool000009_ooool001cooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`0Gooooo`ooYko[0_nW`>/7ojO1k0KoZ<7/00?oZ<3[ojNojonW_n/03?nW_n/2ojNn
jP[oYko[1OnW`^`:ojO2k@koYl3[3OnW_^X?ojRnj@04ojS0jol0003o0000o`0000_oZ;kY00?oZL3Z
ojRnjOnX_^T01onX_^T2ojRojPGoZKoY2?nX_nX2ojJoj`GoZ;oZ2?nU_n`2ojK1k0GoYKo/2?nX`N`0
0onY`>_oZ<3[ojS0j`09ojS0j`03o`000?nX`>_oZL3[00SoZ<3[1_nV_n`00onV_n_oYl3/ojO0k006
ojO0k1Kooooo00?o0000ooooooooool08oooool000[ooooo1?l000002?l@413oooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^1_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01?ooooo
3onW_n/6ojO0j`OoYl7/0_nX`N`5ojS0j`[oYko[1_nW_^X6ojNoj`03ojO1k?nW`^coYl;/00KoYl;/
1_nW`^d?ojO0j`coYkkZ3onX_^T01OnX`>_o0000o`000?l0003oZ<3[00[oZ;kY1OnY`>X7ojRnj@03
ojW1jonY_nWoZKoY00KoZKoY1_nX_nX00onY_nWoZ;oZojRojP06ojRojPKoYKo/0_nW_n/7ojFok0Ko
Z<7/0_nV`>`:ojS0j`03ojW0jol0003oZL3[00;oZL3[2?nX`>/2ojJok0GoY[o[2?nW`>`Eooooo`03
o`000?oooooooooo02?ooooo000<ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`06ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool03oooool2ojS0j`oo
Yko[2?nW`>/5ojO1k0;oZ<7/1onX`>/6ojNoj`?oYkk[1onW_^X2ojNoj`GoYl7/2?nW`^`2ojO2k@oo
Yl3[3?nW_^X00onX_n[oZ;kYojRnj@0<ojRnj@04ojS2k?l0003o0000o`0000GoZ<3[1_nX_^T00onX
`ncoZL3ZojW0jP06ojW0jPCoZ;kY1?nY`N/8ojVoj@;oZ;oZ1OnY_nT8ojRojP;oYKo/1_nW_n/7ojFo
k0;oZ<7/1_nV`>`6ojS0j`03ojS1k?nY`>_oZL3[00;oZL3[00Co0000ojW0jonY`>_oZL3[1onX`>/7
ojJoj`KoYl3/0_nV`>`Fooooo`03o`000?oooooooooo02;ooooo00000ooooooo0000o`000004o`00
00Gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Kooooo0_l0000I
ooooo`03o`000?oooooooooo00cooooo1OnX`>/?ojNoj`SoYl3[00?oYl7/ojS1k?nX`N`01?nX`N`7
ojS0j`;oYko[1onW_^/5ojNnjP;oYl3/1onW`N`6ojO2k0;oZ<7/3OnW`>/<ojNnjPGoZ;oZ2_nX_^T2
ojS2k0;o000000?oZ<;/ojS0jonX`>/01_nX`>/2ojRnj@GoZ<?/2?nY`>X00onX_^WoZL7[ojW1j`05
ojW1j`KoZKoY00?oZL7[ojVojOnY_nT01_nY_nT6ojRojP03ojVoj_nW_n_oYko[00OoYko[0onU_n`4
ojJok0SoY/3/0_nX`>/5ojS1k0CoZL3[00Co0000ojW0jonY`>_oZL3[1onX`>/7ojJoj`;oYl3/1_nV
`>`Fooooo`03o`000?oooooooooo027ooooo000<ooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02_oo
ool7ojS0j`ooYko[1_nW`>/9ojS1k0GoZ<3[0onW_n/8ojNnj`03ojNnj_nW`>coYl3/00CoYl3/1onW
`N`2ojO2k0KoZ<7/2OnW`>/<ojNnjPWoZ;oZ1_nX_^T00onX`ngoZ<;/o`000002o`0000CoZ<;/1_nX
`>/2ojK1k@OoZ<?/1_nY`>X2ojO2k@SoZL7[0_nY_nT5ojW1j`SoZKoY0_nX_nX5ojVojPOoYko[00?o
Z;oZojJok?nV_n`01_nV_n`6ojK0k003ojFok?nX`NcoZ<7/00GoZ<7/1OnY`>/00ol0003oZL3[ojW0
j`07ojS0j`KoY[o[0_nW_n/8ojK0k1Gooooo00?o0000ooooooooool08Oooool000cooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`07ooooo`?oZ<7[1onX`>/?ojNoj`;oYl3[3OnX`N`00onX`>_oYko[ojNo
j`05ojNoj`KoYkk[00?oYko[ojO0k?nW`>`01_nW`>`5ojO1k0[oZ<7/1OnW`>/<ojNnjPgoZ;oZ0_nX
_^T2ojS3k@?o00002?nX`^`2ojS0j`KoY/7]1onX`n`2ojW0jPKoYl;]1_nY`N/00onV`NgoZL7[ojW1
j`06ojW1j`KoZKoY00?oZL7ZojVoj_nY_nX01_nY_nX4ojNoj`CoZ;oZ2?nV_n`2ojK0k0GoYKo/1onX
`N`4ojW0j`04o`000?nY`>_oZL3[ojW0j`OoZ<3[0_nV_n/6ojNoj`KoY/3/00?oY[o/ooooooooool0
5?ooool00ol0003oooooooooo`0Pooooo`003?ooool00ol0003oooooooooo`02ooooo`05oa0@4?oo
ooooooooooooool@41001Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00?ooooo
1onX`N/5ojS0j`ooYko[0_nW`N`=ojS1k0[oYko[0_nW_^/5ojNoj`SoYl3/00?oYl7/ojS1k?nX`N`0
3?nX`N`00onW`>_oYkkZojNnjP0:ojNnjP;oYko[3OnX_nX2ojO2k@?o00001?nX`nd6ojS2k0;oY[k[
2?nV`Nd3ojS3k0CoYKk[2?nW`^d2ojW1j`GoY/7]2?nY`N/2ojVoj@GoZL7Z2?nY_nX00onW_n_oZ;oZ
ojRojP05ojRojPKoY[o/00?oYko[ojFok?nU_n`01OnU_n`6ojS1k003ojO0k?nY`>_oZL3[00?oZL3[
00?o0000ojW0jonY`>/02?nX`>/8ojNoj`;oY/3/1OnV_n`Fooooo`03o`000?oooooooooo01oooooo
000<ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o0000
7_ooool00ol0003oooooojS1j`0:ojS1j`03ojS0jonW_n_oYko[00goYko[1_nW`N`9ojS1k1GoYko[
1_nW`>`00onX`^coZ<7/ojS1k00<ojS1k0_oYkkZ1_nW_n/9ojRojP;oYl;]0ol000000onW`^goZ<?]
ojS3k@05ojS3k@;oZ<;/1_nV_^/6ojK1k@03ojNhi_nU_^_oYKk[00KoYKk[1_nW`^d00onV_>WoY/7]
ojK1k@06ojK1k@KoZL7[00?oYl7]ojW1j_nY`NX01_nY`NX6ojVojP;oZL3Z2?nX_nX2ojJok0GoYko[
1onU_n`2ojS1k0GoYl3/1OnY`>/00ol0003oZL3[ojW0j`08ojS0j`OoYko[2?nV_n`Eooooo`03o`00
0?oooooooooo01oooooo000:ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`03o`000?oooooooooo01cooooo3OnX`N/2ojO0j`koYko[2?nW`N`5ojS1k0?oZ<3[
5_nW_n/2ojO0k0GoZ<;/2_nX`N`=ojNnjPSoYko[1_nX_nX01?nW`^go0000o`000?l00005ojO2k@Go
Z<?]0_nW^nP8ojJnj`;oY/7]1OnW^>H8ojFnj`;oYl;]1OnV_>T8ojK1k@;oZL7[1OnW`Nd8ojW1jP;o
ZKoZ1_nY`>X6ojRojP03ojVoj_nW_n_oYko[00GoYko[1onU_n`8ojO0k0GoZL3[00?o0000ojW0jonY
`>/02?nX`>/7ojNoj`SoY[o/5Oooool00ol0003oooooooooo`0Nooooo`006oooool00ol0003ooooo
ooooo`0Jooooo`?oYl3[2OnX`N/6ojO0j`koYko[2?nW`N`00onX`NcoZ<3[ojS0j`05ojS0j`GoYko[
0_nW_^/=ojNoj`WoZ<;/1_nX`N`2ojNojPooYkkZ2?nW_n/2ojRojP04ojO2kOl0003o0000o`0000Wo
Yl;]00?oZ<?]ojNkj?nW^nP01?nW^nP6ojJnj`03ojRchOnW^>KoYkSV00KoYkSV1_nU_^/00onY]^;o
Y[cYojJlj@06ojJlj@KoY/7]0_nV_>T7ojO1k@KoZL7Z0_nX`^`8ojW0jP;oZ;oZ1OnY_nX7ojNoj`Oo
YKo/2?nW`>`4ojW0j`04o`000?nY`>_oZL3[ojW0j`KoZ<3[00?oZL3[ojNojonW_n/01_nW_n/7ojJo
k1Kooooo00?o0000ooooooooool07Oooool001_ooooo00?o0000ooooooooool05oooool7ojO0j`Oo
Z<7[2?nW`>/>ojNoj`KoYl7/0_nX`N`8ojS0j`03ojNojonW_^_oYkk[00CoYkk[2OnW_n/=ojS2k0;o
Z<7/1_nW_nX?ojNnjPKoYko[00CoYl;]o`000?l0003o00002onW`^d00onW^>KoYk_XojNkj006ojNk
j0?oY[k[1?nX/n48ojNhiP;oYKk[1OnY]^88ojJlj@;oY/7]1_nV_>T7ojO1k@;oZL7Z1_nX`^`6ojW0
jP03oj[2jonY_n[oZKoZ00GoZKoZ1_nW_n/2ojRoj`OoYKo/1_nW`>`2ojK0k0CoZL3[00Co0000ojW0
jonY`>_oZL3[0_nX`>/5ojW0j`SoYko[1onV_n`Dooooo`;o00007oooool001_ooooo0_l0000Foooo
o`?oYko[1onW`>/7ojS1j`SoYl3[3_nW_n/2ojO1k0KoZ<7/1_nX`>/2ojNoj`OoYkk[1_nW_n/00onW
`NcoZ<;/ojS2k00;ojS2k0?oYko[1onW_nX?ojNnjP;oYko[0_nW`^d2o`0000_oYl;]1OnW^>H8ojNk
j003ojJnjonX/n7oZ;?Q00CoZ;?Q1_nW^>H00on[[MWoZKKRojVfhP06ojVfhPKoY[cY00?oZkKQojJl
jOnV_>T01onV_>T3ojO1k@CoYKg[2?nX`^`2ojW0jPGoZ/;[1onY_nX2ojNoj`KoZ;o[1onU_n`2ojO0
k0KoY/3/1?nY`>/00ol0003oZL3[ojS0j`08ojW0j`KoYko[00?oYl3[ojJok?nV_n`01OnV_n`Foooo
o`03o`000?oooooooooo01cooooo000Jooooo`03o`000?oooooooooo01?ooooo1onW_n/5ojO0j`Wo
Z<7[1_nW`>/>ojNoj`[oZ<7/0_nX`>/6ojNoj`OoYkk[0_nW_n/5ojO1k0WoZ<;/1onW_n/5ojNojP;o
YkgZ3OnW_^X00onX`^goYl;]o`000002o`0000[oYl;]00?oYkOTojNhi_nW^>H01_nW^>H6ojNkj003
ojR]fonX/n7oZ;?Q00GoZ;?Q1?nW^>H4oj^]f@SoZKKR0_nV_>T5oj^fh@OoY[cY00?oZkSSojFmjonU
_N/01_nU_N/6ojS2k003ojFok?nZ`^_oZ/;[00GoZ/;[1_nY_nX00onZ`>[oZ;o[ojRoj`07ojRoj`?o
YKo/1?nV_n`8ojK0k0;oZL3[0_nX`>/00ol0003oZ<3[ojS0j`08ojW0j`;oYko[1OnW`>/7ojJok1Go
oooo00?o0000ooooooooool07?ooool001[ooooo00?o0000ooooooooool03oooool<ojNoj`03ojO0
jonX`N_oZ<7[00_oZ<7[0_nW`>/>ojNoj`coZ<7/2_nW_n/5ojNnj`;oYko[1onW`N`6ojS2k0;oZ<3[
2?nW_n/00onW_n[oYkgZojNmjP04ojNmjPWoYkkZ0_nX`^d3o`0000[oYl;]1OnW]n@8ojNhiP;oYk_X
1OnX[M/7ojRch@03ojNhi_n[[MWoZjgI00GoZjgI1_nY]^800on]ZmGoZkKQoj^fh@06oj^fh@CoY[cY
1?n[^><8ojFmj`;oZ<;/1OnU_n`7oj[2j`;oZKoZ1OnZ`>X7ojRoj`03ojW0j_nV_ncoY[o/00KoY[o/
1_nV`>`00onU_ncoZ<3[ojS0j`02ojS0j`03o`000?nX`>_oZ<3[00SoZL3[1onW`>/8ojJok1Gooooo
00?o0000ooooooooool06oooool001[ooooo00?o0000ooooooooool02oooool?ojNoj`03ojO0jonX
`N_oZ<7[00_oZ<7[3onW_n/3ojO0j`SoZ<7/3_nW_n/00onW_^_oYko[ojNoj`04ojNoj`OoYl7/0_nX
`^`6ojS0j`KoYko[00?oYkkZojNmj_nW_NX01_nW_NX5ojNnjP;oZ<?]0ol00004ojS2k@KoYl;]2OnW
]n@6ojNhiP03ojNXeonX[M_oZ:gK00KoZ:gK1OnX/n400on[YM;oZjgIoj^]f@06oj^]f@CoZKKR1?n]
ZmD8oj^fh@03ojJljOn[^>?oZkSS00GoZkSS1_nU_N/00onY^nKoYKo/ojFok005ojFok0KoZ/;[00?o
Z<7/oj[0j_nZ`>X01_nZ`>X4ojRoj`CoZL3Z2?nV_n`2ojK0k0GoYKo/1?nX`>/00ol0003oZ<3[ojS0
j`08ojW0j`OoYl3[2?nV_n`Eooooo`03o`000?oooooooooo00Kooooo1Ol0000?ooooo`006_ooool2
o`0000Wooooo3onW_n/5ojO0j`WoZ<7[3onW_n/7ojO0j`GoZ<7/0_nX`N/FojNoj`GoYl7/0onX`^`7
ojS0j`;oYko[1OnW_^X8ojNmjP03ojNnj_nX`ngoZ<?]00?o000000?oZ<?]ojS2kOnX`^d01OnX`^d2
ojO2k@goYkOT0_nW^>H5ojNXe`SoZ:gK00?oZ;?Qoj^Ud_n[YM800on[YM88oj^]f@03ojVfh_n]ZmGo
[J_E00Go[J_E1_n[]^400on`[]KoZkSSoj^hh`07oj^hh`;oYKg[1OnY^nH7ojFok0;oZ/;[1OnX`N`8
oj[0jP03ojRojonY`>[oZL3Z00GoZL3Z1_nV_n`00onW_n_oYKo/ojFok005ojFok0GoZ<3[00?o0000
ojS0jonY`>/01onY`>/8ojO0j`SoY[o/5?ooool00ol0003oooooooooo`06ooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@03oooool001[ooooo00?o0000ooooooooool01_ooool2ojS1j`koYko[1onW`>/9
ojS1j`koYko[2?nW`>/00onX`NcoZ<7[ojS1j`04ojS1jaKoYko[00?oYl7/ojS2k?nX`^`01OnX`^`5
ojS0j`WoYkkZ1_nW_NX01?nW`Ngo0000o`000?l00005ojS3k@GoZ<;]0_nW^>H=ojNgi003ojJVeOnW
Z=OoYjSG00KoYjSG1_nX[M/00on/Y<ooZjGBoj^UdP05oj^UdPKoZjgI00?o/ZW?ojf[eOn]ZmD01on]
ZmD2oj^fh@Go/:kF1on[^><00ona/m[oZK_VojVkiP06ojVkiPGoYKo/0_nU_NX7ojS1k0KoZ/3Z0_nZ
`NX8ojW0jP;oY[o/1OnW_n/7ojFok0CoZ<3[00?o0000ojS0jonX`>/02?nY`>/8ojO0j`OoY[o/5Ooo
ool00ol0003oooooooooo`06ooooo`03oiRHV?lQ8B7ok^k^013ooooo000Jooooo`03o`000?oooooo
oooo00?ooooo1_nX`N/>ojNoj`OoYl3[2OnX`N/>ojNoj`KoYl3[00?oZ<7/ojS1jonX`N/01_nX`N/D
ojNoj`[oZ<;/00?oZ<3[ojNnj_nW_^X02onW_^X2ojNmjP05ojO1kOl0003o0000o`000?nW`Nd02?nX
`nd00onX`^goYkSVojNhiP04ojNhiPWoYkOT1OnVY]D7ojNXe`CoZ:gK1?n/Y<l7oj^UdP?oZjgI1?nb
ZLl7ojf[e@03okN^d?n`[]Ko/:kF00Ko/:kF1?n[^><4ok6cfPSoZK_V00?oYKo/ojFmj_nU_NX01?nU
_NX7ojS1k0;oZ/3Z1_nZ`NX7ojW0jPOoYko[1onU_n`5ojS0j`03o`000?nX`>_oZ<3[00KoZL3[0_nY
`N/8ojO0j`OoY[o/5Oooool00ol0003oooooooooo`06ooooo`03oiRHV?lQ8B7ok^k^00oooooo000J
ooooo`03o`000?oooooooooo00;oZ<3[2?nX`N/>ojNoj`GoYl3[2onX`N/>ojNoj`;oYl3[1OnX`N`8
ojS1ja3oYko[3?nX`^`00onW_n_oYkkZojNnjP0;ojNnjP04ojJojol0003o0000o`0000GoYl7]1_nX
`nd00onW^nSoYkSVojNhiP06ojNhiPGoYkOT00?oYJGFojJVeOnVY]D01_nVY]D7ojNXe`03ojR]fon/
Y<oo[:C?00Co[:C?2?n[YM800on[[MWo/ZW?ok:Yc`04ok:Yc`Go[J_E0ong[]08ok2^eP03oj^hhona
/m[o/K?J00Go/K?J1_nY^nH00on_^n;oYKgZojFmjP06ojFmjP?oZ<7/1?nU`>`8oj[1jPOoZL3Z1onW
_n/7ojFok0GoZ<3[00?o0000ojS0jonX`>/00_nY`>/6ojW1j`OoYl3[1onV_n`Eooooo`03o`000?oo
oooooooo00Oooooo00?oMgMgofIVI_ooool03_ooool001Wooooo00?o0000ojS0jonX`>/01?nX`>/8
ojS1j`koYko[00?oYl3[ojS1jonX`N/02onX`N/>ojNoj`;oZ<7[1onX`N`6ojS1j`koYko[0onW`N`9
ojS2k0GoYko[2OnW_^X01?nV_n_o0000o`000?l00003ojJoj`KoYl7]0_nX`nd5ojNkj0SoYkSV00?o
YkOTojFUe_nUYMH00onUYMH7ojJVe@KoYjSG00?oZj??ojbTcon/Y<l01_n/Y<l6oj^UdP03ok>[d?nb
ZLoo/ZW?00Go/ZW?0on]ZmD5okN^d0Oo/:kF00?o^[;Aok6cf_na/mX01ona/mX2ojVkiPGo[k_R1_nU
_NX00onY_NSoYL3/ojG0k006ojG0k0KoZ/7Z00?oZ/7[ojW0j_nY`>X01_nY`>X5ojNoj`;oYl3[1onU
_n`5ojS0j`03o`000?nX`>_oZ<3[00SoZL7[1onW`>/7ojJok1Gooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0=ooooo`006Oooool00ol0003oZ<3[ojS0j`05ojS0j`KoZ<7[3_nW_n/3
ojO0j`WoZ<7[3_nW_n/6ojS1j`OoZ<7/0_nX`N/>ojNoj`OoYl7/1OnX`^`2ojS1j`OoYko[1_nW_^X0
0onV_N[o0000o`000007ojJoj`?oYl7]1?nX_nX6ojNkj0KoYkSV00?oY:OHojFUe_nUYMH01OnUYMH7
ojJVe@;oYjSG1On[Xll7ojbTc`CoZjGB1?ncZm07ok:Yc`03ojf[eOng[]3o]jk@00Go]jk@1On`[]H3
okZbd@Oo/K?J00?o^KGFojnkh_n_^n801_n_^n82ojFmjPGoZKgX2?nU`>`2oj[1jPGoZ/7[2?nY`>X0
0onW_n_oYl3[ojO0j`04ojO0j`OoYKo/1?nX`>/01?l0003oZ<3[ojS0jonX`>/7ojW1j`OoYl3[1_nV
_n`2ojJoja?ooooo0ol00004ooooo`05o`000?nj^[[ooooooiRHV?l@41003oooool000kooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?ooooooZ<3[00KoZ<3[0_nX`N/>ojNoj`OoYl3[
1OnX`N/2ojS0j`ooYko[1onX`N/5ojS1k0?oZ<3[3_nW_n/8ojO1k003ojS2k?nX`N_oZ<7[00CoZ<7[
1onW_n/2ojNnjP04ojJmj_l0003o0000o`0000;oY[gZ1_nV_n/00onY`^coZ;oZojRojP06ojRojPKo
Yk_X0_nW^>H5ojBWf0OoYJGF1OnVY]D00onWX]3oZj??oj^Sc`05oj^Sc`So[:C?00?oZjGBok>[d?nc
Zm001OncZm05ok:Yc`03okVbd_ng[]3o]jk@00Ko]jk@0on`[]H6okZbd@Go/K?J0oni]MH6ojnkhP03
okBjg_nY_NSoZKgX00KoZKgX1_nU`>`00onT_ncoZ/7[oj[1j`06oj[1j`KoZL3Z00?oZL7ZojO0jonW
`>/01_nW`>/7ojFok0CoZ<3[00Co0000ojS0jonX`>_oZ<3[1onY`N/7ojO0j`;oY[o/1_nV_n/Doooo
o`03o`000?oooooooooo00;ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00?ooooo`003_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool02?nX`>/?ojNoj`OoYl3[00?oZ<7[
ojS0jonX`>/01?nX`>/?ojNoj`OoZ<7[00?oZ<7/ojS0jonX`>/01OnX`>/5ojNoj`;oY[k[1onW_n/6
ojO1k0;oZL;/1onX`N/5ojNoj`04ojJmj_l0003o0000o`0000KoY[gZ0_nV_n/5ojW2k0SoZ;oZ0onW
^nP2oj>[g0SoY:OH1onUYMH00onVY]GoYj;@ojNRd003ojNRd0OoZj??1_n/Y<l00ona[]Co/j_@ok>[
d006ok>[d0?o/ZW?1?ni/]88okN^d003ok2^e_nj/]7o^[;A00Go^[;A0ona/mX6okVeeP?o[k_R1?nd
^]h8ojVmj0;oYL3/1OnT_n`8oj[1j`;oZL3Z1OnY`NX7ojO0j`SoYKo/1?nX`>/00ol0003oZ<3[ojS0
j`07ojW1j`SoYl3[2?nV_n/Dooooo`03o`000?oooooooooo01Gooooo000>ooooo`05oa0@4?oooooo
ooooooooool@41001_ooool2o`0000;ooooo2?nX`>/?ojNoj`GoYl3[0_nX`N/7ojS0j`ooYko[2?nX
`N/7ojS0j`03ojNojonV_^_oY[k[00CoY[k[1onW_n/2ojO1k0KoZL;/1onX`N/00onW_n_oY[gZo`00
0002o`0000SoY[gZ0_nX`^`7ojW2k0KoZ;oZ00?oY;;Roj>[g?nSZm`01?nSZm`7ojBWf0KoYJGF00?o
Y:3BojNRd?nWX]001?nWX]07oj^Sc`Co[:C?1?na[]@8ok>[d003ok:Yconi/];o^K;B00Co^K;B1_ng
[]000onm]m?o^[;AokZbd@07okZbd@03ok6cf_ni]MKo^KGF00Ko^KGF00?o[k_RokBjg_nd^]h01?nd
^]h6ojVmj0;o[KoW1onT_n`6oj[1j`03ojW1jonY`N[oZL7Z00KoZL7Z1onW`>/8ojFok0CoZ<3[00?o
0000ojS0jonX`>/01onY`N/8ojO0j`OoY[o[5Oooool00ol0003oooooooooo`0Dooooo`003_ooool0
1Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00oooool7ojS0j`ooYko[00?o
Yl3[ojS1jonX`N/01?nX`N/7ojS0j`ooYko[2?nX`N/5ojS0j`;oYko[1onV_^/5ojNoj`?oZ<;/1onY
`^`3ojS1j`;oYkk[0ol00008ojJmjPKoZ<;/1onY`^`2ojRojPGoY;;R1_nSZm`7ojBWf0;oYJGF1OnT
X=86ojNRd0OoZj??00?o[:C?ok6^e?na[]@01Ona[]@6ok>[d003okNkg?ni/];o^K;B00Go^K;B1?ng
[]04okfgd`Oo^[;A00?o`KWCokVee_ni]MH01_ni]MH00oo2^mCo];[NokBjgP06okBjgP;oZKgX1_n]
_nL7ojBok0;oZ/7[1OnY`N/6ojW1jP03ojW1jonW`>_oYl3[00KoYl3[1onU_n`4ojS0j`03o`000?nX
`>_oZ<3[00SoZL7[2?nW`>/7ojJojaCooooo00?o0000ooooooooool05?ooool000kooooo00Go0000
ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00Gooooo1OnX`>/?ojNoj`;oZ<3[1onX
`N/5ojS0j`goYko[3?nX`N/00onX`>_oYko[ojNoj`04ojNoj`OoY[k[00?oYko[ojS2k?nX`^`01OnX
`^`5ojW2k0;oYko[00CoYkk[o`000?l0003o00000onW_^/6ojJmjP03ojJojonX`^coZ<;/00KoZ<;/
1OnY`^`00onU^>KoY;;RojBbhP06ojBbhPGoXj_L1_nTYmP00onOW];oY:3BojBPdP05ojBPdPKoYj;@
1_n[Xll00on^/M[o/JkDok6^e006ok6^e0Co/j_@1?ng^m`7okVbdP03okN^d?nm]m?o_KOC00Go_KOC
1Onj/]43ol6id`Ko^KGF0oo2^m@6okBjgP03ok^ng?n]_nOo[KoW00Oo[KoW0onT_n`3ojFok0SoZL7[
0_nY`NX5ojW1j`SoYl3[1onU_n`4ojS0j`03o`000?nX`>_oZ<3[00SoZL7[1onW`>/7ojJojaGooooo
00?o0000ooooooooool04oooool000kooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`00
0?oooooooooo00Kooooo00?oZ<3[ojNojonW_n/03OnW_n/6ojS0j`OoZ<7[00?oZ<3[ojNojonW_n/0
3?nW_n/=ojS1j`03ojO0jonW_n_oYko[00KoYko[1OnV_^/2ojNoj`SoZ<;/00CoZL;/ojNojonW_n_o
Yko[0ol00007ojNnj`;oY[gZ1OnV_n/8ojS2k003ojW2k?nU^>KoYKSV00?oYKSV1onT/^86oj>[g0;o
Y:OH1OnOW]87ojBPdPKoYj;@0_n[Xll5ojjafPSo/JkD00?o/j_@okNkg?ng^m`01?ng^m`6okVbdP03
ok_5h_nm]m?o_KOC00Ko_KOC0onj/]46ol6id`?o^KGF1_o2^m@3okBjgPCo^kkL1on]_nL00on``NOo
YKo/ojFok005ojFok0KoZL7[00?oZ<3[ojW1jonY`N/01_nY`N/7ojO0j`OoYKo/1OnX`>/00ol0003o
Z<3[ojS0j`08ojW1j`OoYl3[1onV_n/Eooooo`03o`000?oooooooooo01;ooooo000>ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2o`0000Sooooo3onW_n/7ojS0j`GoZ<7[0onX`>/>ojNoj`Wo
Z<7[1OnW`>/8ojNoj`03ojJnjonW_n_oYko[00CoYko[1_nX`^`00onY`^coYko[o`000002o`0000Co
Yko[1OnW_^/2ojJmjPOoY[o[1_nX`^`00onX_^[oYKSVojFhiP05ojFhiPOoY;;R0onSZm`2oibLd`Oo
WikB1onTX=85ojNRd003oj^cgon^/M[o[[7J00Ko[[7J1_na[]@00onad?3o]k_LokNkg006okNkg0Co
^K;B0onkaN88okfgd`03okZbdOo1^M?o`KWC00Ko`KWC00?o^KGFol:ke?o2^m@01_o2^m@00ond^]ko
^kkLok^ng004ok^ng0Co[KoW1?n``NL7ojFok0;oZL7[1OnX`>/8ojW1j`OoYl3[1onU_n`4ojS0j`04
o`000?nX`>_oZ<3[ojS0j`OoZL7[1onW`>/7ojJojaGooooo00?o0000ooooooooool04_ooool000ko
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo00Sooooo3onW_n/7ojS0
j`03ojS1jonX`>_oZ<3[00GoZ<3[3_nW_n/5ojS1j`?oZL7[1_nW`>/6ojNoj`;oY[o[1onW_n/2ojS2
k0?oZL;/0_l00008ojNoj`03ojNnjonV_N[oY[gZ00CoY[gZ1onV_n/2ojS2k0GoZ;kZ1onU^>H3ojBb
hP?oVYkG1_nLW=<7oinNdPOoY:3B00?oYj;@oj^cgon[/ml00on[/ml7ojjafPCo/JkD1?nad?07okNk
g0?o^K;B1OnkaN86okfgd`03okk3g_o1^M?o`KWC00Ko`KWC00?o`/3Hol:ke?o2^m@01_o2^m@00oo6
`MGo^kkLok^ng006ok^ng003ojfoion``NOo/<7W00Go/<7W1_nU_n`8ojS0j`OoZL7[2?nW`>/3ojFo
k0CoYKk/1?nX`>/01?l0003oZ<3[ojS0jonX`>/7ojW1j`OoYl3[1onV_n/Eooooo`03o`000?oooooo
oooo017ooooo000Hooooo`03o`000?oooooooooo00Wooooo3onW_n/3ojS0j`CoZ<7[2?nX`>/>ojNo
j`03ojS1jonY`N_oZL7[00GoZL7[1_nW`>/2ojNoj`KoY[o[1OnW_n/3ojW2k0?o00000onY`^`6ojNo
j`03ojJnjonV_N[oY[gZ00KoY[gZ1OnV_n/2ojW3k0OoZ;kZ1OnU^>H00onMYmgoVYkGoiZNe`05oiZN
e`KoW9cC1_nOW]86ojBPdP03ojJbh?n[/mooZk?O00GoZk?O1on^/MX00ona[]Co/M3`ok7@l005ok7@
l0Oo]k_L00?o^K;Bok_5h_nkaN801OnkaN83okfgd`Co_/?N1_o1^M<3ol;0f0Ko`[_D0oo6`MD6ok^n
g0;o`LCL2?n``NL6ojFok0SoZ<3[1onY`N/7ojO0j`SoYKk/1?nX`>/00ol0003oZ<3[ojS0j`07ojW1
j`KoYl3[00?oYko[ojJojonV_n/01_nV_n/Eooooo`03o`000?oooooooooo013ooooo000Hooooo`03
o`000?oooooooooo00[ooooo3OnW_n/2ojO0j`OoZ<7[1_nX`>/>ojNoj`?oZ<7[1onY`N/3ojO0j`_o
Y[o[00CoYko[ojW2k?nY`^coZL;/0ol00007ojW2k0;oYko[1OnV_^/8ojJmjP03ojJojonY`ncoZL?/
00CoZL?/1onX_^X00onU^>KoWJOMoifWg@03oifWg@KoVYkG1_nLW=<7oinNdP;oY:3B1OnV/^07oj^c
g`Go[[7J0_nQhO`7ok7@l0Ko]k_L0_nUh_/8ok_5hP03okfgdonn`mko_/?N00Co_/?N0oo1^M<6ol;0
f0Co`[_D1?o6`MD4ok^ng0Go`LCL1_n``NL00ona`nOoYKo/ojFok005ojFok0SoZ<3[1onY`N/7ojO0
j`SoYKk/1?nX`>/00ol0003oZ<3[ojS0j`07ojW1j`;oYl3[1OnW_n/6ojJoj`03ojNojooooooooooo
01?ooooo0_l0000Aooooo`005oooool3o`0000gooooo2?nW_n/6ojO0j`OoZ<7[0_nX`>/>ojNoj`Oo
Z<7[1OnY`N/2ojO0j`coY[o[0_nW_n/3o`0000WoZL;/0onW_n/6ojJnj`KoY[gZ0_nW`N`7ojW3k0?o
Z;kZ0onQ/nD7oifWg@KoVYkG1_nLW=<5oinNdP03oj:/gonV/^3oY[;P00KoY[;P1on[/ml00on^/M[o
XN7loj7Qo004oj7Qo0Oo/M3`0_ng^m`6ojGRn`Ko^lGR00?oXMklokk3g_nn`mh01_nn`mh00oo1^M?o
`/3Hol;0f005ol;0f0?o`[_D1_o6`MD00onk_]co`LCLol74g006ol74g0;o/<7W1Ona`nL7ojFok0So
Z<3[1_nY`N/8ojO0j`KoYKk/00?oYKk[ojS0jonX`>/00_nX`>/01?l0003oZ<3[ojS0jonX`>/3ojW1
j`CoZ<7[1onW_n/2ojJoj`GoYko[4oooool00ol0003oooooo`00000Aooooo`005oooool00ol0003o
ooooooooo`0>ooooo`OoYko[1onW`>/8ojS1j`koYko[2?nX`N/00onY`N_oYl3[ojO0j`04ojO0j`So
Y[o[0_nW_n/3o`000003ojNojonY`^coZL;/00KoZL;/1onW_n/6ojJnj`;oY[gZ1_nW`N`5ojW3k0;o
YK_Y1_nQ/nD6oifWg@KoVYkG1onLW=<00onOW];oXZcOoj:/g`03oj:/g`OoY[;P1_n[/ml3ohoUn`Ko
XN7l0onad?06odo;i@KoYN;k0_nkaN85oj7No0Ko_/?N00?o]=Caol;0f?o2`=P01oo2`=P00oo2^mCo
a/7EolK1e@05olK1e@So`LCL00?oa<WNok73iona`nL01_na`nL7ojFok0SoZ<3[1_nY`N/8ojO0j`;o
YKk/1OnU_^/4ojS0j`03o`000?nX`>_oZL7[00SoZ<7[1OnW_n/00onV_n_oYko[ojNoj`06ojNojaCo
oooo00?o0000ooooooooool03oooool001Oooooo00?o0000ooooooooool03oooool7ojNoj`OoYl3[
2?nX`N/>ojNoj`KoZ<7[00?oZL7[ojO0jonW`>/01_nW`>/6ojJoj`?o00001OnW_n/5ojW2k0;oZL7[
2?nW_n/3ojJnj`CoYKk[1onW`N`00onY`ncoYK_YojFkj@04ojFkj@KoXK?U1_nMYmd6oiZNe`?oW9cC
0onLYM/7oj:/g`OoY[;P0_n[/ml7ohoUn`?oXN7l1OnCbo/6oeVko003o`24aolK003o6`0000Go9ZoH
1OnQg_`4okk3gPCo]=Ca1oo2`=P00oo0aMkoa/7EolK1e@05olK1e@;ob<KH1_o1a=`3olC9gPKo/L?W
00?o/LGYojFok?nU_n`01_nU_n`6ojS0j`03ojW0j_nY`N_oZL7[00GoZL7[1_nW`>/00onW`>coYKk[
ojFnj`06ojFnj`;oZ<3[0_nY`N/00ol0003oZL7[ojW1j`08ojS1j`03ojNojonV_n_oY[o[00?oY[o[
2?nW_n/Dooooo`03o`000?oooooooooo00kooooo000Gooooo`03o`000?oooooooooo013ooooo1onW
_n/5ojO0j`[oZ<7[0onW_n/4ojJoj`OoYko[0_nX`N/5ojW1j`SoYl3[0_nV_n/3o`000003ojJojonW
_n_oYko[00KoYko[00?oZL;/ojW1jonY`N/01?nY`N/6ojNoj`03ojJnjonU_^_oYKk[00KoYKk[1OnW
`N`00onY`^coYK_YojFkj@06ojFkj@GoXK?U1onMYmd3oiZNe`;oUYgI1onLYM/6oj:/g`KoY[;P1?n@
iO/3ohoUn`;oJmgQ0onUdOL7oi?;n`?oFK_l1?nF]>`5oe2Xn0;o9ZoH1OnQg_`00onn`mko]=CaokCD
l@05okCDl@Co`/3H1?o0aMh5olK1e@Cob<KH0oo1a=`6olC9gP?o/L?W1?naaNT8ojFok0;oZ<3[1OnY
`>X7ojW1j`;oYl3[1OnW`>`6ojFnj`03ojJojonY`N_oZL7[00?oZL7[00?o0000ojW1jonY`N/01onX
`N/7ojJoj`OoYko[5Oooool00ol0003oooooooooo`0=ooooo`005oooool2o`0001;ooooo1onW_n/0
0onW`>_oZ<7[ojS1j`0:ojS1j`;oYko[1onV_n/5ojNoj`?oZ<3[1_nY`N/6ojO0j`?o00001OnV_n/6
ojNoj`;oZL;[1onY`N/2ojNoj`GoY[k[2?nU_^/00onW`NcoZL;/ojW2k003ojW2k0SoYK_Y1OnQ/nD3
oifWg@?oTI[I1_nFWMT7oibUf`KoXZcO0_nV/^06oi3Un`?oJmgQ1onUdOL3oi?;n`CoYJgM1onF]>`6
oe2Xn0?o06o91?m4^?@7okCDl@03ol;0f?o0aMko`<GN00Go`<GN0oo6`MD6olS6f003ol74g?o4bMko
a<WN00Koa<WN00?o/L?Wok75jOnaaNT01?naaNT7ojFok0SoZL3Z1onY`N/7ojO0k0;oYKk[1OnV_n/4
ojW1j`04o`000?nY`N_oZL7[ojW1j`OoZ<7[1onV_n/7ojNojaCooooo00?o0000ooooooooool03Ooo
ool001Oooooo00?o0000ooooooooool04_ooool5ojNoj`?oYl3[2?nX`N/6ojNoj`OoY[o[00?oYko[
ojS0jonX`>/01OnX`>/6ojW1j`;oYl3[00?oY[o[o`000?l000002OnV_n/2ojNoj`KoZL;[1OnY`N/2
ojNoj`OoY[k[1_nU_^/2ojS1j`KoZL;/1_nU^nT00onL/>KoTZ3Moi:Pg@03oi:Pg@OoTI[I1_nFWMT6
oibUf`GoXZcO1?nLh?d2oi3Un`04odK5^on=k]koSNkNohg^gP?o/]kf1OnUdOL00onW[]goYJgMojF]
g@06ojF]g@GoU[C/0_n/]Ml6oh>bm0;o6X7W0_l0KlT2o`j?h@04odBhm?nde?7o]=CaokCDl@?oT<[k
2Oo0aMh00oo6`MGob<KHolS6f004olS6f003olW:f_o4bMkoa<WN00Koa<WN00?oa/kQok75jOnaaNT0
1_naaNT7ojFok0KoZL3Z00?oZ/7[ojW1jonY`N/01_nY`N/5ojO0k003ojJok?nV_n_oY[o[00KoY[o[
1?nY`N/00ol0003oZL7[ojW1j`08ojS1j`KoY[o[2?nW_n/Dooooo`03o`000?oooooooooo00cooooo
000Gooooo`03o`000?oooooooooo01?ooooo00?oYko[ojO0jonW`>/01OnW`>/7ojS1j`OoYko[1OnV
_n/3ojNoj`OoZ<3[0onY`N/2ojS0j`?o00002OnV_n/4ojNoj`OoZL;[00?oZL7[ojNojonW_n/01?nW
_n/7ojJnj`;oYKk[1_nX`N/6ojW2k0;oYK_Y1OnL/>H5oi:Pg@KoTI[I1_nFWMT7oibUf`03oj:/gonL
h?goW>3m00GoW>3m00?oNNGIohg^g_n=k]h01onbg_H00onUdOOoYjkMojN^g@03ojN^g@SoYJgM00?o
U[C/ojbegon/]Ml01?n/]Ml6oh>bm0Co6X7W0ol>Sn46oi3:n`Oo`<GN0_nkan<5olS6f0?obL[J1_o4
bMh3olK>h@Ko/LGY0_n`a^X7ojFok0;oZL3Z1OnZ`N/8ojW1j`03ojO0k?nV_ncoY[o/00?oY[o/2?nV
_n/4ojW1j`03o`000?nY`N_oZL7[00KoZ<7[00?oZ<3[ojJojonV_n/01OnV_n/6ojNoj`03ojS0jooo
oooooooo01?ooooo00?o0000ooooooooool02oooool001Oooooo00?o0000ooooooooool05Oooool7
ojO0j`OoZ<7[1onW_n/00onV_n_oYko[ojNoj`05ojNoj`GoZ<3[0_nY`N/01?nX`>_o0000o`000?l0
0003ojS0j`OoY[o[1onW_n/8ojW2j`KoYko[1OnV_^/3ojFnj`OoZ<7[0onY`^`3oj>kjPOoW;3V1OnB
X=d6oi6Jf@KoUYgI0onLYM/6oj;<mP;oW>3m0_miiMT01?n=k]koaO7_olGakoo5lNl6ok;NmP03ojZl
ionW[]goYjkM00GoYjkM1_nU[Md00ona/=Oo[;GOojbeg`06ojbeg`KoPk;d1?lJPNL00ol9O>;o3XoQ
o`j?h@06oi3:n`Co`<GN1Onkan<3olS6f0GobL[J0oo4bMh6olK>h@;o/LGY1_n`a^X5ojFok003ojBn
k?nZ`N_oZ/7[00KoZ/7[1onY`N/7ojJok0KoY[o[00?oYko[ojW1jonY`N/00onY`N/00ol0003oZL7[
ojW1j`02ojS1j`GoZ<3[1onV_n/2ojNoj`GoZ<3[5?ooool00ol0003oooooooooo`0;ooooo`005_oo
ool3o`0001Oooooo1OnW`>/3ojS0j`KoZ<7[1OnW_n/3ojJoj`OoYko[00CoZ<3[ojW1jonY`N_oZL7[
0ol00007ojS0j`OoY[o[1onW_n/8ojW2j`KoYko[00?oY[k[ojFnjonU_^/01OnU_^/5ojS1j`03ojW2
k?nS^n[oXk_Z00GoXk_Z1_nL/>H5oi:Pg@KoTI[I1OnFWMT2oibaiPOoX/cf0onVlo82ojkjhPGoaO7_
0_nbg_H5ojZli`KoYjkM1?nU[Md4ok6`e`Ko[;GO00?o^lGRoi:gl?nB]o001OnB]o03ocn<k@04oaZ1
iol9O>;o2GcRo`UlhPKoT<[k00?o`<GNok_7honkan<01_nkan<00oo8a]SobL[JolW:fP05olW:fP03
olC9g_o6c^7oa/kQ00Coa/kQ0_o4d^D8ok36jP03ojFok?nT_^coY;k/00?oY;k/2?nZ`N/7ojW1j`Oo
Y[o/0_nV_n/5ojNoj`CoZL7[00?o0000ojW1jonY`N/01onX`>/8ojJoj`OoZ<3[5?ooool00ol0003o
ooooooooo`0:ooooo`005_ooool00ol0003oooooooooo`0Hooooo`03ojO0jonX`>_oZ<3[00GoZ<3[
1_nX`N/00onW_n_oY[o[ojJoj`05ojJoj`GoYko[00?oZ<3[ojW1jol000000_l00004ojW1j`GoZ<3[
2OnV_n/5ojNoj`;oZL7[2?nY`^/3ojNoj`?oY[k[2?nU_^/00onX`N_oZL;/ojW2k003ojW2k0OoXk_Z
1_nL/>H5oi:Pg@KoTI[I00?oUYgIoibai_nL/NH01?nL/NH4oj;<mP?oY_?b0on^n^85olGak`03okSC
k_nZ_>OoZ[cW00KoZ[cW1_nW[]d00onU[Mgo/K3Gok6`e`05ok6`e`?o[;GO1?nkaN87oi:gl0Co?hc]
00?o87STo`Ulh_l9O>801_m_/oX7ok_7h`03okO6iOo9b][obL[J00GobL[J0_o;c]d5olK>h@Coa=;U
1_n`a^X00on]aNcoY;k/ojBnk005ojBnk0KoZ/7[00?oZ/;[ojW1jonY`N/01_nY`N/3ojJok0?oYKk[
2?nW_n/4ojW1j`03o`000?nY`N_oZL7[00OoZ<3[2?nV_n/6ojS0ja?ooooo0ol0000;ooooo`001?oo
ool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h6ooooo`03o`000?oooooooooo
01[ooooo1onX`>/3ojS1j`CoYl3[1onV_n/00onW_n_oZ<3[ojS0j`03o`0000SoZL7[00?oZ<3[ojJo
jonV_n/02onV_n/00onW_n_oZL7[ojW1j`04ojW1j`KoZL;[00?oYko[ojJnjonV_^/01OnV_^/6ojFn
j`;oZ<3[1_nY`^`7oj>kjP?oW;3V0_n9WN05ohZJg@KoTZ;O2?nL/NH00onRc?KoY_?bojKclP02ojKc
lP?o[_[R1?o5lNl4okSCkPOoZ[cW1OnW[]d00onV[=_o/K3Gok6`e`07ok6`e`03ojbegonkaN;o^lGR
00Co^lGR1onB]o04ocn<k@;o87ST00?o2GcRofncn_m_/oX01?m_/oX4ok_7h`Co]lKU1Oo9b]X4ol_>
g@?oa/kQ1_o4d^D2ok36jPGo[LG/1onT_^`2oj[1j`GoZ/;[1_nY`N/00onX`N_oYKk[ojFnj`05ojFn
j`KoYko[0_nX`>/4ojW1j`03o`000?nY`N_oZL7[00?oZ<3[1?nW`>/8ojJoj`KoZ<3[3oooool3o`00
00;ooooo00?o0000ooooooooool02Oooool000Kooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool06oooool5ojS0j`03ojS1jonW`>_oYl3[
00KoYl3[1OnV_n/01?nW_n_o0000o`000?l00004ojS0j`KoZL7[0_nX`N/>ojJoj`OoZL7[0_nY`^/5
ojNoj`OoY[k[0_nU_^/6ojS0j`KoZL;/0onS^nX3oiRaj@KoRIgP1On:V]d6oi:Rg`KoW;7V1?neiOL3
olGgk0Coe?KT00?oaO7_okSCk_nhdnh01?nhdnh7ojZli`03ojN^gOnV[=_oYZcK00?oYZcK1ona/=L0
0onma^7o^lGRok_5hP06ok_5hP?oT[O`0onC]^l4oe2:j@04ocn<kOlPN>Co87STob1hi0KoKk?j00?o
^lOSokO6iOnga^D01?nga^D3olW:fPOoblkM00?oa/kQolCBiOo4d^D01?o4d^D2okoCj@Oo[LG/0onT
_^`4ojJnj`OoZ/;[0_nY`N/5ojS1j`OoYKk[0_nW_n/6ojS0j`?oZL7[00?o0000ojW1jonX`N/02?nW
`>/6ojJoj`03ojNojonX`>_oZ<3[00GoZ<3[2oooool3o`0000Gooooo00?o0000ooooooooool02Ooo
ool000Kooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Kooooo0_l0
000Mooooo`03ojS0jonX`N_oZ<7[00?oZ<7[2?nW`>/00onV_n_oYko[o`000002o`0000;oYko[1_nX
`>/2ojW1j`KoZ<7[3_nV_n/5ojW1j`?oZL;[1_nW_n/5ojJnj`?oYKk[1onX`>/3ojW2k0?oXkc[1_nH
/NT5ohVMh0KoRY[M1_nBX]l3oibaiPGo]NGg0oo5mn`4omCfi0?od>KV1_nhdnh3ojZli`?oVJkU1onV
[=/4ok6`e`Co_LKQ1_nkaN82okgCj`KoTkK_1?m@R^T2ocejhP;o87ST1OmVX_<8okO6i@03olW:f_o;
c]goblkM00GoblkM0_o=e=l4olCBi@Go_m?Y1On]aN`00onY`^coY[k[ojJnj`06ojJnj`OoZ/;[1onX
`N/7ojFnj`SoZ<3[00CoZL7[ojS1jonX`N_o00000_nX`N/8ojO0j`;oY[o[1OnW_n/7ojS0j`Kooooo
1?l00008ooooo`03o`000?oooooooooo00Wooooo0006ooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000005ooooo`;o00007oooool6ojS1j`KoYl3[00?oY[o[o`000?l00000
1_nW_n/3ojS0j`CoZL7[1onX`N/>ojJoj`03ojW1jonY`^_oZL;[00GoZL;[1_nW_n/00onV_^_oYKk[
ojFnj`05ojFnj`GoZ<3[00?oZ/;[oj>ljonS_>/01OnS_>/6oiRaj@GoRIgP1On:V]d7oi:Rg`03oiba
i_neiOOo]NGg00;o]NGg0oo5mn`5omCfi0God>KV0onhdnh2oj:okPOoVJkU1onV[=/00ona/=Oo_LKQ
okg6h@05okg6h@?o^lGR1Onmdn/6oi>fk`CoD8[Y0olmN^800olPN>CoIZ;cofJRl`03ofJRl`Ko]lKU
0_ngaND6ol_>g@CocMCO00?oa=;UokoCjOnodnT01_nodnT00on]aNcoZL;/ojW2k003ojW2k0SoY[k[
1onZ`^/7ojS1j`OoYKk[1_nX`>/5ojS1j`03o`000?nX`N_oZ<7[00KoYl3[00?oY[o[ojNojonW_n/0
1OnW_n/6ojS0j`04ojS1joooooooooooooooo`?o00003Oooool00ol0003oooooooooo`08ooooo`00
1_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003o
ooooooooo`0Oooooo`KoZ<7[0_nW`>/01?nV_n_o0000o`000?l00002ojJoj`OoYko[1onY`N/5ojS1
j`?oYko[2onV_n/3ojS0j`OoZL;[0onW_n/3ojJoj`SoYKk[00?oZ<3[oj[2jonZ`^/00onZ`^/7oj>l
j`GoV;7Y1On9WN06ohZJg@?oTZ;O1_nQ_Nd01?neiOOoaOO/olGgk?o5mn`5omCfi0God>KV0_o1d>H5
oj:okPOoVJkU1OnV[=/00onW`>_o_LKQokg6h@07okg6h@03ok_5h_nmdn_o_M?[00Go_M?[1_nC]^l4
oe2:j@Co?G[R1OmVX_<3okO6i@Go]lGU0oo;c]d5olgDg`;oc][R1onodnT00ongc^coZL;/ojW2k005
ojW2k0KoY[k[00?oZ;o[oj[2jonZ`^/01_nZ`^/3ojS1j`?oYl3[2?nU_^/2ojS0j`WoZ<7[00?o0000
ojS1jonX`N/00_nW`>/5ojJoj`OoYko[0_nX`>/5ojS1j`;o00004?ooool00ol0003oooooooooo`08
ooooo`001_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41001Oooool0
0ol0003oooooooooo`0Pooooo`?oZ<7[0_nX`>/3o`0000KoY[o[1onW_n/7ojW1j`03ojS1jonW_n_o
Yko[00GoYko[1onV_n/7ojS0j`GoZL;[00?oZ<7[ojJojonV_n/01OnV_n/6ojFnj`;oYko[1_nZ`^/7
oj>lj`GoV;7Y1On9WN03ohZJg@CoT:GS1_nQ_Nd4olGSkP?oe^WS0_oDm^@4om3ViPGo`M3V1OnR_nh7
oiV^i@03ojJ/fonW`>_oYl3[00?oYl3[1onma^43okoNk`Go_M?[00?o[LK/ohZUion:YNL01?n:YNL2
oe]og0;oD8[Y1?lmN^84ofnLk0;oIZ;c00?o]lKUokO5iOngaND01OngaND00oo;c]gocMCOolgDg`03
olgDg`Coc][R1?nodnT4okO>k0OoZL;/0_nV_^/5ojRoj`KoZ/;[00?oZL;[ojO0jonW`>/01OnW`>/6
ojFnj`03ojJnjonX`N_oZ<7[00WoZ<7[00?o0000ojS1jonX`N/02?nV_n/3ojNoj`?oYl3[2?nX`N/A
ooooo`03o`000?oooooooooo00Sooooo0006ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o00008_ooool01?nX`>_o0000o`000?l00003ojS0j`SoY[o[1_nW
_n/8ojW1j`OoYko[1_nV_n/8ojS0j`03ojW2jonX`N_oZ<7[00?oZ<7[1onV_n/2ojFnj`KoYko[1_nZ
`^/3oj>lj`?oVKG/1On3XNH5oh:Jh@SoT:GS0onQ_Nd5olGSkPCoe^WS1?oLh]X00oo@i^Ko`M3Vol7@
iP05ol7@iPGoX[o^0onI[^D4ohRdlPKoYl3[1?nma^46okoNk`03okgCjon]a^co[LK/00?o[LK/1_n:
YNL4oe]og0Co?G[R1_m_W>`6okO5i@?o_<WU0oo=e=l6olkJhP03okoCjOngc^co]lk/00Go]lk/0onY
`^`3ojFok0SoZ;o[0_nZ`^/5ojW2j`OoYl3[0_nU_^/5ojJnj`_oZ<7[00?o0000ojS1jonX`N/01_nV
_n/00onV_^_oYl3[ojO0j`05ojO0j`OoZ<7[4Oooool00ol0003oooooooooo`08ooooo`001?ooool0
0omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003ooooooooo
o`0Oooooo`?o00001onX`>/8ojJoj`KoYko[2?nY`N/5ojNoj`SoY[o[1_nX`>/2oj[2j`KoZ<7[1OnV
_n/3ojFnj`OoYko[0onZ`^/4ojG0k0GoVKG/1On3XNH5oh:Jh@SoT:GS00?oXKg]olGSk_o5hnh00oo5
hnh4omKYh`Gog>;J00?of=GEol7@i_o1d>H01?o1d>H2okS4h`GoS;Kb1on8]?86ojO0j`03okg6hOno
g^oo_mk_00Go_mk_00?o]]Wbojg6k?n]a^`01On]a^`5ohZUi`CoFgoL0omIO]d2ocejhPKoKic/0ong
aND6okc9i@03olgDgoo>f^;oc][R00Coc][R0_o<gnL6okO>k003ok39kOnU_ncoYKo/00GoYKo/1_nX
_n/8ojW2j`KoYl3[0_nV_n/7ojJnj`?oZ<7[0onY`N/5ojS1j`03o`000?nX`N_oZ<7[00;oY[o[1OnV
_^/7ojO0j`OoZ<7[4?ooool00ol0003oooooooooo`08ooooo`005Oooool00ol0003oooooooooo`0L
ooooo`?o00001?ooool5ojS0j`?oYko[1onV_n/3ojNoj`CoZ<3[1onY`N/00onW_n_oY[o[ojJoj`0:
ojJoj`;oZ<3[1_nZ`^/6ojS1j`03ojJojonU_^_oYKk[00GoYKk[1OnW_n/00onZ`N_oYL3/ojG0k006
ojG0k0GoVKG/1On3XNH5oh:Jh@KoT:GS0onU^nT3olGSkPCoe^WS1OoLh]X3omSEe@?o`M3V1Onha><5
ohbflPOoR;Cb0onW`>/5oj;HnP;o_mk_1OnffO87ojg6k0CoRZGW1OmKOm`5oeUng@KoKic/00?o]lGU
okc9iOnlbND01?nlbND00oo3d^Koc][RolkJhP04olkJhPCoc=oW0ongc^`4ok39k@OoYKo/0_nX_n/<
ojW2j`;oYl3[1_nV_n/5ojJnj`03ojS0jonY`N_oZL7[00GoZL7[1OnX`N/00ol0003oYl3[ojJnj`06
ojJnj`KoYl3[00?oZ<3[ojS1jonX`N/01_nX`N/?ooooo`03o`000?oooooooooo00Sooooo000Eoooo
o`03o`000?oooooooooo01Wooooo0ol00008ooooo`03ojS0jonW_n_oYko[00GoYko[1OnV_n/00onW
_n_oZ<3[ojS0j`06ojS0j`GoZL7[0_nX`>/;ojJoj`?oYko[1onZ`^/3ojS1j`CoY[o[1onU_^/00onW
_n_oZ/7[oj[1j`03oj[1j`SoYL3/1OnI]N`5oh>QiPGoPY[Q0_n@YN<7ojFkj@03olGSk_oFjN?oe^WS
00;oe^WS1OoLh]X5omSEe@03ol7@i_nha>?o^<CS00Go^<CS1On<]_83ohRdlPGoO[ol1OnRf?X3oj?E
n@Ko]]Wb0on]a^`3oiVSg0CoOXcF00?oRZGWoe]og?mKOm`00omKOm`4oeUng@KoPj7W1_nlbND3ol?B
iP?oc][R1oo<gnL00ongc^co/<W]ok39k@04ok39k@GoYKo/0_nU_N/;ojW2j`?oZ<7[2?nV_n/00onV
_^_oZ<3[ojS0j`03ojS0j`OoZL7[0_nX`N/2ojO0j`03o`000?nW`>_oYl3[00OoY[k[0_nW`>/5ojS0
j`OoZ<7[3oooool00ol0003oooooooooo`08ooooo`005Oooool00ol0003oooooooooo`0Fooooo`?o
00003Oooool7ojNoj`03ojJojonW_n_oYko[00?oYko[2?nX`>/00onY`N_oZ<3[ojS0j`04ojS0j`Oo
Y[o[1onW_n/5oj[2j`;oZL7[1onV_n/7ojFnj`KoZ/7[1_nU`>`00onM^ngoQZ_]ohJ[k@03ohJ[k@Go
N9[V1_n8XnH7ojFkj@Coa]GU00?oe^WSomcRf_oLh]X00ooLh]X5omSEe@;odLOA1_nha><00onf^]co
SKC`ohfdl005ohfdl0OoO[ol00?oX]Sjoj?EnOnSeOT01OnSeOT3okKIlP;oYK3O1onIXm`4ogj<eP?o
Ig_C0_mKOm`5oeUng@KoPj7W0onlbND6ol?BiP03olkJh_o<gnOoc=oW00Goc=oW0_o1g>d7ok39k@03
ojFok?nU_N_oYKg[00CoYKg[1_nY`^/00onY`^coZ<7[ojS1j`05ojS1j`KoY[o[00?oYKk[ojS0jonX
`>/01OnX`>/5ojW1j`;oZ<7[1?nW`>/00ol0003oYl3[ojO0j`03ojJnj`CoYko[1onX`>/7ojS1j`oo
oooo00?o0000ooooooooool01oooool001Cooooo0_l0000Eooooo`?o00004Oooool5ojNoj`;oY[o[
1_nW_n/6ojS0j`;oZL7[1onX`>/7ojJoj`OoYko[00?oZ/;[ojW1jonY`N/01?nY`N/7ojJoj`OoYKk[
1_nZ`N/2ojG0k0GoWK_]1On6Znd5ogRJiPKoR:?V1OnU^nT5olKEi@;odmOK0ooLh]X5omSEe@CodLOA
0onha><4okJjg0OoSKC`0omn_o`5oiFnl`GoXmGi00?oYk3NojF`gonU/=l01?nU/=l6oiVSg0GoOXcF
1OmWNm<5oeUng@KoPj7W00?o_<WUol?Bi_o3d^H01?o3d^H3olWMi`Coc=oW1Oo1g>d3ok39k@?oZL?/
2?nU_N/2ojW2j`GoZL;/1onX`N/2ojJoj`GoYKk[1onX`>/00onY`N_oZ<7[ojS1j`04ojS1j`CoYl3[
00?o0000ojJojonW_n/01onW_n/5ojS0j`WoZ<7[3_ooool00ol0003oooooooooo`07ooooo`005?oo
ool00ol0003oooooooooo`0Booooo`;o00005Oooool00onW_n_oY[o[ojJoj`04ojJoj`KoYko[0_nX
`>/6ojW1j`GoZ<3[0_nW_n/7ojJoj`GoYko[0_nY`>/7ojW1j`?oY[o[1?nV_n`7ojFnj`?oZ/7[1?nY
`^/6oifkk@GoQZ_]1OmhV^H6ohRSiP?oYK_Y1Oo6eND4om?Gf`03omcRf_oHeMGof=GE00?of=GE1_oA
am400onha>?o][[LokJjg004okJjg0GoSKC`0_nS/>48oiFnl`03oj?EnOnW/=koYk3N00?oYk3N1_nU
/=l6oiVSg0CoOXcF1OmWNm<4og29f`;oFGkM0on3XNL3oiZ]i0Go`m;V1Oo9gNL00oo<gnOo`Mc]ol7L
k@04ol7Lk@;o]<o^1_nY`n`6ojFmj`;oZ<3[1onY`^`3ojS1j`?oYl3[2?nU_^/3ojS0j`_oZ<7[00Ko
Yl3[ojJojonV_n_oY[o[o`000?nV_n/8ojNoj`03ojS0jonX`N_oZ<7[00WoZ<7[00?oYl3[oooooooo
ool03?ooool00ol0003oooooooooo`07ooooo`005?ooool00ol0003oooooooooo`0?ooooo`?o0000
6?ooool7ojJoj`?oYko[1?nW`>/7ojW1j`03ojS0jonW_n_oYko[00CoYko[1onV_n/00onW_n_oZL3[
ojW0j`04ojW0j`GoZL7[0_nX`N/7ojJok0GoYKk[0_nW_n/7ojW2j`KoWK_]1On6Znd4ogRJiPOoR:?V
00?oYK_YolKEiOo6eND00oo6eND5om?Gf`;oem3B0ooHeMD6om77d@03ol^kbonf^]co][[L00Ko][[L
00?oSKC`oj>`hOnS/>401?nS/>46oiFnl`03ojRZf?nW/=koYk3N00GoYk3N1OnU/=l6oiVSg0GoOXcF
1OmWNm<5og29f`OoVZgT0oo3d^H5olWMi`?oc>KZ0oo1g>d5okC?kPKoZL?/0_nU_N/6ojS0j`GoZL;/
00?oZL7/ojO0jonW`>/01OnW`>/6ojFnj`03ojJnjonX`N_oZ<7[00coZ<7[1?nV_n/00ol0003oY[o[
ojJoj`06ojNoj`03ojS0jonX`N_oZ<7[00OoZ<7[1OnW`>/=ooooo`03o`000?oooooooooo00Oooooo
000Dooooo`03o`000?oooooooooo00cooooo0ol0000Looooo`OoY[o[1onW`>/8ojW1j`KoYko[1onV
_n/7ojW0j`03ojW1jonX`N_oZ<7[00CoZ<7[1onV_n`00onU_^_oYko[ojNoj`04ojNoj`OoZL;[0onM
^nd2oiBgk`GoLIo]1?miW^T01?mhV^KoR:?VohRSi_n8XnH5oiVbj@?oa]GU1OoCem/4omO@dP03omSE
eOoAam7odLOA00CodLOA0oo;^l/6okJjg003okN]conS/>7oXk3Q00KoXk3Q0_nE__<5ojRZf0KoYk3N
1_nU/=l6oiVSg0CoOXcF1_mWNm<5og29f`OoVZgT00?o`m;VolWMioo9gNL00oo9gNL5olcVjP03ol7L
kOndcnko]<o^00Go]<o^0onY`n`3ojFmj`SoZ<3[00?oZL;/ojW1k?nY`N`00onY`N`7ojO0j`;oYKk[
1OnV_^/>ojS1j`CoY[o[00?o0000ojJojonV_n/00_nW_n/5ojS0j`OoZ<7[1onW`>/<ooooo`03o`00
0?oooooooooo00Oooooo000Cooooo`?o00002_ooool3o`00023ooooo1onV_n/7ojO0j`SoZL7[1_nW
_n/7ojJoj`GoZL3[0onZ`N/6ojS1j`GoY[o/0_nU_n`7ojNoj`?oZL;[1?nV`>`5oiBgk`GoLIo]1Omi
W^T8oiVbj@03olKEiOoCem_odmOK00?odmOK1OoGd=800ooEalgodLOAom77d@03om77d@Gobk_;0onf
^]`4okN]c`KoXk3Q00?o[jC=ojRZf?nXZ]P01OnXZ]P7ojN`gP?oYK3O0_nLTlX6ohf8bPCoOH3;00?o
OXcFofMkdomWNm<00omWNm<5og29f`KoVZgT0ondb^X3olWMi`Goc>KZ0_o5i^h6okC?kP03ojc5kOnU
_N_oYKg[00GoYKg[1_nX`>/00onY`^coZL7/ojW1k005ojW1k0GoYl3[0_nU_^/7ojJnj`koZ<7[0onV
_n/00onV_^_o0000ojJnj`08ojS0j`OoZ<7[1onW`>/;ooooo`03o`000?oooooooooo00Oooooo000D
ooooo`03o`000?oooooooooo00Kooooo0ol0000Uooooo`KoY[o[1OnW`>/3ojS0j`OoZL7[0onW_n/:
ojJoj`03ojW0jonZ`N_oZ/7[00GoZ/7[1_nX`N/00onV_ncoYKo/ojFok004ojFok0GoYko[0_nY`>X7
ojK0k0GoU;O_1OmaWnd5ogVNj@KoVK;Y0ond`N@3om?Gf`Koem3B0_oEald3om77d@Oobk_;00?o][[L
okN]cong[Ll01?ng[Ll3oj>`h@Co[jC=1onXZ]P3ojN`gP?oXiO81_nLTlX6ohf8bPCoOH3;1?miQ=82
ofMkd`GoL8WK0_nJ[N@7okC:jP03olWMioo<i^[oc>KZ00;oc>KZ1Oo5i^h2okC?kPGo[<G]1onU_N/2
ojS0j`GoZL;/1onY`N`00onW`>_oYKk[ojFnj`04ojFnj`GoY[k[3_nX`N/00onW_n_oY[k[ojJnj`02
ojJnj`03o`000?nV_^_oY[k[00KoZ<3[2OnX`N/3ojO0j`?oY[o[2oooool00ol0003oooooooooo`07
ooooo`005?ooool00ol0003oooooooooo`03ooooo`?o0000:Oooool6ojJoj`03ojO0jonX`>_oZ<3[
00GoZ<3[1OnY`N/2ojS1j`_oY[o[0onW_n/7oj[1j`?oZ<7[0onW_n/7ojFok003ojNojonY`>[oZL3Z
00CoZL3Z1onV`>`5oiBgk`CoLIo]1_miW^T2oiVbj@Oo]<7T00?odmOKomO@d_oGd=801?oGd=84omG7
c@03om77dOo;^l_obk_;00Gobk_;00?ob;?5okN]cong[Ll01_ng[Ll00onS/>7o[jC=ojnTc@04ojnT
c@GoZ:[H00?oZIO4oj>Gb?nSUlP01OnSUlP5oibCbPKoSHS:1OmmP</5ogV4dPKoQiWN1ondb^X3ol;N
k@03olcVj_o5i^koaNK^00CoaNK^0_ned^l6ojc5k@KoYKg[00?oYko[ojW2k?nY`^`01_nY`^`3ojW1
k0?oZ<3[2?nU_^/00onV_^_oZ<7[ojS1j`0<ojS1j`GoYko[1?nV_^/00ol0003oY[k[ojJnj`02ojS0
j`_oZ<7[00?oZ<3[ojJojonV_n/01OnV_n/;ooooo`03o`000?oooooooooo00Kooooo000Cooooo`04
o`000?ooooooooooooooo`?o0000;Oooool3ojJoj`?oYko[2?nX`>/00onY`N_oZ<7[ojS1j`04ojS1
j`OoY[o[1onW_n/7oj[1j`KoYko[1OnU_n`2ojFnk0OoZL3Z1OnV`>`2oj6nk@GoQ[7a0omWW>h01?ma
WngoNIkYogVNjOmiW^T3oh6Xk@Oo]<7T0_o3amd5omO@dPGoeLO=1oo;^l/3olRca@Ko]jg?00?o^jK4
ojnTcOn_Y<d01On_Y<d3ojRZf0CoZIO41_nSUlP6oibCbPKoSHS:1?mmP</6ogV4dPKoQiWN1?ndb^X4
ol;Nk@?oanc^0oo5i^h5okGBk`Ko[<G]0_nU_N/5ojNoj`OoZL;/1onX`>/6ojFnj`03ojJnjonX`N_o
Z<7[00coZ<7[1onW_n/3ojJnj`03ojNojol0003oYko[00[oZ<7[1OnX`>/7ojJoj`[ooooo00?o0000
ooooooooool01_ooool001?ooooo1?l0000aooooo`KoYko[1_nX`>/2ojW1j`OoZ<7[0onV_n/3ojJo
k0SoYko[1onZ`N/6ojNoj`03ojFok?nU_^coYKk/00CoYKk/1onY`>X00onV`>coXKk]oj6nk@04oj6n
k@GoQ[7a1?mWW>h6oh6Xk@Go]<7T1?o3amd3omO@dPKoeLO=00?odL39ol^kboo;^l/00oo;^l/5olRc
a@Co]jg?0onkY/@7ojnTc@03ojRZf?nYUlCoZIO400?oZIO41onSUlP5oibCbPKoSHS:1OmmP</6ogV4
dPKoQiWN00?o]<[Zol;NkOo2g^d00oo2g^d5olO/kP03olGVk_ned^oo]M;_00Go]M;_0on/aNd3ojJn
j`OoYko[1onY`^`7ojS0j`;oYKk[1OnV_^/>ojS1j`GoYko[0_nV_^/4ojNoj`03o`000?nW_n_oZ<7[
00KoZ<7[2?nX`>/3ojJoj`?oYko[2_ooool00ol0003oooooooooo`06ooooo`004oooool2o`0003Co
oooo1_nW_n/2ojS0j`KoZL7[1OnX`N/2ojO0j`KoY[o/1_nW_n/2ojS0j`OoZ/7[0onW_n/3ojJok0Oo
YKk/0onY`>X4oj_1jPOoXKk]1On6/O44ofNLkPKoPJS]0ond`N@6ol?7g@03omO@d_oEalgoeLO=00Co
eLO=0ooA`<T3ol^kb`Kob;?50ong[Ll5ok^Va0Go[jC=00?o/ig1ojVGa?nYUl@01OnYUl@6oj>Gb0Ko
W9?:1_n=R<X4ogf0b`KoNHCB1On7VMh3ojW3k0?o`]k]1Oo7k>h2ol;Xl@Ko]M;_00?o[<G]ojJnjonV
_^/01OnV_^/5ojNoj`WoZL;/0onX`>/;ojJnj`?oZ<7[0onX`N`8ojS1j`03ojNojonV_^_oY[k[00Co
Y[k[0onW_n/00ol0003oYko[ojNoj`07ojS1j`KoZ<3[2?nW_n/9ooooo`03o`000?oooooooooo00Ko
oooo0005o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo03;o
oooo1onW_n/7ojW1j`03ojS1jonW`>_oYl3[00CoYl3[1_nV_n`2ojNoj`KoZ<3[1OnZ`N/2ojW1j`Ko
Y[o/1OnU_^`3ojFok0KoZl7Z1OnQ_^d00onM_NooN:ccogR/l`03ogR/l`CoHYka00?oIic^oh6XkOn1
Z>d01?n1Z>d00ond`NCo`lOMol?7g@04ol?7g@;obLOH1OoEald5om70b@03ol^kboo8/lGob;?500Ko
b;?500?o]jg?ok^Va?nkY/@01?nkY/@3ojnTc@Co/ig11_nYUl@7oj>Gb0?oW9?:0_nHS<D6ohf8b@Co
R8c@00?oOH3;ogV4d_miQ=801?miQ=800on7VMkoZL?/ojW3k005ojW3k003ol;NkOo7k>koanc^00;o
anc^1Oo2j?42okGBk`Go[<G]1onV_^/00onW_n_oZL;/ojW2k009ojW2k003ojS1jonV_^_oY[k[00_o
Y[k[00?oZ<7[ojS1k?nX`N`01OnX`N`6ojS1j`03ojO0jonV_^_oY[k[00KoY[k[0onW_n/00ol0003o
Z<7[ojS1j`07ojS1j`;oZ<3[3?nW_n/8ooooo`03o`000?oooooooooo00Kooooo00001OnHV9So8B4Q
onk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`09ooooo`03o`000?oooooooooo
03?ooooo1_nW_n/7ojW1j`OoYl3[1onV_n`7ojS0j`03oj[1jonY`N_oZL7[00CoZL7[1_nV_n`00onU
_^coYKo/ojFok005ojFok0KoZl7Z00?oXKk]oifmkonM_Nl00onM_Nl5ogR/l`CoHYka1on;/O05ol?7
g@CobLOH0ooEald6om70b@Sob;?500?oak34ok^Va?nkY/@01_nkY/@00on_Y<go/ig1ok>M`@03ok>M
`@KoZIO41_nSUlP00onRTL?oV8c5oiR<a@04oiR<a@KoSHS91?n8S=06ohbIf`OoZL?/0onli?<00oo7
k>ko`^Saol;Xl@04ol;Xl@;o/]7`1on/aNd3ojJnj`?oY[o[2OnY`^`5ojS1j`WoY[k[1OnX`N/7ojS1
k0;oZ<7[1OnW`>/6ojJnj`03ojNojonX`N_oZ<7[00;oZ<7[00?o0000ojS1jonX`N/01_nX`N/=ojNo
j`03ojO0jooooooooooo00Kooooo00?o0000ooooooooool01_ooool00004oooooonHV9So8B4Qonk^
kPCooooo00Go410@oooooooooooooooooa0@400:ooooo`03o`000?oooooooooo03?ooooo1_nW_n/7
ojW1j`GoYl3[2OnV_n`5ojS0j`;oZL3Z1onY`N/3ojJok0_oYKo/0on[`NX3oj[1jPKoWKg_1Omh[?<4
of:Nl@OoRk7`0oo3amd6olW7f003omG7cOoA`<WodL3900GodL3900?ocKc9olRcaOo8/lD01?o8/lD3
olN`a0Ko^jK400?o_JO3ok>M`OncWL401OncWL46ojVGa0;oXiO81OnRTL<5oiR<a@KoSHS91On8S=06
ohbIf`CoZL?/1?nli?<4okkalP03ol;XlOnbdO3o/]7`00Co/]7`1On/aNd00onV_N[oY[o[ojJoj`05
ojJoj`OoZL;/1onX`N/5ojJnj`;oY[gZ1onX`N/6ojS1k0SoYl3[0_nV_^/5ojNoj`CoZ<7[00?o0000
ojS1jonX`N/01_nX`N/9ojNoj`GoYl3[1oooool00ol0003oooooooooo`06ooooo`000_ooool00onH
V9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000002oooool2o`0003Cooooo0onW_n/3
ojO0j`OoZL7[00?oYl3[ojJok?nV_n`02onV_n`00onX`>_oZL3ZojW0jP04ojW0jPGoZL7[0_nX`>/<
ojFok0;oY[o/1_nZ`NX6oifmk`GoN:cc1?mRW_47oh^al003ol?7gOo9amSobLOH00GobLOH1ooA`<T3
olflb@Cob;?51Oo7/<@4ok^Va0?o_JO31_ncWL45ojVGa003oj^I`onRTL?oXY7300GoXY731_nHS<D5
ohf8b@KoR8c@1_n<VM/00onY`nco_>CcokcTl`02okcTl`Go__7b00?o^^?cok;Al?nbdO001_nbdO00
0on/aNgoY[gZojJmjP03ojJmjPOoY[o[1onY`^`7ojS1j`03ojJnjonV_N[oY[gZ00CoY[gZ1OnX`N/8
ojS1k0KoYl3[00?oY[k[ojNojonW_n/01_nW_n/3ojS1j`03o`000?nX`N_oZ<7[00OoZ<7[1_nW_n/8
ojO0j`Oooooo00?o0000ooooooooool01Oooool000?ooooo00?oMgMgofIVI_ooool00_ooool01Ol0
003ooooooooooooooooo000000gooooo00?o0000ooooooooool0<_ooool6ojO0j`SoZL7[3OnV_n`7
ojW0jP03ojW1jonX`>_oZ<3[00CoZ<3[2?nU_n`6ojJok0KoZ/7Z0onM_Nl3oi^lk`GoKj[e0omLXO@0
1?mRW_7oRk7`oh^al?n;/O04oi2ilPSobLOH1OoA`<T4olflb@?ob;?51_o7/<@3ok^Va0Co_JO31onc
WL400onYUlCoZiW3oj^I``03oj^I``OoXY731OnHS<D6ohf8b@GoR8c@1On<VM/4ojc?l`03okcTlonn
lO;o__7b00;o__7b1?njho<6ok;Al003ojW2k?nV_N[oY[gZ00GoY[gZ1OnV_n/2ojW3k0OoZL;/0onX
`N/3ojJnj`SoY[gZ00?oZ<7[ojS1k?nX`N`02_nX`N`2ojO0j`GoY[k[1_nW_n/00onX`>_oZ<7[ojS1
j`02ojS1j`03o`000?nX`N_oZ<7[00GoZ<7[2?nW_n/6ojO0j`03ojS0jooooooooooo00Gooooo00?o
0000ooooooooool01Oooool000Cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oo
oooooooo00cooooo00?o0000ooooooooool0<_ooool6ojO0j`SoZL7[3OnV_n`5ojW0jP?oZ/7Z1_nX
`>/7ojFok0OoY[o/1_nZ`NX6oi^lk`GoKj[e1OmLXO@6oi2ilPSobLOH0ooA`<T6olflb@03olRcaOo7
/<Coak3400Koak3400?o^jK4okfW`onmYl<01?nmYl<5ok>M`@03okFRa_n[VL?oZiW300CoZiW31onR
TL<5oiR<a@KoSHS91_n8S=000on<VM_o[<ocojc?l`04ojc?l`?o]Ngf00?o__7bok[Slonjho<01Onj
ho<2ok;Al0GoZL;/1onV_NX00onV_n_oZL?/ojW3k004ojW3k0GoZL;/0_nX`>/6ojJnj`KoY[gZ00?o
Z<7[ojS1k?nX`N`02OnX`N`3ojO0j`OoY[k[0_nW_n/5ojS0j`CoZ<7[00Co0000ojS1jonX`N_oZ<7[
3?nW_n/2ojO0j`GoZ<3[1_ooool00ol0003oooooooooo`05ooooo`0000Go0000okZj^_ooooooV9RH
oa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03oooool00ol0003oooooooooo`0booooo`?o
Yl3[1?nX`>/7ojW1j`goY[o/00?oZL3Zoj[1j_nZ`NX01OnZ`NX6ojS0j`OoYKo/1onV_n`6oj[1jPKo
Vkc_1Om_Z_D5oebQm0KoT;Wb2?o9amP00ooA`<WocKc9olflb@05olflb@Soak3400?oa;?:okfW`onm
Yl<01OnmYl<4ok>M`@?o]J;61_n[VL<6oj:A``KoV8c50on=R<T2oiNOf@SoUjkW0on/co<4okG]mP?o
]_3e1Onjho<2ojk;k`OoZL;/0onV_NX4ojO1k0OoZL?/00?oZL;/ojS0jonX`>/01?nX`>/6ojJnj`;o
Y[gZ1OnX`N/7ojS1k0OoYl3[1OnV_^/00onW_n_oZ<3[ojS0j`06ojS0j`CoZ<7[00?o0000ojS1jonW
_n/02_nW_n/2ojO0j`SoZ<3[1Oooool00ol0003oooooooooo`05ooooo`0000GoV9RHoa0@4?l0003o
8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04?ooool2o`0003Cooooo1_nX`>/5ojW1
j`;oZ<3[3OnV_n`8oj[1jPKoZ<3[1onU_n`7ojJok0KoZ/7Z1_nK_>l5off/mP?oEJ?f0_mLXO@3oi2i
lP?oS[gf1_o9amP00oo4bMkocKc9olflb@05olflb@;ob;c>1_o7/<@3olBcbPKo_JO30oncWL44okFR
aPKoZiW31onRTL<3oiR<a@;oWIcB1_nGWmT8oiN^i`04ojc?lonekOKo]NgfokG]mPKo]_3e00?o^^?c
ojk;kon^bnl01?n^bnl5ojW2k0;oY[gZ1onW`N`3ojW3k0?oZ<;/2?nX`>/6ojJnj`OoZ<7[1onX`N`7
ojO0j`03ojJnjonW_n_oYko[00?oYko[1_nX`>/00onX`NcoZ<7[ojS1j`02ojS1j`03o`000?nX`N_o
Z<7[00OoYko[1_nW`>/6ojS0j`03ojS1jooooooooooo00?ooooo00?o0000ooooooooool01Oooool0
01oooooo00?o0000ooooooooool0<_ooool6ojS0j`03ojW1jonX`>_oZ<3[00CoZ<3[3OnV_n`8oj[1
jPKoZ<3[1onU_n`7ojJok0?oZ/7Z0onZ`>X6oi^lk`GoKJcf1_mEXoH5ohjmmP?obLOH1?o4bMh5olfl
b@Cob;c>1?o7/<@4olBcbPOo_JO300?o/ig1okFRa_neX/H01?neX/H5oj^I``KoXY7300?oYIo@oifL
d_nMW=801?nMW=86oiNOf@KoUjkW0on[hoX00onekOKo]_3eokK`m@04okK`m@?o/=?c1_n^bnl00onY
`^coY[gZojJmjP04ojJmjPGoYl7/0_nY`n`6ojS2k0KoZ<3[00?oY[gZojJnjonV_^/01OnV_^/5ojS1
j`WoZ<7/0onW`>/3ojJnj`OoYko[0_nX`>/5ojS1k0CoZ<7[00?o0000ojS1jonX`N/01onW_n/6ojO0
j`;oZ<3[1OnX`N/4ooooo`03o`000?oooooooooo00Gooooo000Pooooo`03o`000?oooooooooo03;o
oooo3OnX`>/=ojJok0SoZ/7Z1_nX`>/7ojFok0GoY[o/0_nV`>`6oj[0jPKoVkc_1Om][?H6oeFSmPGo
S[gf00?obLOHolC9g_o4bMh01?o4bMh3olflb@Gob;c>0oo7/<@5olBcbPKo_JO300?o_:k<okFRa_ne
X/H01OneX/H6oj^I``;oXY731OnUWm06oifLdPKoUioI0_nG[^L5oj_SnPCoZO7f00?o]_3eok3Clon`
do<01On`do<3ojk;k`?oYkkZ1onV_NX00onW`NcoZL?/ojW3k004ojW3k0KoZ<;/0_nX`>/5ojJmjPOo
Y[k[00?oZ<7[ojS1k?nX`N`02OnX`N`00onW`>_oY[k[ojJnj`05ojJnj`GoYko[0_nX`>/7ojS1k0?o
Z<7[00?oYko[o`000?nW_n/02?nW_n/3ojO0j`;oZ<3[2?nX`N/3ooooo`03o`000?oooooooooo00Go
oooo000Qooooo`03o`000?oooooooooo03;ooooo3_nX`>/=ojJok0OoZ/7Z0onX`>/3ojO0j`OoYKo/
00?oY[o/ojK0k?nV`>`01?nV`>`6oj[0jP?oVkc_1?nM_Nl5ogB`m`GoBj?g1On1__/7olC9gP03olfl
bOo8_<kob;c>00Gob;c>00?oak34olBcb_o4/lX01Oo4/lX3okfW``Co_:k<1_neX/H5oj^I``03ojfY
donUWm3oYIo@00GoYIo@1_nMW=85oiNOf@?oYMWj0on[hoX5ojWamP;o/Mkg1_n`do<00onY`^_oYkkZ
ojNnjP05ojNnjPGoY[gZ00?oZ<?/ojW3k?nY`n`01_nY`n`3ojS2k0?oYko[1onV_NX3ojJnj`coZ<7/
1OnW`>/7ojJnj`03ojNojonX`>_oZ<3[00CoZ<3[1OnX`N`00onX`N_oYko[ojNoj`02ojNoj`03o`00
0?nW_n_oYko[00OoYko[1_nX`>/6ojS1j`03ojS0jooooooooooo00;ooooo00?o0000ooooooooool0
1?ooool002;ooooo00?o0000ooooooooool0<_ooool>ojS0j`goY[o/1onZ`NX6ojO0j`OoYKo/1onV
`>`6oj[0jPOoWKg_1_md/?L4od^Sm`GoPKkk1Oo4bMh2okG>k@Kob;c>00?oa<cPolBcb_o4/lX01_o4
/lX00onmYl?o_:k<okb^c004okb^c0Oo]J;600?oZiW3ojfYdon]ZM<00on]ZM<6ojFOd0OoWIcB00?o
UioIojGIn_nUfOX01OnUfOX01?n[ho[oZO7fojWam_nYlOH6ok7Nm`;o/=?c1OnY`^/7ojNnjP03ojJm
j_nX`ncoZ<?/00?oZ<?/1_nY`n`00onX`NcoYko[ojNoj`05ojNoj`GoY[gZ0_nV_^/=ojS1k0OoYl3[
0onV_^/3ojNoj`SoZ<3[00?oZ<7/ojS1jonX`N/00onX`N/4ojNoj`03o`000?nW_n_oYko[00OoYko[
1_nX`>/2ojS1j`GoZ<3[0oooool00ol0003oooooooooo`04ooooo`008oooool2o`0003?ooooo0onX
`>/4ojW0j`OoZ<3[3OnV_n`7oj[1jPKoYl3[1onU_n`7ojK0k0KoZ/3Z1OnM_Nl3oj6mk@KoP[Kf0_m7
Y?L00om;XoOoPKkkoh6nn`03oh6nn`03olC9g_nec^go]Lk]00Co]Lk]0oo8_<h4olC<h0Koa;?:00?o
`LSPokb^c?nl[/`01_nl[/`5okFRaP03okJig?n]ZM?o[JWC00Go[JWC1_nUWm05oifLdP;oXm;h1_nU
fOX2oic]m`?oZ^Gj1Onag_L2oj_6kPOoZL;[0onW_^X3ojK0k0OoZ<?/0_nY`n`5ojS1k0OoYko[00?o
Y[gZojJnjonV_^/01?nV_^/=ojS1k0GoYl3[0_nV_^/6ojNoj`KoZ<3[00?oZ<7/ojS1jonX`N/01OnX
`N/4ojNoj`03o`000?nW_n_oYko[00OoYko[0onX`>/2ojS1k0SoZ<3[0_ooool00ol0003ooooooooo
o`04ooooo`009Oooool00ol0003oooooooooo`0booooo`KoZL3[1OnX`>/2ojO0j`[oY[o/0onW`>/7
oj[1jPOoYl3[1_nU_n`7ojK0k0KoZ/3Z00?oWKg_oj6mkOnQ_Nd01OnQ_Nd6oh:fmPCoAjCg1OmW^_d6
okG>k@03olRlc_o4c>3oa<cP00Coa<cP1?o4/lX3ol78h0Oo_:k<0oneX/H4okJig0Ko[JWC1_nUWm02
oifLdPKoXm;h0_nUfOX2oic]m`OoZ^Gj00?o/Mkgoj_6k_n[a^h01?n[a^h5ojW2j`;oY[kZ1_nV`>`5
ojS3k0;oZ<;/1onX`N`3ojNoj`?oY[gZ2?nV_^/=ojS1k003ojO0jonV_^_oY[k[00CoY[k[1_nW_n/2
ojS0j`GoZ<7/1OnX`N/6ojNoj`03o`000?nW_n_oYko[00GoYko[00?oZ<3[ojS1k?nX`N`01?nX`N`6
ojS0j`04ojNojoooooooooooo`0000Kooooo000Vooooo`03o`000?oooooooooo03;ooooo1_nY`>/0
0onX`>_oYl3[ojO0j`04ojO0j`OoY[o/1_nW`>/7oj[1jPOoYl3[1_nU_n`7ojK0k0?oZ/3Z0on[`NX8
oj6mk@?oP[Kf0onB^o<3oeZZn@03odNTmomW^_goIk[m00?oIk[m0onec^d3ohc=oPKoa<cP0oo4/lX5
ol78h0Oo_:k<00?o]J;6okJig?nf^M`01?nf^M`6ojfYd`?oYIo@2OnSd_P3oi3Yn0?oW^Kl1OnZiOX3
oj[:l0KoZlK^00?oZL;[ojJnj_nV_^X01?nV_^X6ojK0k003ojS3k?nX`^coZ<;/00CoZ<;/1OnX`N`2
ojNnjPKoY[gZ1_nV_^/;ojS1k0?oYko[2?nV_^/3ojNoj`;oZ<7[2?nX`N`00onX`N_oYko[ojNoj`07
ojNoj`03o`000?nW_n_oYko[00;oYko[1OnX`>/6ojS1k0;oZ<3[1OnW_n/00ooooooo0000ooooo`05
ooooo`009oooool00ol0003oooooooooo`0booooo`KoZL3[1onW`>/7ojJok0KoYl3[1onZ`NX5ojO0
j`;oZ<3[1_nU_n`5ojK0k0;oYL3]1_n[`NX6oj6mk@;oY[k[1_nB^o<5oeZZn@GoBK3i1On<cOh6olC<
h003olBcb_o1b>3o`LSP00Co`LSP1_nl[/`00ongdNgo][WLokJig005okJig0Go[JWC0onQeo/7oj?B
n0?oT>Wh1onNi_`00onZiO[oZ/[`oj[:l005oj[:l0?oZlK^0_nW_NT8ojJnjP?oY/3/0onX`nd7ojS2
k003ojS1k?nW_^[oYkkZ00CoYkkZ1_nV_NX2ojJnj`[oZ<7/0_nX`N/6ojNoj`KoY[k[00?oYko[ojS1
jonX`N/01?nX`N/6ojS1k003ojS1jonW_n_oYko[00WoYko[00?o0000ojO0jonX`>/01onX`>/3ojS1
k0CoZ<3[1_nW_n/00ol0003oooooooooo`04ooooo`00:?ooool2o`0003?ooooo1_nY`>/7ojO0j`Oo
Y[o/0onW`>/3ojO0k0OoZ/7Z00?oYl3[ojS0jonX`>/01?nX`>/6ojFok003ojK0k?nU`>goYL3]00Co
YL3]1_n[`NX2oj6mk@KoY[k[1_nB^o<5oeZZn@GoBK3i1On<cOh3olC<h0CoW]Kk1_o1b>02okb^c0Go
]m7]1onf^M`00on]ZM?oXMOkoj7Gn`05oj7Gn`?oXm;h1?n5i?L3oi?Ro@?oW^Kl1?nXbo86oj[:l0Oo
YkgY1_nV_^X8ojS3k@GoZ<;/00?oZ;o[ojNnj_nW_^X01_nW_^X3ojJmjP?oYl3[2?nX`N`6ojS1j`Ko
Yko[0_nV_^/5ojNoj`KoZ<7[0_nX`N`5ojS1j`OoYko[1?nW`>/00ol0003oYl3[ojS0j`05ojS0j`03
ojS1k?nX`>_oZ<3[00KoZ<3[0onW_n/2ooooo`03o`000?oooooooooo00Cooooo000Zooooo`03o`00
0?oooooooooo037ooooo1_nY`>/7ojO0j`OoY[o/1_nW`>`7oj[1jPOoZ<3[1_nU_n`7ojG0k@?oZl7Z
0onY`N/8ojJnj`?oT[_c1?nM_>h5ogbgn@GoAZch1OmI`?/6oikFn`?o`LSP1?nCfOh6okOAk@?o][WL
1?nEg?h6oj7Gn`?oM]ke0_n5i?L5oi?Ro@;oY/_c1onXbo82oj[:l0_oYkgY0_nV_^X<ojS3k@03ojS2
k?nX_n_oZ;o[00?oZ;o[1_nW_^X00onV_^_oYl3[ojO0j`05ojO0j`KoZ<7/2?nX`N/3ojNoj`;oY[k[
2?nW_n/3ojS1j`CoZ<7/1_nX`N/7ojNoj`CoYl3[00Co0000ojO0jonX`>_oZ<3[1OnX`N`6ojS0j`Oo
oooo00?o0000ooooooooool00oooool002_ooooo00?o0000ooooooooool0<Oooool3ojW0j`CoZL3Z
1_nW`>/7ojJok0KoYl3/1onZ`NX5ojS0j`;oZ;oZ1_nU_n`5ojG0k@;oY;o]1_nY`N/6ojJnj`;oZL3Z
1onM_>h5ogbgn@GoAZch1OmI`?/3oikFn`CoGLSj1_nCfOh3okOAk@CoN=Wl1_nEg?h2oj7Gn`CoM]ke
1On=g?l00onCh_goY/_cojK;l`04ojK;l`GoZ<_b0_nX_^T;ojNmj@;oZ<;]2_nX`nd4ojS1k0KoZ;o[
0_nW_^X5ojJnj`OoYl3[1_nX`N`6ojS1j`03ojNnj_nV_^_oY[k[00CoY[k[1_nW_n/9ojS1k0?oZ<7[
2_nW_n/3ojO0j`03o`000?nX`>_oZ<7/00OoZ<7/0_nX`>/:ooooo`03o`000?oooooooooo00?ooooo
000/ooooo`03o`000?oooooooooo037ooooo1onY`>X6ojO0j`OoY[o/0onW`>`3ojK0k0OoZ/7Z00?o
Z<3[ojRoj_nX_nX01?nX_nX6ojFok003ojG0kOnT_ngoY;o]00CoY;o]1_nY`N/2ojJnj`KoZL3Z1OnM
_>h2ojJmjPKoUkgb1_m^]_/5odBdmPGoGLSj0onCfOh5oeG8m0GoN=Wl0onEg?h3ofGElPGoS=?o0on=
g?l4ojC8lPKoY/_c00?oZ<_bojRnjOnX_^T01?nX_^T7ojNmj@KoZ<;]1OnX`nd9ojS1k0?oZ;o[0onV
_NX7ojJnj`?oYl3[2_nX`N`2ojS1j`GoYkkZ1_nV_^/2ojNoj`_oZ<7/00?oZ<3[ojNojonW_n/02_nW
_n/00onW`>_oZ<3[ojS0j`02ojS0j`03o`000?nX`>_oZ<7/00GoZ<7/3Oooool00ol0003ooooooooo
o`03ooooo`00;Oooool2o`0003;ooooo1onY`>X6ojO0j`OoY[o/1_nV`>`7oj[1jPOoZ;oZ0onU_n`3
ojJok0OoY;o]0onY`N/3ojO1k0SoZL3Z00?oWKc^ojJmj_nV_NX01?nV_NX6oiNmlP?oK[Kk1?nE__<6
og6jo0GoCkgh0omEb?@5ofc8oP?oGLge1?n@bO/5ohcCo`;oXlC`1onTb?83ojK;l`?oYkkY1onX_^T3
ojNmj@CoYl7/1_nX`^d00onX`ngoZ<7/ojS1k009ojS1k003ojNmj_nV_N[oY[gZ00GoY[gZ1OnV_^/=
ojS1k0;oZ<3[1onW_^X3ojJnj`?oYl3[2OnX`N`5ojS0j`SoYko[1OnW`>/4ojS0j`04o`000?nX`>_o
Z<7/ojS1k13ooooo00?o0000ooooooooool00oooool002oooooo00?o0000ooooooooool0<?ooool7
ojW0jPKoYl3[1onV_n`6ojK0k0OoZ/7Z1OnX_nX2ojVojPKoY[o/1OnT_nd2ojFok@KoYl7/1_nY`>X0
0onZ`^_oY[gZojJmjP06ojJmjP?oUkgb0onS_N`7oiFnl`?oLK[l0onI_o87ohC2n`?oK<Sn1?nJaOD6
oi39n`03ohcCoonSa?3oXlC`00CoXlC`1OnTb?800onW_NWoYkkYojNnj@05ojNnj@GoZ;kY2OnW`N`3
ojS2k@;oZ<;/2OnX`N`5ojNmjPOoY[gZ00?oY[k[ojS1k?nX`N`02onX`N`6ojS0j`GoYkkZ00?oYko[
ojO0jonW`>/01OnW`>/6ojS1k0SoZ<3[1OnW_n/8ojO0j`?oZ<3[00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`03ooooo`00<?ooool00ol0003oooooooooo`0aooooo`KoZL3Z1onW`>/6ojJo
k0KoY/3/1onZ`NX00onX_n[oZKoZojVojP04ojVojPKoY[o/00?oY;o]ojFokOnU_nd01?nU_nd6ojO1
k0;oZL3Z1OnZ`^/6ojJmjP03oj[1j_nS_NcoXkg/00GoXkg/0onE__<3oj>mk0OoVKob0on4`_/3oino
k`SoV/Ge0on@bO/3ojC0kPOoXlC`00?oY<SbojNmjOnW_NT00onW_NT7ojNnj@03ojRnjOnW`NcoYl7/
00WoYl7/00?oZ<;]ojS2k?nX`^`01?nX`^`6ojS1k003ojNnj_nW_N[oYkgZ00GoYkgZ0onV_NX3ojO0
k0koZ<7/1onX`>/00onW_^[oYko[ojNoj`03ojNoj`OoYl3[1_nX`N`6ojS0j`OoYko[1_nW`>/5oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool00oooool0037ooooo00?o0000oooooooo
ool0<Oooool7ojW0jPKoYl3[1onV_n`5ojK0k0GoZ/7Z0onY`N/6ojVojP?oY[o/1?nW_n/6ojFok@?o
Yl7/1?nU`>d6oj[2j`;oY[gZ1OnZ`NX5oj>mk0;oZKoZ1_nS_N`5oiVolP;oYKgZ1_nO_nl6oi[5m@03
ojFmjonT`>koY<3^00GoY<3^0onSa?03ojRmj@OoYkgY0onW_^T<ojO1k0GoZ<;]1_nX`^`2ojS1k0Go
YkkZ1OnW_NX2ojNoj`KoYl3/3_nX`N`3ojS0j`?oYkkZ1onW_n/3ojO0j`[oZ<7/0_nX`>/;ojNoj`;o
Yl3[2Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo000booooo`;o0000
<_ooool7ojW0jPKoYl3[1onV_n`5ojK0k003oj[1j_nY`N_oZL7[00GoZL7[1?nY_nX3oj[0jPKoYko[
0onU_nd3ojFok0OoYL3]0onZ`^/3ojO1k@OoZ/7Z00?oXkg/ojVoj_nY_nX01?nY_nX6oj>mk003oiVo
l_nU_N[oYKgZ00CoYKgZ1_nO_nl2oi[5m@GoYKg[1OnT`>h2ojRnj@KoZ;gY1OnW_NT2ojS2k0[oYl7/
0onW`^d7ojS2k@?oZ<;/1?nX_n/6ojNnjP03ojNmj_nW_n_oYko[00CoYko[1_nW`>`<ojS1k0SoYkkZ
1OnW_n/<ojS1k0goYko[3_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo
000dooooo`03o`000?oooooooooo033ooooo1onY`>X3ojO0j`CoZ<3[1_nV_n`6ojK0k0OoZL7[00?o
ZKoZoj[0j_nZ`>X01?nZ`>X4ojNoj`;oZ;oZ1_nU_n`7ojG0k@KoYl7]1OnZ`NX2ojS2k0OoZKoZ0onS
_N`3ojW0jPOoYKgZ0onO_nl4ojRnj@KoYKg[00?oY<3^ojRnjOnX_^T01?nX_^T6ojRmj@03ojNmjOnX
`^coZ<;/00CoZ<;/1OnW`N`8ojO2k@GoZ<;]0_nW_n/7ojRoj`KoYkkZ1onW_n/3ojO0k0_oZ<7/3?nW
_^X00onW_n_oZ<7/ojS1k00:ojS1k0coYko[4_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00;ooooo000eooooo`03o`000?oooooooooo033ooooo1OnY`>X2ojW0j`OoZ<3[0onV_n`:
ojK0k0?oZL7[0onX`>/7oj[0jP03ojNojonX_n[oZ;oZ00?oZ;oZ1_nU_n`7ojG0k@KoYl7]00?oZ/7Z
ojS2k?nX`^`01?nX`^`5ojVojP;oZ<;/1_nY`>X5ojFmjP;oZL7[1onX_^T3ojFmj`?oZL7[1onX_^T3
ojRmj@CoYl;]1_nX`^`00onW`NcoYl;]ojO2k@0:ojO2k@03ojS2kOnW_n_oYko[00CoYko[1OnX_n/8
ojNnjPGoYko[3?nX`N`2ojRoj`_oYkkZ0_nW`>/>ojS1k0SoYko[5_ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00;ooooo000fooooo`03o`000?oooooooooo033ooooo00?oZL3ZojW0
jonY`>/01?nY`>/7ojS0j`goY/3/1_nX`>/5oj[0jP;oZ/7Z1_nX_nX3ojFok0?oY[o[1onU`>d3ojO1
k@CoYL3]1_nX`^`00onY_n[oZ<;/ojS2k004ojS2k0KoZL3Z00?oYKgZojW1jonY`N/01?nY`N/5ojRn
j@;oZ<;/1_nY`N/5ojRnj@WoYl;]0onX`^`=ojO2k@?oYl3[1onW_n/00onX_n_oYkkZojNnjP0:ojNn
jP03ojNojonX`NcoZ<7/00WoZ<7/00?oZ<3[ojRojonX_n/01?nX_n/6ojNnjP03ojNojonW`>_oYl3[
00CoYl3[3_nX`N`3ojNoja_ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02oooo
o`00=oooool2o`00037ooooo1onY`>/7ojS0j`goY/3/1_nX`>/00onZ`>[oZ/7Zoj[1jP04oj[1jPCo
Z;oZ0_nY_nT6ojJoj`GoYL3]0_nV_n`7ojG0k@?oZ<;/0onU`Nd7ojS2k0?oZL3Z1?nW`^d6ojW1j`03
ojRnjOnX`^coZ<;/00CoZ<;/1_nY`N/00onX_^WoYl;]ojO2k@0FojO2k@SoYl3[0onW_n/3ojNmj@[o
YkkZ0onW`N`9ojS1k0GoZ<3[1_nX_n/2ojNnjPGoYko[1_nW`>/<ojS1k23ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`02ooooo`00>Oooool00ol0003oooooooooo`0_ooooo`GoZL3[
2OnX`>/3ojK0k0?oY[o[1onV`>`3ojS0j`CoYl3/1_nZ`NX00onX_n[oZKoYojVoj@03ojVoj@KoY[o[
00?oYL3]ojJok?nV_n`01?nV_n`5ojG0k@;oY/3/1_nU`Nd5ojS2k0;oYL7]1onW`^d3ojW1j`?oY/;]
1onX`^`3ojW1j`CoY/;]5?nW`^d:ojO0j`SoYkgY1OnW_^X8ojO1k0OoZ<7/1onX`>/3ojRoj`?oYkkZ
1onW_n/3ojO0j`_oZ<7/8oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo
000jooooo`03o`000?oooooooooo02oooooo00?oZL3[ojS0jonX`>/02OnX`>/2ojW0jPKoY[o[1onV
`>`7ojO0k0?oZ/7Z0onY`N/6ojVoj@?oY[o[1?nX_nX6ojJok003ojG0kOnV`>coY/3/00CoY/3/1_nU
`Nd00onX`^coYL7]ojG1k@04ojG1k@GoYl;]0_nV`Nd6ojK2k@GoZ<;/00?oY/7]ojK2kOnV`^d01_nV
`^d3ojO2k@;oYl7/2_nW`^d4ojNoj`OoYl3[3?nW_NT00onW_^[oYl7/ojO1k00:ojO1k0OoZ<7/1OnX
`>/8ojNnjPGoYko[00?oYl7/ojS1k?nX`N`02?nX`N`Xooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool00_ooool003_ooooo00?o0000ooooooooool0<?ooool7ojS0j`KoZL3Z1_nV_n/7
ojK0k0GoYl3/0_nV`>`6ojW1j`CoZKoY0_nZ`>X7ojRojP?oY[o/0onW_^X7ojK0k0?oYL7]1?nV`>`6
ojG1k@03ojO2kOnV`NgoY/7]00CoY/7]1_nV`^d00onX`^coY/7]ojK1k@03ojK1k@KoY/;]00?oYl3/
ojO1k?nW`N`01?nW`N`5ojO2k@WoYko[0onW`>/=ojNmj@goYl7/2_nX`N`00onX`>_oYkkZojNnjP0:
ojNnjP03ojNojonW`NcoYl7/00?oYl7/1OnX`N`]ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool00Oooool003cooooo00?o0000ooooooooool0<?ooool6ojS0j`OoZL3Z0onV_n/4ojNo
j`KoY/3/00?oYl3/ojK0k?nV`>`01?nV`>`6ojW1j`03ojVojOnZ`>[oZ/3Z00?oZ/3Z1OnX_nX2ojVo
j@KoYkkZ1OnV`>`2ojNnjPOoY/3/0onU`Nd3ojK0k0OoY/7]0onV`^d3ojK0k0KoY/7]0_nV`^d5ojO0
k0KoYl7/00?oYl;]ojNojonW_n/02OnW_n/2ojRnj@_oYkgY3_nW`N`:ojS1k0goYkkZ1?nW`>/6ojO1
k003ojS1k?oooooooooo02oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`01oooo
o`00?Oooool2o`00037ooooo1_nX`>/7ojW0jPOoYko[3OnV`>`3ojW1j`?oYl7/1_nZ`>X00onX_n[o
ZKoYojVoj@04ojVoj@KoYkkZ00?oY/3/ojNnj_nW_^X01?nW_^X5ojK0k0;oYkkZ1_nV`>`5ojK1k@03
ojNojonV`>coY/3/00GoY/3/0onV`Nd3ojNoj`OoYl3/0onW`N`4ojNnjPOoYko[1_nX_^T7ojNmjA;o
Yl7/1OnX`N`2ojNoj`_oYkkZ0_nW_n/7ojO0j`?oYl7/=?ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo007ooooo000oooooo`03o`000?oooooooooo02oooooo1_nX`>/7ojW0jPGoYko[
0_nX_n/=ojK0k0KoYl7/0onZ`>X3ojS1j`OoZKoY0onW_^X4ojVoj@KoYkkZ00?oY/3/ojNnj_nW_^X0
1?nW_^X6ojK0k003ojK1kOnW_n_oYko[00?oYko[1OnV`>`2ojNnjPKoYko[1OnW`>`2ojNnj@OoYkkZ
0onW_n/:ojRnj@?oYkgY5_nW`N`00onX`NcoYko[ojNoj`04ojNoj`OoYkkZ1_nW_n/5ojO0jcWooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`01ooooo`00@?ooool00ol0003ooooooooo
o`0_ooooo`?oZ<3[1?nW`>/6ojW0jP03ojNojonX_n_oZ;o[00CoZ;o[3OnV`>`4ojO1k0;oY/3/1_nX
`N/5ojVoj@;oZL7[1onY_nT3ojNnjP?oZKoY1onW_^X3ojK0k0?oYkkZ1_nW_n/00onV`>coYkkZojNn
jP04ojNnjPKoYko[00?oYl3/ojNnjOnW_^T01?nW_^T5ojNnjP03ojRnj_nX_^WoZ;kY00[oZ;kY6?nW
`N`:ojNoj`?oYkkZ2_nW_n/00onW`>_oooooooooo`0kooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool00Oooool0047ooooo00?o0000ooooooooool0;oooool7ojO0j`?oZL3Z0onY`>/7
ojRoj`?oY/3/1?nW_n/6ojK0k003ojO1k?nV`>coY/3/00?oY/3/1_nX`N/00onY_nWoZL7[ojW1j`04
ojW1j`GoZKoY0_nY`N/6ojVoj@GoYkkZ00?oZKoYojNnj_nW_^X01OnW_^X3ojNoj`?oZ;kY1onW_^X3
ojNoj`CoZ;kY1_nW_^T00onW_^[oZ;kZojRnjP03ojRnjPSoZ;kY5onW`N`00onW`>_oYko[ojNoj`09
ojNoj`;oYkoZ2_nW_n]1ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00Oooool0
04;ooooo0_l0000`ooooo`GoYl3[0_nW`>`6ojW0j`GoZ;o[0_nY_nX7ojNoj`coY/3/0onX`N/4ojK1
k0KoZL7[00?oZKoYojW1jonY`N/01?nY`N/6ojVoj@03ojNnj_nY_nWoZKoY00?oZKoY1OnW_^X2ojVo
jPKoZ;kY1OnW_^X2ojRojPOoZ;kY0onW_^T2ojRoj`OoZ;kZ0onX_^THojO1k0GoYl3[1_nW_n/00onW
_^[oYkoZojNojP04ojNojPGoYko[A_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
007ooooo0014ooooo`03o`000?oooooooooo02kooooo00?oYl3[ojO0k?nW`>`01?nW`>`6ojW0j`03
ojRojonY_n[oZKoZ00CoZKoZ1OnW_n/2ojRoj`coY/3/1onV`N`3ojW1j`?oYl7/1onY`N/3ojVoj@Co
ZL7[1OnY_nT00onW_^[oZKoZojVojP04ojVojPKoZ;kY00?oYkkZojRoj_nX_nX01?nX_nX5ojRnj@03
ojS1jonX_n_oZ;o[00CoZ;o[1OnX_^XIojO1k0WoYl3[0_nW_n/5ojNnjPKoYkoZ00?oYko[oooooooo
ool0B?ooool00ol0003oooooooooo`07ooooo`7o00000Oooool1ooooo`00AOooool00ol0003ooooo
ooooo`0_ooooo`KoYl3/0onY`>/4ojS0j`KoZKoZ00?oYko[ojRojonX_n/01?nX_n/5ojK0k003ojNo
jonV`>coY/3/00CoY/3/1OnV`N`2ojK0k0KoYl7/1OnY`N/2ojO1k0OoZL7[0_nY_nT3ojS1j`OoZKoZ
0onX_^T4ojS1j`KoZ;oZ00?oZ;kYojS1jonX`N/00onX`N/6ojRoj`03ojRnj_nW`NcoYl7/01KoYl7/
2onW`>/:ojNnjP?oYkoZC_ooool00ol0003oooooooooo`06ooooo`7o00000Oooool1ooooo`00A_oo
ool00ol0003oooooooooo`0`ooooo`GoYl3/1onX`>/3ojVojPCoZL3[1_nX_n/00onV`>coYko[ojNo
j`03ojNoj`KoY/3/00?oY/7/ojK0k?nV`>`01?nV`>`6ojO1k003ojW1jonW`NcoYl7/00CoYl7/1OnY
`N/00onW`NcoZ<7[ojS1j`04ojS1j`GoZKoZ0_nW`N`7ojS1j`?oZ;oZ0_nW`N`7ojS1j`?oZ;o[6?nW
`N`:ojO0j`goYkkZD_ooool00ol0003oooooooooo`06ooooo`7o00000Oooool1ooooo`00Aoooool2
o`00037ooooo1OnW`>`5ojS0j`;oYl3/1onY`>/3ojRoj`?oZKoZ1_nW_n/3ojK0k0CoY[o[1_nV`>`3
ojO1k0CoY/3/1_nW`N`00onY`N_oYl7/ojO1k003ojO1k0KoZ<7[00?oZKoZojO1k?nW`N`01?nW`N`5
ojS1j`OoYl7/1OnX`N/IojO1k0[oYl3[3OnW_^YFooooo`03o`000?oooooooooo00Gooooo0Ol00001
ooooo`7ooooo0019ooooo`03o`000?oooooooooo02oooooo1OnW`>`00onX`>_oYl3/ojO0k004ojO0
k0GoZL3[0_nX`>/6ojVojPCoYko[0_nX_nX7ojJoj`?oY/3/0onV_n`7ojK0k0?oYl7/0onV`>`6ojO1
k0?oZ<7[1?nV`N`6ojO1k003ojS1jonW`NcoYl7/00WoYl7/00?oZ<7[ojO1k?nW`N`05OnW`N`2ojNo
j`[oYl3[3OnW_^YJooooo`03o`000?oooooooooo00Cooooo0Ol00001ooooo`7ooooo001:ooooo`03
o`000?oooooooooo02oooooo0_nW`>`4ojK0k0KoYl3/00?oZL3[ojS0jonX`>/01?nX`>/6ojVojP03
ojNojonX_n[oZ;oZ00?oZ;oZ1OnV_n/2ojRojPKoY[o/1OnV`>`00onV_ncoY/3/ojK0k005ojK0k0?o
Yl7/0onV`>`7ojK1k0?oYl7/0onV`N`OojO1k0OoYko[1OnW`>/2ojRnjP_oYkkZGoooool00ol0003o
ooooooooo`03ooooo`7o00000Oooool1ooooo`00Boooool00ol0003oooooooooo`0_ooooo`KoY/3/
1_nW`>`7ojS0j`?oZKoZ1?nY`>/5ojRojP03ojJojonX_n[oZ;oZ00CoZ;oZ1_nV_n`00onV`>coY[o/
ojJok003ojJok0GoY/3/0_nW_n/6ojK0k0GoY/7/0_nW`>`6ojK1k13oYl7/1?nW`>`7ojO1k0_oYko[
00?oYl3[ojRnj_nX_^X01?nX_^X7ojNnjV;ooooo00?o0000ooooooooool00oooool1o`00007ooooo
0Oooool004cooooo0_l0000`ooooo`KoY/3/1_nW`>`5ojS0j`;oYl3/1onY`>/2ojRojPCoZL3Z1_nX
_nX3ojJok0CoYkoZ1OnV_n`00onV`>coYko[ojNoj`04ojNoj`KoY/3/00?oY/7/ojO0k?nW`>`01?nW
`>`4ojK1k0;oYko[2onW`N`2ojNoj`OoYl3/0onW`N`2ojNnjP[oYko[2_nX_^X3ojNnjVKooooo00?o
0000ooooooooool00oooool1o`00007ooooo001>ooooo`03o`000?oooooooooo02kooooo1_nV`>`6
ojO0k003ojS0jonW`>coYl3/00CoYl3/1OnY`>/00onX`>_oZL3ZojW0jP05ojW0jP?oZ;oZ0onY`>X7
ojNojP;oY[o/1?nW_nX6ojNoj`?oY/3/1?nW_n/6ojO0k003ojK1k?nW_n_oYko[00?oYko[1onW`N`6
ojNoj`GoYl3/00?oZ;kZojNnj_nW_^X01?nW_^X5ojNoj`;oZ;oZ2_nX_^Y/ooooo`03o`000?oooooo
oooo00;ooooo0Ol00001ooooo`00Coooool00ol0003oooooooooo`0_ooooo`GoY/3/0onW`>`4ojK0
k0KoYl3/00?oZL3[ojS0jonX`>/00onX`>/5ojW0jP;oZ<3[1_nY`>X5ojNojP03ojVoj_nW_n[oYkoZ
00GoYkoZ0onW_n/3ojRojPOoYko[0onW`>`3ojNnjPKoYko[0onW`N`4ojNnjPKoYko[00?oYl3/ojRn
j_nX_^X00onX_^X6ojNnjP03ojNojonX_n[oZ;oZ00CoZ;oZ1OnX_^Yaooooo`05o`000?oooooooooo
ooooool000000Oooool0053ooooo00?o0000ooooooooool0;oooool2ojK0k0CoYko[1_nV`>`7ojO0
k0GoZ<3[00?oZL3ZojS0jonX`>/01?nX`>/6ojW0jP03ojNoj_nY_n[oZKoZ00?oZKoZ1OnW_nX2ojS0
jPKoZ;oZ1OnW_n/00onX_n[oYkkZojNnjP05ojNnjP?oYko[0onX_^X7ojNnjP?oYko[0onX_nX6ojRn
jP?oYkkZ1?nX_n/6ojRojP03ojRnj_oooooooooo07;ooooo00Go0000ooooooooooooooooo`000001
ooooo`00DOooool2o`00033ooooo1_nW_n/3ojK0k0?oY[o/1onW`>`2ojS0j`CoYl3/1_nX`>/3ojW0
jPCoZ<3[1OnY_nX00onW_n[oZ<3ZojS0jP04ojS0jPKoZ;oZ00?oYko[ojRoj_nX_nX00onX_nX5ojNn
jP;oZ;oZ1_nX_^X5ojNnjPSoZ;oZ0onX_^X3ojS0j`OoZ;o[0onX_nYhooooo`04o`000?oooooooooo
o`00007ooooo001Cooooo`03o`000?oooooooooo02kooooo1?nW_n/2ojRoj`KoY[o/1OnW`>`00onV
`>coYl3/ojO0k005ojO0k0?oZ<3[0onW`N`7ojS0j`;oZKoZ1?nX`N/6ojS0jP?oZ;oZ0onX`>/6ojRo
jP03ojNnj_nX_n[oZ;oZ00CoZ;oZ1_nX_^X00onW_^[oZ;oZojRojP08ojRojPSoZ<3[1OnX_n]moooo
o`03o`000?oooooo0000007ooooo001Dooooo`03o`000?oooooooooo02kooooo00?oYko[ojRojonX
_n/00onX_n/6ojJok003ojO0k?nV`>coY/3/00?oY/3/1OnW`>`2ojK0k0KoYl7/1OnX`>/00onW`Nco
Z<7[ojS1j`05ojS1j`?oZ<3Z0onX`N/6ojS0j`?oZ;oZ1?nX`>/6ojRojP?oZ;kZ0onX`>/7ojRojPco
Z<3[00?oZ;o[ooooooooool0O_ooool00ol0003oooooo`000001ooooo`00EOooool00ol0003ooooo
ooooo`0^ooooo`KoZ;o[0onV_n`4ojNoj`GoY/3/00?oYl3/ojK0k?nV`>`01?nV`>`6ojO1k003ojS0
jonW`NcoYl7/00?oYl7/1OnX`N/2ojO1k0KoZ<7[1?nX`>/2ojO1k0OoZ<3[0onX_nX2ojO1k0OoZ<3[
0onX_nX4ojO1k0WoZ<3[Q?ooool1o`00007ooooo0Ol0000005Kooooo0_l0000_ooooo`?oZ;o[0onX
`>/7ojNoj`;oY/3/1?nW_n/6ojK0k0?oYl7/1?nV`>`5ojO1k003ojS1jonW`NcoYl7/00CoYl7/1_nX
`N/00onX`>_oYl7/ojO1k003ojO1k0GoZ<3[1onW`N`5ojS0j`WoYl7/0onX`>^:ooooo`;o0000001H
ooooo`03o`000?oooooooooo02gooooo1_nX`>/5ojNoj`;oZ;oZ1_nW_n/3ojK0k0?oYko[1onV`>`2
ojO1k0CoYl3/1_nW`N`3ojS1j`WoYl7/00?oZ<3[ojO1k?nW`N`02OnW`N`00onX`>_oYl7/ojO1k009
ojO1k8gooooo0ol0000005Wooooo00?o0000ooooooooool0;Oooool6ojS0j`03ojNojonX_n[oZ;oZ
00CoZ;oZ1?nW_n/2ojRojPKoYko[1OnV`>`00onW_n_oYl3/ojO0k005ojO0k0?oYl7/1?nW`>`OojO1
k8cooooo1?l00003ooooo`00F_ooool00ol0003oooooooooo`0]ooooo`OoZ<3[1_nX_nX00onW_n_o
Z;oZojRojP03ojRojPKoYko[00?oY/3/ojNojonW_n/00onW_n/5ojO0k0;oYko[1onW`>`2ojO1k0?o
Yl3/2_nW`N`3ojO0k0WoYl7/S?ooool3o`0000Oooooo001Kooooo`03o`000?oooooooooo02gooooo
1onX`>/3ojRojP?oZ<3[1_nX_nX3ojNoj`CoZ;oZ1OnW_n/00onW`>coYko[ojNoj`04ojNoj`GoYl3/
00?oYko[ojO0k?nW`>`01?nW`>`5ojO1k003ojNojonW`>coYl3/00GoYl3/0onW`Nb=ooooo`Co0000
2_ooool005cooooo0_l0000^ooooo`GoZ<3[0_nW`>/6ojS0j`?oZ;oZ1?nX`>/6ojRojP;oYko[1?nX
_nX6ojNoj`03ojO0k?nW_n_oYko[00?oYko[1_nW`>`00onW`NcoYko[ojNoj`03ojNoj`GoYl3/SOoo
ool4o`0000kooooo001Nooooo`03o`000?oooooooooo02cooooo00?oZ<3[ojO0jonW`>/01?nW`>/4
ojS0j`;oYl3[1onX`>/3ojRojP;oZ<3[1onX_nX3ojNoj`?oZ;oZ1_nW_n/3ojO0k0CoYkoZ1OnW_n/0
0onW`>coooooooooo`2:ooooo`Co00004_ooool005oooooo00?o0000ooooooooool0;Oooool6ojO0
j`03ojS0jonW`>_oYl3[00?oYl3[1OnX`>/2ojO0j`GoZ<3[1OnX_nX2ojS0j`KoZ;oZ0onW_n/3ojRo
jPOoYkoZ0_nW_n^;ooooo`Co00005_ooool0063ooooo00?o0000ooooooooool0;Oooool3ojO0j`Co
Yl3/1OnW`>/00onX`>_oYl3[ojO0j`04ojO0j`GoZ<3[00?oZ;oZojS0jonX`>/01?nX`>/4ojRojP;o
Z<3[1_nX_nX5ojNojX_ooooo0ol0000Jooooo`00HOooool2o`0002oooooo1_nW`>`2ojO0j`CoYl7/
1_nW`>/2ojS0j`CoYl3[1_nX`>/00onX_n[oZ<3[ojS0j`03ojS0j`KoZ;oZ00?oYkoZooooooooool0
R?ooool4o`0001gooooo001Sooooo`03o`000?oooooooooo02gooooo1OnW`>`7ojO1k0?oYl3[0onW
`N`6ojO0j`?oZ<3[0onW`>/6ojS0j`?oZ;oZROooool4o`00027ooooo001Tooooo`03o`000?oooooo
oooo02gooooo1OnW`>`5ojO1k0;oYl3/1_nW`N`3ojO0j`CoYl7/1OnW`>/3ojS0jh[ooooo1?l0000U
ooooo`00IOooool00ol0003oooooooooo`0]ooooo`GoYl3/00?oYl7/ojO0k?nW`>`01?nW`>`4ojO1
k0;oYl3/1onW`N`2ojO0jh_ooooo1?l0000Yooooo`00I_ooool2o`0002kooooo0_nW`>`4ojNoj`Ko
Yl3/00?oYl7/ojO0k?nW`>`00onW`>`5ojO1k8_ooooo0ol0000]ooooo`00J?ooool00ol0003ooooo
ooooo`0/ooooo`KoYko[0onW`>`3ojNoj`KoYl3/00?oYl7/ooooooooool0R?ooool4o`00033ooooo
001Yooooo`03o`000?oooooooooo02cooooo0onW_n/4ojRoj`GoYko[0onW`>b9ooooo`Co0000=?oo
ool006[ooooo00?o0000ooooooooool0;?ooool7ojRoj`;oYko[R_ooool4o`0003Sooooo001[oooo
o`;o0000;Oooool5ojRojhWooooo1?l0000looooo`00KOooool00ol0003oooooooooo`0[ooooo`03
ojRojooooooooooo08Oooooo0ol00010ooooo`00K_ooool00ol0003oooooooooo`0Zooooo`03o`00
0?oooooooooo08?ooooo1?l00013ooooo`00Koooool00ol0003oooooooooo`0Yooooo`03o`000?oo
oooooooo07oooooo1?l00017ooooo`00L?ooool2o`0002Wooooo00?o0000ooooooooool0Noooool4
o`0004_ooooo001booooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0Moooool4o`00
04oooooo001cooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0M?ooool3o`0005?o
oooo001dooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0L?ooool4o`0005Kooooo
001eooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0K?ooool4o`0005[ooooo001f
ooooo`;o00008oooool00ol0003oooooooooo`1Xooooo`Co0000G_ooool007Sooooo00?o0000oooo
ooooool08?ooool00ol0003oooooooooo`1Tooooo`Co0000H_ooool007Wooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`1Qooooo`?o0000I_ooool007[ooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`1Mooooo`Co0000JOooool007_ooooo0_l0000Nooooo`03o`000?oo
oooooooo05Wooooo1?l0001]ooooo`00OOooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo05Gooooo1?l0001aooooo`00O_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
057ooooo1?l0001eooooo`00Ooooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04ko
oooo0ol0001iooooo`00P?ooool2o`0001Wooooo00?o0000ooooooooool0B_ooool4o`0007cooooo
0022ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0A_ooool4o`00083ooooo0023
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0@_ooool4o`0008Cooooo0024oooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0?_ooool4o`0008Sooooo0025ooooo`;o
00004oooool00ol0003oooooooooo`0looooo`?o0000S?ooool008Oooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0hooooo`Co0000Soooool008Sooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0dooooo`Co0000Toooool008Wooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0`ooooo`Co0000Uoooool008[ooooo0_l0000>ooooo`03o`000?oooooooooo
02cooooo1?l0002Kooooo`00S?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Wo
oooo0ol0002Oooooo`00SOooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Gooooo
1?l0002Rooooo`00S_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo027ooooo1?l0
002Vooooo`00Soooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01gooooo1?l0002Z
ooooo`00T?ooool2o`0000Sooooo00?o0000ooooooooool06Oooool4o`000:kooooo002Booooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool05_ooool3o`000;;ooooo002Cooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool04_ooool4o`000;Gooooo002Dooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool03_ooool4o`000;Wooooo002Eooooo`;o00000oooool0
0ol0003oooooooooo`0:ooooo`Co0000_Oooool009Oooooo00Co0000oooooooooooo00002?ooool4
o`000<7ooooo002Hooooo`03o`000?oooooo000000Gooooo0ol00035ooooo`00VOooool2o`000003
ooooool0003o000000;o0000b?ooool009[ooooo0_l0003<ooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0538698, 0.0432538, \
0.0035044, 0.0035044}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[.12586 .2075 -12 -8.99448 ]
[.12586 .2075 0 .00552 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.56094 .0364 -5.16972 -9 ]
[.56094 .0364 .83028 0 ]
[.75679 .08071 0 -6.17777 ]
[.75679 .08071 12 2.82223 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.9429 .3657 0 -5.9083 ]
[.9429 .3657 6 3.0917 ]
[.02494 .25992 -18 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.01611 .31527 -18 -2.78472 ]
[.01611 .31527 0 6.21528 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00254 .43215 -12 -2.88407 ]
[-0.00254 .43215 0 6.11593 ]
[-0.0124 .49393 -12 -2.93688 ]
[-0.0124 .49393 0 6.06312 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
[(-2)] .12586 .2075 1 .99877 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.56863 .04703 m
.57247 .05235 L
s
[(2)] .56094 .0364 .72324 1 Mshowa
.125 Mabswid
.18558 .19702 m
.18832 .19985 L
s
.23703 .17687 m
.23971 .17975 L
s
.28951 .15632 m
.29214 .15925 L
s
.39772 .11395 m
.40023 .11699 L
s
.4535 .09211 m
.45595 .0952 L
s
.51046 .06981 m
.51284 .07294 L
s
.08568 .23614 m
.08851 .23887 L
s
.62804 .02377 m
.63027 .02701 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.7445 .0853 m
.73835 .08759 L
s
[(-2)] .75679 .08071 -1 .37284 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.93037 .36962 m
.92411 .37158 L
s
[(2)] .9429 .3657 -1 .31296 Mshowa
.125 Mabswid
.7708 .12553 m
.7671 .12688 L
s
.79613 .16428 m
.79242 .1656 L
s
.82054 .20161 m
.81682 .20291 L
s
.86679 .27235 m
.86305 .2736 L
s
.88871 .30589 m
.88497 .30711 L
s
.9099 .3383 m
.90615 .3395 L
s
.71716 .04348 m
.71349 .04489 L
s
.95018 .39992 m
.94642 .40107 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(-20)] .02494 .25992 1 -0.39157 Mshowa
.02837 .31059 m
.0345 .30825 L
s
[(-10)] .01611 .31527 1 -0.38117 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.00981 .42772 m
.01599 .4255 L
s
[(10)] -0.00254 .43215 1 -0.3591 Mshowa
0 .48963 m
.0062 .48748 L
s
[(20)] -0.0124 .49393 1 -0.34736 Mshowa
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.657 .75 .918 r
.39362 .69477 .40169 .70188 .4152 .69801 .40717 .69088 Mtetra
.654 .75 .92 r
.40717 .69088 .4152 .69801 .42878 .69413 .42079 .68707 Mtetra
.653 .752 .922 r
.42079 .68707 .42878 .69413 .44242 .69033 .43448 .68328 Mtetra
.655 .754 .922 r
.43448 .68328 .44242 .69033 .45614 .68655 .44824 .67939 Mtetra
.657 .752 .92 r
.44824 .67939 .45614 .68655 .46992 .68269 .46207 .67543 Mtetra
.658 .751 .919 r
.46207 .67543 .46992 .68269 .48378 .67877 .47597 .67141 Mtetra
.658 .749 .918 r
.47597 .67141 .48378 .67877 .4977 .67478 .48994 .66738 Mtetra
.655 .748 .918 r
.48994 .66738 .4977 .67478 .5117 .67076 .50398 .66341 Mtetra
.653 .75 .921 r
.50398 .66341 .5117 .67076 .52577 .66675 .5181 .65949 Mtetra
.653 .754 .924 r
.5181 .65949 .52577 .66675 .53991 .66281 .53229 .65554 Mtetra
.655 .755 .924 r
.53229 .65554 .53991 .66281 .55412 .65887 .54655 .65152 Mtetra
.656 .754 .922 r
.54655 .65152 .55412 .65887 .56841 .65491 .56088 .64746 Mtetra
.656 .753 .921 r
.56088 .64746 .56841 .65491 .58277 .65089 .5753 .64335 Mtetra
.657 .752 .92 r
.5753 .64335 .58277 .65089 .59721 .64683 .58978 .63919 Mtetra
.657 .75 .918 r
.58978 .63919 .59721 .64683 .61172 .64274 .60434 .63501 Mtetra
.657 .749 .917 r
.60434 .63501 .61172 .64274 .62631 .63862 .61898 .63081 Mtetra
.657 .748 .917 r
.61898 .63081 .62631 .63862 .64097 .63448 .63369 .6266 Mtetra
.657 .747 .916 r
.63369 .6266 .64097 .63448 .65571 .63031 .64848 .62239 Mtetra
.656 .746 .916 r
.64848 .62239 .65571 .63031 .67053 .62613 .66335 .61816 Mtetra
.66335 .61816 .67053 .62613 .68542 .62193 .6783 .61392 Mtetra
.6783 .61392 .68542 .62193 .7004 .61771 .69333 .60966 Mtetra
.69333 .60966 .7004 .61771 .71545 .61348 .70844 .6054 Mtetra
.655 .746 .917 r
.70844 .6054 .71545 .61348 .73059 .60922 .72363 .60112 Mtetra
.655 .747 .917 r
.72363 .60112 .73059 .60922 .7458 .60494 .73891 .59683 Mtetra
.655 .748 .918 r
.73891 .59683 .7458 .60494 .7611 .60063 .75426 .59253 Mtetra
.655 .749 .919 r
.75426 .59253 .7611 .60063 .77648 .59628 .7697 .5882 Mtetra
.655 .751 .92 r
.7697 .5882 .77648 .59628 .79194 .59189 .78522 .58382 Mtetra
.656 .752 .921 r
.78522 .58382 .79194 .59189 .80748 .58744 .80083 .57939 Mtetra
.656 .754 .922 r
.80083 .57939 .80748 .58744 .8231 .58297 .81652 .57492 Mtetra
.657 .756 .923 r
.81652 .57492 .8231 .58297 .83881 .57849 .83228 .57037 Mtetra
.658 .755 .922 r
.83228 .57037 .83881 .57849 .85461 .57408 .84813 .56578 Mtetra
.656 .751 .92 r
.84813 .56578 .85461 .57408 .8705 .56968 .86408 .56124 Mtetra
.654 .748 .919 r
.86408 .56124 .8705 .56968 .88648 .56523 .88012 .55676 Mtetra
.88012 .55676 .88648 .56523 .90254 .56073 .89625 .55227 Mtetra
.655 .75 .92 r
.89625 .55227 .90254 .56073 .91868 .55615 .91247 .5477 Mtetra
.656 .752 .921 r
.91247 .5477 .91868 .55615 .93491 .55148 .92877 .54307 Mtetra
.658 .755 .922 r
.92877 .54307 .93491 .55148 .95123 .54683 .94515 .53832 Mtetra
.657 .753 .921 r
.94515 .53832 .95123 .54683 .96765 .54225 .96163 .53359 Mtetra
.655 .75 .92 r
.96163 .53359 .96765 .54225 .98417 .53766 .97821 .52894 Mtetra
.654 .75 .92 r
.38547 .68761 .39362 .69477 .40717 .69088 .39906 .68379 Mtetra
.653 .752 .923 r
.39906 .68379 .40717 .69088 .42079 .68707 .41272 .67998 Mtetra
.655 .754 .922 r
.41272 .67998 .42079 .68707 .43448 .68328 .42646 .67607 Mtetra
.657 .752 .92 r
.42646 .67607 .43448 .68328 .44824 .67939 .44026 .67208 Mtetra
.658 .751 .918 r
.44026 .67208 .44824 .67939 .46207 .67543 .45414 .66803 Mtetra
.658 .749 .917 r
.45414 .66803 .46207 .67543 .47597 .67141 .46809 .66399 Mtetra
.654 .749 .919 r
.46809 .66399 .47597 .67141 .48994 .66738 .4821 .66007 Mtetra
.653 .752 .923 r
.4821 .66007 .48994 .66738 .50398 .66341 .49619 .65614 Mtetra
.654 .755 .924 r
.49619 .65614 .50398 .66341 .5181 .65949 .51035 .65214 Mtetra
.656 .754 .922 r
.51035 .65214 .5181 .65949 .53229 .65554 .52459 .64808 Mtetra
.657 .752 .92 r
.52459 .64808 .53229 .65554 .54655 .65152 .5389 .64396 Mtetra
.658 .751 .919 r
.5389 .64396 .54655 .65152 .56088 .64746 .55328 .63977 Mtetra
.658 .749 .917 r
.55328 .63977 .56088 .64746 .5753 .64335 .56774 .63557 Mtetra
.658 .747 .916 r
.56774 .63557 .5753 .64335 .58978 .63919 .58228 .63136 Mtetra
.656 .747 .916 r
.58228 .63136 .58978 .63919 .60434 .63501 .59689 .62719 Mtetra
.655 .748 .918 r
.59689 .62719 .60434 .63501 .61898 .63081 .61158 .62303 Mtetra
.655 .75 .92 r
.61158 .62303 .61898 .63081 .63369 .6266 .62635 .61885 Mtetra
.655 .751 .921 r
.62635 .61885 .63369 .6266 .64848 .62239 .64119 .61463 Mtetra
.655 .753 .921 r
.64119 .61463 .64848 .62239 .66335 .61816 .65612 .61039 Mtetra
.656 .753 .922 r
.65612 .61039 .66335 .61816 .6783 .61392 .67112 .6061 Mtetra
.67112 .6061 .6783 .61392 .69333 .60966 .68621 .60179 Mtetra
.656 .753 .921 r
.68621 .60179 .69333 .60966 .70844 .6054 .70137 .59743 Mtetra
.657 .752 .92 r
.70137 .59743 .70844 .6054 .72363 .60112 .71661 .59305 Mtetra
.657 .75 .919 r
.71661 .59305 .72363 .60112 .73891 .59683 .73194 .58864 Mtetra
.656 .748 .918 r
.73194 .58864 .73891 .59683 .75426 .59253 .74735 .58424 Mtetra
.655 .746 .917 r
.74735 .58424 .75426 .59253 .7697 .5882 .76285 .57987 Mtetra
.654 .746 .917 r
.76285 .57987 .7697 .5882 .78522 .58382 .77843 .57551 Mtetra
.654 .747 .919 r
.77843 .57551 .78522 .58382 .80083 .57939 .7941 .57112 Mtetra
.655 .75 .92 r
.7941 .57112 .80083 .57939 .81652 .57492 .80985 .56666 Mtetra
.656 .752 .921 r
.80985 .56666 .81652 .57492 .83228 .57037 .82569 .56214 Mtetra
.657 .754 .922 r
.82569 .56214 .83228 .57037 .84813 .56578 .84161 .55755 Mtetra
.658 .756 .922 r
.84161 .55755 .84813 .56578 .86408 .56124 .85761 .55289 Mtetra
.658 .754 .921 r
.85761 .55289 .86408 .56124 .88012 .55676 .8737 .54821 Mtetra
.654 .749 .919 r
.8737 .54821 .88012 .55676 .89625 .55227 .88989 .54365 Mtetra
.654 .748 .919 r
.88989 .54365 .89625 .55227 .91247 .5477 .90618 .5391 Mtetra
.655 .75 .92 r
.90618 .5391 .91247 .5477 .92877 .54307 .92255 .53447 Mtetra
.656 .752 .92 r
.92255 .53447 .92877 .54307 .94515 .53832 .93901 .52977 Mtetra
.658 .755 .921 r
.93901 .52977 .94515 .53832 .96163 .53359 .95555 .52494 Mtetra
.657 .753 .921 r
.95555 .52494 .96163 .53359 .97821 .52894 .97219 .52014 Mtetra
.653 .752 .922 r
.37724 .68048 .38547 .68761 .39906 .68379 .39088 .67666 Mtetra
.655 .754 .922 r
.39088 .67666 .39906 .68379 .41272 .67998 .40459 .67273 Mtetra
.657 .752 .92 r
.40459 .67273 .41272 .67998 .42646 .67607 .41836 .66873 Mtetra
.659 .751 .918 r
.41836 .66873 .42646 .67607 .44026 .67208 .43222 .66465 Mtetra
.657 .749 .918 r
.43222 .66465 .44026 .67208 .45414 .66803 .44614 .66062 Mtetra
.653 .749 .92 r
.44614 .66062 .45414 .66803 .46809 .66399 .46012 .6567 Mtetra
.653 .754 .924 r
.46012 .6567 .46809 .66399 .4821 .66007 .47419 .65275 Mtetra
.655 .754 .923 r
.47419 .65275 .4821 .66007 .49619 .65614 .48832 .64871 Mtetra
.656 .753 .921 r
.48832 .64871 .49619 .65614 .51035 .65214 .50253 .64461 Mtetra
.659 .752 .919 r
.50253 .64461 .51035 .65214 .52459 .64808 .51682 .6404 Mtetra
.659 .749 .917 r
.51682 .6404 .52459 .64808 .5389 .64396 .53118 .63618 Mtetra
.657 .747 .916 r
.53118 .63618 .5389 .64396 .55328 .63977 .54561 .632 Mtetra
.654 .747 .918 r
.54561 .632 .55328 .63977 .56774 .63557 .56012 .62789 Mtetra
.654 .751 .921 r
.56012 .62789 .56774 .63557 .58228 .63136 .57471 .62377 Mtetra
.654 .754 .923 r
.57471 .62377 .58228 .63136 .59689 .62719 .58937 .61963 Mtetra
.654 .756 .925 r
.58937 .61963 .59689 .62719 .61158 .62303 .60412 .61544 Mtetra
.655 .757 .925 r
.60412 .61544 .61158 .62303 .62635 .61885 .61894 .61121 Mtetra
.655 .756 .924 r
.61894 .61121 .62635 .61885 .64119 .61463 .63384 .60694 Mtetra
.63384 .60694 .64119 .61463 .65612 .61039 .64882 .60265 Mtetra
.64882 .60265 .65612 .61039 .67112 .6061 .66388 .59832 Mtetra
.66388 .59832 .67112 .6061 .68621 .60179 .67902 .59397 Mtetra
.656 .756 .924 r
.67902 .59397 .68621 .60179 .70137 .59743 .69424 .58958 Mtetra
.656 .757 .924 r
.69424 .58958 .70137 .59743 .71661 .59305 .70954 .58516 Mtetra
.657 .757 .924 r
.70954 .58516 .71661 .59305 .73194 .58864 .72492 .5807 Mtetra
.72492 .5807 .73194 .58864 .74735 .58424 .74039 .57619 Mtetra
.657 .755 .922 r
.74039 .57619 .74735 .58424 .76285 .57987 .75594 .57165 Mtetra
.657 .752 .92 r
.75594 .57165 .76285 .57987 .77843 .57551 .77157 .56709 Mtetra
.655 .747 .918 r
.77157 .56709 .77843 .57551 .7941 .57112 .7873 .56262 Mtetra
.654 .746 .917 r
.7873 .56262 .7941 .57112 .80985 .56666 .80311 .55817 Mtetra
.653 .747 .919 r
.80311 .55817 .80985 .56666 .82569 .56214 .81902 .55371 Mtetra
.655 .751 .92 r
.81902 .55371 .82569 .56214 .84161 .55755 .83501 .54915 Mtetra
.656 .753 .921 r
.83501 .54915 .84161 .55755 .85761 .55289 .85108 .54451 Mtetra
.658 .756 .922 r
.85108 .54451 .85761 .55289 .8737 .54821 .86723 .53977 Mtetra
.658 .755 .922 r
.86723 .53977 .8737 .54821 .88989 .54365 .88347 .535 Mtetra
.655 .75 .92 r
.88347 .535 .88989 .54365 .90618 .5391 .89982 .53035 Mtetra
.653 .748 .919 r
.89982 .53035 .90618 .5391 .92255 .53447 .91627 .52573 Mtetra
.655 .75 .92 r
.91627 .52573 .92255 .53447 .93901 .52977 .9328 .52103 Mtetra
.656 .752 .92 r
.9328 .52103 .93901 .52977 .95555 .52494 .94942 .51625 Mtetra
.658 .755 .921 r
.94942 .51625 .95555 .52494 .97219 .52014 .96612 .51134 Mtetra
.655 .753 .922 r
.36894 .67332 .37724 .68048 .39088 .67666 .38262 .66939 Mtetra
.657 .752 .92 r
.38262 .66939 .39088 .67666 .40459 .67273 .39637 .66537 Mtetra
.659 .751 .918 r
.39637 .66537 .40459 .67273 .41836 .66873 .4102 .66127 Mtetra
.657 .749 .918 r
.4102 .66127 .41836 .66873 .43222 .66465 .42409 .65723 Mtetra
.653 .75 .921 r
.42409 .65723 .43222 .66465 .44614 .66062 .43805 .6533 Mtetra
.653 .754 .924 r
.43805 .6533 .44614 .66062 .46012 .6567 .45209 .64933 Mtetra
.655 .754 .922 r
.45209 .64933 .46012 .6567 .47419 .65275 .4662 .64526 Mtetra
.658 .752 .92 r
.4662 .64526 .47419 .65275 .48832 .64871 .48038 .64109 Mtetra
.659 .751 .918 r
.48038 .64109 .48832 .64871 .50253 .64461 .49464 .63685 Mtetra
.658 .748 .916 r
.49464 .63685 .50253 .64461 .51682 .6404 .50897 .63263 Mtetra
.654 .747 .918 r
.50897 .63263 .51682 .6404 .53118 .63618 .52338 .62854 Mtetra
.653 .751 .922 r
.52338 .62854 .53118 .63618 .54561 .632 .53787 .62446 Mtetra
.653 .755 .925 r
.53787 .62446 .54561 .632 .56012 .62789 .55243 .62033 Mtetra
.654 .756 .925 r
.55243 .62033 .56012 .62789 .57471 .62377 .56707 .61614 Mtetra
.655 .755 .924 r
.56707 .61614 .57471 .62377 .58937 .61963 .58178 .6119 Mtetra
.656 .754 .923 r
.58178 .6119 .58937 .61963 .60412 .61544 .59658 .60763 Mtetra
.656 .753 .921 r
.59658 .60763 .60412 .61544 .61894 .61121 .61145 .60332 Mtetra
.656 .752 .921 r
.61145 .60332 .61894 .61121 .63384 .60694 .6264 .59898 Mtetra
.656 .752 .92 r
.6264 .59898 .63384 .60694 .64882 .60265 .64143 .59462 Mtetra
.656 .751 .92 r
.64143 .59462 .64882 .60265 .66388 .59832 .65655 .59025 Mtetra
.655 .751 .92 r
.65655 .59025 .66388 .59832 .67902 .59397 .67174 .58588 Mtetra
.67174 .58588 .67902 .59397 .69424 .58958 .68702 .58148 Mtetra
.655 .752 .921 r
.68702 .58148 .69424 .58958 .70954 .58516 .70238 .57705 Mtetra
.656 .753 .922 r
.70238 .57705 .70954 .58516 .72492 .5807 .71783 .57259 Mtetra
.656 .754 .922 r
.71783 .57259 .72492 .5807 .74039 .57619 .73336 .56808 Mtetra
.656 .756 .923 r
.73336 .56808 .74039 .57619 .75594 .57165 .74897 .56353 Mtetra
.658 .757 .923 r
.74897 .56353 .75594 .57165 .77157 .56709 .76466 .55891 Mtetra
.76466 .55891 .77157 .56709 .7873 .56262 .78044 .55425 Mtetra
.658 .753 .92 r
.78044 .55425 .7873 .56262 .80311 .55817 .7963 .54958 Mtetra
.654 .747 .918 r
.7963 .54958 .80311 .55817 .81902 .55371 .81227 .54504 Mtetra
.653 .746 .918 r
.81227 .54504 .81902 .55371 .83501 .54915 .82833 .54053 Mtetra
.654 .749 .919 r
.82833 .54053 .83501 .54915 .85108 .54451 .84447 .53594 Mtetra
.656 .752 .921 r
.84447 .53594 .85108 .54451 .86723 .53977 .8607 .53124 Mtetra
.658 .755 .922 r
.8607 .53124 .86723 .53977 .88347 .535 .87701 .52644 Mtetra
.87701 .52644 .88347 .535 .89982 .53035 .89341 .52158 Mtetra
.655 .75 .92 r
.89341 .52158 .89982 .53035 .91627 .52573 .90991 .51684 Mtetra
.653 .748 .919 r
.90991 .51684 .91627 .52573 .9328 .52103 .92652 .51215 Mtetra
.655 .75 .92 r
.92652 .51215 .9328 .52103 .94942 .51625 .94321 .50738 Mtetra
.656 .752 .92 r
.94321 .50738 .94942 .51625 .96612 .51134 .95999 .5025 Mtetra
.657 .752 .92 r
.36055 .66603 .36894 .67332 .38262 .66939 .37428 .662 Mtetra
.659 .751 .918 r
.37428 .662 .38262 .66939 .39637 .66537 .38808 .65789 Mtetra
.657 .749 .918 r
.38808 .65789 .39637 .66537 .4102 .66127 .40195 .65381 Mtetra
.653 .75 .921 r
.40195 .65381 .4102 .66127 .42409 .65723 .41588 .64987 Mtetra
.653 .754 .923 r
.41588 .64987 .42409 .65723 .43805 .6533 .42989 .64588 Mtetra
.656 .754 .922 r
.42989 .64588 .43805 .6533 .45209 .64933 .44397 .64178 Mtetra
.658 .752 .919 r
.44397 .64178 .45209 .64933 .4662 .64526 .45813 .63757 Mtetra
.66 .75 .917 r
.45813 .63757 .4662 .64526 .48038 .64109 .47237 .63331 Mtetra
.656 .747 .917 r
.47237 .63331 .48038 .64109 .49464 .63685 .48667 .62914 Mtetra
.653 .749 .921 r
.48667 .62914 .49464 .63685 .50897 .63263 .50105 .62508 Mtetra
.652 .754 .924 r
.50105 .62508 .50897 .63263 .52338 .62854 .51551 .62098 Mtetra
.654 .756 .924 r
.51551 .62098 .52338 .62854 .53787 .62446 .53004 .6168 Mtetra
.655 .755 .923 r
.53004 .6168 .53787 .62446 .55243 .62033 .54466 .61256 Mtetra
.657 .753 .921 r
.54466 .61256 .55243 .62033 .56707 .61614 .55934 .60824 Mtetra
.659 .752 .919 r
.55934 .60824 .56707 .61614 .58178 .6119 .57411 .60384 Mtetra
.659 .748 .916 r
.57411 .60384 .58178 .6119 .59658 .60763 .58895 .59943 Mtetra
.658 .746 .915 r
.58895 .59943 .59658 .60763 .61145 .60332 .60388 .59503 Mtetra
.657 .744 .914 r
.60388 .59503 .61145 .60332 .6264 .59898 .61888 .59062 Mtetra
.61888 .59062 .6264 .59898 .64143 .59462 .63397 .58622 Mtetra
.656 .743 .914 r
.63397 .58622 .64143 .59462 .65655 .59025 .64914 .58181 Mtetra
.64914 .58181 .65655 .59025 .67174 .58588 .66439 .57739 Mtetra
.655 .743 .914 r
.66439 .57739 .67174 .58588 .68702 .58148 .67972 .57297 Mtetra
.655 .743 .915 r
.67972 .57297 .68702 .58148 .70238 .57705 .69514 .56855 Mtetra
.654 .744 .916 r
.69514 .56855 .70238 .57705 .71783 .57259 .71065 .56413 Mtetra
.653 .747 .918 r
.71065 .56413 .71783 .57259 .73336 .56808 .72624 .55971 Mtetra
.655 .75 .92 r
.72624 .55971 .73336 .56808 .74897 .56353 .74192 .55519 Mtetra
.656 .753 .921 r
.74192 .55519 .74897 .56353 .76466 .55891 .75768 .5506 Mtetra
.657 .755 .922 r
.75768 .5506 .76466 .55891 .78044 .55425 .77352 .54594 Mtetra
.658 .757 .923 r
.77352 .54594 .78044 .55425 .7963 .54958 .78945 .5412 Mtetra
.659 .756 .922 r
.78945 .5412 .7963 .54958 .81227 .54504 .80546 .53642 Mtetra
.656 .75 .919 r
.80546 .53642 .81227 .54504 .82833 .54053 .82157 .53173 Mtetra
.653 .746 .918 r
.82157 .53173 .82833 .54053 .84447 .53594 .83778 .52716 Mtetra
.654 .748 .919 r
.83778 .52716 .84447 .53594 .8607 .53124 .85409 .52251 Mtetra
.656 .751 .92 r
.85409 .52251 .8607 .53124 .87701 .52644 .87047 .51775 Mtetra
.658 .755 .921 r
.87047 .51775 .87701 .52644 .89341 .52158 .88694 .51287 Mtetra
.659 .755 .922 r
.88694 .51287 .89341 .52158 .90991 .51684 .90349 .50793 Mtetra
.655 .75 .92 r
.90349 .50793 .90991 .51684 .92652 .51215 .92016 .50313 Mtetra
.653 .748 .919 r
.92016 .50313 .92652 .51215 .94321 .50738 .93694 .49836 Mtetra
.655 .75 .92 r
.93694 .49836 .94321 .50738 .95999 .5025 .95379 .4935 Mtetra
.659 .752 .919 r
.35209 .65862 .36055 .66603 .37428 .662 .36587 .6545 Mtetra
.658 .75 .918 r
.36587 .6545 .37428 .662 .38808 .65789 .37971 .65037 Mtetra
.653 .749 .92 r
.37971 .65037 .38808 .65789 .40195 .65381 .39361 .64641 Mtetra
.653 .753 .923 r
.39361 .64641 .40195 .65381 .41588 .64987 .40759 .64241 Mtetra
.656 .754 .922 r
.40759 .64241 .41588 .64987 .42989 .64588 .42165 .6383 Mtetra
.659 .752 .919 r
.42165 .6383 .42989 .64588 .44397 .64178 .43578 .63406 Mtetra
.66 .75 .917 r
.43578 .63406 .44397 .64178 .45813 .63757 .44999 .62977 Mtetra
.655 .747 .918 r
.44999 .62977 .45813 .63757 .47237 .63331 .46427 .62564 Mtetra
.652 .751 .922 r
.46427 .62564 .47237 .63331 .48667 .62914 .47862 .62157 Mtetra
.653 .755 .925 r
.47862 .62157 .48667 .62914 .50105 .62508 .49305 .61744 Mtetra
.655 .755 .923 r
.49305 .61744 .50105 .62508 .51551 .62098 .50756 .61322 Mtetra
.658 .753 .921 r
.50756 .61322 .51551 .62098 .53004 .6168 .52214 .60888 Mtetra
.66 .751 .918 r
.52214 .60888 .53004 .6168 .54466 .61256 .53681 .60443 Mtetra
.66 .747 .915 r
.53681 .60443 .54466 .61256 .55934 .60824 .55154 .59999 Mtetra
.658 .744 .914 r
.55154 .59999 .55934 .60824 .57411 .60384 .56636 .59561 Mtetra
.655 .745 .916 r
.56636 .59561 .57411 .60384 .58895 .59943 .58126 .5913 Mtetra
.654 .748 .919 r
.58126 .5913 .58895 .59943 .60388 .59503 .59624 .58698 Mtetra
.654 .752 .921 r
.59624 .58698 .60388 .59503 .61888 .59062 .6113 .58262 Mtetra
.655 .754 .923 r
.6113 .58262 .61888 .59062 .63397 .58622 .62644 .57821 Mtetra
.655 .755 .923 r
.62644 .57821 .63397 .58622 .64914 .58181 .64167 .57375 Mtetra
.656 .756 .923 r
.64167 .57375 .64914 .58181 .66439 .57739 .65698 .56925 Mtetra
.657 .755 .922 r
.65698 .56925 .66439 .57739 .67972 .57297 .67236 .5647 Mtetra
.657 .753 .92 r
.67236 .5647 .67972 .57297 .69514 .56855 .68784 .56011 Mtetra
.657 .749 .918 r
.68784 .56011 .69514 .56855 .71065 .56413 .70339 .55549 Mtetra
.655 .745 .916 r
.70339 .55549 .71065 .56413 .72624 .55971 .71904 .55096 Mtetra
.653 .743 .915 r
.71904 .55096 .72624 .55971 .74192 .55519 .73478 .54649 Mtetra
.652 .744 .917 r
.73478 .54649 .74192 .55519 .75768 .5506 .75061 .54202 Mtetra
.654 .749 .92 r
.75061 .54202 .75768 .5506 .77352 .54594 .76652 .53743 Mtetra
.656 .753 .921 r
.76652 .53743 .77352 .54594 .78945 .5412 .78252 .53272 Mtetra
.658 .756 .922 r
.78252 .53272 .78945 .5412 .80546 .53642 .7986 .52792 Mtetra
.659 .757 .922 r
.7986 .52792 .80546 .53642 .82157 .53173 .81476 .52304 Mtetra
.657 .753 .92 r
.81476 .52304 .82157 .53173 .83778 .52716 .83102 .51824 Mtetra
.653 .746 .918 r
.83102 .51824 .83778 .52716 .85409 .52251 .84739 .51359 Mtetra
.653 .748 .919 r
.84739 .51359 .85409 .52251 .87047 .51775 .86386 .50888 Mtetra
.656 .751 .92 r
.86386 .50888 .87047 .51775 .88694 .51287 .8804 .50404 Mtetra
.658 .755 .921 r
.8804 .50404 .88694 .51287 .90349 .50793 .89703 .49906 Mtetra
.89703 .49906 .90349 .50793 .92016 .50313 .91375 .49405 Mtetra
.654 .749 .92 r
.91375 .49405 .92016 .50313 .93694 .49836 .93059 .48921 Mtetra
.654 .748 .919 r
.93059 .48921 .93694 .49836 .95379 .4935 .94752 .48436 Mtetra
.659 .751 .918 r
.34355 .65111 .35209 .65862 .36587 .6545 .35737 .64694 Mtetra
.654 .749 .92 r
.35737 .64694 .36587 .6545 .37971 .65037 .37125 .64291 Mtetra
.652 .752 .923 r
.37125 .64291 .37971 .65037 .39361 .64641 .3852 .63893 Mtetra
.655 .754 .922 r
.3852 .63893 .39361 .64641 .40759 .64241 .39923 .63481 Mtetra
.659 .752 .919 r
.39923 .63481 .40759 .64241 .42165 .6383 .41334 .63056 Mtetra
.66 .75 .917 r
.41334 .63056 .42165 .6383 .43578 .63406 .42752 .62623 Mtetra
.654 .748 .918 r
.42752 .62623 .43578 .63406 .44999 .62977 .44177 .62209 Mtetra
.651 .752 .923 r
.44177 .62209 .44999 .62977 .46427 .62564 .45609 .61803 Mtetra
.653 .755 .924 r
.45609 .61803 .46427 .62564 .47862 .62157 .47049 .61386 Mtetra
.656 .754 .922 r
.47049 .61386 .47862 .62157 .49305 .61744 .48497 .6096 Mtetra
.66 .753 .919 r
.48497 .6096 .49305 .61744 .50756 .61322 .49953 .60514 Mtetra
.661 .748 .915 r
.49953 .60514 .50756 .61322 .52214 .60888 .51417 .60066 Mtetra
.657 .745 .915 r
.51417 .60066 .52214 .60888 .53681 .60443 .52888 .5963 Mtetra
.653 .747 .919 r
.52888 .5963 .53681 .60443 .55154 .59999 .54367 .59206 Mtetra
.652 .753 .923 r
.54367 .59206 .55154 .59999 .56636 .59561 .55854 .5878 Mtetra
.652 .757 .926 r
.55854 .5878 .56636 .59561 .58126 .5913 .5735 .5835 Mtetra
.654 .759 .927 r
.5735 .5835 .58126 .5913 .59624 .58698 .58853 .57911 Mtetra
.655 .758 .926 r
.58853 .57911 .59624 .58698 .6113 .58262 .60365 .57468 Mtetra
.655 .758 .925 r
.60365 .57468 .6113 .58262 .62644 .57821 .61885 .57021 Mtetra
.61885 .57021 .62644 .57821 .64167 .57375 .63413 .56571 Mtetra
.656 .758 .925 r
.63413 .56571 .64167 .57375 .65698 .56925 .64949 .56118 Mtetra
.64949 .56118 .65698 .56925 .67236 .5647 .66494 .55661 Mtetra
.656 .759 .926 r
.66494 .55661 .67236 .5647 .68784 .56011 .68047 .55199 Mtetra
.658 .76 .925 r
.68047 .55199 .68784 .56011 .70339 .55549 .69609 .54729 Mtetra
.659 .759 .924 r
.69609 .54729 .70339 .55549 .71904 .55096 .71179 .54253 Mtetra
.659 .755 .921 r
.71179 .54253 .71904 .55096 .73478 .54649 .72757 .53776 Mtetra
.655 .747 .918 r
.72757 .53776 .73478 .54649 .75061 .54202 .74346 .53311 Mtetra
.652 .743 .916 r
.74346 .53311 .75061 .54202 .76652 .53743 .75944 .52858 Mtetra
.652 .745 .918 r
.75944 .52858 .76652 .53743 .78252 .53272 .77551 .52402 Mtetra
.656 .752 .921 r
.77551 .52402 .78252 .53272 .7986 .52792 .79166 .51927 Mtetra
.658 .755 .922 r
.79166 .51927 .7986 .52792 .81476 .52304 .80789 .5144 Mtetra
.659 .757 .922 r
.80789 .5144 .81476 .52304 .83102 .51824 .82421 .50943 Mtetra
.657 .753 .921 r
.82421 .50943 .83102 .51824 .84739 .51359 .84063 .50454 Mtetra
.652 .747 .919 r
.84063 .50454 .84739 .51359 .86386 .50888 .85716 .49982 Mtetra
.653 .748 .919 r
.85716 .49982 .86386 .50888 .8804 .50404 .87379 .49503 Mtetra
.656 .752 .92 r
.87379 .49503 .8804 .50404 .89703 .49906 .89049 .4901 Mtetra
.659 .755 .921 r
.89049 .4901 .89703 .49906 .91375 .49405 .90728 .48502 Mtetra
.657 .754 .921 r
.90728 .48502 .91375 .49405 .93059 .48921 .92417 .47997 Mtetra
.653 .749 .92 r
.92417 .47997 .93059 .48921 .94752 .48436 .94118 .47508 Mtetra
.656 .75 .919 r
.33493 .64351 .34355 .65111 .35737 .64694 .34879 .63939 Mtetra
.652 .751 .922 r
.34879 .63939 .35737 .64694 .37125 .64291 .36271 .6354 Mtetra
.654 .753 .923 r
.36271 .6354 .37125 .64291 .3852 .63893 .37671 .6313 Mtetra
.658 .752 .92 r
.37671 .6313 .3852 .63893 .39923 .63481 .39079 .62706 Mtetra
.66 .751 .917 r
.39079 .62706 .39923 .63481 .41334 .63056 .40494 .6227 Mtetra
.655 .748 .918 r
.40494 .6227 .41334 .63056 .42752 .62623 .41916 .61851 Mtetra
.651 .751 .923 r
.41916 .61851 .42752 .62623 .44177 .62209 .43346 .61444 Mtetra
.653 .755 .924 r
.43346 .61444 .44177 .62209 .45609 .61803 .44783 .61026 Mtetra
.656 .754 .922 r
.44783 .61026 .45609 .61803 .47049 .61386 .46229 .60595 Mtetra
.662 .753 .918 r
.46229 .60595 .47049 .61386 .48497 .6096 .47682 .60143 Mtetra
.661 .747 .914 r
.47682 .60143 .48497 .6096 .49953 .60514 .49143 .59693 Mtetra
.653 .745 .917 r
.49143 .59693 .49953 .60514 .51417 .60066 .50611 .59271 Mtetra
.651 .752 .923 r
.50611 .59271 .51417 .60066 .52888 .5963 .52087 .58851 Mtetra
.652 .757 .927 r
.52087 .58851 .52888 .5963 .54367 .59206 .53572 .58422 Mtetra
.654 .758 .926 r
.53572 .58422 .54367 .59206 .55854 .5878 .55065 .57985 Mtetra
.654 .756 .924 r
.55065 .57985 .55854 .5878 .5735 .5835 .56565 .57545 Mtetra
.654 .754 .923 r
.56565 .57545 .5735 .5835 .58853 .57911 .58074 .57102 Mtetra
.656 .755 .923 r
.58074 .57102 .58853 .57911 .60365 .57468 .59591 .56649 Mtetra
.656 .754 .922 r
.59591 .56649 .60365 .57468 .61885 .57021 .61117 .56194 Mtetra
.656 .753 .921 r
.61117 .56194 .61885 .57021 .63413 .56571 .6265 .55739 Mtetra
.655 .752 .922 r
.6265 .55739 .63413 .56571 .64949 .56118 .64193 .55285 Mtetra
.655 .753 .922 r
.64193 .55285 .64949 .56118 .66494 .55661 .65744 .54828 Mtetra
.657 .755 .923 r
.65744 .54828 .66494 .55661 .68047 .55199 .67303 .54362 Mtetra
.657 .755 .922 r
.67303 .54362 .68047 .55199 .69609 .54729 .68871 .53892 Mtetra
.657 .757 .923 r
.68871 .53892 .69609 .54729 .71179 .54253 .70447 .53419 Mtetra
.658 .759 .924 r
.70447 .53419 .71179 .54253 .72757 .53776 .72032 .52938 Mtetra
.66 .76 .924 r
.72032 .52938 .72757 .53776 .74346 .53311 .73625 .52448 Mtetra
.659 .754 .92 r
.73625 .52448 .74346 .53311 .75944 .52858 .75227 .51959 Mtetra
.652 .744 .917 r
.75227 .51959 .75944 .52858 .77551 .52402 .76841 .51498 Mtetra
.651 .743 .918 r
.76841 .51498 .77551 .52402 .79166 .51927 .78464 .5104 Mtetra
.655 .751 .92 r
.78464 .5104 .79166 .51927 .80789 .5144 .80095 .50559 Mtetra
.658 .754 .921 r
.80095 .50559 .80789 .5144 .82421 .50943 .81734 .50064 Mtetra
.66 .757 .922 r
.81734 .50064 .82421 .50943 .84063 .50454 .83381 .49558 Mtetra
.656 .753 .921 r
.83381 .49558 .84063 .50454 .85716 .49982 .85039 .49063 Mtetra
.652 .746 .919 r
.85039 .49063 .85716 .49982 .87379 .49503 .86709 .48586 Mtetra
.654 .749 .92 r
.86709 .48586 .87379 .49503 .89049 .4901 .88388 .48096 Mtetra
.657 .752 .92 r
.88388 .48096 .89049 .4901 .90728 .48502 .90074 .4759 Mtetra
.659 .755 .921 r
.90074 .4759 .90728 .48502 .92417 .47997 .9177 .47073 Mtetra
.655 .752 .921 r
.9177 .47073 .92417 .47997 .94118 .47508 .93477 .46568 Mtetra
.652 .749 .921 r
.32623 .63587 .33493 .64351 .34879 .63939 .34012 .63184 Mtetra
.653 .753 .923 r
.34012 .63184 .34879 .63939 .36271 .6354 .35409 .62777 Mtetra
.656 .753 .921 r
.35409 .62777 .36271 .6354 .37671 .6313 .36814 .62355 Mtetra
.661 .752 .918 r
.36814 .62355 .37671 .6313 .39079 .62706 .38227 .61917 Mtetra
.657 .749 .917 r
.38227 .61917 .39079 .62706 .40494 .6227 .39646 .6149 Mtetra
.651 .75 .922 r
.39646 .6149 .40494 .6227 .41916 .61851 .41073 .61081 Mtetra
.652 .754 .924 r
.41073 .61081 .41916 .61851 .43346 .61444 .42507 .60663 Mtetra
.656 .754 .922 r
.42507 .60663 .43346 .61444 .44783 .61026 .4395 .60231 Mtetra
.662 .753 .917 r
.4395 .60231 .44783 .61026 .46229 .60595 .454 .59774 Mtetra
.659 .746 .914 r
.454 .59774 .46229 .60595 .47682 .60143 .46858 .59327 Mtetra
.651 .746 .919 r
.46858 .59327 .47682 .60143 .49143 .59693 .48324 .58908 Mtetra
.65 .755 .926 r
.48324 .58908 .49143 .59693 .50611 .59271 .49797 .58487 Mtetra
.653 .757 .926 r
.49797 .58487 .50611 .59271 .52087 .58851 .51279 .58053 Mtetra
.653 .755 .924 r
.51279 .58053 .52087 .58851 .53572 .58422 .52769 .57616 Mtetra
.658 .755 .922 r
.52769 .57616 .53572 .58422 .55065 .57985 .54267 .57162 Mtetra
.657 .752 .92 r
.54267 .57162 .55065 .57985 .56565 .57545 .55773 .56709 Mtetra
.653 .748 .92 r
.55773 .56709 .56565 .57545 .58074 .57102 .57287 .56269 Mtetra
.651 .75 .922 r
.57287 .56269 .58074 .57102 .59591 .56649 .5881 .55832 Mtetra
.652 .755 .925 r
.5881 .55832 .59591 .56649 .61117 .56194 .60341 .55388 Mtetra
.655 .76 .927 r
.60341 .55388 .61117 .56194 .6265 .55739 .61881 .54929 Mtetra
.658 .761 .926 r
.61881 .54929 .6265 .55739 .64193 .55285 .63429 .54454 Mtetra
.66 .758 .922 r
.63429 .54454 .64193 .55285 .65744 .54828 .64985 .53972 Mtetra
.659 .752 .919 r
.64985 .53972 .65744 .54828 .67303 .54362 .6655 .53494 Mtetra
.655 .749 .919 r
.6655 .53494 .67303 .54362 .68871 .53892 .68124 .53027 Mtetra
.654 .751 .921 r
.68124 .53027 .68871 .53892 .70447 .53419 .69707 .52563 Mtetra
.657 .755 .922 r
.69707 .52563 .70447 .53419 .72032 .52938 .71298 .5208 Mtetra
.657 .756 .923 r
.71298 .5208 .72032 .52938 .73625 .52448 .72898 .51595 Mtetra
.66 .76 .924 r
.72898 .51595 .73625 .52448 .75227 .51959 .74507 .51095 Mtetra
.66 .758 .922 r
.74507 .51095 .75227 .51959 .76841 .51498 .76124 .50594 Mtetra
.653 .747 .919 r
.76124 .50594 .76841 .51498 .78464 .5104 .77752 .5012 Mtetra
.65 .743 .918 r
.77752 .5012 .78464 .5104 .80095 .50559 .79392 .49657 Mtetra
.655 .751 .92 r
.79392 .49657 .80095 .50559 .81734 .50064 .81038 .49167 Mtetra
.658 .754 .921 r
.81038 .49167 .81734 .50064 .83381 .49558 .82693 .48662 Mtetra
.66 .757 .922 r
.82693 .48662 .83381 .49558 .85039 .49063 .84357 .48148 Mtetra
.655 .751 .921 r
.84357 .48148 .85039 .49063 .86709 .48586 .86032 .47652 Mtetra
.652 .747 .919 r
.86032 .47652 .86709 .48586 .88388 .48096 .87719 .47167 Mtetra
.655 .751 .92 r
.87719 .47167 .88388 .48096 .90074 .4759 .89413 .46664 Mtetra
.658 .754 .92 r
.89413 .46664 .90074 .4759 .9177 .47073 .91116 .46145 Mtetra
.659 .755 .921 r
.91116 .46145 .9177 .47073 .93477 .46568 .92829 .45621 Mtetra
.651 .752 .923 r
.31743 .62824 .32623 .63587 .34012 .63184 .33137 .6242 Mtetra
.655 .753 .922 r
.33137 .6242 .34012 .63184 .35409 .62777 .34539 .62001 Mtetra
.659 .752 .919 r
.34539 .62001 .35409 .62777 .36814 .62355 .35948 .61566 Mtetra
.66 .75 .917 r
.35948 .61566 .36814 .62355 .38227 .61917 .37366 .61126 Mtetra
.652 .748 .921 r
.37366 .61126 .38227 .61917 .39646 .6149 .38789 .60713 Mtetra
.651 .753 .924 r
.38789 .60713 .39646 .6149 .41073 .61081 .40221 .60298 Mtetra
.655 .754 .922 r
.40221 .60298 .41073 .61081 .42507 .60663 .4166 .59867 Mtetra
.662 .753 .918 r
.4166 .59867 .42507 .60663 .4395 .60231 .43108 .59409 Mtetra
.66 .747 .915 r
.43108 .59409 .4395 .60231 .454 .59774 .44564 .58957 Mtetra
.65 .747 .92 r
.44564 .58957 .454 .59774 .46858 .59327 .46026 .58538 Mtetra
.65 .755 .926 r
.46026 .58538 .46858 .59327 .48324 .58908 .47496 .58116 Mtetra
.653 .756 .925 r
.47496 .58116 .48324 .58908 .49797 .58487 .48975 .5768 Mtetra
.656 .754 .922 r
.48975 .5768 .49797 .58487 .51279 .58053 .50462 .57233 Mtetra
.657 .752 .92 r
.50462 .57233 .51279 .58053 .52769 .57616 .51957 .5678 Mtetra
.645 .746 .923 r
.51957 .5678 .52769 .57616 .54267 .57162 .53461 .56368 Mtetra
.622 .75 .938 r
.53461 .56368 .54267 .57162 .55773 .56709 .54973 .56024 Mtetra
.608 .777 .961 r
.54973 .56024 .55773 .56709 .57287 .56269 .56495 .55693 Mtetra
.603 .808 .979 r
.56495 .55693 .57287 .56269 .5881 .55832 .58026 .55333 Mtetra
.608 .835 .986 r
.58026 .55333 .5881 .55832 .60341 .55388 .59566 .54927 Mtetra
.623 .852 .986 r
.59566 .54927 .60341 .55388 .61881 .54929 .61113 .54463 Mtetra
.645 .858 .981 r
.61113 .54463 .61881 .54929 .63429 .54454 .62667 .53943 Mtetra
.667 .852 .971 r
.62667 .53943 .63429 .54454 .64985 .53972 .64227 .53375 Mtetra
.682 .832 .955 r
.64227 .53375 .64985 .53972 .6655 .53494 .65795 .52777 Mtetra
.682 .799 .937 r
.65795 .52777 .6655 .53494 .68124 .53027 .67371 .52192 Mtetra
.665 .764 .924 r
.67371 .52192 .68124 .53027 .69707 .52563 .68958 .51675 Mtetra
.655 .749 .919 r
.68958 .51675 .69707 .52563 .71298 .5208 .70556 .512 Mtetra
.656 .752 .921 r
.70556 .512 .71298 .5208 .72898 .51595 .72163 .50718 Mtetra
.658 .755 .922 r
.72163 .50718 .72898 .51595 .74507 .51095 .73778 .50223 Mtetra
.66 .759 .923 r
.73778 .50223 .74507 .51095 .76124 .50594 .75402 .49716 Mtetra
.661 .758 .922 r
.75402 .49716 .76124 .50594 .77752 .5012 .77035 .49204 Mtetra
.652 .747 .919 r
.77035 .49204 .77752 .5012 .79392 .49657 .7868 .48725 Mtetra
.65 .744 .918 r
.7868 .48725 .79392 .49657 .81038 .49167 .80335 .48253 Mtetra
.656 .751 .92 r
.80335 .48253 .81038 .49167 .82693 .48662 .81997 .47752 Mtetra
.659 .755 .921 r
.81997 .47752 .82693 .48662 .84357 .48148 .83668 .47235 Mtetra
.66 .756 .921 r
.83668 .47235 .84357 .48148 .86032 .47652 .85348 .46714 Mtetra
.652 .748 .92 r
.85348 .46714 .86032 .47652 .87719 .47167 .87042 .46221 Mtetra
.653 .748 .919 r
.87042 .46221 .87719 .47167 .89413 .46664 .88745 .45723 Mtetra
.656 .752 .92 r
.88745 .45723 .89413 .46664 .91116 .46145 .90456 .45207 Mtetra
.659 .755 .921 r
.90456 .45207 .91116 .46145 .92829 .45621 .92175 .44674 Mtetra
.653 .752 .923 r
.30855 .62056 .31743 .62824 .33137 .6242 .32253 .61643 Mtetra
.657 .752 .92 r
.32253 .61643 .33137 .6242 .34539 .62001 .3366 .61215 Mtetra
.661 .752 .917 r
.3366 .61215 .34539 .62001 .35948 .61566 .35075 .60769 Mtetra
.655 .749 .919 r
.35075 .60769 .35948 .61566 .37366 .61126 .36496 .60342 Mtetra
.65 .752 .924 r
.36496 .60342 .37366 .61126 .38789 .60713 .37924 .59929 Mtetra
.654 .754 .923 r
.37924 .59929 .38789 .60713 .40221 .60298 .3936 .595 Mtetra
.661 .753 .919 r
.3936 .595 .40221 .60298 .4166 .59867 .40805 .59046 Mtetra
.662 .749 .915 r
.40805 .59046 .4166 .59867 .43108 .59409 .42258 .58584 Mtetra
.651 .746 .919 r
.42258 .58584 .43108 .59409 .44564 .58957 .43718 .58162 Mtetra
.649 .754 .926 r
.43718 .58162 .44564 .58957 .46026 .58538 .45185 .5774 Mtetra
.653 .755 .925 r
.45185 .5774 .46026 .58538 .47496 .58116 .46661 .57304 Mtetra
.657 .754 .921 r
.46661 .57304 .47496 .58116 .48975 .5768 .48145 .56849 Mtetra
.651 .749 .921 r
.48145 .56849 .48975 .5768 .50462 .57233 .49637 .56415 Mtetra
.616 .742 .936 r
.49637 .56415 .50462 .57233 .51957 .5678 .51137 .56094 Mtetra
.569 .763 .97 r
.51137 .56094 .51957 .5678 .53461 .56368 .52646 .55862 Mtetra
.524 .801 .996 r
.52646 .55862 .53461 .56368 .54973 .56024 .54166 .55639 Mtetra
.477 .818 .999 r
.54166 .55639 .54973 .56024 .56495 .55693 .55697 .55418 Mtetra
.463 .842 .987 r
.55697 .55418 .56495 .55693 .58026 .55333 .57237 .55132 Mtetra
.482 .868 .974 r
.57237 .55132 .58026 .55333 .59566 .54927 .58785 .54755 Mtetra
.521 .892 .97 r
.58785 .54755 .59566 .54927 .61113 .54463 .60341 .54288 Mtetra
.574 .913 .971 r
.60341 .54288 .61113 .54463 .62667 .53943 .61904 .5373 Mtetra
.633 .926 .973 r
.61904 .5373 .62667 .53943 .64227 .53375 .63471 .5308 Mtetra
.682 .92 .972 r
.63471 .5308 .64227 .53375 .65795 .52777 .65043 .52363 Mtetra
.699 .893 .968 r
.65043 .52363 .65795 .52777 .67371 .52192 .66622 .51647 Mtetra
.707 .858 .954 r
.66622 .51647 .67371 .52192 .68958 .51675 .68209 .50939 Mtetra
.688 .801 .935 r
.68209 .50939 .68958 .51675 .70556 .512 .69806 .5032 Mtetra
.66 .756 .921 r
.69806 .5032 .70556 .512 .72163 .50718 .71419 .49814 Mtetra
.654 .749 .92 r
.71419 .49814 .72163 .50718 .73778 .50223 .73041 .49331 Mtetra
.658 .755 .921 r
.73041 .49331 .73778 .50223 .75402 .49716 .74672 .48827 Mtetra
.661 .758 .922 r
.74672 .48827 .75402 .49716 .77035 .49204 .76312 .48309 Mtetra
.76312 .48309 .77035 .49204 .7868 .48725 .7796 .47789 Mtetra
.65 .745 .919 r
.7796 .47789 .7868 .48725 .80335 .48253 .79622 .47312 Mtetra
.651 .746 .919 r
.79622 .47312 .80335 .48253 .81997 .47752 .81293 .46825 Mtetra
.657 .753 .92 r
.81293 .46825 .81997 .47752 .83668 .47235 .82972 .46312 Mtetra
.66 .756 .921 r
.82972 .46312 .83668 .47235 .85348 .46714 .84659 .45782 Mtetra
.656 .754 .921 r
.84659 .45782 .85348 .46714 .87042 .46221 .86357 .45265 Mtetra
.651 .747 .92 r
.86357 .45265 .87042 .46221 .88745 .45723 .88068 .44768 Mtetra
.655 .75 .92 r
.88068 .44768 .88745 .45723 .90456 .45207 .89787 .44252 Mtetra
.658 .753 .92 r
.89787 .44252 .90456 .45207 .92175 .44674 .91515 .43719 Mtetra
.655 .753 .922 r
.29958 .6128 .30855 .62056 .32253 .61643 .31361 .60857 Mtetra
.659 .752 .919 r
.31361 .60857 .32253 .61643 .3366 .61215 .32773 .60415 Mtetra
.66 .75 .917 r
.32773 .60415 .3366 .61215 .35075 .60769 .34192 .59969 Mtetra
.651 .749 .921 r
.34192 .59969 .35075 .60769 .36496 .60342 .35617 .59553 Mtetra
.652 .753 .924 r
.35617 .59553 .36496 .60342 .37924 .59929 .3705 .5913 Mtetra
.657 .753 .921 r
.3705 .5913 .37924 .59929 .3936 .595 .38492 .58686 Mtetra
.664 .752 .916 r
.38492 .58686 .3936 .595 .40805 .59046 .39942 .58216 Mtetra
.654 .747 .918 r
.39942 .58216 .40805 .59046 .42258 .58584 .41399 .5778 Mtetra
.648 .752 .926 r
.41399 .5778 .42258 .58584 .43718 .58162 .42863 .5736 Mtetra
.652 .755 .925 r
.42863 .5736 .43718 .58162 .45185 .5774 .44336 .56923 Mtetra
.657 .754 .921 r
.44336 .56923 .45185 .5774 .46661 .57304 .45817 .56467 Mtetra
.648 .747 .922 r
.45817 .56467 .46661 .57304 .48145 .56849 .47306 .56042 Mtetra
.591 .738 .945 r
.47306 .56042 .48145 .56849 .49637 .56415 .48801 .55789 Mtetra
.514 .76 .986 r
.48801 .55789 .49637 .56415 .51137 .56094 .50306 .55646 Mtetra
.404 .766 .994 r
.50306 .55646 .51137 .56094 .52646 .55862 .51822 .55577 Mtetra
.344 .779 .967 r
.51822 .55577 .52646 .55862 .54166 .55639 .53349 .5546 Mtetra
.373 .817 .949 r
.53349 .5546 .54166 .55639 .55697 .55418 .54888 .55214 Mtetra
.491 .871 .976 r
.54888 .55214 .55697 .55418 .57237 .55132 .56435 .54826 Mtetra
.574 .881 .992 r
.56435 .54826 .57237 .55132 .58785 .54755 .5799 .5437 Mtetra
.603 .871 .992 r
.5799 .5437 .58785 .54755 .60341 .54288 .59555 .53899 Mtetra
.609 .873 .991 r
.59555 .53899 .60341 .54288 .61904 .5373 .61127 .53412 Mtetra
.619 .897 .987 r
.61127 .53412 .61904 .5373 .63471 .5308 .62707 .52856 Mtetra
.653 .931 .971 r
.62707 .52856 .63471 .5308 .65043 .52363 .6429 .52157 Mtetra
.699 .947 .957 r
.6429 .52157 .65043 .52363 .66622 .51647 .65874 .51326 Mtetra
.736 .928 .954 r
.65874 .51326 .66622 .51647 .68209 .50939 .67462 .50443 Mtetra
.729 .881 .951 r
.67462 .50443 .68209 .50939 .69806 .5032 .69059 .49634 Mtetra
.705 .823 .938 r
.69059 .49634 .69806 .5032 .71419 .49814 .70668 .48935 Mtetra
.663 .761 .923 r
.70668 .48935 .71419 .49814 .73041 .49331 .72296 .48411 Mtetra
.654 .749 .919 r
.72296 .48411 .73041 .49331 .74672 .48827 .73934 .47918 Mtetra
.659 .755 .921 r
.73934 .47918 .74672 .48827 .76312 .48309 .75581 .47406 Mtetra
.662 .759 .922 r
.75581 .47406 .76312 .48309 .7796 .47789 .77236 .46874 Mtetra
.657 .755 .922 r
.77236 .46874 .7796 .47789 .79622 .47312 .78902 .4636 Mtetra
.649 .744 .919 r
.78902 .4636 .79622 .47312 .81293 .46825 .80581 .45879 Mtetra
.654 .749 .919 r
.80581 .45879 .81293 .46825 .82972 .46312 .82268 .45372 Mtetra
.659 .754 .92 r
.82268 .45372 .82972 .46312 .84659 .45782 .83962 .44842 Mtetra
.66 .756 .921 r
.83962 .44842 .84659 .45782 .86357 .45265 .85666 .44305 Mtetra
.652 .749 .921 r
.85666 .44305 .86357 .45265 .88068 .44768 .87384 .43797 Mtetra
.653 .748 .92 r
.87384 .43797 .88068 .44768 .89787 .44252 .89111 .43285 Mtetra
.657 .752 .92 r
.89111 .43285 .89787 .44252 .91515 .43719 .90847 .42753 Mtetra
.656 .752 .921 r
.29053 .60493 .29958 .6128 .31361 .60857 .30461 .60061 Mtetra
.661 .752 .918 r
.30461 .60061 .31361 .60857 .32773 .60415 .31877 .59609 Mtetra
.656 .749 .919 r
.31877 .59609 .32773 .60415 .34192 .59969 .333 .59173 Mtetra
.65 .751 .924 r
.333 .59173 .34192 .59969 .35617 .59553 .3473 .58754 Mtetra
.654 .753 .922 r
.3473 .58754 .35617 .59553 .3705 .5913 .36168 .58319 Mtetra
.662 .753 .918 r
.36168 .58319 .3705 .5913 .38492 .58686 .37615 .57854 Mtetra
.66 .749 .916 r
.37615 .57854 .38492 .58686 .39942 .58216 .3907 .57393 Mtetra
.648 .749 .923 r
.3907 .57393 .39942 .58216 .41399 .5778 .40531 .56972 Mtetra
.651 .754 .925 r
.40531 .56972 .41399 .5778 .42863 .5736 .42 .56539 Mtetra
.655 .753 .922 r
.42 .56539 .42863 .5736 .44336 .56923 .43479 .56089 Mtetra
.652 .75 .922 r
.43479 .56089 .44336 .56923 .45817 .56467 .44965 .55647 Mtetra
.588 .734 .944 r
.44965 .55647 .45817 .56467 .47306 .56042 .46455 .55401 Mtetra
.483 .745 .986 r
.46455 .55401 .47306 .56042 .48801 .55789 .47954 .5532 Mtetra
.329 .723 .982 r
.47954 .5532 .48801 .55789 .50306 .55646 .49463 .55362 Mtetra
.307 .759 .957 r
.49463 .55362 .50306 .55646 .51822 .55577 .50986 .55286 Mtetra
.526 .865 .993 r
.50986 .55286 .51822 .55577 .53349 .5546 .52521 .54912 Mtetra
.664 .839 .967 r
.52521 .54912 .53349 .5546 .54888 .55214 .54064 .54365 Mtetra
.687 .766 .911 r
.54064 .54365 .54888 .55214 .56435 .54826 .55615 .53762 Mtetra
.675 .716 .88 r
.55615 .53762 .56435 .54826 .5799 .5437 .57174 .53196 Mtetra
.654 .689 .87 r
.57174 .53196 .5799 .5437 .59555 .53899 .58743 .52719 Mtetra
.634 .681 .877 r
.58743 .52719 .59555 .53899 .61127 .53412 .60322 .52332 Mtetra
.624 .697 .897 r
.60322 .52332 .61127 .53412 .62707 .52856 .61913 .51982 Mtetra
.632 .748 .932 r
.61913 .51982 .62707 .52856 .6429 .52157 .63512 .51577 Mtetra
.667 .841 .966 r
.63512 .51577 .6429 .52157 .65874 .51326 .65115 .50997 Mtetra
.734 .927 .955 r
.65115 .50997 .65874 .51326 .67462 .50443 .66713 .50114 Mtetra
.767 .932 .939 r
.66713 .50114 .67462 .50443 .69059 .49634 .68311 .49108 Mtetra
.746 .879 .94 r
.68311 .49108 .69059 .49634 .70668 .48935 .6992 .48225 Mtetra
.708 .821 .935 r
.6992 .48225 .70668 .48935 .72296 .48411 .71544 .47507 Mtetra
.659 .757 .922 r
.71544 .47507 .72296 .48411 .73934 .47918 .73188 .4699 Mtetra
.656 .752 .92 r
.73188 .4699 .73934 .47918 .75581 .47406 .74842 .4648 Mtetra
.66 .755 .92 r
.74842 .4648 .75581 .47406 .77236 .46874 .76504 .45954 Mtetra
.662 .758 .921 r
.76504 .45954 .77236 .46874 .78902 .4636 .78176 .45413 Mtetra
.652 .749 .921 r
.78176 .45413 .78902 .4636 .80581 .45879 .7986 .44913 Mtetra
.65 .745 .919 r
.7986 .44913 .80581 .45879 .82268 .45372 .81555 .44418 Mtetra
.657 .752 .92 r
.81555 .44418 .82268 .45372 .83962 .44842 .83258 .4389 Mtetra
.661 .755 .92 r
.83258 .4389 .83962 .44842 .85666 .44305 .84969 .43345 Mtetra
.656 .753 .921 r
.84969 .43345 .85666 .44305 .87384 .43797 .86692 .42817 Mtetra
.651 .748 .92 r
.86692 .42817 .87384 .43797 .89111 .43285 .88428 .42305 Mtetra
.656 .751 .92 r
.88428 .42305 .89111 .43285 .90847 .42753 .90172 .41772 Mtetra
.658 .752 .92 r
.28138 .59696 .29053 .60493 .30461 .60061 .29551 .59253 Mtetra
.661 .751 .917 r
.29551 .59253 .30461 .60061 .31877 .59609 .30972 .58797 Mtetra
.652 .749 .921 r
.30972 .58797 .31877 .59609 .333 .59173 .32399 .58369 Mtetra
.651 .752 .924 r
.32399 .58369 .333 .59173 .3473 .58754 .33834 .57943 Mtetra
.657 .753 .921 r
.33834 .57943 .3473 .58754 .36168 .58319 .35277 .57495 Mtetra
.664 .752 .916 r
.35277 .57495 .36168 .58319 .37615 .57854 .3673 .57017 Mtetra
.653 .748 .919 r
.3673 .57017 .37615 .57854 .3907 .57393 .38188 .56576 Mtetra
.648 .752 .925 r
.38188 .56576 .3907 .57393 .40531 .56972 .39654 .5615 Mtetra
.652 .753 .924 r
.39654 .5615 .40531 .56972 .42 .56539 .41129 .55708 Mtetra
.658 .754 .921 r
.41129 .55708 .42 .56539 .43479 .56089 .42612 .55243 Mtetra
.611 .737 .935 r
.42612 .55243 .43479 .56089 .44965 .55647 .441 .54932 Mtetra
.491 .728 .977 r
.441 .54932 .44965 .55647 .46455 .55401 .45593 .54866 Mtetra
.314 .697 .979 r
.45593 .54866 .46455 .55401 .47954 .5532 .47094 .5497 Mtetra
.306 .743 .967 r
.47094 .5497 .47954 .5532 .49463 .55362 .4861 .54945 Mtetra
.614 .862 .99 r
.4861 .54945 .49463 .55362 .50986 .55286 .50142 .54478 Mtetra
.718 .782 .903 r
.50142 .54478 .50986 .55286 .52521 .54912 .51683 .53742 Mtetra
.739 .717 .831 r
.51683 .53742 .52521 .54912 .54064 .54365 .5323 .52768 Mtetra
.704 .648 .791 r
.5323 .52768 .54064 .54365 .55615 .53762 .54782 .51874 Mtetra
.668 .604 .774 r
.54782 .51874 .55615 .53762 .57174 .53196 .56341 .51168 Mtetra
.635 .575 .77 r
.56341 .51168 .57174 .53196 .58743 .52719 .5791 .50685 Mtetra
.602 .558 .777 r
.5791 .50685 .58743 .52719 .60322 .52332 .59493 .50425 Mtetra
.57 .553 .796 r
.59493 .50425 .60322 .52332 .61913 .51982 .61092 .50356 Mtetra
.548 .574 .832 r
.61092 .50356 .61913 .51982 .63512 .51577 .62706 .5037 Mtetra
.592 .662 .887 r
.62706 .5037 .63512 .51577 .65115 .50997 .64327 .50145 Mtetra
.653 .766 .932 r
.64327 .50145 .65115 .50997 .66713 .50114 .65948 .49649 Mtetra
.759 .897 .939 r
.65948 .49649 .66713 .50114 .68311 .49108 .67559 .48702 Mtetra
.787 .917 .927 r
.67559 .48702 .68311 .49108 .6992 .48225 .69168 .47621 Mtetra
.751 .862 .93 r
.69168 .47621 .6992 .48225 .71544 .47507 .7079 .4671 Mtetra
.693 .798 .93 r
.7079 .4671 .71544 .47507 .73188 .4699 .72433 .46048 Mtetra
.654 .75 .92 r
.72433 .46048 .73188 .4699 .74842 .4648 .74094 .45545 Mtetra
.659 .754 .921 r
.74094 .45545 .74842 .4648 .76504 .45954 .75764 .45017 Mtetra
.662 .757 .92 r
.75764 .45017 .76504 .45954 .78176 .45413 .77442 .44471 Mtetra
.658 .755 .922 r
.77442 .44471 .78176 .45413 .7986 .44913 .79132 .4394 Mtetra
.648 .745 .92 r
.79132 .4394 .7986 .44913 .81555 .44418 .80835 .43448 Mtetra
.655 .75 .92 r
.80835 .43448 .81555 .44418 .83258 .4389 .82545 .42923 Mtetra
.66 .754 .92 r
.82545 .42923 .83258 .4389 .84969 .43345 .84264 .42376 Mtetra
.659 .754 .921 r
.84264 .42376 .84969 .43345 .86692 .42817 .85993 .41829 Mtetra
.651 .748 .921 r
.85993 .41829 .86692 .42817 .88428 .42305 .87736 .41312 Mtetra
.654 .749 .92 r
.87736 .41312 .88428 .42305 .90172 .41772 .89488 .40779 Mtetra
.659 .752 .919 r
.27215 .5889 .28138 .59696 .29551 .59253 .28633 .58437 Mtetra
.66 .751 .918 r
.28633 .58437 .29551 .59253 .30972 .58797 .30058 .57982 Mtetra
.65 .75 .923 r
.30058 .57982 .30972 .58797 .32399 .58369 .31489 .57557 Mtetra
.652 .752 .923 r
.31489 .57557 .32399 .58369 .33834 .57943 .32929 .57121 Mtetra
.66 .753 .919 r
.32929 .57121 .33834 .57943 .35277 .57495 .34378 .56656 Mtetra
.663 .751 .916 r
.34378 .56656 .35277 .57495 .3673 .57017 .35835 .56179 Mtetra
.648 .748 .922 r
.35835 .56179 .3673 .57017 .38188 .56576 .37298 .55752 Mtetra
.65 .753 .925 r
.37298 .55752 .38188 .56576 .39654 .5615 .38769 .55314 Mtetra
.656 .753 .921 r
.38769 .55314 .39654 .5615 .41129 .55708 .40249 .54855 Mtetra
.645 .747 .923 r
.40249 .54855 .41129 .55708 .42612 .55243 .41736 .54431 Mtetra
.537 .721 .958 r
.41736 .54431 .42612 .55243 .441 .54932 .43224 .54302 Mtetra
.361 .694 .982 r
.43224 .54302 .441 .54932 .45593 .54866 .44717 .544 Mtetra
.276 .696 .969 r
.44717 .544 .45593 .54866 .47094 .5497 .46225 .54496 Mtetra
.602 .843 .99 r
.46225 .54496 .47094 .5497 .4861 .54945 .47752 .5408 Mtetra
.743 .775 .879 r
.47752 .5408 .4861 .54945 .50142 .54478 .49294 .53197 Mtetra
.764 .708 .799 r
.49294 .53197 .50142 .54478 .51683 .53742 .50842 .51947 Mtetra
.723 .637 .762 r
.50842 .51947 .51683 .53742 .5323 .52768 .52392 .50787 Mtetra
.685 .604 .76 r
.52392 .50787 .5323 .52768 .54782 .51874 .53945 .49908 Mtetra
.661 .594 .769 r
.53945 .49908 .54782 .51874 .56341 .51168 .55506 .49239 Mtetra
.637 .586 .78 r
.55506 .49239 .56341 .51168 .5791 .50685 .57076 .48749 Mtetra
.61 .571 .786 r
.57076 .48749 .5791 .50685 .59493 .50425 .58658 .48439 Mtetra
.575 .548 .788 r
.58658 .48439 .59493 .50425 .61092 .50356 .60256 .48342 Mtetra
.522 .517 .792 r
.60256 .48342 .61092 .50356 .62706 .5037 .61876 .4853 Mtetra
.494 .521 .813 r
.61876 .4853 .62706 .5037 .64327 .50145 .63514 .48813 Mtetra
.559 .627 .876 r
.63514 .48813 .64327 .50145 .65948 .49649 .65156 .48727 Mtetra
.668 .758 .917 r
.65156 .48727 .65948 .49649 .67559 .48702 .66791 .48168 Mtetra
.786 .885 .917 r
.66791 .48168 .67559 .48702 .69168 .47621 .6841 .47086 Mtetra
.787 .887 .917 r
.6841 .47086 .69168 .47621 .7079 .4671 .70032 .45999 Mtetra
.737 .834 .924 r
.70032 .45999 .7079 .4671 .72433 .46048 .71672 .45141 Mtetra
.665 .765 .924 r
.71672 .45141 .72433 .46048 .74094 .45545 .73338 .44584 Mtetra
.656 .75 .919 r
.73338 .44584 .74094 .45545 .75764 .45017 .75015 .44063 Mtetra
.661 .755 .92 r
.75015 .44063 .75764 .45017 .77442 .44471 .76701 .43519 Mtetra
.663 .757 .92 r
.76701 .43519 .77442 .44471 .79132 .4394 .78396 .42965 Mtetra
.65 .748 .921 r
.78396 .42965 .79132 .4394 .80835 .43448 .80106 .4246 Mtetra
.652 .747 .919 r
.80106 .4246 .80835 .43448 .82545 .42923 .81824 .41943 Mtetra
.659 .753 .92 r
.81824 .41943 .82545 .42923 .84264 .42376 .83551 .41395 Mtetra
.661 .755 .92 r
.83551 .41395 .84264 .42376 .85993 .41829 .85287 .40835 Mtetra
.652 .75 .921 r
.85287 .40835 .85993 .41829 .87736 .41312 .87037 .40306 Mtetra
.653 .749 .92 r
.87037 .40306 .87736 .41312 .89488 .40779 .88798 .39773 Mtetra
.66 .752 .918 r
.26282 .58075 .27215 .5889 .28633 .58437 .27705 .57614 Mtetra
.657 .751 .919 r
.27705 .57614 .28633 .58437 .30058 .57982 .29135 .57162 Mtetra
.65 .751 .923 r
.29135 .57162 .30058 .57982 .31489 .57557 .3057 .56734 Mtetra
.654 .752 .922 r
.3057 .56734 .31489 .57557 .32929 .57121 .32015 .56289 Mtetra
.663 .753 .917 r
.32015 .56289 .32929 .57121 .34378 .56656 .33469 .5581 Mtetra
.659 .75 .918 r
.33469 .5581 .34378 .56656 .35835 .56179 .3493 .55344 Mtetra
.647 .75 .925 r
.3493 .55344 .35835 .56179 .37298 .55752 .36398 .54917 Mtetra
.652 .753 .924 r
.36398 .54917 .37298 .55752 .38769 .55314 .37874 .54469 Mtetra
.658 .753 .92 r
.37874 .54469 .38769 .55314 .40249 .54855 .3936 .53996 Mtetra
.61 .737 .935 r
.3936 .53996 .40249 .54855 .41736 .54431 .40848 .53682 Mtetra
.463 .71 .975 r
.40848 .53682 .41736 .54431 .43224 .54302 .42337 .53674 Mtetra
.276 .652 .968 r
.42337 .53674 .43224 .54302 .44717 .544 .43832 .53879 Mtetra
.48 .785 .998 r
.43832 .53879 .44717 .544 .46225 .54496 .4535 .53718 Mtetra
.727 .792 .904 r
.4535 .53718 .46225 .54496 .47752 .5408 .4689 .52939 Mtetra
.789 .734 .802 r
.4689 .52939 .47752 .5408 .49294 .53197 .48443 .51541 Mtetra
.75 .662 .763 r
.48443 .51541 .49294 .53197 .50842 .51947 .49996 .50177 Mtetra
.711 .635 .771 r
.49996 .50177 .50842 .51947 .52392 .50787 .51549 .49147 Mtetra
.68 .635 .798 r
.51549 .49147 .52392 .50787 .53945 .49908 .53106 .48423 Mtetra
.651 .642 .828 r
.53106 .48423 .53945 .49908 .55506 .49239 .54671 .47916 Mtetra
.652 .667 .852 r
.54671 .47916 .55506 .49239 .57076 .48749 .56245 .47421 Mtetra
.65 .666 .852 r
.56245 .47421 .57076 .48749 .58658 .48439 .57828 .46936 Mtetra
.603 .62 .841 r
.57828 .46936 .58658 .48439 .60256 .48342 .59425 .46671 Mtetra
.539 .566 .83 r
.59425 .46671 .60256 .48342 .61876 .4853 .61042 .46715 Mtetra
.465 .508 .818 r
.61042 .46715 .61876 .4853 .63514 .48813 .62684 .47101 Mtetra
.447 .512 .832 r
.62684 .47101 .63514 .48813 .65156 .48727 .64345 .47526 Mtetra
.581 .665 .896 r
.64345 .47526 .65156 .48727 .66791 .48168 .66001 .47325 Mtetra
.728 .798 .907 r
.66001 .47325 .66791 .48168 .6841 .47086 .6764 .46495 Mtetra
.806 .875 .897 r
.6764 .46495 .6841 .47086 .70032 .45999 .69266 .45289 Mtetra
.763 .842 .911 r
.69266 .45289 .70032 .45999 .71672 .45141 .70908 .44296 Mtetra
.693 .792 .926 r
.70908 .44296 .71672 .45141 .73338 .44584 .72573 .43617 Mtetra
.654 .75 .92 r
.72573 .43617 .73338 .44584 .75015 .44063 .74258 .43099 Mtetra
.659 .754 .92 r
.74258 .43099 .75015 .44063 .76701 .43519 .75952 .42555 Mtetra
.664 .757 .92 r
.75952 .42555 .76701 .43519 .78396 .42965 .77653 .41989 Mtetra
.653 .752 .922 r
.77653 .41989 .78396 .42965 .80106 .4246 .79369 .41464 Mtetra
.65 .747 .92 r
.79369 .41464 .80106 .4246 .81824 .41943 .81096 .4095 Mtetra
.657 .752 .92 r
.81096 .4095 .81824 .41943 .83551 .41395 .8283 .40401 Mtetra
.661 .755 .92 r
.8283 .40401 .83551 .41395 .85287 .40835 .84574 .39834 Mtetra
.654 .752 .921 r
.84574 .39834 .85287 .40835 .87037 .40306 .8633 .3929 Mtetra
.652 .749 .921 r
.8633 .3929 .87037 .40306 .88798 .39773 .88099 .38756 Mtetra
.661 .752 .918 r
.2534 .57252 .26282 .58075 .27705 .57614 .26768 .56785 Mtetra
.655 .751 .92 r
.26768 .56785 .27705 .57614 .29135 .57162 .28202 .56335 Mtetra
.65 .751 .923 r
.28202 .56335 .29135 .57162 .3057 .56734 .29642 .55901 Mtetra
.655 .752 .921 r
.29642 .55901 .3057 .56734 .32015 .56289 .31092 .55448 Mtetra
.664 .753 .917 r
.31092 .55448 .32015 .56289 .33469 .5581 .32551 .54959 Mtetra
.655 .75 .919 r
.32551 .54959 .33469 .5581 .3493 .55344 .34017 .54501 Mtetra
.647 .751 .925 r
.34017 .54501 .3493 .55344 .36398 .54917 .35489 .54066 Mtetra
.652 .751 .922 r
.35489 .54066 .36398 .54917 .37874 .54469 .36971 .53614 Mtetra
.656 .752 .921 r
.36971 .53614 .37874 .54469 .3936 .53996 .38461 .53144 Mtetra
.568 .726 .948 r
.38461 .53144 .3936 .53996 .40848 .53682 .3995 .5294 Mtetra
.391 .681 .975 r
.3995 .5294 .40848 .53682 .42337 .53674 .41439 .53044 Mtetra
.292 .662 .971 r
.41439 .53044 .42337 .53674 .43832 .53879 .4294 .53223 Mtetra
.642 .805 .962 r
.4294 .53223 .43832 .53879 .4535 .53718 .44471 .52759 Mtetra
.782 .764 .837 r
.44471 .52759 .4535 .53718 .4689 .52939 .46025 .51552 Mtetra
.787 .703 .771 r
.46025 .51552 .4689 .52939 .48443 .51541 .47586 .49967 Mtetra
.743 .668 .777 r
.47586 .49967 .48443 .51541 .49996 .50177 .49143 .48733 Mtetra
.69 .664 .819 r
.49143 .48733 .49996 .50177 .51549 .49147 .50698 .47992 Mtetra
.633 .689 .885 r
.50698 .47992 .51549 .49147 .53106 .48423 .5226 .47597 Mtetra
.624 .76 .944 r
.5226 .47597 .53106 .48423 .54671 .47916 .53832 .47204 Mtetra
.65 .8 .955 r
.53832 .47204 .54671 .47916 .56245 .47421 .55413 .46703 Mtetra
.681 .809 .943 r
.55413 .46703 .56245 .47421 .57828 .46936 .57001 .46095 Mtetra
.682 .779 .924 r
.57001 .46095 .57828 .46936 .59425 .46671 .58598 .45488 Mtetra
.596 .673 .894 r
.58598 .45488 .59425 .46671 .61042 .46715 .60211 .45229 Mtetra
.474 .56 .863 r
.60211 .45229 .61042 .46715 .62684 .47101 .61851 .45471 Mtetra
.381 .486 .842 r
.61851 .45471 .62684 .47101 .64345 .47526 .63519 .46073 Mtetra
.476 .569 .87 r
.63519 .46073 .64345 .47526 .66001 .47325 .65194 .46297 Mtetra
.658 .736 .907 r
.65194 .46297 .66001 .47325 .6764 .46495 .66854 .45765 Mtetra
.796 .842 .886 r
.66854 .45765 .6764 .46495 .69266 .45289 .68491 .44575 Mtetra
.785 .846 .898 r
.68491 .44575 .69266 .45289 .70908 .44296 .70135 .43457 Mtetra
.72 .804 .917 r
.70135 .43457 .70908 .44296 .72573 .43617 .71801 .42654 Mtetra
.655 .754 .922 r
.71801 .42654 .72573 .43617 .74258 .43099 .73493 .42123 Mtetra
.659 .754 .92 r
.73493 .42123 .74258 .43099 .75952 .42555 .75193 .41573 Mtetra
.663 .755 .919 r
.75193 .41573 .75952 .42555 .77653 .41989 .76902 .41004 Mtetra
.656 .753 .921 r
.76902 .41004 .77653 .41989 .79369 .41464 .78624 .40459 Mtetra
.648 .747 .921 r
.78624 .40459 .79369 .41464 .81096 .4095 .80359 .39946 Mtetra
.657 .752 .92 r
.80359 .39946 .81096 .4095 .8283 .40401 .82101 .39394 Mtetra
.661 .754 .919 r
.82101 .39394 .8283 .40401 .84574 .39834 .83852 .38821 Mtetra
.656 .752 .921 r
.83852 .38821 .84574 .39834 .8633 .3929 .85616 .38265 Mtetra
.651 .749 .921 r
.85616 .38265 .8633 .3929 .88099 .38756 .87392 .37726 Mtetra
.661 .753 .918 r
.24389 .56421 .2534 .57252 .26768 .56785 .25821 .55948 Mtetra
.654 .751 .921 r
.25821 .55948 .26768 .56785 .28202 .56335 .27259 .55497 Mtetra
.65 .751 .923 r
.27259 .55497 .28202 .56335 .29642 .55901 .28704 .55058 Mtetra
.656 .752 .921 r
.28704 .55058 .29642 .55901 .31092 .55448 .30159 .54598 Mtetra
.665 .753 .916 r
.30159 .54598 .31092 .55448 .32551 .54959 .31624 .54101 Mtetra
.653 .75 .921 r
.31624 .54101 .32551 .54959 .34017 .54501 .33094 .53647 Mtetra
.648 .75 .924 r
.33094 .53647 .34017 .54501 .35489 .54066 .34571 .53205 Mtetra
.653 .751 .922 r
.34571 .53205 .35489 .54066 .36971 .53614 .36058 .52743 Mtetra
.65 .749 .922 r
.36058 .52743 .36971 .53614 .38461 .53144 .37553 .52289 Mtetra
.535 .715 .955 r
.37553 .52289 .38461 .53144 .3995 .5294 .39043 .52163 Mtetra
.352 .653 .968 r
.39043 .52163 .3995 .5294 .41439 .53044 .40533 .52341 Mtetra
.389 .694 .981 r
.40533 .52341 .41439 .53044 .4294 .53223 .42042 .52419 Mtetra
.704 .784 .914 r
.42042 .52419 .4294 .53223 .44471 .52759 .43584 .51739 Mtetra
.808 .758 .806 r
.43584 .51739 .44471 .52759 .46025 .51552 .45151 .50237 Mtetra
.791 .714 .778 r
.45151 .50237 .46025 .51552 .47586 .49967 .46719 .48667 Mtetra
.744 .703 .813 r
.46719 .48667 .47586 .49967 .49143 .48733 .48279 .47587 Mtetra
.636 .693 .886 r
.48279 .47587 .49143 .48733 .50698 .47992 .49837 .47176 Mtetra
.586 .751 .956 r
.49837 .47176 .50698 .47992 .5226 .47597 .51405 .46889 Mtetra
.604 .787 .969 r
.51405 .46889 .5226 .47597 .53832 .47204 .52983 .4652 Mtetra
.648 .809 .961 r
.52983 .4652 .53832 .47204 .55413 .46703 .54571 .46014 Mtetra
.688 .82 .946 r
.54571 .46014 .55413 .46703 .57001 .46095 .56167 .45372 Mtetra
.709 .818 .932 r
.56167 .45372 .57001 .46095 .58598 .45488 .57769 .44645 Mtetra
.678 .781 .928 r
.57769 .44645 .58598 .45488 .60211 .45229 .59381 .44044 Mtetra
.493 .627 .911 r
.59381 .44044 .60211 .45229 .61851 .45471 .6102 .44118 Mtetra
.334 .508 .88 r
.6102 .44118 .61851 .45471 .63519 .46073 .6269 .44693 Mtetra
.366 .522 .88 r
.6269 .44693 .63519 .46073 .65194 .46297 .64378 .45204 Mtetra
.605 .703 .913 r
.64378 .45204 .65194 .46297 .66854 .45765 .66052 .44882 Mtetra
.772 .805 .879 r
.66052 .44882 .66854 .45765 .68491 .44575 .67703 .43785 Mtetra
.794 .832 .881 r
.67703 .43785 .68491 .44575 .70135 .43457 .69351 .42582 Mtetra
.736 .802 .904 r
.69351 .42582 .70135 .43457 .71801 .42654 .71021 .41688 Mtetra
.661 .757 .922 r
.71021 .41688 .71801 .42654 .73493 .42123 .72718 .41129 Mtetra
.658 .752 .919 r
.72718 .41129 .73493 .42123 .75193 .41573 .74426 .40578 Mtetra
.662 .755 .919 r
.74426 .40578 .75193 .41573 .76902 .41004 .76143 .40006 Mtetra
.659 .754 .92 r
.76143 .40006 .76902 .41004 .78624 .40459 .77871 .39446 Mtetra
.647 .747 .922 r
.77871 .39446 .78624 .40459 .80359 .39946 .79613 .38929 Mtetra
.656 .751 .92 r
.79613 .38929 .80359 .39946 .82101 .39394 .81363 .38374 Mtetra
.661 .754 .919 r
.81363 .38374 .82101 .39394 .83852 .38821 .83122 .37796 Mtetra
.657 .753 .92 r
.83122 .37796 .83852 .38821 .85616 .38265 .84893 .37229 Mtetra
.651 .749 .921 r
.84893 .37229 .85616 .38265 .87392 .37726 .86678 .36686 Mtetra
.662 .753 .918 r
.23428 .55582 .24389 .56421 .25821 .55948 .24865 .55103 Mtetra
.654 .751 .921 r
.24865 .55103 .25821 .55948 .27259 .55497 .26307 .5465 Mtetra
.65 .75 .923 r
.26307 .5465 .27259 .55497 .28704 .55058 .27757 .54206 Mtetra
.656 .752 .92 r
.27757 .54206 .28704 .55058 .30159 .54598 .29217 .53738 Mtetra
.665 .753 .916 r
.29217 .53738 .30159 .54598 .31624 .54101 .30686 .53237 Mtetra
.651 .75 .922 r
.30686 .53237 .31624 .54101 .33094 .53647 .32161 .52782 Mtetra
.649 .75 .923 r
.32161 .52782 .33094 .53647 .34571 .53205 .33644 .52334 Mtetra
.654 .751 .921 r
.33644 .52334 .34571 .53205 .36058 .52743 .35136 .51863 Mtetra
.646 .748 .924 r
.35136 .51863 .36058 .52743 .37553 .52289 .36635 .5142 Mtetra
.517 .706 .957 r
.36635 .5142 .37553 .52289 .39043 .52163 .38127 .51332 Mtetra
.347 .638 .962 r
.38127 .51332 .39043 .52163 .40533 .52341 .3962 .51541 Mtetra
.46 .702 .972 r
.3962 .51541 .40533 .52341 .42042 .52419 .41135 .51539 Mtetra
.724 .773 .892 r
.41135 .51539 .42042 .52419 .43584 .51739 .42687 .50747 Mtetra
.822 .765 .799 r
.42687 .50747 .43584 .51739 .45151 .50237 .44265 .49105 Mtetra
.802 .742 .796 r
.44265 .49105 .45151 .50237 .46719 .48667 .4584 .47569 Mtetra
.734 .735 .852 r
.4584 .47569 .46719 .48667 .48279 .47587 .47404 .46653 Mtetra
.598 .727 .935 r
.47404 .46653 .48279 .47587 .49837 .47176 .48966 .46355 Mtetra
.575 .748 .959 r
.48966 .46355 .49837 .47176 .51405 .46889 .50539 .46092 Mtetra
.612 .769 .955 r
.50539 .46092 .51405 .46889 .52983 .4652 .52124 .45717 Mtetra
.654 .782 .942 r
.52124 .45717 .52983 .4652 .54571 .46014 .53719 .45206 Mtetra
.69 .792 .928 r
.53719 .45206 .54571 .46014 .56167 .45372 .55322 .44559 Mtetra
.715 .799 .917 r
.55322 .44559 .56167 .45372 .57769 .44645 .56931 .43798 Mtetra
.707 .79 .916 r
.56931 .43798 .57769 .44645 .59381 .44044 .58548 .43071 Mtetra
.527 .695 .945 r
.58548 .43071 .59381 .44044 .6102 .44118 .60187 .42969 Mtetra
.295 .53 .909 r
.60187 .42969 .6102 .44118 .6269 .44693 .61859 .43497 Mtetra
.258 .498 .895 r
.61859 .43497 .6269 .44693 .64378 .45204 .63554 .4414 Mtetra
.572 .698 .927 r
.63554 .4414 .64378 .45204 .66052 .44882 .65239 .43921 Mtetra
.756 .787 .878 r
.65239 .43921 .66052 .44882 .67703 .43785 .66901 .42895 Mtetra
.793 .811 .866 r
.66901 .42895 .67703 .43785 .69351 .42582 .68557 .41649 Mtetra
.743 .793 .893 r
.68557 .41649 .69351 .42582 .71021 .41688 .70232 .40705 Mtetra
.665 .758 .92 r
.70232 .40705 .71021 .41688 .72718 .41129 .71936 .40124 Mtetra
.657 .751 .919 r
.71936 .40124 .72718 .41129 .74426 .40578 .73651 .39572 Mtetra
.662 .754 .918 r
.73651 .39572 .74426 .40578 .76143 .40006 .75375 .38995 Mtetra
.66 .754 .919 r
.75375 .38995 .76143 .40006 .77871 .39446 .7711 .38424 Mtetra
.647 .748 .922 r
.7711 .38424 .77871 .39446 .79613 .38929 .7886 .37901 Mtetra
.655 .751 .92 r
.7886 .37901 .79613 .38929 .81363 .38374 .80618 .37342 Mtetra
.66 .753 .919 r
.80618 .37342 .81363 .38374 .83122 .37796 .82384 .36759 Mtetra
.658 .752 .92 r
.82384 .36759 .83122 .37796 .84893 .37229 .84163 .36183 Mtetra
.651 .749 .922 r
.84163 .36183 .84893 .37229 .86678 .36686 .85955 .35634 Mtetra
.662 .753 .918 r
.22457 .54734 .23428 .55582 .24865 .55103 .23898 .54251 Mtetra
.654 .751 .921 r
.23898 .54251 .24865 .55103 .26307 .5465 .25346 .53794 Mtetra
.651 .75 .922 r
.25346 .53794 .26307 .5465 .27757 .54206 .268 .53344 Mtetra
.656 .752 .92 r
.268 .53344 .27757 .54206 .29217 .53738 .28265 .52872 Mtetra
.665 .754 .917 r
.28265 .52872 .29217 .53738 .30686 .53237 .29739 .52366 Mtetra
.651 .75 .922 r
.29739 .52366 .30686 .53237 .32161 .52782 .31219 .51906 Mtetra
.649 .749 .923 r
.31219 .51906 .32161 .52782 .33644 .52334 .32707 .51453 Mtetra
.654 .751 .921 r
.32707 .51453 .33644 .52334 .35136 .51863 .34204 .50977 Mtetra
.646 .749 .924 r
.34204 .50977 .35136 .51863 .36635 .5142 .35708 .50529 Mtetra
.519 .704 .954 r
.35708 .50529 .36635 .5142 .38127 .51332 .37205 .50437 Mtetra
.366 .632 .956 r
.37205 .50437 .38127 .51332 .3962 .51541 .38701 .50643 Mtetra
.479 .687 .958 r
.38701 .50643 .3962 .51541 .41135 .51539 .4022 .50637 Mtetra
.724 .77 .89 r
.4022 .50637 .41135 .51539 .42687 .50747 .41778 .49839 Mtetra
.829 .781 .806 r
.41778 .49839 .42687 .50747 .44265 .49105 .43365 .48188 Mtetra
.821 .781 .815 r
.43365 .48188 .44265 .49105 .4584 .47569 .44948 .46645 Mtetra
.744 .773 .876 r
.44948 .46645 .4584 .47569 .47404 .46653 .46519 .45722 Mtetra
.597 .73 .937 r
.46519 .45722 .47404 .46653 .48966 .46355 .48087 .4542 Mtetra
.585 .725 .94 r
.48087 .4542 .48966 .46355 .50539 .46092 .49665 .45152 Mtetra
.619 .738 .931 r
.49665 .45152 .50539 .46092 .52124 .45717 .51256 .44772 Mtetra
.656 .751 .919 r
.51256 .44772 .52124 .45717 .53719 .45206 .52856 .44255 Mtetra
.688 .761 .907 r
.52856 .44255 .53719 .45206 .55322 .44559 .54466 .43602 Mtetra
.712 .767 .896 r
.54466 .43602 .55322 .44559 .56931 .43798 .56082 .42835 Mtetra
.704 .765 .9 r
.56082 .42835 .56931 .43798 .58548 .43071 .57706 .42102 Mtetra
.526 .697 .948 r
.57706 .42102 .58548 .43071 .60187 .42969 .5935 .41996 Mtetra
.229 .536 .924 r
.5935 .41996 .60187 .42969 .61859 .43497 .61026 .4252 Mtetra
.168 .498 .907 r
.61026 .4252 .61859 .43497 .63554 .4414 .62725 .4316 Mtetra
.564 .717 .944 r
.62725 .4316 .63554 .4414 .65239 .43921 .64416 .42936 Mtetra
.755 .784 .877 r
.64416 .42936 .65239 .43921 .66901 .42895 .66086 .41903 Mtetra
.787 .791 .856 r
.66086 .41903 .66901 .42895 .68557 .41649 .6775 .40649 Mtetra
.74 .78 .885 r
.6775 .40649 .68557 .41649 .70232 .40705 .69434 .39698 Mtetra
.665 .755 .917 r
.69434 .39698 .70232 .40705 .71936 .40124 .71144 .39111 Mtetra
.657 .752 .92 r
.71144 .39111 .71936 .40124 .73651 .39572 .72867 .38552 Mtetra
.662 .754 .918 r
.72867 .38552 .73651 .39572 .75375 .38995 .74598 .37969 Mtetra
.66 .753 .919 r
.74598 .37969 .75375 .38995 .7711 .38424 .76341 .37393 Mtetra
.647 .748 .923 r
.76341 .37393 .7711 .38424 .7886 .37901 .78098 .36863 Mtetra
.655 .751 .92 r
.78098 .36863 .7886 .37901 .80618 .37342 .79863 .36298 Mtetra
.66 .753 .919 r
.79863 .36298 .80618 .37342 .82384 .36759 .81638 .35708 Mtetra
.658 .752 .92 r
.81638 .35708 .82384 .36759 .84163 .36183 .83424 .35126 Mtetra
.651 .749 .922 r
.83424 .35126 .84163 .36183 .85955 .35634 .85224 .3457 Mtetra
.661 .753 .918 r
.21476 .53879 .22457 .54734 .23898 .54251 .22922 .53391 Mtetra
.654 .751 .921 r
.22922 .53391 .23898 .54251 .25346 .53794 .24374 .52927 Mtetra
.65 .75 .922 r
.24374 .52927 .25346 .53794 .268 .53344 .25834 .52473 Mtetra
.656 .751 .92 r
.25834 .52473 .268 .53344 .28265 .52872 .27303 .51998 Mtetra
.665 .754 .917 r
.27303 .51998 .28265 .52872 .29739 .52366 .28783 .51487 Mtetra
.653 .751 .922 r
.28783 .51487 .29739 .52366 .31219 .51906 .30267 .51018 Mtetra
.648 .749 .923 r
.30267 .51018 .31219 .51906 .32707 .51453 .3176 .50562 Mtetra
.653 .75 .921 r
.3176 .50562 .32707 .51453 .34204 .50977 .33262 .50085 Mtetra
.65 .751 .923 r
.33262 .50085 .34204 .50977 .35708 .50529 .34772 .49616 Mtetra
.538 .708 .95 r
.34772 .49616 .35708 .50529 .37205 .50437 .36275 .49477 Mtetra
.4 .636 .95 r
.36275 .49477 .37205 .50437 .38701 .50643 .37776 .49646 Mtetra
.459 .656 .945 r
.37776 .49646 .38701 .50643 .4022 .50637 .39296 .49712 Mtetra
.702 .763 .899 r
.39296 .49712 .4022 .50637 .41778 .49839 .40856 .49015 Mtetra
.826 .799 .826 r
.40856 .49015 .41778 .49839 .43365 .48188 .42449 .4749 Mtetra
.842 .824 .83 r
.42449 .4749 .43365 .48188 .44948 .46645 .44043 .45896 Mtetra
.782 .817 .881 r
.44043 .45896 .44948 .46645 .46519 .45722 .45625 .44795 Mtetra
.633 .746 .929 r
.45625 .44795 .46519 .45722 .48087 .4542 .472 .44368 Mtetra
.599 .706 .919 r
.472 .44368 .48087 .4542 .49665 .45152 .48783 .44067 Mtetra
.623 .709 .908 r
.48783 .44067 .49665 .45152 .51256 .44772 .50379 .43682 Mtetra
.656 .722 .897 r
.50379 .43682 .51256 .44772 .52856 .44255 .51985 .4316 Mtetra
.686 .732 .886 r
.51985 .4316 .52856 .44255 .54466 .43602 .536 .425 Mtetra
.702 .737 .878 r
.536 .425 .54466 .43602 .56082 .42835 .55223 .41756 Mtetra
.676 .734 .894 r
.55223 .41756 .56082 .42835 .57706 .42102 .56854 .41136 Mtetra
.454 .666 .954 r
.56854 .41136 .57706 .42102 .5935 .41996 .58508 .41198 Mtetra
.114 .512 .909 r
.58508 .41198 .5935 .41996 .61026 .4252 .60189 .41764 Mtetra
.136 .539 .921 r
.60189 .41764 .61026 .4252 .62725 .4316 .6189 .42265 Mtetra
.592 .752 .954 r
.6189 .42265 .62725 .4316 .64416 .42936 .63583 .41927 Mtetra
.766 .784 .867 r
.63583 .41927 .64416 .42936 .66086 .41903 .65258 .40808 Mtetra
.776 .771 .848 r
.65258 .40808 .66086 .41903 .6775 .40649 .66932 .39582 Mtetra
.73 .765 .881 r
.66932 .39582 .6775 .40649 .69434 .39698 .68625 .38667 Mtetra
.661 .75 .917 r
.68625 .38667 .69434 .39698 .71144 .39111 .70344 .3809 Mtetra
.658 .753 .92 r
.70344 .3809 .71144 .39111 .72867 .38552 .72074 .37521 Mtetra
.662 .754 .918 r
.72074 .37521 .72867 .38552 .74598 .37969 .73812 .3693 Mtetra
.659 .752 .919 r
.73812 .3693 .74598 .37969 .76341 .37393 .75563 .36351 Mtetra
.647 .748 .923 r
.75563 .36351 .76341 .37393 .78098 .36863 .77327 .35815 Mtetra
.656 .752 .921 r
.77327 .35815 .78098 .36863 .79863 .36298 .791 .35242 Mtetra
.661 .753 .919 r
.791 .35242 .79863 .36298 .81638 .35708 .80882 .34644 Mtetra
.657 .752 .92 r
.80882 .34644 .81638 .35708 .83424 .35126 .82677 .34057 Mtetra
.651 .749 .922 r
.82677 .34057 .83424 .35126 .85224 .3457 .84485 .33495 Mtetra
.661 .753 .918 r
.20485 .53015 .21476 .53879 .22922 .53391 .21936 .52523 Mtetra
.655 .752 .921 r
.21936 .52523 .22922 .53391 .24374 .52927 .23393 .5205 Mtetra
.65 .749 .922 r
.23393 .5205 .24374 .52927 .25834 .52473 .24857 .51593 Mtetra
.655 .751 .92 r
.24857 .51593 .25834 .52473 .27303 .51998 .26331 .51116 Mtetra
.664 .754 .917 r
.26331 .51116 .27303 .51998 .28783 .51487 .27815 .50602 Mtetra
.655 .752 .921 r
.27815 .50602 .28783 .51487 .30267 .51018 .29306 .50119 Mtetra
.648 .748 .923 r
.29306 .50119 .30267 .51018 .3176 .50562 .30803 .4966 Mtetra
.652 .75 .921 r
.30803 .4966 .3176 .50562 .33262 .50085 .3231 .49184 Mtetra
.656 .752 .921 r
.3231 .49184 .33262 .50085 .34772 .49616 .33827 .48689 Mtetra
.571 .72 .943 r
.33827 .48689 .34772 .49616 .36275 .49477 .35338 .48462 Mtetra
.45 .648 .943 r
.35338 .48462 .36275 .49477 .37776 .49646 .36845 .48548 Mtetra
.429 .62 .931 r
.36845 .48548 .37776 .49646 .39296 .49712 .38364 .48711 Mtetra
.651 .734 .91 r
.38364 .48711 .39296 .49712 .40856 .49015 .39922 .48221 Mtetra
.797 .807 .86 r
.39922 .48221 .40856 .49015 .42449 .4749 .41515 .46978 Mtetra
.859 .863 .842 r
.41515 .46978 .42449 .4749 .44043 .45896 .4312 .45353 Mtetra
.817 .867 .884 r
.4312 .45353 .44043 .45896 .45625 .44795 .44716 .44083 Mtetra
.719 .822 .929 r
.44716 .44083 .45625 .44795 .472 .44368 .46304 .43312 Mtetra
.631 .719 .911 r
.46304 .43312 .472 .44368 .48783 .44067 .47894 .4289 Mtetra
.631 .696 .892 r
.47894 .4289 .48783 .44067 .50379 .43682 .49494 .42472 Mtetra
.655 .7 .88 r
.49494 .42472 .50379 .43682 .51985 .4316 .51105 .41943 Mtetra
.677 .708 .871 r
.51105 .41943 .51985 .4316 .536 .425 .52726 .41306 Mtetra
.677 .713 .876 r
.52726 .41306 .536 .425 .55223 .41756 .54355 .4067 Mtetra
.59 .702 .921 r
.54355 .4067 .55223 .41756 .56854 .41136 .55996 .40386 Mtetra
.301 .646 .968 r
.55996 .40386 .56854 .41136 .58508 .41198 .57658 .40609 Mtetra
0 .464 .846 r
.57658 .40609 .58508 .41198 .60189 .41764 .59346 .41195 Mtetra
.227 .653 .957 r
.59346 .41195 .60189 .41764 .6189 .42265 .61045 .41399 Mtetra
.656 .785 .943 r
.61045 .41399 .6189 .42265 .63583 .41927 .62739 .40838 Mtetra
.776 .773 .85 r
.62739 .40838 .63583 .41927 .65258 .40808 .64418 .3961 Mtetra
.759 .75 .845 r
.64418 .3961 .65258 .40808 .66932 .39582 .66103 .38455 Mtetra
.713 .75 .882 r
.66103 .38455 .66932 .39582 .68625 .38667 .67808 .37619 Mtetra
.656 .747 .917 r
.67808 .37619 .68625 .38667 .70344 .3809 .69535 .37057 Mtetra
.659 .754 .92 r
.69535 .37057 .70344 .3809 .72074 .37521 .71271 .36476 Mtetra
.663 .754 .918 r
.71271 .36476 .72074 .37521 .73812 .3693 .73017 .35876 Mtetra
.657 .751 .919 r
.73017 .35876 .73812 .3693 .75563 .36351 .74776 .353 Mtetra
.648 .749 .923 r
.74776 .353 .75563 .36351 .77327 .35815 .76548 .34755 Mtetra
.657 .752 .92 r
.76548 .34755 .77327 .35815 .791 .35242 .78328 .34172 Mtetra
.661 .753 .919 r
.78328 .34172 .791 .35242 .80882 .34644 .80118 .33567 Mtetra
.656 .751 .92 r
.80118 .33567 .80882 .34644 .82677 .34057 .81921 .32978 Mtetra
.651 .75 .922 r
.81921 .32978 .82677 .34057 .84485 .33495 .83737 .32407 Mtetra
.66 .753 .918 r
.19483 .52142 .20485 .53015 .21936 .52523 .20939 .51648 Mtetra
.657 .753 .92 r
.20939 .51648 .21936 .52523 .23393 .5205 .22402 .51163 Mtetra
.65 .749 .922 r
.22402 .51163 .23393 .5205 .24857 .51593 .2387 .50701 Mtetra
.654 .75 .921 r
.2387 .50701 .24857 .51593 .26331 .51116 .25349 .50223 Mtetra
.663 .753 .918 r
.25349 .50223 .26331 .51116 .27815 .50602 .26838 .4971 Mtetra
.658 .754 .92 r
.26838 .4971 .27815 .50602 .29306 .50119 .28334 .49209 Mtetra
.647 .748 .923 r
.28334 .49209 .29306 .50119 .30803 .4966 .29837 .48747 Mtetra
.652 .75 .921 r
.29837 .48747 .30803 .4966 .3231 .49184 .31349 .48265 Mtetra
.658 .751 .919 r
.31349 .48265 .3231 .49184 .33827 .48689 .32871 .47757 Mtetra
.611 .735 .934 r
.32871 .47757 .33827 .48689 .35338 .48462 .34393 .4741 Mtetra
.506 .667 .935 r
.34393 .4741 .35338 .48462 .36845 .48548 .3591 .47375 Mtetra
.43 .605 .92 r
.3591 .47375 .36845 .48548 .38364 .48711 .37429 .47556 Mtetra
.569 .674 .91 r
.37429 .47556 .38364 .48711 .39922 .48221 .3898 .47364 Mtetra
.727 .789 .901 r
.3898 .47364 .39922 .48221 .41515 .46978 .40565 .46543 Mtetra
.844 .887 .871 r
.40565 .46543 .41515 .46978 .4312 .45353 .42176 .45092 Mtetra
.845 .93 .885 r
.42176 .45092 .4312 .45353 .44716 .44083 .43787 .43675 Mtetra
.785 .906 .925 r
.43787 .43675 .44716 .44083 .46304 .43312 .45391 .42598 Mtetra
.716 .825 .933 r
.45391 .42598 .46304 .43312 .47894 .4289 .46994 .41831 Mtetra
.66 .733 .903 r
.46994 .41831 .47894 .4289 .49494 .42472 .486 .41286 Mtetra
.655 .707 .885 r
.486 .41286 .49494 .42472 .51105 .41943 .50217 .40752 Mtetra
.652 .706 .886 r
.50217 .40752 .51105 .41943 .52726 .41306 .51842 .40229 Mtetra
.593 .707 .923 r
.51842 .40229 .52726 .41306 .54355 .4067 .53479 .39929 Mtetra
.414 .711 .985 r
.53479 .39929 .54355 .4067 .55996 .40386 .5513 .39942 Mtetra
.025 .545 .863 r
.5513 .39942 .55996 .40386 .57658 .40609 .56801 .40304 Mtetra
0 .475 .765 r
.56801 .40304 .57658 .40609 .59346 .41195 .58493 .40705 Mtetra
.463 .807 .999 r
.58493 .40705 .59346 .41195 .61045 .41399 .6019 .40469 Mtetra
.728 .794 .905 r
.6019 .40469 .61045 .41399 .62739 .40838 .61881 .39593 Mtetra
.769 .746 .832 r
.61881 .39593 .62739 .40838 .64418 .3961 .63567 .38332 Mtetra
.738 .733 .846 r
.63567 .38332 .64418 .3961 .66103 .38455 .65264 .3729 Mtetra
.689 .737 .887 r
.65264 .3729 .66103 .38455 .67808 .37619 .66981 .36566 Mtetra
.654 .748 .919 r
.66981 .36566 .67808 .37619 .69535 .37057 .68716 .36005 Mtetra
.659 .752 .918 r
.68716 .36005 .69535 .37057 .71271 .36476 .7046 .35418 Mtetra
.664 .754 .917 r
.7046 .35418 .71271 .36476 .73017 .35876 .72213 .34809 Mtetra
.653 .749 .92 r
.72213 .34809 .73017 .35876 .74776 .353 .7398 .3424 Mtetra
.649 .75 .923 r
.7398 .3424 .74776 .353 .76548 .34755 .7576 .33683 Mtetra
.657 .752 .92 r
.7576 .33683 .76548 .34755 .78328 .34172 .77548 .33089 Mtetra
.661 .753 .918 r
.77548 .33089 .78328 .34172 .80118 .33567 .79345 .32476 Mtetra
.654 .75 .92 r
.79345 .32476 .80118 .33567 .81921 .32978 .81157 .31887 Mtetra
.652 .75 .922 r
.81157 .31887 .81921 .32978 .83737 .32407 .82981 .31307 Mtetra
.659 .752 .919 r
.18471 .51259 .19483 .52142 .20939 .51648 .19931 .50764 Mtetra
.66 .753 .919 r
.19931 .50764 .20939 .51648 .22402 .51163 .214 .50266 Mtetra
.65 .749 .922 r
.214 .50266 .22402 .51163 .2387 .50701 .22873 .49798 Mtetra
.653 .749 .921 r
.22873 .49798 .2387 .50701 .25349 .50223 .24356 .4932 Mtetra
.66 .753 .919 r
.24356 .4932 .25349 .50223 .26838 .4971 .2585 .48811 Mtetra
.663 .755 .919 r
.2585 .48811 .26838 .4971 .28334 .49209 .27353 .48289 Mtetra
.648 .748 .922 r
.27353 .48289 .28334 .49209 .29837 .48747 .2886 .47818 Mtetra
.65 .748 .921 r
.2886 .47818 .29837 .48747 .31349 .48265 .30377 .47336 Mtetra
.656 .75 .919 r
.30377 .47336 .31349 .48265 .32871 .47757 .31904 .46831 Mtetra
.645 .749 .925 r
.31904 .46831 .32871 .47757 .34393 .4741 .33438 .46363 Mtetra
.553 .691 .931 r
.33438 .46363 .34393 .4741 .3591 .47375 .34965 .46196 Mtetra
.477 .629 .919 r
.34965 .46196 .3591 .47375 .37429 .47556 .36492 .4626 Mtetra
.49 .613 .9 r
.36492 .4626 .37429 .47556 .3898 .47364 .38034 .46323 Mtetra
.641 .728 .912 r
.38034 .46323 .3898 .47364 .40565 .46543 .39612 .45861 Mtetra
.754 .836 .914 r
.39612 .45861 .40565 .46543 .42176 .45092 .41215 .44921 Mtetra
.824 .953 .902 r
.41215 .44921 .42176 .45092 .43787 .43675 .42835 .43606 Mtetra
.793 .975 .909 r
.42835 .43606 .43787 .43675 .45391 .42598 .44454 .42381 Mtetra
.73 .948 .951 r
.44454 .42381 .45391 .42598 .46994 .41831 .4607 .41445 Mtetra
.68 .904 .975 r
.4607 .41445 .46994 .41831 .486 .41286 .47689 .40722 Mtetra
.634 .849 .982 r
.47689 .40722 .486 .41286 .50217 .40752 .49314 .40182 Mtetra
.556 .822 .996 r
.49314 .40182 .50217 .40752 .51842 .40229 .50947 .39827 Mtetra
.371 .781 .982 r
.50947 .39827 .51842 .40229 .53479 .39929 .52592 .39688 Mtetra
.045 .597 .827 r
.52592 .39688 .53479 .39929 .5513 .39942 .54253 .39841 Mtetra
.122 0 0 r
.54253 .39841 .5513 .39942 .56801 .40304 .55932 .4009 Mtetra
.248 .744 .908 r
.55932 .4009 .56801 .40304 .58493 .40705 .57624 .39962 Mtetra
.662 .821 .96 r
.57624 .39962 .58493 .40705 .6019 .40469 .5932 .39349 Mtetra
.763 .767 .856 r
.5932 .39349 .6019 .40469 .61881 .39593 .61012 .38201 Mtetra
.746 .718 .826 r
.61012 .38201 .61881 .39593 .63567 .38332 .62708 .37047 Mtetra
.718 .727 .857 r
.62708 .37047 .63567 .38332 .65264 .3729 .64417 .36128 Mtetra
.665 .731 .899 r
.64417 .36128 .65264 .3729 .66981 .36566 .66146 .35516 Mtetra
.656 .752 .921 r
.66146 .35516 .66981 .36566 .68716 .36005 .67888 .34941 Mtetra
.661 .752 .918 r
.67888 .34941 .68716 .36005 .7046 .35418 .69639 .34341 Mtetra
.663 .752 .916 r
.69639 .34341 .7046 .35418 .72213 .34809 .714 .3373 Mtetra
.649 .748 .921 r
.714 .3373 .72213 .34809 .7398 .3424 .73176 .3317 Mtetra
.652 .752 .923 r
.73176 .3317 .7398 .3424 .7576 .33683 .74962 .32596 Mtetra
.659 .753 .919 r
.74962 .32596 .7576 .33683 .77548 .33089 .76757 .3199 Mtetra
.661 .752 .918 r
.76757 .3199 .77548 .33089 .79345 .32476 .78563 .31372 Mtetra
.652 .749 .921 r
.78563 .31372 .79345 .32476 .81157 .31887 .80383 .30785 Mtetra
.653 .751 .922 r
.80383 .30785 .81157 .31887 .82981 .31307 .82215 .30194 Mtetra
.658 .752 .919 r
.17449 .50367 .18471 .51259 .19931 .50764 .18913 .49873 Mtetra
.661 .754 .919 r
.18913 .49873 .19931 .50764 .214 .50266 .20387 .49364 Mtetra
.652 .75 .922 r
.20387 .49364 .214 .50266 .22873 .49798 .21866 .48884 Mtetra
.651 .749 .921 r
.21866 .48884 .22873 .49798 .24356 .4932 .23353 .48405 Mtetra
.657 .751 .92 r
.23353 .48405 .24356 .4932 .2585 .48811 .24851 .47904 Mtetra
.664 .756 .919 r
.24851 .47904 .2585 .48811 .27353 .48289 .2636 .47371 Mtetra
.653 .752 .922 r
.2636 .47371 .27353 .48289 .2886 .47818 .27874 .46876 Mtetra
.648 .746 .921 r
.27874 .46876 .2886 .47818 .30377 .47336 .29395 .46397 Mtetra
.652 .749 .921 r
.29395 .46397 .30377 .47336 .31904 .46831 .30927 .459 Mtetra
.658 .754 .921 r
.30927 .459 .31904 .46831 .33438 .46363 .32469 .45378 Mtetra
.612 .729 .928 r
.32469 .45378 .33438 .46363 .34965 .46196 .3401 .45015 Mtetra
.54 .66 .914 r
.3401 .45015 .34965 .46196 .36492 .4626 .35549 .44904 Mtetra
.492 .605 .893 r
.35549 .44904 .36492 .4626 .38034 .46323 .37093 .44967 Mtetra
.536 .626 .889 r
.37093 .44967 .38034 .46323 .39612 .45861 .38657 .44897 Mtetra
.654 .753 .922 r
.38657 .44897 .39612 .45861 .41215 .44921 .40252 .44371 Mtetra
.72 .868 .951 r
.40252 .44371 .41215 .44921 .42835 .43606 .41866 .4357 Mtetra
.73 .975 .924 r
.41866 .4357 .42835 .43606 .44454 .42381 .43493 .42522 Mtetra
.629 .962 .877 r
.43493 .42522 .44454 .42381 .4607 .41445 .45122 .41556 Mtetra
.528 .921 .872 r
.45122 .41556 .4607 .41445 .47689 .40722 .46754 .40785 Mtetra
.398 .854 .859 r
.46754 .40785 .47689 .40722 .49314 .40182 .4839 .40241 Mtetra
.218 .742 .793 r
.4839 .40241 .49314 .40182 .50947 .39827 .50034 .39925 Mtetra
0 0 0 r
.50034 .39925 .50947 .39827 .52592 .39688 .5169 .39806 Mtetra
.051 0 0 r
.5169 .39806 .52592 .39688 .54253 .39841 .53361 .39772 Mtetra
.268 .771 .864 r
.53361 .39772 .54253 .39841 .55932 .4009 .55045 .39491 Mtetra
.632 .85 .983 r
.55045 .39491 .55932 .4009 .57624 .39962 .56739 .38932 Mtetra
.749 .781 .879 r
.56739 .38932 .57624 .39962 .5932 .39349 .58435 .37909 Mtetra
.744 .711 .821 r
.58435 .37909 .5932 .39349 .61012 .38201 .60133 .36747 Mtetra
.72 .702 .833 r
.60133 .36747 .61012 .38201 .62708 .37047 .61841 .3576 Mtetra
.685 .716 .873 r
.61841 .3576 .62708 .37047 .64417 .36128 .63564 .35028 Mtetra
.654 .742 .914 r
.63564 .35028 .64417 .36128 .66146 .35516 .65302 .34459 Mtetra
.659 .754 .92 r
.65302 .34459 .66146 .35516 .67888 .34941 .6705 .33863 Mtetra
.663 .753 .917 r
.6705 .33863 .67888 .34941 .69639 .34341 .68808 .33249 Mtetra
.658 .749 .917 r
.68808 .33249 .69639 .34341 .714 .3373 .70578 .3265 Mtetra
.648 .749 .923 r
.70578 .3265 .714 .3373 .73176 .3317 .72362 .32089 Mtetra
.655 .754 .922 r
.72362 .32089 .73176 .3317 .74962 .32596 .74155 .31496 Mtetra
.66 .753 .919 r
.74155 .31496 .74962 .32596 .76757 .3199 .75958 .30878 Mtetra
.659 .751 .918 r
.75958 .30878 .76757 .3199 .78563 .31372 .77773 .30259 Mtetra
.651 .749 .922 r
.77773 .30259 .78563 .31372 .80383 .30785 .79601 .29672 Mtetra
.654 .752 .922 r
.79601 .29672 .80383 .30785 .82215 .30194 .81441 .29067 Mtetra
.656 .751 .92 r
.16416 .49465 .17449 .50367 .18913 .49873 .17885 .48971 Mtetra
.661 .754 .919 r
.17885 .48971 .18913 .49873 .20387 .49364 .19363 .48457 Mtetra
.656 .753 .921 r
.19363 .48457 .20387 .49364 .21866 .48884 .20848 .47959 Mtetra
.65 .748 .921 r
.20848 .47959 .21866 .48884 .23353 .48405 .2234 .47479 Mtetra
.654 .75 .92 r
.2234 .47479 .23353 .48405 .24851 .47904 .23842 .46981 Mtetra
.662 .754 .919 r
.23842 .46981 .24851 .47904 .2636 .47371 .25355 .46451 Mtetra
.66 .755 .921 r
.25355 .46451 .2636 .47371 .27874 .46876 .26876 .45926 Mtetra
.648 .747 .921 r
.26876 .45926 .27874 .46876 .29395 .46397 .28403 .45441 Mtetra
.651 .748 .92 r
.28403 .45441 .29395 .46397 .30927 .459 .2994 .44943 Mtetra
.655 .75 .919 r
.2994 .44943 .30927 .459 .32469 .45378 .31486 .44427 Mtetra
.652 .751 .922 r
.31486 .44427 .32469 .45378 .3401 .45015 .33041 .43919 Mtetra
.596 .702 .917 r
.33041 .43919 .3401 .45015 .35549 .44904 .34595 .43613 Mtetra
.551 .646 .897 r
.34595 .43613 .35549 .44904 .37093 .44967 .3615 .43478 Mtetra
.522 .599 .872 r
.3615 .43478 .37093 .44967 .38657 .44897 .37713 .43468 Mtetra
.554 .625 .877 r
.37713 .43468 .38657 .44897 .40252 .44371 .39296 .43336 Mtetra
.629 .733 .922 r
.39296 .43336 .40252 .44371 .41866 .4357 .40903 .42896 Mtetra
.67 .831 .961 r
.40903 .42896 .41866 .4357 .43493 .42522 .42526 .42276 Mtetra
.627 .922 .976 r
.42526 .42276 .43493 .42522 .45122 .41556 .44159 .41599 Mtetra
.48 .897 .891 r
.44159 .41599 .45122 .41556 .46754 .40785 .458 .40958 Mtetra
.325 .809 .786 r
.458 .40958 .46754 .40785 .4839 .40241 .47448 .40409 Mtetra
.251 .761 .756 r
.47448 .40409 .4839 .40241 .50034 .39925 .49105 .39953 Mtetra
.314 .804 .844 r
.49105 .39953 .50034 .39925 .5169 .39806 .50774 .39534 Mtetra
.513 .88 .979 r
.50774 .39534 .5169 .39806 .53361 .39772 .52454 .39058 Mtetra
.673 .833 .96 r
.52454 .39058 .53361 .39772 .55045 .39491 .54144 .384 Mtetra
.736 .767 .877 r
.54144 .384 .55045 .39491 .56739 .38932 .5584 .3743 Mtetra
.732 .699 .82 r
.5584 .3743 .56739 .38932 .58435 .37909 .57541 .36331 Mtetra
.711 .682 .821 r
.57541 .36331 .58435 .37909 .60133 .36747 .59249 .35358 Mtetra
.693 .704 .855 r
.59249 .35358 .60133 .36747 .61841 .3576 .60968 .34557 Mtetra
.658 .724 .897 r
.60968 .34557 .61841 .3576 .63564 .35028 .62702 .33962 Mtetra
.656 .753 .921 r
.62702 .33962 .63564 .35028 .65302 .34459 .64447 .33373 Mtetra
.66 .751 .918 r
.64447 .33373 .65302 .34459 .6705 .33863 .66203 .32767 Mtetra
.663 .751 .916 r
.66203 .32767 .6705 .33863 .68808 .33249 .67968 .32146 Mtetra
.652 .747 .919 r
.67968 .32146 .68808 .33249 .70578 .3265 .69747 .31566 Mtetra
.65 .752 .924 r
.69747 .31566 .70578 .3265 .72362 .32089 .71538 .3099 Mtetra
.657 .753 .921 r
.71538 .3099 .72362 .32089 .74155 .31496 .73339 .3038 Mtetra
.661 .753 .918 r
.73339 .3038 .74155 .31496 .75958 .30878 .75149 .29751 Mtetra
.656 .75 .919 r
.75149 .29751 .75958 .30878 .77773 .30259 .76973 .29139 Mtetra
.651 .751 .923 r
.76973 .29139 .77773 .30259 .79601 .29672 .7881 .28544 Mtetra
.655 .752 .921 r
.7881 .28544 .79601 .29672 .81441 .29067 .80657 .27926 Mtetra
.655 .75 .92 r
.15372 .48551 .16416 .49465 .17885 .48971 .16845 .48057 Mtetra
.659 .753 .919 r
.16845 .48057 .17885 .48971 .19363 .48457 .18328 .47544 Mtetra
.66 .754 .92 r
.18328 .47544 .19363 .48457 .20848 .47959 .1982 .47026 Mtetra
.651 .749 .921 r
.1982 .47026 .20848 .47959 .2234 .47479 .21317 .46538 Mtetra
.652 .749 .92 r
.21317 .46538 .2234 .47479 .23842 .46981 .22823 .46042 Mtetra
.657 .752 .919 r
.22823 .46042 .23842 .46981 .25355 .46451 .2434 .45524 Mtetra
.664 .757 .92 r
.2434 .45524 .25355 .46451 .26876 .45926 .25867 .4498 Mtetra
.654 .751 .921 r
.25867 .4498 .26876 .45926 .28403 .45441 .27401 .44468 Mtetra
.648 .745 .92 r
.27401 .44468 .28403 .45441 .2994 .44943 .28942 .43975 Mtetra
.653 .749 .92 r
.28942 .43975 .2994 .44943 .31486 .44427 .30493 .43462 Mtetra
.657 .752 .92 r
.30493 .43462 .31486 .44427 .33041 .43919 .32055 .42929 Mtetra
.648 .745 .92 r
.32055 .42929 .33041 .43919 .34595 .43613 .33624 .42427 Mtetra
.601 .689 .904 r
.33624 .42427 .34595 .43613 .3615 .43478 .35193 .42104 Mtetra
.572 .644 .883 r
.35193 .42104 .3615 .43478 .37713 .43468 .36768 .41895 Mtetra
.556 .605 .857 r
.36768 .41895 .37713 .43468 .39296 .43336 .38352 .41762 Mtetra
.569 .612 .856 r
.38352 .41762 .39296 .43336 .40903 .42896 .39952 .41578 Mtetra
.598 .668 .888 r
.39952 .41578 .40903 .42896 .42526 .42276 .41569 .4126 Mtetra
.633 .743 .927 r
.41569 .4126 .42526 .42276 .44159 .41599 .43203 .40793 Mtetra
.646 .797 .955 r
.43203 .40793 .44159 .41599 .458 .40958 .44848 .40256 Mtetra
.644 .824 .969 r
.44848 .40256 .458 .40958 .47448 .40409 .46505 .39701 Mtetra
.648 .825 .968 r
.46505 .39701 .47448 .40409 .49105 .39953 .48171 .3913 Mtetra
.673 .805 .946 r
.48171 .3913 .49105 .39953 .50774 .39534 .49849 .38487 Mtetra
.706 .766 .899 r
.49849 .38487 .50774 .39534 .52454 .39058 .51536 .37694 Mtetra
.716 .713 .847 r
.51536 .37694 .52454 .39058 .54144 .384 .53231 .36763 Mtetra
.709 .674 .814 r
.53231 .36763 .54144 .384 .5584 .3743 .54932 .35779 Mtetra
.698 .669 .818 r
.54932 .35779 .5584 .3743 .57541 .36331 .56641 .3487 Mtetra
.689 .692 .848 r
.56641 .3487 .57541 .36331 .59249 .35358 .58358 .34076 Mtetra
.66 .711 .885 r
.58358 .34076 .59249 .35358 .60968 .34557 .60089 .33461 Mtetra
.654 .747 .918 r
.60089 .33461 .60968 .34557 .62702 .33962 .6183 .32879 Mtetra
.659 .753 .919 r
.6183 .32879 .62702 .33962 .64447 .33373 .63583 .32275 Mtetra
.663 .752 .917 r
.63583 .32275 .64447 .33373 .66203 .32767 .65345 .31651 Mtetra
.658 .748 .917 r
.65345 .31651 .66203 .32767 .67968 .32146 .67119 .31045 Mtetra
.648 .749 .923 r
.67119 .31045 .67968 .32146 .69747 .31566 .68907 .30472 Mtetra
.654 .754 .923 r
.68907 .30472 .69747 .31566 .71538 .3099 .70704 .29871 Mtetra
.659 .753 .919 r
.70704 .29871 .71538 .3099 .73339 .3038 .72512 .29246 Mtetra
.66 .751 .918 r
.72512 .29246 .73339 .3038 .75149 .29751 .74331 .28612 Mtetra
.652 .748 .92 r
.74331 .28612 .75149 .29751 .76973 .29139 .76164 .28008 Mtetra
.653 .752 .923 r
.76164 .28008 .76973 .29139 .7881 .28544 .78009 .27399 Mtetra
.657 .752 .92 r
.78009 .27399 .7881 .28544 .80657 .27926 .79864 .26768 Mtetra
.653 .749 .92 r
.14318 .47623 .15372 .48551 .16845 .48057 .15795 .47131 Mtetra
.657 .752 .92 r
.15795 .47131 .16845 .48057 .18328 .47544 .17282 .46621 Mtetra
.661 .755 .92 r
.17282 .46621 .18328 .47544 .1982 .47026 .18779 .46093 Mtetra
.655 .752 .921 r
.18779 .46093 .1982 .47026 .21317 .46538 .20282 .45585 Mtetra
.651 .748 .921 r
.20282 .45585 .21317 .46538 .22823 .46042 .21793 .45089 Mtetra
.654 .75 .92 r
.21793 .45089 .22823 .46042 .2434 .45524 .23314 .44578 Mtetra
.661 .754 .919 r
.23314 .44578 .2434 .45524 .25867 .4498 .24846 .44039 Mtetra
.662 .757 .921 r
.24846 .44039 .25867 .4498 .27401 .44468 .26388 .4349 Mtetra
.65 .747 .92 r
.26388 .4349 .27401 .44468 .28942 .43975 .27934 .42984 Mtetra
.65 .745 .919 r
.27934 .42984 .28942 .43975 .30493 .43462 .2949 .42477 Mtetra
.653 .749 .92 r
.2949 .42477 .30493 .43462 .32055 .42929 .31057 .41954 Mtetra
.658 .754 .921 r
.31057 .41954 .32055 .42929 .33624 .42427 .32634 .41411 Mtetra
.651 .744 .918 r
.32634 .41411 .33624 .42427 .35193 .42104 .34219 .4089 Mtetra
.621 .695 .897 r
.34219 .4089 .35193 .42104 .36768 .41895 .35807 .40485 Mtetra
.597 .652 .874 r
.35807 .40485 .36768 .41895 .38352 .41762 .37402 .40173 Mtetra
.595 .624 .85 r
.37402 .40173 .38352 .41762 .39952 .41578 .39008 .39869 Mtetra
.594 .608 .836 r
.39008 .39869 .39952 .41578 .41569 .4126 .40626 .39567 Mtetra
.608 .618 .836 r
.40626 .39567 .41569 .4126 .43203 .40793 .42259 .39196 Mtetra
.628 .641 .844 r
.42259 .39196 .43203 .40793 .44848 .40256 .43906 .3873 Mtetra
.647 .66 .849 r
.43906 .3873 .44848 .40256 .46505 .39701 .45567 .38169 Mtetra
.664 .667 .843 r
.45567 .38169 .46505 .39701 .48171 .3913 .47239 .37512 Mtetra
.677 .662 .828 r
.47239 .37512 .48171 .3913 .49849 .38487 .48921 .36759 Mtetra
.682 .652 .813 r
.48921 .36759 .49849 .38487 .51536 .37694 .50612 .35934 Mtetra
.681 .648 .811 r
.50612 .35934 .51536 .37694 .53231 .36763 .52311 .35111 Mtetra
.684 .663 .824 r
.52311 .35111 .53231 .36763 .54932 .35779 .54018 .34294 Mtetra
.675 .684 .85 r
.54018 .34294 .54932 .35779 .56641 .3487 .55734 .33571 Mtetra
.658 .708 .885 r
.55734 .33571 .56641 .3487 .58358 .34076 .57461 .32964 Mtetra
.654 .745 .916 r
.57461 .32964 .58358 .34076 .60089 .33461 .592 .3238 Mtetra
.658 .754 .921 r
.592 .3238 .60089 .33461 .6183 .32879 .60948 .31774 Mtetra
.661 .751 .917 r
.60948 .31774 .6183 .32879 .63583 .32275 .62708 .31152 Mtetra
.661 .749 .915 r
.62708 .31152 .63583 .32275 .65345 .31651 .64478 .30528 Mtetra
.65 .746 .92 r
.64478 .30528 .65345 .31651 .67119 .31045 .66261 .29946 Mtetra
.651 .753 .925 r
.66261 .29946 .67119 .31045 .68907 .30472 .68056 .29355 Mtetra
.657 .754 .921 r
.68056 .29355 .68907 .30472 .70704 .29871 .69861 .28735 Mtetra
.66 .752 .918 r
.69861 .28735 .70704 .29871 .72512 .29246 .71676 .28097 Mtetra
.657 .749 .918 r
.71676 .28097 .72512 .29246 .74331 .28612 .73504 .27471 Mtetra
.651 .75 .922 r
.73504 .27471 .74331 .28612 .76164 .28008 .75346 .26865 Mtetra
.655 .753 .922 r
.75346 .26865 .76164 .28008 .78009 .27399 .77198 .26239 Mtetra
.658 .752 .92 r
.77198 .26239 .78009 .27399 .79864 .26768 .79061 .25594 Mtetra
.652 .749 .921 r
.13253 .46685 .14318 .47623 .15795 .47131 .14734 .46192 Mtetra
.655 .751 .92 r
.14734 .46192 .15795 .47131 .17282 .46621 .16225 .45683 Mtetra
.659 .753 .919 r
.16225 .45683 .17282 .46621 .18779 .46093 .17726 .45156 Mtetra
.66 .755 .92 r
.17726 .45156 .18779 .46093 .20282 .45585 .19237 .44624 Mtetra
.651 .748 .921 r
.19237 .44624 .20282 .45585 .21793 .45089 .20753 .4412 Mtetra
.652 .748 .92 r
.20753 .4412 .21793 .45089 .23314 .44578 .22278 .43612 Mtetra
.655 .751 .92 r
.22278 .43612 .23314 .44578 .24846 .44039 .23814 .43087 Mtetra
.662 .757 .92 r
.23814 .43087 .24846 .44039 .26388 .4349 .25361 .42532 Mtetra
.66 .756 .921 r
.25361 .42532 .26388 .4349 .27934 .42984 .26916 .41985 Mtetra
.65 .746 .919 r
.26916 .41985 .27934 .42984 .2949 .42477 .28477 .4147 Mtetra
.651 .746 .919 r
.28477 .4147 .2949 .42477 .31057 .41954 .30048 .40951 Mtetra
.653 .748 .92 r
.30048 .40951 .31057 .41954 .32634 .41411 .3163 .40418 Mtetra
.656 .753 .921 r
.3163 .40418 .32634 .41411 .34219 .4089 .33222 .39872 Mtetra
.657 .749 .918 r
.33222 .39872 .34219 .4089 .35807 .40485 .34823 .39319 Mtetra
.645 .716 .9 r
.34823 .39319 .35807 .40485 .37402 .40173 .36432 .38808 Mtetra
.626 .674 .876 r
.36432 .38808 .37402 .40173 .39008 .39869 .38048 .38367 Mtetra
.621 .651 .859 r
.38048 .38367 .39008 .39869 .40626 .39567 .39674 .3794 Mtetra
.625 .636 .841 r
.39674 .3794 .40626 .39567 .42259 .39196 .41312 .37482 Mtetra
.632 .629 .829 r
.41312 .37482 .42259 .39196 .43906 .3873 .42963 .36973 Mtetra
.641 .629 .822 r
.42963 .36973 .43906 .3873 .45567 .38169 .44626 .36405 Mtetra
.651 .633 .819 r
.44626 .36405 .45567 .38169 .47239 .37512 .46301 .35776 Mtetra
.66 .641 .821 r
.46301 .35776 .47239 .37512 .48921 .36759 .47986 .35095 Mtetra
.667 .655 .828 r
.47986 .35095 .48921 .36759 .50612 .35934 .4968 .34384 Mtetra
.669 .671 .843 r
.4968 .34384 .50612 .35934 .52311 .35111 .51384 .33685 Mtetra
.659 .687 .865 r
.51384 .33685 .52311 .35111 .54018 .34294 .53097 .33056 Mtetra
.654 .719 .897 r
.53097 .33056 .54018 .34294 .55734 .33571 .5482 .32469 Mtetra
.656 .748 .918 r
.5482 .32469 .55734 .33571 .57461 .32964 .56555 .31875 Mtetra
.658 .754 .92 r
.56555 .31875 .57461 .32964 .592 .3238 .583 .31268 Mtetra
.661 .751 .917 r
.583 .31268 .592 .3238 .60948 .31774 .60056 .30645 Mtetra
.661 .749 .915 r
.60056 .30645 .60948 .31774 .62708 .31152 .61823 .30017 Mtetra
.652 .746 .918 r
.61823 .30017 .62708 .31152 .64478 .30528 .63602 .29423 Mtetra
.65 .753 .925 r
.63602 .29423 .64478 .30528 .66261 .29946 .65393 .28835 Mtetra
.656 .755 .923 r
.65393 .28835 .66261 .29946 .68056 .29355 .67194 .28216 Mtetra
.659 .752 .919 r
.67194 .28216 .68056 .29355 .69861 .28735 .69006 .27579 Mtetra
.66 .75 .917 r
.69006 .27579 .69861 .28735 .71676 .28097 .7083 .26937 Mtetra
.652 .748 .92 r
.7083 .26937 .71676 .28097 .73504 .27471 .72668 .26323 Mtetra
.653 .752 .923 r
.72668 .26323 .73504 .27471 .75346 .26865 .74517 .25702 Mtetra
.656 .752 .921 r
.74517 .25702 .75346 .26865 .77198 .26239 .76377 .25062 Mtetra
.66 .752 .919 r
.76377 .25062 .77198 .26239 .79061 .25594 .78248 .24404 Mtetra
.652 .749 .921 r
.12176 .45739 .13253 .46685 .14734 .46192 .13662 .45238 Mtetra
.653 .749 .92 r
.13662 .45238 .14734 .46192 .16225 .45683 .15157 .44732 Mtetra
.656 .752 .92 r
.15157 .44732 .16225 .45683 .17726 .45156 .16662 .4421 Mtetra
.661 .755 .92 r
.16662 .4421 .17726 .45156 .19237 .44624 .18178 .43669 Mtetra
.657 .753 .921 r
.18178 .43669 .19237 .44624 .20753 .4412 .19701 .43139 Mtetra
.651 .747 .92 r
.19701 .43139 .20753 .4412 .22278 .43612 .21231 .42628 Mtetra
.653 .749 .92 r
.21231 .42628 .22278 .43612 .23814 .43087 .22771 .42107 Mtetra
.656 .752 .92 r
.22771 .42107 .23814 .43087 .25361 .42532 .24322 .41569 Mtetra
.662 .758 .921 r
.24322 .41569 .25361 .42532 .26916 .41985 .25883 .41005 Mtetra
.659 .755 .921 r
.25883 .41005 .26916 .41985 .28477 .4147 .27453 .40451 Mtetra
.651 .745 .919 r
.27453 .40451 .28477 .4147 .30048 .40951 .2903 .39925 Mtetra
.65 .745 .919 r
.2903 .39925 .30048 .40951 .3163 .40418 .30616 .39397 Mtetra
.654 .748 .919 r
.30616 .39397 .3163 .40418 .33222 .39872 .32213 .38853 Mtetra
.654 .75 .921 r
.32213 .38853 .33222 .39872 .34823 .39319 .3382 .38306 Mtetra
.658 .754 .921 r
.3382 .38306 .34823 .39319 .36432 .38808 .35437 .3774 Mtetra
.657 .743 .914 r
.35437 .3774 .36432 .38808 .38048 .38367 .37064 .37174 Mtetra
.652 .718 .897 r
.37064 .37174 .38048 .38367 .39674 .3794 .387 .36621 Mtetra
.649 .695 .88 r
.387 .36621 .39674 .3794 .41312 .37482 .40347 .36071 Mtetra
.648 .681 .867 r
.40347 .36071 .41312 .37482 .42963 .36973 .42003 .35512 Mtetra
.65 .675 .861 r
.42003 .35512 .42963 .36973 .44626 .36405 .43671 .34937 Mtetra
.652 .676 .86 r
.43671 .34937 .44626 .36405 .46301 .35776 .45349 .34344 Mtetra
.654 .683 .865 r
.45349 .34344 .46301 .35776 .47986 .35095 .47037 .33743 Mtetra
.655 .698 .878 r
.47037 .33743 .47986 .35095 .4968 .34384 .48736 .33144 Mtetra
.654 .719 .896 r
.48736 .33144 .4968 .34384 .51384 .33685 .50445 .32557 Mtetra
.654 .742 .915 r
.50445 .32557 .51384 .33685 .53097 .33056 .52165 .31971 Mtetra
.658 .754 .921 r
.52165 .31971 .53097 .33056 .5482 .32469 .53896 .31366 Mtetra
.658 .752 .919 r
.53896 .31366 .5482 .32469 .56555 .31875 .55637 .30756 Mtetra
.661 .751 .917 r
.55637 .30756 .56555 .31875 .583 .31268 .5739 .3013 Mtetra
.66 .748 .915 r
.5739 .3013 .583 .31268 .60056 .30645 .59153 .29502 Mtetra
.653 .746 .918 r
.59153 .29502 .60056 .30645 .61823 .30017 .60928 .28902 Mtetra
.649 .752 .924 r
.60928 .28902 .61823 .30017 .63602 .29423 .62715 .28311 Mtetra
.655 .756 .924 r
.62715 .28311 .63602 .29423 .65393 .28835 .64513 .27692 Mtetra
.658 .753 .919 r
.64513 .27692 .65393 .28835 .67194 .28216 .66322 .27055 Mtetra
.66 .751 .917 r
.66322 .27055 .67194 .28216 .69006 .27579 .68142 .26408 Mtetra
.655 .748 .919 r
.68142 .26408 .69006 .27579 .7083 .26937 .69975 .2578 Mtetra
.651 .751 .923 r
.69975 .2578 .7083 .26937 .72668 .26323 .71821 .25161 Mtetra
.655 .753 .922 r
.71821 .25161 .72668 .26323 .74517 .25702 .73678 .24522 Mtetra
.658 .752 .92 r
.73678 .24522 .74517 .25702 .76377 .25062 .75546 .23865 Mtetra
.659 .751 .918 r
.75546 .23865 .76377 .25062 .78248 .24404 .77426 .23203 Mtetra
.656 .753 .921 r
.11086 .44793 .12176 .45739 .13662 .45238 .12578 .44273 Mtetra
.652 .749 .921 r
.12578 .44273 .13662 .45238 .15157 .44732 .14078 .43765 Mtetra
.654 .75 .92 r
.14078 .43765 .15157 .44732 .16662 .4421 .15587 .43245 Mtetra
.658 .752 .92 r
.15587 .43245 .16662 .4421 .18178 .43669 .17107 .42709 Mtetra
.66 .755 .92 r
.17107 .42709 .18178 .43669 .19701 .43139 .18637 .4216 Mtetra
.655 .751 .921 r
.18637 .4216 .19701 .43139 .21231 .42628 .20174 .41628 Mtetra
.651 .747 .92 r
.20174 .41628 .21231 .42628 .22771 .42107 .21718 .41107 Mtetra
.653 .749 .92 r
.21718 .41107 .22771 .42107 .24322 .41569 .23273 .40575 Mtetra
.656 .752 .92 r
.23273 .40575 .24322 .41569 .25883 .41005 .24838 .40028 Mtetra
.662 .758 .922 r
.24838 .40028 .25883 .41005 .27453 .40451 .26415 .39457 Mtetra
.66 .756 .921 r
.26415 .39457 .27453 .40451 .2903 .39925 .28 .38889 Mtetra
.652 .746 .918 r
.28 .38889 .2903 .39925 .30616 .39397 .29592 .38348 Mtetra
.651 .744 .918 r
.29592 .38348 .30616 .39397 .32213 .38853 .31194 .37808 Mtetra
.653 .747 .919 r
.31194 .37808 .32213 .38853 .3382 .38306 .32807 .37259 Mtetra
.654 .748 .919 r
.32807 .37259 .3382 .38306 .35437 .3774 .34429 .367 Mtetra
.654 .751 .921 r
.34429 .367 .35437 .3774 .37064 .37174 .36062 .36137 Mtetra
.655 .753 .922 r
.36062 .36137 .37064 .37174 .387 .36621 .37705 .3557 Mtetra
.657 .752 .92 r
.37705 .3557 .387 .36621 .40347 .36071 .39358 .34991 Mtetra
.657 .747 .917 r
.39358 .34991 .40347 .36071 .42003 .35512 .41022 .34409 Mtetra
.656 .744 .915 r
.41022 .34409 .42003 .35512 .43671 .34937 .42695 .33827 Mtetra
.655 .743 .915 r
.42695 .33827 .43671 .34937 .45349 .34344 .44379 .33244 Mtetra
.655 .747 .917 r
.44379 .33244 .45349 .34344 .47037 .33743 .46074 .32658 Mtetra
.657 .752 .92 r
.46074 .32658 .47037 .33743 .48736 .33144 .4778 .3206 Mtetra
.657 .754 .921 r
.4778 .3206 .48736 .33144 .50445 .32557 .49496 .31458 Mtetra
.657 .752 .92 r
.49496 .31458 .50445 .32557 .52165 .31971 .51223 .30851 Mtetra
.659 .75 .917 r
.51223 .30851 .52165 .31971 .53896 .31366 .5296 .30235 Mtetra
.66 .749 .916 r
.5296 .30235 .53896 .31366 .55637 .30756 .54709 .29607 Mtetra
.659 .747 .915 r
.54709 .29607 .55637 .30756 .5739 .3013 .56469 .28981 Mtetra
.652 .745 .918 r
.56469 .28981 .5739 .3013 .59153 .29502 .5824 .28382 Mtetra
.65 .752 .924 r
.5824 .28382 .59153 .29502 .60928 .28902 .60023 .27786 Mtetra
.655 .757 .924 r
.60023 .27786 .60928 .28902 .62715 .28311 .61817 .27164 Mtetra
.658 .753 .92 r
.61817 .27164 .62715 .28311 .64513 .27692 .63623 .26526 Mtetra
.66 .751 .918 r
.63623 .26526 .64513 .27692 .66322 .27055 .65439 .25876 Mtetra
.657 .749 .918 r
.65439 .25876 .66322 .27055 .68142 .26408 .67268 .25236 Mtetra
.652 .75 .922 r
.67268 .25236 .68142 .26408 .69975 .2578 .6911 .24614 Mtetra
.654 .753 .923 r
.6911 .24614 .69975 .2578 .71821 .25161 .70963 .23976 Mtetra
.657 .752 .92 r
.70963 .23976 .71821 .25161 .73678 .24522 .72828 .23322 Mtetra
.659 .752 .919 r
.72828 .23322 .73678 .24522 .75546 .23865 .74705 .22653 Mtetra
.655 .749 .919 r
.74705 .22653 .75546 .23865 .77426 .23203 .76595 .21997 Mtetra
.659 .754 .92 r
.09983 .4384 .11086 .44793 .12578 .44273 .11482 .43304 Mtetra
.654 .75 .921 r
.11482 .43304 .12578 .44273 .14078 .43765 .12987 .42783 Mtetra
.652 .748 .92 r
.12987 .42783 .14078 .43765 .15587 .43245 .14501 .42265 Mtetra
.655 .751 .92 r
.14501 .42265 .15587 .43245 .17107 .42709 .16025 .41732 Mtetra
.659 .754 .92 r
.16025 .41732 .17107 .42709 .18637 .4216 .17559 .41184 Mtetra
.66 .755 .921 r
.17559 .41184 .18637 .4216 .20174 .41628 .19103 .40627 Mtetra
.654 .75 .92 r
.19103 .40627 .20174 .41628 .21718 .41107 .20654 .40089 Mtetra
.651 .747 .919 r
.20654 .40089 .21718 .41107 .23273 .40575 .22214 .39558 Mtetra
.654 .749 .92 r
.22214 .39558 .23273 .40575 .24838 .40028 .23784 .39016 Mtetra
.656 .752 .921 r
.23784 .39016 .24838 .40028 .26415 .39457 .25364 .38462 Mtetra
.66 .758 .922 r
.25364 .38462 .26415 .39457 .28 .38889 .26955 .37887 Mtetra
.661 .758 .922 r
.26955 .37887 .28 .38889 .29592 .38348 .28556 .37308 Mtetra
.656 .75 .919 r
.28556 .37308 .29592 .38348 .31194 .37808 .30165 .36741 Mtetra
.653 .744 .917 r
.30165 .36741 .31194 .37808 .32807 .37259 .31783 .36186 Mtetra
.652 .744 .917 r
.31783 .36186 .32807 .37259 .34429 .367 .33411 .35628 Mtetra
.653 .746 .918 r
.33411 .35628 .34429 .367 .36062 .36137 .35049 .35064 Mtetra
.655 .748 .918 r
.35049 .35064 .36062 .36137 .37705 .3557 .36698 .3449 Mtetra
.36698 .3449 .37705 .3557 .39358 .34991 .38358 .3391 Mtetra
.655 .749 .919 r
.38358 .3391 .39358 .34991 .41022 .34409 .40027 .33326 Mtetra
.656 .75 .919 r
.40027 .33326 .41022 .34409 .42695 .33827 .41708 .32737 Mtetra
.41708 .32737 .42695 .33827 .44379 .33244 .43399 .32143 Mtetra
.43399 .32143 .44379 .33244 .46074 .32658 .451 .31544 Mtetra
.657 .749 .918 r
.451 .31544 .46074 .32658 .4778 .3206 .46812 .3094 Mtetra
.658 .749 .917 r
.46812 .3094 .4778 .3206 .49496 .31458 .48535 .30325 Mtetra
.659 .748 .916 r
.48535 .30325 .49496 .31458 .51223 .30851 .50269 .29703 Mtetra
.659 .747 .915 r
.50269 .29703 .51223 .30851 .5296 .30235 .52014 .29079 Mtetra
.655 .745 .916 r
.52014 .29079 .5296 .30235 .54709 .29607 .5377 .28466 Mtetra
.651 .748 .921 r
.5377 .28466 .54709 .29607 .56469 .28981 .55538 .27865 Mtetra
.651 .755 .925 r
.55538 .27865 .56469 .28981 .5824 .28382 .57316 .27259 Mtetra
.656 .757 .924 r
.57316 .27259 .5824 .28382 .60023 .27786 .59107 .26632 Mtetra
.658 .753 .92 r
.59107 .26632 .60023 .27786 .61817 .27164 .60908 .25992 Mtetra
.66 .751 .918 r
.60908 .25992 .61817 .27164 .63623 .26526 .62721 .25339 Mtetra
.657 .749 .917 r
.62721 .25339 .63623 .26526 .65439 .25876 .64546 .24693 Mtetra
.652 .749 .921 r
.64546 .24693 .65439 .25876 .67268 .25236 .66384 .24065 Mtetra
.653 .753 .923 r
.66384 .24065 .67268 .25236 .6911 .24614 .68234 .23427 Mtetra
.656 .753 .921 r
.68234 .23427 .6911 .24614 .70963 .23976 .70095 .22773 Mtetra
.659 .752 .919 r
.70095 .22773 .70963 .23976 .72828 .23322 .71968 .22102 Mtetra
.657 .75 .918 r
.71968 .22102 .72828 .23322 .74705 .22653 .73854 .21434 Mtetra
.653 .75 .921 r
.73854 .21434 .74705 .22653 .76595 .21997 .75753 .2078 Mtetra
.659 .753 .92 r
.08869 .42874 .09983 .4384 .11482 .43304 .10373 .42334 Mtetra
.658 .754 .92 r
.10373 .42334 .11482 .43304 .12987 .42783 .11885 .41791 Mtetra
.653 .749 .92 r
.11885 .41791 .12987 .42783 .14501 .42265 .13404 .41266 Mtetra
.13404 .41266 .14501 .42265 .16025 .41732 .14932 .40736 Mtetra
.656 .751 .92 r
.14932 .40736 .16025 .41732 .17559 .41184 .1647 .40193 Mtetra
.659 .754 .921 r
.1647 .40193 .17559 .41184 .19103 .40627 .18019 .39635 Mtetra
.66 .755 .921 r
.18019 .39635 .19103 .40627 .20654 .40089 .19578 .3907 Mtetra
.654 .75 .92 r
.19578 .3907 .20654 .40089 .22214 .39558 .21144 .38522 Mtetra
.652 .747 .919 r
.21144 .38522 .22214 .39558 .23784 .39016 .22718 .37979 Mtetra
.653 .748 .92 r
.22718 .37979 .23784 .39016 .25364 .38462 .24303 .37429 Mtetra
.655 .751 .92 r
.24303 .37429 .25364 .38462 .26955 .37887 .25898 .36868 Mtetra
.658 .756 .922 r
.25898 .36868 .26955 .37887 .28556 .37308 .27504 .36294 Mtetra
.66 .759 .923 r
.27504 .36294 .28556 .37308 .30165 .36741 .2912 .35706 Mtetra
.659 .756 .921 r
.2912 .35706 .30165 .36741 .31783 .36186 .30746 .35119 Mtetra
.657 .75 .918 r
.30746 .35119 .31783 .36186 .33411 .35628 .32382 .34536 Mtetra
.654 .745 .917 r
.32382 .34536 .33411 .35628 .35049 .35064 .34026 .3396 Mtetra
.654 .744 .916 r
.34026 .3396 .35049 .35064 .36698 .3449 .35681 .33382 Mtetra
.654 .745 .916 r
.35681 .33382 .36698 .3449 .38358 .3391 .37347 .32799 Mtetra
.655 .745 .916 r
.37347 .32799 .38358 .3391 .40027 .33326 .39023 .32209 Mtetra
.656 .746 .916 r
.39023 .32209 .40027 .33326 .41708 .32737 .40709 .31613 Mtetra
.40709 .31613 .41708 .32737 .43399 .32143 .42407 .31011 Mtetra
.657 .746 .916 r
.42407 .31011 .43399 .32143 .451 .31544 .44115 .30402 Mtetra
.657 .746 .915 r
.44115 .30402 .451 .31544 .46812 .3094 .45834 .29788 Mtetra
.657 .745 .915 r
.45834 .29788 .46812 .3094 .48535 .30325 .47564 .29171 Mtetra
.654 .745 .916 r
.47564 .29171 .48535 .30325 .50269 .29703 .49305 .28561 Mtetra
.652 .748 .92 r
.49305 .28561 .50269 .29703 .52014 .29079 .51057 .27956 Mtetra
.652 .753 .924 r
.51057 .27956 .52014 .29079 .5377 .28466 .5282 .2735 Mtetra
.654 .757 .925 r
.5282 .2735 .5377 .28466 .55538 .27865 .54595 .2673 Mtetra
.656 .756 .923 r
.54595 .2673 .55538 .27865 .57316 .27259 .56381 .26096 Mtetra
.658 .752 .919 r
.56381 .26096 .57316 .27259 .59107 .26632 .58179 .25451 Mtetra
.659 .75 .917 r
.58179 .25451 .59107 .26632 .60908 .25992 .59988 .24797 Mtetra
.657 .748 .917 r
.59988 .24797 .60908 .25992 .62721 .25339 .6181 .24148 Mtetra
.652 .749 .92 r
.6181 .24148 .62721 .25339 .64546 .24693 .63643 .23515 Mtetra
.653 .753 .923 r
.63643 .23515 .64546 .24693 .66384 .24065 .65489 .22875 Mtetra
.656 .754 .922 r
.65489 .22875 .66384 .24065 .68234 .23427 .67347 .22218 Mtetra
.658 .752 .919 r
.67347 .22218 .68234 .23427 .70095 .22773 .69216 .21546 Mtetra
.659 .75 .918 r
.69216 .21546 .70095 .22773 .71968 .22102 .71098 .20869 Mtetra
.654 .749 .92 r
.71098 .20869 .71968 .22102 .73854 .21434 .72993 .20209 Mtetra
.653 .752 .922 r
.72993 .20209 .73854 .21434 .75753 .2078 .74901 .19545 Mtetra
.657 .752 .92 r
.07743 .41894 .08869 .42874 .10373 .42334 .09251 .41354 Mtetra
.659 .754 .92 r
.09251 .41354 .10373 .42334 .11885 .41791 .10769 .40803 Mtetra
.657 .753 .921 r
.10769 .40803 .11885 .41791 .13404 .41266 .12294 .40255 Mtetra
.652 .748 .92 r
.12294 .40255 .13404 .41266 .14932 .40736 .13827 .39721 Mtetra
.653 .749 .92 r
.13827 .39721 .14932 .40736 .1647 .40193 .1537 .39181 Mtetra
.656 .751 .92 r
.1537 .39181 .1647 .40193 .18019 .39635 .16923 .38628 Mtetra
.658 .754 .921 r
.16923 .38628 .18019 .39635 .19578 .3907 .18487 .38061 Mtetra
.659 .756 .921 r
.18487 .38061 .19578 .3907 .21144 .38522 .2006 .37488 Mtetra
.656 .751 .92 r
.2006 .37488 .21144 .38522 .22718 .37979 .21642 .36924 Mtetra
.652 .747 .919 r
.21642 .36924 .22718 .37979 .24303 .37429 .23232 .3637 Mtetra
.653 .747 .919 r
.23232 .3637 .24303 .37429 .25898 .36868 .24832 .35812 Mtetra
.654 .75 .92 r
.24832 .35812 .25898 .36868 .27504 .36294 .26442 .35244 Mtetra
.656 .753 .921 r
.26442 .35244 .27504 .36294 .2912 .35706 .28063 .34667 Mtetra
.657 .757 .923 r
.28063 .34667 .2912 .35706 .30746 .35119 .29695 .34082 Mtetra
.659 .759 .924 r
.29695 .34082 .30746 .35119 .32382 .34536 .31337 .33486 Mtetra
.658 .758 .923 r
.31337 .33486 .32382 .34536 .34026 .3396 .32989 .32888 Mtetra
.658 .754 .921 r
.32989 .32888 .34026 .3396 .35681 .33382 .34651 .3229 Mtetra
.657 .751 .919 r
.34651 .3229 .35681 .33382 .37347 .32799 .36323 .3169 Mtetra
.656 .749 .918 r
.36323 .3169 .37347 .32799 .39023 .32209 .38006 .31089 Mtetra
.656 .748 .918 r
.38006 .31089 .39023 .32209 .40709 .31613 .39699 .30486 Mtetra
.655 .748 .918 r
.39699 .30486 .40709 .31613 .42407 .31011 .41403 .29881 Mtetra
.655 .749 .919 r
.41403 .29881 .42407 .31011 .44115 .30402 .43118 .29275 Mtetra
.654 .75 .92 r
.43118 .29275 .44115 .30402 .45834 .29788 .44844 .28667 Mtetra
.653 .753 .923 r
.44844 .28667 .45834 .29788 .47564 .29171 .4658 .28059 Mtetra
.653 .756 .925 r
.4658 .28059 .47564 .29171 .49305 .28561 .48328 .27448 Mtetra
.655 .758 .926 r
.48328 .27448 .49305 .28561 .51057 .27956 .50088 .26826 Mtetra
.656 .756 .924 r
.50088 .26826 .51057 .27956 .5282 .2735 .51859 .26195 Mtetra
.657 .753 .921 r
.51859 .26195 .5282 .2735 .54595 .2673 .53641 .25555 Mtetra
.659 .751 .918 r
.53641 .25555 .54595 .2673 .56381 .26096 .55435 .24905 Mtetra
.659 .749 .917 r
.55435 .24905 .56381 .26096 .58179 .25451 .5724 .24249 Mtetra
.656 .748 .918 r
.5724 .24249 .58179 .25451 .59988 .24797 .59058 .23602 Mtetra
.652 .749 .921 r
.59058 .23602 .59988 .24797 .6181 .24148 .60887 .22965 Mtetra
.653 .754 .923 r
.60887 .22965 .6181 .24148 .63643 .23515 .62729 .2232 Mtetra
.656 .754 .922 r
.62729 .2232 .63643 .23515 .65489 .22875 .64583 .2166 Mtetra
.658 .752 .92 r
.64583 .2166 .65489 .22875 .67347 .22218 .66448 .20986 Mtetra
.659 .751 .918 r
.66448 .20986 .67347 .22218 .69216 .21546 .68326 .20304 Mtetra
.655 .749 .919 r
.68326 .20304 .69216 .21546 .71098 .20869 .70217 .19636 Mtetra
.653 .752 .922 r
.70217 .19636 .71098 .20869 .72993 .20209 .72122 .1897 Mtetra
.655 .753 .922 r
.72122 .1897 .72993 .20209 .74901 .19545 .74038 .18292 Mtetra
.655 .751 .92 r
.06606 .40898 .07743 .41894 .09251 .41354 .08117 .40358 Mtetra
.657 .752 .92 r
.08117 .40358 .09251 .41354 .10769 .40803 .09639 .39808 Mtetra
.659 .754 .921 r
.09639 .39808 .10769 .40803 .12294 .40255 .11171 .39248 Mtetra
.657 .752 .92 r
.11171 .39248 .12294 .40255 .13827 .39721 .12711 .38692 Mtetra
.653 .748 .92 r
.12711 .38692 .13827 .39721 .1537 .39181 .14259 .38148 Mtetra
.653 .749 .92 r
.14259 .38148 .1537 .39181 .16923 .38628 .15816 .37598 Mtetra
.656 .751 .92 r
.15816 .37598 .16923 .38628 .18487 .38061 .17384 .37036 Mtetra
.658 .754 .921 r
.17384 .37036 .18487 .38061 .2006 .37488 .18962 .36463 Mtetra
.659 .756 .921 r
.18962 .36463 .2006 .37488 .21642 .36924 .20551 .3588 Mtetra
.658 .753 .92 r
.20551 .3588 .21642 .36924 .23232 .3637 .22149 .35299 Mtetra
.654 .747 .919 r
.22149 .35299 .23232 .3637 .24832 .35812 .23755 .34731 Mtetra
.653 .747 .918 r
.23755 .34731 .24832 .35812 .26442 .35244 .2537 .34161 Mtetra
.653 .748 .919 r
.2537 .34161 .26442 .35244 .28063 .34667 .26997 .33586 Mtetra
.655 .75 .92 r
.26997 .33586 .28063 .34667 .29695 .34082 .28633 .33003 Mtetra
.655 .752 .921 r
.28633 .33003 .29695 .34082 .31337 .33486 .30281 .32414 Mtetra
.656 .755 .923 r
.30281 .32414 .31337 .33486 .32989 .32888 .31938 .31819 Mtetra
.656 .757 .924 r
.31938 .31819 .32989 .32888 .34651 .3229 .33607 .3122 Mtetra
.656 .758 .925 r
.33607 .3122 .34651 .3229 .36323 .3169 .35286 .30616 Mtetra
.656 .759 .925 r
.35286 .30616 .36323 .3169 .38006 .31089 .36975 .30007 Mtetra
.656 .758 .925 r
.36975 .30007 .38006 .31089 .39699 .30486 .38675 .29397 Mtetra
.655 .758 .926 r
.38675 .29397 .39699 .30486 .41403 .29881 .40386 .28786 Mtetra
.40386 .28786 .41403 .29881 .43118 .29275 .42108 .2817 Mtetra
.656 .758 .925 r
.42108 .2817 .43118 .29275 .44844 .28667 .43841 .27549 Mtetra
.656 .757 .924 r
.43841 .27549 .44844 .28667 .4658 .28059 .45585 .26923 Mtetra
.656 .755 .923 r
.45585 .26923 .4658 .28059 .48328 .27448 .47341 .26291 Mtetra
.657 .752 .92 r
.47341 .26291 .48328 .27448 .50088 .26826 .49107 .25653 Mtetra
.658 .751 .919 r
.49107 .25653 .50088 .26826 .51859 .26195 .50886 .25006 Mtetra
.658 .749 .917 r
.50886 .25006 .51859 .26195 .53641 .25555 .52676 .24353 Mtetra
.658 .748 .917 r
.52676 .24353 .53641 .25555 .55435 .24905 .54477 .23698 Mtetra
.654 .747 .918 r
.54477 .23698 .55435 .24905 .5724 .24249 .56291 .23055 Mtetra
.653 .751 .922 r
.56291 .23055 .5724 .24249 .59058 .23602 .58116 .22414 Mtetra
.654 .754 .923 r
.58116 .22414 .59058 .23602 .60887 .22965 .59954 .21762 Mtetra
.656 .754 .922 r
.59954 .21762 .60887 .22965 .62729 .2232 .61803 .21098 Mtetra
.658 .752 .92 r
.61803 .21098 .62729 .2232 .64583 .2166 .63665 .2042 Mtetra
.659 .751 .918 r
.63665 .2042 .64583 .2166 .66448 .20986 .65539 .19735 Mtetra
.655 .749 .919 r
.65539 .19735 .66448 .20986 .68326 .20304 .67426 .19062 Mtetra
.653 .751 .922 r
.67426 .19062 .68326 .20304 .70217 .19636 .69326 .18392 Mtetra
.655 .753 .922 r
.69326 .18392 .70217 .19636 .72122 .1897 .71239 .1771 Mtetra
.656 .752 .921 r
.71239 .1771 .72122 .1897 .74038 .18292 .73164 .17017 Mtetra
.653 .749 .92 r
.05456 .39885 .06606 .40898 .08117 .40358 .06972 .39347 Mtetra
.655 .751 .92 r
.06972 .39347 .08117 .40358 .09639 .39808 .08498 .38796 Mtetra
.657 .753 .92 r
.08498 .38796 .09639 .39808 .11171 .39248 .10034 .38235 Mtetra
.659 .754 .921 r
.10034 .38235 .11171 .39248 .12711 .38692 .1158 .37666 Mtetra
.657 .752 .92 r
.1158 .37666 .12711 .38692 .14259 .38148 .13135 .37101 Mtetra
.653 .748 .92 r
.13135 .37101 .14259 .38148 .15816 .37598 .14698 .36546 Mtetra
.14698 .36546 .15816 .37598 .17384 .37036 .1627 .35987 Mtetra
.655 .751 .92 r
.1627 .35987 .17384 .37036 .18962 .36463 .17853 .35416 Mtetra
.656 .753 .921 r
.17853 .35416 .18962 .36463 .20551 .3588 .19446 .34838 Mtetra
.659 .756 .922 r
.19446 .34838 .20551 .3588 .22149 .35299 .2105 .34247 Mtetra
.659 .755 .921 r
.2105 .34247 .22149 .35299 .23755 .34731 .22663 .33653 Mtetra
.657 .751 .919 r
.22663 .33653 .23755 .34731 .2537 .34161 .24287 .33062 Mtetra
.654 .747 .918 r
.24287 .33062 .2537 .34161 .26997 .33586 .25919 .32478 Mtetra
.25919 .32478 .26997 .33586 .28633 .33003 .27561 .31892 Mtetra
.27561 .31892 .28633 .33003 .30281 .32414 .29214 .31301 Mtetra
.654 .749 .919 r
.29214 .31301 .30281 .32414 .31938 .31819 .30878 .30704 Mtetra
.655 .75 .919 r
.30878 .30704 .31938 .31819 .33607 .3122 .32552 .30101 Mtetra
.655 .751 .92 r
.32552 .30101 .33607 .3122 .35286 .30616 .34237 .29493 Mtetra
.656 .751 .92 r
.34237 .29493 .35286 .30616 .36975 .30007 .35933 .28881 Mtetra
.656 .752 .921 r
.35933 .28881 .36975 .30007 .38675 .29397 .3764 .28264 Mtetra
.3764 .28264 .38675 .29397 .40386 .28786 .39358 .27642 Mtetra
.656 .751 .92 r
.39358 .27642 .40386 .28786 .42108 .2817 .41087 .27015 Mtetra
.41087 .27015 .42108 .2817 .43841 .27549 .42827 .26383 Mtetra
.657 .75 .919 r
.42827 .26383 .43841 .27549 .45585 .26923 .44579 .25745 Mtetra
.657 .75 .918 r
.44579 .25745 .45585 .26923 .47341 .26291 .46341 .251 Mtetra
.658 .749 .917 r
.46341 .251 .47341 .26291 .49107 .25653 .48116 .24451 Mtetra
.657 .748 .917 r
.48116 .24451 .49107 .25653 .50886 .25006 .49901 .23798 Mtetra
.655 .747 .918 r
.49901 .23798 .50886 .25006 .52676 .24353 .51699 .23152 Mtetra
.653 .75 .921 r
.51699 .23152 .52676 .24353 .54477 .23698 .53508 .22509 Mtetra
.653 .754 .923 r
.53508 .22509 .54477 .23698 .56291 .23055 .55329 .21861 Mtetra
.655 .755 .923 r
.55329 .21861 .56291 .23055 .58116 .22414 .57163 .21201 Mtetra
.656 .753 .921 r
.57163 .21201 .58116 .22414 .59954 .21762 .59008 .20532 Mtetra
.658 .752 .919 r
.59008 .20532 .59954 .21762 .61803 .21098 .60866 .1985 Mtetra
.658 .75 .918 r
.60866 .1985 .61803 .21098 .63665 .2042 .62736 .19162 Mtetra
.655 .748 .919 r
.62736 .19162 .63665 .2042 .65539 .19735 .64619 .18485 Mtetra
.653 .751 .921 r
.64619 .18485 .65539 .19735 .67426 .19062 .66515 .17811 Mtetra
.655 .753 .922 r
.66515 .17811 .67426 .19062 .69326 .18392 .68424 .17126 Mtetra
.656 .752 .921 r
.68424 .17126 .69326 .18392 .71239 .1771 .70345 .1643 Mtetra
.658 .752 .919 r
.70345 .1643 .71239 .1771 .73164 .17017 .72279 .15719 Mtetra
.654 .75 .92 r
.04294 .38864 .05456 .39885 .06972 .39347 .05815 .38316 Mtetra
.653 .749 .92 r
.05815 .38316 .06972 .39347 .08498 .38796 .07345 .37768 Mtetra
.656 .751 .92 r
.07345 .37768 .08498 .38796 .10034 .38235 .08885 .37207 Mtetra
.657 .753 .921 r
.08885 .37207 .10034 .38235 .1158 .37666 .10436 .36637 Mtetra
.658 .754 .921 r
.10436 .36637 .1158 .37666 .13135 .37101 .11997 .36059 Mtetra
.657 .753 .92 r
.11997 .36059 .13135 .37101 .14698 .36546 .13567 .3548 Mtetra
.653 .748 .919 r
.13567 .3548 .14698 .36546 .1627 .35987 .15144 .34913 Mtetra
.15144 .34913 .1627 .35987 .17853 .35416 .16732 .34345 Mtetra
.655 .75 .92 r
.16732 .34345 .17853 .35416 .19446 .34838 .1833 .33767 Mtetra
.656 .752 .921 r
.1833 .33767 .19446 .34838 .2105 .34247 .19938 .33181 Mtetra
.657 .754 .922 r
.19938 .33181 .2105 .34247 .22663 .33653 .21557 .32587 Mtetra
.658 .756 .922 r
.21557 .32587 .22663 .33653 .24287 .33062 .23187 .31984 Mtetra
.658 .755 .922 r
.23187 .31984 .24287 .33062 .25919 .32478 .24827 .31378 Mtetra
.657 .752 .92 r
.24827 .31378 .25919 .32478 .27561 .31892 .26476 .30771 Mtetra
.656 .749 .918 r
.26476 .30771 .27561 .31892 .29214 .31301 .28136 .30166 Mtetra
.655 .747 .918 r
.28136 .30166 .29214 .31301 .30878 .30704 .29806 .29561 Mtetra
.655 .747 .917 r
.29806 .29561 .30878 .30704 .32552 .30101 .31487 .28952 Mtetra
.31487 .28952 .32552 .30101 .34237 .29493 .33178 .28338 Mtetra
.33178 .28338 .34237 .29493 .35933 .28881 .34881 .27718 Mtetra
.656 .747 .917 r
.34881 .27718 .35933 .28881 .3764 .28264 .36594 .27094 Mtetra
.656 .748 .917 r
.36594 .27094 .3764 .28264 .39358 .27642 .38319 .26464 Mtetra
.656 .747 .917 r
.38319 .26464 .39358 .27642 .41087 .27015 .40055 .25829 Mtetra
.657 .747 .917 r
.40055 .25829 .41087 .27015 .42827 .26383 .41802 .25188 Mtetra
.41802 .25188 .42827 .26383 .44579 .25745 .4356 .24543 Mtetra
.656 .747 .917 r
.4356 .24543 .44579 .25745 .46341 .251 .4533 .23899 Mtetra
.654 .748 .919 r
.4533 .23899 .46341 .251 .48116 .24451 .47111 .23255 Mtetra
.654 .751 .921 r
.47111 .23255 .48116 .24451 .49901 .23798 .48904 .2261 Mtetra
.653 .754 .923 r
.48904 .2261 .49901 .23798 .51699 .23152 .5071 .21962 Mtetra
.655 .755 .923 r
.5071 .21962 .51699 .23152 .53508 .22509 .52527 .21303 Mtetra
.656 .754 .922 r
.52527 .21303 .53508 .22509 .55329 .21861 .54356 .20636 Mtetra
.657 .752 .92 r
.54356 .20636 .55329 .21861 .57163 .21201 .56197 .1996 Mtetra
.658 .751 .919 r
.56197 .1996 .57163 .21201 .59008 .20532 .58051 .19274 Mtetra
.658 .749 .918 r
.58051 .19274 .59008 .20532 .60866 .1985 .59917 .18585 Mtetra
.654 .748 .919 r
.59917 .18585 .60866 .1985 .62736 .19162 .61796 .17907 Mtetra
.653 .751 .922 r
.61796 .17907 .62736 .19162 .64619 .18485 .63688 .17228 Mtetra
.655 .753 .922 r
.63688 .17228 .64619 .18485 .66515 .17811 .65592 .16538 Mtetra
.656 .753 .921 r
.65592 .16538 .66515 .17811 .68424 .17126 .67509 .15839 Mtetra
.658 .752 .919 r
.67509 .15839 .68424 .17126 .70345 .1643 .69439 .15125 Mtetra
.657 .75 .918 r
.69439 .15125 .70345 .1643 .72279 .15719 .71382 .1441 Mtetra
.657 .753 .92 r
.03117 .37843 .04294 .38864 .05815 .38316 .04644 .37276 Mtetra
.654 .75 .92 r
.04644 .37276 .05815 .38316 .07345 .37768 .0618 .36718 Mtetra
.653 .749 .92 r
.0618 .36718 .07345 .37768 .08885 .37207 .07724 .3616 Mtetra
.655 .751 .92 r
.07724 .3616 .08885 .37207 .10436 .36637 .09279 .3559 Mtetra
.657 .753 .921 r
.09279 .3559 .10436 .36637 .11997 .36059 .10845 .35011 Mtetra
.658 .754 .921 r
.10845 .35011 .11997 .36059 .13567 .3548 .1242 .34424 Mtetra
.1242 .34424 .13567 .3548 .15144 .34913 .14005 .33835 Mtetra
.655 .75 .919 r
.14005 .33835 .15144 .34913 .16732 .34345 .15599 .33251 Mtetra
.653 .748 .919 r
.15599 .33251 .16732 .34345 .1833 .33767 .17202 .32671 Mtetra
.654 .749 .92 r
.17202 .32671 .1833 .33767 .19938 .33181 .18816 .32086 Mtetra
.655 .751 .92 r
.18816 .32086 .19938 .33181 .21557 .32587 .2044 .31492 Mtetra
.656 .752 .921 r
.2044 .31492 .21557 .32587 .23187 .31984 .22075 .30891 Mtetra
.656 .754 .922 r
.22075 .30891 .23187 .31984 .24827 .31378 .2372 .30285 Mtetra
.657 .756 .923 r
.2372 .30285 .24827 .31378 .26476 .30771 .25376 .29672 Mtetra
.25376 .29672 .26476 .30771 .28136 .30166 .27043 .29053 Mtetra
.657 .755 .922 r
.27043 .29053 .28136 .30166 .29806 .29561 .2872 .28432 Mtetra
.657 .753 .921 r
.2872 .28432 .29806 .29561 .31487 .28952 .30407 .27809 Mtetra
.656 .751 .92 r
.30407 .27809 .31487 .28952 .33178 .28338 .32106 .27183 Mtetra
.656 .75 .919 r
.32106 .27183 .33178 .28338 .34881 .27718 .33815 .26554 Mtetra
.33815 .26554 .34881 .27718 .36594 .27094 .35535 .25922 Mtetra
.655 .75 .919 r
.35535 .25922 .36594 .27094 .38319 .26464 .37266 .25287 Mtetra
.655 .75 .92 r
.37266 .25287 .38319 .26464 .40055 .25829 .39009 .24648 Mtetra
.655 .751 .92 r
.39009 .24648 .40055 .25829 .41802 .25188 .40763 .24007 Mtetra
.655 .752 .921 r
.40763 .24007 .41802 .25188 .4356 .24543 .42528 .23364 Mtetra
.654 .754 .923 r
.42528 .23364 .4356 .24543 .4533 .23899 .44306 .22717 Mtetra
.655 .755 .924 r
.44306 .22717 .4533 .23899 .47111 .23255 .46094 .22065 Mtetra
.655 .755 .923 r
.46094 .22065 .47111 .23255 .48904 .2261 .47895 .21405 Mtetra
.656 .754 .922 r
.47895 .21405 .48904 .2261 .5071 .21962 .49708 .20739 Mtetra
.656 .752 .921 r
.49708 .20739 .5071 .21962 .52527 .21303 .51533 .20066 Mtetra
.658 .752 .919 r
.51533 .20066 .52527 .21303 .54356 .20636 .53371 .19383 Mtetra
.658 .75 .918 r
.53371 .19383 .54356 .20636 .56197 .1996 .5522 .18694 Mtetra
.656 .749 .918 r
.5522 .18694 .56197 .1996 .58051 .19274 .57082 .18007 Mtetra
.654 .749 .92 r
.57082 .18007 .58051 .19274 .59917 .18585 .58956 .17326 Mtetra
.654 .752 .922 r
.58956 .17326 .59917 .18585 .61796 .17907 .60844 .16642 Mtetra
.655 .753 .922 r
.60844 .16642 .61796 .17907 .63688 .17228 .62744 .15947 Mtetra
.656 .753 .921 r
.62744 .15947 .63688 .17228 .65592 .16538 .64657 .15243 Mtetra
.658 .752 .919 r
.64657 .15243 .65592 .16538 .67509 .15839 .66583 .14525 Mtetra
.657 .75 .918 r
.66583 .14525 .67509 .15839 .69439 .15125 .68522 .13806 Mtetra
.654 .75 .92 r
.68522 .13806 .69439 .15125 .71382 .1441 .70475 .13095 Mtetra
.658 .753 .92 r
.01926 .36811 .03117 .37843 .04644 .37276 .03459 .36237 Mtetra
.657 .753 .92 r
.03459 .36237 .04644 .37276 .0618 .36718 .05001 .35661 Mtetra
.654 .75 .92 r
.05001 .35661 .0618 .36718 .07724 .3616 .06551 .35091 Mtetra
.653 .749 .92 r
.06551 .35091 .07724 .3616 .09279 .3559 .0811 .34523 Mtetra
.655 .751 .92 r
.0811 .34523 .09279 .3559 .10845 .35011 .0968 .33944 Mtetra
.656 .752 .921 r
.0968 .33944 .10845 .35011 .1242 .34424 .1126 .33357 Mtetra
.657 .754 .921 r
.1126 .33357 .1242 .34424 .14005 .33835 .12851 .32762 Mtetra
.658 .754 .921 r
.12851 .32762 .14005 .33835 .15599 .33251 .14452 .32161 Mtetra
.657 .752 .92 r
.14452 .32161 .15599 .33251 .17202 .32671 .16062 .3156 Mtetra
.654 .748 .919 r
.16062 .3156 .17202 .32671 .18816 .32086 .17682 .30965 Mtetra
.17682 .30965 .18816 .32086 .2044 .31492 .19311 .30369 Mtetra
.654 .749 .919 r
.19311 .30369 .2044 .31492 .22075 .30891 .20951 .29769 Mtetra
.655 .75 .92 r
.20951 .29769 .22075 .30891 .2372 .30285 .22602 .2916 Mtetra
.656 .752 .921 r
.22602 .2916 .2372 .30285 .25376 .29672 .24264 .28546 Mtetra
.656 .753 .921 r
.24264 .28546 .25376 .29672 .27043 .29053 .25936 .27927 Mtetra
.656 .754 .922 r
.25936 .27927 .27043 .29053 .2872 .28432 .27619 .27302 Mtetra
.656 .755 .923 r
.27619 .27302 .2872 .28432 .30407 .27809 .29313 .26674 Mtetra
.656 .756 .923 r
.29313 .26674 .30407 .27809 .32106 .27183 .31018 .26042 Mtetra
.31018 .26042 .32106 .27183 .33815 .26554 .32734 .25406 Mtetra
.32734 .25406 .33815 .26554 .35535 .25922 .34461 .24766 Mtetra
.34461 .24766 .35535 .25922 .37266 .25287 .362 .24123 Mtetra
.362 .24123 .37266 .25287 .39009 .24648 .3795 .23476 Mtetra
.656 .755 .923 r
.3795 .23476 .39009 .24648 .40763 .24007 .39711 .22824 Mtetra
.39711 .22824 .40763 .24007 .42528 .23364 .41484 .22169 Mtetra
.656 .754 .922 r
.41484 .22169 .42528 .23364 .44306 .22717 .43269 .21508 Mtetra
.656 .753 .921 r
.43269 .21508 .44306 .22717 .46094 .22065 .45065 .20841 Mtetra
.657 .752 .92 r
.45065 .20841 .46094 .22065 .47895 .21405 .46874 .20168 Mtetra
.657 .751 .919 r
.46874 .20168 .47895 .21405 .49708 .20739 .48695 .19487 Mtetra
.658 .75 .918 r
.48695 .19487 .49708 .20739 .51533 .20066 .50528 .188 Mtetra
.657 .749 .918 r
.50528 .188 .51533 .20066 .53371 .19383 .52373 .18111 Mtetra
.654 .748 .919 r
.52373 .18111 .53371 .19383 .5522 .18694 .54231 .17429 Mtetra
.654 .751 .921 r
.54231 .17429 .5522 .18694 .57082 .18007 .56101 .16744 Mtetra
.654 .753 .922 r
.56101 .16744 .57082 .18007 .58956 .17326 .57984 .16053 Mtetra
.655 .753 .922 r
.57984 .16053 .58956 .17326 .60844 .16642 .5988 .15353 Mtetra
.657 .753 .921 r
.5988 .15353 .60844 .16642 .62744 .15947 .61789 .14643 Mtetra
.658 .752 .919 r
.61789 .14643 .62744 .15947 .64657 .15243 .6371 .13922 Mtetra
.657 .75 .918 r
.6371 .13922 .64657 .15243 .66583 .14525 .65645 .132 Mtetra
.654 .75 .92 r
.65645 .132 .66583 .14525 .68522 .13806 .67594 .12484 Mtetra
.654 .752 .922 r
.67594 .12484 .68522 .13806 .70475 .13095 .69557 .11764 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
[(-2)] .12586 .2075 1 .99877 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.56863 .04703 m
.57247 .05235 L
s
[(2)] .56094 .0364 .72324 1 Mshowa
.125 Mabswid
.18558 .19702 m
.18832 .19985 L
s
.23703 .17687 m
.23971 .17975 L
s
.28951 .15632 m
.29214 .15925 L
s
.39772 .11395 m
.40023 .11699 L
s
.4535 .09211 m
.45595 .0952 L
s
.51046 .06981 m
.51284 .07294 L
s
.08568 .23614 m
.08851 .23887 L
s
.62804 .02377 m
.63027 .02701 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 233.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00o?ooool2o`0006[ooooo003iooooo`?o000000?oooooo`000?ooool0
JOooool00?Oooooo0_l00004ooooo`;o0000JOooool00?Cooooo0ol00006ooooo`03o`000?oooooo
000006Sooooo003;ooooo`Go00008_ooool2o`0000Wooooo00?o0000ooooool00000J?ooool00<_o
oooo00GoV9RHob4Q8Oo^k^koooooodA4A00Oooooo`?o00002oooool01?l0003oooooooooool0001W
ooooo`00c?ooool00onHV9So8B4Qonk^kP0Mooooo`?o00003_ooool01Ol0003ooooooooooooooooo
000006Kooooo003=ooooo`03oiRHV?lQ8B7ok^k^01[ooooo0_l0000Aooooo`05o`000?oooooooooo
ooooool00000I_ooool00<kooooo00?oMgMgofIVI_ooool05_ooool3o`0001?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1Sooooo`00coooool00ol0003oooooooooo`0Cooooo`;o
00000_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0H_ooool00<_ooooo00Go0000okZj^_ooooooV9RHoa0@400Booooo`?o00006Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo06;ooooo003;ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`04?ooool2o`0001cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Qooooo`00
gOooool3o`0001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Qooooo`00fooo
ool2o`00027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Pooooo`00f?ooool3
o`0002?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Oooooo`00eOooool3o`00
02Kooooo00?o0000ooooooooool01?ooool2o`00067ooooo003Cooooo`;o0000:Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo05kooooo003@ooooo`?o000000?oooooo`000?ooool0
:?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05gooooo003>ooooo`;o00001Ooo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0GOoo
ool00<_ooooo0ol0000`ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0G?ooool0
0<Wooooo0_l0000cooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Foooool00<Ko
oooo0ol0000eooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Foooool00<Cooooo
0_l0000hooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0F_ooool00<7ooooo0ol0
000jooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03_ooool5o`0004Kooooo002n
ooooo`?o0000?Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00kooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A016ooooo`00_?ooool2o`0000?ooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo1_l00003ooooo`03oiRHV?lQ8B7o
k^k^04Oooooo002iooooo`?o0000@oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00kooooo00?oV9RHob4Q8Oo^k^h0A_ooool00;Oooooo0_l00016ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03oooool00omgMgOoIVIVooooo`15ooooo`00]?ooool3o`0004Sooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Cooooo
002booooo`;o0000Boooool00ol0003oooooooooo`0=ooooo`;o00003?ooool01Ol0003o^[Zjoooo
oonHV9So410@04Kooooo002_ooooo`?o0000COooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c016ooooo`00[Oooool2o`00053ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`1Dooooo`00Z_ooool4o`00057ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1Dooooo`00Z?ooool2o`0000Cooooo00?o0000oooo
ooooool0C_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05?ooooo001nooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h08_ooool3o`0005Oooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`1Booooo`00O_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01oooooo0ol0001Joooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool0D_ooool007kooooo00Go410@oooooooo
oooooooooa0@400Mooooo`;o0000GOooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
057ooooo001nooooo`05o`000?ooooooooooooooool000006_ooool3o`0005oooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`1@ooooo`00O_ooool01Ol0003ooooooooooooooooo0000
01Sooooo0_l0001Rooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0D?ooool007ko
oooo00Go410@oooooooooooooooooa0@400Eooooo`?o0000I?ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo04oooooo001nooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool2o`00
00?ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
04kooooo001nooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04?ooool3o`0006Sooooo00?oYl3/o`00
0?ooool05_ooool00ol0003oooooooooo`1>ooooo`00TOooool2o`0006Sooooo1?nW`>`00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo04gooooo002>ooooo`?o0000J?ooool7ojO0k003o`00
0?oooooooooo01Cooooo0ol0001>ooooo`00Roooool3o`0006Wooooo0_nW_n/7ojO0k003o`000?oo
oooooooo01Kooooo00?o0000ooooooooool0C?ooool008Wooooo0_l0001Yooooo`KoYko[1_nW`>`0
0ol0003oYl3/ooooo`0Gooooo`03o`000?oooooooooo04_ooooo0026ooooo`?o0000J?ooool00onX
_n_oYko[ojNoj`07ojNoj`GoYl3/00?o0000ojNojoooool06?ooool00ol0003oooooooooo`1:oooo
o`00Q?ooool2o`0000;ooooo00?o0000ooooooooool0Hoooool5ojRoj`WoYko[0_nW`>`2ojNoj`03
o`000?nW_n_oYko[01Sooooo00?o0000ooooooooool0B_ooool0087ooooo0ol00005ooooo`03o`00
0?oooooooooo063ooooo2?nX_n/7ojNoj`03ojRojonW_n_oYko[00;oYko[00Co0000ojNojonW_n_o
Yko[6?ooool00ol0003oooooooooo`19ooooo`00Ooooool2o`0006Wooooo00?oZ<3[ojRojonX_n/0
1onX_n/4ojNoj`GoZ;o[0onW_n/00ol0003oYko[ojNoj`02ojNojaSooooo00?o0000ooooooooool0
B?ooool007cooooo0ol0001Xooooo`GoZ<3[2OnX_n/00onW_n_oZ;o[ojRoj`06ojRoj`;oYko[00Go
0000ojNojonW_n_oYko[ojRoj`0Hooooo`03o`000?oooooooooo04Sooooo001jooooo`;o0000Iooo
ool:ojS0j`KoZ;o[0_nX`>/9ojRoj`;oYko[00?o0000ojNojonX_n/00onX_n/Hooooo`03o`000?oo
oooooooo04Oooooo001gooooo`?o0000I_ooool>ojS0j`;oZ;o[1_nX`>/9ojRoj`03ojNojol0003o
Z;o[00GoZ;o[6?ooool00ol0003oooooooooo`16ooooo`00M?ooool3o`0006Kooooo00?oYl3/ojS0
jonX`>/03OnX`>/2ojO0j`SoZ<3[1_nX_n/2ojS0j`03ojRojol0003oZ;o[00GoZ;o[6?ooool00ol0
003oooooooooo`16ooooo`00L_ooool2o`0000;ooooo00?o0000ooooooooool0H_ooool4ojO0k0_o
Z<3[1_nW`>/8ojS0j`;oZ;o[1_nX`>/00ol0003oZ;o[ojRoj`05ojRojaSooooo00?o0000oooooooo
ool0AOooool006oooooo0ol0001Wooooo`OoYl3/1onX`>/00onW`>coYl3[ojO0j`07ojO0j`KoZ<3[
00?oYl3[ojS0jonX`>/01_nX`>/00ol0003oZ;o[ojRoj`04ojRoj`03ojS0jooooooooooo01Kooooo
00?o0000ooooooooool0AOooool006gooooo0_l0001Wooooo`[oYl3/1?nX`>/5ojO0k0WoYl3[0_nX
`>/5ojO0j`OoZ<3[00Co0000ojS0jonX_n_oZ;o[1OnX`>/Gooooo`;o0000A_ooool006[ooooo0ol0
001Vooooo`koYl3/00?oZ<3[ojO0k?nW`>`01_nW`>`7ojO0j`03ojO0k?nW`>_oYl3[00KoYl3[1_nX
`>/00ol0003oYl3[ojS0j`07ojS0jaSooooo00?o0000ooooooooool0@oooool006Sooooo0_l0001V
ooooo`;oYl3[6?nW`>`4ojO0j`GoYl3/2?nW`>/2ojS0j`?oYl3[00?o0000ojO0jonW`>/02?nX`>/G
ooooo`03o`000?oooooooooo04?ooooo001Uooooo`?o0000IOooool6ojO0jaSoYl3/00?oYl3[ojO0
k?nW`>`01_nW`>`6ojO0j`03ojO0k?nW`>_oYl3[00?oYl3[00Co0000ojO0jonW`>_oYl3[1_nX`>/0
0onW`>_oooooooooo`0Fooooo`03o`000?oooooooooo04;ooooo001Sooooo`;o0000IOooool00onW
_n_oYl3[ojO0j`07ojO0j`KoYl3/00?oYko[ojO0k?nW`>`05onW`>`4ojO0j`CoYl3/1OnW`>/01?l0
003oYl3[ojO0jonW`>/2ojS0j`GoYl3[6?ooool00ol0003oooooooooo`11ooooo`00H?ooool3o`00
0003ooooool0003ooooo06;ooooo1?nW_n/9ojO0j`;oYl3/1OnW_n/IojO0k003ojO0jonW`>coYl3/
00GoYl3/1?nW`>/01?l0003oYl3[ojO0jonW`>`8ojO0jaOooooo00?o0000ooooooooool0@Oooool0
03Kooooo1Ol0000Sooooo`;o0000I_ooool7ojNoj`OoYl3[2OnW_n/6ojO0k0;oYko[3_nW`>`2ojO0
j`SoYl3/1?nW`>/00ol0003oYl3/ojO0k002ojO0k0SoYl3[5oooool00ol0003oooooooooo`10oooo
o`00=_ooool01OnHV9So8B4Qonk^k_ooooooA4A4023ooooo0ol0001Uooooo`;oZ;o[2?nW_n/4ojO0
j`goYko[0_nW`>`6ojNoj`[oYl3/1_nW`>/8ojO0k004ojO0jonW`>coYl3/o`0000GoYl3/1_nW`>/0
0onW`>coooooooooo`0Fooooo`03o`000?oooooooooo03oooooo000^ooooo`Ko00000oooool00onH
V9So8B4Qonk^kP0Nooooo`?o0000IOooool6ojRoj`SoYko[00?oYl3[ojNojonW_n/03?nW_n/00onX
_n_oYko[ojNoj`07ojNoj`KoYl3/00?oYko[ojO0jonW`>/01onW`>/:ojO0k003o`000?nW`>coYl3/
00?oYl3/1?nW`>/4ojO0k1Oooooo00?o0000ooooooooool0?oooool003Sooooo00?oV9RHob4Q8Oo^
k^h06oooool2o`0006Gooooo2_nX_n/6ojNoj`;oZ;o[3?nW_n/4ojRoj`WoYko[0_nW`>`5ojNoj`Wo
Yl3[2OnW`>`00ol0003oYl3/ojO0k004ojO0k003ojO0jonW`>coYl3/00GoYl3/5oooool00ol0003o
ooooooooo`0nooooo`00>Oooool00omgMgOoIVIVooooo`0Gooooo`?o0000I?ooool>ojRoj`;oYko[
1_nX_n/9ojNoj`OoZ;o[1onW_n/00onX_n_oYko[ojNoj`06ojNoj`KoYl3[0_nW_n/9ojO0k003o`00
0?nW`>coYl3/00coYl3/6?ooool00ol0003oooooooooo`0mooooo`00>_ooool00ol0003ooooooooo
o`0Dooooo`;o0000I?ooool00onX`>_oZ;o[ojRoj`0=ojRoj`03ojS0jonX_n_oZ;o[00OoZ;o[1_nW
_n/00onX`>_oZ;o[ojRoj`07ojRoj`CoYko[1?nX_n/8ojNoj`;oYl3[1_nW_n/8ojO0k003o`000?nW
`>coYl3/00goYl3/5oooool00ol0003oooooooooo`0mooooo`00=_ooool01Ol0003o^[ZjoooooonH
V9So410@01?ooooo0ol00002ooooo`03o`000?oooooooooo05oooooo1?nX`>/;ojRoj`GoZ<3[2OnX
_n/2ojNoj`GoZ<3[2OnX_n/00onW_n_oZ;o[ojRoj`05ojRoj`KoYko[00?oZ<3[ojNojonW_n/01onW
_n/6ojO0k003ojNojol0003oYl3/00koYl3/6?ooool00ol0003oooooooooo`0looooo`00=_ooool0
1OnHV9So410@o`000?lQ8B7oc<c<017ooooo0_l0001Uooooo`OoZ<3[1onX_n/00onW`>_oZ<3[ojS0
j`06ojS0j`KoZ;o[2_nX`>/6ojRoj`;oZ<3[2?nX_n/4ojNoj`CoZ<3[2OnW_n/2ojO0k0CoYko[00?o
0000ojO0k?nW`>`03_nW`>`Fooooo`?o0000?Oooool004Wooooo0ol0001Uooooo`[oZ<3[1?nX_n/4
ojO0j`SoZ<3[0_nX_n/>ojS0j`;oZ;o[1_nX`>/8ojRoj`03ojNojonX`>_oZ<3[00GoZ<3[1onW_n/0
0onX`>_oYko[ojNoj`04ojNoj`03o`000?nW_n_oYl3/00GoYl3/0_nW_n/8ojO0k1Oooooo00?o0000
ooooooooool0>oooool004Oooooo0_l0001Uooooo`koZ<3[00?oZ;o[ojO0jonW`>/01OnW`>/6ojS0
j`03ojO1k?nX`>_oZ<3[00goZ<3[00?oYl3[ojS0jonX`>/01onX`>/6ojRoj`WoZ<3[1?nW_n/5ojS0
j`GoYko[00?o0000ojNojonW_n/00_nW`>`6ojNoj`SoYl3/5oooool00ol0003oooooooooo`0joooo
o`00A?ooool3o`0006Cooooo00?oYl3[ojS0jonX`>/03?nX`>/2ojO1k0SoYl3[1?nX`>/4ojO1k0_o
Z<3[1OnW`>/9ojS0j`;oZ;o[3OnX`>/00onW_n_oZ<3[ojS0j`06ojS0j`CoYko[00?o0000ojNojonX
_n/02OnW_n/6ojO0k003ojNojooooooooooo01Kooooo00?o0000ooooooooool0>Oooool0047ooooo
0ol0001Tooooo`GoYl3[2_nX`>/6ojO1k0SoYl3[00?oZ<3[ojO1k?nW`N`01OnW`N`7ojS0j`03ojO1
k?nW`>_oYl3[00KoYl3[1_nX`>/2ojO1k1WoZ<3[0_nW_n/00onX_n_o0000ojRoj`02ojRoj`WoYko[
0_nW`>`5ojNojaOooooo00?o0000ooooooooool0>Oooool003oooooo0ol0001Sooooo`03ojO1k?nW
`>_oYl3[00KoYl3[1_nX`>/:ojO1k0KoYl3[2_nW`N`4ojS0j`CoYl7/2?nW`>/2ojS0j`KoYl7/6?nX
`>/3ojRoj`03o`000?nX_n_oZ;o[00;oZ;o[1_nW_n/2ojRoj`SoYko[5oooool00ol0003ooooooooo
o`0hooooo`00??ooool3o`0000?ooooo00?o0000ooooooooool0G_ooool4ojO1k0SoYl3[0_nX`>/>
ojO1k0;oYl3[3_nW`N`00onX`>_oYl7/ojO1k005ojO1k0KoYl3[2_nW`N`6ojS0j`03ojO1k?nX`>_o
Z<3[00ooZ<3[0_nX_n/00ol0003oZ;o[ojRoj`03ojRoj`;oYko[1_nX_n/8ojNojaKooooo00?o0000
ooooooooool01oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02cooooo000jooooo`;o0000IOooool7
ojO1k0KoYl3[:_nW`N`2ojO0j`koYl7/0_nX`>/5ojO1k17oZ<3[00?oZ;o[o`000?nX_n/00onX_n/0
0onX`>_oZ;o[ojRoj`07ojRoj`OoYko[5oooool00ol0003oooooooooo`06ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL0;?ooool003Oooooo0ol0001Uooooo`[oYl7/0_nW`>//ojO1k003ojO0k?nW`Nco
Yl7/01KoYl7/1_nX`>/2ojO1k0SoZ<3[0_nX_n/00ol0003oZ;o[ojS0j`03ojS0j`WoZ;o[1onW_n/G
ooooo`03o`000?oooooooooo00Gooooo00Go410@oooooooooooooooooa0@400/ooooo`00=Oooool2
o`0006Gooooo7?nW`N`00onW`>_oYl7/ojO1k00<ojO1k0;oYko[3?nW`N`4ojO0k1SoYl7/0_nX`>/6
ojO1k0SoZ<3[00?oZ;o[o`000?nX`>/01OnX`>/6ojRoj`;oZ<3[2?nW_n/Fooooo`03o`000?oooooo
oooo00Gooooo00Go0000ooooooooooooooooo`00000/ooooo`00<_ooool3o`0006Cooooo7?nW`N`5
ojO0j`[oYl7/1_nW_n/9ojO1k0OoYl3/1_nW`N`2ojJoj`koYl7/00?oYl3/ojO1k?nW`N`01onW`N`6
ojS0j`03ojO0jonX`>_o000000OoZ<3[0_nX_n/6ojS0j`SoYko[5_ooool00ol0003oooooooooo`04
ooooo`05o`000?ooooooooooooooool00000;?ooool0033ooooo0_l0001ToooooacoYl7/00?oYko[
ojO0jonW`>/01_nW`>/6ojO1k0[oYko[1_nW`N`00onW_n_oYl3/ojO0k007ojO0k0;oYl7/1_nV_n/:
ojO1k0GoYl3/2OnW`N`2ojS0j`GoYl3[00?o0000ojS0jonX`>/03OnX`>/6ojNoj`;oZ<3[5oooool0
0ol0003oooooooooo`03ooooo`05oa0@4?ooooooooooooooool@4100;?ooool002gooooo0ol00000
0ooooooo0000ooooo`1Pooooo`ooYl7/0_nW`>/;ojO1k0GoYko[2?nW`>/2ojO1k0koYko[0_nW`N`5
ojNoj`OoYl3/0_nW_n/8ojJoj`KoYl7/00?oY[o[ojO0k?nW`>`01_nW`>`6ojO1k0;oYl3/1onW`>/0
0ol0003oZ<3[ojS0j`0>ojS0j`;oYko[1_nX`>/Fooooo`;o00001?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg02cooooo000Zooooo`?o0000Hoooool?ojO1k0KoYl3[1onW`N`00onW_n[oYko[ojNoj`06
ojNoj`KoYl3[0_nX_nX>ojNoj`03ojRoj_nW_n_oYko[00KoYko[1?nW`>`5ojNoj`SoY[o[0_nW`N`5
ojJoj`SoYl3/0_nW`N`6ojO0k0KoYl3[00?o0000ojO0jonX`>/05onX`>/Cooooo`;o000000?ooooo
o`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02cooooo000Xooooo`;o0000Hoooool?
ojO1k0[oYl3[1?nW`N`4ojNojPSoYko[0_nW`>/6ojRojP[oYko[1OnX_nX8ojNoj`03ojO0k?nW_n_o
Yko[00KoYko[1_nV_n/00onX_n[oY[o[ojJoj`06ojJoj`KoYl3/00?oY[o[ojO0k?nW`>`01onW`>`5
ojO0j`03o`000?nW`>coZ<3[01SoZ<3[5_ooool00ol0003oooooooooo`0booooo`009Oooool3o`00
06;ooooo3onW`N`>ojO0j`03ojO1k?nW_n[oYkoZ00GoYkoZ1_nW_n/:ojRojPKoYko[2OnX_nX6ojNo
j`03ojRoj_nW_n_oYko[00SoYko[0_nV_n/5ojRojPSoY[o[0_nW`>`5ojJoj`WoYl3/0_nW`>/00onW
`>co0000o`000002ojO0k1SoZ<3[5_ooool00ol0003oooooooooo`0booooo`008oooool2o`0006;o
oooo3onW`N`2ojNoj`koYl3[00?oZ;oZojNoj_nW_nX01_nW_nX4ojNoj`goZ;oZ0_nW_n/=ojRojP;o
Yko[1OnX_nX8ojNoj`WoZ;oZ1_nV_n/00onX_n[oY[o[ojJoj`06ojJoj`KoYl3/0_nV_n`3o`000003
ojO0k?l0003oYl3/00;oYl3/1_nX`>/00onW`>coZ<3[ojS0j`0?ojS0jaKooooo00?o0000oooooooo
ool0<Oooool0023ooooo0ol0001Rooooo`koYl7/1_nW_n/:ojO0j`GoZ;oZ2?nW_nX00onW_n_oZ;oZ
ojRojP0<ojRojP03ojS0jonX_n[oZ;oZ00coZ;oZ00?oZ<3[ojRoj_nX_nX01_nX_nX4ojNoj`goZ;oZ
0_nV_n/5ojRojPSoY[o[0_nW`>`2ojJok0?o000000?oY[o/ojO0k?nW`>`00_nW`>`01?l0003oYl3/
ojO0k?nW`>`2ojS0j`GoYl3/1onX`>/00onW`>_oZ<3[ojS0j`06ojS0jaOooooo00?o0000oooooooo
ool0<?ooool001oooooo0_l0001Rooooo`goYl7/2_nW_n/6ojO0j`WoZ;oZ1_nW_nX2ojRoj`_oZ;oZ
1OnX`>/:ojRojPGoZ<3[2?nX_nX00onW_n_oZ;oZojRojP0<ojRojP03ojS0jonX_n[oZ;oZ00KoZ;oZ
1_nV_n/00onX_n_oY[o/o`000002o`0000CoY[o/1OnW`>`00ol0003oY/3/ojK0k008ojO0k0CoZ<3[
1?nW`>/8ojS0jaKooooo00?o0000ooooooooool0<?ooool001oooooo00?o0000ooooool00000Gooo
ool<ojO1k0koYko[0_nW`>/=ojRojP;oYkoZ1_nX_n/7ojRojPWoZ<3[1_nX_nX9ojS0j`KoZ;oZ0_nX
`>/<ojRojPCoZ<3[2?nX_nX2ojJoj`;oZ;o[0ol00008ojJok0;oYl3/0onV`>`00ol0003oY/3/ojK0
k008ojO0k003ojS0jonW`>_oYl3[00GoYl3[1onX`>/Gooooo`03o`000?oooooooooo02oooooo000<
ooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00Co0000oooooooooooo0000
Foooool<ojO1k13oYko[00?oYkoZojRoj_nX_nX03?nX_nX:ojRoj`CoZ;oZ3?nX`>/2ojRojPgoZ<3[
0_nX_nX6ojS0j`WoZ;oZ1onX`>/6ojRojP03ojS0jonX_n_o000000;o00001?nX_n/6ojJok003ojNo
jonV`>coY/3/00?oY/3/00Co0000ojK0k?nV`>coY/3/1onW`>`9ojO0j`OoZ<3[5oooool00ol0003o
ooooooooo`0^ooooo`003?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`06ooooo`;o00000_ooool00ol0003oooooooooo`1Eooooo`coYl7/4?nW_n/5ojNo
jP[oZ;oZ3_nX_n/00onX_n[oZ<3[ojS0j`0;ojS0j`03ojO1k?nX`>_oZ<3[00coZ<3[00?oYl7/ojS0
jonX`>/01onX`>/6ojRojP[oZ<3[0_nX_nX2ojS0j`?o00002?nX_n/2ojJok0GoYko[1OnV`>`01?l0
003oY/3/ojK0k?nV`>`7ojO0k0OoYl3[00?oYl3/ojS0jonX`>/01_nX`>/Fooooo`03o`000?oooooo
oooo02kooooo0004ooooo`Ko00000oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?oooooooooo
ooooool@41001Oooool2o`0000Cooooo00?o0000ooooooooool0DOooool=ojO1k0ooYko[2OnW_nX6
ojRojP;oYl3[3_nX_n/2ojO1k0[oZ<3[1OnW`N`:ojS0j`GoYl7/2OnX`>/2ojRojPkoZ<3[0ol00004
ojS0j`KoZ;o[00?oZ<3ZojNojonW_n/01_nW_n/5ojK0k003o`000?nV_n_oY[o[00SoYl3/1?nW`>/4
ojO0k0SoZ<3[5_ooool00ol0003oooooooooo`0]ooooo`003_ooool00onHV9So8B4Qonk^kP03oooo
o`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo04gooooo3_nW`N`>ojNoj`goYkoZ0_nX_nX6ojO0j`[oZ;o[1_nW`N`6ojS0j`03ojO2kOnW`Nco
Yl7/00KoYl7/1_nX`>/9ojO1k0KoZ<3[0_nW`N`>ojS0j`;o00002?nX`>/2ojRoj`GoZ<3Z2?nW_n/2
ojK0k0;oY[o[00Co0000ojJojonV_n_oY[o[2?nW`>`00onW`>_oYl3/ojO0k005ojO0k0OoZ<3[5ooo
ool00ol0003oooooooooo`0/ooooo`003oooool00omgMgOoIVIVooooo`02ooooo`05o`000?oooooo
ooooooooool000001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04Wooooo3onW
`N`=ojNoj`ooYkoZ2_nW`>/6ojRoj`[oYl7/0_nX`>/5ojO2k@SoYl7/0_nX`>/=ojO1k0;oZ<3[1_nW
`N`:ojS0j`?o00002_nX`>/8ojS0jPKoYko[00?oZ;oZojJojonV_n/00onV_n/00ol0003oY[o[ojJo
j`06ojO0k0?oY[o/2?nW`>`7ojS0jaGooooo0_l0000^ooooo`004?ooool01Ol0003ooooooooooooo
oooo410@00?ooooo00?o410@ooooooooool00oooool2o`0000Oooooo00?o0000ooooooooool0A_oo
ool?ojO1k003ojO0jonW_n_oYko[00WoYko[3onW_nX>ojO0j`;oZ;o[3OnW`N`8ojO2k@KoYl7/00?o
Y/3/ojO1k?nW`N`03?nW`N`2ojK1k0SoYl7/1_nX`>/3o`0000koZ<3[2?nX`>X2ojNoj`GoZ;oZ1OnV
_n/00ol0003oY[o[ojJoj`02ojO0k0OoY[o/1onW`>`8ojS0jaKooooo00?o0000ooooooooool0:ooo
ool000cooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04;ooooo3onW`N`5ojO0j`OoYko[
3onW_nX@ojO0j`03ojO2k?nW`NcoYl7/00koYl7/2?nW`^d2ojO1k0GoY/3/2_nW`N`6ojK1k0SoYl7/
0_nX`>/3o`0000?oYl7/1_nX`>/00onW`NcoZ<3[ojS0j`06ojS0j`KoZ<3Z00?oZ<3[ojRoj_nX_nX0
1_nX_nX5ojJoj`03o`000?nX_n_oZ;o[00WoY[o/1onW`>`8ojS0jaGooooo00?o0000ooooooooool0
:oooool000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03kooooo0_nW`>/=ojO1k0;o
Z<3[1onW`>/4ojNoj`koYkoZ4?nW`>/5ojO2k13oYl7/1_nW`^d00onV_n_oY/3/ojK0k006ojK0k0Ko
Yl7/0_nV_n/8ojK1k0KoYl7/0ol00007ojO1k0;oZ<3[1OnW`N`8ojS0j`;oZ<3Z1OnX`>/8ojRojP;o
Y[o[0_nX_n/01?l0003oZ;o[ojRojonX_n/6ojJok0;oY[o[2?nW`>`6ojS0j`03ojO0jooooooooooo
01Cooooo00?o0000ooooooooool0:_ooool001kooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0jooooo`KoYl3[2OnW`N`6ojS0j`OoYl3[00?oYko[ojNoj_nW_nX03?nW_nX?ojO0j`03
ojO2kOnW`^coYl;/00KoYl;/1_nW`N`2ojO0k0SoYl7/0_nW`^d5ojJoj`SoY/3/0_nW`N`6ojJoj`So
Y/7/0_nW`N`3o`0000?oY/3/1_nW`N`00onV`>coYl7/ojO1k006ojO1k0KoZ<3[00?oYl7/ojS0jonX
`>/01_nX`>/6ojRojP03ojS0jonX_n_oZ;o[00?oZ;o[00Co0000ojRojonX_n_oZ;o[0_nV_n`6ojJo
j`SoYl3/0_nX`>/5ojO0jaKooooo00?o0000ooooooooool0:Oooool001gooooo0ol0000;ooooo`03
o`000?oooooooooo03Kooooo2_nW`>/5ojO1k0;oZ<7/2?nX`>/5ojO0j`goYkoZ3onW`>/5ojO2k@So
Yl;/0_nW`N`6ojO0k0KoYl7/0_nW_^X7ojJoj`KoY/3/0_nW_^X8ojJoj`KoY/7/0ol00007ojK0k0;o
Yl7/1OnV`>`8ojO1k0;oZ<3[1OnW`N`8ojS0j`;oZ;oZ1OnX`>/5ojRoj`03o`000?nX_n_oZ<3[00So
Y[o[1_nW`>`2ojK0k0OoYl3[5_ooool00ol0003oooooooooo`0Yooooo`007Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo03;ooooo3_nW`>/00onW`NcoZ<7/ojS1k004ojS1k0SoZ<3[
00?oYl3[ojNoj_nW_nX02onW_nX?ojO0j`WoYl;]1_nW`^`2ojNoj`SoYl3/0_nW`N`6ojNnjPOoY[o[
0_nV`>`6ojNnjPSoY[o[0_nV`N`3o`0000?oY[k[1_nV`>`00onW_^_oY/3/ojK0k006ojK0k0KoYl7/
00?oY/3/ojO1k?nW`N`01_nW`N`6ojS0j`03ojS1jonX`>_oZ<3[00KoZ<3[1?nX_n/01?nX`>_o0000
ojS0jonX`>/8ojJoj`;oYl3/1_nV`>`7ojO0jaKooooo00?o0000ooooooooool0:?ooool001gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0_ooooo`03ojNojonW`>_oYl3[00coYl3[
2OnX`N`6ojS0j`coYkoZ3onW`>/=ojO2k@;oYl;/1_nW_n/6ojO0k0;oZ;kZ2?nW_^X5ojJoj`;oZ;oZ
2?nW_^X6ojJoj`?o00001onV_^/2ojK0k0GoYkk[2?nV`>`2ojO1k0GoY/3/2?nW`N`2ojS0j`GoZ<7[
2?nX`>/01OnX_n_oZ<3[ojS0jonX`>_o000000?oZ<3[1_nV_n/00onW_n_oY/3/ojK0k006ojK0k0Ko
Yl3[00?oYl3/ooooooooool05Oooool00ol0003oooooooooo`0Wooooo`007Oooool2o`0000oooooo
00?o0000ooooooooool0:oooool5ojNoj`[oYl3[3OnX`N`2ojS0j`coYkoZ3onW`>/2ojO2k0goYl;]
2_nW_n/2ojO0k0KoZ;kZ2?nW_^X00onV_n_oZ;oZojRojP04ojRojPSoYkkZ0_nV_n/00onX_n[o0000
o`000002ojRojPOoY[k[00?oZ;oZojNnjonW_^/01_nW_^/6ojK0k003ojJnjonV`>coY/3/00KoY/3/
1_nW`N`00onV`>coZ<7[ojS1j`06ojS1j`coZ<3[00Co0000ojS0jonX`>_oZ<3[0_nV_n/5ojNoj`So
Y/3/0_nW`>/5ojO0k1Kooooo00?o0000ooooooooool09oooool001gooooo00?o0000ooooooooool0
3oooool2o`0002Sooooo2OnW_n/6ojO0j`ooZ<7/0_nW_n/;ojNojPkoYl3[1_nW`^`9ojO2k@coYko[
2_nX_^X6ojNnjPWoZ;oZ1_nW_^X01?nX_n[o0000o`000?l00005ojRojPCoY[k[1?nX_nX8ojNnj`;o
Y/3/1OnV_^/8ojK0k0;oYl7/1OnV`>`8ojS1j`coZ<3[00?o0000ojS0jonY`>/02?nW_n/6ojK0k003
ojJok?nW`>coYl3/00KoYl3/5_ooool00ol0003oooooooooo`0Vooooo`007Oooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo02;ooooo3OnW_n/2ojO0j`ooZ<7/1_nW_n/8ojNojPgoYl3[
2_nW`^`5ojO2k@goYko[3OnX_^X2ojNnjPgoZ;oZ0_nW_^X01?nX_n[o0000o`000?l00009ojRojP03
ojJnjonX_n[oZ;oZ00GoZ;oZ1_nW_^/00onY_n[oY[k[ojJnj`06ojJnj`KoY/3/00?oY[k[ojK0k?nV
`>`01_nV`>`6ojS1j`03ojO1k?nX`>_oZ<3[00WoZ<3[0_nY`>/00ol0003oZL3[ojW0j`08ojNoj`;o
Y/3/1OnV_n`8ojO0k1Kooooo00?o0000ooooooooool09Oooool001gooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0Nooooo`ooYko[0_nW`N`=ojS1k0[oYko[1OnW_nX3ojNoj`WoYl3[
3_nW`^`00onW`^goYko[ojNoj`0=ojNoj`goZ;kZ4?nX_nX3o`0000_oZ;oZ0_nY`>X8ojRojP;oYkk[
1OnY_nX8ojJnj`;oY/3/1OnV_^/8ojK0k0;oZ<7[1OnW`N`8ojS0j`CoZL3[00Co0000ojW0jonY`>_o
ZL3[1_nW_n/00onX`>_oY[o/ojJok006ojJok0OoYl3/5_ooool2o`0002Kooooo000Looooo`?o0000
5?ooool00ol0003oooooooooo`0Jooooo`ooYko[1_nW`N`9ojS1k0koYko[00?oYkoZojNojonW_n/0
1OnW_n/6ojO0j`ooYl;/3onW_n/<ojRnjQ3oZ;oZ0ol0000;ojRojPKoZL3Z1_nX_nX00onY`>[oZKoZ
ojVojP06ojVojPKoY[k[00?oZKoZojJnjonV_^/01_nV_^/6ojK0k0;oYKo/1onW`N`8ojS0j`CoZL3[
00Co0000ojW0jonY`>_oZL3[0_nW_n/5ojS0j`SoY[o/1onW`>`Dooooo`03o`000?oooooo000002Ko
oooo000Looooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool05oooool?ojNoj`;oYl3[
1onW`N`6ojS1k003ojS0jonW_n_oYko[01KoYko[0_nW`>/?ojO2k0ooYko[3?nX_^X00onX_n_oZ;oZ
ojRojP0<ojRojP04ojS0jol0003o0000o`0000_oZ;oZ00?oZ<3[ojW0j_nY`>X01onY`>X2ojRojPGo
ZL3Z2?nY_nX2ojJnj`GoZKoZ2?nV_^/2ojK0k0KoYKo/1onW`N`8ojS0j`CoZL3[00?o0000ojW0jonX
`>/02?nX`>/6ojJok003ojJojonW`>coYl3/00KoYl3/5_ooool00ol0003oooooooooo`0Sooooo`00
2_ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h6ooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool04oooool?ojNoj`KoYl3[1onW`N`2ojS1k0GoZ<3[5_nW_n/0
0onW`NcoYl;/ojO2k00<ojO2k0ooYko[0_nW_^X:ojRnjPGoZ;o[2_nX_nX01OnX`>_o0000o`000?l0
003oZ<3[00[oZ;oZ1OnX`>/7ojW0jP03ojS1jonY`>[oZL3Z00KoZL3Z1_nY_nX00onY`>[oZKoZojVo
jP06ojVojPKoY[k[0_nX_nX8ojFok0?oYl7/1?nV`>`8ojS0j`;oZL3[00?oZ<3[o`000?nX`>/02_nX
`>/2ojJok0GoY[o[2?nW`>`Eooooo`03o`000?oooooooooo02?ooooo000<ooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool03oooool2ojS0j`goYko[2_nW`>/5ojO1k0;oZ<7/1onX`>/BojNoj`GoYl7/2_nW
`^`?ojNoj`KoYkkZ1_nX_^X00onW_n_oZ;o[ojRoj`06ojRoj`KoZ;oZ00CoZ<7[o`000?l0003o0000
1OnX`>/6ojRojP03ojS1jonX`>_oZ<3[00KoZ<3[1?nY`>X4ojS1j`SoZL3Z0_nY_nX5ojW0jPSoZKoZ
0_nV_^/6ojRojPKoYKo/00?oY[o[ojK0k?nV`>`01_nV`>`6ojS0j`03ojO1k?nX`>_oZ<3[00;oZ<3[
00?o0000ojS0jonX`>/01onX`>/00onY`>_oY[o[ojJoj`05ojJoj`KoYl3/0_nV_n`Fooooo`03o`00
0?oooooooooo02;ooooo00000ooooooo0000o`000004o`0000Gooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@00Kooooo0_l0000Iooooo`03o`000?oooooooooo00cooooo
1OnX`>/9ojNoj`koYl3[00?oYl7/ojS1k?nX`N`01?nX`N`7ojS0j`koYko[2OnW`N`6ojO2k0;oZ<3[
3OnW_n/:ojNnjP;oZ;kZ1OnW_n/8ojRoj`;oZ;oZ0_nX`N/2o`000003ojS1jonX`>_oZ<3[00KoZ<3[
0_nX_nX5ojS1j`SoZ<3[00?oZL3ZojS1jonX`N/01OnX`N/6ojW0jP03ojS1jonY`>[oZL3Z00KoZL3Z
1_nY_nX00onY`>[oZ;oZojRojP07ojRojP;oYKo/1OnV_n/8ojK0k0;oZ<3[1OnW`N`4ojS0j`03o`00
0?nX`>_oZ<3[00?oZ<3[1OnY`>/7ojJoj`;oYl3/1_nV_n`Fooooo`03o`000?oooooooooo027ooooo
000<ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool02_ooool7ojS0j`OoYko[3_nW`>/9ojS1k0GoZ<3[
3?nW_n/=ojO1k0;oYl;/1_nX`>/9ojNoj`coYkkZ2OnW_n/6ojRoj`03ojS0jonX`N_o000000;o0000
1?nX`N/6ojS0j`03ojNmj_nX`N_oZ<7[00KoZ<7[1_nX`>/2ojNoj`SoZ<7[0_nY`>X5ojS1j`SoZL3Z
0_nY_nX5ojW0jPOoZ;oZ00?oZL3ZojJojonV_n/01_nV_n/6ojK0k003ojFok?nW`NcoYl7/00GoYl7/
1OnX`>/00ol0003oZ<3[ojS0j`07ojW0j`KoY[o[0_nW_n/8ojJok1Gooooo00?o0000ooooooooool0
8Oooool000cooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Gooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`07ooooo`?oZ<7[1onX`>/7ojNoj`[oYl3[
3OnX`N`00onX`>_oYko[ojNoj`0;ojNoj`03ojO0jonW`NcoYl7/00_oYl7/0_nX`N/8ojS0j`GoYko[
3?nW_^X=ojNoj`;oZ;o[0_nX`>/3o`0000SoZ<7[0_nX`>/5ojNmjPSoZ<7[0_nX`>/6ojNoj`KoZ<7[
00?oYkkZojS1jonX`N/01_nX`N/6ojW0jP03ojS0jonY`>[oZL3Z00KoZL3Z1?nX_nX4ojW0jPSoY[o[
0_nV`>`5ojFok0OoYl7/1?nX`>/01?l0003oZ<3[ojS0jonX`>/7ojW0j`;oY[o[1_nW_n/7ojJok1Ko
oooo00?o0000ooooooooool08?ooool000cooooo00?o0000ooooooooool00_ooool01Ol@413ooooo
oooooooooooo410@00Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`03ooooo`Oo
Z<7[1OnX`>/9ojNoj`KoYl3[3onX`N`<ojNoj`GoYl3[2OnW`N`6ojS1j`SoZ<3[00?oYko[ojNnj_nW
_^X02_nW_^X?ojNoj`;oYkoZ0ol00004ojS0j`KoZ<7[00?oYkSUojNmj_nW_NX01_nW_NX6ojS1j`;o
YkSU2?nW_n/2ojS1j`GoYkkZ2?nX`N/2ojW0jPGoZ<3[2?nY`>X00onX_n[oZL3ZojW0jP05ojW0jPKo
Y[o[00?oZ;oZojFok?nU_n`01OnU_n`6ojO1k003ojK0k?nX`>_oZ<3[00?oZ<3[00?o0000ojS0jonX
`>/02?nY`>/8ojNoj`OoY[o/5_ooool00ol0003oooooooooo`0Oooooo`003?ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2o`0001kooooo00?o0000oooooonX
`N/02_nX`N/00onX`>_oYko[ojNoj`0;ojNoj`;oYl3[3onX`N`>ojNoj`OoYl3[1_nW`N`00onX`^co
Z<7[ojS1j`06ojS1j`KoZ<3[2onW_^X?ojNoj`;oYkoZ0ol000000onW_n[oZ<3[ojS0j`05ojS0j`;o
Z<7[1OnW^>D8ojNmjP;oZ<7[1_nW^>D6ojNoj`03ojReh_nW_^[oYkkZ00KoYkkZ1_nX`N/00onW_n_o
Z<3[ojS0j`06ojS0j`KoZL3Z0_nX`>/8ojW0jP;oY[o[1OnX_nX7ojFok0;oYl7/1OnV`>`5ojS0j`03
o`000?nX`>_oZ<3[00SoZL3[1_nW_n/00onW`>_oY[o/ojJok006ojJok1Gooooo00?o0000oooooooo
ool07oooool000[ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo00?o0000ooooooooool07?ooool=ojS1j`koYko[0_nW`>/=ojS1k0?oZ<3[3onW_n/7ojO0j`;o
Yl7/1OnX`^`8ojS1j`;oZ<3[3?nW_^X?ojNoj`04ojNnj_l0003o0000o`0000GoYkoZ1OnX`>/2ojNb
h0OoYkSU1_nW_NX00onX[mgoYkSUojNhi@07ojNhi@;oYko[1OnX]N88ojNnjP;oZ<7[1OnW_n/8ojS0
j`;oZL3Z1_nX`>/7ojW0jPOoZ;oZ1_nU_n`00onV_n_oY/3/ojK0k006ojK0k0GoZ<3[00?o0000ojS0
jonX`>/02?nY`>/2ojNoj`GoYl3[2?nV_n`Eooooo`03o`000?oooooooooo01kooooo000Kooooo`03
o`000?oooooooooo01[ooooo0onW`>/9ojS1j`koYko[1_nW`>/9ojS1k0OoZ<3[3onW_n/5ojO0j`Wo
Z<;/1_nX`N/<ojNnjPooYko[00GoYkkZo`000?l0003o0000ojNnjP08ojNojP03ojS0jonW/^3oYk;P
00CoYk;P1onW^>D2ojNmjPGoZ:oM1onW^>D00on/[mWoZ;GRojRehP06ojRehPKoYkkZ00?oZ;KRojNo
jonW_n/01_nW_n/6ojS0j`;oYl3[2?nX`>/7ojW0jPOoZ;oZ0_nU_n`5ojJoj`SoY/3/1?nX`>/01?l0
003oZ<3[ojS0jonX`>/7ojW0j`SoYl3[1onV_n`Fooooo`03o`000?oooooooooo01gooooo000Koooo
o`03o`000?oooooooooo01Oooooo1onW`>/7ojS1j`ooYko[1onW`>/6ojS1k0;oZ<7[2?nX`>/?ojNo
j`03ojO0jonX`^coZ<;/00_oZ<;/0_nX`N/<ojNnjPooYko[00CoYkkZo`000?l0003o00001OnW_^X6
ojNojP03ojN^gOnW/^3oYk;P00KoYk;P1OnW^>D00on[ZmOoZ:oMojR_g@06ojR_g@CoYkSU1?n/[mT8
ojRehP;oYkkZ1OnX]^88ojNoj`;oZ<3[1_nW`>/6ojS0j`03ojS1jonY`>[oZL3Z00GoZL3Z1_nX_nX2
ojW0jPOoY[o[1_nV`>`2ojJok0CoZ<3[00Co0000ojS0jonX`>_oZ<3[1onY`>/8ojO0j`OoY[o/5?oo
ool2o`0001oooooo000Kooooo`;o00005_ooool:ojO0j`OoZ<7[3onW_n/7ojO0j`;oZ<7/1_nX`N/6
ojS0j`ooYko[00?oZ<7/ojS2k?nX`^`02onX`^`<ojNnjPooYko[0_nW_^X2o`0000WoYkkZ0_nW_nX5
ojN^g@SoYk;P00?oYkSUoj^[eon[ZmL00on[ZmL8ojR_g@03ojNhiOn/[mWo[:oI00Go[:oI1_nX]N80
0on`/MWoZ;KRojRfhP06ojRfhPKoYko[0_nX^ND8ojO0j`;oZ<3[1OnX`N/7ojW0jP;oZ;oZ1_nY`>X7
ojJoj`;oY/3/1_nV_n`4ojS0j`03o`000?nX`>_oZ<3[00SoZL3[1_nW`>/00onX`>_oY[o/ojJok005
ojJok1Kooooo00?o0000ooooooooool07?ooool001[ooooo00?o0000ooooooooool04oooool<ojO0
j`WoZ<7[3onW_n/5ojO0j`?oZ<7/1onX`N/2ojS0j`ooYko[1OnX`N`9ojS2k0coYkkZ3onW_n/00onX
_n[oYkkZo`000002o`0000[oYkkZ00?oYZgLojN^gOnW[]d01_nW[]d6ojNbh003ojZWdon[ZmOoZj_G
00GoZj_G1_nX[md00on_ZM;o[:oIojb_f@06ojb_f@CoZ;GR1?n`/MT8ojRfhP;oYko[1_nX^ND6ojO0
j`03ojNmjOnX`N_oZ<7[00GoZ<7[1_nY`>X00onY`>_oZL3ZojW0jP07ojW0jP?oY[o[1?nW_n/8ojJo
k0CoZ<3[00?o0000ojS0jonX`>/02?nY`>/2ojO0j`GoZ<3[1onV_n`Eooooo`03o`000?oooooooooo
01cooooo000Jooooo`03o`000?oooooooooo00oooooo1?nW_n/9ojO0j`goZ<7[3onW_n/00onW`>_o
Z<7/ojS1k005ojS1k0GoZ<7[3onW_n/2ojO0j`OoZ<7/1_nX`^`2ojRoj`WoYkkZ3onW_n/2ojRojP?o
00002_nW_^X5ojJ]g0SoYjkM0_nW/^05ojZWd`KoZj_G1?nX[md4ojnYdPSo[:oI00?oZ;GRok2afOn`
/MT01On`/MT6ojRfhP03ok6df_nX^NGoZ;WU00OoZ;WU0_nW`>/5ojNmj@OoZ<7[0_nY`>X5ojW0j`Oo
ZL3Z00?oZL7ZojNojonW_n/01_nW_n/6ojJok003ojFok?nX`>_oZ<3[00;oZ<3[00?o0000ojS0jonX
`>/02?nY`>/7ojS0j`SoY[o/5Oooool00ol0003oooooooooo`0Kooooo`006_ooool00ol0003ooooo
ooooo`0;ooooo`WoYko[1_nW`>/00onX`>_oZ<7[ojS1j`0;ojS1j`ooYko[0onW`>/7ojS1k003ojS1
jonW_n_oYko[00goYko[1_nW`>/7ojS1k0;oZ<;/1_nX_n/6ojNnjP03ojNnjonW_n_oYko[00_oYko[
0_nX`>/3o`0000CoZ;oZ1_nW_^X00onV[=coYZgLojJ]g006ojJ]g0KoYjkM00?oZ:CBojZWdonZYm<0
1_nZYm<6oj^[e`03ojR_gOn_ZM;o[jWB00Go[jWB1_n/[mT00onbZm7o/;7Iok2af@07ok2af@;oZ;KR
1Ona]=X7ojRii@03ojnggonW_NWoYkgY00GoYkgY1_nX`N/00onW`>_oZL3[ojW0j`06ojW0j`CoZL3Z
1?nY`NX8ojNoj`;oY[o/1OnU_n`4ojS0j`03o`000?nX`>_oZ<3[00SoZL3[1onX`>/8ojJok1Gooooo
00?o0000ooooooooool01_ooool5o`0000oooooo000Jooooo`;o00002Oooool=ojNoj`;oYl3[1OnX
`>/9ojS1j`ooYko[1onW`>/5ojS1k0;oZ<3[3_nW_n/8ojO0j`GoZ<7/0onX`N/7ojRoj`;oYkkZ1OnW
_^/9ojNoj`;oZ<3[0ol000000onX`>_oZ;oZojRojP05ojRojP;oYkkZ1OnV[=`7ojJ]g0CoYjkM1?nX
Y=87ojZWd`GoZj_G00?o[ZG?ojnYd_n_ZM801_n_ZM84ojb_f@Co/Z_A1on`/MT00onf[];o/KCJok6d
fP06ok6dfPCoZ;WU1?n_]ml7ojNmj@;oZ<7[1OnW`>/8ojW0j`03ojW0j_nY`N[oZL7Z00GoZL7Z1_nW
_n/00onX`>_oYKo/ojFok005ojFok0GoZ<3[00?o0000ojO0jonY`>/01onY`>/8ojS0j`SoY[o/5?oo
ool00ol0003oooooooooo`06ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@03oooool001[ooooo00?o
0000ooooooooool01_ooool2ojS0j`coYko[0_nW`>/7ojS0j`KoZ<7[0onX`>/;ojNoj`_oYl3[00?o
Z<7/ojS0jonX`>/01?nX`>/>ojNoj`SoYl3[00?oZ<7/ojS1jonX`N/01OnX`N/5ojRoj`;oY[kZ1onW
_^/6ojNoj`04ojO0k?l0003o0000o`0000GoZ<3[1OnX_nX00onU[]goYZcLojJ/g006ojJ/g0OoYZgL
00?oYjkMojRTd_nXY=801?nXY=88ojZWd`03oj^[eon^YLoo[ZG?00?o[ZG?2?n_ZM800on/[mWo/Z_A
ok:[d@05ok:[d@Go/;7I0onf[]88ok6dfP03ojRiiOn_]moo[kOO00Go[kOO1OnW_NT2ojZkiPOoYl3[
1_nY`>/2ojS0j`SoZL7Z0_nW_n/5ojS0j`OoYKo/0_nX`>/2ojO0j`03o`000?nW`>_oYl3[00SoZL3[
2?nX`>/7ojJok1Gooooo00?o0000ooooooooool01_ooool00onHV9So8B4Qonk^kP0@ooooo`006_oo
ool00ol0003oooooooooo`03ooooo`KoZ<3[2?nW_n/6ojO0j`OoZ<3[0_nX`N/7ojS0j`OoYko[3OnW
`>/00onX`N_oZ<3[ojS0j`06ojS0j`koYko[1_nW`>/2ojS2k0SoZ<7[00?oZ;o[ojJnj_nV_^X01?nV
_^X7ojNnj`;oYko[00GoYl3/o`000?l0003o0000ojO0k008ojS0j`03ojRoj_nU[]goYJkM00?oYJkM
1onV[=`6ojJ]g003ojJRdOnXY=;oZ:CB00KoZ:CB1_nZYm<00on^Y]3o[ZG?ojjUc`05ojjUc`Ko[jWB
00?o]Jc@ok:[dOnbZm401_nbZm43ok2af@Ko]ZkB1_na]=X00onh/mGo[kOOojngg`07ojngg`03ojNm
jOnZ^nKoZ[_V00CoZ[_V1onW`>/2ojW0j`KoZ<3[1_nY`NX00onY`N_oZ<3[ojS0j`05ojS0j`SoYKo/
1?nW`>/00ol0003oYl3[ojO0j`06ojW0j`[oZ<3[1onV_n`Eooooo`03o`000?oooooooooo00Kooooo
00?oV9RHob4Q8Oo^k^h03oooool001[ooooo00?o0000ooooooooool02_nX`>/7ojNoj`OoYl3[1OnX
`>/3ojS1j`SoZ<3[1onW_n/9ojO0j`GoZ<7[2?nX`>/>ojNoj`;oYl3[1_nX`^`6ojS1j`03ojNnj_nV
_^[oY[kZ00KoY[kZ1OnW_^/01?nW`>_o0000o`000?l00005ojO0k0KoZ<3[00?oY[7QojF^gOnU[]d0
1OnU[]d7ojJ/g0;oYZgL1OnVX]47ojRTdPCoZZOC1?n^Y]07ojjUc`?o[jWB1?ne[=08ok:[d@03ok2a
fOnf[];o]ZkB00Go]ZkB1?na]=X4okRce@Oo[kOO00?o]k[KojZki_nZ^nH01_nZ^nH3ojO0j`CoYko[
2?nX`>/2ojW1jPGoZL7[1onX`>/8ojFok0CoYl3[00?o0000ojO0jonW`>/00_nY`>/=ojS0j`OoY[o/
5Oooool00ol0003oooooooooo`07ooooo`03ogMgMomVIVKooooo00kooooo000Iooooo`03o`000?nX
`>_oZ<3[00coZ<3[1onW_n/7ojO0j`03ojS0jonX`N_oZ<7[00GoZ<7[1_nX`>/9ojNoj`GoYl3[2OnX
`N/6ojS0j`;oY[o[2onW_n/4ojS1k0OoZ<;/0_nX`N/5ojNnjPSoY[kZ00?oYkk[ojO0jol000000_l0
0002ojO0j`OoYl3/0_nX`>/5ojJah@OoYJkM1OnV[=`00onTXM;oYZ;AojJRd@05ojJRd@SoZ:CB00?o
ZZOCojjVd?n^Y]001?n^Y]08ojjUc`03ojnYd_ne[=3o]Jc@00Co]Jc@1_nbZm400onk/]7o]ZkBokJ^
dP07okJ^dP03ok6df_nh/mGo^;?E00Go^;?E1?n_]ml4okNjf`KoZ[_V00?o/;cSojNojonW_n/01_nW
_n/6ojS0j`03ojS1jonY`N_oZL7[00KoZL7[1onX`>/8ojFok0CoYl3[00?o0000ojO0jonW`>/03onX
`>/7ojJok1Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0=ooooo`006Oooool0
0ol0003oZ<3[ojS0j`0;ojS0j`WoYko[1OnW`>/3ojS0j`OoZ<7[0_nX`>/=ojNoj`03ojO0jonX`N_o
Z<7[00_oZ<7[0_nX`>/6ojJoj`KoYko[00?oYl3[ojS1k?nX`N`01_nX`N`5ojS2k0;oYko[1onW_^X6
ojJnjP03ojNojol0003o000000KoYl3[1OnW`>`2ojJgi@OoY[7Q1onU[]d00onV[=coY:7BojBQdP03
ojBQdPOoYZ;A1_nXY=800on]ZM?o[ZK@ojjVd006ojjVd0Ko[ZG?00?o]kKHokF/d?ne[=001One[=04
ok:[d@Co^k;A1onf[]800onn]];o^;?EokRce@07okRce@03ojnggong^]_o]k[K00Co]k[K1?nZ^nH4
ok2lh`SoYko[0_nX`>/5ojS1j`SoZL7[1onX`>/7ojFok0CoYl3[00Co0000ojO0jonW`>_oYl3[3_nX
`>/6ojJok0;oY[o[4oooool3o`0000Cooooo00Go0000okZj^_ooooooV9RHoa0@400?ooooo`003_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooooonX`>/02?nX`>/=ojNoj`03ojO0
jonX`>_oZ<3[00GoZ<3[1OnX`N/2ojS0j`goYko[0_nW`>/<ojS1j`?oYl3[1onV_n/2ojNoj`GoYl3[
2?nX`N`00onX`^coYko[ojNoj`04ojNoj`OoYkkZ0_nV_^X01?nW_n_o0000o`000?l00002ojNoj`Oo
Yl3[00?oYl3/ojJgiOnV]nD01?nV]nD6ojJah@KoYJkM00?oXJ7DojBQd_nTXM801OnTXM86ojJRd@Co
Z:CB1?n]ZM<7ojjVd0Co[ZG?1?ng]]P7okF/d003ok:[dOnk/]7o^k;A00Go^k;A1Onf[]83okjfdPOo
^;?E00?o_[OCokNjfong^]/01_ng^]/00onZ^nKo/;cSok2lh`05ok2lh`KoYko[00?oYkoZojS1jonX
`N/01_nX`N/7ojW1j`SoZ<3[1onU_n`4ojO0j`04o`000?nW`>_oYl3[ojO0j`koZ<3[0_nV_n`6ojJo
jaCooooo00?o0000ooooooooool00_ooool01OnHV9So410@o`000?lQ8B7oc<c<00oooooo000>oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`08ojS0j`coYko[0onW`>/7
ojS0j`03ojS1jonX`>_oZ<3[00CoZ<3[2OnW_n/6ojO0j`SoZ<7[1onW`>/5ojJoj`;oYko[1onW`>/6
ojS1k003ojW2k?nW_n_oYko[00KoYko[1OnW_^X01?nW_n_o0000o`000?l00006ojNoj`?oYl3[0onX
_^T8ojJgi@KoY[7Q0_nU[]d5oj6Qe0KoY:7B1onVX]400onXY=;o[JWCojfYd`04ojfYd`So[ZK@00?o
[ZG?okNff?ng]]P01?ng]]P6okF/d003okc4h?nk/]7o^k;A00Ko^k;A0onf[]86okjfdPGo^;?E0onn
]m<6okNjf`03okbkf?n`_>?o/;cS00Oo/;cS0_nW_n/5ojNojPSoZ<7[1onY`N/7ojS0j`SoYKo/1?nW
`>/00ol0003oYl3[ojO0j`0?ojS0j`SoY[o[5?ooool00ol0003oooooooooo`0Eooooo`003_ooool0
1Ol@413ooooooooooooooooo410@00Kooooo0_l00002ooooo`SoZ<3[2?nW_n/7ojO0j`GoZ<3[0_nX
`N/7ojS0j`SoYko[1onW`>/8ojS1j`OoYl3[00?oY[o[ojNojonW_n/01?nW_n/7ojO0j`;oZ<7/1OnY
`^`8ojNoj`03ojNnj_nW_n_o000000;o00002?nW_n/2ojS1j`KoZ;kY2?nV]nD3ojJah@;oWj;G1onQ
XM@7ojBQdPGoYZ;A00?oZJ[GojfYdon]ZM<01_n]ZM<6ojjVd003okC4i_ng]]So]kKH00Ko]kKH1?ne
[=03okc4h0So^k;A00?o]ZkBokjfd_nn]]801Onn]]83okRce@Ko_[OC0ong^]/4okbkf0Oo/;cS00?o
][oQojNoj_nW_nX01_nW_nX6ojS1j`03ojS0jonY`N_oZL7[00KoZL7[1onX`>/8ojFok0CoYl3[00?o
0000ojO0jonW`>/03onX`>/7ojJojaGooooo00?o0000ooooooooool05?ooool000kooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00?ooooo1onX`>/8ojNoj`OoYl3[00?o
Z<3[ojS1jonX`N/01?nX`N/7ojS0j`SoYko[1onW`>/8ojS1j`GoYl3[0_nV_n/7ojNoj`GoYl3[0onX
`^`6ojW2k0KoYko[0ol00008ojNoj`KoZ<7[1_nX_^T6ojJgi@03oijVfonOX]OoWj;G00CoWj;G1onQ
XM@7ojBQdP03ojJRdOnYZ]OoZJ[G00?oZJ[G1on]ZM<4ojjVd0Co]<CV1ong]]P3okF/d0Go_<CP1_nk
/]400onoan7o_[KBokjfdP07okjfdP03okRceOnn]m?o_[OC00Ko_[OC00?o]k[Kokbkf?nl^mP01?nl
^mP4ok2lh`Co][oQ2?nW_nX2ojS1j`GoZ<3[1onY`N/8ojS0j`OoYKo/1?nW`>/00ol0003oYl3[ojO0
j`06ojS0j`;oZL7[2?nX`>/7ojJojaCooooo00?o0000ooooooooool05?ooool000kooooo00Go0000
ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00Gooooo1OnX`>/:ojNoj`GoYl3[0_nX
`>/7ojS1j`GoZ<3[2_nW_n/3ojO0j`coZ<7[00?oYl3[ojJojonV_n/01?nV_n/7ojNoj`03ojO0jonX
`^coZ<;/00GoZ<;/1_nY`^`2ojNoj`?o00000onV_^/7ojNoj`SoZ<7[1_nX_^T2ojJgi@GoWZKK1_nO
X]L6oj6Qe0KoY:7B00?oYJSIojVZeonYZ]L01OnYZ]L7ojfYd`03ojjVd?nda>Ko]<CV00Go]<CV1ong
]]P00one[=3o_<CPokc4h004okc4h0Go^k;A0onoan47okjfdP03ol?4fonn]m?o_[OC00Ko_[OC00?o
a;kDokbkf?nl^mP01_nl^mP00on`_>?o][oQokJoh@05okJoh@KoYkoZ00?oZKoZojS0jonX`>/01_nX
`>/7ojW1j`SoZ<3[1onU_n`4ojO0j`03o`000?nW`>_oYl3[00;oZ<3[1_nY`N/6ojS0j`03ojO0jonV
_n_oY[o[00GoY[o[5Oooool00ol0003oooooooooo`0Cooooo`003_ooool01Ol@413ooooooooooooo
oooo410@00Gooooo00?o0000ooooooooool01_ooool00onX`>_oYko[ojNoj`0<ojNoj`03ojO0jonX
`>_oZ<3[00CoZ<3[1onX`N/00onX`>_oYko[ojNoj`0:ojNoj`;oYl3[3OnX`N/00onW_n_oY[o[ojJo
j`06ojJoj`GoYko[0_nW`>/8ojS2k0?oZL;/00CoY[k[o`000?l0003o00001onV_^/7ojNoj`SoZ<7[
0onX_^T2oj2/h0OoWZKK1_nOX]L7oj6Qe0;oY:7B1OnUZ=T6ojVZe`Ko[JWC00?o[<kbokC4i_nda>H0
1_nda>H6okNff0;o[=Ge1onla>03ok^bd@Go_lOQ1Onn]]83ol?4f`Ko_[OC0oo4_]@6okbkf003ol:o
f?nf_n7o][oQ00Oo][oQ0_nW_nX5ojVojPOoZ<3[2?nY`N/6ojS0j`03ojS1jonU_ncoYKo/00KoYKo/
1?nW`>/00ol0003oYl3[ojO0j`08ojW1j`;oZ<3[1OnW`>/7ojJojaGooooo00?o0000ooooooooool0
4_ooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o00002?ooool=ojNoj`;oYl3[
1onX`>/5ojS1j`?oZ<3[2?nW_n/6ojO0j`WoZ<7[1OnW_n/8ojJoj`03ojNojonW`>_oYl3[00CoYl3[
1_nX`^`00onX`N_oY[k[o`000002o`0000WoY[k[2OnW_n/6ojS1j`03ojFgi_nP[>3oX:cP00CoX:cP
1onNY]/6oinRe`?oXJ7D0onPY=P8ojFXf@KoZJ[G0_n]ZM<5ojc>lPSo]<CV0_ng]]P6ojcEm@Oo_<CP
00?o^k;Aoko7hOnoan401?noan43okjfdPKo`lCK1?nn]m<5olBne0Co_;_H0oo2_mP7okJoh@;o^/?Q
1onY_nX7ojS0j`SoZL7[0_nX`>/5ojS1j`OoYKo/1?nW`>/01?l0003oYl3[ojO0jonW`>/7ojW1j`Oo
Yl3[1onV_n/Eooooo`03o`000?oooooooooo01;ooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool00ol0003oooooooooo`08ooooo`WoYko[1_nW`>/7ojS0j`03ojS1jonX`>_oZ<3[00Go
Z<3[1onW_n/7ojO0j`SoZ<7[1_nW_n/6ojJoj`;oYko[1onW`>/2ojS2k0?oZ<7[0_l00009ojJnj`go
Yko[0_nX`N/5ojFgiPKoX:cP1_nNY]/5oinRe`03oi^Ne_nPY=SoX:CH00GoX:CH1onUZ=T5ojVZe`?o
YM?g1_n/c_86okC4iP?oPn7j1on/eOD3okc4h0CoXMWk1onoan400onn]];o`lCKol?4f`05ol?4f`?o
_[OC1_o4_]@3okbkf0Go`[oH1?nf_n45ok[3h@GoZKoZ00?oZ/7ZojS0jonX`>/01_nX`>/7ojW1j`So
Z<7[1onU_n`4ojO0j`04o`000?nW`>_oYl3[ojO0j`OoZL7[1onW`>/7ojJojaGooooo00?o0000oooo
ooooool04Oooool001Sooooo00?o0000ooooooooool02Oooool8ojNoj`OoYl3[0onX`>/4ojS1j`So
Z<3[1onW_n/7ojO0j`SoZ<7[1_nW_n/2ojJoj`KoYko[1OnW`>/2ojW2k004ojS1jol0003o0000o`00
00?oZ<7[1onV_^/=ojNoj`03ojRojonU]nKoYKOV00KoYKOV1OnP[>07oijVf`03oinReonKW]KoVikF
00?oVikF1onPY=P7ojFXf@03ojVZeonUdoOoYM?g00GoYM?g1_n/c_82okC4iPOoPn7j0on/eOD5odC5
g@KoXMWk1Onoan400onYd_Go`lCKol?4f`07ol?4f`03okjgdoo4_]Coa;kD00Koa;kD00?o_;_Hol:o
f?o2_mP01Oo2_mP00onf_n7o^/?Qok[3h@06ok[3h@03ojVoj_nZ`N[oZ/7Z00?oZ/7Z2?nX`>/7ojW1
j`OoZ<7[2?nU_n`4ojO0j`03o`000?nW`>_oZ<3[00OoZL7[1onW`>/8ojJojaGooooo00?o0000oooo
ooooool04?ooool001Sooooo00?o0000ooooooooool02_ooool8ojNoj`GoYl3[0_nX`>/7ojS1j`Ko
Z<3[00?oY[o[ojNojonW_n/01_nW_n/5ojO0j`[oZ<7[0onW_n/4ojJoj`OoYko[00CoYl3[ojW2k?nY
`^coZL;/0ol00007ojS1j`OoY[k[2OnW_n/5ojRoj`OoYKOV1_nP[>03oijVf`?oV9_F1onKW]H6oj2T
f0KoYJSI0_nTd_P8ojGCm`?o[<kb0om@cMP3o`0000GoG/Ok00?o2iSCo`d00?l=00001_m4aMd6oj7I
n`03oko7hOnYd_GoZM;e00?oZM;e1oo3a=/00onjbnOoa;kDolBne006olBne003olK5fOo2_mSo`[oH
00Go`[oH0_o6aMT7ok[3h@03okg7h_nZ`N[oZ/7Z00GoZ/7Z2?nX`>/7ojW1j`OoZ<7[2?nU_n`2ojO0
j`;oZ<3[00?o0000ojS0jonX`>/01onY`N/7ojO0j`KoY[o[00?oYko[ooooooooool04oooool2o`00
017ooooo000Gooooo`?o00003Oooool7ojNoj`03ojO0jonX`>_oZ<3[00CoZ<3[1onX`N/2ojS0j`Go
Y[o[2?nW_n/00onW`>_oZ<7[ojS1j`0:ojS1j`;oYko[1onV_n/5ojNoj`;oYl3[0ol00004ojW2k0Go
Z<7[2OnV_^/6ojNoj`;oYl3[1_nX_n/7ojFgiP?oX:cP0_nHWmT7oiRKePKoVikF1onPY=P2ojFXf@Ko
Y=;h1_nUdoL01?m0`/7o=kg;ocNmbolg_L/6ohkBoP?oG/Ok1?nG]>`7ofVfo003o`J;g?lO003o7`00
00?o?kkX1onYd_D4ol?4f`Co^/_W1_o4_]@3olK5f@Go`[oH1?o6aMT4ok[3h@Co_LOR1onZ`NX8ojS0
j`KoZL7[2?nX`N/6ojFok003ojFojonX`>_oZ<3[00;oZ<3[00Co0000ojS0jonX`>_oZ<3[1onY`N/7
ojO0j`;oY[o[1OnW_n/Cooooo`03o`000?oooooo0000017ooooo000Gooooo`03o`000?oooooooooo
00kooooo1OnW_n/2ojO0j`OoZ<3[1OnX`N/3ojS0j`KoY[o[1_nW_n/2ojO0j`WoZ<7[1_nW_n/7ojJo
j`03ojNojonW`>_oYl3[00?o000000?oYl3[ojW2k?nY`^`01OnY`^`00onX`N_oY[k[ojJnj`0;ojJn
j`;oYko[1_nW`>/6ojRoj`?oYKOV0onHY]l6oiROf@OoV9_F1_nKW]H5oj2Tf0?oYLcd1onTd_P2ojGC
m`?oIM[K0onRfO/6ohkBoP03ojJdh_nG]>coUkC/00KoUkC/0omY]_`4oiNcj`?oCJGg00?o1X_Locnn
j?lo_^P01onYd_D00oo3a=_o^/_Wok[;i`05ok[;i`?oa;kD1Oo6aMT3ol:of0Ooa/GI00?o^/?Qokg7
h_nman801?nman86oj[1jP;oZ/;[2?nX`>/6ojW1j`SoZ<7[0_nU_n`5ojFoj`CoZ<3[00?o0000ojS0
jonX`>/02?nY`N/5ojO0j`03ojJojonW_n_oYko[00KoYko[5?ooool00ol0003oooooooooo`0?oooo
o`005oooool00ol0003oooooooooo`0?ooooo`03ojNojonW`>_oYl3[00CoYl3[1onX`>/00onX`N_o
Z<3[ojS0j`05ojS0j`KoY[o[0_nW_n/6ojO0j`OoZ<7[2?nW_n/5ojJoj`04ojNojol0003o0000o`00
00GoYl3[1OnY`^`2ojS1j`_oY[k[1?nW_n/7ojO0j`?oZ;o[0_nN/ND7oiRVg`KoV9oI1_nHVmH7oi^N
eP03oj2Tf?nUc?CoYLcd00GoYLcd0onTd_P2oe??b@?oIM[K1onRfO/2ohkBoPGoY[CR1_nG]>`00on]
]^3oUk?[oiNcj`06oiNcj`KoCJGg0onYd_D4ogK>o`So^/_W00?oa;kDolK5fOo6aMT01Oo6aMT00oo2
_mSoa/GIolK5f@05olK5f@03olW:fonman;o_LOR00Ko_LOR0_nZ`NX6oj[2j`OoZ<3[1onY`N/6ojS1
j`03ojO0jonU_n_oYKo[00KoYKo[1?nX`>/00ol0003oZ<3[ojS0j`08ojW1j`03ojO0jonV_n_oY[o[
00?oY[o[2?nW_n/Dooooo`03o`000?oooooooooo00kooooo000Gooooo`03o`000?oooooooooo013o
oooo1onW`>/5ojS0j`?oZ<7[1onX`>/3ojJoj`CoYko[1onW`>/7ojS1j`SoYko[00?oY[o[ojNojol0
00000_l00002ojNoj`OoYl3[00?oZL;/ojS1jonX`N/01?nX`N/7ojJnj`SoYko[1OnW`>/00onV_^_o
W[7Uoijai@04oijai@OoV:KO1OnHWmT7oiRKeP?oVikF1?nR_^d6ojG<m0CoN^GT0on7jml3ojkWn@Go
X]Wk00?oYkCRojJdh_nV]>801_nV]>83oiNdk0Co[KKP2?nG/n/6odfUm`;o07KH1Omfc_l6ok[;i`03
ojO8lOo6aMWoa/GI00Goa/GI00?oa<SMolK5fOo6aMT01Oo6aMT3olW:f`Ko_LOR0_nnbn@8oj[2j`Oo
Z<3[1onY`N/2ojS1j`GoYl3[1_nU_n/00onV_n_oZ<3[ojS0j`03ojS0j`03o`000?nX`>_oZ<3[00Oo
ZL7[1onV_n/7ojNojaGooooo00?o0000ooooooooool03Oooool001Oooooo0_l0000Booooo`OoYl3[
00?oZ<3[ojS1jonX`N/01OnX`N/5ojS0j`WoYko[1OnW`>/9ojS1j`KoYko[0ol00006ojNoj`?oYl3[
1?nY`^/7ojS1j`OoY[k[2?nW_n/00onW`>_oY[k[ojJnj`03ojJnj`KoW[7U1_nHY]l6oiROf@?oV9_F
0onIZn<8oj:nk@?oYLcd0omjiN@3ohO[g`Oo[^Oi00?oX]WkojNdh_nW]>800onW]>88ojJdhP03oiNd
k?n]]^3o[KKP00Co[KKP1_nG/n/2ojfki0GoM:[d0_lMPnP2o`1ff0;o>ZOd0_mfc_l2ok[;i`GoYlSa
1Oo6aMT3olC8g@Goa/GI1Oo9b]/3okg7hPGo_/_T1_nZ`^/00onY`NcoZ<3[ojS0j`06ojS0j`OoZL7[
1onW`>/2ojFoj`GoY[o[1?nX`>/01?l0003oZ<3[ojS0jonX`>/7ojW1j`OoY[o[1onW_n/Dooooo`03
o`000?oooooooooo00gooooo000Gooooo`03o`000?oooooooooo01;ooooo1OnW`>/3ojS0j`OoZ<7[
00?oZ<3[ojNojonW_n/02onW_n/00onW`>_oZ<7[ojS1j`0;ojS1j`;oYko[00?oY[o[o`000?l00000
0onV_n/5ojNoj`;oYl3[1onY`^/5ojS1j`WoY[k[1_nW_n/2ojS1j`KoY[k[1_nN/ND6oiRVg`?oV9oI
0_nAW=/7oiV[h`SoX[k]00?oYLcdog[Ui?nQm^000_nQm^04ok[bl`?o[^Oi0onX^nL7ojNdhPKoY[CR
00?o[KGNojffh?n]]^001_n]]^02oiNcj`Ko[K_T1OmdZ_@4oaf3j0Co>ZOd1onWb?43olK5f@Goa<SM
0oo6aMT7olW:f`03okg7h_nnbnCo_/_T00Go_/_T0_nZ`^/5ojW1k0KoZ<3[00?oZ<7[ojW1jonY`N/0
1_nY`N/5ojO0j`;oYl3/1onV_n/4ojS0j`03o`000?nX`>_oZ<3[00SoZL7[1_nV_n/8ojNojaCooooo
00?o0000ooooooooool03?ooool001Oooooo00?o0000ooooooooool04oooool00onW`>_oZ<3[ojS0
j`05ojS0j`OoZ<7[3?nW_n/3ojO0j`[oZ<7[0_nW`>/3o`0000KoY[o[00?oYko[ojO0jonW`>/01?nW
`>/7ojW2j`03ojS1jonV_^_oY[k[00_oY[k[0_nW_n/6ojS1j`KoY[k[1_nN/ND3oiRVg`;oSY[K1_nA
W=/7oiV[h`KoX[k]0_nPk?T2oj7fh0Go^_;c00?o]m?^ojRkionX^nL01OnX^nL7ojNdhP;oY[CR1On]
]Mh6ojffh003ok>lh?n]^nCo[K_T00Oo[K_T1OmdZ_@4oaf3j0;o8XW[0_ljYo@7ojO8l@03olK5fOo4
b=goa<SM00Goa<SM00?oa/GIolW:foo9b]/01Oo9b]/00oo;cmgo_/_Tokk;i005okk;i0;o_<gW1onY
`N`2ojS0j`GoZ<7[2?nY`N/00onW`>_oYl3/ojO0k004ojO0k0OoY[o[1?nX`>/00ol0003oZ<3[ojS0
j`06ojW1j`03ojS1jonV_n_oY[o[00GoY[o[1_nW_n/00onW`>_oooooooooo`0Cooooo`03o`000?oo
oooooooo00_ooooo000Gooooo`03o`000?oooooooooo01Gooooo1onX`>/7ojS1j`SoYko[1onW`>/7
ojS1j`04ojO0jol0003o0000o`0000?oYl3[1OnV_n/2ojNoj`OoYl3[1OnY`^/3ojS1j`_oY[k[0onW
_n/7ojS1j`?oY[k[0_nI/>L6oi:ThPKoSY[K1_nAW=/7oiV[h`;oX[k]0onPk?T3oj7fh0Co^_;c1?ng
dnh7ojRki`GoYkCR00?oYk?Qojfeg_n]]Mh01_n]]Mh3ojffh0Co/kcP1on]^n@00ond`nKoQ[;bohJb
lP04ohJblP;o>XW/0_lMPnP4ob:9j`?oYlSa1?nG`?@6olC8g@;o`LSP1_o9b]/3ol_?g@Co_/_T1Onl
cNL5ojW1k003ojO1k?nX`N_oZ<7[00KoZ<7[1onY`N/8ojO0k0KoY[o[1OnX`>/00ol0003oZ<3[ojS0
j`02ojW1j`GoZ<7[1onV_n/2ojNoj`GoYl3[5?ooool00ol0003oooooooooo`0;ooooo`005_ooool3
o`0001Oooooo2?nX`>/6ojS1j`GoYko[0onV_n/7ojO0j`CoZ<7[0ol00007ojO0j`03ojJojonW_n_o
Yko[00CoYko[1onW`>/00onY`^_oZ<7[ojS1j`05ojS1j`OoY[k[1onW_n/5ojS1j`03ojFnjonI/>Oo
VK3W00CoVK3W1_nBY>86ohjJf`KoTIcK1OnIZn<4oj_DmP03oj3/nOnQm^3o^_W/00CoboWX00?o^_;c
okOCk_ngdnh01?ngdnh7ojRki`03ojNdh_nW/n7oYk?Q00?oYk?Q2?n]]Mh00on]]^3o/kcPok>lh004
ok>lh0Co[K_T1?nd`nH6ohJblPCo>XW/1?lRRN/7oiO0m0?oa<SM1Oo1b>03olW:f`KobloM00?o_/_T
okc=ionlcNL01_nlcNL00onY`NcoYl7/ojO1k003ojO1k0SoZ<7[1onY`N/6ojO0k0SoY[o[1?nX`>/0
0ol0003oZ<3[ojS1j`07ojS1j`SoY[o[1onW`>/Dooooo`03o`000?oooooooooo00[ooooo000Foooo
o`03o`000?oooooooooo01Sooooo2?nX`>/6ojS1j`03ojNojonV_n_oY[o[00GoY[o[1OnW`>/00onX
`>_oZ<7[o`000002o`0000CoZ<7[1OnW`>/2ojJoj`OoYko[1OnW`>/2ojW1j`SoZ<7[1_nV_^/8ojNo
j`03ojS1jonU_^_oYKk[00?oYKk[1_nI/>L6oi:ThPGoSY[K1onAW=/00onIZn?oZmCfoj_DmP04oj_D
mP?o^_W/1?o;nNP3olSWk0Ko]m?^0onX^nL3oj6bi0OoYk?Q1_n]]Mh2ojnkhPOo/kcP00?o[K_TokC3
i_nd`nH01Ond`nH6ohJblPCo>XW/0_l[OnP2ob:9j`OoUl3d00?oa<SMol78h?o1b>001Oo1b>000oo9
b]_obloMol_?g@04ol_?g@;obmCQ1onlcNL00onhcN[oYl7/ojO1k005ojO1k0OoZ<7[2?nY`N/2ojO0
k0coY[o[0_nX`>/2ojS1j`03o`000?nX`N_oZ<7[00OoZ<7[2?nV_n/5ojO0j`03ojS0jooooooooooo
017ooooo0ol0000;ooooo`001?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h6ooooo`03o`000?oooooooooo01[ooooo1onX`>/3ojS1j`CoYko[1onV_n/00onW`>_oZ<3[ojS0
j`03o`0000SoZ<7[00?oYl3[ojJojonV_n/01?nV_n/7ojNoj`03ojO0jonY`N_oZL7[00CoZL7[1_nX
`N/00onV_n_oY[k[ojJnj`05ojJnj`KoYko[0_nX`>/6ojFnj`KoVK3W1OnBY>86ohjJf`?oTIcK1OnQ
^n`3oj_DmP?o^_W/1Oo;nNP5olSWk0?o]m?^0_nQ^>T7oj6bi0OoYk?Q0_n]]Mh6ojnkhPGo/kcP0_nf
a>D8okC3iP?oQ[;b0_n6/O43od^7j0;o>XW/1?l[OnP3oiO0m0?oT;Oa1oo1b>02ol79h0GobloM1?o;
e>44okc=i`Co^<gZ1onW`N`7ojS1j`OoZL7[3OnV_n/2ojNoj`CoZ<7[00?o0000ojS1jonX`N/01OnX
`N/2ojO0j`SoY[o[00?oYl3[ojS0jonX`>/00onX`>/?ooooo`?o00000_ooool00ol0003ooooooooo
o`09ooooo`001_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_oo
ool00ol0003oooooooooo`0Kooooo`GoZ<3[00?oZ<7[ojNojonW_n/01_nW_n/5ojJoj`04ojNojol0
003o0000o`0000CoZ<3[1_nX`N/2ojS0j`OoY[o[0onW_n/4ojO0j`OoZL7[0_nX`N/5ojJoj`OoY[k[
0_nW_n/6ojS0j`KoYKk[1_nI/>L5oi:ThP?oSY[K0_n=Wn09oj6kk004oj_Dm_njnNco^_W/ok[ik0Co
boWX1_o8in`00onhd^goXKSYoj6hj@04oj6hj@OoXK;T1OnW/n400onW^>Go[k_RojnkhP07ojnkhP03
ok>lh?nfa>Go]/CU00Co]/CU1_nd`nH00ondb^[oQ[7aohJal@04ohJal@GoBhOX1?l[OnP6oi2gl@Co
`LSP1Oo1bN03ol_?g@KobmCQ00?o_<gWokS=j_nhcNX01OnhcNX3ojO1k0CoYko[1onX`N/7ojW1j`Wo
Y[o[1_nW_n/3ojS1j`03o`000?nX`N_oZ<7[00;oZ<7[1_nW`>/6ojJoj`03ojNojonX`>_oZ<3[00Go
Z<3[2oooool3o`0000Gooooo00?o0000ooooooooool02Oooool000Kooooo00?o0000ooooooooool0
0_ooool01Ol@413ooooooooooooooooo410@00Kooooo0_l0000Mooooo`03ojS0jonX`N_oZ<7[00?o
Z<7[2?nW_n/00onV_n_oYko[o`000002o`0000;oYko[1_nX`>/2ojS1j`KoZ<3[1onV_n/7ojO0j`So
ZL7[1_nV_n/5ojJnj`?oYko[1onX`>/3ojFnj`;oV;?Z1_n=YND5ohFIg`KoSIoP1onQ^n`4okSNl`?o
d_?V00?oboWXolSWk?o8in`00oo8in`4okSBk@KoXKSY1onQ/^@00onW/n7oYkSUojNhi@03ojNhi@Oo
[k_R00?o/<;XokK4iOnfa>D01_nfa>D2okC3iPGo]<[Z1_n6/O44od^7j0?o@WoU0_l[OnP6oi2gl@03
ol78h?o1bN3o`LWP00Ko`LWP00?obloMol_DhOo;e>401?o;e>42olSHi@Ko^<gZ00?o/L[]ojNojonW
_n/01_nW_n/5ojS1j`WoZL7[1OnV_n/2ojFnj`SoYko[0onX`N/00ol0003oZL7[ojW1j`08ojO0j`;o
Y[o[1OnW_n/7ojS0j`Kooooo1?l00008ooooo`03o`000?oooooooooo00Wooooo0006ooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000005ooooo`;o00007oooool6ojS1j`Ko
Yko[00?oY[o[o`000?l000001_nW_n/3ojS0j`CoZL7[1onX`>/7ojJoj`OoYl3[2?nY`N/6ojJoj`03
ojJnjonW_n_oYko[00GoYko[1OnX`>/00onV`>coV;?ZoiRcjP04oiRcjPKoSJGU1On5VMl6ohfOh0Co
XK_/1Onhg_<3om;ciPCof>kR0_o8in`6okSBk@KoXKSY0onQ/^@4oinej0KoYkSU1?n_^n84ok32j0Ko
]/CU0_ngc>X7okC:jPKoQ[7a1?m;QnP5od9oi@?oT;Oa0_nB/^d8ol79h003olG>hOo;e>7obmCQ00Co
bmCQ1?o8f>D3okS=jPCo/L[]2?nW_n/00onX`N_oZL7[ojW1j`0;ojW1j`03ojJojonU_^_oYKk[00Co
YKk[1_nW_n/00onX`>_oZL7[ojW1j`02ojW1j`03o`000?nY`N_oZL7[00KoYl3[00?oY[o[ojNojonW
_n/01OnW_n/7ojS0j`?ooooo0ol0000=ooooo`03o`000?oooooooooo00Sooooo0006ooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo01oo
oooo1_nX`N/2ojNoj`04ojJojol0003o0000o`0000;oY[o[1OnW_n/2ojO0j`OoZL7[1OnX`>/9ojJo
j`GoYl3[2_nY`N/3ojJoj`?oYKk[2?nW_n/00onX`>_oY/3/ojK0k003ojK0k0KoV;?Z1_n=YND5ohFI
g`KoSIoP00?oXK_/okSNlonhg_<01?nhg_<3om;ciPGof>kR0ooAgN86okSBk@?oXKSY0_nI]>/8oine
j0KoYkSU00?o[k_Rok32j?n``^P01On``^P3okK4i@Go]lcZ1Ondb^X00on]angoOZ3YogjPj@04ogjP
j@?oEH;Q0_m;QnP4od9oi@KoT[;]1_o1bN03olG>h@?obmCQ1oo8f>D00onhcN[o/L[]ok7:k@04ok7:
k@OoYko[2onY`N/3ojS1k0SoYKk[0_nW_n/5ojS0j`CoZL7[00?o0000ojW1jonY`N/00_nW`>/5ojJo
j`OoYko[1onX`>/2o`00013ooooo00?o0000ooooooooool02?ooool000Kooooo00?o0000oooooooo
ool00_ooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool08?ooool3ojS1
j`;oYl3[0ol00006ojJoj`03ojNojonW`>_oYl3[00CoYl3[1onY`N/00onX`>_oY[o[ojJoj`0;ojJo
j`03ojO0jonY`N_oZL7[00[oZL7[00?oYl3[ojFnjonU_^/01OnU_^/8ojNoj`KoY/3/1_nH/nX5ohfU
i@GoQIWO1On=Wn03ojO0k0Co^=kc0ooBlnH5omS^hPGodMgR0onhd^d2oj:nk@KoVKC[2?nO]NP3ojNh
i@?oYl3[2?n``^P00onfa>Go]lcZokO<jP05okO<jP03okC:j_n]ango[LO]00?o[LO]1_mnX>T5oeF2
h@Co@WoU1_nB/^d3ol79h0KoaLkQ00?obmCQolSHiOo8f>D01Oo8f>D00oo3enWo/L[]ok7:k@06ok7:
k@OoYko[1onY`N/7ojS1k0KoYKk[00?oY[k[ojS0jonX`>/01OnX`>/4ojW1j`03o`000?nY`N_oZ<7[
00SoY[o[1_nW_n/8ojS0ja7ooooo00?o0000ooooooooool02?ooool000Kooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_l0000Rooooo`04ojO0jol0003o0000
o`0000?oYl3[1OnV_n/3ojNoj`KoYl3[1OnY`N/3ojS1j`[oY[o[0onW_n/9ojW1j`GoYl3[1onU_^/8
ojNoj`KoY/3/1_nH/nX5ohfUi@GoQIWO00?oSIoPojO0k?nW`>`01_nW`>`01?nhg_?od_?Vom;ci_oB
lnH4omS^hPKodMgR00?ob=7Qoj:nkOnR_^d01?nR_^d6oiVdj`KoWkGX00?oW[c^ojO0jonW`>/01OnW
`>/6ok32j0?o/<[]1Ongc>X2okGAkPKo[LO]1_mnX>T4oeF2h@;oGHGQ0_m2OnD7oi:bk@03ol79h?o5
c^7oaLkQ00CoaLkQ0oo;en84olSHi@Co`mOY1_nab^d00onZ`ncoYko[ojNoj`06ojNoj`OoZL7[1onX
`N`2ojFnj`GoY[k[1onX`>/2ojW1j`;oZ<7[00?o0000ojS1jonX`N/01onV_n/7ojNoj`KoZ<3[00?o
Z<7[ooooooooool03oooool00ol0003oooooooooo`08ooooo`001?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`0Oooooo`?o00001onW
`>/00onV_n_oYko[ojNoj`05ojNoj`KoYl3[00?oZL7[ojS1jonX`N/01OnX`N/6ojJoj`OoYko[2?nY
`N/6ojO0j`GoYKk[0onV_n/7ojNoj`?oY/3/0onL^^d5ohZXj@GoOI[T1_n9X><7ojO0k0Co`MKY0ooH
hmh00ooHk^;odMgRom7MhP04om7MhP?ob=7Q1_nR_^d6oiVdj`;oWkGX1OnN_>h7ojO0j`;o/<;X1on`
b^d00ongc>[o]M7^okGAkP04okGAkPKo[LO]1OmnX>T5oeF2h@CoGHGQ0onB/^d4oiZcj@GoaLkQ1Oo;
en800oo8f>Go`mOYol?Gj@05ol?Gj@;o/L[]1OnZ`n`6ojNoj`;oZ<7[1_nY`N/6ojS1k0;oY[o[1onV
_^/3ojS0j`SoZ<7[00?o0000ojS1jonX`N/01onV_n/7ojNoj`;oZ<3[1OnX`N/@ooooo`03o`000?oo
oooooooo00Sooooo000Eooooo`03o`000?oooooooooo01cooooo0ol00004ooooo`GoYl3[0onV_n/7
ojNoj`?oYl3[1?nX`>/7ojS1j`KoY[o[1onW_n/8ojW1j`KoYl3[00?oYKk[ojJojonV_n/01OnV_n/5
ojNoj`03ojS1jonL^^goW;[]00GoW;[]1On:Z>T5ogfJi0KoRJ3S1?nW`>`5ol7Fj@Cof>?N0_oKg=L3
om7MhPKob=7Q1_nR_^d3oiVdj`?oUKW`1onN_>h5ojO0j`;oYlSa1on`b^d00on`dO;o]M7^okGAkP06
okGAkP?o[LO]0_nH[>@4ogV?g0;oOZ3Y1OmEP^43oef5h@SoV[?Y0oo5c^45ol_GhP;oc]oU1_o3enT2
okcEk0OoZ/?/0_nW_n/6ojS1j`KoZL7[0_nX`N`6ojJoj`GoY[k[00?oYko[ojS1jonX`N/02_nX`N/0
0ol0003oYl7[ojJoj`06ojJoj`KoYko[00?oYl3[ojS1jonX`N/01_nX`N/?ooooo`03o`000?oooooo
oooo00Sooooo000Eooooo`03o`000?oooooooooo01Wooooo0ol00008ooooo`03ojO0jonV_n_oY[o[
00GoY[o[1OnW_n/00onW`>_oZ<3[ojS0j`06ojS0j`GoZ<7[0_nW`>/6ojJoj`GoYko[0onX`>/7ojW1
j`?oYl3[1?nU_n/7ojJoj`03ojNojonX`N_oZ<7[00?oZ<7[1onL^^d5ohZXj@GoOI[T1_n9X><00onW
`>co`MKYol7Fj@04ol7Fj@Gof>?N0ooKg=L00ooAgN;ob=7QolSAh@06olSAh@?oX[k]0onH^^l6oiFi
l0OoW[c^00?oYl3[ojO8lOnWb?401?nWb?44ok3:k@Co/=7b1_nedNh00on^ancoV:cToiR/i004oiR/
i0GoNHoL0omQO=L2oeF2h@CoGHGQ2?nJ/nT00oo5c^7obmORol_GhP03ol_GhPCoc]oU0oo3enT5okcE
k0GoZ/?/0_nW_n/8ojS1j`?oZL7[0onY`^/8ojJoj`03ojJnjonW_n_oYko[00?oYko[2OnX`N/2ojO1
j`03o`000?nW`N_oYl7[00OoY[o[0_nW_n/5ojO0j`OoZ<7[3oooool00ol0003oooooooooo`08oooo
o`005Oooool00ol0003oooooooooo`0Fooooo`?o00003Oooool7ojJoj`03ojNojonW`>_oYl3[00?o
Yl3[2?nX`>/00onX`N_oYl3[ojO0j`04ojO0j`KoY[o[00?oYko[ojS0jonX`>/01OnX`>/5ojW1j`03
ojS1jonU_n_oYKo[00KoYKo[1onV_n/6ojS1j`OoW;[]1On:Z>T4ogfJi0GoRJ3S0onT^^T4ol7Fj@Go
f>?N1?oKg=L00ooGd]Cob=7QolSAh@05olSAh@;o_/GP1_nH^^l6oiFil0?oW[c^1OnLa?@6ojO8l@03
ok3:kOn`dO;o/=7b00Go/=7b0_nedNh5ojk7k0KoV:cT1OmiSm`5of5le`CoGHGQ1_nJ/nT3ojRlj0?o
bmOR1_o>gnD00oo3enWo_=G/okcEk005okcEk003oj[3k?nW_n_oYko[00CoYko[1onX`N/7ojW2j`Ko
Y[o[00?oY[k[ojNojonW_n/01OnW_n/7ojS1j`CoYl7[00?o0000ojO1jonW`N/00onV_n/4ojNoj`Oo
Yl3[1onX`N/?ooooo`03o`000?oooooooooo00Oooooo000Dooooo`;o00005Oooool3o`00017ooooo
1onV_n/6ojO0j`KoZ<3[0_nY`N/7ojO0j`OoY[o[1onX`>/00onY`N_oZ<7[ojS1j`03ojS1j`SoYKo[
1onV_n/6ojS1j`?oW;[]0on=/>h5ogZQj`CoOIcV00?oOI[TohVPhonT^^T01onT^^T00oo1e^Wof>?N
omSSgP03omSSgPGofmcG0_oGd]@4olSAh@Go_/GP1_nH^^l3oiFil0?oTkoe2?nLa?@3ojO8l@CoYLof
1On`dO82ojk?l@Oo[/O/1OnH[>@6ogV?g0CoHGcG1?miTMh00omMQN7oV[?YoiZcj@07ojRlj003ol_G
h_o>gnGoc]oU00Coc]oU0_o9hnX6okcEk003ok7<k_nW_n_oYko[00KoYko[1onX`N/7ojW2j`;oY[o[
1OnV_^/7ojNoj`OoZ<7[1?nW`N/00ol0003oY[o[ojJoj`07ojNoj`GoYl3[2OnX`N/>ooooo`03o`00
0?oooooooooo00Oooooo000Dooooo`03o`000?oooooooooo01;ooooo0_l0000Eooooo`OoY[o[1_nW
`>/2ojS0j`KoZL7[1OnW`>/9ojJoj`GoZ<3[0_nY`N/6ojS1j`KoYKo[0_nU_^/7ojJoj`?oZ<7[1?nU
_n`5ohf`kPGoNZ7[1OmmW>H7ojBjj@?o^/WV0ooHhmh5om_Le`Coem;D00?ob=7Qokk5h?nnaN001_nn
aN03oiRjk`?oVK[_1_nC_oD6oic4m0;oV/Wh1onUcoH00on`dO;o[/oaojk?l@04ojk?l@Oo[/O/1OnH
[>@5ogV?g0GoHGcG1OmiTMh7ojRlj0;o^/cX1?o>gnD5olWSjP;o_=G/1Onac>h6ojNoj`;oYl3[1onX
`N/3ojW2j`?oZ<7/2?nV_^/3ojNoj`?oZ<3[2?nX`N/01OnW`N_oY[o[ojJojonV_n_o000000;oY[o[
1onW_n/00onW`>_oZ<7[ojS1j`09ojS1j`03ojO0jooooooooooo00cooooo00?o0000ooooooooool0
1oooool001Cooooo00?o0000ooooooooool03oooool3o`0001Sooooo1onV_n/3ojO0j`CoZ<3[1onY
`N/00onW`>_oY[o[ojJoj`0;ojJoj`03ojS0jonY`N_oZL7[00CoZL7[1_nX`N/2ojFoj`KoYKk[1OnV
_n/2ojNoj`OoYKo/1On=/>h5ogZQj`GoOIcV1?nT^^T6ok[9iP03omSSg_oKg=OofmcG00?ofmcG1OoG
d]@00ooBam3o_/GPokk5h005okk5h0;o^kcJ1_nI^^l6oi>om@;oW<Cd1_nJbOP5ojG?mP?oY/cd1_n^
co43ojk7k0?oVYkG1On9T=@4ogN2d@;oNHoL1?mQO=L6ogVAgPCoZ;cX1Onjc>P00oo>gnGobN?ZolWS
jP04olWSjP;o`=c^1onac>h2ojNoj`KoYl3[1OnX`N/00onY`^coZ<7/ojS1k005ojS1k0OoY[k[1onX
`>/7ojS1j`CoY[o[00Co0000ojJojonV_n_oY[o[0onW_n/3ojO0j`WoZ<7[1OnW`>/=ooooo`03o`00
0?oooooooooo00Oooooo000Dooooo`03o`000?oooooooooo00cooooo0ol0000Looooo`GoY[o[0_nW
_n/7ojS0j`GoZL7[0onX`N/;ojJoj`;oYko[1onY`N/3ojS1j`CoYl3/1onU_^/00onV_n_oYko[ojNo
j`04ojNoj`OoYKo/1On=/>h4ogZQj`KoOIcV00?oY;[Yok[9i_njbNH01OnjbNH3olc>g0?ofmcG1OoG
d]@3om;7d0Co_/GP1Onk_=X6oiVjk`?oTkoe1?nF`?@7oi[9n003ojG?m_nVc?CoY/cd00GoY/cd0on^
co42ojJZfPOoVYkG1On9T=@5ogN2d@;oLX?D0_mQO=L7ogVAgP03ojRlj?njc>So^/cX00Co^/cX0oo9
h^X3olWSjPGo`=c^1Onac>h2ojS1k0SoYl3[00?oZ<7[ojW2k?nY`^`00onY`^`7ojS1k0OoY[k[1onX
`>/7ojS1j`CoY[o[00?o0000ojJojonV_n/01onW`>/7ojS1j`OoYl3[3?ooool00ol0003ooooooooo
o`07ooooo`004oooool3o`0000[ooooo0ol0000Pooooo`03ojJojonW_n_oYko[00CoYko[1onX`>/0
0onY`N_oZ<7[ojS1j`05ojS1j`OoY[o[1_nW_n/8ojW1j`KoYl3/1OnU_^/2ojJoj`OoYko[0onU_n`3
oiblk`GoPJ[_1?m^V^/01?mjXN_oOIcVogfLi_mmW>H3oi6/j0Ko^/WV1Oo<c]`00ooKg=Ooem;DomOB
e003omOBe0God/O@00?o_/GPok^lf_nk_=X01_nk_=X3oiVjk`CoX[7R1_nF`?@3oi[9n0CoWl;a1_nV
c?@7ojJZfPKoVYkG1On9T=@6ogN2d@CoLX?D0omiTMh4oiBZi@Go^/cX1Oo9h^X00oo9hn[o`=c^ol3L
kP05ol3LkP03ok7<k_nX`NcoZ<7/00CoZ<7/1_nW`>/00onX`N_oZL;/ojW2k005ojW2k0GoZ<7/2OnV
_^/3ojS0j`_oZ<7[1?nV_n/00ol0003oY[o[ojJoj`07ojO0j`OoZ<7[1onW`>/;ooooo`03o`000?oo
oooooooo00Oooooo000Dooooo`03o`000?oooooooooo00Kooooo0ol0000Uooooo`KoYko[2?nX`>/7
ojS1j`KoY[o[1onW_n/8ojW1j`KoYl3/00?oYKk[ojJojonV_n/01?nV_n/5ojNoj`;oZ<3[1_nL_>l5
oh6Zk`CoKY[[1onA[>P3ok[9iPOoc<kL0_oCc=<3omOBe0Kod/O@2?nk_=X00onn/m3oX[7Roj:ahP06
oj:ahP?oU/3d0onR/>87oio2l@;oY/cd2onVZ]X5oiZNe`KoRI3D1OmgP]44og:3e0SoU:[U0onjc>P5
olWRjP;obN[]1_o0g>h00oned^ooZ<7/ojS1k006ojS1k0;oYl3[1OnX`N/7ojW2k003ojS1k?nV_^_o
Y[k[00WoY[k[00?oYl3[ojS1jonX`N/02onX`N/00onW`>_oY[o[ojJoj`02ojJoj`03o`000?nV_n_o
Y[o[00KoYl3[00?oZ<3[ojS1jonX`N/01_nX`N/3ojO0j`?oYko[2oooool00ol0003oooooooooo`07
ooooo`005?ooool00ol0003oooooooooo`03ooooo`?o0000:Oooool6ojNoj`SoZ<3[1OnX`N/2ojO0
j`KoY[o[1OnW_n/3ojS0j`OoZL7[0onW`>`3ojFok0OoY[o[00?oYko[ojS0jonX`>/01?nX`>/6oibl
k`GoPJ[_1?m^V^/7oi6/j003ok[9i_o<c]coc<kL00Goc<kL1?oCc=<00ooGd]Cod/O@om;7d004om;7
d0;ocKg;1_nk_=X3okjcd0KoX[7R00?o/:WAoj:`h_nR/>801OnR/>85oio2l@03ojJTdonVZ][oYZ[J
00_oYZ[J1_nJW]L5ohV@e0KoMh;A1?mbPm@8oiBZi@03ok[<j?o9h^[obN;Z00?obN;Z1?o9j^d2ol3L
kPGo]M;_1_nX`N`00onW_n_oZ<7[ojS1j`06ojS1j`KoZL;/2OnV_^/5ojO0j`WoZ<7[1OnW`>/4ojJo
j`03o`000?nV_n_oY[o[00;oYl3[1OnX`>/7ojS1j`OoYko[2oooool00ol0003oooooooooo`06oooo
o`004oooool01?l0003oooooooooooooool3o`0002gooooo1_nW_n/8ojS0j`03ojS1jonW`>_oYl3[
00CoYl3[1_nV_n/00onW_n_oZ<3[ojS0j`05ojS0j`OoZL7[1_nU_n`8ojJoj`KoZ<3[1_nL_>l5oh6Z
k`CoKY[[1OnA[>P3ojJkj0Goc<kL1OoCc=<00ooDalkod/O@om;7d003om;7d0CocKg;0onk_=X6okjc
d0?oX[7R1?n`ZM47oj:`hP03oio2lOnVY=?oYZCC00?oYZCC3OnVZ]X3oiZNe`;oThc91?n5Q<X2ohV@
e0GoMh;A1OmbPm@6oiBZi@;oZl;Z0oo9h^X5olWZk@?o_^7`1_ned^l2ojS1k0GoYko[1_nX`N/8ojW2
k0OoY[k[1onW`>/5ojS1j`;oZ<7/1onW`>/3ojJoj`03ojNojol0003oYko[00SoZ<3[1onX`N/7ojNo
j`[ooooo00?o0000ooooooooool01_ooool001?ooooo1?l0000aooooo`KoYko[1_nX`>/2ojW1j`Oo
Yl3[1_nV_n/8ojS0j`OoZL7[1_nU_n`8ojJoj`KoZ<3[0onL_>l3oi:hl@CoLjGa1?m]W^h00om^V^_o
TJcXojJkj006ojJkj0?oc<kL1_oCc=<2omC7cP?od/O@1_o=_L/00onk_=[o_[?@okjcd006okjcd003
oj:ah_n`ZM7o/:WA00Co/:WA1OnR/>800on^X/coYZCCojJTd`05ojJTd`[oYZ[J0_nLT/T6oi><b@Go
QHC:1?mnQM02ogN2d@GoLX?D0_nDZ^D6oj_2jP03olWRj_o9j^gobN[]00;obN[]1_nnhO03okGBk`?o
ZL;/1onW_n/2ojS1j`coZL;/1onV_^/7ojO0j`03ojS1jonX`NcoZ<7/00CoZ<7/1OnW`>/2ojJnj`Co
Yko[00?o0000ojNojonX`>/01OnX`>/9ojS1j`KoYko[2_ooool00ol0003oooooooooo`06ooooo`00
4oooool2o`0003Cooooo1_nW_n/2ojS0j`KoZL7[1OnW`>/2ojJok0KoY[o[2?nX`>/7ojW1j`KoYKo/
2?nV_n/3ojS0j`?oYl3[1_nB^?44og>Ul@GoKIk^2?nV^nP00oo<c]codlcCom?<d`04om?<d`Coe<O>
00?od/O@olfmboo=_L/01Oo=_L/8okjcd003okj[a_n`ZM7o/:WA00Ko/:WA00?oX[3RojjRc?n^X/`0
0on^X/`6ojJTd`KoYZ[J00?oXiK7oibBbOnLT/T01?nLT/T5oi><b@KoQHC:1OmnQM06ohnPh0KoZl;Z
1?o2iO000oo9j^go_^7`okkQl004okkQl003okCBl?nY`^coZL;/00GoZL;/1OnW_n/2ojS1j`[oZL;/
0onV_n/8ojJnj`?oYl3[0onX`N/8ojS1k003ojO0jonV_^_oY[k[00CoY[k[0onW_n/00ol0003oYko[
ojNoj`02ojS0j`_oZ<7[2?nW_n/9ooooo`03o`000?oooooooooo00Kooooo0005o`0000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo03;ooooo0onW_n/4ojO0j`OoZL7[
00?oYl3[ojJok?nV_n`01?nV_n`6ojJoj`SoZ<3[1OnY`N/00onX`N_oYKo/ojFok005ojFok0SoY[o[
1_nW`>/6oi:hl@CoLjGa1Om]W^h6ojJkj0;o/l?V1OoCc=<5omC7cPOocKg;0_o:]/L6okjcd0?o_Z_6
1_n`ZM400onfX/Go[Z;<ojjRc005ojjRc0KoYZCC0_nVZ]X5oj>Fa`GoW9;91_nCS<T5ohF4bPKoOXG@
1_n?X>03oj_2jPGo`^G`0_o4k_04okkQl0Co]=;`1onY`^`00onW_n_oZ<7[ojS1j`04ojS1j`KoZL;/
1onV_n/6ojJnj`03ojO0jonX`N_oZ<7[00GoZ<7[1_nX`N`00onW`>_oY[k[ojJnj`06ojJnj`?oYko[
00?o0000ojO0jonW`>/02OnX`N/<ojNoj`Sooooo00?o0000ooooooooool01_ooool00005oiRHV?lQ
8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Wooooo00?o0000oooooooo
ool0<oooool6ojO0j`OoZL7[1onV_n`3ojJoj`CoYko[1onX`>/00onY`N_oZ<7[ojS1j`03ojS1j`Oo
YKo/2?nV_n/6ojO0j`?oT[Sa0_n9]O<4ofJRl`03og>UlOm]W^koKIk^00?oKIk^0_nV^nP6ok?3iP?o
dlcC1_oDalh00ooB`lcocKg;olfmb`03olfmb`Cob[K70onn/m06okj[aPCo/:WA0onfX/D6ojjRc0Go
YZCC00?oZIS4oj>FaonSU/L01OnSU/L6oibBb@GoThc91_n5Q<X5ogj5d0OoSj3P00?oZl;Zol;Ul?o2
iO000oo2iO04olC^l003okkQl?ndd_3o]=;`00Go]=;`0onY`^`3ojNoj`SoZ<7[1_nY`^`7ojJoj`;o
Y[k[1OnW`>/7ojS1j`;oZ<7/1OnW`>/6ojJnj`03ojNojonW`>_oYl3[00;oYl3[00?o0000ojO0jonW
`>/01_nX`N/>ojNoj`Sooooo00?o0000ooooooooool01_ooool00004oooooonHV9So8B4Qonk^kPCo
oooo00Go410@oooooooooooooooooa0@400:ooooo`03o`000?oooooooooo03?ooooo1_nW`>/7ojW1
j`SoY[o/1_nW_n/5ojS0j`;oZL3[1_nX`N/8ojFok0OoY[o[0onW`>/3ojK0k0GoRKGc1OmVX_<5ogFW
l@So/l?V00?odlcComC7c_oDalh01?oDalh3om;3c0?ocKg;1_o:]/L00onn/m3o_Z_6okj[aP05okj[
aP?o/:WA1?nfX/D7ojjRc003ojJTdonYV<CoZIS400?oZIS41_nSU/L6oibBb@GoThc91_n5Q<X5ogj5
d0KoSj3P0_nWa>h3ol;Ul0Goa>k`0onjhO<5okCBl003ojS1jonW_n_oYko[00GoYko[1_nX`N/00onX
`^coZL;/ojW2k005ojW2k0GoY[o[0_nV_^/7ojO0j`?oZ<7[0onX`N`8ojO0j`;oY[k[1OnW_n/4ojO0
j`03o`000?nW`>_oYl3[00KoZ<7[3_nW_n/7ooooo`03o`000?oooooooooo00Kooooo0002ooooo`03
oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000;ooooo`;o0000=?ooool3ojO0
j`?oZ<3[1onY`N/8ojJok0KoYko[00?oZ<3[ojW0jonY`>/01?nY`>/6ojS1j`SoYKo/1OnV_n/2ojNo
j`KoY/3/1On9]O<5ofJRl`GoMJOa1_nc`nH2okW5h`Goe<O>1OoB`l`00oo=_L_ob[K7olZfa`05olZf
a`Wo_Z_600?o/:WAokJRaOnfX/D01?nfX/D5ojjRc003ojnJ`_nYV<CoZIS400CoZIS41onSU/L5oibB
b@KoThc91_n5Q<X5ogj5d0;oSj3P1_nWa>h00oo2iO3oa>k`olC^l002olC^l0Ko^^7c00?o]=;`ojS1
jonX`N/00onX`N/7ojNoj`;oZ<7[1OnX`^`7ojW2k003ojJojonV_^_oY[k[00CoY[k[1OnW`>/2ojS1
j`KoZ<7/1_nW`>/00onV_n_oYko[ojNoj`06ojNoj`?oYl3[00?o0000ojS1jonX`N/01onX`N/>ojNo
j`Oooooo00?o0000ooooooooool01Oooool000?ooooo00?oMgMgofIVI_ooool00_ooool01Ol0003o
oooooooooooooooo000000gooooo00?o0000ooooooooool0<_ooool6ojS0j`GoZL7[0onX`>/7ojJo
k0KoYko[1onY`>/3ojS1j`CoYl3[1onU_n`00onV_n_oYko[ojNoj`04ojNoj`KoY/3/1On9]O<5ofJR
l`GoMJOa0_nc`nH6okW5h`?oe<O>1_oB`l`7olZfa`;obK?51onnZlH00onoZL?o]Z;5okJRa@05okJR
a@?o[Z;<1?n_V/86ojVHa0KoXiK71_nLT/T3oi><b@;oTHg;1_n<T]@6oiNYh`KoYlC^1?nkkO@00oo4
k_3o^^7cok[Ql`04ok[Ql`03ok3=konX`N_oZ<7[00GoZ<7[1OnW_n/2ojS1k0OoZ<;/0onY`^`3ojNo
j`SoY[k[00?oYl3[ojS1jonX`N/01?nX`N/6ojS1k0;oYl3[1OnV_n/6ojNoj`03ojO0jonX`N_oZ<7[
00;oZ<7[00?o0000ojS1jonX`N/01OnX`N/>ojNoj`03ojO0jooooooooooo00Gooooo00?o0000oooo
ooooool01Oooool000Cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo
00cooooo00?o0000ooooooooool0<_ooool6ojS0j`03ojW1jonX`>_oZ<3[00GoZ<3[1_nV_n`7ojNo
j`GoZL3[0onY`NX6ojO0j`OoYKo/1onW_n/3ojK0k0?oYKo/1On4]?@5oefQm0GoNZoe2?niaN<00ooD
alkod/?<om;3c004om;3c0;oc/;>1Oo:]/L4olVca@Go_Z_60onoZL<7okJRa@03ojjRc?n_V/;o[i[2
00?o[i[21_nYV<@5oj>Fa`03oj:CaOnJS/KoVXk600CoVXk61_nASL/6ohbBe0KoUjWS0onWa>h5ok_]
m0?o_>gd0_njhO<5ok3=k`OoZ<7[00?oYko[ojS1k?nX`N`01?nX`N`7ojS2k0KoYko[1_nV_^/00onW
`>_oZ<7[ojS1j`06ojS1j`?oZ<7/0onX`>/7ojJoj`;oYko[1OnW`>/4ojS1j`04o`000?nX`N_oZ<7[
ojS1j`koYko[1OnW`>/6ooooo`03o`000?oooooooooo00Gooooo00001Ol0003o^[ZjoooooonHV9So
410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0?ooooo`03o`000?oooooooooo03;ooooo3_nX
`>/6ojJok0OoYko[00?oZL3[ojW1j_nY`NX01OnY`NX6ojO0j`OoYKo/1OnW_n/2ojO0j`KoYKo/1On4
]?@5oefQm0GoNZoe1_niaN<2okW5i0God/?<1?o>`/h3olZfa`GobK?50onnZlH5oknY``Ko]Z;500?o
^J?3ojnJ`_n_V/801On_V/86ojVHa003oj>FaonRTlGoXY?500?oXY?51_nJS/H5oi6=b`OoS9;D1_nG
ZN<00onWa>ko^ngdok_]m002ok_]m0Co_>gd0_ndfo@7ok3=k`?oZ<7[0onW`>/8ojS1k0OoZ<;/1_nW
_n/2ojJnj`GoYl3[1_nX`N/00onX`NcoZ<3[ojS0j`05ojS0j`GoY[o[00?oYko[ojO0jonW`>/01_nW
`>/3ojS1j`03ojS1k?l0003oZ<7/00goYko[2?nW`>/5ooooo`03o`000?oooooooooo00Gooooo0000
1OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0@ooooo`;o0000
=?ooool=ojS0j`KoY[o/1OnW_n/2ojO0j`SoZL7Z0onW`>/3ojO0k0OoYKo/00?oYko[ojO0jonW`>/0
1?nW`>/6ojFok0GoQ;Cd1OmMXO@5ogZ_m@;o^LGS1_niaN@3om;3c0Koc/;>00?ob[K7olVcaOo9/lD0
1Oo9/lD00onnZlKo_jW3oknY``04oknY``Go]Z;50oniXl<6ojnJ`PGoZIS400?oZi[6oj:CaOnRTlD0
1?nRTlD6oiZ>aPKoTHg;1on<T]@3oiNYh`GoZ]Og00Co^ngdokc]m?nlkOCo_>gd1Ondfo@5ok3=k`;o
Yko[1_nW`>/6ojS1k0WoZ<;/0onW_n/3ojJnj`OoYl3[0_nX`N/5ojS1k0OoZ<3[00?oY[o[ojNojonW
_n/00onW_n/6ojO0j`03ojS1jonX`NcoZ<7/00;oZ<7/00?o0000ojS1k?nX`N`03OnW_n/6ojO0j`03
ojS1jooooooooooo00?ooooo00?o0000ooooooooool01Oooool001oooooo00?o0000ooooooooool0
<_ooool=ojS0j`KoY[o/00?oYko[ojO0jonW`>/01?nW`>/6ojW1jP;oZ/7Z1_nW`>`5ojFok0;oY[o/
1onW`>/6ojFok0KoQ;Cd1?mHXoH6ogFcn0Oo^LGT00?od/?<olk2c_o>`/h01?o>`/h00oo8`mKobK?5
olVca@06olVca@So_jW30_nfX/D5okVS``Oo[i[200?oZIS4oj^Ja_n[V/H00on[V/H6oj:Ca@KoVXk6
1OnASL/6ohbBe0;oXKo^1_nZeoL3ok;bm003okc]m?ndfoCo]=_d00Go]=_d00?o/<g_ojNojonW_n/0
1?nW_n/6ojO0j`;oZ<7/2onX`^`00onV_^[oY[k[ojJnj`05ojJnj`GoYl3[2OnX`N`3ojS0j`?oYkk[
1onW_n/2ojO0j`GoZ<7[1?nX`N`00ol0003oZ<7/ojS1k00=ojNoj`;oYl3[1OnX`N/4ooooo`03o`00
0?oooooooooo00Gooooo000Pooooo`03o`000?oooooooooo03;ooooo3OnX`>/6ojJok0OoYl3[0_nY
`NX6oj[1jPKoYl3/00?oYKo/ojJok?nV_n`01?nV_n`7ojO0j`KoYKo/1_n4]?@4oeRSmPKoMK?h1Oni
aN@2okC8j@Goc/;>0oo8`mH6olVca@;obK_=1onoZL<00onfX/Go^J?3okVS``05okVS``Go[i[200?o
]:G:oj^Ja_n[V/H01?n[V/H6oj:Ca@KoVXk61_nASL/2ohbBe0KoXKo^0_nZeoL5ok;bm0?o/^Cg1Ond
fo@2oj[3k0OoYko[0onW`>/4ojS1k0SoZ<;/1OnV_^X7ojJnj`03ojO0jonX`NcoZ<7/00WoZ<7/00?o
Z<3[ojNnjonW_^/01OnW_^/5ojNoj`;oYl3[1onX`N/3ojS1k003ojNojol0003oYko[00_oYko[0_nW
`>/8ojS1j`?ooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool0<_ooool;
ojS0j`?oYl3[1OnV_n`8ojO0j`OoZ/7Z0onW`>`:ojJok0OoYl3[1_nU_n`3ohBdm0?oR;Od0omJYoL0
0omHXoKoMK?hogFcn004ogFcn003okW5i?ndb>Wo]<SY00Co]<SY0oo>`/h5olS3ePCobK?50oo9^ld6
oknY``03ol>ec?niXl?o^J?300Ko^J?31?n_V/83okBUbPKoZi[61OnRTlD7oiZ>aP?oTHg;0onO/^D6
oj6okPCoYnkh00?o/_;dok;Tmonbi?L01Onbi?L00ondfoCoZ/?/oj[3k004oj[3k0GoYko[2OnX`N`3
ojS2k0?oZ<7[1onV_^X3ojJnj`?oYl3[2OnX`N`5ojS0j`OoYkk[00?oYko[ojO0jonW`>/01?nW`>/5
ojS1j`03ojS1k?nW_n_oYko[00;oYko[00?o0000ojNojonW_n/01onW_n/6ojO0j`KoZ<7[00?oZ<3[
ooooooooool00_ooool00ol0003oooooooooo`04ooooo`008_ooool00ol0003oooooooooo`0boooo
o`OoZ<3[1onW`>/5ojJok0SoYl3[1onZ`NX=ojJok0OoYl3[0onU_n`3ojJok0KoR;Od1OmJYoL5of>a
n`Oo]<SY00?oc/;>olS3e_o8`mH01?o8`mH3olVca@GobK_=1?noZL<3ol>ec0Oo^J?30on_V/84okBU
bPKoZi[61_nRTlD3oiZ>aP?oXZkP1onO/^D3oj6okPGoYnkh0_n^joP6ok;Tm`;o[/c_1onZ`n`00onW
_n_oZ<7/ojS1k009ojS1k003ojS2k?nX`N_oZ<7[00GoZ<7[1OnV_^X2ojJnj`KoYl3[1onX`N`7ojS0
j`?oYkk[0onW_n/8ojO0j`03ojS1jonX`NcoZ<7/00?oZ<7/1?nW_n/00ol0003oYko[ojNoj`07ojNo
j`KoYl3[0_nX`N/5ojS0j`?ooooo00?o0000ooooooooool01?ooool002?ooooo0_l0000cooooo`?o
Z<3[1?nY`>/7ojO0j`KoY[o/1onW`>/7oj[1jPgoY[o/1OnW`>/2ojO0k0KoY[o/1_n8]o@6oeZWm`Co
Hk7k1Ondb>T00onTc_Kob<?FolS3eP06olS3eP03olVcaOo9^lgobK_=00CobK_=0onoZL<4ol>ec0So
^J?300?o[i[2okBUb_ndYLX01?ndYLX5oj^JaPGoXY?500?oYk3Noj:^h?nR[^001OnR[^07oinbi@03
oj6ok_nWk_SoYnkh00;oYnkh1On^joP2ok;Tm`Ko[/c_0onZ`n`3ojO0j`WoZ<7/1OnX`^`7ojS1j`03
ojJnj_nV_^_oY[k[00CoY[k[1_nW`>/7ojS1k0GoZ<3[0_nW_^/6ojNoj`KoYl3[2?nX`N`4ojNoj`03
o`000?nW_n_oYko[00OoYko[0onW`>/2ojS1j`SoZ<3[0_ooool00ol0003oooooooooo`04ooooo`00
9Oooool00ol0003oooooooooo`0booooo`KoZL3[1onW`>/7ojJok0KoYl3[1onZ`NX=ojJok003ojO0
jonW`>coYl3/00CoYl3/1_nV_n`3ohRgm0CoTKWb1OmT[_T3odZYn003of>anondb>WoY<kf00CoY<kf
1_o8`mH00onjb^OobK_=olVkc@06olVkc@03oknY`oo3]Lco`kG<00Co`kG<1_niXl<00onm]mCo]:G:
okBUbP05okBUbPKoZi[600?oXY?5ojN`g_nW/=h00onW/=h6oj:^h0KoWk;U0onNiO`00onWk_So[^_h
ojk[n004ojk[n0?o[]Cd1On^c>l2ojNoj`KoYl3[1OnX`N`9ojS2k0?oZ<7[0onV_^X8ojJnj`?oYl3[
2_nX`N`00onX`>_oYkk[ojNnj`04ojNnj`KoYko[0_nW`>/:ojS1k0KoYko[00?o0000ojNojonW_n/0
1OnW_n/00onW`>_oZ<7[ojS1j`04ojS1j`KoZ<3[00CoYko[oooooooooooo00001_ooool002Kooooo
00?o0000ooooooooool0<_ooool6ojW0j`OoYl3[1onV_n`6ojO0j`GoZ/7Z0_nZ`>X;ojJok0;oYKo/
1onW`>`3ojJok0?oYl3[1onA^O85ofB^n@GoBZWh1OnTc_H3olS3ePCo^/[W1_o9^ld00onna^7o`kG<
ol>ec005ol>ec0Co^J?31?nm]m@6okBUbPGoZi[600?o[;OQojN`g_nW/=h01OnW/=h6oj:^h0;oWk;U
1OnNiO`4oj;]n@03ojk[n?n^e?Co[]Cd00Go[]Cd00?o[/c_ojNojonW_n/01?nW_n/6ojO0j`03ojS1
k?nX`^coZ<;/00WoZ<;/0_nW_n/6ojJnjPKoY[k[00?oYl3[ojS1k?nX`N`02?nX`N`3ojNoj`SoYkk[
0onW_n/2ojO0j`WoZ<7/2OnW_n/00ol0003oYko[ojNoj`02ojNoj`GoYl3[1_nX`N/2ojS0j`GoYko[
00?oooooo`000?ooool01Oooool002Oooooo00?o0000ooooooooool0<_ooool6ojW0j`OoYl3[1onV
_n`6ojO0j`03oj[1j_nZ`>[oZ/3Z00CoZ/3Z1onV_n`6ojFok0GoYl3/0_nV`>`6ojO0j`OoTKWb1OmT
[_T5odZYn0GoY<kf00?ob<?Fok[:ionjb^L01?njb^L3olVkc@Co_/KQ1oo3]L`00oniXl?o_KODokfg
e004okfge0Oo]:G:00?oZi[6ojbghOn/]n400on/]n47ojN`gP?oXZkP1OnKgod00onNiOcoX^gioj;]
n@04oj;]n@?oZ][h1On^e?@00onX`>_oYko[ojNoj`06ojNoj`?oYl3[0onX`N`8ojS2k0KoYko[1_nV
_^X2ojJnj`GoYl3[1onX`N`6ojNoj`KoYkk[00?oYko[ojO0jonW`>/01?nW`>/7ojS1k0_oYko[00?o
0000ojNojonW`>/01onW`>/3ojS1j`CoZ<3[1_nW_n/00ol0003oooooooooo`04ooooo`00:?ooool2
o`0003?ooooo1_nY`>/7ojO0j`OoY[o/1_nW`>/7oj[0jP?oY[o/1?nW_n/6ojFok003ojO0k?nV`>co
Y/3/00CoY/3/1_nW`>/3oi6ilPGoW;c_1Omf]OT5odJVm`GoN/So1_njb^L00oo9^lgo_/KQokk6h@04
okk6h@Go`kG<00?o]lSWokfge?nm]m@01Onm]m@6okBUbP03ojo4jOn/]n7o[;OQ00Go[;OQ1OnW/=h3
oi[No@GoVmom1?nBjOP00onRkOWoZ][hoj[Jn005oj[Jn003ojkDm?nX`>_oZ<3[00?oZ<3[1_nW_n/8
ojS1k0GoZ<;/00?oZ<7[ojNojonW_n/01_nW_n/3ojJnjP?oYko[1onW`>/7ojS1k0KoYko[0_nW_^/5
ojNoj`KoYl3[1onX`N`;ojNoj`03o`000?nW_n_oYl3[00GoYl3[00?oZ<7/ojS0jonX`>/01_nX`>/3
ojNoj`;ooooo00?o0000ooooooooool01?ooool002[ooooo00?o0000ooooooooool0<Oooool6ojW0
j`OoYl3[1onV_n`6ojO0j`OoZ/3Z1onW_n/3ojFok0?oYL3/1onV`>`3ojO0j`?oZ<3[2?nL_>l5ogJe
n@GoAZKg1Omjb?l3ok[:i`?oV]Om1onna^400oo3]Lco]lSWokO8i`03okO8i`Oo_KOD0_ndYLX5ojo4
j@Oo[;OQ00?oYk3Noi[NoOnJg_d01OnJg_d00onKgogoT^Whoi;Yn002oi;Yn0GoYM_k0onZf_P3ojS2
k0OoZ<3[0_nW_n/<ojS1k003ojS2k?nX`N_oZ<7[00?oZ<7[1_nW_n/00onV_^[oYko[ojNoj`05ojNo
j`GoYl3[2OnX`N`3ojNoj`;oYkk[2?nW_n/3ojO0j`[oZ<7/2onW_n/01?l0003oYko[ojO0jonW`>/5
ojS1k0KoZ<3[1oooool00ol0003oooooooooo`03ooooo`00:oooool00ol0003oooooooooo`0aoooo
o`OoZL3[1_nW`>/7ojJok0KoYl3[1onZ`>X7ojNoj`KoYL3/1onV`>`6ojS0j`KoW;c_0_nU_n`6ohVh
m@GoG;7k1Om6/_P5oi[Go@Go_/KQ0_nMg?d6okO8i`Go_KOD0_nYe_L6ojo4j@Ko[;OQ0onBhOd3oi[N
o@CoQNCh0onOf_`5ojGKn`;oZ<;]1_nX`^`5ojS0j`coZ<7/1?nX`^`6ojS1j`;oYko[1OnV_^X7ojNo
j`03ojO0jonX`NcoZ<7/00WoZ<7/00?oYko[ojNnjonW_^/01?nW_^/6ojNoj`03ojO0jonX`NcoZ<7/
00WoZ<7/3OnW_n/00ol0003oYl3[ojS1k007ojS1k0;oZ<3[2_ooool00ol0003oooooooooo`03oooo
o`00;?ooool00ol0003oooooooooo`0aooooo`OoZL3[1_nW`>/7ojJok0KoYl3[1onZ`>X7ojNoj`Ko
YL3/1onV`>`6ojS0j`;oW;c_1_nU_n`6ohVhm@GoG;7k1Om6/_P5oi[Go@03okk6hOnMg?goWMcm00Co
WMcm1_ngb>L00onm]mCoZMKgojWFm`04ojWFm`Ko[lCY0_n/]n45oi;Qo@CoNmki00?oQNChoioJo?nO
f_`01OnOf_`00onUfo_oZ<;]ojS2k@04ojS2k@KoZ<;/00?oZ<3[ojS1k?nX`N`02OnX`N`9ojS2k0?o
Z<7[0onW_^X7ojJnjP?oYko[3?nX`N`5ojNoj`KoYkk[0_nW_n/5ojO0j`KoZ<7/00?oZ<7[ojNojonW
_n/02onW_n/4ojO0j`03o`000?nW`>_oZ<7/00GoZ<7/3Oooool00ol0003oooooooooo`03ooooo`00
;Oooool2o`0003;ooooo1onY`>/6ojO0j`GoY[o/0_nV`>`6ojO0j`GoZ/3Z0_nY`>X7ojNoj`?oYL3/
0onU_n`7ojK0k0?oZ<3[0onW`>/8ojFok0?oRKSe1?nL_>l6ogfjnPGoD;;j1Om>__L5oigLo@?o]lSW
1?n6gOh6ojWFm`?o[lCY1Ommg_T00onBhOgoNmkiog_Nn@03og_Nn@GoVmGl0onOf_`3ojO2k@OoZ<;]
0onX`^`4ojO0k0OoZ<7/2onX`^`8ojNnjPGoY[kZ0_nW`>/;ojS1k0;oZ<3[1onW_n/3ojNnj`[oYl3[
0_nX`N`5ojS1j`goYko[1?nW`>/01?l0003oYl3[ojS1k?nX`N`@ooooo`03o`000?oooooooooo00?o
oooo000_ooooo`03o`000?oooooooooo033ooooo1onY`>/6ojO0j`03ojJok?nV`>coY/3/00CoY/3/
1_nW`>/00onZ`>[oZL3ZojW0jP04ojW0jPGoYko[0_nX_n/6ojFok0OoY/3/1_nW`>/6ojFok003ojS1
jonL_>ooW;c_00KoW;c_0omm^_X2oiJkl@OoNkkl1_mD^O/5odk2m0GoQ]gn0onYe_L5oeoAlP?oOMki
0omfeo`4oi[>nPGoVmGl00?oY/7/ojO2kOnW`^d01OnW`^d5ojS2k@WoYl3/0onX`N`2ojO2k@WoZ<;/
3?nW_^X00onV_^[oYl3[ojO0j`04ojO0j`OoZ<7/1_nX`>/6ojNoj`coYl3[00?oZ<7/ojS1jonX`N/0
1_nX`N/=ojNoj`?oYl3[00?o0000ooooooooool04Oooool00ol0003oooooooooo`03ooooo`00<?oo
ool00ol0003oooooooooo`0aooooo`KoZL3[1onW`>/6ojK0k0OoYl3[1_nY`>X00onW_n_oZ;o[ojRo
j`04ojRoj`KoYKo/1onV`>`6ojO0j`;oYKo/1OnX`N/6oiblk`03ojJok?nF^o7oU[_a00CoU[_a1omk
__`3oeBin`?oPl;l1omWa?h3oeS7m`CoQ/gn1OmjdOl2oi_6mPOoV/kj00?oVmGlojK1k?nV`N`00onV
`N`7ojO2k@03ojS2kOnW`>coYl3/00WoYl3/00?oYl;/ojO2kOnW`^d01?nW`^d6ojS2k003ojRojonW
_^[oYkkZ00SoYkkZ0onW_n/8ojO0j`KoZ<7/1onX`>/6ojNoj`SoYl3[1OnX`N`6ojS1j`goYko[1Ooo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00?ooooo000aooooo`03o`000?oooooo
oooo037ooooo1onY`>/6ojO0j`OoY/3/1_nW`>/7ojW0jPKoZ;o[1onU_n`6ojK0k0?oYl3[1?nV`>`6
ojS1j`;oW;c_1OnV_n`6oiJkl@?oNkkl1?nG_?46oh?2o0?oIlCn1?nA`oP7ohK=oP03og[AoonKa_Ko
VlKf00CoVlKf0onJc_X3ojJok0OoY/7/0onW`^d4ojO0j`SoYl3/1OnW`^`6ojO2k@;oZ<;/1OnX_n/5
ojNnjPSoYko[1_nW`>/8ojS1k0?oZ<3[0onW_^X7ojNoj`?oYl3[2_nX`N`2ojS1j`goYko[2Oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo000booooo`;o0000<_ooool7ojW0
j`KoYl3[1onV`>`4ojO0j`?oYl3/1_nY`>X4ojRoj`?oZL3Z1_nU_n`3ojK0k0?oYL3/1onV`>`3ojS1
j`?oYl3/1onV_n`3oiJkl@CoYKo/1_nG_?43oh?2o0CoWKg_1_nA`oP3ohK=oPCoWko`1OnKa_H2ojNo
j`KoY[o/1OnV`N`2ojO1k0OoYl3[0onW`>`:ojO2k0?oYl;]1?nX`>/6ojRoj`03ojNnj_nW_n_oYko[
00[oYko[0_nW`>/:ojS1k0;oYko[1_nW_^X5ojNoj`;oYl3[2_nX`N`2ojO0j`_oYko[3_ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo000dooooo`03o`000?oooooooooo033o
oooo1onY`>/7ojO0j`KoY/3/00?oYl3[ojO0k?nW`>`01?nW`>`6ojW0jP03ojRojonY`>[oZL3Z00Co
ZL3Z1?nU_n`2ojNoj`KoYL3/1OnV`>`2ojK1k0KoYl3/1OnV_n`2ojS1j`OoYKo/0onG_?43ojJoj`Oo
WKg_0onA`oP4ojFnk0KoWko`00?oVlKfojNojonW_n/01?nW_n/6ojJok003ojK1k?nW`NcoYl7/00Co
Yl7/1OnW`>/=ojO2k0;oZ<7/1onX`>/3ojRoj`?oYkkZ2_nW_n/4ojO1k0OoZ<7/1_nW_n/6ojNnjP03
ojNojonW`>_oYl3[00CoYl3[1_nX`N`6ojO0j`KoYko[4_ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo00;ooooo000eooooo`03o`000?oooooooooo033ooooo1onY`>/7ojO0j`KoY/3/
1onW`>`3ojW0jP?oZ<3[1onY`>X00onU_ncoYko[ojNoj`03ojNoj`KoYL3/00?oY/3/ojK1k?nV`N`0
1?nV`N`6ojO0k003ojJok?nX`N_oZ<7[00CoZ<7[1OnU_n`2ojS1j`KoY[o[1OnM_Nl2ojS0j`OoYKk/
0onO_o03ojS0j`OoYko[0onV_n`:ojO1k003ojO0jonW`^coYl;/00_oYl;/1_nX`N`5ojS0j`SoYkkZ
1OnW_n/9ojO1k0?oZ<7/0_nX`>/8ojNoj`?oYkkZ0_nW_n/8ojO0j`KoZ<7/1_nW`>/2ojNojaKooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`00=_ooool00ol0003ooooooooo
o`0`ooooo`OoZL3[1OnW`>/2ojS0j`KoY/3/1OnW`>`2ojK0k0KoZ<3[1onY`>X6ojNoj`?oYL3/0onU
_n`7ojK1k0?oYl3/1?nV`N`6ojS1j`03ojFok?nX`N_oZ<7[00CoZ<7[1_nV_n/00onM_NooZ<3[ojS0
j`04ojS0j`GoYKk/0_nX`N`6ojS0j`GoYko[3?nW`N`=ojO2k0?oYl7/1onX`N`00onX`>_oYkkZojNn
jP0:ojNnjP03ojNojonW`NcoYl7/00WoYl7/00?oZ<7/ojS0jonX`>/01?nX`>/=ojNoj`KoYl3[2?nX
`N`3ojO0ja_ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`00=oooool2
o`00037ooooo1onY`>/00onW`>_oZ<3[ojS0j`04ojS0j`KoY/3/00?oYl3/ojK0k?nV`>`01?nV`>`6
ojS0j`OoZL3Z1?nW_n/2ojRojPKoYKo/1OnV`N`2ojG0k@OoY/7/0onX`N/3ojO1k0OoZ<7[0onV_n/4
ojO1k0KoZ<3[00?oYKk/ojS1k?nX`N`01?nX`N`6ojS0j`03ojNojonW`NcoYl7/00WoYl7/00?oYl;]
ojO2k?nW`^`02_nW`^`8ojO1k0?oZ<7/0onW_^T:ojNnjP?oYl3/2OnW`N`5ojS1k0KoZ<3[3OnW_n/2
ojO0j`[oZ<7/8?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo000ioooo
o`03o`000?oooooooooo02oooooo1OnY`>/9ojS0j`?oY/3/0onV_n`7ojK0k0OoZ<3[1_nY`>X00onW
_n_oZ;oZojRojP03ojRojPKoYKo/00?oY/7/ojG0kOnU`>d01?nU`>d5ojK1k0;oY/7]1_nW`N`5ojS1
j`WoYl7/0onX`>/3ojO1k0OoZ<7/0onX`>/;ojO1k0GoYl;]2?nW`^`:ojO1k0SoYkkY1OnW_^X2ojO0
j`KoYl3/1OnW`N`9ojS1k0?oZ<3[0onW_^X:ojNoj`?oYl7/2?nX`N`Sooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool00_ooool003[ooooo00?o0000ooooooooool0;oooool00onY`>_o
Z<3[ojS0j`0;ojS0j`KoY[o/1onV`>`7ojS0j`?oZL3Z0onY`>/6ojRojP?oYKo/1?nW_n/6ojG0k@03
ojK1k?nV`NgoY/7]00CoY/7]1_nW`N`00onX`N_oYl7/ojO1k009ojO1k0;oYl7]1_nW`N`5ojS1k003
ojO2kOnW`NcoYl7/00WoYl7/2OnW`^d3ojO2k0_oYl7/3?nW_^T00onW_^[oYl3[ojO0j`04ojO0j`Ko
Yl3/00?oYl7/ojS1k?nX`N`02OnX`N`8ojNnjPGoYko[00?oYl3[ojO1k?nW`N`01OnW`N`3ojS1k2So
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`00>oooool00ol0003ooooo
ooooo`0`ooooo`goZ<3[1_nV_n`7ojK0k0GoZ<3[0_nW`>`6ojW0j`CoZ;oZ0_nY`>X7ojNoj`?oYL3]
0onV_^/7ojK1k@?oYl7/1?nV`Nd7ojO1k0KoYl7]1_nW`N`00onX`NcoYl;]ojO2k@03ojO2k@KoYl7/
00?oY/7]ojO2kOnW`^d02OnW`^d2ojO0j`[oYl7/3OnW_^T:ojO0j`?oYl3/2onX`N`<ojNnjP03ojNo
jonW`>_oYl3[00?oYl3[1OnW`N`]ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
0Oooool003cooooo00?o0000ooooooooool0<?ooool=ojS0j`?oY[o/1?nV_n/6ojK0k003ojS0jonW
`>coYl3/00CoYl3/1_nY`>/00onX_n[oZL3ZojW0jP03ojW0jPGoYko[0_nY_nX6ojJnj`GoY/7]0_nV
_n/7ojK1k@?oYl7/0onV`Nd7ojO1k@?oYl7/0onV`Nd6ojO2k@;oYl7/1OnV`Nd7ojO2k@KoYl3[1OnW
`N`2ojRnj@_oYkkY3OnW`>/00onW`NcoZ<7/ojS1k008ojS1k0?oYko[2_nW_^X:ojO0j`03ojO1k?oo
oooooooo02oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`01ooooo`00?Oooool2
o`00037ooooo2onX`>/2ojW0jPOoY[o[1_nV`>`7ojO0k0?oZL3[0onX`>/6ojW0jP03ojNojonY_n[o
ZKoZ00CoZKoZ1_nV_^/00onV`NgoY[o[ojJoj`04ojJoj`GoY/7]0_nV_^/6ojK1k@GoYl7]00?oY/3/
ojK1kOnV`Nd01OnV`Nd3ojO2k@?oY/3/1onV`Nd3ojO2k@CoYko[1_nW`>/00onW`NcoZ;kYojRnj@04
ojRnj@OoYkkY3OnW`>/5ojO1k0GoZ<7/0_nX_n/6ojNoj`GoYkkZ0_nW_n/:ojO0jcCooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`01ooooo`00?oooool00ol0003oooooooooo`0_oooo
o`OoZ<3[1_nY`>X5ojJoj`;oYko[1_nV`>`5ojO0k0;oY/3/1_nX`>/3ojW0jP?oZL3[1onY_nX3ojJn
j`CoZ;oZ1_nV_n/00onV`NgoY[k[ojJnj`04ojJnj`KoY/7]00?oYl7]ojK0k?nV`>`00onV`>`5ojK1
k@;oYko[1_nV`>`5ojK1k@;oYkkZ1onW_n/3ojO0j`[oZ;kY0onW_^T<ojO0j`[oYl7/00?oZ<7/ojRo
jonX_n/01?nX_n/6ojNoj`03ojNnj_nW_n_oYko[00CoYko[1OnW`>/iooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool00Oooool0043ooooo00?o0000ooooooooool0;oooool7ojS0j`Ko
ZL3Z00?oY[o[ojNojonW_n/01?nW_n/6ojK0k003ojO0k?nV`>coY/3/00CoY/3/1?nX`>/2ojO1k0Ko
ZL3[1OnY_nX2ojW0j`OoZ;oZ0onV_n/3ojRnj@OoY[k[0onV`Nd3ojNnjPKoY/3/00?oY/7]ojNojonW
_n/01?nW_n/6ojK0k003ojK1kOnW_^[oYkkZ00CoYkkZ1OnW_n/00onX_^[oZ;kYojRnj@0:ojRnj@co
Yl3[3?nW`N`4ojS0j`KoZ;o[3OnW_n/00onW`>_oooooooooo`0kooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool00Oooool0047ooooo00?o0000ooooooooool0;oooool7ojS0j`?oZL3Z
0onY`>/7ojNoj`?oY/3/1?nV_n/6ojK0k003ojS0jonW`NcoYl7/00?oYl7/1_nY`>/00onY_n[oZL3[
ojW0j`04ojW0j`GoZ;oZ0_nY`>X6ojRnj@GoY[k[00?oZKoYojNnj_nW_^X01OnW_^X3ojK0k0?oZ;kZ
1onW_n/3ojK0k0CoZ;kY1_nW_^X00onW_n_oZ;kZojRnjP03ojRnjPSoZ;kY3?nW`>/;ojO1k003ojO0
jonX`>_oZ<3[00KoZ<3[0onX_n/2ojNojP[oYko[@Oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo007ooooo0012ooooo`;o0000<?ooool5ojS0j`;oYl3[1_nY`>/5ojNoj`;oZ;oZ1onV
_n/6ojK0k0KoYl7/0onY`>/4ojO1k0KoZL3[00?oZ;oZojW0j_nY`>X01?nY`>X6ojRnj@03ojJnjonY
_nWoZKoY00?oZKoY1OnW_^X2ojVojPKoZ;kZ1OnW_n/2ojRojPOoZ;kY0onW_^X2ojRojPOoZ;kZ0onX
_^T=ojO0j`_oYl7/1OnW`>/6ojS0j`03ojNnj_nW_n[oYkoZ00CoYkoZ1OnW_n]6ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool00Oooool004Cooooo00?o0000ooooooooool0;_ooool0
0onX`>_oYl3[ojO0j`04ojO0j`KoZL3[00?oYko[ojRoj_nX_nX01?nX_nX5ojJoj`;oYko[1_nV`>`4
ojO1k0;oY/3/1onW`N`3ojW0j`?oYl7/1onY`>X3ojRnj@CoZL3[1OnY_nT00onW_^[oZKoZojVojP04
ojVojPKoZ;kZ00?oYko[ojRoj_nX_nX01?nX_nX5ojRnj@03ojS0jonX_n[oZ;oZ00CoZ;oZ1OnX_^X<
ojO0j`goYl7/0onW`>`6ojO0j`;oZ<3[1OnW_^X6ojNojP03ojNojooooooooooo04Sooooo00?o0000
ooooooooool01oooool1o`00007ooooo0Oooool004Gooooo00?o0000ooooooooool0;oooool6ojO0
j`?oZL3[1?nX`>/6ojRojP03ojJojonW_n_oYko[00CoYko[1_nV`>`00onW`NcoY/3/ojK0k003ojK0
k0GoYl7/0_nV`N`6ojO1k0GoZL3Z0_nW`N`7ojW0j`;oZKoY0onX`>/7ojVojP?oZ;kZ1?nX`>/6ojRo
jP03ojRnjOnX`>_oZ<3[00?oZ<3[1_nX_nX00onX_^[oYl3[ojO0j`09ojO0j`goYl7/2?nW`>`3ojO0
j`[oYkkZ0onW_nY>ooooo`03o`000?oooooooooo00Kooooo0Ol00001ooooo`7ooooo0016ooooo`03
o`000?oooooooooo033ooooo0_nW`>/3ojO0k0OoZ<3[0onX_nX4ojW0jPKoYko[0onV`>`3ojJoj`Ko
Y/3/00?oYl7/ojK1k?nV`N`01?nV`N`6ojO1k003ojW0j_nW`NcoYl7/00CoYl7/1OnY`>/00onW`Nco
Z<3[ojS0j`04ojS0j`GoZKoZ2OnX`>/3ojRojPWoZ<3[0onX_nX4ojO1k0OoYl3[3OnW`N`:ojO0k0go
YkkZD_ooool00ol0003oooooooooo`06ooooo`7o00000Oooool1ooooo`00Aoooool2o`00037ooooo
1OnW`>`7ojS0j`OoZL3Z0onW_n/3ojRojPKoY[o[0onV`>`4ojJok0KoY/7/3OnW`N`00onY`>_oYl7/
ojO1k003ojO1k0KoZ<3[00?oZKoZojS0jonX`>/02OnX`>/00onW`NcoZ<3[ojS0j`09ojS0j`WoYl7/
0onW`>/=ojO1k0?oYl3[1onW`>`=ojNnjUKooooo00?o0000ooooooooool01Oooool1o`00007ooooo
0Oooool004Wooooo00?o0000ooooooooool0;oooool5ojO0k0OoZ<3[1OnY`>X2ojS0j`KoZ;oZ1?nV
_n/2ojRojPOoY[o/0onV`N`3ojK0k1?oYl7/0onX`>/4ojO1k0OoZ<3[1OnW`N`7ojS0jaOoYl7/2OnW
`>/3ojO0k0goYkkZF_ooool00ol0003oooooooooo`04ooooo`7o00000Oooool1ooooo`00B_ooool0
0ol0003oooooooooo`0_ooooo`KoYl3/1_nX`>/00onY`>[oZ<3[ojS0j`04ojS0j`KoZ;oZ00?oY[o[
ojRoj_nX_nX00onX_nX5ojJok0;oYko[1_nV`>`5ojO1k003ojK0k?nW`NcoYl7/01;oYl7/0onX`>/9
ojO1k0?oZ<3[5_nW`N`00onW_n_oYl3[ojO0j`09ojO0j`goYkkZGoooool00ol0003oooooooooo`03
ooooo`7o00000Oooool1ooooo`00Boooool00ol0003oooooooooo`0_ooooo`KoYl3/0onX`>/3ojO0
k0OoZ<3[0onX_nX4ojW0j`GoZ;oZ00?oY[o/ojNojonW_n/01?nW_n/6ojK0k003ojO1k?nV`>coY/3/
00?oY/3/1OnW`N`2ojK0k0_oYl7/0_nV`N`QojO1k0GoYko[1onW`>/=ojNnjV;ooooo00?o0000oooo
ooooool00oooool1o`00007ooooo0Oooool004cooooo0_l0000`ooooo`CoYl3/0_nV`>`6ojO0k0Go
Z<3[0_nW`>/7ojW0j`;oZ;oZ1?nX`>X6ojNoj`?oY/3/1?nW_n/5ojK0k003ojO1k?nV`>coY/3/00Co
Y/3/1onW`N`6ojK1k0CoYl7/0_nW`>`;ojO1k0;oYl3[2_nW`N`9ojNoj`?oYl3[1?nX_nX9ojNnjVKo
oooo00?o0000ooooooooool00oooool1o`00007ooooo001>ooooo`03o`000?oooooooooo02kooooo
00?oYl3/ojK0k?nV`>`00onV`>`6ojO0k003ojS0jonW`>_oYl3[00CoYl3[1OnY`>/00onX`>_oZ<3Z
ojS0jP05ojS0jP?oYko[0onX_nX7ojNoj`;oY/3/1?nW_n/6ojK0k0?oYl7/1?nW_n/6ojK1k003ojO1
k?nW`>coYl3/00?oYl3/1onW`N`6ojO0j`GoYl7/00?oYkoZojNojonW_n/02OnW_n/9ojRojP?oYkkZ
K?ooool00ol0003oooooooooo`02ooooo`7o00000Oooool004oooooo00?o0000ooooooooool0;ooo
ool5ojK0k0OoYl3/1_nW`>/00onY`>_oZ<3[ojS0j`03ojS0j`GoZ<3Z0_nX`>/6ojRojPGoYko[00?o
Z;oZojNojonW_n/01OnW_n/3ojK0k0?oYkoZ1onW_n/3ojK1k0?oYko[1_nW`>`3ojO1k0CoYko[1_nW
`>/00onW`NcoYkoZojNojP03ojNojPOoYko[2onX_nYaooooo`05o`000?ooooooooooooooool00000
0Oooool0053ooooo00?o0000ooooooooool0;oooool2ojK0k0CoY[o[1_nW`>`3ojO0j`CoYl3/1OnX
`>/00onX`>[oZ<3[ojS0j`04ojS0j`KoZ;oZ00?oYko[ojRoj_nX_nX00onX_nX5ojNoj`;oZ;oZ1_nW
_nX5ojNoj`03ojRoj_nW_n_oYko[00GoYko[0onW`>`3ojRojPOoYko[0onW`>/3ojRojPKoYkoZ0onW
_n/;ojRojWCooooo00Go0000ooooooooooooooooo`000001ooooo`00DOooool2o`00033ooooo1_nV
_n/3ojO0k0?oY/3/1onW`>`2ojS0j`?oYl7/1onX`>/3ojRojPCoZ<3[1OnX_nX00onW_n_oZ;oZojRo
jP04ojRojPKoYkoZ00?oYko[ojRoj_nX_nX00onX_nX5ojNoj`SoZ;oZ1OnW_n/8ojRojP?oYkoZ0onX
_n/:ojRojWSooooo00Co0000oooooooooooo00000Oooool005?ooooo00?o0000ooooooooool0;_oo
ool4ojJoj`;oYko[1_nV`>`5ojO0k003ojK0k?nW`NcoYl7/00CoYl7/1OnX`>/2ojO1k0OoZ<3[0_nX
_nX4ojS0j`KoZ;oZ0onW_nX3ojS0j`KoZ;oZ00?oYko[ojRoj_nX_nX02_nX_nX00onW_n_oZ;oZojRo
jP08ojRojP;oZ<3[1_nX_n/5ojRojWgooooo00?o0000ooooool000000Oooool005Cooooo00?o0000
ooooooooool0;_ooool00onV_n_oYko[ojNoj`03ojNoj`KoY/3/00?oYl3/ojK0k?nV`>`00onV`>`6
ojO1k003ojS0jonW`NcoYl7/00CoYl7/1OnX`>/00onW`NcoZ<3[ojS0j`05ojS0j`?oZ;oZ2OnX`>/3
ojRojPCoZ<3[2OnX_nX3ojS0j`OoZ;oZ1_nX`>/6ojRoj`03ojRoj_oooooooooo07kooooo00?o0000
ooooool000000Oooool005Gooooo00?o0000ooooooooool0;_ooool6ojNoj`?oY/3/1?nW_n/5ojK0
k0?oYl7/1?nW`>`6ojO1k003ojS0jonW`NcoYl7/00?oYl7/1OnX`>/2ojO1k0[oZ<3[0_nW`>/7ojS0
j`?oZ;oZ2OnX`>/3ojRojPCoYl3[1_nX`>/3ojRojhCooooo0Ol00001ooooo`7o0000001Fooooo`;o
0000;oooool3ojNoj`?oZ<3[1onW_n/2ojK0k0CoYko[1_nW`>`<ojO1k003ojS0jonW`NcoYl7/00Co
Yl7/1onX`>/5ojO0j`GoZ<3[0_nW`N`:ojS0j`;oYl7/1onW`>/3ojS0jh[ooooo0_l0000005Sooooo
00?o0000ooooooooool0;Oooool6ojS0j`GoYko[0_nX_n/6ojNoj`?oYl3/0onW_n/CojO1k0?oZ<3[
0onW`N`6ojO0j`03ojS0jonW`NcoYl7/00CoYl7/1_nX`>/6ojO1k0GoYl3[SOooool3o`000000FOoo
ool00ol0003oooooooooo`0]ooooo`KoZ<3[00?oYko[ojRojonX_n/01?nX_n/4ojNoj`;oZ;o[1_nW
_n/5ojO1k003ojNojonW`NcoYl7/017oYl7/0onW`>/:ojO1k0;oZ<3[2_nW`N`00onW`>_ooooooooo
o`2:ooooo`Co00000oooool005[ooooo00?o0000ooooooooool0;Oooool7ojS0j`KoZ;o[00?oYko[
ojRojonX_n/00onX_n/6ojNoj`03ojO1k?nW_n_oYko[00?oYko[1OnW`N`2ojNoj`[oYl7/0_nW`>`F
ojO1k8cooooo0ol00007ooooo`00Foooool00ol0003oooooooooo`0]ooooo`OoZ<3[0onX_n/3ojS0
j`KoZ;o[0onW_n/4ojRoj`GoYko[00?oYl7/ojNojonW_n/01?nW_n/7ojO1k0GoYl3/1OnW`N`00onW
_n_oYl7/ojO1k008ojO1k8gooooo1?l0000:ooooo`00G?ooool2o`0002kooooo3OnX`>/3ojRoj`Co
Z<3[1_nX_n/2ojNoj`CoZ;o[1_nW_n/3ojO1k0?oYko[1_nW`>`00onW`NcoYko[ojNoj`03ojNoj`Go
Yl7/SOooool4o`0000kooooo001Nooooo`03o`000?oooooooooo02cooooo5?nX`>/3ojRoj`;oZ<3[
1onX_n/3ojNoj`?oZ;oZ1_nW_n/3ojO0k0WoYko[00?oYl7/ooooooooool0R_ooool4o`0001;ooooo
001Oooooo`03o`000?oooooooooo02gooooo6?nX`>/5ojRoj`;oZ<3[1_nX_nX3ojNoj`?oZ;o[2OnW
_n^;ooooo`Co00005_ooool0063ooooo00?o0000ooooooooool0;Oooool3ojS0j`CoYl3/4OnX`>/0
0onX_n_oZ<3[ojS0j`04ojS0j`CoZ;oZ0_nX`>/6ojRoj`GoYko[Roooool3o`0001[ooooo001Qoooo
o`;o0000;oooool6ojO0k0;oZ<3[1?nW`N`BojS0j`03ojRoj_nX`>_oZ<3[00?oZ<3[1_nX_n/00onW
_n_oooooooooo`28ooooo`Co00007Oooool006?ooooo00?o0000ooooooooool0;Oooool5ojO0k0Oo
Yl7/0onX`>/3ojO1k1;oZ<3[0onX_n^9ooooo`Co00008Oooool006Cooooo00?o0000ooooooooool0
;Oooool5ojO0k0GoYl7/0_nW`>`6ojO1k0?oZ<3[0onW`N`9ojS0jh[ooooo1?l0000Uooooo`00IOoo
ool00ol0003oooooooooo`0]ooooo`GoYl3/00?oYl7/ojO0k?nW`>`01?nW`>`4ojO1k0;oYl3/1_nW
`N`4ojS0jh[ooooo1?l0000Yooooo`00I_ooool2o`0002kooooo0_nW`>`4ojNoj`KoYl3/00?oYl7/
ojO0k?nW`>`00onW`>`6ojO1k003ojS0jooooooooooo08Oooooo0ol0000]ooooo`00J?ooool00ol0
003oooooooooo`0/ooooo`KoYko[0onW`>`3ojNoj`KoYl3/0onW`Nb8ooooo`Co0000<?ooool006Wo
oooo00?o0000ooooooooool0;?ooool3ojNoj`CoZ;o[1OnW_n/3ojO0k8Wooooo1?l0000dooooo`00
J_ooool00ol0003oooooooooo`0/ooooo`OoZ;o[0_nW_n^:ooooo`Co0000>?ooool006_ooooo0_l0
000]ooooo`GoZ;o[ROooool4o`0003cooooo001]ooooo`03o`000?oooooooooo02_ooooo00?oZ;o[
ooooooooool0Qoooool3o`00043ooooo001^ooooo`03o`000?oooooooooo02[ooooo00?o0000oooo
ooooool0Poooool4o`0004?ooooo001_ooooo`03o`000?oooooooooo02Wooooo00?o0000oooooooo
ool0Ooooool4o`0004Oooooo001`ooooo`;o0000:Oooool00ol0003oooooooooo`1kooooo`Co0000
Boooool007;ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1gooooo`Co0000Cooo
ool007?ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1dooooo`?o0000Doooool0
07Cooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1`ooooo`Co0000E_ooool007Go
oooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1/ooooo`Co0000F_ooool007Kooooo
0_l0000Sooooo`03o`000?oooooooooo06Sooooo1?l0001Nooooo`00N?ooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo06Cooooo1?l0001Rooooo`00NOooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo067ooooo0ol0001Vooooo`00N_ooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo05gooooo1?l0001Yooooo`00Noooool2o`0001kooooo00?o0000oooooooo
ool0FOooool4o`0006gooooo001mooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
EOooool4o`00077ooooo001nooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0DOoo
ool4o`0007Gooooo001oooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0C_ooool3
o`0007Wooooo0020ooooo`;o00006Oooool00ol0003oooooooooo`1:ooooo`Co0000O?ooool008;o
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`16ooooo`Co0000P?ooool008?ooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`12ooooo`Co0000Q?ooool008Cooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`0nooooo`Co0000R?ooool008Gooooo0_l0000C
ooooo`03o`000?oooooooooo03cooooo0ol0002<ooooo`00Qoooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo03Sooooo1?l0002?ooooo`00R?ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo03Cooooo1?l0002Cooooo`00ROooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo033ooooo1?l0002Gooooo`00R_ooool2o`0000kooooo00?o0000ooooooooool0;?oo
ool4o`0009_ooooo002<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0:Oooool3
o`0009oooooo002=ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool09Oooool4o`00
0:;ooooo002>ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08Oooool4o`000:Ko
oooo002?ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07Oooool4o`000:[ooooo
002@ooooo`;o00002?ooool00ol0003oooooooooo`0Iooooo`Co0000[_ooool009;ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Fooooo`?o0000/_ooool009?ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Booooo`Co0000]Oooool009Cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0>ooooo`Co0000^Oooool009Gooooo0_l00003ooooo`03o`00
0?oooooooooo00[ooooo1?l0002mooooo`00Uoooool01?l0003oooooooooool00008ooooo`Co0000
`Oooool009Sooooo00?o0000ooooool000001Oooool3o`000<Gooooo002Iooooo`;o000000?ooooo
o`000?l000000_l00038ooooo`00V_ooool2o`000<cooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
0000\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0538698, 0.0432538, \
0.0035044, 0.0035044}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[.12586 .2075 -12 -8.99448 ]
[.12586 .2075 0 .00552 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.56094 .0364 -5.16972 -9 ]
[.56094 .0364 .83028 0 ]
[.75679 .08071 0 -6.17777 ]
[.75679 .08071 12 2.82223 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.9429 .3657 0 -5.9083 ]
[.9429 .3657 6 3.0917 ]
[.02494 .25992 -18 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.01611 .31527 -18 -2.78472 ]
[.01611 .31527 0 6.21528 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00254 .43215 -12 -2.88407 ]
[-0.00254 .43215 0 6.11593 ]
[-0.0124 .49393 -12 -2.93688 ]
[-0.0124 .49393 0 6.06312 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
[(-2)] .12586 .2075 1 .99877 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.56863 .04703 m
.57247 .05235 L
s
[(2)] .56094 .0364 .72324 1 Mshowa
.125 Mabswid
.18558 .19702 m
.18832 .19985 L
s
.23703 .17687 m
.23971 .17975 L
s
.28951 .15632 m
.29214 .15925 L
s
.39772 .11395 m
.40023 .11699 L
s
.4535 .09211 m
.45595 .0952 L
s
.51046 .06981 m
.51284 .07294 L
s
.08568 .23614 m
.08851 .23887 L
s
.62804 .02377 m
.63027 .02701 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.7445 .0853 m
.73835 .08759 L
s
[(-2)] .75679 .08071 -1 .37284 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.93037 .36962 m
.92411 .37158 L
s
[(2)] .9429 .3657 -1 .31296 Mshowa
.125 Mabswid
.7708 .12553 m
.7671 .12688 L
s
.79613 .16428 m
.79242 .1656 L
s
.82054 .20161 m
.81682 .20291 L
s
.86679 .27235 m
.86305 .2736 L
s
.88871 .30589 m
.88497 .30711 L
s
.9099 .3383 m
.90615 .3395 L
s
.71716 .04348 m
.71349 .04489 L
s
.95018 .39992 m
.94642 .40107 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(-20)] .02494 .25992 1 -0.39157 Mshowa
.02837 .31059 m
.0345 .30825 L
s
[(-10)] .01611 .31527 1 -0.38117 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.00981 .42772 m
.01599 .4255 L
s
[(10)] -0.00254 .43215 1 -0.3591 Mshowa
0 .48963 m
.0062 .48748 L
s
[(20)] -0.0124 .49393 1 -0.34736 Mshowa
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.655 .751 .921 r
.39362 .69479 .40169 .70183 .4152 .69802 .40717 .69097 Mtetra
.655 .752 .921 r
.40717 .69097 .4152 .69802 .42878 .69422 .42079 .68712 Mtetra
.656 .752 .921 r
.42079 .68712 .42878 .69422 .44242 .69039 .43448 .68324 Mtetra
.657 .752 .92 r
.43448 .68324 .44242 .69039 .45614 .68653 .44824 .67931 Mtetra
.657 .751 .919 r
.44824 .67931 .45614 .68653 .46992 .68262 .46207 .67535 Mtetra
.656 .75 .92 r
.46207 .67535 .46992 .68262 .48378 .67868 .47597 .67142 Mtetra
.655 .751 .92 r
.47597 .67142 .48378 .67868 .4977 .67475 .48994 .66748 Mtetra
.655 .752 .921 r
.48994 .66748 .4977 .67475 .5117 .67082 .50398 .66352 Mtetra
.50398 .66352 .5117 .67082 .52577 .66687 .5181 .65954 Mtetra
.656 .752 .921 r
.5181 .65954 .52577 .66687 .53991 .66291 .53229 .65552 Mtetra
.657 .752 .92 r
.53229 .65552 .53991 .66291 .55412 .65892 .54655 .65144 Mtetra
.657 .751 .919 r
.54655 .65144 .55412 .65892 .56841 .6549 .56088 .64733 Mtetra
.657 .75 .919 r
.56088 .64733 .56841 .6549 .58277 .65083 .57529 .64322 Mtetra
.656 .749 .919 r
.57529 .64322 .58277 .65083 .59721 .64673 .58978 .6391 Mtetra
.656 .75 .919 r
.58978 .6391 .59721 .64673 .61172 .64262 .60434 .63498 Mtetra
.656 .75 .92 r
.60434 .63498 .61172 .64262 .6263 .63849 .61898 .63083 Mtetra
.656 .751 .92 r
.61898 .63083 .6263 .63849 .64097 .63434 .63369 .62667 Mtetra
.656 .752 .921 r
.63369 .62667 .64097 .63434 .6557 .63018 .64849 .62248 Mtetra
.64849 .62248 .6557 .63018 .67052 .626 .66336 .61826 Mtetra
.66336 .61826 .67052 .626 .68542 .6218 .67831 .61402 Mtetra
.67831 .61402 .68542 .6218 .70039 .61758 .69333 .60975 Mtetra
.69333 .60975 .70039 .61758 .71545 .61334 .70844 .60546 Mtetra
.656 .752 .92 r
.70844 .60546 .71545 .61334 .73058 .60909 .72363 .60114 Mtetra
.656 .751 .92 r
.72363 .60114 .73058 .60909 .7458 .60482 .7389 .5968 Mtetra
.7389 .5968 .7458 .60482 .76109 .60053 .75426 .59244 Mtetra
.656 .75 .919 r
.75426 .59244 .76109 .60053 .77647 .59622 .76969 .58807 Mtetra
.655 .749 .919 r
.76969 .58807 .77647 .59622 .79194 .59188 .78521 .5837 Mtetra
.78521 .5837 .79194 .59188 .80748 .58749 .80082 .57931 Mtetra
.655 .75 .92 r
.80082 .57931 .80748 .58749 .82311 .58307 .81651 .57489 Mtetra
.656 .752 .921 r
.81651 .57489 .82311 .58307 .83882 .57861 .83229 .57041 Mtetra
.656 .753 .921 r
.83229 .57041 .83882 .57861 .85461 .57414 .84815 .56589 Mtetra
.84815 .56589 .85461 .57414 .8705 .56964 .86409 .56134 Mtetra
.656 .752 .921 r
.86409 .56134 .8705 .56964 .88647 .56515 .88012 .55677 Mtetra
.656 .751 .92 r
.88012 .55677 .88647 .56515 .90253 .56065 .89624 .55219 Mtetra
.655 .75 .92 r
.89624 .55219 .90253 .56065 .91868 .55612 .91246 .54762 Mtetra
.91246 .54762 .91868 .55612 .93492 .55154 .92876 .54303 Mtetra
.656 .752 .92 r
.92876 .54303 .93492 .55154 .95124 .54692 .94516 .53837 Mtetra
.656 .752 .921 r
.94516 .53837 .95124 .54692 .96765 .54227 .96164 .53368 Mtetra
.96164 .53368 .96765 .54227 .98416 .53761 .97821 .52895 Mtetra
.655 .752 .921 r
.38547 .6877 .39362 .69479 .40717 .69097 .39906 .68383 Mtetra
.656 .752 .921 r
.39906 .68383 .40717 .69097 .42079 .68712 .41273 .67994 Mtetra
.657 .752 .92 r
.41273 .67994 .42079 .68712 .43448 .68324 .42646 .67598 Mtetra
.657 .751 .919 r
.42646 .67598 .43448 .68324 .44824 .67931 .44026 .67201 Mtetra
.655 .75 .92 r
.44026 .67201 .44824 .67931 .46207 .67535 .45414 .66807 Mtetra
.655 .752 .921 r
.45414 .66807 .46207 .67535 .47597 .67142 .46808 .66412 Mtetra
.46808 .66412 .47597 .67142 .48994 .66748 .4821 .66015 Mtetra
.4821 .66015 .48994 .66748 .50398 .66352 .49619 .65614 Mtetra
.657 .752 .92 r
.49619 .65614 .50398 .66352 .5181 .65954 .51035 .65206 Mtetra
.657 .751 .919 r
.51035 .65206 .5181 .65954 .53229 .65552 .52459 .64796 Mtetra
.657 .75 .918 r
.52459 .64796 .53229 .65552 .54655 .65144 .5389 .64384 Mtetra
.656 .749 .919 r
.5389 .64384 .54655 .65144 .56088 .64733 .55328 .63974 Mtetra
.655 .751 .92 r
.55328 .63974 .56088 .64733 .57529 .64322 .56774 .63563 Mtetra
.655 .752 .921 r
.56774 .63563 .57529 .64322 .58978 .6391 .58228 .6315 Mtetra
.58228 .6315 .58978 .6391 .60434 .63498 .59689 .62735 Mtetra
.655 .753 .922 r
.59689 .62735 .60434 .63498 .61898 .63083 .61158 .62318 Mtetra
.61158 .62318 .61898 .63083 .63369 .62667 .62635 .61899 Mtetra
.62635 .61899 .63369 .62667 .64849 .62248 .6412 .61476 Mtetra
.655 .754 .922 r
.6412 .61476 .64849 .62248 .66336 .61826 .65612 .6105 Mtetra
.656 .754 .922 r
.65612 .6105 .66336 .61826 .67831 .61402 .67113 .60622 Mtetra
.67113 .60622 .67831 .61402 .69333 .60975 .68621 .60191 Mtetra
.68621 .60191 .69333 .60975 .70844 .60546 .70138 .59757 Mtetra
.70138 .59757 .70844 .60546 .72363 .60114 .71662 .5932 Mtetra
.71662 .5932 .72363 .60114 .7389 .5968 .73195 .58881 Mtetra
.656 .753 .921 r
.73195 .58881 .7389 .5968 .75426 .59244 .74736 .58438 Mtetra
.74736 .58438 .75426 .59244 .76969 .58807 .76285 .57994 Mtetra
.656 .752 .92 r
.76285 .57994 .76969 .58807 .78521 .5837 .77843 .57548 Mtetra
.656 .751 .92 r
.77843 .57548 .78521 .5837 .80082 .57931 .79409 .571 Mtetra
.655 .749 .919 r
.79409 .571 .80082 .57931 .81651 .57489 .80984 .56653 Mtetra
.80984 .56653 .81651 .57489 .83229 .57041 .82568 .56206 Mtetra
.655 .75 .92 r
.82568 .56206 .83229 .57041 .84815 .56589 .84161 .55755 Mtetra
.656 .752 .921 r
.84161 .55755 .84815 .56589 .86409 .56134 .85762 .55296 Mtetra
.656 .753 .921 r
.85762 .55296 .86409 .56134 .88012 .55677 .87371 .54834 Mtetra
.87371 .54834 .88012 .55677 .89624 .55219 .8899 .54369 Mtetra
.656 .752 .92 r
.8899 .54369 .89624 .55219 .91246 .54762 .90617 .53903 Mtetra
.655 .75 .92 r
.90617 .53903 .91246 .54762 .92876 .54303 .92254 .53439 Mtetra
.92254 .53439 .92876 .54303 .94516 .53837 .93901 .52972 Mtetra
.656 .752 .92 r
.93901 .52972 .94516 .53837 .96164 .53368 .95556 .525 Mtetra
.95556 .525 .96164 .53368 .97821 .52895 .9722 .52023 Mtetra
.656 .752 .921 r
.37724 .68053 .38547 .6877 .39906 .68383 .39088 .67662 Mtetra
.657 .752 .92 r
.39088 .67662 .39906 .68383 .41273 .67994 .40459 .67265 Mtetra
.657 .751 .919 r
.40459 .67265 .41273 .67994 .42646 .67598 .41837 .66866 Mtetra
.655 .75 .92 r
.41837 .66866 .42646 .67598 .44026 .67201 .43221 .66471 Mtetra
.655 .752 .921 r
.43221 .66471 .44026 .67201 .45414 .66807 .44613 .66074 Mtetra
.44613 .66074 .45414 .66807 .46808 .66412 .46012 .65675 Mtetra
.656 .752 .921 r
.46012 .65675 .46808 .66412 .4821 .66015 .47419 .65271 Mtetra
.657 .752 .92 r
.47419 .65271 .4821 .66015 .49619 .65614 .48832 .6486 Mtetra
.657 .75 .919 r
.48832 .6486 .49619 .65614 .51035 .65206 .50254 .64447 Mtetra
.656 .75 .919 r
.50254 .64447 .51035 .65206 .52459 .64796 .51682 .64037 Mtetra
.655 .751 .92 r
.51682 .64037 .52459 .64796 .5389 .64384 .53118 .63627 Mtetra
.655 .752 .921 r
.53118 .63627 .5389 .64384 .55328 .63974 .54561 .63216 Mtetra
.655 .752 .922 r
.54561 .63216 .55328 .63974 .56774 .63563 .56012 .62803 Mtetra
.655 .753 .922 r
.56012 .62803 .56774 .63563 .58228 .6315 .57471 .62387 Mtetra
.655 .754 .922 r
.57471 .62387 .58228 .6315 .59689 .62735 .58937 .61968 Mtetra
.656 .753 .922 r
.58937 .61968 .59689 .62735 .61158 .62318 .60412 .61544 Mtetra
.656 .753 .921 r
.60412 .61544 .61158 .62318 .62635 .61899 .61894 .61116 Mtetra
.656 .752 .92 r
.61894 .61116 .62635 .61899 .6412 .61476 .63383 .60687 Mtetra
.656 .751 .92 r
.63383 .60687 .6412 .61476 .65612 .6105 .64881 .60256 Mtetra
.64881 .60256 .65612 .6105 .67113 .60622 .66387 .59823 Mtetra
.66387 .59823 .67113 .60622 .68621 .60191 .67901 .59389 Mtetra
.655 .751 .92 r
.67901 .59389 .68621 .60191 .70138 .59757 .69423 .58954 Mtetra
.655 .752 .921 r
.69423 .58954 .70138 .59757 .71662 .5932 .70954 .58517 Mtetra
.656 .753 .921 r
.70954 .58517 .71662 .5932 .73195 .58881 .72492 .58075 Mtetra
.656 .754 .922 r
.72492 .58075 .73195 .58881 .74736 .58438 .74039 .57629 Mtetra
.74039 .57629 .74736 .58438 .76285 .57994 .75595 .57179 Mtetra
.657 .754 .921 r
.75595 .57179 .76285 .57994 .77843 .57548 .77158 .56726 Mtetra
.657 .753 .921 r
.77158 .56726 .77843 .57548 .79409 .571 .7873 .56271 Mtetra
.656 .752 .921 r
.7873 .56271 .79409 .571 .80984 .56653 .80311 .55814 Mtetra
.656 .751 .92 r
.80311 .55814 .80984 .56653 .82568 .56206 .81901 .55358 Mtetra
.655 .749 .919 r
.81901 .55358 .82568 .56206 .84161 .55755 .835 .54903 Mtetra
.655 .749 .92 r
.835 .54903 .84161 .55755 .85762 .55296 .85108 .54447 Mtetra
.656 .752 .92 r
.85108 .54447 .85762 .55296 .87371 .54834 .86724 .53982 Mtetra
.656 .753 .921 r
.86724 .53982 .87371 .54834 .8899 .54369 .88349 .53513 Mtetra
.657 .753 .921 r
.88349 .53513 .8899 .54369 .90617 .53903 .89983 .5304 Mtetra
.656 .752 .921 r
.89983 .5304 .90617 .53903 .92254 .53439 .91626 .52566 Mtetra
.655 .75 .92 r
.91626 .52566 .92254 .53439 .93901 .52972 .93279 .52094 Mtetra
.93279 .52094 .93901 .52972 .95556 .525 .94942 .51621 Mtetra
.656 .752 .92 r
.94942 .51621 .95556 .525 .9722 .52023 .96613 .5114 Mtetra
.657 .752 .92 r
.36894 .67329 .37724 .68053 .39088 .67662 .38262 .66931 Mtetra
.657 .751 .919 r
.38262 .66931 .39088 .67662 .40459 .67265 .39637 .6653 Mtetra
.655 .75 .92 r
.39637 .6653 .40459 .67265 .41837 .66866 .41019 .66133 Mtetra
.655 .752 .921 r
.41019 .66133 .41837 .66866 .43221 .66471 .42409 .65734 Mtetra
.42409 .65734 .43221 .66471 .44613 .66074 .43805 .65334 Mtetra
.656 .752 .921 r
.43805 .65334 .44613 .66074 .46012 .65675 .45209 .64927 Mtetra
.657 .752 .919 r
.45209 .64927 .46012 .65675 .47419 .65271 .4662 .64513 Mtetra
.657 .75 .919 r
.4662 .64513 .47419 .65271 .48832 .6486 .48038 .641 Mtetra
.655 .75 .92 r
.48038 .641 .48832 .6486 .50254 .64447 .49464 .6369 Mtetra
.655 .752 .921 r
.49464 .6369 .50254 .64447 .51682 .64037 .50897 .63279 Mtetra
.654 .752 .922 r
.50897 .63279 .51682 .64037 .53118 .63627 .52338 .62868 Mtetra
.655 .753 .922 r
.52338 .62868 .53118 .63627 .54561 .63216 .53787 .62453 Mtetra
.656 .753 .922 r
.53787 .62453 .54561 .63216 .56012 .62803 .55243 .62032 Mtetra
.657 .753 .921 r
.55243 .62032 .56012 .62803 .57471 .62387 .56706 .61604 Mtetra
.657 .751 .919 r
.56706 .61604 .57471 .62387 .58937 .61968 .58178 .61173 Mtetra
.657 .749 .918 r
.58178 .61173 .58937 .61968 .60412 .61544 .59657 .60742 Mtetra
.657 .748 .917 r
.59657 .60742 .60412 .61544 .61894 .61116 .61144 .60309 Mtetra
.656 .748 .917 r
.61144 .60309 .61894 .61116 .63383 .60687 .62639 .59876 Mtetra
.62639 .59876 .63383 .60687 .64881 .60256 .64143 .59441 Mtetra
.64143 .59441 .64881 .60256 .66387 .59823 .65654 .59004 Mtetra
.65654 .59004 .66387 .59823 .67901 .59389 .67173 .58565 Mtetra
.656 .747 .917 r
.67173 .58565 .67901 .59389 .69423 .58954 .68701 .58125 Mtetra
.655 .747 .917 r
.68701 .58125 .69423 .58954 .70954 .58517 .70237 .57684 Mtetra
.655 .747 .918 r
.70237 .57684 .70954 .58517 .72492 .58075 .71782 .57241 Mtetra
.655 .748 .919 r
.71782 .57241 .72492 .58075 .74039 .57629 .73335 .56798 Mtetra
.654 .75 .92 r
.73335 .56798 .74039 .57629 .75595 .57179 .74897 .56352 Mtetra
.656 .752 .921 r
.74897 .56352 .75595 .57179 .77158 .56726 .76467 .55898 Mtetra
.657 .754 .922 r
.76467 .55898 .77158 .56726 .7873 .56271 .78045 .55439 Mtetra
.657 .754 .921 r
.78045 .55439 .7873 .56271 .80311 .55814 .79632 .54975 Mtetra
.657 .753 .921 r
.79632 .54975 .80311 .55814 .81901 .55358 .81227 .5451 Mtetra
.656 .752 .92 r
.81227 .5451 .81901 .55358 .835 .54903 .82832 .54044 Mtetra
.655 .75 .92 r
.82832 .54044 .835 .54903 .85108 .54447 .84446 .53581 Mtetra
.654 .749 .919 r
.84446 .53581 .85108 .54447 .86724 .53982 .86069 .53118 Mtetra
.655 .751 .92 r
.86069 .53118 .86724 .53982 .88349 .53513 .87701 .52647 Mtetra
.656 .752 .921 r
.87701 .52647 .88349 .53513 .89983 .5304 .89342 .5217 Mtetra
.657 .753 .921 r
.89342 .5217 .89983 .5304 .91626 .52566 .90992 .5169 Mtetra
.656 .752 .921 r
.90992 .5169 .91626 .52566 .93279 .52094 .92651 .51208 Mtetra
.655 .75 .92 r
.92651 .51208 .93279 .52094 .94942 .51621 .9432 .50729 Mtetra
.9432 .50729 .94942 .51621 .96613 .5114 .95999 .50247 Mtetra
.657 .751 .919 r
.36056 .66596 .36894 .67329 .38262 .66931 .37428 .66192 Mtetra
.655 .75 .92 r
.37428 .66192 .38262 .66931 .39637 .6653 .38808 .65793 Mtetra
.655 .752 .921 r
.38808 .65793 .39637 .6653 .41019 .66133 .40194 .65393 Mtetra
.40194 .65393 .41019 .66133 .42409 .65734 .41588 .6499 Mtetra
.656 .752 .921 r
.41588 .6499 .42409 .65734 .43805 .65334 .42989 .64581 Mtetra
.658 .751 .919 r
.42989 .64581 .43805 .65334 .45209 .64927 .44398 .64165 Mtetra
.656 .75 .919 r
.44398 .64165 .45209 .64927 .4662 .64513 .45813 .63752 Mtetra
.655 .75 .92 r
.45813 .63752 .4662 .64513 .48038 .641 .47236 .63341 Mtetra
.654 .752 .921 r
.47236 .63341 .48038 .641 .49464 .6369 .48667 .6293 Mtetra
.654 .753 .922 r
.48667 .6293 .49464 .6369 .50897 .63279 .50105 .62517 Mtetra
.655 .753 .922 r
.50105 .62517 .50897 .63279 .52338 .62868 .51551 .62097 Mtetra
.658 .753 .92 r
.51551 .62097 .52338 .62868 .53787 .62453 .53004 .61667 Mtetra
.658 .75 .918 r
.53004 .61667 .53787 .62453 .55243 .62032 .54465 .61235 Mtetra
.657 .748 .917 r
.54465 .61235 .55243 .62032 .56706 .61604 .55934 .60803 Mtetra
.656 .748 .918 r
.55934 .60803 .56706 .61604 .58178 .61173 .57411 .60374 Mtetra
.656 .749 .919 r
.57411 .60374 .58178 .61173 .59657 .60742 .58895 .59944 Mtetra
.655 .751 .92 r
.58895 .59944 .59657 .60742 .61144 .60309 .60388 .59511 Mtetra
.655 .752 .921 r
.60388 .59511 .61144 .60309 .62639 .59876 .61889 .59076 Mtetra
.61889 .59076 .62639 .59876 .64143 .59441 .63397 .58638 Mtetra
.656 .753 .921 r
.63397 .58638 .64143 .59441 .65654 .59004 .64914 .58197 Mtetra
.64914 .58197 .65654 .59004 .67173 .58565 .66439 .57753 Mtetra
.66439 .57753 .67173 .58565 .68701 .58125 .67973 .57305 Mtetra
.656 .752 .92 r
.67973 .57305 .68701 .58125 .70237 .57684 .69514 .56855 Mtetra
.656 .751 .92 r
.69514 .56855 .70237 .57684 .71782 .57241 .71064 .56403 Mtetra
.656 .749 .919 r
.71064 .56403 .71782 .57241 .73335 .56798 .72623 .55949 Mtetra
.655 .748 .918 r
.72623 .55949 .73335 .56798 .74897 .56352 .7419 .55498 Mtetra
.654 .747 .918 r
.7419 .55498 .74897 .56352 .76467 .55898 .75767 .55047 Mtetra
.654 .749 .919 r
.75767 .55047 .76467 .55898 .78045 .55439 .77352 .54593 Mtetra
.656 .752 .921 r
.77352 .54593 .78045 .55439 .79632 .54975 .78945 .54129 Mtetra
.657 .754 .921 r
.78945 .54129 .79632 .54975 .81227 .5451 .80547 .53658 Mtetra
.80547 .53658 .81227 .5451 .82832 .54044 .82158 .53184 Mtetra
.656 .753 .921 r
.82158 .53184 .82832 .54044 .84446 .53581 .83778 .5271 Mtetra
.655 .75 .92 r
.83778 .5271 .84446 .53581 .86069 .53118 .85407 .52238 Mtetra
.654 .749 .919 r
.85407 .52238 .86069 .53118 .87701 .52647 .87046 .51768 Mtetra
.655 .751 .92 r
.87046 .51768 .87701 .52647 .89342 .5217 .88694 .51291 Mtetra
.657 .752 .921 r
.88694 .51291 .89342 .5217 .90992 .5169 .90351 .50805 Mtetra
.657 .753 .921 r
.90351 .50805 .90992 .5169 .92651 .51208 .92017 .50317 Mtetra
.656 .752 .92 r
.92017 .50317 .92651 .51208 .9432 .50729 .93693 .49828 Mtetra
.655 .75 .92 r
.93693 .49828 .9432 .50729 .95999 .50247 .95378 .49342 Mtetra
.656 .751 .92 r
.3521 .65854 .36056 .66596 .37428 .66192 .36587 .65451 Mtetra
.655 .751 .921 r
.36587 .65451 .37428 .66192 .38808 .65793 .3797 .65049 Mtetra
.655 .752 .921 r
.3797 .65049 .38808 .65793 .40194 .65393 .39361 .64646 Mtetra
.656 .752 .921 r
.39361 .64646 .40194 .65393 .41588 .6499 .4076 .64235 Mtetra
.658 .752 .919 r
.4076 .64235 .41588 .6499 .42989 .64581 .42166 .63817 Mtetra
.656 .75 .919 r
.42166 .63817 .42989 .64581 .44398 .64165 .43579 .63402 Mtetra
.655 .751 .92 r
.43579 .63402 .44398 .64165 .45813 .63752 .44999 .6299 Mtetra
.654 .752 .922 r
.44999 .6299 .45813 .63752 .47236 .63341 .46427 .62578 Mtetra
.654 .753 .922 r
.46427 .62578 .47236 .63341 .48667 .6293 .47862 .62162 Mtetra
.657 .753 .921 r
.47862 .62162 .48667 .6293 .50105 .62517 .49305 .61735 Mtetra
.658 .751 .919 r
.49305 .61735 .50105 .62517 .51551 .62097 .50756 .61301 Mtetra
.657 .748 .917 r
.50756 .61301 .51551 .62097 .53004 .61667 .52214 .60869 Mtetra
.656 .748 .918 r
.52214 .60869 .53004 .61667 .54465 .61235 .53681 .60441 Mtetra
.655 .75 .92 r
.53681 .60441 .54465 .61235 .55934 .60803 .55155 .60013 Mtetra
.654 .752 .922 r
.55155 .60013 .55934 .60803 .57411 .60374 .56637 .59584 Mtetra
.654 .753 .923 r
.56637 .59584 .57411 .60374 .58895 .59944 .58127 .59154 Mtetra
.654 .754 .923 r
.58127 .59154 .58895 .59944 .60388 .59511 .59625 .5872 Mtetra
.655 .755 .924 r
.59625 .5872 .60388 .59511 .61889 .59076 .61131 .58282 Mtetra
.655 .756 .924 r
.61131 .58282 .61889 .59076 .63397 .58638 .62645 .57841 Mtetra
.62645 .57841 .63397 .58638 .64914 .58197 .64168 .57395 Mtetra
.656 .756 .924 r
.64168 .57395 .64914 .58197 .66439 .57753 .65698 .56946 Mtetra
.65698 .56946 .66439 .57753 .67973 .57305 .67237 .56492 Mtetra
.657 .756 .923 r
.67237 .56492 .67973 .57305 .69514 .56855 .68785 .56035 Mtetra
.657 .755 .922 r
.68785 .56035 .69514 .56855 .71064 .56403 .7034 .55573 Mtetra
.657 .754 .922 r
.7034 .55573 .71064 .56403 .72623 .55949 .71905 .5511 Mtetra
.657 .753 .921 r
.71905 .5511 .72623 .55949 .7419 .55498 .73478 .54646 Mtetra
.656 .751 .92 r
.73478 .54646 .7419 .55498 .75767 .55047 .7506 .54182 Mtetra
.655 .748 .918 r
.7506 .54182 .75767 .55047 .77352 .54593 .76651 .53722 Mtetra
.654 .747 .918 r
.76651 .53722 .77352 .54593 .78945 .54129 .78251 .53263 Mtetra
.655 .75 .92 r
.78251 .53263 .78945 .54129 .80547 .53658 .7986 .52797 Mtetra
.657 .753 .921 r
.7986 .52797 .80547 .53658 .82158 .53184 .81477 .52319 Mtetra
.657 .754 .921 r
.81477 .52319 .82158 .53184 .83778 .5271 .83104 .51837 Mtetra
.657 .753 .921 r
.83104 .51837 .83778 .5271 .85407 .52238 .84739 .51354 Mtetra
.655 .751 .92 r
.84739 .51354 .85407 .52238 .87046 .51768 .86384 .50875 Mtetra
.654 .749 .92 r
.86384 .50875 .87046 .51768 .88694 .51291 .88039 .50397 Mtetra
.656 .751 .92 r
.88039 .50397 .88694 .51291 .90351 .50805 .89703 .49911 Mtetra
.657 .752 .921 r
.89703 .49911 .90351 .50805 .92017 .50317 .91376 .49418 Mtetra
.91376 .49418 .92017 .50317 .93693 .49828 .93059 .48922 Mtetra
.656 .752 .92 r
.93059 .48922 .93693 .49828 .95378 .49342 .94751 .48427 Mtetra
.655 .751 .92 r
.34356 .65108 .3521 .65854 .36587 .65451 .35737 .64704 Mtetra
.655 .752 .921 r
.35737 .64704 .36587 .65451 .3797 .65049 .37125 .64299 Mtetra
.656 .752 .921 r
.37125 .64299 .3797 .65049 .39361 .64646 .3852 .63888 Mtetra
.658 .752 .919 r
.3852 .63888 .39361 .64646 .4076 .64235 .39923 .63468 Mtetra
.657 .75 .919 r
.39923 .63468 .4076 .64235 .42166 .63817 .41334 .6305 Mtetra
.655 .751 .92 r
.41334 .6305 .42166 .63817 .43579 .63402 .42751 .62636 Mtetra
.654 .752 .922 r
.42751 .62636 .43579 .63402 .44999 .6299 .44176 .62223 Mtetra
.654 .753 .922 r
.44176 .62223 .44999 .6299 .46427 .62578 .45609 .61805 Mtetra
.658 .753 .92 r
.45609 .61805 .46427 .62578 .47862 .62162 .47049 .61373 Mtetra
.659 .75 .918 r
.47049 .61373 .47862 .62162 .49305 .61735 .48498 .60937 Mtetra
.656 .748 .918 r
.48498 .60937 .49305 .61735 .50756 .61301 .49953 .60507 Mtetra
.655 .75 .92 r
.49953 .60507 .50756 .61301 .52214 .60869 .51417 .6008 Mtetra
.654 .752 .922 r
.51417 .6008 .52214 .60869 .53681 .60441 .52888 .59654 Mtetra
.653 .753 .923 r
.52888 .59654 .53681 .60441 .55155 .60013 .54367 .59227 Mtetra
.653 .755 .924 r
.54367 .59227 .55155 .60013 .56637 .59584 .55855 .58796 Mtetra
.654 .756 .924 r
.55855 .58796 .56637 .59584 .58127 .59154 .5735 .5836 Mtetra
.658 .756 .923 r
.5735 .5836 .58127 .59154 .59625 .5872 .58853 .57908 Mtetra
.657 .753 .92 r
.58853 .57908 .59625 .5872 .61131 .58282 .60365 .57458 Mtetra
.656 .75 .919 r
.60365 .57458 .61131 .58282 .62645 .57841 .61884 .57008 Mtetra
.656 .749 .919 r
.61884 .57008 .62645 .57841 .64168 .57395 .63412 .56558 Mtetra
.655 .749 .919 r
.63412 .56558 .64168 .57395 .65698 .56946 .64949 .56107 Mtetra
.654 .75 .92 r
.64949 .56107 .65698 .56946 .67237 .56492 .66494 .55658 Mtetra
.653 .752 .922 r
.66494 .55658 .67237 .56492 .68785 .56035 .68048 .55209 Mtetra
.656 .756 .923 r
.68048 .55209 .68785 .56035 .7034 .55573 .6961 .54745 Mtetra
.657 .757 .923 r
.6961 .54745 .7034 .55573 .71905 .5511 .7118 .54275 Mtetra
.658 .756 .923 r
.7118 .54275 .71905 .5511 .73478 .54646 .72759 .53801 Mtetra
.658 .755 .922 r
.72759 .53801 .73478 .54646 .7506 .54182 .74346 .53325 Mtetra
.657 .753 .921 r
.74346 .53325 .7506 .54182 .76651 .53722 .75943 .52851 Mtetra
.656 .75 .919 r
.75943 .52851 .76651 .53722 .78251 .53263 .77549 .52379 Mtetra
.653 .747 .919 r
.77549 .52379 .78251 .53263 .7986 .52797 .79165 .51913 Mtetra
.654 .749 .919 r
.79165 .51913 .7986 .52797 .81477 .52319 .8079 .51443 Mtetra
.657 .753 .921 r
.8079 .51443 .81477 .52319 .83104 .51837 .82422 .50958 Mtetra
.657 .754 .921 r
.82422 .50958 .83104 .51837 .84739 .51354 .84064 .50467 Mtetra
.657 .753 .921 r
.84064 .50467 .84739 .51354 .86384 .50875 .85716 .49977 Mtetra
.655 .751 .92 r
.85716 .49977 .86384 .50875 .88039 .50397 .87377 .4949 Mtetra
.654 .749 .92 r
.87377 .4949 .88039 .50397 .89703 .49911 .89049 .49005 Mtetra
.656 .751 .92 r
.89049 .49005 .89703 .49911 .91376 .49418 .90729 .4851 Mtetra
.657 .753 .921 r
.90729 .4851 .91376 .49418 .93059 .48922 .92418 .48008 Mtetra
.657 .752 .921 r
.92418 .48008 .93059 .48922 .94751 .48427 .94118 .47504 Mtetra
.655 .752 .921 r
.33493 .64356 .34356 .65108 .35737 .64704 .34878 .6395 Mtetra
.34878 .6395 .35737 .64704 .37125 .64299 .36271 .6354 Mtetra
.657 .752 .92 r
.36271 .6354 .37125 .64299 .3852 .63888 .37671 .63119 Mtetra
.657 .75 .919 r
.37671 .63119 .3852 .63888 .39923 .63468 .39079 .62697 Mtetra
.655 .75 .92 r
.39079 .62697 .39923 .63468 .41334 .6305 .40494 .6228 Mtetra
.654 .752 .922 r
.40494 .6228 .41334 .6305 .42751 .62636 .41916 .61866 Mtetra
.654 .753 .922 r
.41916 .61866 .42751 .62636 .44176 .62223 .43346 .61447 Mtetra
.658 .753 .92 r
.43346 .61447 .44176 .62223 .45609 .61805 .44784 .61011 Mtetra
.659 .75 .917 r
.44784 .61011 .45609 .61805 .47049 .61373 .46229 .60573 Mtetra
.656 .748 .918 r
.46229 .60573 .47049 .61373 .48498 .60937 .47682 .60143 Mtetra
.654 .751 .921 r
.47682 .60143 .48498 .60937 .49953 .60507 .49142 .59717 Mtetra
.652 .752 .923 r
.49142 .59717 .49953 .60507 .51417 .6008 .50611 .59293 Mtetra
.653 .754 .924 r
.50611 .59293 .51417 .6008 .52888 .59654 .52087 .58865 Mtetra
.657 .756 .923 r
.52087 .58865 .52888 .59654 .54367 .59227 .53572 .58419 Mtetra
.659 .753 .92 r
.53572 .58419 .54367 .59227 .55855 .58796 .55064 .57965 Mtetra
.656 .748 .917 r
.55064 .57965 .55855 .58796 .5735 .5836 .56565 .5752 Mtetra
.654 .746 .917 r
.56565 .5752 .5735 .5836 .58853 .57908 .58074 .57081 Mtetra
.652 .75 .921 r
.58074 .57081 .58853 .57908 .60365 .57458 .59591 .56645 Mtetra
.653 .754 .924 r
.59591 .56645 .60365 .57458 .61884 .57008 .61117 .56202 Mtetra
.655 .758 .925 r
.61117 .56202 .61884 .57008 .63412 .56558 .62651 .55747 Mtetra
.658 .759 .924 r
.62651 .55747 .63412 .56558 .64949 .56107 .64193 .55281 Mtetra
.659 .756 .922 r
.64193 .55281 .64949 .56107 .66494 .55658 .65743 .54808 Mtetra
.658 .751 .919 r
.65743 .54808 .66494 .55658 .68048 .55209 .67302 .54337 Mtetra
.656 .746 .916 r
.67302 .54337 .68048 .55209 .6961 .54745 .6887 .53873 Mtetra
.653 .746 .918 r
.6887 .53873 .6961 .54745 .7118 .54275 .70447 .53417 Mtetra
.654 .751 .921 r
.70447 .53417 .7118 .54275 .72759 .53801 .72033 .52953 Mtetra
.658 .757 .923 r
.72033 .52953 .72759 .53801 .74346 .53325 .73626 .5247 Mtetra
.659 .756 .922 r
.73626 .5247 .74346 .53325 .75943 .52851 .75229 .51983 Mtetra
.657 .754 .921 r
.75229 .51983 .75943 .52851 .77549 .52379 .76841 .51498 Mtetra
.656 .752 .92 r
.76841 .51498 .77549 .52379 .79165 .51913 .78462 .51016 Mtetra
.653 .748 .919 r
.78462 .51016 .79165 .51913 .8079 .51443 .80093 .50543 Mtetra
.654 .748 .919 r
.80093 .50543 .8079 .51443 .82422 .50958 .81734 .50067 Mtetra
.657 .753 .921 r
.81734 .50067 .82422 .50958 .84064 .50467 .83383 .49573 Mtetra
.657 .754 .921 r
.83383 .49573 .84064 .50467 .85716 .49977 .8504 .49074 Mtetra
.657 .752 .921 r
.8504 .49074 .85716 .49977 .87377 .4949 .86708 .48576 Mtetra
.655 .75 .92 r
.86708 .48576 .87377 .4949 .89049 .49005 .88386 .48084 Mtetra
.654 .75 .92 r
.88386 .48084 .89049 .49005 .90729 .4851 .90074 .4759 Mtetra
.656 .752 .92 r
.90074 .4759 .90729 .4851 .92418 .48008 .91771 .47084 Mtetra
.657 .753 .92 r
.91771 .47084 .92418 .48008 .94118 .47504 .93477 .46574 Mtetra
.655 .752 .921 r
.32622 .63599 .33493 .64356 .34878 .6395 .34012 .63188 Mtetra
.656 .752 .92 r
.34012 .63188 .34878 .6395 .36271 .6354 .35409 .62768 Mtetra
.658 .751 .919 r
.35409 .62768 .36271 .6354 .37671 .63119 .36814 .62342 Mtetra
.655 .75 .92 r
.36814 .62342 .37671 .63119 .39079 .62697 .38226 .61922 Mtetra
.654 .751 .921 r
.38226 .61922 .39079 .62697 .40494 .6228 .39646 .61505 Mtetra
.654 .752 .922 r
.39646 .61505 .40494 .6228 .41916 .61866 .41073 .61086 Mtetra
.658 .753 .92 r
.41073 .61086 .41916 .61866 .43346 .61447 .42507 .6065 Mtetra
.659 .75 .917 r
.42507 .6065 .43346 .61447 .44784 .61011 .4395 .60208 Mtetra
.655 .749 .919 r
.4395 .60208 .44784 .61011 .46229 .60573 .454 .59777 Mtetra
.653 .751 .922 r
.454 .59777 .46229 .60573 .47682 .60143 .46858 .59351 Mtetra
.652 .753 .923 r
.46858 .59351 .47682 .60143 .49142 .59717 .48323 .58927 Mtetra
.654 .755 .924 r
.48323 .58927 .49142 .59717 .50611 .59293 .49797 .58493 Mtetra
.66 .755 .92 r
.49797 .58493 .50611 .59293 .52087 .58865 .51279 .58034 Mtetra
.655 .747 .917 r
.51279 .58034 .52087 .58865 .53572 .58419 .52769 .57593 Mtetra
.646 .747 .923 r
.52769 .57593 .53572 .58419 .55064 .57965 .54267 .57183 Mtetra
.637 .756 .934 r
.54267 .57183 .55064 .57965 .56565 .5752 .55773 .56794 Mtetra
.632 .771 .946 r
.55773 .56794 .56565 .5752 .58074 .57081 .57289 .56409 Mtetra
.631 .787 .957 r
.57289 .56409 .58074 .57081 .59591 .56645 .58813 .56012 Mtetra
.635 .801 .962 r
.58813 .56012 .59591 .56645 .61117 .56202 .60346 .55588 Mtetra
.644 .81 .963 r
.60346 .55588 .61117 .56202 .62651 .55747 .61887 .55129 Mtetra
.655 .814 .959 r
.61887 .55129 .62651 .55747 .64193 .55281 .63435 .54635 Mtetra
.665 .809 .953 r
.63435 .54635 .64193 .55281 .65743 .54808 .6499 .54113 Mtetra
.67 .798 .944 r
.6499 .54113 .65743 .54808 .67302 .54337 .66553 .53579 Mtetra
.67 .782 .934 r
.66553 .53579 .67302 .54337 .6887 .53873 .68125 .53049 Mtetra
.665 .765 .925 r
.68125 .53049 .6887 .53873 .70447 .53417 .69706 .5254 Mtetra
.657 .75 .919 r
.69706 .5254 .70447 .53417 .72033 .52953 .71297 .52061 Mtetra
.652 .746 .918 r
.71297 .52061 .72033 .52953 .73626 .5247 .72899 .516 Mtetra
.657 .754 .922 r
.72899 .516 .73626 .5247 .75229 .51983 .74508 .51115 Mtetra
.659 .757 .922 r
.74508 .51115 .75229 .51983 .76841 .51498 .76126 .50618 Mtetra
.658 .755 .921 r
.76126 .50618 .76841 .51498 .78462 .51016 .77753 .50124 Mtetra
.656 .752 .92 r
.77753 .50124 .78462 .51016 .80093 .50543 .7939 .49633 Mtetra
.653 .748 .919 r
.7939 .49633 .80093 .50543 .81734 .50067 .81037 .49154 Mtetra
.654 .749 .919 r
.81037 .49154 .81734 .50067 .83383 .49573 .82694 .48668 Mtetra
.657 .753 .921 r
.82694 .48668 .83383 .49573 .8504 .49074 .84358 .48164 Mtetra
.84358 .48164 .8504 .49074 .86708 .48576 .86033 .47658 Mtetra
.656 .752 .921 r
.86033 .47658 .86708 .48576 .88386 .48084 .87717 .47153 Mtetra
.654 .749 .92 r
.87717 .47153 .88386 .48084 .90074 .4759 .89412 .46655 Mtetra
.655 .75 .92 r
.89412 .46655 .90074 .4759 .91771 .47084 .91117 .4615 Mtetra
.657 .752 .92 r
.91117 .4615 .91771 .47084 .93477 .46574 .92831 .45634 Mtetra
.655 .752 .921 r
.31743 .62834 .32622 .63599 .34012 .63188 .33137 .62417 Mtetra
.658 .752 .919 r
.33137 .62417 .34012 .63188 .35409 .62768 .34539 .61988 Mtetra
.657 .75 .919 r
.34539 .61988 .35409 .62768 .36814 .62342 .35949 .61563 Mtetra
.654 .751 .921 r
.35949 .61563 .36814 .62342 .38226 .61922 .37365 .61142 Mtetra
.653 .752 .922 r
.37365 .61142 .38226 .61922 .39646 .61505 .38789 .60722 Mtetra
.657 .753 .921 r
.38789 .60722 .39646 .61505 .41073 .61086 .40221 .60289 Mtetra
.659 .751 .918 r
.40221 .60289 .41073 .61086 .42507 .6065 .41661 .59844 Mtetra
.656 .749 .918 r
.41661 .59844 .42507 .6065 .4395 .60208 .43108 .59409 Mtetra
.653 .751 .922 r
.43108 .59409 .4395 .60208 .454 .59777 .44563 .58981 Mtetra
.651 .752 .924 r
.44563 .58981 .454 .59777 .46858 .59351 .46026 .58557 Mtetra
.656 .755 .923 r
.46026 .58557 .46858 .59351 .48323 .58927 .47496 .58113 Mtetra
.659 .752 .919 r
.47496 .58113 .48323 .58927 .49797 .58493 .48975 .57656 Mtetra
.647 .744 .92 r
.48975 .57656 .49797 .58493 .51279 .58034 .50462 .57241 Mtetra
.628 .751 .935 r
.50462 .57241 .51279 .58034 .52769 .57593 .51957 .56883 Mtetra
.607 .767 .956 r
.51957 .56883 .52769 .57593 .54267 .57183 .53461 .56568 Mtetra
.567 .782 .98 r
.53461 .56568 .54267 .57183 .55773 .56794 .54975 .56316 Mtetra
.54 .815 .997 r
.54975 .56316 .55773 .56794 .57289 .56409 .56499 .5605 Mtetra
.529 .847 .998 r
.56499 .5605 .57289 .56409 .58813 .56012 .58032 .55728 Mtetra
.536 .871 .992 r
.58032 .55728 .58813 .56012 .60346 .55588 .59574 .55336 Mtetra
.561 .889 .987 r
.59574 .55336 .60346 .55588 .61887 .55129 .61123 .54873 Mtetra
.598 .903 .985 r
.61123 .54873 .61887 .55129 .63435 .54635 .62679 .54339 Mtetra
.641 .907 .982 r
.62679 .54339 .63435 .54635 .6499 .54113 .6424 .53735 Mtetra
.68 .896 .975 r
.6424 .53735 .6499 .54113 .66553 .53579 .65807 .53072 Mtetra
.698 .864 .961 r
.65807 .53072 .66553 .53579 .68125 .53049 .6738 .52395 Mtetra
.687 .82 .946 r
.6738 .52395 .68125 .53049 .69706 .5254 .68963 .51779 Mtetra
.678 .789 .933 r
.68963 .51779 .69706 .5254 .71297 .52061 .70556 .51208 Mtetra
.664 .762 .923 r
.70556 .51208 .71297 .52061 .72899 .516 .72161 .50693 Mtetra
.653 .746 .918 r
.72161 .50693 .72899 .516 .74508 .51115 .73778 .50221 Mtetra
.655 .751 .92 r
.73778 .50221 .74508 .51115 .76126 .50618 .75403 .49735 Mtetra
.659 .757 .922 r
.75403 .49735 .76126 .50618 .77753 .50124 .77037 .49229 Mtetra
.658 .754 .921 r
.77037 .49229 .77753 .50124 .7939 .49633 .7868 .48726 Mtetra
.656 .752 .921 r
.7868 .48726 .7939 .49633 .81037 .49154 .80333 .48229 Mtetra
.653 .748 .919 r
.80333 .48229 .81037 .49154 .82694 .48668 .81996 .47743 Mtetra
.655 .75 .92 r
.81996 .47743 .82694 .48668 .84358 .48164 .83669 .47245 Mtetra
.658 .753 .921 r
.83669 .47245 .84358 .48164 .86033 .47658 .8535 .46731 Mtetra
.657 .753 .921 r
.8535 .46731 .86033 .47658 .87717 .47153 .87041 .46218 Mtetra
.655 .751 .921 r
.87041 .46218 .87717 .47153 .89412 .46655 .88743 .4571 Mtetra
.654 .749 .92 r
.88743 .4571 .89412 .46655 .91117 .4615 .90455 .45204 Mtetra
.656 .752 .92 r
.90455 .45204 .91117 .4615 .92831 .45634 .92177 .44684 Mtetra
.657 .752 .92 r
.30855 .6206 .31743 .62834 .33137 .62417 .32254 .61635 Mtetra
.658 .751 .919 r
.32254 .61635 .33137 .62417 .34539 .61988 .33661 .61202 Mtetra
.655 .75 .92 r
.33661 .61202 .34539 .61988 .35949 .61563 .35074 .60778 Mtetra
.654 .751 .922 r
.35074 .60778 .35949 .61563 .37365 .61142 .36495 .60356 Mtetra
.655 .752 .922 r
.36495 .60356 .37365 .61142 .38789 .60722 .37924 .59927 Mtetra
.66 .753 .919 r
.37924 .59927 .38789 .60722 .40221 .60289 .39361 .5948 Mtetra
.657 .75 .918 r
.39361 .5948 .40221 .60289 .41661 .59844 .40806 .59038 Mtetra
.654 .751 .921 r
.40806 .59038 .41661 .59844 .43108 .59409 .42258 .58607 Mtetra
.651 .752 .923 r
.42258 .58607 .43108 .59409 .44563 .58981 .43717 .58182 Mtetra
.656 .755 .923 r
.43717 .58182 .44563 .58981 .46026 .58557 .45185 .57737 Mtetra
.659 .752 .919 r
.45185 .57737 .46026 .58557 .47496 .58113 .46661 .57279 Mtetra
.641 .744 .924 r
.46661 .57279 .47496 .58113 .48975 .57656 .48145 .56884 Mtetra
.61 .751 .945 r
.48145 .56884 .48975 .57656 .50462 .57241 .49636 .56575 Mtetra
.548 .76 .976 r
.49636 .56575 .50462 .57241 .51957 .56883 .51136 .56386 Mtetra
.469 .78 .998 r
.51136 .56386 .51957 .56883 .53461 .56568 .52647 .56256 Mtetra
.416 .809 .987 r
.52647 .56256 .53461 .56568 .54975 .56316 .54168 .56073 Mtetra
.432 .834 .977 r
.54168 .56073 .54975 .56316 .56499 .5605 .557 .55809 Mtetra
.486 .86 .983 r
.557 .55809 .56499 .5605 .58032 .55728 .57241 .55463 Mtetra
.537 .877 .989 r
.57241 .55463 .58032 .55728 .59574 .55336 .58791 .55049 Mtetra
.573 .886 .99 r
.58791 .55049 .59574 .55336 .61123 .54873 .60348 .54583 Mtetra
.599 .895 .988 r
.60348 .54583 .61123 .54873 .62679 .54339 .61913 .54063 Mtetra
.625 .908 .983 r
.61913 .54063 .62679 .54339 .6424 .53735 .63484 .53474 Mtetra
.655 .922 .976 r
.63484 .53474 .6424 .53735 .65807 .53072 .6506 .52801 Mtetra
.688 .929 .968 r
.6506 .52801 .65807 .53072 .6738 .52395 .66639 .52046 Mtetra
.72 .917 .961 r
.66639 .52046 .6738 .52395 .68963 .51779 .68223 .51235 Mtetra
.718 .862 .95 r
.68223 .51235 .68963 .51779 .70556 .51208 .69815 .50482 Mtetra
.69 .806 .937 r
.69815 .50482 .70556 .51208 .72161 .50693 .71421 .49851 Mtetra
.669 .77 .926 r
.71421 .49851 .72161 .50693 .73778 .50221 .7304 .49306 Mtetra
.653 .747 .919 r
.7304 .49306 .73778 .50221 .75403 .49735 .74672 .48824 Mtetra
.656 .751 .92 r
.74672 .48824 .75403 .49735 .77037 .49229 .76313 .48329 Mtetra
.66 .756 .921 r
.76313 .48329 .77037 .49229 .7868 .48726 .77962 .47813 Mtetra
.658 .754 .921 r
.77962 .47813 .7868 .48726 .80333 .48229 .79622 .47304 Mtetra
.655 .751 .92 r
.79622 .47304 .80333 .48229 .81996 .47743 .81291 .46804 Mtetra
.652 .748 .92 r
.81291 .46804 .81996 .47743 .83669 .47245 .82972 .46311 Mtetra
.657 .752 .92 r
.82972 .46311 .83669 .47245 .8535 .46731 .8466 .45796 Mtetra
.658 .753 .921 r
.8466 .45796 .8535 .46731 .87041 .46218 .86358 .45275 Mtetra
.657 .752 .92 r
.86358 .45275 .87041 .46218 .88743 .4571 .88067 .44755 Mtetra
.654 .75 .92 r
.88067 .44755 .88743 .4571 .90455 .45204 .89786 .44243 Mtetra
.655 .75 .92 r
.89786 .44243 .90455 .45204 .92177 .44684 .91516 .43724 Mtetra
.658 .752 .92 r
.29958 .61279 .30855 .6206 .32254 .61635 .31362 .60844 Mtetra
.657 .751 .919 r
.31362 .60844 .32254 .61635 .33661 .61202 .32773 .60412 Mtetra
.654 .751 .921 r
.32773 .60412 .33661 .61202 .35074 .60778 .34191 .59986 Mtetra
.653 .752 .922 r
.34191 .59986 .35074 .60778 .36495 .60356 .35617 .5956 Mtetra
.658 .753 .92 r
.35617 .5956 .36495 .60356 .37924 .59927 .37051 .59117 Mtetra
.659 .75 .918 r
.37051 .59117 .37924 .59927 .39361 .5948 .38493 .58666 Mtetra
.655 .75 .92 r
.38493 .58666 .39361 .5948 .40806 .59038 .39942 .5823 Mtetra
.651 .751 .923 r
.39942 .5823 .40806 .59038 .42258 .58607 .41398 .57802 Mtetra
.653 .754 .924 r
.41398 .57802 .42258 .58607 .43717 .58182 .42863 .57366 Mtetra
.661 .754 .919 r
.42863 .57366 .43717 .58182 .45185 .57737 .44337 .56899 Mtetra
.641 .744 .924 r
.44337 .56899 .45185 .57737 .46661 .57279 .45817 .56503 Mtetra
.599 .747 .948 r
.45817 .56503 .46661 .57279 .48145 .56884 .47303 .56222 Mtetra
.5 .743 .982 r
.47303 .56222 .48145 .56884 .49636 .56575 .48798 .56125 Mtetra
.392 .759 .993 r
.48798 .56125 .49636 .56575 .51136 .56386 .50303 .56075 Mtetra
.376 .79 .979 r
.50303 .56075 .51136 .56386 .52647 .56256 .51821 .5594 Mtetra
.477 .838 .993 r
.51821 .5594 .52647 .56256 .54168 .56073 .5335 .55666 Mtetra
.585 .856 .995 r
.5335 .55666 .54168 .56073 .557 .55809 .54888 .55259 Mtetra
.657 .836 .969 r
.54888 .55259 .557 .55809 .57241 .55463 .56434 .54734 Mtetra
.669 .79 .939 r
.56434 .54734 .57241 .55463 .58791 .55049 .57988 .54202 Mtetra
.654 .757 .925 r
.57988 .54202 .58791 .55049 .60348 .54583 .59551 .5373 Mtetra
.637 .751 .931 r
.59551 .5373 .60348 .54583 .61913 .54063 .61125 .53319 Mtetra
.632 .779 .952 r
.61125 .53319 .61913 .54063 .63484 .53474 .62708 .52902 Mtetra
.656 .836 .97 r
.62708 .52902 .63484 .53474 .6506 .52801 .64297 .52365 Mtetra
.685 .885 .972 r
.64297 .52365 .6506 .52801 .66639 .52046 .65889 .51693 Mtetra
.719 .917 .962 r
.65889 .51693 .66639 .52046 .68223 .51235 .67482 .50879 Mtetra
.744 .922 .951 r
.67482 .50879 .68223 .51235 .69815 .50482 .69076 .49977 Mtetra
.741 .881 .945 r
.69076 .49977 .69815 .50482 .71421 .49851 .70679 .49119 Mtetra
.698 .81 .935 r
.70679 .49119 .71421 .49851 .7304 .49306 .72298 .48448 Mtetra
.669 .77 .925 r
.72298 .48448 .7304 .49306 .74672 .48824 .73933 .47893 Mtetra
.651 .747 .919 r
.73933 .47893 .74672 .48824 .76313 .48329 .75581 .47411 Mtetra
.658 .754 .92 r
.75581 .47411 .76313 .48329 .77962 .47813 .77238 .46897 Mtetra
.66 .756 .921 r
.77238 .46897 .77962 .47813 .79622 .47304 .78903 .46374 Mtetra
.657 .753 .921 r
.78903 .46374 .79622 .47304 .81291 .46804 .80579 .45859 Mtetra
.653 .749 .92 r
.80579 .45859 .81291 .46804 .82972 .46311 .82266 .45358 Mtetra
.654 .749 .919 r
.82266 .45358 .82972 .46311 .8466 .45796 .83963 .4485 Mtetra
.658 .753 .92 r
.83963 .4485 .8466 .45796 .86358 .45275 .85668 .44322 Mtetra
.657 .753 .92 r
.85668 .44322 .86358 .45275 .88067 .44755 .87383 .43794 Mtetra
.655 .751 .921 r
.87383 .43794 .88067 .44755 .89786 .44243 .8911 .43272 Mtetra
.654 .75 .92 r
.8911 .43272 .89786 .44243 .91516 .43724 .90847 .42751 Mtetra
.658 .752 .919 r
.29053 .60487 .29958 .61279 .31362 .60844 .30461 .60047 Mtetra
.655 .751 .92 r
.30461 .60047 .31362 .60844 .32773 .60412 .31877 .59615 Mtetra
.653 .751 .922 r
.31877 .59615 .32773 .60412 .34191 .59986 .33299 .59187 Mtetra
.655 .752 .921 r
.33299 .59187 .34191 .59986 .35617 .5956 .3473 .58753 Mtetra
.66 .752 .919 r
.3473 .58753 .35617 .5956 .37051 .59117 .36169 .58298 Mtetra
.657 .75 .919 r
.36169 .58298 .37051 .59117 .38493 .58666 .37615 .57852 Mtetra
.653 .751 .922 r
.37615 .57852 .38493 .58666 .39942 .5823 .39069 .57417 Mtetra
.651 .752 .924 r
.39069 .57417 .39942 .5823 .41398 .57802 .4053 .56987 Mtetra
.66 .755 .92 r
.4053 .56987 .41398 .57802 .42863 .57366 .42001 .56519 Mtetra
.648 .745 .92 r
.42001 .56519 .42863 .57366 .44337 .56899 .43478 .56097 Mtetra
.603 .743 .943 r
.43478 .56097 .44337 .56899 .45817 .56503 .44961 .55807 Mtetra
.492 .731 .978 r
.44961 .55807 .45817 .56503 .47303 .56222 .46449 .55739 Mtetra
.358 .733 .988 r
.46449 .55739 .47303 .56222 .48798 .56125 .47948 .55755 Mtetra
.382 .778 .987 r
.47948 .55755 .48798 .56125 .50303 .56075 .49461 .55656 Mtetra
.548 .838 .998 r
.49461 .55656 .50303 .56075 .51821 .5594 .50986 .5533 Mtetra
.704 .829 .942 r
.50986 .5533 .51821 .5594 .5335 .55666 .52521 .54665 Mtetra
.719 .74 .868 r
.52521 .54665 .5335 .55666 .54888 .55259 .54062 .53884 Mtetra
.695 .671 .822 r
.54062 .53884 .54888 .55259 .56434 .54734 .55609 .53141 Mtetra
.669 .633 .804 r
.55609 .53141 .56434 .54734 .57988 .54202 .57164 .52512 Mtetra
.643 .61 .802 r
.57164 .52512 .57988 .54202 .59551 .5373 .5873 .52035 Mtetra
.618 .598 .808 r
.5873 .52035 .59551 .5373 .61125 .53319 .60308 .51708 Mtetra
.596 .598 .824 r
.60308 .51708 .61125 .53319 .62708 .52902 .61899 .51499 Mtetra
.586 .623 .855 r
.61899 .51499 .62708 .52902 .64297 .52365 .63504 .51328 Mtetra
.604 .7 .911 r
.63504 .51328 .64297 .52365 .65889 .51693 .65117 .51042 Mtetra
.686 .827 .951 r
.65117 .51042 .65889 .51693 .67482 .50879 .66726 .50412 Mtetra
.739 .892 .949 r
.66726 .50412 .67482 .50879 .69076 .49977 .68332 .4955 Mtetra
.766 .909 .938 r
.68332 .4955 .69076 .49977 .70679 .49119 .69938 .48569 Mtetra
.749 .874 .937 r
.69938 .48569 .70679 .49119 .72298 .48448 .71553 .47671 Mtetra
.696 .802 .93 r
.71553 .47671 .72298 .48448 .73933 .47893 .73188 .46998 Mtetra
.663 .762 .924 r
.73188 .46998 .73933 .47893 .75581 .47411 .7484 .4646 Mtetra
.652 .746 .919 r
.7484 .4646 .75581 .47411 .77238 .46897 .76505 .45969 Mtetra
.66 .756 .921 r
.76505 .45969 .77238 .46897 .78903 .46374 .78178 .45438 Mtetra
.659 .754 .921 r
.78178 .45438 .78903 .46374 .80579 .45859 .7986 .44911 Mtetra
.655 .751 .921 r
.7986 .44911 .80579 .45859 .82266 .45358 .81553 .44395 Mtetra
.652 .748 .92 r
.81553 .44395 .82266 .45358 .83963 .4485 .83258 .43889 Mtetra
.657 .752 .92 r
.83258 .43889 .83963 .4485 .85668 .44322 .8497 .4336 Mtetra
.658 .753 .92 r
.8497 .4336 .85668 .44322 .87383 .43794 .86693 .42824 Mtetra
.656 .752 .92 r
.86693 .42824 .87383 .43794 .8911 .43272 .88426 .42291 Mtetra
.654 .75 .92 r
.88426 .42291 .8911 .43272 .90847 .42751 .90171 .41766 Mtetra
.658 .751 .919 r
.28139 .59686 .29053 .60487 .30461 .60047 .29552 .59244 Mtetra
.655 .751 .921 r
.29552 .59244 .30461 .60047 .31877 .59615 .30971 .58811 Mtetra
.653 .751 .922 r
.30971 .58811 .31877 .59615 .33299 .59187 .32399 .58379 Mtetra
.657 .752 .92 r
.32399 .58379 .33299 .59187 .3473 .58753 .33834 .57932 Mtetra
.66 .751 .918 r
.33834 .57932 .3473 .58753 .36169 .58298 .35278 .57474 Mtetra
.655 .75 .92 r
.35278 .57474 .36169 .58298 .37615 .57852 .36729 .57031 Mtetra
.651 .751 .923 r
.36729 .57031 .37615 .57852 .39069 .57417 .38187 .56598 Mtetra
.655 .753 .922 r
.38187 .56598 .39069 .57417 .4053 .56987 .39654 .56148 Mtetra
.658 .75 .918 r
.39654 .56148 .4053 .56987 .42001 .56519 .4113 .55686 Mtetra
.621 .742 .933 r
.4113 .55686 .42001 .56519 .43478 .56097 .42609 .55345 Mtetra
.527 .731 .968 r
.42609 .55345 .43478 .56097 .44961 .55807 .44093 .55225 Mtetra
.362 .707 .985 r
.44093 .55225 .44961 .55807 .46449 .55739 .45584 .55296 Mtetra
.368 .752 .988 r
.45584 .55296 .46449 .55739 .47948 .55755 .47089 .55264 Mtetra
.572 .827 .993 r
.47089 .55264 .47948 .55755 .49461 .55656 .48611 .54927 Mtetra
.745 .805 .9 r
.48611 .54927 .49461 .55656 .50986 .5533 .50145 .54074 Mtetra
.739 .702 .817 r
.50145 .54074 .50986 .5533 .52521 .54665 .51685 .5306 Mtetra
.72 .653 .782 r
.51685 .5306 .52521 .54665 .54062 .53884 .53229 .52025 Mtetra
.69 .616 .768 r
.53229 .52025 .54062 .53884 .55609 .53141 .54777 .51147 Mtetra
.661 .591 .766 r
.54777 .51147 .55609 .53141 .57164 .52512 .56333 .50469 Mtetra
.635 .573 .768 r
.56333 .50469 .57164 .52512 .5873 .52035 .57898 .49984 Mtetra
.607 .558 .774 r
.57898 .49984 .5873 .52035 .60308 .51708 .59477 .49695 Mtetra
.575 .545 .784 r
.59477 .49695 .60308 .51708 .61899 .51499 .61072 .49608 Mtetra
.543 .54 .801 r
.61072 .49608 .61899 .51499 .63504 .51328 .62685 .49681 Mtetra
.54 .567 .831 r
.62685 .49681 .63504 .51328 .65117 .51042 .64312 .49735 Mtetra
.565 .632 .877 r
.64312 .49735 .65117 .51042 .66726 .50412 .65948 .4963 Mtetra
.686 .796 .933 r
.65948 .4963 .66726 .50412 .68332 .4955 .67573 .49001 Mtetra
.758 .876 .932 r
.67573 .49001 .68332 .4955 .69938 .48569 .6919 .4806 Mtetra
.781 .892 .923 r
.6919 .4806 .69938 .48569 .71553 .47671 .70806 .4701 Mtetra
.738 .845 .93 r
.70806 .4701 .71553 .47671 .73188 .46998 .72439 .46154 Mtetra
.685 .784 .926 r
.72439 .46154 .73188 .46998 .7484 .4646 .74093 .45522 Mtetra
.654 .752 .922 r
.74093 .45522 .7484 .4646 .76505 .45969 .75764 .45014 Mtetra
.656 .75 .919 r
.75764 .45014 .76505 .45969 .78178 .45438 .77444 .44493 Mtetra
.66 .755 .921 r
.77444 .44493 .78178 .45438 .7986 .44911 .79133 .43955 Mtetra
.657 .753 .921 r
.79133 .43955 .7986 .44911 .81553 .44395 .80833 .43425 Mtetra
.652 .749 .921 r
.80833 .43425 .81553 .44395 .83258 .43889 .82544 .42912 Mtetra
.655 .75 .92 r
.82544 .42912 .83258 .43889 .8497 .4336 .84265 .42386 Mtetra
.658 .753 .92 r
.84265 .42386 .8497 .4336 .86693 .42824 .85995 .41843 Mtetra
.657 .752 .92 r
.85995 .41843 .86693 .42824 .88426 .42291 .87735 .41302 Mtetra
.654 .751 .921 r
.87735 .41302 .88426 .42291 .90171 .41766 .89487 .40768 Mtetra
.657 .751 .919 r
.27216 .58878 .28139 .59686 .29552 .59244 .28633 .58434 Mtetra
.654 .751 .921 r
.28633 .58434 .29552 .59244 .30971 .58811 .30057 .57998 Mtetra
.653 .751 .922 r
.30057 .57998 .30971 .58811 .32399 .58379 .31489 .57562 Mtetra
.659 .753 .919 r
.31489 .57562 .32399 .58379 .33834 .57932 .3293 .57104 Mtetra
.658 .751 .918 r
.3293 .57104 .33834 .57932 .35278 .57474 .34378 .56646 Mtetra
.653 .751 .921 r
.34378 .56646 .35278 .57474 .36729 .57031 .35834 .56203 Mtetra
.65 .751 .923 r
.35834 .56203 .36729 .57031 .38187 .56598 .37297 .55768 Mtetra
.66 .754 .92 r
.37297 .55768 .38187 .56598 .39654 .56148 .3877 .55295 Mtetra
.644 .745 .923 r
.3877 .55295 .39654 .56148 .4113 .55686 .40248 .54876 Mtetra
.584 .738 .949 r
.40248 .54876 .4113 .55686 .42609 .55345 .4173 .54632 Mtetra
.414 .696 .978 r
.4173 .54632 .42609 .55345 .44093 .55225 .43213 .54697 Mtetra
.334 .711 .983 r
.43213 .54697 .44093 .55225 .45584 .55296 .44709 .54764 Mtetra
.523 .797 .996 r
.44709 .54764 .45584 .55296 .47089 .55264 .46224 .54541 Mtetra
.747 .807 .9 r
.46224 .54541 .47089 .55264 .48611 .54927 .47758 .53675 Mtetra
.76 .71 .805 r
.47758 .53675 .48611 .54927 .50145 .54074 .49301 .52482 Mtetra
.744 .665 .772 r
.49301 .52482 .50145 .54074 .51685 .5306 .50846 .51221 Mtetra
.708 .626 .764 r
.50846 .51221 .51685 .5306 .53229 .52025 .52392 .5019 Mtetra
.667 .608 .779 r
.52392 .5019 .53229 .52025 .54777 .51147 .53943 .49507 Mtetra
.655 .623 .805 r
.53943 .49507 .54777 .51147 .56333 .50469 .55503 .48955 Mtetra
.648 .636 .824 r
.55503 .48955 .56333 .50469 .57898 .49984 .57072 .48465 Mtetra
.636 .631 .828 r
.57072 .48465 .57898 .49984 .59477 .49695 .5865 .48037 Mtetra
.61 .601 .817 r
.5865 .48037 .59477 .49695 .61072 .49608 .60242 .4774 Mtetra
.544 .544 .805 r
.60242 .4774 .61072 .49608 .62685 .49681 .61855 .47797 Mtetra
.495 .516 .808 r
.61855 .47797 .62685 .49681 .64312 .49735 .6349 .48089 Mtetra
.496 .546 .837 r
.6349 .48089 .64312 .49735 .65948 .4963 .6514 .48316 Mtetra
.562 .632 .879 r
.6514 .48316 .65948 .4963 .67573 .49001 .66793 .48214 Mtetra
.714 .806 .922 r
.66793 .48214 .67573 .49001 .6919 .4806 .68428 .47458 Mtetra
.779 .868 .914 r
.68428 .47458 .6919 .4806 .70806 .4701 .70054 .46403 Mtetra
.779 .869 .915 r
.70054 .46403 .70806 .4701 .72439 .46154 .71684 .45347 Mtetra
.709 .804 .924 r
.71684 .45347 .72439 .46154 .74093 .45522 .73339 .44606 Mtetra
.666 .764 .923 r
.73339 .44606 .74093 .45522 .75764 .45014 .75014 .44043 Mtetra
.652 .747 .92 r
.75014 .44043 .75764 .45014 .77444 .44493 .76702 .43536 Mtetra
.661 .755 .92 r
.76702 .43536 .77444 .44493 .79133 .43955 .78398 .42989 Mtetra
.658 .753 .92 r
.78398 .42989 .79133 .43955 .80833 .43425 .80105 .4245 Mtetra
.654 .751 .921 r
.80105 .4245 .80833 .43425 .82544 .42912 .81823 .41925 Mtetra
.653 .749 .92 r
.81823 .41925 .82544 .42912 .84265 .42386 .83552 .414 Mtetra
.658 .753 .92 r
.83552 .414 .84265 .42386 .85995 .41843 .85289 .40852 Mtetra
.657 .753 .92 r
.85289 .40852 .85995 .41843 .87735 .41302 .87037 .40303 Mtetra
.655 .751 .921 r
.87037 .40303 .87735 .41302 .89487 .40768 .88796 .3976 Mtetra
.656 .751 .92 r
.26283 .58062 .27216 .58878 .28633 .58434 .27705 .57617 Mtetra
.654 .751 .921 r
.27705 .57617 .28633 .58434 .30057 .57998 .29133 .57178 Mtetra
.654 .752 .921 r
.29133 .57178 .30057 .57998 .31489 .57562 .3057 .56735 Mtetra
.66 .752 .919 r
.3057 .56735 .31489 .57562 .3293 .57104 .32016 .56268 Mtetra
.657 .751 .919 r
.32016 .56268 .3293 .57104 .34378 .56646 .33469 .55811 Mtetra
.652 .751 .922 r
.33469 .55811 .34378 .56646 .35834 .56203 .34929 .55368 Mtetra
.651 .751 .923 r
.34929 .55368 .35834 .56203 .37297 .55768 .36397 .54926 Mtetra
.661 .754 .919 r
.36397 .54926 .37297 .55768 .3877 .55295 .37875 .54444 Mtetra
.626 .743 .931 r
.37875 .54444 .3877 .55295 .40248 .54876 .39357 .54082 Mtetra
.522 .721 .964 r
.39357 .54082 .40248 .54876 .4173 .54632 .40838 .53976 Mtetra
.342 .678 .978 r
.40838 .53976 .4173 .54632 .43213 .54697 .42324 .54111 Mtetra
.42 .738 .992 r
.42324 .54111 .43213 .54697 .44709 .54764 .43827 .54086 Mtetra
.691 .809 .938 r
.43827 .54086 .44709 .54764 .46224 .54541 .45356 .5347 Mtetra
.775 .741 .822 r
.45356 .5347 .46224 .54541 .47758 .53675 .46902 .52256 Mtetra
.772 .693 .776 r
.46902 .52256 .47758 .53675 .49301 .52482 .48452 .50814 Mtetra
.729 .652 .773 r
.48452 .50814 .49301 .52482 .50846 .51221 .5 .4967 Mtetra
.677 .643 .809 r
.5 .4967 .50846 .51221 .52392 .5019 .51549 .4899 Mtetra
.651 .685 .87 r
.51549 .4899 .52392 .5019 .53943 .49507 .53106 .48519 Mtetra
.635 .723 .911 r
.53106 .48519 .53943 .49507 .55503 .48955 .54672 .48112 Mtetra
.656 .766 .93 r
.54672 .48112 .55503 .48955 .57072 .48465 .56247 .47617 Mtetra
.678 .773 .922 r
.56247 .47617 .57072 .48465 .5865 .48037 .57829 .47033 Mtetra
.662 .732 .902 r
.57829 .47033 .5865 .48037 .60242 .4774 .59422 .46513 Mtetra
.611 .669 .881 r
.59422 .46513 .60242 .4774 .61855 .47797 .61028 .46204 Mtetra
.507 .559 .844 r
.61028 .46204 .61855 .47797 .6349 .48089 .62661 .46365 Mtetra
.437 .504 .83 r
.62661 .46365 .6349 .48089 .6514 .48316 .64321 .46832 Mtetra
.477 .562 .863 r
.64321 .46832 .6514 .48316 .66793 .48214 .6599 .47073 Mtetra
.621 .695 .897 r
.6599 .47073 .66793 .48214 .68428 .47458 .6765 .46707 Mtetra
.758 .829 .907 r
.6765 .46707 .68428 .47458 .70054 .46403 .69289 .45735 Mtetra
.791 .857 .899 r
.69289 .45735 .70054 .46403 .71684 .45347 .70925 .44598 Mtetra
.742 .829 .918 r
.70925 .44598 .71684 .45347 .73339 .44606 .72579 .43705 Mtetra
.681 .775 .922 r
.72579 .43705 .73339 .44606 .75014 .44043 .74256 .43073 Mtetra
.651 .749 .922 r
.74256 .43073 .75014 .44043 .76702 .43536 .75952 .42565 Mtetra
.66 .754 .92 r
.75952 .42565 .76702 .43536 .78398 .42989 .77655 .42014 Mtetra
.659 .754 .92 r
.77655 .42014 .78398 .42989 .80105 .4245 .79369 .41464 Mtetra
.655 .751 .921 r
.79369 .41464 .80105 .4245 .81823 .41925 .81094 .40928 Mtetra
.652 .749 .921 r
.81094 .40928 .81823 .41925 .83552 .414 .8283 .40402 Mtetra
.657 .752 .92 r
.8283 .40402 .83552 .414 .85289 .40852 .84575 .3985 Mtetra
.658 .753 .92 r
.84575 .3985 .85289 .40852 .87037 .40303 .8633 .39293 Mtetra
.656 .752 .92 r
.8633 .39293 .87037 .40303 .88796 .3976 .88097 .38742 Mtetra
.655 .751 .92 r
.25341 .57239 .26283 .58062 .27705 .57617 .26767 .56791 Mtetra
.653 .751 .921 r
.26767 .56791 .27705 .57617 .29133 .57178 .28201 .56348 Mtetra
.655 .752 .921 r
.28201 .56348 .29133 .57178 .3057 .56735 .29642 .55897 Mtetra
.66 .752 .918 r
.29642 .55897 .3057 .56735 .32016 .56268 .31093 .55425 Mtetra
.655 .751 .92 r
.31093 .55425 .32016 .56268 .33469 .55811 .32551 .54968 Mtetra
.651 .751 .922 r
.32551 .54968 .33469 .55811 .34929 .55368 .34015 .54523 Mtetra
.655 .752 .922 r
.34015 .54523 .34929 .55368 .36397 .54926 .35489 .54063 Mtetra
.657 .75 .918 r
.35489 .54063 .36397 .54926 .37875 .54444 .36971 .53594 Mtetra
.606 .739 .938 r
.36971 .53594 .37875 .54444 .39357 .54082 .38455 .53286 Mtetra
.459 .697 .969 r
.38455 .53286 .39357 .54082 .40838 .53976 .39936 .533 Mtetra
.343 .676 .977 r
.39936 .533 .40838 .53976 .42324 .54111 .41426 .53438 Mtetra
.523 .76 .983 r
.41426 .53438 .42324 .54111 .43827 .54086 .42939 .53269 Mtetra
.763 .789 .874 r
.42939 .53269 .43827 .54086 .45356 .5347 .44482 .52277 Mtetra
.791 .727 .793 r
.44482 .52277 .45356 .5347 .46902 .52256 .46039 .50806 Mtetra
.77 .69 .775 r
.46039 .50806 .46902 .52256 .48452 .50814 .47595 .49369 Mtetra
.698 .666 .815 r
.47595 .49369 .48452 .50814 .5 .4967 .49144 .48576 Mtetra
.631 .699 .894 r
.49144 .48576 .5 .4967 .51549 .4899 .50697 .48188 Mtetra
.57 .746 .96 r
.50697 .48188 .51549 .4899 .53106 .48519 .5226 .47948 Mtetra
.584 .817 .988 r
.5226 .47948 .53106 .48519 .54672 .48112 .53833 .47587 Mtetra
.632 .847 .982 r
.53833 .47587 .54672 .48112 .56247 .47617 .55416 .47087 Mtetra
.68 .86 .968 r
.55416 .47087 .56247 .47617 .57829 .47033 .57006 .46447 Mtetra
.718 .854 .947 r
.57006 .46447 .57829 .47033 .59422 .46513 .58602 .45685 Mtetra
.683 .784 .927 r
.58602 .45685 .59422 .46513 .61028 .46204 .60208 .45071 Mtetra
.579 .677 .907 r
.60208 .45071 .61028 .46204 .62661 .46365 .61833 .44865 Mtetra
.411 .523 .861 r
.61833 .44865 .62661 .46365 .64321 .46832 .63494 .45316 Mtetra
.401 .516 .86 r
.63494 .45316 .64321 .46832 .6599 .47073 .65175 .45805 Mtetra
.524 .628 .896 r
.65175 .45805 .6599 .47073 .6765 .46707 .66856 .45811 Mtetra
.726 .789 .903 r
.66856 .45811 .6765 .46707 .69289 .45735 .6851 .44978 Mtetra
.788 .836 .889 r
.6851 .44978 .69289 .45735 .70925 .44598 .70155 .43827 Mtetra
.766 .831 .902 r
.70155 .43827 .70925 .44598 .72579 .43705 .7181 .428 Mtetra
.695 .782 .918 r
.7181 .428 .72579 .43705 .74256 .43073 .73491 .42102 Mtetra
.655 .753 .922 r
.73491 .42102 .74256 .43073 .75952 .42565 .75193 .4157 Mtetra
.657 .75 .918 r
.75193 .4157 .75952 .42565 .77655 .42014 .76904 .41027 Mtetra
.66 .754 .92 r
.76904 .41027 .77655 .42014 .79369 .41464 .78625 .40468 Mtetra
.656 .752 .92 r
.78625 .40468 .79369 .41464 .81094 .40928 .80357 .39921 Mtetra
.652 .749 .921 r
.80357 .39921 .81094 .40928 .8283 .40402 .82101 .39389 Mtetra
.656 .751 .92 r
.82101 .39389 .8283 .40402 .84575 .3985 .83853 .38836 Mtetra
.658 .753 .92 r
.83853 .38836 .84575 .3985 .8633 .39293 .85616 .38272 Mtetra
.656 .752 .92 r
.85616 .38272 .8633 .39293 .88097 .38742 .87391 .37712 Mtetra
.655 .751 .92 r
.2439 .56407 .25341 .57239 .26767 .56791 .2582 .55957 Mtetra
.653 .751 .921 r
.2582 .55957 .26767 .56791 .28201 .56348 .27258 .5551 Mtetra
.656 .752 .92 r
.27258 .5551 .28201 .56348 .29642 .55897 .28705 .55051 Mtetra
.66 .752 .918 r
.28705 .55051 .29642 .55897 .31093 .55425 .3016 .54574 Mtetra
.655 .751 .921 r
.3016 .54574 .31093 .55425 .32551 .54968 .31623 .54115 Mtetra
.651 .75 .923 r
.31623 .54115 .32551 .54968 .34015 .54523 .33092 .53668 Mtetra
.657 .752 .92 r
.33092 .53668 .34015 .54523 .35489 .54063 .34572 .53195 Mtetra
.652 .749 .921 r
.34572 .53195 .35489 .54063 .36971 .53594 .36058 .52739 Mtetra
.591 .734 .943 r
.36058 .52739 .36971 .53594 .38455 .53286 .37544 .52471 Mtetra
.419 .675 .968 r
.37544 .52471 .38455 .53286 .39936 .533 .39027 .52561 Mtetra
.379 .678 .976 r
.39027 .52561 .39936 .533 .41426 .53438 .40521 .52675 Mtetra
.609 .768 .956 r
.40521 .52675 .41426 .53438 .42939 .53269 .42045 .52326 Mtetra
.784 .767 .838 r
.42045 .52326 .42939 .53269 .44482 .52277 .436 .51114 Mtetra
.805 .735 .787 r
.436 .51114 .44482 .52277 .46039 .50806 .45167 .49507 Mtetra
.762 .708 .801 r
.45167 .49507 .46039 .50806 .47595 .49369 .46726 .48265 Mtetra
.675 .714 .878 r
.46726 .48265 .47595 .49369 .49144 .48576 .48278 .47684 Mtetra
.547 .715 .95 r
.48278 .47684 .49144 .48576 .50697 .48188 .49834 .47527 Mtetra
.577 .79 .98 r
.49834 .47527 .50697 .48188 .5226 .47948 .51404 .47215 Mtetra
.648 .795 .953 r
.51404 .47215 .5226 .47948 .53833 .47587 .52983 .46721 Mtetra
.655 .765 .93 r
.52983 .46721 .53833 .47587 .55416 .47087 .54572 .46216 Mtetra
.658 .765 .929 r
.54572 .46216 .55416 .47087 .57006 .46447 .5617 .45699 Mtetra
.703 .81 .932 r
.5617 .45699 .57006 .46447 .58602 .45685 .57775 .44999 Mtetra
.739 .835 .924 r
.57775 .44999 .58602 .45685 .60208 .45071 .59383 .44142 Mtetra
.633 .746 .93 r
.59383 .44142 .60208 .45071 .61833 .44865 .61009 .43711 Mtetra
.426 .6 .918 r
.61009 .43711 .61833 .44865 .63494 .45316 .62666 .43952 Mtetra
.322 .499 .877 r
.62666 .43952 .63494 .45316 .65175 .45805 .64355 .44568 Mtetra
.448 .597 .906 r
.64355 .44568 .65175 .45805 .66856 .45811 .66048 .44787 Mtetra
.685 .75 .901 r
.66048 .44787 .66856 .45811 .6851 .44978 .67718 .44127 Mtetra
.78 .815 .881 r
.67718 .44127 .6851 .44978 .70155 .43827 .69373 .4299 Mtetra
.777 .82 .886 r
.69373 .4299 .70155 .43827 .7181 .428 .71032 .41875 Mtetra
.705 .783 .912 r
.71032 .41875 .7181 .428 .73491 .42102 .72718 .41125 Mtetra
.66 .756 .921 r
.72718 .41125 .73491 .42102 .75193 .4157 .74426 .40568 Mtetra
.655 .75 .92 r
.74426 .40568 .75193 .4157 .76904 .41027 .76145 .40028 Mtetra
.66 .754 .919 r
.76145 .40028 .76904 .41027 .78625 .40468 .77872 .39461 Mtetra
.657 .752 .92 r
.77872 .39461 .78625 .40468 .80357 .39921 .79611 .38905 Mtetra
.652 .749 .921 r
.79611 .38905 .80357 .39921 .82101 .39389 .81363 .38367 Mtetra
.656 .751 .92 r
.81363 .38367 .82101 .39389 .83853 .38836 .83124 .3781 Mtetra
.658 .753 .92 r
.83124 .3781 .83853 .38836 .85616 .38272 .84894 .37239 Mtetra
.656 .752 .92 r
.84894 .37239 .85616 .38272 .87391 .37712 .86676 .36671 Mtetra
.655 .751 .921 r
.23429 .55568 .2439 .56407 .2582 .55957 .24864 .55114 Mtetra
.653 .751 .921 r
.24864 .55114 .2582 .55957 .27258 .5551 .26306 .54662 Mtetra
.656 .752 .92 r
.26306 .54662 .27258 .5551 .28705 .55051 .27758 .54197 Mtetra
.66 .752 .918 r
.27758 .54197 .28705 .55051 .3016 .54574 .29218 .53717 Mtetra
.654 .751 .921 r
.29218 .53717 .3016 .54574 .31623 .54115 .30685 .53254 Mtetra
.65 .75 .923 r
.30685 .53254 .31623 .54115 .33092 .53668 .3216 .52802 Mtetra
.658 .752 .92 r
.3216 .52802 .33092 .53668 .34572 .53195 .33644 .5232 Mtetra
.648 .749 .923 r
.33644 .5232 .34572 .53195 .36058 .52739 .35135 .51871 Mtetra
.582 .731 .945 r
.35135 .51871 .36058 .52739 .37544 .52471 .36625 .51623 Mtetra
.405 .662 .964 r
.36625 .51623 .37544 .52471 .39027 .52561 .3811 .51746 Mtetra
.413 .675 .969 r
.3811 .51746 .39027 .52561 .40521 .52675 .39609 .51838 Mtetra
.649 .763 .933 r
.39609 .51838 .40521 .52675 .42045 .52326 .41141 .51369 Mtetra
.794 .768 .829 r
.41141 .51369 .42045 .52326 .436 .51114 .42707 .50059 Mtetra
.818 .754 .792 r
.42707 .50059 .436 .51114 .45167 .49507 .44283 .48401 Mtetra
.761 .738 .832 r
.44283 .48401 .45167 .49507 .46726 .48265 .45846 .47284 Mtetra
.64 .73 .914 r
.45846 .47284 .46726 .48265 .48278 .47684 .47401 .46849 Mtetra
.517 .72 .965 r
.47401 .46849 .48278 .47684 .49834 .47527 .48962 .46739 Mtetra
.635 .777 .949 r
.48962 .46739 .49834 .47527 .51404 .47215 .50538 .46294 Mtetra
.677 .759 .913 r
.50538 .46294 .51404 .47215 .52983 .46721 .52124 .45702 Mtetra
.657 .732 .905 r
.52124 .45702 .52983 .46721 .54572 .46216 .53719 .45191 Mtetra
.635 .724 .912 r
.53719 .45191 .54572 .46216 .5617 .45699 .55323 .44762 Mtetra
.671 .758 .915 r
.55323 .44762 .5617 .45699 .57775 .44999 .56936 .44185 Mtetra
.746 .807 .901 r
.56936 .44185 .57775 .44999 .59383 .44142 .58552 .4327 Mtetra
.673 .776 .928 r
.58552 .4327 .59383 .44142 .61009 .43711 .6018 .42681 Mtetra
.456 .647 .94 r
.6018 .42681 .61009 .43711 .62666 .43952 .61838 .42783 Mtetra
.242 .494 .896 r
.61838 .42783 .62666 .43952 .64355 .44568 .63531 .4344 Mtetra
.39 .591 .924 r
.63531 .4344 .64355 .44568 .66048 .44787 .65232 .43747 Mtetra
.659 .74 .91 r
.65232 .43747 .66048 .44787 .67718 .44127 .66914 .43199 Mtetra
.773 .799 .874 r
.66914 .43199 .67718 .44127 .69373 .4299 .68578 .42074 Mtetra
.779 .805 .873 r
.68578 .42074 .69373 .4299 .71032 .41875 .70244 .40914 Mtetra
.71 .778 .906 r
.70244 .40914 .71032 .41875 .72718 .41125 .71936 .40132 Mtetra
.662 .756 .92 r
.71936 .40132 .72718 .41125 .74426 .40568 .7365 .39557 Mtetra
.654 .75 .921 r
.7365 .39557 .74426 .40568 .76145 .40028 .75376 .39015 Mtetra
.661 .754 .919 r
.75376 .39015 .76145 .40028 .77872 .39461 .77111 .38441 Mtetra
.657 .752 .92 r
.77111 .38441 .77872 .39461 .79611 .38905 .78858 .37878 Mtetra
.652 .75 .921 r
.78858 .37878 .79611 .38905 .81363 .38367 .80617 .37333 Mtetra
.655 .751 .92 r
.80617 .37333 .81363 .38367 .83124 .3781 .82385 .36771 Mtetra
.658 .752 .92 r
.82385 .36771 .83124 .3781 .84894 .37239 .84164 .36194 Mtetra
.657 .752 .92 r
.84164 .36194 .84894 .37239 .86676 .36671 .85953 .35619 Mtetra
.655 .751 .921 r
.22458 .54721 .23429 .55568 .24864 .55114 .23898 .54262 Mtetra
.653 .751 .921 r
.23898 .54262 .24864 .55114 .26306 .54662 .25345 .53806 Mtetra
.656 .752 .92 r
.25345 .53806 .26306 .54662 .27758 .54197 .26801 .53335 Mtetra
.66 .752 .919 r
.26801 .53335 .27758 .54197 .29218 .53717 .28266 .5285 Mtetra
.654 .751 .921 r
.28266 .5285 .29218 .53717 .30685 .53254 .29738 .52383 Mtetra
.65 .75 .922 r
.29738 .52383 .30685 .53254 .3216 .52802 .31218 .51926 Mtetra
.658 .752 .919 r
.31218 .51926 .3216 .52802 .33644 .5232 .32707 .51439 Mtetra
.648 .749 .923 r
.32707 .51439 .33644 .5232 .35135 .51871 .34203 .50985 Mtetra
.583 .729 .943 r
.34203 .50985 .35135 .51871 .36625 .51623 .35698 .50733 Mtetra
.414 .657 .959 r
.35698 .50733 .36625 .51623 .3811 .51746 .37186 .50852 Mtetra
.431 .665 .96 r
.37186 .50852 .3811 .51746 .39609 .51838 .38689 .5094 Mtetra
.65 .752 .924 r
.38689 .5094 .39609 .51838 .41141 .51369 .40226 .50466 Mtetra
.798 .78 .836 r
.40226 .50466 .41141 .51369 .42707 .50059 .418 .49149 Mtetra
.831 .78 .804 r
.418 .49149 .42707 .50059 .44283 .48401 .43385 .47483 Mtetra
.775 .777 .855 r
.43385 .47483 .44283 .48401 .45846 .47284 .44955 .46359 Mtetra
.639 .745 .925 r
.44955 .46359 .45846 .47284 .47401 .46849 .46516 .45919 Mtetra
.529 .703 .95 r
.46516 .45919 .47401 .46849 .48962 .46739 .48082 .45804 Mtetra
.64 .745 .925 r
.48082 .45804 .48962 .46739 .50538 .46294 .49664 .45354 Mtetra
.677 .757 .911 r
.49664 .45354 .50538 .46294 .52124 .45702 .51256 .44756 Mtetra
.656 .751 .919 r
.51256 .44756 .52124 .45702 .53719 .45191 .52856 .4424 Mtetra
.634 .743 .927 r
.52856 .4424 .53719 .45191 .55323 .44762 .54467 .43805 Mtetra
.671 .756 .914 r
.54467 .43805 .55323 .44762 .56936 .44185 .56086 .43223 Mtetra
.74 .775 .881 r
.56086 .43223 .56936 .44185 .58552 .4327 .57709 .42301 Mtetra
.673 .756 .913 r
.57709 .42301 .58552 .4327 .6018 .42681 .59344 .41706 Mtetra
.443 .657 .951 r
.59344 .41706 .6018 .42681 .61838 .42783 .61007 .41804 Mtetra
.161 .492 .904 r
.61007 .41804 .61838 .42783 .63531 .4344 .62703 .42458 Mtetra
.35 .607 .945 r
.62703 .42458 .63531 .4344 .65232 .43747 .64409 .42762 Mtetra
.659 .754 .921 r
.64409 .42762 .65232 .43747 .66914 .43199 .66098 .42207 Mtetra
.77 .788 .868 r
.66098 .42207 .66914 .43199 .68578 .42074 .6777 .41075 Mtetra
.775 .789 .865 r
.6777 .41075 .68578 .42074 .70244 .40914 .69445 .39907 Mtetra
.709 .77 .9 r
.69445 .39907 .70244 .40914 .71936 .40132 .71145 .39119 Mtetra
.663 .754 .918 r
.71145 .39119 .71936 .40132 .7365 .39557 .72866 .38538 Mtetra
.654 .751 .921 r
.72866 .38538 .7365 .39557 .75376 .39015 .746 .3799 Mtetra
.661 .753 .919 r
.746 .3799 .75376 .39015 .77111 .38441 .76342 .3741 Mtetra
.657 .752 .92 r
.76342 .3741 .77111 .38441 .78858 .37878 .78096 .3684 Mtetra
.652 .75 .921 r
.78096 .3684 .78858 .37878 .80617 .37333 .79862 .36289 Mtetra
.655 .751 .92 r
.79862 .36289 .80617 .37333 .82385 .36771 .81639 .35721 Mtetra
.658 .752 .92 r
.81639 .35721 .82385 .36771 .84164 .36194 .83425 .35137 Mtetra
.657 .752 .92 r
.83425 .35137 .84164 .36194 .85953 .35619 .85223 .34556 Mtetra
.655 .751 .921 r
.21477 .53865 .22458 .54721 .23898 .54262 .22921 .534 Mtetra
.653 .751 .921 r
.22921 .534 .23898 .54262 .25345 .53806 .24373 .52939 Mtetra
.656 .751 .92 r
.24373 .52939 .25345 .53806 .26801 .53335 .25834 .52466 Mtetra
.66 .753 .919 r
.25834 .52466 .26801 .53335 .28266 .5285 .27305 .51975 Mtetra
.655 .751 .921 r
.27305 .51975 .28266 .5285 .29738 .52383 .28782 .51502 Mtetra
.651 .75 .922 r
.28782 .51502 .29738 .52383 .31218 .51926 .30266 .51039 Mtetra
.657 .751 .92 r
.30266 .51039 .31218 .51926 .32707 .51439 .3176 .50551 Mtetra
.651 .751 .922 r
.3176 .50551 .32707 .51439 .34203 .50985 .33262 .50081 Mtetra
.592 .729 .939 r
.33262 .50081 .34203 .50985 .35698 .50733 .34762 .498 Mtetra
.441 .661 .955 r
.34762 .498 .35698 .50733 .37186 .50852 .36255 .49878 Mtetra
.437 .65 .949 r
.36255 .49878 .37186 .50852 .38689 .5094 .37761 .49982 Mtetra
.618 .73 .926 r
.37761 .49982 .38689 .5094 .40226 .50466 .39299 .49618 Mtetra
.793 .792 .852 r
.39299 .49618 .40226 .50466 .418 .49149 .40878 .48385 Mtetra
.84 .809 .82 r
.40878 .48385 .418 .49149 .43385 .47483 .42471 .46754 Mtetra
.806 .821 .863 r
.42471 .46754 .43385 .47483 .44955 .46359 .44053 .4549 Mtetra
.679 .772 .921 r
.44053 .4549 .44955 .46359 .46516 .45919 .45623 .44893 Mtetra
.557 .694 .931 r
.45623 .44893 .46516 .45919 .48082 .45804 .47194 .44723 Mtetra
.608 .703 .912 r
.47194 .44723 .48082 .45804 .49664 .45354 .4878 .44395 Mtetra
.654 .748 .919 r
.4878 .44395 .49664 .45354 .51256 .44756 .50377 .43885 Mtetra
.655 .77 .934 r
.50377 .43885 .51256 .44756 .52856 .4424 .51985 .43364 Mtetra
.658 .771 .933 r
.51985 .43364 .52856 .4424 .54467 .43805 .53601 .4283 Mtetra
.7 .763 .9 r
.53601 .4283 .54467 .43805 .56086 .43223 .55226 .42112 Mtetra
.724 .744 .867 r
.55226 .42112 .56086 .43223 .57709 .42301 .56856 .41235 Mtetra
.635 .723 .911 r
.56856 .41235 .57709 .42301 .59344 .41706 .585 .40788 Mtetra
.363 .632 .956 r
.585 .40788 .59344 .41706 .61007 .41804 .60171 .41017 Mtetra
.085 .496 .899 r
.60171 .41017 .61007 .41804 .62703 .42458 .61871 .41624 Mtetra
.348 .648 .967 r
.61871 .41624 .62703 .42458 .64409 .42762 .6358 .41831 Mtetra
.687 .779 .921 r
.6358 .41831 .64409 .42762 .66098 .42207 .65271 .41152 Mtetra
.769 .777 .859 r
.65271 .41152 .66098 .42207 .6777 .41075 .66951 .39993 Mtetra
.764 .772 .859 r
.66951 .39993 .6777 .41075 .69445 .39907 .68635 .38855 Mtetra
.703 .761 .897 r
.68635 .38855 .69445 .39907 .71145 .39119 .70344 .38086 Mtetra
.66 .751 .917 r
.70344 .38086 .71145 .39119 .72866 .38538 .72073 .3751 Mtetra
.655 .751 .921 r
.72073 .3751 .72866 .38538 .746 .3799 .73814 .36952 Mtetra
.66 .753 .919 r
.73814 .36952 .746 .3799 .76342 .3741 .75564 .36366 Mtetra
.657 .752 .92 r
.75564 .36366 .76342 .3741 .78096 .3684 .77325 .35791 Mtetra
.652 .75 .921 r
.77325 .35791 .78096 .3684 .79862 .36289 .79099 .35234 Mtetra
.656 .752 .921 r
.79099 .35234 .79862 .36289 .81639 .35721 .80883 .34657 Mtetra
.658 .752 .92 r
.80883 .34657 .81639 .35721 .83425 .35137 .82678 .34067 Mtetra
.656 .752 .92 r
.82678 .34067 .83425 .35137 .85223 .34556 .84483 .3348 Mtetra
.655 .751 .921 r
.20486 .53001 .21477 .53865 .22921 .534 .21935 .5253 Mtetra
.653 .751 .921 r
.21935 .5253 .22921 .534 .24373 .52939 .23392 .52064 Mtetra
.655 .751 .92 r
.23392 .52064 .24373 .52939 .25834 .52466 .24857 .51588 Mtetra
.66 .753 .919 r
.24857 .51588 .25834 .52466 .27305 .51975 .26333 .51092 Mtetra
.655 .752 .921 r
.26333 .51092 .27305 .51975 .28782 .51502 .27815 .50611 Mtetra
.651 .75 .922 r
.27815 .50611 .28782 .51502 .30266 .51039 .29304 .50142 Mtetra
.655 .75 .92 r
.29304 .50142 .30266 .51039 .3176 .50551 .30803 .49657 Mtetra
.657 .753 .921 r
.30803 .49657 .3176 .50551 .33262 .50081 .32311 .49163 Mtetra
.608 .734 .934 r
.32311 .49163 .33262 .50081 .34762 .498 .33819 .48832 Mtetra
.484 .675 .949 r
.33819 .48832 .34762 .498 .36255 .49878 .35319 .48827 Mtetra
.441 .635 .938 r
.35319 .48827 .36255 .49878 .37761 .49982 .36827 .48947 Mtetra
.564 .695 .928 r
.36827 .48947 .37761 .49982 .39299 .49618 .38362 .48756 Mtetra
.763 .789 .874 r
.38362 .48756 .39299 .49618 .40878 .48385 .39941 .47732 Mtetra
.837 .834 .844 r
.39941 .47732 .40878 .48385 .42471 .46754 .4154 .46223 Mtetra
.843 .863 .858 r
.4154 .46223 .42471 .46754 .44053 .4549 .43138 .44747 Mtetra
.731 .815 .917 r
.43138 .44747 .44053 .4549 .45623 .44893 .4472 .43924 Mtetra
.628 .737 .925 r
.4472 .43924 .45623 .44893 .47194 .44723 .463 .4351 Mtetra
.592 .673 .896 r
.463 .4351 .47194 .44723 .4878 .44395 .47889 .43246 Mtetra
.622 .698 .899 r
.47889 .43246 .4878 .44395 .50377 .43885 .4949 .42859 Mtetra
.656 .737 .909 r
.4949 .42859 .50377 .43885 .51985 .43364 .51103 .42332 Mtetra
.688 .748 .897 r
.51103 .42332 .51985 .43364 .53601 .4283 .52726 .41663 Mtetra
.707 .729 .867 r
.52726 .41663 .53601 .4283 .55226 .42112 .54356 .4087 Mtetra
.676 .706 .87 r
.54356 .4087 .55226 .42112 .56856 .41235 .55994 .40225 Mtetra
.568 .711 .939 r
.55994 .40225 .56856 .41235 .585 .40788 .57648 .39995 Mtetra
.19 .566 .936 r
.57648 .39995 .585 .40788 .60171 .41017 .5933 .40429 Mtetra
.05 .527 .889 r
.5933 .40429 .60171 .41017 .61871 .41624 .61032 .40902 Mtetra
.424 .723 .988 r
.61032 .40902 .61871 .41624 .6358 .41831 .6274 .40885 Mtetra
.726 .789 .903 r
.6274 .40885 .6358 .41831 .65271 .41152 .64433 .40018 Mtetra
.768 .764 .85 r
.64433 .40018 .65271 .41152 .66951 .39993 .66119 .3883 Mtetra
.748 .755 .858 r
.66119 .3883 .66951 .39993 .68635 .38855 .67815 .37766 Mtetra
.693 .752 .897 r
.67815 .37766 .68635 .38855 .70344 .38086 .69534 .37036 Mtetra
.655 .748 .918 r
.69534 .37036 .70344 .38086 .72073 .3751 .71271 .36473 Mtetra
.657 .753 .921 r
.71271 .36473 .72073 .3751 .73814 .36952 .73019 .359 Mtetra
.66 .752 .918 r
.73019 .359 .73814 .36952 .75564 .36366 .74777 .35309 Mtetra
.656 .751 .92 r
.74777 .35309 .75564 .36366 .77325 .35791 .76546 .34731 Mtetra
.652 .75 .922 r
.76546 .34731 .77325 .35791 .79099 .35234 .78328 .34167 Mtetra
.656 .752 .92 r
.78328 .34167 .79099 .35234 .80883 .34657 .8012 .33581 Mtetra
.658 .752 .919 r
.8012 .33581 .80883 .34657 .82678 .34067 .81922 .32985 Mtetra
.656 .751 .92 r
.81922 .32985 .82678 .34067 .84483 .3348 .83736 .32392 Mtetra
.656 .752 .92 r
.19484 .52128 .20486 .53001 .21935 .5253 .20939 .5165 Mtetra
.654 .751 .921 r
.20939 .5165 .21935 .5253 .23392 .52064 .224 .51178 Mtetra
.224 .51178 .23392 .52064 .24857 .51588 .2387 .50702 Mtetra
.66 .753 .919 r
.2387 .50702 .24857 .51588 .26333 .51092 .2535 .50201 Mtetra
.657 .752 .92 r
.2535 .50201 .26333 .51092 .27815 .50611 .26838 .4971 Mtetra
.652 .75 .922 r
.26838 .4971 .27815 .50611 .29304 .50142 .28333 .49233 Mtetra
.651 .749 .921 r
.28333 .49233 .29304 .50142 .30803 .49657 .29836 .48757 Mtetra
.661 .755 .919 r
.29836 .48757 .30803 .49657 .32311 .49163 .3135 .4824 Mtetra
.626 .741 .929 r
.3135 .4824 .32311 .49163 .33819 .48832 .32866 .47844 Mtetra
.539 .695 .941 r
.32866 .47844 .33819 .48832 .35319 .48827 .34377 .47709 Mtetra
.453 .628 .928 r
.34377 .47709 .35319 .48827 .36827 .48947 .35887 .47819 Mtetra
.52 .658 .922 r
.35887 .47819 .36827 .48947 .38362 .48756 .3742 .47767 Mtetra
.689 .75 .898 r
.3742 .47767 .38362 .48756 .39941 .47732 .3899 .47112 Mtetra
.811 .847 .877 r
.3899 .47112 .39941 .47732 .4154 .46223 .4059 .45847 Mtetra
.852 .899 .868 r
.4059 .45847 .4154 .46223 .43138 .44747 .422 .44352 Mtetra
.808 .905 .908 r
.422 .44352 .43138 .44747 .4472 .43924 .43801 .43159 Mtetra
.706 .809 .929 r
.43801 .43159 .4472 .43924 .463 .4351 .45395 .42438 Mtetra
.652 .726 .903 r
.45395 .42438 .463 .4351 .47889 .43246 .46992 .4193 Mtetra
.634 .674 .871 r
.46992 .4193 .47889 .43246 .4949 .42859 .48598 .41486 Mtetra
.652 .673 .858 r
.48598 .41486 .4949 .42859 .51103 .42332 .50215 .40952 Mtetra
.668 .68 .852 r
.50215 .40952 .51103 .42332 .52726 .41663 .51842 .40328 Mtetra
.657 .683 .864 r
.51842 .40328 .52726 .41663 .54356 .4087 .53478 .39768 Mtetra
.606 .708 .917 r
.53478 .39768 .54356 .4087 .55994 .40225 .55126 .39422 Mtetra
.368 .67 .974 r
.55126 .39422 .55994 .40225 .57648 .39995 .56791 .39555 Mtetra
0 .5 .83 r
.56791 .39555 .57648 .39995 .5933 .40429 .5848 .39998 Mtetra
.133 .626 .912 r
.5848 .39998 .5933 .40429 .61032 .40902 .60184 .40212 Mtetra
.588 .809 .984 r
.60184 .40212 .61032 .40902 .6274 .40885 .61888 .39808 Mtetra
.746 .77 .872 r
.61888 .39808 .6274 .40885 .64433 .40018 .63583 .38787 Mtetra
.761 .748 .84 r
.63583 .38787 .64433 .40018 .66119 .3883 .65277 .37597 Mtetra
.725 .737 .861 r
.65277 .37597 .66119 .3883 .67815 .37766 .66986 .36655 Mtetra
.68 .746 .901 r
.66986 .36655 .67815 .37766 .69534 .37036 .68715 .35979 Mtetra
.651 .747 .92 r
.68715 .35979 .69534 .37036 .71271 .36473 .70461 .35428 Mtetra
.66 .755 .92 r
.70461 .35428 .71271 .36473 .73019 .359 .72215 .34834 Mtetra
.659 .752 .918 r
.72215 .34834 .73019 .359 .74777 .35309 .7398 .3424 Mtetra
.655 .751 .92 r
.7398 .3424 .74777 .35309 .76546 .34731 .75758 .3366 Mtetra
.652 .75 .922 r
.75758 .3366 .76546 .34731 .78328 .34167 .77548 .33089 Mtetra
.657 .753 .92 r
.77548 .33089 .78328 .34167 .8012 .33581 .79347 .32492 Mtetra
.658 .752 .919 r
.79347 .32492 .8012 .33581 .81922 .32985 .81157 .3189 Mtetra
.656 .751 .92 r
.81157 .3189 .81922 .32985 .83736 .32392 .82979 .31293 Mtetra
.657 .752 .92 r
.18473 .51247 .19484 .52128 .20939 .5165 .19932 .50761 Mtetra
.654 .751 .921 r
.19932 .50761 .20939 .5165 .224 .51178 .21398 .50283 Mtetra
.653 .75 .921 r
.21398 .50283 .224 .51178 .2387 .50702 .22873 .49804 Mtetra
.659 .752 .919 r
.22873 .49804 .2387 .50702 .2535 .50201 .24358 .49302 Mtetra
.658 .753 .92 r
.24358 .49302 .2535 .50201 .26838 .4971 .25851 .488 Mtetra
.653 .75 .921 r
.25851 .488 .26838 .4971 .28333 .49233 .27351 .48314 Mtetra
.65 .749 .921 r
.27351 .48314 .28333 .49233 .29836 .48757 .28859 .47834 Mtetra
.66 .752 .918 r
.28859 .47834 .29836 .48757 .3135 .4824 .30378 .47316 Mtetra
.644 .748 .925 r
.30378 .47316 .3135 .4824 .32866 .47844 .31903 .46853 Mtetra
.591 .717 .931 r
.31903 .46853 .32866 .47844 .34377 .47709 .33426 .46569 Mtetra
.486 .641 .925 r
.33426 .46569 .34377 .47709 .35887 .47819 .34943 .466 Mtetra
.494 .629 .912 r
.34943 .466 .35887 .47819 .3742 .47767 .36474 .46633 Mtetra
.588 .688 .911 r
.36474 .46633 .3742 .47767 .3899 .47112 .38032 .46369 Mtetra
.749 .819 .907 r
.38032 .46369 .3899 .47112 .4059 .45847 .39628 .45447 Mtetra
.818 .902 .9 r
.39628 .45447 .4059 .45847 .422 .44352 .4124 .44189 Mtetra
.826 .954 .9 r
.4124 .44189 .422 .44352 .43801 .43159 .42857 .42863 Mtetra
.783 .933 .93 r
.42857 .42863 .43801 .43159 .45395 .42438 .44469 .41771 Mtetra
.706 .837 .945 r
.44469 .41771 .45395 .42438 .46992 .4193 .46079 .41035 Mtetra
.673 .775 .927 r
.46079 .41035 .46992 .4193 .48598 .41486 .47693 .40432 Mtetra
.657 .736 .908 r
.47693 .40432 .48598 .41486 .50215 .40952 .49316 .39892 Mtetra
.64 .73 .914 r
.49316 .39892 .50215 .40952 .51842 .40328 .50949 .39416 Mtetra
.594 .748 .951 r
.50949 .39416 .51842 .40328 .53478 .39768 .52592 .39073 Mtetra
.392 .715 .987 r
.52592 .39073 .53478 .39768 .55126 .39422 .54249 .39091 Mtetra
.026 .569 .841 r
.54249 .39091 .55126 .39422 .56791 .39555 .55924 .39349 Mtetra
0 .561 .787 r
.55924 .39349 .56791 .39555 .5848 .39998 .57617 .39541 Mtetra
.392 .781 .989 r
.57617 .39541 .5848 .39998 .60184 .40212 .59321 .39396 Mtetra
.716 .82 .93 r
.59321 .39396 .60184 .40212 .61888 .39808 .61022 .38581 Mtetra
.752 .746 .847 r
.61022 .38581 .61888 .39808 .63583 .38787 .62721 .37461 Mtetra
.746 .73 .837 r
.62721 .37461 .63583 .38787 .65277 .37597 .64425 .36339 Mtetra
.699 .726 .871 r
.64425 .36339 .65277 .37597 .66986 .36655 .66147 .35539 Mtetra
.666 .742 .907 r
.66147 .35539 .66986 .36655 .68715 .35979 .67887 .3492 Mtetra
.652 .75 .922 r
.67887 .3492 .68715 .35979 .70461 .35428 .6964 .34358 Mtetra
.661 .752 .918 r
.6964 .34358 .70461 .35428 .72215 .34834 .71402 .33755 Mtetra
.658 .751 .919 r
.71402 .33755 .72215 .34834 .7398 .3424 .73175 .33159 Mtetra
.654 .75 .921 r
.73175 .33159 .7398 .3424 .75758 .3366 .74961 .32578 Mtetra
.653 .751 .922 r
.74961 .32578 .75758 .3366 .77548 .33089 .76758 .31996 Mtetra
.658 .752 .92 r
.76758 .31996 .77548 .33089 .79347 .32492 .78565 .3139 Mtetra
.657 .752 .919 r
.78565 .3139 .79347 .32492 .81157 .3189 .80383 .30782 Mtetra
.655 .751 .92 r
.80383 .30782 .81157 .3189 .82979 .31293 .82214 .30181 Mtetra
.658 .752 .92 r
.1745 .50357 .18473 .51247 .19932 .50761 .18914 .49864 Mtetra
.655 .751 .921 r
.18914 .49864 .19932 .50761 .21398 .50283 .20386 .49378 Mtetra
.653 .75 .921 r
.20386 .49378 .21398 .50283 .22873 .49804 .21865 .48894 Mtetra
.657 .751 .919 r
.21865 .48894 .22873 .49804 .24358 .49302 .23354 .48394 Mtetra
.66 .754 .92 r
.23354 .48394 .24358 .49302 .25851 .488 .24853 .47882 Mtetra
.654 .751 .921 r
.24853 .47882 .25851 .488 .27351 .48314 .26359 .47385 Mtetra
.651 .749 .921 r
.26359 .47385 .27351 .48314 .28859 .47834 .27872 .46899 Mtetra
.655 .75 .919 r
.27872 .46899 .28859 .47834 .30378 .47316 .29395 .46394 Mtetra
.658 .755 .921 r
.29395 .46394 .30378 .47316 .31903 .46853 .30928 .45876 Mtetra
.622 .733 .926 r
.30928 .45876 .31903 .46853 .33426 .46569 .32462 .45484 Mtetra
.553 .685 .926 r
.32462 .45484 .33426 .46569 .34943 .466 .33993 .45316 Mtetra
.498 .62 .903 r
.33993 .45316 .34943 .466 .36474 .46633 .35527 .45347 Mtetra
.534 .638 .899 r
.35527 .45347 .36474 .46633 .38032 .46369 .37079 .45269 Mtetra
.621 .711 .911 r
.37079 .45269 .38032 .46369 .39628 .45447 .38658 .44878 Mtetra
.751 .865 .932 r
.38658 .44878 .39628 .45447 .4124 .44189 .40268 .43956 Mtetra
.776 .945 .933 r
.40268 .43956 .4124 .44189 .42857 .42863 .41889 .42868 Mtetra
.742 .981 .912 r
.41889 .42868 .42857 .42863 .44469 .41771 .43514 .41758 Mtetra
.682 .969 .924 r
.43514 .41758 .44469 .41771 .46079 .41035 .45139 .4081 Mtetra
.653 .933 .969 r
.45139 .4081 .46079 .41035 .47693 .40432 .46767 .40066 Mtetra
.596 .888 .99 r
.46767 .40066 .47693 .40432 .49316 .39892 .48399 .39521 Mtetra
.488 .846 .993 r
.48399 .39521 .49316 .39892 .50949 .39416 .5004 .39176 Mtetra
.276 .757 .925 r
.5004 .39176 .50949 .39416 .52592 .39073 .51692 .39037 Mtetra
.003 .58 .725 r
.51692 .39037 .52592 .39073 .54249 .39091 .53359 .39064 Mtetra
.013 .588 .727 r
.53359 .39064 .54249 .39091 .55924 .39349 .55042 .39071 Mtetra
.306 .771 .943 r
.55042 .39071 .55924 .39349 .57617 .39541 .56739 .38913 Mtetra
.679 .857 .967 r
.56739 .38913 .57617 .39541 .59321 .39396 .58441 .38216 Mtetra
.739 .752 .862 r
.58441 .38216 .59321 .39396 .61022 .38581 .60144 .37198 Mtetra
.743 .721 .831 r
.60144 .37198 .61022 .38581 .62721 .37461 .6185 .36068 Mtetra
.714 .71 .845 r
.6185 .36068 .62721 .37461 .64425 .36339 .63568 .35137 Mtetra
.681 .732 .889 r
.63568 .35137 .64425 .36339 .66147 .35539 .65301 .34435 Mtetra
.654 .742 .915 r
.65301 .34435 .66147 .35539 .67887 .3492 .6705 .3386 Mtetra
.656 .754 .922 r
.6705 .3386 .67887 .3492 .6964 .34358 .6881 .33272 Mtetra
.66 .751 .918 r
.6881 .33272 .6964 .34358 .71402 .33755 .70579 .32665 Mtetra
.657 .751 .919 r
.70579 .32665 .71402 .33755 .73175 .33159 .72361 .32067 Mtetra
.652 .75 .921 r
.72361 .32067 .73175 .33159 .74961 .32578 .74154 .31484 Mtetra
.655 .752 .921 r
.74154 .31484 .74961 .32578 .76758 .31996 .75959 .30888 Mtetra
.658 .752 .919 r
.75959 .30888 .76758 .31996 .78565 .3139 .77774 .30274 Mtetra
.657 .751 .92 r
.77774 .30274 .78565 .3139 .80383 .30782 .79601 .29662 Mtetra
.654 .751 .921 r
.79601 .29662 .80383 .30782 .82214 .30181 .8144 .29056 Mtetra
.658 .753 .92 r
.16417 .49458 .1745 .50357 .18914 .49864 .17886 .48957 Mtetra
.655 .751 .921 r
.17886 .48957 .18914 .49864 .20386 .49378 .19363 .48464 Mtetra
.654 .75 .921 r
.19363 .48464 .20386 .49378 .21865 .48894 .20847 .47974 Mtetra
.655 .75 .92 r
.20847 .47974 .21865 .48894 .23354 .48394 .2234 .47477 Mtetra
.66 .754 .919 r
.2234 .47477 .23354 .48394 .24853 .47882 .23844 .46959 Mtetra
.657 .753 .921 r
.23844 .46959 .24853 .47882 .26359 .47385 .25356 .46449 Mtetra
.653 .75 .921 r
.25356 .46449 .26359 .47385 .27872 .46899 .26875 .45951 Mtetra
.651 .748 .921 r
.26875 .45951 .27872 .46899 .29395 .46394 .28402 .45456 Mtetra
.661 .754 .919 r
.28402 .45456 .29395 .46394 .30928 .45876 .29941 .44923 Mtetra
.647 .748 .923 r
.29941 .44923 .30928 .45876 .32462 .45484 .31486 .44435 Mtetra
.609 .716 .921 r
.31486 .44435 .32462 .45484 .33993 .45316 .33032 .44084 Mtetra
.544 .653 .907 r
.33032 .44084 .33993 .45316 .35527 .45347 .34575 .43962 Mtetra
.524 .617 .887 r
.34575 .43962 .35527 .45347 .37079 .45269 .36128 .43927 Mtetra
.558 .641 .889 r
.36128 .43927 .37079 .45269 .38658 .44878 .377 .43772 Mtetra
.618 .712 .913 r
.377 .43772 .38658 .44878 .40268 .43956 .39294 .43382 Mtetra
.702 .861 .958 r
.39294 .43382 .40268 .43956 .41889 .42868 .40912 .42641 Mtetra
.702 .942 .96 r
.40912 .42641 .41889 .42868 .43514 .41758 .42541 .4178 Mtetra
.606 .949 .917 r
.42541 .4178 .43514 .41758 .45139 .4081 .44175 .40956 Mtetra
.462 .889 .844 r
.44175 .40956 .45139 .4081 .46767 .40066 .45814 .40252 Mtetra
.317 .804 .776 r
.45814 .40252 .46767 .40066 .48399 .39521 .47459 .39702 Mtetra
.193 .72 .723 r
.47459 .39702 .48399 .39521 .5004 .39176 .49112 .39308 Mtetra
.128 .675 .715 r
.49112 .39308 .5004 .39176 .51692 .39037 .50776 .39035 Mtetra
.187 .72 .805 r
.50776 .39035 .51692 .39037 .53359 .39064 .52454 .38801 Mtetra
.431 .843 .967 r
.52454 .38801 .53359 .39064 .55042 .39071 .54144 .38447 Mtetra
.682 .86 .967 r
.54144 .38447 .55042 .39071 .56739 .38913 .55843 .37737 Mtetra
.728 .75 .869 r
.55843 .37737 .56739 .38913 .58441 .38216 .57548 .36788 Mtetra
.733 .711 .831 r
.57548 .36788 .58441 .38216 .60144 .37198 .59256 .35714 Mtetra
.718 .699 .831 r
.59256 .35714 .60144 .37198 .6185 .36068 .60972 .34726 Mtetra
.687 .71 .866 r
.60972 .34726 .6185 .36068 .63568 .35137 .62702 .3397 Mtetra
.663 .734 .903 r
.62702 .3397 .63568 .35137 .65301 .34435 .64447 .33353 Mtetra
.651 .749 .921 r
.64447 .33353 .65301 .34435 .6705 .3386 .66203 .32783 Mtetra
.66 .755 .92 r
.66203 .32783 .6705 .3386 .6881 .33272 .6797 .32171 Mtetra
.659 .75 .918 r
.6797 .32171 .6881 .33272 .70579 .32665 .69747 .31563 Mtetra
.655 .75 .92 r
.69747 .31563 .70579 .32665 .72361 .32067 .71537 .30967 Mtetra
.652 .751 .922 r
.71537 .30967 .72361 .32067 .74154 .31484 .73339 .30378 Mtetra
.657 .753 .921 r
.73339 .30378 .74154 .31484 .75959 .30888 .7515 .29766 Mtetra
.658 .752 .919 r
.7515 .29766 .75959 .30888 .77774 .30274 .76974 .29146 Mtetra
.656 .751 .92 r
.76974 .29146 .77774 .30274 .79601 .29662 .78809 .28529 Mtetra
.654 .751 .921 r
.78809 .28529 .79601 .29662 .8144 .29056 .80657 .27919 Mtetra
.658 .752 .92 r
.15373 .48549 .16417 .49458 .17886 .48957 .16847 .48044 Mtetra
.657 .752 .92 r
.16847 .48044 .17886 .48957 .19363 .48464 .18328 .47541 Mtetra
.654 .751 .921 r
.18328 .47541 .19363 .48464 .20847 .47974 .19818 .47043 Mtetra
.653 .75 .921 r
.19818 .47043 .20847 .47974 .2234 .47477 .21316 .46545 Mtetra
.658 .752 .919 r
.21316 .46545 .2234 .47477 .23844 .46959 .22824 .46028 Mtetra
.659 .754 .92 r
.22824 .46028 .23844 .46959 .25356 .46449 .24342 .45504 Mtetra
.654 .751 .921 r
.24342 .45504 .25356 .46449 .26875 .45951 .25866 .44994 Mtetra
.652 .748 .921 r
.25866 .44994 .26875 .45951 .28402 .45456 .27399 .44492 Mtetra
.653 .748 .92 r
.27399 .44492 .28402 .45456 .29941 .44923 .28942 .4398 Mtetra
.661 .757 .921 r
.28942 .4398 .29941 .44923 .31486 .44435 .30495 .43437 Mtetra
.641 .74 .921 r
.30495 .43437 .31486 .44435 .33032 .44084 .32053 .42966 Mtetra
.608 .705 .913 r
.32053 .42966 .33032 .44084 .34575 .43962 .33614 .42614 Mtetra
.558 .641 .889 r
.33614 .42614 .34575 .43962 .36128 .43927 .35175 .42454 Mtetra
.548 .616 .873 r
.35175 .42454 .36128 .43927 .377 .43772 .36747 .42341 Mtetra
.571 .635 .876 r
.36747 .42341 .377 .43772 .39294 .43382 .38336 .42139 Mtetra
.606 .684 .897 r
.38336 .42139 .39294 .43382 .40912 .42641 .39943 .41792 Mtetra
.634 .781 .951 r
.39943 .41792 .40912 .42641 .42541 .4178 .41567 .41306 Mtetra
.642 .877 .985 r
.41567 .41306 .42541 .4178 .44175 .40956 .43205 .40697 Mtetra
.595 .911 .979 r
.43205 .40697 .44175 .40956 .45814 .40252 .44853 .4008 Mtetra
.525 .899 .961 r
.44853 .4008 .45814 .40252 .47459 .39702 .46508 .39526 Mtetra
.485 .882 .957 r
.46508 .39526 .47459 .39702 .49112 .39308 .48173 .39034 Mtetra
.528 .885 .98 r
.48173 .39034 .49112 .39308 .50776 .39035 .49848 .38534 Mtetra
.64 .878 .985 r
.49848 .38534 .50776 .39035 .52454 .38801 .51535 .3791 Mtetra
.702 .801 .926 r
.51535 .3791 .52454 .38801 .54144 .38447 .53232 .37145 Mtetra
.716 .725 .857 r
.53232 .37145 .54144 .38447 .55843 .37737 .54936 .36232 Mtetra
.719 .696 .828 r
.54936 .36232 .55843 .37737 .57548 .36788 .56645 .35226 Mtetra
.709 .686 .825 r
.56645 .35226 .57548 .36788 .59256 .35714 .58362 .34266 Mtetra
.684 .693 .852 r
.58362 .34266 .59256 .35714 .60972 .34726 .60089 .33499 Mtetra
.668 .726 .893 r
.60089 .33499 .60972 .34726 .62702 .3397 .6183 .32853 Mtetra
.651 .743 .916 r
.6183 .32853 .62702 .3397 .64447 .33353 .63583 .32281 Mtetra
.658 .756 .922 r
.63583 .32281 .64447 .33353 .66203 .32783 .65346 .31675 Mtetra
.66 .751 .917 r
.65346 .31675 .66203 .32783 .6797 .32171 .6712 .31059 Mtetra
.657 .75 .919 r
.6712 .31059 .6797 .32171 .69747 .31563 .68906 .30451 Mtetra
.653 .75 .921 r
.68906 .30451 .69747 .31563 .71537 .30967 .70704 .29857 Mtetra
.654 .752 .922 r
.70704 .29857 .71537 .30967 .73339 .30378 .72513 .29254 Mtetra
.658 .752 .92 r
.72513 .29254 .73339 .30378 .7515 .29766 .74332 .2863 Mtetra
.657 .751 .919 r
.74332 .2863 .7515 .29766 .76974 .29146 .76164 .28005 Mtetra
.655 .751 .92 r
.76164 .28005 .76974 .29146 .78809 .28529 .78008 .27386 Mtetra
.654 .751 .921 r
.78008 .27386 .78809 .28529 .80657 .27919 .79864 .26767 Mtetra
.657 .751 .92 r
.14318 .47628 .15373 .48549 .16847 .48044 .15796 .47122 Mtetra
.658 .753 .92 r
.15796 .47122 .16847 .48044 .18328 .47541 .17283 .46608 Mtetra
.655 .751 .92 r
.17283 .46608 .18328 .47541 .19818 .47043 .18778 .46103 Mtetra
.654 .75 .921 r
.18778 .46103 .19818 .47043 .21316 .46545 .20281 .45599 Mtetra
.655 .75 .92 r
.20281 .45599 .21316 .46545 .22824 .46028 .21793 .45088 Mtetra
.66 .754 .92 r
.21793 .45088 .22824 .46028 .24342 .45504 .23316 .44556 Mtetra
.657 .753 .921 r
.23316 .44556 .24342 .45504 .25866 .44994 .24847 .44031 Mtetra
.654 .75 .92 r
.24847 .44031 .25866 .44994 .27399 .44492 .26386 .43515 Mtetra
.651 .747 .92 r
.26386 .43515 .27399 .44492 .28942 .4398 .27933 .43005 Mtetra
.656 .75 .919 r
.27933 .43005 .28942 .4398 .30495 .43437 .29491 .42474 Mtetra
.659 .755 .921 r
.29491 .42474 .30495 .43437 .32053 .42966 .31059 .41929 Mtetra
.641 .735 .917 r
.31059 .41929 .32053 .42966 .33614 .42614 .32631 .41448 Mtetra
.617 .702 .905 r
.32631 .41448 .33614 .42614 .35175 .42454 .34209 .41057 Mtetra
.586 .648 .878 r
.34209 .41057 .35175 .42454 .36747 .42341 .35791 .40789 Mtetra
.572 .618 .86 r
.35791 .40789 .36747 .42341 .38336 .42139 .37382 .40584 Mtetra
.585 .625 .857 r
.37382 .40584 .38336 .42139 .39943 .41792 .38989 .40322 Mtetra
.604 .647 .866 r
.38989 .40322 .39943 .41792 .41567 .41306 .40611 .39975 Mtetra
.624 .68 .882 r
.40611 .39975 .41567 .41306 .43205 .40697 .42248 .39542 Mtetra
.641 .72 .905 r
.42248 .39542 .43205 .40697 .44853 .4008 .43898 .39037 Mtetra
.655 .749 .919 r
.43898 .39037 .44853 .4008 .46508 .39526 .4556 .38476 Mtetra
.668 .754 .915 r
.4556 .38476 .46508 .39526 .48173 .39034 .47233 .37859 Mtetra
.681 .734 .891 r
.47233 .37859 .48173 .39034 .49848 .38534 .48916 .3717 Mtetra
.691 .706 .859 r
.48916 .3717 .49848 .38534 .51535 .3791 .5061 .36391 Mtetra
.698 .686 .835 r
.5061 .36391 .51535 .3791 .53232 .37145 .52311 .35527 Mtetra
.701 .675 .821 r
.52311 .35527 .53232 .37145 .54936 .36232 .5402 .34603 Mtetra
.692 .671 .825 r
.5402 .34603 .54936 .36232 .56645 .35226 .55736 .3374 Mtetra
.677 .686 .85 r
.55736 .3374 .56645 .35226 .58362 .34266 .57462 .33002 Mtetra
.667 .719 .888 r
.57462 .33002 .58362 .34266 .60089 .33499 .59199 .32354 Mtetra
.653 .738 .912 r
.59199 .32354 .60089 .33499 .6183 .32853 .60948 .31771 Mtetra
.656 .754 .922 r
.60948 .31771 .6183 .32853 .63583 .32281 .62708 .31173 Mtetra
.66 .752 .918 r
.62708 .31173 .63583 .32281 .65346 .31675 .64479 .30553 Mtetra
.658 .749 .918 r
.64479 .30553 .65346 .31675 .6712 .31059 .66261 .29938 Mtetra
.655 .75 .92 r
.66261 .29938 .6712 .31059 .68906 .30451 .68055 .29333 Mtetra
.652 .751 .922 r
.68055 .29333 .68906 .30451 .70704 .29857 .6986 .28734 Mtetra
.657 .753 .921 r
.6986 .28734 .70704 .29857 .72513 .29254 .71677 .28112 Mtetra
.658 .751 .919 r
.71677 .28112 .72513 .29254 .74332 .2863 .73505 .27481 Mtetra
.657 .751 .919 r
.73505 .27481 .74332 .2863 .76164 .28005 .75345 .26852 Mtetra
.654 .75 .921 r
.75345 .26852 .76164 .28005 .78008 .27386 .77197 .2623 Mtetra
.655 .752 .921 r
.77197 .2623 .78008 .27386 .79864 .26767 .79062 .25599 Mtetra
.655 .751 .92 r
.13251 .46695 .14318 .47628 .15796 .47122 .14734 .46189 Mtetra
.658 .753 .92 r
.14734 .46189 .15796 .47122 .17283 .46608 .16226 .4567 Mtetra
.656 .752 .92 r
.16226 .4567 .17283 .46608 .18778 .46103 .17727 .45153 Mtetra
.654 .751 .92 r
.17727 .45153 .18778 .46103 .20281 .45599 .19235 .44641 Mtetra
.654 .75 .92 r
.19235 .44641 .20281 .45599 .21793 .45088 .20752 .44129 Mtetra
.657 .752 .92 r
.20752 .44129 .21793 .45088 .23316 .44556 .22279 .43602 Mtetra
.659 .754 .92 r
.22279 .43602 .23316 .44556 .24847 .44031 .23816 .43062 Mtetra
.656 .752 .92 r
.23816 .43062 .24847 .44031 .26386 .43515 .25361 .42533 Mtetra
.653 .749 .92 r
.25361 .42533 .26386 .43515 .27933 .43005 .26914 .4201 Mtetra
.652 .747 .92 r
.26914 .4201 .27933 .43005 .29491 .42474 .28476 .4149 Mtetra
.656 .752 .92 r
.28476 .4149 .29491 .42474 .31059 .41929 .30049 .40948 Mtetra
.659 .755 .921 r
.30049 .40948 .31059 .41929 .32631 .41448 .31632 .40393 Mtetra
.647 .737 .915 r
.31632 .40393 .32631 .41448 .34209 .41057 .33221 .3988 Mtetra
.631 .708 .902 r
.33221 .3988 .34209 .41057 .35791 .40789 .34817 .39426 Mtetra
.619 .671 .878 r
.34817 .39426 .35791 .40789 .37382 .40584 .36422 .39018 Mtetra
.603 .633 .854 r
.36422 .39018 .37382 .40584 .38989 .40322 .38034 .38673 Mtetra
.605 .623 .843 r
.38034 .38673 .38989 .40322 .40611 .39975 .39659 .38315 Mtetra
.617 .628 .839 r
.39659 .38315 .40611 .39975 .42248 .39542 .41298 .37895 Mtetra
.631 .637 .838 r
.41298 .37895 .42248 .39542 .43898 .39037 .4295 .37403 Mtetra
.645 .646 .837 r
.4295 .37403 .43898 .39037 .4556 .38476 .44616 .36835 Mtetra
.657 .652 .833 r
.44616 .36835 .4556 .38476 .47233 .37859 .46293 .36191 Mtetra
.668 .654 .827 r
.46293 .36191 .47233 .37859 .48916 .3717 .4798 .35473 Mtetra
.677 .655 .821 r
.4798 .35473 .48916 .3717 .5061 .36391 .49677 .34692 Mtetra
.679 .656 .821 r
.49677 .34692 .5061 .36391 .52311 .35527 .51383 .33896 Mtetra
.671 .663 .833 r
.51383 .33896 .52311 .35527 .5402 .34603 .53097 .33165 Mtetra
.67 .691 .861 r
.53097 .33165 .5402 .34603 .55736 .3374 .5482 .32478 Mtetra
.662 .719 .891 r
.5482 .32478 .55736 .3374 .57462 .33002 .56554 .31849 Mtetra
.652 .738 .912 r
.56554 .31849 .57462 .33002 .59199 .32354 .583 .31265 Mtetra
.655 .754 .922 r
.583 .31265 .59199 .32354 .60948 .31771 .60056 .30665 Mtetra
.66 .753 .919 r
.60056 .30665 .60948 .31771 .62708 .31173 .61823 .30043 Mtetra
.658 .749 .917 r
.61823 .30043 .62708 .31173 .64479 .30553 .63602 .29423 Mtetra
.656 .75 .919 r
.63602 .29423 .64479 .30553 .66261 .29938 .65392 .2881 Mtetra
.652 .75 .921 r
.65392 .2881 .66261 .29938 .68055 .29333 .67194 .28206 Mtetra
.655 .753 .922 r
.67194 .28206 .68055 .29333 .6986 .28734 .69007 .27589 Mtetra
.658 .752 .92 r
.69007 .27589 .6986 .28734 .71677 .28112 .70831 .26955 Mtetra
.657 .751 .919 r
.70831 .26955 .71677 .28112 .73505 .27481 .72667 .2632 Mtetra
.655 .751 .92 r
.72667 .2632 .73505 .27481 .75345 .26852 .74516 .25689 Mtetra
.654 .751 .921 r
.74516 .25689 .75345 .26852 .77197 .2623 .76377 .25059 Mtetra
.656 .752 .921 r
.76377 .25059 .77197 .2623 .79062 .25599 .78249 .24415 Mtetra
.655 .751 .92 r
.12174 .45752 .13251 .46695 .14734 .46189 .13661 .45243 Mtetra
.656 .751 .92 r
.13661 .45243 .14734 .46189 .16226 .4567 .15158 .44723 Mtetra
.658 .753 .92 r
.15158 .44723 .16226 .4567 .17727 .45153 .16664 .44196 Mtetra
.655 .751 .92 r
.16664 .44196 .17727 .45153 .19235 .44641 .18177 .43675 Mtetra
.654 .75 .92 r
.18177 .43675 .19235 .44641 .20752 .44129 .19699 .43156 Mtetra
.19699 .43156 .20752 .44129 .22279 .43602 .21231 .42633 Mtetra
.658 .753 .92 r
.21231 .42633 .22279 .43602 .23816 .43062 .22773 .42093 Mtetra
.659 .754 .921 r
.22773 .42093 .23816 .43062 .25361 .42533 .24324 .41545 Mtetra
.655 .751 .92 r
.24324 .41545 .25361 .42533 .26914 .4201 .25883 .41009 Mtetra
.653 .749 .92 r
.25883 .41009 .26914 .4201 .28476 .4149 .27451 .40476 Mtetra
.652 .747 .919 r
.27451 .40476 .28476 .4149 .30049 .40948 .29028 .39945 Mtetra
.654 .751 .921 r
.29028 .39945 .30049 .40948 .31632 .40393 .30616 .39402 Mtetra
.66 .757 .921 r
.30616 .39402 .31632 .40393 .33221 .3988 .32214 .38833 Mtetra
.655 .744 .916 r
.32214 .38833 .33221 .3988 .34817 .39426 .33821 .38282 Mtetra
.646 .723 .905 r
.33821 .38282 .34817 .39426 .36422 .39018 .35436 .37762 Mtetra
.639 .701 .891 r
.35436 .37762 .36422 .39018 .38034 .38673 .3706 .37264 Mtetra
.635 .674 .87 r
.3706 .37264 .38034 .38673 .39659 .38315 .38694 .36769 Mtetra
.635 .654 .851 r
.38694 .36769 .39659 .38315 .41298 .37895 .40339 .36261 Mtetra
.638 .644 .839 r
.40339 .36261 .41298 .37895 .4295 .37403 .41996 .35723 Mtetra
.644 .641 .833 r
.41996 .35723 .4295 .37403 .44616 .36835 .43665 .35148 Mtetra
.65 .644 .831 r
.43665 .35148 .44616 .36835 .46293 .36191 .45345 .34534 Mtetra
.655 .651 .834 r
.45345 .34534 .46293 .36191 .4798 .35473 .47035 .33891 Mtetra
.66 .664 .843 r
.47035 .33891 .4798 .35473 .49677 .34692 .48735 .33234 Mtetra
.663 .685 .861 r
.48735 .33234 .49677 .34692 .51383 .33896 .50445 .3258 Mtetra
.662 .709 .883 r
.50445 .3258 .51383 .33896 .53097 .33165 .52165 .31947 Mtetra
.656 .727 .901 r
.52165 .31947 .53097 .33165 .5482 .32478 .53896 .31345 Mtetra
.651 .743 .917 r
.53896 .31345 .5482 .32478 .56554 .31849 .55637 .30762 Mtetra
.657 .756 .923 r
.55637 .30762 .56554 .31849 .583 .31265 .5739 .30151 Mtetra
.659 .753 .919 r
.5739 .30151 .583 .31265 .60056 .30665 .59153 .29527 Mtetra
.658 .749 .917 r
.59153 .29527 .60056 .30665 .61823 .30043 .60928 .28905 Mtetra
.656 .75 .919 r
.60928 .28905 .61823 .30043 .63602 .29423 .62714 .28286 Mtetra
.653 .75 .921 r
.62714 .28286 .63602 .29423 .65392 .2881 .64512 .27677 Mtetra
.654 .753 .923 r
.64512 .27677 .65392 .2881 .67194 .28206 .66322 .27061 Mtetra
.657 .753 .921 r
.66322 .27061 .67194 .28206 .69007 .27589 .68143 .26425 Mtetra
.657 .751 .919 r
.68143 .26425 .69007 .27589 .70831 .26955 .69975 .25785 Mtetra
.656 .751 .92 r
.69975 .25785 .70831 .26955 .72667 .2632 .7182 .25146 Mtetra
.654 .751 .921 r
.7182 .25146 .72667 .2632 .74516 .25689 .73677 .24513 Mtetra
.655 .752 .921 r
.73677 .24513 .74516 .25689 .76377 .25059 .75546 .2387 Mtetra
.657 .752 .92 r
.75546 .2387 .76377 .25059 .78249 .24415 .77427 .23216 Mtetra
.655 .751 .92 r
.11085 .44799 .12174 .45752 .13661 .45243 .12577 .44284 Mtetra
.12577 .44284 .13661 .45243 .15158 .44723 .14078 .43764 Mtetra
.657 .753 .92 r
.14078 .43764 .15158 .44723 .16664 .44196 .15588 .43233 Mtetra
.15588 .43233 .16664 .44196 .18177 .43675 .17108 .42699 Mtetra
.655 .751 .92 r
.17108 .42699 .18177 .43675 .19699 .43156 .18636 .42171 Mtetra
.654 .75 .92 r
.18636 .42171 .19699 .43156 .21231 .42633 .20172 .41643 Mtetra
.20172 .41643 .21231 .42633 .22773 .42093 .21718 .4111 Mtetra
.658 .754 .921 r
.21718 .4111 .22773 .42093 .24324 .41545 .23275 .40559 Mtetra
.659 .754 .921 r
.23275 .40559 .24324 .41545 .25883 .41009 .2484 .40004 Mtetra
.655 .751 .92 r
.2484 .40004 .25883 .41009 .27451 .40476 .26415 .39458 Mtetra
.654 .749 .919 r
.26415 .39458 .27451 .40476 .29028 .39945 .27998 .38913 Mtetra
.653 .747 .919 r
.27998 .38913 .29028 .39945 .30616 .39402 .29591 .38371 Mtetra
.653 .748 .92 r
.29591 .38371 .30616 .39402 .32214 .38833 .31193 .37824 Mtetra
.657 .756 .922 r
.31193 .37824 .32214 .38833 .33821 .38282 .32807 .37256 Mtetra
.659 .754 .92 r
.32807 .37256 .33821 .38282 .35436 .37762 .3443 .36679 Mtetra
.656 .742 .914 r
.3443 .36679 .35436 .37762 .3706 .37264 .36063 .36111 Mtetra
.653 .729 .905 r
.36063 .36111 .3706 .37264 .38694 .36769 .37706 .35548 Mtetra
.651 .716 .896 r
.37706 .35548 .38694 .36769 .40339 .36261 .39358 .34987 Mtetra
.651 .708 .889 r
.39358 .34987 .40339 .36261 .41996 .35723 .41021 .34418 Mtetra
.653 .704 .884 r
.41021 .34418 .41996 .35723 .43665 .35148 .42695 .33835 Mtetra
.655 .705 .884 r
.42695 .33835 .43665 .35148 .45345 .34534 .4438 .3324 Mtetra
.657 .71 .887 r
.4438 .3324 .45345 .34534 .47035 .33891 .46075 .32636 Mtetra
.656 .718 .894 r
.46075 .32636 .47035 .33891 .48735 .33234 .4778 .32034 Mtetra
.655 .729 .904 r
.4778 .32034 .48735 .33234 .50445 .3258 .49496 .31437 Mtetra
.653 .741 .915 r
.49496 .31437 .50445 .3258 .52165 .31947 .51223 .30848 Mtetra
.654 .752 .922 r
.51223 .30848 .52165 .31947 .53896 .31345 .5296 .3025 Mtetra
.658 .756 .922 r
.5296 .3025 .53896 .31345 .55637 .30762 .54709 .29631 Mtetra
.659 .75 .918 r
.54709 .29631 .55637 .30762 .5739 .30151 .56469 .29006 Mtetra
.657 .748 .917 r
.56469 .29006 .5739 .30151 .59153 .29527 .5824 .28383 Mtetra
.656 .749 .919 r
.5824 .28383 .59153 .29527 .60928 .28905 .60023 .27761 Mtetra
.653 .75 .921 r
.60023 .27761 .60928 .28905 .62714 .28286 .61817 .27148 Mtetra
.653 .753 .923 r
.61817 .27148 .62714 .28286 .64512 .27677 .63623 .2653 Mtetra
.657 .754 .921 r
.63623 .2653 .64512 .27677 .66322 .27061 .6544 .25892 Mtetra
.658 .751 .919 r
.6544 .25892 .66322 .27061 .68143 .26425 .67269 .25248 Mtetra
.657 .751 .919 r
.67269 .25248 .68143 .26425 .69975 .25785 .69109 .24604 Mtetra
.655 .75 .92 r
.69109 .24604 .69975 .25785 .7182 .25146 .70963 .23964 Mtetra
.654 .752 .921 r
.70963 .23964 .7182 .25146 .73677 .24513 .72828 .23321 Mtetra
.656 .752 .921 r
.72828 .23321 .73677 .24513 .75546 .2387 .74706 .22665 Mtetra
.657 .751 .92 r
.74706 .22665 .75546 .2387 .77427 .23216 .76595 .22003 Mtetra
.655 .751 .92 r
.09984 .43836 .11085 .44799 .12577 .44284 .11481 .43314 Mtetra
.11481 .43314 .12577 .44284 .14078 .43764 .12986 .42791 Mtetra
.656 .751 .92 r
.12986 .42791 .14078 .43764 .15588 .43233 .14501 .4226 Mtetra
.658 .753 .92 r
.14501 .4226 .15588 .43233 .17108 .42699 .16026 .41718 Mtetra
.657 .752 .92 r
.16026 .41718 .17108 .42699 .18636 .42171 .1756 .41178 Mtetra
.655 .75 .92 r
.1756 .41178 .18636 .42171 .20172 .41643 .19102 .40641 Mtetra
.654 .749 .92 r
.19102 .40641 .20172 .41643 .21718 .4111 .20653 .40104 Mtetra
.655 .75 .92 r
.20653 .40104 .21718 .4111 .23275 .40559 .22214 .39561 Mtetra
.658 .754 .921 r
.22214 .39561 .23275 .40559 .2484 .40004 .23785 .39002 Mtetra
.659 .755 .921 r
.23785 .39002 .2484 .40004 .26415 .39458 .25366 .38437 Mtetra
.656 .751 .92 r
.25366 .38437 .26415 .39458 .27998 .38913 .26955 .37879 Mtetra
.655 .749 .919 r
.26955 .37879 .27998 .38913 .29591 .38371 .28554 .37322 Mtetra
.654 .747 .919 r
.28554 .37322 .29591 .38371 .31193 .37824 .30163 .36766 Mtetra
.653 .747 .918 r
.30163 .36766 .31193 .37824 .32807 .37256 .31781 .36208 Mtetra
.654 .75 .921 r
.31781 .36208 .32807 .37256 .3443 .36679 .3341 .35645 Mtetra
.655 .755 .923 r
.3341 .35645 .3443 .36679 .36063 .36111 .35049 .35074 Mtetra
.658 .757 .923 r
.35049 .35074 .36063 .36111 .37706 .35548 .36698 .34487 Mtetra
.657 .753 .92 r
.36698 .34487 .37706 .35548 .39358 .34987 .38358 .33899 Mtetra
.656 .748 .918 r
.38358 .33899 .39358 .34987 .41021 .34418 .40028 .33311 Mtetra
.656 .746 .916 r
.40028 .33311 .41021 .34418 .42695 .33835 .41708 .32722 Mtetra
.655 .745 .916 r
.41708 .32722 .42695 .33835 .4438 .3324 .43399 .32132 Mtetra
.654 .748 .918 r
.43399 .32132 .4438 .3324 .46075 .32636 .451 .31541 Mtetra
.653 .751 .922 r
.451 .31541 .46075 .32636 .4778 .32034 .46812 .3095 Mtetra
.657 .756 .923 r
.46812 .3095 .4778 .32034 .49496 .31437 .48535 .30342 Mtetra
.658 .756 .922 r
.48535 .30342 .49496 .31437 .51223 .30848 .50269 .29727 Mtetra
.658 .752 .919 r
.50269 .29727 .51223 .30848 .5296 .3025 .52014 .29105 Mtetra
.658 .748 .917 r
.52014 .29105 .5296 .3025 .54709 .29631 .5377 .28481 Mtetra
.657 .748 .917 r
.5377 .28481 .54709 .29631 .56469 .29006 .55537 .27857 Mtetra
.656 .75 .919 r
.55537 .27857 .56469 .29006 .5824 .28383 .57316 .27234 Mtetra
.653 .75 .921 r
.57316 .27234 .5824 .28383 .60023 .27761 .59106 .26617 Mtetra
.654 .753 .923 r
.59106 .26617 .60023 .27761 .61817 .27148 .60908 .25995 Mtetra
.657 .754 .921 r
.60908 .25995 .61817 .27148 .63623 .2653 .62722 .25354 Mtetra
.658 .751 .919 r
.62722 .25354 .63623 .2653 .6544 .25892 .64547 .24707 Mtetra
.657 .75 .919 r
.64547 .24707 .6544 .25892 .67269 .25248 .66384 .24059 Mtetra
.655 .75 .92 r
.66384 .24059 .67269 .25248 .69109 .24604 .68233 .23413 Mtetra
.654 .751 .921 r
.68233 .23413 .69109 .24604 .70963 .23964 .70095 .22768 Mtetra
.656 .753 .921 r
.70095 .22768 .70963 .23964 .72828 .23321 .71969 .2211 Mtetra
.657 .752 .92 r
.71969 .2211 .72828 .23321 .74706 .22665 .73855 .21445 Mtetra
.657 .751 .92 r
.73855 .21445 .74706 .22665 .76595 .22003 .75753 .20776 Mtetra
.656 .752 .92 r
.0887 .42865 .09984 .43836 .11481 .43314 .10373 .42334 Mtetra
.655 .751 .92 r
.10373 .42334 .11481 .43314 .12986 .42791 .11883 .41804 Mtetra
.11883 .41804 .12986 .42791 .14501 .4226 .13403 .41271 Mtetra
.656 .751 .92 r
.13403 .41271 .14501 .4226 .16026 .41718 .14932 .40729 Mtetra
.658 .753 .92 r
.14932 .40729 .16026 .41718 .1756 .41178 .16472 .40179 Mtetra
.656 .752 .92 r
.16472 .40179 .1756 .41178 .19102 .40641 .1802 .3963 Mtetra
.655 .75 .92 r
.1802 .3963 .19102 .40641 .20653 .40104 .19576 .39084 Mtetra
.654 .749 .92 r
.19576 .39084 .20653 .40104 .22214 .39561 .21142 .38537 Mtetra
.654 .75 .92 r
.21142 .38537 .22214 .39561 .23785 .39002 .22718 .37985 Mtetra
.657 .754 .921 r
.22718 .37985 .23785 .39002 .25366 .38437 .24304 .37419 Mtetra
.658 .755 .921 r
.24304 .37419 .25366 .38437 .26955 .37879 .259 .36846 Mtetra
.657 .753 .92 r
.259 .36846 .26955 .37879 .28554 .37322 .27506 .36273 Mtetra
.655 .75 .92 r
.27506 .36273 .28554 .37322 .30163 .36766 .29121 .35704 Mtetra
.655 .749 .919 r
.29121 .35704 .30163 .36766 .31781 .36208 .30745 .35133 Mtetra
.654 .747 .918 r
.30745 .35133 .31781 .36208 .3341 .35645 .3238 .34561 Mtetra
.3238 .34561 .3341 .35645 .35049 .35074 .34025 .33986 Mtetra
.34025 .33986 .35049 .35074 .36698 .34487 .3568 .33406 Mtetra
.655 .75 .92 r
.3568 .33406 .36698 .34487 .38358 .33899 .37346 .32821 Mtetra
.655 .752 .921 r
.37346 .32821 .38358 .33899 .40028 .33311 .39022 .3223 Mtetra
.656 .753 .922 r
.39022 .3223 .40028 .33311 .41708 .32722 .40709 .31634 Mtetra
.656 .753 .921 r
.40709 .31634 .41708 .32722 .43399 .32132 .42406 .31033 Mtetra
.657 .753 .921 r
.42406 .31033 .43399 .32132 .451 .31541 .44114 .30426 Mtetra
.657 .751 .919 r
.44114 .30426 .451 .31541 .46812 .3095 .45834 .29814 Mtetra
.657 .748 .917 r
.45834 .29814 .46812 .3095 .48535 .30342 .47564 .29196 Mtetra
.47564 .29196 .48535 .30342 .50269 .29727 .49305 .28576 Mtetra
.49305 .28576 .50269 .29727 .52014 .29105 .51057 .27953 Mtetra
.656 .749 .918 r
.51057 .27953 .52014 .29105 .5377 .28481 .5282 .27329 Mtetra
.654 .75 .92 r
.5282 .27329 .5377 .28481 .55537 .27857 .54595 .26708 Mtetra
.653 .752 .922 r
.54595 .26708 .55537 .27857 .57316 .27234 .56381 .26086 Mtetra
.654 .754 .923 r
.56381 .26086 .57316 .27234 .59106 .26617 .58179 .25457 Mtetra
.657 .754 .921 r
.58179 .25457 .59106 .26617 .60908 .25995 .59989 .24812 Mtetra
.657 .751 .919 r
.59989 .24812 .60908 .25995 .62722 .25354 .6181 .24162 Mtetra
.657 .75 .919 r
.6181 .24162 .62722 .25354 .64547 .24707 .63643 .2351 Mtetra
.655 .75 .92 r
.63643 .2351 .64547 .24707 .66384 .24059 .65489 .2286 Mtetra
.654 .751 .921 r
.65489 .2286 .66384 .24059 .68233 .23413 .67346 .22211 Mtetra
.655 .753 .921 r
.67346 .22211 .68233 .23413 .70095 .22768 .69216 .21552 Mtetra
.657 .752 .92 r
.69216 .21552 .70095 .22768 .71969 .2211 .71099 .20883 Mtetra
.657 .751 .92 r
.71099 .20883 .71969 .2211 .73855 .21445 .72993 .2021 Mtetra
.656 .751 .92 r
.72993 .2021 .73855 .21445 .75753 .20776 .74901 .19536 Mtetra
.657 .752 .92 r
.07744 .41887 .0887 .42865 .10373 .42334 .09252 .41346 Mtetra
.655 .751 .92 r
.09252 .41346 .10373 .42334 .11883 .41804 .10768 .40807 Mtetra
.10768 .40807 .11883 .41804 .13403 .41271 .12293 .40268 Mtetra
.12293 .40268 .13403 .41271 .14932 .40729 .13827 .39725 Mtetra
.656 .752 .92 r
.13827 .39725 .14932 .40729 .16472 .40179 .15371 .39173 Mtetra
.658 .753 .921 r
.15371 .39173 .16472 .40179 .1802 .3963 .16925 .38614 Mtetra
.656 .752 .92 r
.16925 .38614 .1802 .3963 .19576 .39084 .18487 .38055 Mtetra
.655 .75 .92 r
.18487 .38055 .19576 .39084 .21142 .38537 .20059 .37499 Mtetra
.654 .749 .92 r
.20059 .37499 .21142 .38537 .22718 .37985 .2164 .36941 Mtetra
.654 .75 .92 r
.2164 .36941 .22718 .37985 .24304 .37419 .23231 .3638 Mtetra
.656 .752 .921 r
.23231 .3638 .24304 .37419 .259 .36846 .24832 .35811 Mtetra
.658 .755 .922 r
.24832 .35811 .259 .36846 .27506 .36273 .26444 .35229 Mtetra
.658 .755 .921 r
.26444 .35229 .27506 .36273 .29121 .35704 .28065 .34645 Mtetra
.657 .752 .92 r
.28065 .34645 .29121 .35704 .30745 .35133 .29697 .34059 Mtetra
.656 .75 .92 r
.29697 .34059 .30745 .35133 .3238 .34561 .31338 .33475 Mtetra
.655 .749 .919 r
.31338 .33475 .3238 .34561 .34025 .33986 .32989 .32889 Mtetra
.655 .748 .918 r
.32989 .32889 .34025 .33986 .3568 .33406 .3465 .32299 Mtetra
.3465 .32299 .3568 .33406 .37346 .32821 .36323 .31705 Mtetra
.656 .747 .917 r
.36323 .31705 .37346 .32821 .39022 .3223 .38005 .31107 Mtetra
.38005 .31107 .39022 .3223 .40709 .31634 .39699 .30504 Mtetra
.39699 .30504 .40709 .31634 .42406 .31033 .41403 .29896 Mtetra
.656 .748 .917 r
.41403 .29896 .42406 .31033 .44114 .30426 .43118 .29284 Mtetra
.43118 .29284 .44114 .30426 .45834 .29814 .44844 .28668 Mtetra
.656 .749 .918 r
.44844 .28668 .45834 .29814 .47564 .29196 .46581 .28048 Mtetra
.656 .749 .919 r
.46581 .28048 .47564 .29196 .49305 .28576 .48329 .27425 Mtetra
.655 .75 .92 r
.48329 .27425 .49305 .28576 .51057 .27953 .50088 .26803 Mtetra
.654 .751 .921 r
.50088 .26803 .51057 .27953 .5282 .27329 .51859 .26181 Mtetra
.654 .753 .923 r
.51859 .26181 .5282 .27329 .54595 .26708 .53641 .25554 Mtetra
.656 .754 .922 r
.53641 .25554 .54595 .26708 .56381 .26086 .55435 .24915 Mtetra
.657 .753 .92 r
.55435 .24915 .56381 .26086 .58179 .25457 .57241 .24266 Mtetra
.657 .751 .919 r
.57241 .24266 .58179 .25457 .59989 .24812 .59058 .23613 Mtetra
.657 .75 .919 r
.59058 .23613 .59989 .24812 .6181 .24162 .60887 .22959 Mtetra
.655 .75 .92 r
.60887 .22959 .6181 .24162 .63643 .2351 .62729 .22305 Mtetra
.654 .751 .921 r
.62729 .22305 .63643 .2351 .65489 .2286 .64583 .21652 Mtetra
.655 .753 .921 r
.64583 .21652 .65489 .2286 .67346 .22211 .66449 .2099 Mtetra
.657 .752 .92 r
.66449 .2099 .67346 .22211 .69216 .21552 .68327 .20318 Mtetra
.657 .751 .92 r
.68327 .20318 .69216 .21552 .71099 .20883 .70218 .1964 Mtetra
.656 .751 .92 r
.70218 .1964 .71099 .20883 .72993 .2021 .72121 .18961 Mtetra
.655 .751 .92 r
.72121 .18961 .72993 .2021 .74901 .19536 .74038 .18283 Mtetra
.657 .752 .92 r
.06606 .40896 .07744 .41887 .09252 .41346 .08119 .4035 Mtetra
.08119 .4035 .09252 .41346 .10768 .40807 .0964 .398 Mtetra
.655 .751 .92 r
.0964 .398 .10768 .40807 .12293 .40268 .1117 .39253 Mtetra
.655 .75 .92 r
.1117 .39253 .12293 .40268 .13827 .39725 .1271 .38705 Mtetra
.655 .751 .92 r
.1271 .38705 .13827 .39725 .15371 .39173 .14258 .38152 Mtetra
.656 .752 .92 r
.14258 .38152 .15371 .39173 .16925 .38614 .15817 .37591 Mtetra
.657 .753 .921 r
.15817 .37591 .16925 .38614 .18487 .38055 .17385 .37022 Mtetra
.657 .752 .92 r
.17385 .37022 .18487 .38055 .20059 .37499 .18963 .36453 Mtetra
.655 .751 .92 r
.18963 .36453 .20059 .37499 .2164 .36941 .2055 .35886 Mtetra
.655 .75 .92 r
.2055 .35886 .2164 .36941 .23231 .3638 .22147 .35316 Mtetra
.654 .749 .92 r
.22147 .35316 .23231 .3638 .24832 .35811 .23753 .34745 Mtetra
.655 .75 .92 r
.23753 .34745 .24832 .35811 .26444 .35229 .2537 .34169 Mtetra
.656 .753 .921 r
.2537 .34169 .26444 .35229 .28065 .34645 .26997 .33585 Mtetra
.657 .755 .922 r
.26997 .33585 .28065 .34645 .29697 .34059 .28634 .32992 Mtetra
.28634 .32992 .29697 .34059 .31338 .33475 .30282 .32395 Mtetra
.657 .754 .921 r
.30282 .32395 .31338 .33475 .32989 .32889 .3194 .31796 Mtetra
.657 .752 .92 r
.3194 .31796 .32989 .32889 .3465 .32299 .33608 .31195 Mtetra
.656 .751 .92 r
.33608 .31195 .3465 .32299 .36323 .31705 .35287 .30591 Mtetra
.656 .75 .92 r
.35287 .30591 .36323 .31705 .38005 .31107 .36976 .29985 Mtetra
.656 .75 .919 r
.36976 .29985 .38005 .31107 .39699 .30504 .38676 .29375 Mtetra
.38676 .29375 .39699 .30504 .41403 .29896 .40387 .28761 Mtetra
.655 .75 .92 r
.40387 .28761 .41403 .29896 .43118 .29284 .42109 .28144 Mtetra
.655 .751 .92 r
.42109 .28144 .43118 .29284 .44844 .28668 .43842 .27526 Mtetra
.655 .752 .921 r
.43842 .27526 .44844 .28668 .46581 .28048 .45586 .26904 Mtetra
.654 .753 .922 r
.45586 .26904 .46581 .28048 .48329 .27425 .47341 .2628 Mtetra
.654 .754 .923 r
.47341 .2628 .48329 .27425 .50088 .26803 .49107 .25652 Mtetra
.656 .755 .923 r
.49107 .25652 .50088 .26803 .51859 .26181 .50886 .25014 Mtetra
.657 .753 .921 r
.50886 .25014 .51859 .26181 .53641 .25554 .52676 .24368 Mtetra
.657 .751 .919 r
.52676 .24368 .53641 .25554 .55435 .24915 .54477 .23716 Mtetra
.657 .75 .919 r
.54477 .23716 .55435 .24915 .57241 .24266 .56291 .23061 Mtetra
.656 .75 .919 r
.56291 .23061 .57241 .24266 .59058 .23613 .58116 .22404 Mtetra
.655 .75 .92 r
.58116 .22404 .59058 .23613 .60887 .22959 .59953 .21748 Mtetra
.654 .751 .921 r
.59953 .21748 .60887 .22959 .62729 .22305 .61803 .21091 Mtetra
.655 .753 .921 r
.61803 .21091 .62729 .22305 .64583 .21652 .63665 .20424 Mtetra
.657 .752 .92 r
.63665 .20424 .64583 .21652 .66449 .2099 .65539 .19748 Mtetra
.657 .751 .92 r
.65539 .19748 .66449 .2099 .68327 .20318 .67426 .19068 Mtetra
.656 .751 .92 r
.67426 .19068 .68327 .20318 .70218 .1964 .69326 .18384 Mtetra
.655 .751 .92 r
.69326 .18384 .70218 .1964 .72121 .18961 .71238 .17701 Mtetra
.655 .752 .921 r
.71238 .17701 .72121 .18961 .74038 .18283 .73164 .17014 Mtetra
.656 .751 .92 r
.05456 .39891 .06606 .40896 .08119 .4035 .06973 .39343 Mtetra
.657 .752 .92 r
.06973 .39343 .08119 .4035 .0964 .398 .08499 .38787 Mtetra
.08499 .38787 .0964 .398 .1117 .39253 .10035 .38229 Mtetra
.655 .751 .92 r
.10035 .38229 .1117 .39253 .1271 .38705 .1158 .37672 Mtetra
.655 .75 .92 r
.1158 .37672 .1271 .38705 .14258 .38152 .13133 .37114 Mtetra
.655 .751 .92 r
.13133 .37114 .14258 .38152 .15817 .37591 .14697 .36551 Mtetra
.656 .752 .92 r
.14697 .36551 .15817 .37591 .17385 .37022 .1627 .35982 Mtetra
.657 .753 .921 r
.1627 .35982 .17385 .37022 .18963 .36453 .17854 .35404 Mtetra
.17854 .35404 .18963 .36453 .2055 .35886 .19447 .34823 Mtetra
.656 .751 .92 r
.19447 .34823 .2055 .35886 .22147 .35316 .2105 .34244 Mtetra
.655 .75 .92 r
.2105 .34244 .22147 .35316 .23753 .34745 .22662 .33663 Mtetra
.655 .749 .919 r
.22662 .33663 .23753 .34745 .2537 .34169 .24285 .3308 Mtetra
.24285 .3308 .2537 .34169 .26997 .33585 .25917 .32494 Mtetra
.655 .75 .92 r
.25917 .32494 .26997 .33585 .28634 .32992 .2756 .31903 Mtetra
.655 .752 .921 r
.2756 .31903 .28634 .32992 .30282 .32395 .29214 .31306 Mtetra
.656 .754 .922 r
.29214 .31306 .30282 .32395 .3194 .31796 .30878 .30705 Mtetra
.656 .755 .922 r
.30878 .30705 .3194 .31796 .33608 .31195 .32553 .30097 Mtetra
.656 .755 .923 r
.32553 .30097 .33608 .31195 .35287 .30591 .34238 .29485 Mtetra
.34238 .29485 .35287 .30591 .36976 .29985 .35934 .28871 Mtetra
.35934 .28871 .36976 .29985 .38676 .29375 .37641 .28254 Mtetra
.656 .754 .923 r
.37641 .28254 .38676 .29375 .40387 .28761 .39358 .27634 Mtetra
.655 .755 .923 r
.39358 .27634 .40387 .28761 .42109 .28144 .41087 .2701 Mtetra
.41087 .2701 .42109 .28144 .43842 .27526 .42827 .26384 Mtetra
.656 .755 .923 r
.42827 .26384 .43842 .27526 .45586 .26904 .44578 .2575 Mtetra
.656 .754 .922 r
.44578 .2575 .45586 .26904 .47341 .2628 .46341 .25111 Mtetra
.657 .753 .921 r
.46341 .25111 .47341 .2628 .49107 .25652 .48115 .24466 Mtetra
.657 .751 .919 r
.48115 .24466 .49107 .25652 .50886 .25014 .49901 .23816 Mtetra
.657 .75 .919 r
.49901 .23816 .50886 .25014 .52676 .24368 .51699 .23162 Mtetra
.656 .75 .919 r
.51699 .23162 .52676 .24368 .54477 .23716 .53508 .22506 Mtetra
.53508 .22506 .54477 .23716 .56291 .23061 .55329 .21847 Mtetra
.655 .751 .92 r
.55329 .21847 .56291 .23061 .58116 .22404 .57162 .21189 Mtetra
.654 .752 .921 r
.57162 .21189 .58116 .22404 .59953 .21748 .59008 .20527 Mtetra
.656 .753 .921 r
.59008 .20527 .59953 .21748 .61803 .21091 .60866 .19855 Mtetra
.657 .752 .92 r
.60866 .19855 .61803 .21091 .63665 .20424 .62736 .19176 Mtetra
.657 .751 .92 r
.62736 .19176 .63665 .20424 .65539 .19748 .64619 .18491 Mtetra
.656 .751 .92 r
.64619 .18491 .65539 .19748 .67426 .19068 .66515 .17803 Mtetra
.655 .751 .92 r
.66515 .17803 .67426 .19068 .69326 .18384 .68423 .17117 Mtetra
.655 .752 .921 r
.68423 .17117 .69326 .18384 .71238 .17701 .70345 .16426 Mtetra
.656 .752 .921 r
.70345 .16426 .71238 .17701 .73164 .17014 .72279 .15726 Mtetra
.655 .751 .92 r
.04292 .38874 .05456 .39891 .06973 .39343 .05814 .38321 Mtetra
.656 .751 .92 r
.05814 .38321 .06973 .39343 .08499 .38787 .07345 .37763 Mtetra
.657 .752 .92 r
.07345 .37763 .08499 .38787 .10035 .38229 .08886 .37198 Mtetra
.08886 .37198 .10035 .38229 .1158 .37672 .10437 .3663 Mtetra
.655 .751 .92 r
.10437 .3663 .1158 .37672 .13133 .37114 .11996 .36063 Mtetra
.655 .75 .92 r
.11996 .36063 .13133 .37114 .14697 .36551 .13565 .35494 Mtetra
.13565 .35494 .14697 .36551 .1627 .35982 .15143 .34922 Mtetra
.655 .751 .92 r
.15143 .34922 .1627 .35982 .17854 .35404 .16732 .34344 Mtetra
.657 .753 .921 r
.16732 .34344 .17854 .35404 .19447 .34823 .18331 .33758 Mtetra
.18331 .33758 .19447 .34823 .2105 .34244 .1994 .33167 Mtetra
.657 .752 .92 r
.1994 .33167 .2105 .34244 .22662 .33663 .21559 .32574 Mtetra
.656 .751 .92 r
.21559 .32574 .22662 .33663 .24285 .3308 .23187 .31981 Mtetra
.655 .75 .92 r
.23187 .31981 .24285 .3308 .25917 .32494 .24826 .31385 Mtetra
.655 .75 .919 r
.24826 .31385 .25917 .32494 .2756 .31903 .26475 .30786 Mtetra
.655 .749 .919 r
.26475 .30786 .2756 .31903 .29214 .31306 .28135 .30184 Mtetra
.28135 .30184 .29214 .31306 .30878 .30705 .29805 .29577 Mtetra
.655 .75 .92 r
.29805 .29577 .30878 .30705 .32553 .30097 .31486 .28967 Mtetra
.655 .751 .92 r
.31486 .28967 .32553 .30097 .34238 .29485 .33177 .28351 Mtetra
.656 .752 .92 r
.33177 .28351 .34238 .29485 .35934 .28871 .3488 .27731 Mtetra
.656 .752 .921 r
.3488 .27731 .35934 .28871 .37641 .28254 .36593 .27106 Mtetra
.36593 .27106 .37641 .28254 .39358 .27634 .38318 .26477 Mtetra
.656 .752 .92 r
.38318 .26477 .39358 .27634 .41087 .2701 .40054 .25844 Mtetra
.656 .751 .92 r
.40054 .25844 .41087 .2701 .42827 .26384 .41801 .25205 Mtetra
.656 .75 .919 r
.41801 .25205 .42827 .26384 .44578 .2575 .4356 .24561 Mtetra
.4356 .24561 .44578 .2575 .46341 .25111 .4533 .23914 Mtetra
.4533 .23914 .46341 .25111 .48115 .24466 .47111 .23262 Mtetra
.47111 .23262 .48115 .24466 .49901 .23816 .48904 .22607 Mtetra
.48904 .22607 .49901 .23816 .51699 .23162 .5071 .21948 Mtetra
.655 .75 .92 r
.5071 .21948 .51699 .23162 .53508 .22506 .52527 .21289 Mtetra
.655 .751 .921 r
.52527 .21289 .53508 .22506 .55329 .21847 .54356 .20627 Mtetra
.655 .753 .922 r
.54356 .20627 .55329 .21847 .57162 .21189 .56197 .1996 Mtetra
.656 .753 .921 r
.56197 .1996 .57162 .21189 .59008 .20527 .58051 .19282 Mtetra
.657 .752 .92 r
.58051 .19282 .59008 .20527 .60866 .19855 .59917 .18599 Mtetra
.657 .751 .919 r
.59917 .18599 .60866 .19855 .62736 .19176 .61796 .17911 Mtetra
.656 .751 .92 r
.61796 .17911 .62736 .19176 .64619 .18491 .63687 .1722 Mtetra
.655 .751 .92 r
.63687 .1722 .64619 .18491 .66515 .17803 .65592 .16529 Mtetra
.655 .752 .921 r
.65592 .16529 .66515 .17803 .68423 .17117 .67509 .15834 Mtetra
.656 .752 .921 r
.67509 .15834 .68423 .17117 .70345 .16426 .69439 .1513 Mtetra
.656 .752 .92 r
.69439 .1513 .70345 .16426 .72279 .15726 .71383 .1442 Mtetra
.655 .751 .92 r
.03116 .37844 .04292 .38874 .05814 .38321 .04643 .37286 Mtetra
.04643 .37286 .05814 .38321 .07345 .37763 .06179 .36723 Mtetra
.656 .751 .92 r
.06179 .36723 .07345 .37763 .08886 .37198 .07725 .36156 Mtetra
.657 .752 .92 r
.07725 .36156 .08886 .37198 .10437 .3663 .0928 .35581 Mtetra
.0928 .35581 .10437 .3663 .11996 .36063 .10846 .35003 Mtetra
.656 .751 .92 r
.10846 .35003 .11996 .36063 .13565 .35494 .1242 .34425 Mtetra
.655 .75 .92 r
.1242 .34425 .13565 .35494 .15143 .34922 .14004 .33846 Mtetra
.14004 .33846 .15143 .34922 .16732 .34344 .15598 .33263 Mtetra
.655 .751 .92 r
.15598 .33263 .16732 .34344 .18331 .33758 .17202 .32676 Mtetra
.656 .752 .921 r
.17202 .32676 .18331 .33758 .1994 .33167 .18816 .32083 Mtetra
.657 .753 .921 r
.18816 .32083 .1994 .33167 .21559 .32574 .20441 .31483 Mtetra
.20441 .31483 .21559 .32574 .23187 .31981 .22076 .30878 Mtetra
.657 .752 .92 r
.22076 .30878 .23187 .31981 .24826 .31385 .23721 .3027 Mtetra
.656 .751 .92 r
.23721 .3027 .24826 .31385 .26475 .30786 .25377 .29662 Mtetra
.656 .75 .92 r
.25377 .29662 .26475 .30786 .28135 .30184 .27043 .2905 Mtetra
.656 .75 .919 r
.27043 .2905 .28135 .30184 .29805 .29577 .28719 .28435 Mtetra
.28719 .28435 .29805 .29577 .31486 .28967 .30407 .27816 Mtetra
.30407 .27816 .31486 .28967 .33177 .28351 .32105 .27193 Mtetra
.656 .749 .919 r
.32105 .27193 .33177 .28351 .3488 .27731 .33814 .26565 Mtetra
.33814 .26565 .3488 .27731 .36593 .27106 .35534 .25933 Mtetra
.35534 .25933 .36593 .27106 .38318 .26477 .37266 .25296 Mtetra
.656 .75 .919 r
.37266 .25296 .38318 .26477 .40054 .25844 .39009 .24655 Mtetra
.39009 .24655 .40054 .25844 .41801 .25205 .40763 .2401 Mtetra
.40763 .2401 .41801 .25205 .4356 .24561 .42529 .2336 Mtetra
.42529 .2336 .4356 .24561 .4533 .23914 .44306 .22707 Mtetra
.656 .75 .92 r
.44306 .22707 .4533 .23914 .47111 .23262 .46095 .2205 Mtetra
.655 .751 .92 r
.46095 .2205 .47111 .23262 .48904 .22607 .47896 .21392 Mtetra
.655 .752 .921 r
.47896 .21392 .48904 .22607 .5071 .21948 .49708 .2073 Mtetra
.655 .753 .922 r
.49708 .2073 .5071 .21948 .52527 .21289 .51533 .20063 Mtetra
.656 .753 .921 r
.51533 .20063 .52527 .21289 .54356 .20627 .53371 .19387 Mtetra
.656 .752 .92 r
.53371 .19387 .54356 .20627 .56197 .1996 .5522 .18706 Mtetra
.656 .751 .92 r
.5522 .18706 .56197 .1996 .58051 .19282 .57082 .18019 Mtetra
.656 .751 .919 r
.57082 .18019 .58051 .19282 .59917 .18599 .58956 .17327 Mtetra
.656 .751 .92 r
.58956 .17327 .59917 .18599 .61796 .17911 .60844 .16633 Mtetra
.655 .751 .92 r
.60844 .16633 .61796 .17911 .63687 .1722 .62744 .15938 Mtetra
.655 .752 .921 r
.62744 .15938 .63687 .1722 .65592 .16529 .64657 .15239 Mtetra
.656 .752 .921 r
.64657 .15239 .65592 .16529 .67509 .15834 .66583 .14531 Mtetra
.656 .752 .92 r
.66583 .14531 .67509 .15834 .69439 .1513 .68523 .13816 Mtetra
.656 .751 .92 r
.68523 .13816 .69439 .1513 .71383 .1442 .70475 .13096 Mtetra
.01927 .36806 .03116 .37844 .04643 .37286 .03458 .36239 Mtetra
.655 .751 .92 r
.03458 .36239 .04643 .37286 .06179 .36723 .05 .3567 Mtetra
.05 .3567 .06179 .36723 .07725 .36156 .0655 .35098 Mtetra
.656 .751 .92 r
.0655 .35098 .07725 .36156 .0928 .35581 .08111 .3452 Mtetra
.656 .752 .92 r
.08111 .3452 .0928 .35581 .10846 .35003 .09681 .33936 Mtetra
.657 .753 .921 r
.09681 .33936 .10846 .35003 .1242 .34425 .11262 .33348 Mtetra
.656 .752 .92 r
.11262 .33348 .1242 .34425 .14004 .33846 .12852 .32758 Mtetra
.655 .751 .92 r
.12852 .32758 .14004 .33846 .15598 .33263 .14451 .32167 Mtetra
.655 .75 .92 r
.14451 .32167 .15598 .33263 .17202 .32676 .16061 .31574 Mtetra
.16061 .31574 .17202 .32676 .18816 .32083 .17681 .30976 Mtetra
.655 .751 .92 r
.17681 .30976 .18816 .32083 .20441 .31483 .19311 .30374 Mtetra
.656 .752 .921 r
.19311 .30374 .20441 .31483 .22076 .30878 .20951 .29767 Mtetra
.656 .753 .921 r
.20951 .29767 .22076 .30878 .23721 .3027 .22603 .29154 Mtetra
.657 .753 .921 r
.22603 .29154 .23721 .3027 .25377 .29662 .24265 .28535 Mtetra
.656 .753 .921 r
.24265 .28535 .25377 .29662 .27043 .2905 .25937 .27913 Mtetra
.656 .752 .921 r
.25937 .27913 .27043 .2905 .28719 .28435 .2762 .27288 Mtetra
.656 .752 .92 r
.2762 .27288 .28719 .28435 .30407 .27816 .29314 .26659 Mtetra
.656 .751 .92 r
.29314 .26659 .30407 .27816 .32105 .27193 .31019 .26027 Mtetra
.31019 .26027 .32105 .27193 .33814 .26565 .32735 .25391 Mtetra
.32735 .25391 .33814 .26565 .35534 .25933 .34462 .24752 Mtetra
.34462 .24752 .35534 .25933 .37266 .25296 .36201 .24108 Mtetra
.36201 .24108 .37266 .25296 .39009 .24655 .3795 .23461 Mtetra
.655 .751 .92 r
.3795 .23461 .39009 .24655 .40763 .2401 .39712 .2281 Mtetra
.655 .751 .921 r
.39712 .2281 .40763 .2401 .42529 .2336 .41485 .22155 Mtetra
.655 .752 .921 r
.41485 .22155 .42529 .2336 .44306 .22707 .43269 .21497 Mtetra
.655 .753 .921 r
.43269 .21497 .44306 .22707 .46095 .2205 .45066 .20834 Mtetra
.655 .753 .922 r
.45066 .20834 .46095 .2205 .47896 .21392 .46874 .20167 Mtetra
.656 .753 .921 r
.46874 .20167 .47896 .21392 .49708 .2073 .48695 .19492 Mtetra
.656 .752 .921 r
.48695 .19492 .49708 .2073 .51533 .20063 .50528 .18811 Mtetra
.656 .751 .92 r
.50528 .18811 .51533 .20063 .53371 .19387 .52373 .18125 Mtetra
.656 .751 .919 r
.52373 .18125 .53371 .19387 .5522 .18706 .54231 .17435 Mtetra
.54231 .17435 .5522 .18706 .57082 .18019 .56101 .1674 Mtetra
.656 .751 .92 r
.56101 .1674 .57082 .18019 .58956 .17327 .57984 .16044 Mtetra
.655 .751 .921 r
.57984 .16044 .58956 .17327 .60844 .16633 .5988 .15345 Mtetra
.655 .752 .921 r
.5988 .15345 .60844 .16633 .62744 .15938 .61789 .14641 Mtetra
.656 .752 .921 r
.61789 .14641 .62744 .15938 .64657 .15239 .63711 .13928 Mtetra
.656 .751 .92 r
.63711 .13928 .64657 .15239 .66583 .14531 .65646 .13209 Mtetra
.65646 .13209 .66583 .14531 .68523 .13816 .67594 .12485 Mtetra
.67594 .12485 .68523 .13816 .70475 .13096 .69556 .11758 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
[(-2)] .12586 .2075 1 .99877 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.56863 .04703 m
.57247 .05235 L
s
[(2)] .56094 .0364 .72324 1 Mshowa
.125 Mabswid
.18558 .19702 m
.18832 .19985 L
s
.23703 .17687 m
.23971 .17975 L
s
.28951 .15632 m
.29214 .15925 L
s
.39772 .11395 m
.40023 .11699 L
s
.4535 .09211 m
.45595 .0952 L
s
.51046 .06981 m
.51284 .07294 L
s
.08568 .23614 m
.08851 .23887 L
s
.62804 .02377 m
.63027 .02701 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 233.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00o?ooool2o`0006[ooooo003iooooo`?o000000?oooooo`000?ooool0
JOooool00?Oooooo0_l00004ooooo`;o0000JOooool00?Cooooo0ol00006ooooo`03o`000?oooooo
000006Sooooo003;ooooo`Go00008_ooool2o`0000Wooooo00?o0000ooooool00000J?ooool00<_o
oooo00GoV9RHob4Q8Oo^k^koooooodA4A00Oooooo`?o00002oooool01?l0003oooooooooool0001W
ooooo`00c?ooool00onHV9So8B4Qonk^kP0Mooooo`?o00003_ooool01Ol0003ooooooooooooooooo
000006Kooooo003=ooooo`03oiRHV?lQ8B7ok^k^01[ooooo0_l0000Aooooo`05o`000?oooooooooo
ooooool00000I_ooool00<kooooo00?oMgMgofIVI_ooool05_ooool3o`0001?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1Sooooo`00coooool00ol0003oooooooooo`0Cooooo`;o
00000_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0H_ooool00<_ooooo00Go0000okZj^_ooooooV9RHoa0@400Booooo`?o00006Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo06;ooooo003;ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`04?ooool2o`0001cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Qooooo`00
gOooool3o`0001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Qooooo`00fooo
ool2o`00027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Pooooo`00f?ooool3
o`0002?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Oooooo`00eOooool3o`00
02Kooooo00?o0000ooooooooool01?ooool2o`00067ooooo003Cooooo`;o0000:Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo05kooooo003@ooooo`?o000000?oooooo`000?ooool0
:?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05gooooo003>ooooo`;o00001Ooo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0GOoo
ool00<_ooooo0ol0000`ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0G?ooool0
0<Wooooo0_l0000cooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Foooool00<Ko
oooo0ol0000eooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Foooool00<Cooooo
0_l0000hooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0F_ooool00<7ooooo0ol0
000jooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03_ooool5o`0004Kooooo002n
ooooo`?o0000?Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00kooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A016ooooo`00_?ooool2o`0000?ooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo1_l00003ooooo`03oiRHV?lQ8B7o
k^k^04Oooooo002iooooo`?o0000@oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00kooooo00?oV9RHob4Q8Oo^k^h0A_ooool00;Oooooo0_l00016ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03oooool00omgMgOoIVIVooooo`15ooooo`00]?ooool3o`0004Sooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Cooooo
002booooo`;o0000Boooool00ol0003oooooooooo`0=ooooo`;o00003?ooool01Ol0003o^[Zjoooo
oonHV9So410@04Kooooo002_ooooo`?o0000COooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c016ooooo`00[Oooool2o`00053ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`1Dooooo`00Z_ooool4o`00057ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1Dooooo`00Z?ooool2o`0000Cooooo00?o0000oooo
ooooool0C_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05?ooooo001nooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h08_ooool3o`0005Oooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`1Booooo`00O_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01oooooo0ol0001Joooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool0D_ooool007kooooo00Go410@oooooooo
oooooooooa0@400Mooooo`;o0000GOooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
057ooooo001nooooo`05o`000?ooooooooooooooool000006_ooool3o`0005oooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`1@ooooo`00O_ooool01Ol0003ooooooooooooooooo0000
01Sooooo0_l0001Rooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0D?ooool007ko
oooo00Go410@oooooooooooooooooa0@400Eooooo`?o0000I?ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo04oooooo001nooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool2o`00
00?ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
04kooooo001nooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04?ooool3o`0006Sooooo00?oYl3[o`00
0?ooool05_ooool00ol0003oooooooooo`1>ooooo`00TOooool2o`0006Sooooo1?nW`>/00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo04gooooo002>ooooo`?o0000J?ooool7ojO0j`03o`00
0?oooooooooo01Cooooo0ol0001>ooooo`00Roooool3o`0006Wooooo2OnW`>/00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo04cooooo0029ooooo`;o0000JOooool<ojO0j`03o`000?nW`>_o
oooo01Oooooo00?o0000ooooooooool0Boooool008Kooooo0ol0001Xooooo`ooYl3[00?o0000ojO0
joooool06?ooool00ol0003oooooooooo`1:ooooo`00Q?ooool2o`0000;ooooo00?o0000oooooooo
ool0HooooolBojO0j`03o`000?nW`>_oYl3[01Sooooo00?o0000ooooooooool0B_ooool0087ooooo
0ol00005ooooo`03o`000?oooooooooo063ooooo5?nW`>/01?l0003oYl3[ojO0jonW`>/Hooooo`03
o`000?oooooooooo04Wooooo001oooooo`;o0000JOoooolFojO0j`03o`000?nW`>_oYl3[00;oYl3[
6?ooool00ol0003oooooooooo`18ooooo`00O?ooool3o`0006Sooooo6OnW`>/00ol0003oYl3[ojO0
j`02ojO0jaSooooo00?o0000ooooooooool0B?ooool007[ooooo0_l0001WoooooagoYl3[00?o0000
ojO0jonW`>/00onW`>/Hooooo`03o`000?oooooooooo04Oooooo001gooooo`?o0000I_oooolPojO0
j`03o`000?nW`>_oYl3[00CoYl3[6?ooool00ol0003oooooooooo`16ooooo`00M?ooool3o`0006Ko
oooo8onW`>/00ol0003oYl3[ojO0j`04ojO0jaSooooo00?o0000ooooooooool0A_ooool007;ooooo
0_l00002ooooo`03o`000?oooooooooo06;ooooo9OnW`>/00ol0003oYl3[ojO0j`05ojO0jaSooooo
00?o0000ooooooooool0AOooool006oooooo0ol0001WooooobOoYl3[00?o0000ojO0jonW`>/01OnW
`>/Hooooo`03o`000?oooooooooo04Gooooo001]ooooo`;o0000IooooolZojO0j`03o`000?nW`>_o
Yl3[00KoYl3[5oooool2o`0004Kooooo001Zooooo`?o0000I_ooool]ojO0j`03o`000?nW`>_oYl3[
00OoYl3[6?ooool00ol0003oooooooooo`13ooooo`00J?ooool2o`0006Kooooo<?nW`>/00ol0003o
Yl3[ojO0j`08ojO0jaOooooo00?o0000ooooooooool0@oooool006Gooooo0ol0001Uoooooc?oYl3[
00?o0000ojO0jonW`>/02?nW`>/Hooooo`03o`000?oooooooooo04;ooooo001Sooooo`;o0000IOoo
oolgojO0j`03o`000?nW`>_oYl3[00SoYl3[6?ooool00ol0003oooooooooo`11ooooo`00H?ooool3
o`000003ooooool0003ooooo06;ooooo>OnW`>/00ol0003oYl3[ojO0j`09ojO0jaOooooo00?o0000
ooooooooool0@Oooool003Kooooo1Ol0000Sooooo`;o0000I_oooolMojO0j`;oZ<3[7?nW`>/00ol0
003oYl3[ojO0j`0:ojO0jaOooooo00?o0000ooooooooool0@?ooool003Kooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00Pooooo`?o0000IOoooolMojO0j`KoZ<3[6onW`>/00ol0003oYl3[ojO0j`0:ojO0
jaSooooo00?o0000ooooooooool0?oooool002kooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^01ko
oooo0ol0001UoooooagoYl3[2_nX`>/6ojO0j`03ojS0jonW`>_oYl3[017oYl3[00?o0000ojO0jonW
`>/02onW`>/Gooooo`03o`000?oooooooooo03oooooo000hooooo`03oiRHV?lQ8B7ok^k^01_ooooo
0_l0001UoooooakoYl3[3OnX`>/2ojO0j`GoZ<3[4_nW`>/00ol0003oYl3[ojO0j`0<ojO0jaOooooo
00?o0000ooooooooool0?_ooool003Wooooo00?oMgMgofIVI_ooool05oooool3o`0006Cooooo7onW
`>/GojS0j`KoYl3[0_nX`>/9ojO0j`03o`000?nW`>_oYl3[00coYl3[6?ooool00ol0003ooooooooo
o`0mooooo`00>_ooool00ol0003oooooooooo`0Dooooo`;o0000I?oooolQojO0jaWoZ<3[0_nW`>/6
ojS0j`SoYl3[00?o0000ojO0jonW`>/03OnW`>/Gooooo`03o`000?oooooooooo03gooooo000foooo
o`05o`000?nj^[[ooooooiRHV?l@41004oooool3o`0000;ooooo00?o0000ooooooooool0GooooolT
ojO0jb7oZ<3[1_nW`>/00onX`>_o0000ojO0j`0>ojO0jaSooooo00?o0000ooooooooool0??ooool0
03Kooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Aooooo`;o0000IOooool>ojO0j`03ojO0k?nW`>_o
Yl3[00coYl3[0_nW`>`8ojO0j`KoZ<3[0_nW`>/IojS0j`;oYl3[1?nX`>/00ol0003oYl3[ojO0j`0>
ojO0jaKooooo0ol0000mooooo`00BOooool3o`0006Gooooo00?oYl3/ojO0jonW`>/02onW`>/4ojO0
k0[oYl3[1_nW`>`8ojO0j`;oZ<3[1_nW`>/NojS0j`03o`000?nX`>_oYl3[00GoYl3[0_nX`>/8ojO0
jaOooooo00?o0000ooooooooool0>oooool004Oooooo0_l0001Uooooo`GoYl3/2_nW`>/7ojO0k0So
Yl3[2?nW`>`@ojO0j`KoZ<3[00?oYl3[ojS0jonX`>/05?nX`>/00ol0003oZ<3[ojS0j`02ojO0j`Ko
Z<3[2?nW`>/Gooooo`03o`000?oooooooooo03[ooooo0014ooooo`?o0000I?ooool00onW`>_oYl3/
ojO0k006ojO0k0SoYl3[2?nW`>`9ojO0j`SoYl3/4?nW`>/2ojS0j`GoYl3[5OnX`>/00ol0003oZ<3[
ojS0j`09ojS0j`KoYl3[00?oZ<3[ooooooooool05_ooool00ol0003oooooooooo`0iooooo`00@Ooo
ool3o`0006Cooooo1OnW`>/8ojO0k0SoYl3[2?nW`>`9ojO0j`KoYl3/6OnW`>/6ojS0j`;oYl3[3?nX
`>/00ol0003oZ<3[ojS0j`0:ojS0j`;oYl3[1OnX`>/Gooooo`03o`000?oooooooooo03Wooooo000o
ooooo`?o0000Hoooool9ojO0j`KoYl3/2_nW`>/6ojO0k0;oYko[2OnW`>/2ojO0k1goYl3[0_nX`>/6
ojO0j`OoZ<3[00GoYl3[ojS0jonX`>_oZ<3[o`00000DojS0jaOooooo00?o0000ooooooooool0>?oo
ool003cooooo0ol00003ooooo`03o`000?oooooooooo05kooooo3?nW`>/2ojO0k0koYl3[0_nW`>`6
ojNoj`OoYl3[00?oYko[ojO0jonW`>/03?nW`>/2ojNojaSoYl3[1?nX`>/4ojO0j`;oZ<3[00?o0000
ojS0jonX`>/04onX`>/Fooooo`03o`000?oooooooooo00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0/ooooo`00>_ooool2o`0006Gooooo3OnW`>/2ojNoj`koYl3[2_nW_n/4ojO0j`CoYko[2_nW`>/6
ojNojaSoYl3[00?oZ<3[ojO0jonW`>/01OnW`>/00onX`>_o0000ojS0j`03ojS0j`03ojO0jonX`>_o
Z<3[00koZ<3[5oooool00ol0003oooooooooo`06ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0;?oo
ool003Oooooo0ol0001Uooooo`coYl3[1_nW_n/:ojO0j`koYko[00?oYl3[ojNojonW_n/01OnW_n/6
ojO0j`[oYko[1_nW`>/00onW_n_oYl3[ojO0j`0FojO0j`;oZ<3[00?o0000ojS0jonW`>/00onW`>/@
ojS0jaOooooo00?o0000ooooooooool01Oooool01Ol@413ooooooooooooooooo410@02cooooo000e
ooooo`;o0000IOooool<ojO0j`[oYko[1_nW`>/IojNoj`CoYl3[3OnW_n/2ojO0j`GoYko[6?nW`>/0
0onX`>_o0000ojO0j`05ojO0j`KoZ<3[0_nW`>/8ojS0jaKooooo00?o0000ooooooooool01Oooool0
1Ol0003ooooooooooooooooo000002cooooo000booooo`?o0000I?ooool=ojO0j`goYko[0_nW`>/M
ojNoj`03ojO0jonW_n_oYko[00_oYko[0_nX_n/8ojNoj`KoYl3[00?oYko[ojO0jonW`>/03onW`>/0
0ol0003oYl3[ojO0j`05ojO0j`;oZ<3[1_nW`>/8ojS0jaKooooo00?o0000ooooooooool01?ooool0
1Ol0003ooooooooooooooooo000002cooooo000`ooooo`;o0000I?ooool>ojO0jagoYko[0_nX_n/>
ojNoj`03ojRojonW_n_oYko[00WoYko[1_nX_n/8ojNoj`;oYl3[1OnW_n/@ojO0j`03o`000?nW`>_o
Yl3[00goYl3[2?nX`>/Gooooo`03o`000?oooooooooo00?ooooo00Go410@oooooooooooooooooa0@
400/ooooo`00;Oooool3o`000003ooooool0003ooooo063ooooo3onW`>/LojNoj`KoZ;o[2_nW_n/5
ojRoj`OoYko[00?oZ<3[ojRojonX_n/01onX_n/6ojNoj`03ojRojonW_n_oYko[00KoYko[1_nW`>/2
ojNoj`OoYl3[00?o0000ojO0jonW`>/03_nW`>/8ojS0jaKooooo0_l00004ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL0;?ooool002[ooooo0ol0001Sooooo`ooYl3[7?nW_n/2ojS0j`SoZ;o[1_nW_n/0
0onX`>_oZ;o[ojRoj`06ojRoj`CoYko[1?nX`>/9ojRoj`;oYko[1OnX_n/8ojNoj`;oYl3[1_nW_n/6
ojO0j`03o`000?nW`>_oYl3[00koYl3[2OnX`>/Cooooo`;o000000?oooooo`000?ooool00oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^02cooooo000Xooooo`;o0000Hoooool?ojO0jacoYko[1_nX`>/8
ojRoj`;oYko[1OnX`>/8ojRoj`03ojNojonX`>_oZ<3[00GoZ<3[1onX_n/00onX`>_oZ;o[ojRoj`06
ojRoj`KoYko[00?oZ;o[ojNojonW_n/01onW_n/5ojO0j`03o`000?nW_n_oYl3[00ooYl3[2OnX`>/F
ooooo`03o`000?oooooooooo03;ooooo000Uooooo`?o0000H_ooool?ojO0jacoYko[2_nX`>/6ojRo
j`WoZ<3[1_nX_n/:ojS0j`CoZ;o[1?nX`>/8ojRoj`;oYko[1OnX_n/9ojNoj`;oYl3[00?oYko[o`00
0?l000000_nW_n/@ojO0j`KoZ<3[0_nW`>/Fooooo`03o`000?oooooooooo03;ooooo000Sooooo`;o
0000H_ooool?ojO0jagoYko[3OnX`>/2ojRoj`goZ<3[0_nX_n/>ojS0j`03ojRojonX`>_oZ<3[00Go
Z<3[1_nX_n/00onX`>_oZ;o[ojRoj`06ojRoj`KoYko[0_nX`>/3o`000003ojNojol0003oYko[00;o
Yko[4?nW`>/2ojS0j`KoYl3[5_ooool00ol0003oooooooooo`0aooooo`008?ooool3o`00067ooooo
3onW`>/NojNoj`koZ<3[00?oYl7/ojS0jonX`>/03?nX`>/00onW`NcoZ<3[ojS0j`0<ojS0j`;oZ<7[
2OnX`>/2ojRoj`GoZ<3[2?nX_n/2ojNoj`;oZ<3[0ol000000onX`>_oYko[ojNoj`02ojNoj`04o`00
0?nW_n_oYko[ojNojaOoYl3[5oooool00ol0003oooooooooo`0`ooooo`007oooool2o`00063ooooo
3onW`>/@ojNoj`03ojO0jonW_n_oYko[00coYko[0_nW`N`;ojS0j`GoYl7/2_nX`>/5ojO1k0[oZ<3[
1_nX`N/7ojS0j`03ojS1jonX`>_oZ<3[00KoZ<3[1_nX_n/2ojS0j`?o00001?nX`>/5ojNoj`03o`00
0?nW`>_oYl3[01SoYl3[5_ooool00ol0003oooooooooo`0`ooooo`007oooool00ol0003oooooo`00
001Mooooo`koYl3[4?nW_n/5ojO0j`[oYko[1_nW`N`7ojS0j`WoYl7/1_nX`>/00onW`>coYl7/ojO1
k006ojO1k0KoZ<3[0_nW`N`8ojS1j`CoZ<3[1?nX`N/8ojS0j`;oZ;o[0_nX`>/3o`0000SoZ<3[0_nW
_n/3ojO0j`03o`000?nW`>_oYl3[01OoYl3[5oooool00ol0003oooooooooo`0_ooooo`003?ooool5
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`04o`000?ooooooooooo`0005[ooooo
3OnW`>/@ojNoj`WoYl3[1_nW_n/:ojO1k0CoZ<3[3?nW`N`2ojS0j`GoYl3/2?nW`N`2ojS0j`KoYl7/
2?nX`N/00onX`>_oZ<7[ojS1j`05ojS1j`KoZ<3[00?oZ<7[ojS0jol000000_l0000;ojS0j`GoYl3[
00?o0000ojO0jonW`>/06?nW`>/Gooooo`03o`000?oooooooooo02kooooo000<ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo0_l00002ooooo`03
o`000?oooooooooo05Gooooo3?nW`>/@ojNoj`goYl3[0_nW_n/>ojO1k003ojS0jonW`NcoYl7/00_o
Yl7/00?oYl3[ojO0k?nW`>`01_nW`>`6ojO1k003ojO0k?nW`NcoYl7/00OoYl7/1_nX`N/2ojO0k0So
Z<7[0_nX`>/2ojS1j`?o00003onX`>/5ojO0j`03o`000?nW`>_oYl3[00ooYl3[00?oYko[ojO0jonW
`>/01_nW`>/Fooooo`03o`000?oooooooooo02kooooo0004ooooo`Ko00000oooool00onHV9So8B4Q
onk^kP04ooooo`05oa0@4?ooooooooooooooool@41001Oooool2o`0000Cooooo00?o0000oooooooo
ool0DOooool=ojO0j`ooYko[3onW`>/@ojO1k0;oYl3/2_nW`N`5ojO0j`SoYl3/0_nW`N`5ojO0k0Wo
Yl7/0_nX`N/6ojO0k0KoZ<7[00?oYl3/ojS1jol000000_l00004ojS1j`ooZ<3[1OnW`>/00ol0003o
Z<3[ojS0j`0;ojO0j`GoYko[2?nW`>/Fooooo`03o`000?oooooooooo02gooooo000>ooooo`03oiRH
V?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0COooool>ojO0j`koYko[3onW`>/@ojO1k0KoYl3/1_nW`N`00onW_n_o
Yl3[ojO0j`06ojO0j`KoYl3/00?oYko[ojO0k?nW`>`01_nW`>`6ojO1k0;oYko[2OnW`>`2ojS1j`?o
Yl3/0_l00008ojS1j`ooZ<3[0_nW`>/2ojS0j`04o`000?nX`>_oZ<3[ojS0j`OoYl3[00?oZ<3[ojNo
jonW_n/01_nW_n/7ojO0jaOooooo00?o0000ooooooooool0;?ooool000oooooo00?oMgMgofIVI_oo
ool00_ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`19ooooo`ooYl3[3OnW_n/?ojO0ja3oYl7/00?oYl3[ojO0k?nW`>`01onW`>`2ojO1
k0GoYko[2?nW`>/2ojO0k0GoYko[2?nW`>`2ojO1k0KoYko[1onW`>`00onW_n_oYl3/ojO0k003o`00
00?oYl3/1_nX`N/00onW`>coZ<3[ojS0j`0BojS0j`03o`000?nX`>_oZ<3[00CoYl3[1OnX`>/8ojNo
j`OoYl3[5Oooool2o`0002kooooo000@ooooo`05o`000?ooooooooooooooool@41000oooool00ol@
413oooooooooo`03ooooo`;o00001oooool00ol0003oooooooooo`16ooooo`ooYl3[3?nW_n/?ojO0
ja3oYl7/1OnW`>/7ojO0k0WoYko[1_nW`>/9ojNoj`KoYl3/2_nW_n/4ojO0k0;oYko[0ol00007ojO0
k0;oZ<7[1OnW`>`DojS0j`04o`000?nX`>_oZ<3[ojO0j`SoZ<3[1_nW_n/9ojO0jaKooooo00?o0000
ooooooooool0:oooool000cooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04;ooooo3onW
`>/<ojNoj`ooYl3[4?nW`N`9ojO0j`CoYl3/3?nW_n/2ojO0j`goYko[0_nW`>`>ojNoj`03ojO0k?nW
_n_o000000;o00000onW_n/6ojO0k003ojNojonW`>coYl3/00KoYl3/1_nX`>/00onW`>coZ<3[ojS0
j`0;ojS0j`03o`000?nX`>_oZ<3[00WoZ<3[0_nW_n/=ojO0jaGooooo00?o0000ooooooooool0:ooo
ool000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03kooooo3onW`>/=ojNoj`koYl3[
4?nW`N`=ojO0j`03ojO0k?nW_n_oYko[00_oYko[00?oZ;oZojNojonW_n/03?nW_n/2ojRojPkoYko[
0ol00007ojNoj`;oYl3/1OnW_n/8ojO0k0;oZ<3[1OnW`>`<ojS0j`03o`000?nX`>_oZ<3[00WoZ<3[
3onW`>/Fooooo`03o`000?oooooooooo02[ooooo000Nooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool0>_ooool?ojO0j`koYko[3_nW`>/?ojO1k003ojNojonW`>_oYl3[00coYl3[3?nW
_n/5ojRojP[oYko[1_nX_nX:ojNoj`?o00004_nW_n/6ojO0k003ojJojonW`>coYl3/00KoYl3/3?nX
`>/00ol0003oZ<3[ojS0j`09ojS0j`ooYl3[5_ooool00ol0003oooooooooo`0Yooooo`007Oooool3
o`0000_ooooo00?o0000ooooooooool0=_ooool2ojS0j`goYl3[3onW_n/=ojO0j`ooYl7/1OnW_n/:
ojO0j`coYko[2OnX_nX6ojNoj`[oZ;oZ1_nW_n/3o`0001KoYko[0_nW`>`5ojJoj`SoYl3/3?nX`>/0
0ol0003oZ<3[ojS0j`08ojS0j`ooYl3[5_ooool00ol0003oooooooooo`0Yooooo`007Oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo03;ooooo1_nX`>/9ojO0j`ooYko[3OnW`>/?ojO1
k0WoYko[1_nW`>/00onW_n[oYko[ojNoj`09ojNoj`goZ;oZ0_nW_n/>ojRojP;oYko[0ol00002ojRo
jPOoYko[00?oZ;oZojNojonW_n/03OnW_n/8ojJoj`KoYl3/00?oY/3/ojS0jonX`>/02onX`>/00ol0
003oZ<3[ojS0j`08ojS0j`ooYl3[5_ooool00ol0003oooooooooo`0Xooooo`007Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo02oooooo00?oYl3[ojS0jonX`>/01_nX`>/6ojO0ja7o
Yko[2_nW`>/?ojO1k0goYko[0_nW`>/5ojNojPOoYko[3onX_nX2ojS0j`koZ;oZ0ol00006ojRojPCo
Yko[1?nX_nX?ojNoj`SoY[o[0_nW`>`5ojK0k0coZ<3[00?o0000ojS0jonX`>/02?nX`>/?ojO0jaOo
oooo00?o0000ooooooooool09oooool001gooooo0_l0000?ooooo`03o`000?oooooooooo02_ooooo
1OnW`>/8ojS0j`;oYl3[5OnW_n/6ojO0j`ooYl7/3onW_n/9ojNojPCoYko[3_nX_nX6ojS0j`[oZ;oZ
00?oZ;o[o`000?l000000_nX_n/8ojRojP03ojNojonX_n[oZ;oZ00GoZ;oZ1_nW_n/00onX_n[oYko[
ojNoj`06ojNoj`KoY[o[00?oYko[ojK0k?nV`>`01_nV`>`6ojS0j`;oYl3/1?nX`>/00ol0003oZ<3[
ojS0j`08ojS0j`ooYl3[5_ooool00ol0003oooooooooo`0Wooooo`007Oooool00ol0003ooooooooo
o`0?ooooo`;o0000:?ooool9ojO0j`KoZ<3[0_nW`>/GojNoj`;oYl3[3onW`N`?ojNoj`goYkoZ00?o
Yko[ojRoj_nX_nX03?nX_nX00onX`NcoZ<3[ojS0j`06ojS0j`KoZ;oZ00CoZ<7/o`000?l0003o0000
1OnX_n/6ojRojP;oZ<3[2?nX_nX2ojNoj`GoZ;oZ2?nW_n/2ojJoj`GoYko[2?nV`>`2ojS0j`KoYl3/
1?nX`>/00ol0003oZ<3[ojS0j`08ojS0j`KoYl3[00?oZ<3[ojO0jonW`>/01_nW`>/Fooooo`03o`00
0?oooooooooo02Kooooo000Mooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool08_oo
ool=ojO0j`;oZ<3[1_nW`>/EojNoj`ooYl7/3onW_n/?ojNojP?oZ<3[2_nX_nX5ojS1k0SoZ<3[0_nX
_nX01OnX`Nco0000o`000?l0003oZ<7/00SoZ;o[0_nX_nX6ojS0j`KoZ;oZ00?oZ<3[ojRoj_nX_nX0
1_nX_nX6ojNoj`03ojRojonW_n_oYko[00KoYko[1_nV`>`2ojNoj`SoYl3/1?nX`>/00ol0003oZ<3[
ojS0j`08ojS0j`;oYl3[1OnX`>/8ojO0jaKooooo00?o0000ooooooooool09Oooool001gooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0Nooooo`ooYl3[0_nX`>/8ojO0ja;oYko[3_nW
`N`?ojNoj`ooYkoZ1onX`>/6ojRojPWoZ<7/1_nX`>/01?nW`>co0000o`000?l00005ojS1k0KoZ;o[
0_nX`N`8ojS0j`;oZ;oZ1OnX`>/8ojRojP;oYko[1OnX_n/8ojNoj`;oY/3/1_nW_n/6ojO0k003ojK0
k?nX`>_oZ<3[00;oZ<3[00?o0000ojS0jonX`>/04?nX`>/7ojO0jaKooooo0_l0000Vooooo`007?oo
ool3o`0001Cooooo00?o0000ooooooooool06_ooool?ojO0j`KoZ<3[2?nW`>/@ojNoj`goYl7/00?o
Yl3[ojNojonW_n/03?nW_n/?ojNojP[oZ<3[0_nX_nX=ojS1k0;oZ<3[00GoYl3/o`000?l0003o0000
ojO0k008ojS1k0;oZ;o[1_nX`N`6ojS0j`03ojO1k?nX`>_oZ<3[00KoZ<3[1_nX_nX00onX`>_oZ;o[
ojRoj`06ojRoj`KoYko[0_nX_n/8ojNoj`;oYl3/1OnV`>`4ojS0j`03o`000?nX`>_oZ<3[013oZ<3[
1onW`>/Dooooo`03o`000?oooooo000002Kooooo000Looooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool05oooool2ojNoj`goYl3[2OnX`>/6ojO0j`ooYko[3?nW`N`5ojO0j`[oYko[3onW
_nX<ojS0j`03ojO0k?nX`NcoZ<7/00coZ<7/00CoYkgZo`000?l0003o00001OnW`>`6ojS1k0;oY[kZ
2?nX`N`2ojS0j`GoYl7/2?nX`>/2ojRojPGoZ<3[2?nX_n/2ojNoj`KoZ;o[1onW_n/8ojK0k0CoZ<3[
00?o0000ojS0jonW`>/03onX`>/8ojO0jaKooooo00?o0000ooooooooool08oooool000[ooooo1?l0
00002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^1_ooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo01Cooooo1OnW_n/9ojO0j`goZ<3[0_nW`>/?ojNoj`coYl7/00?oZ<3[ojO0
jonW`>/01_nW`>/6ojNoj`ooYkoZ0_nW`>/:ojS0j`GoYl3/2_nX`N`01OnW_N[o0000o`000?l0003o
YkgZ00SoYl3/0_nX`N`6ojJnjPKoZ<7/00?oY[cYojO1k?nW`N`01_nW`N`6ojS0j`03ojO1k?nX`>_o
Z<3[00KoZ<3[1_nX_n/00onX`>[oZ;o[ojRoj`07ojRoj`OoYko[2?nV`>`2ojS0j`03ojO0jol0003o
Yl3[00;oYl3[3onX`>/8ojO0jaGooooo00?o0000ooooooooool08oooool000cooooo00?o0000oooo
ooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`0Aooooo`SoYko[1OnW`>/?ojS0j`ooYko[0onW`>/9ojO1k0GoZ<3[2?nW`>/2
ojNoj`ooYkoZ1_nW`>/6ojS0j`03ojNojonW`>coYl3/00KoYl3/1_nX`N`01?nW^^Oo0000o`000?l0
0005ojNmjPKoYl3/00?oYk[VojJnj_nV_^X01onV_^X2ojS1k0GoY[cY2?nW`N`2ojS0j`GoYl7/2?nX
`>/2ojRoj`GoZ<3Z2?nX_n/8ojNoj`KoY/3/00?oY[o[ojO0jonW`>/00_nW`>/01?l0003oYl3[ojO0
jonW`>/>ojS0j`SoYl3[5_ooool00ol0003oooooooooo`0Rooooo`0000?oooooo`000?l000001?l0
0005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`;o0000
6Oooool00ol0003oooooooooo`0>ooooo`_oYko[00?oYl3[ojS0jonX`>/03OnX`>/?ojNoj`OoYl3[
1OnW`N`2ojS1j`OoZ<3[1_nW`>/2ojNoj`goYkoZ0_nW`>`8ojO0j`;oZ<3[1OnW_n/8ojO0k0;oZ<7/
0_nW^^L2o`000003ojNjionW_N[oYkgZ00KoYkgZ0_nW`>`5ojNjiPOoY[kZ00?oZKSTojJljOnV_>T0
1_nV_>T6ojO1k003ojNljOnW`NcoYl7/00KoYl7/1_nX`>/00onX`NcoZ<3ZojS0jP06ojS0jPSoZ;o[
2?nW_n/2ojK0k0GoY[o[1?nW`>/01?l0003oYl3[ojO0jonW`>/>ojS0j`SoYl3[5_ooool00ol0003o
ooooooooo`0Qooooo`003?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
00001_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00[ooooo3OnW_n/00onW`>_o
Z<3[ojS0j`0<ojS0j`03ojO0jonW_n_oYko[00koYko[2?nW`>/00onW`NcoZ<7[ojS1j`04ojS1j`Oo
Z<3[0_nW`>/6ojNoj`WoYkoZ1_nW`>`6ojO0j`;oYkkZ1onW_n/6ojO0k003ojNgi?nW^^Oo000000;o
00001?nW^^L6ojNmjP03ojVeh_nW^^KoYk[V00KoYk[V1?nV_^X4ojVhi0SoY[cY0_nW`N`5ojNlj@So
Yl7/0_nX`>/5ojS1k0SoZ<3Z2?nX_n/6ojNoj`03ojS0jonV_n_oY[o[00GoY[o[1OnW`>/00ol0003o
Yl3/ojO0k00?ojS0j`SoYl3[5Oooool00ol0003oooooooooo`0Qooooo`003?ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo00Oooooo0onW`>/9ojNoj`GoYl3[2_nX`>/5ojO0ja3oYko[1_nW`>/00onX`Nco
Z<7[ojS1j`06ojS1j`GoZ<3[2_nW_n/5ojNojP?oYl3[1onW`>`2ojO0j`KoYkkZ1onW_n/2ojO0k0;o
YkOT0ol00008ojNji`;oYkgZ1OnY]N88ojNjiP03ojJnj_nY^>CoZKST00GoZKST1_nV_>T00onZ^>?o
YkcYojNlj@06ojNlj@KoYl7/00?oY[kZojS1k?nX`N`01_nX`N`6ojS0jP;oZ<7[2?nX_n/2ojNoj`Go
Z<3[1onV_n/2ojO0j`;oYl3/00Co0000ojO0k?nW`>coYl3/3onX`>/7ojO0jaKooooo00?o0000oooo
ooooool08?ooool000cooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@
00Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`03ooooo`OoYl3[1OnW_n/9ojO0
j`SoZ<3[1onW`>/@ojNoj`;oYl3[1OnX`N`8ojS1j`03ojS0jonW_n_oYko[00coYko[00?oYkoZojO0
jonW`>/01OnW`>/5ojO0k0[oYkkZ1OnW_n/2ojReh`?o00001?nW]n@6ojNji`03ojV_g?nY]N;oZKGR
00KoZKGR1_nW^^H00on[/=coZKSTojVhi007ojVhi0;oY[cY1OnZ^><8ojNlj@;oYl7/1OnV_^X8ojS1
k0;oZ<3Z1_nX`N/6ojRoj`SoZ<3[1_nV_n/00onW_n_oYl3/ojO0k003ojO0k003o`000?nW`>coYl3/
013oZ<3[1onW`>/Fooooo`03o`000?oooooooooo01oooooo000<ooooo`03o`000?oooooooooo00;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o00007_ooool00ol0003oooooojO0j`0:ojO0
j`03ojNojonW`>_oYl3[00_oYl3[2?nX`>/7ojO0j`koYko[2OnX`N`6ojS1ja7oYko[2?nW`>/00onW
`>coYkkZojNnjP0<ojNnjP03ojNojonX]N?oZ;GS00?o000000?oZ;GSojNgi?nW]n@01OnW]n@2ojNj
i`GoZJoL2?nY]N82ojNjiPGoZk3L1onY^>@00on][mWoZ[SSojZhh`06ojZhh`KoYkcY00?oZkWTojJn
j_nV_^X01_nV_^X6ojS1k0;oY[o[2?nX`N/2ojRoj`coZ<3[0_nV_n/5ojNoj`GoYl3/00?o0000ojO0
k?nW`>`03onX`>/8ojO0jaGooooo00?o0000ooooooooool07oooool000[ooooo00?oEEEEofIVI_l0
00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool07?ooool=ojO0
j`;oYko[3?nW`>/:ojS0j`GoYl3[3?nW_n/=ojS1k0;oZ<7[5OnW_n/6ojO0j`03ojNojonW_^[oYkkZ
00coYkkZ00CoYkCRo`000?l0003o00001OnX]N<5ojNgi003ojRYeonY[mcoZJoL00KoZJoL1_nY]N80
0on[ZMGoZk3Loj^`g006oj^`g0CoZKST1?n][mT8ojZhh`;oYkcY1On[^N@8ojJnjP;oZ<7/1_nV_n/6
ojS1j`03ojO1k?nX`>_oZ<3[00coZ<3[2?nW_n/5ojO0k003o`000?nV_ncoY[o/00ooZ<3[2?nW`>/E
ooooo`03o`000?oooooooooo01kooooo000Kooooo`03o`000?oooooooooo01[ooooo0onX`>/9ojO0
j`KoYko[2?nW`>/>ojS0j`03ojO0jonW_n_oYko[00[oYko[0_nW`>/=ojS1k1WoYko[0_nW`>/5ojNo
j`[oYkkZ00GoYkCRo`000?l0003o0000ojNdhP08ojReh`03ojNgi?nXZMOoZ:WG00?oZ:WG2?nY[m`2
ojVehPGoZjWE2?n[/=`00onY^>Co[JoIojf_f@05ojf_f@KoZ[SS00?o[k7Joj^ii?n[^N@01_n[^N@6
ojJnjP;oZK_W2?nV_n/2ojS1j`GoYl7/3_nX`>/8ojNoj`;oYl3/0_nV_n`01?l0003oY[o/ojJok?nV
_n`6ojS0j`03ojO0jonX`>_oZ<3[00KoZ<3[1onW`>/Fooooo`03o`000?oooooooooo01gooooo000K
ooooo`03o`000?oooooooooo01Oooooo1onX`>/5ojO0j`[oYko[1OnW`>/?ojS0j`_oYko[1_nW`>/9
ojS1k1_oYko[00?oZ<3[ojNojonW_n/01_nW_n/6ojNnjP04ojNdh_l0003o0000o`0000GoYkCR1_nX
]N<00onWY]GoZ:WGojRYe`05ojRYe`KoZJoL00?o[JOBoj^YeOn[ZMD01_n[ZMD6oj^`g003ok6[don]
[mWo[JoI00Ko[JoI1?nZ^><4ojnafPSoZkWT0_nV_^X6ojVki`KoY[o[00?oYkgZojO1k?nW`N`01OnW
`N`6ojS0j`03ojW0jonX`>_oZ<3[00KoZ<3[1_nW_n/2ojO0j`CoY[o/00Co0000ojJok?nV_ncoY[o/
0_nX`>/5ojO0j`SoZ<3[1onW`>/Dooooo`;o00007oooool001_ooooo0_l0000Fooooo`?oYl3[1onX
`>/00onW`>_oYko[ojNoj`0<ojNoj`03ojO0jonX`>_oZ<3[00goZ<3[3_nW_n/7ojO0j`KoZ<7/00?o
Z<3[ojNojonW_n/05onW_n/5ojS0j`SoYko[0_nW_^X2ojNdhP;o00002?nW]>84ojReh`CoYjKE1onX
ZML3ojV_g0Co[JOB1on[ZMD4oj^`g0Co/J_C2?n][mT00onZ^>?o[k7JojnafP05ojnafPKoZkWT00?o
[kGMojVkionY^nL01onY^nL2ojJoj`GoYkgZ1onW`N`2ojS0j`GoZL3[2?nX`>/2ojNoj`KoYl3[1?nV
_n`00ol0003oY[o/ojJok008ojO0j`OoZ<3[1onW`>/Fooooo`03o`000?oooooooooo01cooooo000J
ooooo`03o`000?oooooooooo01?ooooo1onW`>/5ojS0j`;oYl3[3OnW_n/00onW`>_oZ<3[ojS0j`0;
ojS0j`?oYl3[3onW_n/7ojO0j`;oZ<7/1OnX`>/EojNoj`;oZ<7/1onX`>/6ojNoj`03ojJehonW]>;o
000000;o00002onW]>800onX]N?oYjKEojNVe@04ojNVe@SoZ:WG00?oZJoLojfWd_n]Ym800on]Ym88
oj^Ye@03oj^`g?naZm?o/J_C00Go/J_C1_n][mT00one[m?o[k7JojnafP07ojnafP;oZkWT1On_]Md7
ojVki`03ojjkhonW_N[oYkgZ00GoYkgZ1_nW`N`00onV_ncoZL3[ojW0j`06ojW0j`SoZ<3[2?nW`>/4
ojJok003o`000?nV_ncoY[o/00SoYl3[1onX`>/7ojO0jaGooooo00?o0000ooooooooool07?ooool0
01[ooooo00?o0000ooooooooool03oooool<ojO0j`03ojS0jonW`>_oYl3[00CoYl3[2OnW_n/5ojO0
j`WoZ<3[1onW`>/?ojNoj`GoYl3[0_nX`N/7ojS0ja7oYko[1_nX`N`7ojS0j`;oYko[0_nV]N<3o`00
00goYkCR00?oYZCDojNVeOnWY]D01_nWY]D6ojRYe`So[JOB1_n[ZMD00onc[=;o/J_Cok6[d`06ok6[
d`Co[JoI1?ne[m<7ojnafP03okNbe?n_]Mgo[kGM00Ko[kGM1?nY^nL4ojjkh`OoYkgZ0_nW`N`5ojJo
k0SoZL3[2?nX`>/7ojO0j`CoY[o/00?o0000ojJok?nV_n`02?nW`>/7ojS0j`KoYl3[0_nX`>/Eoooo
o`03o`000?oooooooooo01_ooooo000Jooooo`03o`000?oooooooooo00_ooooo3onW`>/00onX`>_o
Yl3[ojO0j`06ojO0j`SoYko[1_nW`>/9ojS0j`OoYl3[3onW_n/00onW`>_oZ<7[ojS1j`04ojS1j`Oo
Z<3[3_nW_n/00onW`NcoZ<7/ojS1k006ojS1k0GoZ<3[0_nV]nD3o`0000CoY[GS2OnW]>85ojJTe0Oo
YjKE1?nXZML:ojfWdPCoZjWE1?nc[=88ok6[d`03ojf_fOne[m?o]JoC00Go]JoC1On_/MX3okNbe0So
[kGM00?oZK_Wojjkhon^^n<01?n^^n<6ojNmjP;oZ[gX1onV_n`6ojW0j`;oZ<7[2?nX`>/7ojO0j`Co
Y[o/00?o0000ojJok?nV_n`02?nW`>/7ojS0j`;oYl3[1_nX`>/Eooooo`03o`000?oooooooooo00Ko
oooo1Ol0000?ooooo`006_ooool2o`0000Wooooo3onW`>/5ojS0j`SoYl3[2?nW_n/6ojO0j`WoZ<3[
1OnW`>/?ojNoj`;oZ<7/1onX`N/5ojS0j`coYko[1OnW`N`8ojS1k003ojS0jonV]nGoY[OU00?o0000
00?oY[OUojJehonV]N<01?nV]N<6ojNdhP03ojBTeOnVY=CoYZCD00KoYZCD1onWY]D00onXZMOo[JOB
ojfWdP0;ojfWdP03oj^YeOnc[=;o/jcB00Go/jcB1_naZm<00onh/]?o]JoCokF_d`06okF_d`?o[k7J
1_ng/]@6ojneg@03okJef?n^^n?o[[_S00Ko[[_S0_nW_NX6ojZmj0OoY[o/0_nY`>/6ojS1j`OoZ<3[
1onW`>/5ojJok003o`000?nV_n_oYl3[00OoYl3[4?nX`>/Dooooo`03o`000?oooooooooo00Kooooo
00GoV9RHob4Q8Oo^k^koooooodA4A00?ooooo`006_ooool00ol0003oooooooooo`06ooooo`koYl3[
2OnX`>/6ojO0j`[oYko[0onW`>/<ojS0j`03ojO0jonW_n_oYko[00goYko[1_nX`N`7ojS1j`03ojS0
jonW_n_oYko[00coYko[1onW`N`6ojS1k004ojNjiol0003o0000o`0000GoY[OU1_nV]N<2ojNdhPGo
Y:CE1onVY=@6ojNVe@03oj^Wdon]Ym;o[JOB00_o[JOB00?o/ZoEok>/d_nc[=801_nc[=84ok6[d`Co
^;;C2?ne[m<00on_/M[o]k;DokNbe005okNbe0Co[kGM1?nf]MP6ojjkh`03ok:ig_nZ_NSoZ[gX00Oo
Z[gX0onV_n`4ojJoj`SoZ<7[1onX`>/7ojO0j`;oY[o/0_nV_n/00ol0003oY[o[ojJoj`08ojO0j`oo
Z<3[5Oooool00ol0003oooooooooo`06ooooo`03oiRHV?lQ8B7ok^k^013ooooo000Jooooo`03o`00
0?oooooooooo00?ooooo3_nW`>/=ojS0j`;oYl3[3?nW_n/2ojO0j`goZ<3[00?oYl3[ojNojonW_n/0
2onW_n/3ojO0j`OoZ<7/0onX`N/CojNoj`OoYl7/0_nX`N`01OnW^^Oo0000o`000?l0003oYk[W00So
Y[OU0onV]N<2oj>TePSoY:CE1onVY=@2ojNVe@GoZjOC2_n]Ym84ok:_e@So/jcB00?o/J_CokRbdonh
/]<01Onh/]<6okF_d`03ok^fe?ng/]Co]k;D00Oo]k;D00?o[kGMokJef?nf]MP01Onf]MP3ojjkh`Co
/[WN1onZ_NP00on^_^KoY[o[ojJoj`06ojJoj`KoZ<7[2?nX`>/6ojO0j`;oZ<3[1?nV_n/00ol0003o
Y[o[ojJoj`08ojO0j`ooZ<3[5Oooool00ol0003oooooooooo`06ooooo`03oiRHV?lQ8B7ok^k^00oo
oooo000Jooooo`03o`000?oooooooooo017oYl3[3?nX`>/3ojO0j`WoYko[1_nW`>/9ojS0j`GoYl3[
2OnW_n/7ojO0j`GoZ<7/0_nX`>/FojNoj`GoYl7/00CoYkgYo`000?l0003o00001OnW^^L6ojJgi@03
oj:WfOnSY=KoXjCF00CoXjCF1onTY=D6ojJTe003ojRVeOn[Ym?oZjOC00GoZjOC2On]Ym86ok:_e@Ko
/jcB00?o]kWKokRbdonh/]<01_nh/]<4okF_d`Co^kKD1ong/]@00onn^=Co][GHokJef007okJef003
ojjkhonb^Mko/[WN00Co/[WN1?nZ_NP4ojjniPSoY[o[0_nX`N/<ojS0j`;oYl3[1_nX`>/4ojJoj`03
o`000?nV_n_oY[o[00SoYl3[3_nX`>/Eooooo`03o`000?oooooooooo00Oooooo00?oMgMgofIVI_oo
ool03_ooool001Wooooo00?o0000ojO0jonW`>/04onW`>/8ojS0j`OoYl3[1_nW_n/9ojO0j`OoZ<3[
1onW`>/8ojNoj`SoYl3[00?oZ<7/ojS0jonX`>/01?nX`>/FojNoj`03ojO1k?nW_NWo000000;o0000
0_nW_NT7ojNji`;oY[OU1OnRYmT6oj>TePOoY:CE0_nVY=@5ojRVe@OoZjOC1_n]Ym800on`]=_o/ZoE
ok:_e@06ok:_e@?o/jcB1?ng^M/8okRbd`03okF_donk]]Co^kKD00Go^kKD1Ong/]@3okjhe0Oo][GH
00?o_[[Fok:ig_nb^Mh01_nb^Mh00onZ_NSo[[kVojjniP05ojjniPKoY[o[00?oYko[ojS0jonX`>/0
5OnX`>/4ojJoj`03o`000?nV_n_oY[o[00SoYl3[3_nX`>/Eooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool03Oooool001Wooooo00?o0000ojO0jonW`>/05?nW`>/8ojS0j`OoYl3[0_nW
_n/=ojO0j`OoZ<3[1onW`>/8ojNoj`KoYl3[00?oZ<7[ojS0jonX`>/01_nX`>/DojNoj`03ojS1jol0
003o000000KoYkgY1OnW^^L00onR[=koXZOIoj:Wf@05oj:Wf@OoXjCF1OnTY=D00onUYMKoZ:KEojRV
e@05ojRVe@OoZjOC1?n]Ym84ok2df`So/ZoE00?o/jcBokNifong^M/01?ng^M/6okRbd`03okZog_nk
]]Co^kKD00Ko^kKD0ong/]@6okjhe0Go][GH0onn^]H6ok:igP03okVlg?n^_^Ko[[kV00Oo[[kV0_nV
_n/5ojNojaKoZ<3[1?nV_n/01?l0003oY[o[ojJojonV_n/7ojO0j`goZ<3[0_nW`>/Cooooo`?o0000
1?ooool01Ol0003o^[ZjoooooonHV9So410@00oooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01_ooool00ol0003oooooojO0j`0EojO0j`SoZ<3[1OnW`>/2ojNoj`goYl3[2OnX`>/5ojO0j`[o
Yko[0_nW`>/5ojS1j`SoZ<3[4?nW_n/01OnX`N_o0000o`000?l0003oZ<7[00SoYkgY00?oYk[Woj:/
g_nR[=h00onR[=h7oj:Wf@OoXjCF00?oY:CEojFUe_nUYMH00onUYMH7ojRVe@OoZjOC00?o[JOBok2d
fon`]=/01On`]=/6ok:_e@03ok?=kOng^M_o]kWK00Go]kWK1?nh/]<4okZogPSo^kKD00?o]k;Dokjh
e?nn^=@01Onn^=@3okJef0Ko_[[F0onb^Mh4okVlg0Oo[[kV00?o/L3UojNojonW_n/01_nW_n/6ojS0
j`03ojO0jonX`>_oZ<3[00goZ<3[1?nV_n/01?l0003oY[o[ojJojonV_n/7ojO0j`WoZ<3[1_nW`>/D
ooooo`03o`000?oooooooooo00;ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00?ooooo`003_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool05?nW`>/:ojS0j`03ojO0jonW
_n_oYko[00CoYko[2OnW`>/=ojS0j`03ojO0jonW_n_oYko[00[oYko[2OnX`N/6ojS0j`koYko[00Co
Z<7/o`000?l0003o00001OnX`N/6ojNmj@03oj>ci?nR[=koXZcN00GoXZcN1_nRYmT6oj>TeP03oj6S
e_nUYMKoYJGF00GoYJGF1_nXY]D6oj^Wd`03ojjki?n`]=_o/;CK00Ko/;CK1?nb[mD4ok?=k@Oo]kWK
00?o^;;CokZog_nj_mh01Onj_mh6ok^fe003okg0g?nn^=Co_[SD00Oo_[SD00?o][GHokjje_nn^]H0
1_nn^]H00onb^Mko^KcLokVlg004okVlg0Co[[kV1?na`>D8ojNoj`;oZ<3[1OnW`>/6ojS0j`03ojW0
jonX`>_oZ<3[00KoZ<3[1?nV_n/00ol0003oY[o[ojJoj`07ojO0j`SoZ<3[2?nW`>/Dooooo`03o`00
0?oooooooooo01Gooooo000>ooooo`05oa0@4?ooooooooooooooool@41001_ooool2o`0000;ooooo
4?nW`>/<ojS0j`;oYl3[1onW_n/8ojO0j`coZ<3[2onW_n/=ojS1j`;oZ<3[3_nW_n/01?nX`Nco0000
o`000?l00003ojS1k0KoZ<7[0_nW_NT5oj>ci0KoXZcN1onRYmT2oj>TePGoXJ?F1_nUYMH7ojRVe@;o
ZjOC1On^^n@8ok2df`03ok:_eOnccNgo/lg]00Go/lg]1Ong^M/2ojkLm`Oo^[oN1?nk]]@4okg0g0Oo
_[SD00?o`;kHokjje_nn^]H01_nn^]H00oo2_mOo^KcLokVlg006okVlg003ojjni_na`>Go/L3U00Go
/L3U1_nW_n/00onX`>[oYl3[ojO0j`06ojO0j`;oZ<3[1OnY`>/8ojS0j`CoY[o[00?o0000ojJojonV
_n/01onW`>/8ojS0j`OoYl3[5Oooool00ol0003oooooooooo`0Dooooo`003_ooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool00oooool?ojO0j`SoZ<3[1_nW`>/7ojNoj`So
Yl3[2?nX`>/>ojNoj`coZ<7[0onW`>/<ojNoj`?o00001onX`N`3ojS1j`;oYKWW2?nS/n@6oj:/gP?o
XZOI0onMX=H7oj6SePOoYJGF1OnXY]D00on[`N[o[[_Tojjki006ojjki0Ko/;CK0_nSh?`7ok?=k@?o
]kWK1On^g?L7okZogP03ok^fe?nm`=co_L3L00Go_L3L1?nn^=@4ol2nf0Ko_[[F0oo2_mL6okVlg0;o
_l7K2?na`>D2ojNoj`GoZ<3Z1onW`>/8ojW0j`OoZ<3[1?nV_n/00ol0003oY[o[ojJoj`08ojO0j`So
Z<3[1onW`>/Dooooo`03o`000?oooooooooo01Cooooo000>ooooo`05o`000?ooooooooooooooool0
00001Oooool00ol0003oooooooooo`05ooooo`ooYl3[1onX`>/7ojO0j`GoYko[2_nW`>/3ojS0j`Co
Yl3[3onW_n/8ojS1j`OoYl3[2?nW_n/3o`0000?oYko[1_nX`N`00onW_^[oYKWWojFii`04ojFii`Oo
Xk?T1OnR[=h00onJWmOoWJ3FoifPeP05oifPePOoXJ?F1onUYMH00onXY]GoZl7Zoj_1jP03oj_1jPSo
[[_T0_n`]=/6oj?Po0Oo/lg]00?o]kWKojkLmon^g?L01On^g?L5okZogP03ojgKmonm`=co_L3L00Oo
_L3L00?o_[SDol2nf?o0_]P01Oo0_]P3okjjePGo`[oG1?ni_=`5oko1f`Ko/L3U00?o/l;UojS0j_nX
`>X01_nX`>X7ojO0j`SoZL3[1onX`>/4ojJoj`03o`000?nV_n_oY[o[00SoYl3[1onX`>/7ojO0jaGo
oooo00?o0000ooooooooool04oooool000kooooo00Go410@oooooooooooooooooa0@4005ooooo`03
o`000?oooooooooo00Kooooo3onW`>/7ojS0j`OoYl3[00?oYko[ojO0jonW`>/02_nW`>/2ojS0j`Oo
Yl3[3onW_n/7ojS1j`SoYl3[1?nW_n/3o`0000OoYko[0_nX`N`5ojNnjPKoYKWW1onS/n@00onR[=ko
VYoGoiZOe`03oiZOe`KoWJ3F1onQXmH6ojFUeP03ojNojon[`N[oZl7Z00GoZl7Z1_n^^n@3ohORnPOo
Xn3l0onccNd5ofkGm`Oo[]cg00?o^[oNojgKmon]foL00on]foL7okg0g003okOAk_o0_]So`;kH00Oo
`;kH00?o_[[Fol:oeoo2_mL01Oo2_mL00oni_=co_l7Koko1f`06oko1f`;o/L3U1Onc`^D6ojS0jP03
ojW1jonW`>_oYl3[00KoYl3[1_nY`>/00onY`N_oZ<3[ojS0j`06ojS0j`CoY[o[00?o0000ojJojonV
_n/02?nW`>/7ojS0j`OoYl3[5Oooool00ol0003oooooooooo`0Booooo`003_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_l00008ooooo`goYl3[2OnX`>/5ojO0j`?oYko[2?nW`>/6ojS0j`Oo
Yl3[3onW_n/7ojS1j`KoYl3[0_nW_n/3o`0000WoYko[0_nX`N/7ojNnjPKoYKWW0onS/n@3oiZRfPOo
VYoG1_nMX=H7oj6SeP;oYJGF1OnW_n/7oj_1jP;o[[_T1on7h_X3oj?Po0Ko;kS>1_m^eoL3ojkLm`?o
C/Ga1on]foL4okg0g0Co]m7^1oo0_]P00onnaMoo`[oGol:oe`05ol:oe`03olC3fOno`M_o_l7K00Ko
_l7K00?o`lGKok?2iOnc`^D01_nc`^D2ojS0jPGoZL7[2?nW`>/2ojW0j`GoZL7[1onX`>/4ojJoj`04
o`000?nV_n_oY[o[ojJoj`OoYl3[1onX`>/7ojO0jaGooooo00?o0000ooooooooool04_ooool000ko
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo00Sooooo2OnW`>/=ojS0
j`03ojO0jonW_n_oYko[00GoYko[1onW`>/7ojS0j`GoYl3[3onW_n/9ojS1j`;oYl3[0onW_n/2o`00
00WoYko[1_nX`N/7ojNnjP?oYKWW0_nNZn07oiZRfPKoVYoG1_nMX=H6oj6SeP;oY;SW1onW_n/5oj_1
jPCoO>7d1?n7h_X3ogcHoP?oA/7/1?nH_o<7ofBgo003o`JAeol3U[[o0iJj00CoC/Ga1on]foL00onm
`=co]m7^okOAkP05okOAkPCo`;kH1?nnaMl5ol:oe`?oa<?I1_no`M/3ol?5f`Ko/l;U00?o]LGVojW1
jonY`N/01_nY`N/6ojO0j`03ojNojonY`N_oZL7[00KoZL7[1onX`>/4ojJoj`04o`000?nV_n_oY[o[
ojJoj`OoYl3[1onX`>/7ojO0jaGooooo00?o0000ooooooooool04Oooool001Sooooo00?o0000oooo
ooooool02Oooool8ojO0j`[oZ<3[1?nW`>/8ojNoj`OoYl3[1onX`>/00onW`>_oYko[ojNoj`0=ojNo
j`_oZ<7[0_nW`>/01?nW_n_o0000o`000?l00009ojNoj`;oYl3[1onX`N/5ojNnjP03oj6ei_nNZn3o
WZ_P00CoWZ_P1onJX]X6oiZOe`KoWJ3F0_nQXmH6ojBhi`OoYko[00?oZl7ZogcQm?mlhO@00omlhO@2
oc6h^@KoO=Sn0_nS^^T7oiRol`?oI;Ol1?nK]NX3oej[n@;o1Y7G00?o08o9odk5lOn]foL00_n]foL4
ofC7o@So]m7^00?o`;kHokk5gonnaMl01OnnaMl3ol:oe`Goa<?I0ono`M/6ol?5f`?o/l;U1?neaNH8
ojW1j`;oYl3[1OnW_n/6ojW1j`03ojS1jonX`>_oZ<3[00KoZ<3[1?nV_n/00ol0003oY[o[ojJoj`07
ojO0j`OoZ<3[2?nW`>/Eooooo`03o`000?oooooooooo013ooooo000Hooooo`03o`000?oooooooooo
00[ooooo2?nW`>/7ojS0j`OoYl3[1_nW_n/9ojO0j`GoZ<3[0onW`>/>ojNoj`SoZ<7[0onW`>/3o`00
00WoYko[1_nW`>/7ojS1j`03ojNnj_nQ]NKoXKGV00?oXKGV1_nNZn06oiZRfPOoVYoG0onMX=H3oin^
h@SoY;SW0onW_n/5ohKVmP;oDLg61OnHhod2ogcHoPKoXk[Y1OnH_o<00onX[]goVkGZoi^ejP06oi^e
jPOoGZ_i00?o07oDo`2?bOmTaod01?mTaod6okOAkP03oiK?nonnaMoo_/GO00Oo_/GO00?o`[oGolC3
fOo4`mT01Oo4`mT00ono`M_o`lGKol?5f`06ol?5f`03ok?2iOneaNKo]LGV00Co]LGV2?nY`N/7ojNo
j`;oZL7[1OnX`N/8ojS0j`CoY[o[00?o0000ojJojonV_n/01onW`>/7ojS0j`OoYl3[5Oooool2o`00
017ooooo000Gooooo`?o00003Oooool7ojO0j`OoZ<3[1onW`>/2ojNoj`goYl3[00?oZ<3[ojO0jonW
`>/01OnW`>/>ojNoj`OoZ<7[0ol00004ojO0j`GoYko[0onV_n/7ojO0j`?oZ<7[0onU_>X7oj6eiPKo
WZ_P1_nJX]X3oiZOe`?oVZGM1onO[^46ojBhi`CoV>Wj0_n6i_H01?mfhmSoYnkhojO^n?nWk_P5oiSS
o@;oZ;cX2?nS^^T00onH_o?oZ:kMojR^g@03ojR^g@SoVkGZ0omNZoT3oi6fl0;o<93_0_l0Om@2ob:P
j@;oI<Om0_ngdNh5oiK?n`Oo_/GO00?o^LWWolC3fOo4`mT01Oo4`mT00oo4a]_o`lGKol?5f`06ol?5
f`03olK9gOneaNKo]LGV00Ko]LGV2?nY`N/6ojNoj`SoZ<7[1_nX`>/00onW`>_oY[o[ojJoj`02ojJo
j`03o`000?nV_n_oY[o[00KoYl3[2OnX`>/7ojO0ja?ooooo00?o0000ooooool000004Oooool001Oo
oooo00?o0000ooooooooool03_ooool5ojO0j`WoZ<3[5?nW`>/2ojS0j`SoYl3[3_nW_n/3ojS1j`?o
000000?oZ<7[ojO0jonW`>/01OnW`>/00onW_n_oY[o[ojJoj`05ojJoj`GoYl3[0_nX`N/6ojFljPKo
XKGV1onNZn03oiZRfP;oUIoK1onJYMd7oin^h@?oY;SW1OnHjOX2ogKSf0KoYnkh00?oV>?mojRlj?nX
_>P01?nX_>P6oj>jj@03oj^^f_nX[]goZ:kM00GoZ:kM1_nK]NX2ojfdgPKoTKK`1?l`T>l5ob:Pj@Ko
U/ok1?nnaMl4okW9i`Goa<?I0oo4a]/6ol?5f`?oa/WM1_neaNH2okG7i`SoZL7[1_nW_n/8ojS1j`;o
Z<3[1OnW`>/4ojJoj`03o`000?nV_n_oY[o[00;oYl3[3?nX`>/8ojO0jaCooooo00?o0000oooooooo
ool03oooool001Oooooo00?o0000ooooooooool03oooool00onW`>_oZ<3[ojS0j`0;ojS0ja3oYl3[
1_nX`>/6ojO0j`koYko[00CoZ<7[o`000?l0003o00001OnX`N/5ojO0j`;oYko[2?nV_n/00onW`>_o
Z<7[ojS1j`04ojS1j`KoYKcZ1_nQ]NH3oij[h0?oTYkL1_nEWm/7oiZUg@OoWjkQ00CoY;SWoiSYn_nH
jO[oV>Wj0omfhmP7ojO^n0;o[<K]1onX_>P2oj>jj@GoZjkJ1onX[]d2oi^ejPKo[KCN1_nA]_05oc2@
k`;o38KS0_lRX>T6oiK?n`03okk5gonibNOo^LWW00Co^LWW0oo4`mT6olC6f`?o`lGK1_o6bMd2okG5
iPKo]LOW1_nY`N/00onX`N_oYko[ojNoj`05ojNoj`OoZ<7[2?nW`>/4ojJoj`03o`000?nV_n_oY[o[
00koZ<3[2?nW`>/Dooooo`03o`000?oooooooooo00kooooo000Gooooo`03o`000?oooooooooo013o
oooo3?nX`>/AojO0j`OoZ<3[0_nW`>/>ojNoj`04ojS1jol0003o0000o`0000WoZ<7[00?oYl3[ojNo
jonW_n/01?nW_n/6ojJoj`03ojO0jonX`N_oZ<7[00KoZ<7[1_nU_>X3oj6eiP;oUZGP1onBW]`6oiFO
f`KoVZGM1_nO[^43ojCPo0?oVo;Z1?n^n>`2ojO^n0Ko[<K]1OnX_>P00onV[=_oZjkJoj^^fP06oj^^
fPGoZ:kM00?o];[Mojfdg_n]]=h01on]]=h3oi6fl0?oX[WY0omLXO@2oc2@k`Co38KS1_m/^O`7okW9
i`03olC3fOo4a]_oa<KK00Koa<KK00?o`lGKolK9gOo6bMd01?o6bMd00oo7c]oo]LOWokG7i`07okG7
i`;oZL7[1OnX`N/7ojNoj`OoZ<7[1onW`>/5ojJoj`03o`000?nV_n_oY[o[00koZ<3[1onW`>/Eoooo
o`03o`000?oooooooooo00gooooo000Gooooo`;o00004_ooool8ojS0jaGoYl3[1onX`>/=ojNoj`?o
00002OnX`N/4ojO0j`OoYko[0_nV_n/5ojO0j`SoZ<7[0onU_>X2oifci`KoUZGP1onBW]`5oiFOf`Oo
VZGM0_nO[^44ojCPo0?oVo;Z1On^n>`2okCFl@So[<K]00?oZ;cXojJ/fonV[=/00onV[=/7oj^^fP?o
Z:kM1?nd^]d7ojfdgP03okVngOnR^NWoX[WY00GoX[WY1_mLXO@00olEO^Ko38KSo`b6h`06ofbio0Go
^LWW00?o[lO[olC6foo4a]/01_o4a]/2olG9gPGoa/WM0oo7c]l7okG7i`03okC8jOnX`N_oZ<7[00Ko
Z<7[0onW_n/4ojRoj`OoZ<7[1onW`>/4ojJoj`04o`000?nV_n_oY[o[ojJoj`koZ<3[1onW`>/Doooo
o`03o`000?oooooooooo00gooooo000Gooooo`03o`000?oooooooooo01;ooooo2?nX`>/EojO0j`Oo
Z<3[2_nW_n/2o`0000?oYko[1onX`N/7ojO0j`GoYko[0_nV_n/7ojO0j`KoZ<7[00?oY;cZoifcionM
/nL01?nM/nL6oiJUh0KoTYkL1_nEWm/3oiZUg@KoX/Oc00?oY>3loi_bj_nKl^X00_nKl^X3ojkhk0Ko
]=Ka1_n/a^d00onR[=koYZcKojJ/f`05ojJ/f`OoZjkJ00?oZ:kMokBjgOnd^]d01?nd^]d4ojfdgPCo
^KkM1onR^NT6oebQm0?o5GkV1_m/^O`00onibNOo[lO[ojo7j`03ojo7j`Koa<KK1?o5bMh3olK9g@Go
alkO1?neanL4okC8j@KoZ<7[00?oYl3/ojRojonX_n/01_nX_n/7ojS1j`OoYl3[1?nV_n/00ol0003o
Y[o[ojNoj`0>ojS0j`SoYl3[5?ooool00ol0003oooooooooo`0<ooooo`005oooool00ol0003ooooo
ooooo`0Cooooo`SoZ<3[4onW`>/9ojS0j`KoYko[0ol00006ojNoj`OoZ<7[1onW`>/00onW_n_oY[o[
ojJoj`04ojJoj`OoYl3[0_nX`N/5ojBljPKoWK?W1_nFYN06oi:Ng0?oUIoK1?nK[nD6oj;7l`Co/o7e
0onmnnT3olS^kPKo]=Ka0_n/a^d5oj:/gPKoYZcK1_n[[]X00on`_nGo];[MokBjg@06okBjg@03ojfd
g_ni_]go^KkM00Go^KkM1OnR^NT2ojc1j@GoLJSc0olYONL2oaEniPCoFJGg1on_an/3olC6f`OoaLWN
00?oa/WMolO>goo7c]l01Oo7c]l00oneanOo]<SYokC8j@05okC8j@;oZ<7[1OnW`>`8ojRoj`OoZ<7[
1onW`>/2ojJoj`;oYko[00?o0000ojNojonW_n/03_nX`>/6ojO0j`03ojNojooooooooooo01?ooooo
00?o0000ooooooooool02oooool001Oooooo00?o0000ooooooooool05Oooool7ojS0j`ooYl3[3OnX
`>/2ojNoj`?o00002?nW_n/2ojS0j`OoZ<7[1OnW`>/3ojNoj`KoY[o[1OnW`>/3ojS1j`KoY;cZ1_nM
/nL6oiJUh0?oTYkL0_nBX^08oi^_i@?oX/Oc1OnclOD3okgkj@Gob>k^0onde_42ojJii`SoXZcN1_nV
[=/2oj^^fPGo/;oU1_nd^]d00onc`nKo^KkMokVng@07okVng@03oj:ijOn/`NWo[<7Y00Co[<7Y1Oma
Z?<5obUmi`CoFJGg1on_an/00oo4a]_oaLWNolG9gP05olG9gP03olG<goo7c]ooalkO00GoalkO0_o6
dN86okC8j@03ok78jonW`>coYl3/00KoYl3/1_nX_n/9ojS1j`KoYl3[1OnW_n/00ol0003oYko[ojNo
j`0>ojS0j`;oYl3[1OnW_n/Dooooo`03o`000?oooooooooo00_ooooo000Fooooo`?o00005oooool5
ojS0ja7oYl3[2_nX`>/01?nW`>_o0000o`000?l00008ojNoj`KoZ<3[1onX`N/00onW`>_oYko[ojNo
j`05ojNoj`KoY[o[00?oYl3[ojS1jonX`N/01OnX`N/6ojBljP?oWK?W0_n>Y><6ohbMg`KoTZ;P2?nK
[nD00onRao?o/o7eok?am@02ok?am@?o_O_Y1_o8k^h00ondcngoY[WWojJii`04ojJii`OoXZcN1OnV
[=/00onW_>So/;oUok2oi@06ok2oi@?o];[M1?nc`nH7okVng@;o_LKQ1on/`NT5og6Xl`Co:GgW0omI
Vo42oeVUm`Go[lO[0_nX`N/6olG9gP?oaLcO1?o7c]l5olKAhP?o]<SY1?nab>/8ojO0k0;oZ;o[2onX
`N/00onX`>_oYl3[ojO0j`05ojO0j`CoYko[00?o0000ojNojonW_n/03OnX`>/00onW`>_oYko[ojNo
j`06ojNojaCooooo00?o0000ooooooooool02_ooool001Kooooo00?o0000ooooooooool06?ooool0
0onX`>_oYl3[ojO0j`0CojO0j`KoZ<3[00CoYl3[o`000?l0003o00001?nW`>/7ojNoj`OoZ<3[1OnX
`N/2ojO0j`SoYko[0onV_n/3ojNoj`SoZ<7[0onT_>X2oi^dj@KoSZCS1_n<WMl6oi:Rh0KoVjoU1?nc
g?D01?nclOGo_O_YokgkjOnmnnT5olS^kPCo]<o]1_nV^NL7oj:/gP03ojJ/fonW_>SoYkcX00?oYkcX
2?n`_nD00ond^]go/l?Vok?3iP04ok?3iPCo^KkM1Onma^45ojc1j@03ojc6kOmdYO3oM:G`00;oM:G`
0_maZ?<4obUmi`GoFI_a00?o[lO[ojS1jonX`N/01?nX`N/3olG9gPKoaLcO00?oalkOolKAh_o6dN80
1_o6dN800ondb>Wo/LS[ok78j`04ok78j`KoYl3/00?oY[o/ojS1jonX`N/02?nX`N/5ojS0j`OoYl3[
1?nW_n/00ol0003oYko[ojNoj`09ojS0j`GoYl3[1onW_n/Cooooo`?o00002oooool000Cooooo1?l0
00002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^1_ooool00ol0003oooooooooo`0Joooo
oaGoYl3[0onX`>/3o`0000SoYl3[1onW_n/7ojS0j`03ojS1jonW`>_oYl3[00CoYl3[1_nW_n/00onV
_n_oYko[ojNoj`05ojNoj`KoZ<7[00?oY;g[oi^djOnK]>T01?nK]>T6ohjTh`KoS9gO1OnBX^04oi^_
i@Go/mce0oo6lNh4om?diP;ob>k^1_ndcnd6ojJii`?oXZcN1?nO/^H6ojNlj0Ko/;oU0_nXaNh7ok?3
iP03okVngOnma^7o_LKQ00Ko_LKQ00?o[<7Yojc6kOn/a^d00on/a^d5ogBUl0?o?GkU0_lYONL4oeVK
l@SoZ<7[00?oaLWNolG<goo5c=l01?o5c=l2olO@h@Ooa]7R00?oa=CVok78jonab>/01_nab>/2ojO0
k0GoY[o/1_nX`N/00onY`N_oZ<3[ojS0j`05ojS0j`KoYl3[0_nV_n/4ojNoj`03o`000?nW_n_oZ<3[
00OoZ<3[1onW`>/7ojNoj`oooooo0ol00002ooooo`03o`000?oooooooooo00Wooooo0006ooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo
01_ooooo4onW`>/01?nX`>_o0000o`000?l00004ojS0j`KoYl3[2OnW_n/3ojS0j`CoZ<7[1onW`>/2
ojNoj`GoY[o[1onW_n/2ojS1j`GoY;g[1_nK]>T5ohjTh`KoS9gO1_nBX^000onK[nGo/mceok?Lm@04
ok?Lm@?oa_7^1OoCm>H3olkWj0Ko]<o]0onV^NL2oiN/i@SoWk;V1_nW_>P2ok2oi@KoZ<G^1Onc`nH2
oj_1j@Oo_LKQ00?o_/kVojc6kOn/a^d01On/a^d5ogBUl0Go?GkU1?mIVo46ojS1j`;oZ;gX1Oo5c=l4
olO@h@Coa]7R1?o4e>H6ok78j`;o[/K/1onV_n`2ojS1j`GoZL7[1onX`>/2ojO0j`KoY[o[0onW_n/0
0ol0003oYko[ojNoj`08ojS0j`KoYl3[2?nW_n/;ooooo`?o00001Oooool00ol0003oooooooooo`09
ooooo`001_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool2
o`0001gooooo3onW`>/01?nX`>_o0000o`000?l00008ojS0j`;oYl3[2onW_n/2ojS0j`OoZ<7[1OnW
`>/3ojNoj`KoY[o[1OnW_n/3ojW1j`KoY;g[1OnK]>T6ohjTh`KoS9gO0onBX^04oijfj@Co/mce0oo6
lNh5om?diPGoc^OX0ondcnd2oj2lk0KoUjcU2?nO/^H3ojNlj0?oYlG_2?nXaNh00onc`nKoZl7Yoj_1
j@04oj_1j@Co_LKQ1?nnc^H7ojc6k@GoM:G`1?lmO^D4of>Gk003oeVKlOnX`N_oZ<7[00KoZ;gX0oo5
c=l6olO@h@03olKAh_o4e>Koa=CV00Goa=CV0_nab>/6ojk6k0GoY[o/0_nV_n/7ojW1j`OoZ<3[2?nV
_n/3ojNoj`03o`000?nX`>_oZ<3[00SoZ<3[1_nW`>/8ojNoj`Kooooo1?l00008ooooo`03o`000?oo
oooooooo00Wooooo0006ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0005ooooo`;o00007oooool=ojO0j`;o00002OnX`>/4ojO0j`SoYko[1_nX`>/7ojS1j`03ojO0jonW
_n_oYko[00GoYko[1_nV_n/00onW_n_oZL7[ojW1j`05ojW1j`KoY;g[1OnK]>T3ohjTh`;oQYgS1_n>
Y><9oijfj@04ok?LmOo6lNkoa_7^olKakPCodoCV1_o>inP00onkd>[oX;c/oj2lk004oj2lk0KoUjcU
1_nO/^H2ojNoj`KoYlG_1_nXaNh2oj:nk@OoZl7Y00?o_LKQokk>i_nnc^H01Onnc^H3ojc6k@?oX[k^
1?m]VN/2ogBUl0Co?GkU1OmSUn`8ojRmj003olG<goo7d>7oam3Q00Coam3Q0_o9e^<6olCDiP;o_MC[
2?n^a^`00onV_ncoY[o[ojJoj`04ojJoj`OoZL7[1onX`>/7ojJoj`CoZ<3[00?o0000ojS0jonX`>/0
1onX`>/7ojO0j`OoYko[0oooool3o`0000gooooo00?o0000ooooooooool02?ooool000Kooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0
7oooool9ojO0j`?o00000_nW`>/7ojS0j`OoYl3[2?nW_n/6ojS0j`GoZ<7[0onX`>/7ojNoj`?oY[o[
0onW_n/8ojW1j`?oY;g[0_nK]n/5oh^Wj0KoQYgS1_n>Y><7oijfj@?o`=g^1?oAi^H00ooCm>Koc^OX
olkWj003olkWj0Co^m3Z1_nP_>`6oiN/i@;oWk;V1_nW_n/6ojO5k`;oZ<G^1_nR_^d5oj_1j@;oZl;Z
1_nnc^H2okgEk0KoX[k^1Om]VN/2oe9oh0;o?GkU1_mSUn`6ojRmj0;o[koV1Oo7d>44olWFh`?oa=CV
1Onme>/6ojk6k003oj[3k?nV_n_oY[o[00KoY[o[0onY`N/3ojS1j`SoZ<3[1onV_n/4ojS0j`03o`00
0?nX`>_oZ<3[00OoZ<3[1onW`>/7ojNoj`;o00004?ooool00ol0003oooooooooo`08ooooo`001_oo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003ooooo
ooooo`0Pooooo`GoYl3[0ol00006ojO0j`OoZ<3[1onW`>/8ojNoj`KoZ<3[00?oZ<7[ojS0jonX`>/0
1OnX`>/5ojNoj`03ojJojonW_n_oYko[00GoYko[1_nY`N/00onU_ncoVkO[oi^gj`04oi^gj`GoRjOX
1_n6WN<6ohjTh`CoW[KY1?o0gNh5om7ViP?of^KN00?oc^OXok_@j_nkd>X01Onkd>X6oj2lk0?oUjcU
0onK/nT8ojNoj`?oYlG_0onW`>/8oj:nk@03oj_1jOn[`^[oZl;Z00CoZl;Z0onnc^H5okgEk0KoX[k^
1Om]VN/4oe9oh0KoHiO/0_nX_NP6ojnoiP?oam3Q1_o9e^<00oo4e>Ko_MC[okgDj`05okgDj`;o[/K/
1OnZ`n`6ojJoj`03ojNojonX`N_oZ<7[00GoZ<7[1_nX`>/00onW`>_oY[o[ojJoj`05ojJoj`CoZ<3[
00?o0000ojS0jonX`>/02?nX`>/3ojO0j`_oYko[4Oooool00ol0003oooooooooo`08ooooo`001_oo
ool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2o`0002;ooooo
00CoYl3[o`000?l0003o00002onW`>/6ojS0j`SoYl3[1onW_n/3ojS0j`?oZ<7[2?nX`>/00onW_n_o
Y[o[ojJoj`03ojJoj`OoYko[0_nY`N/5ojFok0KoVkO[1On;YnP6ohJMh`KoSZCS00?oW[KYol3Mk_o0
gNh00oo0gNh5om7ViPCof^KN00?oemcKok_@j_nkd>X01_nkd>X3oj2lk0;oS[7^1onK/nT6ojNoj`03
ojg1jOnW`>_oYl3[00GoYl3[1_nR_^d00onR^NWoZl;Zoj_2jP06oj_2jP03okk>i_nmeNco_MG/00Go
_MG/1_nR_^h4offIj`CoDWoP1_mbV>L9ojnoiP03olO@hOo9e^?obMKS00CobMKS0_o:fnH6okgDj`03
okG=k?nZ`ncoZ/?/00KoZ/?/0_nV_n/5ojNoj`OoZ<7[0_nX`>/5ojO0j`OoY[o[1?nX`>/00ol0003o
Z<3[ojS0j`07ojS0j`goYko[00?oYl3[ooooooooool03oooool00ol0003oooooooooo`08ooooo`00
1?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003o
ooooooooo`0Oooooo`?o00003onW`>/6ojS0j`SoYl3[1_nW_n/7ojS1j`KoZ<3[0_nW`>/6ojJoj`Go
Yko[0onY`N/6ojFok0KoVkO[1On;YnP6ohJMh`?oSZCS1?nN]^T3ol3MkPGodNKV1?oJi]h3omOLf`Ko
^m3Z0_n]aN/5ohjakPOoVk?Y0_nW_n/5ojg1j@OoYl3[0_nR_^d5oj:ij@KoZl;Z0onccnh5okgEk003
ojk8kOnD[NSoU:gX00CoU:gX1?mYQM`00om]VN_oDWoPoe9oh002oe9oh0KoLYSW1on__nH00onibNOo
bMKSolWFh`04olWFh`Cob]_V0_nme>/5okG=k0KoZ/?/0_nW`>`6ojNoj`SoZ<7[1onW`>/3ojJoj`?o
Yko[1OnX`>/00ol0003oZ<3[ojS0j`07ojS0j`WoYko[1OnW`>/@ooooo`03o`000?oooooooooo00So
oooo000Eooooo`03o`000?oooooooooo01cooooo0ol00004ooooo`ooYl3[0onX`>/;ojO0j`KoYko[
1onX`N/2ojS0j`KoYl3[1_nV_n/00onW_n_oZL7[ojW1j`05ojW1j`KoYKo/0onK]n/2ohf_k@GoOikW
1_n8XnH8oijfj@03ol3Mk_oAi^KodNKV00?odNKV1?oJi]h5omOLf`;o^m3Z1_n]aN/5ohjakPGoVk?Y
00?oXkk/ojg1jOn]`NT01_n]`NT5ojO0j`;oZ;_W1onR^NT3oj_2jPKo/lo^00?o_MG/ojk8kOn^b>d0
0on^b>d6oiB]j0CoJHGL0omVQ=`2oe9oh0KoLYSW1?n__nH4okW9i`?obMKS1Oo:fnH2olONjPOo]Lg/
0_nZ`n`6ojO0k0KoYko[2?nX`N/5ojO0j`SoYko[1OnX`>/00ol0003oZ<3[ojS0j`06ojS0j`OoYko[
2?nW`>/?ooooo`03o`000?oooooooooo00Sooooo000Eooooo`03o`000?oooooooooo01Wooooo0ol0
0008ooooo`goYl3[00?oZ<3[ojO0jonW`>/02onW`>/8ojNoj`SoZ<7[1onW`>/7ojJoj`OoZL7[0onU
_n`3oinkk@GoSJo]1OmoW^L6ohRSiPKoW[KY1?nodNP2om7ViPCof^KN1OoGg=/2olkBg0So[LG[1On>
/Nh00onK/nWoXkk/oj>nk003oj>nk0So[L7Y00?oYl3[ojRkionX^nL01?nX^nL7oj:ij@03oj_2j_nc
cnko/lo^00Co/lo^0_ngf_86ojk8k@KoU:gX1?mYQM`5ofJ4g0KoLYSW00?o[koVokW9ionibNL01Oni
bNL00oo9e^?ob]_Vol[KiP03ol[KiPCoamkZ1OnecN`2ojo8k@SoYl3/0onW_n/;ojS1j`03ojO0jonW
_n_oYko[00[oYko[1?nX`>/00ol0003oZ<3[ojS0j`07ojS0j`OoYko[1_nW`>/00onX`>_ooooooooo
o`0=ooooo`03o`000?oooooooooo00Sooooo000Eooooo`03o`000?oooooooooo01Kooooo0ol0000=
ooooo`SoYl3[1OnX`>/9ojO0j`coYko[2?nX`N/5ojO0j`03ojNojonV_n_oY[o[00KoY[o[1OnY`N/2
ojS1j`KoWk_]1On=[nd5ognNi`KoR:?V0onN]^T6okoAj0CocmSP00?of^KNomOLfooGg=/00ooGg=/4
olkBg0Ko[LG[0_nS_^`5ohNcl`KoXkk/1_n]`NT2ojg2j@OoZ;_W0onR^NT4ojS3k@Co/lo^1Ongf_86
ojk8k@GoU:gX1OmYQM`4ofJ4g0OoQZ3U1_nibNL3ol;Dj0?ob]_V1_o7g^X00onecNco[lS]ojo8k@04
ojo8k@KoYl3/00?oY[k[ojS1jonX`N/02onX`N/00onX`>_oYko[ojNoj`0:ojNoj`KoZ<3[00?o0000
ojS0jonX`>/00onX`>/4ojO0j`OoYko[0_nW`>/5ojS0j`oooooo00?o0000ooooooooool01oooool0
01Cooooo0_l0000Eooooo`?o00004Oooool7ojO0j`KoZ<3[2?nW`>/:ojNoj`CoZ<3[1onX`N/00onW
`>_oYko[ojNoj`03ojNoj`SoY[o[00?oZL7[ojS1jonX`N/01?nX`N/6oinkk@CoSJo]1_moW^L6ohRS
iP03oijfjOnodNSo_m7X00Co_m7X1?o?f>03omKEf0?oemcK1_o>d]`2ojg5j`KoXkk/1On7/o<6oj>n
k0;o[L7Y1_n]`^T5ojRki`;oYl?^1onX`nd00onccnko]m[bokOJlP06okOJlP?o[/S]0_nLZn44oh6?
f0;oU:gX1?mYQM`5ofJ4g0OoQZ3U0onibNL6ol;Dj003ol[Ki_o7g^[oamkZ00CoamkZ00?o_=S^ojo8
kOn_b>d01_n_b>d2ojO0k0GoY[k[2OnX`N/5ojS0j`SoYko[2_nX`>/00ol0003oZ<3[ojS0j`07ojO0
j`OoYko[1onX`>/>ooooo`03o`000?oooooooooo00Oooooo000Dooooo`03o`000?oooooooooo01;o
oooo0_l0000Eooooo`OoYl3[1_nX`>/8ojO0j`OoYko[1onX`>/5ojS1j`;oZ<3[1_nW_n/6ojJoj`;o
Yko[1onX`N/3oinkk@?oUkO^0omlY>`00on=[ngoOikWognNi`04ognNi`?oR:?V1?nF/>T3okoAj0Go
cmSP1OoFeMP00ooGg=_oc];LolkBg004olkBg0;oa/KJ2?nS_^`5ohNcl`?oXkk/0onRa_88ojg2j@03
ojRkionW`nkoYl?^00CoYl?^1OnX`nd3ojkLm`Ko]m[b00?oZK_Voib[hOnLZn401?nLZn45oh6?f0Co
Kh7D00?oJHGLofJ4g?mVQ=`00omVQ=`7ohJPi@03okW9ioo2e>So`]CX00Co`]CX0_o7g^T4olONjPCo
_=S^1_n_b>d2ojW3k0KoY[k[1onX`N/8ojS0j`?oYko[0onV_n/<ojS0j`03o`000?nX`>_oZ<3[00Oo
Yl3[1onW_n/6ojS0j`kooooo00?o0000ooooooooool01oooool001Cooooo00?o0000ooooooooool0
3oooool3o`0001Sooooo1onW`>/7ojS0j`OoYl3[1onW_n/7ojS0j`03ojS1jonX`>_oZ<3[00CoZ<3[
1_nW_n/2ojJoj`KoYko[1OnX`N/00onT_ncoUkO^oiNgkP05oiNgkPCoO:C/1OmnXNT8oiJ`j@03okoA
j?o?f>3ocmSP00?ocmSP1_oFeMP00ooGcm7oc];LolkBg003olkBg0Coa/KJ1_nS_^`2oj>jj@GoQ;Sg
1_nRa_86ojg2j@;oYL_c1onW`nh00onX`ngo[]cgojkLm`05ojkLm`;o]m[b1OnY^nH5oib[h@KoPHoH
1?m_PM@4ogZ?g0;oIXCL0on6X>D4oijai@Co`]CX1Oo7g^T00oo7g^[o_=S^okcHkP05okcHkP;o[lS]
1_nY`n`6ojJnj`OoZ<7[1_nX`>/00onW`>_oY[o[ojJoj`05ojJoj`_oZ<3[00Co0000ojS0jonX`>_o
Z<3[0onW`>/;ojNoj`KoZ<3[3Oooool00ol0003oooooooooo`07ooooo`005?ooool00ol0003ooooo
ooooo`0<ooooo`?o00007?ooool5ojO0j`WoZ<3[2?nW`>/6ojNoj`GoZ<3[0_nX`N/7ojS0j`?oYko[
1?nV_n/7ojNoj`03ojS1jonT_ncoY;o/00?oY;o/1onG]nh4ogbTk0GoOZ7Y1_nF/>T3ok2oi@?ocmSP
1ooFeMP2omO?d@?oc];L1_o6a]X2oj>nk0KoXk[Y1On4^?L6oj;6lP;o[L;Y1_nUbo<5ojO3kP?oXMSk
1On^g?L2ojg5k0KoZK_V1_nLZn45oh6?f0GoKh7D1OmjSm`8oijai@03ol;Dj?o7g^WoamkY00CoamkY
0oo7i>`5okcHkP;o//g^2?nY`n`3ojJnj`[oZ<7[0_nX`>/5ojO0j`OoY[o[2onX`>/00ol0003oZ<3[
ojO0j`0=ojNoj`03ojO0jonX`>_oZ<3[00GoZ<3[3?ooool00ol0003oooooooooo`07ooooo`004ooo
ool3o`0000[ooooo0ol0000Pooooo`03ojO0jonX`>_oZ<3[00_oZ<3[2?nW`>/6ojNoj`03ojS0jonX
`N_oZ<7[00CoZ<7[1OnX`>/3ojO0j`KoY[o[1OnW_n/2ojS0j`KoY;o/1onG]nh4ogbTk0GoOZ7Y0onF
/>T6ok2oi@03oloHh?oFeMSoe]GH00Goe]GH1?oGcm400oo>d]coa/KJolK6fP04olK6fP;o`[cD2?nS
^^T5ohBhm`?oX/Kb1?nCb_X7ojG;l`03ojO3k_nQf?_oXMSk00GoXMSk00?o[]cgojg5k?n]aN`01?n]
aN`6ojVkiPGoW:_Q1On1SmP6ofn1e0GoNXoL1_nN/ND2okK>k0GoamkY1Oo7i>`00onlf>ko//g^ok;=
kP04ok;=kPKoZL?/00?oY[o[ojS1jonX`N/03?nX`N/7ojO0j`?oY[o[0onW_n/:ojS0j`;oYl3[00?o
0000ojO0jonW`>/02OnW_n/5ojO0j`OoZ<3[2oooool00ol0003oooooooooo`07ooooo`005?ooool0
0ol0003oooooooooo`06ooooo`?o00009Oooool>ojS0j`OoYl3[1_nW_n/7ojS1j`03ojS0jonW`>_o
Yl3[00GoYl3[1_nV_n/00onW_n_oZ<3[ojS0j`04ojS0j`KoY;o/0onG]nh3ohVal0CoLj3]00?oO:C/
ogjQjOmnXNT00omnXNT00onF/>Wo/;oUok2oi@04ok2oi@?o`lWO1OoFeMP5omO?d@03omC7cOo6a][o
a/KJ00?oa/KJ1?o2_=@6oj>jj@;o[;KP1_n<]o<6oi?:nP?oYL_c1?nEdO`6oj7Hn`;oYlC^1on]aN`3
ojVkiP;oW9WA1?n;Rlh2oib[h@GoPHoH1Om_PM@6ogZ?g0?oW[7U1Onfc^`3olONj@GoanC/00?o_mo_
ok;=k_nbcNh01_nbcNh2ojW3k0GoY[o[3_nX`N/5ojO0j`SoYko[1onX`>/4ojO0j`03o`000?nW`>_o
Yl3[00OoYko[2?nW`>/6ojS0j`_ooooo00?o0000ooooooooool01oooool001Cooooo00?o0000oooo
ooooool00oooool3o`0002Wooooo3_nX`>/5ojO0j`SoYko[2?nX`N/7ojO0j`KoY[o[1onX`>/3ojBo
k0CoX;g]1On9/O04og>Pk@KoQJS/1On`_nD5ol?9g`?oe]GH1OoGcm43omC7c@?oa/KJ1_o2_=@2oj>j
j@Ko[;KP1_n<]o<3oi?:nPCoTKke1_nEdO`2oj7Hn`KoYlC^1On]aN`00onRXM?oW9WAoibId@04oibI
d@GoRh_>1?mnQ<h00on1SmSoKh7Dofn1e004ofn1e0KoNXoL00?oW[7UokK>k?nfc^`01Onfc^`00oo7
g^WoanC/olOTk002olOTk0Co_mo_1_nbcNh00on[aNcoY[o[ojJoj`06ojJoj`koZ<7[00?oYl3[ojNo
jonW_n/02_nW_n/7ojS0j`CoYl3[00?o0000ojO0jonW`>/01onW_n/6ojO0j`SoZ<3[2oooool00ol0
003oooooooooo`06ooooo`004oooool01?l0003oooooooooooooool3o`0002gooooo3_nX`>/00onW
`>_oYko[ojNoj`0:ojNoj`SoZ<7[1OnW`>/00onW_n_oY[o[ojJoj`05ojJoj`GoZ<3[0onY`N/6oj2m
k@GoRK7`1?mcX>d6ohFXk0?o/;oU1oo3bMl00ooFeMSoeloAomO?d@03omO?d@Goe<O=00?oa/KJol:l
e?o2_=@01?o2_=@00oo3]Lgo[;KPojbfh007ojbfh0?oS;Oc0onQ/^@7oi6nm@?oUM7l0onR^NT8ojO4
kP03ojg5k?nRXM?oXZ7C00?oXZ7C1OnLVM46oh^;cPCoOXC>1_mnRmH6ohnQh@Oo]/k/0oo2h>h00oo7
i>co_mo_okoOk`05okoOk`;o//g^1On[aN`6ojJoj`03ojO0jonX`N_oZ<7[00_oZ<7[00?oYl3[ojNo
jonW_n/02_nW_n/9ojS0j`?oYl3[00?oYko[o`000?nW_n/02?nW_n/2ojO0j`coZ<3[2_ooool00ol0
003oooooooooo`06ooooo`004oooool4o`00037ooooo3?nX`>/2ojO0j`[oYko[0onX`>/8ojS1j`03
ojO0jonW_n_oYko[00?oYko[1onV_n/00onX`>_oZL7[ojW1j`05ojW1j`KoX;g]1On9/O04og>Pk@Ko
QJS/00?o/;oUol?9goo3bMl01Oo3bMl3ol_:fP?oeloA1_oDald00ooA`L[o`[cDol:le003ol:le0?o
`kG=1on/]^000onbZ]3oXK;Toj6bi005oj6bi0GoTKke0_nV[mh6oj:ij@KoYlC^00?oYJ;Boj:QdonR
XM<01?nRXM<6oibId@GoRh_>1OmnQ<h6ogj;ePKoSj7Q1?nfc^`4ol;PkP?oa>S`1Onognl2ok;?k`Oo
ZlG/0_nV_n/5ojO0j`WoZ<7[1OnW`>/8ojNoj`goZ<3[1?nW_n/00ol0003oYko[ojNoj`05ojNoj`03
ojO0jonX`>_oZ<3[00WoZ<3[0onW`>/:ooooo`03o`000?oooooooooo00Kooooo000Cooooo`;o0000
=?ooool8ojS0j`KoYl3[1onW_n/6ojS0j`KoZ<7[0_nX`>/6ojNoj`OoY[o[2?nY`N/3oj2mk@?oVk__
1?mk[?84og2Rl004og>PkOn5Z>coQJS/ohFXk0?oT;7]1_o3bMl5ol_:fP03omO?dOoDalgoe<O=00Co
e<O=0ooA`LX3ol:le0Go`kG=1?n/]^04ok:Zd0OoXK;T00?oTKkeojJ_g_nV[mh01?nV[mh6oj:ij@;o
YlC^1OnUX]86oj:Qd`GoW9WA1_n;Rlh5ogj4cPKoOX_F1_n?XN400onfc^co`^3^ol;PkP03ol;PkPGo
a>S`00?o_mo_ok;?konbcnl01?nbcnl5oj_5k0;oYko[1onW`>/6ojS1j`SoYl3[1_nW_n/?ojS0j`?o
Yko[00?o0000ojNojonW_n/00_nW_n/5ojO0j`OoZ<3[1onW`>/9ooooo`03o`000?oooooooooo00Ko
oooo0005o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo03;o
oooo1onX`>/7ojO0j`OoYko[1_nX`>/2ojS1j`KoZ<3[1_nW_n/7ojJoj`KoZL7[0_nX`>/6oi^kk`Co
Njcb1Om`X_06oi2ak@?o`lWO1_o;b]X2olc7ePGoe<O=1OoA`LX00oo2_=Co`kG=ol>ec@05ol>ec@03
ojbfh?nbZ]3o/Z[@00Go/Z[@1OnQ/^@00on]Y<ooYZoNojJ_gP06ojJ_gP?oX[WY0_nWWlh7ojFRdPKo
XZ7C1OnLVM46oh^;cPGoOXC>1_mnRmH5ohnQh@?o[l_^0oo2h>h5olCXl003okgQlOnbcnoo//o_00Ko
//o_00?oZlG/ojNojonW_n/01?nW_n/5ojO0j`03ojS1k?nX`N_oZ<7[00GoZ<7[1_nW`>/8ojNoj`Ko
Z<3[00?oZ<7[ojS0jonX`>/01_nX`>/3ojNoj`03o`000?nW_n_oYko[00OoYl3[1onX`>/7ojO0j`So
oooo00?o0000ooooooooool01_ooool00005oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Wooooo00?o0000ooooooooool0<oooool6ojS0j`OoYl3[1onW_n/>ojS0
j`?oYko[0onV_n`7ojJoj`;oZL7[1_nX`>/6oi^kk`CoNjcb1Om`X_06oi2ak@03ol?9goo;b][obl[J
00Cobl[J1?o<amH3omC7c@KodL7:2?o3]Ld9ok:Zd003oj6bi?n]Y<oo[JC?00?o[JC?1_nV[mh00onZ
VlOoYio>ojNOcP04ojNOcPKoYJ;B1onRXM<5oibId@KoRh_>1OmnQ<h6ogj;eP03ohnQhOn_bnko[l_^
00Go[l_^00?o`^3^olCXl?o4j?000_o4j?04okgQl@Ko//o_00?oZlG]ojNojonW_n/01_nW_n/00onW
`>_oZ<7/ojS1k003ojS1k0OoZ<7[0_nW`>/<ojNoj`;oZ<3[1OnX`N/6ojS0j`03ojO0jonW_n_oYko[
00;oYko[00?o0000ojNojonW_n/01OnW`>/8ojS0j`KoYl3[00?oYko[ooooooooool01_ooool00ol0
003oooooooooo`06ooooo`0000CooooooiRHV?lQ8B7ok^k^1?ooool01Ol@413ooooooooooooooooo
410@00[ooooo00?o0000ooooooooool0<oooool6ojS0j`OoYl3[1onW_n/>ojS0j`KoY[o/1OnV_n/3
ojNoj`OoZ<3[0onK^nl2oiNjl0CoL:Wd00?oNjcbog2Rl?m`X_000om`X_03oi2ak@?oW[[]1Oo;b]X6
olc7eP03omC7cOoA`L[odL7:00GodL7:00?oc[c9ol>ecOo3]Ld01?o3]Ld2olF`aPOo/Z[@00?o^ZK5
ojfTcon]Y<l01On]Y<l3ojJ_gPCoZY_71_nWWlh6ojFRdP?oXZ7C0onKS/H5oi>;b0KoRh[=1On:TM@6
oi2Qh0Oo[l_^0onmi?800oo4j?3o_N7aokgQl@05okgQl@;o//o_1On[aNd6ojNoj`03ojO0jonX`Nco
Z<7/00GoZ<7/1OnX`N/2ojO0j`[oYko[0onX`>/8ojS1j`;oZ<3[1OnW`>/4ojNoj`04o`000?nW_n_o
Yko[ojO0j`coZ<3[0_nW`>/5ojNoj`Oooooo00?o0000ooooooooool01_ooool000;ooooo00?oV9RH
ob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000_ooooo0_l0000dooooo`KoZ<3[1onW
`>/7ojNoj`koZ<3[1_nV_n`00onV_n_oYko[ojNoj`05ojNoj`GoZ<3[0_nV`>`5oiNjl0GoL:Wd1Om_
Y_86oijjk@?obl[J1oo<amH7om71bP?oc[c91?o3]Ld4olF`aPGo/Z[@0onjY/D7ojfTc`03ojJ_g_nZ
VlOoZY_700?oZY_71_nWWlh5ojFRdP03oj:Ba?nKS/KoVhk600GoVhk61OnCRlP6oh^:c@GoRY7D1_n@
XN04ojo;kPCo_NCb0onnk?<5okgQl@?o/<k_1_n[aNd2ojNoj`GoYl3[1onX`N`00onX`N_oYl3[ojO0
j`04ojO0j`OoYko[1_nX`>/6ojS1j`03ojS0jonW`>_oYl3[00KoYl3[0onW_n/00ol0003oYl3[ojO0
j`0:ojS0j`?oYl3[2?nW_n/7ooooo`03o`000?oooooooooo00Gooooo0003ooooo`03ogMgMomVIVKo
oooo00;ooooo00Go0000ooooooooooooooooo`00000=ooooo`03o`000?oooooooooo03;ooooo1_nX
`>/8ojO0j`KoYko[3_nX`>/7ojJok0OoYko[00?oZ<3[ojK0k?nV`>`01?nV`>`5oiNjl0GoL:Wd1Om_
Y_86oijjk@03ol_:f_o<amKoc<OF00Goc<OF0_o;a=@5om71bPCoc[c90oo3]Ld5olF`aP?o/Z[@1Onj
Y/D6ojfTc`03okFP`onZVlOoZY_700GoZY_71_nWWlh00onUX];oXY;4oj:Ba003oj:Ba0KoVhk61OnC
RlP6oh^:c@KoRY7D1_n@XN000on_bnko_NCbokgTlP02okgTlPKo_^cc00?o_N7aok3>kon`c^l01On`
c^l3oj_5k@?oYkk[1onW`>/3ojS1k0?oZ<7[2?nW`>/7ojNoj`KoZ<3[0_nX`N/5ojS0j`KoYl3[00?o
Yko[ojO0jonW`>/00_nW`>/00ol0003oYl3[ojO0j`07ojS0j`KoYl3[1onW_n/7ooooo`03o`000?oo
oooooooo00Gooooo0004ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413ooooooooo
o`0<ooooo`03o`000?oooooooooo03;ooooo1_nX`>/8ojO0j`KoYko[3?nX`>/3ojO0j`KoY[o/1OnW
_n/2ojS0j`OoY/3/1OnG^_05og2Ym0GoKjKb0onN^^d4ojK0k0Goc<OF1?o;a=@3om71bPKoc[c900?o
`kG=olF`a_o5/<H01Oo5/<H00onbZ]3o^ZK5okZVa@04okZVa@Co[JC?1?neX<<6ojZKa`GoYio>00?o
ZIO4oj:Ba?nRT/@01?nRT/@7oi^>aPGoTh_81On;R/d6ohZAe0GoT:7P1?n_do<00onmi?;o_^ccokk/
l`04okk/l`;o]mcc1_n`c^l00onY`ncoYkk[ojNnj`05ojNnj`GoYl3[0_nX`N`6ojS1j`KoYl3[2OnW
_n/3ojS0j`?oZ<7[1onX`>/2ojO0j`GoYko[1?nW`>/00ol0003oYl3[ojO0j`07ojS0j`KoYl3[1onW
_n/6ooooo`03o`000?oooooooooo00Gooooo00001Ol0003o^[ZjoooooonHV9So410@00?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0?ooooo`03o`000?oooooooooo03;ooooo1onX`>/7ojO0j`?oYko[
0onW`>/8ojS0j`OoYl3[1_nV_n`00onW_n_oZ<3[ojS0j`04ojS0j`GoY/3/0_nU_n`5oiFjl@GoJJSe
1Om^Z_D7ojK0k0?oc<OF1_o;a=@00ooA`L[oc[c9oljlb@05oljlb@SoaK362?njY/D00on]Y<oo]J33
okFP``04okFP``OoZY_700?oYio>ojVGa?nYUl@00onYUl@6oj:Ba0KoVhk61OnCRlP6oh^:c@KoRY7D
00?oT:7PojoClon_do<01?n_do<4okSZmP03okk/longg??o]mcc00Co]mcc0_n`c^l5ojW3k0OoYkk[
00?oYl3[ojS1k?nX`N`01?nX`N`6ojS1j`;oYl3[2onW_n/00onX`>_oZ<7[ojS1j`05ojS1j`GoZ<3[
00?oYl3[ojNojonW_n/01OnW_n/5ojO0j`03o`000?nX`>_oZ<3[00OoZ<3[0onW`>/:ojNoj`Gooooo
00?o0000ooooooooool01Oooool00005oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^013ooooo0_l0000dooooo`KoZ<3[3OnW`>/7ojS0j`SoYl3[1_nV_n`7ojS0j`03
ojK0k?nU_ncoYKo/00CoYKo/1OnE^_45ofVXm@GoKZ[e1onV`>`00oo<amKoblCDol_4e004ol_4e003
olS4e_o>_<Woc[c900Goc[c90_o:^//6olF`aP;oaK761onjY/D8okFP``GoZY_700?o/9g4ojVGa?nY
Ul@01?nYUl@6oj:Ba0KoVhk61_nCRlP5oh^:c@?oRY7D1OnJ/nT3ojoCl`Oo^>[f1Ongg?<2ojg9kPKo
ZL?/1_nW_^/9ojS1k0?oZ<7[0onW`>/9ojNoj`GoZ<3[1onX`N/00onX`>_oYl3[ojO0j`03ojO0j`Oo
Yko[0_nW`>/2ojS0j`03o`000?nX`>_oZ<3[00KoZ<3[00?oYl3[ojNojonW_n/02_nW_n/00onW`>_o
ooooooooo`03ooooo`03o`000?oooooooooo00Gooooo000Oooooo`03o`000?oooooooooo03;ooooo
1_nX`>/=ojO0j`OoZ<3[2?nW`>/6ojJok0OoZ<3[1onU_n`5oiFjl@GoJJSe1Om^Z_D3ojK0k0CoY/?^
1Oo;a=@3olS4ePGoc[c91?o:^//4olF`aP?oaK761_njY/D2okjZa@Oo]J330onZVlL4ok2Ma0KoZIO4
1OnRT/@7oi^>aP?oTh_80_nHVM86oiJOfPSoV[?Y00?o[m?cokSZm_nhj_H01onhj_H00ongg??o[LW^
ojg9kP04ojg9kPKoZL?/0_nW_^/;ojS1k003ojS1jonW`>_oYl3[00GoYl3[1onW_n/7ojS0j`?oZ<7[
0onX`>/7ojO0j`?oYko[1?nW`>/4ojS0j`03o`000?nX`>_oZ<3[00;oZ<3[1OnW`>/8ojNoj`GoYl3[
1?ooool00ol0003oooooooooo`05ooooo`008?ooool00ol0003oooooooooo`0booooo`?oZ<3[4OnW
`>/6ojS0j`SoYl3[1_nV_n`7ojS0j`OoYKo/1OnD^o45ofNYmPGoJJch1onV`nh3ol_4e0Gob<CF0oo>
_<T5olZjb`?oaK361Oo5/LH4okZVa@?o_Z[52?neX<<00onZVlOo/9g4ok2Ma003ok2Ma0KoZIO41_nR
T/@3oi^>aP?oWYW>1_nHVM86oiJOfPKoV[?Y0on_h_P7okSZmP;o[m7b1on]bNh3ojW3k0?oY[k[2OnX
`N`5ojS1j`OoYl3[1onW_n/5ojS0j`03ojS1jonX`>_oZ<3[00GoZ<3[1OnW`>/2ojNoj`OoYl3[1?nX
`>/00ol0003oZ<3[ojO0j`07ojO0j`GoYko[2?nW`>/3ooooo`03o`000?oooooooooo00Gooooo000Q
ooooo`03o`000?oooooooooo03;ooooo5?nW`>/7ojS0j`OoYl3[1_nV_n`7ojS0j`OoYKo/1OnD^o45
ofNYmPGoJJch1onV`nh00oo;a=Cob<CFolS4eP05olS4eP03oljlbOo:^/_ob[[;00Gob[[;00?oaK36
olFaa_o5/LH01?o5/LH3okZVa@Go_Z[51_neX<<00onhYlSo/9g4ok2Ma005ok2Ma0GoZIO41OnRT/@0
0onTW<goWYW>oijIcP05oijIcPKoV9WB1_nFWmX2oiZcj@Go[n;h1?n`kOL00onhj_Ko[m7bojoAlP04
ojoAlPGo[LW^00?oZ;o[ojJnjonV_^/01OnV_^/7ojS1k0OoZ<7[0onW`>/;ojNoj`03ojS0jonX`N_o
Z<7[00?oZ<7[1onX`>/00onW`>_oYko[ojNoj`04ojNoj`KoYl3[1?nX`>/00ol0003oZ<3[ojS0j`06
ojO0j`OoYko[1onW`>/4ooooo`03o`000?oooooooooo00Cooooo000Rooooo`03o`000?oooooooooo
03;ooooo5OnW`>/6ojS0j`OoYl3[1_nV_n`7ojS0j`OoYKo/1OnD^o45ofNYmPGoJJch0onV`nh4oi_4
m0Kob<CF00?o`lWOolZjboo:^//01Oo:^//00oo6_M;oaK76olFaaP06olFaaP03okZVaOnnZ/Go_Z[5
00Co_Z[51OneX<<3okRWb0Ko/9g41_nYUl@00onRT/CoY9c=ojBLc@03ojBLc@KoWYW>1_nHVM85oiJO
fP?oYmKh0on_h_P5ok3]m`;o/]gf1on_dO800on]bNkoZ;o[ojRoj`03ojRoj`OoY[k[1onX`N`5ojS1
j`koYko[00?oZ<3[ojS1jonX`N/01OnX`N/3ojS0j`_oYko[1_nW`>/4ojS0j`03o`000?nX`>_oZ<3[
00;oYl3[2onW_n/7ojO0j`?ooooo00?o0000ooooooooool01?ooool002?ooooo0_l0000coooooaGo
Yl3[1_nX`>/7ojO0j`KoY[o/1onX`>/5ojFok0;oY[o[1_nG^o45of^/m`CoHJgi1onKa?@3olS4ePCo
`lWO1Oo:^//3olJmdPKoaK7600?o`[G>okjZaOnnZ/D01OnnZ/D3okFP``Go^:O81_n`WL@5ojVGa003
oj^RcOnTW<goY9c=00CoY9c=1_nNVLh7oiRIdP03oiJOf_nWe_SoYmKh00GoYmKh00?o[n;hok3]mon`
kOL00_n`kOL5ok;MmP?o[m7b0onZ`n`7ojRoj`?oY[k[2onX`N`00onX`N_oYko[ojNoj`0<ojNoj`Go
Z<3[1OnX`N/2ojO0j`coYko[2?nW`>/3ojS0j`03ojO0jol0003oYl3[00_oYko[2_nW`>/2ooooo`03
o`000?oooooooooo00Cooooo000Uooooo`03o`000?oooooooooo03;ooooo5?nW`>/6ojS0j`OoYl3[
1_nV_n`7ojS0j`03ojFok?nV_n_oY[o[00CoY[o[1_nG^o45of^/m`CoHJgi1onKa?@00oo8a=Ko`lWO
ol?9g`04ol?9g`?ob[[;1Oo6_M84olFaaP?o`[G>1onnZ/D00oneX<?o^:O8okRWb004okRWb0Oo/9g4
00?oZIO4oj^RcOn[X/d00on[X/d6ojBLc@KoWYW>0onHVM84oj77l`KoYmKh0onWk?T00on`kOOo/]gf
ok;MmP04ok;MmP;oZlS_1_nZ`n`5ojRoj`;oYl3[2_nX`N`3ojS0j`goYko[2?nX`>/00onX`N_oYl3[
ojO0j`04ojO0j`SoYko[2_nW`>/2ojS0j`CoYl3[00?o0000ojO0jonW_n/01_nW_n/=ojO0j`;ooooo
00?o0000ooooooooool01?ooool002Kooooo00?o0000ooooooooool0<_oooolDojO0j`KoZ<3[1onW
`>/6ojJok0OoZ<3[1onV_n/3oiNkl@?oVkg`1Ome/_P3oeN]nP04of6]nOnKa?CoVlCdoi_4m0CoQL;k
1oo3bMl00oo:^/_oa[gBolJmdP04olJmdP?oaK761Oo2]Lh5okjZa@03okfcdOnhYlSo^:O800Ko^:O8
1On`WL@00onaZm;oZj;=oj^Rc@05oj^Rc@GoY9c=1OnNVLh2oj?0kPOoXLOc0_nWe_P5ojO/n@Co[^Gi
00?o/]gfoj_8kon[b>l01?n[b>l6oj[3k003ojRojonW`>_oYl3[00CoYl3[1onX`N`6ojS0j`goYko[
1_nX`>/00onX`N_oYl3[ojO0j`06ojO0j`GoYko[2OnW`>/6ojS0j`?oYl3[00?o0000ojO0jonW`>/0
1onW_n/=ojO0j`03ooooool0003ooooo00Gooooo000Wooooo`03o`000?oooooooooo03;ooooo5?nW
`>/6ojS0j`OoYl3[1_nV_n`7ojS0j`GoY[o[0_nX_n/6oi^ml0GoMK;h1OmG[OX6ohG2n`Go`lWO00?o
/<o`olJmd_o6_M801_o6_M800oo5/LKo`[G>ol:ecP04ol:ecP?o_Z[51?nm/m47okRWb0;o/9g41Ona
Zm86oj^Rc@KoY9c=00?oWYW>oj?0k_nS`>h01?nS`>h5oj77l`CoWnSk00?oYnciojkUnOn^iOT01?n^
iOT00on[c?7oZlS_oj_8k`06oj_8k`?oZ/?/0onW_^/7ojO0j`OoZ<7/1_nX`>/=ojNoj`;oZ<3[1OnX
`N/6ojO0j`OoYko[1onW`>/8ojS0j`?oYl3[00?o0000ojNojonW_n/01onW_n/=ojO0j`03o`000?oo
oooooooo00Cooooo000Xooooo`;o0000<ooooolDojO0j`KoZ<3[1onW`>/7ojJok0KoZ<3[00?oY[o[
ojRojonX_n/01?nX_n/6oi^ml0GoMK;h1_mG[OX5ohG2n`03ol?9gon`co3o/<o`00?o/<o`1_o6_M80
0onoc^Ko`[G>ol:ecP06ol:ecP03okjZaOnm/m7o_K?A00Co_K?A1OnhYlP00onh_Mko/J_Bok6[dP05
ok6[dPOoZj;=0onTW<d3ojO1k0OoXl3^00?oXLOcoioXnonOj?/01?nOj?/4ojCXn`03ojkUnOn[c?7o
Zlca00?oZlca1_n[b>l00onW_^[oYkk[ojNnj`05ojNnj`GoYl3[2OnX`N`3ojS0j`goYko[2_nX`N/2
ojO0j`_oYko[1onW`>/6ojS0j`03ojO0jonW_n_oYko[00;oYko[00?o0000ojNojonW_n/01OnW_n/<
ojO0j`;ooooo00?o0000ooooooooool01?ooool002[ooooo00?o0000ooooooooool0<OoooolDojO0
j`KoZ<3[1onW`>/7ojJok0?oZ<3[0onW`>`7ojRoj`?oVkg`0onP_^h6ohFhmPKoEjgj1Om[_?d5ok3?
l0?oa[gB1?noc^H6ol:ecP03okk>i_nm/m7o_K?A00Go_K?A0onhYlP4okRmgPKo/J_B1_n[X/d00on[
b_3oYl7/ojO1k005ojO1k0GoXl3^1?nIiO`00onOj?_oY>SkojCXn`04ojCXn`;oZ/oc1_n[c?42oj_8
k`GoYkkZ1onW_^/00onW`>_oZ<7/ojS1k009ojS1k003ojO0jonW_n_oYko[00[oYko[00?oYl3[ojS1
jonX`N/02OnX`N/2ojO0j`_oYko[2_nW`>/2ojS0j`GoYl3[1?nW_n/01?l0003oYko[ojNojonW_n/;
ojO0j`Oooooo00?o0000ooooooooool00oooool002_ooooo00?o0000ooooooooool0<OoooolDojO0
j`KoZ<3[1onW`>/5ojJok0;oY/3/1_nW`>`5ojRoj`;oZL7[1_nP_^h7ohFhmPGoEjgj1Om[_?d5ok3?
l003olJmd_noc^Ko_lkV00Co_lkV0oo2]Lh4okk>iPOo_K?A00?o^:O8okRmg_nh_Mh01?nh_Mh6ok6[
dP;oZj;=1On[b_07ojO1k003oj?0k_nIiOcoVNGl00CoVNGl0onIio`2ojCXn`KoZ/oc0on[c?43ojS0
j`OoYkkZ0onW_^/<ojS1k0GoYl3[2?nW_n/5ojO0j`KoZ<7[00?oZ<3[ojO0jonW`>/01?nW`>/7ojNo
jaGoYl3[0onW_n/00ol0003oYko[ojO0j`09ojO0j`[ooooo00?o0000ooooooooool00oooool002co
oooo00?o0000ooooooooool0<OoooolDojO0j`KoZ<3[1onW`>/00onV_ncoY/3/ojK0k004ojK0k0Ko
Yl3/00?oZ;o[ojW1jonY`N/01?nY`N/6oj2nkP?oQKSf1?nE_?86ofVbnPGoEKKk1On5c?h6oko>iP03
ol:ec_nnc^Ko_/kV00Co_/kV1Onm/m42okCDl@Ko^;gN1OnaZm82ojSFn0OoZl[`0onW`N`5oi;Ro@;o
VNGl1OnIio`3ojO@m@GoZ/oc0_nX`N`6ojS0j`GoYkkZ0_nW`N`:ojS1k0?oZ<3[1onW`>/6ojNoj`Oo
Yl3[0_nX`N/5ojS0j`KoYl3[1onW_n/CojO0j`GoYko[00?o0000ojNojonW`>/01OnW`>/=ooooo`03
o`000?oooooooooo00?ooooo000]ooooo`;o0000<_oooolDojO0j`KoZ<3[1onW`>/7ojK0k0?oYl3/
0onV`>`7ojW1j`?oX;k^1?nT_^`6oiFllPKoJK;j1OmE]_/5ohG<oP?o_lkV1?nBdoh6okk>iP03okfc
dOnde?7o]=Ca00Co]=Ca1_nh_Mh00onaZm;oZ=KhojSFn004ojSFn0GoZl[`1?n9h?d3oi;Ro@GoSn?l
00?oVNOlojO@mOnWd?D01OnWd?D00onZco?oZ<7/ojS1k004ojS1k0KoZ<3[00?oYkkZojO1k?nW`N`0
1?nW`N`6ojS1k0OoZ<3[1OnW`>/8ojNoj`GoYl3[0_nX`N/7ojS0j`?oYl3[2_nW_n/?ojO0j`WoYko[
00Co0000ojNojonW`>_oYl3[4?ooool00ol0003oooooooooo`03ooooo`00;oooool00ol0003ooooo
ooooo`0`oooooaCoYl3[1_nX`>/7ojO0j`goY/3/1OnY`N/2ojS1j`OoY;k/0onE_?83oijmkPKoQ[_g
1_mL]?`5oek0o0KoT]?n0onnc^H4ohcFo`Ko]=Ca0onh_Mh4oiGKoPKoZ=Kh00?oZl[`ohWPoOn9h?d0
1?n9h?d4ohWNo@?oSn?l1?nTcoH5ojO@m@03ojS2k?nX`NcoZ<7/00KoZ<7/0onX`>/2ojO0k0SoYl7/
1_nX`N`7ojS0j`03ojO0jonW_n_oYko[00[oYko[00?oYl3[ojS1jonX`N/01?nX`N/5ojS0j`03ojO0
jonW_n_oYko[00[oYko[3_nW`>/;ojNoj`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
0oooool0033ooooo00?o0000ooooooooool0<OoooolCojO0j`OoZ<3[1_nW`>/=ojK0k003ojW1jonX
`N_oZ<7[00CoZ<7[1OnT_^`2ojRoj`KoW[g^1_n6^oL6oebdo0GoG/3l0onBdoh4of77o0KoS=Ko0ond
e?44og[FoPKoUM_n0onXe_P5ogcLn`03ohWPoOn9g_goRMkm00CoRMkm0_nRcOH7ojC?mP03ojO@mOnX
`^coZ<;/00?oZ<;/1_nX`N`00onW_n_oYl3/ojO0k004ojO0k0KoYl7/2?nX`N`3ojS0j`koYko[0onX
`N`7ojS1j`03ojS0jonW`>_oYl3[00?oYl3[2?nW_n/BojO0j`KoYko[1Oooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo00?ooooo000aooooo`03o`000?oooooooooo037ooooo5?nW`>/7
ojS0j`;oYl3[1?nX`>/<ojK0k0OoZ<7[00?oY;k/ojRojonX_n/01?nX_n/6oijmkP?oQ[_g1?nJ__46
ogfknPKoFk_l1OmQao`3ohcFo`GoH<[j1Omje_h3oiGKoPGoK]Gj0omlg?/5ohOHo`03ohWNoOnRcOKo
X/gf00CoX/gf0onTcoH4ojO2k0KoZ<;/0_nX`N`5ojNoj`KoYl3/0_nW`N`:ojS1k0koYko[00?oYl3[
ojS1k?nX`N`01OnX`N`3ojS1j`[oYl3[1_nW_n/DojO0j`;oYko[2Oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00?ooooo000booooo`;o0000<_oooolDojO0j`goZ<3[1?nV`>`3ojO0
j`GoY/3/1OnX`N/2ojO0k0OoZ;o[0onN_Nh3ojFnj`OoV[ka0omm^oX3oiVolPOoOkkk1OmT`_h3of3:
nPGoN<Oo1_mZco`3ofkEnPCoR]3o0on7f?l4oj79m0GoX/gf0_nW`N`7ojO2k0?oZ<;/2_nW_n/3ojO0
k0_oZ<7/3_nW_n/5ojO0j`GoZ<7/0_nX`>/;ojO0j`SoYko[4OnW`>/>ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool00_ooool003Cooooo00?o0000ooooooooool0<?oooolDojO0j`go
Z<3[00?oY/3/ojO0jonW`>/01?nW`>/5ojK0k003ojS1jonW`>coYl3/00CoYl3/1OnX_n/2ojS1j`Ko
YKk[1OnJ__42ojBnk0KoVKob1Omo__/2oic0l@KoS<;i1Omhaol2oi_4m0OoTLSj0on:d?l4oj75lPKo
XLWd00?oX/gfojO1k?nW`N`01?nW`N`5ojO2k0goYko[0_nW`N`:ojS1k0?oYl3[3OnW_n/7ojO0j`03
ojS1k?nX`>_oZ<3[00CoZ<3[1onW`>/<ojNoj`coYl3[4_ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo00;ooooo000eooooo`03o`000?oooooooooo033ooooo5?nW`>/=ojS0j`OoYl3[
1_nV`>`6ojO0k003ojRojonX`N_oZ<7[00CoZ<7[1_nU_^/00onJ__7oY;k/ojBnk004ojBnk0KoVKob
00?oOkkkoic0lOnL`?401?nL`?46ohc2n@03ogS7oonKa?CoVlCd00CoVlCd1OnAb?X2oj?1k`OoXLGb
0onQbO@4ojJoj`KoYl7/00?oYl;/ojNojonW_n/02onW_n/6ojO1k0GoZ<7/2?nW`>/=ojNoj`GoYl3[
00?oZ<7[ojS0jonX`>/01_nX`>/3ojO0j`goYko[2onW`>/Fooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool00_ooool003Kooooo00?o0000ooooooooool0<?oooolDojO0j`goZ<3[1OnW
`>/2ojNoj`KoY/3/0onW`>`3ojK0k0OoZ<7[0onU_^/4ojW1j`KoY;k/0onI_o84ojBnk0KoW<3a0on<
`_T4oj30k`KoVlCd00?oTLSjoj?1konS`Nl01?nS`Nl5oj75lP;oYkkZ1onV_n/3ojO1k0goYko[2_nW
`N`00onX`NcoYl3[ojO0j`0:ojO0j`goYko[00?oYl3[ojS1jonX`N/00onX`N/6ojS0j`03ojO0jonW
_n_oYko[00[oYko[2onW`>/Kooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00_oo
ool003Oooooo0_l0000aoooooaCoYl3[3OnX`>/00onW`>_oYko[ojNoj`04ojNoj`CoY/3/0_nW`>`6
ojK0k0GoZ<7[0_nW`N`7ojW1j`?oY;k/0onX`>/7ojBnk0?oW<3a1?nU_^/6oj30k`?oVlCd1?nU_n`6
oj?1k`03oj75l_nW_^[oYkkZ00CoYkkZ1OnV_n/00onX`>_oYko[ojNoj`0:ojNoj`_oYl7/3OnW`>/=
ojNoj`CoYl7/1_nX`N/2ojS0j`GoYl3[2?nW_n/:ojO0jb3ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`02ooooo`00>Oooool00ol0003oooooooooo`0_oooooa7oYl3[0onW`>`>ojS0
j`KoYko[00?oY/3/ojO0k?nW`>`00onW`>`6ojK0k003ojS1jonW`NcoYl7/00CoYl7/1OnY`N/2ojO1
k0KoZ<3[1OnT_^`2ojS0j`OoYKk[0onP`>l3ojNojPOoYKo/0onS`Nl3ojNojPOoYkkZ00?oY[o[ojS0
jonX`>/00onX`>/8ojNoj`[oYl7/3OnW`>/2ojNojP_oYko[2OnW`N`3ojS1j`[oYl3[1_nW_n/8ojO0
jb?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`02ooooo`00>_ooool00ol0003o
ooooooooo`0_ooooo`koYl3[1_nW`>`>ojS0j`?oYko[0onX_n/6ojO0k0OoY/3/1_nW`N`00onY`N_o
Yl7/ojO1k004ojO1k0KoZ<3[00?oY;k/ojS0jonX`>/01?nX`>/5ojFnj`;oZ<7[1_nW_nX5ojFok0;o
Z<3[1_nW_nX5ojNnjP03ojS1k?nX`>_oZ<3[00GoZ<3[0onW_n/;ojO1k0goYl3[1_nW_nX7ojNoj`_o
Yl7/3OnW`>/8ojNoj`?oYl3[:?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00;o
oooo000kooooo`03o`000?oooooooooo033ooooo3OnW`>/6ojO0k0koZ<3[1_nX_n/4ojO0k0;oYko[
1onV`>`3ojO1k0?oY/3/1onW`N`3ojS0j`CoYl7/1_nX`>/00onU_^_oZ<7[ojS1j`04ojS1j`KoYkoZ
00?oYKo/ojS0jonX`>/01?nX`>/6ojNojP03ojNnj_nX`NcoZ<7/00?oZ<7/1OnX`>/<ojO1k0goYl3[
2_nW_nX3ojNoj`?oYl3[2?nW`N`=ojO0j`[oYko[;Oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo007ooooo000looooo`03o`000?oooooooooo033ooooo0onW`>/3ojS0j`OoYl3[1onW
`>`=ojS0j`KoZ;o[00?oYl3/ojNojonW_n/00onW_n/5ojK0k0;oYl3[1_nV`>`5ojO1k0;oY/3/1onW
`N`3ojS0j`?oYl7/1onX`N/3ojNojP?oZ<7/1onX`>/3ojNojP?oYl7/1_nX`N`00onX`>_oYl7/ojO1
k009ojO1k0goYl3[3OnW_nX8ojO0j`?oYl7/3OnW`>/;ojNojc7ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`01ooooo`00?Oooool2o`00037ooooo1_nX`>/7ojO0j`OoYl3/0onX`>/3
ojO0j`OoZ<3[1_nX_n/6ojNoj`03ojK0k?nW`>_oYl3[00CoYl3[1_nV`>`00onW`NcoY/3/ojK0k004
ojK0k0GoYl7/0_nV`>`6ojO1k0GoZ<7[00?oYl7/ojS1k?nX`N`01OnX`N`3ojS0j`[oYl7/0onX`N`;
ojO1k0goYl3[3OnW_nX:ojO0j`;oYl7/2onW`>/<ojNojcCooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`01ooooo`00?oooool00ol0003oooooooooo`0_ooooo`KoZ<3[1onW`>/7ojO0
k0KoYl3[1onX`>/6ojRoj`?oYko[0onX_n/7ojO0j`?oY/3/1?nW`>`6ojK0k003ojO1k?nV`>coY/3/
00CoY/3/1_nW`N`00onX`N_oYl7/ojO1k003ojO1k0GoZ<7/0_nW`>`;ojO1k0;oYl3/2_nW`N`=ojO0
j`coYkoZ2onW`>/6ojO1k0OoYl3[2onW_n/iooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool00Oooool0043ooooo00?o0000ooooooooool0;oooool7ojS0j`KoYl3[1onW`>`6ojO0j`Oo
Z<3[1?nX_n/2ojS0j`KoZ;o[1OnW`>/2ojNoj`OoYl3/0onV`>`3ojO0k0OoY/3/0onW`N`3ojK0k0Ko
Yl7/00?oZ<7/ojO0k?nW`>`01?nW`>`7ojO1k0KoYl3/1OnW`N`=ojO0j`_oYkoZ3OnW`>/:ojO1k0Ko
Yl3[2?nW_n/mooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00Oooool0047ooooo
00?o0000ooooooooool0;oooool7ojS0j`OoYl3[1_nW`>`3ojO0j`CoYl3/1_nX`>/00onX_n_oZ<3[
ojS0j`03ojS0j`KoZ;o[00?oYl3[ojNojonW_n/01?nW_n/5ojO0k0;oYko[1_nW`>`5ojK0k003ojO0
jonV`>coY/3/00GoY/3/0onW`N`:ojO0k0?oYl7/2_nW`>`00onW`NcoYl3[ojO0j`0;ojO0j`[oYkoZ
3OnW`>/<ojO1k0WoYl3[0onW_n]1ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
0Oooool004;ooooo0_l0000`ooooo`OoZ<3[1onW`>/3ojO0k0?oYl3[1onW`>`3ojS0j`?oYl3/1_nX
`>/3ojRoj`CoZ<3[1_nW_n/00onW`>coYko[ojNoj`04ojNoj`KoYl3/00?oY/3/ojO0jonW`>/00onW
`>/5ojK0k0;oYko[2onW`>`2ojNoj`[oYl3/0_nW_n/:ojO0j`_oYkoZ3OnW`>/;ojO1k0coYl3[A_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo007ooooo0014ooooo`03o`000?oooooo
oooo02kooooo1onX`>/5ojO0j`;oZ<3[1_nW`>/=ojO0k0goZ<3[0onW_n/3ojRojPOoYko[0onW`>`4
ojNoj`GoYl3[00?oY/3/ojNojonW_n/01?nW_n/7ojO0k0KoYko[1OnW`>`7ojNoj`GoYl3[0_nX_nX:
ojNojPgoYl3[2onW`N`<ojO0jd[ooooo00?o0000ooooooooool01oooool1o`00007ooooo0Oooool0
04Gooooo00?o0000ooooooooool0;oooool6ojS0j`03ojO0jonX`>_oZ<3[00CoZ<3[1_nW`>/=ojO0
k0goZ<3[1_nX_nX5ojNoj`;oZ;oZ1onW_n/2ojO0j`[oYko[0onW`>`:ojNoj`03ojO0k?nW_n_oYko[
00WoYko[00?oYl3[ojRoj_nX_nX01?nX_nX5ojNojPgoYl3[2onW`N`=ojO0jdkooooo00?o0000oooo
ooooool01_ooool1o`00007ooooo0Oooool004Kooooo00?o0000ooooooooool0<?ooool<ojS0j`?o
Yl3[1?nW_n/<ojO0k0goZ<3[1_nX_nX00onW_n_oZ;oZojRojP04ojRojPGoYko[00?oZ;o[ojNojonW
_n/02OnW_n/2ojRojP[oYko[0_nX_nX:ojNoj`CoZ;o[1_nX_nX00onW_n[oYl3[ojO0j`0;ojO0j`[o
Yl7/3OnW`>]Booooo`03o`000?oooooooooo00Kooooo0Ol00001ooooo`7ooooo0017ooooo`;o0000
<Oooool<ojS0j`OoYko[0onW`>`3ojO0j`KoYl3/0onX`>/4ojO0k0KoZ<3[0onX_nX4ojS0j`KoZ;oZ
00?oYko[ojRojonX_n/00onX_n/7ojNoj`KoZ;oZ1OnW_n/00onX_n_oZ;oZojRojP04ojRojPGoYko[
0_nX`>/7ojRoj`?oZ;oZ3OnW`>/:ojO1k0goYl3[E_ooool00ol0003oooooooooo`05ooooo`7o0000
0Oooool1ooooo`00BOooool00ol0003oooooooooo`0_ooooo`coZ<3[1OnW_n/2ojRoj`KoYl3[1?nW
`>`2ojO0j`OoYl3/0onX`>/3ojO0k0OoZ<3[0onX_nX3ojS0j`KoZ;o[0onW_n/4ojS0j`KoZ;oZ00?o
Yko[ojRojonX_n/00onX_n/6ojRojP03ojNojonX`>_oZ<3[00CoZ<3[1OnX_n/2ojO0k0_oYl3[00?o
Yl3/ojO1k?nW`N`02?nW`N`=ojO0je[ooooo00?o0000ooooooooool01?ooool1o`00007ooooo0Ooo
ool004[ooooo00?o0000ooooooooool0;oooool<ojS0j`03ojNojonX_n_oZ;o[00CoZ;o[1_nW`>/0
0onW`>coYl3[ojO0j`03ojO0j`goYl3/1OnX`>/00onW`>coZ<3[ojS0j`05ojS0j`?oZ;o[2_nX`>/3
ojRojP?oZ<3[1_nX_n/3ojRojP[oZ<3[00?oZ;o[ojO0k?nW`>`01?nW`>`7ojO0j`GoYl3/1OnW`N`=
ojO0jeoooooo00?o0000ooooooooool00oooool1o`00007ooooo0Oooool004_ooooo00?o0000oooo
ooooool0;oooool=ojS0j`KoZ;o[0onW`>/4ojNoj`GoYl3[3OnW`>`00onX`>_oYl3/ojO0k003ojO0
k0GoZ<3[0_nW`>`;ojS0j`;oYl3/1_nX`>/3ojRoj`?oYl3/2_nX`>/4ojO1k0KoYl3/0onW`>/9ojO0
k003ojO1k?nW`>_oYl3[00_oYl3[H_ooool00ol0003oooooooooo`03ooooo`7o00000Oooool1oooo
o`00C?ooool2o`00033ooooo1?nX`>/2ojO0j`OoZ<3[0onX_n/3ojS0j`OoYko[0_nW`>/4ojNoja;o
Yl3/00?oZ<3[ojO0k?nW`>`01?nW`>`7ojS0j`KoYl3/1?nX`>/8ojO0k0GoZ<3[0_nW`>`7ojO1k0oo
Yl3/3OnW`>]Vooooo`03o`000?oooooooooo00?ooooo0Ol00001ooooo`00C_ooool00ol0003ooooo
ooooo`0^ooooo`03ojS0jonW`>_oYl3[00?oYl3[1OnX`>/2ojO0j`KoZ<3[1OnW_n/00onX_n_oYko[
ojNoj`05ojNoj`?oYl3/0onW`>/CojO0k0?oZ<3[2_nW`>`00onX`>_oYl3/ojO0k009ojO0k003ojS0
jonW`>coYl3/00CoYl3/1OnW`N`00onW`>_oYl3/ojO0k009ojO0k0coYl3[K?ooool00ol0003ooooo
ooooo`02ooooo`7o00000Oooool004oooooo00?o0000ooooooooool0;oooool5ojO0j`03ojS0jonW
`>_oYl3[00CoYl3[1_nX`>/00onW_n_oZ;o[ojRoj`03ojRoj`GoYko[0_nX_n/6ojO0j`GoYl3/00?o
Yl3[ojO0k?nW`>`02?nW`>`3ojO0jb3oYl3/00?oYl7/ojO0jonW`>/00onW`>/7ojO0k0_oYl3[LOoo
ool01Ol0003ooooooooooooooooo0000007ooooo001@ooooo`03o`000?oooooooooo02oooooo3?nW
`>/7ojS0j`GoZ;o[00?oYko[ojRojonX_n/01?nX_n/6ojO0j`03ojO0k?nW`>_oYl3[00?oYl3[1OnW
`>`2ojNoj`KoYl3[1OnW`>`00onW`>_oYl3/ojO0k008ojO0k0?oYl3[2_nW`>`9ojO0j`?oYl3/1?nW
_n/7ojO0jgCooooo00Go0000ooooooooooooooooo`000001ooooo`00DOooool2o`00033ooooo3?nW
`>/7ojS0j`;oZ;o[1?nX`>/6ojRoj`?oYl3[1?nW_n/5ojO0j`03ojO0k?nW_n_oYko[00CoYko[1_nW
`>/00onW`>coYl3[ojO0j`03ojO0j`GoYl3/2?nW`>/5ojO0k0_oYl3[2_nW_n/3ojO0jgSooooo00Co
0000oooooooooooo00000Oooool005?ooooo00?o0000ooooooooool0;_ooool<ojO0j`GoZ<3[00?o
Yl3[ojS0jonX`>/01OnX`>/3ojRoj`?oZ<3[1onW_n/2ojO0j`[oYko[0onW`>/3ojNoj`KoYl3[00?o
Yl3/ojO0jonW`>/02_nW`>/00onW`>coYl3[ojO0j`08ojO0j`goYko[OOooool00ol0003oooooo`00
0001ooooo`00E?ooool00ol0003oooooooooo`0^ooooo`coYl3[00?oZ<3[ojO0jonW`>/00onW`>/5
ojS0j`;oYl3[1_nX`>/5ojNoj`03ojS0jonW_n_oYko[00SoYko[0onX_n/6ojNoj`?oYl3[1?nW_n/9
ojO0j`?oYko[1onW`>/=ojNojh3ooooo00?o0000ooooool000000Oooool005Gooooo00?o0000oooo
ooooool0;_oooolBojO0j`03ojS0jonW`>_oYl3[00CoYl3[1_nX`>/00onW_n_oZ<3[ojS0j`03ojS0
j`GoYko[0_nX`>/6ojRoj`CoYko[0_nX_n/7ojNoj`?oYl3[0_nX_n/7ojNoj`?oYl3[1?nX_n/9ojNo
jhCooooo0Ol00001ooooo`7o0000001Fooooo`;o0000;ooooolIojO0j`?oZ<3[1?nW`>/5ojS0j`03
ojNojonX`>_oZ<3[00CoZ<3[1_nX_n/00onW_n_oZ;o[ojRoj`03ojRoj`GoYko[0_nX`>/5ojRoj`Go
Yko[0_nX`>/7ojRoj`?oYko[R_ooool2o`000000F?ooool00ol0003oooooooooo`0]ooooob3oYl3[
0_nX`>/4ojO0j`KoZ<3[0onX_n/3ojS0j`KoZ;o[00?oYko[ojS0jonX`>/01?nX`>/5ojRoj`03ojNo
jonX`>_oZ<3[00CoZ<3[1OnX_n^=ooooo`?o0000001Iooooo`03o`000?oooooooooo02gooooo9_nW
`>/3ojS0j`?oYl3[1_nX`>/3ojRoj`[oZ<3[0_nX_n/:ojS0j`03ojRojooooooooooo08[ooooo1?l0
0003ooooo`00F_ooool00ol0003oooooooooo`0]ooooobcoYl3[1?nX`>/2ojO0j`[oZ<3[0onW`>/9
ojS0jhcooooo0ol00007ooooo`00Foooool00ol0003oooooooooo`0]ooooo`[oYl3[0onW_n/OojO0
j`03ojS0jonW`>_oYl3[00?oYl3[1OnX`>/8ojO0j`?oZ<3[SOooool4o`0000[ooooo001Looooo`;o
0000;_ooool5ojO0j`;oZ<3[1_nW_n/3ojO0j`CoYko[7_nW`>/00onX`>_oYl3[ojO0j`08ojO0jhgo
oooo1?l0000>ooooo`00G_ooool00ol0003oooooooooo`0/ooooo`03ojO0jonX`>_oZ<3[00CoZ<3[
1?nW_n/2ojS0j`OoYko[0onW`>/2ojNojb3oYl3[S?ooool4o`0001;ooooo001Oooooo`03o`000?oo
oooooooo02gooooo1_nX`>/00onW_n_oZ<3[ojS0j`03ojS0j`GoYko[0_nX`>/5ojNoj`GoYl3[0_nW
_n/EojO0jh_ooooo1?l0000Fooooo`00H?ooool00ol0003oooooooooo`0]ooooo`coZ<3[00?oYko[
ojS0jonX`>/01?nX`>/5ojNoj`03ojO0jonW_n_oYko[00CoYko[1?nW`>/2ojNoj`[oYl3[S?ooool3
o`0001[ooooo001Qooooo`;o0000;ooooolBojS0j`;oYko[1?nX`>/6ojNoj`03ojO0jonW_n_oYko[
00?oYko[1OnW`>^<ooooo`Co00007Oooool006?ooooo00?o0000ooooooooool0;Oooool3ojS0j`;o
Yl3[4onX`>/3ojNoj`?oZ<3[1_nW_n/00onW`>_oooooooooo`29ooooo`Co00008Oooool006Cooooo
00?o0000ooooooooool0;Oooool5ojO0j`GoZ<3[0_nW`>/BojS0j`?oYko[R_ooool4o`0002Gooooo
001Uooooo`03o`000?oooooooooo02gooooo1OnW`>/00onX`>_oYl3[ojO0j`04ojO0j`CoZ<3[0_nW
`>/9ojS0jh_ooooo1?l0000Yooooo`00I_ooool2o`0002kooooo3?nW`>/00onX`>_oYl3[ojO0j`03
ojO0j`GoZ<3[Roooool3o`0002gooooo001Xooooo`03o`000?oooooooooo02cooooo4_nW`>/00onX
`>_oooooooooo`28ooooo`Co0000<?ooool006Wooooo00?o0000ooooooooool0;?ooool?ojO0jhWo
oooo1?l0000dooooo`00J_ooool00ol0003oooooooooo`0/ooooo`WoYl3[R_ooool4o`0003Sooooo
001[ooooo`;o0000;Oooool5ojO0jhWooooo1?l0000looooo`00KOooool00ol0003oooooooooo`0[
ooooo`03ojO0jooooooooooo08Oooooo0ol00010ooooo`00K_ooool00ol0003oooooooooo`0Zoooo
o`03o`000?oooooooooo08?ooooo1?l00013ooooo`00Koooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo07oooooo1?l00017ooooo`00L?ooool2o`0002Wooooo00?o0000ooooooooool0
Noooool4o`0004_ooooo001booooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0Mooo
ool4o`0004oooooo001cooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0M?ooool3
o`0005?ooooo001dooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0L?ooool4o`00
05Kooooo001eooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0K?ooool4o`0005[o
oooo001fooooo`;o00008oooool00ol0003oooooooooo`1Xooooo`Co0000G_ooool007Sooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`1Tooooo`Co0000H_ooool007Wooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`1Qooooo`?o0000I_ooool007[ooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`1Mooooo`Co0000JOooool007_ooooo0_l0000Nooooo`03
o`000?oooooooooo05Wooooo1?l0001]ooooo`00OOooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo05Gooooo1?l0001aooooo`00O_ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo057ooooo1?l0001eooooo`00Ooooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo04kooooo0ol0001iooooo`00P?ooool2o`0001Wooooo00?o0000ooooooooool0B_ooool4o`00
07cooooo0022ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0A_ooool4o`00083o
oooo0023ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0@_ooool4o`0008Cooooo
0024ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0?_ooool4o`0008Sooooo0025
ooooo`;o00004oooool00ol0003oooooooooo`0looooo`?o0000S?ooool008Oooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0hooooo`Co0000Soooool008Sooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0dooooo`Co0000Toooool008Wooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0`ooooo`Co0000Uoooool008[ooooo0_l0000>ooooo`03o`000?oo
oooooooo02cooooo1?l0002Kooooo`00S?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo02Wooooo0ol0002Oooooo`00SOooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
02Gooooo1?l0002Rooooo`00S_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo027o
oooo1?l0002Vooooo`00Soooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01gooooo
1?l0002Zooooo`00T?ooool2o`0000Sooooo00?o0000ooooooooool06Oooool4o`000:kooooo002B
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05_ooool3o`000;;ooooo002Coooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04_ooool4o`000;Gooooo002Dooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool03_ooool4o`000;Wooooo002Eooooo`;o0000
0oooool00ol0003oooooooooo`0:ooooo`Co0000_Oooool009Oooooo00Co0000oooooooooooo0000
2?ooool4o`000<7ooooo002Hooooo`03o`000?oooooo000000Gooooo0ol00035ooooo`00VOooool2
o`000003ooooool0003o000000;o0000b?ooool009[ooooo0_l0003<ooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0538698, 0.0432538, \
0.0035044, 0.0035044}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[.12586 .2075 -12 -8.99448 ]
[.12586 .2075 0 .00552 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.56094 .0364 -5.16972 -9 ]
[.56094 .0364 .83028 0 ]
[.75679 .08071 0 -6.17777 ]
[.75679 .08071 12 2.82223 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.9429 .3657 0 -5.9083 ]
[.9429 .3657 6 3.0917 ]
[.02494 .25992 -18 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.01611 .31527 -18 -2.78472 ]
[.01611 .31527 0 6.21528 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00254 .43215 -12 -2.88407 ]
[-0.00254 .43215 0 6.11593 ]
[-0.0124 .49393 -12 -2.93688 ]
[-0.0124 .49393 0 6.06312 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
[(-2)] .12586 .2075 1 .99877 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.56863 .04703 m
.57247 .05235 L
s
[(2)] .56094 .0364 .72324 1 Mshowa
.125 Mabswid
.18558 .19702 m
.18832 .19985 L
s
.23703 .17687 m
.23971 .17975 L
s
.28951 .15632 m
.29214 .15925 L
s
.39772 .11395 m
.40023 .11699 L
s
.4535 .09211 m
.45595 .0952 L
s
.51046 .06981 m
.51284 .07294 L
s
.08568 .23614 m
.08851 .23887 L
s
.62804 .02377 m
.63027 .02701 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.7445 .0853 m
.73835 .08759 L
s
[(-2)] .75679 .08071 -1 .37284 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.93037 .36962 m
.92411 .37158 L
s
[(2)] .9429 .3657 -1 .31296 Mshowa
.125 Mabswid
.7708 .12553 m
.7671 .12688 L
s
.79613 .16428 m
.79242 .1656 L
s
.82054 .20161 m
.81682 .20291 L
s
.86679 .27235 m
.86305 .2736 L
s
.88871 .30589 m
.88497 .30711 L
s
.9099 .3383 m
.90615 .3395 L
s
.71716 .04348 m
.71349 .04489 L
s
.95018 .39992 m
.94642 .40107 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(-20)] .02494 .25992 1 -0.39157 Mshowa
.02837 .31059 m
.0345 .30825 L
s
[(-10)] .01611 .31527 1 -0.38117 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.00981 .42772 m
.01599 .4255 L
s
[(10)] -0.00254 .43215 1 -0.3591 Mshowa
0 .48963 m
.0062 .48748 L
s
[(20)] -0.0124 .49393 1 -0.34736 Mshowa
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.653 .753 .923 r
.39362 .69482 .40169 .7018 .4152 .69806 .40717 .69105 Mtetra
.657 .754 .921 r
.40717 .69105 .4152 .69806 .42878 .6943 .42079 .68715 Mtetra
.658 .751 .918 r
.42079 .68715 .42878 .6943 .44242 .69043 .43448 .68318 Mtetra
.657 .749 .918 r
.43448 .68318 .44242 .69043 .45614 .68648 .44824 .67923 Mtetra
.656 .75 .919 r
.44824 .67923 .45614 .68648 .46992 .68254 .46207 .67531 Mtetra
.653 .751 .921 r
.46207 .67531 .46992 .68254 .48378 .67862 .47597 .67145 Mtetra
.653 .753 .923 r
.47597 .67145 .48378 .67862 .4977 .67474 .48994 .66759 Mtetra
.655 .755 .923 r
.48994 .66759 .4977 .67474 .5117 .67089 .50398 .66361 Mtetra
.657 .753 .921 r
.50398 .66361 .5117 .67089 .52577 .667 .5181 .65954 Mtetra
.658 .75 .918 r
.5181 .65954 .52577 .667 .53991 .66298 .53229 .65544 Mtetra
.658 .749 .917 r
.53229 .65544 .53991 .66298 .55412 .65892 .54655 .65133 Mtetra
.657 .748 .917 r
.54655 .65133 .55412 .65892 .56841 .65483 .56088 .64723 Mtetra
.656 .749 .918 r
.56088 .64723 .56841 .65483 .58277 .65073 .57529 .64313 Mtetra
.655 .749 .919 r
.57529 .64313 .58277 .65073 .5972 .64663 .58978 .63906 Mtetra
.654 .751 .921 r
.58978 .63906 .5972 .64663 .61171 .64251 .60434 .635 Mtetra
.654 .753 .923 r
.60434 .635 .61171 .64251 .6263 .63839 .61898 .6309 Mtetra
.654 .755 .924 r
.61898 .6309 .6263 .63839 .64096 .63425 .6337 .62677 Mtetra
.654 .757 .925 r
.6337 .62677 .64096 .63425 .6557 .63009 .64849 .6226 Mtetra
.655 .757 .925 r
.64849 .6226 .6557 .63009 .67052 .62592 .66336 .6184 Mtetra
.655 .758 .925 r
.66336 .6184 .67052 .62592 .68541 .62172 .67831 .61416 Mtetra
.67831 .61416 .68541 .62172 .70039 .61749 .69334 .60988 Mtetra
.656 .758 .925 r
.69334 .60988 .70039 .61749 .71544 .61325 .70845 .60557 Mtetra
.656 .757 .924 r
.70845 .60557 .71544 .61325 .73057 .60899 .72364 .60122 Mtetra
.657 .756 .923 r
.72364 .60122 .73057 .60899 .74579 .60471 .73891 .59683 Mtetra
.657 .754 .922 r
.73891 .59683 .74579 .60471 .76109 .60042 .75425 .5924 Mtetra
.657 .752 .92 r
.75425 .5924 .76109 .60042 .77647 .59612 .76969 .58798 Mtetra
.656 .749 .919 r
.76969 .58798 .77647 .59612 .79193 .59181 .78521 .58359 Mtetra
.655 .748 .918 r
.78521 .58359 .79193 .59181 .80748 .58749 .80081 .5792 Mtetra
.654 .747 .918 r
.80081 .5792 .80748 .58749 .82311 .58314 .81651 .57481 Mtetra
.81651 .57481 .82311 .58314 .83883 .57874 .83229 .57041 Mtetra
.654 .749 .919 r
.83229 .57041 .83883 .57874 .85462 .57421 .84815 .56598 Mtetra
.656 .753 .921 r
.84815 .56598 .85462 .57421 .8705 .56964 .8641 .56145 Mtetra
.658 .756 .922 r
.8641 .56145 .8705 .56964 .88646 .56508 .88013 .5568 Mtetra
.658 .755 .921 r
.88013 .5568 .88646 .56508 .90252 .56057 .89624 .55214 Mtetra
.656 .751 .92 r
.89624 .55214 .90252 .56057 .91868 .55607 .91245 .54754 Mtetra
.655 .749 .919 r
.91245 .54754 .91868 .55607 .93492 .55158 .92876 .54296 Mtetra
.654 .748 .919 r
.92876 .54296 .93492 .55158 .95125 .54701 .94516 .5384 Mtetra
.655 .75 .92 r
.94516 .5384 .95125 .54701 .96766 .5423 .96165 .53377 Mtetra
.658 .754 .921 r
.96165 .53377 .96766 .5423 .98416 .53758 .97821 .52899 Mtetra
.657 .754 .921 r
.38547 .68778 .39362 .69482 .40717 .69105 .39906 .68386 Mtetra
.659 .751 .918 r
.39906 .68386 .40717 .69105 .42079 .68715 .41273 .67987 Mtetra
.657 .749 .918 r
.41273 .67987 .42079 .68715 .43448 .68318 .42646 .67591 Mtetra
.656 .75 .919 r
.42646 .67591 .43448 .68318 .44824 .67923 .44027 .67198 Mtetra
.652 .751 .922 r
.44027 .67198 .44824 .67923 .46207 .67531 .45414 .66813 Mtetra
.653 .754 .924 r
.45414 .66813 .46207 .67531 .47597 .67145 .46808 .66424 Mtetra
.657 .755 .922 r
.46808 .66424 .47597 .67145 .48994 .66759 .4821 .66019 Mtetra
.658 .751 .919 r
.4821 .66019 .48994 .66759 .50398 .66361 .49619 .65608 Mtetra
.658 .749 .917 r
.49619 .65608 .50398 .66361 .5181 .65954 .51035 .65196 Mtetra
.657 .748 .917 r
.51035 .65196 .5181 .65954 .53229 .65544 .52459 .64785 Mtetra
.656 .749 .918 r
.52459 .64785 .53229 .65544 .54655 .65133 .5389 .64377 Mtetra
.653 .75 .921 r
.5389 .64377 .54655 .65133 .56088 .64723 .55328 .63976 Mtetra
.653 .753 .923 r
.55328 .63976 .56088 .64723 .57529 .64313 .56775 .63574 Mtetra
.653 .756 .925 r
.56775 .63574 .57529 .64313 .58978 .63906 .58228 .63166 Mtetra
.654 .757 .925 r
.58228 .63166 .58978 .63906 .60434 .635 .5969 .62752 Mtetra
.656 .757 .924 r
.5969 .62752 .60434 .635 .61898 .6309 .61159 .62331 Mtetra
.656 .755 .923 r
.61159 .62331 .61898 .6309 .6337 .62677 .62635 .61908 Mtetra
.656 .753 .922 r
.62635 .61908 .6337 .62677 .64849 .6226 .6412 .61483 Mtetra
.656 .752 .921 r
.6412 .61483 .64849 .6226 .66336 .6184 .65612 .61056 Mtetra
.65612 .61056 .66336 .6184 .67831 .61416 .67113 .60628 Mtetra
.67113 .60628 .67831 .61416 .69334 .60988 .68621 .60198 Mtetra
.655 .752 .921 r
.68621 .60198 .69334 .60988 .70845 .60557 .70138 .59767 Mtetra
.655 .753 .922 r
.70138 .59767 .70845 .60557 .72364 .60122 .71663 .59334 Mtetra
.655 .755 .923 r
.71663 .59334 .72364 .60122 .73891 .59683 .73196 .58897 Mtetra
.656 .757 .924 r
.73196 .58897 .73891 .59683 .75425 .5924 .74737 .58455 Mtetra
.657 .758 .924 r
.74737 .58455 .75425 .5924 .76969 .58798 .76286 .58005 Mtetra
.658 .758 .924 r
.76286 .58005 .76969 .58798 .78521 .58359 .77843 .5755 Mtetra
.658 .755 .921 r
.77843 .5755 .78521 .58359 .80081 .5792 .79409 .57092 Mtetra
.656 .75 .919 r
.79409 .57092 .80081 .5792 .81651 .57481 .80983 .56643 Mtetra
.655 .748 .919 r
.80983 .56643 .81651 .57481 .83229 .57041 .82567 .56196 Mtetra
.654 .747 .918 r
.82567 .56196 .83229 .57041 .84815 .56598 .8416 .55749 Mtetra
.654 .748 .919 r
.8416 .55749 .84815 .56598 .8641 .56145 .85762 .55301 Mtetra
.654 .75 .92 r
.85762 .55301 .8641 .56145 .88013 .5568 .87373 .54847 Mtetra
.658 .756 .922 r
.87373 .54847 .88013 .5568 .89624 .55214 .8899 .54375 Mtetra
.8899 .54375 .89624 .55214 .91245 .54754 .90617 .53899 Mtetra
.656 .752 .92 r
.90617 .53899 .91245 .54754 .92876 .54296 .92253 .53431 Mtetra
.655 .75 .92 r
.92253 .53431 .92876 .54296 .94516 .5384 .939 .52965 Mtetra
.654 .748 .919 r
.939 .52965 .94516 .5384 .96165 .53377 .95556 .52503 Mtetra
.655 .75 .92 r
.95556 .52503 .96165 .53377 .97821 .52899 .97221 .52031 Mtetra
.659 .751 .918 r
.37724 .68057 .38547 .68778 .39906 .68386 .39088 .67656 Mtetra
.657 .749 .918 r
.39088 .67656 .39906 .68386 .41273 .67987 .40459 .67258 Mtetra
.655 .75 .92 r
.40459 .67258 .41273 .67987 .42646 .67591 .41837 .66864 Mtetra
.652 .751 .922 r
.41837 .66864 .42646 .67591 .44027 .67198 .43221 .66478 Mtetra
.653 .754 .924 r
.43221 .66478 .44027 .67198 .45414 .66813 .44613 .66085 Mtetra
.658 .754 .921 r
.44613 .66085 .45414 .66813 .46808 .66424 .46012 .65676 Mtetra
.659 .75 .918 r
.46012 .65676 .46808 .66424 .4821 .66019 .47419 .65263 Mtetra
.658 .749 .917 r
.47419 .65263 .4821 .66019 .49619 .65608 .48833 .64849 Mtetra
.657 .749 .918 r
.48833 .64849 .49619 .65608 .51035 .65196 .50254 .64439 Mtetra
.653 .749 .92 r
.50254 .64439 .51035 .65196 .52459 .64785 .51682 .6404 Mtetra
.652 .753 .924 r
.51682 .6404 .52459 .64785 .5389 .64377 .53118 .6364 Mtetra
.653 .757 .926 r
.53118 .6364 .5389 .64377 .55328 .63976 .54561 .63233 Mtetra
.656 .757 .924 r
.54561 .63233 .55328 .63976 .56775 .63574 .56012 .62814 Mtetra
.657 .754 .921 r
.56012 .62814 .56775 .63574 .58228 .63166 .57471 .6239 Mtetra
.657 .751 .919 r
.57471 .6239 .58228 .63166 .5969 .62752 .58937 .61964 Mtetra
.657 .749 .917 r
.58937 .61964 .5969 .62752 .61159 .62331 .60411 .61535 Mtetra
.657 .748 .917 r
.60411 .61535 .61159 .62331 .62635 .61908 .61893 .61105 Mtetra
.657 .747 .916 r
.61893 .61105 .62635 .61908 .6412 .61483 .63383 .60674 Mtetra
.657 .746 .916 r
.63383 .60674 .6412 .61483 .65612 .61056 .64881 .60242 Mtetra
.656 .746 .916 r
.64881 .60242 .65612 .61056 .67113 .60628 .66387 .59809 Mtetra
.66387 .59809 .67113 .60628 .68621 .60198 .67901 .59376 Mtetra
.655 .746 .916 r
.67901 .59376 .68621 .60198 .70138 .59767 .69423 .58942 Mtetra
.655 .746 .917 r
.69423 .58942 .70138 .59767 .71663 .59334 .70953 .58508 Mtetra
.655 .747 .918 r
.70953 .58508 .71663 .59334 .73196 .58897 .72492 .58071 Mtetra
.655 .748 .918 r
.72492 .58071 .73196 .58897 .74737 .58455 .7404 .57632 Mtetra
.655 .75 .92 r
.7404 .57632 .74737 .58455 .76286 .58005 .75595 .5719 Mtetra
.655 .753 .922 r
.75595 .5719 .76286 .58005 .77843 .5755 .77159 .56743 Mtetra
.657 .757 .924 r
.77159 .56743 .77843 .5755 .79409 .57092 .78731 .56284 Mtetra
.659 .759 .924 r
.78731 .56284 .79409 .57092 .80983 .56643 .80311 .55817 Mtetra
.658 .755 .921 r
.80311 .55817 .80983 .56643 .82567 .56196 .819 .55349 Mtetra
.655 .75 .919 r
.819 .55349 .82567 .56196 .8416 .55749 .83499 .54892 Mtetra
.654 .748 .919 r
.83499 .54892 .8416 .55749 .85762 .55301 .85107 .54438 Mtetra
.654 .747 .919 r
.85107 .54438 .85762 .55301 .87373 .54847 .86724 .53984 Mtetra
.654 .749 .919 r
.86724 .53984 .87373 .54847 .8899 .54375 .8835 .53524 Mtetra
.657 .754 .921 r
.8835 .53524 .8899 .54375 .90617 .53899 .89984 .53048 Mtetra
.659 .756 .922 r
.89984 .53048 .90617 .53899 .92253 .53431 .91626 .52563 Mtetra
.656 .752 .92 r
.91626 .52563 .92253 .53431 .939 .52965 .93278 .52086 Mtetra
.655 .75 .92 r
.93278 .52086 .939 .52965 .95556 .52503 .94941 .51614 Mtetra
.653 .748 .919 r
.94941 .51614 .95556 .52503 .97221 .52031 .96613 .51144 Mtetra
.658 .75 .918 r
.36894 .67324 .37724 .68057 .39088 .67656 .38262 .66923 Mtetra
.656 .75 .919 r
.38262 .66923 .39088 .67656 .40459 .67258 .39637 .66527 Mtetra
.652 .751 .922 r
.39637 .66527 .40459 .67258 .41837 .66864 .41019 .6614 Mtetra
.654 .754 .924 r
.41019 .6614 .41837 .66864 .43221 .66478 .42408 .65745 Mtetra
.658 .754 .921 r
.42408 .65745 .43221 .66478 .44613 .66085 .43805 .65333 Mtetra
.659 .75 .917 r
.43805 .65333 .44613 .66085 .46012 .65676 .45209 .64917 Mtetra
.658 .749 .917 r
.45209 .64917 .46012 .65676 .47419 .65263 .4662 .64503 Mtetra
.655 .749 .919 r
.4662 .64503 .47419 .65263 .48833 .64849 .48038 .64096 Mtetra
.651 .751 .922 r
.48038 .64096 .48833 .64849 .50254 .64439 .49464 .63699 Mtetra
.652 .755 .926 r
.49464 .63699 .50254 .64439 .51682 .6404 .50897 .63297 Mtetra
.656 .757 .924 r
.50897 .63297 .51682 .6404 .53118 .6364 .52338 .62878 Mtetra
.658 .753 .92 r
.52338 .62878 .53118 .6364 .54561 .63233 .53787 .62452 Mtetra
.658 .75 .917 r
.53787 .62452 .54561 .63233 .56012 .62814 .55243 .62022 Mtetra
.659 .748 .916 r
.55243 .62022 .56012 .62814 .57471 .6239 .56706 .61589 Mtetra
.658 .746 .915 r
.56706 .61589 .57471 .6239 .58937 .61964 .58178 .61157 Mtetra
.657 .746 .915 r
.58178 .61157 .58937 .61964 .60411 .61535 .59657 .60725 Mtetra
.657 .746 .916 r
.59657 .60725 .60411 .61535 .61893 .61105 .61144 .60293 Mtetra
.656 .746 .916 r
.61144 .60293 .61893 .61105 .63383 .60674 .62639 .59861 Mtetra
.656 .747 .917 r
.62639 .59861 .63383 .60674 .64881 .60242 .64142 .59429 Mtetra
.656 .748 .918 r
.64142 .59429 .64881 .60242 .66387 .59809 .65654 .58992 Mtetra
.657 .748 .918 r
.65654 .58992 .66387 .59809 .67901 .59376 .67173 .58551 Mtetra
.656 .747 .917 r
.67173 .58551 .67901 .59376 .69423 .58942 .687 .58109 Mtetra
.656 .746 .917 r
.687 .58109 .69423 .58942 .70953 .58508 .70236 .57667 Mtetra
.655 .745 .916 r
.70236 .57667 .70953 .58508 .72492 .58071 .71781 .57225 Mtetra
.654 .745 .916 r
.71781 .57225 .72492 .58071 .7404 .57632 .73334 .56783 Mtetra
.654 .745 .917 r
.73334 .56783 .7404 .57632 .75595 .5719 .74896 .56342 Mtetra
.654 .746 .918 r
.74896 .56342 .75595 .5719 .77159 .56743 .76466 .55897 Mtetra
.654 .748 .919 r
.76466 .55897 .77159 .56743 .78731 .56284 .78046 .55448 Mtetra
.655 .752 .921 r
.78046 .55448 .78731 .56284 .80311 .55817 .79633 .54993 Mtetra
.658 .758 .923 r
.79633 .54993 .80311 .55817 .819 .55349 .81228 .54519 Mtetra
.659 .758 .923 r
.81228 .54519 .819 .55349 .83499 .54892 .82832 .5404 Mtetra
.657 .752 .92 r
.82832 .5404 .83499 .54892 .85107 .54438 .84445 .5357 Mtetra
.654 .748 .919 r
.84445 .5357 .85107 .54438 .86724 .53984 .86068 .53108 Mtetra
.653 .747 .919 r
.86068 .53108 .86724 .53984 .8835 .53524 .87701 .52647 Mtetra
.654 .748 .919 r
.87701 .52647 .8835 .53524 .89984 .53048 .89343 .52181 Mtetra
.657 .754 .921 r
.89343 .52181 .89984 .53048 .91626 .52563 .90993 .51697 Mtetra
.659 .756 .922 r
.90993 .51697 .91626 .52563 .93278 .52086 .92651 .51204 Mtetra
.656 .752 .92 r
.92651 .51204 .93278 .52086 .94941 .51614 .94319 .50721 Mtetra
.654 .75 .92 r
.94319 .50721 .94941 .51614 .96613 .51144 .95998 .50242 Mtetra
.656 .75 .919 r
.36056 .66588 .36894 .67324 .38262 .66923 .37429 .66188 Mtetra
.652 .751 .922 r
.37429 .66188 .38262 .66923 .39637 .66527 .38808 .65799 Mtetra
.653 .754 .924 r
.38808 .65799 .39637 .66527 .41019 .6614 .40194 .65404 Mtetra
.658 .754 .921 r
.40194 .65404 .41019 .6614 .42408 .65745 .41588 .6499 Mtetra
.659 .75 .917 r
.41588 .6499 .42408 .65745 .43805 .65333 .42989 .64571 Mtetra
.658 .749 .917 r
.42989 .64571 .43805 .65333 .45209 .64917 .44398 .64155 Mtetra
.654 .749 .92 r
.44398 .64155 .45209 .64917 .4662 .64503 .45813 .63752 Mtetra
.651 .752 .924 r
.45813 .63752 .4662 .64503 .48038 .64096 .47236 .63354 Mtetra
.654 .756 .925 r
.47236 .63354 .48038 .64096 .49464 .63699 .48667 .62944 Mtetra
.658 .755 .922 r
.48667 .62944 .49464 .63699 .50897 .63297 .50105 .62519 Mtetra
.659 .75 .917 r
.50105 .62519 .50897 .63297 .52338 .62878 .51551 .62087 Mtetra
.66 .748 .916 r
.51551 .62087 .52338 .62878 .53787 .62452 .53004 .61651 Mtetra
.658 .747 .915 r
.53004 .61651 .53787 .62452 .55243 .62022 .54465 .61218 Mtetra
.656 .746 .916 r
.54465 .61218 .55243 .62022 .56706 .61589 .55934 .60791 Mtetra
.653 .748 .919 r
.55934 .60791 .56706 .61589 .58178 .61157 .57411 .60374 Mtetra
.652 .753 .923 r
.57411 .60374 .58178 .61157 .59657 .60725 .58896 .59954 Mtetra
.653 .757 .926 r
.58896 .59954 .59657 .60725 .61144 .60293 .60388 .59529 Mtetra
.653 .76 .928 r
.60388 .59529 .61144 .60293 .62639 .59861 .61889 .59098 Mtetra
.654 .761 .928 r
.61889 .59098 .62639 .59861 .64142 .59429 .63398 .58662 Mtetra
.655 .762 .928 r
.63398 .58662 .64142 .59429 .65654 .58992 .64915 .58221 Mtetra
.64915 .58221 .65654 .58992 .67173 .58551 .6644 .57774 Mtetra
.656 .762 .928 r
.6644 .57774 .67173 .58551 .687 .58109 .67973 .57323 Mtetra
.657 .761 .926 r
.67973 .57323 .687 .58109 .70236 .57667 .69515 .56865 Mtetra
.658 .759 .924 r
.69515 .56865 .70236 .57667 .71781 .57225 .71064 .56403 Mtetra
.659 .755 .921 r
.71064 .56403 .71781 .57225 .73334 .56783 .72622 .55937 Mtetra
.656 .749 .918 r
.72622 .55937 .73334 .56783 .74896 .56342 .74189 .55481 Mtetra
.654 .745 .917 r
.74189 .55481 .74896 .56342 .76466 .55897 .75766 .55031 Mtetra
.653 .745 .917 r
.75766 .55031 .76466 .55897 .78046 .55448 .77351 .54583 Mtetra
.653 .746 .918 r
.77351 .54583 .78046 .55448 .79633 .54993 .78946 .54131 Mtetra
.654 .749 .919 r
.78946 .54131 .79633 .54993 .81228 .54519 .80548 .53672 Mtetra
.657 .755 .922 r
.80548 .53672 .81228 .54519 .82832 .5404 .82159 .53198 Mtetra
.66 .758 .923 r
.82159 .53198 .82832 .5404 .84445 .5357 .83778 .5271 Mtetra
.658 .754 .921 r
.83778 .5271 .84445 .5357 .86068 .53108 .85406 .52227 Mtetra
.654 .749 .919 r
.85406 .52227 .86068 .53108 .87701 .52647 .87045 .51758 Mtetra
.653 .747 .919 r
.87045 .51758 .87701 .52647 .89343 .52181 .88694 .5129 Mtetra
.654 .748 .919 r
.88694 .5129 .89343 .52181 .90993 .51697 .90352 .50817 Mtetra
.658 .754 .921 r
.90352 .50817 .90993 .51697 .92651 .51204 .92018 .50324 Mtetra
.659 .756 .922 r
.92018 .50324 .92651 .51204 .94319 .50721 .93692 .49823 Mtetra
.656 .751 .92 r
.93692 .49823 .94319 .50721 .95998 .50242 .95377 .49334 Mtetra
.653 .75 .921 r
.3521 .65848 .36056 .66588 .37429 .66188 .36586 .65455 Mtetra
.652 .753 .924 r
.36586 .65455 .37429 .66188 .38808 .65799 .3797 .65062 Mtetra
.658 .754 .921 r
.3797 .65062 .38808 .65799 .40194 .65404 .39361 .64647 Mtetra
.659 .75 .917 r
.39361 .64647 .40194 .65404 .41588 .6499 .4076 .64226 Mtetra
.658 .749 .917 r
.4076 .64226 .41588 .6499 .42989 .64571 .42166 .63807 Mtetra
.653 .749 .92 r
.42166 .63807 .42989 .64571 .44398 .64155 .43579 .63403 Mtetra
.65 .752 .924 r
.43579 .63403 .44398 .64155 .45813 .63752 .44999 .63005 Mtetra
.655 .756 .924 r
.44999 .63005 .45813 .63752 .47236 .63354 .46427 .62589 Mtetra
.658 .753 .92 r
.46427 .62589 .47236 .63354 .48667 .62944 .47862 .62159 Mtetra
.66 .75 .916 r
.47862 .62159 .48667 .62944 .50105 .62519 .49305 .61721 Mtetra
.659 .748 .915 r
.49305 .61721 .50105 .62519 .51551 .62087 .50756 .61284 Mtetra
.656 .746 .916 r
.50756 .61284 .51551 .62087 .53004 .61651 .52214 .60859 Mtetra
.651 .748 .921 r
.52214 .60859 .53004 .61651 .54465 .61218 .53681 .60449 Mtetra
.65 .755 .926 r
.53681 .60449 .54465 .61218 .55934 .60791 .55155 .60035 Mtetra
.652 .76 .929 r
.55155 .60035 .55934 .60791 .57411 .60374 .56637 .59612 Mtetra
.655 .761 .927 r
.56637 .59612 .57411 .60374 .58896 .59954 .58127 .59174 Mtetra
.656 .758 .925 r
.58127 .59174 .58896 .59954 .60388 .59529 .59625 .58733 Mtetra
.656 .755 .922 r
.59625 .58733 .60388 .59529 .61889 .59098 .61131 .58291 Mtetra
.656 .753 .921 r
.61131 .58291 .61889 .59098 .63398 .58662 .62645 .57847 Mtetra
.656 .752 .92 r
.62645 .57847 .63398 .58662 .64915 .58221 .64168 .57401 Mtetra
.656 .752 .921 r
.64168 .57401 .64915 .58221 .6644 .57774 .65699 .56954 Mtetra
.655 .752 .921 r
.65699 .56954 .6644 .57774 .67973 .57323 .67238 .56505 Mtetra
.655 .754 .923 r
.67238 .56505 .67973 .57323 .69515 .56865 .68786 .56055 Mtetra
.655 .757 .925 r
.68786 .56055 .69515 .56865 .71064 .56403 .70342 .55601 Mtetra
.658 .762 .926 r
.70342 .55601 .71064 .56403 .72622 .55937 .71906 .55133 Mtetra
.66 .763 .926 r
.71906 .55133 .72622 .55937 .74189 .55481 .73478 .54654 Mtetra
.66 .758 .923 r
.73478 .54654 .74189 .55481 .75766 .55031 .75059 .54172 Mtetra
.656 .75 .919 r
.75059 .54172 .75766 .55031 .77351 .54583 .7665 .53705 Mtetra
.653 .745 .917 r
.7665 .53705 .77351 .54583 .78946 .54131 .7825 .53249 Mtetra
.652 .745 .918 r
.7825 .53249 .78946 .54131 .80548 .53672 .7986 .52794 Mtetra
.653 .748 .919 r
.7986 .52794 .80548 .53672 .82159 .53198 .81478 .5233 Mtetra
.656 .753 .921 r
.81478 .5233 .82159 .53198 .83778 .5271 .83105 .51853 Mtetra
.66 .758 .923 r
.83105 .51853 .83778 .5271 .85406 .52227 .84739 .51355 Mtetra
.658 .755 .921 r
.84739 .51355 .85406 .52227 .87045 .51758 .86383 .50864 Mtetra
.654 .749 .92 r
.86383 .50864 .87045 .51758 .88694 .5129 .88038 .50387 Mtetra
.653 .748 .919 r
.88038 .50387 .88694 .5129 .90352 .50817 .89703 .49913 Mtetra
.654 .749 .919 r
.89703 .49913 .90352 .50817 .92018 .50324 .91378 .49431 Mtetra
.659 .755 .921 r
.91378 .49431 .92018 .50324 .93692 .49823 .93059 .48926 Mtetra
.658 .755 .921 r
.93059 .48926 .93692 .49823 .95377 .49334 .9475 .4842 Mtetra
.651 .752 .923 r
.34356 .65107 .3521 .65848 .36586 .65455 .35736 .64715 Mtetra
.656 .754 .922 r
.35736 .64715 .36586 .65455 .3797 .65062 .37125 .64303 Mtetra
.659 .751 .918 r
.37125 .64303 .3797 .65062 .39361 .64647 .38521 .6388 Mtetra
.658 .75 .917 r
.38521 .6388 .39361 .64647 .4076 .64226 .39924 .63458 Mtetra
.654 .749 .92 r
.39924 .63458 .4076 .64226 .42166 .63807 .41334 .6305 Mtetra
.65 .752 .924 r
.41334 .6305 .42166 .63807 .43579 .63403 .42751 .62652 Mtetra
.655 .756 .924 r
.42751 .62652 .43579 .63403 .44999 .63005 .44176 .62233 Mtetra
.659 .753 .919 r
.44176 .62233 .44999 .63005 .46427 .62589 .45609 .61799 Mtetra
.661 .75 .916 r
.45609 .61799 .46427 .62589 .47862 .62159 .4705 .61357 Mtetra
.659 .747 .915 r
.4705 .61357 .47862 .62159 .49305 .61721 .48498 .60921 Mtetra
.651 .746 .919 r
.48498 .60921 .49305 .61721 .50756 .61284 .49953 .60509 Mtetra
.649 .753 .926 r
.49953 .60509 .50756 .61284 .52214 .60859 .51417 .60102 Mtetra
.652 .76 .928 r
.51417 .60102 .52214 .60859 .53681 .60449 .52888 .59678 Mtetra
.656 .759 .925 r
.52888 .59678 .53681 .60449 .55155 .60035 .54367 .59238 Mtetra
.657 .753 .921 r
.54367 .59238 .55155 .60035 .56637 .59612 .55855 .58796 Mtetra
.657 .749 .918 r
.55855 .58796 .56637 .59612 .58127 .59174 .5735 .58353 Mtetra
.658 .75 .918 r
.5735 .58353 .58127 .59174 .59625 .58733 .58853 .57902 Mtetra
.657 .748 .917 r
.58853 .57902 .59625 .58733 .61131 .58291 .60365 .57453 Mtetra
.656 .747 .917 r
.60365 .57453 .61131 .58291 .62645 .57847 .61884 .57005 Mtetra
.61884 .57005 .62645 .57847 .64168 .57401 .63412 .56555 Mtetra
.63412 .56555 .64168 .57401 .65699 .56954 .64949 .56103 Mtetra
.655 .747 .917 r
.64949 .56103 .65699 .56954 .67238 .56505 .66494 .55651 Mtetra
.654 .747 .918 r
.66494 .55651 .67238 .56505 .68786 .56055 .68048 .55202 Mtetra
.655 .749 .919 r
.68048 .55202 .68786 .56055 .70342 .55601 .6961 .54745 Mtetra
.6961 .54745 .70342 .55601 .71906 .55133 .71181 .54286 Mtetra
.654 .752 .922 r
.71181 .54286 .71906 .55133 .73478 .54654 .7276 .53825 Mtetra
.658 .759 .925 r
.7276 .53825 .73478 .54654 .75059 .54172 .74348 .53348 Mtetra
.661 .763 .925 r
.74348 .53348 .75059 .54172 .7665 .53705 .75943 .52853 Mtetra
.66 .757 .922 r
.75943 .52853 .7665 .53705 .7825 .53249 .77548 .52362 Mtetra
.653 .747 .918 r
.77548 .52362 .7825 .53249 .7986 .52794 .79163 .51897 Mtetra
.652 .745 .918 r
.79163 .51897 .7986 .52794 .81478 .5233 .80789 .51437 Mtetra
.653 .747 .919 r
.80789 .51437 .81478 .5233 .83105 .51853 .82423 .50968 Mtetra
.656 .752 .92 r
.82423 .50968 .83105 .51853 .84739 .51355 .84066 .50483 Mtetra
.66 .758 .922 r
.84066 .50483 .84739 .51355 .86383 .50864 .85716 .49976 Mtetra
.658 .754 .921 r
.85716 .49976 .86383 .50864 .88038 .50387 .87376 .49479 Mtetra
.654 .749 .92 r
.87376 .49479 .88038 .50387 .89703 .49913 .89048 .48996 Mtetra
.653 .748 .919 r
.89048 .48996 .89703 .49913 .91378 .49431 .90729 .48514 Mtetra
.655 .75 .919 r
.90729 .48514 .91378 .49431 .93059 .48926 .9242 .48019 Mtetra
.659 .755 .921 r
.9242 .48019 .93059 .48926 .9475 .4842 .94117 .47503 Mtetra
.654 .753 .923 r
.33493 .64364 .34356 .65107 .35736 .64715 .34878 .63959 Mtetra
.659 .752 .919 r
.34878 .63959 .35736 .64715 .37125 .64303 .36271 .63534 Mtetra
.659 .75 .917 r
.36271 .63534 .37125 .64303 .38521 .6388 .37672 .63108 Mtetra
.655 .749 .919 r
.37672 .63108 .38521 .6388 .39924 .63458 .39079 .62693 Mtetra
.65 .751 .923 r
.39079 .62693 .39924 .63458 .41334 .6305 .40493 .62294 Mtetra
.654 .755 .924 r
.40493 .62294 .41334 .6305 .42751 .62652 .41916 .61876 Mtetra
.659 .753 .919 r
.41916 .61876 .42751 .62652 .44176 .62233 .43346 .6144 Mtetra
.661 .75 .916 r
.43346 .6144 .44176 .62233 .45609 .61799 .44784 .60995 Mtetra
.658 .747 .916 r
.44784 .60995 .45609 .61799 .4705 .61357 .46229 .60558 Mtetra
.649 .747 .921 r
.46229 .60558 .4705 .61357 .48498 .60921 .47682 .60153 Mtetra
.648 .756 .928 r
.47682 .60153 .48498 .60921 .49953 .60509 .49142 .59746 Mtetra
.656 .76 .926 r
.49142 .59746 .49953 .60509 .51417 .60102 .50611 .59306 Mtetra
.657 .753 .921 r
.50611 .59306 .51417 .60102 .52888 .59678 .52087 .58863 Mtetra
.659 .75 .917 r
.52087 .58863 .52888 .59678 .54367 .59238 .53572 .58412 Mtetra
.657 .748 .917 r
.53572 .58412 .54367 .59238 .55855 .58796 .55064 .57968 Mtetra
.651 .747 .92 r
.55064 .57968 .55855 .58796 .5735 .58353 .56565 .57542 Mtetra
.647 .75 .925 r
.56565 .57542 .5735 .58353 .58853 .57902 .58075 .57127 Mtetra
.642 .76 .934 r
.58075 .57127 .58853 .57902 .60365 .57453 .59593 .56721 Mtetra
.644 .773 .942 r
.59593 .56721 .60365 .57453 .61884 .57005 .61119 .56298 Mtetra
.651 .784 .945 r
.61119 .56298 .61884 .57005 .63412 .56555 .62654 .55844 Mtetra
.66 .786 .942 r
.62654 .55844 .63412 .56555 .64949 .56103 .64195 .55357 Mtetra
.665 .78 .934 r
.64195 .55357 .64949 .56103 .66494 .55651 .65745 .54854 Mtetra
.663 .767 .927 r
.65745 .54854 .66494 .55651 .68048 .55202 .67303 .54359 Mtetra
.661 .755 .92 r
.67303 .54359 .68048 .55202 .6961 .54745 .6887 .53875 Mtetra
.655 .748 .918 r
.6887 .53875 .6961 .54745 .71181 .54286 .70446 .5341 Mtetra
.653 .747 .918 r
.70446 .5341 .71181 .54286 .7276 .53825 .72033 .52951 Mtetra
.654 .749 .919 r
.72033 .52951 .7276 .53825 .74348 .53348 .73627 .52484 Mtetra
.655 .753 .922 r
.73627 .52484 .74348 .53348 .75943 .52853 .75231 .52013 Mtetra
.662 .762 .925 r
.75231 .52013 .75943 .52853 .77548 .52362 .76841 .51509 Mtetra
.662 .76 .923 r
.76841 .51509 .77548 .52362 .79163 .51897 .78461 .51002 Mtetra
.654 .748 .919 r
.78461 .51002 .79163 .51897 .80789 .51437 .80092 .50527 Mtetra
.651 .745 .918 r
.80092 .50527 .80789 .51437 .82423 .50968 .81733 .5006 Mtetra
.653 .747 .919 r
.81733 .5006 .82423 .50968 .84066 .50483 .83384 .49584 Mtetra
.657 .752 .92 r
.83384 .49584 .84066 .50483 .85716 .49976 .85042 .49088 Mtetra
.661 .758 .922 r
.85042 .49088 .85716 .49976 .87376 .49479 .86708 .48572 Mtetra
.656 .753 .921 r
.86708 .48572 .87376 .49479 .89048 .48996 .88385 .48073 Mtetra
.653 .748 .92 r
.88385 .48073 .89048 .48996 .90729 .48514 .90074 .47584 Mtetra
.653 .748 .919 r
.90074 .47584 .90729 .48514 .9242 .48019 .91772 .47093 Mtetra
.657 .752 .92 r
.91772 .47093 .9242 .48019 .94117 .47503 .93478 .46581 Mtetra
.658 .754 .921 r
.32621 .63611 .33493 .64364 .34878 .63959 .34012 .63188 Mtetra
.66 .751 .917 r
.34012 .63188 .34878 .63959 .36271 .63534 .3541 .62758 Mtetra
.658 .75 .918 r
.3541 .62758 .36271 .63534 .37672 .63108 .36815 .62333 Mtetra
.65 .749 .922 r
.36815 .62333 .37672 .63108 .39079 .62693 .38226 .61932 Mtetra
.652 .754 .925 r
.38226 .61932 .39079 .62693 .40493 .62294 .39645 .61519 Mtetra
.659 .754 .92 r
.39645 .61519 .40493 .62294 .41916 .61876 .41073 .61082 Mtetra
.661 .75 .916 r
.41073 .61082 .41916 .61876 .43346 .6144 .42508 .60634 Mtetra
.659 .748 .916 r
.42508 .60634 .43346 .6144 .44784 .60995 .43951 .60194 Mtetra
.648 .747 .922 r
.43951 .60194 .44784 .60995 .46229 .60558 .454 .5979 Mtetra
.649 .757 .928 r
.454 .5979 .46229 .60558 .47682 .60153 .46857 .59377 Mtetra
.657 .758 .924 r
.46857 .59377 .47682 .60153 .49142 .59746 .48323 .58933 Mtetra
.658 .75 .918 r
.48323 .58933 .49142 .59746 .50611 .59306 .49797 .58486 Mtetra
.658 .749 .917 r
.49797 .58486 .50611 .59306 .52087 .58863 .51279 .58036 Mtetra
.645 .745 .922 r
.51279 .58036 .52087 .58863 .53572 .58412 .52769 .5763 Mtetra
.619 .749 .939 r
.52769 .5763 .53572 .58412 .55064 .57968 .54267 .57301 Mtetra
.597 .775 .965 r
.54267 .57301 .55064 .57968 .56565 .57542 .55775 .57002 Mtetra
.583 .809 .986 r
.55775 .57002 .56565 .57542 .58075 .57127 .57293 .56685 Mtetra
.576 .838 .995 r
.57293 .56685 .58075 .57127 .59593 .56721 .58819 .56331 Mtetra
.584 .858 .995 r
.58819 .56331 .59593 .56721 .61119 .56298 .60354 .55928 Mtetra
.603 .871 .992 r
.60354 .55928 .61119 .56298 .62654 .55844 .61896 .55469 Mtetra
.627 .878 .988 r
.61896 .55469 .62654 .55844 .64195 .55357 .63445 .54956 Mtetra
.651 .879 .982 r
.63445 .54956 .64195 .55357 .65745 .54854 .65 .54392 Mtetra
.673 .868 .973 r
.65 .54392 .65745 .54854 .67303 .54359 .66562 .53789 Mtetra
.688 .841 .957 r
.66562 .53789 .67303 .54359 .6887 .53875 .6813 .53168 Mtetra
.684 .802 .938 r
.6813 .53168 .6887 .53875 .70446 .5341 .69708 .52577 Mtetra
.665 .764 .924 r
.69708 .52577 .70446 .5341 .72033 .52951 .71297 .52063 Mtetra
.654 .748 .919 r
.71297 .52063 .72033 .52951 .73627 .52484 .72898 .51593 Mtetra
.72898 .51593 .73627 .52484 .75231 .52013 .74508 .51121 Mtetra
.654 .749 .92 r
.74508 .51121 .75231 .52013 .76841 .51509 .76127 .50645 Mtetra
.661 .76 .923 r
.76127 .50645 .76841 .51509 .78461 .51002 .77754 .50137 Mtetra
.663 .761 .923 r
.77754 .50137 .78461 .51002 .80092 .50527 .79388 .49619 Mtetra
.653 .748 .919 r
.79388 .49619 .80092 .50527 .81733 .5006 .81036 .49137 Mtetra
.651 .745 .919 r
.81036 .49137 .81733 .5006 .83384 .49584 .82693 .48664 Mtetra
.653 .748 .919 r
.82693 .48664 .83384 .49584 .85042 .49088 .8436 .48179 Mtetra
.659 .754 .92 r
.8436 .48179 .85042 .49088 .86708 .48572 .86034 .47668 Mtetra
.661 .757 .922 r
.86034 .47668 .86708 .48572 .88385 .48073 .87716 .47144 Mtetra
.654 .75 .92 r
.87716 .47144 .88385 .48073 .90074 .47584 .89411 .46645 Mtetra
.653 .748 .92 r
.89411 .46645 .90074 .47584 .91772 .47093 .91117 .4615 Mtetra
.654 .749 .92 r
.91117 .4615 .91772 .47093 .93478 .46581 .92832 .45647 Mtetra
.66 .752 .918 r
.31742 .62841 .32621 .63611 .34012 .63188 .33137 .62409 Mtetra
.659 .75 .918 r
.33137 .62409 .34012 .63188 .3541 .62758 .3454 .61978 Mtetra
.653 .749 .921 r
.3454 .61978 .3541 .62758 .36815 .62333 .35948 .61565 Mtetra
.65 .753 .925 r
.35948 .61565 .36815 .62333 .38226 .61932 .37364 .6116 Mtetra
.658 .755 .922 r
.37364 .6116 .38226 .61932 .39645 .61519 .38789 .60724 Mtetra
.661 .751 .917 r
.38789 .60724 .39645 .61519 .41073 .61082 .40221 .60275 Mtetra
.66 .749 .916 r
.40221 .60275 .41073 .61082 .42508 .60634 .41661 .59828 Mtetra
.649 .747 .921 r
.41661 .59828 .42508 .60634 .43951 .60194 .43108 .59419 Mtetra
.648 .756 .928 r
.43108 .59419 .43951 .60194 .454 .5979 .44562 .59007 Mtetra
.657 .757 .924 r
.44562 .59007 .454 .5979 .46857 .59377 .46025 .5856 Mtetra
.659 .751 .918 r
.46025 .5856 .46857 .59377 .48323 .58933 .47497 .58106 Mtetra
.653 .747 .919 r
.47497 .58106 .48323 .58933 .49797 .58486 .48975 .57672 Mtetra
.623 .742 .932 r
.48975 .57672 .49797 .58486 .51279 .58036 .50462 .57338 Mtetra
.571 .757 .966 r
.50462 .57338 .51279 .58036 .52769 .5763 .51957 .57114 Mtetra
.523 .795 .995 r
.51957 .57114 .52769 .5763 .54267 .57301 .53462 .56907 Mtetra
.473 .812 .999 r
.53462 .56907 .54267 .57301 .55775 .57002 .54978 .56706 Mtetra
.458 .833 .99 r
.54978 .56706 .55775 .57002 .57293 .56685 .56504 .56453 Mtetra
.473 .856 .981 r
.56504 .56453 .57293 .56685 .58819 .56331 .58039 .56124 Mtetra
.503 .876 .978 r
.58039 .56124 .58819 .56331 .60354 .55928 .59582 .55725 Mtetra
.537 .892 .978 r
.59582 .55725 .60354 .55928 .61896 .55469 .61133 .55263 Mtetra
.573 .905 .978 r
.61133 .55263 .61896 .55469 .63445 .54956 .62691 .54737 Mtetra
.612 .917 .977 r
.62691 .54737 .63445 .54956 .65 .54392 .64254 .54141 Mtetra
.656 .924 .975 r
.64254 .54141 .65 .54392 .66562 .53789 .65822 .53466 Mtetra
.692 .916 .971 r
.65822 .53466 .66562 .53789 .6813 .53168 .67395 .52738 Mtetra
.704 .889 .965 r
.67395 .52738 .6813 .53168 .69708 .52577 .68975 .52014 Mtetra
.708 .853 .951 r
.68975 .52014 .69708 .52577 .71297 .52063 .70562 .51306 Mtetra
.683 .793 .933 r
.70562 .51306 .71297 .52063 .72898 .51593 .72162 .50709 Mtetra
.658 .753 .92 r
.72162 .50709 .72898 .51593 .74508 .51121 .73778 .50214 Mtetra
.653 .747 .919 r
.73778 .50214 .74508 .51121 .76127 .50645 .75404 .49739 Mtetra
.654 .749 .92 r
.75404 .49739 .76127 .50645 .77754 .50137 .77039 .49255 Mtetra
.662 .759 .922 r
.77039 .49255 .77754 .50137 .79388 .49619 .7868 .48736 Mtetra
.662 .76 .923 r
.7868 .48736 .79388 .49619 .81036 .49137 .80331 .48213 Mtetra
.652 .747 .919 r
.80331 .48213 .81036 .49137 .82693 .48664 .81995 .47729 Mtetra
.651 .746 .919 r
.81995 .47729 .82693 .48664 .8436 .48179 .83669 .47247 Mtetra
.654 .749 .92 r
.83669 .47247 .8436 .48179 .86034 .47668 .85352 .4675 Mtetra
.661 .757 .921 r
.85352 .4675 .86034 .47668 .87716 .47144 .87042 .4622 Mtetra
.658 .755 .922 r
.87042 .4622 .87716 .47144 .89411 .46645 .88742 .45699 Mtetra
.653 .749 .92 r
.88742 .45699 .89411 .46645 .91117 .4615 .90454 .45195 Mtetra
.653 .748 .92 r
.90454 .45195 .91117 .4615 .92832 .45647 .92178 .44692 Mtetra
.66 .751 .918 r
.30855 .62061 .31742 .62841 .33137 .62409 .32254 .61624 Mtetra
.657 .75 .919 r
.32254 .61624 .33137 .62409 .3454 .61978 .33661 .61195 Mtetra
.649 .75 .923 r
.33661 .61195 .3454 .61978 .35948 .61565 .35074 .60791 Mtetra
.654 .754 .923 r
.35074 .60791 .35948 .61565 .37364 .6116 .36495 .60366 Mtetra
.66 .752 .918 r
.36495 .60366 .37364 .6116 .38789 .60724 .37924 .59918 Mtetra
.662 .75 .916 r
.37924 .59918 .38789 .60724 .40221 .60275 .39362 .59463 Mtetra
.652 .747 .92 r
.39362 .59463 .40221 .60275 .41661 .59828 .40806 .59041 Mtetra
.646 .753 .927 r
.40806 .59041 .41661 .59828 .43108 .59419 .42257 .58636 Mtetra
.657 .758 .924 r
.42257 .58636 .43108 .59419 .44562 .59007 .43717 .58188 Mtetra
.66 .751 .918 r
.43717 .58188 .44562 .59007 .46025 .5856 .45185 .57731 Mtetra
.651 .747 .92 r
.45185 .57731 .46025 .5856 .47497 .58106 .46661 .57301 Mtetra
.602 .739 .941 r
.46661 .57301 .47497 .58106 .48975 .57672 .48143 .57024 Mtetra
.527 .757 .98 r
.48143 .57024 .48975 .57672 .50462 .57338 .49633 .56873 Mtetra
.436 .774 .997 r
.49633 .56873 .50462 .57338 .51957 .57114 .51134 .56776 Mtetra
.388 .788 .985 r
.51134 .56776 .51957 .57114 .53462 .56907 .52647 .56652 Mtetra
.424 .827 .979 r
.52647 .56652 .53462 .56907 .54978 .56706 .5417 .56411 Mtetra
.543 .87 .993 r
.5417 .56411 .54978 .56706 .56504 .56453 .55702 .56018 Mtetra
.619 .858 .988 r
.55702 .56018 .56504 .56453 .58039 .56124 .57243 .55553 Mtetra
.643 .826 .97 r
.57243 .55553 .58039 .56124 .59582 .55725 .58791 .55075 Mtetra
.645 .805 .959 r
.58791 .55075 .59582 .55725 .61133 .55263 .60349 .54608 Mtetra
.641 .803 .961 r
.60349 .54608 .61133 .55263 .62691 .54737 .61916 .54153 Mtetra
.637 .824 .972 r
.61916 .54153 .62691 .54737 .64254 .54141 .63491 .53685 Mtetra
.644 .866 .982 r
.63491 .53685 .64254 .54141 .65822 .53466 .65073 .53143 Mtetra
.677 .913 .975 r
.65073 .53143 .65822 .53466 .67395 .52738 .66656 .52447 Mtetra
.712 .931 .962 r
.66656 .52447 .67395 .52738 .68975 .52014 .68241 .51631 Mtetra
.732 .911 .956 r
.68241 .51631 .68975 .52014 .70562 .51306 .69831 .50786 Mtetra
.726 .873 .95 r
.69831 .50786 .70562 .51306 .72162 .50709 .71429 .49993 Mtetra
.698 .812 .936 r
.71429 .49993 .72162 .50709 .73778 .50214 .73041 .49328 Mtetra
.66 .757 .922 r
.73041 .49328 .73778 .50214 .75404 .49739 .74672 .48817 Mtetra
.652 .747 .919 r
.74672 .48817 .75404 .49739 .77039 .49255 .76314 .48335 Mtetra
.654 .749 .92 r
.76314 .48335 .77039 .49255 .7868 .48736 .77965 .47843 Mtetra
.664 .761 .922 r
.77965 .47843 .7868 .48736 .80331 .48213 .79622 .47306 Mtetra
.659 .757 .922 r
.79622 .47306 .80331 .48213 .81995 .47729 .8129 .46787 Mtetra
.651 .746 .92 r
.8129 .46787 .81995 .47729 .83669 .47247 .82971 .463 Mtetra
.652 .747 .919 r
.82971 .463 .83669 .47247 .85352 .4675 .84661 .45807 Mtetra
.657 .751 .919 r
.84661 .45807 .85352 .4675 .87042 .4622 .8636 .45288 Mtetra
.661 .757 .921 r
.8636 .45288 .87042 .4622 .88742 .45699 .88066 .44747 Mtetra
.655 .751 .921 r
.88066 .44747 .88742 .45699 .90454 .45195 .89785 .44232 Mtetra
.652 .748 .92 r
.89785 .44232 .90454 .45195 .92178 .44692 .91516 .43724 Mtetra
.659 .751 .918 r
.29959 .61272 .30855 .62061 .32254 .61624 .31363 .60834 Mtetra
.653 .75 .921 r
.31363 .60834 .32254 .61624 .33661 .61195 .32773 .60414 Mtetra
.65 .752 .925 r
.32773 .60414 .33661 .61195 .35074 .60791 .3419 .60003 Mtetra
.659 .754 .921 r
.3419 .60003 .35074 .60791 .36495 .60366 .35617 .59559 Mtetra
.662 .751 .916 r
.35617 .59559 .36495 .60366 .37924 .59918 .37052 .59101 Mtetra
.658 .749 .917 r
.37052 .59101 .37924 .59918 .39362 .59463 .38493 .58657 Mtetra
.645 .749 .925 r
.38493 .58657 .39362 .59463 .40806 .59041 .39941 .58252 Mtetra
.654 .757 .925 r
.39941 .58252 .40806 .59041 .42257 .58636 .41398 .57815 Mtetra
.659 .751 .918 r
.41398 .57815 .42257 .58636 .43717 .58188 .42863 .57359 Mtetra
.655 .749 .919 r
.42863 .57359 .43717 .58188 .45185 .57731 .44336 .56915 Mtetra
.6 .736 .94 r
.44336 .56915 .45185 .57731 .46661 .57301 .45814 .56643 Mtetra
.503 .745 .982 r
.45814 .56643 .46661 .57301 .48143 .57024 .47298 .56541 Mtetra
.384 .745 .992 r
.47298 .56541 .48143 .57024 .49633 .56873 .48793 .56527 Mtetra
.366 .775 .982 r
.48793 .56527 .49633 .56873 .51134 .56776 .50301 .56435 Mtetra
.534 .854 .997 r
.50301 .56435 .51134 .56776 .52647 .56652 .51821 .56091 Mtetra
.665 .832 .964 r
.51821 .56091 .52647 .56652 .5417 .56411 .5335 .55554 Mtetra
.693 .762 .905 r
.5335 .55554 .5417 .56411 .55702 .56018 .54886 .54933 Mtetra
.693 .715 .866 r
.54886 .54933 .55702 .56018 .57243 .55553 .56428 .54278 Mtetra
.675 .677 .844 r
.56428 .54278 .57243 .55553 .58791 .55075 .57979 .53687 Mtetra
.65 .65 .837 r
.57979 .53687 .58791 .55075 .60349 .54608 .5954 .53215 Mtetra
.627 .64 .844 r
.5954 .53215 .60349 .54608 .61916 .54153 .61113 .52862 Mtetra
.613 .651 .864 r
.61113 .52862 .61916 .54153 .63491 .53685 .62698 .52574 Mtetra
.618 .687 .892 r
.62698 .52574 .63491 .53685 .65073 .53143 .64293 .52252 Mtetra
.634 .744 .927 r
.64293 .52252 .65073 .53143 .66656 .52447 .65895 .51846 Mtetra
.676 .837 .96 r
.65895 .51846 .66656 .52447 .68241 .51631 .67498 .51244 Mtetra
.734 .912 .955 r
.67498 .51244 .68241 .51631 .69831 .50786 .69097 .50385 Mtetra
.756 .913 .944 r
.69097 .50385 .69831 .50786 .71429 .49993 .70696 .49445 Mtetra
.74 .871 .941 r
.70696 .49445 .71429 .49993 .73041 .49328 .72306 .48591 Mtetra
.7 .811 .934 r
.72306 .48591 .73041 .49328 .74672 .48817 .73934 .47909 Mtetra
.657 .754 .922 r
.73934 .47909 .74672 .48817 .76314 .48335 .75581 .47404 Mtetra
.653 .748 .92 r
.75581 .47404 .76314 .48335 .77965 .47843 .77239 .46911 Mtetra
.657 .751 .919 r
.77239 .46911 .77965 .47843 .79622 .47306 .78905 .46397 Mtetra
.665 .761 .922 r
.78905 .46397 .79622 .47306 .8129 .46787 .80578 .45849 Mtetra
.654 .751 .921 r
.80578 .45849 .8129 .46787 .82971 .463 .82265 .45342 Mtetra
.65 .746 .92 r
.82265 .45342 .82971 .463 .84661 .45807 .83963 .44849 Mtetra
.653 .749 .92 r
.83963 .44849 .84661 .45807 .8636 .45288 .8567 .4434 Mtetra
.661 .755 .92 r
.8567 .4434 .8636 .45288 .88066 .44747 .87384 .43796 Mtetra
.658 .755 .921 r
.87384 .43796 .88066 .44747 .89785 .44232 .89109 .43261 Mtetra
.653 .749 .92 r
.89109 .43261 .89785 .44232 .91516 .43724 .90846 .42745 Mtetra
.658 .751 .918 r
.29054 .60477 .29959 .61272 .31363 .60834 .30462 .60038 Mtetra
.65 .75 .923 r
.30462 .60038 .31363 .60834 .32773 .60414 .31876 .59626 Mtetra
.653 .753 .923 r
.31876 .59626 .32773 .60414 .3419 .60003 .33299 .59198 Mtetra
.661 .752 .918 r
.33299 .59198 .3419 .60003 .35617 .59559 .3473 .58743 Mtetra
.662 .751 .916 r
.3473 .58743 .35617 .59559 .37052 .59101 .3617 .58281 Mtetra
.65 .748 .921 r
.3617 .58281 .37052 .59101 .38493 .58657 .37615 .57859 Mtetra
.647 .754 .927 r
.37615 .57859 .38493 .58657 .39941 .58252 .39068 .57442 Mtetra
.658 .754 .921 r
.39068 .57442 .39941 .58252 .41398 .57815 .40531 .56985 Mtetra
.659 .751 .918 r
.40531 .56985 .41398 .57815 .42863 .57359 .42001 .56522 Mtetra
.619 .738 .932 r
.42001 .56522 .42863 .57359 .44336 .56915 .43476 .56194 Mtetra
.508 .73 .973 r
.43476 .56194 .44336 .56915 .45814 .56643 .44954 .56106 Mtetra
.372 .724 .989 r
.44954 .56106 .45814 .56643 .47298 .56541 .46442 .56141 Mtetra
.36 .758 .985 r
.46442 .56141 .47298 .56541 .48793 .56527 .47944 .56094 Mtetra
.598 .85 .992 r
.47944 .56094 .48793 .56527 .50301 .56435 .4946 .55681 Mtetra
.708 .79 .915 r
.4946 .55681 .50301 .56435 .51821 .56091 .50987 .55005 Mtetra
.735 .727 .844 r
.50987 .55005 .51821 .56091 .5335 .55554 .52521 .54098 Mtetra
.714 .666 .802 r
.52521 .54098 .5335 .55554 .54886 .54933 .54059 .53187 Mtetra
.685 .623 .78 r
.54059 .53187 .54886 .54933 .56428 .54278 .55602 .52393 Mtetra
.66 .599 .775 r
.55602 .52393 .56428 .54278 .57979 .53687 .57154 .51754 Mtetra
.637 .583 .777 r
.57154 .51754 .57979 .53687 .5954 .53215 .58716 .51276 Mtetra
.613 .571 .782 r
.58716 .51276 .5954 .53215 .61113 .52862 .6029 .50957 Mtetra
.588 .561 .791 r
.6029 .50957 .61113 .52862 .62698 .52574 .6188 .50796 Mtetra
.565 .563 .81 r
.6188 .50796 .62698 .52574 .64293 .52252 .63485 .50755 Mtetra
.559 .596 .847 r
.63485 .50755 .64293 .52252 .65895 .51846 .65104 .50713 Mtetra
.604 .681 .896 r
.65104 .50713 .65895 .51846 .67498 .51244 .66727 .50438 Mtetra
.665 .781 .935 r
.66727 .50438 .67498 .51244 .69097 .50385 .68349 .49896 Mtetra
.753 .89 .94 r
.68349 .49896 .69097 .50385 .70696 .49445 .69959 .48979 Mtetra
.771 .901 .932 r
.69959 .48979 .70696 .49445 .72306 .48591 .71571 .47977 Mtetra
.745 .858 .932 r
.71571 .47977 .72306 .48591 .73934 .47909 .73194 .47098 Mtetra
.686 .791 .929 r
.73194 .47098 .73934 .47909 .75581 .47404 .7484 .46463 Mtetra
.653 .748 .92 r
.7484 .46463 .75581 .47404 .77239 .46911 .76505 .45966 Mtetra
.654 .749 .92 r
.76505 .45966 .77239 .46911 .78905 .46397 .7818 .45463 Mtetra
.663 .757 .92 r
.7818 .45463 .78905 .46397 .80578 .45849 .7986 .44919 Mtetra
.661 .758 .922 r
.7986 .44919 .80578 .45849 .82265 .45342 .81552 .44378 Mtetra
.65 .747 .92 r
.81552 .44378 .82265 .45342 .83963 .44849 .83257 .43879 Mtetra
.652 .747 .92 r
.83257 .43879 .83963 .44849 .8567 .4434 .84972 .43371 Mtetra
.658 .752 .919 r
.84972 .43371 .8567 .4434 .87384 .43796 .86694 .42835 Mtetra
.661 .756 .921 r
.86694 .42835 .87384 .43796 .89109 .43261 .88425 .42282 Mtetra
.654 .75 .921 r
.88425 .42282 .89109 .43261 .90846 .42745 .9017 .41755 Mtetra
.656 .75 .92 r
.2814 .59675 .29054 .60477 .30462 .60038 .29552 .5924 Mtetra
.649 .751 .924 r
.29552 .5924 .30462 .60038 .31876 .59626 .3097 .58827 Mtetra
.657 .754 .921 r
.3097 .58827 .31876 .59626 .33299 .59198 .32398 .58382 Mtetra
.662 .752 .917 r
.32398 .58382 .33299 .59198 .3473 .58743 .33835 .57918 Mtetra
.659 .75 .917 r
.33835 .57918 .3473 .58743 .3617 .58281 .35279 .57462 Mtetra
.645 .749 .925 r
.35279 .57462 .3617 .58281 .37615 .57859 .36728 .57053 Mtetra
.654 .755 .924 r
.36728 .57053 .37615 .57859 .39068 .57442 .38187 .56609 Mtetra
.66 .751 .918 r
.38187 .56609 .39068 .57442 .40531 .56985 .39655 .56141 Mtetra
.646 .746 .922 r
.39655 .56141 .40531 .56985 .42001 .56522 .41128 .55722 Mtetra
.546 .725 .957 r
.41128 .55722 .42001 .56522 .43476 .56194 .42603 .55578 Mtetra
.4 .715 .987 r
.42603 .55578 .43476 .56194 .44954 .56106 .44083 .55617 Mtetra
.338 .723 .984 r
.44083 .55617 .44954 .56106 .46442 .56141 .45576 .55657 Mtetra
.587 .832 .991 r
.45576 .55657 .46442 .56141 .47944 .56094 .47089 .55289 Mtetra
.723 .781 .898 r
.47089 .55289 .47944 .56094 .4946 .55681 .48615 .54532 Mtetra
.759 .723 .819 r
.48615 .54532 .4946 .55681 .50987 .55005 .5015 .53413 Mtetra
.729 .657 .778 r
.5015 .53413 .50987 .55005 .52521 .54098 .51687 .52303 Mtetra
.696 .624 .772 r
.51687 .52303 .52521 .54098 .54059 .53187 .53227 .51397 Mtetra
.676 .615 .78 r
.53227 .51397 .54059 .53187 .55602 .52393 .54774 .50663 Mtetra
.659 .614 .792 r
.54774 .50663 .55602 .52393 .57154 .51754 .56328 .50069 Mtetra
.643 .612 .803 r
.56328 .50069 .57154 .51754 .58716 .51276 .57892 .49585 Mtetra
.625 .603 .808 r
.57892 .49585 .58716 .51276 .6029 .50957 .59467 .49209 Mtetra
.6 .584 .807 r
.59467 .49209 .6029 .50957 .6188 .50796 .61056 .48975 Mtetra
.568 .56 .805 r
.61056 .48975 .6188 .50796 .63485 .50755 .62662 .48917 Mtetra
.526 .537 .809 r
.62662 .48917 .63485 .50755 .65104 .50713 .64288 .49066 Mtetra
.514 .554 .834 r
.64288 .49066 .65104 .50713 .66727 .50438 .65931 .49229 Mtetra
.586 .661 .89 r
.65931 .49229 .66727 .50438 .68349 .49896 .67574 .49027 Mtetra
.678 .773 .922 r
.67574 .49027 .68349 .49896 .69959 .48979 .69209 .48428 Mtetra
.774 .879 .923 r
.69209 .48428 .69959 .48979 .71571 .47977 .70829 .47411 Mtetra
.774 .877 .923 r
.70829 .47411 .71571 .47977 .73194 .47098 .72454 .46392 Mtetra
.732 .834 .928 r
.72454 .46392 .73194 .47098 .7484 .46463 .74095 .45559 Mtetra
.665 .764 .924 r
.74095 .45559 .7484 .46463 .76505 .45966 .75763 .45007 Mtetra
.652 .747 .92 r
.75763 .45007 .76505 .45966 .7818 .45463 .77445 .44504 Mtetra
.657 .751 .919 r
.77445 .44504 .7818 .45463 .7986 .44919 .79135 .43977 Mtetra
.665 .76 .92 r
.79135 .43977 .7986 .44919 .81552 .44378 .80832 .43413 Mtetra
.653 .75 .921 r
.80832 .43413 .81552 .44378 .83257 .43879 .82543 .42897 Mtetra
.65 .747 .92 r
.82543 .42897 .83257 .43879 .84972 .43371 .84265 .4239 Mtetra
.655 .75 .92 r
.84265 .4239 .84972 .43371 .86694 .42835 .85997 .41861 Mtetra
.662 .756 .92 r
.85997 .41861 .86694 .42835 .88425 .42282 .87735 .41298 Mtetra
.656 .753 .921 r
.87735 .41298 .88425 .42282 .9017 .41755 .89486 .40757 Mtetra
.653 .75 .921 r
.27216 .58867 .2814 .59675 .29552 .5924 .28633 .58437 Mtetra
.65 .752 .924 r
.28633 .58437 .29552 .5924 .3097 .58827 .30056 .58015 Mtetra
.659 .753 .919 r
.30056 .58015 .3097 .58827 .32398 .58382 .31489 .57558 Mtetra
.662 .752 .917 r
.31489 .57558 .32398 .58382 .33835 .57918 .32931 .57087 Mtetra
.653 .749 .92 r
.32931 .57087 .33835 .57918 .35279 .57462 .34378 .56646 Mtetra
.645 .751 .927 r
.34378 .56646 .35279 .57462 .36728 .57053 .35832 .56231 Mtetra
.658 .755 .921 r
.35832 .56231 .36728 .57053 .38187 .56609 .37297 .55767 Mtetra
.659 .751 .918 r
.37297 .55767 .38187 .56609 .39655 .56141 .38769 .55297 Mtetra
.608 .736 .936 r
.38769 .55297 .39655 .56141 .41128 .55722 .40244 .54995 Mtetra
.469 .716 .977 r
.40244 .54995 .41128 .55722 .42603 .55578 .41719 .54973 Mtetra
.331 .686 .98 r
.41719 .54973 .42603 .55578 .44083 .55617 .43202 .55095 Mtetra
.497 .789 .997 r
.43202 .55095 .44083 .55617 .45576 .55657 .44706 .54916 Mtetra
.713 .795 .916 r
.44706 .54916 .45576 .55657 .47089 .55289 .4623 .54214 Mtetra
.773 .739 .821 r
.4623 .54214 .47089 .55289 .48615 .54532 .47767 .53014 Mtetra
.749 .673 .777 r
.47767 .53014 .48615 .54532 .5015 .53413 .49308 .51753 Mtetra
.715 .646 .778 r
.49308 .51753 .5015 .53413 .51687 .52303 .50848 .50737 Mtetra
.688 .645 .801 r
.50848 .50737 .51687 .52303 .53227 .51397 .52392 .49978 Mtetra
.653 .649 .834 r
.52392 .49978 .53227 .51397 .54774 .50663 .53943 .49477 Mtetra
.65 .687 .871 r
.53943 .49477 .54774 .50663 .56328 .50069 .55503 .49015 Mtetra
.657 .716 .892 r
.55503 .49015 .56328 .50069 .57892 .49585 .57072 .48525 Mtetra
.662 .718 .89 r
.57072 .48525 .57892 .49585 .59467 .49209 .5865 .48007 Mtetra
.652 .687 .871 r
.5865 .48007 .59467 .49209 .61056 .48975 .60237 .47527 Mtetra
.594 .623 .849 r
.60237 .47527 .61056 .48975 .62662 .48917 .61841 .47308 Mtetra
.539 .573 .837 r
.61841 .47308 .62662 .48917 .64288 .49066 .63466 .4735 Mtetra
.484 .53 .828 r
.63466 .4735 .64288 .49066 .65931 .49229 .65115 .47645 Mtetra
.489 .551 .846 r
.65115 .47645 .65931 .49229 .67574 .49027 .66779 .47882 Mtetra
.598 .682 .9 r
.66779 .47882 .67574 .49027 .69209 .48428 .68435 .47613 Mtetra
.723 .803 .914 r
.68435 .47613 .69209 .48428 .70829 .47411 .70076 .46811 Mtetra
.79 .872 .908 r
.70076 .46811 .70829 .47411 .72454 .46392 .71705 .45697 Mtetra
.76 .845 .916 r
.71705 .45697 .72454 .46392 .74095 .45559 .73347 .44728 Mtetra
.694 .795 .927 r
.73347 .44728 .74095 .45559 .75763 .45007 .75014 .44045 Mtetra
.652 .75 .921 r
.75014 .44045 .75763 .45007 .77445 .44504 .76702 .43536 Mtetra
.653 .75 .92 r
.76702 .43536 .77445 .44504 .79135 .43977 .784 .43018 Mtetra
.665 .758 .919 r
.784 .43018 .79135 .43977 .80832 .43413 .80105 .4245 Mtetra
.658 .755 .922 r
.80105 .4245 .80832 .43413 .82543 .42897 .81821 .41907 Mtetra
.65 .747 .921 r
.81821 .41907 .82543 .42897 .84265 .4239 .83551 .41396 Mtetra
.653 .749 .92 r
.83551 .41396 .84265 .4239 .85997 .41861 .85291 .4087 Mtetra
.661 .754 .919 r
.85291 .4087 .85997 .41861 .87735 .41298 .87037 .40305 Mtetra
.658 .754 .921 r
.87037 .40305 .87735 .41298 .89486 .40757 .88795 .39749 Mtetra
.651 .75 .922 r
.26284 .58052 .27216 .58867 .28633 .58437 .27704 .57624 Mtetra
.652 .752 .923 r
.27704 .57624 .28633 .58437 .30056 .58015 .29133 .57191 Mtetra
.66 .752 .918 r
.29133 .57191 .30056 .58015 .31489 .57558 .30571 .56726 Mtetra
.662 .752 .917 r
.30571 .56726 .31489 .57558 .32931 .57087 .32017 .56251 Mtetra
.649 .749 .922 r
.32017 .56251 .32931 .57087 .34378 .56646 .33468 .55821 Mtetra
.649 .752 .925 r
.33468 .55821 .34378 .56646 .35832 .56231 .34928 .55388 Mtetra
.658 .752 .919 r
.34928 .55388 .35832 .56231 .37297 .55767 .36398 .5492 Mtetra
.654 .75 .921 r
.36398 .5492 .37297 .55767 .38769 .55297 .37874 .54466 Mtetra
.558 .724 .952 r
.37874 .54466 .38769 .55297 .40244 .54995 .39348 .54292 Mtetra
.399 .693 .979 r
.39348 .54292 .40244 .54995 .41719 .54973 .40824 .54369 Mtetra
.355 .701 .984 r
.40824 .54369 .41719 .54973 .43202 .55095 .42313 .54452 Mtetra
.649 .807 .959 r
.42313 .54452 .43202 .55095 .44706 .54916 .4383 .53974 Mtetra
.767 .762 .848 r
.4383 .53974 .44706 .54916 .4623 .54214 .45368 .52901 Mtetra
.776 .706 .786 r
.45368 .52901 .4623 .54214 .47767 .53014 .46914 .51497 Mtetra
.74 .671 .783 r
.46914 .51497 .47767 .53014 .49308 .51753 .48458 .5033 Mtetra
.698 .667 .816 r
.48458 .5033 .49308 .51753 .50848 .50737 .50001 .49549 Mtetra
.639 .682 .875 r
.50001 .49549 .50848 .50737 .52392 .49978 .51549 .49135 Mtetra
.612 .749 .942 r
.51549 .49135 .52392 .49978 .53943 .49477 .53106 .48792 Mtetra
.617 .794 .966 r
.53106 .48792 .53943 .49477 .55503 .49015 .54674 .48393 Mtetra
.644 .821 .968 r
.54674 .48393 .55503 .49015 .57072 .48525 .5625 .47898 Mtetra
.674 .829 .958 r
.5625 .47898 .57072 .48525 .5865 .48007 .57834 .47307 Mtetra
.692 .816 .941 r
.57834 .47307 .5865 .48007 .60237 .47527 .59425 .46659 Mtetra
.675 .769 .922 r
.59425 .46659 .60237 .47527 .61841 .47308 .61025 .46081 Mtetra
.585 .658 .888 r
.61025 .46081 .61841 .47308 .63466 .4735 .62646 .45874 Mtetra
.492 .57 .862 r
.62646 .45874 .63466 .4735 .65115 .47645 .64293 .46061 Mtetra
.432 .521 .849 r
.64293 .46061 .65115 .47645 .66779 .47882 .65967 .46493 Mtetra
.509 .596 .876 r
.65967 .46493 .66779 .47882 .68435 .47613 .67644 .46592 Mtetra
.653 .735 .909 r
.67644 .46592 .68435 .47613 .70076 .46811 .69307 .46084 Mtetra
.779 .841 .899 r
.69307 .46084 .70076 .46811 .71705 .45697 .70947 .45002 Mtetra
.78 .85 .904 r
.70947 .45002 .71705 .45697 .73347 .44728 .72592 .43921 Mtetra
.726 .812 .919 r
.72592 .43921 .73347 .44728 .75014 .44045 .74258 .43096 Mtetra
.658 .757 .923 r
.74258 .43096 .75014 .44045 .76702 .43536 .75952 .42558 Mtetra
.653 .75 .921 r
.75952 .42558 .76702 .43536 .784 .43018 .77657 .42035 Mtetra
.662 .753 .918 r
.77657 .42035 .784 .43018 .80105 .4245 .7937 .41475 Mtetra
.662 .757 .92 r
.7937 .41475 .80105 .4245 .81821 .41907 .81092 .4091 Mtetra
.65 .748 .921 r
.81092 .4091 .81821 .41907 .83551 .41396 .82829 .40392 Mtetra
.652 .748 .921 r
.82829 .40392 .83551 .41396 .85291 .4087 .84577 .39864 Mtetra
.659 .753 .919 r
.84577 .39864 .85291 .4087 .87037 .40305 .86331 .39301 Mtetra
.66 .755 .92 r
.86331 .39301 .87037 .40305 .88795 .39749 .88096 .38731 Mtetra
.65 .75 .923 r
.25342 .57229 .26284 .58052 .27704 .57624 .26766 .56802 Mtetra
.654 .752 .922 r
.26766 .56802 .27704 .57624 .29133 .57191 .282 .56358 Mtetra
.661 .752 .918 r
.282 .56358 .29133 .57191 .30571 .56726 .29643 .55885 Mtetra
.661 .752 .917 r
.29643 .55885 .30571 .56726 .32017 .56251 .31094 .55409 Mtetra
.646 .748 .924 r
.31094 .55409 .32017 .56251 .33468 .55821 .3255 .54985 Mtetra
.652 .753 .923 r
.3255 .54985 .33468 .55821 .34928 .55388 .34015 .54536 Mtetra
.66 .752 .918 r
.34015 .54536 .34928 .55388 .36398 .5492 .3549 .54056 Mtetra
.642 .745 .924 r
.3549 .54056 .36398 .5492 .37874 .54466 .36969 .53639 Mtetra
.511 .709 .961 r
.36969 .53639 .37874 .54466 .39348 .54292 .38443 .53565 Mtetra
.361 .67 .974 r
.38443 .53565 .39348 .54292 .40824 .54369 .39921 .53707 Mtetra
.463 .737 .987 r
.39921 .53707 .40824 .54369 .42313 .54452 .41419 .53648 Mtetra
.712 .782 .907 r
.41419 .53648 .42313 .54452 .4383 .53974 .42948 .52941 Mtetra
.793 .751 .814 r
.42948 .52941 .4383 .53974 .45368 .52901 .44499 .51576 Mtetra
.775 .706 .786 r
.44499 .51576 .45368 .52901 .46914 .51497 .46051 .50176 Mtetra
.735 .695 .813 r
.46051 .50176 .46914 .51497 .48458 .5033 .47598 .49156 Mtetra
.643 .687 .877 r
.47598 .49156 .48458 .5033 .50001 .49549 .49143 .48721 Mtetra
.578 .742 .954 r
.49143 .48721 .50001 .49549 .51549 .49135 .50696 .48469 Mtetra
.568 .783 .98 r
.50696 .48469 .51549 .49135 .53106 .48792 .5226 .48185 Mtetra
.608 .815 .98 r
.5226 .48185 .53106 .48792 .54674 .48393 .53834 .47781 Mtetra
.642 .825 .971 r
.53834 .47781 .54674 .48393 .5625 .47898 .55418 .47281 Mtetra
.673 .834 .961 r
.55418 .47281 .5625 .47898 .57834 .47307 .57009 .46686 Mtetra
.707 .842 .947 r
.57009 .46686 .57834 .47307 .59425 .46659 .58607 .45968 Mtetra
.716 .827 .934 r
.58607 .45968 .59425 .46659 .61025 .46081 .60211 .45217 Mtetra
.67 .772 .927 r
.60211 .45217 .61025 .46081 .62646 .45874 .61827 .4465 Mtetra
.515 .629 .901 r
.61827 .4465 .62646 .45874 .64293 .46061 .63473 .44676 Mtetra
.406 .541 .879 r
.63473 .44676 .64293 .46061 .65967 .46493 .65148 .45092 Mtetra
.419 .547 .878 r
.65148 .45092 .65967 .46493 .67644 .46592 .66841 .45477 Mtetra
.597 .693 .91 r
.66841 .45477 .67644 .46592 .69307 .46084 .68521 .45193 Mtetra
.747 .797 .893 r
.68521 .45193 .69307 .46084 .70947 .45002 .70177 .44245 Mtetra
.789 .839 .89 r
.70177 .44245 .70947 .45002 .72592 .43921 .71827 .43087 Mtetra
.747 .814 .905 r
.71827 .43087 .72592 .43921 .74258 .43096 .73494 .42149 Mtetra
.668 .764 .922 r
.73494 .42149 .74258 .43096 .75952 .42558 .75192 .41563 Mtetra
.652 .748 .92 r
.75192 .41563 .75952 .42558 .77657 .42035 .76905 .41041 Mtetra
.659 .752 .919 r
.76905 .41041 .77657 .42035 .7937 .41475 .78626 .40487 Mtetra
.665 .757 .919 r
.78626 .40487 .7937 .41475 .81092 .4091 .80355 .39905 Mtetra
.651 .749 .921 r
.80355 .39905 .81092 .4091 .82829 .40392 .82099 .39377 Mtetra
.651 .748 .921 r
.82099 .39377 .82829 .40392 .84577 .39864 .83854 .38846 Mtetra
.658 .752 .919 r
.83854 .38846 .84577 .39864 .86331 .39301 .85617 .38283 Mtetra
.661 .755 .919 r
.85617 .38283 .86331 .39301 .88096 .38731 .87389 .37702 Mtetra
.649 .75 .923 r
.24391 .56399 .25342 .57229 .26766 .56802 .25819 .5597 Mtetra
.655 .752 .921 r
.25819 .5597 .26766 .56802 .282 .56358 .27258 .55517 Mtetra
.662 .753 .917 r
.27258 .55517 .282 .56358 .29643 .55885 .28706 .55037 Mtetra
.66 .752 .918 r
.28706 .55037 .29643 .55885 .31094 .55409 .30161 .5456 Mtetra
.644 .748 .925 r
.30161 .5456 .31094 .55409 .3255 .54985 .31621 .54138 Mtetra
.654 .752 .922 r
.31621 .54138 .3255 .54985 .34015 .54536 .33092 .53676 Mtetra
.661 .752 .918 r
.33092 .53676 .34015 .54536 .3549 .54056 .34572 .5319 Mtetra
.627 .742 .93 r
.34572 .5319 .3549 .54056 .36969 .53639 .36054 .52816 Mtetra
.481 .7 .965 r
.36054 .52816 .36969 .53639 .38443 .53565 .3753 .52794 Mtetra
.356 .657 .97 r
.3753 .52794 .38443 .53565 .39921 .53707 .39011 .52961 Mtetra
.547 .75 .971 r
.39011 .52961 .39921 .53707 .41419 .53648 .40518 .52766 Mtetra
.744 .773 .876 r
.40518 .52766 .41419 .53648 .42948 .52941 .42059 .51867 Mtetra
.803 .747 .8 r
.42059 .51867 .42948 .52941 .44499 .51576 .4362 .50361 Mtetra
.778 .723 .801 r
.4362 .50361 .44499 .51576 .46051 .50176 .45178 .49021 Mtetra
.711 .715 .852 r
.45178 .49021 .46051 .50176 .47598 .49156 .46726 .48235 Mtetra
.593 .725 .936 r
.46726 .48235 .47598 .49156 .49143 .48721 .48274 .47957 Mtetra
.543 .748 .971 r
.48274 .47957 .49143 .48721 .50696 .48469 .49832 .47765 Mtetra
.613 .791 .967 r
.49832 .47765 .50696 .48469 .5226 .48185 .51403 .47374 Mtetra
.662 .779 .935 r
.51403 .47374 .5226 .48185 .53834 .47781 .52984 .46842 Mtetra
.656 .748 .917 r
.52984 .46842 .53834 .47781 .55418 .47281 .54573 .46337 Mtetra
.649 .745 .92 r
.54573 .46337 .55418 .47281 .57009 .46686 .56172 .45859 Mtetra
.683 .785 .928 r
.56172 .45859 .57009 .46686 .58607 .45968 .57779 .45239 Mtetra
.73 .823 .922 r
.57779 .45239 .58607 .45968 .60211 .45217 .59389 .44418 Mtetra
.71 .802 .922 r
.59389 .44418 .60211 .45217 .61827 .4465 .61008 .4368 Mtetra
.571 .713 .938 r
.61008 .4368 .61827 .4465 .63473 .44676 .62651 .43459 Mtetra
.399 .572 .907 r
.62651 .43459 .63473 .44676 .65148 .45092 .64327 .43802 Mtetra
.346 .528 .892 r
.64327 .43802 .65148 .45092 .66841 .45477 .66029 .44319 Mtetra
.544 .663 .914 r
.66029 .44319 .66841 .45477 .68521 .45193 .67723 .4422 Mtetra
.719 .773 .896 r
.67723 .4422 .68521 .45193 .70177 .44245 .69394 .43401 Mtetra
.789 .821 .877 r
.69394 .43401 .70177 .44245 .71827 .43087 .71051 .42207 Mtetra
.756 .807 .894 r
.71051 .42207 .71827 .43087 .73494 .42149 .72723 .41204 Mtetra
.68 .771 .92 r
.72723 .41204 .73494 .42149 .75192 .41563 .74425 .40563 Mtetra
.651 .749 .921 r
.74425 .40563 .75192 .41563 .76905 .41041 .76145 .40037 Mtetra
.657 .751 .92 r
.76145 .40037 .76905 .41041 .78626 .40487 .77874 .39484 Mtetra
.666 .757 .918 r
.77874 .39484 .78626 .40487 .80355 .39905 .7961 .3889 Mtetra
.652 .75 .922 r
.7961 .3889 .80355 .39905 .82099 .39377 .81361 .38352 Mtetra
.65 .748 .921 r
.81361 .38352 .82099 .39377 .83854 .38846 .83124 .37817 Mtetra
.657 .751 .92 r
.83124 .37817 .83854 .38846 .85617 .38283 .84895 .37253 Mtetra
.662 .755 .919 r
.84895 .37253 .85617 .38283 .87389 .37702 .86675 .36662 Mtetra
.648 .75 .923 r
.23429 .5556 .24391 .56399 .25819 .5597 .24863 .55128 Mtetra
.655 .752 .921 r
.24863 .55128 .25819 .5597 .27258 .55517 .26306 .54668 Mtetra
.662 .753 .918 r
.26306 .54668 .27258 .55517 .28706 .55037 .27759 .54183 Mtetra
.659 .752 .919 r
.27759 .54183 .28706 .55037 .30161 .5456 .29219 .53704 Mtetra
.644 .749 .925 r
.29219 .53704 .30161 .5456 .31621 .54138 .30684 .53278 Mtetra
.655 .752 .921 r
.30684 .53278 .31621 .54138 .33092 .53676 .32159 .52808 Mtetra
.661 .752 .918 r
.32159 .52808 .33092 .53676 .34572 .5319 .33645 .52317 Mtetra
.618 .74 .934 r
.33645 .52317 .34572 .5319 .36054 .52816 .3513 .51969 Mtetra
.473 .693 .964 r
.3513 .51969 .36054 .52816 .3753 .52794 .36609 .51967 Mtetra
.369 .65 .965 r
.36609 .51967 .3753 .52794 .39011 .52961 .38093 .52139 Mtetra
.586 .746 .953 r
.38093 .52139 .39011 .52961 .40518 .52766 .39608 .51863 Mtetra
.76 .773 .863 r
.39608 .51863 .40518 .52766 .42059 .51867 .41159 .5085 Mtetra
.812 .758 .803 r
.41159 .5085 .42059 .51867 .4362 .50361 .4273 .49296 Mtetra
.784 .748 .82 r
.4273 .49296 .4362 .50361 .45178 .49021 .44293 .47999 Mtetra
.692 .737 .885 r
.44293 .47999 .45178 .49021 .46726 .48235 .45844 .47344 Mtetra
.566 .725 .948 r
.45844 .47344 .46726 .48235 .48274 .47957 .47396 .47131 Mtetra
.552 .736 .962 r
.47396 .47131 .48274 .47957 .49832 .47765 .4896 .46933 Mtetra
.659 .774 .934 r
.4896 .46933 .49832 .47765 .51403 .47374 .50537 .46415 Mtetra
.681 .752 .905 r
.50537 .46415 .51403 .47374 .52984 .46842 .52124 .45803 Mtetra
.656 .728 .902 r
.52124 .45803 .52984 .46842 .54573 .46337 .53719 .45292 Mtetra
.63 .718 .91 r
.53719 .45292 .54573 .46337 .56172 .45859 .55324 .44883 Mtetra
.653 .743 .916 r
.55324 .44883 .56172 .45859 .57779 .45239 .56939 .4438 Mtetra
.727 .793 .904 r
.56939 .4438 .57779 .45239 .59389 .44418 .58557 .43554 Mtetra
.724 .792 .906 r
.58557 .43554 .59389 .44418 .61008 .4368 .60182 .42742 Mtetra
.612 .74 .936 r
.60182 .42742 .61008 .4368 .62651 .43459 .61826 .42376 Mtetra
.389 .6 .93 r
.61826 .42376 .62651 .43459 .64327 .43802 .63504 .42663 Mtetra
.283 .526 .909 r
.63504 .42663 .64327 .43802 .66029 .44319 .65211 .43218 Mtetra
.501 .657 .93 r
.65211 .43218 .66029 .44319 .67723 .4422 .66915 .43225 Mtetra
.703 .766 .901 r
.66915 .43225 .67723 .4422 .69394 .43401 .68598 .42477 Mtetra
.786 .805 .868 r
.68598 .42477 .69394 .43401 .71051 .42207 .70263 .41267 Mtetra
.758 .797 .885 r
.70263 .41267 .71051 .42207 .72723 .41204 .71942 .40234 Mtetra
.687 .77 .915 r
.71942 .40234 .72723 .41204 .74425 .40563 .7365 .39554 Mtetra
.651 .75 .922 r
.7365 .39554 .74425 .40563 .76145 .40037 .75377 .39022 Mtetra
.656 .751 .92 r
.75377 .39022 .76145 .40037 .77874 .39484 .77113 .38467 Mtetra
.666 .756 .917 r
.77113 .38467 .77874 .39484 .7961 .3889 .78857 .37866 Mtetra
.653 .751 .922 r
.78857 .37866 .7961 .3889 .81361 .38352 .80615 .37318 Mtetra
.65 .749 .922 r
.80615 .37318 .81361 .38352 .83124 .37817 .82386 .36778 Mtetra
.656 .751 .92 r
.82386 .36778 .83124 .37817 .84895 .37253 .84165 .36209 Mtetra
.662 .754 .919 r
.84165 .36209 .84895 .37253 .86675 .36662 .85952 .35611 Mtetra
.648 .75 .923 r
.22459 .54713 .23429 .5556 .24863 .55128 .23896 .54276 Mtetra
.655 .751 .92 r
.23896 .54276 .24863 .55128 .26306 .54668 .25344 .53812 Mtetra
.662 .753 .918 r
.25344 .53812 .26306 .54668 .27759 .54183 .26802 .53321 Mtetra
.659 .752 .919 r
.26802 .53321 .27759 .54183 .29219 .53704 .28267 .52838 Mtetra
.644 .748 .925 r
.28267 .52838 .29219 .53704 .30684 .53278 .29737 .52407 Mtetra
.656 .751 .92 r
.29737 .52407 .30684 .53278 .32159 .52808 .31217 .51932 Mtetra
.661 .753 .918 r
.31217 .51932 .32159 .52808 .33645 .52317 .32708 .51436 Mtetra
.618 .74 .934 r
.32708 .51436 .33645 .52317 .3513 .51969 .34198 .51084 Mtetra
.479 .687 .959 r
.34198 .51084 .3513 .51969 .36609 .51967 .3568 .51077 Mtetra
.385 .644 .959 r
.3568 .51077 .36609 .51967 .38093 .52139 .37167 .51246 Mtetra
.591 .732 .942 r
.37167 .51246 .38093 .52139 .39608 .51863 .38688 .50966 Mtetra
.761 .776 .865 r
.38688 .50966 .39608 .51863 .41159 .5085 .40246 .49946 Mtetra
.822 .78 .813 r
.40246 .49946 .41159 .5085 .4273 .49296 .41825 .48384 Mtetra
.797 .779 .836 r
.41825 .48384 .4273 .49296 .44293 .47999 .43396 .4708 Mtetra
.695 .761 .903 r
.43396 .4708 .44293 .47999 .45844 .47344 .44954 .4642 Mtetra
.568 .719 .944 r
.44954 .4642 .45844 .47344 .47396 .47131 .46511 .46202 Mtetra
.562 .717 .945 r
.46511 .46202 .47396 .47131 .4896 .46933 .48079 .45999 Mtetra
.66 .752 .918 r
.48079 .45999 .4896 .46933 .50537 .46415 .49663 .45475 Mtetra
.682 .759 .91 r
.49663 .45475 .50537 .46415 .52124 .45803 .51255 .44857 Mtetra
.656 .751 .92 r
.51255 .44857 .52124 .45803 .53719 .45292 .52856 .44341 Mtetra
.628 .741 .929 r
.52856 .44341 .53719 .45292 .55324 .44883 .54468 .43927 Mtetra
.653 .75 .921 r
.54468 .43927 .55324 .44883 .56939 .4438 .56088 .43419 Mtetra
.724 .771 .89 r
.56088 .43419 .56939 .4438 .58557 .43554 .57713 .42586 Mtetra
.721 .77 .892 r
.57713 .42586 .58557 .43554 .60182 .42742 .59345 .41767 Mtetra
.613 .734 .932 r
.59345 .41767 .60182 .42742 .61826 .42376 .60996 .41396 Mtetra
.359 .611 .946 r
.60996 .41396 .61826 .42376 .63504 .42663 .62679 .41679 Mtetra
.223 .531 .921 r
.62679 .41679 .63504 .42663 .65211 .43218 .6439 .42232 Mtetra
.483 .678 .951 r
.6439 .42232 .65211 .43218 .66915 .43225 .66099 .42233 Mtetra
.703 .77 .904 r
.66099 .42233 .66915 .43225 .68598 .42477 .67789 .41479 Mtetra
.782 .791 .86 r
.67789 .41479 .68598 .42477 .70263 .41267 .69463 .40262 Mtetra
.755 .784 .877 r
.69463 .40262 .70263 .41267 .71942 .40234 .7115 .39221 Mtetra
.687 .763 .91 r
.7115 .39221 .71942 .40234 .7365 .39554 .72866 .38535 Mtetra
.651 .75 .922 r
.72866 .38535 .7365 .39554 .75377 .39022 .746 .37996 Mtetra
.656 .752 .92 r
.746 .37996 .75377 .39022 .77113 .38467 .76344 .37435 Mtetra
.666 .756 .917 r
.76344 .37435 .77113 .38467 .78857 .37866 .78095 .36828 Mtetra
.653 .75 .921 r
.78095 .36828 .78857 .37866 .80615 .37318 .79861 .36274 Mtetra
.65 .749 .922 r
.79861 .36274 .80615 .37318 .82386 .36778 .81639 .35727 Mtetra
.656 .752 .92 r
.81639 .35727 .82386 .36778 .84165 .36209 .83426 .35152 Mtetra
.662 .754 .918 r
.83426 .35152 .84165 .36209 .85952 .35611 .85222 .34547 Mtetra
.649 .75 .923 r
.21478 .53856 .22459 .54713 .23896 .54276 .2292 .53413 Mtetra
.655 .751 .92 r
.2292 .53413 .23896 .54276 .25344 .53812 .24373 .52947 Mtetra
.662 .753 .918 r
.24373 .52947 .25344 .53812 .26802 .53321 .25835 .52452 Mtetra
.66 .753 .919 r
.25835 .52452 .26802 .53321 .28267 .52838 .27306 .51961 Mtetra
.644 .748 .924 r
.27306 .51961 .28267 .52838 .29737 .52407 .2878 .51524 Mtetra
.654 .75 .92 r
.2878 .51524 .29737 .52407 .31217 .51932 .30265 .51048 Mtetra
.661 .753 .918 r
.30265 .51048 .31217 .51932 .32708 .51436 .31761 .50547 Mtetra
.627 .743 .931 r
.31761 .50547 .32708 .51436 .34198 .51084 .33258 .50159 Mtetra
.495 .687 .953 r
.33258 .50159 .34198 .51084 .3568 .51077 .34745 .50125 Mtetra
.404 .639 .951 r
.34745 .50125 .3568 .51077 .37167 .51246 .36236 .50282 Mtetra
.569 .709 .937 r
.36236 .50282 .37167 .51246 .38688 .50966 .37757 .50073 Mtetra
.745 .777 .879 r
.37757 .50073 .38688 .50966 .40246 .49946 .39318 .49156 Mtetra
.828 .803 .827 r
.39318 .49156 .40246 .49946 .41825 .48384 .40905 .47627 Mtetra
.815 .812 .848 r
.40905 .47627 .41825 .48384 .43396 .4708 .42486 .46264 Mtetra
.727 .794 .905 r
.42486 .46264 .43396 .4708 .44954 .4642 .44054 .4546 Mtetra
.593 .723 .934 r
.44054 .4546 .44954 .4642 .46511 .46202 .45617 .45169 Mtetra
.569 .698 .928 r
.45617 .45169 .46511 .46202 .48079 .45999 .4719 .44962 Mtetra
.628 .721 .913 r
.4719 .44962 .48079 .45999 .49663 .45475 .48778 .44556 Mtetra
.664 .76 .922 r
.48778 .44556 .49663 .45475 .51255 .44857 .50377 .44007 Mtetra
.655 .775 .937 r
.50377 .44007 .51255 .44857 .52856 .44341 .51984 .43485 Mtetra
.646 .772 .94 r
.51984 .43485 .52856 .44341 .54468 .43927 .53602 .42991 Mtetra
.683 .766 .914 r
.53602 .42991 .54468 .43927 .56088 .43419 .55228 .42353 Mtetra
.72 .751 .877 r
.55228 .42353 .56088 .43419 .57713 .42586 .56859 .41513 Mtetra
.704 .746 .885 r
.56859 .41513 .57713 .42586 .59345 .41767 .58499 .40757 Mtetra
.571 .711 .937 r
.58499 .40757 .59345 .41767 .60996 .41396 .60159 .4052 Mtetra
.294 .605 .952 r
.60159 .4052 .60996 .41396 .62679 .41679 .61849 .40853 Mtetra
.173 .544 .927 r
.61849 .40853 .62679 .41679 .6439 .42232 .63564 .41359 Mtetra
.507 .721 .969 r
.63564 .41359 .6439 .42232 .66099 .42233 .65275 .41246 Mtetra
.719 .778 .899 r
.65275 .41246 .66099 .42233 .67789 .41479 .66969 .40407 Mtetra
.776 .777 .854 r
.66969 .40407 .67789 .41479 .69463 .40262 .68652 .3919 Mtetra
.748 .771 .872 r
.68652 .3919 .69463 .40262 .7115 .39221 .70348 .38166 Mtetra
.679 .754 .907 r
.70348 .38166 .7115 .39221 .72866 .38535 .72073 .37505 Mtetra
.651 .75 .922 r
.72073 .37505 .72866 .38535 .746 .37996 .73814 .3696 Mtetra
.657 .752 .92 r
.73814 .3696 .746 .37996 .76344 .37435 .75565 .36389 Mtetra
.666 .755 .917 r
.75565 .36389 .76344 .37435 .78095 .36828 .77324 .35776 Mtetra
.652 .749 .921 r
.77324 .35776 .78095 .36828 .79861 .36274 .79098 .35219 Mtetra
.65 .749 .922 r
.79098 .35219 .79861 .36274 .81639 .35727 .80884 .34665 Mtetra
.657 .752 .92 r
.80884 .34665 .81639 .35727 .83426 .35152 .82679 .34081 Mtetra
.662 .754 .918 r
.82679 .34081 .83426 .35152 .85222 .34547 .84482 .33471 Mtetra
.65 .75 .923 r
.20487 .52991 .21478 .53856 .2292 .53413 .21934 .52541 Mtetra
.654 .75 .921 r
.21934 .52541 .2292 .53413 .24373 .52947 .23391 .52074 Mtetra
.661 .753 .918 r
.23391 .52074 .24373 .52947 .25835 .52452 .24858 .51576 Mtetra
.661 .754 .919 r
.24858 .51576 .25835 .52452 .27306 .51961 .26334 .51076 Mtetra
.646 .749 .924 r
.26334 .51076 .27306 .51961 .2878 .51524 .27813 .50628 Mtetra
.652 .749 .921 r
.27813 .50628 .2878 .51524 .30265 .51048 .29303 .50155 Mtetra
.66 .753 .919 r
.29303 .50155 .30265 .51048 .31761 .50547 .30804 .4965 Mtetra
.642 .748 .926 r
.30804 .4965 .31761 .50547 .33258 .50159 .32309 .49209 Mtetra
.522 .694 .947 r
.32309 .49209 .33258 .50159 .34745 .50125 .33803 .49115 Mtetra
.431 .64 .944 r
.33803 .49115 .34745 .50125 .36236 .50282 .35298 .49239 Mtetra
.525 .676 .933 r
.35298 .49239 .36236 .50282 .37757 .50073 .36817 .4916 Mtetra
.71 .768 .898 r
.36817 .4916 .37757 .50073 .39318 .49156 .38376 .48425 Mtetra
.82 .817 .847 r
.38376 .48425 .39318 .49156 .40905 .47627 .39968 .47022 Mtetra
.833 .845 .855 r
.39968 .47022 .40905 .47627 .42486 .46264 .41561 .45585 Mtetra
.777 .833 .895 r
.41561 .45585 .42486 .46264 .44054 .4546 .43144 .44531 Mtetra
.642 .749 .927 r
.43144 .44531 .44054 .4546 .45617 .45169 .44716 .44071 Mtetra
.592 .695 .914 r
.44716 .44071 .45617 .45169 .4719 .44962 .46295 .43794 Mtetra
.603 .686 .901 r
.46295 .43794 .4719 .44962 .48778 .44556 .47885 .43487 Mtetra
.633 .719 .909 r
.47885 .43487 .48778 .44556 .50377 .44007 .49489 .43056 Mtetra
.656 .754 .922 r
.49489 .43056 .50377 .44007 .51984 .43485 .51103 .42528 Mtetra
.679 .761 .913 r
.51103 .42528 .51984 .43485 .53602 .42991 .52726 .41904 Mtetra
.702 .742 .883 r
.52726 .41904 .53602 .42991 .55228 .42353 .54357 .41156 Mtetra
.703 .723 .865 r
.54357 .41156 .55228 .42353 .56859 .41513 .55996 .40374 Mtetra
.668 .723 .89 r
.55996 .40374 .56859 .41513 .58499 .40757 .57645 .39777 Mtetra
.476 .678 .953 r
.57645 .39777 .58499 .40757 .60159 .4052 .59316 .39782 Mtetra
.188 .58 .94 r
.59316 .39782 .60159 .4052 .61849 .40853 .61013 .40179 Mtetra
.176 .591 .939 r
.61013 .40179 .61849 .40853 .63564 .41359 .6273 .40547 Mtetra
.571 .768 .972 r
.6273 .40547 .63564 .41359 .65275 .41246 .64441 .40236 Mtetra
.744 .782 .884 r
.64441 .40236 .65275 .41246 .66969 .40407 .66137 .39252 Mtetra
.767 .762 .848 r
.66137 .39252 .66969 .40407 .68652 .3919 .67829 .38057 Mtetra
.736 .758 .871 r
.67829 .38057 .68652 .3919 .70348 .38166 .69536 .37084 Mtetra
.668 .746 .909 r
.69536 .37084 .70348 .38166 .72073 .37505 .71271 .36466 Mtetra
.652 .751 .922 r
.71271 .36466 .72073 .37505 .73814 .3696 .7302 .35914 Mtetra
.659 .753 .92 r
.7302 .35914 .73814 .3696 .75565 .36389 .74778 .35328 Mtetra
.665 .754 .916 r
.74778 .35328 .75565 .36389 .77324 .35776 .76545 .34714 Mtetra
.651 .749 .922 r
.76545 .34714 .77324 .35776 .79098 .35219 .78327 .34155 Mtetra
.651 .75 .922 r
.78327 .34155 .79098 .35219 .80884 .34665 .8012 .33592 Mtetra
.658 .753 .92 r
.8012 .33592 .80884 .34665 .82679 .34081 .81923 .32996 Mtetra
.661 .753 .918 r
.81923 .32996 .82679 .34081 .84482 .33471 .83735 .32382 Mtetra
.651 .75 .922 r
.19486 .52118 .20487 .52991 .21934 .52541 .20938 .51658 Mtetra
.652 .749 .921 r
.20938 .51658 .21934 .52541 .23391 .52074 .22399 .51192 Mtetra
.66 .753 .919 r
.22399 .51192 .23391 .52074 .24858 .51576 .23871 .50693 Mtetra
.662 .754 .918 r
.23871 .50693 .24858 .51576 .26334 .51076 .25352 .50184 Mtetra
.649 .75 .923 r
.25352 .50184 .26334 .51076 .27813 .50628 .26837 .4972 Mtetra
.649 .748 .921 r
.26837 .4972 .27813 .50628 .29303 .50155 .28331 .49254 Mtetra
.658 .753 .92 r
.28331 .49254 .29303 .50155 .30804 .4965 .29836 .4875 Mtetra
.654 .753 .923 r
.29836 .4875 .30804 .4965 .32309 .49209 .31349 .48262 Mtetra
.563 .713 .942 r
.31349 .48262 .32309 .49209 .33803 .49115 .32853 .48058 Mtetra
.469 .649 .937 r
.32853 .48058 .33803 .49115 .35298 .49239 .34355 .4811 Mtetra
.477 .637 .925 r
.34355 .4811 .35298 .49239 .36817 .4916 .3587 .48166 Mtetra
.657 .739 .91 r
.3587 .48166 .36817 .4916 .38376 .48425 .37425 .47653 Mtetra
.782 .812 .876 r
.37425 .47653 .38376 .48425 .39968 .47022 .39014 .46533 Mtetra
.842 .872 .864 r
.39014 .46533 .39968 .47022 .41561 .45585 .40618 .45075 Mtetra
.81 .875 .894 r
.40618 .45075 .41561 .45585 .43144 .44531 .42215 .43859 Mtetra
.731 .835 .929 r
.42215 .43859 .43144 .44531 .44716 .44071 .43804 .43036 Mtetra
.638 .728 .913 r
.43804 .43036 .44716 .44071 .46295 .43794 .45391 .42586 Mtetra
.62 .687 .891 r
.45391 .42586 .46295 .43794 .47885 .43487 .46987 .42207 Mtetra
.633 .68 .877 r
.46987 .42207 .47885 .43487 .49489 .43056 .48595 .41771 Mtetra
.653 .689 .871 r
.48595 .41771 .49489 .43056 .51103 .42528 .50213 .41238 Mtetra
.672 .696 .864 r
.50213 .41238 .51103 .42528 .52726 .41904 .51842 .40606 Mtetra
.682 .7 .86 r
.51842 .40606 .52726 .41904 .54357 .41156 .53479 .39917 Mtetra
.67 .706 .874 r
.53479 .39917 .54357 .41156 .55996 .40374 .55125 .39298 Mtetra
.573 .701 .929 r
.55125 .39298 .55996 .40374 .57645 .39777 .56785 .39056 Mtetra
.323 .669 .975 r
.56785 .39056 .57645 .39777 .59316 .39782 .58465 .39215 Mtetra
.078 .554 .9 r
.58465 .39215 .59316 .39782 .61013 .40179 .6017 .39623 Mtetra
.306 .706 .977 r
.6017 .39623 .61013 .40179 .6273 .40547 .61884 .39691 Mtetra
.649 .789 .949 r
.61884 .39691 .6273 .40547 .64441 .40236 .63595 .39142 Mtetra
.762 .773 .861 r
.63595 .39142 .64441 .40236 .66137 .39252 .65293 .38007 Mtetra
.753 .744 .845 r
.65293 .38007 .66137 .39252 .67829 .38057 .66996 .36875 Mtetra
.715 .744 .875 r
.66996 .36875 .67829 .38057 .69536 .37084 .68716 .36002 Mtetra
.658 .745 .914 r
.68716 .36002 .69536 .37084 .71271 .36466 .7046 .35421 Mtetra
.653 .752 .923 r
.7046 .35421 .71271 .36466 .7302 .35914 .72216 .34856 Mtetra
.662 .754 .919 r
.72216 .34856 .7302 .35914 .74778 .35328 .73981 .34251 Mtetra
.662 .752 .917 r
.73981 .34251 .74778 .35328 .76545 .34714 .75757 .33642 Mtetra
.65 .749 .922 r
.75757 .33642 .76545 .34714 .78327 .34155 .77547 .33079 Mtetra
.652 .751 .922 r
.77547 .33079 .78327 .34155 .8012 .33592 .79348 .32506 Mtetra
.659 .753 .92 r
.79348 .32506 .8012 .33592 .81923 .32996 .81158 .31898 Mtetra
.66 .752 .918 r
.81158 .31898 .81923 .32996 .83735 .32382 .82978 .31282 Mtetra
.653 .751 .922 r
.18474 .51236 .19486 .52118 .20938 .51658 .19932 .50764 Mtetra
.65 .749 .922 r
.19932 .50764 .20938 .51658 .22399 .51192 .21397 .503 Mtetra
.659 .753 .919 r
.21397 .503 .22399 .51192 .23871 .50693 .22873 .498 Mtetra
.662 .754 .918 r
.22873 .498 .23871 .50693 .25352 .50184 .24359 .49285 Mtetra
.653 .752 .922 r
.24359 .49285 .25352 .50184 .26837 .4972 .25851 .488 Mtetra
.645 .746 .922 r
.25851 .488 .26837 .4972 .28331 .49254 .27349 .48342 Mtetra
.658 .753 .92 r
.27349 .48342 .28331 .49254 .29836 .4875 .28859 .47834 Mtetra
.659 .753 .919 r
.28859 .47834 .29836 .4875 .31349 .48262 .30378 .47319 Mtetra
.609 .733 .933 r
.30378 .47319 .31349 .48262 .32853 .48058 .31895 .46975 Mtetra
.515 .666 .93 r
.31895 .46975 .32853 .48058 .34355 .4811 .33406 .46917 Mtetra
.468 .622 .918 r
.33406 .46917 .34355 .4811 .3587 .48166 .34921 .47007 Mtetra
.576 .677 .909 r
.34921 .47007 .3587 .48166 .37425 .47653 .36466 .46788 Mtetra
.712 .785 .908 r
.36466 .46788 .37425 .47653 .39014 .46533 .38047 .46035 Mtetra
.816 .877 .89 r
.38047 .46035 .39014 .46533 .40618 .45075 .39654 .4477 Mtetra
.83 .922 .896 r
.39654 .4477 .40618 .45075 .42215 .43859 .41266 .43443 Mtetra
.785 .903 .925 r
.41266 .43443 .42215 .43859 .43804 .43036 .42872 .42368 Mtetra
.727 .839 .934 r
.42872 .42368 .43804 .43036 .45391 .42586 .44475 .41554 Mtetra
.661 .74 .908 r
.44475 .41554 .45391 .42586 .46987 .42207 .46079 .41004 Mtetra
.649 .703 .886 r
.46079 .41004 .46987 .42207 .48595 .41771 .47692 .40493 Mtetra
.654 .692 .873 r
.47692 .40493 .48595 .41771 .50213 .41238 .49316 .39953 Mtetra
.659 .694 .871 r
.49316 .39953 .50213 .41238 .51842 .40606 .50949 .39385 Mtetra
.651 .703 .885 r
.50949 .39385 .51842 .40606 .53479 .39917 .52592 .38855 Mtetra
.577 .708 .931 r
.52592 .38855 .53479 .39917 .55125 .39298 .54246 .38591 Mtetra
.403 .719 .988 r
.54246 .38591 .55125 .39298 .56785 .39056 .55916 .38594 Mtetra
.112 .606 .906 r
.55916 .38594 .56785 .39056 .58465 .39215 .57606 .38855 Mtetra
.092 .613 .881 r
.57606 .38855 .58465 .39215 .6017 .39623 .59314 .39056 Mtetra
.522 .817 .999 r
.59314 .39056 .6017 .39623 .61884 .39691 .61026 .3874 Mtetra
.722 .792 .907 r
.61026 .3874 .61884 .39691 .63595 .39142 .62735 .37878 Mtetra
.758 .743 .84 r
.62735 .37878 .63595 .39142 .65293 .38007 .64439 .36697 Mtetra
.734 .73 .847 r
.64439 .36697 .65293 .38007 .66996 .36875 .66153 .35663 Mtetra
.689 .732 .883 r
.66153 .35663 .66996 .36875 .68716 .36002 .67887 .34922 Mtetra
.652 .746 .918 r
.67887 .34922 .68716 .36002 .7046 .35421 .6964 .34358 Mtetra
.653 .751 .921 r
.6964 .34358 .7046 .35421 .72216 .34856 .71404 .33785 Mtetra
.665 .755 .918 r
.71404 .33785 .72216 .34856 .73981 .34251 .73175 .33159 Mtetra
.658 .75 .918 r
.73175 .33159 .73981 .34251 .75757 .33642 .74959 .3256 Mtetra
.65 .75 .923 r
.74959 .3256 .75757 .33642 .77547 .33079 .76758 .31992 Mtetra
.653 .751 .922 r
.76758 .31992 .77547 .33079 .79348 .32506 .78566 .31408 Mtetra
.661 .754 .919 r
.78566 .31408 .79348 .32506 .81158 .31898 .80383 .30785 Mtetra
.658 .751 .919 r
.80383 .30785 .81158 .31898 .82978 .31282 .82213 .30169 Mtetra
.656 .752 .921 r
.17451 .50346 .18474 .51236 .19932 .50764 .18915 .4986 Mtetra
.649 .748 .922 r
.18915 .4986 .19932 .50764 .21397 .503 .20384 .49395 Mtetra
.657 .751 .919 r
.20384 .49395 .21397 .503 .22873 .498 .21865 .48898 Mtetra
.662 .754 .919 r
.21865 .48898 .22873 .498 .24359 .49285 .23356 .48379 Mtetra
.659 .754 .92 r
.23356 .48379 .24359 .49285 .25851 .488 .24854 .4787 Mtetra
.645 .746 .922 r
.24854 .4787 .25851 .488 .27349 .48342 .26357 .47408 Mtetra
.654 .749 .919 r
.26357 .47408 .27349 .48342 .28859 .47834 .27871 .4691 Mtetra
.66 .753 .919 r
.27871 .4691 .28859 .47834 .30378 .47319 .29396 .46387 Mtetra
.646 .749 .925 r
.29396 .46387 .30378 .47319 .31895 .46975 .30926 .45914 Mtetra
.561 .692 .928 r
.30926 .45914 .31895 .46975 .33406 .46917 .32448 .45722 Mtetra
.502 .639 .916 r
.32448 .45722 .33406 .46917 .34921 .47007 .33971 .45719 Mtetra
.51 .625 .901 r
.33971 .45719 .34921 .47007 .36466 .46788 .35507 .45717 Mtetra
.629 .719 .912 r
.35507 .45717 .36466 .46788 .38047 .46035 .37078 .45295 Mtetra
.728 .82 .922 r
.37078 .45295 .38047 .46035 .39654 .4477 .38675 .44472 Mtetra
.805 .928 .916 r
.38675 .44472 .39654 .4477 .41266 .43443 .40293 .43276 Mtetra
.795 .957 .919 r
.40293 .43276 .41266 .43443 .42872 .42368 .41914 .4209 Mtetra
.75 .937 .947 r
.41914 .4209 .42872 .42368 .44475 .41554 .43532 .41113 Mtetra
.712 .897 .963 r
.43532 .41113 .44475 .41554 .46079 .41004 .45151 .40312 Mtetra
.682 .829 .954 r
.45151 .40312 .46079 .41004 .47692 .40493 .46774 .39655 Mtetra
.654 .787 .945 r
.46774 .39655 .47692 .40493 .49316 .39953 .48404 .3911 Mtetra
.619 .776 .956 r
.48404 .3911 .49316 .39953 .50949 .39385 .50044 .38676 Mtetra
.547 .785 .987 r
.50044 .38676 .50949 .39385 .52592 .38855 .51694 .38388 Mtetra
.376 .769 .987 r
.51694 .38388 .52592 .38855 .54246 .38591 .53357 .38279 Mtetra
.13 .65 .887 r
.53357 .38279 .54246 .38591 .55916 .38594 .55037 .38383 Mtetra
.052 .607 .82 r
.55037 .38383 .55916 .38594 .57606 .38855 .56734 .38501 Mtetra
.412 .817 .98 r
.56734 .38501 .57606 .38855 .59314 .39056 .58441 .38242 Mtetra
.677 .812 .947 r
.58441 .38242 .59314 .39056 .61026 .3874 .60153 .37576 Mtetra
.752 .76 .859 r
.60153 .37576 .61026 .3874 .62735 .37878 .61862 .3648 Mtetra
.738 .718 .833 r
.61862 .3648 .62735 .37878 .64439 .36697 .63576 .35381 Mtetra
.714 .724 .858 r
.63576 .35381 .64439 .36697 .66153 .35663 .65303 .34473 Mtetra
.664 .729 .898 r
.65303 .34473 .66153 .35663 .67887 .34922 .6705 .33853 Mtetra
.652 .75 .922 r
.6705 .33853 .67887 .34922 .6964 .34358 .6881 .33283 Mtetra
.657 .753 .921 r
.6881 .33283 .6964 .34358 .71404 .33785 .70581 .32688 Mtetra
.665 .753 .915 r
.70581 .32688 .71404 .33785 .73175 .33159 .7236 .32054 Mtetra
.653 .747 .919 r
.7236 .32054 .73175 .33159 .74959 .3256 .74153 .31469 Mtetra
.65 .751 .923 r
.74153 .31469 .74959 .3256 .76758 .31992 .75959 .30892 Mtetra
.655 .752 .922 r
.75959 .30892 .76758 .31992 .78566 .31408 .77775 .30292 Mtetra
.662 .753 .918 r
.77775 .30292 .78566 .31408 .80383 .30785 .796 .29657 Mtetra
.656 .75 .919 r
.796 .29657 .80383 .30785 .82213 .30169 .81439 .29045 Mtetra
.658 .753 .92 r
.16418 .49448 .17451 .50346 .18915 .4986 .17887 .48948 Mtetra
.65 .749 .922 r
.17887 .48948 .18915 .4986 .20384 .49395 .19361 .48475 Mtetra
.653 .749 .92 r
.19361 .48475 .20384 .49395 .21865 .48898 .20846 .47985 Mtetra
.66 .754 .919 r
.20846 .47985 .21865 .48898 .23356 .48379 .22341 .47467 Mtetra
.662 .755 .919 r
.22341 .47467 .23356 .48379 .24854 .4787 .23846 .46941 Mtetra
.65 .75 .923 r
.23846 .46941 .24854 .4787 .26357 .47408 .25355 .46457 Mtetra
.648 .745 .92 r
.25355 .46457 .26357 .47408 .27871 .4691 .26873 .45976 Mtetra
.658 .753 .92 r
.26873 .45976 .27871 .4691 .29396 .46387 .28402 .45454 Mtetra
.659 .755 .921 r
.28402 .45454 .29396 .46387 .30926 .45914 .29941 .44925 Mtetra
.62 .732 .926 r
.29941 .44925 .30926 .45914 .32448 .45722 .31479 .44535 Mtetra
.548 .664 .913 r
.31479 .44535 .32448 .45722 .33971 .45719 .33013 .44393 Mtetra
.514 .622 .896 r
.33013 .44393 .33971 .45719 .35507 .45717 .34553 .44378 Mtetra
.542 .634 .891 r
.34553 .44378 .35507 .45717 .37078 .45295 .3611 .44277 Mtetra
.642 .738 .919 r
.3611 .44277 .37078 .45295 .38675 .44472 .37699 .43798 Mtetra
.709 .836 .943 r
.37699 .43798 .38675 .44472 .40293 .43276 .39308 .43046 Mtetra
.748 .945 .946 r
.39308 .43046 .40293 .43276 .41914 .4209 .40933 .42055 Mtetra
.709 .972 .928 r
.40933 .42055 .41914 .4209 .43532 .41113 .42563 .41058 Mtetra
.661 .96 .937 r
.42563 .41058 .43532 .41113 .45151 .40312 .44195 .40184 Mtetra
.606 .935 .956 r
.44195 .40184 .45151 .40312 .46774 .39655 .4583 .39469 Mtetra
.535 .901 .966 r
.4583 .39469 .46774 .39655 .48404 .3911 .47471 .38918 Mtetra
.428 .851 .953 r
.47471 .38918 .48404 .3911 .50044 .38676 .4912 .38533 Mtetra
.278 .771 .896 r
.4912 .38533 .50044 .38676 .51694 .38388 .5078 .38309 Mtetra
.133 .678 .812 r
.5078 .38309 .51694 .38388 .53357 .38279 .52454 .38209 Mtetra
.127 .675 .805 r
.52454 .38209 .53357 .38279 .55037 .38383 .54142 .38107 Mtetra
.428 .84 .969 r
.54142 .38107 .55037 .38383 .56734 .38501 .55844 .37764 Mtetra
.66 .827 .963 r
.55844 .37764 .56734 .38501 .58441 .38242 .57554 .37144 Mtetra
.741 .77 .876 r
.57554 .37144 .58441 .38242 .60153 .37576 .59265 .36138 Mtetra
.735 .712 .829 r
.59265 .36138 .60153 .37576 .61862 .3648 .60981 .35042 Mtetra
.717 .707 .839 r
.60981 .35042 .61862 .3648 .63576 .35381 .62706 .34073 Mtetra
.68 .714 .875 r
.62706 .34073 .63576 .35381 .65303 .34473 .64447 .33355 Mtetra
.653 .742 .915 r
.64447 .33355 .65303 .34473 .6705 .33853 .66203 .3278 Mtetra
.653 .753 .923 r
.66203 .3278 .6705 .33853 .6881 .33283 .67971 .32197 Mtetra
.663 .755 .919 r
.67971 .32197 .6881 .33283 .70581 .32688 .69748 .31571 Mtetra
.661 .749 .916 r
.69748 .31571 .70581 .32688 .7236 .32054 .71536 .30948 Mtetra
.65 .749 .922 r
.71536 .30948 .7236 .32054 .74153 .31469 .73338 .30368 Mtetra
.651 .752 .923 r
.73338 .30368 .74153 .31469 .75959 .30892 .75151 .29778 Mtetra
.658 .753 .92 r
.75151 .29778 .75959 .30892 .77775 .30292 .76974 .29158 Mtetra
.661 .752 .917 r
.76974 .29158 .77775 .30292 .796 .29657 .78808 .28519 Mtetra
.654 .75 .92 r
.78808 .28519 .796 .29657 .81439 .29045 .80656 .27908 Mtetra
.659 .753 .92 r
.15373 .48543 .16418 .49448 .17887 .48948 .16848 .48033 Mtetra
.653 .751 .922 r
.16848 .48033 .17887 .48948 .19361 .48475 .18328 .47543 Mtetra
.65 .748 .921 r
.18328 .47543 .19361 .48475 .20846 .47985 .19816 .47061 Mtetra
.659 .753 .919 r
.19816 .47061 .20846 .47985 .22341 .47467 .21316 .46544 Mtetra
.662 .755 .919 r
.21316 .46544 .22341 .47467 .23846 .46941 .22826 .46012 Mtetra
.657 .754 .921 r
.22826 .46012 .23846 .46941 .25355 .46457 .24342 .45494 Mtetra
.646 .744 .921 r
.24342 .45494 .25355 .46457 .26873 .45976 .25864 .45017 Mtetra
.654 .749 .919 r
.25864 .45017 .26873 .45976 .28402 .45454 .27398 .44505 Mtetra
.659 .753 .92 r
.27398 .44505 .28402 .45454 .29941 .44925 .28942 .43973 Mtetra
.655 .753 .922 r
.28942 .43973 .29941 .44925 .31479 .44535 .30494 .43453 Mtetra
.605 .71 .918 r
.30494 .43453 .31479 .44535 .33013 .44393 .32044 .43111 Mtetra
.558 .652 .898 r
.32044 .43111 .33013 .44393 .34553 .44378 .33594 .42946 Mtetra
.536 .617 .88 r
.33594 .42946 .34553 .44378 .3611 .44277 .35153 .42871 Mtetra
.558 .633 .881 r
.35153 .42871 .3611 .44277 .37699 .43798 .36728 .42714 Mtetra
.623 .721 .917 r
.36728 .42714 .37699 .43798 .39308 .43046 .38329 .42296 Mtetra
.672 .814 .951 r
.38329 .42296 .39308 .43046 .40933 .42055 .39948 .41676 Mtetra
.668 .904 .978 r
.39948 .41676 .40933 .42055 .42563 .41058 .41579 .40968 Mtetra
.607 .939 .948 r
.41579 .40968 .42563 .41058 .44195 .40184 .43219 .40224 Mtetra
.504 .908 .896 r
.43219 .40224 .44195 .40184 .4583 .39469 .44865 .39546 Mtetra
.393 .852 .852 r
.44865 .39546 .4583 .39469 .47471 .38918 .46518 .38991 Mtetra
.298 .795 .82 r
.46518 .38991 .47471 .38918 .4912 .38533 .48179 .38559 Mtetra
.274 .779 .83 r
.48179 .38559 .4912 .38533 .5078 .38309 .49851 .38193 Mtetra
.384 .838 .918 r
.49851 .38193 .5078 .38309 .52454 .38209 .51536 .37793 Mtetra
.562 .872 .994 r
.51536 .37793 .52454 .38209 .54142 .38107 .53232 .37304 Mtetra
.683 .818 .948 r
.53232 .37304 .54142 .38107 .55844 .37764 .54939 .36611 Mtetra
.731 .757 .874 r
.54939 .36611 .55844 .37764 .57554 .37144 .56651 .3565 Mtetra
.725 .701 .827 r
.56651 .3565 .57554 .37144 .59265 .36138 .58368 .34604 Mtetra
.71 .691 .83 r
.58368 .34604 .59265 .36138 .60981 .35042 .60093 .33648 Mtetra
.688 .704 .86 r
.60093 .33648 .60981 .35042 .62706 .34073 .6183 .3287 Mtetra
.656 .727 .901 r
.6183 .3287 .62706 .34073 .64447 .33355 .63583 .32274 Mtetra
.653 .752 .922 r
.63583 .32274 .64447 .33355 .66203 .3278 .65347 .31689 Mtetra
.657 .753 .921 r
.65347 .31689 .66203 .3278 .67971 .32197 .67121 .31083 Mtetra
.665 .753 .916 r
.67121 .31083 .67971 .32197 .69748 .31571 .68905 .30441 Mtetra
.654 .747 .918 r
.68905 .30441 .69748 .31571 .71536 .30948 .70703 .2984 Mtetra
.65 .751 .923 r
.70703 .2984 .71536 .30948 .73338 .30368 .72513 .29253 Mtetra
.653 .752 .923 r
.72513 .29253 .73338 .30368 .75151 .29778 .74334 .28649 Mtetra
.661 .754 .919 r
.74334 .28649 .75151 .29778 .76974 .29158 .76164 .28008 Mtetra
.658 .75 .918 r
.76164 .28008 .76974 .29158 .78808 .28519 .78007 .27374 Mtetra
.653 .75 .921 r
.78007 .27374 .78808 .28519 .80656 .27908 .79863 .2676 Mtetra
.66 .754 .92 r
.14318 .47628 .15373 .48543 .16848 .48033 .15797 .47111 Mtetra
.657 .753 .92 r
.15797 .47111 .16848 .48033 .18328 .47543 .17284 .46601 Mtetra
.649 .747 .921 r
.17284 .46601 .18328 .47543 .19816 .47061 .18777 .46116 Mtetra
.654 .749 .92 r
.18777 .46116 .19816 .47061 .21316 .46544 .2028 .45609 Mtetra
.66 .754 .92 r
.2028 .45609 .21316 .46544 .22826 .46012 .21794 .45078 Mtetra
.661 .756 .92 r
.21794 .45078 .22826 .46012 .24342 .45494 .23318 .44539 Mtetra
.652 .75 .922 r
.23318 .44539 .24342 .45494 .25864 .45017 .24847 .44033 Mtetra
.646 .743 .92 r
.24847 .44033 .25864 .45017 .27398 .44505 .26383 .43545 Mtetra
.658 .753 .92 r
.26383 .43545 .27398 .44505 .28942 .43973 .27932 .43011 Mtetra
.659 .754 .92 r
.27932 .43011 .28942 .43973 .30494 .43453 .29491 .42467 Mtetra
.651 .748 .92 r
.29491 .42467 .30494 .43453 .32044 .43111 .31057 .41951 Mtetra
.609 .699 .908 r
.31057 .41951 .32044 .43111 .33594 .42946 .32622 .41594 Mtetra
.575 .65 .887 r
.32622 .41594 .33594 .42946 .35153 .42871 .34191 .41368 Mtetra
.563 .621 .868 r
.34191 .41368 .35153 .42871 .36728 .42714 .3577 .41197 Mtetra
.57 .623 .865 r
.3577 .41197 .36728 .42714 .38329 .42296 .37363 .40997 Mtetra
.598 .673 .893 r
.37363 .40997 .38329 .42296 .39948 .41676 .38974 .40676 Mtetra
.636 .749 .93 r
.38974 .40676 .39948 .41676 .41579 .40968 .40603 .40194 Mtetra
.65 .807 .959 r
.40603 .40194 .41579 .40968 .43219 .40224 .42245 .39636 Mtetra
.639 .851 .981 r
.42245 .39636 .43219 .40224 .44865 .39546 .43898 .39063 Mtetra
.617 .872 .99 r
.43898 .39063 .44865 .39546 .46518 .38991 .45559 .38502 Mtetra
.61 .87 .991 r
.45559 .38502 .46518 .38991 .48179 .38559 .47231 .37953 Mtetra
.632 .849 .983 r
.47231 .37953 .48179 .38559 .49851 .38193 .48914 .37389 Mtetra
.669 .813 .952 r
.48914 .37389 .49851 .38193 .51536 .37793 .50607 .36748 Mtetra
.706 .771 .902 r
.50607 .36748 .51536 .37793 .53232 .37304 .52311 .35945 Mtetra
.715 .718 .851 r
.52311 .35945 .53232 .37304 .54939 .36611 .54022 .35017 Mtetra
.708 .682 .823 r
.54022 .35017 .54939 .36611 .56651 .3565 .55739 .34057 Mtetra
.7 .68 .827 r
.55739 .34057 .56651 .3565 .58368 .34604 .57464 .33151 Mtetra
.684 .695 .854 r
.57464 .33151 .58368 .34604 .60093 .33648 .592 .32377 Mtetra
.658 .716 .891 r
.592 .32377 .60093 .33648 .6183 .3287 .60948 .31764 Mtetra
.652 .748 .92 r
.60948 .31764 .6183 .3287 .63583 .32274 .62709 .31179 Mtetra
.654 .753 .922 r
.62709 .31179 .63583 .32274 .65347 .31689 .6448 .30584 Mtetra
.665 .756 .918 r
.6448 .30584 .65347 .31689 .67121 .31083 .66261 .29941 Mtetra
.659 .748 .915 r
.66261 .29941 .67121 .31083 .68905 .30441 .68054 .29315 Mtetra
.65 .749 .922 r
.68054 .29315 .68905 .30441 .70703 .2984 .6986 .28723 Mtetra
.651 .753 .924 r
.6986 .28723 .70703 .2984 .72513 .29253 .71678 .28122 Mtetra
.657 .754 .921 r
.71678 .28122 .72513 .29253 .74334 .28649 .73506 .27495 Mtetra
.662 .752 .917 r
.73506 .27495 .74334 .28649 .76164 .28008 .75344 .26844 Mtetra
.655 .749 .919 r
.75344 .26844 .76164 .28008 .78007 .27374 .77196 .26218 Mtetra
.652 .751 .922 r
.77196 .26218 .78007 .27374 .79863 .2676 .79062 .25599 Mtetra
.66 .754 .92 r
.1325 .46703 .14318 .47628 .15797 .47111 .14735 .46181 Mtetra
.659 .754 .92 r
.14735 .46181 .15797 .47111 .17284 .46601 .16227 .45659 Mtetra
.653 .751 .921 r
.16227 .45659 .17284 .46601 .18777 .46116 .17726 .45156 Mtetra
.65 .747 .921 r
.17726 .45156 .18777 .46116 .2028 .45609 .19233 .4466 Mtetra
.658 .753 .92 r
.19233 .4466 .2028 .45609 .21794 .45078 .20752 .44131 Mtetra
.661 .755 .92 r
.20752 .44131 .21794 .45078 .23318 .44539 .2228 .43588 Mtetra
.66 .755 .921 r
.2228 .43588 .23318 .44539 .24847 .44033 .23817 .43046 Mtetra
.648 .745 .92 r
.23817 .43046 .24847 .44033 .26383 .43545 .2536 .42543 Mtetra
.649 .744 .919 r
.2536 .42543 .26383 .43545 .27932 .43011 .26912 .42037 Mtetra
.658 .753 .921 r
.26912 .42037 .27932 .43011 .29491 .42467 .28476 .41493 Mtetra
.659 .755 .921 r
.28476 .41493 .29491 .42467 .31057 .41951 .30049 .40941 Mtetra
.653 .747 .919 r
.30049 .40941 .31057 .41951 .32622 .41594 .31631 .40409 Mtetra
.625 .703 .901 r
.31631 .40409 .32622 .41594 .34191 .41368 .33215 .39981 Mtetra
.596 .656 .879 r
.33215 .39981 .34191 .41368 .3577 .41197 .34804 .39669 Mtetra
.592 .633 .861 r
.34804 .39669 .3577 .41197 .37363 .40997 .36404 .39373 Mtetra
.59 .619 .849 r
.36404 .39373 .37363 .40997 .38974 .40676 .38016 .39083 Mtetra
.602 .63 .851 r
.38016 .39083 .38974 .40676 .40603 .40194 .39642 .38738 Mtetra
.62 .66 .867 r
.39642 .38738 .40603 .40194 .42245 .39636 .41283 .38311 Mtetra
.638 .69 .882 r
.41283 .38311 .42245 .39636 .43898 .39063 .42938 .37811 Mtetra
.653 .71 .889 r
.42938 .37811 .43898 .39063 .45559 .38502 .44606 .37243 Mtetra
.667 .715 .884 r
.44606 .37243 .45559 .38502 .47231 .37953 .46284 .36608 Mtetra
.679 .705 .868 r
.46284 .36608 .47231 .37953 .48914 .37389 .47974 .35898 Mtetra
.687 .687 .844 r
.47974 .35898 .48914 .37389 .50607 .36748 .49674 .35106 Mtetra
.689 .668 .824 r
.49674 .35106 .50607 .36748 .52311 .35945 .51382 .34256 Mtetra
.686 .662 .82 r
.51382 .34256 .52311 .35945 .54022 .35017 .53097 .3341 Mtetra
.687 .674 .831 r
.53097 .3341 .54022 .35017 .55739 .34057 .54821 .32581 Mtetra
.673 .687 .856 r
.54821 .32581 .55739 .34057 .57464 .33151 .56555 .31866 Mtetra
.657 .714 .891 r
.56555 .31866 .57464 .33151 .592 .32377 .583 .31257 Mtetra
.653 .746 .919 r
.583 .31257 .592 .32377 .60948 .31764 .60056 .30669 Mtetra
.654 .754 .923 r
.60056 .30669 .60948 .31764 .62709 .31179 .61824 .30071 Mtetra
.662 .755 .919 r
.61824 .30071 .62709 .31179 .6448 .30584 .63602 .29434 Mtetra
.662 .748 .914 r
.63602 .29434 .6448 .30584 .66261 .29941 .65391 .28793 Mtetra
.652 .746 .919 r
.65391 .28793 .66261 .29941 .68054 .29315 .67193 .28191 Mtetra
.651 .752 .924 r
.67193 .28191 .68054 .29315 .6986 .28723 .69007 .27591 Mtetra
.654 .753 .923 r
.69007 .27591 .6986 .28723 .71678 .28122 .70832 .26974 Mtetra
.661 .754 .919 r
.70832 .26974 .71678 .28122 .73506 .27495 .72667 .26322 Mtetra
.658 .75 .917 r
.72667 .26322 .73506 .27495 .75344 .26844 .74515 .25677 Mtetra
.653 .75 .921 r
.74515 .25677 .75344 .26844 .77196 .26218 .76376 .25051 Mtetra
.652 .751 .922 r
.76376 .25051 .77196 .26218 .79062 .25599 .7825 .24423 Mtetra
.658 .753 .92 r
.12172 .45765 .1325 .46703 .14735 .46181 .13661 .45243 Mtetra
.66 .754 .92 r
.13661 .45243 .14735 .46181 .16227 .45659 .15159 .44712 Mtetra
.657 .753 .92 r
.15159 .44712 .16227 .45659 .17726 .45156 .16665 .44187 Mtetra
.65 .747 .921 r
.16665 .44187 .17726 .45156 .19233 .4466 .18176 .43685 Mtetra
.653 .748 .92 r
.18176 .43685 .19233 .4466 .20752 .44131 .19698 .4317 Mtetra
.659 .754 .92 r
.19698 .4317 .20752 .44131 .2228 .43588 .21231 .42629 Mtetra
.661 .756 .92 r
.21231 .42629 .2228 .43588 .23817 .43046 .22774 .42076 Mtetra
.659 .754 .921 r
.22774 .42076 .23817 .43046 .2536 .42543 .24325 .41531 Mtetra
.648 .743 .919 r
.24325 .41531 .2536 .42543 .26912 .42037 .25882 .41022 Mtetra
.65 .745 .919 r
.25882 .41022 .26912 .42037 .28476 .41493 .27449 .40503 Mtetra
.658 .754 .921 r
.27449 .40503 .28476 .41493 .30049 .40941 .29028 .39952 Mtetra
.658 .755 .922 r
.29028 .39952 .30049 .40941 .31631 .40409 .30616 .39395 Mtetra
.658 .751 .919 r
.30616 .39395 .31631 .40409 .33215 .39981 .32214 .38835 Mtetra
.645 .721 .904 r
.32214 .38835 .33215 .39981 .34804 .39669 .33819 .3832 Mtetra
.624 .677 .881 r
.33819 .3832 .34804 .39669 .36404 .39373 .35429 .37886 Mtetra
.615 .652 .864 r
.35429 .37886 .36404 .39373 .38016 .39083 .37049 .37483 Mtetra
.617 .638 .848 r
.37049 .37483 .38016 .39083 .39642 .38738 .38681 .37061 Mtetra
.624 .631 .837 r
.38681 .37061 .39642 .38738 .41283 .38311 .40327 .36598 Mtetra
.632 .631 .831 r
.40327 .36598 .41283 .38311 .42938 .37811 .41985 .36081 Mtetra
.642 .634 .827 r
.41985 .36081 .42938 .37811 .44606 .37243 .43655 .35506 Mtetra
.652 .639 .824 r
.43655 .35506 .44606 .37243 .46284 .36608 .45337 .34872 Mtetra
.66 .644 .823 r
.45337 .34872 .46284 .36608 .47974 .35898 .4703 .34185 Mtetra
.667 .65 .824 r
.4703 .34185 .47974 .35898 .49674 .35106 .48732 .33455 Mtetra
.673 .662 .831 r
.48732 .33455 .49674 .35106 .51382 .34256 .50444 .32705 Mtetra
.671 .676 .846 r
.50444 .32705 .51382 .34256 .53097 .3341 .52165 .31986 Mtetra
.66 .691 .869 r
.52165 .31986 .53097 .3341 .54821 .32581 .53896 .31347 Mtetra
.653 .724 .901 r
.53896 .31347 .54821 .32581 .56555 .31866 .55637 .30754 Mtetra
.654 .75 .92 r
.55637 .30754 .56555 .31866 .583 .31257 .5739 .30157 Mtetra
.654 .754 .923 r
.5739 .30157 .583 .31257 .60056 .30669 .59154 .29555 Mtetra
.661 .755 .92 r
.59154 .29555 .60056 .30669 .61824 .30071 .60928 .28919 Mtetra
.663 .749 .914 r
.60928 .28919 .61824 .30071 .63602 .29434 .62714 .28271 Mtetra
.653 .745 .917 r
.62714 .28271 .63602 .29434 .65391 .28793 .64512 .2766 Mtetra
.651 .752 .924 r
.64512 .2766 .65391 .28793 .67193 .28191 .66322 .27057 Mtetra
.653 .754 .924 r
.66322 .27057 .67193 .28191 .69007 .27591 .68144 .26441 Mtetra
.659 .754 .921 r
.68144 .26441 .69007 .27591 .70832 .26974 .69976 .25796 Mtetra
.661 .751 .917 r
.69976 .25796 .70832 .26974 .72667 .26322 .71819 .25137 Mtetra
.654 .748 .919 r
.71819 .25137 .72667 .26322 .74515 .25677 .73676 .24502 Mtetra
.652 .751 .922 r
.73676 .24502 .74515 .25677 .76376 .25051 .75546 .23871 Mtetra
.654 .752 .922 r
.75546 .23871 .76376 .25051 .7825 .24423 .77428 .2323 Mtetra
.654 .749 .92 r
.11084 .44807 .12172 .45765 .13661 .45243 .12576 .44294 Mtetra
.659 .754 .92 r
.12576 .44294 .13661 .45243 .15159 .44712 .14078 .43759 Mtetra
.14078 .43759 .15159 .44712 .16665 .44187 .1559 .43221 Mtetra
.655 .752 .921 r
.1559 .43221 .16665 .44187 .18176 .43685 .17108 .42695 Mtetra
.65 .746 .92 r
.17108 .42695 .18176 .43685 .19698 .4317 .18634 .42185 Mtetra
.655 .75 .92 r
.18634 .42185 .19698 .4317 .21231 .42629 .20171 .41655 Mtetra
.659 .755 .921 r
.20171 .41655 .21231 .42629 .22774 .42076 .21719 .41104 Mtetra
.661 .757 .921 r
.21719 .41104 .22774 .42076 .24325 .41531 .23276 .40542 Mtetra
.658 .754 .921 r
.23276 .40542 .24325 .41531 .25882 .41022 .24842 .39989 Mtetra
.649 .743 .918 r
.24842 .39989 .25882 .41022 .27449 .40503 .26414 .39468 Mtetra
.649 .744 .919 r
.26414 .39468 .27449 .40503 .29028 .39952 .27996 .38944 Mtetra
.657 .753 .921 r
.27996 .38944 .29028 .39952 .30616 .39395 .2959 .38385 Mtetra
.657 .754 .921 r
.2959 .38385 .30616 .39395 .32214 .38835 .31193 .37821 Mtetra
.659 .755 .921 r
.31193 .37821 .32214 .38835 .33819 .3832 .32807 .37249 Mtetra
.656 .744 .914 r
.32807 .37249 .33819 .3832 .35429 .37886 .3443 .36682 Mtetra
.65 .717 .897 r
.3443 .36682 .35429 .37886 .37049 .37483 .36062 .36134 Mtetra
.644 .69 .878 r
.36062 .36134 .37049 .37483 .38681 .37061 .37703 .35596 Mtetra
.64 .67 .863 r
.37703 .35596 .38681 .37061 .40327 .36598 .39355 .35068 Mtetra
.642 .662 .855 r
.39355 .35068 .40327 .36598 .41985 .36081 .41018 .3452 Mtetra
.647 .661 .849 r
.41018 .3452 .41985 .36081 .43655 .35506 .42692 .33938 Mtetra
.653 .663 .848 r
.42692 .33938 .43655 .35506 .45337 .34872 .44377 .33321 Mtetra
.657 .668 .85 r
.44377 .33321 .45337 .34872 .4703 .34185 .46074 .32685 Mtetra
.656 .677 .858 r
.46074 .32685 .4703 .34185 .48732 .33455 .4778 .32057 Mtetra
.656 .694 .874 r
.4778 .32057 .48732 .33455 .50444 .32705 .49496 .3144 Mtetra
.654 .718 .895 r
.49496 .3144 .50444 .32705 .52165 .31986 .51223 .30841 Mtetra
.653 .742 .915 r
.51223 .30841 .52165 .31986 .53896 .31347 .5296 .30248 Mtetra
.654 .754 .923 r
.5296 .30248 .53896 .31347 .55637 .30754 .54709 .29645 Mtetra
.655 .753 .922 r
.54709 .29645 .55637 .30754 .5739 .30157 .56469 .29037 Mtetra
.662 .755 .919 r
.56469 .29037 .5739 .30157 .59154 .29555 .5824 .28394 Mtetra
.662 .748 .914 r
.5824 .28394 .59154 .29555 .60928 .28919 .60022 .27746 Mtetra
.654 .744 .916 r
.60022 .27746 .60928 .28919 .62714 .28271 .61816 .2713 Mtetra
.651 .751 .923 r
.61816 .2713 .62714 .28271 .64512 .2766 .63622 .26522 Mtetra
.652 .754 .924 r
.63622 .26522 .64512 .2766 .66322 .27057 .6544 .25904 Mtetra
.657 .754 .922 r
.6544 .25904 .66322 .27057 .68144 .26441 .67269 .25263 Mtetra
.661 .752 .918 r
.67269 .25263 .68144 .26441 .69976 .25796 .69109 .24599 Mtetra
.656 .748 .918 r
.69109 .24599 .69976 .25796 .71819 .25137 .70962 .23952 Mtetra
.653 .751 .921 r
.70962 .23952 .71819 .25137 .73676 .24502 .72828 .23315 Mtetra
.653 .752 .922 r
.72828 .23315 .73676 .24502 .75546 .23871 .74706 .22675 Mtetra
.657 .753 .921 r
.74706 .22675 .75546 .23871 .77428 .2323 .76596 .22011 Mtetra
.652 .748 .92 r
.09984 .43836 .11084 .44807 .12576 .44294 .11479 .43326 Mtetra
.657 .751 .92 r
.11479 .43326 .12576 .44294 .14078 .43759 .12986 .42795 Mtetra
.659 .754 .92 r
.12986 .42795 .14078 .43759 .1559 .43221 .14502 .42251 Mtetra
.658 .754 .92 r
.14502 .42251 .1559 .43221 .17108 .42695 .16028 .41707 Mtetra
.654 .75 .921 r
.16028 .41707 .17108 .42695 .18634 .42185 .1756 .41177 Mtetra
.65 .746 .92 r
.1756 .41177 .18634 .42185 .20171 .41655 .191 .40657 Mtetra
.656 .751 .92 r
.191 .40657 .20171 .41655 .21719 .41104 .20652 .40114 Mtetra
.659 .755 .921 r
.20652 .40114 .21719 .41104 .23276 .40542 .22214 .39554 Mtetra
.661 .757 .921 r
.22214 .39554 .23276 .40542 .24842 .39989 .23786 .38985 Mtetra
.659 .754 .921 r
.23786 .38985 .24842 .39989 .26414 .39468 .25367 .38421 Mtetra
.651 .744 .918 r
.25367 .38421 .26414 .39468 .27996 .38944 .26955 .37881 Mtetra
.649 .742 .917 r
.26955 .37881 .27996 .38944 .2959 .38385 .28553 .37346 Mtetra
.653 .749 .92 r
.28553 .37346 .2959 .38385 .31193 .37821 .30161 .36792 Mtetra
.657 .754 .921 r
.30161 .36792 .31193 .37821 .32807 .37249 .31781 .3622 Mtetra
.657 .755 .922 r
.31781 .3622 .32807 .37249 .3443 .36682 .3341 .35644 Mtetra
.656 .755 .922 r
.3341 .35644 .3443 .36682 .36062 .36134 .35049 .35067 Mtetra
.658 .75 .918 r
.35049 .35067 .36062 .36134 .37703 .35596 .36699 .3448 Mtetra
.656 .741 .912 r
.36699 .3448 .37703 .35596 .39355 .35068 .38358 .33894 Mtetra
.655 .731 .905 r
.38358 .33894 .39355 .35068 .41018 .3452 .40028 .33308 Mtetra
.655 .724 .9 r
.40028 .33308 .41018 .3452 .42692 .33938 .41708 .32719 Mtetra
.41708 .32719 .42692 .33938 .44377 .33321 .43399 .32127 Mtetra
.654 .73 .905 r
.43399 .32127 .44377 .33321 .46074 .32685 .451 .31534 Mtetra
.653 .74 .913 r
.451 .31534 .46074 .32685 .4778 .32057 .46812 .30943 Mtetra
.655 .749 .919 r
.46812 .30943 .4778 .32057 .49496 .3144 .48535 .30342 Mtetra
.655 .754 .923 r
.48535 .30342 .49496 .3144 .51223 .30841 .50269 .29738 Mtetra
.50269 .29738 .51223 .30841 .5296 .30248 .52014 .29131 Mtetra
.658 .754 .921 r
.52014 .29131 .5296 .30248 .54709 .29645 .5377 .28505 Mtetra
.662 .752 .917 r
.5377 .28505 .54709 .29645 .56469 .29037 .55537 .2786 Mtetra
.66 .746 .913 r
.55537 .2786 .56469 .29037 .5824 .28394 .57316 .27217 Mtetra
.653 .745 .917 r
.57316 .27217 .5824 .28394 .60022 .27746 .59106 .266 Mtetra
.651 .752 .923 r
.59106 .266 .60022 .27746 .61816 .2713 .60908 .25988 Mtetra
.653 .754 .924 r
.60908 .25988 .61816 .2713 .63622 .26522 .62722 .25365 Mtetra
.656 .754 .922 r
.62722 .25365 .63622 .26522 .6544 .25904 .64547 .24724 Mtetra
.661 .753 .918 r
.64547 .24724 .6544 .25904 .67269 .25263 .66384 .24058 Mtetra
.658 .748 .917 r
.66384 .24058 .67269 .25263 .69109 .24599 .68233 .23402 Mtetra
.653 .75 .92 r
.68233 .23402 .69109 .24599 .70962 .23952 .70095 .22759 Mtetra
.653 .752 .922 r
.70095 .22759 .70962 .23952 .72828 .23315 .71969 .22115 Mtetra
.655 .753 .922 r
.71969 .22115 .72828 .23315 .74706 .22675 .73855 .21457 Mtetra
.659 .753 .919 r
.73855 .21457 .74706 .22675 .76596 .22011 .75753 .20775 Mtetra
.653 .75 .921 r
.08871 .42859 .09984 .43836 .11479 .43326 .10372 .42338 Mtetra
.652 .748 .92 r
.10372 .42338 .11479 .43326 .12986 .42795 .11882 .41818 Mtetra
.658 .753 .92 r
.11882 .41818 .12986 .42795 .14502 .42251 .13403 .41272 Mtetra
.659 .754 .92 r
.13403 .41272 .14502 .42251 .16028 .41707 .14934 .40719 Mtetra
.658 .753 .921 r
.14934 .40719 .16028 .41707 .1756 .41177 .16473 .40168 Mtetra
.653 .749 .92 r
.16473 .40168 .1756 .41177 .191 .40657 .1802 .39631 Mtetra
.651 .746 .919 r
.1802 .39631 .191 .40657 .20652 .40114 .19575 .391 Mtetra
.655 .751 .92 r
.19575 .391 .20652 .40114 .22214 .39554 .21141 .38548 Mtetra
.659 .755 .921 r
.21141 .38548 .22214 .39554 .23786 .38985 .22718 .37981 Mtetra
.66 .757 .922 r
.22718 .37981 .23786 .38985 .25367 .38421 .24305 .37405 Mtetra
.659 .756 .921 r
.24305 .37405 .25367 .38421 .26955 .37881 .25902 .36828 Mtetra
.655 .748 .918 r
.25902 .36828 .26955 .37881 .28553 .37346 .27507 .36263 Mtetra
.651 .742 .916 r
.27507 .36263 .28553 .37346 .30161 .36792 .2912 .35712 Mtetra
.651 .744 .918 r
.2912 .35712 .30161 .36792 .31781 .3622 .30744 .35157 Mtetra
.653 .749 .92 r
.30744 .35157 .31781 .3622 .3341 .35644 .32378 .3459 Mtetra
.656 .754 .922 r
.32378 .3459 .3341 .35644 .35049 .35067 .34023 .34007 Mtetra
.34023 .34007 .35049 .35067 .36699 .3448 .35679 .3342 Mtetra
.656 .755 .923 r
.35679 .3342 .36699 .3448 .38358 .33894 .37345 .32829 Mtetra
.37345 .32829 .38358 .33894 .40028 .33308 .39022 .32236 Mtetra
.39022 .32236 .40028 .33308 .41708 .32719 .40708 .3164 Mtetra
.40708 .3164 .41708 .32719 .43399 .32127 .42406 .31042 Mtetra
.655 .755 .923 r
.42406 .31042 .43399 .32127 .451 .31534 .44114 .3044 Mtetra
.44114 .3044 .451 .31534 .46812 .30943 .45833 .29835 Mtetra
.655 .753 .922 r
.45833 .29835 .46812 .30943 .48535 .30342 .47563 .29226 Mtetra
.659 .754 .921 r
.47563 .29226 .48535 .30342 .50269 .29738 .49304 .286 Mtetra
.66 .752 .918 r
.49304 .286 .50269 .29738 .52014 .29131 .51057 .27961 Mtetra
.66 .747 .914 r
.51057 .27961 .52014 .29131 .5377 .28505 .5282 .27318 Mtetra
.656 .744 .914 r
.5282 .27318 .5377 .28505 .55537 .2786 .54595 .26689 Mtetra
.653 .747 .919 r
.54595 .26689 .55537 .2786 .57316 .27217 .56381 .26071 Mtetra
.652 .753 .924 r
.56381 .26071 .57316 .27217 .59106 .266 .58179 .25453 Mtetra
.653 .755 .924 r
.58179 .25453 .59106 .266 .60908 .25988 .59989 .24824 Mtetra
.656 .754 .922 r
.59989 .24824 .60908 .25988 .62722 .25365 .6181 .24179 Mtetra
.66 .753 .919 r
.6181 .24179 .62722 .25365 .64547 .24724 .63643 .23511 Mtetra
.658 .748 .917 r
.63643 .23511 .64547 .24724 .66384 .24058 .65488 .22849 Mtetra
.654 .749 .92 r
.65488 .22849 .66384 .24058 .68233 .23402 .67346 .22201 Mtetra
.653 .752 .922 r
.67346 .22201 .68233 .23402 .70095 .22759 .69217 .21553 Mtetra
.654 .753 .922 r
.69217 .21553 .70095 .22759 .71969 .22115 .71099 .20897 Mtetra
.659 .754 .92 r
.71099 .20897 .71969 .22115 .73855 .21457 .72993 .20214 Mtetra
.658 .75 .918 r
.72993 .20214 .73855 .21457 .75753 .20775 .749 .19529 Mtetra
.656 .752 .92 r
.07746 .41878 .08871 .42859 .10372 .42338 .09253 .41341 Mtetra
.652 .748 .92 r
.09253 .41341 .10372 .42338 .11882 .41818 .10767 .40814 Mtetra
.653 .749 .92 r
.10767 .40814 .11882 .41818 .13403 .41272 .12291 .4028 Mtetra
.658 .754 .92 r
.12291 .4028 .13403 .41272 .14934 .40719 .13827 .39724 Mtetra
.659 .755 .921 r
.13827 .39724 .14934 .40719 .16473 .40168 .15372 .39163 Mtetra
.658 .753 .921 r
.15372 .39163 .16473 .40168 .1802 .39631 .16926 .38603 Mtetra
.653 .749 .92 r
.16926 .38603 .1802 .39631 .19575 .391 .18487 .38055 Mtetra
.651 .746 .919 r
.18487 .38055 .19575 .391 .21141 .38548 .20058 .37513 Mtetra
.654 .75 .92 r
.20058 .37513 .21141 .38548 .22718 .37981 .21639 .36956 Mtetra
.658 .755 .921 r
.21639 .36956 .22718 .37981 .24305 .37405 .23231 .36382 Mtetra
.659 .757 .922 r
.23231 .36382 .24305 .37405 .25902 .36828 .24833 .358 Mtetra
.24833 .358 .25902 .36828 .27507 .36263 .26445 .35213 Mtetra
.658 .753 .92 r
.26445 .35213 .27507 .36263 .2912 .35712 .28067 .34627 Mtetra
.656 .747 .917 r
.28067 .34627 .2912 .35712 .30744 .35157 .29697 .34046 Mtetra
.652 .742 .915 r
.29697 .34046 .30744 .35157 .32378 .3459 .31338 .33475 Mtetra
.653 .742 .916 r
.31338 .33475 .32378 .3459 .34023 .34007 .32988 .32899 Mtetra
.653 .745 .917 r
.32988 .32899 .34023 .34007 .35679 .3342 .34649 .32317 Mtetra
.654 .748 .919 r
.34649 .32317 .35679 .3342 .37345 .32829 .36321 .31728 Mtetra
.655 .75 .92 r
.36321 .31728 .37345 .32829 .39022 .32236 .38004 .31132 Mtetra
.656 .751 .92 r
.38004 .31132 .39022 .32236 .40708 .3164 .39698 .30529 Mtetra
.657 .751 .92 r
.39698 .30529 .40708 .3164 .42406 .31042 .41402 .2992 Mtetra
.657 .751 .919 r
.41402 .2992 .42406 .31042 .44114 .3044 .43117 .29303 Mtetra
.658 .75 .918 r
.43117 .29303 .44114 .3044 .45833 .29835 .44843 .28679 Mtetra
.659 .747 .915 r
.44843 .28679 .45833 .29835 .47563 .29226 .46581 .28048 Mtetra
.659 .744 .913 r
.46581 .28048 .47563 .29226 .49304 .286 .48329 .27412 Mtetra
.656 .743 .914 r
.48329 .27412 .49304 .286 .51057 .27961 .50088 .26785 Mtetra
.654 .746 .918 r
.50088 .26785 .51057 .27961 .5282 .27318 .51859 .26164 Mtetra
.652 .751 .922 r
.51859 .26164 .5282 .27318 .54595 .26689 .53641 .25543 Mtetra
.653 .755 .924 r
.53641 .25543 .54595 .26689 .56381 .26071 .55435 .24917 Mtetra
.654 .755 .924 r
.55435 .24917 .56381 .26071 .58179 .25453 .57241 .24282 Mtetra
.657 .755 .922 r
.57241 .24282 .58179 .25453 .59989 .24824 .59058 .23628 Mtetra
.66 .752 .918 r
.59058 .23628 .59989 .24824 .6181 .24179 .60887 .22958 Mtetra
.658 .748 .916 r
.60887 .22958 .6181 .24179 .63643 .23511 .62728 .22294 Mtetra
.654 .749 .919 r
.62728 .22294 .63643 .23511 .65488 .22849 .64582 .21641 Mtetra
.653 .752 .922 r
.64582 .21641 .65488 .22849 .67346 .22201 .66449 .20989 Mtetra
.654 .753 .923 r
.66449 .20989 .67346 .22201 .69217 .21553 .68328 .2033 Mtetra
.658 .754 .921 r
.68328 .2033 .69217 .21553 .71099 .20897 .70218 .19647 Mtetra
.659 .751 .918 r
.70218 .19647 .71099 .20897 .72993 .20214 .72121 .18956 Mtetra
.656 .749 .919 r
.72121 .18956 .72993 .20214 .749 .19529 .74037 .18274 Mtetra
.658 .753 .92 r
.06607 .4089 .07746 .41878 .09253 .41341 .0812 .40341 Mtetra
.656 .751 .92 r
.0812 .40341 .09253 .41341 .10767 .40814 .09641 .39797 Mtetra
.652 .748 .92 r
.09641 .39797 .10767 .40814 .12291 .4028 .11169 .39261 Mtetra
.654 .749 .92 r
.11169 .39261 .12291 .4028 .13827 .39724 .12708 .38716 Mtetra
.658 .754 .921 r
.12708 .38716 .13827 .39724 .15372 .39163 .14258 .38151 Mtetra
.659 .755 .921 r
.14258 .38151 .15372 .39163 .16926 .38603 .15818 .37581 Mtetra
.658 .754 .921 r
.15818 .37581 .16926 .38603 .18487 .38055 .17387 .37011 Mtetra
.655 .749 .919 r
.17387 .37011 .18487 .38055 .20058 .37513 .18964 .36449 Mtetra
.651 .746 .919 r
.18964 .36449 .20058 .37513 .21639 .36956 .20549 .35896 Mtetra
.652 .748 .92 r
.20549 .35896 .21639 .36956 .23231 .36382 .22145 .35336 Mtetra
.657 .753 .921 r
.22145 .35336 .23231 .36382 .24833 .358 .23752 .34756 Mtetra
.658 .756 .922 r
.23752 .34756 .24833 .358 .26445 .35213 .2537 .34168 Mtetra
.658 .757 .923 r
.2537 .34168 .26445 .35213 .28067 .34627 .26998 .33574 Mtetra
.659 .757 .923 r
.26998 .33574 .28067 .34627 .29697 .34046 .28635 .32976 Mtetra
.658 .754 .921 r
.28635 .32976 .29697 .34046 .31338 .33475 .30283 .32378 Mtetra
.657 .75 .918 r
.30283 .32378 .31338 .33475 .32988 .32899 .31941 .31778 Mtetra
.656 .746 .916 r
.31941 .31778 .32988 .32899 .34649 .32317 .33609 .31178 Mtetra
.655 .744 .915 r
.33609 .31178 .34649 .32317 .36321 .31728 .35288 .30576 Mtetra
.655 .742 .914 r
.35288 .30576 .36321 .31728 .38004 .31132 .36977 .29972 Mtetra
.656 .742 .914 r
.36977 .29972 .38004 .31132 .39698 .30529 .38677 .29362 Mtetra
.656 .743 .914 r
.38677 .29362 .39698 .30529 .41402 .2992 .40388 .28746 Mtetra
.40388 .28746 .41402 .2992 .43117 .29303 .42109 .28127 Mtetra
.655 .744 .915 r
.42109 .28127 .43117 .29303 .44843 .28679 .43842 .27507 Mtetra
.655 .746 .917 r
.43842 .27507 .44843 .28679 .46581 .28048 .45586 .26886 Mtetra
.654 .749 .92 r
.45586 .26886 .46581 .28048 .48329 .27412 .47341 .26264 Mtetra
.653 .753 .923 r
.47341 .26264 .48329 .27412 .50088 .26785 .49108 .25641 Mtetra
.653 .755 .924 r
.49108 .25641 .50088 .26785 .51859 .26164 .50886 .25013 Mtetra
.654 .756 .924 r
.50886 .25013 .51859 .26164 .53641 .25543 .52676 .24378 Mtetra
.655 .755 .923 r
.52676 .24378 .53641 .25543 .55435 .24917 .54477 .23735 Mtetra
.659 .754 .921 r
.54477 .23735 .55435 .24917 .57241 .24282 .56291 .23072 Mtetra
.66 .75 .917 r
.56291 .23072 .57241 .24282 .59058 .23628 .58116 .224 Mtetra
.657 .747 .917 r
.58116 .224 .59058 .23628 .60887 .22958 .59953 .21736 Mtetra
.654 .749 .92 r
.59953 .21736 .60887 .22958 .62728 .22294 .61803 .2108 Mtetra
.653 .752 .922 r
.61803 .2108 .62728 .22294 .64582 .21641 .63665 .20424 Mtetra
.654 .753 .923 r
.63665 .20424 .64582 .21641 .66449 .20989 .6554 .1976 Mtetra
.658 .754 .921 r
.6554 .1976 .66449 .20989 .68328 .2033 .67427 .19076 Mtetra
.659 .751 .918 r
.67427 .19076 .68328 .2033 .70218 .19647 .69326 .1838 Mtetra
.656 .749 .918 r
.69326 .1838 .70218 .19647 .72121 .18956 .71238 .17693 Mtetra
.654 .751 .921 r
.71238 .17693 .72121 .18956 .74037 .18274 .73164 .17008 Mtetra
.659 .754 .92 r
.05455 .39895 .06607 .4089 .0812 .40341 .06974 .39336 Mtetra
.657 .753 .92 r
.06974 .39336 .0812 .40341 .09641 .39797 .085 .38779 Mtetra
.655 .751 .92 r
.085 .38779 .09641 .39797 .11169 .39261 .10036 .38226 Mtetra
.652 .748 .92 r
.10036 .38226 .11169 .39261 .12708 .38716 .11579 .3768 Mtetra
.654 .749 .92 r
.11579 .3768 .12708 .38716 .14258 .38151 .13132 .37126 Mtetra
.658 .754 .921 r
.13132 .37126 .14258 .38151 .15818 .37581 .14697 .36552 Mtetra
.659 .755 .921 r
.14697 .36552 .15818 .37581 .17387 .37011 .16271 .35973 Mtetra
.658 .754 .921 r
.16271 .35973 .17387 .37011 .18964 .36449 .17855 .35392 Mtetra
.656 .751 .92 r
.17855 .35392 .18964 .36449 .20549 .35896 .19448 .34814 Mtetra
.653 .746 .918 r
.19448 .34814 .20549 .35896 .22145 .35336 .2105 .34246 Mtetra
.652 .746 .918 r
.2105 .34246 .22145 .35336 .23752 .34756 .22661 .33677 Mtetra
.654 .75 .92 r
.22661 .33677 .23752 .34756 .2537 .34168 .24283 .33098 Mtetra
.656 .754 .922 r
.24283 .33098 .2537 .34168 .26998 .33574 .25916 .32505 Mtetra
.657 .755 .922 r
.25916 .32505 .26998 .33574 .28635 .32976 .2756 .31906 Mtetra
.657 .757 .923 r
.2756 .31906 .28635 .32976 .30283 .32378 .29214 .31302 Mtetra
.657 .757 .924 r
.29214 .31302 .30283 .32378 .31941 .31778 .30879 .30695 Mtetra
.657 .757 .923 r
.30879 .30695 .31941 .31778 .33609 .31178 .32553 .30084 Mtetra
.657 .756 .923 r
.32553 .30084 .33609 .31178 .35288 .30576 .34239 .29471 Mtetra
.656 .755 .923 r
.34239 .29471 .35288 .30576 .36977 .29972 .35935 .28856 Mtetra
.656 .754 .922 r
.35935 .28856 .36977 .29972 .38677 .29362 .37641 .28239 Mtetra
.655 .754 .922 r
.37641 .28239 .38677 .29362 .40388 .28746 .39359 .27619 Mtetra
.655 .755 .923 r
.39359 .27619 .40388 .28746 .42109 .28127 .41088 .26998 Mtetra
.654 .755 .924 r
.41088 .26998 .42109 .28127 .43842 .27507 .42827 .26374 Mtetra
.654 .756 .924 r
.42827 .26374 .43842 .27507 .45586 .26886 .44578 .25746 Mtetra
.654 .756 .925 r
.44578 .25746 .45586 .26886 .47341 .26264 .46341 .25115 Mtetra
.655 .756 .924 r
.46341 .25115 .47341 .26264 .49108 .25641 .48115 .24478 Mtetra
.655 .755 .923 r
.48115 .24478 .49108 .25641 .50886 .25013 .49901 .23835 Mtetra
.658 .754 .921 r
.49901 .23835 .50886 .25013 .52676 .24378 .51699 .23177 Mtetra
.659 .752 .918 r
.51699 .23177 .52676 .24378 .54477 .23735 .53508 .22508 Mtetra
.659 .748 .916 r
.53508 .22508 .54477 .23735 .56291 .23072 .55329 .21837 Mtetra
.655 .747 .917 r
.55329 .21837 .56291 .23072 .58116 .224 .57162 .21177 Mtetra
.654 .75 .921 r
.57162 .21177 .58116 .224 .59953 .21736 .59008 .20517 Mtetra
.653 .752 .922 r
.59008 .20517 .59953 .21736 .61803 .2108 .60866 .19856 Mtetra
.654 .753 .923 r
.60866 .19856 .61803 .2108 .63665 .20424 .62737 .19188 Mtetra
.658 .754 .921 r
.62737 .19188 .63665 .20424 .6554 .1976 .64619 .185 Mtetra
.659 .751 .918 r
.64619 .185 .6554 .1976 .67427 .19076 .66514 .178 Mtetra
.656 .749 .918 r
.66514 .178 .67427 .19076 .69326 .1838 .68423 .17108 Mtetra
.655 .751 .92 r
.68423 .17108 .69326 .1838 .71238 .17693 .70344 .16418 Mtetra
.653 .751 .922 r
.70344 .16418 .71238 .17693 .73164 .17008 .72279 .1573 Mtetra
.657 .752 .92 r
.04291 .38883 .05455 .39895 .06974 .39336 .05814 .38324 Mtetra
.659 .754 .921 r
.05814 .38324 .06974 .39336 .085 .38779 .07346 .37756 Mtetra
.657 .753 .92 r
.07346 .37756 .085 .38779 .10036 .38226 .08888 .3719 Mtetra
.655 .751 .92 r
.08888 .3719 .10036 .38226 .11579 .3768 .10437 .36626 Mtetra
.652 .748 .92 r
.10437 .36626 .11579 .3768 .13132 .37126 .11995 .3607 Mtetra
.653 .749 .92 r
.11995 .3607 .13132 .37126 .14697 .36552 .13563 .35508 Mtetra
.657 .754 .921 r
.13563 .35508 .14697 .36552 .16271 .35973 .15143 .34927 Mtetra
.658 .755 .921 r
.15143 .34927 .16271 .35973 .17855 .35392 .16733 .34338 Mtetra
.658 .754 .921 r
.16733 .34338 .17855 .35392 .19448 .34814 .18332 .33747 Mtetra
.657 .753 .921 r
.18332 .33747 .19448 .34814 .2105 .34246 .19941 .33156 Mtetra
.656 .749 .919 r
.19941 .33156 .2105 .34246 .22661 .33677 .21559 .32566 Mtetra
.653 .746 .918 r
.21559 .32566 .22661 .33677 .24283 .33098 .23187 .31983 Mtetra
.23187 .31983 .24283 .33098 .25916 .32505 .24825 .31397 Mtetra
.654 .749 .92 r
.24825 .31397 .25916 .32505 .2756 .31906 .26474 .30804 Mtetra
.655 .752 .921 r
.26474 .30804 .2756 .31906 .29214 .31302 .28133 .30202 Mtetra
.656 .754 .922 r
.28133 .30202 .29214 .31302 .30879 .30695 .29804 .29592 Mtetra
.656 .755 .923 r
.29804 .29592 .30879 .30695 .32553 .30084 .31485 .28977 Mtetra
.656 .756 .923 r
.31485 .28977 .32553 .30084 .34239 .29471 .33177 .28359 Mtetra
.656 .756 .924 r
.33177 .28359 .34239 .29471 .35935 .28856 .3488 .27737 Mtetra
.3488 .27737 .35935 .28856 .37641 .28239 .36593 .27113 Mtetra
.36593 .27113 .37641 .28239 .39359 .27619 .38318 .26485 Mtetra
.655 .756 .924 r
.38318 .26485 .39359 .27619 .41088 .26998 .40054 .25854 Mtetra
.655 .756 .923 r
.40054 .25854 .41088 .26998 .42827 .26374 .41801 .25219 Mtetra
.655 .755 .923 r
.41801 .25219 .42827 .26374 .44578 .25746 .43559 .2458 Mtetra
.657 .754 .922 r
.43559 .2458 .44578 .25746 .46341 .25115 .45329 .23932 Mtetra
.658 .753 .92 r
.45329 .23932 .46341 .25115 .48115 .24478 .47111 .23274 Mtetra
.658 .751 .918 r
.47111 .23274 .48115 .24478 .49901 .23835 .48904 .22609 Mtetra
.658 .748 .916 r
.48904 .22609 .49901 .23835 .51699 .23177 .5071 .2194 Mtetra
.656 .746 .917 r
.5071 .2194 .51699 .23177 .53508 .22508 .52527 .21277 Mtetra
.654 .749 .919 r
.52527 .21277 .53508 .22508 .55329 .21837 .54356 .20616 Mtetra
.654 .752 .922 r
.54356 .20616 .55329 .21837 .57162 .21177 .56197 .19953 Mtetra
.654 .753 .923 r
.56197 .19953 .57162 .21177 .59008 .20517 .58051 .19287 Mtetra
.654 .754 .923 r
.58051 .19287 .59008 .20517 .60866 .19856 .59918 .18613 Mtetra
.658 .754 .921 r
.59918 .18613 .60866 .19856 .62737 .19188 .61796 .17918 Mtetra
.659 .751 .918 r
.61796 .17918 .62737 .19188 .64619 .185 .63687 .17216 Mtetra
.656 .749 .918 r
.63687 .17216 .64619 .185 .66514 .178 .65591 .1652 Mtetra
.655 .751 .92 r
.65591 .1652 .66514 .178 .68423 .17108 .67509 .15826 Mtetra
.653 .751 .922 r
.67509 .15826 .68423 .17108 .70344 .16418 .6944 .15133 Mtetra
.655 .753 .922 r
.6944 .15133 .70344 .16418 .72279 .1573 .71384 .14429 Mtetra
.653 .749 .92 r
.03116 .37848 .04291 .38883 .05814 .38324 .04641 .37295 Mtetra
.657 .753 .92 r
.04641 .37295 .05814 .38324 .07346 .37756 .06178 .36727 Mtetra
.658 .754 .921 r
.06178 .36727 .07346 .37756 .08888 .3719 .07726 .36149 Mtetra
.657 .753 .92 r
.07726 .36149 .08888 .3719 .10437 .36626 .09282 .35573 Mtetra
.656 .751 .92 r
.09282 .35573 .10437 .36626 .11995 .3607 .10846 .34998 Mtetra
.653 .748 .919 r
.10846 .34998 .11995 .3607 .13563 .35508 .1242 .34429 Mtetra
.1242 .34429 .13563 .35508 .15143 .34927 .14003 .33858 Mtetra
.656 .752 .921 r
.14003 .33858 .15143 .34927 .16733 .34338 .15597 .33272 Mtetra
.658 .755 .921 r
.15597 .33272 .16733 .34338 .18332 .33747 .17202 .32676 Mtetra
.17202 .32676 .18332 .33747 .19941 .33156 .18817 .32075 Mtetra
.658 .754 .921 r
.18817 .32075 .19941 .33156 .21559 .32566 .20442 .31471 Mtetra
.657 .753 .92 r
.20442 .31471 .21559 .32566 .23187 .31983 .22077 .30866 Mtetra
.656 .749 .919 r
.22077 .30866 .23187 .31983 .24825 .31397 .23722 .30261 Mtetra
.654 .746 .917 r
.23722 .30261 .24825 .31397 .26474 .30804 .25377 .29657 Mtetra
.25377 .29657 .26474 .30804 .28133 .30202 .27043 .29053 Mtetra
.654 .746 .918 r
.27043 .29053 .28133 .30202 .29804 .29592 .28719 .28443 Mtetra
.655 .748 .919 r
.28719 .28443 .29804 .29592 .31485 .28977 .30406 .27827 Mtetra
.655 .75 .919 r
.30406 .27827 .31485 .28977 .33177 .28359 .32104 .27207 Mtetra
.655 .751 .92 r
.32104 .27207 .33177 .28359 .3488 .27737 .33813 .2658 Mtetra
.656 .751 .92 r
.33813 .2658 .3488 .27737 .36593 .27113 .35534 .25948 Mtetra
.35534 .25948 .36593 .27113 .38318 .26485 .37265 .2531 Mtetra
.37265 .2531 .38318 .26485 .40054 .25854 .39008 .24667 Mtetra
.657 .75 .919 r
.39008 .24667 .40054 .25854 .41801 .25219 .40763 .24018 Mtetra
.657 .749 .918 r
.40763 .24018 .41801 .25219 .43559 .2458 .42528 .23363 Mtetra
.657 .748 .916 r
.42528 .23363 .43559 .2458 .45329 .23932 .44306 .22703 Mtetra
.657 .746 .916 r
.44306 .22703 .45329 .23932 .47111 .23274 .46095 .2204 Mtetra
.655 .747 .917 r
.46095 .2204 .47111 .23274 .48904 .22609 .47896 .2138 Mtetra
.655 .749 .919 r
.47896 .2138 .48904 .22609 .5071 .2194 .49709 .20718 Mtetra
.654 .752 .921 r
.49709 .20718 .5071 .2194 .52527 .21277 .51533 .20054 Mtetra
.654 .753 .923 r
.51533 .20054 .52527 .21277 .54356 .20616 .53371 .19388 Mtetra
.654 .754 .923 r
.53371 .19388 .54356 .20616 .56197 .19953 .5522 .18716 Mtetra
.656 .754 .922 r
.5522 .18716 .56197 .19953 .58051 .19287 .57082 .18031 Mtetra
.658 .753 .92 r
.57082 .18031 .58051 .19287 .59918 .18613 .58957 .17331 Mtetra
.658 .75 .918 r
.58957 .17331 .59918 .18613 .61796 .17918 .60844 .16628 Mtetra
.656 .749 .918 r
.60844 .16628 .61796 .17918 .63687 .17216 .62744 .1593 Mtetra
.655 .751 .92 r
.62744 .1593 .63687 .17216 .65591 .1652 .64657 .15232 Mtetra
.653 .751 .922 r
.64657 .15232 .65591 .1652 .67509 .15826 .66583 .14534 Mtetra
.655 .753 .922 r
.66583 .14534 .67509 .15826 .6944 .15133 .68523 .13826 Mtetra
.658 .753 .92 r
.68523 .13826 .6944 .15133 .71384 .14429 .70476 .131 Mtetra
.654 .749 .92 r
.01927 .36802 .03116 .37848 .04641 .37295 .03458 .36242 Mtetra
.03458 .36242 .04641 .37295 .06178 .36727 .04998 .35679 Mtetra
.657 .752 .921 r
.04998 .35679 .06178 .36727 .07726 .36149 .0655 .35102 Mtetra
.658 .754 .921 r
.0655 .35102 .07726 .36149 .09282 .35573 .08111 .34515 Mtetra
.657 .753 .921 r
.08111 .34515 .09282 .35573 .10846 .34998 .09682 .33928 Mtetra
.656 .752 .92 r
.09682 .33928 .10846 .34998 .1242 .34429 .11262 .33341 Mtetra
.654 .749 .919 r
.11262 .33341 .1242 .34429 .14003 .33858 .12852 .32758 Mtetra
.653 .748 .919 r
.12852 .32758 .14003 .33858 .15597 .33272 .1445 .32176 Mtetra
.654 .75 .92 r
.1445 .32176 .15597 .33272 .17202 .32676 .16059 .31587 Mtetra
.657 .753 .921 r
.16059 .31587 .17202 .32676 .18817 .32075 .1768 .30984 Mtetra
.657 .755 .922 r
.1768 .30984 .18817 .32075 .20442 .31471 .19311 .30374 Mtetra
.658 .755 .922 r
.19311 .30374 .20442 .31471 .22077 .30866 .20952 .2976 Mtetra
.657 .754 .922 r
.20952 .2976 .22077 .30866 .23722 .30261 .22604 .29143 Mtetra
.657 .753 .921 r
.22604 .29143 .23722 .30261 .25377 .29657 .24266 .28524 Mtetra
.656 .751 .92 r
.24266 .28524 .25377 .29657 .27043 .29053 .25938 .27902 Mtetra
.656 .749 .919 r
.25938 .27902 .27043 .29053 .28719 .28443 .27621 .27277 Mtetra
.656 .748 .918 r
.27621 .27277 .28719 .28443 .30406 .27827 .29315 .26649 Mtetra
.656 .747 .917 r
.29315 .26649 .30406 .27827 .32104 .27207 .3102 .26018 Mtetra
.656 .746 .917 r
.3102 .26018 .32104 .27207 .33813 .2658 .32736 .25382 Mtetra
.656 .746 .916 r
.32736 .25382 .33813 .2658 .35534 .25948 .34463 .24743 Mtetra
.34463 .24743 .35534 .25948 .37265 .2531 .36201 .24099 Mtetra
.656 .746 .917 r
.36201 .24099 .37265 .2531 .39008 .24667 .37951 .23451 Mtetra
.656 .747 .917 r
.37951 .23451 .39008 .24667 .40763 .24018 .39712 .22799 Mtetra
.655 .748 .918 r
.39712 .22799 .40763 .24018 .42528 .23363 .41485 .22143 Mtetra
.655 .749 .919 r
.41485 .22143 .42528 .23363 .44306 .22703 .43269 .21485 Mtetra
.655 .751 .92 r
.43269 .21485 .44306 .22703 .46095 .2204 .45066 .20824 Mtetra
.654 .753 .922 r
.45066 .20824 .46095 .2204 .47896 .2138 .46874 .2016 Mtetra
.654 .753 .923 r
.46874 .2016 .47896 .2138 .49709 .20718 .48695 .19492 Mtetra
.654 .754 .923 r
.48695 .19492 .49709 .20718 .51533 .20054 .50528 .18819 Mtetra
.655 .754 .923 r
.50528 .18819 .51533 .20054 .53371 .19388 .52373 .18139 Mtetra
.658 .754 .921 r
.52373 .18139 .53371 .19388 .5522 .18716 .54231 .17443 Mtetra
.658 .751 .919 r
.54231 .17443 .5522 .18716 .57082 .18031 .56101 .1674 Mtetra
.657 .749 .918 r
.56101 .1674 .57082 .18031 .58957 .17331 .57984 .16037 Mtetra
.655 .749 .919 r
.57984 .16037 .58957 .17331 .60844 .16628 .59879 .15336 Mtetra
.654 .751 .921 r
.59879 .15336 .60844 .16628 .62744 .1593 .61788 .14635 Mtetra
.654 .752 .922 r
.61788 .14635 .62744 .1593 .64657 .15232 .63711 .13933 Mtetra
.655 .753 .922 r
.63711 .13933 .64657 .15232 .66583 .14534 .65646 .13219 Mtetra
.658 .753 .92 r
.65646 .13219 .66583 .14534 .68523 .13826 .67594 .12489 Mtetra
.657 .75 .919 r
.67594 .12489 .68523 .13826 .70476 .131 .69556 .11755 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
[(-2)] .12586 .2075 1 .99877 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.56863 .04703 m
.57247 .05235 L
s
[(2)] .56094 .0364 .72324 1 Mshowa
.125 Mabswid
.18558 .19702 m
.18832 .19985 L
s
.23703 .17687 m
.23971 .17975 L
s
.28951 .15632 m
.29214 .15925 L
s
.39772 .11395 m
.40023 .11699 L
s
.4535 .09211 m
.45595 .0952 L
s
.51046 .06981 m
.51284 .07294 L
s
.08568 .23614 m
.08851 .23887 L
s
.62804 .02377 m
.63027 .02701 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 233.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00o?ooool2o`0006[ooooo003iooooo`?o000000?oooooo`000?ooool0
JOooool00?Oooooo0_l00004ooooo`;o0000JOooool00?Cooooo0ol00006ooooo`03o`000?oooooo
000006Sooooo003;ooooo`Go00008_ooool2o`0000Wooooo00?o0000ooooool00000J?ooool00<_o
oooo00GoV9RHob4Q8Oo^k^koooooodA4A00Oooooo`?o00002oooool01?l0003oooooooooool0001W
ooooo`00c?ooool00onHV9So8B4Qonk^kP0Mooooo`?o00003_ooool01Ol0003ooooooooooooooooo
000006Kooooo003=ooooo`03oiRHV?lQ8B7ok^k^01[ooooo0_l0000Aooooo`05o`000?oooooooooo
ooooool00000I_ooool00<kooooo00?oMgMgofIVI_ooool05_ooool3o`0001?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1Sooooo`00coooool00ol0003oooooooooo`0Cooooo`;o
00000_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0H_ooool00<_ooooo00Go0000okZj^_ooooooV9RHoa0@400Booooo`?o00006Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo06;ooooo003;ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`04?ooool2o`0001cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Qooooo`00
gOooool3o`0001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Qooooo`00fooo
ool2o`00027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Pooooo`00f?ooool3
o`0002?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Oooooo`00eOooool3o`00
02Kooooo00?o0000ooooooooool01?ooool2o`00067ooooo003Cooooo`;o0000:Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo05kooooo003@ooooo`?o000000?oooooo`000?ooool0
:?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05gooooo003>ooooo`;o00001Ooo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0GOoo
ool00<_ooooo0ol0000`ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0G?ooool0
0<Wooooo0_l0000cooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Foooool00<Ko
oooo0ol0000eooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Foooool00<Cooooo
0_l0000hooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0F_ooool00<7ooooo0ol0
000jooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03_ooool5o`0004Kooooo002n
ooooo`?o0000?Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00kooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A016ooooo`00_?ooool2o`0000?ooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo1_l00003ooooo`03oiRHV?lQ8B7o
k^k^04Oooooo002iooooo`?o0000@oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00kooooo00?oV9RHob4Q8Oo^k^h0A_ooool00;Oooooo0_l00016ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03oooool00omgMgOoIVIVooooo`15ooooo`00]?ooool3o`0004Sooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Cooooo
002booooo`;o0000Boooool00ol0003oooooooooo`0=ooooo`;o00003?ooool01Ol0003o^[Zjoooo
oonHV9So410@04Kooooo002_ooooo`?o0000COooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c016ooooo`00[Oooool2o`00053ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`1Dooooo`00Z_ooool4o`00057ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1Dooooo`00Z?ooool2o`0000Cooooo00?o0000oooo
ooooool0C_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05?ooooo001nooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h08_ooool3o`0005Oooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`1Booooo`00O_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01oooooo0ol0001Joooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool0D_ooool007kooooo00Go410@oooooooo
oooooooooa0@400Mooooo`;o0000GOooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
057ooooo001nooooo`05o`000?ooooooooooooooool000006_ooool3o`0005oooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`1@ooooo`00O_ooool01Ol0003ooooooooooooooooo0000
01Sooooo0_l0001Rooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0D?ooool007ko
oooo00Go410@oooooooooooooooooa0@400Eooooo`?o0000I?ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo04oooooo001nooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool2o`00
00?ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
04kooooo001nooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04?ooool3o`0006Sooooo00?oZ;o[o`00
0?ooool05_ooool00ol0003oooooooooo`1>ooooo`00TOooool2o`0006Sooooo1?nX_n/00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo04gooooo002>ooooo`?o0000J?ooool7ojRoj`03o`00
0?oooooooooo01Cooooo0ol0001>ooooo`00Roooool3o`0006Wooooo0_nX`>/7ojRoj`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool0C?ooool008Wooooo0_l0001Yooooo`KoZ<3[1_nX_n/0
0ol0003oZ;o[ooooo`0Gooooo`03o`000?oooooooooo04_ooooo0026ooooo`?o0000J?ooool00onW
`>coZ<3[ojS0j`07ojS0j`GoZ;o[00?o0000ojS0joooool06?ooool00ol0003oooooooooo`1:oooo
o`00Q?ooool2o`0000;ooooo00?o0000ooooooooool0Hoooool5ojO0k0WoZ<3[0_nX_n/2ojS0j`03
o`000?nX`>_oZ<3[01Sooooo00?o0000ooooooooool0B_ooool0087ooooo0ol00005ooooo`03o`00
0?oooooooooo063ooooo2?nW`>`7ojS0j`03ojO0k?nX`>_oZ<3[00;oZ<3[00Co0000ojS0jonX`>_o
Z<3[6?ooool00ol0003oooooooooo`19ooooo`00Ooooool2o`0006Wooooo2_nW`>`4ojS0j`GoYl3/
0onX`>/00ol0003oZ<3[ojS0j`02ojS0jaSooooo00?o0000ooooooooool0B?ooool007cooooo0ol0
001Xooooo`koYl3/00?oZ<3[ojO0k?nW`>`01_nW`>`2ojS0j`05o`000?nX`>_oZ<3[ojS0jonW`>`0
6?ooool00ol0003oooooooooo`18ooooo`00N_ooool2o`0006Oooooo0_nW`>/IojO0k0;oZ<3[00?o
0000ojS0jonW`>`00onW`>`Hooooo`03o`000?oooooooooo04Oooooo001gooooo`?o0000I_ooool6
ojO0jaWoYl3/00?oZ<3[o`000?nW`>`01OnW`>`Hooooo`03o`000?oooooooooo04Kooooo001doooo
o`?o0000I_ooool00onW_n_oYl3[ojO0j`07ojO0j`KoYl3/0_nW`>/AojO0k003o`000?nW`>coYl3/
00CoYl3/6?ooool00ol0003oooooooooo`16ooooo`00L_ooool2o`0000;ooooo00?o0000oooooooo
ool0H_ooool4ojNoj`WoYl3[0_nW`>`6ojO0ja3oYl3/00?o0000ojO0k?nW`>`01OnW`>`Hooooo`03
o`000?oooooooooo04Gooooo001_ooooo`?o0000Ioooool7ojNoj`OoYl3[00?oYko[ojO0jonW`>/0
1onW`>/6ojO0k003ojO0jonW`>coYl3/00KoYl3/00?o0000ojO0k?nW`>`01OnW`>`Hooooo`03o`00
0?oooooooooo04Gooooo001]ooooo`;o0000Ioooool2ojRoj`SoYko[1?nW`>/5ojNoj`WoYl3[0_nW
`>`5ojO0j`OoYl3/00?o0000ojO0k?nW`>`01_nW`>`Gooooo`;o0000A_ooool006[ooooo0ol0001V
ooooo`KoZ;o[2?nW_n/00onW`>_oYko[ojNoj`06ojNoj`OoYl3[00?oYko[ojO0jonW`>/01_nW`>/6
ojO0k003o`000?nW`>_oYl3/00OoYl3/6?ooool00ol0003oooooooooo`13ooooo`00J?ooool2o`00
06Kooooo0_nX`>/8ojRoj`KoYko[0_nX_n/8ojNoj`CoYl3[1OnW_n/8ojO0j`;oYl3/0onW`>/00ol0
003oYl3[ojO0j`08ojO0k1Oooooo00?o0000ooooooooool0@oooool006Gooooo0ol0001Uooooo`Ko
Z<3[2?nX_n/2ojNoj`KoZ;o[2?nW_n/00onW`>_oYko[ojNoj`06ojNoj`KoYl3[00?oYko[ojO0jonW
`>/00onW`>/01?l0003oYl3[ojO0jonW`>/6ojO0k003ojO0jooooooooooo01Kooooo00?o0000oooo
ooooool0@_ooool006?ooooo0_l0001Uooooo`03ojS1jonX`>_oZ<3[00OoZ<3[1_nX_n/00onX`>_o
Z;o[ojRoj`07ojRoj`KoYko[00?oZ<3[ojNojonW_n/01onW_n/4ojO0j`CoYko[1OnW`>/01?l0003o
Yl3[ojO0jonW`>/2ojO0k0GoYl3[6?ooool00ol0003oooooooooo`11ooooo`00H?ooool3o`000003
ooooool0003ooooo06;ooooo1?nX`N/9ojS0j`;oZ;o[1OnX`>/9ojRoj`;oYko[1OnX`>/9ojNoj`03
ojO0jonW_n_oYko[00GoYko[1?nW`>/01?l0003oYl3[ojO0jonW_n/8ojO0jaOooooo00?o0000oooo
ooooool0@Oooool003Kooooo1Ol0000Sooooo`;o0000I_ooool7ojS1j`OoZ<3[00?oYl7/ojS0jonX
`>/01_nX`>/6ojRoj`;oZ<7[2?nX`>/6ojNoj`;oZ<3[2?nW_n/4ojO0j`03o`000?nW_n_oYko[00;o
Yko[2?nW`>/Gooooo`03o`000?oooooooooo043ooooo000fooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@08?ooool3o`0006Gooooo0_nW`N`8ojS1j`CoZ<3[1OnW`N`8ojS0j`;oZ;o[1_nX`N/8ojS0j`;o
Yko[1_nX`>/8ojNoj`04ojO0jonW_n_oYko[o`0000GoYko[1_nW`>/00onW_n_oooooooooo`0Foooo
o`03o`000?oooooooooo03oooooo000^ooooo`Ko00000oooool00onHV9So8B4Qonk^kP0Nooooo`?o
0000IOooool6ojO1k0SoZ<7[00?oZ<3[ojO1k?nW`N`01_nW`N`6ojS0j`03ojO1k?nX`N_oZ<7[00Oo
Z<7[1_nX`>/00onX`N_oZ<3[ojS0j`07ojS0j`KoYko[00GoZ<3[ojNojonW_n_oYko[o`000005ojNo
j`CoYl3[1?nW_n/Gooooo`03o`000?oooooooooo03oooooo000hooooo`03oiRHV?lQ8B7ok^k^01_o
oooo0_l0001Uooooo`[oYl7/1_nX`N/:ojO1k0CoZ<3[1?nW`N`9ojS1j`;oZ<3[1OnX`N/9ojS0j`;o
Yko[1OnX`>/2ojNoj`03o`000?nW_n_oYko[00CoYko[00?oYl3[ojNojonW_n/01OnW_n/Gooooo`03
o`000?oooooooooo03kooooo000iooooo`03ogMgMomVIVKooooo01Oooooo0ol0001Tooooo`koYl7/
0_nX`N/>ojO1k003ojS0jonW`NcoYl7/00GoYl7/1onX`N/00onW`>coZ<7[ojS1j`06ojS1j`KoZ<3[
0_nX`N/8ojS0j`03ojNojol0003oYko[00?oYko[0_nX`>/8ojNojaSooooo00?o0000ooooooooool0
?Oooool003[ooooo00?o0000ooooooooool05?ooool2o`0006Cooooo00?oYl3/ojO1k?nW`N`03OnW
`N`00onW`>coYl7/ojO1k00=ojO1k003ojO0k?nW`NcoYl7/00OoYl7/1?nX`N/4ojO0k0SoZ<7[0_nX
`>/6ojS1j`SoZ<3[00?o0000ojNojonX`>/01OnX`>/8ojNojaOooooo00?o0000ooooooooool0?Ooo
ool003Kooooo00Go0000okZj^_ooooooV9RHoa0@400Cooooo`?o00000_ooool00ol0003ooooooooo
o`1Oooooo`CoYl3/2onW`N`5ojO0k0_oYl7/1OnW`>`9ojO1k003ojS1jonW`>coYl3/00GoYl3/1_nX
`N/00onW`>coZ<7[ojS1j`07ojS1j`KoZ<3[00?oZ<7[o`000?nX`>/01onX`>/6ojNoj`03ojRojooo
oooooooo01Kooooo00?o0000ooooooooool0??ooool003Kooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00Aooooo`;o0000IOooool7ojO0k0OoYl7/00?oYl3[ojO0k?nW`>`01_nW`>`6ojO1k0[oYl3/1_nW
`N`:ojO0k0CoZ<7[1?nW`>`9ojS1j`;oZ<3[1?nX`N/00ol0003oZ<3[ojS0j`07ojS0j`;oYko[1OnX
_n/Fooooo`?o0000?Oooool004Wooooo0ol0001Uooooo`[oYl3/1?nW`N`4ojO0j`SoYl3/0_nW`N`>
ojO0k0;oYl7/3_nW`>`00onX`N_oYl3/ojO0k005ojO0k0OoZ<7[00?oYl3/ojS1jonX`N/01?nX`N/0
0ol0003oZ<7[ojS0j`05ojS0j`;oZ<7[2?nX_n/Gooooo`03o`000?oooooooooo03_ooooo0017oooo
o`;o0000IOooool>ojO0k003ojO1k?nW`>_oYl3[00GoYl3[1_nW`>`2ojNoj`koYl3/00?oYko[ojO0
k?nW`>`05_nW`>`4ojS1j`GoYl3/1OnX`N/00ol0003oZ<7[ojS1j`02ojS0j`KoZ<7[2?nX_n/Goooo
o`03o`000?oooooooooo03[ooooo0014ooooo`?o0000I?ooool00onW`>_oYl3/ojO0k00<ojO0k0;o
Yko[2?nW`>/4ojO0k0GoYko[2_nW`>`5ojNojaSoYl3/00?oZ<7[ojO0k?nW`>`01_nW`>`4ojS1j`03
o`000?nX`N_oYl3/00WoZ<7[1_nX_n/00onX`>_oooooooooo`0Fooooo`03o`000?oooooooooo03Wo
oooo0011ooooo`?o0000I?ooool5ojO0j`[oYl3/1_nW_n/8ojO0j`03ojO0k?nW_n_oYko[00KoYko[
1_nW`>`00onW_n[oYko[ojNoj`06ojNoj`KoYl3/0_nW_n/IojO0k0;oZ<7[00?oYl3/o`000?nW`>`0
0_nW`>`9ojS1j`;oZ;o[1OnX`>/Gooooo`03o`000?oooooooooo03Wooooo000oooooo`?o0000Hooo
ool00onW_n_oYl3[ojO0j`06ojO0j`KoYl3/0_nW_nX8ojNoj`KoYl3[0_nW_^X9ojNoj`;oYl3/1OnW
_nX8ojNoj`;oYl3/1_nW_n/KojO0k003o`000?nW`>coYl3/00;oYl3/1_nX`N/2ojO0k0SoZ<3[5ooo
ool00ol0003oooooooooo`0hooooo`00??ooool3o`0000?ooooo00?o0000ooooooooool0GOooool5
ojNoj`SoYl3[0_nW`>`6ojNojPSoYko[0_nW`>/6ojNnjPOoYko[00?oZ;oZojNoj_nW_nX01_nW_nX6
ojNoj`;oZ;oZ2?nW_n/6ojO0k003ojNojonW`>coYl3/017oYl3/00?o0000ojO0k?nW`>`00onW`>`2
ojS1j`KoYl3/2?nX`>/Fooooo`03o`000?oooooooooo00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0/ooooo`00>_ooool2o`0006?ooooo2OnW_n/6ojO0j`;oZ;kZ2?nW_nX6ojNoj`03ojRoj_nW_^[o
YkkZ00OoYkkZ1?nW_n/4ojRojPSoYkoZ0_nW_n/6ojRojPSoYko[0_nW`>`5ojNoja;oYl3/00?o0000
ojO0k?nW`>`03?nW`>`7ojS0jaOooooo00?o0000ooooooooool01_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg02cooooo000gooooo`?o0000Hoooool<ojNoj`;oYl3[1_nX_^X8ojNojP;oYko[1OnX_nX9
ojNnjP03ojNojonX_n[oZ;oZ00GoZ;oZ1_nW_nX:ojRojPKoYko[00?oZ;oZojNojonW_n/01_nW_n/6
ojO0k0;oYko[2_nW`>`00ol0003oYl3/ojO0k00<ojO0k0OoZ<3[5oooool00ol0003oooooooooo`05
ooooo`05oa0@4?ooooooooooooooool@4100;?ooool003Gooooo0_l0001Tooooo`goYko[00?oZ;oZ
ojRnj_nX_^X01onX_^X6ojNojP03ojS0jonX_n[oZ;oZ00KoZ;oZ1_nW_^X2ojS0j`SoZ;oZ1?nW_nX=
ojRojP;oYko[1OnX_nX8ojNoj`;oYl3/1_nW_n/9ojO0k003o`000?nW`>coYl3/00coYl3/2?nX`>/F
ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`00000/ooooo`00<_ooool3
o`0006Cooooo00?oYkoZojNojonW_n/02_nW_n/4ojRojPWoZ;kZ0_nW_nX5ojS0j`SoZ;oZ0_nW_^X6
ojS0j`SoZ;oZ00?oYkoZojRoj_nX_nX03?nX_nX00onX`>_oZ;oZojRojP06ojRojPKoYko[00?oZ;oZ
ojNojonW_n/01onW_n/6ojO0k003ojNojonW`>co000000ooYl3/2?nX`>/Fooooo`03o`000?oooooo
oooo00Cooooo00Go0000ooooooooooooooooo`00000/ooooo`00<?ooool2o`0006Cooooo1OnW_nX9
ojNoj`OoZ;oZ1onX_^X9ojS0j`KoZ;oZ0_nX`N/8ojS0j`KoZ;oZ00?oZ<7[ojRoj_nX_nX02_nX_nX5
ojS0j`SoZ;oZ0_nW_n/5ojRojPWoYko[0_nW`>`5ojNoj`03o`000?nW`>coYl3/00CoYl3/00?oYl3[
ojO0k?nW`>`01_nW`>`6ojS0j`;oYl3/5oooool00ol0003oooooooooo`03ooooo`05oa0@4?oooooo
ooooooooool@4100;?ooool002gooooo0ol000000ooooooo0000ooooo`1Pooooo`03ojNnj_nW_n[o
YkoZ00KoYkoZ1_nW_n/2ojRoj`SoZ;oZ1?nX_^X<ojS0j`;oZ;oZ1_nX`N/8ojS0j`;oZ;oZ1OnX`N/9
ojRojPSoZ<3[1_nX_nX00onX`>_oZ;oZojRojP06ojRojPKoYko[0_nX_nX7ojNoj`03o`000?nW`>co
Yl3/00;oYl3/1?nW`>/8ojO0k0;oZ<3[1_nW`>`Fooooo`;o00001?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg02cooooo000Zooooo`?o0000Hoooool5ojNnjPSoYkoZ0_nW_n/6ojRoj`SoZ;oZ00?oZ;kZ
ojS0jonX`>/02onX`>/2ojO1k0SoZ<7[1_nX`>/00onW`NcoZ<7[ojS1j`06ojS1j`KoZ;oZ0_nX`N`9
ojS0j`;oZ;oZ1OnX`>/8ojRojP;oYko[1_nX_nX6ojNoj`03o`000?nW_n_oYl3/00OoYl3[1_nW`>`0
0onV`>coYl3/ojO0k007ojO0k1?ooooo0_l000000ooooooo0000ooooo`03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h0;?ooool002Sooooo0_l0001Sooooo`WoYkkZ1_nW_nX:ojRoj`KoZ;oZ00?oZ<7/
ojS0jonX`>/02OnX`>/6ojO1k0SoZ<7[0_nX`>/5ojO1k0SoZ<7[0_nX_nX6ojS1k0OoZ<3[00?oYl7/
ojS0jonX`>/01_nX`>/6ojRojP03ojW0jonX_n[oZ;oZ00OoZ;oZ1OnW_n/00ol0003oYko[ojO0j`08
ojO0j`;oYl3/1OnV`>`9ojO0k1Kooooo00?o0000ooooooooool0<_ooool002Gooooo0ol0001Roooo
o`goYkkZ0_nW_nX>ojRoj`;oZ;oZ1OnX`N`7ojS0j`[oYl7/1_nX`N/9ojO1k0KoZ<7[00?oYl7/ojS1
k?nX`N`01onX`N`4ojS0j`CoYl7/2?nX`>/2ojRojPGoZL3[2OnX_nX3ojNoj`;o00000_nW_n/7ojO0
j`03ojNojonV`>coY/3/00KoY/3/1_nW`>`2ojK0k1Kooooo00?o0000ooooooooool0<_ooool002?o
oooo0_l0001Rooooo`ooYkkZ0_nW`>/>ojRoj`03ojO1k?nX`NcoZ<7/00KoZ<7/1?nX`>/=ojO1k0;o
Z<7[3OnW`N`2ojS1j`GoYl7/2OnX`N`00onX`>_oYl7/ojO1k005ojO1k0KoZ<3[00?oYl7/ojW0jonY
`>/01_nY`>/6ojRojP;oZL3[0ol000000onW_n_o0000ojNoj`02ojNoj`CoYl3[1?nW_n/8ojK0k0;o
Yl3/1_nV`>`Fooooo`03o`000?oooooooooo037ooooo000Pooooo`?o0000HOooool?ojNnjPKoYl3[
2_nX_n/5ojO1k0SoZ<7/00?oZ<3[ojO1k?nW`N`09?nW`N`6ojS1k0_oYl7/0_nX`>/5ojO1k0SoZL3[
0_nX_nX2ojW0j`?o000000?oZL3[ojNojonW_n/00_nW_n/01Ol0003oYko[ojNojonW_n_oYl3[00Oo
Yko[1_nV`>`00onW_n_oY/3/ojK0k006ojK0k1Oooooo00?o0000ooooooooool0<?ooool001oooooo
0_l0001Pooooo`ooYkkZ2_nW`>/6ojRoj`WoYl7/1_nX`N`YojO1k0;oZ<7/5_nW`N`6ojW0j`03ojS1
k?nY`>_o000000;o00001?nY`>/5ojNoj`03o`000?nY`>[oZL3Z00WoYko[0_nV`>`5ojNoj`SoY/3/
5_ooool00ol0003oooooooooo`0`ooooo`007oooool00ol0003oooooo`00001Mooooo`koYkkZ3_nW
`>/2ojRoj`goYl7/0_nX`N`=ojO1k003ojO0k?nW`NcoYl7/00coYl7/00?oY/3/ojO1k?nW`N`03?nW
`N`2ojK0k1SoYl7/0_nY`>/2ojS1k0?o00002?nY`>/2ojNoj`?oZL3Z00?o0000ojW0j_nY`>X01onW
_n/00onX_n[oYko[ojNoj`06ojNoj`OoY/3/5oooool00ol0003oooooooooo`0_ooooo`003?ooool5
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`04o`000?ooooooooooo`0005[ooooo
3OnW_^X@ojO0jacoYl7/1OnW`>`:ojO1k0GoY/3/2_nW`N`6ojK0k1KoYl7/00?oY/7/ojS1k?l00000
0_l00004ojS1k0KoZL3[00?oZ<7[ojW0j_nY`>X00onY`>X01?l0003oZL3ZojW0j_nY`>X4ojNoj`Co
Z;oZ2?nW_n/7ojK0k1Oooooo00?o0000ooooooooool0;_ooool000cooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool2o`0000;ooooo00?o0000oooo
ooooool0EOooool2ojNojP_oYkkZ3onW`>/LojO1k003ojNojonW`>coYl3/00KoYl3/1_nW`N`00onW
_^_oY/3/ojK0k006ojK0k0KoYl7/00?oYko[ojK0k?nV`>`01onV`>`6ojO1k0;oY/3/2_nW`N`2ojK1
k0?o00002?nX`N`2ojW0j`GoZ<7[1OnY`>X01Ol0003oZL3ZojW0j_nY`>[oYko[00OoZ;oZ1onW_n/8
ojK0k1Kooooo00?o0000ooooooooool0;_ooool000Cooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^
00Cooooo00Go410@oooooooooooooooooa0@4005ooooo`;o00001?ooool00ol0003oooooooooo`1A
ooooo`KoYkoZ2OnW_^X=ojO0jagoYl7/1?nW_n/8ojO0k0;oYl7/1OnW_^/8ojK0k0;oYl7/1OnW_n/9
ojK0k0;oYl7/1_nV`>`6ojO1k003ojK0k?nV`Nco000000;o00001?nV`N`6ojS1k003ojO1k?nX`N_o
Z<7[00KoZ<7[1OnY`>X00ol0003oZL7[ojW1j`09ojRojPOoYko[2?nV`>`Fooooo`03o`000?oooooo
oooo02gooooo000>ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000005
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0COooool2ojNoj`SoYkoZ1_nW_^X<
ojO0jakoYl7/1onW_n/6ojO0k003ojNnjOnW_^_oYkk[00KoYkk[1_nV`>`00onW_^WoYko[ojNoj`06
ojNoj`KoY/3/0onW_^X8ojK0k0;oYl7/0onV`>`2o`0000SoY/7/0_nX`N`5ojO1k0SoZ<7[0_nY`>X2
ojW1j`04o`000?nY`N_oZL7[ojW1j`OoZ;oZ00?oZL3ZojNojonW_n/01_nW_n/6ojK0k003ojNojooo
oooooooo01Gooooo00?o0000ooooooooool0;?ooool000oooooo00?oMgMgofIVI_ooool00_ooool0
1Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`19ooooo`KoYko[2?nW_nX2ojNnjPcoYl3[7onW`N`00onW_^[oYko[ojNoj`07ojNoj`;oYl3/1OnW
_^T8ojNnj`;oY/3/1OnW_^T8ojNoj`;oY/3/1onW_^X6ojK0k003ojNnj_nV`>coY/3/00?o00000onV
`>`6ojK1k003ojK0k?nW`NcoYl7/00KoYl7/1_nX`N/00onW`>coZL7[ojW1j`03ojW1j`03o`000?nY
`N_oZL7[00CoZ;oZ1OnY`>X8ojNoj`;oY/3/1OnW_n/Eooooo`;o0000;_ooool0013ooooo00Go0000
oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00?ooooo0_l00007ooooo`03o`000?oo
oooooooo04Kooooo2OnW_n/6ojNojP03ojNojonW`>_oYl3[00WoYl3[7onW`N`5ojNnjPOoYko[00?o
Z;kYojNnjOnW_^T01_nW_^T6ojNnj`03ojRojOnW_^WoYkkY00KoYkkY1_nW_n/2ojRnj@WoYkkZ0_nV
`>`3ojNnjP?o00001onV`>`2ojK1k0GoY/3/2?nW`N`2ojS1j`GoYl3/1OnY`N/01?l0003oZL7[ojW1
jonX_nX8ojW0jPKoYko[00?oZ;o[ojNojonW_n/01_nW_n/Fooooo`03o`000?oooooooooo02_ooooo
000<ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`12ooooo`goYko[0_nW_nX5ojNoj`Oo
Yl3[7onW`N`9ojNnjPCoYko[1?nX_^T8ojNnj@;oYkk[1OnX_nT8ojNnj@;oYko[1_nX_^T7ojNnjP03
ojVojOnW_^[oYkkZ00?o00000onW_^X6ojK0k003ojNnj_nV`>coY/3/00KoY/3/1_nW`N`00onV`>co
Yl3/ojO0k006ojO0k0GoZL7[00?o0000ojS1jonY`>X02OnY`>X2ojNoj`GoZ;o[2?nW_n/Eooooo`03
o`000?oooooooooo02_ooooo000<ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0noooo
o`;oYl3[5_nW_n/4ojO0jakoYl7/3OnW_^X00onW_n_oZ;kYojRnj@05ojRnj@KoYkkY00?oZ<3[ojRo
jOnX_nT01_nX_nT6ojNnj@;oZL3Z2?nX_^T4ojNnjP;oZKoY0ol00007ojNnjP;oY/3/1OnW_^X8ojK0
k0;oYl7/1OnV`>`8ojO0k0;oZL7[0_nX`N/00ol0003oZ<7[ojS1j`08ojW0jP03ojW1jonX_n_oZ;o[
00GoZ;o[2?nW_n/Fooooo`03o`000?oooooooooo02[ooooo000Nooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0>_ooool6ojO0jaKoYko[00?oYl3[ojO1k?nW`N`06onW`N`00onW_^Wo
YkkZojNnjP0<ojNnjP03ojRoj_nX_^WoZ;kY00OoZ;kY0_nW_^T5ojS0j`SoZ;oY0_nW_^T6ojW0jPSo
Z;kY00?oYkkZojVojOl000000_l00003ojVoj@KoYkkZ00?oZKoYojNnj_nW_^X01_nW_^X6ojK0k003
ojJnjonV`>coY/3/00KoY/3/1_nW`>`00onV`>coZ<7[ojS1j`03ojS1j`03o`000?nX`N_oZ<7[00Co
ZL3Z1OnY`N/7ojRoj`SoYko[5_ooool00ol0003oooooooooo`0Yooooo`007Oooool3o`0000_ooooo
00?o0000ooooooooool0=_ooool2ojS0j`SoYl3[1OnW_n/2ojNnj`goYko[7?nW`N`5ojNnj@[oYkkZ
1OnX_nX7ojRnj@;oZ<7[1onX`>/6ojRoj@;oZ<7[2?nY`>X6ojRnj@?o00001onY_nT2ojNnjPGoZKoY
2?nW_^X2ojK0k0GoY[k[2?nV`>`2ojO0k0GoY/3/1OnX`N/01?l0003oZ<7[ojS1jonY`>X7ojW1j`Ko
Z;o[00?oZL3ZojNojonW_n/01_nW_n/Fooooo`03o`000?oooooooooo02Wooooo000Mooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool0<_ooool6ojS0j`SoYl3[00?oYko[ojNnjonW_^/0
1?nW_^/9ojNojacoYl7/2OnW_^T6ojNnjP03ojRojonX_n[oZ;oZ00KoZ;oZ1?nX_^T5ojS1j`OoZ<3[
0_nX_nT6ojS1j`SoZL3Z0_nX_^T3o`0000;oZL7[1onY_nT00onY`N_oZKoYojVoj@06ojVoj@KoYkkZ
00?oZKoYojJnjonV_^/01_nV_^/6ojK0k003ojJok?nV`>coY/3/00KoY/3/1OnX`N/00ol0003oYl3/
ojO0k008ojW1j`;oZ;o[1OnY`>X8ojNojaKooooo00?o0000ooooooooool0:?ooool001gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0_ooooo`03ojS1k?nX`>_oZ<3[00KoZ<3[1_nW
`>/00onW_^[oYkk[ojNnj`06ojNnj`KoYko[6onW`N`=ojNnj@;oYkkZ1OnX_n/8ojRojP03ojRnjOnX
`N_oZ<7[00KoZ<7[1OnX`>/2ojO1k0SoZ<7[1_nY`>X3o`0000KoZL7[1?nY_nT4ojW1j`SoZKoY0_nW
_^X5ojVoj@SoY[k[0_nV`>`5ojJok0SoY/3/0_nX`N/2ojO0k004o`000?nW`>coYl3/ojO0k0KoZL7[
00?oZ<3[ojW0j_nY`>X01_nY`>X7ojNojaOooooo00?o0000ooooooooool09oooool001gooooo0_l0
000?ooooo`03o`000?oooooooooo02_ooooo1OnX`N`8ojS0j`;oYl3[1OnW_^X8ojNnj`;oYko[3?nW
`N`2ojS1k0goYl7/0_nW_NT=ojNnj@;oZ<3[1onX_n/6ojRojP?oYl3/2?nX`N/00onX`>_oYl7/ojO1
k004ojO1k0SoZ<7[0_nY`>X00onW`>co0000o`000002ojO0k0SoZL7[00?oZKoYojW1jonY`N/01OnY
`N/6ojVoj@03ojW1jonY_nWoZKoY00KoZKoY1_nV_^/00onX_n[oY[o/ojJok006ojJok0SoY/3/1?nW
`>`01?l0003oYl3/ojO0k?nW`>`2ojW1j`GoZ<3[2?nY`>X7ojNojaKooooo00?o0000ooooooooool0
9oooool001gooooo00?o0000ooooooooool03oooool2o`0002Sooooo2OnX`N`6ojS0j`WoYkkZ1_nW
_^/<ojO1k0KoZ<7/2OnW`N`6ojNmj@WoYkkY1_nX`>/7ojRoj`;oZ;oZ1onW`>`6ojS1j`WoYl7/1_nX
`N/01?nW`Nco0000o`000?l00005ojO0k0KoZL7[0_nW`N`8ojW1j`;oZKoY1OnY`N/8ojVoj@;oY[k[
1OnX_nX8ojJok0SoY/3/1?nW`>`00ol0003oYl3/ojK0k008ojS0j`KoZL3Z00?oZL3[ojNojonW_n/0
1_nW_n/Fooooo`03o`000?oooooooooo02Kooooo000Mooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool08_ooool=ojS1k0;oZ<3[3OnW_^X2ojNnj`coYl7/2_nX`N`5ojO1k0[oYkgY1OnW
_^T:ojS0j`GoZ;o[0onW`N`8ojO0k0;oZ<7[3OnW`N`2ojS1j`05ojO1k?l0003o0000o`000?nW`N`0
2?nW`>`2ojW1j`KoYl7/1_nY`N/00onW`NcoZL7[ojW1j`06ojW1j`KoZKoY00?oZ/7[ojRoj_nX_nX0
1_nX_nX6ojJok0;oYko[2?nV`>`2ojO0k0;oY/3/00?o0000ojK0k?nV`>`02?nX`>/2ojW0jPGoZL3[
2?nW_n/Fooooo`03o`000?oooooooooo02Gooooo000Mooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool07_ooool?ojS1k0;oYko[3OnW_^X2ojO0j`_oYl7/3OnX`N`00onW`NcoYkgYojNm
j@0<ojNmj@03ojNnjOnX`>_oZ<3[00coZ<3[00?oZ;o[ojO1k?nW`N`01OnW`N`6ojO0k003ojNojonW
`NcoYl7/00coYl7/00CoYkgZo`000?l0003o00001OnW`N`6ojO0k0;oYko[2?nW`N`2ojW1j`GoYl7/
2?nY`N/2ojVoj@GoZ/7[2?nX_nX2ojJok0KoYko[1_nV`>`00onV_ncoY/3/ojK0k002ojK0k004o`00
0?nV`>coY/3/ojK0k0KoZ<3[00?oYl3/ojW0jonY`>/01_nY`>/6ojNoj`03ojS0jooooooooooo01Co
oooo0_l0000Vooooo`007?ooool3o`0001Cooooo00?o0000ooooooooool06oooool>ojS1k0KoYko[
2OnW_^X6ojO0j`WoYl7/3OnX`N`00onW_^[oYkgYojNmj@0<ojNmj@03ojO0jonX`>_oZ<3[00coZ<3[
2_nW`N`2ojO0k0GoYko[2_nW`N`01OnW_N[o0000o`000?l0003oYkgZ00SoYl7/0_nW`>`6ojNoj`Ko
Yl7/00?oYkk[ojO1k?nW`N`01_nW`N`6ojW1j`03ojO0k?nZ`N_oZ/7[00KoZ/7[1_nX_nX2oj[0jPSo
Yko[0_nV`>`5ojJok0CoY/3/00Co0000ojK0k?nV`>coY/3/0_nX`>/5ojO0k0SoZL3[0_nW_n/5ojS0
jaCooooo00?o0000ooooool000009_ooool001cooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`0Iooooo`goZ<7/0_nX`>/7ojNoj`KoYkkZ00?oYko[ojO0jonW`>/01_nW`>/6ojO1k0co
Z<7/1OnW_^X:ojNmj@GoYl3[2_nX`>/<ojO1k003ojNmjOnW_n_oYko[00KoYko[1_nW`N`01?nW]nGo
0000o`000?l00005ojNmjPKoYl7/0_nW^NH8ojNoj`;oYl7/1OnW_^/8ojO1k0;oZL7[1OnW`>`8oj[1
j`;oZ;oZ1_nZ`>X6ojNoj`03ojVoj_nV_ncoY[o/00KoY[o/1?nV`>`00ol0003oY/3/ojK0k008ojO0
k0KoZL3[00?oZL7[ojS0jonX`>/01_nX`>/Fooooo`03o`000?oooooooooo02?ooooo000:ooooo`Co
000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`0Fooooo`?oZ<3[2OnX`N`6ojS0j`OoYko[0_nW_^X5ojNoj`SoYl3[0_nW
`N`<ojS1k0WoYkkZ1_nW_NT00onW_n_oYl3[ojO0j`06ojO0j`KoZ<3[3?nW`N`5ojNmj@SoYko[0_nW
`N`01OnW]nGo0000o`000?l0003oYkOU00SoYkgZ0_nW`N`6ojNiiPKoYko[00?oZ;KTojNnjonW_^/0
1_nW_^/6ojO1k003ojJojonW`>coYl3/00KoYl3/1_nZ`N/00onX`>_oZ/3Zoj[0jP07oj[0jP;oYko[
1OnY_nX8ojJok0?oY/3/00Co0000ojK0k?nV`>coY/3/2?nW`>`2ojW0j`GoZL7[2?nX`>/Eooooo`03
o`000?oooooooooo02?ooooo000<ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`06ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool04_ooool7ojS0j`Go
Z<7/0_nX`N/8ojS0j`GoYko[0_nW_^/7ojNoj`KoYl3[3?nX`N`=ojNnjP;oYkgY1OnW_n/8ojO0j`;o
Z<3[3?nW`N`00onW^^OoYkgYojNmj@06ojNmj@KoYko[00CoYk7Oo`000?l0003o00001OnW]nD6ojNm
jP03ojR`g_nW^NKoYkWV00OoYkWV0_nW_n/5ojRfi0SoYkk[0_nW`N`5ojJoj`SoYl3/0_nZ`N/5ojS0
j`OoZ/3Z00?oZL7[ojVoj_nY_nX01_nY_nX6ojJok003ojNojonV`>coY/3/00;oY/3/00Co0000ojK0
k?nV`>coY/3/1onW`>`7ojW1j`SoZ<3[5_ooool00ol0003oooooooooo`0Rooooo`0000?oooooo`00
0?l000001?l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006
ooooo`;o00006Oooool00ol0003oooooooooo`0>ooooo`?oYko[2?nX`>/00onX`NcoZ<7[ojS1j`04
ojS1j`SoZ<3[00?oYko[ojNnjonW_^/01?nW_^/7ojNoj`;oYl3[3?nX`N`2ojRoj`goYkkZ2OnW_n/6
ojO0j`coYl7/1OnW^^L8ojNmj@;oYko[0_nW/Ml2o`000003ojNagonW]nGoYkOU00KoYkOU0_nW_NX5
ojR`gPOoYkWV00?o[:oKojRfi?nX]^@01_nX]^@6ojNnj`03ojRgi?nV_n_oY[o[00KoY[o[1onW`>`8
ojS0j`CoZ/3Z1?nY`N/8ojVojP;oY[o/1OnW_n/4ojK0k004o`000?nV`>coY/3/ojK0k0OoYl3/1onY
`N/8ojS0jaKooooo00?o0000ooooooooool08Oooool000cooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`0:ooooo`OoYko[1_nX`>/9ojS1j`KoZ<3[2OnW_^/5ojNoj`coZ<7/1_nX_n/9ojNnjPgoYko[0_nW
`>/<ojO1k0;oYkWV1onW^^L6ojNmj@03ojN]fonW/Moo000000;o00001?nW/Ml6ojNgi@03oj^]f?nX
/=koZ;3N00KoZ;3N1?nW^NH4ojb_f`SoZ;KT0_nW_^/5ojRgi0SoY[o[1onW`>`8ojS0j`03oj[0j_nY
`N_oZL7[00GoZL7[1_nY_nX00onZ`>[oYko[ojNoj`05ojNoj`GoY/3/00?o0000ojJok?nV_n`01onW
`>`6ojW1j`[oZ<3[5Oooool00ol0003oooooooooo`0Qooooo`003?ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo00Oooooo2_nW_n/2ojS0j`goZ<7[0_nX`>/=ojNnj`03ojNojonX`NcoZ<7/00_oZ<7/00?o
Z<7[ojRojonX_n/01_nX_n/7ojNnjPgoYko[3?nW`N`6ojNiiPOoYk[W0_nW_NT2ojN]f`?o00002?nW
/Ml2ojNgi@GoZjgH2?nX/=h00onW^NKo[:oKojb_f`05ojb_f`KoZ;KT00?o[k7JojRgi?nX]n@01_nX
]n@6ojJoj`03ojNji_nW`>coYl3/00KoYl3/1_nX`>/2ojO0k0SoZL7[0_nY_nX5oj[0jPOoYko[0_nV
`>`2ojJok004o`000?nV_ncoY[o/ojJok0OoYl3/0_nY`N/<ojS0j`03ojW0jooooooooooo01Cooooo
00?o0000ooooooooool08?ooool000cooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@00Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`03ooooo`coYko[
3onX`N/2ojNoj`goYkk[0_nW`N`:ojS1k0GoZ<7[2?nX_n/7ojNnjPWoYko[3?nW`N`:ojNiiPGoYk[W
00?oZ:_IojN]fol000000_l00004ojN]f`KoYk7O00?o[:WDoj^]f?n[[MP01_n[[MP6ojR`gP03ojn/
e?n/[m_o[:oK00Ko[:oK1?nX]^@4ojnafPSoZ;OT0_nV_n/5ojNjiPSoYl3/0_nX`>/6ojO0k0KoZL7[
00?oZ<3[oj[0j_nZ`>X01OnZ`>X6ojNoj`03ojRojonV_ncoY[o/00?oY[o/00?o0000ojJok?nV_n`0
1_nW`>`2ojK0k0[oZ<3[1OnY`>/Fooooo`03o`000?oooooooooo01oooooo000<ooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o00007_ooool00ol0003ooooo
ojNoj`0;ojNoj`ooZ<7[1_nW_n/9ojNnj`KoYl7/2?nX`N`7ojS1j`KoZ;o[00?oYkgZojNnj_nW_^X0
1_nW_^X6ojNoj`_oYl7/3_nW^NH00onW^^OoZ:_IojR[f@03o`0000OoYjgK1?nW/Ml4ojbYe0OoZjgH
1?nX/=h4ojn/e0So[:oK00?oZ;KTojnaf_n_/MX01On_/MX6ojRgi003ok2dg?nW^^KoYk[V00KoYk[V
1_nW`>`2ojNmjPSoYl3/0_nY`N/5ojS0j`OoZ/3Z0_nW_n/5ojRoj`GoY[o/00?o0000ojJok?nV_n`0
0_nW`>`6ojK0k0OoZ<3[2?nY`>/Eooooo`03o`000?oooooooooo01oooooo000:ooooo`03oeEEEOmV
IVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo01cooooo
3OnW_n/2ojO0j`coZ<7[0_nX`>/8ojNoj`GoYkk[0onW_n/7ojO1k0SoZ<7/1onX`N/2ojRoj`GoYkgZ
2?nW_^X2ojNoj`coYl7/00?oYk_WojNii_nW^NH03?nW^NH01?nWZMWo0000o`000?l00004ojR[f@Oo
YjgK00?oYk7OojbYe?n/ZM@01?n/ZM@8oj^]f003ojR`g_n_[=Co[jcD00Go[jcD1_n/[m/00onc[]?o
[k7JojnafP06ojnafPCoZ;OT1?n`]=`8ojNjiP;oYl3/1_nW_NX6ojO0k003ojJok?nX`>_oZ<3[00Go
Z<3[1_nZ`>X00onZ`N_oZ;o[ojRoj`06ojRoj`GoY[o/00?o0000ojJok?nV_n`02?nV`>`7ojS0j`So
ZL3[5Oooool00ol0003oooooooooo`0Nooooo`006oooool00ol0003oooooooooo`0Jooooo`?oYl3[
2OnW_n/6ojO0j`SoZ<7[1_nX`>/8ojNoj`03ojNnjonW_n_oYko[00GoYko[1OnW`N`:ojS1k0GoZ<7[
0_nV_NX7ojNmjPKoYkkZ3?nW`N`5ojNki`_oYkWV0ol000000onWZMWoZ:_IojR[f@05ojR[f@GoYjgK
00?oZZKBojbYe?n/ZM@01_n/ZM@6oj^]f003ojnYdOn_[=Co[jcD00Ko[jcD1?n/[m/4ok>^d`So[k7J
00?oZ;OTok2dg?n`]=`01On`]=`6ojNjiP;o[[KO2?nW_NX2ojO0k0GoY[o/1onX`>/2oj[0jPGoZ/7[
2?nX_n/4ojJok004o`000?nV_ncoY[o/ojJok0KoY/3/00?oY[o/ojS0jonX`>/01_nX`>/6ojW0j`03
ojW1jooooooooooo01Cooooo00?o0000ooooooooool07Oooool001_ooooo00?o0000ooooooooool0
5oooool7ojO0j`OoYko[2?nW`>/7ojS1j`OoZ<3[1_nW_n/2ojJnj`SoYko[00?oYl7/ojS1k?nX`N`0
3?nX`N`00onX`N_oY[gZojJmjP04ojJmjPOoYkgZ0_nW_^X<ojO1k003ojNmjOnW^nOoYk_W00KoYk_W
1onW^NH3o`0000CoYjWI2?nXZmT00onW[M_oZZKBojZVdP03ojZVdPOo[:WD1?n[[MP4ojnYd@So[jcD
00?o[:oKok>^donc[]<01Onc[]<6ojnafP03okF`e?n`]=co/;CL00Oo/;CL0_nW^^H6ojjfg`KoYkgZ
00?oZK[UojJok?nV_n`01OnV_n`6ojS0j`03ojO0jonZ`N_oZ/7[00KoZ/7[1_nX_n/2ojW0jPCoY[o/
00Co0000ojJok?nV_ncoY[o/0_nV`>`5ojJok0SoZ<3[0_nY`>/5ojW1jaCooooo0_l0000Oooooo`00
6oooool2o`0001Cooooo1OnX`>/7ojO0j`OoYko[2?nW`>/7ojS1j`OoZ<3[0_nW_n/6ojJnj`KoYko[
3onX`N`00onW_n[oY[gZojJmjP06ojJmjPGoYkgZ3?nW`N`5ojNmj@OoYk_W1OnW^NH2o`0000SoYjWI
1_nXZmT00onXY=;oZZKBojZVdP05ojZVdPOo[:WD00?oZjgHojnYdOn_ZM401On_ZM46ojn/e003okF^
d_nc[]?o/jkC00Ko/jkC1?n_/MX4okF`e0Oo/;CL00?o]kCFojjfgon^]]l01on^]]l2ojNmjPGoZK[U
1onV_n`2ojS0j`GoYl3[2?nZ`N/2ojRoj`KoZL3Z1?nV_n`00ol0003oY[o/ojJok008ojJok0OoZ<3[
1onY`N/Fooooo`03o`000?oooooooooo01cooooo000Jooooo`03o`000?oooooooooo013ooooo0_nX
`N/8ojS0j`GoYl3[2OnW_n/6ojO0j`WoZ<7[1OnX`>/3ojNnj`OoY[k[0_nW_n/?ojS1k0GoYkoZ2?nV
_NX00onW_N[oYl7/ojO1k00:ojO1k0;oZ;o[1onW_NT7ojNki`04ojNii_l0003o0000o`0000?oYJWI
1onWZMT4ojR[f@CoZ:CB1_nZY]86ojbYe003ok2[d_n_ZM7o[jWA00Ko[jWA1?n_[=@4okF^dPSo/jkC
00?o[k7JokF`e?ne/=@01One/=@4ok2dg0Co]kCF1on^]]l00onf^M_oZK[UojVji@05ojVji@KoY[o/
00?oY[k[ojO0jonW`>/01_nW`>/6oj[1j`;oZL7[2?nY`>X4ojJok003o`000?nV_ncoY[o/00SoY[o/
1onX`>/7ojW1jaGooooo00?o0000ooooooooool07?ooool001[ooooo00?o0000ooooooooool03Ooo
ool6ojS1j`SoZ<3[00?oYl3[ojNojonW_n/02onW_n/2ojO0j`goZ<7[00?oZ<3[ojNnjonW_^/01OnW
_^/5ojJnj`;oZ<3[3OnX`N`2ojS0j`OoYkoZ1_nV_NX2ojNoj`WoYl7/1_nX_n/7ojNmj@?oYk_W00Co
Y:WJo`000?l0003o00001onUZMT7ojNYf@03ojR[fOnXY=;oZ:CB00CoZ:CB1onZY]83ojbYe0Co/:_B
2?n_ZM400on_[=Co]JkBokF^dP05okF^dPKo/jkC00?o^K?CokF`e?ne/=@01one/=@00on`]=co]kCF
okNdeP05okNdePCo[[KO1?nf^M/7ojVji@;oY[o/1OnV_^/8ojO0j`;oZ/7[1_nY`N/6ojW0jP03oj[1
j_nV_ncoY[o/00;oY[o/00?o0000ojJok?nV_n`02?nV_n`7ojS0j`SoZL7[5Oooool00ol0003ooooo
ooooo`0Kooooo`006_ooool00ol0003oooooooooo`0;ooooo`;oZ<3[1onX`N/6ojS0j`03ojO0jonW
_n_oYko[00_oYko[3OnX`N/5ojO0j`OoYkk[00?oY[k[ojS0jonX`>/01?nX`>/9ojS1k0KoZ<3[1onW
_nX2ojJmjPKoYko[1onW`N`8ojRoj`GoYkgY00?oXj_LojBYf_l000000_l00003ojBYfPOoYJWI1_nW
ZMT00onVXm;oZ:CBojRTdP06ojRTdPOoZZKB00?o[:WDok2[d_n`Zm801?n`Zm86ojnYd@03okNgfOne
[];o]JkB00Ko]JkB1?nc[]<4okVcd`Oo]K3D00?o_;KDokNde_ng]=H01ong]=H00on^]]oo][WKokJi
f`04okJif`KoZK[U00?o/;_RojJnjonV_^/01_nV_^/6ojO0j`;oYl3/2?nY`N/2ojW0jPGoZ/7Z1?nV
_n`00ol0003oY[o/ojJok008ojJok0OoZ<3[2?nY`N/Eooooo`03o`000?oooooooooo00Kooooo1Ol0
000?ooooo`006_ooool2o`0000Wooooo1_nX`>/7ojS1j`;oZ<3[1OnW`>/9ojNoj`koZ<7[2?nW`>/5
ojNnj`;oY[o[1onX`>/8ojS1k0OoZ<3[1OnW_nX3ojJnj`OoYko[1onW`N`8ojRoj`03ojNmjOnSZmco
Xj_L00?o00001onTZMX7ojFYf@;oYjWI1OnVXm87ojRTdPKoZZKB00?o[joHok2[d_n`Zm801On`Zm84
ojnYd@Co]kOI2?ne[]800onc[]?o^K?CokVcd`05okVcd`Go]K3D0onl]]@7okNdeP03okbgeOnf^M_o
][WK00Ko][WK0_nY^^D5ok2khPSoY[k[0_nW`>/6ojO0k0KoZL7[00?oZ<3[oj[1j_nZ`NX01OnZ`NX5
ojJok003o`000?nV_n_oY[o[00OoY[o/1_nX`>/2ojO0j`SoZL7[5?ooool00ol0003oooooooooo`06
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@03oooool001[ooooo00?o0000ooooooooool01_ooool2
ojNoj`OoZ<3[1OnX`N/2ojS0j`OoYl3[2OnW_n/>ojS1j`SoYl3[00?oYkk[ojJojonV_n/01?nV_n/7
ojS0j`SoZ<7/1onX`>/00onW_n[oY[k[ojJnj`05ojJnj`GoYko[0_nX`N`7ojO1k0KoZ;o[00CoY;3P
o`000?l0003o00001?nSZm`6ojBYfPKoYJWI00?oY:;CojJSd_nVXm801OnVXm88ojRTdP;oZZKB1On_
[mP7ok2[dP03ojnYdOng]mWo]kOI00Co]kOI1one[]800onk`Moo^K?CokVcd`06okVcd`?o]K3D1_nl
]]@5okNdeP?o_;OE1_nf^M/00onk^]So/;_Rok2khP06ok2khPKoY[k[0_nX_^T8ojO0k0;oZL7[1OnX
`>/7oj[1jP;oY[o/0_nV_n/01?l0003oY[o[ojJojonV_n/7ojJok0;oZ<3[1_nW`>/7ojW1jaGooooo
00?o0000ooooooooool01_ooool00onHV9So8B4Qonk^kP0@ooooo`006_ooool00ol0003ooooooooo
o`03ooooo`KoYko[1onX`>/00onX`N_oZ<3[ojS0j`04ojS0j`OoYl3[2OnW_n/>ojS1j`KoYl3[00?o
Y[k[ojJojonV_n/01_nV_n/5ojS0j`[oZ<7/0onX`>/4ojJmjPSoY[k[00?oYko[ojS1k?nX`N`01?nX
`N`7ojO1k0;oZ;o[00GoY;3Po`000?l0003o0000ojB`h006oj>[g0OoY:WJ0_nUZMT5ojBRd`OoYZ?B
1_nXY=800on]]=ko[joHojn_f006ojn_f0Go/:_B00?o]<GVokNgfOng]mT01_ng]mT5okF^dP?o^l7O
2?ni/m<00one/=Co_;KDokbfe005okbfe0?o]kCF1_nl]mD4okJif`?o^k[H2?n`^n82ojJnj`KoZ;kY
1_nW`>`00onV`>coZ<3[ojS0j`05ojS0j`SoZ/7Z1?nV_n/01?l0003oY[o[ojJojonV_n/7ojJok0So
Yl3[1onY`N/Eooooo`03o`000?oooooooooo00Kooooo00?oV9RHob4Q8Oo^k^h03oooool001[ooooo
00?o0000ooooooooool02_nW_n/5ojS0j`;oZ<7[1onX`>/5ojO0j`?oY[o[2?nW_n/>ojS1j`;oYl3[
1OnV_^/8ojJoj`03ojS0jonX`NcoZ<7/00[oZ<7/0_nW_n/7ojJmjPKoY[k[00?oZ<7[ojS1k?nX`N`0
1_nX`N`5ojO1k004ojJgiOl0003o0000o`0000GoY;3P1_nSZm`5ojBYfP03oj6Qe?nTX]?oY:;C00Go
Y:;C1onVXm84ojRTdPCo[KCN1on_[mP3ok2[dPCo]<GV1ong]mT3okF^dPKo^l7O1_ni/m<00onmaN3o
_;KDokbfe007okbfe003okNde_nl]mGo_;OE00Go_;OE0onf^M/5ok^jf0Ko/;_R0_ng_]l8ojRnj@;o
Yl3/1OnV`>`7ojS0j`SoZ/7Z1?nV_n/00ol0003oY[o[ojNoj`08ojJok0OoYl3[1onY`N/Eooooo`03
o`000?oooooooooo00Oooooo00?oMgMgofIVI_ooool03_ooool001Wooooo00?o0000ojNojonW_n/0
3?nW_n/00onX`>_oZ<7[ojS1j`04ojS1j`OoZ<3[00?oYl3[ojJojonV_n/01OnV_n/6ojNoj`koZ<7[
0_nW_n/7ojJnj`KoY[o[0_nX`N/9ojS1k0KoYko[1onV_NX2ojJnj`GoZ<7[2?nX`N`00onW`NcoY[OU
o`000002o`000003ojJgiOnT/>3oY;3P00GoY;3P1onSZm`00onTZM[oXJ7Doj6Qe003oj6Qe0OoY:;C
1onVXm800onXY=;o[KCNojfdgP05ojfdgPOo[joH00?o/:_BokC5i_ndaNH01?ndaNH7okNgf@03okF^
d_nk`Moo^l7O00Go^l7O1?ni/m<4okg5h0Oo_;KD00?o`<;KokbgeOnl]mD01onl]mD00onf^M_o^k[H
ok^jf004ok^jf0Co/;_R1Ong_]l6ojRnj@03oj^nj?nV`>coY/3/00KoY/3/1onX`>/8oj[1jP;oY[o[
0_nW_n/00ol0003oYko[ojNoj`08ojJok0OoYl3[1onY`N/Eooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool03Oooool001Wooooo00?o0000ojNojonW_n/02onW_n/2ojS0j`OoZ<7[1OnX
`>/3ojO0j`OoY[o[0_nW_n/>ojS1j`KoYko[1onV_^/2ojJoj`KoZ<7[1_nX`N`00onX`N_oYko[ojNo
j`06ojNoj`GoY[gZ0_nW_n/7ojS1j`KoZ<7/00?oYkkYo`000?l000001OnV]nD7ojB`h0?oXj_L0onO
XMH7oj6Qe0KoY:;C1_nVXm800onZ]n;o[KCNojfdgP06ojfdgPKo[joH00?oZm3cokC5i_ndaNH01_nd
aNH5okNgf@03ojkAl_nk`Moo^l7O00Oo^l7O00?o^K?Cokg5h?nmaN001OnmaN05okbfe0?o`<;K1onl
]mD00oo2_]Oo^k[Hok^jf006ok^jf003ok2kh_ng_]oo]kkO00Ko]kkO0_nX_^T5oj^nj0SoY/3/1onX
`>/7oj[1jPCoYko[00Co0000ojNojonW_n_oYko[1onV_n`7ojO0j`SoZL7[4oooool3o`0000Cooooo
00Go0000okZj^_ooooooV9RHoa0@400?ooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Ko
oooo00?o0000oooooonW_n/02?nW_n/6ojS0j`OoZ<7[00?oZ<3[ojO0jonW`>/01OnW`>/5ojJoj`;o
Yko[3onX`N/7ojNoj`GoY[k[0onW_n/7ojS1j`;oZ<7/1OnX`N/8ojNoj`03ojJmj_nW_n_oYko[00Co
Yko[1onX`N/2ojS1k005ojNnjOl0003o0000o`000?nW_^T01onV]nD5ojB`h003oifSfOnOXMKoWj7F
00GoWj7F1_nQXM@7ojBRd`;oYZ?B1OnZ]n88ojfdgP;o[joH1On[d?<8okC5iP03okNgfOn^dO;o[]7b
00?o[]7b1onk`Ml00onXdoKo_LGPokg5h006okg5h0?o_;KD1_o0`]/5okbge@?o`[kG1_nk^]P00oo0
_]So]kkOokNng`06okNng`03okc2g_n[_^SoZkkX00KoZkkX1_nV`>`00onV_ncoZ<3[ojS0j`06ojS0
j`OoZ/7Z1?nW_n/01?l0003oYko[ojNojonW_n/7ojJok0OoYl3[2?nY`N/Dooooo`03o`000?oooooo
oooo00;ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00?ooooo`003_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Kooooo00?o0000ooooooooool02?nW_n/7ojS0j`GoZ<7[0onX`>/7ojO0j`03ojJojonW
_n_oYko[00CoYko[3onX`N/7ojNoj`03ojJnjonW_n_oYko[00GoYko[1OnX`N/2ojS1k0OoZ<7[1_nW
_n/00onV_N[oYko[ojNoj`06ojNoj`KoZ<7[0ol00005ojNnj@OoY[OU00?oY;3PoifSfOnMXmT00onM
XmT7oinQePKoXJ7D1OnTX]<2ojNeh`OoZ[OR1_n]]=h2oj7In`OoZm3c1_ndaNH2ohoOoPKo[]7b1?nk
`Ml4ojSCmPSo_LGP00?o_;KDol32foo0`]/01Oo0`]/3okbge@Ko`[kG0onk^]P4ol2nf0Ko]kkO0onl
`]h8oj^nj0;oY/3/1OnV_n`6ojS0j`03ojO0jonZ`N[oZ/7Z00KoZ/7Z1?nW_n/00ol0003oYko[ojO0
k007ojJok0KoYl3[0_nX`>/8ojW1jaCooooo00?o0000ooooooooool05Oooool000kooooo00Go410@
oooooooooooooooooa0@4006ooooo`;o00000_ooool8ojNoj`OoZ<3[00?oZ<7[ojS0jonX`>/01OnX
`>/5ojO0j`;oY[o[1onW_n/?ojS1j`GoYko[0onV_^/7ojNoj`03ojS1jonX`NcoZ<7/00CoZ<7/1onX
`N/2ojNoj`GoY[gZ2?nW_n/2ojS1j`?o00000onX`N/6ojNnj@?oY[OU0onMY]d6oifSf@OoWj7F1onQ
XM@00onTX]?oYkGSojNeh`04ojNeh`OoZ[OR0_n]]=h6oj7In`OoZm3c0_ndaNH6ohoOoPKo[]7b00?o
^l7OojSCm_nXdoH01OnXdoH6okg5h003ojg?l_o0`]_o`<;K00Oo`<;K00?o_;OEol:neoo2_]L01_o2
_]L00onk^]So`;kHol2nf004ol2nf0?o]kkO1_nl`]h6oj^nj003ojg1j?nV_ncoY[o/00KoY[o/0_nX
`>/5ojO0j`SoZ/7Z0_nW_n/2ojO0k003o`000?nW`>coYl3/00OoY[o/0_nW`>/6ojS0j`OoZL7[5Ooo
ool00ol0003oooooooooo`0Dooooo`003_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o
0000ooooooooool00oooool7ojNoj`?oZ<3[1OnX`N/7ojS0j`03ojO0jonV_n_oY[o[00CoY[o[1onW
_n/?ojS1j`03ojNojonV_^_oY[k[00GoY[k[1OnW_n/2ojS1j`OoZ<7/1OnX`N/2ojJnj`OoY[gZ1_nW
_n/3o`0000OoZ<7[0onW_^T2oin]h@OoWJKM1_nMXmT7oinQeP?oXJ7D0onS/>48ojNeh`GoZ[OR0onL
g_d7oj7In`?oZm3c1_mRe^/6ohoOoP?o[]7b1?m]eoP7ojSCmP;o_LGP1On]co87ol32f`03okS:j?o2
_]Oo`[kG00Ko`[kG00?o`lGLol2nf?o0_]P01_o0_]P00ong_]oo_<;Nokc2gP06okc2gP;oZkkX1On]
`NP7ojJok0SoYl3[1onZ`NX4ojO0k003o`000?nW`>coYl3/00KoY[o/0_nV_n/8ojS0j`OoZL7[5?oo
ool00ol0003oooooooooo`0Dooooo`003_ooool01Ol0003ooooooooooooooooo000000Gooooo00?o
0000ooooooooool01Oooool5ojNoj`;oZ<3[2?nX`N/5ojS0j`;oYl3[1onV_n/5ojNoj`goZ<7[1?nW
_n/8ojJnj`03ojNojonX`N_oZ<7[00CoZ<7[1onX`N`00onX`N_oY[k[ojJnj`04ojJnj`OoY[gZ0_nW
_n/3o`0000WoZ<7[00?oYKSWoin]hOnO[N401?nO[N47oifVg@GoWJ?I1_nOXMH00onNZ=goXk3Qoj>`
h@05oj>`h@SoYkGS00?oZ[ORoicNoOnLg_d01OnLg_d3oj7In`CoA/OD1Om7aND3ob:]c`KoH<Cl00?o
8JKSob2/c_lP[<h01Om]eoP3ojSCmPCoJM7j1on]co84ol32f`Co^<[X1_o2_]L3ol?5g0Ko`;kH0_o4
`mT7okc2gP03oko5gon]`NSo[L7X00Ko[L7X1onV_n`8ojO0j`OoZ/7Z1?nW`>`00ol0003oYl3/ojO0
k002ojJok0KoY[o[1onX`>/7ojW1jaGooooo00?o0000ooooooooool04oooool000kooooo00Go410@
oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo00Kooooo00?oYko[ojS0jonX`>/01?nX
`>/8ojS1j`03ojS0jonW`>_oYl3[00CoYl3[1onV_n/00onW_n_oZ<7[ojS1j`0:ojS1j`;oZ<3[1onW
_n/6ojJnj`03ojO0jonX`N_oZ<7[00KoZ<7[1OnX`N`2ojS1j`OoY[k[1OnV_NX3o`0000WoZ<7[1OnU
^>L6oin]h@KoWJKM1_nMXmT2oinQePGoWZSM1onS/>46ojNeh`?oWMom1OnLg_d2odc;d@KoKMWc0om7
aND5ohc8o0?oH<Cl1?nC]Nh7ofNho0;o79_W00?o3I_AofWAn_mYdOX00omYdOX7ojg?lP03ol32fonh
b^So^<[X00Go^<[X0oo2_]L5ol?5g0Go`;kH1?o4`mT4okc2gPCo_lGO1_n]`NP00on_`nSoY[o/ojJo
k006ojJok0OoYl3[2?nZ`NX3ojO0k004ojJok?l0003oY[o/ojJok0SoY[o[1onX`>/7ojW1jaGooooo
00?o0000ooooooooool04_ooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o0000
2?ooool7ojS0j`KoZ<7[0_nX`>/7ojO0j`GoY[o[0onW_n/8ojS1j`KoZ<3[1onW_n/2ojJnj`GoYl3[
2?nX`N/00onX`NcoZ<7[ojS1j`04ojS1j`OoY[k[00CoY[gZo`000?l0003o00001?nX`>/5ojS1j`;o
Z<3[1onU^>L5oin]h@OoWJKM0onMXmT2oiZQf@SoWZSM1onS/>42ojNeh`OoWMom00?oW=kmodc;dOn8
i_L00on8i_L3ofgIl`GoW/Kd1On<b?`00onV/n;oTkG^oi>ekP06oi>ekPOoIkSl1OlLVnL00olGW>7o
JM7jofWAnP03ojg?lPCoQM7o2?nhb^P00oo2_]Oo`lGLol?5g004ol?5g0?o`;kH1oo4`mT00onl`]ko
_lGOoko5g`05oko5g`;o[L7X1On_`nP8ojJok0OoYl3[1_nZ`NX00onZ`N_oY[o/ojJok002ojJok004
o`000?nV_ncoY[o/ojJok0OoY[o[1onX`>/6ojW1j`03ojS1jooooooooooo01?ooooo00?o0000oooo
ooooool04_ooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo
00Sooooo1onX`>/2ojS1j`KoZ<3[1onW`>/00onV_n_oYko[ojNoj`05ojNoj`OoZ<7[1onX`>/5ojNo
j`;oY[k[1onW`>/6ojS1j`;oZL7[1onX`N/5ojJnj`;o00002?nX`>/00onX`N_oZ<3[ojS0j`04ojS0
j`KoYKSW1_nO[N43oifVg@?oUikI1_nJXMT7oijXg@KoXk3Q0onSfO/6oigOo@KoR>Kg0_nWbO48oik6
m003ohc8o?nV/n;oY[?R00?oY[?R2?nC]Nh3ofNho0GoT[?]1OmBZoT00olCSNKo5icQoaNLh@06ohGA
o`Ko^<[X00?oY/Wbol?5g?o3aM`01_o3aM`00oo0_]Soa<?IolC3f@05olC3f@03olK6f_noaMoo_lGO
00Go_lGO00?o`LSPojo3j?n_`nP01_n_`nP7ojJok0SoYl3[0_nZ`NX5oj[1j`CoY[o/00Co0000ojJo
k?nV_ncoY[o/1onV_n/7ojS0j`;oZL7[1OnX`N/Eooooo`03o`000?oooooooooo017ooooo000Hoooo
o`03o`000?oooooooooo00Wooooo1OnX`>/3ojS1j`OoZ<3[0onW`>/4ojJoj`SoYko[1onX`N/7ojS0
j`03ojNojonV_^_oY[k[00CoY[k[1onW`>/2ojS1j`KoZL7[1OnX`N/3ojJnj`?o00000onV_^/6ojS0
j`03ojS1k?nX`>_oZ<3[00KoZ<3[1_nU^>L3oin]h@;oUj;L1onGW]T6oiZQf@OoWZSM0_nS/>47oj?I
n`;oWMom1?nKko@2ohSVm`KoYlWa1_nNa_@00onX/MkoY[?RojJchP05ojJchPKoTkG^0_n[]=l8oi:c
k@GoDZ_i0olCSNH6ohGAo`;o^<[X1OnVbO86ol?5g003okk8h_o4`mWoa<?I00Goa<?I0oo6a]X5oko5
g`?o`LSP2?n_`nP7ojJok0KoYl3[00?oZ<3[oj[1jonZ`N/01_nZ`N/4ojJok003o`000?nV_ncoY[o[
00OoY[o[1onX`>/8ojS1jaGooooo00?o0000ooooooooool04?ooool001Sooooo00?o0000oooooooo
ool02_ooool00onX`>_oZ<7[ojS1j`05ojS1j`GoZ<3[0_nW`>/7ojJoj`KoYko[2OnX`N/5ojS0j`?o
Yko[1_nV_^/5ojO0j`?oZ<7[1onY`N/01?nX`N_oY[k[ojJnjonV_^/3o`0000OoY[k[0_nX`>/5ojS1
k0SoZ<3[0onU^>L2oiRWh@KoUj;L1onGW]T6oiZQf@GoWZSM0onVc_D6oj?In`03oh7XiOnKkoCoVnod
00CoVnod0_n^e?@7ojO9l@;oW/Kd1OnX/Mh7ojJchP;oTkG^1_n[]=l6oi:ck@03oj^ihomi[O?oNJgc
00CoNJgc0_l`U?02oa>=iPGoC[Cj1onVbO83ol?5g0Co_/SR1Oo4`mT5olK6fP?o_lGO1Oo1b>06ojo3
j0;o[lGZ1onV_n`2ojO0j`GoZ<3[2?nZ`N/2ojJok0;oY[o[00?o0000ojJojonV_n/01onV_n/7ojS0
j`OoZ<7[5Oooool2o`00017ooooo000Gooooo`?o00003Oooool7ojS1j`03ojS0jonW`>_oYl3[00Co
Yl3[1onV_n/2ojNoj`goZ<7[00?oZ<3[ojNojonW_n/01OnW_n/6ojJnj`03ojO0jonX`N_oZ<7[00Go
Z<7[1OnY`N/2ojS1j`?o00002OnV_^/3ojS1j`KoZ<7/1_nX`>/00onO/nKoV:OQoiRWh@04oiRWh@Ko
Uj;L1_nGW]T7oiZQf@03oijXgOnVc_GoY/ke00KoY/ke00CoXmWkoh7XiOn1j>GoPNSU1?nKko@6ojkD
m0GoYlWa00?oYk7OojRag_nX/Mh01_nX/Mh5ojJchP03ojjcg?n[]=ooZkCO00OoZkCO0_nB/nd5oj^i
h`KoNJgc1?l`U?05odjdnPOoY/Wb00?o`lGLokk8h_nnb>801?nnb>83olC3f@Ooa/KJ00?o_lGOol78
h?o1b>001Oo1b>02ojo3j0Ko[lGZ1OnV_n`00onV_n_oZ<3[ojS0j`06ojS0j`OoZ/7[1?nV_n/00ol0
003oY[o[ojJoj`08ojJoj`OoZ<3[1onX`N/Cooooo`03o`000?oooooo0000017ooooo000Gooooo`03
o`000?oooooooooo00kooooo1OnX`N/2ojS0j`OoYl3[1OnV_n/3ojNoj`coZ<7[0_nX`>/8ojNoj`?o
Y[k[1?nW`>/7ojS1j`03ojW1jonX`N_oZ<7[00?o000000?oZ<7[ojJnjonV_^/01_nV_^/7ojS1j`Ko
Z<7/0_nX`>/5oinciPKoV:OQ1OnGX]`7oiNNf@?oVZ7I1OnR_nh6ojK>m@?oVo3b0onYmNl2okKUmPSo
[]Cd00?oYlWaojNagonW/Ml00onW/Ml8ojRagP03ojJch_n^/mco[[?L00?o[[?L1on[]=l00onc^Mgo
ZkWSoj^ih`05oj^ih`OoNJgc1Ol`U?02obfGl0;oC[Cj0onVbO84oi;4n0Oo_/SR00?oa<?IolK6f_o6
a]X01Oo6a]X00oo8b]co`LSPol78h005ol78h0;o`/cR2?n_aNX00onV_ncoY[o[ojJoj`03ojJoj`So
Z<3[1onZ`N/4ojJoj`03o`000?nV_n_oY[o[00SoY[o[1OnX`>/00onY`N_oZ<7[ojS1j`06ojS1jaCo
oooo00?o0000ooooooooool03oooool001Oooooo00?o0000ooooooooool03oooool00onX`N_oZ<3[
ojS0j`04ojS0j`OoYl3[00?oY[o[ojNojonW_n/01OnW_n/8ojS1j`KoZ<3[1_nW_n/00onV_^_oYl3[
ojO0j`06ojO0j`GoZ<7[00CoZL7[o`000?l0003o00001OnX`N/7ojJnj`SoZ<7[0onX`N`3ojNoj`Oo
Wk?V1OnHYn46oiNRg0GoUikI00?oVJcToj:ok_nR_nh01onR_nh2ojK>m@CoVo3b0onYmNl5okKUmPKo
[]Cd00?oY[?RojNagonW/Ml01OnW/Ml6ojRagP03ojbbgOn^/mco[[?L00Go[[?L1?n[]=l4ok>ig@Oo
ZkWS0omi[O<4oi:fk`?oBi[c0_l`U?04obfGl0OoT/Ch1Onnb>82okS7iPKoa/KJ0oo8b]`4ol78h0Go
`/cR1_n_aNX00on^aN_oY[o[ojJoj`05ojJoj`OoZ<3[2?nZ`N/4ojJoj`03o`000?nV_n_oY[o[00So
Y[o[00?oZ<3[ojW1jonY`N/00onY`N/8ojS1jaCooooo00?o0000ooooooooool03_ooool001Oooooo
00?o0000ooooooooool04?ooool7ojS0j`GoYl3[0onV_n/7ojNoj`OoZ<7[1onX`>/2ojNoj`GoY[k[
2?nW`>/00onX`N_oZL7[o`000002o`0000;oZL7[1onX`N/7ojJnj`OoZ<7[1onW_n/6oinciPKoV:OQ
1_nGX]`00onGW]WoVJcToiV/i003oiV/i0OoX[o^1?n[ioX00onKl?;oZOG_ojWek`02ojWek`Oo]^Gf
0_n^e?@5ojJchPOoYk7O0_nX/Mh5ojbbg@Oo[[?L00?oZkCOok>igOnc^Md01Onc^Md5oj^ih`;o];kR
1onB]^l5od^Jl`;o;8_]0_l]Uo07oi;4n003okk8h_nhanKo^<OV00Co^<OV0oo6a]X6olS:g003ol78
h?o2c>;o`/cR00Ko`/cR0_n_aNX5ojk5j`OoY[o[1onX`>/6oj[1j`03ojW1jonV_n_oY[o[00?oY[o[
00?o0000ojJojonV_n/01_nV_n/00onW_n_oZL7[ojW1j`05ojW1j`KoZ<7[00?oYl3[ooooooooool0
4oooool00ol0003oooooooooo`0=ooooo`005oooool2o`0001;ooooo1onX`>/00onW`>_oY[o[ojJo
j`05ojJoj`GoYko[0_nX`>/7ojS1j`GoZ<3[0_nW_n/7ojJnj`KoYl3[0ol00006ojW1j`?oZ<7[1?nU
_^/7ojJnj`OoZ<7[1onW_n/6oinciP?oV:OQ0_n@W]h6oi6Og@OoVJcT1?nR_nh5oj_WnPCo]OS]1?no
ko83okKUmP;oZKgX2?nV/n85ojNag`03ojN`g_n//]go[;;M00Ko[;;M1On^/m`00onc_N;o/kWMok>i
g@07ok>ig@03oj^ihond_^;o];kR00Co];kR1onB]^l5od^Jl`Co;8_]0onBa?P3oh6hn0So^<OV00?o
a/KJolS:g?o8b]`01Oo8b]`8ol;<hP03ol7>i?n^aN_o[/G[00Ko[/G[1onV_n/7ojS0j`;oZ/7[1OnY
`N/4ojJoj`03o`000?nV_n_oY[o[00?oY[o[1OnW_n/7ojW1j`;oZ<7[1OnW`>/Dooooo`03o`000?oo
oooooooo00gooooo000Gooooo`03o`000?oooooooooo01;ooooo1OnX`>/3ojO0j`OoY[o[00?oYko[
ojS0jonX`>/01?nX`>/7ojS1j`03ojS0jonW_n_oYko[00CoYko[1onV_^/2ojO0j`03ojS1jol0003o
000000?oZ<7[1OnY`N/2ojS1j`OoYKk[1OnV_^/2ojS0j`OoZ<7[1onW_n/3oinciP;oTjKS1_n@W]h6
oi6Og@OoVJcT00?oX[o^oj_Wn_n[ioX00on[ioX4okGhk@Go_nob00?o^]K_ojVmj?nY_NP01?nY_NP8
ojJchP03ojNagonW/=koYk3N00?oYk3N1on//]d3ojjcg0Co/kgR1onc^Md00onh`>3o];kRokBnhP06
okBnhP?oT[K_1?nL^nh3oe^LlP;oBi[c1?l/Rnd6oh6hn0Ko^<OV00?o/lGWolS:g?o8b]`01Oo8b]`2
olW>gPKo`/cR0oo1c^@6ojk5j`03oj_3k?nV_n_oY[o[00KoY[o[1OnX`>/2ojW0j`OoZL7[1?nV_n/0
0ol0003oY[o[ojJoj`08ojNoj`KoZL7[2?nW`>/Dooooo`03o`000?oooooooooo00cooooo000Goooo
o`03o`000?oooooooooo01?ooooo00?oZ<3[ojO0jonW`>/01OnW`>/7ojJoj`OoZ<3[2?nX`N/6ojNo
j`GoY[k[00CoYko[o`000?l0003o00001_nX`N/00onY`N_oZ<7[ojS1j`04ojS1j`OoYKk[00?oY[k[
ojS0jonX`>/01?nX`>/7ojS1j`?oYko[0onK/^P6oi>Vh`KoT9kN1_nAWmd5oiV/i0Co[=3c0_n[ioX3
okGhk@Go_nob1?nje^l6ojVmj0KoY[?R00?oXZkPojN`g_nW/=h01OnW/=h7ojbbg@03ojjcg?nc_N;o
/kgR00Co/kgR1?nc^Md4okS0h0Ko];kR0_nhaN@7oibkkPCoFicb0oliQn/2obb;k@GoPKSh1?nhanH4
ok?5i`Gob<[L1?o9c]h3ol;<hPKo`LkT0_n^aN/5oj_3k0SoY[o[00?oZ<3[ojW0jonY`>/01?nY`>/7
ojW1j`CoY[o[00?o0000ojJojonV_n/01onW_n/7ojW1j`KoYl3[00?oYko[ooooooooool04oooool0
0ol0003oooooooooo`0;ooooo`005oooool00ol0003oooooooooo`0Eooooo`OoYl3[1onV_n/7ojS0
j`SoZ<7[1_nW_n/00onV_^_oYko[o`000002o`0000?oYko[1OnX`N/3ojW1j`KoZ<7[1OnU_^/3ojJn
j`KoZ<3[1OnX`N/2ojJoj`KoVk;X1_nCY^<6oi2NgPKoTIoM00?oVJcTojc@lon/d?<01On/d?<3okoa
lPCoboC[00?o_nobok[Fkonje^l01Onje^l6ojVmj0;oY[?R1OnR[^06ojN`gPKo[;;M0_n]`^T7ok>m
hP03ok>igOnh`>3o^<3P00Go^<3P0ond_^85okS5i0OoW;_^1?mKW?85ocV7j`GoPKSh00?o^<OVok?5
ioncaNL01OncaNL3olS:g0KobLkN00?o`/cRol7>i?o1c^@01?o1c^@00onod>OoZl?/oj_3k006oj_3
k0KoY[o[00?oYko[ojW0jonY`>/01_nY`>/3ojW1j`?oZ<7/1OnV_n/00ol0003oY[o[ojJoj`07ojNo
j`OoZL7[0_nW`>/5ojNojaCooooo00?o0000ooooooooool02oooool001Kooooo0ol0000Gooooo`Go
Yl3[0onW_n/6ojJoj`GoZ<3[2_nX`N/3ojNoj`04ojJnjol0003o0000o`0000OoYko[00?oZ<7[ojW1
jonY`N/01OnY`N/6ojS1j`03ojFnjonV_^_oY[k[00GoY[k[1_nX`>/00onX`N_oY[o[ojJoj`04ojJo
j`KoVk;X1OnCY^<7oi2NgP?oTIoM1?nO^>X4ojc@l`Co_o7b1?o;m>/3olSWk0Oo^]K_0onY_NP2oij_
i0SoXZkP1_nW/=h2ojbbg@Ko[L;Y1Onc_N800on^a>Wo^<3PokS0h007okS0h003okBnh_nhaNCo^<GT
00Go^<GT0onL^nh3oibmk`CoHiW^00?oFicbocV7joliQn/00_liQn/6og^]l`So/lGW00?ob<[LolW>
g_o9c]h01?o9c]h2olWBh0Go`LkT0onod>L8oj_3k0;oY[o[1OnW_n/6ojW0j`03oj[2jonX`NcoZ<7/
00GoZ<7/1?nV_n/00ol0003oY[o[ojJoj`07ojNoj`OoZL7[2?nW_n/Dooooo`03o`000?oooooooooo
00[ooooo000Fooooo`03o`000?oooooooooo01Sooooo00?oYl3[ojNojonW_n/01OnW_n/6ojJoj`03
ojS0jonX`N_oZ<7[00[oZ<7[00?oYl3[ojJnjol000000_l00004ojJnj`GoYko[0_nX`N/8ojW1j`?o
Z<7[0onU_^/8ojJnj`?oZ<3[0onX`N/7ojJoj`KoVk;X1OnCY^<3oi2NgP?oSZ;Q2?nO^>X00on/d??o
_o7bokoalP03okoalPCoboC[1_o8in`3ok[Fk`;oXk[Y1_nN[n@7oj:^h0GoYk3N0_nW`N`8ojg2j@03
ok>mh_n^a>Wo[/CY00?o[/CY1onh`>02okW5h`Ko^<GT00?o^L[WoibmkonL_Nl01OnL_Nl4of>IkP?o
B8KX0_liQn/6og^]l`Ko/lGW0_nca>H5olW>gPCobM;P0oo1c^@5oko@i`KoZl?/00?oZ<7/ojNojonW
_n/01_nW_n/2ojW0j`GoZ/;[1onX`N`4ojJoj`03o`000?nV_n_oY[o[00OoYko[1onY`N/7ojNoja?o
oooo0ol0000;ooooo`001?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h6
ooooo`03o`000?oooooooooo01[ooooo1onW_n/3ojJoj`CoZ<3[2?nX`N/2ojO0j`?o00002?nV_^/0
0onW_n_oZ<7[ojS1j`04ojS1j`KoZL7[00?oZ<7[ojFnjonU_^/01OnU_^/6ojJnj`03ojS0jonX`N_o
Z<7[00GoZ<7[1onV_n/3oi^bj0;oSZKU1On9WN47ohjRh@KoWkSZ1?nee_42okoalPCoboC[1_o8in`0
0onkeNgoXk[Yoj>jj@04oj>jj@KoWZoT1onR[^000onW/=koYl7/ojO1k004ojO1k0Ko[L;Y0_nUaO06
ojk4j@Co^<3P1OniaN<3okS5i0Co^L[W1onL_Nl4of>IkPGoB8KX1_mk[O<2ok?5i`Ko/lCV0oo9c]h6
olWBh003ol7>i?nod>Oo_m3W00Go_m3W0_n[`n`5ojS1k0OoYko[1onZ`^/6ojS1k0;oYko[1?nV_n/0
0ol0003oY[o[ojNoj`05ojNoj`;oZ<3[1onY`N/7ojNoj`oooooo0ol00002ooooo`03o`000?oooooo
oooo00Wooooo0006ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06
ooooo`03o`000?oooooooooo01_ooooo1OnW_n/00onV_n_oZ<3[ojS0j`06ojS0j`KoZ<7[0ol00004
ojO0j`KoY[k[0_nW_n/7ojS1j`;oZL7[1OnX`N/7ojFnj`;oY[k[1OnX`>/7ojS1j`?oY[o[0onJ]N/6
ohjVi@GoRIgQ1on>X^43oinhjPKo]MKa1?o>kNX00oo;m>_ob>O/olSWk003olSWk0Co^mG]1_nS^^T6
oij_i0?oXZkP1?nR^>P7ojO1k0;o[L;Y1_nUaO06ojk4j@03okS0h?niaN?o^LGS00Ko^LGS00?o^<GT
okW:ionib^L01?nib^L7oibmk`CoHiW^1?m8Q^P7oh2XkPSo/lCV00?obLkNolWBh?o9d^001?o9d^02
olWFh`Ko_m3W0_nicn/7ojS1k0OoYko[1onZ`^/2ojS1k0KoYko[0onV_n/00ol0003oY[o[ojJoj`02
ojNoj`KoZ<3[1OnY`N/00onX`N_oYko[ojNoj`06ojNoj`_ooooo0ol00005ooooo`03o`000?oooooo
oooo00Wooooo0006ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006
ooooo`;o00007Oooool00onW_n_oY[o[ojJoj`03ojJoj`SoZ<3[0_nX`N/3o`0000;oZ<7[1_nW`>/2
ojJnj`KoYko[1OnX`N/2ojW1j`OoZ<7[2?nU_^/6ojS0j`GoZ<7[0_nW`>`6oiZej`KoSZKU1On9WN47
ohjRh@03oinhj_nee_7o]MKa00Co]MKa1?o>kNX4omC/i@03olSWk?nkeNgo^mG]00Go^mG]1_nS^^T3
oij_i0;oVZoV2?nR^>P5ojO1k0;oYlK_2?nUaO03ojk4j@?oYko[1oniaN<2ok[;i`Oo^L[W0onL_Nl3
oi:fl0CoIY;X00?oHiW^odR6j?m8Q^P00_m8Q^P7oh2XkPKo/lCV00?o^<GUolWBh?o9d^001?o9d^04
olWFh`;o_m3W1_nicn/5ojS1k0;oY[o[1onW_n/7oj[2j`SoYko[0onV_n/00ol0003oY[o[ojJoj`08
ojS0j`03ojW1jonX`N_oZ<7[00?oZ<7[2?nW_n/6ooooo`Co00002?ooool00ol0003oooooooooo`09
ooooo`001_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001Oooool2
o`0001oooooo1_nV_n/6ojS0j`03ojS1jol0003o000000KoZ<7[0onW`>/4ojJoj`OoYko[00?oZ<7[
ojW1jonY`N/01?nY`N/7ojS1j`SoYKk[1_nX`>/00onX`N_oYl3/ojO0k004ojO0k0KoV[G[1On>Y^D5
ohVMh@KoSZ;Q0onT_>/3okGFl@Goc^gZ1?oDk>D2oloOi0So^mG]0onS^^T2oiNaj@KoVZoV2?nR^>P0
0onW`NcoYlK_ojO6k`04ojO6k`KoYLG`00?oX;g]ojNojonW_n/01OnW_n/4okW5h`Go^/_W1Onib^L2
okG=k0KoT[K`1?mVT^P3oeR7i0;oB8KX1on0Z>h2ok?4iPGo^<GU0oo9d^05olWFh`;oamWW2?nicn/0
0onX`NcoY[o[ojJoj`04ojJoj`OoYko[1onZ`^/6ojNoj`GoY[o[00?o0000ojJojonV_n/01_nX`>/0
0onY`N_oZ<7[ojS1j`05ojS1j`KoYko[00CoY[o[oooooooooooooooo0ol0000=ooooo`03o`000?oo
oooooooo00Sooooo0006ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0005ooooo`03o`000?oooooooooo01oooooo1_nV_n/2ojS0j`04ojS1jol0003o0000o`0000OoZ<7[
0_nX`>/7ojJoj`GoYko[0onX`>/6ojW1j`GoZ<7[0onV_n`7ojFnj`KoZ<3[1onW`>`6oiZej`GoSZKU
1On9WN42ohjRh@OoY;c[00?o]MKaolk]j_o>kNX00_o>kNX5omC/i@CocmoT1_nkeNd00onT_ngoUk7Y
oiNaj@04oiNaj@KoVZoV1_nR^>P2ojW2k0OoYlK_0_nUaO05oj2mk@OoYko[00?o^LGSok[;ionjbnL0
1_njbnL00onib^Oo]Lg/okG=k004okG=k0GoT[K`1OmVT^P5oeR7i0?oP:S^0on;ZNT8okS5i@03olWB
h?o9e^?obMKS00?obMKS1?o7fNL6okW?j`03ok7;kOnV_n_oY[o[00KoY[o[0onW_n/3ojS0j`SoZ/;[
0_nW_n/9ojJoj`03o`000?nV_n_oY[o[00;oZ<3[1OnY`N/7ojS1j`;oYko[1OnV_n/2o`00013ooooo
00?o0000ooooooooool02?ooool000Kooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@00Gooooo00?o0000ooooooooool08?ooool3ojJoj`;oYko[0ol00007ojS1j`KoZ<3[
1onV_n/00onW_n_oZ<3[ojS0j`05ojS0j`KoZL7[00?oZ<7[ojJok?nV_n`01OnV_n`5ojFnj`03ojNo
jonX`>_oZ<3[00GoZ<3[1onW`>`3oiZej`;oS:WY1On3WnD7ohZRi0KoY;c[1?njdN`00oo>kN[oe>cU
omC/i@03omC/i@KocmoT0_nkeNd5ojBok@KoUk7Y1_nJ[nH2oj:hj0KoZL;/1OnWa^l2ojO0j`OoX;g]
1OnW_n/2ojNnjPOo^/_W00?o^];/okG=k?necN`01_necN`5oi:fl0GoIY;X1?mHQn@7oh^Yj@Ko^<GU
0onoc>@3olWFh`KoamWW0_nicn/5ok7;k@OoY[o[1onX`>/6oj[2j`03ojW2k?nV_n_oY[o[00WoY[o[
00?o0000ojJojonW_n/02?nY`N/3ojS1j`?oYl3[2?nV_n/Aooooo`03o`000?oooooooooo00Sooooo
0006ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o0000
8_ooool01?nW_n_o0000o`000?l00003ojNoj`SoZ<7[1_nX`>/8ojJoj`OoZ<3[1_nY`N/8ojJok003
ojFnjonW_n_oYko[00?oYko[1onX`>/3ojO0k0?oW[_]1_n<ZNT5oh>Oi@OoRZ;T0onT_>/6ok[Ak0?o
d>3S0_oDk>D6oloOi0;oa]GU1onT_nd6oiNaj@?oVZoV0onP^>T8ojW2k003ojO6konW`>_oYl3[00Co
Yl3[1onP_Nd00onW_n_oYkkZojNnjP04ojNnjPCo^/_W1?njd^`6okG=k003oj_5kOn3XNKoPj7V00?o
Pj7V1?mWR^42ofJBj0CoF8OT1on;ZNT3okS5i@Ko_lcT00?obMKSolOIioo7fNL01?o7fNL00oo2f>[o
/L_]ok7;k@06ok7;k@OoY[o[1onX`>/2oj[2j`GoZL;/2OnV_n/2ojNoj`03o`000?nW_n_oYko[00Oo
ZL7[1onW`>/6ojJoj`03ojNojooooooooooo00oooooo00?o0000ooooooooool02?ooool000Cooooo
00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000oooooooo
ool07oooool3o`0000OoYko[2?nX`N/6ojS0j`SoY[o[1OnX`>/00onX`N_oZL7[ojW1j`05ojW1j`Ko
Y[o/0_nU_^/6ojNoj`GoZ<3[0onX`N/5oijkk@KoS:WY1On3WnD7ohZRi003ojBljonjdNco^]7/00Co
^]7/1?o@h><3omOOg@?ocmoT1Oo6eND7ojBok@?oUk7Y0_nA/^d7oj2hj@KoZL;/0_n^`^P7ojO0j`?o
X;g]1?nQ]nP7ojNnjP03ok[;ionjd^co^];/00Go^];/0_necN`5oj_5k@GoPj7V1OmWR^43of^<h0;o
F8OT1on;ZNT00onhaNGo_lcToko<i004oko<i0;oamOV1?o7fNL4ol;HjPKo/L_]0_nZ`n`6ojJoj`Ko
Z<3[0_nY`N/7ojW2k0?oY[o[0onV_^/5ojNoj`03o`000?nW_n_oYko[00OoZL7[1onW`>/2ojJoj`Go
Yko[4?ooool00ol0003oooooooooo`08ooooo`005Oooool00ol0003oooooooooo`0Looooo`?o0000
1?ooool5ojNoj`?oZ<3[1onX`N/3ojS0j`CoYl3[1onV_n/00onX`>_oZ<7[ojS1j`03ojS1j`OoZL7[
0_nV_n`6ojFnj`KoYko[00?oZ<3[ojS1jonX`N/01OnX`N/5oijkk@GoS:WY1On3WnD6ohZRi0;oXKSY
1OnjdN`4om3Ph`GoemoM00?ocmoTolKEiOo6eND01Oo6eND3ojBok@CoUkW_1OnA/^d7oj2hj@;oZL;/
1_n^`^P5ojO0j`03ojNji_nQ]nSoXKOX00KoXKOX1OnW_^X3ojk8k@Go^];/0_ngdnl7oj_5k@GoPj7V
1OmWR^45of^<h0?oRjWY0onH/NP6oko<i0CoamOV00?oamWWol;Hj_o2f>X01Oo2f>X2ok7;k@KoZ/?/
1_nV_n/2ojS0j`KoZL7[1OnY`^`00onW`>_oY[k[ojJnj`05ojJnj`GoYko[00?o0000ojS0jonY`N/0
1_nY`N/6ojO0j`WoYko[3oooool00ol0003oooooooooo`08ooooo`005Oooool00ol0003ooooooooo
o`0Iooooo`?o00002?ooool00onW_n_oZ<3[ojS0j`05ojS0j`KoZ<7[2?nW`>/5ojJoj`;oYko[1_nX
`N/5ojW1j`?oZ<7[1onU_^/3ojNoj`CoZ<3[1onX`N/5oijkk@GoS:WY1On3WnD2ohZRi0KoXKSY0onj
dN`4om3Ph`KoemoM0_oEf=X5olKEi@;o^/_W1onG^Nl5oi6bk@GoX;SY0_nX`>/8ojk2j003ojO0jonW
^^KoYk[V00?oYk[V2?nQ]nP00onW_^[o[/S]ojk8k@05ojk8k@03ok[Bk?ngdnoo]m?_00Co]m?_1on[
aNd4oh>QiPKoIh[Q1?m[S>07oiRaj0?o_lcT1Oo7enH2ol[Oj0Ko`]SZ0_nkeNd8oj[3k0?oY[o[0onW
_n/8ojW1j`03ojW2k?nW`>_oYl3[00?oYl3[1onV_^/2ojNoj`;oZ<3[00?o0000ojS0jonX`>/01onY
`N/2ojO0j`coYko[3oooool00ol0003oooooooooo`08ooooo`005Oooool00ol0003oooooooooo`0F
ooooo`?o00003Oooool7ojS0j`KoZ<7[2?nW`>/00onV_n_oYko[ojNoj`04ojNoj`KoZ<7[00?oZL7[
ojS1jonX`N/01OnX`N/6ojFnj`SoZ<3[1OnX`N/00onU_ncoSk7]ohnak@03ohnak@GoP:?Z1on2WnH7
oj6hj@03ok[Ak?o@h>?od>3S00;od>3S1_oGgmd4omGHfP03olKEiOnjbnOo^/_W00Co^/_W1onG^Nl5
oi6bk@03oj2hjOnX`>_oZ<3[00CoZ<3[1_n^`^P2ojk0i`KoYk[V1_nQ]nP00onV_^_o[/S]ojk8k@05
ojk8k@;o]=Ob1ongdnl3oj_5k@?oUJSS1?mmTM`00on3XNKoIh[QofN:h@03ofN:h@GoJhcP1onH/NP0
0onoc>CoamOVolOGiP03olOGiPCob]oX0oo2f>X5ok_Ek@KoZ/?/2?nW_n/6ojW1j`03oj[2k?nW`>_o
Yl3[00GoYl3[1OnV_^/2ojJoj`CoZ<3[00?o0000ojS0jonX`>/00onY`N/4ojS1k0koYko[3oooool0
0ol0003oooooooooo`07ooooo`005?ooool2o`0001Gooooo0ol0000Aooooo`GoZ<3[2?nX`N/6ojO0
j`;oY[o[1onW_n/3ojS1j`CoZL7[1onX`N/6ojFnj`SoZ<3[00?oZ<7[ojFok?nU_n`00onU_n`5ohna
k@GoP:?Z1on2WnH5oj6hj@Co]/SX00?od>3SomOOgOoGgmd01?oGgmd5omGHfP03om3?fOnjbnOo^/_W
00Go^/_W0onG^Nl4oi6hl@GoSkOa1onX`>/2ojk2j0Ko[/3W1_nW^^H2oj6gj0GoY[k[1?n^b>d5okCG
lPGo]m?_00?o[<C/oiFXhonEZ><01OnEZ><4ogfAg0CoKXGI0_mWR^45of^<h0GoV;7X0onW_>P3olOG
iPKob]oX00?o`]SZok_EkOnkeNd01OnkeNd2oj[3k0coYko[0_nY`N/5oj[2k0OoYl3[00?oY[k[ojJo
jonV_n/01?nV_n/4ojS0j`03o`000?nY`N_oZL7[00OoZ<7/3_nW_n/>ooooo`03o`000?oooooooooo
00Oooooo000Dooooo`03o`000?oooooooooo01;ooooo0_l0000Eooooo`03ojS0jonX`N_oZ<7[00[o
Z<7[0_nW`>/6ojJoj`GoYko[0_nX`>/7ojW1j`GoZ<7[0_nV_n`6ojFnj`SoZ<3[1_nU_n`5ohnak@Go
P:?Z1on2WnH00onQ^>Wo]/SXokK8j004okK8j0?ob<oP1?oGgmd5omGHfP?od<oI1OnjbnL2ok72i`Oo
TKSa1On?]o45ojS0j`;oZ<K_2?n^`>L3ojNjiP?oYkoZ1onV_^/00on^b>go]=ObokCGlP06okCGlP03
okOCkon/a>co[<C/00?o[<C/1_nEZ><5ogfAg0GoKXGI1?n2V>02of^<h003oiRaj?nW_>SoYkcX00Go
YkcX00?oamOVol[Oj?o:gnP01?o:gnP2olKPk0Ko^mG]0_n_b^d<ojNoj`03ojS0jonZ`^coZ/;/00Ko
Z/;/0onW`>/3ojJnj`SoY[o[00GoZ<3[ojW1jonY`N_oZL7[o`000002ojW1j`OoZ<7/3?nW_n/00onX
`>_oooooooooo`0<ooooo`03o`000?oooooooooo00Oooooo000Dooooo`03o`000?oooooooooo00oo
oooo0ol0000Hooooo`[oZ<7[1?nX`>/7ojJoj`03ojNojonX`>_oZ<3[00CoZ<3[1onY`N/00onX`N_o
Y[o/ojJok004ojJok0KoYKk[2?nX`>/6ojFok0GoSk7]1On0XnX3oh:OiPCoTjgX1Onfb>P6olS?h003
omOOgOoEf=[oeMSJ00?oeMSJ1Oo@cmT00onjbnOo/L;Wok72i`04ok72i`OoTKSa1On?]o400onX`>_o
Z<K_ojS6k`04ojS6k`Ko[/3W00?oZLO_ojNoj_nW_nX01OnW_nX5ojJnj`?o[=Gf1_ndeo800onad?3o
[<C/ojc4k005ojc4k0GoUJSS1_mmTM`5ofj5f@GoPYSP1onW_>P2okW=j@Cob]oX1Oo6h>`2ok_Ek@Ko
[l[]2?nW_n/5ojS0j`KoZ/;/00?oZ<7/ojJnjonV_^/01OnV_^/6ojJoj`03ojNojonY`N_oZL7[00;o
ZL7[00Co0000ojW1jonY`N_oZL7[0onX`N`<ojNoj`GoZ<3[3Oooool00ol0003oooooooooo`07oooo
o`005?ooool00ol0003oooooooooo`0<ooooo`?o00007?ooool8ojS1j`KoZ<3[2?nV_n/6ojS0j`Oo
ZL7[1onV_n`3ojFnj`CoYko[1onX`>/3ojFok0;oVk_^1On3Z^h6ogNOj`OoTjgX0onfb>P6olS?h0?o
dM7H0ooEf=X6om3?f@03olc7e_na`^Oo/L;W00Go/L;W0onA^?44oi2ilPGoSKcf1onXa^l2ojk0i`Go
ZLO_1onW_nX00onV_^_o[=GfojcEmP05ojcEmP;o]=Ob1Onad?07ojc4k0GoUJSS1OmmTM`6ofj5f@Go
PYSP1?nW_>P5okW=j@03ol[Oj?o6h>coa^3/00Coa^3/0_nnfnh8ojo:k@KoYko[1onX`>/2oj[2k0Go
Z<7/1onV_^/2ojJoj`GoYko[1?nY`N/00ol0003oZL7[ojW1k00>ojNoj`OoZ<3[3?ooool00ol0003o
ooooooooo`07ooooo`004oooool3o`0000[ooooo0ol0000Pooooo`SoZ<7[1_nX`>/8ojJoj`KoZ<3[
1onY`N/5ojJok0?oYKk/1_nW_n/7ojS0j`GoVk_^1On3Z^h6ogNOj`OoTjgX00?o]/SXolS?h?o8cn00
1?o8cn05om7Af003omGHf_o@cmWod<oI00Cod<oI0oo<amH5ok72i`;o/KcR1on@^O85ohflmPGoZ<K_
0_nLb_L7ojW7k`GoYkoZ0onTdoP5ojcEmP?o[=Ce1_nad?03ojc4k0?oV9oI1On9T]H4og^7d`;oOI7L
1Om^QMT6oh:Hh003ojNlj?nicNWo^LgY00Co^LgY0oo6hN`3olKPk0Go_]_^1_n_b^d00onX`NcoYko[
ojNoj`05ojNoj`GoZ<3[0_nY`^`7ojS1k0KoY[k[2?nW_n/2ojW1j`;oZL7/00?o0000ojW1k?nY`N`0
3_nW_n/7ojS0j`_ooooo00?o0000ooooooooool01oooool001Cooooo00?o0000ooooooooool01_oo
ool3o`0002Gooooo1onX`N/3ojS0j`CoYl3/1onV_n/3ojS0j`?oZ<7[1onY`N/00onV_ncoYKk/ojFn
k005ojFnk0KoYko[1onX`>/5oi^kkPGoPj[^1_mgWn/5oi>]j0;oZ;gX1Oo8cn05om7Af0;odlgC1Oo@
cmT5olc7eP03ok72iona_>;o/KcR00Co/KcR1on@^O85ohflmP03ojS6konLb_OoW<[g00CoW<[g1onY
anl00onW_n[oY=?hojCCn005ojCCn003ojcEm_n/e?Go[=Ce00Go[=Ce0onad?02ojJ_gPOoV9oI1On9
T]H5og^7d`CoOHgH0_m^QMT3oh:Hh0?oVJkV1OnicNT5olKQk003olKPk?nnfnko_]_^00Go_]_^0_n_
b^d5ojS1k0OoYko[00?oZ<3[ojW2k?nY`^`01?nY`^`5ojS1k003ojJojonV_^_oY[k[00GoY[k[1_nW
_n/00onX`N_oZL7/ojW1k002ojW1k003o`000?nY`NcoZL7/00ooYko[0onX`>/3ojS1j`_ooooo00?o
0000ooooooooool01oooool001Cooooo00?o0000ooooooooool00oooool3o`0002Wooooo1OnX`N/0
0onX`>_oYl3/ojO0k006ojO0k0GoY[o[0_nW_n/6ojS1j`GoZL7[0onX`N/7ojFnk0?oYko[2_nX`>/5
oi^kkPGoPj[^1_mgWn/00onC[NSoZ;gXojRmj004ojRmj0?ob<oP1OoAdMP4om?=d`?od<oI1_o<amH8
ok6lhP?oT;Wb1?nG^Nl6oh^on0KoW<[g0onYanl4oi_@nPKoY=?h0onTd_L5ojcDm@03ojVghonV[mko
YZoN00CoYZoN1onHWmT4ohVBePKoNhOC1OmmSMP7oiV^iP?o^LgY1Oo6hN`2olGVkPKo_]_^00?o/lo_
ojS1k?nX`N`01_nX`N`6ojNoj`SoZL;/00?oZ<7/ojJojonV_n/00onV_n/7ojJnj`;oYko[1OnX`N/4
ojW1k003o`000?nY`NcoZL7/00koYko[1onX`N/;ooooo`03o`000?oooooooooo00Kooooo000Coooo
o`04o`000?ooooooooooooooo`?o0000;Oooool00onX`N_oZ<3[ojS0j`03ojS0j`SoYl3/00?oY[o[
ojNojonW_n/01?nW_n/6ojS1j`03ojW1jonX`N_oZ<7[00GoZ<7[1_nU_^`<ojS0j`;oYl3/1_n@]_44
ogRVk`KoNZ?/1onX_NP00oo8cn3odM7Hom7Af003om7Af0KodlgC00?od<oIolc7e_o<amH01?o<amH2
olRod@Ko/KcR0_nf]mX7oiNik`KoRkoh0onLb_L4oi78nPKoVm3j0_nTdoP7ojCBm`03ojcDmOnY]n?o
ZKOS00?oZKOS1_nV[mh6oiROf@GoRI;F1_mkQm<5ogf=f0OoVJkV00?o^LgYolKQk?o6hN`00oo6hN`4
olGVkP;o_]_^1Onccnl6ojS1k003ojJojonW_n_oYko[00GoYko[1onY`^`7ojJoj`GoY[k[0_nW_n/7
ojS1j`?oZL7/00?oYl3[o`000?nW`>/03onW_n/7ojS1j`[ooooo00?o0000ooooooooool01_ooool0
01?ooooo1?l0000booooo`GoZ<3[1_nW`>`2ojJok0OoYko[0onX`N/3ojW1j`SoZ<7[1_nU_^`8ojS0
j`KoYl3/1_n@]_44ogRVk`KoNZ?/1OnX_NP3okG4i@?odM7H1_oCcM<2om;7d0Goc<OF1?o8_m43ok6l
hPGo][OJ1onG^Nl3oh^on0CoTkgd1_nAb?X3oi_@nPCoWL_g1_nTd_L00onX]nCoZKOSojVgh`05ojVg
h`GoYZoN1onHWmT4ohVBePKoNhOC1OmmSMP6oiV^iP;o[LG/0oo6hN`5olGVkP;o_Mk`1onccnl2ojS1
k0GoY[o[1onW_n/7ojW2k0OoY[o[00?oY[k[ojNojonW_n/01?nW_n/5ojS1j`;oZL;/1?nW`>/00ol0
003oYl3[ojNoj`0>ojNoj`KoZ<7[2_ooool00ol0003oooooooooo`06ooooo`004oooool2o`0003Go
oooo1OnX`>/2ojO0k0KoY[o/1OnW_n/2ojS0j`KoZL7[1_nX`N/2ojO0k0KoYKk/1onX`>/7ojO0k0Ko
T;Ka1?mhY^l6ogZSk003ojRmj?nea>Go]LCU00Go]LCU00?odM7Hom?=dooCcM<01?oCcM<4om;7d0?o
c<OF1_o8_m400ona_>;o][OJokJgfP05okJgfP?oUkW_1?nT[n07oi>mm0?oTLSj1?nL_o46oig;m`;o
Y=;g1OnX]n@7ojVgh`GoYZoN0onHWmT3oi6?cPCoQXW?00?oRI;Fog^7domkQm<01?mkQm<5ogf=f0;o
VJkV1_n]aN`00oo6hNcoaNK^olGVkP02olGVkPGo_Mk`1Onccnl2ojS1k0KoY[o[1_nW_n/9ojW2k0?o
Y[o[0onV_^/8ojNoj`03ojS1jonY`^coZL;/00CoZL;/0onW`>/00ol0003oYl3[ojO0j`0=ojNoj`So
Z<7[2Oooool00ol0003oooooooooo`06ooooo`001Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02?ooool00ol0003oooooooooo`0cooooo`KoZ<3[1onV_n`00onW_n_oZ<3[ojS0j`04ojS0j`Ko
ZL7[0_nX`N/6ojO0k0KoYKk/1onX`>/5ojO0k0;oY;o]1On5/O84ofjSl@04ogRVkomjXncoNZ?/ogZS
k0?oQZg^1_nea>D2okk6h@GodlgC1_oBam000oo<amKob;oAolRod@04olRod@03olNicOnf]m[o][OJ
00Go][OJ00?o_;7@ojB_h?nT[n001_nT[n05oi>mm0;oXjkO1onL_o43oig;m`?oYZoN1_nX]n@6ojVg
h`03oinJc_nIULkoVIG>00?oVIG>1_nASlh5ohJ9c`KoPhgE1_nFZN<6ojg5k0Co`>?`00?oaNK^okgN
l?nmg_001Onmg_000onccnooZ<7/ojS1k004ojS1k0KoY[o[0_nW_n/;ojW2k003ojNojonV_^_oY[k[
00GoY[k[1_nW_n/00onX`>_oZL;/ojW2k006ojW2k0?oYl3[00?o0000ojNojonW_n/02OnW_n/<ojS1
j`Sooooo00?o0000ooooooooool01_ooool00005oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Wooooo00?o0000ooooooooool0<oooool6ojS0j`OoY[o/1onX`>/7
ojW1j`OoYl3/0onU_^`3ojJoj`OoZ<3[00?oYl3/ojBokOnT_nd01?nT_nd5ohFalPGoKZ?a1_n6[Nh3
okG4i@Go_/KQ0ooCcM<7om;7d003olo2cOo8_m7ob;oA00?ob;oA0oo7^Ld5okJgfP?o_;7@2?nT[n00
0onC_OCoXjkOoj>^g`04oj>^g`GoW;oa00?oYjKEojJ_g_nV[mh01OnV[mh6ojRgi0;oZKOS1OnOV/h5
oiVEcPKoTHo>1On6RLl6oh>=e@KoUZWS0on]aN`5ol3Sl0;o`NWa1_nmg_000onbcnooZ<7/ojS1k006
ojS1k0?oY[o[0onW_n/9ojW2k0GoYko[1onV_^/2ojNoj`GoZ<3[1_nY`^`00onX`N_oYko[ojNoj`02
ojNoj`03o`000?nW_n_oYko[00KoYko[3OnX`N/00onW`>_oooooooooo`06ooooo`03o`000?oooooo
oooo00Kooooo00001?ooooooV9RHob4Q8Oo^k^h4ooooo`05oa0@4?ooooooooooooooool@41002_oo
ool00ol0003oooooooooo`0cooooo`KoZ<3[1onV_n`8ojS0j`KoZL7[1OnW`>`2ojJok0KoY[o[2?nX
`>/6ojBok@GoQK7b1Om^Xo46ohJ]kP03okG4iOnna^7o_/KQ00Go_/KQ00?odlgCom;7d?oBam001OoB
am03olo2c@?ob;oA1Oo7^Ld3okJgfPGo_;7@1_nT[n000onbZ]3oXjkOoj>^g`06oj>^g`03oibolOnW
Y]GoYjKE00?oYjKE1onV[mh3ojRgi0;oY9c=1onOV/h5oiVEcPKoTHo>1On6RLl6oh>=e@OoUZWS00?o
[LG/ol3Sl?o0ho000_o0ho05ol7Yl@;o_Mk`1Onbcnl6ojS1k0SoYko[1onY`^`7ojNoj`?oY[k[0onW
_n/8ojS0j`;oZL;/1OnX`N/4ojNoj`03o`000?nW_n_oYko[00KoYko[2OnX`N/5ojO0j`Oooooo00?o
0000ooooooooool01_ooool000;ooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooo
oooo000000_ooooo0_l0000dooooo`?oZ<3[0onW`>/7ojJok0SoZ<3[1_nY`N/00onW`>coY[o/ojJo
k004ojJok0KoY[o[2?nX`>/6ojBok@GoQK7b1Om^Xo43ohJ]kP?oTKG_1_nna^43ol;6g@God/O@1Oo?
`/d00oo8_m7oakW=olNic@05olNic@03okJgf_nl/M3o_;7@00Go_;7@0_nT[n05ok:Zd0KoXjkO00?o
/:G=ojNVeOnWY]D01OnWY]D5ojJ_gP03ojRMb_nTW<goY9c=00CoY9c=1onOV/h5oiVEcPGoTHo>1_n6
RLl5oh>=e@KoUZWS0onZanl00oo0ho3o`NWaol7Yl@04ol7Yl@;o^Moc1onbcnl2ojS1k0coYko[1onY
`^`5ojNoj`;oY[k[1_nW_n/6ojS0j`03ojS2k?nX`N_oZ<7[00KoZ<7[0onW_n/00ol0003oYko[ojNo
j`07ojNoj`?oZ<7[0onX`N`8ojO0j`Oooooo00?o0000ooooooooool01Oooool000?ooooo00?oMgMg
ofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool0<_oo
ool6ojO0j`SoY[o/1onX`>/6ojW1j`OoY[o/1onV_n/7ojS0j`?oY;o]0onP_^h5ogj_l`GoIj?c1_nA
]Nl3okk6h@Ko`/KM0ooBam06olo2c@OoakW=00?oa[C9okbad?nl/M001Onl/M000onmZlSo/Z[@ok:Z
d005ok:Zd0CoXjkO1?n`YLd7ojNVe@03ojJ_g_nXWL[oZ9g:00?oZ9g:1_nTW<d6oinJcPGoVIG>1_nA
Slh5ohJ9c`KoPhgE0_nFZN<5oj[7k`?o^nWd0oo1jO45okWOl`Go//o_0_nX`>/:ojNoj`_oZL;/00?o
Yko[ojJnjonV_^/01?nV_^/6ojNoj`;oZ<3[1OnX`^`6ojS1j`GoYko[00?o0000ojNojonW_n/01OnW
_n/2ojS1j`KoZ<7/1_nW`>/00onW_n_oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo0004
ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`0<ooooo`03o`000?oo
oooooooo03;ooooo1_nW`>/8ojJok0OoZ<3[1_nY`N/5ojJok0?oYKo/1_nV_n/5ojS0j`;oZL3[1_nP
_^h5ogj_l`GoIj?c1_nA]Nl00onna^7o`/KMol;6g@06ol;6g@03om;7d?o?`/gocl;=00Cocl;=0_o=
_l`5olNic@?oa[C91Onl/M03okf[b0Oo/Z[@00?oXjkOok2UcOn`YLd01On`YLd5ojNVe@03ojfMaonX
WL[oZ9g:00CoZ9g:1_nTW<d7oinJcPGoVIG>1OnASlh6ohJ9c`?oPhgE1?nJ[^D3oj[7k`Ko^nWd00?o
`NWaokWOlonigo<01Onigo<00onbcnooZ<3[ojS0j`04ojS0j`OoYko[3?nY`^`00onW_n_oY[k[ojJn
j`06ojJnj`?oYko[0onW`>/7ojS2k0;oZ<7[2OnW_n/01?l0003oYko[ojNojonW_n/6ojS1j`KoZ<7/
0_nW`>/5ojNoj`Kooooo00?o0000ooooooooool01Oooool00005o`000?nj^[[ooooooiRHV?l@4100
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00oooooo00?o0000ooooooooool0<_ooool3ojO0j`Co
Yl3/1onV_n`7ojS0j`KoZL7[00?oY[o/ojFok?nU_n`01OnU_n`6ojJoj`03ojS0jonY`>_oZL3[00Co
ZL3[1_nP_^h5ogj_l`GoIj?c0onA]Nl3oiNkl@Oo`/KM0_o2aM`5olo2c@CocKo<0oo7^Ld5olJdb@?o
_;7@1OnmZlP5ok:Zd003okNUaon`YLgo/:G=00Ko/:G=0onWY]D4ojfMa`KoZ9g:1_nTW<d3oinJcP?o
W9;81OnFSlX5oi2@c`OoSiSH1onJ[^D00onZanoo^nWdok_Ym006ok_Ym0Ko^Moc00?o[/_^ojS0jonX
`>/01_nX`>/7ojNoj`SoZL;/1OnW_n/6ojJnj`03ojNojonW`>_oYl3[00GoYl3[1OnX`^`00onX`N_o
Yko[ojNoj`0:ojNoj`03o`000?nW_n_oZ<7[00OoZ<7[0onX`N`2ojO0j`SoYko[1Oooool00ol0003o
ooooooooo`05ooooo`0000GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h04?ooool2o`0003Cooooo1_nW`>`5ojJok0;oY[o[1onX`>/6ojW1j`SoYKo/0onV_n/3ojNo
j`OoZL3[0onP_^h3oijmk`GoNZoe1OmRY?D6oiNkl@Co`/KM1Oo2aM`3olo2c@KocKo<00?oakW=olJd
bOo6]<T01Oo6]<T00onl/M3o_J_8okf[b004okf[b0?o/Z[@1?ngYLL8ok2Uc@03ojNVeOn]WLOo[Ig7
00?o[Ig71_nXWLX5ojBLc@03oj>Ea_nLT/SoW9;800CoW9;81_nFSlX5oi2@c`OoSiSH1OnJ[^D3ojgF
m@So^nWd0_nigo<5ojk;kPKoZ<3[2OnW_n/6ojW2k0OoYko[0_nV_^/5ojNoj`OoYl3[00?oZ<;/ojS1
jonX`N/00onX`N/;ojNoj`03o`000?nW_n_oYko[00KoZ<7[00?oZ<7/ojO0jonW`>/01?nW`>/7ojNo
j`Gooooo00?o0000ooooooooool01Oooool001oooooo00?o0000ooooooooool0<_ooool6ojO0k003
ojJok?nV_n_oY[o[00CoY[o[1OnX`>/2ojW0j`KoZL7[1_nU_n`2ojBok0KoYko[1onY`>/6oijmk`Go
NZoe1OmRY?D6oiNkl@03ol;6gOo2aMco`/GL00Ko`/GL00?ocl;=olfoc?o=_l`01Oo=_l`8olJdb@So
_J_800?o/Z[@okNUaongYLL01?ngYLL6ok2Uc@03ok:OaOn]WLOo[Ig700Go[Ig71_nXWLX00onTW<go
XiG6oj>EaP03oj>EaPKoW9;81OnFSlX6oi2@c`OoSiSH00?oVZkUojgFmOn]e_D01On]e_D6ok_Ym0?o
]M[c1_n^bnh2ojS0j`_oYko[00?oZL?/ojW2k?nY`^`01OnY`^`5ojNoj`;oY[k[1onW_n/3ojO0j`?o
Z<;/1onX`N/;ojNoj`03o`000?nW_n_oYko[00;oZ<7[1OnX`N`6ojO0j`OoYko[1?ooool00ol0003o
ooooooooo`05ooooo`008?ooool00ol0003oooooooooo`0booooo`?oYl3/0onV_n`7ojJoj`03ojS0
jonY`>_oZL3[00CoZL3[1_nY`N/2ojFok0KoY;o/1_nW_n/7ojW0j`KoW[g_1Omj[oD5of:Tm@?oUk_a
0_nF__<8ol;5g003okk5h?o=_lcocKo<00GocKo<0_o;`=08olJdb@Ko_J_800?o_jc6okNUaongYLL0
1OngYLL4ok2Uc@Co/Yo51_n]WLL5ojRMbP03ojRIa_nSULKoXiG600CoXiG61_nLT/P6oiJ?bPGoT93?
1_n?V=P2oj:nk@Ko[MKe0onfk_H00onkjOCo]M[cokGJl`05okGJl`?o[/_^3?nW_n/5ojW3k0OoZL;/
00?oYko[ojJnjonV_^/01?nV_^/5ojNoj`03ojO0jonX`^coZ<;/00GoZ<;/1OnX`N/=ojNoj`03o`00
0?nX`N_oZ<7/00OoZ<7/0onW`>/:ojNoj`?ooooo00?o0000ooooooooool01Oooool0027ooooo00?o
0000ooooooooool0<_ooool6ojJok0GoY[o[0onW_n/6ojW0j`?oZL7[1?nX`>/7ojBok0?oYko[0onW
`>/7ojW0j`KoW[g_1Omi/OH5oejVm`GoU[kc1_o2aM`3okk5h0GocKo<1?o;`=08olJdb@Co_J_80ono
[<H7okNUa`03ok2UcOnbWlGo/Yo500Co/Yo51on]WLL00onXWL[oZ9W6ojRIaP03ojRIaPKoXiG61OnL
T/P6oiJ?bPKoT93?0_n?V=P6oj:nk@;o[MKe1Onfk_H3okCSm`Go]M[c00?oZ/?/ojNojonW_n/02_nW
_n/2ojO0k0OoZL?/0onY`^`3ojNoj`SoY[k[00?oYko[ojO0jonW`>/00onW`>/7ojS2k003ojS1jonW
_n_oYko[00coYko[0_nX`N/00ol0003oZ<7[ojS1j`06ojS1k003ojO0jonW_n_oYko[00_oYko[1?oo
ool00ol0003oooooooooo`04ooooo`008_ooool00ol0003oooooooooo`0booooo`KoY[o/00?oY[o[
ojNojonW_n/01OnW_n/7ojW0j`KoZ<3[1onT_n`6ojO0j`OoZL3[1_nN_Nl5ogVamPGoGZKg1OnF__<3
ol;5g0Ko_/GP0oo=_l`5ol_0d0Soa[C90onmZlP4okn/aPKo]jG700?o^ZS7ok:OaOnbWlD01OnbWlD6
ojfMa`03ojnOaonXVLKoZ9W600CoZ9W61_nSULH6oibBb0KoUXo:0on@T<l3oij_i0KoX[k]1?n]jOT0
0onfk_Ko]>?gokCSm`05okCSm`03okGJlonZ`ncoZ/?/00?oZ/?/2?nW_n/6ojO0k0GoZL?/0_nX`N`6
ojNoj`KoY[k[00?oYko[ojO0jonW`>/01OnW`>/3ojS2k0?oZ<7[3_nW_n/4ojS1j`03o`000?nX`N_o
Z<7[00;oZ<7/1OnW`>/=ojNoj`?ooooo00?o0000ooooooooool01?ooool002?ooooo0_l0000coooo
o`OoY[o/1onW_n/7ojW0j`KoZ<3[1onT_n`6ojO0j`OoZL3[1_nN_Nl5ogVamPGoGZKg1OnF__<00oo2
aMco_/GPokk5h006okk5h003olfoc?o;`=3obl3@00Gobl3@2?o6]<T00onmZlSo_jc6okn/aP04okn/
aPCo]jG70onjZ<L7ok:Oa@?o[Ig70on_WlL7ojRIaPGoXiG61_nLT/P3oiJ?bP?oW:KM1onN[n@3oj:n
k@Go[NWi0_naj_P6okCSm`03ojo=l?nZ`ncoZ/?/00GoZ/?/1onW_n/7ojO0k003ojW3k?nX`NcoZ<7/
00CoZ<7/1_nW_n/2ojJnj`GoYko[1OnW`>/2ojS2k0KoZ<7[3_nW_n/3ojS1j`03ojS1k?l0003oZ<7/
00SoYl3[3OnW_n/2ooooo`03o`000?oooooooooo00Cooooo000Uooooo`03o`000?oooooooooo03;o
oooo1_nV_n`5ojNoj`;oYl3[1onY`>/6ojS0j`OoY;o/1_nW`>/7ojW0j`?oW[g_1?nP_Nh5og^cm`Co
FjSh1On<_oP7okk5h003okK8j?o;`=3obl3@00Gobl3@00?oa<?IolJdbOo6]<T01Oo6]<T00oo5_M;o
_jc6okn/aP05okn/aP?o]jG71?njZ<L7ok:Oa@03ojfMaon_WlOo[io700Co[io71_nXVLH6oj>EaP?o
W9;80_nPXmP7oibVg@OoWZoT00?oX[k]ojgYnOn]jOT00_n]jOT5ok7Zn0;o]>?g1On_cO05oj[3k0Wo
Yko[0onW`>`3ojW3k0SoZ<7/0onW_n/2ojJnj`SoYko[00?oYl3[ojS2k?nX`^`01?nX`^`6ojS1j`co
Yko[0_nX`N/4ojS1k003o`000?nX`NcoYl3[00GoYl3[3OnW_n/01?nX`N_oooooooooool00006oooo
o`009_ooool00ol0003oooooooooo`0booooo`KoY[o/00?oYko[ojO0jonW`>/01?nW`>/7ojW0j`Ko
Z<3[1onT_n`6ojO0j`OoZL3[1onP_Nh5og^cm`CoFjSh1On<_oP4okk5h0Co]/SX1Oo;`=03olC3f@Go
a[C90oo5_M87okn/aP03okNUaonjZ<Oo^ZS700Co^ZS71OnbWlD00onfZ/go[io7ojnOa`05ojnOa`Ko
Z9W61OnSULH00onVY]KoX:?Hoj2Sf004oj2Sf0KoW:KM1_nN[n@3ojCMn`03ojgYnOnaj_So/N[h00Co
/N[h0on`eo@6ojo=l003oj[3k?nW_n_oYko[00WoYko[0_nX`^`6ojW3k0KoZ<7/00?oYkkZojJnjonV
_^/01?nV_^/6ojNoj`03ojS1k?nX`^coZ<;/00KoZ<;/0onX`N/;ojNoj`KoZ<7[0onX`N`00ol0003o
Z<7/ojS1k002ojO0j`goYko[1OnX`N/00ooooooo0000ooooo`05ooooo`009oooool00ol0003ooooo
ooooo`0booooo`KoY[o/1onW`>/7ojW0j`KoZ<3[1onT_n`6ojO0j`OoZL3[1OnP_Nh2ojBnk0GoP[Gf
0omLZoT00omKZ?SoS;ohohbon003ohbon003okk5h?nfb>So]/SX00Go]/SX0oo;`=05olC3f@?oa[C9
1?o5_M86okn/aP03ol:idOnjZ<Oo^ZS700Go^ZS70onbWlD4okJZc@Ko[io71onXVLH00onSULKoYZKF
ojJVeP03ojJVePKoX:?H1_nLY]d2oij_i0GoY=gk1?nWk?T00onaj_So/=Odok3Gm005ok3Gm0?o[lg`
2onW_n/6ojS2k0KoZL?/0_nX`N`5ojNnjPKoY[k[0_nW_n/5ojS1k0KoZ<;/00?oZ<3[ojNojonW_n/0
2onW_n/8ojS1j`?oZ<7/00?o0000ojO0jonW_n/03_nW_n/6ojS1j`03o`000?oooooooooo00Cooooo
000Xooooo`;o0000<oooool6ojJok0OoYl3[1onY`>/6ojS0j`OoY;o/0onW`>/3ojO0k0OoZL3[00?o
X;g^ojBnk?nT_^`01?nT_^`5oh:emPGoG:_i1Omf_?`7okK8j003ol_0d?o4`mWoa<?I00Goa<?I00?o
a[C9olFmd_o5_M801?o5_M84okn/aP?o`[WA1onjZ<L00onbWlGo]Z[=okJZc@03okJZc@Oo[io71OnX
VLH00on/[MSoYZKFojJVeP05ojJVePKoX:?H0onLY]d5oj?Bn003ojCMnonWk?WoYnci00CoYnci0_n/
g_T6ok3Gm003ojW1jonW_n_oYko[00[oYko[00?oYl3/ojS2k?nX`^`01_nX`^`3ojW3k0?oYko[1onW
_^X3ojJnj`CoYko[1_nX`N`2ojS2k0GoZ<3[3OnW_n/6ojS1j`03ojS1k?nW`>_oYl3[00;oYl3[00?o
0000ojO0jonW_n/03_nW_n/3ojS1j`;ooooo00?o0000ooooooooool01?ooool002[ooooo00?o0000
ooooooooool0<Oooool6ojJok0OoYl3[1onY`>/6ojS0j`OoY;o/1_nW`>`5ojW0j`;oZ<3[1onT_^`5
oh:emPGoG:_i1Omf_?`3okK8j0CoY/ke1_o4`mT00onfbn[oaKgBolFmdP05olFmdP?o_jc61Oo2^M45
okZXa`03okbjf?nfZ/go]Z[=00Go]Z[=1_n_WlL2ojRIaPGo[:gH1_nVY]H5oj2Sf0?oY<gf1OnSd_P4
oicZnP03ojO/nOn/g_Wo[=ki00Co[=ki0_n`eo@5ojW1j`SoYko[1OnW`>`7ojS2k0OoYko[1OnW_^X0
0onW_^_oYko[ojNoj`06ojNoj`?oZ<7/0_nX`^`8ojS0j`goYko[0_nX`N/5ojS1k0CoYl3[00?o0000
ojO0jonW_n/03?nW_n/7ooooo`03o`000?oooooooooo00?ooooo000[ooooo`03o`000?oooooooooo
037ooooo0onV_n`3ojFok0OoYl3[1onY`>/6ojS0j`OoY;o/1_nW`>`00onY`>_oZ<3[ojS0j`04ojS0
j`GoY;k/0_nW_n/6ohjil`GoI[7j1OmJ/o/6ojK>m@?oa<?I1?nfbnX7olFmdP03okn/a_o2^M7o`[WA
00Co`[WA0onjZ<L4okbjf0Ko]Z[=1On_WlL00ona]mgo[:gHojb]f005ojb]f0OoYZKF00?oX:?HojC=
m_nTcOH01OnTcOH00onSd_SoW>[joicZnP04oicZnP;oY^7k1On/g_T2ojW4k@OoZL7[1_nW_n/7ojO0
k0OoZ<;/1onW_n/00onW_^[oYkk[ojNnj`03ojNnj`KoYko[1onX`^`6ojS0j`goYko[2OnX`N`3ojO0
j`03o`000?nW_n_oYko[00WoYko[2_ooool00ol0003oooooooooo`03ooooo`00;?ooool00ol0003o
ooooooooo`0aooooo`KoYKo/1onW`>/7ojW0j`OoZ<3[1_nT_n`3ojO0k0CoY/3/1_nX`>/00onT_^co
Yko[ojNoj`04ojNoj`KoS[Wc1OmV/OX6oeZcn`GoY/ke00?oa<?IokK;j_nfbnX01?nfbnX5olFmdP;o
^LOU1oo2^M400onjZ<Oo_;[Hokbjf004okbjf0Ko]Z[=00?o[io7ok6ggOna]md00ona]md7ojb]f0?o
YZKF1?nUc_D6ojC=mP?oT^Oj0_nLj_X6ojKQn`03ojcNnOnYa>goZLC]00CoZLC]1OnY`N/8ojNoj`Go
Yl3/0_nX`nd7ojS2k0?oYko[0onW_^X7ojNnj`;oYko[2onX`^`2ojS0j`goYko[2onX`N`00onW`>_o
Yko[ojNoj`02ojNoj`03o`000?nW_n_oYko[00GoYko[3Oooool00ol0003oooooooooo`03ooooo`00
;Oooool2o`0003;ooooo1_nU_n`7ojO0j`GoZL3[0_nY`>X7ojS0j`?oY;o/0onU_n`7ojK0k0KoZ<3[
1onW_n/3ohjil`?oVkc_1_mh]oX6oeB_nPGoOlWo1_nfbnX00oo5_M;o^LOUokW7i@04okW7i@Go`[WA
00?o]L[Zokbjf?nl^]P01Onl^]P5okJZc@03ok73iona]mgo/KOM00Go/KOM1On/[MP2ojCCn0OoYLke
0_nTcOH5oi;WnPCoX>3l0onVhO/4oj[7k`KoZLC]00?oZL7[ojNojonW_n/02_nW_n/00onW`>coZ<?]
ojS3k@04ojS3k@GoZ<;/2?nW_^X5ojNnj`;oYl3[2_nX`^`AojNoj`SoZ<7/1OnW`>/4ojNoj`04o`00
0?nW_n_oYko[ojNoja3ooooo00?o0000ooooooooool00oooool002oooooo00?o0000ooooooooool0
<?ooool7ojFok0KoYl3[00?oZL3[ojW0j_nY`>X01?nY`>X5ojS0j`?oZL3Z1OnU_n`7ojK0k0KoZ<3[
1OnW_n/2ojS0j`KoVkc_1_mh]oX6oeB_nPGoOlWo0onfbnX3oiKDo@Oo^LOU00?o`[WAokG:j_neb^X0
0oneb^X7okbjf003okJZcOna`nOo/L?W00?o/L?W1ona]md00on/[MSoY=?hojCCn004ojCCn0GoYLke
1?n9i?X00onBio[oX>3loj3Po004oj3Po003ojS9lOnZanooZ/O_00KoZ/O_0onYa>d=ojNoj`[oZ<?]
00?oZ<;/ojNnj_nW_^X02_nW_^X00onW_^_oYl3[ojO0j`04ojO0j`GoZ<;/00?oZ<7[ojNojonW_n/0
4onW_n/3ojS1k0;oZ<7[2?nW`>/3ojNoj`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
0oooool0033ooooo00?o0000ooooooooool0<Oooool6ojFok0OoYl3[1_nY`>X00onX`>_oZL3ZojW0
jP05ojW0jPGoYKo/1onV`>`6ojS0j`03ojNojonX`>_oZ<3[00CoZ<3[1_nK_>l3ogRgnPCoRkWd1OmV
]o`6oeJin`GoU]Cm1OnianD2oiWIo@Ko]L[Z1Onl^]P2oj[DmPKo/L?W1Ona]md3oikKo0KoY=?h00?o
YLkeohWTn_n9i?X00on9i?X5oi[No@03oj3Po?nXbO7oZ<Wa00?oZ<Wa1_nZanl00onW_n[oYko[ojNo
j`0:ojNoj`03ojO1k?nX`ngoZ<?]00SoZ<?]0onW_n/;ojNnjP?oYko[1onW`>/00onX`^coZ<7[ojS1
j`03ojS1ja?oYko[00?oZ<7/ojS1jonX`N/01?nX`N/6ojO0j`Gooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`03ooooo`00<Oooool00ol0003oooooooooo`0aooooo`CoYKo/0onV_n`6
ojO0j`CoZL3Z0onY`>/7ojW0jP;oYKo/1?nV_n`6ojK0k0?oZ<3[0onX`N/7ojS0j`?oVkc_1?nU_^`6
oh^im0GoI[Ol1_mF^O/5oiKDo@03okW7iOnIfOgoVMWm00CoVMWm1_neb^X00onl^]SoZ]Cfoj[DmP04
oj[DmPKo/L?W00?o/KOMoikKo?nNfo`01OnNfo`3ojCCn0CoP>3j0_nEfoh6oi[No@;oY/Sa1_nXbO42
oj[7k`GoYkoZ2?nW_n/5ojO1k0GoZ<?]0_nX`N/6ojNoj`KoYkkZ00?oYkk[ojNojonW_n/01OnW_n/3
ojO0j`?oZ<;/1onX`N/?ojNoj`GoZ<7/1_nX`N/2ojO0j`Wooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`03ooooo`00<_ooool2o`0003;ooooo00?oYKo/ojJok?nV_n`01?nV_n`6ojO0
j`03ojW0j_nY`>_oZL3[00CoZL3[1onY`>X6ojJok0CoY/3/0onU`>d5ojS1j`OoZ<3[1onU_^`3oh^i
m0?oW[c^1_n2^_T6oenio@KoG<;l1OnIfOd3okG:jPCoR=[o1_nZe?H3ok73i`GoRmkn0onNfo`5ogWK
n`03oh3Pn_nEfokoUM_n00CoUM_n0_nJg_d6ojK8l@?oZ<Wa2_nW_nX3ojNoj`[oYl7/00?oZ<?]ojS1
jonX`N/01?nX`N/6ojNoj`;oYkkZ1OnW_^/5ojNoj`;oZ<7/1_nX`^`5ojS1j`goYko[00?oYl3[ojS1
k?nX`N`01_nX`N`3ojS1j`kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02oooo
o`00=?ooool00ol0003oooooooooo`0`ooooo`OoY[o/0onW`>/3ojO0k0OoZL3[1onY`>X6ojJok003
ojK0k?nU`>goYL3]00CoYL3]1OnX`N/7ojS0j`GoYKk/0_nX`>/6oijlkPKoP[[i0omO^Od4oh2nn`Ko
H[km1OmMa_/6ohSJo`?oZ]Cf1Om/doX3oh_NoPCoMMGm0omifo/5oi?FoP?oUM_n1?nTaO45ojK8l@go
YkoZ0_nW`>/:ojO1k0?oZ<;/1onX`N/3ojNoj`?oYkkZ1onW_^/00onW_n_oZ<7/ojS1k004ojS1k0Ko
Z<;/00?oZ<7[ojNojonW_n/02onW_n/5ojO0j`KoZ<7/4_ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo00;ooooo000eooooo`03o`000?oooooooooo033ooooo1onV_n`6ojO0k0GoZL3[
0_nX`>/7ojW0jP?oY[o/1?nW_n/6ojG0k@;oZ<7[1?nW`N`6ojS0j`03ojFnk?nX`>_oZ<3[00CoZ<3[
1_nN_>h3oh:jn@CoVKc`1_n0__/3of:no@CoQ/7j1_m_a_l5of?9o0?oK=?j1Omicol3ogGEo@GoULol
0onCe_h4ojC2k`KoY<Ga00?oY/SaojNoj_nW_nX02onW_nX6ojO0j`GoYl7/00?oZ<;]ojS2k?nX`^`0
1OnX`^`5ojS1j`SoYkkZ1OnW_^/00onW`>coZ<7/ojS1k006ojS1k0?oZ<;/4?nW_n/6ojO0j`;oZ<7/
5_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo000fooooo`03o`000?oo
oooooooo033ooooo1onV_n`6ojO0k003ojW0jonX`>_oZ<3[00CoZ<3[1onY`>X7ojNoj`?oYL3]0onU
_n`6ojO1k0?oZ<3[0onX`N/7ojS0j`?oW[c^1?nW_n/6oiVll0?oP;kk1?nJ_O06ohK1nP?oKlKo1?nB
`OL6ohG;oP?oNLoo1?nHa_L5oiG?o0;oYKo/1onT`^l3ojC5l@goYkoZ2_nW`>/00onW`NcoZ<;]ojS2
k@03ojS2k@OoZ<;/00?oZ<7[ojNnj_nW_^X02_nW_^X00onW_^_oYl3/ojO0k003ojO0k0KoZ<7/00?o
Z<7[ojNojonW_n/04_nW_n/3ojO0ja_ooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`02ooooo`00=oooool2o`0003;ooooo1_nV_n`3ojO0k0CoY/3/1_nX`>/7ojW0jPGoYko[0_nX_nX6
ojFok0CoYl7/0_nU`Nd6ojS1j`OoZ<3[1onW_n/3oiVll0?oY[o[1onJ_O03ohK1nPCoWkg^1_nB`OL3
ohG;oPCoW[o`1_nHa_L00onEcocoYKo/ojFok004ojFok0GoY<;_00?oZ;oZojNoj_nW_nX02_nW_nX=
ojO0j`03ojO3kOnX`^goZ<;]00GoZ<;]0onX`^`=ojNnjPCoYko[1_nW`>`2ojS1k0GoZ<7[4_nW_n/P
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool003Wooooo00?o0000oooo
ooooool0<?ooool6ojJok0OoY/3/1_nX`>/7ojW0jP03ojNojonX_n[oZ;oZ00CoZ;oZ1_nU_n`00onW
`NcoYL7]ojG1k@03ojG1k@KoZ<7[1onX`>/5ojNoj`;oZ<3[1_nV_n/5oiZml0;oYko[1onO_Nh3oi;1
m`?oYKk/1onN_o03oiS6m`CoY[o[1_nU_n`00onT`^ooZ;oZojRojP03ojRojPSoYkoZ3OnW`>/5ojO3
k@GoZ<;]3OnW_^X9ojNoj`?oYl3/0onX`^`7ojS1j`koYko[8oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00;ooooo000jooooo`03o`000?oooooooooo033ooooo1_nV_n`7ojK0k0Ko
Z<3[1onY`>X7ojRojP?oYKo/0onV_n/6ojG1k@?oZ<7[1?nW`N`6ojS0j`03ojNojonX`>_oZ<3[00Co
Z<3[1_nV_n/00onJ_O3oYko[ojNoj`04ojNoj`GoWkg^0_nX_nX6ojFnk0GoW[o`0_nX_nX7ojJoj`?o
YKo/0_nX_n/7ojRojP?oYkoZ3OnW`>/:ojO3k@03ojS2kOnW_^[oYkkZ00_oYkkZ2onW_n/8ojS2k0Go
Z<7[2onW_n/Xooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00_ooool003_ooooo
00?o0000ooooooooool0<?ooool6ojJok0OoY/3/1_nX`>/7ojW0jPGoZ;oZ0_nY`>X6ojJoj`CoYL7]
0_nU_n`7ojO1k0?oZ<3[0onX`^`7ojS0j`?oY[o[1?nX`>/6ojNoj`03oinmk_nX_n[oZ;oZ00CoZ;oZ
1_nU_^`00onN_o3oZ;oZojRojP04ojRojPGoY[o[1onX_n/5ojRojP;oYl7/2onW`>/<ojO3k@CoYkoZ
2OnW_^X;ojNoj`coZ<;/00?oZ<7[ojNojonW_n/02?nW_n/]ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool00Oooool003cooooo00?o0000ooooooooool0<?ooool3ojJok0?oYko[1onV
`>`3ojS0j`CoZ<7[1_nY`>X00onX_n[oZL3ZojW0jP04ojW0jPKoY[o[00?oYL7]ojFok?nU_n`00onU
_n`5ojO1k0;oYL3]1_nX`^`5ojS0j`;oZ<7/1onX`>/3ojNoj`?oZ;o[1onX_nX3ojFnk0[oZ;oZ00?o
Y[o[ojRojonX_n/02OnX_n/00onX_n[oYl7/ojO1k004ojO1k0OoYl3[2onW`nd00onX_n_oYkoZojNo
jP06ojNojPGoYkkZ2_nW_n/3ojO1k0[oZ<;/2onW_n/aooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool00Oooool003gooooo0_l0000aooooo`KoYko[1onV`>`7ojS1j`?oZL3Z0onY`>/7
ojW0jP?oY[o[0onX_nX6ojFok003ojO1k?nU`>goYL3]00CoYL3]1_nX`^`00onX`>_oZ<7/ojS1k004
ojS1k0GoZ<3[0_nX`^`6ojRoj`GoZ;oZ00?oZ<3[ojRoj_nX_nX02_nX_nX00onX`>_oZ;o[ojRoj`08
ojRoj`CoYl;/1_nW`N`3ojO0j`CoYl;]1onW`nd5ojRoj`KoYkoZ1onW_^X5ojNoj`SoYl7/1OnX`^`2
ojS0j`[oYko[=?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo007ooooo000ooooo
o`03o`000?oooooooooo02oooooo1_nW_n/7ojK0k0GoZ<7[0_nW`>`6ojW0j`OoZL3Z1_nX_nX3ojFo
k0?oY[o[1onU`>d3ojS2k0CoYL7]1_nX`N`00onX`>_oZ<;/ojS2k004ojS2k0KoZ;o[00?oZ;oZojS0
jonX`>/00onX`>/8ojRojPGoZ<3[1OnX_n/2ojO2k@OoYl;/0onW`N`:ojO2k@?oYl?]0onW_n/6ojRo
j`;oYkoZ2onW_^X00onW_n_oYl7/ojO1k00:ojO1k003ojS2k?nX`>_oZ<3[00CoZ<3[1OnW_n/ioooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00Oooool0043ooooo00?o0000oooooooo
ool0;oooool7ojNoj`KoY/3/00?oZ<7[ojO0k?nW`>`01?nW`>`6ojW0j`OoZL3Z1?nX_nX2ojVojPKo
Y[o[1OnU`>d2ojJoj`OoYL7]0onX`N`3ojK1k@OoZ<;/0onX_n/3ojO2k@KoZ<3[0onX_nX4ojO2k0Ko
Z<3[00?oZ;o[ojO2kOnW`^d01?nW`^d5ojO2k003ojO1kOnW`^goYl;]00[oYl;]00?oYkoZojNojonW
_n/01OnW_n/3ojRoj`goYkkZ0onW`>`:ojO1k0?oZ<7/1onX`>/00onW_n_oooooooooo`0kooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool00Oooool0047ooooo00?o0000ooooooooool0
;oooool7ojNoj`?oY/3/0onV_n`7ojO0k0?oZL3[1?nX`N/6ojW0jP03ojRoj_nY_n[oZKoZ00?oZKoZ
1_nV_n/00onU`>goY[o[ojJoj`04ojJoj`GoYL7]0_nU_n`6ojK1k@GoZ<;/00?oYL7]ojO2kOnW`^d0
1OnW`^d3ojS0j`?oY/;]1onW`^`3ojS0j`CoY/;]1_nW`^d00onW`^coYl7]ojO1k@03ojO1k@SoYl;]
1OnW_nX5ojNoj`goYkkZ00?oYl3[ojO0k?nW`>`01OnW`>`5ojO1k0SoZ<7/0onX`>]1ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool00Oooool004;ooooo0_l0000`ooooo`GoYko[0_nX
`>/6ojJok0GoYl3/0_nV`>`7ojS1j`?oZL3Z0onX`>/6ojVojP?oY[o[1?nX_nX6ojJoj`03ojG1kOnU
_ncoYKo/00CoYKo/1_nV`Nd00onX`^coYL7]ojG1k@03ojG1k@GoYl;]0_nV`>d6ojK2k@GoYl;/0_nV
`Nd7ojK2k@?oYl;]0_nV`>`7ojO1k@?oYl;]1?nW_^X6ojNojP03ojNojonW_^[oYkkZ00_oYkkZ1OnW
`>/7ojO0k003ojO1k?nX`NcoZ<7/00SoZ<7/A_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo007ooooo0014ooooo`03o`000?oooooooooo02kooooo00?oYko[ojS0jonX`>/01?nX`>/6
ojJok003ojO0k?nV`>coY/3/00CoY/3/1OnX`N/2ojO1k0KoZ<3[1?nY_nX2ojW0jPOoZ;oZ0onV_n/4
ojRojPKoYKo/0onV`Nd4ojJoj`GoYL7]00?oYl;]ojK0kOnV`>d01?nV`>d6ojK2k@03ojO2k?nV`Ngo
Y/7]00CoY/7]1OnV`^d00onW_n_oY/3/ojK0k004ojK0k0GoYl7]0_nX_^X7ojNnjP?oYkoZ0onX_^X:
ojNnjPWoYl3[0onW`>`4ojO1k0OoZ<7/B_ooool00ol0003oooooooooo`07ooooo`7o00000Oooool1
ooooo`00AOooool00ol0003oooooooooo`0_ooooo`KoZ<3[0onV_n`4ojNoj`KoY/3/00?oZ<7[ojO1
k?nW`N`01?nW`N`6ojS0j`03ojVoj_nY`>[oZL3Z00?oZL3Z1OnX_nX2ojVojPOoZ;oZ0onU_n`3ojRo
jPOoY[o[0_nU`Nd4ojJnj`KoY/3]0onV`^d4ojJoj`KoY/7]00?oY/;]ojNojonW_n/00onW_n/6ojK0
k003ojO1kOnX_^[oZ;kZ00CoZ;kZ1OnW_^X2ojRojPKoZ;kZ1OnW_^X;ojO0j`?oYl;/1onW`N`3ojS1
k4kooooo00?o0000ooooooooool01_ooool1o`00007ooooo0Oooool004Kooooo00?o0000oooooooo
ool0<?ooool5ojS0j`OoYko[0onV`>`4ojJok0KoYl7/0onX`>/3ojS1k0KoZL3Z00?oZ;oZojVoj_nY
_nX01?nY_nX5ojRojP;oZKoZ1_nX_nX5ojJoj`03ojRoj_nV_^_oY[k[00GoY[k[0onV`>d3ojNnjPOo
Y[o[0onV`Nd3ojNnjPKoYko[0onV`>`:ojRnjP03ojNnj_nX_n[oZ;oZ00CoZ;oZ1_nX_^X00onW_^[o
Yl3[ojO0j`08ojO0j`SoYl;/1OnW`NaBooooo`03o`000?oooooooooo00Kooooo0Ol00001ooooo`7o
oooo0017ooooo`;o0000<Oooool5ojS0j`GoYko[0_nX_n/7ojJok0?oYl7/0onV`>`6ojS1k0?oZL3Z
1?nX`N/6ojVojP03ojRoj_nY_n[oZKoZ00CoZKoZ1_nX_nX00onV_n_oZ;oZojRojP03ojRojPGoY[k[
0_nX_nX6ojNnjPGoY[o[00?oZ;oZojNnj_nW_^X01OnW_^X3ojNoj`goZ;kZ2_nX_nX3ojRnjP[oYl3[
3?nW`^`00onW`Ncoooooooooo`1Dooooo`03o`000?oooooooooo00Gooooo0Ol00001ooooo`7ooooo
0019ooooo`03o`000?oooooooooo02oooooo1OnX`>/00onW_n_oZ;o[ojRoj`04ojRoj`GoY[o/0_nW
_n/6ojK0k0CoZ<7/0_nV`N`7ojS1j`?oZKoZ0onX`>/7ojVojP?oZ;oZ0onY_nX6ojRojP03ojJnjonX
_n[oZ;oZ00CoZ;oZ1_nW_^X00onV_n_oZ;oZojRojP03ojRojPGoYkkZ0_nX_nX;ojRnjPgoZ;oZ00?o
Yl3/ojO0jonW`>/02?nW`>/=ojO2k5[ooooo00?o0000ooooooooool01?ooool1o`00007ooooo0Ooo
ool004[ooooo00?o0000ooooooooool0;oooool6ojS0j`KoZ;o[00?oY[o/ojNojonW_n/01?nW_n/6
ojK0k003ojS1k?nV`NcoY/7/00?oY/7/1OnX`N/2ojO1k0KoZ<3[1OnY_nX00onX`>_oZKoZojVojP05
ojVojPgoZ;oZ0onW_^X9ojRojP03ojNnj_nX_n[oZ;oZ00CoZ;oZ1onX_^X=ojRojPGoYl3/1OnW`>/2
ojO1k0[oYl;/H?ooool00ol0003oooooooooo`03ooooo`7o00000Oooool1ooooo`00Boooool00ol0
003oooooooooo`0_ooooo`KoZ<3[1onX_n/6ojNoj`?oY/3/1?nV_n`5ojK1k003ojS1jonW`NcoYl7/
00CoYl7/1_nX`>/00onY_n[oZ<3[ojS0j`03ojS0j`GoZKoZ0_nX`>/PojRojP?oZ;kZ1?nX`>/9ojRo
jP?oYl7/1_nW`>`00onW`>_oYl7/ojO1k004ojO1k0GoYl;/I?ooool00ol0003oooooooooo`03oooo
o`7o00000Oooool1ooooo`00C?ooool2o`00033ooooo1_nX`>/7ojRoj`?oYko[0onX_n/7ojJok0;o
Y/7/1?nV`>`6ojO1k0?oZ<3[1?nW`N`5ojS0j`03ojVoj_nX`>_oZ<3[00CoZ<3[4OnX_nX2ojS0j`_o
Z;oZ0_nX`N/7ojS0j`?oZ;oZ2OnW`N`3ojO0k0[oYl7/00?oYl;/ooooooooool0I_ooool00ol0003o
ooooooooo`03ooooo`7o00000Oooool004kooooo00?o0000ooooooooool0;_ooool6ojS0j`GoZ;o[
0_nX`>X6ojRoj`GoY[o/00?oYko[ojK0k?nV`>`01OnV`>`3ojO1k0?oY/3/1onW`N`2ojS0j`CoYl7/
1_nX`>/3ojRojPCoZ<7/1onX_nX5ojS0j`OoZ;oZ1_nX`N/5ojS0jaSoYl7/K?ooool00ol0003ooooo
ooooo`02ooooo`7o00000Oooool004oooooo00?o0000ooooooooool0;oooool5ojS0j`03ojRojonX
`>[oZ<3Z00CoZ<3Z1_nX_n/00onV_ncoYko[ojNoj`03ojNoj`GoY/3/0_nW_n/6ojK0k0GoYl7/00?o
Y/3/ojO1k?nW`N`01OnW`N`3ojS0j`?oYl7/1onX`N`3ojRojP?oYl7/1_nX`>/3ojRojPCoYl7/1_nX
`N/00onX`>_oYl7/ojO1k00EojO1k77ooooo00Go0000ooooooooooooooooo`000001ooooo`00D?oo
ool00ol0003oooooooooo`0_ooooo`;oZ<3[0onX`N/7ojS0jP?oZ;o[1?nX_nX5ojNoj`03ojK0k?nW
_n_oYko[00CoYko[1_nV`>`00onW`NcoY/3/ojK0k003ojK0k0GoYl7/0_nV`>`6ojO1k0GoZ<7/00?o
Y/7]ojO1k?nW`N`01OnW`N`3ojS0j`?oYl7]1onW`N`3ojS1j`coYl7/1?nW`>`7ojO1k7Cooooo00Go
0000ooooooooooooooooo`000001ooooo`00DOooool2o`00033ooooo1OnX`N/5ojS0jP;oZ<3[1onX
_nX2ojNoj`CoZ;oZ1_nW_n/3ojK0k0CoYko[1OnV`>`00onW`NcoY/3/ojK0k004ojK0k0KoYl7/00?o
Z<7/ojK1kOnV`Nd00onV`Nd5ojO1k0;oY/3/1_nW`Nd5ojO1k003ojO0k?nW`NcoYl7/00SoYl7/0onW
`>/7ojO0k0?oYl7/N?ooool01?l0003oooooooooool00001ooooo`00Doooool00ol0003ooooooooo
o`0^ooooo`GoZ<7[00?oZ<3ZojS0jonX`>/01?nX`>/5ojRojP03ojS0jonX_n[oZ;oZ00GoZ;oZ0onW
_n/3ojRojPOoYko[0_nV`>`4ojNoj`KoY/3/0onW`N`3ojK0k0KoY/7]00?oYl7/ojK0k?nV`>`01?nV
`>`6ojO1k@03ojO1k?nW`>coYl3/00?oYl3/1OnW`N`2ojNoj`KoYl3[1OnW`>amooooo`03o`000?oo
oooo0000007ooooo001Dooooo`03o`000?oooooooooo02kooooo0_nX`N/4ojO0k0KoZ<3[00?oZ;oZ
ojS0jonX`>/00onX`>/=ojRojPGoYko[00?oZ;oZojNojonW_n/01OnW_n/3ojK0k0?oYko[1_nV`>`3
ojK1k@CoYko[1_nV`>`3ojO1k@?oYko[1_nW`>`00onW`NcoYko[ojNoj`04ojNoj`KoYl3[00?oYl3/
ooooooooool0O_ooool00ol0003oooooo`000001ooooo`00EOooool00ol0003oooooooooo`0^oooo
o`KoYl3/0onX`>/4ojO1k0GoZ<3[3OnX_nX00onW_n_oZ;oZojRojP03ojRojPGoYko[0_nX_nX6ojNo
j`CoY/3/0_nX_n/7ojNoj`?oY/3/2OnW_n/3ojO0k0[oYko[0onW`>^4ooooo`7o00000Oooool1o`00
0000E_ooool2o`0002oooooo0onW`>`3ojK0k0OoYl7/0_nX`>/4ojS1ja;oZ;oZ00?oYko[ojRoj_nX
_nX01?nX_nX6ojNoj`03ojK0k?nX_n_oZ;o[00?oZ;o[1OnW_n/2ojRojP[oYko[0_nX_nX:ojNojh[o
oooo0_l0000005Sooooo00?o0000ooooooooool0;Oooool6ojK0k0GoYl7/0_nV`>`6ojS1j`?oZ;oZ
0onX`N/CojRojP?oYko[0onX_nX6ojRoj`03ojNojonX_n[oZ;oZ00CoZ;oZ1_nW_n/6ojRojPGoYko[
SOooool3o`000000FOooool00ol0003oooooooooo`0]ooooo`KoY/3/00?oYl7/ojK0k?nV`>`01?nV
`>`4ojS1j`;oYl7/1_nX`N/5ojRojP03ojS1jonX_n[oZ;oZ00SoZ;oZ0onX_n/6ojRojP?oZ;o[2_nX
_nX2ojNoj`[oZ;oZ00?oYko[ooooooooool0R_ooool4o`0000?ooooo001Jooooo`03o`000?oooooo
oooo02gooooo0onV`>`4ojNoj`KoY/3/00?oZ<7[ojO1k?nW`N`00onW`N`6ojS1j`03ojRoj_nX`N_o
Z<7[00?oZ<7[1OnX_nX2ojS1j`KoZ;o[1?nX_nX2ojS0j`[oZ;oZ0onX_n/9ojRojXcooooo0ol00007
ooooo`00Foooool00ol0003oooooooooo`0^ooooo`KoYko[1_nV`>`6ojO1k0?oZ<7[1?nW`N`5ojS1
j`03ojRoj_nX`N_oZ<7[00CoZ<7[1_nX_n/00onX_n[oZ<3[ojS0j`03ojS0j`GoZ;oZ00?oZ<3[ojRo
jonX_n/01OnX_n/3ojRojXgooooo1?l0000:ooooo`00G?ooool2o`0002oooooo1_nW_n/6ojK0k0?o
Yl7/1?nV`>`6ojO1k0;oZ<7[1?nW`N`6ojS1j`?oZ;o[0onX`N`6ojS0j`03ojRoj_nX`>_oZ<3[00?o
Z<3[1OnX_n^=ooooo`Co00003_ooool005kooooo00?o0000ooooooooool0;Oooool6ojNoj`CoY/3/
0_nW_n/7ojK0k0?oYl7/0_nV`>`7ojO1k0?oZ<7[0onW`N`6ojS1k0?oZ<3[1?nW`N`5ojS0j`03ojRo
jooooooooooo08[ooooo1?l0000Booooo`00Goooool00ol0003oooooooooo`0]ooooo`KoYko[00?o
Y/3/ojNojonW_n/00onW_n/5ojK0k0;oYko[1OnV`>`5ojO1k0;oY/3/1_nW`N`3ojS1k0CoYl3/1_nW
`N`2ojS0jh_ooooo1?l0000Fooooo`00H?ooool00ol0003oooooooooo`0]ooooo`?oYko[1?nX_n/5
ojNoj`03ojK0k?nW_n_oYko[00CoYko[1OnV`>`00onW`NcoY/3/ojK0k004ojK0k0CoYl7/0_nW`>/7
ojO0k0?oYl7/S?ooool3o`0001[ooooo001Qooooo`;o0000;oooool6ojRoj`;oYko[1?nX_n/6ojNo
j`;oY/3/1?nW_n/6ojK0k003ojO1k?nW`>_oYl3[00?oYl3[1OnW`>b<ooooo`Co00007Oooool006?o
oooo00?o0000ooooooooool0;Oooool3ojRoj`;oZ<3[1onX_n/3ojNoj`?oZ;o[1_nW_n/3ojK0k0?o
Yko[1_nW`>/00onW`>coooooooooo`29ooooo`Co00008Oooool006Cooooo00?o0000ooooooooool0
;Oooool5ojS0j`GoZ;o[0_nX`>/6ojRoj`?oYko[1?nX_n/5ojNoj`?oYl3[R_ooool4o`0002Gooooo
001Uooooo`03o`000?oooooooooo02gooooo1OnX`>/00onX_n_oZ<3[ojS0j`04ojS0j`CoZ;o[0_nX
`>/7ojRoj`;oYko[Roooool4o`0002Wooooo001Vooooo`;o0000;_ooool2ojS0j`CoZ<7[1_nX`>/0
0onX_n_oZ<3[ojS0j`03ojS0j`GoZ;o[Roooool3o`0002gooooo001Xooooo`03o`000?oooooooooo
02cooooo1_nX`N/3ojS0j`?oZ<7[1_nX`>/00onX_n_oooooooooo`28ooooo`Co0000<?ooool006Wo
oooo00?o0000ooooooooool0;?ooool3ojS1j`CoYl3/1OnX`N/3ojS0jhWooooo1?l0000dooooo`00
J_ooool00ol0003oooooooooo`0/ooooo`OoYl3/0_nX`N^:ooooo`Co0000>?ooool006_ooooo0_l0
000]ooooo`GoYl3/ROooool4o`0003cooooo001]ooooo`03o`000?oooooooooo02_ooooo00?oYl3/
ooooooooool0Qoooool3o`00043ooooo001^ooooo`03o`000?oooooooooo02[ooooo00?o0000oooo
ooooool0Poooool4o`0004?ooooo001_ooooo`03o`000?oooooooooo02Wooooo00?o0000oooooooo
ool0Ooooool4o`0004Oooooo001`ooooo`;o0000:Oooool00ol0003oooooooooo`1kooooo`Co0000
Boooool007;ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1gooooo`Co0000Cooo
ool007?ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1dooooo`?o0000Doooool0
07Cooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1`ooooo`Co0000E_ooool007Go
oooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1/ooooo`Co0000F_ooool007Kooooo
0_l0000Sooooo`03o`000?oooooooooo06Sooooo1?l0001Nooooo`00N?ooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo06Cooooo1?l0001Rooooo`00NOooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo067ooooo0ol0001Vooooo`00N_ooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo05gooooo1?l0001Yooooo`00Noooool2o`0001kooooo00?o0000oooooooo
ool0FOooool4o`0006gooooo001mooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
EOooool4o`00077ooooo001nooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0DOoo
ool4o`0007Gooooo001oooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0C_ooool3
o`0007Wooooo0020ooooo`;o00006Oooool00ol0003oooooooooo`1:ooooo`Co0000O?ooool008;o
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`16ooooo`Co0000P?ooool008?ooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`12ooooo`Co0000Q?ooool008Cooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`0nooooo`Co0000R?ooool008Gooooo0_l0000C
ooooo`03o`000?oooooooooo03cooooo0ol0002<ooooo`00Qoooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo03Sooooo1?l0002?ooooo`00R?ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo03Cooooo1?l0002Cooooo`00ROooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo033ooooo1?l0002Gooooo`00R_ooool2o`0000kooooo00?o0000ooooooooool0;?oo
ool4o`0009_ooooo002<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0:Oooool3
o`0009oooooo002=ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool09Oooool4o`00
0:;ooooo002>ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08Oooool4o`000:Ko
oooo002?ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07Oooool4o`000:[ooooo
002@ooooo`;o00002?ooool00ol0003oooooooooo`0Iooooo`Co0000[_ooool009;ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Fooooo`?o0000/_ooool009?ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Booooo`Co0000]Oooool009Cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0>ooooo`Co0000^Oooool009Gooooo0_l00003ooooo`03o`00
0?oooooooooo00[ooooo1?l0002mooooo`00Uoooool01?l0003oooooooooool00008ooooo`Co0000
`Oooool009Sooooo00?o0000ooooool000001Oooool3o`000<Gooooo002Iooooo`;o000000?ooooo
o`000?l000000_l00038ooooo`00V_ooool2o`000<cooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
0000\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0538698, 0.0432538, \
0.0035044, 0.0035044}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[.12586 .2075 -12 -8.99448 ]
[.12586 .2075 0 .00552 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.56094 .0364 -5.16972 -9 ]
[.56094 .0364 .83028 0 ]
[.75679 .08071 0 -6.17777 ]
[.75679 .08071 12 2.82223 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.9429 .3657 0 -5.9083 ]
[.9429 .3657 6 3.0917 ]
[.02494 .25992 -18 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.01611 .31527 -18 -2.78472 ]
[.01611 .31527 0 6.21528 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00254 .43215 -12 -2.88407 ]
[-0.00254 .43215 0 6.11593 ]
[-0.0124 .49393 -12 -2.93688 ]
[-0.0124 .49393 0 6.06312 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
[(-2)] .12586 .2075 1 .99877 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.56863 .04703 m
.57247 .05235 L
s
[(2)] .56094 .0364 .72324 1 Mshowa
.125 Mabswid
.18558 .19702 m
.18832 .19985 L
s
.23703 .17687 m
.23971 .17975 L
s
.28951 .15632 m
.29214 .15925 L
s
.39772 .11395 m
.40023 .11699 L
s
.4535 .09211 m
.45595 .0952 L
s
.51046 .06981 m
.51284 .07294 L
s
.08568 .23614 m
.08851 .23887 L
s
.62804 .02377 m
.63027 .02701 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.7445 .0853 m
.73835 .08759 L
s
[(-2)] .75679 .08071 -1 .37284 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.93037 .36962 m
.92411 .37158 L
s
[(2)] .9429 .3657 -1 .31296 Mshowa
.125 Mabswid
.7708 .12553 m
.7671 .12688 L
s
.79613 .16428 m
.79242 .1656 L
s
.82054 .20161 m
.81682 .20291 L
s
.86679 .27235 m
.86305 .2736 L
s
.88871 .30589 m
.88497 .30711 L
s
.9099 .3383 m
.90615 .3395 L
s
.71716 .04348 m
.71349 .04489 L
s
.95018 .39992 m
.94642 .40107 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(-20)] .02494 .25992 1 -0.39157 Mshowa
.02837 .31059 m
.0345 .30825 L
s
[(-10)] .01611 .31527 1 -0.38117 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.00981 .42772 m
.01599 .4255 L
s
[(10)] -0.00254 .43215 1 -0.3591 Mshowa
0 .48963 m
.0062 .48748 L
s
[(20)] -0.0124 .49393 1 -0.34736 Mshowa
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.654 .753 .922 r
.39362 .69484 .40169 .70182 .4152 .69808 .40717 .69105 Mtetra
.658 .753 .921 r
.40717 .69105 .4152 .69808 .42878 .69431 .42079 .68713 Mtetra
.659 .75 .918 r
.42079 .68713 .42878 .69431 .44242 .69041 .43448 .68314 Mtetra
.656 .749 .918 r
.43448 .68314 .44242 .69041 .45614 .68645 .44824 .67923 Mtetra
.655 .75 .92 r
.44824 .67923 .45614 .68645 .46992 .68253 .46207 .67534 Mtetra
.653 .752 .922 r
.46207 .67534 .46992 .68253 .48378 .67864 .47597 .67149 Mtetra
.653 .754 .923 r
.47597 .67149 .48378 .67864 .4977 .67478 .48994 .6676 Mtetra
.656 .755 .922 r
.48994 .6676 .4977 .67478 .5117 .67092 .50398 .66359 Mtetra
.658 .752 .919 r
.50398 .66359 .5117 .67092 .52577 .667 .5181 .65949 Mtetra
.659 .749 .916 r
.5181 .65949 .52577 .667 .53991 .66296 .53229 .65538 Mtetra
.657 .747 .917 r
.53229 .65538 .53991 .66296 .55412 .65887 .54655 .65131 Mtetra
.656 .748 .918 r
.54655 .65131 .55412 .65887 .56841 .65477 .56088 .64724 Mtetra
.655 .75 .92 r
.56088 .64724 .56841 .65477 .58277 .65069 .57529 .64318 Mtetra
.654 .751 .921 r
.57529 .64318 .58277 .65069 .5972 .64661 .58978 .63912 Mtetra
.654 .753 .923 r
.58978 .63912 .5972 .64661 .61171 .64252 .60434 .63506 Mtetra
.654 .755 .924 r
.60434 .63506 .61171 .64252 .6263 .63842 .61898 .63096 Mtetra
.654 .756 .925 r
.61898 .63096 .6263 .63842 .64096 .63429 .6337 .62682 Mtetra
.655 .757 .925 r
.6337 .62682 .64096 .63429 .6557 .63015 .64849 .62265 Mtetra
.64849 .62265 .6557 .63015 .67052 .62597 .66336 .61844 Mtetra
.655 .758 .925 r
.66336 .61844 .67052 .62597 .68542 .62177 .67831 .6142 Mtetra
.67831 .6142 .68542 .62177 .70039 .61755 .69334 .60993 Mtetra
.656 .758 .925 r
.69334 .60993 .70039 .61755 .71544 .61329 .70845 .60562 Mtetra
.656 .757 .924 r
.70845 .60562 .71544 .61329 .73058 .60902 .72364 .60127 Mtetra
.657 .757 .924 r
.72364 .60127 .73058 .60902 .74579 .60472 .73891 .59689 Mtetra
.657 .756 .923 r
.73891 .59689 .74579 .60472 .76109 .6004 .75426 .59246 Mtetra
.657 .754 .921 r
.75426 .59246 .76109 .6004 .77646 .59608 .76969 .58803 Mtetra
.656 .752 .92 r
.76969 .58803 .77646 .59608 .79193 .59175 .78521 .5836 Mtetra
.656 .75 .919 r
.78521 .5836 .79193 .59175 .80748 .58744 .80081 .57917 Mtetra
.655 .748 .918 r
.80081 .57917 .80748 .58744 .82311 .58312 .8165 .57475 Mtetra
.654 .746 .918 r
.8165 .57475 .82311 .58312 .83883 .57875 .83228 .57037 Mtetra
.654 .747 .918 r
.83228 .57037 .83883 .57875 .85462 .57424 .84815 .56597 Mtetra
.655 .751 .921 r
.84815 .56597 .85462 .57424 .8705 .56968 .8641 .56147 Mtetra
.658 .755 .922 r
.8641 .56147 .8705 .56968 .88647 .56511 .88013 .55684 Mtetra
.88013 .55684 .88647 .56511 .90252 .56055 .89624 .55217 Mtetra
.657 .753 .921 r
.89624 .55217 .90252 .56055 .91867 .55604 .91245 .54753 Mtetra
.656 .75 .92 r
.91245 .54753 .91867 .55604 .93492 .55156 .92875 .54292 Mtetra
.653 .747 .919 r
.92875 .54292 .93492 .55156 .95125 .54701 .94516 .53838 Mtetra
.654 .749 .919 r
.94516 .53838 .95125 .54701 .96766 .54233 .96165 .53377 Mtetra
.657 .753 .921 r
.96165 .53377 .96766 .54233 .98416 .5376 .97822 .52901 Mtetra
.38546 .68778 .39362 .69484 .40717 .69105 .39906 .68384 Mtetra
.659 .75 .918 r
.39906 .68384 .40717 .69105 .42079 .68713 .41273 .67984 Mtetra
.656 .749 .918 r
.41273 .67984 .42079 .68713 .43448 .68314 .42646 .67591 Mtetra
.654 .751 .921 r
.42646 .67591 .43448 .68314 .44824 .67923 .44026 .67202 Mtetra
.653 .752 .923 r
.44026 .67202 .44824 .67923 .46207 .67534 .45414 .66816 Mtetra
.654 .754 .923 r
.45414 .66816 .46207 .67534 .47597 .67149 .46808 .66425 Mtetra
.658 .755 .921 r
.46808 .66425 .47597 .67149 .48994 .6676 .4821 .66016 Mtetra
.659 .75 .917 r
.4821 .66016 .48994 .6676 .50398 .66359 .49619 .65602 Mtetra
.658 .748 .916 r
.49619 .65602 .50398 .66359 .5181 .65949 .51035 .65193 Mtetra
.656 .748 .918 r
.51035 .65193 .5181 .65949 .53229 .65538 .52459 .64787 Mtetra
.655 .75 .92 r
.52459 .64787 .53229 .65538 .54655 .65131 .5389 .64383 Mtetra
.653 .752 .922 r
.5389 .64383 .54655 .65131 .56088 .64724 .55329 .63982 Mtetra
.653 .754 .924 r
.55329 .63982 .56088 .64724 .57529 .64318 .56775 .63579 Mtetra
.653 .756 .925 r
.56775 .63579 .57529 .64318 .58978 .63912 .58228 .6317 Mtetra
.655 .757 .925 r
.58228 .6317 .58978 .63912 .60434 .63506 .5969 .62753 Mtetra
.657 .756 .923 r
.5969 .62753 .60434 .63506 .61898 .63096 .61159 .62329 Mtetra
.657 .753 .921 r
.61159 .62329 .61898 .63096 .6337 .62682 .62635 .61904 Mtetra
.657 .751 .92 r
.62635 .61904 .6337 .62682 .64849 .62265 .6412 .61477 Mtetra
.656 .75 .919 r
.6412 .61477 .64849 .62265 .66336 .61844 .65612 .6105 Mtetra
.656 .749 .918 r
.65612 .6105 .66336 .61844 .67831 .6142 .67113 .60621 Mtetra
.67113 .60621 .67831 .6142 .69334 .60993 .68621 .60192 Mtetra
.655 .749 .919 r
.68621 .60192 .69334 .60993 .70845 .60562 .70138 .59762 Mtetra
.655 .75 .92 r
.70138 .59762 .70845 .60562 .72364 .60127 .71663 .59331 Mtetra
.654 .752 .922 r
.71663 .59331 .72364 .60127 .73891 .59689 .73196 .58898 Mtetra
.655 .755 .923 r
.73196 .58898 .73891 .59689 .75426 .59246 .74737 .58458 Mtetra
.657 .758 .924 r
.74737 .58458 .75426 .59246 .76969 .58803 .76286 .5801 Mtetra
.658 .758 .924 r
.76286 .5801 .76969 .58803 .78521 .5836 .77844 .57556 Mtetra
.658 .756 .922 r
.77844 .57556 .78521 .5836 .80081 .57917 .79409 .57098 Mtetra
.657 .753 .921 r
.79409 .57098 .80081 .57917 .8165 .57475 .80984 .56645 Mtetra
.656 .751 .92 r
.80984 .56645 .8165 .57475 .83228 .57037 .82567 .56192 Mtetra
.655 .748 .918 r
.82567 .56192 .83228 .57037 .84815 .56597 .8416 .55743 Mtetra
.653 .746 .918 r
.8416 .55743 .84815 .56597 .8641 .56147 .85762 .55297 Mtetra
.654 .748 .919 r
.85762 .55297 .8641 .56147 .88013 .55684 .87373 .54848 Mtetra
.657 .755 .922 r
.87373 .54848 .88013 .55684 .89624 .55217 .88991 .54379 Mtetra
.658 .756 .922 r
.88991 .54379 .89624 .55217 .91245 .54753 .90617 .53903 Mtetra
.657 .753 .921 r
.90617 .53903 .91245 .54753 .92875 .54292 .92253 .53431 Mtetra
.656 .751 .92 r
.92253 .53431 .92875 .54292 .94516 .53838 .93899 .52962 Mtetra
.653 .747 .919 r
.93899 .52962 .94516 .53838 .96165 .53377 .95556 .525 Mtetra
.654 .749 .919 r
.95556 .525 .96165 .53377 .97822 .52901 .97221 .52032 Mtetra
.659 .751 .918 r
.37724 .68055 .38546 .68778 .39906 .68384 .39088 .67652 Mtetra
.656 .749 .918 r
.39088 .67652 .39906 .68384 .41273 .67984 .40459 .67258 Mtetra
.654 .751 .921 r
.40459 .67258 .41273 .67984 .42646 .67591 .41837 .66868 Mtetra
.652 .752 .923 r
.41837 .66868 .42646 .67591 .44026 .67202 .43221 .66481 Mtetra
.654 .754 .923 r
.43221 .66481 .44026 .67202 .45414 .66816 .44613 .66085 Mtetra
.659 .754 .92 r
.44613 .66085 .45414 .66816 .46808 .66425 .46012 .65672 Mtetra
.659 .749 .916 r
.46012 .65672 .46808 .66425 .4821 .66016 .47419 .65257 Mtetra
.657 .748 .917 r
.47419 .65257 .4821 .66016 .49619 .65602 .48833 .64849 Mtetra
.655 .75 .92 r
.48833 .64849 .49619 .65602 .51035 .65193 .50254 .64444 Mtetra
.652 .751 .922 r
.50254 .64444 .51035 .65193 .52459 .64787 .51682 .64046 Mtetra
.652 .754 .924 r
.51682 .64046 .52459 .64787 .5389 .64383 .53118 .63645 Mtetra
.654 .757 .925 r
.53118 .63645 .5389 .64383 .55329 .63982 .54561 .63235 Mtetra
.658 .756 .923 r
.54561 .63235 .55329 .63982 .56775 .63579 .56012 .6281 Mtetra
.658 .752 .919 r
.56012 .6281 .56775 .63579 .58228 .6317 .57471 .62382 Mtetra
.658 .748 .916 r
.57471 .62382 .58228 .6317 .5969 .62753 .58937 .61953 Mtetra
.658 .746 .915 r
.58937 .61953 .5969 .62753 .61159 .62329 .60411 .61524 Mtetra
.657 .745 .915 r
.60411 .61524 .61159 .62329 .62635 .61904 .61893 .61096 Mtetra
.61893 .61096 .62635 .61904 .6412 .61477 .63383 .60666 Mtetra
.656 .746 .916 r
.63383 .60666 .6412 .61477 .65612 .6105 .64881 .60236 Mtetra
.64881 .60236 .65612 .6105 .67113 .60621 .66386 .59803 Mtetra
.66386 .59803 .67113 .60621 .68621 .60192 .679 .59369 Mtetra
.679 .59369 .68621 .60192 .70138 .59762 .69422 .58933 Mtetra
.656 .745 .916 r
.69422 .58933 .70138 .59762 .71663 .59331 .70953 .58496 Mtetra
.655 .744 .916 r
.70953 .58496 .71663 .59331 .73196 .58898 .72492 .5806 Mtetra
.654 .745 .916 r
.72492 .5806 .73196 .58898 .74737 .58458 .74039 .57624 Mtetra
.654 .747 .918 r
.74039 .57624 .74737 .58458 .76286 .5801 .75595 .57186 Mtetra
.654 .75 .921 r
.75595 .57186 .76286 .5801 .77844 .57556 .7716 .56745 Mtetra
.657 .756 .923 r
.7716 .56745 .77844 .57556 .79409 .57098 .78732 .56289 Mtetra
.658 .758 .924 r
.78732 .56289 .79409 .57098 .80984 .56645 .80312 .55823 Mtetra
.659 .756 .922 r
.80312 .55823 .80984 .56645 .82567 .56192 .819 .55354 Mtetra
.657 .752 .921 r
.819 .55354 .82567 .56192 .8416 .55743 .83499 .54892 Mtetra
.655 .75 .919 r
.83499 .54892 .8416 .55743 .85762 .55297 .85106 .54432 Mtetra
.653 .747 .918 r
.85106 .54432 .85762 .55297 .87373 .54848 .86723 .53979 Mtetra
.653 .747 .919 r
.86723 .53979 .87373 .54848 .88991 .54379 .8835 .53524 Mtetra
.657 .753 .921 r
.8835 .53524 .88991 .54379 .90617 .53903 .89984 .53051 Mtetra
.658 .756 .922 r
.89984 .53051 .90617 .53903 .92253 .53431 .91626 .52567 Mtetra
.657 .753 .921 r
.91626 .52567 .92253 .53431 .93899 .52962 .93278 .52087 Mtetra
.656 .751 .92 r
.93278 .52087 .93899 .52962 .95556 .525 .9494 .5161 Mtetra
.653 .748 .919 r
.9494 .5161 .95556 .525 .97221 .52032 .96613 .51142 Mtetra
.657 .749 .918 r
.36894 .67321 .37724 .68055 .39088 .67652 .38262 .66923 Mtetra
.654 .751 .921 r
.38262 .66923 .39088 .67652 .40459 .67258 .39637 .6653 Mtetra
.652 .752 .923 r
.39637 .6653 .40459 .67258 .41837 .66868 .41019 .66143 Mtetra
.655 .754 .923 r
.41019 .66143 .41837 .66868 .43221 .66481 .42408 .65745 Mtetra
.659 .753 .919 r
.42408 .65745 .43221 .66481 .44613 .66085 .43805 .65328 Mtetra
.659 .749 .916 r
.43805 .65328 .44613 .66085 .46012 .65672 .45209 .64913 Mtetra
.656 .748 .918 r
.45209 .64913 .46012 .65672 .47419 .65257 .4662 .64505 Mtetra
.654 .75 .921 r
.4662 .64505 .47419 .65257 .48833 .64849 .48038 .64102 Mtetra
.651 .752 .924 r
.48038 .64102 .48833 .64849 .50254 .64444 .49464 .63705 Mtetra
.653 .756 .925 r
.49464 .63705 .50254 .64444 .51682 .64046 .50897 .63299 Mtetra
.658 .756 .923 r
.50897 .63299 .51682 .64046 .53118 .63645 .52338 .62873 Mtetra
.659 .751 .918 r
.52338 .62873 .53118 .63645 .54561 .63235 .53787 .62442 Mtetra
.659 .747 .915 r
.53787 .62442 .54561 .63235 .56012 .6281 .55243 .62011 Mtetra
.657 .746 .915 r
.55243 .62011 .56012 .6281 .57471 .62382 .56706 .61584 Mtetra
.657 .747 .916 r
.56706 .61584 .57471 .62382 .58937 .61953 .58178 .61157 Mtetra
.656 .748 .918 r
.58178 .61157 .58937 .61953 .60411 .61524 .59657 .6073 Mtetra
.656 .75 .919 r
.59657 .6073 .60411 .61524 .61893 .61096 .61144 .60302 Mtetra
.655 .751 .92 r
.61144 .60302 .61893 .61096 .63383 .60666 .62639 .59872 Mtetra
.655 .752 .921 r
.62639 .59872 .63383 .60666 .64881 .60236 .64143 .5944 Mtetra
.656 .752 .921 r
.64143 .5944 .64881 .60236 .66386 .59803 .65654 .59003 Mtetra
.656 .753 .921 r
.65654 .59003 .66386 .59803 .679 .59369 .67173 .58561 Mtetra
.656 .752 .92 r
.67173 .58561 .679 .59369 .69422 .58933 .68701 .58118 Mtetra
.656 .751 .92 r
.68701 .58118 .69422 .58933 .70953 .58496 .70237 .57672 Mtetra
.656 .75 .919 r
.70237 .57672 .70953 .58496 .72492 .5806 .71781 .57225 Mtetra
.656 .748 .918 r
.71781 .57225 .72492 .5806 .74039 .57624 .73334 .56778 Mtetra
.655 .746 .917 r
.73334 .56778 .74039 .57624 .75595 .57186 .74895 .56331 Mtetra
.654 .745 .916 r
.74895 .56331 .75595 .57186 .7716 .56745 .76466 .55887 Mtetra
.653 .745 .917 r
.76466 .55887 .7716 .56745 .78732 .56289 .78045 .55444 Mtetra
.653 .749 .92 r
.78045 .55444 .78732 .56289 .80312 .55823 .79633 .54995 Mtetra
.658 .757 .923 r
.79633 .54995 .80312 .55823 .819 .55354 .81229 .54525 Mtetra
.659 .758 .923 r
.81229 .54525 .819 .55354 .83499 .54892 .82832 .54046 Mtetra
.658 .754 .921 r
.82832 .54046 .83499 .54892 .85106 .54432 .84445 .53572 Mtetra
.656 .751 .92 r
.84445 .53572 .85106 .54432 .86723 .53979 .86068 .53103 Mtetra
.653 .747 .919 r
.86068 .53103 .86723 .53979 .8835 .53524 .87701 .52642 Mtetra
.87701 .52642 .8835 .53524 .89984 .53051 .89343 .52181 Mtetra
.657 .753 .921 r
.89343 .52181 .89984 .53051 .91626 .52567 .90993 .517 Mtetra
.659 .756 .922 r
.90993 .517 .91626 .52567 .93278 .52087 .92651 .51208 Mtetra
.657 .753 .921 r
.92651 .51208 .93278 .52087 .9494 .5161 .94319 .50721 Mtetra
.655 .751 .92 r
.94319 .50721 .9494 .5161 .96613 .51142 .95998 .50239 Mtetra
.655 .75 .92 r
.36056 .66586 .36894 .67321 .38262 .66923 .37428 .66191 Mtetra
.652 .752 .922 r
.37428 .66191 .38262 .66923 .39637 .6653 .38807 .65802 Mtetra
.654 .754 .923 r
.38807 .65802 .39637 .6653 .41019 .66143 .40194 .65404 Mtetra
.659 .753 .919 r
.40194 .65404 .41019 .66143 .42408 .65745 .41588 .64985 Mtetra
.659 .749 .917 r
.41588 .64985 .42408 .65745 .43805 .65328 .4299 .64568 Mtetra
.656 .749 .918 r
.4299 .64568 .43805 .65328 .45209 .64913 .44398 .64158 Mtetra
.653 .751 .922 r
.44398 .64158 .45209 .64913 .4662 .64505 .45813 .63758 Mtetra
.651 .753 .924 r
.45813 .63758 .4662 .64505 .48038 .64102 .47236 .63359 Mtetra
.655 .756 .924 r
.47236 .63359 .48038 .64102 .49464 .63705 .48667 .62942 Mtetra
.66 .754 .92 r
.48667 .62942 .49464 .63705 .50897 .63299 .50105 .6251 Mtetra
.66 .748 .915 r
.50105 .6251 .50897 .63299 .52338 .62873 .51551 .62076 Mtetra
.658 .746 .915 r
.51551 .62076 .52338 .62873 .53787 .62442 .53004 .61649 Mtetra
.656 .748 .917 r
.53004 .61649 .53787 .62442 .55243 .62011 .54465 .61223 Mtetra
.654 .75 .92 r
.54465 .61223 .55243 .62011 .56706 .61584 .55934 .60802 Mtetra
.652 .752 .923 r
.55934 .60802 .56706 .61584 .58178 .61157 .57411 .60385 Mtetra
.652 .755 .925 r
.57411 .60385 .58178 .61157 .59657 .6073 .58896 .59964 Mtetra
.653 .758 .927 r
.58896 .59964 .59657 .6073 .61144 .60302 .60389 .59539 Mtetra
.653 .76 .928 r
.60389 .59539 .61144 .60302 .62639 .59872 .6189 .59107 Mtetra
.654 .761 .928 r
.6189 .59107 .62639 .59872 .64143 .5944 .63398 .58671 Mtetra
.655 .761 .928 r
.63398 .58671 .64143 .5944 .65654 .59003 .64915 .5823 Mtetra
.655 .762 .928 r
.64915 .5823 .65654 .59003 .67173 .58561 .66441 .57784 Mtetra
.656 .762 .927 r
.66441 .57784 .67173 .58561 .68701 .58118 .67974 .57333 Mtetra
.657 .761 .927 r
.67974 .57333 .68701 .58118 .70237 .57672 .69515 .56876 Mtetra
.658 .76 .925 r
.69515 .56876 .70237 .57672 .71781 .57225 .71065 .56414 Mtetra
.659 .757 .923 r
.71065 .56414 .71781 .57225 .73334 .56778 .72623 .55948 Mtetra
.657 .753 .921 r
.72623 .55948 .73334 .56778 .74895 .56331 .7419 .55486 Mtetra
.656 .75 .919 r
.7419 .55486 .74895 .56331 .76466 .55887 .75766 .55028 Mtetra
.655 .747 .918 r
.75766 .55028 .76466 .55887 .78045 .55444 .7735 .54572 Mtetra
.653 .745 .917 r
.7735 .54572 .78045 .55444 .79633 .54995 .78945 .54122 Mtetra
.652 .745 .918 r
.78945 .54122 .79633 .54995 .81229 .54525 .80548 .53671 Mtetra
.656 .752 .921 r
.80548 .53671 .81229 .54525 .82832 .54046 .8216 .53203 Mtetra
.659 .758 .923 r
.8216 .53203 .82832 .54046 .84445 .53572 .83778 .52716 Mtetra
.658 .756 .922 r
.83778 .52716 .84445 .53572 .86068 .53103 .85407 .52231 Mtetra
.656 .751 .92 r
.85407 .52231 .86068 .53103 .87701 .52642 .87045 .51754 Mtetra
.653 .748 .919 r
.87045 .51754 .87701 .52642 .89343 .52181 .88694 .51285 Mtetra
.653 .747 .919 r
.88694 .51285 .89343 .52181 .90993 .517 .90352 .50817 Mtetra
.657 .753 .921 r
.90352 .50817 .90993 .517 .92651 .51208 .92018 .50327 Mtetra
.659 .755 .921 r
.92018 .50327 .92651 .51208 .94319 .50721 .93692 .49827 Mtetra
.657 .753 .921 r
.93692 .49827 .94319 .50721 .95998 .50239 .95377 .49332 Mtetra
.653 .751 .922 r
.3521 .6585 .36056 .66586 .37428 .66191 .36586 .65458 Mtetra
.653 .753 .923 r
.36586 .65458 .37428 .66191 .38807 .65802 .3797 .65062 Mtetra
.659 .754 .92 r
.3797 .65062 .38807 .65802 .40194 .65404 .39361 .64642 Mtetra
.659 .749 .917 r
.39361 .64642 .40194 .65404 .41588 .64985 .4076 .64221 Mtetra
.656 .749 .918 r
.4076 .64221 .41588 .64985 .4299 .64568 .42166 .6381 Mtetra
.652 .751 .922 r
.42166 .6381 .4299 .64568 .44398 .64158 .43578 .63409 Mtetra
.651 .753 .925 r
.43578 .63409 .44398 .64158 .45813 .63758 .44998 .63009 Mtetra
.657 .756 .923 r
.44998 .63009 .45813 .63758 .47236 .63359 .46427 .62585 Mtetra
.661 .752 .918 r
.46427 .62585 .47236 .63359 .48667 .62942 .47862 .62148 Mtetra
.659 .747 .915 r
.47862 .62148 .48667 .62942 .50105 .6251 .49305 .61715 Mtetra
.657 .747 .917 r
.49305 .61715 .50105 .6251 .51551 .62076 .50756 .61289 Mtetra
.654 .749 .92 r
.50756 .61289 .51551 .62076 .53004 .61649 .52214 .6087 Mtetra
.65 .752 .924 r
.52214 .6087 .53004 .61649 .54465 .61223 .53681 .6046 Mtetra
.651 .757 .927 r
.53681 .6046 .54465 .61223 .55934 .60802 .55155 .60044 Mtetra
.653 .76 .928 r
.55155 .60044 .55934 .60802 .57411 .60385 .56637 .59617 Mtetra
.658 .76 .925 r
.56637 .59617 .57411 .60385 .58896 .59964 .58127 .59171 Mtetra
.657 .755 .922 r
.58127 .59171 .58896 .59964 .60389 .59539 .59625 .58726 Mtetra
.657 .75 .919 r
.59625 .58726 .60389 .59539 .6189 .59107 .61131 .58282 Mtetra
.656 .748 .917 r
.61131 .58282 .6189 .59107 .63398 .58671 .62645 .57837 Mtetra
.656 .747 .917 r
.62645 .57837 .63398 .58671 .64915 .5823 .64167 .57391 Mtetra
.64167 .57391 .64915 .5823 .66441 .57784 .65698 .56945 Mtetra
.655 .748 .918 r
.65698 .56945 .66441 .57784 .67974 .57333 .67238 .56498 Mtetra
.654 .75 .92 r
.67238 .56498 .67974 .57333 .69515 .56876 .68786 .56052 Mtetra
.653 .753 .923 r
.68786 .56052 .69515 .56876 .71065 .56414 .70342 .55607 Mtetra
.657 .76 .926 r
.70342 .55607 .71065 .56414 .72623 .55948 .71907 .55142 Mtetra
.659 .762 .926 r
.71907 .55142 .72623 .55948 .7419 .55486 .73479 .54665 Mtetra
.66 .76 .924 r
.73479 .54665 .7419 .55486 .75766 .55028 .7506 .54183 Mtetra
.658 .754 .921 r
.7506 .54183 .75766 .55028 .7735 .54572 .7665 .53709 Mtetra
.655 .75 .919 r
.7665 .53709 .7735 .54572 .78945 .54122 .7825 .53243 Mtetra
.653 .746 .918 r
.7825 .53243 .78945 .54122 .80548 .53671 .79859 .52783 Mtetra
.652 .745 .918 r
.79859 .52783 .80548 .53671 .8216 .53203 .81478 .52327 Mtetra
.654 .75 .92 r
.81478 .52327 .8216 .53203 .83778 .52716 .83105 .51857 Mtetra
.66 .757 .922 r
.83105 .51857 .83778 .52716 .85407 .52231 .8474 .51362 Mtetra
.659 .756 .922 r
.8474 .51362 .85407 .52231 .87045 .51754 .86383 .50867 Mtetra
.656 .751 .92 r
.86383 .50867 .87045 .51754 .88694 .51285 .88038 .50383 Mtetra
.653 .748 .919 r
.88038 .50383 .88694 .51285 .90352 .50817 .89703 .49908 Mtetra
.653 .747 .919 r
.89703 .49908 .90352 .50817 .92018 .50327 .91378 .49432 Mtetra
.658 .754 .921 r
.91378 .49432 .92018 .50327 .93692 .49827 .9306 .48929 Mtetra
.658 .755 .921 r
.9306 .48929 .93692 .49827 .95377 .49332 .94751 .48423 Mtetra
.652 .752 .923 r
.34355 .65111 .3521 .6585 .36586 .65458 .35736 .64716 Mtetra
.658 .754 .921 r
.35736 .64716 .36586 .65458 .3797 .65062 .37125 .643 Mtetra
.66 .75 .917 r
.37125 .643 .3797 .65062 .39361 .64642 .38521 .63874 Mtetra
.656 .749 .918 r
.38521 .63874 .39361 .64642 .4076 .64221 .39924 .6346 Mtetra
.652 .75 .922 r
.39924 .6346 .4076 .64221 .42166 .6381 .41334 .63056 Mtetra
.651 .753 .924 r
.41334 .63056 .42166 .6381 .43578 .63409 .42751 .62655 Mtetra
.658 .756 .922 r
.42751 .62655 .43578 .63409 .44998 .63009 .44176 .62228 Mtetra
.661 .751 .917 r
.44176 .62228 .44998 .63009 .46427 .62585 .45609 .61788 Mtetra
.659 .747 .915 r
.45609 .61788 .46427 .62585 .47862 .62148 .4705 .61355 Mtetra
.656 .748 .918 r
.4705 .61355 .47862 .62148 .49305 .61715 .48498 .60929 Mtetra
.65 .75 .922 r
.48498 .60929 .49305 .61715 .50756 .61289 .49953 .6052 Mtetra
.649 .755 .927 r
.49953 .6052 .50756 .61289 .52214 .6087 .51417 .60111 Mtetra
.654 .76 .927 r
.51417 .60111 .52214 .6087 .53681 .6046 .52888 .59679 Mtetra
.659 .757 .922 r
.52888 .59679 .53681 .6046 .55155 .60044 .54367 .5923 Mtetra
.657 .749 .918 r
.54367 .5923 .55155 .60044 .56637 .59617 .55854 .58788 Mtetra
.654 .745 .917 r
.55854 .58788 .56637 .59617 .58127 .59171 .5735 .58355 Mtetra
.651 .749 .921 r
.5735 .58355 .58127 .59171 .59625 .58726 .58854 .5793 Mtetra
.65 .755 .926 r
.58854 .5793 .59625 .58726 .61131 .58282 .60366 .57503 Mtetra
.652 .761 .929 r
.60366 .57503 .61131 .58282 .62645 .57837 .61886 .57066 Mtetra
.654 .765 .931 r
.61886 .57066 .62645 .57837 .64167 .57391 .63414 .56616 Mtetra
.657 .766 .93 r
.63414 .56616 .64167 .57391 .65698 .56945 .64951 .56153 Mtetra
.66 .763 .927 r
.64951 .56153 .65698 .56945 .67238 .56498 .66495 .5568 Mtetra
.66 .758 .922 r
.66495 .5568 .67238 .56498 .68786 .56052 .68048 .55205 Mtetra
.658 .751 .919 r
.68048 .55205 .68786 .56052 .70342 .55607 .69609 .54736 Mtetra
.655 .745 .916 r
.69609 .54736 .70342 .55607 .71907 .55142 .7118 .54278 Mtetra
.652 .747 .919 r
.7118 .54278 .71907 .55142 .73479 .54665 .7276 .53827 Mtetra
.656 .756 .924 r
.7276 .53827 .73479 .54665 .7506 .54183 .74349 .53357 Mtetra
.661 .762 .925 r
.74349 .53357 .7506 .54183 .7665 .53709 .75944 .52865 Mtetra
.661 .759 .923 r
.75944 .52865 .7665 .53709 .7825 .53243 .77549 .52371 Mtetra
.656 .752 .92 r
.77549 .52371 .7825 .53243 .79859 .52783 .79163 .51894 Mtetra
.654 .748 .919 r
.79163 .51894 .79859 .52783 .81478 .52327 .80788 .51425 Mtetra
.651 .745 .918 r
.80788 .51425 .81478 .52327 .83105 .51857 .82423 .50963 Mtetra
.654 .749 .919 r
.82423 .50963 .83105 .51857 .8474 .51362 .84066 .50487 Mtetra
.66 .757 .922 r
.84066 .50487 .8474 .51362 .86383 .50867 .85716 .49983 Mtetra
.659 .755 .922 r
.85716 .49983 .86383 .50867 .88038 .50383 .87376 .49481 Mtetra
.655 .751 .92 r
.87376 .49481 .88038 .50383 .89703 .49908 .89047 .48991 Mtetra
.652 .747 .919 r
.89047 .48991 .89703 .49908 .91378 .49432 .90729 .48511 Mtetra
.654 .748 .919 r
.90729 .48511 .91378 .49432 .9306 .48929 .9242 .48021 Mtetra
.659 .755 .921 r
.9242 .48021 .9306 .48929 .94751 .48423 .94118 .47508 Mtetra
.655 .753 .922 r
.33492 .64367 .34355 .65111 .35736 .64716 .34878 .63957 Mtetra
.66 .752 .918 r
.34878 .63957 .35736 .64716 .37125 .643 .36272 .63528 Mtetra
.657 .749 .917 r
.36272 .63528 .37125 .643 .38521 .63874 .37672 .63108 Mtetra
.653 .75 .921 r
.37672 .63108 .38521 .63874 .39924 .6346 .39079 .62699 Mtetra
.65 .752 .924 r
.39079 .62699 .39924 .6346 .41334 .63056 .40493 .62298 Mtetra
.657 .756 .923 r
.40493 .62298 .41334 .63056 .42751 .62655 .41916 .61873 Mtetra
.661 .751 .917 r
.41916 .61873 .42751 .62655 .44176 .62228 .43346 .61429 Mtetra
.659 .747 .916 r
.43346 .61429 .44176 .62228 .45609 .61788 .44784 .60993 Mtetra
.655 .749 .919 r
.44784 .60993 .45609 .61788 .4705 .61355 .46229 .60569 Mtetra
.648 .75 .924 r
.46229 .60569 .4705 .61355 .48498 .60929 .47682 .60164 Mtetra
.649 .757 .928 r
.47682 .60164 .48498 .60929 .49953 .6052 .49142 .59753 Mtetra
.66 .761 .924 r
.49142 .59753 .49953 .6052 .51417 .60111 .50611 .59299 Mtetra
.657 .749 .918 r
.50611 .59299 .51417 .60111 .52888 .59679 .52087 .58856 Mtetra
.649 .745 .92 r
.52087 .58856 .52888 .59679 .54367 .5923 .53572 .58441 Mtetra
.64 .752 .93 r
.53572 .58441 .54367 .5923 .55854 .58788 .55065 .58053 Mtetra
.631 .765 .943 r
.55065 .58053 .55854 .58788 .5735 .58355 .56567 .57682 Mtetra
.625 .781 .956 r
.56567 .57682 .5735 .58355 .58854 .5793 .58078 .57311 Mtetra
.618 .796 .967 r
.58078 .57311 .58854 .5793 .60366 .57503 .59597 .56941 Mtetra
.622 .816 .975 r
.59597 .56941 .60366 .57503 .61886 .57066 .61125 .56538 Mtetra
.635 .832 .976 r
.61125 .56538 .61886 .57066 .63414 .56616 .62661 .56084 Mtetra
.653 .837 .971 r
.62661 .56084 .63414 .56616 .64951 .56153 .64203 .55579 Mtetra
.667 .829 .962 r
.64203 .55579 .64951 .56153 .66495 .5568 .65752 .5504 Mtetra
.67 .812 .951 r
.65752 .5504 .66495 .5568 .68048 .55205 .67309 .545 Mtetra
.672 .796 .941 r
.67309 .545 .68048 .55205 .69609 .54736 .68874 .53962 Mtetra
.669 .777 .931 r
.68874 .53962 .69609 .54736 .7118 .54278 .70448 .53439 Mtetra
.662 .759 .922 r
.70448 .53439 .7118 .54278 .7276 .53827 .72032 .52944 Mtetra
.655 .747 .917 r
.72032 .52944 .7276 .53827 .74349 .53357 .73627 .52476 Mtetra
.651 .747 .92 r
.73627 .52476 .74349 .53357 .75944 .52865 .75231 .52021 Mtetra
.661 .761 .924 r
.75231 .52021 .75944 .52865 .77549 .52371 .76842 .5152 Mtetra
.662 .761 .923 r
.76842 .5152 .77549 .52371 .79163 .51894 .78462 .51013 Mtetra
.657 .753 .921 r
.78462 .51013 .79163 .51894 .80788 .51425 .80092 .50525 Mtetra
.654 .748 .919 r
.80092 .50525 .80788 .51425 .82423 .50963 .81732 .50048 Mtetra
.651 .745 .918 r
.81732 .50048 .82423 .50963 .84066 .50487 .83383 .4958 Mtetra
.655 .749 .919 r
.83383 .4958 .84066 .50487 .85716 .49983 .85042 .49093 Mtetra
.66 .757 .922 r
.85042 .49093 .85716 .49983 .87376 .49481 .86708 .48579 Mtetra
.658 .754 .921 r
.86708 .48579 .87376 .49481 .89047 .48991 .88385 .48073 Mtetra
.654 .75 .92 r
.88385 .48073 .89047 .48991 .90729 .48511 .90073 .47578 Mtetra
.652 .747 .919 r
.90073 .47578 .90729 .48511 .9242 .48021 .91772 .47092 Mtetra
.656 .751 .92 r
.91772 .47092 .9242 .48021 .94118 .47508 .93479 .46584 Mtetra
.66 .754 .92 r
.32621 .63612 .33492 .64367 .34878 .63957 .34012 .63184 Mtetra
.659 .75 .917 r
.34012 .63184 .34878 .63957 .36272 .63528 .3541 .62755 Mtetra
.655 .75 .92 r
.3541 .62755 .36272 .63528 .37672 .63108 .36814 .62339 Mtetra
.65 .751 .923 r
.36814 .62339 .37672 .63108 .39079 .62699 .38226 .61937 Mtetra
.654 .755 .924 r
.38226 .61937 .39079 .62699 .40493 .62298 .39645 .61518 Mtetra
.662 .753 .918 r
.39645 .61518 .40493 .62298 .41916 .61873 .41073 .61071 Mtetra
.659 .748 .916 r
.41073 .61071 .41916 .61873 .43346 .61429 .42508 .60631 Mtetra
.655 .749 .919 r
.42508 .60631 .43346 .61429 .44784 .60993 .4395 .60205 Mtetra
.648 .75 .924 r
.4395 .60205 .44784 .60993 .46229 .60569 .454 .59801 Mtetra
.651 .757 .927 r
.454 .59801 .46229 .60569 .47682 .60164 .46857 .5938 Mtetra
.661 .757 .922 r
.46857 .5938 .47682 .60164 .49142 .59753 .48324 .58924 Mtetra
.653 .745 .917 r
.48324 .58924 .49142 .59753 .50611 .59299 .49797 .58496 Mtetra
.636 .747 .929 r
.49797 .58496 .50611 .59299 .52087 .58856 .51279 .58121 Mtetra
.615 .76 .948 r
.51279 .58121 .52087 .58856 .53572 .58441 .52769 .57799 Mtetra
.571 .772 .974 r
.52769 .57799 .53572 .58441 .55065 .58053 .54269 .57559 Mtetra
.53 .803 .996 r
.54269 .57559 .55065 .58053 .56567 .57682 .55779 .57331 Mtetra
.502 .836 .998 r
.55779 .57331 .56567 .57682 .58078 .57311 .57298 .57056 Mtetra
.493 .859 .987 r
.57298 .57056 .58078 .57311 .59597 .56941 .58827 .56721 Mtetra
.512 .876 .982 r
.58827 .56721 .59597 .56941 .61125 .56538 .60363 .56324 Mtetra
.544 .891 .981 r
.60363 .56324 .61125 .56538 .62661 .56084 .61907 .55866 Mtetra
.577 .904 .981 r
.61907 .55866 .62661 .56084 .64203 .55579 .63458 .55347 Mtetra
.612 .914 .98 r
.63458 .55347 .64203 .55579 .65752 .5504 .65014 .54765 Mtetra
.652 .916 .978 r
.65014 .54765 .65752 .5504 .67309 .545 .66576 .54122 Mtetra
.691 .899 .971 r
.66576 .54122 .67309 .545 .68874 .53962 .68142 .5343 Mtetra
.702 .857 .956 r
.68142 .5343 .68874 .53962 .70448 .53439 .69716 .52749 Mtetra
.684 .808 .941 r
.69716 .52749 .70448 .53439 .72032 .52944 .71302 .5215 Mtetra
.672 .778 .929 r
.71302 .5215 .72032 .52944 .73627 .52476 .72899 .51604 Mtetra
.659 .754 .921 r
.72899 .51604 .73627 .52476 .75231 .52021 .74508 .51111 Mtetra
.651 .744 .917 r
.74508 .51111 .75231 .52021 .76842 .5152 .76128 .50648 Mtetra
.659 .757 .922 r
.76128 .50648 .76842 .5152 .78462 .51013 .77755 .50147 Mtetra
.663 .761 .923 r
.77755 .50147 .78462 .51013 .80092 .50525 .79389 .4963 Mtetra
.657 .753 .921 r
.79389 .4963 .80092 .50525 .81732 .50048 .81035 .49135 Mtetra
.653 .748 .92 r
.81035 .49135 .81732 .50048 .83383 .4958 .82692 .48653 Mtetra
.651 .745 .919 r
.82692 .48653 .83383 .4958 .85042 .49093 .8436 .48177 Mtetra
.657 .752 .92 r
.8436 .48177 .85042 .49093 .86708 .48579 .86034 .47673 Mtetra
.661 .757 .921 r
.86034 .47673 .86708 .48579 .88385 .48073 .87717 .4715 Mtetra
.656 .752 .921 r
.87717 .4715 .88385 .48073 .90073 .47578 .89411 .46642 Mtetra
.653 .749 .92 r
.89411 .46642 .90073 .47578 .91772 .47092 .91116 .46145 Mtetra
.652 .747 .919 r
.91116 .46145 .91772 .47092 .93479 .46584 .92832 .45648 Mtetra
.661 .751 .917 r
.31742 .62839 .32621 .63612 .34012 .63184 .33138 .62403 Mtetra
.657 .749 .918 r
.33138 .62403 .34012 .63184 .3541 .62755 .3454 .6198 Mtetra
.652 .75 .922 r
.3454 .6198 .3541 .62755 .36814 .62339 .35948 .61571 Mtetra
.651 .753 .925 r
.35948 .61571 .36814 .62339 .38226 .61937 .37364 .61162 Mtetra
.661 .755 .92 r
.37364 .61162 .38226 .61937 .39645 .61518 .38789 .60716 Mtetra
.661 .749 .916 r
.38789 .60716 .39645 .61518 .41073 .61071 .40222 .60269 Mtetra
.656 .749 .918 r
.40222 .60269 .41073 .61071 .42508 .60631 .41661 .59836 Mtetra
.648 .75 .924 r
.41661 .59836 .42508 .60631 .4395 .60205 .43108 .5943 Mtetra
.65 .756 .927 r
.43108 .5943 .4395 .60205 .454 .59801 .44562 .59011 Mtetra
.661 .757 .921 r
.44562 .59011 .454 .59801 .46857 .5938 .46026 .58551 Mtetra
.649 .744 .919 r
.46026 .58551 .46857 .5938 .48324 .58924 .47496 .58135 Mtetra
.623 .748 .936 r
.47496 .58135 .48324 .58924 .49797 .58496 .48974 .57798 Mtetra
.571 .756 .965 r
.48974 .57798 .49797 .58496 .51279 .58121 .5046 .57577 Mtetra
.484 .769 .994 r
.5046 .57577 .51279 .58121 .52769 .57799 .51956 .57458 Mtetra
.418 .801 .991 r
.51956 .57458 .52769 .57799 .54269 .57559 .53463 .57301 Mtetra
.428 .827 .981 r
.53463 .57301 .54269 .57559 .55779 .57331 .54981 .57063 Mtetra
.491 .855 .989 r
.54981 .57063 .55779 .57331 .57298 .57056 .56507 .5674 Mtetra
.551 .867 .995 r
.56507 .5674 .57298 .57056 .58827 .56721 .58043 .56348 Mtetra
.591 .867 .994 r
.58043 .56348 .58827 .56721 .60363 .56324 .59586 .55913 Mtetra
.611 .863 .991 r
.59586 .55913 .60363 .56324 .61907 .55866 .61138 .55451 Mtetra
.622 .867 .989 r
.61138 .55451 .61907 .55866 .63458 .55347 .62698 .54962 Mtetra
.632 .88 .987 r
.62698 .54962 .63458 .55347 .65014 .54765 .64264 .54429 Mtetra
.647 .899 .983 r
.64264 .54429 .65014 .54765 .66576 .54122 .65837 .53827 Mtetra
.671 .918 .975 r
.65837 .53827 .66576 .54122 .68142 .5343 .67413 .53137 Mtetra
.7 .927 .966 r
.67413 .53137 .68142 .5343 .69716 .52749 .68992 .52364 Mtetra
.725 .908 .958 r
.68992 .52364 .69716 .52749 .71302 .5215 .70575 .5155 Mtetra
.71 .844 .947 r
.70575 .5155 .71302 .5215 .72899 .51604 .7217 .50837 Mtetra
.682 .792 .933 r
.7217 .50837 .72899 .51604 .74508 .51111 .73779 .50243 Mtetra
.662 .76 .923 r
.73779 .50243 .74508 .51111 .76128 .50648 .75403 .49729 Mtetra
.651 .744 .918 r
.75403 .49729 .76128 .50648 .77755 .50147 .77039 .49259 Mtetra
.66 .757 .922 r
.77039 .49259 .77755 .50147 .79389 .4963 .78681 .48747 Mtetra
.663 .761 .923 r
.78681 .48747 .79389 .4963 .81035 .49135 .80332 .48222 Mtetra
.656 .752 .921 r
.80332 .48222 .81035 .49135 .82692 .48653 .81995 .47722 Mtetra
.652 .747 .92 r
.81995 .47722 .82692 .48653 .8436 .48177 .83668 .47238 Mtetra
.651 .746 .919 r
.83668 .47238 .8436 .48177 .86034 .47673 .85352 .46752 Mtetra
.66 .755 .921 r
.85352 .46752 .86034 .47673 .87717 .4715 .87042 .46227 Mtetra
.659 .756 .921 r
.87042 .46227 .87717 .4715 .89411 .46642 .88742 .45701 Mtetra
.655 .751 .92 r
.88742 .45701 .89411 .46642 .91116 .46145 .90454 .45189 Mtetra
.652 .747 .92 r
.90454 .45189 .91116 .46145 .92832 .45648 .92177 .4469 Mtetra
.659 .75 .917 r
.30855 .62056 .31742 .62839 .33138 .62403 .32255 .61622 Mtetra
.655 .75 .92 r
.32255 .61622 .33138 .62403 .3454 .6198 .33661 .61201 Mtetra
.649 .751 .924 r
.33661 .61201 .3454 .6198 .35948 .61571 .35073 .60795 Mtetra
.657 .755 .922 r
.35073 .60795 .35948 .61571 .37364 .61162 .36495 .60361 Mtetra
.662 .751 .916 r
.36495 .60361 .37364 .61162 .38789 .60716 .37925 .59907 Mtetra
.658 .749 .917 r
.37925 .59907 .38789 .60716 .40222 .60269 .39362 .59467 Mtetra
.65 .749 .922 r
.39362 .59467 .40222 .60269 .41661 .59836 .40805 .59052 Mtetra
.647 .754 .927 r
.40805 .59052 .41661 .59836 .43108 .5943 .42257 .58644 Mtetra
.662 .759 .922 r
.42257 .58644 .43108 .5943 .44562 .59011 .43717 .58178 Mtetra
.649 .745 .919 r
.43717 .58178 .44562 .59011 .46026 .58551 .45185 .57759 Mtetra
.616 .746 .939 r
.45185 .57759 .46026 .58551 .47496 .58135 .46659 .57441 Mtetra
.533 .744 .973 r
.46659 .57441 .47496 .58135 .48974 .57798 .48139 .57301 Mtetra
.418 .756 .995 r
.48139 .57301 .48974 .57798 .5046 .57577 .4963 .57254 Mtetra
.379 .786 .982 r
.4963 .57254 .5046 .57577 .51956 .57458 .51133 .57133 Mtetra
.477 .834 .995 r
.51133 .57133 .51956 .57458 .53463 .57301 .52647 .56875 Mtetra
.592 .85 .993 r
.52647 .56875 .53463 .57301 .54981 .57063 .5417 .56474 Mtetra
.676 .826 .956 r
.5417 .56474 .54981 .57063 .56507 .5674 .55701 .5591 Mtetra
.688 .766 .911 r
.55701 .5591 .56507 .5674 .58043 .56348 .57239 .55316 Mtetra
.673 .718 .883 r
.57239 .55316 .58043 .56348 .59586 .55913 .58786 .54773 Mtetra
.655 .691 .872 r
.58786 .54773 .59586 .55913 .61138 .55451 .60342 .54305 Mtetra
.637 .684 .878 r
.60342 .54305 .61138 .55451 .62698 .54962 .61909 .53915 Mtetra
.624 .7 .899 r
.61909 .53915 .62698 .54962 .64264 .54429 .63488 .53575 Mtetra
.625 .746 .934 r
.63488 .53575 .64264 .54429 .65837 .53827 .65075 .53207 Mtetra
.66 .823 .962 r
.65075 .53207 .65837 .53827 .67413 .53137 .66666 .52673 Mtetra
.691 .878 .968 r
.66666 .52673 .67413 .53137 .68992 .52364 .68258 .51994 Mtetra
.723 .913 .96 r
.68258 .51994 .68992 .52364 .70575 .5155 .69851 .51174 Mtetra
.745 .917 .95 r
.69851 .51174 .70575 .5155 .7217 .50837 .71445 .50276 Mtetra
.73 .864 .944 r
.71445 .50276 .7217 .50837 .73779 .50243 .7305 .49471 Mtetra
.687 .796 .932 r
.7305 .49471 .73779 .50243 .75403 .49729 .74674 .48847 Mtetra
.662 .76 .923 r
.74674 .48847 .75403 .49729 .77039 .49259 .76313 .48325 Mtetra
.65 .744 .919 r
.76313 .48325 .77039 .49259 .78681 .48747 .77965 .47851 Mtetra
.663 .76 .922 r
.77965 .47851 .78681 .48747 .80332 .48222 .79623 .47318 Mtetra
.661 .758 .922 r
.79623 .47318 .80332 .48222 .81995 .47722 .8129 .46791 Mtetra
.654 .75 .92 r
.8129 .46791 .81995 .47722 .83668 .47238 .8297 .46289 Mtetra
.65 .746 .919 r
.8297 .46289 .83668 .47238 .85352 .46752 .84661 .45802 Mtetra
.655 .749 .919 r
.84661 .45802 .85352 .46752 .87042 .46227 .8636 .45293 Mtetra
.661 .756 .921 r
.8636 .45293 .87042 .46227 .88742 .45701 .88067 .44754 Mtetra
.657 .753 .921 r
.88067 .44754 .88742 .45701 .90454 .45189 .89785 .44229 Mtetra
.653 .749 .921 r
.89785 .44229 .90454 .45189 .92177 .4469 .91515 .43719 Mtetra
.657 .75 .918 r
.29959 .61266 .30855 .62056 .32255 .61622 .31363 .60835 Mtetra
.652 .75 .922 r
.31363 .60835 .32255 .61622 .33661 .61201 .32773 .6042 Mtetra
.651 .753 .924 r
.32773 .6042 .33661 .61201 .35073 .60795 .3419 .60005 Mtetra
.662 .754 .919 r
.3419 .60005 .35073 .60795 .36495 .60361 .35617 .59549 Mtetra
.66 .749 .916 r
.35617 .59549 .36495 .60361 .37925 .59907 .37052 .59098 Mtetra
.654 .75 .92 r
.37052 .59098 .37925 .59907 .39362 .59467 .38493 .58668 Mtetra
.646 .751 .926 r
.38493 .58668 .39362 .59467 .40805 .59052 .39941 .58261 Mtetra
.658 .757 .923 r
.39941 .58261 .40805 .59052 .42257 .58644 .41398 .57808 Mtetra
.654 .746 .917 r
.41398 .57808 .42257 .58644 .43717 .58178 .42863 .57369 Mtetra
.619 .744 .935 r
.42863 .57369 .43717 .58178 .45185 .57759 .44333 .57041 Mtetra
.526 .736 .971 r
.44333 .57041 .45185 .57759 .46659 .57441 .45808 .5692 Mtetra
.386 .734 .991 r
.45808 .5692 .46659 .57441 .48139 .57301 .47293 .5693 Mtetra
.381 .776 .987 r
.47293 .5693 .48139 .57301 .4963 .57254 .4879 .5684 Mtetra
.536 .833 .999 r
.4879 .5684 .4963 .57254 .51133 .57133 .503 .56542 Mtetra
.694 .829 .947 r
.503 .56542 .51133 .57133 .52647 .56875 .51821 .55919 Mtetra
.724 .747 .87 r
.51821 .55919 .52647 .56875 .5417 .56474 .53348 .55126 Mtetra
.704 .675 .819 r
.53348 .55126 .5417 .56474 .55701 .5591 .54881 .54333 Mtetra
.684 .639 .799 r
.54881 .54333 .55701 .5591 .57239 .55316 .56421 .53609 Mtetra
.663 .616 .792 r
.56421 .53609 .57239 .55316 .58786 .54773 .57968 .53002 Mtetra
.641 .599 .791 r
.57968 .53002 .58786 .54773 .60342 .54305 .59526 .52528 Mtetra
.62 .588 .797 r
.59526 .52528 .60342 .54305 .61909 .53915 .61096 .5219 Mtetra
.6 .585 .807 r
.61096 .5219 .61909 .53915 .63488 .53575 .6268 .51969 Mtetra
.586 .592 .825 r
.6268 .51969 .63488 .53575 .65075 .53207 .64278 .51819 Mtetra
.582 .622 .857 r
.64278 .51819 .65075 .53207 .66666 .52673 .65888 .51672 Mtetra
.613 .711 .914 r
.65888 .51672 .66666 .52673 .68258 .51994 .67503 .51353 Mtetra
.691 .831 .95 r
.67503 .51353 .68258 .51994 .69851 .51174 .69113 .50704 Mtetra
.74 .892 .948 r
.69113 .50704 .69851 .51174 .71445 .50276 .70718 .49842 Mtetra
.763 .907 .939 r
.70718 .49842 .71445 .50276 .7305 .49471 .72324 .48875 Mtetra
.736 .859 .938 r
.72324 .48875 .7305 .49471 .74674 .48847 .73942 .48039 Mtetra
.685 .789 .929 r
.73942 .48039 .74674 .48847 .76313 .48325 .75582 .47414 Mtetra
.657 .755 .922 r
.75582 .47414 .76313 .48325 .77965 .47851 .77238 .46903 Mtetra
.653 .746 .918 r
.77238 .46903 .77965 .47851 .79623 .47318 .78906 .46407 Mtetra
.664 .76 .921 r
.78906 .46407 .79623 .47318 .8129 .46791 .80579 .4586 Mtetra
.658 .754 .921 r
.80579 .4586 .8129 .46791 .8297 .46289 .82265 .45339 Mtetra
.652 .749 .92 r
.82265 .45339 .8297 .46289 .84661 .45802 .83962 .44838 Mtetra
.65 .746 .92 r
.83962 .44838 .84661 .45802 .8636 .45293 .8567 .44342 Mtetra
.66 .754 .92 r
.8567 .44342 .8636 .45293 .88067 .44754 .87384 .43803 Mtetra
.659 .756 .921 r
.87384 .43803 .88067 .44754 .89785 .44229 .89109 .43262 Mtetra
.655 .751 .921 r
.89109 .43262 .89785 .44229 .91515 .43719 .90846 .42738 Mtetra
.655 .75 .92 r
.29054 .60473 .29959 .61266 .31363 .60835 .30462 .60043 Mtetra
.649 .75 .923 r
.30462 .60043 .31363 .60835 .32773 .6042 .31876 .59631 Mtetra
.656 .754 .922 r
.31876 .59631 .32773 .6042 .3419 .60005 .33299 .59194 Mtetra
.662 .751 .916 r
.33299 .59194 .3419 .60005 .35617 .59549 .34731 .58732 Mtetra
.657 .749 .918 r
.34731 .58732 .35617 .59549 .37052 .59098 .3617 .58286 Mtetra
.648 .749 .923 r
.3617 .58286 .37052 .59098 .38493 .58668 .37615 .5787 Mtetra
.65 .755 .926 r
.37615 .5787 .38493 .58668 .39941 .58261 .39068 .57443 Mtetra
.66 .753 .919 r
.39068 .57443 .39941 .58261 .41398 .57808 .40531 .56978 Mtetra
.633 .743 .928 r
.40531 .56978 .41398 .57808 .42863 .57369 .41998 .56608 Mtetra
.555 .736 .96 r
.41998 .56608 .42863 .57369 .44333 .57041 .43469 .56434 Mtetra
.39 .711 .986 r
.43469 .56434 .44333 .57041 .45808 .5692 .44946 .56487 Mtetra
.369 .753 .989 r
.44946 .56487 .45808 .5692 .47293 .5693 .46437 .56454 Mtetra
.553 .822 .996 r
.46437 .56454 .47293 .5693 .4879 .5684 .47943 .56157 Mtetra
.732 .811 .913 r
.47943 .56157 .4879 .5684 .503 .56542 .49463 .5538 Mtetra
.74 .714 .828 r
.49463 .5538 .503 .56542 .51821 .55919 .5099 .54404 Mtetra
.722 .661 .79 r
.5099 .54404 .51821 .55919 .53348 .55126 .52521 .53405 Mtetra
.699 .631 .777 r
.52521 .53405 .53348 .55126 .54881 .54333 .54056 .52512 Mtetra
.676 .611 .776 r
.54056 .52512 .54881 .54333 .56421 .53609 .55597 .51771 Mtetra
.657 .601 .78 r
.55597 .51771 .56421 .53609 .57968 .53002 .57146 .51172 Mtetra
.64 .594 .786 r
.57146 .51172 .57968 .53002 .59526 .52528 .58705 .50692 Mtetra
.621 .584 .791 r
.58705 .50692 .59526 .52528 .61096 .5219 .60276 .50333 Mtetra
.598 .57 .794 r
.60276 .50333 .61096 .5219 .6268 .51969 .6186 .50117 Mtetra
.57 .557 .8 r
.6186 .50117 .6268 .51969 .64278 .51819 .63462 .50055 Mtetra
.547 .555 .814 r
.63462 .50055 .64278 .51819 .65888 .51672 .65081 .50105 Mtetra
.545 .579 .84 r
.65081 .50105 .65888 .51672 .67503 .51353 .66714 .50132 Mtetra
.58 .654 .887 r
.66714 .50132 .67503 .51353 .69113 .50704 .68352 .4996 Mtetra
.694 .807 .935 r
.68352 .4996 .69113 .50704 .70718 .49842 .69976 .49299 Mtetra
.756 .878 .934 r
.69976 .49299 .70718 .49842 .72324 .48875 .71593 .48368 Mtetra
.776 .892 .927 r
.71593 .48368 .72324 .48875 .73942 .48039 .7321 .47344 Mtetra
.724 .833 .932 r
.7321 .47344 .73942 .48039 .75582 .47414 .74846 .46551 Mtetra
.675 .776 .926 r
.74846 .46551 .75582 .47414 .77238 .46903 .76505 .45959 Mtetra
.651 .748 .921 r
.76505 .45959 .77238 .46903 .78906 .46407 .7818 .45464 Mtetra
.66 .754 .919 r
.7818 .45464 .78906 .46407 .80579 .4586 .79861 .4493 Mtetra
.662 .759 .922 r
.79861 .4493 .80579 .4586 .82265 .45339 .81552 .44384 Mtetra
.654 .751 .921 r
.81552 .44384 .82265 .45339 .83962 .44838 .83256 .43867 Mtetra
.65 .746 .92 r
.83256 .43867 .83962 .44838 .8567 .44342 .84971 .43367 Mtetra
.656 .749 .919 r
.84971 .43367 .8567 .44342 .87384 .43803 .86695 .42841 Mtetra
.661 .756 .92 r
.86695 .42841 .87384 .43803 .89109 .43262 .88426 .42287 Mtetra
.656 .752 .921 r
.88426 .42287 .89109 .43262 .90846 .42738 .90169 .41751 Mtetra
.653 .751 .921 r
.2814 .59674 .29054 .60473 .30462 .60043 .29552 .59246 Mtetra
.649 .751 .924 r
.29552 .59246 .30462 .60043 .31876 .59631 .3097 .58831 Mtetra
.66 .754 .92 r
.3097 .58831 .31876 .59631 .33299 .59194 .32399 .58374 Mtetra
.661 .751 .916 r
.32399 .58374 .33299 .59194 .34731 .58732 .33835 .57913 Mtetra
.654 .75 .92 r
.33835 .57913 .34731 .58732 .3617 .58286 .35278 .57472 Mtetra
.645 .75 .926 r
.35278 .57472 .3617 .58286 .37615 .5787 .36728 .57062 Mtetra
.659 .756 .922 r
.36728 .57062 .37615 .5787 .39068 .57443 .38187 .566 Mtetra
.65 .746 .92 r
.38187 .566 .39068 .57443 .40531 .56978 .39653 .5617 Mtetra
.599 .74 .943 r
.39653 .5617 .40531 .56978 .41998 .56608 .41123 .55893 Mtetra
.44 .704 .978 r
.41123 .55893 .41998 .56608 .43469 .56434 .42593 .55924 Mtetra
.342 .718 .985 r
.42593 .55924 .43469 .56434 .44946 .56487 .44074 .55975 Mtetra
.515 .798 .997 r
.44074 .55975 .44946 .56487 .46437 .56454 .45574 .55764 Mtetra
.732 .809 .913 r
.45574 .55764 .46437 .56454 .47943 .56157 .47094 .54987 Mtetra
.755 .718 .818 r
.47094 .54987 .47943 .56157 .49463 .5538 .48622 .53886 Mtetra
.741 .671 .783 r
.48622 .53886 .49463 .5538 .5099 .54404 .50154 .52724 Mtetra
.713 .641 .776 r
.50154 .52724 .5099 .54404 .52521 .53405 .51688 .51722 Mtetra
.673 .624 .792 r
.51688 .51722 .52521 .53405 .54056 .52512 .53227 .51043 Mtetra
.66 .644 .823 r
.53227 .51043 .54056 .52512 .55597 .51771 .54773 .50494 Mtetra
.656 .671 .853 r
.54773 .50494 .55597 .51771 .57146 .51172 .56327 .49997 Mtetra
.655 .69 .87 r
.56327 .49997 .57146 .51172 .58705 .50692 .57891 .49512 Mtetra
.652 .688 .871 r
.57891 .49512 .58705 .50692 .60276 .50333 .59463 .49039 Mtetra
.639 .664 .858 r
.59463 .49039 .60276 .50333 .6186 .50117 .61047 .48618 Mtetra
.611 .621 .837 r
.61047 .48618 .6186 .50117 .63462 .50055 .62644 .4833 Mtetra
.546 .56 .82 r
.62644 .4833 .63462 .50055 .65081 .50105 .64264 .48369 Mtetra
.51 .54 .823 r
.64264 .48369 .65081 .50105 .66714 .50132 .65905 .48573 Mtetra
.514 .566 .847 r
.65905 .48573 .66714 .50132 .68352 .4996 .6756 .48719 Mtetra
.581 .653 .886 r
.6756 .48719 .68352 .4996 .69976 .49299 .69214 .48538 Mtetra
.716 .812 .925 r
.69214 .48538 .69976 .49299 .71593 .48368 .70849 .47778 Mtetra
.775 .871 .918 r
.70849 .47778 .71593 .48368 .7321 .47344 .72475 .46747 Mtetra
.771 .871 .921 r
.72475 .46747 .7321 .47344 .74846 .46551 .74107 .45735 Mtetra
.699 .798 .926 r
.74107 .45735 .74846 .46551 .76505 .45959 .75765 .45036 Mtetra
.661 .76 .923 r
.75765 .45036 .76505 .45959 .7818 .45464 .77444 .44496 Mtetra
.653 .747 .919 r
.77444 .44496 .7818 .45464 .79861 .4493 .79136 .43987 Mtetra
.665 .759 .92 r
.79136 .43987 .79861 .4493 .81552 .44384 .80833 .43424 Mtetra
.657 .753 .921 r
.80833 .43424 .81552 .44384 .83256 .43867 .82542 .42892 Mtetra
.651 .748 .921 r
.82542 .42892 .83256 .43867 .84971 .43367 .84265 .42381 Mtetra
.652 .748 .92 r
.84265 .42381 .84971 .43367 .86695 .42841 .85997 .41864 Mtetra
.661 .755 .92 r
.85997 .41864 .86695 .42841 .88426 .42287 .87735 .41304 Mtetra
.658 .754 .921 r
.87735 .41304 .88426 .42287 .90169 .41751 .89486 .40755 Mtetra
.651 .75 .922 r
.27216 .58868 .2814 .59674 .29552 .59246 .28632 .58443 Mtetra
.651 .752 .923 r
.28632 .58443 .29552 .59246 .3097 .58831 .30056 .58016 Mtetra
.662 .753 .917 r
.30056 .58016 .3097 .58831 .32399 .58374 .3149 .57547 Mtetra
.659 .75 .917 r
.3149 .57547 .32399 .58374 .33835 .57913 .32931 .57088 Mtetra
.65 .75 .922 r
.32931 .57088 .33835 .57913 .35278 .57472 .34378 .56657 Mtetra
.647 .752 .926 r
.34378 .56657 .35278 .57472 .36728 .57062 .35832 .56237 Mtetra
.662 .755 .919 r
.35832 .56237 .36728 .57062 .38187 .566 .37297 .55759 Mtetra
.632 .744 .928 r
.37297 .55759 .38187 .566 .39653 .5617 .38766 .55383 Mtetra
.535 .725 .962 r
.38766 .55383 .39653 .5617 .41123 .55893 .40234 .55255 Mtetra
.352 .687 .98 r
.40234 .55255 .41123 .55893 .42593 .55924 .41706 .5537 Mtetra
.429 .75 .994 r
.41706 .5537 .42593 .55924 .44074 .55975 .43196 .5532 Mtetra
.682 .81 .944 r
.43196 .5532 .44074 .55975 .45574 .55764 .4471 .54743 Mtetra
.769 .746 .832 r
.4471 .54743 .45574 .55764 .47094 .54987 .46241 .53612 Mtetra
.761 .693 .786 r
.46241 .53612 .47094 .54987 .48622 .53886 .47777 .52324 Mtetra
.729 .66 .782 r
.47777 .52324 .48622 .53886 .50154 .52724 .49313 .51236 Mtetra
.679 .65 .814 r
.49313 .51236 .50154 .52724 .51688 .51722 .50849 .50568 Mtetra
.655 .693 .873 r
.50849 .50568 .51688 .51722 .53227 .51043 .52392 .50085 Mtetra
.634 .726 .915 r
.52392 .50085 .53227 .51043 .54773 .50494 .53944 .4969 Mtetra
.636 .766 .941 r
.53944 .4969 .54773 .50494 .56327 .49997 .55506 .49265 Mtetra
.652 .791 .949 r
.55506 .49265 .56327 .49997 .57891 .49512 .57076 .48775 Mtetra
.67 .796 .942 r
.57076 .48775 .57891 .49512 .59463 .49039 .58654 .4822 Mtetra
.679 .779 .926 r
.58654 .4822 .59463 .49039 .61047 .48618 .6024 .47635 Mtetra
.657 .734 .907 r
.6024 .47635 .61047 .48618 .62644 .4833 .61836 .47137 Mtetra
.612 .675 .886 r
.61836 .47137 .62644 .4833 .64264 .48369 .63448 .46828 Mtetra
.518 .572 .849 r
.63448 .46828 .64264 .48369 .65905 .48573 .65088 .46945 Mtetra
.47 .534 .841 r
.65088 .46945 .65905 .48573 .6756 .48719 .66752 .47269 Mtetra
.498 .577 .866 r
.66752 .47269 .6756 .48719 .69214 .48538 .68427 .47437 Mtetra
.629 .705 .901 r
.68427 .47437 .69214 .48538 .70849 .47778 .70088 .47041 Mtetra
.752 .831 .912 r
.70088 .47041 .70849 .47778 .72475 .46747 .71729 .46105 Mtetra
.787 .863 .905 r
.71729 .46105 .72475 .46747 .74107 .45735 .73364 .44996 Mtetra
.736 .83 .923 r
.73364 .44996 .74107 .45735 .75765 .45036 .7502 .44134 Mtetra
.676 .772 .923 r
.7502 .44134 .75765 .45036 .77444 .44496 .76702 .43527 Mtetra
.65 .748 .921 r
.76702 .43527 .77444 .44496 .79136 .43987 .78401 .43024 Mtetra
.664 .756 .919 r
.78401 .43024 .79136 .43987 .80833 .43424 .80106 .42461 Mtetra
.661 .756 .921 r
.80106 .42461 .80833 .43424 .82542 .42892 .81821 .41908 Mtetra
.653 .75 .921 r
.81821 .41908 .82542 .42892 .84265 .42381 .8355 .41385 Mtetra
.65 .747 .921 r
.8355 .41385 .84265 .42381 .85997 .41864 .85291 .40871 Mtetra
.66 .753 .919 r
.85291 .40871 .85997 .41864 .87735 .41304 .87038 .40312 Mtetra
.659 .755 .92 r
.87038 .40312 .87735 .41304 .89486 .40755 .88795 .3975 Mtetra
.65 .75 .923 r
.26284 .58055 .27216 .58868 .28632 .58443 .27704 .5763 Mtetra
.654 .752 .922 r
.27704 .5763 .28632 .58443 .30056 .58016 .29133 .57189 Mtetra
.663 .752 .916 r
.29133 .57189 .30056 .58016 .3149 .57547 .30571 .56714 Mtetra
.658 .75 .918 r
.30571 .56714 .3149 .57547 .32931 .57088 .32017 .56256 Mtetra
.647 .749 .924 r
.32017 .56256 .32931 .57088 .34378 .56657 .33468 .55832 Mtetra
.653 .753 .923 r
.33468 .55832 .34378 .56657 .35832 .56237 .34928 .55386 Mtetra
.657 .749 .918 r
.34928 .55386 .35832 .56237 .37297 .55759 .36397 .54922 Mtetra
.611 .74 .937 r
.36397 .54922 .37297 .55759 .38766 .55383 .37868 .54607 Mtetra
.458 .698 .971 r
.37868 .54607 .38766 .55383 .40234 .55255 .39335 .54624 Mtetra
.352 .691 .981 r
.39335 .54624 .40234 .55255 .41706 .5537 .40812 .54729 Mtetra
.543 .774 .983 r
.40812 .54729 .41706 .5537 .43196 .5532 .42311 .54514 Mtetra
.761 .788 .875 r
.42311 .54514 .43196 .5532 .4471 .54743 .43841 .53543 Mtetra
.778 .721 .799 r
.43841 .53543 .4471 .54743 .46241 .53612 .45383 .52205 Mtetra
.759 .689 .785 r
.45383 .52205 .46241 .53612 .47777 .52324 .46924 .50914 Mtetra
.695 .667 .819 r
.46924 .50914 .47777 .52324 .49313 .51236 .4846 .5016 Mtetra
.648 .706 .89 r
.4846 .5016 .49313 .51236 .50849 .50568 .5 .49713 Mtetra
.6 .74 .943 r
.5 .49713 .50849 .50568 .52392 .50085 .51548 .49412 Mtetra
.596 .789 .973 r
.51548 .49412 .52392 .50085 .53944 .4969 .53107 .49069 Mtetra
.628 .815 .972 r
.53107 .49069 .53944 .4969 .55506 .49265 .54675 .48623 Mtetra
.645 .816 .965 r
.54675 .48623 .55506 .49265 .57076 .48775 .56253 .48128 Mtetra
.66 .82 .96 r
.56253 .48128 .57076 .48775 .58654 .4822 .57838 .47585 Mtetra
.69 .833 .952 r
.57838 .47585 .58654 .4822 .6024 .47635 .59431 .46937 Mtetra
.702 .82 .938 r
.59431 .46937 .6024 .47635 .61836 .47137 .6103 .46247 Mtetra
.666 .762 .922 r
.6103 .46247 .61836 .47137 .63448 .46828 .6264 .45703 Mtetra
.588 .681 .905 r
.6264 .45703 .63448 .46828 .65088 .46945 .64272 .4547 Mtetra
.454 .55 .864 r
.64272 .4547 .65088 .46945 .66752 .47269 .65938 .45785 Mtetra
.44 .542 .864 r
.65938 .45785 .66752 .47269 .68427 .47437 .67624 .46152 Mtetra
.53 .626 .891 r
.67624 .46152 .68427 .47437 .70088 .47041 .6931 .46149 Mtetra
.715 .786 .908 r
.6931 .46149 .70088 .47041 .71729 .46105 .70968 .45371 Mtetra
.783 .841 .896 r
.70968 .45371 .71729 .46105 .73364 .44996 .72613 .44262 Mtetra
.767 .841 .908 r
.72613 .44262 .73364 .44996 .7502 .44134 .74268 .43242 Mtetra
.692 .783 .921 r
.74268 .43242 .7502 .44134 .76702 .43527 .75952 .4256 Mtetra
.654 .753 .922 r
.75952 .4256 .76702 .43527 .78401 .43024 .77657 .42033 Mtetra
.658 .75 .918 r
.77657 .42033 .78401 .43024 .80106 .42461 .79371 .41486 Mtetra
.663 .757 .92 r
.79371 .41486 .80106 .42461 .81821 .41908 .81093 .40916 Mtetra
.654 .751 .921 r
.81093 .40916 .81821 .41908 .8355 .41385 .82828 .4038 Mtetra
.649 .747 .921 r
.82828 .4038 .8355 .41385 .85291 .40871 .84576 .39861 Mtetra
.657 .751 .919 r
.84576 .39861 .85291 .40871 .87038 .40312 .86332 .39307 Mtetra
.661 .755 .92 r
.86332 .39307 .87038 .40312 .88795 .3975 .88096 .38734 Mtetra
.649 .75 .923 r
.25342 .57234 .26284 .58055 .27704 .5763 .26766 .56807 Mtetra
.656 .752 .921 r
.26766 .56807 .27704 .5763 .29133 .57189 .282 .56354 Mtetra
.663 .752 .917 r
.282 .56354 .29133 .57189 .30571 .56714 .29644 .55876 Mtetra
.656 .751 .92 r
.29644 .55876 .30571 .56714 .32017 .56256 .31093 .55417 Mtetra
.645 .749 .925 r
.31093 .55417 .32017 .56256 .33468 .55832 .32549 .54995 Mtetra
.657 .754 .921 r
.32549 .54995 .33468 .55832 .34928 .55386 .34015 .54529 Mtetra
.65 .748 .921 r
.34015 .54529 .34928 .55386 .36397 .54922 .35488 .54085 Mtetra
.589 .735 .945 r
.35488 .54085 .36397 .54922 .37868 .54607 .36961 .53826 Mtetra
.399 .672 .97 r
.36961 .53826 .37868 .54607 .39335 .54624 .38428 .5394 Mtetra
.402 .702 .983 r
.38428 .5394 .39335 .54624 .40812 .54729 .3991 .53995 Mtetra
.646 .783 .947 r
.3991 .53995 .40812 .54729 .42311 .54514 .41423 .53539 Mtetra
.78 .758 .833 r
.41423 .53539 .42311 .54514 .43841 .53543 .42965 .52337 Mtetra
.787 .723 .792 r
.42965 .52337 .43841 .53543 .45383 .52205 .44515 .50898 Mtetra
.743 .698 .809 r
.44515 .50898 .45383 .52205 .46924 .50914 .46058 .49821 Mtetra
.671 .712 .879 r
.46058 .49821 .46924 .50914 .4846 .5016 .47597 .49264 Mtetra
.59 .727 .939 r
.47597 .49264 .4846 .5016 .5 .49713 .4914 .48998 Mtetra
.583 .774 .97 r
.4914 .48998 .5 .49713 .51548 .49412 .50694 .48698 Mtetra
.625 .79 .961 r
.50694 .48698 .51548 .49412 .53107 .49069 .5226 .48281 Mtetra
.644 .777 .944 r
.5226 .48281 .53107 .49069 .54675 .48623 .53834 .47815 Mtetra
.654 .776 .939 r
.53834 .47815 .54675 .48623 .56253 .48128 .55418 .47315 Mtetra
.663 .779 .936 r
.55418 .47315 .56253 .48128 .57838 .47585 .57011 .46782 Mtetra
.675 .787 .933 r
.57011 .46782 .57838 .47585 .59431 .46937 .58611 .46199 Mtetra
.704 .812 .932 r
.58611 .46199 .59431 .46937 .6103 .46247 .60218 .45497 Mtetra
.712 .813 .928 r
.60218 .45497 .6103 .46247 .6264 .45703 .6183 .44759 Mtetra
.638 .743 .925 r
.6183 .44759 .6264 .45703 .64272 .4547 .6346 .44315 Mtetra
.488 .63 .916 r
.6346 .44315 .64272 .4547 .65938 .45785 .65121 .44402 Mtetra
.391 .534 .879 r
.65121 .44402 .65938 .45785 .67624 .46152 .66814 .4486 Mtetra
.459 .589 .896 r
.66814 .4486 .67624 .46152 .6931 .46149 .68516 .45082 Mtetra
.659 .73 .902 r
.68516 .45082 .6931 .46149 .70968 .45371 .70193 .44541 Mtetra
.77 .818 .89 r
.70193 .44541 .70968 .45371 .72613 .44262 .7185 .43473 Mtetra
.783 .832 .89 r
.7185 .43473 .72613 .44262 .74268 .43242 .73507 .42342 Mtetra
.706 .788 .915 r
.73507 .42342 .74268 .43242 .75952 .4256 .75195 .41593 Mtetra
.661 .758 .922 r
.75195 .41593 .75952 .4256 .77657 .42033 .76905 .41033 Mtetra
.655 .749 .919 r
.76905 .41033 .77657 .42033 .79371 .41486 .78627 .40497 Mtetra
.665 .757 .919 r
.78627 .40497 .79371 .41486 .81093 .40916 .80356 .39914 Mtetra
.655 .752 .921 r
.80356 .39914 .81093 .40916 .82828 .4038 .82099 .39368 Mtetra
.65 .748 .922 r
.82099 .39368 .82828 .4038 .84576 .39861 .83854 .38841 Mtetra
.655 .75 .92 r
.83854 .38841 .84576 .39861 .86332 .39307 .85618 .38289 Mtetra
.661 .755 .919 r
.85618 .38289 .86332 .39307 .88096 .38734 .8739 .37707 Mtetra
.649 .75 .923 r
.2439 .56404 .25342 .57234 .26766 .56807 .25819 .55975 Mtetra
.658 .752 .92 r
.25819 .55975 .26766 .56807 .282 .56354 .27258 .55511 Mtetra
.662 .752 .917 r
.27258 .55511 .282 .56354 .29644 .55876 .28706 .5503 Mtetra
.655 .751 .92 r
.28706 .5503 .29644 .55876 .31093 .55417 .30161 .54571 Mtetra
.644 .749 .925 r
.30161 .54571 .31093 .55417 .32549 .54995 .31621 .54147 Mtetra
.66 .754 .92 r
.31621 .54147 .32549 .54995 .34015 .54529 .33092 .53667 Mtetra
.644 .747 .924 r
.33092 .53667 .34015 .54529 .35488 .54085 .34569 .5324 Mtetra
.566 .727 .95 r
.34569 .5324 .35488 .54085 .36961 .53826 .36043 .53039 Mtetra
.374 .661 .969 r
.36043 .53039 .36961 .53826 .38428 .5394 .37512 .53188 Mtetra
.452 .709 .977 r
.37512 .53188 .38428 .5394 .3991 .53995 .39001 .53187 Mtetra
.701 .78 .913 r
.39001 .53187 .3991 .53995 .41423 .53539 .40527 .52527 Mtetra
.792 .754 .819 r
.40527 .52527 .41423 .53539 .42965 .52337 .4208 .51193 Mtetra
.794 .735 .798 r
.4208 .51193 .42965 .52337 .44515 .50898 .43637 .49736 Mtetra
.726 .717 .842 r
.43637 .49736 .44515 .50898 .46058 .49821 .45182 .48851 Mtetra
.634 .727 .915 r
.45182 .48851 .46058 .49821 .47597 .49264 .46722 .48448 Mtetra
.56 .739 .96 r
.46722 .48448 .47597 .49264 .4914 .48998 .48271 .48235 Mtetra
.613 .773 .957 r
.48271 .48235 .4914 .48998 .50694 .48698 .49832 .47861 Mtetra
.64 .764 .938 r
.49832 .47861 .50694 .48698 .5226 .48281 .51403 .47415 Mtetra
.65 .762 .931 r
.51403 .47415 .5226 .48281 .53834 .47815 .52984 .46931 Mtetra
.656 .76 .927 r
.52984 .46931 .53834 .47815 .55418 .47315 .54574 .46426 Mtetra
.66 .762 .925 r
.54574 .46426 .55418 .47315 .57011 .46782 .56173 .459 Mtetra
.669 .768 .924 r
.56173 .459 .57011 .46782 .58611 .46199 .5778 .45336 Mtetra
.687 .779 .921 r
.5778 .45336 .58611 .46199 .60218 .45497 .59395 .44697 Mtetra
.724 .806 .915 r
.59395 .44697 .60218 .45497 .6183 .44759 .61014 .43896 Mtetra
.678 .779 .926 r
.61014 .43896 .6183 .44759 .6346 .44315 .62646 .43286 Mtetra
.542 .687 .933 r
.62646 .43286 .6346 .44315 .65121 .44402 .64304 .43166 Mtetra
.355 .544 .901 r
.64304 .43166 .65121 .44402 .66814 .4486 .66 .43631 Mtetra
.402 .573 .907 r
.66 .43631 .66814 .4486 .68516 .45082 .67711 .43975 Mtetra
.609 .704 .912 r
.67711 .43975 .68516 .45082 .70193 .44541 .69406 .43633 Mtetra
.758 .8 .887 r
.69406 .43633 .70193 .44541 .7185 .43473 .71074 .42613 Mtetra
.786 .818 .878 r
.71074 .42613 .7185 .43473 .73507 .42342 .72738 .41434 Mtetra
.719 .793 .91 r
.72738 .41434 .73507 .42342 .75195 .41593 .74429 .40615 Mtetra
.666 .76 .92 r
.74429 .40615 .75195 .41593 .76905 .41033 .76145 .40027 Mtetra
.652 .749 .921 r
.76145 .40027 .76905 .41033 .78627 .40497 .77875 .39494 Mtetra
.666 .757 .918 r
.77875 .39494 .78627 .40497 .80356 .39914 .79611 .38901 Mtetra
.656 .752 .921 r
.79611 .38901 .80356 .39914 .82099 .39368 .81361 .38345 Mtetra
.65 .749 .922 r
.81361 .38345 .82099 .39368 .83854 .38841 .83124 .37811 Mtetra
.654 .75 .92 r
.83124 .37811 .83854 .38841 .85618 .38289 .84896 .37258 Mtetra
.662 .754 .919 r
.84896 .37258 .85618 .38289 .8739 .37707 .86676 .36668 Mtetra
.649 .75 .923 r
.23429 .55566 .2439 .56404 .25819 .55975 .24862 .55132 Mtetra
.659 .752 .919 r
.24862 .55132 .25819 .55975 .27258 .55511 .26306 .54662 Mtetra
.662 .753 .917 r
.26306 .54662 .27258 .55511 .28706 .5503 .27759 .54176 Mtetra
.655 .751 .921 r
.27759 .54176 .28706 .5503 .30161 .54571 .29218 .53715 Mtetra
.644 .749 .925 r
.29218 .53715 .30161 .54571 .31621 .54147 .30683 .53287 Mtetra
.661 .753 .919 r
.30683 .53287 .31621 .54147 .33092 .53667 .3216 .52799 Mtetra
.64 .747 .926 r
.3216 .52799 .33092 .53667 .34569 .5324 .33641 .52379 Mtetra
.551 .72 .952 r
.33641 .52379 .34569 .5324 .36043 .53039 .35118 .52212 Mtetra
.379 .654 .965 r
.35118 .52212 .36043 .53039 .37512 .53188 .3659 .52367 Mtetra
.484 .706 .967 r
.3659 .52367 .37512 .53188 .39001 .53187 .38084 .52329 Mtetra
.722 .774 .894 r
.38084 .52329 .39001 .53187 .40527 .52527 .3962 .51558 Mtetra
.802 .764 .819 r
.3962 .51558 .40527 .52527 .4208 .51193 .41182 .50159 Mtetra
.802 .754 .809 r
.41182 .50159 .4208 .51193 .43637 .49736 .42747 .48709 Mtetra
.716 .741 .871 r
.42747 .48709 .43637 .49736 .45182 .48851 .44295 .47926 Mtetra
.609 .731 .932 r
.44295 .47926 .45182 .48851 .46722 .48448 .45839 .47596 Mtetra
.57 .736 .954 r
.45839 .47596 .46722 .48448 .48271 .48235 .47393 .47361 Mtetra
.624 .751 .938 r
.47393 .47361 .48271 .48235 .49832 .47861 .4896 .46968 Mtetra
.645 .754 .929 r
.4896 .46968 .49832 .47861 .51403 .47415 .50537 .46504 Mtetra
.649 .753 .925 r
.50537 .46504 .51403 .47415 .52984 .46931 .52124 .46021 Mtetra
.656 .757 .924 r
.52124 .46021 .52984 .46931 .54574 .46426 .5372 .45511 Mtetra
.662 .759 .922 r
.5372 .45511 .54574 .46426 .56173 .459 .55325 .44972 Mtetra
.666 .758 .919 r
.55325 .44972 .56173 .459 .5778 .45336 .56939 .44415 Mtetra
.683 .767 .915 r
.56939 .44415 .5778 .45336 .59395 .44697 .58561 .43787 Mtetra
.718 .78 .902 r
.58561 .43787 .59395 .44697 .61014 .43896 .60188 .42996 Mtetra
.697 .778 .914 r
.60188 .42996 .61014 .43896 .62646 .43286 .61824 .42301 Mtetra
.573 .714 .938 r
.61824 .42301 .62646 .43286 .64304 .43166 .63484 .42066 Mtetra
.322 .558 .921 r
.63484 .42066 .64304 .43166 .66 .43631 .65184 .42513 Mtetra
.35 .571 .922 r
.65184 .42513 .66 .43631 .67711 .43975 .66901 .42913 Mtetra
.577 .702 .927 r
.66901 .42913 .67711 .43975 .69406 .43633 .68607 .42672 Mtetra
.749 .789 .885 r
.68607 .42672 .69406 .43633 .71074 .42613 .70286 .41679 Mtetra
.783 .804 .87 r
.70286 .41679 .71074 .42613 .72738 .41434 .71957 .40484 Mtetra
.726 .788 .901 r
.71957 .40484 .72738 .41434 .74429 .40615 .73654 .39618 Mtetra
.669 .759 .918 r
.73654 .39618 .74429 .40615 .76145 .40027 .75376 .39012 Mtetra
.651 .749 .921 r
.75376 .39012 .76145 .40027 .77875 .39494 .77114 .38476 Mtetra
.666 .756 .918 r
.77114 .38476 .77875 .39494 .79611 .38901 .78858 .37877 Mtetra
.657 .752 .92 r
.78858 .37877 .79611 .38901 .81361 .38345 .80615 .37312 Mtetra
.65 .749 .922 r
.80615 .37312 .81361 .38345 .83124 .37811 .82385 .3677 Mtetra
.653 .75 .921 r
.82385 .3677 .83124 .37811 .84896 .37258 .84166 .36214 Mtetra
.662 .754 .919 r
.84166 .36214 .84896 .37258 .86676 .36668 .85953 .35617 Mtetra
.649 .75 .923 r
.22458 .54718 .23429 .55566 .24862 .55132 .23896 .5428 Mtetra
.659 .752 .919 r
.23896 .5428 .24862 .55132 .26306 .54662 .25345 .53805 Mtetra
.662 .753 .918 r
.25345 .53805 .26306 .54662 .27759 .54176 .26803 .53315 Mtetra
.655 .751 .921 r
.26803 .53315 .27759 .54176 .29218 .53715 .28266 .52849 Mtetra
.644 .748 .925 r
.28266 .52849 .29218 .53715 .30683 .53287 .29736 .52416 Mtetra
.661 .753 .918 r
.29736 .52416 .30683 .53287 .3216 .52799 .31218 .51923 Mtetra
.64 .747 .926 r
.31218 .51923 .3216 .52799 .33641 .52379 .32704 .51499 Mtetra
.552 .718 .95 r
.32704 .51499 .33641 .52379 .35118 .52212 .34185 .51327 Mtetra
.394 .648 .959 r
.34185 .51327 .35118 .52212 .3659 .52367 .3566 .51479 Mtetra
.496 .695 .958 r
.3566 .51479 .3659 .52367 .38084 .52329 .37159 .51436 Mtetra
.721 .769 .891 r
.37159 .51436 .38084 .52329 .3962 .51558 .387 .5066 Mtetra
.808 .779 .826 r
.387 .5066 .3962 .51558 .41182 .50159 .40271 .49253 Mtetra
.813 .779 .821 r
.40271 .49253 .41182 .50159 .42747 .48709 .41844 .47796 Mtetra
.722 .768 .889 r
.41844 .47796 .42747 .48709 .44295 .47926 .43398 .47007 Mtetra
.608 .735 .935 r
.43398 .47007 .44295 .47926 .45839 .47596 .44948 .46672 Mtetra
.576 .722 .943 r
.44948 .46672 .45839 .47596 .47393 .47361 .46506 .46433 Mtetra
.626 .741 .93 r
.46506 .46433 .47393 .47361 .4896 .46968 .48079 .46034 Mtetra
.645 .747 .924 r
.48079 .46034 .4896 .46968 .50537 .46504 .49662 .45564 Mtetra
.65 .749 .922 r
.49662 .45564 .50537 .46504 .52124 .46021 .51254 .45077 Mtetra
.656 .751 .92 r
.51254 .45077 .52124 .46021 .5372 .45511 .52857 .44561 Mtetra
.662 .753 .917 r
.52857 .44561 .5372 .45511 .55325 .44972 .54468 .44017 Mtetra
.666 .754 .916 r
.54468 .44017 .55325 .44972 .56939 .44415 .56089 .43454 Mtetra
.683 .76 .91 r
.56089 .43454 .56939 .44415 .58561 .43787 .57717 .42819 Mtetra
.716 .77 .894 r
.57717 .42819 .58561 .43787 .60188 .42996 .59351 .42023 Mtetra
.696 .764 .904 r
.59351 .42023 .60188 .42996 .61824 .42301 .60994 .41321 Mtetra
.572 .717 .941 r
.60994 .41321 .61824 .42301 .63484 .42066 .6266 .41081 Mtetra
.282 .566 .934 r
.6266 .41081 .63484 .42066 .65184 .42513 .64364 .41524 Mtetra
.308 .581 .938 r
.64364 .41524 .65184 .42513 .66901 .42913 .66086 .41921 Mtetra
.571 .718 .942 r
.66086 .41921 .66901 .42913 .68607 .42672 .67799 .41675 Mtetra
.748 .783 .881 r
.67799 .41675 .68607 .42672 .70286 .41679 .69485 .40675 Mtetra
.779 .791 .862 r
.69485 .40675 .70286 .41679 .71957 .40484 .71165 .39472 Mtetra
.725 .776 .893 r
.71165 .39472 .71957 .40484 .73654 .39618 .7287 .38599 Mtetra
.669 .757 .916 r
.7287 .38599 .73654 .39618 .75376 .39012 .74599 .37986 Mtetra
.651 .75 .922 r
.74599 .37986 .75376 .39012 .77114 .38476 .76345 .37445 Mtetra
.666 .755 .917 r
.76345 .37445 .77114 .38476 .78858 .37877 .78096 .36839 Mtetra
.657 .752 .92 r
.78096 .36839 .78858 .37877 .80615 .37312 .79861 .36267 Mtetra
.65 .749 .922 r
.79861 .36267 .80615 .37312 .82385 .3677 .81639 .3572 Mtetra
.653 .75 .921 r
.81639 .3572 .82385 .3677 .84166 .36214 .83427 .35156 Mtetra
.662 .754 .918 r
.83427 .35156 .84166 .36214 .85953 .35617 .85222 .34553 Mtetra
.649 .75 .923 r
.21477 .53862 .22458 .54718 .23896 .5428 .2292 .53418 Mtetra
.658 .752 .919 r
.2292 .53418 .23896 .5428 .25345 .53805 .24373 .52941 Mtetra
.662 .753 .918 r
.24373 .52941 .25345 .53805 .26803 .53315 .25836 .52445 Mtetra
.655 .751 .921 r
.25836 .52445 .26803 .53315 .28266 .52849 .27305 .51971 Mtetra
.644 .748 .924 r
.27305 .51971 .28266 .52849 .29736 .52416 .28779 .51533 Mtetra
.66 .752 .918 r
.28779 .51533 .29736 .52416 .31218 .51923 .30266 .51039 Mtetra
.644 .748 .925 r
.30266 .51039 .31218 .51923 .32704 .51499 .31758 .50597 Mtetra
.568 .721 .945 r
.31758 .50597 .32704 .51499 .34185 .51327 .33245 .50383 Mtetra
.412 .644 .952 r
.33245 .50383 .34185 .51327 .3566 .51479 .34724 .50522 Mtetra
.489 .678 .949 r
.34724 .50522 .3566 .51479 .37159 .51436 .36224 .5051 Mtetra
.699 .759 .898 r
.36224 .5051 .37159 .51436 .387 .5066 .37767 .49833 Mtetra
.808 .794 .84 r
.37767 .49833 .387 .5066 .40271 .49253 .39345 .48477 Mtetra
.825 .805 .833 r
.39345 .48477 .40271 .49253 .41844 .47796 .40927 .46997 Mtetra
.747 .799 .894 r
.40927 .46997 .41844 .47796 .43398 .47007 .42491 .46093 Mtetra
.632 .746 .93 r
.42491 .46093 .43398 .47007 .44948 .46672 .44049 .45675 Mtetra
.574 .707 .932 r
.44049 .45675 .44948 .46672 .46506 .46433 .45611 .45448 Mtetra
.623 .729 .923 r
.45611 .45448 .46506 .46433 .48079 .46034 .47189 .45059 Mtetra
.642 .74 .919 r
.47189 .45059 .48079 .46034 .49662 .45564 .48777 .44597 Mtetra
.652 .745 .918 r
.48777 .44597 .49662 .45564 .51254 .45077 .50376 .44097 Mtetra
.656 .745 .916 r
.50376 .44097 .51254 .45077 .52857 .44561 .51984 .43575 Mtetra
.661 .747 .914 r
.51984 .43575 .52857 .44561 .54468 .44017 .53602 .43032 Mtetra
.669 .751 .912 r
.53602 .43032 .54468 .44017 .56089 .43454 .55228 .42451 Mtetra
.686 .754 .903 r
.55228 .42451 .56089 .43454 .57717 .42819 .56863 .41795 Mtetra
.718 .76 .886 r
.56863 .41795 .57717 .42819 .59351 .42023 .58504 .40974 Mtetra
.677 .744 .901 r
.58504 .40974 .59351 .42023 .60994 .41321 .60155 .40346 Mtetra
.532 .703 .949 r
.60155 .40346 .60994 .41321 .6266 .41081 .6183 .40211 Mtetra
.224 .564 .937 r
.6183 .40211 .6266 .41081 .64364 .41524 .6354 .40667 Mtetra
.289 .608 .954 r
.6354 .40667 .64364 .41524 .66086 .41921 .65265 .41 Mtetra
.599 .75 .95 r
.65265 .41 .66086 .41921 .67799 .41675 .6698 .40641 Mtetra
.753 .779 .875 r
.6698 .40641 .67799 .41675 .69485 .40675 .68672 .39599 Mtetra
.774 .778 .856 r
.68672 .39599 .69485 .40675 .71165 .39472 .70361 .38398 Mtetra
.715 .762 .889 r
.70361 .38398 .71165 .39472 .7287 .38599 .72076 .37557 Mtetra
.666 .753 .915 r
.72076 .37557 .7287 .38599 .74599 .37986 .73814 .36951 Mtetra
.652 .75 .922 r
.73814 .36951 .74599 .37986 .76345 .37445 .75566 .36399 Mtetra
.666 .755 .917 r
.75566 .36399 .76345 .37445 .78096 .36839 .77325 .35787 Mtetra
.656 .751 .92 r
.77325 .35787 .78096 .36839 .79861 .36267 .79098 .35212 Mtetra
.65 .749 .922 r
.79098 .35212 .79861 .36267 .81639 .3572 .80884 .34659 Mtetra
.654 .751 .921 r
.80884 .34659 .81639 .3572 .83427 .35156 .82679 .34086 Mtetra
.662 .754 .918 r
.82679 .34086 .83427 .35156 .85222 .34553 .84483 .33477 Mtetra
.649 .75 .923 r
.20486 .52996 .21477 .53862 .2292 .53418 .21934 .52546 Mtetra
.656 .751 .92 r
.21934 .52546 .2292 .53418 .24373 .52941 .23391 .52069 Mtetra
.662 .754 .918 r
.23391 .52069 .24373 .52941 .25836 .52445 .24859 .51567 Mtetra
.656 .752 .92 r
.24859 .51567 .25836 .52445 .27305 .51971 .26333 .51085 Mtetra
.645 .748 .924 r
.26333 .51085 .27305 .51971 .28779 .51533 .27813 .50639 Mtetra
.657 .751 .919 r
.27813 .50639 .28779 .51533 .30266 .51039 .29304 .50148 Mtetra
.65 .751 .923 r
.29304 .50148 .30266 .51039 .31758 .50597 .30802 .4968 Mtetra
.592 .727 .938 r
.30802 .4968 .31758 .50597 .33245 .50383 .32297 .49398 Mtetra
.44 .65 .948 r
.32297 .49398 .33245 .50383 .34724 .50522 .33781 .49494 Mtetra
.475 .656 .94 r
.33781 .49494 .34724 .50522 .36224 .5051 .35282 .49531 Mtetra
.651 .737 .912 r
.35282 .49531 .36224 .5051 .37767 .49833 .36822 .4905 Mtetra
.797 .806 .858 r
.36822 .4905 .37767 .49833 .39345 .48477 .38402 .47813 Mtetra
.833 .83 .844 r
.38402 .47813 .39345 .48477 .40927 .46997 .39994 .46335 Mtetra
.788 .836 .889 r
.39994 .46335 .40927 .46997 .42491 .46093 .41573 .45224 Mtetra
.675 .772 .924 r
.41573 .45224 .42491 .46093 .44049 .45675 .43141 .4464 Mtetra
.594 .709 .923 r
.43141 .4464 .44049 .45675 .45611 .45448 .4471 .44351 Mtetra
.606 .701 .911 r
.4471 .44351 .45611 .45448 .47189 .45059 .4629 .44027 Mtetra
.636 .727 .913 r
.4629 .44027 .47189 .45059 .48777 .44597 .47884 .43584 Mtetra
.649 .737 .914 r
.47884 .43584 .48777 .44597 .50376 .44097 .49488 .4309 Mtetra
.656 .742 .913 r
.49488 .4309 .50376 .44097 .51984 .43575 .51102 .42563 Mtetra
.664 .744 .91 r
.51102 .42563 .51984 .43575 .53602 .43032 .52726 .42002 Mtetra
.675 .745 .904 r
.52726 .42002 .53602 .43032 .55228 .42451 .54359 .4139 Mtetra
.699 .748 .889 r
.54359 .4139 .55228 .42451 .56863 .41795 .55999 .40657 Mtetra
.703 .735 .876 r
.55999 .40657 .56863 .41795 .58504 .40974 .57647 .39888 Mtetra
.639 .724 .91 r
.57647 .39888 .58504 .40974 .60155 .40346 .59308 .39416 Mtetra
.44 .673 .962 r
.59308 .39416 .60155 .40346 .6183 .40211 .60995 .39481 Mtetra
.159 .563 .931 r
.60995 .39481 .6183 .40211 .6354 .40667 .6271 .39922 Mtetra
.313 .656 .971 r
.6271 .39922 .6354 .40667 .65265 .41 .64437 .40123 Mtetra
.657 .786 .943 r
.64437 .40123 .65265 .41 .6698 .40641 .6615 .39552 Mtetra
.759 .772 .864 r
.6615 .39552 .6698 .40641 .68672 .39599 .67847 .38447 Mtetra
.764 .763 .852 r
.67847 .38447 .68672 .39599 .70361 .38398 .69547 .37279 Mtetra
.702 .751 .89 r
.69547 .37279 .70361 .38398 .72076 .37557 .71273 .36496 Mtetra
.661 .749 .916 r
.71273 .36496 .72076 .37557 .73814 .36951 .73019 .35906 Mtetra
.654 .752 .921 r
.73019 .35906 .73814 .36951 .75566 .36399 .74779 .35338 Mtetra
.665 .754 .917 r
.74779 .35338 .75566 .36399 .77325 .35787 .76545 .34723 Mtetra
.655 .751 .92 r
.76545 .34723 .77325 .35787 .79098 .35212 .78326 .34145 Mtetra
.65 .749 .922 r
.78326 .34145 .79098 .35212 .80884 .34659 .8012 .33587 Mtetra
.655 .752 .921 r
.8012 .33587 .80884 .34659 .82679 .34086 .81923 .33002 Mtetra
.661 .753 .918 r
.81923 .33002 .82679 .34086 .84483 .33477 .83735 .32387 Mtetra
.65 .75 .922 r
.19485 .52121 .20486 .52996 .21934 .52546 .20937 .51664 Mtetra
.654 .75 .92 r
.20937 .51664 .21934 .52546 .23391 .52069 .22399 .51189 Mtetra
.663 .754 .918 r
.22399 .51189 .23391 .52069 .24859 .51567 .23872 .50681 Mtetra
.658 .752 .92 r
.23872 .50681 .24859 .51567 .26333 .51085 .25351 .50189 Mtetra
.647 .749 .923 r
.25351 .50189 .26333 .51085 .27813 .50639 .26836 .49732 Mtetra
.653 .749 .92 r
.26836 .49732 .27813 .50639 .29304 .50148 .28331 .49251 Mtetra
.657 .753 .921 r
.28331 .49251 .29304 .50148 .30802 .4968 .29836 .48753 Mtetra
.612 .734 .933 r
.29836 .48753 .30802 .4968 .32297 .49398 .3134 .48406 Mtetra
.488 .672 .946 r
.3134 .48406 .32297 .49398 .33781 .49494 .32833 .48396 Mtetra
.463 .637 .931 r
.32833 .48396 .33781 .49494 .35282 .49531 .34335 .48476 Mtetra
.582 .698 .922 r
.34335 .48476 .35282 .49531 .36822 .4905 .35866 .48231 Mtetra
.764 .798 .881 r
.35866 .48231 .36822 .4905 .38402 .47813 .37445 .47214 Mtetra
.828 .847 .862 r
.37445 .47214 .38402 .47813 .39994 .46335 .39043 .45824 Mtetra
.828 .87 .876 r
.39043 .45824 .39994 .46335 .41573 .45224 .4064 .44482 Mtetra
.725 .815 .921 r
.4064 .44482 .41573 .45224 .43141 .4464 .42221 .43687 Mtetra
.647 .747 .923 r
.42221 .43687 .43141 .4464 .4471 .44351 .438 .43203 Mtetra
.609 .694 .903 r
.438 .43203 .4471 .44351 .4629 .44027 .45385 .42867 Mtetra
.619 .697 .9 r
.45385 .42867 .4629 .44027 .47884 .43584 .46982 .42489 Mtetra
.645 .72 .903 r
.46982 .42489 .47884 .43584 .49488 .4309 .48592 .42005 Mtetra
.656 .727 .902 r
.48592 .42005 .49488 .4309 .51102 .42563 .50212 .41472 Mtetra
.667 .731 .898 r
.50212 .41472 .51102 .42563 .52726 .42002 .51841 .40889 Mtetra
.688 .735 .887 r
.51841 .40889 .52726 .42002 .54359 .4139 .5348 .402 Mtetra
.694 .724 .873 r
.5348 .402 .54359 .4139 .55999 .40657 .55126 .39467 Mtetra
.664 .714 .886 r
.55126 .39467 .55999 .40657 .57647 .39888 .56782 .38882 Mtetra
.576 .72 .94 r
.56782 .38882 .57647 .39888 .59308 .39416 .58454 .38613 Mtetra
.28 .621 .96 r
.58454 .38613 .59308 .39416 .60995 .39481 .60152 .38902 Mtetra
.135 .591 .925 r
.60152 .38902 .60995 .39481 .6271 .39922 .61871 .39244 Mtetra
.416 .734 .991 r
.61871 .39244 .6271 .39922 .64437 .40123 .63597 .39208 Mtetra
.716 .798 .915 r
.63597 .39208 .64437 .40123 .6615 .39552 .65308 .38383 Mtetra
.761 .76 .851 r
.65308 .38383 .6615 .39552 .67847 .38447 .67011 .37222 Mtetra
.745 .747 .853 r
.67011 .37222 .67847 .38447 .69547 .37279 .68723 .36151 Mtetra
.689 .747 .896 r
.68723 .36151 .69547 .37279 .71273 .36496 .7046 .35424 Mtetra
.655 .747 .918 r
.7046 .35424 .71273 .36496 .73019 .35906 .72216 .34853 Mtetra
.658 .754 .921 r
.72216 .34853 .73019 .35906 .74779 .35338 .73982 .34262 Mtetra
.663 .752 .917 r
.73982 .34262 .74779 .35338 .76545 .34723 .75757 .33647 Mtetra
.654 .75 .92 r
.75757 .33647 .76545 .34723 .78326 .34145 .77546 .33067 Mtetra
.649 .749 .923 r
.77546 .33067 .78326 .34145 .8012 .33587 .79348 .32504 Mtetra
.657 .753 .921 r
.79348 .32504 .8012 .33587 .81923 .33002 .81158 .31904 Mtetra
.661 .753 .918 r
.81158 .31904 .81923 .33002 .83735 .32387 .82978 .31285 Mtetra
.651 .75 .922 r
.18474 .51237 .19485 .52121 .20937 .51664 .19931 .5077 Mtetra
.651 .749 .921 r
.19931 .5077 .20937 .51664 .22399 .51189 .21397 .50301 Mtetra
.662 .754 .918 r
.21397 .50301 .22399 .51189 .23872 .50681 .22874 .49789 Mtetra
.659 .754 .92 r
.22874 .49789 .23872 .50681 .25351 .50189 .24359 .49285 Mtetra
.65 .75 .922 r
.24359 .49285 .25351 .50189 .26836 .49732 .2585 .48812 Mtetra
.647 .746 .922 r
.2585 .48812 .26836 .49732 .28331 .49251 .27348 .48348 Mtetra
.662 .755 .919 r
.27348 .48348 .28331 .49251 .29836 .48753 .2886 .47825 Mtetra
.632 .743 .928 r
.2886 .47825 .29836 .48753 .3134 .48406 .30372 .47407 Mtetra
.55 .699 .938 r
.30372 .47407 .3134 .48406 .32833 .48396 .31879 .47241 Mtetra
.466 .628 .923 r
.31879 .47241 .32833 .48396 .34335 .48476 .33382 .47324 Mtetra
.532 .66 .918 r
.33382 .47324 .34335 .48476 .35866 .48231 .34909 .47237 Mtetra
.682 .748 .901 r
.34909 .47237 .35866 .48231 .37445 .47214 .36475 .46612 Mtetra
.801 .851 .888 r
.36475 .46612 .37445 .47214 .39043 .45824 .38074 .45419 Mtetra
.833 .895 .885 r
.38074 .45419 .39043 .45824 .4064 .44482 .39682 .44065 Mtetra
.8 .9 .913 r
.39682 .44065 .4064 .44482 .42221 .43687 .41284 .42915 Mtetra
.705 .808 .929 r
.41284 .42915 .42221 .43687 .438 .43203 .42877 .42195 Mtetra
.657 .742 .913 r
.42877 .42195 .438 .43203 .45385 .42867 .44472 .41664 Mtetra
.634 .696 .89 r
.44472 .41664 .45385 .42867 .46982 .42489 .46075 .41221 Mtetra
.64 .688 .879 r
.46075 .41221 .46982 .42489 .48592 .42005 .47689 .40749 Mtetra
.654 .696 .877 r
.47689 .40749 .48592 .42005 .50212 .41472 .49313 .4021 Mtetra
.667 .701 .872 r
.49313 .4021 .50212 .41472 .51841 .40889 .50948 .39603 Mtetra
.672 .7 .868 r
.50948 .39603 .51841 .40889 .5348 .402 .52592 .38965 Mtetra
.655 .704 .883 r
.52592 .38965 .5348 .402 .55126 .39467 .54245 .38417 Mtetra
.604 .722 .928 r
.54245 .38417 .55126 .39467 .56782 .38882 .5591 .3806 Mtetra
.398 .685 .976 r
.5591 .3806 .56782 .38882 .58454 .38613 .57595 .38139 Mtetra
.1 .594 .902 r
.57595 .38139 .58454 .38613 .60152 .38902 .593 .38429 Mtetra
.215 .673 .947 r
.593 .38429 .60152 .38902 .61871 .39244 .61022 .3856 Mtetra
.599 .818 .984 r
.61022 .3856 .61871 .39244 .63597 .39208 .62742 .38113 Mtetra
.741 .769 .876 r
.62742 .38113 .63597 .39208 .65308 .38383 .64454 .37113 Mtetra
.757 .744 .841 r
.64454 .37113 .65308 .38383 .67011 .37222 .66165 .35937 Mtetra
.718 .73 .859 r
.66165 .35937 .67011 .37222 .68723 .36151 .67891 .35013 Mtetra
.675 .742 .902 r
.67891 .35013 .68723 .36151 .7046 .35424 .69639 .34349 Mtetra
.65 .747 .921 r
.69639 .34349 .7046 .35424 .72216 .34853 .71404 .33791 Mtetra
.664 .757 .919 r
.71404 .33791 .72216 .34853 .73982 .34262 .73176 .33171 Mtetra
.661 .751 .917 r
.73176 .33171 .73982 .34262 .75757 .33647 .74959 .32561 Mtetra
.653 .75 .921 r
.74959 .32561 .75757 .33647 .77546 .33067 .76757 .3198 Mtetra
.65 .75 .923 r
.76757 .3198 .77546 .33067 .79348 .32504 .78566 .31409 Mtetra
.66 .754 .92 r
.78566 .31409 .79348 .32504 .81158 .31904 .80384 .30791 Mtetra
.66 .752 .918 r
.80384 .30791 .81158 .31904 .82978 .31285 .82213 .3017 Mtetra
.653 .751 .921 r
.17451 .50345 .18474 .51237 .19931 .5077 .18914 .49866 Mtetra
.649 .748 .922 r
.18914 .49866 .19931 .5077 .21397 .50301 .20384 .49399 Mtetra
.66 .753 .918 r
.20384 .49399 .21397 .50301 .22874 .49789 .21866 .48889 Mtetra
.661 .755 .919 r
.21866 .48889 .22874 .49789 .24359 .49285 .23356 .48374 Mtetra
.654 .751 .921 r
.23356 .48374 .24359 .49285 .2585 .48812 .24853 .47881 Mtetra
.645 .746 .922 r
.24853 .47881 .2585 .48812 .27348 .48348 .26356 .47418 Mtetra
.659 .751 .918 r
.26356 .47418 .27348 .48348 .2886 .47825 .27872 .46901 Mtetra
.65 .751 .923 r
.27872 .46901 .2886 .47825 .30372 .47407 .29394 .46416 Mtetra
.603 .723 .929 r
.29394 .46416 .30372 .47407 .31879 .47241 .30914 .46089 Mtetra
.501 .647 .923 r
.30914 .46089 .31879 .47241 .33382 .47324 .32426 .46078 Mtetra
.502 .629 .908 r
.32426 .46078 .33382 .47324 .34909 .47237 .3395 .46088 Mtetra
.586 .686 .91 r
.3395 .46088 .34909 .47237 .36475 .46612 .35502 .45828 Mtetra
.732 .808 .911 r
.35502 .45828 .36475 .46612 .38074 .45419 .37092 .44985 Mtetra
.803 .895 .908 r
.37092 .44985 .38074 .45419 .39682 .44065 .38703 .43808 Mtetra
.813 .936 .911 r
.38703 .43808 .39682 .44065 .41284 .42915 .4032 .42568 Mtetra
.781 .92 .93 r
.4032 .42568 .41284 .42915 .42877 .42195 .41933 .41493 Mtetra
.708 .829 .94 r
.41933 .41493 .42877 .42195 .44472 .41664 .43542 .40749 Mtetra
.675 .772 .924 r
.43542 .40749 .44472 .41664 .46075 .41221 .45154 .40138 Mtetra
.66 .732 .903 r
.45154 .40138 .46075 .41221 .47689 .40749 .46775 .39581 Mtetra
.656 .715 .892 r
.46775 .39581 .47689 .40749 .49313 .4021 .48405 .39035 Mtetra
.652 .714 .893 r
.48405 .39035 .49313 .4021 .50948 .39603 .50045 .38501 Mtetra
.639 .725 .91 r
.50045 .38501 .50948 .39603 .52592 .38965 .51694 .38021 Mtetra
.594 .744 .948 r
.51694 .38021 .52592 .38965 .54245 .38417 .53355 .37675 Mtetra
.416 .718 .987 r
.53355 .37675 .54245 .38417 .5591 .3806 .55031 .37666 Mtetra
.14 .641 .907 r
.55031 .37666 .5591 .3806 .57595 .38139 .56725 .37827 Mtetra
.134 .653 .888 r
.56725 .37827 .57595 .38139 .593 .38429 .58436 .37927 Mtetra
.458 .806 .998 r
.58436 .37927 .593 .38429 .61022 .3856 .60156 .37689 Mtetra
.717 .811 .924 r
.60156 .37689 .61022 .3856 .62742 .38113 .61873 .36857 Mtetra
.748 .744 .848 r
.61873 .36857 .62742 .38113 .64454 .37113 .63589 .35746 Mtetra
.739 .725 .838 r
.63589 .35746 .64454 .37113 .66165 .35937 .6531 .34654 Mtetra
.691 .722 .873 r
.6531 .34654 .66165 .35937 .67891 .35013 .67051 .33883 Mtetra
.661 .741 .909 r
.67051 .33883 .67891 .35013 .69639 .34349 .6881 .33275 Mtetra
.653 .751 .922 r
.6881 .33275 .69639 .34349 .71404 .33791 .70581 .32698 Mtetra
.665 .754 .916 r
.70581 .32698 .71404 .33791 .73176 .33171 .7236 .32065 Mtetra
.657 .749 .918 r
.7236 .32065 .73176 .33171 .74959 .32561 .74153 .31463 Mtetra
.651 .75 .922 r
.74153 .31463 .74959 .32561 .76757 .3198 .75959 .30883 Mtetra
.652 .752 .923 r
.75959 .30883 .76757 .3198 .78566 .31409 .77776 .30296 Mtetra
.661 .754 .919 r
.77776 .30296 .78566 .31409 .80384 .30791 .79601 .29664 Mtetra
.658 .751 .919 r
.79601 .29664 .80384 .30791 .82213 .3017 .81439 .29043 Mtetra
.655 .752 .921 r
.16418 .49444 .17451 .50345 .18914 .49866 .17886 .48953 Mtetra
.65 .748 .922 r
.17886 .48953 .18914 .49866 .20384 .49399 .19361 .4848 Mtetra
.656 .75 .919 r
.19361 .4848 .20384 .49399 .21866 .48889 .20846 .47982 Mtetra
.662 .755 .919 r
.20846 .47982 .21866 .48889 .23356 .48374 .22342 .47456 Mtetra
.657 .753 .92 r
.22342 .47456 .23356 .48374 .24853 .47881 .23845 .46947 Mtetra
.648 .748 .922 r
.23845 .46947 .24853 .47881 .26356 .47418 .25354 .46468 Mtetra
.651 .746 .92 r
.25354 .46468 .26356 .47418 .27872 .46901 .26872 .45977 Mtetra
.66 .756 .921 r
.26872 .45977 .27872 .46901 .29394 .46416 .28403 .45447 Mtetra
.633 .739 .924 r
.28403 .45447 .29394 .46416 .30914 .46089 .29935 .45014 Mtetra
.572 .696 .925 r
.29935 .45014 .30914 .46089 .32426 .46078 .31463 .44783 Mtetra
.505 .623 .902 r
.31463 .44783 .32426 .46078 .3395 .46088 .3299 .44788 Mtetra
.536 .637 .898 r
.3299 .44788 .3395 .46088 .35502 .45828 .34535 .44702 Mtetra
.611 .704 .91 r
.34535 .44702 .35502 .45828 .37092 .44985 .36107 .44342 Mtetra
.735 .846 .932 r
.36107 .44342 .37092 .44985 .38703 .43808 .37713 .43486 Mtetra
.776 .925 .934 r
.37713 .43486 .38703 .43808 .4032 .42568 .39333 .42425 Mtetra
.764 .962 .931 r
.39333 .42425 .4032 .42568 .41933 .41493 .40958 .41338 Mtetra
.73 .959 .944 r
.40958 .41338 .41933 .41493 .43542 .40749 .42584 .40361 Mtetra
.71 .91 .965 r
.42584 .40361 .43542 .40749 .45154 .40138 .44212 .39542 Mtetra
.681 .855 .966 r
.44212 .39542 .45154 .40138 .46775 .39581 .45843 .38867 Mtetra
.648 .819 .965 r
.45843 .38867 .46775 .39581 .48405 .39035 .47481 .38316 Mtetra
.603 .804 .977 r
.47481 .38316 .48405 .39035 .50045 .38501 .49127 .37888 Mtetra
.521 .802 .997 r
.49127 .37888 .50045 .38501 .51694 .38021 .50784 .37607 Mtetra
.354 .771 .978 r
.50784 .37607 .51694 .38021 .53355 .37675 .52454 .37486 Mtetra
.134 .67 .852 r
.52454 .37486 .53355 .37675 .55031 .37666 .54139 .37479 Mtetra
.15 .682 .859 r
.54139 .37479 .55031 .37666 .56725 .37827 .5584 .37448 Mtetra
.406 .809 .982 r
.5584 .37448 .56725 .37827 .58436 .37927 .57555 .3721 Mtetra
.693 .843 .955 r
.57555 .3721 .58436 .37927 .60156 .37689 .59272 .36468 Mtetra
.737 .748 .861 r
.59272 .36468 .60156 .37689 .61873 .36857 .60992 .35445 Mtetra
.74 .719 .832 r
.60992 .35445 .61873 .36857 .63589 .35746 .62714 .34327 Mtetra
.704 .706 .849 r
.62714 .34327 .63589 .35746 .6531 .34654 .6445 .33447 Mtetra
.674 .732 .894 r
.6445 .33447 .6531 .34654 .67051 .33883 .66203 .32773 Mtetra
.651 .744 .917 r
.66203 .32773 .67051 .33883 .6881 .33275 .67971 .32199 Mtetra
.66 .756 .921 r
.67971 .32199 .6881 .33275 .70581 .32698 .69748 .31583 Mtetra
.663 .75 .915 r
.69748 .31583 .70581 .32698 .7236 .32065 .71536 .30954 Mtetra
.654 .749 .92 r
.71536 .30954 .7236 .32065 .74153 .31463 .73337 .30356 Mtetra
.65 .75 .923 r
.73337 .30356 .74153 .31463 .75959 .30883 .75151 .29774 Mtetra
.656 .753 .922 r
.75151 .29774 .75959 .30883 .77776 .30296 .76975 .29164 Mtetra
.661 .752 .918 r
.76975 .29164 .77776 .30296 .79601 .29664 .78808 .28525 Mtetra
.656 .75 .919 r
.78808 .28525 .79601 .29664 .81439 .29043 .80655 .27904 Mtetra
.657 .752 .92 r
.15374 .48536 .16418 .49444 .17886 .48953 .16848 .48034 Mtetra
.652 .75 .922 r
.16848 .48034 .17886 .48953 .19361 .4848 .18328 .47549 Mtetra
.651 .748 .921 r
.18328 .47549 .19361 .4848 .20846 .47982 .19816 .47063 Mtetra
.662 .755 .919 r
.19816 .47063 .20846 .47982 .22342 .47456 .21317 .46534 Mtetra
.66 .755 .92 r
.21317 .46534 .22342 .47456 .23845 .46947 .22826 .46009 Mtetra
.653 .751 .921 r
.22826 .46009 .23845 .46947 .25354 .46468 .24341 .45505 Mtetra
.646 .744 .921 r
.24341 .45505 .25354 .46468 .26872 .45977 .25864 .45026 Mtetra
.659 .752 .919 r
.25864 .45026 .26872 .45977 .28403 .45447 .27399 .44498 Mtetra
.654 .752 .922 r
.27399 .44498 .28403 .45447 .29935 .45014 .28941 .43984 Mtetra
.622 .726 .921 r
.28941 .43984 .29935 .45014 .31463 .44783 .30485 .43584 Mtetra
.56 .669 .91 r
.30485 .43584 .31463 .44783 .3299 .44788 .32026 .434 Mtetra
.526 .619 .887 r
.32026 .434 .3299 .44788 .34535 .44702 .33571 .43351 Mtetra
.556 .64 .889 r
.33571 .43351 .34535 .44702 .36107 .44342 .35135 .43196 Mtetra
.612 .703 .909 r
.35135 .43196 .36107 .44342 .37713 .43486 .36723 .42825 Mtetra
.696 .839 .952 r
.36723 .42825 .37713 .43486 .39333 .42425 .38337 .42117 Mtetra
.723 .928 .959 r
.38337 .42117 .39333 .42425 .40958 .41338 .39965 .41231 Mtetra
.682 .958 .947 r
.39965 .41231 .40958 .41338 .42584 .40361 .416 .40344 Mtetra
.616 .95 .929 r
.416 .40344 .42584 .40361 .44212 .39542 .43239 .39529 Mtetra
.542 .923 .92 r
.43239 .39529 .44212 .39542 .45843 .38867 .44882 .38834 Mtetra
.46 .884 .912 r
.44882 .38834 .45843 .38867 .47481 .38316 .46531 .38278 Mtetra
.359 .829 .886 r
.46531 .38278 .47481 .38316 .49127 .37888 .48189 .37861 Mtetra
.255 .765 .844 r
.48189 .37861 .49127 .37888 .50784 .37607 .49856 .37565 Mtetra
.204 .73 .829 r
.49856 .37565 .50784 .37607 .52454 .37486 .51537 .37343 Mtetra
.266 .764 .89 r
.51537 .37343 .52454 .37486 .54139 .37479 .53232 .37123 Mtetra
.492 .857 .988 r
.53232 .37123 .54139 .37479 .5584 .37448 .54939 .36723 Mtetra
.693 .841 .954 r
.54939 .36723 .5584 .37448 .57555 .3721 .56655 .35981 Mtetra
.727 .744 .865 r
.56655 .35981 .57555 .3721 .59272 .36468 .58376 .35017 Mtetra
.731 .711 .832 r
.58376 .35017 .59272 .36468 .60992 .35445 .601 .33943 Mtetra
.709 .696 .836 r
.601 .33943 .60992 .35445 .62714 .34327 .61834 .33004 Mtetra
.679 .714 .875 r
.61834 .33004 .62714 .34327 .6445 .33447 .63583 .32285 Mtetra
.657 .737 .908 r
.63583 .32285 .6445 .33447 .66203 .32773 .65346 .31681 Mtetra
.653 .752 .922 r
.65346 .31681 .66203 .32773 .67971 .32199 .67122 .31093 Mtetra
.665 .754 .917 r
.67122 .31093 .67971 .32199 .69748 .31583 .68906 .30452 Mtetra
.658 .748 .916 r
.68906 .30452 .69748 .31583 .71536 .30954 .70702 .29837 Mtetra
.652 .75 .921 r
.70702 .29837 .71536 .30954 .73337 .30356 .72512 .29242 Mtetra
.65 .751 .924 r
.72512 .29242 .73337 .30356 .75151 .29774 .74334 .28651 Mtetra
.66 .755 .92 r
.74334 .28651 .75151 .29774 .76975 .29164 .76165 .28014 Mtetra
.66 .751 .918 r
.76165 .28014 .76975 .29164 .78808 .28525 .78007 .27376 Mtetra
.655 .75 .92 r
.78007 .27376 .78808 .28525 .80655 .27904 .79863 .26753 Mtetra
.659 .754 .92 r
.14318 .47623 .15374 .48536 .16848 .48034 .15797 .47108 Mtetra
.655 .751 .921 r
.15797 .47108 .16848 .48034 .18328 .47549 .17283 .46607 Mtetra
.65 .747 .921 r
.17283 .46607 .18328 .47549 .19816 .47063 .18776 .46121 Mtetra
.657 .751 .919 r
.18776 .46121 .19816 .47063 .21317 .46534 .2028 .45605 Mtetra
.662 .756 .92 r
.2028 .45605 .21317 .46534 .22826 .46009 .21795 .45067 Mtetra
.657 .753 .92 r
.21795 .45067 .22826 .46009 .24341 .45505 .23317 .44543 Mtetra
.65 .748 .921 r
.23317 .44543 .24341 .45505 .25864 .45026 .24846 .44045 Mtetra
.647 .744 .92 r
.24846 .44045 .25864 .45026 .27399 .44498 .26382 .43553 Mtetra
.662 .758 .921 r
.26382 .43553 .27399 .44498 .28941 .43984 .27933 .43001 Mtetra
.649 .747 .921 r
.27933 .43001 .28941 .43984 .30485 .43584 .29489 .42497 Mtetra
.62 .717 .915 r
.29489 .42497 .30485 .43584 .32026 .434 .31047 .42098 Mtetra
.571 .656 .895 r
.31047 .42098 .32026 .434 .33571 .43351 .32605 .41884 Mtetra
.548 .618 .875 r
.32605 .41884 .33571 .43351 .35135 .43196 .34169 .41766 Mtetra
.568 .635 .878 r
.34169 .41766 .35135 .43196 .36723 .42825 .35751 .4157 Mtetra
.603 .682 .897 r
.35751 .4157 .36723 .42825 .38337 .42117 .37352 .4123 Mtetra
.636 .773 .946 r
.37352 .4123 .38337 .42117 .39965 .41231 .38971 .40741 Mtetra
.663 .879 .979 r
.38971 .40741 .39965 .41231 .416 .40344 .40607 .40081 Mtetra
.632 .921 .977 r
.40607 .40081 .416 .40344 .43239 .39529 .42253 .39389 Mtetra
.563 .918 .957 r
.42253 .39389 .43239 .39529 .44882 .38834 .43906 .38748 Mtetra
.487 .893 .933 r
.43906 .38748 .44882 .38834 .46531 .38278 .45566 .38187 Mtetra
.433 .866 .923 r
.45566 .38187 .46531 .38278 .48189 .37861 .47236 .37705 Mtetra
.428 .857 .941 r
.47236 .37705 .48189 .37861 .49856 .37565 .48915 .37275 Mtetra
.505 .874 .98 r
.48915 .37275 .49856 .37565 .51537 .37343 .50607 .36814 Mtetra
.643 .875 .984 r
.50607 .36814 .51537 .37343 .53232 .37123 .52311 .36181 Mtetra
.704 .794 .92 r
.52311 .36181 .53232 .37123 .54939 .36723 .54024 .35395 Mtetra
.717 .725 .856 r
.54024 .35395 .54939 .36723 .56655 .35981 .55743 .34461 Mtetra
.719 .698 .829 r
.55743 .34461 .56655 .35981 .58376 .35017 .57469 .33446 Mtetra
.702 .685 .83 r
.57469 .33446 .58376 .35017 .601 .33943 .59203 .32526 Mtetra
.678 .699 .863 r
.59203 .32526 .601 .33943 .61834 .33004 .60949 .31795 Mtetra
.661 .73 .901 r
.60949 .31795 .61834 .33004 .63583 .32285 .62708 .31169 Mtetra
.65 .746 .92 r
.62708 .31169 .63583 .32285 .65346 .31681 .6448 .30593 Mtetra
.664 .759 .921 r
.6448 .30593 .65346 .31681 .67122 .31093 .66261 .29953 Mtetra
.661 .749 .915 r
.66261 .29953 .67122 .31093 .68906 .30452 .68054 .29319 Mtetra
.654 .749 .919 r
.68054 .29319 .68906 .30452 .70702 .29837 .69859 .28711 Mtetra
.65 .75 .923 r
.69859 .28711 .70702 .29837 .72512 .29242 .71677 .28117 Mtetra
.655 .754 .923 r
.71677 .28117 .72512 .29242 .74334 .28651 .73506 .275 Mtetra
.661 .753 .918 r
.73506 .275 .74334 .28651 .76165 .28014 .75345 .2685 Mtetra
.657 .749 .918 r
.75345 .2685 .76165 .28014 .78007 .27376 .77196 .26215 Mtetra
.653 .75 .921 r
.77196 .26215 .78007 .27376 .79863 .26753 .79061 .25594 Mtetra
.661 .754 .92 r
.13251 .46701 .14318 .47623 .15797 .47108 .14736 .46175 Mtetra
.656 .752 .92 r
.14736 .46175 .15797 .47108 .17283 .46607 .16227 .45661 Mtetra
.652 .749 .921 r
.16227 .45661 .17283 .46607 .18776 .46121 .17726 .45162 Mtetra
.651 .748 .92 r
.17726 .45162 .18776 .46121 .2028 .45605 .19233 .44663 Mtetra
.661 .755 .92 r
.19233 .44663 .2028 .45605 .21795 .45067 .20752 .44122 Mtetra
.661 .756 .92 r
.20752 .44122 .21795 .45067 .23317 .44543 .22281 .43581 Mtetra
.656 .752 .921 r
.22281 .43581 .23317 .44543 .24846 .44045 .23816 .43055 Mtetra
.648 .745 .92 r
.23816 .43055 .24846 .44045 .26382 .43553 .25359 .42555 Mtetra
.651 .745 .919 r
.25359 .42555 .26382 .43553 .27933 .43001 .26911 .42041 Mtetra
.661 .757 .921 r
.26911 .42041 .27933 .43001 .29489 .42497 .28476 .41483 Mtetra
.649 .744 .919 r
.28476 .41483 .29489 .42497 .31047 .42098 .30047 .40971 Mtetra
.626 .714 .909 r
.30047 .40971 .31047 .42098 .32605 .41884 .31622 .40541 Mtetra
.595 .663 .886 r
.31622 .40541 .32605 .41884 .34169 .41766 .332 .40232 Mtetra
.569 .621 .864 r
.332 .40232 .34169 .41766 .35751 .4157 .34784 .4003 Mtetra
.579 .626 .862 r
.34784 .4003 .35751 .4157 .37352 .4123 .36383 .39787 Mtetra
.599 .651 .873 r
.36383 .39787 .37352 .4123 .38971 .40741 .37999 .39458 Mtetra
.62 .688 .892 r
.37999 .39458 .38971 .40741 .40607 .40081 .3963 .39038 Mtetra
.637 .743 .925 r
.3963 .39038 .40607 .40081 .42253 .39389 .41275 .38546 Mtetra
.644 .792 .954 r
.41275 .38546 .42253 .39389 .43906 .38748 .42932 .38008 Mtetra
.646 .819 .966 r
.42932 .38008 .43906 .38748 .45566 .38187 .44601 .37441 Mtetra
.654 .822 .964 r
.44601 .37441 .45566 .38187 .47236 .37705 .4628 .36844 Mtetra
.671 .8 .944 r
.4628 .36844 .47236 .37705 .48915 .37275 .4797 .36201 Mtetra
.687 .76 .907 r
.4797 .36201 .48915 .37275 .50607 .36814 .4967 .35484 Mtetra
.696 .717 .865 r
.4967 .35484 .50607 .36814 .52311 .36181 .5138 .34675 Mtetra
.702 .693 .838 r
.5138 .34675 .52311 .36181 .54024 .35395 .53098 .33777 Mtetra
.703 .679 .824 r
.53098 .33777 .54024 .35395 .55743 .34461 .54823 .32836 Mtetra
.687 .672 .83 r
.54823 .32836 .55743 .34461 .57469 .33446 .56556 .32001 Mtetra
.673 .694 .861 r
.56556 .32001 .57469 .33446 .59203 .32526 .583 .31288 Mtetra
.661 .726 .897 r
.583 .31288 .59203 .32526 .60949 .31795 .60056 .30659 Mtetra
.65 .744 .918 r
.60056 .30659 .60949 .31795 .62708 .31169 .61824 .30075 Mtetra
.66 .758 .922 r
.61824 .30075 .62708 .31169 .6448 .30593 .63602 .29446 Mtetra
.663 .749 .914 r
.63602 .29446 .6448 .30593 .66261 .29953 .65391 .28802 Mtetra
.656 .747 .917 r
.65391 .28802 .66261 .29953 .68054 .29319 .67193 .28184 Mtetra
.651 .75 .922 r
.67193 .28184 .68054 .29319 .69859 .28711 .69007 .27581 Mtetra
.651 .752 .924 r
.69007 .27581 .69859 .28711 .71677 .28117 .70832 .26977 Mtetra
.66 .755 .921 r
.70832 .26977 .71677 .28117 .73506 .275 .72668 .26329 Mtetra
.659 .75 .917 r
.72668 .26329 .73506 .275 .75345 .2685 .74515 .25679 Mtetra
.655 .75 .92 r
.74515 .25679 .75345 .2685 .77196 .26215 .76376 .25044 Mtetra
.651 .75 .922 r
.76376 .25044 .77196 .26215 .79061 .25594 .7825 .24421 Mtetra
.66 .754 .92 r
.12172 .45766 .13251 .46701 .14736 .46175 .13662 .45238 Mtetra
.659 .754 .92 r
.13662 .45238 .14736 .46175 .16227 .45661 .15159 .44709 Mtetra
.655 .751 .921 r
.15159 .44709 .16227 .45661 .17726 .45162 .16664 .44192 Mtetra
.65 .747 .921 r
.16664 .44192 .17726 .45162 .19233 .44663 .18176 .4369 Mtetra
.655 .749 .919 r
.18176 .4369 .19233 .44663 .20752 .44122 .19698 .43169 Mtetra
.662 .756 .92 r
.19698 .43169 .20752 .44122 .22281 .43581 .21232 .42618 Mtetra
.659 .755 .921 r
.21232 .42618 .22281 .43581 .23816 .43055 .22774 .42073 Mtetra
.655 .751 .92 r
.22774 .42073 .23816 .43055 .25359 .42555 .24324 .41542 Mtetra
.648 .743 .919 r
.24324 .41542 .25359 .42555 .26911 .42041 .25881 .41033 Mtetra
.652 .747 .919 r
.25881 .41033 .26911 .42041 .28476 .41483 .27449 .40507 Mtetra
.661 .758 .922 r
.27449 .40507 .28476 .41483 .30047 .40971 .29029 .39941 Mtetra
.652 .745 .917 r
.29029 .39941 .30047 .40971 .31622 .40541 .30616 .39406 Mtetra
.637 .72 .907 r
.30616 .39406 .31622 .40541 .332 .40232 .32209 .38925 Mtetra
.623 .683 .886 r
.32209 .38925 .332 .40232 .34784 .4003 .33809 .38499 Mtetra
.601 .638 .86 r
.33809 .38499 .34784 .4003 .36383 .39787 .35415 .38159 Mtetra
.597 .624 .849 r
.35415 .38159 .36383 .39787 .37999 .39458 .37033 .3783 Mtetra
.608 .63 .847 r
.37033 .3783 .37999 .39458 .3963 .39038 .38665 .37452 Mtetra
.621 .643 .85 r
.38665 .37452 .3963 .39038 .41275 .38546 .40311 .37008 Mtetra
.635 .657 .854 r
.40311 .37008 .41275 .38546 .42932 .38008 .41971 .36499 Mtetra
.648 .667 .855 r
.41971 .36499 .42932 .38008 .44601 .37441 .43643 .35924 Mtetra
.659 .672 .851 r
.43643 .35924 .44601 .37441 .4628 .36844 .45328 .35285 Mtetra
.67 .671 .843 r
.45328 .35285 .4628 .36844 .4797 .36201 .47023 .34578 Mtetra
.678 .667 .832 r
.47023 .34578 .4797 .36201 .4967 .35484 .48728 .33806 Mtetra
.683 .663 .824 r
.48728 .33806 .4967 .35484 .5138 .34675 .50442 .32981 Mtetra
.681 .661 .824 r
.50442 .32981 .5138 .34675 .53098 .33777 .52165 .32167 Mtetra
.67 .668 .839 r
.52165 .32167 .53098 .33777 .54823 .32836 .53896 .31439 Mtetra
.667 .7 .872 r
.53896 .31439 .54823 .32836 .56556 .32001 .55637 .30765 Mtetra
.658 .727 .9 r
.55637 .30765 .56556 .32001 .583 .31288 .5739 .30147 Mtetra
.651 .744 .918 r
.5739 .30147 .583 .31288 .60056 .30659 .59154 .29559 Mtetra
.66 .757 .922 r
.59154 .29559 .60056 .30659 .61824 .30075 .60929 .2893 Mtetra
.663 .751 .915 r
.60929 .2893 .61824 .30075 .63602 .29446 .62714 .28282 Mtetra
.657 .746 .916 r
.62714 .28282 .63602 .29446 .65391 .28802 .64512 .27657 Mtetra
.653 .75 .921 r
.64512 .27657 .65391 .28802 .67193 .28184 .66321 .27045 Mtetra
.65 .752 .924 r
.66321 .27045 .67193 .28184 .69007 .27581 .68144 .26439 Mtetra
.657 .755 .922 r
.68144 .26439 .69007 .27581 .70832 .26977 .69976 .25801 Mtetra
.661 .751 .917 r
.69976 .25801 .70832 .26977 .72668 .26329 .7182 .25143 Mtetra
.656 .749 .918 r
.7182 .25143 .72668 .26329 .74515 .25679 .73676 .24498 Mtetra
.653 .75 .921 r
.73676 .24498 .74515 .25679 .76376 .25044 .75546 .23866 Mtetra
.652 .752 .923 r
.75546 .23866 .76376 .25044 .7825 .24421 .77428 .23231 Mtetra
.655 .75 .92 r
.11083 .4481 .12172 .45766 .13662 .45238 .12576 .44292 Mtetra
.66 .755 .92 r
.12576 .44292 .13662 .45238 .15159 .44709 .14079 .43752 Mtetra
.657 .753 .92 r
.14079 .43752 .15159 .44709 .16664 .44192 .1559 .43221 Mtetra
.653 .75 .921 r
.1559 .43221 .16664 .44192 .18176 .4369 .17108 .42702 Mtetra
.65 .747 .92 r
.17108 .42702 .18176 .4369 .19698 .43169 .18634 .4219 Mtetra
.657 .752 .92 r
.18634 .4219 .19698 .43169 .21232 .42618 .20171 .41651 Mtetra
.661 .757 .921 r
.20171 .41651 .21232 .42618 .22774 .42073 .2172 .41091 Mtetra
.658 .754 .921 r
.2172 .41091 .22774 .42073 .24324 .41542 .23276 .40541 Mtetra
.655 .75 .92 r
.23276 .40541 .24324 .41542 .25881 .41033 .24841 .4 Mtetra
.649 .743 .918 r
.24841 .4 .25881 .41033 .27449 .40507 .26413 .3948 Mtetra
.65 .746 .92 r
.26413 .3948 .27449 .40507 .29029 .39941 .27995 .38952 Mtetra
.661 .758 .922 r
.27995 .38952 .29029 .39941 .30616 .39406 .2959 .38377 Mtetra
.657 .75 .919 r
.2959 .38377 .30616 .39406 .32209 .38925 .31194 .37814 Mtetra
.649 .732 .91 r
.31194 .37814 .32209 .38925 .33809 .38499 .32805 .37279 Mtetra
.64 .709 .897 r
.32805 .37279 .33809 .38499 .35415 .38159 .34425 .36773 Mtetra
.634 .679 .875 r
.34425 .36773 .35415 .38159 .37033 .3783 .36054 .36282 Mtetra
.631 .653 .854 r
.36054 .36282 .37033 .3783 .38665 .37452 .37694 .35792 Mtetra
.628 .637 .84 r
.37694 .35792 .38665 .37452 .40311 .37008 .39345 .35301 Mtetra
.633 .634 .833 r
.39345 .35301 .40311 .37008 .41971 .36499 .41008 .34774 Mtetra
.642 .637 .83 r
.41008 .34774 .41971 .36499 .43643 .35924 .42684 .34192 Mtetra
.651 .641 .827 r
.42684 .34192 .43643 .35924 .45328 .35285 .44371 .33555 Mtetra
.657 .645 .826 r
.44371 .33555 .45328 .35285 .47023 .34578 .4607 .32881 Mtetra
.658 .65 .831 r
.4607 .32881 .47023 .34578 .48728 .33806 .47777 .32207 Mtetra
.661 .666 .844 r
.47777 .32207 .48728 .33806 .50442 .32981 .49495 .31531 Mtetra
.662 .69 .865 r
.49495 .31531 .50442 .32981 .52165 .32167 .51223 .30872 Mtetra
.66 .716 .89 r
.51223 .30872 .52165 .32167 .53896 .31439 .5296 .3024 Mtetra
.654 .734 .908 r
.5296 .3024 .53896 .31439 .55637 .30765 .54709 .29637 Mtetra
.651 .748 .921 r
.54709 .29637 .55637 .30765 .5739 .30147 .5647 .29046 Mtetra
.662 .759 .922 r
.5647 .29046 .5739 .30147 .59154 .29559 .5824 .28405 Mtetra
.662 .75 .915 r
.5824 .28405 .59154 .29559 .60929 .2893 .60022 .27757 Mtetra
.657 .745 .915 r
.60022 .27757 .60929 .2893 .62714 .28282 .61816 .27128 Mtetra
.653 .75 .92 r
.61816 .27128 .62714 .28282 .64512 .27657 .63622 .2651 Mtetra
.65 .751 .923 r
.63622 .2651 .64512 .27657 .66321 .27045 .6544 .259 Mtetra
.655 .755 .923 r
.6544 .259 .66321 .27045 .68144 .26439 .6727 .25268 Mtetra
.661 .753 .919 r
.6727 .25268 .68144 .26439 .69976 .25801 .6911 .24606 Mtetra
.658 .749 .917 r
.6911 .24606 .69976 .25801 .7182 .25143 .70962 .23952 Mtetra
.654 .75 .92 r
.70962 .23952 .7182 .25143 .73676 .24498 .72828 .23309 Mtetra
.652 .751 .922 r
.72828 .23309 .73676 .24498 .75546 .23866 .74706 .22673 Mtetra
.656 .754 .922 r
.74706 .22673 .75546 .23866 .77428 .23231 .76596 .22015 Mtetra
.652 .749 .92 r
.09983 .4384 .11083 .4481 .12576 .44292 .11479 .43328 Mtetra
.658 .753 .92 r
.11479 .43328 .12576 .44292 .14079 .43752 .12986 .42792 Mtetra
.66 .755 .92 r
.12986 .42792 .14079 .43752 .1559 .43221 .14503 .42245 Mtetra
.656 .752 .92 r
.14503 .42245 .1559 .43221 .17108 .42702 .16027 .41709 Mtetra
.652 .749 .92 r
.16027 .41709 .17108 .42702 .18634 .4219 .17559 .41184 Mtetra
.651 .747 .92 r
.17559 .41184 .18634 .4219 .20171 .41651 .191 .40661 Mtetra
.658 .753 .92 r
.191 .40661 .20171 .41651 .2172 .41091 .20652 .40109 Mtetra
.661 .757 .921 r
.20652 .40109 .2172 .41091 .23276 .40541 .22215 .39542 Mtetra
.658 .754 .921 r
.22215 .39542 .23276 .40541 .24841 .4 .23787 .38982 Mtetra
.655 .75 .92 r
.23787 .38982 .24841 .4 .26413 .3948 .25366 .3843 Mtetra
.65 .744 .918 r
.25366 .3843 .26413 .3948 .27995 .38952 .26954 .37893 Mtetra
.65 .743 .918 r
.26954 .37893 .27995 .38952 .2959 .38377 .28552 .37356 Mtetra
.655 .754 .922 r
.28552 .37356 .2959 .38377 .31194 .37814 .30161 .36793 Mtetra
.66 .756 .922 r
.30161 .36793 .31194 .37814 .32805 .37279 .31781 .36211 Mtetra
.657 .747 .916 r
.31781 .36211 .32805 .37279 .34425 .36773 .3341 .35636 Mtetra
.653 .733 .908 r
.3341 .35636 .34425 .36773 .36054 .36282 .35049 .3507 Mtetra
.65 .719 .899 r
.35049 .3507 .36054 .36282 .37694 .35792 .36697 .3451 Mtetra
.649 .707 .889 r
.36697 .3451 .37694 .35792 .39345 .35301 .38356 .33947 Mtetra
.65 .696 .879 r
.38356 .33947 .39345 .35301 .41008 .34774 .40026 .33373 Mtetra
.651 .69 .873 r
.40026 .33373 .41008 .34774 .42684 .34192 .41706 .32784 Mtetra
.654 .691 .872 r
.41706 .32784 .42684 .34192 .44371 .33555 .43397 .3218 Mtetra
.656 .698 .877 r
.43397 .3218 .44371 .33555 .4607 .32881 .451 .31565 Mtetra
.658 .71 .887 r
.451 .31565 .4607 .32881 .47777 .32207 .46812 .30946 Mtetra
.656 .721 .896 r
.46812 .30946 .47777 .32207 .49495 .31531 .48535 .30333 Mtetra
.654 .734 .908 r
.48535 .30333 .49495 .31531 .51223 .30872 .50269 .29729 Mtetra
.652 .745 .918 r
.50269 .29729 .51223 .30872 .5296 .3024 .52014 .29132 Mtetra
.656 .755 .923 r
.52014 .29132 .5296 .3024 .54709 .29637 .5377 .28515 Mtetra
.661 .756 .92 r
.5377 .28515 .54709 .29637 .5647 .29046 .55538 .27872 Mtetra
.661 .747 .914 r
.55538 .27872 .5647 .29046 .5824 .28405 .57316 .27227 Mtetra
.656 .745 .916 r
.57316 .27227 .5824 .28405 .60022 .27757 .59106 .26597 Mtetra
.653 .75 .92 r
.59106 .26597 .60022 .27757 .61816 .27128 .60908 .25975 Mtetra
.651 .752 .923 r
.60908 .25975 .61816 .27128 .63622 .2651 .62722 .2536 Mtetra
.654 .755 .924 r
.62722 .2536 .63622 .2651 .6544 .259 .64548 .24728 Mtetra
.66 .755 .92 r
.64548 .24728 .6544 .259 .6727 .25268 .66384 .24065 Mtetra
.659 .749 .917 r
.66384 .24065 .6727 .25268 .6911 .24606 .68233 .23404 Mtetra
.655 .749 .919 r
.68233 .23404 .6911 .24606 .70962 .23952 .70094 .22753 Mtetra
.652 .75 .922 r
.70094 .22753 .70962 .23952 .72828 .23309 .71969 .22112 Mtetra
.654 .753 .923 r
.71969 .22112 .72828 .23309 .74706 .22673 .73856 .21459 Mtetra
.659 .753 .92 r
.73856 .21459 .74706 .22673 .76596 .22015 .75753 .2078 Mtetra
.653 .749 .921 r
.08871 .42861 .09983 .4384 .11479 .43328 .10372 .42342 Mtetra
.653 .749 .92 r
.10372 .42342 .11479 .43328 .12986 .42792 .11882 .41818 Mtetra
.66 .754 .92 r
.11882 .41818 .12986 .42792 .14503 .42245 .13403 .41267 Mtetra
.659 .755 .921 r
.13403 .41267 .14503 .42245 .16027 .41709 .14934 .40715 Mtetra
.656 .751 .92 r
.14934 .40715 .16027 .41709 .17559 .41184 .16473 .40171 Mtetra
.652 .748 .92 r
.16473 .40171 .17559 .41184 .191 .40661 .18019 .39638 Mtetra
.651 .747 .919 r
.18019 .39638 .191 .40661 .20652 .40109 .19574 .39104 Mtetra
.657 .754 .921 r
.19574 .39104 .20652 .40109 .22215 .39542 .21141 .38544 Mtetra
.661 .757 .922 r
.21141 .38544 .22215 .39542 .23787 .38982 .22719 .37969 Mtetra
.659 .755 .921 r
.22719 .37969 .23787 .38982 .25366 .3843 .24306 .37398 Mtetra
.656 .752 .92 r
.24306 .37398 .25366 .3843 .26954 .37893 .25901 .36833 Mtetra
.653 .746 .918 r
.25901 .36833 .26954 .37893 .28552 .37356 .27506 .36274 Mtetra
.651 .742 .917 r
.27506 .36274 .28552 .37356 .30161 .36793 .29119 .35724 Mtetra
.651 .746 .919 r
.29119 .35724 .30161 .36793 .31781 .36211 .30743 .35167 Mtetra
.654 .754 .923 r
.30743 .35167 .31781 .36211 .3341 .35636 .32378 .34596 Mtetra
.659 .757 .923 r
.32378 .34596 .3341 .35636 .35049 .3507 .34024 .34004 Mtetra
.658 .753 .92 r
.34024 .34004 .35049 .3507 .36697 .3451 .3568 .33412 Mtetra
.657 .747 .917 r
.3568 .33412 .36697 .3451 .38356 .33947 .37346 .3282 Mtetra
.656 .743 .914 r
.37346 .3282 .38356 .33947 .40026 .33373 .39022 .32226 Mtetra
.655 .74 .912 r
.39022 .32226 .40026 .33373 .41706 .32784 .40709 .3163 Mtetra
.40709 .3163 .41706 .32784 .43397 .3218 .42406 .31032 Mtetra
.655 .742 .914 r
.42406 .31032 .43397 .3218 .451 .31565 .44114 .30432 Mtetra
.654 .746 .918 r
.44114 .30432 .451 .31565 .46812 .30946 .45833 .29833 Mtetra
.653 .752 .922 r
.45833 .29833 .46812 .30946 .48535 .30333 .47563 .29232 Mtetra
.658 .757 .923 r
.47563 .29232 .48535 .30333 .50269 .29729 .49304 .2861 Mtetra
.66 .756 .921 r
.49304 .2861 .50269 .29729 .52014 .29132 .51057 .27973 Mtetra
.661 .749 .916 r
.51057 .27973 .52014 .29132 .5377 .28515 .5282 .2733 Mtetra
.658 .745 .914 r
.5282 .2733 .5377 .28515 .55538 .27872 .54595 .26694 Mtetra
.655 .746 .917 r
.54595 .26694 .55538 .27872 .57316 .27227 .56381 .26065 Mtetra
.653 .75 .921 r
.56381 .26065 .57316 .27227 .59106 .26597 .58179 .25441 Mtetra
.651 .752 .924 r
.58179 .25441 .59106 .26597 .60908 .25975 .59989 .2482 Mtetra
.654 .755 .924 r
.59989 .2482 .60908 .25975 .62722 .2536 .61811 .24183 Mtetra
.66 .755 .92 r
.61811 .24183 .62722 .2536 .64548 .24728 .63643 .23518 Mtetra
.659 .749 .917 r
.63643 .23518 .64548 .24728 .66384 .24065 .65488 .22852 Mtetra
.656 .749 .918 r
.65488 .22852 .66384 .24065 .68233 .23404 .67346 .22196 Mtetra
.653 .75 .921 r
.67346 .22196 .68233 .23404 .70094 .22753 .69216 .21548 Mtetra
.652 .752 .923 r
.69216 .21548 .70094 .22753 .71969 .22112 .71099 .20898 Mtetra
.658 .755 .921 r
.71099 .20898 .71969 .22112 .73856 .21459 .72994 .20218 Mtetra
.659 .751 .918 r
.72994 .20218 .73856 .21459 .75753 .2078 .749 .19532 Mtetra
.655 .751 .92 r
.07746 .41876 .08871 .42861 .10372 .42342 .09252 .41344 Mtetra
.652 .748 .92 r
.09252 .41344 .10372 .42342 .11882 .41818 .10767 .40817 Mtetra
.654 .75 .92 r
.10767 .40817 .11882 .41818 .13403 .41267 .12291 .4028 Mtetra
.66 .755 .921 r
.12291 .4028 .13403 .41267 .14934 .40715 .13828 .39719 Mtetra
.659 .754 .921 r
.13828 .39719 .14934 .40715 .16473 .40171 .15373 .39159 Mtetra
.656 .751 .92 r
.15373 .39159 .16473 .40171 .18019 .39638 .16926 .38606 Mtetra
.653 .748 .919 r
.16926 .38606 .18019 .39638 .19574 .39104 .18487 .38062 Mtetra
.651 .746 .919 r
.18487 .38062 .19574 .39104 .21141 .38544 .20057 .37518 Mtetra
.656 .752 .921 r
.20057 .37518 .21141 .38544 .22719 .37969 .21639 .36955 Mtetra
.66 .757 .922 r
.21639 .36955 .22719 .37969 .24306 .37398 .23232 .36373 Mtetra
.659 .756 .922 r
.23232 .36373 .24306 .37398 .25901 .36833 .24834 .35789 Mtetra
.657 .753 .921 r
.24834 .35789 .25901 .36833 .27506 .36274 .26445 .3521 Mtetra
.656 .75 .919 r
.26445 .3521 .27506 .36274 .29119 .35724 .28066 .34632 Mtetra
.654 .745 .917 r
.28066 .34632 .29119 .35724 .30743 .35167 .29697 .34058 Mtetra
.652 .742 .916 r
.29697 .34058 .30743 .35167 .32378 .34596 .31337 .33487 Mtetra
.653 .744 .916 r
.31337 .33487 .32378 .34596 .34024 .34004 .32987 .32911 Mtetra
.654 .748 .919 r
.32987 .32911 .34024 .34004 .3568 .33412 .34649 .32328 Mtetra
.654 .752 .922 r
.34649 .32328 .3568 .33412 .37346 .3282 .36321 .31738 Mtetra
.655 .754 .923 r
.36321 .31738 .37346 .3282 .39022 .32226 .38004 .31142 Mtetra
.656 .755 .923 r
.38004 .31142 .39022 .32226 .40709 .3163 .39697 .30539 Mtetra
.656 .756 .923 r
.39697 .30539 .40709 .3163 .42406 .31032 .41402 .2993 Mtetra
.657 .755 .922 r
.41402 .2993 .42406 .31032 .44114 .30432 .43117 .29314 Mtetra
.658 .753 .92 r
.43117 .29314 .44114 .30432 .45833 .29833 .44843 .2869 Mtetra
.659 .75 .918 r
.44843 .2869 .45833 .29833 .47563 .29232 .4658 .2806 Mtetra
.659 .746 .914 r
.4658 .2806 .47563 .29232 .49304 .2861 .48329 .27424 Mtetra
.657 .744 .914 r
.48329 .27424 .49304 .2861 .51057 .27973 .50088 .26791 Mtetra
.656 .745 .916 r
.50088 .26791 .51057 .27973 .5282 .2733 .51859 .2616 Mtetra
.654 .749 .919 r
.51859 .2616 .5282 .2733 .54595 .26694 .53641 .25531 Mtetra
.652 .751 .922 r
.53641 .25531 .54595 .26694 .56381 .26065 .55435 .24907 Mtetra
.652 .754 .924 r
.55435 .24907 .56381 .26065 .58179 .25441 .57241 .2428 Mtetra
.656 .756 .924 r
.57241 .2428 .58179 .25441 .59989 .2482 .59058 .23633 Mtetra
.66 .754 .92 r
.59058 .23633 .59989 .2482 .61811 .24183 .60887 .22965 Mtetra
.659 .749 .917 r
.60887 .22965 .61811 .24183 .63643 .23518 .62728 .22297 Mtetra
.656 .749 .918 r
.62728 .22297 .63643 .23518 .65488 .22852 .64582 .21637 Mtetra
.653 .75 .921 r
.64582 .21637 .65488 .22852 .67346 .22196 .66448 .20984 Mtetra
.652 .752 .923 r
.66448 .20984 .67346 .22196 .69216 .21548 .68327 .2033 Mtetra
.657 .755 .922 r
.68327 .2033 .69216 .21548 .71099 .20898 .70218 .19651 Mtetra
.659 .751 .918 r
.70218 .19651 .71099 .20898 .72994 .20218 .72121 .1896 Mtetra
.657 .75 .918 r
.72121 .1896 .72994 .20218 .749 .19532 .74037 .18273 Mtetra
.657 .752 .92 r
.06607 .40887 .07746 .41876 .09252 .41344 .0812 .40341 Mtetra
.654 .75 .92 r
.0812 .40341 .09252 .41344 .10767 .40817 .0964 .39801 Mtetra
.652 .748 .92 r
.0964 .39801 .10767 .40817 .12291 .4028 .11169 .39264 Mtetra
.655 .75 .92 r
.11169 .39264 .12291 .4028 .13828 .39719 .12708 .38715 Mtetra
.659 .755 .921 r
.12708 .38715 .13828 .39719 .15373 .39159 .14259 .38146 Mtetra
.659 .754 .921 r
.14259 .38146 .15373 .39159 .16926 .38606 .15818 .37576 Mtetra
.656 .751 .92 r
.15818 .37576 .16926 .38606 .18487 .38062 .17386 .37013 Mtetra
.654 .748 .919 r
.17386 .37013 .18487 .38062 .20057 .37518 .18963 .36455 Mtetra
.652 .746 .919 r
.18963 .36455 .20057 .37518 .21639 .36955 .20549 .35902 Mtetra
.653 .75 .921 r
.20549 .35902 .21639 .36955 .23232 .36373 .22145 .35338 Mtetra
.659 .756 .922 r
.22145 .35338 .23232 .36373 .24834 .35789 .23753 .34751 Mtetra
.659 .757 .922 r
.23753 .34751 .24834 .35789 .26445 .3521 .25371 .34157 Mtetra
.659 .756 .922 r
.25371 .34157 .26445 .3521 .28066 .34632 .26999 .33563 Mtetra
.657 .753 .921 r
.26999 .33563 .28066 .34632 .29697 .34058 .28636 .32971 Mtetra
.656 .75 .919 r
.28636 .32971 .29697 .34058 .31337 .33487 .30283 .32378 Mtetra
.656 .747 .917 r
.30283 .32378 .31337 .33487 .32987 .32911 .31941 .31784 Mtetra
.655 .745 .916 r
.31941 .31784 .32987 .32911 .34649 .32328 .33609 .31187 Mtetra
.655 .743 .915 r
.33609 .31187 .34649 .32328 .36321 .31738 .35287 .30587 Mtetra
.655 .743 .914 r
.35287 .30587 .36321 .31738 .38004 .31142 .36976 .29983 Mtetra
.656 .743 .914 r
.36976 .29983 .38004 .31142 .39697 .30539 .38676 .29373 Mtetra
.38676 .29373 .39697 .30539 .41402 .2993 .40387 .28757 Mtetra
.40387 .28757 .41402 .2993 .43117 .29314 .42109 .28137 Mtetra
.656 .744 .914 r
.42109 .28137 .43117 .29314 .44843 .2869 .43842 .27513 Mtetra
.656 .745 .916 r
.43842 .27513 .44843 .2869 .4658 .2806 .45586 .26887 Mtetra
.655 .747 .917 r
.45586 .26887 .4658 .2806 .48329 .27424 .47341 .26259 Mtetra
.655 .75 .92 r
.47341 .26259 .48329 .27424 .50088 .26791 .49108 .25629 Mtetra
.653 .752 .922 r
.49108 .25629 .50088 .26791 .51859 .2616 .50886 .25002 Mtetra
.652 .754 .924 r
.50886 .25002 .51859 .2616 .53641 .25531 .52676 .24373 Mtetra
.653 .755 .925 r
.52676 .24373 .53641 .25531 .55435 .24907 .54477 .23738 Mtetra
.658 .757 .923 r
.54477 .23738 .55435 .24907 .57241 .2428 .56291 .23077 Mtetra
.66 .752 .918 r
.56291 .23077 .57241 .2428 .59058 .23633 .58116 .22407 Mtetra
.658 .748 .917 r
.58116 .22407 .59058 .23633 .60887 .22965 .59953 .21739 Mtetra
.656 .749 .918 r
.59953 .21739 .60887 .22965 .62728 .22297 .61803 .21075 Mtetra
.653 .75 .921 r
.61803 .21075 .62728 .22297 .64582 .21637 .63665 .20418 Mtetra
.652 .752 .923 r
.63665 .20418 .64582 .21637 .66448 .20984 .6554 .1976 Mtetra
.657 .755 .922 r
.6554 .1976 .66448 .20984 .68327 .2033 .67427 .19079 Mtetra
.659 .752 .919 r
.67427 .19079 .68327 .2033 .70218 .19651 .69326 .18384 Mtetra
.657 .75 .918 r
.69326 .18384 .70218 .19651 .72121 .1896 .71238 .17692 Mtetra
.655 .75 .92 r
.71238 .17692 .72121 .1896 .74037 .18273 .73163 .17005 Mtetra
.659 .754 .92 r
.05455 .39893 .06607 .40887 .0812 .40341 .06974 .39332 Mtetra
.656 .752 .92 r
.06974 .39332 .0812 .40341 .0964 .39801 .085 .38779 Mtetra
.654 .75 .92 r
.085 .38779 .0964 .39801 .11169 .39264 .10035 .3823 Mtetra
.653 .748 .92 r
.10035 .3823 .11169 .39264 .12708 .38715 .11578 .37683 Mtetra
.655 .75 .92 r
.11578 .37683 .12708 .38715 .14259 .38146 .13132 .37125 Mtetra
.659 .755 .921 r
.13132 .37125 .14259 .38146 .15818 .37576 .14697 .36548 Mtetra
.14697 .36548 .15818 .37576 .17386 .37013 .16272 .35967 Mtetra
.656 .752 .92 r
.16272 .35967 .17386 .37013 .18963 .36455 .17855 .35392 Mtetra
.655 .749 .919 r
.17855 .35392 .18963 .36455 .20549 .35902 .19448 .3482 Mtetra
.652 .746 .918 r
.19448 .3482 .20549 .35902 .22145 .35338 .21049 .34253 Mtetra
.653 .747 .919 r
.21049 .34253 .22145 .35338 .23753 .34751 .22661 .33682 Mtetra
.654 .752 .921 r
.22661 .33682 .23753 .34751 .25371 .34157 .24283 .331 Mtetra
.658 .757 .923 r
.24283 .331 .25371 .34157 .26999 .33563 .25917 .32501 Mtetra
.25917 .32501 .26999 .33563 .28636 .32971 .27561 .31897 Mtetra
.658 .756 .922 r
.27561 .31897 .28636 .32971 .30283 .32378 .29215 .31291 Mtetra
.657 .755 .922 r
.29215 .31291 .30283 .32378 .31941 .31784 .30879 .30683 Mtetra
.657 .753 .921 r
.30879 .30683 .31941 .31784 .33609 .31187 .32554 .30074 Mtetra
.656 .752 .92 r
.32554 .30074 .33609 .31187 .35287 .30587 .34239 .29463 Mtetra
.656 .751 .92 r
.34239 .29463 .35287 .30587 .36976 .29983 .35935 .28849 Mtetra
.656 .75 .92 r
.35935 .28849 .36976 .29983 .38676 .29373 .37642 .28232 Mtetra
.37642 .28232 .38676 .29373 .40387 .28757 .39359 .27612 Mtetra
.655 .751 .92 r
.39359 .27612 .40387 .28757 .42109 .28137 .41088 .26988 Mtetra
.655 .752 .921 r
.41088 .26988 .42109 .28137 .43842 .27513 .42828 .26361 Mtetra
.654 .752 .922 r
.42828 .26361 .43842 .27513 .45586 .26887 .44579 .25734 Mtetra
.654 .753 .923 r
.44579 .25734 .45586 .26887 .47341 .26259 .46341 .25106 Mtetra
.653 .755 .924 r
.46341 .25106 .47341 .26259 .49108 .25629 .48115 .24474 Mtetra
.654 .756 .925 r
.48115 .24474 .49108 .25629 .50886 .25002 .49901 .23837 Mtetra
.657 .757 .923 r
.49901 .23837 .50886 .25002 .52676 .24373 .51699 .23182 Mtetra
.659 .754 .92 r
.51699 .23182 .52676 .24373 .54477 .23738 .53508 .22515 Mtetra
.659 .749 .917 r
.53508 .22515 .54477 .23738 .56291 .23077 .55329 .21843 Mtetra
.656 .747 .917 r
.55329 .21843 .56291 .23077 .58116 .22407 .57162 .21177 Mtetra
.655 .749 .919 r
.57162 .21177 .58116 .22407 .59953 .21739 .59008 .20511 Mtetra
.653 .751 .921 r
.59008 .20511 .59953 .21739 .61803 .21075 .60866 .19851 Mtetra
.653 .753 .923 r
.60866 .19851 .61803 .21075 .63665 .20418 .62737 .19188 Mtetra
.657 .755 .922 r
.62737 .19188 .63665 .20418 .6554 .1976 .6462 .18503 Mtetra
.659 .752 .919 r
.6462 .18503 .6554 .1976 .67427 .19079 .66515 .17805 Mtetra
.657 .75 .918 r
.66515 .17805 .67427 .19079 .69326 .18384 .68423 .17108 Mtetra
.655 .75 .92 r
.68423 .17108 .69326 .18384 .71238 .17692 .70344 .16415 Mtetra
.653 .75 .921 r
.70344 .16415 .71238 .17692 .73163 .17005 .72279 .15728 Mtetra
.658 .753 .92 r
.04291 .38883 .05455 .39893 .06974 .39332 .05814 .38322 Mtetra
.659 .754 .921 r
.05814 .38322 .06974 .39332 .085 .38779 .07347 .37752 Mtetra
.656 .752 .92 r
.07347 .37752 .085 .38779 .10035 .3823 .08888 .3719 Mtetra
.654 .75 .92 r
.08888 .3719 .10035 .3823 .11578 .37683 .10437 .3663 Mtetra
.653 .748 .92 r
.10437 .3663 .11578 .37683 .13132 .37125 .11995 .36073 Mtetra
.654 .75 .92 r
.11995 .36073 .13132 .37125 .14697 .36548 .13563 .35508 Mtetra
.658 .755 .921 r
.13563 .35508 .14697 .36548 .16272 .35967 .15143 .34923 Mtetra
.659 .755 .921 r
.15143 .34923 .16272 .35967 .17855 .35392 .16733 .34332 Mtetra
.657 .753 .921 r
.16733 .34332 .17855 .35392 .19448 .3482 .18332 .33744 Mtetra
.656 .751 .92 r
.18332 .33744 .19448 .3482 .21049 .34253 .19941 .33158 Mtetra
.655 .748 .918 r
.19941 .33158 .21049 .34253 .22661 .33682 .21559 .32572 Mtetra
.653 .746 .918 r
.21559 .32572 .22661 .33682 .24283 .331 .23186 .3199 Mtetra
.653 .747 .919 r
.23186 .3199 .24283 .331 .25917 .32501 .24825 .31402 Mtetra
.654 .751 .921 r
.24825 .31402 .25917 .32501 .27561 .31897 .26473 .30808 Mtetra
.656 .755 .923 r
.26473 .30808 .27561 .31897 .29215 .31291 .28133 .30203 Mtetra
.657 .757 .924 r
.28133 .30203 .29215 .31291 .30879 .30683 .29804 .29589 Mtetra
.29804 .29589 .30879 .30683 .32554 .30074 .31485 .28972 Mtetra
.31485 .28972 .32554 .30074 .34239 .29463 .33177 .28352 Mtetra
.656 .756 .924 r
.33177 .28352 .34239 .29463 .35935 .28849 .3488 .2773 Mtetra
.3488 .2773 .35935 .28849 .37642 .28232 .36594 .27106 Mtetra
.655 .756 .924 r
.36594 .27106 .37642 .28232 .39359 .27612 .38318 .26479 Mtetra
.38318 .26479 .39359 .27612 .41088 .26988 .40054 .25849 Mtetra
.40054 .25849 .41088 .26988 .42828 .26361 .41801 .25217 Mtetra
.655 .757 .925 r
.41801 .25217 .42828 .26361 .44579 .25734 .43559 .24581 Mtetra
.656 .757 .924 r
.43559 .24581 .44579 .25734 .46341 .25106 .45329 .23936 Mtetra
.657 .755 .922 r
.45329 .23936 .46341 .25106 .48115 .24474 .47111 .23279 Mtetra
.658 .752 .92 r
.47111 .23279 .48115 .24474 .49901 .23837 .48904 .22616 Mtetra
.658 .749 .917 r
.48904 .22616 .49901 .23837 .51699 .23182 .5071 .21946 Mtetra
.657 .747 .916 r
.5071 .21946 .51699 .23182 .53508 .22515 .52527 .2128 Mtetra
.656 .748 .918 r
.52527 .2128 .53508 .22515 .55329 .21843 .54356 .20613 Mtetra
.654 .75 .92 r
.54356 .20613 .55329 .21843 .57162 .21177 .56197 .19947 Mtetra
.653 .751 .922 r
.56197 .19947 .57162 .21177 .59008 .20511 .58051 .19284 Mtetra
.653 .754 .923 r
.58051 .19284 .59008 .20511 .60866 .19851 .59918 .18614 Mtetra
.658 .755 .922 r
.59918 .18614 .60866 .19851 .62737 .19188 .61796 .17921 Mtetra
.658 .751 .919 r
.61796 .17921 .62737 .19188 .6462 .18503 .63687 .1722 Mtetra
.657 .749 .918 r
.63687 .1722 .6462 .18503 .66515 .17805 .65591 .16521 Mtetra
.656 .75 .919 r
.65591 .16521 .66515 .17805 .68423 .17108 .67509 .15822 Mtetra
.653 .75 .921 r
.67509 .15822 .68423 .17108 .70344 .16415 .6944 .15131 Mtetra
.654 .753 .922 r
.6944 .15131 .70344 .16415 .72279 .15728 .71384 .1443 Mtetra
.654 .75 .92 r
.03115 .37851 .04291 .38883 .05814 .38322 .04641 .37296 Mtetra
.658 .753 .921 r
.04641 .37296 .05814 .38322 .07347 .37752 .06179 .36724 Mtetra
.659 .754 .921 r
.06179 .36724 .07347 .37752 .08888 .3719 .07726 .36145 Mtetra
.656 .752 .92 r
.07726 .36145 .08888 .3719 .10437 .3663 .09282 .35572 Mtetra
.655 .75 .92 r
.09282 .35572 .10437 .3663 .11995 .36073 .10846 .35002 Mtetra
.653 .748 .919 r
.10846 .35002 .11995 .36073 .13563 .35508 .12419 .34433 Mtetra
.653 .749 .92 r
.12419 .34433 .13563 .35508 .15143 .34923 .14002 .33859 Mtetra
.657 .753 .921 r
.14002 .33859 .15143 .34923 .16733 .34332 .15597 .33271 Mtetra
.659 .756 .922 r
.15597 .33271 .16733 .34332 .18332 .33744 .17202 .32671 Mtetra
.658 .755 .921 r
.17202 .32671 .18332 .33744 .19941 .33158 .18818 .32068 Mtetra
.657 .752 .92 r
.18818 .32068 .19941 .33158 .21559 .32572 .20442 .31468 Mtetra
.656 .75 .92 r
.20442 .31468 .21559 .32572 .23186 .3199 .22077 .30868 Mtetra
.655 .748 .918 r
.22077 .30868 .23186 .3199 .24825 .31402 .23722 .30266 Mtetra
.654 .746 .917 r
.23722 .30266 .24825 .31402 .26473 .30808 .25377 .29664 Mtetra
.654 .746 .918 r
.25377 .29664 .26473 .30808 .28133 .30203 .27042 .29059 Mtetra
.654 .748 .918 r
.27042 .29059 .28133 .30203 .29804 .29589 .28718 .28449 Mtetra
.655 .75 .92 r
.28718 .28449 .29804 .29589 .31485 .28972 .30405 .27833 Mtetra
.655 .752 .921 r
.30405 .27833 .31485 .28972 .33177 .28352 .32104 .27212 Mtetra
.656 .753 .922 r
.32104 .27212 .33177 .28352 .3488 .2773 .33813 .26585 Mtetra
.656 .754 .922 r
.33813 .26585 .3488 .2773 .36594 .27106 .35533 .25953 Mtetra
.35533 .25953 .36594 .27106 .38318 .26479 .37265 .25316 Mtetra
.656 .753 .921 r
.37265 .25316 .38318 .26479 .40054 .25849 .39008 .24673 Mtetra
.657 .752 .92 r
.39008 .24673 .40054 .25849 .41801 .25217 .40762 .24024 Mtetra
.657 .751 .919 r
.40762 .24024 .41801 .25217 .43559 .24581 .42528 .2337 Mtetra
.657 .749 .917 r
.42528 .2337 .43559 .24581 .45329 .23936 .44306 .22709 Mtetra
.657 .747 .916 r
.44306 .22709 .45329 .23936 .47111 .23279 .46095 .22046 Mtetra
.656 .747 .917 r
.46095 .22046 .47111 .23279 .48904 .22616 .47896 .21382 Mtetra
.656 .748 .918 r
.47896 .21382 .48904 .22616 .5071 .21946 .49709 .20715 Mtetra
.655 .75 .92 r
.49709 .20715 .5071 .21946 .52527 .2128 .51533 .20048 Mtetra
.653 .751 .921 r
.51533 .20048 .52527 .2128 .54356 .20613 .53371 .19383 Mtetra
.653 .753 .923 r
.53371 .19383 .54356 .20613 .56197 .19947 .5522 .18714 Mtetra
.655 .755 .923 r
.5522 .18714 .56197 .19947 .58051 .19284 .57082 .18033 Mtetra
.658 .754 .921 r
.57082 .18033 .58051 .19284 .59918 .18614 .58957 .17335 Mtetra
.658 .75 .918 r
.58957 .17335 .59918 .18614 .61796 .17921 .60844 .16632 Mtetra
.657 .749 .918 r
.60844 .16632 .61796 .17921 .63687 .1722 .62744 .15929 Mtetra
.655 .75 .92 r
.62744 .15929 .63687 .1722 .65591 .16521 .64657 .15228 Mtetra
.653 .751 .921 r
.64657 .15228 .65591 .16521 .67509 .15822 .66583 .14532 Mtetra
.654 .753 .922 r
.66583 .14532 .67509 .15822 .6944 .15131 .68523 .13827 Mtetra
.657 .753 .921 r
.68523 .13827 .6944 .15131 .71384 .1443 .70476 .13103 Mtetra
.654 .749 .92 r
.01927 .36805 .03115 .37851 .04641 .37296 .03458 .36245 Mtetra
.654 .75 .92 r
.03458 .36245 .04641 .37296 .06179 .36724 .04998 .3568 Mtetra
.657 .753 .921 r
.04998 .3568 .06179 .36724 .07726 .36145 .0655 .351 Mtetra
.659 .755 .921 r
.0655 .351 .07726 .36145 .09282 .35572 .08112 .34511 Mtetra
.657 .752 .92 r
.08112 .34511 .09282 .35572 .10846 .35002 .09683 .33926 Mtetra
.655 .75 .92 r
.09683 .33926 .10846 .35002 .12419 .34433 .11262 .33344 Mtetra
.654 .749 .919 r
.11262 .33344 .12419 .34433 .14002 .33859 .12851 .32762 Mtetra
.653 .748 .919 r
.12851 .32762 .14002 .33859 .15597 .33271 .1445 .32179 Mtetra
.654 .751 .921 r
.1445 .32179 .15597 .33271 .17202 .32671 .16059 .31588 Mtetra
.657 .755 .922 r
.16059 .31588 .17202 .32671 .18818 .32068 .1768 .30982 Mtetra
.658 .756 .922 r
.1768 .30982 .18818 .32068 .20442 .31468 .19311 .30369 Mtetra
.658 .755 .921 r
.19311 .30369 .20442 .31468 .22077 .30868 .20953 .29754 Mtetra
.657 .753 .921 r
.20953 .29754 .22077 .30868 .23722 .30266 .22604 .29138 Mtetra
.656 .751 .92 r
.22604 .29138 .23722 .30266 .25377 .29664 .24266 .28522 Mtetra
.656 .75 .919 r
.24266 .28522 .25377 .29664 .27042 .29059 .25938 .27903 Mtetra
.655 .748 .918 r
.25938 .27903 .27042 .29059 .28718 .28449 .27621 .2728 Mtetra
.655 .747 .917 r
.27621 .2728 .28718 .28449 .30405 .27833 .29315 .26654 Mtetra
.29315 .26654 .30405 .27833 .32104 .27212 .31019 .26024 Mtetra
.655 .746 .917 r
.31019 .26024 .32104 .27212 .33813 .26585 .32735 .25389 Mtetra
.656 .746 .917 r
.32735 .25389 .33813 .26585 .35533 .25953 .34462 .24749 Mtetra
.34462 .24749 .35533 .25953 .37265 .25316 .36201 .24105 Mtetra
.36201 .24105 .37265 .25316 .39008 .24673 .37951 .23456 Mtetra
.656 .747 .917 r
.37951 .23456 .39008 .24673 .40762 .24024 .39712 .22802 Mtetra
.39712 .22802 .40762 .24024 .42528 .2337 .41485 .22144 Mtetra
.656 .748 .918 r
.41485 .22144 .42528 .2337 .44306 .22709 .4327 .21483 Mtetra
.655 .749 .919 r
.4327 .21483 .44306 .22709 .46095 .22046 .45066 .20819 Mtetra
.655 .751 .92 r
.45066 .20819 .46095 .22046 .47896 .21382 .46874 .20153 Mtetra
.654 .752 .922 r
.46874 .20153 .47896 .21382 .49709 .20715 .48695 .19487 Mtetra
.654 .753 .923 r
.48695 .19487 .49709 .20715 .51533 .20048 .50528 .18817 Mtetra
.654 .755 .923 r
.50528 .18817 .51533 .20048 .53371 .19383 .52373 .1814 Mtetra
.657 .755 .922 r
.52373 .1814 .53371 .19383 .5522 .18714 .54231 .17446 Mtetra
.658 .752 .919 r
.54231 .17446 .5522 .18714 .57082 .18033 .56101 .16744 Mtetra
.657 .749 .918 r
.56101 .16744 .57082 .18033 .58957 .17335 .57984 .16039 Mtetra
.656 .749 .918 r
.57984 .16039 .58957 .17335 .60844 .16632 .59879 .15334 Mtetra
.655 .75 .92 r
.59879 .15334 .60844 .16632 .62744 .15929 .61788 .14631 Mtetra
.653 .751 .921 r
.61788 .14631 .62744 .15929 .64657 .15228 .63711 .1393 Mtetra
.654 .753 .922 r
.63711 .1393 .64657 .15228 .66583 .14532 .65646 .1322 Mtetra
.657 .753 .921 r
.65646 .1322 .66583 .14532 .68523 .13827 .67594 .12492 Mtetra
.658 .751 .919 r
.67594 .12492 .68523 .13827 .70476 .13103 .69556 .11757 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
[(-2)] .12586 .2075 1 .99877 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.56863 .04703 m
.57247 .05235 L
s
[(2)] .56094 .0364 .72324 1 Mshowa
.125 Mabswid
.18558 .19702 m
.18832 .19985 L
s
.23703 .17687 m
.23971 .17975 L
s
.28951 .15632 m
.29214 .15925 L
s
.39772 .11395 m
.40023 .11699 L
s
.4535 .09211 m
.45595 .0952 L
s
.51046 .06981 m
.51284 .07294 L
s
.08568 .23614 m
.08851 .23887 L
s
.62804 .02377 m
.63027 .02701 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 233.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00o?ooool2o`0006[ooooo003iooooo`?o000000?oooooo`000?ooool0
JOooool00?Oooooo0_l00004ooooo`;o0000JOooool00?Cooooo0ol00006ooooo`03o`000?oooooo
000006Sooooo003;ooooo`Go00008_ooool2o`0000Wooooo00?o0000ooooool00000J?ooool00<_o
oooo00GoV9RHob4Q8Oo^k^koooooodA4A00Oooooo`?o00002oooool01?l0003oooooooooool0001W
ooooo`00c?ooool00onHV9So8B4Qonk^kP0Mooooo`?o00003_ooool01Ol0003ooooooooooooooooo
000006Kooooo003=ooooo`03oiRHV?lQ8B7ok^k^01[ooooo0_l0000Aooooo`05o`000?oooooooooo
ooooool00000I_ooool00<kooooo00?oMgMgofIVI_ooool05_ooool3o`0001?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1Sooooo`00coooool00ol0003oooooooooo`0Cooooo`;o
00000_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0H_ooool00<_ooooo00Go0000okZj^_ooooooV9RHoa0@400Booooo`?o00006Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo06;ooooo003;ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`04?ooool2o`0001cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Qooooo`00
gOooool3o`0001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Qooooo`00fooo
ool2o`00027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Pooooo`00f?ooool3
o`0002?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Oooooo`00eOooool3o`00
02Kooooo00?o0000ooooooooool01?ooool2o`00067ooooo003Cooooo`;o0000:Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo05kooooo003@ooooo`?o000000?oooooo`000?ooool0
:?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05gooooo003>ooooo`;o00001Ooo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0GOoo
ool00<_ooooo0ol0000`ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0G?ooool0
0<Wooooo0_l0000cooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Foooool00<Ko
oooo0ol0000eooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Foooool00<Cooooo
0_l0000hooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0F_ooool00<7ooooo0ol0
000jooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03_ooool5o`0004Kooooo002n
ooooo`?o0000?Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00kooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A016ooooo`00_?ooool2o`0000?ooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo1_l00003ooooo`03oiRHV?lQ8B7o
k^k^04Oooooo002iooooo`?o0000@oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00kooooo00?oV9RHob4Q8Oo^k^h0A_ooool00;Oooooo0_l00016ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03oooool00omgMgOoIVIVooooo`15ooooo`00]?ooool3o`0004Sooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Cooooo
002booooo`;o0000Boooool00ol0003oooooooooo`0=ooooo`;o00003?ooool01Ol0003o^[Zjoooo
oonHV9So410@04Kooooo002_ooooo`?o0000COooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c016ooooo`00[Oooool2o`00053ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`1Dooooo`00Z_ooool4o`00057ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1Dooooo`00Z?ooool2o`0000Cooooo00?o0000oooo
ooooool0C_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05?ooooo001nooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h08_ooool3o`0005Oooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`1Booooo`00O_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01oooooo0ol0001Joooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool0D_ooool007kooooo00Go410@oooooooo
oooooooooa0@400Mooooo`;o0000GOooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
057ooooo001nooooo`05o`000?ooooooooooooooool000006_ooool3o`0005oooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`1@ooooo`00O_ooool01Ol0003ooooooooooooooooo0000
01Sooooo0_l0001Rooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0D?ooool007ko
oooo00Go410@oooooooooooooooooa0@400Eooooo`?o0000I?ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo04oooooo001nooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool2o`00
00?ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
04kooooo001nooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04?ooool3o`0006Sooooo00?oZ<3[o`00
0?ooool05_ooool00ol0003oooooooooo`1>ooooo`00TOooool2o`0006Sooooo1?nX`>/00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo04gooooo002>ooooo`?o0000J?ooool7ojS0j`03o`00
0?oooooooooo01Cooooo0ol0001>ooooo`00Roooool3o`0006Wooooo2OnX`>/00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo04cooooo0029ooooo`;o0000JOooool<ojS0j`03o`000?nX`>_o
oooo01Oooooo00?o0000ooooooooool0Boooool008Kooooo0ol0001Xooooo`03ojO0k?nX`>_oZ<3[
00coZ<3[00?o0000ojS0joooool06?ooool00ol0003oooooooooo`1:ooooo`00Q?ooool2o`0000;o
oooo00?o0000ooooooooool0Hoooool5ojO0k0goZ<3[00?o0000ojS0jonX`>/06?ooool00ol0003o
ooooooooo`1:ooooo`00POooool3o`0000Gooooo00?o0000ooooooooool0H?ooool8ojO0k0OoZ<3[
00?oYl3/ojS0jonX`>/00_nX`>/01?l0003oZ<3[ojS0jonX`>/Hooooo`03o`000?oooooooooo04Wo
oooo001oooooo`;o0000JOooool00onW`>_oYl3/ojO0k007ojO0k0CoZ<3[1OnW`>`3ojS0j`03o`00
0?nX`>_oZ<3[00;oZ<3[6?ooool00ol0003oooooooooo`18ooooo`00O?ooool3o`0006Sooooo1OnW
`>/9ojO0k003ojS0jonW`>coYl3/00KoYl3/0_nX`>/01Ol0003oZ<3[ojS0jonX`>_oYl3/01Sooooo
00?o0000ooooooooool0B?ooool007[ooooo0_l0001Wooooo`;oYko[2?nW`>/6ojO0k0;oYl3[2OnW
`>`2ojS0j`03o`000?nX`>_oYl3/00?oYl3/6?ooool00ol0003oooooooooo`17ooooo`00Moooool3
o`0006Kooooo1_nW_n/8ojO0j`;oYl3/1_nW`>/9ojO0k003ojS0jol0003oYl3/00GoYl3/6?ooool0
0ol0003oooooooooo`16ooooo`00M?ooool3o`0006Kooooo2_nW_n/6ojO0j`;oYko[2?nW`>/6ojO0
k0;oYko[00?oYl3/o`000?nW`>`01OnW`>`Hooooo`03o`000?oooooooooo04Kooooo001booooo`;o
00000_ooool00ol0003oooooooooo`1Rooooo`goYko[0_nW`>/6ojNoj`SoYl3[0_nW`>`6ojNoj`03
o`000?nW`>coYl3/00GoYl3/6?ooool00ol0003oooooooooo`15ooooo`00Koooool3o`0006Oooooo
3_nW_n/00onX_n_oYko[ojNoj`07ojNoj`KoYl3[2OnW_n/00ol0003oYl3/ojO0k004ojO0k003ojNo
jooooooooooo01Kooooo00?o0000ooooooooool0AOooool006gooooo0_l0001Wooooo`;oZ;o[3?nW
_n/5ojRoj`WoYko[0_nW`>/<ojNoj`04o`000?nW_n_oYl3/ojO0k0GoYko[5oooool2o`0004Kooooo
001Zooooo`?o0000I_ooool6ojRoj`WoYko[2?nX_n/7ojNoj`03ojRojonW_n_oYko[00coYko[00?o
0000ojNojonW_n/01onW_n/Hooooo`03o`000?oooooooooo04?ooooo001Xooooo`;o0000I_ooool2
ojS0j`SoZ;o[1_nW_n/:ojRoj`CoYko[1OnX_n/=ojNoj`03o`000?nW_n_oYko[00SoYko[5oooool0
0ol0003oooooooooo`13ooooo`00IOooool3o`0006Kooooo1OnX`>/8ojRoj`;oYko[3_nX_n/00onW
_n_oZ;o[ojRoj`06ojRoj`KoYko[00?oZ;o[ojNojonW_n/00onW_n/00ol0003oYko[ojNoj`08ojNo
jaSooooo00?o0000ooooooooool0@_ooool006?ooooo0_l0001Wooooo`SoZ<3[1_nX_n/00onX`N_o
Z;o[ojRoj`0=ojRoj`03ojS0jonX_n_oZ;o[00OoZ;o[1?nW_n/4ojRoj`GoYko[00?o0000ojNojonW
_n/02?nW_n/Hooooo`03o`000?oooooooooo047ooooo001Pooooo`?o000000?oooooo`000?ooool0
I?ooool00onX`NcoZ<3[ojS0j`08ojS0j`;oZ;o[1OnX`N/;ojRoj`GoZ<3[2OnX_n/00onW_n_oZ;o[
ojRoj`05ojRoj`CoYko[00Co0000ojNojonW_n_oZ;o[2?nW_n/Gooooo`03o`000?oooooooooo047o
oooo000fooooo`Go00008oooool2o`0006Oooooo1OnX`N`8ojS0j`03ojO1k?nX`N_oZ<7[00KoZ<7[
1_nX_n/2ojS1k0SoZ<3[1_nX_n/2ojS0j`SoZ;o[1?nW_n/00ol0003oZ;o[ojRoj`02ojRoj`SoYko[
5oooool00ol0003oooooooooo`10ooooo`00=_ooool01OnHV9So8B4Qonk^k_ooooooA4A4023ooooo
0ol0001Uooooo`;oYl7/2?nX`N`4ojS0j`GoYl7/2?nX`N/2ojRoj`KoZ<7/2?nX`>/2ojRoj`KoZ<3[
2?nX_n/01?nW_n_oZ;o[ojRojol00005ojRoj`KoYko[00?oZ;o[ooooooooool05_ooool00ol0003o
ooooooooo`0oooooo`00;_ooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h07_ooool3o`0006Gooooo
1_nW`N`8ojS1k003ojS0jonW`NcoYl7/00KoYl7/1_nX`N/00onW`NcoZ<7/ojS1k007ojS1k0KoZ<3[
00?oZ<7/ojS0jonX`>/01onX`>/6ojRoj`05ojS0jonX_n_oZ;o[ojRojol000001OnX_n/4ojNoj`Co
Z;o[5oooool00ol0003oooooooooo`0oooooo`00>?ooool00onHV9So8B4Qonk^kP0Kooooo`;o0000
IOooool2ojO0k0SoYl7/1_nX`N`2ojO0k0SoYl7/1?nX`N/4ojO1k0WoZ<7/0_nX`>/5ojS1k0WoZ<3[
0_nX_n/5ojS0j`;oZ;o[00?o0000ojRojonX_n/01?nX_n/00onW_n_oZ;o[ojRoj`05ojRojaOooooo
00?o0000ooooooooool0?_ooool003Wooooo00?oMgMgofIVI_ooool05oooool3o`0006Cooooo1_nW
`>`8ojO1k0;oZ<7/1_nW`>`8ojO1k003ojS1jonW`NcoYl7/00GoYl7/1onX`N`00onW`>coZ<7/ojS1
k006ojS1k0KoZ<3[0_nX`N`8ojS0j`03ojRojol0003oZ;o[00?oZ;o[0_nX`>/8ojRojaSooooo00?o
0000ooooooooool0?Oooool003[ooooo00?o0000ooooooooool05?ooool2o`0006Cooooo2_nW`>`6
ojO1k003ojO0jonW`>coYl3/00OoYl3/1_nW`N`00onW`>coYl7/ojO1k007ojO1k0CoZ<7/1?nW`>`8
ojS1k0;oZ<3[1_nX`N`8ojS0j`03o`000?nX_n_oZ<3[00GoZ<3[2?nX_n/Gooooo`03o`000?oooooo
oooo03gooooo000fooooo`05o`000?nj^[[ooooooiRHV?l@41004oooool3o`0000;ooooo00?o0000
ooooooooool0Goooool=ojO0k0;oYl7/1OnW`>/9ojO0k0;oYl7/1OnW`>`9ojO1k003ojS1k?nW`>co
Yl3/00GoYl3/1_nX`N`00onV`>coZ<7/ojS1k007ojS1k0KoZ<3[00?oZ<7/o`000?nX`>/01onX`>/6
ojRoj`03ojS0jooooooooooo01Kooooo00?o0000ooooooooool0??ooool003Kooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00Aooooo`;o0000IOooool>ojO0k003ojNojonW`>_oYl3[00KoYl3[1_nW`>`2
ojNoj`SoYl3/1_nW`N`2ojO0j`SoYl3/1?nX`N`4ojK0k0WoZ<7/0_nX`>/4ojS1k003o`000?nX`>_o
Z<3[00OoZ<3[0_nX_n/5ojS0jaKooooo0ol0000mooooo`00BOooool3o`0006Gooooo00?oYl3[ojO0
k?nW`>`02onW`>`4ojNoj`SoYl3[0_nW`>`6ojNoj`SoYl3/0_nW`N`6ojO0j`SoYl3/00?oZ<7/ojK0
k?nV`>`01OnV`>`7ojS1k003ojK0k?nX`NcoZ<7/00CoZ<7/00?o0000ojS1k?nX`>/01OnX`>/2ojS1
j`SoZ<3[5oooool00ol0003oooooooooo`0kooooo`00Aoooool2o`0006Gooooo1OnW`>/:ojO0k0Oo
Yko[1_nW`>/:ojNoj`KoYl3/00?oYko[ojO0jonW`>/01onW`>/6ojO0k003ojNojonV`>coY/3/00Ko
Y/3/1?nX`N`5ojK0k0GoZ<7/00?o0000ojS1k?nX`N`00_nX`>/6ojS1j`SoZ<3[5oooool00ol0003o
ooooooooo`0jooooo`00A?ooool3o`0006Cooooo00?oYko[ojO0jonW`>/01_nW`>/6ojO0k0[oYko[
1?nW`>/=ojNoj`;oYl3/1OnW_n/9ojO0j`;oYl3/1OnW_n/8ojK0k003ojS1k?nV`>coY/3/00KoY/3/
1?nX`N`00ol0003oZ<7/ojK0k009ojS1j`OoZ<3[6?ooool00ol0003oooooooooo`0iooooo`00@Ooo
ool3o`0006Cooooo1OnW_n/8ojO0j`;oYl3/3_nW_n/00onW`>_oYko[ojNoj`0<ojNoj`03ojNoj_nW
_n_oYko[00KoYko[1_nW`>/:ojNoj`KoY/3/0_nW_n/9ojK0k0;oZ<7/00?oY/3/o`000?nV`>`00_nV
`>`9ojS1j`OoZ<3[5oooool00ol0003oooooooooo`0iooooo`00?oooool3o`0006?ooooo2OnW_n/6
ojO0j`;oYkoZ3_nW_n/2ojRojP_oYko[1OnW_nX8ojNoj`;oYl3[3_nW_n/2ojK0k0KoYko[1onV`>`0
1OnW_n_oY/3/ojK0k?nV`>co000000CoY/3/1_nX`N/2ojO0k0SoZ<3[5oooool00ol0003ooooooooo
o`0hooooo`00??ooool3o`0000?ooooo00?o0000ooooooooool0GOooool=ojNoj`;oYl3[1_nW_nX:
ojNoj`KoZ;oZ1onW_n/00onX_n[oYkoZojNojP06ojNojPKoYko[0_nX_nXHojNoj`CoY/3/1?nW_n/2
ojK0k003o`000?nV`>coY/3/00?oY/3/0_nX`N/6ojO0k0SoZ<3[5_ooool00ol0003oooooooooo`07
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0;?ooool003[ooooo0_l0001Sooooo`03ojNoj_nW_n_o
Yko[00coYko[0_nX_nX8ojNojPKoYko[2_nX_nX4ojNoj`CoZ;oZ2?nW_nX2ojNoj`KoZ;oZ6?nW_n/0
0onV`>coYko[ojNoj`05ojNoj`03ojK0k?l0003oY/3/00?oY/3/00?oY[o/ojO0k?nW`>`01onW`>`6
ojS0j`03ojO1k?oooooooooo01Gooooo00?o0000ooooooooool01_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg02cooooo000gooooo`?o0000Hoooool4ojNojP[oYko[1_nX_nX8ojNojP;oYko[3_nX_nX0
0onW_n_oZ;oZojRojP05ojRojPKoYkoZ00?oZ<3[ojRoj_nX_nX01onX_nX6ojNoj`03ojRoj_nW_n_o
Yko[01KoYko[0_nV`>`00ol0003oY/3/ojJok003ojJok0WoYl3/0_nX`>/5ojO1k1Oooooo00?o0000
ooooooooool01Oooool01Ol@413ooooooooooooooooo410@02cooooo000eooooo`;o0000I?ooool7
ojNojPKoYko[2_nX_nX6ojNojP03ojS0jonX_n[oZ;oZ00coZ;oZ0_nX`N/8ojRojPCoYkoZ1?nX`>/9
ojRojP;oYko[1OnX_nXHojNoj`03ojK0k?l0003oY[o/00GoY[o/1_nW`>`2ojK0k0SoYl7/5_ooool0
0ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool00000;?ooool003;ooooo0ol0001T
ooooo`WoYkoZ1?nW_n/=ojRojP;oYkoZ1OnX`>/:ojRojPKoZ<7[2?nX_nX00onW_n[oZ<3[ojS0j`05
ojS0j`OoZ;oZ00?oZ<7[ojRoj_nX_nX01_nX_nX6ojNoj`03ojRoj_nW_n_oYko[00koYko[00?oY[o/
o`000?nV_n`01_nV_n`2ojO0k0KoY/3/2?nW`N`Fooooo`03o`000?oooooooooo00Cooooo00Go0000
ooooooooooooooooo`00000/ooooo`00<?ooool2o`0006Cooooo3OnW_nX00onW_n_oZ;oZojRojP0<
ojRojP03ojS1k?nX`>_oZ<3[00KoZ<3[1_nX_nX2ojS1k0SoZ<7[1_nX_nX00onX`NcoZ<3[ojS0j`06
ojS0j`CoZ;oZ1OnX`N/8ojRojP;oYko[1OnX_nX@ojNoj`03o`000?nV_ncoY[o/00CoY[o/00?oYko[
ojK0k?nV`>`01_nV`>`6ojO1k0;oY/3/5oooool00ol0003oooooooooo`03ooooo`05oa0@4?oooooo
ooooooooool@4100;?ooool002gooooo0ol000000ooooooo0000ooooo`1Pooooo`03ojNnj_nW_n[o
YkoZ00coYkoZ0_nX`>/<ojRojPCoZ<7/2?nX`>/2ojRojPKoZ<7/2?nX`N/2ojRojPGoZ<7/2?nX`>/0
0onX_n[oZ<7[ojS1j`06ojS1j`KoZ;oZ00?oZ<7[ojRoj_nX_nX01_nX_nX6ojNoj`;oZ;oZ1onW_n/0
0ol0003oY[o/ojJok002ojJok0CoYko[2?nV`>`2ojO1k0KoY/3/5_ooool2o`0000Cooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0/ooooo`00:_ooool3o`0006?ooooo1OnW_^X:ojNojPKoZ<3[2OnX_nX7
ojS1k0KoZ<3[0_nW`N`8ojS1k0KoZ<7[00?oYl7/ojS1k?nX`N`01_nX`N`6ojS0j`;oYl7/2OnX`N/2
ojRojPGoZ<7[2?nX_nX2ojNoj`KoZ;oZ1_nW_n/00ol0003oYko[ojJok007ojNoj`KoY/3/00?oYko[
ojK0k?nV`>`01onV`>`Cooooo`;o000000?oooooo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^02cooooo000Xooooo`;o0000Hoooool9ojNnjPKoYkoZ2_nX`>/6ojRojP03ojO1k?nX`Nco
Z<7/00OoZ<7/0_nX`>/6ojO1k0SoZ<7/0_nX`N/5ojO1k0SoZ<7/0_nX`>/6ojO1k0OoZ<7[00?oYl7/
ojS1jonX`N/01_nX`N/6ojRojP03ojS1jonX_n[oZ;oZ00OoZ;oZ1OnW_n/00ol0003oZ;oZojNoj`08
ojNoj`;oY/3/1OnW_n/9ojK0k1Kooooo00?o0000ooooooooool0<_ooool002Gooooo0ol0001Roooo
o`goYkkZ0_nW_nX>ojS0j`;oZ;oZ1OnW`N`7ojS1k0[oYl7/1_nX`N`00onV`NcoYl7/ojO1k006ojO1
k0KoZ<7/00?oY/7/ojO1k?nW`N`01onW`N`4ojS1j`CoYl7/2?nX`N/2ojRojPGoZ<7[2OnX_nX2ojNo
j`03ojRoj_l0003o000000;oZ;oZ4?nW_n/6ojK0k0;oY[o/5_ooool00ol0003oooooooooo`0boooo
o`008oooool2o`0006;ooooo3onW_^X2ojO0j`koZ<3[2OnW`N`4ojS1k0goYl7/0_nX`N`5ojK1k0So
Yl7/0_nX`N`5ojK1k0WoYl7/00?oZ<7[ojO1k?nW`N`01OnW`N`6ojS1j`03ojO1k?nX`N_oZ<7[00Ko
Z<7[1_nX_nX2ojW0j`?o000000?oZ;oZo`000?nX_nX00_nX_nX@ojNoj`;oY/3/1_nV_n`Fooooo`03
o`000?oooooooooo037ooooo000Pooooo`?o0000HOooool?ojNnjPKoYl3[2_nX`>/=ojO1k003ojS1
k?nW`NcoYl7/00coYl7/00?oYl3/ojK1k?nV`N`01_nV`N`6ojO1k003ojK0k?nV`NcoY/7/00KoY/7/
1_nW`N`3ojK0k0SoYl7/0_nX`N/5ojO1k0SoZ<7[0_nX_nX2ojW0j`?o000000?oZL3[ojRoj_nX_nX0
0_nX_nX01?l0003oZ;oZojRoj_nX_nX?ojNoj`SoY[o/5oooool00ol0003oooooooooo`0`ooooo`00
7oooool2o`00063ooooo3onW_^X2ojO1k0SoYl3[1_nX`>/?ojO1k0?oYl3/2_nW`N`5ojO0k0SoY/7/
0_nW`N`5ojK0k0SoY/7/0_nW`N`7ojK0k0KoYl7/00?oY/3/ojO1k?nW`N`01_nW`N`6ojS1j`03ojO1
k?nY`>_o000000;o00001?nY`>/5ojRojP03o`000?nY`>[oZL3Z013oYko[2?nV_n`Fooooo`03o`00
0?oooooooooo033ooooo000Oooooo`03o`000?oooooo000005gooooo3_nW_^X6ojO1k0SoYl3[0_nX
`>/?ojO1k0OoYl3/1_nW`N`00onW_n_oYl3/ojO0k006ojO0k0KoY/7/00?oYko[ojK0k?nV`>`01_nV
`>`6ojK1k0;oYko[2OnV`>`2ojO1k0GoY/3/2?nW`N`2ojS1j`;oYl7/0ol00008ojW0j`;oZ;oZ0onY
`>X00ol0003oZL3ZojW0jP07ojNoj`03ojRoj_nW_n_oYko[00KoYko[1_nV_n`00onW_n_ooooooooo
o`0Eooooo`03o`000?oooooooooo02oooooo000<ooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Kooooo00Co0000oooooooooooo0000F_ooool=ojNnjP[oYl7/1_nW`>/?ojO1k0_oYl3/
0_nW`N`5ojNoj`SoYl3/0_nV`N`5ojNoj`SoY/3/0_nV`N`6ojNoj`OoY/3/00?oYko[ojK0k?nV`>`0
1_nV`>`6ojO1k003ojK0k?nW`Nco000000;o00001?nW`N`6ojW0j`03ojS1k?nY`>[oZL3Z00?oZL3Z
00Co0000ojW0j_nY`>[oZL3Z1?nW_n/4ojRojPSoYko[0_nV_n`5ojNojaOooooo00?o0000oooooooo
ool0;_ooool000cooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01_ooool2o`0000;ooooo00?o0000ooooooooool0EOooool2ojNojP_oYkkZ3OnW`N`2ojO0
j`ooYl7/3OnW`>`00onW_n[oYko[ojNoj`06ojNoj`KoYl3/00?oYkkZojNojonW_n/01_nW_n/6ojK0
k003ojNnj_nW_n_oYko[00OoYko[1?nV`>`4ojNoj`SoY/3/0_nW`N`2ojK0k0?o00002?nW`N`2ojW0
j`GoZ<7/1OnY`>X01Ol0003oZL3ZojW0j_nY`>[oYko[00OoZ;oZ1_nW_n/00onX_n_oYko[ojNoj`06
ojNojaKooooo00?o0000ooooooooool0;_ooool000Cooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^
00Cooooo00Go410@oooooooooooooooooa0@4005ooooo`;o00001?ooool00ol0003oooooooooo`1A
ooooo`KoYkoZ2OnW_^XLojO1k0;oYl3[3?nW`>`4ojNojPSoYko[0_nW`>`5ojNnjPSoYko[0_nV`>`5
ojNnjPWoYko[00?oY/3/ojNojonW_n/01OnW_n/6ojK0k003ojNojonV`>co000000;o00001?nV`>`6
ojO1k003ojK0k?nX`NcoZ<7/00KoZ<7/1OnY`>X00ol0003oZ<7[ojS1j`09ojRojP;oYko[1OnX_n/8
ojNojaKooooo00?o0000ooooooooool0;Oooool000kooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0
003ooooooooooooooooo000000Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1=
ooooo`[oYkoZ1_nW_^X2ojO0k1WoYl7/1_nW`>/9ojO0k0OoYkoZ1_nW_n/00onX_^WoYkkZojNnjP06
ojNnjPKoYko[00?oZ;kYojNnj_nW_^X01_nW_^X6ojNoj`;oYkkZ2OnW_n/2ojK0k0?oYko[0_l00008
ojK0k0;oYl7/1OnV`>`8ojS1k0;oZL3Z0_nX`N/01?l0003oZ<7[ojS1jonX`N/7ojRojP03ojW0jonX
_n_oZ;o[00KoZ;o[1onW_n/Gooooo`03o`000?oooooooooo02cooooo000?ooooo`03ogMgMomVIVKo
oooo00;ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0BOooool>ojNojP;oYkkZ1_nW`>`EojO1k0[oYl3[1_nW`>`00onW_^[oYkoZojNo
jP07ojNojP;oYko[1OnX_^T8ojNnjP;oYko[1OnX_^T8ojNnjP;oYko[1_nW_^X7ojNoj`03ojRnj_nW
_n_oYko[00?o00000onW_n/6ojK0k003ojNojonV`>coY/3/00KoY/3/1_nX`N`00onV`>coZ<7[ojS1
j`03ojS1j`03o`000?nX`N_oZ<7[00CoZ;oZ1OnY`>/8ojRoj`OoYko[5Oooool2o`0002kooooo000@
ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`03ooooo`;o00001ooo
ool00ol0003oooooooooo`16ooooo`03ojNojonW_n[oYkoZ00coYkoZ00?oYl3[ojO0k?nW`>`01onW
`>`AojO1k0koYl3[0_nW`>`5ojNnjPOoYkoZ2OnX_^T6ojNnjP03ojVoj_nX_^WoZ;kY00KoZ;kY1_nW
_^X2ojVoj@SoYkkZ1?nW_n/2ojRnjP?o00001onW_n/2ojK0k0GoYko[2?nV`>`2ojS1k0GoY/3/1OnX
`N/01?l0003oZ<7[ojS1jonX_nX8ojW0j`KoZ;o[00?oZ<3[ojNojonW_n/01_nW_n/Fooooo`03o`00
0?oooooooooo02_ooooo000<ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`12ooooo`Go
Yko[2_nW_nX5ojO0j`OoYl3/3onW`N`2ojNoj`koYl3[00?oYkkYojNnj_nW_^X01_nW_^X4ojNojPco
Z;kY0_nW_^X5ojVojPSoZ;kY0_nW_^X6ojVoj@SoYkkZ00?oYko[ojRnj_l000000_l00003ojRnjPKo
Yko[00?oZ;kZojNojonW_n/01_nW_n/6ojK0k003ojJok?nV`>coY/3/00KoY/3/1OnX`N/00ol0003o
Yl7/ojW0j`09ojW0j`;oZ;o[1OnX`>/8ojNojaGooooo00?o0000ooooooooool0:oooool000cooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo03kooooo2OnW_n/6ojNojP;oYko[1onW`>/4ojO0
k0koYl7/1_nW_n/:ojO0j`GoYkkY2?nW_^X00onW_n[oZ;kYojRnj@0;ojRnj@03ojS1jonY_n[oZKoZ
00KoZKoZ1_nX_^T2ojW1j`SoZKoY1_nW_^X3o`0000OoZ;kZ0_nW_n/5ojRnjPSoYko[0_nV`>`5ojJo
k0SoY/3/0_nX`N/2ojO1k003o`000?nW`NcoYl7/00SoZL3[00?oZ<7[ojS0jonX`>/01OnX`>/8ojNo
jaKooooo00?o0000ooooooooool0:_ooool001kooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0jooooo`goYko[0_nW_nX6ojNoj`OoYl3[00?oYl3/ojO1k?nW`N`03?nW`N`9ojNoj`Ko
Yl3[2OnW_^T6ojNnjP03ojRojonX_^WoZ;kY00WoZ;kY1OnX`N/8ojVojP;oZ;kY1_nY`N/8ojVoj@;o
YkkZ0ol00002ojVojPOoZ;kZ00?oZL3ZojRnj_nX_^X01_nX_^X6ojNoj`03ojNoj_nV_ncoY[o/00Ko
Y[o/1_nV`>`00onV_ncoYl7/ojO1k003ojO1k003o`000?nW`NcoYl7/00CoZL3[1OnX`N/7ojS0j`So
Yko[5_ooool00ol0003oooooooooo`0Yooooo`007Oooool3o`0000_ooooo00?o0000ooooooooool0
=_ooool2ojO0jaOoYko[1OnW`>/3ojS1k0[oYl7/3OnW_n/2ojO0j`goYkkY0_nW_^X5ojRoj`OoZ;kY
0_nX`N`7ojS1j`KoZKoZ0_nW`N`8ojW1j`KoZKoY0ol00006ojVojPCoZ;kZ1?nY`>X8ojRnjP;oYko[
1OnW_nX8ojJok0;oY/3/1OnV_n`5ojO1k004o`000?nW`NcoYl7/ojW0j`OoZ<7[1_nX`>/00onY`>_o
Yko[ojNoj`06ojNojaKooooo00?o0000ooooooooool0:Oooool001gooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0booooo`KoYl3[5onW_n/00onW`>_oZ<7/ojS1k005ojS1k0KoYl7/
00?oYl3[ojNojonW_n/03?nW_n/?ojNnj@03ojS0jonX_n_oZ;o[00KoZ;o[1?nX_^T5ojS1k0OoZ<7[
0_nY_nX6ojO1k0SoZL7[0_nY_nT3o`0000;oZL;/2?nY_nX00onX_^[oZL3ZojW0jP05ojW0jPKoZ;kZ
00?oZKoYojNoj_nW_nX01_nW_nX6ojJok003ojNojonV_ncoY[o/00KoY[o/1OnW`N`00ol0003oY/3/
ojK0k008ojS1j`;oZ<3[1OnY`>/8ojNojaKooooo00?o0000ooooooooool0:?ooool001gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0_ooooo`03ojS0jonW`>_oYl3[00KoYl3[1_nW
_n/00onW_^_oYko[ojNoj`0<ojNoj`[oZ<7/0_nW`N`5ojO0j`[oYko[3onW_^T5ojS0j`SoZ;o[00?o
Z;kYojS1k?nX`N`01_nX`N`5ojS1j`;oY[k[2?nW`N`6ojW1j`?o00001_nY`^`6ojVojP;oZ<7/2?nY
`>X2ojRnjPGoZKoY2?nW_nX2ojJok0GoYko[2?nV_n`2ojO1k0;oY/3/00Co0000ojK0k?nV`>coY/3/
1_nX`N/00onW`>coZL3[ojW0j`06ojW0j`KoYko[00?oZ<3[ooooooooool05Oooool00ol0003ooooo
ooooo`0Wooooo`007Oooool2o`0000oooooo00?o0000ooooooooool0:oooool5ojS0j`SoYl3[0_nW
_n/5ojNnj`[oYko[3?nX`N`9ojO0j`KoYko[3onW_^T2ojS1k0OoZ<3[1_nX_n/3ojO0k0SoZ<7/00?o
Z<7[ojJnjonV_^/01?nV_^/8ojO1k0;oZL7[00?oY[o[o`000?l000000_nV_n/8ojW2k0;oZKoZ1_nX
`N`6ojW0jP03ojS2k?nY_nWoZKoY00KoZKoY1_nW_nX00onY_n[oYko[ojNoj`06ojNoj`KoY[o/0_nV
_n/4ojK0k004o`000?nV`>coY/3/ojK0k0;oZ<7[1OnW`>`8ojW0j`;oYko[1OnX`>/Fooooo`03o`00
0?oooooooooo02Oooooo000Mooooo`03o`000?oooooooooo00oooooo0_l0000Xooooo`;oZ<7[1onX
`>/6ojO0j`;oYkkZ1onW_^/6ojNoj`coZ<7/3OnW`>/2ojNoj`ooYkkY1_nX`N`7ojS0j`;oZ;o[1onW
`>`6ojS1k003ojNkj?nV_^_oY[k[00KoY[k[1_nW`N`01?nW^nSo0000o`000?l00005ojJoj`KoZL;/
0_nV_^/8ojS1k0;oZL3Z1OnX`^`8ojVoj@;oYkoZ1OnY_nX8ojNoj`;oY[o/1_nV_n/4ojK0k003o`00
0?nV`>coY[o/00SoYl3/1_nY`>/00onY`N_oZ<3[ojS0j`06ojS0jaKooooo00?o0000ooooooooool0
9_ooool001gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Rooooo`KoZ<7[1onX
`>/2ojO0j`KoYkkZ1onW_^/2ojNoj`coZ<7/0_nX`>/=ojO0j`ooYkkY0_nW`N`8ojS1k0GoZ<3[0onW
_^/8ojO0k0;oZ<7/1OnW^nP8ojJnj`;oYl7/00GoYk_Xo`000?l0003o0000ojNkj008ojJoj`;oZL;/
1_nV_^/6ojS1k003ojJnjonX`^coZ<;/00KoZ<;/1_nY_nT00onY`^_oZKoZojVojP06ojVojPKoYko[
0_nX_nX8ojJoj`;oY/3/0_nV_n`00ol0003oY[o/ojJok008ojO0k0;oZL3[1OnY`N/8ojS0jaKooooo
00?o0000ooooooooool09Oooool001gooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0Nooooo`;oZ<7/2?nX`N/5ojS0j`;oYko[2?nW_^X5ojNnj`;oYl7/2_nX`N`6ojS0j`WoYl3[3onW
_^T6ojO1k0SoZ<7/00?oZ<3[ojNnjonW_^/01OnW_^/6ojO0k003ojNhiOnW^nSoYk_X00KoYk_X1_nV
_^/01?nX]n?o0000o`000?l00005ojNkj0KoY[o[00?oZ;[VojJnjonV_^/01onV_^/2ojS1k0GoY[k[
2?nX`^`2ojVoj@GoZL;[2?nY_nX2ojNoj`KoZ;oZ1_nV_n/00onW_n_oY[o/ojJok002ojJok004o`00
0?nV_ncoY[o/ojJok0KoYl3/00?oY/3/ojW1jonY`N/01_nY`N/7ojS0jaKooooo0_l0000Vooooo`00
7?ooool3o`0001Cooooo00?o0000ooooooooool06_ooool6ojS1k0SoZ<7[00?oZ<3[ojNojonW_n/0
1?nW_n/8ojNnjP03ojNnjonW`NcoYl7/00CoYl7/2?nX`N`8ojS0j`KoYl3[00?oYkkZojNnjOnW_^T0
3?nW_^T9ojO1k0KoZ<7/0_nW_NT8ojNnj`;oYl3/1OnW^>D8ojNkj0;oY[k[00GoZ;OSo`000?l0003o
0000ojRgh`08ojNkj0;oY[o[1OnX^^H7ojJnj`03ojViiOnV_^_oY[k[00KoY[k[1_nX`^`00onV_^_o
ZL;[ojW2j`06ojW2j`KoZKoZ00?oZ/7ZojRoj_nX_nX01onX_nX2ojJoj`GoYko[1?nV_n`01?l0003o
Y[o/ojJok?nV_n`2ojO0k0GoY/3/2?nY`N/7ojS0jaCooooo00?o0000ooooool000009_ooool001co
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Gooooo`WoZ<7/1_nX`N/9ojNoj`Ko
YkkZ00?oYl3[ojO1k?nW`N`01_nW`N`8ojS1k0SoZ<3[0_nW`>/5ojNnjP[oYkkY3OnW`N`2ojS1k0Ko
YkgY1_nW_^/00onX]N?oYkSUojNhi@06ojNhi@KoYk_X00CoZK3Mo`000?l0003o00001OnX]n<6ojNk
j003ojZcgonX^^KoZ;[V00KoZ;[V1?nV_^/4ojVii@SoY[k[0_nX`^`5ojJnj`SoZL;[0_nY_nX5oj[1
jPOoZ;oZ00?oZKoZojNojonW_n/01_nW_n/4ojJok003o`000?nV_ncoY[o/00SoY/3/1_nY`N/00onX
`N_oZ<3[ojS0j`06ojS0jaKooooo00?o0000ooooooooool08oooool000[ooooo1?l000002?l@413o
ooooooooooo^k^ko<S8bo`000?lb<S;ok^k^1_ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo01Cooooo3?nX`N`2ojS1j`goYko[0_nW_^X5ojO0j`SoYl7/2?nX`N`6ojS0j`WoYkkZ1_nW
_^T?ojO1k0[oYkgY0_nW_^/5ojReh`SoYkSU0_nW^nP01OnY/=go0000o`000?l0003oZK3M00SoZ;OS
0_nW^nP5ojZcg`SoZ;[V00?oY[k[ojViiOnY^ND01OnY^ND6ojJnj`03ojVji_nV_^_oY[k[00KoY[k[
1_nY`^/00onW`>coZ/7Zoj[1jP06oj[1jPCoZ;oZ1?nY_nX8ojNoj`?oY[o/00Co0000ojJok?nV_nco
Y[o/2?nV`>`2ojW1j`GoZ<7[2?nX`>/Eooooo`03o`000?oooooooooo02?ooooo000<ooooo`03o`00
0?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool04Oooool=ojS1k0;oZ<3[3onW_n/7ojO0j`KoYl7/2_nX`N`2ojS0j`go
YkkZ0_nW_^T?ojO1k0coYkgY00?oYk;PojRehonX]N<01_nX]N<6ojNhi@04ojVZf?l0003o0000o`00
00GoZK3M1_nX]n<00on[ZmKoZ[?OojZcg`06ojZcg`KoZ;[V00?o[;7LojViiOnY^ND01onY^ND2ojJn
j`GoZK[V2?nV_^/2ojW2j`GoYl3/2?nZ`NX00onX_n[oZKoZojVojP05ojVojPKoYko[00?oZ;o[ojJo
k?nV_n`00_nV_n`01?l0003oY[o/ojJok?nV_n`6ojK0k003ojJok?nX`N_oZ<7[00GoZ<7[1_nX`>/2
ojW0jaKooooo00?o0000ooooooooool08_ooool00003ooooool0003o000000Co00001Oooool00ol0
003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool2o`0001Wooooo00?o0000
ooooooooool03_ooool3ojO0j`WoZ<7/1_nX`>/?ojNoj`OoYl3[0_nW`N`<ojS1k0;oYkoZ3OnW_^X2
ojO0k0goYl7/3OnW_NT4ojNbh0OoZ;GS1?nW^>D01?nYZ]So0000o`000?nYZ]P7ojV`g@CoZ;OS1?n[
ZmH8ojZcg`;oZ;[V1On//M`7ojVii@03ojfbg?nY^^KoZK[V00KoZK[V1_nV_^/00onX_>SoYl3/ojO0
k006ojO0k0KoZ/7Z0_nX`N/8ojVojP;oYko[1OnX_n/4ojJok004o`000?nV_ncoY[o/ojJok0;oY/3/
1OnV_n`7ojS1j`;oZ<3[1_nY`>/Fooooo`03o`000?oooooooooo027ooooo000<ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool02_ooool7ojO0j`KoZ<7/00?oZ<7[ojS0jonX`>/01_nX`>/5ojNoj`;oYkk[
2?nW_n/5ojO0j`coZ<7/1_nW_nX9ojNnjPKoYl3/2OnW`N`>ojNmj@OoYk;P1onX]N<01?nW^>Go0000
o`000?l00004ojVZf0OoZK3M00?oZ;OSoj^[e_n[ZmH01On[ZmH6ojZcg`03ojn/e?n//Mco[;7L00Ko
[;7L1?nY^ND4ojfbg0SoZK[V0_nV_^/5ojRlj0SoYl3/0_nZ`NX6ojS1j`KoZKoZ00?oZ/7ZojRojonX
_n/01OnX_n/5ojJok003o`000?nW_n_oYko[00OoY[o/1_nX`N/2ojS0j`SoZL3[5Oooool00ol0003o
ooooooooo`0Qooooo`003?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
00001Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Oooooo0onW_n/7ojO0j`;o
Z<7/1OnX`N/8ojS0j`03ojNojonW_^_oYkk[00CoYkk[2?nW_n/00onW`>_oZ<7/ojS1k00;ojS1k003
ojNojonW_n[oYkoZ00KoYkoZ1OnW_^X2ojNoj`SoYl3/1OnW`N`2ojNnj@goYkgY00?oYk3OojNbh?nW
/^001_nW/^05ojReh`?o00001onYZ]P6ojV`g@03ojjYd_n[ZmKoZj_F00KoZj_F1?nZ/ml4ojn/e0So
[;7L00?oZKWUojfbg?n]/]`01On]/]`6ojVjiP03ojffgonX_>SoZ;cX00KoZ;cX1_nW`>`2ojJnjPSo
Z<7[0_nY_nX5oj[1jPOoZ;o[0_nV_n`2ojNoj`04o`000?nW_n_oYko[ojNoj`OoY[o/0_nX`N/6ojS0
j`OoZL3[5_ooool00ol0003oooooooooo`0Pooooo`003?ooool00ol0003oooooooooo`02ooooo`05
oa0@4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
00?ooooo1onW_n/5ojO0j`;oZ<7/1onX`N/6ojS0j`;oYko[1onW_^/6ojNoj`coZ<7/1OnW_n/8ojNo
jP03ojNnj_nW_n_oYko[00CoYko[2?nW`>`00onW`NcoYkkYojNnj@04ojNnj@WoYkgY1OnW/=l8ojNb
h004ojRehol0003o0000o`0000?oZ:KD2?nYZ]P2ojV`g@Go[ZWB2?n[ZmH00onZ/moo[jcDojn/e005
ojn/e0Ko[;7L00?o/joDojfbg?n]/]`01on]/]`2ojVjiPGo[KKO2?nX_>P2ojO0k0KoY[kZ1_nX`N/0
0onW`>coZ/7Zoj[1jP05oj[1jPKoZ;o[00?oZL3ZojNojonW_n/00onW_n/00ol0003oYko[ojNoj`08
ojJok0SoZ<3[1onY`>/Fooooo`03o`000?oooooooooo01oooooo000<ooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o00007_ooool00ol0003oooooojNoj`0:
ojNoj`03ojO0jonX`NcoZ<7/00CoZ<7/1onX`N/2ojS0j`KoYko[1onW_^/2ojNoj`coZ<7/0_nX`>/7
ojNoj`KoYkoZ00?oYkkZojNojonW_n/01_nW_n/6ojO0k003ojRoj_nW_^WoYkkY00KoYkkY1OnW_NT2
ojJ`g`OoYk3O1OnW/^03o`0000OoZ:KD1_nYZ]P9ojjYdPKoZj_F00?o/jgBojn/e?n_[=@01_n_[=@4
ojbag0Co/joD1on]/]`00one/]Ko[KKOojffg`06ojffg`KoZ;cX0_n/^n@8ojJnjP;oZ<7[1OnW`>`7
oj[1jP;oZ;o[1OnY`>X5ojNoj`03o`000?nW_n_oYko[00SoY[o/1_nX`>/00onW`>_oZL3[ojW0j`06
ojW0jaGooooo00?o0000ooooooooool07oooool000[ooooo00?oEEEEofIVI_l000001?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool07?ooool=ojNoj`;oZ<3[1onX`N`5
ojS1j`;oYl3[2?nW_n/5ojNnj`?oYl3[2OnX`N`6ojS0j`OoYko[0_nW_nX5ojNnjPSoYko[0_nW`>`5
ojRojPSoYkkY00?oYkgYojJ`gonV/=l01?nV/=l7ojN`g`04ojNbh?l0003o0000o`0000?oZ:GC1onX
Y]@4ojVZf0_o[ZWB1?n[ZmH4ok>]dPSo[jcD00?o[;7Lok>_e?nc[m@01Onc[m@5ojfbg0?o]K;F2?n]
]]l2ojRlj0Ko[;_T1_nV_^X00onY_NSoYl3/ojO0k005ojO0k0KoZ/7Z00?oZL7[ojW0j_nY`>X01_nY
`>X5ojNoj`03o`000?nW_n_oYko[00SoY[o/0_nX`>/5ojO0j`SoZL3[5Oooool00ol0003ooooooooo
o`0Nooooo`006oooool00ol0003oooooooooo`0Iooooo`goYko[1_nX`>/7ojS1k003ojS1jonW`>_o
Yl3[00CoYl3[2?nW_n/00onW_^_oYl3[ojO0j`05ojO0j`OoZ<7/2?nX`>/5ojNoj`;oY[gZ1onW_^X6
ojNoj`;oZ<3[1onX_nX6ojNnj@03ojJbhOnV/=ooY[3O00KoY[3O1?nW/=l3o`0000KoZ:GC2?nXY]@0
0onYZ]So[ZWBojjYdP0<ojjYdP03oj^[e_nc[M;o/jgB00Go/jgB1_n_[=@00onh/]Co/joDok>_e006
ok>_e0?o[K;L1_ne/]H6ojffg`03okBdfOn/^nCo[;_T00Oo[;_T0_nV_^X5ojVmj0OoYl3/0_nZ`NX5
ojW1j`SoZL3Z1?nW_n/01?l0003oYko[ojNojonW_n/7ojJok0SoYl3[1_nY`>/00onY`N_ooooooooo
o`0Dooooo`03o`000?oooooooooo01gooooo000Kooooo`03o`000?oooooooooo01Gooooo0_nX`>/>
ojNoj`SoZ<3[1OnX`N`2ojS0j`OoYl3[2?nW_n/8ojO0j`OoZ<7/2?nX`>/00onW_n_oY[gZojJmjP04
ojJmjPOoYkkZ0_nW_n/6ojS0j`OoZ;oZ0_nW_^T5ojJbh@SoY[3O0ol00003ojJTd`OoZ:GC1_nXY]@0
0on]Z]Co[ZWBojjYdP0<ojjYdP03ok>ae_nc[M;o/jgB00Ko/jgB1?n_[=@4okRbe0So/joD00?o[K;L
okFbe_ne/]H01One/]H4ojffg`Co];CI1on/^n@00on`^=ooZKgXojVmj005ojVmj0KoYl3/00?oY[o[
ojW1jonY`N/01_nY`N/8ojW0jPCoYko[00Co0000ojNojonW_n_oYko[1onV_n`8ojO0j`;oZL3[1OnY
`N/Dooooo`;o00007oooool001_ooooo0_l0000Cooooo`KoZ<3[3_nW_n/8ojS0j`03ojS1k?nX`>_o
Z<3[00CoZ<3[1onW`>/8ojNoj`KoYl3[2OnX`N`6ojS0j`03ojNnj_nV_N[oY[gZ00KoY[gZ1OnW_^X3
ojS1k0OoZ<3[0onX_nX3ojJdh`SoY[;Q1OnV/=l2o`0000OoYZCC1_nXYM<4ojRVe0Co[J[D2on^ZM84
ok>aePSo/jgB00?o[jcDokRbe?nh/]@01Onh/]@6ok>_e003ok^fe?ne/]Ko]K;F00Oo]K;F00?o[KKO
okBdfOnd]=T01Ond]=T4ojbki0Co/;SO1onY_NP2ojO0k0GoY[o[2?nY`N/8ojW0jPCoYko[00?o0000
ojNojonW`>/02?nV_n`7ojO0j`OoZL7[5_ooool00ol0003oooooooooo`0Looooo`006_ooool00ol0
003oooooooooo`0@ooooo`;oZ<7[2?nX`>/>ojNoj`KoZ<3[0_nX`N/7ojS0j`GoYl3[0onV_^/7ojNo
j`;oYl3[3OnX`N`2ojS0j`GoYkkZ2?nV_NX00onW_^[oZ<7/ojS1k005ojS1k0GoZ<3[00?oY[SVojJd
honV]><01OnV]><8ojJbh@04ojJ`gol0003o0000o`0000?oY:?D1_nVY=<7ojRUd`03ojRVe?n]Z]Co
[J[D00Co[J[D2On^ZM87ok>aePKo/jgB00?o]kWKokRbe?nh/]@01_nh/]@4ok>_e0Co^kKD1one/]H0
0onm^=Co];CIokBdf@07okBdf@03ojbki?n`^=oo/;SO00Co/;SO1_nY_NP00on/_NKoY[o[ojJoj`06
ojJoj`KoZL7[0_nX`N/8ojW0jP;oYko[0_nW`>/00ol0003oYl3[ojO0j`08ojJok0OoYl3[1onY`N/E
ooooo`03o`000?oooooooooo01cooooo000Jooooo`03o`000?oooooooooo00gooooo1_nX`N/8ojS0
j`koYko[0_nX`>/6ojS1j`OoZ<3[00?oYl3[ojJnjonV_^/01OnV_^/5ojNoj`ooZ<7/0_nW_n/7ojNn
jPKoY[gZ0_nW`N`8ojS1k003ojS0jonV^>KoY[SV00?oY[SV1onV]><5ojJbh@?o00001_nTXm@7ojJT
d`GoZ:GC00?oZj_GojfZe?n]Z]@01_n]Z]@6ojjYdP03ok:ggOnc/MKo/k7F00Ko/k7F1?nc[M84okNi
f`So^;;D00?o/joDok^fe?nk]]@01Onk]]@5okFbeP?o_KSD1ond]=T00onm^MKo/;SOok2hg`06ok2h
g`;oZKgX1On/_NH8ojJoj`;oZL7[1_nX`N/6ojW0jP03oj[1j_nW`>_oYl3[00;oYl3[00?o0000ojO0
jonW`>/02?nV_n`7ojO0j`SoZL7[5Oooool00ol0003oooooooooo`0Kooooo`006_ooool00ol0003o
ooooooooo`0;ooooo`;oZ<3[1onX`N/6ojS0j`koYko[2_nX`N/3ojS0j`GoYko[1onV_^/00onW_n_o
Z<7/ojS1k00=ojS1k0KoYko[1onW_^X2ojJmjPKoYl7/1_nX`N`00onW^nSoY[SVojJhiP05ojJhiPOo
Y[CS00CoY[;Qo`000?l0003o00000onRX]D7ojBSe0OoYZCC00?oZ:GCoj^[eon[ZmL00on[ZmL7ojfZ
e0Co[ZWB1?nb]md8ok>aeP03ok>]d_ng^M_o]kWK00Go]kWK1_nh/]@00onj_]go^kKDok^fe006ok^f
e0?o]K;F1_nm^=@5okBdf@?o_KWF1_n`^=l00ong^]_o[;gVojbmiP06ojbmiPKoY[o[0_nW_n/8ojS1
j`;oZL3Z1OnZ`NX4ojO0j`03o`000?nW`>_oYl3[00SoY[o/1onW`>/8ojW1jaGooooo00?o0000oooo
ooooool01_ooool5o`0000oooooo000Jooooo`;o00002Oooool6ojS0j`OoZ<7[0_nX`>/>ojNoj`co
Z<7[0_nW`>/8ojNoj`GoY[k[0_nW_n/=ojS1k0;oZ<3[1onW_n/5ojNnjP?oY[k[1onW`N`2ojS1k0Go
Yk_X1onV^>H4ojJdh`?o00001_nRX]D7ojBSe0KoYZCC00?oZ:cIoj^[eon[ZmL01On[ZmL7ojfZe003
ojjYd_nb]mgo/[OM00Go/[OM1_nc/MH00ondbn_o]kWKokNif`06okNif`Co^;;D1?nj_]d8ok^fe003
okFbe_nm^=Co_KSD00Go_KSD0ond]=T6okfieP?o/;SO1?ng^]/8ojbmiP;oY[o[1_nW_n/6ojS1j`03
ojO0jonZ`N[oZ/7Z00GoZ/7Z1OnW`>/00ol0003oYl3[ojO0j`07ojJok0KoYl3[0_nW_n/8ojW1jaCo
oooo00?o0000ooooooooool01_ooool01OnHV9So8B4Qonk^k_ooooooA4A400oooooo000Jooooo`03
o`000?oooooooooo00Kooooo0_nW_n/7ojS0j`GoZ<7[0_nW`>/@ojNoj`SoZ<7[1_nW`>/8ojNoj`03
ojJnjonW_n_oYko[00CoYko[2OnX`N`6ojS0j`OoYko[00?oYkkZojJnjonV_^/01OnV_^/5ojO1k0;o
Z;oZ1onW^nP7ojJhiP?o00000onPXmL7oj:Re@OoY:?D0_nVY=<5ojR/f@OoZj_G1On]Z]@2ojo2j0Oo
/[OM1?nc/MH4okC;j`So]kWK00?o^;;DokZngOnj_]d01Onj_]d6ok^fe003okbog?nm^=Co_KSD00Oo
_KSD00?o];CIokfie_nm^MH01_nm^MH00on`^=oo]k[KokNjf`04okNjf`Ko[;gV0_n`_nD8ojNoj`;o
Z<7[1OnW`>/7oj[1jPCoYl3[00Co0000ojO0jonW`>_oYl3[1onV_n`2ojO0j`KoYko[1onY`N/Eoooo
o`03o`000?oooooooooo00Kooooo00?oV9RHob4Q8Oo^k^h04?ooool001[ooooo00?o0000oooooooo
ool00oooool6ojNoj`OoZ<3[00?oZ<7[ojO0jonW`>/01?nW`>/@ojNoj`OoZ<7[1onW`>/6ojNoj`03
ojJnjonW_n_oYko[00KoYko[2?nX`N`7ojS0j`?oYko[1?nV_NX8ojJnj`03ojO1k?nX_n[oZ;oZ00Co
Z;oZ1_nW^nP4ojJhiP?o00001onPXmL6oj:Re@KoY:?D00?oYJ[JojR/fOnX[=T01_nX[=T7oj^[e`03
ojfZe?n_`^So[l;X00Co[l;X1onb]md00onc/MKo]<_[okC;j`05okC;j`Ko]kWK00?o/MOdokZngOnj
_]d01_nj_]d4ok^fe0Co_;oL1onm^=@00ono_]Wo_KWFokfieP06okfieP03ol6neong^]_o]k[K00Ko
]k[K0_n/_NH6ok2oi@KoYko[00?oZKoZojO0jonW`>/01OnW`>/8oj[1jPCoYl3[00Co0000ojO0jonW
`>_oYl3[1onV_n`8ojNoj`OoZL7[5Oooool00ol0003oooooooooo`06ooooo`03oiRHV?lQ8B7ok^k^
00oooooo000Jooooo`03o`000?oooooooooo00[oYko[1OnX`>/2ojS1j`OoYl3[4?nW_n/7ojS1j`Oo
Yl3[0_nW_n/5ojJnj`SoYko[2?nX`N`5ojS0j`;oYkk[1onV_NX6ojJnj`03ojS1k?nX_n[oZ;oZ00Ko
Z;oZ1_nW^nP3o`0000CoXJOJ1_nPXmL7oj:Re@;oY:?D1OnUZ]X7ojR/f@KoZj_G00?oZlcaojo2j?n_
`^P01_n_`^P5ok:gg@?oY=ok1_ndbn/4okNif`Co/MOd2?nj_]d00onk]]Co_;oLokbog005okbog0Co
_KSD1?no_]T6okfieP?o`KkG1_ng^]/00onn_m[o/;oUok2oi@07ok2oi@;oYko[1OnY_nX7ojO0j`So
Z/7Z1?nW`>/00ol0003oYl3[ojS0j`08ojJok0OoYko[1onY`N/Eooooo`03o`000?oooooooooo00Oo
oooo00?oMgMgofIVI_ooool03_ooool001Wooooo00?o0000ojNojonW_n/03?nW_n/00onX`>_oZ<7[
ojS1j`04ojS1j`OoYl3[3_nW_n/9ojS1j`GoYl3[0_nW_n/7ojJnj`KoYko[2_nX`N`00onX`>_oYkk[
ojNnj`04ojNnj`OoY[gZ0_nV_^/5ojS1k0SoZ;oZ0_nW^nP3o`0000SoXJOJ1_nPXmL5oj:Re@03oj:X
f_nUZ][oYJ[J00KoYJ[J1onX[=T2oj^[e`GoZlca2?n_`^P00onb]mgoY=okojCOn`05ojCOn`Ko]<_[
00?o]kWKok7Gm?naeo@01Onaeo@6okZng@03ok7Gm?nl_mco_;oL00Oo_;oL00?o_KSDoknnfOno_]T0
1Ono_]T3okfiePGo`KkG1Ong^]/3okjofPOo/;oU00?o/l3SojVoj_nY_nX01_nY_nX5ojO0j`;oY[o/
2?nZ`NX2ojO0j`;oZ<3[00?o0000ojS0jonX`>/02?nV_n`7ojNoj`OoZL7[5Oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00gooooo000Iooooo`03o`000?nW_n_oYko[00_oYko[0onX
`>/6ojS1j`GoYl3[3?nW_n/=ojS1j`03ojO0jonW_n_oYko[00CoYko[1onV_^/2ojNoj`coZ<7/00?o
Yl3[ojNnjonW_^/01_nW_^/5ojJmjP;oYl7/1onX`N`6ojRojP03oj>eiOl0003o000000CoXZgO1onQ
YmX7oj2Se`03oj:ReOnRZ=[oXZSJ00?oXZSJ1onUZ]X6ojR/f@;oYm;f1on[c?46ojo2j0?oPMoj1onT
go/3okC;j`CoOM_l1_naeo@4okZng@Co/MOd1onl_m`00ongcnco_kkIoknnf@07oknnf@03okfie_o1
_]Oo`KkG00Co`KkG0ong^]/6okjofPCo/;oU1?nc`><8ojVojP03ojO0jonV_ncoY[o/00CoY[o/1onZ
`NX4ojS0j`04o`000?nX`>_oZ<3[ojS0j`OoY[o/1onW_n/8ojW1ja?ooooo0ol00004ooooo`05o`00
0?nj^[[ooooooiRHV?l@41003oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03
o`000?ooooooYko[00SoYko[1onX`>/6ojS1j`03ojO0jonW_n_oYko[00coYko[3OnX`N/2ojO0j`Oo
Yko[1OnV_^/3ojO0j`WoZ<7/1OnW`>/8ojNnj`03ojJmj_nW`NcoYl7/00CoYl7/1onX`N`2ojRojP05
oj>eiOl0003o0000o`000?nS]ND01_nR[Ml7oj6WfP?oX:?G0onNY=T7oj:XfPOoYJ[J0_nX[=T6ojOB
mPOoZlca0_n_`^P7oh7OnP?oY=ok1Om4`n<6oggKo0Ko/MOd00?o^[kMok7Gm?naeo@01Onaeo@4okbo
g0Co]lo/1ono_]T00onma>3o`KkGol6ne`06ol6ne`03okNjfonn_m[o_[oJ00Ko_[oJ00?o/;oUok?0
honc`><01Onc`><6ojVojP03oj[0j_nV_ncoY[o/00KoY[o/1onZ`NX4ojS0j`04o`000?nX`>_oZ<3[
ojS0j`OoY[o/1onW_n/8ojW1jaCooooo00?o0000ooooooooool00_ooool01OnHV9So410@o`000?lQ
8B7oc<c<00oooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003ooooooooo
o`08ojNoj`SoZ<3[0onX`N/4ojO0j`koYko[2OnX`N/6ojO0j`OoYko[00?oY[k[ojO0jonW`>/01OnW
`>/5ojS1k0;oZ<7[1onW`>/6ojNnj`03ojJnjonW`NcoYl7/00KoYl7/1OnX`N`01?nV^nSo0000o`00
0?l00005oj>ei@KoXZgO1OnQYmX00onKXMSoWZCIoijTf@05oijTf@OoXZSJ1OnUZ]X3ojGAm`OoYm;f
0on[c?46ofgKl0?oPMoj1_ld^]@6odC3h`?oOM_l1?lV[]/6ofO?n`Oo/MOd00?o_;oLokO?k?ngcn`0
1Ongcn`5oknnf@?o_LCP1_o1_]L00oo2`]Wo_[oJokjofP06okjofP03ol?3f_nc`>?o/l3S00Oo/l3S
0_nY_nX5oj[0jPOoY[o/2?nZ`NX4ojS0j`03o`000?nX`>_oZ<3[00OoY[o/2?nW_n/8ojW1jaCooooo
00?o0000ooooooooool05Oooool000kooooo00Go410@oooooooooooooooooa0@4006ooooo`;o0000
0_ooool8ojNoj`KoZ<3[0_nX`N/7ojO0j`koYko[2?nX`N/7ojO0j`GoYko[0onV_^/7ojO0j`03ojS1
k?nX`N_oZ<7[00CoZ<7[1onW`>/2ojNnj`GoY[k[2?nW`N`00onX`NcoY[_Xo`000002o`0000;oY[_X
1_nS]ND7oj:]g`03oj6Wf_nKXMSoVj7H00?oVj7H1onNY=T7oj:XfP03ojFZf_nUdOOoYM7g00GoYM7g
1OnWd_H4ofkMk0?oKM_`1?m1`mP5ohG=o`?oF/Gj1?nH__87ofZgo0;o8jCX00?o9ZkKofO?nomWco/0
1?mWco/3ok7Gm0CoMLko1ongcn`3oknnf@Ko_LCP1?o1_]L3ol;2f@Ko_[oJ0oo3`mX7ok?0h`03okO3
honZ`>[oZ/3Z00KoZ/3Z1onV_n`8oj[1jPCoZ<3[00?o0000ojS0jonX`>/01onV_n`8ojNoj`OoZL7[
5Oooool00ol0003oooooooooo`0Dooooo`003_ooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool00oooool7ojNoj`;oZ<3[1_nX`N/7ojO0j`koYko[2?nX`N/7ojO0j`03ojNo
jonV_^_oY[k[00GoY[k[1OnW`>/2ojW1k0OoZ<7[1OnW`>/9ojJnj`KoYl7/0ol00006ojJkj0KoXkGU
0onR[Ml3oiROf@KoVj7H1onNY=T6oj:XfP;oY<[d2?nUdOL00onWd_KoK]g/ofkMk003ofkMk0?oFmCR
1OnJcOX5ohG=o`03oj>ij?nH__;oV;kb00KoV;kb1omZ]o`5ob>Tj0Go8ZOS1_mec_l7okO?k003oknn
fOnma>3o_LCP00Go_LCP0oo1_]L5ol;2f@?o_[oJ1_o3`mX4ok?0h`Co]l?S1_nZ`>X00on[`N[oY[o/
ojJok006ojJok0KoZ/7Z00?oZ/7[ojS0jonX`>/00_nX`>/00ol0003oZ<3[ojS0j`08ojJok0SoYko[
1onY`N/Dooooo`03o`000?oooooooooo01Cooooo000>ooooo`05o`000?ooooooooooooooool00000
1Oooool00ol0003oooooooooo`05ooooo`GoYko[0_nX`>/8ojS1j`GoYl3[3_nW_n/:ojS1j`?oYl3[
1?nW_n/8ojJnj`03ojO0jonY`NcoZL7/00CoZL7/1onX`N/00onW`>_oY[k[ojJnj`0;ojJnj`;oYl7/
0ol00003ojRoj`OoY[_X0onS]ND2oiVSg0OoV9oI1_nKXMP7oijTf@;oXZSJ1_nTb_@6ojGAm`?oO>C^
0omeh^T2ojGAm`SoV/gj00?oQLgooj>ij?nS^NP00onS^NP8oiRnlP?oJ[Ol1OnJ^>d6ofF_n@03oaVH
i_lRYn?o8ZOS00KoMLko0ongcn`4oiWAn`So_LCP00?o`KkGol;2fOo2`]T01Oo2`]T00onn_m[o`l?J
ol?3fP06ol?3fP03ok?0hong`n?o]l?S00Go]l?S0_nZ`>X5oj_1jPSoY[o/0_nZ`NX5oj[1j`CoZ<3[
00?o0000ojS0jonX`>/02?nV_n`7ojNoj`OoZL7[5Oooool00ol0003oooooooooo`0Cooooo`003_oo
ool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool01_ooool00onW_n_oZ<3[
ojS0j`04ojS0j`SoZ<7[00?oYl3[ojNojonW_n/03?nW_n/<ojS1j`;oYl3[1onW_n/6ojJnj`03ojS1
jonY`NcoZL7/00KoZL7/1OnX`N/2ojNoj`coY[k[0ol00007ojRoj`?oY[_X0onO[^86oiVSg0OoV9oI
1OnKXMP6oijTf@;oXkk/2?nTb_@2ojGAm`?oO>C^0omeh^T6ojGAm`KoV/gj00?oY[KToj>ij?nS^NP0
1OnS^NP6oiRnlP;oYkCR2?nJ^>d3ofF_n@?oTkS`0om7W_D2oaVHiPCo=jcb1onIdO/6okg4h003okO<
j_o2`]Wo`/;I00Go`/;I00?o`/GMol?3f_o3`mX01_o3`mX2olK7f`Ko]l?S00?o^LKToj_1j_n[`NX0
1_n[`NX6ojJok003ojJojonZ`N_oZ/7[00KoZ/7[0onX`>/01?nW`>_o0000ojO0jonW`>/8ojJok0Oo
Yko[1onY`N/Eooooo`03o`000?oooooooooo01;ooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2o`0000Sooooo1onX`>/6ojS1j`;oYl3[3onW_n/8ojS1j`KoYl3[1onW_n/2ojJnj`Go
Z<7[2?nY`N`00onX`N_oYko[ojNoj`04ojNoj`SoY[k[0ol00004ojW2k0GoZ;o[00?oXkSXoin^h_nO
[^801OnO[^86oiVSg0KoV9oI1_nKXMP2oijTf@KoXkk/1_nTb_@3oi3[m0?oR^c[0on^f_L7ojGAm`;o
V/gj1OnV]^@7oj>ij0;oV;kb1_nW]>86oiZhk@03ojVfh_nC^?3oTkS`00GoTkS`1_m7W_D00olRUnco
=jcbocN/lP07oiWAn`;o_LCP1Ongc>X5ol;2f@?o`/GM1_o3`mX4olK7f`?o]l?S1?nia^@8oj_1jP;o
Y[o/1OnV_n/7oj[1j`CoYl3[00Co0000ojO0jonW`>_oYl3[1onV_n`7ojNoj`OoZL7[5Oooool00ol0
003oooooooooo`0Booooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000oooo
ooooool02?ooool7ojS0j`;oZ<7[1_nW`>/?ojNoj`OoZ<7[1onW`>/5ojNoj`;oY[o[1onX`N/6ojW1
k0;oZ<7[1onW_n/5ojJnj`;o00002?nY`^`00onX_n_oXkSXoj>hj003oj>hj0OoWjkR1OnIXm`7oiRO
f@?oVj7H1?nN/>@7oj>nk0;oY<[d1?n@jo@3oh[/j`Ko[][g1OnUdOL00onW]nCoY[KTojJfi006ojJf
i0GoXkWX00?o[;?NojNdh_nW]>801onW]>82oiZhk@GoZKKR1onC^?06odNNm@?o8YO/0onIdO/3ofZk
o@Oo]lcZ0oo2`]T6ol;5g@?o`l?J1oo6am/00ong`n?o^LKTokW6i004okW6i0KoZl7Z00?oZl;[ojJo
jonV_n/01_nV_n/7oj[1j`CoYl3[00Co0000ojO0jonW`>_oYl3[1onV_n`7ojNoj`OoZL7[5Oooool0
0ol0003oooooooooo`0Aooooo`006?ooool00ol0003oooooooooo`09ooooo`GoZ<3[0onX`N/7ojO0
j`?oYko[1?nV_n/8ojNoj`OoZ<7[1onW`>/00onW_n_oY[o[ojJoj`04ojJoj`OoZ<7[0_nY`N`6ojS1
j`GoYko[0onV_^/3o`0000?oY[k[1_nY`^`00onV_^[oXkSXoj>hj005oj>hj0KoWjkR1_nIXm`3oiRO
f@?oVJKO2?nN/>@5oj>nk0CoXN_j0_n@jo@3oh[/j`So[][g00?oYM7gojNgi?nW]n@00onW]n@8ojJf
i003oj>ij?n//mko[;?N00?o[;?N1onW]>800ona^MooZKKRojVfhP06ojVfhPGoTkS`0_nS^NP6og2/
mP;o:93^0_lRUn`5ofZko@Oo]lcZ00?o`/;Iol;5gOo2aMd01_o2aMd00oo3`m[oa/OKolK7f`05olK7
f`03olO:g?nia^Co^LKT00Ko^LKT0_n[`NX5oj_2j`OoY[o[2?nZ`N/4ojO0j`03o`000?nW`>_oYl3[
00OoY[o/1_nW_n/00onX`>_oZL7[ojW1j`06ojW1jaGooooo00?o0000ooooooooool04?ooool001So
oooo00?o0000ooooooooool02_ooool00onX`>_oZ<7[ojS1j`05ojS1j`GoYl3[0_nW_n/7ojJoj`Ko
Yko[2OnX`N/5ojO0j`WoY[o[1OnX`N/3ojW1j`OoZ<7[00CoYko[ojJnjonV_^_oY[k[0ol00007ojJn
j`;oZL;/1OnV_^X7oj>hj0KoWjkR0onIXm`2oiBPg0OoVJKO2?nN/>@00onS_^coXN_joj7[nP05oj7[
nP?oWO?]0onej?L6ojkJm`03ojRkionW]nCoYkOT00GoYkOT1_nV]^@00onZ/moo[;?NojbcgP05ojbc
gPCoYkCR1?na^Ml8ojVfhP03oi>hl?nS^NSoXkWX00CoXkWX1_m`[?H4obR@kPGoJ[_m1Ongc>X2ojS9
l@Oo`/GM0_o0aml6olK7f`?oal[L1_nia^@2okW9iPOoZl;[1onV_n/8oj[1j`CoYl3[00?o0000ojO0
jonW`>/01onV_n`2ojNoj`GoZ<3[1_nY`N/00onX`N_oooooooooo`0Cooooo`;o00004Oooool001Oo
oooo0ol0000=ooooo`OoZ<7[00?oYl3[ojNojonW_n/01?nW_n/7ojJoj`;oYko[3OnX`N/00onW`>_o
Y[o[ojJoj`0;ojJoj`03ojS1jonY`N_oZL7[00GoZL7[1OnX`N/2ojNoj`?o00002OnV_^/3ojW2k0Ko
Y[kZ1onS^>P3oin^hP;oTIkM1_nDX=`7oiVVg`KoW[3T1?nYhOX2oj7[nP?oWO?]1onej?L2ojkJm`Go
Z;_W1onW]n@2ojJfi0GoZ[?O1on//mh00onW]>;o/KWOok6ig`05ok6ig`KoZKKR0_nc_>07oj>ij0Ko
L:cf1OlXT>h2oe2Wn0;oJ[_m00?o]lcZojS9lOnXbO401?nXbO44ol;5g@Go`<OO0oo6am/5olO:g0Co
^LKT1OnibNH5oj_2j`03oj[2jonV_n_oY[o[00KoY[o[1onZ`N/4ojO0j`04o`000?nW`>_oYl3[ojO0
j`?oY[o/1?nV_n/7ojS0j`;oZL7[1OnX`N/Cooooo`03o`000?oooooo0000017ooooo000Gooooo`03
o`000?oooooooooo00kooooo1OnX`N/2ojS0j`OoYko[1OnV_n/3ojNoj`coZ<7[0_nW`>/;ojJoj`Co
Z<3[1onY`N/00onX`N_oYko[ojNoj`03o`000003ojNojonV_^_oY[k[00KoY[k[1onY`^`6ojJnjP?o
XkSX0onHZN86oi6Ng@KoU:3L1_nIY]l4oij`i0GoZN7j0on^mO83ok[el@Ko]NSg0_n/aN`7ojRki`Go
YkOT00?oYk;PojZcgonZ/ml01_nZ/ml5ojbcgP03ok2lhona^Moo/KWO00Oo/KWO0_nY]^86ok>lh0Go
XkWX00?o[KkVohRcl_n8/o801On8/o83ocV@k`;o:93^0om@YoP8ojS9l@03ol;5gOo0amoo`<OO00Ko
`<OO00?oa/OKolO:g?o7b]`01Oo7b]`00onia^Co^LWVokW9iP06okW9iP03oj_2jonZ`^_oZ/;[00?o
Z/;[2?nV_n/7oj[1j`CoYl3[00?o0000ojO0jonW`>/02?nV_n/6ojS0j`SoZ<7[5?ooool00ol0003o
ooooooooo`0?ooooo`005oooool00ol0003oooooooooo`0?ooooo`03ojS1jonX`>_oZ<3[00CoZ<3[
1onW_n/00onV_n_oYko[ojNoj`05ojNoj`SoZ<7[1_nW`>/7ojJoj`SoZ<3[1OnY`N/01?nX`N_o0000
o`000?l00005ojNoj`GoY[k[0_nV_n/8ojW2k0?oY[kZ0_nP]^P7oiRYhPKoTIkM1_nDX=`6oiVVg`03
oij`i?nYhO[oZN7j00?oZN7j1?n^mO86ok[el@03okGXmon/aNco[<G/00Co[<G/1onX^nL00onW]nCo
Yk;PojNbh003ojNbh0SoZ[?O00?o[;?Nok2lhon`_><00on`_><7ok6ig`03ok:ohonc_>3o/kcP00Oo
/kcP00?oXkWXojfni_n]_^H00on]_^H7ohRclPCo>I3_0_m9Vo@2oe2Wn0KoZ<Wa00?oVKocol37goo0
aml01_o0aml00onob>7oal[LolO:g005olO:g0;ob<gN1onibNH00onhbnSoZ/;[oj[2j`05oj[2j`Ko
Y[o[00?oYko[oj[1jonZ`N/01_nZ`N/4ojO0j`03o`000?nW`>_oYl3[00SoY[o[1_nX`>/8ojS1jaCo
oooo00?o0000ooooooooool03_ooool001Oooooo00?o0000ooooooooool04?ooool7ojS0j`GoYko[
0onV_n/7ojNoj`OoZ<7[1onW`>/7ojJoj`SoZ<3[00?oZL7[ojS1jol000000_l00002ojS1j`OoYko[
00?oY[k[ojJojonV_n/01?nV_n/6ojW2k003ojJnjonP]^SoX;KX00CoX;KX1onHZN85oi6Ng@OoU:3L
0onIY]l5oj;5lP;oZN7j1?n^mO86ok[el@;o]MC`1on/aN`3ojRki`?oXk3Q1onW/^06ojZcg`03ojZk
iOn`_>?o/;cS00Go/;cS1?na^Ml4ok:oh`Oo/kcP00?o]l;Rojfni_n]_^H01On]_^H7ohRclPCo>I3_
1?m9Vo@2ojS9l@GoVKoc1_o0aml3oko8h@Goal[L1?o8cMh4okW9iPCo^<_X1onZ`^/2ojJoj`GoYko[
1_nZ`N/00onY`N_oYl3[ojO0j`03ojO0j`03o`000?nW`>_oYl3[00OoY[o[1onX`>/7ojS1jaGooooo
00?o0000ooooooooool03Oooool001Oooooo0_l0000Booooo`OoZ<3[00?oYko[ojJojonV_n/01OnV
_n/5ojNoj`WoZ<7[1OnW`>/9ojJoj`KoZ<3[0ol00006ojS1j`?oYko[1?nU_^/7ojJoj`;oZL;/1OnV
_^/6oj2fj0KoV:WR1_nAW]d3oiBPg0CoVZkU1onRaO84okW]m@03ojkel_njmO7o^_Ga00;o^_Ga1_ne
e?05ojc5k003oj:bhonS/>7oXk3Q00GoXk3Q1onW/^02ojZcg`GoZ[_U1on`_><00ona^Moo/[oSok:o
h`05ok:oh`Co/kcP1?ng`^87ojfniP?oR;?b0onB]o04odR@k`03ocV@kom9VoCoBI_d00;oBI_d1onI
_o<3ol37g`Ko_lSQ0oo7b]`6olS=gP03okW9i_nhbnSo^<_X00Co^<_X1_nZ`^/2ojW2k0OoYko[0_nZ
`N/5ojW1j`CoYl3[00Co0000ojO0jonW`>_oYl3[1onV_n/7ojS0j`OoZ<7[5?ooool00ol0003ooooo
ooooo`0=ooooo`005oooool00ol0003oooooooooo`0Booooo`GoZ<3[0onW`>/7ojJoj`03ojNojonX
`N_oZ<7[00_oZ<7[00?oYl3[ojJojonV_n/02onV_n/2ojS0j`03ojW1jol0003o000000?oZL7[1OnX
`N/2ojO0j`OoYKk[1OnV_n/2ojW1j`OoY[k[1_nP]^P6oiRYhP?oTIkM0_nAX^08oiZ^i@CoX/Gb1Oni
kOD3ol?fkP;oan_^2?nee?000on/aNcoX[;Soj:bh`03oj:bh`OoXk3Q1OnW/^000onW^^KoZ[_UojZk
i@06ojZki@Go/;cS0_n/_^L8ok:oh`03ok>lh?ng`^;o]l;R00Co]l;R1_n]_^H2ok;3i`KoT[O`1?m8
T>l3odjDl0;oBI_d1onI_o<00oo0amoo_lSQoko8h@06oko8h@03olO:g?o8cMkob<gN00Cob<gN00?o
bM7PokS;j?nhbnP01_nhbnP2oj[2j`KoZL;/1OnW_n/2ojRoj`OoZL7[1?nW`>/00ol0003oYl3[ojNo
j`08ojJoj`?oZ<3[0onY`N/8ojS1jaCooooo00?o0000ooooooooool03?ooool001Oooooo00?o0000
ooooooooool04oooool00onX`>_oYl3[ojO0j`05ojO0j`GoY[o[0_nW_n/<ojS1j`?oYl3[2onV_n/0
1?nX`>_o0000o`000?l00006ojW1j`03ojS1jonW`>_oYl3[00CoYl3[1onU_^/00onV_n_oZL7[ojW1
j`04ojW1j`OoY[k[1_nP]^P3oiRYhP;oS9kO1_nAX^08oiZ^i@03oj;5l_nikOGo^Nge00?o^Nge1?o3
m^h4olO[kPKo]MC`00?oZ;gYoj:bhonR/^<01OnR/^<7oj>`h@03ojNbh?nW^^KoYk[V00?oYk[V2?nZ
^nD00on`_>?o[;kWojbni`04ojbni`Ko/[oS00?o[l7WokO2h_ng`^801_ng`^82ojfniPKo//?W1_nB
]o04odR@k`GoCYC`0onI_o<4oi:gl@Oo_lSQ00?o_lWRolS=g_o8cMh01?o8cMh3olWAh0Ko^<_X0_nd
bNX8ojW2k003ojNojonX_n_oZ;o[00CoZ;o[1onY`N/2ojO0j`;oYko[00?o0000ojNojonW_n/01onV
_n/7ojW1j`KoZ<7[00?oYl3[ooooooooool04oooool00ol0003oooooooooo`0;ooooo`005oooool0
0ol0003oooooooooo`0Eooooo`OoYl3[00?oY[o[ojNojonW_n/01?nW_n/8ojS1j`OoYl3[1onV_n/0
1?nX`>_o0000o`000?l00003ojS0j`GoZL7[0_nX`N/7ojO0j`GoYKk[0onV_^/6ojW1j`GoY[k[00?o
W[OZoi:WiOnBYnD01?nBYnD6ohbNg`KoTJ;P1_nJ[^D4ok;Fl`03okW]mOo3m^ko`oK^00?o`oK^1_o7
jnh2okGDl0GoZ;gY1_nR/^<6oj>`h@03ojFhionW^^KoYk[V00GoYk[V1_nZ^nD2ojVnj0Oo[;kW0_nb
_n<5ojo1i`Ko]l;R0_ngaN@8ok;3i`?oT[O`0_nB]_03oe:>j`;oB93_1Om>U?07oi:gl@Co_lSQ1?no
bN83olS=gPKobM7P0_nhbnP6okC9jPKoZL;/00?oYl3/ojRojonX_n/01_nX_n/6ojW1j`GoYko[00?o
0000ojNojonW_n/01onV_n/7ojW1j`;oZ<7[1OnW`>/Dooooo`03o`000?oooooooooo00_ooooo000F
ooooo`?o00005oooool5ojO0j`WoYko[2?nX`N/7ojO0j`CoY[o[0ol00007ojS0j`03ojW1jonX`N_o
Z<7[00CoZ<7[1onW`>/00onU_^_oY[k[ojJnj`05ojJnj`KoZL7[00?oY[k[oijgj_nN]nX00onN]nX6
oi:Wi@KoS9kO1OnAX^04oiZ^i@Go/]Kc1?o6k>l2ol?fkPKoan_^0ondc^d6ojRmj@KoX[;S0_nS/>45
ojFhi`OoYk[V0_nZ^nD6ojVnj0Go[;kW00?oZl3Yojo1ion_`NL01_n_`NL3okO2hPGo]lGT1_nb`nL2
ok;7j@GoT[K`1OmBS^/5odjDl0OoT[Oa00?o_lSQoko9h_nobN801OnobN800oo8cMkobM7PolWAh004
olWAh0;ob=CS2?ndbNX2ojW2k0GoYl3/1_nX_n/8ojW1j`CoYko[00?o0000ojNojonV_n/01onV_n/7
ojW1j`SoYl3[5?ooool00ol0003oooooooooo`0:ooooo`005_ooool00ol0003oooooooooo`0Hoooo
o`03ojO0jonW_n_oYko[00_oYko[2?nX`N/5ojO0j`03ojNojonV_n_o000000;o00001?nV_n/5ojS0
j`;oZL7[1onX`N/5ojO0j`;oYKk[2?nV_^/3ojW1j`?oY[o[1_nN]nX6oi:Wi@GoS9kO1_nAX^000onJ
[^Go/]Kcok;Fl`04ok;Fl`Goa^c_1?o@knT00oo7jnko]<k]okC>k@05okC>k@KoZ;gY0onR/^<3oijb
iPOoYKSW1OnW^^H2ojNmj@SoZKkX00?o[;kWoj_0jOn[`>T00on[`>T8ojo1i`03okO2h_ngaNCo]lGT
00Go]lGT0_nb`nL6ok;7j@GoT[K`1OmBS^/3oeVBk0;oCYC`0onB]o44oi>ck@Ko_lWR0_o2c><5olWA
h0Cob=CS1_ndbNX00onab>_oYl3/ojO0k006ojO0k0;oZ;o[3?nY`N/2ojNoj`;oY[o[00?o0000ojJo
jonV_n/01onV_n/7ojW1j`OoYl3[4oooool3o`0000_ooooo0004ooooo`Co000000So410@oooooooo
ooook^k^oc8b<_l0003o<S8bonk^kPKooooo00?o0000ooooooooool06_ooool:ojNoj`CoZ<3[1onX
`N/00onW`>_oYko[ojNoj`03o`0000SoY[o[00?oZ<3[ojW1jonY`N/01?nY`N/7ojS1j`03ojO0jonU
_^_oYKk[00CoYKk[1_nV_^/00onY`^_oY[o[ojJoj`05ojJoj`KoW[OZ1OnBYnD6ohbNg`?oTJ;P1?nL
/nP4ok;Fl`Goa^c_1?o@knT2olcVj@So]<k]0onX_NT2oi^ai`OoW[;V1onU^>L00onW^^KoYkgYojNm
j@04ojNmj@KoZKkX00?oZKoYoj_0jOn[`>T01On[`>T6ojo1i`;o[/;X1_ngaN@2okO7iPSo//OY1OnB
]_05oe:>j`CoFI;/2?nC/nd3oko9hPGo`/cS0oo9dN06olSDh`;o]<WZ1Onab>/6ojO0k003ojJojonY
`N_oZL7[00_oZL7[0_nX`>/4ojJoj`03o`000?nV_n_oY[o[00GoY[o[0_nW_n/7ojW1j`OoYl3[3ooo
ool3o`0000;ooooo00?o0000ooooooooool02Oooool000Kooooo00?o0000ooooooooool00_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool06oooool5ojNoj`03ojJojonX
`>_oZ<3[00KoZ<3[1OnX`N/01?nX`>_o0000o`000?l00004ojNoj`KoY[o[0_nW_n/7ojW1j`?oZ<7[
1?nW`>/7ojFnj`;oY[k[1OnY`^/7ojJoj`KoW[OZ1OnBYnD3ohbNg`;oSZ?S2OnL/nP00onbe_?oa^c_
olK/k`02olK/k`God>oY1?o<i^T6okC>k@03ojFok?nK/NOoVk7W00CoVk7W1onN/^H3ojFhi`CoY[cY
1onW_NT2ojVnj0GoZKoY1on[`>T2ojo1i`Ko[/;X0ongaN@5okO7iPKo//OY00?o[LO]ohZ_k_n:[nh0
0on:[nh4oeZ;iP;oDXk[1?mIT^`8oi>ck@03oko9h_o2c>?o`/cS00Go`/cS00?obM7PolSDhoo8e><0
1?o8e><2olCGj0Oo/LS[0_nW`>`5ojJoj`WoZL7[1_nX`>/3ojJoj`03o`000?nV_n_oY[o[00;oY[o[
1_nW_n/5ojW1j`03ojS1jonW`>_oYl3[00KoYl3[2oooool3o`0000Gooooo00?o0000ooooooooool0
2Oooool000Kooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Kooooo
0_l0000Mooooo`03ojNojonV_n_oY[o[00?oY[o[2?nX`>/00onX`N_oZ<3[o`000002o`0000;oZ<3[
1_nW_n/2ojJoj`KoYko[1onY`N/7ojO0j`SoYKk[1_nY`^/5ojJoj`;oWkW[1On?ZnP5ohJNh`KoSZ?S
1onL/nP4okcHkP03olK/koo@knWod>oY00?od>oY1_o<i^T2okC>k@GoYKo/1_nK/NL5oijbiP03oj:j
jOnV_>WoY[cY00KoY[cY1OnW_NT00onW_^[oZKoYojVoj@06ojVoj@GoZl3Y0_nZ`NX8ojk2j003okO5
i?nganKo]lOV00Go]lOV0_nbanT5ojg7k@GoRZo^1OmJRnH3ofJBj0;oFI;/1_nC/nd00onK]>Wo`/cS
ol;<h`05ol;<h`03olGAhoo8e>?ob=CS00Cob=CS1?o4enP5ok78j`;o[LG/1onV_n/5ojW1j`;oZ/;[
2?nX`>/3ojJoj`03o`000?nV_^_oY[k[00SoYko[00?oZL7[ojS1jonX`N/00onX`N/8ojO0j`Kooooo
1?l00008ooooo`03o`000?oooooooooo00Wooooo0006ooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000005ooooo`;o00007oooool6ojJoj`KoZ<3[00?oZ<7[o`000?l00000
1_nX`>/3ojNoj`CoY[o[1onW_n/7ojW1j`OoYl3[2?nU_^/6ojW2j`03ojJojonO^N_oWkW[00CoWkW[
1On?ZnP5ohJNh`KoSZ?S1?nL/nP5okcHkPCocNGX0_o@knT6olcVj@;o^M3[1onU_n`6oi^ai`03oijb
i_nR^^WoX[[Y00?oX[[Y2?nV_>T00onW_NWoYkkZojNnjP03ojNnjPSoZKoY00?oZl3Yoj[1j_nZ`NX0
1?nZ`NX6ojk2j0;o[/CZ1_nganH2okW>jPKo[LO]1_n:[nh5oeZ;iPGoIY;X0_nC/nd5oi^dj@Go`/cS
0oo5dN<3olSDh`Ooa=OX00?o/LS[ojg5k?n]aN`01?n]aN`7ojJoj`03ojW1jonZ`^_oZ/;[00CoZ/;[
1_nX`>/00onW`>_oY[k[ojJnj`02ojJnj`03o`000?nV_^_oY[k[00KoYko[2?nX`N/6ojO0j`04ojNo
joooooooooooooooo`?o00003Oooool00ol0003oooooooooo`08ooooo`001_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`0Oooooo`Ko
Y[o[0_nX`>/01?nX`N_o0000o`000?l00002ojS1j`GoZ<3[0_nW`>/7ojJoj`GoYko[2OnY`N/5ojO0
j`?oY[o[1onU_^/3ojW2j`?oYl3/1onO^N/5ohn[j0GoQYkS1_n>Xn<00onL/nSo_=S^okcHkP04okcH
kPGocNGX1?oEiN800oo<i^Wo^M3[okW@j`04okW@j`OoYKo/0onK/NL3oi^cj@KoX[[Y1_nV_>T2ojJn
j`KoYkkZ1_nY_nT2ojW0jPOoZ/7Z0_n^`^P6ojk4jP?o]lOV1Onic^X6ojg7k@KoRZo^1OmJRnH5ofJB
j0KoVkCY0oo2c><6olGAh`03olSDhoo4enSoa=OX00Goa=OX00?o_=C/ojg5k?n]aN`01_n]aN`3ojJo
j`?oYko[2?nZ`^/2ojS0j`GoYl3[1?nV_^/00ol0003oY[k[ojJnj`02ojNoj`coZ<7[0_nW`>/5ojNo
j`;o00004?ooool00ol0003oooooooooo`08ooooo`001_ooool00ol0003oooooooooo`02ooooo`05
oa0@4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`0Pooooo`?oY[o[0_nW_n/3o`00
00KoZ<7[00?oZ<3[ojO0jonW`>/01?nW`>/7ojJoj`03ojNojonY`N_oZL7[00_oZL7[00?oYl3[ojJo
jonV_n/01OnV_n/5ojFnj`03ojS0jonW`>coYl3/00GoYl3/1onO^N/5ohn[j0GoQYkS0on>Xn<4oibd
j0Co_=S^1Oo=iNP4omGUhP;odmkP1onid>/3ojFok0?oV;G/1onK/nT6oj:jj@;oY[cY1_nV_^/6ojNn
jP;oZKoY1_nY`>X5oj[1jP;oZ/;[2?n^a>X00onganKo^LkZokW>jP05okW>jP?o[LO]0_nS_^`6ogbQ
jP?oI8SQ0_mJRnH6ofJBj0KoVkCY00?o`/cSolGAhoo5dN<01?o5dN<3olSGi@Coa=OX1?nle>`6ojg5
k003ojW2k?nW_n_oYko[00GoYko[1_nZ`^/00onY`^coYl3[ojO0j`05ojO0j`CoY[k[00?o0000ojJn
jonV_^/02onX`N/3ojS0j`SoYko[4Oooool00ol0003oooooooooo`08ooooo`001_ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2o`0002;ooooo00CoYko[o`00
0?l0003o00000onW_n/8ojS1j`KoYl3[2?nV_n/:ojW1j`?oZ<3[2?nV_n/00onU_^_oZ<3[ojS0j`03
ojS0j`OoYl3/0onO^N/3oi:bk0GoPIoV1On9XnD9oibdj003okcHk_o=iNSocNGX00?ocNGX1?oEiN84
om?Nh0Go^M3[0_n/aN`6oiRek0OoVk?Y0onR^^T3ojBmj`SoY[k[0onW_^X3ojO0j`SoZL3Z00?oZ/7Z
oj[2jonZ`^/01?nZ`^/6ojk4jP03ojo7jonic^[o^LkZ00Go^LkZ00?o]]3]oj>nk?nS_^`01?nS_^`6
ogbQjPGoI8SQ1_mVT^P3oi^dj@CoZ;[V0oo5dN<6olSGi@03olCGj?nle>co_=C/00Go_=C/0_n]aN`5
ojW2k0OoYko[0_nZ`^/5ojW2k0OoYl3[1?nV_^/00ol0003oY[k[ojJnj`06ojS1j`03ojW1jonX`>_o
Z<3[00GoZ<3[1_nW_n/00onV_n_oooooooooo`0?ooooo`03o`000?oooooooooo00Sooooo0004oooo
o`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooo
oooo01oooooo0ol00007ojNoj`SoZ<7[1_nW`>/8ojJoj`KoZL7[1onX`>/6ojJoj`;oYKk[1_nX`>/5
ojO0k0;oX[g/1_nB/^`5oh6OiPGoRJ?U1onL]>P3ok_>j@?ocNGX1?oEiN86om?Nh003okW@jon/aNco
[<G/00Co[<G/1_nH]N`5oi^cj@03oinjk?nT_N_oY;g[00GoY;g[1_nV_^/00onV_ncoYl3[ojO0j`05
ojO0j`KoZL3Z0_nY`^`7oj[2j`;o[/CZ1On_an/4okW>jPCo]]3]1_nS_^`6ogbQjPCoI8SQ1_meU^D8
ojRjiP03olGAhoo8enGob=OU00Cob=OU0_o9g>L6okcDk0;o//c]1_nY`^`6ojNoj`;oZ<7[1onY`^`3
ojO0j`?oY[o[1OnV_^/00ol0003oY[k[ojJnj`02ojS1j`GoZL7[1onX`>/2ojNoj`GoY[o[4?ooool0
0ol0003oooooooooo`08ooooo`005Oooool00ol0003oooooooooo`0Looooo`?o00001?ooool5ojNo
j`[oZ<7[0onW`>/;ojJoj`KoZL7[1onX`>/2ojJoj`KoYKk[1_nX`>/00onW`>coX[g/oj:mk004oj:m
k0KoT[;/1On1WnH5ohVSi@CoW;CX1_nkc^T00oo=iNSoeNGRomGUhP02omGUhPKodmkP0_o9e^<7ojc5
k0KoV;G/00?oVk?Yoinjk?nO^^`00onO^^`7ojBmj`;oY[k[1OnV_n`7ojO0j`;oZL3Z1_nY`^`5oj[2
j`;oZlC/1on_an/00onic^[o]]3]okK@k@05okK@k@KoXkk/1OmlXNX5ofB8h@KoMIKU1_nX^^H00ong
bNSob=OUolSGi@04olSGi@CobMcW0onle>`5ok;<k@KoZL;/0_nW_n/6ojS1j`GoZL;/00?oZ<7[ojJo
jonV_n/01OnV_n/5ojJnj`03o`000?nW_n_oZL7[00KoZL7[1_nX`>/00onW`>_oY[o[ojJoj`06ojJo
j`oooooo00?o0000ooooooooool02?ooool001Gooooo00?o0000ooooooooool06Oooool3o`0000So
oooo00?oYko[ojS1jonX`N/02_nX`N/00onW`>_oY[o[ojJoj`0;ojJoj`;oZ<3[1_nY`N/5ojS0j`?o
Yl3[1onU_^/3ojS0j`CoZ<7[1_nR_N`5oi:bk0GoPIoV1_n9XnD00onL]>So^lkYok_>j@05ok_>j@Co
cMWS00?oeNGRom?Nh?oCg^001?oCg^04olWFh`Go[<G/00?oXKk^oi:dk_nB]>h01OnB]>h6oinjk0Go
Y;g[0_nU_n`7ojJok0GoYl3[0_nW`N`8ojW2k003oj[2jon[a>coZlC/00CoZlC/1On_an/3okC?kPOo
]]3]0onS_^`2oiJ^i`CoM8cM0_mlXNX4ofB8h@KoMIKU1?nX^^H4okO9j0?ob=OU1oo9g>L00onle>co
//c]ok;<k@05ok;<k@?oZL;/0onV_n/8ojS1j`03ojW2k?nX`N_oZ<7[00?oZ<7[1onV_n/2ojJnj`;o
Yko[00?o0000ojNojonW_n/01onY`N/2ojS0j`GoYl3[1onV_n/?ooooo`03o`000?oooooooooo00So
oooo000Eooooo`03o`000?oooooooooo01Kooooo0ol0000=ooooo`SoZ<7[1OnW`>/9ojJoj`KoZ<3[
1_nY`N/00onX`>_oYl3[ojO0j`05ojO0j`GoYKk[00?oY[k[ojS1jonX`N/01_nX`N/6oj:mk0GoT[;/
1On1WnH3ohVSi@CoUZoX1Onkc^T5olgIh`;odmSL1?oCg^06olWFh`03ojc5k?nQ_^koXKk^00?oXKk^
1onB]>h6oinjk003ojBmjonU_ncoYKo/00CoYKo/1onV_n`00onW`>_oYl7/ojO1k004ojO1k0KoZL;/
00?oZ<?/oj_4k?n[a>`01_n[a>`00on_an_o]<o^okC?kP05okC?kP?o]]3]0onZ`n`6oiJ^i`GoM8cM
1?m`R]d00omTR>7oMIKUogFFi@04ogFFi@03ojRji_ngbNSo]lWX00Go]lWX00?ob=OUolWLioo9g>L0
1Oo9g>L2olGNj`Ko//c]00?o[<K]ojJojonV_n/01OnV_n/6ojS1j`03ojW2jonX`N_oZ<7[00GoZ<7[
1OnV_n/2ojJnj`CoYko[00?o0000ojNojonW_n/00onY`N/4ojS1j`OoYl3[1onV_n/?ooooo`03o`00
0?oooooooooo00Oooooo000Dooooo`;o00005Oooool3o`00017ooooo1OnX`N/2ojW1j`KoYl3[2?nV
_n/7ojS0j`?oZL7[1?nX`N/7ojO0j`03ojFnjonV_^_oY[k[00?oY[k[2?nX`N/3oj:mk0;oV[W]1On0
YN`5oh2Qj0SoUZoX0onkc^T5olgIh`GodmSL00?odmkPolWFhoo9e^<01?o9e^<2oko<i0KoXKk^1onB
]>h3oinjk0?oX;g^1onU_n`3ojJok0CoY/3/1onW`N`2ojW2k0GoZ<?/1_n[a>`2ojc9kPKo]<o^0_nc
dO06oj[3k0KoUZkW1OmdS=d4og2:g@OoQj3T1_ngbNP3ol3Dj@CobMcW1Oo5g^/2ok;<k@Go[<K]1onV
_n/2ojS1j`GoZL;[1onX`N/00onV_n_oY[k[ojJnj`04ojJnj`CoYko[00?o0000ojS1jonX`N/01onX
`N/5ojO0j`;oYko[1_nV_n/?ooooo`03o`000?oooooooooo00Oooooo000Dooooo`03o`000?oooooo
oooo01;ooooo0_l0000Eooooo`03ojS1jonY`N_oZL7[00CoZL7[1_nW`>/8ojJoj`GoZ<3[0onY`N/6
ojS1j`GoYl3[0_nU_n`6ojJnj`KoZ<7[0_nV`>`5oiZik@GoP:G/1On0XNP8oiJ_j003ok_>jOo=fN?o
cMWS00?ocMWS1OoCf=`3omGDf0?obMKS1Onoc>@6oj6nkP?oT[C^1?nC^?46oj2mkPGoYKo/0_nU`Nd7
ojK0k0GoYl7/0_nW`^d7ojS3k0;oZlC/1_n/bNh3okC?kPGo/m7`1_nZ`n`5oiJ^i`KoM8cM1?m`R]d7
ohNPi0?o]lWX1_o0e>T00oo9g>OoaMk[olGNj`04olGNj`;o^MG^1_n/a^d6ojJoj`03ojNnjonY`^_o
ZL;[00KoZL;[0onX`N/3ojNoj`SoY[k[00GoYko[ojS1jonX`N_oZ<7[o`000009ojS1j`03ojO0jonW
_n_oYko[00CoYko[1_nV_n/>ooooo`03o`000?oooooooooo00Oooooo000Dooooo`03o`000?oooooo
oooo00oooooo0ol0000Hooooo`OoZL7[1onW`>/7ojJoj`03ojS0jonY`N_oZL7[00GoZL7[1_nX`N/0
0onW`>_oYKo/ojFok004ojFok0KoY[k[0_nX`N/6ojK0k0GoV[W]1On0YN`5oh2Qj0KoUZoX0on^_nH3
olgIh`GodmSL1OoEe=P00oo9e^?o_lcToko<i005oko<i0?oXKk^0onK_>l7oi>hl@KoX;g^00?oYKo/
ojG1kOnU`Nd01?nU`Nd7ojK0k003ojO1k?nW`^goYl;]00CoYl;]1OnX`n`2ojW7k`So[<W^00?o]<o^
ok?Al?ncdO001OncdO03oj[3k0;oW:cR1?n4T]T2oiJ^i`GoM8cM1Om`R]d7ohNPi003okO9j?o0e>Wo
`=CY00Co`=CY0_o6g^/4olGNj`Go^MG^1_n/a^d2ojJoj`GoYkk[1_nY`^/00onY`^coYko[ojNoj`05
ojNoj`OoY[k[1?nX`N/00ol0003oZ<7[ojS1j`04ojS1j`?oYl3[2?nW_n/3ojJoj`?oYl3[3Oooool0
0ol0003oooooooooo`07ooooo`005?ooool00ol0003oooooooooo`0<ooooo`?o00007?ooool5ojW1
j`?oZ<7[1_nW`>/8ojJoj`OoZL7[0onX`N/3ojS0j`OoYKo/0onV_^/4ojS0j`OoY/3/1OnJ^Nd5oh2U
k0GoP:7X0_nF[nP7ojjoiP03olgIhooCf=codmSL00?odmSL1OoEe=P2om?>e@Ko_lcT0_nha><6oi^l
k`OoTkSa0onP_Nh3oio0l0OoYL7]0onV`>`4ojK3kPOoYl;]00?oZ<?/ojW7konYanl01?nYanl6ojc9
kP;o/=Gc1_ncdO000onX^nSoW:cRoib/hP04oib/hPGoQ9;I1?mhR=L2ogB<g@GoL8[M0on7X>@3oj6d
iPKo`=CY1?o6g^/00oo5g^_o^MG^okWEkP06okWEkP?o[<K]0onX`N`7ojNnj`;oZL;[1OnY`^`7ojNo
j`OoY[k[1?nX`N/00ol0003oZ<7[ojW1j`07ojO0j`KoYko[00?oY[o[ojO0jonW`>/01OnW`>/<oooo
o`03o`000?oooooooooo00Oooooo000Cooooo`?o00002_ooool3o`00023ooooo00?oZL7[ojS1jonX
`N/01OnX`N/6ojO0j`SoY[o[1_nY`N/7ojS0j`GoYKo/0_nU_^`7ojS0j`GoY/3/00?oXKk]ohbbl?n<
/_000on</_05ogNPk0OoR:S[1_n^_nH3ol?<h@?odmSL1OoEe=P4om?>e@?o_lcT1Onha><6oi^lk`?o
TkSa1?nA_?@6oio0l0GoYL7]0_nS`o07ojK3kPGoYl;]0_nWa_07ojW7k`;o[<W^1_n`eO<2ok?Al0Go
Z;_X1OnL[>86ohBBf@GoN8SG1OmoTmd7oj6diP?o`=CY1Oo6g^/3olKTk@Ko^MG^00?o[lW]ojS1k?nX
`N`01OnX`N`5ojNnj`WoZL;/0onW_n/3ojJoj`SoY[k[0_nX`N/2ojW1j`03o`000?nY`N_oZL7[00Oo
Yl3[0_nW_n/5ojJoj`OoYl3[2oooool00ol0003oooooooooo`07ooooo`005?ooool00ol0003ooooo
ooooo`06ooooo`?o00009Oooool7ojS1j`?oYl3[1?nV_n`7ojJoj`KoZL7[1onX`>/00onU_ncoYKk/
ojFnk004ojFnk0OoZ<3[00?oY/3/oj6nkOnQ_^d00onQ_^d5ohbbl0GoMj3/1on8Z>/3ojjoiPKo`lcQ
00?odmSLomGDf?oEe=P00ooEe=P6om?>e@03oko<i?nha>?o^<CS00Go^<CS0onK_>l3oi^kkPOoTKcd
1_nO`?000onU`NgoXl?`oj?3l004oj?3l0OoY/?^00?oYl;]ojO6l?nWa_001?nWa_05ojW7k`?oZ=7e
1On`eO<2ojg7k@OoZ;_X1OnL[>86ohBBf@GoN8SG1OmoTmd7oj6diP03ol3DjOo6g^_oa]k[00?oa]k[
1Oo6i>d2okWEkPGo[lW]1onX`N`00onW_^_oZL;/ojW2k009ojW2k003ojO0jonV_n_oY[o[00GoY[o[
1_nV_^/00onX`>_oZL7[ojW1j`02ojW1j`03o`000?nY`N_oZL7[00KoYl3[00?oYko[ojJojonV_n/0
1_nV_n/3ojO0j`?oZ<7[2oooool00ol0003oooooooooo`07ooooo`005?ooool00ol0003ooooooooo
o`03ooooo`?o0000:Oooool5ojS1j`03ojS0jonV_ncoY[o/00KoY[o/1OnV_n/2ojNoj`KoZL7[1OnX
`>/3ojO0j`KoYKk/1OnX`>/2ojW1j`KoXKk]1On</_05ogNPk0OoR:S[00?o[[oVol?<hOo3c>401?o3
c>43olc>f`?oeMCH1ooCc]D00oo@am;o^<CSokS4h`04okS4h`;o]kgN1_nK^nh7oi6lm0?oWl3`0onL
aO@7oj?3l0?oY/?^1?nTa_47ojO6l003ojW7konXdOGoZ=7e00GoZ=7e00?o/=Gcojg7kOn]and01?n]
and7ojRkj0CoW:cR1_n4T]T5ogR8e`KoOi?M1OnQ]>H3okO?k0?oa]k[1Oo6i>d00onlfo3o[lW]ojo9
k@06ojo9k@?oZ<7/0onV_^/9ojW2k0GoYl3[1onV_n/2ojJnj`GoZ<3[1?nY`N/00ol0003oZL7[ojW1
j`02ojO0j`GoYko[1_nV_n/00onW_n_oZ<7[ojS1j`05ojS1j`_ooooo00?o0000ooooooooool01_oo
ool001?ooooo00Co0000oooooooooooooooo0ol0000]ooooo`03ojS1jonX`>_oZ<3[00?oZ<3[2?nV
_n`00onV_n_oYko[ojNoj`04ojNoj`KoZL7[00?oZ<3[ojO0jonW`>/01OnW`>/6ojFnk003ojS0jonY
`N_oZL7[00CoZL7[1_nQ_^d5ohbbl0GoMj3/0on8Z>/4oiBbk0Go`lcQ1Oo<c]/00ooEe=SodlkEom?>
e@05om?>e@?od<OB0onha><5okNmgPKoVk_^0onA_?@4ohnmm@KoW<Gd1OnS`o02oio:mPOoY<Ka0onW
a_05ojG@m`GoZ=7e0_n[bo47ojg7k@?oZ;_X0onLW]H4oh^?d@03oib/h_n4T]WoQ9;I00CoQ9;I1?mh
R=L7ognCg@03oj6di_ngcnco]lo/00Go]lo/00?oa]k[olKTkOo6i>d00_o6i>d4okcKl0Ko[lW]00?o
ZL;/ojJnjonV_^/01OnV_^/7ojW2k0OoYl3[1OnV_n/2ojJnj`OoZ<3[0onY`N/00onX`N_o0000ojS1
j`08ojNoj`;oY[o[1OnW_n/7ojS1j`[ooooo00?o0000ooooooooool01_ooool001?ooooo1?l0000b
ooooo`GoZ<3[2?nV_n`7ojNoj`KoZL7[2?nW`>/6ojFnk0OoZL7[0onQ_^d3oibkkPGoO:cb1OmfXnh7
oiBbk0?o`lcQ1_o<c]/2olk;e`GodlkE1Oo@am800onha>?o]kgNokNmgP05okNmgP?oVk_^0onR^^X7
ohnmm@KoW<Gd00?oXl?`oio:m_nOb_H01?nOb_H5ojC6l@;oX=3h2?nUd?L00onXdOGoZl_aoj_;l@04
oj_;l@Go[LO]00?oXjWKoibNe_nLW]H01OnLW]H4oh^?d@KoPX[B1?n3T=P01?mhR=OoOi?MognCgOmo
Tmd3oiBWhPOo]lo/0oo1h>l00oo6i>go_=_`okcKl005okcKl0;o[lW]1OnY`^`7ojJnj`OoZL;/1onW
`>/00onV_n_oY[k[ojJnj`04ojJnj`GoZ<3[0_nX`N`4ojS1j`03o`000?nX`N_oYko[00GoYko[00?o
Y[o[ojNojonW_n/01_nW_n/6ojS1j`[ooooo00?o0000ooooooooool01_ooool001?ooooo0_l0000e
ooooo`GoZ<3[2?nV_n`5ojNoj`;oZ<3[1_nY`N/6ojO0j`;oY[o/1_nU_^`5ojW1j`;oZ<3[1_nL^nh5
ogb/lPGoMZ?^1onD/^`00oo3c>7oc<kKolc>f`04olc>f`Coc/_G0ooCc]D6om37dP03olg1cong_Mko
]kgN00Co]kgN00?o^KOGoj:jj_nR^^X01OnR^^X7ohnmm@?oW<Gd1?nEa_P6oio:mP03ojC6lOnPd?So
X=3h00CoX=3h1_nUd?L2ojK:lPOoZl_a00?o[LO]oj>YfonSZM/00onSZM/6oibNePGoRhoA1_n2R]84
oh>@f0OoU:OR1?ngcn`4ol7Pk`?o`nS`1Onlfo02ojo;kPKoZL;/1_nV_^/00onX`NcoZL;/ojW2k006
ojW2k0?oYl3[0onW_n/8ojJnj`03ojS0jonX`NcoZ<7/00CoZ<7/0onX`N/00ol0003oZ<7[ojS1j`02
ojNoj`GoY[o[1_nW_n/8ojS1j`Wooooo00?o0000ooooooooool01_ooool000Go00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0<oooool2ojS0j`CoYl3[1onV_n`0
0onW_n_oZ<3[ojS0j`04ojS0j`KoZL7[0_nW`>/6ojJok0KoYKk/00?oZL7[ojS0jonX`>/01?nX`>/6
oibkkPGoO:cb1OmfXnh5oiBbk0;oY[cY1Oo<c]/6olk;e`03om?>eOo@am;od<OB00Cod<OB0oo=`Ll3
okNmgPCo^KOG1onR^^X3ohnmm@GoUk[`1_nEa_P3oio:mPCoV<Wi1_nPd?P2ojG@m`KoY/[b0on[bo43
ojJ`gPKoXjWK1_nLW]H6oh^?d@GoPX[B1On3T=P7oiBWhP03okO?k?o1h>oo`N3_00?o`N3_1Oo3j?00
0onlfo3o[l_^ojo;kP04ojo;kPKoZL;/0_nV_^/5ojS1k0KoZL;/00?oZ<3[ojNojonW_n/01OnW_n/6
ojJnj`03ojNojonX`NcoZ<7/00KoZ<7/0onX`N/00ol0003oYl3[ojO0j`07ojJoj`;oYko[3?nX`N/8
ooooo`03o`000?oooooooooo00Kooooo00001OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`09ooooo`03o`000?oooooooooo03?ooooo1_nW`>/7ojJok0OoZ<3[0onY
`N/4ojS1j`OoY[o/0onU_^`3ojNoj`OoZ<3[0onL^nh4oiNjl0CoL:Kb0omiYo02ogJSkP03oiBbk?nV
_>WoY[cY00CoY[cY0oo<c]/6olk;e`;oc/OC1Oo@am85olg1c`03okNmg_ni]mOo^KOG00Co^KOG1OnR
^^X2oj^fh@SoUk[`0onEa_P4oiVml@KoV<Wi0onPd?P4oj;4l0GoY/[b00?oYk3NojJ`g_nV/=h01OnV
/=h6oj>Yf`KoW9kF1On;Sm45oh::dPKoPi3H1OnDYn83ok7>k`?o`N3_1Oo3j?000onjgO7o[l_^ojo;
kP06ojo;kP?oZL;/0onV_^/7ojS1k0;oZL;/1OnX`>/7ojNoj`;oY[k[1OnW_n/7ojS1k0CoYl3[00?o
0000ojO0jonW`>/01OnV_n/00onW_n_oZ<7[ojS1j`0;ojS1j`03ojS0jooooooooooo00Kooooo00?o
0000ooooooooool01_ooool00004oooooonHV9So8B4Qonk^kPCooooo00Go410@oooooooooooooooo
oa0@400:ooooo`03o`000?oooooooooo03?ooooo1_nW`>/7ojJok0GoZ<3[0onY`N/6ojS1j`GoY[o/
0_nU_n`6ojNoj`GoZ<3[0onV`>`6oiNjl0CoL:Kb1OmiYo07ojJlj@03olc>foo>bmOoc/_G00Coc/_G
1?o>am<3om37dPKocL7?2?ni]mL00onR^^[oZkKQoj^fh@04oj^fh@KoUk[`00?oYKCSoiVmlOnI_O40
1_nI_O43oiS9n@?oX[WZ1onRa?000onVb_;oYk3NojN`gP03ojN`gPOoY[3N1OnSZM/6oibNePKoRhoA
1On2R]86oh>@f003oiBWh_nac^oo/Lk_00Go/Lk_00?o`N3_ol?Xl?o3j?000_o3j?04ok[Ml@Ko[l_^
00?oZL;/ojJnjonV_^/01OnV_^/5ojS1k0;oZL;/1onX`>/3ojNoj`?oY[k[2?nW_n/7ojS1k0CoYl3[
00Co0000ojO0jonW`>_oY[o[1OnW_n/9ojS1j`GoZ<3[1oooool00ol0003oooooooooo`06ooooo`00
0_ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000002oooool2o`0003Co
oooo1_nW`>/7ojJok003ojS0jonY`N_oZL7[00GoZL7[1_nX`N/00onV_ncoYKo/ojFok004ojFok0Ko
Yko[00?oZ<3[ojK0k?nV`>`01OnV`>`6oiNjl0CoL:Kb1OmiYo05ojJlj@?o//;U0oo>bmL7olk7d`03
om37d_o=`LoocL7?00CocL7?0_o;_<`6okVge`;o_[;?1on[]^42oiNjl0GoYKCS1_nI_O400onW/Moo
X[WZoj:ijP05oj:ijPGoX/C`00?oYj_JojN`g_nW/=h01OnW/=h7ojJ`gPGoXjWK0onLW]H2oi6>c0Ko
S8k@1?n;U=L01?n2R];oPi3Hoh>@f?n3T=P4oiBWh`Ko/Lk_0onmi?800oo3j?3o^]gaok[Ml@05ok[M
l@;o[l_^1OnY`^`7ojJnj`03ojS1k?nY`^coZL;/00CoZL;/1OnX`>/2ojNoj`KoY[k[1_nW_n/9ojS1
k0?oYl3[00?o0000ojNojonW_n/01onW_n/6ojS1j`SoZ<3[1oooool00ol0003oooooooooo`05oooo
o`000oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000003Oooool00ol0
003oooooooooo`0booooo`KoYl3[1OnV_n`3ojJoj`OoZL7[0onX`N/3ojS0j`OoYKo/0onW_n/4ojS0
j`OoY/3/0onG^_02oi6hl@CoJJCc00?oL:KbogVWl?miYo000omiYo000onV_>Wo//;Uok;2i@05ok;2
i@03olk;eoo>am?oc/OC00Goc/OC0_o=`m45olg1c`Cobkc<0oni]mL5okjbc`GoZkKQ0_naZ]47ojFd
h`;oVKga1OnW/Ml7oj:ijP03oj;4l?nWZm[oYj_J00?oYj_J1onW/=h3ojJ`gP?oWYG:1OnITL/6oi6>
c0KoS8k@1?n;U=L8oiBWh`?o/Lk_1?nmi?83okkZl`Go^]ga0_n^b^h7ojW2k0?oY[k[0onX`N`8ojW2
k003ojS0jonW_n_oYko[00CoYko[1_nV_^/2ojNoj`_oZ<7/00?oYl3[ojNojonW_n/00_nW_n/00ol0
003oYko[ojNoj`05ojNoj`;oZ<3[1_nX`N/6ojS0j`03ojO0jooooooooooo00Gooooo00?o0000oooo
ooooool01Oooool000Cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo
00cooooo00?o0000ooooooooool0<_ooool6ojO0j`03ojJok?nV_n_oY[o[00GoY[o[1onY`N/6ojS0
j`SoYKo/1_nX`>/5ojK0k0;oY;o/1OnA^?45ofVTl`GoOJgb1_nb`^D2okS4i0Koc/OC1?o=`m43olg1
c`Kobkc<00?o^KOGokjbconn//l01Onn//l00on[]^7o/J[Aok6Zd@04ok6Zd@GoYKCS00?o[JK@ojNa
gonW/Ml01_nW/Ml5oj:ijP03ojRTd_nWZm[oYj_J00GoYj_J1OnW/=h00onSV<WoWYG:oijEbP04oijE
bPKoVI7;1OnAS/`6ohb>d0GoRiCG2?nDYn<01?nac^oo_NCbokgTl_nmi?86okkZl`03ok[MlOn^b^ko
[/[^00Co[/[^1OnY`^`2ojJnjPKoZ<7/1_nY`^`00onX`>_oYko[ojNoj`06ojNoj`?oY[k[0onW_n/9
ojS1k0GoYl3[1?nW_n/01?l0003oYko[ojNojonW_n/6ojS0j`KoZ<7[0_nX`>/5ojO0j`Kooooo00?o
0000ooooooooool01Oooool00005o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00oooooo00?o0000ooooooooool0<_ooool3ojO0j`CoY[o/1onV_n/7ojW1j`KoZ<3[
2?nU_n`6ojS0j`03ojK0k?nT_ncoY;o/00CoY;o/1OnA^?45ofVTl`GoOJgb0onb`^D5okS4i0?oc/OC
1oo=`m400oo=`Loobkc<ol^lc005ol^lc0So_[;?2?naZ]400onU]>?o[JK@ojfVd003ojfVd0SoYk7O
00?oX[WZojRTd_nXY=800onXY=87ojN[fP03ojN`g_nSV<WoXiS900?oXiS91_nNULX5oiVAb`KoTHk<
1_n<S]05oh^De`KoU:OS0on`e?<00onmi?;o_^[cokkZl`04okkZl`03okGHl_n^b^ko[/[^00Ko[/[^
00?oZL;/ojJnj_nV_^X01?nV_^X6ojS1k0;oZL;/1OnX`>/6ojNoj`03ojJnjonW_n_oYko[00GoYko[
1_nX`N`8ojO0j`CoYko[00?o0000ojNojonX`>/01onX`>/3ojS1j`;oZ<3[2?nW`>/5ooooo`03o`00
0?oooooooooo00Gooooo00001OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0@ooooo`;o0000=?ooool6ojJok0GoY[o[0_nW_n/7ojW1j`?oZ<3[0onW`>/8ojFok0Ko
Z<3[1onT_n`5oi6hl@GoJJCc1Omm[O800onb`^Go^<CTokS4i005okS4i003olk7doo=`m7ocL?A00Go
cL?A00?ob/7Aol^lc?o;_<`01Oo;_<`2olVibPKo_[;?0_o2/<P6ok6Zd@03okZXb?n]Y]3o[JK@00Go
[JK@1_nW/Ml00on/Wl[oZ:CBojRTdP05ojRTdPGoYj_J00?oZ9W7oj>HbOnSV<T01?nSV<T6oijEbPKo
VI7;1OnAS/`6ohb>d0KoRiCG0_nDYn<5ok3Dl`Co^NWe00?o_^[cokGHl_nef?800onef?86ojk:kP03
ojS1jonV_^[oY[kZ00KoY[kZ0onX`N`3ojW2k0OoZ<3[0_nW_n/5ojJnj`OoYko[1_nX`N`6ojO0j`Go
Yko[00?o0000ojNojonW_n/01_nX`>/00onX`NcoZ<3[ojS0j`04ojS0j`KoYl3[00?oYko[oooooooo
ool00oooool00ol0003oooooooooo`05ooooo`007oooool00ol0003oooooooooo`0booooo`KoY[o/
00?oY[o[ojNojonW_n/01?nW_n/8ojW1j`GoYl3[1_nU_n`2ojBok0KoZ<3[1OnT_n`2oj>ok@GoSKOc
1OmTYOD5ogjam@Ko^<CT00?o^<KTolg3dOo=`m401Oo=`m43ol[1d@Gobkc<1?o9^LX4okjbc`Co`[38
1?naZ]43okZXb0Oo[JK@0_nW/Ml5ojbObPOoZ:CB00?oYj_JojRIaonXVLL00onXVLL6oj>Hb@GoWYG:
1_nITL/6oi6>c0KoS8k@0on;U=L4oibfj@?o/=Cc1OnijOD2okWXm@Ko]MSb0_n^b^h5ojS1j`KoY[kZ
2?nY`^`5ojS0j`;oYko[1onV_^/3ojNoj`[oZ<7/0_nW`>/9ojNoj`03o`000?nW_n_oYko[00;oZ<3[
1OnX`N`6ojS0j`;oYl3[1OnW_n/4ooooo`03o`000?oooooooooo00Gooooo000Pooooo`03o`000?oo
oooooooo03;ooooo1_nV_n`7ojNoj`SoZL7[1OnW`>/2ojFok0KoY;o/1_nX`>/00onT_ncoXko]oj>o
k@04oj>ok@GoSKOc1OmTYOD5ogjam@?o^<CT1?nha^@5olg3d@Gob/7A0oo;_<`5olVibP?o_[;?1Oo2
/<P3ok6Zd@Go^ZS81On]Y]000onfY<Ko[9o:ojbObP05ojbObPKoZ:CB00?o[Ic6ojRIaonXVLL01?nX
VLL6oj>Hb@KoWYG:1_nITL/3oi6>c0;oUYOC1_nDWm/8oibfj@03ok3DlonijOGo^NWe00;o^NWe1Oni
j?D3okGHlP?o[<O]1onX`N/2ojJnjPcoZL;/00?oZ<3[ojNojonW_n/01?nW_n/5ojJnj`03ojNojonX
`NcoZ<7/00[oZ<7/0_nW`>/;ojNoj`03o`000?nX`>_oZ<7/00OoZ<7/0onX`>/2ojO0j`SoYko[0ooo
ool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`0booooo`KoY[o/1OnW_n/3
ojO0j`OoZL7[1_nW`>/7ojBok0?oZ<3[0onY`>/7oj>ok@GoSKOc1OmTYOD5ogjam@03okS4i?nha^Co
^<KT00Co^<KT0oo=`m47ol[1d@03ol^lc?o9^L[obKW:00GobKW:00?o_[;?ol:`b?o2/<P01Oo2/<P0
0onaZ]7o^ZS8okZXb004okZXb0?o[JK@1?nfY<H6ojbObPCoZ:CB1?n]W<H6ojRIa`GoXiS91_nNULX3
oiVAb`?oVIG>1_nFUm<6oiBOf`KoW;KY0on`h?L00onijOGo^NSeokWXm@04okWXm@03ojo>l?n/ango
[<O]00Go[<O]1OnX`N/2ojJoj`[oZL;/0onW`>/8ojNoj`03ojJnjonW_n_oYko[00?oYko[2?nX`N`6
ojO0j`SoYko[0_nX`>/00ol0003oZ<3[ojS0j`06ojS1k003ojS0jonW`>_oYl3[00CoYl3[1onW_n/4
ooooo`03o`000?oooooooooo00Cooooo000Rooooo`03o`000?oooooooooo03;ooooo1_nV_n`00onW
_n_oYl3[ojO0j`05ojO0j`GoZL7[0_nY`>/6ojO0j`OoY;o/1_nY`>/7oj>ok@KoSKSc1?mQYoL5og^d
m`Oo^<KT00?ocL?Aol[1dOo:`M401Oo:`M400oo7`]GobKW:olVibP05olVibP03olNhc?o2/<So`[38
00Go`[3800?o`[79okZXb?njZ<P01_njZ<P00on]Y]3o]ZC6okJTaP03okJTaPOo[9o:00?oZ:CBojfL
a_n]W<H01?n]W<H6ojRIa`KoXiS90onNULX2oijFc0OoVIG>1_nFUm<6oiBOf`;oW;KY1On`h?L4ok?]
m`03okWXmOn_c_3o[lk`00?o[lk`1on/and00onX`N_oY[o[ojJoj`04ojJoj`OoZL;/1_nW`>/6ojNo
j`03ojJnjonW_n_oYko[00GoYko[1_nX`N`8ojO0j`KoYko[1?nX`>/00ol0003oZ<3[ojS0j`02ojS1
k0GoZ<3[1_nW`>/7ojNoj`?ooooo00?o0000ooooooooool01?ooool002?ooooo0_l0000cooooo`Oo
Y[o/1onW`>/00onY`N_oZL3[ojW0j`04ojW0j`KoYl3[1onT_n`6ojW0j`OoXko]1_n=^?<4of6Wm`Go
NkCg1Onha^@2ok?7j@Kob/7A0oo7`]D5olVibP?oakS<1Oo2/<P3ol:ab@Ko^ZS800?o_J_8okJTa_nf
Y<H01OnfY<H5ojbObP03ok:Qa_n]W<Ko[Ic600Go[Ic61onXVLL3oj>Hb@;oY9W:1_nNU/`6oiVEcPKo
UYOC1OnDWm/3ojSBmP?o/>3g1OnckOL00oncfoCo[lk`ojo>l005ojo>l0?o[<O]0onW_nX8ojJoj`Oo
ZL;/1_nW`>/2ojNoj`GoY[k[1OnW_n/2ojS2k0KoZ<7/1_nW`>/8ojNoj`?oZ<3[00?oZ<7/o`000?nX
`N`02?nX`>/3ojO0j`[oYko[0_ooool00ol0003oooooooooo`04ooooo`009Oooool00ol0003ooooo
ooooo`0booooo`KoY[o/1OnW`>/2ojS0j`OoZL3[1_nW`>/7ojBok0KoZL3[1onS_nd3ohfhl`?oT;[c
0omOZOP00omQYoOoNkCgog^dm`03og^dm`03okS6i?ncanWo/lOY00Co/lOY0oo:`M46olO2e@?obKW:
1Oo7^<`3ol:`b0Go`[791?njZ<P3okf[b0Ko]ZC60on/WlX4ok:QaPOo[Ic61OnXVLL00onYWL[oY9W:
ojBIbP04ojBIbPKoWYK<1OnIULh7oiJGd`03oiBOfonXd_KoZ=;f00GoZ=;f00?o/>3gok?]monckOL0
0_nckOL4ok?Km0Go[lk`0_nY`^`6ojNojPKoY[o[00?oZL?/ojW2k?nY`^`01_nY`^`3ojO0j`;oYkk[
2?nV_^/00onW_n_oZ<;/ojS2k004ojS2k0KoZ<7/0_nW`>/:ojNoj`;oZ<3[1?nX`N`00ol0003oZ<7/
ojS0j`05ojS0j`03ojO0jonW_n_oYko[00[oYko[00CoZ<3[oooooooooooo00001_ooool002Kooooo
00?o0000ooooooooool0<_ooool6ojJok003ojO0jonX`>_oZ<3[00CoZ<3[1onY`>/6ojO0j`OoY;o/
1_nY`>/5oj>ok@;oY;o/1_n@^_<4oenYn0GoLkGj1oncanT00oo:`M7oal;EolO2e@06olO2e@03olVi
b_o7^<coakS<00GoakS<00?o`[38ol:abOo2/LT01?o2/LT3okZXb0Co_J_81onfY<H00on/Wl[o/Z76
ok:QaP03ok:QaPOo[Ic60_nXVLL5ojVMbPGoY9W:1_nNU/`6oiVEcP?oUYOC1?nO_^l6ojSBmP?oZn_i
00?o/nggok?Km?ncfo@01Oncfo@00on_c_3oZL;/ojW2k004ojW2k0KoYkoZ0_nV_n/5ojW3k0KoZL;/
00?oYko[ojNnjonW_^/01?nW_^/6ojJnj`03ojO0jonX`^coZ<;/00KoZ<;/0onX`N`2ojO0j`WoYko[
1_nX`>/3ojS1k003o`000?nX`NcoZ<7/00;oZ<3[1OnW`>/8ojNoj`GoZ<3[00?oooooo`000?ooool0
1Oooool002Oooooo00?o0000ooooooooool0<_ooool6ojJok0OoZ<3[1onY`>/6ojO0j`OoY;o/1_nY
`>/00onS_ngoY;o/ojBok004ojBok0KoT;[c1?mOZOP5og>enPGo/lOY0_nUb?87olO2e@03ol;9goo7
^<coakS<00GoakS<00?oa;kDol:abOo2/LT01_o2/LT00onjZ<So_J_8okf[b004okf[b0Go]ZC600?o
^:W:ok:Qa_nbXLH01OnbXLH5ojfLaP03ojnSc?nYWL[oZIg:00GoZIg:1_nTVLX6oijFc0?oVIG>0onO
/nH7oinnk`;oZ=;f1On[joT3ok3Vn0Go/m_d0_n[a^h7ojW2k0?oYkoZ1?nW`N`6ojW3k0;oZL;/1OnW
_n/6ojNnj`;oY[k[1OnW`>/6ojS2k003ojS1jonW`>_oYl3[00CoYl3[1onW_n/8ojS0j`?oZ<7/00?o
0000ojS0jonW`>/01onW`>/7ojNoj`KoZ<3[00?o0000ooooooooool01?ooool002Sooooo0_l0000c
ooooo`KoY[o/1onX`>/7ojW0j`KoYl3[1onT_n`3ojW0j`?oZ<7[1onT_n`3oi2jl`?oU[ca0omV[?P0
0omOZOSoLkGjog>enP03og>enP03ok?7jOnUb?;oYLSb00CoYLSb1?o7`]D4ol;9g`GoakS<0oo4_]@6
ol:ab@03ol6gdOnmZlSo_J_800Go_J_80onfY<H4okRYbPKo/Z760on]W<H4ojnSc0KoZIg:1_nTVLX5
oijFc003oj>_h?nO/nKoWk?V00GoWk?V1OnO_^l4ojGVn`03oj_[nOn`i_So/>Kh00Go/>Kh00?o/m_d
oj_6k_n[a^h01?n[a^h5ojW2k003ojJojonW`NcoYl7/00KoYl7/0onY`n`3ojS1j`OoYko[0onW_^/4
ojJnj`KoYl3[0_nX`^`5ojS1j`KoYl3[1onW_n/6ojS0j`03ojS1k?nX`>_oZ<3[00;oZ<3[00?o0000
ojS0jonW`>/01OnW`>/9ojNoj`?oZ<3[0_ooool00ol0003oooooooooo`04ooooo`00:_ooool00ol0
003oooooooooo`0aooooo`KoY[o/1onX`>/5ojW0j`;oZL3Z1_nW`>/7ojBok0KoZ<7[1OnT_n`2ojJo
j`KoU[ca1OmV[?P5ofJcn`KoYLSb00?oal;Eol;9goo2bMl01Oo2bMl3olNhc0Goa;kD1?o2/LT3ol6g
d@Oo_J_800?o]ZC6okRYb_nhZLX00onhZLX7ok:QaP03ojfLa_n_Xlco[j?<00?o[j?<1onYWLX6ojBI
bP03oijFc?nS[n3oXjoP00?oXjoP1onO/nH00onO_^ooYNKkojGVn`04ojGVn`?oY^[j0on`i_P4ojc;
l0OoZlK^00?oZL;/ojJojonV_n/00onV_n/6ojO1k003ojS2k?nX`N_oZ<7[00GoZ<7[1OnW_n/00onW
_^[oY[k[ojJnj`06ojJnj`?oYl3[0_nX`^`8ojS1j`?oYl3[2_nW_n/2ojS0j`GoZ<7/1?nX`>/01?l0
003oZ<3[ojO0jonW`>/;ojNoj`Oooooo00?o0000ooooooooool00oooool002_ooooo00?o0000oooo
ooooool0<Oooool6ojJok0OoZ<3[00?oZL3[ojW0j_nY`>X01?nY`>X6ojO0j`OoY;o/1_nX`N/00onT
_ncoY[o[ojJoj`04ojJoj`KoU[ca1OmV[?P5ofJcn`?oYLSb0on;a_/8ol;9g`03olNhc?o4_]Coa;kD
00Coa;kD0oo2/LT5ol6gd@Go_J_800?o_KKCokRYb_nhZLX01OnhZLX5ok:QaP03okB/dOn_Xlco[j?<
00Go[j?<1_nYWLX3ojBIbP?oYk3O1onS[n05oinciPCoXN7l00?oYNKkojKZn_nVj_X00onVj_X2oj_?
l`Oo[<_`0on[a^h3ojNnjPOoY[o[0_nW`N`5ojS2k0OoZ<7[00?oYko[ojNnj_nW_^X00onW_^X6ojJn
j`03ojS1k?nX`^coZ<;/00CoZ<;/1_nX`N/=ojNoj`WoZ<7/0onX`>/00ol0003oYko[ojNoj`09ojNo
j`[ooooo00?o0000ooooooooool00oooool002cooooo00?o0000ooooooooool0<Oooool6ojJok0Oo
Z<3[1onY`>X6ojO0j`OoY;o/1onX`N/6ojJoj`?oU[ca1?nL_Nl5ogFbn0GoF[3k1On;a_/6ol;9g`03
ojk?lOo4_]Coa;kD00Koa;kD00?o`[79ol6gdOo1]m401?o1]m43okf[b0Co_KKC1_nhZLX3ok:QaPCo
]:cA1_n_Xl`5ojVMbP03ojbgh_nW/=ooYk3O00GoYk3O1onS[n000onO/nKoXN7loj7Qo004oj7Qo0?o
W>Wj00?oY^[joj_?lon[co<01?n[co<5ojc;l0;oZ<3[1_nW_^X5ojJoj`;oZ<?]1onX`^`3ojS1j`?o
Yko[1onW_^X2ojJnj`GoZ<7/1_nX`^`2ojS1j`goYko[2onX`N`00onX`>_oYko[ojNoj`02ojNoj`03
o`000?nW_n_oYko[00GoYko[3Oooool00ol0003oooooooooo`03ooooo`00;Oooool2o`0003;ooooo
1_nV_n`7ojS0j`OoZL3Z1_nW`>/5ojBok0;oYKo/1onX`N/3ojJoj`?oZ;o[1onL_Nl5ogFbn0GoF[3k
1On;a_/2ol;9g`Go[/oa1_o4_]@00onkcnWo`KOAol6gd@06ol6gd@03okf[b?nm]]?o_KKC00Co_KKC
1_nhZLX00onbXLKo]:cAokB/d@04okB/d@Ko[j?<00?oZIg:ojbgh_n/]n800on/]n86ojN`g`KoXjoP
0onOgOd2oj7Qo0GoW>Wj0onZe?H6oj_?l`03ojc;l?nX`>_oZ<3[00CoZ<3[1_nW_^X00onV_n_oZ<?]
ojS3k@04ojS3k@GoZ<;/2?nW_n/5ojNnjP;oYko[1onX`N`3ojS2k0?oZ<3[3_nW_n/8ojS1k0GoZ<3[
1?nW_n/01?l0003oYko[ojNojonW_n/@ooooo`03o`000?oooooooooo00?ooooo000_ooooo`03o`00
0?oooooooooo033ooooo1onV_n`6ojS0j`OoZL3Z1_nW`>/00onT_ncoYKo/ojFok004ojFok0GoZ<7[
0_nW`>`6ojRoj`GoW;g_0_nQ_^d6ohRimPGoFZoj1Om]_oh6ojk?l@?oa;kD1?nkcnT6ol6gd@03ok_?
jOnm]]?o_KKC00Go_KKC1OnhZLX00oni_mko]:cAokB/d@05okB/d@Go[j?<00?o/<CYojbgh_n/]n80
1On/]n86ojN`g`;oXjoP1OnOgOd4oi?Wn`03oicYn_nZe?KoZ]Cf00GoZ]Cf0on[co<2ojS2k0SoZ<3[
0onW_^X3ojS2k@OoZ<?]00?oZ<;/ojNojonW_n/02_nW_n/00onW_^[oYko[ojNoj`04ojNoj`KoZ<7/
1onX`>/5ojNoj`03ojNnjonW_n_oYko[00KoYko[1OnX`N`8ojS0j`?oYko[00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`03ooooo`00<?ooool00ol0003oooooooooo`0aooooo`KoY[o/1onX
`>/6ojW0jPOoYl3[1_nU_n`00onX`N_oYl3/ojO0k004ojO0k0KoZ;o[00?oW;g_oj6nkOnQ_^d01?nQ
_^d6ohRimPGoFZoj1Om]_oh6ojk?l@03olBne?nkcnWo^loY00Co^loY0oo1]m44ok_?j@Oo_KKC00?o
^:W:okVog_ni_mh00oni_mh7okB/d@03ojnSc?n`a>Wo/<CY00?o/<CY1on/]n83ojN`g`GoW=cm00?o
Wmgmoi?WnonCio/01?nCio/2ojOFn0KoZ]Cf00?oZ<?]ojS2k?nX`^`01?nX`^`6ojS0j`03ojO0k?nX
`^goZ<;]00GoZ<;]0onX`nd3ojS0j`_oYko[0onW_^X7ojNoj`KoZ<7/1onX`>/00onW_n_oYkk[ojNn
j`03ojNnj`KoYko[1onX`N`6ojS0j`Gooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`03ooooo`00<Oooool00ol0003oooooooooo`0aooooo`OoY[o/1_nX`>/7ojW0jPOoYl3[1_nU_n`6
ojO0k0?oZ;o[0onY`N/7oj6nk@?oR;Wf0onI_O46og2dnPGoEkOl1_n3c?l6ok_?j@03ol6gdOnkcnWo
^loY00Co^loY1Onm]]<2ok7DlPKo^KoN1Ond[=42ojgCm0Ko/<CY1On/]n83oiOMoPGoW=cm1?n;i?/0
0onCio_oYmKhojOFn004ojOFn0;oZ]Cf1OnX`nd6ojS2k0;oZ<3[1OnW`>`5ojS2k@;oZ<7/1_nX`>/6
ojNoj`SoYkkZ0onW_n/3ojS2k0OoZ<7/0onX`>/3ojNoj`OoYkk[0_nW_n/;ojS1k0;oZ<3[2Oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo000booooo`;o0000<_ooool7ojJo
k0KoZ<3[1onY`>X5ojO0j`;oZ;o[1_nU_n`4ojO0k0?oYL3]1OnY`N/5oj6nk@;oY[k[1_nI_O46og2d
nPGoEkOl1_n3c?l3ok_?j@?oSM;n1onkcnT00onm]]?o/MCbok7DlP04ok7DlPKo^KoN00?o]:cAojgC
m?n]do@01?n]do@6ok34j@03ojbgh_nGgOkoUmgn00GoUmgn00?oW=cmoh_Tnon;i?/00_n;i?/4oj;D
n@GoYmKh0_nXa>h7ojS3k@?oZ<;/1?nW_n/6ojO0k003ojS2kOnX`NcoZ<7/00CoZ<7/1_nX`>/2ojNo
j`[oYkkZ0_nX`N`6ojS2k0GoZ<7/0_nW`>/6ojNoj`GoYkk[00?oYl3[ojS1k?nX`N`02OnX`N`>oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool003Cooooo00?o0000oooooooo
ool0<?ooool7ojJok0?oZ<3[0onW`>/7ojW0jP03ojO0jonX_n_oZ;o[00CoZ;o[1_nU_n`00onW`>co
YL3]ojG0k@04ojG0k@GoZL7[00?oXKk]ojJnjonV_^/01?nV_^/6oiVml@?oL;Cj1?n>_?D5of>fo0Go
G/3m1_n=d_h3ok_?j@CoRMGo1onae?83okVogPCoUmWn1_n]do@3ok34j@GoSMgn0onGgOh3oh?Pn`?o
Wm3i1_nRe?T00onWe_SoZ<C^ojS4kP04ojS4kPGoZ<?]2OnW_n/3ojO0k0?oZ<;/1onX`N`3ojS0j`_o
YkkZ1_nX`N`6ojS2k003ojS1k?nW`>_oYl3[00CoYl3[1_nW_n/00onW_^_oYl3[ojO0j`03ojO0j`Ko
Z<7/4_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo000eooooo`03o`00
0?oooooooooo033ooooo1onV_n`6ojO0j`OoZL3Z1onX_n/3ojFok0?oY[o/1onU`>d2ojW1j`CoZ<7/
1_nV_^/3oiVml@CoX[k]1_n>_?D5of>fo0GoG/3m0on=d_h4of76o0KoRMGo0onae?84og[EoPOoUmWn
0on]do@4oggJo@?oSMgn1Omnfo`00on3h?_oWm3ioio@n@05oio@n@?oX]Ci1?nW`nh6ojS4kP03ojS3
kOnW_n_oYko[00WoYko[00?oZ<;]ojS2k?nX`^`01OnX`^`5ojS1k003ojNojonW_^[oYkkZ00[oYkkZ
00?oYko[ojS1k?nX`N`01_nX`N`3ojS2k0;oZ<3[2?nW`>/6ojNoj`KoYl3[0_nX`N`Fooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool00_ooool003Kooooo00?o0000ooooooooool0<?oo
ool7ojJok0KoYl3[1onY`>X5ojRoj`;oZ;oZ1_nV_n`5ojG0k@;oYKo]1_nX`N`3ojJnj`?oZ<3[1onR
_^d3ohjlm@CoW[k_1_n6_?P5of:ko@GoHLKl0on9eOl5of79n`GoN]Gn0onGfOh5ofgCn`?oOM[m1On0
e_l3ogkKo0CoW/_g1OnOd?T2ojK2k@OoYl?^0onXa>h2ojNojPWoYko[1OnX`^d7ojS2k003ojS1k?nW
_n_oYko[00?oYko[2?nW_^X5ojNoj`OoZ<7/1_nX`>/6ojO0j`03ojNnjonW_n_oYko[00GoYko[0onW
`>/Kooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00_ooool003Oooooo0_l0000b
ooooo`KoY[o/0onW`>/4ojO0k0KoZL3Z00?oZ;o[ojRoj_nX_nX01?nX_nX6ojJok003ojG0kOnU_ngo
YKo]00CoYKo]1?nX`N`2ojK1k@KoZ<3[1OnR_^d2ojNnjPOoW[k_0on6_?P3oifnl0KoR;ki1_m[`Oh3
of79n`CoNlCn1_m[cOd3ofgCn`GoQlgn0on0e_l4oio7m0KoW/_g00?oWm3iojK2kOnV`^d01?nV`^d5
ojO3kPOoYkoZ1_nW_n/00onW`ngoZ<;]ojS2k@05ojS2k@?oZ<;/2_nW_n/3ojNnjP[oYko[1onX`N`6
ojS0j`;oYl3[1OnW_^/5ojNojb3ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`02
ooooo`00>Oooool00ol0003oooooooooo`0`ooooo`KoY[o/1onW`>`6ojW0jPOoZ;oZ0onV_n`4ojNo
j`KoYKo]00?oZ<7/ojK1kOnV`Nd00onV`Nd6ojS0j`03oj:nkOnW_^[oYkkZ00CoYkkZ1OnN_^l2ojJn
j`KoWKk`1_n8__T3of_1oPCoT/7g1_mka?h3of_=o@GoT/Gi0on7cOh3oj73l@OoWlOd0onNboL3ojK1
k@OoY/;]00?oYl?^ojNoj_nW_nX02OnW_nX2ojNoj`GoYl?]1OnX`^d2ojO0j`_oYko[0_nW_^X:ojNo
j`?oZ<;/1onX`N`3ojS0j`?oYko[1onW_^/00onW_n_oooooooooo`0Qooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool00_ooool003[ooooo00?o0000ooooooooool0<?ooool6ojJok0Go
Yl3/0_nV`>`6ojW0jPGoZ;oZ0_nY`>X7ojNoj`?oYKo]0onU_n`6ojK1k@?oZ<3[1?nX`N`6ojNnjP03
oijnkonV_^_oY[k[00CoY[k[1_nM__03ohRnn@CoWko_1_nB`OL3og_4oPCoWL;b1OnBaOT00onS`>ko
XL?aoj73l@05oj73l@GoWlOd00?oY[o[ojK1kOnV`Nd01OnV`Nd3ojK2k@goYkoZ2_nW`nd00onX`^go
Yl3[ojO0j`04ojO0j`OoYko[1_nW_^X5ojNoj`SoZ<;/1OnX`N`8ojNoj`?oYkk[:?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00;ooooo000kooooo`03o`000?oooooooooo033ooooo
1_nV_n`00onW`>coY/3/ojK0k004ojK0k0KoZL3Z00?oZ;oZojW0j_nY`>X01?nY`>X5ojNoj`;oZ;o[
1_nU_n`4ojK1k@;oYL3]1onX`N`3ojNnjP?oZL;/1onV_^/3oifnl0CoY[k[1_nO_nl3oi;1m`CoX[o]
1_nM`_800onBaOWoXl3^oj?0kP03oj?0kPOoXL?a00?oWlOdojJojonV_n/00onV_n/5ojK1k@;oZ;o[
2onW_nX2ojO2k@[oYl?]2_nW`>/3ojNoj`[oYkkZ00?oYko[ojS2k?nX`^`02_nX`^`00onX`NcoYko[
ojNoj`08ojNojbgooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`01ooooo`00??oo
ool00ol0003oooooooooo`0`ooooo`KoY[o/1onV`>`3ojW0jPCoZ<7[1_nY`>X00onW_n_oZ;o[ojRo
j`04ojRoj`KoYKo/00?oY/7]ojG0kOnU`>d00onU`>d5ojS1k0;oYL7]1_nY`^`5ojJnj`;oZL7[1onV
_^/3oinok`?oYkkZ1onR_nd3oig2lP?oY[k[1_nS`>h3oj73l@CoYkkZ1_nV_n/00onV`NgoZ;o[ojRo
j`04ojRoj`OoYkoZ1_nW`^d5ojO3k@coYl3[3?nW_^X3ojO1k0[oZ<;/1?nW`>/7ojNojc7ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`01ooooo`00?Oooool2o`00037ooooo1_nV_n`7
ojK0k0OoZ<7[1_nY`>X7ojRoj`?oYKo/0onW_n/6ojG0k@03ojS1k?nU`NgoYL7]00CoYL7]1_nY`^`0
0onV_^_oZL7[ojW1j`04ojW1j`GoY[k[0_nY`N`6ojNnjPGoX[o]00?oZ;o[ojJnjonV_^/01OnV_^/3
oj?0kP?oZ;o[1onW_^X3ojJoj`?oZ<7/1onX_n/3ojNojP[oYl;]00?oYl?]ojO0jonW`>/02OnW`>/<
ojNnjP;oYl3/1_nW`N`5ojS2k0;oZ<7[1onW`>/3ojNojcCooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`01ooooo`00?oooool00ol0003oooooooooo`0_ooooo`KoY[o/1onV`>`5ojS1
j`;oYl7/1_nY`>X5ojRoj`;oZ;oZ1_nW_n/3ojG0k@?oY[o/1onU`Nd3ojW2k0CoY/7]1_nY`N/00onV
_^_oZL7/ojW1k004ojW1k0KoYkkZ00?oX[o]ojRojonX_n/00onX_n/5ojJnj`;oZ<7/1_nX_n/5ojNn
jP;oZ<;/1_nX`N`5ojRoj`coYl;]2onW`>/<ojNnjPKoYl3/1_nW`N`00onX`^coZ<7[ojS1j`04ojS1
j`GoYl3[>Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo007ooooo0010ooooo`03
o`000?oooooooooo02oooooo0onV_n`4ojO0j`KoY/3/00?oZ<7[ojO1k?nW`N`01?nW`N`6ojW0jP03
ojRojonX_n[oZ;oZ00CoZ;oZ1?nW_n/2ojRojPKoY[o/1OnU`Nd2ojFok0OoY/7]0onY`N/3ojK1k@Oo
ZL7/0onW_^X3ojS2k0KoZ;o[00?oY[k[ojS1k?nX`N`01?nX`N`6ojRoj`03ojNnj_nX`^coZ<;/00Co
Z<;/1_nX`N`00onX_n_oYl;]ojO2k@09ojO2k@_oYl3[3OnW_^X3ojNoj`OoYl3/0onW`N`3ojS1k0Oo
Z<7[00?oYl3[ooooooooool0>oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo007o
oooo0011ooooo`03o`000?oooooooooo02oooooo1onW`>/3ojK0k0?oY[o/1onW`N`3ojW0jPCoZL7[
1_nX_nX00onW_n_oZ;oZojRojP03ojRojPKoY[o/00?oYL7]ojFok?nU_n`01?nU_n`5ojK1k@;oYKo/
1_nV`Nd5ojW1k003ojK1kOnX`^coZ<;/00GoZ<;/0onX_n/3ojO2k@OoZ<7/0onX_n/4ojO2k@KoZ<;/
0onX`N`;ojO2k@[oYl3[3OnW_^X8ojNoj`GoYl3/2?nX`N`3ojS1jd7ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`01ooooo`00@_ooool2o`00033ooooo1OnW`>/2ojNoj`KoY[o/1OnW
`N`2ojK0k0OoZL7[0onX_nX3ojW0jPKoZ;oZ0onV_n`4ojNoj`KoYKo/00?oY/7]ojFok?nU_n`01?nU
_n`6ojK1k@03ojW1k?nV`NgoY/7]00?oY/7]1OnX`^`2ojK1k@KoYl;]1OnX`N`2ojK1k@OoYl;]0onX
`^`2ojK1k0[oYl;]2onW`>/=ojNnjPcoYko[00?oYl3/ojS1k?nX`N`02?nX`Na6ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool00Oooool004Cooooo00?o0000ooooooooool0;_ooool0
0onW`>_oYko[ojNoj`04ojNoj`KoY[o/00?oYl7/ojK0k?nV`>`01?nV`>`5ojW1j`;oZ<7/1_nY`>X4
ojRojP;oZKoZ1onW_n/3ojFok0CoYko[1_nU_n`3ojK1k@CoYKo/1OnV`Nd00onX`^coY/7]ojK1k@04
ojK1k@KoYl;]00?oZ<7/ojK1kOnV`Nd01?nV`Nd5ojO2k@03ojK0k?nV`NcoY/7/00CoY/7/1OnW`^d2
ojNoj`[oYl3[3OnW_^X<ojNoj`CoYl7/1onX`Na:ooooo`03o`000?oooooooooo00Oooooo0Ol00001
ooooo`7ooooo0015ooooo`03o`000?oooooooooo02oooooo1_nW_n/7ojJok0KoY/3/00?oZL7[ojS1
k?nX`N`01?nX`N`6ojW0jP03ojRoj_nY_n[oZKoZ00?oZKoZ1OnW_n/2ojRojPOoYko[0onU_n`3ojNo
j`OoYKo/0_nV`Nd4ojJok0KoY/7]0onW`^d4ojK0k0KoY/7]00?oYl;]ojK0k?nV`>`00onV`>`6ojK1
k003ojO2kOnW_n_oYko[00CoYko[1OnW`>/2ojRnjP_oYkkZ2onW_n/3ojO2k0OoYl7/0onX`Na>oooo
o`03o`000?oooooooooo00Kooooo0Ol00001ooooo`7ooooo0016ooooo`03o`000?oooooooooo033o
oooo0_nW_n/3ojRoj`OoY[o/1onV`>`6ojS1k0?oZL3Z0onY`N/6ojVojP03ojNojonX_n[oZ;oZ00Co
Z;oZ1OnW_n/2ojRojPKoYko[1OnU_n`00onW_n_oY[o/ojJok005ojJok0?oY/7]0onW_n/7ojK0k0?o
Y/7]0onW_n/6ojK0k0?oY/7/2_nW_n/00onW`>_oZ;kZojRnjP04ojRnjPOoYkkZ2_nW_n/8ojO2k0Go
Yl7/D_ooool00ol0003oooooooooo`06ooooo`7o00000Oooool1ooooo`00Aoooool2o`00037ooooo
1OnX_n/5ojJok0;oYko[1onV`>`3ojS1k0?oY/3/1_nY`N/3ojVojPCoZL3[1_nX_nX00onW_n_oZ;oZ
ojRojP04ojRojPKoYko[00?oYKo/ojNojonW_n/00onW_n/5ojJok0;oZ;oZ1_nW_n/5ojK0k003ojNo
j_nW_n_oYko[00GoYko[0onV`>`3ojRojP[oYko[2_nX_^X3ojNnjP[oYko[3?nW`^`00onW`Ncooooo
ooooo`1Dooooo`03o`000?oooooooooo00Gooooo0Ol00001ooooo`7ooooo0019ooooo`03o`000?oo
oooooooo02oooooo1OnX_n/00onV_ncoYko[ojNoj`04ojNoj`GoY/3/0_nV_n`6ojK0k0CoZL7[0_nW
`N`7ojW0j`?oZ;oZ0onY`>X7ojRojP?oYko[0onX_nX6ojNoj`03ojJok?nX_n[oZ;oZ00CoZ;oZ1_nW
_n/00onV`>coYkoZojNojP03ojNojPGoYko[0_nX_^X6ojRojPGoYko[3OnX_^X00onX`>_oYko[ojNo
j`08ojNoj`goYl;/F_ooool00ol0003oooooooooo`04ooooo`7o00000Oooool1ooooo`00B_ooool0
0ol0003oooooooooo`0_ooooo`;oZ;o[1?nX_nX6ojNoj`03ojK0k?nV_ncoY[o/00CoY[o/1_nV`>`0
0onY`N_oYl7/ojO1k003ojO1k0GoZL3[0_nX`N`6ojW0jPGoZ;oZ00?oZL3ZojRoj_nX_nX01OnX_nX3
ojNoj`[oZ;oZ0onW_n/3ojRnjPKoYkoZ00?oYko[ojRnj_nX_^X01?nX_^X6ojRojP03ojNojonX_^[o
Z;kZ00_oZ;kZ1OnX`>/5ojNoj`;oYl7/2_nW`^aPooooo`03o`000?oooooooooo00?ooooo0Ol00001
ooooo`7ooooo001;ooooo`03o`000?oooooooooo02oooooo1_nX_nX3ojNoj`CoZ;o[1_nV_n`7ojK0
k0GoYl7/00?oZL3[ojS1k?nX`N`01?nX`N`6ojW0jP03ojRoj_nY`>[oZL3Z00?oZL3Z1OnX_nX2ojW0
j`goZ;oZ1_nX_^X3ojNojP?oZ;oZ1onX_^X7ojRojPWoZ;kZ2OnX`>/00onW_n_oYl7/ojO1k004ojO1
k0GoYl;/I?ooool00ol0003oooooooooo`03ooooo`7o00000Oooool1ooooo`00C?ooool2o`00033o
oooo1?nX_nX2ojW0jPOoZ;o[0onV_n`3ojNoj`OoY/3/0_nW`N`4ojK0k0KoZ<7/0onY`>X4ojS1k0Go
ZL3Z00?oZ;oZojW0jonY`>/01?nY`>/=ojRojPCoZ;kZ0_nX`>/6ojRojPGoZ;kZ0_nX`>/7ojRojP?o
Z;kZ0_nX`N`:ojS0j`[oYl7/00?oYl;/ooooooooool0I_ooool00ol0003oooooooooo`03ooooo`7o
00000Oooool004kooooo00?o0000ooooooooool0;_ooool00onX_n[oZL3ZojW0jP03ojW0jPGoZ;o[
0_nX_nX6ojNoj`GoY/3/00?oYko[ojK0k?nV`>`01OnV`>`3ojS1k0?oY/3/1onX`N`2ojW0jP?oZ<7/
1onY`>/3ojRojPCoZ<7[1_nX_nX00onX_^[oZ<3[ojS0j`03ojS0j`KoZ;oZ00?oZ;kZojS0jonX`>/0
1?nX`>/5ojRojP03ojO1k?nX`NcoZ<7/00CoZ<7/1OnX`>/<ojO1k6cooooo00?o0000ooooooooool0
0_ooool1o`00007ooooo001?ooooo`03o`000?oooooooooo02oooooo1OnY`>X00onX_n_oZ;oZojRo
jP04ojRojPKoYko[00?oY/3/ojNojonW_n/00onW_n/5ojK0k0;oY[o/1_nV`>`5ojS1k003ojK0k?nX
`NcoZ<7/00CoZ<7/1OnY`>/2ojO1k0OoZ<7[0onX_nX3ojS1k0KoZ<3[0onX_nX4ojS1k0KoZ<3[00?o
Z;oZojO1k?nW`N`00onW`N`6ojS1k003ojS0jonW`NcoYl7/00WoYl7/LOooool01Ol0003ooooooooo
oooooooo0000007ooooo001@ooooo`03o`000?oooooooooo02oooooo0_nY`>X3ojS1j`OoZ;oZ0onW
_n/4ojRojPGoYko[00?oY/3/ojJok?nV_n`01?nV_n`6ojK0k003ojS1k?nV`>coY/3/00?oY/3/1_nX
`N`00onY`>_oYl7/ojO1k004ojO1k0GoZ<7[00?oYl7/ojS1k?nX`N`01OnX`N`3ojS0j`?oYl7/1onX
`N`3ojS0j`WoYl7/0onX`N`;ojO1k7Cooooo00Go0000ooooooooooooooooo`000001ooooo`00DOoo
ool2o`00033ooooo1OnX`N/5ojRojP;oZ<3[1onX_nX6ojNoj`KoY[o/3?nV`>`3ojS1k0CoY/3/1_nW
`N`00onX`N_oYl7/ojO1k003ojO1k0GoZ<7/0_nV`N`6ojO1k0GoZ<7/2onW`N`3ojO0k0[oYl7/N?oo
ool01?l0003oooooooooool00001ooooo`00Doooool00ol0003oooooooooo`0^ooooo`GoZ<7[00?o
Z;oZojS0jonX`>/01?nX`>/6ojRojPOoYko[0onV_n`3ojNoj`WoY/3/1?nW`>`6ojK0k0?oYl7/0onV
`>`6ojO1k003ojS1k?nV`NcoY/7/00CoY/7/1_nW`N`00onX`NcoYl7/ojO1k008ojO1k0;oYl3[1_nW
`>`5ojO1k7gooooo00?o0000ooooool000000Oooool005Cooooo00?o0000ooooooooool0;_ooool2
ojS1j`CoYl3/1_nX`>/6ojRojPGoYko[0_nX_nX6ojNoj`GoY/3/00?oYko[ojO0k?nW`>`01OnW`>`3
ojK0k0?oYko[1_nV`>`3ojO1k0CoY/3/1_nV`N`3ojO1k0?oYl3/1onW`N`6ojO0j`KoYl3/00?oYl7/
ooooooooool0O_ooool00ol0003oooooo`000001ooooo`00EOooool00ol0003oooooooooo`0^oooo
o`KoYl3/0onX`>/4ojS1j`GoZ;oZ00?oYko[ojRoj_nX_nX01?nX_nX6ojNoj`03ojK0k?nW_n_oYko[
00?oYko[1OnW`>`8ojNoj`CoY/3/0_nW_n/7ojK0k0?oY/7/0_nW_n/7ojO0k0?oYl7/1?nW_n/6ojO0
j`?oYl3/Q?ooool1o`00007ooooo0Ol0000005Kooooo0_l0000_ooooo`?oYl3/0onV`>`7ojS1j`;o
Z;oZ1?nX`N/6ojRojP?oYko[1?nX_nX5ojNoj`03ojO0k?nW_n_oYko[00[oYko[00?oY/3/ojNojonW
_n/00onW_n/5ojK0k0OoYko[1OnW`>`9ojNoj`?oYl3[R_ooool2o`000000F?ooool00ol0003ooooo
ooooo`0]ooooo`KoY/3/1OnX`N/2ojO0k0KoZ<7[0onX_nX3ojS0j`OoZ;oZ0_nW_n/4ojRojPWoYko[
0onX_nX6ojNoj`03ojK0k?nW_n_oYko[00WoYko[00?oYl3/ojNojonW_n/02OnW_n^=ooooo`?o0000
001Iooooo`03o`000?oooooooooo02gooooo1_nV`>`00onX`N_oYl3/ojO0k004ojO0k0CoZ<7[0_nW
`N`6ojS0j`GoZ;oZ00?oZ<3[ojRoj_nX_nX01OnX_nX3ojNoj`WoZ;oZ0onW_n/4ojRojPSoYko[1?nX
_nX7ojNojhcooooo1?l00003ooooo`00F_ooool00ol0003oooooooooo`0]ooooo`?oY/3/2_nW`>`0
0onX`N_oYl7/ojO1k003ojO1k0KoZ<3[00?oZ;oZojS0jonX`>/00onX`>/5ojRojP;oZ<7[4onX_nX3
ojNoj`WoZ;oZ0onW_n^<ooooo`?o00001oooool005_ooooo00?o0000ooooooooool0;_ooool9ojO0
k0?oY/3/1_nW`N`3ojS0j`CoYl7/1OnX`>/00onX_n[oZ<7[ojS1j`04ojS1ja7oZ;oZ00?oZ<3[ojRo
j_nX_nX02?nX_nZ=ooooo`Co00002_ooool005cooooo0_l0000_ooooo`?oYl3/0onW_n/6ojK0k0?o
Yl7/1?nV`>`6ojO1k0;oZ<3[1?nW`N`6ojS1j`?oZ;oZ0onX`N/7ojRojPGoZ<3[1OnX_nZ=ooooo`Co
00003_ooool005kooooo00?o0000ooooooooool0;Oooool6ojNoj`CoY/3/0_nW`>/7ojK0k0?oYl7/
0_nV`>`7ojO1k0?oZ<7[0onW`N`6ojS1j`?oZ;oZ1?nW`N`5ojS0j`03ojRoj_oooooooooo08[ooooo
1?l0000Booooo`00Goooool00ol0003oooooooooo`0]ooooo`KoYko[00?oY/3/ojO0jonW`>/00onW
`>/5ojK0k0;oYl3[1OnV`>`5ojO1k0;oYl3/1_nW`N`3ojS1j`[oYl7/0_nX`>^;ooooo`Co00005_oo
ool0063ooooo00?o0000ooooooooool0;Oooool3ojNoj`CoZ;o[1OnW`>/00onV`>coYl3[ojO0j`04
ojO0j`GoY/3/00?oYl7/ojO0k?nW`>`01?nW`>`4ojO1k0;oYl3/2onW`Nb;ooooo`?o00006_ooool0
067ooooo0_l0000_ooooo`KoZ;o[0_nW`>/4ojNoj`KoYl3[0_nV`>`4ojO0j`KoYl3/00?oYl7/ojO0
k?nW`>`00onW`>`7ojO1k8[ooooo1?l0000Mooooo`00Hoooool00ol0003oooooooooo`0]ooooo`?o
Z;o[0_nX`>/7ojNoj`?oYl3[0onW_n/6ojO0j`?oYl3/0onW_n/6ojO0k0?oYl7/ROooool4o`00027o
oooo001Tooooo`03o`000?oooooooooo02gooooo1OnX`>/5ojNoj`;oZ;o[1_nW_n/3ojO0j`WoYko[
0onW`>b:ooooo`Co00009Oooool006Gooooo00?o0000ooooooooool0;Oooool5ojS0j`03ojNojonX
_n_oZ;o[00CoZ;o[1?nW_n/2ojRoj`WoYko[Roooool4o`0002Wooooo001Vooooo`;o0000;_ooool6
ojS0j`KoZ;o[00?oYko[ojRojonX_n/00onX_n/5ojNojh_ooooo0ol0000]ooooo`00J?ooool00ol0
003oooooooooo`0/ooooo`KoZ<3[0onX_n/3ojS0j`KoZ;o[00?oYko[ooooooooool0R?ooool4o`00
033ooooo001Yooooo`03o`000?oooooooooo02cooooo0onX`>/4ojO0k0GoZ<3[0onX_n^9ooooo`Co
0000=?ooool006[ooooo00?o0000ooooooooool0;?ooool7ojO0k0;oZ<3[R_ooool4o`0003Sooooo
001[ooooo`;o0000;Oooool5ojO0k8Wooooo1?l0000looooo`00KOooool00ol0003oooooooooo`0[
ooooo`03ojO0k?oooooooooo08Oooooo0ol00010ooooo`00K_ooool00ol0003oooooooooo`0Zoooo
o`03o`000?oooooooooo08?ooooo1?l00013ooooo`00Koooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo07oooooo1?l00017ooooo`00L?ooool2o`0002Wooooo00?o0000ooooooooool0
Noooool4o`0004_ooooo001booooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0Mooo
ool4o`0004oooooo001cooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0M?ooool3
o`0005?ooooo001dooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0L?ooool4o`00
05Kooooo001eooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0K?ooool4o`0005[o
oooo001fooooo`;o00008oooool00ol0003oooooooooo`1Xooooo`Co0000G_ooool007Sooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`1Tooooo`Co0000H_ooool007Wooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`1Qooooo`?o0000I_ooool007[ooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`1Mooooo`Co0000JOooool007_ooooo0_l0000Nooooo`03
o`000?oooooooooo05Wooooo1?l0001]ooooo`00OOooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo05Gooooo1?l0001aooooo`00O_ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo057ooooo1?l0001eooooo`00Ooooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo04kooooo0ol0001iooooo`00P?ooool2o`0001Wooooo00?o0000ooooooooool0B_ooool4o`00
07cooooo0022ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0A_ooool4o`00083o
oooo0023ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0@_ooool4o`0008Cooooo
0024ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0?_ooool4o`0008Sooooo0025
ooooo`;o00004oooool00ol0003oooooooooo`0looooo`?o0000S?ooool008Oooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0hooooo`Co0000Soooool008Sooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0dooooo`Co0000Toooool008Wooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0`ooooo`Co0000Uoooool008[ooooo0_l0000>ooooo`03o`000?oo
oooooooo02cooooo1?l0002Kooooo`00S?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo02Wooooo0ol0002Oooooo`00SOooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
02Gooooo1?l0002Rooooo`00S_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo027o
oooo1?l0002Vooooo`00Soooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01gooooo
1?l0002Zooooo`00T?ooool2o`0000Sooooo00?o0000ooooooooool06Oooool4o`000:kooooo002B
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05_ooool3o`000;;ooooo002Coooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04_ooool4o`000;Gooooo002Dooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool03_ooool4o`000;Wooooo002Eooooo`;o0000
0oooool00ol0003oooooooooo`0:ooooo`Co0000_Oooool009Oooooo00Co0000oooooooooooo0000
2?ooool4o`000<7ooooo002Hooooo`03o`000?oooooo000000Gooooo0ol00035ooooo`00VOooool2
o`000003ooooool0003o000000;o0000b?ooool009[ooooo0_l0003<ooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0538698, 0.0432538, \
0.0035044, 0.0035044}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[.12586 .2075 -12 -8.99448 ]
[.12586 .2075 0 .00552 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.56094 .0364 -5.16972 -9 ]
[.56094 .0364 .83028 0 ]
[.75679 .08071 0 -6.17777 ]
[.75679 .08071 12 2.82223 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.9429 .3657 0 -5.9083 ]
[.9429 .3657 6 3.0917 ]
[.02494 .25992 -18 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.01611 .31527 -18 -2.78472 ]
[.01611 .31527 0 6.21528 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00254 .43215 -12 -2.88407 ]
[-0.00254 .43215 0 6.11593 ]
[-0.0124 .49393 -12 -2.93688 ]
[-0.0124 .49393 0 6.06312 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
[(-2)] .12586 .2075 1 .99877 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.56863 .04703 m
.57247 .05235 L
s
[(2)] .56094 .0364 .72324 1 Mshowa
.125 Mabswid
.18558 .19702 m
.18832 .19985 L
s
.23703 .17687 m
.23971 .17975 L
s
.28951 .15632 m
.29214 .15925 L
s
.39772 .11395 m
.40023 .11699 L
s
.4535 .09211 m
.45595 .0952 L
s
.51046 .06981 m
.51284 .07294 L
s
.08568 .23614 m
.08851 .23887 L
s
.62804 .02377 m
.63027 .02701 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.7445 .0853 m
.73835 .08759 L
s
[(-2)] .75679 .08071 -1 .37284 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.93037 .36962 m
.92411 .37158 L
s
[(2)] .9429 .3657 -1 .31296 Mshowa
.125 Mabswid
.7708 .12553 m
.7671 .12688 L
s
.79613 .16428 m
.79242 .1656 L
s
.82054 .20161 m
.81682 .20291 L
s
.86679 .27235 m
.86305 .2736 L
s
.88871 .30589 m
.88497 .30711 L
s
.9099 .3383 m
.90615 .3395 L
s
.71716 .04348 m
.71349 .04489 L
s
.95018 .39992 m
.94642 .40107 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(-20)] .02494 .25992 1 -0.39157 Mshowa
.02837 .31059 m
.0345 .30825 L
s
[(-10)] .01611 .31527 1 -0.38117 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.00981 .42772 m
.01599 .4255 L
s
[(10)] -0.00254 .43215 1 -0.3591 Mshowa
0 .48963 m
.0062 .48748 L
s
[(20)] -0.0124 .49393 1 -0.34736 Mshowa
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.656 .752 .92 r
.39362 .69483 .40169 .70187 .4152 .69807 .40717 .69097 Mtetra
.657 .751 .919 r
.40717 .69097 .4152 .69807 .42878 .69422 .42079 .68707 Mtetra
.656 .751 .919 r
.42079 .68707 .42878 .69422 .44242 .69035 .43448 .68317 Mtetra
.655 .751 .92 r
.43448 .68317 .44242 .69035 .45614 .68646 .44824 .6793 Mtetra
.654 .752 .922 r
.44824 .6793 .45614 .68646 .46992 .6826 .46207 .67543 Mtetra
.655 .753 .922 r
.46207 .67543 .46992 .6826 .48378 .67873 .47597 .67149 Mtetra
.656 .752 .92 r
.47597 .67149 .48378 .67873 .4977 .67483 .48994 .66751 Mtetra
.657 .751 .919 r
.48994 .66751 .4977 .67483 .5117 .67087 .50398 .66348 Mtetra
.657 .75 .919 r
.50398 .66348 .5117 .67087 .52577 .66689 .5181 .65944 Mtetra
.5181 .65944 .52577 .66689 .53991 .66286 .53229 .65539 Mtetra
.655 .75 .92 r
.53229 .65539 .53991 .66286 .55412 .65882 .54655 .65139 Mtetra
.654 .752 .921 r
.54655 .65139 .55412 .65882 .56841 .65478 .56088 .64737 Mtetra
.654 .753 .922 r
.56088 .64737 .56841 .65478 .58277 .65075 .57529 .64332 Mtetra
.655 .754 .923 r
.57529 .64332 .58277 .65075 .59721 .64671 .58978 .63923 Mtetra
.656 .754 .922 r
.58978 .63923 .59721 .64671 .61172 .64265 .60434 .6351 Mtetra
.656 .753 .922 r
.60434 .6351 .61172 .64265 .6263 .63856 .61898 .63094 Mtetra
.656 .752 .921 r
.61898 .63094 .6263 .63856 .64097 .63444 .6337 .62676 Mtetra
.656 .752 .92 r
.6337 .62676 .64097 .63444 .65571 .6303 .64849 .62256 Mtetra
.656 .751 .92 r
.64849 .62256 .65571 .6303 .67053 .62612 .66336 .61834 Mtetra
.66336 .61834 .67053 .62612 .68542 .62192 .67831 .6141 Mtetra
.67831 .6141 .68542 .62192 .7004 .6177 .69334 .60984 Mtetra
.69334 .60984 .7004 .6177 .71545 .61344 .70845 .60556 Mtetra
.656 .752 .921 r
.70845 .60556 .71545 .61344 .73058 .60916 .72364 .60126 Mtetra
.72364 .60126 .73058 .60916 .7458 .60484 .73891 .59693 Mtetra
.656 .753 .922 r
.73891 .59693 .7458 .60484 .76109 .6005 .75427 .59257 Mtetra
.656 .754 .922 r
.75427 .59257 .76109 .6005 .77647 .59613 .7697 .58818 Mtetra
.657 .755 .922 r
.7697 .58818 .77647 .59613 .79193 .59175 .78522 .58373 Mtetra
.657 .754 .922 r
.78522 .58373 .79193 .59175 .80747 .58739 .80082 .57926 Mtetra
.657 .752 .92 r
.80082 .57926 .80747 .58739 .8231 .58302 .8165 .57477 Mtetra
.655 .75 .919 r
.8165 .57477 .8231 .58302 .83882 .57863 .83228 .57031 Mtetra
.655 .749 .919 r
.83228 .57031 .83882 .57863 .85462 .57419 .84814 .56585 Mtetra
.655 .75 .92 r
.84814 .56585 .85462 .57419 .87051 .56972 .86409 .56137 Mtetra
.655 .751 .92 r
.86409 .56137 .87051 .56972 .88647 .5652 .88013 .55684 Mtetra
.656 .752 .921 r
.88013 .55684 .88647 .5652 .90253 .56063 .89625 .55226 Mtetra
.657 .753 .921 r
.89625 .55226 .90253 .56063 .91867 .55605 .91246 .54762 Mtetra
.91246 .54762 .91867 .55605 .93491 .5515 .92876 .54295 Mtetra
.655 .751 .92 r
.92876 .54295 .93491 .5515 .95124 .54692 .94515 .53832 Mtetra
.655 .75 .92 r
.94515 .53832 .95124 .54692 .96766 .54232 .96164 .53368 Mtetra
.655 .751 .92 r
.96164 .53368 .96766 .54232 .98417 .53765 .97822 .529 Mtetra
.657 .751 .919 r
.38547 .6877 .39362 .69483 .40717 .69097 .39906 .68379 Mtetra
.656 .751 .919 r
.39906 .68379 .40717 .69097 .42079 .68707 .41273 .67987 Mtetra
.655 .751 .92 r
.41273 .67987 .42079 .68707 .43448 .68317 .42646 .67599 Mtetra
.654 .752 .922 r
.42646 .67599 .43448 .68317 .44824 .6793 .44026 .6721 Mtetra
.656 .753 .921 r
.44026 .6721 .44824 .6793 .46207 .67543 .45414 .66813 Mtetra
.657 .752 .92 r
.45414 .66813 .46207 .67543 .47597 .67149 .46808 .66412 Mtetra
.657 .751 .919 r
.46808 .66412 .47597 .67149 .48994 .66751 .4821 .66007 Mtetra
.657 .75 .919 r
.4821 .66007 .48994 .66751 .50398 .66348 .49619 .65602 Mtetra
.655 .75 .919 r
.49619 .65602 .50398 .66348 .5181 .65944 .51035 .65201 Mtetra
.654 .751 .921 r
.51035 .65201 .5181 .65944 .53229 .65539 .52459 .648 Mtetra
.654 .753 .923 r
.52459 .648 .53229 .65539 .54655 .65139 .5389 .64397 Mtetra
.655 .754 .922 r
.5389 .64397 .54655 .65139 .56088 .64737 .55329 .63986 Mtetra
.656 .753 .921 r
.55329 .63986 .56088 .64737 .57529 .64332 .56775 .63573 Mtetra
.656 .752 .92 r
.56775 .63573 .57529 .64332 .58978 .63923 .58228 .63156 Mtetra
.657 .751 .919 r
.58228 .63156 .58978 .63923 .60434 .6351 .59689 .62736 Mtetra
.657 .75 .919 r
.59689 .62736 .60434 .6351 .61898 .63094 .61158 .62313 Mtetra
.657 .749 .918 r
.61158 .62313 .61898 .63094 .6337 .62676 .62635 .61889 Mtetra
.62635 .61889 .6337 .62676 .64849 .62256 .64119 .61463 Mtetra
.656 .748 .918 r
.64119 .61463 .64849 .62256 .66336 .61834 .65612 .61036 Mtetra
.65612 .61036 .66336 .61834 .67831 .6141 .67112 .60608 Mtetra
.67112 .60608 .67831 .6141 .69334 .60984 .6862 .60178 Mtetra
.6862 .60178 .69334 .60984 .70845 .60556 .70137 .59747 Mtetra
.655 .748 .918 r
.70137 .59747 .70845 .60556 .72364 .60126 .71662 .59315 Mtetra
.655 .749 .919 r
.71662 .59315 .72364 .60126 .73891 .59693 .73195 .58881 Mtetra
.655 .75 .919 r
.73195 .58881 .73891 .59693 .75427 .59257 .74736 .58444 Mtetra
.655 .751 .92 r
.74736 .58444 .75427 .59257 .7697 .58818 .76286 .58004 Mtetra
.656 .752 .921 r
.76286 .58004 .7697 .58818 .78522 .58373 .77844 .5756 Mtetra
.656 .753 .921 r
.77844 .5756 .78522 .58373 .80082 .57926 .7941 .57113 Mtetra
.657 .754 .922 r
.7941 .57113 .80082 .57926 .8165 .57477 .80985 .56658 Mtetra
.80985 .56658 .8165 .57477 .83228 .57031 .82568 .562 Mtetra
.657 .752 .92 r
.82568 .562 .83228 .57031 .84814 .56585 .8416 .55742 Mtetra
.655 .75 .919 r
.8416 .55742 .84814 .56585 .86409 .56137 .85761 .55289 Mtetra
.655 .749 .919 r
.85761 .55289 .86409 .56137 .88013 .55684 .87371 .54835 Mtetra
.655 .75 .92 r
.87371 .54835 .88013 .55684 .89625 .55226 .8899 .54375 Mtetra
.656 .751 .92 r
.8899 .54375 .89625 .55226 .91246 .54762 .90618 .53911 Mtetra
.657 .753 .921 r
.90618 .53911 .91246 .54762 .92876 .54295 .92254 .53439 Mtetra
.92254 .53439 .92876 .54295 .94515 .53832 .939 .52965 Mtetra
.655 .751 .92 r
.939 .52965 .94515 .53832 .96164 .53368 .95555 .52495 Mtetra
.655 .75 .92 r
.95555 .52495 .96164 .53368 .97822 .529 .9722 .52023 Mtetra
.657 .751 .919 r
.37724 .68049 .38547 .6877 .39906 .68379 .39088 .67655 Mtetra
.655 .751 .92 r
.39088 .67655 .39906 .68379 .41273 .67987 .40459 .67266 Mtetra
.654 .752 .922 r
.40459 .67266 .41273 .67987 .42646 .67599 .41836 .66875 Mtetra
.656 .753 .921 r
.41836 .66875 .42646 .67599 .44026 .6721 .43221 .66476 Mtetra
.657 .751 .92 r
.43221 .66476 .44026 .6721 .45414 .66813 .44613 .66073 Mtetra
.657 .751 .919 r
.44613 .66073 .45414 .66813 .46808 .66412 .46013 .65666 Mtetra
.656 .75 .919 r
.46013 .65666 .46808 .66412 .4821 .66007 .47419 .6526 Mtetra
.654 .75 .92 r
.47419 .6526 .4821 .66007 .49619 .65602 .48832 .64861 Mtetra
.654 .753 .922 r
.48832 .64861 .49619 .65602 .51035 .65201 .50253 .64459 Mtetra
.655 .754 .922 r
.50253 .64459 .51035 .65201 .52459 .648 .51682 .6405 Mtetra
.656 .753 .921 r
.51682 .6405 .52459 .648 .5389 .64397 .53118 .63636 Mtetra
.657 .751 .92 r
.53118 .63636 .5389 .64397 .55329 .63986 .54561 .63218 Mtetra
.658 .751 .919 r
.54561 .63218 .55329 .63986 .56775 .63573 .56012 .62795 Mtetra
.657 .749 .918 r
.56012 .62795 .56775 .63573 .58228 .63156 .57471 .62371 Mtetra
.657 .748 .917 r
.57471 .62371 .58228 .63156 .59689 .62736 .58937 .61946 Mtetra
.656 .748 .917 r
.58937 .61946 .59689 .62736 .61158 .62313 .60411 .61522 Mtetra
.655 .748 .918 r
.60411 .61522 .61158 .62313 .62635 .61889 .61893 .61099 Mtetra
.655 .75 .919 r
.61893 .61099 .62635 .61889 .64119 .61463 .63383 .60673 Mtetra
.655 .751 .92 r
.63383 .60673 .64119 .61463 .65612 .61036 .64881 .60244 Mtetra
.656 .752 .92 r
.64881 .60244 .65612 .61036 .67112 .60608 .66387 .59812 Mtetra
.66387 .59812 .67112 .60608 .6862 .60178 .67901 .59376 Mtetra
.656 .751 .92 r
.67901 .59376 .6862 .60178 .70137 .59747 .69422 .58936 Mtetra
.657 .75 .919 r
.69422 .58936 .70137 .59747 .71662 .59315 .70953 .58494 Mtetra
.656 .749 .918 r
.70953 .58494 .71662 .59315 .73195 .58881 .72491 .58053 Mtetra
.655 .748 .918 r
.72491 .58053 .73195 .58881 .74736 .58444 .74038 .57612 Mtetra
.655 .747 .918 r
.74038 .57612 .74736 .58444 .76286 .58004 .75594 .5717 Mtetra
.654 .748 .919 r
.75594 .5717 .76286 .58004 .77844 .5756 .77158 .56728 Mtetra
.655 .75 .92 r
.77158 .56728 .77844 .5756 .7941 .57113 .78731 .5628 Mtetra
.655 .751 .92 r
.78731 .5628 .7941 .57113 .80985 .56658 .80312 .55827 Mtetra
.656 .753 .921 r
.80312 .55827 .80985 .56658 .82568 .562 .81902 .55369 Mtetra
.657 .755 .922 r
.81902 .55369 .82568 .562 .8416 .55742 .835 .54904 Mtetra
.657 .754 .921 r
.835 .54904 .8416 .55742 .85761 .55289 .85106 .54436 Mtetra
.655 .75 .92 r
.85106 .54436 .85761 .55289 .87371 .54835 .86723 .53973 Mtetra
.655 .749 .919 r
.86723 .53973 .87371 .54835 .8899 .54375 .88349 .53512 Mtetra
.655 .75 .92 r
.88349 .53512 .8899 .54375 .90618 .53911 .89983 .53046 Mtetra
.656 .751 .92 r
.89983 .53046 .90618 .53911 .92254 .53439 .91627 .52575 Mtetra
.657 .753 .921 r
.91627 .52575 .92254 .53439 .939 .52965 .93279 .52095 Mtetra
.93279 .52095 .939 .52965 .95555 .52495 .94941 .51613 Mtetra
.655 .751 .92 r
.94941 .51613 .95555 .52495 .9722 .52023 .96612 .51136 Mtetra
.36894 .67323 .37724 .68049 .39088 .67655 .38262 .66931 Mtetra
.654 .752 .922 r
.38262 .66931 .39088 .67655 .40459 .67266 .39637 .66538 Mtetra
.656 .753 .921 r
.39637 .66538 .40459 .67266 .41836 .66875 .41019 .66138 Mtetra
.657 .751 .92 r
.41019 .66138 .41836 .66875 .43221 .66476 .42409 .65733 Mtetra
.657 .751 .919 r
.42409 .65733 .43221 .66476 .44613 .66073 .43805 .65324 Mtetra
.656 .75 .919 r
.43805 .65324 .44613 .66073 .46013 .65666 .45209 .64918 Mtetra
.654 .751 .921 r
.45209 .64918 .46013 .65666 .47419 .6526 .4662 .64518 Mtetra
.654 .753 .923 r
.4662 .64518 .47419 .6526 .48832 .64861 .48038 .64113 Mtetra
.656 .753 .922 r
.48038 .64113 .48832 .64861 .50253 .64459 .49464 .637 Mtetra
.657 .752 .92 r
.49464 .637 .50253 .64459 .51682 .6405 .50897 .63283 Mtetra
.658 .751 .919 r
.50897 .63283 .51682 .6405 .53118 .63636 .52338 .62858 Mtetra
.658 .749 .917 r
.52338 .62858 .53118 .63636 .54561 .63218 .53787 .62433 Mtetra
.656 .748 .917 r
.53787 .62433 .54561 .63218 .56012 .62795 .55243 .62011 Mtetra
.654 .749 .919 r
.55243 .62011 .56012 .62795 .57471 .62371 .56706 .61595 Mtetra
.654 .752 .922 r
.56706 .61595 .57471 .62371 .58937 .61946 .58178 .61176 Mtetra
.654 .754 .924 r
.58178 .61176 .58937 .61946 .60411 .61522 .59657 .60755 Mtetra
.654 .756 .925 r
.59657 .60755 .60411 .61522 .61893 .61099 .61145 .60329 Mtetra
.655 .757 .925 r
.61145 .60329 .61893 .61099 .63383 .60673 .6264 .59899 Mtetra
.6264 .59899 .63383 .60673 .64881 .60244 .64143 .59464 Mtetra
.655 .757 .924 r
.64143 .59464 .64881 .60244 .66387 .59812 .65655 .59028 Mtetra
.65655 .59028 .66387 .59812 .67901 .59376 .67174 .58588 Mtetra
.656 .757 .924 r
.67174 .58588 .67901 .59376 .69422 .58936 .68702 .58145 Mtetra
.68702 .58145 .69422 .58936 .70953 .58494 .70238 .57697 Mtetra
.657 .757 .924 r
.70238 .57697 .70953 .58494 .72491 .58053 .71782 .57245 Mtetra
.657 .755 .922 r
.71782 .57245 .72491 .58053 .74038 .57612 .73334 .56789 Mtetra
.657 .753 .92 r
.73334 .56789 .74038 .57612 .75594 .5717 .74895 .56331 Mtetra
.656 .749 .919 r
.74895 .56331 .75594 .5717 .77158 .56728 .76465 .55878 Mtetra
.654 .747 .918 r
.76465 .55878 .77158 .56728 .78731 .5628 .78044 .55428 Mtetra
.654 .748 .919 r
.78044 .55428 .78731 .5628 .80312 .55827 .79632 .54978 Mtetra
.655 .75 .92 r
.79632 .54978 .80312 .55827 .81902 .55369 .81228 .5452 Mtetra
.656 .751 .92 r
.81228 .5452 .81902 .55369 .835 .54904 .82833 .54057 Mtetra
.657 .754 .921 r
.82833 .54057 .835 .54904 .85106 .54436 .84446 .53586 Mtetra
.658 .754 .921 r
.84446 .53586 .85106 .54436 .86723 .53973 .86068 .53109 Mtetra
.656 .751 .92 r
.86068 .53109 .86723 .53973 .88349 .53512 .877 .52637 Mtetra
.654 .749 .92 r
.877 .52637 .88349 .53512 .89983 .53046 .89342 .52168 Mtetra
.655 .75 .92 r
.89342 .52168 .89983 .53046 .91627 .52575 .90992 .51695 Mtetra
.656 .751 .92 r
.90992 .51695 .91627 .52575 .93279 .52095 .92652 .51217 Mtetra
.657 .753 .921 r
.92652 .51217 .93279 .52095 .94941 .51613 .9432 .50729 Mtetra
.9432 .50729 .94941 .51613 .96612 .51136 .95998 .5024 Mtetra
.654 .752 .921 r
.36056 .66593 .36894 .67323 .38262 .66931 .37428 .662 Mtetra
.656 .753 .921 r
.37428 .662 .38262 .66931 .39637 .66538 .38808 .65799 Mtetra
.657 .752 .92 r
.38808 .65799 .39637 .66538 .41019 .66138 .40194 .65392 Mtetra
.658 .751 .919 r
.40194 .65392 .41019 .66138 .42409 .65733 .41588 .6498 Mtetra
.656 .75 .919 r
.41588 .6498 .42409 .65733 .43805 .65324 .42989 .64574 Mtetra
.653 .751 .921 r
.42989 .64574 .43805 .65324 .45209 .64918 .44397 .64172 Mtetra
.654 .753 .922 r
.44397 .64172 .45209 .64918 .4662 .64518 .45813 .63765 Mtetra
.656 .753 .921 r
.45813 .63765 .4662 .64518 .48038 .64113 .47236 .63349 Mtetra
.658 .752 .919 r
.47236 .63349 .48038 .64113 .49464 .637 .48667 .62926 Mtetra
.658 .75 .918 r
.48667 .62926 .49464 .637 .50897 .63283 .50105 .62499 Mtetra
.657 .748 .917 r
.50105 .62499 .50897 .63283 .52338 .62858 .51551 .62076 Mtetra
.653 .749 .92 r
.51551 .62076 .52338 .62858 .53787 .62433 .53004 .61663 Mtetra
.653 .753 .923 r
.53004 .61663 .53787 .62433 .55243 .62011 .54465 .61248 Mtetra
.654 .756 .925 r
.54465 .61248 .55243 .62011 .56706 .61595 .55934 .60827 Mtetra
.656 .756 .924 r
.55934 .60827 .56706 .61595 .58178 .61176 .57411 .60396 Mtetra
.656 .754 .922 r
.57411 .60396 .58178 .61176 .59657 .60755 .58896 .59964 Mtetra
.656 .753 .921 r
.58896 .59964 .59657 .60755 .61145 .60329 .60389 .5953 Mtetra
.656 .751 .92 r
.60389 .5953 .61145 .60329 .6264 .59899 .61889 .59094 Mtetra
.61889 .59094 .6264 .59899 .64143 .59464 .63398 .58656 Mtetra
.63398 .58656 .64143 .59464 .65655 .59028 .64915 .58214 Mtetra
.64915 .58214 .65655 .59028 .67174 .58588 .6644 .5777 Mtetra
.6644 .5777 .67174 .58588 .68702 .58145 .67973 .57324 Mtetra
.656 .752 .92 r
.67973 .57324 .68702 .58145 .70238 .57697 .69515 .56876 Mtetra
.655 .753 .921 r
.69515 .56876 .70238 .57697 .71782 .57245 .71066 .56425 Mtetra
.655 .754 .923 r
.71066 .56425 .71782 .57245 .73334 .56789 .72624 .55973 Mtetra
.657 .757 .923 r
.72624 .55973 .73334 .56789 .74895 .56331 .74191 .55511 Mtetra
.658 .757 .923 r
.74191 .55511 .74895 .56331 .76465 .55878 .75767 .55042 Mtetra
.658 .754 .921 r
.75767 .55042 .76465 .55878 .78044 .55428 .7735 .54572 Mtetra
.655 .749 .919 r
.7735 .54572 .78044 .55428 .79632 .54978 .78944 .54111 Mtetra
.654 .747 .918 r
.78944 .54111 .79632 .54978 .81228 .5452 .80547 .53654 Mtetra
.654 .749 .919 r
.80547 .53654 .81228 .5452 .82833 .54057 .82159 .53192 Mtetra
.655 .751 .92 r
.82159 .53192 .82833 .54057 .84446 .53586 .83779 .52723 Mtetra
.657 .753 .921 r
.83779 .52723 .84446 .53586 .86068 .53109 .85408 .52245 Mtetra
.658 .754 .921 r
.85408 .52245 .86068 .53109 .877 .52637 .87046 .5176 Mtetra
.656 .752 .92 r
.87046 .5176 .877 .52637 .89342 .52168 .88693 .5128 Mtetra
.654 .749 .92 r
.88693 .5128 .89342 .52168 .90992 .51695 .90351 .50804 Mtetra
.655 .75 .92 r
.90351 .50804 .90992 .51695 .92652 .51217 .92018 .50323 Mtetra
.656 .751 .92 r
.92018 .50323 .92652 .51217 .9432 .50729 .93693 .49836 Mtetra
.657 .753 .921 r
.93693 .49836 .9432 .50729 .95998 .5024 .95378 .4934 Mtetra
.655 .752 .921 r
.3521 .65859 .36056 .66593 .37428 .662 .36586 .65458 Mtetra
.657 .752 .92 r
.36586 .65458 .37428 .662 .38808 .65799 .3797 .6505 Mtetra
.658 .751 .919 r
.3797 .6505 .38808 .65799 .40194 .65392 .39362 .64636 Mtetra
.656 .75 .919 r
.39362 .64636 .40194 .65392 .41588 .6498 .4076 .64227 Mtetra
.653 .751 .921 r
.4076 .64227 .41588 .6498 .42989 .64574 .42165 .63824 Mtetra
.654 .753 .922 r
.42165 .63824 .42989 .64574 .44397 .64172 .43578 .63414 Mtetra
.656 .753 .921 r
.43578 .63414 .44397 .64172 .45813 .63765 .44999 .62996 Mtetra
.658 .751 .919 r
.44999 .62996 .45813 .63765 .47236 .63349 .46427 .62569 Mtetra
.658 .75 .917 r
.46427 .62569 .47236 .63349 .48667 .62926 .47862 .62141 Mtetra
.655 .748 .919 r
.47862 .62141 .48667 .62926 .50105 .62499 .49305 .61724 Mtetra
.652 .751 .922 r
.49305 .61724 .50105 .62499 .51551 .62076 .50756 .61312 Mtetra
.653 .755 .925 r
.50756 .61312 .51551 .62076 .53004 .61663 .52214 .60892 Mtetra
.656 .756 .923 r
.52214 .60892 .53004 .61663 .54465 .61248 .53681 .60462 Mtetra
.656 .753 .921 r
.53681 .60462 .54465 .61248 .55934 .60827 .55155 .60031 Mtetra
.656 .751 .92 r
.55155 .60031 .55934 .60827 .57411 .60396 .56637 .59598 Mtetra
.657 .752 .92 r
.56637 .59598 .57411 .60396 .58896 .59964 .58127 .59159 Mtetra
.655 .751 .92 r
.58127 .59159 .58896 .59964 .60389 .5953 .59625 .58723 Mtetra
.654 .751 .921 r
.59625 .58723 .60389 .5953 .61889 .59094 .61131 .58287 Mtetra
.655 .752 .922 r
.61131 .58287 .61889 .59094 .63398 .58656 .62645 .57848 Mtetra
.656 .754 .922 r
.62645 .57848 .63398 .58656 .64915 .58214 .64168 .57403 Mtetra
.657 .754 .922 r
.64168 .57403 .64915 .58214 .6644 .5777 .65699 .56951 Mtetra
.657 .753 .921 r
.65699 .56951 .6644 .5777 .67973 .57324 .67237 .56495 Mtetra
.656 .752 .92 r
.67237 .56495 .67973 .57324 .69515 .56876 .68785 .56039 Mtetra
.655 .751 .92 r
.68785 .56039 .69515 .56876 .71066 .56425 .70341 .55587 Mtetra
.656 .752 .92 r
.70341 .55587 .71066 .56425 .72624 .55973 .71906 .55129 Mtetra
.656 .751 .92 r
.71906 .55129 .72624 .55973 .74191 .55511 .73479 .54668 Mtetra
.655 .752 .921 r
.73479 .54668 .74191 .55511 .75767 .55042 .75061 .54206 Mtetra
.657 .756 .923 r
.75061 .54206 .75767 .55042 .7735 .54572 .76652 .53733 Mtetra
.659 .757 .923 r
.76652 .53733 .7735 .54572 .78944 .54111 .7825 .53252 Mtetra
.657 .753 .92 r
.7825 .53252 .78944 .54111 .80547 .53654 .79858 .52775 Mtetra
.654 .748 .919 r
.79858 .52775 .80547 .53654 .82159 .53192 .81477 .5231 Mtetra
.81477 .5231 .82159 .53192 .83779 .52723 .83104 .51844 Mtetra
.655 .751 .92 r
.83104 .51844 .83779 .52723 .85408 .52245 .8474 .51367 Mtetra
.657 .753 .921 r
.8474 .51367 .85408 .52245 .87046 .5176 .86385 .50882 Mtetra
.658 .754 .921 r
.86385 .50882 .87046 .5176 .88693 .5128 .88038 .50389 Mtetra
.656 .751 .92 r
.88038 .50389 .88693 .5128 .90351 .50804 .89702 .49902 Mtetra
.654 .749 .92 r
.89702 .49902 .90351 .50804 .92018 .50323 .91376 .49419 Mtetra
.655 .75 .92 r
.91376 .49419 .92018 .50323 .93693 .49836 .9306 .48929 Mtetra
.656 .752 .92 r
.9306 .48929 .93693 .49836 .95378 .4934 .94752 .48432 Mtetra
.34355 .65116 .3521 .65859 .36586 .65458 .35736 .64707 Mtetra
.658 .751 .919 r
.35736 .64707 .36586 .65458 .3797 .6505 .37125 .64292 Mtetra
.657 .75 .919 r
.37125 .64292 .3797 .6505 .39362 .64636 .38521 .63878 Mtetra
.653 .75 .921 r
.38521 .63878 .39362 .64636 .4076 .64227 .39923 .63473 Mtetra
.654 .753 .922 r
.39923 .63473 .4076 .64227 .42165 .63824 .41333 .63063 Mtetra
.656 .753 .921 r
.41333 .63063 .42165 .63824 .43578 .63414 .42751 .62643 Mtetra
.659 .752 .919 r
.42751 .62643 .43578 .63414 .44999 .62996 .44177 .62213 Mtetra
.658 .75 .917 r
.44177 .62213 .44999 .62996 .46427 .62569 .45609 .61783 Mtetra
.653 .748 .92 r
.45609 .61783 .46427 .62569 .47862 .62141 .4705 .61369 Mtetra
.652 .753 .924 r
.4705 .61369 .47862 .62141 .49305 .61724 .48497 .60956 Mtetra
.655 .756 .924 r
.48497 .60956 .49305 .61724 .50756 .61312 .49953 .60528 Mtetra
.656 .753 .922 r
.49953 .60528 .50756 .61312 .52214 .60892 .51417 .60098 Mtetra
.656 .751 .92 r
.51417 .60098 .52214 .60892 .53681 .60462 .52888 .59663 Mtetra
.655 .751 .92 r
.52888 .59663 .53681 .60462 .55155 .60031 .54367 .59231 Mtetra
.649 .75 .923 r
.54367 .59231 .55155 .60031 .56637 .59598 .55855 .58818 Mtetra
.642 .754 .93 r
.55855 .58818 .56637 .59598 .58127 .59159 .57351 .58423 Mtetra
.632 .764 .942 r
.57351 .58423 .58127 .59159 .59625 .58723 .58856 .58049 Mtetra
.633 .783 .954 r
.58856 .58049 .59625 .58723 .61131 .58287 .60369 .57659 Mtetra
.637 .799 .96 r
.60369 .57659 .61131 .58287 .62645 .57848 .61891 .57241 Mtetra
.645 .809 .962 r
.61891 .57241 .62645 .57848 .64168 .57403 .6342 .56792 Mtetra
.655 .812 .959 r
.6342 .56792 .64168 .57403 .65699 .56951 .64956 .5631 Mtetra
.664 .807 .951 r
.64956 .5631 .65699 .56951 .67237 .56495 .665 .558 Mtetra
.671 .795 .941 r
.665 .558 .67237 .56495 .68785 .56039 .68051 .55273 Mtetra
.666 .775 .931 r
.68051 .55273 .68785 .56039 .70341 .55587 .69611 .54767 Mtetra
.662 .76 .923 r
.69611 .54767 .70341 .55587 .71906 .55129 .7118 .54279 Mtetra
.657 .752 .92 r
.7118 .54279 .71906 .55129 .73479 .54668 .72759 .5381 Mtetra
.655 .751 .92 r
.72759 .5381 .73479 .54668 .75061 .54206 .74348 .53344 Mtetra
.656 .751 .92 r
.74348 .53344 .75061 .54206 .76652 .53733 .75945 .52873 Mtetra
.656 .753 .921 r
.75945 .52873 .76652 .53733 .7825 .53252 .77551 .52399 Mtetra
.659 .757 .923 r
.77551 .52399 .7825 .53252 .79858 .52775 .79164 .51909 Mtetra
.658 .755 .921 r
.79164 .51909 .79858 .52775 .81477 .5231 .80788 .5142 Mtetra
.654 .748 .919 r
.80788 .5142 .81477 .5231 .83104 .51844 .82421 .50947 Mtetra
.653 .748 .919 r
.82421 .50947 .83104 .51844 .8474 .51367 .84065 .50474 Mtetra
.655 .751 .92 r
.84065 .50474 .8474 .51367 .86385 .50882 .85717 .4999 Mtetra
.657 .753 .921 r
.85717 .4999 .86385 .50882 .88038 .50389 .87378 .49495 Mtetra
.658 .754 .921 r
.87378 .49495 .88038 .50389 .89702 .49902 .89047 .48994 Mtetra
.655 .751 .92 r
.89047 .48994 .89702 .49902 .91376 .49419 .90728 .48502 Mtetra
.654 .749 .92 r
.90728 .48502 .91376 .49419 .9306 .48929 .92419 .48011 Mtetra
.655 .751 .92 r
.92419 .48011 .9306 .48929 .94752 .48432 .94119 .47512 Mtetra
.657 .752 .919 r
.33493 .64362 .34355 .65116 .35736 .64707 .34879 .63946 Mtetra
.657 .751 .919 r
.34879 .63946 .35736 .64707 .37125 .64292 .36272 .63528 Mtetra
.654 .75 .92 r
.36272 .63528 .37125 .64292 .38521 .63878 .37671 .63119 Mtetra
.653 .752 .922 r
.37671 .63119 .38521 .63878 .39923 .63473 .39079 .62709 Mtetra
.656 .753 .921 r
.39079 .62709 .39923 .63473 .41333 .63063 .40494 .62288 Mtetra
.659 .752 .919 r
.40494 .62288 .41333 .63063 .42751 .62643 .41916 .61857 Mtetra
.659 .75 .917 r
.41916 .61857 .42751 .62643 .44177 .62213 .43346 .61424 Mtetra
.653 .748 .92 r
.43346 .61424 .44177 .62213 .45609 .61783 .44784 .61009 Mtetra
.651 .753 .924 r
.44784 .61009 .45609 .61783 .4705 .61369 .46229 .60596 Mtetra
.656 .756 .923 r
.46229 .60596 .4705 .61369 .48497 .60956 .47682 .60163 Mtetra
.655 .751 .921 r
.47682 .60163 .48497 .60956 .49953 .60528 .49142 .59734 Mtetra
.656 .752 .921 r
.49142 .59734 .49953 .60528 .51417 .60098 .50611 .59296 Mtetra
.646 .748 .924 r
.50611 .59296 .51417 .60098 .52888 .59663 .52087 .58894 Mtetra
.623 .751 .938 r
.52087 .58894 .52888 .59663 .54367 .59231 .53572 .5856 Mtetra
.599 .772 .962 r
.53572 .5856 .54367 .59231 .55855 .58818 .55067 .58266 Mtetra
.581 .802 .984 r
.55067 .58266 .55855 .58818 .57351 .58423 .5657 .57967 Mtetra
.569 .829 .994 r
.5657 .57967 .57351 .58423 .58856 .58049 .58083 .57644 Mtetra
.566 .845 .997 r
.58083 .57644 .58856 .58049 .60369 .57659 .59605 .57295 Mtetra
.575 .861 .996 r
.59605 .57295 .60369 .57659 .61891 .57241 .61135 .56899 Mtetra
.595 .875 .993 r
.61135 .56899 .61891 .57241 .6342 .56792 .62672 .56446 Mtetra
.621 .884 .989 r
.62672 .56446 .6342 .56792 .64956 .5631 .64215 .55934 Mtetra
.646 .884 .984 r
.64215 .55934 .64956 .5631 .665 .558 .65765 .55375 Mtetra
.664 .875 .978 r
.65765 .55375 .665 .558 .68051 .55273 .67322 .54789 Mtetra
.679 .863 .969 r
.67322 .54789 .68051 .55273 .69611 .54767 .68884 .54177 Mtetra
.688 .835 .953 r
.68884 .54177 .69611 .54767 .7118 .54279 .70455 .5356 Mtetra
.681 .797 .937 r
.70455 .5356 .7118 .54279 .72759 .5381 .72034 .52983 Mtetra
.665 .764 .924 r
.72034 .52983 .72759 .5381 .74348 .53344 .73627 .52473 Mtetra
.655 .751 .921 r
.73627 .52473 .74348 .53344 .75945 .52873 .7523 .52 Mtetra
.657 .752 .921 r
.7523 .52 .75945 .52873 .77551 .52399 .76842 .51519 Mtetra
.655 .751 .921 r
.76842 .51519 .77551 .52399 .79164 .51909 .78464 .5104 Mtetra
.659 .757 .922 r
.78464 .5104 .79164 .51909 .80788 .5142 .80093 .50541 Mtetra
.659 .755 .922 r
.80093 .50541 .80788 .5142 .82421 .50947 .81732 .50043 Mtetra
.654 .748 .919 r
.81732 .50043 .82421 .50947 .84065 .50474 .83382 .49564 Mtetra
.653 .748 .919 r
.83382 .49564 .84065 .50474 .85717 .4999 .85041 .49082 Mtetra
.655 .751 .92 r
.85041 .49082 .85717 .4999 .87378 .49495 .8671 .4859 Mtetra
.658 .753 .921 r
.8671 .4859 .87378 .49495 .89047 .48994 .88386 .48085 Mtetra
.657 .754 .921 r
.88386 .48085 .89047 .48994 .90728 .48502 .90073 .47577 Mtetra
.654 .75 .92 r
.90073 .47577 .90728 .48502 .92419 .48011 .91771 .4708 Mtetra
.655 .75 .92 r
.91771 .4708 .92419 .48011 .94119 .47512 .93478 .46579 Mtetra
.658 .751 .919 r
.32622 .636 .33493 .64362 .34879 .63946 .34012 .63178 Mtetra
.655 .75 .92 r
.34012 .63178 .34879 .63946 .36272 .63528 .3541 .62763 Mtetra
.653 .751 .922 r
.3541 .62763 .36272 .63528 .37671 .63119 .36814 .62354 Mtetra
.656 .753 .922 r
.36814 .62354 .37671 .63119 .39079 .62709 .38226 .61933 Mtetra
.658 .752 .919 r
.38226 .61933 .39079 .62709 .40494 .62288 .39646 .61501 Mtetra
.659 .75 .918 r
.39646 .61501 .40494 .62288 .41916 .61857 .41073 .61064 Mtetra
.653 .749 .92 r
.41073 .61064 .41916 .61857 .43346 .61424 .42508 .60645 Mtetra
.651 .753 .924 r
.42508 .60645 .43346 .61424 .44784 .61009 .4395 .60231 Mtetra
.656 .755 .923 r
.4395 .60231 .44784 .61009 .46229 .60596 .454 .59797 Mtetra
.656 .751 .92 r
.454 .59797 .46229 .60596 .47682 .60163 .46858 .59362 Mtetra
.653 .751 .921 r
.46858 .59362 .47682 .60163 .49142 .59734 .48323 .58935 Mtetra
.631 .746 .93 r
.48323 .58935 .49142 .59734 .50611 .59296 .49796 .5858 Mtetra
.586 .754 .958 r
.49796 .5858 .50611 .59296 .52087 .58894 .51278 .58334 Mtetra
.545 .787 .988 r
.51278 .58334 .52087 .58894 .53572 .5856 .52769 .58117 Mtetra
.494 .804 1 r
.52769 .58117 .53572 .5856 .55067 .58266 .54271 .57924 Mtetra
.469 .824 .996 r
.54271 .57924 .55067 .58266 .5657 .57967 .55782 .57697 Mtetra
.477 .847 .989 r
.55782 .57697 .5657 .57967 .58083 .57644 .57303 .57401 Mtetra
.504 .866 .986 r
.57303 .57401 .58083 .57644 .59605 .57295 .58833 .57039 Mtetra
.54 .879 .989 r
.58833 .57039 .59605 .57295 .61135 .56899 .6037 .56625 Mtetra
.569 .886 .99 r
.6037 .56625 .61135 .56899 .62672 .56446 .61916 .56167 Mtetra
.591 .894 .988 r
.61916 .56167 .62672 .56446 .64215 .55934 .63468 .55667 Mtetra
.611 .905 .985 r
.63468 .55667 .64215 .55934 .65765 .55375 .65027 .55113 Mtetra
.638 .916 .98 r
.65027 .55113 .65765 .55375 .67322 .54789 .66591 .54492 Mtetra
.675 .918 .974 r
.66591 .54492 .67322 .54789 .68884 .54177 .6816 .53799 Mtetra
.701 .903 .968 r
.6816 .53799 .68884 .54177 .70455 .5356 .69733 .53071 Mtetra
.704 .872 .961 r
.69733 .53071 .70455 .5356 .72034 .52983 .71314 .52367 Mtetra
.702 .836 .947 r
.71314 .52367 .72034 .52983 .73627 .52473 .72904 .5169 Mtetra
.676 .783 .93 r
.72904 .5169 .73627 .52473 .7523 .52 .74508 .51123 Mtetra
.658 .754 .921 r
.74508 .51123 .7523 .52 .76842 .51519 .76126 .5063 Mtetra
.656 .751 .92 r
.76126 .5063 .76842 .51519 .78464 .5104 .77754 .50144 Mtetra
.655 .751 .92 r
.77754 .50144 .78464 .5104 .80093 .50541 .79392 .49657 Mtetra
.66 .757 .922 r
.79392 .49657 .80093 .50541 .81732 .50043 .81037 .49149 Mtetra
.658 .755 .921 r
.81037 .49149 .81732 .50043 .83382 .49564 .82692 .48645 Mtetra
.653 .748 .92 r
.82692 .48645 .83382 .49564 .85041 .49082 .84358 .4816 Mtetra
.654 .749 .92 r
.84358 .4816 .85041 .49082 .8671 .4859 .86034 .47669 Mtetra
.656 .751 .92 r
.86034 .47669 .8671 .4859 .88386 .48085 .87718 .47165 Mtetra
.658 .754 .921 r
.87718 .47165 .88386 .48085 .90073 .47577 .89412 .4665 Mtetra
.656 .752 .921 r
.89412 .4665 .90073 .47577 .91771 .4708 .91116 .46139 Mtetra
.654 .75 .92 r
.91116 .46139 .91771 .4708 .93478 .46579 .92831 .45635 Mtetra
.657 .751 .919 r
.31743 .62829 .32622 .636 .34012 .63178 .33138 .62405 Mtetra
.653 .75 .921 r
.33138 .62405 .34012 .63178 .3541 .62763 .34539 .61993 Mtetra
.654 .752 .922 r
.34539 .61993 .3541 .62763 .36814 .62354 .35948 .61575 Mtetra
.657 .752 .92 r
.35948 .61575 .36814 .62354 .38226 .61933 .37365 .61146 Mtetra
.66 .751 .918 r
.37365 .61146 .38226 .61933 .39646 .61501 .3879 .60705 Mtetra
.655 .749 .919 r
.3879 .60705 .39646 .61501 .41073 .61064 .40221 .60277 Mtetra
.65 .751 .923 r
.40221 .60277 .41073 .61064 .42508 .60645 .4166 .59863 Mtetra
.655 .755 .923 r
.4166 .59863 .42508 .60645 .4395 .60231 .43108 .59429 Mtetra
.656 .751 .92 r
.43108 .59429 .4395 .60231 .454 .59797 .44563 .58992 Mtetra
.652 .75 .922 r
.44563 .58992 .454 .59797 .46858 .59362 .46025 .58568 Mtetra
.617 .743 .936 r
.46025 .58568 .46858 .59362 .48323 .58935 .47494 .58254 Mtetra
.555 .755 .97 r
.47494 .58254 .48323 .58935 .49796 .5858 .48971 .58066 Mtetra
.481 .777 .996 r
.48971 .58066 .49796 .5858 .51278 .58334 .50458 .57937 Mtetra
.421 .786 .995 r
.50458 .57937 .51278 .58334 .52769 .58117 .51956 .57819 Mtetra
.438 .822 .989 r
.51956 .57819 .52769 .58117 .54271 .57924 .53464 .57601 Mtetra
.549 .863 .996 r
.53464 .57601 .54271 .57924 .55782 .57697 .54982 .57227 Mtetra
.63 .848 .983 r
.54982 .57227 .55782 .57697 .57303 .57401 .56508 .56762 Mtetra
.658 .807 .955 r
.56508 .56762 .57303 .57401 .58833 .57039 .58041 .56268 Mtetra
.661 .773 .932 r
.58041 .56268 .58833 .57039 .6037 .56625 .59583 .5578 Mtetra
.655 .753 .922 r
.59583 .5578 .6037 .56625 .61916 .56167 .61135 .55318 Mtetra
.647 .751 .925 r
.61135 .55318 .61916 .56167 .63468 .55667 .62695 .54882 Mtetra
.642 .767 .939 r
.62695 .54882 .63468 .55667 .65027 .55113 .64265 .54452 Mtetra
.642 .802 .96 r
.64265 .54452 .65027 .55113 .66591 .54492 .65843 .53992 Mtetra
.655 .856 .976 r
.65843 .53992 .66591 .54492 .6816 .53799 .67426 .53441 Mtetra
.689 .907 .972 r
.67426 .53441 .6816 .53799 .69733 .53071 .6901 .52731 Mtetra
.72 .92 .961 r
.6901 .52731 .69733 .53071 .71314 .52367 .70595 .51916 Mtetra
.727 .892 .955 r
.70595 .51916 .71314 .52367 .72904 .5169 .72186 .51111 Mtetra
.717 .854 .947 r
.72186 .51111 .72904 .5169 .74508 .51123 .73787 .50365 Mtetra
.687 .797 .933 r
.73787 .50365 .74508 .51123 .76126 .5063 .75404 .49746 Mtetra
.659 .756 .922 r
.75404 .49746 .76126 .5063 .77754 .50144 .77037 .4924 Mtetra
.656 .751 .92 r
.77037 .4924 .77754 .50144 .79392 .49657 .78681 .48747 Mtetra
.78681 .48747 .79392 .49657 .81037 .49149 .80334 .4825 Mtetra
.66 .757 .921 r
.80334 .4825 .81037 .49149 .82692 .48645 .81995 .47731 Mtetra
.656 .753 .921 r
.81995 .47731 .82692 .48645 .84358 .4816 .83667 .47226 Mtetra
.653 .748 .92 r
.83667 .47226 .84358 .4816 .86034 .47669 .8535 .46735 Mtetra
.655 .75 .92 r
.8535 .46735 .86034 .47669 .87718 .47165 .87043 .46231 Mtetra
.657 .752 .92 r
.87043 .46231 .87718 .47165 .89412 .4665 .88744 .45715 Mtetra
.658 .754 .921 r
.88744 .45715 .89412 .4665 .91116 .46139 .90454 .45191 Mtetra
.654 .75 .92 r
.90454 .45191 .91116 .46139 .92831 .45635 .92176 .44679 Mtetra
.655 .75 .92 r
.30855 .62051 .31743 .62829 .33138 .62405 .32254 .6163 Mtetra
.653 .752 .922 r
.32254 .6163 .33138 .62405 .34539 .61993 .3366 .61215 Mtetra
.656 .753 .921 r
.3366 .61215 .34539 .61993 .35948 .61575 .35074 .60787 Mtetra
.659 .752 .919 r
.35074 .60787 .35948 .61575 .37365 .61146 .36496 .60346 Mtetra
.658 .75 .918 r
.36496 .60346 .37365 .61146 .3879 .60705 .37925 .59906 Mtetra
.651 .749 .922 r
.37925 .59906 .3879 .60705 .40221 .60277 .39361 .5949 Mtetra
.654 .754 .923 r
.39361 .5949 .40221 .60277 .4166 .59863 .40805 .5906 Mtetra
.655 .751 .921 r
.40805 .5906 .4166 .59863 .43108 .59429 .42257 .58624 Mtetra
.654 .752 .922 r
.42257 .58624 .43108 .59429 .44563 .58992 .43717 .58189 Mtetra
.615 .742 .936 r
.43717 .58189 .44563 .58992 .46025 .58568 .45182 .57879 Mtetra
.538 .747 .972 r
.45182 .57879 .46025 .58568 .47494 .58254 .46654 .57727 Mtetra
.439 .755 .995 r
.46654 .57727 .47494 .58254 .48971 .58066 .48135 .5767 Mtetra
.393 .773 .991 r
.48135 .5767 .48971 .58066 .50458 .57937 .49627 .57587 Mtetra
.511 .84 .998 r
.49627 .57587 .50458 .57937 .51956 .57819 .51132 .57297 Mtetra
.652 .837 .971 r
.51132 .57297 .51956 .57819 .53464 .57601 .52647 .56795 Mtetra
.694 .771 .911 r
.52647 .56795 .53464 .57601 .54982 .57227 .54169 .56181 Mtetra
.705 .723 .864 r
.54169 .56181 .54982 .57227 .56508 .56762 .55697 .55475 Mtetra
.689 .678 .833 r
.55697 .55475 .56508 .56762 .58041 .56268 .57232 .54799 Mtetra
.667 .644 .817 r
.57232 .54799 .58041 .56268 .59583 .5578 .58775 .54218 Mtetra
.646 .623 .813 r
.58775 .54218 .59583 .5578 .61135 .55318 .60329 .5375 Mtetra
.626 .614 .818 r
.60329 .5375 .61135 .55318 .62695 .54882 .61894 .53396 Mtetra
.609 .617 .834 r
.61894 .53396 .62695 .54882 .64265 .54452 .63473 .53137 Mtetra
.6 .64 .862 r
.63473 .53137 .64265 .54452 .65843 .53992 .65064 .52911 Mtetra
.618 .692 .896 r
.65064 .52911 .65843 .53992 .67426 .53441 .66662 .52592 Mtetra
.641 .755 .932 r
.66662 .52592 .67426 .53441 .6901 .52731 .68266 .5216 Mtetra
.689 .848 .959 r
.68266 .5216 .6901 .52731 .70595 .51916 .69869 .51513 Mtetra
.736 .908 .953 r
.69869 .51513 .70595 .51916 .72186 .51111 .71466 .50652 Mtetra
.747 .896 .946 r
.71466 .50652 .72186 .51111 .73787 .50365 .73068 .49764 Mtetra
.727 .854 .941 r
.73068 .49764 .73787 .50365 .75404 .49746 .74682 .48969 Mtetra
.688 .796 .932 r
.74682 .48969 .75404 .49746 .77037 .4924 .76314 .48337 Mtetra
.657 .754 .922 r
.76314 .48337 .77037 .4924 .78681 .48747 .77964 .47831 Mtetra
.656 .752 .921 r
.77964 .47831 .78681 .48747 .80334 .4825 .79623 .47326 Mtetra
.657 .752 .92 r
.79623 .47326 .80334 .4825 .81995 .47731 .81292 .46815 Mtetra
.66 .756 .921 r
.81292 .46815 .81995 .47731 .83667 .47226 .8297 .46289 Mtetra
.654 .75 .92 r
.8297 .46289 .83667 .47226 .8535 .46735 .84659 .45786 Mtetra
.653 .748 .92 r
.84659 .45786 .8535 .46735 .87043 .46231 .86359 .45284 Mtetra
.656 .751 .92 r
.86359 .45284 .87043 .46231 .88744 .45715 .88068 .44768 Mtetra
.658 .754 .92 r
.88068 .44768 .88744 .45715 .90454 .45191 .89786 .44238 Mtetra
.656 .753 .921 r
.89786 .44238 .90454 .45191 .92176 .44679 .91514 .43713 Mtetra
.653 .75 .921 r
.29959 .61266 .30855 .62051 .32254 .6163 .31362 .60848 Mtetra
.654 .752 .922 r
.31362 .60848 .32254 .6163 .3366 .61215 .32772 .60425 Mtetra
.657 .752 .92 r
.32772 .60425 .3366 .61215 .35074 .60787 .34191 .59988 Mtetra
.66 .751 .918 r
.34191 .59988 .35074 .60787 .36496 .60346 .35618 .5954 Mtetra
.654 .749 .92 r
.35618 .5954 .36496 .60346 .37925 .59906 .37051 .59112 Mtetra
.651 .752 .924 r
.37051 .59112 .37925 .59906 .39361 .5949 .38492 .5869 Mtetra
.656 .753 .922 r
.38492 .5869 .39361 .5949 .40805 .5906 .39941 .58248 Mtetra
.656 .751 .92 r
.39941 .58248 .40805 .5906 .42257 .58624 .41398 .57805 Mtetra
.628 .743 .93 r
.41398 .57805 .42257 .58624 .43717 .58189 .42861 .57453 Mtetra
.541 .736 .965 r
.42861 .57453 .43717 .58189 .45182 .57879 .44327 .57309 Mtetra
.428 .739 .992 r
.44327 .57309 .45182 .57879 .46654 .57727 .45801 .57289 Mtetra
.381 .756 .991 r
.45801 .57289 .46654 .57727 .48135 .5767 .47288 .57249 Mtetra
.561 .839 .997 r
.47288 .57249 .48135 .5767 .49627 .57587 .48789 .56912 Mtetra
.694 .804 .933 r
.48789 .56912 .49627 .57587 .51132 .57297 .50302 .56302 Mtetra
.734 .74 .857 r
.50302 .56302 .51132 .57297 .52647 .56795 .51822 .55442 Mtetra
.723 .68 .808 r
.51822 .55442 .52647 .56795 .54169 .56181 .53347 .54511 Mtetra
.696 .633 .782 r
.53347 .54511 .54169 .56181 .55697 .55475 .54877 .53663 Mtetra
.672 .609 .776 r
.54877 .53663 .55697 .55475 .57232 .54799 .56413 .52957 Mtetra
.654 .598 .779 r
.56413 .52957 .57232 .54799 .58775 .54218 .57958 .52378 Mtetra
.64 .591 .784 r
.57958 .52378 .58775 .54218 .60329 .5375 .59513 .51903 Mtetra
.623 .583 .788 r
.59513 .51903 .60329 .5375 .61894 .53396 .61079 .51535 Mtetra
.603 .572 .792 r
.61079 .51535 .61894 .53396 .63473 .53137 .62659 .51294 Mtetra
.578 .561 .799 r
.62659 .51294 .63473 .53137 .65064 .52911 .64256 .51199 Mtetra
.559 .566 .817 r
.64256 .51199 .65064 .52911 .66662 .52592 .65869 .51189 Mtetra
.566 .612 .858 r
.65869 .51189 .66662 .52592 .68266 .5216 .67492 .51109 Mtetra
.618 .702 .905 r
.67492 .51109 .68266 .5216 .69869 .51513 .69116 .50777 Mtetra
.683 .804 .94 r
.69116 .50777 .69869 .51513 .71466 .50652 .70736 .50167 Mtetra
.753 .891 .941 r
.70736 .50167 .71466 .50652 .73068 .49764 .72346 .49253 Mtetra
.758 .887 .936 r
.72346 .49253 .73068 .49764 .74682 .48969 .7396 .48315 Mtetra
.73 .843 .934 r
.7396 .48315 .74682 .48969 .76314 .48337 .75588 .47501 Mtetra
.679 .782 .928 r
.75588 .47501 .76314 .48337 .77964 .47831 .77238 .469 Mtetra
.656 .751 .92 r
.77238 .469 .77964 .47831 .79623 .47326 .78905 .46393 Mtetra
.78905 .46393 .79623 .47326 .81292 .46815 .80581 .45883 Mtetra
.66 .755 .92 r
.80581 .45883 .81292 .46815 .8297 .46289 .82266 .45354 Mtetra
.658 .755 .921 r
.82266 .45354 .8297 .46289 .84659 .45786 .83961 .44829 Mtetra
.652 .748 .92 r
.83961 .44829 .84659 .45786 .86359 .45284 .85668 .44324 Mtetra
.655 .75 .92 r
.85668 .44324 .86359 .45284 .88068 .44768 .87385 .43807 Mtetra
.657 .752 .92 r
.87385 .43807 .88068 .44768 .89786 .44238 .8911 .43276 Mtetra
.658 .754 .921 r
.8911 .43276 .89786 .44238 .91514 .43713 .90846 .42738 Mtetra
.653 .751 .922 r
.29054 .60478 .29959 .61266 .31362 .60848 .30461 .60058 Mtetra
.655 .752 .921 r
.30461 .60058 .31362 .60848 .32772 .60425 .31876 .59625 Mtetra
.659 .752 .919 r
.31876 .59625 .32772 .60425 .34191 .59988 .333 .59179 Mtetra
.658 .75 .918 r
.333 .59179 .34191 .59988 .35618 .5954 .34731 .58732 Mtetra
.65 .75 .922 r
.34731 .58732 .35618 .5954 .37051 .59112 .36168 .58311 Mtetra
.654 .753 .923 r
.36168 .58311 .37051 .59112 .38492 .5869 .37614 .57873 Mtetra
.656 .751 .92 r
.37614 .57873 .38492 .5869 .39941 .58248 .39069 .57426 Mtetra
.645 .748 .924 r
.39069 .57426 .39941 .58248 .41398 .57805 .40529 .57016 Mtetra
.568 .733 .953 r
.40529 .57016 .41398 .57805 .42861 .57453 .41992 .56821 Mtetra
.451 .732 .987 r
.41992 .56821 .42861 .57453 .44327 .57309 .4346 .56795 Mtetra
.367 .728 .989 r
.4346 .56795 .44327 .57309 .45801 .57289 .44938 .56821 Mtetra
.551 .823 .996 r
.44938 .56821 .45801 .57289 .47288 .57249 .46435 .56526 Mtetra
.706 .795 .919 r
.46435 .56526 .47288 .57249 .48789 .56912 .47947 .55863 Mtetra
.755 .736 .835 r
.47947 .55863 .48789 .56912 .50302 .56302 .49468 .54826 Mtetra
.734 .67 .787 r
.49468 .54826 .50302 .56302 .51822 .55442 .50993 .53735 Mtetra
.702 .633 .776 r
.50993 .53735 .51822 .55442 .53347 .54511 .52521 .52817 Mtetra
.682 .626 .786 r
.52521 .52817 .53347 .54511 .54877 .53663 .54053 .52067 Mtetra
.668 .63 .803 r
.54053 .52067 .54877 .53663 .56413 .52957 .55594 .51447 Mtetra
.657 .636 .818 r
.55594 .51447 .56413 .52957 .57958 .52378 .57142 .50913 Mtetra
.649 .64 .827 r
.57142 .50913 .57958 .52378 .59513 .51903 .587 .50434 Mtetra
.639 .635 .83 r
.587 .50434 .59513 .51903 .61079 .51535 .60268 .50007 Mtetra
.622 .62 .828 r
.60268 .50007 .61079 .51535 .62659 .51294 .61848 .49669 Mtetra
.596 .596 .822 r
.61848 .49669 .62659 .51294 .64256 .51199 .63443 .49462 Mtetra
.563 .566 .815 r
.63443 .49462 .64256 .51199 .65869 .51189 .65056 .49426 Mtetra
.527 .544 .817 r
.65056 .49426 .65869 .51189 .67492 .51109 .6669 .4957 Mtetra
.529 .575 .846 r
.6669 .4957 .67492 .51109 .69116 .50777 .68337 .49661 Mtetra
.606 .687 .9 r
.68337 .49661 .69116 .50777 .70736 .50167 .6998 .49373 Mtetra
.695 .796 .928 r
.6998 .49373 .70736 .50167 .72346 .49253 .71613 .48709 Mtetra
.769 .881 .927 r
.71613 .48709 .72346 .49253 .7396 .48315 .73233 .47715 Mtetra
.758 .866 .928 r
.73233 .47715 .7396 .48315 .75588 .47501 .74861 .46771 Mtetra
.718 .824 .93 r
.74861 .46771 .75588 .47501 .77238 .469 .76508 .45999 Mtetra
.665 .764 .924 r
.76508 .45999 .77238 .469 .78905 .46393 .78178 .45447 Mtetra
.656 .751 .92 r
.78178 .45447 .78905 .46393 .80581 .45883 .79862 .44933 Mtetra
.657 .752 .92 r
.79862 .44933 .80581 .45883 .82266 .45354 .81554 .44409 Mtetra
.661 .756 .921 r
.81554 .44409 .82266 .45354 .83961 .44829 .83256 .43867 Mtetra
.654 .75 .921 r
.83256 .43867 .83961 .44829 .85668 .44324 .8497 .43351 Mtetra
.653 .749 .92 r
.8497 .43351 .85668 .44324 .87385 .43807 .86694 .42834 Mtetra
.656 .751 .92 r
.86694 .42834 .87385 .43807 .8911 .43276 .88427 .42302 Mtetra
.659 .754 .92 r
.88427 .42302 .8911 .43276 .90846 .42738 .9017 .41757 Mtetra
.653 .752 .922 r
.28139 .59683 .29054 .60478 .30461 .60058 .29551 .59257 Mtetra
.657 .752 .92 r
.29551 .59257 .30461 .60058 .31876 .59625 .30971 .58817 Mtetra
.66 .752 .918 r
.30971 .58817 .31876 .59625 .333 .59179 .324 .58362 Mtetra
.655 .75 .92 r
.324 .58362 .333 .59179 .34731 .58732 .33835 .57923 Mtetra
.65 .752 .924 r
.33835 .57923 .34731 .58732 .36168 .58311 .35277 .57497 Mtetra
.656 .753 .921 r
.35277 .57497 .36168 .58311 .37614 .57873 .36728 .57049 Mtetra
.655 .751 .921 r
.36728 .57049 .37614 .57873 .39069 .57426 .38187 .56601 Mtetra
.613 .74 .936 r
.38187 .56601 .39069 .57426 .40529 .57016 .39649 .5629 Mtetra
.502 .727 .973 r
.39649 .5629 .40529 .57016 .41992 .56821 .41112 .56212 Mtetra
.373 .704 .985 r
.41112 .56212 .41992 .56821 .4346 .56795 .42582 .56287 Mtetra
.478 .783 .998 r
.42582 .56287 .4346 .56795 .44938 .56821 .4407 .56139 Mtetra
.694 .804 .933 r
.4407 .56139 .44938 .56821 .46435 .56526 .45579 .55524 Mtetra
.765 .747 .836 r
.45579 .55524 .46435 .56526 .47947 .55863 .47103 .54433 Mtetra
.75 .681 .784 r
.47103 .54433 .47947 .55863 .49468 .54826 .4863 .53214 Mtetra
.715 .648 .782 r
.4863 .53214 .49468 .54826 .50993 .53735 .50158 .52226 Mtetra
.692 .651 .805 r
.50158 .52226 .50993 .53735 .52521 .52817 .51689 .51464 Mtetra
.651 .656 .842 r
.51689 .51464 .52521 .52817 .54053 .52067 .53227 .5099 Mtetra
.641 .701 .89 r
.53227 .5099 .54053 .52067 .55594 .51447 .54773 .50577 Mtetra
.643 .749 .926 r
.54773 .50577 .55594 .51447 .57142 .50913 .56329 .50143 Mtetra
.654 .779 .941 r
.56329 .50143 .57142 .50913 .587 .50434 .57893 .49659 Mtetra
.667 .783 .936 r
.57893 .49659 .587 .50434 .60268 .50007 .59465 .49122 Mtetra
.673 .759 .915 r
.59465 .49122 .60268 .50007 .61848 .49669 .61045 .48565 Mtetra
.657 .707 .884 r
.61045 .48565 .61848 .49669 .63443 .49462 .62636 .48069 Mtetra
.592 .629 .857 r
.62636 .48069 .63443 .49462 .65056 .49426 .64246 .47864 Mtetra
.543 .58 .842 r
.64246 .47864 .65056 .49426 .6669 .4957 .65877 .4789 Mtetra
.492 .538 .832 r
.65877 .4789 .6669 .4957 .68337 .49661 .67534 .48155 Mtetra
.513 .574 .855 r
.67534 .48155 .68337 .49661 .6998 .49373 .69202 .48292 Mtetra
.617 .702 .905 r
.69202 .48292 .6998 .49373 .71613 .48709 .70859 .47946 Mtetra
.73 .817 .919 r
.70859 .47946 .71613 .48709 .73233 .47715 .72498 .4712 Mtetra
.78 .873 .916 r
.72498 .4712 .73233 .47715 .74861 .46771 .74128 .46064 Mtetra
.746 .839 .921 r
.74128 .46064 .74861 .46771 .76508 .45999 .75774 .4516 Mtetra
.69 .791 .927 r
.75774 .4516 .76508 .45999 .78178 .45447 .77444 .44497 Mtetra
.656 .753 .921 r
.77444 .44497 .78178 .45447 .79862 .44933 .79134 .43973 Mtetra
.656 .751 .92 r
.79134 .43973 .79862 .44933 .81554 .44409 .80835 .4345 Mtetra
.661 .755 .92 r
.80835 .4345 .81554 .44409 .83256 .43867 .82543 .42903 Mtetra
.657 .753 .921 r
.82543 .42903 .83256 .43867 .8497 .43351 .84263 .42369 Mtetra
.652 .749 .92 r
.84263 .42369 .8497 .43351 .86694 .42834 .85995 .4185 Mtetra
.655 .751 .92 r
.85995 .4185 .86694 .42834 .88427 .42302 .87737 .41316 Mtetra
.658 .753 .92 r
.87737 .41316 .88427 .42302 .9017 .41757 .89487 .40766 Mtetra
.654 .752 .922 r
.27215 .58881 .28139 .59683 .29551 .59257 .28632 .58447 Mtetra
.657 .752 .92 r
.28632 .58447 .29551 .59257 .30971 .58817 .30057 .57999 Mtetra
.66 .752 .918 r
.30057 .57999 .30971 .58817 .324 .58362 .3149 .5754 Mtetra
.652 .75 .921 r
.3149 .5754 .324 .58362 .33835 .57923 .3293 .57107 Mtetra
.652 .752 .923 r
.3293 .57107 .33835 .57923 .35277 .57497 .34377 .56668 Mtetra
.656 .751 .92 r
.34377 .56668 .35277 .57497 .36728 .57049 .35833 .56217 Mtetra
.648 .75 .923 r
.35833 .56217 .36728 .57049 .38187 .56601 .37296 .5579 Mtetra
.566 .729 .951 r
.37296 .5579 .38187 .56601 .39649 .5629 .38757 .55598 Mtetra
.433 .709 .981 r
.38757 .55598 .39649 .5629 .41112 .56212 .40221 .55622 Mtetra
.377 .714 .987 r
.40221 .55622 .41112 .56212 .42582 .56287 .41697 .55672 Mtetra
.634 .808 .966 r
.41697 .55672 .42582 .56287 .4407 .56139 .43198 .55239 Mtetra
.756 .765 .86 r
.43198 .55239 .4407 .56139 .45579 .55524 .44721 .54264 Mtetra
.772 .709 .793 r
.44721 .54264 .45579 .55524 .47103 .54433 .46253 .52941 Mtetra
.736 .67 .786 r
.46253 .52941 .47103 .54433 .4863 .53214 .47784 .51825 Mtetra
.7 .67 .818 r
.47784 .51825 .4863 .53214 .50158 .52226 .49314 .51045 Mtetra
.636 .68 .874 r
.49314 .51045 .50158 .52226 .51689 .51464 .50848 .50651 Mtetra
.605 .751 .947 r
.50848 .50651 .51689 .51464 .53227 .5099 .52392 .50333 Mtetra
.61 .796 .971 r
.52392 .50333 .53227 .5099 .54773 .50577 .53945 .49956 Mtetra
.624 .812 .972 r
.53945 .49956 .54773 .50577 .56329 .50143 .55508 .49525 Mtetra
.643 .82 .968 r
.55508 .49525 .56329 .50143 .57893 .49659 .5708 .49036 Mtetra
.662 .825 .962 r
.5708 .49036 .57893 .49659 .59465 .49122 .58659 .48488 Mtetra
.679 .828 .955 r
.58659 .48488 .59465 .49122 .61045 .48565 .60245 .47885 Mtetra
.696 .821 .942 r
.60245 .47885 .61045 .48565 .62636 .48069 .61839 .47221 Mtetra
.678 .774 .923 r
.61839 .47221 .62636 .48069 .64246 .47864 .63442 .46634 Mtetra
.584 .656 .886 r
.63442 .46634 .64246 .47864 .65877 .4789 .65068 .46438 Mtetra
.504 .578 .863 r
.65068 .46438 .65877 .4789 .67534 .48155 .66723 .46586 Mtetra
.455 .534 .85 r
.66723 .46586 .67534 .48155 .69202 .48292 .68403 .46948 Mtetra
.533 .614 .879 r
.68403 .46948 .69202 .48292 .70859 .47946 .70084 .46959 Mtetra
.663 .744 .911 r
.70084 .46959 .70859 .47946 .72498 .4712 .71747 .46414 Mtetra
.773 .845 .906 r
.71747 .46414 .72498 .4712 .74128 .46064 .73388 .45374 Mtetra
.769 .85 .912 r
.73388 .45374 .74128 .46064 .75774 .4516 .75035 .44356 Mtetra
.72 .811 .922 r
.75035 .44356 .75774 .4516 .77444 .44497 .76704 .43559 Mtetra
.662 .76 .923 r
.76704 .43559 .77444 .44497 .79134 .43973 .78399 .43004 Mtetra
.656 .752 .92 r
.78399 .43004 .79134 .43973 .80835 .4345 .80107 .42473 Mtetra
.659 .752 .919 r
.80107 .42473 .80835 .4345 .82543 .42903 .81823 .41928 Mtetra
.659 .754 .92 r
.81823 .41928 .82543 .42903 .84263 .42369 .83549 .41377 Mtetra
.652 .749 .921 r
.83549 .41377 .84263 .42369 .85995 .4185 .85289 .40853 Mtetra
.654 .75 .92 r
.85289 .40853 .85995 .4185 .87737 .41316 .87038 .40316 Mtetra
.657 .752 .92 r
.87038 .40316 .87737 .41316 .89487 .40766 .88796 .39763 Mtetra
.655 .752 .921 r
.26283 .58069 .27215 .58881 .28632 .58447 .27704 .57628 Mtetra
.658 .752 .919 r
.27704 .57628 .28632 .58447 .30057 .57999 .29134 .57172 Mtetra
.659 .751 .918 r
.29134 .57172 .30057 .57999 .3149 .5754 .30572 .56712 Mtetra
.65 .75 .922 r
.30572 .56712 .3149 .5754 .3293 .57107 .32015 .56281 Mtetra
.654 .752 .922 r
.32015 .56281 .3293 .57107 .34377 .56668 .33468 .55831 Mtetra
.656 .751 .92 r
.33468 .55831 .34377 .56668 .35833 .56217 .34929 .55373 Mtetra
.634 .744 .928 r
.34929 .55373 .35833 .56217 .37296 .5579 .36394 .5499 Mtetra
.519 .717 .962 r
.36394 .5499 .37296 .5579 .38757 .55598 .37856 .54895 Mtetra
.386 .686 .978 r
.37856 .54895 .38757 .55598 .40221 .55622 .39321 .54993 Mtetra
.482 .752 .989 r
.39321 .54993 .40221 .55622 .41697 .55672 .40806 .54894 Mtetra
.706 .784 .912 r
.40806 .54894 .41697 .55672 .43198 .55239 .4232 .5422 Mtetra
.787 .749 .818 r
.4232 .5422 .43198 .55239 .44721 .54264 .43857 .52926 Mtetra
.766 .699 .788 r
.43857 .52926 .44721 .54264 .46253 .52941 .45395 .51616 Mtetra
.728 .689 .813 r
.45395 .51616 .46253 .52941 .47784 .51825 .46928 .50655 Mtetra
.639 .684 .876 r
.46928 .50655 .47784 .51825 .49314 .51045 .48459 .50243 Mtetra
.584 .747 .955 r
.48459 .50243 .49314 .51045 .50848 .50651 .49998 .49976 Mtetra
.589 .785 .973 r
.49998 .49976 .50848 .50651 .52392 .50333 .51547 .49655 Mtetra
.62 .796 .966 r
.51547 .49655 .52392 .50333 .53945 .49956 .53107 .49248 Mtetra
.65 .798 .954 r
.53107 .49248 .53945 .49956 .55508 .49525 .54676 .48758 Mtetra
.653 .784 .944 r
.54676 .48758 .55508 .49525 .5708 .49036 .56254 .48263 Mtetra
.56254 .48263 .5708 .49036 .58659 .48488 .57841 .47765 Mtetra
.675 .805 .945 r
.57841 .47765 .58659 .48488 .60245 .47885 .59436 .47182 Mtetra
.696 .818 .94 r
.59436 .47182 .60245 .47885 .61839 .47221 .61036 .46512 Mtetra
.71 .821 .934 r
.61036 .46512 .61839 .47221 .63442 .46634 .62643 .45787 Mtetra
.674 .777 .928 r
.62643 .45787 .63442 .46634 .65068 .46438 .64262 .45207 Mtetra
.533 .635 .897 r
.64262 .45207 .65068 .46438 .66723 .46586 .65913 .45185 Mtetra
.439 .555 .876 r
.65913 .45185 .66723 .46586 .68403 .46948 .67595 .45522 Mtetra
.446 .556 .873 r
.67595 .45522 .68403 .46948 .70084 .46959 .69295 .45847 Mtetra
.604 .696 .908 r
.69295 .45847 .70084 .46959 .71747 .46414 .70978 .4554 Mtetra
.739 .798 .9 r
.70978 .4554 .71747 .46414 .73388 .45374 .72636 .44642 Mtetra
.782 .844 .899 r
.72636 .44642 .73388 .45374 .75035 .44356 .74288 .43539 Mtetra
.742 .816 .91 r
.74288 .43539 .75035 .44356 .76704 .43559 .75957 .42631 Mtetra
.675 .77 .922 r
.75957 .42631 .76704 .43559 .78399 .43004 .77656 .42019 Mtetra
.655 .75 .92 r
.77656 .42019 .78399 .43004 .80107 .42473 .7937 .41486 Mtetra
.657 .752 .92 r
.7937 .41486 .80107 .42473 .81823 .41928 .81095 .40942 Mtetra
.661 .755 .92 r
.81095 .40942 .81823 .41928 .83549 .41377 .82828 .40378 Mtetra
.653 .75 .921 r
.82828 .40378 .83549 .41377 .85289 .40853 .84575 .39844 Mtetra
.653 .75 .92 r
.84575 .39844 .85289 .40853 .87038 .40316 .86332 .39305 Mtetra
.657 .752 .92 r
.86332 .39305 .87038 .40316 .88796 .39763 .88098 .38749 Mtetra
.655 .752 .921 r
.2534 .57249 .26283 .58069 .27704 .57628 .26767 .56801 Mtetra
.659 .752 .919 r
.26767 .56801 .27704 .57628 .29134 .57172 .28201 .56338 Mtetra
.657 .751 .919 r
.28201 .56338 .29134 .57172 .30572 .56712 .29643 .55879 Mtetra
.649 .75 .923 r
.29643 .55879 .30572 .56712 .32015 .56281 .31092 .55445 Mtetra
.656 .752 .921 r
.31092 .55445 .32015 .56281 .33468 .55831 .32549 .54987 Mtetra
.656 .751 .92 r
.32549 .54987 .33468 .55831 .34929 .55373 .34015 .54526 Mtetra
.612 .739 .936 r
.34015 .54526 .34929 .55373 .36394 .5499 .35482 .54206 Mtetra
.488 .711 .969 r
.35482 .54206 .36394 .5499 .37856 .54895 .36945 .54163 Mtetra
.374 .674 .975 r
.36945 .54163 .37856 .54895 .39321 .54993 .38413 .54288 Mtetra
.577 .769 .97 r
.38413 .54288 .39321 .54993 .40806 .54894 .3991 .54018 Mtetra
.748 .771 .872 r
.3991 .54018 .40806 .54894 .4232 .5422 .41437 .53101 Mtetra
.793 .735 .799 r
.41437 .53101 .4232 .5422 .43857 .52926 .42985 .51663 Mtetra
.761 .709 .803 r
.42985 .51663 .43857 .52926 .45395 .51616 .44526 .50451 Mtetra
.694 .705 .856 r
.44526 .50451 .45395 .51616 .46928 .50655 .46059 .49767 Mtetra
.586 .727 .941 r
.46059 .49767 .46928 .50655 .48459 .50243 .47593 .49512 Mtetra
.575 .766 .969 r
.47593 .49512 .48459 .50243 .49998 .49976 .49137 .49241 Mtetra
.625 .783 .957 r
.49137 .49241 .49998 .49976 .51547 .49655 .50694 .48833 Mtetra
.661 .773 .932 r
.50694 .48833 .51547 .49655 .53107 .49248 .5226 .48318 Mtetra
.658 .747 .916 r
.5226 .48318 .53107 .49248 .54676 .48758 .53834 .47816 Mtetra
.656 .745 .915 r
.53834 .47816 .54676 .48758 .56254 .48263 .55418 .47316 Mtetra
.655 .744 .916 r
.55418 .47316 .56254 .48263 .57841 .47765 .57011 .46819 Mtetra
.651 .744 .918 r
.57011 .46819 .57841 .47765 .59436 .47182 .58614 .46335 Mtetra
.677 .778 .926 r
.58614 .46335 .59436 .47182 .61036 .46512 .60223 .45742 Mtetra
.71 .807 .926 r
.60223 .45742 .61036 .46512 .62643 .45787 .61838 .4501 Mtetra
.713 .808 .924 r
.61838 .4501 .62643 .45787 .64262 .45207 .63459 .44261 Mtetra
.6 .73 .935 r
.63459 .44261 .64262 .45207 .65913 .45185 .65104 .43947 Mtetra
.45 .594 .903 r
.65104 .43947 .65913 .45185 .67595 .45522 .66784 .44172 Mtetra
.386 .537 .884 r
.66784 .44172 .67595 .45522 .69295 .45847 .68494 .44633 Mtetra
.541 .648 .904 r
.68494 .44633 .69295 .45847 .70978 .4554 .70195 .44565 Mtetra
.702 .767 .903 r
.70195 .44565 .70978 .4554 .72636 .44642 .71871 .43831 Mtetra
.783 .827 .886 r
.71871 .43831 .72636 .44642 .74288 .43539 .73529 .42689 Mtetra
.752 .813 .901 r
.73529 .42689 .74288 .43539 .75957 .42631 .75203 .41718 Mtetra
.691 .782 .92 r
.75203 .41718 .75957 .42631 .77656 .42019 .76904 .4103 Mtetra
.656 .752 .921 r
.76904 .4103 .77656 .42019 .7937 .41486 .78626 .40488 Mtetra
.656 .751 .92 r
.78626 .40488 .7937 .41486 .81095 .40942 .80358 .39942 Mtetra
.661 .755 .919 r
.80358 .39942 .81095 .40942 .82828 .40378 .82099 .39371 Mtetra
.654 .751 .921 r
.82099 .39371 .82828 .40378 .84575 .39844 .83852 .38825 Mtetra
.653 .749 .921 r
.83852 .38825 .84575 .39844 .86332 .39305 .85617 .38282 Mtetra
.656 .751 .92 r
.85617 .38282 .86332 .39305 .88098 .38749 .87392 .37723 Mtetra
.656 .752 .92 r
.24389 .56419 .2534 .57249 .26767 .56801 .2582 .55966 Mtetra
.659 .752 .919 r
.2582 .55966 .26767 .56801 .28201 .56338 .27259 .55497 Mtetra
.656 .751 .92 r
.27259 .55497 .28201 .56338 .29643 .55879 .28706 .55037 Mtetra
.65 .75 .923 r
.28706 .55037 .29643 .55879 .31092 .55445 .30159 .54598 Mtetra
.656 .752 .921 r
.30159 .54598 .31092 .55445 .32549 .54987 .31622 .54134 Mtetra
.654 .751 .921 r
.31622 .54134 .32549 .54987 .34015 .54526 .33092 .53673 Mtetra
.595 .734 .941 r
.33092 .53673 .34015 .54526 .35482 .54206 .34561 .53399 Mtetra
.468 .698 .968 r
.34561 .53399 .35482 .54206 .36945 .54163 .36026 .53397 Mtetra
.389 .675 .973 r
.36026 .53397 .36945 .54163 .38413 .54288 .37498 .5351 Mtetra
.631 .768 .946 r
.37498 .5351 .38413 .54288 .3991 .54018 .39005 .53106 Mtetra
.772 .769 .85 r
.39005 .53106 .3991 .54018 .41437 .53101 .40545 .52005 Mtetra
.798 .741 .8 r
.40545 .52005 .41437 .53101 .42985 .51663 .421 .50537 Mtetra
.761 .731 .825 r
.421 .50537 .42985 .51663 .44526 .50451 .43646 .4941 Mtetra
.653 .717 .895 r
.43646 .4941 .44526 .50451 .46059 .49767 .4518 .48934 Mtetra
.565 .736 .956 r
.4518 .48934 .46059 .49767 .47593 .49512 .46718 .48715 Mtetra
.591 .756 .957 r
.46718 .48715 .47593 .49512 .49137 .49241 .48268 .48415 Mtetra
.661 .772 .932 r
.48268 .48415 .49137 .49241 .50694 .48833 .49831 .47898 Mtetra
.646 .743 .92 r
.49831 .47898 .50694 .48833 .5226 .48318 .51403 .47437 Mtetra
.635 .753 .933 r
.51403 .47437 .5226 .48318 .53834 .47816 .52984 .47009 Mtetra
.654 .779 .94 r
.52984 .47009 .53834 .47816 .55418 .47316 .54574 .46504 Mtetra
.674 .785 .933 r
.54574 .46504 .55418 .47316 .57011 .46819 .56173 .45921 Mtetra
.666 .763 .923 r
.56173 .45921 .57011 .46819 .58614 .46335 .57781 .45372 Mtetra
.651 .744 .918 r
.57781 .45372 .58614 .46335 .60223 .45742 .59399 .44879 Mtetra
.703 .785 .915 r
.59399 .44879 .60223 .45742 .61838 .4501 .61021 .44167 Mtetra
.721 .796 .911 r
.61021 .44167 .61838 .4501 .63459 .44261 .62648 .4337 Mtetra
.659 .767 .93 r
.62648 .4337 .63459 .44261 .65104 .43947 .64292 .42834 Mtetra
.464 .63 .926 r
.64292 .42834 .65104 .43947 .66784 .44172 .65973 .42961 Mtetra
.344 .543 .904 r
.65973 .42961 .66784 .44172 .68494 .44633 .67686 .43441 Mtetra
.48 .624 .914 r
.67686 .43441 .68494 .44633 .70195 .44565 .69402 .4355 Mtetra
.672 .75 .909 r
.69402 .4355 .70195 .44565 .71871 .43831 .71093 .42944 Mtetra
.778 .811 .879 r
.71093 .42944 .71871 .43831 .73529 .42689 .72761 .41804 Mtetra
.759 .809 .892 r
.72761 .41804 .73529 .42689 .75203 .41718 .7444 .40778 Mtetra
.702 .782 .913 r
.7444 .40778 .75203 .41718 .76904 .4103 .76145 .40033 Mtetra
.657 .753 .921 r
.76145 .40033 .76904 .4103 .78626 .40488 .77874 .3948 Mtetra
.656 .751 .92 r
.77874 .3948 .78626 .40488 .80358 .39942 .79613 .3893 Mtetra
.661 .754 .919 r
.79613 .3893 .80358 .39942 .82099 .39371 .81361 .38352 Mtetra
.655 .752 .921 r
.81361 .38352 .82099 .39371 .83852 .38825 .83122 .37796 Mtetra
.653 .75 .921 r
.83122 .37796 .83852 .38825 .85617 .38282 .84895 .37248 Mtetra
.656 .751 .92 r
.84895 .37248 .85617 .38282 .87392 .37723 .86677 .36684 Mtetra
.656 .752 .92 r
.23428 .55581 .24389 .56419 .2582 .55966 .24863 .55122 Mtetra
.66 .752 .919 r
.24863 .55122 .2582 .55966 .27259 .55497 .26308 .54648 Mtetra
.656 .751 .92 r
.26308 .54648 .27259 .55497 .28706 .55037 .27759 .54185 Mtetra
.65 .75 .923 r
.27759 .54185 .28706 .55037 .30159 .54598 .29217 .5374 Mtetra
.656 .751 .92 r
.29217 .5374 .30159 .54598 .31622 .54134 .30684 .53272 Mtetra
.653 .751 .921 r
.30684 .53272 .31622 .54134 .33092 .53673 .32159 .5281 Mtetra
.585 .731 .944 r
.32159 .5281 .33092 .53673 .34561 .53399 .33631 .52557 Mtetra
.46 .688 .965 r
.33631 .52557 .34561 .53399 .36026 .53397 .35099 .52578 Mtetra
.413 .673 .968 r
.35099 .52578 .36026 .53397 .37498 .5351 .36575 .52672 Mtetra
.654 .762 .929 r
.36575 .52672 .37498 .5351 .39005 .53106 .3809 .52194 Mtetra
.784 .772 .842 r
.3809 .52194 .39005 .53106 .40545 .52005 .39641 .50999 Mtetra
.805 .758 .809 r
.39641 .50999 .40545 .52005 .421 .50537 .41204 .4953 Mtetra
.763 .754 .844 r
.41204 .4953 .421 .50537 .43646 .4941 .42755 .48449 Mtetra
.625 .727 .92 r
.42755 .48449 .43646 .4941 .4518 .48934 .44291 .48074 Mtetra
.565 .731 .953 r
.44291 .48074 .4518 .48934 .46718 .48715 .45834 .47857 Mtetra
.614 .751 .943 r
.45834 .47857 .46718 .48715 .48268 .48415 .47391 .47497 Mtetra
.663 .753 .917 r
.47391 .47497 .48268 .48415 .49831 .47898 .4896 .46968 Mtetra
.623 .739 .93 r
.4896 .46968 .49831 .47898 .51403 .47437 .50536 .46582 Mtetra
.613 .754 .946 r
.50536 .46582 .51403 .47437 .52984 .47009 .52124 .46216 Mtetra
.653 .784 .944 r
.52124 .46216 .52984 .47009 .54574 .46504 .53721 .45706 Mtetra
.691 .795 .929 r
.53721 .45706 .54574 .46504 .56173 .45921 .55326 .45051 Mtetra
.686 .778 .921 r
.55326 .45051 .56173 .45921 .57781 .45372 .56939 .44416 Mtetra
.649 .747 .921 r
.56939 .44416 .57781 .45372 .59399 .44879 .58564 .43923 Mtetra
.689 .762 .907 r
.58564 .43923 .59399 .44879 .61021 .44167 .60194 .43261 Mtetra
.721 .784 .902 r
.60194 .43261 .61021 .44167 .62648 .4337 .61828 .42451 Mtetra
.686 .772 .917 r
.61828 .42451 .62648 .4337 .64292 .42834 .63475 .41801 Mtetra
.469 .654 .941 r
.63475 .41801 .64292 .42834 .65973 .42961 .65159 .4187 Mtetra
.311 .554 .921 r
.65159 .4187 .65973 .42961 .67686 .43441 .66876 .4234 Mtetra
.432 .621 .931 r
.66876 .4234 .67686 .43441 .69402 .4355 .68601 .42534 Mtetra
.655 .746 .917 r
.68601 .42534 .69402 .4355 .71093 .42944 .70303 .41993 Mtetra
.772 .798 .874 r
.70303 .41993 .71093 .42944 .72761 .41804 .7198 .40862 Mtetra
.761 .799 .883 r
.7198 .40862 .72761 .41804 .7444 .40778 .73666 .39802 Mtetra
.708 .777 .907 r
.73666 .39802 .7444 .40778 .76145 .40033 .75377 .39023 Mtetra
.658 .753 .92 r
.75377 .39023 .76145 .40033 .77874 .3948 .77113 .3846 Mtetra
.656 .751 .92 r
.77113 .3846 .77874 .3948 .79613 .3893 .7886 .37903 Mtetra
.661 .753 .919 r
.7886 .37903 .79613 .3893 .81361 .38352 .80616 .37321 Mtetra
.656 .752 .92 r
.80616 .37321 .81361 .38352 .83122 .37796 .82384 .36756 Mtetra
.652 .75 .921 r
.82384 .36756 .83122 .37796 .84895 .37248 .84164 .36203 Mtetra
.656 .751 .92 r
.84164 .36203 .84895 .37248 .86677 .36684 .85955 .35633 Mtetra
.22457 .54734 .23428 .55581 .24863 .55122 .23897 .5427 Mtetra
.66 .752 .919 r
.23897 .5427 .24863 .55122 .26308 .54648 .25346 .53791 Mtetra
.656 .751 .92 r
.25346 .53791 .26308 .54648 .27759 .54185 .26802 .53324 Mtetra
.65 .75 .923 r
.26802 .53324 .27759 .54185 .29217 .5374 .28265 .52874 Mtetra
.656 .751 .92 r
.28265 .52874 .29217 .5374 .30684 .53272 .29737 .52401 Mtetra
.653 .751 .921 r
.29737 .52401 .30684 .53272 .32159 .5281 .31217 .51934 Mtetra
.586 .73 .943 r
.31217 .51934 .32159 .5281 .33631 .52557 .32693 .51677 Mtetra
.466 .683 .96 r
.32693 .51677 .33631 .52557 .35099 .52578 .34164 .51694 Mtetra
.428 .665 .961 r
.34164 .51694 .35099 .52578 .36575 .52672 .35645 .51784 Mtetra
.654 .753 .922 r
.35645 .51784 .36575 .52672 .3809 .52194 .37165 .51301 Mtetra
.786 .777 .845 r
.37165 .51301 .3809 .52194 .39641 .50999 .38723 .50099 Mtetra
.814 .778 .819 r
.38723 .50099 .39641 .50999 .41204 .4953 .40294 .48622 Mtetra
.771 .776 .857 r
.40294 .48622 .41204 .4953 .42755 .48449 .41852 .47535 Mtetra
.623 .74 .931 r
.41852 .47535 .42755 .48449 .44291 .48074 .43394 .47155 Mtetra
.569 .72 .944 r
.43394 .47155 .44291 .48074 .45834 .47857 .44942 .46934 Mtetra
.617 .738 .933 r
.44942 .46934 .45834 .47857 .47391 .47497 .46504 .46568 Mtetra
.663 .753 .917 r
.46504 .46568 .47391 .47497 .4896 .46968 .48079 .46035 Mtetra
.623 .74 .931 r
.48079 .46035 .4896 .46968 .50536 .46582 .49661 .45643 Mtetra
.617 .738 .932 r
.49661 .45643 .50536 .46582 .52124 .46216 .51254 .45272 Mtetra
.656 .751 .92 r
.51254 .45272 .52124 .46216 .53721 .45706 .52857 .44756 Mtetra
.69 .762 .907 r
.52857 .44756 .53721 .45706 .55326 .45051 .54469 .44096 Mtetra
.685 .76 .909 r
.54469 .44096 .55326 .45051 .56939 .44416 .56089 .43454 Mtetra
.649 .749 .922 r
.56089 .43454 .56939 .44416 .58564 .43923 .57719 .42956 Mtetra
.689 .762 .907 r
.57719 .42956 .58564 .43923 .60194 .43261 .59356 .42288 Mtetra
.719 .771 .893 r
.59356 .42288 .60194 .43261 .61828 .42451 .60998 .41471 Mtetra
.685 .76 .909 r
.60998 .41471 .61828 .42451 .63475 .41801 .62652 .40816 Mtetra
.459 .664 .95 r
.62652 .40816 .63475 .41801 .65159 .4187 .6434 .4088 Mtetra
.274 .56 .931 r
.6434 .4088 .65159 .4187 .66876 .4234 .66062 .41346 Mtetra
.407 .636 .949 r
.66062 .41346 .66876 .4234 .68601 .42534 .67792 .41536 Mtetra
.655 .753 .922 r
.67792 .41536 .68601 .42534 .70303 .41993 .69501 .40989 Mtetra
.77 .789 .869 r
.69501 .40989 .70303 .41993 .7198 .40862 .71187 .3985 Mtetra
.758 .786 .876 r
.71187 .3985 .7198 .40862 .73666 .39802 .72881 .38784 Mtetra
.707 .77 .902 r
.72881 .38784 .73666 .39802 .75377 .39023 .746 .37998 Mtetra
.658 .752 .92 r
.746 .37998 .75377 .39023 .77113 .3846 .76343 .37428 Mtetra
.656 .751 .92 r
.76343 .37428 .77113 .3846 .7886 .37903 .78098 .36865 Mtetra
.661 .753 .919 r
.78098 .36865 .7886 .37903 .80616 .37321 .79861 .36277 Mtetra
.656 .751 .92 r
.79861 .36277 .80616 .37321 .82384 .36756 .81637 .35705 Mtetra
.652 .75 .921 r
.81637 .35705 .82384 .36756 .84164 .36203 .83426 .35146 Mtetra
.656 .751 .92 r
.83426 .35146 .84164 .36203 .85955 .35633 .85224 .34569 Mtetra
.21476 .53877 .22457 .54734 .23897 .5427 .22921 .53409 Mtetra
.659 .752 .919 r
.22921 .53409 .23897 .5427 .25346 .53791 .24374 .52926 Mtetra
.656 .752 .92 r
.24374 .52926 .25346 .53791 .26802 .53324 .25835 .52452 Mtetra
.65 .75 .923 r
.25835 .52452 .26802 .53324 .28265 .52874 .27303 .51999 Mtetra
.656 .751 .92 r
.27303 .51999 .28265 .52874 .29737 .52401 .2878 .5152 Mtetra
.654 .751 .921 r
.2878 .5152 .29737 .52401 .31217 .51934 .30266 .51045 Mtetra
.595 .732 .94 r
.30266 .51045 .31217 .51934 .32693 .51677 .31748 .50757 Mtetra
.485 .683 .954 r
.31748 .50757 .32693 .51677 .34164 .51694 .33224 .50744 Mtetra
.433 .653 .952 r
.33224 .50744 .34164 .51694 .35645 .51784 .34706 .50846 Mtetra
.635 .738 .922 r
.34706 .50846 .35645 .51784 .37165 .51301 .36228 .50428 Mtetra
.777 .782 .858 r
.36228 .50428 .37165 .51301 .38723 .50099 .37791 .49307 Mtetra
.824 .8 .829 r
.37791 .49307 .38723 .50099 .40294 .48622 .39371 .47816 Mtetra
.785 .799 .864 r
.39371 .47816 .40294 .48622 .41852 .47535 .40938 .46668 Mtetra
.652 .763 .93 r
.40938 .46668 .41852 .47535 .43394 .47155 .42489 .46177 Mtetra
.576 .711 .935 r
.42489 .46177 .43394 .47155 .44942 .46934 .44042 .45944 Mtetra
.602 .72 .927 r
.44042 .45944 .44942 .46934 .46504 .46568 .45608 .45629 Mtetra
.662 .752 .918 r
.45608 .45629 .46504 .46568 .48079 .46035 .47188 .45096 Mtetra
.646 .749 .924 r
.47188 .45096 .48079 .46035 .49661 .45643 .48777 .44619 Mtetra
.637 .728 .914 r
.48777 .44619 .49661 .45643 .51254 .45272 .50375 .44176 Mtetra
.656 .721 .896 r
.50375 .44176 .51254 .45272 .52857 .44756 .51984 .43654 Mtetra
.673 .727 .89 r
.51984 .43654 .52857 .44756 .54469 .44096 .53602 .43054 Mtetra
.665 .738 .904 r
.53602 .43054 .54469 .44096 .56089 .43454 .55229 .42488 Mtetra
.651 .75 .922 r
.55229 .42488 .56089 .43454 .57719 .42956 .56866 .41978 Mtetra
.702 .765 .901 r
.56866 .41978 .57719 .42956 .59356 .42288 .58509 .41247 Mtetra
.716 .758 .886 r
.58509 .41247 .59356 .42288 .60998 .41471 .60157 .40431 Mtetra
.66 .741 .91 r
.60157 .40431 .60998 .41471 .62652 .40816 .61821 .39877 Mtetra
.424 .66 .959 r
.61821 .39877 .62652 .40816 .6434 .4088 .63517 .39992 Mtetra
.226 .56 .936 r
.63517 .39992 .6434 .4088 .66062 .41346 .65244 .40462 Mtetra
.418 .674 .967 r
.65244 .40462 .66062 .41346 .67792 .41536 .66976 .40557 Mtetra
.672 .766 .921 r
.66976 .40557 .67792 .41536 .69501 .40989 .68689 .39932 Mtetra
.769 .78 .862 r
.68689 .39932 .69501 .40989 .71187 .3985 .70382 .3877 Mtetra
.751 .772 .871 r
.70382 .3877 .71187 .3985 .72881 .38784 .72086 .37722 Mtetra
.7 .761 .899 r
.72086 .37722 .72881 .38784 .746 .37998 .73814 .36957 Mtetra
.657 .751 .919 r
.73814 .36957 .746 .37998 .76343 .37428 .75565 .36385 Mtetra
.656 .751 .92 r
.75565 .36385 .76343 .37428 .78098 .36865 .77327 .35816 Mtetra
.661 .754 .919 r
.77327 .35816 .78098 .36865 .79861 .36277 .79098 .35219 Mtetra
.655 .751 .92 r
.79098 .35219 .79861 .36277 .81637 .35705 .80882 .34644 Mtetra
.652 .75 .921 r
.80882 .34644 .81637 .35705 .83426 .35146 .82678 .34077 Mtetra
.656 .751 .92 r
.82678 .34077 .83426 .35146 .85224 .34569 .84485 .33493 Mtetra
.655 .751 .92 r
.20485 .53011 .21476 .53877 .22921 .53409 .21934 .5254 Mtetra
.659 .752 .919 r
.21934 .5254 .22921 .53409 .24374 .52926 .23393 .52053 Mtetra
.657 .752 .92 r
.23393 .52053 .24374 .52926 .25835 .52452 .24859 .5157 Mtetra
.65 .749 .922 r
.24859 .5157 .25835 .52452 .27303 .51999 .26331 .51112 Mtetra
.656 .751 .92 r
.26331 .51112 .27303 .51999 .2878 .5152 .27813 .5063 Mtetra
.27813 .5063 .2878 .5152 .30266 .51045 .29304 .50145 Mtetra
.612 .737 .935 r
.29304 .50145 .30266 .51045 .31748 .50757 .30794 .49802 Mtetra
.51 .687 .947 r
.30794 .49802 .31748 .50757 .33224 .50744 .32276 .49739 Mtetra
.438 .644 .945 r
.32276 .49739 .33224 .50744 .34706 .50846 .33761 .49847 Mtetra
.597 .713 .925 r
.33761 .49847 .34706 .50846 .36228 .50428 .35281 .49555 Mtetra
.751 .782 .878 r
.35281 .49555 .36228 .50428 .37791 .49307 .36843 .48606 Mtetra
.83 .82 .84 r
.36843 .48606 .37791 .49307 .39371 .47816 .38431 .4713 Mtetra
.806 .828 .868 r
.38431 .4713 .39371 .47816 .40938 .46668 .40011 .45883 Mtetra
.707 .798 .921 r
.40011 .45883 .40938 .46668 .42489 .46177 .41575 .45171 Mtetra
.59 .713 .928 r
.41575 .45171 .42489 .46177 .44042 .45944 .43134 .44892 Mtetra
.597 .706 .92 r
.43134 .44892 .44042 .45944 .45608 .45629 .44704 .44597 Mtetra
.635 .725 .913 r
.44704 .44597 .45608 .45629 .47188 .45096 .46288 .44163 Mtetra
.662 .758 .921 r
.46288 .44163 .47188 .45096 .48777 .44619 .47884 .43621 Mtetra
.658 .743 .913 r
.47884 .43621 .48777 .44619 .50375 .44176 .49488 .43091 Mtetra
.656 .725 .9 r
.49488 .43091 .50375 .44176 .51984 .43654 .51102 .42564 Mtetra
.655 .725 .9 r
.51102 .42564 .51984 .43654 .53602 .43054 .52726 .42039 Mtetra
.651 .741 .915 r
.52726 .42039 .53602 .43054 .55229 .42488 .5436 .41527 Mtetra
.677 .763 .916 r
.5436 .41527 .55229 .42488 .56866 .41978 .56002 .40905 Mtetra
.704 .749 .886 r
.56002 .40905 .56866 .41978 .58509 .41247 .57651 .40142 Mtetra
.706 .744 .881 r
.57651 .40142 .58509 .41247 .60157 .40431 .59307 .39362 Mtetra
.603 .715 .923 r
.59307 .39362 .60157 .40431 .61821 .39877 .60983 .3902 Mtetra
.352 .646 .965 r
.60983 .3902 .61821 .39877 .63517 .39992 .62688 .39226 Mtetra
.179 .567 .935 r
.62688 .39226 .63517 .39992 .65244 .40462 .6442 .39669 Mtetra
.478 .732 .982 r
.6442 .39669 .65244 .40462 .66976 .40557 .66151 .39576 Mtetra
.703 .778 .91 r
.66151 .39576 .66976 .40557 .68689 .39932 .67865 .3881 Mtetra
.767 .77 .855 r
.67865 .3881 .68689 .39932 .70382 .3877 .69565 .3763 Mtetra
.74 .76 .869 r
.69565 .3763 .70382 .3877 .72086 .37722 .7128 .36623 Mtetra
.689 .752 .899 r
.7128 .36623 .72086 .37722 .73814 .36957 .73019 .35903 Mtetra
.656 .75 .919 r
.73019 .35903 .73814 .36957 .75565 .36385 .74778 .35329 Mtetra
.656 .751 .92 r
.74778 .35329 .75565 .36385 .77327 .35816 .76548 .34752 Mtetra
.661 .753 .918 r
.76548 .34752 .77327 .35816 .79098 .35219 .78326 .34148 Mtetra
.654 .75 .92 r
.78326 .34148 .79098 .35219 .80882 .34644 .80119 .33571 Mtetra
.653 .751 .921 r
.80119 .33571 .80882 .34644 .82678 .34077 .81923 .32996 Mtetra
.656 .752 .92 r
.81923 .32996 .82678 .34077 .84485 .33493 .83737 .32403 Mtetra
.655 .751 .92 r
.19484 .52135 .20485 .53011 .21934 .5254 .20938 .51662 Mtetra
.658 .752 .919 r
.20938 .51662 .21934 .5254 .23393 .52053 .22401 .51173 Mtetra
.659 .753 .919 r
.22401 .51173 .23393 .52053 .24859 .5157 .23872 .50679 Mtetra
.65 .749 .922 r
.23872 .50679 .24859 .5157 .26331 .51112 .25349 .50214 Mtetra
.654 .75 .92 r
.25349 .50214 .26331 .51112 .27813 .5063 .26836 .49731 Mtetra
.656 .752 .92 r
.26836 .49731 .27813 .5063 .29304 .50145 .28332 .49238 Mtetra
.634 .745 .928 r
.28332 .49238 .29304 .50145 .30794 .49802 .29831 .48822 Mtetra
.535 .694 .941 r
.29831 .48822 .30794 .49802 .32276 .49739 .31321 .48699 Mtetra
.457 .647 .94 r
.31321 .48699 .32276 .49739 .33761 .49847 .32811 .48772 Mtetra
.544 .678 .926 r
.32811 .48772 .33761 .49847 .35281 .49555 .34325 .48644 Mtetra
.705 .768 .901 r
.34325 .48644 .35281 .49555 .36843 .48606 .35882 .4793 Mtetra
.817 .829 .859 r
.35882 .4793 .36843 .48606 .38431 .4713 .37474 .46586 Mtetra
.828 .86 .87 r
.37474 .46586 .38431 .4713 .40011 .45883 .39067 .45224 Mtetra
.77 .838 .904 r
.39067 .45224 .40011 .45883 .41575 .45171 .40649 .44219 Mtetra
.637 .744 .925 r
.40649 .44219 .41575 .45171 .43134 .44892 .42218 .43771 Mtetra
.599 .694 .91 r
.42218 .43771 .43134 .44892 .44704 .44597 .43793 .4347 Mtetra
.614 .7 .906 r
.43793 .4347 .44704 .44597 .46288 .44163 .4538 .43114 Mtetra
.635 .725 .913 r
.4538 .43114 .46288 .44163 .47884 .43621 .46979 .42671 Mtetra
.656 .756 .923 r
.46979 .42671 .47884 .43621 .49488 .43091 .4859 .42142 Mtetra
.656 .757 .924 r
.4859 .42142 .49488 .43091 .51102 .42564 .50211 .41609 Mtetra
.50211 .41609 .51102 .42564 .52726 .42039 .51841 .41072 Mtetra
.677 .762 .915 r
.51841 .41072 .52726 .42039 .5436 .41527 .5348 .40448 Mtetra
.693 .745 .891 r
.5348 .40448 .5436 .41527 .56002 .40905 .55128 .39736 Mtetra
.701 .731 .874 r
.55128 .39736 .56002 .40905 .57651 .40142 .56783 .38967 Mtetra
.671 .721 .887 r
.56783 .38967 .57651 .40142 .59307 .39362 .58449 .38346 Mtetra
.501 .684 .949 r
.58449 .38346 .59307 .39362 .60983 .3902 .60138 .38291 Mtetra
.235 .615 .955 r
.60138 .38291 .60983 .3902 .62688 .39226 .61853 .38602 Mtetra
.191 .617 .946 r
.61853 .38602 .62688 .39226 .6442 .39669 .63587 .38901 Mtetra
.573 .784 .979 r
.63587 .38901 .6442 .39669 .66151 .39576 .65315 .38555 Mtetra
.736 .782 .89 r
.65315 .38555 .66151 .39576 .67865 .3881 .67029 .37609 Mtetra
.759 .755 .849 r
.67029 .37609 .67865 .3881 .69565 .3763 .68739 .36453 Mtetra
.73 .752 .87 r
.68739 .36453 .69565 .3763 .7128 .36623 .70464 .35495 Mtetra
.674 .743 .903 r
.70464 .35495 .7128 .36623 .73019 .35903 .72215 .34839 Mtetra
.655 .751 .92 r
.72215 .34839 .73019 .35903 .74778 .35329 .73982 .34262 Mtetra
.657 .752 .92 r
.73982 .34262 .74778 .35329 .76548 .34752 .75759 .33674 Mtetra
.661 .753 .918 r
.75759 .33674 .76548 .34752 .78326 .34148 .77546 .33065 Mtetra
.653 .75 .921 r
.77546 .33065 .78326 .34148 .80119 .33571 .79346 .32486 Mtetra
.653 .751 .921 r
.79346 .32486 .80119 .33571 .81923 .32996 .81158 .31902 Mtetra
.657 .752 .92 r
.81158 .31902 .81923 .32996 .83737 .32403 .8298 .313 Mtetra
.654 .75 .921 r
.18472 .5125 .19484 .52135 .20938 .51662 .19931 .50774 Mtetra
.657 .752 .92 r
.19931 .50774 .20938 .51662 .22401 .51173 .21398 .50283 Mtetra
.66 .753 .919 r
.21398 .50283 .22401 .51173 .23872 .50679 .22875 .49781 Mtetra
.652 .751 .922 r
.22875 .49781 .23872 .50679 .25349 .50214 .24357 .49305 Mtetra
.653 .749 .921 r
.24357 .49305 .25349 .50214 .26836 .49731 .25849 .48823 Mtetra
.656 .751 .92 r
.25849 .48823 .26836 .49731 .28332 .49238 .2735 .48328 Mtetra
.648 .75 .924 r
.2735 .48328 .28332 .49238 .29831 .48822 .28857 .47857 Mtetra
.572 .714 .938 r
.28857 .47857 .29831 .48822 .31321 .48699 .30358 .47626 Mtetra
.495 .659 .934 r
.30358 .47626 .31321 .48699 .32811 .48772 .31855 .47617 Mtetra
.494 .641 .921 r
.31855 .47617 .32811 .48772 .34325 .48644 .33364 .47633 Mtetra
.647 .733 .912 r
.33364 .47633 .34325 .48644 .35882 .4793 .34913 .47155 Mtetra
.768 .81 .886 r
.34913 .47155 .35882 .4793 .37474 .46586 .36499 .46122 Mtetra
.835 .879 .875 r
.36499 .46122 .37474 .46586 .39067 .45224 .38104 .44732 Mtetra
.804 .879 .901 r
.38104 .44732 .39067 .45224 .40649 .44219 .39702 .43554 Mtetra
.733 .837 .929 r
.39702 .43554 .40649 .44219 .42218 .43771 .41291 .4272 Mtetra
.634 .724 .913 r
.41291 .4272 .42218 .43771 .43793 .4347 .42874 .4228 Mtetra
.615 .69 .897 r
.42874 .4228 .43793 .4347 .4538 .43114 .44466 .41917 Mtetra
.629 .695 .893 r
.44466 .41917 .4538 .43114 .46979 .42671 .46069 .41494 Mtetra
.642 .705 .893 r
.46069 .41494 .46979 .42671 .4859 .42142 .47685 .41015 Mtetra
.656 .721 .897 r
.47685 .41015 .4859 .42142 .50211 .41609 .49311 .40476 Mtetra
.669 .726 .892 r
.49311 .40476 .50211 .41609 .51841 .41072 .50947 .39876 Mtetra
.678 .718 .879 r
.50947 .39876 .51841 .41072 .5348 .40448 .52592 .3922 Mtetra
.689 .717 .871 r
.52592 .3922 .5348 .40448 .55128 .39736 .54245 .38502 Mtetra
.673 .712 .877 r
.54245 .38502 .55128 .39736 .56783 .38967 .55908 .37862 Mtetra
.571 .698 .927 r
.55908 .37862 .56783 .38967 .58449 .38346 .57586 .37621 Mtetra
.349 .685 .98 r
.57586 .37621 .58449 .38346 .60138 .38291 .59286 .37731 Mtetra
.128 .592 .921 r
.59286 .37731 .60138 .38291 .61853 .38602 .61008 .3806 Mtetra
.357 .741 .987 r
.61008 .3806 .61853 .38602 .63587 .38901 .6274 .38029 Mtetra
.66 .793 .946 r
.6274 .38029 .63587 .38901 .65315 .38555 .64466 .3743 Mtetra
.756 .769 .864 r
.64466 .3743 .65315 .38555 .67029 .37609 .66181 .36324 Mtetra
.743 .738 .847 r
.66181 .36324 .67029 .37609 .68739 .36453 .67902 .3524 Mtetra
.71 .741 .875 r
.67902 .3524 .68739 .36453 .70464 .35495 .69641 .34381 Mtetra
.662 .744 .911 r
.69641 .34381 .70464 .35495 .72215 .34839 .71403 .3377 Mtetra
.656 .752 .921 r
.71403 .3377 .72215 .34839 .73982 .34262 .73177 .33183 Mtetra
.659 .753 .92 r
.73177 .33183 .73982 .34262 .75759 .33674 .74961 .32581 Mtetra
.659 .751 .918 r
.74961 .32581 .75759 .33674 .77546 .33065 .76756 .31973 Mtetra
.652 .75 .921 r
.76756 .31973 .77546 .33065 .79346 .32486 .78565 .3139 Mtetra
.654 .752 .921 r
.78565 .3139 .79346 .32486 .81158 .31902 .80384 .30796 Mtetra
.657 .752 .92 r
.80384 .30796 .81158 .31902 .8298 .313 .82214 .30184 Mtetra
.653 .75 .921 r
.1745 .50355 .18472 .5125 .19931 .50774 .18913 .49877 Mtetra
.657 .752 .92 r
.18913 .49877 .19931 .50774 .21398 .50283 .20385 .49384 Mtetra
.66 .753 .919 r
.20385 .49384 .21398 .50283 .22875 .49781 .21867 .48877 Mtetra
.655 .752 .921 r
.21867 .48877 .22875 .49781 .24357 .49305 .23355 .48385 Mtetra
.65 .748 .921 r
.23355 .48385 .24357 .49305 .25849 .48823 .24851 .47906 Mtetra
.656 .752 .92 r
.24851 .47906 .25849 .48823 .2735 .48328 .26357 .47404 Mtetra
.655 .751 .92 r
.26357 .47404 .2735 .48328 .28857 .47857 .27872 .46902 Mtetra
.614 .733 .931 r
.27872 .46902 .28857 .47857 .30358 .47626 .29385 .4654 Mtetra
.538 .677 .928 r
.29385 .4654 .30358 .47626 .31855 .47617 .30893 .46418 Mtetra
.488 .632 .916 r
.30893 .46418 .31855 .47617 .33364 .47633 .32403 .46452 Mtetra
.567 .671 .909 r
.32403 .46452 .33364 .47633 .34913 .47155 .3394 .46257 Mtetra
.694 .774 .913 r
.3394 .46257 .34913 .47155 .36499 .46122 .35514 .4558 Mtetra
.799 .868 .899 r
.35514 .4558 .36499 .46122 .38104 .44732 .37119 .44415 Mtetra
.825 .918 .899 r
.37119 .44415 .38104 .44732 .39702 .43554 .38733 .43116 Mtetra
.781 .897 .925 r
.38733 .43116 .39702 .43554 .41291 .4272 .40339 .42056 Mtetra
.73 .84 .933 r
.40339 .42056 .41291 .4272 .42874 .4228 .41942 .41228 Mtetra
.656 .735 .908 r
.41942 .41228 .42874 .4228 .44466 .41917 .43543 .40694 Mtetra
.639 .697 .887 r
.43543 .40694 .44466 .41917 .46069 .41494 .45153 .40224 Mtetra
.643 .691 .879 r
.45153 .40224 .46069 .41494 .47685 .41015 .46772 .39731 Mtetra
.654 .693 .875 r
.46772 .39731 .47685 .41015 .49311 .40476 .48403 .39186 Mtetra
.664 .697 .871 r
.48403 .39186 .49311 .40476 .50947 .39876 .50044 .38587 Mtetra
.668 .7 .871 r
.50044 .38587 .50947 .39876 .52592 .3922 .51695 .37966 Mtetra
.655 .703 .882 r
.51695 .37966 .52592 .3922 .54245 .38502 .53354 .37408 Mtetra
.575 .703 .929 r
.53354 .37408 .54245 .38502 .55908 .37862 .55027 .37148 Mtetra
.415 .725 .989 r
.55027 .37148 .55908 .37862 .57586 .37621 .56715 .37125 Mtetra
.158 .631 .928 r
.56715 .37125 .57586 .37621 .59286 .37731 .58425 .37347 Mtetra
.187 .676 .924 r
.58425 .37347 .59286 .37731 .61008 .3806 .6015 .37437 Mtetra
.57 .825 .993 r
.6015 .37437 .61008 .3806 .6274 .38029 .61878 .3703 Mtetra
.727 .787 .9 r
.61878 .3703 .6274 .38029 .64466 .3743 .63602 .36129 Mtetra
.749 .739 .842 r
.63602 .36129 .64466 .3743 .66181 .36324 .65324 .34991 Mtetra
.725 .726 .852 r
.65324 .34991 .66181 .36324 .67902 .3524 .67057 .34011 Mtetra
.686 .731 .885 r
.67057 .34011 .67902 .3524 .69641 .34381 .6881 .33276 Mtetra
.656 .746 .916 r
.6881 .33276 .69641 .34381 .71403 .3377 .7058 .32684 Mtetra
.656 .751 .92 r
.7058 .32684 .71403 .3377 .73177 .33183 .72362 .32092 Mtetra
.661 .754 .919 r
.72362 .32092 .73177 .33183 .74961 .32581 .74154 .31475 Mtetra
.657 .75 .919 r
.74154 .31475 .74961 .32581 .76756 .31973 .75958 .3087 Mtetra
.652 .751 .922 r
.75958 .3087 .76756 .31973 .78565 .3139 .77774 .30281 Mtetra
.655 .752 .921 r
.77774 .30281 .78565 .3139 .80384 .30796 .79602 .29676 Mtetra
.658 .752 .92 r
.79602 .29676 .80384 .30796 .82214 .30184 .8144 .29053 Mtetra
.653 .75 .921 r
.16418 .4945 .1745 .50355 .18913 .49877 .17885 .48969 Mtetra
.656 .751 .92 r
.17885 .48969 .18913 .49877 .20385 .49384 .19362 .48474 Mtetra
.659 .753 .919 r
.19362 .48474 .20385 .49384 .21867 .48877 .20848 .47965 Mtetra
.658 .753 .92 r
.20848 .47965 .21867 .48877 .23355 .48385 .22342 .47456 Mtetra
.65 .748 .921 r
.22342 .47456 .23355 .48385 .24851 .47906 .23843 .46972 Mtetra
.654 .75 .92 r
.23843 .46972 .24851 .47906 .26357 .47404 .25354 .4647 Mtetra
.656 .751 .92 r
.25354 .4647 .26357 .47404 .27872 .46902 .26874 .4596 Mtetra
.645 .748 .924 r
.26874 .4596 .27872 .46902 .29385 .4654 .284 .45486 Mtetra
.579 .702 .926 r
.284 .45486 .29385 .4654 .30893 .46418 .2992 .45235 Mtetra
.526 .654 .916 r
.2992 .45235 .30893 .46418 .32403 .46452 .31439 .45157 Mtetra
.515 .628 .901 r
.31439 .45157 .32403 .46452 .3394 .46257 .32969 .45132 Mtetra
.611 .703 .909 r
.32969 .45132 .3394 .46257 .35514 .4558 .34531 .44776 Mtetra
.708 .802 .923 r
.34531 .44776 .35514 .4558 .37119 .44415 .36122 .44039 Mtetra
.792 .91 .921 r
.36122 .44039 .37119 .44415 .38733 .43116 .37739 .42914 Mtetra
.797 .949 .92 r
.37739 .42914 .38733 .43116 .40339 .42056 .39361 .41733 Mtetra
.761 .927 .943 r
.39361 .41733 .40339 .42056 .41942 .41228 .4098 .40731 Mtetra
.723 .885 .955 r
.4098 .40731 .41942 .41228 .43543 .40694 .42598 .39902 Mtetra
.694 .808 .936 r
.42598 .39902 .43543 .40694 .45153 .40224 .4422 .39207 Mtetra
.671 .752 .912 r
.4422 .39207 .45153 .40224 .46772 .39731 .45848 .386 Mtetra
.656 .725 .9 r
.45848 .386 .46772 .39731 .48403 .39186 .47485 .38049 Mtetra
.642 .72 .905 r
.47485 .38049 .48403 .39186 .50044 .38587 .49131 .37552 Mtetra
.616 .733 .93 r
.49131 .37552 .50044 .38587 .51695 .37966 .50786 .37145 Mtetra
.552 .761 .975 r
.50786 .37145 .51695 .37966 .53354 .37408 .52454 .36874 Mtetra
.389 .762 .992 r
.52454 .36874 .53354 .37408 .55027 .37148 .54135 .36778 Mtetra
.175 .671 .917 r
.54135 .36778 .55027 .37148 .56715 .37125 .55834 .36867 Mtetra
.145 .67 .878 r
.55834 .36867 .56715 .37125 .58425 .37347 .5755 .36902 Mtetra
.499 .841 .997 r
.5755 .36902 .58425 .37347 .6015 .37437 .59274 .36544 Mtetra
.696 .803 .931 r
.59274 .36544 .6015 .37437 .61878 .3703 .61001 .35798 Mtetra
.746 .75 .855 r
.61001 .35798 .61878 .3703 .63602 .36129 .62726 .3471 Mtetra
.728 .715 .838 r
.62726 .3471 .63602 .36129 .65324 .34991 .64459 .33673 Mtetra
.705 .724 .865 r
.64459 .33673 .65324 .34991 .67057 .34011 .66205 .32814 Mtetra
.664 .732 .9 r
.66205 .32814 .67057 .34011 .6881 .33276 .6797 .32181 Mtetra
.656 .75 .92 r
.6797 .32181 .6881 .33276 .7058 .32684 .69748 .31586 Mtetra
.657 .752 .92 r
.69748 .31586 .7058 .32684 .72362 .32092 .71538 .3098 Mtetra
.661 .752 .918 r
.71538 .3098 .72362 .32092 .74154 .31475 .73337 .30356 Mtetra
.654 .749 .92 r
.73337 .30356 .74154 .31475 .75958 .3087 .7515 .29757 Mtetra
.653 .751 .922 r
.7515 .29757 .75958 .3087 .77774 .30281 .76974 .29157 Mtetra
.656 .752 .921 r
.76974 .29157 .77774 .30281 .79602 .29676 .7881 .28541 Mtetra
.659 .752 .919 r
.7881 .28541 .79602 .29676 .8144 .29053 .80656 .2791 Mtetra
.653 .75 .921 r
.15374 .48536 .16418 .4945 .17885 .48969 .16846 .48048 Mtetra
.654 .75 .92 r
.16846 .48048 .17885 .48969 .19362 .48474 .18327 .47554 Mtetra
.657 .752 .92 r
.18327 .47554 .19362 .48474 .20848 .47965 .19818 .47045 Mtetra
.66 .754 .92 r
.19818 .47045 .20848 .47965 .22342 .47456 .21318 .46524 Mtetra
.653 .751 .921 r
.21318 .46524 .22342 .47456 .23843 .46972 .22825 .46024 Mtetra
.651 .748 .92 r
.22825 .46024 .23843 .46972 .25354 .4647 .24339 .45529 Mtetra
.656 .752 .92 r
.24339 .45529 .25354 .4647 .26874 .4596 .25865 .45013 Mtetra
.656 .752 .921 r
.25865 .45013 .26874 .4596 .284 .45486 .27399 .44494 Mtetra
.629 .735 .924 r
.27399 .44494 .284 .45486 .2992 .45235 .28935 .44071 Mtetra
.567 .678 .914 r
.28935 .44071 .2992 .45235 .31439 .45157 .30466 .43863 Mtetra
.531 .638 .901 r
.30466 .43863 .31439 .45157 .32969 .45132 .32002 .43783 Mtetra
.541 .633 .891 r
.32002 .43783 .32969 .45132 .34531 .44776 .33552 .43681 Mtetra
.623 .717 .913 r
.33552 .43681 .34531 .44776 .36122 .44039 .35131 .43271 Mtetra
.695 .811 .937 r
.35131 .43271 .36122 .44039 .37739 .42914 .36735 .42576 Mtetra
.748 .922 .949 r
.36735 .42576 .37739 .42914 .39361 .41733 .38358 .41621 Mtetra
.739 .965 .936 r
.38358 .41621 .39361 .41733 .4098 .40731 .3999 .40592 Mtetra
.713 .959 .946 r
.3999 .40592 .4098 .40731 .42598 .39902 .41623 .39649 Mtetra
.678 .934 .968 r
.41623 .39649 .42598 .39902 .4422 .39207 .43258 .38853 Mtetra
.644 .906 .982 r
.43258 .38853 .4422 .39207 .45848 .386 .44897 .38186 Mtetra
.606 .883 .991 r
.44897 .38186 .45848 .386 .47485 .38049 .46543 .37629 Mtetra
.553 .864 .996 r
.46543 .37629 .47485 .38049 .49131 .37552 .48198 .37182 Mtetra
.459 .836 .989 r
.48198 .37182 .49131 .37552 .50786 .37145 .49862 .36865 Mtetra
.31 .774 .944 r
.49862 .36865 .50786 .37145 .52454 .36874 .51539 .36699 Mtetra
.176 .702 .865 r
.51539 .36699 .52454 .36874 .54135 .36778 .53231 .36621 Mtetra
.22 .733 .877 r
.53231 .36621 .54135 .36778 .55834 .36867 .54938 .3647 Mtetra
.512 .858 .993 r
.54938 .3647 .55834 .36867 .5755 .36902 .56656 .36057 Mtetra
.684 .811 .943 r
.56656 .36057 .5755 .36902 .59274 .36544 .58382 .35354 Mtetra
.738 .756 .867 r
.58382 .35354 .59274 .36544 .61001 .35798 .6011 .34334 Mtetra
.726 .709 .834 r
.6011 .34334 .61001 .35798 .62726 .3471 .61843 .3329 Mtetra
.709 .71 .849 r
.61843 .3329 .62726 .3471 .64459 .33673 .63586 .32375 Mtetra
.675 .718 .881 r
.63586 .32375 .64459 .33673 .66205 .32814 .65346 .31678 Mtetra
.656 .743 .914 r
.65346 .31678 .66205 .32814 .6797 .32181 .67121 .31079 Mtetra
.656 .752 .921 r
.67121 .31079 .6797 .32181 .69748 .31586 .68907 .30476 Mtetra
.66 .753 .919 r
.68907 .30476 .69748 .31586 .71538 .3098 .70703 .29852 Mtetra
.658 .75 .918 r
.70703 .29852 .71538 .3098 .73337 .30356 .72511 .29232 Mtetra
.652 .75 .921 r
.72511 .29232 .73337 .30356 .7515 .29757 .74333 .28632 Mtetra
.654 .752 .922 r
.74333 .28632 .7515 .29757 .76974 .29157 .76165 .28019 Mtetra
.657 .752 .92 r
.76165 .28019 .76974 .29157 .7881 .28541 .78008 .2739 Mtetra
.658 .751 .919 r
.78008 .2739 .7881 .28541 .80656 .2791 .79863 .26754 Mtetra
.655 .752 .921 r
.14319 .47618 .15374 .48536 .16846 .48048 .15796 .47117 Mtetra
.653 .75 .921 r
.15796 .47117 .16846 .48048 .18327 .47554 .17282 .46622 Mtetra
.656 .751 .92 r
.17282 .46622 .18327 .47554 .19818 .47045 .18777 .46112 Mtetra
.659 .753 .92 r
.18777 .46112 .19818 .47045 .21318 .46524 .20282 .45589 Mtetra
.658 .753 .92 r
.20282 .45589 .21318 .46524 .22825 .46024 .21795 .45066 Mtetra
.651 .748 .921 r
.21795 .45066 .22825 .46024 .24339 .45529 .23315 .44567 Mtetra
.654 .749 .92 r
.23315 .44567 .24339 .45529 .25865 .45013 .24845 .44054 Mtetra
.655 .751 .921 r
.24845 .44054 .25865 .45013 .27399 .44494 .26384 .43533 Mtetra
.654 .752 .921 r
.26384 .43533 .27399 .44494 .28935 .44071 .27932 .43013 Mtetra
.618 .721 .919 r
.27932 .43013 .28935 .44071 .30466 .43863 .2948 .42621 Mtetra
.573 .668 .903 r
.2948 .42621 .30466 .43863 .32002 .43783 .31028 .42396 Mtetra
.548 .631 .886 r
.31028 .42396 .32002 .43783 .33552 .43681 .32581 .42268 Mtetra
.556 .632 .882 r
.32581 .42268 .33552 .43681 .35131 .43271 .34149 .42113 Mtetra
.611 .703 .91 r
.34149 .42113 .35131 .43271 .36735 .42576 .35742 .41741 Mtetra
.666 .792 .942 r
.35742 .41741 .36735 .42576 .38358 .41621 .37356 .41147 Mtetra
.682 .885 .973 r
.37356 .41147 .38358 .41621 .3999 .40592 .38984 .40435 Mtetra
.66 .945 .959 r
.38984 .40435 .3999 .40592 .41623 .39649 .40624 .39626 Mtetra
.595 .942 .929 r
.40624 .39626 .41623 .39649 .43258 .38853 .4227 .38849 Mtetra
.526 .916 .915 r
.4227 .38849 .43258 .38853 .44897 .38186 .43921 .3817 Mtetra
.452 .881 .904 r
.43921 .3817 .44897 .38186 .46543 .37629 .45579 .37608 Mtetra
.367 .834 .882 r
.45579 .37608 .46543 .37629 .48198 .37182 .47244 .37163 Mtetra
.286 .785 .853 r
.47244 .37163 .48198 .37182 .49862 .36865 .4892 .36818 Mtetra
.276 .778 .859 r
.4892 .36818 .49862 .36865 .51539 .36699 .50609 .36506 Mtetra
.426 .852 .948 r
.50609 .36506 .51539 .36699 .53231 .36621 .52311 .36097 Mtetra
.599 .863 .993 r
.52311 .36097 .53231 .36621 .54938 .3647 .54024 .35568 Mtetra
.696 .802 .931 r
.54024 .35568 .54938 .3647 .56656 .36057 .55747 .34814 Mtetra
.728 .744 .865 r
.55747 .34814 .56656 .36057 .58382 .35354 .57475 .33838 Mtetra
.718 .699 .831 r
.57475 .33838 .58382 .35354 .6011 .34334 .59209 .32831 Mtetra
.704 .696 .84 r
.59209 .32831 .6011 .34334 .61843 .3329 .60952 .31922 Mtetra
.681 .709 .87 r
.60952 .31922 .61843 .3329 .63586 .32375 .62709 .31181 Mtetra
.657 .733 .906 r
.62709 .31181 .63586 .32375 .65346 .31678 .6448 .30571 Mtetra
.656 .752 .921 r
.6448 .30571 .65346 .31678 .67121 .31079 .66262 .29962 Mtetra
.657 .752 .92 r
.66262 .29962 .67121 .31079 .68907 .30476 .68055 .29345 Mtetra
.66 .752 .918 r
.68055 .29345 .68907 .30476 .70703 .29852 .69859 .28711 Mtetra
.654 .748 .919 r
.69859 .28711 .70703 .29852 .72511 .29232 .71676 .28101 Mtetra
.653 .752 .922 r
.71676 .28101 .72511 .29232 .74333 .28632 .73505 .27491 Mtetra
.656 .752 .921 r
.73505 .27491 .74333 .28632 .76165 .28019 .75346 .26866 Mtetra
.658 .752 .919 r
.75346 .26866 .76165 .28019 .78008 .2739 .77197 .26224 Mtetra
.656 .751 .919 r
.77197 .26224 .78008 .2739 .79863 .26754 .79061 .25588 Mtetra
.657 .752 .92 r
.13252 .4669 .14319 .47618 .15796 .47117 .14735 .46176 Mtetra
.653 .75 .921 r
.14735 .46176 .15796 .47117 .17282 .46622 .16226 .45675 Mtetra
.654 .75 .92 r
.16226 .45675 .17282 .46622 .18777 .46112 .17725 .45166 Mtetra
.657 .752 .92 r
.17725 .45166 .18777 .46112 .20282 .45589 .19235 .44645 Mtetra
.66 .754 .92 r
.19235 .44645 .20282 .45589 .21795 .45066 .20754 .44111 Mtetra
.655 .752 .921 r
.20754 .44111 .21795 .45066 .23315 .44567 .2228 .4359 Mtetra
.651 .747 .92 r
.2228 .4359 .23315 .44567 .24845 .44054 .23814 .43083 Mtetra
.656 .751 .92 r
.23814 .43083 .24845 .44054 .26384 .43533 .25359 .42554 Mtetra
.25359 .42554 .26384 .43533 .27932 .43013 .26913 .42022 Mtetra
.652 .748 .92 r
.26913 .42022 .27932 .43013 .2948 .42621 .28475 .41501 Mtetra
.62 .712 .912 r
.28475 .41501 .2948 .42621 .31028 .42396 .30038 .41096 Mtetra
.586 .666 .894 r
.30038 .41096 .31028 .42396 .32581 .42268 .31604 .40822 Mtetra
.571 .635 .876 r
.31604 .40822 .32581 .42268 .34149 .42113 .33178 .4061 Mtetra
.568 .626 .869 r
.33178 .4061 .34149 .42113 .35742 .41741 .34763 .40409 Mtetra
.593 .666 .89 r
.34763 .40409 .35742 .41741 .37356 .41147 .36367 .40102 Mtetra
.633 .739 .924 r
.36367 .40102 .37356 .41147 .38984 .40435 .37991 .3963 Mtetra
.654 .801 .954 r
.37991 .3963 .38984 .40435 .40624 .39626 .39629 .39062 Mtetra
.645 .859 .981 r
.39629 .39062 .40624 .39626 .4227 .38849 .41278 .38462 Mtetra
.611 .892 .989 r
.41278 .38462 .4227 .38849 .43921 .3817 .42936 .37868 Mtetra
.573 .898 .984 r
.42936 .37868 .43921 .3817 .45579 .37608 .44604 .37301 Mtetra
.558 .892 .985 r
.44604 .37301 .45579 .37608 .47244 .37163 .46282 .3676 Mtetra
.579 .882 .992 r
.46282 .3676 .47244 .37163 .4892 .36818 .4797 .36225 Mtetra
.627 .854 .985 r
.4797 .36225 .4892 .36818 .50609 .36506 .49669 .35658 Mtetra
.674 .807 .947 r
.49669 .35658 .50609 .36506 .52311 .36097 .51379 .34993 Mtetra
.709 .764 .895 r
.51379 .34993 .52311 .36097 .54024 .35568 .53099 .34161 Mtetra
.714 .713 .848 r
.53099 .34161 .54024 .35568 .55747 .34814 .54826 .3322 Mtetra
.703 .683 .828 r
.54826 .3322 .55747 .34814 .57475 .33838 .5656 .32287 Mtetra
.695 .687 .838 r
.5656 .32287 .57475 .33838 .59209 .32831 .58303 .31416 Mtetra
.678 .702 .865 r
.58303 .31416 .59209 .32831 .60952 .31922 .60057 .30677 Mtetra
.658 .725 .898 r
.60057 .30677 .60952 .31922 .62709 .31181 .61824 .30055 Mtetra
.656 .749 .919 r
.61824 .30055 .62709 .31181 .6448 .30571 .63602 .29445 Mtetra
.656 .751 .92 r
.63602 .29445 .6448 .30571 .66262 .29962 .65392 .28831 Mtetra
.66 .753 .919 r
.65392 .28831 .66262 .29962 .68055 .29345 .67193 .28194 Mtetra
.657 .749 .918 r
.67193 .28194 .68055 .29345 .69859 .28711 .69006 .27569 Mtetra
.652 .751 .922 r
.69006 .27569 .69859 .28711 .71676 .28101 .70831 .26958 Mtetra
.655 .753 .922 r
.70831 .26958 .71676 .28101 .73505 .27491 .72668 .26333 Mtetra
.657 .752 .92 r
.72668 .26333 .73505 .27491 .75346 .26866 .74516 .25694 Mtetra
.658 .751 .919 r
.74516 .25694 .75346 .26866 .77197 .26224 .76376 .25046 Mtetra
.654 .75 .92 r
.76376 .25046 .77197 .26224 .79061 .25588 .78249 .2441 Mtetra
.658 .753 .92 r
.12174 .45754 .13252 .4669 .14735 .46176 .13662 .45232 Mtetra
.655 .752 .921 r
.13662 .45232 .14735 .46176 .16226 .45675 .15158 .44717 Mtetra
.653 .749 .92 r
.15158 .44717 .16226 .45675 .17725 .45166 .16662 .44208 Mtetra
.656 .751 .92 r
.16662 .44208 .17725 .45166 .19235 .44645 .18176 .43686 Mtetra
.658 .753 .92 r
.18176 .43686 .19235 .44645 .20754 .44111 .197 .43151 Mtetra
.659 .754 .92 r
.197 .43151 .20754 .44111 .2228 .4359 .21233 .4261 Mtetra
.653 .749 .92 r
.21233 .4261 .2228 .4359 .23814 .43083 .22773 .42088 Mtetra
.651 .747 .92 r
.22773 .42088 .23814 .43083 .25359 .42554 .24322 .4157 Mtetra
.656 .752 .92 r
.24322 .4157 .25359 .42554 .26913 .42022 .25881 .4103 Mtetra
.656 .751 .92 r
.25881 .4103 .26913 .42022 .28475 .41501 .2745 .40488 Mtetra
.653 .747 .919 r
.2745 .40488 .28475 .41501 .30038 .41096 .29028 .39953 Mtetra
.632 .715 .907 r
.29028 .39953 .30038 .41096 .31604 .40822 .3061 .39494 Mtetra
.603 .671 .888 r
.3061 .39494 .31604 .40822 .33178 .4061 .32194 .39149 Mtetra
.595 .646 .871 r
.32194 .39149 .33178 .4061 .34763 .40409 .33789 .38834 Mtetra
.589 .627 .857 r
.33789 .38834 .34763 .40409 .36367 .40102 .35394 .38543 Mtetra
.597 .634 .859 r
.35394 .38543 .36367 .40102 .37991 .3963 .37014 .38216 Mtetra
.614 .665 .876 r
.37014 .38216 .37991 .3963 .39629 .39062 .38649 .37815 Mtetra
.631 .703 .897 r
.38649 .37815 .39629 .39062 .41278 .38462 .40298 .37344 Mtetra
.644 .734 .914 r
.40298 .37344 .41278 .38462 .42936 .37868 .4196 .36816 Mtetra
.655 .752 .922 r
.4196 .36816 .42936 .37868 .44604 .37301 .43634 .36242 Mtetra
.665 .756 .918 r
.43634 .36242 .44604 .37301 .46282 .3676 .4532 .35622 Mtetra
.677 .745 .902 r
.4532 .35622 .46282 .3676 .4797 .36225 .47017 .34944 Mtetra
.687 .723 .877 r
.47017 .34944 .4797 .36225 .49669 .35658 .48724 .34195 Mtetra
.693 .697 .849 r
.48724 .34195 .49669 .35658 .51379 .34993 .5044 .3337 Mtetra
.691 .674 .829 r
.5044 .3337 .51379 .34993 .53099 .34161 .52164 .32507 Mtetra
.686 .669 .828 r
.52164 .32507 .53099 .34161 .54826 .3322 .53897 .31667 Mtetra
.686 .684 .843 r
.53897 .31667 .54826 .3322 .5656 .32287 .55638 .30855 Mtetra
.669 .697 .867 r
.55638 .30855 .5656 .32287 .58303 .31416 .5739 .30159 Mtetra
.657 .724 .898 r
.5739 .30159 .58303 .31416 .60057 .30677 .59154 .2954 Mtetra
.656 .748 .918 r
.59154 .2954 .60057 .30677 .61824 .30055 .60929 .28926 Mtetra
.655 .751 .92 r
.60929 .28926 .61824 .30055 .63602 .29445 .62715 .28311 Mtetra
.66 .753 .919 r
.62715 .28311 .63602 .29445 .65392 .28831 .64512 .27673 Mtetra
.658 .749 .917 r
.64512 .27673 .65392 .28831 .67193 .28194 .66321 .27037 Mtetra
.653 .749 .92 r
.66321 .27037 .67193 .28194 .69006 .27569 .68143 .26421 Mtetra
.654 .753 .922 r
.68143 .26421 .69006 .27569 .70831 .26958 .69976 .25797 Mtetra
.656 .752 .921 r
.69976 .25797 .70831 .26958 .72668 .26333 .71821 .25159 Mtetra
.658 .752 .919 r
.71821 .25159 .72668 .26333 .74516 .25694 .73677 .24507 Mtetra
.656 .75 .919 r
.73677 .24507 .74516 .25694 .76376 .25046 .75546 .2386 Mtetra
.654 .751 .921 r
.75546 .2386 .76376 .25046 .78249 .2441 .77427 .23218 Mtetra
.657 .752 .92 r
.11084 .44805 .12174 .45754 .13662 .45232 .12577 .4428 Mtetra
.657 .753 .92 r
.12577 .4428 .13662 .45232 .15158 .44717 .14079 .43752 Mtetra
.654 .75 .921 r
.14079 .43752 .15158 .44717 .16662 .44208 .15588 .43234 Mtetra
.654 .749 .92 r
.15588 .43234 .16662 .44208 .18176 .43686 .17107 .42713 Mtetra
.656 .752 .92 r
.17107 .42713 .18176 .43686 .197 .43151 .18635 .42179 Mtetra
.659 .754 .92 r
.18635 .42179 .197 .43151 .21233 .4261 .20173 .41634 Mtetra
.658 .754 .921 r
.20173 .41634 .21233 .4261 .22773 .42088 .2172 .41086 Mtetra
.653 .748 .92 r
.2172 .41086 .22773 .42088 .24322 .4157 .23275 .40557 Mtetra
.652 .747 .919 r
.23275 .40557 .24322 .4157 .25881 .4103 .24838 .40029 Mtetra
.656 .752 .92 r
.24838 .40029 .25881 .4103 .2745 .40488 .26413 .39479 Mtetra
.655 .751 .921 r
.26413 .39479 .2745 .40488 .29028 .39953 .27997 .38931 Mtetra
.657 .75 .919 r
.27997 .38931 .29028 .39953 .3061 .39494 .2959 .38374 Mtetra
.646 .728 .909 r
.2959 .38374 .3061 .39494 .32194 .39149 .31191 .37855 Mtetra
.627 .689 .889 r
.31191 .37855 .32194 .39149 .33789 .38834 .32798 .37405 Mtetra
.615 .663 .873 r
.32798 .37405 .33789 .38834 .35394 .38543 .34412 .36998 Mtetra
.615 .646 .858 r
.34412 .36998 .35394 .38543 .37014 .38216 .36039 .36584 Mtetra
.619 .636 .846 r
.36039 .36584 .37014 .38216 .38649 .37815 .37678 .36144 Mtetra
.623 .634 .84 r
.37678 .36144 .38649 .37815 .40298 .37344 .3933 .35676 Mtetra
.633 .639 .839 r
.3933 .35676 .40298 .37344 .4196 .36816 .40994 .35157 Mtetra
.644 .647 .838 r
.40994 .35157 .4196 .36816 .43634 .36242 .42672 .34575 Mtetra
.655 .651 .834 r
.42672 .34575 .43634 .36242 .4532 .35622 .44362 .33931 Mtetra
.662 .652 .83 r
.44362 .33931 .4532 .35622 .47017 .34944 .46062 .33236 Mtetra
.666 .653 .827 r
.46062 .33236 .47017 .34944 .48724 .34195 .47773 .32512 Mtetra
.671 .659 .829 r
.47773 .32512 .48724 .34195 .5044 .3337 .49493 .31759 Mtetra
.675 .671 .839 r
.49493 .31759 .5044 .3337 .52164 .32507 .51222 .31 Mtetra
.671 .686 .855 r
.51222 .31 .52164 .32507 .53897 .31667 .5296 .30282 Mtetra
.661 .702 .877 r
.5296 .30282 .53897 .31667 .55638 .30855 .54709 .29634 Mtetra
.655 .731 .905 r
.54709 .29634 .55638 .30855 .5739 .30159 .56469 .29024 Mtetra
.657 .75 .919 r
.56469 .29024 .5739 .30159 .59154 .2954 .5824 .28405 Mtetra
.655 .751 .92 r
.5824 .28405 .59154 .2954 .60929 .28926 .60023 .27786 Mtetra
.66 .753 .919 r
.60023 .27786 .60929 .28926 .62715 .28311 .61817 .27146 Mtetra
.659 .749 .917 r
.61817 .27146 .62715 .28311 .64512 .27673 .63622 .26505 Mtetra
.653 .748 .919 r
.63622 .26505 .64512 .27673 .66321 .27037 .65439 .25882 Mtetra
.653 .752 .922 r
.65439 .25882 .66321 .27037 .68143 .26421 .67269 .25257 Mtetra
.655 .753 .922 r
.67269 .25257 .68143 .26421 .69976 .25797 .6911 .24618 Mtetra
.658 .752 .92 r
.6911 .24618 .69976 .25797 .71821 .25159 .70963 .23965 Mtetra
.658 .751 .919 r
.70963 .23965 .71821 .25159 .73677 .24507 .72827 .23308 Mtetra
.654 .75 .92 r
.72827 .23308 .73677 .24507 .75546 .2386 .74705 .22661 Mtetra
.654 .752 .921 r
.74705 .22661 .75546 .2386 .77427 .23218 .76596 .22009 Mtetra
.656 .752 .92 r
.09983 .43845 .11084 .44805 .12577 .4428 .1148 .43318 Mtetra
.658 .753 .92 r
.1148 .43318 .12577 .4428 .14079 .43752 .12987 .42783 Mtetra
.657 .752 .92 r
.12987 .42783 .14079 .43752 .15588 .43234 .14503 .42248 Mtetra
.653 .749 .92 r
.14503 .42248 .15588 .43234 .17107 .42713 .16026 .41723 Mtetra
.654 .75 .92 r
.16026 .41723 .17107 .42713 .18635 .42179 .17558 .41191 Mtetra
.656 .752 .92 r
.17558 .41191 .18635 .42179 .20173 .41634 .19101 .40648 Mtetra
.659 .754 .921 r
.19101 .40648 .20173 .41634 .2172 .41086 .20654 .40093 Mtetra
.658 .754 .921 r
.20654 .40093 .2172 .41086 .23275 .40557 .22216 .39537 Mtetra
.653 .748 .919 r
.22216 .39537 .23275 .40557 .24838 .40029 .23785 .38997 Mtetra
.652 .747 .919 r
.23785 .38997 .24838 .40029 .26413 .39479 .25364 .38458 Mtetra
.656 .751 .92 r
.25364 .38458 .26413 .39479 .27997 .38931 .26954 .37902 Mtetra
.26954 .37902 .27997 .38931 .2959 .38374 .28553 .37341 Mtetra
.656 .752 .92 r
.28553 .37341 .2959 .38374 .31191 .37855 .30162 .36776 Mtetra
.655 .743 .915 r
.30162 .36776 .31191 .37855 .32798 .37405 .31781 .36212 Mtetra
.648 .719 .9 r
.31781 .36212 .32798 .37405 .34412 .36998 .33408 .35668 Mtetra
.642 .693 .883 r
.33408 .35668 .34412 .36998 .36039 .36584 .35045 .35141 Mtetra
.634 .673 .869 r
.35045 .35141 .36039 .36584 .37678 .36144 .36691 .34637 Mtetra
.636 .665 .861 r
.36691 .34637 .37678 .36144 .3933 .35676 .38349 .34114 Mtetra
.641 .659 .853 r
.38349 .34114 .3933 .35676 .40994 .35157 .40018 .3356 Mtetra
.646 .658 .847 r
.40018 .3356 .40994 .35157 .42672 .34575 .417 .32971 Mtetra
.652 .66 .845 r
.417 .32971 .42672 .34575 .44362 .33931 .43393 .32347 Mtetra
.658 .667 .847 r
.43393 .32347 .44362 .33931 .46062 .33236 .45097 .31692 Mtetra
.662 .675 .852 r
.45097 .31692 .46062 .33236 .47773 .32512 .46811 .31018 Mtetra
.659 .683 .861 r
.46811 .31018 .47773 .32512 .49493 .31759 .48535 .30366 Mtetra
.658 .7 .877 r
.48535 .30366 .49493 .31759 .51222 .31 .50269 .2973 Mtetra
.655 .722 .898 r
.50269 .2973 .51222 .31 .5296 .30282 .52014 .29114 Mtetra
.655 .743 .914 r
.52014 .29114 .5296 .30282 .54709 .29634 .5377 .285 Mtetra
.656 .751 .92 r
.5377 .285 .54709 .29634 .56469 .29024 .55538 .27881 Mtetra
.55538 .27881 .56469 .29024 .5824 .28405 .57316 .27256 Mtetra
.659 .753 .919 r
.57316 .27256 .5824 .28405 .60023 .27786 .59106 .26613 Mtetra
.658 .749 .917 r
.59106 .26613 .60023 .27786 .61817 .27146 .60908 .2597 Mtetra
.654 .748 .919 r
.60908 .2597 .61817 .27146 .63622 .26505 .62721 .25343 Mtetra
.653 .752 .922 r
.62721 .25343 .63622 .26505 .65439 .25882 .64547 .24714 Mtetra
.655 .753 .922 r
.64547 .24714 .65439 .25882 .67269 .25257 .66384 .24073 Mtetra
.657 .752 .92 r
.66384 .24073 .67269 .25257 .6911 .24618 .68233 .23419 Mtetra
.658 .751 .919 r
.68233 .23419 .6911 .24618 .70963 .23965 .70094 .22756 Mtetra
.655 .75 .919 r
.70094 .22756 .70963 .23965 .72827 .23308 .71968 .22103 Mtetra
.654 .751 .921 r
.71968 .22103 .72827 .23308 .74705 .22661 .73855 .21448 Mtetra
.655 .752 .921 r
.73855 .21448 .74705 .22661 .76596 .22009 .75754 .20785 Mtetra
.655 .751 .92 r
.0887 .42871 .09983 .43845 .1148 .43318 .10372 .42342 Mtetra
.657 .752 .92 r
.10372 .42342 .1148 .43318 .12987 .42783 .11883 .41805 Mtetra
.658 .753 .92 r
.11883 .41805 .12987 .42783 .14503 .42248 .13404 .41261 Mtetra
.656 .752 .92 r
.13404 .41261 .14503 .42248 .16026 .41723 .14934 .40721 Mtetra
.653 .749 .92 r
.14934 .40721 .16026 .41723 .17558 .41191 .16471 .40186 Mtetra
.655 .75 .92 r
.16471 .40186 .17558 .41191 .19101 .40648 .18018 .39644 Mtetra
.656 .752 .92 r
.18018 .39644 .19101 .40648 .20654 .40093 .19576 .39091 Mtetra
.658 .754 .921 r
.19576 .39091 .20654 .40093 .22216 .39537 .21143 .38528 Mtetra
.21143 .38528 .22216 .39537 .23785 .38997 .2272 .37962 Mtetra
.654 .749 .919 r
.2272 .37962 .23785 .38997 .25364 .38458 .24305 .37407 Mtetra
.652 .746 .919 r
.24305 .37407 .25364 .38458 .26954 .37902 .25899 .36857 Mtetra
.654 .749 .92 r
.25899 .36857 .26954 .37902 .28553 .37341 .27504 .36298 Mtetra
.656 .752 .92 r
.27504 .36298 .28553 .37341 .30162 .36776 .29119 .35726 Mtetra
.656 .752 .921 r
.29119 .35726 .30162 .36776 .31781 .36212 .30744 .35153 Mtetra
.655 .751 .92 r
.30744 .35153 .31781 .36212 .33408 .35668 .32379 .34576 Mtetra
.657 .746 .916 r
.32379 .34576 .33408 .35668 .35045 .35141 .34024 .33991 Mtetra
.655 .735 .908 r
.34024 .33991 .35045 .35141 .36691 .34637 .3568 .33409 Mtetra
.653 .721 .898 r
.3568 .33409 .36691 .34637 .38349 .34114 .37345 .32826 Mtetra
.653 .711 .89 r
.37345 .32826 .38349 .34114 .40018 .3356 .39021 .32238 Mtetra
.653 .706 .886 r
.39021 .32238 .40018 .3356 .417 .32971 .40708 .31642 Mtetra
.654 .707 .886 r
.40708 .31642 .417 .32971 .43393 .32347 .42406 .31038 Mtetra
.655 .712 .89 r
.42406 .31038 .43393 .32347 .45097 .31692 .44114 .30429 Mtetra
.655 .721 .898 r
.44114 .30429 .45097 .31692 .46811 .31018 .45834 .29819 Mtetra
.654 .735 .909 r
.45834 .29819 .46811 .31018 .48535 .30366 .47563 .29212 Mtetra
.656 .746 .916 r
.47563 .29212 .48535 .30366 .50269 .2973 .49305 .28595 Mtetra
.656 .751 .92 r
.49305 .28595 .50269 .2973 .52014 .29114 .51057 .27976 Mtetra
.655 .752 .921 r
.51057 .27976 .52014 .29114 .5377 .285 .5282 .27354 Mtetra
.658 .752 .92 r
.5282 .27354 .5377 .285 .55538 .27881 .54595 .26719 Mtetra
.659 .751 .918 r
.54595 .26719 .55538 .27881 .57316 .27256 .56381 .26074 Mtetra
.657 .748 .917 r
.56381 .26074 .57316 .27256 .59106 .26613 .58179 .25433 Mtetra
.654 .748 .919 r
.58179 .25433 .59106 .26613 .60908 .2597 .59989 .24803 Mtetra
.653 .753 .923 r
.59989 .24803 .60908 .2597 .62721 .25343 .6181 .24169 Mtetra
.655 .753 .922 r
.6181 .24169 .62721 .25343 .64547 .24714 .63644 .23524 Mtetra
.657 .752 .92 r
.63644 .23524 .64547 .24714 .66384 .24073 .65489 .22868 Mtetra
.658 .751 .919 r
.65489 .22868 .66384 .24073 .68233 .23419 .67346 .22202 Mtetra
.656 .75 .919 r
.67346 .22202 .68233 .23419 .70094 .22756 .69216 .21542 Mtetra
.654 .751 .921 r
.69216 .21542 .70094 .22756 .71968 .22103 .71099 .20884 Mtetra
.655 .752 .921 r
.71099 .20884 .71968 .22103 .73855 .21448 .72994 .20218 Mtetra
.656 .752 .92 r
.72994 .20218 .73855 .21448 .75754 .20785 .74901 .19542 Mtetra
.654 .75 .92 r
.07745 .41884 .0887 .42871 .10372 .42342 .09251 .41353 Mtetra
.656 .751 .92 r
.09251 .41353 .10372 .42342 .11883 .41805 .10767 .40814 Mtetra
.657 .752 .92 r
.10767 .40814 .11883 .41805 .13404 .41261 .12293 .40267 Mtetra
.657 .753 .92 r
.12293 .40267 .13404 .41261 .14934 .40721 .13828 .39714 Mtetra
.656 .751 .92 r
.13828 .39714 .14934 .40721 .16471 .40186 .15372 .39165 Mtetra
.653 .749 .92 r
.15372 .39165 .16471 .40186 .18018 .39644 .16924 .38621 Mtetra
.655 .75 .92 r
.16924 .38621 .18018 .39644 .19576 .39091 .18486 .38069 Mtetra
.656 .752 .92 r
.18486 .38069 .19576 .39091 .21143 .38528 .20058 .37507 Mtetra
.658 .754 .921 r
.20058 .37507 .21143 .38528 .2272 .37962 .21641 .36937 Mtetra
.658 .755 .921 r
.21641 .36937 .2272 .37962 .24305 .37407 .23233 .36361 Mtetra
.656 .751 .92 r
.23233 .36361 .24305 .37407 .25899 .36857 .24834 .35788 Mtetra
.653 .747 .918 r
.24834 .35788 .25899 .36857 .27504 .36298 .26444 .35225 Mtetra
.653 .747 .919 r
.26444 .35225 .27504 .36298 .29119 .35726 .28064 .34658 Mtetra
.654 .75 .92 r
.28064 .34658 .29119 .35726 .30744 .35153 .29695 .34084 Mtetra
.656 .752 .92 r
.29695 .34084 .30744 .35153 .32379 .34576 .31336 .33499 Mtetra
.656 .751 .92 r
.31336 .33499 .32379 .34576 .34024 .33991 .32988 .3291 Mtetra
.656 .752 .921 r
.32988 .3291 .34024 .33991 .3568 .33409 .34649 .32319 Mtetra
.656 .751 .92 r
.34649 .32319 .3568 .33409 .37345 .32826 .36322 .31724 Mtetra
.656 .75 .919 r
.36322 .31724 .37345 .32826 .39021 .32238 .38004 .31125 Mtetra
.656 .749 .919 r
.38004 .31125 .39021 .32238 .40708 .31642 .39698 .30523 Mtetra
.656 .75 .919 r
.39698 .30523 .40708 .31642 .42406 .31038 .41402 .29915 Mtetra
.41402 .29915 .42406 .31038 .44114 .30429 .43117 .29304 Mtetra
.656 .751 .92 r
.43117 .29304 .44114 .30429 .45834 .29819 .44843 .2869 Mtetra
.656 .752 .921 r
.44843 .2869 .45834 .29819 .47563 .29212 .4658 .28072 Mtetra
.656 .751 .92 r
.4658 .28072 .47563 .29212 .49305 .28595 .48328 .2745 Mtetra
.657 .752 .92 r
.48328 .2745 .49305 .28595 .51057 .27976 .50088 .26817 Mtetra
.658 .751 .919 r
.50088 .26817 .51057 .27976 .5282 .27354 .51859 .26176 Mtetra
.658 .749 .917 r
.51859 .26176 .5282 .27354 .54595 .26719 .53641 .25531 Mtetra
.655 .747 .918 r
.53641 .25531 .54595 .26719 .56381 .26074 .55435 .24895 Mtetra
.653 .75 .921 r
.55435 .24895 .56381 .26074 .58179 .25433 .57241 .24262 Mtetra
.654 .753 .923 r
.57241 .24262 .58179 .25433 .59989 .24803 .59058 .23622 Mtetra
.655 .753 .922 r
.59058 .23622 .59989 .24803 .6181 .24169 .60888 .22973 Mtetra
.657 .752 .92 r
.60888 .22973 .6181 .24169 .63644 .23524 .62729 .22313 Mtetra
.658 .751 .919 r
.62729 .22313 .63644 .23524 .65489 .22868 .64582 .21644 Mtetra
.656 .75 .919 r
.64582 .21644 .65489 .22868 .67346 .22202 .66448 .20979 Mtetra
.654 .751 .921 r
.66448 .20979 .67346 .22202 .69216 .21542 .68327 .20316 Mtetra
.655 .752 .921 r
.68327 .20316 .69216 .21542 .71099 .20884 .70218 .19647 Mtetra
.656 .752 .921 r
.70218 .19647 .71099 .20884 .72994 .20218 .72122 .18969 Mtetra
.657 .752 .92 r
.72122 .18969 .72994 .20218 .74901 .19542 .74038 .18281 Mtetra
.655 .751 .92 r
.06607 .40888 .07745 .41884 .09251 .41353 .08119 .40349 Mtetra
.654 .75 .92 r
.08119 .40349 .09251 .41353 .10767 .40814 .09639 .39809 Mtetra
.656 .752 .92 r
.09639 .39809 .10767 .40814 .12293 .40267 .1117 .39259 Mtetra
.657 .752 .92 r
.1117 .39259 .12293 .40267 .13828 .39714 .1271 .38703 Mtetra
.657 .753 .921 r
.1271 .38703 .13828 .39714 .15372 .39165 .14259 .38141 Mtetra
.656 .751 .92 r
.14259 .38141 .15372 .39165 .16924 .38621 .15818 .37582 Mtetra
.654 .749 .92 r
.15818 .37582 .16924 .38621 .18486 .38069 .17385 .37028 Mtetra
.654 .75 .92 r
.17385 .37028 .18486 .38069 .20058 .37507 .18962 .36467 Mtetra
.656 .752 .92 r
.18962 .36467 .20058 .37507 .21641 .36937 .20549 .35897 Mtetra
.657 .753 .921 r
.20549 .35897 .21641 .36937 .23233 .36361 .22146 .3532 Mtetra
.658 .755 .921 r
.22146 .3532 .23233 .36361 .24834 .35788 .23754 .34735 Mtetra
.658 .754 .921 r
.23754 .34735 .24834 .35788 .26444 .35225 .25372 .34148 Mtetra
.656 .75 .919 r
.25372 .34148 .26444 .35225 .28064 .34658 .26999 .33563 Mtetra
.654 .747 .918 r
.26999 .33563 .28064 .34658 .29695 .34084 .28635 .32982 Mtetra
.28635 .32982 .29695 .34084 .31336 .33499 .30282 .32399 Mtetra
.654 .748 .919 r
.30282 .32399 .31336 .33499 .32988 .3291 .31939 .3181 Mtetra
.655 .75 .92 r
.31939 .3181 .32988 .3291 .34649 .32319 .33607 .31216 Mtetra
.655 .751 .92 r
.33607 .31216 .34649 .32319 .36322 .31724 .35286 .30616 Mtetra
.656 .752 .92 r
.35286 .30616 .36322 .31724 .38004 .31125 .36975 .3001 Mtetra
.36975 .3001 .38004 .31125 .39698 .30523 .38675 .294 Mtetra
.38675 .294 .39698 .30523 .41402 .29915 .40386 .28786 Mtetra
.40386 .28786 .41402 .29915 .43117 .29304 .42108 .28166 Mtetra
.657 .752 .92 r
.42108 .28166 .43117 .29304 .44843 .2869 .43841 .2754 Mtetra
.657 .751 .919 r
.43841 .2754 .44843 .2869 .4658 .28072 .45585 .26908 Mtetra
.658 .75 .918 r
.45585 .26908 .4658 .28072 .48328 .2745 .47341 .2627 Mtetra
.657 .748 .917 r
.47341 .2627 .48328 .2745 .50088 .26817 .49108 .25629 Mtetra
.655 .747 .917 r
.49108 .25629 .50088 .26817 .51859 .26176 .50886 .24992 Mtetra
.654 .749 .919 r
.50886 .24992 .51859 .26176 .53641 .25531 .52676 .24357 Mtetra
.654 .752 .922 r
.52676 .24357 .53641 .25531 .55435 .24895 .54477 .23719 Mtetra
.655 .754 .923 r
.54477 .23719 .55435 .24895 .57241 .24262 .56291 .23073 Mtetra
.656 .753 .922 r
.56291 .23073 .57241 .24262 .59058 .23622 .58116 .22418 Mtetra
.657 .752 .92 r
.58116 .22418 .59058 .23622 .60888 .22973 .59954 .21753 Mtetra
.658 .751 .919 r
.59954 .21753 .60888 .22973 .62729 .22313 .61803 .21081 Mtetra
.656 .75 .919 r
.61803 .21081 .62729 .22313 .64582 .21644 .63665 .20413 Mtetra
.654 .751 .921 r
.63665 .20413 .64582 .21644 .66448 .20979 .65539 .19747 Mtetra
.655 .752 .921 r
.65539 .19747 .66448 .20979 .68327 .20316 .67427 .19074 Mtetra
.656 .752 .921 r
.67427 .19074 .68327 .20316 .70218 .19647 .69326 .18393 Mtetra
.657 .752 .92 r
.69326 .18393 .70218 .19647 .72122 .18969 .71238 .17701 Mtetra
.657 .751 .919 r
.71238 .17701 .72122 .18969 .74038 .18281 .73164 .17006 Mtetra
.656 .752 .92 r
.05456 .39886 .06607 .40888 .08119 .40349 .06974 .39335 Mtetra
.655 .75 .92 r
.06974 .39335 .08119 .40349 .09639 .39809 .08499 .38788 Mtetra
.654 .75 .92 r
.08499 .38788 .09639 .39809 .1117 .39259 .10034 .38238 Mtetra
.656 .752 .92 r
.10034 .38238 .1117 .39259 .1271 .38703 .11579 .37678 Mtetra
.657 .753 .92 r
.11579 .37678 .1271 .38703 .14259 .38141 .13134 .37112 Mtetra
.657 .753 .921 r
.13134 .37112 .14259 .38141 .15818 .37582 .14698 .36541 Mtetra
.656 .752 .92 r
.14698 .36541 .15818 .37582 .17385 .37028 .16272 .3597 Mtetra
.654 .749 .92 r
.16272 .3597 .17385 .37028 .18962 .36467 .17854 .35405 Mtetra
.17854 .35405 .18962 .36467 .20549 .35897 .19446 .34836 Mtetra
.655 .751 .92 r
.19446 .34836 .20549 .35897 .22146 .3532 .21049 .34257 Mtetra
.656 .752 .921 r
.21049 .34257 .22146 .3532 .23754 .34735 .22662 .33673 Mtetra
.657 .754 .922 r
.22662 .33673 .23754 .34735 .25372 .34148 .24285 .33082 Mtetra
.658 .755 .922 r
.24285 .33082 .25372 .34148 .26999 .33563 .25918 .32484 Mtetra
.657 .754 .921 r
.25918 .32484 .26999 .33563 .28635 .32982 .27562 .31884 Mtetra
.657 .751 .919 r
.27562 .31884 .28635 .32982 .30282 .32399 .29216 .31283 Mtetra
.656 .748 .918 r
.29216 .31283 .30282 .32399 .31939 .3181 .3088 .3068 Mtetra
.655 .747 .917 r
.3088 .3068 .31939 .3181 .33607 .31216 .32554 .30078 Mtetra
.655 .746 .917 r
.32554 .30078 .33607 .31216 .35286 .30616 .34239 .29471 Mtetra
.655 .747 .917 r
.34239 .29471 .35286 .30616 .36975 .3001 .35935 .28859 Mtetra
.656 .747 .917 r
.35935 .28859 .36975 .3001 .38675 .294 .37641 .28242 Mtetra
.37641 .28242 .38675 .294 .40386 .28786 .39359 .27619 Mtetra
.39359 .27619 .40386 .28786 .42108 .28166 .41088 .26991 Mtetra
.41088 .26991 .42108 .28166 .43841 .2754 .42828 .26359 Mtetra
.655 .747 .917 r
.42828 .26359 .43841 .2754 .45585 .26908 .44579 .25727 Mtetra
.655 .748 .918 r
.44579 .25727 .45585 .26908 .47341 .2627 .46341 .25093 Mtetra
.654 .75 .92 r
.46341 .25093 .47341 .2627 .49108 .25629 .48115 .24457 Mtetra
.654 .753 .922 r
.48115 .24457 .49108 .25629 .50886 .24992 .49901 .23818 Mtetra
.655 .754 .923 r
.49901 .23818 .50886 .24992 .52676 .24357 .51699 .23172 Mtetra
.655 .754 .922 r
.51699 .23172 .52676 .24357 .54477 .23719 .53508 .22519 Mtetra
.656 .752 .921 r
.53508 .22519 .54477 .23719 .56291 .23073 .55329 .21859 Mtetra
.657 .752 .92 r
.55329 .21859 .56291 .23073 .58116 .22418 .57163 .21189 Mtetra
.657 .75 .919 r
.57163 .21189 .58116 .22418 .59954 .21753 .59008 .20515 Mtetra
.655 .749 .919 r
.59008 .20515 .59954 .21753 .61803 .21081 .60866 .19845 Mtetra
.654 .751 .921 r
.60866 .19845 .61803 .21081 .63665 .20413 .62736 .19174 Mtetra
.655 .752 .921 r
.62736 .19174 .63665 .20413 .65539 .19747 .64619 .18497 Mtetra
.656 .752 .921 r
.64619 .18497 .65539 .19747 .67427 .19074 .66515 .17813 Mtetra
.657 .752 .92 r
.66515 .17813 .67427 .19074 .69326 .18393 .68423 .17117 Mtetra
.657 .751 .919 r
.68423 .17117 .69326 .18393 .71238 .17701 .70344 .16418 Mtetra
.655 .75 .92 r
.70344 .16418 .71238 .17701 .73164 .17006 .72279 .15721 Mtetra
.657 .752 .92 r
.04292 .38874 .05456 .39886 .06974 .39335 .05815 .38316 Mtetra
.656 .752 .92 r
.05815 .38316 .06974 .39335 .08499 .38788 .07346 .37756 Mtetra
.655 .75 .92 r
.07346 .37756 .08499 .38788 .10034 .38238 .08886 .37199 Mtetra
.654 .75 .92 r
.08886 .37199 .10034 .38238 .11579 .37678 .10436 .36639 Mtetra
.656 .752 .92 r
.10436 .36639 .11579 .37678 .13134 .37112 .11995 .3607 Mtetra
.657 .752 .921 r
.11995 .3607 .13134 .37112 .14698 .36541 .13565 .35495 Mtetra
.657 .753 .921 r
.13565 .35495 .14698 .36541 .16272 .3597 .15144 .34914 Mtetra
.657 .752 .92 r
.15144 .34914 .16272 .3597 .17854 .35405 .16733 .34331 Mtetra
.655 .75 .92 r
.16733 .34331 .17854 .35405 .19446 .34836 .18331 .33752 Mtetra
.654 .749 .919 r
.18331 .33752 .19446 .34836 .21049 .34257 .19939 .33172 Mtetra
.654 .75 .92 r
.19939 .33172 .21049 .34257 .22662 .33673 .21557 .32587 Mtetra
.656 .752 .92 r
.21557 .32587 .22662 .33673 .24285 .33082 .23186 .31994 Mtetra
.656 .753 .921 r
.23186 .31994 .24285 .33082 .25918 .32484 .24825 .31396 Mtetra
.656 .754 .922 r
.24825 .31396 .25918 .32484 .27562 .31884 .26475 .30793 Mtetra
.657 .755 .922 r
.26475 .30793 .27562 .31884 .29216 .31283 .28135 .30184 Mtetra
.28135 .30184 .29216 .31283 .3088 .3068 .29805 .29571 Mtetra
.657 .754 .922 r
.29805 .29571 .3088 .3068 .32554 .30078 .31486 .28956 Mtetra
.656 .753 .921 r
.31486 .28956 .32554 .30078 .34239 .29471 .33178 .28337 Mtetra
.656 .752 .92 r
.33178 .28337 .34239 .29471 .35935 .28859 .34881 .27716 Mtetra
.656 .751 .92 r
.34881 .27716 .35935 .28859 .37641 .28242 .36594 .27091 Mtetra
.36594 .27091 .37641 .28242 .39359 .27619 .38319 .26463 Mtetra
.655 .752 .921 r
.38319 .26463 .39359 .27619 .41088 .26991 .40054 .25833 Mtetra
.40054 .25833 .41088 .26991 .42828 .26359 .41801 .25199 Mtetra
.655 .753 .922 r
.41801 .25199 .42828 .26359 .44579 .25727 .4356 .24562 Mtetra
.655 .754 .923 r
.4356 .24562 .44579 .25727 .46341 .25093 .45329 .2392 Mtetra
.45329 .2392 .46341 .25093 .48115 .24457 .47111 .23273 Mtetra
.656 .754 .922 r
.47111 .23273 .48115 .24457 .49901 .23818 .48904 .2262 Mtetra
.656 .753 .921 r
.48904 .2262 .49901 .23818 .51699 .23172 .5071 .21962 Mtetra
.657 .752 .92 r
.5071 .21962 .51699 .23172 .53508 .22519 .52527 .21294 Mtetra
.657 .751 .919 r
.52527 .21294 .53508 .22519 .55329 .21859 .54356 .20621 Mtetra
.657 .75 .918 r
.54356 .20621 .55329 .21859 .57163 .21189 .56197 .19946 Mtetra
.655 .75 .919 r
.56197 .19946 .57163 .21189 .59008 .20515 .58051 .19274 Mtetra
.654 .752 .921 r
.58051 .19274 .59008 .20515 .60866 .19845 .59917 .186 Mtetra
.655 .753 .921 r
.59917 .186 .60866 .19845 .62736 .19174 .61796 .17918 Mtetra
.656 .752 .921 r
.61796 .17918 .62736 .19174 .64619 .18497 .63688 .17229 Mtetra
.657 .752 .92 r
.63688 .17229 .64619 .18497 .66515 .17813 .65592 .1653 Mtetra
.657 .751 .919 r
.65592 .1653 .66515 .17813 .68423 .17117 .67509 .15826 Mtetra
.655 .75 .92 r
.67509 .15826 .68423 .17117 .70344 .16418 .69439 .15125 Mtetra
.655 .751 .921 r
.69439 .15125 .70344 .16418 .72279 .15721 .71383 .1442 Mtetra
.656 .752 .92 r
.03115 .3785 .04292 .38874 .05815 .38316 .04643 .37286 Mtetra
.657 .752 .92 r
.04643 .37286 .05815 .38316 .07346 .37756 .0618 .36718 Mtetra
.656 .752 .92 r
.0618 .36718 .07346 .37756 .08886 .37199 .07726 .36148 Mtetra
.655 .75 .92 r
.07726 .36148 .08886 .37199 .10436 .36639 .0928 .35581 Mtetra
.654 .75 .92 r
.0928 .35581 .10436 .36639 .11995 .3607 .10845 .35011 Mtetra
.656 .751 .92 r
.10845 .35011 .11995 .3607 .13565 .35495 .12419 .34433 Mtetra
.656 .752 .921 r
.12419 .34433 .13565 .35495 .15144 .34914 .14004 .33849 Mtetra
.657 .753 .921 r
.14004 .33849 .15144 .34914 .16733 .34331 .15598 .33259 Mtetra
.15598 .33259 .16733 .34331 .18331 .33752 .17203 .32665 Mtetra
.656 .751 .92 r
.17203 .32665 .18331 .33752 .19939 .33172 .18818 .3207 Mtetra
.655 .749 .919 r
.18818 .3207 .19939 .33172 .21557 .32587 .20442 .31478 Mtetra
.654 .749 .919 r
.20442 .31478 .21557 .32587 .23186 .31994 .22076 .30882 Mtetra
.655 .75 .92 r
.22076 .30882 .23186 .31994 .24825 .31396 .2372 .30282 Mtetra
.655 .751 .92 r
.2372 .30282 .24825 .31396 .26475 .30793 .25376 .29676 Mtetra
.656 .752 .921 r
.25376 .29676 .26475 .30793 .28135 .30184 .27042 .29064 Mtetra
.656 .753 .921 r
.27042 .29064 .28135 .30184 .29805 .29571 .28718 .28447 Mtetra
.656 .753 .922 r
.28718 .28447 .29805 .29571 .31486 .28956 .30406 .27827 Mtetra
.656 .754 .922 r
.30406 .27827 .31486 .28956 .33178 .28337 .32104 .27202 Mtetra
.32104 .27202 .33178 .28337 .34881 .27716 .33814 .26574 Mtetra
.33814 .26574 .34881 .27716 .36594 .27091 .35534 .25942 Mtetra
.35534 .25942 .36594 .27091 .38319 .26463 .37265 .25306 Mtetra
.37265 .25306 .38319 .26463 .40054 .25833 .39008 .24666 Mtetra
.39008 .24666 .40054 .25833 .41801 .25199 .40762 .24022 Mtetra
.656 .753 .922 r
.40762 .24022 .41801 .25199 .4356 .24562 .42528 .23374 Mtetra
.656 .753 .921 r
.42528 .23374 .4356 .24562 .45329 .2392 .44305 .22721 Mtetra
.656 .752 .921 r
.44305 .22721 .45329 .2392 .47111 .23273 .46095 .22062 Mtetra
.657 .752 .92 r
.46095 .22062 .47111 .23273 .48904 .2262 .47896 .21396 Mtetra
.657 .751 .919 r
.47896 .21396 .48904 .2262 .5071 .21962 .49708 .20725 Mtetra
.657 .75 .918 r
.49708 .20725 .5071 .21962 .52527 .21294 .51533 .20049 Mtetra
.655 .749 .919 r
.51533 .20049 .52527 .21294 .54356 .20621 .53371 .19377 Mtetra
.655 .751 .92 r
.53371 .19377 .54356 .20621 .56197 .19946 .5522 .18702 Mtetra
.655 .752 .921 r
.5522 .18702 .56197 .19946 .58051 .19274 .57082 .18022 Mtetra
.655 .753 .921 r
.57082 .18022 .58051 .19274 .59917 .186 .58957 .17335 Mtetra
.656 .752 .921 r
.58957 .17335 .59917 .186 .61796 .17918 .60844 .16641 Mtetra
.657 .752 .92 r
.60844 .16641 .61796 .17918 .63688 .17229 .62744 .15938 Mtetra
.657 .751 .919 r
.62744 .15938 .63688 .17229 .65592 .1653 .64657 .15231 Mtetra
.655 .75 .92 r
.64657 .15231 .65592 .1653 .67509 .15826 .66583 .14526 Mtetra
.655 .751 .921 r
.66583 .14526 .67509 .15826 .69439 .15125 .68523 .13817 Mtetra
.655 .752 .921 r
.68523 .13817 .69439 .15125 .71383 .1442 .70476 .13102 Mtetra
.656 .751 .92 r
.01926 .3681 .03115 .3785 .04643 .37286 .03458 .36244 Mtetra
.656 .752 .92 r
.03458 .36244 .04643 .37286 .0618 .36718 .04999 .35671 Mtetra
.657 .752 .92 r
.04999 .35671 .0618 .36718 .07726 .36148 .06551 .35093 Mtetra
.656 .752 .92 r
.06551 .35093 .07726 .36148 .0928 .35581 .08112 .34513 Mtetra
.655 .75 .92 r
.08112 .34513 .0928 .35581 .10845 .35011 .09681 .33934 Mtetra
.654 .75 .92 r
.09681 .33934 .10845 .35011 .12419 .34433 .11261 .33353 Mtetra
.655 .751 .92 r
.11261 .33353 .12419 .34433 .14004 .33849 .1285 .32767 Mtetra
.656 .752 .92 r
.1285 .32767 .14004 .33849 .15598 .33259 .1445 .32173 Mtetra
.656 .753 .921 r
.1445 .32173 .15598 .33259 .17203 .32665 .16061 .31575 Mtetra
.657 .753 .921 r
.16061 .31575 .17203 .32665 .18818 .3207 .17681 .30971 Mtetra
.17681 .30971 .18818 .3207 .20442 .31478 .19312 .30363 Mtetra
.656 .751 .92 r
.19312 .30363 .20442 .31478 .22076 .30882 .20953 .29754 Mtetra
.655 .749 .919 r
.20953 .29754 .22076 .30882 .2372 .30282 .22604 .29144 Mtetra
.22604 .29144 .2372 .30282 .25376 .29676 .24265 .28532 Mtetra
.24265 .28532 .25376 .29676 .27042 .29064 .25937 .27916 Mtetra
.655 .75 .92 r
.25937 .27916 .27042 .29064 .28718 .28447 .2762 .27296 Mtetra
.2762 .27296 .28718 .28447 .30406 .27827 .29313 .2667 Mtetra
.655 .751 .92 r
.29313 .2667 .30406 .27827 .32104 .27202 .31018 .2604 Mtetra
.656 .751 .92 r
.31018 .2604 .32104 .27202 .33814 .26574 .32734 .25405 Mtetra
.656 .752 .92 r
.32734 .25405 .33814 .26574 .35534 .25942 .34461 .24765 Mtetra
.34461 .24765 .35534 .25942 .37265 .25306 .362 .24121 Mtetra
.362 .24121 .37265 .25306 .39008 .24666 .3795 .23472 Mtetra
.656 .751 .92 r
.3795 .23472 .39008 .24666 .40762 .24022 .39711 .22818 Mtetra
.656 .751 .919 r
.39711 .22818 .40762 .24022 .42528 .23374 .41484 .22158 Mtetra
.657 .75 .919 r
.41484 .22158 .42528 .23374 .44305 .22721 .43269 .21494 Mtetra
.43269 .21494 .44305 .22721 .46095 .22062 .45066 .20825 Mtetra
.656 .749 .918 r
.45066 .20825 .46095 .22062 .47896 .21396 .46874 .20153 Mtetra
.655 .749 .919 r
.46874 .20153 .47896 .21396 .49708 .20725 .48695 .19481 Mtetra
.655 .751 .92 r
.48695 .19481 .49708 .20725 .51533 .20049 .50528 .18806 Mtetra
.655 .752 .921 r
.50528 .18806 .51533 .20049 .53371 .19377 .52373 .18126 Mtetra
.655 .753 .922 r
.52373 .18126 .53371 .19377 .5522 .18702 .54231 .17441 Mtetra
.656 .752 .921 r
.54231 .17441 .5522 .18702 .57082 .18022 .56101 .16749 Mtetra
.656 .752 .92 r
.56101 .16749 .57082 .18022 .58957 .17335 .57984 .16049 Mtetra
.657 .751 .92 r
.57984 .16049 .58957 .17335 .60844 .16641 .5988 .15342 Mtetra
.656 .75 .919 r
.5988 .15342 .60844 .16641 .62744 .15938 .61788 .14633 Mtetra
.655 .75 .92 r
.61788 .14633 .62744 .15938 .64657 .15231 .6371 .13923 Mtetra
.655 .752 .921 r
.6371 .13923 .64657 .15231 .66583 .14526 .65646 .1321 Mtetra
.65646 .1321 .66583 .14526 .68523 .13817 .67594 .12491 Mtetra
.656 .752 .921 r
.67594 .12491 .68523 .13817 .70476 .13102 .69557 .11763 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
[(-2)] .12586 .2075 1 .99877 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.56863 .04703 m
.57247 .05235 L
s
[(2)] .56094 .0364 .72324 1 Mshowa
.125 Mabswid
.18558 .19702 m
.18832 .19985 L
s
.23703 .17687 m
.23971 .17975 L
s
.28951 .15632 m
.29214 .15925 L
s
.39772 .11395 m
.40023 .11699 L
s
.4535 .09211 m
.45595 .0952 L
s
.51046 .06981 m
.51284 .07294 L
s
.08568 .23614 m
.08851 .23887 L
s
.62804 .02377 m
.63027 .02701 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 233.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00o?ooool2o`0006[ooooo003iooooo`?o000000?oooooo`000?ooool0
JOooool00?Oooooo0_l00004ooooo`;o0000JOooool00?Cooooo0ol00006ooooo`03o`000?oooooo
000006Sooooo003;ooooo`Go00008_ooool2o`0000Wooooo00?o0000ooooool00000J?ooool00<_o
oooo00GoV9RHob4Q8Oo^k^koooooodA4A00Oooooo`?o00002oooool01?l0003oooooooooool0001W
ooooo`00c?ooool00onHV9So8B4Qonk^kP0Mooooo`?o00003_ooool01Ol0003ooooooooooooooooo
000006Kooooo003=ooooo`03oiRHV?lQ8B7ok^k^01[ooooo0_l0000Aooooo`05o`000?oooooooooo
ooooool00000I_ooool00<kooooo00?oMgMgofIVI_ooool05_ooool3o`0001?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1Sooooo`00coooool00ol0003oooooooooo`0Cooooo`;o
00000_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0H_ooool00<_ooooo00Go0000okZj^_ooooooV9RHoa0@400Booooo`?o00006Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo06;ooooo003;ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`04?ooool2o`0001cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Qooooo`00
gOooool3o`0001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Qooooo`00fooo
ool2o`00027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Pooooo`00f?ooool3
o`0002?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Oooooo`00eOooool3o`00
02Kooooo00?o0000ooooooooool01?ooool2o`00067ooooo003Cooooo`;o0000:Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo05kooooo003@ooooo`?o000000?oooooo`000?ooool0
:?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05gooooo003>ooooo`;o00001Ooo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0GOoo
ool00<_ooooo0ol0000`ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0G?ooool0
0<Wooooo0_l0000cooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Foooool00<Ko
oooo0ol0000eooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Foooool00<Cooooo
0_l0000hooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0F_ooool00<7ooooo0ol0
000jooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03_ooool5o`0004Kooooo002n
ooooo`?o0000?Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00kooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A016ooooo`00_?ooool2o`0000?ooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo1_l00003ooooo`03oiRHV?lQ8B7o
k^k^04Oooooo002iooooo`?o0000@oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00kooooo00?oV9RHob4Q8Oo^k^h0A_ooool00;Oooooo0_l00016ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03oooool00omgMgOoIVIVooooo`15ooooo`00]?ooool3o`0004Sooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Cooooo
002booooo`;o0000Boooool00ol0003oooooooooo`0=ooooo`;o00003?ooool01Ol0003o^[Zjoooo
oonHV9So410@04Kooooo002_ooooo`?o0000COooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c016ooooo`00[Oooool2o`00053ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`1Dooooo`00Z_ooool4o`00057ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1Dooooo`00Z?ooool2o`0000Cooooo00?o0000oooo
ooooool0C_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05?ooooo001nooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h08_ooool3o`0005Oooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`1Booooo`00O_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01oooooo0ol0001Joooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool0D_ooool007kooooo00Go410@oooooooo
oooooooooa0@400Mooooo`;o0000GOooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
057ooooo001nooooo`05o`000?ooooooooooooooool000006_ooool3o`0005oooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`1@ooooo`00O_ooool01Ol0003ooooooooooooooooo0000
01Sooooo0_l0001Rooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0D?ooool007ko
oooo00Go410@oooooooooooooooooa0@400Eooooo`?o0000I?ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo04oooooo001nooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool2o`00
00?ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
04kooooo001nooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04?ooool3o`0006Sooooo00?oYl3[o`00
0?ooool05_ooool00ol0003oooooooooo`1>ooooo`00TOooool2o`0006Sooooo1?nW`>/00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo04gooooo002>ooooo`?o0000J?ooool7ojO0j`03o`00
0?oooooooooo01Cooooo0ol0001>ooooo`00Roooool3o`0006Wooooo2OnW`>/00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo04cooooo0029ooooo`;o0000JOooool<ojO0j`03o`000?nW`>_o
oooo01Oooooo00?o0000ooooooooool0Boooool008Kooooo0ol0001Xooooo`ooYl3[00?o0000ojO0
joooool06?ooool00ol0003oooooooooo`1:ooooo`00Q?ooool2o`0000;ooooo00?o0000oooooooo
ool0HooooolBojO0j`03o`000?nW`>_oYl3[01Sooooo00?o0000ooooooooool0B_ooool0087ooooo
0ol00005ooooo`03o`000?oooooooooo063ooooo5?nW`>/01?l0003oYl3[ojO0jonW`>/Hooooo`03
o`000?oooooooooo04Wooooo001oooooo`;o0000JOooool00onW_n_oYl3[ojO0j`0CojO0j`03o`00
0?nW`>_oYl3[00;oYl3[6?ooool00ol0003oooooooooo`18ooooo`00O?ooool3o`0006Sooooo1OnW
_n/DojO0j`03o`000?nW`>_oYl3[00;oYl3[6?ooool00ol0003oooooooooo`18ooooo`00N_ooool2
o`0006Oooooo2_nW_n/6ojO0j`;oYko[2onW`>/00ol0003oYl3[ojO0j`03ojO0jaSooooo00?o0000
ooooooooool0Aoooool007Oooooo0ol0001Vooooo`koYko[0_nW`>/6ojNoj`[oYl3[00?o0000ojO0
jonW`>/01?nW`>/Hooooo`03o`000?oooooooooo04Kooooo001dooooo`?o0000I_ooool00onX`>_o
Yko[ojNoj`0=ojNoj`;oZ<3[2?nW_n/6ojO0j`;oYko[00?oYl3[o`000?nW`>/01OnW`>/Hooooo`03
o`000?oooooooooo04Kooooo001booooo`;o00000_ooool00ol0003oooooooooo`1Rooooo`CoZ<3[
2onW_n/6ojS0j`SoYko[0_nW`>/6ojNoj`03o`000?nW`>_oYl3[00GoYl3[6?ooool00ol0003ooooo
ooooo`15ooooo`00Koooool3o`0006Oooooo1onX`>/7ojNoj`[oZ<3[1_nW_n/00onX`>_oYko[ojNo
j`06ojNoj`03o`000?nW`>_oYl3[00CoYl3[00?oYko[ooooooooool05_ooool00ol0003ooooooooo
o`15ooooo`00KOooool2o`0006Oooooo0_nW`>/8ojS0j`CoYko[3_nX`>/2ojNoj`GoZ<3[1onW_n/0
1?l0003oYko[ojO0jonW`>/5ojNojaOooooo0_l00016ooooo`00J_ooool3o`0006Kooooo1_nW`>/8
ojS0j`03ojNojonX`>_oZ<3[01KoZ<3[1_nW_n/00ol0003oZ<3[ojNoj`07ojNojaSooooo00?o0000
ooooooooool0@oooool006Sooooo0_l0001Vooooo`[oYl3[1_nX`>/2ojO0jaWoZ<3[0_nW_n/3ojS0
j`03o`000?nX`>_oZ<3[00SoYko[5oooool00ol0003oooooooooo`13ooooo`00IOooool3o`0006Go
oooo3_nW`>/2ojS0j`KoYl3[7OnX`>/01?l0003oZ<3[ojS0jonX`>/6ojNoj`03ojS0jooooooooooo
01Kooooo00?o0000ooooooooool0@_ooool006?ooooo0_l0001Uooooo`03ojO0k?nW`>_oYl3[01Oo
Yl3[1_nX`>/00onW`>_oZ<3[ojS0j`0DojS0j`04o`000?nX`>_oZ<3[ojS0j`;oYko[1OnX`>/Hoooo
o`03o`000?oooooooooo047ooooo001Pooooo`?o000000?oooooo`000?ooool0H_ooool4ojO0k1Wo
Yl3[0_nX`>/5ojO0jaGoZ<3[00?o0000ojS0jonX`>/02OnX`>/Gooooo`03o`000?oooooooooo047o
oooo000fooooo`Go00008oooool2o`0006Kooooo1onW`>`PojO0j`KoZ<3[0_nW`>/<ojS0j`03o`00
0?nX`>_oZ<3[00[oZ<3[5oooool00ol0003oooooooooo`10ooooo`00=_ooool01OnHV9So8B4Qonk^
k_ooooooA4A4023ooooo0ol0001Uooooo`;oYl3[2?nW`>`QojO0j`;oZ<3[1_nW`>/;ojS0j`03o`00
0?nX`>_oZ<3[00[oZ<3[6?ooool00ol0003oooooooooo`0oooooo`00;_ooool6o`0000?ooooo00?o
V9RHob4Q8Oo^k^h07_ooool3o`0006Gooooo1_nW`>/8ojO0k2WoYl3[1_nX`>/01OnW`>_oZ<3[ojS0
jonX`>_o000000goZ<3[5oooool00ol0003oooooooooo`0oooooo`00>?ooool00onHV9So8B4Qonk^
kP0Kooooo`;o0000IOooool:ojO0j`KoYl3/:onW`>/2ojS0j`GoYl3[0_nX`>/00ol0003oZ<3[ojS0
j`0<ojS0jaOooooo00?o0000ooooooooool0?_ooool003Wooooo00?oMgMgofIVI_ooool05oooool3
o`0006Cooooo3_nW`>/2ojO0k3KoYl3[00?oZ<3[o`000?nX`>/00onX`>/2ojO0j`SoZ<3[6?ooool0
0ol0003oooooooooo`0mooooo`00>_ooool00ol0003oooooooooo`0Dooooo`;o0000I?ooool00onW
_n_oYl3[ojO0j`0=ojO0j`03ojNojonW`>_oYl3[00goYl3[00?oYko[ojO0jonW`>/09onW`>/00ol0
003oZ<3[ojO0j`05ojO0j`SoZ<3[5oooool00ol0003oooooooooo`0mooooo`00=_ooool01Ol0003o
^[ZjoooooonHV9So410@01?ooooo0ol00002ooooo`03o`000?oooooooooo05oooooo1?nW_n/;ojO0
j`GoYko[2onW`>/5ojNojbSoYl3[00?o0000ojO0jonW`>/01_nW`>/6ojS0j`03ojO0jooooooooooo
01Kooooo00?o0000ooooooooool0??ooool003Kooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Aoooo
o`;o0000IOooool7ojNoj`OoYl3[00?oZ;o[ojNojonW_n/01_nW_n/6ojO0j`;oZ;o[2?nW_n/6ojO0
j`;oYko[7onW`>/00ol0003oYl3[ojO0j`07ojO0j`;oZ<3[1OnW`>/Fooooo`?o0000?Oooool004Wo
oooo0ol0001Uooooo`[oYko[1?nW`>/4ojRoj`SoYko[0_nW`>/6ojRoj`SoYko[0_nW`>/6ojNojako
Yl3[00?o0000ojO0jonW`>/03onW`>/Gooooo`03o`000?oooooooooo03_ooooo0017ooooo`;o0000
IOooool>ojNoj`03ojO0jonX_n_oZ;o[00GoZ;o[1_nW_n/2ojS0j`SoZ;o[1_nW_n/00onX_n_oYko[
ojNoj`07ojNoj`KoYl3[00?oYko[ojO0jonW`>/05?nW`>/00ol0003oYl3[ojO0j`0@ojO0jaOooooo
00?o0000ooooooooool0>_ooool004Cooooo0ol0001Tooooo`03ojRojonW_n_oYko[00coYko[0_nX
`>/8ojRoj`CoYko[1OnX`>/8ojRoj`;oYko[1OnX_n/9ojNoj`;oYl3[1OnW_n/EojO0j`03o`000?nW
`>_oYl3[013oYl3[6?ooool00ol0003oooooooooo`0iooooo`00@Oooool3o`0006Cooooo1OnX_n/:
ojNoj`KoZ<3[2?nX_n/00onW_n_oZ<3[ojS0j`06ojS0j`KoZ;o[00?oZ<3[ojRojonX_n/01_nX_n/6
ojNoj`;oZ<3[2?nW_n/6ojO0j`;oYko[3?nW`>/00ol0003oYl3[ojO0j`0AojO0jaOooooo00?o0000
ooooooooool0>Oooool003oooooo0ol0001Sooooo`WoZ;o[1_nW_n/:ojS0j`KoZ;o[2onX`>/2ojRo
j`GoZ<3[2?nX_n/2ojNoj`KoZ<3[2?nW_n/2ojO0j`KoYko[1onW`>/01OnW_n_oYl3[ojO0jonW`>_o
000001CoYl3[5oooool00ol0003oooooooooo`0hooooo`00??ooool3o`0000?ooooo00?o0000oooo
ooooool0G_ooool<ojRoj`;oYko[3_nX`>/2ojRoj`goZ<3[00?oYl3[ojS0jonX`>/01_nX`>/6ojRo
j`[oZ<3[1_nW_n/00onX`>_oYko[ojNoj`07ojNoj`CoYl3[1?nW_n/2ojO0j`03o`000?nW`>_oYl3[
01?oYl3[5_ooool00ol0003oooooooooo`07ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0;?ooool0
03[ooooo0_l0001Uooooo`goZ;o[0_nW`>/>ojS0j`03ojO0jonX`>_oZ<3[00_oZ<3[1?nW`>/8ojS0
j`;oZ;o[3_nX`>/2ojNoj`GoZ<3[2OnW_n/00onW`>_oYko[ojNoj`05ojNoj`03ojO0jol0003oYl3[
00?oYl3[00?oYko[ojO0jonW`>/03_nW`>/Gooooo`03o`000?oooooooooo00Kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0/ooooo`00=oooool3o`0006Gooooo00?oYl3[ojRojonX_n/02OnX_n/6ojO0
j`[oZ<3[1OnW`>/:ojS0j`OoYl3[1_nX`>/00onW`>coZ<3[ojS0j`0FojS0j`KoYko[0_nX`>/8ojNo
j`;oYl3[00?o0000ojO0jonW_n/00onW_n/@ojO0jaOooooo00?o0000ooooooooool01Oooool01Ol@
413ooooooooooooooooo410@02cooooo000eooooo`;o0000IOooool5ojO0j`OoZ;o[2_nW`>/6ojS0
j`03ojO1k?nW`>_oYl3[00KoYl3[1_nX`>/2ojO1k0SoYl3[1?nX`>/4ojO0k1SoZ<3[0_nW_n/6ojS0
j`SoYko[00?oYl3[o`000?nW_n/01OnW_n/6ojO0j`;oYko[2?nW`>/Fooooo`03o`000?oooooooooo
00Gooooo00Go0000ooooooooooooooooo`00000/ooooo`00<_ooool3o`0006Cooooo2OnW`>/4ojRo
j`goYl3[0_nX`>/5ojO1k0SoYl3[0_nX`>/6ojO1k0SoYl3[00?oZ<3[ojO0k?nW`>`01OnW`>`6ojS0
j`;oYl3/6?nX`>/6ojNoj`03ojS0jonW_n_o000000OoYko[0_nW`>/6ojNoj`SoYl3[5_ooool00ol0
003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000;?ooool0033ooooo0_l0001Toooo
o`goYl3[00?oZ;o[ojO0jonW`>/03?nW`>/9ojO1k0KoYl3[2_nW`N`6ojO0j`03ojO1k?nW`>coYl3/
00OoYl3/0_nX`>/6ojO0k1SoZ<3[0_nW_n/5ojS0j`03o`000?nW_n_oYko[00CoYko[00?oZ<3[ojNo
jonW_n/01_nW_n/8ojO0jaOooooo00?o0000ooooooooool00oooool01Ol@413ooooooooooooooooo
410@02cooooo000]ooooo`?o000000?oooooo`000?ooool0H?ooool?ojO0j`;oYl3/2onW`>/=ojO1
k0;oYl3[3_nW`N`2ojO0j`GoYl7/4OnW`>`6ojS0j`03ojO0k?nX`>_oZ<3[01GoZ<3[00?o0000ojNo
jonW_n/00_nW_n/4ojS0j`SoYko[2?nW`>/Fooooo`;o00001?ooool01OmgMgOoV9RHoooooonHV9So
MgMg02cooooo000Zooooo`?o0000Hoooool?ojO0j`KoYl3/1onW`>/?ojO1k0;oYl3/3_nW`N`00onW
`>coYl7/ojO1k006ojO1k17oYl3/0_nX`>/5ojO0k1KoZ<3[00?o0000ojS0jonW_n/01onX`>/7ojNo
j`WoYl3[4oooool2o`000003ooooool0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0/
ooooo`00:?ooool2o`0006?ooooo3onW`>/2ojO1k0SoYl3/1?nW`>/>ojO1k0KoYl3/2_nW`N`5ojO0
k0SoYl7/6?nW`>`6ojS0j`03ojO0k?nX`>_oZ<3[00coZ<3[00?o0000ojS0jonX`>/02?nX`>/7ojNo
j`WoYl3[5_ooool00ol0003oooooooooo`0booooo`009Oooool3o`0006;ooooo3onW`>/6ojO1k0So
Yl3/00?oYl3[ojO1k?nW`N`02onW`N`2ojNoj`SoYl3/1_nW`N`00onW_n_oYl3/ojO0k006ojO0k0Ko
Yl7/00?oYko[ojO0k?nW`>`05onW`>`2ojS0j`GoYl3/3?nX`>/2o`0000[oZ<3[2?nW_n/6ojO0j`;o
Yko[5_ooool00ol0003oooooooooo`0booooo`008oooool2o`0006;ooooo3onW`>/:ojO1k0OoYl3/
2onW`N`6ojNoj`SoYl3/0_nW`N`5ojNoj`SoYl3/0_nW`N`5ojNoj`SoYl3/00?oYko[ojO0k?nW`>`0
5OnW`>`6ojS0j`;oYl3/0ol000000onX`>_o0000ojS0j`0:ojS0j`SoYko[0_nW`>/6ojNojaKooooo
00?o0000ooooooooool0<Oooool0023ooooo0ol0001Rooooo`koYl3[3_nW`N`7ojO0k0OoYl7/2_nW
_n/6ojO0k003ojNoj_nW_n_oYko[00KoYko[1_nW`>`9ojNoj`CoYl3/1OnW_n/GojO0k0;oZ<3[0_nW
`>`3o`000003ojO0k?nX`>_oZ<3[00;oZ<3[00?o0000ojS0jonX`>/02OnX`>/6ojNoj`03ojS0jonW
_n_oYko[00KoYko[5oooool00ol0003oooooooooo`0`ooooo`007oooool2o`0006;ooooo3OnW`>/@
ojO1k003ojO0jonW`>coYl3/00KoYl3/1?nW`N`=ojNoj`;oYl3/1OnW_nX8ojNoj`;oYl3/3OnW_n/0
0onW`>coYko[ojNoj`06ojNoj`KoYl3/00?oYko[ojO0k?nW`>`03_nW`>`3o`0000CoYl3/1OnX`>/0
0ol0003oYl3[ojO0j`08ojS0j`CoYko[1?nX`>/8ojNojaKooooo00?o0000ooooooooool0<?ooool0
01oooooo00?o0000ooooool00000Goooool<ojO0ja3oYl7/1OnW`>/8ojO0k003ojO1k?nW_n_oYko[
00coYko[00?oZ;oZojNoj_nW_nX01_nW_nX6ojNoj`03ojRoj_nW_n_oYko[00coYko[0_nX_nX9ojNo
j`;oYl3/1OnW_n/<ojO0k0?o00002?nW`>`2ojS0j`?oYl3[00?o0000ojO0jonW`>/02?nX`>/00onW
_n_oZ<3[ojS0j`05ojS0j`KoYko[00?oYl3[ooooooooool05Oooool00ol0003oooooooooo`0_oooo
o`003?ooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`04o`000?oooooooooo
o`0005_ooooo3?nW`>/@ojO1k0WoYl3[1_nW`>`2ojNojP_oYko[1OnX_nX8ojNojP;oYko[1OnX_nX:
ojNoj`KoZ;oZ1onW_n/00onX_n[oYko[ojNoj`06ojNoj`KoYl3/00?oYko[ojO0k?l000000_l0000;
ojO0k0GoYl3[00Co0000ojO0jonW`>_oYl3[4?nX`>/2ojNoj`GoYl3[5oooool00ol0003ooooooooo
o`0^ooooo`003?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`06ooooo`;o00000_ooool00ol0003oooooooooo`1Eooooo`goYl3[3onW`N`=ojO0j`;oYl3/
1_nW_nX7ojNoj`03ojRojonX_n[oZ;oZ00KoZ;oZ1_nW_nX00onX`>_oZ;oZojRojP06ojRojPKoYko[
00?oZ<3[ojRoj_nX_nX01onX_nX4ojNoj`CoZ;oZ2?nW_n/2ojO0k0;oYko[0ol0000?ojO0k0GoYl3[
00Co0000ojO0jonW`>_oYl3[3onX`>/8ojO0jaKooooo00?o0000ooooooooool0;_ooool000Cooooo
1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4005ooooo`;o
00001?ooool00ol0003oooooooooo`1Aooooo`ooYl3[3OnW`N`?ojO0j`[oYkoZ1?nW_n/4ojRoj`So
Z;oZ0_nW_nX5ojS0j`SoZ;oZ0_nW_n/5ojS0j`WoZ;oZ00?oYko[ojRoj_nX_nX01OnX_nX6ojNoj`03
ojRoj_nW_n_o000000;o00001?nW_n/6ojO0k003ojNojonW`>coYl3/00KoYl3/1OnW`>/00ol0003o
Yl3/ojO0k00@ojS0j`SoYl3[5_ooool00ol0003oooooooooo`0]ooooo`003_ooool00onHV9So8B4Q
onk^kP03ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo04gooooo0_nW_n/>ojO0j`coYl7/3onW`>/>ojNojP03ojNojonX_n_oZ;o[00Go
Z;o[1_nX_nX9ojS0j`KoZ;oZ2OnX`>/6ojRojP;oZ<3[2OnX_nX2ojNoj`?oZ;oZ0_l00008ojNoj`;o
Yl3/1OnW_n/8ojO0k0;oYl3[0_nW`>`01?l0003oYl3/ojO0k?nW`>`@ojS0j`KoYl3[00?oZ<3[oooo
ooooool05Oooool00ol0003oooooooooo`0/ooooo`003oooool00omgMgOoIVIVooooo`02ooooo`05
o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
04Wooooo1_nW_n/:ojO0j`coYl7/3onW`>/@ojNojP03ojS0jonX_n_oZ;o[00OoZ;o[0_nX_nX=ojS0
j`;oZ;oZ3OnX`>/2ojRojPKoZ<3[1onX_nX00onX`>_oZ;oZojRojP03o`0000?oZ;oZ1_nW_n/00onX
_n[oYko[ojNoj`06ojNoj`KoYl3/00?oY/3/ojO0k?nW`>`00onW`>`00ol0003oYl3/ojO0k006ojS0
j`?oYl3[2?nX`>/2ojO0j`GoZ<3[5Oooool2o`0002kooooo000@ooooo`05o`000?oooooooooooooo
ool@41000oooool00ol@413oooooooooo`03ooooo`;o00001oooool00ol0003oooooooooo`16oooo
o`WoYko[1_nW`>/<ojO1k0ooYl3[4?nW_nX5ojS0j`OoZ;o[00?oYl3[ojS0jonX`>/03?nX`>/00onW
`>_oZ<3[ojS0j`0<ojS0j`;oYl3[2?nX`>/4ojRojP;oZ<3[0ol00007ojRojP;oYko[1OnX_nX8ojNo
j`;oYl3/1OnV`>`5ojO0k003o`000?nW`>coYl3/00;oZ<3[1onW`>/?ojS0jaKooooo00?o0000oooo
ooooool0:oooool000cooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04;ooooo3OnW_n/2
ojO0j`coYl7/3onW`>/@ojNojPWoZ<3[1?nX_n/4ojO0j`[oZ<3[1OnW`>/:ojS0j`KoYl3[2?nX`>/0
0onX_n[oZ<3[o`000002o`0000?oZ<3[1_nX_nX00onX`>_oZ;oZojRojP06ojRojPKoYko[00?oZ;o[
ojK0k?nV`>`01_nV`>`5ojO0k003o`000?nW`>coYl3[00WoYl3[3onX`>/Eooooo`03o`000?oooooo
oooo02_ooooo000<ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0nooooo`ooYko[0_nW
`>`;ojO1k0koYl3[4?nW_nX=ojS0j`03ojRojonW`>_oYl3[00GoYl3[1_nX`>/9ojO0j`KoZ<3[2_nW
`>/6ojS0j`?o00001onX`>/2ojRojPGoZ<3[2?nX_nX2ojNoj`GoZ;o[2?nV`>`4ojO0k003o`000?nW
`>coYl3/00SoYl3[00?oYl3/ojS0jonX`>/03OnX`>/Fooooo`03o`000?oooooooooo02[ooooo000N
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0>_ooool?ojNoj`KoYl3/2?nW`N`>
ojO0j`ooYkoZ00?oYl3[ojS0jonX`>/03?nX`>/:ojO0j`;oZ<3[3OnW`>/2ojS0j`koYl3[0_nX`>/3
o`0000;oYl3[1onX`>/00onW`>_oZ<3[ojS0j`06ojS0j`KoZ;oZ00?oZ<3[ojRojonX_n/01_nX_n/6
ojK0k003ojNojonW`>coYl3/00?oYl3/00?o0000ojO0k?nW`>`01?nW`>/5ojO0k0ooZ<3[5_ooool0
0ol0003oooooooooo`0Yooooo`007Oooool3o`0000_ooooo00?o0000ooooooooool0=_ooool?ojNo
j`;oYl3[2?nW`>`5ojO1k0goYl3[3onW_nX5ojO0j`[oZ<3[3?nW`>/2ojNnjPgoYl3[0_nW_^T>ojO0
j`?o00001_nW`>/4ojS0j`CoYl3[2?nX`>/2ojRojPGoZ<3[2?nX_n/2ojK0k0GoYko[1OnW`>`01?l0
003oYl3/ojO0k?nW`>/7ojO0k0KoZ<3[0_nW`>/7ojS0jaKooooo00?o0000ooooooooool0:Oooool0
01gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0booooo`ooYko[1_nW`>/8ojO0
k003ojO1k?nW`>_oYl3[00_oYl3[3onW_nX9ojO0j`KoZ<3[3?nW`>/6ojNnjPWoYl3[1_nW_^T:ojO0
j`?o00000_nX_n/8ojO0j`03ojS0jonW`>_oYl3[00GoYl3[1_nX`>/00onW`>_oZ<3[ojS0j`06ojS0
j`KoZ;o[00?oZ<3[ojNojonW_n/01_nW_n/5ojO0k003o`000?nV_n_oY[o[00SoYl3/0_nX`>/6ojO0
j`OoZ<3[5_ooool00ol0003oooooooooo`0Xooooo`007Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo02oooooo3onW_n/9ojO0j`KoYl3/0_nX`N`:ojO0j`ooYkoZ3OnW`>/2ojS0j`co
Yl3[0_nW_>P8ojNnjPGoYl3[0_nW^>D8ojNnj@KoYl3[0ol00006ojRoj`KoYl3[0_nW_n/8ojO0j`;o
Z<3[1OnW`>/8ojS0j`;oZ;o[1OnX`>/8ojNoj`;oYl3/0_nV_n/01?l0003oY[o[ojJojonV_n/7ojO0
k0SoYl3[1onX`>/Gooooo`03o`000?oooooooooo02Oooooo000Mooooo`;o00003oooool00ol0003o
ooooooooo`0[ooooo`ooYko[3OnW`>/2ojO0k0KoZ<7/1_nW`>/2ojNnjPgoYkoZ3onW`>/2ojNoj`_o
Yl3[1OnW_>P8ojNnjP03ojO0jonW^>GoYkSU00CoYkSU2?nW_^T2ojO0j`03ojNkiol0003o000000;o
Yk_W2?nX_n/2ojO0j`KoYko[1_nW`>/00onW_n_oYl3[ojO0j`06ojO0j`ooZ<3[1_nW_n/2ojRoj`Co
Y[o[00Co0000ojJojonV_n_oY[o[1onW`>`8ojO0j`OoZ<3[5_ooool00ol0003oooooooooo`0Woooo
o`007Oooool00ol0003oooooooooo`0?ooooo`;o0000:?ooool2ojO0j`goYko[3onW`>/:ojS1k0;o
Yl3[1_nW_^X9ojNojPooYl3[1_nW_n/8ojO0j`SoYkcX1_nW_^X00onX/n3oYkSUojNhi@06ojNhi@Ko
YkkY00CoZK?Po`000?l0003o00001OnW^nL6ojRoj`;oZ;WU2?nW_n/2ojO0j`GoYko[2?nW`>/?ojS0
j`;oYko[1_nX_n/4ojJoj`03o`000?nV_n_oYko[00SoYl3/1onW`>/8ojS0jaKooooo00?o0000oooo
ooooool09_ooool001gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Rooooo`Ko
Yl3[2OnW_n/?ojO0j`coZ<7/0_nW_nX8ojNnjPGoYkoZ3onW`>/:ojNoj`GoYl3[0_nW^>D9ojNlj0;o
YkkZ1OnX/n08ojNhi@;oYkkY00GoZK?Po`000?l0003o0000ojVch008ojNki`;oZ;o[1_nX^ND6ojNo
j`03ojRiiOnW_n_oYko[00KoYko[1onW`>/@ojS0j`SoZ;o[0_nV_n/2ojNoj`03o`000?nW_n_oYko[
00SoYl3/1onW`>/8ojS0jaKooooo00?o0000ooooooooool09Oooool001gooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`0Nooooo`;oZ<3[2?nW`>/7ojNoj`goYl3[3?nX`N`6ojNojPSo
YkkZ00?oYkoZojO0jonW`>/03OnW`>/>ojNoj`03ojO0jonW^>GoYkSU00CoYkSU1onW_>P00onX[]co
Z;?PojRch006ojRch0KoYkSU00CoZjoJo`000?l0003o00001OnY/n06ojNki`03oj^bgOnX^NGoZ;WU
00OoZ;WU0_nW_n/5ojRii@SoYko[1onW`>/@ojS0j`KoZ;o[00?oZL3[ojNojonW_n/00_nW_n/01?l0
003oYko[ojNojonW_n/6ojO0k003ojK0k?nW`>_oYl3[00KoYl3[1onX`>/Fooooo`;o00009_ooool0
01cooooo0ol0000Dooooo`03o`000?oooooooooo01[ooooo1_nX`>/8ojO0j`OoYko[2OnW`>/=ojS1
k003ojNojonW_n[oYkoZ00KoYkoZ1_nW_^X?ojO0j`ooYko[00?oYkKSojNhiOnW^>D01_nW^>D4ojNl
j0CoZ:kL1onX/n04ojNhi@?o000000?oZjoJojVch?nY/n001_nY/n02ojNki`GoZk;M1onX^ND00on]
/mgoZ;WUojRii@06ojRii@KoYko[00?oZ;_WojO0jonW`>/01_nW`>/6ojS0j`03ojO0jonX`>_oZ<3[
00OoZ<3[0_nX_n/5ojW0j`CoYko[00Co0000ojNojonW_n_oYko[0_nW`>`5ojK0k0SoYl3[1onX`>/D
ooooo`03o`000?oooooo000002Kooooo000Looooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool05oooool9ojS0j`KoYl3[2OnW_n/6ojO0j`03ojO1k?nX`NcoZ<7/00[oZ<7/1?nW_n/8ojNo
jP;oYkkZ3onW`>/?ojNoj`GoYkKS2?nW^>D00onW_>SoZ:kLojR^g005ojR^g0OoZ;?P0ol00005oj^_
fPKoZK?P00?o[joGoj^bgOn[/]d01_n[/]d4ojRii@Co[K?M2?nX^ND2ojNoj`GoZ;_W2?nW`>/2ojS0
j`GoYl3[2?nX`>/8ojW0j`CoYko[00?o0000ojNojonX_n/02?nV`>`7ojO0j`SoZ<3[5_ooool00ol0
003oooooooooo`0Sooooo`002_ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h6ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool05?ooool<ojS0j`;oYl3[3OnW
_n/2ojO0j`GoYl7/2OnX`N`7ojNoj`KoYkoZ00?oYko[ojO0jonW`>/03?nW`>/?ojNoj`03ojNdh_nW
]^?oYkKS00KoYkKS1_nW^>D00onY[=[oZ:kLojR^g006ojR^g0CoZ;?P0ol00008oj^_fPCoZK?P1?n_
[mL8oj^bg@03ojRiiOn]/mgo[K?M00Go[K?M1_nX^ND00on^]MkoZ;_WojRki`06ojRki`KoYl3[00?o
YkkYojO0jonW`>/01_nW`>/8ojS0j`SoZL3[0_nW_n/00onX_n_o0000ojRoj`02ojRoj`SoY/3/1onW
`>/8ojS0jaGooooo00?o0000ooooooooool08oooool000cooooo00?o0000ooooooooool00_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`0Aooooo`goZ<3[3onW_n/2ojO0j`OoYl7/1_nX`N`3ojS0j`OoYko[0_nW_nX5ojNoj`[oYl3[3onW
_n/5ojNdhPSoYkKS0_nW^>D5ojV/fPSoZ:kL0ol00004ojb[ePSoZjoJ00?oZK?Pojn_eon_[mL01On_
[mL6oj^bg@03ok6_e_n]/mgo[K?M00Ko[K?M1?nX^ND4ojjegPSoZ;_W0_nW`>/5ojNnj@SoYl3[2?nX
`>/6ojW0j`03ojW1jonX_n_oZ;o[00;oZ;o[00Co0000ojRojonX_n_oZ;o[1_nV`>`00onV_n_oYl3[
ojO0j`05ojO0j`SoZ<3[5_ooool00ol0003oooooooooo`0Rooooo`0000?oooooo`000?l000001?l0
0005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`;o0000
6Oooool00ol0003oooooooooo`0>ooooo`?oYl3[2OnX`>/?ojNoj`KoYl3[1onW`N`2ojS1k0OoZ<3[
3_nW_n/8ojO0j`goYko[2OnW]>86ojNfh`03ojRZf?nY[=[oZJcJ00KoZJcJ1OnX[]`2o`0000So[:_F
1_n[[mX00on_Zm?o[joGojn_e`06ojn_e`CoZk;M1?na[mH8ojfcg@03ojRiiOn^]Mko[[GN00Go[[GN
1_nX^nL00on/]n7oYkkYojNnj@06ojNnj@KoYl3[0_nW_n/8ojS0j`;oZL3[1OnY`N/4ojRoj`04o`00
0?nX_n_oZ;o[ojRoj`;oY/3/1OnV_n/7ojO0j`SoZ<3[5_ooool00ol0003oooooooooo`0Qooooo`00
3?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo00[ooooo1onW`>/6ojS0j`03ojO0jonW_n_oYko[00_o
Yko[2_nW`>/5ojO1k0?oZ<7[2?nX`>/>ojNoj`SoYl3[2OnW_n/=ojNdhP;oYkKS1OnXZ]P7ojV/fP;o
Z:kL0ol00003oj^Xe0Oo[:_F1?n[[mX4ojn[d`So[joG00?oZk;Mok6_e_na[mH01Ona[mH6ojfcg@03
okBbeon^]Mko[[GN00Oo[[GN0_nX^nL5ojbgh@SoYkkY0_nW`>/6ojNoj`KoZ<3[00?oYl3[ojW1jonY
`N/01OnY`N/5ojRoj`03o`000?nX`>_oZ<3[00OoY[o[2?nW`>/8ojS0jaGooooo00?o0000oooooooo
ool08Oooool000cooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Go
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`07ooooo`[oYl3[0_nX`>/5ojO0j`Wo
Yko[3_nW`>/00onW`NcoZ<7[ojS1j`05ojS1j`KoZ<3[3_nW_n/:ojO0j`GoYko[0_nW]^<=ojNdhP03
ojJXf?nXZ]SoZ:[H00KoZ:[H1OnY[=X3o`0000KoZjSD2?n/ZmH00on[[m[o[j_Cojn[d`05ojn[d`Ko
[joG00?o/jkCok6_e_na[mH01_na[mH4ojfcg@Co];;G1on^]Mh00one]MWo[;OQojbgh@06ojbgh@Ko
YkkY0_nY^nH8ojNoj`;oZ<3[1OnW`>/7ojW1j`;oZ;o[0_nX`>/01?l0003oZ<3[ojS0jonX`>/7ojJo
j`SoYl3[1_nX`>/00onW`>_oooooooooo`0Dooooo`03o`000?oooooooooo023ooooo000<ooooo`03
o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool00oooool<ojO0j`;oZ<3[1onW`>/8ojNoj`goYl3[0_nX`N`8ojS1
j`;oZ<3[3_nW_n/>ojO0j`03ojNojonW]^?oYkKS00CoYkKS2OnW]>85ojJXf0OoZ:[H0_nY[=X3o`00
0003ojV/f_nZYm?oZjSD00OoZjSD1_n/ZmH00on`[=Co[j_Cojn[d`06ojn[d`Co[joG1?nc[]<8ok6_
eP03ojfcgOnd/]Oo];;G00Go];;G1?n^]Mh4okFef@So[;OQ0_nW_^T6ojVkiPKoYko[00?oYkkZojO0
jonW`>/01OnW`>/6ojW1j`KoZ<3[00?o0000ojS0jonX`>/01_nV_n/2ojNoj`SoYl3[0_nX`>/5ojO0
jaKooooo00?o0000ooooooooool07oooool000cooooo00?o0000ooooooooool00_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_l0000Nooooo`03o`000?ooooooYl3[00_oYl3[1_nX`>/7ojO0
j`SoYko[2OnW`>/6ojS1k0KoZ<7[3onW_n/?ojO0j`03ojNhiOnW]^?oYkKS00KoYkKS1OnW]>800onU
Z=SoYZSHojJXf005ojJXf0KoZ:[H0ol000000onY[=[oZZOCojZWd`03ojZWd`OoZjSD1?n/ZmH4ok2/
e0So[j_C00?o[joGok>^donc[]<01Onc[]<6ok6_eP03okNbe?nd/]Oo];;G00Oo];;G00?o[[GNokFe
fOne]MT01One]MT6ojbgh@03okBigOnY^nKoZK_V00OoZK_V0_nW_n/5ojNnjPOoYl3[0_nY`N/:ojS0
j`03o`000?nX`>_oZ<3[00;oY[o[1_nW_n/?ojO0jaGooooo00?o0000ooooooooool07oooool000[o
oooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000oooo
ooooool07?ooool=ojO0j`WoZ<3[1OnW`>/:ojNoj`GoYl3[2_nX`N`2ojS1j`ooYko[3onW`>/5ojNh
i@SoYkKS00?oYkCRojFXf?nUZ=P00onUZ=P7ojJXf0;oZ:[H0ol000000onXZ]SoZJKDojZWd`07ojZW
d`OoZjSD00?o[:_Fok2/e?n`[=@01On`[=@6ojn[d`03okJffOnc[]?o/jkC00Ko/jkC1?na[mH4okNb
e0Oo];;G00?o^KGEokFefOne]MT01_ne]MT4ojbgh@Co];WM1onY^nH00on_^n;oYkkZojNnjP05ojNn
jPOoYl3[3OnX`>/00ol0003oZL3[ojW0j`08ojNoj`ooYl3[5Oooool00ol0003oooooooooo`0Noooo
o`006oooool00ol0003oooooooooo`0Jooooo`?oYko[2OnW`>/=ojS0j`03ojO0jonW_n_oYko[00co
Yko[00?oYl3[ojS1k?nX`N`02_nX`N`?ojNoj`ooYl3[00?oYkcXojNhiOnW^>D01_nW^>D6ojNfh`03
ojBXf_nUZ=SoYJSH00GoYJSH1OnVZ=P3o`0000;oZ:[H1?nYY]@7ojZWd`KoZjSD00?o/K;Iok2/e?n`
[=@01_n`[=@4ojn[d`Co][KI2?nc[]<00ona[mKo]k;DokNbe005okNbe0Go];;G0oni]MD8okFef@03
ojbghOnd^Mgo];WM00Go];WM1?nY^nH4ojnkhPOoYkkZ1onW`>/:ojS0j`;oZL3[00Co0000ojW0jonY
`>_oZL3[1onW_n/?ojO0jaKooooo00?o0000ooooooooool07Oooool001_ooooo00?o0000oooooooo
ool05oooool7ojNoj`OoYl3[3OnX`>/?ojNoj`;oYl3[2OnX`N`?ojNoj`ooYl3[1OnW_>P8ojNhi@;o
YkKS1OnTZ=X6ojFXf0;oYZSH0ol00002ojJXf003ojRZf?nYY]CoZJKD00CoZJKD2?nZYm<2oj^Xe0Go
/K;I2?n`[=@00on_Zm?o][KIokJff@04okJff@Oo/jkC00?o^[kMokNbe?ng/]@01_ng/]@3okBbe`Ko
^KGE1_ne]MT00onj]mKo];WMokBig@07okBig@03ojVki_n_^n;o[k_R00Co[k_R1_nW_^X00onY_^Wo
Yl3[ojO0j`06ojO0j`SoZ<3[1?nY`>/01?l0003oZL3[ojW0jonY`>/7ojNoj`ooYl3[5?ooool2o`00
01oooooo000Kooooo`;o00005?ooool<ojNoj`OoYl3[2OnX`>/?ojNoj`KoYl3[1_nX`N`2ojS1j`ko
Yko[3OnW`>/2ojRnjPOoYkcX1_nW^>D00onRZ]coY:SJojBXfP05ojBXfPKoYJSH0_l00004ojJXf003
ojNVeOnYY]CoZJKD00KoZJKD1_nZYm<00on_^N3o/K;Iok6bf@06ok6bf@Ko/:cD00?o]L?UokJffOnf
]]T01_nf]]T5ok>^d`?o^[kM2?ng/]@00ond/]Oo^KGEokVee@05okVee@Co]KGI1?nj]mH7okBig@03
okVif_n_^n;o[k_R00Ko[k_R0_nW_^X5ojVnj@SoYl3[2?nX`>/4ojW0j`03o`000?nY`>_oZL3[00So
Yko[1_nW`>/00onV_n_oYl3[ojO0j`05ojO0jaKooooo00?o0000ooooooooool07?ooool001[ooooo
00?o0000ooooooooool04?ooool2ojO0j`goYko[2OnW`>/7ojS0j`goYko[2_nW`>/2ojS1k0KoZ<7[
3_nW_n/9ojO0j`KoZ;kZ1onW_>P2ojNhi@GoXZ[L1onTZ=X2ojFXf0?o00000_nUZ=P00onVZ=SoYjKE
ojNVe@03ojNVe@OoZJKD1?nZYm<4ojnih0Oo/K;I1?n`[=@4okG3i@Oo][KI0onc[]<6okZng@Ko]k;D
00?o_<7MokVeeOni]MD01oni]MD00one]MWo^[OFokZgeP05okZgePCo];WM1?ni^MX6ojnkhP03okFm
gonY_^WoZKkY00KoZKkY2?nW`>/8ojS0j`CoZL3[00?o0000ojW0jonY`>/02?nW_n/2ojO0j`GoY[o[
1onW`>/Eooooo`03o`000?oooooooooo01cooooo000Jooooo`03o`000?oooooooooo00gooooo1_nW
`>/9ojNoj`goYl3[1onX`>/9ojNoj`coYl3[2_nX`N/>ojNoj`SoYl3[1onX_^X5ojNlj003oj:/g_nR
Z]coXZ[L00KoXZ[L1OnTZ=X3o`0000CoYJSH00?oY:GFojNVeOnWY]D01OnWY]D7ojVVe003ojZWdon_
^N3o[kWP00Go[kWP1ona/]T00on`[=Co]L?UokG3i@05okG3i@Oo][KI00?o/jkCokZngOnj_]d01Onj
_]d4okNbe0Co_<7M1oni]MD00onn_m[o^[OFokZgeP07okZgeP03okBigOni^M[o^KWJ00Co^KWJ1?n_
^n84okFmg`SoZKkY2?nW`>/6ojS0j`03ojO0jonY`>_oZL3[00;oZL3[00?o0000ojW0jonY`>/01_nW
_n/2ojO0j`OoY[o[2?nW`>/Eooooo`03o`000?oooooooooo01_ooooo000Jooooo`03o`000?oooooo
oooo00_ooooo0_nX`>/7ojO0j`OoYko[3OnW`>/9ojS0j`WoYko[2?nW`>/>ojS1j`koYko[2?nW`>/7
ojRnjP03ojNlj?nR[=koXZcN00?oXZcN1onRZ]`2ojBXfP?o00000_nTZ=X2ojFXf0GoY:GF1onWY]D5
ojVVe0;o[KkV1on_^N06ok6bf@03ojc>l_ne`nGo]L?U00Ko]L?U1_nf]]T00onbcNko^[kMokZng@07
okZng@03okNbe?nl`Mgo_<7M00Go_<7M1Oni]MD3okjofPOo^[OF00?o_kgGokVif_ni^MX01_ni^MX0
0on_^n;o]KgOokFmg`05okFmg`KoZKkY0_n/_^L8ojO0j`;oZ<3[1OnW`>/4ojW0j`03o`000?nY`>_o
ZL3[00;oYko[1_nW`>/7ojJoj`SoYl3[5Oooool00ol0003oooooooooo`06ooooo`Go00003oooool0
01[ooooo0_l00009ooooo`KoZ<3[1onW`>/7ojNoj`WoYl3[3OnX`>/9ojNoj`GoYl3[0_nX`>/=ojS1
j`koYko[2_nW`>/3ojRnjP?oY;7R1onR[=h5oj:Zg0?o00000_nTZ=X3oj:SePSoY:GF1onWY]D00onY
Y]Co[KkVojfniP04ojfniPOo[kWP0_na/]T5ojc>lPSo]L?U0_nf]]T5ok;=kPOo^[kM00?o[loaokc1
gOnl`Md01_nl`Md3okVee@Ko_[oJ1Onj]mH3oknme`Ko^KWJ00?o_[cHokFmgone_Ml01one_Ml2ojVn
j@Ko[;kW1_nW`>/00onW_n_oYl3[ojO0j`05ojO0j`GoZL3[00?o0000ojW1jonY`N/01onW`>/8ojJo
j`SoYl3[5?ooool00ol0003oooooooooo`06ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@03oooool0
01[ooooo00?o0000ooooooooool01_ooool2ojO0j`OoZ<3[1OnW`>/9ojNoj`KoYl3[3OnX`>/<ojNo
j`03ojO0jonX`>_oZ<3[00CoZ<3[2OnX`N/>ojNoj`coYl3[00?oYKSVojBah_nT/N801OnT/N87oj:/
gP06oj:Zg?l0003o0000o`000?nRZ]coWj;G1onRXmH7ojBUePKoYjKE00?oZ/7[ojfni_n]_^H01_n]
_^H5ojnih0?oX=[l1_n/c_86okG3i@;oVMcn1onbcNh4okZng@Co[loa2?nl`Md00oni]MGo_[oJokjo
fP05okjofP?o^[OF1_no_ML4okVifP?o_[cH1one_Ml00onj`=ko[;kWojbni`07ojbni`;oYl3[1OnW
_n/7ojO0j`;oZL3[0_nY`N/01?l0003oZL7[ojW1jonY`N/7ojO0j`SoY[o[1onW`>/Eooooo`03o`00
0?oooooooooo00Kooooo00?oV9RHob4Q8Oo^k^h04?ooool001[ooooo00?o0000ooooooooool00ooo
ool6ojO0j`OoZ<3[00?oYl3[ojNojonW_n/02onW_n/2ojO0j`coZ<3[0_nW`>/=ojNoj`03ojO0jonX
`>_oZ<3[00KoZ<3[1OnX`N/3ojO0j`coYko[2onW`>/5ojFhiPOoY;7R1?nR[=h3o`000003oj:Zg?nO
X]OoWj;G00?oWj;G1onRXmH7ojBUeP;oYjKE1OnZ`N/8ojfniP03ojnih?nPf_coX=[l00GoX=[l1_n/
c_82okG3i@KoVMcn1onbcNh00onj_]go[loaojo?l@05ojo?l@Ko_<7M00?o//g^okjof_nn_mX01onn
_mX00onj]mKo_kgGoknme`05oknme`?o^KWJ1Onn_=P4okFmg`Co^/3N1on/_^L00on``>KoYko[ojNo
j`05ojNoj`SoYl3[1?nY`N/01?l0003oZL7[ojW1jonY`N/7ojO0j`SoY[o[1onW`>/Eooooo`03o`00
0?oooooooooo00Kooooo00?oV9RHob4Q8Oo^k^h03oooool001[ooooo00?o0000ooooooooool02_nW
`>/5ojS0j`;oYl3[3?nW_n/3ojO0j`WoZ<3[1_nW`>/9ojNoj`GoYl3[2?nX`>/00onX`N_oYl3[ojO0
j`05ojO0j`SoYko[3?nW`>/00onW_^[oYKSVojFhiP05ojFhiPKoY;7R00CoXZcNo`000?l0003o0000
0_nR[=h00onNX]SoWj;GoinRe`05oinRe`KoXZ?F1_nTYMH00onW`>coZ/7[oj[1j`06oj[1j`Ko[KkV
0onDhOd7oj3Jo0?o[<kb1?m]f_87oiWLoP?o//g^1?n3foh8ojo?l@;o_<7M1OnbcNh7okjofP03ok[9
i_no_MOo_kgG00Oo_kgG00?o^KWJokjlf?nn_=P01Onn_=P00one_Moo^/3Nok[0gP05ok[0gPCo[;kW
1?n``>H7ojNoj`SoYl3[1?nY`N/00ol0003oZL7[ojW0j`08ojO0j`OoY[o[1onW`>/Eooooo`03o`00
0?oooooooooo00Oooooo00?oMgMgofIVI_ooool03_ooool001Wooooo00?o0000ojO0jonW`>/03?nW
`>/00onX`>_oYl3[ojO0j`04ojO0j`SoYko[1onW`>/7ojS0j`SoYl3[1onW_n/7ojO0j`KoZ<3[0_nX
`N/8ojO0j`OoYko[2OnW`>/5ojNnjPOoYKSV0onT/N83o`0000;oXZcN1OnNX]P6oinRe`OoXZ?F0_nT
YMH5ojO0k0SoZ/7[0_n]_^H7oiCQo@?oX=[l1_m6am/6ofgJlP?oVMcn1Olh^n05oh?KoPKo[loa0_mo
eol7ok;=kPCo_[oJ1?njbNH7oknme`03ol74gOnn_=So_[cH00Go_[cH00?o`/7Iok[0g_nj`=h01onj
`=h00on/_^Oo/<3Vok30iP05ok30iPGoYko[0_nX`>/8ojO0j`;oZL7[0_nY`>/00ol0003oZL3[ojW0
j`08ojO0j`OoY[o[1onW`>/Eooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03Ooo
ool001Wooooo00?o0000ojO0jonW`>/02onW`>/2ojS0j`OoYl3[2?nW_n/7ojO0j`OoZ<3[2?nW`>/7
ojNoj`OoYl3[0_nX`>/6ojS1j`KoYl3[00?oY[k[ojNojonW_n/01_nW_n/7ojO0j`OoYkkZ1onU^>H2
o`000003ojBah_nMYM_oWJGK00OoWZ;H1onOX]L5oj:SeP;oY;_Y1onW`>`6oj[1j`CoS^Cl0onDhOd5
odW8fPCoMMKm1_m?a_43obfcg@KoHl?m1Ol/ZnX00olUZn3oPm_noh?KoP02ojo?l@KoOmOo1onbcNh0
0onn_m[o^/WVok[9iP05ok[9iPCo_kgG1?o1a=d5okjlf0?o`/7I1onj`=h2okg2gPSo/<3V00?oYko[
ojS0jonX`>/01?nX`>/7ojO0j`CoZL3[00Co0000ojW0jonY`>_oZL3[1onW`>/7ojJoj`SoYl3[4ooo
ool3o`0000Cooooo00Go0000okZj^_ooooooV9RHoa0@400?ooooo`003_ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Kooooo00?o0000oooooonW`>/02?nW`>/6ojS0j`OoYl3[2?nW_n/5ojO0j`WoZ<3[
1_nW`>/9ojNoj`GoYl3[2_nX`N/2ojO0j`GoY[k[2?nW_n/7ojO0j`OoYkkZ0onU^>H3o`0000KoWJGK
1onNX]P7oinRe`03oj:Se_nT^nWoY;_Y00CoY;_Y1onW`>`2oj[1j`KoS^Cl1?mMeN42odW8fPKoMMKm
0_nM^nh8ohg2n@?oHl?m1?nC/nd6ofZio@;o::7]0_lUZn06ogoGo`?o//g^1?nAdoh8ok[9iP03oknm
eoo1a=go`LCM00Co`LCM0onn_=P6ol;1f@Co^/3N1Onm`]h6ok30iP03ok?2i_nX`>_oZ<3[00KoZ<3[
1onW`>/4ojW0j`04o`000?nY`>_oZL3[ojW0j`OoYl3[1onV_n/8ojO0jaCooooo00?o0000oooooooo
ool00_ooool01OnHV9So410@o`000?lQ8B7oc<c<00oooooo000>ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01_ooool00ol0003oooooooooo`08ojO0j`OoZ<3[1OnW`>/:ojNoj`03ojO0jonX`>_oZ<3[
00_oZ<3[0_nW`>/=ojNoj`03ojO0jonX`N_oZ<7[00[oZ<7[0_nW_n/7ojJnj`KoYko[2OnW`>/5ojNn
jP04oj2`hol0003o0000o`0000CoWJWO1_nMYM/6oijRf0KoWj;G00?oXK?UojBkjOnT^nT01_nT^nT5
ojO0k0CoT^Gk0_n>i?`5oegEh@GoSMgn0_mee_d6oifkkPKoSL;i00?oYk?Qoi>ckOnC/nd01_nC/nd6
ofZio@Ko::7]1?l_[N`7oi7CoPKo^/WV00?oZ<_bol74gOo1a=d01_o1a=d00onn_=So`/7Iol;1f@06
ol;1f@03ok[0g_nm`]ko_L;N00Ko_L;N0_n``>H5ok?2iPOoZ<3[2?nW`>/4ojW0j`03o`000?nY`>_o
ZL3[00OoYl3[1_nV_n/2ojNoj`SoYl3[5?ooool00ol0003oooooooooo`0Eooooo`003_ooool01Ol@
413ooooooooooooooooo410@00Kooooo0_l00002ooooo`SoYl3[1onX`>/00onW`>_oYko[ojNoj`0:
ojNoj`;oYl3[3?nX`>/3ojO0j`coYko[0onW`>/8ojS1j`KoYko[1onV_^/2ojNoj`goYl3[00?oYkkZ
oj2`hol000000_l000000onP/>?oWJWOoifYg`05oifYg`GoWJGK1onNX]P2oinRe`GoXK?U2?nT^nT0
0onW`>coT^Gkoi;Un`05oi;Un`?oLn7W0onKh_d6ohgMoP;oY;SW1onM^nh2ohg2n@GoYk?Q2?nC/nd3
ofZio@?oT[;]1omI[oX00olPUn_o;jg/obn]k007oi7CoP;o^/WV1OnXbo86ol74g@03okc8hoo2`MWo
`/7I00Ko`/7I00?oa<GJokg2g_nm`]h01_nm`]h00oo0aMko/l;Vok?2iP06ok?2iPOoZ<3[2?nW`>/4
ojW0j`03o`000?nY`>_oZL3[00OoYl3[0_nV_n/6ojNoj`OoYl3[5Oooool00ol0003oooooooooo`0D
ooooo`003_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00oooool7
ojO0j`?oZ<3[1OnW`>/8ojNoj`KoYl3[2?nX`>/7ojO0j`SoYko[1onW`>/7ojS1j`OoYko[1OnV_^/?
ojO0j`?o00001OnP/><6oifYg`KoWJGK0onNX]P3oifZh0SoXK?U1_nT^nT4oicTo@;oT^Gk0omchNL7
oi_Ro@;oSMgn1_nT^>L5oifkkP03oj^cg_nW/n7oYk?Q00KoYk?Q1_nC/nd00on/]^3oT[;]oi:bk@05
oi:bk@OoFJoj0olPUn/3oi7CoPCoFkgl1onXbo83ol74g@Co_<SS1_o2`MT3olC5fPKo_L;N0oo0aMh6
ok?2iP03okC5i_nX`>_oZ<3[00KoZ<3[1onW`>/4ojW0j`03o`000?nY`>_oZL3[00SoYl3[2?nW_n/7
ojO0jaCooooo00?o0000ooooooooool05?ooool000kooooo00Go0000ooooooooooooooooo`000005
ooooo`03o`000?oooooooooo00Gooooo1OnW`>/2ojS0j`SoYl3[1onW_n/7ojO0j`SoZ<3[1onW`>/7
ojNoj`SoYl3[1onX`N/7ojNoj`03ojJnjonW`>_oYl3[00goYl3[0ol00002ojFjj0OoX;3S1_nMZMl3
oifUf`;oV:;K1onMZ^08oj6ci@;oY;_Y1_nLi?d3ohKZjPCoY>Ok1?nKh_d3ojNiiPSoY;SW00?oWK_^
oj^cg_n[/mh00on[/mh8ojNch@;oTk?]1On/]^07oi:bk@?oFJoj1?n0[o83ocbMm0;o89O[1OmK_O`7
ojS;lP03ol74gOnlb>?o_<SS00Co_<SS0oo2`MT6olC5fP?o_L;N1Oo0aMh4ok?2iPCo]<GV2?nX`>/7
ojO0j`CoZL3[00?o0000ojW0jonY`>/02?nW`>/7ojNoj`OoYl3[5Oooool00ol0003oooooooooo`0C
ooooo`003_ooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool01_ooool0
0onW`>_oZ<3[ojS0j`04ojS0j`SoYl3[1onW_n/7ojO0j`SoZ<3[1OnW`>/9ojNoj`KoYl3[2OnX`N/5
ojNoj`;oY[o[3?nW`>/3o`0000KoYK[X1onP/><3oifYg`;oUZ3K1_nHX]/7oifZh0KoXK?U1?nUfo/2
oicTo@?oQ^[Z1onTio/00on[`>WoYkWVojNiiP05ojNiiPKoY;SW00?oZK;Noj^cg_n[/mh01On[/mh6
ojNch@03ok2gg_n/]^3o[;KP00Ko[;KP1OnB/^d2oj^hh`OoP:ob1OllWO@3oc2MlP;oFkgl0onXbo83
oi;8nPSo_<SS00?o`/7IolC5f_o4aMX01_o4aMX00onm`]ko`<GNol35gP05ol35gP03ok?2i_ndaNKo
]<GV00Go]<GV1onX`>/7ojO0j`GoZL3[00?o0000ojW1jonY`N/02?nW`>/7ojNoj`OoYl3[5Oooool0
0ol0003oooooooooo`0Booooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_l00008
ooooo`OoZ<3[1_nW`>/9ojNoj`GoYl3[2_nX`>/00onW`>_oYko[ojNoj`0;ojNoj`;oYl3[3OnX`N/0
0onW_n_oY[o[ojJoj`04ojJoj`SoYl3[0ol00004ojRoj`KoYK[X0onP/><3oiRUgPKoUZ3K1_nHX]/7
oifZh0;oXK?U1_nUfo/4oiSak@Co[Nog0_nTio/5oj_0j@OoYkWV0_nT^>L5ojVbgPOoZk?N0_nW/n45
ok2ggPSo[;KP00?oT[;]oj^hhon[^><01?n[^><7oh2_lPGo?9gd1Ol`WO86oi;8nPKo_<SS00?o/lOX
olC5f_o4aMX01_o4aMX00oo4amco`<GNol35gP05ol35gP;o`/WP2?ndaNH7ojS0j`OoYl3[0_nY`>/2
ojW1j`04o`000?nY`N_oZL7[ojW1j`OoYl3[1onW_n/6ojO0j`03ojS0jooooooooooo01?ooooo00?o
0000ooooooooool04_ooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oo
oooooooo00Sooooo1onX`>/2ojO0j`goYko[00?oYl3[ojS0jonX`>/02_nX`>/2ojO0j`coYko[0onW
`>/<ojS1j`;oYko[1onV_n/5ojO0j`;o00002?nX_n/3ojFjj0;oVZ_S1onHYMh6oiJPf`KoV:;K1OnM
Z^03ojO=m0CoYM_k1?nHlNd5ojg_m`03ok7>kon[`>WoZl3Y00KoZl3Y1OnW^NH00onW/MooZK;NojVb
gP06ojVbgPGoZk?N00?o[KOQok2gg_n`]mh01_n`]mh6ojbfh003ok>kgon[^>?oZkSS00KoZkSS0on0
[o84oiZgk0?oFZGg0_llWO@5oc2MlPGoT/Sj1?nlb><4ok?7j0Koa<GJ0oo4am`5ol35gPCo`/WP1_nd
aNH00onea^SoZ<3[ojS0j`06ojS0j`OoYl3[1?nY`N/01?l0003oZL7[ojW1jonY`N/7ojO0j`OoYko[
0_nW`>/5ojS0jaGooooo00?o0000ooooooooool04Oooool001Sooooo00?o0000ooooooooool02Ooo
ool5ojS0j`?oYl3[2_nW_n/4ojO0j`WoZ<3[1_nW`>/8ojNoj`OoYl3[2?nX`N/6ojNoj`GoY[o[0onW
`>/3o`0000?oYl3[1_nX_n/00onQ]nSoVZ_SoiZ[h`04oiZ[h`KoV:GN1_nFX=/7oiRRf`03oifZh?nW
cOCoYlgd00KoYlgd00CoYM_koiSakOnHlNgoV?7]1On]koL4ok7>k`SoZl3Y00?oYkWVojNagonW/Ml0
0onW/Ml7ojVbgP?oZk?N1?n]]n48ok2ggP;o[;KP1Onc^ml6oj^hh`03okBnhOnJ]ncoV[O/00KoV[O/
1_mJYOL2obfAk`;o<9gb1OnBb?X00onlb>?o/lOXok?7j005ok?7j0?oa<GJ1_o4am`3ol35gPKo`/WP
0_ndaNH5okG6j0OoZ<3[2?nW`>/4ojW1j`03o`000?nY`N_oZL7[00OoYl3[1onW_n/8ojS0jaGooooo
00?o0000ooooooooool04?ooool001Sooooo00?o0000ooooooooool02_ooool00onX`>_oYl3[ojO0
j`05ojO0j`OoYko[1onW`>/7ojS0j`SoYl3[2?nW_n/7ojO0j`OoZ<7[1onW_n/01?nV_n_oYl3[ojO0
jonW`>/3o`0000OoYl3[0_nX_n/5oj6gj0KoVZ_S1_nHYMh6oiJPf`?oV:;K1?nR_N`7ojO=m0?oZ?7e
1?nfmO800on]koOo/Lk_ok7>k`05ok7>k`KoZl3Y00?oY;3QojNagonW/Ml01OnW/Ml7ojVbgP03oj^c
g_n]]n7o[KOQ00Co[KOQ1_n`]mh00ona_^Co/k_Ook>kg`06ok>kg`?oZkSS1?nd_^48oiZgk0KoFZGg
0ol]TNl6ogZkn`So/lOX00?oa<GJolC7g?o4am`01_o4am`00oo0aMko`/WPol;9h004ol;9h003ol;<
h_nea^So]LKX00Ko]LKX1onX`>/8ojO0j`CoZL7[00?o0000ojW1jonY`N/01onW`>/7ojNoj`OoZ<3[
5Oooool2o`00017ooooo000Gooooo`?o00003Oooool7ojO0j`OoYko[1onW`>/7ojS0j`SoYl3[2?nW
_n/5ojO0j`WoZ<7[1OnW_n/2ojJoj`?o00002OnW`>/2ojNoj`OoXKOX1OnJZn<6oiRUgPGoUZ3K0_nG
Z^<7oj:mk0CoYlgd0onXlOD5okKelP?o^N;d1onac^l2oj_0j@GoY;3Q1_nW/Ml6ojVbgP03oj^ii?n]
]n7o[KOQ00Go[KOQ1?n`]mh4ok6ni0So/k_O00?oZkSSokBnhOnd_^401?nd_^46oiZgk0;oZ;gX1Om/
Z?D2ocV?k`;o;I7_1_mj^o/6ok?7j0;o[<C[1oo4am`00oo5bMko`/WPol;9h004ol;9h0?o`/cR1_ne
a^P00oncb>WoZ<3[ojS0j`06ojS0j`OoYl3[1?nY`N/01?l0003oZL7[ojW1jonY`N/3ojO0j`_oYko[
1onX`>/Cooooo`03o`000?oooooo0000017ooooo000Gooooo`03o`000?oooooooooo00kooooo1onW
`>/7ojNoj`GoYl3[2OnX`>/6ojO0j`[oYko[00?oYl3[ojS1jonX`N/02onX`N/00onW_n_oY[o[ojJo
j`03o`000003ojJojonW`>_oYl3[00KoYl3[1_nW_n/6oj6gj0KoVZ_S1_nHYMh00onFX=_oUj[SoiNZ
h`04oiNZh`OoX[g/00?oYlgdojSamOnXlOD00_nXlOD4okKelPOo^N;d0onac^l2oj>bh`SoY;3Q1_nW
/Ml2ojVbgPGoZkWT1on]]n400on`]mko/KkTok6ni005ok6ni0Ko/k_O0_nd_n87okBnh@;oV[O/1_nX
_NP5ofbXm@Co>Ho_1_mj^o/2ok?7j0Ko[<C[1?o4am`4olG9gP?o`/WP1_o2c>83okG6j0Co/lSY2?nX
`>/7ojO0j`CoZL7[00?o0000ojW1jonY`N/03_nW_n/8ojS0jaCooooo00?o0000ooooooooool03ooo
ool001Oooooo00?o0000ooooooooool03oooool7ojO0j`OoYko[00?oYl3[ojS0jonX`>/02onX`>/2
ojO0j`coYko[00?oYl3[ojS1jonX`N/02onX`N/01?nW_n_o0000o`000?l00005ojJoj`OoYl3[1onW
_n/6oj6gj0?oVZ_S0_nBX^06oi6PgPSoUj[S1OnR_N`4ojkRn@Co_OO_00?o]_GbokWRm?nih_@01Oni
h_@00onW_>SoXk;Soj>bh`04oj>bh`OoY;3Q1OnW/Ml00onW^>GoZkWToj^ii006oj^ii0Go[KOQ0_n]
`nX8ok6ni0;o/k_O1_nd_n85okBnh@;o]l;R2?nX_NP5ofbXm@Co>Ho_1_m[[?L8ojc4j`03olC7g?o5
bMkoaLWN00GoaLWN00?o`/WPol;<h_o2c>801_o2c>800onea^So/lSYok?8j@04ok?8j@KoZ<3[2OnW
`>/4ojW1j`03o`000?nY`N_oZL7[00koYko[2?nX`>/Dooooo`03o`000?oooooooooo00kooooo000G
ooooo`03o`000?oooooooooo013ooooo1onW`>/5ojNoj`?oYl3[2_nX`>/4ojO0j`WoYko[1OnW`>/9
ojS1j`04ojNojol0003o0000o`0000;oYko[1onV_n/7ojO0j`OoYko[0onQ]nP2oiJZi0KoTZ;P1_nA
X=h8oiNZh`03oj:mk?n^h_Wo[^;i00Co[^;i1?nmmnl4ol;]l@;o^N;d1OnW_>P6oj>bh`OoY;3Q00?o
Yk7OojNhiOnW^>D00onW^>D8oj^ii003ojfghOn]`n[o[L?Z00Co[L?Z1_na_^@00on]`n[o];oRokBo
hP07okBohP03okBnhOng`^;o]l;R00Co]l;R1_nX_NP00on_`^SoMJWcogFYl`04ogFYl`;oAXo^0_li
Snl6of^/m`Ko[<C[00?oYl3/olG9g_o5bMh01Oo5bMh2olG<g`Oo`/cR00?o`/oTok?8jOncb>T01_nc
b>T2ojS0j`_oYl3[00?oZ<3[ojW1jonY`N/00onY`N/00ol0003oZL7[ojW1j`06ojNoj`03ojJojonW
_n_oYko[00GoYko[1onX`>/Eooooo`03o`000?oooooooooo00gooooo000Gooooo`;o00004_ooool7
ojO0j`03ojNojonW`>_oYl3[00GoYl3[1onX`>/7ojO0j`OoYko[1onW`>/6ojS1j`?o00001_nW_n/3
ojJoj`_oYl3[0onW_n/3oijfj@KoUZ[T1_nBX^06oi6PgPKoUj[S0onZb_43ojkRn@Co_OO_1Oo2kO40
0onjenkoYkcXojNlj006ojNlj0KoXk;S0onT/>44ojBdi0KoYkSU1_n[^N@2ojO1k0Oo[L?Z0_na_^@5
ojg3jPOo];oR00?o/l?VokO2h_ng`^801_ng`^82ojRmj0Go[l;X1_meZO<4odJ?kPKoJjcg0_n/a>/5
ojO0k0GoaLWN1?o5c=l4ol;<hPCo`/oT1_ncb>T2ok38j`WoYl3[1OnX`>/4ojW1j`04o`000?nY`N_o
ZL7[ojW1j`;oYko[1OnV_n/7ojNoj`OoZ<3[5?ooool00ol0003oooooooooo`0=ooooo`005oooool0
0ol0003oooooooooo`0Booooo`GoYl3[0onW_n/7ojO0j`OoZ<3[1onW`>/7ojNoj`OoYl3[0onX`N/2
o`0000?oZ<7[1OnW_n/2ojJoj`coYl3[0_nV_n/6oijfj@KoUZ[T1_nBX^06oi6PgP;oUj[S1onZb_40
1?n^h_Wo_OO_okggkonmmnl5ol;]l@Co^]O^1onW_>P5oj>bh`03oj6ai?nT]>CoY;CT00KoY;CT1_nW
^>D2oj^ii0KoYl7/1On]`nX00onV_N[o[L?Zojg3jP06ojg3jPCo];oR1?nc`nH6okO2hP;o^<GT1on_
`^P6ogFYl`CoAXo^1OmXX_88ojO0k0?oaLWN1_o5c=l00oo2c>;o`/oTol;?i005ol;?i0;o/lSY1_n`
b>/5ojO0j`03ojNojonX`>_oZ<3[00KoZ<3[1?nY`N/00ol0003oZL7[ojS1j`08ojJoj`?oYko[0onW
`>/8ojS0jaCooooo00?o0000ooooooooool03?ooool001Oooooo00?o0000ooooooooool04oooool0
0onW`>_oYko[ojNoj`05ojNoj`GoYl3[2OnX`>/5ojO0j`WoYko[1OnW`>/01?nX`N_o0000o`000?l0
0006ojS1j`03ojNojonV_n_oY[o[00CoY[o[2?nW`>/6ojJoj`KoW[KY1OnFZ^@7oi:Rh0?oTJ3N1?nL
/nP6oj[:l@?o_ncb1?o<l^/2ol;]l@Ko^]O^1onW_>P00onS/^?oXK7Toj6ai003oj6ai0SoY;CT0onW
^>D;ojO1k003ojg3j_nV_N[oY[gZ00?oY[gZ2?n]`nX00ond_n;o/l?Vok?3iP04ok?3iPCo]l;R1Onh
aN@5ojo2j003ojo5j_mhYo3oN:O`00CoN:O`0om?SN/2odJ?kPGoJ:;b2?nW`>`00oo5bMkoaLcOolG<
g`04olG<g`;oaloQ1_o2cn@2ol3@iPSo/<S[00?oYl3[ojNojonW_n/00onW_n/8ojS0j`;oZL7[0_nX
`N/00ol0003oZ<7[ojS1j`07ojJoj`OoYl3[1_nX`>/00onX`N_oooooooooo`0Cooooo`03o`000?oo
oooooooo00_ooooo000Gooooo`03o`000?oooooooooo01Gooooo1onW_n/00onW`>_oZ<3[ojS0j`0;
ojS0j`03ojO0jonW_n_oYko[00_oYko[00?oYl3[ojS1jol000000_l00008ojS1j`;oYko[1onV_n/8
ojO0j`KoY[o[1_nN]^T5oiJZi0?oTZ;P0on>XN48oibcj0?oZ/[a1?nok?85olcbj`?oanG/1_njenh3
ojNlj0?oWK3U1onQ/N@6ojBdi0koYl7/00?oYkWVojJmj_nV_NX01OnV_NX6ojg3jP;oY[o/1onc`nH0
0ong`^;o^<GTokS5i006okS5i003ojo2j?n_aN[o[lGZ00?o[lGZ1_mhYo05odn=j`GoJ:;b1_nW`>`0
0onW_^[oaLcOolG<g`04olG<g`CoaloQ0oo2cn@5ol3@iPKo/<S[00?o[<G/ojNojonW_n/01OnW_n/7
ojS0j`GoZ<7[00?o0000ojS1jonX`N/01onV_n/7ojO0j`;oZ<3[1OnX`N/Dooooo`03o`000?oooooo
oooo00_ooooo000Fooooo`?o00005oooool5ojNoj`?oYl3[3_nX`>/:ojNoj`04ojO0jol0003o0000
o`0000SoZ<7[1_nW_n/7ojJoj`SoYl3[1_nV_n/3oijfj@;oTZ_W1On<XN87ohjQh@SoW;?X00?oZ/[a
oko/l_nok?800_nok?85olcbj`GoanG/0onjenh3oj:ij@KoWK3U1onQ/N@2ojBdi0koYl7/1OnW^NH7
ojJmjP;o[L?Z1_nV_n`5ok?3iP;o/<?X1onhaN@00onhb>Ko[lGZojo5jP05ojo5jPKoN:O`1?m?SN/4
ofjNkP;oJ:;b0_nW`>`5ojNnjP?oaLcO1oo7cn400oo2cnCo`=3Vol3@iP05ol3@iP;o/<S[1On/aN`7
ojNoj`OoZ<3[1?nX`N/00ol0003oZ<7[ojS0j`07ojJoj`OoYl3[2?nX`N/Dooooo`03o`000?oooooo
oooo00[ooooo000Fooooo`03o`000?oooooooooo01Sooooo00?oYko[ojO0jonW`>/01OnW`>/>ojS0
j`KoYko[00CoYl3[o`000?l0003o00001?nW`>/7ojS1j`OoYko[1OnV_n/:ojO0j`?oY[o[0_nN^>/6
oi:[i`GoS:7R1on>XN46oibcj0Co/Lo_00?o_ncbolcbjoo<l^/00_o<l^/6olOUk003ok_FkOnR^NWo
X[WY00GoX[WY1_nM/>D5oj6ai0;oX[WY3?nW`N`9ojNiiPGoY[gZ0_nZ_>L8ojJok003ok?3i_n``nSo
/<?X00Co/<?X1?nhaN@4okS8iPOo[lGZ1_mhYo04odn=j`KoKYk^1onW_^X00oo5c=ooaloQolO?h@05
olO?h@03olSCh_o0d>Ko`=3V00Go`=3V00?o_M3Xojc5k?n/aN`01_n/aN`3ojNoj`?oYl3[2?nX`>/2
ojS1j`;oZ<3[00?o0000ojS0jonX`>/01onV_n/7ojO0j`OoZ<7[4oooool3o`0000_ooooo0004oooo
o`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo00?o0000ooooooooool0
6_ooool7ojO0j`koZ<3[0onW_n/3o`0000SoYl3[1onX`N/7ojNoj`03ojJojonW`>_oYl3[00_oYl3[
1_nN^>/6oi:[i`GoS:7R1on>XN42oibcj0Ko/Lo_1?o:j>/00oo<l^_oanG/olOUk003olOUk0Co^mK]
1onR^NT6oif`i@03oj6ai?nR^NWoX[WY00CoX[WY2?nW`N`=ojNiiP03ojJmj_nZ_>OoZ[cW00CoZ[cW
2?nV_n`7ok33j003okS5i?nhb>Ko^<SV00Go^<SV1On_aNX00onXa>koMZ7]ogJQk@04ogJQk@?oF8_W
0_m?SN/6ofjNkPGoYkkZ0_n/_nP6olO?h@?ob=?R1?o0d>H4okg@j0Ko[<G/00?oZL;/ojO0jonW`>/0
1OnW`>/6ojS0j`;oZL7[1?nX`>/00ol0003oZ<3[ojJoj`05ojJoj`;oYko[1onW`>/7ojS1j`oooooo
0ol00002ooooo`03o`000?oooooooooo00Wooooo0006ooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo01_ooooo1_nW`>/=ojS0j`04ojNo
jol0003o0000o`0000CoYko[1_nW`>/2ojS0j`OoZ<7[0onW_n/4ojJoj`koYl3[1_nN^>/5oi:[i`Ko
S:7R1On>XN42oingj@Ko/Lo_1?o:j>/4om?[iP;oanG/1_nke^d7oj:ij@?oWK3U0onM/nL7oj:ij@?o
Yl7/1?nX_^T<ojNiiP;o[;[S1onZ_>L8ojJok0Oo/<?X2?nhb>H00on_aN[oZ<C^ojS4kP03ojS4kPKo
MZ7]1OmHRnL6ofjNkP03ojNnj_n/_nSo[;oX00Co[;oX0oo7cn46olSChP03ol3@i_nmd>So_M3X00Go
_M3X0_n/aN`5ojW2k0OoYl3[0_nX`>/6ojW1j`?oZ<3[00?o0000ojS0jonX`>/00_nV_n/6ojNoj`Go
Yl3[00?oZ<3[ojS1jonX`N/01_nX`N/;ooooo`?o00001Oooool00ol0003oooooooooo`09ooooo`00
1_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool2o`0001go
oooo1_nW`>/9ojS0j`04ojNojol0003o0000o`0000SoYko[0_nW`>/6ojS0j`GoZ<7[0_nW`>/7ojJo
j`koYl3[1_nN^>/5oi:[i`KoS:7R00?oSZ7QoingjOnO]nT01?nO]nT3ok7?k`Gob^S[1OoCjnH3olgQ
iPKo^mK]0onR^NT3oiVaj0OoWK?W1OnR^NT00onY`^_oZ;kYojRnj@06ojRnj@SoYkWV1_n/^^<5ojZl
i`;o[l;X2?nV_n`7ok33j0Ko^<SV00?o^<_YojS4k_nXa>h01OnXa>h6ogJQk@CoF8_W1_mjWnT8ojbo
j003olO?hOo8dn;ob=?R00Cob=?R0_o8f>H6okg@j0;o^<o/1onY`^`7ojO0j`SoZL7[0onX`>/00ol0
003oYko[ojNoj`08ojNoj`03ojO0jonX`>_oZ<3[00?oZ<3[2?nX`N/6ooooo`Co00002?ooool00ol0
003oooooooooo`09ooooo`001_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000001Oooool2o`0001oooooo1_nW`>/7ojS0j`;o00002OnW_n/4ojO0j`OoZ<3[00?oZ<7[ojO0
jonW`>/01?nW`>/7ojJoj`koYl3[0onN^>/2oi6]j@GoQj?V1on:X^@7oingj@03ok7?koo:j>_ob^S[
00?ob^S[1OoCjnH5olgQiP?o^mK]0_nS_^`7oiVaj0OoWK?W00?oX[WYojW2jonY`^/00onY`^/8ojRn
j@?oYkWV0onW^>D8ojbjh`03ojZlion_`^So[l;X00Co[l;X1_nV_n`00onV_n_o/<?Xok33j006ok33
j0;o^<SV1OnhbnT7ojS4kPKoMZ7]1?mHRnL6ogZOj@Ko[;oX0_nca>L5olSChPCob=SV0onmd>P5okS?
k0OoZL;/1onW`>/7ojW1j`CoYko[00?o0000ojNojonW_n/01onW_n/7ojS0j`KoZ<7[00CoYl3[oooo
oooooooooooo0ol0000=ooooo`03o`000?oooooooooo00Sooooo0006ooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo01oooooo1_nW`>/3
ojS0j`?o00000_nX`>/7ojNoj`OoYl3[1OnX`>/3ojS1j`KoYl3[1OnV_n/3ojNoj`[oYl3[0_nQ_>`6
oi6]j@GoQj?V1on:X^@5oingj@Co]Lg/0_o:j>/4om?[iPKocN7V00?oaMKWoj>nk?nS_^`01?nS_^`7
oiVaj0GoWK?W0_nR^NT6ojW2j`KoZ;kY00?oXk[YojNhiOnW^>D01OnW^>D6ojbjh`;o/<?X1on_`^P2
ojJok0GoY[o[1_n``nP2ok?8jPOo^<_Y0onXa>h3oiVjk`KoLiSW0_mRRN82oeR;i`KoNYoY1?n/_nP5
ok?4i`?ob=?R1_o8f>H00onmd>So^<o/okS?k005okS?k0?oZL;/2onW`>/7ojW1j`CoYko[00?o0000
ojNojonW_n/01onW_n/7ojS0j`;oZ<7[1OnW`>/2o`00013ooooo00?o0000ooooooooool02?ooool0
00Kooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000
ooooooooool08?ooool3ojO0j`;oZ<3[0ol00006ojS0j`OoYko[1onW`>/00onX`>_oZ<7[ojS1j`05
ojS1j`KoYl3[00?oY[o[ojNojonW_n/01OnW_n/6ojO0j`KoXKc/1_nA[NT5ohNSiPOoRZ;T00?oWkOY
okG=k?necN`01OnecN`4olcNiP03om?[i_o=hNKocN7V00CocN7V0oo5e^L6oj>nk0OoVK7X00?oWK?W
oj:ijOnR^NT01?nR^NT6ojW2j`;oZ;kY1OnS^^T7ojNhi@;o[;[S1_n``nP5ojo2j0;o[lO[1onV_n/3
ok33j0Go/lSZ1OnhbnT2okK>k0KoVK[_1_mcV>L4of:9hPKoNYoY00?o[;oXok?4ionca>L01_nca>L0
0oo8dn;ob=SVolSHiP04olSHiP03olCIjOnhcnco^<o/00Go^<o/00?o/<[]ojO0jonW`>/02onW`>/0
0onX`>_oZL7[ojW1j`05ojW1j`CoYko[00?o0000ojNojonV_n/02?nW_n/3ojS0j`?oZ<7[2?nW`>/A
ooooo`03o`000?oooooooooo00Sooooo0006ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o00008_ooool01?nX`>_o0000o`000?l00008ojS0j`?oYl3[1_nW
_n/5ojO0j`?oZ<3[1onX`N/3ojO0j`?oY[o[2?nW_n/6ojO0j`KoXKc/1_nA[NT5ohNSiPGoRZ;T0_nL
/nP6okG=k0Goc=kV0_oEhMl3olgQiPKoaMKW1_nS_^`3oiVaj0CoV;C[1onR^NT3ojW2j`?oYKo/1onS
^^T5ojNhi@03ojO0jon``nSo/<?X00Oo/<?X00?o[l;Xojo7jon_an/01?n_an/7ojJoj`03ok33j?nc
b>[o/lSZ00Go/lSZ00?o^<_YokK>k?nfc^`01?nfc^`6oiVjk`GoLiSW1?mRRN87ohZUi`Oo/lCW0_nm
c>H4olSHiPCoa=WY1?nhcn`4ok3:k@WoYl3[1OnX`>/7ojW1j`;oYko[0_nV_n/00ol0003oY[o[ojJo
j`06ojNoj`03ojO0jonX`N_oZ<7[00GoZ<7[1_nW`>/00onW_n_oooooooooo`0?ooooo`03o`000?oo
oooooooo00Sooooo0004ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`03o`000?oooooooooo01oooooo0ol00008ojS0j`OoYl3[1_nW_n/00onW`>_oZ<3[ojS0
j`05ojS0j`GoZ<7[00?oZ<3[ojJojonV_n/01OnV_n/6ojNoj`SoYl3[1_nQ_>`6oi6]j@GoQj?V00?o
RZ;Toibcj?nL/nP01?nL/nP3okG=k0Koc=kV1?oEhMl00oo=hNKoaMKWolGFi`06olGFi`?oXkk/0onG
]^d7oiRdj`GoX[WY00?oZL3[ojFok?nU_n`01OnU_n`7oj>jj@03ojNhiOnW`>_oYl3[00?oYl3[1on`
`nP2ok3;k@Oo[lO[0onV_n/3ojJnj`Oo/lSZ0_nec^d7okK>k0KoVK[_1?mcV>L5of:9hPOoRZGW1?nc
a>L5okg<iP03olSHi_o4fNWoa=WY00Goa=WY00?o^<o/ok3:kOn`b^d01?n`b^d8ojO0j`OoZ<3[0onY
`N/3ojS1j`GoY[o[00?o0000ojJojonV_n/00_nW_n/5ojO0j`OoZ<7[0_nW`>/5ojNoja3ooooo00?o
0000ooooooooool02?ooool001Gooooo00?o0000ooooooooool07?ooool3o`0000Cooooo2?nX`>/7
ojO0j`OoYko[1onX`>/00onX`N_oZ<3[ojS0j`03ojS0j`OoY[o[0_nW_n/<ojO0j`?oXKc/0onD/nd5
ohJWjPKoPj3V1onL/nP00onecNcoc=kVolcNiP04olcNiPGoeN7O0_oCg=h6olGFi`;o]<c[1_nG]^d7
oiRdj`03oj:ijOnY`>_oZL3[00?oZL3[1onU_n`3oj>jj@CoWKc^1_nW`>/4ok33j0Go/<_]1On_an/0
0onZ`ncoY[k[ojJnj`05ojJnj`Co/lSZ1Onec^d5okK>k003ojc6kOn8X^GoR:;U00CoR:;U1?m`S^00
0omcV>OoHXWRof:9hP03of:9hPOoRZGW00?o/lCWokg<i_nmc>H01?nmc>H2olGHi`Koa=WY0_nne^/7
ok3:k@SoYl3[1OnX`>/8ojS1j`GoY[o[00?o0000ojNojonW`>/01_nW`>/7ojS1j`SoYko[3oooool0
0ol0003oooooooooo`08ooooo`005Oooool00ol0003oooooooooo`0Iooooo`?o00002?ooool8ojS0
j`GoYl3[2OnW_n/=ojS0j`SoY[o[2_nW`>/4ojFok0GoU;?]1On6YnX6oh>PiPGoW;?X0onaa^T4olcN
iPGoeN7O1OoCg=h00oo5e^Oo]<c[okC<j`04okC<j`KoUkK]0onH]>/4oiZhk@KoZL3[1OnU_n`00onO
_NkoWKc^oiflkP06oiflkPKoYl3[00?o/<?Xok3;kOn`bnd01_n`bnd00on_an_oZ/?/oj[3k003oj[3
k0OoY[k[00?o/lSZokG>kOnec^d01_nec^d00onfc^co[<K]ojc6k@03ojc6k@KoR:;U1?m`S^04og:>
g`;oHXWR0on:YNL4oiZbj0Go_LcV1?o5f>L3olCIj@Go_]K[1On`b^d2oj[3k0SoYl3[00?oZ<3[ojS1
jonX`N/02_nX`N/2ojJoj`;oYko[00?o0000ojNojonW_n/01onW`>/7ojS1j`OoYko[3oooool00ol0
003oooooooooo`08ooooo`005Oooool00ol0003oooooooooo`0Fooooo`?o00003Oooool7ojS0j`03
ojO0jonW_n_oYko[00_oYko[3OnX`>/8ojJoj`KoYl3[2?nU_n`5oiBck@GoQZOZ1_n3X>H00onL/nSo
/LKYok76j@06ok76j@03olcNi_oEhMooeN7O00?oeN7O1OoCg=h2olkCgPOo]<c[0onG]^d2oi>fk`So
V[S]1_nY`>/00onU_ncoWkg^oinmkP03oinmkPSoWKc^0onW`>/4ojO8l@Ko/<_]00?o[<S^oj[3k?nZ
`n`01OnZ`n`5ojJnj`?o[LO]1_nec^d00oned^oo[<K]ojc6k@05ojc6k@GoR:;U1Om`S^05og:>g`So
V[;X0onmc>H6olGHi`03olCIjOnne^_o_]K[00Go_]K[00?o/<[]oj[3k?nZ`n`01?nZ`n`7ojO0j`co
Z<7[1_nW_n/00ol0003oYko[ojNoj`03ojO0j`CoZ<3[1onX`N/7ojNoj`oooooo00?o0000oooooooo
ool01oooool001Cooooo0_l0000Eooooo`?o00004Oooool7ojS0j`coYko[0_nW`>/:ojS0j`CoYl3[
1onV_n/6ojO0j`SoYKo/1OnD/nd5ohJWjP?oPj3V0onAZnP7ok76j@?oa<oR0ooEhMl5om?LgPCoc]?N
1Ondc>/2ojK3kPGoTkK_2?nJ^>d3ojW0j`?oZL3Z1_nO_Nh6oiflkP;oW<7b1onWb?42ok3;k@Go[<S^
1onZ`n`00onV_^_o[LO]ojg7k@05ojg7k@;o]Lk]1Oned^l7ojc6k@CoR:;U1_m`S^05og:>g`SoV[;X
00?o_LcVolGHioo5f>L01?o5f>L2olOOjPKo_]K[00?o]m;^oj[3k?nZ`n`01_nZ`n`7ojO0j`SoZ<7[
2_nW_n/00ol0003oYko[ojNoj`07ojS0j`GoZ<7[0_nW`>/7ojNoj`kooooo00?o0000ooooooooool0
1oooool001Cooooo00?o0000ooooooooool04_ooool2o`0001Gooooo1onX`>/8ojNoj`KoYl3[1OnX
`>/3ojS1j`KoYl3[1OnV_n/2ojNoj`KoYl3[1_nU_n`00onM^nkoRJg]ohV]k@03ohV]k@GoO:7Z1onA
ZnP4ok76j@Koa<oR00?oeN7Oom?Lg_oCg=h00_oCg=h7olkCgP03okC<jonV`nkoY/?^00CoY/?^1OnC
]^l6oiZhk@03oiflk_nY`>[oZL3Z00GoZL3Z1_nO_Nh2oiflkPKoW<7b1OnWb?42ojO7l0Oo[<S^0onZ
`n`4ojJnj`Ko[LO]0_nbdO07okGBk`?o[<K]0onEYn84oh6Cg003ohRRiOm`S^3oL8kP00?oL8kP1_mb
S]l6oiZbj0;oZKkY1?o5f>L5olOOjP;o_]K[1Ongd^h6oj[3k0WoYl3[1_nX`N/<ojNoj`03o`000?nW
_n_oYko[00OoZ<3[00?oZ<7[ojO0jonW`>/01?nW`>/6ojNoj`kooooo00?o0000ooooooooool01ooo
ool001Cooooo00?o0000ooooooooool03oooool3o`0001Sooooo1onX`>/7ojNoj`OoYl3[00?oZ<3[
ojS1jonX`N/01OnX`N/6ojO0j`03ojJojonW_n_oYko[00CoYko[1_nW`>/2ojFok0GoWK_^1On9[Nd5
ogbQjPOoTJ_X00?o/LKYolC?h_o4cn801Oo4cn84om7Df`03om?Lg_o>dmkoc]?N00Goc]?N0_o8c=d7
ojK3kPGoTkK_0_nJ^>d5oiflkPOoZL3Z1onO_Nh7oic1lP03ojO8lOnWao3oYlO`00CoYlO`1On/b>h0
0onW_^[oY[k[ojJnj`06ojJnj`?o[LO]1OnbdO05okGBk`03ojg6k?nEYn;oUJOR00GoUJOR1?n1Tm`4
ogB8f@;oL8kP1_mbS]l2oiZbj0KoZKkY00?oaMSWolOOj_o7gnX01?o7gnX2ol;Mk@Oo]m;^0_nZ`n`;
ojO0j`03ojS0jonX`N_oZ<7[00GoZ<7[2onW_n/01?l0003oYko[ojNojonW_n/3ojS0j`?oZ<7[2?nW
`>/6ojNoj`gooooo00?o0000ooooooooool01oooool001Cooooo00?o0000ooooooooool03?ooool3
o`0001cooooo1OnX`>/3ojO0j`KoYko[1OnW`>/3ojS0j`OoZ<7[0onW`>/3ojJoj`OoYko[1onW`>/6
oifkkPGoRJg]1OmlXNX5oi6[j0?oYK_Y1Oo4cn85om7Df`03omCAeoo>dmkoc]?N00Coc]?N1?o8c=d5
ojK3kP03oinmk_nA^?7oTKSa00CoTKSa1onM_>h7ojW0jPOoWkg^0onL`O84oj;0kPOoYlO`00?o[<S^
ojNnj_nW_^X00onW_^X8ojJnj`03ojg7kOnbdO3o/]7`00Go/]7`00?o]M;_ojg6k?n]a^`00on]a^`7
oiFWhPCoPI?L1OmdR=T6ohRMh@OoZKkY0onjdN/3olOOjPGo`]g]1Ongd^h2ojg8k@WoYl3[1OnX`>/7
ojS1j`_oYko[00?o0000ojNojonW`>/01onX`N/6ojO0j`SoYko[3?ooool00ol0003oooooooooo`07
ooooo`004oooool3o`0000[ooooo0ol0000Pooooo`03ojS0jonW`>_oYl3[00GoYl3[1_nW_n/00onW
`>_oZ<3[ojS0j`05ojS0j`GoZ<7[00?oZ<3[ojJojonV_n/01OnV_n/5ojNoj`WoYl3[1_nM^nh5ohV]
k@GoO:7Z00?oTJ_XojFkjOnU^nT01OnU^nT3olC?hPGodMCK0ooDdML3olkCgPOob<cM00?oY/?^oinm
k_nO_Nh00onO_Nh6oi6hl@OoWKc^1onY`>X5oinmkP;oYKk[1onR`>h5ojO7l0SoYkkZ1_nV_^/2ojc>
l@Ko/]7`0_nbd_46ojg6k0KoUJOR1On1Tm`5ogB8f@KoR9gQ1?nY_^T6ok[Aj`03olOOj_o2gNgo`]g]
00Go`]g]00?o]m;^ojg8kOn]b>d01?n]b>d7ojO0j`OoZ<3[0onX`N/3ojO0j`[oYko[0_nW`>/00ol0
003oYl3[ojO0j`07ojS1j`;oYl3[3?nW_n/;ooooo`03o`000?oooooooooo00Oooooo000Dooooo`03
o`000?oooooooooo00Kooooo0ol0000Uooooo`OoYl3[1onW_n/7ojS0j`03ojS1jonX`>_oZ<3[00?o
Z<3[1onV_n/00onW_n_oYl3[ojO0j`0;ojO0j`?oWK_^0_nB]_05ogjXk`GoOZC[2OnU^nT00oo4cn;o
dMCKom7Df`03om7Df`Goe=7G00?oc]?NolS<gOo8c=d01Oo8c=d2olG6f`KoWkg^1_nA^?43oiflkPCo
WL3a1onY`>X00onO_NkoYKk[ojFnj`04ojFnj`OoX/3^00?oYlO`ojNnj_nW_^X02_nW_^X2ojJnj`Ko
[<ka0_nbdO06ok;Bl@Ko[LK/1_nEYn84oh6Cg0KoM8SI1_n8WN400onY_^Wo^]7[ok[Aj`05ok[Aj`;o
a>7]1_o2gNd2ok[Gk`Oo[LS]1onW`>/5ojS0j`03ojS1jonW`>_oYl3[00GoYl3[1onW_n/4ojO0j`03
o`000?nW`>_oYl3[00OoZ<7[2onW_n/3ojO0j`_ooooo00?o0000ooooooooool01oooool001Cooooo
00?o0000ooooooooool00oooool3o`0002Wooooo1OnW`>/9ojNoj`goZ<3[2?nV_n/:ojO0j`?oYKo/
1OnB]_05ogjXk`GoOZC[1onU^nT3okC4iP?odMCK1_oDdML2om;<e0Cob<cM1Oo5a]/6oinmkP?oTKSa
0on@^o<7oig0l@GoZL3Z0_nYaNh7ojFnj`?oX/3^0onX_nX;ojNnjPCoYlSa1On/c_43ojgCm0Oo/];a
0on]a^`2oiNQf`KoRiCG1?mmRM@00on1TmcoM8SIogB8f@04ogB8f@?oR9gQ0onM/nL6ok[Aj`Coa>7]
0_o2gNd6ok[Gk`?o[LS]0onX`N`8ojO0j`03ojS0jonX`N_oZ<7[00?oZ<7[1onW`>/7ojNoj`CoYl3[
00?o0000ojO0jonW`>/01onX`N/7ojNoj`OoYl3[2oooool00ol0003oooooooooo`06ooooo`004ooo
ool01?l0003oooooooooooooool3o`0002gooooo00?oYl3[ojNojonW_n/02onW_n/=ojS0j`SoY[o[
1_nW`>/7ojFok0GoT[K`1OmnZ>l5ogjTj`CoYK_Y1_nda>H00ooAe=_oe=7GomCAe`04omCAe`God/cD
00?ob<cMolG6foo5a]/01Oo5a]/3oinmkPCoWk[[1On@^o<7oig0l@03ojW0j_nYaNkoZLG^00CoZLG^
1OnU_^/00onYaNkoZ;oZojRojP05ojRojPKoYkkZ2OnWb?400on/c_7o[M?dojgCm005ojgCm0?o/];a
0onX]>86oiNQf`KoRiCG1?mmRM@6oh>BfPOoWK?W0onjdN/5olCQk@03ol;Skonjenoo^]O_00Go^]O_
00?o/<_^ojS1k?nX`N`01OnX`N`7ojO0j`OoZ<7[1OnW`>/9ojNoj`?oYl3[00?oZ<3[o`000?nX`>/0
2?nX`N/7ojNoj`OoYl3[2_ooool00ol0003oooooooooo`06ooooo`004oooool4o`0003;ooooo2onW
_n/2ojO0j`[oZ<3[0onW`>/8ojJoj`KoYl3[1onU_n`5oi:fl0GoOZS_1OmnY>/00onU^nWo]<CVokC4
iP05okC4iP;o`<SP1OoDdML5om;<e003om37dOo5a]_oaLKK00GoaLKK0_o3`MP7oinjj`GoT;_c0onM
`?44oiO1m0OoZLG^00?oYKk[ojW5k_nYaNh00onYaNh7ojRojP;oYkkZ2onWb?43ojWCmPGo[M?d00?o
[<;ZojRdh_nX]>801OnX]>86oiNQf`GoRiCG1OmmRM@6oh>BfPOoWK?W00?o^]7[olCQkOo4hNd00oo4
hNd3ol;Sk`Co^]O_1?n`bnh7ojS1k0OoYl3[1onX`N/00onW`>_oYko[ojNoj`09ojNoj`;oYl3[1?nX
`>/00ol0003oZ<3[ojS1j`05ojS1j`03ojO0jonW_n_oYko[00KoYko[1_nW`>/:ooooo`03o`000?oo
oooooooo00Kooooo000Cooooo`;o0000=Oooool7ojNoj`KoYl3[1onX`>/6ojO0j`KoY[o[0_nW_n/6
ojO0j`GoYKo/0_nR_^d5ohRal0CoM:G`1on;[Nd5okC4iPCo`<SP0ooDdML5om;<e0?od<OA1Oo5a]/4
ol?1f0GoWk[[0_nW]nD6oi2lm0KoUl7d1OnYaNh2oio8m0KoZLG^1OnX_nX2ojK<m0WoYlSa1onYdoH0
0on]doCo[<;Zojc2jP03ojc2jPKoZ;CR1_nGXM/5oh^De`KoOHWD1On3T]X6oifci`?o/L_]0oo4hNd5
ol;Sk`03ok[Gkon`bnko/<_^00Co/<_^1_nX`N`9ojO0j`KoZ<7[2OnW_n/6ojO0j`?oZ<3[00?o0000
ojS0jonX`>/00_nX`N/5ojO0j`OoYko[1onW`>/9ooooo`03o`000?oooooooooo00Kooooo0005o`00
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo03?ooooo1_nW_n/7
ojO0j`OoZ<3[1_nW`>/2ojJoj`KoYko[1_nW`>/00onU_ncoX[k]oj:nk@04oj:nk@GoR;7`1?mdYO07
oh^]k@?o]<CV1_o0b>000ooDdMOod/cDom;<e003om;<e0God<OA0oo5a]/6ol?1f003oinjjonW]nGo
YkOU00CoYkOU1_n@_?@6oiO1m003ojW5k_nOb?CoWlSd00CoWlSd1_nYaNh00onX_n[oY/cdojK<m004
ojK<m0KoYlSa0_nTdOL6ojWCmP03oj[8kon/`^[o[<;Z00Go[<;Z1_nX]>86oiNQf`GoRiCG1OmmRM@6
oh>BfP;oWK?W1onabnd00oo4hNgo`^?_ol;Sk`03ol;Sk`?o^][`1_n`bnh2ojS1k0_oYl3[00?oZ<7/
ojS1jonX`N/01OnX`N/7ojNoj`SoYl3[0onX`>/00ol0003oZ<7[ojS1j`07ojO0j`OoYko[1onW`>/8
ooooo`03o`000?oooooooooo00Kooooo00001OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`09ooooo`03o`000?oooooooooo03?ooooo1_nW_n/5ojO0j`WoZ<3[0onW
`>/4ojK0k0OoYko[1_nW`>/7oj:nk@GoR;7`1?mdYO07oh^]k@03okC4i_o0b>3o`<SP00Co`<SP0oo6
b=/3om;<e0Ood<OA00?oaLKKol?1f?o3`MP01?o3`MP00oo2^m?oYkOUojNgi@06ojNgi@?oT;cd0onF
^_07oi?4n0KoWlSd0onYaNh4oik;m`KoY/cd0_nWb?46ojCAm`;oZM?f1OnZb>l7ojc2jP?oZ;CR0_nH
V=86oi2@d0CoQX_A00?oRiCGogf9e?mmRM@01?mmRM@3oh>BfP?oVjoV1onabnd3ol3Tl003ol;Skonj
f_3o^][`00Go^][`0on`bnh3ojS1k0WoYl3[1OnX`N`7ojS1j`OoYko[1_nW`>/00onX`>_oZ<7[ojS1
j`02ojS1j`03o`000?nX`N_oZ<7[00GoYl3[2?nW_n/6ojO0j`03ojS0jooooooooooo00Kooooo00?o
0000ooooooooool01_ooool00004oooooonHV9So8B4Qonk^kPCooooo00Go410@oooooooooooooooo
oa0@400:ooooo`03o`000?oooooooooo03?ooooo1_nW_n/00onW`>_oZ<3[ojS0j`0<ojS0j`KoY/3/
1onW_n/6ojO0j`GoX[k]0_nL_>l5oh:_lP?oL:Ca00CoM:G`oh^]kOn;[NgoRjg]1?nH]^`5ol38h0Go
a/SK00?od/cDom37dOo@am401Oo@am42olk2c`Go`l7H0oo2^m<6ojNgi@;o/KCK1_nF^_07oi?4n0?o
WlSd1?nFb?T6oik;m`?oY/cd1?nOcoP5ojCAm`;oYlO`1onZb>l3ojc2jP?oWikC1_nHV=86oi2@d0Co
QX_A1_n7TmP7oi^_iPCo/L_]1?o0i?02okoUlPKo^][`00?o[lc^ojS1k?nX`N`01OnX`N`7ojO0j`Oo
Z<7/0onX`N/;ojNoj`;oYl3[1OnX`>/4ojS1j`04o`000?nX`N_oZ<7[ojO0j`coYko[0_nW`>/5ojS0
j`Oooooo00?o0000ooooooooool01_ooool000;ooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003o
oooooooooooooooo000000_ooooo0_l0000dooooo`KoYko[3onX`>/6ojK0k0OoYko[1_nW`>/00onR
_^goW;c_oiblk`04oiblk`GoPZob1Om`Y?46oiRfk0?o`<SP1_o6b=/7om37d@Coc/;?0oo3`MP5ol:k
d`?oYkOU1Ona]=/6oiJjl0?oTlCh1?nE_o@7oiK8n@?oW/_g1?nLboP6oio?n003ojCAmonWao3oYlO`
00CoYlO`1OnZb>l00onSX]CoWikCoinNd`05oinNd`GoV9SB1_n@T=05ohJ;d@KoQi?H1onK[nH00ona
bngo`>C`ol3Tl002ol3Tl0Go_nGb0_njf_05ojo<kPOoZ<7/1onW`>/7ojS1k0coYko[00?oYl3[ojS0
jonX`>/01_nX`>/3ojS1j`03o`000?nW`>_oYl3[00[oYko[0onW`>/8ojS0j`Oooooo00?o0000oooo
ooooool01Oooool000?ooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo0000
00gooooo00?o0000ooooooooool0<_ooool6ojNoj`ooZ<3[0onV`>`3ojJok0OoYko[1onW`>/6oibl
k`GoPZob1Om`Y?46oiRfk003ol38h?o6b=_oa/SK00Coa/SK0_o9a]P5om37d@Koc/;?00?o`l7Hol:k
doo2^m<01Oo2^m<00onW]nGo/KCKok6df`05ok6df`?oU[[`0onS[n07oiFom0?oU/Si1OnJ`?86oic;
n0?oWloh1?nT_nd6ojO7l003oj[8konSX]CoXj;D00?oXj;D1_nOW]<6oiRHdPKoT93@1On6Rm46ohNC
f0GoVjoV1?n^cO000oo0i?3o_nGbokoUlP03okoUlP;o]m[b1on_c>h3ojS1k0_oYl3[1onX`N`8ojNo
j`GoYl3[1_nX`>/00onX`N_oYl3[ojO0j`02ojO0j`03o`000?nW`>_oYl3[00OoYko[1_nW`>/7ojS0
j`Oooooo00?o0000ooooooooool01Oooool000Cooooo00Go0000oooooooooooooooooa0@4003oooo
o`03oa0@4?oooooooooo00cooooo00?o0000ooooooooool0<_ooool6ojNoj`ooZ<3[1_nV_n`5ojNo
j`WoYl3[1_nL_>l5oh:_lPGoL:Ca0onH]^`3oj:lk0Goa/SK1?o9a]P3om37d@Koc/;?00?oc;g<ol:k
doo2^m<01Oo2^m<00oo2]Lgo/KCKok6df`05ok6df`03okZ`d?nS[n3oXjoP00GoXjoP1OnE_o@2oj:^
g`SoV/3b0onLboP3ojBch`OoY;o]0onWao02ojJSd`OoXj;D1_nOW]<5oiRHdPKoT93@1On6Rm47ohNC
f003oi^_i_n^cO3o[/g`00Co[/g`0_nlj?<3okoUlPGo]m[b1On_c>h2ojS1j`coYl3[2OnX`N`6ojNo
j`OoYl3[0_nX`>/5ojS1j`CoYl3[00?o0000ojO0jonW`>/01onW_n/6ojO0j`OoZ<3[1_ooool00ol0
003oooooooooo`05ooooo`0000Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03oooool00ol0003oooooooooo`0booooo`OoYko[3_nX`>/6ojJok003ojNojonW`>_o
Yl3[00_oYl3[0onL_>l3oiRkl0GoO:kd1Om^Yo<6oj:lk0?oa/SK1_o9a]P00oo@am7oc/;?olk2c`04
olk2c`?oc;g<1Oo2^m<3ol:ec@Go/KCK0onj/=07oj>_h003oiFom?nR[]ooXZkO00CoXZkO1_nJ`?80
0onVYmOoY;?SojBch`05ojBch`GoY;o]00?oZ:;AojJSdonVXm<01?nVXm<6oj>Re0KoWikC1_nHV=86
oi2@d0GoQX_A0on7TmP4oijci`Co[/g`1Onlj?<00onoiO;o]m[bokOJlP05okOJlP03ojo<k_nX`N_o
Z<7[00CoZ<7[2?nW`>/;ojS1k0SoYko[1OnW`>/00onX`>_oZ<7[ojS1j`06ojS1j`?oYl3[00?oYko[
o`000?nW_n/02?nW_n/3ojO0j`[oZ<3[1Oooool00ol0003oooooooooo`05ooooo`0000GoV9RHoa0@
4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04?ooool2o`0003Cooooo1_nW
_n/>ojS0j`KoY[o/3_nW`>/6oiRkl0GoO:kd1Om^Yo<6oj:lk003olK8foo9a]SobLKH00CobLKH0_o8
aML5olk2c`Goc;g<0oo2^m<5ol:ec@?o/KCK1Onj/=05oj>_h003ok>[dOnR[]ooXZkO00KoXZkO0_nJ
`?85ojJWe`OoY;?S00?oY;o]ojRRdOnXX]400onXX]46ojJSd`KoXj;D1_nOW]<3oiRHdP;oTho<1_n?
T=46oi2Lf`OoW[?W00?o[/g`okcXlonlj?<01?nlj?<2ok[Tm0Ko]m[b00?o[LS^ojS1jonX`N/01_nX
`N/6ojO0j`WoZ<7/3?nW_n/00onW`>_oZ<3[ojS0j`03ojS0j`KoZ<7[00?oYl3[ojNojonW_n/00_nW
_n/00ol0003oYko[ojNoj`06ojNoj`03ojO0jonX`>_oZ<3[00[oZ<3[00?oYl3[ooooooooool00ooo
ool00ol0003oooooooooo`05ooooo`007oooool00ol0003oooooooooo`0booooo`KoYko[3_nX`>/6
ojJok0koYl3[1_nH^o05ogb^m0GoKZOc0onR_>`3ojO0k0GobLKH1?o8aML3olk2c`Ooc;g<00?o`[_C
ol:ecOo2]Ld01Oo2]Ld00ona]=_o^[3@okZ`d005okZ`d003oj>_h?ncZm7o/j_A00?o/j_A1_nR[]l0
0onaY/koYZOGojJWe`05ojJWe`KoY;?S00?oZj7=ojRRdOnXX]401OnXX]45ojJSd`GoXj;D00?oWiG9
oiZBb_nJT/X01?nJT/X6oi>?c0KoSi3A1_n@W=/5oijci`?o/=We0onlj?<5ok[Tm0;o]m[b1On]b>h6
ojS1j`03ojS0jonW`>_oYl3[00GoYl3[1OnX`N`2ojS1j`[oYko[0onW`>/7ojS0j`;oZ<7[1OnW`>/4
ojNoj`03o`000?nW_n_oYko[00;oYko[1OnW`>/8ojS0j`GoYl3[1?ooool00ol0003oooooooooo`05
ooooo`008?ooool00ol0003oooooooooo`0booooo`?oYko[0onW`>/>ojS0j`KoY[o/3_nW`>/3oiRk
l0?oU[[a1Omg[_D5offZmPKoYl3/0oo9a]P6olS5e`03olk2coo<_Lcoc;g<00Koc;g<1oo2]Ld00oo4
//Wo^[3@okZ`d005okZ`d003okb[bOncZm7o/j_A00Go/j_A0onR[]l4ok6VcPOoYZOG0_nT/n<5oj^Q
c@KoZ:;A1_nVXm<00onSX]CoWiG9oinEb@03oinEb@KoVY;:1OnCSl`6ohn@d@OoT9cK00?oW[?Wok3I
mOn`fOD01On`fOD00onlj??o^^Cdok[Tm003ok[Tm0;o/mKb1on]b>h2ojS1j`GoZ<3[1onW`>/00onX
`NcoZ<7[ojS1j`04ojS1j`KoYko[1onW`>/5ojS0j`;oZ<7[1onW`>/4ojNoj`03o`000?nW_n_oYl3[
00OoYl3[1OnX`>/8ojO0j`?ooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000oooooooo
ool0<_ooool6ojO0j`koZ<3[1onV_n`=ojO0j`KoU[[a1Omg[_D5offZmPKoYl3/00?obLKHolS5eoo8
aML01?o8aML2olG4f@Ooc;g<0_o;_<`5ol:ec@?oa;;91Onj/=03okb[b@Oo/j_A00?oXZkOok6Vc_na
Y/h01?naY/h5ojJWe`03ojjPbOn[XLgoZj7=00GoZj7=1onXX]43ojJSd`;oXiO81_nOULT6oiZBbPKo
Tho<1On?T=46oi2Lf`;oY<7^1_n`fOD3okS[mP03ok[Tm?nce_;o/mKb00Co/mKb1On]b>h2ojO0j`Oo
Z<3[0onW`>/3ojS1k0SoZ<7[1_nW_n/7ojO0j`03ojS0jonX`N_oZ<7[00CoZ<7[1OnW`>/5ojNoj`03
o`000?nW_n_oYko[00KoYl3[1onX`>/6ojO0j`03ojNojooooooooooo00;ooooo00?o0000oooooooo
ool01?ooool002;ooooo00?o0000ooooooooool0<_ooool6ojO0j`coZ<3[0onW`>/6ojJok0goYl3[
1_nF^_45ogN^m@GoKJ[f0onW`>`3ojO3k@Gob<GG1?o5a=T5olbmc0Cobkc<0oo2]Ld5olBbb@?o^[3@
1OnlZlT5ok>[d@03okNUb?naY/ko/JK>00Go/JK>0onVYmL4ojjPb@KoZj7=1_nXX]400onWVLOoXiO8
oj>Gb004oj>Gb0KoWiG91OnJT/X6oi>?c0KoSi3A0_n@W=/6ojC1kP;o/=We1OnhjoH2okCOmPOo/mKb
00?o[LS^ojO0jonW`>/01?nW`>/5ojS0j`;oYl3[1_nX`N`6ojS1j`SoYko[0onW`>/3ojS0j`SoZ<7[
00?oYl3[ojNojonW_n/01onW_n/00ol0003oYko[ojNoj`02ojO0j`_oZ<3[0_nW`>/5ojNoj`?ooooo
00?o0000ooooooooool01?ooool002?ooooo0_l0000cooooo`OoYl3[2?nX`>/6ojO0j`KoY[o/3OnW
`>/3oiJjl@?oUK_a1Ome/?L5ofV/m`KoYl?]0oo8aML6olG4f@?oc;g<1_o;_<`00oo2]Lgoa;;9olBb
b@05olBbb@03okZ`d?nlZlWo_:_900Co_:_90oncZm44okNUb0Oo/JK>00?oYZOGojjPbOn^X<T00on^
X<T7oj^Qc@;oZ:;A1OnWVLL5oj>Gb0KoWiG91_nJT/X6oi>?c0?oSi3A0onN/ND6ojC1kP?o/>Sh0onh
joH5okCOmP?o/mKb1?nZ`n`7ojO0j`03ojS0jonW`>_oYl3[00CoYl3[1_nX`N`2ojS1j`[oYko[0_nW
`>/6ojS0j`KoZ<7[00?oYl3[ojNojonW_n/02?nW_n/00onW`>_o0000ojO0j`0;ojS0j`;oYl3[2?nW
_n/2ooooo`03o`000?oooooooooo00Cooooo000Uooooo`03o`000?oooooooooo03;ooooo1_nW`>/7
ojS0j`OoYl3[1_nV_n`=ojO0j`KoUK_a1Ome/?L5ofV/m`KoYl?]00?ob<GGolG4fOo5a=T01_o5a=T0
0oo<_Lcobkc<ol^lc004ol^lc003olVodOo4//Woa;;900Koa;;92?nlZlT00oncZm7o]jG8okNUb004
okNUb0Go/JK>00?o/j;6ojjPbOn^X<T01On^X<T5oj^Qc@03ojbKa_nWVLOoYiW700GoYiW71_nSUlP5
oinEb@KoVY;:0onCSl`3oiVSg0OoW[7U0onT`Nh6ok3Xn003okS[m_ndgoKo]=of00?o]=of0_n^c>l7
oj[3k0koYl3[0onX`N`2ojS0j`WoYko[1_nW`>/6ojS0j`;oZ<7[1OnW`>/7ojNoj`CoYl3[00?o0000
ojO0jonX`>/01_nX`>/6ojO0j`KoYko[00CoYl3[oooooooooooo00001_ooool002Kooooo00?o0000
ooooooooool0<_ooool6ojO0j`OoZ<3[1onW`>/6ojJok0goYl3[1_nE^o45ogF`m`GoJJcg0onW`nd3
oj74lPOoaLCI0_noaMl5ol^lc0?obKoA1_o4//T2olFeb`Ko_:_900?o_jk8okNUb?ngYLP01OngYLP3
ok6VcPCo/j;61_n^X<T3oj^Qc@Co[9_61_nWVLL6oj>Gb0KoWiG90onJT/X2oi^Me@OoVJ?L1onN/ND0
0onT`Nko/>Shok3Xn004ok3Xn0?o/nOg00?o]=ofojk<kon^c>l01?n^c>l5oj[3k0koYl3[00?oZ<7/
ojS0jonX`>/01?nX`>/7ojNoj`SoYl3[0onX`>/2ojS1j`SoYl3[1onW_n/3ojO0j`03o`000?nW`>_o
Yl3[00OoZ<3[1_nW`>/2ojNoj`GoYl3[00?oooooo`000?ooool01Oooool002Oooooo00?o0000oooo
ooooool0<_ooool6ojO0j`OoZ<3[1onW`>/6ojJok0goYl3[0onE^o44oiRkl0GoMk;g1?mS[?T6oj74
lPCoaLCI1OnoaMl3ol^lc0GobKoA1?o4//T4olFeb`Co_:_90ono[/P7okNUb003ok6Vc_ncX/Ko/j;6
00Co/j;61_n^X<T00on[XLgo[9_6ojbKaP03ojbKaPOoYiW71_nSUlP3oinEb@;oX9gA1_nKWMD6oiVS
g0KoW[7U0onWfoT2ok3Xn0Go/nOg0_n`eO<7ojk<k`03oj[3k?nW`>_oYl3[00coYl3[1OnX`N`6ojS0
j`OoYko[1_nW`>/7ojS1j`KoYl3[2OnW_n/3ojO0j`03o`000?nX`>_oZ<3[00OoZ<3[0onW`>/4ojNo
j`KoYl3[00?o0000ooooooooool01?ooool002Sooooo0_l0000cooooo`KoYl3[1onX`>/7ojO0j`Ko
Y[o/3_nW`>/6oiRkl0GoMk;g1?mS[?T6oj74lP03olG4fOnoaMoo_lGO00Ko_lGO00?obkc<olVodOo9
_m401?o9_m43olBbb@GoaKG;0onlZlT4okn^b0Ko]jG800?o^j_9ok>Ra_ncX/H01OncX/H5ojjPb@03
ok:Rb?n/VlKo[9_600Go[9_61_nWVLL3oj>Gb0?oYIo@1_nPWM46oi^Me@KoVJ?L0_nN/ND5ojOKn@Co
[>_i00?o/nOgok3Elon`eO<01?n`eO<5ojk<k`03ojS0jonW`>_oYl3[00WoYl3[2_nX`N`3ojS0j`[o
Yko[0_nW`>/;ojS1j`;oYl3[2onW_n/00onW`>_oZ<3[ojS0j`02ojS0j`03o`000?nX`>_oZ<3[00Go
Z<3[00?oYl3[ojNojonW_n/01_nW_n/3ojO0j`;ooooo00?o0000ooooooooool01?ooool002[ooooo
00?o0000ooooooooool0<Oooool6ojO0j`OoZ<3[1onW`>/6ojJok0koYl3[0onH^o03oibmk`GoO;Kh
0omO[?T01?mS[?WoXLCboj74l_nQa?83oi?4n0Oo_lGO00?o]<SYolVodOo9_m401_o9_m400oo4//Wo
aKG;olFeb`05olFeb`03okb[bOno[/So_jk800Co_jk81?ngYLP3ok^[b@Oo/j;600?o[Z39ok:Rb?nb
X/P00onbX/P6ojbKaPGoYiW700?oZZCAojFOd?nUWm001OnUWm06oj2Md@KoVigE0onIXm`5ojC=m@03
ojOKnOn/joWo[>_i00Co[>_i0_n]g?P7ok3El`03ojk<konX`>_oZ<3[00?oZ<3[1onW`>/<ojS1k0co
Yko[0_nW`>/;ojS1j`coYko[1OnW`>/4ojS0j`04o`000?nX`>_oZ<3[ojS0j`GoYl3[1_nW_n/7oooo
o`03o`000?oooooooooo00?ooooo000[ooooo`03o`000?oooooooooo037ooooo1_nW`>/7ojS0j`Oo
Yl3[1_nV_n`>ojO0j`KoW;g_1Oml]_P5oen/n@GoTlCh1?noaMl4okC8j@KobKoA00?o`L?LolFeboo5
]L/01Oo5]L/00oo3_mKo_jk8okn^b005okn^b0?o]jG81?nkZlT6ok>RaP03okV^c_nbX/So/Z;800Co
/Z;81on/VlH00onWVLOoZZCAojZTd@03ojZTd@KoYIo@1_nPWM45oi^Me@?oY<C`1OnTcOD3oj?ZnP;o
[>_i1_n]g?P3ok3El`?oZL;/1onX`>/7ojO0j`SoZ<7/3?nW_n/6ojO0j`OoZ<7[3OnW_n/8ojO0j`?o
Z<3[00?o0000ojS0jonW`>/01onW`>/2ojNoj`[ooooo00?o0000ooooooooool00oooool002cooooo
00?o0000ooooooooool0<Oooool6ojO0j`OoZ<3[1onW`>/6ojJok0koYl3[1_nL_Nl5ogbfn0GoGjci
1OnCa?P00onoaMoo]<SYokC8j@04okC8j@CobKoA1?o1`m`5olFeb`?o`koF1ono[/P00ongYLSo^j_9
ok^[b@04ok^[b@Co/j;60oni[/h6ok:Rb0Go[9_600?o/:gEojZTdOnZY=401?nZY=46ojFOd0OoX9gA
00?oVigEojC4l?nTa?001OnTa?000onTcOGoXn[joj?ZnP03oj?ZnP?oZMoj1On]g?P2oj[6kPKoZL;/
1OnX`>/9ojO0j`?oZ<7/0onX`N/>ojNoj`KoYl3[1onX`N/=ojNoj`KoYl3[1OnX`>/00ol0003oZ<3[
ojO0j`05ojO0j`gooooo00?o0000ooooooooool00oooool002gooooo0_l0000booooo`KoYl3[1onX
`>/7ojO0j`KoY[o/3_nW`>/3oibmk`?oX[k]1_n4]oH5of:_nPGoNl3m1_ndb>T00oo9_m7o`L?Lol73
g005ol73g0?oaKG;1Oo3_mH5okn^b003ol6leOnkZlWo^j_900Go^j_90oncX/H4okV^cPKo/Z;80on/
VlH4ok2]e@KoZZCA1_nUWm03oj2Md@CoYL3/1_nTa?03oicWo003oj?Zn_nYgo[oZMoj00GoZMoj00?o
[Mchoj[6k_nZa^h01?nZa^h6ojW2k003ojS0jonW`>_oYl3[00WoYl3[0_nX`N`6ojS1j`koYko[0onW
`>/3ojS1k0OoZ<7[3OnW_n/2ojO0j`WoZ<3[00Co0000ojS0jonW`>_oYl3[4?ooool00ol0003ooooo
ooooo`03ooooo`00;oooool00ol0003oooooooooo`0`ooooo`OoYl3[1_nX`>/7ojO0j`KoY[o/3_nW
`>/6oj:nk@KoQ;Of1OmR[oX5og_0o@?o]<SY0onRc_L8ol73g003olFeboo3_mKo`koF00Co`koF0ono
[/P4ol6le@Oo^j_900?o/j;6okV^c_ni[/h01?ni[/h6ok:Rb003ojbKa_n`[MGo/:gE00Co/:gE1OnZ
Y=45ojFOd0;oYl3/1onU`>`2ojC4l0GoW>Ol0onUh_/5ojWOnP03oj_;l?nZa^koZ/K^00KoZ/K^0onY
`^`;ojO0j`KoZ<7/1_nX`N/<ojNoj`03ojO0jonX`NcoZ<7/00GoZ<7/1OnX`N/<ojNoj`;oYl3[2onX
`>/00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00?ooooo000`ooooo`03o`000?oooooo
oooo037ooooo1_nW`>/7ojS0j`KoYl3[1onV_n`=ojO0j`KoX[k]0on4]oH4oi2jl`GoK[Gk1OmP]_`5
oj;>m`Ko`L?L00?o/Lg^ol>oe_o3_mH01_o3_mH00ono[/So`KcEol6le@04ol6le@Go^j_900?o^kgK
okV^c_ni[/h01Oni[/h5ok:Rb003okBigOn`[MGo/:gE00Go/:gE1_nZY=400onUWm3oYl3/ojO0k004
ojO0k0GoYL3/1?nGi?`00onLiocoYN;kojGRn`05ojGRn`03ojWOn_n[bo3oZl_`00?oZl_`1_nZa^h;
ojO0j`_oZ<7/0onX`N/;ojNoj`GoYl3[1onX`N`00onX`N_oYko[ojNoj`09ojNoj`OoYl3[1_nX`>/5
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00oooool0037ooooo00?o0000oooo
ooooool0<Oooool7ojO0j`KoZ<3[1?nW`>/3ojS0j`KoY[o/0onW`>/4ojO0k0KoYl3[0onR_^d3ojFo
k0OoT;[c1Om^]O/5of2fo0GoX/kg0_o1`m`5ok7=kPKo`koF00?o]<_[ol6leOo1_=D01Oo1_=D3ok^[
b@Co^kgK1oni[/h00onbX/So];WMokBig@03okBig@Oo/:gE0onZY=43ojW5kPOoYl3/00?oYL3/oiOT
o?nGi?`01?nGi?`2oikRo@KoYN;k0_nYc_<6oj_;l0;oZ/K^2_nW`>/2ojO1k0coZ<7/2onW_n/:ojO0
j`?oZ<7/1?nX`>/8ojNoj`_oYl3[0_nX`>/9ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool00oooool003;ooooo0_l0000booooo`OoYl3[1_nX`>/00onW`>_oZ<3[ojS0j`04ojS0j`Oo
Y[o/1_nW`>`7ojO0j`GoYKo/1On@^_<2oibmk`KoP;[i1OmO]?`5og[8o`Ko/Lg^0_o3_mH5okC;j`Oo
`KcE00?o^j_9ok^mfonk_M/01?nk_M/5okV^cP03ok75jOnd^Mgo];WM00Go];WM1On`[MD2ojS>m0Ko
ZLG^1OnW`>`4oi7Ro@03oiOTo?nNh_goW^;m00CoW^;m0_nUh_/6ojW>l`?oZl_`2onW`>/6ojO1k0So
Z<7/3?nW_n/;ojO0j`;oZ<7/1onX`>/6ojNoj`[oYl3[3_ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo00;ooooo000dooooo`03o`000?oooooooooo033ooooo1onW`>/=ojS0j`OoY[o/
1_nW`>`7ojO0j`GoYKo/00?oT;[coibmkonL_Nl01?nL_Nl6oh2jn@GoGkCl1Omjb?l3ok7=kP?oSM;n
1_ndbn/6ol6le@03ok7=k_nk_M_o^kgK00Ko^kgK00?o^Jk>ok75jOnaaNT00onaaNT7okBig@03ok2]
eOnXc_CoZ<kd00CoZ<kd1_nYaNh00onW`>coTN;moi7Ro@04oi7Ro@?oV=on0onNh_d4ojO?m@GoZLkc
0_nX`>/=ojO0j`OoYl7/0onX`N`4ojS0j`goYko[1onW`>/6ojS1k0GoZ<3[2?nW_n/5ojO0ja;ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`00=Oooool00ol0003ooooooooo
o`0`ooooo`OoYl3[3OnX`>/7ojJok0?oYl3/0onV`>`7ojO0j`;oYKo/1?nW`>/6oibmk`?oP;[i1?nA
^o<5og>ko0GoGK[m1On=d_h6okC;j`;o`KcE1OnacNh6ok^mf`03ojKFn?naaNWo/LGY00Go/LGY1Ond
^Md2oj7In`OoZ<kd0onYaNh4oh[Qo@;oTN;m1OnHgoh3ojG?mPKoYloe00?oZLkcojS0jonX`>/01?nX
`>/=ojO0j`GoYl7/00?oZ<7/ojS0jonX`>/01_nX`>/=ojNoj`?oYl3[2_nX`N`00onX`>_oYko[ojNo
j`0:ojNoj`03ojO0jooooooooooo01Cooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`02ooooo`00=_ooool00ol0003oooooooooo`0`ooooo`OoYl3[3OnX`>/5ojJok0;oY[o[1_nV`>`=
ojO0j`?oW;g_0onU_n`7oi6kl`GoLk_l1OmM^_d5ohgBoP?o]<_[1?n?e_l6ok7=kP;o^kgK1OnVe_P7
ok75j@03okBigOnQfO_oXMWk00CoXMWk0onXc_@5oh7Mo0?oR^7m1OnCg?h00onHgokoYLofojG?mP05
ojG?mP?oYloe0_nX`N`8ojS0j`goYl3[00?oYl7/ojS1k?nX`N`00onX`N`6ojS0j`goYko[00?oYl3[
ojS1k?nX`N`02_nX`N`;ojNoja_ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02
ooooo`00=oooool2o`00037ooooo1onW`>/=ojS0j`03ojJok?nV_n_oY[o[00CoY[o[1_nV`>`=ojO0
j`KoYKo/1OnA^o<2oj2nkPKoR[cg1_m]_Od5of71o@GoSmKo0onacNh4oh;Go`KoY]Kh0onaaNT5ohcL
oP?oXMWk1Omjf?d3oh7Mo0GoT=So0onCg?h4oj?<m@GoYLof00?oYl7/ojS1k?nX`N`01?nX`N`6ojS0
j`_oYl3[2_nX`N`2ojS0j`goYko[1OnW`>/8ojS1k0[oYko[8?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00;ooooo000iooooo`03o`000?oooooooooo02oooooo1onW`>/=ojS0j`Oo
Y[o[1onV`>`<ojO0j`KoYKo/00?oTK_coj2nk_nP_^h01?nP_^h6ohZlm`?oKKgm1?n9_oP5og31oPKo
I<Gm1On2eol3ojKFn0GoL=;m0on<g?h5ogSBoP?oN]Sm1OnAe?h3oi3Ho`?oX/Sd1onSc?D00onUcoKo
Yl7/ojO1k003ojO1k0KoZ<7/0_nX`>/:ojO0j`;oYl7/2_nX`N`=ojNoj`[oYl3[0onX`N`3ojS0j`So
Yko[8oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo000jooooo`03o`00
0?oooooooooo02oooooo1onW`>/=ojS0j`GoY[o[0_nW_n/7ojK0k0?oYl3[0onW`>`6ojO0j`?oYKo/
1?nW`>/6oj2nkP?oR[cg1?nM_Nl6ohVon0GoL<7n0omTaOd5og_6oPGoJlWn0om`d_d5ogk=o`?oN=;n
1?nDcO/5oi7DoP03oj73lOnRb?CoX/Sd00GoX/Sd0onSc?D3ojO0k0OoYl7/0onX`N`;ojO0j`KoYl7/
1OnX`N`=ojNoj`goYl3[00?oZ<7/ojS0jonX`>/01OnX`>/3ojNojbSooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`02ooooo`00>oooool00ol0003oooooooooo`0`ooooo`KoYl3[3OnX
`>/00onV_n_oYko[ojNoj`04ojNoj`GoY/3/0_nV_n`6ojO0k0CoYl3[0_nW`>`7ojO0j`?oX;k^0onW
`>`7oifmk`?oRKoh1?nM_^l6ohk1n0?oNlKn1?nF`OD6oh_9o0?oO/go1?nIaOH6oiC=n`03oi7Do_nQ
`o7oXL?a00?oXL?a1OnRb?@2ojO0j`KoYl3/1OnW`N`<ojO0j`[oYl7/00?oZ<7/ojNojonW_n/02onW
_n/=ojO0j`GoZ<7/1OnX`>/]ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00Ooo
ool003cooooo00?o0000ooooooooool0<?ooool3ojO0j`?oYl3/3_nX`>/6ojNoj`03ojK0k?nV_nco
Y[o/00CoY[o/1_nW`>`00onW`>_oYl3/ojO0k003ojO0k0OoYl3[1_nW`>`5oifmk`;oY[o/1onM_^l3
ohk1n0?oXKk^1onF`OD3oh_9o0?oWl3`1onIaOH3oiC=n`?oY<7^1_nQ`o400onRb?CoYl3[ojO0j`04
ojO0j`KoYl3/00?oYl7/ojO0jonW`>/02OnW`>/<ojO1k0;oZ;o[3OnW_n/:ojO0j`[oZ<7/00?oZ<3[
ooooooooool0;oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo007ooooo000moooo
o`;o0000<Oooool6ojO0k0koZ<3[0onW_n/3ojRoj`OoY[o/0onW`>`3ojK0k0KoYl3/1onW`>/6ojO0
k003oifmkonV_ncoY[o/00CoY[o/1OnM_^l2ojO0j`KoXKk^1OnF`OD00onU_ncoWl3`oio0l005oio0
l0?oVLGf0onV_n`7ojC1kP?oXL?a2_nW`>/3ojO0k0_oYl3[2onW`N`00onW`>_oZ;o[ojRoj`04ojRo
j`goYko[1OnW`>/2ojO1k0[oZ<7/=?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
007ooooo000oooooo`03o`000?oooooooooo02oooooo1_nW`>`>ojS0j`KoZ;o[1OnV_n`2ojNoj`Ko
Y/3/0onW`>`3ojO1k0OoYl3[0onW`>`4ojO0j`KoY[o/00?oWKk_ojO0jonW`>/01?nW`>/6oj6nkP03
oiK1mOnU_ncoYKo/00?oYKo/1OnO`?02ojO0j`KoY[o/1OnT`Nh2ojS0jaOoYl3[2onW`N`5ojO0j`Ko
Z;o[3OnW_n/00onW`>_oYl7/ojO1k004ojO1k0GoZ<7/>Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo007ooooo0010ooooo`03o`000?oooooooooo02oooooo1onW`>`=ojS0j`KoZ;o[
00?oY[o/ojNojonW_n/01?nW_n/4ojK0k0;oY[o/1_nW`N`5ojO0j`;oYl7/1onW`>/3ojJok0[oYl3[
0onQ_^h3ojO0j`KoYKo/00?oWl3`ojO0jonW`>/01?nW`>/6ojJok003ojC1k_nX`>_oZ<3[00CoZ<3[
4_nW`>/;ojO1k0[oYl3[0onX_n/=ojNoj`?oYl3/1onW`N`00onX`Ncoooooooooo`0kooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool00Oooool0047ooooo00?o0000ooooooooool0;ooo
ool7ojO0k0?oZ<3[0onW`>/7ojS0j`?oZ;o[1?nX`>/6ojNoj`03ojK0k?nV_ncoY[o/00?oY[o/1_nW
`N`00onW`>_oYl7/ojO1k004ojO1k0GoYl3[0_nW`N`CojO0j`?oYKo/2_nW`>/3ojJok0CoYl3[1_nX
`>/>ojO0j`[oYl7/3OnW`>/=ojNoj`03ojO0jonW`>coYl3/00GoYl3/0onW`Na1ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool00Oooool004;ooooo0_l0000`ooooo`OoYl3/1_nW`>/>
ojS0j`?oYko[1?nX_n/5ojJok0?oYl7/1?nV`>`6ojO1k003ojO0jonW`NcoYl7/00CoYl7/4OnW`>/2
ojO0k1CoYl3[0onX`>/2ojO1k0[oYl3[2onW`N`=ojO0j`goYko[1OnW`>/5ojO0k4Kooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`01ooooo`00A?ooool00ol0003oooooooooo`0^oooo
o`OoYl3/1_nW`>/>ojS0j`OoZ;o[0_nV_n`3ojNoj`OoY/3/0onW`N`3ojK0k0OoYl7/0onW`>/4ojO1
k0KoYl3[1_nW`>`BojO0j`OoYl7/1OnW`>/<ojO1k0goYl3[3?nW_n/:ojO0j`03ojO0k?oooooooooo
04Sooooo00?o0000ooooooooool01oooool1o`00007ooooo0Oooool004Gooooo00?o0000oooooooo
ool0;oooool6ojO0k0?oYl3[1?nW`>`=ojS0j`GoZ;o[00?oZ<3[ojNojonW_n/01?nW_n/5ojK0k0;o
Yko[1_nV`>`5ojO1k0;oY/3/1onW`N`2ojO0j`?oYl7/1onW`>`3ojO0j`CoYl7/1onW`>/;ojO1k003
ojO0jonW`NcoYl7/00WoYl7/0_nW_n/;ojO0j`_oYko[3OnW`>]>ooooo`03o`000?oooooooooo00Ko
oooo0Ol00001ooooo`7ooooo0016ooooo`03o`000?oooooooooo033ooooo0_nW`>`3ojNoj`OoYl3/
0onX`>/4ojO0j`KoZ<3[00?oZ;o[ojS0jonX`>/00onX`>/6ojNoj`03ojK0k?nW_n_oYko[00CoYko[
1_nV`>`00onW`NcoY/3/ojK0k004ojK0k0GoYl7/00?oY/3/ojO1k?nW`N`01?nW`N`5ojO0k0WoYl7/
0onW`>/GojO1k0KoYko[1onW`>/:ojNoj`goYl3[D_ooool00ol0003oooooooooo`06ooooo`7o0000
0Oooool1ooooo`00Aoooool2o`00037ooooo1OnW_n/7ojO0k0OoYl3[3?nX`>/3ojNoj`CoZ;o[1_nW
_n/3ojK0k0CoYko[1_nV`>`00onW`NcoY/3/ojK0k003ojK0k0KoYl7/00?oYl3/ojO1k?nW`N`02OnW
`N`00onW`>coYl7/ojO1k009ojO1k0;oYl3/2_nW`N`:ojNoj`?oYl3[2_nW_n/=ojO0jeKooooo00?o
0000ooooooooool01Oooool1o`00007ooooo0Oooool004Wooooo00?o0000ooooooooool0;oooool5
ojNoj`OoYl3/1OnW`>/2ojO0k0coZ<3[1onX_n/3ojNoj`?oZ;oZ1onW_n/3ojK0k0?oYko[1_nV`>`3
ojO1k0CoY/3/1onW`N`5ojO0k0OoYl7/1_nW`>`5ojO1k0;oYkoZ2onW_n/00onX_n_oYko[ojNoj`08
ojNoj`goYl3[F_ooool00ol0003oooooooooo`04ooooo`7o00000Oooool1ooooo`00B_ooool00ol0
003oooooooooo`0_ooooo`KoYko[1_nW`>`00onW`>_oYl3/ojO0k004ojO0k0coZ<3[1OnX_n/2ojS0
j`KoZ;oZ1OnW_n/00onX_n[oYko[ojNoj`05ojNoj`?oY/3/0onW_n/7ojK0k0?oYl7/0onW_n/6ojO0
k0?oYl7/1?nW_n/6ojO0k003ojO1k?nW_n[oYkoZ00CoYkoZ1onW_n/5ojRoj`GoYko[3OnW`>]Ooooo
o`03o`000?oooooooooo00?ooooo0Ol00001ooooo`7ooooo001;ooooo`03o`000?oooooooooo02oo
oooo1_nW_n/3ojO0k0CoYko[1_nW`>`3ojS0j`CoYl3/1OnX`>/00onX_n_oZ<3[ojS0j`04ojS0j`Ko
Z;oZ00?oYko[ojRoj_nX_nX00onX_nX5ojNoj`;oZ;oZ1_nW_n/5ojK0k0;oZ;oZ1_nW_n/3ojO0k0?o
YkoZ1onW_n/3ojO0k0CoZ;oZ1_nW_nX3ojNoj`WoZ;o[00?oYko[ojO0jonW`>/02onW`>]Rooooo`03
o`000?oooooooooo00?ooooo0Ol00001ooooo`7ooooo001<ooooo`;o0000<?ooool4ojNoj`;oZ<3[
1onW_n/=ojO0k0;oZ<3[0onW`>/7ojS0j`?oZ;oZ1?nX`>/5ojRojP03ojNojonX_n[oZ;oZ00CoZ;oZ
1_nW_n/00onV`>coZ;oZojRojP04ojRojPCoYko[0_nX_nX6ojNojPGoYko[0_nX_n/7ojRojP?oYkoZ
3?nX_n/=ojO0jfKooooo00?o0000ooooooooool00oooool1o`00007ooooo001>ooooo`03o`000?oo
oooooooo02kooooo00?oYko[ojS0jonX`>/00onX`>/7ojNoj`coYl3/1_nW`>/5ojS0j`;oYl3[1onX
`>/2ojRojPCoZ<3[1_nX_nX3ojNoj`CoZ;o[1_nX_nX00onW_n_oZ;oZojRojP03ojRojPKoYkoZ00?o
Yko[ojRojonX_n/01?nX_n/5ojRojP03ojS0jonX_n_oZ;o[00WoZ;o[3?nW`>]/ooooo`03o`000?oo
oooooooo00;ooooo0Ol00001ooooo`00Coooool00ol0003oooooooooo`0_ooooo`GoZ<3[1onW_n/<
ojO0k0KoYl3[00?oZ<3[ojO0jonW`>/01?nW`>/5ojS0j`03ojO0jonX`>_oZ<3[00GoZ<3[0onX_nX3
ojS0j`OoZ;o[0onX_nX3ojS0j`KoZ;oZ0onW_nX4ojS0j`KoZ;o[00?oZ;oZojS0jonX`>/00onX`>/7
ojRoj`_oYl3[LOooool01Ol0003ooooooooooooooooo0000007ooooo001@ooooo`03o`000?oooooo
oooo02oooooo1OnX`>/7ojNoj`?oYl3/1?nW_n/5ojO0k0?oYl3[1?nW`>`6ojO0j`03ojS0jonW`>_o
Yl3[00?oYl3[1OnX`>/2ojO0j`KoZ<3[1OnX_n/8ojS0j`?oZ;oZ2_nX`>/3ojRoj`?oYl3[1_nX`>/3
ojRoj`CoYl3/1onW`>]dooooo`05o`000?ooooooooooooooool000000Oooool0057ooooo0_l0000`
ooooo`GoZ<3[1OnW_n/2ojS0j`OoYko[0_nW`>`4ojNoj`KoYl3/0onW`>/4ojO0k0GoYl3[00?oZ<3[
ojO0jonW`>/01?nW`>/6ojS0j`03ojRojonX`>_oZ<3[00SoZ<3[0_nW`>/;ojS0j`SoYl3[0onX`>/3
ojO1k0OoYl3/0onW`>]hooooo`04o`000?ooooooooooo`00007ooooo001Cooooo`03o`000?oooooo
oooo02kooooo1OnX`>/00onW_n_oZ<3[ojS0j`04ojS0j`GoYko[00?oZ;o[ojNojonW_n/01OnW_n/3
ojO0k0?oYl3[1onW`>`2ojO0j`CoYl3/1_nW`>/3ojS0j`?oYl3/1onX`>/6ojO0j`OoZ<3[2_nW`>/8
ojO1k0GoYl3/OOooool00ol0003oooooo`000001ooooo`00E?ooool00ol0003oooooooooo`0^oooo
o`coZ<3[00?oYko[ojRojonX_n/00onX_n/7ojNoj`KoYl3[1OnW`>`00onW`>_oYl3/ojO0k005ojO0
k0?oYl3[2OnW`>`3ojS0j`CoYl7/1_nW`>/3ojS0j`?oYl7/1onW`>/<ojO1k003ojO0k?oooooooooo
07kooooo00?o0000ooooool000000Oooool005Gooooo00?o0000ooooooooool0;_ooool=ojS0j`Go
Z;o[1onW_n/6ojO0j`03ojO0k?nW`>_oYl3[00?oYl3[1OnW`>`2ojO0j`coYl3/1onW`N`3ojO0j`;o
Yl3/1onW`N`3ojO0j`CoYl3/2OnW`Nb4ooooo`7o00000Oooool1o`000000E_ooool2o`0002oooooo
0onX`>/3ojO0j`OoZ<3[0_nX_n/4ojS0j`KoYko[0onW`>/4ojNoj`GoYl3[00?oYl3/ojO0jonW`>/0
1?nW`>/<ojO0k0GoYl7/0_nW`>/5ojO0k0GoYl7/0_nW`>/7ojO0k0?oYl7/R_ooool2o`000000F?oo
ool00ol0003oooooooooo`0]ooooo`KoYl3[3OnX`>/3ojNoj`?oZ<3[1onW_n/2ojO0j`CoYko[1_nW
`>/3ojO0k0?oYko[1_nW`>`00onW`NcoYl3[ojO0j`04ojO0j`GoYl3/00?oYl7/ojO0jonW`>/01?nW
`>/5ojO0k8gooooo0ol0000005Wooooo00?o0000ooooooooool0;Oooool6ojO0ja?oZ<3[1OnW_n/0
0onX`>_oYko[ojNoj`05ojNoj`?oYl3[2OnW_n/3ojO0k0CoYko[1_nW`>/2ojO0k0CoYko[1_nW`>/0
0onW`>coooooooooo`2:ooooo`Co00000oooool005[ooooo00?o0000ooooooooool0;Oooool7ojO0
ja;oZ<3[00?oYko[ojS0jonX`>/00onX`>/5ojNoj`;oZ<3[2_nW_n/2ojRoj`OoYko[0onW`>/3ojRo
j`KoYko[0onW`>^<ooooo`?o00001oooool005_ooooo00?o0000ooooooooool0;_ooool6ojO0j`?o
Z<3[0onW`>/BojS0j`03ojNojonX`>_oZ<3[00CoZ<3[1onW_n/5ojRoj`GoYko[2?nX_n/3ojNojhgo
oooo1?l0000:ooooo`00G?ooool2o`0002oooooo3?nW`>/3ojS0j`CoYl3[4_nX`>/3ojNoj`?oZ<3[
1_nX_n/00onW_n_oZ;o[ojRoj`08ojRojhgooooo1?l0000>ooooo`00G_ooool00ol0003ooooooooo
o`0]ooooo`[oYl3[0_nW`>`7ojO0j`?oZ<3[0_nW`>/CojS0j`?oZ;o[1?nX`>/6ojRojhcooooo1?l0
000Booooo`00Goooool00ol0003oooooooooo`0]ooooo`OoYl3[1OnW`>`5ojO0j`;oYl3/1OnW`>/5
ojS0j`;oYl3[2OnX`>/3ojO0j`OoZ<3[0_nX_n^;ooooo`Co00005_ooool0063ooooo00?o0000oooo
ooooool0;Oooool7ojO0j`GoYl3/00?oYl3[ojO0k?nW`>`01?nW`>`5ojO0j`03ojS0jonW`>_oYl3[
00CoYl3[1?nX`>/2ojO0k0KoYl3[1OnX`>^;ooooo`?o00006_ooool0067ooooo0_l0000_ooooo`Ko
Yl3[0_nW`>`4ojO0j`KoYl3/0_nW`>/4ojO0k0KoYl3[00?oZ<3[ojO0k?nW`>`00onW`>`6ojO0j`03
ojS0jooooooooooo08Sooooo1?l0000Mooooo`00Hoooool00ol0003oooooooooo`0]ooooo`?oYl3[
0_nX`>/7ojO0j`?oYl3/0onW`>/6ojO0k0?oYl3[2OnW`>`3ojO0jhWooooo1?l0000Qooooo`00I?oo
ool00ol0003oooooooooo`0]ooooo`GoZ<3[3OnW`>/3ojO0k0CoYl3[2?nW`>b:ooooo`Co00009Ooo
ool006Gooooo00?o0000ooooooooool0;Oooool5ojS0jaCoYl3[0_nW`>b;ooooo`Co0000:Oooool0
06Kooooo0_l0000^ooooo`KoZ<3[4OnW`>^;ooooo`?o0000;Oooool006Sooooo00?o0000oooooooo
ool0;?ooool6ojS0j`?oYl3[0onX`>/7ojO0jh[ooooo1?l0000`ooooo`00JOooool00ol0003ooooo
ooooo`0/ooooo`?oZ<3[1?nW`>/5ojS0j`?oYl3[ROooool4o`0003Cooooo001Zooooo`03o`000?oo
oooooooo02cooooo1onW`>/2ojS0jh[ooooo1?l0000hooooo`00Joooool2o`0002gooooo1OnW`>^9
ooooo`Co0000??ooool006gooooo00?o0000ooooooooool0:oooool00onW`>_oooooooooo`27oooo
o`?o0000@?ooool006kooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`23ooooo`Co
0000@oooool006oooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1oooooo`Co0000
Aoooool0073ooooo0_l0000Yooooo`03o`000?oooooooooo07_ooooo1?l0001;ooooo`00L_ooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo07Oooooo1?l0001?ooooo`00Loooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo07Cooooo0ol0001Cooooo`00M?ooool00ol0003o
ooooooooo`0Tooooo`03o`000?oooooooooo073ooooo1?l0001Fooooo`00MOooool00ol0003ooooo
ooooo`0Sooooo`03o`000?oooooooooo06cooooo1?l0001Jooooo`00M_ooool2o`0002?ooooo00?o
0000ooooooooool0J?ooool4o`0005kooooo001hooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool0I?ooool4o`0006;ooooo001iooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool0HOooool3o`0006Kooooo001jooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool0GOooool4o`0006Wooooo001kooooo`;o00007_ooool00ol0003oooooooooo`1Iooooo`Co0000
KOooool007gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Eooooo`Co0000LOoo
ool007kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1Aooooo`Co0000MOooool0
07oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1>ooooo`?o0000NOooool0083o
oooo0_l0000Iooooo`03o`000?oooooooooo04[ooooo1?l0001looooo`00P_ooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo04Kooooo1?l00020ooooo`00Poooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo04;ooooo1?l00024ooooo`00Q?ooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo03kooooo1?l00028ooooo`00QOooool2o`0001?ooooo00?o0000oooo
ooooool0??ooool3o`0008cooooo0027ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool0>?ooool4o`0008oooooo0028ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
=?ooool4o`0009?ooooo0029ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0<?oo
ool4o`0009Oooooo002:ooooo`;o00003_ooool00ol0003oooooooooo`0/ooooo`Co0000Voooool0
08cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Yooooo`?o0000Woooool008go
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Uooooo`Co0000X_ooool008kooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Qooooo`Co0000Y_ooool008oooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Mooooo`Co0000Z_ooool0093ooooo0_l00008
ooooo`03o`000?oooooooooo01Wooooo1?l0002^ooooo`00T_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo01Kooooo0ol0002booooo`00Toooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo01;ooooo1?l0002eooooo`00U?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00kooooo1?l0002iooooo`00UOooool2o`0000?ooooo00?o0000ooooooooool02_oo
ool4o`000;gooooo002Gooooo`04o`000?ooooooooooo`0000Sooooo1?l00031ooooo`00V?ooool0
0ol0003oooooo`000005ooooo`?o0000aOooool009Wooooo0_l000000ooooooo0000o`000002o`00
0<Sooooo002Jooooo`;o0000c?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0538698, 0.0432538, \
0.0035044, 0.0035044}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[.12586 .2075 -12 -8.99448 ]
[.12586 .2075 0 .00552 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.56094 .0364 -5.16972 -9 ]
[.56094 .0364 .83028 0 ]
[.75679 .08071 0 -6.17777 ]
[.75679 .08071 12 2.82223 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.9429 .3657 0 -5.9083 ]
[.9429 .3657 6 3.0917 ]
[.02494 .25992 -18 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.01611 .31527 -18 -2.78472 ]
[.01611 .31527 0 6.21528 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00254 .43215 -12 -2.88407 ]
[-0.00254 .43215 0 6.11593 ]
[-0.0124 .49393 -12 -2.93688 ]
[-0.0124 .49393 0 6.06312 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
[(-2)] .12586 .2075 1 .99877 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.56863 .04703 m
.57247 .05235 L
s
[(2)] .56094 .0364 .72324 1 Mshowa
.125 Mabswid
.18558 .19702 m
.18832 .19985 L
s
.23703 .17687 m
.23971 .17975 L
s
.28951 .15632 m
.29214 .15925 L
s
.39772 .11395 m
.40023 .11699 L
s
.4535 .09211 m
.45595 .0952 L
s
.51046 .06981 m
.51284 .07294 L
s
.08568 .23614 m
.08851 .23887 L
s
.62804 .02377 m
.63027 .02701 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.7445 .0853 m
.73835 .08759 L
s
[(-2)] .75679 .08071 -1 .37284 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.93037 .36962 m
.92411 .37158 L
s
[(2)] .9429 .3657 -1 .31296 Mshowa
.125 Mabswid
.7708 .12553 m
.7671 .12688 L
s
.79613 .16428 m
.79242 .1656 L
s
.82054 .20161 m
.81682 .20291 L
s
.86679 .27235 m
.86305 .2736 L
s
.88871 .30589 m
.88497 .30711 L
s
.9099 .3383 m
.90615 .3395 L
s
.71716 .04348 m
.71349 .04489 L
s
.95018 .39992 m
.94642 .40107 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(-20)] .02494 .25992 1 -0.39157 Mshowa
.02837 .31059 m
.0345 .30825 L
s
[(-10)] .01611 .31527 1 -0.38117 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.00981 .42772 m
.01599 .4255 L
s
[(10)] -0.00254 .43215 1 -0.3591 Mshowa
0 .48963 m
.0062 .48748 L
s
[(20)] -0.0124 .49393 1 -0.34736 Mshowa
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.658 .75 .918 r
.39362 .6948 .40169 .70191 .4152 .69804 .40717 .69087 Mtetra
.655 .749 .919 r
.40717 .69087 .4152 .69804 .42878 .69413 .42079 .68704 Mtetra
.653 .752 .922 r
.42079 .68704 .42878 .69413 .44243 .6903 .43448 .68324 Mtetra
.654 .753 .923 r
.43448 .68324 .44243 .6903 .45614 .68651 .44824 .67939 Mtetra
.655 .753 .922 r
.44824 .67939 .45614 .68651 .46992 .68269 .46207 .67548 Mtetra
.658 .753 .92 r
.46207 .67548 .46992 .68269 .48378 .6788 .47597 .67145 Mtetra
.659 .75 .917 r
.47597 .67145 .48378 .6788 .4977 .67483 .48994 .66738 Mtetra
.657 .748 .917 r
.48994 .66738 .4977 .67483 .5117 .67079 .50398 .66338 Mtetra
.654 .749 .92 r
.50398 .66338 .5117 .67079 .52577 .66674 .5181 .65944 Mtetra
.654 .753 .923 r
.5181 .65944 .52577 .66674 .53991 .66278 .53229 .65548 Mtetra
.653 .754 .924 r
.53229 .65548 .53991 .66278 .55412 .65882 .54655 .65151 Mtetra
.654 .755 .924 r
.54655 .65151 .55412 .65882 .56841 .65485 .56088 .64749 Mtetra
.655 .755 .923 r
.56088 .64749 .56841 .65485 .58277 .65086 .5753 .64343 Mtetra
.657 .754 .922 r
.5753 .64343 .58277 .65086 .59721 .64683 .58978 .63927 Mtetra
.658 .752 .92 r
.58978 .63927 .59721 .64683 .61172 .64277 .60434 .63507 Mtetra
.658 .75 .918 r
.60434 .63507 .61172 .64277 .62631 .63868 .61898 .63086 Mtetra
.657 .747 .916 r
.61898 .63086 .62631 .63868 .64097 .63455 .63369 .62664 Mtetra
.657 .746 .915 r
.63369 .62664 .64097 .63455 .65571 .6304 .64848 .62241 Mtetra
.657 .745 .915 r
.64848 .62241 .65571 .6304 .67053 .62622 .66335 .61818 Mtetra
.656 .745 .915 r
.66335 .61818 .67053 .62622 .68543 .62202 .6783 .61393 Mtetra
.656 .744 .915 r
.6783 .61393 .68543 .62202 .7004 .6178 .69333 .60969 Mtetra
.656 .745 .915 r
.69333 .60969 .7004 .6178 .71546 .61355 .70844 .60543 Mtetra
.655 .745 .916 r
.70844 .60543 .71546 .61355 .73059 .60928 .72363 .60117 Mtetra
.655 .746 .917 r
.72363 .60117 .73059 .60928 .74581 .60497 .73891 .5969 Mtetra
.654 .748 .919 r
.73891 .5969 .74581 .60497 .7611 .60063 .75427 .59262 Mtetra
.655 .751 .921 r
.75427 .59262 .7611 .60063 .77648 .59625 .76971 .58828 Mtetra
.656 .754 .922 r
.76971 .58828 .77648 .59625 .79193 .59183 .78523 .58386 Mtetra
.657 .755 .923 r
.78523 .58386 .79193 .59183 .80747 .58739 .80083 .57938 Mtetra
.657 .756 .923 r
.80083 .57938 .80747 .58739 .8231 .58293 .81651 .57486 Mtetra
.657 .755 .922 r
.81651 .57486 .8231 .58293 .83881 .57848 .83228 .57031 Mtetra
.657 .754 .921 r
.83228 .57031 .83881 .57848 .85461 .5741 .84813 .56575 Mtetra
.656 .75 .919 r
.84813 .56575 .85461 .5741 .87051 .56973 .86408 .56124 Mtetra
.653 .746 .918 r
.86408 .56124 .87051 .56973 .88648 .56527 .88012 .5568 Mtetra
.654 .748 .919 r
.88012 .5568 .88648 .56527 .90254 .56072 .89626 .55232 Mtetra
.656 .752 .921 r
.89626 .55232 .90254 .56072 .91868 .55611 .91247 .54771 Mtetra
.657 .754 .921 r
.91247 .54771 .91868 .55611 .93491 .55145 .92876 .54303 Mtetra
.658 .755 .922 r
.92876 .54303 .93491 .55145 .95123 .54682 .94515 .53829 Mtetra
.657 .753 .921 r
.94515 .53829 .95123 .54682 .96765 .54228 .96162 .53358 Mtetra
.654 .748 .919 r
.96162 .53358 .96765 .54228 .98417 .53769 .97821 .52896 Mtetra
.655 .749 .919 r
.38547 .68761 .39362 .6948 .40717 .69087 .39907 .68376 Mtetra
.653 .752 .922 r
.39907 .68376 .40717 .69087 .42079 .68704 .41273 .67995 Mtetra
.654 .753 .923 r
.41273 .67995 .42079 .68704 .43448 .68324 .42646 .67608 Mtetra
.656 .753 .921 r
.42646 .67608 .43448 .68324 .44824 .67939 .44026 .67214 Mtetra
.659 .752 .919 r
.44026 .67214 .44824 .67939 .46207 .67548 .45414 .66806 Mtetra
.659 .749 .917 r
.45414 .66806 .46207 .67548 .47597 .67145 .46809 .66398 Mtetra
.655 .748 .918 r
.46809 .66398 .47597 .67145 .48994 .66738 .4821 .66002 Mtetra
.653 .751 .921 r
.4821 .66002 .48994 .66738 .50398 .66338 .49619 .65608 Mtetra
.653 .754 .923 r
.49619 .65608 .50398 .66338 .5181 .65944 .51035 .65213 Mtetra
.654 .754 .924 r
.51035 .65213 .5181 .65944 .53229 .65548 .52459 .64813 Mtetra
.655 .755 .923 r
.52459 .64813 .53229 .65548 .54655 .65151 .5389 .64405 Mtetra
.659 .754 .92 r
.5389 .64405 .54655 .65151 .56088 .64749 .55329 .63984 Mtetra
.659 .75 .917 r
.55329 .63984 .56088 .64749 .5753 .64343 .56774 .6356 Mtetra
.659 .746 .915 r
.56774 .6356 .5753 .64343 .58978 .63927 .58228 .63136 Mtetra
.657 .745 .915 r
.58228 .63136 .58978 .63927 .60434 .63507 .59689 .62716 Mtetra
.656 .746 .916 r
.59689 .62716 .60434 .63507 .61898 .63086 .61158 .62298 Mtetra
.656 .747 .917 r
.61158 .62298 .61898 .63086 .63369 .62664 .62635 .61877 Mtetra
.656 .749 .918 r
.62635 .61877 .63369 .62664 .64848 .62241 .64119 .61455 Mtetra
.656 .75 .919 r
.64119 .61455 .64848 .62241 .66335 .61818 .65611 .6103 Mtetra
.656 .751 .92 r
.65611 .6103 .66335 .61818 .6783 .61393 .67112 .60602 Mtetra
.67112 .60602 .6783 .61393 .69333 .60969 .6862 .6017 Mtetra
.656 .75 .919 r
.6862 .6017 .69333 .60969 .70844 .60543 .70136 .59736 Mtetra
.656 .749 .918 r
.70136 .59736 .70844 .60543 .72363 .60117 .71661 .59299 Mtetra
.656 .747 .917 r
.71661 .59299 .72363 .60117 .73891 .5969 .73194 .58861 Mtetra
.655 .745 .916 r
.73194 .58861 .73891 .5969 .75427 .59262 .74735 .58424 Mtetra
.654 .744 .916 r
.74735 .58424 .75427 .59262 .76971 .58828 .76285 .57991 Mtetra
.653 .745 .917 r
.76285 .57991 .76971 .58828 .78523 .58386 .77844 .57557 Mtetra
.653 .748 .919 r
.77844 .57557 .78523 .58386 .80083 .57938 .79411 .57121 Mtetra
.656 .753 .921 r
.79411 .57121 .80083 .57938 .81651 .57486 .80986 .56671 Mtetra
.657 .755 .922 r
.80986 .56671 .81651 .57486 .83228 .57031 .82569 .56213 Mtetra
.658 .756 .922 r
.82569 .56213 .83228 .57031 .84813 .56575 .8416 .55749 Mtetra
.658 .755 .922 r
.8416 .55749 .84813 .56575 .86408 .56124 .8576 .55284 Mtetra
.657 .752 .92 r
.8576 .55284 .86408 .56124 .88012 .5568 .8737 .5482 Mtetra
.654 .747 .918 r
.8737 .5482 .88012 .5568 .89626 .55232 .8899 .54368 Mtetra
.653 .747 .919 r
.8899 .54368 .89626 .55232 .91247 .54771 .90619 .53915 Mtetra
.656 .751 .92 r
.90619 .53915 .91247 .54771 .92876 .54303 .92256 .53448 Mtetra
.657 .753 .921 r
.92256 .53448 .92876 .54303 .94515 .53829 .93901 .52973 Mtetra
.658 .755 .921 r
.93901 .52973 .94515 .53829 .96162 .53358 .95555 .52491 Mtetra
.656 .753 .921 r
.95555 .52491 .96162 .53358 .97821 .52896 .97219 .52013 Mtetra
.653 .751 .922 r
.37725 .68045 .38547 .68761 .39907 .68376 .39088 .67663 Mtetra
.654 .753 .923 r
.39088 .67663 .39907 .68376 .41273 .67995 .40458 .67275 Mtetra
.656 .753 .921 r
.40458 .67275 .41273 .67995 .42646 .67608 .41836 .66878 Mtetra
.659 .752 .919 r
.41836 .66878 .42646 .67608 .44026 .67214 .43221 .66468 Mtetra
.658 .749 .917 r
.43221 .66468 .44026 .67214 .45414 .66806 .44614 .6606 Mtetra
.654 .748 .919 r
.44614 .6606 .45414 .66806 .46809 .66398 .46013 .65665 Mtetra
.653 .752 .923 r
.46013 .65665 .46809 .66398 .4821 .66002 .47419 .6527 Mtetra
.653 .754 .924 r
.47419 .6527 .4821 .66002 .49619 .65608 .48832 .64873 Mtetra
.654 .754 .923 r
.48832 .64873 .49619 .65608 .51035 .65213 .50253 .64469 Mtetra
.659 .754 .921 r
.50253 .64469 .51035 .65213 .52459 .64813 .51682 .64047 Mtetra
.66 .75 .917 r
.51682 .64047 .52459 .64813 .5389 .64405 .53118 .63621 Mtetra
.659 .746 .914 r
.53118 .63621 .5389 .64405 .55329 .63984 .54561 .63197 Mtetra
.656 .745 .916 r
.54561 .63197 .55329 .63984 .56774 .6356 .56012 .62782 Mtetra
.655 .748 .919 r
.56012 .62782 .56774 .6356 .58228 .63136 .57471 .62367 Mtetra
.654 .752 .921 r
.57471 .62367 .58228 .63136 .59689 .62716 .58937 .61952 Mtetra
.654 .754 .923 r
.58937 .61952 .59689 .62716 .61158 .62298 .60411 .61534 Mtetra
.654 .755 .924 r
.60411 .61534 .61158 .62298 .62635 .61877 .61894 .61114 Mtetra
.654 .756 .925 r
.61894 .61114 .62635 .61877 .64119 .61455 .63384 .60689 Mtetra
.655 .757 .925 r
.63384 .60689 .64119 .61455 .65611 .6103 .64881 .60261 Mtetra
.64881 .60261 .65611 .6103 .67112 .60602 .66387 .59829 Mtetra
.656 .758 .925 r
.66387 .59829 .67112 .60602 .6862 .6017 .67901 .59392 Mtetra
.656 .758 .924 r
.67901 .59392 .6862 .6017 .70136 .59736 .69423 .58951 Mtetra
.657 .757 .924 r
.69423 .58951 .70136 .59736 .71661 .59299 .70953 .58506 Mtetra
.657 .756 .923 r
.70953 .58506 .71661 .59299 .73194 .58861 .72492 .58059 Mtetra
.657 .755 .922 r
.72492 .58059 .73194 .58861 .74735 .58424 .74038 .57609 Mtetra
.657 .753 .92 r
.74038 .57609 .74735 .58424 .76285 .57991 .75593 .57158 Mtetra
.656 .749 .918 r
.75593 .57158 .76285 .57991 .77844 .57557 .77157 .56707 Mtetra
.654 .745 .916 r
.77157 .56707 .77844 .57557 .79411 .57121 .7873 .56264 Mtetra
.653 .744 .917 r
.7873 .56264 .79411 .57121 .80986 .56671 .80312 .55824 Mtetra
.653 .748 .919 r
.80312 .55824 .80986 .56671 .82569 .56213 .81903 .5538 Mtetra
.657 .754 .922 r
.81903 .5538 .82569 .56213 .8416 .55749 .83501 .54917 Mtetra
.658 .756 .922 r
.83501 .54917 .8416 .55749 .8576 .55284 .85107 .54446 Mtetra
.658 .755 .922 r
.85107 .54446 .8576 .55284 .8737 .5482 .86723 .53972 Mtetra
.657 .754 .921 r
.86723 .53972 .8737 .5482 .8899 .54368 .88347 .53498 Mtetra
.654 .748 .919 r
.88347 .53498 .8899 .54368 .90619 .53915 .89982 .53037 Mtetra
.653 .747 .919 r
.89982 .53037 .90619 .53915 .92256 .53448 .91627 .52578 Mtetra
.656 .751 .92 r
.91627 .52578 .92256 .53448 .93901 .52973 .9328 .52104 Mtetra
.657 .753 .921 r
.9328 .52104 .93901 .52973 .95555 .52491 .94942 .51621 Mtetra
.658 .755 .921 r
.94942 .51621 .95555 .52491 .97219 .52013 .96612 .51131 Mtetra
.654 .753 .923 r
.36894 .67328 .37725 .68045 .39088 .67663 .38262 .66939 Mtetra
.656 .753 .921 r
.38262 .66939 .39088 .67663 .40458 .67275 .39637 .66542 Mtetra
.66 .752 .919 r
.39637 .66542 .40458 .67275 .41836 .66878 .41019 .66129 Mtetra
.658 .749 .917 r
.41019 .66129 .41836 .66878 .43221 .66468 .42409 .6572 Mtetra
.654 .749 .92 r
.42409 .6572 .43221 .66468 .44614 .6606 .43805 .65324 Mtetra
.652 .753 .923 r
.43805 .65324 .44614 .6606 .46013 .65665 .45209 .64929 Mtetra
.653 .754 .924 r
.45209 .64929 .46013 .65665 .47419 .6527 .4662 .6453 Mtetra
.656 .754 .922 r
.4662 .6453 .47419 .6527 .48832 .64873 .48038 .64117 Mtetra
.66 .752 .918 r
.48038 .64117 .48832 .64873 .50253 .64469 .49464 .63689 Mtetra
.66 .747 .915 r
.49464 .63689 .50253 .64469 .51682 .64047 .50897 .63261 Mtetra
.656 .746 .916 r
.50897 .63261 .51682 .64047 .53118 .63621 .52338 .62847 Mtetra
.654 .749 .92 r
.52338 .62847 .53118 .63621 .54561 .63197 .53787 .62435 Mtetra
.653 .753 .923 r
.53787 .62435 .54561 .63197 .56012 .62782 .55243 .62024 Mtetra
.652 .755 .925 r
.55243 .62024 .56012 .62782 .57471 .62367 .56707 .61612 Mtetra
.653 .757 .926 r
.56707 .61612 .57471 .62367 .58937 .61952 .58178 .61196 Mtetra
.653 .758 .926 r
.58178 .61196 .58937 .61952 .60411 .61534 .59658 .60774 Mtetra
.654 .758 .926 r
.59658 .60774 .60411 .61534 .61894 .61114 .61145 .60348 Mtetra
.655 .758 .926 r
.61145 .60348 .61894 .61114 .63384 .60689 .62641 .59916 Mtetra
.656 .757 .925 r
.62641 .59916 .63384 .60689 .64881 .60261 .64144 .59479 Mtetra
.655 .756 .924 r
.64144 .59479 .64881 .60261 .66387 .59829 .65655 .59042 Mtetra
.65655 .59042 .66387 .59829 .67901 .59392 .67175 .58606 Mtetra
.655 .757 .925 r
.67175 .58606 .67901 .59392 .69423 .58951 .68703 .58164 Mtetra
.656 .758 .925 r
.68703 .58164 .69423 .58951 .70953 .58506 .70239 .57717 Mtetra
.657 .759 .925 r
.70239 .57717 .70953 .58506 .72492 .58059 .71783 .57264 Mtetra
.658 .759 .925 r
.71783 .57264 .72492 .58059 .74038 .57609 .73336 .56806 Mtetra
.658 .759 .924 r
.73336 .56806 .74038 .57609 .75593 .57158 .74896 .56344 Mtetra
.658 .757 .923 r
.74896 .56344 .75593 .57158 .77157 .56707 .76465 .5588 Mtetra
.657 .754 .921 r
.76465 .5588 .77157 .56707 .7873 .56264 .78043 .55417 Mtetra
.657 .75 .919 r
.78043 .55417 .7873 .56264 .80312 .55824 .7963 .54956 Mtetra
.653 .744 .917 r
.7963 .54956 .80312 .55824 .81903 .5538 .81227 .54508 Mtetra
.652 .744 .917 r
.81227 .54508 .81903 .5538 .83501 .54917 .82833 .54062 Mtetra
.655 .751 .92 r
.82833 .54062 .83501 .54917 .85107 .54446 .84448 .53598 Mtetra
.658 .755 .922 r
.84448 .53598 .85107 .54446 .86723 .53972 .8607 .5312 Mtetra
.658 .756 .922 r
.8607 .5312 .86723 .53972 .88347 .53498 .877 .52638 Mtetra
.658 .754 .921 r
.877 .52638 .88347 .53498 .89982 .53037 .8934 .52156 Mtetra
.654 .749 .919 r
.8934 .52156 .89982 .53037 .91627 .52578 .90991 .51686 Mtetra
.653 .747 .919 r
.90991 .51686 .91627 .52578 .9328 .52104 .92652 .51221 Mtetra
.656 .751 .92 r
.92652 .51221 .9328 .52104 .94942 .51621 .94321 .50738 Mtetra
.657 .754 .921 r
.94321 .50738 .94942 .51621 .96612 .51131 .95999 .50246 Mtetra
.655 .753 .922 r
.36055 .66602 .36894 .67328 .38262 .66939 .37428 .66205 Mtetra
.659 .753 .919 r
.37428 .66205 .38262 .66939 .39637 .66542 .38808 .65792 Mtetra
.659 .749 .917 r
.38808 .65792 .39637 .66542 .41019 .66129 .40195 .65379 Mtetra
.654 .749 .92 r
.40195 .65379 .41019 .66129 .42409 .6572 .41588 .64981 Mtetra
.652 .752 .923 r
.41588 .64981 .42409 .6572 .43805 .65324 .42989 .64585 Mtetra
.653 .754 .924 r
.42989 .64585 .43805 .65324 .45209 .64929 .44397 .64184 Mtetra
.658 .754 .921 r
.44397 .64184 .45209 .64929 .4662 .6453 .45813 .63765 Mtetra
.661 .751 .917 r
.45813 .63765 .4662 .6453 .48038 .64117 .47237 .63332 Mtetra
.658 .746 .915 r
.47237 .63332 .48038 .64117 .49464 .63689 .48667 .62909 Mtetra
.654 .748 .918 r
.48667 .62909 .49464 .63689 .50897 .63261 .50105 .62498 Mtetra
.652 .752 .923 r
.50105 .62498 .50897 .63261 .52338 .62847 .51551 .62089 Mtetra
.651 .754 .925 r
.51551 .62089 .52338 .62847 .53787 .62435 .53004 .61681 Mtetra
.652 .757 .926 r
.53004 .61681 .53787 .62435 .55243 .62024 .54466 .61267 Mtetra
.655 .758 .926 r
.54466 .61267 .55243 .62024 .56707 .61612 .55935 .60841 Mtetra
.66 .757 .922 r
.55935 .60841 .56707 .61612 .58178 .61196 .57411 .60397 Mtetra
.659 .75 .918 r
.57411 .60397 .58178 .61196 .59658 .60774 .58896 .59954 Mtetra
.657 .746 .915 r
.58896 .59954 .59658 .60774 .61145 .60348 .60388 .59516 Mtetra
.657 .743 .914 r
.60388 .59516 .61145 .60348 .62641 .59916 .61889 .59078 Mtetra
.656 .743 .914 r
.61889 .59078 .62641 .59916 .64144 .59479 .63397 .5864 Mtetra
.656 .744 .914 r
.63397 .5864 .64144 .59479 .65655 .59042 .64914 .58199 Mtetra
.64914 .58199 .65655 .59042 .67175 .58606 .66439 .57755 Mtetra
.656 .743 .914 r
.66439 .57755 .67175 .58606 .68703 .58164 .67973 .5731 Mtetra
.655 .743 .914 r
.67973 .5731 .68703 .58164 .70239 .57717 .69515 .56866 Mtetra
.654 .744 .916 r
.69515 .56866 .70239 .57717 .71783 .57264 .71066 .56426 Mtetra
.652 .748 .92 r
.71066 .56426 .71783 .57264 .73336 .56806 .72625 .55988 Mtetra
.656 .756 .923 r
.72625 .55988 .73336 .56806 .74896 .56344 .74193 .55531 Mtetra
.658 .759 .924 r
.74193 .55531 .74896 .56344 .76465 .5588 .75768 .55061 Mtetra
.659 .759 .924 r
.75768 .55061 .76465 .5588 .78043 .55417 .77351 .54585 Mtetra
.659 .757 .922 r
.77351 .54585 .78043 .55417 .7963 .54956 .78944 .5411 Mtetra
.657 .754 .921 r
.78944 .5411 .7963 .54956 .81227 .54508 .80545 .53637 Mtetra
.654 .747 .918 r
.80545 .53637 .81227 .54508 .82833 .54062 .82157 .53175 Mtetra
.651 .744 .917 r
.82157 .53175 .82833 .54062 .84448 .53598 .83779 .52723 Mtetra
.654 .749 .92 r
.83779 .52723 .84448 .53598 .8607 .5312 .85409 .52257 Mtetra
.658 .755 .921 r
.85409 .52257 .8607 .5312 .877 .52638 .87047 .51772 Mtetra
.659 .756 .922 r
.87047 .51772 .877 .52638 .8934 .52156 .88693 .51281 Mtetra
.658 .754 .921 r
.88693 .51281 .8934 .52156 .90991 .51686 .90349 .50791 Mtetra
.654 .748 .919 r
.90349 .50791 .90991 .51686 .92652 .51221 .92017 .50316 Mtetra
.653 .747 .919 r
.92017 .50316 .92652 .51221 .94321 .50738 .93694 .49842 Mtetra
.656 .752 .92 r
.93694 .49842 .94321 .50738 .95999 .50246 .95379 .49349 Mtetra
.658 .753 .92 r
.35209 .65866 .36055 .66602 .37428 .66205 .36586 .65454 Mtetra
.66 .75 .917 r
.36586 .65454 .37428 .66205 .38808 .65792 .37971 .65035 Mtetra
.654 .748 .919 r
.37971 .65035 .38808 .65792 .40195 .65379 .39362 .64635 Mtetra
.652 .752 .923 r
.39362 .64635 .40195 .65379 .41588 .64981 .4076 .64238 Mtetra
.653 .753 .923 r
.4076 .64238 .41588 .64981 .42989 .64585 .42165 .63836 Mtetra
.658 .754 .921 r
.42165 .63836 .42989 .64585 .44397 .64184 .43578 .63413 Mtetra
.661 .75 .916 r
.43578 .63413 .44397 .64184 .45813 .63765 .44999 .62978 Mtetra
.657 .746 .916 r
.44999 .62978 .45813 .63765 .47237 .63332 .46427 .62557 Mtetra
.653 .749 .92 r
.46427 .62557 .47237 .63332 .48667 .62909 .47862 .62146 Mtetra
.651 .753 .924 r
.47862 .62146 .48667 .62909 .50105 .62498 .49305 .61741 Mtetra
.651 .755 .926 r
.49305 .61741 .50105 .62498 .51551 .62089 .50756 .61332 Mtetra
.655 .758 .925 r
.50756 .61332 .51551 .62089 .53004 .61681 .52214 .60904 Mtetra
.661 .755 .92 r
.52214 .60904 .53004 .61681 .54466 .61267 .53681 .60455 Mtetra
.658 .746 .915 r
.53681 .60455 .54466 .61267 .55935 .60841 .55155 .60016 Mtetra
.653 .743 .915 r
.55155 .60016 .55935 .60841 .57411 .60397 .56637 .59593 Mtetra
.648 .748 .922 r
.56637 .59593 .57411 .60397 .58896 .59954 .58127 .59186 Mtetra
.645 .757 .931 r
.58127 .59186 .58896 .59954 .60388 .59516 .59626 .58781 Mtetra
.645 .768 .938 r
.59626 .58781 .60388 .59516 .61889 .59078 .61133 .58369 Mtetra
.647 .776 .942 r
.61133 .58369 .61889 .59078 .63397 .5864 .62648 .57942 Mtetra
.652 .782 .943 r
.62648 .57942 .63397 .5864 .64914 .58199 .64171 .57497 Mtetra
.656 .784 .942 r
.64171 .57497 .64914 .58199 .66439 .57755 .65702 .57033 Mtetra
.661 .78 .938 r
.65702 .57033 .66439 .57755 .67973 .5731 .6724 .56554 Mtetra
.663 .773 .931 r
.6724 .56554 .67973 .5731 .69515 .56866 .68786 .56067 Mtetra
.663 .763 .924 r
.68786 .56067 .69515 .56866 .71066 .56426 .70341 .55582 Mtetra
.659 .751 .918 r
.70341 .55582 .71066 .56426 .72625 .55988 .71905 .55113 Mtetra
.654 .743 .915 r
.71905 .55113 .72625 .55988 .74193 .55531 .73479 .5466 Mtetra
.651 .744 .918 r
.73479 .5466 .74193 .55531 .75768 .55061 .75062 .54218 Mtetra
.655 .754 .922 r
.75062 .54218 .75768 .55061 .77351 .54585 .76653 .53753 Mtetra
.659 .759 .924 r
.76653 .53753 .77351 .54585 .78944 .5411 .78252 .53269 Mtetra
.66 .758 .923 r
.78252 .53269 .78944 .5411 .80545 .53637 .79859 .52781 Mtetra
.658 .755 .922 r
.79859 .52781 .80545 .53637 .82157 .53175 .81476 .52297 Mtetra
.655 .75 .919 r
.81476 .52297 .82157 .53175 .83779 .52723 .83102 .51824 Mtetra
.651 .744 .918 r
.83102 .51824 .83779 .52723 .85409 .52257 .8474 .51366 Mtetra
.654 .748 .919 r
.8474 .51366 .85409 .52257 .87047 .51772 .86386 .50894 Mtetra
.658 .755 .921 r
.86386 .50894 .87047 .51772 .88693 .51281 .8804 .504 Mtetra
.659 .755 .921 r
.8804 .504 .88693 .51281 .90349 .50791 .89702 .49901 Mtetra
.657 .754 .921 r
.89702 .49901 .90349 .50791 .92017 .50316 .91375 .49404 Mtetra
.653 .747 .919 r
.91375 .49404 .92017 .50316 .93694 .49842 .93059 .48925 Mtetra
.654 .748 .919 r
.93059 .48925 .93694 .49842 .95379 .49349 .94753 .48439 Mtetra
.66 .751 .918 r
.34355 .65116 .35209 .65866 .36586 .65454 .35737 .64694 Mtetra
.656 .749 .918 r
.35737 .64694 .36586 .65454 .37971 .65035 .37125 .64287 Mtetra
.652 .752 .923 r
.37125 .64287 .37971 .65035 .39362 .64635 .3852 .63888 Mtetra
.652 .753 .923 r
.3852 .63888 .39362 .64635 .4076 .64238 .39923 .63485 Mtetra
.658 .754 .921 r
.39923 .63485 .4076 .64238 .42165 .63836 .41333 .63063 Mtetra
.662 .751 .916 r
.41333 .63063 .42165 .63836 .43578 .63413 .42752 .62624 Mtetra
.657 .747 .916 r
.42752 .62624 .43578 .63413 .44999 .62978 .44177 .62202 Mtetra
.653 .75 .921 r
.44177 .62202 .44999 .62978 .46427 .62557 .45609 .61792 Mtetra
.65 .753 .925 r
.45609 .61792 .46427 .62557 .47862 .62146 .47049 .61387 Mtetra
.651 .756 .926 r
.47049 .61387 .47862 .62146 .49305 .61741 .48497 .60976 Mtetra
.661 .758 .922 r
.48497 .60976 .49305 .61741 .50756 .61332 .49953 .60526 Mtetra
.66 .749 .916 r
.49953 .60526 .50756 .61332 .52214 .60904 .51417 .60082 Mtetra
.65 .743 .917 r
.51417 .60082 .52214 .60904 .53681 .60455 .52888 .59673 Mtetra
.637 .75 .93 r
.52888 .59673 .53681 .60455 .55155 .60016 .54368 .59301 Mtetra
.625 .765 .947 r
.54368 .59301 .55155 .60016 .56637 .59593 .55856 .5895 Mtetra
.614 .784 .963 r
.55856 .5895 .56637 .59593 .58127 .59186 .57353 .58611 Mtetra
.596 .799 .978 r
.57353 .58611 .58127 .59186 .59626 .58781 .5886 .58291 Mtetra
.593 .826 .988 r
.5886 .58291 .59626 .58781 .61133 .58369 .60376 .57936 Mtetra
.599 .847 .991 r
.60376 .57936 .61133 .58369 .62648 .57942 .61899 .57535 Mtetra
.613 .861 .99 r
.61899 .57535 .62648 .57942 .64171 .57497 .63429 .57086 Mtetra
.633 .867 .986 r
.63429 .57086 .64171 .57497 .65702 .57033 .64967 .56588 Mtetra
.656 .864 .978 r
.64967 .56588 .65702 .57033 .6724 .56554 .6651 .56044 Mtetra
.675 .851 .966 r
.6651 .56044 .6724 .56554 .68786 .56067 .6806 .55463 Mtetra
.675 .824 .955 r
.6806 .55463 .68786 .56067 .70341 .55582 .69618 .54901 Mtetra
.675 .803 .943 r
.69618 .54901 .70341 .55582 .71905 .55113 .71184 .5435 Mtetra
.671 .78 .931 r
.71184 .5435 .71905 .55113 .73479 .5466 .7276 .5382 Mtetra
.662 .758 .921 r
.7276 .5382 .73479 .5466 .75062 .54218 .74347 .53328 Mtetra
.653 .743 .916 r
.74347 .53328 .75062 .54218 .76653 .53753 .75944 .5287 Mtetra
.651 .745 .919 r
.75944 .5287 .76653 .53753 .78252 .53269 .77552 .52419 Mtetra
.659 .758 .923 r
.77552 .52419 .78252 .53269 .79859 .52781 .79166 .51928 Mtetra
.66 .759 .923 r
.79166 .51928 .79859 .52781 .81476 .52297 .80788 .51429 Mtetra
.659 .756 .922 r
.80788 .51429 .81476 .52297 .83102 .51824 .8242 .50936 Mtetra
.655 .751 .92 r
.8242 .50936 .83102 .51824 .8474 .51366 .84063 .50454 Mtetra
.651 .744 .918 r
.84063 .50454 .8474 .51366 .86386 .50894 .85717 .4999 Mtetra
.654 .749 .919 r
.85717 .4999 .86386 .50894 .8804 .504 .87379 .49508 Mtetra
.658 .755 .921 r
.87379 .49508 .8804 .504 .89702 .49901 .89049 .49004 Mtetra
.659 .755 .921 r
.89049 .49004 .89702 .49901 .91375 .49404 .90727 .48497 Mtetra
.656 .753 .921 r
.90727 .48497 .91375 .49404 .93059 .48925 .92417 .47997 Mtetra
.652 .747 .919 r
.92417 .47997 .93059 .48925 .94753 .48439 .94119 .47513 Mtetra
.658 .749 .918 r
.33493 .64353 .34355 .65116 .35737 .64694 .34879 .63936 Mtetra
.653 .75 .921 r
.34879 .63936 .35737 .64694 .37125 .64287 .36271 .63534 Mtetra
.652 .752 .923 r
.36271 .63534 .37125 .64287 .3852 .63888 .37671 .63132 Mtetra
.656 .754 .922 r
.37671 .63132 .3852 .63888 .39923 .63485 .39078 .62714 Mtetra
.662 .752 .917 r
.39078 .62714 .39923 .63485 .41333 .63063 .40494 .62272 Mtetra
.658 .747 .916 r
.40494 .62272 .41333 .63063 .42752 .62624 .41917 .61844 Mtetra
.652 .75 .921 r
.41917 .61844 .42752 .62624 .44177 .62202 .43346 .61433 Mtetra
.649 .753 .925 r
.43346 .61433 .44177 .62202 .45609 .61792 .44783 .61028 Mtetra
.651 .756 .926 r
.44783 .61028 .45609 .61792 .47049 .61387 .46228 .60613 Mtetra
.663 .757 .92 r
.46228 .60613 .47049 .61387 .48497 .60976 .47682 .60154 Mtetra
.656 .744 .915 r
.47682 .60154 .48497 .60976 .49953 .60526 .49142 .59722 Mtetra
.636 .744 .926 r
.49142 .59722 .49953 .60526 .51417 .60082 .50611 .59354 Mtetra
.614 .758 .948 r
.50611 .59354 .51417 .60082 .52888 .59673 .52087 .5904 Mtetra
.572 .773 .974 r
.52087 .5904 .52888 .59673 .54368 .59301 .53573 .58802 Mtetra
.527 .798 .995 r
.53573 .58802 .54368 .59301 .55856 .5895 .55069 .58589 Mtetra
.497 .829 .999 r
.55069 .58589 .55856 .5895 .57353 .58611 .56575 .58339 Mtetra
.487 .85 .99 r
.56575 .58339 .57353 .58611 .5886 .58291 .5809 .58035 Mtetra
.513 .866 .989 r
.5809 .58035 .5886 .58291 .60376 .57936 .59613 .57674 Mtetra
.543 .878 .99 r
.59613 .57674 .60376 .57936 .61899 .57535 .61144 .57265 Mtetra
.569 .886 .99 r
.61144 .57265 .61899 .57535 .63429 .57086 .62683 .56812 Mtetra
.591 .894 .988 r
.62683 .56812 .63429 .57086 .64967 .56588 .64228 .56315 Mtetra
.612 .903 .985 r
.64228 .56315 .64967 .56588 .6651 .56044 .65781 .55768 Mtetra
.637 .911 .982 r
.65781 .55768 .6651 .56044 .6806 .55463 .67338 .55164 Mtetra
.665 .914 .977 r
.67338 .55164 .6806 .55463 .69618 .54901 .689 .54505 Mtetra
.696 .895 .969 r
.689 .54505 .69618 .54901 .71184 .5435 .70468 .53805 Mtetra
.701 .853 .955 r
.70468 .53805 .71184 .5435 .7276 .5382 .72043 .53131 Mtetra
.685 .808 .941 r
.72043 .53131 .7276 .5382 .74347 .53328 .7363 .52533 Mtetra
.672 .777 .928 r
.7363 .52533 .74347 .53328 .75944 .5287 .75229 .51988 Mtetra
.656 .75 .919 r
.75229 .51988 .75944 .5287 .77552 .52419 .76841 .51509 Mtetra
.649 .742 .917 r
.76841 .51509 .77552 .52419 .79166 .51928 .78465 .51058 Mtetra
.659 .757 .922 r
.78465 .51058 .79166 .51928 .80788 .51429 .80095 .50561 Mtetra
.661 .759 .923 r
.80095 .50561 .80788 .51429 .8242 .50936 .81733 .50053 Mtetra
.659 .756 .922 r
.81733 .50053 .8242 .50936 .84063 .50454 .83381 .49551 Mtetra
.654 .75 .92 r
.83381 .49551 .84063 .50454 .85717 .4999 .8504 .49065 Mtetra
.65 .744 .918 r
.8504 .49065 .85717 .4999 .87379 .49508 .8671 .48594 Mtetra
.656 .751 .92 r
.8671 .48594 .87379 .49508 .89049 .49004 .88388 .48098 Mtetra
.659 .755 .921 r
.88388 .48098 .89049 .49004 .90727 .48497 .90074 .47584 Mtetra
.658 .755 .921 r
.90074 .47584 .90727 .48497 .92417 .47997 .91769 .47069 Mtetra
.654 .75 .92 r
.91769 .47069 .92417 .47997 .94119 .47513 .93477 .4657 Mtetra
.654 .749 .92 r
.32623 .63586 .33493 .64353 .34879 .63936 .34012 .63178 Mtetra
.652 .752 .923 r
.34012 .63178 .34879 .63936 .36271 .63534 .35409 .62775 Mtetra
.653 .753 .923 r
.35409 .62775 .36271 .63534 .37671 .63132 .36813 .62364 Mtetra
.662 .754 .918 r
.36813 .62364 .37671 .63132 .39078 .62714 .38226 .61921 Mtetra
.66 .748 .916 r
.38226 .61921 .39078 .62714 .40494 .62272 .39646 .61485 Mtetra
.653 .749 .92 r
.39646 .61485 .40494 .62272 .41917 .61844 .41073 .6107 Mtetra
.649 .752 .925 r
.41073 .6107 .41917 .61844 .43346 .61433 .42507 .60664 Mtetra
.651 .755 .926 r
.42507 .60664 .43346 .61433 .44783 .61028 .43949 .60249 Mtetra
.664 .757 .919 r
.43949 .60249 .44783 .61028 .46228 .60613 .454 .59786 Mtetra
.653 .743 .916 r
.454 .59786 .46228 .60613 .47682 .60154 .46858 .59364 Mtetra
.625 .745 .933 r
.46858 .59364 .47682 .60154 .49142 .59722 .48322 .59029 Mtetra
.582 .759 .962 r
.48322 .59029 .49142 .59722 .50611 .59354 .49795 .58786 Mtetra
.502 .767 .991 r
.49795 .58786 .50611 .59354 .52087 .5904 .51277 .58658 Mtetra
.444 .8 .997 r
.51277 .58658 .52087 .5904 .53573 .58802 .52769 .58503 Mtetra
.453 .827 .991 r
.52769 .58503 .53573 .58802 .55069 .58589 .54272 .58271 Mtetra
.516 .851 .996 r
.54272 .58271 .55069 .58589 .56575 .58339 .55785 .57954 Mtetra
.578 .855 .996 r
.55785 .57954 .56575 .58339 .5809 .58035 .57305 .57567 Mtetra
.617 .844 .986 r
.57305 .57567 .5809 .58035 .59613 .57674 .58834 .57133 Mtetra
.635 .829 .975 r
.58834 .57133 .59613 .57674 .61144 .57265 .60371 .5668 Mtetra
.64 .818 .968 r
.60371 .5668 .61144 .57265 .62683 .56812 .61917 .56223 Mtetra
.641 .819 .968 r
.61917 .56223 .62683 .56812 .64228 .56315 .63471 .55761 Mtetra
.643 .831 .973 r
.63471 .55761 .64228 .56315 .65781 .55768 .65033 .55279 Mtetra
.649 .854 .978 r
.65033 .55279 .65781 .55768 .67338 .55164 .66602 .54751 Mtetra
.662 .882 .979 r
.66602 .54751 .67338 .55164 .689 .54505 .68176 .54151 Mtetra
.682 .905 .974 r
.68176 .54151 .689 .54505 .70468 .53805 .69753 .53463 Mtetra
.706 .916 .966 r
.69753 .53463 .70468 .53805 .72043 .53131 .71333 .52696 Mtetra
.725 .894 .956 r
.71333 .52696 .72043 .53131 .7363 .52533 .72917 .519 Mtetra
.703 .833 .945 r
.72917 .519 .7363 .52533 .75229 .51988 .74515 .51219 Mtetra
.68 .79 .932 r
.74515 .51219 .75229 .51988 .76841 .51509 .76127 .50632 Mtetra
.659 .756 .921 r
.76127 .50632 .76841 .51509 .78465 .51058 .77753 .50132 Mtetra
.648 .741 .917 r
.77753 .50132 .78465 .51058 .80095 .50561 .79393 .49675 Mtetra
.659 .756 .922 r
.79393 .49675 .80095 .50561 .81733 .50053 .81038 .49168 Mtetra
.661 .759 .922 r
.81038 .49168 .81733 .50053 .83381 .49551 .82692 .48651 Mtetra
.658 .755 .921 r
.82692 .48651 .83381 .49551 .8504 .49065 .84356 .48143 Mtetra
.653 .748 .92 r
.84356 .48143 .8504 .49065 .8671 .48594 .86033 .47657 Mtetra
.651 .745 .919 r
.86033 .47657 .8671 .48594 .88388 .48098 .8772 .47176 Mtetra
.658 .753 .92 r
.8772 .47176 .88388 .48098 .90074 .47584 .89413 .46662 Mtetra
.659 .755 .921 r
.89413 .46662 .90074 .47584 .91769 .47069 .91116 .46139 Mtetra
.657 .754 .921 r
.91116 .46139 .91769 .47069 .93477 .4657 .92829 .4562 Mtetra
.652 .751 .922 r
.31744 .6282 .32623 .63586 .34012 .63178 .33137 .62414 Mtetra
.652 .752 .923 r
.33137 .62414 .34012 .63178 .35409 .62775 .34538 .62006 Mtetra
.659 .754 .92 r
.34538 .62006 .35409 .62775 .36813 .62364 .35948 .61572 Mtetra
.662 .75 .915 r
.35948 .61572 .36813 .62364 .38226 .61921 .37366 .61124 Mtetra
.654 .748 .918 r
.37366 .61124 .38226 .61921 .39646 .61485 .3879 .60703 Mtetra
.65 .751 .924 r
.3879 .60703 .39646 .61485 .41073 .6107 .40221 .60294 Mtetra
.649 .754 .926 r
.40221 .60294 .41073 .6107 .42507 .60664 .4166 .59883 Mtetra
.663 .757 .92 r
.4166 .59883 .42507 .60664 .43949 .60249 .43108 .5942 Mtetra
.653 .744 .916 r
.43108 .5942 .43949 .60249 .454 .59786 .44563 .58994 Mtetra
.619 .744 .935 r
.44563 .58994 .454 .59786 .46858 .59364 .46023 .58674 Mtetra
.553 .75 .969 r
.46023 .58674 .46858 .59364 .48322 .59029 .47491 .58496 Mtetra
.452 .758 .995 r
.47491 .58496 .48322 .59029 .49795 .58786 .48967 .58427 Mtetra
.409 .791 .991 r
.48967 .58427 .49795 .58786 .51277 .58658 .50456 .58301 Mtetra
.494 .83 .999 r
.50456 .58301 .51277 .58658 .52769 .58503 .51955 .58048 Mtetra
.599 .841 .99 r
.51955 .58048 .52769 .58503 .54272 .58271 .53464 .57657 Mtetra
.68 .817 .949 r
.53464 .57657 .54272 .58271 .55785 .57954 .54981 .57094 Mtetra
.695 .758 .9 r
.54981 .57094 .55785 .57954 .57305 .57567 .56504 .56473 Mtetra
.683 .706 .865 r
.56504 .56473 .57305 .57567 .58834 .57133 .58035 .55877 Mtetra
.667 .673 .846 r
.58035 .55877 .58834 .57133 .60371 .5668 .59574 .5534 Mtetra
.651 .654 .84 r
.59574 .5534 .60371 .5668 .61917 .56223 .61123 .54877 Mtetra
.636 .648 .844 r
.61123 .54877 .61917 .56223 .63471 .55761 .62683 .54489 Mtetra
.624 .655 .86 r
.62683 .54489 .63471 .55761 .65033 .55279 .64255 .5416 Mtetra
.617 .681 .888 r
.64255 .5416 .65033 .55279 .66602 .54751 .65838 .53857 Mtetra
.625 .735 .926 r
.65838 .53857 .66602 .54751 .68176 .54151 .67429 .53497 Mtetra
.663 .814 .956 r
.67429 .53497 .68176 .54151 .69753 .53463 .69021 .52963 Mtetra
.694 .868 .964 r
.69021 .52963 .69753 .53463 .71333 .52696 .70615 .52287 Mtetra
.723 .903 .959 r
.70615 .52287 .71333 .52696 .72917 .519 .72208 .51481 Mtetra
.74 .905 .951 r
.72208 .51481 .72917 .519 .74515 .51219 .73803 .50613 Mtetra
.719 .848 .943 r
.73803 .50613 .74515 .51219 .76127 .50632 .75412 .49855 Mtetra
.685 .793 .932 r
.75412 .49855 .76127 .50632 .77753 .50132 .77038 .49242 Mtetra
.659 .756 .922 r
.77038 .49242 .77753 .50132 .79393 .49675 .7868 .48737 Mtetra
.649 .742 .917 r
.7868 .48737 .79393 .49675 .81038 .49168 .80336 .4827 Mtetra
.661 .757 .921 r
.80336 .4827 .81038 .49168 .82692 .48651 .81997 .47749 Mtetra
.661 .758 .922 r
.81997 .47749 .82692 .48651 .84356 .48143 .83667 .47225 Mtetra
.657 .754 .921 r
.83667 .47225 .84356 .48143 .86033 .47657 .85348 .46712 Mtetra
.65 .746 .919 r
.85348 .46712 .86033 .47657 .8772 .47176 .87042 .46228 Mtetra
.653 .747 .919 r
.87042 .46228 .8772 .47176 .89413 .46662 .88745 .45728 Mtetra
.659 .754 .921 r
.88745 .45728 .89413 .46662 .91116 .46139 .90455 .452 Mtetra
.659 .755 .921 r
.90455 .452 .91116 .46139 .92829 .4562 .92175 .4467 Mtetra
.651 .752 .923 r
.30855 .6205 .31744 .6282 .33137 .62414 .32253 .61642 Mtetra
.654 .753 .922 r
.32253 .61642 .33137 .62414 .34538 .62006 .33659 .61223 Mtetra
.663 .753 .917 r
.33659 .61223 .34538 .62006 .35948 .61572 .35075 .60771 Mtetra
.658 .748 .917 r
.35075 .60771 .35948 .61572 .37366 .61124 .36496 .60335 Mtetra
.651 .751 .923 r
.36496 .60335 .37366 .61124 .3879 .60703 .37924 .59919 Mtetra
.648 .752 .925 r
.37924 .59919 .3879 .60703 .40221 .60294 .3936 .5951 Mtetra
.66 .756 .921 r
.3936 .5951 .40221 .60294 .4166 .59883 .40805 .59058 Mtetra
.658 .747 .916 r
.40805 .59058 .4166 .59883 .43108 .5942 .42257 .58612 Mtetra
.622 .742 .932 r
.42257 .58612 .43108 .5942 .44563 .58994 .43715 .58283 Mtetra
.548 .744 .967 r
.43715 .58283 .44563 .58994 .46023 .58674 .45177 .58121 Mtetra
.427 .741 .992 r
.45177 .58121 .46023 .58674 .47491 .58496 .46647 .58099 Mtetra
.408 .78 .993 r
.46647 .58099 .47491 .58496 .48967 .58427 .4813 .57998 Mtetra
.537 .827 .999 r
.4813 .57998 .48967 .58427 .50456 .58301 .49626 .57717 Mtetra
.676 .824 .954 r
.49626 .57717 .50456 .58301 .51955 .58048 .51133 .57163 Mtetra
.722 .758 .881 r
.51133 .57163 .51955 .58048 .53464 .57657 .52647 .56405 Mtetra
.709 .688 .828 r
.52647 .56405 .53464 .57657 .54981 .57094 .54166 .55612 Mtetra
.694 .652 .804 r
.54166 .55612 .54981 .57094 .56504 .56473 .55691 .54848 Mtetra
.676 .629 .794 r
.55691 .54848 .56504 .56473 .58035 .55877 .57223 .54167 Mtetra
.659 .612 .791 r
.57223 .54167 .58035 .55877 .59574 .5534 .58764 .53591 Mtetra
.642 .6 .792 r
.58764 .53591 .59574 .5534 .61123 .54877 .60314 .53122 Mtetra
.625 .592 .796 r
.60314 .53122 .61123 .54877 .62683 .54489 .61877 .52761 Mtetra
.607 .586 .804 r
.61877 .52761 .62683 .54489 .64255 .5416 .63452 .52506 Mtetra
.592 .587 .817 r
.63452 .52506 .64255 .5416 .65838 .53857 .65042 .52336 Mtetra
.584 .601 .836 r
.65042 .52336 .65838 .53857 .67429 .53497 .66646 .52197 Mtetra
.587 .637 .868 r
.66646 .52197 .67429 .53497 .69021 .52963 .6826 .52025 Mtetra
.628 .73 .92 r
.6826 .52025 .69021 .52963 .70615 .52287 .69875 .51646 Mtetra
.694 .831 .949 r
.69875 .51646 .70615 .52287 .72208 .51481 .71486 .50988 Mtetra
.736 .885 .948 r
.71486 .50988 .72208 .51481 .73803 .50613 .73092 .50145 Mtetra
.755 .897 .941 r
.73092 .50145 .73803 .50613 .75412 .49855 .74699 .49218 Mtetra
.724 .844 .938 r
.74699 .49218 .75412 .49855 .77038 .49242 .76321 .48434 Mtetra
.683 .788 .929 r
.76321 .48434 .77038 .49242 .7868 .48737 .77963 .47819 Mtetra
.654 .751 .921 r
.77963 .47819 .7868 .48737 .80336 .4827 .79623 .47324 Mtetra
.652 .745 .918 r
.79623 .47324 .80336 .4827 .81997 .47749 .81294 .46836 Mtetra
.662 .758 .921 r
.81294 .46836 .81997 .47749 .83667 .47225 .82971 .46302 Mtetra
.66 .756 .921 r
.82971 .46302 .83667 .47225 .85348 .46712 .84658 .45774 Mtetra
.654 .751 .921 r
.84658 .45774 .85348 .46712 .87042 .46228 .86358 .45268 Mtetra
.65 .745 .919 r
.86358 .45268 .87042 .46228 .88745 .45728 .88069 .44777 Mtetra
.657 .752 .92 r
.88069 .44777 .88745 .45728 .90455 .452 .89787 .44251 Mtetra
.659 .755 .921 r
.89787 .44251 .90455 .452 .92175 .4467 .91514 .43713 Mtetra
.652 .752 .923 r
.29959 .61274 .30855 .6205 .32253 .61642 .31361 .60861 Mtetra
.658 .753 .92 r
.31361 .60861 .32253 .61642 .33659 .61223 .32773 .60422 Mtetra
.662 .75 .916 r
.32773 .60422 .33659 .61223 .35075 .60771 .34192 .59967 Mtetra
.653 .749 .92 r
.34192 .59967 .35075 .60771 .36496 .60335 .35618 .59542 Mtetra
.649 .751 .924 r
.35618 .59542 .36496 .60335 .37924 .59919 .3705 .59131 Mtetra
.653 .754 .924 r
.3705 .59131 .37924 .59919 .3936 .5951 .38491 .58702 Mtetra
.664 .753 .917 r
.38491 .58702 .3936 .5951 .40805 .59058 .39942 .58232 Mtetra
.634 .742 .926 r
.39942 .58232 .40805 .59058 .42257 .58612 .41396 .57863 Mtetra
.569 .742 .958 r
.41396 .57863 .42257 .58612 .43715 .58283 .42855 .5766 Mtetra
.429 .722 .987 r
.42855 .5766 .43715 .58283 .45177 .58121 .44318 .57672 Mtetra
.398 .761 .993 r
.44318 .57672 .45177 .58121 .46647 .58099 .45795 .57618 Mtetra
.548 .816 .996 r
.45795 .57618 .46647 .58099 .4813 .57998 .47286 .57343 Mtetra
.709 .811 .928 r
.47286 .57343 .4813 .57998 .49626 .57717 .48792 .56674 Mtetra
.737 .731 .845 r
.48792 .56674 .49626 .57717 .51133 .57163 .50305 .55773 Mtetra
.724 .675 .802 r
.50305 .55773 .51133 .57163 .52647 .56405 .51823 .54811 Mtetra
.706 .645 .786 r
.51823 .54811 .52647 .56405 .54166 .55612 .53345 .53911 Mtetra
.685 .625 .783 r
.53345 .53911 .54166 .55612 .55691 .54848 .54873 .53137 Mtetra
.664 .615 .789 r
.54873 .53137 .55691 .54848 .57223 .54167 .56408 .52518 Mtetra
.652 .616 .801 r
.56408 .52518 .57223 .54167 .58764 .53591 .57952 .51992 Mtetra
.646 .619 .809 r
.57952 .51992 .58764 .53591 .60314 .53122 .59505 .51517 Mtetra
.637 .615 .812 r
.59505 .51517 .60314 .53122 .61877 .52761 .61068 .51094 Mtetra
.619 .6 .809 r
.61068 .51094 .61877 .52761 .63452 .52506 .62643 .50765 Mtetra
.591 .578 .807 r
.62643 .50765 .63452 .52506 .65042 .52336 .64234 .50592 Mtetra
.566 .566 .812 r
.64234 .50592 .65042 .52336 .66646 .52197 .65843 .5055 Mtetra
.551 .57 .827 r
.65843 .5055 .66646 .52197 .6826 .52025 .67468 .50573 Mtetra
.557 .601 .853 r
.67468 .50573 .6826 .52025 .69875 .51646 .69104 .50536 Mtetra
.603 .685 .899 r
.69104 .50536 .69875 .51646 .71486 .50988 .70741 .50263 Mtetra
.698 .813 .936 r
.70741 .50263 .71486 .50988 .73092 .50145 .72366 .4959 Mtetra
.75 .873 .936 r
.72366 .4959 .73092 .50145 .74699 .49218 .73984 .48687 Mtetra
.765 .885 .931 r
.73984 .48687 .74699 .49218 .76321 .48434 .75603 .47714 Mtetra
.715 .823 .932 r
.75603 .47714 .76321 .48434 .77963 .47819 .77243 .46961 Mtetra
.674 .776 .927 r
.77243 .46961 .77963 .47819 .79623 .47324 .78903 .46376 Mtetra
.649 .745 .92 r
.78903 .46376 .79623 .47324 .81294 .46836 .80582 .45896 Mtetra
.658 .752 .919 r
.80582 .45896 .81294 .46836 .82971 .46302 .82268 .45373 Mtetra
.662 .758 .921 r
.82268 .45373 .82971 .46302 .84658 .45774 .83961 .44831 Mtetra
.658 .754 .921 r
.83961 .44831 .84658 .45774 .86358 .45268 .85666 .44302 Mtetra
.65 .747 .92 r
.85666 .44302 .86358 .45268 .88069 .44777 .87385 .43804 Mtetra
.653 .748 .919 r
.87385 .43804 .88069 .44777 .89787 .44251 .89112 .43289 Mtetra
.659 .754 .92 r
.89112 .43289 .89787 .44251 .91514 .43713 .90846 .42746 Mtetra
.653 .752 .923 r
.29053 .60489 .29959 .61274 .31361 .60861 .3046 .60068 Mtetra
.662 .753 .918 r
.3046 .60068 .31361 .60861 .32773 .60422 .31877 .59612 Mtetra
.659 .749 .917 r
.31877 .59612 .32773 .60422 .34192 .59967 .33301 .59166 Mtetra
.651 .751 .923 r
.33301 .59166 .34192 .59967 .35618 .59542 .3473 .58745 Mtetra
.648 .752 .925 r
.3473 .58745 .35618 .59542 .3705 .59131 .36167 .58331 Mtetra
.662 .756 .92 r
.36167 .58331 .3705 .59131 .38491 .58702 .37615 .57865 Mtetra
.652 .745 .918 r
.37615 .57865 .38491 .58702 .39942 .58232 .39068 .57436 Mtetra
.6 .741 .943 r
.39068 .57436 .39942 .58232 .41396 .57863 .40524 .57163 Mtetra
.467 .718 .978 r
.40524 .57163 .41396 .57863 .42855 .5766 .41982 .57146 Mtetra
.376 .732 .99 r
.41982 .57146 .42855 .5766 .44318 .57672 .4345 .5716 Mtetra
.519 .797 .996 r
.4345 .5716 .44318 .57672 .45795 .57618 .44936 .56952 Mtetra
.708 .808 .927 r
.44936 .56952 .45795 .57618 .47286 .57343 .46439 .56288 Mtetra
.749 .732 .836 r
.46439 .56288 .47286 .57343 .48792 .56674 .47954 .55294 Mtetra
.74 .682 .795 r
.47954 .55294 .48792 .56674 .50305 .55773 .49474 .542 Mtetra
.718 .652 .784 r
.49474 .542 .50305 .55773 .51823 .54811 .50995 .53209 Mtetra
.682 .635 .796 r
.50995 .53209 .51823 .54811 .53345 .53911 .52521 .5249 Mtetra
.665 .65 .826 r
.52521 .5249 .53345 .53911 .54873 .53137 .54053 .51929 Mtetra
.658 .681 .861 r
.54053 .51929 .54873 .53137 .56408 .52518 .55593 .51438 Mtetra
.655 .705 .884 r
.55593 .51438 .56408 .52518 .57952 .51992 .57143 .50966 Mtetra
.657 .718 .893 r
.57143 .50966 .57952 .51992 .59505 .51517 .58701 .50486 Mtetra
.658 .718 .893 r
.58701 .50486 .59505 .51517 .61068 .51094 .60268 .49999 Mtetra
.653 .704 .884 r
.60268 .49999 .61068 .51094 .62643 .50765 .61844 .4953 Mtetra
.636 .672 .868 r
.61844 .4953 .62643 .50765 .64234 .50592 .63432 .49132 Mtetra
.601 .621 .843 r
.63432 .49132 .64234 .50592 .65843 .5055 .65035 .48894 Mtetra
.545 .567 .827 r
.65035 .48894 .65843 .5055 .67468 .50573 .66663 .48934 Mtetra
.52 .557 .833 r
.66663 .48934 .67468 .50573 .69104 .50536 .6831 .49081 Mtetra
.534 .591 .858 r
.6831 .49081 .69104 .50536 .70741 .50263 .69967 .4913 Mtetra
.605 .684 .898 r
.69967 .4913 .70741 .50263 .72366 .4959 .71621 .48843 Mtetra
.715 .816 .928 r
.71621 .48843 .72366 .4959 .73984 .48687 .73257 .4809 Mtetra
.766 .868 .923 r
.73257 .4809 .73984 .48687 .75603 .47714 .74884 .47106 Mtetra
.76 .866 .927 r
.74884 .47106 .75603 .47714 .77243 .46961 .76519 .4615 Mtetra
.699 .798 .927 r
.76519 .4615 .77243 .46961 .78903 .46376 .78179 .45457 Mtetra
.66 .759 .923 r
.78179 .45457 .78903 .46376 .80582 .45896 .79861 .44925 Mtetra
.65 .744 .918 r
.79861 .44925 .80582 .45896 .82268 .45373 .81556 .4443 Mtetra
.662 .757 .92 r
.81556 .4443 .82268 .45373 .83961 .44831 .83257 .4388 Mtetra
.66 .756 .921 r
.83257 .4388 .83961 .44831 .85666 .44302 .84968 .43338 Mtetra
.653 .751 .921 r
.84968 .43338 .85666 .44302 .87385 .43804 .86693 .42821 Mtetra
.65 .746 .92 r
.86693 .42821 .87385 .43804 .89112 .43289 .88429 .42314 Mtetra
.658 .753 .92 r
.88429 .42314 .89112 .43289 .90846 .42746 .90171 .41769 Mtetra
.655 .752 .921 r
.28138 .59696 .29053 .60489 .3046 .60068 .29551 .59262 Mtetra
.663 .752 .916 r
.29551 .59262 .3046 .60068 .31877 .59612 .30972 .58797 Mtetra
.655 .749 .919 r
.30972 .58797 .31877 .59612 .33301 .59166 .324 .58359 Mtetra
.649 .751 .924 r
.324 .58359 .33301 .59166 .3473 .58745 .33834 .57941 Mtetra
.651 .753 .924 r
.33834 .57941 .3473 .58745 .36167 .58331 .35276 .57512 Mtetra
.664 .754 .917 r
.35276 .57512 .36167 .58331 .37615 .57865 .36729 .57033 Mtetra
.63 .742 .928 r
.36729 .57033 .37615 .57865 .39068 .57436 .38184 .56672 Mtetra
.54 .73 .963 r
.38184 .56672 .39068 .57436 .40524 .57163 .3964 .56533 Mtetra
.387 .704 .984 r
.3964 .56533 .40524 .57163 .41982 .57146 .41099 .56601 Mtetra
.453 .761 .995 r
.41099 .56601 .41982 .57146 .4345 .5716 .42575 .56516 Mtetra
.664 .806 .951 r
.42575 .56516 .4345 .5716 .44936 .56952 .44074 .56005 Mtetra
.759 .754 .849 r
.44074 .56005 .44936 .56952 .46439 .56288 .4559 .54994 Mtetra
.756 .699 .797 r
.4559 .54994 .46439 .56288 .47954 .55294 .47113 .53807 Mtetra
.733 .668 .787 r
.47113 .53807 .47954 .55294 .49474 .542 .48636 .52724 Mtetra
.685 .651 .811 r
.48636 .52724 .49474 .542 .50995 .53209 .50159 .52023 Mtetra
.661 .686 .863 r
.50159 .52023 .50995 .53209 .52521 .5249 .51689 .51517 Mtetra
.629 .718 .911 r
.51689 .51517 .52521 .5249 .54053 .51929 .53227 .51148 Mtetra
.621 .763 .948 r
.53227 .51148 .54053 .51929 .55593 .51438 .54775 .50778 Mtetra
.627 .8 .965 r
.54775 .50778 .55593 .51438 .57143 .50966 .56331 .50358 Mtetra
.643 .821 .968 r
.56331 .50358 .57143 .50966 .58701 .50486 .57897 .49874 Mtetra
.664 .827 .962 r
.57897 .49874 .58701 .50486 .60268 .49999 .5947 .49325 Mtetra
.681 .816 .947 r
.5947 .49325 .60268 .49999 .61844 .4953 .61049 .48724 Mtetra
.683 .783 .926 r
.61049 .48724 .61844 .4953 .63432 .49132 .62637 .48122 Mtetra
.649 .725 .904 r
.62637 .48122 .63432 .49132 .65035 .48894 .64238 .47659 Mtetra
.603 .662 .88 r
.64238 .47659 .65035 .48894 .66663 .48934 .65857 .47393 Mtetra
.518 .571 .848 r
.65857 .47393 .66663 .48934 .6831 .49081 .67505 .47517 Mtetra
.492 .554 .847 r
.67505 .47517 .6831 .49081 .69967 .4913 .69174 .47751 Mtetra
.525 .602 .873 r
.69174 .47751 .69967 .4913 .71621 .48843 .70851 .47809 Mtetra
.643 .724 .907 r
.70851 .47809 .71621 .48843 .73257 .4809 .72512 .47356 Mtetra
.744 .83 .917 r
.72512 .47356 .73257 .4809 .74884 .47106 .74155 .46463 Mtetra
.777 .862 .912 r
.74155 .46463 .74884 .47106 .76519 .4615 .75792 .45411 Mtetra
.732 .829 .925 r
.75792 .45411 .76519 .4615 .78179 .45457 .7745 .4457 Mtetra
.678 .776 .924 r
.7745 .4457 .78179 .45457 .79861 .44925 .79133 .43957 Mtetra
.648 .746 .921 r
.79133 .43957 .79861 .44925 .81556 .4443 .80836 .43465 Mtetra
.66 .753 .919 r
.80836 .43465 .81556 .4443 .83257 .4388 .82545 .42921 Mtetra
.662 .757 .92 r
.82545 .42921 .83257 .4388 .84968 .43338 .84263 .42365 Mtetra
.656 .753 .921 r
.84263 .42365 .84968 .43338 .86693 .42821 .85993 .41829 Mtetra
.649 .746 .921 r
.85993 .41829 .86693 .42821 .88429 .42314 .87737 .4132 Mtetra
.656 .75 .919 r
.87737 .4132 .88429 .42314 .90171 .41769 .89489 .40779 Mtetra
.658 .753 .92 r
.27215 .58893 .28138 .59696 .29551 .59262 .28632 .58444 Mtetra
.662 .751 .916 r
.28632 .58444 .29551 .59262 .30972 .58797 .30058 .57979 Mtetra
.653 .75 .921 r
.30058 .57979 .30972 .58797 .324 .58359 .3149 .57546 Mtetra
.648 .751 .924 r
.3149 .57546 .324 .58359 .33834 .57941 .32928 .57126 Mtetra
.658 .754 .921 r
.32928 .57126 .33834 .57941 .35276 .57512 .34377 .56669 Mtetra
.657 .748 .917 r
.34377 .56669 .35276 .57512 .36729 .57033 .35833 .56212 Mtetra
.604 .739 .94 r
.35833 .56212 .36729 .57033 .38184 .56672 .3729 .55924 Mtetra
.463 .706 .973 r
.3729 .55924 .38184 .56672 .3964 .56533 .38744 .55924 Mtetra
.387 .712 .987 r
.38744 .55924 .3964 .56533 .41099 .56601 .40208 .55972 Mtetra
.56 .78 .981 r
.40208 .55972 .41099 .56601 .42575 .56516 .41695 .55727 Mtetra
.748 .786 .884 r
.41695 .55727 .42575 .56516 .44074 .56005 .43209 .54847 Mtetra
.768 .722 .809 r
.43209 .54847 .44074 .56005 .4559 .54994 .44735 .53631 Mtetra
.755 .691 .791 r
.44735 .53631 .4559 .54994 .47113 .53807 .46263 .52414 Mtetra
.701 .669 .816 r
.46263 .52414 .47113 .53807 .48636 .52724 .47787 .51622 Mtetra
.657 .701 .879 r
.47787 .51622 .48636 .52724 .50159 .52023 .49313 .5114 Mtetra
.6 .73 .936 r
.49313 .5114 .50159 .52023 .51689 .51517 .50847 .50852 Mtetra
.581 .783 .975 r
.50847 .50852 .51689 .51517 .53227 .51148 .52392 .50554 Mtetra
.615 .816 .977 r
.52392 .50554 .53227 .51148 .54775 .50778 .53946 .50142 Mtetra
.635 .811 .968 r
.53946 .50142 .54775 .50778 .56331 .50358 .5551 .49686 Mtetra
.648 .806 .959 r
.5551 .49686 .56331 .50358 .57897 .49874 .57082 .49196 Mtetra
.657 .809 .956 r
.57082 .49196 .57897 .49874 .5947 .49325 .58662 .48674 Mtetra
.669 .821 .957 r
.58662 .48674 .5947 .49325 .61049 .48724 .60251 .48107 Mtetra
.699 .839 .95 r
.60251 .48107 .61049 .48724 .62637 .48122 .61844 .47424 Mtetra
.703 .82 .937 r
.61844 .47424 .62637 .48122 .64238 .47659 .63445 .4673 Mtetra
.655 .748 .919 r
.63445 .4673 .64238 .47659 .65857 .47393 .65061 .46232 Mtetra
.577 .667 .9 r
.65061 .46232 .65857 .47393 .67505 .47517 .66699 .46049 Mtetra
.476 .561 .863 r
.66699 .46049 .67505 .47517 .69174 .47751 .68372 .46301 Mtetra
.473 .564 .867 r
.68372 .46301 .69174 .47751 .70851 .47809 .70062 .46557 Mtetra
.553 .642 .892 r
.70062 .46557 .70851 .47809 .72512 .47356 .7175 .46472 Mtetra
.707 .785 .912 r
.7175 .46472 .72512 .47356 .74155 .46463 .73411 .45734 Mtetra
.772 .841 .904 r
.73411 .45734 .74155 .46463 .75792 .45411 .75059 .44693 Mtetra
.763 .844 .912 r
.75059 .44693 .75792 .45411 .7745 .4457 .76714 .43697 Mtetra
.696 .788 .922 r
.76714 .43697 .7745 .4457 .79133 .43957 .78399 .42998 Mtetra
.654 .754 .923 r
.78399 .42998 .79133 .43957 .80836 .43465 .80107 .42473 Mtetra
.654 .747 .918 r
.80107 .42473 .80836 .43465 .82545 .42921 .81825 .41949 Mtetra
.663 .756 .92 r
.81825 .41949 .82545 .42921 .84263 .42365 .8355 .41383 Mtetra
.659 .754 .92 r
.8355 .41383 .84263 .42365 .85993 .41829 .85287 .40831 Mtetra
.65 .748 .921 r
.85287 .40831 .85993 .41829 .87737 .4132 .87038 .40313 Mtetra
.654 .749 .92 r
.87038 .40313 .87737 .4132 .89489 .40779 .88798 .39777 Mtetra
.661 .753 .919 r
.26282 .58081 .27215 .58893 .28632 .58444 .27705 .57619 Mtetra
.66 .751 .917 r
.27705 .57619 .28632 .58444 .30058 .57979 .29135 .57157 Mtetra
.651 .75 .922 r
.29135 .57157 .30058 .57979 .3149 .57546 .30571 .56724 Mtetra
.648 .751 .925 r
.30571 .56724 .3149 .57546 .32928 .57126 .32014 .56301 Mtetra
.663 .755 .919 r
.32014 .56301 .32928 .57126 .34377 .56669 .33468 .55822 Mtetra
.646 .746 .922 r
.33468 .55822 .34377 .56669 .35833 .56212 .34927 .55401 Mtetra
.576 .734 .95 r
.34927 .55401 .35833 .56212 .3729 .55924 .36385 .5518 Mtetra
.405 .683 .975 r
.36385 .5518 .3729 .55924 .38744 .55924 .37839 .55271 Mtetra
.442 .727 .987 r
.37839 .55271 .38744 .55924 .40208 .55972 .39311 .55252 Mtetra
.66 .787 .942 r
.39311 .55252 .40208 .55972 .41695 .55727 .40811 .54759 Mtetra
.77 .754 .839 r
.40811 .54759 .41695 .55727 .43209 .54847 .42338 .53648 Mtetra
.777 .719 .798 r
.42338 .53648 .43209 .54847 .44735 .53631 .43873 .52322 Mtetra
.738 .694 .809 r
.43873 .52322 .44735 .53631 .46263 .52414 .45402 .51288 Mtetra
.676 .704 .868 r
.45402 .51288 .46263 .52414 .47787 .51622 .46927 .50708 Mtetra
.593 .721 .933 r
.46927 .50708 .47787 .51622 .49313 .5114 .48456 .50445 Mtetra
.569 .771 .974 r
.48456 .50445 .49313 .5114 .50847 .50852 .49996 .50182 Mtetra
.617 .796 .968 r
.49996 .50182 .50847 .50852 .52392 .50554 .51547 .49786 Mtetra
.645 .779 .945 r
.51547 .49786 .52392 .50554 .53946 .50142 .53107 .49325 Mtetra
.657 .771 .934 r
.53107 .49325 .53946 .50142 .5551 .49686 .54677 .48825 Mtetra
.655 .762 .928 r
.54677 .48825 .5551 .49686 .57082 .49196 .56255 .48331 Mtetra
.653 .761 .929 r
.56255 .48331 .57082 .49196 .58662 .48674 .57843 .47842 Mtetra
.662 .773 .932 r
.57843 .47842 .58662 .48674 .60251 .48107 .59439 .47314 Mtetra
.678 .789 .933 r
.59439 .47314 .60251 .48107 .61844 .47424 .61042 .46721 Mtetra
.711 .823 .934 r
.61042 .46721 .61844 .47424 .63445 .4673 .62649 .45991 Mtetra
.71 .815 .93 r
.62649 .45991 .63445 .4673 .65061 .46232 .64264 .45261 Mtetra
.63 .733 .922 r
.64264 .45261 .65061 .46232 .66699 .46049 .65899 .44851 Mtetra
.506 .628 .906 r
.65899 .44851 .66699 .46049 .68372 .46301 .67567 .44906 Mtetra
.433 .553 .877 r
.67567 .44906 .68372 .46301 .70062 .46557 .69265 .45262 Mtetra
.489 .603 .893 r
.69265 .45262 .70062 .46557 .7175 .46472 .7097 .45402 Mtetra
.649 .725 .904 r
.7097 .45402 .7175 .46472 .73411 .45734 .72653 .44909 Mtetra
.756 .816 .9 r
.72653 .44909 .73411 .45734 .75059 .44693 .74314 .43927 Mtetra
.779 .837 .896 r
.74314 .43927 .75059 .44693 .76714 .43697 .75971 .42828 Mtetra
.713 .797 .917 r
.75971 .42828 .76714 .43697 .78399 .42998 .77658 .42048 Mtetra
.664 .762 .923 r
.77658 .42048 .78399 .42998 .80107 .42473 .7937 .41476 Mtetra
.65 .746 .92 r
.7937 .41476 .80107 .42473 .81825 .41949 .81097 .40963 Mtetra
.663 .756 .919 r
.81097 .40963 .81825 .41949 .8355 .41383 .82829 .4039 Mtetra
.66 .754 .92 r
.82829 .4039 .8355 .41383 .85287 .40831 .84573 .39828 Mtetra
.652 .75 .922 r
.84573 .39828 .85287 .40831 .87038 .40313 .86331 .39296 Mtetra
.651 .748 .92 r
.86331 .39296 .87038 .40313 .88798 .39777 .88099 .38762 Mtetra
.662 .753 .918 r
.2534 .5726 .26282 .58081 .27705 .57619 .26768 .56788 Mtetra
.659 .751 .918 r
.26768 .56788 .27705 .57619 .29135 .57157 .28202 .56327 Mtetra
.65 .75 .923 r
.28202 .56327 .29135 .57157 .30571 .56724 .29642 .55894 Mtetra
.648 .751 .924 r
.29642 .55894 .30571 .56724 .32014 .56301 .31091 .55464 Mtetra
.665 .755 .917 r
.31091 .55464 .32014 .56301 .33468 .55822 .3255 .54972 Mtetra
.634 .744 .928 r
.3255 .54972 .33468 .55822 .34927 .55401 .34012 .54585 Mtetra
.538 .721 .958 r
.34012 .54585 .34927 .55401 .36385 .5518 .3547 .54451 Mtetra
.385 .68 .976 r
.3547 .54451 .36385 .5518 .37839 .55271 .36927 .54557 Mtetra
.502 .738 .979 r
.36927 .54557 .37839 .55271 .39311 .55252 .38406 .54455 Mtetra
.717 .782 .903 r
.38406 .54455 .39311 .55252 .40811 .54759 .3992 .53726 Mtetra
.782 .746 .82 r
.3992 .53726 .40811 .54759 .42338 .53648 .41458 .5247 Mtetra
.779 .724 .801 r
.41458 .5247 .42338 .53648 .43873 .52322 .43 .51134 Mtetra
.716 .707 .841 r
.43 .51134 .43873 .52322 .45402 .51288 .44529 .50313 Mtetra
.631 .722 .913 r
.44529 .50313 .45402 .51288 .46927 .50708 .46056 .49926 Mtetra
.551 .742 .965 r
.46056 .49926 .46927 .50708 .48456 .50445 .4759 .49733 Mtetra
.607 .782 .965 r
.4759 .49733 .48456 .50445 .49996 .50182 .49136 .49372 Mtetra
.649 .771 .938 r
.49136 .49372 .49996 .50182 .51547 .49786 .50693 .48901 Mtetra
.663 .758 .921 r
.50693 .48901 .51547 .49786 .53107 .49325 .5226 .4838 Mtetra
.657 .743 .913 r
.5226 .4838 .53107 .49325 .54677 .48825 .53835 .4788 Mtetra
.656 .744 .914 r
.53835 .4788 .54677 .48825 .56255 .48331 .55419 .4738 Mtetra
.655 .744 .915 r
.55419 .4738 .56255 .48331 .57843 .47842 .57012 .46881 Mtetra
.649 .741 .916 r
.57012 .46881 .57843 .47842 .59439 .47314 .58615 .46403 Mtetra
.661 .757 .921 r
.58615 .46403 .59439 .47314 .61042 .46721 .60226 .45875 Mtetra
.688 .783 .923 r
.60226 .45875 .61042 .46721 .62649 .45991 .61844 .45234 Mtetra
.727 .816 .92 r
.61844 .45234 .62649 .45991 .64264 .45261 .63464 .44422 Mtetra
.68 .785 .929 r
.63464 .44422 .64264 .45261 .65899 .44851 .65098 .43806 Mtetra
.562 .691 .927 r
.65098 .43806 .65899 .44851 .67567 .44906 .6676 .43632 Mtetra
.41 .566 .897 r
.6676 .43632 .67567 .44906 .69265 .45262 .68462 .43987 Mtetra
.438 .582 .899 r
.68462 .43987 .69265 .45262 .7097 .45402 .70178 .44265 Mtetra
.59 .688 .909 r
.70178 .44265 .7097 .45402 .72653 .44909 .71881 .44003 Mtetra
.738 .795 .898 r
.71881 .44003 .72653 .44909 .74314 .43927 .73556 .43097 Mtetra
.779 .824 .887 r
.73556 .43097 .74314 .43927 .75971 .42828 .75221 .41971 Mtetra
.733 .808 .911 r
.75221 .41971 .75971 .42828 .77658 .42048 .76909 .41092 Mtetra
.674 .767 .92 r
.76909 .41092 .77658 .42048 .7937 .41476 .78625 .40473 Mtetra
.647 .747 .922 r
.78625 .40473 .7937 .41476 .81097 .40963 .8036 .39963 Mtetra
.662 .755 .919 r
.8036 .39963 .81097 .40963 .82829 .4039 .821 .39386 Mtetra
.661 .755 .92 r
.821 .39386 .82829 .4039 .84573 .39828 .83851 .38813 Mtetra
.653 .751 .921 r
.83851 .38813 .84573 .39828 .86331 .39296 .85616 .38269 Mtetra
.65 .748 .921 r
.85616 .38269 .86331 .39296 .88099 .38762 .87393 .37734 Mtetra
.663 .753 .917 r
.24388 .56429 .2534 .5726 .26768 .56788 .25821 .5595 Mtetra
.657 .751 .919 r
.25821 .5595 .26768 .56788 .28202 .56327 .2726 .55489 Mtetra
.649 .75 .923 r
.2726 .55489 .28202 .56327 .29642 .55894 .28705 .55053 Mtetra
.649 .751 .924 r
.28705 .55053 .29642 .55894 .31091 .55464 .30158 .54616 Mtetra
.665 .754 .916 r
.30158 .54616 .31091 .55464 .3255 .54972 .31623 .54118 Mtetra
.625 .743 .931 r
.31623 .54118 .3255 .54972 .34012 .54585 .33087 .53756 Mtetra
.51 .709 .961 r
.33087 .53756 .34012 .54585 .3547 .54451 .34546 .53679 Mtetra
.398 .677 .973 r
.34546 .53679 .3547 .54451 .36927 .54557 .36007 .53781 Mtetra
.545 .739 .966 r
.36007 .53781 .36927 .54557 .38406 .54455 .37494 .53605 Mtetra
.745 .777 .878 r
.37494 .53605 .38406 .54455 .3992 .53726 .39021 .52712 Mtetra
.792 .752 .816 r
.39021 .52712 .3992 .53726 .41458 .5247 .40568 .51368 Mtetra
.779 .737 .814 r
.40568 .51368 .41458 .5247 .43 .51134 .42114 .50094 Mtetra
.7 .731 .874 r
.42114 .50094 .43 .51134 .44529 .50313 .43646 .49401 Mtetra
.59 .724 .937 r
.43646 .49401 .44529 .50313 .46056 .49926 .45175 .49136 Mtetra
.566 .748 .962 r
.45175 .49136 .46056 .49926 .4759 .49733 .46715 .48902 Mtetra
.63 .76 .941 r
.46715 .48902 .4759 .49733 .49136 .49372 .48267 .48491 Mtetra
.665 .76 .921 r
.48267 .48491 .49136 .49372 .50693 .48901 .49831 .4796 Mtetra
.646 .741 .919 r
.49831 .4796 .50693 .48901 .5226 .4838 .51403 .47501 Mtetra
.635 .754 .934 r
.51403 .47501 .5226 .4838 .53835 .4788 .52984 .47074 Mtetra
.654 .779 .941 r
.52984 .47074 .53835 .4788 .55419 .4738 .54575 .46569 Mtetra
.674 .785 .933 r
.54575 .46569 .55419 .4738 .57012 .46881 .56174 .45986 Mtetra
.666 .764 .923 r
.56174 .45986 .57012 .46881 .58615 .46403 .57782 .45435 Mtetra
.647 .742 .918 r
.57782 .45435 .58615 .46403 .60226 .45875 .59401 .44956 Mtetra
.677 .764 .917 r
.59401 .44956 .60226 .45875 .61844 .45234 .61026 .44356 Mtetra
.717 .787 .907 r
.61026 .44356 .61844 .45234 .63464 .44422 .62655 .43576 Mtetra
.711 .794 .916 r
.62655 .43576 .63464 .44422 .65098 .43806 .64292 .42825 Mtetra
.599 .724 .932 r
.64292 .42825 .65098 .43806 .6676 .43632 .65954 .42509 Mtetra
.406 .598 .924 r
.65954 .42509 .6676 .43632 .68462 .43987 .67656 .4279 Mtetra
.392 .575 .912 r
.67656 .4279 .68462 .43987 .70178 .44265 .69381 .43145 Mtetra
.541 .671 .922 r
.69381 .43145 .70178 .44265 .71881 .44003 .71099 .43042 Mtetra
.722 .78 .898 r
.71099 .43042 .71881 .44003 .73556 .43097 .72785 .422 Mtetra
.776 .81 .88 r
.72785 .422 .73556 .43097 .75221 .41971 .7446 .41069 Mtetra
.744 .803 .899 r
.7446 .41069 .75221 .41971 .76909 .41092 .76151 .40119 Mtetra
.681 .768 .917 r
.76151 .40119 .76909 .41092 .78625 .40473 .77872 .39463 Mtetra
.647 .748 .923 r
.77872 .39463 .78625 .40473 .8036 .39963 .79615 .38948 Mtetra
.662 .754 .919 r
.79615 .38948 .8036 .39963 .821 .39386 .81363 .38369 Mtetra
.662 .755 .919 r
.81363 .38369 .821 .39386 .83851 .38813 .83121 .37787 Mtetra
.654 .751 .921 r
.83121 .37787 .83851 .38813 .85616 .38269 .84893 .37232 Mtetra
.649 .748 .922 r
.84893 .37232 .85616 .38269 .87393 .37734 .86679 .36695 Mtetra
.663 .753 .917 r
.23427 .55591 .24388 .56429 .25821 .5595 .24865 .55105 Mtetra
.657 .751 .92 r
.24865 .55105 .25821 .5595 .2726 .55489 .26308 .54641 Mtetra
.649 .75 .923 r
.26308 .54641 .2726 .55489 .28705 .55053 .27757 .54203 Mtetra
.651 .751 .923 r
.27757 .54203 .28705 .55053 .30158 .54616 .29216 .53755 Mtetra
.664 .753 .916 r
.29216 .53755 .30158 .54616 .31623 .54118 .30685 .53256 Mtetra
.62 .741 .933 r
.30685 .53256 .31623 .54118 .33087 .53756 .32154 .52906 Mtetra
.498 .701 .96 r
.32154 .52906 .33087 .53756 .34546 .53679 .33614 .52855 Mtetra
.415 .672 .967 r
.33614 .52855 .34546 .53679 .36007 .53781 .35079 .52948 Mtetra
.568 .735 .954 r
.35079 .52948 .36007 .53781 .37494 .53605 .36573 .52728 Mtetra
.757 .774 .867 r
.36573 .52728 .37494 .53605 .39021 .52712 .38109 .51749 Mtetra
.8 .763 .819 r
.38109 .51749 .39021 .52712 .40568 .51368 .39666 .50365 Mtetra
.781 .756 .83 r
.39666 .50365 .40568 .51368 .42114 .50094 .41217 .49141 Mtetra
.691 .748 .895 r
.41217 .49141 .42114 .50094 .43646 .49401 .42753 .48502 Mtetra
.568 .721 .945 r
.42753 .48502 .43646 .49401 .45175 .49136 .44286 .4829 Mtetra
.584 .742 .951 r
.44286 .4829 .45175 .49136 .46715 .48902 .45831 .48018 Mtetra
.643 .754 .929 r
.45831 .48018 .46715 .48902 .48267 .48491 .4739 .47565 Mtetra
.664 .752 .915 r
.4739 .47565 .48267 .48491 .49831 .4796 .48959 .47032 Mtetra
.623 .739 .93 r
.48959 .47032 .49831 .4796 .51403 .47501 .50536 .46647 Mtetra
.616 .756 .945 r
.50536 .46647 .51403 .47501 .52984 .47074 .52123 .46268 Mtetra
.653 .782 .942 r
.52123 .46268 .52984 .47074 .54575 .46569 .53721 .45758 Mtetra
.688 .792 .929 r
.53721 .45758 .54575 .46569 .56174 .45986 .55326 .45116 Mtetra
.686 .778 .921 r
.55326 .45116 .56174 .45986 .57782 .45435 .5694 .4448 Mtetra
.648 .747 .922 r
.5694 .4448 .57782 .45435 .59401 .44956 .58565 .43992 Mtetra
.667 .753 .914 r
.58565 .43992 .59401 .44956 .61026 .44356 .60198 .43424 Mtetra
.709 .775 .904 r
.60198 .43424 .61026 .44356 .62655 .43576 .61835 .4267 Mtetra
.722 .786 .903 r
.61835 .4267 .62655 .43576 .64292 .42825 .63477 .41855 Mtetra
.616 .736 .932 r
.63477 .41855 .64292 .42825 .65954 .42509 .65143 .41474 Mtetra
.409 .623 .94 r
.65143 .41474 .65954 .42509 .67656 .4279 .66847 .41692 Mtetra
.352 .577 .926 r
.66847 .41692 .67656 .4279 .69381 .43145 .68578 .42077 Mtetra
.508 .669 .936 r
.68578 .42077 .69381 .43145 .71099 .43042 .70306 .42051 Mtetra
.714 .774 .9 r
.70306 .42051 .71099 .43042 .72785 .422 .72003 .41244 Mtetra
.772 .799 .875 r
.72003 .41244 .72785 .422 .7446 .41069 .73686 .40111 Mtetra
.748 .794 .89 r
.73686 .40111 .7446 .41069 .76151 .40119 .75384 .39122 Mtetra
.685 .766 .913 r
.75384 .39122 .76151 .40119 .77872 .39463 .77112 .38444 Mtetra
.648 .748 .923 r
.77112 .38444 .77872 .39463 .79615 .38948 .78861 .37919 Mtetra
.66 .753 .918 r
.78861 .37919 .79615 .38948 .81363 .38369 .80617 .37339 Mtetra
.662 .754 .919 r
.80617 .37339 .81363 .38369 .83121 .37787 .82383 .36749 Mtetra
.655 .751 .921 r
.82383 .36749 .83121 .37787 .84893 .37232 .84163 .36185 Mtetra
.649 .748 .922 r
.84163 .36185 .84893 .37232 .86679 .36695 .85956 .35643 Mtetra
.663 .753 .917 r
.22456 .54743 .23427 .55591 .24865 .55105 .23898 .54253 Mtetra
.657 .752 .92 r
.23898 .54253 .24865 .55105 .26308 .54641 .25346 .53784 Mtetra
.649 .75 .923 r
.25346 .53784 .26308 .54641 .27757 .54203 .26801 .53341 Mtetra
.651 .75 .922 r
.26801 .53341 .27757 .54203 .29216 .53755 .28264 .52889 Mtetra
.664 .754 .917 r
.28264 .52889 .29216 .53755 .30685 .53256 .29738 .52385 Mtetra
.62 .741 .933 r
.29738 .52385 .30685 .53256 .32154 .52906 .31211 .5203 Mtetra
.501 .698 .957 r
.31211 .5203 .32154 .52906 .33614 .52855 .32676 .51976 Mtetra
.428 .666 .961 r
.32676 .51976 .33614 .52855 .35079 .52948 .34144 .52065 Mtetra
.572 .726 .947 r
.34144 .52065 .35079 .52948 .36573 .52728 .35642 .51841 Mtetra
.757 .774 .867 r
.35642 .51841 .36573 .52728 .38109 .51749 .37185 .50855 Mtetra
.806 .778 .826 r
.37185 .50855 .38109 .51749 .39666 .50365 .3875 .49464 Mtetra
.789 .777 .842 r
.3875 .49464 .39666 .50365 .41217 .49141 .40309 .48233 Mtetra
.693 .76 .904 r
.40309 .48233 .41217 .49141 .42753 .48502 .41851 .47588 Mtetra
.568 .72 .944 r
.41851 .47588 .42753 .48502 .44286 .4829 .43388 .47371 Mtetra
.589 .728 .94 r
.43388 .47371 .44286 .4829 .45831 .48018 .44938 .47095 Mtetra
.644 .747 .924 r
.44938 .47095 .45831 .48018 .4739 .47565 .46503 .46637 Mtetra
.664 .753 .917 r
.46503 .46637 .4739 .47565 .48959 .47032 .48078 .46099 Mtetra
.623 .74 .931 r
.48078 .46099 .48959 .47032 .50536 .46647 .49661 .45708 Mtetra
.62 .739 .932 r
.49661 .45708 .50536 .46647 .52123 .46268 .51254 .45324 Mtetra
.656 .751 .92 r
.51254 .45324 .52123 .46268 .53721 .45758 .52857 .44809 Mtetra
.687 .761 .908 r
.52857 .44809 .53721 .45758 .55326 .45116 .54469 .4416 Mtetra
.685 .76 .909 r
.54469 .4416 .55326 .45116 .5694 .4448 .56089 .43519 Mtetra
.648 .748 .923 r
.56089 .43519 .5694 .4448 .58565 .43992 .5772 .43025 Mtetra
.667 .755 .916 r
.5772 .43025 .58565 .43992 .60198 .43424 .5936 .42451 Mtetra
.708 .768 .899 r
.5936 .42451 .60198 .43424 .61835 .4267 .61004 .41691 Mtetra
.72 .771 .893 r
.61004 .41691 .61835 .4267 .63477 .41855 .62653 .4087 Mtetra
.616 .735 .931 r
.62653 .4087 .63477 .41855 .65143 .41474 .64326 .40483 Mtetra
.396 .63 .948 r
.64326 .40483 .65143 .41474 .66847 .41692 .66035 .40697 Mtetra
.319 .586 .939 r
.66035 .40697 .66847 .41692 .68578 .42077 .6777 .41078 Mtetra
.497 .683 .949 r
.6777 .41078 .68578 .42077 .70306 .42051 .69505 .41047 Mtetra
.714 .773 .899 r
.69505 .41047 .70306 .42051 .72003 .41244 .71209 .40233 Mtetra
.77 .789 .869 r
.71209 .40233 .72003 .41244 .73686 .40111 .72901 .39093 Mtetra
.746 .783 .883 r
.72901 .39093 .73686 .40111 .75384 .39122 .74607 .38097 Mtetra
.685 .763 .911 r
.74607 .38097 .75384 .39122 .77112 .38444 .76342 .37412 Mtetra
.648 .748 .923 r
.76342 .37412 .77112 .38444 .78861 .37919 .78099 .36881 Mtetra
.66 .753 .919 r
.78099 .36881 .78861 .37919 .80617 .37339 .79863 .36295 Mtetra
.662 .754 .918 r
.79863 .36295 .80617 .37339 .82383 .36749 .81637 .35699 Mtetra
.655 .751 .92 r
.81637 .35699 .82383 .36749 .84163 .36185 .83424 .35128 Mtetra
.649 .748 .922 r
.83424 .35128 .84163 .36185 .85956 .35643 .85225 .34579 Mtetra
.663 .753 .917 r
.21475 .53887 .22456 .54743 .23898 .54253 .22922 .53393 Mtetra
.657 .752 .92 r
.22922 .53393 .23898 .54253 .25346 .53784 .24375 .52918 Mtetra
.649 .75 .923 r
.24375 .52918 .25346 .53784 .26801 .53341 .25834 .52469 Mtetra
.649 .749 .923 r
.25834 .52469 .26801 .53341 .28264 .52889 .27301 .52017 Mtetra
.665 .754 .917 r
.27301 .52017 .28264 .52889 .29738 .52385 .28781 .51504 Mtetra
.625 .743 .932 r
.28781 .51504 .29738 .52385 .31211 .5203 .3026 .51128 Mtetra
.518 .701 .953 r
.3026 .51128 .31211 .5203 .32676 .51976 .3173 .5104 Mtetra
.436 .657 .954 r
.3173 .5104 .32676 .51976 .34144 .52065 .33201 .51131 Mtetra
.56 .712 .942 r
.33201 .51131 .34144 .52065 .35642 .51841 .34701 .50942 Mtetra
.744 .772 .875 r
.34701 .50942 .35642 .51841 .37185 .50855 .36248 .5003 Mtetra
.809 .793 .837 r
.36248 .5003 .37185 .50855 .3875 .49464 .37819 .48665 Mtetra
.804 .8 .848 r
.37819 .48665 .3875 .49464 .40309 .48233 .39389 .47369 Mtetra
.707 .776 .906 r
.39389 .47369 .40309 .48233 .41851 .47588 .40939 .46659 Mtetra
.589 .727 .939 r
.40939 .46659 .41851 .47588 .43388 .47371 .42483 .46381 Mtetra
.582 .711 .931 r
.42483 .46381 .43388 .47371 .44938 .47095 .44037 .46132 Mtetra
.634 .737 .922 r
.44037 .46132 .44938 .47095 .46503 .46637 .45606 .45706 Mtetra
.665 .756 .918 r
.45606 .45706 .46503 .46637 .48078 .46099 .47187 .45158 Mtetra
.645 .748 .924 r
.47187 .45158 .48078 .46099 .49661 .45708 .48776 .44684 Mtetra
.637 .728 .914 r
.48776 .44684 .49661 .45708 .51254 .45324 .50375 .44241 Mtetra
.656 .723 .898 r
.50375 .44241 .51254 .45324 .52857 .44809 .51984 .43719 Mtetra
.673 .729 .892 r
.51984 .43719 .52857 .44809 .54469 .4416 .53602 .43119 Mtetra
.666 .738 .904 r
.53602 .43119 .54469 .4416 .56089 .43519 .55229 .42551 Mtetra
.647 .749 .924 r
.55229 .42551 .56089 .43519 .5772 .43025 .56867 .42056 Mtetra
.677 .76 .914 r
.56867 .42056 .5772 .43025 .5936 .42451 .58512 .41437 Mtetra
.713 .763 .891 r
.58512 .41437 .5936 .42451 .61004 .41691 .60162 .40638 Mtetra
.706 .754 .889 r
.60162 .40638 .61004 .41691 .62653 .4087 .6182 .39868 Mtetra
.598 .727 .934 r
.6182 .39868 .62653 .4087 .64326 .40483 .63501 .39536 Mtetra
.353 .62 .952 r
.63501 .39536 .64326 .40483 .66035 .40697 .65218 .39805 Mtetra
.298 .603 .951 r
.65218 .39805 .66035 .40697 .6777 .41078 .66958 .40149 Mtetra
.516 .712 .961 r
.66958 .40149 .6777 .41078 .69505 .41047 .68694 .40031 Mtetra
.722 .775 .895 r
.68694 .40031 .69505 .41047 .71209 .40233 .70404 .39169 Mtetra
.768 .78 .863 r
.70404 .39169 .71209 .40233 .72901 .39093 .72104 .38015 Mtetra
.738 .771 .879 r
.72104 .38015 .72901 .39093 .74607 .38097 .7382 .37044 Mtetra
.681 .757 .909 r
.7382 .37044 .74607 .38097 .76342 .37412 .75564 .36368 Mtetra
.647 .748 .923 r
.75564 .36368 .76342 .37412 .78099 .36881 .77329 .35834 Mtetra
.662 .754 .919 r
.77329 .35834 .78099 .36881 .79863 .36295 .791 .35236 Mtetra
.662 .753 .918 r
.791 .35236 .79863 .36295 .81637 .35699 .80881 .34635 Mtetra
.654 .751 .921 r
.80881 .34635 .81637 .35699 .83424 .35128 .82677 .3406 Mtetra
.649 .749 .922 r
.82677 .3406 .83424 .35128 .85225 .34579 .84486 .33503 Mtetra
.662 .753 .918 r
.20484 .53022 .21475 .53887 .22922 .53393 .21935 .52527 Mtetra
.659 .753 .92 r
.21935 .52527 .22922 .53393 .24375 .52918 .23394 .52042 Mtetra
.65 .75 .922 r
.23394 .52042 .24375 .52918 .25834 .52469 .24858 .51585 Mtetra
.648 .749 .923 r
.24858 .51585 .25834 .52469 .27301 .52017 .2633 .51132 Mtetra
.665 .754 .916 r
.2633 .51132 .27301 .52017 .28781 .51504 .27814 .50615 Mtetra
.634 .746 .929 r
.27814 .50615 .28781 .51504 .3026 .51128 .293 .50205 Mtetra
.545 .708 .947 r
.293 .50205 .3026 .51128 .3173 .5104 .30778 .5005 Mtetra
.444 .65 .947 r
.30778 .5005 .3173 .5104 .33201 .51131 .32252 .50139 Mtetra
.538 .691 .938 r
.32252 .50139 .33201 .51131 .34701 .50942 .33752 .50016 Mtetra
.715 .763 .89 r
.33752 .50016 .34701 .50942 .36248 .5003 .35297 .49259 Mtetra
.805 .806 .852 r
.35297 .49259 .36248 .5003 .37819 .48665 .36873 .47967 Mtetra
.819 .822 .851 r
.36873 .47967 .37819 .48665 .39389 .47369 .38454 .46594 Mtetra
.738 .804 .904 r
.38454 .46594 .39389 .47369 .40939 .46659 .40016 .45743 Mtetra
.629 .746 .932 r
.40016 .45743 .40939 .46659 .42483 .46381 .4157 .45331 Mtetra
.572 .696 .925 r
.4157 .45331 .42483 .46381 .44037 .46132 .43127 .45116 Mtetra
.622 .723 .919 r
.43127 .45116 .44037 .46132 .45606 .45706 .44701 .4473 Mtetra
.651 .743 .917 r
.44701 .4473 .45606 .45706 .47187 .45158 .46286 .44232 Mtetra
.663 .759 .922 r
.46286 .44232 .47187 .45158 .48776 .44684 .47883 .43683 Mtetra
.657 .742 .913 r
.47883 .43683 .48776 .44684 .50375 .44241 .49488 .43156 Mtetra
.656 .725 .9 r
.49488 .43156 .50375 .44241 .51984 .43719 .51102 .42629 Mtetra
.655 .725 .9 r
.51102 .42629 .51984 .43719 .53602 .43119 .52726 .42102 Mtetra
.649 .74 .915 r
.52726 .42102 .53602 .43119 .55229 .42551 .5436 .41596 Mtetra
.661 .759 .923 r
.5436 .41596 .55229 .42551 .56867 .42056 .56003 .41039 Mtetra
.687 .755 .904 r
.56003 .41039 .56867 .42056 .58512 .41437 .57654 .40369 Mtetra
.719 .755 .881 r
.57654 .40369 .58512 .41437 .60162 .40638 .59311 .39524 Mtetra
.678 .735 .893 r
.59311 .39524 .60162 .40638 .6182 .39868 .60979 .38878 Mtetra
.552 .712 .946 r
.60979 .38878 .6182 .39868 .63501 .39536 .6267 .38679 Mtetra
.283 .606 .954 r
.6267 .38679 .63501 .39536 .65218 .39805 .64396 .39015 Mtetra
.3 .636 .965 r
.64396 .39015 .65218 .39805 .66958 .40149 .66138 .39273 Mtetra
.568 .752 .964 r
.66138 .39273 .66958 .40149 .68694 .40031 .67873 .38984 Mtetra
.734 .775 .886 r
.67873 .38984 .68694 .40031 .70404 .39169 .69587 .38043 Mtetra
.765 .77 .857 r
.69587 .38043 .70404 .39169 .72104 .38015 .71295 .36879 Mtetra
.725 .757 .878 r
.71295 .36879 .72104 .38015 .7382 .37044 .73023 .35965 Mtetra
.674 .752 .91 r
.73023 .35965 .7382 .37044 .75564 .36368 .74777 .35314 Mtetra
.647 .748 .923 r
.74777 .35314 .75564 .36368 .77329 .35834 .76549 .34773 Mtetra
.662 .754 .918 r
.76549 .34773 .77329 .35834 .791 .35236 .78328 .34164 Mtetra
.661 .753 .918 r
.78328 .34164 .791 .35236 .80881 .34635 .80118 .33559 Mtetra
.653 .75 .921 r
.80118 .33559 .80881 .34635 .82677 .3406 .81921 .32982 Mtetra
.65 .75 .922 r
.81921 .32982 .82677 .3406 .84486 .33503 .83738 .32415 Mtetra
.661 .752 .918 r
.19483 .52148 .20484 .53022 .21935 .52527 .20938 .51653 Mtetra
.66 .754 .919 r
.20938 .51653 .21935 .52527 .23394 .52042 .22402 .51157 Mtetra
.651 .75 .922 r
.22402 .51157 .23394 .52042 .24858 .51585 .23871 .50691 Mtetra
.648 .748 .923 r
.23871 .50691 .24858 .51585 .2633 .51132 .25348 .50235 Mtetra
.663 .752 .917 r
.25348 .50235 .2633 .51132 .27814 .50615 .26837 .49721 Mtetra
.646 .75 .925 r
.26837 .49721 .27814 .50615 .293 .50205 .2833 .49267 Mtetra
.581 .72 .938 r
.2833 .49267 .293 .50205 .30778 .5005 .29818 .49016 Mtetra
.46 .649 .94 r
.29818 .49016 .30778 .5005 .32252 .50139 .31296 .49082 Mtetra
.511 .667 .933 r
.31296 .49082 .32252 .50139 .33752 .50016 .32795 .49036 Mtetra
.662 .741 .908 r
.32795 .49036 .33752 .50016 .35297 .49259 .34333 .48507 Mtetra
.789 .812 .871 r
.34333 .48507 .35297 .49259 .36873 .47967 .35911 .47348 Mtetra
.825 .841 .86 r
.35911 .47348 .36873 .47967 .38454 .46594 .37502 .45971 Mtetra
.784 .845 .897 r
.37502 .45971 .38454 .46594 .40016 .45743 .39081 .4489 Mtetra
.683 .779 .923 r
.39081 .4489 .40016 .45743 .4157 .45331 .40647 .44273 Mtetra
.596 .706 .92 r
.40647 .44273 .4157 .45331 .43127 .45116 .42212 .43976 Mtetra
.598 .69 .907 r
.42212 .43976 .43127 .45116 .44701 .4473 .43787 .4368 Mtetra
.633 .723 .913 r
.43787 .4368 .44701 .4473 .46286 .44232 .45377 .43248 Mtetra
.649 .744 .919 r
.45377 .43248 .46286 .44232 .47883 .43683 .46978 .42749 Mtetra
.658 .76 .925 r
.46978 .42749 .47883 .43683 .49488 .43156 .48589 .42211 Mtetra
.656 .758 .925 r
.48589 .42211 .49488 .43156 .51102 .42629 .5021 .41678 Mtetra
.654 .757 .926 r
.5021 .41678 .51102 .42629 .52726 .42102 .51841 .4115 Mtetra
.663 .761 .923 r
.51841 .4115 .52726 .42102 .5436 .41596 .53481 .40583 Mtetra
.678 .754 .908 r
.53481 .40583 .5436 .41596 .56003 .41039 .5513 .39948 Mtetra
.705 .748 .885 r
.5513 .39948 .56003 .41039 .57654 .40369 .56786 .39175 Mtetra
.7 .728 .872 r
.56786 .39175 .57654 .40369 .59311 .39524 .5845 .38401 Mtetra
.631 .717 .909 r
.5845 .38401 .59311 .39524 .60979 .38878 .6013 .37952 Mtetra
.453 .684 .964 r
.6013 .37952 .60979 .38878 .6267 .38679 .61834 .37976 Mtetra
.213 .608 .95 r
.61834 .37976 .6267 .38679 .64396 .39015 .63566 .38305 Mtetra
.347 .688 .981 r
.63566 .38305 .64396 .39015 .66138 .39273 .65309 .38415 Mtetra
.642 .789 .952 r
.65309 .38415 .66138 .39273 .67873 .38984 .67041 .3788 Mtetra
.746 .77 .872 r
.67041 .3788 .67873 .38984 .69587 .38043 .68759 .36847 Mtetra
.758 .758 .852 r
.68759 .36847 .69587 .38043 .71295 .36879 .70476 .35696 Mtetra
.706 .744 .881 r
.70476 .35696 .71295 .36879 .73023 .35965 .72217 .34869 Mtetra
.665 .747 .912 r
.72217 .34869 .73023 .35965 .74777 .35314 .73981 .34252 Mtetra
.649 .75 .923 r
.73981 .34252 .74777 .35314 .76549 .34773 .7576 .33695 Mtetra
.663 .753 .917 r
.7576 .33695 .76549 .34773 .78328 .34164 .77547 .33078 Mtetra
.66 .752 .918 r
.77547 .33078 .78328 .34164 .80118 .33559 .79345 .3247 Mtetra
.652 .749 .921 r
.79345 .3247 .80118 .33559 .81921 .32982 .81157 .31893 Mtetra
.651 .751 .922 r
.81157 .31893 .81921 .32982 .83738 .32415 .82981 .31313 Mtetra
.658 .752 .919 r
.18471 .51263 .19483 .52148 .20938 .51653 .19931 .50771 Mtetra
.662 .754 .919 r
.19931 .50771 .20938 .51653 .22402 .51157 .214 .50263 Mtetra
.652 .75 .921 r
.214 .50263 .22402 .51157 .23871 .50691 .22874 .49787 Mtetra
.648 .748 .922 r
.22874 .49787 .23871 .50691 .25348 .50235 .24356 .49325 Mtetra
.658 .751 .918 r
.24356 .49325 .25348 .50235 .26837 .49721 .25849 .48824 Mtetra
.657 .754 .922 r
.25849 .48824 .26837 .49721 .2833 .49267 .2735 .48323 Mtetra
.606 .73 .932 r
.2735 .48323 .2833 .49267 .29818 .49016 .28848 .47994 Mtetra
.499 .672 .941 r
.28848 .47994 .29818 .49016 .31296 .49082 .30335 .4796 Mtetra
.491 .646 .926 r
.30335 .4796 .31296 .49082 .32795 .49036 .31833 .47975 Mtetra
.594 .703 .919 r
.31833 .47975 .32795 .49036 .34333 .48507 .33361 .4769 Mtetra
.75 .798 .891 r
.33361 .4769 .34333 .48507 .35911 .47348 .34935 .46754 Mtetra
.814 .85 .876 r
.34935 .46754 .35911 .47348 .37502 .45971 .3653 .45474 Mtetra
.819 .874 .886 r
.3653 .45474 .37502 .45971 .39081 .4489 .38128 .44193 Mtetra
.736 .828 .921 r
.38128 .44193 .39081 .4489 .40647 .44273 .3971 .43347 Mtetra
.658 .758 .924 r
.3971 .43347 .40647 .44273 .42212 .43976 .41287 .42816 Mtetra
.606 .692 .903 r
.41287 .42816 .42212 .43976 .43787 .4368 .42868 .42485 Mtetra
.609 .687 .898 r
.42868 .42485 .43787 .4368 .45377 .43248 .4446 .42143 Mtetra
.638 .717 .905 r
.4446 .42143 .45377 .43248 .46978 .42749 .46066 .41684 Mtetra
.649 .73 .909 r
.46066 .41684 .46978 .42749 .48589 .42211 .47682 .41179 Mtetra
.656 .741 .912 r
.47682 .41179 .48589 .42211 .5021 .41678 .49309 .4064 Mtetra
.664 .744 .91 r
.49309 .4064 .5021 .41678 .51841 .4115 .50946 .40067 Mtetra
.673 .739 .9 r
.50946 .40067 .51841 .4115 .53481 .40583 .52592 .39447 Mtetra
.696 .737 .883 r
.52592 .39447 .53481 .40583 .5513 .39948 .54247 .3871 Mtetra
.694 .719 .868 r
.54247 .3871 .5513 .39948 .56786 .39175 .55909 .3796 Mtetra
.654 .709 .888 r
.55909 .3796 .56786 .39175 .5845 .38401 .57583 .37411 Mtetra
.558 .719 .948 r
.57583 .37411 .5845 .38401 .6013 .37952 .59274 .37182 Mtetra
.304 .648 .969 r
.59274 .37182 .6013 .37952 .61834 .37976 .60991 .37399 Mtetra
.213 .645 .952 r
.60991 .37399 .61834 .37976 .63566 .38305 .62726 .37618 Mtetra
.46 .757 .994 r
.62726 .37618 .63566 .38305 .65309 .38415 .64468 .37489 Mtetra
.708 .797 .92 r
.64468 .37489 .65309 .38415 .67041 .3788 .66197 .36692 Mtetra
.752 .758 .857 r
.66197 .36692 .67041 .3788 .68759 .36847 .67919 .35584 Mtetra
.741 .743 .853 r
.67919 .35584 .68759 .36847 .70476 .35696 .69649 .34523 Mtetra
.693 .743 .89 r
.69649 .34523 .70476 .35696 .72217 .34869 .71402 .33764 Mtetra
.655 .744 .916 r
.71402 .33764 .72217 .34869 .73981 .34252 .73177 .33183 Mtetra
.654 .753 .923 r
.73177 .33183 .73981 .34252 .7576 .33695 .74962 .32602 Mtetra
.663 .753 .917 r
.74962 .32602 .7576 .33695 .77547 .33078 .76757 .31979 Mtetra
.659 .751 .918 r
.76757 .31979 .77547 .33078 .79345 .3247 .78563 .31369 Mtetra
.65 .749 .922 r
.78563 .31369 .79345 .3247 .81157 .31893 .80384 .30792 Mtetra
.653 .752 .922 r
.80384 .30792 .81157 .31893 .82981 .31313 .82216 .30197 Mtetra
.655 .751 .92 r
.17449 .50368 .18471 .51263 .19931 .50771 .18913 .49881 Mtetra
.663 .755 .918 r
.18913 .49881 .19931 .50771 .214 .50263 .20387 .49364 Mtetra
.655 .752 .921 r
.20387 .49364 .214 .50263 .22874 .49787 .21867 .48874 Mtetra
.649 .748 .922 r
.21867 .48874 .22874 .49787 .24356 .49325 .23354 .48403 Mtetra
.651 .748 .921 r
.23354 .48403 .24356 .49325 .25849 .48824 .2485 .47921 Mtetra
.664 .757 .919 r
.2485 .47921 .25849 .48824 .2735 .48323 .26358 .47388 Mtetra
.63 .742 .928 r
.26358 .47388 .2735 .48323 .28848 .47994 .27866 .46975 Mtetra
.557 .698 .934 r
.27866 .46975 .28848 .47994 .30335 .4796 .29367 .4679 Mtetra
.488 .637 .92 r
.29367 .4679 .30335 .4796 .31833 .47975 .30866 .46817 Mtetra
.545 .666 .916 r
.30866 .46817 .31833 .47975 .33361 .4769 .32389 .46688 Mtetra
.668 .743 .907 r
.32389 .46688 .33361 .4769 .34935 .46754 .33948 .46119 Mtetra
.783 .844 .898 r
.33948 .46119 .34935 .46754 .3653 .45474 .35543 .45035 Mtetra
.818 .889 .894 r
.35543 .45035 .3653 .45474 .38128 .44193 .3715 .4377 Mtetra
.801 .897 .911 r
.3715 .4377 .38128 .44193 .3971 .43347 .38754 .42613 Mtetra
.716 .819 .93 r
.38754 .42613 .3971 .43347 .41287 .42816 .40347 .41848 Mtetra
.665 .755 .917 r
.40347 .41848 .41287 .42816 .42868 .42485 .4194 .41282 Mtetra
.629 .695 .893 r
.4194 .41282 .42868 .42485 .4446 .42143 .43539 .40857 Mtetra
.628 .681 .881 r
.43539 .40857 .4446 .42143 .46066 .41684 .45148 .40431 Mtetra
.64 .693 .883 r
.45148 .40431 .46066 .41684 .47682 .41179 .46769 .39952 Mtetra
.654 .704 .883 r
.46769 .39952 .47682 .41179 .49309 .4064 .484 .39407 Mtetra
.668 .709 .878 r
.484 .39407 .49309 .4064 .50946 .40067 .50043 .38795 Mtetra
.677 .706 .87 r
.50043 .38795 .50946 .40067 .52592 .39447 .51694 .3813 Mtetra
.675 .699 .865 r
.51694 .3813 .52592 .39447 .54247 .3871 .53355 .37463 Mtetra
.647 .702 .886 r
.53355 .37463 .54247 .3871 .55909 .3796 .55025 .36938 Mtetra
.59 .727 .939 r
.55025 .36938 .55909 .3796 .57583 .37411 .56709 .36614 Mtetra
.386 .688 .979 r
.56709 .36614 .57583 .37411 .59274 .37182 .58413 .36691 Mtetra
.18 .647 .936 r
.58413 .36691 .59274 .37182 .60991 .37399 .60137 .36881 Mtetra
.316 .726 .978 r
.60137 .36881 .60991 .37399 .62726 .37618 .61874 .36889 Mtetra
.625 .819 .975 r
.61874 .36889 .62726 .37618 .64468 .37489 .63611 .36371 Mtetra
.734 .767 .879 r
.63611 .36371 .64468 .37489 .66197 .36692 .6534 .35402 Mtetra
.749 .742 .845 r
.6534 .35402 .66197 .36692 .67919 .35584 .67069 .34269 Mtetra
.715 .727 .86 r
.67069 .34269 .67919 .35584 .69649 .34523 .68814 .33351 Mtetra
.676 .74 .899 r
.68814 .33351 .69649 .34523 .71402 .33764 .70579 .32667 Mtetra
.648 .746 .921 r
.70579 .32667 .71402 .33764 .73177 .33183 .72363 .32108 Mtetra
.66 .757 .922 r
.72363 .32108 .73177 .33183 .74962 .32602 .74155 .31493 Mtetra
.662 .752 .917 r
.74155 .31493 .74962 .32602 .76757 .31979 .75957 .30867 Mtetra
.657 .75 .919 r
.75957 .30867 .76757 .31979 .78563 .31369 .77773 .3026 Mtetra
.649 .749 .923 r
.77773 .3026 .78563 .31369 .80384 .30792 .79602 .2968 Mtetra
.656 .753 .921 r
.79602 .2968 .80384 .30792 .82216 .30197 .81441 .29067 Mtetra
.653 .75 .921 r
.16416 .49461 .17449 .50368 .18913 .49881 .17884 .48979 Mtetra
.662 .754 .918 r
.17884 .48979 .18913 .49881 .20387 .49364 .19363 .48461 Mtetra
.659 .754 .921 r
.19363 .48461 .20387 .49364 .21867 .48874 .20849 .47952 Mtetra
.651 .749 .921 r
.20849 .47952 .21867 .48874 .23354 .48403 .22341 .47469 Mtetra
.648 .747 .921 r
.22341 .47469 .23354 .48403 .2485 .47921 .23841 .46993 Mtetra
.662 .753 .918 r
.23841 .46993 .2485 .47921 .26358 .47388 .25354 .46463 Mtetra
.651 .752 .923 r
.25354 .46463 .26358 .47388 .27866 .46975 .26873 .4597 Mtetra
.604 .721 .927 r
.26873 .4597 .27866 .46975 .29367 .4679 .28389 .45638 Mtetra
.52 .657 .921 r
.28389 .45638 .29367 .4679 .30866 .46817 .29896 .45571 Mtetra
.516 .637 .908 r
.29896 .45571 .30866 .46817 .32389 .46688 .31415 .45534 Mtetra
.586 .687 .911 r
.31415 .45534 .32389 .46688 .33948 .46119 .32961 .45268 Mtetra
.708 .789 .915 r
.32961 .45268 .33948 .46119 .35543 .45035 .34544 .4453 Mtetra
.784 .879 .916 r
.34544 .4453 .35543 .45035 .3715 .4377 .36152 .4345 Mtetra
.803 .922 .916 r
.36152 .4345 .3715 .4377 .38754 .42613 .37768 .42267 Mtetra
.781 .92 .93 r
.37768 .42267 .38754 .42613 .40347 .41848 .39383 .4119 Mtetra
.721 .842 .939 r
.39383 .4119 .40347 .41848 .4194 .41282 .40992 .40394 Mtetra
.68 .78 .926 r
.40992 .40394 .4194 .41282 .43539 .40857 .42603 .3976 Mtetra
.66 .731 .902 r
.42603 .3976 .43539 .40857 .45148 .40431 .4422 .39198 Mtetra
.653 .703 .884 r
.4422 .39198 .45148 .40431 .46769 .39952 .45847 .38655 Mtetra
.653 .693 .875 r
.45847 .38655 .46769 .39952 .484 .39407 .47484 .38103 Mtetra
.655 .694 .874 r
.47484 .38103 .484 .39407 .50043 .38795 .49131 .37543 Mtetra
.651 .702 .885 r
.49131 .37543 .50043 .38795 .51694 .3813 .50787 .37002 Mtetra
.634 .721 .911 r
.50787 .37002 .51694 .3813 .53355 .37463 .52454 .36533 Mtetra
.575 .744 .957 r
.52454 .36533 .53355 .37463 .55025 .36938 .54133 .36229 Mtetra
.405 .724 .989 r
.54133 .36229 .55025 .36938 .56709 .36614 .55827 .36211 Mtetra
.193 .676 .929 r
.55827 .36211 .56709 .36614 .58413 .36691 .5754 .36303 Mtetra
.257 .721 .948 r
.5754 .36303 .58413 .36691 .60137 .36881 .59269 .36294 Mtetra
.537 .823 .998 r
.59269 .36294 .60137 .36881 .61874 .36889 .61005 .35936 Mtetra
.715 .796 .915 r
.61005 .35936 .61874 .36889 .63611 .36371 .62739 .35097 Mtetra
.742 .743 .852 r
.62739 .35097 .63611 .36371 .6534 .35402 .64472 .34019 Mtetra
.731 .723 .843 r
.64472 .34019 .6534 .35402 .67069 .34269 .66212 .3297 Mtetra
.691 .723 .874 r
.66212 .3297 .67069 .34269 .68814 .33351 .67971 .32191 Mtetra
.66 .739 .908 r
.67971 .32191 .68814 .33351 .70579 .32667 .69748 .31578 Mtetra
.65 .751 .923 r
.69748 .31578 .70579 .32667 .72363 .32108 .71539 .31002 Mtetra
.662 .754 .918 r
.71539 .31002 .72363 .32108 .74155 .31493 .73338 .3037 Mtetra
.66 .751 .917 r
.73338 .3037 .74155 .31493 .75957 .30867 .75149 .29743 Mtetra
.653 .749 .92 r
.75149 .29743 .75957 .30867 .77773 .3026 .76973 .29143 Mtetra
.65 .751 .923 r
.76973 .29143 .77773 .3026 .79602 .2968 .78811 .28552 Mtetra
.658 .754 .92 r
.78811 .28552 .79602 .2968 .81441 .29067 .80657 .27922 Mtetra
.652 .749 .921 r
.15373 .48544 .16416 .49461 .17884 .48979 .16845 .48061 Mtetra
.659 .752 .919 r
.16845 .48061 .17884 .48979 .19363 .48461 .18327 .47551 Mtetra
.662 .755 .919 r
.18327 .47551 .19363 .48461 .20849 .47952 .1982 .47023 Mtetra
.653 .75 .921 r
.1982 .47023 .20849 .47952 .22341 .47469 .21318 .46527 Mtetra
.649 .747 .921 r
.21318 .46527 .22341 .47469 .23841 .46993 .22823 .46043 Mtetra
.653 .748 .919 r
.22823 .46043 .23841 .46993 .25354 .46463 .24338 .45541 Mtetra
.664 .758 .92 r
.24338 .45541 .25354 .46463 .26873 .4597 .25866 .44996 Mtetra
.634 .74 .924 r
.25866 .44996 .26873 .4597 .28389 .45638 .27394 .44556 Mtetra
.584 .7 .922 r
.27394 .44556 .28389 .45638 .29896 .45571 .28919 .44286 Mtetra
.52 .633 .903 r
.28919 .44286 .29896 .45571 .31415 .45534 .30441 .4424 Mtetra
.543 .643 .899 r
.30441 .4424 .31415 .45534 .32961 .45268 .3198 .44125 Mtetra
.607 .7 .91 r
.3198 .44125 .32961 .45268 .34544 .4453 .33546 .43779 Mtetra
.711 .816 .931 r
.33546 .43779 .34544 .4453 .36152 .4345 .35144 .43024 Mtetra
.765 .901 .937 r
.35144 .43024 .36152 .4345 .37768 .42267 .36762 .42027 Mtetra
.769 .943 .937 r
.36762 .42027 .37768 .42267 .39383 .4119 .38387 .40966 Mtetra
.748 .947 .945 r
.38387 .40966 .39383 .4119 .40992 .40394 .40014 .39969 Mtetra
.727 .904 .957 r
.40014 .39969 .40992 .40394 .42603 .3976 .41642 .39102 Mtetra
.693 .843 .955 r
.41642 .39102 .42603 .3976 .4422 .39198 .43271 .38396 Mtetra
.669 .803 .947 r
.43271 .38396 .4422 .39198 .45847 .38655 .44907 .37786 Mtetra
.654 .784 .943 r
.44907 .37786 .45847 .38655 .47484 .38103 .46551 .37228 Mtetra
.638 .779 .949 r
.46551 .37228 .47484 .38103 .49131 .37543 .48204 .36724 Mtetra
.602 .782 .967 r
.48204 .36724 .49131 .37543 .50787 .37002 .49867 .36316 Mtetra
.515 .783 .993 r
.49867 .36316 .50787 .37002 .52454 .36533 .51541 .3607 Mtetra
.364 .768 .984 r
.51541 .3607 .52454 .36533 .54133 .36229 .53229 .35958 Mtetra
.211 .713 .907 r
.53229 .35958 .54133 .36229 .55827 .36211 .54933 .35913 Mtetra
.272 .748 .935 r
.54933 .35913 .55827 .36211 .5754 .36303 .56653 .35806 Mtetra
.509 .834 .999 r
.56653 .35806 .5754 .36303 .59269 .36294 .58384 .35454 Mtetra
.699 .818 .939 r
.58384 .35454 .59269 .36294 .61005 .35936 .60118 .34684 Mtetra
.732 .745 .862 r
.60118 .34684 .61005 .35936 .62739 .35097 .61854 .33677 Mtetra
.734 .719 .837 r
.61854 .33677 .62739 .35097 .64472 .34019 .63594 .32595 Mtetra
.699 .707 .854 r
.63594 .32595 .64472 .34019 .66212 .3297 .65349 .31741 Mtetra
.672 .731 .894 r
.65349 .31741 .66212 .3297 .67971 .32191 .6712 .31062 Mtetra
.649 .743 .918 r
.6712 .31062 .67971 .32191 .69748 .31578 .68908 .30489 Mtetra
.658 .757 .923 r
.68908 .30489 .69748 .31578 .71539 .31002 .70704 .29872 Mtetra
.662 .751 .916 r
.70704 .29872 .71539 .31002 .73338 .3037 .72512 .29234 Mtetra
.658 .75 .918 r
.72512 .29234 .73338 .3037 .75149 .29743 .74331 .2861 Mtetra
.65 .749 .922 r
.74331 .2861 .75149 .29743 .76973 .29143 .76165 .28016 Mtetra
.653 .753 .923 r
.76165 .28016 .76973 .29143 .78811 .28552 .78009 .27404 Mtetra
.659 .752 .919 r
.78009 .27404 .78811 .28552 .80657 .27922 .79863 .26762 Mtetra
.652 .749 .921 r
.14319 .47617 .15373 .48544 .16845 .48061 .15795 .4713 Mtetra
.654 .75 .92 r
.15795 .4713 .16845 .48061 .18327 .47551 .17281 .4663 Mtetra
.663 .756 .919 r
.17281 .4663 .18327 .47551 .1982 .47023 .18779 .46096 Mtetra
.658 .754 .921 r
.18779 .46096 .1982 .47023 .21318 .46527 .20283 .45577 Mtetra
.651 .749 .921 r
.20283 .45577 .21318 .46527 .22823 .46043 .21794 .4508 Mtetra
.649 .746 .921 r
.21794 .4508 .22823 .46043 .24338 .45541 .23313 .44588 Mtetra
.66 .753 .919 r
.23313 .44588 .24338 .45541 .25866 .44996 .24845 .44051 Mtetra
.658 .755 .922 r
.24845 .44051 .25866 .44996 .27394 .44556 .26385 .4352 Mtetra
.624 .726 .92 r
.26385 .4352 .27394 .44556 .28919 .44286 .27925 .43111 Mtetra
.574 .681 .912 r
.27925 .43111 .28919 .44286 .30441 .4424 .29462 .42874 Mtetra
.536 .629 .891 r
.29462 .42874 .30441 .4424 .3198 .44125 .31002 .42784 Mtetra
.56 .645 .891 r
.31002 .42784 .3198 .44125 .33546 .43779 .3256 .42611 Mtetra
.609 .699 .908 r
.3256 .42611 .33546 .43779 .35144 .43024 .34142 .42249 Mtetra
.681 .809 .943 r
.34142 .42249 .35144 .43024 .36762 .42027 .35749 .41601 Mtetra
.726 .902 .957 r
.35749 .41601 .36762 .42027 .38387 .40966 .37375 .40739 Mtetra
.713 .943 .957 r
.37375 .40739 .38387 .40966 .40014 .39969 .39009 .39841 Mtetra
.678 .954 .951 r
.39009 .39841 .40014 .39969 .41642 .39102 .40648 .38972 Mtetra
.638 .944 .955 r
.40648 .38972 .41642 .39102 .43271 .38396 .42291 .38189 Mtetra
.606 .924 .97 r
.42291 .38189 .43271 .38396 .44907 .37786 .43939 .37515 Mtetra
.566 .9 .981 r
.43939 .37515 .44907 .37786 .46551 .37228 .45593 .36952 Mtetra
.502 .874 .979 r
.45593 .36952 .46551 .37228 .48204 .36724 .47255 .36501 Mtetra
.404 .835 .953 r
.47255 .36501 .48204 .36724 .49867 .36316 .48928 .3616 Mtetra
.299 .784 .906 r
.48928 .3616 .49867 .36316 .51541 .3607 .50612 .35907 Mtetra
.277 .77 .9 r
.50612 .35907 .51541 .3607 .53229 .35958 .52311 .35684 Mtetra
.363 .807 .954 r
.52311 .35684 .53229 .35958 .54933 .35913 .54024 .35427 Mtetra
.564 .86 .997 r
.54024 .35427 .54933 .35913 .56653 .35806 .55748 .34953 Mtetra
.698 .816 .938 r
.55748 .34953 .56653 .35806 .58384 .35454 .57481 .34188 Mtetra
.724 .74 .865 r
.57481 .34188 .58384 .35454 .60118 .34684 .59218 .33229 Mtetra
.727 .712 .837 r
.59218 .33229 .60118 .34684 .61854 .33677 .60959 .32181 Mtetra
.702 .698 .843 r
.60959 .32181 .61854 .33677 .63594 .32595 .62712 .31282 Mtetra
.679 .719 .88 r
.62712 .31282 .63594 .32595 .65349 .31741 .64479 .30558 Mtetra
.654 .736 .91 r
.64479 .30558 .65349 .31741 .6712 .31062 .66262 .29959 Mtetra
.652 .753 .924 r
.66262 .29959 .6712 .31062 .68908 .30489 .68056 .29366 Mtetra
.662 .754 .918 r
.68056 .29366 .68908 .30489 .70704 .29872 .6986 .28725 Mtetra
.66 .75 .916 r
.6986 .28725 .70704 .29872 .72512 .29234 .71676 .28089 Mtetra
.654 .749 .92 r
.71676 .28089 .72512 .29234 .74331 .2861 .73504 .27474 Mtetra
.649 .751 .924 r
.73504 .27474 .74331 .2861 .76165 .28016 .75346 .26875 Mtetra
.657 .755 .922 r
.75346 .26875 .76165 .28016 .78009 .27404 .77198 .26238 Mtetra
.66 .752 .918 r
.77198 .26238 .78009 .27404 .79863 .26762 .79061 .25588 Mtetra
.652 .749 .921 r
.13253 .46681 .14319 .47617 .15795 .4713 .14734 .46186 Mtetra
.14734 .46186 .15795 .4713 .17281 .4663 .16224 .45688 Mtetra
.659 .752 .919 r
.16224 .45688 .17281 .4663 .18779 .46096 .17725 .45163 Mtetra
.662 .756 .92 r
.17725 .45163 .18779 .46096 .20283 .45577 .19237 .44622 Mtetra
.654 .75 .921 r
.19237 .44622 .20283 .45577 .21794 .4508 .20754 .44109 Mtetra
.65 .747 .921 r
.20754 .44109 .21794 .4508 .23313 .44588 .22278 .43608 Mtetra
.65 .746 .92 r
.22278 .43608 .23313 .44588 .24845 .44051 .23812 .43103 Mtetra
.664 .758 .921 r
.23812 .43103 .24845 .44051 .26385 .4352 .2536 .42544 Mtetra
.653 .75 .921 r
.2536 .42544 .26385 .4352 .27925 .43111 .26913 .42024 Mtetra
.622 .719 .915 r
.26913 .42024 .27925 .43111 .29462 .42874 .28467 .41613 Mtetra
.582 .67 .9 r
.28467 .41613 .29462 .42874 .31002 .42784 .30021 .4135 Mtetra
.553 .628 .88 r
.30021 .4135 .31002 .42784 .3256 .42611 .31579 .41202 Mtetra
.569 .641 .882 r
.31579 .41202 .3256 .42611 .34142 .42249 .33155 .40992 Mtetra
.602 .683 .898 r
.33155 .40992 .34142 .42249 .35749 .41601 .3475 .40649 Mtetra
.637 .759 .936 r
.3475 .40649 .35749 .41601 .37375 .40739 .36364 .4016 Mtetra
.675 .86 .97 r
.36364 .4016 .37375 .40739 .39009 .39841 .37997 .39489 Mtetra
.667 .912 .977 r
.37997 .39489 .39009 .39841 .40648 .38972 .39641 .38758 Mtetra
.623 .928 .971 r
.39641 .38758 .40648 .38972 .42291 .38189 .41292 .38052 Mtetra
.562 .919 .956 r
.41292 .38052 .42291 .38189 .43939 .37515 .4295 .37407 Mtetra
.5 .896 .941 r
.4295 .37407 .43939 .37515 .45593 .36952 .44616 .36838 Mtetra
.448 .872 .933 r
.44616 .36838 .45593 .36952 .47255 .36501 .4629 .36348 Mtetra
.423 .855 .938 r
.4629 .36348 .47255 .36501 .48928 .3616 .47974 .35919 Mtetra
.445 .855 .963 r
.47974 .35919 .48928 .3616 .50612 .35907 .4967 .35516 Mtetra
.535 .869 .993 r
.4967 .35516 .50612 .35907 .52311 .35684 .51379 .35052 Mtetra
.655 .856 .977 r
.51379 .35052 .52311 .35684 .54024 .35427 .53099 .34405 Mtetra
.703 .78 .912 r
.53099 .34405 .54024 .35427 .55748 .34953 .54829 .33608 Mtetra
.715 .725 .858 r
.54829 .33608 .55748 .34953 .57481 .34188 .56565 .32674 Mtetra
.716 .701 .834 r
.56565 .32674 .57481 .34188 .59218 .33229 .58307 .31675 Mtetra
.697 .689 .838 r
.58307 .31675 .59218 .33229 .60959 .32181 .60059 .30791 Mtetra
.678 .707 .87 r
.60059 .30791 .60959 .32181 .62712 .31282 .61824 .30057 Mtetra
.658 .73 .903 r
.61824 .30057 .62712 .31282 .64479 .30558 .63602 .29435 Mtetra
.648 .748 .922 r
.63602 .29435 .64479 .30558 .66262 .29959 .65393 .28852 Mtetra
.661 .758 .922 r
.65393 .28852 .66262 .29959 .68056 .29366 .67194 .28212 Mtetra
.661 .75 .916 r
.67194 .28212 .68056 .29366 .6986 .28725 .69006 .27568 Mtetra
.658 .749 .918 r
.69006 .27568 .6986 .28725 .71676 .28089 .7083 .26935 Mtetra
.65 .748 .922 r
.7083 .26935 .71676 .28089 .73504 .27474 .72668 .2633 Mtetra
.653 .753 .923 r
.72668 .2633 .73504 .27474 .75346 .26875 .74517 .25707 Mtetra
.659 .753 .919 r
.74517 .25707 .75346 .26875 .77198 .26238 .76377 .25056 Mtetra
.659 .751 .918 r
.76377 .25056 .77198 .26238 .79061 .25588 .78248 .244 Mtetra
.654 .75 .921 r
.12176 .45738 .13253 .46681 .14734 .46186 .13662 .45232 Mtetra
.652 .749 .921 r
.13662 .45232 .14734 .46186 .16224 .45688 .15157 .4473 Mtetra
.654 .749 .92 r
.15157 .4473 .16224 .45688 .17725 .45163 .16661 .44218 Mtetra
.662 .756 .92 r
.16661 .44218 .17725 .45163 .19237 .44622 .18177 .43673 Mtetra
.659 .755 .921 r
.18177 .43673 .19237 .44622 .20754 .44109 .19702 .43134 Mtetra
.653 .749 .92 r
.19702 .43134 .20754 .44109 .22278 .43608 .21232 .42616 Mtetra
.65 .746 .92 r
.21232 .42616 .22278 .43608 .23812 .43103 .22771 .42107 Mtetra
.651 .747 .919 r
.22771 .42107 .23812 .43103 .2536 .42544 .2432 .41588 Mtetra
.664 .76 .922 r
.2432 .41588 .2536 .42544 .26913 .42024 .25882 .41018 Mtetra
.652 .747 .919 r
.25882 .41018 .26913 .42024 .28467 .41613 .2745 .4049 Mtetra
.628 .717 .911 r
.2745 .4049 .28467 .41613 .30021 .4135 .29021 .40052 Mtetra
.602 .675 .892 r
.29021 .40052 .30021 .4135 .31579 .41202 .30595 .39712 Mtetra
.572 .63 .871 r
.30595 .39712 .31579 .41202 .33155 .40992 .32173 .39491 Mtetra
.579 .633 .869 r
.32173 .39491 .33155 .40992 .3475 .40649 .33765 .39241 Mtetra
.598 .658 .879 r
.33765 .39241 .3475 .40649 .36364 .4016 .35375 .3891 Mtetra
.62 .696 .898 r
.35375 .3891 .36364 .4016 .37997 .39489 .37001 .38487 Mtetra
.637 .753 .933 r
.37001 .38487 .37997 .39489 .39641 .38758 .38641 .3799 Mtetra
.642 .81 .964 r
.38641 .3799 .39641 .38758 .41292 .38052 .40294 .37443 Mtetra
.634 .849 .982 r
.40294 .37443 .41292 .38052 .4295 .37407 .41958 .36874 Mtetra
.624 .866 .988 r
.41958 .36874 .4295 .37407 .44616 .36838 .43633 .36301 Mtetra
.625 .866 .988 r
.43633 .36301 .44616 .36838 .4629 .36348 .45318 .35721 Mtetra
.642 .851 .98 r
.45318 .35721 .4629 .36348 .47974 .35919 .47014 .3512 Mtetra
.668 .818 .956 r
.47014 .3512 .47974 .35919 .4967 .35516 .4872 .34469 Mtetra
.688 .77 .914 r
.4872 .34469 .4967 .35516 .51379 .35052 .50437 .33741 Mtetra
.698 .724 .87 r
.50437 .33741 .51379 .35052 .53099 .34405 .52164 .3292 Mtetra
.704 .7 .844 r
.52164 .3292 .53099 .34405 .54829 .33608 .53899 .32014 Mtetra
.703 .685 .83 r
.53899 .32014 .54829 .33608 .56565 .32674 .55641 .31077 Mtetra
.684 .678 .838 r
.55641 .31077 .56565 .32674 .58307 .31675 .57392 .3026 Mtetra
.673 .702 .869 r
.57392 .3026 .58307 .31675 .60059 .30791 .59154 .29542 Mtetra
.658 .727 .9 r
.59154 .29542 .60059 .30791 .61824 .30057 .60928 .28914 Mtetra
.648 .745 .921 r
.60928 .28914 .61824 .30057 .63602 .29435 .62716 .2833 Mtetra
.66 .759 .924 r
.62716 .2833 .63602 .29435 .65393 .28852 .64513 .27693 Mtetra
.661 .75 .916 r
.64513 .27693 .65393 .28852 .67194 .28212 .66321 .27044 Mtetra
.659 .749 .917 r
.66321 .27044 .67194 .28212 .69006 .27568 .68142 .26403 Mtetra
.652 .749 .92 r
.68142 .26403 .69006 .27568 .7083 .26935 .69975 .25784 Mtetra
.65 .752 .924 r
.69975 .25784 .7083 .26935 .72668 .2633 .71821 .2517 Mtetra
.658 .755 .922 r
.71821 .2517 .72668 .2633 .74517 .25707 .73678 .2452 Mtetra
.659 .751 .918 r
.73678 .2452 .74517 .25707 .76377 .25056 .75546 .23859 Mtetra
.658 .75 .919 r
.75546 .23859 .76377 .25056 .78248 .244 .77426 .23202 Mtetra
.658 .754 .921 r
.11085 .44796 .12176 .45738 .13662 .45232 .12578 .44269 Mtetra
.653 .749 .921 r
.12578 .44269 .13662 .45232 .15157 .4473 .14078 .43759 Mtetra
.652 .748 .92 r
.14078 .43759 .15157 .4473 .16661 .44218 .15587 .43247 Mtetra
.656 .751 .92 r
.15587 .43247 .16661 .44218 .18177 .43673 .17106 .42717 Mtetra
.662 .757 .92 r
.17106 .42717 .18177 .43673 .19702 .43134 .18637 .42162 Mtetra
.657 .753 .921 r
.18637 .42162 .19702 .43134 .21232 .42616 .20174 .41621 Mtetra
.652 .748 .92 r
.20174 .41621 .21232 .42616 .22771 .42107 .21719 .41096 Mtetra
.65 .745 .919 r
.21719 .41096 .22771 .42107 .2432 .41588 .23273 .40577 Mtetra
.652 .747 .92 r
.23273 .40577 .2432 .41588 .25882 .41018 .24837 .40047 Mtetra
.664 .76 .922 r
.24837 .40047 .25882 .41018 .2745 .4049 .26414 .39469 Mtetra
.656 .749 .918 r
.26414 .39469 .2745 .4049 .29021 .40052 .27998 .38918 Mtetra
.637 .721 .909 r
.27998 .38918 .29021 .40052 .30595 .39712 .29586 .38436 Mtetra
.622 .69 .892 r
.29586 .38436 .30595 .39712 .32173 .39491 .31181 .38009 Mtetra
.601 .648 .868 r
.31181 .38009 .32173 .39491 .33765 .39241 .32782 .37661 Mtetra
.594 .631 .857 r
.32782 .37661 .33765 .39241 .35375 .3891 .34393 .37341 Mtetra
.603 .637 .858 r
.34393 .37341 .35375 .3891 .37001 .38487 .36018 .36978 Mtetra
.616 .653 .864 r
.36018 .36978 .37001 .38487 .38641 .3799 .37659 .36558 Mtetra
.63 .672 .872 r
.37659 .36558 .38641 .3799 .40294 .37443 .39313 .36077 Mtetra
.642 .689 .879 r
.39313 .36077 .40294 .37443 .41958 .36874 .4098 .35544 Mtetra
.652 .7 .882 r
.4098 .35544 .41958 .36874 .43633 .36301 .4266 .34963 Mtetra
.661 .704 .878 r
.4266 .34963 .43633 .36301 .45318 .35721 .44351 .34335 Mtetra
.67 .7 .869 r
.44351 .34335 .45318 .35721 .47014 .3512 .46054 .33653 Mtetra
.678 .691 .855 r
.46054 .33653 .47014 .3512 .4872 .34469 .47767 .32909 Mtetra
.684 .681 .841 r
.47767 .32909 .4872 .34469 .50437 .33741 .49489 .32106 Mtetra
.688 .673 .831 r
.49489 .32106 .50437 .33741 .52164 .3292 .51221 .31259 Mtetra
.682 .669 .831 r
.51221 .31259 .52164 .3292 .53899 .32014 .52961 .30439 Mtetra
.672 .677 .847 r
.52961 .30439 .53899 .32014 .55641 .31077 .5471 .29697 Mtetra
.668 .707 .877 r
.5471 .29697 .55641 .31077 .57392 .3026 .56469 .29011 Mtetra
.655 .727 .902 r
.56469 .29011 .57392 .3026 .59154 .29542 .5824 .28394 Mtetra
.648 .746 .921 r
.5824 .28394 .59154 .29542 .60928 .28914 .60024 .27805 Mtetra
.659 .76 .924 r
.60024 .27805 .60928 .28914 .62716 .2833 .61817 .27166 Mtetra
.661 .751 .916 r
.61817 .27166 .62716 .2833 .64513 .27693 .63622 .26514 Mtetra
.659 .748 .916 r
.63622 .26514 .64513 .27693 .66321 .27044 .65439 .25869 Mtetra
.654 .749 .919 r
.65439 .25869 .66321 .27044 .68142 .26403 .67268 .25238 Mtetra
.65 .751 .923 r
.67268 .25238 .68142 .26403 .69975 .25784 .6911 .24623 Mtetra
.656 .755 .923 r
.6911 .24623 .69975 .25784 .71821 .2517 .70964 .23979 Mtetra
.659 .752 .919 r
.70964 .23979 .71821 .2517 .73678 .2452 .72828 .23315 Mtetra
.659 .751 .918 r
.72828 .23315 .73678 .2452 .75546 .23859 .74705 .2265 Mtetra
.654 .749 .92 r
.74705 .2265 .75546 .23859 .77426 .23202 .76595 .22 Mtetra
.66 .755 .92 r
.09983 .43845 .11085 .44796 .12578 .44269 .11482 .43304 Mtetra
.655 .752 .921 r
.11482 .43304 .12578 .44269 .14078 .43759 .12988 .42777 Mtetra
.652 .749 .92 r
.12988 .42777 .14078 .43759 .15587 .43247 .14502 .42259 Mtetra
.653 .749 .92 r
.14502 .42259 .15587 .43247 .17106 .42717 .16024 .41736 Mtetra
.658 .753 .92 r
.16024 .41736 .17106 .42717 .18637 .42162 .17559 .41191 Mtetra
.662 .757 .921 r
.17559 .41191 .18637 .42162 .20174 .41621 .19103 .40628 Mtetra
.656 .752 .92 r
.19103 .40628 .20174 .41621 .21719 .41096 .20655 .40081 Mtetra
.652 .748 .92 r
.20655 .40081 .21719 .41096 .23273 .40577 .22215 .39547 Mtetra
.65 .745 .919 r
.22215 .39547 .23273 .40577 .24837 .40047 .23784 .39017 Mtetra
.652 .747 .919 r
.23784 .39017 .24837 .40047 .26414 .39469 .25362 .38479 Mtetra
.662 .759 .923 r
.25362 .38479 .26414 .39469 .27998 .38918 .26954 .37899 Mtetra
.659 .754 .92 r
.26954 .37899 .27998 .38918 .29586 .38436 .28554 .37325 Mtetra
.649 .733 .911 r
.28554 .37325 .29586 .38436 .31181 .38009 .30162 .36786 Mtetra
.638 .709 .898 r
.30162 .36786 .31181 .38009 .32782 .37661 .31776 .36286 Mtetra
.63 .68 .879 r
.31776 .36286 .32782 .37661 .34393 .37341 .334 .35809 Mtetra
.625 .654 .859 r
.334 .35809 .34393 .37341 .36018 .36978 .35034 .35342 Mtetra
.619 .637 .847 r
.35034 .35342 .36018 .36978 .37659 .36558 .36678 .34895 Mtetra
.626 .638 .843 r
.36678 .34895 .37659 .36558 .39313 .36077 .38335 .34408 Mtetra
.635 .642 .84 r
.38335 .34408 .39313 .36077 .4098 .35544 .40006 .33873 Mtetra
.644 .647 .838 r
.40006 .33873 .4098 .35544 .4266 .34963 .41689 .33284 Mtetra
.653 .651 .835 r
.41689 .33284 .4266 .34963 .44351 .34335 .43384 .32643 Mtetra
.661 .653 .832 r
.43384 .32643 .44351 .34335 .46054 .33653 .4509 .31952 Mtetra
.667 .656 .83 r
.4509 .31952 .46054 .33653 .47767 .32909 .46807 .3122 Mtetra
.663 .657 .833 r
.46807 .3122 .47767 .32909 .49489 .32106 .48533 .30508 Mtetra
.664 .671 .846 r
.48533 .30508 .49489 .32106 .51221 .31259 .50269 .29806 Mtetra
.665 .694 .867 r
.50269 .29806 .51221 .31259 .52961 .30439 .52014 .29125 Mtetra
.66 .717 .891 r
.52014 .29125 .52961 .30439 .5471 .29697 .5377 .28484 Mtetra
.652 .734 .909 r
.5377 .28484 .5471 .29697 .56469 .29011 .55538 .27878 Mtetra
.65 .751 .923 r
.55538 .27878 .56469 .29011 .5824 .28394 .57317 .27277 Mtetra
.66 .759 .924 r
.57317 .27277 .5824 .28394 .60024 .27805 .59107 .26633 Mtetra
.661 .75 .916 r
.59107 .26633 .60024 .27805 .61817 .27166 .60908 .2598 Mtetra
.659 .748 .916 r
.60908 .2598 .61817 .27166 .63622 .26514 .62721 .25331 Mtetra
.655 .749 .919 r
.62721 .25331 .63622 .26514 .65439 .25869 .64546 .24693 Mtetra
.65 .75 .922 r
.64546 .24693 .65439 .25869 .67268 .25238 .66384 .24073 Mtetra
.654 .755 .924 r
.66384 .24073 .67268 .25238 .6911 .24623 .68234 .23432 Mtetra
.659 .753 .92 r
.68234 .23432 .6911 .24623 .70964 .23979 .70095 .22767 Mtetra
.659 .751 .918 r
.70095 .22767 .70964 .23979 .72828 .23315 .71968 .22097 Mtetra
.656 .75 .919 r
.71968 .22097 .72828 .23315 .74705 .2265 .73854 .21434 Mtetra
.652 .75 .922 r
.73854 .21434 .74705 .2265 .76595 .22 .75754 .20785 Mtetra
.658 .753 .92 r
.08869 .42878 .09983 .43845 .11482 .43304 .10372 .42338 Mtetra
.66 .755 .92 r
.10372 .42338 .11482 .43304 .12988 .42777 .11885 .4179 Mtetra
.654 .75 .92 r
.11885 .4179 .12988 .42777 .14502 .42259 .13404 .4126 Mtetra
.652 .748 .92 r
.13404 .4126 .14502 .42259 .16024 .41736 .14932 .40732 Mtetra
.653 .749 .92 r
.14932 .40732 .16024 .41736 .17559 .41191 .1647 .40199 Mtetra
.658 .754 .92 r
.1647 .40199 .17559 .41191 .19103 .40628 .18018 .39642 Mtetra
.661 .757 .921 r
.18018 .39642 .19103 .40628 .20655 .40081 .19578 .39071 Mtetra
.657 .752 .92 r
.19578 .39071 .20655 .40081 .22215 .39547 .21144 .38514 Mtetra
.653 .748 .919 r
.21144 .38514 .22215 .39547 .23784 .39017 .22719 .37968 Mtetra
.651 .745 .918 r
.22719 .37968 .23784 .39017 .25362 .38479 .24303 .37425 Mtetra
.651 .746 .919 r
.24303 .37425 .25362 .38479 .26954 .37899 .25897 .36878 Mtetra
.656 .755 .923 r
.25897 .36878 .26954 .37899 .28554 .37325 .27503 .36311 Mtetra
.661 .759 .923 r
.27503 .36311 .28554 .37325 .30162 .36786 .2912 .35718 Mtetra
.658 .748 .917 r
.2912 .35718 .30162 .36786 .31776 .36286 .30745 .35136 Mtetra
.652 .731 .907 r
.30745 .35136 .31776 .36286 .334 .35809 .32379 .3457 Mtetra
.647 .714 .897 r
.32379 .3457 .334 .35809 .35034 .35342 .34023 .34021 Mtetra
.645 .7 .886 r
.34023 .34021 .35034 .35342 .36678 .34895 .35676 .33471 Mtetra
.644 .683 .872 r
.35676 .33471 .36678 .34895 .38335 .34408 .37341 .32913 Mtetra
.645 .674 .863 r
.37341 .32913 .38335 .34408 .40006 .33873 .39017 .32339 Mtetra
.648 .67 .857 r
.39017 .32339 .40006 .33873 .41689 .33284 .40705 .31743 Mtetra
.651 .671 .856 r
.40705 .31743 .41689 .33284 .43384 .32643 .42403 .31126 Mtetra
.655 .677 .859 r
.42403 .31126 .43384 .32643 .4509 .31952 .44113 .30492 Mtetra
.658 .689 .868 r
.44113 .30492 .4509 .31952 .46807 .3122 .45833 .29849 Mtetra
.659 .705 .881 r
.45833 .29849 .46807 .3122 .48533 .30508 .47564 .29206 Mtetra
.657 .718 .893 r
.47564 .29206 .48533 .30508 .50269 .29806 .49305 .28578 Mtetra
.653 .732 .907 r
.49305 .28578 .50269 .29806 .52014 .29125 .51057 .27968 Mtetra
.65 .746 .919 r
.51057 .27968 .52014 .29125 .5377 .28484 .5282 .27367 Mtetra
.656 .758 .925 r
.5282 .27367 .5377 .28484 .55538 .27878 .54595 .26741 Mtetra
.66 .756 .921 r
.54595 .26741 .55538 .27878 .57317 .27277 .56381 .26093 Mtetra
.66 .748 .916 r
.56381 .26093 .57317 .27277 .59107 .26633 .58179 .25439 Mtetra
.658 .747 .916 r
.58179 .25439 .59107 .26633 .60908 .2598 .59988 .24789 Mtetra
.655 .748 .918 r
.59988 .24789 .60908 .2598 .62721 .25331 .6181 .24149 Mtetra
.651 .75 .922 r
.6181 .24149 .62721 .25331 .64546 .24693 .63644 .23523 Mtetra
.653 .755 .924 r
.63644 .23523 .64546 .24693 .66384 .24073 .65489 .22881 Mtetra
.658 .754 .921 r
.65489 .22881 .66384 .24073 .68234 .23432 .67347 .22214 Mtetra
.659 .751 .918 r
.67347 .22214 .68234 .23432 .70095 .22767 .69216 .2154 Mtetra
.658 .75 .918 r
.69216 .2154 .70095 .22767 .71968 .22097 .71098 .20868 Mtetra
.652 .749 .921 r
.71098 .20868 .71968 .22097 .73854 .21434 .72993 .20213 Mtetra
.653 .753 .923 r
.72993 .20213 .73854 .21434 .75754 .20785 .74902 .19549 Mtetra
.655 .751 .92 r
.07743 .41894 .08869 .42878 .10372 .42338 .0925 .41359 Mtetra
.659 .754 .92 r
.0925 .41359 .10372 .42338 .11885 .4179 .10768 .40806 Mtetra
.659 .754 .921 r
.10768 .40806 .11885 .4179 .13404 .4126 .12295 .40253 Mtetra
.654 .749 .92 r
.12295 .40253 .13404 .4126 .14932 .40732 .13828 .39715 Mtetra
.652 .748 .92 r
.13828 .39715 .14932 .40732 .1647 .40199 .1537 .39178 Mtetra
.653 .749 .92 r
.1537 .39178 .1647 .40199 .18018 .39642 .16922 .38634 Mtetra
.658 .754 .921 r
.16922 .38634 .18018 .39642 .19578 .39071 .18486 .38069 Mtetra
.661 .758 .922 r
.18486 .38069 .19578 .39071 .21144 .38514 .2006 .3749 Mtetra
.658 .753 .92 r
.2006 .3749 .21144 .38514 .22719 .37968 .21642 .36919 Mtetra
.654 .748 .919 r
.21642 .36919 .22719 .37968 .24303 .37425 .23233 .3636 Mtetra
.652 .746 .918 r
.23233 .3636 .24303 .37425 .25897 .36878 .24833 .35802 Mtetra
.652 .745 .918 r
.24833 .35802 .25897 .36878 .27503 .36311 .26442 .35244 Mtetra
.653 .748 .92 r
.26442 .35244 .27503 .36311 .2912 .35718 .28063 .3468 Mtetra
.656 .756 .924 r
.28063 .3468 .2912 .35718 .30745 .35136 .29694 .341 Mtetra
.66 .76 .924 r
.29694 .341 .30745 .35136 .32379 .3457 .31336 .33499 Mtetra
.659 .753 .92 r
.31336 .33499 .32379 .3457 .34023 .34021 .32988 .329 Mtetra
.657 .744 .914 r
.32988 .329 .34023 .34021 .35676 .33471 .3465 .32304 Mtetra
.655 .736 .909 r
.3465 .32304 .35676 .33471 .37341 .32913 .36322 .31707 Mtetra
.655 .729 .904 r
.36322 .31707 .37341 .32913 .39017 .32339 .38005 .31109 Mtetra
.655 .726 .902 r
.38005 .31109 .39017 .32339 .40705 .31743 .39699 .30506 Mtetra
.39699 .30506 .40705 .31743 .42403 .31126 .41403 .29898 Mtetra
.655 .729 .904 r
.41403 .29898 .42403 .31126 .44113 .30492 .43118 .29289 Mtetra
.654 .735 .909 r
.43118 .29289 .44113 .30492 .45833 .29849 .44843 .28679 Mtetra
.653 .743 .916 r
.44843 .28679 .45833 .29849 .47564 .29206 .4658 .28072 Mtetra
.652 .751 .922 r
.4658 .28072 .47564 .29206 .49305 .28578 .48328 .27466 Mtetra
.656 .758 .925 r
.48328 .27466 .49305 .28578 .51057 .27968 .50088 .26839 Mtetra
.659 .757 .923 r
.50088 .26839 .51057 .27968 .5282 .27367 .51859 .26196 Mtetra
.66 .751 .917 r
.51859 .26196 .5282 .27367 .54595 .26741 .53641 .25545 Mtetra
.659 .747 .915 r
.53641 .25545 .54595 .26741 .56381 .26093 .55435 .24894 Mtetra
.657 .747 .916 r
.55435 .24894 .56381 .26093 .58179 .25439 .5724 .24243 Mtetra
.654 .748 .919 r
.5724 .24243 .58179 .25439 .59988 .24789 .59058 .23604 Mtetra
.651 .751 .923 r
.59058 .23604 .59988 .24789 .6181 .24149 .60888 .22973 Mtetra
.654 .755 .924 r
.60888 .22973 .6181 .24149 .63644 .23523 .62729 .22326 Mtetra
.658 .754 .921 r
.62729 .22326 .63644 .23523 .65489 .22881 .64583 .21657 Mtetra
.659 .751 .918 r
.64583 .21657 .65489 .22881 .67347 .22214 .66448 .20979 Mtetra
.658 .75 .918 r
.66448 .20979 .67347 .22214 .69216 .2154 .68326 .20302 Mtetra
.653 .749 .92 r
.68326 .20302 .69216 .2154 .71098 .20868 .70217 .19639 Mtetra
.653 .752 .923 r
.70217 .19639 .71098 .20868 .72993 .20213 .72122 .18975 Mtetra
.656 .754 .922 r
.72122 .18975 .72993 .20213 .74902 .19549 .74038 .18291 Mtetra
.654 .75 .92 r
.06606 .40894 .07743 .41894 .0925 .41359 .08117 .40359 Mtetra
.656 .751 .92 r
.08117 .40359 .0925 .41359 .10768 .40806 .09639 .39814 Mtetra
.66 .755 .921 r
.09639 .39814 .10768 .40806 .12295 .40253 .11171 .3925 Mtetra
.658 .754 .921 r
.11171 .3925 .12295 .40253 .13828 .39715 .12711 .38689 Mtetra
.654 .749 .92 r
.12711 .38689 .13828 .39715 .1537 .39178 .14259 .38142 Mtetra
.653 .748 .92 r
.14259 .38142 .1537 .39178 .16922 .38634 .15816 .37594 Mtetra
.653 .749 .92 r
.15816 .37594 .16922 .38634 .18486 .38069 .17383 .37041 Mtetra
.657 .753 .921 r
.17383 .37041 .18486 .38069 .2006 .3749 .18961 .36472 Mtetra
.66 .758 .922 r
.18961 .36472 .2006 .3749 .21642 .36919 .2055 .35884 Mtetra
.66 .755 .921 r
.2055 .35884 .21642 .36919 .23233 .3636 .22149 .35297 Mtetra
.655 .75 .919 r
.22149 .35297 .23233 .3636 .24833 .35802 .23755 .34723 Mtetra
.654 .747 .918 r
.23755 .34723 .24833 .35802 .26442 .35244 .25371 .3415 Mtetra
.653 .745 .917 r
.25371 .3415 .26442 .35244 .28063 .3468 .26997 .33576 Mtetra
.26997 .33576 .28063 .3468 .29694 .341 .28634 .33001 Mtetra
.653 .747 .919 r
.28634 .33001 .29694 .341 .31336 .33499 .3028 .3242 Mtetra
.654 .753 .922 r
.3028 .3242 .31336 .33499 .32988 .329 .31938 .31832 Mtetra
.655 .757 .925 r
.31938 .31832 .32988 .329 .3465 .32304 .33606 .31237 Mtetra
.656 .759 .926 r
.33606 .31237 .3465 .32304 .36322 .31707 .35285 .30635 Mtetra
.657 .759 .925 r
.35285 .30635 .36322 .31707 .38005 .31109 .36974 .30026 Mtetra
.656 .758 .925 r
.36974 .30026 .38005 .31109 .39699 .30506 .38674 .29416 Mtetra
.655 .758 .925 r
.38674 .29416 .39699 .30506 .41403 .29898 .40385 .28805 Mtetra
.656 .759 .926 r
.40385 .28805 .41403 .29898 .43118 .29289 .42107 .28187 Mtetra
.657 .759 .925 r
.42107 .28187 .43118 .29289 .44843 .28679 .43841 .27561 Mtetra
.657 .757 .924 r
.43841 .27561 .44843 .28679 .4658 .28072 .45585 .26929 Mtetra
.658 .754 .921 r
.45585 .26929 .4658 .28072 .48328 .27466 .47341 .26289 Mtetra
.659 .749 .917 r
.47341 .26289 .48328 .27466 .50088 .26839 .49108 .25643 Mtetra
.658 .747 .915 r
.49108 .25643 .50088 .26839 .51859 .26196 .50886 .24994 Mtetra
.657 .747 .916 r
.50886 .24994 .51859 .26196 .53641 .25545 .52676 .24345 Mtetra
.656 .748 .917 r
.52676 .24345 .53641 .25545 .55435 .24894 .54477 .23696 Mtetra
.652 .748 .92 r
.54477 .23696 .55435 .24894 .5724 .24243 .56291 .2306 Mtetra
.651 .753 .924 r
.56291 .2306 .5724 .24243 .59058 .23604 .58116 .22423 Mtetra
.655 .756 .924 r
.58116 .22423 .59058 .23604 .60888 .22973 .59954 .21767 Mtetra
.658 .754 .921 r
.59954 .21767 .60888 .22973 .62729 .22326 .61803 .21094 Mtetra
.659 .75 .918 r
.61803 .21094 .62729 .22326 .64583 .21657 .63665 .20414 Mtetra
.658 .75 .918 r
.63665 .20414 .64583 .21657 .66448 .20979 .65539 .19733 Mtetra
.654 .749 .92 r
.65539 .19733 .66448 .20979 .68326 .20302 .67426 .19064 Mtetra
.652 .752 .923 r
.67426 .19064 .68326 .20302 .70217 .19639 .69327 .18398 Mtetra
.656 .754 .922 r
.69327 .18398 .70217 .19639 .72122 .18975 .71239 .17711 Mtetra
.658 .752 .92 r
.71239 .17711 .72122 .18975 .74038 .18291 .73164 .17012 Mtetra
.653 .749 .92 r
.05457 .39882 .06606 .40894 .08117 .40359 .06972 .39343 Mtetra
.654 .75 .92 r
.06972 .39343 .08117 .40359 .09639 .39814 .08498 .38797 Mtetra
.656 .752 .92 r
.08498 .38797 .09639 .39814 .11171 .3925 .10033 .38241 Mtetra
.659 .755 .921 r
.10033 .38241 .11171 .3925 .12711 .38689 .1158 .37669 Mtetra
.658 .754 .921 r
.1158 .37669 .12711 .38689 .14259 .38142 .13135 .37098 Mtetra
.654 .749 .92 r
.13135 .37098 .14259 .38142 .15816 .37594 .14698 .3654 Mtetra
.653 .748 .919 r
.14698 .3654 .15816 .37594 .17383 .37041 .1627 .35981 Mtetra
.653 .748 .92 r
.1627 .35981 .17383 .37041 .18961 .36472 .17852 .35418 Mtetra
.655 .751 .921 r
.17852 .35418 .18961 .36472 .2055 .35884 .19445 .34846 Mtetra
.659 .757 .922 r
.19445 .34846 .2055 .35884 .22149 .35297 .21049 .34254 Mtetra
.66 .758 .922 r
.21049 .34254 .22149 .35297 .23755 .34723 .22663 .33656 Mtetra
.658 .754 .92 r
.22663 .33656 .23755 .34723 .25371 .3415 .24287 .33059 Mtetra
.655 .749 .919 r
.24287 .33059 .25371 .3415 .26997 .33576 .25919 .32471 Mtetra
.654 .747 .918 r
.25919 .32471 .26997 .33576 .28634 .33001 .27562 .31881 Mtetra
.654 .746 .917 r
.27562 .31881 .28634 .33001 .3028 .3242 .29215 .31289 Mtetra
.654 .745 .916 r
.29215 .31289 .3028 .3242 .31938 .31832 .30879 .30693 Mtetra
.30879 .30693 .31938 .31832 .33606 .31237 .32553 .30094 Mtetra
.655 .745 .916 r
.32553 .30094 .33606 .31237 .35285 .30635 .34238 .29488 Mtetra
.655 .746 .917 r
.34238 .29488 .35285 .30635 .36974 .30026 .35934 .28877 Mtetra
.656 .747 .917 r
.35934 .28877 .36974 .30026 .38674 .29416 .3764 .2826 Mtetra
.656 .748 .917 r
.3764 .2826 .38674 .29416 .40385 .28805 .39358 .27637 Mtetra
.657 .747 .916 r
.39358 .27637 .40385 .28805 .42107 .28187 .41087 .27007 Mtetra
.657 .746 .916 r
.41087 .27007 .42107 .28187 .43841 .27561 .42827 .26372 Mtetra
.657 .746 .915 r
.42827 .26372 .43841 .27561 .45585 .26929 .44579 .25733 Mtetra
.44579 .25733 .45585 .26929 .47341 .26289 .46342 .25089 Mtetra
.657 .747 .916 r
.46342 .25089 .47341 .26289 .49108 .25643 .48116 .24443 Mtetra
.656 .748 .917 r
.48116 .24443 .49108 .25643 .50886 .24994 .49901 .23795 Mtetra
.653 .748 .92 r
.49901 .23795 .50886 .24994 .52676 .24345 .51699 .23155 Mtetra
.652 .751 .923 r
.51699 .23155 .52676 .24345 .54477 .23696 .53508 .22516 Mtetra
.653 .755 .925 r
.53508 .22516 .54477 .23696 .56291 .2306 .55329 .21871 Mtetra
.657 .756 .923 r
.55329 .21871 .56291 .2306 .58116 .22423 .57163 .21203 Mtetra
.658 .753 .92 r
.57163 .21203 .58116 .22423 .59954 .21767 .59008 .20526 Mtetra
.658 .75 .918 r
.59008 .20526 .59954 .21767 .61803 .21094 .60866 .19843 Mtetra
.657 .749 .918 r
.60866 .19843 .61803 .21094 .63665 .20414 .62736 .1916 Mtetra
.654 .749 .92 r
.62736 .1916 .63665 .20414 .65539 .19733 .64619 .18488 Mtetra
.652 .752 .922 r
.64619 .18488 .65539 .19733 .67426 .19064 .66515 .17816 Mtetra
.656 .754 .922 r
.66515 .17816 .67426 .19064 .69327 .18398 .68424 .17127 Mtetra
.657 .752 .92 r
.68424 .17127 .69327 .18398 .71239 .17711 .70345 .16426 Mtetra
.658 .751 .919 r
.70345 .16426 .71239 .17711 .73164 .17012 .72279 .15716 Mtetra
.655 .751 .92 r
.04294 .38864 .05457 .39882 .06972 .39343 .05815 .38312 Mtetra
.653 .749 .92 r
.05815 .38312 .06972 .39343 .08498 .38797 .07345 .37764 Mtetra
.654 .75 .92 r
.07345 .37764 .08498 .38797 .10033 .38241 .08885 .37208 Mtetra
.656 .752 .92 r
.08885 .37208 .10033 .38241 .1158 .37669 .10435 .36643 Mtetra
.659 .755 .921 r
.10435 .36643 .1158 .37669 .13135 .37098 .11996 .36062 Mtetra
.659 .754 .921 r
.11996 .36062 .13135 .37098 .14698 .3654 .13567 .35479 Mtetra
.654 .75 .92 r
.13567 .35479 .14698 .3654 .1627 .35981 .15145 .34908 Mtetra
.653 .748 .919 r
.15145 .34908 .1627 .35981 .17852 .35418 .16733 .34338 Mtetra
.16733 .34338 .17852 .35418 .19445 .34846 .1833 .33765 Mtetra
.654 .749 .92 r
.1833 .33765 .19445 .34846 .21049 .34254 .19938 .33186 Mtetra
.656 .754 .922 r
.19938 .33186 .21049 .34254 .22663 .33656 .21556 .32596 Mtetra
.659 .758 .923 r
.21556 .32596 .22663 .33656 .24287 .33059 .23186 .31991 Mtetra
.659 .757 .923 r
.23186 .31991 .24287 .33059 .25919 .32471 .24826 .31382 Mtetra
.658 .754 .921 r
.24826 .31382 .25919 .32471 .27562 .31881 .26476 .30771 Mtetra
.657 .751 .919 r
.26476 .30771 .27562 .31881 .29215 .31289 .28136 .30163 Mtetra
.655 .749 .919 r
.28136 .30163 .29215 .31289 .30879 .30693 .29806 .29555 Mtetra
.655 .748 .918 r
.29806 .29555 .30879 .30693 .32553 .30094 .31487 .28944 Mtetra
.655 .747 .917 r
.31487 .28944 .32553 .30094 .34238 .29488 .33179 .28328 Mtetra
.655 .746 .917 r
.33179 .28328 .34238 .29488 .35934 .28877 .34881 .27709 Mtetra
.656 .746 .917 r
.34881 .27709 .35934 .28877 .3764 .2826 .36595 .27084 Mtetra
.656 .746 .916 r
.36595 .27084 .3764 .2826 .39358 .27637 .38319 .26455 Mtetra
.656 .747 .917 r
.38319 .26455 .39358 .27637 .41087 .27007 .40055 .2582 Mtetra
.40055 .2582 .41087 .27007 .42827 .26372 .41802 .25182 Mtetra
.656 .748 .918 r
.41802 .25182 .42827 .26372 .44579 .25733 .4356 .2454 Mtetra
.655 .749 .919 r
.4356 .2454 .44579 .25733 .46342 .25089 .4533 .23899 Mtetra
.653 .75 .921 r
.4533 .23899 .46342 .25089 .48116 .24443 .47111 .23259 Mtetra
.653 .753 .923 r
.47111 .23259 .48116 .24443 .49901 .23795 .48904 .22617 Mtetra
.653 .755 .925 r
.48904 .22617 .49901 .23795 .51699 .23155 .50709 .21971 Mtetra
.656 .757 .924 r
.50709 .21971 .51699 .23155 .53508 .22516 .52527 .21308 Mtetra
.657 .754 .921 r
.52527 .21308 .53508 .22516 .55329 .21871 .54356 .20634 Mtetra
.658 .751 .918 r
.54356 .20634 .55329 .21871 .57163 .21203 .56197 .19953 Mtetra
.658 .749 .918 r
.56197 .19953 .57163 .21203 .59008 .20526 .58051 .19269 Mtetra
.657 .749 .918 r
.58051 .19269 .59008 .20526 .60866 .19843 .59917 .18583 Mtetra
.653 .749 .92 r
.59917 .18583 .60866 .19843 .62736 .1916 .61796 .1791 Mtetra
.653 .752 .923 r
.61796 .1791 .62736 .1916 .64619 .18488 .63688 .17234 Mtetra
.656 .754 .922 r
.63688 .17234 .64619 .18488 .66515 .17816 .65592 .1654 Mtetra
.657 .752 .92 r
.65592 .1654 .66515 .17816 .68424 .17127 .67509 .15835 Mtetra
.658 .751 .919 r
.67509 .15835 .68424 .17127 .70345 .16426 .69439 .15121 Mtetra
.657 .75 .919 r
.69439 .15121 .70345 .16426 .72279 .15716 .71382 .14409 Mtetra
.658 .754 .92 r
.03116 .37846 .04294 .38864 .05815 .38312 .04644 .37276 Mtetra
.655 .75 .92 r
.04644 .37276 .05815 .38312 .07345 .37764 .0618 .36715 Mtetra
.653 .749 .92 r
.0618 .36715 .07345 .37764 .08885 .37208 .07725 .36156 Mtetra
.654 .75 .92 r
.07725 .36156 .08885 .37208 .10435 .36643 .09279 .35591 Mtetra
.656 .751 .92 r
.09279 .35591 .10435 .36643 .11996 .36062 .10844 .35017 Mtetra
.658 .755 .921 r
.10844 .35017 .11996 .36062 .13567 .35479 .1242 .34428 Mtetra
.659 .755 .921 r
.1242 .34428 .13567 .35479 .15145 .34908 .14005 .33835 Mtetra
.656 .751 .92 r
.14005 .33835 .15145 .34908 .16733 .34338 .156 .33248 Mtetra
.654 .749 .919 r
.156 .33248 .16733 .34338 .1833 .33765 .17203 .32665 Mtetra
.654 .748 .919 r
.17203 .32665 .1833 .33765 .19938 .33186 .18817 .3208 Mtetra
.18817 .3208 .19938 .33186 .21556 .32596 .2044 .31491 Mtetra
.654 .75 .92 r
.2044 .31491 .21556 .32596 .23186 .31991 .22074 .30896 Mtetra
.655 .753 .922 r
.22074 .30896 .23186 .31991 .24826 .31382 .23719 .30294 Mtetra
.657 .757 .923 r
.23719 .30294 .24826 .31382 .26476 .30771 .25375 .2968 Mtetra
.658 .758 .924 r
.25375 .2968 .26476 .30771 .28136 .30163 .27042 .2906 Mtetra
.658 .757 .923 r
.27042 .2906 .28136 .30163 .29806 .29555 .28719 .28438 Mtetra
.657 .755 .922 r
.28719 .28438 .29806 .29555 .31487 .28944 .30407 .27813 Mtetra
.657 .754 .921 r
.30407 .27813 .31487 .28944 .33179 .28328 .32105 .27185 Mtetra
.656 .753 .921 r
.32105 .27185 .33179 .28328 .34881 .27709 .33815 .26556 Mtetra
.656 .752 .921 r
.33815 .26556 .34881 .27709 .36595 .27084 .35535 .25924 Mtetra
.655 .752 .921 r
.35535 .25924 .36595 .27084 .38319 .26455 .37266 .25289 Mtetra
.37266 .25289 .38319 .26455 .40055 .2582 .39009 .24652 Mtetra
.655 .753 .922 r
.39009 .24652 .40055 .2582 .41802 .25182 .40763 .24013 Mtetra
.654 .754 .923 r
.40763 .24013 .41802 .25182 .4356 .2454 .42528 .23371 Mtetra
.654 .756 .924 r
.42528 .23371 .4356 .2454 .4533 .23899 .44305 .22726 Mtetra
.655 .757 .925 r
.44305 .22726 .4533 .23899 .47111 .23259 .46094 .22074 Mtetra
.656 .757 .924 r
.46094 .22074 .47111 .23259 .48904 .22617 .47895 .2141 Mtetra
.657 .754 .921 r
.47895 .2141 .48904 .22617 .50709 .21971 .49708 .20738 Mtetra
.658 .751 .919 r
.49708 .20738 .50709 .21971 .52527 .21308 .51533 .2006 Mtetra
.658 .749 .918 r
.51533 .2006 .52527 .21308 .54356 .20634 .53371 .19376 Mtetra
.657 .749 .918 r
.53371 .19376 .54356 .20634 .56197 .19953 .5522 .1869 Mtetra
.655 .749 .919 r
.5522 .1869 .56197 .19953 .58051 .19269 .57082 .18008 Mtetra
.653 .75 .921 r
.57082 .18008 .58051 .19269 .59917 .18583 .58957 .1733 Mtetra
.653 .753 .923 r
.58957 .1733 .59917 .18583 .61796 .1791 .60844 .16647 Mtetra
.656 .754 .922 r
.60844 .16647 .61796 .1791 .63688 .17234 .62744 .15948 Mtetra
.657 .752 .92 r
.62744 .15948 .63688 .17234 .65592 .1654 .64657 .15239 Mtetra
.658 .751 .919 r
.64657 .15239 .65592 .1654 .67509 .15835 .66583 .14522 Mtetra
.657 .75 .919 r
.66583 .14522 .67509 .15835 .69439 .15121 .68522 .13806 Mtetra
.654 .75 .92 r
.68522 .13806 .69439 .15121 .71382 .14409 .70475 .13097 Mtetra
.658 .753 .92 r
.01925 .36814 .03116 .37846 .04644 .37276 .03458 .3624 Mtetra
.658 .754 .921 r
.03458 .3624 .04644 .37276 .0618 .36715 .05001 .3566 Mtetra
.655 .751 .92 r
.05001 .3566 .0618 .36715 .07725 .36156 .06551 .35088 Mtetra
.653 .749 .92 r
.06551 .35088 .07725 .36156 .09279 .35591 .08111 .34519 Mtetra
.654 .749 .92 r
.08111 .34519 .09279 .35591 .10844 .35017 .0968 .33944 Mtetra
.655 .751 .92 r
.0968 .33944 .10844 .35017 .1242 .34428 .1126 .33361 Mtetra
.657 .754 .921 r
.1126 .33361 .1242 .34428 .14005 .33835 .1285 .32767 Mtetra
.659 .755 .922 r
.1285 .32767 .14005 .33835 .156 .33248 .14452 .32164 Mtetra
.658 .753 .92 r
.14452 .32164 .156 .33248 .17203 .32665 .16062 .31559 Mtetra
.655 .75 .919 r
.16062 .31559 .17203 .32665 .18817 .3208 .17682 .30961 Mtetra
.654 .748 .919 r
.17682 .30961 .18817 .3208 .2044 .31491 .19312 .30363 Mtetra
.19312 .30363 .2044 .31491 .22074 .30896 .20952 .29762 Mtetra
.20952 .29762 .22074 .30896 .23719 .30294 .22602 .29157 Mtetra
.654 .749 .919 r
.22602 .29157 .23719 .30294 .25375 .2968 .24264 .28546 Mtetra
.655 .751 .92 r
.24264 .28546 .25375 .2968 .27042 .2906 .25936 .2793 Mtetra
.655 .753 .922 r
.25936 .2793 .27042 .2906 .28719 .28438 .27619 .27309 Mtetra
.656 .755 .923 r
.27619 .27309 .28719 .28438 .30407 .27813 .29313 .26682 Mtetra
.656 .756 .924 r
.29313 .26682 .30407 .27813 .32105 .27185 .31018 .26051 Mtetra
.656 .757 .924 r
.31018 .26051 .32105 .27185 .33815 .26556 .32734 .25415 Mtetra
.32734 .25415 .33815 .26556 .35535 .25924 .34461 .24776 Mtetra
.34461 .24776 .35535 .25924 .37266 .25289 .36199 .24132 Mtetra
.36199 .24132 .37266 .25289 .39009 .24652 .37949 .23484 Mtetra
.656 .756 .924 r
.37949 .23484 .39009 .24652 .40763 .24013 .39711 .22831 Mtetra
.656 .755 .923 r
.39711 .22831 .40763 .24013 .42528 .23371 .41484 .22172 Mtetra
.657 .754 .921 r
.41484 .22172 .42528 .23371 .44305 .22726 .43269 .21508 Mtetra
.657 .752 .92 r
.43269 .21508 .44305 .22726 .46094 .22074 .45066 .20837 Mtetra
.657 .75 .918 r
.45066 .20837 .46094 .22074 .47895 .2141 .46874 .20161 Mtetra
.657 .749 .918 r
.46874 .20161 .47895 .2141 .49708 .20738 .48695 .1948 Mtetra
.48695 .1948 .49708 .20738 .51533 .2006 .50528 .18796 Mtetra
.656 .749 .918 r
.50528 .18796 .51533 .2006 .53371 .19376 .52373 .1811 Mtetra
.654 .749 .92 r
.52373 .1811 .53371 .19376 .5522 .1869 .54231 .17431 Mtetra
.653 .752 .922 r
.54231 .17431 .5522 .1869 .57082 .18008 .56101 .1675 Mtetra
.655 .754 .923 r
.56101 .1675 .57082 .18008 .58957 .1733 .57984 .16057 Mtetra
.656 .754 .922 r
.57984 .16057 .58957 .1733 .60844 .16647 .5988 .15353 Mtetra
.657 .752 .92 r
.5988 .15353 .60844 .16647 .62744 .15948 .61789 .14639 Mtetra
.658 .751 .919 r
.61789 .14639 .62744 .15948 .64657 .15239 .6371 .13918 Mtetra
.656 .75 .919 r
.6371 .13918 .64657 .15239 .66583 .14522 .65645 .13199 Mtetra
.654 .75 .92 r
.65645 .13199 .66583 .14522 .68522 .13806 .67594 .12486 Mtetra
.654 .752 .922 r
.67594 .12486 .68522 .13806 .70475 .13097 .69557 .11767 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
[(-2)] .12586 .2075 1 .99877 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.56863 .04703 m
.57247 .05235 L
s
[(2)] .56094 .0364 .72324 1 Mshowa
.125 Mabswid
.18558 .19702 m
.18832 .19985 L
s
.23703 .17687 m
.23971 .17975 L
s
.28951 .15632 m
.29214 .15925 L
s
.39772 .11395 m
.40023 .11699 L
s
.4535 .09211 m
.45595 .0952 L
s
.51046 .06981 m
.51284 .07294 L
s
.08568 .23614 m
.08851 .23887 L
s
.62804 .02377 m
.63027 .02701 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 233.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00o?ooool2o`0006[ooooo003iooooo`?o000000?oooooo`000?ooool0
JOooool00?Oooooo0_l00004ooooo`;o0000JOooool00?Cooooo0ol00006ooooo`03o`000?oooooo
000006Sooooo003;ooooo`Go00008_ooool2o`0000Wooooo00?o0000ooooool00000J?ooool00<_o
oooo00GoV9RHob4Q8Oo^k^koooooodA4A00Oooooo`?o00002oooool01?l0003oooooooooool0001W
ooooo`00c?ooool00onHV9So8B4Qonk^kP0Mooooo`?o00003_ooool01Ol0003ooooooooooooooooo
000006Kooooo003=ooooo`03oiRHV?lQ8B7ok^k^01[ooooo0_l0000Aooooo`05o`000?oooooooooo
ooooool00000I_ooool00<kooooo00?oMgMgofIVI_ooool05_ooool3o`0001?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1Sooooo`00coooool00ol0003oooooooooo`0Cooooo`;o
00000_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0H_ooool00<_ooooo00Go0000okZj^_ooooooV9RHoa0@400Booooo`?o00006Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo06;ooooo003;ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`04?ooool2o`0001cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Qooooo`00
gOooool3o`0001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Qooooo`00fooo
ool2o`00027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Pooooo`00f?ooool3
o`0002?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Oooooo`00eOooool3o`00
02Kooooo00?o0000ooooooooool01?ooool2o`00067ooooo003Cooooo`;o0000:Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo05kooooo003@ooooo`?o000000?oooooo`000?ooool0
:?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05gooooo003>ooooo`;o00001Ooo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0GOoo
ool00<_ooooo0ol0000`ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0G?ooool0
0<Wooooo0_l0000cooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Foooool00<Ko
oooo0ol0000eooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Foooool00<Cooooo
0_l0000hooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0F_ooool00<7ooooo0ol0
000jooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03_ooool5o`0004Kooooo002n
ooooo`?o0000?Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00kooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A016ooooo`00_?ooool2o`0000?ooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo1_l00003ooooo`03oiRHV?lQ8B7o
k^k^04Oooooo002iooooo`?o0000@oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00kooooo00?oV9RHob4Q8Oo^k^h0A_ooool00;Oooooo0_l00016ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03oooool00omgMgOoIVIVooooo`15ooooo`00]?ooool3o`0004Sooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Cooooo
002booooo`;o0000Boooool00ol0003oooooooooo`0=ooooo`;o00003?ooool01Ol0003o^[Zjoooo
oonHV9So410@04Kooooo002_ooooo`?o0000COooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c016ooooo`00[Oooool2o`00053ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`1Dooooo`00Z_ooool4o`00057ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1Dooooo`00Z?ooool2o`0000Cooooo00?o0000oooo
ooooool0C_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05?ooooo001nooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h08_ooool3o`0005Oooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`1Booooo`00O_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01oooooo0ol0001Joooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool0D_ooool007kooooo00Go410@oooooooo
oooooooooa0@400Mooooo`;o0000GOooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
057ooooo001nooooo`05o`000?ooooooooooooooool000006_ooool3o`0005oooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`1@ooooo`00O_ooool01Ol0003ooooooooooooooooo0000
01Sooooo0_l0001Rooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0D?ooool007ko
oooo00Go410@oooooooooooooooooa0@400Eooooo`?o0000I?ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo04oooooo001nooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool2o`00
00?ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
04kooooo001nooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04?ooool3o`0006Sooooo00?oYl3/o`00
0?ooool05_ooool00ol0003oooooooooo`1>ooooo`00TOooool2o`0006Sooooo1?nW`>`00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo04gooooo002>ooooo`?o0000J?ooool7ojO0k003o`00
0?oooooooooo01Cooooo0ol0001>ooooo`00Roooool3o`0006Wooooo0_nW_n/7ojO0k003o`000?oo
oooooooo01Kooooo00?o0000ooooooooool0C?ooool008Wooooo0_l0001Yooooo`KoYko[1_nW`>`0
0ol0003oYl3/ooooo`0Gooooo`03o`000?oooooooooo04_ooooo0026ooooo`?o0000J?ooool:ojNo
j`GoYl3/00?o0000ojNojoooool06?ooool00ol0003oooooooooo`1:ooooo`00Q?ooool2o`0000;o
oooo00?o0000ooooooooool0Hoooool>ojNoj`;oYl3/0_nW_n/00ol0003oYko[ojNoj`0Hooooo`03
o`000?oooooooooo04[ooooo0021ooooo`?o00001Oooool00ol0003oooooooooo`1Pooooo`ooYko[
00?oZ;o[ojNojonW_n/00_nW_n/01?l0003oYko[ojNojonW_n/Hooooo`03o`000?oooooooooo04Wo
oooo001oooooo`;o0000JOooool00onX`>_oYko[ojNoj`0;ojNoj`GoZ;o[0onW_n/00ol0003oYko[
ojNoj`02ojNojaSooooo00?o0000ooooooooool0B?ooool007cooooo0ol0001Xooooo`GoZ<3[2_nW
_n/8ojRoj`;oYko[00Go0000ojNojonW_n_oYko[ojRoj`0Hooooo`03o`000?oooooooooo04Sooooo
001jooooo`;o0000Ioooool:ojS0j`KoYko[0_nX`>/9ojRoj`;oYko[00?o0000ojNojonX_n/00onX
_n/Hooooo`03o`000?oooooooooo04Oooooo001gooooo`?o0000I_ooool>ojS0j`;oYko[1_nX`>/9
ojRoj`03ojNojol0003oZ;o[00GoZ;o[6?ooool00ol0003oooooooooo`16ooooo`00M?ooool3o`00
06Kooooo00?oYl7/ojS0jonX`>/05onX`>/6ojRoj`;oZ<3[00?oZ;o[o`000?nX_n/01OnX_n/Hoooo
o`03o`000?oooooooooo04Kooooo001booooo`;o00000_ooool00ol0003oooooooooo`1Rooooo`Co
Yl7/6OnX`>/2ojRoj`KoZ<3[00?o0000ojRojonX_n/01OnX_n/Hooooo`03o`000?oooooooooo04Go
oooo001_ooooo`?o0000Ioooool7ojO1k0OoZ<3[00?oYl7/ojS0jonX`>/05_nX`>/00ol0003oZ;o[
ojRoj`04ojRoj`03ojS0jooooooooooo01Kooooo00?o0000ooooooooool0AOooool006gooooo0_l0
001Wooooo`[oYl7/1?nX`>/5ojO1k1OoZ<3[00Co0000ojS0jonX_n_oZ;o[1OnX`>/Gooooo`;o0000
A_ooool006[ooooo0ol0001Vooooo`koYl7/00?oZ<3[ojO1k?nW`N`01_nW`N`7ojS0j`03ojO1k?nX
`>_oZ<3[00coZ<3[00?o0000ojS0jonX`>/01onX`>/Hooooo`03o`000?oooooooooo04?ooooo001X
ooooo`;o0000I_ooool2ojO0k0koYl7/0_nW`>`8ojO1k0CoZ<3[1OnW`N`=ojS0j`03o`000?nX`>_o
Z<3[00SoZ<3[5oooool00ol0003oooooooooo`13ooooo`00IOooool3o`0006Gooooo1_nW`>`:ojO1
k0KoYl3/2?nW`N`00onX`>_oYl7/ojO1k006ojO1k0KoZ<3[00?oYl7/ojS0jonX`>/00onX`>/00ol0
003oZ<3[ojS0j`08ojS0jaSooooo00?o0000ooooooooool0@_ooool006?ooooo0_l0001Uooooo`03
ojNojonW`>coYl3/00OoYl3/1_nW`N`00onW_n_oYl3/ojO0k007ojO0k0KoYl7/00?oYl3/ojO1k?nW
`N`01onW`N`4ojS0j`CoYl7/1OnX`>/00ol0003oZ<3[ojS0j`08ojS0jaSooooo00?o0000oooooooo
ool0@Oooool0063ooooo0ol000000ooooooo0000ooooo`1Rooooo`CoYko[2OnW`>`2ojO1k0GoYko[
2OnW`>`2ojO1k0GoYl3/2OnW`N`00onX`>_oYl7/ojO1k005ojO1k0CoZ<3[00Co0000ojS0jonX`>_o
Yl7/2?nX`>/Gooooo`03o`000?oooooooooo047ooooo000fooooo`Go00008oooool2o`0006Kooooo
1onW_n/7ojO0k0WoYko[1_nW`>`2ojNoj`SoYl3/1_nW`N`2ojK0k0SoYl7/1?nX`>/00ol0003oYl7/
ojO1k002ojO1k0SoZ<3[5oooool00ol0003oooooooooo`10ooooo`00=_ooool01OnHV9So8B4Qonk^
k_ooooooA4A4023ooooo0ol0001Uooooo`[oYko[1?nW`>`=ojNoj`;oYl3/1_nW_n/8ojO0k0;oYl7/
1_nV`>`8ojO1k004ojS0jonW`NcoYl7/o`0000GoYl7/1_nX`>/00onW`Ncoooooooooo`0Fooooo`03
o`000?oooooooooo03oooooo000^ooooo`Ko00000oooool00onHV9So8B4Qonk^kP0Nooooo`?o0000
IOooool>ojNoj`03ojO0k?nW_n_oYko[00coYko[00?oZ;o[ojNojonW_n/01onW_n/6ojO0k003ojNo
jonV`>coY/3/00OoY/3/1_nW`N`01OnV`>coYl7/ojO1k?nW`Nco000000GoYl7/1?nX`>/4ojO1k1Oo
oooo00?o0000ooooooooool0?oooool003Sooooo00?oV9RHob4Q8Oo^k^h06oooool2o`0006Gooooo
0_nX_n/>ojNoj`;oZ;o[3?nW_n/4ojRoj`WoYko[0_nW`>`5ojNoj`WoY/3/0_nW`N`5ojK0k0;oYl7/
00?o0000ojO1k?nW`N`01?nW`N`00onX`>_oYl7/ojO1k005ojO1k1Oooooo00?o0000ooooooooool0
?_ooool003Wooooo00?oMgMgofIVI_ooool05oooool3o`0006Cooooo1_nX_n/:ojNoj`KoZ;o[2OnW
_n/7ojRoj`OoYko[00?oZ;o[ojNojonW_n/01_nW_n/6ojK0k0;oYko[2?nV`>`00onW`Nco0000ojO1
k003ojO1k0;oYl3/2?nW`N`Hooooo`03o`000?oooooooooo03gooooo000jooooo`03o`000?oooooo
oooo01Cooooo0_l0001Tooooo`[oZ;o[1_nW_n/:ojRoj`KoYko[2_nX_n/4ojNoj`CoZ;o[2?nW_n/2
ojK0k0KoYko[2?nV`>`00ol0003oYl7/ojO0k005ojO0k0SoYl7/5oooool00ol0003oooooooooo`0m
ooooo`00=_ooool01Ol0003o^[ZjoooooonHV9So410@01?ooooo0ol00002ooooo`03o`000?oooooo
oooo05oooooo3OnX_n/2ojNoj`koZ;o[0_nW_n/>ojRoj`03ojNojonX_n_oZ;o[00GoZ;o[1_nW_n/0
0onX_n_oYko[ojNoj`07ojNoj`KoY/3/00?oYko[o`000?nW`>`01onW`>`6ojO1k003ojO0k?oooooo
oooo01Kooooo00?o0000ooooooooool0??ooool003Kooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00A
ooooo`;o0000IOooool>ojRoj`03ojS0jonX_n_oZ;o[00coZ;o[0_nX`>/HojRoj`CoYko[1?nX_n/9
ojNoj`;oY/3/1?nW_n/00ol0003oYl3/ojO0k007ojO0k0;oYl7/1OnW`>`Fooooo`?o0000?Oooool0
04Wooooo0ol0001Uooooo`koZ;o[1?nX`>/:ojRoj`KoZ<3[6?nX_n/00onW_n_oZ;o[ojRoj`05ojRo
j`OoYko[00?oZ;o[ojNojonW_n/01?nW_n/00ol0003oYko[ojO0k005ojO0k0;oY[o[2?nW`>`Goooo
o`03o`000?oooooooooo03_ooooo0017ooooo`;o0000IOooool?ojRoj`OoZ<3[1_nX_n/00onX`N_o
Z<3[ojS0j`07ojS0j`KoZ;o[00?oZ<3[ojRojonX_n/05_nX_n/4ojNoj`GoZ;o[1OnW_n/00ol0003o
Yko[ojNoj`02ojO0k0KoY[o[2?nW`>`Gooooo`03o`000?oooooooooo03[ooooo0014ooooo`?o0000
I?ooool00onX`>_oZ;o[ojRoj`0<ojRoj`;oZ<7[2?nX`>/4ojRoj`CoZ<7[2OnX`>/2ojRoj`GoZ<3[
6?nX_n/00onW_n_oZ;o[ojRoj`06ojRoj`CoYko[00?o0000ojNojonX_n/02OnV_n/6ojO0k003ojJo
k?oooooooooo01Kooooo00?o0000ooooooooool0>Oooool0047ooooo0ol0001Tooooo`GoZ<3[2_nX
_n/6ojS1j`SoZ<3[00?oZ;o[ojS1jonX`N/01OnX`N/7ojS0j`03ojS1k?nX`>_oZ<3[00KoZ<3[1_nX
_n/2ojS1j`koZ;o[0_nX`>/9ojRoj`;oYko[00?oZ;o[o`000?nX_n/00_nX_n/9ojJoj`;oYl3/1OnV
_n`Gooooo`03o`000?oooooooooo03Wooooo000oooooo`?o0000Hoooool00onX`N_oZ<3[ojS0j`06
ojS0j`KoZ;o[0_nW`N`8ojS1j`KoZ<3[0_nW`N`8ojS1j`CoZ<3[1?nX`N`8ojS0j`;oZ;o[1_nX`N/:
ojRoj`KoZ<3[1onX_n/01OnX`>_oZ;o[ojRojonX_n_o000000CoZ;o[1_nV_n/2ojNoj`SoY[o/5ooo
ool00ol0003oooooooooo`0hooooo`00??ooool3o`0000?ooooo00?o0000ooooooooool0G_ooool4
ojS1j`SoZ<3[0_nX_n/6ojO1k0SoZ<7[0_nX`>/6ojO1k0SoZ<7[00?oZ<3[ojS1k?nX`N`01OnX`N`6
ojS0j`;oYl7/2?nX`N/6ojRoj`03ojS1jonX`>_oZ<3[00OoZ<3[1?nX_n/4ojS0j`;oZ;o[00?o0000
ojRojonX_n/00onX_n/2ojJoj`KoYko[2?nV_n`Fooooo`03o`000?oooooooooo00Oooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0/ooooo`00>_ooool2o`0006Gooooo1onX`N/6ojS0j`[oYl7/1_nX`N/:
ojO1k0KoZ<7[00?oYl7/ojS1k?nX`N`01onX`N`2ojS0j`KoYl7/2?nX`N/2ojRoj`GoZ<7[2OnX`>/0
0onX_n_oZ<3[ojS0j`05ojS0j`03ojRojol0003oZ;o[00?oZ;o[00?oZ<3[ojNojonW_n/01onW_n/6
ojJok003ojNojooooooooooo01Gooooo00?o0000ooooooooool01_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg02cooooo000gooooo`?o0000IOooool00onW`NcoZ<7[ojS1j`07ojS1j`;oZ<3[3_nW`N`2
ojS1j`koYl7/0_nX`N/5ojO1k0OoZ<7/00?oY/3/ojO1k?nW`N`01onW`N`6ojS1j`03ojO1k?nX`N_o
Z<7[00KoZ<7[1_nX`>/2ojS1j`SoZ<3[0_nX_n/00ol0003oZ;o[ojS0j`03ojS0j`WoYko[0_nV_n`5
ojNojaOooooo00?o0000ooooooooool01Oooool01Ol@413ooooooooooooooooo410@02cooooo000e
ooooo`;o0000IOooool5ojO1k0OoZ<7[4?nW`N`00onW`>coYl7/ojO1k00<ojO1k0;oY/3/2?nW`N`4
ojS1k0CoY/3/2OnW`N`2ojS1j`GoYl7/2?nX`N/2ojS0j`KoZ<7[2?nX`>/00onX_n_o0000ojS0j`05
ojS0j`KoYko[0_nX`>/8ojNojaKooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooo
oooo000002cooooo000booooo`?o0000I?ooool9ojO1k0CoZ<7[3onW`N`5ojO0k0[oYl7/1_nV`>`8
ojO1k003ojS1k?nV`>coY/3/00GoY/3/1_nW`N`2ojK0k0SoYl7/1_nX`N/00onW`NcoZ<7[ojS1j`07
ojS1j`SoZ<3[00?o0000ojS0jonX`>/01OnX`>/2ojNoj`KoZ<3[2?nW_n/Fooooo`03o`000?oooooo
oooo00Cooooo00Go0000ooooooooooooooooo`00000/ooooo`00<?ooool2o`0006Cooooo3OnW`N`0
0onX`N_oYl7/ojO1k00<ojO1k003ojNojonW`>coYl3/00KoYl3/1_nW`N`2ojNoj`SoY/3/1_nW`N`0
0onV_n_oY/3/ojK0k007ojK0k0;oYl7/1_nV`>`8ojO1k0;oZ<7[1OnW`N`9ojS1j`OoZ<3[00?o0000
ojS0jonX`>/03OnX`>/6ojNoj`;oZ;o[5oooool00ol0003oooooooooo`03ooooo`05oa0@4?oooooo
ooooooooool@4100;?ooool002gooooo0ol000000ooooooo0000ooooo`1PoooooacoYl7/1OnW_n/8
ojO0k0;oYl7/1_nW_n/8ojK0k0;oYl7/1OnV_n/7ojK0k0;oYko[2?nV`>`6ojO1k003ojJok?nW`Nco
Yl7/00KoYl7/1_nX`N/2ojO1k0OoZ<3[00?o0000ojS0jonX`>/03_nX`>/2ojNoj`KoZ;o[5_ooool2
o`0000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0/ooooo`00:_ooool3o`0006?ooooo7?nW`N`9
ojNoj`KoYl3/0_nW_nX8ojNoj`KoY/3/00?oYkoZojJojonV_n/01_nV_n/4ojK0k0GoYko[2?nV`>`2
ojO1k0GoY[o/2?nW`N`2ojS1j`KoYl7/1_nX`>/00ol0003oZ<3[ojS0j`0>ojS0j`WoZ;o[4oooool2
o`000003ooooool0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0/ooooo`00:?ooool2
o`0006?ooooo3onW`N`2ojO0k0coYl7/3?nW_n/2ojO0k0KoYkoZ2?nW_n/2ojK0k0GoYkoZ2?nV_n/0
0onV`>coYko[ojNoj`06ojNoj`KoY/3/00?oYko[ojJok?nV_n`01_nV_n`6ojO1k003ojJok?nW`Nco
Yl7/00OoYl7/1OnX`>/00ol0003oYl7/ojS0j`0?ojS0j`WoZ;o[5_ooool00ol0003oooooooooo`0b
ooooo`009Oooool3o`0006;ooooo3onW`N`6ojO0k0WoYl7/3OnW_n/2ojRojPSoYkoZ1_nW_n/00onX
_n[oYkoZojNojP06ojNojPKoY[o[00?oZ;oZojNojonW_n/02?nW_n/2ojK0k0GoYko[2?nV_n`2ojO1
k0GoY[o/2OnW`N`2ojS0j`03ojO1k?l0003o000000;oYl7/4?nX`>/6ojRoj`;oZ<3[5_ooool00ol0
003oooooooooo`0booooo`008oooool2o`0006;ooooo3onW`N`2ojO0j`SoYl3/1_nW`N`<ojNoj`Ko
Z;oZ2?nW_nX2ojNoj`GoZ;oZ2?nW_nX2ojJoj`GoZ;oZ2?nW_n/00onX_n[oYko[ojNoj`06ojNoj`Ko
Y[o/00?oYko[ojJok?nV_n`01_nV_n`6ojO1k0;oY/3/0ol000000onW`Nco0000ojO1k002ojO1k0Ko
Z<3[00?oZ<7/ojS0jonX`>/01onX`>/2ojRoj`KoZ<3[5_ooool00ol0003oooooooooo`0aooooo`00
8?ooool3o`0006;ooooo3_nW`N`6ojO0j`SoYl3/0_nW`N`<ojNoj`03ojRnj_nX_n[oZ;oZ00OoZ;oZ
1_nW_nX9ojRojPKoYkoZ2OnX_nX4ojNoj`GoZ;oZ2?nW_n/2ojJok0GoYko[2?nV_n`2ojO1k0;oY/3/
0ol000000onV`>coYl7/ojO1k002ojO1k004o`000?nW`NcoYl7/ojO1k0;oZ<3[1OnX`N`@ojS0jaOo
oooo00?o0000ooooooooool0<?ooool001oooooo0_l0001Rooooo`goYl7/2_nW`>/6ojO0k003ojNo
j_nW_n_oYko[00[oYko[1?nX_^X9ojRojP;oYkoZ3OnX_nX2ojNojPgoZ;oZ00?oYko[ojRoj_nX_nX0
1_nX_nX6ojNoj`03ojRoj_nW_n_oYko[00KoYko[1_nV_n`00onW_n_oY/3/o`000002o`0000CoY/3/
1OnW`N`00ol0003oY/3/ojK0k008ojS1k13oZ<3[5_ooool00ol0003oooooooooo`0`ooooo`007ooo
ool00ol0003oooooo`00001Oooooo`coYl7/3_nW`>/2ojO0k0GoYkoZ2OnW_n/7ojRnjQKoZ;oZ00?o
Z<3ZojRoj_nX_nX05onX_nX2ojNoj`GoZ;oZ2?nW_n/2ojJok0;oYko[0ol00008ojK0k0;oYl7/0onV
`>`00ol0003oY/3/ojK0k008ojS1k0ooZ<3[5oooool00ol0003oooooooooo`0_ooooo`003?ooool5
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`04o`000?ooooooooooo`0005_ooooo
3?nW`N`@ojO0j`WoYkoZ1_nW_n/:ojRnjQ;oZ;oZ1OnX`>XGojRojP03ojVoj_nX_n[oZ;oZ00KoZ;oZ
1_nW_n/00onX_n[oYko[o`000002o`0000CoYko[1_nV`>`00onV_n_oY/3/ojK0k003ojK0k004o`00
0?nV`>coY/3/ojK0k0KoZ<7/00?oYl3/ojS0jonX`>/03_nX`>/Gooooo`03o`000?oooooooooo02ko
oooo000<ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Kooooo0_l00002ooooo`03o`000?oooooooooo05Gooooo3?nW`N`@ojO0j`goYkoZ0_nW_n/>ojRn
jPkoZ;oZ00?oZ<7/ojS0j_nX`>X01_nX`>X6ojRojP03ojS1jonX_n[oZ;oZ00_oZ;oZ1?nY_nX8ojRo
jP;oYko[0_nX_nX3o`0000SoYko[0_nV`>`5ojJoj`GoY/3/00Co0000ojK0k?nV`>coY/3/0_nX`N`5
ojO0k0OoZ<3[00?oZ<7/ojS0jonX`>/01_nX`>/Fooooo`03o`000?oooooooooo02kooooo0004oooo
o`Ko00000oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41001Oooool2
o`0000Cooooo00?o0000ooooooooool0DOooool=ojO1k0ooYl3[00?oYkkZojNoj_nW_nX03?nW_nX@
ojRnjP03ojS1jonX_n[oZ;oZ00WoZ;oZ1OnX`N`8ojS0jP;oZ;oZ1OnX`N/:ojRojPOoZKoZ1_nX_nX0
0onY`>[oZ;oZo`000002o`0000CoZ;oZ1_nW_n/00onX_n[oY[o[ojJoj`06ojJoj`GoY/3/00?o0000
ojJok?nV_n`02?nW`>`4ojS0j`CoZ<7/2?nX`>/Fooooo`03o`000?oooooooooo02gooooo000>oooo
o`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0COooool>ojO1k0koYl3[1OnW_^X:ojNojQ3oZ;kZ1OnX`N/7
ojRojP03ojO2k?nX`NcoZ<7/00KoZ<7/1_nX`>X00onW`^coZ<7[ojS1j`06ojS1j`KoZ;oZ0_nX`^`8
ojVojPCoZ;oZ0_nY`>X2o`0000SoZ;oZ0_nW_n/5ojRojPSoY[o[0_nV`>`2ojJok004o`000?nV_nco
Y[o/ojJok0SoYl3/00?oZ<3[ojS1k?nX`N`01OnX`N`7ojS0jaOooooo00?o0000ooooooooool0;?oo
ool000oooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`19ooooo`ooYl7/3OnW`>/9ojNnjPKoYkoZ0_nX
_nX>ojRnjP03ojS1k?nX`N_oZ<7[00KoZ<7[1?nX_nX4ojO2k0SoZ<7/0_nX`>X5ojO2k0SoZ<7[0_nX
_nX6ojS2k0SoZKoZ00?oZ;oZojW0j_l000000_l00003ojW0jPKoZ;oZ00?oZKoZojRoj_nX_nX01_nX
_nX6ojJoj`03ojRojonV_ncoY[o/00?oY[o/00?o0000ojJok?nV_n`01_nW`>`3ojK0k0SoZ<7/1onX
`>/Eooooo`;o0000;_ooool0013ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oo
oooooooo00?ooooo0_l00007ooooo`03o`000?oooooooooo04Kooooo00?oYl3/ojO1k?nW`N`03?nW
`N`2ojS1j`[oYl3[3OnW_^X2ojNojPKoZ;oZ2_nX_^X5ojS1k0SoZ<7[00?oZ;oZojO2k?nW`^`01OnW
`^`6ojS1k003ojJnjonW`^coYl;/00KoYl;/1_nX`N/2ojK0k0SoZ<;/1_nY_nX3o`0000OoZL3Z0_nX
_nX5ojVojPSoZ;oZ0_nV_n/5ojRoj`GoY[o/00?o0000ojJok?nV_n`00_nW`>`7ojK0k0KoZ<7/00?o
Yl3/ojS0jonX`>/01_nX`>/Fooooo`03o`000?oooooooooo02_ooooo000<ooooo`05o`000?nj^[[o
oooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`12ooooo`GoYl3/2_nW`N`6ojS1j`KoYl3[3onW_^X2ojNojPSoZ;oZ
1_nX_^X00onX`^coZ<7/ojS1k006ojS1k0KoZ<7[0_nV`>`8ojO2k0;oZ<7/1OnV_^/8ojO2k0;oZ<7[
1_nV`>`8ojS2k0;oZKoZ0ol00003ojS2k0KoZL3Z00?oZ<;/ojVoj_nY_nX01_nY_nX6ojRojP03ojVo
j_nX_n_oZ;o[00KoZ;o[1OnV_n`00ol0003oYko[ojNoj`09ojK0k0;oZ<7/1OnW`>`8ojS0jaGooooo
00?o0000ooooooooool0:oooool000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03ko
oooo0_nW`>/7ojO0k0KoYl7/0_nX`N`8ojS1j`;oYl3[3onW_^X6ojNojPSoZ;oZ0_nX_^X5ojS2k0So
Z<7/0_nX`N/6ojK0k0KoYl;/00?oYk_XojJnjonV_^/01_nV_^/6ojO2k0;oY[_X2?nV`>`6ojS2k0?o
00001onX`^`2ojW0jPGoZ<;/2?nY_nX2ojRojPGoZKoZ2?nX_n/2ojJok0;oYko[00Co0000ojNojonW
_n_oYko[1_nV`>`2ojJok0SoYl3/1_nX`>/00onX`N_oooooooooo`0Dooooo`03o`000?oooooooooo
02[ooooo000Nooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0>_ooool6ojO0j`Oo
Yl3/0_nW`N`6ojS1k0KoZ<7[0_nW_nX>ojNnjPWoYkoZ1_nX_nX00onW`^goZ<;/ojS2k006ojS2k0Ko
Z<7/0_nW_^X8ojK0k0;oYl;/1OnW^nP8ojJnj`;oYl;/1_nV^nP8ojK0k0;oZ<;/0ol00003ojFnj`Ko
Z<;/00?oYKk[ojS2k?nX`^`01_nX`^`6ojVojP03ojW2k?nY_n[oZKoZ00KoZKoZ1_nX_n/00onX_n[o
Yko[ojNoj`03ojNoj`04o`000?nW_n_oYko[ojNoj`;oY/3/1_nV_n`8ojO0k0;oZ<3[1OnX`N/Foooo
o`03o`000?oooooooooo02Wooooo000Mooooo`?o00002oooool00ol0003oooooooooo`0fooooo`;o
Yko[2?nW`>/5ojO0k0[oZ<7/0onX`N/5ojNojP[oYkkZ3OnW_nX2ojRojPGoYl;]2?nX`^`2ojS1k0Ko
YkkZ1_nV`>`2ojRgi0OoYk_X1_nV_^/2ojRgi0SoY[_X1_nV`>`3o`0000OoYKk[0_nX`^`5ojFnj`So
Z<;/0_nY_nX5ojW2k0SoZKoZ0_nX_n/5ojRojPGoYko[00?o0000ojNojonX_n/02?nV_n`6ojO0k0;o
Y/3/1onX`N/Fooooo`03o`000?oooooooooo02Wooooo000Mooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool0<_ooool6ojNoj`SoYl3[00?oYl3/ojS1k?nX`N`03?nX`N`00onX`N_oYkoZ
ojNojP05ojNojPOoYkkZ3_nW_nX00onW`^coYl;]ojO2k@06ojO2k@KoZ<;/00?oYkcXojNnj_nW_^X0
1onW_^X2ojK0k0KoZ;OT1onW^nP2ojJnj`KoZ;OT2?nV^nP2ojK0k0?o00000_nW^^H7ojFnj`03ojRj
i_nU_^_oYKk[00KoYKk[1_nX`^`00onU_ncoZL;/ojW2k006ojW2k0KoZKoZ00?oZL7[ojRoj_nX_nX0
1_nX_nX4ojNoj`04ojRojol0003oZ;o[ojRoj`SoY[o/0_nW`>`6ojK0k0OoZ<7[5_ooool00ol0003o
ooooooooo`0Xooooo`007Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02oooooo
2OnW_n/6ojO0j`03ojS2k?nX`NcoZ<7/00coZ<7/0_nW_n/8ojNojPOoYkkZ2_nW_nX5ojO2k0SoYl;]
0_nX`^`5ojNlj0OoYkkZ00?oZ;CQojRgi?nX]n@01onX]n@5ojNkj003ojZagOnX]nCoZ;OT00OoZ;OT
1_nV^nP3o`0000KoYk[V1?nU_^/4ojRjiPSoYKk[0_nX`^`5ojFok0SoZL;/0_nY_nX5ojW1j`SoZ;oZ
00GoYko[ojRojonX_n_oZ;o[o`000003ojRoj`KoY[o/00?oYko[ojK0k?nV`>`01_nV`>`6ojS1j`03
ojO0jooooooooooo01Gooooo00?o0000ooooooooool09oooool001gooooo0_l0000?ooooo`03o`00
0?oooooooooo02_ooooo3OnW_n/2ojO0j`GoZ<;/2_nX`N`6ojNoj`KoYkoZ2OnW_^X6ojNojPWoYl;/
1_nW`^d2ojNji`OoYkcX1?nW_^X4ojRdh@WoZ;OT00?oYk_XojZagOnZ/Md00onZ/Md9ojRgi0;oY[_X
00?oZkCPo`000?l000000_n[]>08ojNjiP03ojFnjonX^^KoZ;[V00GoZ;[V1_nU_^/00onX^^OoYKo/
ojFok006ojFok0KoZL;/00?oY/3/ojW1jonY`N/01_nY`N/6ojRojP;oZL3Z1?nX_n/01?l0003oZ;o[
ojRojonX_n/2ojJok0GoYko[2?nV`>`2ojS1j`GoYl3[5_ooool00ol0003oooooooooo`0Wooooo`00
7Oooool00ol0003oooooooooo`0?ooooo`;o0000:?ooool?ojNoj`;oZ<7/1onX`^`6ojS1k0[oYko[
0_nW_nX=ojNnjP;oYkoZ3OnW`^`2ojO2k@KoYk[W1onW_>P00onW_^[oZ;CQojRdh@05ojRdh@OoZ;OT
00?oZJ_HojZagOnZ/Md01OnZ/Md7ojRgi004ojb]f?l0003o0000o`0000GoZkCP1_nW^^H00on//mko
Z;[VojRjiP07ojRjiP;oYKk[1OnX^^L8ojFok0;oZL;/1OnV`>`8ojW1j`;oZ;oZ1_nY`>X4ojRoj`03
o`000?nX_n_oZ<3Z00SoYko[1_nV`>`00onV_ncoYl3[ojO0j`06ojO0jaKooooo00?o0000oooooooo
ool09_ooool001gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Rooooo`ooYko[
1_nX`N`7ojS2k0;oZ<7/3?nW_n/?ojNnjP;oZ<;/3OnW`^`2ojNiiPSoYk[W1OnW_>P2ojR`gPSoZ;CQ
1?nX]n@4ojV[f0OoZ[7M1?nX]n@3o`000003ojb]f?n[]>3oZkCP00KoZkCP0_nW^^H5ojbcgPOoZ;[V
00?o[KCNojRjionX^^L01_nX^^L6ojFok003ojNlj?nV`>coY/3/00KoY/3/1_nY`N/00onX`NcoZL3Z
ojW0jP07ojW0jP;oZ;o[0_nX`>X00ol0003oZ<3ZojS0jP08ojNoj`;oY/3/1OnV_n`8ojO0jaKooooo
00?o0000ooooooooool09Oooool001gooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0Nooooo`ooYko[0_nW`>`8ojS1k0GoZ<;/0_nX`>/;ojNoj`koYkkZ1_nX`^`9ojO2k0KoYkWV2?nW
^^L00onW_>SoZ;3NojR`gP04ojR`gPSoZ;CQ00?oZ;OTojV[f?nYZmP01OnYZmP7ojZag@?o00001On/
[MP6oj^dh003ojn]e_n//mko[;?N00Ko[;?N1?nX^^H4ojfdgPSoZ;[W0_nU_n`5ojNlj0SoY/3/0_nY
`N/5ojS1k0OoZL3Z00?oZL7[ojS0j_nX`>X00_nX`>X01?l0003oZ<3ZojS0j_nX`>X6ojNoj`03ojRo
jonV_ncoY[o/00KoY[o/1_nW`>/00onW`>coooooooooo`0Dooooo`;o00009_ooool001cooooo0ol0
000Dooooo`03o`000?oooooooooo01[ooooo3onW_n/6ojO0k0SoZ<7/00?oZ<;/ojS0jonX`>/01?nX
`>/9ojNoj`goYkkZ00?oYl;]ojS2k?nX`^`01_nX`^`6ojO2k0WoYkWV1_nW^^L00onW[M_oZ;3NojR`
gP06ojR`gPKoZ;CQ00?oZJSEojV[f?nYZmP01_nYZmP4ojZag@?o00002?n/[MP4oj^dh0Co[jgF2?n/
/mh00onX^^Ko[KCNojfdgP05ojfdgPKoZ;[W00?o[KSQojNlj?nW_>P01_nW_>P6ojK0k003ojJnjonX
`NcoZ<7/00KoZ<7/1?nY`>X4ojW1j`CoZ<3Z00Co0000ojS0j_nX`>[oZ<3Z0_nW_n/5ojRoj`SoY[o/
0_nW`>/5ojO0k1Cooooo00?o0000ooooool000009_ooool001cooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`0Goooooa3oYko[2?nW`>`6ojS1k003ojS1jonX`>_oZ<3[00KoZ<3[1_nW
_n/<ojNnjPGoYl;]2?nX`^`2ojO2k0goYkWV0_nW^^L5ojN]f`SoZ;3N0_nX]>45ojVXe@SoZJ_H0ol0
0004ojj[e0So[:gH00?oZkCPojn]e_n_[MH01On_[MH6ojbcgP03ok:`e_n]]=ko[KCN00Ko[KCN1?nX
^^L4ojfhh@SoYkcX0_nV`>`5ojJnj`SoZ<7/00?oZL3ZojW1jonY`N/01OnY`N/4ojS0jP03o`000?nX
`>[oZL3Z00SoZ;o[1onV_n`8ojO0k1Kooooo00?o0000ooooooooool08oooool000[ooooo1?l00000
2?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^1_ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo01?ooooo5?nW_n/8ojO0k0;oZ<7/1OnX`N/8ojS0j`;oYko[3?nW_^X00onW`Nco
Yl;]ojO2k@06ojO2k@KoZ<;/00?oYk[WojNii_nW^NH03?nW^NH00onVZm_oYjgKojN]f`06ojN]f`Ko
Z;3N00?oZZODojVXeOnYZ=D01_nYZ=D4ojV[f0?o00002?n^Zm@6ojb]f003ok>_e?n_[MKo[jgF00Ko
[jgF1?n//mh4ok:`ePSo[KCN00?oZ;[WojfhhOn]^>401On]^>46ojNlj003ojbki?nV_^_oY[k[00Ko
Y[k[1_nX`N`2ojK0k0SoZL7[0_nX`>X00onY`>[o0000ojW0jP02ojW0jPSoZ;o[1onV_n`8ojO0k1Go
oooo00?o0000ooooooooool08oooool000cooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0?ooooo`;o
Z<3[5_nW_n/6ojO0k0;oZ<7/1onX`N/6ojS0j`coYkkZ1OnW`N`8ojO2k@;oZ<;/1OnW^^L:ojNiiPGo
YZ_K1onW[M/4ojR`gPCoZZOD1onYZ=D01?nYZmSo0000o`000?l00004ok2/e0Oo[Z_D1?n/[MP4ok>_
e0So[jgF00?o[;?Nok:`e_nb/=H01Onb/=H6ojfdgP03ok>beon]^>7o[KSQ00Oo[KSQ0_nW_>P5ojbk
i0SoY[k[0_nX`N`6ojK0k0KoZL7[00?oZ<7/ojW0j_nY`>X00_nY`>X01?l0003oZL3ZojW0j_nY`>X6
ojRoj`03ojS0jonV_ncoY[o/00GoY[o/1_nW`>`2ojK0k1Kooooo00?o0000ooooooooool08_ooool0
0003ooooool0003o000000Co00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@41001_ooool2o`0001Wooooo00?o0000ooooooooool03?ooool5ojS0jaKoYko[0_nW`>`6
ojS1k0OoZ<7[0_nX`>/<ojNnjP;oYl3/1onW`N`6ojO2k@;oYkcX1onW^^L6ojNiiP03ojF[fonVZm_o
YZ_K00KoYZ_K1onW[M/00onX/=koZZODojZWe004ojZWe0KoZJSE0_l000000onYZmSo/:cDok2/e004
ok2/e0So[Z_D00?o[:gHok>_e?nc[m@01Onc[m@6ojn]eP03okNceOnb/=Ko/[3F00Ko/[3F1?n]]=h4
ok>be`Oo[KSQ00?o/[CJojbki?n/^n@01_n/^n@6ojJnj`;oZ;gX2?nV`>`2ojW1j`GoZ<7/1?nY`>X0
1?l0003oZL3ZojW0j_nY`>X2ojRoj`GoZ<3[1onV_n`2ojO0k0KoY/3/5_ooool00ol0003ooooooooo
o`0Qooooo`003?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_oo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00[ooooo1onX`>/DojNoj`;oZ<;/2?nX
`N`5ojS1j`?oYko[2OnW_^X6ojO0k0OoYl7/0_nW`^d6ojNlj0OoYk[W0_nW^NH5ojF[f`OoYZ_K1_nW
[M/00onYYmCoZZODojZWe006ojZWe0;oZJSE0ol000000onYZ=Go[jkGok2/e007ok2/e0Ko[Z_D00?o
];?Hok>_e?nc[m@01_nc[m@4ojn]ePCo]k?E2?nb/=H00on]]=ko/k;Gok>be`05ok>be`Co[KSQ1?nb
]=X8ojbki0;oY[k[1_nX_NP6ojK0k003ojFnjonX`NcoZ<7/00GoZ<7/1OnY`>X00ol0003oZL3ZojW0
jP07ojS0j`KoY[o/0_nV_n/8ojK0k1Gooooo00?o0000ooooooooool08Oooool000cooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`07ooooo`?oZ<7/1onX`>/@ojNoj`KoZ<;/2?nX`N`00onX`N_oYko[ojNo
j`05ojNoj`KoYkkZ00?oYko[ojO0k?nW`>`01_nW`>`5ojO1k0;oZ;kY2?nW_>P5ojNji`03ojF/g?nU
Zm_oYJ_K00KoYJ_K1onVZm/2ojN]f`GoZJOD1_nZYm@3o`0000;oZJSE1?n_[]L7ok2/e0Co[Z_D1?nd
/mP8ok>_e003ojn]e_ng/mGo]k?E00Go]k?E1_nb/=H00onj]]Ko/k;Gok>be`07ok>be`03ojfhhOnb
]=[o/[CJ00Go/[CJ1_n/^n@00on`^MooZ;gXojRmj007ojRmj0;oY/3/1OnU_^/7ojS1k0CoZL3Z00Co
0000ojW0j_nY`>[oZL3Z1onX`>/2ojJok0KoY[o[1_nV`>`00onV_ncoooooooooo`0Dooooo`03o`00
0?oooooooooo023ooooo000<ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooo
oa0@4005ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool00oooool7ojS1k0GoZ<3[
3onW_n/2ojO1k0OoZ<;/1_nX`N`:ojNoj`;oYkkZ1OnW_n/8ojO0k003ojO1k?nX_^WoZ;kY00CoZ;kY
2?nW_>P00onW^^OoYJcLojF/g003ojF/g0OoYJ_K1_nVZm/00onWY]GoZJODojVWe005ojVWe0?oZZOD
0ol00002ojZWe003ojVXeOn_[]Oo[jkG00Co[jkG2?n`[=@00on^ZmCo];?HokBcf005okBcf0Ko/joD
00?o]kWKokNceOng/mD01_ng/mD4ok:`ePCo^[KF1onc/]L00onk^=Ko/[CJok:dfP07ok:dfP;o[;_T
1On`^Ml7ojRmj003ojfmi_nU_^_oYKk[00GoYKk[1_nX`N`00onW`>coZL3ZojW0jP03ojW0jP03o`00
0?nY`>[oZL3Z00SoZ<3[2?nV_n/2ojK0k0GoY[o/5_ooool00ol0003oooooooooo`0Oooooo`003?oo
ool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2o`0001kooooo
00?o0000oooooonX`N/00_nX`N/8ojS1k003ojS0jonW_n_oYko[00goYko[1_nW`N`7ojS2k0;oZ<7/
3?nW_n/2ojNnjPOoYko[1_nW`>`00onX`>_oZ;kYojRnj@06ojRnj@KoYkcX00?oY:kOojF/g?nU[=`0
1OnU[=`7ojF[f`;oYZ_K1OnWY]D6ojVWe0?o00001?nZYm@00on]/=[o[jkGojn^e`06ojn^e`Ko/:cD
00?o/[WNokBcf?nd/mP01_nd/mP4ok>_e0Co]kWK2?ng/mD00onb/=Ko^[KFokZfeP05okZfePGo/k;G
0onk^=H7ok:dfP03ok^ieon`^Moo/;WO00Ko/;WO1?nX_NP4ojfmiPOoYKk[0_nX`N`5ojO0k0GoZL3Z
00?o0000ojW0j_nY`>X02?nX`>/6ojJoj`03ojNojonV_ncoY[o/00KoY[o/5Oooool00ol0003ooooo
ooooo`0Oooooo`002_ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool00ol0003oooooooooo`0Looooo`OoZ<7[1_nX`N`2ojO0j`koYko[2?nW`N`5ojS2k0?oZ<7[
2OnW_n/6ojNnjPOoYko[0_nW`>`5ojS0j`SoZ;kY0_nW_>P5ojB^g`OoYJcL1OnUZm/00onTYMKoYjKE
ojNVe@05ojNVe@?oZJOD0ol000000onYYmCoZZODojZWe002ojZWe0Co[K3J1on_[]L4ok2/e0Co/[WN
2?nd/mP00onc[mCo]kWKokNif`05okNif`Ko]k?E00?o^KgMokZfe_nj]]H01_nj]]H3ok>be`Ko^kSF
1Onb]=X3ok^ie`So/;WO00?oZ;gXojfmi_n]_NH01?n]_NH6ojFnj`03ojNnj_nW`>coYl3/00KoYl3/
1OnY`>X00ol0003oZL3ZojW0jP08ojS0j`;oY[o[1OnW_n/8ojJok1Gooooo00?o0000ooooooooool0
7_ooool001_ooooo00?o0000ooooooooool06_ooool3ojO0j`OoZ<7[0_nX`N`6ojO0j`koYko[2?nW
`N`00onX`^coZ<7[ojS1j`05ojS1j`GoYko[2_nW_^X5ojNoj`;oZ<;/1onX`>/6ojRnj@03ojFch_nT
[]ooY:kO00KoY:kO1onU[=`00onUZm_oY:GFojBUeP03ojBUePKoYjKE0ol00005ojVWe003ojZWe?n]
/=[o[K3J00Go[K3J1on_[]L00on`[=Co/[WNok:igP05ok:igPKo];?H00?o/lOYokNifong^M/01_ng
^M/4okNce@Co^KgM2?nj]]H00onc/]Oo^kSFok^heP05ok^heP?o/[CJ1_nk^ML6ok2ig`03okNjg?n]
_NKo[KgV00Ko[KgV0_nU_^/5ojNnjPSoYl3/1?nY`>X01?l0003oZL3ZojW0j_nY`>X6ojS0j`03ojW0
jonW_n_oYko[00KoYko[1onV_n`Fooooo`03o`000?oooooooooo01gooooo000Kooooo`03o`000?oo
oooooooo01Oooooo1onW`>/7ojS1j`SoYl3[3_nW_n/6ojO1k0;oZ<;/2?nX`N/00onW_n_oYkkZojNn
jP0<ojNnjP03ojNojonX`^coZ<;/00CoZ<;/1onX`>/2ojRnj@GoYK?R1onT[]l6ojF/g003oj:TeonT
YMKoY:GF00GoY:GF0_nWY]D3o`000003ojNVeOnYYmCoZJOD00CoZJOD00?oZk?Nojf`f_n]/=X01_n]
/=X6ojn^e`03ok35jOnb^Mko/[WN00Ko/[WN1?nd/mP4ok?7j@So]kWK00?o]k?EokVmgOni_Md01Oni
_Md6okZfeP03ok^ng?nk^=Ko^kSF00Oo^kSF00?o/[CJok^ieonk^ML01Onk^ML4ok2ig`Co]k[L1_n]
_NH00ona_^?oYkkZojNnjP06ojNnjPKoYl3/0_nV_n`4ojW0jP04o`000?nY`>[oZL3ZojW0jP;oZ<3[
1OnY`>/8ojNoj`OoY[o/5?ooool2o`0001oooooo000Kooooo`;o00005_ooool3ojNoj`OoYl3[1onX
`N/8ojO0j`koYko[0_nW`N`6ojS2k0KoZ<7[0_nW_n/=ojNnjP03ojO1k?nX`^coZ<;/00KoZ<;/1OnX
`>/2ojFfi@OoYK?R1onT[]l2ojF/g0GoXZCG1_nTYMH2o`0000GoYjKE0_nYYm@5oj^cgPSo[K3J0_n_
[]L5ok35j@So/[WN00?o];?Hok?7jOncanT01OncanT6okNif`03ok;@l?ni_Mgo^KgM00Ko^KgM1?nj
]]H4ok^ng0Oo^kSF00?o_KkJok^ieonk^ML01onk^ML00on`^Moo]k[LokNjg004okNjg0Co[KgV1?na
_^<8ojNnjP;oYl3/1_nV_n`4ojW0jP03o`000?nY`>[oZL7[00SoZL3[1_nW_n/00onW`>_oY[o/ojJo
k005ojJok1Kooooo00?o0000ooooooooool07?ooool001[ooooo00?o0000ooooooooool04oooool7
ojNoj`GoYl3[2OnX`N/6ojO0j`koYko[0onX`N`7ojS2k0;oZ<7[1_nW_n/9ojNnjPGoYl7/2?nX`^`0
0onX`>_oYKKUojFfi@04ojFfi@KoYK?R1_nT[]l00onPXmOoXZCGoj:Te`05oj:Te`?oY:GF0ol00000
0onTYMKoYjKEojNVe@03ojNVe@03ojVdh?n[/mkoZk?N00KoZk?N1_n]/=X00on[dOCo/<GYok35j@06
ok35j@Ko/[WN00?oYm_jok?7jOncanT01_ncanT4okNif`Co/]3`2?ni_Md00onj]]Ko^kkLok^ng005
ok^ng0Co^kSF1?nm_]X7ok^ie`03oknmf?ng^]co]k[L00Ko]k[L00?o[KgVok6nhona_^<01Ona_^<6
ojNnjP;oZ[oY2?nV_n`2ojW0jP;oZL7[00?o0000ojW1jonY`N/02?nY`>/2ojNoj`GoYl3[1onV_n`E
ooooo`03o`000?oooooooooo01cooooo000Jooooo`03o`000?oooooooooo00oooooo3?nW_n/00onW
`>_oZ<7[ojS1j`0;ojS1j`;oYl3[3_nW_n/7ojS1k0GoZ<;/2_nW_n/5ojNnjP;oYko[1onW`N`6ojS2
k003ojJkj?nU]^GoYKKU00KoYKKU1_nU/n82ojB^g`GoX:?G1_nRY=L3o`0000GoY:GF00?oYjKEojVd
h?nY]>000onY]>07oj^cgPCo[K3J1?n[dO@8ok35j@;o/[WN1OnWfoX8ok?7j@03okNifonbd?3o/]3`
00Go/]3`1_ni_Md00onbdO3o^kkLok^ng007ok^ng003ok^he_nm_][o_KkJ00Go_KkJ1Onk^ML3oknm
f0Ko]k[L00?o_KkJok6nhona_^<01ona_^<2ojNnjPKoZ[oY1_nV_n`00onU_ncoZL7[ojW1j`02ojW1
j`03o`000?nY`N_oZL7[00SoZL3[1onW`>/8ojJok1Gooooo00?o0000ooooooooool06oooool001[o
oooo00?o0000ooooooooool02oooool2ojO0j`goYko[00?oYl3[ojS1jonX`N/02onX`N/?ojNoj`?o
Yl3[1onX`N`00onX`^coYko[ojNoj`0<ojNoj`03ojNnj_nW_n_oYko[00CoYko[1onW`N`2ojS2k0Go
Y[_X2?nU]^D3ojFchP;oWZ?H1onPXmL3oj:Te`?o000000?oXZCGojBUe_nTYMH01?nTYMH00onV/n7o
ZKCPojVdh005ojVdh0OoZk?N00?o[K3Joj_Am?n[dO@01On[dO@6ok35j@?oR=kn1_nWfoX6ok?7j@;o
T=co1onbd?04okVmg@Co/]7`1onk_]`00ongbn[o_KkJokfnfP06okfnfP?o^kWG1Ono_MP4okNjg0Co
_KkJ1ona_^<2okBnh@SoZ[oY0_nV_n`5ojFok0CoZL7[00?o0000ojW1jonY`N/02?nY`>/7ojO0j`So
Y[o/5Oooool00ol0003oooooooooo`06ooooo`Go00003oooool001[ooooo0_l00009ooooo`KoYl3[
2OnW_n/5ojO0j`WoZ<7[3onW_n/7ojO0j`GoZ<7/0_nX`N/=ojNoj`03ojJnjonW_n_oYko[00KoYko[
1OnW`N`2ojRojPOoY[_X1_nU]^D00onOYm_oWZ?HoijSf004oijSf0KoX:?G0ol00005oj:Te`;oY:GF
1OnV/n47ojVdh0GoZk?N0onTfOX7oj_Am0;o/<GY1on8g_h6ojOKnP;o/lOY1_n@g?l7ok;@l003okVm
gOnbdO3o/]7`00Go/]7`1?nk_]`4okO;jPSo_KkJ00?o^kWGoknmf?no_MP01Ono_MP00ong^]co_KkJ
okfnfP05okfnfPCo/KkS1Ond_^46ojZoj@03ojc0j?nU_ncoYKo/00GoYKo/1OnY`N/00ol0003oZL7[
ojW0j`07ojW0j`SoYl3[2?nV_n`Dooooo`03o`000?oooooooooo00Kooooo00GoV9RHob4Q8Oo^k^ko
ooooodA4A00?ooooo`006_ooool00ol0003oooooooooo`06ooooo`;oZ<7[1onW`>/7ojNoj`OoYl3[
2OnX`N/>ojNoj`SoYl3[00?oZ<7/ojS1jonX`N/01?nX`N/9ojNoj`GoY[k[2?nW_n/00onW`NcoZ;oZ
ojRojP04ojRojPOoY[_X0_nU]^D5oinWf`KoWZ?H0_nPXmL3o`000003oj2SeonRY=OoXZCG00CoXZCG
00?oY;3QojJchOnV/n401_nV/n47ojVdh003oj^cg_nTfO[oY=Wj00KoY=Wj0on[dO@5og7JmPCoR=kn
1Om6aNH6oec>m0KoT=co0onbd?04oh;Eo`So/]7`00?o^kkLokO;j_ngbnX01OngbnX6okfnfP03ok_4
hOno_MSo_kgH00Go_kgH00?o`<;Kokfnf_nm_]X01onm_]X00ona_^?o];kQokBnh@06okBnh@;oZ[oY
1On/`>P7ojFok0CoZL7[00?o0000ojW1jonY`N/02?nY`>/8ojO0j`OoY[o/5Oooool00ol0003ooooo
ooooo`06ooooo`03oiRHV?lQ8B7ok^k^013ooooo000Jooooo`03o`000?oooooooooo00?ooooo1_nX
`N/7ojO0j`OoYko[1onW`>/9ojS1j`koYko[1_nW`>/00onX`^coZ<7[ojS1j`06ojS1j`GoYko[2OnV
_^/6ojNoj`;oZL;/1onX_nX5ojJkj003oj6^hOnOYm_oWjOK00GoWjOK1OnNXmP3o`0000GoX:?G0_nR
Y=L5ojB`h@OoY[?Q1_nY]>03oioMo0KoY=Wj1?m/f_03og7JmPKoC<SW0om6aNH6oeg4n`Go=[KX1Om5
_nl6oh;Eo`Ko/]7`00?oRM;ookO;j_ngbnX01_ngbnX4okfnfPCo^lCQ1Ono_MP3ol32f`Oo_KkJ00?o
`/;JokBnhOnd_^401_nd_^400oni`N3o[<3Xojc0j005ojc0j0OoYKo/1OnY`N/00ol0003oZL7[ojW1
j`06ojW0j`;oZL7[2?nW`>/7ojJok1Gooooo00?o0000ooooooooool01_ooool00onHV9So8B4Qonk^
kP0?ooooo`006_ooool00ol0003oooooooooo`02ojS0j`SoZ<7[1OnW`>/9ojNoj`GoYl3[2onX`N/>
ojNoj`;oYl3[1OnX`^`8ojS1j`03ojNojonV_^_oY[k[00_oY[k[0_nW_n/6ojW2k0OoZ;oZ00?oY[_X
oj6^hOnQ[^400onQ[^47oinWf`04oijSf?l0003o0000o`0000?oWZ?H0onPXmL3oj6/g`OoY;3Q1onV
/n42ojVdh0OoWmgl0_nTfOX4ofcJl0KoImGc0om<b>L6oh?8oP?oGLCk1?nC__@6ofNio@;o<Jg]0_m5
_nl6oh;Eo`;o/]7`1On9d_l8okO;jP03okfnf_nka>7o^lCQ00Go^lCQ0ono_MP5ol32f`Co_KkJ1?o2
`]X6okBnh@?o^L7P1on/`>P7ojFok0GoZL7[00?o0000ojW1jonY`N/00_nY`>/6ojW1j`OoYl3[1onV
_n`Eooooo`03o`000?oooooooooo00Oooooo00?oMgMgofIVI_ooool03_ooool001Wooooo00?o0000
ojS0jonX`>/01?nX`>/8ojS1j`03ojO0jonW_n_oYko[00_oYko[00?oYl3[ojS1jonX`N/02onX`N/>
ojNoj`;oZ<3[1onX`^`6ojS1j`;oYko[3?nV_^/3ojO1k0OoZL;/0onX_nX3oj>ei@OoXJkQ1?nOYm/3
o`0000GoWZ?H00?oWJOMoj6/gonQ[=l01OnQ[=l6ojB`h@KoY[?Q1onOgO`5og;OkPCoP=oj1?mWeO<4
oi[8m`KoPlSn00?oX[SYoi>nm?nC__@01_nC__@6ofNio@Ko<Jg]1Om1^?86ohWBo`Ko]l_Z00?oWm7i
ok_4hOnka>401onka>400ono_MSo`<;Kol32f`05ol32f`03okfnf_o2`][o`/;J00Go`/;J0ond_^46
okW1h0Go[<3X0_n^`NP7ojFok0GoZL7[00?o0000ojS0jonX`>/02?nY`N/7ojO0j`OoY[o/5Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00gooooo000Iooooo`03o`000?nX`>_oZ<3[
00GoZ<3[1_nX`N/>ojNoj`?oYl3[2OnX`N/>ojNoj`KoZ<3[1onX`^`2ojS1j`KoYko[2?nV_^/7ojO1
k0GoZL;/0_nV^nT6oj>ei@OoXJkQ00?oWjOKo`000?l000000onOYm/2oijSf0GoWJOM1onQ[=l6ojB`
h@;oY[?Q1_nOgO`4ogoUl0;oL]o^1on0goX2oj?7lPOoV/Sg0_n3b?h5oj:hj@SoTkkd0omW^Od4oiNj
l0KoH[3j0_l^YNl2od6hlPKoRM;o0_ngbnX5oioAn@Oo^lCQ00?o]Lc[ol32foo0`]/01Oo0`]/00onn
aMoo`/;Jol;2fP07ol;2fP03okBnhOni`N3o^L7P00Ko^L7P00?o[<3Xojk1j?n^`NP01?n^`NP7ojFo
k0;oZL7[0_nX`>/01?l0003oZ<3[ojS0jonX`>/7ojW1j`OoYl3[2?nV_n`Cooooo`?o00001?ooool0
1Ol0003o^[ZjoooooonHV9So410@00oooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_oo
ool00ol0003oooooojS0j`06ojS0j`;oZ<7[3_nW_n/7ojO0j`OoZ<7[3onW_n/7ojS0j`GoZ<;/0onX
`>/7ojNoj`OoY[k[2?nW`N`00onY`^coY[_YojJkj@04ojJkj@KoXkGU1?nQ[^43o`0000?oWjOK0_nJ
Xm/8oifWg@OoXJcO0onT/>45oj;In`;oWmgl1omoiO04oi3Vn`;oP=oj1_nSao85oi[8m`03ojJch_nR
^>WoX[SY00KoX[SY1_nC__@2ojFchPOoUk[`1_mR/?X6objUk`GoD;Wj1_nOdOT4ok_4h@Co]Lc[1Oo0
`]/3okk5g`Oo`/;J0_o3aM/7okW1h003okc5hOn^`NSo[/7X00Ko[/7X1onU_n`4ojS0j`04o`000?nX
`>_oZ<3[ojS0j`OoZL7[1onW`>/8ojJok1Cooooo00?o0000ooooooooool00_ooool01OnHV9So410@
o`000?lQ8B7oc<c<00oooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003o
ooooooooo`05ojS0j`?oZ<7[3onW_n/7ojO0j`OoZ<7[3onW_n/7ojS0j`03ojS2k?nX`>_oZ<3[00Go
Z<3[1OnW_n/9ojJnj`KoYl7/00?oZ<7[ojJkjOnV^nT01_nV^nT6oj>ei@?o00000onHXM/6oiZSf`Oo
WJOM1_nQ[=l2ojC?mPOoX]Wk1?n?jo@2ogoUl0KoT>Kk0_nWb?48oj?7lP03oi[8monV/n;oY[?R00?o
Y[?R2?nR^>T2oi>nm0KoYK?R1OnG^_000onW]N?oS[SbohjhlP06ohjhlPKoCJGh0_lfYO<2oe2inPKo
Wm7i00?o^lCQokG<jonec>/01Onec>/3ol32f`Go_/GO1?o2`]X5ol?5f`Co^L7P1?nlaN46ojk1j003
ojo3jOnU_ncoYKo/00KoYKo/1?nX`>/00ol0003oZ<3[ojS0j`07ojW1j`SoYl3[2?nV_n`Dooooo`03
o`000?oooooooooo01Gooooo000>ooooo`05oa0@4?ooooooooooooooool@41001_ooool2o`0000;o
oooo00?oZ<3[ojS1jonX`N/01OnX`N/?ojNoj`GoYl3[2OnX`N/?ojNoj`GoZ<3[0onY`^`7ojS0j`03
ojNojonV_^_oY[k[00_oY[k[0_nW`N`5ojS1j`SoY[_Y0_nS]ND3o`0000OoV:7K1_nJXm/7oifWg@;o
XJcO1_nTcoH4oj;In`GoSn_d1?nKk?P2oi3Vn`KoYlSa1_nSao800onW/MooY[?RojJchP05ojJchPKo
X[SY00?o[;;MojFch_nU/n801onU/n800onG^_3oYkGSojNeh`03ojNeh`SoS[Sb1_m=YOP5ocJUl`Go
ML7n2?nec>/00oo0`]_o_/GOokk5g`05okk5g`03ol;2f_o3aM_o`lGK00Ko`lGK00?o^L7Pokc5hOnl
aN401?nlaN44ojk1j0Co[l?Y2?nU_n`4ojS0j`03o`000?nX`>_oZ<3[00OoZL7[2?nW`>/6ojJok003
ojJojooooooooooo01?ooooo00?o0000ooooooooool05?ooool000kooooo00Go0000oooooooooooo
ooooo`000006ooooo`03o`000?oooooooooo00?ooooo1onX`N/?ojNoj`03ojO0jonX`N_oZ<7[00_o
Z<7[3onW_n/00onX`>_oZL;/ojW2k005ojW2k0GoZ<3[0_nW_n/<ojJnj`?oZL;/1_nX`N/6ojJkj@?o
00001?nIYMh7oiRQf`GoVZ?K1_nMYmd2oj?0kPSoY<of00?oX]Wkoho[m?n?jo@00_n?jo@6oi_/n0;o
Zlgb2?nWb?42oj?7lPGoYk7O1onV/n82oj:hj@Go[;;M1onU/n800ona^=koYkGSojNeh`05ojNeh`Ko
S[Sb0_nQ]nP6og>_mP?o=Y_c0_lfYO<5ogG1oPKo]Lc[00?oY<Wcokk5gonnaMl01OnnaMl00onka^;o
`lGKol?5f`06ol?5f`03olC7g?nlaN7o_<GQ00Ko_<GQ00?o[/7Xojo3jOn_`nT01On_`nT7ojFok0Co
Z<3[00?o0000ojS0jonX`>/02?nY`N/8ojO0j`;oY[o/1OnV_n/Dooooo`03o`000?oooooooooo01Co
oooo000>ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`05ooooo`Go
Z<7[0_nW`>/=ojNoj`;oYl3[3?nX`N/=ojNoj`CoZ<7[2?nY`^`00onX`>_oYko[ojNoj`04ojNoj`So
Y[k[1onY`^`6ojS1j`;oY[_Y0ol00002oin`i0GoVJGN1onHXM/6oiZSf`;oWJOM1_nS`>h6ojC?mP?o
Wngh1?nSlO@2oi_/n0KoZlgb1_nWb?49ojNag`GoY[?R00?o[KCNojbbgOn//]d01_n//]d4ojFchPCo
/KSN1onW]N<2ohjhlPKoXKOX1_mc[oH5ocJKl`?oF;3k0_me`Oh2okG<j`GoY<Wc1OnnaMl3ok_6hPKo
`lGK0oo4am`6okc5h@;o_/SR2?n_`nT7ojFok0CoZ<3[00?o0000ojS0jonX`>/02?nY`N/7ojO0j`Oo
Y[o[5Oooool00ol0003oooooooooo`0Cooooo`003_ooool01Ol@413ooooooooooooooooo410@00Go
oooo00?o0000ooooooooool01_ooool00onX`N_oYl3[ojO0j`04ojO0j`WoYko[1_nW`>/8ojS1j`ko
Yko[1onX`N/6ojW2k003ojS0jonW_n_oYko[00KoYko[1OnV_^/2ojJoj`SoZL;/0onX`N/01?nS^>So
0000o`000?l00006oin`i0GoVJGN1onHXM/3oiZSf`CoW[;U1onS`>h2ojC?mPCoWngh1_nSlO@3ok7G
m0KoZlgb0_nWb?4=ojNag`03ojJch_n]]=ko[KCN00?o[KCN2?n//]d00onU/n;o/KSNok6hgP05ok6h
gPGoYkGS00?o/k[Ooj6gj?nQ]nP01onQ]nP6og>_mPGo=Y_c1?mH/?/7ojC9l`?o_/GO1_nka^83ol?5
f`Goa<OL1?nlaN45okk8hPKo[l?Y00?o[lCYojFok?nU_n`01OnU_n`5ojS0j`03o`000?nY`N_oZL7[
00SoZL7[1onW`>/7ojJojaGooooo00?o0000ooooooooool04_ooool000kooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o00002?ooool7ojO0j`OoYko[2?nW`>/8ojS1j`koYko[1onX`N/2ojW2
k0GoZ<3[2?nW_n/00onV_^_oY[o[ojJoj`04ojJoj`KoZL;/00?oYko[oj>hj?l000000_l00003oj>h
j0KoWk3T1OnIYMh6oiRQf`03oiVXhOnN/^GoW[;U00KoW[;U1OnS`>h4oj[YnP;oWngh1?nSlO@7ok7G
m0?oZlgb0onW/n8=ojNag`03oj^eh?n]]=ko[KCN00Go[KCN1_n//]d00onb_>;o/KSNok6hgP07ok6h
gP03ojNehonc^]oo/k[O00?o/k[O1onQ]nP00on]_>CoSKKbohfflP04ohfflPCoB9_d0_lfVo<4oeR`
n`OoY<Wc00?o_/GOok_6h_nka^801_nka^800oo3aM_oa<OLolC7g005olC7g003okc5hOnnb>;o_/SR
00Ko_/SR0_n_`nT5ojo4j@OoYKo/0_nX`>/2ojW1j`03o`000?nY`N_oZL7[00SoZL7[1onW`>/7ojJo
jaGooooo00?o0000ooooooooool04_ooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`03o`000?oooooooooo00Sooooo1onW`>/7ojNoj`SoYl3[2?nX`N/5ojNoj`;oY[o[1onW_n/5ojS1
j`?oZL7[1_nX`>/6ojNoj`;oY[k[1onV_n/2ojW2k0?oYko[0_l00007oj>hj0KoWk3T1OnIYMh2oiRQ
f`GoVJSQ2?nN/^D00onS`>koZ^Wjoj[YnP05oj[YnP?o[OCc0onjio@6ok7Gm003ojRki_nW/n;oYk?R
00GoYk?R2OnW/Ml5oj^eh0Oo[KCN0_n//]d5ok:lhPOo/KSN00?o];oRok>jgonc^]l01Onc^]l4oj6g
j0Co[KcT1_n=]_86odRKm0?oC:;g00CoF;3kojC9lonTbO?oY<Wc1?nA`?H7ok_6hP03okS6iOo4amco
a<OL00Goa<OL00?oaLWNokk8h_nnb>801_nnb>800onobn?o[lCYojo4j@06ojo4j@OoYKo/1?nY`N/0
0ol0003oZL7[ojW1j`08ojW1j`OoYl3[1onV_n/Eooooo`03o`000?oooooooooo017ooooo000Hoooo
o`03o`000?oooooooooo00Wooooo1OnW`>/9ojNoj`KoYl3[2_nX`N/00onW_n_oY[o[ojJoj`04ojJo
j`OoYko[00?oZ<7[ojW1jonY`N/01OnY`N/6ojS0j`;oYko[1_nV_^/5ojJoj`;oZL;/00CoYko[o`00
0?l0003o00000onW_n/7oj>hj0?oWk3T0_nBXMh6oiBRgPOoVJSQ1_nN/^D3ojcLn0CoZ^Wj0on]m?<6
ok[Wm0;o/MOd1OnX^nH7ojNchPGoYk7O00?oYkCRoj^eh?n[]N001_n[]N05ojfdgP03ojbmi_nb_>;o
/[cR00Ko/[cR1?na^=h4okBohPOo/k[O00?oXKOXojfli?n]_>@01On]_>@6ohfflPKoB9_d1?m<X_L7
oi70mPCo^lKR1?nha^D5olC7g0?oaLWN1_nnb>83oko;h`Ko[lCY00?o[/CZojFok?nU_n`01_nU_n`4
ojW1j`03o`000?nY`N_oZL7[00OoZL7[1_nW`>/00onV_ncoY[o[ojJoj`06ojJojaGooooo00?o0000
ooooooooool04?ooool001Sooooo00?o0000ooooooooool02_ooool00onW`>_oYko[ojNoj`0;ojNo
j`;oYl3[3?nX`N/00onW_n_oY[o[ojJoj`06ojJoj`GoYko[0onX`N/7ojW1j`?oZ<3[1?nV_n/7ojJn
j`04ojJojonY`^coZL;/ojW2k0?o00001onW_n/3oj>hj0?oVZcT1_nBXMh6oiBRgPKoVJSQ1?nN/^D6
ojcLn003oj[Yn_n]m??o[OCc00;o[OCc1_njio@2ojk7k@OoZ;_V1onW/n800onW/MooYkCRojNdhP03
ojNdhPSoZkGP00?o[KCNojbmi_n/_NH00on/_NH8ok:lhP03ok6hg_nd_n;o];oR00Go];oR1Onc^]l2
okS1h@So[KcT0on=]_83oiVjk`GoFYkc0om<V_<2odbRm`OoTL3f00?o^lKRokS6iOnha^D01Onha^D3
olC7g0GoaLWN0onnb>85oko;h`Co[lCY1?n^a>X8ojFok0CoZL7[00?o0000ojW1jonY`N/01onY`N/2
ojO0j`GoY[o/1_nV_n/00onW_n_oooooooooo`0Cooooo`;o00004Oooool001Oooooo0ol0000=oooo
o`[oYko[1?nW`>/9ojS1j`GoYko[2?nV_n/00onW_n_oZ<7[ojS1j`05ojS1j`GoZL7[0_nW`>/7ojJo
j`GoY[k[0_nV_n/3o`0000CoZL;/1OnW_n/00onP]nWoVZcToiZ/i005oiZ/i0GoTZ7N1onDX]h6oiVX
h@03oijbiOn/g?So[=ch00Go[=ch1?nflO@4okobl@03ok[Wm?n^ango[/O]00Co[/O]1_nX^nH6ojNc
hP03oj>ah_nW]>;oYkCR00GoYkCR1_n[]N000onY_^So[;gVojbmiP05ojbmiPKo/[cR00?o[L7XokBo
h_nd_n801ond_n800onc^]oo^<7QokS1h@04okS1h@Ko[KcT0_nd`N<6oiVjk`GoFYkc1Om<V_<3oi70
mP?oQ;Kf2Onha^D00oo4amcoaLWNolG9gP05olG9gP03okk8h_nobn?o_l_S00Go_l_S00?o[lCYojk4
j_n^a>X01On^a>X7ojFok0CoZL7[00?o0000ojW1jonY`N/01?nY`N/4ojS1j`OoY[o/0_nV_n/5ojNo
ja?ooooo00?o0000ooooool000004Oooool001Oooooo00?o0000ooooooooool03_ooool7ojNoj`Oo
Yl3[2?nX`N/6ojNoj`KoY[o[0_nW_n/8ojS1j`03ojW1jonW`>_oYl3[00CoYl3[1onV_n/00onV_^_o
Y[o[ojJoj`03o`000003ojJojonY`^coZL;/00GoZL;/00?oYko[oj2gjOnP]nT00onP]nT7oiZ/i0Go
TZ7N1onDX]h3oiVXh@CoXl;_1?n/g?P4okKam0Go_o;a0_nheo07ojk7k@KoZ;_V0_nW/n85oj>ahPOo
YkCR0_n[]N05ojVnj0Oo[;gV0_nb_>85ojg1j0Oo];oR00?o[l7WokS1hOnh`N401_nh`N42ojfli0Ko
]<7S1_nI^^l5oeZNl`GoC9[c1_n4]_H7okS6i@03okK5i_o5bMkoaLWN00GoaLWN0_o5c=l6oko;h`;o
_/gV2?n^a>X7ojFok0CoZL7[00?o0000ojW1jonY`N/02?nX`N/5ojJok003ojJojonW_n_oYko[00Ko
Yko[5?ooool00ol0003oooooooooo`0?ooooo`005oooool00ol0003oooooooooo`0?ooooo`OoYko[
1onW`>/8ojS1j`KoYko[0_nV_n/6ojNoj`KoZ<7[00?oZL7[ojO0jonW`>/01_nW`>/5ojJoj`04ojJn
jol0003o0000o`0000GoY[o[1OnY`^`00onV_n_oX;OYoj2gj@05oj2gj@KoVZcT1OnBXMh6oiBRgP03
oiZ^iOnS`^ooXl;_00OoXl;_00Co[=chokKam?nflOCo]_7d1Onol_45okSGl0Oo[/O]0onX^nH2oj2^
h@SoXk7R1OnW]>800onW_NWoZKkXojVnj006ojVnj0Go[;gV00?oZL;/ojg1j?n]`NP01_n]`NP4okBo
hPCo[l7W1_nh`N400onf`nCo]<7SokC1h`07okC1h`?oVK[_0onM_>h3ofFQlP;oFYkc1Om<V_<6ohBf
mPCo^<KU1?nfaNH4olG9gPGoaLcO0onobn<5okk=iPKo[/CZ00?o[<C[ojFok?nU_n`01_nU_n`4ojW1
j`03o`000?nY`N_oZL7[00SoZ<7[00?oY[o/ojJojonV_n/00onV_n/8ojNojaCooooo00?o0000oooo
ooooool03_ooool001Oooooo00?o0000ooooooooool04?ooool7ojNoj`GoYl3[2_nX`N/3ojNoj`Co
Y[o[1onW_n/2ojS1j`GoZL7[2?nW`>/00onV_n_oY[k[o`000002o`000003ojJnjonV_n_oY[o[00Ko
Y[o[00?oZL;/ojJojonV_n/00onV_n/7oj2gj@KoVZcT1OnBXMh2oiBRgPGoVZkU1onS`^l3okWVm0Co
a?7_0_nol_47okSGl0?o[/O]0onQ/N@6oj2^h@SoXk7R00?oYkCRojNmjOnW_NT00onW_NT8ojVnj003
ojbmi_nY`^coZL;/00?oZL;/2?n]`NP00ond_n;o[l7Wojo1i`05ojo1i`?o^<7Q1?nf`n@7okC1h`03
okS5i?nM_>koWKc^00GoWKc^1OmUXO83oe6Fl0;oC9[c1_n4]_H00onha^Go]/GVokK5iP05okK5iP03
olG9g_o5c=ooaLcO00KoaLcO00?o_l_Sokk=i_nncNH01OnncNH2ojk4jPGo[<C[1_nU_n`00onV_^_o
ZL7[ojW1j`03ojW1j`03o`000?nY`N_oZL7[00OoZ<7[1onV_n/7ojNojaGooooo00?o0000oooooooo
ool03Oooool001Oooooo0_l0000Booooo`OoYko[00?oYl3[ojS1jonX`N/02_nX`N/2ojNoj`OoY[o[
1OnW_n/3ojS0j`KoZL7[1_nW`>/3o`0000GoY[k[1_nV_n/2ojW2k0KoY[o[1onP]nT3oiZ/i0;oSJ3Q
1_nAY>47oiZ^i@CoXl;_1?nii_@5olCak`?oan_^1Onheo000onZ`N[oXK7Toj6ai005oj6ai0KoX:kQ
1_nS/N800onV^^SoYkgYojNmj@05ojNmj@KoZKkX0_nW`Nd6ojW2k0Ko[L7X0_nY`^`8ojo1i`03okS1
hOnf`nCo]/?T00Co]/?T1?nd`N<4okS5i0OoWKc^1OmUXO85oe6Fl0KoOjkb1_nfaNH00onfa^KoaLcO
olG<g`06olG<g`03olK?hOnncNKo_/gV00Go_/gV0_nkc^T7ojc4j`;oYKo/1OnV_^/4ojW1j`04o`00
0?nY`N_oZL7[ojW1j`OoZ<7[1onV_n/7ojNojaCooooo00?o0000ooooooooool03Oooool001Oooooo
00?o0000ooooooooool04_ooool5ojNoj`?oYl3[2?nX`N/6ojNoj`OoY[o[00?oYko[ojS0jonX`>/0
1OnX`>/6ojW1j`;oYl3[00?oY[o[o`000?l000000onV_n/6ojJnj`;oY[o[1_nY`^`6ojJoj`?oX;OY
0onDZnH6ohfPh@KoTJCQ1onJ[^D00onS`^oo^NKdokWVm003okWVm0Goa?7_1Oo7jnh00onheo3oZ/7Z
oj[1jP03oj[1jPOoXK7T1_nP[^42oj>ahPGoY[[X1onW_NT2ojVnj0KoYl7]1_nY`^`2ojg1j0KoZL;/
1_n_`NL00on]`^Wo]/?TokK3i006okK3i003okC1honhaNCo^<GT00Go^<GT1_nM_>h4ofROl0;oIJ7b
1OmAU_06ogn^lP?o]/GV1?nfa^H6olG<g`?oa/oQ1?nncNH5ok_>j@Go[<C[00?oZL?/ojJnjonV_^/0
1_nV_^/4ojW1j`03o`000?nY`N_oZL7[00SoZ<7[0onV_n/3ojJnj`SoYko[5?ooool00ol0003ooooo
ooooo`0<ooooo`005oooool00ol0003oooooooooo`0Cooooo`03ojNojonW`>_oYl3[00GoYl3[1onX
`N/7ojNoj`GoY[o[0onW_n/7ojS0j`?oZL7[0_nX`>/3o`0000KoY[o[0onV_^/4ojJoj`OoZL;/0onV
_n/3oinhjPKoU:_V1_n=X>46oi6Th@GoVZkU1?n^co42okWVm0Coa?7_1_o7jnh00ongdNkoZ/7Zoj[1
jP05oj[1jPOoXK7T0onP[^43oj>gi`OoY[[X1OnW_NT2ojO2k0SoYl7]0onY`^`3ojJmjPSoZL;/0_n_
`NL5ojg2j@Ko]/?T0_nea>H6okS5i003okS9ionM_>koWKc^00GoWKc^1OmXWo04oeZCk@;oDIK`1_mo
[_800onfaNKo]/KVokK6iP04okK6iP?oaLcO1_o6cn400onncNKo^lkYok_>j@06ok_>j@03ojc4jonY
`ncoZL?/00?oZL?/2?nV_^/4ojW1j`03o`000?nY`N_oZL7[00KoZ<7[00?oYl3[ojJnjonV_^/01OnV
_^/6ojNoj`03ojS0jooooooooooo01?ooooo00?o0000ooooooooool02oooool001Oooooo00?o0000
ooooooooool05Oooool7ojO0j`OoZ<7[1onW_n/00onV_n_oYko[ojNoj`05ojNoj`GoZ<3[0_nY`N/0
1?nX`>_o0000o`000?l00003ojS0j`GoY[o[0_nV_^/7ojJoj`GoZL;/0_nW_n/6oinhjPKoU:_V1On=
X>47oi6Th@03oiZ^iOn^co7o[/oa00Go[/oa1?o3i^l00oo4lNooan_^olO[kP03olO[kPCo]m7^1_nZ
`NX6oj6ai003oi^_iOnS]nOoXkOW00GoXkOW1onV^^P00onW_NWoYl;/ojO2k004ojO2k0KoYl7]00?o
YkWVojJmj_nV_NX01OnV_NX6ojW2k0;oYKo/1on]`^T2okK3i0Ko]LCV0onhaN@4okS9i`OoWKc^1OmX
Wo05oeZCk@KoPZ__2?nfa^H00oo5c=ooa/oQolK?h@04olK?h@;oam;S1onkc^T00onfc>[oZL?/ojW3
k005ojW3k0KoY[k[00?oYko[ojW1jonY`N/00onY`N/00ol0003oZL7[ojW1j`02ojS1j`GoYl3[1onV
_^/2ojNoj`GoZ<3[5?ooool00ol0003oooooooooo`0;ooooo`005_ooool3o`0001Oooooo1OnW`>/3
ojS0j`KoZ<7[1OnW_n/3ojJoj`OoYko[00CoZ<3[ojW1jonY`N_oZL7[0ol00007ojS0j`03ojJojonV
_^_oY[k[00CoY[k[1onV_n/00onY`^coYko[ojNoj`04ojNoj`KoWkSZ1OnDZnH6ohfPh@?oTJCQ1OnK
/^P4ojk?l@Go`nK_1?o=k>X00oo7jnko]m7^okOAkP05okOAkPKoZ/7Z0_nQ/N@5oi^_i@OoXkOW0onV
^^P4ojS2k0OoYl;/0_nW`Nd5ojNiiPOoY[gZ0_nY`^`6ojFok0Go[L;Y00?oZ/7ZokG4i_nea>H01one
a>H00onhaNCo^<WWokS9i`04okS9i`OoWKc^1OmXWo05oeZCk@KoPZ__1_nfa^H2okS7i@Goa/oQ1?o7
d^<4ok_>j@Co]/cZ1onY`n`2ojJnj`GoYko[1?nY`N/00ol0003oZL7[ojW1j`07ojO0j`SoY[k[1onX
`>/Dooooo`03o`000?oooooooooo00[ooooo000Fooooo`03o`000?oooooooooo01Sooooo00?oYl3[
ojS0jonX`>/01OnX`>/6ojS1j`03ojNojonV_n_oY[o[00GoY[o[1OnW_n/00onW`>_oZL7[o`000002
o`0000CoZL7[1OnX`>/2ojNoj`OoY[k[1OnV_n/2ojW2j`OoYko[1_nO^>X5oiB[iP?oSJ3Q0on?YN@8
oi^bj003ojk?lOo3i^oo`nK_00Co`nK_1?o=k>X3olgUj@Oo]m7^0onZ`NX2oi^ai`SoVjoU1OnS]nL0
0onV_^_oZ<;/ojS2k006ojS2k0GoYl;/2OnW^NH5ojJmjP;oZ[cW2?nU_n`00on]`^WoZ/7Zoj[1jP03
oj[1jPOo]LCV0_nea^L7okS9i`?oWKc^1?nI^Nh3ofNIk0;oJ9o`1?mJTnd7oh:[k`;o]/KV1_nhanD3
olK?h@Koam;S00?o^lkYokK<j_nfc>X01Onfc>X3ojW3k0?oYl7/2?nW_n/4ojW1j`03o`000?nY`N_o
ZL7[00OoYl3[2?nV_^/5ojS0j`03ojS1jooooooooooo017ooooo0ol0000;ooooo`001?ooool4o`00
0008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h6ooooo`03o`000?oooooooooo01[ooooo
1onX`>/3ojS1j`CoYl3[1onV_n/00onW_n_oYl3[ojO0j`03o`0000SoZL7[00?oZ<3[ojNojonW_n/0
1?nW_n/7ojJnj`03ojJojonY`^_oZL;[00CoZL;[1onW_n/3oinhjP;oTZkY1On9XN@7ohnUi0KoVk;X
0onfd>h4ol?Vk`CocNcZ1Oo=iNT5okOAkP03ojS2k?nK/NOoVk7W00CoVk7W2?nK[nD00onS]nOoY[k[
ojJnj`03ojJnj`SoZ<;/00?oYl;/ojNii_nW^NH02onW^NH00onV_N[oZ[cWojZli`04ojZli`OoYKo/
1onZ`NX4okG4iPGo]LKW1OnhbNL2okK;jPOoVKW^1?mWVN`4ofBCj@04oeZCkOn2ZnooPZ__oh:[k`?o
RZ_/2OnhanD00oo6cn7oam;SolOBh`04olOBh`03olOFiOnfc>[o]/cZ00Go]/cZ00?o//W/ojO1k?nW
`N`01OnW`N`6ojNoj`;oZ<3[1?nY`N/00ol0003oZL7[ojW1j`07ojO0j`SoY[k[00?oZ<3[ojS1jonX
`N/00onX`N/?ooooo`?o00000_ooool00ol0003oooooooooo`09ooooo`001_ooool00ol0003ooooo
ooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`0Kooooo`Go
Z<3[00?oZ<7[ojO0jonW`>/01_nW`>/6ojJoj`?o00001?nW`>/6ojW1j`;oZ<7[1onW_n/7ojJnj`Oo
ZL;[0onW_n/3oinij`KoTZkY1On9XN@7ohnUi0?oVk;X1onfd>h00oo3i^oocNcZolg/jP02olg/jPOo
cNGY00?o]m7^ojS2k?nX`^`00onX`^`6oi^ai`KoVjoU00?oX[WYojJnjonV_^/01OnV_^/6ojS2k003
ojRmjOnW^NKoYkWV00_oYkWV0_n/^^@7ojZli`OoYKo/1onZ`NX00onea>Ko]LKWokG6i`06okG6i`03
okS9ionfbn[o]/_Z00Co]/_Z1onI^Nh4ofNIk0CoI9?Y1on:Zn`7okS7i@;o_<_U1?o7d^<4olOFi@Co
]/cZ1?nbbN`7ojO1k0;oYko[1_nX`>/3ojW1j`03o`000?nY`N_oZ<7[00SoYl3[1_nV_^/00onW_n_o
Z<7[ojS1j`05ojS1j`_ooooo0ol00005ooooo`03o`000?oooooooooo00Wooooo0006ooooo`03o`00
0?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`;o00007Oooool00onX`>_o
Z<7[ojS1j`03ojS1j`SoYl3[0_nV_n/3o`0000;oY[o[1_nW`>/2ojW1j`KoZ<7[1OnW_n/2ojJoj`Oo
Y[k[1OnY`^/2ojS1k0KoWkW[1_nB[^T5ohVQi0OoSjGT00?oVk;XokK@k_nfd>h01Onfd>h4olSQjP03
olg/j_o=iNWocNGY00GocNGY0_nldn/6ojS2k0KoVk7W0_nK[nD5oj:ij@OoY[k[0_nX`^`5ojRmj@Wo
YkWV1_n/^^@5ojZli`;o[l;X1onU_n`5oj[1jP;oZ/3Y1onea^L00ongbNSo]/_ZokK;jP06okK;jP?o
VKW^0on?/>d2ofR@i@;oIiW/1OmTTnT7ohZ[k0Co^<OU1OnlbnD00oo7d^?oamKUolOFi@05olOFi@03
okK<j_nbbNco//W/00Go//W/1OnW`N`2ojFnj`SoZ<3[00CoZL7[ojS1jonX`N_o00000_nX`N/8ojO0
j`;oY[k[1OnW_n/7ojS1j`Kooooo1?l00008ooooo`03o`000?oooooooooo00Wooooo0006ooooo`03
o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000005ooooo`;o00007oooool6ojS1
j`KoYl3[00?oYko[o`000?l000001_nV_n/3ojO0j`CoZL7[1onX`N/00onW_n_oY[o[ojJoj`04ojJo
j`OoY[k[00?oZL;[ojS1k?nX`N`01?nX`N`6oinij`GoTZkY1_n9XN@3ohnUi0CoVk?X1_nfd>h4olSQ
jPCodN?T0_o=iNT6okcCj`KoZ<;/0onK/NL4oiV`j0KoX[WY1OnV_^/2ojW2k0OoZ;gY1OnW^NH2ojNi
i@So[;[T00?oZ[cWojo2j?n_`^P01?n_`^P7ojFok003oj[1j_nZ`>WoZ/3Y00CoZ/3Y1?nea^L4okO9
j0Ko]/_Z00?o[/S]ohn`kOn?/>d01On?/>d4ofR@i@GoI9?Y1on:Zn`00onhanGo_<_Uokc;i@04okc;
i@;o`M3V1_o7e^D2ol?Hj@So//W/00?oYl7/ojFnjonU_^/01?nU_^/6ojS0j`03ojW1jonX`N_oZ<7[
00;oZ<7[00?o0000ojS1jonX`N/01_nW`>/00onV_n_oYko[ojNoj`05ojNoj`OoZ<7[0oooool3o`00
00gooooo00?o0000ooooooooool02?ooool000Kooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000000Gooooo00?o0000ooooooooool07oooool6ojS1j`;oYl3[00CoYko[o`00
0?l0003o00000_nW_n/5ojJoj`;oYko[1onY`N/5ojS1j`?oYko[1_nV_n/5ojJnj`?oZ<3[1_nX`N`6
oinij`GoTZkY0on9XN@3oh^TiPOoVk?X0onfd>h5olSQjPGodN?T0_oAgn87okcCj`?oZ<;/0_nH]>/8
oiV`j0KoX[WY00?oY[k[ojW2k?nY`^`01?nY`^`7ojRmj@03ojNii_nW^NGoYkWU00CoYkWU1_n/^^@9
ojo2j0OoYKo/1onZ`>T00onea^Oo]lWXokO9j005okO9j0;o]/_Z1On^b>d6ohn`k@CoJ93U1?m`U>H2
ofBCj@?oRZ_/1?nG/>P5okc;i@Co`M3V0oo7e^D5ol?Hj@Ko//W/00?o[LK/ojFnjonU_^/01_nU_^/2
ojS0j`GoZL7[1?nX`N/00ol0003oZ<7[ojS1j`02ojO0j`GoY[o[1onW_n/7ojS1j`;o00004?ooool0
0ol0003oooooooooo`08ooooo`001_ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@41001Oooool00ol0003oooooooooo`0Pooooo`GoZ<7[0ol00006ojNoj`03ojJojonW_n_o
Yko[00CoYko[1onY`N/00onX`N_oYko[ojNoj`05ojNoj`KoY[o[00?oY[k[ojS0jonX`>/01OnX`>/6
ojS1k0?oWkW[0_nE/n`5ohFRi`OoRjCV1onK/nP00onfd>kob>7ZolSQjP02olSQjPKodN?T1?oAgn85
okcCj`;o[/O/1OnH]>/8oiV`j0?oX[WY0onV_^X7ojW2k0?oZ;gY1?nS^^T7ojNii@;o[;[T2on_`^P0
0on_an_oYKo/ojFok006ojFok0GoZ/3Y0_n]`nX6okO9j0;o^]3[1on^b>d5ohn`k@GoJ93U1_m`U>H7
oiN`j0?o_<_U1_o1d>H00oo7e^Go`mSYol?Hj@05ol?Hj@;o//W/1On]a^`6ojFnj`03ojJnjonY`N_o
ZL7[00GoZL7[1?nX`N/00ol0003oZ<7[ojS1j`08ojJoj`?oYko[0onX`>/8ojS1ja7ooooo00?o0000
ooooooooool02?ooool000Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_l0000Rooooo`04ojS1jol0003o0000o`0000?oZ<7[1OnW_n/3ojJoj`KoYko[2?nY
`N/7ojNoj`?oY[o[0onV_^/8ojS0j`?oZ<7/0onR_N`5oiFck0GoQJ;W1on;Y>H5oi^cj0Co]LWZ00?o
b>7Zom7Si?oAhn@01?oAhn@6om7OhP03okcCjon^anco[/O/00Co[/O/1OnH]>/6oiV`j003oinijonV
_^[oY[kZ00GoY[kZ1OnY`^`00onU_ncoXk[Yoj>jj@06oj>jj@GoYkWU00?oYl3[ojo2j?n_`^P02On_
`^P4ojo7j`SoYKo/00?oZ/3Yojg3j_n]`nX01?n]`nX3okO9j0Go^]3[1on^b>d5ohn`k@GoJ93U1_m`
U>H7oiN`j003okc;iOo1d>Ko`M3V00Co`M3V00?oaMOWol?HjOo3f>T01Oo3f>T00onke>co[LK/ojg6
k006ojg6k0;oYKk[1OnV_^/7ojW1j`CoZ<7[00?o0000ojS1jonX`N/01_nV_n/00onV_^_oZ<3[ojS0
j`05ojS0j`OoZ<7[4Oooool00ol0003oooooooooo`08ooooo`001?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`0Oooooo`?o00001onX
`N/00onW_n_oY[o[ojJoj`05ojJoj`KoYko[2?nY`N/5ojNoj`03ojJojonV_^_oY[k[00GoY[k[1_nX
`>/2ojW2j`KoX[g/1OnE/n`5ohFRi`OoRjCV00?oVk?XokG9j_nebNX01?nebNX3olSHi@CodN?T1_oA
gn82olSHi@Oo[/O/1OnH]>/2oiV`j0GoWkW[1onV_^X00onY`^coYKo/ojFok003ojFok0SoXk[Y00?o
YkWUojO0jonW`>/00onW`>/9ojo2j0Ko[lO[1_nU_n`00onU_N_o[L?Zojg3jP06ojg3jP03okO9j?nj
d>_o^]3[00Go^]3[0on^b>d3oj6kk0GoPJ3W1?m^SN02ofR@i@KoL9CV0onG/>P3ojJii`Ko`M3V0oo5
enL4ol?Hj@Co^mC/1_n]a^`2ojS2k0OoY[k[0onY`N/3ojW2j`GoZ<7[00?o0000ojS1jonX`N/00_nV
_n/5ojJnj`OoZ<3[1onX`N/@ooooo`03o`000?oooooooooo00Sooooo000Eooooo`03o`000?oooooo
oooo01cooooo0ol00004ooooo`GoZ<7[0onW_n/7ojJoj`?oYko[1?nX`>/7ojW1j`03ojNojonV_n_o
Y[o[00?oY[o[1onV_^/2ojS0j`KoZL;[1_nR_N`5oiFck0GoQJ;W0on;Y>H4oiJ_j@Go]LWZ1_o8f>D0
0ooAhnCodMoRom7OhP03om7OhPGob=SU1On^an`00onQ_^koT[;/oi:bk004oi:bk0OoWkW[1OnV_^X2
oj[1j`KoYKo/1_nS^^T2oijmkPKoYl3[1_n_`^P3ok3:k@Ko[lO[0_nU_n`5ojFmj`Ko[L?Z0on`b>`5
ok[@j`;o]M3^1_nQ^n`5oh6Pi`GoKXgP1_mmV^@7ojJii`?o`M3V1_o5enL00oo3f>Wo^mC/ok_Dk005
ok_Dk0;o[LK/1_nX`^`5ojJnj`03ojS0jonY`^_oZL;[00GoZL;[1OnX`N/00ol0003oYl3[ojJnj`06
ojJnj`KoZ<3[2OnX`N/?ooooo`03o`000?oooooooooo00Sooooo000Eooooo`03o`000?oooooooooo
01Wooooo0ol00008ooooo`03ojS1jonW_n_oYko[00GoYko[1_nV_n/8ojS0j`GoZL7[0_nX`N/6ojJo
j`GoY[k[0onW_n/7ojW2j`?oX[g/0onJ^>d5ohFXj`GoQ:?X1onF[nT3okG9jPKob=SU1?o@fN000ooA
gn;ob=SUolSHi@06olSHi@03ojk7k?nQ_^koXKk^00?oXKk^1_nB/^`7oinij`03ojJnj_nZ`N_oZ/7[
00CoZ/7[1_nU_n`2oj>jj@KoW[g^1_nW`>/2ojo2j0Oo/<[]0on_an/3oj[3k0OoYKg[0_n]`nX7ok38
k003ok[@joned>ko]M3^00Co]M3^1OnQ^n`6oh6Pi`GoKXgP1_mmV^@7ojJii`03ol7@i_o5enOoaMOW
00CoaMOW0oo6g>T5ok_Dk0;o//c]2?nX`^`00onV_^_oZ<3[ojS0j`03ojS0j`OoZL;[0_nX`N/2ojO0
j`03o`000?nW`>_oYl3[00OoY[k[0_nX`>/<ojS1j`oooooo00?o0000ooooooooool02?ooool001Go
oooo00?o0000ooooooooool05_ooool3o`0000gooooo1onW_n/6ojJoj`SoZ<3[00?oZL7[ojS1jonX
`N/01?nX`N/6ojJoj`03ojJnjonW_n_oYko[00GoYko[1OnY`^/00onV`>coV[S]oiZhk@05oiZhk@Go
QJS[1On4XnP7oiJ_j@03okG9j_o8f>Gob=SU00Cob=SU1Oo@fN000ooCemcob=SUolSHi@05olSHi@;o
_<gW1_nQ_^h6oi:bk0?oWkW[1?nR_>`7oj[1j`?oYKo/0onO_Nh8oijmkP?oYl3[1?nWb?46ok3:k@03
ojc8k_nZ`ncoZ/?/00GoZ/?/1OnU_N/2ojW1j`Oo/<S/00?o]];_okG@k_ned>h01_ned>h5oj6kk0Go
PJ3W1_m^SN06ogfJi0GoY[WW0ondb>T3olGGi`Koa]cY00?o^mC/ok;<kOnbc>d01?nbc>d6ojS2k003
ojJnjonX`>_oZ<3[00GoZ<3[1OnY`^/2ojS1j`CoYl3[00?o0000ojO0jonW`>/00onV_^/4ojNoj`ko
Z<7[3oooool00ol0003oooooooooo`07ooooo`005?ooool2o`0001Gooooo0ol0000Aooooo`GoYko[
2?nV_n/6ojS0j`;oZL7[1onX`N/7ojJoj`OoYko[00?oZL;[ojK0k?nV`>`00onV`>`7oiZhk@GoQJS[
1On4XnP5oiJ_j@?oZkkX0oo8f>D6om3Ih0?odmOL1?o8f>D5okc=i`KoXKk^0onB/^`3oiBfkPOoX[c/
1OnZ`N/2ojW0jPKoWkg^1_nN_Nh2oig1l@OoYlSa0_n`b^d5ojc8kPOoZ/?/00?oYKg[ojW1jonY`N/0
1?nY`N/4ok38k0Co]];_1_ned>h00onW_n_oTj[Voi>ZiP03oi>ZiPCoNHoL0_n1X>L6ofj=h0KoOI[T
00?oY[WWokC8jOndb>T01Ondb>T00oo5enOoa]cYolKLj@04olKLj@03ol;MkOnbc>go//c]00Ko//c]
0_nX`^`5ojJnj`OoZ<3[00?oZL;[ojS1jonX`N/01?nX`N/4ojO0j`03o`000?nV_^_oYko[00OoYko[
3_nX`N/>ooooo`03o`000?oooooooooo00Oooooo000Dooooo`03o`000?oooooooooo01;ooooo0_l0
000Eooooo`03ojNojonV_n_oY[o[00[oY[o[0_nX`>/6ojW1j`GoZ<7[0_nW_n/7ojJoj`GoYko[0_nY
`>/6ojK0k0OoV[S]1On5Z>/5ohBSj003oiJ_jOn[_^SoZkkX00GoZkkX00?ob=SUom3Ih?o@fN001?o@
fN05om?Gg003olSHiOnlcNOo_<gW00Ko_<gW0onQ_^h3oiJjl0KoU;K^1onR_>`00onZ`N_oZL3ZojW0
jP04ojW0jPKoWkg^0_nN_Nh6oig1l@GoYlSa0_nWao06ojc8kPKoZ/?/0_nV_NX7ojW1j`03ok38k?nf
d^oo]];_00Go]];_0_ned>h5ojNoj`GoTj[V1OmiSm`6ogV@g@KoSJCT1ondb>T2okkDjPCoa]cY1?o2
gNd6ok;<k@03ojc6kOnV_^_oY[k[00KoY[k[0onX`>/3ojW2j`SoZ<7[00KoYl3[ojJnjonV_^_oY[k[
o`000?nV_^/8ojNoj`coZ<7[00?oYko[ooooooooool03?ooool00ol0003oooooooooo`07ooooo`00
5?ooool00ol0003oooooooooo`0?ooooo`?o00006?ooool:ojJoj`CoYko[1onY`N/00onX`N_oYko[
ojNoj`04ojNoj`OoY[o[00?oYko[ojW0jonY`>/01?nY`>/6ojK0k0?oV[S]0on>/^l5ogbSj`KoRj[Z
1_n[_^P3oko<i0Cod=WP1OoCem`3om7Bf@Ko_<gW0_nda^L6oiJjl0KoU;K^0onR_>`4ojBok0OoZL3Z
1_nO_Nh8oig1l@03ojO8lOnWao3oYlO`00CoYlO`1_n/b>h2oj[3k0KoY[gZ1OnY`N/3ojg9kPGo]];_
0_ncdNl6ojNoj`KoTj[V1OmiSm`6ogV@g@KoSJCT1?ndb>T5okkDjP03olKLjOo2gNgo`]g]00Go`]g]
0_nbc>d5ojc6k@OoY[k[1onY`^/7ojS1j`CoY[k[00?o0000ojJnjonV_^/01_nW_n/00onX`>_oZ<7[
ojS1j`07ojS1j`GoYko[3Oooool00ol0003oooooooooo`07ooooo`005?ooool00ol0003ooooooooo
o`0<ooooo`?o00007?ooool7ojJoj`OoYko[2?nY`N/6ojNoj`GoY[o[0_nU_n/7ojW0j`?oY/3/1?nQ
_Nd5ohjbk`GoO:?[1_n;Z^X3oj^nj0Oo_lcT00?od=WPom?Gg?oCem`00ooCem`6om7Bf@03okc=iond
a^Oo]<KW00Co]<KW1_nF^_03oiBfkP?oU[[`1onT_n`7ojW0jPKoWkg^1_nM`O42oj;1k`OoYlO`0on/
b>h3ojNnjPSoY[gZ00?oZL7[ojg9k_n]bNh01On]bNh00onfd^oo/m7_ok?Ak`04ok?Ak`KoYko[1OnC
Z^H6ogV?g0GoNI3M1on=Y>@00ondb>Wo_]CZokkDjP04okkDjP?oa=k/1Oo2gNd2okOBkPOo[<K]1onV
_^/7ojW2j`OoZ<7[1?nV_^/00ol0003oY[k[ojJnj`02ojNoj`GoZ<3[1onX`N/7ojNoj`cooooo00?o
0000ooooooooool01oooool001?ooooo0ol0000:ooooo`?o00008?ooool7ojJoj`OoYko[2?nY`N/6
ojNoj`03ojJojonU_n_oYKo[00CoYKo[1OnY`>/3ojW1j`KoXKg]1On>/^l5ogbSj`KoRj[Z00?oZkkX
oko<i?noc>@01Onoc>@3olW?gP?odmOL1_oAd]T2olg<f@Oo]<KW0onF^_03oi6hl@KoU[[`1onT_n`7
ojW0jPKoWkg^0_nM`O46oj;1k`GoYlO`0_nW_^T6ojNnjPKoY[gZ00?oZLG^ojg9k_n]bNh01On]bNh2
ok;Fl`Oo/m7_0onW_n/2oiZYh@CoQ9;I0_nCZ^H6ogV?g0CoNI3M1_n=Y>@2ojBij0Go_]CZ1Oo4g^`0
0oo2gNgo]m;^okOBkP04okOBkPGo[<K]0_nW`>/7ojJnj`?oZL;[0onY`^`8ojS1j`CoY[k[00?o0000
ojJnjonX`>/01onX`>/7ojS1j`OoYko[2oooool00ol0003oooooooooo`07ooooo`005?ooool00ol0
003oooooooooo`06ooooo`?o00009Oooool6ojJoj`GoYko[0onX`>/7ojW1j`?oYko[0onV_n/7ojFo
j`03ojW0jonY`N_oZL7[00GoZL7[1_nQ_Nd5ohjbk`GoO:?[0on;Z^X3oiRcj`Ko_lcT1Oo9cmh00ooC
emcodM;Iom7Bf@04om7Bf@CocLcI1Onda^L2ok72i`KoTKSa1_nF^_03ojBok0CoY<7]1onY`>X3oinm
kP?oYKg[2?nR`Nl00onWao3oYkkYojNnj@04ojNnj@KoYkkZ0_nV_NX5ojW5kPCo[LW^1Onbe_<5ok?A
k`03ojJiionJZN7oVZWQ00CoVZWQ1On4T]T6ogf=f0CoQY[O00?oNI3MohfTi?n=Y>@01_nT^NP3okkD
jPGoa=k/00?o`n;^okOBk_ngd^h01_ngd^h00on/a^goYl3[ojO0j`04ojO0j`GoY[k[00?oZL7[ojW2
k?nY`^`01OnY`^`6ojS1j`03ojNojonV_^_oY[k[00;oY[k[00?o0000ojJnjonV_^/01_nX`>/9ojS1
j`?oYko[0onV_n/;ooooo`03o`000?oooooooooo00Oooooo000Dooooo`03o`000?oooooooooo00?o
oooo0ol0000Yooooo`KoY[o[00?oYko[ojS0jonX`>/01OnX`>/5ojW1j`;oZ<7[1_nV_n/5ojFoj`?o
Y[o[1onY`N/3oj6mk@;oVk[^1Omo[?05ogfUk@OoV;?[0onoc>@7olW?gP03olk>f_oAd]WodM;I00?o
dM;I1_o=c=T00onda^Oo/L;Wok72i`04ok72i`KoTKSa0onF^_03oiFml`OoY<7]1OnY`>X2oj[2j`Ko
YKg[1_nR`Nl2ojRnj@OoYkkY0onW_^X3ojO2k@OoZLG^00?o[LW^ok;Flonbe_<01_nbe_<00oncdNoo
Y[WWojJii`03ojJii`KoVZWQ1On4T]T6ogf=f0GoQY[O2?nT^NP00onne>[oa=k/olCNk003olCNk0?o
`n;^1_ngd^h00on^bNgoYl3[ojO0j`06ojO0j`03ojJnjonY`N_oZL7[00?oZL7[1onY`^`2ojS1j`Go
Yko[1?nV_^/00ol0003oY[k[ojJnj`02ojS0j`_oZ<7[00?oYl3[ojJojonV_n/01OnV_n/;ooooo`03
o`000?oooooooooo00Kooooo000Cooooo`04o`000?ooooooooooooooo`?o0000;Oooool6ojJoj`So
Z<3[00?oZL7[ojS1jonX`N/01?nX`N/6ojJoj`03ojFojonV_n_oY[o[00GoY[o[1OnY`N/00onX`Nco
Vk[^oi^jkP04oi^jkPGoOjc`1OmmYNd7oiRcj`03oko<i?o9cmkobLoN00GobLoN0oo>c]X3om7Bf@Ko
cLcI0_o9a]L7ok72i`KoTKSa1_nE_O<7ojC1k@03ojW0j_nZ`^_oZ/;[00CoZ/;[1_nU_N/2oj;1k`Ko
Z;kY1OnW_^T2ojO3k@KoYl;]1OnYaNh3oj_Bm0Ko/]Kc00?o[/S]ojJiionV^NL01OnV^NL5oiZYh@Ko
Q9;I1OmmSMP6ohJJg`KoY;WX0_ngd>d3olCNk0Ko`n;^0_ngd^h5ojk9k@KoYl3[00?oY[gZojW1jonY
`N/01OnY`N/5ojW2k0;oZ<7[1onW_n/3ojJnj`03ojO0jol0003oYl3[00[oZ<7[1OnW`>/7ojJoj`[o
oooo00?o0000ooooooooool01_ooool001?ooooo1?l0000aooooo`KoY[o[1_nX`>/2ojW1j`OoZ<7[
0onV_n/3ojJok0SoY[o[00?oZL7[ojS1k?nX`N`00onX`N`6oi^jkPGoOjc`1OmmYNd5oiRcj`?oZKgX
1Oo9cmh5olk>fP03om7BfOo=c=WocLcI00CocLcI1?o9a]L5ok72i`;o/;oU1_nA^?46oiFml`?oY<7]
1?nQ`_07oj[2j`?oYKg[0onY`^/8ojRnj@03ojNnjOnW`ngoYl?]00CoYl?]1_nW`^d00onYaNkoZm;d
oj_Bm005oj_Bm0;o/]Kc1On^b>d7ojJii`GoVZWQ1On4T]T5ogf=f0OoQY[O0_nT^NP6okO@k@03olCN
k?o3h^ko`n;^00Co`n;^00?o^MS`ojk9kOn^bNd01_n^bNd2ojO0j`GoY[gZ1onY`N/00onY`^coZ<7[
ojS1j`04ojS1j`GoYko[0_nV_^/4ojO0j`03o`000?nW`>_oZ<7[00KoZ<7[2?nW`>/3ojJoj`?oYko[
2_ooool00ol0003oooooooooo`06ooooo`004oooool2o`0003Cooooo1_nV_n/2ojS0j`KoZL7[1OnX
`N/2ojO0j`KoY[o/1_nV_n/2ojS0j`KoZ<7/1_nK^^h5ogn/l0GoOJG]00?oV;?[ojVmj?nY_NP01OnY
_NP3olW?gPGoc/kJ0oo?bmH3olg<f@OobLKG00?o/L;Wok2oiOn`_nD01?n`_nD6oi6hl@?oUKgc0on@
_oH7oj72l0GoZ/;[0_nVaO06ojW2j`KoZ;kY00?oZ<G_ojO3kOnW`nd01_nW`nd3ojO2k@CoZ<od1On[
d_@2ojk@lPOo[/S]0onV^NL3oiVNe`GoRi7C1?n5S]D2ohBBf@GoOHgH0on6V]l4oiZ_i@Ko]m3]1?no
gnl00oo3h^ko^MS`okWHl003okWHl0Ko[/W]00?oZ<7/ojJmj_nV_NX01_nV_NX3ojW1j`?oZL;/2?nX
`N/00onW_n_oY[k[ojJnj`04ojJnj`?oYl3[00?o0000ojO0jonW`>/01onX`N/6ojO0j`SoYko[2Ooo
ool00ol0003oooooooooo`06ooooo`001Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?oo
ool00ol0003oooooooooo`0booooo`?oY[o[1?nW_n/7ojW1j`03ojS1jonW`>_oYl3[00CoYl3[1_nV
_n`2ojJoj`KoZ<3[1_nX`N`3oi^jkP?oU;S`1?meY_06oh:ZkPSoZKgX00?obLoNolk>f_o>c]X00oo>
c]X5olo;eP03olg<fOo9a]OobLKG00GobLKG0_o7`M@7ok2oi@?oTKSa0onG^Nl6oi2omPOoXL;`00?o
Z/;[ojK5l?nVaO001?nVaO06ojW2j`;oZ;kY1OnXaNl6ojO3k@03ojG>mOnXcoCoZ<od00KoZ<od00?o
Zm;dojk@l_n^d?801?n^d?85ojk8k@03oj:/g_nIW]OoVIkG00GoVIkG1On;TM<5ohF>e@GoR9OK2?nJ
[nD3okO@k@Go_mo_00?o`NG`okWHl?nif?001Onif?02ojk9k@GoZ<7/1_nV_NX00onX`NcoZL;/ojW2
k005ojW2k0KoZ<7[00?oYko[ojJnjonV_^/01_nV_^/3ojO0j`03o`000?nX`N_oZ<7[00OoZ<7[0_nW
`>/<ojNoj`Sooooo00?o0000ooooooooool01_ooool00005oiRHV?lQ8B7ok^k^oooooom4A4@00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Wooooo00?o0000ooooooooool0<oooool6ojNoj`OoZL7[
1onW`>/3ojJok0CoYKo/1onX`>/3ojS1k0?oYKo/1_nD^?04ogFVl0KoPZ[^1_nY_NP3okO3h`?oc/kJ
1_o?bmH00oo>am?obLKGolW6e`04olW6e`Coal7D1On`_nD2ok>kg`KoUkW_1_n@_oH3oj72l0CoVlSg
1onVaO03ojW2j`?oYLOa1onXaNl2ojO3k@GoYLke1_nXco@2ojWCmPOo[]3b00?o[/S]oj:/g_nR[=h0
0onR[=h6oiVNe`GoRi7C1_n5S]D5ohRGf`SoVZoU00?o]m3]okoOkonognl00onognl3ol7Ul0Go^MS`
0_n_bnh7ojS1k0;oY[gZ1OnX`N`7ojW2k0;oZ<7[1OnW_n/6ojJnj`03ojNojonX`N_oZ<7[00;oZ<7[
00?o0000ojS1jonX`N/01_nX`N/=ojNoj`03ojO0jooooooooooo00Kooooo00?o0000ooooooooool0
1_ooool00004oooooonHV9So8B4Qonk^kPCooooo00Go410@oooooooooooooooooa0@400:ooooo`03
o`000?oooooooooo03?ooooo1_nW_n/7ojW1j`GoYl3[0onV_n/6ojFok0GoZ<3[0_nY`>X6ojFok0Ko
U;S`1?meY_06oh:ZkP;oZKgX1ong`n<00oo>c][ocl_Folo;eP04olo;eP?oc/OC0oo9a]L7olO1e003
ok2oiOnc^moo/k_O00Co/k_O1_nG^Nl3oi2omP?oSKgg1onKb?L5ojK5l0;oWL_g1_nUao45ojS5k`?o
X/og1_nUc_D2ojS?m0KoZM?f0on^d?83ojNdhPOoXZcN1OnIW]L6oh^Ad`KoQHkE1On8Um/6oiZ_i@;o
/]3_0onognl6ol7Ul003okWHl?n_bnko[l_^00Co[l_^1OnX`N`2ojFmjPOoZ<7/0onY`^`3ojS1k0So
Yko[0_nV_^/5ojNoj`CoZ<7[00?o0000ojS1jonX`N/01_nX`N/9ojNoj`GoYl3[1oooool00ol0003o
ooooooooo`06ooooo`000_ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool0
00002oooool2o`0003Cooooo0onW_n/3ojO0j`OoZL7[00?oYl3[ojJojonV_n/01OnV_n/6ojFok003
ojS0jonY`>[oZL3Z00CoZL3Z1_nU_n`3oiBhl0?oRkGb0omaY_801?meY_3oPZ[^oh:Zk_n2Z^h4ohV`
l0Ko]l?S0_nnaMl5olo;ePGoc/OC00?obLKGolO1e?o7`M@01_o7`M@8ok>kg`?oUkW_0onQ^>T6ohfm
m`OoVlSg00?oY/G`oig;monMboL01?nMboL6ojG7l@03ojS5konRcoOoX/og00GoX/og0onUc_D4ojCB
m`GoZM?f00?oZ;OTojNdh_nW]>801OnW]>86oj:/gPKoVIkG1On;TM<6ohF>e@KoR9OK0_nJ[nD6ok;@
k`03okoOkoo1iO3o`NG`00Co`NG`0_nhfO47ojo;kP03ojS1k?nU_N[oYKgZ00CoYKgZ1OnX`N`2ojW2
k0KoZ<7/1_nW_n/00onV_^_oYko[ojNoj`06ojNoj`?oZ<7[00?o0000ojS1jonX`N/01onX`N/6ojNo
j`SoYl3[1oooool00ol0003oooooooooo`05ooooo`000oooool00omgMgOoIVIVooooo`02ooooo`05
o`000?ooooooooooooooool000003Oooool00ol0003oooooooooo`0booooo`KoYl3[2?nY`N/7ojJo
j`KoYKo/1onY`>X3ojFok0CoX[k]1On;]O85og6VlPKoRK3`0ong`n<5okk5g`?ocl_F1_o>am<00oo<
`m7oal7DolO1e005olO1e0;oakc@1_nc^ml2okNde`KoXKSY1_n=_OL3oi_8m`CoTLGi1onMboL3ojG7
l@CoWM3j1OnRcoL3oj3<m`KoY=;g00?oZM?fojRgi?nX]n@00onX]n@7ojNdhPKoXZcN1OnIW]L6oh^A
d`KoQHkE0on8Um/4oiZ_iPGo/]3_0onlh_82ol7Ul0Ko^=Wa0on_bnh3ojS1j`SoYKgZ00?oZ<7/ojW2
k?nY`^`01?nY`^`6ojS1k0;oYko[1OnV_^/6ojNoj`GoZ<7[00?o0000ojS1jonX`N/01OnX`N/8ojNo
j`KoYl3[00?oZ<7[ooooooooool01Oooool00ol0003oooooooooo`05ooooo`001?ooool01Ol0003o
oooooooooooooooo410@00?ooooo00?o410@ooooooooool03?ooool00ol0003oooooooooo`0boooo
o`KoYl3[2?nY`N/5ojJoj`03ojJok?nU_ncoYKo/00GoYKo/1OnY`>X3oj[1jPKoX[k]1On;]O85og6V
lPKoRK3`00?o]l?Sokk5gonnaMl01OnnaMl00oo?bmKoc/OColk7d`04olk7d`?oc<?A1Oo7`M@4olNl
d0?o/k_O1Ong]=L6oj6hj@?oSKgg1?nG^>h6oi75n@?oWL_g1OnDb?T6oig@nP03oj;?monPc?OoX<cg
00GoX<cg0onTd_L9ojRgi0OoYkCR0onR[=h2oiNCcPGoT93?1_n=TM<6ohjIfPSoVZoV00?o/]3_okcR
l_nlh_800onlh_83okgWl`Go^=Wa0_n^b^h6ojS1j`KoYKgZ00?oZ<7/ojW2k?nY`^`01_nY`^`3ojS1
k0?oYl3[1onV_^/2ojNoj`WoZ<7[00Co0000ojS1jonX`N_oZ<7[3?nW_n/2ojO0j`GoZ<7[1_ooool0
0ol0003oooooooooo`05ooooo`0000Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03oooool00ol0003oooooooooo`0booooo`?oYl3[1?nX`>/7ojW1j`03ojJojonV
_ncoY[o/00?oY[o/1onU_n`00onY`>[oZ/7Zoj[1jP05oj[1jPKoX[k]1On;]O85og6VlP?oRK3`0on?
]_46okk5g`;o`LKM1Oo>am<5olc3d@?oal7D1_o7_=000onc^moo]kCGokNde`05okNde`?oXKSY0on]
]=h7oiNhkP?oTLGi1?nI^^l7oiC8n@?oWM3j1?nN`o85oj3<m`03ojNdh_nX]nCoZ;OT00_oZ;OT0onW
]>83oijIc`KoUi?>1On@T<l6ohfAd`KoSYWJ1_nJ[nH2ok7DlP?o_>;b1_nmio<00onhfO7o[/[^ojk:
kP04ojk:kPKoZ<7[0_nU_NX5ojS1k0KoZL;/00?oZ<7/ojO0jonW`>/01OnW`>/5ojJnj`03ojNojonX
`N_oZ<7[00[oZ<7[00?o0000ojS1jonW_n/02_nW_n/2ojO0j`SoZ<7[1Oooool00ol0003ooooooooo
o`05ooooo`0000GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
4?ooool2o`0003Cooooo1_nX`>/5ojW1j`;oZ<7[1_nV_n`7ojFok0SoZ/7Z0onR_^d3oinnkPGoQ;?c
1Om_Z?@6ohnfl@?o_/GO1Oo1a]d3olk7d`Ooc<?A00?oal7DolNld?o7_=001Oo7_=07okNde`03okba
con]]=ko[KCN00Go[KCN1OnG^>h2ojRch@OoVK[_0onDb?T3oj6gj@SoW/?b00?oX<cgojNdh_nW]>80
0onW]>8:ojRgi0;oXig?1onNVLl5oiNCcPGoT93?1on=TM<5ohjIfPCoVZoV1Onae?800onlh_;o_NOc
okgWl`04okgWl`03ok?ElOn^b^ko[/[^00Ko[/[^0onX`N/3ojJmjPOoZ<7/0_nY`^`5ojS1k0OoYl3[
00?oY[k[ojNojonW_n/00onW_n/6ojS1j`03ojS1k?nX`N_oZ<7[00;oZ<7[00?o0000ojS1jonX`N/0
1onW_n/6ojO0j`OoZ<7[1Oooool00ol0003oooooooooo`05ooooo`007oooool00ol0003ooooooooo
o`0booooo`KoZ<3[00?oZL7[ojS1jonX`N/01?nX`N/6ojJok0OoYKo/2?nZ`NX6oinnkPGoQ;?c1Om_
Z?@6ohnfl@03okk5goo1a]go`LKM00Go`LKM00?oc/OColc3dOo<`m401Oo<`m400oo:`=3oakc@olNl
d005olNld0;oakW=1Ong]=L3okbac`Oo[KCN00?oUkS^ojRchOnX/n401?nX/n45oiVjk`03ojV_g?nQ
]nWoXKOY00GoXKOY1_nN`o800onX[]coYkCRojNdhP05ojNdhPGoZ;OT00?oYIk?oj>MconSWLl01?nS
WLl6oijIc`KoUi?>1On@T<l6ohfAd`KoSYWJ00?oVZoVok7Dl_nae?801?nae?82okWWm@Co_NOc1?nc
eO46ojk:kP03ojNojonV_N[oY[gZ00GoY[gZ1OnX`N`2ojS2k0OoZ<7/0onW`>/3ojJnj`OoYko[0_nX
`N/5ojS1k0CoZ<7[00?o0000ojS1jonX`N/01onW_n/6ojO0j`OoZ<7[1?ooool00ol0003ooooooooo
o`05ooooo`008?ooool00ol0003oooooooooo`0booooo`?oZ<3[0onY`>/7ojS1j`KoY[o/1onU_n`8
oj[1jPKoWkk^1On4/o<5ofnXm0?oSkKa0onB^O88ol76g@Koc<?A0oo:`=05olNld0CoakW=0ong]=L5
okbac`Go[KCN0_ncZm07ojRch@03oiVjkonY[mcoZJoL00?oZJoL1onQ]nT2oik3lPGoZ:kL1onW]>80
0onX]nCoYIk?ojFNc`03ojFNc`KoXig?1OnNVLl6oiNCcPGoT93?1on=TM<3ohjIfPCoX;[[0onae?85
okWWm@03okgWlonceO7o/mGa00Go/mGa0_n^b^h5ojNoj`OoY[gZ00?oZ<7/ojS2k?nX`^`01?nX`^`5
ojS1k003ojNojonV_^_oY[k[00GoY[k[1OnW_n/2ojS1j`OoZ<7/0onX`N/00onW_n_o0000ojNoj`08
ojNoj`?oYl3[0_nX`>/8ojS1j`?ooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000oooo
ooooool0<_ooool6ojW0j`GoZ<7[0onX`>/5ojJok0GoYKo/0onV_n`7oj[1jP?oWkk^0onN_Nh5oh2b
m0GoKJ[f1_nB^O88ol76g@?oc<?A1_o:`=03olNld0KoakW=00?o]kCGokbaconl/Ll01Onl/Ll00on]
]=ko/j_@ok>[d004ok>[d0GoZ;?Q00?o[jK?ojV_g?nY[m`01OnY[m`5oj6gj@03ojZVdonX[]coZ:kL
00GoZ:kL1_nW]>800onVWLgoYIk?ojFNc`04ojFNc`KoXig?1_nNVLl6oiNCcPGoT93?0on=TM<3oiJS
gPSoX;[[00?o/MCbokWWmOniioD00oniioD3okWTm0Go/mGa0_n/a^d7ojNoj`?oY[gZ2onX`^`00onX
`NcoYko[ojNoj`03ojNoj`OoY[k[00?oYko[ojS1jonX`N/01?nX`N/5ojS1k003ojS1jonW_n_oYko[
00;oYko[00?o0000ojNojonW_n/01_nW_n/00onW`>_oZ<3[ojS0j`04ojS0j`KoZ<7[00?oYl3[oooo
ooooool00_ooool00ol0003oooooooooo`04ooooo`008_ooool00ol0003oooooooooo`0booooo`Ko
ZL3[00?oZ<7[ojS0jonX`>/01OnX`>/5ojJok003ojFok?nV_ncoY[o/00GoY[o/1OnZ`NX2ojW1jPKo
W[g^1On0/_@5offZmPKoT[Wb2?o1a]d00oo<`m7ob/3@ol[0d006ol[0d003olNld?o7^LgoakW=00Go
akW=1onl/Ll00oo1/<[o/j_@ok>[d006ok>[d003ojRchOn_Y/oo[jK?00?o[jK?1onY[m`00onQ]nWo
ZZKCojZVd`03ojZVd`OoZ:kL0_nW]>85ojJMc@KoYIk?1_nSWLl5oijIc`?oUi?>0onGU]45oiFIePOo
UZ?N1_nP^^/3ok7NmP03okWWmOnii?Co^NCd00Go^NCd00?o/mGaojc6kOn/a^d01?n/a^d5ojNoj`;o
Y[k[3?nX`^`00onX`NcoYko[ojNoj`05ojNoj`?oY[k[0onW_n/8ojS1j`03ojS1k?nX`N_oZ<7[00?o
Z<7[1?nW_n/00ol0003oYko[ojNoj`02ojNoj`GoYl3[1_nX`>/2ojS1j`GoYl3[0oooool00ol0003o
ooooooooo`04ooooo`008oooool2o`0003?ooooo1onY`>/7ojS0j`goY[o/00?oZ/7ZojW1j_nY`NX0
1?nY`NX6oijmkPGoP;;d1Om]Z_H3oi:ilP?oTKcd1_o1a]d00onna^3ob/3@ol[0d006ol[0d003olRn
dOo7^LgoakW=00GoakW=0_o6^<`5okbac`?o`K3:1_ncZm000onkZlWo[jK?ojnVc`05ojnVc`GoZJoL
00?o[Z;;ojZVdonZY]<01OnZY]<5ojR^g003ojVMbOnVWLgoYYg=00GoYYg=1_nUW/l5oj>Mc`03oinG
bonKU/goViK=00?oViK=1onGU]45oiFIePOoUZ?N0_nP^^/5ok7NmP?o]>[g1Onii?@2ojo>l0Oo[<K]
00?oYko[ojJnjonV_^/01?nV_^/8ojS2k0GoZ<7/1OnW_n/2ojJnjPKoYko[1_nX`N/00onX`NcoZ<7[
ojS1j`05ojS1j`CoYko[00?o0000ojNojonW`>/01onW`>/3ojS0j`;oZ<7[2?nW`>/2ooooo`03o`00
0?oooooooooo00Cooooo000Uooooo`03o`000?oooooooooo03;ooooo1_nY`>/7ojS0j`goY[o/1onY
`NX6oijmkPGoOk?e1OmZ[?L6oi6lm0?o`LKM1?nna^06ol[0d0?ob;kA1Oo7^Ld4olJhc0?o_;7?1Oo1
/<X4ok>[d0?o^j_91on_Y/l00onY[mco[Z;;ojjRb`03ojjRb`OoZZKC00?oZ:kLojVMbOnYWLT00onY
WLT6ojJMc@OoYIk?00?oXig?oinGbonOUl/00onOUl/5oi^Fc@KoUiKA1_nEVMH5oiJSgP?oZM3d0ona
g_H6okCZm`03okWTm?n_c_3o[lk`00Co[lk`0on/a^d3ojNnjPSoY[k[1_nX`^`7ojS1k003ojNojonV
_^[oY[kZ00CoY[kZ1_nW_n/2ojS1j`GoZ<7/1OnX`N/6ojNoj`03o`000?nW_n_oYl3[00GoYl3[00?o
Z<3[ojS1jonX`N/01?nX`N/6ojO0j`04ojNojoooooooooooo`0000Kooooo000Vooooo`03o`000?oo
oooooooo03;ooooo1_nY`>/7ojS0j`goY[o/1OnY`NX2ojW0jPKoW[g^1Omo/oD5ofZ/m`KoTKcd00?o
`LKMokk6h?nna^001?nna^03ol[0d0Kob;kA0oo7^Ld6olJhc003okbacoo1/<[o`K3:00Co`K3:0onc
Zm05ok^[b@Go[jK?00?o]jK8ojjRbon^X//01On^X//5ojZVd`03ojnOb?nYWLWoZIg900GoZIg91_nV
WLd3ojFNc`?oY9W:1_nOUl/6oi^Fc@GoUiKA1onEVMH00onFXmkoZM3dojW@m005ojW@m003ok7Nm_nd
j_Oo]>[g00Co]>[g0_ncf_@5ojo>l0;oZL;[1_nW_^X6ojJnj`SoZ<;/0onX`N`3ojNoj`SoY[kZ0onW
_n/:ojS1k003ojS1jonW_n_oYko[00OoYko[00?o0000ojNojonW_n/00_nW`>/5ojS0j`KoZ<7[0_nW
`>/5ojNoj`03ooooool0003ooooo00Gooooo000Wooooo`03o`000?oooooooooo03;ooooo0onY`>/3
ojW0jPOoZ<3[3OnV_n`00onY`N[oZL3ZojW0jP04ojW0jPKoW[g^1Omo/oD5ofZ/m`?oTKcd0on;_OL7
okk6h003ol[0d?o8_]7ob;kA00Kob;kA00?oakW=olJhc?o6^<`01Oo6^<`8ol6`bP03ok>[d?nkZlWo
^j_900Co^j_90on_Y/l4okNVb0Oo[Z;;00?oZZKCojnOb?n_WlP00on_WlP6ojVMb@GoYYg=00?oZ9c:
ojBIb_nTVLX01OnTVLX6oinGb`GoViK=1_nGU]43oiFIePCoWkc]1_nYd?@3ojkWn@;o]>[g1_ncf_@0
0on_c_3oZL;[ojW2j`04ojW2j`KoYkkZ0_nV_^/:ojS2k0;oZ<7[1_nW_n/6ojJnjP03ojO0jonX`Nco
Z<7/00[oZ<7/00?oZ<7[ojNojonW_n/02OnW_n/00ol0003oYl3[ojS0j`07ojS0j`?oZ<7[1?nX`>/6
ojNoj`03o`000?oooooooooo00Cooooo000Xooooo`;o0000<oooool6ojW0jPOoZ<3[2_nV_n`3ojK0
k0OoZL3Z0onN_Nh3oinnkPKoP[Gf1?mU[OT6oh^mm`Go_/KP0_ngb>L7olRnd@03olG1e_o6^<coa[S<
00Goa[S<0_o4^<l6ol6`bP03ol6bc?nkZlWo^j_900Ko^j_900?o[jK?okNVb?ngY/P01?ngY/P5ojjR
b`03okBUbOn_WlSo[io800Co[io81onYWLT00onVWLgoZ9c:ojRLbP03ojRLbPKoY9W:1_nOUl/6oi^F
c@?oUiKA0onM[^<7oinlk@;oZM3d1On^ioT3ok;Un0Go/m[d00?oZlO^ojW2jonY`^/01_nY`^/3ojNn
jP?oYl7/2?nX`^`6ojS1j`KoYko[0_nV_^X5ojO0j`SoZ<7/1OnX`N/7ojNoj`CoYl3[00?o0000ojO0
jonX`>/01OnX`>/00onX`NcoZ<3[ojS0j`06ojS0j`?oYko[0_ooool00ol0003oooooooooo`04oooo
o`00:_ooool00ol0003oooooooooo`0aooooo`KoZL3Z1onX`>/7ojJok0KoY/3/1OnY`>X2oj[1jPKo
Wkk^1_n2]OH4ofF]n@KoRkgg00?o_/KPokO8iongb>L01?ngb>L4olRnd@CoaL7F1Oo6^<`4olBhc`Co
`K3:0oo1//`6ok^[b@03okf^bongY/So]jK800Go]jK80on^X//4okBUb@Ko[io81OnYWLT00on]XL_o
Z9c:ojRLbP04ojRLbPKoY9W:1onOUl/3oi^Fc@;oWjOL1onM[^<5oinlk@CoZN7j00?o[^Oiok;Un?nb
iOP01OnbiOP00oncf_CoZlO^oj_7kP03oj_7kPKoZL;[00?oY[k[ojO1k?nW`N`01OnW`N`5ojS2k003
ojS1k?nX`N_oZ<7[00KoZ<7[0onW_n/2ojJnjPSoYl3[1onX`N`6ojS1j`OoYko[1?nW`>/01?l0003o
Yl3[ojS0jonX`>/5ojS1k0KoZ<3[1oooool00ol0003oooooooooo`03ooooo`00:oooool00ol0003o
ooooooooo`0aooooo`OoZL3Z1_nX`>/7ojJok0KoY/3/00?oZL3Zoj[1j_nZ`NX01?nZ`NX6oinnkP?o
P[Gf0on9^?D3of:^n@04ofF]nOn;_OOoRkggoh^mm`?oP;cj1ongb>L00oo8_]7oaL7FolG1eP05olG1
eP?oa[S<1Oo4^<l3ol6`bPGo`K;<1?nkZlT3okf^b`Oo]jK800?o[Z;;okBUbOndYLT00ondYLT6ojnO
b0?oZIg91?n]XL/6ojRLbPKoY9W:1OnOUl/00onRYMSoWjOLoinWg004oinWg0OoWJkS00?oWkc]ojWQ
n_nYhOX01?nYhOX2oj[YnPKo/^Gh0_n/cO46oj_7kP;oZL;[1OnV_^/7ojO1k003ojS2k?nX`NcoZ<7/
00?oZ<7/1_nX`N/00onW_^[oY[kZojJnjP04ojJnjPKoYl3[2OnX`N`3ojS1j`[oYko[0onW`>/00ol0
003oZ<7[ojS1k007ojS1k0;oZ<3[2_ooool00ol0003oooooooooo`03ooooo`00;?ooool00ol0003o
ooooooooo`0aooooo`OoZL3Z1_nX`>/7ojJok0KoY/3/1onZ`NX3oinnkPCoX[k]1On9^?D5of:^n@Go
P;cj1Ongb>L00onXbO7oaL7FolG1eP07olG1eP03olJhc?o4^<ooa;S?00Goa;S?00?o`K3:ol6bc?o1
//`01?o1//`3ok^[b@Co_Jk;1_ngY/P00oni[<go]:G9okBUb@05okBUb@Ko[io800?oZIg9ojfQbon]
XL/00on]XL/6ojRLbPKoY9W:0_nOUl/5oj:Uf0KoWjOL1OnM[^<3ojKJnP?oZN7j1OnZjOX2ok;Un0Ko
[<ga0on[anh3ojNnjPOoY[k[0onW`N`3ojS2k0OoZ<7/0_nX`N/5ojNnjPKoY[kZ0_nW`>/;ojS1k003
ojS0jonW_n_oYko[00[oYko[00?oYl3[ojS1jonX`N/00_nX`N/00ol0003oZ<7[ojS1k005ojS1k0go
oooo00?o0000ooooooooool00oooool002gooooo0_l0000booooo`OoZL3Z1_nX`>/7ojJok0KoY/3/
1onZ`NX7oj:nk@GoRKSe1OmR[_T5oh2lnP03okO8ionXbO7oZ<Wa00?oZ<Wa1oo5`MH00onobN;oa;S?
olBhc`05olBhc`03ol;1fOo1//co`K;<00Ko`K;<00?o^j_9okf^bonm[//01?nm[//4okNVb0?o^Jc=
1_ndYLT5ojnOb003ok6VcOn]XL_o[J7;00Go[J7;1_nXW<X3ojBIbP;oYZOG1onRYMP7oinWg003oif^
honVf_[oY][j00GoY][j00?oZN7joj[Yn_nZjOX00onZjOX3ojcBm0Go[<ga00?oZ<3[ojNnj_nW_^X0
1OnW_^X5ojJnj`SoZ<;/1OnX`N`2ojRoj`OoYkkZ0onV_^X<ojS1k0GoZ<3[2?nW_n/5ojO0j`CoZ<7[
00Co0000ojS1jonX`NcoZ<7/4?ooool00ol0003oooooooooo`03ooooo`00;oooool00ol0003ooooo
ooooo`0`ooooo`OoZL3Z1_nX`>/7ojJok0KoY/3/1onZ`NX5oj:nk@;oYKk/1_nC^o<5ofN^n@GoLK[l
1OnXbO44olG1ePCo_lWR1Oo4^<l3ol;1f@Ko`K;<00?o_k_Fokf^bonm[//01Onm[//3okNVb0Co^Jc=
1ondYLT00on_WlSo/JK=ok6Vc@03ok6Vc@Ko[J7;1OnXW<X00onZ[=SoYZOGojJWe`04ojJWe`KoXZGH
1_nOYm`2ojCDn@KoY][j0onSjO/00onZjO[o[=;dojcBm005ojcBm003ojc=lOnX`>_oZ<3[00?oZ<3[
1onW_^X00onV_^_oZ<;/ojS2k00:ojS2k003ojS1k?nX_n_oZ;o[00CoZ;o[1OnW_^X00onW_n_oZ<7/
ojS1k00;ojS1k0SoZ<3[1OnW_n/8ojO0j`?oZ<7[00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`03ooooo`00<?ooool00ol0003oooooooooo`0aooooo`KoZL3Z1onX`>/6ojJok0?oY/3/0onU
`>`7oj[1jP03oj:nkOnU_^coYKk/00CoYKk/1_nC^o<5ofN^n@GoLK[l1OnXbO400oo5`MKo_lWRoko9
hP04oko9hP?oa;S?1_o2`MT3ol6bc0Co_k_F1onm[//00ongY/So^Jc=okV/c@04okV/c@Go]:G900?o
]K3Cok6VcOnaY/d01OnaY/d6ojfQb`03ojRLb_nZ[=SoZZcH00?oZZcH1_nVYmL6oj:Uf0;oWjOL1_nT
e?T2ojKJnPGoXnWk0_n/fOL6ojcBm003ojW3k?nX`>_oZ<3[00GoZ<3[0onW_^X3ojO1k0_oZ<;/0onX
`N/7ojRoj`03ojNnj_nW_n_oYko[00?oYko[3OnX`N`6ojS0j`03ojNnjonW_n_oYko[00CoYko[1_nW
`>/5ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00oooool0037ooooo00?o0000
ooooooooool0<Oooool7ojW0jPKoZ<3[1onV_n`5ojG0k0GoZ/7Z0onY`N/6ojFnk0?oTk_c0onJ_O06
ogJdn@CoHkKl1_n?ao/6oko9hP03olBhcoo2`MWo`/7I00Ko`/7I00?o`K;<oknke_no^mH01?no^mH5
okf^b`03okbkf?ni[<go^Jc=00Go^Jc=0ondYLT4okF`d`Ko/JK=1On]XL/00on^]=goZZcHojZ/f005
ojZ/f0KoYZOG0onRYMP4ojCAm`GoY=Ci1?nLio`00onSjO_o[=WgojcIm`04ojcIm`;o[=;d1OnY`n`5
ojS0j`;oY[o[1_nW`N`6ojS2k003ojS1k?nX`N_oZ<7[00GoZ<7[0onX_n/3ojNnjPOoYko[3OnX`N`2
ojS0j`GoYkk[1_nW_n/2ojO0j`Wooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`03
ooooo`00<_ooool2o`0003;ooooo1onY`>X6ojS0j`OoY[o/1OnU`>`00onZ`N[oZL7[ojW1j`05ojW1
j`CoYKk/0onX_nX5oiZml0KoM[Ci1?mS]_`6oho7n`?o_lWR0onYc_<7ol;1f@03okG>kOno^mKo_k_F
00Go_k_F0onm[//4okbkf0Oo^Jc=00?o]:G9okF`done/=<01?ne/=<6ok6Vc@03ojfQbon^]=go[[CM
00?o[[CM1_nZ[=P5ojJWe`?oXm7g1_nTdOL00onTe?WoW>OloicWo002oicWo0GoYmgj0on/fOL4ojW5
kPKoZL?/00?oZ<3[ojJojonV_n/01?nV_n/6ojO1k0;oZ<;/1OnX`N`5ojS1j`SoYkkZ1OnW_n/<ojS1
k0?oYko[1onW_^/3ojNoj`kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02oooo
o`00=?ooool00ol0003oooooooooo`0`ooooo`OoZL3Z1onX`>/6ojJok0KoYL3/1onY`N/00onU_^co
Z;oZojRojP04ojRojPGoV[g`0omf]?T4ohZjmP;oHkCk00CoHkKloho7non?ao_oSlOk1?mc`_h5ojW>
l`Co`/7I1?nec^d7oknkeP03okf^bonl^mSo_;_H00?o_;_H1_ni[<d00onh`^7o]K3CokF`d`05okF`
d`Go/JK=00?o/L;VojjdgOn^]=d01On^]=d6ojZ/f003ojJWeonSdOOoXm7g00GoXm7g0onTdOL3oiOT
o0?oX]gl1OnWgOX2ojW7l0OoZLG^0onY`n`3ojNnjPOoY[o[0onW`N`4ojS2k0KoZ<7/00?oZ<7[ojNn
j_nW_^X02_nW_^X00onW_n_oZ<7/ojS1k009ojS1k003ojS1jonW_n_oYko[00GoYko[1OnW_^/Boooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool003Gooooo00?o0000oooooooo
ool0<?ooool5ojW0jP;oZL3[1onX`>/6ojJok0OoYL3/0onY`N/3ojS1j`OoZ;oZ0_nJ_O04oj6mk@Ko
R[[f1OmS]?/5og?2oPGoZLkc00?o`/7IokG>kOnec^d01?nec^d6oknkeP03okG?kOnl^mSo_;_H00Go
_;_H0_ni[<d5okS2h@Oo]K3C00?o/JK=ok72i_na`^H00ona`^H7ojjdg@?oZZcH0onRe?T6oj?Am`?o
TN;m00?oUnCloj;Mo?nRgO`01OnRgO`00onWgO[oZLO`ojW7l004ojW7l0GoZLG^00?oYkkYojNnj_nW
_^X01OnW_^X5ojJoj`WoZ<;/0onX`N`2ojNoj`_oYkkZ0_nW`>/9ojS1k0GoZ<7[1onW_n/00onW_^_o
ooooooooo`0Dooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool003Kooooo
00?o0000ooooooooool0<?ooool00onY`>[oZL3[ojW0j`04ojW0j`GoZ<3[0_nX`>X6ojJok0OoYL3/
1_nX`N/5ojRojP;oZL7Z1_nQ_Nd3ohZjmP?oVKga1_mg]oX5of2ko@GoQ<cn1_nec^d2oknkePGo]Lo]
1Onl^mP2ojgBm0Ko^<;Q1_ne/=<00on^dO;o/L;Vok72iP04ok72iPKo[[CM0_nMf?`6oj;Dn@;oXm7g
1OnAh_d3oicLo@GoX]gl0_nWb?47ojW7l003ojW5k_nW_^WoYkkY00?oYkkY1onW_^X00onV_n_oZ<;/
ojS2k009ojS2k003ojS0jonW_n_oYko[00CoYko[1_nW_^X00onW_n_oYl3[ojO0j`04ojO0j`OoZ<7/
1onX`N/3ojNoja_ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`00=ooo
ool2o`00037ooooo1onY`>/00onX`>_oZ<3ZojS0jP04ojS0jPKoY[o/1onU`>`6ojS1j`03ojRoj_nY
`N[oZL7Z00CoZL7Z1?nQ_Nd2ojJnj`KoVKga1_mg]oX5of2ko@GoQ<cn0onec^d4ohc@oPKo]Lo]00?o
_;_HojgBm?n]d_@01?n]d_@6okS2h@;o]K3C1On^dO86ok72iP;o[[CM1_nMf?`3oj;Dn@GoRn3m00?o
TN;moicLoOnLg?d01OnLg?d00onRgOcoYlSaojO8l@04ojO8l@?oZLO`2_nW_^T3ojNnjPcoZ<;/1OnX
`>/6ojNoj`;oYkkZ1OnW_n/6ojO0j`OoZ<7/1OnX`N/Pooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool00_ooool003Wooooo00?o0000ooooooooool0;oooool7ojW0j`OoZ<3Z0onV_n`3
ojNoj`OoYL3/0onX`N/4ojK0k0KoZL7Z00?oXKg]ojJnjonV_^/00onV_^/6oiVml@?oMkOj1?nA_OD5
offho0GoIL;n1_n<d?h3okG?k@CoRM?o1_n]d_@3okS2h@CoVMOm1_n^dO83ok72iPGoTm[n0onMf?`5
oh?Mo@?oRn3m1OnIf?d3oicLo@?oY/Sa1OnWb?4=ojNnj@;oYl;/2_nX`^`3ojS1k0OoZ<3[0onW_n/3
ojNnjPOoYko[0onW`>/:ojS1k003ojS1jooooooooooo027ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`02ooooo`00>_ooool00ol0003oooooooooo`0_ooooo`OoZL3[1OnX`>X2ojW0
jPKoYko[1OnU`>`9ojK0k0?oZL7Z0onY`N/6ojJnj`?oVKga1?nR_Nd6oi6mm@GoKKSl1OmU`_h3ohc@
oPCoJ<On1_n9dol3ojgBm0CoO]Co1_nIeod3ojkAlPGoQ=Wn0onCf_h5ogcIo@?oPmgm0onGdo`6oiWH
o@;oYLKa1_nVb?400onWb?7oYkkYojNnj@0;ojNnj@KoYl;/1OnX`^`8ojS1k0GoZ<3[2?nW_^X5ojNo
j`_oZ<7/:?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00;ooooo000kooooo`03
o`000?oooooooooo033ooooo1_nY`>/00onX`>[oZL3ZojW0jP04ojW0jPKoYko[00?oYL3/ojK0k?nV
`>`02OnV`>`2ojG0k0KoZL7[1?nV_^/2ojW0jPOoX[g]0onA_OD3oinmkPKoS;kg1_m]_Od5ofS7oP?o
RM?o1?mXb_d6ogkDo`?oVMOm1Omcdod3ohCIoPGoOmCo0omlfOd3oiS<nPKoUm?l0_nIf?d6ojG6l@?o
Y/Sa3OnW_^T3ojO1k0OoYl;/00?oZ<;/ojS1k?nX`N`02_nX`N`00onX`>_oYkkZojNnjP0:ojNnjP03
ojNojonX`NcoZ<7/00SoZ<7/;Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo007o
oooo000looooo`03o`000?oooooooooo033ooooo0onY`>/3ojS0j`OoZL3Z1onW_n/7ojK0k0KoYL3/
1_nY`N/00onV_^_oZL3ZojW0jP03ojW0jPGoX[g]0_nX_nX6oinmkPKoS;kg0om]_Od4ohfon0KoLl;n
1OmXb_d3ogkDo`GoLLco0omcdod4ohK<oPGoOmCo0_nMb?H6oiS<nP?oUm?l1?nUa?05ojG6l@goYkkY
2?nW`N`5ojO2k0_oZ<7/3OnW_^X4ojO1k0OoZ<7/<Oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo007ooooo000mooooo`;o0000<Oooool6ojS0j`OoZL3Z1onW_n/6ojK0k0OoYL3/0onY
`N/3ojO1k0KoZL3Z00?oX[g]ojRoj_nX_nX01?nX_nX6oinmkP?oS;kg1?nN_^l6ohfon0?oLl;n1?nD
`_H6oh34o@?oLLco0onBaOT7ohK<oP03ogoDoonMb?KoWLSf00CoWLSf0onHc?X4ojG1kPKoYLC`00?o
YLKaojNnjOnW_^T02onW_^T<ojO1k003ojO2k?nX`NcoZ<7/00SoZ<7/0_nW_nX;ojNnjP;oYl3[1onW
`N`3ojS1k3Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`01ooooo`00?oooool0
0ol0003oooooooooo`0_ooooo`KoZ<3[1onY`>X5ojNoj`;oZ;oZ1_nV`>`5ojG0k0;oY/3/1_nW`N`3
ojW0jP?oZ<7[1onX_nX3oinmkPCoYkkZ1_nN_^l3ohfon0CoWkk^1_nD`_H3oh34o@?oWL;b1_nBaOT3
ohK<oPCoWl?b1OnMb?H2ojFok0OoYL7^0onUa?03ojRnj@[oYkkY3?nW`N`4ojO2k0OoZ<7/1_nW_nX7
ojNnjPKoYl3[1OnW`N`iooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00Oooool0
043ooooo00?o0000ooooooooool0;oooool3ojS0j`CoYl3[1_nY`>X00onW_n_oZ;oZojRojP04ojRo
jPKoY/3/00?oYL3/ojK0k?nV`>`01?nV`>`4ojO1k0;oYL3/1_nX`N/5ojRojP;oZL7[1onW_^X3oijn
k`?oYkkZ1onO_^h3oiC2mP?oX[k]1_nM`_83oi;5n@CoXko^1_nO`o800onMb?KoYKo/ojFok004ojFo
k0GoYL7^00?oZ;kZojRnjOnX_^T01OnX_^T5ojNnj@coYl7/2OnW`^`3ojS1k0CoYko[1_nW_nX3ojNn
jP?oYko[1onW`>/00onW`Ncoooooooooo`0kooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool00Oooool0047ooooo00?o0000ooooooooool0;oooool7ojO0j`?oZL3Z0onY`>/7ojRojP?o
Y/3/1?nW_n/6ojK0k003ojO1k?nU`>coYL3/00?oYL3/1_nX`N/00onX_n[oZL7[ojW1j`04ojW1j`Go
YkkZ0_nY`N/6ojNnjPGoWkk^00?oYkkZoj:nkOnR_^d01OnR_^d3oig2lP?oY[kZ1onS_nh3oio3lPCo
YkkZ1_nU_n`00onU`NkoZ;kZojRnjP03ojRnjPOoZ;kY00?oYkkYojO1k?nW`N`02_nW`N`;ojO2k0Wo
Yko[0onW_nX2ojNnjPOoYko[0onW`>]1ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool00Oooool004;ooooo0_l0000`ooooo`GoYl3[0_nW`>`6ojW0j`GoZ;oZ0_nY_nX7ojNoj`OoY/3/
1OnU`>`3ojS1j`CoY/7]1_nY`N/00onW_^[oZL7[ojW1j`04ojW1j`KoYkkZ00?oWkk^ojNnj_nW_^X0
0onW_^X5oj:nk@;oZ;oZ1_nV_^X5oj>okP;oZ;kZ1onW_^X3ojFok0;oZ;o[1onX_^X3ojRnj@CoYl;]
3OnW`N`7ojO2k0_oYko[1onW_^X5ojNojdKooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`01ooooo`00A?ooool00ol0003oooooooooo`0^ooooo`03ojO0jonW`>coYl3/00CoYl3/1_nY
`>/00onX_n[oZKoZojVojP04ojVojPGoYko[0_nX_nX7ojK0k0;oYL3/0onV`>`7ojK1k@?oZL7[0onV
`Nd7ojW1j`?oYkkZ1?nY`N/5ojNnjP03oj:nkOnX_n[oZ;oZ00CoZ;oZ1_nV_^X00onS_nkoZ;kZojRn
jP04ojRnjPGoYkkZ00?oZ<7/ojRojonX_n/01?nX_n/5ojRnjPWoYl;]3OnW`N`3ojO2k0?oYl3[2?nW
_n/;ojNnjP03ojNojooooooooooo04Sooooo00?o0000ooooooooool01oooool1o`00007ooooo0Ooo
ool004Gooooo00?o0000ooooooooool0;oooool6ojO0k0?oZL3[1?nX`>/6ojVojP03ojNojonX_n[o
Z;oZ00CoZ;oZ1OnV`>`00onW_n_oY/3/ojK0k004ojK0k0GoY/7]0_nV`>`6ojK1k@GoZL7[0_nV`Nd7
ojW1j`;oYkkZ0onY`^`7ojRojP?oY[kZ1?nY`N/6ojRnjP03ojNnj_nX`NcoZ<7/00?oZ<7/1_nX_n/0
0onX_^[oYl;]ojO2k@09ojO2k@goYl7/2?nW`>/3ojNoj`goYkkZC_ooool00ol0003oooooooooo`06
ooooo`7o00000Oooool1ooooo`00A_ooool00ol0003oooooooooo`0`ooooo`;oYl3/0onV`>`7ojS0
j`?oZKoZ1?nY`>X6ojRojP03ojK0k?nW_n_oYko[00?oYko[1_nV`>`00onV`NgoY/3/ojK0k004ojK0
k0KoY/7]00?oZL7[ojK1kOnV`Nd01?nV`Nd5ojW1j`03ojK1kOnY`^coZL;/00CoZL;/1OnX_nX2ojO2
k0OoZL7[0onX_^X2ojO2k@OoZ<7/0onX_n/;ojO2k@goYl7/2_nW`>/=ojNnjU;ooooo00?o0000oooo
ooooool01_ooool1o`00007ooooo0Oooool004Oooooo0_l0000aooooo`GoY/3/1OnX`>/2ojO0k0Oo
ZL3Z0onX_nX3ojVojPKoYko[0onV`>`4ojNoj`KoY/3/0onV`Nd4ojK0k0KoY/7]00?oZL7[ojK1kOnV
`Nd00onV`Nd6ojW2k003ojRoj_nW`^coYl;/00CoYl;/1OnY`N/00onV`NgoYl;]ojO2k@04ojO2k@Go
Z<7/0_nW`Nd:ojO2k@goYl7/0onW_n/7ojO0j`goYkkZE_ooool00ol0003oooooooooo`05ooooo`7o
00000Oooool1ooooo`00BOooool00ol0003oooooooooo`0_ooooo`GoY/3/00?oZ<3[ojO0k?nW`>`0
1?nW`>`5ojW0jP;oZ<7[1_nY_nX4ojNoj`;oZ;oZ1onW_n/3ojK0k0?oY[o[1onV`>`3ojK1k@?oY/3/
1_nV`Nd3ojW2k0CoY/7]1_nW`^`00onY`N_oY/7]ojK1k@03ojK1k@KoYl;]00?oZ<7/ojO1kOnW`Nd0
1?nW`Nd5ojO2k@coYl7/2OnW_n/3ojO0j`goYkkZF_ooool00ol0003oooooooooo`04ooooo`7o0000
0Oooool1ooooo`00B_ooool00ol0003oooooooooo`0_ooooo`KoY/3/1_nW`>`00onY`>[oZ<7[ojS1
j`04ojS1j`KoZKoZ00?oYko[ojRoj_nX_nX00onX_nX5ojNoj`;oZ;oZ1_nV_n/5ojK0k003ojNojonV
`>coY/3/00GoY/3/0onV`Nd3ojK0k0OoY/7]0onW`^`3ojK1k0KoY/7]0onW`^d4ojK1k0KoYl7]00?o
Yl;]ojO1k?nW`N`02OnW`N`00onW_n[oYko[ojNoj`09ojNoj`;oZ;kZ2onW_^YOooooo`03o`000?oo
oooooooo00?ooooo0Ol00001ooooo`7ooooo001;ooooo`03o`000?oooooooooo02oooooo1_nV`>`3
ojO0k0?oY/3/1onX`N/3ojVojP?oZL7[1_nX_nX00onW_n_oZ;oZojRojP04ojRojPKoY[o[00?oY/3/
ojNojonW_n/00onW_n/5ojK0k0;oYko[1_nV`>`5ojK1k@;oY/3/1_nV`N`3ojK1k@?oYl3/1onV`N`3
ojO1k@CoYl3[1onW`N`5ojNojPOoYko[1_nX_^X7ojNnjV;ooooo00?o0000ooooooooool00oooool1
o`00007ooooo0Oooool004cooooo0_l0000`ooooo`coY/3/1OnX`N/2ojO0k0KoZL7[0onX_nX3ojW0
jPOoZ;oZ0onV_n/4ojRojPGoYko[00?oY/3/ojNojonW_n/01?nW_n/6ojK0k003ojK1kOnV`>coY/3/
00CoY/3/1?nV`N`2ojNoj`KoYl3/1OnV`N`2ojNoj`OoYl3[0onW`N`2ojNnjPOoYkoZ0onW_n/:ojRn
jP?oYkkZI_ooool00ol0003oooooooooo`03ooooo`7o00000Oooool004kooooo00?o0000oooooooo
ool0;_ooool<ojK0k003ojS1jonW`>coYl3/00CoYl3/1?nY`N/2ojO1k0KoZL3Z1OnX_nX2ojW0jPOo
Z;oZ0_nW_n/4ojRnjPKoYko[0onV`>`4ojNoj`KoY/3/00?oY/7/ojNojonW_n/00onW_n/6ojO0k003
ojK1k?nW_n_oYko[00CoYko[1OnW`>/00onX_^[oYkkZojNnjP04ojNnjPGoYkoZ0_nX_nX:ojRnjVco
oooo00?o0000ooooooooool00_ooool1o`00007ooooo001?ooooo`03o`000?oooooooooo02oooooo
3?nV`>`6ojO0k003ojW1jonW`NcoYl7/00?oYl7/1_nY`>X00onX_n[oZL3ZojW0jP04ojW0jPGoZ;oZ
00?oZKoZojRnj_nX_^X01OnX_^X3ojNoj`?oZ;kZ1onW_n/3ojK0k0?oYkkZ1_nW_n/3ojO0k0CoYkkZ
1_nW_n/00onW`>_oZ;kZojRnjP03ojRnjPKoYkkZ00?oYkoZojRoj_nX_nX01?nX_nX5ojRnjW7ooooo
00Go0000ooooooooooooooooo`000001ooooo`00D?ooool00ol0003oooooooooo`0_ooooo`;oY/3/
1?nW_n/6ojK0k0?oYl3/1?nV`>`5ojO1k0?oZL3Z1?nX`N/6ojW0jP03ojRoj_nY_n[oZKoZ00?oZKoZ
1OnX_^X2ojW0jPKoZ;kZ1OnW_n/00onX_n[oYkkZojNnjP05ojNnjP?oYko[0onX_^T7ojNnjP?oYko[
2OnX_^X3ojNnjPCoZ;o[1_nX_nX00onX_^[oooooooooo`1booooo`05o`000?ooooooooooooooool0
00000Oooool0057ooooo0_l0000`ooooo`KoYko[0onV`>`3ojNoj`OoY/3/0_nW`N`4ojK0k0KoZ<7[
0onY`>X4ojS1j`GoZKoZ00?oZ;kZojW0j_nY`>X01?nY`>X6ojRnjP03ojNojonX_n[oZ;oZ00?oZ;oZ
1OnW_^X2ojRojPKoZ;kY1OnW_^X00onX_n[oZ;kZojRnjP08ojRnjP?oZ<3[1onX_n/3ojRojWSooooo
00Co0000oooooooooooo00000Oooool005?ooooo00?o0000ooooooooool0;_ooool4ojNoj`;oZ;o[
1_nW_n/=ojK0k0?oZ<7[0onW`>`7ojS1j`;oZKoZ1?nX`N/6ojW0jP?oZ;kZ0onX`>/6ojRojP03ojNn
j_nX_n[oZ;oZ00CoZ;oZ1_nX_^T00onW_^[oZ;oZojRojP03ojRojPGoZ;kZ0_nX`N`6ojS0j`GoZ;o[
OOooool00ol0003oooooo`000001ooooo`00E?ooool00ol0003oooooooooo`0^ooooo`03ojNojonX
_n_oZ;o[00?oZ;o[1_nW_n/=ojK0k0KoYl3/1OnX`N/00onW`NcoZ<7[ojS1j`05ojS1j`?oZL3Z0onW
`N`6ojS0j`?oZ;oZ1?nX`N/6ojRojP?oZ;kY0onX`N/6ojRojP03ojRnj_nX`NcoZ<7/00CoZ<7/1_nX
`>/00onX_n_oooooooooo`1nooooo`03o`000?oooooo0000007ooooo001Eooooo`03o`000?oooooo
oooo02kooooo1_nX_n/7ojNoj`coY/3/1_nW`>`00onX`N_oYl7/ojO1k003ojO1k0GoZ<7[2?nW`N`4
ojS0j`;oYl7/1onX`N/3ojRojP;oYl7/1onX`N/3ojRojPCoYl7/1_nX`N`3ojS0jhCooooo0Ol00001
ooooo`7o0000001Fooooo`;o0000;oooool3ojRoj`?oZ<3[1onW_n/2ojK0k0CoYko[1_nV`>`3ojO0
k0CoY/3/1OnW`N`00onX`N_oYl7/ojO1k00:ojO1k003ojS0jonW`NcoYl7/00?oYl7/1OnX`N/7ojO1
k0GoZ<7[2OnW`N`3ojS1k8[ooooo0_l0000005Sooooo00?o0000ooooooooool0;Oooool6ojS0j`Go
Yko[0_nX_nX6ojNoj`?oY/3/0onW_n/7ojK0k0;oYl7/1?nV`>`BojO1k003ojS1jonW`NcoYl7/00Wo
Yl7/00?oZ<7[ojO1k?nW`N`02OnW`Nb=ooooo`?o0000001Iooooo`03o`000?oooooooooo02gooooo
1_nX`>/00onW_n_oZ;oZojRojP04ojRojPCoYko[0_nX_nX6ojNoj`GoY/3/00?oYko[ojK0k?nV`>`0
1OnV`>`3ojO1k0CoYl3/7onW`Nb<ooooo`Co00000oooool005[ooooo00?o0000ooooooooool0;Ooo
ool7ojS0j`KoZ;oZ00?oYko[ojRoj_nX_nX00onX_nX6ojNoj`03ojK0k?nW_n_oYko[00?oYko[1OnV
`>`2ojNoj`OoYl3/0_nW`N`3ojO0j`[oYl7/0onW`>`9ojO1k8cooooo0ol00007ooooo`00Foooool0
0ol0003oooooooooo`0]ooooo`OoZ<3[0onX_nX3ojS0j`KoZ;oZ0onW_n/4ojRojPGoYko[00?oY/3/
ojNojonW_n/01?nW_n/5ojO0k003ojNojonW`>_oYl3[00CoYl3[1OnW`N`00onW_n_oYl3/ojO0k005
ojO0k0?oYl7/SOooool4o`0000[ooooo001Looooo`;o0000;_ooool5ojS0j`;oYl3/1_nX`>/3ojRo
jPCoZ<3[1_nX_nX2ojNoj`CoZ;oZ1_nW_n/00onW`>coYko[ojNoj`03ojNoj`KoYl3[00?oYl7/ojNo
jonW_n/00onW_n/5ojO0k8gooooo1?l0000>ooooo`00G_ooool00ol0003oooooooooo`0/ooooo`03
ojS0jonW`>coYl3/00CoYl3/1?nX`>/2ojO0j`OoZ<3[0onX_nX2ojS0j`OoZ;oZ0onW_n/3ojRojPKo
Yko[0onW`>/4ojRojPGoYko[00?oYl3/ooooooooool0R_ooool4o`0001;ooooo001Oooooo`03o`00
0?oooooooooo02gooooo1_nW`>`00onX`>_oYl3[ojO0j`03ojO0j`GoZ<3[0_nW`>/5ojS0j`GoZ;oZ
0_nX`>/6ojRojP?oYko[2_nX_nX2ojNojh_ooooo1?l0000Fooooo`00H?ooool00ol0003ooooooooo
o`0]ooooo`OoYl3/1OnW`>/00onX`>_oYl3[ojO0j`04ojO0j`GoZ<3[00?oZ;oZojS0jonX`>/01?nX
`>/4ojRojP;oZ<3[2onX_nZ;ooooo`?o00006_ooool0067ooooo0_l0000_ooooo`KoYl3/0_nW`>/4
ojO0k0KoYl3[0_nX`>/4ojO0j`KoZ<3[00?oZ;oZojS0jonX`>/00onX`>/7ojRojX[ooooo1?l0000M
ooooo`00Hoooool00ol0003oooooooooo`0]ooooo`coYl3/0onW`>/3ojO0k0KoYl3[0onX`>/3ojO0
k0KoZ<3[0onX_nZ9ooooo`Co00008Oooool006Cooooo00?o0000ooooooooool0;OoooolBojO0k0?o
Yl3[2OnW`>`3ojS0jh[ooooo1?l0000Uooooo`00IOooool00ol0003oooooooooo`0]oooooa_oYl3/
Roooool4o`0002Wooooo001Vooooo`;o0000;_ooool2ojO0k0CoYko[4OnW`>b;ooooo`?o0000;Ooo
ool006Sooooo00?o0000ooooooooool0;?ooool6ojNoj`?oYl3/0onW_n/7ojO0k8[ooooo1?l0000`
ooooo`00JOooool00ol0003oooooooooo`0/ooooo`?oYko[1?nX_n/5ojNoj`?oYl3/ROooool4o`00
03Cooooo001Zooooo`03o`000?oooooooooo02cooooo1onX_n/2ojNojh[ooooo1?l0000hooooo`00
Joooool2o`0002gooooo1OnX_n^9ooooo`Co0000??ooool006gooooo00?o0000ooooooooool0:ooo
ool00onX_n_oooooooooo`27ooooo`?o0000@?ooool006kooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`23ooooo`Co0000@oooool006oooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`1oooooo`Co0000Aoooool0073ooooo0_l0000Yooooo`03o`000?oooooooooo07_o
oooo1?l0001;ooooo`00L_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo07Oooooo
1?l0001?ooooo`00Loooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo07Cooooo0ol0
001Cooooo`00M?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo073ooooo1?l0001F
ooooo`00MOooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo06cooooo1?l0001Joooo
o`00M_ooool2o`0002?ooooo00?o0000ooooooooool0J?ooool4o`0005kooooo001hooooo`03o`00
0?oooooooooo023ooooo00?o0000ooooooooool0I?ooool4o`0006;ooooo001iooooo`03o`000?oo
oooooooo01oooooo00?o0000ooooooooool0HOooool3o`0006Kooooo001jooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool0GOooool4o`0006Wooooo001kooooo`;o00007_ooool00ol0
003oooooooooo`1Iooooo`Co0000KOooool007gooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`1Eooooo`Co0000LOooool007kooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`1Aooooo`Co0000MOooool007oooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`1>ooooo`?o0000NOooool0083ooooo0_l0000Iooooo`03o`000?oooooooooo04[ooooo1?l0001l
ooooo`00P_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04Kooooo1?l00020oooo
o`00Poooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04;ooooo1?l00024ooooo`00
Q?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo03kooooo1?l00028ooooo`00QOoo
ool2o`0001?ooooo00?o0000ooooooooool0??ooool3o`0008cooooo0027ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool0>?ooool4o`0008oooooo0028ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0=?ooool4o`0009?ooooo0029ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool0<?ooool4o`0009Oooooo002:ooooo`;o00003_ooool00ol0003ooooo
ooooo`0/ooooo`Co0000Voooool008cooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0Yooooo`?o0000Woooool008gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0U
ooooo`Co0000X_ooool008kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Qoooo
o`Co0000Y_ooool008oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Mooooo`Co
0000Z_ooool0093ooooo0_l00008ooooo`03o`000?oooooooooo01Wooooo1?l0002^ooooo`00T_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Kooooo0ol0002booooo`00Toooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo01;ooooo1?l0002eooooo`00U?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00kooooo1?l0002iooooo`00UOooool2o`0000?o
oooo00?o0000ooooooooool02_ooool4o`000;gooooo002Gooooo`04o`000?ooooooooooo`0000So
oooo1?l00031ooooo`00V?ooool00ol0003oooooo`000005ooooo`?o0000aOooool009Wooooo0_l0
00000ooooooo0000o`000002o`000<Sooooo002Jooooo`;o0000c?ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0538698, 0.0432538, \
0.0035044, 0.0035044}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[.12586 .2075 -12 -8.99448 ]
[.12586 .2075 0 .00552 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.56094 .0364 -5.16972 -9 ]
[.56094 .0364 .83028 0 ]
[.75679 .08071 0 -6.17777 ]
[.75679 .08071 12 2.82223 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.9429 .3657 0 -5.9083 ]
[.9429 .3657 6 3.0917 ]
[.02494 .25992 -18 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.01611 .31527 -18 -2.78472 ]
[.01611 .31527 0 6.21528 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00254 .43215 -12 -2.88407 ]
[-0.00254 .43215 0 6.11593 ]
[-0.0124 .49393 -12 -2.93688 ]
[-0.0124 .49393 0 6.06312 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
[(-2)] .12586 .2075 1 .99877 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.56863 .04703 m
.57247 .05235 L
s
[(2)] .56094 .0364 .72324 1 Mshowa
.125 Mabswid
.18558 .19702 m
.18832 .19985 L
s
.23703 .17687 m
.23971 .17975 L
s
.28951 .15632 m
.29214 .15925 L
s
.39772 .11395 m
.40023 .11699 L
s
.4535 .09211 m
.45595 .0952 L
s
.51046 .06981 m
.51284 .07294 L
s
.08568 .23614 m
.08851 .23887 L
s
.62804 .02377 m
.63027 .02701 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.7445 .0853 m
.73835 .08759 L
s
[(-2)] .75679 .08071 -1 .37284 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.93037 .36962 m
.92411 .37158 L
s
[(2)] .9429 .3657 -1 .31296 Mshowa
.125 Mabswid
.7708 .12553 m
.7671 .12688 L
s
.79613 .16428 m
.79242 .1656 L
s
.82054 .20161 m
.81682 .20291 L
s
.86679 .27235 m
.86305 .2736 L
s
.88871 .30589 m
.88497 .30711 L
s
.9099 .3383 m
.90615 .3395 L
s
.71716 .04348 m
.71349 .04489 L
s
.95018 .39992 m
.94642 .40107 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(-20)] .02494 .25992 1 -0.39157 Mshowa
.02837 .31059 m
.0345 .30825 L
s
[(-10)] .01611 .31527 1 -0.38117 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.00981 .42772 m
.01599 .4255 L
s
[(10)] -0.00254 .43215 1 -0.3591 Mshowa
0 .48963 m
.0062 .48748 L
s
[(20)] -0.0124 .49393 1 -0.34736 Mshowa
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.658 .75 .918 r
.39362 .69476 .40169 .70189 .4152 .698 .40717 .69086 Mtetra
.654 .749 .92 r
.40717 .69086 .4152 .698 .42878 .69411 .42079 .68706 Mtetra
.652 .752 .923 r
.42079 .68706 .42878 .69411 .44242 .69032 .43448 .68329 Mtetra
.655 .755 .923 r
.43448 .68329 .44242 .69032 .45614 .68656 .44824 .67941 Mtetra
.657 .753 .92 r
.44824 .67941 .45614 .68656 .46992 .68271 .46207 .67544 Mtetra
.659 .751 .918 r
.46207 .67544 .46992 .68271 .48378 .67878 .47597 .6714 Mtetra
.659 .749 .917 r
.47597 .6714 .48378 .67878 .4977 .67478 .48994 .66734 Mtetra
.655 .748 .918 r
.48994 .66734 .4977 .67478 .5117 .67074 .50398 .66339 Mtetra
.653 .75 .921 r
.50398 .66339 .5117 .67074 .52577 .66671 .5181 .6595 Mtetra
.652 .755 .925 r
.5181 .6595 .52577 .66671 .53991 .66279 .53229 .65557 Mtetra
.654 .756 .925 r
.53229 .65557 .53991 .66279 .55412 .65888 .54655 .65156 Mtetra
.655 .755 .923 r
.54655 .65156 .55412 .65888 .56841 .65493 .56088 .64749 Mtetra
.656 .753 .921 r
.56088 .64749 .56841 .65493 .58277 .65092 .5753 .64338 Mtetra
.658 .751 .919 r
.5753 .64338 .58277 .65092 .59721 .64687 .58978 .6392 Mtetra
.658 .749 .917 r
.58978 .6392 .59721 .64687 .61172 .64277 .60434 .63499 Mtetra
.658 .747 .916 r
.60434 .63499 .61172 .64277 .62631 .63865 .61898 .63077 Mtetra
.657 .746 .915 r
.61898 .63077 .62631 .63865 .64097 .6345 .63369 .62655 Mtetra
.657 .745 .915 r
.63369 .62655 .64097 .6345 .65571 .63034 .64848 .62233 Mtetra
.657 .744 .915 r
.64848 .62233 .65571 .63034 .67053 .62615 .66335 .6181 Mtetra
.656 .744 .915 r
.66335 .6181 .67053 .62615 .68542 .62195 .6783 .61386 Mtetra
.6783 .61386 .68542 .62195 .7004 .61774 .69333 .60961 Mtetra
.69333 .60961 .7004 .61774 .71546 .6135 .70844 .60535 Mtetra
.655 .744 .915 r
.70844 .60535 .71546 .6135 .73059 .60925 .72363 .60108 Mtetra
.655 .745 .916 r
.72363 .60108 .73059 .60925 .74581 .60497 .7389 .59681 Mtetra
.654 .746 .917 r
.7389 .59681 .74581 .60497 .7611 .60066 .75426 .59254 Mtetra
.654 .748 .919 r
.75426 .59254 .7611 .60066 .77648 .59632 .7697 .58823 Mtetra
.655 .751 .92 r
.7697 .58823 .77648 .59632 .79194 .59192 .78523 .58385 Mtetra
.656 .753 .921 r
.78523 .58385 .79194 .59192 .80748 .58745 .80083 .57943 Mtetra
.656 .755 .923 r
.80083 .57943 .80748 .58745 .8231 .58295 .81652 .57495 Mtetra
.658 .758 .923 r
.81652 .57495 .8231 .58295 .8388 .57845 .83228 .57037 Mtetra
.658 .757 .923 r
.83228 .57037 .8388 .57845 .85461 .57406 .84813 .56576 Mtetra
.657 .751 .92 r
.84813 .56576 .85461 .57406 .8705 .56968 .86408 .5612 Mtetra
.654 .747 .918 r
.86408 .5612 .8705 .56968 .88648 .56525 .88012 .55675 Mtetra
.653 .747 .919 r
.88012 .55675 .88648 .56525 .90254 .56075 .89625 .55228 Mtetra
.655 .75 .92 r
.89625 .55228 .90254 .56075 .91869 .55616 .91247 .54772 Mtetra
.656 .752 .921 r
.91247 .54772 .91869 .55616 .93491 .55147 .92877 .54308 Mtetra
.658 .756 .922 r
.92877 .54308 .93491 .55147 .95123 .54681 .94515 .53831 Mtetra
.657 .754 .921 r
.94515 .53831 .95123 .54681 .96765 .54224 .96162 .53356 Mtetra
.654 .749 .919 r
.96162 .53356 .96765 .54224 .98417 .53767 .97821 .52893 Mtetra
.654 .749 .92 r
.38547 .68759 .39362 .69476 .40717 .69086 .39906 .68378 Mtetra
.652 .752 .923 r
.39906 .68378 .40717 .69086 .42079 .68706 .41272 .68 Mtetra
.655 .754 .923 r
.41272 .68 .42079 .68706 .43448 .68329 .42646 .67609 Mtetra
.657 .752 .92 r
.42646 .67609 .43448 .68329 .44824 .67941 .44026 .67209 Mtetra
.659 .751 .918 r
.44026 .67209 .44824 .67941 .46207 .67544 .45414 .66801 Mtetra
.658 .748 .917 r
.45414 .66801 .46207 .67544 .47597 .6714 .46809 .66395 Mtetra
.653 .748 .919 r
.46809 .66395 .47597 .6714 .48994 .66734 .4821 .66006 Mtetra
.652 .753 .924 r
.4821 .66006 .48994 .66734 .50398 .66339 .49619 .65617 Mtetra
.654 .756 .925 r
.49619 .65617 .50398 .66339 .5181 .6595 .51035 .65218 Mtetra
.656 .755 .923 r
.51035 .65218 .5181 .6595 .53229 .65557 .52459 .64811 Mtetra
.657 .752 .92 r
.52459 .64811 .53229 .65557 .54655 .65156 .5389 .64398 Mtetra
.659 .751 .918 r
.5389 .64398 .54655 .65156 .56088 .64749 .55328 .63975 Mtetra
.659 .748 .916 r
.55328 .63975 .56088 .64749 .5753 .64338 .56774 .63552 Mtetra
.658 .745 .914 r
.56774 .63552 .5753 .64338 .58978 .6392 .58228 .6313 Mtetra
.656 .745 .915 r
.58228 .6313 .58978 .6392 .60434 .63499 .59689 .62713 Mtetra
.655 .746 .917 r
.59689 .62713 .60434 .63499 .61898 .63077 .61158 .62299 Mtetra
.655 .749 .92 r
.61158 .62299 .61898 .63077 .63369 .62655 .62635 .61882 Mtetra
.655 .752 .921 r
.62635 .61882 .63369 .62655 .64848 .62233 .64119 .61462 Mtetra
.655 .754 .922 r
.64119 .61462 .64848 .62233 .66335 .6181 .65612 .61038 Mtetra
.655 .755 .923 r
.65612 .61038 .66335 .6181 .6783 .61386 .67112 .6061 Mtetra
.656 .755 .923 r
.67112 .6061 .6783 .61386 .69333 .60961 .6862 .60177 Mtetra
.657 .754 .922 r
.6862 .60177 .69333 .60961 .70844 .60535 .70137 .59741 Mtetra
.657 .753 .92 r
.70137 .59741 .70844 .60535 .72363 .60108 .71661 .59301 Mtetra
.657 .75 .919 r
.71661 .59301 .72363 .60108 .7389 .59681 .73193 .58858 Mtetra
.656 .747 .917 r
.73193 .58858 .7389 .59681 .75426 .59254 .74734 .58417 Mtetra
.654 .744 .916 r
.74734 .58417 .75426 .59254 .7697 .58823 .76284 .57982 Mtetra
.76284 .57982 .7697 .58823 .78523 .58385 .77843 .57549 Mtetra
.653 .746 .918 r
.77843 .57549 .78523 .58385 .80083 .57943 .7941 .57114 Mtetra
.655 .75 .92 r
.7941 .57114 .80083 .57943 .81652 .57495 .80986 .5667 Mtetra
.656 .752 .921 r
.80986 .5667 .81652 .57495 .83228 .57037 .82569 .56218 Mtetra
.657 .755 .922 r
.82569 .56218 .83228 .57037 .84813 .56576 .84161 .55758 Mtetra
.659 .758 .923 r
.84161 .55758 .84813 .56576 .86408 .5612 .85761 .55287 Mtetra
.658 .755 .921 r
.85761 .55287 .86408 .5612 .88012 .55675 .8737 .54817 Mtetra
.654 .748 .919 r
.8737 .54817 .88012 .55675 .89625 .55228 .88989 .54363 Mtetra
.653 .747 .918 r
.88989 .54363 .89625 .55228 .91247 .54772 .90618 .53911 Mtetra
.654 .749 .92 r
.90618 .53911 .91247 .54772 .92877 .54308 .92256 .53449 Mtetra
.656 .752 .92 r
.92256 .53449 .92877 .54308 .94515 .53831 .93902 .52979 Mtetra
.659 .756 .922 r
.93902 .52979 .94515 .53831 .96162 .53356 .95555 .52494 Mtetra
.657 .754 .921 r
.95555 .52494 .96162 .53356 .97821 .52893 .97219 .52011 Mtetra
.652 .752 .923 r
.37724 .68047 .38547 .68759 .39906 .68378 .39088 .67668 Mtetra
.655 .754 .923 r
.39088 .67668 .39906 .68378 .41272 .68 .40458 .67275 Mtetra
.658 .752 .92 r
.40458 .67275 .41272 .68 .42646 .67609 .41836 .66873 Mtetra
.66 .751 .917 r
.41836 .66873 .42646 .67609 .44026 .67209 .43222 .66463 Mtetra
.657 .748 .917 r
.43222 .66463 .44026 .67209 .45414 .66801 .44614 .66059 Mtetra
.652 .749 .921 r
.44614 .66059 .45414 .66801 .46809 .66395 .46012 .6567 Mtetra
.652 .754 .925 r
.46012 .6567 .46809 .66395 .4821 .66006 .47419 .65279 Mtetra
.655 .756 .924 r
.47419 .65279 .4821 .66006 .49619 .65617 .48832 .64875 Mtetra
.657 .753 .921 r
.48832 .64875 .49619 .65617 .51035 .65218 .50253 .64463 Mtetra
.66 .752 .918 r
.50253 .64463 .51035 .65218 .52459 .64811 .51682 .64038 Mtetra
.66 .748 .915 r
.51682 .64038 .52459 .64811 .5389 .64398 .53118 .63613 Mtetra
.658 .745 .915 r
.53118 .63613 .5389 .64398 .55328 .63975 .54561 .63193 Mtetra
.654 .746 .918 r
.54561 .63193 .55328 .63975 .56774 .63552 .56012 .62786 Mtetra
.653 .751 .922 r
.56012 .62786 .56774 .63552 .58228 .6313 .57471 .62378 Mtetra
.652 .756 .925 r
.57471 .62378 .58228 .6313 .59689 .62713 .58937 .61967 Mtetra
.653 .759 .927 r
.58937 .61967 .59689 .62713 .61158 .62299 .60412 .61551 Mtetra
.654 .759 .927 r
.60412 .61551 .61158 .62299 .62635 .61882 .61894 .61127 Mtetra
.655 .759 .926 r
.61894 .61127 .62635 .61882 .64119 .61462 .63384 .607 Mtetra
.655 .758 .925 r
.63384 .607 .64119 .61462 .65612 .61038 .64882 .6027 Mtetra
.64882 .6027 .65612 .61038 .67112 .6061 .66388 .59838 Mtetra
.66388 .59838 .67112 .6061 .6862 .60177 .67902 .59402 Mtetra
.67902 .59402 .6862 .60177 .70137 .59741 .69424 .58964 Mtetra
.655 .759 .926 r
.69424 .58964 .70137 .59741 .71661 .59301 .70954 .58523 Mtetra
.657 .76 .926 r
.70954 .58523 .71661 .59301 .73193 .58858 .72492 .58074 Mtetra
.658 .76 .925 r
.72492 .58074 .73193 .58858 .74734 .58417 .74039 .57619 Mtetra
.658 .758 .923 r
.74039 .57619 .74734 .58417 .76284 .57982 .75593 .57161 Mtetra
.658 .753 .92 r
.75593 .57161 .76284 .57982 .77843 .57549 .77156 .56702 Mtetra
.655 .746 .917 r
.77156 .56702 .77843 .57549 .7941 .57114 .78729 .56256 Mtetra
.653 .744 .916 r
.78729 .56256 .7941 .57114 .80986 .5667 .80311 .55816 Mtetra
.652 .746 .918 r
.80311 .55816 .80986 .5667 .82569 .56218 .81902 .55374 Mtetra
.655 .75 .92 r
.81902 .55374 .82569 .56218 .84161 .55758 .83501 .54918 Mtetra
.656 .753 .921 r
.83501 .54918 .84161 .55758 .85761 .55287 .85108 .54454 Mtetra
.659 .757 .923 r
.85108 .54454 .85761 .55287 .8737 .54817 .86723 .53977 Mtetra
.659 .757 .922 r
.86723 .53977 .8737 .54817 .88989 .54363 .88347 .53497 Mtetra
.655 .749 .919 r
.88347 .53497 .88989 .54363 .90618 .53911 .89982 .53032 Mtetra
.653 .747 .919 r
.89982 .53032 .90618 .53911 .92256 .53449 .91627 .52573 Mtetra
.654 .749 .919 r
.91627 .52573 .92256 .53449 .93902 .52979 .9328 .52105 Mtetra
.656 .752 .92 r
.9328 .52105 .93902 .52979 .95555 .52494 .94942 .51627 Mtetra
.659 .756 .922 r
.94942 .51627 .95555 .52494 .97219 .52011 .96612 .51133 Mtetra
.654 .754 .923 r
.36894 .67333 .37724 .68047 .39088 .67668 .38262 .66941 Mtetra
.657 .752 .92 r
.38262 .66941 .39088 .67668 .40458 .67275 .39637 .66538 Mtetra
.66 .751 .918 r
.39637 .66538 .40458 .67275 .41836 .66873 .4102 .66125 Mtetra
.657 .748 .917 r
.4102 .66125 .41836 .66873 .43222 .66463 .42409 .6572 Mtetra
.652 .749 .921 r
.42409 .6572 .43222 .66463 .44614 .66059 .43805 .65331 Mtetra
.652 .754 .925 r
.43805 .65331 .44614 .66059 .46012 .6567 .45209 .64936 Mtetra
.655 .755 .923 r
.45209 .64936 .46012 .6567 .47419 .65279 .4662 .64529 Mtetra
.658 .752 .92 r
.4662 .64529 .47419 .65279 .48832 .64875 .48038 .6411 Mtetra
.661 .75 .916 r
.48038 .6411 .48832 .64875 .50253 .64463 .49464 .6368 Mtetra
.659 .746 .914 r
.49464 .6368 .50253 .64463 .51682 .64038 .50897 .63256 Mtetra
.653 .745 .918 r
.50897 .63256 .51682 .64038 .53118 .63613 .52338 .62852 Mtetra
.651 .752 .923 r
.52338 .62852 .53118 .63613 .54561 .63193 .53787 .62449 Mtetra
.652 .757 .927 r
.53787 .62449 .54561 .63193 .56012 .62786 .55243 .6204 Mtetra
.654 .759 .926 r
.55243 .6204 .56012 .62786 .57471 .62378 .56707 .61619 Mtetra
.655 .757 .925 r
.56707 .61619 .57471 .62378 .58937 .61967 .58178 .61196 Mtetra
.655 .754 .923 r
.58178 .61196 .58937 .61967 .60412 .61551 .59658 .6077 Mtetra
.655 .753 .922 r
.59658 .6077 .60412 .61551 .61894 .61127 .61145 .60342 Mtetra
.656 .753 .922 r
.61145 .60342 .61894 .61127 .63384 .607 .6264 .59909 Mtetra
.656 .753 .921 r
.6264 .59909 .63384 .607 .64882 .6027 .64144 .59473 Mtetra
.656 .752 .921 r
.64144 .59473 .64882 .6027 .66388 .59838 .65655 .59036 Mtetra
.655 .752 .921 r
.65655 .59036 .66388 .59838 .67902 .59402 .67175 .58599 Mtetra
.656 .753 .921 r
.67175 .58599 .67902 .59402 .69424 .58964 .68703 .58158 Mtetra
.68703 .58158 .69424 .58964 .70954 .58523 .70239 .57712 Mtetra
.70239 .57712 .70954 .58523 .72492 .58074 .71783 .57264 Mtetra
.656 .755 .923 r
.71783 .57264 .72492 .58074 .74039 .57619 .73336 .56814 Mtetra
.656 .757 .924 r
.73336 .56814 .74039 .57619 .75593 .57161 .74897 .5636 Mtetra
.658 .76 .925 r
.74897 .5636 .75593 .57161 .77156 .56702 .76466 .55894 Mtetra
.659 .76 .924 r
.76466 .55894 .77156 .56702 .78729 .56256 .78044 .55422 Mtetra
.659 .754 .92 r
.78044 .55422 .78729 .56256 .80311 .55816 .7963 .54951 Mtetra
.654 .745 .917 r
.7963 .54951 .80311 .55816 .81902 .55374 .81226 .545 Mtetra
.652 .744 .917 r
.81226 .545 .81902 .55374 .83501 .54918 .82833 .54054 Mtetra
.654 .748 .919 r
.82833 .54054 .83501 .54918 .85108 .54454 .84447 .53597 Mtetra
.656 .752 .921 r
.84447 .53597 .85108 .54454 .86723 .53977 .8607 .53128 Mtetra
.658 .756 .922 r
.8607 .53128 .86723 .53977 .88347 .53497 .87701 .52644 Mtetra
.659 .757 .922 r
.87701 .52644 .88347 .53497 .89982 .53032 .8934 .52155 Mtetra
.655 .75 .92 r
.8934 .52155 .89982 .53032 .91627 .52573 .90991 .51682 Mtetra
.653 .747 .919 r
.90991 .51682 .91627 .52573 .9328 .52105 .92652 .51216 Mtetra
.654 .749 .92 r
.92652 .51216 .9328 .52105 .94942 .51627 .94322 .5074 Mtetra
.657 .752 .92 r
.94322 .5074 .94942 .51627 .96612 .51133 .96 .50251 Mtetra
.657 .753 .92 r
.36055 .66605 .36894 .67333 .38262 .66941 .37428 .66201 Mtetra
.66 .751 .918 r
.37428 .66201 .38262 .66941 .39637 .66538 .38808 .65787 Mtetra
.658 .749 .917 r
.38808 .65787 .39637 .66538 .4102 .66125 .40195 .65377 Mtetra
.651 .749 .921 r
.40195 .65377 .4102 .66125 .42409 .6572 .41588 .64987 Mtetra
.652 .754 .925 r
.41588 .64987 .42409 .6572 .43805 .65331 .42989 .64592 Mtetra
.656 .754 .923 r
.42989 .64592 .43805 .65331 .45209 .64936 .44397 .64182 Mtetra
.66 .752 .919 r
.44397 .64182 .45209 .64936 .4662 .64529 .45813 .63756 Mtetra
.661 .749 .915 r
.45813 .63756 .4662 .64529 .48038 .6411 .47237 .63325 Mtetra
.656 .746 .916 r
.47237 .63325 .48038 .6411 .49464 .6368 .48667 .62909 Mtetra
.651 .749 .921 r
.48667 .62909 .49464 .6368 .50897 .63256 .50105 .62509 Mtetra
.651 .756 .927 r
.50105 .62509 .50897 .63256 .52338 .62852 .51551 .62105 Mtetra
.654 .758 .926 r
.51551 .62105 .52338 .62852 .53787 .62449 .53004 .61685 Mtetra
.655 .755 .924 r
.53004 .61685 .53787 .62449 .55243 .6204 .54466 .61263 Mtetra
.656 .753 .921 r
.54466 .61263 .55243 .6204 .56707 .61619 .55935 .60835 Mtetra
.658 .753 .92 r
.55935 .60835 .56707 .61619 .58178 .61196 .57411 .60397 Mtetra
.656 .749 .919 r
.57411 .60397 .58178 .61196 .59658 .6077 .58896 .59966 Mtetra
.654 .749 .919 r
.58896 .59966 .59658 .6077 .61145 .60342 .60389 .59539 Mtetra
.653 .75 .921 r
.60389 .59539 .61145 .60342 .6264 .59909 .6189 .59112 Mtetra
.654 .753 .922 r
.6189 .59112 .6264 .59909 .64144 .59473 .63399 .5868 Mtetra
.655 .755 .923 r
.63399 .5868 .64144 .59473 .65655 .59036 .64916 .58239 Mtetra
.657 .756 .923 r
.64916 .58239 .65655 .59036 .67175 .58599 .66441 .57789 Mtetra
.658 .754 .921 r
.66441 .57789 .67175 .58599 .68703 .58158 .67974 .57333 Mtetra
.658 .751 .919 r
.67974 .57333 .68703 .58158 .70239 .57712 .69515 .56877 Mtetra
.656 .749 .918 r
.69515 .56877 .70239 .57712 .71783 .57264 .71066 .56426 Mtetra
.654 .749 .92 r
.71066 .56426 .71783 .57264 .73336 .56814 .72625 .55981 Mtetra
.655 .752 .921 r
.72625 .55981 .73336 .56814 .74897 .5636 .74192 .55526 Mtetra
.656 .753 .921 r
.74192 .55526 .74897 .5636 .76466 .55894 .75768 .55065 Mtetra
.656 .756 .923 r
.75768 .55065 .76466 .55894 .78044 .55422 .77353 .54601 Mtetra
.659 .76 .924 r
.77353 .54601 .78044 .55422 .7963 .54951 .78945 .54121 Mtetra
.66 .759 .923 r
.78945 .54121 .7963 .54951 .81226 .545 .80545 .53637 Mtetra
.656 .75 .919 r
.80545 .53637 .81226 .545 .82833 .54054 .82156 .53167 Mtetra
.652 .744 .917 r
.82156 .53167 .82833 .54054 .84447 .53597 .83778 .52715 Mtetra
.653 .746 .919 r
.83778 .52715 .84447 .53597 .8607 .53128 .85409 .52255 Mtetra
.656 .751 .92 r
.85409 .52255 .8607 .53128 .87701 .52644 .87047 .51779 Mtetra
.659 .756 .922 r
.87047 .51779 .87701 .52644 .8934 .52155 .88694 .51287 Mtetra
.659 .757 .922 r
.88694 .51287 .8934 .52155 .90991 .51682 .90349 .50789 Mtetra
.654 .75 .92 r
.90349 .50789 .90991 .51682 .92652 .51216 .92016 .50311 Mtetra
.653 .747 .919 r
.92016 .50311 .92652 .51216 .94322 .5074 .93694 .49838 Mtetra
.655 .75 .92 r
.93694 .49838 .94322 .5074 .96 .50251 .9538 .49352 Mtetra
.659 .752 .918 r
.35209 .65864 .36055 .66605 .37428 .66201 .36587 .65449 Mtetra
.659 .75 .917 r
.36587 .65449 .37428 .66201 .38808 .65787 .37971 .65033 Mtetra
.652 .748 .921 r
.37971 .65033 .38808 .65787 .40195 .65377 .39361 .64641 Mtetra
.652 .754 .924 r
.39361 .64641 .40195 .65377 .41588 .64987 .40759 .64245 Mtetra
.656 .754 .922 r
.40759 .64245 .41588 .64987 .42989 .64592 .42165 .63833 Mtetra
.66 .752 .918 r
.42165 .63833 .42989 .64592 .44397 .64182 .43578 .63405 Mtetra
.661 .749 .915 r
.43578 .63405 .44397 .64182 .45813 .63756 .44999 .6297 Mtetra
.654 .746 .917 r
.44999 .6297 .45813 .63756 .47237 .63325 .46427 .6256 Mtetra
.65 .751 .924 r
.46427 .6256 .47237 .63325 .48667 .62909 .47862 .62162 Mtetra
.652 .757 .927 r
.47862 .62162 .48667 .62909 .50105 .62509 .49305 .61749 Mtetra
.654 .756 .924 r
.49305 .61749 .50105 .62509 .51551 .62105 .50756 .61328 Mtetra
.656 .753 .921 r
.50756 .61328 .51551 .62105 .53004 .61685 .52214 .60898 Mtetra
.658 .752 .919 r
.52214 .60898 .53004 .61685 .54466 .61263 .53681 .60463 Mtetra
.651 .747 .92 r
.53681 .60463 .54466 .61263 .55935 .60835 .55155 .60049 Mtetra
.641 .749 .927 r
.55155 .60049 .55935 .60835 .57411 .60397 .56638 .59666 Mtetra
.627 .761 .943 r
.56638 .59666 .57411 .60397 .58896 .59966 .58129 .59316 Mtetra
.623 .784 .959 r
.58129 .59316 .58896 .59966 .60389 .59539 .5963 .58957 Mtetra
.622 .805 .97 r
.5963 .58957 .60389 .59539 .6189 .59112 .61138 .58575 Mtetra
.626 .821 .975 r
.61138 .58575 .6189 .59112 .63399 .5868 .62655 .58163 Mtetra
.634 .831 .976 r
.62655 .58163 .63399 .5868 .64916 .58239 .64179 .57718 Mtetra
.646 .835 .973 r
.64179 .57718 .64916 .58239 .66441 .57789 .6571 .57239 Mtetra
.659 .831 .966 r
.6571 .57239 .66441 .57789 .67974 .57333 .67248 .5673 Mtetra
.669 .819 .955 r
.67248 .5673 .67974 .57333 .69515 .56877 .68793 .56198 Mtetra
.675 .8 .941 r
.68793 .56198 .69515 .56877 .71066 .56426 .70345 .55656 Mtetra
.668 .773 .929 r
.70345 .55656 .71066 .56426 .72625 .55981 .71907 .55147 Mtetra
.66 .755 .92 r
.71907 .55147 .72625 .55981 .74192 .55526 .73479 .54668 Mtetra
.654 .748 .919 r
.73479 .54668 .74192 .55526 .75768 .55065 .75062 .54212 Mtetra
.655 .751 .92 r
.75062 .54212 .75768 .55065 .77353 .54601 .76653 .53749 Mtetra
.656 .753 .921 r
.76653 .53749 .77353 .54601 .78945 .54121 .78252 .53278 Mtetra
.658 .757 .923 r
.78252 .53278 .78945 .54121 .80545 .53637 .7986 .52797 Mtetra
.661 .76 .924 r
.7986 .52797 .80545 .53637 .82156 .53167 .81476 .52301 Mtetra
.658 .754 .921 r
.81476 .52301 .82156 .53167 .83778 .52715 .83102 .51817 Mtetra
.651 .744 .918 r
.83102 .51817 .83778 .52715 .85409 .52255 .84739 .51357 Mtetra
.652 .746 .919 r
.84739 .51357 .85409 .52255 .87047 .51779 .86386 .50891 Mtetra
.656 .751 .92 r
.86386 .50891 .87047 .51779 .88694 .51287 .8804 .50407 Mtetra
.659 .756 .921 r
.8804 .50407 .88694 .51287 .90349 .50789 .89703 .49906 Mtetra
.659 .756 .922 r
.89703 .49906 .90349 .50789 .92016 .50311 .91374 .49401 Mtetra
.653 .748 .92 r
.91374 .49401 .92016 .50311 .93694 .49838 .93058 .4892 Mtetra
.653 .747 .919 r
.93058 .4892 .93694 .49838 .9538 .49352 .94753 .48437 Mtetra
.66 .75 .917 r
.34355 .65111 .35209 .65864 .36587 .65449 .35737 .6469 Mtetra
.653 .748 .92 r
.35737 .6469 .36587 .65449 .37971 .65033 .37125 .6429 Mtetra
.651 .753 .924 r
.37125 .6429 .37971 .65033 .39361 .64641 .3852 .63896 Mtetra
.655 .754 .923 r
.3852 .63896 .39361 .64641 .40759 .64245 .39923 .63484 Mtetra
.66 .753 .919 r
.39923 .63484 .40759 .64245 .42165 .63833 .41334 .63055 Mtetra
.662 .749 .915 r
.41334 .63055 .42165 .63833 .43578 .63405 .42752 .62617 Mtetra
.653 .746 .918 r
.42752 .62617 .43578 .63405 .44999 .6297 .44177 .62207 Mtetra
.649 .752 .925 r
.44177 .62207 .44999 .6297 .46427 .6256 .45609 .61808 Mtetra
.653 .757 .926 r
.45609 .61808 .46427 .6256 .47862 .62162 .47049 .61391 Mtetra
.654 .754 .923 r
.47049 .61391 .47862 .62162 .49305 .61749 .48497 .60969 Mtetra
.659 .754 .92 r
.48497 .60969 .49305 .61749 .50756 .61328 .49953 .60529 Mtetra
.651 .748 .92 r
.49953 .60529 .50756 .61328 .52214 .60898 .51417 .60116 Mtetra
.629 .746 .932 r
.51417 .60116 .52214 .60898 .53681 .60463 .52888 .59773 Mtetra
.6 .763 .957 r
.52888 .59773 .53681 .60463 .55155 .60049 .54369 .59491 Mtetra
.577 .796 .983 r
.54369 .59491 .55155 .60049 .56638 .59666 .55859 .59214 Mtetra
.556 .823 .996 r
.55859 .59214 .56638 .59666 .58129 .59316 .57358 .58924 Mtetra
.539 .836 .999 r
.57358 .58924 .58129 .59316 .5963 .58957 .58867 .58625 Mtetra
.542 .856 .997 r
.58867 .58625 .5963 .58957 .61138 .58575 .60384 .58279 Mtetra
.554 .872 .994 r
.60384 .58279 .61138 .58575 .62655 .58163 .61908 .5788 Mtetra
.574 .884 .991 r
.61908 .5788 .62655 .58163 .64179 .57718 .63441 .57431 Mtetra
.6 .893 .989 r
.63441 .57431 .64179 .57718 .6571 .57239 .64979 .56932 Mtetra
.629 .897 .986 r
.64979 .56932 .6571 .57239 .67248 .5673 .66524 .5638 Mtetra
.658 .895 .981 r
.66524 .5638 .67248 .5673 .68793 .56198 .68074 .55779 Mtetra
.673 .879 .975 r
.68074 .55779 .68793 .56198 .70345 .55656 .69631 .55168 Mtetra
.685 .863 .967 r
.69631 .55168 .70345 .55656 .71907 .55147 .71195 .54543 Mtetra
.69 .831 .95 r
.71195 .54543 .71907 .55147 .73479 .54668 .72766 .53922 Mtetra
.678 .788 .933 r
.72766 .53922 .73479 .54668 .75062 .54212 .74349 .53362 Mtetra
.66 .756 .921 r
.74349 .53362 .75062 .54212 .76653 .53749 .75945 .52873 Mtetra
.653 .748 .919 r
.75945 .52873 .76653 .53749 .78252 .53278 .77552 .52412 Mtetra
.657 .753 .921 r
.77552 .52412 .78252 .53278 .7986 .52797 .79166 .51932 Mtetra
.657 .755 .922 r
.79166 .51932 .7986 .52797 .81476 .52301 .8079 .51446 Mtetra
.661 .76 .923 r
.8079 .51446 .81476 .52301 .83102 .51817 .82421 .50941 Mtetra
.658 .755 .921 r
.82421 .50941 .83102 .51817 .84739 .51357 .84062 .50447 Mtetra
.651 .745 .918 r
.84062 .50447 .84739 .51357 .86386 .50891 .85716 .49981 Mtetra
.652 .747 .919 r
.85716 .49981 .86386 .50891 .8804 .50407 .87379 .49507 Mtetra
.656 .752 .92 r
.87379 .49507 .8804 .50407 .89703 .49906 .89049 .49013 Mtetra
.66 .756 .921 r
.89049 .49013 .89703 .49906 .91374 .49401 .90728 .48501 Mtetra
.658 .755 .922 r
.90728 .48501 .91374 .49401 .93058 .4892 .92417 .47993 Mtetra
.652 .748 .92 r
.92417 .47993 .93058 .4892 .94753 .48437 .94118 .47507 Mtetra
.656 .749 .918 r
.33493 .64349 .34355 .65111 .35737 .6469 .34879 .63937 Mtetra
.65 .751 .923 r
.34879 .63937 .35737 .6469 .37125 .6429 .36271 .63542 Mtetra
.654 .754 .924 r
.36271 .63542 .37125 .6429 .3852 .63896 .37671 .63133 Mtetra
.659 .753 .92 r
.37671 .63133 .3852 .63896 .39923 .63484 .39079 .62706 Mtetra
.662 .751 .916 r
.39079 .62706 .39923 .63484 .41334 .63055 .40494 .62264 Mtetra
.655 .747 .917 r
.40494 .62264 .41334 .63055 .42752 .62617 .41917 .61848 Mtetra
.648 .751 .925 r
.41917 .61848 .42752 .62617 .44177 .62207 .43346 .6145 Mtetra
.653 .757 .926 r
.43346 .6145 .44177 .62207 .45609 .61808 .44783 .61031 Mtetra
.655 .753 .922 r
.44783 .61031 .45609 .61808 .47049 .61391 .46228 .60606 Mtetra
.659 .753 .92 r
.46228 .60606 .47049 .61391 .48497 .60969 .47682 .60165 Mtetra
.642 .745 .924 r
.47682 .60165 .48497 .60969 .49953 .60529 .49142 .59782 Mtetra
.595 .746 .949 r
.49142 .59782 .49953 .60529 .51417 .60116 .5061 .59529 Mtetra
.552 .779 .983 r
.5061 .59529 .51417 .60116 .52888 .59773 .52087 .59317 Mtetra
.497 .799 .999 r
.52087 .59317 .52888 .59773 .54369 .59491 .53574 .59135 Mtetra
.465 .816 .997 r
.53574 .59135 .54369 .59491 .55859 .59214 .55072 .58933 Mtetra
.471 .841 .991 r
.55072 .58933 .55859 .59214 .57358 .58924 .56579 .58662 Mtetra
.505 .861 .99 r
.56579 .58662 .57358 .58924 .58867 .58625 .58094 .58322 Mtetra
.563 .873 .994 r
.58094 .58322 .58867 .58625 .60384 .58279 .59618 .57912 Mtetra
.598 .869 .993 r
.59618 .57912 .60384 .58279 .61908 .5788 .61149 .5747 Mtetra
.612 .861 .99 r
.61149 .5747 .61908 .5788 .63441 .57431 .62689 .57017 Mtetra
.616 .862 .99 r
.62689 .57017 .63441 .57431 .64979 .56932 .64237 .56553 Mtetra
.619 .875 .99 r
.64237 .56553 .64979 .56932 .66524 .5638 .65792 .56057 Mtetra
.634 .897 .986 r
.65792 .56057 .66524 .5638 .68074 .55779 .67352 .55491 Mtetra
.653 .913 .979 r
.67352 .55491 .68074 .55779 .69631 .55168 .68917 .54853 Mtetra
.685 .916 .972 r
.68917 .54853 .69631 .55168 .71195 .54543 .70486 .54144 Mtetra
.705 .898 .966 r
.70486 .54144 .71195 .54543 .72766 .53922 .7206 .53413 Mtetra
.705 .866 .958 r
.7206 .53413 .72766 .53922 .74349 .53362 .73642 .52711 Mtetra
.7 .825 .942 r
.73642 .52711 .74349 .53362 .75945 .52873 .75233 .5205 Mtetra
.668 .769 .926 r
.75233 .5205 .75945 .52873 .77552 .52412 .76842 .51521 Mtetra
.653 .748 .919 r
.76842 .51521 .77552 .52412 .79166 .51932 .78465 .51051 Mtetra
.657 .753 .921 r
.78465 .51051 .79166 .51932 .8079 .51446 .80095 .50564 Mtetra
.658 .754 .921 r
.80095 .50564 .8079 .51446 .82421 .50941 .81734 .5007 Mtetra
.662 .76 .923 r
.81734 .5007 .82421 .50941 .84062 .50447 .83381 .49555 Mtetra
.657 .754 .921 r
.83381 .49555 .84062 .50447 .85716 .49981 .85039 .49057 Mtetra
.65 .745 .919 r
.85039 .49057 .85716 .49981 .87379 .49507 .86709 .48586 Mtetra
.653 .748 .919 r
.86709 .48586 .87379 .49507 .89049 .49013 .88388 .48099 Mtetra
.657 .753 .92 r
.88388 .48099 .89049 .49013 .90728 .48501 .90075 .47593 Mtetra
.66 .757 .921 r
.90075 .47593 .90728 .48501 .92417 .47993 .91769 .4707 Mtetra
.655 .752 .921 r
.91769 .4707 .92417 .47993 .94118 .47507 .93476 .46565 Mtetra
.651 .749 .921 r
.32623 .63583 .33493 .64349 .34879 .63937 .34012 .63184 Mtetra
.652 .753 .924 r
.34012 .63184 .34879 .63937 .36271 .63542 .35409 .6278 Mtetra
.657 .753 .921 r
.35409 .6278 .36271 .63542 .37671 .63133 .36814 .62358 Mtetra
.662 .752 .917 r
.36814 .62358 .37671 .63133 .39079 .62706 .38227 .61913 Mtetra
.657 .747 .916 r
.38227 .61913 .39079 .62706 .40494 .62264 .39646 .61485 Mtetra
.648 .75 .923 r
.39646 .61485 .40494 .62264 .41917 .61848 .41073 .61085 Mtetra
.652 .756 .926 r
.41073 .61085 .41917 .61848 .43346 .6145 .42507 .60668 Mtetra
.654 .753 .922 r
.42507 .60668 .43346 .6145 .44783 .61031 .43949 .60242 Mtetra
.658 .753 .92 r
.43949 .60242 .44783 .61031 .46228 .60606 .454 .59801 Mtetra
.631 .742 .928 r
.454 .59801 .46228 .60606 .47682 .60165 .46856 .59451 Mtetra
.57 .747 .961 r
.46856 .59451 .47682 .60165 .49142 .59782 .4832 .59249 Mtetra
.5 .776 .994 r
.4832 .59249 .49142 .59782 .5061 .59529 .49792 .59107 Mtetra
.431 .781 .997 r
.49792 .59107 .5061 .59529 .52087 .59317 .51275 .59001 Mtetra
.439 .816 .992 r
.51275 .59001 .52087 .59317 .53574 .59135 .5277 .58804 Mtetra
.552 .86 .997 r
.5277 .58804 .53574 .59135 .55072 .58933 .54273 .5844 Mtetra
.642 .841 .977 r
.54273 .5844 .55072 .58933 .56579 .58662 .55785 .57965 Mtetra
.671 .791 .938 r
.55785 .57965 .56579 .58662 .58094 .58322 .57304 .57445 Mtetra
.673 .747 .906 r
.57304 .57445 .58094 .58322 .59618 .57912 .5883 .56922 Mtetra
.666 .72 .889 r
.5883 .56922 .59618 .57912 .61149 .5747 .60365 .56423 Mtetra
.656 .706 .884 r
.60365 .56423 .61149 .5747 .62689 .57017 .6191 .55966 Mtetra
.646 .702 .887 r
.6191 .55966 .62689 .57017 .64237 .56553 .63464 .55549 Mtetra
.639 .71 .899 r
.63464 .55549 .64237 .56553 .65792 .56057 .65029 .55157 Mtetra
.637 .735 .919 r
.65029 .55157 .65792 .56057 .67352 .55491 .66603 .54762 Mtetra
.642 .782 .949 r
.66603 .54762 .67352 .55491 .68917 .54853 .68184 .54322 Mtetra
.66 .847 .972 r
.68184 .54322 .68917 .54853 .70486 .54144 .69769 .53769 Mtetra
.696 .904 .97 r
.69769 .53769 .70486 .54144 .7206 .53413 .71352 .53046 Mtetra
.724 .914 .959 r
.71352 .53046 .7206 .53413 .73642 .52711 .72937 .52227 Mtetra
.723 .881 .954 r
.72937 .52227 .73642 .52711 .75233 .5205 .7453 .51444 Mtetra
.712 .845 .946 r
.7453 .51444 .75233 .5205 .76842 .51521 .76133 .50721 Mtetra
.677 .782 .929 r
.76133 .50721 .76842 .51521 .78465 .51051 .77755 .50148 Mtetra
.654 .748 .919 r
.77755 .50148 .78465 .51051 .80095 .50564 .79392 .49668 Mtetra
.657 .753 .921 r
.79392 .49668 .80095 .50564 .81734 .5007 .81039 .49173 Mtetra
.659 .754 .921 r
.81039 .49173 .81734 .5007 .83381 .49555 .82694 .48667 Mtetra
.662 .759 .922 r
.82694 .48667 .83381 .49555 .85039 .49057 .84356 .48143 Mtetra
.655 .751 .921 r
.84356 .48143 .85039 .49057 .86709 .48586 .86032 .47648 Mtetra
.65 .745 .919 r
.86032 .47648 .86709 .48586 .88388 .48099 .87719 .4717 Mtetra
.655 .75 .92 r
.87719 .4717 .88388 .48099 .90075 .47593 .89414 .46668 Mtetra
.659 .754 .92 r
.89414 .46668 .90075 .47593 .91769 .4707 .91116 .46145 Mtetra
.66 .756 .921 r
.91116 .46145 .91769 .4707 .93476 .46565 .92828 .45617 Mtetra
.65 .752 .924 r
.31743 .62822 .32623 .63583 .34012 .63184 .33137 .62423 Mtetra
.655 .754 .923 r
.33137 .62423 .34012 .63184 .35409 .6278 .34538 .62004 Mtetra
.661 .753 .918 r
.34538 .62004 .35409 .6278 .36814 .62358 .35949 .61564 Mtetra
.661 .749 .915 r
.35949 .61564 .36814 .62358 .38227 .61913 .37366 .61119 Mtetra
.649 .747 .921 r
.37366 .61119 .38227 .61913 .39646 .61485 .38789 .60715 Mtetra
.65 .754 .926 r
.38789 .60715 .39646 .61485 .41073 .61085 .4022 .60303 Mtetra
.654 .754 .923 r
.4022 .60303 .41073 .61085 .42507 .60668 .4166 .59876 Mtetra
.659 .753 .92 r
.4166 .59876 .42507 .60668 .43949 .60242 .43108 .59431 Mtetra
.631 .741 .928 r
.43108 .59431 .43949 .60242 .454 .59801 .44561 .59081 Mtetra
.556 .742 .963 r
.44561 .59081 .454 .59801 .46856 .59451 .46019 .5891 Mtetra
.463 .76 .994 r
.46019 .5891 .46856 .59451 .4832 .59249 .47486 .5883 Mtetra
.402 .769 .994 r
.47486 .5883 .4832 .59249 .49792 .59107 .48964 .58759 Mtetra
.493 .831 .998 r
.48964 .58759 .49792 .59107 .51275 .59001 .50455 .58505 Mtetra
.648 .841 .974 r
.50455 .58505 .51275 .59001 .5277 .58804 .51955 .58015 Mtetra
.696 .773 .911 r
.51955 .58015 .5277 .58804 .54273 .5844 .53464 .57401 Mtetra
.71 .723 .86 r
.53464 .57401 .54273 .5844 .55785 .57965 .54978 .56676 Mtetra
.697 .678 .827 r
.54978 .56676 .55785 .57965 .57304 .57445 .56498 .55953 Mtetra
.678 .643 .808 r
.56498 .55953 .57304 .57445 .5883 .56922 .58026 .55302 Mtetra
.66 .621 .799 r
.58026 .55302 .5883 .56922 .60365 .56423 .59562 .54741 Mtetra
.643 .607 .798 r
.59562 .54741 .60365 .56423 .6191 .55966 .61108 .54277 Mtetra
.628 .599 .802 r
.61108 .54277 .6191 .55966 .63464 .55549 .62666 .53911 Mtetra
.612 .598 .812 r
.62666 .53911 .63464 .55549 .65029 .55157 .64237 .53637 Mtetra
.598 .606 .831 r
.64237 .53637 .65029 .55157 .66603 .54762 .65821 .53435 Mtetra
.595 .634 .86 r
.65821 .53435 .66603 .54762 .68184 .54322 .67417 .53238 Mtetra
.616 .689 .895 r
.67417 .53238 .68184 .54322 .69769 .53769 .6902 .5293 Mtetra
.642 .757 .932 r
.6902 .5293 .69769 .53769 .71352 .53046 .70626 .52495 Mtetra
.696 .856 .959 r
.70626 .52495 .71352 .53046 .72937 .52227 .72228 .51819 Mtetra
.738 .908 .952 r
.72228 .51819 .72937 .52227 .7453 .51444 .73825 .50955 Mtetra
.741 .887 .946 r
.73825 .50955 .7453 .51444 .76133 .50721 .75428 .50097 Mtetra
.721 .845 .941 r
.75428 .50097 .76133 .50721 .77755 .50148 .77044 .49332 Mtetra
.677 .781 .929 r
.77044 .49332 .77755 .50148 .79392 .49668 .78681 .48748 Mtetra
.653 .748 .919 r
.78681 .48748 .79392 .49668 .81039 .49173 .80335 .48263 Mtetra
.657 .753 .921 r
.80335 .48263 .81039 .49173 .82694 .48667 .81998 .47758 Mtetra
.66 .756 .921 r
.81998 .47758 .82694 .48667 .84356 .48143 .83668 .47237 Mtetra
.662 .758 .922 r
.83668 .47237 .84356 .48143 .86032 .47648 .85348 .46707 Mtetra
.651 .747 .92 r
.85348 .46707 .86032 .47648 .87719 .4717 .87041 .46219 Mtetra
.652 .746 .919 r
.87041 .46219 .87719 .4717 .89414 .46668 .88745 .45726 Mtetra
.656 .752 .92 r
.88745 .45726 .89414 .46668 .91116 .46145 .90456 .4521 Mtetra
.661 .756 .921 r
.90456 .4521 .91116 .46145 .92828 .45617 .92175 .44672 Mtetra
.652 .753 .924 r
.30855 .62056 .31743 .62822 .33137 .62423 .32253 .61647 Mtetra
.657 .752 .92 r
.32253 .61647 .33137 .62423 .34538 .62004 .3366 .61216 Mtetra
.663 .752 .916 r
.3366 .61216 .34538 .62004 .35949 .61564 .35075 .60763 Mtetra
.654 .748 .918 r
.35075 .60763 .35949 .61564 .37366 .61119 .36496 .6034 Mtetra
.648 .752 .926 r
.36496 .6034 .37366 .61119 .38789 .60715 .37924 .59935 Mtetra
.654 .755 .924 r
.37924 .59935 .38789 .60715 .4022 .60303 .3936 .59507 Mtetra
.658 .753 .92 r
.3936 .59507 .4022 .60303 .4166 .59876 .40805 .5906 Mtetra
.641 .744 .924 r
.40805 .5906 .4166 .59876 .43108 .59431 .42256 .58672 Mtetra
.559 .733 .957 r
.42256 .58672 .43108 .59431 .44561 .59081 .43709 .58504 Mtetra
.454 .746 .991 r
.43709 .58504 .44561 .59081 .46019 .5891 .4517 .58455 Mtetra
.389 .753 .992 r
.4517 .58455 .46019 .5891 .47486 .5883 .46642 .58423 Mtetra
.538 .833 .999 r
.46642 .58423 .47486 .5883 .48964 .58759 .48129 .5813 Mtetra
.687 .812 .942 r
.48129 .5813 .48964 .58759 .50455 .58505 .49628 .57551 Mtetra
.728 .744 .865 r
.49628 .57551 .50455 .58505 .51955 .58015 .51134 .56745 Mtetra
.726 .69 .816 r
.51134 .56745 .51955 .58015 .53464 .57401 .52646 .5583 Mtetra
.702 .644 .789 r
.52646 .5583 .53464 .57401 .54978 .56676 .54163 .54971 Mtetra
.679 .621 .783 r
.54163 .54971 .54978 .56676 .56498 .55953 .55685 .54247 Mtetra
.665 .614 .788 r
.55685 .54247 .56498 .55953 .58026 .55302 .57215 .53628 Mtetra
.654 .613 .796 r
.57215 .53628 .58026 .55302 .59562 .54741 .58754 .53089 Mtetra
.644 .611 .802 r
.58754 .53089 .59562 .54741 .61108 .54277 .60303 .5262 Mtetra
.633 .606 .805 r
.60303 .5262 .61108 .54277 .62666 .53911 .61862 .5222 Mtetra
.618 .596 .805 r
.61862 .5222 .62666 .53911 .64237 .53637 .63433 .519 Mtetra
.599 .582 .805 r
.63433 .519 .64237 .53637 .65821 .53435 .65018 .51689 Mtetra
.574 .568 .809 r
.65018 .51689 .65821 .53435 .67417 .53238 .66621 .51615 Mtetra
.56 .576 .827 r
.66621 .51615 .67417 .53238 .6902 .5293 .6824 .516 Mtetra
.576 .628 .866 r
.6824 .516 .6902 .5293 .70626 .52495 .69867 .51476 Mtetra
.623 .711 .908 r
.69867 .51476 .70626 .52495 .72228 .51819 .71493 .51123 Mtetra
.692 .817 .942 r
.71493 .51123 .72228 .51819 .73825 .50955 .73112 .50476 Mtetra
.753 .894 .942 r
.73112 .50476 .73825 .50955 .75428 .50097 .74722 .49561 Mtetra
.75 .879 .938 r
.74722 .49561 .75428 .50097 .77044 .49332 .76337 .48661 Mtetra
.723 .837 .935 r
.76337 .48661 .77044 .49332 .78681 .48748 .77968 .47881 Mtetra
.668 .769 .925 r
.77968 .47881 .78681 .48748 .80335 .48263 .79623 .47326 Mtetra
.653 .748 .919 r
.79623 .47326 .80335 .48263 .81998 .47758 .81294 .46832 Mtetra
.657 .753 .92 r
.81294 .46832 .81998 .47758 .83668 .47237 .82973 .46319 Mtetra
.663 .758 .921 r
.82973 .46319 .83668 .47237 .85348 .46707 .84659 .45779 Mtetra
.657 .755 .922 r
.84659 .45779 .85348 .46707 .87041 .46219 .86357 .45259 Mtetra
.649 .745 .92 r
.86357 .45259 .87041 .46219 .88745 .45726 .88068 .4477 Mtetra
.654 .75 .92 r
.88068 .4477 .88745 .45726 .90456 .4521 .89788 .44256 Mtetra
.659 .754 .92 r
.89788 .44256 .90456 .4521 .92175 .44672 .91515 .43719 Mtetra
.654 .753 .922 r
.29958 .61283 .30855 .62056 .32253 .61647 .31361 .6086 Mtetra
.661 .753 .918 r
.31361 .6086 .32253 .61647 .3366 .61216 .32773 .60413 Mtetra
.661 .75 .916 r
.32773 .60413 .3366 .61216 .35075 .60763 .34192 .59963 Mtetra
.648 .748 .922 r
.34192 .59963 .35075 .60763 .36496 .6034 .35617 .59556 Mtetra
.651 .754 .925 r
.35617 .59556 .36496 .6034 .37924 .59935 .3705 .59135 Mtetra
.656 .752 .921 r
.3705 .59135 .37924 .59935 .3936 .59507 .38492 .58696 Mtetra
.653 .75 .921 r
.38492 .58696 .3936 .59507 .40805 .5906 .3994 .58266 Mtetra
.585 .734 .946 r
.3994 .58266 .40805 .5906 .42256 .58672 .41391 .58039 Mtetra
.474 .739 .986 r
.41391 .58039 .42256 .58672 .43709 .58504 .42846 .57982 Mtetra
.379 .729 .99 r
.42846 .57982 .43709 .58504 .4517 .58455 .4431 .58004 Mtetra
.529 .817 .999 r
.4431 .58004 .4517 .58455 .46642 .58423 .45792 .5775 Mtetra
.698 .803 .93 r
.45792 .5775 .46642 .58423 .48129 .5813 .47289 .57131 Mtetra
.746 .74 .846 r
.47289 .57131 .48129 .5813 .49628 .57551 .48797 .56186 Mtetra
.736 .681 .798 r
.48797 .56186 .49628 .57551 .51134 .56745 .50309 .55142 Mtetra
.706 .643 .784 r
.50309 .55142 .51134 .56745 .52646 .5583 .51824 .54239 Mtetra
.686 .636 .794 r
.51824 .54239 .52646 .5583 .54163 .54971 .53344 .53498 Mtetra
.673 .645 .814 r
.53344 .53498 .54163 .54971 .55685 .54247 .54871 .52878 Mtetra
.658 .654 .834 r
.54871 .52878 .55685 .54247 .57215 .53628 .56406 .52366 Mtetra
.653 .669 .853 r
.56406 .52366 .57215 .53628 .58754 .53089 .5795 .51893 Mtetra
.655 .682 .863 r
.5795 .51893 .58754 .53089 .60303 .5262 .59503 .51418 Mtetra
.654 .682 .863 r
.59503 .51418 .60303 .5262 .61862 .5222 .61064 .50941 Mtetra
.645 .665 .855 r
.61064 .50941 .61862 .5222 .63433 .519 .62635 .50504 Mtetra
.621 .637 .845 r
.62635 .50504 .63433 .519 .65018 .51689 .6422 .50176 Mtetra
.596 .609 .835 r
.6422 .50176 .65018 .51689 .66621 .51615 .6582 .49971 Mtetra
.564 .577 .825 r
.6582 .49971 .66621 .51615 .6824 .516 .67439 .49932 Mtetra
.533 .558 .827 r
.67439 .49932 .6824 .516 .69867 .51476 .69079 .50039 Mtetra
.546 .598 .857 r
.69079 .50039 .69867 .51476 .71493 .51123 .7073 .50047 Mtetra
.615 .698 .903 r
.7073 .50047 .71493 .51123 .73112 .50476 .72374 .49725 Mtetra
.703 .809 .931 r
.72374 .49725 .73112 .50476 .74722 .49561 .74006 .49028 Mtetra
.767 .884 .93 r
.74006 .49028 .74722 .49561 .76337 .48661 .75626 .48045 Mtetra
.749 .86 .931 r
.75626 .48045 .76337 .48661 .77968 .47881 .77256 .47142 Mtetra
.709 .818 .933 r
.77256 .47142 .77968 .47881 .79623 .47326 .78906 .46412 Mtetra
.658 .757 .923 r
.78906 .46412 .79623 .47326 .81294 .46832 .80582 .4589 Mtetra
.656 .751 .92 r
.80582 .4589 .81294 .46832 .82973 .46319 .82268 .45377 Mtetra
.66 .754 .92 r
.82268 .45377 .82973 .46319 .84659 .45779 .83963 .44845 Mtetra
.663 .758 .921 r
.83963 .44845 .84659 .45779 .86357 .45259 .85666 .44298 Mtetra
.651 .748 .921 r
.85666 .44298 .86357 .45259 .88068 .4477 .87384 .43795 Mtetra
.651 .746 .919 r
.87384 .43795 .88068 .4477 .89788 .44256 .89112 .43289 Mtetra
.657 .752 .92 r
.89112 .43289 .89788 .44256 .91515 .43719 .90848 .42755 Mtetra
.656 .752 .921 r
.29052 .60496 .29958 .61283 .31361 .6086 .3046 .60063 Mtetra
.663 .753 .917 r
.3046 .60063 .31361 .6086 .32773 .60413 .31877 .59604 Mtetra
.655 .749 .918 r
.31877 .59604 .32773 .60413 .34192 .59963 .333 .5917 Mtetra
.647 .752 .925 r
.333 .5917 .34192 .59963 .35617 .59556 .34729 .58761 Mtetra
.654 .754 .923 r
.34729 .58761 .35617 .59556 .3705 .59135 .36168 .58326 Mtetra
.659 .753 .92 r
.36168 .58326 .3705 .59135 .38492 .58696 .37614 .57873 Mtetra
.623 .74 .931 r
.37614 .57873 .38492 .58696 .3994 .58266 .39064 .57537 Mtetra
.516 .729 .97 r
.39064 .57537 .3994 .58266 .41391 .58039 .40514 .57441 Mtetra
.389 .713 .987 r
.40514 .57441 .41391 .58039 .42846 .57982 .41971 .57492 Mtetra
.463 .78 .998 r
.41971 .57492 .42846 .57982 .4431 .58004 .43445 .57365 Mtetra
.686 .81 .941 r
.43445 .57365 .4431 .58004 .45792 .5775 .44939 .56785 Mtetra
.754 .748 .847 r
.44939 .56785 .45792 .5775 .47289 .57131 .46448 .558 Mtetra
.749 .69 .795 r
.46448 .558 .47289 .57131 .48797 .56186 .47963 .54652 Mtetra
.715 .655 .788 r
.47963 .54652 .48797 .56186 .50309 .55142 .49478 .53699 Mtetra
.694 .658 .81 r
.49478 .53699 .50309 .55142 .51824 .54239 .50996 .5295 Mtetra
.659 .666 .846 r
.50996 .5295 .51824 .54239 .53344 .53498 .52521 .52444 Mtetra
.642 .703 .891 r
.52521 .52444 .53344 .53498 .54871 .52878 .54053 .52033 Mtetra
.637 .75 .93 r
.54053 .52033 .54871 .52878 .56406 .52366 .55595 .51628 Mtetra
.64 .78 .948 r
.55595 .51628 .56406 .52366 .5795 .51893 .57146 .51191 Mtetra
.651 .795 .952 r
.57146 .51191 .5795 .51893 .59503 .51418 .58705 .50712 Mtetra
.663 .798 .947 r
.58705 .50712 .59503 .51418 .61064 .50941 .60272 .50189 Mtetra
.672 .79 .937 r
.60272 .50189 .61064 .50941 .62635 .50504 .61847 .49635 Mtetra
.672 .762 .918 r
.61847 .49635 .62635 .50504 .6422 .50176 .6343 .49085 Mtetra
.648 .705 .889 r
.6343 .49085 .6422 .50176 .6582 .49971 .65025 .48632 Mtetra
.592 .637 .864 r
.65025 .48632 .6582 .49971 .67439 .49932 .66641 .48426 Mtetra
.548 .59 .848 r
.66641 .48426 .67439 .49932 .69079 .50039 .68279 .48428 Mtetra
.505 .553 .838 r
.68279 .48428 .69079 .50039 .7073 .50047 .69941 .48631 Mtetra
.534 .598 .864 r
.69941 .48631 .7073 .50047 .72374 .49725 .71611 .48673 Mtetra
.624 .71 .908 r
.71611 .48673 .72374 .49725 .74006 .49028 .7327 .48301 Mtetra
.734 .827 .923 r
.7327 .48301 .74006 .49028 .75626 .48045 .74908 .47461 Mtetra
.774 .875 .921 r
.74908 .47461 .75626 .48045 .77256 .47142 .7654 .46438 Mtetra
.741 .838 .924 r
.7654 .46438 .77256 .47142 .78906 .46412 .78187 .45562 Mtetra
.683 .785 .928 r
.78187 .45562 .78906 .46412 .80582 .4589 .79862 .44933 Mtetra
.653 .749 .92 r
.79862 .44933 .80582 .4589 .82268 .45377 .81556 .44425 Mtetra
.657 .753 .92 r
.81556 .44425 .82268 .45377 .83963 .44845 .83258 .43897 Mtetra
.663 .757 .92 r
.83258 .43897 .83963 .44845 .85666 .44298 .84969 .43342 Mtetra
.656 .754 .922 r
.84969 .43342 .85666 .44298 .87384 .43795 .86692 .42812 Mtetra
.649 .746 .92 r
.86692 .42812 .87384 .43795 .89112 .43289 .88428 .42308 Mtetra
.655 .751 .92 r
.88428 .42308 .89112 .43289 .90848 .42755 .90172 .41776 Mtetra
.659 .752 .919 r
.28138 .597 .29052 .60496 .3046 .60063 .29551 .59254 Mtetra
.663 .751 .916 r
.29551 .59254 .3046 .60063 .31877 .59604 .30973 .5879 Mtetra
.65 .748 .921 r
.30973 .5879 .31877 .59604 .333 .5917 .32399 .5837 Mtetra
.65 .753 .925 r
.32399 .5837 .333 .5917 .34729 .58761 .33833 .57948 Mtetra
.655 .752 .921 r
.33833 .57948 .34729 .58761 .36168 .58326 .35277 .57506 Mtetra
.653 .751 .921 r
.35277 .57506 .36168 .58326 .37614 .57873 .36727 .57067 Mtetra
.573 .73 .949 r
.36727 .57067 .37614 .57873 .39064 .57537 .38176 .56863 Mtetra
.443 .717 .982 r
.38176 .56863 .39064 .57537 .40514 .57441 .39627 .56869 Mtetra
.385 .721 .989 r
.39627 .56869 .40514 .57441 .41971 .57492 .41089 .56903 Mtetra
.63 .812 .97 r
.41089 .56903 .41971 .57492 .43445 .57365 .42576 .56484 Mtetra
.746 .764 .867 r
.42576 .56484 .43445 .57365 .44939 .56785 .44084 .55586 Mtetra
.766 .714 .803 r
.44084 .55586 .44939 .56785 .46448 .558 .45603 .54361 Mtetra
.733 .673 .792 r
.45603 .54361 .46448 .558 .47963 .54652 .47121 .53305 Mtetra
.703 .675 .819 r
.47121 .53305 .47963 .54652 .49478 .53699 .48638 .52519 Mtetra
.648 .681 .868 r
.48638 .52519 .49478 .53699 .50996 .5295 .50159 .52079 Mtetra
.618 .737 .932 r
.50159 .52079 .50996 .5295 .52521 .52444 .51688 .51741 Mtetra
.614 .781 .961 r
.51688 .51741 .52521 .52444 .54053 .52033 .53227 .51375 Mtetra
.621 .797 .967 r
.53227 .51375 .54053 .52033 .55595 .51628 .54776 .50974 Mtetra
.634 .804 .964 r
.54776 .50974 .55595 .51628 .57146 .51191 .56333 .50531 Mtetra
.647 .808 .96 r
.56333 .50531 .57146 .51191 .58705 .50712 .579 .50047 Mtetra
.66 .811 .956 r
.579 .50047 .58705 .50712 .60272 .50189 .59474 .49521 Mtetra
.672 .815 .952 r
.59474 .49521 .60272 .50189 .61847 .49635 .61055 .48953 Mtetra
.681 .815 .947 r
.61055 .48953 .61847 .49635 .6343 .49085 .62644 .48349 Mtetra
.69 .804 .936 r
.62644 .48349 .6343 .49085 .65025 .48632 .6424 .47716 Mtetra
.664 .753 .916 r
.6424 .47716 .65025 .48632 .66641 .48426 .65848 .47186 Mtetra
.581 .651 .884 r
.65848 .47186 .66641 .48426 .68279 .48428 .67482 .47007 Mtetra
.517 .589 .866 r
.67482 .47007 .68279 .48428 .69941 .48631 .69142 .47105 Mtetra
.478 .553 .854 r
.69142 .47105 .69941 .48631 .71611 .48673 .70827 .4738 Mtetra
.55 .63 .884 r
.70827 .4738 .71611 .48673 .7327 .48301 .7251 .47322 Mtetra
.664 .746 .911 r
.7251 .47322 .7327 .48301 .74908 .47461 .74175 .46775 Mtetra
.769 .849 .911 r
.74175 .46775 .74908 .47461 .7654 .46438 .75817 .45758 Mtetra
.764 .852 .917 r
.75817 .45758 .7654 .46438 .78187 .45562 .77465 .44768 Mtetra
.716 .812 .925 r
.77465 .44768 .78187 .45562 .79862 .44933 .79136 .43992 Mtetra
.658 .757 .923 r
.79136 .43992 .79862 .44933 .81556 .44425 .80836 .43459 Mtetra
.656 .751 .92 r
.80836 .43459 .81556 .44425 .83258 .43897 .82546 .42929 Mtetra
.661 .754 .919 r
.82546 .42929 .83258 .43897 .84969 .43342 .84264 .42376 Mtetra
.661 .756 .921 r
.84264 .42376 .84969 .43342 .86692 .42812 .85992 .41821 Mtetra
.649 .747 .921 r
.85992 .41821 .86692 .42812 .88428 .42308 .87736 .41312 Mtetra
.653 .749 .92 r
.87736 .41312 .88428 .42308 .90172 .41776 .89489 .40783 Mtetra
.661 .753 .918 r
.27214 .58893 .28138 .597 .29551 .59254 .28633 .58436 Mtetra
.661 .751 .917 r
.28633 .58436 .29551 .59254 .30973 .5879 .30059 .57975 Mtetra
.647 .749 .924 r
.30059 .57975 .30973 .5879 .32399 .5837 .31489 .57561 Mtetra
.652 .753 .924 r
.31489 .57561 .32399 .5837 .33833 .57948 .32928 .57126 Mtetra
.658 .752 .92 r
.32928 .57126 .33833 .57948 .35277 .57506 .34377 .56669 Mtetra
.636 .744 .926 r
.34377 .56669 .35277 .57506 .36727 .57067 .3583 .56286 Mtetra
.521 .72 .963 r
.3583 .56286 .36727 .57067 .38176 .56863 .37278 .56189 Mtetra
.39 .694 .981 r
.37278 .56189 .38176 .56863 .39627 .56869 .3873 .56271 Mtetra
.494 .764 .991 r
.3873 .56271 .39627 .56869 .41089 .56903 .40202 .56143 Mtetra
.708 .785 .912 r
.40202 .56143 .41089 .56903 .42576 .56484 .41703 .5547 Mtetra
.777 .745 .824 r
.41703 .5547 .42576 .56484 .44084 .55586 .43225 .5427 Mtetra
.757 .697 .794 r
.43225 .5427 .44084 .55586 .45603 .54361 .44748 .53057 Mtetra
.722 .688 .817 r
.44748 .53057 .45603 .54361 .47121 .53305 .46268 .52154 Mtetra
.655 .69 .871 r
.46268 .52154 .47121 .53305 .48638 .52519 .47786 .51679 Mtetra
.604 .741 .941 r
.47786 .51679 .48638 .52519 .50159 .52079 .49311 .51374 Mtetra
.598 .776 .965 r
.49311 .51374 .50159 .52079 .51688 .51741 .50846 .51048 Mtetra
.614 .786 .964 r
.50846 .51048 .51688 .51741 .53227 .51375 .52392 .50674 Mtetra
.64 .794 .956 r
.52392 .50674 .53227 .51375 .54776 .50974 .53946 .5022 Mtetra
.65 .784 .945 r
.53946 .5022 .54776 .50974 .56333 .50531 .5551 .49744 Mtetra
.654 .777 .939 r
.5551 .49744 .56333 .50531 .579 .50047 .57083 .49255 Mtetra
.656 .778 .938 r
.57083 .49255 .579 .50047 .59474 .49521 .58664 .48753 Mtetra
.661 .787 .941 r
.58664 .48753 .59474 .49521 .61055 .48953 .60254 .48228 Mtetra
.681 .806 .942 r
.60254 .48228 .61055 .48953 .62644 .48349 .6185 .47622 Mtetra
.694 .81 .937 r
.6185 .47622 .62644 .48349 .6424 .47716 .63453 .46967 Mtetra
.699 .807 .932 r
.63453 .46967 .6424 .47716 .65848 .47186 .65063 .46289 Mtetra
.655 .758 .925 r
.65063 .46289 .65848 .47186 .67482 .47007 .66688 .45785 Mtetra
.548 .642 .895 r
.66688 .45785 .67482 .47007 .69142 .47105 .68344 .45715 Mtetra
.468 .571 .876 r
.68344 .45715 .69142 .47105 .70827 .4738 .70031 .45966 Mtetra
.474 .571 .873 r
.70031 .45966 .70827 .4738 .7251 .47322 .71735 .46207 Mtetra
.603 .693 .907 r
.71735 .46207 .7251 .47322 .74175 .46775 .73422 .4591 Mtetra
.732 .798 .905 r
.73422 .4591 .74175 .46775 .75817 .45758 .75083 .4505 Mtetra
.779 .849 .904 r
.75083 .4505 .75817 .45758 .77465 .44768 .76735 .43972 Mtetra
.741 .821 .914 r
.76735 .43972 .77465 .44768 .79136 .43992 .78405 .43075 Mtetra
.673 .771 .924 r
.78405 .43075 .79136 .43992 .80836 .43459 .80107 .42474 Mtetra
.654 .749 .919 r
.80107 .42474 .80836 .43459 .82546 .42929 .81825 .41949 Mtetra
.659 .753 .92 r
.81825 .41949 .82546 .42929 .84264 .42376 .83552 .414 Mtetra
.663 .757 .92 r
.83552 .414 .84264 .42376 .85992 .41821 .85286 .40828 Mtetra
.651 .75 .922 r
.85286 .40828 .85992 .41821 .87736 .41312 .87037 .40304 Mtetra
.651 .748 .92 r
.87037 .40304 .87736 .41312 .89489 .40783 .88798 .39777 Mtetra
.662 .753 .917 r
.26282 .58078 .27214 .58893 .28633 .58436 .27705 .57611 Mtetra
.658 .75 .918 r
.27705 .57611 .28633 .58436 .30059 .57975 .29135 .57158 Mtetra
.646 .75 .925 r
.29135 .57158 .30059 .57975 .31489 .57561 .3057 .56741 Mtetra
.654 .753 .922 r
.3057 .56741 .31489 .57561 .32928 .57126 .32014 .56296 Mtetra
.658 .752 .92 r
.32014 .56296 .32928 .57126 .34377 .56669 .33468 .55833 Mtetra
.608 .738 .937 r
.33468 .55833 .34377 .56669 .3583 .56286 .34921 .55532 Mtetra
.482 .714 .973 r
.34921 .55532 .3583 .56286 .37278 .56189 .3637 .55496 Mtetra
.38 .686 .979 r
.3637 .55496 .37278 .56189 .3873 .56271 .37825 .55597 Mtetra
.603 .783 .967 r
.37825 .55597 .3873 .56271 .40202 .56143 .3931 .55263 Mtetra
.75 .767 .867 r
.3931 .55263 .40202 .56143 .41703 .5547 .40825 .54338 Mtetra
.782 .729 .803 r
.40825 .54338 .41703 .5547 .43225 .5427 .42357 .53003 Mtetra
.748 .702 .808 r
.42357 .53003 .43225 .5427 .44748 .53057 .43883 .51908 Mtetra
.692 .704 .857 r
.43883 .51908 .44748 .53057 .46268 .52154 .45403 .51241 Mtetra
.608 .726 .929 r
.45403 .51241 .46268 .52154 .47786 .51679 .46924 .50933 Mtetra
.589 .763 .962 r
.46924 .50933 .47786 .51679 .49311 .51374 .48454 .50641 Mtetra
.611 .775 .959 r
.48454 .50641 .49311 .51374 .50846 .51048 .49995 .50282 Mtetra
.644 .778 .945 r
.49995 .50282 .50846 .51048 .52392 .50674 .51547 .49826 Mtetra
.652 .761 .93 r
.51547 .49826 .52392 .50674 .53946 .5022 .53107 .4935 Mtetra
.652 .757 .926 r
.53107 .4935 .53946 .5022 .5551 .49744 .54677 .48872 Mtetra
.656 .759 .926 r
.54677 .48872 .5551 .49744 .57083 .49255 .56256 .48378 Mtetra
.659 .76 .925 r
.56256 .48378 .57083 .49255 .58664 .48753 .57843 .47867 Mtetra
.659 .759 .924 r
.57843 .47867 .58664 .48753 .60254 .48228 .59439 .47354 Mtetra
.663 .765 .925 r
.59439 .47354 .60254 .48228 .6185 .47622 .61044 .46821 Mtetra
.687 .791 .929 r
.61044 .46821 .6185 .47622 .63453 .46967 .62655 .46189 Mtetra
.703 .803 .927 r
.62655 .46189 .63453 .46967 .65063 .46289 .64272 .45489 Mtetra
.699 .798 .926 r
.64272 .45489 .65063 .46289 .66688 .45785 .65897 .44804 Mtetra
.605 .722 .927 r
.65897 .44804 .66688 .45785 .68344 .45715 .67547 .44483 Mtetra
.489 .614 .902 r
.67547 .44483 .68344 .45715 .70031 .45966 .69231 .44601 Mtetra
.425 .555 .882 r
.69231 .44601 .70031 .45966 .71735 .46207 .70945 .4497 Mtetra
.539 .641 .899 r
.70945 .4497 .71735 .46207 .73422 .4591 .72654 .4492 Mtetra
.686 .757 .906 r
.72654 .4492 .73422 .4591 .75083 .4505 .74336 .44263 Mtetra
.779 .832 .893 r
.74336 .44263 .75083 .4505 .76735 .43972 .75995 .43155 Mtetra
.753 .821 .905 r
.75995 .43155 .76735 .43972 .78405 .43075 .77669 .42185 Mtetra
.694 .787 .922 r
.77669 .42185 .78405 .43075 .80107 .42474 .79371 .41487 Mtetra
.653 .751 .921 r
.79371 .41487 .80107 .42474 .81825 .41949 .81096 .40958 Mtetra
.657 .752 .92 r
.81096 .40958 .81825 .41949 .83552 .414 .82831 .40408 Mtetra
.664 .756 .919 r
.82831 .40408 .83552 .414 .85286 .40828 .84573 .39829 Mtetra
.654 .752 .922 r
.84573 .39829 .85286 .40828 .87037 .40304 .8633 .39287 Mtetra
.65 .747 .921 r
.8633 .39287 .87037 .40304 .88798 .39777 .88099 .38759 Mtetra
.663 .753 .917 r
.2534 .57255 .26282 .58078 .27705 .57611 .26768 .5678 Mtetra
.655 .75 .92 r
.26768 .5678 .27705 .57611 .29135 .57158 .28202 .56332 Mtetra
.647 .75 .925 r
.28202 .56332 .29135 .57158 .3057 .56741 .29642 .55907 Mtetra
.654 .751 .921 r
.29642 .55907 .3057 .56741 .32014 .56296 .31091 .55458 Mtetra
.657 .752 .92 r
.31091 .55458 .32014 .56296 .33468 .55833 .32549 .54996 Mtetra
.581 .731 .945 r
.32549 .54996 .33468 .55833 .34921 .55532 .34002 .54763 Mtetra
.447 .697 .973 r
.34002 .54763 .34921 .55532 .3637 .55496 .35452 .54789 Mtetra
.408 .698 .98 r
.35452 .54789 .3637 .55496 .37825 .55597 .36914 .54847 Mtetra
.666 .782 .935 r
.36914 .54847 .37825 .55597 .3931 .55263 .38411 .54332 Mtetra
.775 .762 .842 r
.38411 .54332 .3931 .55263 .40825 .54338 .3994 .53202 Mtetra
.782 .73 .804 r
.3994 .53202 .40825 .54338 .42357 .53003 .41478 .51864 Mtetra
.743 .722 .832 r
.41478 .51864 .42357 .53003 .43883 .51908 .43007 .50873 Mtetra
.651 .715 .895 r
.43007 .50873 .43883 .51908 .45403 .51241 .44527 .50417 Mtetra
.585 .742 .951 r
.44527 .50417 .45403 .51241 .46924 .50933 .46052 .50153 Mtetra
.593 .758 .957 r
.46052 .50153 .46924 .50933 .48454 .50641 .47588 .49854 Mtetra
.64 .772 .944 r
.47588 .49854 .48454 .50641 .49995 .50282 .49136 .49413 Mtetra
.648 .756 .928 r
.49136 .49413 .49995 .50282 .51547 .49826 .50693 .48948 Mtetra
.648 .755 .927 r
.50693 .48948 .51547 .49826 .53107 .4935 .52259 .48484 Mtetra
.651 .76 .929 r
.52259 .48484 .53107 .4935 .54677 .48872 .53835 .48003 Mtetra
.655 .762 .928 r
.53835 .48003 .54677 .48872 .56256 .48378 .5542 .47504 Mtetra
.66 .763 .926 r
.5542 .47504 .56256 .48378 .57843 .47867 .57013 .46985 Mtetra
.663 .764 .925 r
.57013 .46985 .57843 .47867 .59439 .47354 .58616 .4645 Mtetra
.663 .759 .922 r
.58616 .4645 .59439 .47354 .61044 .46821 .60227 .45915 Mtetra
.668 .762 .921 r
.60227 .45915 .61044 .46821 .62655 .46189 .61847 .45356 Mtetra
.702 .791 .92 r
.61847 .45356 .62655 .46189 .64272 .45489 .63472 .44653 Mtetra
.71 .794 .917 r
.63472 .44653 .64272 .45489 .65897 .44804 .65102 .43912 Mtetra
.662 .767 .928 r
.65102 .43912 .65897 .44804 .67547 .44483 .66749 .43367 Mtetra
.512 .652 .921 r
.66749 .43367 .67547 .44483 .69231 .44601 .68432 .43367 Mtetra
.402 .569 .904 r
.68432 .43367 .69231 .44601 .70945 .4497 .70149 .43727 Mtetra
.476 .61 .904 r
.70149 .43727 .70945 .4497 .72654 .4492 .71874 .43877 Mtetra
.643 .732 .913 r
.71874 .43877 .72654 .4492 .74336 .44263 .73575 .43396 Mtetra
.769 .813 .888 r
.73575 .43396 .74336 .44263 .75995 .43155 .75246 .42321 Mtetra
.765 .822 .897 r
.75246 .42321 .75995 .43155 .77669 .42185 .76923 .41276 Mtetra
.71 .791 .914 r
.76923 .41276 .77669 .42185 .79371 .41487 .78627 .40498 Mtetra
.655 .753 .922 r
.78627 .40498 .79371 .41487 .81096 .40958 .8036 .39956 Mtetra
.657 .752 .92 r
.8036 .39956 .81096 .40958 .82831 .40408 .82102 .394 Mtetra
.663 .755 .918 r
.82102 .394 .82831 .40408 .84573 .39829 .83852 .38818 Mtetra
.657 .753 .921 r
.83852 .38818 .84573 .39829 .8633 .39287 .85615 .3826 Mtetra
.649 .747 .921 r
.85615 .3826 .8633 .39287 .88099 .38759 .87392 .37729 Mtetra
.664 .753 .917 r
.24389 .56424 .2534 .57255 .26768 .5678 .25822 .55942 Mtetra
.653 .75 .921 r
.25822 .55942 .26768 .5678 .28202 .56332 .27259 .55496 Mtetra
.648 .75 .924 r
.27259 .55496 .28202 .56332 .29642 .55907 .28704 .55064 Mtetra
.654 .751 .921 r
.28704 .55064 .29642 .55907 .31091 .55458 .30158 .54609 Mtetra
.30158 .54609 .31091 .55458 .32549 .54996 .3162 .54152 Mtetra
.562 .724 .95 r
.3162 .54152 .32549 .54996 .34002 .54763 .33075 .53965 Mtetra
.431 .684 .97 r
.33075 .53965 .34002 .54763 .35452 .54789 .34527 .54026 Mtetra
.458 .707 .975 r
.34527 .54026 .35452 .54789 .36914 .54847 .35995 .54021 Mtetra
.695 .772 .911 r
.35995 .54021 .36914 .54847 .38411 .54332 .37503 .53391 Mtetra
.789 .763 .83 r
.37503 .53391 .38411 .54332 .3994 .53202 .39044 .52131 Mtetra
.784 .741 .814 r
.39044 .52131 .3994 .53202 .41478 .51864 .40588 .50825 Mtetra
.733 .738 .855 r
.40588 .50825 .41478 .51864 .43007 .50873 .42119 .49941 Mtetra
.619 .729 .925 r
.42119 .49941 .43007 .50873 .44527 .50417 .43641 .49591 Mtetra
.58 .743 .953 r
.43641 .49591 .44527 .50417 .46052 .50153 .45171 .49333 Mtetra
.612 .756 .947 r
.45171 .49333 .46052 .50153 .47588 .49854 .46713 .4898 Mtetra
.647 .756 .928 r
.46713 .4898 .47588 .49854 .49136 .49413 .48267 .48517 Mtetra
.644 .75 .926 r
.48267 .48517 .49136 .49413 .50693 .48948 .4983 .48064 Mtetra
.646 .755 .928 r
.4983 .48064 .50693 .48948 .52259 .48484 .51402 .47599 Mtetra
.651 .758 .928 r
.51402 .47599 .52259 .48484 .53835 .48003 .52984 .47115 Mtetra
.656 .76 .926 r
.52984 .47115 .53835 .48003 .5542 .47504 .54575 .46611 Mtetra
.66 .761 .925 r
.54575 .46611 .5542 .47504 .57013 .46985 .56175 .46085 Mtetra
.665 .762 .923 r
.56175 .46085 .57013 .46985 .58616 .4645 .57784 .45539 Mtetra
.667 .762 .921 r
.57784 .45539 .58616 .4645 .60227 .45915 .59401 .44982 Mtetra
.664 .757 .919 r
.59401 .44982 .60227 .45915 .61847 .45356 .61028 .44435 Mtetra
.69 .769 .912 r
.61028 .44435 .61847 .45356 .63472 .44653 .62661 .43775 Mtetra
.711 .787 .911 r
.62661 .43775 .63472 .44653 .65102 .43912 .64299 .43019 Mtetra
.69 .778 .919 r
.64299 .43019 .65102 .43912 .66749 .43367 .65947 .42353 Mtetra
.538 .691 .938 r
.65947 .42353 .66749 .43367 .68432 .43367 .6763 .42233 Mtetra
.395 .59 .922 r
.6763 .42233 .68432 .43367 .70149 .43727 .6935 .42549 Mtetra
.42 .595 .917 r
.6935 .42549 .70149 .43727 .71874 .43877 .71086 .42821 Mtetra
.614 .72 .921 r
.71086 .42821 .71874 .43877 .73575 .43396 .72801 .42448 Mtetra
.755 .794 .885 r
.72801 .42448 .73575 .43396 .75246 .42321 .74484 .41428 Mtetra
.77 .812 .886 r
.74484 .41428 .75246 .42321 .76923 .41276 .76167 .40336 Mtetra
.721 .789 .906 r
.76167 .40336 .76923 .41276 .78627 .40498 .77875 .39499 Mtetra
.657 .754 .921 r
.77875 .39499 .78627 .40498 .8036 .39956 .79614 .38941 Mtetra
.657 .752 .92 r
.79614 .38941 .8036 .39956 .82102 .394 .81364 .3838 Mtetra
.662 .754 .918 r
.81364 .3838 .82102 .394 .83852 .38818 .83122 .37795 Mtetra
.658 .753 .92 r
.83122 .37795 .83852 .38818 .85615 .3826 .84892 .37223 Mtetra
.649 .748 .922 r
.84892 .37223 .85615 .3826 .87392 .37729 .86678 .36688 Mtetra
.664 .753 .917 r
.23427 .55584 .24389 .56424 .25822 .55942 .24865 .55097 Mtetra
.652 .75 .922 r
.24865 .55097 .25822 .55942 .27259 .55496 .26307 .5465 Mtetra
.649 .75 .923 r
.26307 .5465 .27259 .55496 .28704 .55064 .27757 .54212 Mtetra
.655 .751 .921 r
.27757 .54212 .28704 .55064 .30158 .54609 .29216 .53749 Mtetra
.651 .75 .922 r
.29216 .53749 .30158 .54609 .3162 .54152 .30683 .53296 Mtetra
.552 .72 .951 r
.30683 .53296 .3162 .54152 .33075 .53965 .3214 .5313 Mtetra
.428 .675 .966 r
.3214 .5313 .33075 .53965 .34527 .54026 .33595 .53205 Mtetra
.491 .707 .966 r
.33595 .53205 .34527 .54026 .35995 .54021 .35069 .53156 Mtetra
.706 .767 .9 r
.35069 .53156 .35995 .54021 .37503 .53391 .36585 .52468 Mtetra
.797 .769 .827 r
.36585 .52468 .37503 .53391 .39044 .52131 .38135 .51144 Mtetra
.788 .758 .825 r
.38135 .51144 .39044 .52131 .40588 .50825 .39685 .49859 Mtetra
.726 .753 .874 r
.39685 .49859 .40588 .50825 .42119 .49941 .4122 .49041 Mtetra
.604 .733 .936 r
.4122 .49041 .42119 .49941 .43641 .49591 .42746 .48728 Mtetra
.584 .736 .948 r
.42746 .48728 .43641 .49591 .45171 .49333 .44281 .48464 Mtetra
.624 .75 .937 r
.44281 .48464 .45171 .49333 .46713 .4898 .4583 .48077 Mtetra
.647 .751 .925 r
.4583 .48077 .46713 .4898 .48267 .48517 .47389 .47612 Mtetra
.643 .75 .927 r
.47389 .47612 .48267 .48517 .4983 .48064 .48958 .47156 Mtetra
.646 .752 .926 r
.48958 .47156 .4983 .48064 .51402 .47599 .50536 .46688 Mtetra
.653 .754 .924 r
.50536 .46688 .51402 .47599 .52984 .47115 .52124 .46193 Mtetra
.656 .754 .922 r
.52124 .46193 .52984 .47115 .54575 .46611 .53721 .45683 Mtetra
.659 .755 .921 r
.53721 .45683 .54575 .46611 .56175 .46085 .55327 .45158 Mtetra
.665 .758 .92 r
.55327 .45158 .56175 .46085 .57784 .45539 .56942 .44605 Mtetra
.668 .759 .919 r
.56942 .44605 .57784 .45539 .59401 .44982 .58566 .4404 Mtetra
.665 .757 .919 r
.58566 .4404 .59401 .44982 .61028 .44435 .60199 .43483 Mtetra
.683 .762 .912 r
.60199 .43483 .61028 .44435 .62661 .43775 .6184 .42847 Mtetra
.71 .777 .905 r
.6184 .42847 .62661 .43775 .64299 .43019 .63485 .42086 Mtetra
.699 .774 .91 r
.63485 .42086 .64299 .43019 .65947 .42353 .65139 .41372 Mtetra
.559 .71 .942 r
.65139 .41372 .65947 .42353 .6763 .42233 .66824 .41174 Mtetra
.387 .606 .935 r
.66824 .41174 .6763 .42233 .6935 .42549 .68547 .41456 Mtetra
.377 .593 .93 r
.68547 .41456 .6935 .42549 .71086 .42821 .70291 .41783 Mtetra
.598 .719 .929 r
.70291 .41783 .71086 .42821 .72801 .42448 .72016 .41458 Mtetra
.746 .785 .885 r
.72016 .41458 .72801 .42448 .74484 .41428 .7371 .40473 Mtetra
.77 .8 .878 r
.7371 .40473 .74484 .41428 .76167 .40336 .75401 .39355 Mtetra
.725 .784 .899 r
.75401 .39355 .76167 .40336 .77875 .39499 .77115 .38486 Mtetra
.66 .754 .92 r
.77115 .38486 .77875 .39499 .79614 .38941 .78861 .37912 Mtetra
.656 .751 .92 r
.78861 .37912 .79614 .38941 .81364 .3838 .80618 .37348 Mtetra
.662 .754 .918 r
.80618 .37348 .81364 .3838 .83122 .37795 .82384 .36758 Mtetra
.659 .753 .92 r
.82384 .36758 .83122 .37795 .84892 .37223 .84162 .36177 Mtetra
.648 .748 .922 r
.84162 .36177 .84892 .37223 .86678 .36688 .85955 .35636 Mtetra
.664 .753 .917 r
.22456 .54737 .23427 .55584 .24865 .55097 .23899 .54245 Mtetra
.652 .75 .922 r
.23899 .54245 .24865 .55097 .26307 .5465 .25346 .53793 Mtetra
.649 .75 .923 r
.25346 .53793 .26307 .5465 .27757 .54212 .268 .5335 Mtetra
.655 .751 .921 r
.268 .5335 .27757 .54212 .29216 .53749 .28264 .52883 Mtetra
.651 .75 .922 r
.28264 .52883 .29216 .53749 .30683 .53296 .29735 .52425 Mtetra
.552 .719 .95 r
.29735 .52425 .30683 .53296 .3214 .5313 .31197 .52255 Mtetra
.436 .67 .961 r
.31197 .52255 .3214 .5313 .33595 .53205 .32655 .52327 Mtetra
.5 .698 .958 r
.32655 .52327 .33595 .53205 .35069 .53156 .34133 .52273 Mtetra
.705 .765 .898 r
.34133 .52273 .35069 .53156 .36585 .52468 .35655 .5158 Mtetra
.8 .777 .832 r
.35655 .5158 .36585 .52468 .38135 .51144 .37213 .50249 Mtetra
.796 .777 .835 r
.37213 .50249 .38135 .51144 .39685 .49859 .38771 .48957 Mtetra
.73 .769 .884 r
.38771 .48957 .39685 .49859 .4122 .49041 .40312 .48132 Mtetra
.604 .734 .936 r
.40312 .48132 .4122 .49041 .42746 .48728 .41843 .47815 Mtetra
.587 .727 .941 r
.41843 .47815 .42746 .48728 .44281 .48464 .43383 .47546 Mtetra
.625 .741 .93 r
.43383 .47546 .44281 .48464 .4583 .48077 .44937 .47154 Mtetra
.647 .748 .923 r
.44937 .47154 .4583 .48077 .47389 .47612 .46502 .46684 Mtetra
.644 .747 .924 r
.46502 .46684 .47389 .47612 .48958 .47156 .48076 .46223 Mtetra
.646 .748 .923 r
.48076 .46223 .48958 .47156 .50536 .46688 .4966 .4575 Mtetra
.653 .75 .921 r
.4966 .4575 .50536 .46688 .52124 .46193 .51254 .45249 Mtetra
.656 .751 .92 r
.51254 .45249 .52124 .46193 .53721 .45683 .52857 .44733 Mtetra
.659 .752 .919 r
.52857 .44733 .53721 .45683 .55327 .45158 .54469 .44203 Mtetra
.665 .754 .917 r
.54469 .44203 .55327 .45158 .56942 .44605 .56091 .43644 Mtetra
.668 .755 .916 r
.56091 .43644 .56942 .44605 .58566 .4404 .57721 .43073 Mtetra
.665 .754 .917 r
.57721 .43073 .58566 .4404 .60199 .43483 .59361 .42511 Mtetra
.683 .76 .91 r
.59361 .42511 .60199 .43483 .6184 .42847 .61008 .41868 Mtetra
.709 .768 .899 r
.61008 .41868 .6184 .42847 .63485 .42086 .62661 .41101 Mtetra
.698 .765 .903 r
.62661 .41101 .63485 .42086 .65139 .41372 .64322 .40381 Mtetra
.559 .711 .942 r
.64322 .40381 .65139 .41372 .66824 .41174 .66013 .40177 Mtetra
.368 .614 .945 r
.66013 .40177 .66824 .41174 .68547 .41456 .67741 .40456 Mtetra
.349 .603 .943 r
.67741 .40456 .68547 .41456 .70291 .41783 .6949 .40779 Mtetra
.596 .729 .937 r
.6949 .40779 .70291 .41783 .72016 .41458 .71222 .40448 Mtetra
.746 .783 .883 r
.71222 .40448 .72016 .41458 .7371 .40473 .72924 .39456 Mtetra
.767 .789 .871 r
.72924 .39456 .7371 .40473 .75401 .39355 .74623 .38331 Mtetra
.724 .776 .894 r
.74623 .38331 .75401 .39355 .77115 .38486 .76345 .37454 Mtetra
.66 .753 .919 r
.76345 .37454 .77115 .38486 .78861 .37912 .78099 .36874 Mtetra
.656 .752 .92 r
.78099 .36874 .78861 .37912 .80618 .37348 .79864 .36304 Mtetra
.662 .754 .918 r
.79864 .36304 .80618 .37348 .82384 .36758 .81637 .35708 Mtetra
.659 .753 .919 r
.81637 .35708 .82384 .36758 .84162 .36177 .83423 .35119 Mtetra
.648 .748 .922 r
.83423 .35119 .84162 .36177 .85955 .35636 .85224 .34572 Mtetra
.664 .753 .917 r
.21475 .53881 .22456 .54737 .23899 .54245 .22923 .53385 Mtetra
.653 .751 .922 r
.22923 .53385 .23899 .54245 .25346 .53793 .24374 .52925 Mtetra
.648 .749 .923 r
.24374 .52925 .25346 .53793 .268 .5335 .25833 .52479 Mtetra
.654 .751 .921 r
.25833 .52479 .268 .5335 .28264 .52883 .27302 .5201 Mtetra
.27302 .5201 .28264 .52883 .29735 .52425 .28779 .51538 Mtetra
.563 .721 .947 r
.28779 .51538 .29735 .52425 .31197 .52255 .30246 .51339 Mtetra
.453 .669 .956 r
.30246 .51339 .31197 .52255 .32655 .52327 .31708 .51389 Mtetra
.489 .681 .951 r
.31708 .51389 .32655 .52327 .34133 .52273 .33187 .51373 Mtetra
.694 .761 .903 r
.33187 .51373 .34133 .52273 .35655 .5158 .34713 .50727 Mtetra
.797 .785 .842 r
.34713 .50727 .35655 .5158 .37213 .50249 .36276 .49445 Mtetra
.807 .797 .843 r
.36276 .49445 .37213 .50249 .38771 .48957 .37844 .48117 Mtetra
.746 .787 .886 r
.37844 .48117 .38771 .48957 .40312 .48132 .39395 .47215 Mtetra
.617 .738 .933 r
.39395 .47215 .40312 .48132 .41843 .47815 .40932 .46851 Mtetra
.589 .719 .933 r
.40932 .46851 .41843 .47815 .43383 .47546 .42477 .46579 Mtetra
.618 .729 .926 r
.42477 .46579 .43383 .47546 .44937 .47154 .44035 .46211 Mtetra
.648 .746 .921 r
.44035 .46211 .44937 .47154 .46502 .46684 .45606 .45732 Mtetra
.645 .744 .922 r
.45606 .45732 .46502 .46684 .48076 .46223 .47186 .45263 Mtetra
.647 .744 .92 r
.47186 .45263 .48076 .46223 .4966 .4575 .48775 .44783 Mtetra
.651 .746 .919 r
.48775 .44783 .4966 .4575 .51254 .45249 .50375 .44283 Mtetra
.656 .749 .918 r
.50375 .44283 .51254 .45249 .52857 .44733 .51984 .43761 Mtetra
.661 .75 .916 r
.51984 .43761 .52857 .44733 .54469 .44203 .53602 .43219 Mtetra
.665 .75 .914 r
.53602 .43219 .54469 .44203 .56091 .43644 .5523 .42656 Mtetra
.667 .751 .913 r
.5523 .42656 .56091 .43644 .57721 .43073 .56867 .42082 Mtetra
.664 .751 .915 r
.56867 .42082 .57721 .43073 .59361 .42511 .58514 .41517 Mtetra
.689 .76 .906 r
.58514 .41517 .59361 .42511 .61008 .41868 .60167 .40839 Mtetra
.708 .759 .892 r
.60167 .40839 .61008 .41868 .62661 .41101 .61826 .40063 Mtetra
.688 .753 .901 r
.61826 .40063 .62661 .41101 .64322 .40381 .63496 .39379 Mtetra
.533 .699 .946 r
.63496 .39379 .64322 .40381 .66013 .40177 .65196 .39245 Mtetra
.333 .612 .952 r
.65196 .39245 .66013 .40177 .67741 .40456 .66931 .39548 Mtetra
.346 .628 .957 r
.66931 .39548 .67741 .40456 .6949 .40779 .68683 .39809 Mtetra
.609 .745 .941 r
.68683 .39809 .6949 .40779 .71222 .40448 .70418 .39419 Mtetra
.752 .783 .878 r
.70418 .39419 .71222 .40448 .72924 .39456 .72126 .38376 Mtetra
.761 .777 .866 r
.72126 .38376 .72924 .39456 .74623 .38331 .73834 .37262 Mtetra
.718 .767 .892 r
.73834 .37262 .74623 .38331 .76345 .37454 .75566 .36404 Mtetra
.657 .751 .919 r
.75566 .36404 .76345 .37454 .78099 .36874 .77328 .35827 Mtetra
.657 .753 .92 r
.77328 .35827 .78099 .36874 .79864 .36304 .79101 .35248 Mtetra
.662 .754 .918 r
.79101 .35248 .79864 .36304 .81637 .35708 .80882 .34643 Mtetra
.658 .752 .919 r
.80882 .34643 .81637 .35708 .83423 .35119 .82676 .34051 Mtetra
.649 .749 .922 r
.82676 .34051 .83423 .35119 .85224 .34572 .84485 .33497 Mtetra
.663 .753 .917 r
.20484 .53017 .21475 .53881 .22923 .53385 .21936 .52518 Mtetra
.655 .752 .921 r
.21936 .52518 .22923 .53385 .24374 .52925 .23393 .52047 Mtetra
.648 .748 .923 r
.23393 .52047 .24374 .52925 .25833 .52479 .24857 .51599 Mtetra
.654 .751 .921 r
.24857 .51599 .25833 .52479 .27302 .5201 .2633 .51125 Mtetra
.657 .752 .92 r
.2633 .51125 .27302 .5201 .28779 .51538 .27813 .50639 Mtetra
.583 .727 .942 r
.27813 .50639 .28779 .51538 .30246 .51339 .29287 .50385 Mtetra
.478 .673 .95 r
.29287 .50385 .30246 .51339 .31708 .51389 .30755 .50392 Mtetra
.469 .66 .944 r
.30755 .50392 .31708 .51389 .33187 .51373 .32234 .50433 Mtetra
.667 .747 .91 r
.32234 .50433 .33187 .51373 .34713 .50727 .33759 .49892 Mtetra
.785 .791 .858 r
.33759 .49892 .34713 .50727 .36276 .49445 .35324 .48728 Mtetra
.818 .816 .848 r
.35324 .48728 .36276 .49445 .37844 .48117 .36902 .47353 Mtetra
.769 .808 .884 r
.36902 .47353 .37844 .48117 .39395 .47215 .38466 .46331 Mtetra
.649 .758 .929 r
.38466 .46331 .39395 .47215 .40932 .46851 .40012 .45849 Mtetra
.594 .714 .927 r
.40012 .45849 .40932 .46851 .42477 .46579 .41562 .45562 Mtetra
.605 .716 .923 r
.41562 .45562 .42477 .46579 .44035 .46211 .43124 .45238 Mtetra
.644 .74 .919 r
.43124 .45238 .44035 .46211 .45606 .45732 .447 .44771 Mtetra
.649 .746 .92 r
.447 .44771 .45606 .45732 .47186 .45263 .46286 .4428 Mtetra
.648 .742 .918 r
.46286 .4428 .47186 .45263 .48775 .44783 .47881 .43788 Mtetra
.652 .742 .916 r
.47881 .43788 .48775 .44783 .50375 .44283 .49486 .43281 Mtetra
.656 .743 .914 r
.49486 .43281 .50375 .44283 .51984 .43761 .51102 .42754 Mtetra
.66 .744 .912 r
.51102 .42754 .51984 .43761 .53602 .43219 .52726 .42207 Mtetra
.663 .746 .911 r
.52726 .42207 .53602 .43219 .5523 .42656 .5436 .41644 Mtetra
.663 .747 .913 r
.5436 .41644 .5523 .42656 .56867 .42082 .56004 .41081 Mtetra
.668 .752 .913 r
.56004 .41081 .56867 .42082 .58514 .41517 .57656 .40492 Mtetra
.699 .759 .898 r
.57656 .40492 .58514 .41517 .60167 .40839 .59316 .39758 Mtetra
.705 .75 .887 r
.59316 .39758 .60167 .40839 .61826 .40063 .60982 .38985 Mtetra
.662 .737 .906 r
.60982 .38985 .61826 .40063 .63496 .39379 .62662 .3841 Mtetra
.484 .686 .956 r
.62662 .3841 .63496 .39379 .65196 .39245 .64373 .38387 Mtetra
.281 .605 .953 r
.64373 .38387 .65196 .39245 .66931 .39548 .66115 .38728 Mtetra
.38 .673 .974 r
.66115 .38728 .66931 .39548 .68683 .39809 .67867 .38857 Mtetra
.64 .764 .938 r
.67867 .38857 .68683 .39809 .70418 .39419 .69604 .38346 Mtetra
.76 .779 .868 r
.69604 .38346 .70418 .39419 .72126 .38376 .71316 .37233 Mtetra
.752 .765 .863 r
.71316 .37233 .72126 .38376 .73834 .37262 .73035 .36151 Mtetra
.707 .758 .892 r
.73035 .36151 .73834 .37262 .75566 .36404 .74779 .35339 Mtetra
.655 .749 .919 r
.74779 .35339 .75566 .36404 .77328 .35827 .76549 .34765 Mtetra
.657 .752 .92 r
.76549 .34765 .77328 .35827 .79101 .35248 .78329 .34178 Mtetra
.663 .754 .918 r
.78329 .34178 .79101 .35248 .80882 .34643 .80118 .33564 Mtetra
.657 .751 .919 r
.80118 .33564 .80882 .34643 .82676 .34051 .8192 .32973 Mtetra
.649 .749 .923 r
.8192 .32973 .82676 .34051 .84485 .33497 .83737 .3241 Mtetra
.662 .753 .918 r
.19483 .52145 .20484 .53017 .21936 .52518 .20939 .51644 Mtetra
.657 .753 .92 r
.20939 .51644 .21936 .52518 .23393 .52047 .22402 .51158 Mtetra
.647 .748 .923 r
.22402 .51158 .23393 .52047 .24857 .51599 .2387 .50708 Mtetra
.654 .751 .921 r
.2387 .50708 .24857 .51599 .2633 .51125 .25348 .5023 Mtetra
.658 .752 .919 r
.25348 .5023 .2633 .51125 .27813 .50639 .26836 .49733 Mtetra
.608 .736 .936 r
.26836 .49733 .27813 .50639 .29287 .50385 .28321 .494 Mtetra
.511 .682 .944 r
.28321 .494 .29287 .50385 .30755 .50392 .29796 .49338 Mtetra
.458 .643 .937 r
.29796 .49338 .30755 .50392 .32234 .50433 .31275 .49414 Mtetra
.62 .718 .916 r
.31275 .49414 .32234 .50433 .33759 .49892 .32794 .49047 Mtetra
.755 .788 .88 r
.32794 .49047 .33759 .49892 .35324 .48728 .34356 .48078 Mtetra
.824 .832 .855 r
.34356 .48078 .35324 .48728 .36902 .47353 .35944 .46692 Mtetra
.792 .834 .884 r
.35944 .46692 .36902 .47353 .38466 .46331 .37521 .45549 Mtetra
.705 .799 .923 r
.37521 .45549 .38466 .46331 .40012 .45849 .39083 .44843 Mtetra
.609 .721 .925 r
.39083 .44843 .40012 .45849 .41562 .45562 .40639 .44502 Mtetra
.605 .709 .917 r
.40639 .44502 .41562 .45562 .43124 .45238 .42205 .44176 Mtetra
.624 .716 .913 r
.42205 .44176 .43124 .45238 .447 .44771 .43784 .43781 Mtetra
.648 .742 .918 r
.43784 .43781 .447 .44771 .46286 .4428 .45376 .43289 Mtetra
.653 .744 .917 r
.45376 .43289 .46286 .4428 .47881 .43788 .46978 .42775 Mtetra
.653 .74 .914 r
.46978 .42775 .47881 .43788 .49486 .43281 .48589 .42259 Mtetra
.656 .741 .912 r
.48589 .42259 .49486 .43281 .51102 .42754 .5021 .41726 Mtetra
.659 .742 .911 r
.5021 .41726 .51102 .42754 .52726 .42207 .51841 .41177 Mtetra
.659 .743 .912 r
.51841 .41177 .52726 .42207 .5436 .41644 .53481 .40624 Mtetra
.664 .748 .913 r
.53481 .40624 .5436 .41644 .56004 .41081 .55131 .4005 Mtetra
.686 .754 .903 r
.55131 .4005 .56004 .41081 .57656 .40492 .56789 .39377 Mtetra
.697 .742 .886 r
.56789 .39377 .57656 .40492 .59316 .39758 .58454 .38633 Mtetra
.694 .74 .887 r
.58454 .38633 .59316 .39758 .60982 .38985 .60128 .37904 Mtetra
.605 .717 .923 r
.60128 .37904 .60982 .38985 .62662 .3841 .61822 .37545 Mtetra
.409 .678 .971 r
.61822 .37545 .62662 .3841 .64373 .38387 .63543 .37633 Mtetra
.231 .606 .952 r
.63543 .37633 .64373 .38387 .66115 .38728 .65292 .37975 Mtetra
.459 .737 .988 r
.65292 .37975 .66115 .38728 .67867 .38857 .67042 .37892 Mtetra
.687 .78 .922 r
.67042 .37892 .67867 .38857 .69604 .38346 .68776 .3719 Mtetra
.762 .766 .856 r
.68776 .3719 .69604 .38346 .71316 .37233 .70494 .36028 Mtetra
.738 .751 .863 r
.70494 .36028 .71316 .37233 .73035 .36151 .72226 .35007 Mtetra
.691 .748 .895 r
.72226 .35007 .73035 .36151 .74779 .35339 .73982 .34264 Mtetra
.654 .749 .92 r
.73982 .34264 .74779 .35339 .76549 .34765 .7576 .3369 Mtetra
.657 .752 .92 r
.7576 .3369 .76549 .34765 .78329 .34178 .77548 .33096 Mtetra
.664 .754 .918 r
.77548 .33096 .78329 .34178 .80118 .33564 .79345 .32471 Mtetra
.654 .75 .92 r
.79345 .32471 .80118 .33564 .8192 .32973 .81156 .31883 Mtetra
.65 .75 .923 r
.81156 .31883 .8192 .32973 .83737 .3241 .82981 .3131 Mtetra
.661 .753 .918 r
.18471 .51263 .19483 .52145 .20939 .51644 .19932 .50763 Mtetra
.661 .754 .919 r
.19932 .50763 .20939 .51644 .22402 .51158 .214 .50259 Mtetra
.647 .748 .923 r
.214 .50259 .22402 .51158 .2387 .50708 .22873 .49803 Mtetra
.652 .749 .92 r
.22873 .49803 .2387 .50708 .25348 .5023 .24356 .49325 Mtetra
.658 .752 .919 r
.24356 .49325 .25348 .5023 .26836 .49733 .25849 .48824 Mtetra
.636 .746 .928 r
.25849 .48824 .26836 .49733 .28321 .494 .27344 .48398 Mtetra
.539 .692 .938 r
.27344 .48398 .28321 .494 .29796 .49338 .28828 .48266 Mtetra
.47 .647 .936 r
.28828 .48266 .29796 .49338 .31275 .49414 .30311 .48315 Mtetra
.557 .68 .921 r
.30311 .48315 .31275 .49414 .32794 .49047 .31822 .48149 Mtetra
.707 .772 .903 r
.31822 .48149 .32794 .49047 .34356 .48078 .33376 .47426 Mtetra
.808 .835 .871 r
.33376 .47426 .34356 .48078 .35944 .46692 .34966 .46163 Mtetra
.817 .864 .882 r
.34966 .46163 .35944 .46692 .37521 .45549 .36559 .44886 Mtetra
.761 .836 .91 r
.36559 .44886 .37521 .45549 .39083 .44843 .3814 .43927 Mtetra
.657 .759 .925 r
.3814 .43927 .39083 .44843 .40639 .44502 .39708 .43404 Mtetra
.611 .705 .912 r
.39708 .43404 .40639 .44502 .42205 .44176 .41279 .43056 Mtetra
.616 .704 .907 r
.41279 .43056 .42205 .44176 .43784 .43781 .42862 .42685 Mtetra
.628 .714 .908 r
.42862 .42685 .43784 .43781 .45376 .43289 .44457 .42266 Mtetra
.648 .738 .915 r
.44457 .42266 .45376 .43289 .46978 .42775 .46064 .41764 Mtetra
.654 .744 .916 r
.46064 .41764 .46978 .42775 .48589 .42259 .47681 .41239 Mtetra
.656 .744 .914 r
.47681 .41239 .48589 .42259 .5021 .41726 .49308 .407 Mtetra
.659 .744 .913 r
.49308 .407 .5021 .41726 .51841 .41177 .50945 .40148 Mtetra
.664 .747 .912 r
.50945 .40148 .51841 .41177 .53481 .40624 .52592 .39571 Mtetra
.682 .749 .902 r
.52592 .39571 .53481 .40624 .55131 .4005 .54248 .38912 Mtetra
.69 .736 .886 r
.54248 .38912 .55131 .4005 .56789 .39377 .55912 .38202 Mtetra
.693 .731 .88 r
.55912 .38202 .56789 .39377 .58454 .38633 .57584 .37469 Mtetra
.655 .721 .897 r
.57584 .37469 .58454 .38633 .60128 .37904 .59268 .36912 Mtetra
.516 .701 .954 r
.59268 .36912 .60128 .37904 .61822 .37545 .60975 .368 Mtetra
.296 .65 .969 r
.60975 .368 .61822 .37545 .63543 .37633 .62707 .37014 Mtetra
.246 .655 .962 r
.62707 .37014 .63543 .37633 .65292 .37975 .64458 .37218 Mtetra
.568 .789 .982 r
.64458 .37218 .65292 .37975 .67042 .37892 .66205 .36871 Mtetra
.73 .784 .896 r
.66205 .36871 .67042 .37892 .68776 .3719 .67937 .3595 Mtetra
.754 .751 .849 r
.67937 .3595 .68776 .3719 .70494 .36028 .69664 .34804 Mtetra
.727 .746 .867 r
.69664 .34804 .70494 .36028 .72226 .35007 .71407 .33843 Mtetra
.672 .739 .9 r
.71407 .33843 .72226 .35007 .73982 .34264 .73177 .33183 Mtetra
.654 .75 .921 r
.73177 .33183 .73982 .34264 .7576 .3369 .74962 .32602 Mtetra
.659 .752 .919 r
.74962 .32602 .7576 .3369 .77548 .33096 .76758 .31995 Mtetra
.663 .753 .917 r
.76758 .31995 .77548 .33096 .79345 .32471 .78563 .31365 Mtetra
.651 .748 .921 r
.78563 .31365 .79345 .32471 .81156 .31883 .80383 .30783 Mtetra
.651 .751 .923 r
.80383 .30783 .81156 .31883 .82981 .3131 .82216 .30198 Mtetra
.659 .752 .919 r
.17449 .50371 .18471 .51263 .19932 .50763 .18913 .49874 Mtetra
.663 .755 .919 r
.18913 .49874 .19932 .50763 .214 .50259 .20388 .49357 Mtetra
.65 .75 .923 r
.20388 .49357 .214 .50259 .22873 .49803 .21866 .48885 Mtetra
.65 .748 .921 r
.21866 .48885 .22873 .49803 .24356 .49325 .23353 .48411 Mtetra
.655 .751 .92 r
.23353 .48411 .24356 .49325 .25849 .48824 .2485 .47915 Mtetra
.653 .753 .923 r
.2485 .47915 .25849 .48824 .27344 .48398 .26356 .47423 Mtetra
.579 .715 .936 r
.26356 .47423 .27344 .48398 .28828 .48266 .27852 .47172 Mtetra
.506 .66 .93 r
.27852 .47172 .28828 .48266 .30311 .48315 .29343 .47135 Mtetra
.502 .642 .918 r
.29343 .47135 .30311 .48315 .31822 .48149 .30846 .47129 Mtetra
.645 .732 .912 r
.30846 .47129 .31822 .48149 .33376 .47426 .32391 .46654 Mtetra
.757 .81 .895 r
.32391 .46654 .33376 .47426 .34966 .46163 .33972 .45688 Mtetra
.822 .878 .885 r
.33972 .45688 .34966 .46163 .36559 .44886 .35576 .44385 Mtetra
.795 .877 .907 r
.35576 .44385 .36559 .44886 .3814 .43927 .37174 .43255 Mtetra
.737 .836 .926 r
.37174 .43255 .3814 .43927 .39708 .43404 .38763 .42403 Mtetra
.648 .741 .917 r
.38763 .42403 .39708 .43404 .41279 .43056 .40345 .41906 Mtetra
.621 .702 .903 r
.40345 .41906 .41279 .43056 .42862 .42685 .41933 .41512 Mtetra
.628 .701 .898 r
.41933 .41512 .42862 .42685 .44457 .42266 .43532 .4109 Mtetra
.636 .705 .896 r
.43532 .4109 .44457 .42266 .46064 .41764 .45143 .40632 Mtetra
.646 .718 .9 r
.45143 .40632 .46064 .41764 .47681 .41239 .46765 .4013 Mtetra
.656 .727 .902 r
.46765 .4013 .47681 .41239 .49308 .407 .48398 .39585 Mtetra
.665 .731 .898 r
.48398 .39585 .49308 .407 .50945 .40148 .50041 .38997 Mtetra
.673 .728 .89 r
.50041 .38997 .50945 .40148 .52592 .39571 .51694 .38364 Mtetra
.679 .72 .88 r
.51694 .38364 .52592 .39571 .54248 .38912 .53355 .37695 Mtetra
.684 .721 .878 r
.53355 .37695 .54248 .38912 .55912 .38202 .55025 .36996 Mtetra
.663 .717 .889 r
.55025 .36996 .55912 .38202 .57584 .37469 .56706 .36401 Mtetra
.563 .706 .937 r
.56706 .36401 .57584 .37469 .59268 .36912 .58403 .36167 Mtetra
.383 .702 .984 r
.58403 .36167 .59268 .36912 .60975 .368 .60121 .36217 Mtetra
.204 .64 .949 r
.60121 .36217 .60975 .368 .62707 .37014 .61861 .36448 Mtetra
.407 .765 .995 r
.61861 .36448 .62707 .37014 .64458 .37218 .63609 .36337 Mtetra
.662 .795 .946 r
.63609 .36337 .64458 .37218 .66205 .36871 .65353 .35722 Mtetra
.753 .768 .865 r
.65353 .35722 .66205 .36871 .67937 .3595 .67085 .34625 Mtetra
.738 .734 .847 r
.67085 .34625 .67937 .3595 .69664 .34804 .68824 .33554 Mtetra
.706 .737 .875 r
.68824 .33554 .69664 .34804 .71407 .33843 .70581 .32703 Mtetra
.658 .741 .911 r
.70581 .32703 .71407 .33843 .73177 .33183 .72363 .32101 Mtetra
.656 .754 .922 r
.72363 .32101 .73177 .33183 .74962 .32602 .74156 .31501 Mtetra
.661 .753 .918 r
.74156 .31501 .74962 .32602 .76758 .31995 .75958 .30878 Mtetra
.661 .751 .917 r
.75958 .30878 .76758 .31995 .78563 .31365 .77772 .30252 Mtetra
.649 .748 .922 r
.77772 .30252 .78563 .31365 .80383 .30783 .79601 .29672 Mtetra
.653 .752 .922 r
.79601 .29672 .80383 .30783 .82216 .30198 .81441 .29071 Mtetra
.656 .751 .92 r
.16416 .49468 .17449 .50371 .18913 .49874 .17884 .48974 Mtetra
.663 .755 .918 r
.17884 .48974 .18913 .49874 .20388 .49357 .19364 .48452 Mtetra
.655 .753 .922 r
.19364 .48452 .20388 .49357 .21866 .48885 .20849 .47956 Mtetra
.647 .747 .922 r
.20849 .47956 .21866 .48885 .23353 .48411 .2234 .47485 Mtetra
.654 .75 .921 r
.2234 .47485 .23353 .48411 .2485 .47915 .23842 .46988 Mtetra
.659 .752 .919 r
.23842 .46988 .2485 .47915 .26356 .47423 .25354 .46471 Mtetra
.623 .738 .929 r
.25354 .46471 .26356 .47423 .27852 .47172 .26865 .46075 Mtetra
.547 .679 .926 r
.26865 .46075 .27852 .47172 .29343 .47135 .28367 .45926 Mtetra
.499 .636 .915 r
.28367 .45926 .29343 .47135 .30846 .47129 .29872 .45928 Mtetra
.562 .666 .907 r
.29872 .45928 .30846 .47129 .32391 .46654 .31401 .45746 Mtetra
.688 .771 .915 r
.31401 .45746 .32391 .46654 .33972 .45688 .32971 .45096 Mtetra
.781 .856 .906 r
.32971 .45096 .33972 .45688 .35576 .44385 .34572 .44025 Mtetra
.814 .909 .905 r
.34572 .44025 .35576 .44385 .37174 .43255 .36185 .42787 Mtetra
.776 .889 .926 r
.36185 .42787 .37174 .43255 .38763 .42403 .37791 .4175 Mtetra
.729 .843 .935 r
.37791 .4175 .38763 .42403 .40345 .41906 .39394 .40922 Mtetra
.666 .754 .916 r
.39394 .40922 .40345 .41906 .41933 .41512 .40994 .40346 Mtetra
.64 .709 .897 r
.40994 .40346 .41933 .41512 .43532 .4109 .42599 .39867 Mtetra
.638 .699 .889 r
.42599 .39867 .43532 .4109 .45143 .40632 .44215 .39393 Mtetra
.645 .7 .886 r
.44215 .39393 .45143 .40632 .46765 .4013 .45842 .38887 Mtetra
.654 .703 .883 r
.45842 .38887 .46765 .4013 .48398 .39585 .4748 .38336 Mtetra
.663 .707 .88 r
.4748 .38336 .48398 .39585 .50041 .38997 .49129 .37739 Mtetra
.669 .709 .877 r
.49129 .37739 .50041 .38997 .51694 .38364 .50787 .3711 Mtetra
.668 .71 .879 r
.50787 .3711 .51694 .38364 .53355 .37695 .52454 .36485 Mtetra
.647 .711 .894 r
.52454 .36485 .53355 .37695 .55025 .36996 .54131 .35958 Mtetra
.572 .718 .941 r
.54131 .35958 .55025 .36996 .56706 .36401 .55822 .35686 Mtetra
.428 .735 .991 r
.55822 .35686 .56706 .36401 .58403 .36167 .5753 .35629 Mtetra
.229 .669 .955 r
.5753 .35629 .58403 .36167 .60121 .36217 .59258 .35778 Mtetra
.29 .731 .964 r
.59258 .35778 .60121 .36217 .61861 .36448 .61 .3576 Mtetra
.591 .82 .987 r
.61 .3576 .61861 .36448 .63609 .36337 .62746 .35315 Mtetra
.73 .787 .898 r
.62746 .35315 .63609 .36337 .65353 .35722 .64486 .34386 Mtetra
.744 .735 .843 r
.64486 .34386 .65353 .35722 .67085 .34625 .66224 .33266 Mtetra
.72 .724 .853 r
.66224 .33266 .67085 .34625 .68824 .33554 .67976 .323 Mtetra
.679 .728 .887 r
.67976 .323 .68824 .33554 .70581 .32703 .69749 .31586 Mtetra
.653 .746 .918 r
.69749 .31586 .70581 .32703 .72363 .32101 .71539 .30997 Mtetra
.657 .752 .92 r
.71539 .30997 .72363 .32101 .74156 .31501 .73339 .30387 Mtetra
.663 .754 .918 r
.73339 .30387 .74156 .31501 .75958 .30878 .75149 .29747 Mtetra
.656 .749 .918 r
.75149 .29747 .75958 .30878 .77772 .30252 .76973 .29134 Mtetra
.649 .75 .923 r
.76973 .29134 .77772 .30252 .79601 .29672 .7881 .28547 Mtetra
.655 .753 .922 r
.7881 .28547 .79601 .29672 .81441 .29071 .80658 .27929 Mtetra
.654 .75 .92 r
.15372 .48553 .16416 .49468 .17884 .48974 .16845 .4806 Mtetra
.661 .753 .919 r
.16845 .4806 .17884 .48974 .19364 .48452 .18328 .47542 Mtetra
.661 .755 .92 r
.18328 .47542 .19364 .48452 .20849 .47956 .1982 .47019 Mtetra
.648 .747 .922 r
.1982 .47019 .20849 .47956 .2234 .47485 .21316 .46541 Mtetra
.651 .748 .92 r
.21316 .46541 .2234 .47485 .23842 .46988 .22822 .46048 Mtetra
.656 .751 .92 r
.22822 .46048 .23842 .46988 .25354 .46471 .24339 .45535 Mtetra
.653 .752 .923 r
.24339 .45535 .25354 .46471 .26865 .46075 .25863 .45032 Mtetra
.591 .71 .926 r
.25863 .45032 .26865 .46075 .28367 .45926 .2738 .44738 Mtetra
.538 .66 .915 r
.2738 .44738 .28367 .45926 .29872 .45928 .28895 .4462 Mtetra
.517 .628 .9 r
.28895 .4462 .29872 .45928 .31401 .45746 .30418 .44585 Mtetra
.601 .693 .907 r
.30418 .44585 .31401 .45746 .32971 .45096 .31972 .44262 Mtetra
.699 .794 .924 r
.31972 .44262 .32971 .45096 .34572 .44025 .33559 .43559 Mtetra
.776 .889 .926 r
.33559 .43559 .34572 .44025 .36185 .42787 .35171 .42517 Mtetra
.793 .934 .924 r
.35171 .42517 .36185 .42787 .37791 .4175 .36794 .41372 Mtetra
.763 .913 .94 r
.36794 .41372 .37791 .4175 .39394 .40922 .38413 .40372 Mtetra
.726 .872 .949 r
.38413 .40372 .39394 .40922 .40994 .40346 .40031 .3954 Mtetra
.696 .806 .933 r
.40031 .3954 .40994 .40346 .42599 .39867 .41651 .38834 Mtetra
.667 .749 .911 r
.41651 .38834 .42599 .39867 .44215 .39393 .43276 .38238 Mtetra
.656 .722 .897 r
.43276 .38238 .44215 .39393 .45842 .38887 .44909 .37683 Mtetra
.655 .713 .891 r
.44909 .37683 .45842 .38887 .4748 .38336 .46553 .37125 Mtetra
.46553 .37125 .4748 .38336 .49129 .37739 .48206 .36565 Mtetra
.645 .718 .901 r
.48206 .36565 .49129 .37739 .50787 .3711 .49869 .36045 Mtetra
.614 .73 .928 r
.49869 .36045 .50787 .3711 .52454 .36485 .51542 .35638 Mtetra
.555 .759 .973 r
.51542 .35638 .52454 .36485 .54131 .35958 .53228 .35357 Mtetra
.416 .761 .995 r
.53228 .35357 .54131 .35958 .55822 .35686 .54928 .35248 Mtetra
.245 .704 .951 r
.54928 .35248 .55822 .35686 .5753 .35629 .56646 .3529 Mtetra
.261 .734 .939 r
.56646 .3529 .5753 .35629 .59258 .35778 .5838 .35229 Mtetra
.546 .838 .999 r
.5838 .35229 .59258 .35778 .61 .3576 .60121 .34825 Mtetra
.704 .799 .924 r
.60121 .34825 .61 .3576 .62746 .35315 .61865 .3403 Mtetra
.743 .744 .852 r
.61865 .3403 .62746 .35315 .64486 .34386 .63606 .32939 Mtetra
.722 .712 .84 r
.63606 .32939 .64486 .34386 .66224 .33266 .65357 .31929 Mtetra
.698 .722 .868 r
.65357 .31929 .66224 .33266 .67976 .323 .67122 .31098 Mtetra
.658 .732 .904 r
.67122 .31098 .67976 .323 .69749 .31586 .68907 .30483 Mtetra
.656 .753 .921 r
.68907 .30483 .69749 .31586 .71539 .30997 .70705 .29877 Mtetra
.66 .752 .919 r
.70705 .29877 .71539 .30997 .73339 .30387 .72512 .29249 Mtetra
.663 .751 .916 r
.72512 .29249 .73339 .30387 .75149 .29747 .74331 .28605 Mtetra
.651 .747 .92 r
.74331 .28605 .75149 .29747 .76973 .29134 .76164 .28006 Mtetra
.651 .752 .923 r
.76164 .28006 .76973 .29134 .7881 .28547 .78009 .27403 Mtetra
.657 .753 .92 r
.78009 .27403 .7881 .28547 .80658 .27929 .79864 .26771 Mtetra
.652 .748 .92 r
.14318 .47624 .15372 .48553 .16845 .4806 .15794 .47135 Mtetra
.657 .752 .92 r
.15794 .47135 .16845 .4806 .18328 .47542 .17282 .46623 Mtetra
.663 .756 .919 r
.17282 .46623 .18328 .47542 .1982 .47019 .1878 .46087 Mtetra
.654 .752 .922 r
.1878 .46087 .1982 .47019 .21316 .46541 .20283 .45582 Mtetra
.648 .746 .921 r
.20283 .45582 .21316 .46541 .22822 .46048 .21792 .45096 Mtetra
.654 .75 .92 r
.21792 .45096 .22822 .46048 .24339 .45535 .23313 .44584 Mtetra
.658 .753 .92 r
.23313 .44584 .24339 .45535 .25863 .45032 .24845 .44054 Mtetra
.641 .743 .923 r
.24845 .44054 .25863 .45032 .2738 .44738 .2638 .43583 Mtetra
.576 .684 .914 r
.2638 .43583 .2738 .44738 .28895 .4462 .27907 .43341 Mtetra
.541 .646 .903 r
.27907 .43341 .28895 .4462 .30418 .44585 .29438 .43223 Mtetra
.539 .631 .891 r
.29438 .43223 .30418 .44585 .31972 .44262 .3098 .43122 Mtetra
.612 .705 .91 r
.3098 .43122 .31972 .44262 .33559 .43559 .32552 .42749 Mtetra
.689 .801 .934 r
.32552 .42749 .33559 .43559 .35171 .42517 .34151 .42076 Mtetra
.742 .898 .948 r
.34151 .42076 .35171 .42517 .36794 .41372 .35772 .41165 Mtetra
.753 .95 .942 r
.35772 .41165 .36794 .41372 .38413 .40372 .37403 .4014 Mtetra
.737 .945 .95 r
.37403 .4014 .38413 .40372 .40031 .3954 .39037 .39172 Mtetra
.708 .915 .966 r
.39037 .39172 .40031 .3954 .41651 .38834 .40671 .38345 Mtetra
.683 .884 .973 r
.40671 .38345 .41651 .38834 .43276 .38238 .42309 .37627 Mtetra
.664 .851 .971 r
.42309 .37627 .43276 .38238 .44909 .37683 .43953 .36992 Mtetra
.645 .828 .97 r
.43953 .36992 .44909 .37683 .46553 .37125 .45604 .36428 Mtetra
.619 .82 .978 r
.45604 .36428 .46553 .37125 .48206 .36565 .47265 .35936 Mtetra
.575 .823 .992 r
.47265 .35936 .48206 .36565 .49869 .36045 .48935 .35528 Mtetra
.493 .819 1 r
.48935 .35528 .49869 .36045 .51542 .35638 .50616 .35231 Mtetra
.362 .78 .977 r
.50616 .35231 .51542 .35638 .53228 .35357 .52311 .35077 Mtetra
.249 .737 .923 r
.52311 .35077 .53228 .35357 .54928 .35248 .54022 .34984 Mtetra
.32 .784 .94 r
.54022 .34984 .54928 .35248 .56646 .3529 .55747 .34777 Mtetra
.556 .852 .998 r
.55747 .34777 .56646 .3529 .5838 .35229 .57483 .34329 Mtetra
.694 .805 .934 r
.57483 .34329 .5838 .35229 .60121 .34825 .59225 .33574 Mtetra
.736 .748 .862 r
.59225 .33574 .60121 .34825 .61865 .3403 .60969 .32539 Mtetra
.721 .706 .836 r
.60969 .32539 .61865 .3403 .63606 .32939 .6272 .31519 Mtetra
.705 .712 .854 r
.6272 .31519 .63606 .32939 .65357 .31929 .64482 .30623 Mtetra
.666 .717 .887 r
.64482 .30623 .65357 .31929 .67122 .31098 .66262 .29962 Mtetra
.653 .746 .918 r
.66262 .29962 .67122 .31098 .68907 .30483 .68056 .29362 Mtetra
.657 .753 .92 r
.68056 .29362 .68907 .30483 .70705 .29877 .69861 .28742 Mtetra
.663 .753 .918 r
.69861 .28742 .70705 .29877 .72512 .29249 .71676 .28094 Mtetra
.657 .748 .917 r
.71676 .28094 .72512 .29249 .74331 .28605 .73504 .27465 Mtetra
.649 .75 .923 r
.73504 .27465 .74331 .28605 .76164 .28006 .75346 .26867 Mtetra
.654 .754 .923 r
.75346 .26867 .76164 .28006 .78009 .27403 .77198 .26243 Mtetra
.659 .753 .919 r
.77198 .26243 .78009 .27403 .79864 .26771 .79061 .25594 Mtetra
.65 .748 .921 r
.13253 .46683 .14318 .47624 .15794 .47135 .14733 .46196 Mtetra
.655 .751 .92 r
.14733 .46196 .15794 .47135 .17282 .46623 .16224 .45687 Mtetra
.661 .754 .919 r
.16224 .45687 .17282 .46623 .1878 .46087 .17726 .45155 Mtetra
.661 .756 .92 r
.17726 .45155 .1878 .46087 .20283 .45582 .19237 .44617 Mtetra
.649 .747 .921 r
.19237 .44617 .20283 .45582 .21792 .45096 .20753 .44121 Mtetra
.651 .746 .92 r
.20753 .44121 .21792 .45096 .23313 .44584 .22277 .43617 Mtetra
.654 .75 .92 r
.22277 .43617 .23313 .44584 .24845 .44054 .23813 .43096 Mtetra
.659 .755 .921 r
.23813 .43096 .24845 .44054 .2638 .43583 .25359 .42556 Mtetra
.631 .733 .921 r
.25359 .42556 .2638 .43583 .27907 .43341 .26905 .42115 Mtetra
.58 .675 .905 r
.26905 .42115 .27907 .43341 .29438 .43223 .28448 .4186 Mtetra
.555 .64 .89 r
.28448 .4186 .29438 .43223 .3098 .43122 .29996 .417 Mtetra
.553 .63 .882 r
.29996 .417 .3098 .43122 .32552 .42749 .31557 .4155 Mtetra
.602 .693 .907 r
.31557 .4155 .32552 .42749 .34151 .42076 .33142 .41207 Mtetra
.666 .785 .938 r
.33142 .41207 .34151 .42076 .35772 .41165 .34752 .40615 Mtetra
.691 .869 .965 r
.34752 .40615 .35772 .41165 .37403 .4014 .36378 .39891 Mtetra
.694 .937 .964 r
.36378 .39891 .37403 .4014 .39037 .39172 .38017 .39051 Mtetra
.661 .951 .952 r
.38017 .39051 .39037 .39172 .40671 .38345 .39663 .38213 Mtetra
.626 .941 .956 r
.39663 .38213 .40671 .38345 .42309 .37627 .41313 .37448 Mtetra
.591 .924 .965 r
.41313 .37448 .42309 .37627 .43953 .36992 .42969 .36779 Mtetra
.545 .902 .97 r
.42969 .36779 .43953 .36992 .45604 .36428 .44631 .3621 Mtetra
.484 .876 .966 r
.44631 .3621 .45604 .36428 .47265 .35936 .46301 .35742 Mtetra
.406 .841 .946 r
.46301 .35742 .47265 .35936 .48935 .35528 .47982 .3537 Mtetra
.329 .803 .915 r
.47982 .3537 .48935 .35528 .50616 .35231 .49674 .35073 Mtetra
.323 .799 .912 r
.49674 .35073 .50616 .35231 .52311 .35077 .5138 .3478 Mtetra
.467 .858 .976 r
.5138 .3478 .52311 .35077 .54022 .34984 .53099 .3437 Mtetra
.614 .849 .988 r
.53099 .3437 .54022 .34984 .55747 .34777 .5483 .33826 Mtetra
.704 .797 .923 r
.5483 .33826 .55747 .34777 .57483 .34329 .5657 .33029 Mtetra
.727 .738 .86 r
.5657 .33029 .57483 .34329 .59225 .33574 .58314 .32033 Mtetra
.713 .697 .833 r
.58314 .32033 .59225 .33574 .60969 .32539 .60065 .31044 Mtetra
.701 .7 .846 r
.60065 .31044 .60969 .32539 .6272 .31519 .61827 .30151 Mtetra
.672 .71 .876 r
.61827 .30151 .6272 .31519 .64482 .30623 .63602 .29447 Mtetra
.653 .739 .913 r
.63602 .29447 .64482 .30623 .66262 .29962 .65393 .28845 Mtetra
.657 .755 .922 r
.65393 .28845 .66262 .29962 .68056 .29362 .67194 .28222 Mtetra
.66 .753 .918 r
.67194 .28222 .68056 .29362 .69861 .28742 .69006 .2758 Mtetra
.662 .75 .916 r
.69006 .2758 .69861 .28742 .71676 .28094 .7083 .26929 Mtetra
.651 .746 .92 r
.7083 .26929 .71676 .28094 .73504 .27465 .72667 .26321 Mtetra
.651 .753 .924 r
.72667 .26321 .73504 .27465 .75346 .26867 .74517 .25706 Mtetra
.656 .753 .921 r
.74517 .25706 .75346 .26867 .77198 .26243 .76377 .25066 Mtetra
.661 .753 .918 r
.76377 .25066 .77198 .26243 .79061 .25594 .78248 .24402 Mtetra
.651 .749 .921 r
.12176 .45735 .13253 .46683 .14733 .46196 .13662 .45238 Mtetra
.652 .748 .92 r
.13662 .45238 .14733 .46196 .16224 .45687 .15156 .44736 Mtetra
.657 .752 .92 r
.15156 .44736 .16224 .45687 .17726 .45155 .16662 .44212 Mtetra
.662 .756 .92 r
.16662 .44212 .17726 .45155 .19237 .44617 .18178 .43665 Mtetra
.657 .754 .921 r
.18178 .43665 .19237 .44617 .20753 .44121 .19702 .43134 Mtetra
.648 .745 .92 r
.19702 .43134 .20753 .44121 .22277 .43617 .21231 .42632 Mtetra
.653 .748 .92 r
.21231 .42632 .22277 .43617 .23813 .43096 .22771 .42112 Mtetra
.655 .75 .92 r
.22771 .42112 .23813 .43096 .25359 .42556 .24321 .41581 Mtetra
.658 .754 .921 r
.24321 .41581 .25359 .42556 .26905 .42115 .25881 .41033 Mtetra
.632 .725 .915 r
.25881 .41033 .26905 .42115 .28448 .4186 .27443 .40581 Mtetra
.59 .673 .897 r
.27443 .40581 .28448 .4186 .29996 .417 .29004 .40284 Mtetra
.575 .643 .881 r
.29004 .40284 .29996 .417 .31557 .4155 .30572 .4005 Mtetra
.565 .626 .871 r
.30572 .4005 .31557 .4155 .33142 .41207 .3215 .39853 Mtetra
.589 .662 .889 r
.3215 .39853 .33142 .41207 .34752 .40615 .33747 .39559 Mtetra
.632 .737 .924 r
.33747 .39559 .34752 .40615 .36378 .39891 .35365 .39088 Mtetra
.659 .804 .952 r
.35365 .39088 .36378 .39891 .38017 .39051 .37 .38499 Mtetra
.657 .865 .978 r
.37 .38499 .38017 .39051 .39663 .38213 .38647 .37862 Mtetra
.625 .904 .985 r
.38647 .37862 .39663 .38213 .41313 .37448 .40303 .3722 Mtetra
.576 .911 .974 r
.40303 .3722 .41313 .37448 .42969 .36779 .41967 .36604 Mtetra
.529 .902 .961 r
.41967 .36604 .42969 .36779 .44631 .3621 .4364 .36029 Mtetra
.502 .89 .958 r
.4364 .36029 .44631 .3621 .46301 .35742 .45323 .35497 Mtetra
.51 .885 .972 r
.45323 .35497 .46301 .35742 .47982 .3537 .47016 .34991 Mtetra
.555 .88 .991 r
.47016 .34991 .47982 .3537 .49674 .35073 .4872 .3448 Mtetra
.618 .855 .988 r
.4872 .3448 .49674 .35073 .5138 .3478 .50436 .33921 Mtetra
.675 .809 .947 r
.50436 .33921 .5138 .3478 .53099 .3437 .52164 .33242 Mtetra
.711 .763 .893 r
.52164 .33242 .53099 .3437 .5483 .33826 .539 .32383 Mtetra
.714 .711 .846 r
.539 .32383 .5483 .33826 .5657 .33029 .55644 .31422 Mtetra
.7 .684 .831 r
.55644 .31422 .5657 .33029 .58314 .32033 .57395 .30498 Mtetra
.694 .692 .844 r
.57395 .30498 .58314 .32033 .60065 .31044 .59156 .29635 Mtetra
.671 .703 .872 r
.59156 .29635 .60065 .31044 .61827 .30151 .60929 .2893 Mtetra
.653 .732 .907 r
.60929 .2893 .61827 .30151 .63602 .29447 .62715 .28323 Mtetra
.657 .754 .922 r
.62715 .28323 .63602 .29447 .65393 .28845 .64513 .27697 Mtetra
.659 .752 .919 r
.64513 .27697 .65393 .28845 .67194 .28222 .66322 .2706 Mtetra
.662 .752 .917 r
.66322 .2706 .67194 .28222 .69006 .2758 .68142 .26403 Mtetra
.655 .747 .918 r
.68142 .26403 .69006 .2758 .7083 .26929 .69975 .25775 Mtetra
.65 .751 .924 r
.69975 .25775 .7083 .26929 .72667 .26321 .71821 .25164 Mtetra
.655 .754 .923 r
.71821 .25164 .72667 .26321 .74517 .25706 .73678 .24526 Mtetra
.659 .753 .919 r
.73678 .24526 .74517 .25706 .76377 .25066 .75546 .23866 Mtetra
.66 .751 .917 r
.75546 .23866 .76377 .25066 .78248 .24402 .77426 .23199 Mtetra
.656 .753 .921 r
.11086 .44791 .12176 .45735 .13662 .45238 .12578 .4427 Mtetra
.65 .747 .921 r
.12578 .4427 .13662 .45238 .15156 .44736 .14077 .43768 Mtetra
.654 .75 .92 r
.14077 .43768 .15156 .44736 .16662 .44212 .15587 .43249 Mtetra
.659 .753 .92 r
.15587 .43249 .16662 .44212 .18178 .43665 .17107 .42709 Mtetra
.662 .757 .92 r
.17107 .42709 .18178 .43665 .19702 .43134 .18638 .42154 Mtetra
.654 .751 .921 r
.18638 .42154 .19702 .43134 .21231 .42632 .20174 .41625 Mtetra
.649 .745 .92 r
.20174 .41625 .21231 .42632 .22771 .42112 .21718 .41114 Mtetra
.654 .749 .92 r
.21718 .41114 .22771 .42112 .24321 .41581 .23273 .4058 Mtetra
.655 .75 .92 r
.23273 .4058 .24321 .41581 .25881 .41033 .24837 .4004 Mtetra
.659 .754 .921 r
.24837 .4004 .25881 .41033 .27443 .40581 .26413 .39481 Mtetra
.642 .728 .911 r
.26413 .39481 .27443 .40581 .29004 .40284 .27993 .38982 Mtetra
.606 .678 .892 r
.27993 .38982 .29004 .40284 .30572 .4005 .29573 .38621 Mtetra
.595 .653 .877 r
.29573 .38621 .30572 .4005 .3215 .39853 .31161 .38302 Mtetra
.587 .631 .862 r
.31161 .38302 .3215 .39853 .33747 .39559 .3276 .38015 Mtetra
.592 .635 .863 r
.3276 .38015 .33747 .39559 .35365 .39088 .34372 .37705 Mtetra
.609 .67 .883 r
.34372 .37705 .35365 .39088 .37 .38499 .36001 .37321 Mtetra
.626 .716 .911 r
.36001 .37321 .37 .38499 .38647 .37862 .37645 .36863 Mtetra
.644 .76 .933 r
.37645 .36863 .38647 .37862 .40303 .3722 .39303 .36329 Mtetra
.65 .788 .948 r
.39303 .36329 .40303 .3722 .41967 .36604 .40973 .35761 Mtetra
.651 .801 .955 r
.40973 .35761 .41967 .36604 .4364 .36029 .42653 .3518 Mtetra
.653 .801 .954 r
.42653 .3518 .4364 .36029 .45323 .35497 .44345 .34587 Mtetra
.664 .792 .943 r
.44345 .34587 .45323 .35497 .47016 .34991 .46048 .33959 Mtetra
.682 .772 .919 r
.46048 .33959 .47016 .34991 .4872 .3448 .47762 .33255 Mtetra
.693 .739 .886 r
.47762 .33255 .4872 .3448 .50436 .33921 .49486 .32475 Mtetra
.697 .704 .853 r
.49486 .32475 .50436 .33921 .52164 .33242 .5122 .31618 Mtetra
.693 .678 .831 r
.5122 .31618 .52164 .33242 .539 .32383 .52961 .30737 Mtetra
.687 .674 .832 r
.52961 .30737 .539 .32383 .55644 .31422 .54711 .29886 Mtetra
.685 .689 .848 r
.54711 .29886 .55644 .31422 .57395 .30498 .5647 .29076 Mtetra
.663 .7 .874 r
.5647 .29076 .57395 .30498 .59156 .29635 .58241 .28407 Mtetra
.653 .731 .907 r
.58241 .28407 .59156 .29635 .60929 .2893 .60023 .27798 Mtetra
.657 .754 .921 r
.60023 .27798 .60929 .2893 .62715 .28323 .61817 .27169 Mtetra
.658 .751 .919 r
.61817 .27169 .62715 .28323 .64513 .27697 .63623 .26533 Mtetra
.662 .752 .917 r
.63623 .26533 .64513 .27697 .66322 .2706 .65439 .25873 Mtetra
.657 .747 .916 r
.65439 .25873 .66322 .2706 .68142 .26403 .67268 .2523 Mtetra
.65 .749 .922 r
.67268 .2523 .68142 .26403 .69975 .25775 .6911 .24614 Mtetra
.653 .754 .924 r
.6911 .24614 .69975 .25775 .71821 .25164 .70964 .2398 Mtetra
.657 .753 .92 r
.70964 .2398 .71821 .25164 .73678 .24526 .72829 .23325 Mtetra
.661 .752 .918 r
.72829 .23325 .73678 .24526 .75546 .23866 .74705 .22651 Mtetra
.655 .749 .918 r
.74705 .22651 .75546 .23866 .77426 .23199 .76595 .21994 Mtetra
.66 .755 .92 r
.09983 .4384 .11086 .44791 .12578 .4427 .11482 .433 Mtetra
.653 .75 .921 r
.11482 .433 .12578 .4427 .14077 .43768 .12987 .42781 Mtetra
.651 .747 .92 r
.12987 .42781 .14077 .43768 .15587 .43249 .145 .42268 Mtetra
.655 .751 .92 r
.145 .42268 .15587 .43249 .17107 .42709 .16025 .41735 Mtetra
.66 .755 .92 r
.16025 .41735 .17107 .42709 .18638 .42154 .17559 .41183 Mtetra
.661 .757 .921 r
.17559 .41183 .18638 .42154 .20174 .41625 .19104 .4062 Mtetra
.653 .749 .92 r
.19104 .4062 .20174 .41625 .21718 .41114 .20655 .40087 Mtetra
.649 .744 .919 r
.20655 .40087 .21718 .41114 .23273 .4058 .22213 .39564 Mtetra
.654 .749 .92 r
.22213 .39564 .23273 .4058 .24837 .4004 .23783 .39021 Mtetra
.655 .75 .92 r
.23783 .39021 .24837 .4004 .26413 .39481 .25363 .38472 Mtetra
.659 .755 .921 r
.25363 .38472 .26413 .39481 .27993 .38982 .26954 .37902 Mtetra
.651 .739 .914 r
.26954 .37902 .27993 .38982 .29573 .38621 .28552 .37361 Mtetra
.63 .698 .894 r
.28552 .37361 .29573 .38621 .31161 .38302 .30154 .36893 Mtetra
.614 .667 .878 r
.30154 .36893 .31161 .38302 .3276 .38015 .31763 .36489 Mtetra
.611 .648 .863 r
.31763 .36489 .3276 .38015 .34372 .37705 .33383 .36089 Mtetra
.613 .637 .851 r
.33383 .36089 .34372 .37705 .36001 .37321 .35016 .35675 Mtetra
.614 .634 .847 r
.35016 .35675 .36001 .37321 .37645 .36863 .3666 .3525 Mtetra
.625 .645 .85 r
.3666 .3525 .37645 .36863 .39303 .36329 .38319 .34773 Mtetra
.637 .659 .855 r
.38319 .34773 .39303 .36329 .40973 .35761 .39991 .3424 Mtetra
.648 .67 .858 r
.39991 .3424 .40973 .35761 .42653 .3518 .41676 .33652 Mtetra
.658 .674 .854 r
.41676 .33652 .42653 .3518 .44345 .34587 .43373 .33009 Mtetra
.666 .671 .845 r
.43373 .33009 .44345 .34587 .46048 .33959 .45082 .3231 Mtetra
.672 .665 .835 r
.45082 .3231 .46048 .33959 .47762 .33255 .46801 .31556 Mtetra
.672 .659 .83 r
.46801 .31556 .47762 .33255 .49486 .32475 .48529 .30792 Mtetra
.674 .664 .832 r
.48529 .30792 .49486 .32475 .5122 .31618 .50267 .30011 Mtetra
.676 .676 .842 r
.50267 .30011 .5122 .31618 .52961 .30737 .52014 .29234 Mtetra
.669 .689 .86 r
.52014 .29234 .52961 .30737 .54711 .29886 .5377 .2852 Mtetra
.657 .708 .885 r
.5377 .2852 .54711 .29886 .5647 .29076 .55538 .27881 Mtetra
.653 .739 .913 r
.55538 .27881 .5647 .29076 .58241 .28407 .57317 .2727 Mtetra
.657 .754 .922 r
.57317 .2727 .58241 .28407 .60023 .27798 .59107 .26638 Mtetra
.658 .751 .919 r
.59107 .26638 .60023 .27798 .61817 .27169 .60909 .25998 Mtetra
.662 .752 .917 r
.60909 .25998 .61817 .27169 .63623 .26533 .62721 .25336 Mtetra
.658 .747 .916 r
.62721 .25336 .63623 .26533 .65439 .25873 .64546 .24686 Mtetra
.651 .747 .921 r
.64546 .24686 .65439 .25873 .67268 .2523 .66384 .24064 Mtetra
.652 .754 .924 r
.66384 .24064 .67268 .2523 .6911 .24614 .68234 .23431 Mtetra
.656 .754 .922 r
.68234 .23431 .6911 .24614 .70964 .2398 .70096 .22776 Mtetra
.66 .753 .919 r
.70096 .22776 .70964 .2398 .72829 .23325 .71968 .22101 Mtetra
.658 .749 .917 r
.71968 .22101 .72829 .23325 .74705 .22651 .73854 .2143 Mtetra
.652 .749 .921 r
.73854 .2143 .74705 .22651 .76595 .21994 .75753 .2078 Mtetra
.659 .754 .92 r
.08869 .42876 .09983 .4384 .11482 .433 .10373 .42332 Mtetra
.10373 .42332 .11482 .433 .12987 .42781 .11885 .41787 Mtetra
.651 .748 .92 r
.11885 .41787 .12987 .42781 .145 .42268 .13404 .41266 Mtetra
.652 .748 .92 r
.13404 .41266 .145 .42268 .16025 .41735 .14931 .4074 Mtetra
.656 .751 .92 r
.14931 .4074 .16025 .41735 .17559 .41183 .1647 .40196 Mtetra
.66 .756 .921 r
.1647 .40196 .17559 .41183 .19104 .4062 .18019 .39633 Mtetra
.661 .757 .921 r
.18019 .39633 .19104 .4062 .20655 .40087 .19578 .39063 Mtetra
.654 .749 .92 r
.19578 .39063 .20655 .40087 .22213 .39564 .21144 .38518 Mtetra
.65 .744 .918 r
.21144 .38518 .22213 .39564 .23783 .39021 .22718 .37984 Mtetra
.653 .748 .92 r
.22718 .37984 .23783 .39021 .25363 .38472 .24303 .37435 Mtetra
.655 .75 .92 r
.24303 .37435 .25363 .38472 .26954 .37902 .25898 .36875 Mtetra
.657 .754 .922 r
.25898 .36875 .26954 .37902 .28552 .37361 .27503 .36305 Mtetra
.658 .749 .918 r
.27503 .36305 .28552 .37361 .30154 .36893 .29119 .35727 Mtetra
.65 .726 .905 r
.29119 .35727 .30154 .36893 .31763 .36489 .30743 .35172 Mtetra
.64 .696 .886 r
.30743 .35172 .31763 .36489 .33383 .36089 .32374 .34648 Mtetra
.63 .673 .872 r
.32374 .34648 .33383 .36089 .35016 .35675 .34015 .34159 Mtetra
.631 .662 .862 r
.34015 .34159 .35016 .35675 .3666 .3525 .35666 .33659 Mtetra
.634 .653 .852 r
.35666 .33659 .3666 .3525 .38319 .34773 .37331 .33134 Mtetra
.639 .65 .845 r
.37331 .33134 .38319 .34773 .39991 .3424 .39007 .32575 Mtetra
.644 .65 .841 r
.39007 .32575 .39991 .3424 .41676 .33652 .40696 .3198 Mtetra
.65 .653 .839 r
.40696 .3198 .41676 .33652 .43373 .33009 .42396 .31347 Mtetra
.656 .657 .839 r
.42396 .31347 .43373 .33009 .45082 .3231 .44108 .30681 Mtetra
.661 .665 .843 r
.44108 .30681 .45082 .3231 .46801 .31556 .4583 .29989 Mtetra
.665 .677 .851 r
.4583 .29989 .46801 .31556 .48529 .30792 .47562 .29285 Mtetra
.66 .685 .862 r
.47562 .29285 .48529 .30792 .50267 .30011 .49304 .28615 Mtetra
.657 .702 .881 r
.49304 .28615 .50267 .30011 .52014 .29234 .51057 .27976 Mtetra
.653 .727 .903 r
.51057 .27976 .52014 .29234 .5377 .2852 .5282 .27361 Mtetra
.655 .749 .919 r
.5282 .27361 .5377 .2852 .55538 .27881 .54595 .26737 Mtetra
.657 .754 .922 r
.54595 .26737 .55538 .27881 .57317 .2727 .56381 .26102 Mtetra
.658 .751 .919 r
.56381 .26102 .57317 .2727 .59107 .26638 .58179 .25456 Mtetra
.661 .751 .917 r
.58179 .25456 .59107 .26638 .60909 .25998 .59988 .24793 Mtetra
.658 .747 .915 r
.59988 .24793 .60909 .25998 .62721 .25336 .61809 .24141 Mtetra
.651 .747 .92 r
.61809 .24141 .62721 .25336 .64546 .24686 .63643 .23513 Mtetra
.652 .754 .924 r
.63643 .23513 .64546 .24686 .66384 .24064 .65489 .22878 Mtetra
.656 .754 .922 r
.65489 .22878 .66384 .24064 .68234 .23431 .67347 .22222 Mtetra
.659 .753 .919 r
.67347 .22222 .68234 .23431 .70096 .22776 .69216 .21546 Mtetra
.66 .75 .917 r
.69216 .21546 .70096 .22776 .71968 .22101 .71097 .20865 Mtetra
.653 .748 .919 r
.71097 .20865 .71968 .22101 .73854 .2143 .72993 .20207 Mtetra
.653 .752 .923 r
.72993 .20207 .73854 .2143 .75753 .2078 .74901 .19547 Mtetra
.657 .752 .92 r
.07743 .41897 .08869 .42876 .10373 .42332 .09251 .41355 Mtetra
.66 .755 .92 r
.09251 .41355 .10373 .42332 .11885 .41787 .10769 .40801 Mtetra
.658 .754 .921 r
.10769 .40801 .11885 .41787 .13404 .41266 .12295 .40251 Mtetra
.651 .747 .92 r
.12295 .40251 .13404 .41266 .14931 .4074 .13827 .39722 Mtetra
.652 .748 .92 r
.13827 .39722 .14931 .4074 .1647 .40196 .1537 .39184 Mtetra
.656 .752 .92 r
.1537 .39184 .1647 .40196 .18019 .39633 .16923 .38631 Mtetra
.66 .756 .921 r
.16923 .38631 .18019 .39633 .19578 .39063 .18487 .3806 Mtetra
.661 .757 .921 r
.18487 .3806 .19578 .39063 .21144 .38518 .20061 .37481 Mtetra
.656 .75 .919 r
.20061 .37481 .21144 .38518 .22718 .37984 .21642 .36919 Mtetra
.651 .744 .918 r
.21642 .36919 .22718 .37984 .24303 .37435 .23232 .36372 Mtetra
.651 .746 .919 r
.23232 .36372 .24303 .37435 .25898 .36875 .24831 .35819 Mtetra
.655 .75 .92 r
.24831 .35819 .25898 .36875 .27503 .36305 .26442 .35249 Mtetra
.655 .751 .921 r
.26442 .35249 .27503 .36305 .29119 .35727 .28063 .34675 Mtetra
.656 .754 .922 r
.28063 .34675 .29119 .35727 .30743 .35172 .29694 .34093 Mtetra
.658 .75 .918 r
.29694 .34093 .30743 .35172 .32374 .34648 .31336 .335 Mtetra
.655 .737 .909 r
.31336 .335 .32374 .34648 .34015 .34159 .32987 .32912 Mtetra
.652 .718 .897 r
.32987 .32912 .34015 .34159 .35666 .33659 .34649 .32329 Mtetra
.65 .704 .886 r
.34649 .32329 .35666 .33659 .37331 .33134 .36321 .31744 Mtetra
.65 .695 .878 r
.36321 .31744 .37331 .33134 .39007 .32575 .38003 .31151 Mtetra
.651 .691 .874 r
.38003 .31151 .39007 .32575 .40696 .3198 .39697 .30548 Mtetra
.652 .691 .874 r
.39697 .30548 .40696 .3198 .42396 .31347 .41401 .29935 Mtetra
.654 .696 .877 r
.41401 .29935 .42396 .31347 .44108 .30681 .43117 .29314 Mtetra
.654 .705 .884 r
.43117 .29314 .44108 .30681 .4583 .29989 .44843 .28691 Mtetra
.654 .719 .896 r
.44843 .28691 .4583 .29989 .47562 .29285 .4658 .28072 Mtetra
.653 .736 .91 r
.4658 .28072 .47562 .29285 .49304 .28615 .48328 .27459 Mtetra
.656 .749 .919 r
.48328 .27459 .49304 .28615 .51057 .27976 .50088 .26834 Mtetra
.656 .754 .922 r
.50088 .26834 .51057 .27976 .5282 .27361 .51859 .26201 Mtetra
.657 .752 .92 r
.51859 .26201 .5282 .27361 .54595 .26737 .53641 .25562 Mtetra
.66 .752 .918 r
.53641 .25562 .54595 .26737 .56381 .26102 .55435 .24906 Mtetra
.66 .749 .916 r
.55435 .24906 .56381 .26102 .58179 .25456 .5724 .24244 Mtetra
.656 .746 .916 r
.5724 .24244 .58179 .25456 .59988 .24793 .59058 .23595 Mtetra
.651 .748 .921 r
.59058 .23595 .59988 .24793 .61809 .24141 .60887 .22964 Mtetra
.652 .755 .925 r
.60887 .22964 .61809 .24141 .63643 .23513 .62729 .22323 Mtetra
.656 .755 .923 r
.62729 .22323 .63643 .23513 .65489 .22878 .64583 .21664 Mtetra
.659 .753 .919 r
.64583 .21664 .65489 .22878 .67347 .22222 .66448 .20986 Mtetra
.66 .75 .917 r
.66448 .20986 .67347 .22222 .69216 .21546 .68326 .203 Mtetra
.654 .748 .919 r
.68326 .203 .69216 .21546 .71097 .20865 .70217 .19634 Mtetra
.652 .752 .923 r
.70217 .19634 .71097 .20865 .72993 .20207 .72122 .18971 Mtetra
.655 .753 .922 r
.72122 .18971 .72993 .20207 .74901 .19547 .74039 .18294 Mtetra
.655 .75 .92 r
.06606 .409 .07743 .41897 .09251 .41355 .08117 .40361 Mtetra
.657 .753 .92 r
.08117 .40361 .09251 .41355 .10769 .40801 .09639 .39809 Mtetra
.66 .755 .921 r
.09639 .39809 .10769 .40801 .12295 .40251 .11171 .39245 Mtetra
.657 .753 .921 r
.11171 .39245 .12295 .40251 .13827 .39722 .12712 .38688 Mtetra
.652 .747 .92 r
.12712 .38688 .13827 .39722 .1537 .39184 .14259 .38149 Mtetra
.653 .748 .92 r
.14259 .38149 .1537 .39184 .16923 .38631 .15816 .37602 Mtetra
.656 .751 .92 r
.15816 .37602 .16923 .38631 .18487 .3806 .17383 .37039 Mtetra
.658 .755 .921 r
.17383 .37039 .18487 .3806 .20061 .37481 .18962 .36463 Mtetra
.661 .758 .922 r
.18962 .36463 .20061 .37481 .21642 .36919 .20551 .35875 Mtetra
.659 .753 .92 r
.20551 .35875 .21642 .36919 .23232 .36372 .22149 .35291 Mtetra
.652 .745 .918 r
.22149 .35291 .23232 .36372 .24831 .35819 .23755 .34728 Mtetra
.651 .744 .918 r
.23755 .34728 .24831 .35819 .26442 .35249 .2537 .34164 Mtetra
.652 .747 .919 r
.2537 .34164 .26442 .35249 .28063 .34675 .26996 .33593 Mtetra
.655 .75 .92 r
.26996 .33593 .28063 .34675 .29694 .34093 .28633 .33009 Mtetra
.655 .751 .92 r
.28633 .33009 .29694 .34093 .31336 .335 .3028 .3242 Mtetra
.655 .753 .922 r
.3028 .3242 .31336 .335 .32987 .32912 .31938 .31827 Mtetra
.31938 .31827 .32987 .32912 .34649 .32329 .33606 .3123 Mtetra
.656 .752 .921 r
.33606 .3123 .34649 .32329 .36321 .31744 .35285 .30627 Mtetra
.656 .75 .919 r
.35285 .30627 .36321 .31744 .38003 .31151 .36974 .30019 Mtetra
.656 .748 .918 r
.36974 .30019 .38003 .31151 .39697 .30548 .38675 .29409 Mtetra
.655 .748 .918 r
.38675 .29409 .39697 .30548 .41401 .29935 .40386 .28798 Mtetra
.656 .75 .919 r
.40386 .28798 .41401 .29935 .43117 .29314 .42108 .2818 Mtetra
.656 .752 .921 r
.42108 .2818 .43117 .29314 .44843 .28691 .43841 .27556 Mtetra
.656 .754 .922 r
.43841 .27556 .44843 .28691 .4658 .28072 .45585 .26929 Mtetra
.656 .753 .921 r
.45585 .26929 .4658 .28072 .48328 .27459 .4734 .26297 Mtetra
.656 .751 .92 r
.4734 .26297 .48328 .27459 .50088 .26834 .49107 .2566 Mtetra
.659 .751 .918 r
.49107 .2566 .50088 .26834 .51859 .26201 .50886 .25009 Mtetra
.66 .75 .916 r
.50886 .25009 .51859 .26201 .53641 .25562 .52676 .2435 Mtetra
.659 .747 .915 r
.52676 .2435 .53641 .25562 .55435 .24906 .54477 .2369 Mtetra
.653 .745 .917 r
.54477 .2369 .55435 .24906 .5724 .24244 .5629 .2305 Mtetra
.651 .751 .922 r
.5629 .2305 .5724 .24244 .59058 .23595 .58116 .22415 Mtetra
.653 .755 .925 r
.58116 .22415 .59058 .23595 .60887 .22964 .59954 .21766 Mtetra
.656 .755 .922 r
.59954 .21766 .60887 .22964 .62729 .22323 .61804 .21101 Mtetra
.659 .753 .919 r
.61804 .21101 .62729 .22323 .64583 .21664 .63665 .20421 Mtetra
.66 .75 .917 r
.63665 .20421 .64583 .21664 .66448 .20986 .65539 .19732 Mtetra
.655 .748 .918 r
.65539 .19732 .66448 .20986 .68326 .203 .67426 .19059 Mtetra
.652 .751 .922 r
.67426 .19059 .68326 .203 .70217 .19634 .69326 .18393 Mtetra
.654 .753 .923 r
.69326 .18393 .70217 .19634 .72122 .18971 .71239 .17713 Mtetra
.657 .753 .921 r
.71239 .17713 .72122 .18971 .74039 .18294 .73164 .17018 Mtetra
.652 .748 .92 r
.05457 .39884 .06606 .409 .08117 .40361 .06972 .39349 Mtetra
.655 .751 .92 r
.06972 .39349 .08117 .40361 .09639 .39809 .08498 .38798 Mtetra
.658 .753 .92 r
.08498 .38798 .09639 .39809 .11171 .39245 .10034 .38236 Mtetra
.66 .755 .921 r
.10034 .38236 .11171 .39245 .12712 .38688 .11581 .37664 Mtetra
.657 .753 .92 r
.11581 .37664 .12712 .38688 .14259 .38149 .13136 .37097 Mtetra
.652 .747 .919 r
.13136 .37097 .14259 .38149 .15816 .37602 .14698 .36546 Mtetra
.652 .747 .92 r
.14698 .36546 .15816 .37602 .17383 .37039 .16269 .3599 Mtetra
.655 .751 .92 r
.16269 .3599 .17383 .37039 .18962 .36463 .17852 .3542 Mtetra
.657 .754 .921 r
.17852 .3542 .18962 .36463 .20551 .35875 .19446 .3484 Mtetra
.66 .758 .922 r
.19446 .3484 .20551 .35875 .22149 .35291 .2105 .34245 Mtetra
.66 .757 .922 r
.2105 .34245 .22149 .35291 .23755 .34728 .22664 .33647 Mtetra
.657 .75 .919 r
.22664 .33647 .23755 .34728 .2537 .34164 .24287 .33055 Mtetra
.653 .745 .917 r
.24287 .33055 .2537 .34164 .26996 .33593 .25919 .32475 Mtetra
.653 .744 .917 r
.25919 .32475 .26996 .33593 .28633 .33009 .27561 .31893 Mtetra
.653 .746 .918 r
.27561 .31893 .28633 .33009 .3028 .3242 .29214 .31306 Mtetra
.654 .748 .919 r
.29214 .31306 .3028 .3242 .31938 .31827 .30877 .30712 Mtetra
.655 .75 .919 r
.30877 .30712 .31938 .31827 .33606 .3123 .32552 .30108 Mtetra
.32552 .30108 .33606 .3123 .35285 .30627 .34237 .29499 Mtetra
.656 .75 .919 r
.34237 .29499 .35285 .30627 .36974 .30019 .35933 .28887 Mtetra
.656 .751 .92 r
.35933 .28887 .36974 .30019 .38675 .29409 .3764 .28269 Mtetra
.3764 .28269 .38675 .29409 .40386 .28798 .39358 .27648 Mtetra
.656 .75 .919 r
.39358 .27648 .40386 .28798 .42108 .2818 .41087 .27022 Mtetra
.41087 .27022 .42108 .2818 .43841 .27556 .42827 .26391 Mtetra
.658 .751 .919 r
.42827 .26391 .43841 .27556 .45585 .26929 .44578 .2575 Mtetra
.658 .75 .917 r
.44578 .2575 .45585 .26929 .4734 .26297 .46341 .25101 Mtetra
.659 .748 .916 r
.46341 .25101 .4734 .26297 .49107 .2566 .48116 .24447 Mtetra
.658 .746 .915 r
.48116 .24447 .49107 .2566 .50886 .25009 .49901 .23791 Mtetra
.654 .745 .916 r
.49901 .23791 .50886 .25009 .52676 .2435 .51699 .23146 Mtetra
.652 .749 .92 r
.51699 .23146 .52676 .2435 .54477 .2369 .53508 .22507 Mtetra
.652 .754 .925 r
.53508 .22507 .54477 .2369 .5629 .2305 .55329 .21864 Mtetra
.655 .756 .924 r
.55329 .21864 .5629 .2305 .58116 .22415 .57163 .21205 Mtetra
.656 .754 .922 r
.57163 .21205 .58116 .22415 .59954 .21766 .59008 .20535 Mtetra
.659 .752 .919 r
.59008 .20535 .59954 .21766 .61804 .21101 .60866 .1985 Mtetra
.659 .75 .917 r
.60866 .1985 .61804 .21101 .63665 .20421 .62736 .19158 Mtetra
.655 .747 .918 r
.62736 .19158 .63665 .20421 .65539 .19732 .64619 .18482 Mtetra
.652 .751 .922 r
.64619 .18482 .65539 .19732 .67426 .19059 .66515 .17811 Mtetra
.654 .754 .923 r
.66515 .17811 .67426 .19059 .69326 .18393 .68424 .17128 Mtetra
.656 .753 .921 r
.68424 .17128 .69326 .18393 .71239 .17713 .70345 .16432 Mtetra
.659 .752 .919 r
.70345 .16432 .71239 .17713 .73164 .17018 .72279 .15718 Mtetra
.654 .75 .92 r
.04294 .38862 .05457 .39884 .06972 .39349 .05815 .38315 Mtetra
.652 .748 .92 r
.05815 .38315 .06972 .39349 .08498 .38798 .07344 .3777 Mtetra
.656 .751 .92 r
.07344 .3777 .08498 .38798 .10034 .38236 .08885 .37209 Mtetra
.657 .753 .921 r
.08885 .37209 .10034 .38236 .11581 .37664 .10436 .36638 Mtetra
.659 .755 .921 r
.10436 .36638 .11581 .37664 .13136 .37097 .11997 .36057 Mtetra
.658 .753 .92 r
.11997 .36057 .13136 .37097 .14698 .36546 .13567 .35476 Mtetra
.653 .747 .919 r
.13567 .35476 .14698 .36546 .16269 .3599 .15145 .34912 Mtetra
.652 .747 .919 r
.15145 .34912 .16269 .3599 .17852 .3542 .16732 .34347 Mtetra
.654 .75 .92 r
.16732 .34347 .17852 .3542 .19446 .3484 .18329 .33771 Mtetra
.656 .752 .921 r
.18329 .33771 .19446 .3484 .2105 .34245 .19938 .33184 Mtetra
.657 .756 .922 r
.19938 .33184 .2105 .34245 .22664 .33647 .21557 .32589 Mtetra
.659 .758 .923 r
.21557 .32589 .22664 .33647 .24287 .33055 .23187 .31982 Mtetra
.659 .756 .922 r
.23187 .31982 .24287 .33055 .25919 .32475 .24827 .31373 Mtetra
.658 .752 .919 r
.24827 .31373 .25919 .32475 .27561 .31893 .26477 .30764 Mtetra
.656 .747 .917 r
.26477 .30764 .27561 .31893 .29214 .31306 .28137 .30159 Mtetra
.654 .744 .916 r
.28137 .30159 .29214 .31306 .30877 .30712 .29806 .29556 Mtetra
.29806 .29556 .30877 .30712 .32552 .30108 .31487 .28949 Mtetra
.655 .745 .916 r
.31487 .28949 .32552 .30108 .34237 .29499 .33178 .28336 Mtetra
.655 .746 .916 r
.33178 .28336 .34237 .29499 .35933 .28887 .34881 .27718 Mtetra
.656 .746 .916 r
.34881 .27718 .35933 .28887 .3764 .28269 .36594 .27093 Mtetra
.36594 .27093 .3764 .28269 .39358 .27648 .38319 .26462 Mtetra
.657 .746 .916 r
.38319 .26462 .39358 .27648 .41087 .27022 .40055 .25826 Mtetra
.657 .746 .915 r
.40055 .25826 .41087 .27022 .42827 .26391 .41802 .25183 Mtetra
.657 .745 .915 r
.41802 .25183 .42827 .26391 .44578 .2575 .4356 .24537 Mtetra
.656 .745 .915 r
.4356 .24537 .44578 .2575 .46341 .25101 .4533 .23891 Mtetra
.654 .746 .918 r
.4533 .23891 .46341 .25101 .48116 .24447 .47111 .2325 Mtetra
.653 .75 .921 r
.47111 .2325 .48116 .24447 .49901 .23791 .48904 .22608 Mtetra
.653 .754 .924 r
.48904 .22608 .49901 .23791 .51699 .23146 .5071 .21964 Mtetra
.655 .757 .925 r
.5071 .21964 .51699 .23146 .53508 .22507 .52527 .21307 Mtetra
.656 .755 .923 r
.52527 .21307 .53508 .22507 .55329 .21864 .54356 .2064 Mtetra
.657 .753 .92 r
.54356 .2064 .55329 .21864 .57163 .21205 .56197 .19963 Mtetra
.659 .751 .918 r
.56197 .19963 .57163 .21205 .59008 .20535 .58051 .19273 Mtetra
.658 .749 .917 r
.58051 .19273 .59008 .20535 .60866 .1985 .59917 .1858 Mtetra
.654 .747 .918 r
.59917 .1858 .60866 .1985 .62736 .19158 .61796 .17904 Mtetra
.653 .751 .922 r
.61796 .17904 .62736 .19158 .64619 .18482 .63688 .17229 Mtetra
.654 .754 .923 r
.63688 .17229 .64619 .18482 .66515 .17811 .65592 .16541 Mtetra
.656 .753 .921 r
.65592 .16541 .66515 .17811 .68424 .17128 .67509 .15841 Mtetra
.659 .753 .919 r
.67509 .15841 .68424 .17128 .70345 .16432 .69439 .15124 Mtetra
.658 .75 .918 r
.69439 .15124 .70345 .16432 .72279 .15718 .71382 .14407 Mtetra
.658 .753 .92 r
.03117 .37842 .04294 .38862 .05815 .38315 .04645 .37274 Mtetra
.654 .749 .92 r
.04645 .37274 .05815 .38315 .07344 .3777 .0618 .36717 Mtetra
.652 .748 .92 r
.0618 .36717 .07344 .3777 .08885 .37209 .07724 .36162 Mtetra
.655 .751 .92 r
.07724 .36162 .08885 .37209 .10436 .36638 .09279 .35592 Mtetra
.657 .753 .921 r
.09279 .35592 .10436 .36638 .11997 .36057 .10844 .35013 Mtetra
.659 .755 .921 r
.10844 .35013 .11997 .36057 .13567 .35476 .1242 .34423 Mtetra
.658 .754 .921 r
.1242 .34423 .13567 .35476 .15145 .34912 .14006 .33831 Mtetra
.655 .749 .919 r
.14006 .33831 .15145 .34912 .16732 .34347 .156 .33248 Mtetra
.652 .746 .919 r
.156 .33248 .16732 .34347 .18329 .33771 .17202 .32671 Mtetra
.653 .748 .919 r
.17202 .32671 .18329 .33771 .19938 .33184 .18815 .3209 Mtetra
.655 .751 .92 r
.18815 .3209 .19938 .33184 .21557 .32589 .2044 .31496 Mtetra
.656 .753 .921 r
.2044 .31496 .21557 .32589 .23187 .31982 .22074 .30895 Mtetra
.657 .755 .923 r
.22074 .30895 .23187 .31982 .24827 .31373 .2372 .30288 Mtetra
.658 .758 .924 r
.2372 .30288 .24827 .31373 .26477 .30764 .25376 .29672 Mtetra
.658 .758 .923 r
.25376 .29672 .26477 .30764 .28137 .30159 .27043 .29051 Mtetra
.658 .756 .922 r
.27043 .29051 .28137 .30159 .29806 .29556 .2872 .28428 Mtetra
.657 .753 .921 r
.2872 .28428 .29806 .29556 .31487 .28949 .30408 .27804 Mtetra
.657 .751 .919 r
.30408 .27804 .31487 .28949 .33178 .28336 .32106 .27177 Mtetra
.656 .749 .919 r
.32106 .27177 .33178 .28336 .34881 .27718 .33815 .26547 Mtetra
.656 .749 .918 r
.33815 .26547 .34881 .27718 .36594 .27093 .35535 .25915 Mtetra
.655 .748 .918 r
.35535 .25915 .36594 .27093 .38319 .26462 .37267 .2528 Mtetra
.655 .749 .919 r
.37267 .2528 .38319 .26462 .40055 .25826 .39009 .24643 Mtetra
.655 .75 .92 r
.39009 .24643 .40055 .25826 .41802 .25183 .40763 .24003 Mtetra
.654 .752 .922 r
.40763 .24003 .41802 .25183 .4356 .24537 .42528 .23362 Mtetra
.654 .755 .924 r
.42528 .23362 .4356 .24537 .4533 .23891 .44306 .22717 Mtetra
.654 .756 .925 r
.44306 .22717 .4533 .23891 .47111 .2325 .46094 .22068 Mtetra
.655 .757 .925 r
.46094 .22068 .47111 .2325 .48904 .22608 .47895 .21409 Mtetra
.656 .755 .923 r
.47895 .21409 .48904 .22608 .5071 .21964 .49708 .20743 Mtetra
.657 .753 .921 r
.49708 .20743 .5071 .21964 .52527 .21307 .51533 .2007 Mtetra
.658 .752 .919 r
.51533 .2007 .52527 .21307 .54356 .2064 .53371 .19383 Mtetra
.659 .75 .917 r
.53371 .19383 .54356 .2064 .56197 .19963 .5522 .18691 Mtetra
.656 .748 .917 r
.5522 .18691 .56197 .19963 .58051 .19273 .57082 .18003 Mtetra
.653 .748 .92 r
.57082 .18003 .58051 .19273 .59917 .1858 .58956 .17325 Mtetra
.653 .753 .923 r
.58956 .17325 .59917 .1858 .61796 .17904 .60844 .16643 Mtetra
.655 .754 .923 r
.60844 .16643 .61796 .17904 .63688 .17229 .62744 .1595 Mtetra
.656 .753 .921 r
.62744 .1595 .63688 .17229 .65592 .16541 .64657 .15245 Mtetra
.659 .752 .919 r
.64657 .15245 .65592 .16541 .67509 .15841 .66583 .14525 Mtetra
.658 .75 .918 r
.66583 .14525 .67509 .15841 .69439 .15124 .68522 .13804 Mtetra
.654 .749 .92 r
.68522 .13804 .69439 .15124 .71382 .14407 .70475 .13094 Mtetra
.658 .754 .921 r
.01926 .36812 .03117 .37842 .04645 .37274 .03459 .36236 Mtetra
.658 .753 .921 r
.03459 .36236 .04645 .37274 .0618 .36717 .05001 .35658 Mtetra
.654 .749 .92 r
.05001 .35658 .0618 .36717 .07724 .36162 .06551 .3509 Mtetra
.653 .748 .92 r
.06551 .3509 .07724 .36162 .09279 .35592 .0811 .34524 Mtetra
.655 .75 .92 r
.0811 .34524 .09279 .35592 .10844 .35013 .0968 .33947 Mtetra
.657 .753 .921 r
.0968 .33947 .10844 .35013 .1242 .34423 .1126 .33359 Mtetra
.658 .755 .921 r
.1126 .33359 .1242 .34423 .14006 .33831 .12851 .32762 Mtetra
.659 .755 .921 r
.12851 .32762 .14006 .33831 .156 .33248 .14452 .32159 Mtetra
.657 .752 .92 r
.14452 .32159 .156 .33248 .17202 .32671 .16063 .31556 Mtetra
.654 .747 .918 r
.16063 .31556 .17202 .32671 .18815 .3209 .17682 .30963 Mtetra
.653 .746 .918 r
.17682 .30963 .18815 .3209 .2044 .31496 .19311 .3037 Mtetra
.653 .748 .919 r
.19311 .3037 .2044 .31496 .22074 .30895 .20951 .29771 Mtetra
.655 .75 .92 r
.20951 .29771 .22074 .30895 .2372 .30288 .22602 .29164 Mtetra
.655 .752 .921 r
.22602 .29164 .2372 .30288 .25376 .29672 .24263 .2855 Mtetra
.656 .754 .922 r
.24263 .2855 .25376 .29672 .27043 .29051 .25936 .2793 Mtetra
.656 .755 .923 r
.25936 .2793 .27043 .29051 .2872 .28428 .27619 .27306 Mtetra
.656 .757 .924 r
.27619 .27306 .2872 .28428 .30408 .27804 .29313 .26677 Mtetra
.29313 .26677 .30408 .27804 .32106 .27177 .31018 .26045 Mtetra
.656 .758 .925 r
.31018 .26045 .32106 .27177 .33815 .26547 .32734 .25408 Mtetra
.32734 .25408 .33815 .26547 .35535 .25915 .34461 .24769 Mtetra
.34461 .24769 .35535 .25915 .37267 .2528 .362 .24126 Mtetra
.656 .757 .925 r
.362 .24126 .37267 .2528 .39009 .24643 .3795 .23479 Mtetra
.656 .757 .924 r
.3795 .23479 .39009 .24643 .40763 .24003 .39711 .22828 Mtetra
.656 .756 .924 r
.39711 .22828 .40763 .24003 .42528 .23362 .41484 .22172 Mtetra
.656 .755 .923 r
.41484 .22172 .42528 .23362 .44306 .22717 .43269 .21512 Mtetra
.656 .754 .922 r
.43269 .21512 .44306 .22717 .46094 .22068 .45065 .20845 Mtetra
.657 .752 .92 r
.45065 .20845 .46094 .22068 .47895 .21409 .46874 .20171 Mtetra
.658 .751 .919 r
.46874 .20171 .47895 .21409 .49708 .20743 .48695 .19487 Mtetra
.658 .749 .917 r
.48695 .19487 .49708 .20743 .51533 .2007 .50528 .18798 Mtetra
.657 .748 .917 r
.50528 .18798 .51533 .2007 .53371 .19383 .52373 .18107 Mtetra
.654 .747 .918 r
.52373 .18107 .53371 .19383 .5522 .18691 .54231 .17426 Mtetra
.653 .751 .921 r
.54231 .17426 .5522 .18691 .57082 .18003 .56101 .16744 Mtetra
.654 .754 .923 r
.56101 .16744 .57082 .18003 .58956 .17325 .57984 .16055 Mtetra
.655 .754 .922 r
.57984 .16055 .58956 .17325 .60844 .16643 .5988 .15356 Mtetra
.657 .753 .921 r
.5988 .15356 .60844 .16643 .62744 .1595 .61789 .14645 Mtetra
.659 .752 .919 r
.61789 .14645 .62744 .1595 .64657 .15245 .6371 .13921 Mtetra
.657 .749 .918 r
.6371 .13921 .64657 .15245 .66583 .14525 .65645 .13197 Mtetra
.654 .749 .92 r
.65645 .13197 .66583 .14525 .68522 .13804 .67594 .12483 Mtetra
.654 .752 .922 r
.67594 .12483 .68522 .13804 .70475 .13094 .69557 .11765 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
[(-2)] .12586 .2075 1 .99877 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.56863 .04703 m
.57247 .05235 L
s
[(2)] .56094 .0364 .72324 1 Mshowa
.125 Mabswid
.18558 .19702 m
.18832 .19985 L
s
.23703 .17687 m
.23971 .17975 L
s
.28951 .15632 m
.29214 .15925 L
s
.39772 .11395 m
.40023 .11699 L
s
.4535 .09211 m
.45595 .0952 L
s
.51046 .06981 m
.51284 .07294 L
s
.08568 .23614 m
.08851 .23887 L
s
.62804 .02377 m
.63027 .02701 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 233.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00o?ooool2o`0006[ooooo003iooooo`?o000000?oooooo`000?ooool0
JOooool00?Oooooo0_l00004ooooo`;o0000JOooool00?Cooooo0ol00006ooooo`03o`000?oooooo
000006Sooooo003;ooooo`Go00008_ooool2o`0000Wooooo00?o0000ooooool00000J?ooool00<_o
oooo00GoV9RHob4Q8Oo^k^koooooodA4A00Oooooo`?o00002oooool01?l0003oooooooooool0001W
ooooo`00c?ooool00onHV9So8B4Qonk^kP0Mooooo`?o00003_ooool01Ol0003ooooooooooooooooo
000006Kooooo003=ooooo`03oiRHV?lQ8B7ok^k^01[ooooo0_l0000Aooooo`05o`000?oooooooooo
ooooool00000I_ooool00<kooooo00?oMgMgofIVI_ooool05_ooool3o`0001?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1Sooooo`00coooool00ol0003oooooooooo`0Cooooo`;o
00000_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0H_ooool00<_ooooo00Go0000okZj^_ooooooV9RHoa0@400Booooo`?o00006Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo06;ooooo003;ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`04?ooool2o`0001cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Qooooo`00
gOooool3o`0001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Qooooo`00fooo
ool2o`00027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Pooooo`00f?ooool3
o`0002?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Oooooo`00eOooool3o`00
02Kooooo00?o0000ooooooooool01?ooool2o`00067ooooo003Cooooo`;o0000:Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo05kooooo003@ooooo`?o000000?oooooo`000?ooool0
:?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05gooooo003>ooooo`;o00001Ooo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0GOoo
ool00<_ooooo0ol0000`ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0G?ooool0
0<Wooooo0_l0000cooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Foooool00<Ko
oooo0ol0000eooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Foooool00<Cooooo
0_l0000hooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0F_ooool00<7ooooo0ol0
000jooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03_ooool5o`0004Kooooo002n
ooooo`?o0000?Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00kooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A016ooooo`00_?ooool2o`0000?ooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo1_l00003ooooo`03oiRHV?lQ8B7o
k^k^04Oooooo002iooooo`?o0000@oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00kooooo00?oV9RHob4Q8Oo^k^h0A_ooool00;Oooooo0_l00016ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03oooool00omgMgOoIVIVooooo`15ooooo`00]?ooool3o`0004Sooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Cooooo
002booooo`;o0000Boooool00ol0003oooooooooo`0=ooooo`;o00003?ooool01Ol0003o^[Zjoooo
oonHV9So410@04Kooooo002_ooooo`?o0000COooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c016ooooo`00[Oooool2o`00053ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`1Dooooo`00Z_ooool4o`00057ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1Dooooo`00Z?ooool2o`0000Cooooo00?o0000oooo
ooooool0C_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05?ooooo001nooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h08_ooool3o`0005Oooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`1Booooo`00O_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01oooooo0ol0001Joooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool0D_ooool007kooooo00Go410@oooooooo
oooooooooa0@400Mooooo`;o0000GOooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
057ooooo001nooooo`05o`000?ooooooooooooooool000006_ooool3o`0005oooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`1@ooooo`00O_ooool01Ol0003ooooooooooooooooo0000
01Sooooo0_l0001Rooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0D?ooool007ko
oooo00Go410@oooooooooooooooooa0@400Eooooo`?o0000I?ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo04oooooo001nooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool2o`00
00?ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
04kooooo001nooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04?ooool3o`0006Sooooo00?oYl3/o`00
0?ooool05_ooool00ol0003oooooooooo`1>ooooo`00TOooool2o`0006Sooooo1?nW`>`00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo04gooooo002>ooooo`?o0000J?ooool7ojO0k003o`00
0?oooooooooo01Cooooo0ol0001>ooooo`00Roooool3o`0006Wooooo0_nW_n/7ojO0k003o`000?oo
oooooooo01Kooooo00?o0000ooooooooool0C?ooool008Wooooo0_l0001Yooooo`KoYko[1_nW`>`0
0ol0003oYl3/ooooo`0Gooooo`03o`000?oooooooooo04_ooooo0026ooooo`?o0000J?ooool00onX
_n_oYko[ojNoj`07ojNoj`GoYl3/00?o0000ojNojoooool06?ooool00ol0003oooooooooo`1:oooo
o`00Q?ooool2o`0000;ooooo00?o0000ooooooooool0Hoooool5ojRoj`WoYko[0_nW`>`2ojNoj`03
o`000?nW_n_oYko[01Sooooo00?o0000ooooooooool0B_ooool0087ooooo0ol00005ooooo`03o`00
0?oooooooooo063ooooo2?nX_n/7ojNoj`03ojRojonW_n_oYko[00;oYko[00Co0000ojNojonW_n_o
Yko[6?ooool00ol0003oooooooooo`19ooooo`00Ooooool2o`0006Wooooo00?oZ<3[ojRojonX_n/0
1onX_n/4ojNoj`GoZ;o[0onW_n/00ol0003oYko[ojNoj`02ojNojaSooooo00?o0000ooooooooool0
B?ooool007cooooo0ol0001Xooooo`GoZ<3[2OnX_n/00onW_n_oZ;o[ojRoj`06ojRoj`;oYko[00Go
0000ojNojonW_n_oYko[ojRoj`0Hooooo`03o`000?oooooooooo04Sooooo001jooooo`;o0000Iooo
ool:ojS0j`KoZ;o[0_nX`>/9ojRoj`;oYko[00?o0000ojNojonX_n/00onX_n/Hooooo`03o`000?oo
oooooooo04Oooooo001gooooo`?o0000I_ooool>ojS0j`;oZ;o[1_nX`>/9ojRoj`03ojNojol0003o
Z;o[00GoZ;o[6?ooool00ol0003oooooooooo`16ooooo`00M?ooool3o`0006Kooooo00?oYl7/ojS0
jonX`>/03OnX`>/2ojO0j`SoZ<3[1_nX_n/2ojS0j`03ojRojol0003oZ;o[00GoZ;o[6?ooool00ol0
003oooooooooo`16ooooo`00L_ooool2o`0000;ooooo00?o0000ooooooooool0H_ooool4ojO1k0_o
Z<3[1_nW`>/8ojS0j`;oZ;o[1_nX`>/00ol0003oZ;o[ojRoj`05ojRojaSooooo00?o0000oooooooo
ool0AOooool006oooooo0ol0001Wooooo`OoYl7/1onX`>/00onW`NcoYl3[ojO0j`07ojO0j`KoZ<3[
00?oYl3[ojS0jonX`>/01_nX`>/00ol0003oZ;o[ojRoj`04ojRoj`03ojS0jooooooooooo01Kooooo
00?o0000ooooooooool0AOooool006gooooo0_l0001Wooooo`[oYl7/1?nX`>/5ojO1k0WoYl3[0_nX
`>/5ojO0j`OoZ<3[00Co0000ojS0jonX_n_oZ;o[1OnX`>/Gooooo`;o0000A_ooool006[ooooo0ol0
001Vooooo`koYl7/00?oZ<3[ojO1k?nW`N`01_nW`N`7ojO0j`03ojO1k?nW`>_oYl3[00KoYl3[1_nX
`>/00ol0003oYl3[ojS0j`07ojS0jaSooooo00?o0000ooooooooool0@oooool006Sooooo0_l0001V
ooooo`;oYl3[3_nW`N`2ojO0k0SoYl7/1?nW`>/5ojO1k0SoYl3[0_nX`>/3ojO0j`03o`000?nW`>_o
Yl3[00SoZ<3[5oooool00ol0003oooooooooo`13ooooo`00IOooool3o`0006Gooooo1_nW`>/:ojO1
k0KoYl3/2?nW`N`00onW`>_oYl7/ojO1k006ojO1k0KoYl3[00?oYl7/ojO0jonW`>/00onW`>/01?l0
003oYl3[ojO0jonW`>/7ojS0jaSooooo00?o0000ooooooooool0@_ooool006?ooooo0_l0001Uoooo
o`03ojNojonW`>_oYl3[00OoYl3[1_nW`N`00onW_n_oYl3/ojO0k007ojO0k0KoYl7/00?oYl3/ojO1
k?nW`N`01onW`N`4ojO0j`CoYl7/1OnW`>/01?l0003oYl3[ojO0jonW`>/7ojS0jaSooooo00?o0000
ooooooooool0@Oooool0063ooooo0ol000000ooooooo0000ooooo`1Rooooo`CoYko[2OnW`>/2ojO1
k0GoYko[2OnW`>`2ojO1k0GoYl3/2OnW`N`00onW`>_oYl7/ojO1k005ojO1k0CoYl3[00Co0000ojO0
jonW`>_oYl3/2?nX`>/Gooooo`03o`000?oooooooooo047ooooo000fooooo`Go00008oooool2o`00
06Kooooo1onW_n/7ojO0j`03ojNoj_nW_n_oYko[00KoYko[1_nW`>`2ojNoj`SoYl3/1_nW`N`2ojK0
k0SoYl7/1?nW`>/00ol0003oYl3/ojO0k002ojO0k0SoZ<3[5oooool00ol0003oooooooooo`10oooo
o`00=_ooool01OnHV9So8B4Qonk^k_ooooooA4A4023ooooo0ol0001Uooooo`;oZ;oZ2?nW_n/4ojO0
j`GoYkoZ2?nW_n/2ojO0k0KoYko[2?nW`>`2ojO1k0KoY/3/2?nW`N`01?nW`>_oYl3/ojO0k?l00005
ojO0k0KoZ<3[00?oYl3/ooooooooool05_ooool00ol0003oooooooooo`0oooooo`00;_ooool6o`00
00?ooooo00?oV9RHob4Q8Oo^k^h07_ooool3o`0006Gooooo1_nX_nX8ojNoj`03ojO0jonW_n[oYkoZ
00KoYkoZ1_nW_n/00onX_n[oYko[ojNoj`07ojNoj`KoYl3/00?oYko[ojK0k?nV`>`01onV`>`6ojO1
k005ojK0k?nW`>coYl3/ojO0k?l000001OnW`>`4ojS0j`CoYl3/5oooool00ol0003oooooooooo`0o
ooooo`00>?ooool00onHV9So8B4Qonk^kP0Kooooo`;o0000IOooool:ojRojPKoYko[0_nX_nX8ojNo
jPCoYko[1?nX_nX9ojNoj`;oYl3/1OnW_n/9ojK0k0;oYl7/1OnV`>`2ojO0k003o`000?nW`>coYl3/
00CoYl3/00?oZ<3[ojO0k?nW`>`01OnW`>`Gooooo`03o`000?oooooooooo03kooooo000iooooo`03
ogMgMomVIVKooooo01Oooooo0ol0001Tooooo`koZ;oZ0_nW_n/6ojRojPSoYkoZ00?oYko[ojRoj_nX
_nX01OnX_nX7ojNoj`03ojRoj_nW_n_oYko[00KoYko[1_nV`>`2ojNoj`SoY/3/00?oYl3/o`000?nW
`>`00onW`>`2ojK0k0SoYl3/6?ooool00ol0003oooooooooo`0mooooo`00>_ooool00ol0003ooooo
ooooo`0Dooooo`;o0000I?ooool00onX`>_oZ;oZojRojP0=ojRojP03ojS0jonX_n[oZ;oZ00OoZ;oZ
1_nW_nX00onX`>_oZ;oZojRojP07ojRojPCoYko[1?nX_nX8ojNoj`;oY/3/1_nW_n/8ojK0k003o`00
0?nW`>coY/3/00GoY/3/2?nW`>`Gooooo`03o`000?oooooooooo03gooooo000fooooo`05o`000?nj
^[[ooooooiRHV?l@41004oooool3o`0000;ooooo00?o0000ooooooooool0Goooool4ojS0j`_oZ;oZ
1OnX`>/9ojRojP;oYkoZ1OnX`>/9ojRojP03ojNojonX_n[oZ;oZ00GoZ;oZ1_nW_n/00onX_n[oYko[
ojNoj`07ojNoj`KoY/3/00?oYko[o`000?nV`>`01onV`>`7ojO0k1Sooooo00?o0000ooooooooool0
??ooool003Kooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Aooooo`;o0000IOooool7ojS0j`OoZ;oZ
2OnX`>/6ojRojP[oZ<3[1_nX_nX2ojS0j`SoZ;oZ1?nW_n/4ojRojPWoYko[0_nV`>`4ojNoj`03o`00
0?nV`>coY/3/00OoY/3/1onW`>`Fooooo`?o0000?Oooool004Wooooo0ol0001Uooooo`[oZ<3[1?nX
_nX<ojS0j`;oZ;oZ3_nX`>/2ojRojPKoZ<3[2?nX_nX00onW_n_oZ;oZojRojP05ojRojPOoYko[00?o
Z;oZojNojonW_n/01?nW_n/00ol0003oYko[ojK0k005ojK0k0;oYko[2?nW`>`Gooooo`03o`000?oo
oooooooo03_ooooo0017ooooo`;o0000IOooool>ojS0j`03ojRoj_nX`>_oZ<3[00_oZ<3[00?oYl7/
ojS0jonX`>/03OnX`>/00onW`NcoZ<3[ojS0j`07ojS0j`KoZ;oZ00?oZ<3[ojRoj_nX_nX01_nX_nX4
ojNoj`GoZ;oZ1OnW_n/00ol0003oYko[ojNoj`02ojK0k0KoYko[2?nW`>`Gooooo`03o`000?oooooo
oooo03[ooooo0014ooooo`?o0000I?ooool00onW`NcoZ<3[ojS0j`0<ojS0j`;oYl7/3?nX`>/4ojO1
k0_oZ<3[1OnW`N`9ojS0j`;oZ;oZ1OnX`>/8ojRojP03ojNojonX_n[oZ;oZ00KoZ;oZ1?nW_n/00ol0
003oYko[ojRojP09ojNoj`KoYl3/00?oY[o[ooooooooool05_ooool00ol0003oooooooooo`0ioooo
o`00@Oooool3o`0006Cooooo1OnW`N`:ojS0j`KoYl7/2OnX`>/7ojO1k0OoZ<3[2OnW`N`6ojS0j`;o
Yl7/2?nX`>/6ojRojP;oZ<3[2OnX_nX2ojNoj`03ojRoj_l0003oZ;oZ00;oZ;oZ2OnW_n/2ojO0k0Go
Y[o[5oooool00ol0003oooooooooo`0iooooo`00?oooool3o`0006?ooooo2OnW`N`6ojS0j`[oYl7/
1_nX`>/:ojO1k0CoZ<3[3?nW`N`2ojS0j`KoYl7/2?nX`>/2ojRojPKoZ<3[1onX_nX01OnX`>_oZ;oZ
ojRoj_nX_n[o000000CoZ;oZ1_nW_n/2ojRojPSoY[o[5oooool00ol0003oooooooooo`0hooooo`00
??ooool3o`0000?ooooo00?o0000ooooooooool0G_ooool<ojO1k0;oZ<3[3_nW`N`2ojS0j`koYl7/
00?oZ<3[ojO1k?nW`N`05OnW`N`6ojS0j`03ojO1k?nX`>_oZ<3[00OoZ<3[1?nX_nX4ojS0j`;oZ;oZ
00?o0000ojRoj_nX_nX00onX_nX2ojNoj`KoZ;oZ2?nV_n/Fooooo`03o`000?oooooooooo00Oooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0/ooooo`00>_ooool2o`0006Gooooo;OnW`N`00onV`NcoYl7/
ojO1k00GojO1k0;oZ<3[1OnW`N`9ojS0j`03ojRoj_nX`>_oZ<3[00GoZ<3[00?oZ;oZo`000?nX_nX0
0onX_nX00onX`>_oZ;oZojRojP07ojRojPKoY[o[00?oYko[ooooooooool05Oooool00ol0003ooooo
ooooo`06ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0;?ooool003Oooooo0ol0001UooooobcoYl7/
1OnV`N`7ojO1k003ojK0k?nW`NcoYl7/00goYl7/00?oY/7/ojO1k?nW`N`01_nW`N`6ojS0j`;oYl7/
2?nX`>/2ojRojP03o`000?nX_n[oZ<3[00?oZ<3[2OnX_nX2ojJoj`GoYko[5oooool00ol0003ooooo
ooooo`05ooooo`05oa0@4?ooooooooooooooool@4100;?ooool003Gooooo0_l0001UoooooacoYl7/
00?oYko[ojO1k?nW`N`03?nW`N`2ojJoj`SoY/7/1?nW`N`4ojK0k0_oYl7/1OnV`N`8ojO1k0;oZ<3[
1_nW`N`8ojS0j`03ojRoj_l0003oZ<3[00GoZ<3[1_nX_nX2ojW0j`SoYko[5_ooool00ol0003ooooo
ooooo`05ooooo`05o`000?ooooooooooooooool00000;?ooool003;ooooo0ol0001ToooooacoYl7/
1OnW_n/:ojO1k0KoY[o[2?nV`N`00onW`NcoY/3/ojK0k005ojK0k0KoYl7/0_nV_n/8ojK1k0KoYl7/
00?oY/7/ojO1k?nW`N`01onW`N`6ojS0j`03ojO1k?nX`>_o000000OoZ<3[0_nX_nX6ojW0j`SoYko[
5_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000;?ooool0033ooooo
0_l0001ToooooacoYl7/00?oYkk[ojNojonW_n/01_nW_n/6ojO1k0;oYkkZ2?nV_n/6ojK1k003ojNn
j_nV`>coY/3/00OoY/3/0_nW`N`6ojJoj`SoY/7/0_nW`N`5ojK1k0WoYl7/0_nX`>/5ojO1k003o`00
0?nX`>_oZ<3[00GoZ<3[2?nY`>/6ojNoj`;oZ<3Z5oooool00ol0003oooooooooo`03ooooo`05oa0@
4?ooooooooooooooool@4100;?ooool002gooooo0ol000000ooooooo0000ooooo`1Pooooo`ooYl7/
0_nW`>`;ojO1k0GoYkk[2?nW_n/2ojO1k0KoYkkZ2?nV_n/2ojK1k0GoYkkZ1onV`>`2ojNnjPSoY[o[
1_nV`N`00onV_n_oY/7/ojK1k006ojK1k0KoYl7/0_nV`N`7ojO1k003o`000?nX`>_oZ<3[00KoZ<3[
2?nY`>/2ojNoj`KoZ<3Z5_ooool2o`0000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0/ooooo`00
:_ooool3o`0006?ooooo3onW`N`6ojO0k0OoYl7/00?oYkkZojNnjonW_^/01_nW_^/6ojNoj`;oZ;kZ
2?nW_^X6ojJoj`03ojRoj_nW_^[oYkkZ00KoYkkZ1?nV`>`5ojNnjPSoY[o[0_nV`N`5ojJoj`SoY/7/
0_nW`N`6ojK1k0KoYl7/00?o0000ojO1k?nX`>/01onX`>/6ojW0j`03ojS0jonX`>[oZ<3Z00OoZ<3Z
4oooool2o`000003ooooool0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0/ooooo`00
:?ooool2o`0006?ooooo00?oYl;/ojO1k?nW`N`03?nW`N`2ojNoj`SoYl3/1?nW`N`4ojNnjPSoYkk[
0_nW_n/6ojRnjPSoYkkZ0_nV_n/5ojRojPSoYkkZ00?oY/3/ojNnj_nW_^X01_nW_^X6ojJoj`03ojRo
j_nV_n_oY[o[00KoY[o[1_nV`N`00onV_n_oY/7/ojK1k007ojK1k0GoYl7/00?o0000ojO1k?nX`>/0
1onX`>/4ojW0j`CoZ<3[2OnX`>XFooooo`03o`000?oooooooooo03;ooooo000Uooooo`?o0000H_oo
ool5ojO2k0[oYl7/1_nW_n/8ojO0k003ojO1k?nW_^[oYkkZ00GoYkkZ1_nW_^/2ojRojPSoZ;kZ1_nW
_^X9ojRojPKoYkkZ00?oZ;oZojNnj_nW_^X02?nW_^X2ojJoj`GoZ;oZ2?nV_n/2ojK1k0GoY[o[2OnV
`N`3ojO1k0;o00000_nW`N`8ojS0j`03ojW0jonX`>_oZ<3[00GoZ<3[1_nX`>X2ojW0jaKooooo00?o
0000ooooooooool0<_ooool002?ooooo0_l0001Rooooo`WoYl;/1_nW`N`:ojNoj`KoYl3/00?oZ;kZ
ojNnj_nW_^X01_nW_^X4ojNnj`GoZ;oZ2?nX_^X2ojNnjPgoZ;oZ0_nW_^X5ojRojPSoYkkZ00?oZL3Z
ojRoj_nX_nX01_nX_nX6ojJoj`03ojRoj_nV_n_oY[o[00KoY[o[1_nV`N`2ojJok0?o000000?oYl7/
o`000?nW`N`00_nW`N`6ojS0j`03ojO1k?nX`>_oZ<3[00OoZ<3[0_nX`>X6ojW0jaKooooo00?o0000
ooooooooool0<Oooool0023ooooo0ol0001Rooooo`coYl;/0_nW`N`>ojNoj`;oYl3/1OnX_^X8ojNn
jP03ojNnjonX_n[oZ;oZ00KoZ;oZ1_nX_^X00onX`>_oZ;oZojRojP0<ojRojP03ojS0jonX_n[oZ;oZ
00KoZ;oZ1?nW_^X5ojW0jPSoZ;oZ0_nV_n/5ojRojPSoY[o[0_nV`N`2ojJok0?o000000?oY[o/ojO1
k?nW`N`00_nW`N`01?l0003oYl7/ojO1k?nW`N`2ojS0j`GoYl7/1onX`>/00onW`>_oZL3[ojW0j`06
ojW0jaOooooo00?o0000ooooooooool0<?ooool001oooooo0_l0001Rooooo`goYl;/4?nW_n/9ojRn
jPKoYkkZ2onX_nX2ojRnjPGoZ<3[2_nX_nX5ojS0j`SoZ;oZ00?oYkkZojW0j_nY`>X01_nY`>X6ojRo
jP03ojW0j_nX_n[oZ;oZ00KoZ;oZ1_nV_n/00onX_n[oY[o/o`000002o`0000CoY[o/1OnW`N`00ol0
003oY/3/ojK0k008ojO1k0CoZ<3[1?nW`>/8ojW0jaKooooo00?o0000ooooooooool0<?ooool001oo
oooo00?o0000ooooool00000Goooool<ojO2k13oYko[3OnX_^X2ojNnjPgoZ;oZ00?oYl3[ojS0jonX
`>/01_nX`>/6ojRojPWoZ<3[1_nX_nX2ojS0j`SoZL3Z1?nX_nX4ojW0jPSoZ;oZ0_nV_n/2ojRojP?o
00002?nV_n`2ojO1k0?oY/3/00?o0000ojK0k?nV`>`02?nW`N`00onX`>_oYl3[ojO0j`05ojO0j`Ko
ZL3[00?oZ<3[ooooooooool05Oooool00ol0003oooooooooo`0_ooooo`003?ooool5o`0000?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`04o`000?ooooooooooo`0005_ooooo3?nW`^`@ojNo
j`ooZ;kZ0_nX`>/<ojRojPCoYl3[2?nX`>/2ojRojPgoZ<3[0_nX_nX6ojS0j`SoZL3Z00?oZ;oZojW0
j_nY`>X01OnY`>X6ojRojP03ojW0j_nX_n[o000000;o00001?nX_nX6ojJok003ojNojonV`>coY/3/
00?oY/3/00Co0000ojK0k?nV`>coY/3/1_nW`N`00onV`>coYl3[ojO0j`07ojO0j`;oZL3[1OnX`>/G
ooooo`03o`000?oooooooooo02kooooo000<ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo0_l00002ooooo`03o`000?oooooooooo05Gooooo0_nW
`N`:ojO2k13oYko[3onX_^X6ojS0j`WoZ;oZ1onW`>/6ojS0j`03ojO1k?nX`>_oZ<3[00coZ<3[00?o
Z<7/ojS0jonX`>/01onX`>/6ojW0jP03ojS0jonY`>[oZL3Z00OoZL3Z0_nX_nX2ojW0jP?o00002?nX
_nX2ojJok0GoYko[1OnV`>`01?l0003oY/3/ojK0k?nV`>`2ojO1k0GoY/3/1onW`>/00onW`NcoZ<3[
ojS0j`06ojS0jaKooooo00?o0000ooooooooool0;_ooool000Cooooo1_l00003ooooo`03oiRHV?lQ
8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4005ooooo`;o00001?ooool00ol0003ooooo
ooooo`1Aooooo`KoYl7/1onW`^`?ojNoj`03ojNnj_nX_^[oZ;kZ00coZ;kZ0_nW_n/8ojS0j`KoZ;oZ
2_nW`>/2ojS0j`GoYl7/2_nX`>/5ojS1k0WoZ<3[0_nY`>X5ojS0j`OoZL3Z00?oZ<3[ojW0j_l00000
0_l00004ojW0jPKoZ;oZ00?oZL3ZojNojonW_n/01_nW_n/5ojK0k003o`000?nV_^_oY[k[00SoY/3/
1?nW`>/4ojO1k0SoZ<3[5_ooool00ol0003oooooooooo`0]ooooo`003_ooool00onHV9So8B4Qonk^
kP03ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo04gooooo2_nW`N`4ojO2k0koYko[1OnW_^X:ojRnjPKoYko[2?nX`>/2ojRojPcoYl3[
00?oYko[ojO1k?nW`N`01_nW`N`6ojS0j`03ojNojonX`NcoZ<7/00KoZ<7/1_nX`>/2ojS1k0SoZ<3[
1?nY`>X2ojS0j`;o00002?nY`>X2ojRojPGoZL3Z2?nW_n/2ojK0k0;oY[k[00Co0000ojJnjonV_^_o
Y[k[2?nV`>`00onW`>_oYl7/ojO1k005ojO1k0OoZ<3[5oooool00ol0003oooooooooo`0/ooooo`00
3oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo04Wooooo3_nW`N`00onW`^coYko[ojNoj`0;ojNoj`Wo
YkkZ1_nX_^X:ojNoj`KoZ<3[00?oYl7/ojO0jonW`>/02_nW`>/4ojNoj`SoYl7/0_nX`>/5ojNoj`So
Z<7/0_nX`>/6ojS1k0SoZ<3[00?oZL3ZojS0jol000000_l00003ojS0j`KoZL3Z00?oZ<3[ojW0j_nY
`>X01_nY`>X6ojNoj`03ojVoj_nV_^_oY[k[00?oY[k[00?o0000ojJnjonV_^/01_nV`>`3ojJok0So
Yl7/1onX`>/Eooooo`;o0000;_ooool0013ooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo00?ooooo0_l00007ooooo`03o`000?oooooooooo04Kooooo3onW`N`00onX`>_o
Yko[ojNoj`09ojNoj`goYkkZ0_nX_^X>ojNoj`;oZ<3[1OnW`N`9ojO0j`OoYko[1_nW`N`00onW^^Oo
Yko[ojNoj`06ojNoj`KoZ<7/0_nW_NT8ojS1k0KoZ<3[0ol00007ojS0j`;oZL3Z1OnX`>/8ojW0jP;o
Yko[1OnY_nX5ojJnj`03o`000?nV_^_oY[k[00;oY/3/1onV_n`6ojO1k003ojK0k?nX`>_oZ<3[00Ko
Z<3[5_ooool00ol0003oooooooooo`0[ooooo`003?ooool01Ol0003o^[ZjoooooonHV9So410@00?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0@_ooool?ojO1k0GoZ<3[1onW_n/?ojNnjP;oYl3[3_nW_n/00onW`>_oYl7/ojO1k006ojO1
k0KoYl3[0_nW_>P8ojNoj`;oYl7/1OnW^^L8ojNoj`;oZ<7/1_nW_NT8ojS1k0;oZ<3[0ol00003ojS1
j`KoZ<3[00?oZ<7/ojS0jonX`>/01_nX`>/6ojW0jP03ojS0jonY_n[oZKoZ00KoZKoZ1OnV_^/00ol0
003oZ;oZojRojP09ojJok0;oYl7/1OnV`>`8ojS0jaGooooo00?o0000ooooooooool0:oooool000co
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo03kooooo3onW`N`9ojS0j`CoYko[3_nW_^X6
ojO0j`[oYko[1OnW`>/8ojO1k0;oYl3[1_nW_>P6ojNoj`03ojRchOnW^^OoYk[W00KoYk[W1_nW_n/2
ojRehPSoYkgY1_nX`N`3o`0000OoZ<7[0_nX`>/5ojS1k0SoZ<3[0_nY`>X5ojS0j`SoZKoZ0_nV_^/2
ojRojP04o`000?nX_n[oZ;oZojRojPKoY[o/0_nV_n/8ojK0k0KoZ<3[00?oYl3/ooooooooool05?oo
ool00ol0003oooooooooo`0Zooooo`007_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo03[ooooo3onW`N`=ojS0j`03ojNojonW_^[oYkkZ00coYkkZ2OnW`>/7ojNoj`SoYl3[1_nW`N`0
0onW^>GoYkcXojNlj007ojNlj0;oYko[1OnX/n48ojNji`;oYko[1_nX]N88ojNmj@;oZ<7/0ol00002
ojNkj0OoZ<7[00?oYk_XojS1k?nX`N`01_nX`N`6ojS0j`03ojS1k?nX`>_oZ<3[00KoZ<3[1_nY_nX0
0onY`>_oZ;oZojRojP03ojRojP04o`000?nX_n[oZ;oZojRojP;oY[o/1_nV_n/8ojK0k0;oZ<3[1OnW
`>`Fooooo`03o`000?oooooooooo02Wooooo000Mooooo`?o00002oooool00ol0003oooooooooo`0f
ooooo`;oYl3[3OnW`N`2ojS1k0goZ<3[3OnW_^X=ojO0j`OoYko[2?nW`>/2ojO1k0GoYkSU1onW_>P0
0onX[mcoZ;?QojRch@06ojRch@KoYk[W00?oZk3LojReh_nX]N801onX]N86ojNmj@?o00001_nW^nP4
ojS1j`CoYk_X2?nX`N`2ojS0j`GoZ<7/2?nX`>/2ojVojPGoZL3[1OnX_nX00ol0003oZ;oZojW0jP08
ojJoj`KoY/3/0_nV_n`7ojO0k1Kooooo00?o0000ooooooooool0:Oooool001gooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0booooo`KoYl3[2OnW`N`6ojS1k0WoZ<3[3OnW_^X00onW
_n_oYl3[ojO0j`0<ojO0j`WoYko[1_nW`>/00onW]>;oYkSUojNhi@06ojNhi@CoYkcX1?nX[m`7ojRc
h@CoYk[W1?n[/=`9ojRehP;oYkgY0ol00002ojVcg`SoYk_X00?oZ<7[ojNkj?nW^nP01OnW^nP6ojS1
k003ojNmjOnX`NcoZ<7/00KoZ<7/1onX`>/8ojW0j`CoZ;oZ00CoZL3Zo`000?nY`>[oZL3Z2?nV_n/2
ojK0k0KoY[o/1onW`>`Fooooo`03o`000?oooooooooo02Sooooo000Mooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool0;oooool00onW_n_oYl3[ojO0j`06ojO0j`KoYl7/00?oZ<;/ojS1
k?nX`N`01_nX`N`6ojS0j`coYkkZ1OnW_n/:ojO0j`goYko[0_nW`>/5ojNdhPSoYkSU00?oYkcXojR_
g?nX[m`01OnX[m`7ojRch@03ojNjion[/=coZk3L00GoZk3L1onX]N83o`0000KoZK?O1_nW^nP00on[
/mooYk_XojNkj007ojNkj0;oZ<7/1OnW_NT8ojS1k0OoZ<3[2?nY`>/01OnX_n[oZL3ZojW0j_nY`>[o
000000?oZL3Z1_nV_n/00onW_n_oY[o/ojJok006ojJok0OoYl3/5oooool00ol0003oooooooooo`0W
ooooo`007Oooool2o`0000oooooo00?o0000ooooooooool0:oooool5ojNoj`SoYl3[0_nW`N`5ojS2
k0SoZ<7/0_nX`>/<ojNnjPWoYko[1_nW`>/?ojNoj`;oYk;P1onW]>86ojNhi@03ojZ]fOnX[mcoZ:oL
00OoZ:oL1OnX/n400on][MOoZk3Loj^`g007oj^`g0CoZ;GR0_l00002ojn`f@SoZK?O0_nW^nP5oj^c
g`OoYk_X00?o[;GPojNmjOnW_NT01_nW_NT6ojS1k003ojNnjonX`>_oZ<3[00KoZ<3[1_nY`>/2ojS0
j`CoZL3Z00Co0000ojW0j_nY`>[oZL3Z0_nV_n/5ojNoj`SoY[o/1onW`>`Fooooo`03o`000?oooooo
oooo02Oooooo000Mooooo`03o`000?oooooooooo00oooooo0_l0000Xooooo`WoYko[1_nW`>/9ojS2
k0KoZ<7/3OnW_^X<ojNoj`;oYl3[3onW_n/6ojNbh0OoYkCR0_nW^>D5ojZ]f@WoZ:oL00?oZ;?Qojf]
eon][ML00on][ML9oj^`g0?o00001On_/=T6ojVcg`03ok6af?n[/mooZk?O00KoZk?O1?nW^nP4ojbe
h0SoYkgY0_nX`N`5ojNnj`SoZ<3[0_nY`>/6ojS0j`CoZL3Z00?o0000ojW0j_nY`N/02?nW_n/7ojJo
k0SoYl3/5_ooool00ol0003oooooooooo`0Vooooo`007Oooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo02;ooooo3OnW_n/2ojO0j`goZ<;/0_nX`N`>ojNnjQcoYko[00?oY[3OojNbh?nW
/^001onW/^05ojNdhP03ojVZeonZ[MWoZZgI00KoZZgI1onX[m`00on/ZMCo[JgGojf]e`05ojf]e`Go
Zk3L0ol00008ojn`f@CoZK?O1?na/MP8oj^cg`03ojNkj?n/]N3o[;GP00Go[;GP1_nW_NT00onZ]n?o
Ykk[ojNnj`06ojNnj`KoZ<3[00?oYl3[ojS0jonX`>/01onX`>/2ojW0jP;oZL7[00?o0000ojW1jonY
`N/02?nW_n/7ojJok0SoYl3/5_ooool00ol0003oooooooooo`0Uooooo`007Oooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo01kooooo0_nW_^/=ojNoj`;oZ<7/3OnX`^`2ojNojPgoYkkZ
6onW_n/5ojJ`g`WoYk;P00?oYkCRojVZeonYZ]L00onYZ]L8ojZ]f@CoZ:oL1?n/ZM@7ojf]e`04oj^`
g?l0003o0000o`0000Co[jcD2?n_/=T00onY/moo/K7Hok6af005ok6af0KoZk?O00?o/k?Hojbeh?n/
]N001on/]N02ojNmj@GoZ[OS2?nW_^/2ojS0j`GoYl3[2?nX`>/4ojW1j`04o`000?nY`N_oZL7[ojW1
j`KoYko[00?oZL3ZojJok?nV_n`01_nV_n`6ojO0k003ojK0k?oooooooooo01Cooooo0_l0000Voooo
o`007?ooool3o`0001Cooooo00?o0000ooooooooool06_ooool6ojNnj`WoYko[1_nX`N`9ojS2k0Ko
YkoZ2OnW_^X=ojNoj`03ojO0jonW_n_oYko[00coYko[2?nV/=l7ojNbh003ojNXe_nYZ]OoZJ[G00Go
ZJ[G2?nZ[MT00onX[mco[:WDojbYe004ojbYe0Go[JgG0ol000000on[/=co[jcDojn/e005ojn/e0Ko
[k3I00?o/joDok6af?na/MP01_na/MP4oj^cg`Co/k?H1on/]N000ond]][oZ[OSojZgh`06ojZgh`Ko
Ykk[00?oZ;_WojO0jonW`>/01_nW`>/8ojS0j`CoZL7[00Co0000ojW1jonY`N_oZL7[0_nW_n/5ojW0
jPSoY[o/0_nW`>`5ojK0k1Cooooo00?o0000ooooool000009_ooool001cooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`0Gooooo`;oYko[1onW_^/6ojNoj`;oYl3[1onX`N`6ojS2k003
ojS0jonW_n[oYkoZ00KoYkoZ1_nW_^X<ojNoj`GoYl3[2_nW_n/<ojJ`g`CoYk;P1?nWZ=H7ojVZe`Ko
ZZgI00?o[:SDojbYe?n/ZM@01_n/ZM@01?n][MOo0000o`000?l00002ojf]e`03ok6]e?n_[=Co[jcD
00Ko[jcD1?n_/=T4ok>_e0So/K7H00?oZk?Ook>cf?nc/mP01Onc/mP4ojbeh0Co];KJ2?nZ]n<2ojNn
j`GoZ;_W2?nW`>/8ojS0j`CoZL7[00?o0000ojW1jonY`>/02?nY`>X6ojJok003ojJojonV`>coY/3/
00KoY/3/5_ooool00ol0003oooooooooo`0Sooooo`002_ooool4o`000008oa0@4?ooooooooooonk^
k_lb<S;o0000oc8b<_o^k^h6ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool04ooo
ool6ojNoj`OoYkk[0_nW_n/6ojO0j`OoZ<7/0_nX`^`5ojS0j`SoYkoZ0_nW_^X<ojNoj`03ojO0k?nW
`>_oYl3[00KoYl3[1_nW_n/00onV/N3oY[3OojJ`g`0=ojJ`g`03ojNbh?nWZ=KoYjSF00CoYjSF2?nY
Z]L2ojZ]f@Go[:SD1On/ZM@3o`0000?o[JgG1?na[M@8ojn/e003ojn`fOnc[mCo/joD00Go/joD1_na
/MP00onf/]Go/k?Hok>cf007ok>cf003ojbeh?nd]][o];KJ00Go];KJ1_nZ]n<00onb^=koZ;_WojRk
i`06ojRki`KoYl3[0_nW_^/8ojS0j`;oZL7[00?oZL3[o`000?nY`>/00_nY`>/8ojW0jP;oY[o/1OnV
_n/8ojK0k1Gooooo00?o0000ooooooooool08oooool000cooooo00?o0000ooooooooool00_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`0?ooooo`;oZ<3[2?nW_n/5ojNnj`[oYl3[1onX`N`7ojS0j`KoYkoZ0onW_^/9ojNoj`GoYl3/2?nW
`>/2ojNoj`GoY[7P3OnV/=l00onVYmKoYjSFojNXeP06ojNXePKoZJ[G00?o[:[EojbXe?n/Z=@01On/
Z=@2ojbYe0?o00000on/ZM@00on][MOo/JgDok6]e005ok6]e0Ko[jcD00?o][KHok>_e?nc[m@01_nc
[m@4ok6af0Co][;E1onc/mP00onh]=Ko];KJokBffP06okBffPCoZ[OS1?nb^=h8ojRki`;oYl3[1_nW
_^/6ojS0j`03ojO1k?nY`>_oZL3[00;oZL3[00Co0000ojW0jonY`>_oZL3[1onY`>X7ojJoj`KoY/3/
0_nV_n`Fooooo`03o`000?oooooooooo02;ooooo00000ooooooo0000o`000004o`0000Gooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Kooooo0_l0000Iooooo`03o`00
0?oooooooooo00_ooooo1_nX`>/8ojNoj`03ojNnjonW`>_oYl3[00coYl3[1onX`N`7ojS0j`;oYkoZ
1onW_^/5ojNoj`WoYl3/1_nW`>/00onV]>;oY[7PojJah006ojJah0WoY[3O1OnVYmH7ojNXePCoZJ[G
1?n/Z]D6ojbXe0;o00001On/ZM@00onb]=[o/JgDok6]e006ok6]e0Co[jcD1?nf]]P8ok>_e003ok6a
f?nf/]Go][;E00Go][;E1Onc/mP3okRdePSo];KJ00?oZ[OSok:hg_nb^=h01Onb^=h6ojRki`;o[K[S
2?nW_^/2ojS0j`GoYl7/1?nY`>/01?l0003oZL3[ojW0jonY`>/7ojW0jPOoY[o[0_nV`>`6ojJok1Ko
oooo00?o0000ooooooooool08Oooool000cooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`08ooooo`;o
Z<7[1onX`>/7ojNoj`koYl3[00?oZ<;/ojS1k?nX`N`01_nX`N`5ojS0j`?oYkkZ2?nW_^/00onW_n_o
Yl3/ojO0k00;ojO0k0;oYl3[1OnV]>87ojJah0KoY[3O00?oY:KGojJWe_nVYmH01_nVYmH7ojNXeP03
ojVZeon/Z]Go[:[E00Co[:[E0on/Z=@3o`000003ojbXe?n/ZMCo[:WD00;o[:WD1?nb]=X8ok6]e003
ojn/e?nf]]So][KH00Go][KH1_nc[m@00onj_=co][;EokJbe@06okJbe@?o/k?H1_nh]=H6okBffP03
okRfeonb^=ko/[SN00Oo/[SN0_nX^nL6ojfjh`KoYkk[00?oZ;gYojO1k?nW`N`01OnW`N`5ojW0j`03
o`000?nX`>_oZ<3[00OoZL3Z1_nV_n/2ojNoj`SoY[o/5Oooool00ol0003oooooooooo`0Qooooo`00
3?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo00Gooooo1OnX`N/7ojS0j`OoYko[2_nW`>/5ojS2k0So
Z<7/00?oZ<3[ojNnj_nW_^X01OnW_^X6ojNnj`03ojO0jonW`>coYl3/00_oYl3/00?oY[OUojJdh_nV
]>801_nV]>87ojJah0;oY[3O1OnTY]L7ojJWePKoYjSF00?oZZ_HojbZeOn/Z]D01On/Z]D3o`0000Go
[:SD00?o[:WDok:df_nb]=X01Onb]=X6ok6]e003okK3i?nf]]So][KH00Ko][KH1?nc[m@4okZlg0So
][;E00?o/k?HokRde_nh]=H01Onh]=H4okBffPCo^;KG1onb^=h00onh^M[o[K[Sojfjh`07ojfjh`;o
Ykk[1OnX_NT7ojO1k0;oZL3[0_nX`>/01?l0003oZ<3[ojS0jonX`>/7ojW0jP;oY[o[1_nW_n/7ojJo
k1Kooooo00?o0000ooooooooool08?ooool000cooooo00?o0000ooooooooool00_ooool01Ol@413o
oooooooooooooooo410@00Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`02oooo
o`SoZ<7[1OnX`>/2ojJnj`OoYko[1_nW`>/2ojS1k0OoZ<;/1_nX`N`:ojNnjP;oYkk[1OnW`>/9ojO0
k0GoY[OU2?nV]>85ojJah003oj>Vf?nTY]OoY:KG00GoY:KG2?nVYmH2ojNXePGoZZ_H0on/Z]D3o`00
0003ojbZeOn/Z=Co[:SD00Co[:SD00?o/KgRok:df_nb]=X01_nb]=X4ok6]e0Co]/?T2?nf]]P00onc
[mCo^[cLokZlg005okZlg0Ko][;E00?o_;oLokRde_nh]=H01onh]=H00ond]][o^;KGokRfe`05okRf
e`Co/[SN1?nh^MX7ojfjh`03okBlgonX_NWoZ;gY00GoZ;gY1_nW`N`00onW_n_oZ<3[ojS0j`03ojS0
j`03o`000?nX`>_oZ<3[00KoZL3Z0_nY`N/8ojNoj`OoY[o/5_ooool00ol0003oooooooooo`0Ooooo
o`003?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2o`00
01kooooo00?o0000oooooonX`N/02_nX`N/00onX`>_oY[k[ojJnj`04ojJnj`OoYko[0_nW`>/6ojS1
k0OoZ<;/0_nX`N`<ojNnjP;oYko[1onW`>/6ojO0k003ojNlj?nV]nGoY[OU00GoY[OU2?nV]>800onV
/N3oXjKHoj>Vf003oj>Vf0OoY:KG1_nVYmH00onX[=[oZZ_HojZ[f005ojZ[f0?o00001On/Z]D2ojbX
e0Go/KgR2?nb]=X00ona[MCo]/?TokK3i005okK3i0Ko][KH00?o]<c/okZlg?nj_=`01_nj_=`4okJb
e@Co_;oL1onh]=H00onn_][o^;KGokRfe`07okRfe`03ok:hg_nh^M[o^;WJ00Go^;WJ1?n]^^<4okBl
g`OoZ;gY0_nW`N`5ojNoj`GoZ<3[00?o0000ojS0jonX`>/00_nY`>X6ojW1j`KoYko[00?oZ<3[ojJo
k?nV_n`01_nV_n`Eooooo`03o`000?oooooooooo01oooooo000:ooooo`03oeEEEOmVIVKo000000Co
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo01cooooo3OnX`N/2ojNo
j`OoY[k[1OnW_n/2ojO0j`SoZ<7/1OnX`^`3ojRoj`WoYkkZ1_nW_n/7ojO0j`;oYl3/1OnW_>P7ojJg
i@KoY[CR00?oXZOJoj>Vf?nSY]P01OnSY]P6ojBVe`CoYZOF1?nX[=X3ojZ[f0?o000000?oZZ_HojbZ
eOn/Z]D01?n/Z]D00on^aN_o/KgRok6mhP06ok6mhPKo/[CJ00?o[<obokK3i?nf`n@01_nf`n@4okJf
f0Co]<c/2?nj_=`00onf/]Go_;oLokbog005okbog0Go^;CF0onn_]X7okRfe`03okjleonh^M[o^;WJ
00Oo^;WJ00?o[K[SokBlgond_=l01?nd_=l6ojRmj@03ojbmi_nW_n_oYko[00KoYko[1OnX`>/00ol0
003oZ<3[ojS0j`08ojW1j`;oYko[1OnX`>/8ojJok1Gooooo00?o0000ooooooooool07_ooool001_o
oooo00?o0000ooooooooool06_ooool3ojS0j`WoZ<7[1_nW_n/7ojJnj`03ojNojonW`>_oYl3[00Co
Yl3[2?nX`N`00onX`^coZ;o[ojRoj`05ojRoj`GoYkkZ0_nV_n/8ojNoj`GoYl3[0_nX_n/7ojNlj0Oo
Y[OU0_nV]>85oj:WfPKoXjKH1onTY]L00onVYmKoZ:cJojR/fP04ojR/fP?o00001?nZZmP4ojbZe@Co
[/G[2?na_N82ok:dfPGo[<ob2?nf`n@00onf]]So]<c/okC<k005okC<k0Ko^[cL00?o/Lk_okbog?nl
_m`01_nl_m`3okRdePKo_[kJ1Onh]]L3okjle`Oo^;WJ00?o_;_HokBlgond_=l01_nd_=l2ojRmj@Go
[;gV2?nW_n/4ojS0j`04o`000?nX`>_oZ<3[ojS0j`OoZL7[2?nX`>/7ojJok1Kooooo00?o0000oooo
ooooool07Oooool001_ooooo00?o0000ooooooooool05oooool7ojS0j`OoZ<7[2?nW_n/5ojJnj`;o
Yko[1onW`>/8ojS1k0SoZ;o[00?oYkkZojJojonV_n/01?nV_n/8ojNoj`03ojO0jonX_n_oZ;o[00Co
Z;o[1onW_>P3ojJgi@?oXJWL2?nRYmX6oj>Vf0GoY:KG00?oYJ_KojR/f_nX[=X00_nX[=X3o`000003
ojR/f_nZZmSoZZ_H00GoZZ_H00?o[:[Eojk5jon^aN/01On^aN/6ok6mhP;oW][l1on/co86okK3i0;o
WMWl1ondc>`4okZlg0Co/Lk_2?nl_m`00onh]=Ko_[kJokjnfP05okjnfP?o^;KG1_nn_=L5okRifP?o
_;_H1_nd_=l00onj_]go[;gVojbmiP06ojbmiPSoYko[1?nX`>/01?l0003oZ<3[ojS0jonX`>/7ojW1
j`SoZ<3[1onV_n`Dooooo`;o00007oooool001_ooooo0_l0000Fooooo`?oYko[1onX`>/7ojS1j`So
Yko[00?oY[k[ojNojonW_n/01?nW_n/7ojO0j`SoZ<7/1_nX_n/2ojJnj`OoY[o[1_nW_n/00onW`Nco
Z;o[ojRoj`06ojRoj`GoYkcX00?oXJcOoj6Yg?nQZM`01OnQZM`7oj:WfPOoXjKH00?oY:KGojF[fonU
Zm/00onUZm/00onX[=[o0000o`000004ojR/fPKoZZ_H0_nYb_48ojk5j`;o/KgR1_nNf_`7ojc?lP;o
]/?T1_nMfO`7okC<k003okZlg?nac^oo/Lk_00Go/Lk_1_nl_m`00ondc>co_[kJokjnfP07okjnfP03
okRfeonn_=Oo_[cG00Go_[cG0onh^MX5okbkf0Co];cO1?nj_]d8ojbmiPSoYko[1?nX`>/00ol0003o
Z<3[ojS0j`08ojW1j`OoZ<3[1onV_n`Fooooo`03o`000?oooooooooo01cooooo000Jooooo`03o`00
0?oooooooooo01?ooooo1onW_n/5ojS0j`WoZ<7[1_nW_n/00onV_n_oYko[ojNoj`06ojNoj`GoYl3[
0onX`^`7ojS1k0;oZ;o[1_nV_^/7ojJoj`;oYko[1OnW`N`8ojRoj`03ojNlj?nQ[=ooXJcO00?oXJcO
1onQZM`7oj:WfP?oXjKH0onSZ=X4ojF[f`?o00001onX[=X2ojZ[f0KoZL[a1_n^aN/3ohkQo@OoW][l
0on/co85ogOKn@OoWMWl0ondc>`4ohkJo`Oo/Lk_1?nl_m`4okC<k0Oo_[kJ00?o^/WUokjleonn_=L0
1onn_=L00onh^M[o_;_Hokbkf005okbkf003okBlgonj_]go^[kM00Go^[kM1_n/_NH2ok2oi@SoYko[
1?nX`>/00ol0003oZ<3[ojS0j`08ojW1j`OoZ<3[1onV_n`Eooooo`03o`000?oooooooooo01cooooo
000Jooooo`03o`000?oooooooooo00oooooo3?nW_n/00onX`>_oZ<7[ojS1j`0;ojS1j`;oYko[1OnV
_n/8ojNoj`03ojO0jonX`^coZ<;/00GoZ<;/1OnX`N`:ojJnj`GoY[o[0_nW`>/7ojO1k0KoZ;o[00?o
Xk;Roj6/gonQ[=l01OnQ[=l6oj6Yg0KoXZOJ00?oWjGIoj>Xf_nSZ=X01OnSZ=X3o`0000CoYJ_K1OnX
[=X3ojO=m0OoZL[a0_n^aN/8ohkQo@?oW][l1OmBc>T6ogOKn@?oWMWl1OmAb?06ohkJo`Oo/Lk_00?o
_;oLokC<k?ndc>`01Ondc>`4okjnfPCo^/WU1onn_=L00oo0a=go_;_Hokbkf005okbkf003ol70fOnj
_]go^[kM00Oo^[kM0_n/_NH6ok2oi@OoYko[1?nX`>/00ol0003oZ<3[ojS0j`08ojW1j`OoZ<3[1_nV
_n`2ojFok1Gooooo00?o0000ooooooooool06oooool001[ooooo00?o0000ooooooooool02oooool?
ojNoj`03ojS0jonX`N_oZ<7[00_oZ<7[0_nW_n/7ojJoj`KoYko[0onX`N/7ojS2k003ojS1k?nV_^_o
Y[k[00coY[k[00?oY[o[ojO0jonW`>/01?nW`>/7ojO1k0;oZ;o[1OnS/^87oj6/g`KoXJWL0_nRYmX5
oinUf@?oXjSJ0ol000000onSZ=[oYJ_KojF[f`05ojF[f`03ojR/f_nWcOCoYlgd00GoYlgd1OnYb_44
oh;Rn0CoS^7m1_mDcNX3oe;<j@GoG<Oj1_lo_>`6oe78l0KoS][o0onac^l4oh_Fo`So]<c/00?o_[kJ
ok[9iOnjbND01OnjbND5okjle`?o`<CM1Onl^mP3ol70f@Oo^[kM00?o_<3Lok2oiOn`_nD01on`_nD7
ojNoj`CoZ<3[00?o0000ojS0jonX`>/02?nY`N/7ojS0j`;oY[o/1_nU_n`Eooooo`03o`000?oooooo
oooo00Kooooo1Ol0000?ooooo`006_ooool2o`0000Wooooo3onW_n/5ojS0j`WoZ<7[1_nW_n/7ojJo
j`;oYko[1onX`N/5ojS2k0;oZ<3[3OnV_^/00onW_n_oYl3[ojO0j`06ojO0j`GoYl7/0_nV^NL7oj>b
hPOoXJcO0onQZM`2oifRf0OoWjGI0ol00004oj>XfPKoYJ_K0_nVcO@8ojO=m003ojW:lOn2h_SoP^;h
00GoP^;h1?mWeo83oeC=jPKoO]7o0omLaoX5ohk2n@KoJ/;n1_ln]?<5od:kl0KoRmKo1_ndc>`00onG
dOco^/WUok[9i@06ok[9i@?o_[cG1_o0a=d3okbkf0Go`L3I1Onj_]d3okc0g0Oo/;oU00?o]<;TojNo
jonW_n/01OnW_n/5ojS0j`03o`000?nX`>_oZL7[00OoZL7[2?nX`>/8ojFok1Cooooo00?o0000oooo
ooooool01_ooool01OnHV9So8B4Qonk^k_ooooooA4A400oooooo000Jooooo`03o`000?oooooooooo
00Kooooo0_nX`>/<ojNoj`;oYl3[1onX`>/6ojS1j`?oZ<3[1_nW_n/5ojJoj`?oYl3[2?nX`N/00onX
`^coZ<3[ojS0j`04ojS0j`WoY[k[1OnW_n/8ojO0j`03ojO1k?nV^NOoY[WW00CoY[WW1_nS/^86oj6/
g`03oibSfOnMX]SoWJ;H00CoWJ;H0onOYMT3o`000003oinUfOnSZ=[oXjSJ00GoXjSJ0_nUZm/6ojK=
m0KoYlgd1?n0hoD2oh;Rn0CoImOb1OnCd_d6ogkAo`;oWK[]2?n>`_T3of[2oP?oT[O`1om]_?d2ocZ[
m0;o@[_`1_n;e_l2okC<k0GoUm7l2?njbND00onn_=Oo`<CMol34g@06ol34g@03okbkf?o1`=Wo`L3I
00Co`L3I0onj_]d6okc0g0Co/;oU1?nd`^@7ojNoj`CoZ<3[00?o0000ojS0jonX`>/02?nY`N/8ojS0
j`OoYKo/5Oooool00ol0003oooooooooo`06ooooo`03oiRHV?lQ8B7ok^k^013ooooo000Jooooo`03
o`000?oooooooooo00?ooooo1_nX`>/8ojNoj`KoYl3[1onX`>/2ojS1j`OoZ<3[1_nW_n/00onV_n_o
Yl3[ojO0j`05ojO0j`KoZ<7[00?oZL;/ojS0jonX`>/01_nX`>/7ojJnj`OoYko[1_nW`>/00onX_n_o
Y[WWojJii`06ojJii`KoXk;R0_nQ[=l5oibSf@GoWJ;H0ol00004oinUf@KoXjSJ0_nVbO88ojK=m0;o
Ylgd1?n0hoD5og_Pm`?oW]7j1onCd_d2ogkAo`KoWK[]1_n>`_T00onU]^CoT[O`oi:gl005oi:gl0Oo
KKcm1_ljZo@5odZkmPKoUm7l1_njbND00onYbo;o`<CMol34g@06ol34g@03ok[8iOo1`=Wo`L3I00Ko
`L3I00?o^[kMokc0g?nl`=`01_nl`=`00on`_nGo]<;TokC2i004okC2i0KoYko[1_nX`>/00ol0003o
Z<3[ojS0j`08ojW1j`SoZ<3[1onU_n`Eooooo`03o`000?oooooooooo00Kooooo00?oV9RHob4Q8Oo^
k^h03oooool001[ooooo00?o0000ooooooooool00_nX`N/8ojS0j`GoYko[0_nV_n/7ojO0j`GoZ<3[
0onX`N/8ojS0j`?oYko[1?nV_n/7ojO0j`;oZ<7[1OnY`^`8ojS0j`OoY[k[1onW_n/2ojO0j`GoZ;o[
2?nV^NL3oj>bhP;oW:GL1onLXmT2oifRf0?o00000_nMX]P6oinUf@;oXjSJ1_nVbO86ojK=m0?oQnKf
1?n;i_P2og_Pm`SoW]7j0onCd_d3ojFgiPSoWK[]0_n>`_T5ojFfi0OoT[O`0om]_?d4oi2dk`OoH[?k
0_ldXo82odZkmPKoUm7l0_njbND5ojW;lPKo`<CM0onjb>D6ol70f@03ol?4fonl`=co_<3L00Ko_<3L
00?o`<?LokC2i?nd`^@01_nd`^@2ojNoj`[oZ<3[00?o0000ojS0jonX`>/02?nY`N/7ojS0j`OoYKo/
5Oooool00ol0003oooooooooo`07ooooo`03ogMgMomVIVKooooo00kooooo000Iooooo`03o`000?nX
`N_oZ<7[00CoZ<7[2?nX`>/00onW_n_oY[o[ojJoj`04ojJoj`OoYl3[00?oZ<3[ojS1jonX`N/01OnX
`N/6ojS0j`WoY[o[1OnW`>/2ojS1j`OoZL;/1_nX`>/9ojJnj`GoYko[0onX`N`6ojRoj`KoY[WW00?o
WJ[PoibUg?nLYM`01?nLYM`5oibSf@?o00001_nMX]P3oinUf@CoY<;^1onVbO82ojK=m0?oQnKf1on;
i_P3ojGCn0KoW]7j00?oYkKTojFgi_nU]nH01OnU]nH6oifjk@03oj^ehOnU]^CoYKKT00KoYKKT1OnB
]o000onY]n?oT;C_oi2dk`06oi2dk`OoH[?k1OldXo85ofS3oPOoZL_b0oo0a=d5ok[8i@Go`L3I0oo3
a=/6okc0g0?o`<?L1_nd`^@2okO4i0coZ<3[00?o0000ojO0jonW`>/02?nY`N/7ojS0j`OoYKo/5Ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00gooooo000Iooooo`03o`000?nX`N_o
Z<7[00GoZ<7[1_nX`>/2ojNoj`OoY[o[1OnW`>/3ojS0j`OoZ<7[0_nX`>/=ojJoj`03ojO0jonX`N_o
Z<7[00CoZ<7[1onY`^`2ojS0j`goY[k[00?oYko[ojS1k?nX`N`01OnX`N`6ojRoj`;oY[WW1OnMZ^06
oibUg0;oW:?I0_l00002oibSf@KoWJ;H00?oX;OYojC2k_nT`^h01_nT`^h5ojK9lPCoTnWi1?nGk?L2
oh_Vn0OoYM?h0_nNdOX5ojNfi0OoYKOV0_nM^^d5oj^eh@SoYKKT00?oT[O`ojVghonY]n<00onY]n<8
oi2dk`?oH[?k1?n4/o@3od^Vn0;o=:?b1OmX`oh7ojW;lP03ol34gOnjb>Go^/SU00Co^/SU0oo1`=T6
ol?4f`?o_<3L1_o0`m`3okC2i0Go]lCT2OnX`>/2ojO0j`04o`000?nW`>_oYl3[ojO0j`OoZL7[1onX
`>/6ojFok0;oY[o/4oooool3o`0000Cooooo00Go0000okZj^_ooooooV9RHoa0@400?ooooo`003_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooooonX`N/01_nX`N/2ojS0j`KoYko[
1onV_n/00onW`>_oZ<3[ojS0j`05ojS0j`GoZ<7[0_nX`>/=ojJoj`;oYl3[1onX`N/5ojW2k0?oYko[
2_nV_^/4ojNoj`SoZ<7/0onX_n/3oj6bi0OoWJ[P1?nLYM`3o`0000GoW:?I0_nMX]P5oj2gj@SoY<;^
00?oY/Wboi?YnOnCjOT00_nCjOT6oiO/m`?oZMWh1_nUdoP9ojNfi0GoYKOV00?oZkGPoj^ehOn[]N40
1_n[]N46ojFfi003ojnhh?nY]n?oZKOS00GoZKOS1_n@]>l2ojNhi@OoQ;?d1_m;Y_P2ocjWmP;oJ<?n
0onYbo84oi79n`Oo^/SU00?o`L3Iol?4foo3a=/01_o3a=/00onl`=co`<?Lol33g006ol33g003okC2
i?nga>Co]lCT00Go]lCT1onX`>/4ojO0j`04o`000?nW`>_oYl3[ojO0j`OoZL7[1onX`>/2ojFok0Ko
Y[o/5?ooool00ol0003oooooooooo`02ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03oooool000ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00GoZ<7[0onX`>/7ojNo
j`GoY[o[0onW`>/7ojS0j`03ojS1jonX`>_oZ<3[00CoZ<3[2OnV_n/6ojO0j`OoZ<7[00?oZL;/ojNo
jonW_n/01OnW_n/5ojJnj`WoYko[1_nX`N`00onV_NWoXK;Toj6bi005oj6bi0KoWJ[P00CoW:GLo`00
0?l0003o00000onLYM`3oibSf@;oVj_R2?nP]nT6ojC2kP?oWnOl1?nPl?@2oiO/m`OoZMWh0_nUdoP=
ojNfi003ojFgi_n[]N3oZkGP00?oZkGP2?n[]N42ojFfi0Go[kSP1onY]n<2oi2dk`KoYkSU1on4/o@6
od^Vn0Go?ZOf1_nAbO/5ok[8i@03ojo7k?o3a=_o`lCK00Ko`lCK00?o`/ONol33g?o0`m`01_o0`m`0
0oo2a]go]lCTokO4i005okO4i003okW6i?nX`>_oZ<3[00KoZ<3[1?nW`>/00ol0003oYl3[ojO0j`07
ojW1j`SoZ<3[2?nV_n`Dooooo`03o`000?oooooooooo01Gooooo000>ooooo`05oa0@4?oooooooooo
ooooool@41001_ooool2o`0000;ooooo00?oZ<7[ojS0jonX`>/01OnX`>/7ojNoj`03ojJojonW`>_o
Yl3[00GoYl3[1OnX`>/2ojS1j`OoZ<3[1OnV_n/3ojNoj`OoYl3[1OnX`N/3ojW1j`OoYko[00?oY[k[
ojNojonW_n/02onW_n/2ojS1k0GoY[gY1onQ/^@3oifZh0?o00000onLYM`3oiNRg0KoVj_R2?nP]nT2
ojC2kPCoWnOl1OnPl?@3ojkRn@KoZMWh00?oYkSUojNfi?nW]^@03?nW]^@00onY]>7oZkGPoj^eh005
oj^eh0KoZkGQ00?o[KSQojnhh?n_^>001_n_^>05ojVgh`;o/K_Q2?nW^>D3ohBcm0CoV[O/1OmX[OP4
oc^Kl`;o?ZOf1_nAbO/00onjb>Go[lO/ojo7k003ojo7k0Ko`lCK0oo2amh6ol33g0?o`/KM1?nga>@4
okW6i0SoZ<3[1?nW`>/00ol0003oYl3[ojO0j`07ojW1j`SoZ<3[1_nV_n`00onV_n_oooooooooo`0C
ooooo`03o`000?oooooooooo01Cooooo000>ooooo`05o`000?ooooooooooooooool000001_ooool0
0ol0003oooooooooo`03ooooo`OoZ<3[0onW_n/5ojJoj`OoYl3[00?oZ<3[ojS1jonX`N/01?nX`N/7
ojS0j`03ojJojonW_n_oYko[00GoYko[1onW`>/00onX`N_oZL7[ojW1j`05ojW1j`GoYko[0_nV_^/<
ojNoj`;oZ<7[1onV_NT6oj6bi0?o000000?oWJ[PoiJQg?nFXM`01onGX]`6oi^[hPKoX;OY1?nXgOX0
0onOiocoX?3doj3`m003oj3`m0Oo[^;i00?oZMWhojNhiOnW^>D00onW^>D:ojNfi0GoZKCQ1_n[]N04
oj^eh@Co[KSQ2?n_^>000onY]n?o/K_Qok6kh@04ok6kh@KoYkSU00?o/KgSoiZgk?nJ]n`01_nJ]n`5
ofR]n0Go>i_c1_me_?`7ojo7k0?o`lCK1_o2amh3ol33g0Ko`/KM00?o]lCTokW6i?nia^@01Onia^@6
ojS0j`03ojS1jonW`>_oYl3[00;oYl3[00?o0000ojO0jonW`>/02?nY`N/8ojS0j`;oY[o/1OnV_n/D
ooooo`03o`000?oooooooooo01Cooooo000>ooooo`05o`000?ooooooooooooooool000001Oooool0
0ol0003oooooooooo`05ooooo`GoZ<3[0_nW_n/8ojJoj`GoYl3[0_nX`>/7ojS1j`GoZ<3[0onV_n/7
ojNoj`?oYl3[1?nX`N/8ojW1j`03ojNojonV_^_oY[k[00CoY[k[2?nW_n/6ojS1j`OoY[gY0_nQ/^@3
o`000003oiRWh?nFXMcoUZ7L00CoUZ7L1onGX]`6oi^[hP;oX;OY1_nXgOX4ojWcl`;oX?3d1on^h_T0
0onZ_nWoYkSUojNhi@05ojNhi@KoYkKT00?oYk?RojVdhOnY]>401_nY]>46oj^eh003oj^ehOn]^>7o
[KSQ00Go[KSQ1_n_^>000on`_>;o/K_Qok6kh@06ok6kh@;oYkSU1Ona_N<8oiZgk0GoJ:gh1OlkVo<6
ogFlo0Oo[lO/00?o`lCKol;7g_o2amh01_o2amh00oo0`mco`/KMol;6g@04ol;6g@03olC9g_nia^Co
^LKT00Oo^LKT0_nX`>/5ojS1j`CoYl3[00?o0000ojO0jonW`>/02?nY`N/7ojS0j`OoY[o[5Oooool0
0ol0003oooooooooo`0Cooooo`003_ooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000
ooooooooool01_ooool00onX`>_oYko[ojNoj`04ojNoj`SoY[o[00?oYl3[ojS0jonX`>/01?nX`>/7
ojS1j`03ojS0jonV_n_oY[o[00GoY[o[1OnW_n/2ojO0j`OoZ<7[1_nY`N/00onW_n_oY[k[ojJnj`06
ojJnj`OoYko[1onX`N/5ojJmj@?o00001OnHYn05oiJQg0OoUj;L1OnKZn83ojS=l`CoZ=gj1_nYlo<4
okGZm`;o[^;i1OnZ_nT7ojNhi@;oYkKT1OnW/n87ojVdh@GoZkGP00?o[;[SojfhhOn]^>401on]^>42
ojnhh0Go/;cR1_na^n400onb_N;o/KgSok6mh`06ok6mh`KoV[O/00?oZKcWog^_m?mk[o@01?mk[o@3
odNJl`;o>i_c1_me_?`3ojo7k0CoXl?`1oo2amh2ol38h0Go`/KM0oo4bMh7okW6i003okW8i_nX`N_o
Z<7[00GoZ<7[1OnW`>/00ol0003oZ<3[ojS0j`08ojW1j`OoZ<3[1onV_n/Eooooo`03o`000?oooooo
oooo01;ooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2o`0000Sooooo1onW_n/6
ojJoj`;oYl3[1onX`>/5ojS1j`?oZ<3[1onV_n/00onW_n_oYl3[ojO0j`04ojO0j`OoZ<7[0_nY`N/5
ojNoj`SoY[k[1onW_n/7ojS1j`04ojJmjOl0003o0000o`0000;oVjgT1_nHYn06oiJQg0OoUj;L00?o
Vj_RojS=lonXcO<01_nXcO<00onXgO[oZO?cojWcl`02ojWcl`Ko]N[g00?o//k^ojZojOnZ_nT01_nZ
_nT5ojNhi@03ojFch_nW/n;oYk?R00KoYk?R1onY]>400on[]N3o[;[Sojbjh`03ojbjh`Oo[KSQ00?o
[[oVok2lh_n`_>801_n`_>83ok6kh@Co/[gR2?na_N<2oiZgk0GoZKcW1_mk[o@5odNJl`KoHJci1onS
`o04ol;7gPGo`<SP0oo2a]d5olC9gPCo^LKT1?nib>H7ojS1j`;oYl3[0_nX`>/01?l0003oZ<3[ojS0
jonX`>/7ojW1j`OoZ<3[1onV_n/Eooooo`03o`000?oooooooooo01;ooooo000>ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`08ooooo`OoYko[0_nV_n/6ojO0j`OoZ<3[
00?oZ<7[ojS0jonX`>/01OnX`>/7ojJoj`OoYl3[1OnX`N/3ojW1j`KoYko[1_nV_^/9ojNoj`?oZ<7[
0_nT^^T2o`0000KoVjgT1_nHYn05oiJQg0KoUj;L0_nQ_>`7ojS=l`?o/Nof0onllO<4okGZm`Co//k^
2?nZ_nT00onW^>GoYK?RojFchP03ojFchPOoYk?R1_nY]>400onZ^nGo[;[Sojbjh`05ojbjh`Co[KSQ
1?n^_nH8ok2lhP03ok6khOnb_N;o/[gR00Co/[gR1_na_N<2okBoh`OoZKcW1_mk[o@5odNJl`KoHJci
1onS`o000oo2amko`<SPol38h006ol38h003ol;6gOo4bMkoa<WN00Goa<WN00?o^LKTokW8i_nib>H0
1Onib>H7ojS1j`CoZ<3[00Co0000ojS0jonX`>_oZ<3[1onY`N/7ojS0j`OoY[o[5Oooool00ol0003o
ooooooooo`0Aooooo`006?ooool00ol0003oooooooooo`09ooooo`GoYko[0onV_n/7ojO0j`?oZ<3[
1?nX`N/8ojS0j`OoY[o[1onW`>/00onX`N_oZL7[ojW1j`05ojW1j`KoYko[0_nV_^/;ojNoj`;oZ<7[
00CoY;[Yo`000?l0003o00000_nT^^T7oi^]i0GoV:OP1_nFXM`2oiNRg0KoXKc/1?nXcO<4ok7_mPKo
_?7c00?o]N[gok;>k_nbc^h01?nbc^h6ojZoj@03oj>bhonU/n;oYK?R00GoYK?R1onW/n82ojVdh@Go
Z[_U1on/^^<00on]^>7o[[oVojjoiP05ojjoiPKo/;cR00?o[l7Wok:mh_nb_N801_nb_N82ok6mh`Ko
];oS1OnY_>L2ok30iPKoR;;b0omEW?<2odNJl`KoHJci0onS`o03oi^nl0So`<SP00?o_/SRolC9g_o4
bMh01Oo4bMh2olG<h0Ko^LSV00?o^<WWojS1jonX`N/01_nX`N/4ojS0j`03o`000?nX`>_oZ<3[00Oo
ZL7[1_nX`>/00onW`>coY[o[ojJoj`06ojJojaGooooo00?o0000ooooooooool04?ooool001Sooooo
00?o0000ooooooooool02_ooool00onW_n_oY[o[ojJoj`05ojJoj`GoYl3[0_nX`>/7ojS1j`KoZ<3[
2OnV_n/5ojO0j`?oZ<7[1onY`N/3ojNoj`CoY[k[2?nW_n/3ojS1j`?o00001_nT^^T7oi^]i0GoV:OP
0onFXM`4oiJYh`OoXKc/00?oZ<gcok7_m_nakoH00onakoH6okcal`?o^Mob1_nbc^h2ojZoj@GoXk;S
1onU/n85ojNchP03ojNji_nZ^nGoZ[_U00KoZ[_U1On/^^<2ojVoj@So[[oV0_n`_>85ojo1i`Ko/[gR
00?o//;UokBohond_n<01ond_n<00onY_>Oo/<3Vok30iP04ok30iPKoR;;b1OmEW?<5oeRPm0OoVkk`
1_o0b>03okk8hPGoa<WN1?o5c>03okW8iPCo^<WW2?nX`N/4ojS0j`03o`000?nX`>_oZ<3[00OoZL7[
0_nX`>/5ojO0k0OoY[o[5Oooool2o`00017ooooo000Gooooo`?o00003Oooool7ojJoj`03ojO0jonX
`>_oZ<3[00CoZ<3[1onX`N/2ojS0j`goY[o[00?oYl3[ojS1jonX`N/01OnX`N/5ojW1j`;oYko[1onV
_^/7ojNoj`?o00001?nX`N/6ojBjj@?oVjgT0onCY>45oi2PgPSoUZWS1OnQ_>`4ok3Nm`;o/Nof1?nl
lO<7okWOlP?o//k^0onS]ND7oj>bh`OoYK?R00?oYk?RojNji_nW^^H00onW^^H8ojZki@03ojbjhonY
_nWoZKoY00CoZKoY1_n^_nH00onY_nWo[l7Wojo1i`06ojo1i`?o/[gR1?nb`^D7okBoh`03okG2i?n`
`>Ko/<3V00Ko/<3V1_n8/_85oeFLl`GoF:3d1onK__03ol38h0Go_/SR0oo4bMh7olG<h003okW8i_nh
bNOo^<WW00Co^<WW1_nX`N/00onW`>coZ<3[ojS0j`02ojS0j`03o`000?nX`>_oZ<3[00SoZL7[1onW
`>`7ojJoja?ooooo00?o0000ooooool000004Oooool001Oooooo00?o0000ooooooooool03_ooool5
ojJoj`;oYko[1onX`>/8ojS1j`coY[o[0_nW`>/8ojS1j`03ojW1jonW_n_oYko[00CoYko[1onV_^/3
ojNoj`?o000000?oYko[ojS1jonX`N/01OnX`N/3ojBjj@;oUjcU1onCY>45oi2PgPSoUZWS00?oXKc/
ok3Nmon`g_L01On`g_L3ol3cl@?o`nW`1_nigo800onZ`N[oXkGUoj>ei@05oj>ei@OoXk;S0onU/n84
ojFgiPKoYk[V1_nZ^nD2ojRnj@OoZKoY0_n^_nH5ojVoj@So[l7W00?o/[gRok;2iOnb`^D01?nb`^D4
okBoh`Co]L;T1_n``>H00onb`nOoSkKaohnfl@05ohnfl@?oGYga0_mEW?<5oeRPm0OoVkk`00?o`<SP
okk8h_nnb>801Onnb>800oo4bMkoaLcPolG<h005olG<h003olG?h_nhbNOo^<WW00Ko^<WW0_nX`N/5
ojO0k0CoZ<3[00?o0000ojS0jonX`>/02?nY`N/5ojO0k003ojJok?nV_n_oY[o[00KoY[o[5?ooool0
0ol0003oooooooooo`0?ooooo`005oooool00ol0003oooooooooo`0?ooooo`03ojJojonW_n_oYko[
00CoYko[1onX`>/8ojS1j`SoY[o[1_nW`>/6ojS1j`03ojW1jonW_n_oYko[00KoYko[1OnV_^/01?nW
_n_o0000o`000?l00005ojNoj`GoZ<7[00?oXKWZoiN/iOnG[>D01?nG[>D7oi>Th@GoT:3N1_nFZN<3
oj[8l0Co/=kg1?o0lo46ol?Yl003okWOl_nZ`N[oZ/7Z00?oZ/7Z1onS]ND5oj>bh`03oj:diOnU]nKo
YKOV00KoYKOV1_nW^^H2ojZki@KoZ;kY1OnY_nT00onX_^WoZKoYojVoj@06ojVoj@Ko[l7W0_n[`>T7
ok;2i@03okBohone`^Co]L;T00Go]L;T0on``>H4ok;3i`OoSkKa1OmNWO43oeVJl@;oF:3d0onK__03
oiRjk`Wo_/SR1_o5c>03olG?hPKo^<WW00?o]L[YojO0k?nW`>`01_nW`>`4ojS0j`03o`000?nX`>_o
Z<3[00SoZL7[00?oYl3/ojJok?nV_n`00onV_n`8ojJojaCooooo00?o0000ooooooooool03_ooool0
01Oooooo00?o0000ooooooooool04?ooool7ojNoj`GoZ<3[2_nX`N/7ojJoj`OoYl3[0_nX`N/5ojW1
j`SoYko[00?oY[k[ojNojol000000_l00009ojNoj`03ojS1jonQ^N[oXKWZ00?oXKWZ1_nG[>D6oi>T
h@KoT:3N0_nFZN<7oj[8l003ok3Nmoo0lo7o`??a00?o`??a1_o3jO000onjenooZ/7Zoj[1jP05oj[1
jPOoXkGU00?oXk;Soj:diOnR]>D00onR]>D8ojFgiP?oYk[V0onW_^T8ojRnj@03ojVojOnX_^WoZ;kY
00?oZ;kY2?nY_nT2ojo1i`KoZl3Y1Onb`^D2ok32i`So]L;T00?o/<3Vok;3ionb`nL01?nb`nL7ohnf
l@GoGYga1OmIV_46oiRjk`Wo_/SR0oo5c>06olG?hP;o^<WW1Oneb^T6ojO0k003ojO0jonX`>_oZ<3[
00?oZ<3[00?o0000ojS0jonX`>/01onY`N/7ojJok0KoY[o[00?oYko[ooooooooool04oooool00ol0
003oooooooooo`0=ooooo`005oooool2o`0001;ooooo1onW_n/00onX`>_oZ<7[ojS1j`0:ojS1j`Wo
Y[o[1OnW`>/3ojS1j`KoZL7[1_nW_n/3o`0000_oYko[0_nX`N/6oj6ijPKoUjcU1_nCY>43oi2PgPCo
V[7X1_nZb?04okgUlP;o`??a1Oo3jO04ok[Gk`OoZ/7Z0onS]ND3oj2ci@OoX[CU1_nU]nH00onW_^[o
YkkYojNnj@05ojNnj@KoZ;kY00?oZ;gYojRnjOnX_^T01OnX_^T8ojVoj@SoZl3Y00?o//;Uok32ion`
`^L01?n``^L6okG2i003okG4i_nb`nOo//?W00Ko//?W0on?]_43ohnel@CoHi__0_mNWO45oeVJl@Ko
V;[_2Onnb>800oo5c>3oaLoRolG?hP04olG?hP03ol?BiOneb^Wo]L[Y00Ko]L[Y0_nW`>`5ojO0j`Co
Z<3[00Co0000ojS0jonX`>_oZ<3[1onY`N/7ojJok0;oY[o[1OnW_n/Dooooo`03o`000?oooooooooo
00gooooo000Gooooo`03o`000?oooooooooo01;ooooo1OnW_n/3ojS0j`SoZ<7[3OnV_n/00onW`>_o
Z<7[ojS1j`05ojS1j`KoZL7[0_nW_n/00onV_^_o0000o`000003ojJnj`SoYko[1_nX`N/6oj6ijPKo
UjcU0onCY>42ohfQh@SoV[7X0onZb?06okgUlPCobno/00?o`nW`ok[Gkonjenl01Onjenl5oj[1jP03
oijcionP/nGoX;?U00GoX;?U1onR]>D2ojFgiPGoYkkZ1onW_^T2ojRnj@GoZ;gY1onX_^T8ojVoj@Ko
Zl3Y00?oZL3Zok32ion``^L01_n``^L2okG2i0Go]LCV1_nb`nL2ok;6j0KoSkGa1OmSVnl4of2GkP;o
FI[a0onH^^l3oiVhk@Oo_/SR00?o`L_RolG?h_o5cn801?o5cn83ol?Bi@Ko]L[Y00?o/LW/ojO0jonW
`>/01_nW`>/4ojS0j`03o`000?nX`>_oZ<3[00SoZL7[0onV_n`3ojJoj`SoYko[5?ooool00ol0003o
ooooooooo`0<ooooo`005oooool00ol0003oooooooooo`0Cooooo`03ojNojonX`>_oZ<3[00GoZ<3[
1onX`N/<ojJoj`?oYl3[1onX`N/3ojW1j`;oYl3[0ol00006ojJnj`OoYko[1onX`N/3oj6ijP;oU:cW
1_n>Xn<6ohfQh@SoV[7X00?oZ/S`okgUl_nmiO801?nmiO84ol__k0?oa^?]1onjenl00onZ`N[oW[?W
oijci`03oijci`OoX;?U1OnR]>D00onU_>[oYkkZojNnjP06ojNnjPGoYkkY0_nW_NT7ojRmj@GoZ;kY
0_nY_^T8ojVoj@;oZl3Y1OnY`>X6ok32i`03ojk2j?nea>Ko]LCV00Ko]LCV0_nb`nL6ok;6j0KoSkGa
1OmSVnl5of2GkPOoVKS]1?nnb>84ol7;hP?oaLoR1_o3d^D3okG:j@Co/LW/2?nW`>/4ojS0j`03o`00
0?nX`>_oZ<3[00OoZL7[1onV_n/6ojNoj`03ojO0jooooooooooo01?ooooo00?o0000ooooooooool0
2oooool001Oooooo00?o0000ooooooooool05Oooool7ojS0j`OoZ<7[2?nV_n/7ojO0j`GoZ<7[0_nY
`N/01?nW`>_o0000o`000?l00003ojO0j`GoY[k[2OnW_n/5ojS1j`;oXK_[1OnD[>L6ohjSh`KoSJ7Q
1_nJ/NP3ok3=k`?o_NGb1Oo;kn`5olKSk@?o^]O_0onU_NX7oijci`OoX;?U00?oX[CUojFlj_nU_>X0
0onU_>X8ojNnjP03ojNnjOnW_NWoYkgY00CoYkgY1onX_NT00onX_^WoZKkYojVnj@04ojVnj@KoZKoY
00?oZ/3YojW0j_nY`>X01OnY`>X4ok32i`Co[/;X1_nea>H2okG6i`So//KX1_n?]O44of>Kk`KoH9O^
1onI^>d00onnb>;o`L_Rol7;hP05ol7;hP03olG?h_o3d^Go`m;U00Ko`m;U00?o]L[Yok79k?nabN`0
1?nabN`6ojO0j`03ojNojonX`>_oZ<3[00?oZ<3[00?o0000ojS0jonX`>/01onY`N/7ojJoj`;oYko[
1OnW`>/Dooooo`03o`000?oooooooooo00_ooooo000Fooooo`?o00005oooool5ojS0j`WoZ<7[2?nV
_n/7ojO0j`04ojS1jonY`N_oZL7[ojW1j`?o00001onW`>/00onV_^_oYko[ojNoj`0;ojNoj`03ojS1
jonQ^n_oXK_[00CoXK_[1OnD[>L6ohjSh`KoSJ7Q0_nJ/NP7ok3=k`03okgUl_o;kncobno/00?obno/
1Oo6hnd2okcFk@KoYKgZ1onN/nL3oj2ci@CoX;KX1_nU_>X6ojNnjPWoYkgY0onX_NT4ojRnj@OoZKkY
0_nY_nT5oj[0j@OoZL3Z00?o/<;Wojk2j?n^`^P01On^`^P3okG4iPGo]LKW1_nba^P00on`an_oRK3`
ohV`l004ohV`l0CoIIO/00?oHi__of2Gk_mPUnh00omPUnh6oiVhk@03oifhjoo1bn;o`L_R00Go`L_R
0_o4d><7ol?Bi@03ol3BionabNco/LW/00Ko/LW/0_nW`>/5ojNoj`CoZ<3[00?o0000ojS0jonY`N/0
1onY`N/6ojJoj`;oY[k[1onW`>/Dooooo`03o`000?oooooooooo00[ooooo000Fooooo`03o`000?oo
oooooooo01Sooooo00?oZ<3[ojS1jonX`N/02onX`N/8ojJoj`GoYl3[00?oZ<3[ojW1jol000000_l0
0004ojW1j`GoYl3[0_nU_^/<ojNoj`;oZ<7[1onQ^n/5oiB/i`GoSZ?S1On=XN43oibdj0Ko/<g_1?o6
hnd2ol__k0Coa^?]1Onle^d6ojFmjPGoW[?W00?oWKCXoj2fj?nP]^P01_nP]^P6ojFljP;oYkkZ2onW
_NT00onW_^WoZ;kYojRnj@06ojRnj@GoZKkY00?oZ[oYoj[0jOnZ`>T01_nZ`>T5ojW0jP;oZ/7Z2?n^
`^P00onea>Ko]LKWokG6i`05okG6i`;o//KX1On`an/6ohV`l0CoIIO/1?m[V>X2of2GkP;oVKS]1OnM
^>/5ol7;hPCoa=3S1?o3d^D4ol3Bi`Ko/LW/00?o[<G/ojNojonW_n/01_nW_n/2ojS0j`;oZL7[00?o
0000ojW1jonY`N/01onY`N/2ojJoj`KoY[k[1OnW`>/00onX`>_oooooooooo`0Aooooo`?o00002ooo
ool000Cooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^1_ooool00ol0003o
ooooooooo`0Jooooo`[oZ<7[1?nW_n/7ojJoj`03ojO0jonX`>_oZ<3[00?o00002?nY`N/00onW`>_o
YKk[ojFnj`04ojFnj`SoYko[1_nX`N/7oj6kj`GoU:cW1On>Xn<00on=XN7oW;CXoibdj005oibdj0?o
/<g_1_o6hnd4om3Xi`03olKSkOnle^go_=K]00Go_=K]1_nU_NX00onN/nOoWKCXoifdj003oifdj0So
X;KX0onU_>X3ojNnjPWoYkgY1OnW_^T8ojRnj@03ojVnjOnZ_nWoZ[oY00?oZ[oY2?nZ`>T00onY`>[o
Z/7Zoj[1jP04oj[1jPKo[/;X0_n^`nT6okG6i`;o]/WY1on`an/5ohV`l0GoIIO/1_m[V>X7oifhj`?o
`L_R1_o4d><00oo3d^Go`=;Wol3Bi`05ol3Bi`;o/LW/1On/aN`6ojNoj`;oYl3[1?nY`N/00ol0003o
ZL7[ojW1j`03ojW1j`CoYl7/2?nV_^/00onW`>_oZ<3[ojS0j`03ojS0j`oooooo0ol00002ooooo`03
o`000?oooooooooo00Wooooo0006ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`06ooooo`03o`000?oooooooooo01_ooooo1_nX`N/8ojNoj`GoY[o[00CoYko[o`000?l0
003o00001?nX`>/6ojW1j`;oZ<7[1onU_^/7ojNoj`OoZ<7[0onQ^n/3oi>_j@GoRZGW1On9XN@9oibd
j003ok3=koo6hngoa^?]00Coa^?]1?o@j>L3ol_Pj0Oo_=K]0onU_NX3oibdj@KoWKCX1_nP]^P00onU
_N_oYkkZojNnjP05ojNnjPKoYkgY00?oY[gZojNnjOnW_^T01OnW_^T6ojRnj@;oZKoZ1_nZ_nT6oj[0
j@;oZl7Z1onZ`NX2ojk2j0Ko[/?Y0onea^L5okK9j@Oo/<O[1On9/?05ofFGk0KoJiSZ1onM^>/00oo1
bn;oa=3SolC@h`04olC@h`03olODi?o0d^Oo`=;W00Go`=;W0_nmd^T7ojc5k0;oYko[1_nW`>/3ojW1
j`03o`000?nY`N_oZL7[00SoYl7/1onV_^/7ojS0j`_ooooo0ol00005ooooo`03o`000?oooooooooo
00Wooooo0006ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006oooo
o`;o00007Oooool6ojS1j`SoYko[00?oY[o[ojNojol000000_l00002ojNoj`KoZ<3[0_nY`N/6ojS1
j`GoYKk[0_nV_^/7ojNoj`GoZ<7[0_nT_^`6oi>_j@GoRZGW1On9XN@7oibdj0?o//_/0oo6hnd5om3X
i`Gobn3X0onle^d4ojS2k0KoW;CY1_nM]>P2oj2fj0GoYKg[1onW_^X2ojNmj@GoY[gZ1onW_^T2ojRn
j@KoZKoZ1_nZ_nT2oj[0j@KoZl7Z1OnZ`NX2oj[1j`So[/?Y00?o]LKWokK9jOnfbNT01OnfbNT3ok37
j`?oZLC]1On3Y^/4ofJAi`;oIIO/1_m[V>X3oifhj`?oY;_Y1_o4d><3olODi0Co`=;W1Onmd^T5ojc5
k0;oZ<7/2?nW`>/3ojW1j`03o`000?nY`N_oZL7[00SoYl7/1onV_^/7ojS0j`Kooooo1?l00008oooo
o`03o`000?oooooooooo00Wooooo0006ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`000005ooooo`;o00007oooool6ojS1j`KoYko[00?oY[o[o`000?l000001_nW_n/3ojS0
j`CoZL7[1onX`N/00onU_^_oY[k[ojJnj`04ojJnj`OoYko[00?oZ<7[ojBnk?nT_^`01?nT_^`6oi>_
j@GoRZGW1On9XN@4oibdj0Ko//_/00?oa^?]om3Xioo@j>L00oo@j>L5ol_Pj0;o`]KX1onX`^`6oibd
j@?oWKCX1?nO]nT6ojFmj`GoYkkZ0_nU_N/7ojJmjPGoYkkY0_nW_n/8ojVojP?oZ[oY0onZ`NX8oj_1
jP03oj[1j_nZ`N_oZ/7[00CoZ/7[1_n^`nT00on`a>Wo]/WYokK9j@05okK9j@;o]L_Z1_nYa>d5oh>V
j`GoIY7W1_miW>L7ojBkj@?oa=3S1_o7e>@00oo0d^Oo_M;YokgBj@06okgBj@03ojc5k?nX`NcoZ<7/
00CoZ<7/1_nW`>/00onX`>_oZL7[ojW1j`02ojW1j`03o`000?nY`N_oZL7[00KoYl7/00?oY[o[ojJn
jonV_^/01OnV_^/6ojS0j`04ojS1joooooooooooooooo`?o00003Oooool00ol0003oooooooooo`08
ooooo`001_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001Oooool0
0ol0003oooooooooo`0Oooooo`KoZ<7[0_nW_n/01?nV_n_o0000o`000?l00002ojJoj`GoYko[0_nX
`>/7ojW1j`GoZ<7[0onV_n/6ojJnj`GoYko[0onX`>/6ojBnk0GoTjoY1On:YNL6ohVQi003oibdj?nb
bnco//_/00Go//_/1?o7fnL2om3Xi`Gobn3X1?o2e^P7ojS2k0?oW;CY0_nJ]NX8oingj@KoYKg[00?o
YkkZojFmjonU_N/01?nU_N/7ojJmjP03ojNnjOnW_n_oYko[00CoYko[1_nY_nX00onX`>_oZ/7Zoj[1
jP05oj[1jPKoZl7Z0_n[`^/7oj[1j`;o[/?Y1On`a>T4okK9j@Go]L_Z1_nYa>d5oh>Vj`GoIY7W1_mi
W>L7ojBkj@03olC@hoo7e>CoamCT00CoamCT0oo7fNL6okgBj@03okO?k?nX`NcoZ<7/00KoZ<7/0_nW
`>/5ojS0j`CoZL7[00?o0000ojW1jonY`N/00_nW`N`5ojJoj`OoY[k[0_nX`>/5ojS1j`;o00004?oo
ool00ol0003oooooooooo`08ooooo`001_ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooo
ooooooooool@41001Oooool00ol0003oooooooooo`0Pooooo`?oZ<7[0_nW`>/3o`0000KoY[o[00?o
Yko[ojS0jonX`>/01?nX`>/7ojW1j`03ojS1jonV_n_oY[o[00GoY[o[1_nV_^/00onW_n_oZ<3[ojS0
j`05ojS0j`KoY;k/1OnC[nT5ohZUi`?oRJ7T1?nI/NP4ok;;k0Koam_W0ooBh>83ol_Pj0Ko`]KX1OnX
`^`00onK^>coV[GZoiZejP04oiZejPSoWkOY0onU_N/3ojJnj`OoYKg[0onV_NX4ojJnj`OoYko[0_nY
_nX5ojS0j`OoZ/7Z0_n[`NX6oj_2j`GoZ/7[0_nY`N/7ok34j@03okK9jOnebn[o]L_Z00Ko]L_Z0onY
a>d2oiZhk@CoOIgV0_n3Y^/5ofJAi`KoNIcW1OnT^nT3ojo1i`?oamCT1_o7fNL2okgBj@Go]lo/1_nX
`N`00onW_n_oZ<3[ojS0j`05ojS0j`CoZL7[00?o0000ojW1jonY`^/02?nV_n/3ojJnj`?oYko[2?nX
`N/Aooooo`03o`000?oooooooooo00Sooooo0006ooooo`03o`000?oooooooooo00;ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o00008_ooool01?nW`>_o0000o`000?l00003ojO0j`SoY[o[
1_nX`>/8ojW1j`OoY[o[0onV_^/3ojNoj`SoZ<3[0onT_^`2oiNek@GoRJSZ1On4X>H9oiVaj003ok;;
k?o7fnOoam_W00Coam_W1OoBh>800oo;h>So`]KXol;Fj006ol;Fj003ojS2k?nK^>coVkS/00?oVkS/
1_nJ]NX6oingj@03ojBmjonV_^_oY[k[00GoY[k[1OnU_N/00onU_^_oY[k[ojJnj`06ojJnj`GoYko[
0_nW`>/7ojS0j`GoZ/7Z0_nZ`^/8oj_2j`03oj[1jonY`N_oZL7[00CoZL7[1On`a>T2ok?:j`Oo]L_Z
00?o//c]oiZhkOnJ^>d01?nJ^>d5ogfMiPCoK8kQ0_mVTNL6ogVLi`03ojBkjOn_`NOo[l7W00Go[l7W
00?oamCTolOIioo7fNL01?o7fNL00oo3f^[o]lo/okO?k006okO?k0;oZ<7/1OnW_n/7ojS0j`;oZL7[
0_nY`^/00ol0003oZL;[ojW2j`06ojJoj`03ojJnjonW_n_oYko[00GoYko[1_nX`N/00onY`N_ooooo
ooooo`0?ooooo`03o`000?oooooooooo00Sooooo0004ooooo`03oeEEEOmVIVKo000000Cooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo01oooooo0ol00007ojO0j`SoY[o[
1_nX`>/8ojW1j`GoY[o[00?oYKk[ojNojonW_n/01OnW_n/6ojS0j`03ojO0k?nG]NgoUkG]00CoUkG]
1On9Z>X5ohBPiPOoVK7X0on`aNX3olOKi`Kod^3R0ooAgN46ol;Fj0;o]<c/1_nK^>`6oiZejP;oWkOY
1OnT_N/7ojJnj`03ojFmjonU_^_oYKk[00?oYKk[2?nV_^/00onW_n_oYl3[ojO0j`04ojO0j`OoZ<3[
00?oZ/7Zoj[2jonZ`^/01?nZ`^/6oj_2j`03oj[3jonY`N_oZL7[00KoZL7[00?o/<CYok?:joncb^/0
1?ncb^/4okG;jPCo//c]1_nJ^>d5ogfMiPGoK8kQ1_n9Y>H7ojo1i`03ok_<ioo7fNOoamWW00CoamWW
0oo3f^X6okO?k0;o[/S]1onW_n/3ojS0j`?oZ<7[1OnY`^/00ol0003oZL;[ojW2j`02ojJoj`GoY[k[
1onW_n/2ojS1j`GoZL7[4?ooool00ol0003oooooooooo`08ooooo`005Oooool00ol0003ooooooooo
o`0Looooo`?o00001?ooool5ojO0j`[oY[o[0onX`>/;ojW1j`03ojJojonU_^_oYKk[00?oYKk[1onW
_n/2ojS0j`GoYl3/1_nG]Nd5ohVXjPGoQ:3V1?nI/NP6ok35jP03olOKiooBh>;od^3R00Cod^3R1OoA
gN42ol;Fj0Ko]<c/1_nK^>`3oiZejP?oV[O/1onT_N/5ojJnj`;oYKk/1_nU_^/6ojJnj`;oYko[1onW
`>/3ojS0j`CoZ<7[1onZ`^/2oj_2j`GoZ/?[1_nY`N/2oj_3j`Oo/l[[00?o]L_Zok;<kOnbc>d01?nb
c>d6oiZhk@KoOIgV1Om/S^46ohVTiPCo[l7W1?nkc>L3olOIi`Ko`m[Z0_ngcn`6ojk8k@GoYko[00?o
Yl3[ojS1jonX`N/01OnX`N/5ojW2j`03o`000?nX`NcoY[k[00KoY[k[1_nW_n/00onW`>_oZL7[ojW1
j`06ojW1j`oooooo00?o0000ooooooooool02?ooool001Gooooo00?o0000ooooooooool06Oooool3
o`0000Sooooo00?oYl3[ojJojonV_n/02_nV_n/00onW`>_oZL7[ojW1j`0;ojW1j`;oYl3/1_nU_^/5
ojNoj`?oYl3[1_nW`>`6oiNek@GoRJSZ1On4X>H00onI/NSo/<GZok35jP05ok35jP?o`LoU1?oBh>85
om7Mh@;ob]GR2?ndc>`3oi^hk0?oV;K]1_nJ]n`7ojBmj`03ojJnjonU_^coYKk/00CoYKk/1_nU_^/2
ojJnj`KoYko[1OnW`>/00onW`NcoZ<7[ojS1j`06ojS1j`GoZ/;[0_nZ`n`7oj[3j`;oZL7[1_n[`n/5
ok?:j`;o/lg]1onbc>d6oiZhk@KoOIgV1?m/S^47ohVTiP03ojo1ionkc>Oo^lcW00Go^lcW00?oamWW
ol?Jj_o3f^X01?o3f^X2okgFk0So[/S]00?oYko[ojO0jonW`>/00onW`>/7ojS1j`;oZL;[0_nX`N`0
0ol0003oZ<7/ojS1k007ojJnj`;oYko[1OnW`>/6ojW1j`03ojS1jooooooooooo00gooooo00?o0000
ooooooooool02?ooool001Gooooo00?o0000ooooooooool05_ooool3o`0000gooooo2?nV_n/5ojO0
j`WoZL7[1_nW`>`6ojFnj`03ojNojonW`>_oYl3[00GoYl3[1_nW`>`3oiNek@;oS:g]1_moX^X6ohnZ
j0Go/<GZ1_o1cnD00ooBh>;odMgQom7Mh@03om7Mh@Cob]GR1_ndc>`2ojK2k@KoV;K]1_nJ]n`3ojBm
j`CoYKk[1onU_^`3ojFnj`?oYKo/2?nW_n/00onW`>_oYl7/ojO1k003ojO1k0SoZ<7[00?oZ/;[oj[3
k?nZ`n`01?nZ`n`5oj[3j`;oZL;/2?n[`n/00oncb^_o/lg]ok?=k@04ok?=k@Go//c]00?oYl;/ohbT
iOn<Y>D01?n<Y>D6ogNBh0CoNI;O00CoK8kQohVTi_n9Y>KoRJCV1?nJ/NP6ok_<i`?oa=WY0oo3f^X5
okgFk0Ko[/S]00?oZ<7/ojO0jonW`>/01OnW`>/5ojS1j`;oZL;[1?nX`N`00ol0003oZ<7/ojS1k007
ojJnj`OoYl3[0_nY`N/5ojS1j`oooooo00?o0000ooooooooool01oooool001Cooooo0_l0000Eoooo
o`?o00004Oooool7ojJoj`KoYl3[2?nY`N/7ojO0k0?oYKk[1?nV_n/7ojO0j`?oYl3/0_nO_>d6ohb]
k@KoOj;Z1_n?Z^P3ok35jPKo`LoU0oo>eMh3om7Mh@Kob]GR0_ndc>`6ojK2k@KoV;K]0onJ]n`3oijj
k@OoYKk[1OnU_^`2ojBok0KoYKo/1_nW_n/8ojO1k0KoZ<7[00?oZ<;/oj[3k?nZ`n`01_nZ`n`00onZ
`n_oZL;/ojW2k004ojW2k0KoZl?[00?o[l[]ok?=kOnccNd01_nccNd00onbc>goYl;/ojO2k003ojO2
k0KoS:CU1_mgT^04ogVBg`SoV[7X0onkc>L6olCIj@03ol?Jj_nme^co_MK/00Go_MK/0_n^b>d5ojS1
k0OoYl3[00?oZ<7[ojW2jonY`^/01?nY`^/4ojS1k003o`000?nV_n_oY[o[00OoY[k[1OnW`>/9ojS1
j`kooooo00?o0000ooooooooool01oooool001Cooooo00?o0000ooooooooool04_ooool2o`0001Go
oooo1onV_n/6ojO0j`SoZL7[1OnW`>`2ojFok0OoY[o[1OnW`>/2ojS0j`GoWkc]1_n<[Nd6ognRjPKo
Sj[X00?o/<GZol7?iOo1cnD01?o1cnD5olkEgP03om7MhOo:eN;ob]GR00Cob]GR0oo4c^87ojK2k@?o
V;K]0_nF^>h7oijjk@OoYKk[00?oYKk/ojBok?nT_n`01?nT_n`6ojFok0;oYko[3?nW`N`2ojS1j`Go
Z<;/1_nZ`n`2ojW3k0OoZL;/0_n[`n/5ojo:k@Ko/lg]00?o//k^ojO2k?nW`^`01OnW`^`6ohbTi@Go
Mi;P1OmiT]l8oiZaj003ok_<ioo4fNWoa=WY00Coa=WY0_o6gn/6okgFk003okGAk_nX`NcoZ<7/00Ko
Z<7/0onW`>/3ojS0j`SoZL;[00GoZ<7/ojJojonV_n_oY[o[o`000002ojJoj`OoY[k[00?oYl3[ojS1
jonX`N/02OnX`N/00onW`>_oooooooooo`0<ooooo`03o`000?oooooooooo00Oooooo000Dooooo`03
o`000?oooooooooo00oooooo0ol0000Hooooo`OoY[o[0onW`>/4ojS0j`OoZL7[00?oYl3/ojFok?nU
_n`01?nU_n`7ojJoj`03ojO0jonX`>_oZ<3[00CoZ<3[1OnO_>d6ohb]k@KoOj;Z0on?Z^P4ojFkj@?o
`LoU1_o>eMh3om;DfP?ob]GR1_o4c^85ojK2k@03oiflk_nF^>koU[S^00CoU[S^1onN^^d3ojFnj`Co
YKo/1onT_n`3ojFok0?oYL3]2onW`N`3ojO2k@OoZ<;/0_nZ`n`6ojW3k0GoZL;/0_nY`n`7ojo:k@;o
/lg]1Onbc^h7ojO2k0KoS:CU1?mgT^06ogVBg`KoV[7X0_nY_^T4olCIj@Goa]o[0_nme^`5okGAkPKo
Z<7/00?oYko[ojS0jonX`>/01OnX`>/6ojW2j`03ojW2k?nV_n_oY[o[00;oY[o[00Co0000ojJojonV
_n_oY[o[0onV_^/3ojNoj`WoZ<7[1OnW`>/=ooooo`03o`000?oooooooooo00Oooooo000Dooooo`03
o`000?oooooooooo00cooooo0ol0000Looooo`OoY[o[1onX`>/8ojW1j`KoYKo/1OnV_n/2ojNoj`Oo
Z<3[1OnO_>d3ohb]k@?oPJS^1On0Y>/8ojFkj@03ol7?iOo>eMkoc]GN00Coc]GN1OoBe=X00oo:eN;o
a<kRolC>hP06olC>hP03ojK2kOnM_>koWKc^00?oWKc^1_nF^>h5oijjk@03oinmk_nU_ncoYKo/00Ko
YKo/1OnT_n`00onT_ngoYL3]ojG0k@05ojG0k@KoYl7/0_nV`^d6ojO2k@GoZ<;/0_nX`nd8ojW3k003
ojW2k?nY`ncoZL?/00CoZL?/1On_b^d3ok7?k`Ko//k^0onW`^`3oiBVhPKoQ9KM1?mjSMX00omgT^3o
NI;OogVBg`04ogVBg`;oV[7X1_nY_^T00oo4fNWoa]o[olKOj`04olKOj`;o_mc^1onedNh2ojS1k0Go
Yko[1onX`>/2ojW2j`GoZL;/1?nV_n/00ol0003oY[o[ojJnj`07ojNoj`OoZ<7[1onW`>/<ooooo`03
o`000?oooooooooo00Oooooo000Cooooo`?o00002_ooool3o`00023ooooo1onV_n/7ojS0j`SoZL7[
1_nU_n`00onV_n_oYko[ojNoj`04ojNoj`GoZ<3[0_nW`>`6oiBgk`GoPJS^1On0Y>/6ojFkj@;o]<GW
1Oo>eMh6om;DfP03om7@fOo4c^;oa<kR00Goa<kR0_nnbN86oiflkPKoU[S^00?oW[[]oinmk_nO_Nh0
0onO_Nh8ojFok003ojBok?nT_ngoY;o]00?oY;o]1onU`>d2ojO1k0KoY/;]1_nW`^d00onX`^coZ<?]
ojS3k@04ojS3k@KoZL?/00?oZ<;/ojW3k?nY`n`01_nY`n`00on_b^go/Lo_ok7?k`05ok7?k`?o//k^
0_nY`>X7oiBVhPKoQ9KM1?mjSMX7ohbQhPKoZKkY0onkdn`3olKOj`Go_mc^1OnedNh2oj_4k0OoYko[
0onX`>/3ojS1j`SoZL;/0_nV_n/2ojJnj`03o`000?nV_^_oY[k[00OoYko[1onX`N/7ojO0j`_ooooo
00?o0000ooooooooool01oooool001Cooooo00?o0000ooooooooool01_ooool3o`0002Gooooo1_nV
_n/5ojS0j`?oZL3[1onY`N/6ojFok0OoYko[00?oZ<3[ojO0k?nW`>`01?nW`>`6oiBgk`GoPJS^1On0
Y>/3ojFkj@Go]<GW0oo>eMh6om;DfP?odM3I1?o4c^85okk9hPKoWKc^0onF^>h3oiJjl0KoWkg^1_nU
_n`2ojG0k0KoY;o]1OnU`>d2ojG1k@SoY/;]0onW`^d3ojO3k@OoZ<?]0_nY`n`5ojS2k0KoZL?/0_n^
c_46ok7?k`;o/<g_1OnY`>X7oiBVhPGoQ9KM1OmjSMX7ohbQhP?oZKkY1_nkdn`00oo6gn_o_mc^okoL
kP05okoLkP03okGAk_n[a>coZlC/00CoZlC/1OnW_n/00onX`>_oZ<7[ojS1j`05ojS1j`KoZL;/00?o
Yl3[ojJnjonV_^/00_nV_^/00ol0003oY[k[ojJnj`06ojNoj`03ojS0jonX`N_oZ<7[00KoZ<7[0onW
`>/3ojJoj`_ooooo00?o0000ooooooooool01oooool001Cooooo00?o0000ooooooooool00oooool3
o`0002Wooooo1_nV_n/00onX`>_oZL3[ojW0j`05ojW0j`GoZL7[0_nW`>`6ojFok0GoYko[0onW`>/6
ojO0k0KoU;O_1On1Z>h5oh2Tj`03ojFkjOndaNOo]<GW00Go]<GW00?oc]GNom;Df_oBe=X01?oBe=X5
om7@f@03olC>h_nnbN;o_/WR00Ko_/WR0onM_>h3oiZkk`KoU[[`1_nO_Nh2ojFok0KoYL3/1_nT_nd0
0onU`>goYL7]ojG1k@04ojG1k@SoY/;]1_nW`nd5ojS3k@WoZ<;/0_nY`n`6ojk>l@?o/Lo_1On`cNl5
ojW0jPKoU:KR1On4U]d6ogZ=fPOoS:7R00?oZKkYok_Ck?nkdn`01?nkdn`00oo4h^ko_mc^okoLkP05
okoLkP03okWFkon[a>coZlC/00KoZlC/00?oYko[ojS0jonX`>/00onX`>/7ojS1j`;oZL;/1OnW`>/4
ojJnj`03o`000?nV_^_oY[k[00;oYko[1OnX`>/6ojS1j`03ojS1k?nV_n_oY[o[00GoY[o[2oooool0
0ol0003oooooooooo`06ooooo`004oooool01?l0003oooooooooooooool3o`0002gooooo0onV_n/3
ojNoj`SoZL3[00?oZL7[ojO0k?nW`>`01?nW`>`6ojFok003ojNojonW`>_oYl3[00GoYl3[1_nW`>`3
oiBgk`;oRK7`1OmhYNl6ohj^j`Ko]<GW0oo1bN44om;DfPGodM3I0_o>c=L7okk9hP;o^/CR1_nJ^nl6
oiJjl0?oWkg^0onO_nl8ojG0k0KoY;o]1onU`Nd8ojK2k@KoYl?]00?oZ<?]ojS2k?nX`^`02OnX`^`2
ojW9l0So[/ka00?o/Lo_ok3=kon`cNl01On`cNl5ojW0jPKoU:KR1On4U]d5ogZ=fPKoS:7R00?oWkGX
ok_Ck?nkdn`01?nkdn`3olCRkPCo_mc^1?nie^l6oj_4k003ojNojonX`>_oZ<3[00GoZ<3[1OnX`N/2
ojW2k0OoYl3[0onV_^/00onW_n_o0000ojNoj`08ojS0j`;oZ<7[1OnX`N`7ojJoj`[ooooo00?o0000
ooooooooool01_ooool001?ooooo1?l0000aooooo`KoYko[1_nY`>/2ojW1j`OoYl3/0onU_n`3ojJo
j`SoYl3[0onW`>`3oj:nk@GoRK7`1OmhYNl6ohj^j`?o]<GW1oo1bN400ooBe=[odM3Iom7@f@03om7@
f@Coc/cG1?nnbN85ok[4hPKoV[__0onF^_03oiFllPKoWko_1_nU`>`2ojG1k@KoY;o]1onU`Nd8ojK2
k@?oYl?]0onW`^d8ojS2k0KoZLW`1_n^c_42ojk@lPKo/<g_00?oYKCSoiNSgOnGXmd00onGXmd6ohbG
f@GoPHgF1?n8VMd2ogZ=fP;oS:7R1OnO]NP3ok_Ck0Koa>;^00?o_mc^okWFkonie^l01Onie^l2oj_4
k0GoYko[1onX`>/00onX`N_oZL;/ojW2k004ojW2k0GoYl3[0_nV_^/4ojNoj`03o`000?nW_n_oZ<3[
00GoZ<3[00?oZ<7[ojS1k?nX`N`01_nX`N`3ojJoj`?oYko[2_ooool00ol0003oooooooooo`06oooo
o`004oooool2o`0003Cooooo1_nW_n/2ojW0j`KoZL7[1OnW`>`2ojJok0KoY[o[1_nW`>/2ojS0j`Ko
X[k]1On9/O05ogRUk`KoSZk[00?o]<GWol79hOo1bN401Oo1bN43olS:f`?odM3I1_o>c=L00onnbN;o
^/CRok[4hP06ok[4hPKoV[__1_nE_?86oinok`;oYL3/1_nU`Nd6ojBok@OoYL7]1_nV`^d00onV`Ngo
Yl;]ojO2k@05ojO2k@GoZ<;/0onWao06ojW9l0;o[/ka1_n^d?82ok3=k`GoYKCS1OnGXmd6ohbGf@Go
PHgF1_n8VMd7oinej003ok_Ck?o4h^koa>;^00Coa>;^0_nohO06okWFk`03ojg7kOnW_n_oYko[00Ko
Yko[0onX`>/3ojS1j`SoZL;/00?oYl3[ojJnjonV_^/01?nV_^/3ojNoj`03o`000?nW_n_oYko[00;o
Z<3[1OnX`N/6ojS1k0SoYko[2Oooool00ol0003oooooooooo`06ooooo`001Ol00003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`0booooo`?oYko[1?nW`>/7ojW1j`03
ojO0k?nV_ncoY[o/00CoY[o/1_nV_n/2ojO0j`KoZ<3[1_nR_^d5ohVal0GoN:G_0on>[^/3oijgjPKo
`LWQ1Oo8b]/00ooAd=Woc/cGolk<e`04olk<e`?oblKE1_nja>82okW0g`KoV[__1_nE_?83oinok`?o
W<7b2?nU`Nd3ojBok@[oYL7]0_nV`^d5ojK1k@OoYl;]00?oZ<;/ojO7l?nWao001OnWao03ojW9l0Co
[=3c1On^d?800on/`n_oYKCSojFdh`05ojFdh`KoUj?M1On<UmT6oh6=ePKoR9WM1OnO]NP3ok??kP?o
a>;^1OnohO02okWFk`Go[LO]1_nW_n/00onX`>_oZ<7[ojS1j`05ojS1j`KoZL;/00?oZ<7[ojJnjonV
_^/01_nV_^/3ojNoj`03o`000?nW`>_oYl3[00OoZ<7[0_nX`N`<ojNoj`Sooooo00?o0000oooooooo
ool01_ooool00005oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Wooooo00?o0000ooooooooool0<oooool6ojO0j`OoZL7[1onV_n`7ojJoj`OoZ<3[0onR_^d3oi^l
k`GoPZka1?meY>l7oijgjP?o`LWQ1oo8b]/00oo<b=Ooc/cGolk<e`03olk<e`GoblKE0onja>85okW0
g`KoV[__0onE_?83oiBnl`KoW<7b1_nU`Nd2oj?5l@_oYL7]0_nV`^h7ojK1k@?oYl;]1?nWa_06ojO7
l0;oZ<od1on/d?<00on^d?;o[<?[ojc3j`03ojc3j`KoYKCS1_nGXmd5ohbGf@KoPHgF1on8VMd00onO
]NSo/lo^ok??kP05ok??kP03olCRk_nohO3o_n7`00?o_n7`0_nhf?07ojg7k@;oYko[1OnX`>/7ojS1
j`;oZL;/1OnX`N/6ojJnj`03ojJojonW`>_oYl3[00;oYl3[00?o0000ojO0jonW`>/01OnX`N/00onX
`NcoYko[ojNoj`0<ojNoj`Sooooo00?o0000ooooooooool01_ooool00004oooooonHV9So8B4Qonk^
kPCooooo00Go410@oooooooooooooooooa0@400:ooooo`03o`000?oooooooooo03?ooooo1_nW`>/7
ojW1j`GoY[o/0_nU_n`7ojJoj`OoZ<3[1_nK_>l5oh:^l@CoMJC_1onN]nX00oo1bN7ob<[KolS:f`05
olS:f`?oc<SG0oo>c=L7ol_6e@03ok[4h_ni`=oo^L3O00Go^L3O0onJ^nl3oijjk0KoU;kc1_nL`O82
ojG1k@KoXlGa1onU`Nd6ojK2kPGoY/7]0_nVb?47ojO6l0;oYlO`1_nXco@5ojc@l`;o[<[_1_n/`n/6
ojFdh`KoUj?M1On<UmT6oh6=eP?oR9WM0onM/^L7ok??kP?o`>Ca00?o_n7`okSHl?nhf?001?nhf?05
ojg7k@;oYko[1onX`>/3ojS1j`?oZL;/2?nX`N/2ojJnj`GoY[o[1?nW`>/01?l0003oYl3[ojO0jonX
`N/5ojS1k0koYko[1oooool00ol0003oooooooooo`06ooooo`000_ooool00onHV9So8B4Qonk^kP03
ooooo`05o`000?ooooooooooooooool000002oooool2o`0003Cooooo0onW`>/3ojS0j`OoZL7[00?o
Y[o/ojFok?nU_n`01?nU_n`7ojJoj`OoZ<3[1_nK_>l5oh:^l@CoMJC_1OnN]nX3ojZoj0Gob<[K1Oo<
b=L00oo>c=OoblKEol_6e@05ol_6e@;obL;C1_ni`=l2ok^lfPKoW[[/1_nD__<3oic1lPCoUl;d1onS
aO43ojG1k@CoY<Oa1_nV`^h00onV`NgoY/SaojK8l@04ojK8l@GoYlK`0_nUc_D8ojS?m003ojc@lon/
b^oo[<[_00Co[<[_1_n/`n/3ojFdh`;oV9_E1_n@Tm<5ohR>d`KoRiWK1onM/^L4ok??kPCo`>Ca00?o
_N?bokSHl?nhf?001_nhf?000on]angoYko[ojNoj`04ojNoj`GoZ<3[0_nX`N/6ojW2k0KoZ<7[00?o
Y[k[ojJojonV_n/01_nV_n/3ojO0j`03o`000?nX`N_oZ<7[00OoZ<7/3_nW_n/7ooooo`03o`000?oo
oooooooo00Gooooo0003ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`00
000=ooooo`03o`000?oooooooooo03;ooooo1_nX`>/8ojW1j`KoYKo/1OnV_n/2ojO0j`OoZ<3[0onK
_>l2oiFjl@GoNZcc1?mhZ?400omeY>ooW[OZojZoj006ojZoj0?ob<[K1Oo<b=L2olc6e0KoblKE1?o9
`]<3okW0g`Go^kcJ1_nN^^`3oiBnl`CoUKgc1_nG`_@3oj?5l@?oW<Ke2?nTao43ojK2kPCoXl_d1_nV
b?400onWa_3oYLkeojG>m@04ojG>m@KoZ<od0_nYc?87ojc:k`?o[<?[0_nNXmP6oiRKe@KoT9?C1On8
S]<6oh^If`OoWK;W00?o/lo^ol3TlOo0i?400_o0i?44okgSlPKo^=S`00?o[LS]ojNojonW_n/01_nW
_n/00onX`>_oZ<7[ojS1j`04ojS1j`KoZL;/0_nX`N/5ojJnj`KoY[o[00?oYl3[ojS1jonX`N/00_nX
`N/00ol0003oZ<7[ojS1j`05ojS1k0koYko[00?oZ<3[ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`001?ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool03?oo
ool00ol0003oooooooooo`0booooo`KoZ<3[2?nY`N/6ojFok003ojJojonW`>_oYl3[00CoYl3[2?nX
`>/4oiFjl@GoNZcc1OmhZ?48ojZoj003olS:foo<b=Ooc<SG00?oc<SG1?o<a]@3ol_6e@OobL;C00?o
^L3Ook^lf_nk_=X01Onk_=X3oijjk0CoY[OU1_nE_O<3oiO2m0?oU/?f1_nLa_D6ojC7l@;oWLWf1onS
bo@3ojK8l@CoX/gf1_nUc_D2ojS?m0KoZLcb0on/b^l3ojFZfPKoWZ?H1OnHVmD6oi2Cd`KoR8kC1_n;
VM/5oifbi`Co/M7a00?o`>CaokgSl_nmho801?nmho82okSHl0Go[LS]1_nW_n/00onX`>_oZ<7[ojS1
j`06ojS1j`?oZL;/0onX`N/7ojJnj`;oY[o[1OnW`>/4ojS1j`04o`000?nX`N_oZ<7[ojS1k0koYko[
1OnX`>/6ooooo`03o`000?oooooooooo00Gooooo00001Ol0003o^[ZjoooooonHV9So410@00?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0?ooooo`03o`000?oooooooooo03;ooooo0onX`>/4ojW0j`Oo
ZL7[1_nU_n`7ojO0j`SoZ<3[1?nE^_45ogZ/l`GoN:Sa1_nZ_nP3ok72i`?oc<SG1_o<a]@00oo;a]Go
bL;ColW2d`05olW2d`;ob;g@1_nk_=X00onn^=CoY[OUojJgi@06ojJgi@?oUKgc0onK^Nd6oiK3mPKo
W<Ke0_nTao46oig9mPGoXl_d0_nNc?L7oj;=mP?oYLke1?nVbo<5ojW<lP03ojN^g?nUZ][oYJ[J00Go
YJ[J1_nNXmP5oiRKe@KoT9?C1On8S]<7oh^If`03oifbionadO7o/M7a00Co/M7a0_nlj?<5okgSlP?o
]]Sb1_n]b>d2ojNoj`GoZ<3[1_nX`N/00onY`^coZ<7[ojS1j`05ojS1j`KoY[k[2?nW`>/3ojS1j`03
ojS1k?l0003oZ<7/00goYko[2?nX`>/5ooooo`03o`000?oooooooooo00Gooooo00001OnHV9So410@
o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0@ooooo`;o0000=?ooool6ojW0
j`GoZL7[0_nX`>/6ojFok0OoYl3[2?nX`>/4oiFjl@GoNZcc1OmhZ?42ojZoj0Oo/L;W00?oc<SGolc6
e?o<a]@01Oo<a]@00oo<a=?obL;ColW2d`04olW2d`Cob;g@0onk_=X4okjhe0KoY[OU0_na]=/6oi^i
k@KoU/?f0onLa_D4oiW6m`OoWLWf00?oXl_doik<monNc?L01?nNc?L5oj;=mP;oXlOb1onVbo<00onY
c?;oYjkLojN^g003ojN^g0KoYJ[J1_nNXmP5oiRKe@KoT9?C1_n8S]<3oh^If`CoWkKX1?nadO45okcX
l`03okgSl_nff?;o]]Sb00Go]]Sb0on]b>d3ojNoj`OoZ<3[0_nX`N/5ojW2k0OoZ<7[1_nV_^/6ojO0
j`GoZ<7/00?o0000ojS1k?nX`N`03OnW_n/6ojS0j`03ojS1k?oooooooooo00?ooooo00?o0000oooo
ooooool01Oooool001oooooo00?o0000ooooooooool0<_ooool6ojW0j`03ojW1jonX`>_oZ<3[00Co
Z<3[1_nU_n`7ojO0j`KoZ<3[0_nW`>/5oi2hlPGoLj_d1Omm[_<6ok72i`03okC3iOo<a]Coc<KD00Go
c<KD0oo<a=<3olW2d`Oob;g@00?o^kcJokjhe?nn^=@01?nn^=@3ojJgi@Go/KCK1_nK^Nd3oiK3mPCo
V[g`1_nIa_L3oig9mPCoWLOf1onNc?L00onRcOKoXlOboj?7lP04oj?7lPGoY/_c2?nW[]`5ojFZfPOo
WZ?H1OnHVmD6oi2Cd`?oR8kC0_nCX=d8oinfj003ok7AlOnlj??o_>Sc00Co_>Sc0_nihO@6okKHlP03
oj_4kOnW_n_oYko[00GoYko[1OnX`>/2ojS1k0OoZL;/0onX`N/:ojJnj`;oYl3[2OnX`N`00ol0003o
Z<7/ojS1k00=ojNoj`;oZ<3[1OnX`N`4ooooo`03o`000?oooooooooo00Gooooo000Pooooo`03o`00
0?oooooooooo03;ooooo1_nY`>/7ojS0j`KoYKo/1onW`>/2ojS0j`KoYl3[1On@^?85og>[m0GoOJkc
0ona`^L4okC3i@Goc<KD1Oo<a=<00oo9`]?ob;g@olRmd005olRmd003olRjcOnn^=Co_[SD00Ko_[SD
00?oY[OUok6dfona]=/01Ona]=/3oi^ik@?oYk3N1onJ_O03oiW6m`CoW[c^1_nMaoH3oik<m`CoXko^
1onSao800onVbo?oYjkLojN^g009ojN^g0KoYJ[J0onNXmP3oiVDcPGoTY7?1_n?Tm<6oi>Pg@KoWkKX
0onbfoD3okcXl`Go^N7d0_nff?85oj_4k@OoYko[00?oZ<3[ojS1k?nX`N`01?nX`N`5ojW2k003ojS1
jonV_^_oY[k[00[oY[k[0_nW`>/:ojS1k003ojNojol0003oYko[00_oYko[0_nW`>/8ojS1k0?ooooo
00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool0<_ooool6ojW0j`GoZ<3[0onW
`>/5ojFok0ooYl3[1On@^?85og>[m0GoOJkc00?o/L;WokC3iOnd`nD01?nd`nD3olc6e0Koc<CC1oo8
_M03olRjc@Ko_[SD00?o_k?>ok6dfona]=/01Ona]=/00onh/=7oYk3NojN`gP05ojN`gPGoV[g`0_nU
[]h7oijlkP?oWLOf0onT/n@7oj>okP?oXlOb0onWZmX=ojN^g0?oYJ[J0_nNV<h7oiVDcPGoTY7?1_n?
Tm<6oi>Pg@?oWkKX1_nbfoD00onlj??o^N7dokWQm003okWQm0;o/m?a1on[a>d3ojNoj`?oZ<3[2?nX
`N`00onY`^coZ<7[ojS1j`03ojS1j`SoY[k[1_nW`>/6ojS1k0CoYko[00?o0000ojNojonW_n/01onW
_n/6ojO0j`KoZ<7/00?oZ<7[ooooooooool00_ooool00ol0003oooooooooo`04ooooo`008_ooool0
0ol0003oooooooooo`0booooo`KoZL3[00?oZ<3[ojO0jonW`>/01OnW`>/5ojFok0goYl3[0_nV_n`5
ohfhl`GoKj_f1Omo/_D7okC3i@03olc6e?o<a=?oc<CC00Coc<CC0_o9`m@5olRmd0Gob;[=0onn^=@4
oknccPGo/KCK0onh/=47ojN`gP03oiZml?nU[]koYJkN00CoYJkN1OnN_>h00onXZ]SoY;?TojBci005
ojBci0GoXko^00?oZ:OEojN[f_nWZmX01OnWZmX:ojN^g0;oXY_>1_nNV<h6oiVDcPKoTY7?1On?Tm<7
oi>Pg@03oinfj?nbfoGo/]_e00Co/]_e0onijOD00onihOCo/m?aok?Cl@04ok?Cl@GoZlC]0_nW_n/6
ojS0j`KoZ<7/00?oZL;/ojS1jonX`N/01OnX`N/3ojJnj`?oYkk[2?nW`>/6ojS1k0CoYko[00?o0000
ojNojonW_n/01onW_n/6ojO0j`;oZ<7/1OnX`N/3ooooo`03o`000?oooooooooo00Cooooo000Soooo
o`;o0000<oooool3ojW0j`CoZL3Z1onW`>/6ojFok0SoYl3[1_nV_n`5ohfhl`GoKj_f1Omo/_D5okC3
i@;o]<CV1Oo<a=<4olW3e0?ob;g@1oo8^/d00onn^=Co_k?>oknccP04oknccP?o/KCK1Onh/=45ojN`
gP03ok>/dOnU[]koYJkN00KoYJkN00?oW[c^ojRZf?nXZ]P00onXZ]P7ojBci003oj>ok_nXYmGoZ:OE
00?oZ:OE1_nWZmX6ojN^g003ojBLcOnRVlkoXY_>00CoXY_>1_nNV<h5oiVDcPKoTY7?1_n?Tm<3oi>P
g@GoY<7^0_nbfoD5okWYm@03okCMmOncdo7o/m?a00Ko/m?a00?oZlC]ojNojonW_n/01?nW_n/6ojS0
j`;oZ<7/1OnY`^`5ojS1j`;oY[kZ1_nW_^/6ojO0j`SoZ<7/1?nW_n/00ol0003oYko[ojNoj`07ojNo
j`?oYl3[0_nX`N`8ojS1j`;ooooo00?o0000ooooooooool01?ooool002Gooooo00?o0000oooooooo
ool0<_ooool6ojW0jPGoYl3[0_nW`>`7ojFok0KoYl3[1onV_n`5ohfhl`GoKj_f1Omo/_D00ond`nGo
]<CVokC4iP04okC4iP?oc<CC1_o9`m@00oo8_M3ob;[=olRjc@06olRjc@So_k?>00?o/KCKokR`dOnh
/=401Onh/=400onW/=ko/jcAok>/d@03ok>/d@KoYJkN00?o/JS?ojRZf?nXZ]P01OnXZ]P5ojBci003
ojbUd?nXYmGoZ:OE00GoZ:OE1_nWZmX2ojN^g0GoY9c=1_nRVlh5oijHcPKoVIC>1_nBTLl3ohnCd`?o
WK3U1_nT`Nh3ok;Wn0?o^NWe1?ndgOD6ok?Cl@03ojS1jonW_n_oYko[00KoYko[0onX`>/3ojS1k0Oo
ZL;/00?oZ<7[ojJnj_nV_^X01?nV_^X6ojNnj`;oYl3[2_nX`N`6ojNoj`03o`000?nW_n_oYko[00Go
Yko[00?oYl3[ojS1k?nX`N`01?nX`N`6ojS1j`04ojNojoooooooooooo`0000Kooooo000Vooooo`03
o`000?oooooooooo03;ooooo1_nY`>X00onW`>_oYl3/ojO0k004ojO0k0GoYKo/0_nV_n`6ojO0j`Oo
Y[o/1On=^?<5off/m`GoOKCg1onda>H00oo<a=?obL?DolW3e004olW3e003olK3eoo8^/gob;[=00So
b;[=1_no/lh00oo1//_o^;3AokR`d@05okR`d@03ok^/b_nc[=7o/jcA00Go/jcA0onU[]h4ok6Xc`Oo
Z:[H00?oY;?TojbUd?n/YM000on/YM07ojRWe@?oYj_J0_nWW</7ojBLc@KoXY_>1_nNV<h5oiVDcP?o
TY7?0onHX]`7oif`i@?oY<7^1_nbioP00onijOGo]=geokCMm@04okCMm@;o/m?a1OnX`N/6ojNoj`03
ojO0jonX`NcoZ<7/00GoZ<7/0onY`^`3ojNoj`SoY[kZ0onW_^/2ojO0j`WoZ<7/2OnW_n/00ol0003o
Yko[ojNoj`02ojNoj`GoYl3[1_nX`N`2ojS1j`GoYko[00?oooooo`000?ooool01Oooool002Oooooo
00?o0000ooooooooool0<_ooool6ojW0jPOoYl3/00?oYKo/ojJok?nV_n`01?nV_n`6ojO0j`OoY[o/
1On=^?<5off/m`GoOKCg1Onda>H2ok75j@GobL?D0oo6`mL:olRjc@Co_k?>0oo1///5okR`d@?o^jc:
1onc[=400onU[]ko/JS?ok6Xc`04ok6Xc`GoZ:[H00?o[j;;ojbUd?n/YM001On/YM05ojRWe@03ojZM
bOnWW<_oYic;00CoYic;1_nTW<d7oj:KcP?oWYS>0_nLVLl5oiVKe0OoV:;L1onM/>D00onT`Nko/^Oh
ok;Wn004ok;Wn0?o]>Gg0ondgOD4ojg9kPKoZ<7[0_nW_n/5ojO0j`GoZ<7/0_nX`^`6ojNoj`KoY[kZ
00?oYko[ojO0jonW`>/01?nW`>/7ojS1k0_oYko[00?o0000ojNojonW`>/01onW`>/3ojS1k0CoZ<7[
1_nW_n/00ol0003oooooooooo`04ooooo`00:?ooool2o`0003?ooooo1_nY`>X5ojO0k0WoY[o/1_nW
`>/7ojJok0GoSKSc1Om][?L5ogfdm`03okC4i_naaNWo/LGY00Co/LGY0oo9`m@5olK3e`Wob;[=0ono
/lh5ol6bb`?o^;3A1Onk[<X5ok>/d@03okNWbOnaZ<oo/JS?00Go/JS?0onXZ]P4ojnRb`Ko[:G@0onX
YmD4ojZMb@KoYic;1_nTW<d5oj:KcP03oj2IcOnLVLooW9W?00CoW9W?1OnIVm@6oiRRg0KoWK3U0onX
f?P2ok;Wn0Go]>Gg00?o/=Ccojg9k_n]bNh01_n]bNh3ojS1j`[oYl3[00?oZ<7/ojS2k?nX`^`01?nX
`^`6ojNoj`;oY[kZ1OnW_n/6ojO0j`OoZ<7/2onW_n/00ol0003oYko[ojO0j`05ojO0j`03ojS1k?nX
`N_oZ<7[00KoZ<7[0onW_n/2ooooo`03o`000?oooooooooo00Cooooo000Zooooo`03o`000?oooooo
oooo037ooooo1_nY`>X00onW`>coY[o/ojJok00;ojJok0KoYl3[1OnV_n`2ojO0j`KoSkWc1Om^[oP4
ogFdn@Oo/LGY00?obL?DolK3eoo6`mL01Oo6`mL9olRjc@03okncc_o1//_o`K;;00Go`K;;00?o^;3A
ok^/b_nk[<X01?nk[<X3ok>/d@Co]jO91onaZ<l00onXZ]So[j;;ojnRb`04ojnRb`Ko[:G@00?oZ:OE
ojZMbOnZWLT00onZWLT6ojNLb`KoY9c=0_nRVlh5oj2Ic@GoW9W?1_nIVm@6oiRRg0;oWK3U1OnXf?P3
ojoZn0?o]>Gg1?n`e?<6ojg9kP03ojNojonW`>_oYl3[00[oYl3[2OnX`^`3ojNoj`;oY[kZ2?nW_n/3
ojO0j`[oZ<7/2onW_n/01?l0003oYko[ojO0jonW`>/5ojS1k0KoZ<7[1oooool00ol0003ooooooooo
o`03ooooo`00:oooool00ol0003oooooooooo`0aooooo`OoZL3Z3OnV_n`6ojO0j`03ojJok?nW`>_o
Yl3[00CoYl3[1_n?^O<5ofj_n0CoMKCi1OnaaNT2oj[8k`Koa/?G00?o_lCMolRjcOo8^/d01_o8^/d0
0oo6_];o`K;;ol6bb`05ol6bb`03olBfcOnk[<[o^jc:00Ko^jc:00?o/jcAokNWbOngYlT01?ngYlT5
ok6Xc`03okBTb?n_X/_o[j;;00Go[j;;1On/YM000on]W/SoZYg9ojZMb@05ojZMb@KoYic;0onTW<d2
ojBKc0OoX9W=1_nLVLl6oiVKe0?oV:;L1?nTb?83ojSHn0Ko[n[h00?o]>Ggok3Dlon`e?<01?n`e?<2
ojg9kPGoYko[2?nW`>/;ojS2k003ojNnj_nV_^[oY[kZ00CoY[kZ1_nW_n/00onW`>_oZ<7/ojS1k009
ojS1k0goYko[00?o0000ojO0jonX`N`01onX`N`2ojS1j`[ooooo00?o0000ooooooooool00oooool0
02cooooo00?o0000ooooooooool0<Oooool7ojW0jPgoY[o/3OnW`>/3ohnil`?oU;_a1Omb/_T3ofRb
nP03ogFdnOnaaNWoZ/S_00GoZ/S_0oo6`mL4oko4g@Kob;[=0oo6_]85ol6bb`?oa;K=1_nk[<X00ono
/<_o]jO9okNWb@05okNWb@?o/JS?1?ndY<P7ojnRb`03ojbUd?n]W/So[Ik800?o[Ik81_nZWLT5ojNL
b`03ojRNc?nTVlcoY9_<00CoY9_<1_nPVLd6oibIc`GoVI_D0_nS_>/7ojC8lP03ojSHn?n_j_So[n[h
00Co[n[h0_n_g?L5ok3Dl`;oZ<7[1onW_n/3ojO0j`?oYl7/2OnX`^`5ojNnjPKoY[kZ0_nW_n/5ojO0
j`KoZ<7/00?oZ<7[ojNojonW_n/02onW_n/4ojO0j`03o`000?nW`>_oZ<7/00GoZ<7/3Oooool00ol0
003oooooooooo`03ooooo`00;Oooool2o`0003;ooooo1onY`>X;ojJok0;oYKo/2onW`>/2ojS0j`Ko
U;_a1Omb/_T5ofRbnPKoZ/S_00?oa/?Goko4gOnoa=d01?noa=d3olRjc@Koa[kB0oo1///5olBfc@Co
^jc:0ono/</7okNWb@03ok6XcondY<So]:C800Co]:C81On_X//00oncY<Wo[Ik8ojfNb005ojfNb0Ko
ZYg900?oYic;ojRNc?nXW/`00onXW/`6ojBKc0KoX9W=1_nLVLl00onIVmCoXkc[oj>lj`04oj>lj`Go
Y<Sb0onWjOX2ojoZn0Ko[mcg00?o/=CcojS1jonX`N/01?nX`N/5ojNoj`;oYl3[1_nW`N`5ojS2k0;o
Z<7[1onW_^X3ojJnjP?oYko[1onW`>/2ojS1k0GoZ<7[3OnW_n/4ojO0j`04o`000?nW`>_oZ<7/ojS1
k13ooooo00?o0000ooooooooool00oooool002oooooo00?o0000ooooooooool0<?ooool7ojW0jPOo
Y[o/1_nU_n`7ojO0j`KoZ<3[1_nD^o45og:bn@GoJ;;j0onZb>l3oi[8m`Oo_lCM00?ob;[=olJnd_o6
_]801_o6_]800oo1//_oa;K=olBfc@04olBfc@?o^jc:1Ono/</5okNWb@03okb^c?ndY<So]:C800Go
]:C80on_X//4ok>Tb@Ko[Ik81OnZWLT00on]Y<koZ9k<ojRNc004ojRNc0KoY9_<1_nPVLd3oibIc`?o
XkGV2?nS_>/00onTb?;oYnWjojOYnP03ojOYnPCo[>7i0on_g?L3oj_5k@OoZ<7[00?oYko[ojO0jonW
`>/01?nW`>/6ojO1k003ojS2k?nX`N_oZ<7[00CoZ<7[1OnW_^X00onV_^_oYko[ojNoj`05ojNoj`Go
Yl3[00?oZ<;/ojS1jonX`N/01_nX`N/=ojNoj`?oYl3[00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`03ooooo`00<?ooool00ol0003oooooooooo`0aooooo`KoZL3Z0onV_n`4ojNoj`KoYKo/
1_nW`>/7ojS0j`?oU;_a1?nK_>l5og^fn@GoHJoj1OnJb?L5oko4g@;o]LSY1oo6_]800onn`mgoa;K=
olBfc@06olBfc@03ok^/b_no/<_o_k3;00Co_k3;0ongYlT4okb^c0Oo]:C800?o[j;;ok>TbOncY<T0
0oncY<T7ojfNb003ojZMbOn]Y<ko[JC>00?o[JC>1_nXW/`6ojBKc0?oX9W=0onU/n<6oj>eiPKoXkc[
0onRiO`00onWjO[o[>7iojcQn@04ojcQn@03ojc<l?n[aNgoZlG]00GoZlG]0onX`N/;ojO0j`?oYl7/
0onX`^`7ojS1j`03ojNnj_nV_^_oY[k[00?oY[k[1onW_n/00onW`>_oZ<;/ojS2k003ojS2k0KoZ<7[
3OnW_n/5ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00oooool0037ooooo00?o
0000ooooooooool0<Oooool7ojW0jPKoYko[1onU_n`5ojO0j`SoZ<3[1_nK_>l5og^fn@GoHJoj1OnJ
b?L00onoa=go]LSYokG8j@04okG8j@Coa[kB1?nn`md6olBfc@03ol6of?no/<_o_k3;00Ko_k3;00?o
]jO9okb^c?nl[/`00onl[/`6okBTb003okV`d?ncY<Wo/jC900Go/jC91On]W/P00onb[M?o[JC>ojfT
cP04ojfTcPKoZ9k<1OnTVl`00onW]>;oYK?SojFch`05ojFch`KoXkGV0_nS_>/5oj;Uo0?oZ>Gk0_n/
hOT5ojc<l0GoZlG]0_nW_n/<ojO0j`SoZ<;/0onX`N/3ojNnjPOoY[k[0onW_n/4ojS1k0KoZ<;/0_nX
`N/=ojNoj`Wooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`03ooooo`00<_ooool2
o`0003;ooooo1onY`>X6ojNoj`OoYKo/1OnW`>/8ojS0j`CoVkc_0onR_^d5ohFhmPGoHk7k1?mn`od7
okG8j@03olJnd_nn`mgo_/?M00Co_/?M1?o4]/d4ol6of0Ko_k3;00?o_[gHokb^c?nl[/`01?nl[/`4
okBTb0Co^K3@1_ncY<T3ojfNb0Co/ZgC1_n]Y<h6ojRNc003ojBKc?nW]>;oYkCR00?oYkCR1onU/n<3
oj>eiPGoW]om00?oX^GlojSUnonXiO/00onXiO/3oj_Am0Ko[<c`00?oZlG]ojNojonW_n/01?nW_n/8
ojO0j`[oZ<;/2?nW_^X5ojJnj`;oYl3[1onX`N`3ojS2k0;oZ<3[2onW_n/>ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool00_ooool003Cooooo00?o0000ooooooooool0<?ooool7ojW0
jPOoYko[1_nU_n`2ojO0j`CoYl3/1onX`>/00onK_>ooX[k]oj:nk@04oj:nk@GoQKSf1OmS/O/4ogk3
o@Go]LSY0_nQcoP7okk3g@03olBfcOo1_mSo`KoH00Co`KoH1?no/</4okjmf0Ko_:k<00?o]:C8okV`
d?ni/=001?ni/=07ok>Tb@03ojfNb?nb[M?o/ZgC00?o/ZgC1_n]Y<h5ojRNc003ojZhhonW]>;oYkCR
00GoYkCR1OnU/n<3oigLo@GoW]om0onQiO`00onXiO_oZm7doj_Am005oj_Am0?o[<c`2_nW_n/3ojO0
j`CoYl7/1onX`^`<ojNnjP03ojJnjonW`>_oYl3[00CoYl3[1_nX`N`6ojS0j`KoYko[4_ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo000eooooo`03o`000?oooooooooo033o
oooo1onY`>X7ojNoj`KoYKo/1onW`>`6ojS0j`OoX[k]0_n5^?H3oi:jlPKoLKOk0_mR^?d00omn`ogo
]LSYoj7?n005oj7?n0Go_/?M0_n_co07ol6of003okn`bonn_MSo_[gH00Co_[gH1Onl[/`00onj_]go
^K3@okV`d005okV`d0Ko/jC900?o]KWLok:]donb[M<01?nb[M<7ojfTcP03ojRNc?nZ^>?oZ[SS00?o
Z[SS1onW]>800onU/n?oWMcmoigLo@05oigLo@03oikOoOnQiOcoXNGl00?oXNGl0onXe?L5oj_Am003
ojS0jonW_n_oYko[00[oYko[2OnW`N`3ojS2k0;oZ<3[2onW_^X2ojNoj`SoYl3[1_nX`N`6ojS0j`;o
Yko[5_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo000fooooo`03o`00
0?oooooooooo033ooooo1onY`>X5ojNoj`;oZ;o[1_nU_n`5ojO0k0;oY/3/1_nX`>/5oj:nk@;oYl3[
1OnB^_86og6gn`CoH[Sm1_nQcoP00onn`mgo[lo`ojo?l004ojo?l0Go`KoH00?o//g^okjmf?nn_MP0
1Onn_MP3okb^c0Co^[kM1oni/=02ok>Tb@Go]KWL1_nb[M<3ojfTcP?o[;oW1onZ^><3ojNdhPGoW=cm
0onMg?d5oiWTo@03oj7Uo?nXe?OoZ=Cg00GoZ=Cg00?oZm7dojS0jonX`>/00onX`>/8ojNoj`_oYl7/
00?oZ<;/ojS0jonX`>/01?nX`>/6ojNnjP03ojNnjonW_n_oYko[00CoYko[1_nW`>/00onX`^coZ<7/
ojS1k005ojS1k0?oZ<3[6oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo
000gooooo`;o0000<Oooool7ojW0jP03ojNojonX_n_oZ;o[00CoZ;o[1_nU_n`00onW`>coY/3/ojK0
k004ojK0k0KoZ<3[00?oX[k]ojO0jonW`>/01?nW`>/5oi:jlP?oLKOk1?n4^_P2of>fo004of:hoOnQ
coSoXLohoj7?n0CoM/Oo1_n_co000oo1_mSo//g^ok;=kP03ok;=kPOo_[gH00?o_:k<okZngOnj_]d0
1?nj_]d5okV`d003ok;5jOne^Mco]KWL00Go]KWL1Onb[M<2oj_:l0Ko[;oW1OnZ^><3oiWNoPGoW=cm
1?nBh_d3oiWTo@?oYMGi1_nXe?L00onX`N_oZ<3[ojS0j`05ojS0j`?oYko[0onW`>/9ojO1k0GoZ<;/
1_nX`>/2ojNnjPGoYkk[1_nW_n/2ojO0j`GoZ<;/1OnX`N`Pooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool00_ooool003Wooooo00?o0000ooooooooool0;oooool7ojW0jPOoZ;o[1_nU
_n`7ojK0k0?oZ<3[2_nW`>/2oi:jlPCoWkg^1_n4^_P5of>fo0GoM/Oo0on_co03ohOAo`Ko//g^1Onn
_MP2ojo?l@Oo^[kM00?o^K3@ok;5jOnbaNT00onbaNT7okFig003ok:]don[b_3oZl[`00CoZl[`1_n/
_nL00onZ^>?oVMknoiWNoP05oiWNoP03oicLoOnBh_goT^;m00CoT^;m0_nRe?T6ojGEn@;oZ=Cg1OnX
`N/5ojS0j`SoYl3[1OnW`N`9ojS2k0?oZ<3[0onW_^X7ojNnj`?oYko[0onW`N`7ojS2k003ojS1k?oo
oooooooo027ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`02ooooo`00>_ooool0
0ol0003oooooooooo`0_ooooo`OoZL3Z1OnX_n/2ojW0jPKoYKo/1onV`>`:ojO0j`?oZ<3[1_nO_Nh3
ohBjn0?oUK_b1_mi_O`5of6jo@GoQm7o1_nbcNh00onn_MSo[loaojo?l@04ojo?l@Go^[kM0_nUeoT6
ok;5j@Go]KWL0_nTeoX7oj_:l0?o[;oW1On@goh3oiWNoPGoSMon00?oT^;moj;DnOnRe?T01?nRe?T3
ojGEn@CoZ<7/1_nX`N/00onX`>_oYl3[ojO0j`0:ojO0j`03ojO1k?nX`^coZ<;/00WoZ<;/2?nW_^X5
ojNnj`03ojO0jonW`NcoYl7/00GoYl7/0onX`^`Xooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool00_ooool003_ooooo00?o0000ooooooooool0<?ooool6ojW0jP03ojRojonY`>[oZL3Z
00CoZL3Z1_nU_n`7ojK0k0GoYl3[0_nW`N`6ojS0j`CoWkg^0_nW_n/6oiFklPKoNKgl1OmQ^_d5ohOA
o`?o//g^1?n9eOl6ojo?l@03okZngOnUeoWoYMOi00CoYMOi1_nbaNT00one^McoY=OjojCGnP04ojCG
nPGoZl[`1?n1g?d3oi3OoPCoR]_o0on=goh4oj3Bn@GoX]Ci0_nW`N`7ojS1k0?oZ<7[3OnW`>/3ojS2
k@SoZ<;/3?nW_^X00onW_^_oYl3[ojO0j`03ojO0j`GoYl7/;Oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo007ooooo000looooo`03o`000?oooooooooo033ooooo0onY`>X3ojW0j`Oo
ZL3Z0onU_n`4ojJoj`KoY/3/00?oYl3[ojO1k?nW`N`01?nW`N`6ojS0j`03oinmk_nW_n_oYko[00?o
Yko[1_nE^o83ogVmo0CoSk_d1_md__d5of?0o@GoRMGo0on_co44ogkDo`KoYMOi0onbaNT5ohgLo`Go
Y=Oj00?oZl[`oh7LoOn1g?d00on1g?d3ohWFo`GoR]_o0onOc_P6oj3Bn@03oj;DnOnW`NcoYl7/00Co
Yl7/1OnX`N`=ojO0j`03ojO2kOnX`^goZ<;]00GoZ<;]0onX`^`3ojNojP[oYkkZ2_nW`>/00onW`Nco
ooooooooo`0_ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00Oooool003gooooo
0_l0000aooooo`KoZL3[1onY`>X7ojJoj`?oY/3/0onU`>`7ojO1k0?oZ<3[0onW`>/6ojNoj`?oUK_b
1?nT_^`6ohnkm0?oM;km1?n>_OH5ogK2oPKoI/Cn1Omne?l3ojGGn@GoL=3m0on=g?l5ogO@o`?oN=Om
0on>d_h6ohWFo`03oh[KoonOc_SoWlkh00GoWlkh0onPd_T4ojO0k0KoYl7/00?oZ<7/ojO0jonW`>/0
2onW`>/5ojO2k@GoZ<;]0_nX_n/6ojNojPGoYkkZ0_nW_n/:ojO0jcCooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`01ooooo`00?oooool00ol0003oooooooooo`0_ooooo`KoZL3[1onY
`>X5ojJoj`;oYko[1_nU`>`5ojO1k0;oY/7/1_nW`>/3ojNoj`?oZ<3[1onT_^`3ohnkm0CoXKg]1_n>
_OH5ogK2oP?oI/Cn1Omoa_h5ofk7o`?oL=3m1?moc?l3ogO@o`CoTl_k1_n>d_h3ohWFo`CoWlSe1OnO
c_P2ojNoj`OoYl3/0onW`N`<ojO0j`CoYl;/1_nW`^d00onX`^goZ;o[ojRoj`04ojRoj`KoYkoZ00?o
YkkZojNojonW_n/01?nW_n/5ojO0jcWooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`01ooooo`00@?ooool00ol0003oooooooooo`0_ooooo`?oZL3[1?nX`>/6ojW0jP03ojJojonW_n_o
Yko[00CoYko[1_nU`>`00onW`NcoY/7/ojK1k004ojK1k0CoYl3[0_nW`N`6ojS0j`GoY;k/0_nX`>/7
oj6mk@?oS[gf0onQ_Nd7oi6omP?oOlKn0onH__86ohg7n`?oOlco1?nI`o@6oi?;n`?oS];n1?nP`_46
oio8m@03oio>n?nW_n_oYko[00CoYko[1OnW`>`<ojO0j`WoYl;/0onW`^d4ojS0j`KoZ;o[0onW_nX3
ojNnjPOoYko[00?oYl3[ooooooooool0>oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo007ooooo0011ooooo`03o`000?oooooooooo02oooooo1onX`>/7ojW0jPKoYko[0onU`>`4ojFo
k0KoY/7/00?oYl3[ojO1k?nW`N`00onW`N`6ojS0j`03ojBnk?nX`>_oZ<3[00CoZ<3[1OnQ_Nd2ojS0
j`KoXKg]1OnA_oH00onT_^coV;kboiRnlP05oiRnlP?oSLOk0onQ_^h7oiW3m0?oTl_k1?nT_nd6oj32
l@?oWlSe2_nW_n/00onW`>coYl3[ojO0j`0:ojO0j`_oYl;/00?oZ<7/ojS0jonX`>/01_nX`>/3ojRo
j`WoYkkZ0onW_n]1ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00Oooool004;o
oooo0_l0000`ooooo`GoZ<3[0_nW`>/7ojW0jP?oYko[0onY_nX7ojFok0?oY/7/0onU`>d6ojO1k0?o
Z<3[1?nW`N`6ojS0j`03oj6mkOnX`>_oZ<3[00CoZ<3[1_nQ_Nd00onA_oKoY;k/ojBnk003ojBnk0Go
V;kb0_nV_n/6oj6nkPGoVL?d0_nV_n/7ojBok@?oX<;a3?nW_n/4ojO0k0WoYl3[2onW`^`5ojS1k0Ko
Z<3[3?nW_^Y6ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00Oooool004Cooooo
00?o0000ooooooooool0;_ooool00onX`>_oYl3[ojO0j`04ojO0j`GoZL3Z0_nY`>/6ojVojPGoYKo/
0_nW_n/6ojG0k@CoYl7/0_nV`Nd7ojO1k0?oZ<3[0onW`>`7ojS0j`?oXKg]1?nX`>/5ojBnk003oiRn
l_nV_n_oY[o[00CoY[o[1_nQ_^h00onI`oCoY[o[ojJoj`04ojJoj`GoY;o]00?oZ<3[ojNojonW_n/0
2OnW_n/9ojO0k0?oYl3[3OnW`^`3ojO1k0KoZ<7/0_nX`>/<ojNnjT[ooooo00?o0000ooooooooool0
1oooool1o`00007ooooo0Oooool004Gooooo00?o0000ooooooooool0;oooool6ojO0j`03ojW0j_nY
`>_oZL3[00CoZL3[1_nY_nX00onU_ncoYko[ojNoj`04ojNoj`KoYL3]00?oYl7/ojK1kOnV`Nd00onV
`Nd5ojO1k0;oY/7]1_nW`>`5ojS0j`;oYl3/1onX`>/2ojBnk0?oZ<7[1onV_n/3oj6nkPCoZ<3[1_nV
_n/00onT_ngoZ<3[ojS0j`03ojS0j`OoYko[2onW`>`2ojO2k@_oYl;/2?nW`N`3ojS1k0goYkkZC_oo
ool00ol0003oooooooooo`06ooooo`7o00000Oooool1ooooo`00A_ooool00ol0003oooooooooo`0`
ooooo`;oYl3[0onW`>`7ojW0j`?oZKoZ1?nY`>X6ojNoj`?oYL3]0onV_n/6ojK1k@03ojO1k?nV`Ngo
Y/7]00CoY/7]1_nW`>`00onX`>_oYl3/ojO0k004ojO0k0GoZ<3[00?oYl7/ojS1jonX`N/01?nX`N/5
ojJoj`;oYl3[1onX`>/3ojJoj`;oYl3[1onX`>/3ojNoj`CoYl7/1onW`>`6ojO2k@OoYl;/2_nW`N`=
ojNnjU;ooooo00?o0000ooooooooool01_ooool1o`00007ooooo0Oooool004Oooooo0_l0000aoooo
o`GoYl3/1OnY`>/2ojS0j`OoZL3Z0onW_n/3ojVojPKoY[o[0onV`Nd4ojFok0KoY/7]0onW`>`4ojO1
k@KoYl3/00?oZ<3[ojO1k?nW`N`00onW`N`6ojS1j`03ojJojonW`>_oYl3[00CoYl3[1OnX`>/00onW
`NcoYl3[ojO0j`04ojO0j`GoZ<3[2OnW`N`3ojO0k0[oYl;]0onW`^`:ojO1k0goYkkZE_ooool00ol0
003oooooooooo`05ooooo`7o00000Oooool1ooooo`00BOooool00ol0003oooooooooo`0_ooooo`Go
Yl3/00?oZL3[ojS0jonX`>/01?nX`>/5ojW0jP;oZL3[1_nY_nX4ojJoj`;oZ;oZ1onU_n`3ojK1k@?o
YL3/1onW`Nd3ojO0k0?oYl7]1_nW`N`3ojS1j`CoYl7/1_nW`>/00onX`>_oYl7/ojO1k003ojO1k0Ko
Yl3[00?oZ<3[ojO1k?nW`N`02OnW`N`<ojO2k@;oYl3[2_nW`N`=ojNnjU[ooooo00?o0000oooooooo
ool01?ooool1o`00007ooooo0Oooool004[ooooo00?o0000ooooooooool0;oooool2ojO0k0CoY/3/
1_nX`>/00onY`>[oZL3[ojW0j`04ojW0j`KoZKoZ00?oY[o[ojRoj_nX_nX00onX_nX5ojFok0;oYkoZ
1_nU`>`5ojO1k@03ojK0k?nW`NgoYl7]00GoYl7]0onW`N`3ojK1k@OoYl7/0onW`>/3ojO2k@KoYl7/
0onW`>/4ojO2k@OoYl7/2onW`^d00onW_n_oYl3[ojO0j`04ojO0j`GoYl7/0_nX_^X;ojNnjUoooooo
00?o0000ooooooooool00oooool1o`00007ooooo0Oooool004_ooooo00?o0000ooooooooool0;ooo
ool6ojK0k0?oZ<3[0onW`N`7ojW0j`?oZKoZ1?nY`>X5ojRojP03ojFok?nW_n[oYkoZ00CoYkoZ1_nU
`>`00onW`NgoY/3/ojK0k003ojK0k0GoYl7]0_nV`>`6ojK1k@GoYl7/0_nV`Nd6ojO2k@?oYl7/0onV
`Nd7ojO2k@?oYl7/1?nV`N`7ojO2k@GoYko[1_nW`>/00onW`NcoZ;kZojRnjP04ojRnjPOoYkkZH_oo
ool00ol0003oooooooooo`03ooooo`7o00000Oooool1ooooo`00C?ooool2o`00033ooooo1_nV`>`6
ojO1k0GoZL3[0_nX`>/7ojW0jP;oZ;oZ1?nY`>X6ojNojP?oYL3/1?nW_^/5ojK0k003ojO1kOnV`>co
Y/3/00CoY/3/1_nV`Nd00onW`NcoY/7]ojK1k@04ojK1k@CoYl;]0_nV`>`6ojK1k@GoYl;]0_nW`>`7
ojK1k0?oYl;]0_nW_^X7ojNoj`?oYl3[2_nX_^X3ojNnjVKooooo00?o0000ooooooooool00oooool1
o`00007ooooo001>ooooo`03o`000?oooooooooo02kooooo1_nV`>`6ojO1k003ojW0jonX`>_oZ<3[
00CoZ<3[1OnY`>X00onX`>_oZL3ZojW0jP05ojW0jP?oYkoZ0onY_nX7ojNnj`;oY/3/1?nW_^X6ojK0
k0?oY/7]1?nV_n/6ojK1k@03ojO2kOnV`>coY/3/00?oY/3/1_nV`Nd00onW`^goYl3/ojO0k004ojO0
k0GoY/7/1onW_^X5ojNoj`coZ;kZK?ooool00ol0003oooooooooo`02ooooo`7o00000Oooool004oo
oooo00?o0000ooooooooool0;oooool5ojK0k0?oYl7/1?nV`>`6ojS0j`03ojW0j_nX`>_oZ<3[00?o
Z<3[1OnY`>X2ojS0j`KoZKoZ1OnW_^/00onY_n[oYkkZojNnjP05ojNnjP?oY/3/0onW_^X7ojJoj`?o
Y/7]0onW_^/6ojK0k0?oY/7]1?nW_^/6ojO0k003ojK1k?nW_^[oYkkZ00WoYkkZ00?oYko[ojRnj_nX
_^X02OnX_^Yaooooo`05o`000?ooooooooooooooool000000Oooool0053ooooo00?o0000oooooooo
ool0;oooool2ojK0k0CoY[o[1_nV`>`3ojS0j`CoYl7/1OnX`>/00onY`>[oZ<3[ojS0j`04ojS0j`Ko
ZKoZ00?oYkk[ojVoj_nY_nX00onY_nX5ojNnjP;oZKoZ1_nW_^X5ojJoj`03ojRnjOnW_^_oYkk[00Go
Ykk[0onV`>`3ojRnjPOoYkk[0onW`>`3ojRnj@WoYkkZ1?nX_nX7ojRnjWCooooo00Go0000oooooooo
ooooooooo`000001ooooo`00DOooool2o`00033ooooo1_nV_n/6ojK0k0OoYl7/0_nX`>/3ojO1k0Oo
Z<3[0onY_nX4ojS0j`GoZKoZ00?oYkkZojVoj_nY_nX01?nY_nX6ojNnjP03ojJojonX_^WoZ;kY00?o
Z;kY1OnW_^/2ojRojPKoZ;kZ1OnW_^/00onX_n[oZ;kYojRnj@05ojRnj@?oYkkZ2_nX_nX3ojRnjWSo
oooo00Co0000oooooooooooo00000Oooool005?ooooo00?o0000ooooooooool0;_ooool4ojJoj`;o
Yko[1_nV`>`5ojO1k003ojK0k?nW`NcoYl7/00CoYl7/1OnX`>/2ojO1k0OoZ<3[0_nY_nX4ojS0j`Ko
ZKoZ0onW_^X3ojVojPKoZ;kY00?oYkk[ojRoj_nX_nX01?nX_nX6ojRnjP03ojNnjonX_n[oZ;oZ00?o
Z;oZ1OnX_^T2ojS0j`_oZ;oZOOooool00ol0003oooooo`000001ooooo`00E?ooool00ol0003ooooo
ooooo`0^ooooo`03ojJojonW_n_oYko[00?oYko[1_nV`>`00onW`NcoY/3/ojK0k003ojK0k0KoYl7/
00?oZ<3[ojO1k?nW`N`01?nW`N`5ojS0j`03ojO1k?nX`>_oZ<3[00GoZ<3[0onY_nX3ojS0j`KoZKoZ
0onX_^T4ojS0j`KoZ;oZ0onX_^X3ojS0j`KoZ;oZ00?oZ;kYojS0jonX`>/01?nX`>/7ojRojX3ooooo
00?o0000ooooool000000Oooool005Gooooo00?o0000ooooooooool0;_ooool6ojNoj`?oY/3/1?nW
_n/5ojK0k0?oYl7/1?nV`N`6ojO1k003ojS0jonW`NcoYl7/00?oYl7/1OnX`>/2ojO1k0KoZ<3[1?nY
_nX9ojS0j`?oZ;oZ2OnX`>/3ojRojPCoYl3[1_nX`>/3ojRojXCooooo0Ol00001ooooo`7o0000001F
ooooo`;o0000;oooool3ojNoj`?oZ;oZ1onW_n/2ojK0k0CoY[o[1_nV`N`3ojO1k0CoY/7/1OnW`N`0
0onX`>_oYl7/ojO1k004ojO1k0KoZ<3[00?oZKoZojS0jonX`>/02?nX`>/2ojO1k0[oZ<3[0_nW`N`7
ojO0j`?oZ<3[R_ooool2o`000000F?ooool00ol0003oooooooooo`0]ooooo`KoZ;oZ1OnW_n/2ojRo
jPKoY[o[0onV`N`3ojJoj`OoY/7/0_nW`N`4ojK1k0KoYl7/0onX`>/3ojO1k0OoZ<3[1_nW`N`6ojS0
j`KoYl7/1OnW`>^=ooooo`?o0000001Iooooo`03o`000?oooooooooo02gooooo1_nX_nX00onW_n_o
Z;oZojRojP04ojRojPCoY[o[0_nX_nX6ojJoj`GoY/7/00?oY[o[ojK1k?nV`N`01OnV`N`3ojO1k0?o
Y/7/1_nW`N`3ojS0j`[oYl7/0_nX`>/:ojO1k003ojO0jooooooooooo08[ooooo1?l00003ooooo`00
F_ooool00ol0003oooooooooo`0]ooooo`?oZ;oZ1?nX`>/6ojRojP03ojJojonX_n[oZ;oZ00?oZ;oZ
1_nV_n/00onV`NcoY[o[ojJoj`03ojJoj`GoY/7/0_nV_n/6ojK1k0CoYl7/0_nV`>`:ojO1k0?oY/7/
2OnW`Nb<ooooo`?o00001oooool005_ooooo00?o0000ooooooooool0;Oooool7ojS0j`?oZ;oZ0onX
`>/6ojRojP?oY[o[1?nX_nX5ojJoj`03ojK1k?nV_n_oY[o[00CoY[o[1_nV`N`00onW`NcoY/3/ojK0
k003ojK0k0GoYl7/00?oYko[ojK1k?nV`N`01OnV`N`3ojO1k8gooooo1?l0000:ooooo`00G?ooool2
o`0002kooooo3OnX`>/3ojRojPCoZ<3[1_nX_nX2ojJoj`CoZ;oZ1_nV_n/3ojK1k0?oYko[1_nV`>`0
0onW`NcoYko[ojNoj`03ojNoj`GoY/7/SOooool4o`0000kooooo001Nooooo`03o`000?oooooooooo
02cooooo5?nX`>/3ojRojP;oZ<3Z1onX_nX3ojJoj`?oZ;oZ1_nW_n/3ojK0k0WoYko[00?oY/7/oooo
ooooool0R_ooool4o`0001;ooooo001Oooooo`03o`000?oooooooooo02gooooo4onX`>/5ojS0jPGo
Z;oZ0_nX`>/6ojRojP?oYko[0onX_nX9ojNojh_ooooo1?l0000Fooooo`00H?ooool00ol0003ooooo
ooooo`0]ooooo`?oZ<3[1?nW`N`<ojS0j`GoZ<3Z00?oZ;oZojS0jonX`>/01?nX`>/4ojRojP;oZ<3[
1_nX_nX5ojNojh_ooooo0ol0000Jooooo`00HOooool2o`0002oooooo1_nW`N`2ojS0j`CoYl7/1_nX
`>/2ojS0jP[oZ<3[00?oZ;oZojS0jonX`>/00onX`>/6ojRojP03ojNojooooooooooo08Sooooo1?l0
000Mooooo`00Hoooool00ol0003oooooooooo`0]ooooo`?oYl7/0_nV`>`7ojO1k0?oZ<3[0onW`N`B
ojS0j`?oZ;oZROooool4o`00027ooooo001Tooooo`03o`000?oooooooooo02gooooo1OnV`>`5ojO1
k0;oY/3/1_nW`N`3ojS0j`?oYl7/2OnX`>^:ooooo`Co00009Oooool006Gooooo00?o0000oooooooo
ool0;Oooool5ojK0k003ojO1k?nV`>coY/3/00CoY/3/1?nW`N`2ojK0k0KoYl7/1?nX`>^:ooooo`Co
0000:Oooool006Kooooo0_l0000^ooooo`;oY/3/1?nW_n/6ojK0k003ojO1k?nV`>coY/3/00?oY/3/
1_nW`N`00onX`>_oooooooooo`27ooooo`?o0000;Oooool006Sooooo00?o0000ooooooooool0;?oo
ool6ojNoj`?oY/3/0onW_n/6ojK0k0?oYl7/R?ooool4o`00033ooooo001Yooooo`03o`000?oooooo
oooo02cooooo0onW_n/4ojRoj`GoYko[0onV`>b9ooooo`Co0000=?ooool006[ooooo00?o0000oooo
ooooool0;?ooool7ojRoj`;oYko[R_ooool4o`0003Sooooo001[ooooo`;o0000;Oooool5ojRojhWo
oooo1?l0000looooo`00KOooool00ol0003oooooooooo`0[ooooo`03ojRojooooooooooo08Oooooo
0ol00010ooooo`00K_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo08?ooooo1?l0
0013ooooo`00Koooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo07oooooo1?l00017
ooooo`00L?ooool2o`0002Wooooo00?o0000ooooooooool0Noooool4o`0004_ooooo001booooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool0Moooool4o`0004oooooo001cooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool0M?ooool3o`0005?ooooo001dooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool0L?ooool4o`0005Kooooo001eooooo`03o`000?oooooo
oooo02?ooooo00?o0000ooooooooool0K?ooool4o`0005[ooooo001fooooo`;o00008oooool00ol0
003oooooooooo`1Xooooo`Co0000G_ooool007Sooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`1Tooooo`Co0000H_ooool007Wooooo00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`1Qooooo`?o0000I_ooool007[ooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`1Mooooo`Co0000JOooool007_ooooo0_l0000Nooooo`03o`000?oooooooooo05Wooooo1?l0001]
ooooo`00OOooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo05Gooooo1?l0001aoooo
o`00O_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo057ooooo1?l0001eooooo`00
Ooooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04kooooo0ol0001iooooo`00P?oo
ool2o`0001Wooooo00?o0000ooooooooool0B_ooool4o`0007cooooo0022ooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool0A_ooool4o`00083ooooo0023ooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool0@_ooool4o`0008Cooooo0024ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool0?_ooool4o`0008Sooooo0025ooooo`;o00004oooool00ol0003ooooo
ooooo`0looooo`?o0000S?ooool008Oooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0hooooo`Co0000Soooool008Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0d
ooooo`Co0000Toooool008Wooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0`oooo
o`Co0000Uoooool008[ooooo0_l0000>ooooo`03o`000?oooooooooo02cooooo1?l0002Kooooo`00
S?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Wooooo0ol0002Oooooo`00SOoo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Gooooo1?l0002Rooooo`00S_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo027ooooo1?l0002Vooooo`00Soooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo01gooooo1?l0002Zooooo`00T?ooool2o`0000So
oooo00?o0000ooooooooool06Oooool4o`000:kooooo002Booooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool05_ooool3o`000;;ooooo002Cooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool04_ooool4o`000;Gooooo002Dooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool03_ooool4o`000;Wooooo002Eooooo`;o00000oooool00ol0003oooooooooo`0:oooo
o`Co0000_Oooool009Oooooo00Co0000oooooooooooo00002?ooool4o`000<7ooooo002Hooooo`03
o`000?oooooo000000Gooooo0ol00035ooooo`00VOooool2o`000003ooooool0003o000000;o0000
b?ooool009[ooooo0_l0003<ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0538698, 0.0432538, \
0.0035044, 0.0035044}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[.12586 .2075 -12 -8.99448 ]
[.12586 .2075 0 .00552 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.56094 .0364 -5.16972 -9 ]
[.56094 .0364 .83028 0 ]
[.75679 .08071 0 -6.17777 ]
[.75679 .08071 12 2.82223 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.9429 .3657 0 -5.9083 ]
[.9429 .3657 6 3.0917 ]
[.02494 .25992 -18 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.01611 .31527 -18 -2.78472 ]
[.01611 .31527 0 6.21528 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00254 .43215 -12 -2.88407 ]
[-0.00254 .43215 0 6.11593 ]
[-0.0124 .49393 -12 -2.93688 ]
[-0.0124 .49393 0 6.06312 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
[(-2)] .12586 .2075 1 .99877 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.56863 .04703 m
.57247 .05235 L
s
[(2)] .56094 .0364 .72324 1 Mshowa
.125 Mabswid
.18558 .19702 m
.18832 .19985 L
s
.23703 .17687 m
.23971 .17975 L
s
.28951 .15632 m
.29214 .15925 L
s
.39772 .11395 m
.40023 .11699 L
s
.4535 .09211 m
.45595 .0952 L
s
.51046 .06981 m
.51284 .07294 L
s
.08568 .23614 m
.08851 .23887 L
s
.62804 .02377 m
.63027 .02701 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.7445 .0853 m
.73835 .08759 L
s
[(-2)] .75679 .08071 -1 .37284 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.93037 .36962 m
.92411 .37158 L
s
[(2)] .9429 .3657 -1 .31296 Mshowa
.125 Mabswid
.7708 .12553 m
.7671 .12688 L
s
.79613 .16428 m
.79242 .1656 L
s
.82054 .20161 m
.81682 .20291 L
s
.86679 .27235 m
.86305 .2736 L
s
.88871 .30589 m
.88497 .30711 L
s
.9099 .3383 m
.90615 .3395 L
s
.71716 .04348 m
.71349 .04489 L
s
.95018 .39992 m
.94642 .40107 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(-20)] .02494 .25992 1 -0.39157 Mshowa
.02837 .31059 m
.0345 .30825 L
s
[(-10)] .01611 .31527 1 -0.38117 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.00981 .42772 m
.01599 .4255 L
s
[(10)] -0.00254 .43215 1 -0.3591 Mshowa
0 .48963 m
.0062 .48748 L
s
[(20)] -0.0124 .49393 1 -0.34736 Mshowa
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.655 .751 .92 r
.39362 .69477 .40169 .70183 .4152 .698 .40717 .69094 Mtetra
.654 .752 .921 r
.40717 .69094 .4152 .698 .42878 .69419 .42079 .68712 Mtetra
.655 .752 .922 r
.42079 .68712 .42878 .69419 .44242 .69039 .43448 .68328 Mtetra
.657 .753 .921 r
.43448 .68328 .44242 .69039 .45614 .68656 .44824 .67933 Mtetra
.658 .751 .919 r
.44824 .67933 .45614 .68656 .46992 .68265 .46207 .67535 Mtetra
.656 .75 .918 r
.46207 .67535 .46992 .68265 .48378 .67869 .47597 .67139 Mtetra
.655 .75 .92 r
.47597 .67139 .48378 .67869 .4977 .67473 .48994 .66744 Mtetra
.654 .751 .921 r
.48994 .66744 .4977 .67473 .5117 .67078 .50398 .6635 Mtetra
.654 .753 .922 r
.50398 .6635 .5117 .67078 .52577 .66683 .5181 .65956 Mtetra
.654 .754 .923 r
.5181 .65956 .52577 .66683 .53991 .6629 .53229 .65558 Mtetra
.657 .754 .921 r
.53229 .65558 .53991 .6629 .55412 .65895 .54655 .65148 Mtetra
.658 .751 .919 r
.54655 .65148 .55412 .65895 .56841 .65495 .56088 .64735 Mtetra
.658 .749 .917 r
.56088 .64735 .56841 .65495 .58277 .65088 .57529 .64321 Mtetra
.657 .748 .917 r
.57529 .64321 .58277 .65088 .59721 .64677 .58978 .63907 Mtetra
.656 .748 .918 r
.58978 .63907 .59721 .64677 .61172 .64264 .60434 .63493 Mtetra
.656 .749 .918 r
.60434 .63493 .61172 .64264 .6263 .63849 .61898 .63078 Mtetra
.656 .75 .919 r
.61898 .63078 .6263 .63849 .64097 .63434 .63369 .62661 Mtetra
.656 .75 .92 r
.63369 .62661 .64097 .63434 .6557 .63016 .64848 .62242 Mtetra
.656 .751 .92 r
.64848 .62242 .6557 .63016 .67052 .62598 .66335 .6182 Mtetra
.66335 .6182 .67052 .62598 .68542 .62178 .6783 .61396 Mtetra
.6783 .61396 .68542 .62178 .70039 .61757 .69333 .60969 Mtetra
.69333 .60969 .70039 .61757 .71545 .61334 .70844 .6054 Mtetra
.656 .75 .919 r
.70844 .6054 .71545 .61334 .73058 .60909 .72363 .60109 Mtetra
.72363 .60109 .73058 .60909 .7458 .60484 .7389 .59676 Mtetra
.656 .749 .918 r
.7389 .59676 .7458 .60484 .7611 .60056 .75425 .59241 Mtetra
.655 .748 .918 r
.75425 .59241 .7611 .60056 .77648 .59627 .76969 .58806 Mtetra
.655 .747 .918 r
.76969 .58806 .77648 .59627 .79194 .59193 .78522 .58371 Mtetra
.654 .748 .919 r
.78522 .58371 .79194 .59193 .80748 .58752 .80082 .57935 Mtetra
.654 .75 .92 r
.80082 .57935 .80748 .58752 .82311 .58306 .81652 .57495 Mtetra
.657 .754 .922 r
.81652 .57495 .82311 .58306 .83881 .57857 .83229 .57044 Mtetra
.657 .755 .922 r
.83229 .57044 .83881 .57857 .85461 .5741 .84814 .56588 Mtetra
.657 .754 .921 r
.84814 .56588 .85461 .5741 .8705 .56962 .86409 .5613 Mtetra
.656 .752 .92 r
.86409 .5613 .8705 .56962 .88647 .56515 .88012 .55674 Mtetra
.655 .75 .92 r
.88012 .55674 .88647 .56515 .90254 .56068 .89624 .55218 Mtetra
.654 .749 .919 r
.89624 .55218 .90254 .56068 .91869 .55616 .91246 .54764 Mtetra
.655 .75 .92 r
.91246 .54764 .91869 .55616 .93492 .55154 .92877 .54307 Mtetra
.657 .753 .921 r
.92877 .54307 .93492 .55154 .95124 .54689 .94516 .53838 Mtetra
.94516 .53838 .95124 .54689 .96765 .54224 .96163 .53365 Mtetra
.656 .752 .92 r
.96163 .53365 .96765 .54224 .98416 .53761 .97821 .52893 Mtetra
.654 .751 .921 r
.38547 .68767 .39362 .69477 .40717 .69094 .39906 .68384 Mtetra
.655 .752 .922 r
.39906 .68384 .40717 .69094 .42079 .68712 .41272 .67998 Mtetra
.657 .753 .92 r
.41272 .67998 .42079 .68712 .43448 .68328 .42646 .676 Mtetra
.658 .751 .918 r
.42646 .676 .43448 .68328 .44824 .67933 .44026 .672 Mtetra
.656 .75 .919 r
.44026 .672 .44824 .67933 .46207 .67535 .45414 .66804 Mtetra
.655 .751 .92 r
.45414 .66804 .46207 .67535 .47597 .67139 .46808 .66408 Mtetra
.654 .751 .922 r
.46808 .66408 .47597 .67139 .48994 .66744 .4821 .66015 Mtetra
.654 .753 .923 r
.4821 .66015 .48994 .66744 .50398 .6635 .49619 .65619 Mtetra
.657 .754 .922 r
.49619 .65619 .50398 .6635 .5181 .65956 .51035 .65211 Mtetra
.658 .752 .919 r
.51035 .65211 .5181 .65956 .53229 .65558 .52459 .64797 Mtetra
.658 .749 .917 r
.52459 .64797 .53229 .65558 .54655 .65148 .5389 .64382 Mtetra
.657 .748 .917 r
.5389 .64382 .54655 .65148 .56088 .64735 .55328 .63969 Mtetra
.656 .749 .918 r
.55328 .63969 .56088 .64735 .57529 .64321 .56774 .63557 Mtetra
.655 .75 .92 r
.56774 .63557 .57529 .64321 .58978 .63907 .58228 .63144 Mtetra
.655 .751 .921 r
.58228 .63144 .58978 .63907 .60434 .63493 .59689 .62731 Mtetra
.654 .753 .922 r
.59689 .62731 .60434 .63493 .61898 .63078 .61158 .62317 Mtetra
.654 .754 .923 r
.61158 .62317 .61898 .63078 .63369 .62661 .62635 .61899 Mtetra
.655 .755 .924 r
.62635 .61899 .63369 .62661 .64848 .62242 .6412 .61478 Mtetra
.655 .756 .924 r
.6412 .61478 .64848 .62242 .66335 .6182 .65612 .61054 Mtetra
.65612 .61054 .66335 .6182 .6783 .61396 .67113 .60625 Mtetra
.656 .756 .924 r
.67113 .60625 .6783 .61396 .69333 .60969 .68621 .60193 Mtetra
.656 .756 .923 r
.68621 .60193 .69333 .60969 .70844 .6054 .70138 .59758 Mtetra
.70138 .59758 .70844 .6054 .72363 .60109 .71662 .59319 Mtetra
.657 .755 .922 r
.71662 .59319 .72363 .60109 .7389 .59676 .73195 .58876 Mtetra
.657 .753 .921 r
.73195 .58876 .7389 .59676 .75425 .59241 .74735 .58432 Mtetra
.656 .752 .92 r
.74735 .58432 .75425 .59241 .76969 .58806 .76285 .57988 Mtetra
.656 .751 .92 r
.76285 .57988 .76969 .58806 .78522 .58371 .77843 .57543 Mtetra
.656 .749 .919 r
.77843 .57543 .78522 .58371 .80082 .57935 .79409 .57097 Mtetra
.654 .747 .918 r
.79409 .57097 .80082 .57935 .81652 .57495 .80984 .56655 Mtetra
.80984 .56655 .81652 .57495 .83229 .57044 .82569 .56211 Mtetra
.655 .751 .92 r
.82569 .56211 .83229 .57044 .84814 .56588 .84161 .5576 Mtetra
.657 .754 .922 r
.84161 .5576 .84814 .56588 .86409 .5613 .85762 .55297 Mtetra
.658 .754 .921 r
.85762 .55297 .86409 .5613 .88012 .55674 .87371 .5483 Mtetra
.656 .752 .921 r
.87371 .5483 .88012 .55674 .89624 .55218 .88989 .54365 Mtetra
.656 .751 .92 r
.88989 .54365 .89624 .55218 .91246 .54764 .90617 .53901 Mtetra
.654 .749 .919 r
.90617 .53901 .91246 .54764 .92877 .54307 .92255 .53441 Mtetra
.655 .75 .92 r
.92255 .53441 .92877 .54307 .94516 .53838 .93901 .52976 Mtetra
.657 .753 .921 r
.93901 .52976 .94516 .53838 .96163 .53365 .95556 .525 Mtetra
.95556 .525 .96163 .53365 .97821 .52893 .9722 .5202 Mtetra
.654 .752 .922 r
.37724 .68053 .38547 .68767 .39906 .68384 .39088 .67666 Mtetra
.657 .753 .92 r
.39088 .67666 .39906 .68384 .41272 .67998 .40459 .67267 Mtetra
.658 .751 .918 r
.40459 .67267 .41272 .67998 .42646 .676 .41837 .66865 Mtetra
.656 .75 .919 r
.41837 .66865 .42646 .676 .44026 .672 .43221 .66467 Mtetra
.655 .751 .921 r
.43221 .66467 .44026 .672 .45414 .66804 .44613 .66071 Mtetra
.653 .752 .922 r
.44613 .66071 .45414 .66804 .46808 .66408 .46012 .65677 Mtetra
.655 .754 .923 r
.46012 .65677 .46808 .66408 .4821 .66015 .47419 .65277 Mtetra
.658 .753 .92 r
.47419 .65277 .4821 .66015 .49619 .65619 .48832 .64863 Mtetra
.658 .75 .918 r
.48832 .64863 .49619 .65619 .51035 .65211 .50254 .64446 Mtetra
.657 .748 .917 r
.50254 .64446 .51035 .65211 .52459 .64797 .51682 .64033 Mtetra
.656 .749 .919 r
.51682 .64033 .52459 .64797 .5389 .64382 .53118 .63621 Mtetra
.655 .751 .921 r
.53118 .63621 .5389 .64382 .55328 .63969 .54561 .63211 Mtetra
.653 .752 .922 r
.54561 .63211 .55328 .63969 .56774 .63557 .56012 .62803 Mtetra
.653 .754 .924 r
.56012 .62803 .56774 .63557 .58228 .63144 .57471 .62392 Mtetra
.654 .756 .925 r
.57471 .62392 .58228 .63144 .59689 .62731 .58938 .61977 Mtetra
.654 .757 .925 r
.58938 .61977 .59689 .62731 .61158 .62317 .60412 .61556 Mtetra
.657 .757 .924 r
.60412 .61556 .61158 .62317 .62635 .61899 .61894 .61126 Mtetra
.656 .754 .922 r
.61894 .61126 .62635 .61899 .6412 .61478 .63384 .60694 Mtetra
.656 .753 .921 r
.63384 .60694 .6412 .61478 .65612 .61054 .64882 .60262 Mtetra
.656 .752 .921 r
.64882 .60262 .65612 .61054 .67113 .60625 .66387 .5983 Mtetra
.655 .752 .921 r
.66387 .5983 .67113 .60625 .68621 .60193 .67902 .59397 Mtetra
.67902 .59397 .68621 .60193 .70138 .59758 .69424 .58963 Mtetra
.654 .754 .923 r
.69424 .58963 .70138 .59758 .71662 .59319 .70954 .58529 Mtetra
.656 .757 .924 r
.70954 .58529 .71662 .59319 .73195 .58876 .72493 .58084 Mtetra
.657 .758 .924 r
.72493 .58084 .73195 .58876 .74735 .58432 .7404 .57634 Mtetra
.657 .757 .923 r
.7404 .57634 .74735 .58432 .76285 .57988 .75595 .57179 Mtetra
.658 .756 .922 r
.75595 .57179 .76285 .57988 .77843 .57543 .77158 .56721 Mtetra
.657 .753 .921 r
.77158 .56721 .77843 .57543 .79409 .57097 .7873 .56265 Mtetra
.656 .751 .92 r
.7873 .56265 .79409 .57097 .80984 .56655 .80311 .5581 Mtetra
.655 .749 .919 r
.80311 .5581 .80984 .56655 .82569 .56211 .81901 .55356 Mtetra
.654 .747 .918 r
.81901 .55356 .82569 .56211 .84161 .5576 .835 .54906 Mtetra
.654 .748 .919 r
.835 .54906 .84161 .5576 .85762 .55297 .85108 .54453 Mtetra
.657 .753 .921 r
.85108 .54453 .85762 .55297 .87371 .5483 .86724 .53985 Mtetra
.658 .755 .922 r
.86724 .53985 .87371 .5483 .88989 .54365 .88348 .5351 Mtetra
.657 .753 .921 r
.88348 .5351 .88989 .54365 .90617 .53901 .89982 .53036 Mtetra
.656 .751 .92 r
.89982 .53036 .90617 .53901 .92255 .53441 .91626 .52565 Mtetra
.654 .749 .919 r
.91626 .52565 .92255 .53441 .93901 .52976 .93279 .52097 Mtetra
.655 .749 .92 r
.93279 .52097 .93901 .52976 .95556 .525 .94942 .51625 Mtetra
.657 .753 .921 r
.94942 .51625 .95556 .525 .9722 .5202 .96613 .5114 Mtetra
.36894 .67333 .37724 .68053 .39088 .67666 .38262 .66933 Mtetra
.658 .751 .919 r
.38262 .66933 .39088 .67666 .40459 .67267 .39637 .66529 Mtetra
.656 .75 .919 r
.39637 .66529 .40459 .67267 .41837 .66865 .4102 .66129 Mtetra
.654 .751 .921 r
.4102 .66129 .41837 .66865 .43221 .66467 .42409 .65732 Mtetra
.653 .752 .922 r
.42409 .65732 .43221 .66467 .44613 .66071 .43805 .65337 Mtetra
.655 .754 .922 r
.43805 .65337 .44613 .66071 .46012 .65677 .45209 .64932 Mtetra
.658 .753 .919 r
.45209 .64932 .46012 .65677 .47419 .65277 .4662 .64514 Mtetra
.658 .749 .917 r
.4662 .64514 .47419 .65277 .48832 .64863 .48038 .64097 Mtetra
.656 .749 .918 r
.48038 .64097 .48832 .64863 .50254 .64446 .49464 .63684 Mtetra
.655 .75 .92 r
.49464 .63684 .50254 .64446 .51682 .64033 .50897 .63274 Mtetra
.653 .752 .922 r
.50897 .63274 .51682 .64033 .53118 .63621 .52338 .62869 Mtetra
.652 .754 .924 r
.52338 .62869 .53118 .63621 .54561 .63211 .53787 .6246 Mtetra
.654 .756 .925 r
.53787 .6246 .54561 .63211 .56012 .62803 .55243 .62043 Mtetra
.658 .756 .922 r
.55243 .62043 .56012 .62803 .57471 .62392 .56706 .6161 Mtetra
.657 .751 .919 r
.56706 .6161 .57471 .62392 .58938 .61977 .58178 .6118 Mtetra
.656 .748 .918 r
.58178 .6118 .58938 .61977 .60412 .61556 .59657 .60753 Mtetra
.655 .747 .918 r
.59657 .60753 .60412 .61556 .61894 .61126 .61145 .60328 Mtetra
.654 .749 .92 r
.61145 .60328 .61894 .61126 .63384 .60694 .6264 .59902 Mtetra
.654 .752 .921 r
.6264 .59902 .63384 .60694 .64882 .60262 .64144 .59472 Mtetra
.656 .754 .922 r
.64144 .59472 .64882 .60262 .66387 .5983 .65655 .59035 Mtetra
.657 .754 .922 r
.65655 .59035 .66387 .5983 .67902 .59397 .67175 .58592 Mtetra
.657 .753 .92 r
.67175 .58592 .67902 .59397 .69424 .58963 .68702 .58144 Mtetra
.657 .75 .919 r
.68702 .58144 .69424 .58963 .70954 .58529 .70238 .57695 Mtetra
.656 .747 .917 r
.70238 .57695 .70954 .58529 .72493 .58084 .71782 .57248 Mtetra
.655 .747 .918 r
.71782 .57248 .72493 .58084 .7404 .57634 .73335 .56804 Mtetra
.653 .75 .921 r
.73335 .56804 .7404 .57634 .75595 .57179 .74897 .56363 Mtetra
.656 .756 .923 r
.74897 .56363 .75595 .57179 .77158 .56721 .76467 .55906 Mtetra
.658 .758 .923 r
.76467 .55906 .77158 .56721 .7873 .56265 .78045 .55439 Mtetra
.658 .756 .922 r
.78045 .55439 .7873 .56265 .80311 .5581 .79631 .54969 Mtetra
.657 .753 .921 r
.79631 .54969 .80311 .5581 .81901 .55356 .81227 .54504 Mtetra
.656 .751 .92 r
.81227 .54504 .81901 .55356 .835 .54906 .82832 .54041 Mtetra
.654 .748 .919 r
.82832 .54041 .835 .54906 .85108 .54453 .84446 .53582 Mtetra
.653 .747 .919 r
.84446 .53582 .85108 .54453 .86724 .53985 .8607 .53123 Mtetra
.656 .752 .921 r
.8607 .53123 .86724 .53985 .88348 .5351 .87702 .52651 Mtetra
.658 .755 .921 r
.87702 .52651 .88348 .5351 .89982 .53036 .89342 .52167 Mtetra
.657 .753 .921 r
.89342 .52167 .89982 .53036 .91626 .52565 .90991 .51686 Mtetra
.656 .751 .92 r
.90991 .51686 .91626 .52565 .93279 .52097 .92651 .51207 Mtetra
.654 .749 .92 r
.92651 .51207 .93279 .52097 .94942 .51625 .94321 .50732 Mtetra
.655 .75 .92 r
.94321 .50732 .94942 .51625 .96613 .5114 .96 .50251 Mtetra
.658 .751 .919 r
.36056 .66599 .36894 .67333 .38262 .66933 .37428 .66192 Mtetra
.656 .75 .919 r
.37428 .66192 .38262 .66933 .39637 .66529 .38808 .65789 Mtetra
.655 .751 .921 r
.38808 .65789 .39637 .66529 .4102 .66129 .40194 .6539 Mtetra
.653 .752 .922 r
.40194 .6539 .4102 .66129 .42409 .65732 .41588 .64994 Mtetra
.656 .754 .922 r
.41588 .64994 .42409 .65732 .43805 .65337 .42989 .64586 Mtetra
.659 .752 .919 r
.42989 .64586 .43805 .65337 .45209 .64932 .44398 .64166 Mtetra
.658 .749 .917 r
.44398 .64166 .45209 .64932 .4662 .64514 .45813 .63748 Mtetra
.656 .749 .919 r
.45813 .63748 .4662 .64514 .48038 .64097 .47237 .63335 Mtetra
.653 .751 .921 r
.47237 .63335 .48038 .64097 .49464 .63684 .48667 .62928 Mtetra
.652 .753 .924 r
.48667 .62928 .49464 .63684 .50897 .63274 .50105 .62522 Mtetra
.654 .756 .925 r
.50105 .62522 .50897 .63274 .52338 .62869 .51551 .62108 Mtetra
.659 .756 .922 r
.51551 .62108 .52338 .62869 .53787 .6246 .53004 .61672 Mtetra
.656 .749 .918 r
.53004 .61672 .53787 .6246 .55243 .62043 .54465 .61246 Mtetra
.652 .747 .919 r
.54465 .61246 .55243 .62043 .56706 .6161 .55935 .60834 Mtetra
.646 .751 .926 r
.55935 .60834 .56706 .6161 .58178 .6118 .57412 .60438 Mtetra
.642 .76 .934 r
.57412 .60438 .58178 .6118 .59657 .60753 .58897 .60047 Mtetra
.64 .771 .942 r
.58897 .60047 .59657 .60753 .61145 .60328 .60391 .59654 Mtetra
.64 .781 .949 r
.60391 .59654 .61145 .60328 .6264 .59902 .61894 .59251 Mtetra
.643 .79 .952 r
.61894 .59251 .6264 .59902 .64144 .59472 .63404 .58831 Mtetra
.648 .795 .953 r
.63404 .58831 .64144 .59472 .65655 .59035 .64921 .5839 Mtetra
.654 .797 .951 r
.64921 .5839 .65655 .59035 .67175 .58592 .66447 .57928 Mtetra
.659 .795 .947 r
.66447 .57928 .67175 .58592 .68702 .58144 .67979 .57449 Mtetra
.663 .788 .941 r
.67979 .57449 .68702 .58144 .70238 .57695 .6952 .5696 Mtetra
.665 .779 .934 r
.6952 .5696 .70238 .57695 .71782 .57248 .71068 .56468 Mtetra
.663 .767 .927 r
.71068 .56468 .71782 .57248 .73335 .56804 .72625 .55981 Mtetra
.66 .756 .921 r
.72625 .55981 .73335 .56804 .74897 .56363 .74191 .55509 Mtetra
.656 .748 .918 r
.74191 .55509 .74897 .56363 .76467 .55906 .75767 .55052 Mtetra
.653 .748 .92 r
.75767 .55052 .76467 .55906 .78045 .55439 .77353 .54605 Mtetra
.657 .755 .923 r
.77353 .54605 .78045 .55439 .79631 .54969 .78946 .54135 Mtetra
.659 .758 .923 r
.78946 .54135 .79631 .54969 .81227 .54504 .80547 .53656 Mtetra
.658 .755 .921 r
.80547 .53656 .81227 .54504 .82832 .54041 .82157 .53178 Mtetra
.656 .752 .92 r
.82157 .53178 .82832 .54041 .84446 .53582 .83777 .52706 Mtetra
.654 .749 .919 r
.83777 .52706 .84446 .53582 .8607 .53123 .85407 .52238 Mtetra
.653 .747 .919 r
.85407 .52238 .8607 .53123 .87702 .52651 .87047 .51773 Mtetra
.656 .751 .92 r
.87047 .51773 .87702 .52651 .89342 .52167 .88695 .51294 Mtetra
.658 .755 .921 r
.88695 .51294 .89342 .52167 .90991 .51686 .90351 .50802 Mtetra
.657 .753 .921 r
.90351 .50802 .90991 .51686 .92651 .51207 .92016 .50313 Mtetra
.655 .751 .92 r
.92016 .50313 .92651 .51207 .94321 .50732 .93692 .49828 Mtetra
.654 .749 .92 r
.93692 .49828 .94321 .50732 .96 .50251 .95379 .49346 Mtetra
.657 .75 .919 r
.3521 .65855 .36056 .66599 .37428 .66192 .36587 .65448 Mtetra
.655 .751 .92 r
.36587 .65448 .37428 .66192 .38808 .65789 .3797 .65045 Mtetra
.653 .751 .922 r
.3797 .65045 .38808 .65789 .40194 .6539 .39361 .64648 Mtetra
.655 .753 .922 r
.39361 .64648 .40194 .6539 .41588 .64994 .40759 .6424 Mtetra
.659 .752 .919 r
.40759 .6424 .41588 .64994 .42989 .64586 .42166 .63818 Mtetra
.658 .749 .917 r
.42166 .63818 .42989 .64586 .44398 .64166 .43579 .63397 Mtetra
.655 .75 .919 r
.43579 .63397 .44398 .64166 .45813 .63748 .44999 .62984 Mtetra
.652 .751 .922 r
.44999 .62984 .45813 .63748 .47237 .63335 .46427 .62578 Mtetra
.651 .754 .924 r
.46427 .62578 .47237 .63335 .48667 .62928 .47862 .62172 Mtetra
.657 .757 .923 r
.47862 .62172 .48667 .62928 .50105 .62522 .49305 .61742 Mtetra
.658 .751 .919 r
.49305 .61742 .50105 .62522 .51551 .62108 .50756 .61311 Mtetra
.65 .746 .92 r
.50756 .61311 .51551 .62108 .53004 .61672 .52214 .60906 Mtetra
.639 .751 .93 r
.52214 .60906 .53004 .61672 .54465 .61246 .53681 .60534 Mtetra
.626 .763 .945 r
.53681 .60534 .54465 .61246 .55935 .60834 .55156 .60188 Mtetra
.611 .778 .961 r
.55156 .60188 .55935 .60834 .57412 .60438 .5664 .59867 Mtetra
.588 .795 .978 r
.5664 .59867 .57412 .60438 .58897 .60047 .58133 .59572 Mtetra
.579 .823 .991 r
.58133 .59572 .58897 .60047 .60391 .59654 .59636 .59251 Mtetra
.576 .846 .995 r
.59636 .59251 .60391 .59654 .61894 .59251 .61146 .58891 Mtetra
.582 .862 .995 r
.61146 .58891 .61894 .59251 .63404 .58831 .62664 .5849 Mtetra
.596 .874 .993 r
.62664 .5849 .63404 .58831 .64921 .5839 .6419 .58045 Mtetra
.615 .88 .99 r
.6419 .58045 .64921 .5839 .66447 .57928 .65722 .57557 Mtetra
.638 .88 .986 r
.65722 .57557 .66447 .57928 .67979 .57449 .67261 .57026 Mtetra
.662 .872 .978 r
.67261 .57026 .67979 .57449 .6952 .5696 .68805 .56457 Mtetra
.681 .854 .965 r
.68805 .56457 .6952 .5696 .71068 .56468 .70356 .55859 Mtetra
.679 .823 .952 r
.70356 .55859 .71068 .56468 .72625 .55981 .71915 .55288 Mtetra
.675 .798 .941 r
.71915 .55288 .72625 .55981 .74191 .55509 .73484 .54741 Mtetra
.669 .777 .93 r
.73484 .54741 .74191 .55509 .75767 .55052 .75062 .54219 Mtetra
.661 .758 .922 r
.75062 .54219 .75767 .55052 .77353 .54605 .76652 .53732 Mtetra
.654 .747 .918 r
.76652 .53732 .77353 .54605 .78946 .54135 .78252 .5327 Mtetra
.654 .75 .92 r
.78252 .5327 .78946 .54135 .80547 .53656 .79861 .52807 Mtetra
.659 .757 .923 r
.79861 .52807 .80547 .53656 .82157 .53178 .81477 .52319 Mtetra
.659 .756 .922 r
.81477 .52319 .82157 .53178 .83777 .52706 .83103 .51831 Mtetra
.656 .752 .92 r
.83103 .51831 .83777 .52706 .85407 .52238 .84739 .5135 Mtetra
.654 .749 .919 r
.84739 .5135 .85407 .52238 .87047 .51773 .86384 .50875 Mtetra
.653 .747 .919 r
.86384 .50875 .87047 .51773 .88695 .51294 .8804 .50403 Mtetra
.656 .752 .92 r
.8804 .50403 .88695 .51294 .90351 .50802 .89704 .49914 Mtetra
.658 .755 .921 r
.89704 .49914 .90351 .50802 .92016 .50313 .91376 .49414 Mtetra
.656 .752 .921 r
.91376 .49414 .92016 .50313 .93692 .49828 .93058 .48919 Mtetra
.655 .751 .92 r
.93058 .48919 .93692 .49828 .95379 .49346 .94751 .48427 Mtetra
.656 .75 .92 r
.34356 .65105 .3521 .65855 .36587 .65448 .35737 .647 Mtetra
.653 .751 .922 r
.35737 .647 .36587 .65448 .3797 .65045 .37125 .643 Mtetra
.654 .753 .922 r
.37125 .643 .3797 .65045 .39361 .64648 .3852 .63894 Mtetra
.659 .753 .92 r
.3852 .63894 .39361 .64648 .40759 .6424 .39923 .63469 Mtetra
.658 .75 .917 r
.39923 .63469 .40759 .6424 .42166 .63818 .41334 .63046 Mtetra
.655 .75 .919 r
.41334 .63046 .42166 .63818 .43579 .63397 .42752 .6263 Mtetra
.652 .751 .922 r
.42752 .6263 .43579 .63397 .44999 .62984 .44176 .62224 Mtetra
.651 .754 .925 r
.44176 .62224 .44999 .62984 .46427 .62578 .45609 .61817 Mtetra
.659 .757 .922 r
.45609 .61817 .46427 .62578 .47862 .62172 .47049 .61379 Mtetra
.655 .748 .918 r
.47049 .61379 .47862 .62172 .49305 .61742 .48497 .60955 Mtetra
.641 .747 .926 r
.48497 .60955 .49305 .61742 .50756 .61311 .49953 .60579 Mtetra
.621 .756 .943 r
.49953 .60579 .50756 .61311 .52214 .60906 .51416 .60254 Mtetra
.584 .768 .967 r
.51416 .60254 .52214 .60906 .53681 .60534 .52888 .60002 Mtetra
.538 .79 .991 r
.52888 .60002 .53681 .60534 .55156 .60188 .5437 .59795 Mtetra
.506 .821 1 r
.5437 .59795 .55156 .60188 .5664 .59867 .55862 .59561 Mtetra
.495 .843 .995 r
.55862 .59561 .5664 .59867 .58133 .59572 .57363 .59279 Mtetra
.519 .857 .995 r
.57363 .59279 .58133 .59572 .59636 .59251 .58873 .58946 Mtetra
.549 .867 .995 r
.58873 .58946 .59636 .59251 .61146 .58891 .6039 .58567 Mtetra
.575 .872 .995 r
.6039 .58567 .61146 .58891 .62664 .5849 .61916 .58151 Mtetra
.593 .875 .993 r
.61916 .58151 .62664 .5849 .6419 .58045 .63449 .57702 Mtetra
.608 .88 .991 r
.63449 .57702 .6419 .58045 .65722 .57557 .6499 .57222 Mtetra
.621 .887 .989 r
.6499 .57222 .65722 .57557 .67261 .57026 .66537 .56703 Mtetra
.636 .897 .985 r
.66537 .56703 .67261 .57026 .68805 .56457 .68091 .56138 Mtetra
.655 .904 .981 r
.68091 .56138 .68805 .56457 .70356 .55859 .69649 .5552 Mtetra
.677 .906 .976 r
.69649 .5552 .70356 .55859 .71915 .55288 .71212 .54852 Mtetra
.7 .884 .966 r
.71212 .54852 .71915 .55288 .73484 .54741 .7278 .54155 Mtetra
.697 .84 .951 r
.7278 .54155 .73484 .54741 .75062 .54219 .74358 .53503 Mtetra
.681 .799 .938 r
.74358 .53503 .75062 .54219 .76652 .53732 .75948 .52925 Mtetra
.669 .771 .927 r
.75948 .52925 .76652 .53732 .78252 .5327 .77551 .52398 Mtetra
.657 .752 .92 r
.77551 .52398 .78252 .5327 .79861 .52807 .79165 .51919 Mtetra
.652 .747 .919 r
.79165 .51919 .79861 .52807 .81477 .52319 .80791 .51455 Mtetra
.659 .757 .922 r
.80791 .51455 .81477 .52319 .83103 .51831 .82422 .50958 Mtetra
.659 .756 .922 r
.82422 .50958 .83103 .51831 .84739 .5135 .84064 .50461 Mtetra
.656 .752 .92 r
.84064 .50461 .84739 .5135 .86384 .50875 .85715 .49972 Mtetra
.654 .749 .92 r
.85715 .49972 .86384 .50875 .8804 .50403 .87377 .49491 Mtetra
.653 .748 .919 r
.87377 .49491 .8804 .50403 .89704 .49914 .89049 .49011 Mtetra
.657 .753 .92 r
.89049 .49011 .89704 .49914 .91376 .49414 .90729 .4851 Mtetra
.658 .754 .921 r
.90729 .4851 .91376 .49414 .93058 .48919 .92418 .48003 Mtetra
.656 .752 .92 r
.92418 .48003 .93058 .48919 .94751 .48427 .94117 .47501 Mtetra
.654 .751 .921 r
.33493 .64353 .34356 .65105 .35737 .647 .34878 .63948 Mtetra
.653 .752 .922 r
.34878 .63948 .35737 .647 .37125 .643 .36271 .63545 Mtetra
.658 .753 .92 r
.36271 .63545 .37125 .643 .3852 .63894 .37671 .63121 Mtetra
.659 .75 .917 r
.37671 .63121 .3852 .63894 .39923 .63469 .39079 .62693 Mtetra
.656 .75 .919 r
.39079 .62693 .39923 .63469 .41334 .63046 .40494 .62274 Mtetra
.652 .751 .922 r
.40494 .62274 .41334 .63046 .42752 .6263 .41916 .61865 Mtetra
.651 .753 .924 r
.41916 .61865 .42752 .6263 .44176 .62224 .43346 .61458 Mtetra
.66 .756 .921 r
.43346 .61458 .44176 .62224 .45609 .61817 .44784 .61017 Mtetra
.653 .747 .919 r
.44784 .61017 .45609 .61817 .47049 .61379 .46229 .60599 Mtetra
.632 .747 .931 r
.46229 .60599 .47049 .61379 .48497 .60955 .4768 .60247 Mtetra
.601 .758 .953 r
.4768 .60247 .48497 .60955 .49953 .60579 .4914 .59968 Mtetra
.526 .761 .982 r
.4914 .59968 .49953 .60579 .51416 .60254 .50608 .59823 Mtetra
.471 .795 .999 r
.50608 .59823 .51416 .60254 .52888 .60002 .52086 .59669 Mtetra
.464 .822 .996 r
.52086 .59669 .52888 .60002 .5437 .59795 .53575 .59455 Mtetra
.518 .843 .998 r
.53575 .59455 .5437 .59795 .55862 .59561 .55073 .5916 Mtetra
.58 .849 .995 r
.55073 .5916 .55862 .59561 .57363 .59279 .5658 .58786 Mtetra
.625 .836 .981 r
.5658 .58786 .57363 .59279 .58873 .58946 .58095 .58355 Mtetra
.654 .816 .961 r
.58095 .58355 .58873 .58946 .6039 .58567 .59617 .57872 Mtetra
.66 .789 .943 r
.59617 .57872 .6039 .58567 .61916 .58151 .61147 .57389 Mtetra
.653 .77 .935 r
.61147 .57389 .61916 .58151 .63449 .57702 .62686 .56936 Mtetra
.643 .767 .938 r
.62686 .56936 .63449 .57702 .6499 .57222 .64235 .56513 Mtetra
.639 .782 .95 r
.64235 .56513 .6499 .57222 .66537 .56703 .65793 .5609 Mtetra
.647 .814 .963 r
.65793 .5609 .66537 .56703 .68091 .56138 .67358 .55616 Mtetra
.656 .846 .973 r
.67358 .55616 .68091 .56138 .69649 .5552 .68929 .55083 Mtetra
.672 .877 .975 r
.68929 .55083 .69649 .5552 .71212 .54852 .70503 .54469 Mtetra
.691 .899 .971 r
.70503 .54469 .71212 .54852 .7278 .54155 .7208 .53771 Mtetra
.71 .905 .964 r
.7208 .53771 .7278 .54155 .74358 .53503 .73661 .53011 Mtetra
.722 .877 .953 r
.73661 .53011 .74358 .53503 .75948 .52925 .75246 .52241 Mtetra
.693 .815 .94 r
.75246 .52241 .75948 .52925 .77551 .52398 .76848 .51605 Mtetra
.675 .781 .929 r
.76848 .51605 .77551 .52398 .79165 .51919 .78464 .51044 Mtetra
.658 .755 .921 r
.78464 .51044 .79165 .51919 .80791 .51455 .80094 .50549 Mtetra
.652 .746 .919 r
.80094 .50549 .80791 .51455 .82422 .50958 .81735 .50079 Mtetra
.66 .757 .922 r
.81735 .50079 .82422 .50958 .84064 .50461 .83383 .49573 Mtetra
.659 .756 .922 r
.83383 .49573 .84064 .50461 .85715 .49972 .8504 .49068 Mtetra
.656 .752 .92 r
.8504 .49068 .85715 .49972 .87377 .49491 .86708 .48573 Mtetra
.653 .748 .92 r
.86708 .48573 .87377 .49491 .89049 .49011 .88387 .48087 Mtetra
.654 .748 .919 r
.88387 .48087 .89049 .49011 .90729 .4851 .90075 .47595 Mtetra
.658 .754 .921 r
.90075 .47595 .90729 .4851 .92418 .48003 .91771 .47082 Mtetra
.657 .753 .921 r
.91771 .47082 .92418 .48003 .94117 .47501 .93477 .4657 Mtetra
.653 .751 .922 r
.32622 .63595 .33493 .64353 .34878 .63948 .34012 .63191 Mtetra
.656 .753 .921 r
.34012 .63191 .34878 .63948 .36271 .63545 .35409 .62773 Mtetra
.66 .751 .918 r
.35409 .62773 .36271 .63545 .37671 .63121 .36814 .62341 Mtetra
.657 .749 .918 r
.36814 .62341 .37671 .63121 .39079 .62693 .38227 .61917 Mtetra
.653 .751 .921 r
.38227 .61917 .39079 .62693 .40494 .62274 .39646 .61503 Mtetra
.65 .752 .924 r
.39646 .61503 .40494 .62274 .41916 .61865 .41072 .61095 Mtetra
.659 .756 .922 r
.41072 .61095 .41916 .61865 .43346 .61458 .42507 .60655 Mtetra
.653 .747 .919 r
.42507 .60655 .43346 .61458 .44784 .61017 .43949 .60235 Mtetra
.628 .746 .932 r
.43949 .60235 .44784 .61017 .46229 .60599 .45398 .59893 Mtetra
.58 .752 .96 r
.45398 .59893 .46229 .60599 .4768 .60247 .46853 .59666 Mtetra
.487 .756 .989 r
.46853 .59666 .4768 .60247 .4914 .59968 .48316 .59574 Mtetra
.43 .789 .996 r
.48316 .59574 .4914 .59968 .50608 .59823 .4979 .59452 Mtetra
.487 .821 .999 r
.4979 .59452 .50608 .59823 .52086 .59669 .51275 .59228 Mtetra
.585 .838 .993 r
.51275 .59228 .52086 .59669 .53575 .59455 .5277 .58868 Mtetra
.677 .821 .952 r
.5277 .58868 .53575 .59455 .55073 .5916 .54273 .5832 Mtetra
.701 .761 .898 r
.54273 .5832 .55073 .5916 .5658 .58786 .55782 .5768 Mtetra
.692 .704 .857 r
.55782 .5768 .5658 .58786 .58095 .58355 .57298 .57044 Mtetra
.676 .666 .832 r
.57298 .57044 .58095 .58355 .59617 .57872 .58822 .56449 Mtetra
.662 .644 .822 r
.58822 .56449 .59617 .57872 .61147 .57389 .60354 .55917 Mtetra
.648 .633 .821 r
.60354 .55917 .61147 .57389 .62686 .56936 .61896 .55459 Mtetra
.635 .626 .825 r
.61896 .55459 .62686 .56936 .64235 .56513 .63449 .55074 Mtetra
.623 .627 .834 r
.63449 .55074 .64235 .56513 .65793 .5609 .65014 .54753 Mtetra
.615 .639 .851 r
.65014 .54753 .65793 .5609 .67358 .55616 .66591 .54475 Mtetra
.611 .673 .884 r
.66591 .54475 .67358 .55616 .68929 .55083 .68178 .542 Mtetra
.627 .737 .927 r
.68178 .542 .68929 .55083 .70503 .54469 .69772 .53835 Mtetra
.669 .82 .956 r
.69772 .53835 .70503 .54469 .7208 .53771 .71365 .53277 Mtetra
.7 .872 .962 r
.71365 .53277 .7208 .53771 .73661 .53011 .72958 .5258 Mtetra
.725 .897 .957 r
.72958 .5258 .73661 .53011 .75246 .52241 .74552 .51777 Mtetra
.735 .892 .951 r
.74552 .51777 .75246 .52241 .76848 .51605 .76149 .50942 Mtetra
.706 .828 .94 r
.76149 .50942 .76848 .51605 .78464 .51044 .77762 .50243 Mtetra
.678 .783 .929 r
.77762 .50243 .78464 .51044 .80094 .50549 .79392 .49661 Mtetra
.658 .755 .922 r
.79392 .49661 .80094 .50549 .81735 .50079 .81038 .49159 Mtetra
.653 .747 .919 r
.81038 .49159 .81735 .50079 .83383 .49573 .82695 .48678 Mtetra
.66 .757 .922 r
.82695 .48678 .83383 .49573 .8504 .49068 .84358 .48162 Mtetra
.658 .755 .921 r
.84358 .48162 .8504 .49068 .86708 .48573 .86032 .47652 Mtetra
.655 .751 .92 r
.86032 .47652 .86708 .48573 .88387 .48087 .87717 .47152 Mtetra
.653 .748 .92 r
.87717 .47152 .88387 .48087 .90075 .47595 .89413 .4666 Mtetra
.656 .75 .92 r
.89413 .4666 .90075 .47595 .91771 .47082 .91117 .46153 Mtetra
.658 .754 .921 r
.91117 .46153 .91771 .47082 .93477 .4657 .9283 .4563 Mtetra
.653 .752 .922 r
.31743 .62833 .32622 .63595 .34012 .63191 .33137 .62423 Mtetra
.659 .753 .919 r
.33137 .62423 .34012 .63191 .35409 .62773 .34539 .6199 Mtetra
.658 .75 .918 r
.34539 .6199 .35409 .62773 .36814 .62341 .35949 .61558 Mtetra
.655 .75 .92 r
.35949 .61558 .36814 .62341 .38227 .61917 .37365 .61137 Mtetra
.65 .751 .923 r
.37365 .61137 .38227 .61917 .39646 .61503 .38789 .60728 Mtetra
.656 .755 .922 r
.38789 .60728 .39646 .61503 .41072 .61095 .40221 .60296 Mtetra
.656 .75 .919 r
.40221 .60296 .41072 .61095 .42507 .60655 .4166 .59863 Mtetra
.63 .745 .93 r
.4166 .59863 .42507 .60655 .43949 .60235 .43105 .59513 Mtetra
.576 .748 .958 r
.43105 .59513 .43949 .60235 .45398 .59893 .44556 .59296 Mtetra
.467 .743 .989 r
.44556 .59296 .45398 .59893 .46853 .59666 .46013 .59244 Mtetra
.421 .777 .996 r
.46013 .59244 .46853 .59666 .48316 .59574 .47481 .5915 Mtetra
.516 .818 1 r
.47481 .5915 .48316 .59574 .4979 .59452 .48962 .58911 Mtetra
.653 .828 .967 r
.48962 .58911 .4979 .59452 .51275 .59228 .50455 .58425 Mtetra
.722 .774 .893 r
.50455 .58425 .51275 .59228 .5277 .58868 .51956 .57691 Mtetra
.714 .699 .834 r
.51956 .57691 .5277 .58868 .54273 .5832 .53462 .56896 Mtetra
.701 .66 .806 r
.53462 .56896 .54273 .5832 .55782 .5768 .54974 .56104 Mtetra
.685 .636 .794 r
.54974 .56104 .55782 .5768 .57298 .57044 .56491 .55376 Mtetra
.67 .619 .79 r
.56491 .55376 .57298 .57044 .58822 .56449 .58016 .54737 Mtetra
.655 .609 .79 r
.58016 .54737 .58822 .56449 .60354 .55917 .5955 .54188 Mtetra
.642 .601 .792 r
.5955 .54188 .60354 .55917 .61896 .55459 .61094 .53723 Mtetra
.629 .594 .796 r
.61094 .53723 .61896 .55459 .63449 .55074 .62649 .53344 Mtetra
.614 .588 .801 r
.62649 .53344 .63449 .55074 .65014 .54753 .64216 .53056 Mtetra
.598 .584 .808 r
.64216 .53056 .65014 .54753 .66591 .54475 .65798 .52858 Mtetra
.585 .588 .821 r
.65798 .52858 .66591 .54475 .68178 .542 .67395 .52727 Mtetra
.582 .606 .842 r
.67395 .52727 .68178 .542 .69772 .53835 .69003 .526 Mtetra
.59 .649 .877 r
.69003 .526 .69772 .53835 .71365 .53277 .70622 .52413 Mtetra
.643 .753 .928 r
.70622 .52413 .71365 .53277 .72958 .5258 .72237 .51974 Mtetra
.702 .843 .95 r
.72237 .51974 .72958 .5258 .74552 .51777 .73846 .51283 Mtetra
.737 .885 .948 r
.73846 .51283 .74552 .51777 .76149 .50942 .75452 .5044 Mtetra
.747 .886 .943 r
.75452 .5044 .76149 .50942 .77762 .50243 .77061 .49553 Mtetra
.71 .826 .937 r
.77061 .49553 .77762 .50243 .79392 .49661 .78688 .48833 Mtetra
.677 .78 .928 r
.78688 .48833 .79392 .49661 .81038 .49159 .80334 .48249 Mtetra
.656 .752 .921 r
.80334 .48249 .81038 .49159 .82695 .48678 .81997 .4775 Mtetra
.655 .749 .919 r
.81997 .4775 .82695 .48678 .84358 .48162 .8367 .47251 Mtetra
.66 .757 .921 r
.8367 .47251 .84358 .48162 .86032 .47652 .8535 .46726 Mtetra
.657 .753 .921 r
.8535 .46726 .86032 .47652 .87717 .47152 .87041 .46213 Mtetra
.654 .75 .92 r
.87041 .46213 .87717 .47152 .89413 .4666 .88743 .45711 Mtetra
.653 .748 .92 r
.88743 .45711 .89413 .4666 .91117 .46153 .90456 .4521 Mtetra
.658 .753 .92 r
.90456 .4521 .91117 .46153 .9283 .4563 .92177 .44684 Mtetra
.656 .753 .921 r
.30855 .62063 .31743 .62833 .33137 .62423 .32254 .61639 Mtetra
.66 .751 .918 r
.32254 .61639 .33137 .62423 .34539 .6199 .33661 .612 Mtetra
.656 .75 .919 r
.33661 .612 .34539 .6199 .35949 .61558 .35075 .60772 Mtetra
.652 .751 .922 r
.35075 .60772 .35949 .61558 .37365 .61137 .36495 .60357 Mtetra
.652 .753 .924 r
.36495 .60357 .37365 .61137 .38789 .60728 .37924 .59939 Mtetra
.66 .754 .92 r
.37924 .59939 .38789 .60728 .40221 .60296 .39361 .59489 Mtetra
.639 .745 .926 r
.39361 .59489 .40221 .60296 .4166 .59863 .40803 .59111 Mtetra
.592 .746 .95 r
.40803 .59111 .4166 .59863 .43105 .59513 .4225 .58859 Mtetra
.468 .728 .982 r
.4225 .58859 .43105 .59513 .44556 .59296 .437 .5883 Mtetra
.412 .76 .995 r
.437 .5883 .44556 .59296 .46013 .59244 .45163 .58776 Mtetra
.523 .808 .998 r
.45163 .58776 .46013 .59244 .47481 .5915 .4664 .58547 Mtetra
.687 .818 .945 r
.4664 .58547 .47481 .5915 .48962 .58911 .48131 .57969 Mtetra
.737 .747 .86 r
.48131 .57969 .48962 .58911 .50455 .58425 .49631 .57113 Mtetra
.726 .684 .809 r
.49631 .57113 .50455 .58425 .51956 .57691 .51137 .56174 Mtetra
.711 .653 .79 r
.51137 .56174 .51956 .57691 .53462 .56896 .52646 .55267 Mtetra
.691 .633 .786 r
.52646 .55267 .53462 .56896 .54974 .56104 .5416 .54475 Mtetra
.668 .623 .795 r
.5416 .54475 .54974 .56104 .56491 .55376 .55682 .53856 Mtetra
.658 .632 .813 r
.55682 .53856 .56491 .55376 .58016 .54737 .57211 .53328 Mtetra
.654 .645 .829 r
.57211 .53328 .58016 .54737 .5955 .54188 .5875 .52838 Mtetra
.651 .654 .839 r
.5875 .52838 .5955 .54188 .61094 .53723 .60297 .52368 Mtetra
.647 .652 .841 r
.60297 .52368 .61094 .53723 .62649 .53344 .61853 .51919 Mtetra
.638 .638 .834 r
.61853 .51919 .62649 .53344 .64216 .53056 .6342 .51507 Mtetra
.62 .614 .823 r
.6342 .51507 .64216 .53056 .65798 .52858 .64999 .51188 Mtetra
.587 .583 .816 r
.64999 .51188 .65798 .52858 .67395 .52727 .66597 .51045 Mtetra
.563 .57 .819 r
.66597 .51045 .67395 .52727 .69003 .526 .68212 .5102 Mtetra
.553 .579 .834 r
.68212 .5102 .69003 .526 .70622 .52413 .69843 .5103 Mtetra
.565 .614 .861 r
.69843 .5103 .70622 .52413 .72237 .51974 .71484 .50958 Mtetra
.623 .712 .91 r
.71484 .50958 .72237 .51974 .73846 .51283 .7312 .50603 Mtetra
.707 .827 .939 r
.7312 .50603 .73846 .51283 .75452 .5044 .74744 .49891 Mtetra
.749 .875 .938 r
.74744 .49891 .75452 .5044 .77061 .49553 .76361 .48996 Mtetra
.755 .876 .934 r
.76361 .48996 .77061 .49553 .78688 .48833 .77982 .48074 Mtetra
.702 .808 .931 r
.77982 .48074 .78688 .48833 .80334 .48249 .79628 .47379 Mtetra
.67 .77 .925 r
.79628 .47379 .80334 .48249 .81997 .4775 .81292 .46814 Mtetra
.652 .748 .92 r
.81292 .46814 .81997 .4775 .8367 .47251 .82973 .46322 Mtetra
.659 .754 .92 r
.82973 .46322 .8367 .47251 .8535 .46726 .8466 .45797 Mtetra
.659 .756 .921 r
.8466 .45797 .8535 .46726 .87041 .46213 .86358 .45268 Mtetra
.656 .752 .92 r
.86358 .45268 .87041 .46213 .88743 .45711 .88066 .44753 Mtetra
.652 .748 .92 r
.88066 .44753 .88743 .45711 .90456 .4521 .89787 .44247 Mtetra
.655 .75 .919 r
.89787 .44247 .90456 .4521 .92177 .44684 .91516 .43727 Mtetra
.659 .753 .92 r
.29958 .61284 .30855 .62063 .32254 .61639 .31362 .60846 Mtetra
.658 .75 .918 r
.31362 .60846 .32254 .61639 .33661 .612 .32773 .60407 Mtetra
.654 .751 .921 r
.32773 .60407 .33661 .612 .35075 .60772 .34191 .59981 Mtetra
.65 .751 .923 r
.34191 .59981 .35075 .60772 .36495 .60357 .35616 .59568 Mtetra
.658 .755 .921 r
.35616 .59568 .36495 .60357 .37924 .59939 .37051 .59122 Mtetra
.65 .747 .92 r
.37051 .59122 .37924 .59939 .39361 .59489 .38491 .58703 Mtetra
.61 .744 .94 r
.38491 .58703 .39361 .59489 .40803 .59111 .39935 .58406 Mtetra
.502 .728 .974 r
.39935 .58406 .40803 .59111 .4225 .58859 .41381 .58334 Mtetra
.401 .739 .992 r
.41381 .58334 .4225 .58859 .437 .5883 .42836 .58329 Mtetra
.499 .79 .997 r
.42836 .58329 .437 .5883 .45163 .58776 .44306 .58157 Mtetra
.684 .813 .945 r
.44306 .58157 .45163 .58776 .4664 .58547 .45795 .57589 Mtetra
.747 .746 .851 r
.45795 .57589 .4664 .58547 .48131 .57969 .47297 .56658 Mtetra
.74 .689 .802 r
.47297 .56658 .48131 .57969 .49631 .57113 .48803 .55608 Mtetra
.721 .659 .788 r
.48803 .55608 .49631 .57113 .51137 .56174 .50313 .54624 Mtetra
.687 .64 .798 r
.50313 .54624 .51137 .56174 .52646 .55267 .51825 .53893 Mtetra
.665 .654 .83 r
.51825 .53893 .52646 .55267 .5416 .54475 .53344 .53348 Mtetra
.656 .692 .872 r
.53344 .53348 .5416 .54475 .55682 .53856 .54871 .52881 Mtetra
.648 .721 .902 r
.54871 .52881 .55682 .53856 .57211 .53328 .56407 .52448 Mtetra
.649 .744 .919 r
.56407 .52448 .57211 .53328 .5875 .52838 .57952 .52006 Mtetra
.656 .76 .926 r
.57952 .52006 .5875 .52838 .60297 .52368 .59505 .51531 Mtetra
.664 .762 .923 r
.59505 .51531 .60297 .52368 .61853 .51919 .61066 .51024 Mtetra
.666 .75 .913 r
.61066 .51024 .61853 .51919 .6342 .51507 .62635 .50507 Mtetra
.657 .724 .898 r
.62635 .50507 .6342 .51507 .64999 .51188 .64214 .50024 Mtetra
.638 .685 .878 r
.64214 .50024 .64999 .51188 .66597 .51045 .65806 .4962 Mtetra
.597 .623 .848 r
.65806 .4962 .66597 .51045 .68212 .5102 .67415 .49405 Mtetra
.545 .571 .832 r
.67415 .49405 .68212 .5102 .69843 .5103 .6905 .4945 Mtetra
.527 .567 .839 r
.6905 .4945 .69843 .5103 .71484 .50958 .70703 .49564 Mtetra
.547 .606 .864 r
.70703 .49564 .71484 .50958 .7312 .50603 .72364 .49559 Mtetra
.626 .71 .907 r
.72364 .49559 .7312 .50603 .74744 .49891 .74016 .49185 Mtetra
.722 .828 .93 r
.74016 .49185 .74744 .49891 .76361 .48996 .75651 .48402 Mtetra
.761 .869 .927 r
.75651 .48402 .76361 .48996 .77982 .48074 .77279 .47446 Mtetra
.746 .858 .932 r
.77279 .47446 .77982 .48074 .79628 .47379 .78918 .46556 Mtetra
.691 .792 .927 r
.78918 .46556 .79628 .47379 .81292 .46814 .80582 .45897 Mtetra
.66 .759 .923 r
.80582 .45897 .81292 .46814 .82973 .46322 .82267 .45364 Mtetra
.654 .747 .919 r
.82267 .45364 .82973 .46322 .8466 .45797 .83964 .44858 Mtetra
.661 .756 .921 r
.83964 .44858 .8466 .45797 .86358 .45268 .85668 .44317 Mtetra
.657 .753 .921 r
.85668 .44317 .86358 .45268 .88066 .44753 .87383 .43789 Mtetra
.653 .75 .921 r
.87383 .43789 .88066 .44753 .89787 .44247 .8911 .43274 Mtetra
.653 .749 .92 r
.8911 .43274 .89787 .44247 .91516 .43727 .90848 .42757 Mtetra
.66 .752 .918 r
.29053 .60492 .29958 .61284 .31362 .60846 .30461 .60046 Mtetra
.657 .75 .919 r
.30461 .60046 .31362 .60846 .32773 .60407 .31877 .59609 Mtetra
.652 .751 .922 r
.31877 .59609 .32773 .60407 .34191 .59981 .33299 .59187 Mtetra
.651 .752 .924 r
.33299 .59187 .34191 .59981 .35616 .59568 .34729 .58764 Mtetra
.66 .753 .919 r
.34729 .58764 .35616 .59568 .37051 .59122 .36168 .58309 Mtetra
.633 .745 .929 r
.36168 .58309 .37051 .59122 .38491 .58703 .37611 .57945 Mtetra
.559 .736 .959 r
.37611 .57945 .38491 .58703 .39935 .58406 .39055 .57768 Mtetra
.421 .715 .985 r
.39055 .57768 .39935 .58406 .41381 .58334 .40502 .57795 Mtetra
.45 .759 .995 r
.40502 .57795 .41381 .58334 .42836 .58329 .41964 .5772 Mtetra
.639 .806 .963 r
.41964 .5772 .42836 .58329 .44306 .58157 .43447 .57285 Mtetra
.753 .765 .862 r
.43447 .57285 .44306 .58157 .45795 .57589 .44949 .56346 Mtetra
.753 .702 .804 r
.44949 .56346 .45795 .57589 .47297 .56658 .46459 .55221 Mtetra
.734 .672 .79 r
.46459 .55221 .47297 .56658 .48803 .55608 .4797 .54155 Mtetra
.687 .653 .81 r
.4797 .54155 .48803 .55608 .50313 .54624 .4948 .53448 Mtetra
.661 .685 .862 r
.4948 .53448 .50313 .54624 .51825 .53893 .50996 .52953 Mtetra
.631 .723 .914 r
.50996 .52953 .51825 .53893 .53344 .53348 .52521 .52584 Mtetra
.615 .763 .95 r
.52521 .52584 .53344 .53348 .54871 .52881 .54054 .52235 Mtetra
.616 .797 .969 r
.54054 .52235 .54871 .52881 .56407 .52448 .55597 .51852 Mtetra
.626 .816 .973 r
.55597 .51852 .56407 .52448 .57952 .52006 .57149 .51419 Mtetra
.641 .825 .971 r
.57149 .51419 .57952 .52006 .59505 .51531 .58709 .5094 Mtetra
.656 .829 .966 r
.58709 .5094 .59505 .51531 .61066 .51024 .60277 .50414 Mtetra
.672 .829 .959 r
.60277 .50414 .61066 .51024 .62635 .50507 .61853 .49838 Mtetra
.685 .818 .947 r
.61853 .49838 .62635 .50507 .64214 .50024 .63435 .49227 Mtetra
.681 .784 .928 r
.63435 .49227 .64214 .50024 .65806 .4962 .65026 .48635 Mtetra
.65 .729 .907 r
.65026 .48635 .65806 .4962 .67415 .49405 .6663 .48171 Mtetra
.6 .659 .879 r
.6663 .48171 .67415 .49405 .6905 .4945 .68254 .47922 Mtetra
.521 .573 .848 r
.68254 .47922 .6905 .4945 .70703 .49564 .6991 .4804 Mtetra
.505 .565 .851 r
.6991 .4804 .70703 .49564 .72364 .49559 .71585 .48223 Mtetra
.541 .616 .876 r
.71585 .48223 .72364 .49559 .74016 .49185 .73265 .48218 Mtetra
.659 .744 .913 r
.73265 .48218 .74016 .49185 .75651 .48402 .74924 .47696 Mtetra
.745 .837 .921 r
.74924 .47696 .75651 .48402 .77279 .47446 .76566 .46803 Mtetra
.768 .86 .918 r
.76566 .46803 .77279 .47446 .78918 .46556 .78206 .45801 Mtetra
.721 .821 .927 r
.78206 .45801 .78918 .46556 .80582 .45897 .79868 .45008 Mtetra
.675 .773 .924 r
.79868 .45008 .80582 .45897 .82267 .45364 .81554 .44407 Mtetra
.652 .75 .921 r
.81554 .44407 .82267 .45364 .83964 .44858 .83259 .43901 Mtetra
.66 .754 .92 r
.83259 .43901 .83964 .44858 .85668 .44317 .8497 .4336 Mtetra
.659 .755 .921 r
.8497 .4336 .85668 .44317 .87383 .43789 .86692 .42818 Mtetra
.655 .751 .921 r
.86692 .42818 .87383 .43789 .8911 .43274 .88426 .4229 Mtetra
.652 .748 .92 r
.88426 .4229 .8911 .43274 .90848 .42757 .90172 .41771 Mtetra
.66 .751 .918 r
.28139 .5969 .29053 .60492 .30461 .60046 .29552 .59241 Mtetra
.655 .751 .92 r
.29552 .59241 .30461 .60046 .31877 .59609 .30972 .58805 Mtetra
.65 .75 .923 r
.30972 .58805 .31877 .59609 .33299 .59187 .32398 .58384 Mtetra
.656 .754 .921 r
.32398 .58384 .33299 .59187 .34729 .58764 .33834 .57939 Mtetra
.653 .748 .92 r
.33834 .57939 .34729 .58764 .36168 .58309 .35277 .57505 Mtetra
.609 .742 .94 r
.35277 .57505 .36168 .58309 .37611 .57945 .36721 .57207 Mtetra
.485 .715 .972 r
.36721 .57207 .37611 .57945 .39055 .57768 .38163 .57171 Mtetra
.406 .723 .989 r
.38163 .57171 .39055 .57768 .40502 .57795 .39615 .57191 Mtetra
.549 .781 .985 r
.39615 .57191 .40502 .57795 .41964 .5772 .41087 .56968 Mtetra
.738 .79 .895 r
.41087 .56968 .41964 .5772 .43447 .57285 .42586 .56158 Mtetra
.763 .722 .815 r
.42586 .56158 .43447 .57285 .44949 .56346 .44098 .55013 Mtetra
.752 .691 .794 r
.44098 .55013 .44949 .56346 .46459 .55221 .45613 .53842 Mtetra
.702 .669 .815 r
.45613 .53842 .46459 .55221 .4797 .54155 .47125 .53054 Mtetra
.659 .699 .876 r
.47125 .53054 .4797 .54155 .4948 .53448 .48638 .52568 Mtetra
.608 .731 .932 r
.48638 .52568 .4948 .53448 .50996 .52953 .50158 .52265 Mtetra
.587 .775 .969 r
.50158 .52265 .50996 .52953 .52521 .52584 .51688 .51969 Mtetra
.622 .809 .972 r
.51688 .51969 .52521 .52584 .54054 .52235 .53228 .51555 Mtetra
.641 .797 .958 r
.53228 .51555 .54054 .52235 .55597 .51852 .54777 .51102 Mtetra
.65 .783 .945 r
.54777 .51102 .55597 .51852 .57149 .51419 .56335 .50631 Mtetra
.654 .775 .938 r
.56335 .50631 .57149 .51419 .58709 .5094 .57901 .50147 Mtetra
.657 .776 .937 r
.57901 .50147 .58709 .5094 .60277 .50414 .59476 .4965 Mtetra
.66 .786 .941 r
.59476 .4965 .60277 .50414 .61853 .49838 .6106 .49134 Mtetra
.668 .805 .949 r
.6106 .49134 .61853 .49838 .63435 .49227 .62651 .48579 Mtetra
.699 .831 .946 r
.62651 .48579 .63435 .49227 .65026 .48635 .64247 .47904 Mtetra
.698 .809 .934 r
.64247 .47904 .65026 .48635 .6663 .48171 .65851 .47235 Mtetra
.652 .745 .918 r
.65851 .47235 .6663 .48171 .68254 .47922 .6747 .46751 Mtetra
.577 .664 .897 r
.6747 .46751 .68254 .47922 .6991 .4804 .69115 .46575 Mtetra
.488 .567 .862 r
.69115 .46575 .6991 .4804 .71585 .48223 .70794 .46793 Mtetra
.492 .576 .868 r
.70794 .46793 .71585 .48223 .73265 .48218 .7249 .46988 Mtetra
.57 .652 .892 r
.7249 .46988 .73265 .48218 .74924 .47696 .7418 .46842 Mtetra
.711 .792 .915 r
.7418 .46842 .74924 .47696 .76566 .46803 .7584 .46091 Mtetra
.766 .844 .911 r
.7584 .46091 .76566 .46803 .78206 .45801 .77489 .45086 Mtetra
.754 .843 .918 r
.77489 .45086 .78206 .45801 .79868 .45008 .79148 .44137 Mtetra
.692 .787 .923 r
.79148 .44137 .79868 .45008 .81554 .44407 .80836 .43458 Mtetra
.659 .756 .922 r
.80836 .43458 .81554 .44407 .83259 .43901 .82545 .42919 Mtetra
.655 .749 .919 r
.82545 .42919 .83259 .43901 .8497 .4336 .84266 .42391 Mtetra
.661 .755 .92 r
.84266 .42391 .8497 .4336 .86692 .42818 .85994 .41837 Mtetra
.656 .752 .921 r
.85994 .41837 .86692 .42818 .88426 .4229 .87735 .41298 Mtetra
.652 .749 .921 r
.87735 .41298 .88426 .4229 .90172 .41771 .89488 .40772 Mtetra
.659 .751 .918 r
.27216 .5888 .28139 .5969 .29552 .59241 .28633 .5843 Mtetra
.654 .751 .921 r
.28633 .5843 .29552 .59241 .30972 .58805 .30057 .57994 Mtetra
.649 .751 .924 r
.30057 .57994 .30972 .58805 .32398 .58384 .31488 .57571 Mtetra
.66 .754 .92 r
.31488 .57571 .32398 .58384 .33834 .57939 .32929 .5711 Mtetra
.641 .746 .925 r
.32929 .5711 .33834 .57939 .35277 .57505 .34375 .56711 Mtetra
.578 .736 .951 r
.34375 .56711 .35277 .57505 .36721 .57207 .3582 .56489 Mtetra
.426 .697 .977 r
.3582 .56489 .36721 .57207 .38163 .57171 .37262 .5654 Mtetra
.453 .736 .988 r
.37262 .5654 .38163 .57171 .39615 .57191 .38721 .565 Mtetra
.657 .79 .946 r
.38721 .565 .39615 .57191 .41087 .56968 .40207 .56021 Mtetra
.765 .754 .843 r
.40207 .56021 .41087 .56968 .42586 .56158 .41719 .54962 Mtetra
.77 .715 .801 r
.41719 .54962 .42586 .56158 .44098 .55013 .4324 .53704 Mtetra
.733 .69 .809 r
.4324 .53704 .44098 .55013 .45613 .53842 .44756 .52709 Mtetra
.672 .699 .866 r
.44756 .52709 .45613 .53842 .47125 .53054 .46268 .52157 Mtetra
.604 .726 .931 r
.46268 .52157 .47125 .53054 .48638 .52568 .47784 .51864 Mtetra
.579 .769 .969 r
.47784 .51864 .48638 .52568 .50158 .52265 .49309 .51591 Mtetra
.628 .795 .963 r
.49309 .51591 .50158 .52265 .51688 .51969 .50846 .51176 Mtetra
.647 .77 .938 r
.50846 .51176 .51688 .51969 .53228 .51555 .52392 .50719 Mtetra
.653 .762 .93 r
.52392 .50719 .53228 .51555 .54777 .51102 .53947 .50245 Mtetra
.654 .759 .926 r
.53947 .50245 .54777 .51102 .56335 .50631 .5551 .49764 Mtetra
.656 .758 .925 r
.5551 .49764 .56335 .50631 .57901 .50147 .57083 .49274 Mtetra
.657 .758 .925 r
.57083 .49274 .57901 .50147 .59476 .4965 .58664 .48778 Mtetra
.658 .76 .925 r
.58664 .48778 .59476 .4965 .6106 .49134 .60255 .48273 Mtetra
.662 .765 .927 r
.60255 .48273 .6106 .49134 .62651 .48579 .61854 .47752 Mtetra
.671 .778 .93 r
.61854 .47752 .62651 .48579 .64247 .47904 .6346 .47187 Mtetra
.706 .818 .934 r
.6346 .47187 .64247 .47904 .65851 .47235 .6507 .46478 Mtetra
.701 .807 .931 r
.6507 .46478 .65851 .47235 .6747 .46751 .66688 .45788 Mtetra
.635 .736 .921 r
.66688 .45788 .6747 .46751 .69115 .46575 .68326 .45361 Mtetra
.519 .63 .901 r
.68326 .45361 .69115 .46575 .70794 .46793 .7 .45387 Mtetra
.456 .562 .874 r
.7 .45387 .70794 .46793 .7249 .46988 .71704 .45686 Mtetra
.505 .608 .889 r
.71704 .45686 .7249 .46988 .7418 .46842 .73414 .45785 Mtetra
.651 .727 .905 r
.73414 .45785 .7418 .46842 .7584 .46091 .751 .45287 Mtetra
.751 .82 .906 r
.751 .45287 .7584 .46091 .77489 .45086 .76762 .44335 Mtetra
.771 .839 .904 r
.76762 .44335 .77489 .45086 .79148 .44137 .78422 .43286 Mtetra
.711 .8 .92 r
.78422 .43286 .79148 .44137 .80836 .43458 .8011 .42517 Mtetra
.668 .765 .922 r
.8011 .42517 .80836 .43458 .82545 .42919 .81823 .41932 Mtetra
.652 .749 .92 r
.81823 .41932 .82545 .42919 .84266 .42391 .83553 .4141 Mtetra
.661 .755 .92 r
.83553 .4141 .84266 .42391 .85994 .41837 .85288 .40848 Mtetra
.657 .753 .921 r
.85288 .40848 .85994 .41837 .87735 .41298 .87036 .40298 Mtetra
.653 .75 .921 r
.87036 .40298 .87735 .41298 .89488 .40772 .88796 .39762 Mtetra
.658 .751 .919 r
.26283 .58062 .27216 .5888 .28633 .5843 .27705 .57611 Mtetra
.652 .751 .922 r
.27705 .57611 .28633 .5843 .30057 .57994 .29134 .57176 Mtetra
.65 .751 .923 r
.29134 .57176 .30057 .57994 .31488 .57571 .30569 .56747 Mtetra
.66 .753 .919 r
.30569 .56747 .31488 .57571 .32929 .5711 .32015 .56279 Mtetra
.629 .744 .931 r
.32015 .56279 .32929 .5711 .34375 .56711 .33463 .55916 Mtetra
.534 .723 .96 r
.33463 .55916 .34375 .56711 .3582 .56489 .34907 .55792 Mtetra
.406 .697 .98 r
.34907 .55792 .3582 .56489 .37262 .5654 .36353 .55856 Mtetra
.516 .748 .98 r
.36353 .55856 .37262 .5654 .38721 .565 .3782 .55723 Mtetra
.723 .784 .901 r
.3782 .55723 .38721 .565 .40207 .56021 .39322 .54976 Mtetra
.776 .74 .82 r
.39322 .54976 .40207 .56021 .41719 .54962 .40845 .53763 Mtetra
.77 .716 .802 r
.40845 .53763 .41719 .54962 .4324 .53704 .42372 .52503 Mtetra
.704 .699 .842 r
.42372 .52503 .4324 .53704 .44756 .52709 .43887 .51757 Mtetra
.63 .723 .914 r
.43887 .51757 .44756 .52709 .46268 .52157 .454 .51382 Mtetra
.565 .746 .962 r
.454 .51382 .46268 .52157 .47784 .51864 .4692 .51162 Mtetra
.621 .786 .961 r
.4692 .51162 .47784 .51864 .49309 .51591 .48453 .50769 Mtetra
.647 .764 .934 r
.48453 .50769 .49309 .51591 .50846 .51176 .49995 .50315 Mtetra
.652 .757 .927 r
.49995 .50315 .50846 .51176 .52392 .50719 .51547 .49844 Mtetra
.649 .754 .926 r
.51547 .49844 .52392 .50719 .53947 .50245 .53108 .49381 Mtetra
.646 .756 .93 r
.53108 .49381 .53947 .50245 .5551 .49764 .54677 .48924 Mtetra
.655 .767 .932 r
.54677 .48924 .5551 .49764 .57083 .49274 .56256 .48429 Mtetra
.664 .769 .928 r
.56256 .48429 .57083 .49274 .58664 .48778 .57844 .47898 Mtetra
.662 .762 .924 r
.57844 .47898 .58664 .48778 .60255 .48273 .5944 .47373 Mtetra
.66 .757 .922 r
.5944 .47373 .60255 .48273 .61854 .47752 .61045 .46855 Mtetra
.663 .76 .922 r
.61045 .46855 .61854 .47752 .6346 .47187 .6266 .46319 Mtetra
.678 .774 .923 r
.6266 .46319 .6346 .47187 .6507 .46478 .64281 .45721 Mtetra
.719 .814 .924 r
.64281 .45721 .6507 .46478 .66688 .45788 .65903 .44947 Mtetra
.681 .784 .928 r
.65903 .44947 .66688 .45788 .68326 .45361 .6754 .44329 Mtetra
.583 .702 .924 r
.6754 .44329 .68326 .45361 .7 .45387 .69205 .4409 Mtetra
.441 .576 .893 r
.69205 .4409 .7 .45387 .71704 .45686 .70912 .44379 Mtetra
.457 .584 .892 r
.70912 .44379 .71704 .45686 .73414 .45785 .72635 .44625 Mtetra
.585 .679 .905 r
.72635 .44625 .73414 .45785 .751 .45287 .74345 .44393 Mtetra
.731 .795 .903 r
.74345 .44393 .751 .45287 .76762 .44335 .76022 .43527 Mtetra
.772 .828 .895 r
.76022 .43527 .76762 .44335 .78422 .43286 .77689 .42454 Mtetra
.734 .814 .914 r
.77689 .42454 .78422 .43286 .8011 .42517 .79378 .41574 Mtetra
.678 .77 .92 r
.79378 .41574 .8011 .42517 .81823 .41932 .81095 .4094 Mtetra
.652 .75 .922 r
.81095 .4094 .81823 .41932 .83553 .4141 .82831 .40414 Mtetra
.661 .754 .919 r
.82831 .40414 .83553 .4141 .85288 .40848 .84575 .39848 Mtetra
.659 .754 .92 r
.84575 .39848 .85288 .40848 .87036 .40298 .8633 .39287 Mtetra
.654 .751 .921 r
.8633 .39287 .87036 .40298 .88796 .39762 .88097 .38742 Mtetra
.657 .751 .919 r
.25341 .57238 .26283 .58062 .27705 .57611 .26768 .56785 Mtetra
.651 .75 .922 r
.26768 .56785 .27705 .57611 .29134 .57176 .28201 .56349 Mtetra
.653 .752 .922 r
.28201 .56349 .29134 .57176 .30569 .56747 .29642 .55906 Mtetra
.657 .751 .919 r
.29642 .55906 .30569 .56747 .32015 .56279 .31092 .55444 Mtetra
.617 .742 .935 r
.31092 .55444 .32015 .56279 .33463 .55916 .32542 .55113 Mtetra
.498 .708 .965 r
.32542 .55113 .33463 .55916 .34907 .55792 .33986 .55061 Mtetra
.42 .696 .978 r
.33986 .55061 .34907 .55792 .36353 .55856 .35436 .55114 Mtetra
.569 .754 .965 r
.35436 .55114 .36353 .55856 .3782 .55723 .36912 .54881 Mtetra
.756 .776 .869 r
.36912 .54881 .3782 .55723 .39322 .54976 .38428 .53927 Mtetra
.785 .742 .813 r
.38428 .53927 .39322 .54976 .40845 .53763 .39962 .52621 Mtetra
.762 .724 .817 r
.39962 .52621 .40845 .53763 .42372 .52503 .41491 .51471 Mtetra
.682 .724 .881 r
.41491 .51471 .42372 .52503 .43887 .51757 .43007 .50876 Mtetra
.588 .728 .94 r
.43007 .50876 .43887 .51757 .454 .51382 .44522 .5062 Mtetra
.587 .759 .961 r
.44522 .5062 .454 .51382 .4692 .51162 .46048 .50334 Mtetra
.64 .761 .936 r
.46048 .50334 .4692 .51162 .48453 .50769 .47587 .49899 Mtetra
.65 .755 .926 r
.47587 .49899 .48453 .50769 .49995 .50315 .49136 .49431 Mtetra
.639 .749 .928 r
.49136 .49431 .49995 .50315 .51547 .49844 .50693 .48999 Mtetra
.633 .758 .938 r
.50693 .48999 .51547 .49844 .53108 .49381 .52259 .48581 Mtetra
.645 .775 .942 r
.52259 .48581 .53108 .49381 .54677 .48924 .53836 .48113 Mtetra
.654 .776 .938 r
.53836 .48113 .54677 .48924 .56256 .48429 .55421 .47614 Mtetra
.662 .778 .935 r
.55421 .47614 .56256 .48429 .57844 .47898 .57015 .47083 Mtetra
.674 .784 .932 r
.57015 .47083 .57844 .47898 .5944 .47373 .58617 .46502 Mtetra
.671 .77 .925 r
.58617 .46502 .5944 .47373 .61045 .46855 .60228 .45934 Mtetra
.661 .756 .921 r
.60228 .45934 .61045 .46855 .6266 .46319 .61849 .45402 Mtetra
.669 .761 .919 r
.61849 .45402 .6266 .46319 .64281 .45721 .63478 .44837 Mtetra
.704 .781 .912 r
.63478 .44837 .64281 .45721 .65903 .44947 .6511 .44119 Mtetra
.711 .798 .919 r
.6511 .44119 .65903 .44947 .6754 .44329 .66749 .43369 Mtetra
.625 .739 .929 r
.66749 .43369 .6754 .44329 .69205 .4409 .68412 .42965 Mtetra
.455 .622 .923 r
.68412 .42965 .69205 .4409 .70912 .44379 .70117 .4313 Mtetra
.416 .575 .903 r
.70117 .4313 .70912 .44379 .72635 .44625 .71849 .4346 Mtetra
.525 .651 .915 r
.71849 .4346 .72635 .44625 .74345 .44393 .73577 .4343 Mtetra
.709 .775 .904 r
.73577 .4343 .74345 .44393 .76022 .43527 .75269 .42657 Mtetra
.768 .814 .89 r
.75269 .42657 .76022 .43527 .77689 .42454 .76946 .41585 Mtetra
.749 .812 .902 r
.76946 .41585 .77689 .42454 .79378 .41574 .78637 .40619 Mtetra
.687 .773 .917 r
.78637 .40619 .79378 .41574 .81095 .4094 .80358 .39941 Mtetra
.654 .752 .922 r
.80358 .39941 .81095 .4094 .82831 .40414 .82101 .39399 Mtetra
.658 .751 .919 r
.82101 .39399 .82831 .40414 .84575 .39848 .83854 .38837 Mtetra
.66 .754 .92 r
.83854 .38837 .84575 .39848 .8633 .39287 .85616 .38266 Mtetra
.655 .751 .921 r
.85616 .38266 .8633 .39287 .88097 .38742 .8739 .37711 Mtetra
.656 .751 .92 r
.2439 .56406 .25341 .57238 .26768 .56785 .25821 .55951 Mtetra
.651 .75 .922 r
.25821 .55951 .26768 .56785 .28201 .56349 .27258 .55512 Mtetra
.655 .752 .921 r
.27258 .55512 .28201 .56349 .29642 .55906 .28704 .55058 Mtetra
.655 .75 .92 r
.28704 .55058 .29642 .55906 .31092 .55444 .30159 .54601 Mtetra
.608 .739 .938 r
.30159 .54601 .31092 .55444 .32542 .55113 .31612 .54293 Mtetra
.475 .697 .965 r
.31612 .54293 .32542 .55113 .33986 .55061 .33057 .54285 Mtetra
.441 .695 .973 r
.33057 .54285 .33986 .55061 .35436 .55114 .34512 .54319 Mtetra
.612 .756 .947 r
.34512 .54319 .35436 .55114 .36912 .54881 .35997 .53981 Mtetra
.769 .768 .852 r
.35997 .53981 .36912 .54881 .38428 .53927 .37525 .52913 Mtetra
.793 .751 .814 r
.37525 .52913 .38428 .53927 .39962 .52621 .39067 .51561 Mtetra
.754 .738 .837 r
.39067 .51561 .39962 .52621 .41491 .51471 .40598 .50522 Mtetra
.661 .737 .907 r
.40598 .50522 .41491 .51471 .43007 .50876 .42116 .50024 Mtetra
.565 .729 .952 r
.42116 .50024 .43007 .50876 .44522 .5062 .43635 .49817 Mtetra
.613 .76 .949 r
.43635 .49817 .44522 .5062 .46048 .50334 .45168 .49462 Mtetra
.646 .754 .928 r
.45168 .49462 .46048 .50334 .47587 .49899 .46713 .49005 Mtetra
.646 .75 .925 r
.46713 .49005 .47587 .49899 .49136 .49431 .48267 .48548 Mtetra
.624 .747 .935 r
.48267 .48548 .49136 .49431 .50693 .48999 .49829 .48161 Mtetra
.65 .767 .935 r
.49829 .48161 .50693 .48999 .52259 .48581 .51402 .47679 Mtetra
.666 .758 .919 r
.51402 .47679 .52259 .48581 .53836 .48113 .52984 .47137 Mtetra
.656 .74 .911 r
.52984 .47137 .53836 .48113 .55421 .47614 .54575 .46633 Mtetra
.646 .736 .915 r
.54575 .46633 .55421 .47614 .57015 .47083 .56176 .46165 Mtetra
.66 .756 .921 r
.56176 .46165 .57015 .47083 .58617 .46502 .57785 .45638 Mtetra
.683 .778 .922 r
.57785 .45638 .58617 .46502 .60228 .45934 .59402 .45013 Mtetra
.665 .76 .921 r
.59402 .45013 .60228 .45934 .61849 .45402 .61029 .4446 Mtetra
.665 .756 .919 r
.61029 .4446 .61849 .45402 .63478 .44837 .62665 .43906 Mtetra
.689 .768 .912 r
.62665 .43906 .63478 .44837 .6511 .44119 .64307 .43248 Mtetra
.722 .793 .908 r
.64307 .43248 .6511 .44119 .66749 .43369 .65951 .42438 Mtetra
.652 .758 .927 r
.65951 .42438 .66749 .43369 .68412 .42965 .67616 .41924 Mtetra
.485 .659 .938 r
.67616 .41924 .68412 .42965 .70117 .4313 .69319 .41964 Mtetra
.382 .576 .916 r
.69319 .41964 .70117 .4313 .71849 .4346 .71058 .42329 Mtetra
.483 .64 .925 r
.71058 .42329 .71849 .4346 .73577 .4343 .72798 .42406 Mtetra
.686 .756 .905 r
.72798 .42406 .73577 .4343 .75269 .42657 .74505 .41731 Mtetra
.763 .803 .885 r
.74505 .41731 .75269 .42657 .76946 .41585 .76192 .40668 Mtetra
.756 .805 .892 r
.76192 .40668 .76946 .41585 .78637 .40619 .77887 .39646 Mtetra
.693 .774 .913 r
.77887 .39646 .78637 .40619 .80358 .39941 .79614 .38933 Mtetra
.657 .753 .921 r
.79614 .38933 .80358 .39941 .82101 .39399 .81363 .38374 Mtetra
.657 .751 .919 r
.81363 .38374 .82101 .39399 .83854 .38837 .83124 .37812 Mtetra
.66 .754 .919 r
.83124 .37812 .83854 .38837 .85616 .38266 .84893 .37233 Mtetra
.655 .751 .92 r
.84893 .37233 .85616 .38266 .8739 .37711 .86676 .3667 Mtetra
.656 .751 .92 r
.23429 .55566 .2439 .56406 .25821 .55951 .24864 .55108 Mtetra
.651 .75 .922 r
.24864 .55108 .25821 .55951 .27258 .55512 .26306 .54666 Mtetra
.655 .752 .921 r
.26306 .54666 .27258 .55512 .28704 .55058 .27757 .54204 Mtetra
.653 .75 .921 r
.27757 .54204 .28704 .55058 .30159 .54601 .29216 .53748 Mtetra
.603 .737 .939 r
.29216 .53748 .30159 .54601 .31612 .54293 .30673 .5345 Mtetra
.466 .689 .963 r
.30673 .5345 .31612 .54293 .33057 .54285 .3212 .53461 Mtetra
.457 .691 .967 r
.3212 .53461 .33057 .54285 .34512 .54319 .33579 .5348 Mtetra
.634 .754 .934 r
.33579 .5348 .34512 .54319 .35997 .53981 .35073 .53075 Mtetra
.775 .769 .848 r
.35073 .53075 .35997 .53981 .37525 .52913 .36609 .51956 Mtetra
.799 .763 .819 r
.36609 .51956 .37525 .52913 .39067 .51561 .38159 .50585 Mtetra
.751 .754 .855 r
.38159 .50585 .39067 .51561 .40598 .50522 .39695 .49605 Mtetra
.646 .742 .919 r
.39695 .49605 .40598 .50522 .42116 .50024 .41217 .49155 Mtetra
.56 .725 .951 r
.41217 .49155 .42116 .50024 .43635 .49817 .4274 .48958 Mtetra
.627 .752 .937 r
.4274 .48958 .43635 .49817 .45168 .49462 .44279 .48564 Mtetra
.648 .751 .924 r
.44279 .48564 .45168 .49462 .46713 .49005 .45829 .48097 Mtetra
.638 .746 .927 r
.45829 .48097 .46713 .49005 .48267 .48548 .47388 .47664 Mtetra
.626 .749 .936 r
.47388 .47664 .48267 .48548 .49829 .48161 .48956 .47266 Mtetra
.669 .762 .92 r
.48956 .47266 .49829 .48161 .51402 .47679 .50536 .46711 Mtetra
.679 .749 .904 r
.50536 .46711 .51402 .47679 .52984 .47137 .52124 .46108 Mtetra
.656 .73 .904 r
.52124 .46108 .52984 .47137 .54575 .46633 .5372 .45598 Mtetra
.632 .722 .912 r
.5372 .45598 .54575 .46633 .56176 .46165 .55327 .4518 Mtetra
.643 .738 .918 r
.55327 .4518 .56176 .46165 .57785 .45638 .56943 .44716 Mtetra
.682 .766 .915 r
.56943 .44716 .57785 .45638 .59402 .45013 .58567 .44092 Mtetra
.672 .765 .92 r
.58567 .44092 .59402 .45013 .61029 .4446 .602 .43503 Mtetra
.663 .755 .918 r
.602 .43503 .61029 .4446 .62665 .43906 .61843 .42949 Mtetra
.68 .762 .913 r
.61843 .42949 .62665 .43906 .64307 .43248 .63493 .4232 Mtetra
.724 .783 .899 r
.63493 .4232 .64307 .43248 .65951 .42438 .65144 .41488 Mtetra
.666 .761 .921 r
.65144 .41488 .65951 .42438 .67616 .41924 .66813 .40914 Mtetra
.503 .678 .944 r
.66813 .40914 .67616 .41924 .69319 .41964 .68519 .40883 Mtetra
.354 .582 .929 r
.68519 .40883 .69319 .41964 .71058 .42329 .70262 .41256 Mtetra
.456 .642 .937 r
.70262 .41256 .71058 .42329 .72798 .42406 .72011 .41374 Mtetra
.672 .752 .911 r
.72011 .41374 .72798 .42406 .74505 .41731 .73729 .40757 Mtetra
.759 .794 .881 r
.73729 .40757 .74505 .41731 .76192 .40668 .75425 .39699 Mtetra
.758 .796 .884 r
.75425 .39699 .76192 .40668 .77887 .39646 .77127 .38645 Mtetra
.696 .771 .91 r
.77127 .38645 .77887 .39646 .79614 .38933 .78861 .37912 Mtetra
.658 .754 .92 r
.78861 .37912 .79614 .38933 .81363 .38374 .80617 .3734 Mtetra
.656 .751 .92 r
.80617 .3734 .81363 .38374 .83124 .37812 .82386 .36775 Mtetra
.66 .754 .919 r
.82386 .36775 .83124 .37812 .84893 .37233 .84163 .36188 Mtetra
.656 .751 .92 r
.84163 .36188 .84893 .37233 .86676 .3667 .85953 .35617 Mtetra
.22458 .54719 .23429 .55566 .24864 .55108 .23898 .54255 Mtetra
.651 .75 .922 r
.23898 .54255 .24864 .55108 .26306 .54666 .25345 .53809 Mtetra
.655 .751 .92 r
.25345 .53809 .26306 .54666 .27757 .54204 .26801 .53342 Mtetra
.653 .751 .921 r
.26801 .53342 .27757 .54204 .29216 .53748 .28264 .52882 Mtetra
.603 .736 .939 r
.28264 .52882 .29216 .53748 .30673 .5345 .29725 .52579 Mtetra
.47 .686 .96 r
.29725 .52579 .30673 .5345 .3212 .53461 .31176 .52587 Mtetra
.467 .684 .96 r
.31176 .52587 .3212 .53461 .33579 .5348 .32638 .52602 Mtetra
.635 .747 .929 r
.32638 .52602 .33579 .5348 .35073 .53075 .34137 .52192 Mtetra
.777 .775 .851 r
.34137 .52192 .35073 .53075 .36609 .51956 .35681 .51067 Mtetra
.805 .777 .827 r
.35681 .51067 .36609 .51956 .38159 .50585 .37239 .49688 Mtetra
.757 .773 .866 r
.37239 .49688 .38159 .50585 .39695 .49605 .38781 .48702 Mtetra
.646 .748 .923 r
.38781 .48702 .39695 .49605 .41217 .49155 .40308 .48247 Mtetra
.563 .719 .946 r
.40308 .48247 .41217 .49155 .4274 .48958 .41836 .48046 Mtetra
.628 .742 .929 r
.41836 .48046 .4274 .48958 .44279 .48564 .4338 .47646 Mtetra
.648 .749 .923 r
.4338 .47646 .44279 .48564 .45829 .48097 .44936 .47174 Mtetra
.638 .745 .926 r
.44936 .47174 .45829 .48097 .47388 .47664 .46501 .46736 Mtetra
.627 .742 .93 r
.46501 .46736 .47388 .47664 .48956 .47266 .48075 .46333 Mtetra
.669 .755 .915 r
.48075 .46333 .48956 .47266 .50536 .46711 .4966 .45772 Mtetra
.679 .758 .911 r
.4966 .45772 .50536 .46711 .52124 .46108 .51254 .45164 Mtetra
.656 .751 .92 r
.51254 .45164 .52124 .46108 .5372 .45598 .52857 .44648 Mtetra
.63 .742 .928 r
.52857 .44648 .5372 .45598 .55327 .4518 .54469 .44225 Mtetra
.642 .747 .925 r
.54469 .44225 .55327 .4518 .56943 .44716 .56092 .43755 Mtetra
.681 .76 .91 r
.56092 .43755 .56943 .44716 .58567 .44092 .57722 .43125 Mtetra
.672 .757 .914 r
.57722 .43125 .58567 .44092 .602 .43503 .59362 .42531 Mtetra
.663 .754 .917 r
.59362 .42531 .602 .43503 .61843 .42949 .61011 .4197 Mtetra
.68 .759 .911 r
.61011 .4197 .61843 .42949 .63493 .4232 .62668 .41335 Mtetra
.722 .772 .892 r
.62668 .41335 .63493 .4232 .65144 .41488 .64326 .40497 Mtetra
.666 .754 .916 r
.64326 .40497 .65144 .41488 .66813 .40914 .66002 .39917 Mtetra
.5 .683 .948 r
.66002 .39917 .66813 .40914 .68519 .40883 .67714 .39881 Mtetra
.328 .59 .939 r
.67714 .39881 .68519 .40883 .70262 .41256 .69463 .40251 Mtetra
.442 .653 .949 r
.69463 .40251 .70262 .41256 .72011 .41374 .71217 .40364 Mtetra
.672 .759 .916 r
.71217 .40364 .72011 .41374 .73729 .40757 .72942 .3974 Mtetra
.757 .787 .877 r
.72942 .3974 .73729 .40757 .75425 .39699 .74647 .38675 Mtetra
.756 .786 .878 r
.74647 .38675 .75425 .39699 .77127 .38645 .76357 .37614 Mtetra
.696 .767 .907 r
.76357 .37614 .77127 .38645 .78861 .37912 .78099 .36874 Mtetra
.658 .752 .92 r
.78099 .36874 .78861 .37912 .80617 .3734 .79863 .36296 Mtetra
.656 .752 .92 r
.79863 .36296 .80617 .3734 .82386 .36775 .81639 .35724 Mtetra
.66 .753 .919 r
.81639 .35724 .82386 .36775 .84163 .36188 .83424 .3513 Mtetra
.656 .751 .92 r
.83424 .3513 .84163 .36188 .85953 .35617 .85222 .34554 Mtetra
.656 .752 .92 r
.21477 .53864 .22458 .54719 .23898 .54255 .22922 .53394 Mtetra
.651 .75 .922 r
.22922 .53394 .23898 .54255 .25345 .53809 .24373 .52942 Mtetra
.655 .751 .921 r
.24373 .52942 .25345 .53809 .26801 .53342 .25834 .52474 Mtetra
.655 .752 .921 r
.25834 .52474 .26801 .53342 .28264 .52882 .27303 .52002 Mtetra
.608 .737 .936 r
.27303 .52002 .28264 .52882 .29725 .52579 .28769 .51681 Mtetra
.485 .687 .956 r
.28769 .51681 .29725 .52579 .31176 .52587 .30224 .51662 Mtetra
.469 .674 .954 r
.30224 .51662 .31176 .52587 .32638 .52602 .3169 .51684 Mtetra
.617 .734 .93 r
.3169 .51684 .32638 .52602 .34137 .52192 .3319 .51332 Mtetra
.773 .782 .86 r
.3319 .51332 .34137 .52192 .35681 .51067 .34739 .50245 Mtetra
.81 .791 .835 r
.34739 .50245 .35681 .51067 .37239 .49688 .36304 .48871 Mtetra
.772 .793 .87 r
.36304 .48871 .37239 .49688 .38781 .48702 .37857 .47813 Mtetra
.66 .757 .922 r
.37857 .47813 .38781 .48702 .40308 .48247 .39391 .47299 Mtetra
.571 .715 .939 r
.39391 .47299 .40308 .48247 .41836 .48046 .40924 .47078 Mtetra
.619 .729 .925 r
.40924 .47078 .41836 .48046 .4338 .47646 .42473 .46709 Mtetra
.647 .746 .921 r
.42473 .46709 .4338 .47646 .44936 .47174 .44034 .46236 Mtetra
.646 .747 .923 r
.44034 .46236 .44936 .47174 .46501 .46736 .45605 .45763 Mtetra
.626 .733 .924 r
.45605 .45763 .46501 .46736 .48075 .46333 .47184 .45362 Mtetra
.652 .743 .917 r
.47184 .45362 .48075 .46333 .4966 .45772 .48774 .44863 Mtetra
.666 .764 .923 r
.48774 .44863 .4966 .45772 .51254 .45164 .50375 .44305 Mtetra
.655 .773 .936 r
.50375 .44305 .51254 .45164 .52857 .44648 .51984 .43784 Mtetra
.643 .769 .94 r
.51984 .43784 .52857 .44648 .54469 .44225 .53603 .43299 Mtetra
.66 .762 .925 r
.53603 .43299 .54469 .44225 .56092 .43755 .55231 .42755 Mtetra
.682 .754 .905 r
.55231 .42755 .56092 .43755 .57722 .43125 .56868 .42113 Mtetra
.665 .747 .911 r
.56868 .42113 .57722 .43125 .59362 .42531 .58514 .41543 Mtetra
.665 .753 .916 r
.58514 .41543 .59362 .42531 .61011 .4197 .6017 .40971 Mtetra
.688 .76 .906 r
.6017 .40971 .61011 .4197 .62668 .41335 .61833 .40294 Mtetra
.717 .761 .887 r
.61833 .40294 .62668 .41335 .64326 .40497 .63499 .39465 Mtetra
.653 .742 .916 r
.63499 .39465 .64326 .40497 .66002 .39917 .65184 .38933 Mtetra
.47 .674 .953 r
.65184 .38933 .66002 .39917 .67714 .39881 .66904 .3896 Mtetra
.305 .6 .949 r
.66904 .3896 .67714 .39881 .69463 .40251 .68658 .39313 Mtetra
.444 .675 .961 r
.68658 .39313 .69463 .40251 .71217 .40364 .70416 .39376 Mtetra
.687 .772 .916 r
.70416 .39376 .71217 .40364 .72942 .3974 .72145 .38681 Mtetra
.757 .78 .872 r
.72145 .38681 .72942 .3974 .74647 .38675 .73857 .37597 Mtetra
.75 .776 .874 r
.73857 .37597 .74647 .38675 .76357 .37614 .75577 .36552 Mtetra
.692 .761 .905 r
.75577 .36552 .76357 .37614 .78099 .36874 .77328 .35819 Mtetra
.657 .751 .919 r
.77328 .35819 .78099 .36874 .79863 .36296 .791 .35242 Mtetra
.657 .752 .92 r
.791 .35242 .79863 .36296 .81639 .35724 .80884 .3466 Mtetra
.66 .753 .919 r
.80884 .3466 .81639 .35724 .83424 .3513 .82677 .34061 Mtetra
.655 .751 .92 r
.82677 .34061 .83424 .3513 .85222 .34554 .84483 .33478 Mtetra
.657 .752 .92 r
.20486 .53 .21477 .53864 .22922 .53394 .21936 .52524 Mtetra
.651 .75 .922 r
.21936 .52524 .22922 .53394 .24373 .52942 .23392 .52064 Mtetra
.653 .75 .921 r
.23392 .52064 .24373 .52942 .25834 .52474 .24857 .51598 Mtetra
.657 .753 .92 r
.24857 .51598 .25834 .52474 .27303 .52002 .26331 .51111 Mtetra
.617 .739 .933 r
.26331 .51111 .27303 .52002 .28769 .51681 .27804 .50758 Mtetra
.51 .694 .951 r
.27804 .50758 .28769 .51681 .30224 .51662 .29266 .50686 Mtetra
.468 .664 .947 r
.29266 .50686 .30224 .51662 .3169 .51684 .30734 .50721 Mtetra
.585 .715 .933 r
.30734 .50721 .3169 .51684 .3319 .51332 .32232 .50466 Mtetra
.758 .781 .872 r
.32232 .50466 .3319 .51332 .34739 .50245 .33782 .49481 Mtetra
.811 .805 .846 r
.33782 .49481 .34739 .50245 .36304 .48871 .35355 .48139 Mtetra
.794 .814 .868 r
.35355 .48139 .36304 .48871 .37857 .47813 .36921 .46955 Mtetra
.686 .773 .917 r
.36921 .46955 .37857 .47813 .39391 .47299 .38465 .46333 Mtetra
.59 .72 .934 r
.38465 .46333 .39391 .47299 .40924 .47078 .40005 .46054 Mtetra
.602 .712 .922 r
.40005 .46054 .40924 .47078 .42473 .46709 .41556 .45745 Mtetra
.643 .741 .92 r
.41556 .45745 .42473 .46709 .44034 .46236 .43122 .45284 Mtetra
.651 .747 .92 r
.43122 .45284 .44034 .46236 .45605 .45763 .44699 .44789 Mtetra
.64 .74 .921 r
.44699 .44789 .45605 .45763 .47184 .45362 .46285 .44332 Mtetra
.637 .728 .914 r
.46285 .44332 .47184 .45362 .48774 .44863 .4788 .43887 Mtetra
.649 .745 .92 r
.4788 .43887 .48774 .44863 .50375 .44305 .49485 .43392 Mtetra
.655 .763 .929 r
.49485 .43392 .50375 .44305 .51984 .43784 .51101 .42865 Mtetra
.663 .765 .926 r
.51101 .42865 .51984 .43784 .53603 .43299 .52726 .42307 Mtetra
.675 .754 .91 r
.52726 .42307 .53603 .43299 .55231 .42755 .54361 .41696 Mtetra
.67 .739 .902 r
.54361 .41696 .55231 .42755 .56868 .42113 .56004 .41099 Mtetra
.661 .747 .914 r
.56004 .41099 .56868 .42113 .58514 .41543 .57657 .40539 Mtetra
.669 .753 .914 r
.57657 .40539 .58514 .41543 .6017 .40971 .59319 .39944 Mtetra
.702 .76 .897 r
.59319 .39944 .6017 .40971 .61833 .40294 .60987 .39195 Mtetra
.705 .748 .885 r
.60987 .39195 .61833 .40294 .63499 .39465 .62662 .38413 Mtetra
.626 .73 .922 r
.62662 .38413 .63499 .39465 .65184 .38933 .64357 .3798 Mtetra
.409 .653 .958 r
.64357 .3798 .65184 .38933 .66904 .3896 .66089 .38124 Mtetra
.291 .617 .958 r
.66089 .38124 .66904 .3896 .68658 .39313 .67847 .38434 Mtetra
.477 .71 .972 r
.67847 .38434 .68658 .39313 .70416 .39376 .69605 .3838 Mtetra
.71 .78 .907 r
.69605 .3838 .70416 .39376 .72145 .38681 .71336 .37573 Mtetra
.758 .773 .866 r
.71336 .37573 .72145 .38681 .73857 .37597 .73055 .36464 Mtetra
.739 .764 .873 r
.73055 .36464 .73857 .37597 .75577 .36552 .74787 .35462 Mtetra
.686 .756 .905 r
.74787 .35462 .75577 .36552 .77328 .35819 .76548 .34751 Mtetra
.654 .749 .92 r
.76548 .34751 .77328 .35819 .791 .35242 .78329 .34177 Mtetra
.658 .753 .92 r
.78329 .34177 .791 .35242 .80884 .3466 .8012 .33582 Mtetra
.66 .752 .919 r
.8012 .33582 .80884 .3466 .82677 .34061 .81921 .32979 Mtetra
.655 .751 .92 r
.81921 .32979 .82677 .34061 .84483 .33478 .83735 .32392 Mtetra
.658 .752 .92 r
.19484 .52129 .20486 .53 .21936 .52524 .20939 .51645 Mtetra
.652 .75 .922 r
.20939 .51645 .21936 .52524 .23392 .52064 .224 .51177 Mtetra
.65 .749 .922 r
.224 .51177 .23392 .52064 .24857 .51598 .23869 .50714 Mtetra
.66 .754 .919 r
.23869 .50714 .24857 .51598 .26331 .51111 .2535 .50212 Mtetra
.629 .743 .93 r
.2535 .50212 .26331 .51111 .27804 .50758 .2683 .49817 Mtetra
.544 .705 .945 r
.2683 .49817 .27804 .50758 .29266 .50686 .28301 .49664 Mtetra
.47 .656 .941 r
.28301 .49664 .29266 .50686 .30734 .50721 .29771 .49704 Mtetra
.553 .693 .932 r
.29771 .49704 .30734 .50721 .32232 .50466 .31267 .49541 Mtetra
.72 .765 .888 r
.31267 .49541 .32232 .50466 .33782 .49481 .32812 .48755 Mtetra
.804 .815 .86 r
.32812 .48755 .33782 .49481 .35355 .48139 .34389 .47493 Mtetra
.815 .833 .864 r
.34389 .47493 .35355 .48139 .36921 .46955 .35969 .46183 Mtetra
.724 .803 .913 r
.35969 .46183 .36921 .46955 .38465 .46333 .37528 .45396 Mtetra
.628 .742 .929 r
.37528 .45396 .38465 .46333 .40005 .46054 .39077 .44986 Mtetra
.584 .698 .921 r
.39077 .44986 .40005 .46054 .41556 .45745 .40631 .44734 Mtetra
.633 .73 .918 r
.40631 .44734 .41556 .45745 .43122 .45284 .42201 .44306 Mtetra
.648 .743 .919 r
.42201 .44306 .43122 .45284 .44699 .44789 .43783 .43816 Mtetra
.652 .747 .919 r
.43783 .43816 .44699 .44789 .46285 .44332 .45376 .43307 Mtetra
.65 .736 .912 r
.45376 .43307 .46285 .44332 .4788 .43887 .46977 .42806 Mtetra
.648 .724 .905 r
.46977 .42806 .4788 .43887 .49485 .43392 .48588 .42311 Mtetra
.656 .729 .903 r
.48588 .42311 .49485 .43392 .51101 .42865 .50209 .41779 Mtetra
.664 .731 .9 r
.50209 .41779 .51101 .42865 .52726 .42307 .5184 .41208 Mtetra
.662 .729 .9 r
.5184 .41208 .52726 .42307 .54361 .41696 .53481 .40643 Mtetra
.66 .739 .909 r
.53481 .40643 .54361 .41696 .56004 .41099 .55131 .40085 Mtetra
.663 .75 .915 r
.55131 .40085 .56004 .41099 .57657 .40539 .56791 .39509 Mtetra
.678 .753 .908 r
.56791 .39509 .57657 .40539 .59319 .39944 .58459 .38869 Mtetra
.713 .756 .886 r
.58459 .38869 .59319 .39944 .60987 .39195 .60132 .38049 Mtetra
.679 .732 .891 r
.60132 .38049 .60987 .39195 .62662 .38413 .61817 .37389 Mtetra
.577 .719 .939 r
.61817 .37389 .62662 .38413 .64357 .3798 .63525 .37113 Mtetra
.322 .63 .961 r
.63525 .37113 .64357 .3798 .66089 .38124 .65268 .37375 Mtetra
.303 .651 .97 r
.65268 .37375 .66089 .38124 .67847 .38434 .67028 .37591 Mtetra
.553 .758 .973 r
.67028 .37591 .67847 .38434 .69605 .3838 .68783 .37322 Mtetra
.727 .775 .891 r
.68783 .37322 .69605 .3838 .71336 .37573 .70516 .36407 Mtetra
.756 .764 .859 r
.70516 .36407 .71336 .37573 .73055 .36464 .72243 .35281 Mtetra
.724 .752 .875 r
.72243 .35281 .73055 .36464 .74787 .35462 .73988 .34351 Mtetra
.678 .751 .906 r
.73988 .34351 .74787 .35462 .76548 .34751 .75759 .33672 Mtetra
.652 .749 .921 r
.75759 .33672 .76548 .34751 .78329 .34177 .77549 .33102 Mtetra
.661 .755 .92 r
.77549 .33102 .78329 .34177 .8012 .33582 .79347 .32491 Mtetra
.659 .752 .919 r
.79347 .32491 .8012 .33582 .81921 .32979 .81156 .31884 Mtetra
.654 .751 .921 r
.81156 .31884 .81921 .32979 .83735 .32392 .82979 .31293 Mtetra
.659 .753 .92 r
.18472 .51249 .19484 .52129 .20939 .51645 .19932 .50757 Mtetra
.654 .751 .921 r
.19932 .50757 .20939 .51645 .224 .51177 .21399 .50278 Mtetra
.65 .749 .922 r
.21399 .50278 .224 .51177 .23869 .50714 .22872 .49813 Mtetra
.66 .752 .918 r
.22872 .49813 .23869 .50714 .2535 .50212 .24357 .49308 Mtetra
.641 .747 .926 r
.24357 .49308 .2535 .50212 .2683 .49817 .25845 .48867 Mtetra
.584 .72 .937 r
.25845 .48867 .2683 .49817 .28301 .49664 .27329 .48606 Mtetra
.482 .655 .936 r
.27329 .48606 .28301 .49664 .29771 .49704 .28802 .48625 Mtetra
.523 .669 .929 r
.28802 .48625 .29771 .49704 .31267 .49541 .30296 .48549 Mtetra
.66 .738 .908 r
.30296 .48549 .31267 .49541 .32812 .48755 .31829 .48025 Mtetra
.784 .817 .878 r
.31829 .48025 .32812 .48755 .34389 .47493 .33406 .46907 Mtetra
.82 .848 .87 r
.33406 .46907 .34389 .47493 .35969 .46183 .34997 .45584 Mtetra
.78 .85 .904 r
.34997 .45584 .35969 .46183 .37528 .45396 .36576 .44531 Mtetra
.678 .775 .924 r
.36576 .44531 .37528 .45396 .39077 .44986 .3814 .4393 Mtetra
.607 .711 .919 r
.3814 .4393 .39077 .44986 .40631 .44734 .397 .43594 Mtetra
.602 .693 .907 r
.397 .43594 .40631 .44734 .42201 .44306 .41272 .43279 Mtetra
.64 .732 .915 r
.41272 .43279 .42201 .44306 .43783 .43816 .42858 .42817 Mtetra
.65 .743 .917 r
.42858 .42817 .43783 .43816 .45376 .43307 .44456 .42312 Mtetra
.654 .746 .917 r
.44456 .42312 .45376 .43307 .46977 .42806 .46064 .4179 Mtetra
.655 .743 .914 r
.46064 .4179 .46977 .42806 .48588 .42311 .47681 .41259 Mtetra
.656 .737 .909 r
.47681 .41259 .48588 .42311 .50209 .41779 .49308 .4072 Mtetra
.657 .737 .909 r
.49308 .4072 .50209 .41779 .5184 .41208 .50945 .40173 Mtetra
.659 .744 .913 r
.50945 .40173 .5184 .41208 .53481 .40643 .52592 .39618 Mtetra
.662 .749 .914 r
.52592 .39618 .53481 .40643 .55131 .40085 .54248 .39045 Mtetra
.672 .75 .909 r
.54248 .39045 .55131 .40085 .56791 .39509 .55914 .38427 Mtetra
.702 .752 .891 r
.55914 .38427 .56791 .39509 .58459 .38869 .57587 .37661 Mtetra
.693 .727 .876 r
.57587 .37661 .58459 .38869 .60132 .38049 .59268 .36915 Mtetra
.636 .721 .909 r
.59268 .36915 .60132 .38049 .61817 .37389 .60965 .36437 Mtetra
.47 .69 .962 r
.60965 .36437 .61817 .37389 .63525 .37113 .62688 .36422 Mtetra
.244 .633 .96 r
.62688 .36422 .63525 .37113 .65268 .37375 .64438 .36686 Mtetra
.363 .706 .985 r
.64438 .36686 .65268 .37375 .67028 .37591 .66199 .36744 Mtetra
.644 .796 .956 r
.66199 .36744 .67028 .37591 .68783 .37322 .67949 .36191 Mtetra
.741 .767 .874 r
.67949 .36191 .68783 .37322 .70516 .36407 .69684 .35175 Mtetra
.751 .753 .854 r
.69684 .35175 .70516 .36407 .72243 .35281 .7142 .34058 Mtetra
.704 .74 .879 r
.7142 .34058 .72243 .35281 .73988 .34351 .7318 .33228 Mtetra
.668 .747 .909 r
.7318 .33228 .73988 .34351 .75759 .33672 .74961 .32585 Mtetra
.652 .75 .921 r
.74961 .32585 .75759 .33672 .77549 .33102 .76759 .32006 Mtetra
.661 .753 .918 r
.76759 .32006 .77549 .33102 .79347 .32491 .78564 .31385 Mtetra
.657 .751 .919 r
.78564 .31385 .79347 .32491 .81156 .31884 .80383 .30777 Mtetra
.653 .75 .921 r
.80383 .30777 .81156 .31884 .82979 .31293 .82214 .30183 Mtetra
.659 .753 .919 r
.1745 .50361 .18472 .51249 .19932 .50757 .18915 .4986 Mtetra
.655 .751 .921 r
.18915 .4986 .19932 .50757 .21399 .50278 .20386 .49372 Mtetra
.65 .749 .922 r
.20386 .49372 .21399 .50278 .22872 .49813 .21865 .48899 Mtetra
.657 .75 .919 r
.21865 .48899 .22872 .49813 .24357 .49308 .23354 .48401 Mtetra
.652 .752 .922 r
.23354 .48401 .24357 .49308 .25845 .48867 .2485 .47914 Mtetra
.611 .731 .93 r
.2485 .47914 .25845 .48867 .27329 .48606 .26344 .47567 Mtetra
.518 .677 .937 r
.26344 .47567 .27329 .48606 .28802 .48625 .27828 .47488 Mtetra
.504 .651 .924 r
.27828 .47488 .28802 .48625 .30296 .48549 .2932 .47467 Mtetra
.589 .698 .918 r
.2932 .47467 .30296 .48549 .31829 .48025 .30842 .47195 Mtetra
.739 .794 .897 r
.30842 .47195 .31829 .48025 .33406 .46907 .32411 .46319 Mtetra
.806 .852 .884 r
.32411 .46319 .33406 .46907 .34997 .45584 .34006 .45098 Mtetra
.815 .876 .891 r
.34006 .45098 .34997 .45584 .36576 .44531 .35604 .43851 Mtetra
.738 .832 .923 r
.35604 .43851 .36576 .44531 .3814 .4393 .37186 .42997 Mtetra
.661 .759 .922 r
.37186 .42997 .3814 .4393 .397 .43594 .38761 .42453 Mtetra
.612 .699 .906 r
.38761 .42453 .397 .43594 .41272 .43279 .40338 .42096 Mtetra
.61 .691 .901 r
.40338 .42096 .41272 .43279 .42858 .42817 .41925 .41747 Mtetra
.64 .726 .911 r
.41925 .41747 .42858 .42817 .44456 .42312 .43527 .41275 Mtetra
.649 .738 .914 r
.43527 .41275 .44456 .42312 .46064 .4179 .4514 .40764 Mtetra
.654 .743 .915 r
.4514 .40764 .46064 .4179 .47681 .41259 .46764 .40232 Mtetra
.656 .745 .915 r
.46764 .40232 .47681 .41259 .49308 .4072 .48397 .39687 Mtetra
.659 .746 .914 r
.48397 .39687 .49308 .4072 .50945 .40173 .5004 .39129 Mtetra
.663 .746 .912 r
.5004 .39129 .50945 .40173 .52592 .39618 .51693 .38551 Mtetra
.671 .745 .906 r
.51693 .38551 .52592 .39618 .54248 .39045 .53356 .37932 Mtetra
.696 .745 .889 r
.53356 .37932 .54248 .39045 .55914 .38427 .55027 .37189 Mtetra
.69 .721 .873 r
.55027 .37189 .55914 .38427 .57587 .37661 .56707 .36452 Mtetra
.652 .713 .893 r
.56707 .36452 .57587 .37661 .59268 .36915 .58398 .35904 Mtetra
.557 .718 .948 r
.58398 .35904 .59268 .36915 .60965 .36437 .60108 .35673 Mtetra
.322 .663 .973 r
.60108 .35673 .60965 .36437 .62688 .36422 .61844 .35845 Mtetra
.255 .674 .965 r
.61844 .35845 .62688 .36422 .64438 .36686 .63597 .35993 Mtetra
.491 .774 .995 r
.63597 .35993 .64438 .36686 .66199 .36744 .65356 .35791 Mtetra
.711 .796 .917 r
.65356 .35791 .66199 .36744 .67949 .36191 .67101 .34967 Mtetra
.746 .754 .859 r
.67101 .34967 .67949 .36191 .69684 .35175 .68841 .33881 Mtetra
.733 .739 .856 r
.68841 .33881 .69684 .35175 .7142 .34058 .7059 .32852 Mtetra
.689 .74 .89 r
.7059 .32852 .7142 .34058 .7318 .33228 .72363 .321 Mtetra
.659 .745 .914 r
.72363 .321 .7318 .33228 .74961 .32585 .74155 .31491 Mtetra
.655 .752 .921 r
.74155 .31491 .74961 .32585 .76759 .32006 .75959 .30894 Mtetra
.661 .752 .918 r
.75959 .30894 .76759 .32006 .78564 .31385 .77773 .30268 Mtetra
.656 .751 .919 r
.77773 .30268 .78564 .31385 .80383 .30777 .796 .29658 Mtetra
.652 .75 .921 r
.796 .29658 .80383 .30777 .82214 .30183 .8144 .2906 Mtetra
.66 .753 .919 r
.16416 .49464 .1745 .50361 .18915 .4986 .17886 .48956 Mtetra
.657 .752 .92 r
.17886 .48956 .18915 .4986 .20386 .49372 .19363 .48458 Mtetra
.652 .75 .922 r
.19363 .48458 .20386 .49372 .21865 .48899 .20847 .47974 Mtetra
.651 .748 .921 r
.20847 .47974 .21865 .48899 .23354 .48401 .22339 .47489 Mtetra
.66 .755 .92 r
.22339 .47489 .23354 .48401 .2485 .47914 .23843 .4697 Mtetra
.633 .741 .926 r
.23843 .4697 .2485 .47914 .26344 .47567 .25348 .46545 Mtetra
.572 .705 .932 r
.25348 .46545 .26344 .47567 .27828 .47488 .26846 .46313 Mtetra
.505 .645 .919 r
.26846 .46313 .27828 .47488 .2932 .47467 .28341 .46292 Mtetra
.544 .663 .914 r
.28341 .46292 .2932 .47467 .30842 .47195 .29856 .46163 Mtetra
.65 .733 .91 r
.29856 .46163 .30842 .47195 .32411 .46319 .31407 .45663 Mtetra
.771 .839 .904 r
.31407 .45663 .32411 .46319 .34006 .45098 .32998 .44642 Mtetra
.809 .885 .9 r
.32998 .44642 .34006 .45098 .35604 .43851 .34605 .43427 Mtetra
.799 .896 .912 r
.34605 .43427 .35604 .43851 .37186 .42997 .36211 .42274 Mtetra
.719 .823 .929 r
.36211 .42274 .37186 .42997 .38761 .42453 .37803 .41491 Mtetra
.664 .757 .919 r
.37803 .41491 .38761 .42453 .40338 .42096 .39394 .40925 Mtetra
.63 .703 .898 r
.39394 .40925 .40338 .42096 .41925 .41747 .40988 .40491 Mtetra
.625 .686 .888 r
.40988 .40491 .41925 .41747 .43527 .41275 .42593 .40076 Mtetra
.633 .701 .895 r
.42593 .40076 .43527 .41275 .4514 .40764 .4421 .39625 Mtetra
.645 .719 .902 r
.4421 .39625 .4514 .40764 .46764 .40232 .45838 .39123 Mtetra
.656 .73 .904 r
.45838 .39123 .46764 .40232 .48397 .39687 .47477 .38572 Mtetra
.667 .733 .9 r
.47477 .38572 .48397 .39687 .5004 .39129 .49126 .37971 Mtetra
.676 .73 .89 r
.49126 .37971 .5004 .39129 .51693 .38551 .50785 .3732 Mtetra
.681 .719 .878 r
.50785 .3732 .51693 .38551 .53356 .37932 .52454 .36631 Mtetra
.675 .705 .87 r
.52454 .36631 .53356 .37932 .55027 .37189 .54131 .35961 Mtetra
.648 .71 .892 r
.54131 .35961 .55027 .37189 .56707 .36452 .55819 .35423 Mtetra
.584 .727 .941 r
.55819 .35423 .56707 .36452 .58398 .35904 .57521 .35107 Mtetra
.389 .693 .981 r
.57521 .35107 .58398 .35904 .60108 .35673 .59245 .35168 Mtetra
.226 .675 .952 r
.59245 .35168 .60108 .35673 .61844 .35845 .60988 .35296 Mtetra
.37 .751 .989 r
.60988 .35296 .61844 .35845 .63597 .35993 .62743 .35229 Mtetra
.65 .823 .966 r
.62743 .35229 .63597 .35993 .65356 .35791 .64495 .34628 Mtetra
.733 .762 .876 r
.64495 .34628 .65356 .35791 .67101 .34967 .66241 .33644 Mtetra
.742 .738 .848 r
.66241 .33644 .67101 .34967 .68841 .33881 .67988 .32546 Mtetra
.707 .725 .864 r
.67988 .32546 .68841 .33881 .7059 .32852 .69753 .31663 Mtetra
.674 .74 .9 r
.69753 .31663 .7059 .32852 .72363 .321 .71538 .30979 Mtetra
.652 .746 .919 r
.71538 .30979 .72363 .321 .74155 .31491 .73339 .3039 Mtetra
.66 .755 .921 r
.73339 .3039 .74155 .31491 .75959 .30894 .7515 .29766 Mtetra
.659 .751 .918 r
.7515 .29766 .75959 .30894 .77773 .30268 .76973 .2914 Mtetra
.655 .751 .92 r
.76973 .2914 .77773 .30268 .796 .29658 .78809 .28528 Mtetra
.652 .75 .922 r
.78809 .28528 .796 .29658 .8144 .2906 .80657 .27924 Mtetra
.659 .753 .919 r
.15372 .48555 .16416 .49464 .17886 .48956 .16846 .48046 Mtetra
.658 .753 .92 r
.16846 .48046 .17886 .48956 .19363 .48458 .18329 .47536 Mtetra
.654 .751 .921 r
.18329 .47536 .19363 .48458 .20847 .47974 .19819 .47038 Mtetra
.65 .748 .921 r
.19819 .47038 .20847 .47974 .22339 .47489 .21315 .46553 Mtetra
.658 .751 .919 r
.21315 .46553 .22339 .47489 .23843 .4697 .22824 .46034 Mtetra
.65 .75 .923 r
.22824 .46034 .23843 .4697 .25348 .46545 .24338 .45542 Mtetra
.614 .726 .926 r
.24338 .45542 .25348 .46545 .26846 .46313 .25851 .45176 Mtetra
.541 .671 .922 r
.25851 .45176 .26846 .46313 .28341 .46292 .27357 .45045 Mtetra
.523 .642 .908 r
.27357 .45045 .28341 .46292 .29856 .46163 .28869 .44981 Mtetra
.577 .678 .909 r
.28869 .44981 .29856 .46163 .31407 .45663 .30407 .44743 Mtetra
.686 .77 .915 r
.30407 .44743 .31407 .45663 .32998 .44642 .31982 .44094 Mtetra
.773 .868 .919 r
.31982 .44094 .32998 .44642 .34605 .43427 .33587 .43068 Mtetra
.797 .913 .918 r
.33587 .43068 .34605 .43427 .36211 .42274 .35203 .41916 Mtetra
.783 .916 .929 r
.35203 .41916 .36211 .42274 .37803 .41491 .3682 .40833 Mtetra
.726 .844 .937 r
.3682 .40833 .37803 .41491 .39394 .40925 .38429 .40013 Mtetra
.678 .775 .924 r
.38429 .40013 .39394 .40925 .40988 .40491 .40037 .39385 Mtetra
.656 .729 .903 r
.40037 .39385 .40988 .40491 .42593 .40076 .41651 .38837 Mtetra
.646 .701 .886 r
.41651 .38837 .42593 .40076 .4421 .39625 .43274 .38324 Mtetra
.647 .691 .878 r
.43274 .38324 .4421 .39625 .45838 .39123 .44907 .378 Mtetra
.653 .691 .873 r
.44907 .378 .45838 .39123 .47477 .38572 .4655 .37243 Mtetra
.659 .694 .871 r
.4655 .37243 .47477 .38572 .49126 .37971 .48205 .36651 Mtetra
.661 .697 .873 r
.48205 .36651 .49126 .37971 .50785 .3732 .49869 .36048 Mtetra
.654 .704 .883 r
.49869 .36048 .50785 .3732 .52454 .36631 .51543 .35481 Mtetra
.636 .721 .909 r
.51543 .35481 .52454 .36631 .54131 .35961 .53227 .34994 Mtetra
.57 .737 .954 r
.53227 .34994 .54131 .35961 .55819 .35423 .54924 .34702 Mtetra
.407 .725 .989 r
.54924 .34702 .55819 .35423 .57521 .35107 .56638 .34679 Mtetra
.233 .699 .946 r
.56638 .34679 .57521 .35107 .59245 .35168 .5837 .34728 Mtetra
.323 .752 .972 r
.5837 .34728 .59245 .35168 .60988 .35296 .60117 .34653 Mtetra
.586 .832 .991 r
.60117 .34653 .60988 .35296 .62743 .35229 .61869 .34193 Mtetra
.72 .784 .903 r
.61869 .34193 .62743 .35229 .64495 .34628 .63619 .33309 Mtetra
.737 .738 .852 r
.63619 .33309 .64495 .34628 .66241 .33644 .65369 .32245 Mtetra
.722 .721 .848 r
.65369 .32245 .66241 .33644 .67988 .32546 .67129 .31248 Mtetra
.685 .725 .88 r
.67129 .31248 .67988 .32546 .69753 .31663 .68908 .30491 Mtetra
.66 .74 .909 r
.68908 .30491 .69753 .31663 .71538 .30979 .70704 .29863 Mtetra
.653 .751 .921 r
.70704 .29863 .71538 .30979 .73339 .3039 .72513 .29262 Mtetra
.661 .753 .918 r
.72513 .29262 .73339 .3039 .7515 .29766 .74332 .28625 Mtetra
.657 .75 .918 r
.74332 .28625 .7515 .29766 .76973 .2914 .76163 .28 Mtetra
.653 .75 .921 r
.76163 .28 .76973 .2914 .78809 .28528 .78008 .27387 Mtetra
.653 .751 .922 r
.78008 .27387 .78809 .28528 .80657 .27924 .79864 .26773 Mtetra
.656 .751 .92 r
.14317 .47631 .15372 .48555 .16846 .48046 .15795 .47126 Mtetra
.66 .754 .92 r
.15795 .47126 .16846 .48046 .18329 .47536 .17283 .46606 Mtetra
.656 .752 .92 r
.17283 .46606 .18329 .47536 .19819 .47038 .18779 .46096 Mtetra
.652 .749 .921 r
.18779 .46096 .19819 .47038 .21315 .46553 .20281 .456 Mtetra
.652 .748 .92 r
.20281 .456 .21315 .46553 .22824 .46034 .21792 .451 Mtetra
.66 .755 .921 r
.21792 .451 .22824 .46034 .24338 .45542 .23315 .44566 Mtetra
.639 .742 .923 r
.23315 .44566 .24338 .45542 .25851 .45176 .2484 .44107 Mtetra
.601 .711 .921 r
.2484 .44107 .25851 .45176 .27357 .45045 .26364 .43778 Mtetra
.533 .645 .905 r
.26364 .43778 .27357 .45045 .28869 .44981 .27882 .43682 Mtetra
.543 .644 .899 r
.27882 .43682 .28869 .44981 .30407 .44743 .29414 .43559 Mtetra
.595 .688 .907 r
.29414 .43559 .30407 .44743 .31982 .44094 .30971 .43252 Mtetra
.69 .792 .928 r
.30971 .43252 .31982 .44094 .33587 .43068 .32562 .4258 Mtetra
.757 .886 .936 r
.32562 .4258 .33587 .43068 .35203 .41916 .34177 .41619 Mtetra
.77 .93 .937 r
.34177 .41619 .35203 .41916 .3682 .40833 .35803 .40569 Mtetra
.758 .939 .943 r
.35803 .40569 .3682 .40833 .38429 .40013 .37431 .39552 Mtetra
.738 .896 .95 r
.37431 .39552 .38429 .40013 .40037 .39385 .39059 .38654 Mtetra
.697 .826 .945 r
.39059 .38654 .40037 .39385 .41651 .38837 .40686 .37937 Mtetra
.673 .782 .932 r
.40686 .37937 .41651 .38837 .43274 .38324 .42319 .37314 Mtetra
.662 .756 .92 r
.42319 .37314 .43274 .38324 .44907 .378 .4396 .3673 Mtetra
.656 .742 .913 r
.4396 .3673 .44907 .378 .4655 .37243 .4561 .36166 Mtetra
.65 .74 .915 r
.4561 .36166 .4655 .37243 .48205 .36651 .4727 .35623 Mtetra
.639 .748 .928 r
.4727 .35623 .48205 .36651 .49869 .36048 .48939 .35118 Mtetra
.606 .76 .953 r
.48939 .35118 .49869 .36048 .51543 .35481 .50619 .34709 Mtetra
.517 .765 .987 r
.50619 .34709 .51543 .35481 .53227 .34994 .52312 .34483 Mtetra
.374 .763 .988 r
.52312 .34483 .53227 .34994 .54924 .34702 .54019 .34379 Mtetra
.255 .734 .934 r
.54019 .34379 .54924 .34702 .56638 .34679 .55742 .34312 Mtetra
.337 .776 .965 r
.55742 .34312 .56638 .34679 .5837 .34728 .5748 .34157 Mtetra
.568 .843 .996 r
.5748 .34157 .5837 .34728 .60117 .34653 .59228 .33707 Mtetra
.709 .801 .922 r
.59228 .33707 .60117 .34653 .61869 .34193 .60978 .32883 Mtetra
.729 .738 .858 r
.60978 .32883 .61869 .34193 .63619 .33309 .62731 .31869 Mtetra
.727 .717 .841 r
.62731 .31869 .63619 .33309 .65369 .32245 .64489 .30824 Mtetra
.69 .707 .861 r
.64489 .30824 .65369 .32245 .67129 .31248 .66264 .30017 Mtetra
.669 .734 .898 r
.66264 .30017 .67129 .31248 .68908 .30491 .68055 .29343 Mtetra
.652 .745 .918 r
.68055 .29343 .68908 .30491 .70704 .29863 .69861 .28746 Mtetra
.659 .756 .921 r
.69861 .28746 .70704 .29863 .72513 .29262 .71677 .28112 Mtetra
.659 .751 .917 r
.71677 .28112 .72513 .29262 .74332 .28625 .73504 .27475 Mtetra
.656 .75 .92 r
.73504 .27475 .74332 .28625 .76163 .28 .75344 .26849 Mtetra
.652 .75 .922 r
.75344 .26849 .76163 .28 .78008 .27387 .77198 .26234 Mtetra
.655 .753 .921 r
.77198 .26234 .78008 .27387 .79864 .26773 .79062 .25602 Mtetra
.653 .75 .92 r
.13252 .46695 .14317 .47631 .15795 .47126 .14733 .46196 Mtetra
.659 .753 .92 r
.14733 .46196 .15795 .47126 .17283 .46606 .16226 .45671 Mtetra
.658 .753 .92 r
.16226 .45671 .17283 .46606 .18779 .46096 .17727 .45148 Mtetra
.655 .751 .921 r
.17727 .45148 .18779 .46096 .20281 .456 .19235 .44636 Mtetra
.65 .747 .921 r
.19235 .44636 .20281 .456 .21792 .451 .20751 .44136 Mtetra
.657 .75 .919 r
.20751 .44136 .21792 .451 .23315 .44566 .22278 .43609 Mtetra
.656 .753 .921 r
.22278 .43609 .23315 .44566 .2484 .44107 .23814 .43082 Mtetra
.632 .732 .921 r
.23814 .43082 .2484 .44107 .26364 .43778 .25351 .42642 Mtetra
.592 .697 .916 r
.25351 .42642 .26364 .43778 .27882 .43682 .26888 .42341 Mtetra
.545 .639 .894 r
.26888 .42341 .27882 .43682 .29414 .43559 .28422 .4221 Mtetra
.558 .645 .892 r
.28422 .4221 .29414 .43559 .30971 .43252 .29973 .42037 Mtetra
.599 .687 .904 r
.29973 .42037 .30971 .43252 .32562 .4258 .31546 .41709 Mtetra
.665 .783 .937 r
.31546 .41709 .32562 .4258 .34177 .41619 .33147 .41123 Mtetra
.726 .885 .954 r
.33147 .41123 .34177 .41619 .35803 .40569 .34771 .40274 Mtetra
.728 .931 .957 r
.34771 .40274 .35803 .40569 .37431 .39552 .36404 .39362 Mtetra
.709 .95 .954 r
.36404 .39362 .37431 .39552 .39059 .38654 .38044 .38452 Mtetra
.684 .944 .961 r
.38044 .38452 .39059 .38654 .40686 .37937 .39687 .37608 Mtetra
.67 .919 .975 r
.39687 .37608 .40686 .37937 .42319 .37314 .41334 .36857 Mtetra
.653 .888 .982 r
.41334 .36857 .42319 .37314 .4396 .3673 .42986 .36199 Mtetra
.627 .864 .987 r
.42986 .36199 .4396 .3673 .4561 .36166 .44645 .35629 Mtetra
.589 .852 .994 r
.44645 .35629 .4561 .36166 .4727 .35623 .46313 .35148 Mtetra
.527 .845 .999 r
.46313 .35148 .4727 .35623 .48939 .35118 .4799 .34761 Mtetra
.428 .826 .982 r
.4799 .34761 .48939 .35118 .50619 .34709 .49679 .34469 Mtetra
.321 .787 .935 r
.49679 .34469 .50619 .34709 .52312 .34483 .51382 .34245 Mtetra
.313 .784 .931 r
.51382 .34245 .52312 .34483 .54019 .34379 .53098 .34025 Mtetra
.412 .82 .977 r
.53098 .34025 .54019 .34379 .55742 .34312 .5483 .33741 Mtetra
.607 .859 .991 r
.5483 .33741 .55742 .34312 .5748 .34157 .56572 .33192 Mtetra
.706 .797 .921 r
.56572 .33192 .5748 .34157 .59228 .33707 .5832 .32377 Mtetra
.722 .733 .859 r
.5832 .32377 .59228 .33707 .60978 .32883 .60074 .31404 Mtetra
.721 .71 .839 r
.60074 .31404 .60978 .32883 .62731 .31869 .61833 .30383 Mtetra
.693 .7 .851 r
.61833 .30383 .62731 .31869 .64489 .30824 .63606 .29536 Mtetra
.674 .726 .889 r
.63606 .29536 .64489 .30824 .66264 .30017 .65392 .2883 Mtetra
.655 .74 .912 r
.65392 .2883 .66264 .30017 .68055 .29343 .67194 .28214 Mtetra
.655 .753 .922 r
.67194 .28214 .68055 .29343 .69861 .28746 .69007 .27595 Mtetra
.661 .752 .918 r
.69007 .27595 .69861 .28746 .71677 .28112 .70831 .26949 Mtetra
.657 .749 .918 r
.70831 .26949 .71677 .28112 .73504 .27475 .72667 .26314 Mtetra
.654 .75 .921 r
.72667 .26314 .73504 .27475 .75344 .26849 .74516 .2569 Mtetra
.653 .752 .922 r
.74516 .2569 .75344 .26849 .77198 .26234 .76377 .25066 Mtetra
.658 .754 .921 r
.76377 .25066 .77198 .26234 .79062 .25602 .78249 .24414 Mtetra
.653 .749 .921 r
.12174 .45748 .13252 .46695 .14733 .46196 .13661 .45246 Mtetra
.656 .751 .92 r
.13661 .45246 .14733 .46196 .16226 .45671 .15157 .44728 Mtetra
.66 .754 .92 r
.15157 .44728 .16226 .45671 .17727 .45148 .16664 .44194 Mtetra
.657 .752 .92 r
.16664 .44194 .17727 .45148 .19235 .44636 .18178 .43669 Mtetra
.653 .75 .921 r
.18178 .43669 .19235 .44636 .20751 .44136 .197 .43153 Mtetra
.651 .747 .92 r
.197 .43153 .20751 .44136 .22278 .43609 .2123 .42643 Mtetra
.659 .754 .92 r
.2123 .42643 .22278 .43609 .23814 .43082 .22772 .42099 Mtetra
.653 .75 .921 r
.22772 .42099 .23814 .43082 .25351 .42642 .24321 .41573 Mtetra
.63 .726 .917 r
.24321 .41573 .25351 .42642 .26888 .42341 .25873 .41131 Mtetra
.597 .688 .905 r
.25873 .41131 .26888 .42341 .28422 .4221 .27425 .40808 Mtetra
.56 .638 .885 r
.27425 .40808 .28422 .4221 .29973 .42037 .28979 .40627 Mtetra
.569 .642 .883 r
.28979 .40627 .29973 .42037 .31546 .41709 .30547 .40414 Mtetra
.596 .675 .895 r
.30547 .40414 .31546 .41709 .33147 .41123 .32135 .40093 Mtetra
.631 .742 .927 r
.32135 .40093 .33147 .41123 .34771 .40274 .33743 .39627 Mtetra
.677 .844 .963 r
.33743 .39627 .34771 .40274 .36404 .39362 .35372 .38961 Mtetra
.686 .905 .973 r
.35372 .38961 .36404 .39362 .38044 .38452 .37015 .38199 Mtetra
.657 .93 .972 r
.37015 .38199 .38044 .38452 .39687 .37608 .38665 .37438 Mtetra
.612 .932 .963 r
.38665 .37438 .39687 .37608 .41334 .36857 .40322 .36721 Mtetra
.562 .919 .955 r
.40322 .36721 .41334 .36857 .42986 .36199 .41985 .3607 Mtetra
.51 .899 .948 r
.41985 .3607 .42986 .36199 .44645 .35629 .43655 .35495 Mtetra
.461 .876 .941 r
.43655 .35495 .44645 .35629 .46313 .35148 .45334 .34997 Mtetra
.421 .854 .937 r
.45334 .34997 .46313 .35148 .4799 .34761 .47023 .34565 Mtetra
.41 .844 .946 r
.47023 .34565 .4799 .34761 .49679 .34469 .48724 .34177 Mtetra
.449 .85 .973 r
.48724 .34177 .49679 .34469 .51382 .34245 .50437 .33793 Mtetra
.555 .866 .996 r
.50437 .33793 .51382 .34245 .53098 .34025 .52164 .33311 Mtetra
.669 .844 .967 r
.52164 .33311 .53098 .34025 .5483 .33741 .53901 .32626 Mtetra
.706 .766 .899 r
.53901 .32626 .5483 .33741 .56572 .33192 .55648 .31793 Mtetra
.714 .72 .854 r
.55648 .31793 .56572 .33192 .5832 .32377 .57401 .30848 Mtetra
.712 .7 .837 r
.57401 .30848 .5832 .32377 .60074 .31404 .59161 .29868 Mtetra
.689 .691 .847 r
.59161 .29868 .60074 .31404 .61833 .30383 .60932 .29031 Mtetra
.674 .716 .88 r
.60932 .29031 .61833 .30383 .63606 .29536 .62715 .28315 Mtetra
.658 .735 .907 r
.62715 .28315 .63606 .29536 .65392 .2883 .64513 .27683 Mtetra
.653 .749 .921 r
.64513 .27683 .65392 .2883 .67194 .28214 .66323 .27071 Mtetra
.66 .755 .92 r
.66323 .27071 .67194 .28214 .69007 .27595 .68143 .26423 Mtetra
.658 .749 .917 r
.68143 .26423 .69007 .27595 .70831 .26949 .69975 .25779 Mtetra
.655 .75 .92 r
.69975 .25779 .70831 .26949 .72667 .26314 .7182 .25145 Mtetra
.652 .751 .922 r
.7182 .25145 .72667 .26314 .74516 .2569 .73678 .24518 Mtetra
.656 .753 .922 r
.73678 .24518 .74516 .2569 .76377 .25066 .75547 .23873 Mtetra
.659 .752 .919 r
.75547 .23873 .76377 .25066 .78249 .24414 .77427 .23212 Mtetra
.654 .75 .921 r
.11085 .44795 .12174 .45748 .13661 .45246 .12577 .44282 Mtetra
.653 .749 .92 r
.12577 .44282 .13661 .45246 .15157 .44728 .14077 .4377 Mtetra
.658 .753 .92 r
.14077 .4377 .15157 .44728 .16664 .44194 .15588 .43236 Mtetra
.659 .754 .92 r
.15588 .43236 .16664 .44194 .18178 .43669 .17108 .42696 Mtetra
.656 .751 .92 r
.17108 .42696 .18178 .43669 .197 .43153 .18636 .42164 Mtetra
.652 .748 .92 r
.18636 .42164 .197 .43153 .2123 .42643 .20172 .41643 Mtetra
.651 .747 .92 r
.20172 .41643 .2123 .42643 .22772 .42099 .21717 .41122 Mtetra
.66 .756 .921 r
.21717 .41122 .22772 .42099 .24321 .41573 .23274 .40565 Mtetra
.653 .748 .92 r
.23274 .40565 .24321 .41573 .25873 .41131 .24838 .40032 Mtetra
.634 .725 .913 r
.24838 .40032 .25873 .41131 .27425 .40808 .26406 .39568 Mtetra
.613 .691 .899 r
.26406 .39568 .27425 .40808 .28979 .40627 .27978 .3918 Mtetra
.577 .641 .878 r
.27978 .3918 .28979 .40627 .30547 .40414 .29551 .38933 Mtetra
.579 .637 .873 r
.29551 .38933 .30547 .40414 .32135 .40093 .31137 .38675 Mtetra
.594 .656 .88 r
.31137 .38675 .32135 .40093 .33743 .39627 .32739 .38354 Mtetra
.615 .691 .897 r
.32739 .38354 .33743 .39627 .35372 .38961 .34359 .37946 Mtetra
.635 .751 .932 r
.34359 .37946 .35372 .38961 .37015 .38199 .35994 .37453 Mtetra
.642 .817 .967 r
.35994 .37453 .37015 .38199 .38665 .37438 .37643 .36897 Mtetra
.641 .867 .984 r
.37643 .36897 .38665 .37438 .40322 .36721 .39304 .36287 Mtetra
.622 .888 .988 r
.39304 .36287 .40322 .36721 .41985 .3607 .40976 .35676 Mtetra
.598 .89 .99 r
.40976 .35676 .41985 .3607 .43655 .35495 .42656 .35095 Mtetra
.582 .884 .992 r
.42656 .35095 .43655 .35495 .45334 .34997 .44346 .34545 Mtetra
.591 .878 .993 r
.44346 .34545 .45334 .34997 .47023 .34565 .46047 .33994 Mtetra
.632 .865 .986 r
.46047 .33994 .47023 .34565 .48724 .34177 .4776 .33388 Mtetra
.669 .825 .958 r
.4776 .33388 .48724 .34177 .50437 .33793 .49484 .32718 Mtetra
.691 .769 .911 r
.49484 .32718 .50437 .33793 .52164 .33311 .51218 .31962 Mtetra
.699 .722 .867 r
.51218 .31962 .52164 .33311 .53901 .32626 .52962 .31116 Mtetra
.703 .699 .844 r
.52962 .31116 .53901 .32626 .55648 .31793 .54713 .30203 Mtetra
.701 .688 .835 r
.54713 .30203 .55648 .31793 .57401 .30848 .56473 .29278 Mtetra
.678 .683 .847 r
.56473 .29278 .57401 .30848 .59161 .29868 .58242 .28495 Mtetra
.671 .712 .879 r
.58242 .28495 .59161 .29868 .60932 .29031 .60023 .2779 Mtetra
.658 .732 .905 r
.60023 .2779 .60932 .29031 .62715 .28315 .61817 .27154 Mtetra
.652 .747 .92 r
.61817 .27154 .62715 .28315 .64513 .27683 .63623 .26542 Mtetra
.66 .756 .921 r
.63623 .26542 .64513 .27683 .66323 .27071 .6544 .25892 Mtetra
.659 .75 .917 r
.6544 .25892 .66323 .27071 .68143 .26423 .67268 .25241 Mtetra
.656 .749 .919 r
.67268 .25241 .68143 .26423 .69975 .25779 .69109 .246 Mtetra
.653 .75 .921 r
.69109 .246 .69975 .25779 .7182 .25145 .70963 .23967 Mtetra
.654 .752 .922 r
.70963 .23967 .7182 .25145 .73678 .24518 .72829 .23327 Mtetra
.658 .753 .92 r
.72829 .23327 .73678 .24518 .75547 .23873 .74706 .22664 Mtetra
.657 .751 .919 r
.74706 .22664 .75547 .23873 .77427 .23212 .76595 .21999 Mtetra
.655 .751 .92 r
.09984 .43834 .11085 .44795 .12577 .44282 .11481 .4331 Mtetra
.653 .75 .92 r
.11481 .4331 .12577 .44282 .14077 .4377 .12986 .42791 Mtetra
.654 .75 .92 r
.12986 .42791 .14077 .4377 .15588 .43236 .14501 .42266 Mtetra
.659 .754 .92 r
.14501 .42266 .15588 .43236 .17108 .42696 .16026 .41719 Mtetra
.658 .754 .921 r
.16026 .41719 .17108 .42696 .18636 .42164 .1756 .41173 Mtetra
.655 .751 .92 r
.1756 .41173 .18636 .42164 .20172 .41643 .19103 .40634 Mtetra
.652 .748 .92 r
.19103 .40634 .20172 .41643 .21717 .41122 .20653 .40105 Mtetra
.652 .747 .919 r
.20653 .40105 .21717 .41122 .23274 .40565 .22212 .39573 Mtetra
.66 .756 .921 r
.22212 .39573 .23274 .40565 .24838 .40032 .23784 .39008 Mtetra
.655 .749 .919 r
.23784 .39008 .24838 .40032 .26406 .39568 .25364 .38457 Mtetra
.641 .728 .912 r
.25364 .38457 .26406 .39568 .27978 .3918 .26949 .37956 Mtetra
.626 .703 .9 r
.26949 .37956 .27978 .3918 .29551 .38933 .28541 .37508 Mtetra
.606 .66 .877 r
.28541 .37508 .29551 .38933 .31137 .38675 .30137 .37137 Mtetra
.594 .638 .864 r
.30137 .37137 .31137 .38675 .32739 .38354 .31742 .36813 Mtetra
.6 .642 .863 r
.31742 .36813 .32739 .38354 .34359 .37946 .33361 .36459 Mtetra
.612 .656 .869 r
.33361 .36459 .34359 .37946 .35994 .37453 .34995 .36054 Mtetra
.625 .677 .879 r
.34995 .36054 .35994 .37453 .37643 .36897 .36643 .35592 Mtetra
.637 .699 .891 r
.36643 .35592 .37643 .36897 .39304 .36287 .38305 .3508 Mtetra
.647 .722 .904 r
.38305 .3508 .39304 .36287 .40976 .35676 .3998 .34528 Mtetra
.655 .738 .911 r
.3998 .34528 .40976 .35676 .42656 .35095 .41666 .3394 Mtetra
.662 .74 .908 r
.41666 .3394 .42656 .35095 .44346 .34545 .43365 .33318 Mtetra
.669 .73 .895 r
.43365 .33318 .44346 .34545 .46047 .33994 .45074 .32653 Mtetra
.676 .714 .877 r
.45074 .32653 .46047 .33994 .4776 .33388 .46794 .31938 Mtetra
.683 .699 .859 r
.46794 .31938 .4776 .33388 .49484 .32718 .48525 .31166 Mtetra
.687 .687 .844 r
.48525 .31166 .49484 .32718 .51218 .31962 .50265 .3034 Mtetra
.689 .679 .835 r
.50265 .3034 .51218 .31962 .52962 .31116 .52014 .29482 Mtetra
.681 .675 .838 r
.52014 .29482 .52962 .31116 .54713 .30203 .53771 .2867 Mtetra
.671 .687 .856 r
.53771 .2867 .54713 .30203 .56473 .29278 .55538 .27936 Mtetra
.666 .717 .887 r
.55538 .27936 .56473 .29278 .58242 .28495 .57316 .27255 Mtetra
.656 .733 .906 r
.57316 .27255 .58242 .28495 .60023 .2779 .59107 .26624 Mtetra
.652 .748 .92 r
.59107 .26624 .60023 .2779 .61817 .27154 .60909 .26007 Mtetra
.66 .756 .921 r
.60909 .26007 .61817 .27154 .63623 .26542 .62722 .25355 Mtetra
.659 .749 .917 r
.62722 .25355 .63623 .26542 .6544 .25892 .64547 .247 Mtetra
.656 .749 .918 r
.64547 .247 .6544 .25892 .67268 .25241 .66384 .24054 Mtetra
.654 .75 .921 r
.66384 .24054 .67268 .25241 .69109 .246 .68233 .23414 Mtetra
.653 .752 .922 r
.68233 .23414 .69109 .246 .70963 .23967 .70095 .22774 Mtetra
.657 .754 .921 r
.70095 .22774 .70963 .23967 .72829 .23327 .71969 .22111 Mtetra
.658 .751 .919 r
.71969 .22111 .72829 .23327 .74706 .22664 .73854 .2144 Mtetra
.656 .75 .919 r
.73854 .2144 .74706 .22664 .76595 .21999 .75753 .20773 Mtetra
.657 .752 .92 r
.0887 .42866 .09984 .43834 .11481 .4331 .10373 .42331 Mtetra
.655 .751 .92 r
.10373 .42331 .11481 .4331 .12986 .42791 .11884 .418 Mtetra
.653 .749 .92 r
.11884 .418 .12986 .42791 .14501 .42266 .13403 .41274 Mtetra
.655 .751 .92 r
.13403 .41274 .14501 .42266 .16026 .41719 .14932 .40735 Mtetra
.659 .754 .921 r
.14932 .40735 .16026 .41719 .1756 .41173 .16472 .40179 Mtetra
.658 .753 .921 r
.16472 .40179 .1756 .41173 .19103 .40634 .1802 .39625 Mtetra
.655 .751 .92 r
.1802 .39625 .19103 .40634 .20653 .40105 .19577 .39077 Mtetra
.652 .747 .919 r
.19577 .39077 .20653 .40105 .22212 .39573 .21142 .38537 Mtetra
.21142 .38537 .22212 .39573 .23784 .39008 .22717 .37995 Mtetra
.658 .755 .921 r
.22717 .37995 .23784 .39008 .25364 .38457 .24303 .37427 Mtetra
.658 .752 .92 r
.24303 .37427 .25364 .38457 .26949 .37956 .25899 .36856 Mtetra
.65 .737 .913 r
.25899 .36856 .26949 .37956 .28541 .37508 .27503 .36312 Mtetra
.64 .716 .903 r
.27503 .36312 .28541 .37508 .30137 .37137 .29113 .35803 Mtetra
.631 .689 .886 r
.29113 .35803 .30137 .37137 .31742 .36813 .30732 .3532 Mtetra
.623 .66 .866 r
.30732 .3532 .31742 .36813 .33361 .36459 .32361 .34863 Mtetra
.615 .643 .855 r
.32361 .34863 .33361 .36459 .34995 .36054 .33999 .34434 Mtetra
.62 .643 .851 r
.33999 .34434 .34995 .36054 .36643 .35592 .3565 .33974 Mtetra
.628 .648 .85 r
.3565 .33974 .36643 .35592 .38305 .3508 .37314 .33472 Mtetra
.637 .654 .85 r
.37314 .33472 .38305 .3508 .3998 .34528 .38992 .32924 Mtetra
.646 .659 .849 r
.38992 .32924 .3998 .34528 .41666 .3394 .40683 .32329 Mtetra
.654 .663 .846 r
.40683 .32329 .41666 .3394 .43365 .33318 .42385 .31686 Mtetra
.661 .664 .842 r
.42385 .31686 .43365 .33318 .45074 .32653 .44099 .30997 Mtetra
.667 .664 .838 r
.44099 .30997 .45074 .32653 .46794 .31938 .45824 .30265 Mtetra
.672 .665 .835 r
.45824 .30265 .46794 .31938 .48525 .31166 .47559 .29502 Mtetra
.667 .665 .839 r
.47559 .29502 .48525 .31166 .50265 .3034 .49303 .28765 Mtetra
.665 .678 .852 r
.49303 .28765 .50265 .3034 .52014 .29482 .51056 .28054 Mtetra
.664 .702 .874 r
.51056 .28054 .52014 .29482 .53771 .2867 .5282 .27369 Mtetra
.66 .723 .896 r
.5282 .27369 .53771 .2867 .55538 .27936 .54595 .26718 Mtetra
.654 .738 .911 r
.54595 .26718 .55538 .27936 .57316 .27255 .56381 .26094 Mtetra
.654 .751 .921 r
.56381 .26094 .57316 .27255 .59107 .26624 .58179 .25467 Mtetra
.66 .755 .921 r
.58179 .25467 .59107 .26624 .60909 .26007 .59989 .24812 Mtetra
.659 .749 .917 r
.59989 .24812 .60909 .26007 .62722 .25355 .6181 .24155 Mtetra
.656 .749 .918 r
.6181 .24155 .62722 .25355 .64547 .247 .63643 .23506 Mtetra
.654 .75 .92 r
.63643 .23506 .64547 .247 .66384 .24054 .65489 .22861 Mtetra
.653 .752 .922 r
.65489 .22861 .66384 .24054 .68233 .23414 .67347 .22217 Mtetra
.656 .754 .922 r
.67347 .22217 .68233 .23414 .70095 .22774 .69217 .21555 Mtetra
.658 .752 .919 r
.69217 .21555 .70095 .22774 .71969 .22111 .71098 .20879 Mtetra
.656 .75 .919 r
.71098 .20879 .71969 .22111 .73854 .2144 .72993 .20206 Mtetra
.655 .751 .92 r
.72993 .20206 .73854 .2144 .75753 .20773 .74901 .19537 Mtetra
.658 .753 .92 r
.07744 .4189 .0887 .42866 .10373 .42331 .09252 .41345 Mtetra
.656 .752 .92 r
.09252 .41345 .10373 .42331 .11884 .418 .10769 .40803 Mtetra
.655 .751 .92 r
.10769 .40803 .11884 .418 .13403 .41274 .12293 .40265 Mtetra
.653 .749 .92 r
.12293 .40265 .13403 .41274 .14932 .40735 .13826 .39728 Mtetra
.656 .751 .92 r
.13826 .39728 .14932 .40735 .16472 .40179 .1537 .39179 Mtetra
.659 .755 .921 r
.1537 .39179 .16472 .40179 .1802 .39625 .16925 .38614 Mtetra
.658 .753 .921 r
.16925 .38614 .1802 .39625 .19577 .39077 .18488 .38051 Mtetra
.655 .751 .92 r
.18488 .38051 .19577 .39077 .21142 .38537 .2006 .37492 Mtetra
.653 .748 .919 r
.2006 .37492 .21142 .38537 .22717 .37995 .2164 .36939 Mtetra
.652 .746 .919 r
.2164 .36939 .22717 .37995 .24303 .37427 .2323 .36386 Mtetra
.654 .752 .921 r
.2323 .36386 .24303 .37427 .25899 .36856 .24831 .35823 Mtetra
.659 .756 .921 r
.24831 .35823 .25899 .36856 .27503 .36312 .26443 .35235 Mtetra
.656 .747 .917 r
.26443 .35235 .27503 .36312 .29113 .35803 .28064 .34657 Mtetra
.651 .733 .909 r
.28064 .34657 .29113 .35803 .30732 .3532 .29694 .34093 Mtetra
.646 .717 .9 r
.29694 .34093 .30732 .3532 .32361 .34863 .31333 .33544 Mtetra
.643 .701 .888 r
.31333 .33544 .32361 .34863 .33999 .34434 .32982 .33 Mtetra
.641 .682 .873 r
.32982 .33 .33999 .34434 .3565 .33974 .34642 .32453 Mtetra
.641 .669 .861 r
.34642 .32453 .3565 .33974 .37314 .33472 .36313 .31893 Mtetra
.643 .662 .854 r
.36313 .31893 .37314 .33472 .38992 .32924 .37996 .31314 Mtetra
.646 .66 .85 r
.37996 .31314 .38992 .32924 .40683 .32329 .3969 .30711 Mtetra
.65 .662 .848 r
.3969 .30711 .40683 .32329 .42385 .31686 .41396 .30085 Mtetra
.653 .667 .85 r
.41396 .30085 .42385 .31686 .44099 .30997 .43113 .29439 Mtetra
.657 .676 .856 r
.43113 .29439 .44099 .30997 .45824 .30265 .44841 .2878 Mtetra
.659 .689 .867 r
.44841 .2878 .45824 .30265 .47559 .29502 .46579 .28117 Mtetra
.66 .707 .882 r
.46579 .28117 .47559 .29502 .49303 .28765 .48328 .27459 Mtetra
.658 .721 .896 r
.48328 .27459 .49303 .28765 .51056 .28054 .50088 .26815 Mtetra
.655 .734 .908 r
.50088 .26815 .51056 .28054 .5282 .27369 .51859 .26187 Mtetra
.652 .746 .918 r
.51859 .26187 .5282 .27369 .54595 .26718 .53641 .25566 Mtetra
.657 .755 .922 r
.53641 .25566 .54595 .26718 .56381 .26094 .55435 .24921 Mtetra
.659 .753 .92 r
.55435 .24921 .56381 .26094 .58179 .25467 .57241 .24264 Mtetra
.658 .748 .917 r
.57241 .24264 .58179 .25467 .59989 .24812 .59058 .23607 Mtetra
.656 .749 .918 r
.59058 .23607 .59989 .24812 .6181 .24155 .60887 .22954 Mtetra
.654 .75 .92 r
.60887 .22954 .6181 .24155 .63643 .23506 .62729 .22306 Mtetra
.653 .752 .922 r
.62729 .22306 .63643 .23506 .65489 .22861 .64583 .21658 Mtetra
.656 .754 .922 r
.64583 .21658 .65489 .22861 .67347 .22217 .66449 .20993 Mtetra
.658 .752 .919 r
.66449 .20993 .67347 .22217 .69217 .21555 .68327 .20314 Mtetra
.657 .75 .919 r
.68327 .20314 .69217 .21555 .71098 .20879 .70217 .19636 Mtetra
.655 .751 .92 r
.70217 .19636 .71098 .20879 .72993 .20206 .72121 .1896 Mtetra
.654 .751 .921 r
.72121 .1896 .72993 .20206 .74901 .19537 .74038 .18287 Mtetra
.657 .752 .92 r
.06606 .40899 .07744 .4189 .09252 .41345 .08118 .40352 Mtetra
.658 .753 .92 r
.08118 .40352 .09252 .41345 .10769 .40803 .0964 .39799 Mtetra
.656 .752 .92 r
.0964 .39799 .10769 .40803 .12293 .40265 .11171 .39249 Mtetra
.654 .75 .92 r
.11171 .39249 .12293 .40265 .13826 .39728 .1271 .38702 Mtetra
.653 .749 .92 r
.1271 .38702 .13826 .39728 .1537 .39179 .14258 .38155 Mtetra
.656 .751 .92 r
.14258 .38155 .1537 .39179 .16925 .38614 .15816 .37597 Mtetra
.659 .755 .921 r
.15816 .37597 .16925 .38614 .18488 .38051 .17385 .37024 Mtetra
.658 .754 .921 r
.17385 .37024 .18488 .38051 .2006 .37492 .18964 .3645 Mtetra
.656 .751 .92 r
.18964 .3645 .2006 .37492 .2164 .36939 .20551 .35879 Mtetra
.655 .749 .919 r
.20551 .35879 .2164 .36939 .2323 .36386 .22147 .35311 Mtetra
.653 .746 .918 r
.22147 .35311 .2323 .36386 .24831 .35823 .23753 .34746 Mtetra
.653 .747 .919 r
.23753 .34746 .24831 .35823 .26443 .35235 .25369 .34177 Mtetra
.655 .753 .922 r
.25369 .34177 .26443 .35235 .28064 .34657 .26996 .33597 Mtetra
.659 .755 .921 r
.26996 .33597 .28064 .34657 .29694 .34093 .28634 .32999 Mtetra
.657 .749 .918 r
.28634 .32999 .29694 .34093 .31333 .33544 .30282 .32402 Mtetra
.655 .741 .912 r
.30282 .32402 .31333 .33544 .32982 .33 .31939 .31808 Mtetra
.654 .732 .907 r
.31939 .31808 .32982 .33 .34642 .32453 .33607 .31215 Mtetra
.653 .724 .901 r
.33607 .31215 .34642 .32453 .36313 .31893 .35285 .3062 Mtetra
.653 .719 .897 r
.35285 .3062 .36313 .31893 .37996 .31314 .36975 .30018 Mtetra
.654 .716 .894 r
.36975 .30018 .37996 .31314 .3969 .30711 .38675 .29408 Mtetra
.655 .717 .894 r
.38675 .29408 .3969 .30711 .41396 .30085 .40386 .2879 Mtetra
.656 .72 .896 r
.40386 .2879 .41396 .30085 .43113 .29439 .42108 .28165 Mtetra
.656 .725 .9 r
.42108 .28165 .43113 .29439 .44841 .2878 .43841 .27538 Mtetra
.655 .732 .906 r
.43841 .27538 .44841 .2878 .46579 .28117 .45585 .26911 Mtetra
.654 .74 .913 r
.45585 .26911 .46579 .28117 .48328 .27459 .47341 .26287 Mtetra
.653 .748 .919 r
.47341 .26287 .48328 .27459 .50088 .26815 .49107 .25664 Mtetra
.657 .755 .922 r
.49107 .25664 .50088 .26815 .51859 .26187 .50886 .25022 Mtetra
.659 .754 .921 r
.50886 .25022 .51859 .26187 .53641 .25566 .52676 .24368 Mtetra
.659 .749 .917 r
.52676 .24368 .53641 .25566 .55435 .24921 .54477 .2371 Mtetra
.657 .748 .917 r
.54477 .2371 .55435 .24921 .57241 .24264 .56291 .23055 Mtetra
.656 .749 .919 r
.56291 .23055 .57241 .24264 .59058 .23607 .58116 .224 Mtetra
.654 .751 .921 r
.58116 .224 .59058 .23607 .60887 .22954 .59953 .21749 Mtetra
.653 .752 .922 r
.59953 .21749 .60887 .22954 .62729 .22306 .61803 .21096 Mtetra
.656 .754 .922 r
.61803 .21096 .62729 .22306 .64583 .21658 .63665 .20428 Mtetra
.658 .752 .92 r
.63665 .20428 .64583 .21658 .66449 .20993 .65539 .19746 Mtetra
.657 .75 .919 r
.65539 .19746 .66449 .20993 .68327 .20314 .67426 .19063 Mtetra
.656 .75 .92 r
.67426 .19063 .68327 .20314 .70217 .19636 .69326 .18382 Mtetra
.654 .751 .921 r
.69326 .18382 .70217 .19636 .72121 .1896 .71239 .17704 Mtetra
.655 .752 .922 r
.71239 .17704 .72121 .1896 .74038 .18287 .73164 .17018 Mtetra
.654 .75 .92 r
.05456 .39891 .06606 .40899 .08118 .40352 .06972 .39347 Mtetra
.657 .753 .92 r
.06972 .39347 .08118 .40352 .0964 .39799 .08499 .38789 Mtetra
.658 .753 .92 r
.08499 .38789 .0964 .39799 .11171 .39249 .10035 .38227 Mtetra
.656 .751 .92 r
.10035 .38227 .11171 .39249 .1271 .38702 .1158 .37668 Mtetra
.655 .75 .92 r
.1158 .37668 .1271 .38702 .14258 .38155 .13134 .3711 Mtetra
.653 .749 .92 r
.13134 .3711 .14258 .38155 .15816 .37597 .14697 .36554 Mtetra
.655 .751 .92 r
.14697 .36554 .15816 .37597 .17385 .37024 .1627 .35988 Mtetra
.658 .755 .921 r
.1627 .35988 .17385 .37024 .18964 .3645 .17854 .35407 Mtetra
.658 .754 .921 r
.17854 .35407 .18964 .3645 .20551 .35879 .19448 .34821 Mtetra
.657 .752 .92 r
.19448 .34821 .20551 .35879 .22147 .35311 .21051 .34239 Mtetra
.656 .75 .92 r
.21051 .34239 .22147 .35311 .23753 .34746 .22663 .33657 Mtetra
.654 .748 .918 r
.22663 .33657 .23753 .34746 .25369 .34177 .24285 .33074 Mtetra
.653 .746 .918 r
.24285 .33074 .25369 .34177 .26996 .33597 .25917 .32493 Mtetra
.653 .747 .919 r
.25917 .32493 .26996 .33597 .28634 .32999 .2756 .31908 Mtetra
.654 .752 .921 r
.2756 .31908 .28634 .32999 .30282 .32402 .29213 .31317 Mtetra
.655 .754 .923 r
.29213 .31317 .30282 .32402 .31939 .31808 .30877 .30718 Mtetra
.657 .755 .922 r
.30877 .30718 .31939 .31808 .33607 .31215 .32552 .30107 Mtetra
.657 .753 .921 r
.32552 .30107 .33607 .31215 .35285 .3062 .34237 .29493 Mtetra
.656 .751 .92 r
.34237 .29493 .35285 .3062 .36975 .30018 .35934 .28878 Mtetra
.656 .749 .919 r
.35934 .28878 .36975 .30018 .38675 .29408 .3764 .28261 Mtetra
.655 .749 .919 r
.3764 .28261 .38675 .29408 .40386 .2879 .39358 .27642 Mtetra
.655 .75 .92 r
.39358 .27642 .40386 .2879 .42108 .28165 .41087 .2702 Mtetra
.654 .752 .922 r
.41087 .2702 .42108 .28165 .43841 .27538 .42827 .26397 Mtetra
.657 .755 .923 r
.42827 .26397 .43841 .27538 .45585 .26911 .44578 .25761 Mtetra
.657 .755 .922 r
.44578 .25761 .45585 .26911 .47341 .26287 .46341 .25116 Mtetra
.658 .753 .92 r
.46341 .25116 .47341 .26287 .49107 .25664 .48115 .24466 Mtetra
.658 .749 .917 r
.48115 .24466 .49107 .25664 .50886 .25022 .49901 .23811 Mtetra
.657 .747 .917 r
.49901 .23811 .50886 .25022 .52676 .24368 .51699 .23156 Mtetra
.656 .748 .918 r
.51699 .23156 .52676 .24368 .54477 .2371 .53508 .22501 Mtetra
.655 .75 .92 r
.53508 .22501 .54477 .2371 .56291 .23055 .55329 .21845 Mtetra
.653 .751 .921 r
.55329 .21845 .56291 .23055 .58116 .224 .57163 .21192 Mtetra
.654 .753 .923 r
.57163 .21192 .58116 .224 .59953 .21749 .59008 .20533 Mtetra
.657 .754 .922 r
.59008 .20533 .59953 .21749 .61803 .21096 .60866 .19858 Mtetra
.658 .752 .919 r
.60866 .19858 .61803 .21096 .63665 .20428 .62736 .19172 Mtetra
.657 .75 .918 r
.62736 .19172 .63665 .20428 .65539 .19746 .64619 .18487 Mtetra
.656 .75 .92 r
.64619 .18487 .65539 .19746 .67426 .19063 .66514 .17802 Mtetra
.654 .751 .921 r
.66514 .17802 .67426 .19063 .69326 .18382 .68423 .17119 Mtetra
.654 .752 .922 r
.68423 .17119 .69326 .18382 .71239 .17704 .70345 .1643 Mtetra
.657 .753 .921 r
.70345 .1643 .71239 .17704 .73164 .17018 .72279 .15725 Mtetra
.654 .75 .92 r
.04293 .38871 .05456 .39891 .06972 .39347 .05814 .38321 Mtetra
.655 .75 .92 r
.05814 .38321 .06972 .39347 .08499 .38789 .07345 .37767 Mtetra
.657 .753 .92 r
.07345 .37767 .08499 .38789 .10035 .38227 .08886 .372 Mtetra
.658 .753 .921 r
.08886 .372 .10035 .38227 .1158 .37668 .10437 .36628 Mtetra
.656 .752 .92 r
.10437 .36628 .1158 .37668 .13134 .3711 .11997 .36059 Mtetra
.655 .75 .92 r
.11997 .36059 .13134 .3711 .14697 .36554 .13565 .3549 Mtetra
.654 .749 .92 r
.13565 .3549 .14697 .36554 .1627 .35988 .15143 .34923 Mtetra
.654 .75 .92 r
.15143 .34923 .1627 .35988 .17854 .35407 .16731 .3435 Mtetra
.657 .754 .921 r
.16731 .3435 .17854 .35407 .19448 .34821 .1833 .33763 Mtetra
.658 .755 .921 r
.1833 .33763 .19448 .34821 .21051 .34239 .1994 .33168 Mtetra
.658 .754 .921 r
.1994 .33168 .21051 .34239 .22663 .33657 .21559 .32571 Mtetra
.656 .752 .92 r
.21559 .32571 .22663 .33657 .24285 .33074 .23188 .31976 Mtetra
.656 .75 .919 r
.23188 .31976 .24285 .33074 .25917 .32493 .24827 .31379 Mtetra
.655 .748 .918 r
.24827 .31379 .25917 .32493 .2756 .31908 .26476 .3078 Mtetra
.655 .747 .918 r
.26476 .3078 .2756 .31908 .29213 .31317 .28135 .30179 Mtetra
.654 .746 .917 r
.28135 .30179 .29213 .31317 .30877 .30718 .29805 .29576 Mtetra
.655 .747 .918 r
.29805 .29576 .30877 .30718 .32552 .30107 .31486 .28967 Mtetra
.655 .749 .919 r
.31486 .28967 .32552 .30107 .34237 .29493 .33177 .28354 Mtetra
.655 .75 .92 r
.33177 .28354 .34237 .29493 .35934 .28878 .3488 .27734 Mtetra
.656 .751 .92 r
.3488 .27734 .35934 .28878 .3764 .28261 .36593 .2711 Mtetra
.36593 .2711 .3764 .28261 .39358 .27642 .38318 .2648 Mtetra
.656 .751 .919 r
.38318 .2648 .39358 .27642 .41087 .2702 .40054 .25844 Mtetra
.657 .749 .918 r
.40054 .25844 .41087 .2702 .42827 .26397 .41801 .25203 Mtetra
.657 .748 .917 r
.41801 .25203 .42827 .26397 .44578 .25761 .4356 .24557 Mtetra
.657 .747 .916 r
.4356 .24557 .44578 .25761 .46341 .25116 .4533 .23907 Mtetra
.656 .747 .917 r
.4533 .23907 .46341 .25116 .48115 .24466 .47111 .23256 Mtetra
.656 .748 .918 r
.47111 .23256 .48115 .24466 .49901 .23811 .48905 .22601 Mtetra
.655 .75 .92 r
.48905 .22601 .49901 .23811 .51699 .23156 .5071 .21945 Mtetra
.654 .751 .921 r
.5071 .21945 .51699 .23156 .53508 .22501 .52527 .2129 Mtetra
.654 .752 .922 r
.52527 .2129 .53508 .22501 .55329 .21845 .54356 .20632 Mtetra
.655 .754 .923 r
.54356 .20632 .55329 .21845 .57163 .21192 .56197 .19965 Mtetra
.657 .754 .921 r
.56197 .19965 .57163 .21192 .59008 .20533 .58051 .19283 Mtetra
.658 .751 .919 r
.58051 .19283 .59008 .20533 .60866 .19858 .59917 .18595 Mtetra
.656 .749 .919 r
.59917 .18595 .60866 .19858 .62736 .19172 .61796 .17907 Mtetra
.656 .75 .92 r
.61796 .17907 .62736 .19172 .64619 .18487 .63687 .17218 Mtetra
.654 .751 .921 r
.63687 .17218 .64619 .18487 .66514 .17802 .65592 .16531 Mtetra
.654 .752 .922 r
.65592 .16531 .66514 .17802 .68423 .17119 .67509 .15838 Mtetra
.657 .753 .921 r
.67509 .15838 .68423 .17119 .70345 .1643 .6944 .1513 Mtetra
.657 .751 .919 r
.6944 .1513 .70345 .1643 .72279 .15725 .71383 .14416 Mtetra
.655 .751 .92 r
.03117 .37842 .04293 .38871 .05814 .38321 .04643 .37283 Mtetra
.654 .75 .92 r
.04643 .37283 .05814 .38321 .07345 .37767 .06179 .36724 Mtetra
.655 .75 .92 r
.06179 .36724 .07345 .37767 .08886 .372 .07724 .3616 Mtetra
.657 .753 .921 r
.07724 .3616 .08886 .372 .10437 .36628 .0928 .35584 Mtetra
.658 .753 .921 r
.0928 .35584 .10437 .36628 .11997 .36059 .10846 .35002 Mtetra
.656 .752 .92 r
.10846 .35002 .11997 .36059 .13565 .3549 .12421 .34422 Mtetra
.655 .751 .92 r
.12421 .34422 .13565 .3549 .15143 .34923 .14005 .33841 Mtetra
.654 .749 .919 r
.14005 .33841 .15143 .34923 .16731 .3435 .15598 .33261 Mtetra
.654 .749 .92 r
.15598 .33261 .16731 .3435 .1833 .33763 .17202 .32679 Mtetra
.655 .751 .921 r
.17202 .32679 .1833 .33763 .1994 .33168 .18815 .3209 Mtetra
.657 .755 .922 r
.18815 .3209 .1994 .33168 .21559 .32571 .20441 .31487 Mtetra
.658 .755 .922 r
.20441 .31487 .21559 .32571 .23188 .31976 .22076 .3088 Mtetra
.657 .754 .921 r
.22076 .3088 .23188 .31976 .24827 .31379 .23721 .30269 Mtetra
.657 .752 .92 r
.23721 .30269 .24827 .31379 .26476 .3078 .25377 .29658 Mtetra
.656 .751 .92 r
.25377 .29658 .26476 .3078 .28135 .30179 .27043 .29045 Mtetra
.656 .75 .919 r
.27043 .29045 .28135 .30179 .29805 .29576 .2872 .28429 Mtetra
.656 .749 .919 r
.2872 .28429 .29805 .29576 .31486 .28967 .30407 .2781 Mtetra
.656 .748 .918 r
.30407 .2781 .31486 .28967 .33177 .28354 .32105 .27186 Mtetra
.32105 .27186 .33177 .28354 .3488 .27734 .33814 .26558 Mtetra
.656 .747 .917 r
.33814 .26558 .3488 .27734 .36593 .2711 .35535 .25926 Mtetra
.35535 .25926 .36593 .2711 .38318 .2648 .37266 .2529 Mtetra
.656 .748 .918 r
.37266 .2529 .38318 .2648 .40054 .25844 .39009 .24649 Mtetra
.39009 .24649 .40054 .25844 .41801 .25203 .40763 .24004 Mtetra
.656 .749 .918 r
.40763 .24004 .41801 .25203 .4356 .24557 .42529 .23355 Mtetra
.656 .75 .919 r
.42529 .23355 .4356 .24557 .4533 .23907 .44306 .22703 Mtetra
.655 .751 .92 r
.44306 .22703 .4533 .23907 .47111 .23256 .46095 .22049 Mtetra
.654 .752 .921 r
.46095 .22049 .47111 .23256 .48905 .22601 .47896 .21393 Mtetra
.654 .753 .922 r
.47896 .21393 .48905 .22601 .5071 .21945 .49708 .20734 Mtetra
.654 .754 .923 r
.49708 .20734 .5071 .21945 .52527 .2129 .51533 .2007 Mtetra
.657 .754 .922 r
.51533 .2007 .52527 .2129 .54356 .20632 .53371 .19391 Mtetra
.657 .752 .92 r
.53371 .19391 .54356 .20632 .56197 .19965 .5522 .18704 Mtetra
.657 .75 .918 r
.5522 .18704 .56197 .19965 .58051 .19283 .57082 .18014 Mtetra
.656 .75 .919 r
.57082 .18014 .58051 .19283 .59917 .18595 .58956 .17324 Mtetra
.655 .751 .92 r
.58956 .17324 .59917 .18595 .61796 .17907 .60844 .16632 Mtetra
.654 .751 .921 r
.60844 .16632 .61796 .17907 .63687 .17218 .62744 .15941 Mtetra
.655 .753 .922 r
.62744 .15941 .63687 .17218 .65592 .16531 .64657 .15243 Mtetra
.657 .753 .921 r
.64657 .15243 .65592 .16531 .67509 .15838 .66583 .14531 Mtetra
.657 .751 .919 r
.66583 .14531 .67509 .15838 .6944 .1513 .68523 .13813 Mtetra
.656 .751 .919 r
.68523 .13813 .6944 .1513 .71383 .14416 .70475 .13094 Mtetra
.656 .752 .92 r
.01927 .36806 .03117 .37842 .04643 .37283 .03459 .36236 Mtetra
.655 .751 .92 r
.03459 .36236 .04643 .37283 .06179 .36724 .05 .35667 Mtetra
.654 .75 .92 r
.05 .35667 .06179 .36724 .07724 .3616 .0655 .35098 Mtetra
.655 .75 .92 r
.0655 .35098 .07724 .3616 .0928 .35584 .0811 .34524 Mtetra
.656 .752 .921 r
.0811 .34524 .0928 .35584 .10846 .35002 .09681 .3394 Mtetra
.657 .754 .921 r
.09681 .3394 .10846 .35002 .12421 .34422 .11262 .33348 Mtetra
.657 .752 .92 r
.11262 .33348 .12421 .34422 .14005 .33841 .12852 .32756 Mtetra
.656 .751 .92 r
.12852 .32756 .14005 .33841 .15598 .33261 .14452 .32163 Mtetra
.655 .75 .92 r
.14452 .32163 .15598 .33261 .17202 .32679 .16061 .31569 Mtetra
.654 .749 .919 r
.16061 .31569 .17202 .32679 .18815 .3209 .17681 .30975 Mtetra
.17681 .30975 .18815 .3209 .20441 .31487 .1931 .30377 Mtetra
.655 .751 .921 r
.1931 .30377 .20441 .31487 .22076 .3088 .20951 .29773 Mtetra
.656 .754 .922 r
.20951 .29773 .22076 .3088 .23721 .30269 .22602 .29159 Mtetra
.657 .755 .922 r
.22602 .29159 .23721 .30269 .25377 .29658 .24264 .28539 Mtetra
.24264 .28539 .25377 .29658 .27043 .29045 .25937 .27915 Mtetra
.657 .754 .921 r
.25937 .27915 .27043 .29045 .2872 .28429 .2762 .27289 Mtetra
.656 .753 .921 r
.2762 .27289 .2872 .28429 .30407 .2781 .29314 .26659 Mtetra
.656 .752 .921 r
.29314 .26659 .30407 .2781 .32105 .27186 .31019 .26026 Mtetra
.656 .752 .92 r
.31019 .26026 .32105 .27186 .33814 .26558 .32735 .25389 Mtetra
.32735 .25389 .33814 .26558 .35535 .25926 .34462 .2475 Mtetra
.34462 .2475 .35535 .25926 .37266 .2529 .36201 .24107 Mtetra
.655 .752 .921 r
.36201 .24107 .37266 .2529 .39009 .24649 .3795 .2346 Mtetra
.3795 .2346 .39009 .24649 .40763 .24004 .39712 .2281 Mtetra
.655 .753 .922 r
.39712 .2281 .40763 .24004 .42529 .23355 .41484 .22157 Mtetra
.41484 .22157 .42529 .23355 .44306 .22703 .43269 .21501 Mtetra
.655 .754 .923 r
.43269 .21501 .44306 .22703 .46095 .22049 .45065 .2084 Mtetra
.45065 .2084 .46095 .22049 .47896 .21393 .46874 .20173 Mtetra
.657 .754 .922 r
.46874 .20173 .47896 .21393 .49708 .20734 .48695 .19495 Mtetra
.657 .752 .92 r
.48695 .19495 .49708 .20734 .51533 .2007 .50528 .1881 Mtetra
.657 .75 .918 r
.50528 .1881 .51533 .2007 .53371 .19391 .52373 .18121 Mtetra
.656 .749 .918 r
.52373 .18121 .53371 .19391 .5522 .18704 .54231 .1743 Mtetra
.656 .75 .919 r
.54231 .1743 .5522 .18704 .57082 .18014 .56101 .16738 Mtetra
.655 .751 .92 r
.56101 .16738 .57082 .18014 .58956 .17324 .57984 .16044 Mtetra
.654 .752 .921 r
.57984 .16044 .58956 .17324 .60844 .16632 .5988 .15349 Mtetra
.655 .753 .922 r
.5988 .15349 .60844 .16632 .62744 .15941 .61789 .14644 Mtetra
.657 .753 .921 r
.61789 .14644 .62744 .15941 .64657 .15243 .63711 .13928 Mtetra
.657 .751 .919 r
.63711 .13928 .64657 .15243 .66583 .14531 .65646 .13206 Mtetra
.656 .75 .919 r
.65646 .13206 .66583 .14531 .68523 .13813 .67594 .12483 Mtetra
.655 .751 .92 r
.67594 .12483 .68523 .13813 .70475 .13094 .69556 .11758 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
[(-2)] .12586 .2075 1 .99877 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.56863 .04703 m
.57247 .05235 L
s
[(2)] .56094 .0364 .72324 1 Mshowa
.125 Mabswid
.18558 .19702 m
.18832 .19985 L
s
.23703 .17687 m
.23971 .17975 L
s
.28951 .15632 m
.29214 .15925 L
s
.39772 .11395 m
.40023 .11699 L
s
.4535 .09211 m
.45595 .0952 L
s
.51046 .06981 m
.51284 .07294 L
s
.08568 .23614 m
.08851 .23887 L
s
.62804 .02377 m
.63027 .02701 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 233.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00o?ooool2o`0006[ooooo003iooooo`?o000000?oooooo`000?ooool0
JOooool00?Oooooo0_l00004ooooo`;o0000JOooool00?Cooooo0ol00006ooooo`03o`000?oooooo
000006Sooooo003;ooooo`Go00008_ooool2o`0000Wooooo00?o0000ooooool00000J?ooool00<_o
oooo00GoV9RHob4Q8Oo^k^koooooodA4A00Oooooo`?o00002oooool01?l0003oooooooooool0001W
ooooo`00c?ooool00onHV9So8B4Qonk^kP0Mooooo`?o00003_ooool01Ol0003ooooooooooooooooo
000006Kooooo003=ooooo`03oiRHV?lQ8B7ok^k^01[ooooo0_l0000Aooooo`05o`000?oooooooooo
ooooool00000I_ooool00<kooooo00?oMgMgofIVI_ooool05_ooool3o`0001?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1Sooooo`00coooool00ol0003oooooooooo`0Cooooo`;o
00000_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0H_ooool00<_ooooo00Go0000okZj^_ooooooV9RHoa0@400Booooo`?o00006Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo06;ooooo003;ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`04?ooool2o`0001cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Qooooo`00
gOooool3o`0001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Qooooo`00fooo
ool2o`00027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Pooooo`00f?ooool3
o`0002?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Oooooo`00eOooool3o`00
02Kooooo00?o0000ooooooooool01?ooool2o`00067ooooo003Cooooo`;o0000:Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo05kooooo003@ooooo`?o000000?oooooo`000?ooool0
:?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05gooooo003>ooooo`;o00001Ooo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0GOoo
ool00<_ooooo0ol0000`ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0G?ooool0
0<Wooooo0_l0000cooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Foooool00<Ko
oooo0ol0000eooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Foooool00<Cooooo
0_l0000hooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0F_ooool00<7ooooo0ol0
000jooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03_ooool5o`0004Kooooo002n
ooooo`?o0000?Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00kooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A016ooooo`00_?ooool2o`0000?ooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo1_l00003ooooo`03oiRHV?lQ8B7o
k^k^04Oooooo002iooooo`?o0000@oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00kooooo00?oV9RHob4Q8Oo^k^h0A_ooool00;Oooooo0_l00016ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03oooool00omgMgOoIVIVooooo`15ooooo`00]?ooool3o`0004Sooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Cooooo
002booooo`;o0000Boooool00ol0003oooooooooo`0=ooooo`;o00003?ooool01Ol0003o^[Zjoooo
oonHV9So410@04Kooooo002_ooooo`?o0000COooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c016ooooo`00[Oooool2o`00053ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`1Dooooo`00Z_ooool4o`00057ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1Dooooo`00Z?ooool2o`0000Cooooo00?o0000oooo
ooooool0C_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05?ooooo001nooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h08_ooool3o`0005Oooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`1Booooo`00O_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01oooooo0ol0001Joooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool0D_ooool007kooooo00Go410@oooooooo
oooooooooa0@400Mooooo`;o0000GOooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
057ooooo001nooooo`05o`000?ooooooooooooooool000006_ooool3o`0005oooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`1@ooooo`00O_ooool01Ol0003ooooooooooooooooo0000
01Sooooo0_l0001Rooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0D?ooool007ko
oooo00Go410@oooooooooooooooooa0@400Eooooo`?o0000I?ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo04oooooo001nooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool2o`00
00?ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
04kooooo001nooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04?ooool3o`0006Sooooo00?oYl3[o`00
0?ooool05_ooool00ol0003oooooooooo`1>ooooo`00TOooool2o`0006Sooooo1?nW`>/00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo04gooooo002>ooooo`?o0000J?ooool7ojO0j`03o`00
0?oooooooooo01Cooooo0ol0001>ooooo`00Roooool3o`0006Wooooo0_nW_n/7ojO0j`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool0C?ooool008Wooooo0_l0001Yooooo`KoYko[1_nW`>/0
0ol0003oYl3[ooooo`0Gooooo`03o`000?oooooooooo04_ooooo0026ooooo`?o0000J?ooool00onX
`>_oYko[ojNoj`07ojNoj`GoYl3[00?o0000ojO0joooool06?ooool00ol0003oooooooooo`1:oooo
o`00Q?ooool2o`0000;ooooo00?o0000ooooooooool0Hoooool5ojS0j`WoYko[1?nW`>/00ol0003o
Yl3[ojO0j`0Hooooo`03o`000?oooooooooo04[ooooo0021ooooo`?o00001Oooool00ol0003ooooo
ooooo`1Pooooo`SoZ<3[1onW_n/00onX`>_oYl3[ojO0j`02ojO0j`04o`000?nW`>_oYl3[ojO0jaSo
oooo00?o0000ooooooooool0BOooool007oooooo0_l0001Yooooo`[oZ<3[1?nW_n/5ojS0j`?oYl3[
00?o0000ojO0jonW`>/00_nW`>/Hooooo`03o`000?oooooooooo04Sooooo001looooo`?o0000J?oo
ool>ojS0j`03ojNojonX`>_oZ<3[00KoZ<3[0_nW`>/01Ol0003oYl3[ojO0jonW`>_oZ<3[01Sooooo
00?o0000ooooooooool0B?ooool007[ooooo0_l0001Wooooo`;oYl3/6OnX`>/2ojO0j`03o`000?nW
`>_oZ<3[00?oZ<3[6?ooool00ol0003oooooooooo`17ooooo`00Moooool3o`0006Kooooo1_nW`>`I
ojS0j`03ojO0jol0003oZ<3[00GoZ<3[6?ooool00ol0003oooooooooo`16ooooo`00M?ooool3o`00
06Kooooo00?oYl3[ojO0k?nW`>`01onW`>`6ojS0j`;oYl3/4OnX`>/00ol0003oZ<3[ojS0j`04ojS0
jaSooooo00?o0000ooooooooool0A_ooool007;ooooo0_l00002ooooo`03o`000?oooooooooo06;o
oooo1?nW`>/9ojO0k0;oZ<3[1_nW`>`@ojS0j`03o`000?nX`>_oZ<3[00GoZ<3[6?ooool00ol0003o
ooooooooo`15ooooo`00Koooool3o`0006Oooooo1onW`>/7ojO0k003ojO0jonW`>coYl3/00OoYl3/
1_nX`>/00onW`>coZ<3[ojS0j`06ojS0j`03o`000?nX`>_oZ<3[00GoZ<3[6?ooool00ol0003ooooo
ooooo`15ooooo`00KOooool2o`0006Oooooo2_nW`>/4ojO0k0GoYl3[2OnW`>`2ojS0j`GoYl3/1onX
`>/00ol0003oZ<3[ojS0j`06ojS0jaOooooo0_l00016ooooo`00J_ooool3o`0006Kooooo3_nW`>/0
0onW`>coYl3[ojO0j`06ojO0j`OoYl3/00?oYl3[ojO0k?nW`>`01_nW`>`6ojS0j`03o`000?nW`>co
Z<3[00OoZ<3[6?ooool00ol0003oooooooooo`13ooooo`00J?ooool2o`0006Kooooo0_nW_n/HojO0
j`CoYl3/1OnW`>/8ojO0k0;oZ<3[0onW`>`00ol0003oYl3/ojO0k008ojS0jaOooooo00?o0000oooo
ooooool0@oooool006Gooooo0ol0001Uooooo`KoYko[6?nW`>/00onW`>coYl3[ojO0j`06ojO0j`Ko
Yl3/00?oYl3[ojO0k?nW`>`00onW`>`01?l0003oYl3/ojO0k?nW`>`6ojS0j`03ojO0k?oooooooooo
01Kooooo00?o0000ooooooooool0@_ooool006?ooooo0_l0001Uooooo`[oYko[1_nW`>/00onW_n_o
Yl3[ojO0j`0=ojO0j`03ojNojonW`>_oYl3[00OoYl3[1?nW`>`4ojO0j`GoYl3/00Co0000ojO0k?nW
`>coYl3/0_nX`>/5ojO0k1Sooooo00?o0000ooooooooool0@Oooool0063ooooo0ol000000ooooooo
0000ooooo`1Rooooo`goYko[0_nW`>/5ojNoj`_oYl3[1OnW_n/9ojO0j`03ojO0k?nW`>_oYl3[00Go
Yl3[1?nW`>`01?l0003oYl3/ojO0k?nW`>/8ojO0k1Oooooo00?o0000ooooooooool0@Oooool003Ko
oooo1Ol0000Sooooo`;o0000I_ooool>ojNoj`03ojRojonW_n_oYko[00KoYko[1_nW`>/:ojNoj`Ko
Yl3[0_nW_n/8ojO0j`CoYl3/00?o0000ojO0jonW`>/00_nW`>/8ojO0k1Oooooo00?o0000oooooooo
ool0@?ooool003Kooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Pooooo`?o0000IOooool2ojRoj`co
Yko[1OnX_n/8ojNoj`;oYl3[3_nW_n/2ojO0j`KoYko[2?nW`>/01?nW`>coYl3[ojO0jol00005ojO0
j`KoYl3/00?oYl3[ooooooooool05_ooool00ol0003oooooooooo`0oooooo`00;_ooool6o`0000?o
oooo00?oV9RHob4Q8Oo^k^h07_ooool3o`0006Gooooo1_nX_n/9ojNoj`SoZ;o[1_nW_n/00onX`>_o
Yko[ojNoj`0=ojNoj`03ojRojonW_n_oYko[00OoYko[1_nW`>/01OnW_n_oYl3[ojO0jonW`>_o0000
00GoYl3[1?nW`>`4ojO0jaOooooo00?o0000ooooooooool0?oooool003Sooooo00?oV9RHob4Q8Oo^
k^h06oooool2o`0006Gooooo0_nX`>/8ojRoj`KoYko[0_nX`>/8ojRoj`CoYko[1?nX`>/;ojNoj`Go
Z;o[2OnW_n/2ojO0j`GoYko[0_nW`>/00ol0003oYl3[ojO0j`04ojO0j`03ojO0k?nW`>_oYl3[00Go
Yl3[5oooool00ol0003oooooooooo`0nooooo`00>Oooool00omgMgOoIVIVooooo`0Gooooo`?o0000
I?ooool6ojS0j`SoZ;o[0_nW_n/6ojS0j`SoZ;o[00?oYko[ojS0jonX`>/01OnX`>/7ojNoj`03ojS0
jonX_n_oZ;o[00KoZ;o[1_nW_n/2ojRoj`SoYko[00?oYl3[o`000?nW`>/03OnW`>/Hooooo`03o`00
0?oooooooooo03gooooo000jooooo`03o`000?oooooooooo01Cooooo0_l0001Tooooo`03ojS1k?nX
`>_oZ<3[00OoZ<3[1_nX_n/00onX`NcoZ<3[ojS0j`07ojS0j`KoZ;o[00?oZ<7[ojS0jonX`>/01onX
`>/4ojNoj`CoZ<3[2?nX_n/2ojNoj`KoZ;o[2?nW_n/00ol0003oYl3[ojO0j`0=ojO0jaOooooo00?o
0000ooooooooool0?Oooool003Kooooo00Go0000okZj^_ooooooV9RHoa0@400Cooooo`?o00000_oo
ool00ol0003oooooooooo`1Oooooo`CoZ<7/2OnX`>/2ojRoj`GoZ<7/2OnX`>/2ojRoj`GoZ<7[2OnX
`>/00onW_n_oZ<3[ojS0j`05ojS0j`KoZ;o[00?oZ<3[ojRojonX_n/01onX_n/6ojNoj`03ojRojol0
003oYl3[00koYl3[6?ooool00ol0003oooooooooo`0looooo`00=_ooool01OnHV9So410@o`000?lQ
8B7oc<c<017ooooo0_l0001Uooooo`OoZ<7/1onX`>/00onW`NcoZ<7/ojS1k006ojS1k0KoZ<3[0_nW
`N`8ojS1j`KoZ<3[0_nX`N`8ojS0j`CoZ;o[1?nX`>/9ojRoj`;oYko[1?nX_n/00ol0003oYl3[ojO0
j`0>ojO0jaKooooo0ol0000mooooo`00BOooool3o`0006Gooooo00?oYl7/ojS1k?nX`N`01onX`N`4
ojS0j`CoYl7/2?nX`N`2ojS0j`KoYl7/2?nX`N/2ojS0j`KoZ<7/2?nX`>/00onX_n_oZ<3[ojS0j`05
ojS0j`OoZ;o[00?oZ<3[ojRojonX_n/01?nX_n/00ol0003oZ;o[ojO0j`05ojO0j`;oYko[2?nW`>/G
ooooo`03o`000?oooooooooo03_ooooo0017ooooo`;o0000IOooool5ojO1k0WoZ<7/00?oZ<3[ojO1
k?nW`N`01OnW`N`6ojS1k0;oYl3/2?nW`N`6ojS1j`03ojO0k?nX`NcoZ<7/00OoZ<7/1_nX`>/00onW
`NcoZ<3[ojS0j`06ojS0j`CoZ;o[1OnX`>/5ojRoj`03o`000?nX_n_oZ;o[00;oYl3[1_nW_n/8ojO0
jaOooooo00?o0000ooooooooool0>_ooool004Cooooo0ol0001Tooooo`WoYl7/1_nX`N`2ojO0k0So
Yl7/1?nX`N`5ojO0k0SoYl7/0_nX`N/5ojO0k0WoZ<7/0_nX`>/5ojO1k0SoZ<3[00?oZ;o[ojS0jonX
`>/01_nX`>/4ojRoj`03o`000?nX_n_oZ<3[00WoYko[1_nW`>/00onW_n_oooooooooo`0Fooooo`03
o`000?oooooooooo03Wooooo0011ooooo`?o0000I?ooool=ojO1k0;oZ<7/1_nW`>`8ojO1k003ojS1
k?nW`>coYl3/00KoYl3/1_nW`N`00onW`>_oYl3/ojO0k006ojO0k0KoZ<7/0_nW`>`8ojO1k0KoZ<3[
0_nW`N`9ojS0j`;oZ;o[00?oZ<3[o`000?nX`>/00_nX`>/9ojNoj`;oYl3[1OnW_n/Gooooo`03o`00
0?oooooooooo03Wooooo000oooooo`?o0000Hoooool00onW`>coYl7/ojO1k00<ojO1k0;oYl3[2?nW
`>`6ojO1k0;oYl3[2OnW`>`2ojO1k0GoYl3[2?nW`>`2ojS1k0KoYl3/2?nW`N`2ojS0j`KoYl7/1onX
`>/01OnW`NcoZ<3[ojS0jonX`>_o000000CoZ<3[1_nW_n/2ojS0j`SoYko[5oooool00ol0003ooooo
ooooo`0hooooo`00??ooool3o`0000?ooooo00?o0000ooooooooool0G_ooool4ojO0k0[oYl7/1_nW
`>/8ojO0k0;oYl7/1_nW`>/7ojO0k003ojNojonW`>_oYl3[00KoYl3[1_nW`>`2ojO0j`SoYl3/1_nW
`N`00onW`>coYl7/ojO1k007ojO1k0CoZ<3[1?nW`N`2ojS0j`03o`000?nX`>_oZ<3[00?oZ<3[0_nW
_n/6ojS0j`SoYko[5_ooool00ol0003oooooooooo`07ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
;?ooool003[ooooo0_l0001Uooooo`OoYl3/1_nW`N`:ojO0j`KoYl3/00?oYko[ojO0jonW`>/01onW
`>/4ojO0k0CoYko[2?nW`>/2ojO0k0KoYl3[2?nW`>`2ojO1k0GoYl3/2OnW`N`00onX`>_oYl7/ojO1
k005ojO1k003ojS0jol0003oZ<3[00?oZ<3[00?oZ<7[ojS0jonX`>/01onX`>/6ojNoj`03ojS0jooo
oooooooo01Gooooo00?o0000ooooooooool01_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02cooooo
000gooooo`?o0000IOooool:ojO0k0;oYl7/3_nW`>/2ojO0k0GoYko[2OnW`>/00onW`>coYko[ojNo
j`05ojNoj`KoYl3[00?oYko[ojO0jonW`>/01onW`>/6ojO0k003ojNojonW`>coYl3/00KoYl3/1_nW
`N`2ojO0k0SoYl7/0_nX`>/00ol0003oZ<3[ojS1j`03ojS1j`WoZ<3[0_nW_n/5ojS0jaOooooo00?o
0000ooooooooool01Oooool01Ol@413ooooooooooooooooo410@02cooooo000eooooo`;o0000IOoo
ool<ojO0k0;oYko[3_nW`>/9ojNoj`KoYl3[2_nW_n/4ojO0j`CoYko[2OnW`>/2ojO0k0GoYko[2?nW
`>`2ojO1k0KoYl3/2?nW`N`00onX`>_o0000ojS1j`05ojS1ja3oZ<3[5_ooool00ol0003ooooooooo
o`05ooooo`05o`000?ooooooooooooooool00000;?ooool003;ooooo0ol0001Tooooo`03ojO0jonW
`>coYl3/00[oYl3/1OnW_n/:ojO0j`goYko[0_nW`>/>ojNoj`03ojO0jonW_n_oYko[00GoYko[1_nW
`>/:ojNoj`KoYl3/00?oYko[ojO0k?nW`>`01onW`>`6ojO1k003ojO0k?nX`N_o000000OoZ<7[4?nX
`>/Fooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000/ooooo`00<?oo
ool2o`0006Cooooo1OnW`>/9ojO0k0SoYko[1_nW`>/00onW_n[oYko[ojNoj`0<ojNoj`;oZ;oZ3_nW
_n/00onX_n[oYko[ojNoj`07ojNoj`;oYl3[3_nW_n/2ojO0k0GoYko[2OnW`>`2ojO1k0GoYl3/00?o
0000ojS1jonX`N/01?nX`N/00onW`>coZ<3[ojS0j`0>ojS0jaOooooo00?o0000ooooooooool00ooo
ool01Ol@413ooooooooooooooooo410@02cooooo000]ooooo`?o000000?oooooo`000?ooool0H?oo
ool9ojO0j`KoYl3/2onW_n/2ojO0j`GoYkoZ2_nW_n/6ojRojP[oYko[1OnX_nX7ojNoj`03ojRoj_nW
_n_oYko[01KoYko[1_nW`>`2ojNoj`OoYl3/00?o0000ojS1jonX`N/00_nX`N/4ojO0k13oZ<3[5_oo
ool2o`0000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0/ooooo`00:_ooool3o`0006?ooooo3OnW
`>/2ojO0k0goYko[00?oZ;oZojNoj_nW_nX01_nW_nX6ojNoj`[oZ;oZ1_nW_n/9ojRojPCoYko[1?nX
_nXHojNoj`;oYl3/1_nW_n/6ojO0k003o`000?nW`>coZ<7[00OoYl3/1_nX`>/00onW`>coZ<3[ojS0
j`07ojS0ja?ooooo0_l000000ooooooo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
;?ooool002Sooooo0_l0001Sooooo`ooYl3[3_nW_n/4ojRojPSoYkoZ0_nW_n/>ojRojP;oYko[3OnX
_nX00onW_n_oZ;oZojRojP05ojRojPOoYko[00?oZ;oZojNojonW_n/05_nW_n/5ojO0k003o`000?nW
_n_oYl3/00OoYl3/1?nX`>/4ojO0k0WoZ<3[5_ooool00ol0003oooooooooo`0booooo`009Oooool3
o`0006;ooooo3onW`>/?ojNoj`OoZ;oZ1_nW_nX2ojS0j`koZ;oZ00?oZ<7[ojRoj_nX_nX03?nX_nX0
0onX`>_oZ;oZojRojP07ojRojPCoYko[1?nX_nXHojNoj`;oYl3/00?oYko[o`000?l000000_nW_n/8
ojO0k003ojS0jonW`>coYl3/00GoYl3/1_nX`>/2ojS1jaKooooo00?o0000ooooooooool0<_ooool0
02?ooooo0_l0001Rooooo`ooYl3[4?nW_n/9ojRojPCoYkoZ1OnX`>/:ojRojPGoZ<7[2_nX_nX5ojS0
j`WoZ;oZ00?oYko[ojRoj_nX_nX01OnX_nX6ojNoj`03ojRoj_nW_n_oYko[00koYko[0ol000000onW
_n_o0000ojNoj`02ojNoj`KoYl3/00?oY/3/ojO0k?nW`>`01onW`>`2ojS0j`KoZ<7[5_ooool00ol0
003oooooooooo`0aooooo`008?ooool3o`00067ooooo3onW`>/@ojNoj`goZ;oZ00?oYkoZojS0jonX
`>/01_nX`>/6ojRojP03ojS1k?nX`N_oZ<7[00KoZ<7[1_nX_nX00onX`NcoZ<3[ojS0j`06ojS0j`Ko
Z;oZ0_nX`N/9ojRojP;oYko[1OnX_nX<ojNoj`?o00001OnW_n/01?l0003oYko[ojNojonW_n/2ojO0
k0GoY/3/2?nW`>`8ojS1jaOooooo00?o0000ooooooooool0<?ooool001oooooo0_l0001Pooooo`oo
Yl3[0_nW_nX>ojNoj`03ojRojonX_n[oZ;oZ00coZ;oZ0_nX`N`9ojS0j`;oZ;oZ1OnX`N`8ojS1j`;o
Z;oZ1OnX`N`8ojS0j`;oZ;oZ1_nX`N/7ojRojP03ojS1jonX_n[oZ;oZ00KoZ;oZ1_nW_n/00onX_n[o
Yko[o`000002o`0000WoYko[00?o0000ojNojonW_n/02?nV`>`8ojO0k0SoZ<7[5_ooool00ol0003o
ooooooooo`0`ooooo`007oooool00ol0003oooooo`00001Mooooo`koYl3[1_nW_nX:ojNoj`GoZ;o[
2_nX_nX6ojS1k0OoZ<3[00?oYko[ojS1k?nX`N`01_nX`N`6ojS1j`03ojJnjonX`NcoZ<7/00KoZ<7/
1_nX`>/2ojO0j`SoZ<7[1?nX_nX4ojS1j`SoZ;oZ0_nW_n/2ojRojP?o00003OnW_n/00ol0003oYko[
ojNoj`08ojK0k0SoYl3/1_nX`N/00onW`>_oooooooooo`0Eooooo`03o`000?oooooooooo02oooooo
000<ooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00Co0000oooooooooooo
0000F_ooool=ojO0j`[oYkoZ1_nW_n/00onW`>_oZ;o[ojRoj`06ojRoj`KoZ;oZ2_nX`N`4ojS0j`Co
Yko[2?nX`N`2ojS1j`GoY[k[2?nX`N`2ojS0j`KoYl3[2?nX`N/00onX_n[oZ<7[ojS1j`05ojS1j`Ko
Z;oZ00?oZ<7[ojRoj_l000000_l00004ojRojPKoYko[00?oZ;oZojNojonW_n/00onW_n/01?l0003o
Yko[ojNojonW_n/6ojK0k0;oYko[2?nW`>`2ojS1j`GoYl3[5oooool00ol0003oooooooooo`0^oooo
o`003?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06
ooooo`;o00000_ooool00ol0003oooooooooo`1Eooooo`coYl3[3_nW_nX2ojNoj`GoYl3[2?nX_n/2
ojRojPkoZ<7/00?oZ<3[ojNojonW_n/01OnW_n/6ojS1k003ojNkj?nV_^_oY[k[00KoY[k[1_nX`N`0
0onW_>WoYl3[ojO0j`07ojO0j`KoZ<7[0_nV_n/8ojS1j`;oZ;oZ0_nX`N/3o`0000SoZ;oZ0_nW_n/5
ojRojPGoYko[00Co0000ojNojonW_n_oYko[0_nV`>`6ojNoj`KoYl3/00?oY[o/ojO0jonW`>/01_nW
`>/Fooooo`03o`000?oooooooooo02kooooo0004ooooo`Ko00000oooool00onHV9So8B4Qonk^kP04
ooooo`05oa0@4?ooooooooooooooool@41001Oooool2o`0000Cooooo00?o0000ooooooooool0DOoo
ool=ojO0j`03ojNojonW_n[oYkoZ00coYkoZ2OnW`>/6ojRoj`;oYl3/3_nX`N`00onW_NWoYko[ojNo
j`07ojNoj`;oZ<7/1OnW^nP8ojJnj`;oZ<7/1OnW_>T9ojO0j`;oZ<7[1_nV_n/6ojS1j`03ojJojonX
`N_o000000;o00001?nX`N/6ojRojP03ojS1jonX_n[oZ;oZ00KoZ;oZ1OnW_n/00ol0003oZ;o[ojRo
j`09ojNoj`;oYl3/1OnV_n`8ojO0jaKooooo00?o0000ooooooooool0;Oooool000kooooo00?oV9RH
ob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`1=ooooo`koYl3[1?nW_n/:ojNojPgoYl3[0_nX_n/6ojO0k0[oZ<7/1OnW
_NT7ojNoj`03ojRhiOnW^nSoYk_X00KoYk_X1_nV_^/00onX^NGoYkcYojNlj@06ojNlj@KoYl3[0_nW
^nL9ojJoj`;oZ<7[0onV_n/2o`0000SoZ<7[0_nX_nX5ojS1j`SoZ;oZ0_nW_n/2ojRoj`04o`000?nX
_n_oZ;o[ojRoj`SoYko[2?nV_n`6ojO0j`03ojO0k?oooooooooo01Gooooo00?o0000ooooooooool0
;?ooool000oooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`19ooooo`ooYl3[1onW_n/6ojNojPooYl3[
0_nW_n/8ojO0k0KoZ<7/00?oYk_WojNmjOnW_NT01_nW_NT4ojNoj`CoZ;SU2?nW^nP2ojJnj`GoZ;WU
2?nW_>T2ojO0j`KoYk_W1onV_n/00onX^nOoY[o[ojJoj`03o`0000?oY[o[1_nX`N/00onW_n_oZ<7[
ojS1j`06ojS1j`KoZ;oZ00?oZL3[ojRojonX_n/00onX_n/00ol0003oZ;o[ojRoj`09ojNoj`SoY[o/
0_nW`>/5ojO0k1Gooooo0_l0000^ooooo`004?ooool01Ol0003ooooooooooooooooo410@00?ooooo
00?o410@ooooooooool00oooool2o`0000Oooooo00?o0000ooooooooool0A_ooool00onX`N_oYl3[
ojO0j`0<ojO0j`[oYko[0_nW_nX?ojO0j`KoYko[2?nW`>`2ojS1k0GoYk_W2?nW_NT00onW_n_oZ;SU
ojRhi@05ojRhi@KoYk_X00?oZK?OojRiiOnX^ND01_nX^ND6ojNlj@;oZ[OS2?nW^nL4ojJoj`;oZ;_W
0ol00007ojJoj`;oZ<7[1OnW_n/8ojS1j`;oZ;oZ1OnY`>/5ojRoj`03o`000?nX_n_oZ;o[00WoYko[
1_nV_n`00onW_n_oYl3/ojO0k006ojO0k1Kooooo00?o0000ooooooooool0:oooool000cooooo00Go
0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo04;ooooo1OnX`N/:ojO0j`koYko[3OnW`>/:ojNoj`Ko
Yl3/00?oYkWVojNkionW^nL01_nW^nL6ojNmj@03ojRdhOnX^>GoZ;SU00KoZ;SU1?nW^nP4ojVcg`So
Z;WU0_nW_>T6ojZgh`SoYk_W00?oY[o[ojRkiol000000_l00003ojRki`KoY[o[00?oZ;cXojNojonW
_n/01_nW_n/6ojS1j`03ojO0k?nY`>_oZL3[00KoZL3[1OnX_n/00ol0003oZ<3ZojS0jP09ojNoj`;o
Y[o/1OnW_n/8ojO0k1Gooooo00?o0000ooooooooool0:oooool000cooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo03kooooo0_nX`N`7ojS1j`KoYl3[4_nW_n/9ojO0j`koYko[0_nW`>`5ojNi
iPSoYk_W0_nW_NT5ojRdh@SoZ;SU00?oYk_XojVcgonY/ml01OnY/ml6ojRii@03oj^_fonZ]n?oZ[OS
00OoZ[OS1_nW^nL3o`0000OoZ;_W0_nV_n/5ojRlj0SoYko[0_nX`N/5ojO0k0SoZL3[0_nX_n/2ojS0
jP04o`000?nX`>[oZ<3ZojS0jPKoYko[0_nX_n/7ojNoj`KoYl3/0_nV_n`Fooooo`03o`000?oooooo
oooo02[ooooo000Nooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0>_ooool6ojS1
k0OoZ<7[0_nW`>/FojNoj`KoYl3[3onW_n/00onW^>GoYkWVojNiiP06ojNiiPKoYk_W00?oZ;3MojRd
hOnX]>401_nX]>46ojRhi@03ojZ]f_nY/mooZK?O00KoZK?O1?nX^ND4oj^_f`WoZ[OS0_nW^nL3o`00
00;oZkKQ1onX^nL00on/]n7oZ;cXojRlj006ojRlj0KoYko[00?oYkgYojO0k?nW`>`01_nW`>`6ojW0
j`03ojS1jonX`>[oZ<3Z00?oZ<3Z00Co0000ojS0j_nX`>[oZ<3Z0_nW_n/6ojRoj`OoYko[0_nW`>`6
ojJok1Kooooo00?o0000ooooooooool0:Oooool001gooooo0ol0000;ooooo`03o`000?oooooooooo
03Kooooo2_nX`N`5ojS1ja[oYko[0_nW`>/?ojNoj`GoYkSU2?nW^NH2ojNki`GoZ;3M2?nX]>42ojRh
i@GoZZgJ2?nY/ml00onX^NGoZjoKoj^_f`05oj^_f`OoZ[OS0ol00006oj^fh@CoZ;_W1?n/]n48ojRl
j0;oYko[1OnW_NT8ojO0k0;oZL3[1OnX`N/5ojS0jP03o`000?nX`>[oZL3[00SoZ;o[1_nW_n/00onW
`>_oY[o/ojJok006ojJok1Kooooo00?o0000ooooooooool0:Oooool001gooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0booooo`koZ<7/00?oZ<7[ojNojonW_n/06_nW_n/00onW`>_o
Yko[ojNoj`0<ojNoj`03ojNgi?nW^>GoYkSU00KoYkSU1_nW^NH00onX[M_oZ;3MojR`g@06ojR`g@Ko
Z;CQ00?oZZ[FojZ]f_nZ[MX01_nZ[MX6ojVcg`03ojj/e_n[[m_oZjoK00OoZjoK0onZ]n<3o`0000;o
[JkH2?n[]^400onX^nOo[;OQojbgh@05ojbgh@KoZ;cX00?o[;WSojNmjOnW_NT01_nW_NT6ojO0k003
ojJnjonX`N_oZ<7[00KoZ<7[1?nX`>X01?nY`>_o0000ojW0jonY`>/8ojRoj`;oYko[1OnW`>/8ojJo
k1Kooooo00?o0000ooooooooool0:?ooool001gooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0_ooooo`03ojO1k?nX`NcoZ<7/00coZ<7/00?oYl3[ojNojonW_n/06?nW_n/5ojO0j`[o
Yko[1OnW]n@8ojNhi@;oYkWV1OnX[M/8ojR`g@;oZ;CQ1OnZZ]H8ojZ]fP;oZK?O1On^[=H8oj^_f`?o
00001_n][]P6oj^fh@03ok2`f?n/]n7o[;OQ00Ko[;OQ1?nX_>P4ojbih`SoYkgY0_nW`>`5ojJnj`So
Z<7[00GoZ<3ZojW0jonY`>_oZL3[o`000003ojW0j`KoZ;o[00?oZ<3[ojO0jonW`>/01_nW`>/6ojJo
k003ojJojooooooooooo01Gooooo00?o0000ooooooooool09oooool001gooooo0_l0000?ooooo`03
o`000?oooooooooo02_ooooo1OnW`N`:ojS1k0GoYl3[5_nW_n/2ojS0j`OoYl3[1_nW_n/9ojNgi0Ko
YkSU00?oYj[IojR]fonX[M/01_nX[M/6ojR`g@03ojbZeOnZZ]KoZZ[F00KoZZ[F1_nZ[MX00on`[MGo
[ZcFojj/eP06ojj/ePGoZjoK0_l000000onc/=Go[JkHojf^f006ojf^f0CoZkKQ1?n`/=P8ojbgh@03
ojRlj?n/^N?o[;WS00Go[;WS1_nW_NT00on[^nGoY[k[ojJnj`06ojJnj`KoZ<7[0_nW`>/4ojW0j`04
o`000?nY`>_oZL3[ojW0j`;oZ;o[1OnX`>/8ojO0j`;oY[o/1OnV_n/Fooooo`03o`000?oooooooooo
02Oooooo000Mooooo`03o`000?oooooooooo00oooooo0_l0000Xooooo`;oYl3[1onW`N`6ojS1k0;o
Z<3[1onW`>/6ojNoj`;oYkkZ2onW_n/5ojS0j`OoYl3[0_nW_n/=ojNgi0;oYkSU1OnWZ]T7ojR]f`Co
Z;3M1?n/Z]D8ojZZeP?oZZgJ1?n`[MD8ojj/eP04oj^_fol0003o0000o`0000Co/k3E2?n][]P00on[
]^7o/;3Hok2`f005ok2`f0Ko[;OQ00?o/K?Iojbihon/^N<01on/^N<2ojNmj@GoZk_U2?nV_^/2ojS1
j`KoYl3[1?nY`>/00ol0003oZL3[ojS1j`08ojS0j`OoYl3[2?nV_n/Fooooo`03o`000?oooooooooo
02Kooooo000Mooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool08_ooool6ojO0j`Oo
Yl7/0_nX`N`6ojS0j`OoYl3[0_nW_n/6ojNnjPSoYko[2?nX`>/5ojO0j`03ojNhiOnW]nCoYkOT00co
YkOT00?oYZWIojNZfOnWZ]T01_nWZ]T7ojR]f`03ojR`gOn/Z]Go[:[E00Go[:[E2?nZZ]H00onZ[M[o
/:gEok2]e@04ok2]e@Go[ZcF0ol000000on[[m_o/k3Eok>`e@05ok>`e@Ko[JkH00?o][?Fok2`f?n`
/=P01on`/=P2ojbgh@Go/K?I1on/^N<00on`]=coZk_Uoj^ki@06oj^ki@KoY[k[0_nX_NP8ojO0j`;o
ZL3[0_nX`N/00ol0003oZ<7[ojS1j`08ojS0j`OoYl3[2?nV_n/Fooooo`03o`000?oooooooooo02Go
oooo000Mooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool07_ooool2ojNoj`SoYl3[
1OnW`N`2ojS1j`SoZ<3[1OnW`>/2ojNoj`SoYkkZ1OnW_n/3ojS1k0SoZ<3[00?oYl3[ojNhiOnW^>D0
0onW^>D;ojNgi0CoYZWI1onWZ]T6ojR]f`03ojZYe_n/Z]Go[:[E00Ko[:[E1onZZ]H00on_[mSo/:gE
ok2]e@05ok2]e@;o[ZcF0ol00002ojj/eP03ok>bf?nc/=Go/k3E00Ko/k3E1?n][]P4okJcePOo/;3H
00?o^;GFok6cfOna/mT01_na/mT4ojbih`Co/;CL2?n[^nD2ojJnj`KoZ;gX1_nW`>/00onV_^_oZ<7[
ojS1j`02ojS1j`04o`000?nX`N_oZ<7[ojS1j`KoZ<3[00?oZL3[ojO0jonW`>/01_nW`>/6ojJoj`03
ojNojooooooooooo01Cooooo0_l0000Vooooo`007?ooool3o`0001Cooooo00?o0000ooooooooool0
6_ooool6ojNoj`SoYl3[00?oYl7/ojS1jonX`N/01?nX`N/8ojS0j`03ojO0jonW_n_oYko[00CoYko[
2?nW_^X00onW_n_oZ<7/ojS1k005ojS1k0KoZ<3[00?oYkWVojNhiOnW^>D01OnW^>D9ojNgi0KoYZWI
1onWZ]T3ojR]f`CoZZWF2?n/Z]D4ojZZePCo[joH1On`[MD3o`0000?o[ZcF1?nc/]P8ok>`e@03ojf^
f?nf/mKo][?F00Go][?F1On`/=P3okReePSo/K?I00?o[;WSok2dg?n`]=`01On`]=`6oj^ki@03ojni
hOnX_NSoZ;gX00OoZ;gX0_nW`>/5ojJnj`CoZ<7[00Co0000ojS1jonX`N_oZ<7[0_nX`>/5ojW0j`So
Yl3[0_nV_n/5ojNojaCooooo00?o0000ooooool000009_ooool001cooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0Gooooo`WoYko[1_nW`>/2ojS1k0OoZ<7[1_nX`>/9ojNoj`KoYkkZ
0_nW`N`8ojS1k0;oZ<3[1OnW^NH7ojNhi@KoYkOT00?oYJSIojJYfOnVZMT01OnVZMT8ojNZf@03ojR]
fonZZMKoZZWF00CoZZWF2?n/Z]D00onZZ]Ko[joHojn_f004ojn_f0;o/:gE0ol00003ok2]e@03ojj/
e_nc/]So/k;H00Go/k;H1_nc/=D00onf^=[o][?FokJceP06okJceP?o/;3H1Onh]MH7ok6cf@03okZg
eon`]=co/;CL00Oo/;CL0_n[^nD5ojnih@OoZ;gX00?o[;gVojJnjonV_^/01_nV_^/4ojS1j`03o`00
0?nX`N_oYl3[00SoZL3[1_nW`>/00onX`>_oYko[ojNoj`06ojNojaKooooo00?o0000ooooooooool0
8oooool000[ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^1_ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo01?ooooo3OnW_n/2ojO0j`KoZ<7/1onX`N/2ojS0
j`goYko[0_nW_^X6ojO1k0KoZ<7/00?oYk_XojNii_nW^NH01_nW^NH7ojNhi@;oYkOT1OnUZ=T7ojJY
f@KoYj[I00?oZJWGojZYe_nZZMH01OnZZMH7ojbZe@03ojjbfon_[mSo[joH00Co[joH0ol00005ok2]
e@03ok:hgOnc/]So/k;H00Ko/k;H1?nc/=D4okJhfPSo][?F00?o/;3HokRee_nh]MH01Onh]MH5ok6c
f@?o^[OG1on`]=`00onh^=Wo[kWQojnih@06ojnih@CoZ;gX1?n/_NH8ojJnj`;oZ<7[00?oYl3[o`00
0?nW`>/00_nW`>/8ojW0j`;oYl3[1OnX`>/8ojNojaGooooo00?o0000ooooooooool08oooool000co
oooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`0?ooooo`ooYko[2_nX`N`5ojS1j`ooYko[0onW`>/7ojO1
k0;oZ<7/1OnW^nP7ojNiiPKoYkSU00?oY:WJojFXfOnUZ=T01_nUZ=T7ojJYf@;oYj[I1OnYZML7ojZY
ePCo[:[E1?n^/]/2ojn_f0?o00000_n_[mP4ok2]e@Co/[SM2?nc/]P00onc/=Go][SJokJhfP05okJh
fPKo][?F00?o^;_KokRee_nh]MH01_nh]MH3ok6cf@Ko^[OG1On`]=`3okRhf@So[kWQ00?oZ;gXojbm
i_n/_NH01On/_NH6ojJnj`03ojRnjOnW`>_oYl3[00;oYl3[00Co0000ojO0jonW`>_oYl3[1onY`>/7
ojS0j`KoYko[0_nW`>/Fooooo`03o`000?oooooooooo02;ooooo00000ooooooo0000o`000004o`00
00Gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Kooooo0_l0000I
ooooo`03o`000?oooooooooo00cooooo3_nW_n/>ojS1k003ojS1jonW_n_oYko[00goYko[1onW`>/5
ojO1k0;oYkgY1onW^nP7ojNiiP;oYkSU1OnTZMX7ojFXf@KoYZWI00?oYjWHojVYeonYZML01_nYZML7
ojZYeP03ojbZeOn^/]_o[[;K00Co[[;K0_l00006ojn_f003ok2]eOnb^=go/[SM00Go/[SM1_nc/]P0
0onda>Ko][SJokJhfP06okJhfPCo][?F1?nh^m/8okReeP03ok6cfOnj]mOo^[OG00Go^[OG0on`]=`6
okRhf@Ko[kWQ00?o];WMojbmi_n/_NH01on/_NH2ojJnj`GoZ;kY1?nW`>/01?l0003oYl3[ojO0jonW
`>/7ojW0j`OoZ<3[0_nW_n/6ojO0jaKooooo00?o0000ooooooooool08Oooool000cooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0:ooooo`goYko[00?oYl3[ojS1k?nX`N`03?nX`N`00onW`>_oYko[ojNo
j`0>ojNoj`SoYl3[00?oYl7/ojNmjOnW_NT01?nW_NT7ojNkj0?oYkWV0onTZm`8ojBYfPOoYJSI0_nV
ZMT5ojNYf0OoZJWG1_nZZMH00on]]^3o[[;Kojjbf`02ojjbf`?o000000?o[[;Kojn_f?n_[mP01?n_
[mP00on`a>Wo/[SMok:hg@06ok:hg@Co/k;H1?nda>H8okJhfP03okJce_nh^m_o^;_K00Go^;_K1_nh
]MH00onj_=_o^[OGokZge`07okZge`03ok2dg?nh^=Wo^;SI00Go^;SI1?n_^N44okBig@Oo[;gV00?o
/;gSojRnjOnX_^T01OnX_^T5ojO0j`03o`000?nV_n_oY[o[00OoZL3[2?nX`>/8ojO0jaGooooo00?o
0000ooooooooool08Oooool000cooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000000Gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`07ooooo`?oYl3[2OnW
_n/5ojO0j`[oZ<7/1OnW`>/@ojNoj`KoYl3[00?oZ;o[ojNmjOnW_NT01_nW_NT5ojNkj003ojB^gonT
ZmcoY:_L00GoY:_L1onTZMX7ojFXf@SoYjWH1onYZML2ojZYePGo[KKP0ol00005ojjbf`;o[joH1On`
a>T8ok:hg@03ok>bf?nda>Ko]<CV00Go]<CV1_nf^=X00ondc>_o^;_KokRkf`06okRkf`Co^;GF1?nj
_=/7okZge`03okblf_nh^=Wo^;SI00Oo^;SI00?o[kWQokBigOnd^Md01Ond^Md4ojbmiPCo/;gS1onX
_^T2ojO0j`;oY[o[00Co0000ojJojonV_n_oY[o[1onY`>/8ojS0j`OoYl3[5_ooool00ol0003ooooo
ooooo`0Pooooo`003?ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100
1Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00?ooooo1onW`>/7ojNoj`OoYl3[
1_nX`N`2ojS1j`OoYl3[1_nW_n/2ojNnj`SoYko[0_nW`>/5ojRoj`SoYkgY00?oYk_XojB^gonT[]l0
0onT[]l7ojB[g0OoY:WJ1onUZ=T7ojNYf0KoZJWG00?oZk[Uojffh?n]]^000_n]]^03o`000003ojff
h?n^/]_o[[;K00Co[[;K00?oZm?eok34jOn`a>T01_n`a>T6ok:hg@03oj_Hmonda>Ko]<CV00Ko]<CV
1?nf^=X4okC<j`So^;_K00?o^;GFokZlfonj_=/01Onj_=/4okZge`Co_;cJ1onh^=T00onm_=Wo];WM
okBig@07okBig@03ojbmi_n`_N?o/;gS00Co/;gS1_nX_^T00on[_nSoY[o[ojJoj`03ojJoj`03o`00
0?nV_n_oY[o[00KoZL3[0_nY`N/8ojS0j`OoYl3[5_ooool00ol0003oooooooooo`0Oooooo`003?oo
ool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2o`0001kooooo
00?o0000oooooonX`>/00_nX`>/8ojO0j`OoYko[1onW`>/2ojS1k0KoZ<7[1onW`>/2ojNoj`KoYkk[
1_nW_n/2ojS1j`OoZ;o[1_nW_NT00onT/n?oY:kOojB^g`05ojB^g`OoY:_L1OnTZMX00onSYmWoYJSI
ojFXf@05ojFXf@SoYjWH0_nYZML5oj^ji@?o00001?n]]^04ojjbf`CoZm?e2?n`a>T2ok:hg@GoZmSg
2?nda>H00onf^=[o]<c[okC<j`05okC<j`Ko^;_K00?o]Lg/okZlfonj_=/01onj_=/00onj]mOo_;cJ
okblfP05okblfPGo^;SI0onm_=T7okBig@03ok^mfon`_N?o/;gS00Ko/;gS0_nX_^T5oj^oj0GoY[o[
00?o0000ojJojonV_n/00_nY`>/6ojW1j`OoZ<3[2?nW`>/Eooooo`03o`000?oooooooooo01oooooo
000:ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`00
0?oooooooooo01cooooo1onX`>/6ojO0j`WoYko[1OnW`>/:ojS1j`GoYl3[0onW_n/7ojNnj`;oYko[
1_nX`N/7ojRoj`;oYkgY1OnT/n<6ojB^g`SoY:_L00?oY:WJoj>WfOnSYmT00onSYmT7ojFXf@KoYjWH
00?oZKgXoj^jiOn[^^D00_n[^^D3o`000003oj^jiOn]]^3o[KKP00Go[KKP00?o[[;Koj_CmOn[doD0
1On[doD6ok34j@;oS]gn1on[f?L6okC4iP;oVm_m1ondc>/4okRkf`Co]Lg/1onj_=/00onhb>Oo_;cJ
okblfP06okblfP?o^;SI1_nm_=T4okBig@Co^kgK1_n`_N<00ond_N7oZkoXoj^oj006oj^oj0GoY[o[
00?o0000ojJojonV_n/02?nY`N/7ojS0j`SoYl3[5Oooool00ol0003oooooooooo`0Nooooo`006ooo
ool00ol0003oooooooooo`0Jooooo`?oZ<7[1onX`>/2ojO0j`goYko[00?oYl3[ojS1jonX`N/03?nX
`N/00onW`>_oYko[ojNoj`05ojNoj`GoYkk[0_nW`>`8ojS1j`GoZ;o[00?oYKOVojBchonT/n<01_nT
/n<6ojB^g`KoY:_L00?oX:GIoj>WfOnSYmT01OnSYmT6ojFXf@CoYjWH1?nY_NP3o`0000CoZk[U1_n]
]^03oj7Mo0OoZm?e0_n`a>T6ohkMoPOoZmSg0_nda>H6oi_Ko@Oo]<c[00?o^;_KokG=k?necN`01One
cN`4okZlf`Co^<SW2?nl_=X00onh^=Wo_KcIokflf@06okflf@03okBigOnk_M_o^kgK00Co^kgK1?n`
_N<4okBmh@SoZkoX1?nV_n/01?l0003oY[o[ojJojonV_n/6ojW1j`WoZ<3[1onW`>/Fooooo`03o`00
0?oooooooooo01gooooo000Kooooo`03o`000?oooooooooo01Oooooo1onX`N/5ojS0j`;oYl3[3OnW
_n/?ojS1j`[oYko[00?oYkk[ojO0k?nW`>`01?nW`>`8ojS1j`03ojRojonU]nKoYKOV00?oYKOV1onT
/n<7ojB^g`;oY:_L1OnPYMT6oj>Wf@OoYJSI00CoYjWHojVmj?nY_NSoZKgX0ol000000onY_NSoZk[U
oj^ji@05oj^ji@;o[KKP1onQgO`3oj_Cm@GoL]Wi1on>gOh3oj_Hm`GoJM7j1onKfod3okC<j`CoTMOn
2?necN`00onj_=_o^<SWokS8i`05okS8i`Ko_;cJ00?o^l?PokflfOnm_=T01_nm_=T00onn`M_o^kgK
ok^mf`06ok^mf`03ok2mhond_N7o];gQ00Go];gQ1_n[_nP2ojg0i`CoY[o[00Co0000ojJojonV_n_o
Y[o[0_nY`N/=ojS0j`OoYl3[5?ooool2o`0001oooooo000Kooooo`;o00005_ooool3ojO0j`OoZ<7[
00?oZ<3[ojO0jonW`>/01?nW`>/9ojNoj`ooZ<7[3_nW_n/7ojO0k0KoZ<7[00?oY[_XojFgi_nU]nH0
1OnU]nH7ojBch`?oY:kO0onNY=T8oj2Uf@KoXjOI1OnUZ=T3ojNlj@;o00001?nY_NP6oj^ji@?oUn3n
1_nQgO`4ofSHlPKoL]Wi0on>gOh6oe38kPKoJM7j0onKfod5oeK6m`KoTMOn1_necN`00onFe?go^<SW
okS8i`06okS8i`Co_;cJ1?nk`n06okflf@?o_/7K1_nk_M/00oo0`=[o];gQokBmh@07okBmh@;oZkoX
1_n]`>L4ojJoj`03o`000?nV_n_oYko[00ooZ<3[1onW`>/Fooooo`03o`000?oooooooooo01cooooo
000Jooooo`03o`000?oooooooooo01?ooooo1onW`>/5ojS1j`WoYl3[1onW_n/=ojS1j`?oZ<3[3onW
_n/7ojO0k0;oZ<7[1OnV^nP7ojFgiPGoY;?S00?oWJCJoijTfOnNY=T01OnNY=T7oj2Uf@OoXjOI00Co
YJSIojNljOnW_>WoYkcY0ol000000onW_>WoZKgXojVmj004ojVmj0;oZk[U1onGh?h2oj7Mo0GoJ=Sb
1_m]do/3oe;9k`CoQ<?l1omO`o`6od6kk`KoE/Kg1_nAeoh2okG=k0GoU]Cm2?nhb>L00onl_=[o^l?P
ok_3h005ok_3h0?o_KcI1Onn`M/5ok^mf`?o`<3J1ond_N400oni`=oo[L3Wojg0i`07ojg0i`;oY[o[
0_nW_n/00ol0003oYko[ojNoj`0?ojS0j`OoYl3[5Oooool00ol0003oooooooooo`0Looooo`006_oo
ool00ol0003oooooooooo`0?ooooo`CoYko[2?nW`>/00onX`N_oYl3[ojO0j`0;ojO0j`OoYko[2OnX
`N/7ojS0j`GoYko[0_nW_^/8ojNoj`GoYl3/0_nW_nX7ojJkj0OoYKOV00?oY;?SoifTf_nMY=X00onM
Y=X7oijTf@OoX:GI0onSYmT4ojFhi`?o00001OnW_>T3ojVmj0GoU>;m1?nGh?h5of_Jk`?oQ]So1_m]
do/2oi_2l`SoQ<?l0omO`o`3oi6lm0OoJ;Wm1_lk/_86oe;0n0KoU]Cm1_nhb>L00onVd_Oo^l?Pok_3
h007ok_3h003okflfOnn`M_o_/7K00Co_/7K0onk_M/6ol30fPCo];gQ1?ni`=l7ojg0i`03ojo1ionW
_n_oYko[00;oYko[00?o0000ojNojonW_n/03onX`>/8ojO0jaGooooo00?o0000ooooooooool06ooo
ool001[ooooo00?o0000ooooooooool02oooool9ojNoj`KoYl3[00?oZ<3[ojO0jonW`>/02onW`>/9
ojNoj`WoZ<7[1onX`>/00onW_n_oYkk[ojNnj`04ojNnj`SoYko[00?oYl3/ojNoj_nW_nX01?nW_nX7
ojJkj0?oYKOV0onOZ=d7oifTfPKoWZCI1_nPYMT00onS/^CoYKSWojFhi`02ojFhi`?o000000?oYKSW
ojNljOnW_>T01?nW_>T3oiWSo@KoU>;m1?mfh?02of_Jk`OoQ]So0_m]do/6oi_2l`KoQ<?l0_nR^>P6
oi6lm0OoJ;Wm1_lk/_86oe;0n0KoU]Cm0_nhb>L5ojKBm`Oo^l?P00?o]/_Zokk1fonn`M/01_nn`M/0
0onk_M_o`<3Jol30fP06ol30fP03okBmhOni`=oo^L3O00Go^L3O1?n]`>L4ojo1i`CoYko[00?o0000
ojNojonW_n/03onX`>/8ojO0jaGooooo00?o0000ooooooooool01_ooool5o`0000oooooo000Joooo
o`;o00002Oooool=ojNoj`;oYl3[1OnX`>/9ojO0j`goYko[2OnX`N/5ojS0j`;oYko[1onW_^/6ojNo
j`03ojS1jonW_n[oYkoZ00KoYkoZ1OnV^nP00onQ/>;oWjSMoinXg@05oinXg@KoWJCJ1onNY=T2oj2U
f@GoXk;T0ol00005ojFhi`;oYkcY1onIhod2oiCRo@CoM^3`1_nFf_h3ohKHo`CoXko]2?nK`_<2ohC3
o0KoX[SX1_nA_?@3ofRio@GoUK[`1omS/O/5ocV/l`GoG/3m1onVd_L4ok_3h0Co]/_Z1_nn`M/00onm
a=oo`<3Jol30fP06ol30fP03ol73foni`=oo^L3O00Oo^L3O00?o[L3Wojo1ion_`NL01?n_`NL5ojNo
j`03o`000?nX`>_oZ<3[00ooZ<3[2?nW`>/Dooooo`03o`000?oooooooooo00Kooooo00GoV9RHob4Q
8Oo^k^koooooodA4A00?ooooo`006_ooool00ol0003oooooooooo`06ooooo`;oYl3[3?nW_n/9ojS0
j`KoYl3[3_nW_n/;ojS1j`03ojS0jonW_n_oYko[00CoYko[1onW_^/2ojNoj`GoZ<7[2?nW_nX00onV
^nSoXK3Roj6`hP03oj6`hPOoWjSM1_nMY=X5oijTf@03oin]hOnS/^CoXk;T00;oXk;T0ol000000onS
/^CoYKSWojFhi`04ojFhi`?oWn?l1_nIhod3oh;VlP?oX=gl1_nFf_h2ojJmjPOoXko]1_nK`_<00onW
]>;oX[SXoj:hj007oj:hj0?oTKcd0onU]N@8oiFjl0?oHk7k1?n>]o83oe:Yn@;o>Jcc1OmN`?d7ojKB
m`03ok_3h?nfbn[o]/_Z00Go]/_Z0onn`M/4okg4g`Ko`<3J0oo1`m/7okW0g`;o_L?O1on_`NL2ojNo
j`;oZ<3[00?o0000ojS0jonX`>/04?nX`>/7ojO0jaGooooo00?o0000ooooooooool01_ooool00onH
V9So8B4Qonk^kP0@ooooo`006_ooool00ol0003oooooooooo`03ooooo`KoYl3[2?nW_n/=ojS0j`;o
Yl3[3_nW_n/=ojS1j`03ojO0jonW_n_oYko[00KoYko[1OnW_^/3ojO0j`KoZ<7[1_nW_nX00onS]nOo
XK3Roj6`hP05oj6`hPKoWjSM1onMY=X00onNY=WoWjgQoin]h@03oin]h@?o00001?nS/^@4ojFhi`Ko
Wn?l0_nIhod3oh;VlPSoX=gl00?oU][nojJmj_nV_NX01?nV_NX7oj>ok@;oVl;c1OnW]>87oj:hj003
ojbdg_nU]NCoYKGT00GoYKGT1_nE^_000onV]^CoS[ObohjglP06ohjglPKoDZWi0_m1[?L2oek0o@?o
Y];g1?mma_h8okK;jP03okk1fonma=oo_LCO00Co_LCO0oo0`=X6ol73f`Co^L3O1Onm`ml5ojo1i`03
ok72ionX`>_oZ<3[00?oZ<3[00?o0000ojS0jonX`>/01_nX`>/2ojO0j`SoZ<3[1onW`>/Eooooo`03
o`000?oooooooooo00Kooooo00?oV9RHob4Q8Oo^k^h03oooool001[ooooo00?o0000ooooooooool0
2_nW`>/7ojNoj`coZ<3[0onW`>/;ojNoj`CoYl3[2OnX`N/5ojO0j`SoYko[00?oYkk[ojO0jonW`>/0
1OnW`>/6ojS1j`;oYkoZ1OnS]nL7oj6`hPKoWjSM0onMY=X3oibWgP?oWjgQ0ol000000onO[N7oXk;T
oj>bi005oj>bi003ojFhionOhocoWn?l00GoWn?l1?n?jo@3ojOSn`KoX=gl00?oYkgYojJmj_nV_NX0
1_nV_NX5oj>ok@03ojVbgonW]>;oYkCR00KoYkCR1?nR^>P4ojbdgPOoYKGT0_nE^_05ojJfi0SoS[Ob
1_mBZOT5od6/m`KoOLKn1_nfbnX00onTboCo_LCOokg4g`06okg4g`03ol30f_o1`m_o`L?K00Ko`L?K
00?o^L3Ookg3gonm`ml01_nm`ml00on_`NOo/L;Wok72i`03ok72i`GoZ<3[00?o0000ojS0jonX`>/0
0_nX`>/6ojO0j`KoZ<3[00?oZ<7[ojO0jonW`>/01OnW`>/Eooooo`03o`000?oooooooooo00Oooooo
00?oMgMgofIVI_ooool03_ooool001Wooooo00?o0000ojO0jonW`>/03?nW`>/7ojNoj`SoZ<3[1onW
`>/7ojNoj`SoYl3[1onX`N/7ojO0j`KoYko[0_nV_^/8ojO0j`?oZ<7[0onV_>T7oj>gi`OoXK3R0onO
Z=d2oiVTg0KoW:ON0ol00005oin]h@GoXk;T1?nTgO/2oioSo0CoSn_d1onWho/2oj3Mo0GoYkgY2?nV
_NX00onS_ngoZK;OojVbg`03ojVbg`SoYkCR00?oX[SXojbdg_n/]=h01On/]=h5ojFei003ok2hgonV
]^CoY[KT00KoY[KT1_n>]o82oj:hj0OoN;3f0_lnX_D2od6/m`KoOLKn0_nfbnX5ojC;m0Ko_LCO00?o
^/KTol73foo1`m/01_o1`m/00oo2aMgo_L?Ookg3g`06okg3g`03oko6gona`^Oo/L;W00Go/L;W1OnX
`>/00ol0003oZ<3[ojS0j`08ojO0j`;oZ<3[1OnX`N/7ojO0jaGooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0=ooooo`006Oooool00ol0003oYl3[ojO0j`0;ojO0j`WoYko[2?nX`>/7
ojO0j`OoYko[2?nW`>/7ojS1j`OoYl3[0_nW_n/6ojJnj`KoYl3[00?oZ<3[ojJljOnV_>T01OnV_>T7
oj>gi`?oXK3R0onHXmd6oiVTg0?oW:ON0_l00002oibWgPOoWjgQ00?oXk;TojCMnonTgO/01OnTgO/3
oic^mP?oZn_i1_nWho/00onY`N_oYkgYojNmj@06ojNmj@KoY[gZ00?oZ;7NojVbgonY/]l01OnY/]l6
ojNdhP03ojjhh?n/]=ko[;CN00Ko[;CN0onU]N@4ok2hg`SoY[KT0_n>]o86oj:hj0OoN;3f1?lnX_D5
oebdo0OoY<_d1?nma=l4ok[6i0Ko`L?K0oo2aMd6okg3g`?o_lKO1ona`^L4ojS0j`04o`000?nX`>_o
Z<3[ojS0j`OoYl3[1onX`N/8ojO0ja?ooooo0ol00004ooooo`05o`000?nj^[[ooooooiRHV?l@4100
3oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?ooooooYl3[00SoYl3[
3OnW_n/8ojS0j`GoYl3[2OnW_n/6ojO0j`WoZ<7[1OnW`>/3ojNoj`OoY[k[0_nW`>/5ojS0j`OoY[cY
1OnS]nL00onKZ>3oV:?MoiRSg@05oiRSg@GoVJCL0ol00005oibWgP?oWjgQ1_nTdOL2ojCMn`CoW>kf
1on[joT00onWho_oZL7[ojW1j`03ojW1j`SoYkgY0_nV_NX5ojRagPOoZK;O0_nW]>85ojjhh0So[;CN
00?oYKGTok2hgon`^=l01?n`^=l6ojJfi003ok6jh?nR^>SoX[SX00OoX[SX0omh/?H3oi>hl0CoDZ7f
00?o?Z;eoebdo?mL]?`00omL]?`7ojC;m003okg4gonja^Co^/KT00Go^/KT0oo1`m/6ol;5g@?o_L?O
1Onoa]l6ok72i`;o//CX1?nX`>/01?l0003oZ<3[ojS0jonX`>/7ojO0j`OoZ<7[2?nW`>/Dooooo`03
o`000?oooooooooo00;ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00?ooooo`003_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool02?nW`>/<ojNoj`[oZ<3[00?oYl3[ojNo
jonW_n/02onW_n/2ojO0j`goZ<7[00?oYl3[ojNojonW_n/01OnW_n/5ojJnj`;oZ<7[1onX`>/7ojJl
j@03oj>gionKZ>3oVjSP00?oVjSP1_nHXmd2oiVTg0?o000000?oVJCLoibWg_nLYmh01?nLYmh2oj;0
kPOoY=7g1?nXk_P2oic^mPOoZn_i0_n/b>h6ojW1j`KoYkgY00?oYk3OojRag_nX/Mh01_nX/Mh5ojVb
g`03ojfjhon^^>3o[[SP00Ko[[SP1_n/]=h00onb_^?o/;SOok2hg`06ok2hg`;oY[KT1Ona^^07oj:h
j003ojfki?nC^?3oTkS`00GoTkS`1OmBXOH3odfVn0;oG;Cl0onTbo@3ohg2n@Wo^/KT00?o`L?Kol;5
gOo2aMd01_o2aMd00onm`moo_lKOoko6g`05oko6g`;o/L;W1_nba>P4ojS0j`03o`000?nX`>_oZ<7[
00OoYl3[2?nX`N/8ojO0jaCooooo00?o0000ooooooooool05Oooool000kooooo00Go410@oooooooo
oooooooooa0@4006ooooo`;o00000_ooool8ojO0j`SoYko[3?nX`>/2ojO0j`coYko[0onW`>/<ojS1
j`?oYl3[1onW_n/00onV_^_oZ<7[ojS1j`04ojS1j`OoZ<3[0onV_>T3oj2ciPOoVjSP1?nHXmd3o`00
00GoVJCL0_nLYmh6oj;0kPCoY=7g1_nXk_P4ojoamP;oZn_i1_n/b>h6ojW1j`;oYkgY1OnW/=l8ojRa
gP03ojVbgon]^^?o[K[S00?o[K[S2?n^^>02ojbdgPGo/[kS1_n`^=l00onc`>Co/K[Pok6jh006ok6j
h0CoX[SX1?n]^n@7oi>hl0GoDZ7f1Om=Y_P6ohg2n@Oo^/KT00?o]LOXol;5gOo2aMd01_o2aMd00oo1
amoo_lKOoko6g`05oko6g`03ol79h?nba>So//CX00Oo//CX0_nX`>/2ojS1j`03o`000?nX`N_oZ<7[
00OoYl3[2?nX`N/7ojO0jaGooooo00?o0000ooooooooool05?ooool000kooooo00Go0000oooooooo
ooooooooo`000006ooooo`03o`000?oooooooooo00?ooooo1onW`>/8ojNoj`SoZ<3[1_nW`>/8ojNo
j`OoYl3[2?nX`N/7ojO0j`GoYko[0_nV_n/7ojS1j`GoZ<3[0_nT^^T6oj2ciPKoVjSP00CoV:?Mo`00
0?l0003o00000_nHXmd5oiVTg0;oWK3U2?nR`>h00onTdOOoZ>khojS^n004ojS^n0Go[o7f0_nbdo48
ojc8kP?oZL7[0_nU/>08ojN`g`KoZ;7N00?oZ[_Vojfjhon]^^<01On]^^<6ojjhh003oj^nionb_^?o
/[kS00Ko/[kS0on`^=l4ok?0i0So/K[P00?oX[SXojfki?n]^n@01On]^n@5oi>hl003oj2jk?mXYoGo
J:Oe00;oJ:Oe0_mBXOH5odfVn0KoSL;i1?nja^@4okG7j0Ko`/GM0oo1aml5oko6g`?o`LWP1onba>P0
0onbaNSoZ<7[ojS1j`02ojS1j`03o`000?nX`N_oZ<7[00KoYl3[0_nX`>/8ojS1j`OoYl3[5?ooool0
0ol0003oooooooooo`0Dooooo`003_ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000
ooooooooool01Oooool5ojO0j`[oYko[1onX`>/7ojO0j`SoYko[1onW`>/3ojS1j`CoZ<3[2?nW`>/0
0onW_n_oY[o[ojJoj`04ojJoj`OoZ<7[00?oZ<3[ojBjjOnT^^T01?nT^^T6oj2ciP?oVjSP0ol00006
oiRSg@03oiVTg?nM/>GoWK3U00CoWK3U1_nR`>h4ojoWn@;oZ>kh1On_lOH5ok;Cl@Ko[<S^00?oYK?R
ojF`h?nU/>001?nU/>08ojN`g`;oZ;7N1OnZ^nH7ojfjh`;o[[SP1On[_^L8ok:nh`03ok2hgonc`>Co
/l3T00Co/l3T1_na^^02okK1hPSo[K_T00?oTkS`oj2jk?nP^^`00onP^^`6ofRWm@?oBYge0_m=Y_P6
ohg2n@03ok[6i?neanSo]LOX00Go]LOX0oo2aMd5ol77g`?o_lKO1_o1bN04ok;4j0Co//GX1?nX`N/0
0ol0003oZ<7[ojS1j`02ojO0j`KoZ<3[1onX`N/7ojO0jaGooooo00?o0000ooooooooool04oooool0
00kooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo00Kooooo00?oYl3[
ojNojonW_n/03?nW_n/7ojS0j`OoYl3[2?nW_n/5ojO0j`;oZ<7[1onX`>/6ojO0j`WoY[o[1OnX`N/0
0onW_n_oY;[YojBjj@06ojBjj@GoX;?V0ol00004oi^Xh0?oV:?M0_nHYn48oif`i@?oX/3^1_n_ioT4
okGcm003ojoam_nbdo7o/]?a00Ko/]?a0_n/b>h5ojFchPKoYK3P1_nW/=l00onW^^OoZ[_VojZkiP06
ojZkiPGo[K[S00?oZKkYoj^nion[_^L01_n[_^L6ok:nh`;o[;oX1onc`>@2ok6jh0Ko]/7R1_n]^n@0
0ond_n;oX;[/oj2jk005oj2jk0KoJ:Oe1Om:WOD6ogZen0So]LOX00?o`/GMol77goo1aml01Oo1aml0
0onoa]oo`LWPol79h006ol79h003ok;4j?nbaNSo//GX00Co//GX1OnX`N/00ol0003oZ<3[ojS0j`08
ojS0j`OoZ<7[1onW`>/Eooooo`03o`000?oooooooooo01;ooooo000>ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2o`0000Sooooo3OnW_n/9ojS0j`GoYl3[2_nW_n/00onW`>_oZ<7[ojS1j`04
ojS1j`OoZ<3[0_nW`>/=ojJoj`03ojS1jonW_n_oYko[00?oYko[2?nT^^T01OnP/nKo0000o`000?l0
003oX;?V00?oVjSP0onDXml6oiRWh@SoWK3U00?oX/3^ojoWnOn_ioT00on_ioT5okGcm0?o_>Gc1_nb
do400onW^^OoYK?RojFchP06ojFchPKoYK3P0_nW/=l5ojNji`SoZ[_V00?o[K[SojVnjOnY_^T00onY
_^T8oj^ni`;o/[kS1_n/_nP5ok?0i003ojg0j?nf`N;o]/7R00Oo]/7R0_n]^n@5okBohPOoX;[/1_mX
YoD5odZMm@KoN[Gh1_neanP2ojo5jPKo`LOO2Oo1bN000oo2bn;o//GXok;5j006ok;5j0;oZ<7[0_nX
`>/00ol0003oZ<3[ojS0j`08ojS0j`OoZ<7[1onW`>/Eooooo`03o`000?oooooooooo01;ooooo000>
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`08ooooo`WoYko[3OnX
`>/00onW`>_oYko[ojNoj`0:ojNoj`;oYl3[1onX`N/5ojS0j`?oYl3[3?nV_n/2ojS1j`KoYko[1_nT
^^T2o`0000CoTjCP1onDXml6oiRWh@KoWK3U1?n]f?H00on_ioWo]O?dokGcm003okGcm0Oo_>Gc00?o
/]?aojNjionW^^L00onW^^L7ojFchPGoYK3P0_nU^>H7ojNji`KoZ[_V00?oZ;kYojVnjOnY_^T01OnY
_^T6oj^ni`;oZKoY2?n/_nP00onc`>Co[L3Xojg0j003ojg0j0Oo]/7R00?o/l;UokBoh_nd_n801_nd
_n83oj2jk0CoYkgZ1_mh[?<3odjIlP;oBYge1_mj]OP2okG7j0Ko[lGZ0oo1aml9ol79h0Co`/_R1_nb
aNP2ok76j@CoZ<3[00?o0000ojS0jonX`>/02?nX`>/7ojS1j`OoYl3[5Oooool00ol0003ooooooooo
o`0Aooooo`006?ooool00ol0003oooooooooo`09ooooo`SoYko[2_nX`>/4ojO0j`WoYko[1_nW`>/7
ojS1j`03ojS0jonW`>_oYl3[00GoYl3[2?nV_n/6ojS1j`KoYko[0_nT^^T3o`0000;oW;3V1OnCY>07
oiBSg`KoV:OQ0_nM/>D6ojgHmPCo^^kd0_nelo@7okcUl`03ojg6k?nW^^OoYk[W00GoYk[W1onU/n80
0onU/>3oYKSVojFhiP04ojFhiPOoYk[W0_nZ^nH5ojRnj@OoZKkY0_n[_^L6ojVoj@Ko[;oX00?oZKoZ
ojg0j?n]`>P01On]`>P4okK1hPCo/l;U1_nd_n800ong`^?oYkgZojNmjP06ojNmjPKoN:cc1Om>VO86
og6/mPSo[lGZ00?o`LOOol79h?o1bN001_o1bN07ol;;hP;o//GX1_naa^T4ojS0j`03o`000?nX`>_o
Yl3/00OoZ<3[1onX`N/8ojO0jaGooooo00?o0000ooooooooool04?ooool001Sooooo00?o0000oooo
ooooool02_ooool8ojNoj`OoZ<3[1onW`>/7ojNoj`SoYl3[1OnX`N/3ojS0j`OoYl3[1onV_n/7ojS1
j`?oYko[00CoX[WYo`000?l0003o00001_nL/>H5oi>Th0OoU:?O0onHYn44oj6mk@Co[MSf1_njk_@4
ol;`l@;o_>Gc1On]a^`7ojNji`?oYK?R0onR/nD8ojFhiPGoYk[W00?oYkkZojRnjOnX_^T01_nX_^T5
ojVnj@;oZ;kY2?nY_nT2ojboj0GoZKoZ1on]`>P00onf`N;o/l;Uok?2i@05ok?2i@?o];oR1?ng`^<8
ojNmjPKoN:cc1Om>VO86og6/mPKo[lGZ00?o[<;Zol79h?o1bN001Oo1bN02ol;;h@Ko`/_R0_o1c^@8
ok76j@;oZ<3[0_nW`>`00ol0003oYl3/ojO0k007ojS0j`OoZ<7[1_nW`>/00onW_n_oooooooooo`0C
ooooo`;o00004Oooool001Oooooo0ol0000=ooooo`OoYko[1onX`>/7ojO0j`OoYko[2?nW`>/00onX
`N_oZ<3[ojS0j`05ojS0j`GoYl3[2OnV_n/5ojS1j`;oYko[0ol00003oj:ij@KoW;3V1_nCY>05oiBS
g`03oiR/iOnQ_NgoXKg]00OoXKg]00?o[MSfok[^m?njk_@00onjk_@5ol;`l@?o^MS_1_n]a^`5ojNj
i`;oWjoS1_nR/nD8ojFhiP03ojNjionW_^[oYkkZ00?oYkkZ2?nX_^T00onY_^WoZ;kYojRnj@04ojRn
j@KoZKoY00?oZ;gXojVoj_nY_nX01_nY_nX5ojg0j0;oZl3Y2?nc`^D00ond_n;o]l;SokO2h`04okO2
h`KoYkgZ0_nZ`NX6ogn^lP?oDiO`0_m>VO86og6/mP;o[lGZ1On/`^X5ol79h0Co`/_Q0oo2bn85ol7>
i0Ko/LKY00?o[lGZojO0k?nW`>`00_nW`>`00ol0003oYl3/ojO0k006ojS0j`;oZL7[1onX`N/2ojO0
j`GoYko[4oooool00ol0003oooooo`00000Aooooo`005oooool00ol0003oooooooooo`0>ooooo`Go
Yko[2OnX`>/8ojO0j`KoYko[1_nW`>/2ojS1j`SoZ<3[00?oYl3[ojJojonV_n/02onV_n/00onX`N_o
Yko[ojNoj`03o`000003ojNojonR^NWoX[WY00CoX[WY1_nL/>H6oi>Th003oiBSgonH[>GoV:cU00?o
V:cU1onQ_Nd4okWRm003ok[^m?o2l?7o`_3a00?o`_3a1_nif>l6ojg6k003ojNjionO[n?oWjoS00Co
WjoS1_nR/nD6ojFhiPSoYkkZ1_nX_^T2ojRlj0OoZ;kY0_nY_nT5ojRmj0SoZKoZ00?o[L3Xoj_0jOn[
`>T01?n[`>T6ok?2i@03ok32iong`^?o]l;S00Ko]l;S0_nW_NX6oj[1jPKoOjkb1?mCUo06og6WlPOo
[<;Z0oo1bN07ol;;h@03ol;;h_o1c^Co`LkT00Go`LkT0_naa^T5ojo5jPCoYl3/00?o0000ojO0k?nW
`>`00_nX`>/6ojW1j`GoZ<7[00?oZ<3[ojNojonW_n/01_nW_n/Dooooo`03o`000?oooooooooo00oo
oooo000Gooooo`03o`000?oooooooooo00oooooo00?oYko[ojS0jonX`>/02onX`>/8ojO0j`KoYko[
0_nW`>/6ojS1j`KoZ<3[00?oYl3[ojJojonV_n/02onV_n/01?nX`N_o0000o`000?l00005ojNoj`Ko
X[WY0onL/>H2ohnShPKoTJCR1onH[>D4oj6mk@Go^N;d1?o5k^l2ol;`l@So^MS_0on]a^`2oj6ci@So
WjoS1_nR/nD2ojFhiPcoYkkZ0_nX_^T6ojRlj0GoZ;kY00?oZK[VojRmj?nX_NP01_nX_NP6ojVojP;o
ZKoY1on[`>T2ok?2i@Go/<;W1_ng`^<2okS5i0SoZ/7Z1_mo[_84oe>Gl0KoLJOb1on/`^X00oo1bN3o
`/_Qol;;h@05ol;;h@03ol?=h_o1c^Co`LkT00Go`LkT00?o_loVojo5j_n_aNX01_n_aNX3ojO0k004
ojJok?l0003oY[o/ojJok0SoZL7[00?oZ<7[ojS0jonX`>/00onX`>/8ojNojaCooooo00?o0000oooo
ooooool03_ooool001Oooooo00?o0000ooooooooool04?ooool<ojS0j`[oYl3[0onW_n/4ojO0j`Oo
Z<7[0_nX`>/5ojO0j`WoY[o[00CoZ<7[o`000?l0003o00000_nX`N/7ojNoj`?oX[WY0_nH/>L6ohnS
hPKoTJCR1onH[>D00onQ_Ngo^N;dokWRm004okWRm0GoaNk_0oo8j^d6okWHk`03ojW1jonQ/nGoXK?U
00CoXK?U2?nO[n<3oj:ci@?oY[cY2onW_^X3ojNlj0SoZ;cX00?oZ;kYojVji_nY^^H00onY^^H8ojRm
j0;oZKoZ1_nY_nT5oj_0j@03oj[0j_n``^Oo/<;W00Ko/<;W0ong`^<5okS5i0KoZ/7Z00?oZ/;[oh2]
lOn0[O401?n0[O44oeZDk@03oe>Gl?maYo;oLJOb00?oLJOb1_n/`^X2ojc0j@Ko`/_Q0oo3cN85ol7>
i0?o_loV1_n_aNX00on]aN_oY[o/ojJok003ojJok003o`000?nV_ncoY[o/00OoZL7[1onX`>/6ojNo
j`03ojJojooooooooooo01?ooooo00?o0000ooooooooool03Oooool001Oooooo0_l0000Booooo`So
Z<3[3?nW`>/2ojNoj`OoYl3[2?nX`N/6ojO0j`KoY[o[0ol00006ojS1j`?oYko[0onQ^NX6oiR`i`Ko
Sj?R1_nAY>85oiR/i@?oZ/S_1?nih_@5olG^k`Gob>[]0_nif>l5ojW1j`KoXK?U1_nO[n<00onS^NWo
Y[cYojJlj@05ojJlj@KoYkkZ00?oYkkYojNlj?nW_>P01OnW_>P6ojRlj003ojVki_nY^^KoZK[V00Go
ZK[V1_nX_NP2oj^miPSoZKoY00?oZl3Yoj[0j_nZ`>X00onZ`>X8ok32i`03okO2honhaNCo^<GT00Go
^<GT0_nZ`NX5oj[2j`KoP:ga1?mJU>d4ogBTk`;oLJOb0_n/`^X6ojc0j@?o`/_Q1Oo3cN83ol7>i0Ko
_loV0_n_aNX5ojg5j`CoY[o/00Co0000ojJok?nV_ncoY[o/1onY`N/7ojS0j`;oYko[1OnV_n/Doooo
o`03o`000?oooooooooo00gooooo000Gooooo`03o`000?oooooooooo01;ooooo2?nX`>/8ojO0j`Ko
Yko[1onW`>/8ojS1j`KoYl3[0onV_n/2o`0000?oY[o[1OnX`N/2ojNoj`KoXKWZ1_nH/>L6ohnShPKo
TJCR00?oV:cUoj[8konZb>l01_nZb>l00onih_CoaNk_olG^k`02olG^k`Kob>[]0_nhd^d7ojW1j`Ko
XK?U0_nO[n<5oj>ij@OoY[cY0_nW_^X5ojNnj@OoYkcX0_nX_>P5ojVkiPOoZK[V0_nX_NP6oj^miPKo
ZKoY00?oZ[oYoj[0j_nZ`>X01OnZ`>X6ok32i`03ojk2jOnhaNCo^<GT00Go^<GT0_nib>H6oj[2j`Ko
P:ga1OmJU>d6ogBTk`So[<3Y00?o`/_Qol?=h_o3cN801Oo3cN800oo1c^Co_loVoko?iP04oko?iP03
ok_@jOn]aN_o[LG[00Ko[LG[1?nV_n`00ol0003oY[o/ojJoj`08ojW1j`?oZ<3[0onW`>/8ojJojaCo
oooo00?o0000ooooooooool03?ooool001Oooooo00?o0000ooooooooool04oooool8ojS0j`OoYl3[
1onW_n/5ojO0j`[oZ<7[0onW`>/2ojJoj`?o00001_nV_n/00onX`N_oYko[ojNoj`04ojNoj`KoXKWZ
1OnH/>L7ohnShP?oTJCR0onI[nL7oj[8k`Co`N;_00?oaNk_olSZkOo8j^d00oo8j^d5okSBk@OoZL7[
0onQ/nD2oib`iPSoXkWY1OnV_>T00onW_^[oYkkYojNnj@06ojNnj@GoYkcX00?oYk[WojVki_nY^nH0
1_nY^nH5ojVjiP;o[<7X2?n[_NH2ojVoj@GoZ[oY1onZ`>X2ok32i`Go[/;Y1?nhaN@5okW8iPKoZ/;[
1_n0[O45oeZDk@KoM:C_1_n/`>T00on_`NOo`lgRol?=hP05ol?=hP?oa=3S0onocnH4ok_@j@So[LG[
0_nV_n`2ojJoj`03o`000?nV_n_oY[o[00OoZL7[1onW`>/7ojJojaGooooo00?o0000ooooooooool0
2oooool001Oooooo00?o0000ooooooooool05Oooool7ojS0j`OoYl3[1onW_n/00onW`>_oZ<7[ojS1
j`0:ojS1j`;oYl3[00CoY[o[o`000?l0003o00002?nV_n/2ojS1j`OoYko[1_nQ^NX5oiR`i`?oSj?R
0on>YN@7oiV_i`CoZ/S_1Oo1h^l4olcYj`;ob>[]1onhd^d3ojW1j`?oW;;W1_nL/>H8oj>ij@03ojJl
jOnW_^[oYkkZ00?oYkkZ2?nW_^T00onW_>SoYk[WojNji`03ojNji`SoZK_V00?oZK[Vojc1j?n/`NP0
1?n/`NP6oj^miP03ojk1ionZ_nWoZ[oY00GoZ[oY1_nZ`>X2ojW1jPOo[/;Y00?o^<GTokW8i_nib>H0
1_nib>H3oj[2j`?oY/;]1OmlZ?04of6CjP;oFYC]1_mdY>l2ojc0j@Go[l7W1?o3cN86olC@h`03oko?
i_nkd>Wo^m3Y00Co^m3Y1_n]aN/00on[`ncoY[o[ojJoj`03ojJoj`03o`000?nV_n_oY[o[00OoZL7[
1onW`>/7ojJojaCooooo00?o0000ooooooooool02oooool001Kooooo0ol0000Gooooo`SoZ<3[1_nW
`>/8ojNoj`SoZ<7[0onW`>/3o`0000SoY[o[1_nX`N/7ojNoj`?oXKWZ0_nG/^X6oh^Si0KoSZGT1onI
[nL00onZb>oo`N;_ol7Rk`04ol7Rk`Goc>W[0oo<iNT5okSBk@;oZL;/1_nL/^L6oib`iPKoXkWY0_nV
_^X6ojNnjPKoYkkY00?oYKWWojNjionW^^L01OnW^^L6ojVkiP;oZL?]1on/`NP2oj^miPGo[/7W1onZ
_nT2oj[0jPKoZL7Z1On^`^T2ojk3j@Oo^LSV00?o^<_XojK2kOnV`^d01OnV`^d5ogbXl0GoHI?Z1_mk
Xn`8ojo1i`03ol?=h_o4d>?oa=3S00Goa=3S00?oaM?Uok_@jOnkd>T01_nkd>T2ojg5j`GoZl?/1?nV
_n/00ol0003oY[o[ojNoj`07ojW1j`OoYl3[1onV_n/Eooooo`03o`000?oooooooooo00[ooooo000F
ooooo`03o`000?oooooooooo01Sooooo2?nX`>/6ojO0j`SoYko[1_nX`N/01?nW`>_o0000o`000?l0
0004ojO0j`OoY[o[1onX`N/5ojNoj`03oj6kjonG/^[oUk;Z00CoUk;Z1_n;Xn@6ohjUi0GoVJoW0on`
b^d4ol7Rk`Goc>W[1Oo<iNT00onhd^goZL;/ojW2k004ojW2k0KoW;;W1_nL/>H2oj>ij@KoY[kZ1_nW
_^X2ojNnj@GoYKWW1onW^^L2ojVkiPKoZL?]1On/`NP00onX`nco[/7Wojk1i`06ojk1i`GoZ[oY0_n/
`NT8ojW1jP03ojk2jOn^`nWo[/?Y00Co[/?Y1?nib>H4okS;j0OoY/;]1OmlZ?05of6CjPKoNj?/1_n_
`NL2okG6i`Koa=3S0oo5dnD6ok_@j@03okK<jon[`ncoZl?/00KoZl?/0_nV_n/2ojNoj`03o`000?nW
_n_oYko[00OoZL7[1onW`>/7ojJoja?ooooo0ol0000;ooooo`001?ooool4o`000008oa0@4?oooooo
ooooonk^k_lb<S;o0000oc8b<_o^k^h6ooooo`03o`000?oooooooooo01[ooooo1onX`>/3ojO0j`_o
Yko[0onX`N/3o`0000SoYl3[1onV_n/7ojS1j`03ojNojonQ^n_oXK_[00?oXK_[1_nG/^X6oh^Si0Ko
SZGT00?oVJoWok3:kOn`b^d01_n`b^d00oo1h^ooc>W[olcYj`02olcYj`Koc>GY0_nle>`7ojW2k0Ko
W;;W0onL/>H3oj>kjPSoY[kZ0onW_^X3ojJlj@OoYKWW1OnW^^L2ojO3k@SoZL?]00?o[<7XojS3k?nX
`n`00onX`n`8ojk1i`03ojZojOn/`NWo[<7Y00Co[<7Y1_nY`NX2ojW1j`Oo[/?Y00?o^LSVokS;j?nh
bnP01OnhbnP5ojK2k@03oinmkOmdWncoM9o/00;oM9o/0_mlZ?05of6CjPKoNj?/0on_`NL5okG6i`?o
a=3S1_o5dnD2ok_@j@Go]/c[1_n[`n`2ojS1k0CoYko[00?o0000ojNojonY`N/01OnY`N/2ojS1j`Oo
Yl3[0onV_n/4ojNoj`oooooo0ol00002ooooo`03o`000?oooooooooo00Wooooo0006ooooo`03o`00
0?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo01_o
oooo1OnX`>/00onW`>_oYko[ojNoj`0;ojNoj`04ojS0jol0003o0000o`0000CoZ<7[1_nW`>/2ojNo
j`OoY[o[0onX`N/4ojO0j`KoXK_[1OnG/^X7oh^Si0?oSZGT0onH/>P7ok3:k@CoaMk[00?oc>W[olcU
jOo<iNT00oo<iNT5okcDk0OoZL;/0onL/^L2oiZaj0OoXk_Z1_nV_^X00onV_n_oY[cYojJlj@05ojJl
j@OoYKWW00?oYk[WojO3kOnW`nd01?nW`nd6ojW3k@;oY<C`1_nX`n`6ojk1i`;o[/;X1on/`NT2ojW1
jPKoZL7[1On^`nT2ok34j@So^<_X00?oY/;]oinmkOnO_Nd00onO_Nd5ogBOk0CoJY?W0_mQTnX6og^S
k003ojo1ionea^Oo]LKW00Go]LKW00?oa=3SolGCiOo5dnD01?o5dnD2olGFi`Oo]/c[0_n[`n`6ojS1
k0?oYko[00?o0000ojNojonW_n/00_nY`N/6ojS1j`GoYl3[2OnW_n/;ooooo`?o00001Oooool00ol0
003oooooooooo`09ooooo`001_ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooooooo
ool@41001_ooool2o`0001gooooo00?oZ<3[ojO0jonW`>/00onW`>/9ojNoj`04ojS0jol0003o0000
o`0000;oZ<3[1_nX`N/2ojO0j`KoYko[1OnV_n/2ojRoj`OoYl3[1_nQ^n/5oiNbjP?oRj?T0on;Y>H7
oiR`j0Co/<[]1Oo5g^/4oloRiP;oc>GY1onle>`3ojW2k0?oVkK[1_nJ/NP7oj>kjP;oY[kZ1OnV_n/7
ojJlj@?oYKWW1?nV_^/7ojO3k@;oZL?]1_nTa?06ojS3k0;o[/7W1_n^`^P5ojc1j@;o[<?[2?nY`N/0
0on^`nWo/<CYok34j@04ok34j@Ko^<_X00?o]/c[oinmkOnO_Nd01OnO_Nd5ogBOk0GoJY?W1_n6Y^X7
okG6i`;o^l_W1Oo5dnD4olGFi`Go]/c[0_nabN`8ojS1k0?oYko[00?o0000ojS1jonX`N/02?nX`N/0
0onW`>_oYko[ojNoj`0;ojNoj`Kooooo1?l00008ooooo`03o`000?oooooooooo00Wooooo0006oooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000005ooooo`;o00007oooool6
ojO0j`OoYko[0_l00006ojS0j`?oZ<7[1?nX`>/7ojNoj`03ojJojonX_n_oZ;o[00CoZ;o[1onW`>/3
oj6kj`?oVKK[1On8YNL6oh^TiPOoV;3X00?o/<[]olGNjoo5g^/01?o5g^/5oloRiP;od>3T1_nle>`0
0on]a^coVkK[oi^fj`05oi^fj`KoV[7X1OnS^nX3ojFnj`KoY[o[1OnV_>T00onS^^WoY[k[ojJnj`06
ojJnj`GoYl?]0_nWaNl8ojC4l0?oZ<?/0onT_n`8ojk2j003ojc1jOn/`n_o[<?[00Co[<?[1_nY`N/0
0onZ`N_o/<CYok34j@06ok34j@;o^<_X1Onfc>/7oinmk@GoM9o/1OmZTnL6ohJVjPCo]LKW1OnkbnL3
olGCi@KoaMKW00?o]/c[ok79k?nabN`01?nabN`6ojS1k003ojJojonX`N_oZ<7[00;oZ<7[00?o0000
ojS1jonX`N/01_nX`N/00onX`>_oYko[ojNoj`0<ojNoj`?ooooo0ol0000=ooooo`03o`000?oooooo
oooo00Sooooo0006ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000005
ooooo`03o`000?oooooooooo01oooooo1_nW`>/3ojNoj`?o00000_nW_n/5ojS0j`;oZ<7[1onX`>/5
ojNoj`?oY[o[1_nX_n/5ojO0j`;oXkg/1_nI]^/5ohRUi`KoRjCV1OnH/>P3ojo5jPCoaMk[1Oo?h^H4
om3Pi0?o_=C/1?n]a^`7oi^fj`KoV[7X00?oXk_ZojFnjonU_^/01OnU_^/6ojJoj`03ojJljOnS^^Wo
Xk[Y00?oXk[Y2?nV_^/00onW`ngoYlG_ojO5k`04ojO5k`KoY<C`00?oXKg]ojBok?nT_n`01OnT_n`6
ojk2j0;o[/CZ1on/`n/2ojW1j`GoZ/7[1_n`a>T2okC7j@Oo]/c[0onO_Nd3oiFck0CoL9?T0_mdWn`5
ofZCi`KoQZKZ00?o]LKWok_;ionkbnL01_nkbnL00oo5dnGoaMKWolGFi`04olGFi`03ol7GjonabNco
/LW/00Ko/LW/0_nX`N`5ojJoj`CoZ<7[00?o0000ojS1jonX`N/00_nX`N/5ojS0j`koYko[0_l0000@
ooooo`03o`000?oooooooooo00Sooooo0006ooooo`03o`000?oooooooooo00;ooooo00Go410@oooo
oooooooooooooa0@4005ooooo`03o`000?oooooooooo023ooooo0onW`>/2ojNoj`?o00001_nW_n/0
0onX`>_oZ<7[ojS1j`04ojS1j`OoZ<3[00?oYko[ojJojonV_n/01OnV_n/6ojRoj`03ojO0jonS_Nco
Xkg/00CoXkg/1_nI]^/5ohRUi`KoRjCV00?oV;3Xojo5j_n_aNX01_n_aNX00oo5g^_ocn;VoloRiP02
oloRiPOod>3T00?o_=C/ojg6k?n]a^`01?n]a^`7oi^fj`?oV[7X0onR^^/8ojFnj`?oY[o[0onS_N/6
oj>jj@KoY[k[0_nZ`n`7ojO5k`;oY<C`1OnQ_Nd7ojBok0;o[/;X1_n^a>X5ojc3j`;oZ/;[1_nZ`N/4
ok34j@Go]<OY1Onfc>/2ojk8k@KoUK?/1Om`Tn@4ogBEi0;oJY?W0on6Y^X3oiF]i`Oo^l_W0_o0dNL4
olGFi`Co`MO[1_nabN`00on/aNcoY[o[ojJoj`05ojJoj`CoZ<7[00?o0000ojS1jonY`N/02?nX`>/3
ojNoj`?oY[o[2?nW_n/Aooooo`03o`000?oooooooooo00Sooooo0006ooooo`03o`000?oooooooooo
00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o00008_ooool01?nW_n_o0000o`000?l0
0008ojNoj`?oYl3[1_nX`N/5ojS0j`?oYl3[1onV_n/3ojRoj`?oZ<7[1onS_N`6oiVfj`GoR:GW0on;
Y>H3oi>]j0Oo[lGZ1?o5e^L00oo?h^Kod>3Tom3Pi005om3Pi0?oamWW1_n]a^`3oi^fj`?oUK;[1onR
^^/6ojFnj`03ojJojonS_N_oXkg[00GoXkg[1_nS^^T2ojJnj`KoZ/?/1OnWaNl2ojO0j`OoXKg]1OnT
_n`2ojBlj`So[/CZ00?o[<?[oj[2jonZ`^/01?nZ`^/6oj[1j`03ok34jOndanWo]<OY00Ko]<OY00?o
]/c[ojk8kOn^b>d01?n^b>d6oiFck0GoL9?T1OmdUN@7oiF]i`Co^l_W1Oo0dNL00oo5e^Oo`MO[ol7G
j`05ol7Gj`;o/LW/1On/aN`7ojJoj`;oZ<7[0_nY`N/00ol0003oZL7[ojW1j`06ojS0j`03ojO0jonV
_n_oY[o[00GoY[o[1_nW_n/00onX`>_oooooooooo`0?ooooo`03o`000?oooooooooo00Sooooo0004
ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oo
oooooooo01oooooo0ol00008ojNoj`OoYl3[1_nX`N/00onX`>_oYl3[ojO0j`05ojO0j`KoY[o[1onX
`N/7oj>mk0?oVKK[0_n:Zn`5ohFTj0OoTjgX1?n_aNX6olGFi`;oc][R1?o@h>@6olOIi`?o[LK/0onP
_Nd6oiFbj`OoX[[[0_nU_^/5ojJoj`OoXkg[0onS^^T3ojJnjPSoZ/?/00?oYlG_ojO0jonW`>/01?nW
`>/7oj6mk@03ojBok?nT_>_oY;c[00CoY;c[1_n^a>X00on^ancoZ/;[oj[2j`06oj[2j`?oZ/7[0on[
`^/7okC7j@03okS@k?n^b>go[/S]00Ko[/S]1_nE/n`4og2Ci0KoM9GT1onE[NL00onkbnOo`=7Wol3A
i`04ol3Ai`03olCHjOo1en_o`MO[00Go`MO[0_nhd^d7ojc5k0?oY[o[0onW_n/5ojW1j`03o`000?nY
`N_oZL7[00;oZ<3[1OnW`>/7ojJoj`;oYko[1OnX`>/@ooooo`03o`000?oooooooooo00Sooooo000E
ooooo`03o`000?oooooooooo01cooooo0ol00004ooooo`SoYko[1onW`>/3ojS1j`CoZ<3[1onW`>/6
ojJoj`OoZ<7[0onS_N`3oifik@KoRZ_/1On5Y>P7oi>]j003ojo5j_o5e^OoaMKW00GoaMKW1Oo>f^80
0oo@h>CoamWWolOIi`04olOIi`03okW=jOnP_NgoX;g]00GoX;g]1_nE/^/5oj:jj`;oY;g[1onV_n/5
oj>mj`03oj2kk?nV_^[oY[kZ00GoY[kZ1_nZ`n`2ojg2j@OoYl3[0onQ_Nd4oj6hj@OoY;c[0_n^a>X5
ojk7k0KoZ/;[00?oZL7[oj_2jon[`^/01On[`^/4okC7j@Co^=3/1_n^b>d00onR_>_oQ:7VohBQiP04
ohBQiPCoM8oO00?oL9?TogBEi?mdUN@00omdUN@6oiF]i`03ojJjioo0dNOo`=7W00Co`=7W0oo4f>T4
ol7Gj`Go^=;]1On/aN`00onX`^coYko[ojNoj`05ojNoj`GoZL7[00?o0000ojS1jonW`>/01_nW`>/6
ojJoj`03ojNojonX`>_oZ<3[00KoZ<3[3oooool00ol0003oooooooooo`08ooooo`005Oooool00ol0
003oooooooooo`0Iooooo`?o00002?ooool8ojNoj`GoYl3[2OnX`>/5ojO0j`SoY[o[1OnX`N/3ojJo
k0GoWKW]1_n:Zn`5ohFTj0GoTjgX0onV^nP5olGFi`Goc][R0ooAfMh3olOIi`Co^LgY1onP_Nd6oiFb
j`03oj:jjonT_N_oY;g[00CoY;g[1onV_n/00onS_N_oX;_/oj2kk003oj2kk0OoY[kZ0_nZ`n`6ojg2
j@GoYl3[00?oYk[Woj6hjOnQ^>T01_nQ^>T5ojBlj`;oZ<7[1on^an`2oj[2j`GoZL7[1on[`^/00ond
anWo^=3/okS@k005okS@k0;o[/S]1OnR_>/6ohBQiPCoM8oO1?n1Vn<2ogBEi0;oUJgW1OnV^^L3ol3A
i`Koa=SY00?o`MO[okSBkOnhd^d01_nhd^d00on/aNcoZ<;/ojS2k003ojS2k0OoYko[0_nY`N/2ojS1
j`03o`000?nX`N_oZ<7[00OoYl3[0_nV_n/5ojNoj`KoZ<3[00?oZ<7[ooooooooool03Oooool00ol0
003oooooooooo`08ooooo`005Oooool00ol0003oooooooooo`0Fooooo`?o00003Oooool7ojNoj`03
ojO0jonX`>_oZ<3[00_oZ<3[00?oYl3[ojJojonV_n/02_nV_n/00onX`N_oY[o/ojJok005ojJok0Go
WKW]1On:Zn`6ohFTj003oi>]j?nV^nSoY[_X00GoY[_X0oo5e^L5olkJhPGodMWN00?oamWWokW=jOni
cNT01?nicNT7oj2mk@?oUK;[0onJ]^`7ojBmj`?oY[o[1?nU_n`6oj2kk0GoY[kZ0_n[`NX8ojg2j@03
ojO0jonW^^OoYk[W00?oYk[W2?nQ^>T00onT_>_oZ<7[ojS1j`04ojS1j`Go[/O/0_n[aN`7ojW1j`Go
Zl;[0on]a^`5okS@k0;o/lk^1onR_>/5ohBQiPGoM8oO1_n1Vn<7ojJji`03ol3Aioo4f>Woa=SY00Co
a=SY0oo4g>/6okSBk@03ok3:kOnX`^coZ<;/00GoZ<;/1OnW_n/6ojS1j`03o`000?nX`N_oZ<7[00?o
Yl3[2onW_n/2ojS0j`GoZ<7[3oooool00ol0003oooooooooo`07ooooo`005?ooool2o`0001Gooooo
0ol0000Aooooo`OoYko[3?nX`>/2ojO0j`[oY[o[1?nX`>/7ojJok0GoWKW]1On:Zn`3ohFTj0?oRjWY
2?nV^nP00oo5e^Ooc][RolkJhP03olkJhPKodMWN00?od=GMokW=jOnicNT01OnicNT3oj2mk@CoUkS_
1_nJ]^`5ojBmj`03ojFnjonU_ncoYKo/00KoYKo/1_nP^n`00onV_^[oZl7Zoj_1jP04oj_1jPKo[L;Y
0_n]_nL6ojNji`KoXKSY00?oYKcZojS1jonX`N/01_nX`N/00on^ancoZlG/oj_5k004oj_5k0OoZL7[
00?oZl;[ojg6k?n]a^`01On]a^`00onhd>co/lk^ok?>kP04ok?>kPOoX[c[1?n4XNH6ogB?g`KoPI_S
1OnV^^L3okK:jP?oa=SY1_o4g>/2okSBk@Go/<[]1onX`^`00onW_n_oZ<7[ojS1j`08ojS1j`03o`00
0?nX`>_oZ<3[00koYko[1onX`N/>ooooo`03o`000?oooooooooo00Oooooo000Dooooo`03o`000?oo
oooooooo01;ooooo0_l0000Eooooo`OoYko[2?nX`>/6ojO0j`OoY[o[1onX`>/5ojJok003oj:mkOnB
]>koT[C^00?oT[C^1On1YN/7oh^Yj@KoY[_X0onmbnD3olkJhPKodMWN0oo@eMd5okW=j@?o[lGZ1_nG
^>l6oiZfk003ojBmjonU_^_oYKk[00?oYKk[2?nU_n`3oj2kk0?oX;g^1on[`NX2ojg2j@Ko[KoW1_nW
^^L2oj6hj@GoYKcZ1_nX`N/2ojc8kPOoZlG/0onY`N/3ojW2k0Oo[LK/00?o]=7_ok?>k_ncc^h01_nc
c^h3oj:lj`?oTjWU1?mlTM`00on4XNKoM8oOogB?g`03ogB?g`OoPI_S00?oY[[WokK:j_nfb^X01Onf
b^X00oo4f>Woa=c[olCLj`04olCLj`03okkKk_n`b^go/<[]00Ko/<[]0onX`^`3ojJoj`WoZ<7[0onX
`>/00ol0003oZ<3[ojS0j`0>ojNoj`GoZ<7[00?oZ<3[ooooooooool03?ooool00ol0003ooooooooo
o`07ooooo`005?ooool00ol0003oooooooooo`0?ooooo`?o00006?ooool7ojNoj`?oZ<3[1?nX`N/7
ojO0j`OoY[o[1onX`>/00onV_ncoX[g]oj:mk@03oj:mk@GoT[C^1On1YN/7oh^Yj@?oY[_X1_nmbnD0
0oo>f^;odMWNom7IgP04om7IgPGod=GM00?o^LgYojo5j_n_aNX01On_aNX6oiNhk`?oV[K/0onN^^`6
ojFnj`KoYKo/0_nS_^d6oj2mkPGoZl7Z0_n[`n/8ojfoi`?oYk[W0onW_NT7ojFljP;oZ<7[1_n/b>h5
oj_5k0;oZ<7/1_nY`^`4ojg6k0Co]=7_1_ncc^h00onV_^_oTjWUoi>Yi@05oi>Yi@CoO97L1?mmTmh2
ogB?g`?oPI_S0onAY^@7okK:jP;o_]K[1?o4g>/4okkKkPKo/<[]00?oZlG/ojJojonV_n/01OnV_n/7
ojS1j`CoZ<3[00Co0000ojS0jonX`>_oZ<3[3_nW_n/00onX`N_oZ<3[ojS0j`03ojS0j`gooooo00?o
0000ooooooooool01oooool001Cooooo00?o0000ooooooooool03?ooool3o`0001cooooo1OnW_n/3
ojO0j`KoZ<7[2?nW`>/6ojJoj`GoZ<3[0_nX`N/6oj:mk@GoT[C^1On1YN/7oh^Yj@03ojJkj?nmbnGo
_L_U00Co_L_U0oo8dN04om7IgPGod=GM0_o;d=h8ojo5jP?oUkS_0onB]o06oijjk0KoYKk[0_nU_n`6
oj>nk@KoX;g^00?oZl7Zoj_3jon[`n/01?n[`n/6ojfoi`03oj[2jonW_NWoYkgY00GoYkgY1OnU_>X2
ojW7k`So[<S^00?oZlG/ojS1k?nX`N`01?nX`N`6ojW2k003ojg6k?nddNoo]=7_00Go]=7_0_ncc^h5
ojJnj`KoTjWU1OmlTM`5ogfCgPOoTJKT1?nfb^X5okkFj`03olCLjonnfnko_]_^00Go_]_^0_n`b^d5
oj_5k0OoY[o[1onX`N/4ojS0j`03o`000?nX`>_oYl3[00goYko[00?oZ<7[ojS0jonX`>/01OnX`>/<
ooooo`03o`000?oooooooooo00Oooooo000Cooooo`?o00002_ooool3o`00023ooooo00?oYko[ojO0
jonW`>/01OnW`>/6ojS1j`SoYl3[1_nV_n/00onX`>_oZ<7[ojS1j`04ojS1j`KoX[g]1OnB]>h5oh6U
j`?oRjWY1OnF/^/3okg;i@Oob=7P00?odMWNom3EgOo@eMd00oo@eMd4ol_@gPKo[lGZ0_nX`N`6oi:g
l0KoW[[/0onU_^/3ojFok0SoXkk]0onP_Nh3oj2ok`OoZl?[0_n]_nL5oj[2j`OoYkgY00?oYKcZojW7
konYanl01?nYanl6ojc8kP03ojW3k?nX`NcoZ<7/00KoZ<7/0onY`^`4oj_7kPGo]=7_0_nbcnl7ojJn
j`GoTjWU1_mlTM`5ogfCgPOoTJKT00?o]/[ZokkFjonne^/01?nne^/2ol;Nk@Ko_]_^0_ncc^h7oj_5
k0?oY[o[0onW_n/8ojS1j`;oZ<3[0_nW`>/00ol0003oYl3[ojO0j`09ojNoj`GoZ<7[1onX`>/;oooo
o`03o`000?oooooooooo00Oooooo000Dooooo`03o`000?oooooooooo00Kooooo0ol0000Uooooo`Oo
Yl3[0onX`N/4ojS0j`OoYl3[1_nV_n/7ojS1j`?oX[g]1?nL^nh5ohB]k`GoPJK/1onF/^/00onmbnGo
b=7PolSAh005olSAh0?ocM3L0oo@eMd6ol_@gP;o[lGZ1_nX`N`6oi:gl0?oW[[/0onP_Nd6ojFok0So
Xkk]1_nP_nl5oj_3j`;oY/C_1onZ`^/5ojNmj@;oYlK`1onYanl2ojc8kPGoZL?/1_nX`N`2ojW3k@Oo
ZlO^00?o]=7_ok;?konbcnl01?nbcnl7ojJnj`GoTjWU1OmlTM`6ogfCgPGoTJKT0_nX_^T5okkFj`Co
`]k]0onnfnh5ok?>kPGoZlG/00?oYl3[ojNojonW_n/01OnW_n/7ojS1j`CoYl3[00?o0000ojO0jonW
`>/01onW_n/8ojS1j`?oZ<3[0onW`>/;ooooo`03o`000?oooooooooo00Oooooo000Dooooo`03o`00
0?oooooooooo00?ooooo0ol0000Yooooo`GoYl3[2OnX`>/5ojO0j`;oY[o/1_nV_n/5ojS1j`?oY/3/
1_nL^nh5ohB]k`GoPJK/1OnF/^/2ojRlj0Kob=7P1Oo=d=`00oo@eMgobm3Nol_@gP04ol_@gP;oaL_N
2?nX`N`3oi:gl0;oT;Sb1onP_Nd6ojFok0SoXkk]1_nP_nl00on[`n_oY/C_ojK4k`04ojK4k`OoZ/;[
00?oYkgYojO6l?nWa_001?nWa_05ojW7k`;oZLC]1onY`n`2ojS1k0KoZL?]1On[anh3ok;DlPKo//o_
0onV_^/3oiVXh@GoQI;I1?n1T=T2ogbAg0KoOI?N00?oTJKTojRnjOnX_^T01?nX_^T3okkFj`Ko`]k]
00?o_]_^ok?>k_ncc^h01Oncc^h00on[aNcoYl3[ojO0j`03ojO0j`OoYko[1onX`N/4ojO0j`03o`00
0?nW`>_oYl3[00OoYko[1onX`N/7ojO0j`_ooooo00?o0000ooooooooool01_ooool001?ooooo00Co
0000oooooooooooooooo0ol0000]ooooo`03ojO0jonX`>_oZ<3[00_oZ<3[00?oYl3[ojJok?nV_n`0
1?nV_n`6ojJoj`03ojS1jonV`>coY/3/00GoY/3/1_nL^nh5ohB]k`GoPJK/00?oU[;[ojRlj?nX_>P0
1?nX_>P3olSAh0KocM3L0oo?c]P3ol_@gPGoaL_N1_nX`N`2ojFok0GoT;Sb1onP_Nd3ojFok0?oYL3/
2?nS_^d3oj2ok`?oWko_1onVa>l3oj[2j`GoYLKa1_nWa_000onYanooZLC]ojW4k@04ojW4k@GoZL?/
0_nX`^`8ojW3k@03oj_7k_nbe?;o/]Cb00Go/]Cb0onbcnl2ojJjj0OoVJSQ1On5T]T5oh6@f@KoRYgP
2?nX_^T00onne^_o`]k]ol;Nk@04ol;Nk@;o`N3_1_ncc^h00on]angoYl3[ojO0j`05ojO0j`GoYko[
0_nX`N`7ojS1j`?oYl3[00?oYko[o`000?nW_n/02?nW_n/7ojS1j`OoYl3[2_ooool00ol0003ooooo
ooooo`06ooooo`004oooool4o`00037ooooo3_nX`>/7ojJok0?oY[o[0onX_n/8ojK0k0?oW;_^0_nE
^>l5og^Wk`GoQJ_]2?nX_>P00oo8dN3ocM3Lolg@g004olg@g0GoclkH00?obm3NolG;g_o5bmh01Oo5
bmh2ojS1k0KoYKo/1On@^?85oj2mk@;oX<3_1_nU`>`6oj>nk@;oYKo/1_nO_nl5ojK4k`;oX/;`2?nU
a_43ojO6l0?oYlC^1onYa>d00onY`ncoZ<;/ojS2k004ojS2k0KoZL?]0_n[c_86ok;DlP03ojk8kOnV
^^SoY[[X00CoY[[X1_nIZ>45ohFBf@KoPI3I1_n:WN06ojRnj@;o^=?^1?o2g^d5ol7Pk`;o/lk^1On]
and7ojO0j`03ojNojonX`NcoZ<7/00CoZ<7/1OnX`N/2ojO0j`CoYko[00?o0000ojNojonW_n/01OnW
_n/00onX`>_oZ<7[ojS1j`06ojS1j`KoYl3[2_ooool00ol0003oooooooooo`06ooooo`004oooool2
o`0003Cooooo3_nX`>/7ojJok0KoZ;o[1_nV`>`2ojBok@GoUKS_1OmkYnl5ohF[k@KoZ;cX0onh`n<4
olg@g0KoclkH00?ocl[EolG;g_o5bmh01?o5bmh3ol75g@OoYKo/1On@^?800onP_NgoX<3_oj30k`04
oj30k`KoYL3/0_nS_^d6ojFok0KoWko_00?oY/C_oj;2l?nR`_001?nR`_06ojG6l@03ojG1k_nWa>ko
YlC^00GoYlC^1OnYa>d9ojS2k0;oZL?]1_n[c_82ok;DlPGo[/S]1_nV^^P5oiVXh@KoQI;I1_n1T=T6
ohZMh0;oZ;kY1_nhdnh00oo2g^go`N3_ol7Pk`04ol7Pk`03okGCkon]ango[LO]00Ko[LO]0onW`>/3
ojNoj`SoZ<7/00?oZ<7[ojO0jonW`>/01?nW`>/3ojNoj`03o`000?nW_n_oYko[00;oYko[1OnX`>/6
ojS1j`SoYl3[2Oooool00ol0003oooooooooo`06ooooo`001Ol00003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02?ooool00ol0003oooooooooo`0booooo`koZ<3[1onV_n`6ojRoj`;oY/3/1_nT_nd5
oiFhk`GoNjO_1On5Znd3ojRlj0Oo^<?S00?ocM3Lolo>f?o?c]P01?o?c]P3olo:e@?oaL_N1_o1aMd5
ojFok0;oYKg[1_n?^O<6oj30k`?oYL3/0onU`Nd8ojFok0?oWko_0onS_nd7oj;2l0;oYLKa1OnU`Nh7
ojO4kP03ojW4kOnX`^coZ<;/00WoZ<;/0_nXbO06oj_>lP;o[m7b1_n^b>d7ojJjj0GoVJSQ1On5T]T6
oh6@f@GoRYgP0_nP]NP6okSCkP?o_mo`0oo1h>l4okGCk`Ko[LO]00?oZ<7/ojNojonW_n/01OnW_n/7
ojS1k0SoYl3[0onW_n/00ol0003oYko[ojNoj`07ojS0j`;oZ<7[3?nW`>/8ooooo`03o`000?oooooo
oooo00Kooooo00001OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`09ooooo`03o`000?oooooooooo03?ooooo2onX`>/2ojO0j`OoY[o/0onX_n/4ojS0j`OoY;o]1OnE
^>l5og^Wk`GoQJ_]00?oZ;cXokS3honh`n<01Onh`n<2ol;7g`GoclkH1Oo?b]D00oo5bmko`LGMol75
g@06ol75g@03ojFok?nU_N_oYKg[00CoYKg[1_n?^O<3oj30k`?oW<;b1_nU`Nd6ojFok0;oY/7]1_nS
_nd5oj;2l0;oY/7]1onU`Nh3ojO4kP?oYl;/2OnX`^`6ojS9l0?oZlkb1On_dO86ojk8k@?oY[[X0onH
WmT5oh^Be0CoQY7F0_n5T]T6oh6@f@03ohZMh?nP]NSoX;GX00CoX;GX0onhdnh6okoOl003ol7Pkone
dnoo]M?_00Co]M?_0_n]and5ojS1k0OoYko[1onX`N`6ojO0j`GoYko[00?o0000ojNojonW_n/01OnX
`>/00onX`N_oYl3[ojO0j`0;ojO0j`03ojNojooooooooooo00Kooooo00?o0000ooooooooool01_oo
ool00004oooooonHV9So8B4Qonk^kPCooooo00Go410@oooooooooooooooooa0@400:ooooo`03o`00
0?oooooooooo03?ooooo1onX`>/6ojO0j`OoY[o/1onX`>/5ojBok@03oj6nk_n;]?7oRkCa00CoRkCa
1?mhYo06ohfakPKo^<?S1?o2aml3olo>f0Kocl[E00?oc/KCol75gOo1aMd01Oo1aMd2ol31fPOoYKg[
0on?^O<3oi2jl`KoW<;b1_nU`Nd2ojFok0KoY/7]1_nS_nd00onR`_3oY/7]ojK1k@04ojK1k@GoYL7^
0_nW`^d6ojO2k0KoZ<;/0_nXa^l7ojS9l003oj_>l_n_dO;o[m7b00Go[m7b0on^b>d2oj>_h0OoV9oI
1On;T]@5ohJAePKoS9_M2?nP]NP00onhdnko_mo`okoOl004okoOl0;o_n;a1Onednl2ojg8k@OoZ<7/
0onW_n/;ojS1k0;oYl3[2OnW_n/01?l0003oYko[ojNojonX`>/5ojS1j`WoYl3[1OnW_n/7ooooo`03
o`000?oooooooooo00Kooooo0002ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooooooo
ooooo`00000;ooooo`;o0000=?ooool6ojS0j`OoYl3[1onV_n`7ojS0j`03ojBokOnQ_^koXKk^00?o
XKk^1_n;]?44ogRWl0KoSK7^0onh`n<7ol;7g`03olo>f?o?b]Gocl[E00Cocl[E0oo>a]<4ol75g@Go
`<7J1OnU_N/2ojVlj0KoT;[c1_nL`_83ojG1k@?oXl;_2?nV`Nd3oj>ok@[oY/7]00?oYL7^ojO2kOnW
`^d01?nW`^d6ojO2k0;oZ<;/1_nXa^l5ojS9l0?o[=Ce1On_dO800onX^NGoXjoPoj>_h004oj>_h0Ko
V9oI1On;T]@6ohJAePKoS9_M1_nP]NP2okCCl0Co_mo`1Onoh_400onednoo[LS]ojg8k@04ojg8k@Go
Z<7/0_nV_^/<ojS1k003ojO0jonW_n_oYko[00WoYko[00?o0000ojO0jonW`>/01onX`N/6ojO0j`So
Yko[1oooool00ol0003oooooooooo`05ooooo`000oooool00omgMgOoIVIVooooo`02ooooo`05o`00
0?ooooooooooooooool000003Oooool00ol0003oooooooooo`0booooo`KoZ<3[2?nW`>/6ojJok0Go
Z<3[0_nX`N/6oj6nkPKoRkCa1?mhYo06ohfakP03okS3hoo2amoo`/OO00Go`/OO0_o5b=`5olo:e@Go
c/KC00?o`LGMol31f_o0`MX01_o0`MX00onU_N_oZKcXojVlj004ojVlj0KoT;[c0onL`_83oiK2mPKo
Xl;_1_nV`Nd00onU`nooY/7]ojK1k@0:ojK1k@;oYl?^1onW`^d3ojO2k0CoYlK`1onXa^l00onXbO3o
[=CeojcDm@05ojcDm@03ojoAl_nX^NGoZ;WU00?oZ;WU1_nS[n05oiROf@KoRi;D1_n6TMH6ohbKg@;o
X;GX1_nddo000onogo3o_n;aokoRl@04okoRl@03okCCl?n]b>go[LS]00Ko[LS]00?oZ<7/ojJnjonV
_^/01?nV_^/8ojS1k0GoYl3[1onW_n/4ojO0j`03o`000?nW`>_oYl3[00GoZ<7[0_nX`>/6ojO0j`Oo
Yko[1oooool00ol0003oooooooooo`05ooooo`001?ooool01Ol0003ooooooooooooooooo410@00?o
oooo00?o410@ooooooooool03?ooool00ol0003oooooooooo`0booooo`KoZ<3[2?nW`>/6ojJok003
ojS0jonX`N_oZ<7[00CoZ<7[1_nQ_^h3oh^dl@;oP[7c1?mgZO801?mhYo3oSK7^ohfak_n=/Nh3oiFg
kPKo`/OO1?o5b=`3olo:e@Koc/KC00?oc<?Aol31f_o0`MX01Oo0`MX2ol6lePOoZKcX0on@^_<3oiJj
l0KoU/;f1_nS`^l2ojK1k@GoYL?_2?nV`Nd6ojO3kPGoYl;]0_nVb?47ojO6l0?oZ<K_1?nWe?L6ojcD
m@03ojZojOnX^NGoZ;WU00GoZ;WU1OnS[n06oiROf@GoRi;D1on6TMH3ohbKg@CoWkKX1Onddo03okcR
lP;o_n;a1Onddo06ojg8k@03ojS1jonV_^_oY[k[00KoY[k[1_nX`N`7ojO0j`OoYko[1?nW`>/01?l0
003oYl3[ojO0jonX`N/6ojS0j`KoYl3[1onW_n/6ooooo`03o`000?oooooooooo00Gooooo00001Ol0
003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0?ooooo`03o`000?oo
oooooooo03;ooooo1onX`>/7ojO0j`KoY[o/1onX`N/3oj6nkP?oWKg^1On2/O<5ogNYlPKoUKO^0oo2
aml7olG8g003olo:eOo>a]?oc/KC00Coc/KC0oo<`m44ol31fPGo`KcF1OnY_>P2ojjih@KoU[[`1_nF
`_H3oj?2k`?oW/Wf1onU`nl3ojK1k@GoYLG`1_nW`nh00onW`^goY/SaojK8l@04ojK8l@GoYlK`0onT
doP6ojODm`;o[=Ce1OnZ_nT7ojRii@GoXjoP1OnHWmT6oh^Be0?oQY7F0on@WM`8oinfj003okCCl?nl
h_;o_>;b00?o_>;b0_nli?<7okCCl0;o[LS]1OnX`N/6ojJnj`SoZ<7/1OnW`>/8ojNoj`GoYl3[00?o
0000ojS1jonX`>/01onX`>/3ojO0j`[oYko[1Oooool00ol0003oooooooooo`05ooooo`0000GoV9RH
oa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04?ooool2o`0003Cooooo
1_nX`>/5ojO0j`SoY[o/1OnX`N/2ojS0j`KoWKg^1On2/O<5ogNYlPKoUKO^00?o`/OOolG8g?o5b=`0
1Oo5b=`2olK6f@Goc/KC1Oo<`m400oo0`M[o`KcFol6leP06ol6leP03ojVlj?n^^N7o[[WQ00Co[[WQ
1_nF^_03oiK2mPCoT;kf1OnNbOH5ojG3k`;oX<_f2?nUaO03ojO3kPCoY<ce1_nVb?400onWa_3oY=?h
ojCCn005ojCCn0?oYmCg0onY`n`7ojZoj@?oZ;WU0onNWM85oiJEd0GoT97A1_n=U=D7oi2Mg0KoWkKX
0_nceo<3okcRlPGo_>Cc1Onddo02ojc7k@OoZ<7[0_nV_^/<ojS1k003ojO0jonW_n_oYko[00[oYko[
0_nW`>/2ojS1j`03o`000?nX`N_oZ<7[00KoZ<3[00?oYl3[ojNojonW_n/02_nW_n/00onX`>_ooooo
ooooo`03ooooo`03o`000?oooooooooo00Gooooo000Oooooo`03o`000?oooooooooo03;ooooo1_nX
`>/00onW`>_oY[o/ojJok00:ojJok003ojS1jonX`>_oZ<3[00CoZ<3[1_nM_Nh5oh:al`GoMjWb0onE
]nh4oifkkPGoaLSL1?o6a]T3olk6d`Koc<?A00?obl3@ol6le_o1_=H01Oo1_=H00oo3^M7o[[WQojji
h@06ojjih@?oU[[`1?nQ^NT6oi2nmPGoW/Wf00?oYL?_oj3;m_nPboH01?nPboH6ojG5l003oio?n?nT
c?GoY<ce00KoY<ce0onVb?44oj3@n@GoY=?h0_nW`^d6ojW3k0GoZ[oY00?oXj?EoijMd_nNWM801OnN
WM85oiJEd0GoT97A1_n=U=D6oi2Mg0CoWkKX1Onceo<00onlh_;o_>CcokcTl`05okcTl`03okCCl?n/
ango[<O]00Co[<O]1OnX`N/2ojJoj`[oZ<7/0onW`>/:ojNoj`CoYl3[1?nX`N/00ol0003oZ<7[ojS1
j`02ojS0j`GoYl3[2?nW_n/5ojS0j`Cooooo00?o0000ooooooooool01Oooool0023ooooo00?o0000
ooooooooool0<_ooool6ojS0j`[oY[o/0onW_n/7ojS0j`?oWKg^1?nK_>l5ogb_m0GoN:cd1_nM^nh3
olG8g0Koa/KI00?oc/KColc3dOo<`m401?o<`m43ol_0d0Go`KcF0oo3^M46ojjih@;o];;G1onQ^NT3
oi2nmP?oV[W^1_nDa?P6oj3;mP;oYLG`1OnOcoP6ojC<m@;oWLch1onPd?T00onTdoSoYl;]ojO2k@04
ojO2k@KoZL?/00?oZ[oYoj>SeOnSXmD00onSXmD6oijMdPKoUYG@1On@TM46ohfDe@KoT9gL00?oWkKX
ok?Glonceo<01?nceo<2okWUm0Ko_>Cc0_nad?07ojc7k@03ojS1jonV_n_oY[o[00CoY[o[1_nX`N`7
ojO0j`OoYko[1onW`>/3ojS1j`03ojS0jol0003oZ<3[00SoYl3[1OnW_n/8ojS0j`?ooooo00?o0000
ooooooooool01Oooool0027ooooo00?o0000ooooooooool0<_ooool6ojS0j`SoY[o/1OnW_n/5ojS0
j`?oYl3[1_nK_>l5ogb_m0GoN:cd1_nM^nh00oo5b=coa/KIolK6f@04olK6f@;oa/CI1Oo<`m45ol_0
d0?o`KcF1Oo3^M43ojjih@Go];;G1OnQ^NT2ojbbg@KoV[W^1_nDa?P3oj3;mPCoU/Kh1_nOcoP2ojC<
m@KoWLch0onPd?T3ojJnj`SoYl;]0onY`n`2ojFVe`OoXj?E1OnNWM86oiJEd0GoT97A1on=U=D3oi2M
g0CoY<3]0onceo<5okWUm0;o_>Cc1_nad?03ojc7k@?oZ<3[2?nV_n/6ojS1k0OoYl3[1onW_n/5ojO0
j`03ojS1jonX`>_oZ<3[00;oZ<3[00?o0000ojS0jonX`>/01_nW`>/7ojNoj`OoZ<3[1?ooool00ol0
003oooooooooo`04ooooo`008_ooool00ol0003oooooooooo`0booooo`KoZ<3[2?nV_n`5ojNoj`03
ojS0jonW`>_oYl3[00GoYl3[1_nK_>l5ogb_m0GoN:cd0onM^nh3oj:ok@Goa/KI1?o6a=T3olc3d@Oo
bl3@00?o`KcFol>idOo3^M401Oo3^M400on^^N7o];;GokBbe`05okBbe`03oj6ijOn//]go[;;M00Co
[;;M1_nJ^Nh3oiC4n0CoVk_^1_nFa_P3oio?n0CoWL?c1OnMc?P2ojFhiPKoY[k[1_nW`^d00onVYmKo
YJKGojFVe`04ojFVe`KoXj?E1_nNWM86oiJEd0GoT97A0on=U=D3oiNVh0SoY<3]00?o/mOcokWUm?ni
iO@00oniiO@3okSPl`Go/M3`0_n[aNd6ojS0j`KoY[o[2?nX`N`3ojO0j`_oYko[00?oYl3[ojS1jonX
`N/00onX`N/4ojS0j`03o`000?nX`>_oZ<3[00;oYl3[2onW_n/7ojS0j`?ooooo00?o0000oooooooo
ool01?ooool002?ooooo0_l0000cooooo`OoZ<3[1onV_n`2ojNoj`_oYl3[0onK_>l3oiZll0GoN:oe
1Omg[oD6oj:ok@?oa/KI1_o6a=T00oo<`m7obl3@ol_0d005ol_0d003olRmd?o3^M7o`kWA00Go`kWA
00?oaKO=okBbeond/]L01Ond/]L00onk/<oo[;;Mojbbg@06ojbbg@?oV[W^0onX/^07oi^kkP?oU/Kh
1?nQ^NT6oig3l`03oig<n?nU^>KoYKSV00CoYKSV1_nV_^/2ojO2k@GoYZOF1_nUY]L6oj>Se@GoWYgB
0onFUM03oiFFdPGoU9_G1onGY^06ojC0k@?o/mof00?o^NGdokSPlonhh?<01Onhh?<00onad?3oZlG]
oj_5k@04oj_5k@KoZ<3[0_nV_n/:ojS1k0;oYl3[3?nW_n/00onW`>_oZ<7[ojS1j`05ojS1j`?oZ<3[
00?oYl3[o`000?nW`>/02onW_n/:ojS0j`;ooooo00?o0000ooooooooool01?ooool002Gooooo00?o
0000ooooooooool0<_ooool6ojS0j`OoY[o/3OnW`>/6oiZll0GoN:oe1Omg[oD6oj:ok@03olK6fOo6
a=Woa/CI00Coa/CI0_o4a=X6ol_0d0?ob;g@1Oo3^M43olFgc@Go];;G0onk/<l6ojbbg@03ok>[d?nX
/^3oZ;;P00GoZ;;P1OnK^nh2ojV_g0OoXKWY0onM`o<3ojNag`OoYKSV0onV_^/2ojNUe0OoYZOF1onU
Y]L3oj>Se@;oWIK=1OnIULh7oiFFdPGoU9_G1onGY^02ojC0k@Go/mof0_neioH6okSPl`03ojk<l?n[
aNgoZlG]00KoZlG]0onX`>/2ojNoj`WoZ<7/1_nW`>/8ojNoj`GoYl3[1OnX`N/2ojS0j`CoYl3[00?o
0000ojO0jonW_n/01_nW_n/<ojS0j`04ojO0joooooooooooo`0000Kooooo000Vooooo`03o`000?oo
oooooooo03;ooooo1_nX`>/7ojJok0goYl3[1_nJ_?05ogR_m@GoMjoe0onR_nd3oj;1k`Goa/CI1?o4
a=X3ol_0d0Kob;g@0oo3^M45olFgc@?o];;G1Onk/<l3ojbbg@Co/j_@1onX/^000onK^nkoZJoLojV_
g004ojV_g0GoXKWY00?oZZODojNagonW/Ml01OnW/Ml5ojFhiP03ojRQd?nWYMCoYjGD00CoYjGD1_nV
YmH6ojFVe`03oj6HbonMU/goWIK=00CoWIK=1OnIULh6oiFFdPKoU9_G1OnGY^03oj_Am0?o/mof1One
ioH2okSPl`Go[/c`1_n[aNd7ojNoj`KoZ<7/00?oZ<7[ojO0jonW`>/01_nW`>/5ojNoj`SoYl3[00?o
Z<7[ojS0jonX`>/01?nX`>/3ojO0j`03o`000?nW`>_oYl3[00OoYko[2?nX`>/5ojO0j`03ooooool0
003ooooo00Gooooo000Wooooo`03o`000?oooooooooo03;ooooo0onX`>/3ojO0j`OoY[o/3OnW`>/6
oiZll0GoMk3f1Omd/?L6oj;1k`?oa/CI1_o4a=X00oo;`=3ob;g@olRmd006olRmd003ol>idOo5]lgo
aKO=00GoaKO=00?o];;Gok^`conk/<l01Onk/<l00on//]go/j_@ok>[d004ok>[d0GoZ;;P00?o[jO?
ojV_g?nY[m`01_nY[m`00onQ^NWoZZODojZWe003ojZWe0OoYk7O00?oYKSVojRQd?nXXM000onXXM06
ojNUe0KoYZOF0_nUY]L5oj6Hb`GoWIK=1_nIULh5oiFFdPOoU9_G00?oUjKPoj_Am?n[dO@01On[dO@0
0oncgoKo]NOfokGWmP03okGWmP?o/]Oc1_n^c?02oj_5k@_oYko[0_nX`N`5ojS1j`KoYl3[1onW_n/6
ojO0j`03ojS1k?nX`>_oZ<3[00KoZ<3[0onW`>/00ol0003oYko[ojNoj`07ojNoj`OoZ<3[1_nW`>/0
0ol0003oooooooooo`04ooooo`00:?ooool2o`0003?ooooo1_nW`>/7ojJok0[oYl3[0onW_n/6oiZl
l0GoMk3f1Omd/?L6oj;1k`03olK4fOo4a=[oa<CJ00Coa<CJ00?o`LKNolRmd?o8_M001_o8_M000oo6
_M7oaKO=olFgc@06olFgc@Oo^k3?00?o`;3;ok>[d?ncZm001_ncZm000onX/^3o[jO?ojnWc`03ojnW
c`KoZJoL00?o[j?<ojZWe?nZYm@01OnZYm@5ojNag`03oj^ObonXXM3oZ:7@00GoZ:7@1_nWYM@3ojJW
eP;oY9W:1onQV</6oifFc@GoVIG>1_nEU]83oiBKe`CoX;c]1_n[dO@3ok3Vn003okGWm_nbeo?o/]Oc
00Go/]Oc0on^c?03ojW2k0[oYko[1?nX`^`6ojS1j`;oYl3[2onW_n/2ojO0j`GoZ<7/1_nX`>/00onW
`>_oYko[ojNoj`02ojNoj`03o`000?nW_n_oYko[00GoYko[2OnX`>/3ojO0j`;ooooo00?o0000oooo
ooooool01?ooool002[ooooo00?o0000ooooooooool0<Oooool6ojO0j`OoY[o/1onW`>/6ojNoj`Ko
V[c`1Omg/?H5ogB`m`?oX/7_0onL`O85olC4fP?o`LKN1_o8_M03olJmd@SoaKO=1Onk/<l3ol2`b`Ko
/j_@00?o^jc:ojnWcon_Yll01On_Yll3ojV_g0Co[j?<1onZYm@00onW/MooZio;oj^Ob`03oj^Ob`Ko
Z:7@1OnWYM@00onWVl[oY9W:ojBIbP04ojBIbPKoXIS;1_nMU/d6oiVEcP?oUIKB0onL[>87oj2lk@;o
Zm7d1On`i_P2ok?Rm`Ko/]Oc00?oZlK^ojW2k?nY`^`01OnY`^`5ojNoj`03ojS1k?nX`^coZ<;/00Ko
Z<;/0onX`N/2ojO0j`_oYko[0onX`>/7ojS1k0;oZ<3[1OnW`>/4ojNoj`04o`000?nW_n_oYko[ojNo
j`_oZ<3[1oooool00ol0003oooooooooo`03ooooo`00:oooool00ol0003oooooooooo`0aooooo`Oo
Yl3[1_nV_n`7ojO0j`KoYko[0onJ_?04oi^ml0GoNK;g1Om`/OT5oic1lP?oa<CJ1Oo1a]h3olRmd0Go
a[gA2Oo5]ld3ok^`c`Go`;3;1?ncZm03ok^/bPOo[jO?00?oZJoLojnSc?n_Xl`01?n_Xl`5ojZWe003
ok2RbOn[Wl_oZio;00GoZio;1_nXXM000onWYMCoYi_:ojNKbP03ojNKbPGoY9W:1onQV</6oifFc@?o
VIG>0_nMXmT7oib/hPGoX;c]0on/h?T3ok3Vn0Go/n;g0_nbeo<5oj_6kPOoZL;/00?oYko[ojS1k?nX
`N`00onX`N`6ojS2k003ojS0jonW`>_oYl3[00CoYl3[1onW_n/7ojS0j`GoZ<7/2OnW`>/3ojNoj`03
o`000?nW_n_oZ<3[00WoZ<3[2_ooool00ol0003oooooooooo`03ooooo`00;?ooool00ol0003ooooo
ooooo`0aooooo`OoYl3[1_nV_n`7ojO0j`KoYko[1onK_O05ogVbm`GoL;7i1OnL`O800oo4a=[o`LKN
ol76gP05ol76gP03olRmd?o6_M7oa[gA00Goa[gA2Oo5]ld00onk/<oo`;3;ol2`b`04ol2`b`?o/j_@
1Onk[<X5ojnWc`03okRXbOn_Xlco[j?<00Go[j?<0onZYm@4ok2Rb@KoZio;1OnXXM000on[W/[oYi_:
ojNKbP04ojNKbPKoY9W:1_nQV</3oifFc@?oWj3E1_nMXmT7oib/hP03oj2lkOn/h?Wo[>3i00Go[>3i
00?o/>Khok?Rmonch_L00onch_L2ojc<l0OoZlK^0onY`^`3ojNoj`OoZ<7/0_nX`^`5ojS0j`KoYl3[
1onW_n/7ojS0j`03ojS1k?nW`>_oYl3[00WoYl3[1OnW_n/00ol0003oYko[ojS0j`05ojS0j`gooooo
00?o0000ooooooooool00oooool002gooooo0_l0000booooo`OoYl3[1_nV_n`7ojO0j`KoYko[1OnK
_O02oifmk`GoOkGg1Om[/_X5oi71m`Ko`LKN00?o^LSVolJmdOo6_M401Oo6_M400oo3`MOoaKO=olFg
c@06olFgc@03ol>hd?o0/<_o`;3;00Ko`;3;00?o/j_@ok^/b_nk[<X01?nk[<X3ojnWc`Co^:S91on_
Xl`00onZYmCo/:;9ok2Rb@03ok2Rb@OoZio;00?oZ:7@oj^Nb_n[W/X00on[W/X6ojNKbPGoY9W:1OnQ
V</00onRX=?oWj3EoinPe@05oinPe@KoWJ?I1OnL[>82ojOHn@Ko[>3i0on]ioT00onch_Oo[<c`ojc<
l004ojc<l0GoZlK^2?nW_n/7ojS1k0OoZ<3[0onW`>/:ojNoj`?oZ<3[1?nX`N/8ojO0j`WoYko[00Co
0000ojNojonX`>_oZ<3[4?ooool00ol0003oooooooooo`03ooooo`00;oooool00ol0003ooooooooo
o`0`ooooo`OoYl3[1_nV_n`7ojO0j`KoYko[00?oVkg`oifmkonM_Nl01?nM_Nl5ognem`GoJk;j1OnA
`OL3ol76gPCo^LSV1Oo6_M43ol?1e`KoaKO=0oo3^=06ol2`b`03ol2ccOnk[<[o^jc:00Ko^jc:00?o
[jO?okRXbOnhZ<T00onhZ<T6ojnSc003okJWb_n`X/Wo/:;900Go/:;91On[Wl/00on_X/_oZik:oj^N
bP04oj^NbPKoYi_:1_nTVLX00onQV<_oXZ3Coj:Pd`03oj:Pd`KoWj3E1onMXmT00onL[>;oYmSiojOH
n@04ojOHn@;o[>3i1On]ioT2ojgBl`Oo[<c`00?oZlK^ojNojonW_n/02_nW_n/7ojS1k0GoZ<3[3OnW
_n/00onX`NcoZ<7[ojS1j`06ojS1j`?oYl3[3OnW_n/00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo00?ooooo000`ooooo`03o`000?oooooooooo037ooooo1_nW`>/7ojJok0KoYl3[0onW_n/4
ojS0j`KoWKg_1Omo]OL5of^bnPGoTL7g00?o`LKNokW8i_nib>H01?nib>H3olJmd@Go`l7G0oo5]ld5
ol>hd0Go`;3;0oo0/ld6ok^/bP03okf`cOnhZ<Wo^:S900Co^:S91?n_Xl`4okJWbPKo/:;90on[Wl/4
ojnRb`KoZik:1_nWVlX3ojBIbP;oYJ;B1onRX=<5oinPe@KoWJ?I0_nUd?H5ojOHn@CoYnOk00?o[NOi
ojgBlon]d_<01?n]d_<3ojc<l0?oZ<7[2onW_n/3ojS2k0OoZ<7/00?oZ<3[ojNojonW_n/02onW_n/5
ojS1k0KoZ<7[00?oYl3[ojNojonW_n/02_nW_n/5ooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool00oooool0037ooooo00?o0000ooooooooool0<Oooool7ojO0j`KoY[o/1?nW`>/3ojO0
k0KoZ<3[0onM_Nl4oj6nkPGoR;We1OmW/_X5ohBonPKo^LSV00?oa[gAol?1eoo3`ML01Oo3`ML00oo5
]lgo`kS@ol>hd004ol>hd0?o`;3;1Oo0/ld5ok^/bP?o_K3=1_nhZ<T00on_Xlco]ZO:okJWbP04okJW
bPOo/:;900?oZio;ojnRbon_X//00on_X//6oj^NbPGoYi_:00?oZJCBojFRd_nUX]801?nUX]86oj:P
d`KoWj3E0_nMXmT6ojG@mP03ojOHnOnWio_oYnOk00CoYnOk0_n^f_L5ojgBl`;oZLC]1_nX`N/6ojNo
j`03ojO1k?nX`^coZ<;/00GoZ<;/0onX`N`3ojO0j`[oYko[1?nW`>/6ojS1k0;oZ<7[1OnW`>/8ojNo
j`Wooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`03ooooo`00<_ooool2o`0003;o
oooo1onW`>/6ojJok003ojO0jonW`>coYl3/00CoYl3/1onX`>/6oj6nkPGoR;We1OmW/_X5ohBonP?o
^LSV0onXb_86ol?1e`03okc:iOo3^=3o`kS@00Ko`kS@00?o`;3;ol2ccOo0/ld01?o0/ld3ok^/bPGo
_K3=1OnhZ<T00oni[loo]ZO:okJWbP05okJWbPKo/:;900?o/jS>ojnRbon_X//01?n_X//7oj^NbP03
ojNKb_nYY=;oZJCB00?oZJCB1_nUX]86oj:Pd`?oWj3E1?nSb?<5ojG@mPCoX^Gl00?oYnOkojkJmon^
f_L01?n^f_L00on]d_?oZLC]ojW4k@04ojW4k@KoZ<7[0_nW_n/5ojO1k0GoZ<;/0_nX`>/6ojO0j`Oo
Yko[1onW`>/3ojS1k0;oZ<7[2?nW`>/3ojNoj`kooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`02ooooo`00=?ooool00ol0003oooooooooo`0`ooooo`OoYl3[1onV_n`6ojO0k0OoZ<3[
1_nQ_^h2ohRim@?oTkcc1_m]/_X4og>lo0KoZ<[b0oo3`ML4okc:i@Ko`kS@00?o`<?Lol2ccOo0/ld0
1_o0/ld00onk[<[o_K3=okf`c@04okf`c@?o^:S91?ni[ll7okJWbP?o/:;91?ncZ<h6ojnRb`GoZik:
00?o[J[DojVTd_nYY=801?nYY=86ojFRdPGoXZ3C0_nTa?07oj?8l`03ojG@m_nRiOcoX^Gl00CoX^Gl
0_nYgoX5ojkJm`;oZ/O_1onYa>d3ojS1j`?oYko[1onW`N`00onX`^coZ<3[ojS0j`04ojS0j`KoYl3[
1onW_n/5ojO0j`03ojS1k?nX`N_oZ<7[00CoZ<7[1_nW`>/Booooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool00_ooool003Gooooo00?o0000ooooooooool0<?ooool5ojO0j`;oZ<3[1onV
_n`3ojO0k0?oY/3/1onX`>/3oj6nkP?oY;k/1OnC_?<6offbnPCoLkcl1_nXb_800oo3`MOo_<[Uokc:
i@04okc:i@?o`kS@1?o0`m`6ol2cc@03oknnfOnm/<go_K3=00Ko_K3=00?o^:S9okV_coni[ll01?ni
[ll6okJWbP03ok2RbOncZ<ko/jS>00Co/jS>1_n_X//2oj^NbPGo[J[D1OnYY=87ojFRdP03oj:PdonT
a?3oY<C`00CoY<C`1OnSb?<3oikSo@;oX^Gl1_nYgoX00on^f_OoZ/O_oj[7k`04oj[7k`GoZLC]2?nW
_n/5ojO1k003ojS1k?nX`>_oZ<3[00KoZ<3[0onW`>/:ojNoj`03ojO0jonX`NcoZ<7/00?oZ<7/1_nX
`N/2ojO0jaKooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`00=_ooool0
0ol0003oooooooooo`0`ooooo`03ojO0jonX`>_oZ<3[00CoZ<3[1OnV_n`8ojK0k0GoZ<3[0_nX`N/6
ojBnk0GoTkcc0om]/_X3ogbgn0?oIkWm00CoLkclojS:l_nXb_;oZ<[b1?n<ao`6okc:i@03ol>hd?o0
`mco`<?L00Co`<?L0oo0/ld4oknnf@Ko_K3=00?o_;oLokV_coni[ll01Oni[ll5okJWbP03okJbeOnc
Z<ko/jS>00Go/jS>1On_X//00ona]=_o[J[DojfZe005ojfZe0KoZJCB0onUX]84ojO5k`OoY<C`00?o
XlScoikSoOnNhod00onNhod4oj?Qo0?oZMoj0onYbO07oj[7k`03ojW4kOnW_n_oYko[00[oYko[00?o
Yl7/ojS1k?nX`N`00onX`N`6ojS0j`goYko[2?nX`N`3ojS1ja_ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`02ooooo`00=oooool2o`00037ooooo1onX`>/00onV_ncoY/3/ojK0k00:
ojK0k003ojS0jonX`N_oZ<7[00CoZ<7[1_nT_^`2oi>ll`CoVkg`1Oml]oP5ofNio@KoS<Ol0onlb^D3
oj?>mPOo`<?L00?o`;?=oknnfOno_]T01?no_]T3okf`c@Co_;oL1oni[ll00onfYl[o][;EokJbe@03
okJbe@Oo/jS>00?o[j;;ok6dfona]=/00ona]=/6ojfZe0GoZJCB0_nXbO47ojO5k`?oY<C`1OnKhOd0
0onNhogoXn7loj?Qo004oj?Qo003ojS;l_nYbO3oZLW`00GoZLW`0onZanl3ojNojP[oYko[2_nX`N`2
ojS0j`goYko[2_nX`N`Pooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool0
03Wooooo00?o0000ooooooooool0;oooool7ojS0j`goY/3/1onX`N/3ojBnk0CoYko[1_nK_O04ogbg
n0GoIkWm0on<ao`4og?2oPGoXlkf1Oo0`m`2ojo@l@Oo_kkI00?o_K3=okbog?nl_m`01?nl_m`5okV_
c`03okS6i?nf/]Go][;E00Go][;E1OncZ<h00onc`^Go/KCKok6df`05ok6df`Ko[J[D00?oZJCBojS9
lOnXbO401?nXbO45ojO5k`CoUmon0onKhOd4oigQo@;oXn7l1OnXbo85ojW9l0;oZ;o[1_nW_nX5ojNo
j`;oZ<;/2_nX`N`3ojO0j`goYko[2?nX`N`Sooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool00_ooool003[ooooo00?o0000ooooooooool0;oooool7ojS0j`GoY/3/0_nW`>/6ojK0k0Go
Z<7[0_nW`N/7ojNoj`?oVkg`0onR_^d5ohnlm@KoJkOl1Omc`_h5oj?>mP03ol33g?n_d?7o[m3a00Co
[m3a1Ono_]T2ojoAl@Ko_;oL0oni[ll4okS6i0Oo][;E00?o/jS>ok?2iOnc`^D00onc`^D6ok6df`Go
[J[D0onWd?H6ojS9l@03ojO5konGgokoUmon00CoUmon0_nHgoh5oigQo@?oYlcc1_nXbo800onYbO3o
Z;o[ojRoj`04ojRoj`KoYkoZ00?oYko[ojS2k?nX`^`01?nX`^`5ojS1k0SoYl3[3OnW_n/3ojS1k2So
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`00>oooool00ol0003ooooo
ooooo`0`ooooo`KoZ<3[00?oY/3/ojO0jonW`>/01?nW`>/6ojK0k003ojS1jonW`N_oYl7[00CoYl7[
1OnW_n/2ojS0j`KoX[k]1On?_?D3of^go0CoP;[i1OmV_Od5ogo:o`Ko[m3a00?o_kkIojoAlOn_dO40
1?n_dO46okbog003okV_conha^Co^<KT00Co^<KT1Onf/]D2ojgBl`Ko/l;U1_na]=/00on]Z]CoYm3f
ojO@mP05ojO@mP?oZ<Wa1OnCgoh00onGgokoV=onoiSOoP04oiSOoP03oigQoOnWc??oYlcc00GoYlcc
0onXbo83ojS0j`OoZ;o[0onW_nX3ojO1k0OoZ<;/00?oZ<7/ojO0jonW`>/02_nW`>/;ojNojbgooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`01ooooo`00??ooool00ol0003ooooooooo
o`0`ooooo`KoZ<3[1onW`>/3ojK0k0CoY[o/1_nW`N/00onW_n_oZ<3[ojS0j`04ojS0j`KoX[k]0_n?
_?D4oibnl0KoP;[i1OmV_Od5ogo:o`?o[m3a1?n5c_l6ojoAl@?o_;oL1?nWdoL6okS6i003okJbeOn]
d_?o[M;c00Co[M;c1_nc`^D3ok6df`CoWmKk1OnWd?H3ohcMoP?oTmon1OnDg?h3oiSOoPCoYL_c1OnW
c?<00onX`NcoZ<3[ojS0j`05ojS0j`GoZ;o[2?nW`N`3ojS2k0?oZ<3[2_nW`>/;ojNojc7ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`01ooooo`00?Oooool2o`00037ooooo1_nX`>/7
ojO0j`OoY[o/0onW`N/3ojK0k0OoZ<3[0onR_^d3ojJoj`KoW;k`0on0^_T4oiNnl`GoMk[k1OmY`_h6
ohG>o`?o[m7a1?n4dOl6ojOCm`?o^<KT1?nEe_h6ojgBl`?o/l;U1?nDfOh6oioFn`03ojO@m_n<gOko
S=gn00?oS=gn0onCf?h5oiCLoP?oY<[c1_nUbo<00onWc??oZ<7/ojS1k003ojS1k0OoZ<3[00?oZ;o[
ojO1k?nW`N`02?nW`N`2ojS1k0KoZ<3[1OnW`>/<ojNojcCooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`01ooooo`00?oooool00ol0003oooooooooo`0_ooooo`KoZ<3[1onW`>/5ojJo
k0SoY/3/1OnX`>/2ojS1j`KoY[o[0onL__03oj>nk@OoUkkc1Omg^_/5ofW2oP?oQLko1?m[a_h6ohCA
o`?oYm?g1?mld_l6oiGFoP?o[M;c1?n4eol6oiCIoP?oWmKk1?n4foh00on<gOkoTmSnoi?HoP05oi?H
oP03oiCLo_nTb_?oY<[c00GoY<[c0onUbo<2ojO1k0OoZ<7/0onX`>/4ojO0j`OoYl7/1_nX`N`6ojS0
j`03ojO0jonW_n_oYko[00WoYko[>Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
007ooooo0010ooooo`03o`000?oooooooooo02oooooo1onX`>/6ojO0j`03ojJok?nV`>coY/3/00[o
Y/3/00?oZ<3[ojS1jonX`N/01?nX`N/4ojJoj`;oZ<7[1_nS_^d5oiNnl`;oXKk^1_nC_oD6ogNno@Go
JlKn0on4dOl5ofk9oPGoO=;o0onEe_h4ogKBoPKoQ=Oo0onDfOh4ogkGoP?oQ=_n1OnDd_d3oi?HoPCo
XlOb1OnTb_<00onW`>_oYl7/ojO1k004ojO1k0GoZ<7/2OnW`>/7ojO1k0KoZ<7/0onX`>/;ojNojcgo
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`01ooooo`00@Oooool00ol0003ooooo
ooooo`0_ooooo`OoZ<3[0onW`>/4ojRoj`goY/3/1_nX`N/00onV_n_oZ<7[ojS1j`03ojS1j`KoXkk]
00?oUkkcoj6nk_nQ_^h01?nQ_^h6oi>om@?oMkkm1?nD`?D6ogc1o@?oK/Wn0on6`_/6ogS;o`?oM];n
1?n9b_d6oh7Bo`?oO]On1OnFboX3oiCBo@?oXlGa1onSao800onTb_?oYl3[ojO0j`03ojO0j`KoYl7/
00?oZ<7/ojO0jonW`>/02OnW`>/9ojO1k0?oZ<7/3?nW_n]1ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool00Oooool004;ooooo0_l0000`ooooo`OoZ<3[1onX_n/3ojK0k0?oYl3[1onV
`>`3ojS1j`?oY/3/1_nX`N/3oj>nk@CoYko[1_nQ_^h3oi>om@CoX;k^1_nD`?D3ogc1o@?oVL;c1_n6
`_/3ogS;o`CoULCg1_n9b_d3oh7Bo`CoW<Of1OnFboX00onT`^ooXlGaoj?5l@05oj?5l@?oXlOb1?nW
_n/6ojO0j`?oYl7/2onW`>/;ojO1k0coYko[A_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo007ooooo0014ooooo`03o`000?oooooooooo02kooooo1onX`>/7ojRoj`KoYl3[3OnV`>`4
ojS1j`;oYl7/1onW_n/3oj6nkP?oYko[1onP_^h3oiC0m@CoXKo^1OnI`_<3ohK2n`CoW/7a1_nEa?L3
ohW:o@CoX<?a1_nLaoH00onFbo[oY<;_ojC2k`03ojC2k`GoXlGa2OnW_n/@ojO0j`_oYl7/3?nW_n]:
ooooo`03o`000?oooooooooo00Oooooo0Ol00001ooooo`7ooooo0015ooooo`03o`000?oooooooooo
02oooooo1_nX`>/7ojRoj`KoYl3[3OnV`>`00onX`N_oYl7/ojO1k003ojO1k0GoYko[0_nX`N`6ojNo
j`GoX;k^0_nW_n/7oj6okP;oVL;c0onT_nd7oik1l@?oULCg1?nS`>h6oj33l@?oW<Of0onU`>d6ojC2
k`03oj?5lOnW_n_oYko[00WoYko[0_nW`N`;ojO0j`_oYl7/0onW`>/:ojNojdkooooo00?o0000oooo
ooooool01_ooool1o`00007ooooo0Oooool004Kooooo00?o0000ooooooooool0<?ooool5ojS0j`Oo
Z;o[0onW`>/4ojNoj`coY/3/1_nW`N`00onW_n_oZ<7/ojS1k004ojS1k0KoYko[00?oX;k^ojNojonW
_n/01?nW_n/5oj6okP03ojNojonT_ngoY;o]00CoY;o]1OnN`O42ojJnj`OoXl3^0onP`o42ojJoj`Oo
YL3]0onT`^l;ojNoj`KoYl7/1onW`>/:ojO1k0SoYl3[1OnW_n]Booooo`03o`000?oooooooooo00Ko
oooo0Ol00001ooooo`7ooooo0017ooooo`;o0000<Oooool5ojS0j`GoZ;o[0_nX`>/7ojNoj`?oY/3/
0onW_n/6ojK0k0?oYl7/1?nV`>`6ojS1k0?oYko[1?nX`N/6ojNoj`03oj6ok_nW_n_oYko[00?oYko[
1_nT_nd00onN`O7oY[k[ojJnj`04ojJnj`GoXl3^00?oYko[ojJojonV_n/01?nV_n/5ojG0k@;oZ<3[
2_nW_n/3ojS1k0OoYl7/0onW`>/:ojO1k0coYl3[00?oYko[ooooooooool0E?ooool00ol0003ooooo
ooooo`05ooooo`7o00000Oooool1ooooo`00BOooool00ol0003oooooooooo`0_ooooo`GoZ<3[00?o
Z;o[ojS0jonX`>/01?nX`>/5ojNoj`;oZ;o[1_nW_n/4ojK0k0;oYl3[1onV`>`3ojS1k0?oY/3/1onX
`N/3ojNoj`?oZ<7/1_nW_n/3ojBok@CoZ<3[1_nV_^/00onS`>koYko[ojNoj`03ojNoj`KoY[o[00?o
YL3]ojS0jonX`>/01?nX`>/5ojNoj`;oYl7/1_nX`N`@ojO1k0goYl3[F_ooool00ol0003ooooooooo
o`04ooooo`7o00000Oooool1ooooo`00B_ooool00ol0003oooooooooo`0_ooooo`;oZ<3[1?nW`>/6
ojS0j`03ojNojonX_n_oZ;o[00CoZ;o[1_nW_n/00onV`>coYl3[ojO0j`03ojO0j`goY/3/1OnX`N/0
0onV`NcoZ<7/ojS1k005ojS1k0?oYko[0onX`N`7ojS0j`?oY[k[0onX`N`6ojNoj`?oY[o[1?nX`N`6
ojS0j`03ojNojonW`NcoYl7/00CoYl7/1_nX`N`;ojO1k0coYl3[H?ooool00ol0003oooooooooo`03
ooooo`7o00000Oooool1ooooo`00Boooool00ol0003oooooooooo`0_ooooo`KoYl3[1_nX`>/7ojRo
j`?oYko[1?nX_n/5ojO0j`goY/3/00?oZ<7[ojK1k?nV`N`00onV`N`5ojS1k0;oY/7/1_nX`N`5ojS0
j`;oYl7/1_nX`N`3ojNoj`?oYl7/1onX`N`3ojS0j`[oYl7/0onX`N`:ojO1k0_oYl3[I?ooool00ol0
003oooooooooo`03ooooo`7o00000Oooool1ooooo`00C?ooool2o`00033ooooo1?nW`>/2ojO0k0Ko
Z<3[1OnX_n/2ojS0j`OoZ;o[0_nW`>/4ojNoj`goY/3/1OnV`N`00onX`NcoY/7/ojK1k004ojK1k0Ko
Z<7/00?oZ<3[ojO1k?nW`N`01?nW`N`4ojS1k0;oY/7/1_nW`N`5ojS1k0coYl7/0_nW`>`:ojO1k0Co
Yko[1onW`>]Xooooo`03o`000?oooooooooo00?ooooo0Ol00001ooooo`00C_ooool00ol0003ooooo
ooooo`0^ooooo`03ojO0jonW`>coYl3/00?oYl3/1_nX`>/00onX_n_oZ<3[ojS0j`04ojS0j`GoZ;o[
00?oZ;oZojNojonW_n/01OnW_n/3ojK0k0?oYko[1onV`>`2ojK1k0CoY/3/1_nV`N`3ojS1k0CoY/3/
1_nW`N`00onX`NcoY/7/ojK1k003ojK1k0KoYl7/00?oZ<7/ojO1k?nW`N`02OnW`N`00onW`>_oYl3/
ojO0k004ojO0k0GoYl7/2OnW_n/3ojO0jfcooooo00?o0000ooooooooool00_ooool1o`00007ooooo
001?ooooo`03o`000?oooooooooo02oooooo1OnW`>`3ojS0j`CoYl3[1_nX`>/00onX_n_oZ;oZojRo
jP03ojRojPGoYko[0_nX_nX6ojNoj`GoY/3/00?oYko[ojK0k?nV`>`01OnV`>`3ojK1k0?oYl3[1onV
`>`3ojO1k0?oYl3/1_nV`N`3ojO1k0CoYl3/1onW`N`5ojO0j`KoYl3/00?oYl7/ojNojonW_n/02OnW
_n]aooooo`05o`000?ooooooooooooooool000000Oooool0053ooooo00?o0000ooooooooool0;ooo
ool5ojO0k0OoYl3[1onX`>/5ojRojP03ojNojonX_n[oZ;oZ00CoZ;oZ1_nW_n/00onV`>coYko[ojNo
j`03ojNoj`GoY/3/0_nW_n/6ojO0j`GoY/3/00?oYko[ojO0k?nW`>`01OnW`>`3ojK1k0?oYl3[1onW
`>`3ojO1k0?oYko[1_nW`>/3ojO0k0_oYko[M?ooool01Ol0003ooooooooooooooooo0000007ooooo
001Aooooo`;o0000<?ooool5ojO0k0GoYl3[0_nW`>`7ojS0j`;oZ;oZ0onX`>/7ojRojP?oYko[1?nX
_nX5ojNoj`03ojK0k?nW_n_oYko[00CoYko[1_nW`>/00onV`>coYko[ojNoj`03ojNoj`GoYl3/0_nW
_n/6ojO0j`GoYl3/2?nW_n/3ojO0j`goYko[N?ooool01?l0003oooooooooool00001ooooo`00Dooo
ool00ol0003oooooooooo`0^ooooo`GoYl3/00?oYl3[ojO0k?nW`>`01?nW`>`5ojS0j`03ojO0k?nX
`>_oZ<3[00CoZ<3[1OnX_nX2ojS0j`OoZ;oZ0_nW_n/4ojRojPKoYko[0onW`>/9ojNoj`03ojO0k?nW
_n_oYko[00CoYko[1_nW`>/00onW`>coYko[ojNoj`08ojNoj`;oZ;oZ2onW_n]mooooo`03o`000?oo
oooo0000007ooooo001Dooooo`03o`000?oooooooooo02kooooo0_nW`>`4ojO0j`KoYl3/00?oZ<3[
ojO0k?nW`>`00onW`>`6ojS0j`03ojRoj_nX`>_oZ<3[00CoZ<3[1OnX_nX00onX`>_oZ;oZojRojP05
ojRojP?oYko[0onX_nX9ojNoj`CoZ;oZ1_nW_n/3ojO0j`?oZ;oZ1onW_n/6ojRojPOoYko[P?ooool0
0ol0003oooooo`000001ooooo`00EOooool00ol0003oooooooooo`0^ooooo`KoYl3[3?nW`>`3ojS0
j`CoYl3/1_nX`>/00onX_n[oZ<3[ojS0j`03ojS0j`GoZ;oZ0_nX`>/6ojRojPCoYko[0_nX_n/7ojRo
jP?oYko[2OnX_nX3ojNoj`[oZ;oZ0onW_n^4ooooo`7o00000Oooool1o`000000E_ooool2o`0002oo
oooo0onW`>/3ojNoja?oYl3/0onX`>/4ojO1k0GoZ<3[00?oZ;oZojS0jonX`>/01?nX`>/6ojRojP03
ojNojonX_n_oZ;o[00?oZ;o[1OnX_nX2ojS0j`[oZ;oZ0_nX`>/:ojRojX[ooooo0_l0000005Sooooo
00?o0000ooooooooool0;Oooool6ojNoj`GoYl3/0_nW`>/<ojO0k0OoYl7/0_nX`>/4ojO1k0KoZ<3[
0onX_nX3ojS0j`KoZ;o[00?oZ;oZojS0jonX`>/01?nX`>/6ojRojPKoZ<3[1OnX_nZ=ooooo`?o0000
001Iooooo`03o`000?oooooooooo02gooooo1_nW_n/00onW`>coYl3[ojO0j`04ojO0j`CoYl3/0_nW
`>/6ojO0k0GoYl7/00?oYl3/ojO1k?nW`N`01OnW`N`3ojS0j`?oYl7/1_nX`>/3ojRoj`CoZ<7/1_nX
`>/2ojRojPCoZ<7[1_nX`>/00onX_n[oooooooooo`2:ooooo`Co00000oooool005[ooooo00?o0000
ooooooooool0;Oooool3ojNoj`CoZ;o[1_nW`>/00onW`>coYl3[ojO0j`03ojO0j`KoYl3/00?oYl7/
ojO0k?nW`>`00onW`>`5ojO1k0;oYl3/1_nW`N`4ojS0j`;oYl3/1onX`N`3ojS0j`?oYl7/1_nX`N/3
ojS0jhcooooo0ol00007ooooo`00Foooool00ol0003oooooooooo`0]ooooo`OoZ;o[0onW`>/3ojNo
j`KoYl3[0onW`>`4ojO0j`GoYl3/00?oYl7/ojO0k?nW`>`01?nW`>`6ojO1k003ojS0jonW`>coYl3/
00?oYl3/1OnX`N`00onW`>coYl7/ojO1k005ojO1k0?oZ<7[SOooool4o`0000[ooooo001Looooo`;o
0000;_ooool5ojRoj`;oZ<3[1_nW_n/3ojO0j`CoYko[1_nW`>/2ojO0k0CoYl3[1_nW`>`3ojO1k0Wo
Yl3/00?oZ<7/ojO0k?nW`>`00onW`>`5ojO1k8gooooo1?l0000>ooooo`00G_ooool00ol0003ooooo
ooooo`0/ooooo`03ojRojonX`>_oZ<3[00CoZ<3[1?nW_n/2ojS0j`OoYko[0onW`>/2ojNoj`OoYl3[
0onW`>`3ojO0j`WoYl3/1?nW`>/5ojO0k003ojO1k?oooooooooo08[ooooo1?l0000Booooo`00Gooo
ool00ol0003oooooooooo`0]ooooo`KoZ<3[00?oYko[ojS0jonX`>/00onX`>/5ojNoj`;oZ<3[1OnW
_n/5ojO0j`;oYko[1_nW`>/3ojO0k0CoYko[1_nW`>/2ojO0k8_ooooo1?l0000Fooooo`00H?ooool0
0ol0003oooooooooo`0]ooooo`coZ<3[00?oYko[ojS0jonX`>/01?nX`>/5ojNoj`03ojO0jonW_n_o
Yko[00CoYko[1?nW`>/9ojNoj`?oYl3[S?ooool3o`0001[ooooo001Qooooo`;o0000;ooooolBojS0
j`;oYko[1?nX`>/6ojNoj`03ojO0jonW_n_oYko[00SoYko[S?ooool4o`0001gooooo001Sooooo`03
o`000?oooooooooo02gooooo0onX`>/2ojO0k1?oZ<3[0onW_n/3ojS0j`OoYko[Roooool4o`00027o
oooo001Tooooo`03o`000?oooooooooo02gooooo1OnW`>`5ojS0j`;oYl3/4_nX`>/3ojNojh[ooooo
1?l0000Uooooo`00IOooool00ol0003oooooooooo`0]ooooo`GoYl3/00?oZ<3[ojO0k?nW`>`01?nW
`>`4ojS0j`;oYl3/2_nX`>^:ooooo`Co0000:Oooool006Kooooo0_l0000^ooooo`;oYl3/1?nW`>/6
ojO0k003ojS0jonW`>coYl3/00?oYl3/1onX`>^9ooooo`?o0000;Oooool006Sooooo00?o0000oooo
ooooool0;?ooool6ojO0j`?oYl3/0onW`>/6ojO0k0?oZ<3[R?ooool4o`00033ooooo001Yooooo`03
o`000?oooooooooo02cooooo3?nW`>/3ojO0k8Wooooo1?l0000dooooo`00J_ooool00ol0003ooooo
ooooo`0/ooooo`WoYl3[R_ooool4o`0003Sooooo001[ooooo`;o0000;Oooool5ojO0jhWooooo1?l0
000looooo`00KOooool00ol0003oooooooooo`0[ooooo`03ojO0jooooooooooo08Oooooo0ol00010
ooooo`00K_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo08?ooooo1?l00013oooo
o`00Koooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo07oooooo1?l00017ooooo`00
L?ooool2o`0002Wooooo00?o0000ooooooooool0Noooool4o`0004_ooooo001booooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool0Moooool4o`0004oooooo001cooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0M?ooool3o`0005?ooooo001dooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool0L?ooool4o`0005Kooooo001eooooo`03o`000?oooooooooo02?o
oooo00?o0000ooooooooool0K?ooool4o`0005[ooooo001fooooo`;o00008oooool00ol0003ooooo
ooooo`1Xooooo`Co0000G_ooool007Sooooo00?o0000ooooooooool08?ooool00ol0003ooooooooo
o`1Tooooo`Co0000H_ooool007Wooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`1Q
ooooo`?o0000I_ooool007[ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1Moooo
o`Co0000JOooool007_ooooo0_l0000Nooooo`03o`000?oooooooooo05Wooooo1?l0001]ooooo`00
OOooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo05Gooooo1?l0001aooooo`00O_oo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo057ooooo1?l0001eooooo`00Ooooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04kooooo0ol0001iooooo`00P?ooool2o`00
01Wooooo00?o0000ooooooooool0B_ooool4o`0007cooooo0022ooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool0A_ooool4o`00083ooooo0023ooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool0@_ooool4o`0008Cooooo0024ooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0?_ooool4o`0008Sooooo0025ooooo`;o00004oooool00ol0003oooooooooo`0l
ooooo`?o0000S?ooool008Oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0hoooo
o`Co0000Soooool008Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0dooooo`Co
0000Toooool008Wooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0`ooooo`Co0000
Uoooool008[ooooo0_l0000>ooooo`03o`000?oooooooooo02cooooo1?l0002Kooooo`00S?ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Wooooo0ol0002Oooooo`00SOooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo02Gooooo1?l0002Rooooo`00S_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo027ooooo1?l0002Vooooo`00Soooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo01gooooo1?l0002Zooooo`00T?ooool2o`0000Sooooo00?o
0000ooooooooool06Oooool4o`000:kooooo002Booooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool05_ooool3o`000;;ooooo002Cooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool04_ooool4o`000;Gooooo002Dooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool03_ooool4o`000;Wooooo002Eooooo`;o00000oooool00ol0003oooooooooo`0:ooooo`Co0000
_Oooool009Oooooo00Co0000oooooooooooo00002?ooool4o`000<7ooooo002Hooooo`03o`000?oo
oooo000000Gooooo0ol00035ooooo`00VOooool2o`000003ooooool0003o000000;o0000b?ooool0
09[ooooo0_l0003<ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0538698, 0.0432538, \
0.0035044, 0.0035044}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[.12586 .2075 -12 -8.99448 ]
[.12586 .2075 0 .00552 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.56094 .0364 -5.16972 -9 ]
[.56094 .0364 .83028 0 ]
[.75679 .08071 0 -6.17777 ]
[.75679 .08071 12 2.82223 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.9429 .3657 0 -5.9083 ]
[.9429 .3657 6 3.0917 ]
[.02494 .25992 -18 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.01611 .31527 -18 -2.78472 ]
[.01611 .31527 0 6.21528 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00254 .43215 -12 -2.88407 ]
[-0.00254 .43215 0 6.11593 ]
[-0.0124 .49393 -12 -2.93688 ]
[-0.0124 .49393 0 6.06312 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
[(-2)] .12586 .2075 1 .99877 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.56863 .04703 m
.57247 .05235 L
s
[(2)] .56094 .0364 .72324 1 Mshowa
.125 Mabswid
.18558 .19702 m
.18832 .19985 L
s
.23703 .17687 m
.23971 .17975 L
s
.28951 .15632 m
.29214 .15925 L
s
.39772 .11395 m
.40023 .11699 L
s
.4535 .09211 m
.45595 .0952 L
s
.51046 .06981 m
.51284 .07294 L
s
.08568 .23614 m
.08851 .23887 L
s
.62804 .02377 m
.63027 .02701 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.7445 .0853 m
.73835 .08759 L
s
[(-2)] .75679 .08071 -1 .37284 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.93037 .36962 m
.92411 .37158 L
s
[(2)] .9429 .3657 -1 .31296 Mshowa
.125 Mabswid
.7708 .12553 m
.7671 .12688 L
s
.79613 .16428 m
.79242 .1656 L
s
.82054 .20161 m
.81682 .20291 L
s
.86679 .27235 m
.86305 .2736 L
s
.88871 .30589 m
.88497 .30711 L
s
.9099 .3383 m
.90615 .3395 L
s
.71716 .04348 m
.71349 .04489 L
s
.95018 .39992 m
.94642 .40107 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(-20)] .02494 .25992 1 -0.39157 Mshowa
.02837 .31059 m
.0345 .30825 L
s
[(-10)] .01611 .31527 1 -0.38117 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.00981 .42772 m
.01599 .4255 L
s
[(10)] -0.00254 .43215 1 -0.3591 Mshowa
0 .48963 m
.0062 .48748 L
s
[(20)] -0.0124 .49393 1 -0.34736 Mshowa
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.653 .752 .923 r
.39362 .6948 .40169 .70179 .4152 .69804 .40717 .69105 Mtetra
.656 .754 .922 r
.40717 .69105 .4152 .69804 .42878 .6943 .42079 .68716 Mtetra
.658 .751 .919 r
.42079 .68716 .42878 .6943 .44242 .69044 .43448 .6832 Mtetra
.658 .75 .918 r
.43448 .6832 .44242 .69044 .45614 .6865 .44824 .67923 Mtetra
.657 .749 .918 r
.44824 .67923 .45614 .6865 .46992 .68255 .46207 .67528 Mtetra
.653 .75 .921 r
.46207 .67528 .46992 .68255 .48378 .67861 .47597 .67143 Mtetra
.652 .753 .923 r
.47597 .67143 .48378 .67861 .4977 .67472 .48994 .66758 Mtetra
.655 .755 .924 r
.48994 .66758 .4977 .67472 .5117 .67088 .50398 .66362 Mtetra
.657 .754 .921 r
.50398 .66362 .5117 .67088 .52577 .667 .5181 .65957 Mtetra
.658 .751 .918 r
.5181 .65957 .52577 .667 .53991 .663 .53229 .65547 Mtetra
.659 .749 .917 r
.53229 .65547 .53991 .663 .55412 .65895 .54655 .65134 Mtetra
.658 .748 .916 r
.54655 .65134 .55412 .65895 .56841 .65486 .56088 .6472 Mtetra
.657 .747 .916 r
.56088 .6472 .56841 .65486 .58277 .65075 .57529 .64308 Mtetra
.655 .747 .918 r
.57529 .64308 .58277 .65075 .5972 .64662 .58978 .63902 Mtetra
.654 .75 .92 r
.58978 .63902 .5972 .64662 .61171 .64249 .60434 .63497 Mtetra
.654 .753 .923 r
.60434 .63497 .61171 .64249 .6263 .63835 .61898 .63089 Mtetra
.654 .756 .925 r
.61898 .63089 .6263 .63835 .64096 .63421 .6337 .62677 Mtetra
.654 .758 .926 r
.6337 .62677 .64096 .63421 .6557 .63005 .64849 .62261 Mtetra
.654 .759 .926 r
.64849 .62261 .6557 .63005 .67052 .62587 .66336 .61841 Mtetra
.655 .759 .927 r
.66336 .61841 .67052 .62587 .68541 .62167 .67831 .61417 Mtetra
.655 .76 .926 r
.67831 .61417 .68541 .62167 .70039 .61745 .69334 .60988 Mtetra
.656 .759 .926 r
.69334 .60988 .70039 .61745 .71544 .61321 .70845 .60556 Mtetra
.657 .758 .925 r
.70845 .60556 .71544 .61321 .73057 .60895 .72364 .6012 Mtetra
.657 .757 .923 r
.72364 .6012 .73057 .60895 .74579 .60469 .7389 .5968 Mtetra
.658 .754 .921 r
.7389 .5968 .74579 .60469 .76109 .60041 .75425 .59236 Mtetra
.657 .751 .919 r
.75425 .59236 .76109 .60041 .77647 .59614 .76968 .58793 Mtetra
.655 .748 .918 r
.76968 .58793 .77647 .59614 .79193 .59185 .7852 .58356 Mtetra
.654 .746 .917 r
.7852 .58356 .79193 .59185 .80748 .58752 .80081 .5792 Mtetra
.654 .746 .918 r
.80081 .5792 .80748 .58752 .82312 .58316 .81651 .57484 Mtetra
.654 .748 .918 r
.81651 .57484 .82312 .58316 .83883 .57874 .83229 .57044 Mtetra
.655 .749 .92 r
.83229 .57044 .83883 .57874 .85462 .5742 .84816 .566 Mtetra
.656 .754 .922 r
.84816 .566 .85462 .5742 .87049 .56961 .8641 .56145 Mtetra
.658 .757 .923 r
.8641 .56145 .87049 .56961 .88646 .56507 .88012 .55678 Mtetra
.658 .755 .921 r
.88012 .55678 .88646 .56507 .90252 .56058 .89624 .55212 Mtetra
.655 .75 .92 r
.89624 .55212 .90252 .56058 .91868 .55609 .91245 .54754 Mtetra
.654 .749 .919 r
.91245 .54754 .91868 .55609 .93492 .55159 .92876 .54298 Mtetra
.654 .748 .919 r
.92876 .54298 .93492 .55159 .95125 .547 .94516 .53841 Mtetra
.655 .751 .92 r
.94516 .53841 .95125 .547 .96766 .54229 .96165 .53376 Mtetra
.658 .755 .921 r
.96165 .53376 .96766 .54229 .98415 .53757 .97821 .52897 Mtetra
.656 .754 .922 r
.38547 .68778 .39362 .6948 .40717 .69105 .39906 .68387 Mtetra
.658 .751 .919 r
.39906 .68387 .40717 .69105 .42079 .68716 .41273 .67989 Mtetra
.658 .75 .918 r
.41273 .67989 .42079 .68716 .43448 .6832 .42646 .67591 Mtetra
.656 .75 .919 r
.42646 .67591 .43448 .6832 .44824 .67923 .44027 .67195 Mtetra
.652 .75 .921 r
.44027 .67195 .44824 .67923 .46207 .67528 .45414 .66812 Mtetra
.652 .754 .924 r
.45414 .66812 .46207 .67528 .47597 .67143 .46808 .66425 Mtetra
.656 .755 .923 r
.46808 .66425 .47597 .67143 .48994 .66758 .4821 .66021 Mtetra
.658 .752 .919 r
.4821 .66021 .48994 .66758 .50398 .66362 .49619 .65611 Mtetra
.659 .75 .917 r
.49619 .65611 .50398 .66362 .5181 .65957 .51035 .65197 Mtetra
.658 .748 .916 r
.51035 .65197 .5181 .65957 .53229 .65547 .52459 .64782 Mtetra
.657 .747 .917 r
.52459 .64782 .53229 .65547 .54655 .65134 .5389 .64372 Mtetra
.653 .748 .92 r
.5389 .64372 .54655 .65134 .56088 .6472 .55328 .63973 Mtetra
.652 .753 .924 r
.55328 .63973 .56088 .6472 .57529 .64308 .56775 .63573 Mtetra
.652 .757 .926 r
.56775 .63573 .57529 .64308 .58978 .63902 .58228 .63168 Mtetra
.654 .759 .927 r
.58228 .63168 .58978 .63902 .60434 .63497 .5969 .62755 Mtetra
.655 .758 .925 r
.5969 .62755 .60434 .63497 .61898 .63089 .61159 .62334 Mtetra
.656 .756 .924 r
.61159 .62334 .61898 .63089 .6337 .62677 .62636 .61911 Mtetra
.656 .754 .922 r
.62636 .61911 .6337 .62677 .64849 .62261 .6412 .61486 Mtetra
.656 .753 .921 r
.6412 .61486 .64849 .62261 .66336 .61841 .65613 .6106 Mtetra
.656 .752 .921 r
.65613 .6106 .66336 .61841 .67831 .61417 .67113 .60631 Mtetra
.67113 .60631 .67831 .61417 .69334 .60988 .68622 .60201 Mtetra
.655 .753 .922 r
.68622 .60201 .69334 .60988 .70845 .60556 .70138 .5977 Mtetra
.655 .754 .923 r
.70138 .5977 .70845 .60556 .72364 .6012 .71663 .59336 Mtetra
.655 .756 .924 r
.71663 .59336 .72364 .6012 .7389 .5968 .73196 .589 Mtetra
.656 .759 .925 r
.73196 .589 .7389 .5968 .75425 .59236 .74737 .58457 Mtetra
.658 .76 .926 r
.74737 .58457 .75425 .59236 .76968 .58793 .76286 .58004 Mtetra
.658 .759 .924 r
.76286 .58004 .76968 .58793 .7852 .58356 .77843 .57547 Mtetra
.659 .755 .921 r
.77843 .57547 .7852 .58356 .80081 .5792 .79408 .57088 Mtetra
.656 .749 .919 r
.79408 .57088 .80081 .5792 .81651 .57484 .80983 .5664 Mtetra
.654 .746 .918 r
.80983 .5664 .81651 .57484 .83229 .57044 .82567 .56196 Mtetra
.653 .746 .918 r
.82567 .56196 .83229 .57044 .84816 .566 .84161 .55752 Mtetra
.654 .748 .919 r
.84161 .55752 .84816 .566 .8641 .56145 .85762 .55303 Mtetra
.655 .751 .921 r
.85762 .55303 .8641 .56145 .88012 .55678 .87373 .54847 Mtetra
.658 .756 .922 r
.87373 .54847 .88012 .55678 .89624 .55212 .8899 .54374 Mtetra
.659 .756 .922 r
.8899 .54374 .89624 .55212 .91245 .54754 .90617 .53896 Mtetra
.656 .751 .92 r
.90617 .53896 .91245 .54754 .92876 .54298 .92253 .5343 Mtetra
.654 .749 .919 r
.92253 .5343 .92876 .54298 .94516 .53841 .939 .52967 Mtetra
.654 .748 .919 r
.939 .52967 .94516 .53841 .96165 .53376 .95556 .52504 Mtetra
.655 .751 .92 r
.95556 .52504 .96165 .53376 .97821 .52897 .97221 .52031 Mtetra
.658 .752 .919 r
.37724 .68058 .38547 .68778 .39906 .68387 .39088 .67658 Mtetra
.658 .75 .918 r
.39088 .67658 .39906 .68387 .41273 .67989 .40459 .67257 Mtetra
.656 .75 .919 r
.40459 .67257 .41273 .67989 .42646 .67591 .41837 .66861 Mtetra
.652 .75 .922 r
.41837 .66861 .42646 .67591 .44027 .67195 .43221 .66477 Mtetra
.653 .754 .924 r
.43221 .66477 .44027 .67195 .45414 .66812 .44613 .66086 Mtetra
.657 .755 .922 r
.44613 .66086 .45414 .66812 .46808 .66425 .46012 .65679 Mtetra
.659 .751 .918 r
.46012 .65679 .46808 .66425 .4821 .66021 .47419 .65265 Mtetra
.659 .749 .917 r
.47419 .65265 .4821 .66021 .49619 .65611 .48833 .64848 Mtetra
.658 .748 .917 r
.48833 .64848 .49619 .65611 .51035 .65197 .50254 .64434 Mtetra
.652 .748 .919 r
.50254 .64434 .51035 .65197 .52459 .64782 .51682 .64037 Mtetra
.651 .753 .924 r
.51682 .64037 .52459 .64782 .5389 .64372 .53118 .6364 Mtetra
.652 .758 .927 r
.53118 .6364 .5389 .64372 .55328 .63973 .54561 .63236 Mtetra
.656 .758 .925 r
.54561 .63236 .55328 .63973 .56775 .63573 .56012 .62817 Mtetra
.656 .755 .922 r
.56012 .62817 .56775 .63573 .58228 .63168 .57471 .62394 Mtetra
.656 .751 .92 r
.57471 .62394 .58228 .63168 .5969 .62755 .58938 .61971 Mtetra
.656 .75 .919 r
.58938 .61971 .5969 .62755 .61159 .62334 .60412 .61547 Mtetra
.657 .75 .918 r
.60412 .61547 .61159 .62334 .62636 .61911 .61894 .61116 Mtetra
.657 .749 .918 r
.61894 .61116 .62636 .61911 .6412 .61486 .63383 .60686 Mtetra
.656 .748 .918 r
.63383 .60686 .6412 .61486 .65613 .6106 .64881 .60255 Mtetra
.64881 .60255 .65613 .6106 .67113 .60631 .66387 .59823 Mtetra
.66387 .59823 .67113 .60631 .68622 .60201 .67901 .59389 Mtetra
.655 .748 .918 r
.67901 .59389 .68622 .60201 .70138 .5977 .69423 .58954 Mtetra
.655 .748 .919 r
.69423 .58954 .70138 .5977 .71663 .59336 .70954 .58519 Mtetra
.656 .749 .919 r
.70954 .58519 .71663 .59336 .73196 .589 .72493 .58078 Mtetra
.655 .749 .919 r
.72493 .58078 .73196 .589 .74737 .58457 .7404 .57636 Mtetra
.655 .75 .92 r
.7404 .57636 .74737 .58457 .76286 .58004 .75595 .57193 Mtetra
.655 .754 .923 r
.75595 .57193 .76286 .58004 .77843 .57547 .7716 .56747 Mtetra
.658 .759 .925 r
.7716 .56747 .77843 .57547 .79408 .57088 .78731 .56284 Mtetra
.659 .76 .924 r
.78731 .56284 .79408 .57088 .80983 .5664 .80311 .55814 Mtetra
.659 .755 .921 r
.80311 .55814 .80983 .5664 .82567 .56196 .819 .55344 Mtetra
.655 .748 .919 r
.819 .55344 .82567 .56196 .84161 .55752 .83499 .54891 Mtetra
.653 .746 .918 r
.83499 .54891 .84161 .55752 .85762 .55303 .85107 .54441 Mtetra
.653 .747 .919 r
.85107 .54441 .85762 .55303 .87373 .54847 .86724 .53986 Mtetra
.654 .749 .92 r
.86724 .53986 .87373 .54847 .8899 .54374 .8835 .53525 Mtetra
.658 .755 .922 r
.8835 .53525 .8899 .54374 .90617 .53896 .89983 .53046 Mtetra
.659 .756 .922 r
.89983 .53046 .90617 .53896 .92253 .5343 .91625 .52561 Mtetra
.656 .751 .92 r
.91625 .52561 .92253 .5343 .939 .52967 .93278 .52086 Mtetra
.654 .749 .919 r
.93278 .52086 .939 .52967 .95556 .52504 .94941 .51616 Mtetra
.654 .748 .919 r
.94941 .51616 .95556 .52504 .97221 .52031 .96614 .51145 Mtetra
.658 .75 .918 r
.36894 .67327 .37724 .68058 .39088 .67658 .38262 .66923 Mtetra
.656 .75 .919 r
.38262 .66923 .39088 .67658 .40459 .67257 .39638 .66524 Mtetra
.652 .75 .922 r
.39638 .66524 .40459 .67257 .41837 .66861 .41019 .66139 Mtetra
.653 .754 .924 r
.41019 .66139 .41837 .66861 .43221 .66477 .42408 .65746 Mtetra
.657 .754 .921 r
.42408 .65746 .43221 .66477 .44613 .66086 .43805 .65336 Mtetra
.659 .751 .918 r
.43805 .65336 .44613 .66086 .46012 .65679 .45209 .64919 Mtetra
.659 .749 .916 r
.45209 .64919 .46012 .65679 .47419 .65265 .4662 .645 Mtetra
.655 .748 .918 r
.4662 .645 .47419 .65265 .48833 .64848 .48038 .64092 Mtetra
.651 .75 .922 r
.48038 .64092 .48833 .64848 .50254 .64434 .49464 .63698 Mtetra
.651 .756 .927 r
.49464 .63698 .50254 .64434 .51682 .64037 .50897 .633 Mtetra
.656 .759 .925 r
.50897 .633 .51682 .64037 .53118 .6364 .52338 .6288 Mtetra
.657 .754 .921 r
.52338 .6288 .53118 .6364 .54561 .63236 .53787 .62458 Mtetra
.657 .75 .918 r
.53787 .62458 .54561 .63236 .56012 .62817 .55243 .62033 Mtetra
.658 .75 .918 r
.55243 .62033 .56012 .62817 .57471 .62394 .56706 .61604 Mtetra
.654 .748 .919 r
.56706 .61604 .57471 .62394 .58938 .61971 .58178 .61185 Mtetra
.651 .749 .921 r
.58178 .61185 .58938 .61971 .60412 .61547 .59658 .60774 Mtetra
.649 .753 .925 r
.59658 .60774 .60412 .61547 .61894 .61116 .61146 .60366 Mtetra
.648 .76 .931 r
.61146 .60366 .61894 .61116 .63383 .60686 .62642 .59956 Mtetra
.649 .767 .935 r
.62642 .59956 .63383 .60686 .64881 .60255 .64146 .59538 Mtetra
.653 .773 .937 r
.64146 .59538 .64881 .60255 .66387 .59823 .65658 .59101 Mtetra
.658 .774 .935 r
.65658 .59101 .66387 .59823 .67901 .59389 .67177 .58645 Mtetra
.66 .77 .931 r
.67177 .58645 .67901 .59389 .69423 .58954 .68704 .58182 Mtetra
.66 .764 .926 r
.68704 .58182 .69423 .58954 .70954 .58519 .70239 .57717 Mtetra
.66 .757 .922 r
.70239 .57717 .70954 .58519 .72493 .58078 .71783 .57254 Mtetra
.658 .751 .919 r
.71783 .57254 .72493 .58078 .7404 .57636 .73335 .56799 Mtetra
.654 .748 .919 r
.73335 .56799 .7404 .57636 .75595 .57193 .74897 .56353 Mtetra
.655 .749 .919 r
.74897 .56353 .75595 .57193 .7716 .56747 .76467 .55903 Mtetra
.76467 .55903 .7716 .56747 .78731 .56284 .78046 .55451 Mtetra
.655 .753 .922 r
.78046 .55451 .78731 .56284 .80311 .55814 .79633 .54996 Mtetra
.659 .76 .924 r
.79633 .54996 .80311 .55814 .819 .55344 .81228 .54519 Mtetra
.66 .759 .923 r
.81228 .54519 .819 .55344 .83499 .54891 .82831 .54036 Mtetra
.656 .751 .92 r
.82831 .54036 .83499 .54891 .85107 .54441 .84445 .53567 Mtetra
.653 .747 .918 r
.84445 .53567 .85107 .54441 .86724 .53986 .86068 .53109 Mtetra
.653 .747 .919 r
.86068 .53109 .86724 .53986 .8835 .53525 .87701 .5265 Mtetra
.654 .749 .919 r
.87701 .5265 .8835 .53525 .89983 .53046 .89343 .52182 Mtetra
.658 .755 .921 r
.89343 .52182 .89983 .53046 .91625 .52561 .90992 .51696 Mtetra
.659 .756 .922 r
.90992 .51696 .91625 .52561 .93278 .52086 .9265 .51202 Mtetra
.655 .751 .92 r
.9265 .51202 .93278 .52086 .94941 .51616 .94319 .50721 Mtetra
.654 .749 .92 r
.94319 .50721 .94941 .51616 .96614 .51145 .95999 .50244 Mtetra
.657 .75 .918 r
.36056 .66588 .36894 .67327 .38262 .66923 .37429 .66186 Mtetra
.652 .75 .921 r
.37429 .66186 .38262 .66923 .39638 .66524 .38808 .65797 Mtetra
.652 .754 .924 r
.38808 .65797 .39638 .66524 .41019 .66139 .40194 .65405 Mtetra
.657 .754 .921 r
.40194 .65405 .41019 .66139 .42408 .65746 .41588 .64993 Mtetra
.659 .751 .918 r
.41588 .64993 .42408 .65746 .43805 .65336 .42989 .64573 Mtetra
.659 .749 .916 r
.42989 .64573 .43805 .65336 .45209 .64919 .44398 .64152 Mtetra
.654 .748 .919 r
.44398 .64152 .45209 .64919 .4662 .645 .45813 .63748 Mtetra
.65 .751 .924 r
.45813 .63748 .4662 .645 .48038 .64092 .47236 .63355 Mtetra
.653 .757 .926 r
.47236 .63355 .48038 .64092 .49464 .63698 .48667 .62947 Mtetra
.657 .756 .923 r
.48667 .62947 .49464 .63698 .50897 .633 .50105 .62523 Mtetra
.657 .75 .918 r
.50105 .62523 .50897 .633 .52338 .6288 .51551 .62098 Mtetra
.51551 .62098 .52338 .6288 .53787 .62458 .53004 .61671 Mtetra
.65 .747 .921 r
.53004 .61671 .53787 .62458 .55243 .62033 .54466 .61268 Mtetra
.638 .75 .93 r
.54466 .61268 .55243 .62033 .56706 .61604 .55935 .609 Mtetra
.621 .763 .947 r
.55935 .609 .56706 .61604 .58178 .61185 .57414 .60572 Mtetra
.612 .788 .966 r
.57414 .60572 .58178 .61185 .59658 .60774 .58901 .60239 Mtetra
.606 .811 .979 r
.58901 .60239 .59658 .60774 .61146 .60366 .60397 .59888 Mtetra
.605 .831 .986 r
.60397 .59888 .61146 .60366 .62642 .59956 .61901 .59512 Mtetra
.61 .844 .988 r
.61901 .59512 .62642 .59956 .64146 .59538 .63412 .59105 Mtetra
.62 .852 .987 r
.63412 .59105 .64146 .59538 .65658 .59101 .64931 .58664 Mtetra
.633 .856 .984 r
.64931 .58664 .65658 .59101 .67177 .58645 .66457 .5819 Mtetra
.647 .855 .979 r
.66457 .5819 .67177 .58645 .68704 .58182 .6799 .57685 Mtetra
.661 .847 .971 r
.6799 .57685 .68704 .58182 .70239 .57717 .69529 .57153 Mtetra
.673 .831 .96 r
.69529 .57153 .70239 .57717 .71783 .57254 .71075 .56603 Mtetra
.678 .808 .945 r
.71075 .56603 .71783 .57254 .73335 .56799 .72629 .56048 Mtetra
.67 .778 .931 r
.72629 .56048 .73335 .56799 .74897 .56353 .74193 .55531 Mtetra
.661 .758 .922 r
.74193 .55531 .74897 .56353 .76467 .55903 .75767 .5505 Mtetra
.655 .749 .919 r
.75767 .5505 .76467 .55903 .78046 .55451 .77352 .54595 Mtetra
.77352 .54595 .78046 .55451 .79633 .54996 .78946 .54136 Mtetra
.78946 .54136 .79633 .54996 .81228 .54519 .80549 .53675 Mtetra
.657 .756 .923 r
.80549 .53675 .81228 .54519 .82831 .54036 .82159 .53199 Mtetra
.661 .76 .924 r
.82159 .53199 .82831 .54036 .84445 .53567 .83777 .52706 Mtetra
.658 .754 .921 r
.83777 .52706 .84445 .53567 .86068 .53109 .85406 .52224 Mtetra
.653 .747 .919 r
.85406 .52224 .86068 .53109 .87701 .5265 .87045 .51759 Mtetra
.87045 .51759 .87701 .5265 .89343 .52182 .88695 .51293 Mtetra
.654 .749 .92 r
.88695 .51293 .89343 .52182 .90992 .51696 .90352 .50818 Mtetra
.658 .755 .921 r
.90352 .50818 .90992 .51696 .9265 .51202 .92017 .50322 Mtetra
.659 .756 .922 r
.92017 .50322 .9265 .51202 .94319 .50721 .93692 .49821 Mtetra
.655 .75 .92 r
.93692 .49821 .94319 .50721 .95999 .50244 .95377 .49335 Mtetra
.653 .75 .921 r
.3521 .65846 .36056 .66588 .37429 .66186 .36586 .65453 Mtetra
.651 .753 .924 r
.36586 .65453 .37429 .66186 .38808 .65797 .3797 .65062 Mtetra
.657 .755 .922 r
.3797 .65062 .38808 .65797 .40194 .65405 .39361 .64649 Mtetra
.66 .751 .918 r
.39361 .64649 .40194 .65405 .41588 .64993 .4076 .64227 Mtetra
.659 .749 .917 r
.4076 .64227 .41588 .64993 .42989 .64573 .42166 .63804 Mtetra
.653 .748 .919 r
.42166 .63804 .42989 .64573 .44398 .64152 .43579 .634 Mtetra
.649 .752 .925 r
.43579 .634 .44398 .64152 .45813 .63748 .44999 .63007 Mtetra
.654 .757 .925 r
.44999 .63007 .45813 .63748 .47236 .63355 .46426 .62591 Mtetra
.657 .753 .921 r
.46426 .62591 .47236 .63355 .48667 .62947 .47862 .62166 Mtetra
.658 .75 .918 r
.47862 .62166 .48667 .62947 .50105 .62523 .49305 .61735 Mtetra
.651 .747 .92 r
.49305 .61735 .50105 .62523 .51551 .62098 .50756 .61328 Mtetra
.631 .747 .931 r
.50756 .61328 .51551 .62098 .53004 .61671 .52214 .60984 Mtetra
.599 .761 .956 r
.52214 .60984 .53004 .61671 .54466 .61268 .53681 .6071 Mtetra
.574 .793 .982 r
.53681 .6071 .54466 .61268 .55935 .609 .55158 .60448 Mtetra
.548 .818 .996 r
.55158 .60448 .55935 .609 .57414 .60572 .56644 .60181 Mtetra
.53 .831 .999 r
.56644 .60181 .57414 .60572 .58901 .60239 .58139 .59906 Mtetra
.531 .85 .998 r
.58139 .59906 .58901 .60239 .60397 .59888 .59643 .59587 Mtetra
.542 .864 .995 r
.59643 .59587 .60397 .59888 .61901 .59512 .61155 .59224 Mtetra
.558 .875 .993 r
.61155 .59224 .61901 .59512 .63412 .59105 .62674 .58819 Mtetra
.576 .883 .992 r
.62674 .58819 .63412 .59105 .64931 .58664 .64201 .58374 Mtetra
.595 .89 .99 r
.64201 .58374 .64931 .58664 .66457 .5819 .65735 .57891 Mtetra
.616 .895 .988 r
.65735 .57891 .66457 .5819 .6799 .57685 .67275 .57365 Mtetra
.641 .898 .984 r
.67275 .57365 .6799 .57685 .69529 .57153 .68821 .56794 Mtetra
.666 .895 .979 r
.68821 .56794 .69529 .57153 .71075 .56603 .70372 .56178 Mtetra
.679 .879 .973 r
.70372 .56178 .71075 .56603 .72629 .56048 .7193 .55552 Mtetra
.688 .861 .965 r
.7193 .55552 .72629 .56048 .74193 .55531 .73495 .5492 Mtetra
.691 .829 .949 r
.73495 .5492 .74193 .55531 .75767 .5505 .75068 .54299 Mtetra
.676 .785 .932 r
.75068 .54299 .75767 .5505 .77352 .54595 .76653 .53749 Mtetra
.66 .756 .921 r
.76653 .53749 .77352 .54595 .78946 .54136 .78251 .53263 Mtetra
.654 .748 .919 r
.78251 .53263 .78946 .54136 .80549 .53675 .7986 .52801 Mtetra
.655 .749 .919 r
.7986 .52801 .80549 .53675 .82159 .53199 .81479 .52333 Mtetra
.656 .753 .921 r
.81479 .52333 .82159 .53199 .83777 .52706 .83105 .51854 Mtetra
.661 .76 .923 r
.83105 .51854 .83777 .52706 .85406 .52224 .84739 .51352 Mtetra
.658 .755 .921 r
.84739 .51352 .85406 .52224 .87045 .51759 .86383 .50861 Mtetra
.653 .747 .919 r
.86383 .50861 .87045 .51759 .88695 .51293 .88038 .50389 Mtetra
.88038 .50389 .88695 .51293 .90352 .50818 .89704 .49915 Mtetra
.654 .749 .92 r
.89704 .49915 .90352 .50818 .92017 .50322 .91378 .49432 Mtetra
.659 .756 .921 r
.91378 .49432 .92017 .50322 .93692 .49821 .93059 .48924 Mtetra
.658 .755 .921 r
.93059 .48924 .93692 .49821 .95377 .49335 .9475 .48419 Mtetra
.651 .751 .923 r
.34356 .65105 .3521 .65846 .36586 .65453 .35736 .64714 Mtetra
.656 .754 .922 r
.35736 .64714 .36586 .65453 .3797 .65062 .37124 .64305 Mtetra
.659 .751 .918 r
.37124 .64305 .3797 .65062 .39361 .64649 .38521 .63882 Mtetra
.66 .75 .917 r
.38521 .63882 .39361 .64649 .4076 .64227 .39924 .63455 Mtetra
.654 .748 .919 r
.39924 .63455 .4076 .64227 .42166 .63804 .41334 .63046 Mtetra
.648 .751 .925 r
.41334 .63046 .42166 .63804 .43579 .634 .42751 .62653 Mtetra
.655 .757 .925 r
.42751 .62653 .43579 .634 .44999 .63007 .44176 .62235 Mtetra
.657 .752 .92 r
.44176 .62235 .44999 .63007 .46426 .62591 .45609 .61808 Mtetra
.658 .751 .918 r
.45609 .61808 .46426 .62591 .47862 .62166 .47049 .61377 Mtetra
.644 .746 .923 r
.47049 .61377 .47862 .62166 .49305 .61735 .48497 .60993 Mtetra
.602 .746 .946 r
.48497 .60993 .49305 .61735 .50756 .61328 .49952 .60727 Mtetra
.56 .774 .979 r
.49952 .60727 .50756 .61328 .52214 .60984 .51415 .60514 Mtetra
.51 .797 .998 r
.51415 .60514 .52214 .60984 .53681 .6071 .52889 .60327 Mtetra
.48 .813 .999 r
.52889 .60327 .53681 .6071 .55158 .60448 .54372 .6013 Mtetra
.49 .837 .996 r
.54372 .6013 .55158 .60448 .56644 .60181 .55865 .59868 Mtetra
.532 .856 .997 r
.55865 .59868 .56644 .60181 .58139 .59906 .57367 .59532 Mtetra
.597 .862 .993 r
.57367 .59532 .58139 .59906 .59643 .59587 .58876 .59112 Mtetra
.628 .842 .982 r
.58876 .59112 .59643 .59587 .61155 .59224 .60393 .58667 Mtetra
.641 .822 .97 r
.60393 .58667 .61155 .59224 .62674 .58819 .61918 .58216 Mtetra
.643 .81 .963 r
.61918 .58216 .62674 .58819 .64201 .58374 .63451 .57768 Mtetra
.641 .809 .964 r
.63451 .57768 .64201 .58374 .65735 .57891 .64994 .57322 Mtetra
.638 .821 .971 r
.64994 .57322 .65735 .57891 .67275 .57365 .66544 .5687 Mtetra
.636 .844 .98 r
.66544 .5687 .67275 .57365 .68821 .56794 .68102 .56393 Mtetra
.651 .879 .982 r
.68102 .56393 .68821 .56794 .70372 .56178 .69665 .5583 Mtetra
.667 .901 .979 r
.69665 .5583 .70372 .56178 .7193 .55552 .71231 .55192 Mtetra
.692 .905 .971 r
.71231 .55192 .7193 .55552 .73495 .5492 .728 .54487 Mtetra
.705 .888 .964 r
.728 .54487 .73495 .5492 .75068 .54299 .74375 .53769 Mtetra
.704 .86 .956 r
.74375 .53769 .75068 .54299 .76653 .53749 .75959 .53076 Mtetra
.695 .817 .94 r
.75959 .53076 .76653 .53749 .78251 .53263 .77553 .52437 Mtetra
.666 .767 .925 r
.77553 .52437 .78251 .53263 .7986 .52801 .79165 .51917 Mtetra
.654 .749 .919 r
.79165 .51917 .7986 .52801 .81479 .52333 .8079 .51446 Mtetra
.655 .75 .92 r
.8079 .51446 .81479 .52333 .83105 .51854 .82424 .50971 Mtetra
.656 .752 .921 r
.82424 .50971 .83105 .51854 .84739 .51352 .84066 .50485 Mtetra
.662 .76 .923 r
.84066 .50485 .84739 .51352 .86383 .50861 .85715 .49973 Mtetra
.657 .754 .921 r
.85715 .49973 .86383 .50861 .88038 .50389 .87376 .49476 Mtetra
.652 .747 .919 r
.87376 .49476 .88038 .50389 .89704 .49915 .89048 .48999 Mtetra
.653 .748 .919 r
.89048 .48999 .89704 .49915 .91378 .49432 .9073 .48517 Mtetra
.656 .751 .92 r
.9073 .48517 .91378 .49432 .93059 .48924 .9242 .48019 Mtetra
.66 .756 .921 r
.9242 .48019 .93059 .48924 .9475 .48419 .94117 .47501 Mtetra
.653 .753 .923 r
.33493 .64363 .34356 .65105 .35736 .64714 .34878 .6396 Mtetra
.659 .753 .92 r
.34878 .6396 .35736 .64714 .37124 .64305 .36271 .63537 Mtetra
.66 .751 .917 r
.36271 .63537 .37124 .64305 .38521 .63882 .37672 .63106 Mtetra
.656 .749 .918 r
.37672 .63106 .38521 .63882 .39924 .63455 .39079 .62688 Mtetra
.648 .75 .924 r
.39079 .62688 .39924 .63455 .41334 .63046 .40493 .62295 Mtetra
.654 .756 .925 r
.40493 .62295 .41334 .63046 .42751 .62653 .41916 .61879 Mtetra
.657 .752 .92 r
.41916 .61879 .42751 .62653 .44176 .62235 .43346 .6145 Mtetra
.658 .751 .919 r
.43346 .6145 .44176 .62235 .45609 .61808 .44783 .61017 Mtetra
.637 .745 .926 r
.44783 .61017 .45609 .61808 .47049 .61377 .46228 .60652 Mtetra
.579 .745 .955 r
.46228 .60652 .47049 .61377 .48497 .60993 .47678 .60438 Mtetra
.522 .776 .989 r
.47678 .60438 .48497 .60993 .49952 .60727 .49137 .60275 Mtetra
.457 .782 .998 r
.49137 .60275 .49952 .60727 .51415 .60514 .50606 .60159 Mtetra
.463 .814 .997 r
.50606 .60159 .51415 .60514 .52889 .60327 .52086 .59965 Mtetra
.557 .851 .998 r
.52086 .59965 .52889 .60327 .54372 .6013 .53576 .59621 Mtetra
.645 .834 .973 r
.53576 .59621 .54372 .6013 .55865 .59868 .55073 .59153 Mtetra
.675 .784 .931 r
.55073 .59153 .55865 .59868 .57367 .59532 .56578 .58627 Mtetra
.68 .739 .895 r
.56578 .58627 .57367 .59532 .58876 .59112 .5809 .5808 Mtetra
.678 .712 .875 r
.5809 .5808 .58876 .59112 .60393 .58667 .5961 .5753 Mtetra
.667 .689 .862 r
.5961 .5753 .60393 .58667 .61918 .58216 .61138 .57016 Mtetra
.654 .674 .857 r
.61138 .57016 .61918 .58216 .63451 .57768 .62675 .56563 Mtetra
.641 .669 .861 r
.62675 .56563 .63451 .57768 .64994 .57322 .64223 .56169 Mtetra
.633 .676 .873 r
.64223 .56169 .64994 .57322 .66544 .5687 .65782 .55814 Mtetra
.632 .696 .891 r
.65782 .55814 .66544 .5687 .68102 .56393 .67351 .55455 Mtetra
.635 .723 .912 r
.67351 .55455 .68102 .56393 .69665 .5583 .68928 .55075 Mtetra
.644 .774 .943 r
.68928 .55075 .69665 .5583 .71231 .55192 .70512 .54637 Mtetra
.667 .842 .967 r
.70512 .54637 .71231 .55192 .728 .54487 .72098 .54073 Mtetra
.701 .894 .967 r
.72098 .54073 .728 .54487 .74375 .53769 .73682 .53354 Mtetra
.724 .901 .958 r
.73682 .53354 .74375 .53769 .75959 .53076 .75268 .52555 Mtetra
.718 .869 .953 r
.75268 .52555 .75959 .53076 .77553 .52437 .76863 .51801 Mtetra
.708 .835 .943 r
.76863 .51801 .77553 .52437 .79165 .51917 .78468 .51098 Mtetra
.671 .774 .927 r
.78468 .51098 .79165 .51917 .8079 .51446 .80094 .5055 Mtetra
.654 .749 .92 r
.80094 .5055 .8079 .51446 .82424 .50971 .81734 .5007 Mtetra
.654 .75 .92 r
.81734 .5007 .82424 .50971 .84066 .50485 .83384 .49587 Mtetra
.657 .753 .92 r
.83384 .49587 .84066 .50485 .85715 .49973 .85042 .49089 Mtetra
.662 .759 .922 r
.85042 .49089 .85715 .49973 .87376 .49476 .86707 .48568 Mtetra
.656 .752 .921 r
.86707 .48568 .87376 .49476 .89048 .48999 .88385 .48071 Mtetra
.652 .747 .919 r
.88385 .48071 .89048 .48999 .9073 .48517 .90074 .47587 Mtetra
.653 .748 .92 r
.90074 .47587 .9073 .48517 .9242 .48019 .91772 .47095 Mtetra
.658 .753 .92 r
.91772 .47095 .9242 .48019 .94117 .47501 .93478 .4658 Mtetra
.657 .754 .921 r
.32621 .63611 .33493 .64363 .34878 .6396 .34012 .63191 Mtetra
.66 .751 .917 r
.34012 .63191 .34878 .6396 .36271 .63537 .3541 .62759 Mtetra
.659 .75 .917 r
.3541 .62759 .36271 .63537 .37672 .63106 .36815 .62329 Mtetra
.649 .748 .922 r
.36815 .62329 .37672 .63106 .39079 .62688 .38226 .61931 Mtetra
.651 .755 .926 r
.38226 .61931 .39079 .62688 .40493 .62295 .39645 .61522 Mtetra
.658 .754 .921 r
.39645 .61522 .40493 .62295 .41916 .61879 .41072 .61089 Mtetra
.658 .751 .918 r
.41072 .61089 .41916 .61879 .43346 .6145 .42507 .60653 Mtetra
.637 .744 .926 r
.42507 .60653 .43346 .6145 .44783 .61017 .43948 .60288 Mtetra
.568 .741 .958 r
.43948 .60288 .44783 .61017 .46228 .60652 .45394 .60099 Mtetra
.491 .765 .992 r
.45394 .60099 .46228 .60652 .47678 .60438 .46847 .59987 Mtetra
.433 .772 .997 r
.46847 .59987 .47678 .60438 .49137 .60275 .48312 .59902 Mtetra
.49 .821 .999 r
.48312 .59902 .49137 .60275 .50606 .60159 .49788 .59677 Mtetra
.637 .84 .978 r
.49788 .59677 .50606 .60159 .52086 .59965 .51275 .59221 Mtetra
.692 .78 .918 r
.51275 .59221 .52086 .59965 .53576 .59621 .52769 .58632 Mtetra
.711 .73 .865 r
.52769 .58632 .53576 .59621 .55073 .59153 .5427 .57919 Mtetra
.703 .685 .83 r
.5427 .57919 .55073 .59153 .56578 .58627 .55777 .57179 Mtetra
.686 .65 .808 r
.55777 .57179 .56578 .58627 .5809 .5808 .5729 .56488 Mtetra
.67 .626 .797 r
.5729 .56488 .5809 .5808 .5961 .5753 .58811 .5587 Mtetra
.656 .613 .794 r
.58811 .5587 .5961 .5753 .61138 .57016 .6034 .55332 Mtetra
.643 .605 .796 r
.6034 .55332 .61138 .57016 .62675 .56563 .61879 .54872 Mtetra
.631 .599 .799 r
.61879 .54872 .62675 .56563 .64223 .56169 .6343 .54493 Mtetra
.617 .594 .805 r
.6343 .54493 .64223 .56169 .65782 .55814 .64993 .54193 Mtetra
.604 .595 .815 r
.64993 .54193 .65782 .55814 .67351 .55455 .66569 .53968 Mtetra
.594 .607 .835 r
.66569 .53968 .67351 .55455 .68928 .55075 .68159 .53794 Mtetra
.596 .641 .866 r
.68159 .53794 .68928 .55075 .70512 .54637 .6976 .53595 Mtetra
.62 .698 .9 r
.6976 .53595 .70512 .54637 .72098 .54073 .71365 .5327 Mtetra
.648 .768 .936 r
.71365 .5327 .72098 .54073 .73682 .53354 .72973 .52811 Mtetra
.703 .859 .957 r
.72973 .52811 .73682 .53354 .75268 .52555 .74574 .52113 Mtetra
.735 .898 .952 r
.74574 .52113 .75268 .52555 .76863 .51801 .76172 .51271 Mtetra
.732 .873 .947 r
.76172 .51271 .76863 .51801 .78468 .51098 .77778 .50455 Mtetra
.715 .838 .94 r
.77778 .50455 .78468 .51098 .80094 .5055 .79396 .49716 Mtetra
.672 .774 .927 r
.79396 .49716 .80094 .5055 .81734 .5007 .81037 .49157 Mtetra
.654 .749 .919 r
.81037 .49157 .81734 .5007 .83384 .49587 .82694 .48672 Mtetra
.654 .749 .92 r
.82694 .48672 .83384 .49587 .85042 .49089 .8436 .48182 Mtetra
.659 .755 .921 r
.8436 .48182 .85042 .49089 .86707 .48568 .86034 .47667 Mtetra
.662 .759 .922 r
.86034 .47667 .86707 .48568 .88385 .48071 .87716 .47139 Mtetra
.653 .749 .92 r
.87716 .47139 .88385 .48071 .90074 .47587 .89411 .46645 Mtetra
.652 .747 .919 r
.89411 .46645 .90074 .47587 .91772 .47095 .91117 .46153 Mtetra
.654 .75 .92 r
.91117 .46153 .91772 .47095 .93478 .4658 .92832 .45647 Mtetra
.659 .752 .919 r
.31742 .62843 .32621 .63611 .34012 .63191 .33137 .62412 Mtetra
.66 .751 .917 r
.33137 .62412 .34012 .63191 .3541 .62759 .3454 .61975 Mtetra
.653 .749 .92 r
.3454 .61975 .3541 .62759 .36815 .62329 .35949 .61562 Mtetra
.648 .753 .926 r
.35949 .61562 .36815 .62329 .38226 .61931 .37364 .61163 Mtetra
.657 .756 .923 r
.37364 .61163 .38226 .61931 .39645 .61522 .38789 .60729 Mtetra
.659 .751 .918 r
.38789 .60729 .39645 .61522 .41072 .61089 .40221 .60289 Mtetra
.643 .746 .924 r
.40221 .60289 .41072 .61089 .42507 .60653 .41659 .599 Mtetra
.573 .737 .953 r
.41659 .599 .42507 .60653 .43948 .60288 .431 .59705 Mtetra
.484 .754 .99 r
.431 .59705 .43948 .60288 .45394 .60099 .44548 .59617 Mtetra
.421 .758 .995 r
.44548 .59617 .45394 .60099 .46847 .59987 .46006 .59566 Mtetra
.523 .821 .999 r
.46006 .59566 .46847 .59987 .48312 .59902 .47479 .59316 Mtetra
.672 .818 .953 r
.47479 .59316 .48312 .59902 .49788 .59677 .48964 .58789 Mtetra
.72 .752 .878 r
.48964 .58789 .49788 .59677 .51275 .59221 .50457 .58053 Mtetra
.728 .704 .827 r
.50457 .58053 .51275 .59221 .52769 .58632 .51957 .5717 Mtetra
.708 .657 .797 r
.51957 .5717 .52769 .58632 .5427 .57919 .5346 .56312 Mtetra
.686 .632 .789 r
.5346 .56312 .5427 .57919 .55777 .57179 .5497 .55568 Mtetra
.673 .626 .794 r
.5497 .55568 .55777 .57179 .5729 .56488 .56486 .54922 Mtetra
.663 .627 .803 r
.56486 .54922 .5729 .56488 .58811 .5587 .5801 .54351 Mtetra
.655 .63 .812 r
.5801 .54351 .58811 .5587 .6034 .55332 .59543 .53838 Mtetra
.648 .631 .819 r
.59543 .53838 .6034 .55332 .61879 .54872 .61085 .53373 Mtetra
.639 .627 .821 r
.61085 .53373 .61879 .54872 .6343 .54493 .62637 .52956 Mtetra
.628 .617 .82 r
.62637 .52956 .6343 .54493 .64993 .54193 .642 .52598 Mtetra
.614 .604 .817 r
.642 .52598 .64993 .54193 .66569 .53968 .65777 .52317 Mtetra
.595 .588 .815 r
.65777 .52317 .66569 .53968 .68159 .53794 .67368 .52136 Mtetra
.573 .577 .819 r
.67368 .52136 .68159 .53794 .6976 .53595 .68977 .5207 Mtetra
.563 .59 .838 r
.68977 .5207 .6976 .53595 .71365 .5327 .70601 .52035 Mtetra
.589 .649 .878 r
.70601 .52035 .71365 .5327 .72973 .52811 .7223 .5185 Mtetra
.634 .727 .915 r
.7223 .5185 .72973 .52811 .74574 .52113 .73857 .51453 Mtetra
.7 .829 .944 r
.73857 .51453 .74574 .52113 .76172 .51271 .75475 .50771 Mtetra
.747 .887 .943 r
.75475 .50771 .76172 .51271 .77778 .50455 .77085 .49884 Mtetra
.74 .867 .939 r
.77085 .49884 .77778 .50455 .79396 .49716 .78704 .49031 Mtetra
.714 .83 .937 r
.78704 .49031 .79396 .49716 .81037 .49157 .80338 .48288 Mtetra
.666 .767 .925 r
.80338 .48288 .81037 .49157 .82694 .48672 .81996 .47743 Mtetra
.653 .748 .919 r
.81996 .47743 .82694 .48672 .8436 .48182 .8367 .47251 Mtetra
.654 .749 .92 r
.8367 .47251 .8436 .48182 .86034 .47667 .85352 .46753 Mtetra
.662 .758 .921 r
.85352 .46753 .86034 .47667 .87716 .47139 .87041 .46217 Mtetra
.658 .756 .922 r
.87041 .46217 .87716 .47139 .89411 .46645 .88741 .45696 Mtetra
.652 .748 .92 r
.88741 .45696 .89411 .46645 .91117 .46153 .90455 .45199 Mtetra
.653 .748 .92 r
.90455 .45199 .91117 .46153 .92832 .45647 .92178 .44694 Mtetra
.66 .751 .917 r
.30855 .62063 .31742 .62843 .33137 .62412 .32254 .61624 Mtetra
.658 .75 .917 r
.32254 .61624 .33137 .62412 .3454 .61975 .33661 .6119 Mtetra
.648 .749 .923 r
.33661 .6119 .3454 .61975 .35949 .61562 .35074 .60791 Mtetra
.653 .755 .924 r
.35074 .60791 .35949 .61562 .37364 .61163 .36495 .60368 Mtetra
.658 .751 .919 r
.36495 .60368 .37364 .61163 .38789 .60729 .37924 .59929 Mtetra
.652 .749 .921 r
.37924 .59929 .38789 .60729 .40221 .60289 .3936 .59506 Mtetra
.594 .737 .944 r
.3936 .59506 .40221 .60289 .41659 .599 .40798 .5926 Mtetra
.501 .745 .982 r
.40798 .5926 .41659 .599 .431 .59705 .42241 .59167 Mtetra
.413 .739 .992 r
.42241 .59167 .431 .59705 .44548 .59617 .43692 .59159 Mtetra
.515 .807 .999 r
.43692 .59159 .44548 .59617 .46006 .59566 .45159 .58942 Mtetra
.682 .809 .944 r
.45159 .58942 .46006 .59566 .47479 .59316 .46642 .58387 Mtetra
.736 .748 .862 r
.46642 .58387 .47479 .59316 .48964 .58789 .48136 .5754 Mtetra
.737 .695 .81 r
.48136 .5754 .48964 .58789 .50457 .58053 .49636 .56546 Mtetra
.712 .654 .79 r
.49636 .56546 .50457 .58053 .51957 .5717 .51139 .55638 Mtetra
.691 .643 .797 r
.51139 .55638 .51957 .5717 .5346 .56312 .52646 .54881 Mtetra
.678 .65 .815 r
.52646 .54881 .5346 .56312 .5497 .55568 .54159 .54247 Mtetra
.659 .659 .839 r
.54159 .54247 .5497 .55568 .56486 .54922 .55681 .53746 Mtetra
.652 .681 .864 r
.55681 .53746 .56486 .54922 .5801 .54351 .57211 .53294 Mtetra
.653 .705 .885 r
.57211 .53294 .5801 .54351 .59543 .53838 .5875 .5284 Mtetra
.657 .719 .895 r
.5875 .5284 .59543 .53838 .61085 .53373 .60297 .5237 Mtetra
.66 .72 .893 r
.60297 .5237 .61085 .53373 .62637 .52956 .61852 .51884 Mtetra
.659 .707 .882 r
.61852 .51884 .62637 .52956 .642 .52598 .63416 .51396 Mtetra
.647 .678 .866 r
.63416 .51396 .642 .52598 .65777 .52317 .64991 .50957 Mtetra
.617 .64 .851 r
.64991 .50957 .65777 .52317 .67368 .52136 .6658 .50654 Mtetra
.592 .61 .84 r
.6658 .50654 .67368 .52136 .68977 .5207 .68187 .50475 Mtetra
.561 .58 .831 r
.68187 .50475 .68977 .5207 .70601 .52035 .69813 .50452 Mtetra
.54 .572 .836 r
.69813 .50452 .70601 .52035 .7223 .5185 .71459 .5052 Mtetra
.564 .623 .869 r
.71459 .5052 .7223 .5185 .73857 .51453 .7311 .5044 Mtetra
.628 .716 .91 r
.7311 .5044 .73857 .51453 .75475 .50771 .74755 .50061 Mtetra
.71 .821 .934 r
.74755 .50061 .75475 .50771 .77085 .49884 .76386 .49335 Mtetra
.759 .879 .933 r
.76386 .49335 .77085 .49884 .78704 .49031 .78007 .48392 Mtetra
.74 .852 .932 r
.78007 .48392 .78704 .49031 .80338 .48288 .7964 .47533 Mtetra
.702 .811 .933 r
.7964 .47533 .80338 .48288 .81996 .47743 .81294 .46832 Mtetra
.659 .757 .923 r
.81294 .46832 .81996 .47743 .8367 .47251 .82972 .46312 Mtetra
.654 .749 .92 r
.82972 .46312 .8367 .47251 .85352 .46753 .84662 .45809 Mtetra
.658 .751 .919 r
.84662 .45809 .85352 .46753 .87041 .46217 .8636 .45288 Mtetra
.663 .758 .921 r
.8636 .45288 .87041 .46217 .88741 .45696 .88065 .44742 Mtetra
.654 .75 .921 r
.88065 .44742 .88741 .45696 .90455 .45199 .89785 .44232 Mtetra
.652 .747 .92 r
.89785 .44232 .90455 .45199 .92178 .44694 .91516 .43727 Mtetra
.661 .751 .917 r
.29958 .61275 .30855 .62063 .32254 .61624 .31363 .60831 Mtetra
.653 .749 .92 r
.31363 .60831 .32254 .61624 .33661 .6119 .32773 .60411 Mtetra
.648 .752 .926 r
.32773 .60411 .33661 .6119 .35074 .60791 .3419 .60007 Mtetra
.658 .755 .921 r
.3419 .60007 .35074 .60791 .36495 .60368 .35617 .59565 Mtetra
.658 .751 .919 r
.35617 .59565 .36495 .60368 .37924 .59929 .37051 .5912 Mtetra
.626 .742 .93 r
.37051 .5912 .37924 .59929 .3936 .59506 .38488 .58782 Mtetra
.528 .732 .968 r
.38488 .58782 .3936 .59506 .40798 .5926 .39926 .58667 Mtetra
.423 .728 .989 r
.39926 .58667 .40798 .5926 .42241 .59167 .4137 .58672 Mtetra
.464 .776 .998 r
.4137 .58672 .42241 .59167 .43692 .59159 .42829 .58555 Mtetra
.67 .813 .952 r
.42829 .58555 .43692 .59159 .45159 .58942 .44309 .58035 Mtetra
.742 .754 .862 r
.44309 .58035 .45159 .58942 .46642 .58387 .45804 .57159 Mtetra
.748 .702 .807 r
.45804 .57159 .46642 .58387 .48136 .5754 .47306 .5608 Mtetra
.72 .663 .793 r
.47306 .5608 .48136 .5754 .49636 .56546 .48809 .55123 Mtetra
.698 .66 .808 r
.48809 .55123 .49636 .56546 .51139 .55638 .50314 .54354 Mtetra
.666 .667 .842 r
.50314 .54354 .51139 .55638 .52646 .54881 .51825 .53821 Mtetra
.642 .699 .887 r
.51825 .53821 .52646 .54881 .54159 .54247 .53344 .5342 Mtetra
.63 .749 .933 r
.53344 .5342 .54159 .54247 .55681 .53746 .54872 .53042 Mtetra
.63 .783 .955 r
.54872 .53042 .55681 .53746 .57211 .53294 .56409 .52638 Mtetra
.637 .8 .961 r
.56409 .52638 .57211 .53294 .5875 .5284 .57955 .52199 Mtetra
.647 .809 .961 r
.57955 .52199 .5875 .5284 .60297 .5237 .59509 .51725 Mtetra
.657 .812 .958 r
.59509 .51725 .60297 .5237 .61852 .51884 .61071 .51215 Mtetra
.668 .81 .951 r
.61071 .51215 .61852 .51884 .63416 .51396 .6264 .50669 Mtetra
.677 .797 .939 r
.6264 .50669 .63416 .51396 .64991 .50957 .64217 .50097 Mtetra
.672 .763 .919 r
.64217 .50097 .64991 .50957 .6658 .50654 .65803 .49547 Mtetra
.64 .698 .887 r
.65803 .49547 .6658 .50654 .68187 .50475 .67403 .49132 Mtetra
.587 .632 .863 r
.67403 .49132 .68187 .50475 .69813 .50452 .69025 .48956 Mtetra
.546 .589 .848 r
.69025 .48956 .69813 .50452 .71459 .5052 .70671 .48974 Mtetra
.518 .568 .845 r
.70671 .48974 .71459 .5052 .7311 .5044 .72338 .49119 Mtetra
.557 .624 .875 r
.72338 .49119 .7311 .5044 .74755 .50061 .74008 .4906 Mtetra
.637 .726 .912 r
.74008 .4906 .74755 .50061 .76386 .49335 .75667 .48635 Mtetra
.735 .834 .926 r
.75667 .48635 .76386 .49335 .78007 .48392 .77305 .47795 Mtetra
.763 .87 .927 r
.77305 .47795 .78007 .48392 .7964 .47533 .7894 .46827 Mtetra
.735 .836 .927 r
.7894 .46827 .7964 .47533 .81294 .46832 .80589 .45979 Mtetra
.68 .782 .927 r
.80589 .45979 .81294 .46832 .82972 .46312 .82267 .45362 Mtetra
.654 .749 .92 r
.82267 .45362 .82972 .46312 .84662 .45809 .83964 .44855 Mtetra
.654 .75 .92 r
.83964 .44855 .84662 .45809 .8636 .45288 .8567 .44344 Mtetra
.662 .757 .92 r
.8567 .44344 .8636 .45288 .88065 .44742 .87383 .43793 Mtetra
.658 .755 .922 r
.87383 .43793 .88065 .44742 .89785 .44232 .89108 .43258 Mtetra
.651 .748 .92 r
.89108 .43258 .89785 .44232 .91516 .43727 .90847 .42748 Mtetra
.66 .751 .917 r
.29054 .60479 .29958 .61275 .31363 .60831 .30462 .60034 Mtetra
.649 .749 .923 r
.30462 .60034 .31363 .60831 .32773 .60411 .31876 .59625 Mtetra
.652 .754 .924 r
.31876 .59625 .32773 .60411 .3419 .60007 .33299 .59201 Mtetra
.658 .751 .919 r
.33299 .59201 .3419 .60007 .35617 .59565 .3473 .58754 Mtetra
.651 .749 .922 r
.3473 .58754 .35617 .59565 .37051 .5912 .36167 .58331 Mtetra
.576 .733 .949 r
.36167 .58331 .37051 .5912 .38488 .58782 .37604 .58123 Mtetra
.463 .727 .983 r
.37604 .58123 .38488 .58782 .39926 .58667 .39042 .58096 Mtetra
.415 .733 .991 r
.39042 .58096 .39926 .58667 .4137 .58672 .40491 .58093 Mtetra
.617 .808 .973 r
.40491 .58093 .4137 .58672 .42829 .58555 .41964 .57712 Mtetra
.733 .767 .88 r
.41964 .57712 .42829 .58555 .44309 .58035 .43457 .56912 Mtetra
.762 .721 .814 r
.43457 .56912 .44309 .58035 .45804 .57159 .44962 .55777 Mtetra
.734 .678 .796 r
.44962 .55777 .45804 .57159 .47306 .5608 .46467 .54735 Mtetra
.707 .674 .815 r
.46467 .54735 .47306 .5608 .48809 .55123 .47973 .53927 Mtetra
.657 .679 .86 r
.47973 .53927 .48809 .55123 .50314 .54354 .4948 .53451 Mtetra
.621 .727 .923 r
.4948 .53451 .50314 .54354 .51825 .53821 .50996 .53114 Mtetra
.607 .775 .961 r
.50996 .53114 .51825 .53821 .53344 .5342 .52521 .52777 Mtetra
.611 .795 .97 r
.52521 .52777 .53344 .5342 .54872 .53042 .54055 .52408 Mtetra
.624 .803 .968 r
.54055 .52408 .54872 .53042 .56409 .52638 .55599 .51998 Mtetra
.636 .807 .965 r
.55599 .51998 .56409 .52638 .57955 .52199 .57151 .51551 Mtetra
.647 .809 .961 r
.57151 .51551 .57955 .52199 .59509 .51725 .58712 .51072 Mtetra
.656 .811 .958 r
.58712 .51072 .59509 .51725 .61071 .51215 .60281 .50561 Mtetra
.667 .816 .955 r
.60281 .50561 .61071 .51215 .6264 .50669 .61858 .50012 Mtetra
.678 .819 .951 r
.61858 .50012 .6264 .50669 .64217 .50097 .63441 .49421 Mtetra
.687 .818 .945 r
.63441 .49421 .64217 .50097 .65803 .49547 .65032 .48798 Mtetra
.688 .8 .934 r
.65032 .48798 .65803 .49547 .67403 .49132 .6663 .48173 Mtetra
.654 .738 .911 r
.6663 .48173 .67403 .49132 .69025 .48956 .68243 .4769 Mtetra
.575 .642 .88 r
.68243 .4769 .69025 .48956 .70671 .48974 .69884 .47545 Mtetra
.521 .588 .863 r
.69884 .47545 .70671 .48974 .72338 .49119 .71551 .4764 Mtetra
.499 .57 .858 r
.71551 .4764 .72338 .49119 .74008 .4906 .73241 .47835 Mtetra
.572 .652 .89 r
.73241 .47835 .74008 .4906 .75667 .48635 .74924 .47688 Mtetra
.672 .755 .913 r
.74924 .47688 .75667 .48635 .77305 .47795 .76589 .47111 Mtetra
.761 .848 .917 r
.76589 .47111 .77305 .47795 .7894 .46827 .78233 .4614 Mtetra
.755 .848 .92 r
.78233 .4614 .7894 .46827 .80589 .45979 .79883 .45192 Mtetra
.713 .812 .927 r
.79883 .45192 .80589 .45979 .82267 .45362 .81556 .4443 Mtetra
.66 .759 .923 r
.81556 .4443 .82267 .45362 .83964 .44855 .83258 .4389 Mtetra
.654 .75 .92 r
.83258 .4389 .83964 .44855 .8567 .44344 .84972 .43374 Mtetra
.659 .752 .919 r
.84972 .43374 .8567 .44344 .87383 .43793 .86694 .42835 Mtetra
.662 .757 .921 r
.86694 .42835 .87383 .43793 .89108 .43258 .88425 .42277 Mtetra
.652 .749 .921 r
.88425 .42277 .89108 .43258 .90847 .42748 .9017 .41757 Mtetra
.657 .75 .919 r
.2814 .59675 .29054 .60479 .30462 .60034 .29552 .59236 Mtetra
.647 .75 .925 r
.29552 .59236 .30462 .60034 .31876 .59625 .3097 .58829 Mtetra
.656 .754 .922 r
.3097 .58829 .31876 .59625 .33299 .59201 .32398 .58387 Mtetra
.659 .751 .918 r
.32398 .58387 .33299 .59201 .3473 .58754 .33834 .57933 Mtetra
.631 .743 .929 r
.33834 .57933 .3473 .58754 .36167 .58331 .35273 .57572 Mtetra
.523 .724 .965 r
.35273 .57572 .36167 .58331 .37604 .58123 .36709 .5747 Mtetra
.416 .71 .984 r
.36709 .5747 .37604 .58123 .39042 .58096 .38149 .57508 Mtetra
.508 .77 .99 r
.38149 .57508 .39042 .58096 .40491 .58093 .39608 .57358 Mtetra
.7 .787 .918 r
.39608 .57358 .40491 .58093 .41964 .57712 .41095 .56731 Mtetra
.767 .746 .834 r
.41095 .56731 .41964 .57712 .43457 .56912 .42601 .55634 Mtetra
.754 .698 .799 r
.42601 .55634 .43457 .56912 .44962 .55777 .44112 .54474 Mtetra
.722 .686 .814 r
.44112 .54474 .44962 .55777 .46467 .54735 .45619 .53571 Mtetra
.665 .689 .863 r
.45619 .53571 .46467 .54735 .47973 .53927 .47125 .53056 Mtetra
.609 .732 .933 r
.47125 .53056 .47973 .53927 .4948 .53451 .48636 .52751 Mtetra
.593 .773 .966 r
.48636 .52751 .4948 .53451 .50996 .53114 .50156 .52447 Mtetra
.604 .787 .969 r
.50156 .52447 .50996 .53114 .52521 .52777 .51687 .521 Mtetra
.642 .797 .957 r
.51687 .521 .52521 .52777 .54055 .52408 .53228 .51647 Mtetra
.653 .779 .941 r
.53228 .51647 .54055 .52408 .55599 .51998 .54777 .51168 Mtetra
.656 .763 .929 r
.54777 .51168 .55599 .51998 .57151 .51551 .56335 .50683 Mtetra
.656 .756 .923 r
.56335 .50683 .57151 .51551 .58712 .51072 .57902 .50199 Mtetra
.655 .755 .924 r
.57902 .50199 .58712 .51072 .60281 .50561 .59478 .49715 Mtetra
.655 .763 .929 r
.59478 .49715 .60281 .50561 .61858 .50012 .61062 .49226 Mtetra
.66 .781 .939 r
.61062 .49226 .61858 .50012 .63441 .49421 .62655 .48711 Mtetra
.686 .811 .942 r
.62655 .48711 .63441 .49421 .65032 .48798 .64254 .48088 Mtetra
.697 .815 .938 r
.64254 .48088 .65032 .48798 .6663 .48173 .65858 .47421 Mtetra
.697 .805 .932 r
.65858 .47421 .6663 .48173 .68243 .4769 .6747 .46753 Mtetra
.644 .743 .921 r
.6747 .46753 .68243 .4769 .69884 .47545 .69101 .46299 Mtetra
.548 .636 .89 r
.69101 .46299 .69884 .47545 .71551 .4764 .70764 .46242 Mtetra
.485 .577 .872 r
.70764 .46242 .71551 .4764 .73241 .47835 .72457 .4645 Mtetra
.501 .589 .875 r
.72457 .4645 .73241 .47835 .74924 .47688 .74164 .46597 Mtetra
.613 .701 .907 r
.74164 .46597 .74924 .47688 .76589 .47111 .75853 .46263 Mtetra
.726 .8 .91 r
.75853 .46263 .76589 .47111 .78233 .4614 .77516 .45435 Mtetra
.769 .849 .911 r
.77516 .45435 .78233 .4614 .79883 .45192 .7917 .4441 Mtetra
.738 .823 .917 r
.7917 .4441 .79883 .45192 .81556 .4443 .80842 .43527 Mtetra
.676 .775 .924 r
.80842 .43527 .81556 .4443 .83258 .4389 .82544 .42913 Mtetra
.653 .749 .92 r
.82544 .42913 .83258 .4389 .84972 .43374 .84266 .42394 Mtetra
.655 .75 .92 r
.84266 .42394 .84972 .43374 .86694 .42835 .85997 .41863 Mtetra
.664 .757 .92 r
.85997 .41863 .86694 .42835 .88425 .42277 .87734 .41293 Mtetra
.655 .752 .921 r
.87734 .41293 .88425 .42277 .9017 .41757 .89486 .40756 Mtetra
.653 .75 .921 r
.27217 .58865 .2814 .59675 .29552 .59236 .28633 .58434 Mtetra
.648 .751 .925 r
.28633 .58434 .29552 .59236 .3097 .58829 .30056 .58018 Mtetra
.658 .753 .92 r
.30056 .58018 .3097 .58829 .32398 .58387 .31489 .57566 Mtetra
.657 .751 .92 r
.31489 .57566 .32398 .58387 .33834 .57933 .32929 .57116 Mtetra
.599 .736 .941 r
.32929 .57116 .33834 .57933 .35273 .57572 .34368 .56846 Mtetra
.481 .719 .975 r
.34368 .56846 .35273 .57572 .36709 .5747 .35804 .56806 Mtetra
.412 .707 .983 r
.35804 .56806 .36709 .5747 .38149 .57508 .37248 .5685 Mtetra
.614 .787 .964 r
.37248 .5685 .38149 .57508 .39608 .57358 .38721 .56492 Mtetra
.743 .766 .871 r
.38721 .56492 .39608 .57358 .41095 .56731 .40221 .55617 Mtetra
.774 .727 .809 r
.40221 .55617 .41095 .56731 .42601 .55634 .41738 .54375 Mtetra
.744 .699 .809 r
.41738 .54375 .42601 .55634 .44112 .54474 .43251 .53316 Mtetra
.695 .701 .851 r
.43251 .53316 .44112 .54474 .45619 .53571 .44758 .52637 Mtetra
.615 .72 .921 r
.44758 .52637 .45619 .53571 .47125 .53056 .46265 .52319 Mtetra
.584 .761 .963 r
.46265 .52319 .47125 .53056 .48636 .52751 .47781 .52046 Mtetra
.603 .777 .964 r
.47781 .52046 .48636 .52751 .50156 .52447 .49308 .5171 Mtetra
.649 .784 .946 r
.49308 .5171 .50156 .52447 .51687 .521 .50846 .51241 Mtetra
.658 .757 .923 r
.50846 .51241 .51687 .521 .53228 .51647 .52392 .50752 Mtetra
.653 .748 .92 r
.52392 .50752 .53228 .51647 .54777 .51168 .53947 .50281 Mtetra
.654 .751 .922 r
.53947 .50281 .54777 .51168 .56335 .50683 .55511 .49804 Mtetra
.656 .755 .923 r
.55511 .49804 .56335 .50683 .57902 .50199 .57083 .49315 Mtetra
.658 .756 .922 r
.57083 .49315 .57902 .50199 .59478 .49715 .58665 .48814 Mtetra
.659 .753 .92 r
.58665 .48814 .59478 .49715 .61062 .49226 .60255 .48307 Mtetra
.654 .748 .919 r
.60255 .48307 .61062 .49226 .62655 .48711 .61855 .47817 Mtetra
.658 .757 .923 r
.61855 .47817 .62655 .48711 .64254 .48088 .63464 .47307 Mtetra
.69 .797 .931 r
.63464 .47307 .64254 .48088 .65858 .47421 .65077 .46663 Mtetra
.706 .808 .929 r
.65077 .46663 .65858 .47421 .6747 .46753 .66695 .45952 Mtetra
.694 .795 .928 r
.66695 .45952 .6747 .46753 .69101 .46299 .68323 .45287 Mtetra
.601 .712 .922 r
.68323 .45287 .69101 .46299 .70764 .46242 .69978 .4499 Mtetra
.502 .615 .896 r
.69978 .4499 .70764 .46242 .72457 .4645 .71669 .45083 Mtetra
.456 .57 .881 r
.71669 .45083 .72457 .4645 .74164 .46597 .73388 .45369 Mtetra
.552 .647 .897 r
.73388 .45369 .74164 .46597 .75853 .46263 .75099 .45279 Mtetra
.679 .755 .909 r
.75099 .45279 .75853 .46263 .77516 .45435 .76786 .44656 Mtetra
.768 .832 .901 r
.76786 .44656 .77516 .45435 .7917 .4441 .78448 .43615 Mtetra
.752 .826 .909 r
.78448 .43615 .7917 .4441 .80842 .43527 .80122 .42658 Mtetra
.7 .793 .923 r
.80122 .42658 .80842 .43527 .82544 .42913 .81824 .41938 Mtetra
.655 .753 .922 r
.81824 .41938 .82544 .42913 .84266 .42394 .83552 .41404 Mtetra
.654 .75 .921 r
.83552 .41404 .84266 .42394 .85997 .41863 .85291 .40873 Mtetra
.662 .755 .919 r
.85291 .40873 .85997 .41863 .87734 .41293 .87037 .40302 Mtetra
.658 .754 .921 r
.87037 .40302 .87734 .41293 .89486 .40756 .88795 .39747 Mtetra
.65 .749 .922 r
.26284 .58048 .27217 .58865 .28633 .58434 .27704 .57623 Mtetra
.65 .752 .924 r
.27704 .57623 .28633 .58434 .30056 .58018 .29132 .57194 Mtetra
.658 .752 .919 r
.29132 .57194 .30056 .58018 .31489 .57566 .3057 .56737 Mtetra
.651 .75 .922 r
.3057 .56737 .31489 .57566 .32929 .57116 .32014 .56301 Mtetra
.566 .728 .951 r
.32014 .56301 .32929 .57116 .34368 .56846 .33452 .5611 Mtetra
.447 .703 .976 r
.33452 .5611 .34368 .56846 .35804 .56806 .3489 .56129 Mtetra
.451 .723 .984 r
.3489 .56129 .35804 .56806 .37248 .5685 .36341 .56111 Mtetra
.678 .784 .93 r
.36341 .56111 .37248 .5685 .38721 .56492 .37827 .55561 Mtetra
.77 .758 .842 r
.37827 .55561 .38721 .56492 .40221 .55617 .39341 .5447 Mtetra
.772 .723 .807 r
.39341 .5447 .40221 .55617 .41738 .54375 .40864 .53222 Mtetra
.737 .715 .831 r
.40864 .53222 .41738 .54375 .43251 .53316 .42379 .52274 Mtetra
.649 .71 .891 r
.42379 .52274 .43251 .53316 .44758 .52637 .43885 .51829 Mtetra
.583 .743 .952 r
.43885 .51829 .44758 .52637 .46265 .52319 .45396 .51575 Mtetra
.586 .762 .963 r
.45396 .51575 .46265 .52319 .47781 .52046 .46918 .51293 Mtetra
.646 .78 .945 r
.46918 .51293 .47781 .52046 .49308 .5171 .48452 .50835 Mtetra
.657 .754 .921 r
.48452 .50835 .49308 .5171 .50846 .51241 .49995 .50349 Mtetra
.649 .748 .922 r
.49995 .50349 .50846 .51241 .52392 .50752 .51547 .4989 Mtetra
.646 .756 .929 r
.51547 .4989 .52392 .50752 .53947 .50281 .53108 .49436 Mtetra
.646 .761 .933 r
.53108 .49436 .53947 .50281 .55511 .49804 .54678 .48976 Mtetra
.655 .769 .934 r
.54678 .48976 .55511 .49804 .57083 .49315 .56257 .48482 Mtetra
.663 .772 .931 r
.56257 .48482 .57083 .49315 .58665 .48814 .57844 .47953 Mtetra
.664 .767 .926 r
.57844 .47953 .58665 .48814 .60255 .48307 .59441 .47419 Mtetra
.663 .761 .923 r
.59441 .47419 .60255 .48307 .61855 .47817 .61046 .46889 Mtetra
.655 .75 .92 r
.61046 .46889 .61855 .47817 .63464 .47307 .62662 .46385 Mtetra
.662 .755 .92 r
.62662 .46385 .63464 .47307 .65077 .46663 .64285 .45854 Mtetra
.704 .797 .923 r
.64285 .45854 .65077 .46663 .66695 .45952 .65911 .45144 Mtetra
.71 .801 .921 r
.65911 .45144 .66695 .45952 .68323 .45287 .67543 .44403 Mtetra
.663 .769 .928 r
.67543 .44403 .68323 .45287 .69978 .4499 .69193 .43855 Mtetra
.526 .654 .916 r
.69193 .43855 .69978 .4499 .71669 .45083 .70881 .43825 Mtetra
.439 .583 .9 r
.70881 .43825 .71669 .45083 .73388 .45369 .72603 .44104 Mtetra
.491 .611 .899 r
.72603 .44104 .73388 .45369 .75099 .45279 .74334 .44226 Mtetra
.633 .724 .913 r
.74334 .44226 .75099 .45279 .76786 .44656 .76041 .43791 Mtetra
.754 .81 .897 r
.76041 .43791 .76786 .44656 .78448 .43615 .77717 .42804 Mtetra
.764 .827 .901 r
.77717 .42804 .78448 .43615 .80122 .42658 .79395 .41775 Mtetra
.719 .799 .914 r
.79395 .41775 .80122 .42658 .81824 .41938 .81097 .40963 Mtetra
.66 .757 .922 r
.81097 .40963 .81824 .41938 .83552 .41404 .8283 .40404 Mtetra
.654 .75 .921 r
.8283 .40404 .83552 .41404 .85291 .40873 .84577 .39867 Mtetra
.66 .753 .919 r
.84577 .39867 .85291 .40873 .87037 .40302 .86331 .39299 Mtetra
.66 .755 .92 r
.86331 .39299 .87037 .40302 .88795 .39747 .88096 .38727 Mtetra
.649 .749 .923 r
.25342 .57225 .26284 .58048 .27704 .57623 .26767 .56801 Mtetra
.653 .752 .923 r
.26767 .56801 .27704 .57623 .29132 .57194 .282 .56361 Mtetra
.659 .752 .919 r
.282 .56361 .29132 .57194 .3057 .56737 .29642 .55896 Mtetra
.644 .747 .924 r
.29642 .55896 .3057 .56737 .32014 .56301 .31089 .55482 Mtetra
.539 .72 .957 r
.31089 .55482 .32014 .56301 .33452 .5611 .32528 .5535 Mtetra
.43 .692 .974 r
.32528 .5535 .33452 .5611 .3489 .56129 .33967 .55402 Mtetra
.516 .738 .975 r
.33967 .55402 .3489 .56129 .36341 .56111 .35428 .55281 Mtetra
.707 .77 .901 r
.35428 .55281 .36341 .56111 .37827 .55561 .36925 .54603 Mtetra
.785 .756 .827 r
.36925 .54603 .37827 .55561 .39341 .5447 .38452 .53366 Mtetra
.771 .731 .816 r
.38452 .53366 .39341 .5447 .40864 .53222 .39979 .52162 Mtetra
.72 .728 .857 r
.39979 .52162 .40864 .53222 .42379 .52274 .41495 .5136 Mtetra
.612 .727 .928 r
.41495 .5136 .42379 .52274 .43885 .51829 .43002 .51038 Mtetra
.575 .747 .958 r
.43002 .51038 .43885 .51829 .45396 .51575 .44518 .50794 Mtetra
.618 .765 .95 r
.44518 .50794 .45396 .51575 .46918 .51293 .46046 .50426 Mtetra
.658 .757 .923 r
.46046 .50426 .46918 .51293 .48452 .50835 .47587 .49932 Mtetra
.647 .746 .922 r
.47587 .49932 .48452 .50835 .49995 .50349 .49135 .49477 Mtetra
.637 .752 .931 r
.49135 .49477 .49995 .50349 .51547 .4989 .50692 .49052 Mtetra
.636 .761 .938 r
.50692 .49052 .51547 .4989 .53108 .49436 .52259 .48622 Mtetra
.648 .772 .939 r
.52259 .48622 .53108 .49436 .54678 .48976 .53836 .48146 Mtetra
.654 .771 .935 r
.53836 .48146 .54678 .48976 .56257 .48482 .55421 .47647 Mtetra
.66 .773 .933 r
.55421 .47647 .56257 .48482 .57844 .47953 .57015 .47124 Mtetra
.672 .779 .93 r
.57015 .47124 .57844 .47953 .59441 .47419 .58618 .46555 Mtetra
.672 .772 .925 r
.58618 .46555 .59441 .47419 .61046 .46889 .60229 .4598 Mtetra
.664 .76 .922 r
.60229 .4598 .61046 .46889 .62662 .46385 .6185 .45436 Mtetra
.654 .748 .919 r
.6185 .45436 .62662 .46385 .64285 .45854 .63481 .4493 Mtetra
.685 .766 .913 r
.63481 .4493 .64285 .45854 .65911 .45144 .65117 .44296 Mtetra
.713 .794 .915 r
.65117 .44296 .65911 .45144 .67543 .44403 .66756 .43535 Mtetra
.695 .785 .92 r
.66756 .43535 .67543 .44403 .69193 .43855 .68406 .42851 Mtetra
.563 .703 .935 r
.68406 .42851 .69193 .43855 .70881 .43825 .70092 .4266 Mtetra
.441 .606 .917 r
.70092 .4266 .70881 .43825 .72603 .44104 .71815 .42882 Mtetra
.436 .592 .908 r
.71815 .42882 .72603 .44104 .74334 .44226 .73559 .43144 Mtetra
.601 .706 .918 r
.73559 .43144 .74334 .44226 .76041 .43791 .75281 .42831 Mtetra
.732 .784 .895 r
.75281 .42831 .76041 .43791 .77717 .42804 .76973 .41939 Mtetra
.768 .818 .892 r
.76973 .41939 .77717 .42804 .79395 .41775 .78657 .40866 Mtetra
.732 .799 .906 r
.78657 .40866 .79395 .41775 .81097 .40963 .80362 .39981 Mtetra
.666 .761 .921 r
.80362 .39981 .81097 .40963 .8283 .40404 .82101 .39389 Mtetra
.653 .749 .92 r
.82101 .39389 .8283 .40404 .84577 .39867 .83855 .38849 Mtetra
.659 .752 .919 r
.83855 .38849 .84577 .39867 .86331 .39299 .85617 .38283 Mtetra
.662 .755 .919 r
.85617 .38283 .86331 .39299 .88096 .38727 .87389 .37698 Mtetra
.647 .749 .924 r
.24391 .56394 .25342 .57225 .26767 .56801 .25819 .5597 Mtetra
.654 .752 .922 r
.25819 .5597 .26767 .56801 .282 .56361 .27258 .5552 Mtetra
.659 .752 .919 r
.27258 .5552 .282 .56361 .29642 .55896 .28705 .5505 Mtetra
.636 .746 .927 r
.28705 .5505 .29642 .55896 .31089 .55482 .30155 .54656 Mtetra
.521 .713 .959 r
.30155 .54656 .31089 .55482 .32528 .5535 .31595 .54558 Mtetra
.427 .683 .97 r
.31595 .54558 .32528 .5535 .33967 .55402 .33037 .54623 Mtetra
.559 .742 .962 r
.33037 .54623 .33967 .55402 .35428 .55281 .34506 .5442 Mtetra
.727 .768 .886 r
.34506 .5442 .35428 .55281 .36925 .54603 .36014 .53634 Mtetra
.791 .757 .821 r
.36014 .53634 .36925 .54603 .38452 .53366 .37551 .52328 Mtetra
.77 .743 .828 r
.37551 .52328 .38452 .53366 .39979 .52162 .39083 .51171 Mtetra
.701 .738 .88 r
.39083 .51171 .39979 .52162 .41495 .5136 .406 .50488 Mtetra
.591 .733 .942 r
.406 .50488 .41495 .5136 .43002 .51038 .4211 .50215 Mtetra
.578 .741 .954 r
.4211 .50215 .43002 .51038 .44518 .50794 .43631 .49964 Mtetra
.64 .762 .936 r
.43631 .49964 .44518 .50794 .46046 .50426 .45167 .49528 Mtetra
.655 .751 .92 r
.45167 .49528 .46046 .50426 .47587 .49932 .46712 .49041 Mtetra
.641 .749 .927 r
.46712 .49041 .47587 .49932 .49135 .49477 .48266 .48603 Mtetra
.628 .75 .935 r
.48266 .48603 .49135 .49477 .50692 .49052 .49829 .48202 Mtetra
.655 .766 .931 r
.49829 .48202 .50692 .49052 .52259 .48622 .51402 .47703 Mtetra
.668 .755 .915 r
.51402 .47703 .52259 .48622 .53836 .48146 .52984 .47153 Mtetra
.656 .736 .908 r
.52984 .47153 .53836 .48146 .55421 .47647 .54575 .46648 Mtetra
.644 .731 .912 r
.54575 .46648 .55421 .47647 .57015 .47124 .56176 .4619 Mtetra
.656 .751 .92 r
.56176 .4619 .57015 .47124 .58618 .46555 .57786 .45679 Mtetra
.68 .774 .922 r
.57786 .45679 .58618 .46555 .60229 .4598 .59403 .45069 Mtetra
.67 .764 .921 r
.59403 .45069 .60229 .4598 .6185 .45436 .6103 .44497 Mtetra
.657 .754 .922 r
.6103 .44497 .6185 .45436 .63481 .4493 .62667 .43973 Mtetra
.669 .755 .915 r
.62667 .43973 .63481 .4493 .65117 .44296 .64312 .43398 Mtetra
.712 .784 .909 r
.64312 .43398 .65117 .44296 .66756 .43535 .65959 .42633 Mtetra
.707 .783 .911 r
.65959 .42633 .66756 .43535 .68406 .42851 .67614 .41888 Mtetra
.599 .731 .937 r
.67614 .41888 .68406 .42851 .70092 .4266 .69299 .41564 Mtetra
.447 .627 .93 r
.69299 .41564 .70092 .4266 .71815 .42882 .71023 .41728 Mtetra
.398 .588 .919 r
.71023 .41728 .71815 .42882 .73559 .43144 .72776 .42049 Mtetra
.571 .692 .923 r
.72776 .42049 .73559 .43144 .75281 .42831 .74512 .41836 Mtetra
.715 .774 .899 r
.74512 .41836 .75281 .42831 .76973 .41939 .76217 .41019 Mtetra
.769 .807 .884 r
.76217 .41019 .76973 .41939 .78657 .40866 .77909 .39921 Mtetra
.738 .795 .898 r
.77909 .39921 .78657 .40866 .80362 .39981 .79618 .3899 Mtetra
.672 .763 .919 r
.79618 .3899 .80362 .39981 .82101 .39389 .81363 .38366 Mtetra
.653 .75 .921 r
.81363 .38366 .82101 .39389 .83855 .38849 .83125 .37821 Mtetra
.657 .752 .92 r
.83125 .37821 .83855 .38849 .85617 .38283 .84895 .37253 Mtetra
.663 .755 .919 r
.84895 .37253 .85617 .38283 .87389 .37698 .86675 .36657 Mtetra
.647 .749 .924 r
.2343 .55555 .24391 .56394 .25819 .5597 .24863 .55128 Mtetra
.655 .752 .921 r
.24863 .55128 .25819 .5597 .27258 .5552 .26306 .54672 Mtetra
.659 .752 .919 r
.26306 .54672 .27258 .5552 .28705 .5505 .27758 .54197 Mtetra
.631 .745 .93 r
.27758 .54197 .28705 .5505 .30155 .54656 .29211 .53816 Mtetra
.515 .709 .959 r
.29211 .53816 .30155 .54656 .31595 .54558 .30655 .53728 Mtetra
.432 .678 .966 r
.30655 .53728 .31595 .54558 .33037 .54623 .321 .53795 Mtetra
.581 .739 .951 r
.321 .53795 .33037 .54623 .34506 .5442 .33575 .53546 Mtetra
.737 .769 .879 r
.33575 .53546 .34506 .5442 .36014 .53634 .35092 .52697 Mtetra
.796 .764 .823 r
.35092 .52697 .36014 .53634 .37551 .52328 .36637 .51364 Mtetra
.772 .758 .84 r
.36637 .51364 .37551 .52328 .39083 .51171 .38175 .50231 Mtetra
.69 .748 .896 r
.38175 .50231 .39083 .51171 .406 .50488 .39695 .49608 Mtetra
.584 .731 .944 r
.39695 .49608 .406 .50488 .4211 .50215 .4121 .4935 Mtetra
.583 .735 .947 r
.4121 .4935 .4211 .50215 .43631 .49964 .42736 .4909 Mtetra
.65 .756 .927 r
.42736 .4909 .43631 .49964 .45167 .49528 .44277 .48617 Mtetra
.652 .749 .921 r
.44277 .48617 .45167 .49528 .46712 .49041 .45828 .48137 Mtetra
.635 .746 .929 r
.45828 .48137 .46712 .49041 .48266 .48603 .47387 .47716 Mtetra
.632 .751 .934 r
.47387 .47716 .48266 .48603 .49829 .48202 .48956 .47299 Mtetra
.673 .761 .917 r
.48956 .47299 .49829 .48202 .51402 .47703 .50536 .46726 Mtetra
.68 .748 .902 r
.50536 .46726 .51402 .47703 .52984 .47153 .52124 .4612 Mtetra
.656 .729 .903 r
.52124 .4612 .52984 .47153 .54575 .46648 .5372 .4561 Mtetra
.631 .72 .911 r
.5372 .4561 .54575 .46648 .56176 .4619 .55327 .45196 Mtetra
.638 .734 .918 r
.55327 .45196 .56176 .4619 .57786 .45679 .56944 .44749 Mtetra
.677 .763 .916 r
.56944 .44749 .57786 .45679 .59403 .45069 .58568 .44144 Mtetra
.675 .765 .918 r
.58568 .44144 .59403 .45069 .6103 .44497 .60201 .43544 Mtetra
.66 .755 .92 r
.60201 .43544 .6103 .44497 .62667 .43973 .61844 .43002 Mtetra
.661 .752 .918 r
.61844 .43002 .62667 .43973 .64312 .43398 .63497 .42454 Mtetra
.71 .775 .903 r
.63497 .42454 .64312 .43398 .65959 .42633 .65151 .41687 Mtetra
.71 .776 .904 r
.65151 .41687 .65959 .42633 .67614 .41888 .66813 .40916 Mtetra
.618 .739 .933 r
.66813 .40916 .67614 .41888 .69299 .41564 .68501 .4052 Mtetra
.448 .643 .941 r
.68501 .4052 .69299 .41564 .71023 .41728 .70229 .40647 Mtetra
.37 .592 .931 r
.70229 .40647 .71023 .41728 .72776 .42049 .71987 .40984 Mtetra
.55 .692 .933 r
.71987 .40984 .72776 .42049 .74512 .41836 .73733 .40825 Mtetra
.706 .77 .902 r
.73733 .40825 .74512 .41836 .76217 .41019 .7545 .40046 Mtetra
.767 .798 .878 r
.7545 .40046 .76217 .41019 .77909 .39921 .77149 .38935 Mtetra
.74 .789 .892 r
.77149 .38935 .77909 .39921 .79618 .3899 .78866 .37982 Mtetra
.676 .764 .917 r
.78866 .37982 .79618 .3899 .81363 .38366 .80617 .37333 Mtetra
.653 .75 .921 r
.80617 .37333 .81363 .38366 .83125 .37821 .82386 .36781 Mtetra
.657 .752 .92 r
.82386 .36781 .83125 .37821 .84895 .37253 .84165 .3621 Mtetra
.664 .755 .918 r
.84165 .3621 .84895 .37253 .86675 .36657 .85952 .35605 Mtetra
.647 .749 .924 r
.22459 .54708 .2343 .55555 .24863 .55128 .23896 .54276 Mtetra
.655 .751 .921 r
.23896 .54276 .24863 .55128 .26306 .54672 .25344 .53815 Mtetra
.659 .752 .919 r
.25344 .53815 .26306 .54672 .27758 .54197 .26801 .53335 Mtetra
.631 .745 .93 r
.26801 .53335 .27758 .54197 .29211 .53816 .28259 .52949 Mtetra
.518 .706 .956 r
.28259 .52949 .29211 .53816 .30655 .53728 .29706 .52858 Mtetra
.44 .673 .962 r
.29706 .52858 .30655 .53728 .321 .53795 .31154 .52922 Mtetra
.584 .731 .944 r
.31154 .52922 .321 .53795 .33575 .53546 .32635 .52668 Mtetra
.737 .77 .88 r
.32635 .52668 .33575 .53546 .35092 .52697 .34158 .51813 Mtetra
.801 .776 .83 r
.34158 .51813 .35092 .52697 .36637 .51364 .35711 .50472 Mtetra
.778 .775 .85 r
.35711 .50472 .36637 .51364 .38175 .50231 .37255 .49334 Mtetra
.691 .76 .905 r
.37255 .49334 .38175 .50231 .39695 .49608 .38781 .48704 Mtetra
.586 .727 .941 r
.38781 .48704 .39695 .49608 .4121 .4935 .40301 .48442 Mtetra
.585 .727 .941 r
.40301 .48442 .4121 .4935 .42736 .4909 .41832 .48178 Mtetra
.651 .75 .922 r
.41832 .48178 .42736 .4909 .44277 .48617 .43379 .47699 Mtetra
.652 .75 .922 r
.43379 .47699 .44277 .48617 .45828 .48137 .44935 .47215 Mtetra
.635 .744 .927 r
.44935 .47215 .45828 .48137 .47387 .47716 .465 .46788 Mtetra
.633 .744 .928 r
.465 .46788 .47387 .47716 .48956 .47299 .48074 .46366 Mtetra
.673 .757 .913 r
.48074 .46366 .48956 .47299 .50536 .46726 .4966 .45787 Mtetra
.68 .759 .91 r
.4966 .45787 .50536 .46726 .52124 .4612 .51254 .45176 Mtetra
.656 .751 .92 r
.51254 .45176 .52124 .4612 .5372 .4561 .52857 .4466 Mtetra
.629 .742 .929 r
.52857 .4466 .5372 .4561 .55327 .45196 .54469 .44241 Mtetra
.637 .745 .926 r
.54469 .44241 .55327 .45196 .56944 .44749 .56092 .43789 Mtetra
.677 .758 .912 r
.56092 .43789 .56944 .44749 .58568 .44144 .57723 .43178 Mtetra
.675 .758 .913 r
.57723 .43178 .58568 .44144 .60201 .43544 .59362 .42572 Mtetra
.66 .753 .918 r
.59362 .42572 .60201 .43544 .61844 .43002 .61013 .42024 Mtetra
.661 .753 .918 r
.61013 .42024 .61844 .43002 .63497 .42454 .62672 .4147 Mtetra
.709 .769 .899 r
.62672 .4147 .63497 .42454 .65151 .41687 .64334 .40696 Mtetra
.64334 .40696 .65151 .41687 .66813 .40916 .66002 .3992 Mtetra
.619 .736 .93 r
.66002 .3992 .66813 .40916 .68501 .4052 .67697 .39517 Mtetra
.438 .65 .949 r
.67697 .39517 .68501 .4052 .70229 .40647 .6943 .3964 Mtetra
.348 .6 .942 r
.6943 .3964 .70229 .40647 .71987 .40984 .71194 .39973 Mtetra
.543 .704 .945 r
.71194 .39973 .71987 .40984 .73733 .40825 .72946 .39809 Mtetra
.706 .771 .903 r
.72946 .39809 .73733 .40825 .7545 .40046 .74671 .39023 Mtetra
.765 .789 .873 r
.74671 .39023 .7545 .40046 .77149 .38935 .76379 .37904 Mtetra
.738 .782 .888 r
.76379 .37904 .77149 .38935 .78866 .37982 .78104 .36944 Mtetra
.676 .76 .914 r
.78104 .36944 .78866 .37982 .80617 .37333 .79862 .36289 Mtetra
.653 .75 .921 r
.79862 .36289 .80617 .37333 .82386 .36781 .8164 .35731 Mtetra
.657 .752 .92 r
.8164 .35731 .82386 .36781 .84165 .3621 .83426 .35152 Mtetra
.664 .755 .918 r
.83426 .35152 .84165 .3621 .85952 .35605 .85221 .34542 Mtetra
.647 .749 .924 r
.21478 .53851 .22459 .54708 .23896 .54276 .2292 .53414 Mtetra
.654 .751 .921 r
.2292 .53414 .23896 .54276 .25344 .53815 .24372 .5295 Mtetra
.659 .752 .919 r
.24372 .5295 .25344 .53815 .26801 .53335 .25834 .52465 Mtetra
.636 .746 .928 r
.25834 .52465 .26801 .53335 .28259 .52949 .27298 .52057 Mtetra
.527 .705 .952 r
.27298 .52057 .28259 .52949 .29706 .52858 .2875 .51948 Mtetra
.45 .669 .957 r
.2875 .51948 .29706 .52858 .31154 .52922 .30202 .52002 Mtetra
.571 .717 .941 r
.30202 .52002 .31154 .52922 .32635 .52668 .31684 .51786 Mtetra
.727 .77 .887 r
.31684 .51786 .32635 .52668 .34158 .51813 .3321 .50983 Mtetra
.804 .788 .838 r
.3321 .50983 .34158 .51813 .35711 .50472 .3477 .49655 Mtetra
.788 .792 .856 r
.3477 .49655 .35711 .50472 .37255 .49334 .36324 .48478 Mtetra
.706 .775 .905 r
.36324 .48478 .37255 .49334 .38781 .48704 .37859 .47778 Mtetra
.593 .727 .937 r
.37859 .47778 .38781 .48704 .40301 .48442 .39384 .47491 Mtetra
.586 .72 .936 r
.39384 .47491 .40301 .48442 .41832 .48178 .40919 .47227 Mtetra
.643 .74 .92 r
.40919 .47227 .41832 .48178 .43379 .47699 .42471 .46775 Mtetra
.655 .751 .921 r
.42471 .46775 .43379 .47699 .44935 .47215 .44033 .46273 Mtetra
.641 .744 .924 r
.44033 .46273 .44935 .47215 .465 .46788 .45604 .45819 Mtetra
.63 .736 .924 r
.45604 .45819 .465 .46788 .48074 .46366 .47183 .45403 Mtetra
.656 .747 .917 r
.47183 .45403 .48074 .46366 .4966 .45787 .48774 .44888 Mtetra
.668 .766 .924 r
.48774 .44888 .4966 .45787 .51254 .45176 .50375 .44321 Mtetra
.654 .774 .937 r
.50375 .44321 .51254 .45176 .52857 .4466 .51984 .43799 Mtetra
.64 .769 .941 r
.51984 .43799 .52857 .4466 .54469 .44241 .53603 .43324 Mtetra
.655 .762 .928 r
.53603 .43324 .54469 .44241 .56092 .43789 .55231 .42797 Mtetra
.679 .754 .908 r
.55231 .42797 .56092 .43789 .57723 .43178 .56868 .42169 Mtetra
.67 .749 .91 r
.56868 .42169 .57723 .43178 .59362 .42572 .58515 .4158 Mtetra
.657 .749 .918 r
.58515 .4158 .59362 .42572 .61013 .42024 .60172 .41038 Mtetra
.669 .756 .916 r
.60172 .41038 .61013 .42024 .62672 .4147 .61837 .40446 Mtetra
.709 .762 .894 r
.61837 .40446 .62672 .4147 .64334 .40696 .63505 .39661 Mtetra
.704 .76 .895 r
.63505 .39661 .64334 .40696 .66002 .3992 .65182 .38897 Mtetra
.6 .725 .932 r
.65182 .38897 .66002 .3992 .67697 .39517 .66886 .38556 Mtetra
.413 .65 .956 r
.66886 .38556 .67697 .39517 .6943 .3964 .68627 .38707 Mtetra
.331 .613 .952 r
.68627 .38707 .6943 .3964 .71194 .39973 .70396 .39016 Mtetra
.557 .726 .953 r
.70396 .39016 .71194 .39973 .72946 .39809 .72151 .38787 Mtetra
.716 .776 .9 r
.72151 .38787 .72946 .39809 .74671 .39023 .7388 .3795 Mtetra
.762 .781 .869 r
.7388 .3795 .74671 .39023 .76379 .37904 .75597 .36829 Mtetra
.734 .773 .884 r
.75597 .36829 .76379 .37904 .78104 .36944 .77332 .35876 Mtetra
.672 .754 .912 r
.77332 .35876 .78104 .36944 .79862 .36289 .79099 .35233 Mtetra
.653 .75 .921 r
.79099 .35233 .79862 .36289 .8164 .35731 .80884 .34669 Mtetra
.657 .752 .92 r
.80884 .34669 .8164 .35731 .83426 .35152 .82679 .34081 Mtetra
.663 .754 .918 r
.82679 .34081 .83426 .35152 .85221 .34542 .84482 .33466 Mtetra
.648 .75 .923 r
.20487 .52987 .21478 .53851 .2292 .53414 .21934 .5254 Mtetra
.653 .75 .921 r
.21934 .5254 .2292 .53414 .24372 .5295 .23391 .52077 Mtetra
.659 .752 .919 r
.23391 .52077 .24372 .5295 .25834 .52465 .24857 .51588 Mtetra
.644 .749 .925 r
.24857 .51588 .25834 .52465 .27298 .52057 .26328 .5115 Mtetra
.544 .71 .949 r
.26328 .5115 .27298 .52057 .2875 .51948 .27786 .50998 Mtetra
.465 .668 .951 r
.27786 .50998 .2875 .51948 .30202 .52002 .29242 .51032 Mtetra
.544 .697 .94 r
.29242 .51032 .30202 .52002 .31684 .51786 .30723 .50891 Mtetra
.706 .765 .898 r
.30723 .50891 .31684 .51786 .3321 .50983 .32249 .50186 Mtetra
.8 .796 .848 r
.32249 .50186 .3321 .50983 .3477 .49655 .33814 .48913 Mtetra
.8 .81 .859 r
.33814 .48913 .3477 .49655 .36324 .48478 .35379 .47675 Mtetra
.734 .794 .9 r
.35379 .47675 .36324 .48478 .37859 .47778 .36926 .46843 Mtetra
.611 .733 .933 r
.36926 .46843 .37859 .47778 .39384 .47491 .38458 .46498 Mtetra
.588 .713 .93 r
.38458 .46498 .39384 .47491 .40919 .47227 .39998 .4623 Mtetra
.625 .726 .92 r
.39998 .4623 .40919 .47227 .42471 .46775 .41553 .45838 Mtetra
.658 .752 .919 r
.41553 .45838 .42471 .46775 .44033 .46273 .43121 .45317 Mtetra
.647 .745 .921 r
.43121 .45317 .44033 .46273 .45604 .45819 .44698 .44836 Mtetra
.639 .738 .92 r
.44698 .44836 .45604 .45819 .47183 .45403 .46284 .44384 Mtetra
.639 .731 .915 r
.46284 .44384 .47183 .45403 .48774 .44888 .47879 .43929 Mtetra
.651 .75 .922 r
.47879 .43929 .48774 .44888 .50375 .44321 .49485 .43426 Mtetra
.655 .767 .932 r
.49485 .43426 .50375 .44321 .51984 .43799 .51101 .42899 Mtetra
.661 .769 .93 r
.51101 .42899 .51984 .43799 .53603 .43324 .52726 .42348 Mtetra
.672 .757 .914 r
.52726 .42348 .53603 .43324 .55231 .42797 .54361 .4175 Mtetra
.672 .742 .903 r
.54361 .4175 .55231 .42797 .56868 .42169 .56004 .41146 Mtetra
.664 .746 .911 r
.56004 .41146 .56868 .42169 .58515 .4158 .57658 .40573 Mtetra
.654 .747 .919 r
.57658 .40573 .58515 .4158 .60172 .41038 .59321 .40039 Mtetra
.684 .761 .91 r
.59321 .40039 .60172 .41038 .61837 .40446 .60992 .39373 Mtetra
.708 .755 .888 r
.60992 .39373 .61837 .40446 .63505 .39661 .62667 .38581 Mtetra
.692 .749 .895 r
.62667 .38581 .63505 .39661 .65182 .38897 .64353 .37865 Mtetra
.561 .708 .94 r
.64353 .37865 .65182 .38897 .66886 .38556 .66069 .37648 Mtetra
.371 .644 .961 r
.66069 .37648 .66886 .38556 .68627 .38707 .67819 .3785 Mtetra
.335 .638 .964 r
.67819 .3785 .68627 .38707 .70396 .39016 .6959 .38091 Mtetra
.588 .751 .955 r
.6959 .38091 .70396 .39016 .72151 .38787 .71346 .37749 Mtetra
.731 .78 .892 r
.71346 .37749 .72151 .38787 .7388 .3795 .73079 .36823 Mtetra
.757 .771 .865 r
.73079 .36823 .7388 .3795 .75597 .36829 .74805 .35712 Mtetra
.726 .764 .884 r
.74805 .35712 .75597 .36829 .77332 .35876 .76551 .34792 Mtetra
.666 .751 .913 r
.76551 .34792 .77332 .35876 .79099 .35233 .78328 .34167 Mtetra
.653 .751 .921 r
.78328 .34167 .79099 .35233 .80884 .34669 .80121 .33595 Mtetra
.659 .753 .92 r
.80121 .33595 .80884 .34669 .82679 .34081 .81923 .32996 Mtetra
.662 .753 .918 r
.81923 .32996 .82679 .34081 .84482 .33466 .83734 .32378 Mtetra
.65 .75 .923 r
.19486 .52114 .20487 .52987 .21934 .5254 .20938 .51656 Mtetra
.651 .749 .921 r
.20938 .51656 .21934 .5254 .23391 .52077 .22399 .51195 Mtetra
.658 .752 .92 r
.22399 .51195 .23391 .52077 .24857 .51588 .2387 .50704 Mtetra
.651 .751 .923 r
.2387 .50704 .24857 .51588 .26328 .5115 .25348 .50235 Mtetra
.57 .72 .943 r
.25348 .50235 .26328 .5115 .27786 .50998 .26814 .50014 Mtetra
.486 .671 .946 r
.26814 .50014 .27786 .50998 .29242 .51032 .28276 .50008 Mtetra
.508 .672 .938 r
.28276 .50008 .29242 .51032 .30723 .50891 .29753 .49964 Mtetra
.678 .754 .908 r
.29753 .49964 .30723 .50891 .32249 .50186 .31278 .49377 Mtetra
.783 .796 .864 r
.31278 .49377 .32249 .50186 .33814 .48913 .32842 .4824 Mtetra
.812 .826 .861 r
.32842 .4824 .33814 .48913 .35379 .47675 .34419 .46942 Mtetra
.765 .815 .892 r
.34419 .46942 .35379 .47675 .36926 .46843 .35981 .4595 Mtetra
.648 .757 .929 r
.35981 .4595 .36926 .46843 .38458 .46498 .37525 .4547 Mtetra
.593 .709 .924 r
.37525 .4547 .38458 .46498 .39998 .4623 .39069 .45183 Mtetra
.602 .71 .92 r
.39069 .45183 .39998 .4623 .41553 .45838 .40626 .44868 Mtetra
.65 .744 .918 r
.40626 .44868 .41553 .45838 .43121 .45317 .42199 .44373 Mtetra
.657 .753 .921 r
.42199 .44373 .43121 .45317 .44698 .44836 .43782 .4385 Mtetra
.649 .743 .918 r
.43782 .4385 .44698 .44836 .46284 .44384 .45375 .43354 Mtetra
.647 .734 .912 r
.45375 .43354 .46284 .44384 .47879 .43929 .46976 .42862 Mtetra
.648 .728 .907 r
.46976 .42862 .47879 .43929 .49485 .43426 .48588 .42365 Mtetra
.656 .733 .906 r
.48588 .42365 .49485 .43426 .51101 .42899 .50209 .41832 Mtetra
.663 .735 .903 r
.50209 .41832 .51101 .42899 .52726 .42348 .5184 .41264 Mtetra
.664 .733 .901 r
.5184 .41264 .52726 .42348 .54361 .4175 .53481 .4069 Mtetra
.663 .739 .907 r
.53481 .4069 .54361 .4175 .56004 .41146 .55131 .40119 Mtetra
.655 .745 .916 r
.55131 .40119 .56004 .41146 .57658 .40573 .56792 .39576 Mtetra
.662 .755 .919 r
.56792 .39576 .57658 .40573 .59321 .40039 .58461 .39004 Mtetra
.702 .761 .898 r
.58461 .39004 .59321 .40039 .60992 .39373 .60137 .3825 Mtetra
.704 .745 .884 r
.60137 .3825 .60992 .39373 .62667 .38581 .61819 .37464 Mtetra
.663 .734 .902 r
.61819 .37464 .62667 .38581 .64353 .37865 .63517 .36875 Mtetra
.499 .692 .954 r
.63517 .36875 .64353 .37865 .66069 .37648 .65245 .3681 Mtetra
.318 .635 .964 r
.65245 .3681 .66069 .37648 .67819 .3785 .67004 .37062 Mtetra
.384 .688 .979 r
.67004 .37062 .67819 .3785 .6959 .38091 .68774 .37152 Mtetra
.627 .766 .946 r
.68774 .37152 .6959 .38091 .71346 .37749 .70531 .36676 Mtetra
.748 .78 .879 r
.70531 .36676 .71346 .37749 .73079 .36823 .72265 .35637 Mtetra
.748 .76 .862 r
.72265 .35637 .73079 .36823 .74805 .35712 .74002 .34556 Mtetra
.713 .755 .885 r
.74002 .34556 .74805 .35712 .76551 .34792 .7576 .33695 Mtetra
.66 .748 .915 r
.7576 .33695 .76551 .34792 .78328 .34167 .77548 .33092 Mtetra
.654 .752 .922 r
.77548 .33092 .78328 .34167 .80121 .33595 .79348 .32509 Mtetra
.66 .754 .919 r
.79348 .32509 .80121 .33595 .81923 .32996 .81157 .31896 Mtetra
.66 .752 .918 r
.81157 .31896 .81923 .32996 .83734 .32378 .82978 .31278 Mtetra
.653 .751 .922 r
.18474 .51234 .19486 .52114 .20938 .51656 .19932 .50761 Mtetra
.648 .748 .922 r
.19932 .50761 .20938 .51656 .22399 .51195 .21396 .50303 Mtetra
.658 .752 .92 r
.21396 .50303 .22399 .51195 .2387 .50704 .22873 .49807 Mtetra
.656 .752 .92 r
.22873 .49807 .2387 .50704 .25348 .50235 .24357 .49314 Mtetra
.6 .731 .937 r
.24357 .49314 .25348 .50235 .26814 .50014 .25834 .49005 Mtetra
.516 .68 .94 r
.25834 .49005 .26814 .50014 .28276 .50008 .27304 .48931 Mtetra
.488 .653 .933 r
.27304 .48931 .28276 .50008 .29753 .49964 .2878 .48941 Mtetra
.628 .721 .914 r
.2878 .48941 .29753 .49964 .31278 .49377 .30296 .48541 Mtetra
.749 .79 .886 r
.30296 .48541 .31278 .49377 .32842 .4824 .31855 .47612 Mtetra
.815 .837 .866 r
.31855 .47612 .32842 .4824 .34419 .46942 .33441 .46306 Mtetra
.79 .839 .89 r
.33441 .46306 .34419 .46942 .35981 .4595 .35018 .45187 Mtetra
.711 .805 .924 r
.35018 .45187 .35981 .4595 .37525 .4547 .3658 .44457 Mtetra
.614 .722 .923 r
.3658 .44457 .37525 .4547 .39069 .45183 .38132 .44096 Mtetra
.601 .703 .915 r
.38132 .44096 .39069 .45183 .40626 .44868 .39693 .43781 Mtetra
.619 .711 .911 r
.39693 .43781 .40626 .44868 .42199 .44373 .41267 .434 Mtetra
.653 .748 .919 r
.41267 .434 .42199 .44373 .43782 .4385 .42856 .42883 Mtetra
.658 .752 .92 r
.42856 .42883 .43782 .4385 .45375 .43354 .44455 .42346 Mtetra
.653 .743 .916 r
.44455 .42346 .45375 .43354 .46976 .42862 .46063 .41826 Mtetra
.654 .738 .912 r
.46063 .41826 .46976 .42862 .48588 .42365 .4768 .413 Mtetra
.656 .734 .907 r
.4768 .413 .48588 .42365 .50209 .41832 .49308 .40761 Mtetra
.658 .735 .906 r
.49308 .40761 .50209 .41832 .5184 .41264 .50945 .4021 Mtetra
.659 .74 .91 r
.50945 .4021 .5184 .41264 .53481 .4069 .52592 .39652 Mtetra
.654 .743 .915 r
.52592 .39652 .53481 .4069 .55131 .40119 .54249 .39112 Mtetra
.659 .753 .919 r
.54249 .39112 .55131 .40119 .56792 .39576 .55915 .3855 Mtetra
.69 .76 .905 r
.55915 .3855 .56792 .39576 .58461 .39004 .5759 .37851 Mtetra
.699 .739 .882 r
.5759 .37851 .58461 .39004 .60137 .3825 .59272 .37083 Mtetra
.689 .734 .885 r
.59272 .37083 .60137 .3825 .61819 .37464 .60963 .36362 Mtetra
.6 .714 .924 r
.60963 .36362 .61819 .37464 .63517 .36875 .62675 .36016 Mtetra
.419 .688 .974 r
.62675 .36016 .63517 .36875 .65245 .3681 .64415 .36069 Mtetra
.276 .64 .965 r
.64415 .36069 .65245 .3681 .67004 .37062 .66181 .36318 Mtetra
.475 .751 .99 r
.66181 .36318 .67004 .37062 .68774 .37152 .67948 .36183 Mtetra
.679 .781 .927 r
.67948 .36183 .68774 .37152 .70531 .36676 .69702 .35502 Mtetra
.753 .764 .862 r
.69702 .35502 .70531 .36676 .72265 .35637 .7144 .34395 Mtetra
.736 .748 .862 r
.7144 .34395 .72265 .35637 .74002 .34556 .73189 .33372 Mtetra
.695 .745 .89 r
.73189 .33372 .74002 .34556 .7576 .33695 .74962 .32591 Mtetra
.655 .747 .918 r
.74962 .32591 .7576 .33695 .77548 .33092 .76758 .32 Mtetra
.654 .751 .921 r
.76758 .32 .77548 .33092 .79348 .32509 .78567 .31411 Mtetra
.662 .755 .919 r
.78567 .31411 .79348 .32509 .81157 .31896 .80383 .30781 Mtetra
.658 .751 .918 r
.80383 .30781 .81157 .31896 .82978 .31278 .82213 .30167 Mtetra
.657 .753 .921 r
.17451 .50346 .18474 .51234 .19932 .50761 .18915 .49855 Mtetra
.647 .747 .923 r
.18915 .49855 .19932 .50761 .21396 .50303 .20384 .49397 Mtetra
.656 .751 .919 r
.20384 .49397 .21396 .50303 .22873 .49807 .21865 .48902 Mtetra
.659 .753 .919 r
.21865 .48902 .22873 .49807 .24357 .49314 .23354 .48395 Mtetra
.631 .743 .929 r
.23354 .48395 .24357 .49314 .25834 .49005 .24845 .47983 Mtetra
.544 .691 .935 r
.24845 .47983 .25834 .49005 .27304 .48931 .26323 .47837 Mtetra
.492 .654 .931 r
.26323 .47837 .27304 .48931 .2878 .48941 .27802 .47835 Mtetra
.566 .683 .919 r
.27802 .47835 .2878 .48941 .30296 .48541 .29308 .47639 Mtetra
.699 .77 .906 r
.29308 .47639 .30296 .48541 .31855 .47612 .30858 .46951 Mtetra
.795 .834 .881 r
.30858 .46951 .31855 .47612 .33441 .46306 .32444 .4578 Mtetra
.811 .865 .888 r
.32444 .4578 .33441 .46306 .35018 .45187 .34037 .44545 Mtetra
.763 .842 .911 r
.34037 .44545 .35018 .45187 .3658 .44457 .35618 .43573 Mtetra
.669 .771 .926 r
.35618 .43573 .3658 .44457 .38132 .44096 .37186 .42999 Mtetra
.612 .707 .912 r
.37186 .42999 .38132 .44096 .39693 .43781 .38753 .42641 Mtetra
.612 .7 .906 r
.38753 .42641 .39693 .43781 .41267 .434 .40331 .42283 Mtetra
.623 .709 .908 r
.40331 .42283 .41267 .434 .42856 .42883 .41921 .41881 Mtetra
.65 .744 .918 r
.41921 .41881 .42856 .42883 .44455 .42346 .43525 .41369 Mtetra
.656 .753 .921 r
.43525 .41369 .44455 .42346 .46063 .41826 .45139 .40831 Mtetra
.657 .75 .919 r
.45139 .40831 .46063 .41826 .4768 .413 .46763 .40286 Mtetra
.656 .747 .917 r
.46763 .40286 .4768 .413 .49308 .40761 .48396 .39741 Mtetra
.655 .747 .917 r
.48396 .39741 .49308 .40761 .50945 .4021 .5004 .39196 Mtetra
.656 .75 .919 r
.5004 .39196 .50945 .4021 .52592 .39652 .51693 .38646 Mtetra
.662 .755 .919 r
.51693 .38646 .52592 .39652 .54249 .39112 .53356 .38068 Mtetra
.687 .756 .905 r
.53356 .38068 .54249 .39112 .55915 .3855 .55029 .37378 Mtetra
.692 .734 .883 r
.55029 .37378 .55915 .3855 .5759 .37851 .56709 .36643 Mtetra
.691 .728 .879 r
.56709 .36643 .5759 .37851 .59272 .37083 .58398 .35907 Mtetra
.644 .718 .902 r
.58398 .35907 .59272 .37083 .60963 .36362 .60101 .35389 Mtetra
.508 .705 .959 r
.60101 .35389 .60963 .36362 .62675 .36016 .61827 .35279 Mtetra
.318 .668 .975 r
.61827 .35279 .62675 .36016 .64415 .36069 .63578 .3544 Mtetra
.31 .694 .978 r
.63578 .3544 .64415 .36069 .66181 .36318 .65346 .3554 Mtetra
.584 .793 .979 r
.65346 .3554 .66181 .36318 .67948 .36183 .67109 .35144 Mtetra
.724 .783 .899 r
.67109 .35144 .67948 .36183 .69702 .35502 .6886 .3424 Mtetra
.747 .749 .854 r
.6886 .3424 .69702 .35502 .7144 .34395 .70606 .33132 Mtetra
.724 .742 .866 r
.70606 .33132 .7144 .34395 .73189 .33372 .72367 .32171 Mtetra
.675 .737 .897 r
.72367 .32171 .73189 .33372 .74962 .32591 .74154 .31485 Mtetra
.653 .749 .92 r
.74154 .31485 .74962 .32591 .76758 .32 .75959 .30896 Mtetra
.655 .752 .921 r
.75959 .30896 .76758 .32 .78567 .31411 .77775 .30295 Mtetra
.664 .754 .917 r
.77775 .30295 .78567 .31411 .80383 .30781 .796 .29653 Mtetra
.655 .749 .919 r
.796 .29653 .80383 .30781 .82213 .30167 .81439 .29044 Mtetra
.66 .754 .92 r
.16418 .4945 .17451 .50346 .18915 .49855 .17887 .48943 Mtetra
.648 .748 .922 r
.17887 .48943 .18915 .49855 .20384 .49397 .19361 .48475 Mtetra
.653 .748 .92 r
.19361 .48475 .20384 .49397 .21865 .48902 .20846 .47988 Mtetra
.658 .753 .92 r
.20846 .47988 .21865 .48902 .23354 .48395 .2234 .47479 Mtetra
.651 .751 .923 r
.2234 .47479 .23354 .48395 .24845 .47983 .23841 .46993 Mtetra
.582 .715 .934 r
.23841 .46993 .24845 .47983 .26323 .47837 .25332 .46729 Mtetra
.521 .666 .927 r
.25332 .46729 .26323 .47837 .27802 .47835 .2682 .46652 Mtetra
.517 .649 .917 r
.2682 .46652 .27802 .47835 .29308 .47639 .28318 .466 Mtetra
.637 .726 .913 r
.28318 .466 .29308 .47639 .30858 .46951 .29856 .46156 Mtetra
.74 .803 .903 r
.29856 .46156 .30858 .46951 .32444 .4578 .31432 .45278 Mtetra
.81 .872 .893 r
.31432 .45278 .32444 .4578 .34037 .44545 .33033 .44053 Mtetra
.794 .879 .908 r
.33033 .44053 .34037 .44545 .35618 .43573 .34632 .42925 Mtetra
.744 .843 .925 r
.34632 .42925 .35618 .43573 .37186 .42999 .36223 .42038 Mtetra
.66 .754 .92 r
.36223 .42038 .37186 .42999 .38753 .42641 .37803 .41493 Mtetra
.622 .704 .904 r
.37803 .41493 .38753 .42641 .40331 .42283 .39387 .41092 Mtetra
.622 .696 .898 r
.39387 .41092 .40331 .42283 .41921 .41881 .40981 .4069 Mtetra
.63 .7 .896 r
.40981 .4069 .41921 .41881 .43525 .41369 .42588 .40254 Mtetra
.64 .72 .906 r
.42588 .40254 .43525 .41369 .45139 .40831 .44206 .39776 Mtetra
.649 .737 .914 r
.44206 .39776 .45139 .40831 .46763 .40286 .45835 .39258 Mtetra
.656 .747 .917 r
.45835 .39258 .46763 .40286 .48396 .39741 .47475 .38707 Mtetra
.663 .749 .914 r
.47475 .38707 .48396 .39741 .5004 .39196 .49125 .38124 Mtetra
.672 .745 .906 r
.49125 .38124 .5004 .39196 .51693 .38646 .50784 .37499 Mtetra
.679 .734 .892 r
.50784 .37499 .51693 .38646 .53356 .38068 .52454 .36832 Mtetra
.683 .72 .877 r
.52454 .36832 .53356 .38068 .55029 .37378 .54132 .36129 Mtetra
.683 .719 .877 r
.54132 .36129 .55029 .37378 .56709 .36643 .55819 .35425 Mtetra
.652 .714 .893 r
.55819 .35425 .56709 .36643 .58398 .35907 .57517 .34867 Mtetra
.549 .71 .946 r
.57517 .34867 .58398 .35907 .60101 .35389 .59234 .34657 Mtetra
.381 .707 .985 r
.59234 .34657 .60101 .35389 .61827 .35279 .60972 .34694 Mtetra
.26 .677 .966 r
.60972 .34694 .61827 .35279 .63578 .3544 .6273 .34834 Mtetra
.469 .789 .999 r
.6273 .34834 .63578 .3544 .65346 .3554 .64495 .3462 Mtetra
.671 .794 .94 r
.64495 .3462 .65346 .3554 .67109 .35144 .66255 .33961 Mtetra
.745 .763 .868 r
.66255 .33961 .67109 .35144 .6886 .3424 .68005 .32896 Mtetra
.732 .733 .851 r
.68005 .32896 .6886 .3424 .70606 .33132 .69763 .31854 Mtetra
.704 .735 .875 r
.69763 .31854 .70606 .33132 .72367 .32171 .71539 .31002 Mtetra
.66 .74 .909 r
.71539 .31002 .72367 .32171 .74154 .31485 .73339 .3038 Mtetra
.654 .752 .922 r
.73339 .3038 .74154 .31485 .75959 .30896 .75152 .29781 Mtetra
.659 .753 .92 r
.75152 .29781 .75959 .30896 .77775 .30295 .76974 .29157 Mtetra
.662 .752 .917 r
.76974 .29157 .77775 .30295 .796 .29653 .78807 .28514 Mtetra
.652 .749 .92 r
.78807 .28514 .796 .29653 .81439 .29044 .80656 .2791 Mtetra
.661 .754 .919 r
.15373 .48546 .16418 .4945 .17887 .48943 .16848 .4803 Mtetra
.653 .751 .922 r
.16848 .4803 .17887 .48943 .19361 .48475 .18329 .4754 Mtetra
.648 .747 .921 r
.18329 .4754 .19361 .48475 .20846 .47988 .19816 .47064 Mtetra
.658 .753 .92 r
.19816 .47064 .20846 .47988 .2234 .47479 .21316 .4655 Mtetra
.21316 .4655 .2234 .47479 .23841 .46993 .22824 .46032 Mtetra
.626 .738 .928 r
.22824 .46032 .23841 .46993 .25332 .46729 .24331 .45624 Mtetra
.555 .683 .924 r
.24331 .45624 .25332 .46729 .2682 .46652 .25829 .45448 Mtetra
.516 .647 .915 r
.25829 .45448 .2682 .46652 .28318 .466 .2733 .45395 Mtetra
.56 .666 .909 r
.2733 .45395 .28318 .466 .29856 .46156 .28852 .45216 Mtetra
.674 .762 .916 r
.28852 .45216 .29856 .46156 .31432 .45278 .30415 .44617 Mtetra
.76 .84 .912 r
.30415 .44617 .31432 .45278 .33033 .44053 .3201 .43648 Mtetra
.804 .899 .91 r
.3201 .43648 .33033 .44053 .34632 .42925 .33622 .42467 Mtetra
.779 .891 .924 r
.33622 .42467 .34632 .42925 .36223 .42038 .3523 .41413 Mtetra
.736 .851 .934 r
.3523 .41413 .36223 .42038 .37803 .41493 .36833 .40553 Mtetra
.675 .767 .92 r
.36833 .40553 .37803 .41493 .39387 .41092 .38432 .39938 Mtetra
.64 .713 .9 r
.38432 .39938 .39387 .41092 .40981 .4069 .40034 .39459 Mtetra
.633 .697 .891 r
.40034 .39459 .40981 .4069 .42588 .40254 .41645 .39004 Mtetra
.639 .696 .887 r
.41645 .39004 .42588 .40254 .44206 .39776 .43268 .38521 Mtetra
.646 .699 .885 r
.43268 .38521 .44206 .39776 .45835 .39258 .44902 .38001 Mtetra
.654 .703 .883 r
.44902 .38001 .45835 .39258 .47475 .38707 .46547 .37444 Mtetra
.661 .706 .88 r
.46547 .37444 .47475 .38707 .49125 .38124 .48202 .36849 Mtetra
.668 .708 .877 r
.48202 .36849 .49125 .38124 .50784 .37499 .49868 .36217 Mtetra
.673 .709 .875 r
.49868 .36217 .50784 .37499 .52454 .36832 .51542 .35556 Mtetra
.668 .71 .879 r
.51542 .35556 .52454 .36832 .54132 .36129 .53227 .34918 Mtetra
.638 .711 .9 r
.53227 .34918 .54132 .36129 .55819 .35425 .54922 .34419 Mtetra
.559 .724 .951 r
.54922 .34419 .55819 .35425 .57517 .34867 .56631 .34167 Mtetra
.414 .735 .992 r
.56631 .34167 .57517 .34867 .59234 .34657 .58359 .34116 Mtetra
.271 .697 .967 r
.58359 .34116 .59234 .34657 .60972 .34694 .60106 .34196 Mtetra
.384 .773 .989 r
.60106 .34196 .60972 .34694 .6273 .34834 .61866 .34063 Mtetra
.62 .813 .974 r
.61866 .34063 .6273 .34834 .64495 .3462 .63628 .33551 Mtetra
.729 .782 .894 r
.63628 .33551 .64495 .3462 .66255 .33961 .65384 .32606 Mtetra
.737 .733 .848 r
.65384 .32606 .66255 .33961 .68005 .32896 .67142 .31529 Mtetra
.717 .725 .857 r
.67142 .31529 .68005 .32896 .69763 .31854 .68912 .30576 Mtetra
.677 .727 .887 r
.68912 .30576 .69763 .31854 .71539 .31002 .70704 .29861 Mtetra
.654 .746 .917 r
.70704 .29861 .71539 .31002 .73339 .3038 .72513 .29259 Mtetra
.654 .751 .921 r
.72513 .29259 .73339 .3038 .75152 .29781 .74334 .28652 Mtetra
.663 .755 .919 r
.74334 .28652 .75152 .29781 .76974 .29157 .76164 .28004 Mtetra
.658 .75 .917 r
.76164 .28004 .76974 .29157 .78807 .28514 .78007 .27371 Mtetra
.651 .75 .922 r
.78007 .27371 .78807 .28514 .80656 .2791 .79864 .26763 Mtetra
.66 .754 .919 r
.14317 .47631 .15373 .48546 .16848 .4803 .15797 .47111 Mtetra
.658 .754 .92 r
.15797 .47111 .16848 .4803 .18329 .4754 .17284 .46596 Mtetra
.648 .747 .922 r
.17284 .46596 .18329 .4754 .19816 .47064 .18777 .46116 Mtetra
.654 .748 .919 r
.18777 .46116 .19816 .47064 .21316 .4655 .2028 .45612 Mtetra
.658 .753 .92 r
.2028 .45612 .21316 .4655 .22824 .46032 .21793 .45089 Mtetra
.652 .752 .922 r
.21793 .45089 .22824 .46032 .24331 .45624 .23314 .44584 Mtetra
.599 .715 .926 r
.23314 .44584 .24331 .45624 .25829 .45448 .24827 .44262 Mtetra
.552 .668 .914 r
.24827 .44262 .25829 .45448 .2733 .45395 .26339 .441 Mtetra
.528 .637 .902 r
.26339 .441 .2733 .45395 .28852 .45216 .27856 .44025 Mtetra
.592 .685 .906 r
.27856 .44025 .28852 .45216 .30415 .44617 .29402 .43732 Mtetra
.684 .78 .923 r
.29402 .43732 .30415 .44617 .3201 .43648 .30982 .43085 Mtetra
.757 .866 .929 r
.30982 .43085 .3201 .43648 .33622 .42467 .32589 .42132 Mtetra
.786 .92 .927 r
.32589 .42132 .33622 .42467 .3523 .41413 .34211 .41026 Mtetra
.767 .911 .937 r
.34211 .41026 .3523 .41413 .36833 .40553 .35831 .40009 Mtetra
.733 .874 .946 r
.35831 .40009 .36833 .40553 .38432 .39938 .3745 .39149 Mtetra
.702 .812 .933 r
.3745 .39149 .38432 .39938 .40034 .39459 .39069 .38416 Mtetra
.666 .747 .911 r
.39069 .38416 .40034 .39459 .41645 .39004 .40691 .37822 Mtetra
.652 .716 .895 r
.40691 .37822 .41645 .39004 .43268 .38521 .4232 .37278 Mtetra
.651 .706 .887 r
.4232 .37278 .43268 .38521 .44902 .38001 .4396 .36732 Mtetra
.654 .703 .883 r
.4396 .36732 .44902 .38001 .46547 .37444 .4561 .36168 Mtetra
.657 .704 .882 r
.4561 .36168 .46547 .37444 .48202 .36849 .4727 .35586 Mtetra
.657 .708 .885 r
.4727 .35586 .48202 .36849 .49868 .36217 .48941 .35003 Mtetra
.646 .714 .897 r
.48941 .35003 .49868 .36217 .51542 .35556 .50621 .34469 Mtetra
.607 .726 .929 r
.50621 .34469 .51542 .35556 .53227 .34918 .52312 .34075 Mtetra
.543 .759 .977 r
.52312 .34075 .53227 .34918 .54922 .34419 .54016 .33811 Mtetra
.409 .758 .995 r
.54016 .33811 .54922 .34419 .56631 .34167 .55736 .33709 Mtetra
.285 .726 .964 r
.55736 .33709 .56631 .34167 .58359 .34116 .57473 .337 Mtetra
.364 .782 .977 r
.57473 .337 .58359 .34116 .60106 .34196 .59224 .33536 Mtetra
.592 .832 .99 r
.59224 .33536 .60106 .34196 .61866 .34063 .60983 .3306 Mtetra
.71 .791 .914 r
.60983 .3306 .61866 .34063 .63628 .33551 .62743 .32221 Mtetra
.736 .738 .853 r
.62743 .32221 .63628 .33551 .65384 .32606 .64502 .31156 Mtetra
.716 .713 .846 r
.64502 .31156 .65384 .32606 .67142 .31529 .66271 .30177 Mtetra
.693 .721 .871 r
.66271 .30177 .67142 .31529 .68912 .30576 .68056 .29362 Mtetra
.658 .734 .906 r
.68056 .29362 .68912 .30576 .70704 .29861 .69861 .28735 Mtetra
.654 .752 .922 r
.69861 .28735 .70704 .29861 .72513 .29259 .71678 .28125 Mtetra
.658 .753 .92 r
.71678 .28125 .72513 .29259 .74334 .28652 .73506 .27495 Mtetra
.663 .752 .916 r
.73506 .27495 .74334 .28652 .76164 .28004 .75344 .26839 Mtetra
.654 .748 .919 r
.75344 .26839 .76164 .28004 .78007 .27371 .77196 .26218 Mtetra
.652 .751 .923 r
.77196 .26218 .78007 .27371 .79864 .26763 .79062 .25602 Mtetra
.659 .753 .92 r
.1325 .46705 .14317 .47631 .15797 .47111 .14734 .46184 Mtetra
.66 .755 .92 r
.14734 .46184 .15797 .47111 .17284 .46596 .16228 .45656 Mtetra
.653 .751 .922 r
.16228 .45656 .17284 .46596 .18777 .46116 .17727 .45153 Mtetra
.648 .746 .921 r
.17727 .45153 .18777 .46116 .2028 .45612 .19233 .44664 Mtetra
.658 .753 .92 r
.19233 .44664 .2028 .45612 .21793 .45089 .20751 .44136 Mtetra
.659 .753 .92 r
.20751 .44136 .21793 .45089 .23314 .44584 .22279 .43602 Mtetra
.643 .744 .922 r
.22279 .43602 .23314 .44584 .24827 .44262 .23811 .43122 Mtetra
.586 .693 .916 r
.23811 .43122 .24827 .44262 .26339 .441 .25335 .42843 Mtetra
.553 .658 .905 r
.25335 .42843 .26339 .441 .27856 .44025 .26861 .42678 Mtetra
.545 .638 .893 r
.26861 .42678 .27856 .44025 .29402 .43732 .28397 .42549 Mtetra
.602 .694 .908 r
.28397 .42549 .29402 .43732 .30982 .43085 .29961 .42211 Mtetra
.678 .784 .93 r
.29961 .42211 .30982 .43085 .32589 .42132 .31555 .41582 Mtetra
.73 .871 .947 r
.31555 .41582 .32589 .42132 .34211 .41026 .3317 .40732 Mtetra
.756 .932 .944 r
.3317 .40732 .34211 .41026 .35831 .40009 .34801 .39727 Mtetra
.746 .935 .949 r
.34801 .39727 .35831 .40009 .3745 .39149 .36435 .38749 Mtetra
.721 .909 .96 r
.36435 .38749 .3745 .39149 .39069 .38416 .38069 .37889 Mtetra
.698 .878 .965 r
.38069 .37889 .39069 .38416 .40691 .37822 .39706 .37131 Mtetra
.682 .836 .957 r
.39706 .37131 .40691 .37822 .4232 .37278 .41348 .36451 Mtetra
.668 .802 .947 r
.41348 .36451 .4232 .37278 .4396 .36732 .42997 .35832 Mtetra
.655 .782 .942 r
.42997 .35832 .4396 .36732 .4561 .36168 .44654 .35262 Mtetra
.64 .777 .947 r
.44654 .35262 .4561 .36168 .4727 .35586 .46321 .34741 Mtetra
.616 .786 .963 r
.46321 .34741 .4727 .35586 .48941 .35003 .47997 .34282 Mtetra
.573 .802 .986 r
.47997 .34282 .48941 .35003 .50621 .34469 .49684 .33901 Mtetra
.491 .808 1 r
.49684 .33901 .50621 .34469 .52312 .34075 .51384 .33625 Mtetra
.376 .78 .984 r
.51384 .33625 .52312 .34075 .54016 .33811 .53097 .3347 Mtetra
.302 .76 .951 r
.53097 .3347 .54016 .33811 .55736 .33709 .54827 .33344 Mtetra
.413 .819 .979 r
.54827 .33344 .55736 .33709 .57473 .337 .5657 .33062 Mtetra
.599 .841 .99 r
.5657 .33062 .57473 .337 .59224 .33536 .58324 .32555 Mtetra
.703 .794 .921 r
.58324 .32555 .59224 .33536 .60983 .3306 .60083 .31751 Mtetra
.73 .74 .86 r
.60083 .31751 .60983 .3306 .62743 .32221 .61844 .30729 Mtetra
.715 .707 .842 r
.61844 .30729 .62743 .32221 .64502 .31156 .63613 .29743 Mtetra
.7 .715 .86 r
.63613 .29743 .64502 .31156 .66271 .30177 .65394 .28871 Mtetra
.665 .72 .89 r
.65394 .28871 .66271 .30177 .68056 .29362 .67194 .28206 Mtetra
.653 .746 .918 r
.67194 .28206 .68056 .29362 .69861 .28735 .69007 .27596 Mtetra
.654 .752 .922 r
.69007 .27596 .69861 .28735 .71678 .28125 .70833 .26978 Mtetra
.663 .755 .919 r
.70833 .26978 .71678 .28125 .73506 .27495 .72667 .26319 Mtetra
.658 .749 .917 r
.72667 .26319 .73506 .27495 .75344 .26839 .74515 .25674 Mtetra
.652 .75 .922 r
.74515 .25674 .75344 .26839 .77196 .26218 .76377 .25054 Mtetra
.653 .752 .923 r
.76377 .25054 .77196 .26218 .79062 .25602 .7825 .24425 Mtetra
.657 .752 .92 r
.12172 .45766 .1325 .46705 .14734 .46184 .13661 .45246 Mtetra
.66 .754 .92 r
.13661 .45246 .14734 .46184 .16228 .45656 .15159 .44713 Mtetra
.659 .754 .92 r
.15159 .44713 .16228 .45656 .17727 .45153 .16665 .44182 Mtetra
.649 .747 .921 r
.16665 .44182 .17727 .45153 .19233 .44664 .18176 .43684 Mtetra
.652 .747 .919 r
.18176 .43684 .19233 .44664 .20751 .44136 .19698 .43173 Mtetra
.658 .753 .92 r
.19698 .43173 .20751 .44136 .22279 .43602 .2123 .42637 Mtetra
.658 .754 .921 r
.2123 .42637 .22279 .43602 .23811 .43122 .22772 .42096 Mtetra
.637 .736 .92 r
.22772 .42096 .23811 .43122 .25335 .42843 .24317 .4163 Mtetra
.586 .681 .907 r
.24317 .4163 .25335 .42843 .26861 .42678 .25855 .41348 Mtetra
.564 .652 .894 r
.25855 .41348 .26861 .42678 .28397 .42549 .27399 .41146 Mtetra
.557 .637 .886 r
.27399 .41146 .28397 .42549 .29961 .42211 .28954 .40973 Mtetra
.595 .684 .903 r
.28954 .40973 .29961 .42211 .31555 .41582 .30531 .40652 Mtetra
.659 .771 .932 r
.30531 .40652 .31555 .41582 .3317 .40732 .32135 .40085 Mtetra
.691 .845 .957 r
.32135 .40085 .3317 .40732 .34801 .39727 .33757 .39377 Mtetra
.708 .918 .965 r
.33757 .39377 .34801 .39727 .36435 .38749 .35395 .38538 Mtetra
.695 .944 .96 r
.35395 .38538 .36435 .38749 .38069 .37889 .3704 .3767 Mtetra
.674 .94 .965 r
.3704 .3767 .38069 .37889 .39706 .37131 .3869 .36853 Mtetra
.653 .925 .974 r
.3869 .36853 .39706 .37131 .41348 .36451 .40345 .36111 Mtetra
.628 .908 .983 r
.40345 .36111 .41348 .36451 .42997 .35832 .42005 .35453 Mtetra
.597 .891 .99 r
.42005 .35453 .42997 .35832 .44654 .35262 .43672 .34877 Mtetra
.555 .876 .993 r
.43672 .34877 .44654 .35262 .46321 .34741 .45348 .34385 Mtetra
.497 .859 .989 r
.45348 .34385 .46321 .34741 .47997 .34282 .47033 .33975 Mtetra
.427 .835 .973 r
.47033 .33975 .47997 .34282 .49684 .33901 .4873 .33644 Mtetra
.365 .811 .95 r
.4873 .33644 .49684 .33901 .51384 .33625 .5044 .33365 Mtetra
.382 .82 .953 r
.5044 .33365 .51384 .33625 .53097 .3347 .52164 .33058 Mtetra
.519 .861 .993 r
.52164 .33058 .53097 .3347 .54827 .33344 .53901 .32618 Mtetra
.636 .832 .976 r
.53901 .32618 .54827 .33344 .5657 .33062 .5565 .32036 Mtetra
.708 .787 .913 r
.5565 .32036 .5657 .33062 .58324 .32555 .57406 .31202 Mtetra
.722 .731 .858 r
.57406 .31202 .58324 .32555 .60083 .31751 .59168 .30214 Mtetra
.709 .699 .839 r
.59168 .30214 .60083 .31751 .61844 .30729 .60938 .29253 Mtetra
.699 .706 .853 r
.60938 .29253 .61844 .30729 .63613 .29743 .62717 .28373 Mtetra
.668 .712 .881 r
.62717 .28373 .63613 .29743 .65394 .28871 .64513 .27681 Mtetra
.654 .741 .914 r
.64513 .27681 .65394 .28871 .67194 .28206 .66322 .27065 Mtetra
.654 .753 .922 r
.66322 .27065 .67194 .28206 .69007 .27596 .68144 .26444 Mtetra
.66 .754 .92 r
.68144 .26444 .69007 .27596 .70833 .26978 .69976 .25795 Mtetra
.662 .75 .916 r
.69976 .25795 .70833 .26978 .72667 .26319 .71819 .25132 Mtetra
.653 .747 .919 r
.71819 .25132 .72667 .26319 .74515 .25674 .73677 .24502 Mtetra
.652 .752 .923 r
.73677 .24502 .74515 .25674 .76377 .25054 .75547 .23874 Mtetra
.654 .752 .922 r
.75547 .23874 .76377 .25054 .7825 .24425 .77428 .2323 Mtetra
.653 .749 .92 r
.11084 .44806 .12172 .45766 .13661 .45246 .12575 .44295 Mtetra
.659 .753 .92 r
.12575 .44295 .13661 .45246 .15159 .44713 .14078 .43762 Mtetra
.66 .755 .92 r
.14078 .43762 .15159 .44713 .16665 .44182 .1559 .4322 Mtetra
.656 .753 .921 r
.1559 .4322 .16665 .44182 .18176 .43684 .17109 .42691 Mtetra
.648 .745 .92 r
.17109 .42691 .18176 .43684 .19698 .43173 .18634 .42186 Mtetra
.654 .749 .92 r
.18634 .42186 .19698 .43173 .2123 .42637 .20171 .41658 Mtetra
.657 .753 .921 r
.20171 .41658 .2123 .42637 .22772 .42096 .21718 .41114 Mtetra
.658 .754 .921 r
.21718 .41114 .22772 .42096 .24317 .4163 .23274 .40566 Mtetra
.638 .732 .917 r
.23274 .40566 .24317 .4163 .25855 .41348 .24833 .40088 Mtetra
.595 .679 .9 r
.24833 .40088 .25855 .41348 .27399 .41146 .26389 .3977 Mtetra
.581 .654 .886 r
.26389 .3977 .27399 .41146 .28954 .40973 .27953 .39505 Mtetra
.569 .634 .876 r
.27953 .39505 .28954 .40973 .30531 .40652 .29525 .39289 Mtetra
.589 .662 .889 r
.29525 .39289 .30531 .40652 .32135 .40085 .31116 .38989 Mtetra
.628 .729 .92 r
.31116 .38989 .32135 .40085 .33757 .39377 .32728 .3853 Mtetra
.661 .795 .946 r
.32728 .3853 .33757 .39377 .35395 .38538 .34359 .37938 Mtetra
.667 .856 .972 r
.34359 .37938 .35395 .38538 .3704 .3767 .36003 .37283 Mtetra
.646 .902 .983 r
.36003 .37283 .3704 .3767 .3869 .36853 .37656 .36607 Mtetra
.615 .921 .975 r
.37656 .36607 .3869 .36853 .40345 .36111 .39319 .35924 Mtetra
.573 .917 .966 r
.39319 .35924 .40345 .36111 .42005 .35453 .4099 .3528 Mtetra
.529 .902 .96 r
.4099 .3528 .42005 .35453 .43672 .34877 .42668 .34699 Mtetra
.49 .885 .956 r
.42668 .34699 .43672 .34877 .45348 .34385 .44355 .34181 Mtetra
.473 .874 .959 r
.44355 .34181 .45348 .34385 .47033 .33975 .46053 .33701 Mtetra
.501 .878 .975 r
.46053 .33701 .47033 .33975 .4873 .33644 .47762 .33217 Mtetra
.559 .874 .994 r
.47762 .33217 .4873 .33644 .5044 .33365 .49484 .3271 Mtetra
.625 .845 .984 r
.49484 .3271 .5044 .33365 .52164 .33058 .51217 .3214 Mtetra
.679 .801 .94 r
.51217 .3214 .52164 .33058 .53901 .32618 .52962 .31435 Mtetra
.71 .757 .889 r
.52962 .31435 .53901 .32618 .5565 .32036 .54716 .30566 Mtetra
.711 .71 .847 r
.54716 .30566 .5565 .32036 .57406 .31202 .56477 .29611 Mtetra
.698 .688 .837 r
.56477 .29611 .57406 .31202 .59168 .30214 .58246 .28703 Mtetra
.693 .699 .851 r
.58246 .28703 .59168 .30214 .60938 .29253 .60025 .27848 Mtetra
.667 .706 .877 r
.60025 .27848 .60938 .29253 .62717 .28373 .61817 .27154 Mtetra
.654 .737 .91 r
.61817 .27154 .62717 .28373 .64513 .27681 .63623 .26533 Mtetra
.654 .753 .922 r
.63623 .26533 .64513 .27681 .66322 .27065 .6544 .25907 Mtetra
.657 .753 .921 r
.6544 .25907 .66322 .27065 .68144 .26444 .67269 .25264 Mtetra
.662 .752 .917 r
.67269 .25264 .68144 .26444 .69976 .25795 .69109 .24595 Mtetra
.656 .747 .917 r
.69109 .24595 .69976 .25795 .71819 .25132 .70962 .23951 Mtetra
.652 .751 .922 r
.70962 .23951 .71819 .25132 .73677 .24502 .72828 .23319 Mtetra
.653 .753 .923 r
.72828 .23319 .73677 .24502 .75547 .23874 .74706 .22677 Mtetra
.658 .753 .921 r
.74706 .22677 .75547 .23874 .77428 .2323 .76596 .2201 Mtetra
.651 .748 .921 r
.09984 .43833 .11084 .44806 .12575 .44295 .11479 .43326 Mtetra
.656 .751 .92 r
.11479 .43326 .12575 .44295 .14078 .43762 .12985 .42798 Mtetra
.659 .754 .92 r
.12985 .42798 .14078 .43762 .1559 .4322 .14502 .42254 Mtetra
.66 .755 .92 r
.14502 .42254 .1559 .4322 .17109 .42691 .16028 .41704 Mtetra
.654 .75 .921 r
.16028 .41704 .17109 .42691 .18634 .42186 .1756 .41174 Mtetra
.649 .745 .92 r
.1756 .41174 .18634 .42186 .20171 .41658 .191 .40659 Mtetra
.655 .751 .92 r
.191 .40659 .20171 .41658 .21718 .41114 .20652 .40117 Mtetra
.657 .753 .921 r
.20652 .40117 .21718 .41114 .23274 .40566 .22213 .39565 Mtetra
.658 .753 .92 r
.22213 .39565 .23274 .40566 .24833 .40088 .23785 .39006 Mtetra
.644 .734 .914 r
.23785 .39006 .24833 .40088 .26389 .3977 .25361 .38498 Mtetra
.61 .686 .897 r
.25361 .38498 .26389 .3977 .27953 .39505 .26937 .38114 Mtetra
.596 .661 .883 r
.26937 .38114 .27953 .39505 .29525 .39289 .2852 .37785 Mtetra
.589 .64 .87 r
.2852 .37785 .29525 .39289 .31116 .38989 .30113 .37484 Mtetra
.591 .642 .87 r
.30113 .37484 .31116 .38989 .32728 .3853 .31719 .3717 Mtetra
.608 .675 .888 r
.31719 .3717 .32728 .3853 .34359 .37938 .33341 .36786 Mtetra
.626 .722 .916 r
.33341 .36786 .34359 .37938 .36003 .37283 .3498 .36323 Mtetra
.648 .771 .938 r
.3498 .36323 .36003 .37283 .37656 .36607 .36634 .35769 Mtetra
.651 .801 .955 r
.36634 .35769 .37656 .36607 .39319 .35924 .38301 .35187 Mtetra
.647 .825 .969 r
.38301 .35187 .39319 .35924 .4099 .3528 .39977 .34598 Mtetra
.641 .838 .976 r
.39977 .34598 .4099 .3528 .42668 .34699 .41664 .3401 Mtetra
.639 .838 .977 r
.41664 .3401 .42668 .34699 .44355 .34181 .43361 .33425 Mtetra
.645 .825 .969 r
.43361 .33425 .44355 .34181 .46053 .33701 .4507 .32831 Mtetra
.658 .803 .953 r
.4507 .32831 .46053 .33701 .47762 .33217 .46789 .3221 Mtetra
.682 .781 .926 r
.46789 .3221 .47762 .33217 .49484 .3271 .48521 .31496 Mtetra
.695 .745 .891 r
.48521 .31496 .49484 .3271 .51217 .3214 .50262 .30701 Mtetra
.698 .71 .857 r
.50262 .30701 .51217 .3214 .52962 .31435 .52013 .29834 Mtetra
.693 .685 .838 r
.52013 .29834 .52962 .31435 .54716 .30566 .53772 .28953 Mtetra
.688 .682 .839 r
.53772 .28953 .54716 .30566 .56477 .29611 .5554 .28097 Mtetra
.683 .695 .856 r
.5554 .28097 .56477 .29611 .58246 .28703 .57317 .27296 Mtetra
.662 .706 .879 r
.57317 .27296 .58246 .28703 .60025 .27848 .59107 .26621 Mtetra
.654 .736 .91 r
.59107 .26621 .60025 .27848 .61817 .27154 .60909 .25998 Mtetra
.654 .752 .922 r
.60909 .25998 .61817 .27154 .63623 .26533 .62722 .25368 Mtetra
.656 .753 .921 r
.62722 .25368 .63623 .26533 .6544 .25907 .64548 .24726 Mtetra
.662 .753 .918 r
.64548 .24726 .6544 .25907 .67269 .25264 .66384 .24054 Mtetra
.657 .747 .916 r
.66384 .24054 .67269 .25264 .69109 .24595 .68232 .23398 Mtetra
.652 .749 .921 r
.68232 .23398 .69109 .24595 .70962 .23951 .70095 .22761 Mtetra
.653 .753 .923 r
.70095 .22761 .70962 .23951 .72828 .23319 .71969 .22118 Mtetra
.656 .753 .922 r
.71969 .22118 .72828 .23319 .74706 .22677 .73855 .21457 Mtetra
.66 .753 .919 r
.73855 .21457 .74706 .22677 .76596 .2201 .75753 .20773 Mtetra
.653 .75 .921 r
.08871 .42857 .09984 .43833 .11479 .43326 .10372 .42336 Mtetra
.652 .748 .92 r
.10372 .42336 .11479 .43326 .12985 .42798 .11882 .41818 Mtetra
.657 .753 .92 r
.11882 .41818 .12985 .42798 .14502 .42254 .13403 .41275 Mtetra
.659 .755 .92 r
.13403 .41275 .14502 .42254 .16028 .41704 .14933 .40721 Mtetra
.659 .755 .921 r
.14933 .40721 .16028 .41704 .1756 .41174 .16473 .40164 Mtetra
.653 .749 .92 r
.16473 .40164 .1756 .41174 .191 .40659 .1802 .39628 Mtetra
.649 .744 .919 r
.1802 .39628 .191 .40659 .20652 .40117 .19574 .39102 Mtetra
.655 .751 .92 r
.19574 .39102 .20652 .40117 .22213 .39565 .21141 .38551 Mtetra
.657 .753 .921 r
.21141 .38551 .22213 .39565 .23785 .39006 .22717 .37989 Mtetra
.658 .754 .921 r
.22717 .37989 .23785 .39006 .25361 .38498 .24304 .37419 Mtetra
.651 .74 .915 r
.24304 .37419 .25361 .38498 .26937 .38114 .25898 .36874 Mtetra
.632 .704 .898 r
.25898 .36874 .26937 .38114 .2852 .37785 .27496 .36396 Mtetra
.612 .671 .882 r
.27496 .36396 .2852 .37785 .30113 .37484 .29099 .35992 Mtetra
.609 .654 .869 r
.29099 .35992 .30113 .37484 .31719 .3717 .30713 .35599 Mtetra
.609 .643 .859 r
.30713 .35599 .31719 .3717 .33341 .36786 .32339 .35199 Mtetra
.61 .642 .858 r
.32339 .35199 .33341 .36786 .3498 .36323 .33978 .3479 Mtetra
.621 .656 .863 r
.33978 .3479 .3498 .36323 .36634 .35769 .35631 .34334 Mtetra
.632 .677 .875 r
.35631 .34334 .36634 .35769 .38301 .35187 .37297 .33828 Mtetra
.643 .695 .884 r
.37297 .33828 .38301 .35187 .39977 .34598 .38977 .33276 Mtetra
.652 .707 .887 r
.38977 .33276 .39977 .34598 .41664 .3401 .40669 .32681 Mtetra
.661 .71 .884 r
.40669 .32681 .41664 .3401 .43361 .33425 .42374 .32044 Mtetra
.668 .705 .875 r
.42374 .32044 .43361 .33425 .4507 .32831 .44089 .3136 Mtetra
.674 .694 .86 r
.44089 .3136 .4507 .32831 .46789 .3221 .45816 .30625 Mtetra
.678 .68 .844 r
.45816 .30625 .46789 .3221 .48521 .31496 .47553 .29842 Mtetra
.677 .671 .837 r
.47553 .29842 .48521 .31496 .50262 .30701 .493 .29047 Mtetra
.678 .672 .837 r
.493 .29047 .50262 .30701 .52013 .29834 .51055 .28246 Mtetra
.678 .683 .847 r
.51055 .28246 .52013 .29834 .53772 .28953 .5282 .27454 Mtetra
.668 .693 .864 r
.5282 .27454 .53772 .28953 .5554 .28097 .54595 .26736 Mtetra
.658 .713 .889 r
.54595 .26736 .5554 .28097 .57317 .27296 .56381 .26086 Mtetra
.653 .741 .914 r
.56381 .26086 .57317 .27296 .59107 .26621 .58179 .25461 Mtetra
.654 .753 .922 r
.58179 .25461 .59107 .26621 .60909 .25998 .59989 .24827 Mtetra
.656 .753 .921 r
.59989 .24827 .60909 .25998 .62722 .25368 .61811 .24181 Mtetra
.662 .753 .918 r
.61811 .24181 .62722 .25368 .64548 .24726 .63643 .23508 Mtetra
.658 .747 .916 r
.63643 .23508 .64548 .24726 .66384 .24054 .65488 .22845 Mtetra
.653 .748 .92 r
.65488 .22845 .66384 .24054 .68232 .23398 .67346 .22203 Mtetra
.652 .753 .923 r
.67346 .22203 .68232 .23398 .70095 .22761 .69217 .21556 Mtetra
.654 .753 .922 r
.69217 .21556 .70095 .22761 .71969 .22118 .71099 .20897 Mtetra
.66 .754 .92 r
.71099 .20897 .71969 .22118 .73855 .21457 .72993 .20212 Mtetra
.658 .75 .918 r
.72993 .20212 .73855 .21457 .75753 .20773 .749 .19527 Mtetra
.657 .752 .92 r
.07745 .41879 .08871 .42857 .10372 .42336 .09253 .41338 Mtetra
.652 .748 .92 r
.09253 .41338 .10372 .42336 .11882 .41818 .10767 .40812 Mtetra
.653 .748 .92 r
.10767 .40812 .11882 .41818 .13403 .41275 .12291 .40281 Mtetra
.658 .753 .92 r
.12291 .40281 .13403 .41275 .14933 .40721 .13827 .39727 Mtetra
.659 .755 .921 r
.13827 .39727 .14933 .40721 .16473 .40164 .15372 .39164 Mtetra
.15372 .39164 .16473 .40164 .1802 .39628 .16926 .38599 Mtetra
.654 .749 .92 r
.16926 .38599 .1802 .39628 .19574 .39102 .18488 .38051 Mtetra
.65 .744 .919 r
.18488 .38051 .19574 .39102 .21141 .38551 .20057 .37514 Mtetra
.654 .75 .92 r
.20057 .37514 .21141 .38551 .22717 .37989 .21638 .36959 Mtetra
.657 .753 .921 r
.21638 .36959 .22717 .37989 .24304 .37419 .2323 .36387 Mtetra
.657 .754 .921 r
.2323 .36387 .24304 .37419 .25898 .36874 .24832 .35812 Mtetra
.657 .749 .918 r
.24832 .35812 .25898 .36874 .27496 .36396 .26443 .35233 Mtetra
.649 .728 .907 r
.26443 .35233 .27496 .36396 .29099 .35992 .28063 .3468 Mtetra
.638 .698 .889 r
.28063 .3468 .29099 .35992 .30713 .35599 .29689 .34163 Mtetra
.626 .673 .875 r
.29689 .34163 .30713 .35599 .32339 .35199 .31323 .33688 Mtetra
.626 .662 .866 r
.31323 .33688 .32339 .35199 .33978 .3479 .32969 .33206 Mtetra
.628 .653 .856 r
.32969 .33206 .33978 .3479 .35631 .34334 .34628 .32704 Mtetra
.633 .65 .849 r
.34628 .32704 .35631 .34334 .37297 .33828 .36298 .32173 Mtetra
.638 .65 .845 r
.36298 .32173 .37297 .33828 .38977 .33276 .37982 .31608 Mtetra
.644 .652 .843 r
.37982 .31608 .38977 .33276 .40669 .32681 .39678 .31006 Mtetra
.65 .654 .841 r
.39678 .31006 .40669 .32681 .42374 .32044 .41386 .30366 Mtetra
.656 .658 .84 r
.41386 .30366 .42374 .32044 .44089 .3136 .43105 .29692 Mtetra
.661 .662 .84 r
.43105 .29692 .44089 .3136 .45816 .30625 .44836 .28988 Mtetra
.666 .669 .844 r
.44836 .28988 .45816 .30625 .47553 .29842 .46577 .28262 Mtetra
.668 .68 .852 r
.46577 .28262 .47553 .29842 .493 .29047 .48327 .27531 Mtetra
.662 .688 .863 r
.48327 .27531 .493 .29047 .51055 .28246 .50088 .26839 Mtetra
.658 .705 .882 r
.50088 .26839 .51055 .28246 .5282 .27454 .51859 .26185 Mtetra
.654 .729 .905 r
.51859 .26185 .5282 .27454 .54595 .26736 .53641 .25555 Mtetra
.655 .748 .919 r
.53641 .25555 .54595 .26736 .56381 .26086 .55435 .24922 Mtetra
.654 .753 .922 r
.55435 .24922 .56381 .26086 .58179 .25461 .57241 .24285 Mtetra
.658 .754 .921 r
.57241 .24285 .58179 .25461 .59989 .24827 .59058 .23629 Mtetra
.661 .752 .918 r
.59058 .23629 .59989 .24827 .61811 .24181 .60887 .22955 Mtetra
.658 .747 .916 r
.60887 .22955 .61811 .24181 .63643 .23508 .62728 .2229 Mtetra
.653 .748 .92 r
.62728 .2229 .63643 .23508 .65488 .22845 .64582 .21643 Mtetra
.652 .753 .923 r
.64582 .21643 .65488 .22845 .67346 .22203 .66449 .20992 Mtetra
.654 .753 .923 r
.66449 .20992 .67346 .22203 .69217 .21556 .68328 .20331 Mtetra
.659 .754 .92 r
.68328 .20331 .69217 .21556 .71099 .20897 .70218 .19646 Mtetra
.659 .75 .918 r
.70218 .19646 .71099 .20897 .72993 .20212 .72121 .18953 Mtetra
.655 .749 .919 r
.72121 .18953 .72993 .20212 .749 .19527 .74037 .18275 Mtetra
.658 .753 .92 r
.06607 .40893 .07745 .41879 .09253 .41338 .0812 .40342 Mtetra
.656 .752 .92 r
.0812 .40342 .09253 .41338 .10767 .40812 .09641 .39794 Mtetra
.652 .748 .92 r
.09641 .39794 .10767 .40812 .12291 .40281 .1117 .3926 Mtetra
.653 .749 .92 r
.1117 .3926 .12291 .40281 .13827 .39727 .12708 .38717 Mtetra
.658 .753 .921 r
.12708 .38717 .13827 .39727 .15372 .39164 .14258 .38154 Mtetra
.659 .755 .921 r
.14258 .38154 .15372 .39164 .16926 .38599 .15818 .37583 Mtetra
.15818 .37583 .16926 .38599 .18488 .38051 .17387 .37008 Mtetra
.655 .75 .919 r
.17387 .37008 .18488 .38051 .20057 .37514 .18964 .36444 Mtetra
.65 .744 .918 r
.18964 .36444 .20057 .37514 .21638 .36959 .20549 .35895 Mtetra
.651 .747 .92 r
.20549 .35895 .21638 .36959 .2323 .36387 .22145 .35339 Mtetra
.657 .753 .921 r
.22145 .35339 .2323 .36387 .24832 .35812 .23752 .34759 Mtetra
.23752 .34759 .24832 .35812 .26443 .35233 .25369 .34174 Mtetra
.657 .754 .921 r
.25369 .34174 .26443 .35233 .28063 .3468 .26997 .33586 Mtetra
.657 .748 .917 r
.26997 .33586 .28063 .3468 .29689 .34163 .28634 .32993 Mtetra
.653 .733 .908 r
.28634 .32993 .29689 .34163 .31323 .33688 .30281 .32409 Mtetra
.649 .713 .894 r
.30281 .32409 .31323 .33688 .32969 .33206 .31938 .31832 Mtetra
.647 .696 .882 r
.31938 .31832 .32969 .33206 .34628 .32704 .33605 .31256 Mtetra
.645 .685 .873 r
.33605 .31256 .34628 .32704 .36298 .32173 .35282 .30677 Mtetra
.645 .678 .867 r
.35282 .30677 .36298 .32173 .37982 .31608 .36971 .3009 Mtetra
.649 .677 .864 r
.36971 .3009 .37982 .31608 .39678 .31006 .38672 .2948 Mtetra
.652 .679 .862 r
.38672 .2948 .39678 .31006 .41386 .30366 .40384 .28848 Mtetra
.654 .682 .864 r
.40384 .28848 .41386 .30366 .43105 .29692 .42107 .28206 Mtetra
.655 .688 .869 r
.42107 .28206 .43105 .29692 .44836 .28988 .43841 .27561 Mtetra
.656 .7 .879 r
.43841 .27561 .44836 .28988 .46577 .28262 .45585 .26918 Mtetra
.655 .715 .892 r
.45585 .26918 .46577 .28262 .48327 .27531 .47341 .26281 Mtetra
.654 .733 .908 r
.47341 .26281 .48327 .27531 .50088 .26839 .49107 .25653 Mtetra
.655 .747 .918 r
.49107 .25653 .50088 .26839 .51859 .26185 .50886 .25019 Mtetra
.655 .753 .922 r
.50886 .25019 .51859 .26185 .53641 .25555 .52676 .24381 Mtetra
.52676 .24381 .53641 .25555 .55435 .24922 .54477 .23739 Mtetra
.66 .755 .92 r
.54477 .23739 .55435 .24922 .57241 .24285 .56291 .23071 Mtetra
.661 .75 .916 r
.56291 .23071 .57241 .24285 .59058 .23629 .58116 .22395 Mtetra
.656 .746 .916 r
.58116 .22395 .59058 .23629 .60887 .22955 .59953 .21733 Mtetra
.653 .749 .92 r
.59953 .21733 .60887 .22955 .62728 .2229 .61803 .21082 Mtetra
.653 .753 .923 r
.61803 .21082 .62728 .2229 .64582 .21643 .63665 .20427 Mtetra
.654 .754 .923 r
.63665 .20427 .64582 .21643 .66449 .20992 .6554 .19761 Mtetra
.658 .754 .921 r
.6554 .19761 .66449 .20992 .68328 .20331 .67427 .19074 Mtetra
.659 .751 .918 r
.67427 .19074 .68328 .20331 .70218 .19646 .69325 .18377 Mtetra
.655 .748 .918 r
.69325 .18377 .70218 .19646 .72121 .18953 .71238 .17693 Mtetra
.654 .751 .921 r
.71238 .17693 .72121 .18953 .74037 .18275 .73164 .17011 Mtetra
.658 .754 .92 r
.05455 .39896 .06607 .40893 .0812 .40342 .06973 .39338 Mtetra
.658 .753 .92 r
.06973 .39338 .0812 .40342 .09641 .39794 .085 .38779 Mtetra
.656 .752 .92 r
.085 .38779 .09641 .39794 .1117 .3926 .10036 .38223 Mtetra
.652 .747 .92 r
.10036 .38223 .1117 .3926 .12708 .38717 .11579 .37679 Mtetra
.653 .749 .92 r
.11579 .37679 .12708 .38717 .14258 .38154 .13132 .37126 Mtetra
.657 .753 .921 r
.13132 .37126 .14258 .38154 .15818 .37583 .14696 .36555 Mtetra
.659 .755 .921 r
.14696 .36555 .15818 .37583 .17387 .37008 .16271 .35976 Mtetra
.16271 .35976 .17387 .37008 .18964 .36444 .17855 .35391 Mtetra
.657 .752 .92 r
.17855 .35391 .18964 .36444 .20549 .35895 .19449 .34809 Mtetra
.652 .745 .918 r
.19449 .34809 .20549 .35895 .22145 .35339 .2105 .34243 Mtetra
.651 .744 .918 r
.2105 .34243 .22145 .35339 .23752 .34759 .22661 .33677 Mtetra
.653 .749 .92 r
.22661 .33677 .23752 .34759 .25369 .34174 .24283 .33102 Mtetra
.657 .753 .921 r
.24283 .33102 .25369 .34174 .26997 .33586 .25916 .32508 Mtetra
.657 .754 .921 r
.25916 .32508 .26997 .33586 .28634 .32993 .2756 .3191 Mtetra
.656 .754 .922 r
.2756 .3191 .28634 .32993 .30281 .32409 .29214 .3131 Mtetra
.656 .752 .921 r
.29214 .3131 .30281 .32409 .31938 .31832 .30878 .30707 Mtetra
.657 .748 .917 r
.30878 .30707 .31938 .31832 .33605 .31256 .32553 .30096 Mtetra
.656 .743 .914 r
.32553 .30096 .33605 .31256 .35282 .30677 .34238 .29485 Mtetra
.655 .737 .91 r
.34238 .29485 .35282 .30677 .36971 .3009 .35934 .28871 Mtetra
.655 .734 .907 r
.35934 .28871 .36971 .3009 .38672 .2948 .37641 .28254 Mtetra
.37641 .28254 .38672 .2948 .40384 .28848 .39358 .27633 Mtetra
.655 .737 .91 r
.39358 .27633 .40384 .28848 .42107 .28206 .41087 .2701 Mtetra
.654 .742 .914 r
.41087 .2701 .42107 .28206 .43841 .27561 .42827 .26386 Mtetra
.655 .748 .918 r
.42827 .26386 .43841 .27561 .45585 .26918 .44578 .25754 Mtetra
.655 .752 .921 r
.44578 .25754 .45585 .26918 .47341 .26281 .46341 .25119 Mtetra
.655 .753 .922 r
.46341 .25119 .47341 .26281 .49107 .25653 .48115 .24481 Mtetra
.48115 .24481 .49107 .25653 .50886 .25019 .49901 .23839 Mtetra
.659 .754 .921 r
.49901 .23839 .50886 .25019 .52676 .24381 .51699 .23177 Mtetra
.66 .751 .918 r
.51699 .23177 .52676 .24381 .54477 .23739 .53508 .22505 Mtetra
.659 .747 .915 r
.53508 .22505 .54477 .23739 .56291 .23071 .55329 .21832 Mtetra
.654 .746 .917 r
.55329 .21832 .56291 .23071 .58116 .22395 .57162 .21175 Mtetra
.653 .75 .921 r
.57162 .21175 .58116 .22395 .59953 .21733 .59008 .2052 Mtetra
.653 .754 .923 r
.59008 .2052 .59953 .21733 .61803 .21082 .60866 .19859 Mtetra
.654 .754 .923 r
.60866 .19859 .61803 .21082 .63665 .20427 .62737 .19189 Mtetra
.658 .754 .921 r
.62737 .19189 .63665 .20427 .6554 .19761 .64619 .18498 Mtetra
.659 .751 .918 r
.64619 .18498 .6554 .19761 .67427 .19074 .66514 .17797 Mtetra
.656 .748 .918 r
.66514 .17797 .67427 .19074 .69325 .18377 .68423 .17108 Mtetra
.654 .751 .921 r
.68423 .17108 .69325 .18377 .71238 .17693 .70344 .16421 Mtetra
.654 .752 .922 r
.70344 .16421 .71238 .17693 .73164 .17011 .7228 .15731 Mtetra
.656 .752 .92 r
.04291 .38882 .05455 .39896 .06973 .39338 .05813 .38325 Mtetra
.658 .754 .921 r
.05813 .38325 .06973 .39338 .085 .38779 .07346 .37758 Mtetra
.658 .753 .921 r
.07346 .37758 .085 .38779 .10036 .38223 .08888 .37189 Mtetra
.656 .752 .92 r
.08888 .37189 .10036 .38223 .11579 .37679 .10438 .36623 Mtetra
.652 .747 .919 r
.10438 .36623 .11579 .37679 .13132 .37126 .11996 .36068 Mtetra
.653 .748 .92 r
.11996 .36068 .13132 .37126 .14696 .36555 .13563 .35508 Mtetra
.657 .753 .921 r
.13563 .35508 .14696 .36555 .16271 .35976 .15143 .34929 Mtetra
.658 .755 .921 r
.15143 .34929 .16271 .35976 .17855 .35391 .16732 .34342 Mtetra
.659 .756 .922 r
.16732 .34342 .17855 .35391 .19449 .34809 .18332 .33748 Mtetra
.658 .754 .921 r
.18332 .33748 .19449 .34809 .2105 .34243 .19941 .33152 Mtetra
.656 .749 .918 r
.19941 .33152 .2105 .34243 .22661 .33677 .2156 .32561 Mtetra
.652 .744 .917 r
.2156 .32561 .22661 .33677 .24283 .33102 .23187 .3198 Mtetra
.652 .745 .917 r
.23187 .3198 .24283 .33102 .25916 .32508 .24825 .31396 Mtetra
.653 .748 .92 r
.24825 .31396 .25916 .32508 .2756 .3191 .26474 .30806 Mtetra
.655 .752 .921 r
.26474 .30806 .2756 .3191 .29214 .3131 .28133 .30205 Mtetra
.656 .753 .921 r
.28133 .30205 .29214 .3131 .30878 .30707 .29804 .29595 Mtetra
.29804 .29595 .30878 .30707 .32553 .30096 .31485 .2898 Mtetra
.656 .754 .922 r
.31485 .2898 .32553 .30096 .34238 .29485 .33177 .28362 Mtetra
.33177 .28362 .34238 .29485 .35934 .28871 .34879 .27741 Mtetra
.34879 .27741 .35934 .28871 .37641 .28254 .36593 .27117 Mtetra
.36593 .27117 .37641 .28254 .39358 .27633 .38318 .26489 Mtetra
.38318 .26489 .39358 .27633 .41087 .2701 .40053 .25857 Mtetra
.655 .754 .922 r
.40053 .25857 .41087 .2701 .42827 .26386 .418 .25222 Mtetra
.655 .753 .922 r
.418 .25222 .42827 .26386 .44578 .25754 .43559 .24583 Mtetra
.657 .753 .921 r
.43559 .24583 .44578 .25754 .46341 .25119 .45329 .23934 Mtetra
.659 .753 .92 r
.45329 .23934 .46341 .25119 .48115 .24481 .47111 .23273 Mtetra
.659 .75 .917 r
.47111 .23273 .48115 .24481 .49901 .23839 .48905 .22606 Mtetra
.659 .747 .915 r
.48905 .22606 .49901 .23839 .51699 .23177 .5071 .21935 Mtetra
.655 .745 .916 r
.5071 .21935 .51699 .23177 .53508 .22505 .52527 .21274 Mtetra
.654 .748 .919 r
.52527 .21274 .53508 .22505 .55329 .21832 .54356 .20617 Mtetra
.653 .753 .923 r
.54356 .20617 .55329 .21832 .57162 .21175 .56197 .19957 Mtetra
.654 .754 .923 r
.56197 .19957 .57162 .21175 .59008 .2052 .58051 .1929 Mtetra
.655 .754 .922 r
.58051 .1929 .59008 .2052 .60866 .19859 .59918 .18613 Mtetra
.659 .754 .92 r
.59918 .18613 .60866 .19859 .62737 .19189 .61796 .17916 Mtetra
.659 .75 .918 r
.61796 .17916 .62737 .19189 .64619 .18498 .63687 .17213 Mtetra
.655 .748 .918 r
.63687 .17213 .64619 .18498 .66514 .17797 .65591 .1652 Mtetra
.654 .751 .921 r
.65591 .1652 .66514 .17797 .68423 .17108 .67509 .15829 Mtetra
.654 .752 .922 r
.67509 .15829 .68423 .17108 .70344 .16421 .6944 .15135 Mtetra
.655 .753 .922 r
.6944 .15135 .70344 .16421 .7228 .15731 .71384 .14429 Mtetra
.653 .749 .92 r
.03116 .37846 .04291 .38882 .05813 .38325 .04642 .37295 Mtetra
.656 .752 .92 r
.04642 .37295 .05813 .38325 .07346 .37758 .06178 .36728 Mtetra
.658 .754 .921 r
.06178 .36728 .07346 .37758 .08888 .37189 .07725 .36151 Mtetra
.658 .753 .921 r
.07725 .36151 .08888 .37189 .10438 .36623 .09281 .35573 Mtetra
.656 .752 .92 r
.09281 .35573 .10438 .36623 .11996 .36068 .10847 .34995 Mtetra
.653 .748 .919 r
.10847 .34995 .11996 .36068 .13563 .35508 .1242 .34427 Mtetra
.652 .747 .919 r
.1242 .34427 .13563 .35508 .15143 .34929 .14003 .33857 Mtetra
.655 .751 .921 r
.14003 .33857 .15143 .34929 .16732 .34342 .15597 .33274 Mtetra
.657 .754 .921 r
.15597 .33274 .16732 .34342 .18332 .33748 .17202 .32679 Mtetra
.658 .755 .922 r
.17202 .32679 .18332 .33748 .19941 .33152 .18817 .32078 Mtetra
.658 .756 .922 r
.18817 .32078 .19941 .33152 .2156 .32561 .20442 .31471 Mtetra
.658 .754 .921 r
.20442 .31471 .2156 .32561 .23187 .3198 .22077 .30864 Mtetra
.657 .75 .918 r
.22077 .30864 .23187 .3198 .24825 .31396 .23723 .30256 Mtetra
.654 .746 .917 r
.23723 .30256 .24825 .31396 .26474 .30806 .25378 .29653 Mtetra
.653 .744 .916 r
.25378 .29653 .26474 .30806 .28133 .30205 .27043 .29049 Mtetra
.654 .745 .917 r
.27043 .29049 .28133 .30205 .29804 .29595 .28719 .28441 Mtetra
.654 .747 .918 r
.28719 .28441 .29804 .29595 .31485 .2898 .30406 .27827 Mtetra
.655 .749 .919 r
.30406 .27827 .31485 .2898 .33177 .28362 .32104 .27207 Mtetra
.655 .75 .92 r
.32104 .27207 .33177 .28362 .34879 .27741 .33813 .26581 Mtetra
.656 .751 .92 r
.33813 .26581 .34879 .27741 .36593 .27117 .35534 .25949 Mtetra
.35534 .25949 .36593 .27117 .38318 .26489 .37265 .25311 Mtetra
.657 .75 .919 r
.37265 .25311 .38318 .26489 .40053 .25857 .39008 .24667 Mtetra
.657 .75 .918 r
.39008 .24667 .40053 .25857 .418 .25222 .40763 .24016 Mtetra
.658 .748 .917 r
.40763 .24016 .418 .25222 .43559 .24583 .42529 .2336 Mtetra
.658 .746 .915 r
.42529 .2336 .43559 .24583 .45329 .23934 .44306 .22698 Mtetra
.657 .745 .915 r
.44306 .22698 .45329 .23934 .47111 .23273 .46095 .22035 Mtetra
.655 .746 .917 r
.46095 .22035 .47111 .23273 .48905 .22606 .47896 .21377 Mtetra
.654 .749 .919 r
.47896 .21377 .48905 .22606 .5071 .21935 .49708 .20718 Mtetra
.653 .752 .922 r
.49708 .20718 .5071 .21935 .52527 .21274 .51533 .20058 Mtetra
.654 .754 .923 r
.51533 .20058 .52527 .21274 .54356 .20617 .53371 .19391 Mtetra
.53371 .19391 .54356 .20617 .56197 .19957 .5522 .18717 Mtetra
.656 .754 .922 r
.5522 .18717 .56197 .19957 .58051 .1929 .57082 .1803 Mtetra
.659 .753 .919 r
.57082 .1803 .58051 .1929 .59918 .18613 .58957 .17329 Mtetra
.658 .749 .917 r
.58957 .17329 .59918 .18613 .61796 .17916 .60843 .16625 Mtetra
.655 .748 .918 r
.60843 .16625 .61796 .17916 .63687 .17213 .62744 .1593 Mtetra
.654 .751 .921 r
.62744 .1593 .63687 .17213 .65591 .1652 .64657 .15234 Mtetra
.654 .752 .922 r
.64657 .15234 .65591 .1652 .67509 .15829 .66584 .14535 Mtetra
.655 .753 .922 r
.66584 .14535 .67509 .15829 .6944 .15135 .68523 .13826 Mtetra
.658 .753 .92 r
.68523 .13826 .6944 .15135 .71384 .14429 .70475 .13098 Mtetra
.654 .75 .92 r
.01927 .36801 .03116 .37846 .04642 .37295 .03458 .36241 Mtetra
.653 .749 .92 r
.03458 .36241 .04642 .37295 .06178 .36728 .04998 .35679 Mtetra
.656 .752 .92 r
.04998 .35679 .06178 .36728 .07725 .36151 .06549 .35103 Mtetra
.658 .754 .921 r
.06549 .35103 .07725 .36151 .09281 .35573 .08111 .34517 Mtetra
.08111 .34517 .09281 .35573 .10847 .34995 .09682 .33929 Mtetra
.657 .752 .92 r
.09682 .33929 .10847 .34995 .1242 .34427 .11263 .3334 Mtetra
.655 .749 .919 r
.11263 .3334 .1242 .34427 .14003 .33857 .12852 .32755 Mtetra
.653 .747 .919 r
.12852 .32755 .14003 .33857 .15597 .33274 .1445 .32174 Mtetra
.653 .749 .92 r
.1445 .32174 .15597 .33274 .17202 .32679 .16059 .31587 Mtetra
.656 .753 .921 r
.16059 .31587 .17202 .32679 .18817 .32078 .17679 .30986 Mtetra
.657 .754 .922 r
.17679 .30986 .18817 .32078 .20442 .31471 .1931 .30377 Mtetra
.657 .755 .922 r
.1931 .30377 .20442 .31471 .22077 .30864 .20952 .29764 Mtetra
.658 .756 .922 r
.20952 .29764 .22077 .30864 .23723 .30256 .22603 .29145 Mtetra
.657 .755 .922 r
.22603 .29145 .23723 .30256 .25378 .29653 .24266 .28523 Mtetra
.657 .752 .92 r
.24266 .28523 .25378 .29653 .27043 .29049 .25938 .27899 Mtetra
.656 .75 .919 r
.25938 .27899 .27043 .29049 .28719 .28441 .27621 .27273 Mtetra
.656 .748 .917 r
.27621 .27273 .28719 .28441 .30406 .27827 .29315 .26645 Mtetra
.656 .746 .916 r
.29315 .26645 .30406 .27827 .32104 .27207 .3102 .26013 Mtetra
.656 .745 .916 r
.3102 .26013 .32104 .27207 .33813 .26581 .32736 .25377 Mtetra
.656 .745 .915 r
.32736 .25377 .33813 .26581 .35534 .25949 .34463 .24737 Mtetra
.34463 .24737 .35534 .25949 .37265 .25311 .36201 .24094 Mtetra
.655 .745 .916 r
.36201 .24094 .37265 .25311 .39008 .24667 .37951 .23446 Mtetra
.655 .746 .916 r
.37951 .23446 .39008 .24667 .40763 .24016 .39712 .22795 Mtetra
.655 .747 .918 r
.39712 .22795 .40763 .24016 .42529 .2336 .41485 .22141 Mtetra
.655 .749 .919 r
.41485 .22141 .42529 .2336 .44306 .22698 .4327 .21484 Mtetra
.654 .752 .921 r
.4327 .21484 .44306 .22698 .46095 .22035 .45066 .20825 Mtetra
.654 .754 .923 r
.45066 .20825 .46095 .22035 .47896 .21377 .46874 .20163 Mtetra
.654 .755 .923 r
.46874 .20163 .47896 .21377 .49708 .20718 .48695 .19495 Mtetra
.655 .754 .923 r
.48695 .19495 .49708 .20718 .51533 .20058 .50528 .18821 Mtetra
.656 .754 .922 r
.50528 .18821 .51533 .20058 .53371 .19391 .52373 .18139 Mtetra
.658 .753 .92 r
.52373 .18139 .53371 .19391 .5522 .18717 .54231 .17441 Mtetra
.658 .751 .918 r
.54231 .17441 .5522 .18717 .57082 .1803 .56101 .16737 Mtetra
.657 .748 .917 r
.56101 .16737 .57082 .1803 .58957 .17329 .57984 .16035 Mtetra
.655 .749 .919 r
.57984 .16035 .58957 .17329 .60843 .16625 .5988 .15337 Mtetra
.654 .751 .921 r
.5988 .15337 .60843 .16625 .62744 .1593 .61789 .14637 Mtetra
.654 .752 .922 r
.61789 .14637 .62744 .1593 .64657 .15234 .63711 .13934 Mtetra
.655 .753 .922 r
.63711 .13934 .64657 .15234 .66584 .14535 .65646 .13219 Mtetra
.658 .753 .92 r
.65646 .13219 .66584 .14535 .68523 .13826 .67594 .12487 Mtetra
.657 .75 .918 r
.67594 .12487 .68523 .13826 .70475 .13098 .69556 .11754 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
[(-2)] .12586 .2075 1 .99877 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.56863 .04703 m
.57247 .05235 L
s
[(2)] .56094 .0364 .72324 1 Mshowa
.125 Mabswid
.18558 .19702 m
.18832 .19985 L
s
.23703 .17687 m
.23971 .17975 L
s
.28951 .15632 m
.29214 .15925 L
s
.39772 .11395 m
.40023 .11699 L
s
.4535 .09211 m
.45595 .0952 L
s
.51046 .06981 m
.51284 .07294 L
s
.08568 .23614 m
.08851 .23887 L
s
.62804 .02377 m
.63027 .02701 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 233.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00o?ooool2o`0006[ooooo003iooooo`?o000000?oooooo`000?ooool0
JOooool00?Oooooo0_l00004ooooo`;o0000JOooool00?Cooooo0ol00006ooooo`03o`000?oooooo
000006Sooooo003;ooooo`Go00008_ooool2o`0000Wooooo00?o0000ooooool00000J?ooool00<_o
oooo00GoV9RHob4Q8Oo^k^koooooodA4A00Oooooo`?o00002oooool01?l0003oooooooooool0001W
ooooo`00c?ooool00onHV9So8B4Qonk^kP0Mooooo`?o00003_ooool01Ol0003ooooooooooooooooo
000006Kooooo003=ooooo`03oiRHV?lQ8B7ok^k^01[ooooo0_l0000Aooooo`05o`000?oooooooooo
ooooool00000I_ooool00<kooooo00?oMgMgofIVI_ooool05_ooool3o`0001?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1Sooooo`00coooool00ol0003oooooooooo`0Cooooo`;o
00000_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0H_ooool00<_ooooo00Go0000okZj^_ooooooV9RHoa0@400Booooo`?o00006Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo06;ooooo003;ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`04?ooool2o`0001cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Qooooo`00
gOooool3o`0001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Qooooo`00fooo
ool2o`00027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Pooooo`00f?ooool3
o`0002?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Oooooo`00eOooool3o`00
02Kooooo00?o0000ooooooooool01?ooool2o`00067ooooo003Cooooo`;o0000:Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo05kooooo003@ooooo`?o000000?oooooo`000?ooool0
:?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05gooooo003>ooooo`;o00001Ooo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0GOoo
ool00<_ooooo0ol0000`ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0G?ooool0
0<Wooooo0_l0000cooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Foooool00<Ko
oooo0ol0000eooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Foooool00<Cooooo
0_l0000hooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0F_ooool00<7ooooo0ol0
000jooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03_ooool5o`0004Kooooo002n
ooooo`?o0000?Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00kooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A016ooooo`00_?ooool2o`0000?ooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo1_l00003ooooo`03oiRHV?lQ8B7o
k^k^04Oooooo002iooooo`?o0000@oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00kooooo00?oV9RHob4Q8Oo^k^h0A_ooool00;Oooooo0_l00016ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03oooool00omgMgOoIVIVooooo`15ooooo`00]?ooool3o`0004Sooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Cooooo
002booooo`;o0000Boooool00ol0003oooooooooo`0=ooooo`;o00003?ooool01Ol0003o^[Zjoooo
oonHV9So410@04Kooooo002_ooooo`?o0000COooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c016ooooo`00[Oooool2o`00053ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`1Dooooo`00Z_ooool4o`00057ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1Dooooo`00Z?ooool2o`0000Cooooo00?o0000oooo
ooooool0C_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05?ooooo001nooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h08_ooool3o`0005Oooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`1Booooo`00O_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01oooooo0ol0001Joooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool0D_ooool007kooooo00Go410@oooooooo
oooooooooa0@400Mooooo`;o0000GOooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
057ooooo001nooooo`05o`000?ooooooooooooooool000006_ooool3o`0005oooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`1@ooooo`00O_ooool01Ol0003ooooooooooooooooo0000
01Sooooo0_l0001Rooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0D?ooool007ko
oooo00Go410@oooooooooooooooooa0@400Eooooo`?o0000I?ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo04oooooo001nooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool2o`00
00?ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
04kooooo001nooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04?ooool3o`0006Sooooo00?oZ;o[o`00
0?ooool05_ooool00ol0003oooooooooo`1>ooooo`00TOooool2o`0006Sooooo1?nX_n/00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo04gooooo002>ooooo`?o0000J?ooool7ojRoj`03o`00
0?oooooooooo01Cooooo0ol0001>ooooo`00Roooool3o`0006Wooooo0_nX`>/7ojRoj`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool0C?ooool008Wooooo0_l0001Yooooo`KoZ<3[1_nX_n/0
0ol0003oZ;o[ooooo`0Gooooo`03o`000?oooooooooo04_ooooo0026ooooo`?o0000J?ooool00onW
`>coZ<3[ojS0j`07ojS0j`GoZ;o[00?o0000ojS0joooool06?ooool00ol0003oooooooooo`1:oooo
o`00Q?ooool2o`0000;ooooo00?o0000ooooooooool0Hoooool5ojO0k0WoZ<3[0_nX_n/2ojS0j`03
o`000?nX`>_oZ<3[01Sooooo00?o0000ooooooooool0B_ooool0087ooooo0ol00005ooooo`03o`00
0?oooooooooo063ooooo2?nW`>`7ojS0j`03ojO0k?nX`>_oZ<3[00;oZ<3[00Co0000ojS0jonX`>_o
Z<3[6?ooool00ol0003oooooooooo`19ooooo`00Ooooool2o`0006Wooooo2_nW`>`4ojS0j`GoYl3/
0onX`>/00ol0003oZ<3[ojS0j`02ojS0jaSooooo00?o0000ooooooooool0B?ooool007cooooo0ol0
001Xooooo`koYl3/00?oZ<3[ojO0k?nW`>`01_nW`>`2ojS0j`05o`000?nX`>_oZ<3[ojS0jonW`>`0
6?ooool00ol0003oooooooooo`18ooooo`00N_ooool2o`0006Oooooo0_nW`>/IojO0k0;oZ<3[00?o
0000ojS0jonW`>`00onW`>`Hooooo`03o`000?oooooooooo04Oooooo001gooooo`?o0000I_ooool6
ojO0jaWoYl3/00?oZ<3[o`000?nW`>`01OnW`>`Hooooo`03o`000?oooooooooo04Kooooo001doooo
o`?o0000I_ooool00onW_n_oYl3[ojO0j`07ojO0j`KoYl3/0_nW`>/AojO0k003o`000?nW`>coYl3/
00CoYl3/6?ooool00ol0003oooooooooo`16ooooo`00L_ooool2o`0000;ooooo00?o0000oooooooo
ool0H_ooool4ojNoj`WoYl3[0_nW`>`6ojO0ja3oYl3/00?o0000ojO0k?nW`>`01OnW`>`Hooooo`03
o`000?oooooooooo04Gooooo001_ooooo`?o0000Ioooool7ojNoj`OoYl3[00?oYko[ojO0jonW`>/0
1onW`>/6ojO0k003ojO0jonW`>coYl3/00KoYl3/00?o0000ojO0k?nW`>`01OnW`>`Hooooo`03o`00
0?oooooooooo04Gooooo001]ooooo`;o0000Ioooool2ojRojPSoYko[1?nW`>/5ojNoj`WoYl3[0_nW
`>`5ojO0j`OoYl3/00?o0000ojO0k?nW`>`01_nW`>`Gooooo`;o0000A_ooool006[ooooo0ol0001V
ooooo`KoZ;oZ2?nW_n/00onW`>_oYko[ojNoj`06ojNoj`OoYl3[00?oYko[ojO0jonW`>/01_nW`>/6
ojO0k003o`000?nW`>_oYl3/00OoYl3/6?ooool00ol0003oooooooooo`13ooooo`00J?ooool2o`00
06Kooooo0_nX`>/8ojRojPKoYko[0_nX_nX8ojNoj`CoYl3[1OnW_n/8ojO0j`;oYl3/0onW`>/00ol0
003oYl3[ojO0j`08ojO0k1Oooooo00?o0000ooooooooool0@oooool006Gooooo0ol0001Uooooo`Ko
Z<3[2?nX_nX2ojNoj`KoZ;oZ2?nW_n/00onW`>_oYko[ojNoj`06ojNoj`KoYl3[00?oYko[ojO0jonW
`>/00onW`>/01?l0003oYl3[ojO0jonW`>/6ojO0k003ojO0jooooooooooo01Kooooo00?o0000oooo
ooooool0@_ooool006?ooooo0_l0001Uooooo`[oZ<3[1_nX_nX00onX`>_oZ;oZojRojP07ojRojPKo
Yko[00?oZ;o[ojNojonW_n/01onW_n/4ojO0j`CoYko[1OnW`>/01?l0003oYl3[ojO0jonW`>/2ojO0
k0GoYl3[6?ooool00ol0003oooooooooo`11ooooo`00H?ooool3o`000003ooooool0003ooooo06;o
oooo3OnX`>/2ojRojPGoZ<3[2OnX_nX2ojNoj`GoZ;o[2OnW_n/00onW`>_oYko[ojNoj`05ojNoj`Co
Yl3[00Co0000ojO0jonW`>_oYko[2?nW`>/Gooooo`03o`000?oooooooooo047ooooo000fooooo`Go
00008oooool2o`0006Kooooo3_nX`>/00onW`NcoZ<3[ojS0j`06ojS0j`KoZ;oZ0_nX`N/8ojRoj`Ko
Yko[0_nX`>/8ojNoj`CoYl3[00?o0000ojNojonW_n/00_nW_n/8ojO0jaOooooo00?o0000oooooooo
ool0@?ooool003Kooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Pooooo`?o0000IOooool2ojO1k0co
Z<3[1OnW`N`8ojS0j`;oZ;oZ1_nX`N/8ojRoj`;oYko[1_nX`>/8ojNoj`04ojO0jonW_n_oYko[o`00
00GoYko[1_nW`>/00onW_n_oooooooooo`0Fooooo`03o`000?oooooooooo03oooooo000^ooooo`Ko
00000oooool00onHV9So8B4Qonk^kP0Nooooo`?o0000IOooool6ojO1k0WoZ<3[2?nW`N`6ojS0j`03
ojO1k?nX`N_oZ<7[00OoZ<7[1_nX_n/00onX`N_oZ<3[ojS0j`07ojS0j`KoYko[00GoZ<3[ojNojonW
_n_oYko[o`000005ojNoj`CoYl3[1?nW_n/Gooooo`03o`000?oooooooooo03oooooo000hooooo`03
oiRHV?lQ8B7ok^k^01_ooooo0_l0001Uooooo`[oYl7/1_nX`>/:ojO1k0CoZ<3[1?nW`N`9ojS1j`;o
Z;o[1OnX`N/9ojS0j`;oYko[1OnX`>/2ojNoj`03o`000?nW_n_oYko[00CoYko[00?oYl3[ojNojonW
_n/01OnW_n/Gooooo`03o`000?oooooooooo03kooooo000iooooo`03ogMgMomVIVKooooo01Oooooo
0ol0001Tooooo`koYl7/0_nX`>/>ojO1k003ojS0jonW`NcoYl7/00GoYl7/1onX`N/00onW`NcoZ<7[
ojS1j`06ojS1j`KoZ<3[0_nX`N/8ojS0j`03ojNojol0003oYko[00?oYko[0_nX_n/8ojNojaSooooo
00?o0000ooooooooool0?Oooool003[ooooo00?o0000ooooooooool05?ooool2o`0006Cooooo:_nW
`N`4ojS1j`CoYl7/2?nX`N/2ojS0j`KoZ<7[2?nX`>/00ol0003oYko[ojRoj`05ojRoj`SoYko[5ooo
ool00ol0003oooooooooo`0mooooo`00=_ooool01Ol0003o^[ZjoooooonHV9So410@01?ooooo0ol0
0002ooooo`03o`000?oooooooooo05oooooo;OnW`N`00onX`N_oYl7/ojO1k005ojO1k0KoZ<7[00?o
Yl7/ojS1jonX`N/01onX`N/6ojS0j`03ojS1jol0003oZ;o[00OoZ;o[1_nW_n/00onX_n_ooooooooo
o`0Fooooo`03o`000?oooooooooo03cooooo000fooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`04Ooo
ool2o`0006Gooooo3_nW`N`00onW`>coYl7/ojO1k00<ojO1k0;oYl3/6?nW`N`4ojS1j`CoYl7/2OnX
`N/2ojS0j`CoZ<7[00?o0000ojRojonX_n/01onX_n/2ojNoj`GoZ;o[5_ooool3o`0003gooooo0019
ooooo`?o0000IOooool>ojO1k0CoYl3/2_nW`N`6ojO0k1SoYl7/00?oZ<7[ojO1k?nW`N`01OnW`N`7
ojS1j`03ojO0k?nX`N_oZ<7[00CoZ<7[00?o0000ojS1jonX_n/01OnX_n/2ojS1j`SoZ;o[5oooool0
0ol0003oooooooooo`0kooooo`00Aoooool2o`0006Gooooo3onW`N`7ojO0k0KoYl7/0_nW_n/8ojO0
k0KoYl7/00?oYko[ojO1k?nW`N`03OnW`N`00onW`>coYl7/ojO1k006ojO1k0CoZ<7[1OnW`>`5ojS1
j`03o`000?nX`N_oZ<7[00;oZ;o[1_nX`N/8ojRojaOooooo00?o0000ooooooooool0>_ooool004Co
oooo0ol0001Tooooo`03ojO0jonW`NcoYl7/00coYl7/0_nW_n/8ojO0k0CoYl7/1OnW_n/8ojO0k0;o
Yl7/1OnW_n/;ojO1k0GoYl3/2?nW`N`00onX`N_oYl3/ojO0k006ojO0k0CoZ<7[00?o0000ojS1jonW
`>`02OnX`N/6ojRoj`03ojS0jooooooooooo01Kooooo00?o0000ooooooooool0>Oooool0047ooooo
0ol0001Tooooo`GoYl3[2_nW`N`6ojNoj`SoYl3/00?oYl7/ojNojonW_n/01_nW_n/6ojO0k003ojNn
j_nW_n_oYko[00KoYko[1_nW`N`2ojNoj`SoYl3/1_nW`N`2ojK0k0WoYl3/0_nX`N/00onW`>co0000
ojO0k002ojO0k0WoZ<7[0_nX_n/5ojS0jaOooooo00?o0000ooooooooool0>Oooool003oooooo0ol0
001Sooooo`03ojNojonW`>_oYl3[00KoYl3[1_nW`N`2ojNnjPSoYko[1_nW`>`2ojNnjPWoYko[0_nW
`>`5ojNnjPSoYko[0_nW`N`6ojNoj`SoYl3/0_nW`N`6ojK0k0OoYl3/00GoY/3/ojO0k?nW`>coYl3/
o`000004ojO0k0KoZ<7[0_nW`>`8ojS0jaOooooo00?o0000ooooooooool0>?ooool003cooooo0ol0
0003ooooo`03o`000?oooooooooo05gooooo1OnW_n/8ojO0j`;oYl7/1_nW_^X8ojNoj`;oYl3/1_nW
_^X7ojNoj`03ojRoj_nW_^[oYkkZ00KoYkkZ1_nW_n/2ojNnjPSoYko[1_nW`>`00onW_n_oY/3/ojK0
k007ojK0k0CoYl3/1?nV`>`2ojO0k003o`000?nW`>coYl3/00?oYl3/0_nX`N/6ojO0k0SoZ<3[5_oo
ool00ol0003oooooooooo`07ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0;?ooool003[ooooo0_l0
001Sooooo`WoYko[1_nW`>/2ojRnjPSoYkkZ1_nW_n/00onX_n[oYkkZojNnjP07ojNnjPCoYko[1?nX
_nX8ojNnjP;oYko[1_nW_^X8ojNoj`;oYl3/1OnW_n/9ojK0k003ojO0k?nV`>coY/3/00GoY/3/00?o
Yl3/o`000?nW`>`03OnW`>`7ojS0jaOooooo00?o0000ooooooooool01_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg02cooooo000gooooo`?o0000Hoooool<ojNoj`;oYl3[1_nX_^X8ojNnjP;oYko[1OnX
_nX9ojNnjP03ojNojonX_n[oZ;oZ00GoZ;oZ1_nW_^X00onY_n[oYkkZojNnjP07ojNnjPKoYko[00?o
Z;oZojNojonW_n/01_nW_n/6ojK0k0;oYko[2?nV`>`2ojO0k003o`000?nW`>coYl3/00coYl3/1onX
`>/Gooooo`03o`000?oooooooooo00Gooooo00Go410@oooooooooooooooooa0@400/ooooo`00=Ooo
ool2o`0006Cooooo3OnW_n/:ojRnjPKoYkkZ2OnX_nX6ojNnjP;oZ<3[2?nX_nX4ojNnjPCoZKoZ2OnW
_^X2ojNoj`GoZ;oZ2?nW_n/2ojK0k0KoYko[2?nV`>`00onW`>co0000ojO0k00=ojO0k0SoZ<3[5_oo
ool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool00000;?ooool003;ooooo0ol0
001Tooooo`03ojNnj_nW_n_oYko[00[oYko[3OnX_^X2ojNnjPgoZ;oZ0_nW_^X6ojS0j`SoZ;oZ00?o
YkkZojVoj_nY_nX01OnY_nX7ojNnjP03ojW0jonX_n[oZ;oZ00KoZ;oZ1_nW_n/00onX_n[oYko[ojNo
j`07ojNoj`KoY/3/00?oY[o[ojO0k?l000003onW`>`8ojS0jaKooooo00?o0000ooooooooool01?oo
ool01Ol0003ooooooooooooooooo000002cooooo000`ooooo`;o0000I?ooool5ojNnjPWoYko[3_nX
_^X00onX`>_oZ;oZojRojP0<ojRojP;oZ<7[2?nX`>/6ojRojP03ojS1jonY_n[oZKoZ00KoZKoZ1?nW
_^X5ojW0j`SoZ;oZ0_nW_n/5ojRojPWoYko[0_nV`>`5ojJoj`03o`000?nW`>coYl3/00CoYl3/00?o
Y/3/ojO0k?nW`>`01_nW`>`6ojS0j`;oYl3/5oooool00ol0003oooooooooo`03ooooo`05oa0@4?oo
ooooooooooooool@4100;?ooool002gooooo0ol000000ooooooo0000ooooo`1Pooooo`WoYkkZ1_nW
_n/2ojRojPcoZ;kZ1?nX`>/:ojRojPKoZ<7[2?nX`>/2ojRojPGoZ<7[2?nY_nX00onW_^[oZL3[ojW0
j`06ojW0j`KoZ;oZ00?oZL3[ojRoj_nX_nX01_nX_nX6ojNoj`;oZ;oZ1onV_n/00ol0003oYl3/ojO0
k002ojO0k0CoY/3/2?nW`>`2ojS0j`KoYl3/5_ooool2o`0000Cooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0/ooooo`00:_ooool3o`0006?ooooo3OnW_^X2ojNoj`KoZ;oZ2OnX_^X7ojS0j`KoZ;oZ0_nW
`>`8ojS1j`KoZ<3[00?oYl3/ojS1jonX`N/01_nX`N/6ojVojP;oZ<7[2OnY`>/2ojRojPGoZL3[2?nX
_nX2ojNoj`KoZ;oZ1_nV_n/00ol0003oY[o[ojO0k007ojK0k0KoYl3/00?oY/3/ojO0k?nW`>`01onW
`>`Cooooo`;o000000?oooooo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02cooooo
000Xooooo`;o0000Hoooool?ojNnjP;oZ;o[2?nX_nX6ojRnjP[oZ<3[0_nX_nX6ojO0k0SoZ<7[0_nX
`>/5ojO0k0SoZ<7[0_nY_nX6ojS1j`OoZL3[00?oYl3[ojW0jonY`>/01_nY`>/6ojRojP03ojW0jonX
_n[oZ;oZ00OoZ;oZ1OnV_n/00ol0003oYkoZojK0k008ojK0k0;oYl3/1OnV`>`9ojO0k1Kooooo00?o
0000ooooooooool0<_ooool002Gooooo0ol0001Rooooo`ooYkkZ1_nX_n/8ojRojP;oZ;kZ3?nX`>/:
ojO0k0KoZ<7[2OnW`>`6ojS1j`03ojO0k?nX`N_oZ<7[00OoZ<7[1?nY`>/4ojO0j`SoZL3[0_nX_nX5
ojW0j`WoZ;oZ0_nV_n/00onW_n[o0000o`000002ojNojPOoY/3/00?oYko[ojK0k?nV`>`01_nV`>`8
ojO0k1Kooooo00?o0000ooooooooool0<_ooool002?ooooo0_l0001Rooooo`ooYkkZ2_nX_n/6ojRo
jP03ojO0k?nX`>_oZ<3[00[oZ<3[3OnW`>`2ojS1j`goYl3/0_nX`N/5ojO0k0WoZ<7[00?oZL3[ojO0
jonW`>/01OnW`>/6ojW0j`03ojO0jonY`>_oZL3[00KoZL3[1_nX_nX2ojW0jP?o000000?oYkoZo`00
0?nW_nX00_nW_nX4ojK0k0CoYko[2?nV`>`8ojO0k1Kooooo00?o0000ooooooooool0<Oooool0023o
oooo0ol0001Qooooo`ooYkkZ3_nX_n/2ojRojPGoYl3/2OnX`>/>ojO0k003ojNojonW`>coYl3/00co
Yl3/00?oYko[ojO0k?nW`>`01_nW`>`6ojS1j`;oYl3/2OnW`>/2ojW0j`GoYl3[2?nY`>/2ojRojP;o
ZL3Z0ol000000onY`>[oYkoZojNojP02ojNojP05o`000?nW_n[oYkoZojNoj_nV`>`01onW_n/6ojK0
k003ojJok?nW`>coYl3/00KoYl3/5oooool00ol0003oooooooooo`0`ooooo`007oooool2o`00063o
oooo3onW_^X2ojO0j`koZ;o[00?oYl7/ojO0k?nW`>`01_nW`>`6ojS0j`;oYl3[2onW`>`5ojNoj`[o
Yl3/1OnW_n/8ojO0k0;oZ<7[1_nW`>`7ojO0j`03ojO0k?nW`>_oYl3[00KoYl3[1_nY`>/00onX`>_o
ZL3Zo`000002o`0000CoZL3Z1OnW_nX00ol0003oZKoZojVojP09ojNoj`;oY/3/1OnV_n`8ojO0k1Ko
oooo00?o0000ooooooooool0<?ooool001oooooo00?o0000ooooool00000GOooool>ojNnjPKoYl3[
2_nX_n/5ojO1k0SoYl3/0_nX`>/6ojO0j`OoYl3/00?oYk_XojNojonW_n/01_nW_n/6ojO0k003ojNj
ionW_n_oYko[00KoYko[1_nW`>`2ojNmj@SoYl3/1?nW`>/4ojO0k0SoYl3[0_nY`>/2ojS0j`?o0000
2?nY`>X2ojNojP?oZKoZ00?o0000ojVoj_nY_nX01onW_n/00onX_n[oY[o/ojJok006ojJok0KoYl3/
00?oY/3/ooooooooool05Oooool00ol0003oooooooooo`0_ooooo`003?ooool5o`0000?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP06ooooo`04o`000?ooooooooooo`0005[ooooo3OnW_^X:ojO0j`Ko
Z;o[2OnW`N`6ojO0k0;oYko[2?nW`>/4ojO0k0CoYk_X2?nW_n/2ojO0k0GoYk[W2?nW_n/2ojO0k0Ko
YkgY2?nW`>`00onW`>_oYl3/ojO0k005ojO0k0KoYl3[00?oYl3/ojS0jol000000_l00004ojS0j`Ko
ZL3Z00?oZ<7[ojVoj_nY_nX00onY_nX01?l0003oZKoZojVoj_nY_nX4ojNoj`CoZ;oZ2?nV_n`2ojO0
k0GoY/3/5oooool00ol0003oooooooooo`0^ooooo`003?ooool01OnHV9So8B4Qonk^k_ooooooA4A4
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`;o00000_ooool00ol0003oooooooooo`1E
ooooo`goYkkZ3OnW`>/2ojRoj`goYl7/0_nW`>`6ojNoj`SoYl3[00?oYl3/ojNkj?nW^nP01OnW^nP6
ojNoj`03ojRdhOnW^^OoYk[W00KoYk[W1_nW_n/00onX]^?oYkgYojNmj@07ojNmj@KoYl3/0_nW_>P8
ojO0k0;oYl3[0_nW`>`3o`0000SoZ<3[0_nY`>X5ojS1j`GoZKoZ00Go0000ojVoj_nY_n[oZKoZojNo
j`07ojRojPKoY[o/00?oYko[ojK0k?nV`>`01_nV`>`Fooooo`03o`000?oooooooooo02kooooo0004
ooooo`Ko00000oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41001Ooo
ool2o`0000Cooooo00?o0000ooooooooool0DOooool?ojNnjPgoYl3[3onW`N`2ojNmj@SoYko[1_nW
`>/00onW]nCoYk_XojNkj007ojNkj0;oYko[1OnX]>48ojNji`;oYko[1OnX]^<9ojNmj@;oYl3/1_nW
_>P6ojO0k003ojNlj?nW`>co000000;o00001?nW`>`6ojS0j`03ojO0k?nX`N_oZ<7[00KoZ<7[1OnY
_nX00ol0003oZL7[ojW1j`09ojRojP;oY[o/1OnW_n/8ojK0k1Kooooo00?o0000ooooooooool0;Ooo
ool000kooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000Gooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`1=ooooo`;oYkoZ3_nW_^X2ojNoj`[oYl3[3onW
`N`6ojNmj@SoYko[0_nW`>/5ojNgi0OoYk_X00?oZK3LojRdhOnX]>401_nX]>46ojNji`03oj^agOnX
]^?oZ;KS00KoZ;KS1_nW_NT2ojVdh@WoYkcX0_nW`>`3ojNlj0;o00002?nW`>`2ojS0j`GoYl3/2?nX
`N/2ojVojP;oZL7[00Co0000ojW1jonY`N_oZL7[1onX_nX00onY`>[oYko[ojNoj`06ojNoj`KoY/3/
00?oY[o/ooooooooool05Oooool00ol0003oooooooooo`0/ooooo`003oooool00omgMgOoIVIVoooo
o`02ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo04Wooooo1_nW_nX:ojNnjPKoYko[1_nW`>/?ojO1k0;oYkcX2?nW_NT6ojNoj`03ojNc
hOnW]nCoYkOT00KoYkOT1?nW^nP4ojV`g0OoZ;CQ1?nW^^L4oj^ag@SoZ;KS0_nW_NT6ojVdh@OoYkcX
00?oZ[CPojNlj?nW_>P00ol00003ojNlj0KoYl3/00?oYkgYojO0k?nW`>`01_nW`>`6ojS1j`03ojO0
k?nY`N_oZL7[00?oZL7[00?o0000ojW1jonY`N/01?nX_nX5ojW0jPSoYko[0_nV`>`5ojJok1Gooooo
0_l0000^ooooo`004?ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool0
0oooool2o`0000Oooooo00?o0000ooooooooool0A_ooool00onW_n_oYkoZojNojP06ojNojPKoYkkZ
2_nW_n/2ojO0j`ooYl7/1_nW_>P8ojNmj@;oYko[1OnW/n48ojNgi003ojNkj?nY/=coZK3L00GoZK3L
1onX]>400onW^^OoZk7Moj^ag@05oj^ag@KoZ;KS00?o[[7KojVdhOnY]>401onY]>44ojNlj0;oZ[CP
0ol00007ojNlj0;oYl3/1OnW_NT8ojO0k0;oZ<7[1OnW`>`5ojW1j`04o`000?nY`N_oZL7[ojRojPSo
ZL3Z1_nW_n/00onX_n[oY[o/ojJok006ojJok1Kooooo00?o0000ooooooooool0:oooool000cooooo
00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo04;ooooo1OnW_n/8ojNojP;oYkkZ3?nW_n/?ojO1
k0;oYk_X2?nW_>P6ojNmj@03ojN`g_nW/n7oYk?Q00KoYk?Q1_nW]n@00on[[][oZK3LojV`g006ojV`
g0KoZ;CQ00?o[JkHoj^agOn[/Md01_n[/Md4ojRfh`Co[[7K2OnY]>400onW_>SoZ[CPo`000002o`00
00?oZ[CP1_nW_>P00on[]^7oYkgYojNmj@06ojNmj@KoYl3/00?oYkk[ojO0k?nW`>`01_nW`>`5ojW1
j`03o`000?nX`>_oZL3Z00WoZL3Z0_nW_n/5ojRojPSoY[o/5Oooool00ol0003oooooooooo`0[oooo
o`003?ooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0?_ooool2ojS0j`OoYko[1_nW_nX=
ojNoj`koYl7/1_nW^nP8ojNlj0;oYkgY1OnW/=h8ojNch@;oYkOT1On[[]X8ojV`g0;oZ;CQ1On][]P8
oj^ag@03ojRfhon^/M_o[[7K00Go[[7K1onY]>43o`0000KoZ[CP1?nW_>P4oj^fh@SoYkgY0_nW`>`5
ojNnj`SoYl3/0_nY`N/2ojS0j`03o`000?nX`>_oZ<3[00SoZL3Z00?oZL7[ojRoj_nX_nX01OnX_nX6
ojJok0;oY[o[5_ooool00ol0003oooooooooo`0Zooooo`007_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo03[ooooo1_nX`>/7ojNoj`;oYkoZ3_nW_n/>ojO1k0WoYk_X1_nW_>P00onW
[]goYk3NojN`gP06ojN`gPKoYk?Q00?oZZ_Hoj^^f_n[[]X01_n[[]X6ojV`g003ojf/e_n][]So[JkH
00Ko[JkH1_n[/Md00on`[]Ko[[7Kojjaf`07ojjaf`?oZKCQ0ol00002ok6bf@SoZ[CP00?oYkcXoj^f
hOn[]^401On[]^46ojNmj@03ojZhhonW_^_oYkk[00KoYkk[1onW`>`5ojS0j`03o`000?nX`>_oZ<3[
00CoZL3Z1OnY`N/7ojRojP;oY[o/1_nV_n/Fooooo`03o`000?oooooooooo02Wooooo000Mooooo`?o
00002oooool00ol0003oooooooooo`0fooooo`;oZ<7/2?nX`>/5ojNoj`;oYkkZ3OnW_n/=ojO1k0go
Yk_X0_nW_>P5ojN^g@OoYk3N1?nW/n44ojZ[f0OoZjkJ1?nY/=`4ojf/ePOo[JkH1?n[/Md4ok2^ePSo
[[7K0ol00006ok6bf@KoZ[CP00?o/[CJoj^fhOn[]^401on[]^42ojNmj@GoZ[SS2?nW_^/7ojO0k0Go
Z<3[00Co0000ojS0jonX`>_oZL3Z1onY`N/6ojRojP03ojW0j_nV_n_oY[o[00KoY[o[5_ooool00ol0
003oooooooooo`0Yooooo`007Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03;o
oooo1_nX`N`8ojS0j`03ojNojonW_^[oYkkZ00CoYkkZ2OnW_n/=ojO1k003ojNlj?nW^nSoYk_X00co
Yk_X00?oYZgLojN^gOnW[]d01_nW[]d7ojN`gP03ojNchOnZZmSoZZ_H00CoZZ_H2?n[[]X00onY/=co
[JcFojf/eP04ojf/ePSo[JkH00?oZk7Mok2^e_n`[]H01On`[]H4ojjaf`?o000000?o/[3Fok6bfOna
/]T01_na/]T4ojZdh0Co/[CJ1on[]^400onc]mcoZ[SSojZhh`06ojZhh`KoYkk[00?oZ;_WojO0k?nW
`>`01_nW`>`5ojS0j`03o`000?nW`>_oYl3[00SoZL7[0_nX_nX5ojW0jPSoY[o[5_ooool00ol0003o
ooooooooo`0Xooooo`007Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02oooooo
2OnX`N`6ojS0j`WoYkkZ1_nW_n/2ojO0j`[oYl7/1OnW_>P:ojNkj0GoYZgL1onW[]d6ojN`gP03ojVY
eonZZmSoZZ_H00KoZZ_H1_n[[]X00on]ZmKo[JcFojf/eP06ojf/ePKo[JkH00?o/JoFok2^e_n`[]H0
1on`[]H3o`000003ojjafonb/=Ko/[3F00;o/[3F2?na/]T00onZ]>3o/[CJok:dfP05ok:dfPCoZkKQ
1?nc]m`8ojZhh`;oYkk[1OnX^nL8ojO0k0;oZ<3[0_nW`>/01?l0003oYl3[ojO0jonW`>/6ojW1j`03
ojS0jonY`>[oZL3Z00KoZL3Z1_nV_n/00onW_n_oooooooooo`0Eooooo`03o`000?oooooooooo02Oo
oooo000Mooooo`;o00003oooool00ol0003oooooooooo`0[ooooo`goZ<7/0_nX`>/=ojNnjP;oYko[
1_nW`>/6ojO1k0;oYkkY1onW_>P6ojNkj003ojJ]gOnV[McoYZgL00KoYZgL1onW[]d2ojN`gPGoZJWG
1onZZmP4oj^^fPCo[J_F1on][=H4ojf^f0Co/JoF1_n`[]H2o`000003ok2^e_n^/M_o/[3F00Ko/[3F
1_na/]T00one/]Ko/[CJok:dfP07ok:dfP03oj^fhOnc]mco/kOL00Go/kOL1_nZ^><00ona^=koZ;_W
ojRki`06ojRki`KoYl3/0_nW_^X4ojO0j`04o`000?nW`>_oYl3[ojO0j`;oZL7[1OnX`>/8ojW0jP;o
Y[o[1OnW_n/Fooooo`03o`000?oooooooooo02Oooooo000Mooooo`03o`000?oooooooooo00oooooo
0_l0000Xooooo`ooZ<7/3onW_^X:ojO0j`;oYl7/1_nW_^T7ojNlj0;oYk_X1OnV[Md7ojJ]g0KoYjkM
00?oYjSGojVYeonYZML01_nYZML7ojZ[f003oj^^f_n]ZmKo[J_F00Co[J_F2?n][=H00on][]So/JoF
ok6_eP05ok6_eP;o/:kF0ol00002ok2^eP03okJef?nb/=Ko/[3F00Ko/[3F1?na/]T4okFbePOo/[CJ
00?o]kCGok>gg?nc]m`01_nc]m`4ojZhh`Co/KSN2?nX^nL2ojO0k0KoYkkZ1?nW`>/00ol0003oYl3[
ojO0k008ojS0j`KoZL3Z00?oZL7ZojNojonW_n/01_nW_n/Fooooo`03o`000?oooooooooo02Kooooo
000Mooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool08_ooool?ojS1k0ooYkkZ3?nW
`>/2ojRojPSoYkkY1OnW_>P00onU[MgoYZgMojJ]g@06ojJ]g@OoYZgL0_nW[]d5ojNXe`OoZJWG1_nZ
ZmP00on][]So[J_Fojf[eP06ojf[ePKo[JcF00?o/[GKok6_e_na[mH01Ona[mH3o`0000?o/:kF1?nf
]MP8ok:`eP03ok6bfOne/]Ko]K;F00Go]K;F1Onb]=X3okNde`So/kOL00?oZ[SSok6hg_na^=h01Ona
^=h6ojRki`03ojfjhonW_^[oYkkZ00OoYkkZ0_nW`>/2ojO0k003o`000?nW`>coYl3/00SoZ<3[0_nY
`>X5ojW1jPSoYko[5_ooool00ol0003oooooooooo`0Uooooo`007Oooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo01kooooo3onX`N`2ojRoj`goYkkZ3OnW`>/5ojRojPSoYkkY00?oYkcX
ojF]gOnU[Md00onU[Md7ojJ]g@KoYZgL00?oYZOGojNXeonWZ=L01_nWZ=L7ojVYe`;oZZ_H1On][]P7
ojf[ePCo[JcF1?nb]M/3ok6_eP?o00000ona[mH00on`[]Ko][GHokJef005okJef0Ko/[3F00?o^;_K
okFbe_ne/]H01_ne/]H3ok:dfPKo]kCG1_nc]m`00ong]]So/KSNok6hgP07ok6hgP;oZ;_W1On]^^<7
ojNnjP03ojRmj?nW`>coYl3/00;oYl3/00Co0000ojO0k?nW`>coYl3/1_nX`>/00onW`>_oZL7ZojW1
jP06ojW1jPKoYko[00?oZ<3[ooooooooool05?ooool2o`0002Kooooo000Looooo`?o00005?ooool0
0ol0003oooooooooo`0Kooooo`koZ<7/1_nX_n/9ojNnjPooYl3[1onX_nX6ojNnj@03ojF_gonU[Mgo
YJgM00GoYJgM1onV[Md3ojJ]g0CoYZOG1onWZ=L6ojVYe`03ojbag?n][]So[JkH00Ko[JkH1on]ZmH0
0on][=Ko/[GKok:ef`04ok:ef`?o00001Ona[mH00one`N?o][GHokJef006okJef0Co/[3F1?nh^m/8
okFbeP03ok:df_ng]=Oo]kCG00Go]kCG1?nc]m`4okNff0Oo/KSN00?o]kWKojfjhon]^^<01_n]^^<4
ojNnjPCoZ;gX1?nW`>`01?l0003oYl3/ojO0k?nW`>`2ojS0j`GoYl3[2?nY`NX2ojNoj`GoZ<3[5?oo
ool00ol0003oooooo`00000Vooooo`007?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo01Wooooo3OnX`N`2ojS1j`OoZ;o[1_nW_^X00onW_n_oYl3[ojO0j`0>ojO0j`SoZ;oZ0_nW_^T5
ojF_g`KoYJgM2?nV[Md00onV[McoYZOGojJWe`04ojJWe`OoYjSG0onYZML4ojbag0So[JkH1On]ZmH2
ok6ni0?o/[GK0ol00002ok:ef`Co/JoF1?ne`N<8okJef003ok:`e_nh^m_o^;_K00Go^;_K1_ne/]H0
0onj_Mco]kCGokNde`07okNde`03ok>gg?ng]]So]kKH00Go]kKH1?na^=h4okNif`So[K[S00?oYkkZ
ojRmj?nX_NP01OnX_NP4ojO0k003o`000?nW`>coYko[00SoYl3[1_nY`NX00onY`N_oZ<3[ojS0j`06
ojS0jaKooooo00?o0000ooooooooool08oooool000[ooooo1?l000002?l@413oooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^1_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01Kooooo
0onW`>/9ojS1k0KoZ<7[1onX_n/2ojNnjPGoYko[4?nW`>/6ojRojP03ojFbhOnU[mooYJoO00GoYJoO
1onU[Md6ojJ]g@03ojBVeonVYmOoYZOG00GoYZOG2?nWZ=L00onYZMOo[;7Lojbag004ojbag0So[JkH
00?o[J_Fok6ni?na_^@00ona_^@3o`0000Ko/[GK00?o/JoFokG1hone`N<01One`N<6okJef003okG9
jOnh^m_o^;_K00Ko^;_K1?ne/]H4okZmg0Oo]kCG00?o_;cJokNff?ng]]P01ong]]P00ona^=ko]kWK
okNif`05okNif`Ko[K[S00?o];cOojRmj?nX_NP01onX_NP2ojO0k003ojNojol0003oYko[00;oYko[
2?nW`>/2ojW1jPGoZL7[2?nX`>/Eooooo`03o`000?oooooooooo02?ooooo000<ooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool04_ooool7ojO0j`OoZ<7/2?nX`N/5ojRoj`;oY[kZ1onW_n/6ojO0j`?oYl7/
1onW`>/2ojRojPGoYK;Q1onU[ml7ojF]g@;oYZgM1OnTY]L7ojJWe`KoYjSG00?oZkCOojbag?n//M`0
1On//M`7ojf^f004ojk7kOna_^Co/KkTok6ni0?o00000_na_^@6ok:ef`03ojg=l?ne`N?o]L7S00Ko
]L7S1?nf]MP4okG9j@So^;_K00?o]K;FokZmg?nj_M`01Onj_M`5okNde`?o_;cJ1ong]]P00onl^mWo
]kWKokNif`07okNif`;o[K[S1Ond_=l7ojRmj003ojbliOnW_n_oYko[00;oYko[00Co0000ojNojonW
_n_oYko[1onW`>/7ojW1j`SoZ<3[5_ooool00ol0003oooooooooo`0Rooooo`0000?oooooo`000?l0
00001?l00005ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006oooo
o`;o00006Oooool00ol0003oooooooooo`0>ooooo`?oYko[2?nW`>/7ojS1k0SoZ<7[00?oZ;o[ojJn
j_nV_^X01?nV_^X7ojNoj`;oYl3[1onW`N`5ojO0j`03ojJfi?nU/^7oYK;Q00KoYK;Q1_nU[ml6ojF]
g@03oj>Vf?nTY]OoY:KG00KoY:KG1onVYmL2ojNXe`GoZkCO1on//M`4ojf^f0Co[/O]0_l00006ok6n
i0;o/[GK1On]cO08okG1h`03okJef?nebNWo]LWY00Go]LWY1_nh^m/00oncbn_o^[gLokZmg006okZm
g0?o]kCG1_nl_=X5okNff0?o_;_I1ong^M/00onk^mWo];cOokBlg`06okBlg`CoZ;gX1?n/_>D4ojNo
j`04o`000?nW_n_oYko[ojNoj`OoYl3[1onY`N/8ojS0jaKooooo00?o0000ooooooooool08Oooool0
00cooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`0:ooooo`OoYko[1_nW`>/9ojS1k0KoZ<7[2OnV_^X5
ojNoj`?oZ<7[2?nW`N`00onW`>_oY[KTojJfi003ojJfi0OoYK;Q1onU[ml2ojF]g@GoXjKH1onTY]L6
ojJWe`03ojVeh_n[]=ooZkCO00KoZkCO1on//M`01?n][]So[/O]ojk7kOn^and3o`000003ojk7kOna
_^Co/KkT00Co/KkT00?oWmSkojg=l?n]cO001_n]cO06okG1h`03oj;DnOnebNWo]LWY00Ko]LWY1?nh
^m/4ok?;j`So^[gL00?o]kCGokblf_nl_=X01Onl_=X3okNff0Ko_;_I1Ong^M/3ok^kf@So];cO00?o
Z;gXojbliOn/_>D01?n/_>D5ojNoj`03o`000?nW_n_oYko[00OoYl3[1_nY`N/2ojS1j`SoZ<3[5Ooo
ool00ol0003oooooooooo`0Qooooo`003?ooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000001Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Oooooo2_nW
_n/2ojO0j`goZ<7/0_nX`N/=ojJnjP03ojNojonX`N_oZ<7[00GoZ<7[1_nW`N`00onW^nSoY[KTojJf
i005ojJfi0OoYK;Q0onU[ml3oj:Vf@SoXjKH1onTY]L2ojJWe`GoZKGR1on[]=l6ojbag0;oZ<gc0ol0
0005ojk7k@;o/KkT1OnOf?/8ojg=l0;o]L7S1OnRe?T8okG9j@03okRkfoncbn_o/l_[00Go/l_[1_nj
_M`00oneb^Wo_;cJokblfP07okblfP03okNff?nl^mWo_;_I00Go_;_I0ong^M/6ok^kf@Ko];cO00?o
^KgMojbliOn/_>D01_n/_>D4ojNoj`04o`000?nW_n_oYko[ojNoj`OoYl3[0_nY`N/6ojS1j`KoZ<3[
00?oZL3[ooooooooool05?ooool00ol0003oooooooooo`0Pooooo`003?ooool00ol0003ooooooooo
o`02ooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo00?ooooo3?nW_n/2ojS1j`goZ<7/0_nW_n/=ojJnjP;oZ<3[2?nX`N/2ojO1k0GoYk_X
1onV]^@5ojFbh@03oj2WfonRY]WoXZKI00GoXZKI1onSY]P6ojBVe`03ojJdhonY]N;oZKGR00KoZKGR
1on[]=l2ojbag0;oZ<gc0ol000000onXcO?o[/O]ojk7k@04ojk7k@;oSmon1onOf?/6ojg=l0;oQ=cn
1onRe?T6okG9j@;oVMOm1oncbn/4okZmg0Co]L[Y1onl_=X00onjb>Co_;_Iokbkf@07okbkf@03okNi
fonk^mWo^k_I00Go^k_I1?nd_=l4okVmg@Ko[;cU00?o/KkSojNojonW_n/00onW_n/00ol0003oYko[
ojNoj`06ojO0j`;oYl3/2?nX`N/2ojS0j`GoZL3[5_ooool00ol0003oooooooooo`0Oooooo`003?oo
ool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2o`0001kooooo
00?o0000oooooonW_n/02onW_n/6ojS1j`WoZ<7/1_nW_n/9ojJnjPKoZ<3[1_nX`N/2ojRojPOoYk_X
1onV]^@00onU/^7oX:OKoj2Wf`03oj2Wf`OoXZKI1onSY]P2ojBVe`GoY[CS1onY]N86oj^dg`;oYM?h
0ol00005ojS=l`;o[/O]1_n?goh7oioHn`;o[Lg`1_n4g?h7oj;Dn@;o]LWY1_nIeod7ok?;j`03okZm
g?neb^Wo]L[Y00Go]L[Y1?nl_=X4ok[8i0Oo_;_I00?o_/?Nok^kfOnk^mT01onk^mT00ond_=oo^KgM
okVmg@04okVmg@Co[;cU1?na_^<5ojNoj`03o`000?nW_n_oYko[00;oYl3[1_nW`>`6ojS1j`03ojS0
jonY`>_oZL3[00KoZL3[5Oooool00ol0003oooooooooo`0Oooooo`002_ooool00omEEEGoIVIVo`00
0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`0Looooo`goYko[
0_nW`>/7ojS1j`GoZ<7/0_nX`N/8ojNoj`GoY[kZ0onW_n/7ojS0j`;oZ<7[1_nX_nX6ojNkj0KoY[KT
00?oX:WMoj2WfonPYm/01OnPYm/6oj:Vf@KoXjKH00?oY;7RojJdhonV]><01_nV]><7ojVehP;oZkCO
0_nUdoP3o`000003ojGCn?nXcO?oZ<gc00CoZ<gc0on0h?T7ohoOoP?oWmSk1_mQdO<6ohCLoP?oX]Ci
1OmYdOX7oiWGo@?o/l_[1?nGe?d8okG:j@03okblf_njb>Co^/ST00Go^/ST1Onl^mT3okk3gPOo^k_I
00?o_koJokVmgOni_Md01_ni_Md00on/_>Go/KkSok6nh`05ok6nh`GoYko[00?o0000ojRoj_nX_nX0
2?nW`>`2ojS1j`GoZ<3[2?nY`>/Eooooo`03o`000?oooooooooo01kooooo000Kooooo`03o`000?oo
oooooooo01[ooooo0onX`>/9ojNoj`KoYl3[1onX`N/00onX`NcoZ<7[ojS1j`04ojS1j`SoYko[00?o
Y[kZojNojonW_n/01OnW_n/5ojS0j`;oZ<7[2?nX_nX6ojNkj0;oY[KT1OnPZMd6oj2Wf`OoXZKI0_nS
Y]P5ojBahPOoY[CS1_nY]N82oj?FnP?o00001OnUdoP2ojS=l`OoP>3i0on?goh4oeg?l`CoOLko1omP
ao/6odg2l`KoJM7j0onIeod5oeg8nPKoUmCm1_neb^T00onNd?Wo^/STok[8i006ok[8i0?o_;_I1_nn
`mh5ok^kf@?o_koJ1_ni_Md00onl_mco/KkSok6nh`07ok6nh`;oYko[0_nX_nX01?l0003oZ;oZojRo
j_nX_nX6ojO0k003ojO0jonX`>_oZ<3[00KoZ<3[1_nY`>/00onY`N_oooooooooo`0Dooooo`03o`00
0?oooooooooo01gooooo000Kooooo`03o`000?oooooooooo01Oooooo1onX`>/5ojNoj`;oY[o[2?nW
`>/5ojS1j`?oZ<7/1_nX`N/6ojNoj`;oY[k[2?nW_n/00onX`>_oZ<7[ojS1j`04ojS1j`SoZ;oZ0onW
^nP2oj2/g`SoX:WM1_nPYm/5oj:Vf@03oj6]gonT/N;oY;7R00KoY;7R1onV]><2ojVehP;oXmKj0ol0
0002oj?FnP?oYM?h1_migoD4oh3Pn@GoKMGi0onBcO`6ogg>o`?oH<Ok1On;`_X7ofS2oPKoB;Wf1_mM
b?X6oiODo@;o]L[Y1OnNd?T8ok[8i003okbkfOnn`mko_/?N00Go_/?N0onk^mT5oknofPCo^KgM1?nl
_m`7ok6nh`;o]/7R1?nX_nX01?l0003oZ;oZojRoj_nX_nX2ojO0k0GoYl3[2?nX`>/2ojW0j`GoZL7[
5?ooool2o`0001oooooo000Kooooo`;o00005_ooool3ojS1j`OoZ<3[00?oYko[ojJojonV_n/01?nV
_n/8ojO0j`03ojS1jonX`NcoZ<7/00GoZ<7/1_nX`N/2ojNoj`KoY[k[1_nW_n/2ojS0j`OoZ<7[1_nX
_nX00onS/^?oX:cOoj2/g`04oj2/g`OoX:WM1onPYm/00onRY]WoXJgOoj6]g`03oj6]g`SoY;7R1OnV
]><3ojCFn@;o00001?nSe_X4oggRm0CoNMoe1_mofod2ofgEn@OoT/gl0ommc_l4oi^ik@OoRl;j0omX
`_h4ohnil`OoJKcm1_m5/_L5of;5o@OoW]3i1_njb>@00on[bo3o_/?Nokk3gP07okk3gP03ok^kfOno
_m[o_koJ00Go_koJ00?o^KgMokbog?nl_m`01Onl_m`4ok6nh`Go]/7R1?nX_nX00ol0003oZ;oZoj[0
j@08ojO0j`OoZ<3[1onY`N/Fooooo`03o`000?oooooooooo01cooooo000Jooooo`03o`000?oooooo
oooo01?ooooo1onX`N/5ojS0j`;oYko[1onV_n/6ojO0j`;oZ<7[2?nX`N`3ojS1j`_oY[k[0_nW_n/6
ojS0j`OoZ<7[0_nX_nX5oj>bh`KoX:cO1onPZMd3oj2Wf`?oWZOL1onQ[Ml8ojBahP04ojJdhonTe_Wo
Y=KiojCFn@?o00000_nTe_T00onSe_[oON;doggRm005oggRm0CoS^3n0omofod5oig9mPKoT/gl00?o
YKKUoi^ikOnK^Nd01_nK^Nd5oh_2nP03oj>fi_n?^O?oSkWc00KoSkWc1omY_?d6odFbm`GoH/Gm1onN
d?T2ok[8i0GoZl_`1onn`mh00onib>Ko_koJoknofP05oknofP03ol33g?nl_mco_;oL00Oo_;oL00?o
/KkSokK1h_nf`N801_nf`N82ojRojP;oZ/3Y00?o0000oj[0jOnZ`>T02?nW`>/7ojS0j`OoZL7[5Ooo
ool00ol0003oooooooooo`0Looooo`006_ooool00ol0003oooooooooo`0?ooooo`coZ<7[00?oZ<3[
ojNojonW_n/01?nW_n/7ojJoj`;oYl3[1_nX`N/6ojS1k0;oZ<3[3?nV_^/:ojS0j`GoZ<7[00?oY[[X
oj>bhonS/^<01_nS/^<6oj2/g`GoX:WM00?oW:CKoijWg?nNYm`01OnNYm`7oj6]g`KoY;7R0_nUdoP3
o`0000CoY=Ki1?n7i_D2oggRm0KoS^3n0_nSa_88oig9mP;oT/gl1OnU]^D8oi^ik@03oh_2n_nS]^Ko
XkKV00?oXkKV2?n?^O<3ofVlo@GoS;Gb1_mQ]?`2od:]m`;oH/Gm0onNd?T4ogS9o`OoZl_`1?nn`mh4
okW8iPGo_koJ0oo0`m`7okbog003oko2g?nf`N;o]/7R00Ko]/7R00?o^L?Roj[0jOnZ`>T00_nZ`>T0
0ol0003oZ/3Yoj[0j@06ojO0j`;oYko[1onX`>/8ojW1jaGooooo00?o0000ooooooooool06oooool0
01[ooooo00?o0000ooooooooool02oooool2ojO0j`goZ<7[00?oYl3[ojNojonW_n/01_nW_n/5ojJo
j`?oZ<3[1onX`N/2ojS1k0KoZ<3[2?nV_^/>ojS0j`03ojS1jonV^^SoY[[X00?oY[[X1onS/^<7oj2/
g`03oj2YgOnLY=_oW:CK00?oW:CK1onNYm`7oj6]g`;oY;7R0_nUdoP3o`0000;oYM?h0_nTe_T6ohOV
m@CoV>Cm0_n>h?h6oj?6lPKoWLWf00?oZ;GRojFfiOnU]^D01_nU]^D6oi^ik@03oj^ehOnS]^KoXkKV
00GoXkKV1_n?^O<2ojJfi0SoS;Gb1_mQ]?`5od:]m`KoN<Wo1on[bo000onn`mko^LSVokW8iP05okW8
iP?o_koJ1Oo0`m`4okbog0Co_l;L1_nf`N83okW3hPCoZ/3Y00?o0000oj[0jOnZ`>T00_nW`>/6ojNo
j`OoZ<3[2?nY`N/Eooooo`03o`000?oooooooooo00Kooooo1Ol0000?ooooo`006_ooool2o`0000Wo
oooo1_nW`>/9ojS1j`GoYl3[2?nW_n/00onV_n_oZ<3[ojS0j`05ojS0j`OoZ<7[2?nX`>/5ojJnj`;o
Y[o[3OnX`>/00onX_n_oY[[XojJjj005ojJjj0OoXk;S0onP[=l3oi^Tf`OoW:CK1_nNYm`6oj6]g`;o
Y/gd0ol00004ojGCn0CoT^[g0_n7i_D6oiSTo@?oYlSa1onSa_82oig9mPGoZ;GR2?nU]^D2oi^ik@Go
ZkGQ1onS]^H2ohnil`KoY[KT1_n<]O800onT]nKoP[Ceoh:dm@05oh:dm@?oDJ_i0_m2[OL6ogS9o`?o
Zl_`1?nEboX8okW8iP03oknof_o0`mco`<?L00Go`<?L00?o_;oLoko2g?no`]`01Ono`]`3okK1hPGo
^L?R1OnZ`>T00ol0003o[<7YojNoj`07ojNoj`SoZ<3[2?nY`N/Dooooo`03o`000?oooooooooo00Ko
oooo00GoV9RHob4Q8Oo^k^koooooodA4A00?ooooo`006_ooool00ol0003oooooooooo`06ooooo`;o
Yko[1onW`>/5ojS1j`;oZ<3[1onW`>/9ojNoj`OoZ<3[1onX`N/8ojS0j`03ojJnjonV_n_oY[o[00Co
Y[o[2OnX`>/5ojRoj`OoY[[X1OnS/^<00onKYmkoVjCKoi^Tf`05oi^Tf`KoW:CK1onNYm`2oj6]g`;o
Y/gd0ol00002ojK=m0;oYM?h1_nBj_L4oj3Xn`;oV>Cm1onWb?45oj?6lP03ojRdhOnX]N;oZ;GR00Ko
Z;GR1_nU]^D00on/]MooZkGQoj^eh@06oj^eh@GoXkKV00?o[[SPojJfi?nV]^@01onV]^@2ohbelPGo
Y;OV1on2]?D6oe6[n@GoCk7j1onEboX6okW8iP03ojg7kOo0`mco`<?L00Go`<?L00?o_lOQoko2g?no
`]`01ono`]`00onf`N;o^L?RokW3hP05okW3hP;oZ/3Y0_n/`NT00ol0003o[<7Yojc1j@08ojNoj`So
Z<3[1onY`N/Eooooo`03o`000?oooooooooo00Kooooo00?oV9RHob4Q8Oo^k^h04?ooool001[ooooo
00?o0000ooooooooool00oooool6ojNoj`OoYl3[00?oZ<7[ojS0jonX`>/01?nX`>/7ojO0j`WoYko[
1OnX`>/9ojS1j`KoZ<3[00?oY[k[ojJojonV_n/01_nV_n/5ojS0j`;oZ<7[1onX_n/7ojJjj003oj>b
honKYmkoVjON00?oVjON1onKY=/6oibTf`GoWZOL0_nUaO03o`0000CoY/gd1?nMjoT2oi;Zm`OoX>Sk
0_n[cO88ojO8l@03oj?6l_nX]>7oZ;CQ00?oZ;CQ2?nX]N82ojFfi@Go[;GO2?n[]N400onS]^Ko[[SP
ojjhh003ojjhh0OoY[KT00?o/;[QojBgi_nT]nH01_nT]nH7oh:dm@KoDJ_i1Om?/OX7oiG;nP;o^LSV
1On]and5ol33g0?o_lOQ1ono`]`2ol75g@Ko^L?R00?o^lGRojc1jOn/`NT00on/`NT00ol0003o[<7Y
ojc1j@08ojNoj`SoZ<3[1onY`N/Eooooo`03o`000?oooooooooo00Kooooo00?oV9RHob4Q8Oo^k^h0
3oooool001[ooooo00?o0000ooooooooool02_nW_n/5ojO0j`;oZ<7[1onX`>/5ojO0j`?oY[o[2?nW
_n/00onX`>_oZ<7[ojS1j`0;ojS1j`;oZ<3[1OnV_^/8ojJoj`03ojS0jonX`N_oZ<7[00CoZ<7[1onX
_n/3ojJjj0?oW:_Q1_nKYmh7oi^Tf`OoW:CK00?oWZOLojG5l?nUaO000ol00002ojG5l0?oY/gd1_nM
joT4ojO/n@;oX>Sk1_n[cO86ojO8l@03ojNch_nX]>7oZ;CQ00GoZ;CQ1_nX]N800on[]N3o[;GOojbe
g`06ojbeg`KoZkGQ2?n^^>04ojJfi0Co/;[Q2?nT]nH3oh:dm@CoVKK/1_m[/?T3odJSm`;oCk7j0onE
boX3ogW0o@Oo[LO]0oo0`m`6oko7h@Co_l;L1Oo1aMd3okW3hPCo^lGR1On/`NT00ol0003o[<7Yojc1
j@08ojNoj`OoZ<3[1onY`N/Eooooo`03o`000?oooooooooo00Oooooo00?oMgMgofIVI_ooool03_oo
ool001Wooooo00?o0000ojNojonW_n/03?nW_n/00onW`>_oZ<7[ojS1j`04ojS1j`OoZ<3[00?oYl3[
ojJojonV_n/01OnV_n/6ojNoj`03ojS0jonX`N_oZ<7[00_oZ<7[0_nW_n/7ojJnj`KoY[o[0_nX`>/7
ojS1j`GoZ;o[00?oXKCUoib[hOnLZn401OnLZn46oi^WgPOoVjCK0onLY=/3oj2hjP?o00001_nUaO00
0onVcOCoWN_ioig[n@02oig[n@KoYnci0on^e_@7oj_=lP;oYlSa1OnW/n87ojRdh@;oZ;GR1On[]N08
ojbeg`;oZkGQ3?n^^>000onV]^Co/;[Qok2jh@05ok2jh@KoY;OV00?o/;_RoiVfk?nI]^`01_nI]^`6
of^`n@GoAZ?g1_mi`?d7ojg7k@03ol33g?noan7o_lOQ00Ko_lOQ00?o_l;Lol75gOo1aMd01_o1aMd0
0oni`n;o^lGRok_5hP04ok_5hPGo[<7Y00?o0000ojg2jOn]`^T02?nW_n/7ojS0j`OoZL7[5Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00gooooo000Iooooo`03o`000?nW_n_oYko[
00_oYko[0_nW`>/7ojS1j`GoZ<3[0onW`>/7ojJoj`;oYko[1OnX`>/9ojS1j`KoYko[1onV_^/2ojJo
j`KoZ<3[1onX`N/00onX_n_oXKCUoj6di@03oj6di@OoW:_Q1OnKYmh6oi^Tf`03oi^/honP^>[oX;SZ
00;oX;SZ0_l00002oj2hjPKoYLG`0onUi_/4ojc`m`;oYnci1on^e_@5oj_=lP03ojJdhonW/n;oYk?R
00KoYk?R1OnX]>400onY]>7oZkGPoj^eh006oj^eh0Ko[;GO00?o[K_Tojjhh?n^^>002on^^>000ona
^n;o/;[Qok2jh@07ok2jh@;oY;OV1On`^n88oiVfk0?oJk3i0omo/O@3oe6RmP;oAZ?g1_mi`?d3ojg7
k@CoX<Cb1onoan400onkanCo`LGMol75g@06ol75g@03ol?7g_nkaN;o^lGR00Ko^lGR0_n/`NT2ojg2
j@04o`000?n]`^Wo[L;Yojg2j@OoYko[1onX`>/8ojW1ja?ooooo0ol00004ooooo`05o`000?nj^[[o
oooooiRHV?l@41003oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oo
ooooYko[00SoYko[1_nW`>/7ojS1j`03ojS0jonW`>_oYl3[00GoYl3[1OnV_n/2ojNoj`OoZ<3[2?nX
`N/7ojNoj`GoY[k[0onW_n/7ojS0j`?oZ<7[0onV_NX7oj6di@KoW:_Q1_nKYmh2oi^Tf`GoVjcS0ol0
0005oj2hjP;oYLG`1?nUi_/6ojc`m`;o/^3g2?n^e_@00on[cO;oY[CSojJdh`03ojJdh`SoYk?R00?o
Z;CQojVdhOnY]>400onY]>47oj^eh0Co[;GO1?n]^n@9ojjhh0Go/K_R1on`^^400onb_N7o/;_Rok2k
hP06ok2khPKoVKK/00?oZK_Vognam?mo/O@01Omo/O@5oe6RmPGoH[3j2?nPa?84oko7h@Co^lOT1_o1
aMd3ol?7gPKo^lGR0_nlb><4ojg2j@04o`000?n]`^Wo[L;Yojg2j@OoYko[1onX`>/8ojW1jaCooooo
00?o0000ooooooooool00_ooool01OnHV9So410@o`000?lQ8B7oc<c<00oooooo000>ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`08ojNoj`OoYl3[1OnX`N/3ojS0j`Oo
Yl3[00?oY[o[ojNojonW_n/01?nW_n/7ojS0j`SoZ<7[1onW_n/00onV_^_oYko[ojNoj`05ojNoj`Go
Z<3[0_nX`N/6ojJmjPOoXKCU1_nLZn43oi^WgP?oUjCN0onK[><3o`000003oi^/honP^>[oX;SZ00Co
X;SZ1?nZfoP2ojGVn`Go[?3g1Onbh?L6ojkFm003ojJgiOnV]>?oY[CS00GoY[CS1onW/n87ojVdh@Oo
ZkGP00?o[;GOojfki?n]^n@01On]^n@6ojjhh003ojo1iona^n;o/K_R00Go/K_R1?n`^^44ok:mh@So
/;_R0_nI]^`5ojVkiPOoOk7d1OmAX_H5of:`nPSoX<Cb00?o_lOQok_7i?nkan@01Onkan@3ol75g@Go
`lON1?nkaN85okc8h`Co[L;Y00?o0000ojg2jOn]`nX01onW_n/8ojS0j`SoZL7[5?ooool00ol0003o
ooooooooo`0Eooooo`003_ooool01Ol@413ooooooooooooooooo410@00Kooooo0_l00002ooooo`So
Yko[1onW`>/00onX`N_oZ<3[ojS0j`05ojS0j`GoYl3[0_nV_n/7ojNoj`GoZ<3[2_nX`N/5ojNoj`?o
Y[k[1onW_n/00onX`>_oZ<7[ojS1j`04ojS1j`KoY[gZ1onQ]>D3oib[h@;oUZ?N1_nGY=h3o`0000Go
VjcS0_nP^>X7oj[Kn0Co/O7e00?o[?3gok;Pmonbh?L01_nbh?L2ojkFm0GoY[OU1onV]><7ojNchPOo
ZKCQ1On[]N000on/_^Oo[K_Tojfki006ojfki0Co[[SP1?n_`NL7ok6khP03ok2jhOnb_N7o/[gQ00Go
/[gQ1_n`^n82okBnhPOoZK_V0omo/O@4ohnel0?oGZCf0_mAX_H5of:`nPKoX<Cb00?oU/3dok_7i?nk
an@01onkan@00oo1aMgo`lONol?7gP05ol?7gP03ok_5h_nlb>?o_<SS00Ko_<SS0_n]`^T2ojg3jP03
o`000?n]`n[o[L?Z00OoYko[2?nX`>/7ojW1jaGooooo00?o0000ooooooooool05?ooool000kooooo
00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00?ooooo1onW_n/3ojO0j`Go
Z<7[1onX`>/00onW`>_oY[o[ojJoj`04ojJoj`OoYko[00?oZ<3[ojS1jonX`N/03?nX`N/00onW_n_o
Y[k[ojJnj`05ojJnj`GoYko[0_nX`>/7ojS1j`KoY[gZ0onQ]>D3oiRYhPKoUZ?N0_nGY=h3o`0000;o
UjCN1OnK[><3ojW;lPGoZ]_h1OnalOD3okSXm@Ko/^3g00?oZ[oYojJgiOnV]nD01_nV]nD5ojJdh`03
ojFbh_nW/n;oYk?R00KoYk?R1onY]>400on[]N3o[;kWojbni`03ojbni`So[K_T00?o[[SPojo1ion_
`NL01On_`NL5ok6khP03ok32ionb_N7o/[gQ00Oo/[gQ0_n`^n86okBnhPGoZK_V0_na_nD7ohnel0Go
GZCf0omEXoH2of:`nP;oX<Cb1OnF`?@7ok_7i003okO6i_o3amko`lON00Go`lON00?o`lWOokc8honl
b><01_nlb><00onmbNCo[L?Zojg3jP02ojg3jP03o`000?n]`n[o[L?Z00SoYko[2?nX`>/7ojW1jaCo
oooo00?o0000ooooooooool05?ooool000kooooo00Go0000ooooooooooooooooo`000005ooooo`03
o`000?oooooooooo00Gooooo1OnW_n/2ojO0j`SoZ<7[1OnX`>/2ojO0j`OoY[o[1OnW_n/3ojS0j`[o
Z<7[1?nW_n/8ojJnj`03ojNojonX`>_oZ<3[00CoZ<3[1onX`N/3ojJmjP?oW:oU1_nHZN84oiJSgP?o
00001_nGY=h00onK[>?oZL_bojW;lP06ojW;lP03oj[Kn?nalOGo/O7e00?o/O7e1_nhj?D2ok;Pm`Go
Z[oY2?nV]nD00onV]>?oYK;RojFbhP03ojFbhPOoYk?R1_nY]>42ojVoj@Ko[;kW1_n]^n@2ojW1j`So
[l7W00?o/K_Rok32ion``^L00on``^L7ok:mh@03ok?2iOnd_^;o];kR00Oo];kR00?oZK_Vok6oiOna
_nD01?na_nD7ohnel0GoGZCf1OmEXoH7oiK0m0Co^lOT1?nga^H5ol?7gP?o`lWO1_nlb><3okg9i0Co
[L?Z00?o0000ojg3j_n]`nX02?nW_n/7ojS0j`OoZL7[5Oooool00ol0003oooooooooo`0Cooooo`00
3_ooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool01_ooool00onW_n_o
Yl3[ojO0j`04ojO0j`SoZ<7[00?oZ<3[ojO0jonW`>/01?nW`>/7ojJoj`03ojNojonX`>_oZ<3[00Go
Z<3[1onX`N/7ojNoj`KoY[k[00?oYl3[ojS0jonX`>/01_nX`>/5ojS1j`03ojBkjOnL[nGoW:oU00Go
W:oU1_nHZN83o`0000;oUZ?N1_nGY=h2oj2jj`OoZL_b1?nejoL2ok7am@Ko^>Se0onccnh6ojZoj@Ko
Y[OU00?oXk;SojFbh_nU/^801OnU/^87ojNchP;oZKCQ1_nY_nT6ojbni`;o[K_T1_nY`N/6ojo1i`03
ojS0jon``^Oo/<;W00Go/<;W1?nb_N44ok?2i@Oo];kR00?o]L7Sok6oiOna_nD01_na_nD3ohnel0Co
VKW^0omYY_@2oejTmPGoEJ?f1onF`?@00onkanCo]lKVokO6iP04okO6iP?o`lON1_o3bMl3okc8h`Go
_LWT1On]`nX00ol0003o[<?[ojc3j`08ojNoj`OoZ<3[1onY`N/Eooooo`03o`000?oooooooooo01;o
oooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2o`0000Sooooo1onW`>/6ojS1j`;o
Z<3[1onW`>/5ojJoj`?oYko[1onX`>/7ojS1j`OoYko[0_nV_^/5ojO0j`SoZ<3[00?oZ<7[ojBkjOnT
^nT00onT^nT7oib_i@;oV:WR0ol00006oiJSgP;oUjCN1_nP^^/4ojW;lPKo]N_g1?nnko800onhj?Go
/lo^ok??kP05ok??kPKoZ[oY0_nV]nD5oj>bh`KoYK;R1_nW/n82ojNojPSoZKoY0on/_^L3ojNoj`So
ZL7[0_n_`NL5ojS0j`Oo/<;W00?o/[gQok?2iOnc`^D01Onc`^D4okBnhPCo]L7S1_na_nD00ond`^Go
VKW^oiVikP06oiVikPGoJJKd0omDW?<2oeFSmP?oU/3d1?n>^O<7okO6iP03ol?7g_o3bMoo`lWO00Ko
`lWO00?o_<SSokg9i?nmbN@01OnmbN@2ojg3jP;o[<?[00Co0000ojc3jon/`n_o[<?[1onW_n/7ojS0
j`KoZL7[00?oZ<7[ooooooooool04oooool00ol0003oooooooooo`0Booooo`003_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool02?ooool7ojO0j`;oZ<7[1_nX`>/7ojO0
j`03ojJojonW_n_oYko[00GoYko[1OnX`>/9ojS1j`GoYko[0_nV_^/7ojO0j`SoZ<3[1_nT^nT6oib_
i@;o00001?nHZN83oiJSgPCoUZWS1onP^^/00onYbo;o]N_gokG[m`04okG[m`Go_^ob0_nkgo88ok??
kP?oZ[oY0_nR/^@8oj>bh`KoYK;R0_nW/n86ojNojPKoZKoY00?oYkoZojNojonW_n/01OnW_n/6ojW1
j`03ojNnj_nX`>_oZ<3[00KoZ<3[1On``^L2ojW1j`So/l;U00?o];kRokG1hone`N<01?ne`N<4ok6o
i@Co]<;U2?nI^Nh5ofVVm0GoE9cc1on>^O<5okO6iP;o]<GW1oo3bMl00oo4c>3o_LWTokg9i005okg9
i0;o_<_U1?n/`n/01?l0003o[<?[ojc3jon/`n/7ojNoj`OoZ<3[0_nY`N/5ojS1jaGooooo00?o0000
ooooooooool04Oooool001Sooooo00?o0000ooooooooool02Oooool5ojO0j`?oZ<7[1onX`>/3ojO0
j`CoY[o[2?nW_n/00onX`>_oZ<7[ojS1j`0;ojS1j`03ojNojonV_^_oY[k[00CoY[k[1onW`>/8ojS0
j`KoY;_Y0_nL[nD3o`000003oiBWh_nAX^3oTJ;P00?oTJ;P2?nFZN<5oj2jj`Co/=Sd0_nejoL5okk_
lPGo^mob1_nccnh00onS]^KoX[;Toj:bi004oj:bi0SoXk;S0onU/^84ojJlj@OoYkoZ0_nY_nT5ojNo
jPOoYko[0_nY`N/5ojNnjPSoZ<3[00?o/<;WojW1jonY`N/01?nY`N/6ok?2i@03ojo2j?ne`N?o]L7S
00Ko]L7S00?o/KoUokC2iOnd`^D01Ond`^D6oiVikP03oijlk_m`Y_;oL:Kb00;oL:Kb0_mYY_@5oeBL
l`OoS[Wc00?o]lKVokC5iondaNL01?ndaNL4ol?9g`Coa<cP1?nmbN@5okc;i@Co[<?[00?o0000ojc3
jonZ`^/01onW_n/7ojS0j`SoZ<7[5Oooool00ol0003oooooooooo`0@ooooo`006?ooool00ol0003o
ooooooooo`0:ooooo`03ojO0jonX`N_oZ<7[00GoZ<7[1OnX`>/2ojO0j`OoY[o[1_nW_n/00onX`>_o
Z<7[ojS1j`0;ojS1j`?oYko[1_nV_^/5ojO0j`[oZ<3[0onT^nT01?nH[NKo0000o`000?l00005oiBW
hPGoTJ;P2?nFZN<00onP^^_o/=Sdok3Hm005ok3Hm0Co`Nka00?o_^obok_Ol_nkgo801_nkgo82ok??
kPGoXkKV1_nR/^@6oj>bh`03oj>hionV_>WoY[cY00KoY[cY3_nW_nX5ojNoj`;oZ;gX1onW_^X6ojS0
j`;oYkkZ1onY`N/2ok?2i@Go[l;X1_ne`N<00one`nCo]<;UokC2i@07okC2i@;oVKW^1OnN_>h5og2V
lPCoFIWa0_mDW?<3ohjil`?oRkCa2?ndaNL00oo3bMooa<cPolC<h005olC<h003okg9i?nlbnGo_<_U
00Ko_<_U0_n/`n/2oj[2j`03o`000?nZ`^_oZ/;[00OoYko[1onX`>/7ojS1jaGooooo0_l0000Aoooo
o`005oooool3o`0000gooooo1onX`N/00onX`>_oYl3[ojO0j`04ojO0j`OoY[o[0_nW_n/5ojS0j`Wo
Z<7[1onW_n/6ojJnj`03ojO0jonX`>_oZ<3[00[oZ<3[00?oXk_ZoiR]i_l000000_l00002oiR]iPOo
U:OR1OnAX^06oiJYh`;oZ<G^1_n`f?@4ol7^l@?oa>W_1_nkgo82ojc4j`OoXkKV1_nR/^@2oj>bh`Go
XkSW2?nV_>T>ojNojP03ojNojonX_NSoZ;gX00CoZ;gX1onW_^X2ojS0j`KoYkkZ1OnY`N/00onW_n_o
[l;Xojo2j006ojo2j0?o]L7S1?ne`n@7okC2i@;o]LCV1_nN_>h6og2VlPGoFIWa1on;]?46okC5i`03
okC5i_o4c>3oa<cP00Goa<cP0_o4c^87okc;i@03ok_<ionZ`^_oZ/;[00;oZ/;[00?o0000oj[2jonZ
`^/02?nW_n/7ojS0j`OoZ<7[4oooool00ol0003oooooo`00000Aooooo`005oooool00ol0003ooooo
ooooo`0>ooooo`GoZ<7[0_nX`>/7ojO0j`GoY[o[0onW_n/6ojS0j`SoZ<7[2?nW_n/3ojJnj`CoYl3[
2?nX`>/2oj>kjP?o00001_nH[NH6oiBWhPKoTJ;P0_nFZN<6ojS5kP?o/=Sd1Oo1k_46olCYk`03ok_O
l_n/a>_o[<C[00Co[<C[1onS]^H3oj:bi0?oXK?U1onS^>L6ojJlj@03ojRojonW_n[oYkoZ00_oYkoZ
0_nX_>L7ojRmj0?oYkkZ1?nY_NP8ojNnjP03ojW1jonW_n_oYko[00?oYko[2?n_`^P00one`N?o]L?T
okG3i004okG3i0Co]<;U1Onea>H6oijlkPKoL:Kb1OmIVO46oh^dl@Co]<GW1?ndaNH5olC<h0Coa<kR
1?nlbnD4ok_<i`CoZ/;[00?o0000oj[2jonZ`^/02?nW_n/5ojS0j`03ojW1jonX`N_oZ<7[00KoZ<7[
5?ooool00ol0003oooooooooo`0?ooooo`005oooool00ol0003oooooooooo`0?ooooo`03ojS1jonX
`>_oZ<3[00CoZ<3[1onW`>/00onV_n_oYko[ojNoj`05ojNoj`KoZ<3[2?nX`N/6ojNoj`03ojJnjonW
`>_oYl3[00KoYl3[1OnX`>/01?nX`N_o0000o`000?l00004oj>kjPKoV:gV1_nDYn83oi6Rh0?oV:oW
2?nXaNh00on`f?Co`Nkaol7^l@03ol7^l@Koa>W_0_nlfNl7ojc4j`GoXkKV00?oWk;Uoj6ciOnQ/nD0
1OnQ/nD7oj>hi`;oY[cY1OnX_n/9ojNojPKoZ;cW1OnX_NP00onY^nKoZKgXojVmj006ojVmj0KoYkkZ
00?oZKkYojNojonW_n/01OnW_n/6ojo2j0;oZl7Z1one`n@00ond`^Go]LCVokG4iP06okG4iP?oW[c^
0onN_Nh5og:Tl0CoGYO^0_mIVO46oh^dl@03okC5iondaNKo]<GV00Go]<GV0oo4c>06olC>hP03okc;
iOnkc>Oo^lcW00Go^lcW0onZ`^/01?nX`Nco0000ojS1k?nX`N`8ojNoj`03ojS0jonY`N_oZL7[00?o
ZL7[2?nX`N/Dooooo`03o`000?oooooooooo00kooooo000Gooooo`03o`000?oooooooooo013ooooo
1onX`>/5ojO0j`?oY[o[1onW_n/3ojS0j`_oZ<7[0_nW_n/5ojJnj`SoYl3[00?oZ<3[ojS1jol00000
0_l000000onX`N_oXk_Zoj>kjP05oj>kjPKoV:gV0onDYn82ohjShPOoV:oW1_nXaNh4ok[NlP;o`Nka
1Oo4jNl5okcIk`Oo[<C[00?oXkKVoinbiOnO/^D00onO/^D7oj6ci@GoXkSW0_nW`>/7ojRoj`GoYkoZ
0_nW^nP8ojRli`03ojRmj?nY^nKoZK_V00?oZK_V2?nY_NP2ojNnjPGoZKkY1onW_n/2ojo2j0KoZl7Z
1One`n@9okG4iP03okG6ionN_NkoW[g^00GoW[g^1OmbY?05oejGkPOoS;7^2?ndaNH00oo4c>3oa<kR
olC>hP04olC>hP03olCAi?nkc>Oo^lcW00Go^lcW00?o^<cYojS1k?nX`N`00onX`N`00ol0003oZ<7/
ojS1k007ojNoj`OoZL7[1_nX`N/00onW`>_oooooooooo`0Cooooo`03o`000?oooooooooo00gooooo
000Gooooo`;o00004_ooool7ojS0j`03ojO0jonV_n_oY[o[00GoY[o[1OnW_n/2ojS0j`coZ<7[0_nW
_n/7ojJnj`KoYl3[0ol00005ojS1j`OoXk_Z0onH[NH2oi2Vi0KoSZ?R1onH[nL3ojS5kPKo^]kb1?o9
jnd00oo4jNoo_=W_okcIk`06okcIk`?o[<C[0onO]>L7oinbi@OoXK?U00?oXkSWojO0jonW`>/01?nW
`>/7ojRoj`03ojNoj_nW^nSoYk_X00CoYk_X1_nX_>L00onY_>OoZK_VojVkiP05ojVkiPKoZKgX00?o
[;gWojVnjOnY_^T01_nY_^T5ojNoj`;oZ;o[2?n[`NX00one`nCo]LCVokG4iP08okG4iPCo]LKW1onN
_Nh5og:Tl0GoGYO^1on</Nh6okC5iP03okO6i_o4c^;oa<kR00Coa<kR0oo4dN@4ok_<i`Co^<cY1?nX
`N`01?l0003oZ<7/ojS1k?nX`N`7ojNoj`OoZL7[0_nX`N/5ojO0jaCooooo00?o0000ooooooooool0
3Oooool001Oooooo00?o0000ooooooooool04_ooool8ojS0j`OoY[o[00?oYko[ojS0jonX`>/01?nX
`>/8ojS1j`KoYko[1onV_^/2ojO0j`03ojS0jol0003o000000?oZ<3[1_nX`N/3oj>kjP?oUZkX1_n@
Y^@6ohjShPOoV:oW00?oZ<G^ok[Nl_njg_800onjg_85olW[k@?oanC/1_nlfNl00onX`N_oWkCWoind
i`05oindi`KoWk;U1_nQ/nD2ojJnj`OoYl3[0onX_n/4ojNlj@OoYk_X0_nX_>L5ojVli`OoZK_V0_nY
_NP5ojbmi`SoZKkY00?oYko[ojRojonX_n/01?nX_n/6oj_1jP03ojW0jonea>Ko]LCV00Oo]LCV1_ne
a^L6oijmkP03oiVkkombX>koLZ3^00;oLZ3^0_mbY?05oejGkPOoS;7^0_ndaNH5okO6iP?oa<kR1_o4
dN@00onkc>Oo^<cYokS<j@05okS<j@CoZ<7/00?o0000ojS1k?nW`>`02?nW_n/6ojW1j`SoYl3[5?oo
ool00ol0003oooooooooo`0<ooooo`005oooool00ol0003oooooooooo`0Cooooo`SoZ<3[1onV_n/7
ojS0j`SoZ<7[1_nW_n/5ojJnj`04ojNojol0003o0000o`0000KoZ<3[0onX`N/3oj>lj`KoUZkX1_n@
Y^@6ohjShPGoV:oW1?n]b>h00onjg_;obN_]olW[k@04olW[k@KoanC/00?o_=W_ojS1jonX`N/00onX
`N/7oindi`KoWk;U0_nQ/nD6ojJnj`GoYl3[00?oYkkZojNljOnW_>T01_nW_>T5ojNkj003ojNkionY
_>OoZKcW00KoZKcW1OnY^nH00on/`NWo[;gWojbmi`06ojbmi`KoZKkY00?oZkoXojRojonX_n/01_nX
_n/2oj_1jPGoZL3[1_nea>H9okG6i`;oW[g^1OnI^nl5og:PkPCoIIK[0_mNUnh3ohbakP?oT[7/2?ng
a^H00oo4c^;oa=7TolCAi004olCAi0;o`m?V2?nhc>T2ojS1k0;oYl3/00?o0000ojO0k?nW`>`01onW
_n/7ojW1j`KoYl3[00?oY[o[ooooooooool04oooool00ol0003oooooooooo`0;ooooo`005oooool0
0ol0003oooooooooo`0Eooooo`OoZ<3[1onV_n/7ojS0j`SoZ<7[1_nW_n/00onV_^_oYko[o`000002
o`0000?oYko[1OnX`>/2ojS1j`KoXkc[1_nF[^P5oi2Vi0OoSZ?R00?oV:oWojg8k_n]b>h01?n]b>h3
ol7Mk@CobN_]1_o7i>`2okkGk0KoZ<7[1onO]>L3oinbi@?oWkGX2?nV_^/00onW`>_oYkkZojNnjP03
ojNnjPSoYkcY00?oYk_XojNkionW^nL00onW^nL8ojVli`03ojVki_n/`NWo[<7Y00?o[<7Y2?n/_NL2
ojVnj@GoZkoX1_nX_n/2ojS0j`OoZL3[0_nea>H;okG6i`;o]<SY1onI^nl5og:PkPGoIIK[1onB/N`6
okO6iP;o^lSU1Oo4dN@4ol?CiPKo^<cY00?o/l_/ojO0k?nW`>`00onW`>`00ol0003oYl3/ojO0k007
ojNoj`OoZL7[0_nW`>/5ojJojaCooooo00?o0000ooooooooool02oooool001Kooooo0ol0000Goooo
o`GoZ<3[0onW_n/6ojJoj`GoZ<3[2_nX`N/3ojNoj`04ojFnjol0003o0000o`0000OoYko[00?oZ<3[
ojS1jonX`N/01?nX`N/6oj>lj`KoUZkX1On@Y^@3ohjShPCoV[7X1On]b>h6ol7Mk@03olW[kOo7i>co
anC/00?oanC/1Onnen`6ojS1j`?oWkCW0onL/nL7oinej0KoY[k[00?oZ<3[ojNnj_nW_^X01OnW_^X6
ojNlj@03ojFjj?nW^nOoYk_W00GoYk_W1_nY_>L2ojW4kPKo[<7Y1_n/_NL2ojg1j0OoZkoX0_nX_n/6
ojS0j`KoZL3[2_nea^L6okC8j@OoVK__1OmbX>h5ofFFj`OoT[7/0onga^H5ok_8i@?oa=7T1_o3dnH2
okS<j@Go/l_/1?nW`>`00ol0003oYl3/ojNoj`07ojNoj`OoZL7[2?nV_n/Dooooo`03o`000?oooooo
oooo00[ooooo000Fooooo`03o`000?oooooooooo01Sooooo00?oZ<3[ojNojonW_n/01OnW_n/6ojJo
j`03ojS0jonX`N_oZ<7[00[oZ<7[00?oYl3[ojFnjol000000_l00004ojFnj`GoYko[0_nX`>/7ojS1
j`KoXkc[0onF[^P2ohfXi`KoRj?T1onJ/NP3ojg8kPKo`Mg]1?o=i^P00oo7i>co_]O/okkGk006okkG
k0?oZ<7[0onL]>T6oibci`OoWkGX0_nV_^/5ojS0j`OoYkkZ0_nW_>T5ojFjj0OoYk_W0_nY_>L6ojW4
kPKo[<7Y0_n/_NL6ojg1j0GoZkoX0_n/`^T8ojS0j`KoZL3[1onea^L2okK8j0Oo]<SY0onI^nl3oi2c
k`CoL9_Z0_mbX>h5ofFFj`OoT[7/00?o]lKVok_8iOnkb>D01Onkb>D00oo4dNCo`m?Vol?CiP04ol?C
iP03ol3Cj?ncbnco/l_/00Ko/l_/0_nW`>`2ojNoj`03o`000?nW_n_oYko[00OoYko[1onY`N/7ojJo
ja?ooooo0ol0000;ooooo`001?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^
k^h6ooooo`03o`000?oooooooooo01[ooooo1onW_n/3ojJoj`CoYl3[2?nX`N/2ojO0j`?o00002?nU
_^/00onW_n_oZ<3[ojS0j`04ojS0j`OoZ<7[0onS_>/2oiJajPKoSJSW1_n;Xn@7oiZaj003ojg8k_o1
gNgo`Mg]00Co`Mg]1?o=i^P3ol_Qj0Ko_]O/00?oZlG]oibdjOnL]>T01OnL]>T6oibci`GoWkGX0_nW
_n/7ojS0j`GoYkkZ0_nU^nT7ojFjj0GoYk_W0_nWa>h8ojW4kP?o[<7Y0onW`nd8ojg1j003oj^oj?n/
`^Wo[<;Y00Co[<;Y1_nX`>/00onX`N_oZL3[ojW0j`05ojW0j`Co]LKW1Onfb>P5okC8j@;o/LS[1_n@
/nl5og2KjPCoKiOX0_mUU^/3oi:ak0?oVKC[1onkb>D2ol7?i@Co`m?V1?o0dnP6ok?;k0;o[LK/1?nW
_n/00ol0003oYko[ojNoj`05ojNoj`;oZ<3[1onY`N/7ojJoj`oooooo0ol00002ooooo`03o`000?oo
oooooooo00Wooooo0006ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`06ooooo`03o`000?oooooooooo01_ooooo1OnW_n/00onV_n_oYl3[ojO0j`06ojO0j`KoZ<7[0ol0
0004ojO0j`KoYKk[0_nV_n/7ojS0j`?oZ<7[0onT_^`6oiJajPKoSJSW1_n;Xn@5oiZaj0?o[lO/0oo1
gNd5olgVj0Kobn7X00?o_]O/oj_5kOn[aNd00on[aNd7oibdj@KoW;?W00?oWkGXojNojonW_n/01?nW
_n/7ojS0j`03ojNnj_nU^nWoYK_Y00CoYK_Y1onU^^P00onW^nOoYlC^ojO4kP04ojO4kPKoZLC^00?o
XlC`ojO3kOnW`nd01OnW`nd6ojg1j0;o[L;Y1on/`^T2ojS0j`GoZ<7[1onY`>/00onea^Oo]/SXokK8
j006okK8j003okC8jOnab>_o/LS[00Co/LS[1_n@/nl5og2KjPGoKiOX1onI]>/4ok_8i@Go`LoU00?o
`m?Vol3Cj?o0dnP01Oo0dnP2ok?;k0Ko[LK/0onW_n/00ol0003oYko[ojNoj`02ojNoj`KoZ<3[1OnY
`N/00onX`NcoY[o[ojJoj`06ojJoj`_ooooo0ol00005ooooo`03o`000?oooooooooo00Wooooo0006
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`;o00007Ooo
ool00onW_n_oY[o[ojJoj`03ojJoj`SoYl3[0_nX`N/3o`0000;oZ<7[1_nW`>/2ojFnj`KoY[o[1onX
`>/6ojBnk0KoU[7Z1On=Z>L7oh^Si003oiZaj?n_anco[lO/00Go[lO/00?o`Mg]olgVj?o=i^P00oo=
i^P6ol_Qj0;o`mOY1_n[aNd7oibdj@?oW;?W0onN]^T7ojNoj`?oZ<3[1?nV_^/7ojFkj@?oYK[X1?nV
_n`7ojO4kP;oZLC^1OnSa?07ojO3k@;o[L7X1_n]`^T5ojc2j@;o[<?[1onX`N/5ojW0j`;oZl7Z1onf
b>P00onfbn[o/LS[ok78j`06ok78j`KoT;?_1?m`VnX6ofnGj0OoVKC[00?o^lSUol7?iOo1cnD01?o1
cnD2olCDiPKo`=?X0_nld^X8ojg6k0?oYko[00?o0000ojNojonW_n/02?nX`>/00onY`N_oZ<7/ojS1
k003ojS1k0SoY[o[1_ooool4o`0000Sooooo00?o0000ooooooooool02Oooool000Kooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Gooooo0_l0000Oooooo`KoY[o[1_nW
`>/00onX`>_o0000o`000006ojS1j`?oYl3[2onV_n/7ojS0j`KoY;k/1_nF/NX5ohfXi`?oRj?T1?nG
[nL6ojo7k0Co`]OY0_o=i^P6ol_Qj0Co`mOY1_n[aNd3oibdj@?oVK?Z1onN]^T5ojNoj`;oZ<3[1onV
_^/5ojFkj@03oj>kj_nV_ncoY[o/00KoY[o/1OnWa>h2ojO6k`OoXlC`1OnW`nd2oj>nk@So[L;Y00?o
[<;Yojc3jon/`n/01?n/`n/7ojS1j`03ojW0jon[`N[oZl7Z00CoZl7Z1?nfb>P4okK;jPKo/LS[00?o
ZLC]ohJWj_n6YnX01?n6YnX4og2EiP03og2Kj_m_UnSoKiOX00CoKiOX0onI]>/4oj:ij@Go`LoU1?o4
e>H3ol3Cj0Go_=;Z1_n]a^`00onX`^coYko[ojNoj`02ojNoj`03o`000?nW_n_oYko[00KoZ<3[00?o
ZL7[ojS1k?nX`N`01OnX`N`7ojJoj`?ooooo0ol0000=ooooo`03o`000?oooooooooo00Sooooo0006
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oo
oooooooo01oooooo1_nV_n/2ojO0j`04ojS0jol0003o0000o`0000;oZ<3[1onX`N/<ojJoj`WoZ<3[
1_nT_^`3oiJajP?oSJ_Y1On7XnH7oiN_i`?o[lO/1_o2enT3oloOi0?obn7X1oo3enT3oj_5k@;oWKS/
1onI/nX7oijfj@03ojNojonX`>_oZ<3[00CoZ<3[1onV_^/00onU^nWoXk_Zoj>kjP03oj>kjPSoY[o/
00?oYlC^ojO6konWa^l01?nWa^l7oj?4l003ojO3kOnS_^goXkk]00CoXkk]1_n]`^T2ojg3jPOo[<?[
0onX`N/3ojS1k0SoZl7Z00?o]/SXokK;j_nfbnX01OnfbnX2ok78j`GoZLC]1_n6YnX4og2EiPKoOIcV
2?nR^NT3ol7?i@Koa=CV00?o`=?XokcBj_nld^X01Onld^X2ojg6k0GoZ<;/1?nW_n/00ol0003oYko[
ojNoj`02ojS0j`GoZL7[1onX`N`7ojJoj`;o00004?ooool00ol0003oooooooooo`08ooooo`001_oo
ool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003ooooo
ooooo`0Pooooo`?oY[o[0_nW_n/3o`0000KoZ<3[1onX`N/8ojJoj`goZ<3[0onT_^`2oiVgk@OoSJ_Y
1On7XnH7oiN_i`03ojo7k?o2enWo`]OY00Co`]OY1Oo?gn@00oo;hNSo`mOYol?Gj@05ol?Gj@03okK>
k?nM^>coWKS/00CoWKS/1onI/nX5oijfj@;oY[k[1onX`>/5ojJnj`;oXkc[1_nS^nX6ojJok0;oZlC/
1onWa^l3oj?4l0CoXKg]1onS_^d2ojg2j@Ko[L?Z1On/`n/00on[`n_oZ<7/ojS1k005ojS1k0KoZl7Z
0_n_a>T6okK;jP;o]Lg[1_nYa>d6ohJWjPGoL9GV1_mmW>H8oj:ij@03ol7?iOo4e>Koa=CV00Coa=CV
00?oa=WYokcBj_nld^X01Onld^X00onfcngoZ<;/ojS2k005ojS2k0CoYko[00?o0000ojNojonW_n/0
2?nY`N/3ojS1k0?oYko[2?nV_n/Aooooo`03o`000?oooooooooo00Sooooo0006ooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o00008_ooool01?nW_n_o0000
o`000?l00003ojNoj`GoZ<3[2OnX`N/5ojJoj`?oYKk[2_nX`>/3ojK0k0GoVKO]1on=ZnT5ohNSiPGo
UjoW0on/`nX4ol;Gj@GocmoT0oo?gN<4ol?Gj@Co]/k/1_nM^>`7oiVcjP03oijfjOnV_^_oY[k[00Co
Y[k[1onX`>/00onV_^_oXkc[oj>lj`04oj>lj`KoXk_Z0_nV_n`6oj_4k0GoYlK_0_nW`>/7oj6mk@Go
Xkk]0_nS^n/8ojg3jP03ojc3jon[`n_oZl?[00?oZl?[1onX`N`2oj_1jPKo[lCY0onfbnX5okG=j`Ko
ZLC]1_n6YnX5og2EiPKoOIcV1_nR^NT00on]`NSoa=CVolCDiP04olCDiP?oa=WY1?nld^X4okK?k@Oo
Z<;/1?nW_n/00ol0003oYko[ojNoj`06ojW1j`03ojW2jonW_n_oYko[00GoYko[1_nV_n/00onW_n_o
ooooooooo`0?ooooo`03o`000?oooooooooo00Sooooo0004ooooo`03oeEEEOmVIVKo000000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo01oooooo0ol00007ojNoj`03
ojS0jonX`N_oZ<7[00_oZ<7[00?oY[o[ojFnjonU_^/01OnU_^/6ojS0j`OoY/3/1OnI]nd7ohf[j@Go
Qj?V00?oUjoWojc3j_n/`nX01_n/`nX00oo2enWocmoToloOi003oloOi0KocmgS00?o`mOYokK>k?nf
c^`01?nfc^`6oifhk0?oVK?Z1?nJ]N/7ojJnj`?oZ<3[1?nU_^/7oj>lj`?oXk_Z0onW_nX8oj_4k003
ojO6konW`>_oYl3[00CoYl3[1onQ_Nd00onS_^goXk_[oj>kj`04oj>kj`Ko[L?Z00?o[/K/oj_3jon[
`n/01On[`n/5ojS1k0;oYko[2?n_a>T00onfbn[o]Lg[okG=j`05okG=j`?oZLC]0_nI]^`6oh2Mi@Co
M97Q0_m`UNH6ogfLiP;oX[WY1On]`NP3olCDiPKoa=WY00?o_=;ZokK?kOnfcnd01Onfcnd3ojS2k0So
Yko[00?o0000ojNojonW_n/00_nY`N/5ojW2j`OoYko[0_nV_n/5ojNoja3ooooo00?o0000oooooooo
ool02?ooool001Gooooo00?o0000ooooooooool07?ooool3o`0000Cooooo1OnW_n/3ojS0j`[oZ<7[
1?nW`>`7ojFnj`KoZ<3[1onV`>`5oiVgk@?oSJ_Y0on4YNX6ohnZj0Oo[<?Z0onmcNL3oloOi0KocmgS
0oo:e^<6okK>k0?oWKS/1?nG]N`6oiZej`GoY[k[0_nX`>/7ojFnj`GoXkc[00?oXKc/ojNoj_nW_nX0
1OnW_nX6oj_4k0;o[/;X1onW`>/3oj6mk@CoXKSY1onS^n/2ojg3jPGo[/K/1on[`n/00onX`NcoYko[
ojNoj`04ojNoj`Ko[lCY0_ndc>`6okG=j`03ok7;kOnI]^coVKK/00CoVKK/1_n0WND5ogBAh@KoSJGU
2?n]`NP00oo4e>Koa=WYolCIj@04olCIj@?o`MW[1Onfcnd00on^b>goYko[ojNoj`0:ojNoj`03o`00
0?nX`>_oZL;[00OoZL;[0onW_n/3ojJoj`SoYko[3oooool00ol0003oooooooooo`08ooooo`005Ooo
ool00ol0003oooooooooo`0Iooooo`?o00002?ooool00onW_n_oZ<3[ojS0j`05ojS0j`KoZ<7[2?nW
`>`5ojFnj`;oYko[1_nX`>/5ojK0k0;oX;c]1On>[^`6ohBUjPKoSj[X1?n/`nX6okg=i`03oloOi?o?
gN?ocmgS00CocmgS1Oo:e^<3okK>k0?oYL7]1onG]N`6oiZej`03ojJnjonX`>_oZ<3[00CoZ<3[1onU
_^/00onS_>_oXKc/oj6lk003oj6lk0OoYkoZ0_n[a>`6ojk2j0GoYl3[00?oYk[Woj6hjOnQ^>T01_nQ
^>T5oj>kj`;oYl3[1on^a^`3oj_3j`CoZL;/1onW_n/2ojo4j@Ko]<c/0_necN/5ok7;k@KoVKK/1_n0
WND5ogBAh@KoSJGU1_n]`NP3okW<j0?oa=WY1_o1fN/00onfcngo[/S]ojk8k@03ojk8k@WoYko[0_nX
`>/00ol0003oZ<3[ojS0j`06ojW2j`03ojS1k?nV_n_oY[o[00GoY[o[1onW_n/?ooooo`03o`000?oo
oooooooo00Sooooo000Eooooo`03o`000?oooooooooo01Kooooo0ol0000=ooooo`OoZ<3[1_nX`N/8
ojO0k003ojFnjonW_n_oYko[00CoYko[1_nX`>/00onV`>coX;c]oj2lk@04oj2lk@GoSZk/1_n4YNX6
ohnZj003ojc3j_nmcNOo_LgW00Go_LgW0oo;eN43oloMh`Kob]KS0_o3d>@6ojG1k@OoUkG/0onJ]N/3
oinij`OoZ<3[0onU_^/4ojBnk0KoXKc/1OnW_nX2ojc1j@So[/;X00?oYl3[ojNjionW^^L00onW^^L8
oj6hj@03oj>kjonW`>_oYl3[00CoYl3[1On^a^`00on/aNcoZL;/ojW2k006ojW2k0GoYko[0_nY`N/6
okC<k0;o]<k]1onabnd6oiVfk0GoP9gU1_mdTN46ohfUi@;o[L7X1onic>P00oo4fNWo`MW[ol7Ij`04
ol7Ij`03okcFkOn^b>go[/S]00Go[/S]1onW_n/4ojS0j`03o`000?nX`>_oZ<3[00;oZL;[1OnX`N`7
ojJoj`OoYko[3oooool00ol0003oooooooooo`07ooooo`005?ooool2o`0001Gooooo0ol0000Aoooo
o`OoZ<3[1_nX`N/6ojO0k0;oYKo/1onW_n/7ojS0j`KoX;c]1On>[^`5ohBUjPGoSj[X0onS^NT5okg=
i`GobmGQ00?ocmgSol[Fhoo:e^<01?o:e^<4ol?@i0KoYL7]0onG]N`3oiJfkPOoWkW[1OnX`>/00onW
`>_oY;k/ojBnk006ojBnk0KoXKc/00?oYkoZojc1jOn/`NT01?n/`NT6ojk2j0;o[[oV1_nW^^L6oj6h
j@03ojBkjOnW`>_oYl3[00KoYl3[00?o[/K/ojc5k?n/aN`00on/aN`8ojW2k003ojNojonY`N_oZL7[
00CoZL7[0ondc>`5okC>k@Oo/L_]0onI]^`2ohbRh`CoO9?O0_n0WND5ogBAh@GoSJGU0_nL/nP7okW<
j0;o`]WZ1?o1fN/4okcFk@Oo[/S]1onW_n/4ojS0j`03o`000?nY`^_oZL;[00OoZ<7/1onV_n/7ojNo
j`kooooo00?o0000ooooooooool01oooool001Cooooo00?o0000ooooooooool04_ooool2o`0001Go
oooo1onX`>/6ojS1j`;oYl3/1_nU_n`5ojNoj`WoZ<3[1_nP_>d5ohj^k0GoQ:GZ00?oSj[Xoj>ijOnS
^NT01OnS^NT3okg=i`GobmGQ0oo@e]d4ol[Fh`Ko`m3T0onU`Nd3oibkkPKoU[K^1onO^N/00onX`>_o
Yl3[ojO0j`03ojO0j`SoY;k/0onQ_>`3oj:nk@Oo[<7Y0_n^`^P6ojjoiPKoYk[W0_nQ^>T5ojBkj@Ko
Yl3[0_n/anh6ojc5k0KoZL;/00?oYko[ojW1jonY`N/01_nY`N/00ondc>co]<k]okC>k@05okC>k@?o
/L_]0onT_^/6ohbRh`GoO9?O1?n0U]l2ogBAh@03ohfUiOnL/nSoW;?X00CoW;?X1?nic>P5ol;IjP03
ol7Ijonle^go_=K]00Go_=K]0on^b>d3ojS1k0SoYko[00GoZ<3[ojW2jonY`^_oZL;[o`000002ojW2
j`OoZ<7/1onV_n/5ojNoj`03ojS0jooooooooooo00cooooo00?o0000ooooooooool01oooool001Co
oooo00?o0000ooooooooool03oooool3o`0001Sooooo1onX`>/7ojS1j`OoYKo/00?oYko[ojS0jonX
`>/02onX`>/3oj2lk@;oU;O_1On5Z^d6ohBVjPSoXkWY00?o_LgWol_EhOo;eN400oo;eN46om3Fg@03
ol[Fhoo3d>Co`m3T00Co`m3T00?o^l_Voibkk_nL^nh01OnL^nh6oiJfkPGoWkW[0_nT_N/6ojO0j`Ko
Y;k/2?nR_^d5ojc1j@;o[<;Z2?n^_nH3ojNji`?oYkcX1onT^nT2ojO0j`Ko[<O^1_n/aN`2ojW2k0Go
Yko[1_nY`N/2ok3<kPKo]<k]0_nbc^h6ojBnj`KoS:;S1OmlTml5oh2Fg`SoW;?X00?o^LcXol;Ij_o2
fNX01?o2fNX00oo3g^go_=K]okcFk@05okcFk@03ok??k_nX`NcoZ<7/00GoZ<7/1onW_n/4ojW2j`04
o`000?nY`^_oZL;[ojW2j`?oZ<7/0onW_n/8ojJoj`03ojNojonX`>_oZ<3[00?oZ<3[3Oooool00ol0
003oooooooooo`07ooooo`005?ooool00ol0003oooooooooo`0<ooooo`?o00007?ooool5ojS0j`Wo
Z<7[1OnU_n`3ojFoj`_oZ<3[0_nV`>`5oiBgk`GoQJ[]1_n4Y^X6oj>ij@?o//GW0oo;eN46om3Fg@?o
cm?L0oo3d>@4ok_;iPOoW;_^1_nF]^h00onO^N_oY;g[ojBmj`04ojBmj`KoYl3[0_nT_^`<oj:nk@03
ojc1jOn/`^[o[<;Z00Co[<;Z1_n^_nH00on[`N[oYkcXojNlj005ojNlj0GoY;_Y0_nXaNh8ojc7kP?o
[<G/0onY`^`7ojNoj`;oZL7[1_n`c>h2okC>k@Ko//k^1OnT_^/6ohbRh`KoO9?O1On0U]l6oibcj003
ojc1jOo2fN[o`]WZ00Co`]WZ0oo3g^d4okcFk@Co/lo^1onX`N`7ojNoj`CoZL;[00?o0000ojW2jonY
`^`01onW_n/6ojJoj`03ojNojonX`>_oZ<3[00GoZ<3[3?ooool00ol0003oooooooooo`07ooooo`00
4oooool3o`0000[ooooo0ol0000Pooooo`03ojS0jonX`N_oZ<7[00_oZ<7[00?oYKo/ojFojonU_n/0
1OnU_n/7ojS0j`KoY/3/1OnD]nl5ohFZk@KoQ:KZ0_nS^NT7ok;5i`03ol_EhOo@e]god=KM00Cod=KM
1Oo?dm`00oo3d>Co^l_Vok_;iP04ok_;iPOoW;_^0onF]^h3oiJhk`OoY;g[0onW`>/3ojJok0_oX[k]
0onQ`>l7ojc2jP;o[[oV1On[`NX7ojNlj003ojBkjOnXaNkoZ<G^00CoZ<G^1_n/anh00onYa>goZL;/
ojW2k005ojW2k0GoYko[0_nX`N`6ok3<kP;o/]3`2?nbc^h5ojBnj`KoS:;S1OmlTml6oh2Fg`;oW;?X
1On/`NT3ol;IjPKo`mk]00?o_=K]ok??k_nccnh01Onccnh3ojS1k0_oYko[0_nY`^/2ojW2k003o`00
0?nY`^coZL;/00OoYko[0_nV_n/5ojNoj`OoZ<3[2oooool00ol0003oooooooooo`07ooooo`005?oo
ool00ol0003oooooooooo`06ooooo`?o00009Oooool:ojS1j`CoYl3/1onU_n/6ojS0j`OoY/3/1OnD
]nl5ohFZk@?oQ:KZ1?n@[^/6ok;5i`?o_l[R0oo@e]d6oloCg0;oc<oK1onkbnH3oibkkPCoUk[_1_nF
^>l5ojBmj`SoY[o/2?nR_^d6oj70k`Go[<;Z0_nWa>h7oj_1jPGoYkcX0_nWaNl7ojS5kP;o[<O^1OnY
a>d7ojW2k003ojNojonX`NcoZ<7/00CoZ<7/0on`c>h5ok;@l0Ko//k^00?oYkcYoi>ThOnCY>400onC
Y>46ohFFg0CoOi7K0_mlTml3oh2Fg`?oTZKS1on/`NT00oo2fN[o`mk]ol?Nk@04ol?Nk@?o_M[^1Onc
cnh00onZa>coYko[ojNoj`0;ojNoj`03ojS1jonY`^coZL;/00;oZL;/00?o0000ojW2k?nY`^`01_nW
_n/00onV_n_oYko[ojNoj`06ojNoj`?oZ<3[0onX`N/;ooooo`03o`000?oooooooooo00Oooooo000D
ooooo`03o`000?oooooooooo00?ooooo0ol0000Yooooo`GoZ<7[00?oZL7[ojO0k?nW`>`01_nW`>`5
ojFoj`;oYko[1_nX`>/5ojK0k003oj6nkOn;/>ooRk3_00CoRk3_1OmmYnh7oi2^j`?o//GW1_nob^80
0oo@e]gocm?LoloCg004oloCg0Coc<oK1OnkbnH2okC6i`OoUk[_1_nF^>l00onT_N_oY[o/ojJok00:
ojJok0SoX[k]1_nQ`>l00on/`^[oYlC^ojO4kP04ojO4kPOoZl7Z00?oYkcXojO5konWaNl01?nWaNl5
ojS5kP;oZLG^1onYa>d3ojW2k0CoYko[1onX`N`00on`c>ko/]3`ok;@l005ok;@l0;o//k^1OnW_>T5
oi>Th@KoQIKL1OmoTM/7oi:Vh`Go[<7Y0onleNd3ol?Nk@Ko_M[^00?o/lo^oj[4k?nZa>`00onZa>`9
ojNoj`GoZ<7[1?nY`^`00ol0003oZL;/ojW2k002ojNoj`GoY[o[1_nW_n/00onW`>_oZ<7[ojS1j`05
ojS1j`_ooooo00?o0000ooooooooool01_ooool001?ooooo00Co0000oooooooooooooooo0ol0000]
ooooo`03ojS1jonY`N_oZL7[00?oZL7[2?nW`>`00onU_n_oYko[ojNoj`04ojNoj`KoZ<3[00?oY/3/
oj6nkOnQ_^d00onQ_^d6oh^`k`GoOJO^1on@[^/00onbaNOo_l[Roko:hP04oko:hP?ob<_M1?o?dm`6
olc?f`03ok_;i_nda^Oo]<KW00Co]<KW1onG^^l3oiJhk`?oUK[`2_nV_n`3ojJoj`SoX[k]0onQ`>l3
oj2ok`OoYlC^0on[`NX4ojG5l0OoYlG_00?oZ<G^ojW5k_nYaNh01?nYaNh5ojW4k@;oZ<3[1onW_n/5
ojS1k0?o[loa1Onbd?02ok3<k`KoYkcY1_nCY>46ohFFg0GoOi7K1onBY^<00on/`NWo_=G]okcEk@05
okcEk@03ol?NkOnmf^ko_M[^00Co_M[^00?o]]C_oj[4k?nZa>`01OnZa>`7ojNoj`OoZ<7[0onY`^`0
0onW`>_o0000ojO0j`08ojJoj`;oYko[1OnW`>/7ojS1j`[ooooo00?o0000ooooooooool01_ooool0
01?ooooo1?l0000booooo`GoZL7[1_nW`>`2ojFok0OoYko[1_nX`>/6oj6nk@KoRk3_1OmmYnh5oi2^
j`;oX;SY1Onob^86olS;g@03oloCg?o<cm_oc<oK00Coc<oK0_o9b]/7okC6i`?oUk[_1?nF^_06oiFj
l0GoY[o/00?oY/7]ojJojonV_n/01OnV_n/6oj:nk@;oY;o]1_nP_nl5ojO4kP;oX/;`1onUaO05ojO5
k`;oYlC_1onYaNh00onYa>goZ<3[ojS0j`04ojS0j`OoYko[00?oZ<7/ojo?lOn_co401On_co400onb
d?3o/<c_ok3<k`04ok3<k`GoYkcY1_nCY>46ohFFg0GoOi7K1_nBY^<00onS^NWo_=G]okcEk@05okcE
k@;o`^7^1?nmf^h4okKDk`OoZ/C/1onW_n/5ojS1j`;oZL;/1?nW`>/00ol0003oYl3[ojJoj`05ojJo
j`03ojNojonW`>_oYl3[00KoYl3[1_nX`N/:ooooo`03o`000?oooooooooo00Kooooo000Cooooo`;o
0000=Oooool5ojW1j`;oYl3/1_nU_n`5ojNoj`;oYl3[1_nX`>/6oj6nk@?oRk3_0on4[_03ogbWkP;o
OJO^00?oT:k[oj2hjOnP^>T01?nP^>T3oko:hPKob<_M0_o<bmT5olc?f`CobL[K1Onda^L3ok32i`Ko
U[[`1_nE^_000onV_ncoY/7]ojK1k@03ojK1k@OoY[o[0_nR_^d6ojBok@KoX;o_00?oYlC^oj;2l?nR
`_001?nR`_07ojG5l003ojO5konWa>ooYlC_00CoYlC_1OnYaNh2ojS1k0OoZ<3[0onW_n/4ojS7l0Ko
[loa00?o[m7aok3<kon`c>l01_n`c>l5ojNlj@KoTjCQ1_n5U]`5ognAf`;oTZKS1OnS^NT4okcEk@Go
`^7^00?o_M[^okKDkonfe>l01Onfe>l3oj[4k0_oYko[00?oZ<7[ojW2k?nY`^`01?nY`^`3ojO0j`03
o`000?nW`>_oYl3[00;oY[o[1OnW_n/6ojO0j`SoZ<7[2Oooool00ol0003oooooooooo`06ooooo`00
1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003oooooooooo`0cooooo`;o
ZL7[1?nX`N/7ojFok003ojNojonW`>_oYl3[00CoYl3[1_nX`>/3oj6nk@CoVK__1On4[_05ogbWkPOo
X;SY00?o_l[RolS;gOo8bmd01?o8bmd4olc;f@?oc<oK1_o9b]/00onda^Oo/<;Wok32i`05ok32i`Ko
U[[`0onE^_03oiFllPKoY/7]1OnV_n/2ojO0j`SoY;o]0onP_nl3oj?0kPOoX/;`0onUaO04ojG2kPOo
YlC_00?oZLG^ojS1k?nX`N`01?nX`N`5ojS0j`;oYl?]1onXao02ojo?l@Go[m7a1_n`c>l00onS/^?o
UZ7LoiJQg003oiJQg0KoRiKI1_n4TMP6ohjOg`OoXkWY00?o_=G]ol;Qk_o2hNh01?o2hNh2okgMl0Ko
]]C_00?o[<K]ojNojonW_n/02onW_n/00onX`>_oZL;/ojW2k006ojW2k0?oYl3[00?o0000ojJojonV
_n/01onW_n/2ojO0j`coZ<7[2?ooool00ol0003oooooooooo`06ooooo`0000GoV9RHob4Q8Oo^k^ko
ooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02Oooool00ol0003oooooooooo`0coooo
o`KoZ<7[1onU_n`7ojO0j`?oZ<3[1?nW`>/6oiVkk`GoQ:k`1OmlYnh5oj2hj@;o[L7X1Oo8bmd6olc;
f@03olc?foo9b]_obL[K00CobL[K0_o7a]T8ok32i`?oU[[`0onE^o46oiFllPKoY/7]00?oY[o[ojO0
jonW`>/01?nW`>/6ojBok@;oYKk/1_nS`>h5oj;2l0;oYL7]1onU`^h3ojO4k`?oYl7/2?nX`N`00onX
`>_oYl?]ojO3k@04ojO3k@GoZ<O`0on]dO<6ojoAl@;o/<c_1OnS/^<5oiJQg0KoRiKI1_n4TMP6ohjO
g`GoXkWY0oned^l3ol;QkPGo_Mg`0_nfe>l5ojc6k@WoYko[1OnX`>/6ojW2k003ojS1jonV_n_oY[o[
00;oY[o[00?o0000ojJojonV_n/01_nW_n/=ojS1j`03ojNojooooooooooo00Kooooo00?o0000oooo
ooooool01_ooool00004oooooonHV9So8B4Qonk^kPCooooo00Go410@oooooooooooooooooa0@400:
ooooo`03o`000?oooooooooo03?ooooo1_nX`N/7ojFok0GoYl3[0_nX`>/7ojO0j`KoVK__1On4[_05
ogbWkP03oj2hjOn]`NSo[L7X00Co[L7X0oo8bmd6olc;f@;ocLWF1Oo9b]/4olO6f@Ko/<;W0_n`_nD6
oiFkl@KoUKcb0onV`Nd3oj?3k`OoYl3[0_nT_nd6ojFnk0KoXl3^00?oX/;`ojG1kOnU`Nd01?nU`Nd5
ojG2kP;oYl3/1_nW`N`6ojS1k0;oYl7/1onW`nd00onXao3o[M7cojgAl`05ojgAl`?o[m7a0on/`n/6
oj>bh`KoUZ7L1_n;U]T5ohBAf0OoSYoO00?oXkWYokGBkoned^l01Oned^l00oo2hNko_Mg`okgMl003
okgMl0;o]mK`1on/a^d6ojNoj`SoZ<3[0_nY`^`5ojS1j`CoY[o[00?o0000ojJojonV_n/01_nW_n/9
ojS1j`GoYko[1oooool00ol0003oooooooooo`06ooooo`000_ooool00onHV9So8B4Qonk^kP03oooo
o`05o`000?ooooooooooooooool000002oooool2o`0003Cooooo0onX`N/3ojS0j`OoYKo/00?oYl3[
ojS0jonX`>/01?nX`>/7ojO0j`?oVK__0_nA^?45ogb[lPKoPZc`1on]`NP00oo8bmgoc<_Iolc;f@04
olc;f@CocLWF0oo9b]/6olO6f@;o/<;W1_n`_nD6oiFkl@?oUKcb0onC_O@6oj?3k`GoYl3[0_nX`N`8
ojFnk0?oXl3^0onV_n`7ojG1k@03ojG2k_nW`>coYl3/00CoYl3/1_nW`N`2ojS1k0KoYl7/1OnW`nd3
oj[@m0Go[M7c0_n]c?06ojc3j`GoXk;S1_nFXM`6oh^Ff@GoQ97H1_n>Wml00onP]nSo]M;_okGBk`05
okGBk`;o_n?a0onmgO05okOFl0Go[<K]2?nW_n/6ojS0j`03ojW2k?nX`N_oZ<7[00KoZ<7[0onV_n/0
0ol0003oYko[ojNoj`07ojNoj`?oZ<7[0onX`N`8ojNoj`Oooooo00?o0000ooooooooool01Oooool0
00?ooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000gooooo00?o0000
ooooooooool0<_ooool6ojS0j`SoYKo/1_nX`>/5ojO0j`;oY/3/1OnA^?45ogb[lPKoPZc`1On]`NP3
okC3i@Coc<_I1_o=bMH00oo9b]_oalKIolO6f@04olO6f@?oaL;G1on`_nD3oiFkl@?oUk_a1_nC_O@6
oj?3k`03ojO0jonX`NcoZ<7/00CoZ<7/1_nU_^`00onX`N_oY[o/ojJok005ojJok0GoYL7]0_nW_n/7
ojO0k0koYl7/00?oYl?]oj[@m?nZd?@01OnZd?@00on]dO?o[Lc`ojg<l004ojg<l0Ko[<?[1OnS/^<6
oiJQg0KoRiKI1On4TMP2ohjOg`GoX;OX1?ned^l5okoSl@03okgMl?nge_3o]mK`00Go]mK`00?o[<K]
ojNojonW_n/02_nW_n/2ojS0j`GoZL;/1_nX`N/5ojNoj`03o`000?nW_n_oYko[00GoYko[0_nX`N/6
ojS1k0OoYko[1oooool00ol0003oooooooooo`05ooooo`001?ooool01Ol0003ooooooooooooooooo
410@00?ooooo00?o410@ooooooooool03?ooool00ol0003oooooooooo`0booooo`KoZ<3[2?nU_n`6
ojS0j`03ojO0jonV`>coY/3/00CoY/3/1OnA^?45ogb[lPKoPZc`00?o[L7XokC3iOnd`nD01_nd`nD0
0oo<bmWocLWFolg9eP04olg9eP;ocLKD1Oo7a]T5olG2e`Go/;oU0_nc_>46oiNkl@KoTkgd0onS`nl3
oik3l`OoZ<7/0_nU_^`5ojS1j`OoY[o/00?oYL7]ojNojonW_n/01?nW_n/5ojO0k0;oYl?]3?nW`N`2
ojO?m@KoZ]3d00?oZlocojg<l?n]c?001_n]c?03ojc3j`;oWJ?I1OnGW=L6ohnDe0KoRY;F1_n@Wmh7
oj2gj003okGBkonoho7o_n?a00Co_n?a0_nkgo86okOFl003oj_6kOnW_n_oYko[00WoYko[0onW`>/7
ojW2k0;oZ<7[2OnW_n/01?l0003oYko[ojNojonW_n/6ojS1j`KoZ<7/1onW_n/6ooooo`03o`000?oo
oooooooo00Gooooo00001Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0?ooooo`03o`000?oooooooooo03;ooooo0onX`>/4ojO0k0OoYKo/1_nX`>/7ojK0k0GoTKSa
1OmlZo83oh:/l0?oRk;`1ond`nD2ok[5h`GocLWF1?o=a]@3olO6f@OoaL;G00?o/;oUok>lhOnc_>40
1?nc_>46oiNkl@?oTkgd1?nC_oD5oik3l`GoZ<7/0_nUao47ojS1j`?oY[o/1?nX`N`7ojNoj`03ojO0
k?nW`ngoYl?]00CoYl?]2?nW`N`6ojO?m@;oZ]3d1On[co<6ojg<l003ojF]gOnMXmWoWJ?I00CoWJ?I
1OnGW=L6ohnDe0KoRY;F1_n@Wmh5oj2gj0Co/mCa00?o_n?aok_Ol_nkgo801?nkgo82okOFl0GoZlK]
1onW_n/7ojO0j`GoZL;/00?oZ<7[ojNojonW_n/02_nW_n/00ol0003oYko[ojS1j`07ojS1j`?oZ<7/
0_nW`>/8ojNoj`Gooooo00?o0000ooooooooool01Oooool00005oiRHV?l@413o0000ob4Q8Oo<c<`0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^013ooooo0_l0000dooooo`KoYl3/1OnU_n`2ojJoj`Ko
Z<3[1OnV`>`2ojBok0GoRkGb1OmgZo<6oh^bl0Co]<?U1OnjaN<3olg9ePKocLKD00?oalKIolG2eoo5
`]L01Oo5`]L2olFnd`Oo/kcQ0onG^o44oibjk@KoTkoe1OnN`o<00onX`NcoYLOaojG7l@04ojG7l@Go
Z<7[0_nVb?87ojS1k0GoYko[0_nWao07ojO3k@?oYl7/1?nUcoH5ojO?m@;oZ<oe1on[co<2ojg<l0Go
YJgM1_nMXmT5oiNLe`KoSiCD1On:T]H7oi2OgP03oj2gj?nce?7o/mCa00Co/mCa0_nliO<5ok_OlP;o
]MGa1on[a^d7ojNoj`OoYl3[00?oZL;/ojS1jonX`N/00onX`N/;ojNoj`03o`000?nW_n_oYko[00Ko
Z<7[00?oZ<7/ojO0jonW`>/01?nW`>/7ojNoj`Gooooo00?o0000ooooooooool01Oooool001oooooo
00?o0000ooooooooool0<_ooool6ojO0k003ojFok?nV_n_oY[o[00CoY[o[1_nX`>/00onV`>coY;o/
ojBok004ojBok0GoRkGb1OmgZo<6oh^bl003okC3iOnjaN?o^/GS00Ko^/GS00?ocLWFolg6e?o=a]@0
1?o=a]@2ol_3dPKoaL;G1?o5_]<5ok>lh@;o^;[K1onL^^d3oi>om@?oUKkc1_nF`oH6ojG7l@03ojS1
jonVb?;oY/Sb00CoY/Sb1onX`N`00onW_n_oYlO`ojO7l004ojO7l0GoYl?]0_nRc_L7ojG?mP03ojO?
mOnXcoGoZ<oe00CoZ<oe1On[co<00onX]>7oYJgMojF]g@05ojF]g@KoWJ?I1OnGW=L6ohnDe0KoRY;F
0on@Wmh4oj:jjPCo/mCa1OnliO<00onkgo;o]MGaokGEl@04okGEl@GoZlK]2OnW_n/3ojO0j`?oZL;/
1onX`N/;ojNoj`03o`000?nW_n_oYko[00;oZ<7[1OnX`N`6ojO0j`OoYko[1?ooool00ol0003ooooo
ooooo`05ooooo`008?ooool00ol0003oooooooooo`0booooo`?oYl3/0onV_n`7ojJoj`OoZ<3[1_nT
_n`5oh^elPGoMj_c0on;/_04oi:gl0Ko^/GS0_nlaN45olg6e0Cobl?B0oo5`]L7olFnd`03ok>lhOnh
^]_o^;[K00Co^;[K1OnL^^d2ojJei0KoUKkc1_nF`oH3ojG7l@CoV/Kf1_nVb?83ojS1k0CoY<cd1onW
ao000onW`ngoX/kgoj;>m`04oj;>m`SoYLof1_nXcoD00on[co?oZ;CQojRdh@03ojRdh@KoYJgM1onM
XmT5oiNLe`KoSiCD0on:T]H2oiJVh0SoX[[Z00?o/mCaokcUlonliO<01?nliO<2okONl`Oo]MGa00?o
ZlK]ojNojonW_n/02OnW_n/00onW`>_oZL;/ojW2k005ojW2k0GoZ<7[3OnW_n/00ol0003oZ<7[ojS1
k007ojS1k0?oYl3[2_nW_n/3ooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooo
oooo03;ooooo1_nV_n`5ojJoj`?oYko[1_nX`>/3ojBok0CoX[k]1On6]?<5og>[m0KoT[O`0onjaN<5
okc5h@?ocLKD1_o;`m800oo5`]OoaKkColFnd`05olFnd`03olFkd?nh^]_o^;[K00Ko^;[K00?oW;[]
ojJei?nV]N@01?nV]N@6oiFnl`?oU/?f1?nE`_H6oi[6mP?oY/Sb0onJbOP7ojC<m0?oYlO`1?nOcOL7
oj;>m`SoYLof0onXcoD3ojRhi0KoZ;CQ1_nU[Md3oifSf@?oV9K@1OnBTm46oi2GePKoUZKP1_nR^^X2
ok?Km0Co_>Gc1Ongg_<3okGEl@?oZ/C/2OnW_n/5ojO0j`OoZL;/00?oZ<7[ojNojonW_n/03?nW_n/2
ojS1j`03o`000?nX`N_oZ<7[00KoZ<7/00?oYl3[ojNojonW_n/02_nW_n/00onW`>_oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo000Rooooo`03o`000?oooooooooo03;ooooo1_nV_n`00onV
_n_oYko[ojNoj`05ojNoj`OoZ<3[1_nR_^d5ohJdl`GoLj_d1_nB]o000onjaN?o_<GQokc5h@05okc5
h@03olg6e?o;`m;obl?B00Cobl?B00?ob/7BolFndoo5_]<01Oo5_]<3olFkd0Ko^;[K0_nl]m@7ojJe
i0?oUKkc1?nM^>/6oiG2mP?oV/Kf0onGaOL6oi[9n0GoY<cd0onLboP6oio=m`?oX/kg1?nSc?H6ojG?
mP03ojRhiOnX^>CoZ;ST00GoZ;ST1_nX]>43ojF]g@;oWI[A1onHU]05oi:Cd@KoT9OF1_nFY^03oj:j
jPGo/m_d00?o_>GcokONlongg_<01?ngg_<2ok7Al0KoZ/C/1onW_n/7ojO0j`?oZL;/0onX`N/>ojNo
j`CoZ<7[00?o0000ojS1jonX`N/00_nX`N`5ojO0j`SoYko[1OnW`>/3ooooo`03o`000?oooooooooo
00Cooooo000Sooooo`;o0000<oooool3ojJok0CoYKo/1onW_n/7ojS0j`KoX[k]1On6]?<5og>[m0?o
T[O`0onE^o46okc5h@;o_<CQ1Oo;`m83ol[1dPGoaKkC1Oo5^m03okRjf`Go_;OD1OnV]N@2ok6cf@Oo
WKS[0onE`_H3oi^kkPKoUlGg1_nJbOP00onTc?CoW<_hoic;n005oic;n0?oWlgg1?nQb?@6oj?<mP;o
YLof1OnX^>D7ojRhi0?oZ;CQ0_nPWM46oifJd@KoV9K@1_nBTm45oi2GePOoUZKP00?oX[[Zok?Km?nc
fo@00oncfo@3okWVm@?o]mkc1OnadO06oj[4k0OoYko[1OnW`>/2ojW2k0KoZ<7[3_nW_n/3ojS1j`03
ojS1k?l0003oZ<7/00SoYl3[1OnW_n/8ojO0j`;ooooo00?o0000ooooooooool01?ooool002Gooooo
00?o0000ooooooooool0<_ooool6ojFok0GoYko[0_nW`>/7ojS0j`?oX[k]0onQ_^h5ohBdm0GoL:cf
1_nE^o43okc5h@Go_<CQ0oo;`m85ol[1dP?oaKkC1oo5^m000onh^]_o_;ODokbge005okbge003ojJe
i?na/mWo/K?I00Co/K?I1OnM^>/2ojZ`g0KoVk_^1_nGaOL3oi[9n0CoVlKf1OnLboP2oj6okPOoXLSd
0onSc?H3ojNdhPKoZ;SU1_nX^>@00onSX=;oX9gAoj2Md@04oj2Md@GoWI[A1_nHU]06oi:Cd@KoT9OF
0onFY^04ojG4k`?o/m_d1_nii_D00ongg_?o/M7`ok7Al005ok7Al0?oZ/C/2_nW_n/00onW`>_oZL;/
ojW2k004ojW2k0KoZ<7[3?nW_n/6ojS1k003o`000?nX`NcoYl3[00GoYl3[1onW_n/6ojO0j`04ojS1
joooooooooooo`0000Kooooo000Vooooo`03o`000?oooooooooo03;ooooo1_nU_n`00onW_n_oYl3[
ojO0j`04ojO0j`OoZ<3[1_nQ_^h5ohBdm0GoL:cf1_nE^o400onlaN7o_<CQokc4h@05okc4h@03ol_3
d_o:`M;ob/7B00Gob/7B00?oaKkColFkd?o5^m001Oo5^m000oo5^Lko_;ODokbge005okbge003okjb
cona/mWo/K?I00Ko/K?I00?oWKS[ojZ`g?nZ/=`01?nZ/=`6oi^kkP?oUlGg1?nN^^`6oi_6mP03oic;
n?nQ_nkoXKo^00CoXKo^1OnQb?@00onV[]goYkCRojNdhP05ojNdhPKoZ;SU0_nX^>@5oj>PdPKoX9gA
1OnMV]46oiRFd0KoTY?A0on@UmH3oijbiPOoYLC_00?o/m_dokWVmOnii_D01?nii_D2okCLm0Ko/M7`
00?oZ<7[ojNojonW_n/02_nW_n/00onX`NcoZL;/ojW2k006ojW2k0?oZ<7[2onW_n/9ojS1k003o`00
0?nX`NcoZ<7/00;oYl3[2onW_n/2ojO0j`GoZ<7[00?oooooo`000?ooool01Oooool002Oooooo00?o
0000ooooooooool0<_ooool6ojFok0OoYl3[1onX`>/6oj6nkPGoQ;Cd1Om`[?H3oiFkl@?oU;gc1_nl
a>400onja>;ob/7Bol[1dP05ol[1dP;ob<7C1_o5^m03olFicPGo_;OD0onn//l6ok6cf@03okR_d?nZ
/=coZ[3L00KoZ[3L0onK^nh3ojR]g0OoW[[/0onKa_H3ojBbh`OoXKo^00?oXLSdojJ^gOnV[]d00onV
[]d7ojNdhP?oZ;SU0_nUXM47oj>PdPKoX9gA1OnMV]46oiRFd0?oTY?A0onHY=d7oijbiPGoYLC_0onc
i?L2okWVm@Ko]=cd0_nadO05ojS1j`SoYko[1OnX`N`6ojW2k003ojO0jonW_n_oYko[00_oYko[2onX
`N`00ol0003oYl3[ojNoj`0:ojNoj`CoYl3[1_nX`N/00ol0003oooooooooo`04ooooo`00:?ooool2
o`0003?ooooo1_nU_n`7ojO0j`OoZ<3[1_nQ_^h5oh>em@GoKZgg1_nD_O<3okc4h@Co^/CR1Oo:`M84
olS1d`?oaK_@1_o5^Lh3okbge0Go_[;?0ona/mT4okR_d0KoZ[3L00?o]:c@ojR]g?nX[M`01OnX[M`5
oijjk003ojZZeonT/^?oY;;S00GoY;;S1OnQ_nh00onXZ=KoYZkMojJ^g@05ojJ^g@GoYkCR00?oYj7?
ojFQdOnUXM401?nUXM46oj>PdPOoX9gA1OnMV]43oiRFd0;oV9_E1onHY=d7oijbiP03ojG4konci?Oo
/nCg00?o/nCg0ondhoH5okCLm0;o[LS^1onX`N/7ojNoj`KoZ<7/0_nY`^`5ojO0j`goYko[1onX`N`4
ojO0j`03o`000?nW`>_oYko[00KoYko[2?nW`>/3ojS1j`;ooooo00?o0000ooooooooool01?ooool0
02[ooooo00?o0000ooooooooool0<Oooool6ojFok0OoYl3[1onX`>/6oj6nkPGoPkGe1Om^[OL6oiBm
l`03okc4hOnja>;o^/CR00Co^/CR0oo:`M86olS1d`03olFkd?o5^LkoaKW>00KoaKW>00?o_;ODokjb
conn//l01Onn//l00ona/mWo^:o@okR_d004okR_d0?oZ[3L1?nd[=07ojR]g003oijjk?nZZ]OoZZ[G
00?oZZ[G1onT/^<00onQ_nkoZ:SFojRXeP03ojRXePOoYZkM00?oYkCRojNQconWXLl00onWXLl6ojFQ
d@KoXj3B0onPWM43oifHcPGoVYS@1_nHVmD6oiRTg@KoW[;V0onZeoL00onci?Oo]>?fokCSmP05okCS
mP03okCLm?n]b>ko[LS^00Co[LS^1OnX`N/9ojNoj`?oZ<7/0_nX`^`8ojO0j`goYko[1onX`N`4ojO0
j`03o`000?nW`>_oYko[00KoYko[1_nW`>/7ooooo`03o`000?oooooooooo00?ooooo000[ooooo`03
o`000?oooooooooo037ooooo1_nU_n`7ojO0j`OoZ<3[1_nQ_^h5oh>em@GoKZgg0onD_O<3ohnmmPOo
^/CR00?ob/7BolS1doo8`M<01?o8`M<00oo5`]OoaKW>olFicP06olFicP03olJjconn//oo_[;?00Go
_[;?00?o`K;<okR_d?nh[m001_nh[m000onZ/=co]:c@okB/d004okB/d0GoZ:gL00?o/ZS>ojZZeonZ
Z]L01OnZZ]L5ojBbh`03ojfVd?nXZ=KoZ:SF00GoZ:SF1OnV[]d00onYX<goYj7?ojNQc`05ojNQc`Go
YJ7A1OnSX=800onQVLcoWIS>oifHcP05oifHcPGoVYS@1_nHVmD6oiRTg@;oW[;V1OnZeoL2ok7Wn0Ko
]>?f0_n`e?87ojg8kP03ojS1jonW_n_oYko[00WoYko[1onX`^`6ojO0j`03ojNnjonW_n_oYko[00[o
Yko[2OnX`N`3ojO0j`03o`000?nW_n_oYko[00OoYko[0_nW`>/:ooooo`03o`000?oooooooooo00?o
oooo000/ooooo`03o`000?oooooooooo037ooooo1_nU_n`7ojO0j`OoZ<3[0onQ_^h3oj:nk@KoQKKe
1Om][_P5ohnmmPGo^/CR0_ndaNH5olS1d`?oaL;G1_o5^Lh3olJjc`Go_[;?0oo1//`6okR_d003ok^]
bond[=3o]:c@00Go]:c@0onX[M`4ok:XcPOoZZ[G00?oY;;SojfVd?n]Y]000on]Y]07ojRXeP03ojJ^
gOnYX<goZJ3=00?oZJ3=1_nWXLl6ojFQd@03oj>Pd_nQVLcoXIW<00?oXIW<1_nMV<h6oiZHd0KoV9_E
0onHY=d4ojC6l@?oZ]Og1OnaioP2okCSmPKo/=Cb0on]b>h<ojNoj`_oZ<;/0_nW`>/5ojNnj`SoYko[
2onX`N`5ojNoj`03o`000?nW_n_oYko[00GoYko[3Oooool00ol0003oooooooooo`03ooooo`00;Ooo
ool2o`0003;ooooo1_nU_n`7ojO0j`OoZ<3[1_nR_^d6ohFfm@GoKJkh1On?_OH00onja>;o]<GVokC5
iP04okC5iP?ob<7C1Oo5`]L3olFicPGoa[[?0onn//l5ol6bc0Go^:o@0onk[L/7okB/d003ojR]g?nb
Z<ko/ZS>00?o/ZS>1_nZZ]L00on`Y<co[JK@ojfVd004ojfVd0KoZ:SF00?o[:3;ojVPcOnYX<d01OnY
X<d6ojNQc`?oYJ7A0_nTV//6oj6Ic0KoWIS>1_nJV=05oiRKe@03oj:ijOnTa_7oY<Ka00KoY<Ka00?o
Z]Ogok7Wn?naioP00onaioP3ok3Lm`Go/=Cb0_nY`^`;ojNoj`;oYl3/2_nX`^`3ojNoj`OoYkk[0onW
_n/4ojO0j`SoZ<7/2OnW_n/01?l0003oYko[ojNojonW_n/@ooooo`03o`000?oooooooooo00?ooooo
000_ooooo`03o`000?oooooooooo033ooooo1onU_n`6ojO0j`OoZ<3[1_nR_^d3ohFfm@?oRKSd1Om^
/OT5ohBln@Oo]<GV00?ob<7ColG2eoo5`]L01Oo5`]L00oo5^Lkoa[[?olJjc`05olJjc`03okjbcoo1
//co`K;<00Co`K;<0onh[m05ok^]b`Ko]:c@00?o^:W;ok:Xc_nbZ<h01OnbZ<h2ojZZe`Go/:C<1_n]
Y]02ojRXePGo[:3;1_nYX<d5ojNQc`03ojNLbonTV/_oY9[;00CoY9[;1_nQVL`6oifHcPKoVYS@00?o
V9_Eoj:ijOnR^NT00onR^NT6ojC6l@?oZ^Kj00?o/NOhok3Lmon`g?L01On`g?L00on`e?;oZL;/ojW2
k004ojW2k0OoYko[1_nW`>`5ojS2k003ojS1jonW_n_oYko[00GoYko[1OnW_^/00onW_n_oYl3[ojO0
j`06ojO0j`?oZ<7/0_nX`N/;ojNoj`03o`000?oooooooooo017ooooo00?o0000ooooooooool00ooo
ool0033ooooo00?o0000ooooooooool0<Oooool6ojFok0?oYl3[1?nW`>`6ojS0j`?oX[k]0onT_n`6
ohVhm0GoK[7i1On4_?T5okC5iP;o[LS^1_o5`]L00onna=koa[[?olJjc`05olJjc`03olBneOo1//co
`K;<00Ko`K;<00?o^:o@ok^]bonk[L/01?nk[L/4okB/d0Co^:W;1OnbZ<h00onfYl[o/:C<ok2Tc005
ok2Tc0Go[JK@00?o[j79ojbPbon/X</01On/X</7ojVPc@03ojNQconWW<_oYic;00?oYic;1_nTV//5
oj6Ic0KoWIS>0onJV=03oj6bi0OoX[WY0_nTa_45oj[VnP;o[N7i1_n`g?L00on[ankoZL;/ojW2k006
ojW2k0KoYko[1onW`>`00onX`^coZ<7[ojS1j`03ojS1j`OoYko[00?oYkk[ojNojonW_n/00onW_n/6
ojO0j`03ojS1k?nX`N_oZ<7[00CoZ<7[1_nW_n/5ooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool00oooool0037ooooo00?o0000ooooooooool0<Oooool7ojFok0KoYl3/1onX`>/5ojBo
k0KoRKSd1Om^/OT5ohBln@03okC5i_n]b>ko[LS^00Co[LS^0oo5`]L4okk4gPGoa[[?0oo4_]D6ol6b
c003ol>hd?nk[L_o^jg;00Ko^jg;00?o]:c@okRYbonhZL/01?nhZL/3ok:XcPCo]ZO:1_n`Y<`3ojfV
d0Co[j791_n/X</6ojVPc@03oj^Pc?nWW<_oYic;00CoYic;1_nTV//6oj6Ic0?oWIS>0onR[Ml6oj6b
i0GoX[WY1?nVhO/00onZi_[o[N7iojgQn@04ojgQn@;o/=cg1On[anh6ojW2k0SoYko[0onW`>`3ojS2
k0OoZ<7[0onW_n/3ojNnj`OoYko[0_nW`>/5ojS1k0KoZ<7[0_nW_n/9ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool00oooool003;ooooo0_l0000booooo`OoYKo/1_nW`>`7ojS0j`Go
Y;o/0on9^?@4oi2jl`GoL[?i1Omc^O/6ojg8kP03olG2eonna=ko_/CN00Co_/CN0oo6^/l5olBne@Co
`K;<0oo3^=06ok^]b`03okncc_nhZL_o^:W;00Ko^:W;00?o/ZS>okJWb_nfYlX01?nfYlX6ok2Tc003
ojfVd?n_XLWo[j7900?o[j791on/X</2ojVPc@GoZj3<1OnWW</7ojBJb`?oXIW<0_nTZm`7oj:]g`Ko
XK;T00?oX[WYojKQnonVhO/01?nVhO/2oj[UnPGo[N7i0on]c_46oj_7kP;oZL;/2_nW_n/8ojS2k0Go
Z<7[2?nW_^/5ojNoj`03ojO1k?nX`NcoZ<7/00KoZ<7/0onX`N/>ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool00_ooool003Cooooo00?o0000ooooooooool0<?ooool7ojFok0KoYl3/
1onX`>/2ojBok0CoY[o/1_n@^_<5og:cn@GoLkWk0on]b>h3oig9mPOo_/CN00?oa[[?olBneOo4_]D0
1?o4_]D3ol6bc0Go`kS@0onk[L/4oknccPKo^:W;00?o_;7?okJWb_nfYlX01OnfYlX5ok2Tc003okFX
c?n_XLWo[j7900Go[j791On/X</00on_Y/koZj3<oj^Pc005oj^Pc0KoYic;1OnTV//00onW[=_oY:_L
ojB[g004ojB[g0OoXZgO0onQ/^@5oj;HnP03ojKQnonZiO[oZ^Gj00CoZ^Gj00?o[N7iojg>lOn]c_40
1On]c_43oj_7kP_oYko[3?nX`^`00onX`N_oYkk[ojNnj`0:ojNnj`03ojNojonW`NcoYl7/00?oYl7/
1_nX`N`Booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool003Gooooo00?o
0000ooooooooool0<?ooool5ojFok0;oY[o/1_nW`>`7ojS0j`OoY[o/0_n@^_<4oiVll0GoNkSi1?mY
]?/6oig9mPGo_/CN0_ncbN/7olBne@03ol6bc?o3^=3o`kS@00Go`kS@00?o^jg;okncc_no/lh01?no
/lh4okRYb`?o_;7?1onfYlX00on`Y<co]JS<okFXc003okFXc0Ko[j790on/X</4ojnVcPKoZj3<1_nW
W</2ojBJb`GoYjcK1_nTZm`5oj:]g`;oXm;h1_nRf?X3ojCUn`?oZ^Gj1?n/e?D5ojg>l@03ojS0jonW
_n_oYko[00[oYko[00?oYl7/ojS2k?nX`^`02OnX`^`2ojNoj`_oYkk[0onW_n/6ojO1k0;oZ<7/5_oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo000fooooo`03o`000?oooooo
oooo033ooooo00?oYKo/ojJok?nV_n`01?nV_n`6ojO0k0OoZ<3[1OnV_n`2ojS0j`KoVKc`1Omk^?T4
ofVdn`KoWLWf00?o_/CNok?9joncbN/01?ncbN/5olBne@;o^lCQ1_o3^=000onm`Mco_k?>oknccP05
oknccP?o^:W;1Onl/Ll5okJWbP03okZddoneZ<co]JS<00Go]JS<1_n_XLT00on/X<_o[jK>ojnVcP03
ojnVcPOoZj3<1?nWW</00onZ/=coYjcKojN/f`05ojN/f`OoY:_L00?oXZgOoj?Bn?nSd_P01?nSd_P2
oj;HnPGoY>Gk0_nYf?P7ojcDm@03ojg>lOnX`>_oZ<3[00?oZ<3[2?nW_n/5ojO1k0KoZ<;/00?oZ<7[
ojNojonW_n/01?nW_n/6ojNnj`SoYko[0onW`N`Kooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool00_ooool003Oooooo0_l0000booooo`KoY[o/0onW`>`4ojK0k0KoZ<3[00?oY[o/ojS0
jonX`>/01?nX`>/6oiVll0;oNkSi0on5^OL3ofZen`04ofVdnonMbOKoWLWfoig9mP?oP/Gm1oncbN/0
0oo4_]Go^lCQok_4h@04ok_4h@?o`kS@1?nm`M`7oknccP03okRYbonl/Loo_;7?00Co_;7?0onfYlX4
okZdd`Ko]JS<1On_XLT00onc[mCo[jK>ojnVcP05ojnVcPKoZj3<00?oYic;ojZ`g?nZ/=`00onZ/=`6
ojN/f`KoY:_L0_nTcoH5oj?Bn0CoWNGl00?oY>GkojWHn?nYf?P01?nYf?P3ojcDm@?oZ<7/1onX`>/7
ojNoj`KoYl7/0_nX`^`5ojS1j`KoYko[0_nW_^/:ojNojb3ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`02ooooo`00>Oooool00ol0003oooooooooo`0`ooooo`KoY[o/1onV`>`=ojS0
j`?oVKc`1?nQ_^d4ohFim`GoJ[Gk1On2aOd5ok?9j`;oWLki1onka>400oo3^=3o_L7Lokg1g004okg1
g0Go_k?>00?o_;oLokbaconl/Ll01_nl/Ll00onfYl[o^[CCokZdd`04okZdd`Ko]JS<00?o[j79ok>_
e?nc[m@00onc[m@6ojnVcPGoZj3<00?o[KKOojZ`g?nZ/=`01OnZ/=`6ojN/f`;oY:_L1_nTcoH00onS
d_SoWNGloigUo004oigUo0;oYM[j1OnYf?P2ojS3k@KoZ<7/1OnX`>/9ojNoj`?oYl7/0onX`^`7ojS1
j`?oYko[0onW_^/8ojNojb?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`02oooo
o`00>_ooool00ol0003oooooooooo`0`ooooo`KoY[o/1OnV`>`2ojG0k0goZ<3[1onQ_^d4ohFim`Go
J[Gk1On2aOd00oncbN_oWLkioig>n@04oig>n@Go^lCQ0_n[d?<6okg1g0?o_k?>1?nl_m`6okbac`03
okS0h?nj]=?o^[CC00Go^[CC1OneZ<`00onf^]go/joDok>_e005ok>_e0Ko[jK>00?oZj3<ojffgon]
]]l00on]]]l7ojZ`g0?oYjcK2OnTcoH4oiSSo@03oigUo?nUf_[oYM[j00CoYM[j00?oZMShojS3kOnX
`nd01?nX`nd6ojS1k003ojS0jonW_n_oYko[00WoYko[00?oZ<;]ojS2k?nX`^`01OnX`^`5ojS1j`03
ojNnj_nW_^_oYkk[00GoYkk[0onW_n/Xooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool00_ooool003_ooooo00?o0000ooooooooool0<?ooool6ojJok003ojK0k?nU`>coYL3/00CoYL3/
3OnX`>/5oj6nk@;oY[o/1OnC^o85ogJjn`GoJ[_m1_nMc_T00onka>7oZm3coj_@l`04oj_@l`Ko_L7L
00?o_k?>okbog?nl_m`01?nl_m`3okbac`Co^<3P1onj]=<00oneZ<co][[MokJjg@03okJjg@Oo/joD
0on_Y/h3ojjmi@Ko[KKO1OnZ/=`3ojCBn0OoY<of1_nHhod3oj;Kn`?oYM[j0onXaNh7ojS3k@?oZ<7/
2onW_n/5ojS2k@OoZ<;/00?oZ<7[ojNnj_nW_^X00onW_^X5ojNnjbgooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`01ooooo`00??ooool00ol0003oooooooooo`0`ooooo`?oY[o/1?nW
_n/6ojG0k0?oZ<3[1?nW`N`6ojS0j`03oj6nkOnV_ncoY[o/00CoY[o/1OnC^o85ogJjn`GoJ[_m0onM
c_T4ogK6o`KoZm3c0onm`M`3ojk?l@Oo_;oL00?o_;7?okS0h?nh`>001?nh`>05okZdd`03ok77jonf
^]go][[M00Go][[M1Onc[m@00on/b>ko[[gUojjmi@05ojjmi@Ko[KKO00?oZ[3LojCBn?nTd_P01OnT
d_P3ojC?mPCoTn;m0_nHhod5oj;Kn`03ojS6konXaNkoZ<G^00GoZ<G^1OnX`nd;ojNoj`CoYl;/1_nX
`^d3ojS2k0CoYko[1_nW_^X00onW_^_oooooooooo`0_ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool00Oooool003gooooo0_l0000aooooo`OoYko[0onU`>`3ojFok0OoYl7/1_nX`>/7
ojJok0;oTk_b1?nP_Nh5ohNkm`KoK;[m1Omfa_l3oj_@l`?oPlko1_n^co45okbog0;o[=7c1onh`>00
0onj]=?o/LO[ok77j`03ok77j`Oo][[M00?o/joDojc8k_n/b>h00on/b>h7ojjmi@?o[KKO1OnPeo/3
ojCBn0CoS]on0onCh_d5oikJo003oj;KnonXa^ooZ<K_00?oZ<K_1onXaNh00onX`ngoYko[ojNoj`08
ojNoj`;oYl7/1onW`^`3ojS2k@?oZ<3[1onW_n/3ojNnjSCooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`01ooooo`00?oooool00ol0003oooooooooo`0_ooooo`GoYko[0_nX_n/6ojFo
k0GoYl7/0_nV`N`6ojS0j`GoY[o/0_nX`>/6oj2mkPGoQk_g0om/^_d4oh2nn`GoJKgm1On3c_l6ojk?
l@03okbog?n/dO?o[=7c00Co[=7c1Onh`>02oj?GnPKo/LO[1Onf^]d2ojGEn@Ko[<S^1On^_ND2oiSL
oPKoX=Ok0on:gOh3ohkOoPCoW=Sl1OnNf_`2ojO5k`KoZ<K_0onXaNh;ojNoj`KoYl7/1OnW`^`00onX
`N_oZ<3[ojS0j`05ojS0j`GoYko[>Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
007ooooo0010ooooo`03o`000?oooooooooo02oooooo00?oYko[ojRojonX_n/01?nX_n/6ojFok003
ojO1k?nV`NcoY/7/00CoY/7/1_nX`>/00onV_ncoZ<3[ojS0j`04ojS0j`CoX;g^0_nV_n/6oiRll@Ko
P;kk1OmY_Od5oh?>o`?o[/oa1?n5d_l6ojcAl`03okS0h?nSeo[oXmOj00CoXmOj1_naan/00onf^]go
YMGiojGEn@04ojGEn@Ko[<S^00?o[[gUoiSLo_nHg?h01?nHg?h2oj3Gn`GoR]gn0onJe?`6oicHo003
oikJo?nWaNooYlG_00CoYlG_0onXa^l=ojNoj`[oYl7/00?oYl;/ojS1jonX`N/00onX`N/7ojS0j`03
ojNojooooooooooo03_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`01ooooo`00
@Oooool00ol0003oooooooooo`0_ooooo`OoZ;o[0onU_n`4ojJok0KoY/7/0onX`>/4ojS1j`KoZ<3[
00?oX;g^ojJojonV_n/00onV_n/6oiRll@?oP;kk1?nB_?<6og_1o@GoJl;n1On5d_l3ojcAl`CoOM;o
1_nSeoX3ok77j`?oS]Wo1onUeOT3ojc8kPCoR=_o0onHg?h5ohOIo`03oh[Mo_nJe?coV]Cl00GoV]Cl
0onLf?`3ojK4k`GoYlG_3OnW_n/00onW`>coYl7/ojO1k00:ojO1k003ojS1k?nX`N_oZ<7[00GoZ<7[
0onX`>]1ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00Oooool004;ooooo0_l0
000`ooooo`GoZ;o[0_nX`>X7ojJok0?oY/7/0onU`>d7ojS1j`KoZ<3[1_nV_n/3oiRll@CoY;k/1_nB
_?<3og_1o@CoTKge1Omm`od6ofk5o`GoOM;o0onSeoX4ogK@o`GoS]Wo0onUeOT5oggFoP?oR=_o1On7
e?l3ohOIo`CoVloj0onJe?`4ojG2kPKoY/C_00?oYlG_ojNojonW_n/02onW_n/5ojO0k0SoYl7/1OnX
`N`5ojS1jdKooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`01ooooo`00A?ooool0
0ol0003oooooooooo`0^ooooo`03ojRojonX`>[oZ<3Z00CoZ<3Z1OnV_n`2ojNoj`KoYL3]1OnX`N/2
ojO1k0KoZ<3[1?nV_n/2ojS0j`OoY;k/0onB_?<3oj>nk@OoTKge1Omm`od3ofk5o`?oQLKm1_mdb?l3
ogK@o`CoP/co1_mjd?l3oggFoPGoS=7n0on7e?l3oic9m`GoVloj0_nV`>`7ojG2kP?oY/C_3OnW_n/3
ojO0j`KoYl3/0onW`N`4ojS2k0KoZ<7/00?oZ<7[ooooooooool0B?ooool00ol0003oooooooooo`07
ooooo`7o00000Oooool1ooooo`00AOooool00ol0003oooooooooo`0_ooooo`KoZ<3Z00?oY[o/ojNo
jonW_n/01?nW_n/6ojG0k@03ojS1jonW`NcoYl7/00CoYl7/1_nX`>/00onV_n_oZ<3[ojS0j`03ojS0
j`GoY;k/0_nX`>/6oj>nk@GoTKge0_nS_^d7oiBnm0CoQLKm0omdb?l5oho6nPGoP/co0omjd?l5oi;;
n`?oS=7n0onN`o86oic9m`03oi_?n_nV`>coY/3/00CoY/3/1OnU`^h2ojRoj`_oYko[2?nW`>/3ojO0
k0?oYl;]1onX`^`3ojS1k4kooooo00?o0000ooooooooool01_ooool1o`00007ooooo0Oooool004Ko
oooo00?o0000ooooooooool0<?ooool2ojS0jP?oZL3Z1onW_n/3ojG0k@CoYKo/1_nW`N`3ojS0j`?o
Z<7/1_nX`>/00onT_^coZ<3[ojS0j`04ojS0j`KoXkk]00?oTKgeoj>nkOnS_^d01?nS_^d5oiBnm003
ojBnk?nJ__;oV[kb00CoV[kb1On?a_X2oj6okPOoVL;d0onBbo/2oj>okPOoW/?b0onLbOL4ojJoj`Ko
Y/3/00?oYL;^ojRojonX_n/01?nX_n/7ojNoj`[oYl3[2?nW`^d5ojS2k5;ooooo00?o0000oooooooo
ool01_ooool1o`00007ooooo0Oooool004Oooooo0_l0000aooooo`GoZL3Z1OnW_n/2ojRojPOoYKo/
0onW`N`3ojG0k@KoZ<7/0onX`>/4ojS1j`KoZ<3[0onS_^d4ojS0j`KoXkk]00?oU;kdojBnk?nT_^`0
0onT_^`6oiZnlP03oho6n_nQ_nkoXKo^00CoXKo^1OnI`_@00onV_n_oXko^oj>okP04oj>okPGoW/?b
0_nW_n/7ojJoj`?oY/3/2_nX_n/3ojNoj`[oYl3[3?nW`^d00onX`^coooooooooo`1Dooooo`03o`00
0?oooooooooo00Gooooo0Ol00001ooooo`7ooooo0019ooooo`03o`000?oooooooooo02oooooo1OnY
`>X00onW_n_oZ;oZojRojP04ojRojPGoYKo/0_nW_n/6ojG0k@CoZ<7/0_nV`Nd7ojS1j`goZ<3[0onS
_^d3ojS0j`KoY;k/0onJ__84ojJoj`KoXKo^00?oVL;dojJojonV_n/00onV_n/6oj>okP03oik3l_nW
_n_oYko[00CoYko[1OnV_n/2ojNoj`_oZ;o[00?oYl7/ojO0jonW`>/02?nW`>/=ojO2kE[ooooo00?o
0000ooooooooool01?ooool1o`00007ooooo0Oooool004[ooooo00?o0000ooooooooool0;oooool2
ojW0jPCoZ<3Z1_nX_nX00onU_ncoYko[ojNoj`04ojNoj`KoYL3]00?oZ<7/ojK1kOnV`Nd00onV`Nd5
ojS1j`;oYl7/4onX`>/3ojBnk0?oZ;o[1onV_n/3oj6okP?oZ;o[1_nV_n/3oj>okPCoZ;o[1_nW_n/0
0onV_n_oYko[ojNoj`04ojNoj`OoZ;o[1OnW`N`5ojO0j`coYl;]H?ooool00ol0003oooooooooo`03
ooooo`7o00000Oooool1ooooo`00Boooool00ol0003oooooooooo`0_ooooo`KoZ<3Z0onX_nX4ojS0
jPKoYko[0onU`>d4ojJok0GoY/7]00?oZ<7[ojO1k?nW`N`01?nW`N`CojS0j`KoZ;o[1OnV_n/8ojRo
j`?oY[o[2_nX_n/3ojNoj`CoYl3[1_nW_n/3ojRoj`WoYl7/00?oYl3[ojO2kOnW`^d02OnW`^eToooo
o`03o`000?oooooooooo00?ooooo0Ol00001ooooo`7ooooo001<ooooo`;o0000<?ooool4ojS0jP;o
Z<3[1onX`>X3ojNoj`?oZ;oZ1onV_n`2ojK1k@CoYKo/1_nW`N`3ojS0j`CoYl7/3?nX`>/6ojRoj`03
ojJojonX_n_oZ;o[00SoZ;o[0_nX`N/;ojRoj`;oYl7/1onW`>/3ojNoj`;oYl;/2_nW`N`;ojO2kFSo
oooo00?o0000ooooooooool00oooool1o`00007ooooo001>ooooo`03o`000?oooooooooo02kooooo
00?oZ<3ZojS0jonX`>/00onX`>/7ojS0jPKoZ;oZ1OnV_n`00onW_n_oYKo/ojFok005ojFok0?oYl7/
0onU`>`7ojO1k0;oZ<3[1?nW`N`6ojS0j`?oZ;o[1?nX`N`7ojRoj`GoZ<7[1onX_n/6ojO1k0GoYl3[
00?oYl;]ojO2k?nW`^`01?nW`^`7ojO1k0[oYl;]K?ooool00ol0003oooooooooo`02ooooo`7o0000
0Oooool004oooooo00?o0000ooooooooool0;oooool5ojS0j`OoZ<3Z1_nX_nX00onV_ncoYko[ojNo
j`03ojNoj`GoYKo/0_nW_n/6ojG0k0GoYl7/00?oY/3/ojO1k?nW`N`01OnW`N`3ojS0j`?oYl7]1onX
`N`3ojRoj`?oYl;/1_nX`N/3ojRoj`CoYl;/1_nW`N`00onW`>_oYl;]ojO2k@03ojO2k@KoYl;/1onW
`N`5ojO2kG7ooooo00Go0000ooooooooooooooooo`000001ooooo`00D?ooool00ol0003ooooooooo
o`0_ooooo`;oZ<3[0onX`N/7ojS0jP?oZ;oZ1?nX`>X5ojNoj`03ojFok?nW_n_oYko[00CoYko[1_nU
`>`00onW`NcoY/3/ojK0k003ojK0k0GoYl7/0_nV`>`6ojO1k@GoZ<7/00?oY/7]ojO2k?nW`^`01OnW
`^`3ojS1j`?oY/;]1onW`^`3ojO1k0?oY/7]1_nW`^d3ojO2k0CoYl3/1_nW`N`00onW`^gooooooooo
o`1booooo`05o`000?ooooooooooooooool000000Oooool0057ooooo0_l0000`ooooo`GoZ<7[1OnX
`>X2ojS0j`OoZ<3Z0_nW_n/4ojRojPKoYko[0onU`>`4ojNoj`GoY/3/00?oYl7/ojK0k?nV`>`01?nV
`>`6ojO1k@03ojS1k?nV`NgoY/7]00?oY/7]1OnW`^`2ojK0k0KoY/;]1OnW`^`00onV`>coY/7]ojK1
k@05ojK1k@?oYl;]0onW_n/7ojO0k0?oYl7/N?ooool01?l0003oooooooooool00001ooooo`00Dooo
ool00ol0003oooooooooo`0^ooooo`GoZ<7[00?oZ<3ZojS0jonX`>/01?nX`>/5ojS0jP03ojS0jonX
_n[oZ;oZ00GoZ;oZ0onW_n/3ojRojPOoYko[0_nV`>`4ojNoj`KoY/3/0onW`Nd3ojJok0KoY/7]00?o
Yl;/ojK0k?nV`>`01?nV`>`6ojK2k@03ojO2k?nV`>coY/3/00?oY/3/1OnV`Nd8ojNoj`GoYl3/OOoo
ool00ol0003oooooo`000001ooooo`00E?ooool00ol0003oooooooooo`0^ooooo`;oZ<7[1?nW`>`6
ojS0j`03ojS0j_nX`>_oZ<3[00?oZ<3[1OnX_nX2ojS0j`KoZ;oZ1OnW_n/00onX_n[oYko[ojNoj`05
ojNoj`?oY/3/0onW_n/6ojJok0?oY/7]1?nV_n/6ojK0k0?oY/;]0onW_n/6ojK0k003ojK1kOnW_n_o
Yko[00[oYko[00?oYl3/ooooooooool0O_ooool00ol0003oooooo`000001ooooo`00EOooool00ol0
003oooooooooo`0^ooooo`KoYl3/0onX`>/4ojO1k0GoZ<3[00?oZ;oZojS0jonX`>/01?nX`>/6ojRo
jP03ojNojonX_n[oZ;oZ00?oZ;oZ1OnW_n/2ojRojPKoYko[1?nV_n`2ojRojPOoY[o[0onV`>`2ojRo
jPOoYko[0onV`>`4ojRojPWoYko[Q?ooool1o`00007ooooo0Ol0000005Kooooo0_l0000_ooooo`?o
Yl3/0onV`>`7ojO1k0;oZ<3[1?nX`N`6ojS0j`?oZ;oZ1?nX`>/5ojRojP03ojNojonX_n[oZ;oZ00Co
Z;oZ1_nW_n/00onV_ncoZ;oZojRojP03ojRojPGoY[o[1onX_nX5ojNoj`WoZ;oZ0onW_n^:ooooo`;o
0000001Hooooo`03o`000?oooooooooo02gooooo1_nV`>`5ojO1k0;oY/3/1_nX`N`3ojS0j`?oZ<7[
1onX`>/2ojRojPCoZ<3[1_nX_nX3ojNoj`WoZ;oZ00?oY[o[ojRoj_nX_nX02OnX_nX00onW_n_oZ;oZ
ojRojP09ojRojXgooooo0ol0000005Wooooo00?o0000ooooooooool0;Oooool6ojK0k003ojO1k?nV
`>coY/3/00CoY/3/1?nX`N`2ojK1k0KoZ<7[1OnX`>/00onX`N_oZ<3[ojS0j`05ojS0j`?oZ;oZ0onX
`>/PojRojXcooooo1?l00003ooooo`00F_ooool00ol0003oooooooooo`0]ooooo`?oY/3/1?nW_n/6
ojK0k003ojS1k?nV`NcoY/7/00?oY/7/1_nX`N/00onX`>_oZ<7[ojS1j`03ojS1j`GoZ<3[0_nX`N`6
ojS0j`CoZ;oZ0_nX`>/:ojRojP?oZ<3[2OnX_nZ<ooooo`?o00001oooool005_ooooo00?o0000oooo
ooooool0;_ooool6ojNoj`?oY/3/0onV_n/6ojK1k0?oZ<7[1?nW`N`5ojS1j`03ojS0jonX`NcoZ<7/
00CoZ<7/1_nX`>/00onX_n[oZ<3[ojS0j`03ojS0j`GoZ;oZ00?oZ<7[ojS0jonX`>/01OnX`>/3ojRo
jXgooooo1?l0000:ooooo`00G?ooool2o`0002oooooo0onW_n/3ojRoj`KoY[o[0onV`N`4ojJok0Ko
Yl7/0_nX`N/4ojO1k0KoZ<7/0onX`>/3ojO1k0KoZ<3[00?oZ;oZojS1jonX`N/00onX`N/5ojS0jhgo
oooo1?l0000>ooooo`00G_ooool00ol0003oooooooooo`0]ooooo`KoZ;o[1?nV_n/2ojNoj`OoY[o/
0onW`N`2ojJok0OoYl7/0onX`N`3ojK1k0KoYl7/0onX`>/4ojO1k0GoZ<7[00?oZ<3[ooooooooool0
R_ooool4o`0001;ooooo001Oooooo`03o`000?oooooooooo02gooooo1_nX_n/00onV_n_oYko[ojNo
j`03ojNoj`GoY[o/0_nW_n/5ojJok0GoYl7/0_nV_n/6ojK1k0?oYl7/1?nV`>`6ojO1k0;oZ<7[Rooo
ool4o`0001Kooooo001Pooooo`03o`000?oooooooooo02gooooo1onX_n/5ojNoj`03ojJok?nW_n_o
Yko[00CoYko[1OnV_n`00onW`NcoY[o[ojJoj`04ojJoj`CoY/7/0_nW_n/7ojK0k0?oYl7/S?ooool3
o`0001[ooooo001Qooooo`;o0000;oooool6ojRoj`;oYko[1?nX_n/6ojNoj`;oY[o/1?nW_n/6ojJo
j`03ojK1k?nW_n_oYko[00?oYko[1OnV`>b<ooooo`Co00007Oooool006?ooooo00?o0000oooooooo
ool0;Oooool3ojRoj`;oZ<3[1onX_n/3ojNoj`?oZ;o[1_nW_n/3ojJoj`?oZ;o[1_nW_n/00onV`>co
ooooooooo`29ooooo`Co00008Oooool006Cooooo00?o0000ooooooooool0;Oooool5ojS0j`GoZ;o[
0_nX`>/6ojRoj`?oYko[2OnX_n/3ojNojh[ooooo1?l0000Uooooo`00IOooool00ol0003ooooooooo
o`0]ooooo`GoZ<3[00?oZ;o[ojS0jonX`>/01?nX`>/4ojRoj`;oZ<3[2OnX_n^;ooooo`Co0000:Ooo
ool006Kooooo0_l0000^ooooo`;oZ<3[1?nW`N`6ojS0j`03ojRojonX`>_oZ<3[00?oZ<3[1OnX_n^;
ooooo`?o0000;Oooool006Sooooo00?o0000ooooooooool0;?ooool6ojO1k0?oZ<3[0onW`N`6ojS0
j`03ojRojooooooooooo08Sooooo1?l0000`ooooo`00JOooool00ol0003oooooooooo`0/ooooo`?o
Yl7/1?nW`>`5ojO1k0?oZ<3[ROooool4o`0003Cooooo001Zooooo`03o`000?oooooooooo02cooooo
1onW`>`2ojO1k8[ooooo1?l0000hooooo`00Joooool2o`0002gooooo1OnW`>b9ooooo`Co0000??oo
ool006gooooo00?o0000ooooooooool0:oooool00onW`>coooooooooo`27ooooo`?o0000@?ooool0
06kooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`23ooooo`Co0000@oooool006oo
oooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1oooooo`Co0000Aoooool0073ooooo
0_l0000Yooooo`03o`000?oooooooooo07_ooooo1?l0001;ooooo`00L_ooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo07Oooooo1?l0001?ooooo`00Loooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo07Cooooo0ol0001Cooooo`00M?ooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo073ooooo1?l0001Fooooo`00MOooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo06cooooo1?l0001Jooooo`00M_ooool2o`0002?ooooo00?o0000ooooooooool0
J?ooool4o`0005kooooo001hooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0I?oo
ool4o`0006;ooooo001iooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0HOooool3
o`0006Kooooo001jooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0GOooool4o`00
06Wooooo001kooooo`;o00007_ooool00ol0003oooooooooo`1Iooooo`Co0000KOooool007gooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`1Eooooo`Co0000LOooool007kooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`1Aooooo`Co0000MOooool007oooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`1>ooooo`?o0000NOooool0083ooooo0_l0000Ioooo
o`03o`000?oooooooooo04[ooooo1?l0001looooo`00P_ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo04Kooooo1?l00020ooooo`00Poooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo04;ooooo1?l00024ooooo`00Q?ooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo03kooooo1?l00028ooooo`00QOooool2o`0001?ooooo00?o0000ooooooooool0??ooool3
o`0008cooooo0027ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0>?ooool4o`00
08oooooo0028ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0=?ooool4o`0009?o
oooo0029ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0<?ooool4o`0009Oooooo
002:ooooo`;o00003_ooool00ol0003oooooooooo`0/ooooo`Co0000Voooool008cooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0Yooooo`?o0000Woooool008gooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0Uooooo`Co0000X_ooool008kooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0Qooooo`Co0000Y_ooool008oooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0Mooooo`Co0000Z_ooool0093ooooo0_l00008ooooo`03o`000?oo
oooooooo01Wooooo1?l0002^ooooo`00T_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo01Kooooo0ol0002booooo`00Toooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
01;ooooo1?l0002eooooo`00U?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00ko
oooo1?l0002iooooo`00UOooool2o`0000?ooooo00?o0000ooooooooool02_ooool4o`000;gooooo
002Gooooo`04o`000?ooooooooooo`0000Sooooo1?l00031ooooo`00V?ooool00ol0003oooooo`00
0005ooooo`?o0000aOooool009Wooooo0_l000000ooooooo0000o`000002o`000<Sooooo002Joooo
o`;o0000c?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0538698, 0.0432538, \
0.0035044, 0.0035044}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[.12586 .2075 -12 -8.99448 ]
[.12586 .2075 0 .00552 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.56094 .0364 -5.16972 -9 ]
[.56094 .0364 .83028 0 ]
[.75679 .08071 0 -6.17777 ]
[.75679 .08071 12 2.82223 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.9429 .3657 0 -5.9083 ]
[.9429 .3657 6 3.0917 ]
[.02494 .25992 -18 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.01611 .31527 -18 -2.78472 ]
[.01611 .31527 0 6.21528 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00254 .43215 -12 -2.88407 ]
[-0.00254 .43215 0 6.11593 ]
[-0.0124 .49393 -12 -2.93688 ]
[-0.0124 .49393 0 6.06312 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
[(-2)] .12586 .2075 1 .99877 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.56863 .04703 m
.57247 .05235 L
s
[(2)] .56094 .0364 .72324 1 Mshowa
.125 Mabswid
.18558 .19702 m
.18832 .19985 L
s
.23703 .17687 m
.23971 .17975 L
s
.28951 .15632 m
.29214 .15925 L
s
.39772 .11395 m
.40023 .11699 L
s
.4535 .09211 m
.45595 .0952 L
s
.51046 .06981 m
.51284 .07294 L
s
.08568 .23614 m
.08851 .23887 L
s
.62804 .02377 m
.63027 .02701 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.7445 .0853 m
.73835 .08759 L
s
[(-2)] .75679 .08071 -1 .37284 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.93037 .36962 m
.92411 .37158 L
s
[(2)] .9429 .3657 -1 .31296 Mshowa
.125 Mabswid
.7708 .12553 m
.7671 .12688 L
s
.79613 .16428 m
.79242 .1656 L
s
.82054 .20161 m
.81682 .20291 L
s
.86679 .27235 m
.86305 .2736 L
s
.88871 .30589 m
.88497 .30711 L
s
.9099 .3383 m
.90615 .3395 L
s
.71716 .04348 m
.71349 .04489 L
s
.95018 .39992 m
.94642 .40107 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(-20)] .02494 .25992 1 -0.39157 Mshowa
.02837 .31059 m
.0345 .30825 L
s
[(-10)] .01611 .31527 1 -0.38117 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.00981 .42772 m
.01599 .4255 L
s
[(10)] -0.00254 .43215 1 -0.3591 Mshowa
0 .48963 m
.0062 .48748 L
s
[(20)] -0.0124 .49393 1 -0.34736 Mshowa
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.653 .753 .923 r
.39362 .69485 .40169 .70181 .4152 .69809 .40717 .69108 Mtetra
.658 .754 .921 r
.40717 .69108 .4152 .69809 .42877 .69433 .42079 .68714 Mtetra
.66 .75 .917 r
.42079 .68714 .42877 .69433 .44242 .69042 .43448 .68313 Mtetra
.657 .748 .917 r
.43448 .68313 .44242 .69042 .45614 .68643 .44824 .6792 Mtetra
.655 .75 .92 r
.44824 .6792 .45614 .68643 .46992 .6825 .46207 .67532 Mtetra
.652 .752 .923 r
.46207 .67532 .46992 .6825 .48378 .67862 .47597 .6715 Mtetra
.652 .754 .924 r
.47597 .6715 .48378 .67862 .4977 .67478 .48994 .66764 Mtetra
.656 .756 .923 r
.48994 .66764 .4977 .67478 .5117 .67095 .50398 .66362 Mtetra
.659 .753 .919 r
.50398 .66362 .5117 .67095 .52577 .66705 .5181 .65949 Mtetra
.66 .748 .915 r
.5181 .65949 .52577 .66705 .53991 .66299 .53229 .65534 Mtetra
.657 .746 .915 r
.53229 .65534 .53991 .66299 .55412 .65887 .54655 .65126 Mtetra
.656 .747 .917 r
.54655 .65126 .55412 .65887 .56841 .65474 .56088 .6472 Mtetra
.655 .75 .92 r
.56088 .6472 .56841 .65474 .58277 .65065 .57529 .64315 Mtetra
.653 .751 .922 r
.57529 .64315 .58277 .65065 .5972 .64657 .58978 .63912 Mtetra
.653 .754 .924 r
.58978 .63912 .5972 .64657 .61171 .64248 .60434 .63508 Mtetra
.653 .756 .925 r
.60434 .63508 .61171 .64248 .6263 .63838 .61898 .631 Mtetra
.653 .758 .926 r
.61898 .631 .6263 .63838 .64096 .63426 .6337 .62688 Mtetra
.654 .759 .927 r
.6337 .62688 .64096 .63426 .6557 .63012 .64849 .62272 Mtetra
.654 .76 .927 r
.64849 .62272 .6557 .63012 .67052 .62595 .66337 .61852 Mtetra
.655 .76 .927 r
.66337 .61852 .67052 .62595 .68542 .62175 .67832 .61428 Mtetra
.67832 .61428 .68542 .62175 .70039 .61752 .69335 .61 Mtetra
.656 .76 .927 r
.69335 .61 .70039 .61752 .71544 .61326 .70846 .60568 Mtetra
.656 .76 .926 r
.70846 .60568 .71544 .61326 .73057 .60898 .72364 .60131 Mtetra
.657 .759 .925 r
.72364 .60131 .73057 .60898 .74579 .60468 .73891 .59691 Mtetra
.658 .758 .924 r
.73891 .59691 .74579 .60468 .76108 .60036 .75426 .59246 Mtetra
.658 .755 .922 r
.75426 .59246 .76108 .60036 .77646 .59604 .76969 .588 Mtetra
.657 .752 .921 r
.76969 .588 .77646 .59604 .79192 .59172 .7852 .58356 Mtetra
.656 .75 .919 r
.7852 .58356 .79192 .59172 .80748 .58744 .80081 .57913 Mtetra
.655 .747 .917 r
.80081 .57913 .80748 .58744 .82311 .58315 .8165 .57471 Mtetra
.653 .744 .917 r
.8165 .57471 .82311 .58315 .83884 .57879 .83228 .57036 Mtetra
.653 .745 .918 r
.83228 .57036 .83884 .57879 .85463 .57427 .84816 .566 Mtetra
.655 .751 .921 r
.84816 .566 .85463 .57427 .8705 .56968 .86411 .56151 Mtetra
.658 .757 .923 r
.86411 .56151 .8705 .56968 .88646 .56509 .88013 .55685 Mtetra
.659 .756 .922 r
.88013 .55685 .88646 .56509 .90252 .56053 .89624 .55216 Mtetra
.657 .753 .921 r
.89624 .55216 .90252 .56053 .91867 .55602 .91245 .54751 Mtetra
.655 .75 .92 r
.91245 .54751 .91867 .55602 .93492 .55157 .92875 .54291 Mtetra
.653 .746 .918 r
.92875 .54291 .93492 .55157 .95125 .54703 .94516 .53839 Mtetra
.654 .749 .919 r
.94516 .53839 .95125 .54703 .96766 .54233 .96165 .5338 Mtetra
.658 .754 .921 r
.96165 .5338 .96766 .54233 .98416 .53759 .97822 .52902 Mtetra
.38546 .68781 .39362 .69485 .40717 .69108 .39906 .68385 Mtetra
.66 .75 .917 r
.39906 .68385 .40717 .69108 .42079 .68714 .41273 .67982 Mtetra
.656 .748 .917 r
.41273 .67982 .42079 .68714 .43448 .68313 .42646 .67589 Mtetra
.654 .75 .921 r
.42646 .67589 .43448 .68313 .44824 .6792 .44026 .67201 Mtetra
.652 .752 .923 r
.44026 .67201 .44824 .6792 .46207 .67532 .45414 .66819 Mtetra
.653 .755 .925 r
.45414 .66819 .46207 .67532 .47597 .6715 .46808 .6643 Mtetra
.659 .756 .921 r
.46808 .6643 .47597 .6715 .48994 .66764 .4821 .66017 Mtetra
.66 .75 .916 r
.4821 .66017 .48994 .66764 .50398 .66362 .49619 .656 Mtetra
.658 .746 .915 r
.49619 .656 .50398 .66362 .5181 .65949 .51035 .65189 Mtetra
.656 .747 .917 r
.51035 .65189 .5181 .65949 .53229 .65534 .52459 .64783 Mtetra
.654 .75 .92 r
.52459 .64783 .53229 .65534 .54655 .65126 .5389 .64381 Mtetra
.652 .752 .923 r
.5389 .64381 .54655 .65126 .56088 .6472 .55329 .63984 Mtetra
.651 .756 .926 r
.55329 .63984 .56088 .6472 .57529 .64315 .56775 .63585 Mtetra
.652 .758 .927 r
.56775 .63585 .57529 .64315 .58978 .63912 .58229 .63179 Mtetra
.655 .76 .927 r
.58229 .63179 .58978 .63912 .60434 .63508 .5969 .62762 Mtetra
.657 .758 .924 r
.5969 .62762 .60434 .63508 .61898 .631 .61159 .62334 Mtetra
.657 .754 .921 r
.61159 .62334 .61898 .631 .6337 .62688 .62635 .61907 Mtetra
.657 .751 .919 r
.62635 .61907 .6337 .62688 .64849 .62272 .6412 .6148 Mtetra
.656 .749 .918 r
.6412 .6148 .64849 .62272 .66337 .61852 .65612 .61053 Mtetra
.656 .748 .917 r
.65612 .61053 .66337 .61852 .67832 .61428 .67113 .60625 Mtetra
.67113 .60625 .67832 .61428 .69335 .61 .68621 .60195 Mtetra
.655 .748 .918 r
.68621 .60195 .69335 .61 .70846 .60568 .70138 .59766 Mtetra
.654 .75 .92 r
.70138 .59766 .70846 .60568 .72364 .60131 .71663 .59337 Mtetra
.653 .752 .922 r
.71663 .59337 .72364 .60131 .73891 .59691 .73196 .58907 Mtetra
.655 .757 .925 r
.73196 .58907 .73891 .59691 .75426 .59246 .74738 .58468 Mtetra
.658 .761 .926 r
.74738 .58468 .75426 .59246 .76969 .588 .76287 .58016 Mtetra
.659 .761 .925 r
.76287 .58016 .76969 .588 .7852 .58356 .77844 .57558 Mtetra
.659 .758 .923 r
.77844 .57558 .7852 .58356 .80081 .57913 .79409 .57096 Mtetra
.657 .754 .921 r
.79409 .57096 .80081 .57913 .8165 .57471 .80983 .56641 Mtetra
.656 .751 .92 r
.80983 .56641 .8165 .57471 .83228 .57036 .82567 .56188 Mtetra
.654 .747 .918 r
.82567 .56188 .83228 .57036 .84816 .566 .84159 .5574 Mtetra
.652 .744 .917 r
.84159 .5574 .84816 .566 .86411 .56151 .85762 .55299 Mtetra
.653 .747 .919 r
.85762 .55299 .86411 .56151 .88013 .55685 .87373 .54852 Mtetra
.658 .756 .922 r
.87373 .54852 .88013 .55685 .89624 .55216 .88991 .54381 Mtetra
.659 .757 .922 r
.88991 .54381 .89624 .55216 .91245 .54751 .90617 .53902 Mtetra
.657 .754 .921 r
.90617 .53902 .91245 .54751 .92875 .54291 .92253 .53428 Mtetra
.656 .751 .92 r
.92253 .53428 .92875 .54291 .94516 .53839 .93899 .5296 Mtetra
.653 .746 .919 r
.93899 .5296 .94516 .53839 .96165 .5338 .95556 .52501 Mtetra
.654 .748 .919 r
.95556 .52501 .96165 .5338 .97822 .52902 .97222 .52034 Mtetra
.66 .751 .917 r
.37724 .68057 .38546 .68781 .39906 .68385 .39088 .67651 Mtetra
.657 .748 .917 r
.39088 .67651 .39906 .68385 .41273 .67982 .40459 .67255 Mtetra
.654 .751 .921 r
.40459 .67255 .41273 .67982 .42646 .67589 .41837 .66866 Mtetra
.651 .752 .923 r
.41837 .66866 .42646 .67589 .44026 .67201 .43221 .66484 Mtetra
.654 .755 .924 r
.43221 .66484 .44026 .67201 .45414 .66819 .44613 .66089 Mtetra
.66 .754 .92 r
.44613 .66089 .45414 .66819 .46808 .6643 .46012 .65672 Mtetra
.66 .748 .915 r
.46012 .65672 .46808 .6643 .4821 .66017 .47419 .65253 Mtetra
.657 .747 .916 r
.47419 .65253 .4821 .66017 .49619 .656 .48833 .64845 Mtetra
.655 .749 .919 r
.48833 .64845 .49619 .656 .51035 .65189 .50254 .64441 Mtetra
.651 .751 .923 r
.50254 .64441 .51035 .65189 .52459 .64783 .51682 .64048 Mtetra
.65 .755 .926 r
.51682 .64048 .52459 .64783 .5389 .64381 .53118 .63652 Mtetra
.653 .759 .927 r
.53118 .63652 .5389 .64381 .55329 .63984 .54561 .63244 Mtetra
.659 .759 .924 r
.54561 .63244 .55329 .63984 .56775 .63585 .56012 .62814 Mtetra
.658 .751 .919 r
.56012 .62814 .56775 .63585 .58229 .63179 .57471 .62386 Mtetra
.656 .746 .916 r
.57471 .62386 .58229 .63179 .5969 .62762 .58937 .61964 Mtetra
.654 .745 .917 r
.58937 .61964 .5969 .62762 .61159 .62334 .60412 .61547 Mtetra
.653 .749 .92 r
.60412 .61547 .61159 .62334 .62635 .61907 .61894 .61134 Mtetra
.652 .753 .924 r
.61894 .61134 .62635 .61907 .6412 .6148 .63384 .60717 Mtetra
.653 .757 .926 r
.63384 .60717 .6412 .6148 .65612 .61053 .64883 .60293 Mtetra
.655 .76 .927 r
.64883 .60293 .65612 .61053 .67113 .60625 .66389 .59861 Mtetra
.657 .76 .926 r
.66389 .59861 .67113 .60625 .68621 .60195 .67903 .5942 Mtetra
.658 .759 .924 r
.67903 .5942 .68621 .60195 .70138 .59766 .69424 .58971 Mtetra
.659 .755 .921 r
.69424 .58971 .70138 .59766 .71663 .59337 .70954 .5852 Mtetra
.658 .75 .918 r
.70954 .5852 .71663 .59337 .73196 .58907 .72492 .58071 Mtetra
.656 .746 .916 r
.72492 .58071 .73196 .58907 .74738 .58468 .74039 .57628 Mtetra
.654 .745 .917 r
.74039 .57628 .74738 .58468 .76287 .58016 .75595 .5719 Mtetra
.652 .749 .921 r
.75595 .5719 .76287 .58016 .77844 .57558 .7716 .56755 Mtetra
.657 .758 .924 r
.7716 .56755 .77844 .57558 .79409 .57096 .78732 .56296 Mtetra
.659 .761 .925 r
.78732 .56296 .79409 .57096 .80983 .56641 .80312 .55825 Mtetra
.66 .758 .923 r
.80312 .55825 .80983 .56641 .82567 .56188 .819 .55351 Mtetra
.657 .753 .921 r
.819 .55351 .82567 .56188 .84159 .5574 .83498 .54888 Mtetra
.655 .749 .919 r
.83498 .54888 .84159 .5574 .85762 .55299 .85106 .54428 Mtetra
.652 .745 .918 r
.85106 .54428 .85762 .55299 .87373 .54852 .86723 .53979 Mtetra
.86723 .53979 .87373 .54852 .88991 .54381 .8835 .53528 Mtetra
.657 .754 .921 r
.8835 .53528 .88991 .54381 .90617 .53902 .89984 .53054 Mtetra
.659 .757 .922 r
.89984 .53054 .90617 .53902 .92253 .53428 .91626 .52566 Mtetra
.657 .754 .921 r
.91626 .52566 .92253 .53428 .93899 .5296 .93278 .52084 Mtetra
.655 .751 .92 r
.93278 .52084 .93899 .5296 .95556 .52501 .9494 .51609 Mtetra
.652 .747 .919 r
.9494 .51609 .95556 .52501 .97222 .52034 .96613 .51144 Mtetra
.657 .749 .917 r
.36894 .6732 .37724 .68057 .39088 .67651 .38262 .6692 Mtetra
.654 .75 .921 r
.38262 .6692 .39088 .67651 .40459 .67255 .39637 .66529 Mtetra
.651 .752 .923 r
.39637 .66529 .40459 .67255 .41837 .66866 .41019 .66145 Mtetra
.654 .755 .924 r
.41019 .66145 .41837 .66866 .43221 .66484 .42408 .65748 Mtetra
.661 .754 .919 r
.42408 .65748 .43221 .66484 .44613 .66089 .43805 .65328 Mtetra
.66 .748 .915 r
.43805 .65328 .44613 .66089 .46012 .65672 .45209 .64909 Mtetra
.656 .747 .917 r
.45209 .64909 .46012 .65672 .47419 .65253 .4662 .64501 Mtetra
.653 .75 .921 r
.4662 .64501 .47419 .65253 .48833 .64845 .48038 .64102 Mtetra
.65 .753 .925 r
.48038 .64102 .48833 .64845 .50254 .64441 .49464 .6371 Mtetra
.651 .757 .927 r
.49464 .6371 .50254 .64441 .51682 .64048 .50897 .6331 Mtetra
.66 .759 .924 r
.50897 .6331 .51682 .64048 .53118 .63652 .52338 .62877 Mtetra
.658 .75 .918 r
.52338 .62877 .53118 .63652 .54561 .63244 .53787 .62449 Mtetra
.653 .745 .917 r
.53787 .62449 .54561 .63244 .56012 .62814 .55243 .62039 Mtetra
.646 .749 .924 r
.55243 .62039 .56012 .62814 .57471 .62386 .56707 .61649 Mtetra
.641 .758 .934 r
.56707 .61649 .57471 .62386 .58937 .61964 .5818 .61271 Mtetra
.636 .77 .944 r
.5818 .61271 .58937 .61964 .60412 .61547 .5966 .60897 Mtetra
.634 .783 .953 r
.5966 .60897 .60412 .61547 .61894 .61134 .6115 .60517 Mtetra
.633 .794 .96 r
.6115 .60517 .61894 .61134 .63384 .60717 .62647 .60128 Mtetra
.634 .804 .964 r
.62647 .60128 .63384 .60717 .64883 .60293 .64152 .59723 Mtetra
.642 .813 .965 r
.64152 .59723 .64883 .60293 .66389 .59861 .65665 .59287 Mtetra
.652 .816 .962 r
.65665 .59287 .66389 .59861 .67903 .5942 .67184 .58819 Mtetra
.659 .811 .957 r
.67184 .58819 .67903 .5942 .69424 .58971 .68711 .58335 Mtetra
.663 .803 .95 r
.68711 .58335 .69424 .58971 .70954 .5852 .70245 .5784 Mtetra
.666 .793 .942 r
.70245 .5784 .70954 .5852 .72492 .58071 .71788 .57341 Mtetra
.666 .779 .934 r
.71788 .57341 .72492 .58071 .74039 .57628 .73338 .56844 Mtetra
.664 .765 .926 r
.73338 .56844 .74039 .57628 .75595 .5719 .74897 .56359 Mtetra
.659 .752 .919 r
.74897 .56359 .75595 .5719 .7716 .56755 .76466 .55895 Mtetra
.654 .745 .916 r
.76466 .55895 .7716 .56755 .78732 .56296 .78045 .55447 Mtetra
.651 .748 .92 r
.78045 .55447 .78732 .56296 .80312 .55825 .79634 .55006 Mtetra
.659 .759 .924 r
.79634 .55006 .80312 .55825 .819 .55351 .81229 .5453 Mtetra
.661 .761 .924 r
.81229 .5453 .819 .55351 .83498 .54888 .82832 .54045 Mtetra
.658 .756 .922 r
.82832 .54045 .83498 .54888 .85106 .54428 .84445 .53568 Mtetra
.656 .751 .92 r
.84445 .53568 .85106 .54428 .86723 .53979 .86067 .53099 Mtetra
.653 .746 .918 r
.86067 .53099 .86723 .53979 .8835 .53528 .87701 .52641 Mtetra
.652 .745 .918 r
.87701 .52641 .8835 .53528 .89984 .53054 .89343 .52185 Mtetra
.657 .753 .921 r
.89343 .52185 .89984 .53054 .91626 .52566 .90993 .51703 Mtetra
.66 .757 .922 r
.90993 .51703 .91626 .52566 .93278 .52084 .92651 .51207 Mtetra
.657 .754 .921 r
.92651 .51207 .93278 .52084 .9494 .51609 .94319 .50718 Mtetra
.655 .75 .92 r
.94319 .50718 .9494 .51609 .96613 .51144 .95998 .50237 Mtetra
.654 .75 .92 r
.36056 .66584 .36894 .6732 .38262 .6692 .37428 .6619 Mtetra
.651 .751 .923 r
.37428 .6619 .38262 .6692 .39637 .66529 .38807 .65804 Mtetra
.653 .755 .924 r
.38807 .65804 .39637 .66529 .41019 .66145 .40194 .65408 Mtetra
.661 .754 .919 r
.40194 .65408 .41019 .66145 .42408 .65748 .41588 .64984 Mtetra
.66 .748 .915 r
.41588 .64984 .42408 .65748 .43805 .65328 .4299 .64563 Mtetra
.656 .748 .918 r
.4299 .64563 .43805 .65328 .45209 .64909 .44398 .64155 Mtetra
.651 .75 .922 r
.44398 .64155 .45209 .64909 .4662 .64501 .45813 .63758 Mtetra
.649 .754 .926 r
.45813 .63758 .4662 .64501 .48038 .64102 .47236 .63367 Mtetra
.656 .759 .925 r
.47236 .63367 .48038 .64102 .49464 .6371 .48667 .62948 Mtetra
.66 .754 .92 r
.48667 .62948 .49464 .6371 .50897 .6331 .50105 .62515 Mtetra
.654 .744 .916 r
.50105 .62515 .50897 .6331 .52338 .62877 .51551 .62104 Mtetra
.641 .748 .926 r
.51551 .62104 .52338 .62877 .53787 .62449 .53004 .61731 Mtetra
.628 .759 .941 r
.53004 .61731 .53787 .62449 .55243 .62039 .54466 .6139 Mtetra
.608 .774 .96 r
.54466 .6139 .55243 .62039 .56707 .61649 .55937 .61085 Mtetra
.579 .791 .98 r
.55937 .61085 .56707 .61649 .5818 .61271 .57417 .60818 Mtetra
.562 .822 .994 r
.57417 .60818 .5818 .61271 .5966 .60897 .58906 .60528 Mtetra
.551 .846 .998 r
.58906 .60528 .5966 .60897 .6115 .60517 .60404 .60204 Mtetra
.549 .863 .996 r
.60404 .60204 .6115 .60517 .62647 .60128 .6191 .59842 Mtetra
.558 .874 .993 r
.6191 .59842 .62647 .60128 .64152 .59723 .63423 .5944 Mtetra
.576 .882 .992 r
.63423 .5944 .64152 .59723 .65665 .59287 .64944 .59 Mtetra
.595 .889 .99 r
.64944 .59 .65665 .59287 .67184 .58819 .66471 .58521 Mtetra
.615 .894 .988 r
.66471 .58521 .67184 .58819 .68711 .58335 .68004 .58003 Mtetra
.641 .893 .985 r
.68004 .58003 .68711 .58335 .70245 .5784 .69544 .57446 Mtetra
.667 .883 .978 r
.69544 .57446 .70245 .5784 .71788 .57341 .71089 .56852 Mtetra
.686 .86 .965 r
.71089 .56852 .71788 .57341 .73338 .56844 .7264 .56235 Mtetra
.682 .823 .951 r
.7264 .56235 .73338 .56844 .74897 .56359 .74201 .55655 Mtetra
.675 .795 .938 r
.74201 .55655 .74897 .56359 .76466 .55895 .75771 .55112 Mtetra
.668 .772 .928 r
.75771 .55112 .76466 .55895 .78045 .55447 .77353 .54601 Mtetra
.658 .753 .92 r
.77353 .54601 .78045 .55447 .79634 .55006 .78945 .54127 Mtetra
.652 .744 .917 r
.78945 .54127 .79634 .55006 .81229 .5453 .80549 .53677 Mtetra
.655 .752 .921 r
.80549 .53677 .81229 .5453 .82832 .54045 .8216 .53211 Mtetra
.661 .761 .924 r
.8216 .53211 .82832 .54045 .84445 .53568 .83779 .52717 Mtetra
.66 .757 .922 r
.83779 .52717 .84445 .53568 .86067 .53099 .85406 .52227 Mtetra
.656 .752 .92 r
.85406 .52227 .86067 .53099 .87701 .52641 .87044 .51749 Mtetra
.653 .747 .919 r
.87044 .51749 .87701 .52641 .89343 .52185 .88694 .51284 Mtetra
.651 .745 .918 r
.88694 .51284 .89343 .52185 .90993 .51703 .90353 .50821 Mtetra
.657 .753 .921 r
.90353 .50821 .90993 .51703 .92651 .51207 .92018 .50329 Mtetra
.66 .757 .922 r
.92018 .50329 .92651 .51207 .94319 .50718 .93692 .49825 Mtetra
.657 .753 .921 r
.93692 .49825 .94319 .50718 .95998 .50237 .95377 .4933 Mtetra
.652 .751 .923 r
.3521 .65848 .36056 .66584 .37428 .6619 .36586 .65459 Mtetra
.652 .754 .924 r
.36586 .65459 .37428 .6619 .38807 .65804 .3797 .65067 Mtetra
.661 .755 .92 r
.3797 .65067 .38807 .65804 .40194 .65408 .39361 .64642 Mtetra
.66 .749 .915 r
.39361 .64642 .40194 .65408 .41588 .64984 .4076 .64217 Mtetra
.656 .748 .918 r
.4076 .64217 .41588 .64984 .4299 .64563 .42166 .63806 Mtetra
.651 .75 .922 r
.42166 .63806 .4299 .64563 .44398 .64155 .43578 .6341 Mtetra
.649 .754 .926 r
.43578 .6341 .44398 .64155 .45813 .63758 .44998 .63018 Mtetra
.658 .759 .924 r
.44998 .63018 .45813 .63758 .47236 .63367 .46426 .62589 Mtetra
.659 .75 .918 r
.46426 .62589 .47236 .63367 .48667 .62948 .47862 .62159 Mtetra
.646 .745 .921 r
.47862 .62159 .48667 .62948 .50105 .62515 .49305 .61773 Mtetra
.626 .752 .937 r
.49305 .61773 .50105 .62515 .51551 .62104 .50755 .6144 Mtetra
.592 .765 .961 r
.50755 .6144 .51551 .62104 .53004 .61731 .52214 .61181 Mtetra
.539 .782 .988 r
.52214 .61181 .53004 .61731 .54466 .6139 .53682 .60989 Mtetra
.501 .815 1 r
.53682 .60989 .54466 .6139 .55937 .61085 .55161 .60776 Mtetra
.488 .838 .996 r
.55161 .60776 .55937 .61085 .57417 .60818 .56648 .60516 Mtetra
.519 .853 .996 r
.56648 .60516 .57417 .60818 .58906 .60528 .58144 .60198 Mtetra
.557 .86 .997 r
.58144 .60198 .58906 .60528 .60404 .60204 .59648 .59833 Mtetra
.587 .86 .995 r
.59648 .59833 .60404 .60204 .6191 .59842 .6116 .59432 Mtetra
.607 .856 .991 r
.6116 .59432 .6191 .59842 .63423 .5944 .6268 .59006 Mtetra
.619 .853 .987 r
.6268 .59006 .63423 .5944 .64944 .59 .64208 .58563 Mtetra
.625 .855 .986 r
.64208 .58563 .64944 .59 .66471 .58521 .65743 .581 Mtetra
.631 .863 .986 r
.65743 .581 .66471 .58521 .68004 .58003 .67286 .57613 Mtetra
.637 .876 .986 r
.67286 .57613 .68004 .58003 .69544 .57446 .68836 .57089 Mtetra
.648 .89 .984 r
.68836 .57089 .69544 .57446 .71089 .56852 .7039 .56516 Mtetra
.665 .903 .979 r
.7039 .56516 .71089 .56852 .7264 .56235 .71949 .55886 Mtetra
.684 .905 .974 r
.71949 .55886 .7264 .56235 .74201 .55655 .73513 .55205 Mtetra
.705 .881 .963 r
.73513 .55205 .74201 .55655 .75771 .55112 .75081 .54501 Mtetra
.694 .831 .948 r
.75081 .54501 .75771 .55112 .77353 .54601 .76661 .53864 Mtetra
.678 .791 .935 r
.76661 .53864 .77353 .54601 .78945 .54127 .78254 .53302 Mtetra
.665 .764 .924 r
.78254 .53302 .78945 .54127 .80549 .53677 .7986 .52794 Mtetra
.654 .746 .918 r
.7986 .52794 .80549 .53677 .8216 .53211 .81478 .52331 Mtetra
.653 .748 .92 r
.81478 .52331 .8216 .53211 .83779 .52717 .83106 .51866 Mtetra
.661 .76 .923 r
.83106 .51866 .83779 .52717 .85406 .52227 .8474 .51363 Mtetra
.66 .758 .922 r
.8474 .51363 .85406 .52227 .87044 .51749 .86383 .50863 Mtetra
.656 .752 .92 r
.86383 .50863 .87044 .51749 .88694 .51284 .88037 .50379 Mtetra
.652 .746 .919 r
.88037 .50379 .88694 .51284 .90353 .50821 .89703 .49908 Mtetra
.89703 .49908 .90353 .50821 .92018 .50329 .91378 .49437 Mtetra
.659 .755 .921 r
.91378 .49437 .92018 .50329 .93692 .49825 .9306 .48931 Mtetra
.659 .756 .922 r
.9306 .48931 .93692 .49825 .95377 .4933 .9475 .48421 Mtetra
.651 .752 .924 r
.34355 .65111 .3521 .65848 .36586 .65459 .35736 .6472 Mtetra
.659 .755 .921 r
.35736 .6472 .36586 .65459 .3797 .65067 .37125 .64301 Mtetra
.661 .75 .915 r
.37125 .64301 .3797 .65067 .39361 .64642 .38521 .63871 Mtetra
.656 .748 .917 r
.38521 .63871 .39361 .64642 .4076 .64217 .39924 .63456 Mtetra
.651 .75 .922 r
.39924 .63456 .4076 .64217 .42166 .63806 .41334 .63057 Mtetra
.648 .753 .926 r
.41334 .63057 .42166 .63806 .43578 .6341 .42751 .62664 Mtetra
.659 .758 .923 r
.42751 .62664 .43578 .6341 .44998 .63018 .44176 .62232 Mtetra
.658 .749 .917 r
.44176 .62232 .44998 .63018 .46426 .62589 .45609 .61804 Mtetra
.639 .745 .925 r
.45609 .61804 .46426 .62589 .47862 .62159 .47048 .61437 Mtetra
.611 .754 .947 r
.47048 .61437 .47862 .62159 .49305 .61773 .48495 .61144 Mtetra
.541 .758 .977 r
.48495 .61144 .49305 .61773 .50755 .6144 .4995 .60985 Mtetra
.479 .788 .999 r
.4995 .60985 .50755 .6144 .52214 .61181 .51414 .60843 Mtetra
.462 .818 .997 r
.51414 .60843 .52214 .61181 .53682 .60989 .52889 .60643 Mtetra
.52 .84 .999 r
.52889 .60643 .53682 .60989 .55161 .60776 .54373 .60357 Mtetra
.589 .844 .993 r
.54373 .60357 .55161 .60776 .56648 .60516 .55866 .59986 Mtetra
.639 .826 .972 r
.55866 .59986 .56648 .60516 .58144 .60198 .57367 .59543 Mtetra
.674 .799 .942 r
.57367 .59543 .58144 .60198 .59648 .59833 .58874 .59018 Mtetra
.674 .758 .914 r
.58874 .59018 .59648 .59833 .6116 .59432 .60389 .585 Mtetra
.666 .729 .896 r
.60389 .585 .6116 .59432 .6268 .59006 .61912 .58012 Mtetra
.656 .713 .89 r
.61912 .58012 .6268 .59006 .64208 .58563 .63445 .57563 Mtetra
.646 .709 .893 r
.63445 .57563 .64208 .58563 .65743 .581 .64987 .57154 Mtetra
.638 .719 .906 r
.64987 .57154 .65743 .581 .67286 .57613 .6654 .56775 Mtetra
.631 .744 .929 r
.6654 .56775 .67286 .57613 .68836 .57089 .68103 .56404 Mtetra
.647 .792 .952 r
.68103 .56404 .68836 .57089 .7039 .56516 .69671 .5595 Mtetra
.66 .833 .966 r
.69671 .5595 .7039 .56516 .71949 .55886 .71244 .55423 Mtetra
.676 .87 .972 r
.71244 .55423 .71949 .55886 .73513 .55205 .7282 .54808 Mtetra
.695 .897 .97 r
.7282 .54808 .73513 .55205 .75081 .54501 .74397 .54105 Mtetra
.714 .902 .963 r
.74397 .54105 .75081 .54501 .76661 .53864 .75977 .5334 Mtetra
.718 .867 .952 r
.75977 .5334 .76661 .53864 .78254 .53302 .77565 .52592 Mtetra
.688 .806 .938 r
.77565 .52592 .78254 .53302 .7986 .52794 .7917 .51979 Mtetra
.67 .772 .927 r
.7917 .51979 .7986 .52794 .81478 .52331 .80789 .51441 Mtetra
.654 .749 .919 r
.80789 .51441 .81478 .52331 .83106 .51866 .82423 .50967 Mtetra
.653 .747 .919 r
.82423 .50967 .83106 .51866 .8474 .51363 .84067 .50496 Mtetra
.662 .76 .923 r
.84067 .50496 .8474 .51363 .86383 .50863 .85716 .49984 Mtetra
.66 .757 .922 r
.85716 .49984 .86383 .50863 .88037 .50379 .87376 .49477 Mtetra
.655 .751 .92 r
.87376 .49477 .88037 .50379 .89703 .49908 .89047 .48987 Mtetra
.651 .746 .919 r
.89047 .48987 .89703 .49908 .91378 .49437 .90729 .48512 Mtetra
.653 .747 .919 r
.90729 .48512 .91378 .49437 .9306 .48931 .9242 .48025 Mtetra
.66 .756 .921 r
.9242 .48025 .9306 .48931 .9475 .48421 .94118 .47507 Mtetra
.655 .754 .923 r
.33492 .64369 .34355 .65111 .35736 .6472 .34878 .6396 Mtetra
.662 .752 .917 r
.34878 .6396 .35736 .6472 .37125 .64301 .36272 .63525 Mtetra
.658 .748 .917 r
.36272 .63525 .37125 .64301 .38521 .63871 .37672 .63103 Mtetra
.652 .75 .921 r
.37672 .63103 .38521 .63871 .39924 .63456 .39079 .62698 Mtetra
.647 .752 .926 r
.39079 .62698 .39924 .63456 .41334 .63057 .40493 .62306 Mtetra
.658 .758 .924 r
.40493 .62306 .41334 .63057 .42751 .62664 .41916 .61877 Mtetra
.658 .749 .917 r
.41916 .61877 .42751 .62664 .44176 .62232 .43346 .61445 Mtetra
.636 .744 .926 r
.43346 .61445 .44176 .62232 .45609 .61804 .44782 .61086 Mtetra
.598 .752 .951 r
.44782 .61086 .45609 .61804 .47048 .61437 .46224 .60824 Mtetra
.503 .75 .984 r
.46224 .60824 .47048 .61437 .48495 .61144 .47674 .60728 Mtetra
.438 .784 .998 r
.47674 .60728 .48495 .61144 .4995 .60985 .49134 .60617 Mtetra
.484 .819 .999 r
.49134 .60617 .4995 .60985 .51414 .60843 .50605 .60404 Mtetra
.582 .835 .993 r
.50605 .60404 .51414 .60843 .52889 .60643 .52086 .60058 Mtetra
.674 .818 .952 r
.52086 .60058 .52889 .60643 .54373 .60357 .53575 .59527 Mtetra
.705 .761 .896 r
.53575 .59527 .54373 .60357 .55866 .59986 .55071 .58877 Mtetra
.697 .702 .851 r
.55071 .58877 .55866 .59986 .57367 .59543 .56573 .58215 Mtetra
.683 .663 .824 r
.56573 .58215 .57367 .59543 .58874 .59018 .58082 .57581 Mtetra
.671 .644 .815 r
.58082 .57581 .58874 .59018 .60389 .585 .59599 .56995 Mtetra
.659 .631 .811 r
.59599 .56995 .60389 .585 .61912 .58012 .61124 .56472 Mtetra
.647 .622 .811 r
.61124 .56472 .61912 .58012 .63445 .57563 .62659 .56018 Mtetra
.635 .616 .814 r
.62659 .56018 .63445 .57563 .64987 .57154 .64205 .55633 Mtetra
.624 .614 .821 r
.64205 .55633 .64987 .57154 .6654 .56775 .65763 .55311 Mtetra
.615 .618 .831 r
.65763 .55311 .6654 .56775 .68103 .56404 .67333 .55039 Mtetra
.608 .63 .848 r
.67333 .55039 .68103 .56404 .69671 .5595 .68915 .54796 Mtetra
.608 .667 .882 r
.68915 .54796 .69671 .5595 .71244 .55423 .70507 .54542 Mtetra
.63 .738 .925 r
.70507 .54542 .71244 .55423 .7282 .54808 .72104 .54168 Mtetra
.672 .819 .954 r
.72104 .54168 .7282 .54808 .74397 .54105 .73698 .53605 Mtetra
.702 .87 .961 r
.73698 .53605 .74397 .54105 .75977 .5334 .75292 .52905 Mtetra
.726 .897 .956 r
.75292 .52905 .75977 .5334 .77565 .52592 .76884 .52099 Mtetra
.734 .883 .949 r
.76884 .52099 .77565 .52592 .7917 .51979 .78482 .51276 Mtetra
.696 .814 .938 r
.78482 .51276 .7917 .51979 .80789 .51441 .801 .5062 Mtetra
.672 .775 .927 r
.801 .5062 .80789 .51441 .82423 .50967 .81734 .50065 Mtetra
.654 .749 .92 r
.81734 .50065 .82423 .50967 .84067 .50496 .83384 .49584 Mtetra
.654 .748 .919 r
.83384 .49584 .84067 .50496 .85716 .49984 .85043 .49101 Mtetra
.662 .76 .922 r
.85043 .49101 .85716 .49984 .87376 .49477 .86708 .48578 Mtetra
.659 .755 .921 r
.86708 .48578 .87376 .49477 .89047 .48987 .88385 .48068 Mtetra
.654 .75 .92 r
.88385 .48068 .89047 .48987 .90729 .48512 .90073 .47575 Mtetra
.65 .745 .919 r
.90073 .47575 .90729 .48512 .9242 .48025 .91772 .47095 Mtetra
.656 .751 .919 r
.91772 .47095 .9242 .48025 .94118 .47507 .93479 .46587 Mtetra
.661 .754 .919 r
.32621 .63617 .33492 .64369 .34878 .6396 .34012 .63183 Mtetra
.66 .749 .916 r
.34012 .63183 .34878 .6396 .36272 .63525 .3541 .62751 Mtetra
.655 .749 .919 r
.3541 .62751 .36272 .63525 .37672 .63103 .36815 .62336 Mtetra
.648 .75 .924 r
.36815 .62336 .37672 .63103 .39079 .62698 .38225 .61943 Mtetra
.654 .756 .925 r
.38225 .61943 .39079 .62698 .40493 .62306 .39645 .61524 Mtetra
.66 .752 .918 r
.39645 .61524 .40493 .62306 .41916 .61877 .41073 .61082 Mtetra
.639 .744 .925 r
.41073 .61082 .41916 .61877 .43346 .61445 .42506 .60714 Mtetra
.595 .749 .951 r
.42506 .60714 .43346 .61445 .44782 .61086 .43944 .6046 Mtetra
.485 .74 .984 r
.43944 .6046 .44782 .61086 .46224 .60824 .45387 .60398 Mtetra
.422 .775 .996 r
.45387 .60398 .46224 .60824 .47674 .60728 .46842 .60313 Mtetra
.508 .816 1 r
.46842 .60313 .47674 .60728 .49134 .60617 .48309 .60089 Mtetra
.637 .825 .973 r
.48309 .60089 .49134 .60617 .50605 .60404 .49788 .59654 Mtetra
.72 .783 .902 r
.49788 .59654 .50605 .60404 .52086 .60058 .51276 .58945 Mtetra
.717 .708 .84 r
.51276 .58945 .52086 .60058 .53575 .59527 .52769 .5816 Mtetra
.704 .666 .81 r
.52769 .5816 .53575 .59527 .55071 .58877 .54268 .5737 Mtetra
.691 .644 .798 r
.54268 .5737 .55071 .58877 .56573 .58215 .55772 .5663 Mtetra
.677 .629 .795 r
.55772 .5663 .56573 .58215 .58082 .57581 .57283 .55966 Mtetra
.665 .621 .796 r
.57283 .55966 .58082 .57581 .59599 .56995 .58802 .55378 Mtetra
.654 .617 .799 r
.58802 .55378 .59599 .56995 .61124 .56472 .60329 .54858 Mtetra
.645 .613 .803 r
.60329 .54858 .61124 .56472 .62659 .56018 .61866 .54399 Mtetra
.635 .609 .806 r
.61866 .54399 .62659 .56018 .64205 .55633 .63414 .53999 Mtetra
.623 .602 .808 r
.63414 .53999 .64205 .55633 .65763 .55311 .64973 .53667 Mtetra
.609 .594 .811 r
.64973 .53667 .65763 .55311 .67333 .55039 .66546 .53414 Mtetra
.595 .59 .817 r
.66546 .53414 .67333 .55039 .68915 .54796 .68134 .53238 Mtetra
.584 .594 .828 r
.68134 .53238 .68915 .54796 .70507 .54542 .69735 .53116 Mtetra
.582 .612 .847 r
.69735 .53116 .70507 .54542 .72104 .54168 .71349 .52989 Mtetra
.593 .66 .884 r
.71349 .52989 .72104 .54168 .73698 .53605 .72971 .52786 Mtetra
.654 .767 .932 r
.72971 .52786 .73698 .53605 .75292 .52905 .74586 .52305 Mtetra
.705 .845 .95 r
.74586 .52305 .75292 .52905 .76884 .52099 .76196 .51606 Mtetra
.737 .886 .948 r
.76196 .51606 .76884 .52099 .78482 .51276 .77801 .50763 Mtetra
.744 .883 .943 r
.77801 .50763 .78482 .51276 .801 .5062 .79411 .49894 Mtetra
.699 .812 .935 r
.79411 .49894 .801 .5062 .81734 .50065 .81043 .4922 Mtetra
.67 .772 .926 r
.81043 .4922 .81734 .50065 .83384 .49584 .82693 .48664 Mtetra
.652 .747 .92 r
.82693 .48664 .83384 .49584 .85043 .49101 .8436 .48184 Mtetra
.657 .751 .919 r
.8436 .48184 .85043 .49101 .86708 .48578 .86035 .47679 Mtetra
.663 .759 .922 r
.86035 .47679 .86708 .48578 .88385 .48068 .87716 .47147 Mtetra
.657 .753 .921 r
.87716 .47147 .88385 .48068 .90073 .47575 .8941 .46637 Mtetra
.652 .748 .92 r
.8941 .46637 .90073 .47575 .91772 .47095 .91116 .46145 Mtetra
.651 .746 .919 r
.91116 .46145 .91772 .47095 .93479 .46587 .92833 .45653 Mtetra
.662 .751 .916 r
.31742 .62842 .32621 .63617 .34012 .63183 .33138 .624 Mtetra
.657 .749 .918 r
.33138 .624 .34012 .63183 .3541 .62751 .3454 .61976 Mtetra
.65 .75 .923 r
.3454 .61976 .3541 .62751 .36815 .62336 .35948 .61573 Mtetra
.648 .754 .926 r
.35948 .61573 .36815 .62336 .38225 .61943 .37364 .61173 Mtetra
.663 .757 .92 r
.37364 .61173 .38225 .61943 .39645 .61524 .38789 .6072 Mtetra
.646 .745 .921 r
.38789 .6072 .39645 .61524 .41073 .61082 .4022 .60326 Mtetra
.604 .746 .945 r
.4022 .60326 .41073 .61082 .42506 .60714 .41654 .60052 Mtetra
.49 .732 .979 r
.41654 .60052 .42506 .60714 .43944 .6046 .43092 .59995 Mtetra
.414 .76 .995 r
.43092 .59995 .43944 .6046 .45387 .60398 .44541 .59944 Mtetra
.514 .807 .999 r
.44541 .59944 .45387 .60398 .46842 .60313 .46003 .59732 Mtetra
.667 .817 .955 r
.46003 .59732 .46842 .60313 .48309 .60089 .4748 .59222 Mtetra
.734 .759 .872 r
.4748 .59222 .48309 .60089 .49788 .59654 .48968 .5841 Mtetra
.726 .69 .816 r
.48968 .5841 .49788 .59654 .51276 .58945 .50461 .57511 Mtetra
.713 .661 .797 r
.50461 .57511 .51276 .58945 .52769 .5816 .51957 .56627 Mtetra
.695 .643 .794 r
.51957 .56627 .52769 .5816 .54268 .5737 .53459 .55841 Mtetra
.672 .634 .803 r
.53459 .55841 .54268 .5737 .55772 .5663 .54967 .5522 Mtetra
.661 .645 .823 r
.54967 .5522 .55772 .5663 .57283 .55966 .56483 .54694 Mtetra
.658 .665 .845 r
.56483 .54694 .57283 .55966 .58802 .55378 .58008 .54208 Mtetra
.656 .682 .863 r
.58008 .54208 .58802 .55378 .60329 .54858 .59541 .53738 Mtetra
.656 .692 .872 r
.59541 .53738 .60329 .54858 .61866 .54399 .61082 .53273 Mtetra
.654 .691 .873 r
.61082 .53273 .61866 .54399 .63414 .53999 .62633 .52813 Mtetra
.65 .679 .865 r
.62633 .52813 .63414 .53999 .64973 .53667 .64192 .52369 Mtetra
.639 .657 .851 r
.64192 .52369 .64973 .53667 .66546 .53414 .65763 .51965 Mtetra
.619 .626 .836 r
.65763 .51965 .66546 .53414 .68134 .53238 .67347 .51658 Mtetra
.586 .593 .826 r
.67347 .51658 .68134 .53238 .69735 .53116 .6895 .5152 Mtetra
.566 .581 .828 r
.6895 .5152 .69735 .53116 .71349 .52989 .70571 .51482 Mtetra
.559 .59 .842 r
.70571 .51482 .71349 .52989 .72971 .52786 .72207 .51463 Mtetra
.572 .627 .867 r
.72207 .51463 .72971 .52786 .74586 .52305 .73851 .51356 Mtetra
.638 .732 .917 r
.73851 .51356 .74586 .52305 .76196 .51606 .75487 .50942 Mtetra
.71 .832 .94 r
.75487 .50942 .76196 .51606 .77801 .50763 .7711 .5022 Mtetra
.748 .877 .939 r
.7711 .5022 .77801 .50763 .79411 .49894 .78727 .4933 Mtetra
.747 .873 .938 r
.78727 .4933 .79411 .49894 .81043 .4922 .80351 .48445 Mtetra
.694 .801 .931 r
.80351 .48445 .81043 .4922 .82693 .48664 .82 .47782 Mtetra
.664 .764 .924 r
.82 .47782 .82693 .48664 .8436 .48184 .83669 .47243 Mtetra
.65 .745 .919 r
.83669 .47243 .8436 .48184 .86035 .47679 .85353 .46764 Mtetra
.662 .758 .921 r
.85353 .46764 .86035 .47679 .87716 .47147 .87042 .46229 Mtetra
.661 .758 .922 r
.87042 .46229 .87716 .47147 .8941 .46637 .88742 .45696 Mtetra
.655 .751 .921 r
.88742 .45696 .8941 .46637 .91116 .46145 .90453 .45185 Mtetra
.65 .746 .92 r
.90453 .45185 .91116 .46145 .92833 .45653 .92178 .44693 Mtetra
.66 .75 .916 r
.30855 .62056 .31742 .62842 .33138 .624 .32255 .61617 Mtetra
.654 .75 .92 r
.32255 .61617 .33138 .624 .3454 .61976 .33661 .61199 Mtetra
.647 .751 .925 r
.33661 .61199 .3454 .61976 .35948 .61573 .35073 .60802 Mtetra
.658 .756 .922 r
.35073 .60802 .35948 .61573 .37364 .61173 .36495 .60365 Mtetra
.655 .747 .917 r
.36495 .60365 .37364 .61173 .38789 .6072 .37924 .59935 Mtetra
.619 .743 .935 r
.37924 .59935 .38789 .6072 .4022 .60326 .39356 .5962 Mtetra
.521 .732 .97 r
.39356 .5962 .4022 .60326 .41654 .60052 .40789 .59518 Mtetra
.411 .739 .992 r
.40789 .59518 .41654 .60052 .43092 .59995 .4223 .5951 Mtetra
.493 .79 .998 r
.4223 .5951 .43092 .59995 .44541 .59944 .43687 .59346 Mtetra
.664 .812 .954 r
.43687 .59346 .44541 .59944 .46003 .59732 .45161 .58847 Mtetra
.743 .757 .864 r
.45161 .58847 .46003 .59732 .4748 .59222 .46649 .57975 Mtetra
.737 .694 .81 r
.46649 .57975 .4748 .59222 .48968 .5841 .48143 .56987 Mtetra
.721 .666 .795 r
.48143 .56987 .48968 .5841 .50461 .57511 .4964 .56038 Mtetra
.693 .65 .803 r
.4964 .56038 .50461 .57511 .51957 .56627 .5114 .5529 Mtetra
.668 .658 .831 r
.5114 .5529 .51957 .56627 .53459 .55841 .52646 .54738 Mtetra
.657 .694 .873 r
.52646 .54738 .53459 .55841 .54967 .5522 .54159 .54272 Mtetra
.646 .723 .905 r
.54159 .54272 .54967 .5522 .56483 .54694 .55682 .53854 Mtetra
.643 .749 .926 r
.55682 .53854 .56483 .54694 .58008 .54208 .57213 .53438 Mtetra
.646 .769 .938 r
.57213 .53438 .58008 .54208 .59541 .53738 .58753 .52999 Mtetra
.653 .781 .942 r
.58753 .52999 .59541 .53738 .61082 .53273 .603 .52529 Mtetra
.661 .784 .939 r
.603 .52529 .61082 .53273 .62633 .52813 .61856 .52029 Mtetra
.668 .776 .931 r
.61856 .52029 .62633 .52813 .64192 .52369 .6342 .51505 Mtetra
.668 .757 .917 r
.6342 .51505 .64192 .52369 .65763 .51965 .64992 .50983 Mtetra
.655 .726 .901 r
.64992 .50983 .65763 .51965 .67347 .51658 .66574 .50509 Mtetra
.635 .685 .88 r
.66574 .50509 .67347 .51658 .6895 .5152 .6817 .50122 Mtetra
.592 .624 .852 r
.6817 .50122 .6895 .5152 .70571 .51482 .69786 .49935 Mtetra
.55 .582 .839 r
.69786 .49935 .70571 .51482 .72207 .51463 .71427 .49955 Mtetra
.538 .582 .847 r
.71427 .49955 .72207 .51463 .73851 .51356 .73084 .50018 Mtetra
.558 .62 .87 r
.73084 .50018 .73851 .51356 .75487 .50942 .74749 .49964 Mtetra
.641 .73 .913 r
.74749 .49964 .75487 .50942 .7711 .5022 .764 .49528 Mtetra
.723 .831 .932 r
.764 .49528 .7711 .5022 .78727 .4933 .78034 .48746 Mtetra
.759 .871 .929 r
.78034 .48746 .78727 .4933 .80351 .48445 .79662 .47801 Mtetra
.737 .852 .934 r
.79662 .47801 .80351 .48445 .82 .47782 .81304 .46949 Mtetra
.685 .787 .927 r
.81304 .46949 .82 .47782 .83669 .47243 .82972 .46318 Mtetra
.656 .754 .922 r
.82972 .46318 .83669 .47243 .85353 .46764 .84661 .45805 Mtetra
.654 .746 .918 r
.84661 .45805 .85353 .46764 .87042 .46229 .86361 .45301 Mtetra
.663 .759 .921 r
.86361 .45301 .87042 .46229 .88742 .45696 .88066 .44751 Mtetra
.657 .754 .921 r
.88066 .44751 .88742 .45696 .90453 .45185 .89784 .44225 Mtetra
.652 .749 .921 r
.89784 .44225 .90453 .45185 .92178 .44693 .91515 .43719 Mtetra
.657 .749 .918 r
.29959 .61263 .30855 .62056 .32255 .61617 .31363 .60831 Mtetra
.65 .75 .923 r
.31363 .60831 .32255 .61617 .33661 .61199 .32773 .60422 Mtetra
.648 .753 .926 r
.32773 .60422 .33661 .61199 .35073 .60802 .3419 .60015 Mtetra
.662 .755 .919 r
.3419 .60015 .35073 .60802 .36495 .60365 .35617 .59557 Mtetra
.638 .745 .926 r
.35617 .59557 .36495 .60365 .37924 .59935 .37048 .59181 Mtetra
.572 .739 .955 r
.37048 .59181 .37924 .59935 .39356 .5962 .3848 .58981 Mtetra
.433 .718 .985 r
.3848 .58981 .39356 .5962 .40789 .59518 .39914 .58998 Mtetra
.451 .762 .996 r
.39914 .58998 .40789 .59518 .4223 .5951 .41362 .58918 Mtetra
.623 .804 .969 r
.41362 .58918 .4223 .5951 .43687 .59346 .4283 .58531 Mtetra
.748 .773 .874 r
.4283 .58531 .43687 .59346 .45161 .58847 .44318 .57655 Mtetra
.747 .705 .812 r
.44318 .57655 .45161 .58847 .46649 .57975 .45815 .56605 Mtetra
.732 .677 .797 r
.45815 .56605 .46649 .57975 .48143 .56987 .47313 .55589 Mtetra
.694 .66 .812 r
.47313 .55589 .48143 .56987 .4964 .56038 .48812 .54854 Mtetra
.665 .683 .856 r
.48812 .54854 .4964 .56038 .5114 .5529 .50315 .54339 Mtetra
.639 .72 .907 r
.50315 .54339 .5114 .5529 .52646 .54738 .51825 .53948 Mtetra
.62 .754 .942 r
.51825 .53948 .52646 .54738 .54159 .54272 .53345 .53599 Mtetra
.616 .786 .963 r
.53345 .53599 .54159 .54272 .55682 .53854 .54874 .53233 Mtetra
.627 .806 .968 r
.54874 .53233 .55682 .53854 .57213 .53438 .56411 .52816 Mtetra
.639 .81 .966 r
.56411 .52816 .57213 .53438 .58753 .52999 .57958 .52363 Mtetra
.646 .81 .962 r
.57958 .52363 .58753 .52999 .603 .52529 .59512 .51889 Mtetra
.652 .812 .96 r
.59512 .51889 .603 .52529 .61856 .52029 .61075 .51393 Mtetra
.662 .817 .958 r
.61075 .51393 .61856 .52029 .6342 .51505 .62646 .50861 Mtetra
.677 .821 .952 r
.62646 .50861 .6342 .51505 .64992 .50983 .64223 .50278 Mtetra
.684 .807 .941 r
.64223 .50278 .64992 .50983 .66574 .50509 .65808 .49676 Mtetra
.674 .772 .924 r
.65808 .49676 .66574 .50509 .6817 .50122 .67402 .49116 Mtetra
.643 .721 .905 r
.67402 .49116 .6817 .50122 .69786 .49935 .69012 .48682 Mtetra
.592 .651 .877 r
.69012 .48682 .69786 .49935 .71427 .49955 .70643 .48472 Mtetra
.53 .583 .852 r
.70643 .48472 .71427 .49955 .73084 .50018 .72304 .48552 Mtetra
.52 .581 .857 r
.72304 .48552 .73084 .50018 .74749 .49964 .73983 .48669 Mtetra
.555 .628 .88 r
.73983 .48669 .74749 .49964 .764 .49528 .75666 .48611 Mtetra
.669 .759 .917 r
.75666 .48611 .764 .49528 .78034 .48746 .77324 .48049 Mtetra
.743 .839 .924 r
.77324 .48049 .78034 .48746 .79662 .47801 .78967 .47169 Mtetra
.765 .863 .922 r
.78967 .47169 .79662 .47801 .81304 .46949 .80607 .46185 Mtetra
.714 .816 .929 r
.80607 .46185 .81304 .46949 .82972 .46318 .82272 .45425 Mtetra
.671 .77 .925 r
.82272 .45425 .82972 .46318 .84661 .45805 .83963 .44846 Mtetra
.65 .747 .92 r
.83963 .44846 .84661 .45805 .86361 .45301 .85671 .44352 Mtetra
.662 .756 .92 r
.85671 .44352 .86361 .45301 .88066 .44751 .87385 .43805 Mtetra
.661 .757 .921 r
.87385 .43805 .88066 .44751 .89784 .44225 .89108 .43258 Mtetra
.654 .751 .921 r
.89108 .43258 .89784 .44225 .91515 .43719 .90845 .42735 Mtetra
.655 .75 .92 r
.29054 .60468 .29959 .61263 .31363 .60831 .30462 .6004 Mtetra
.647 .75 .925 r
.30462 .6004 .31363 .60831 .32773 .60422 .31875 .59637 Mtetra
.656 .755 .922 r
.31875 .59637 .32773 .60422 .3419 .60015 .33299 .59198 Mtetra
.656 .748 .918 r
.33299 .59198 .3419 .60015 .35617 .59557 .34729 .5876 Mtetra
.614 .742 .937 r
.34729 .5876 .35617 .59557 .37048 .59181 .36162 .58454 Mtetra
.494 .719 .972 r
.36162 .58454 .37048 .59181 .3848 .58981 .37591 .58404 Mtetra
.41 .728 .99 r
.37591 .58404 .3848 .58981 .39914 .58998 .3903 .58414 Mtetra
.55 .784 .986 r
.3903 .58414 .39914 .58998 .41362 .58918 .40488 .58187 Mtetra
.728 .791 .902 r
.40488 .58187 .41362 .58918 .4283 .58531 .41973 .57436 Mtetra
.756 .723 .822 r
.41973 .57436 .4283 .58531 .44318 .57655 .43471 .56367 Mtetra
.747 .693 .8 r
.43471 .56367 .44318 .57655 .45815 .56605 .44973 .55268 Mtetra
.707 .674 .816 r
.44973 .55268 .45815 .56605 .47313 .55589 .46472 .54466 Mtetra
.666 .695 .867 r
.46472 .54466 .47313 .55589 .48812 .54854 .47972 .53952 Mtetra
.624 .728 .921 r
.47972 .53952 .48812 .54854 .50315 .54339 .49479 .53609 Mtetra
.599 .765 .959 r
.49479 .53609 .50315 .54339 .51825 .53948 .50995 .53305 Mtetra
.616 .796 .968 r
.50995 .53305 .51825 .53948 .53345 .53599 .52521 .52925 Mtetra
.634 .794 .959 r
.52521 .52925 .53345 .53599 .54874 .53233 .54055 .52501 Mtetra
.645 .782 .947 r
.54055 .52501 .54874 .53233 .56411 .52816 .55599 .52051 Mtetra
.65 .777 .941 r
.55599 .52051 .56411 .52816 .57958 .52363 .57152 .51585 Mtetra
.654 .775 .938 r
.57152 .51585 .57958 .52363 .59512 .51889 .58713 .51106 Mtetra
.657 .776 .937 r
.58713 .51106 .59512 .51889 .61075 .51393 .60282 .50614 Mtetra
.66 .78 .937 r
.60282 .50614 .61075 .51393 .62646 .50861 .6186 .50105 Mtetra
.666 .789 .94 r
.6186 .50105 .62646 .50861 .64223 .50278 .63446 .49571 Mtetra
.676 .806 .945 r
.63446 .49571 .64223 .50278 .65808 .49676 .65039 .48991 Mtetra
.695 .819 .941 r
.65039 .48991 .65808 .49676 .67402 .49116 .66637 .48334 Mtetra
.686 .792 .93 r
.66637 .48334 .67402 .49116 .69012 .48682 .68244 .47715 Mtetra
.644 .734 .914 r
.68244 .47715 .69012 .48682 .70643 .48472 .69869 .47269 Mtetra
.573 .654 .891 r
.69869 .47269 .70643 .48472 .72304 .48552 .71521 .47119 Mtetra
.505 .58 .864 r
.71521 .47119 .72304 .48552 .73983 .48669 .73206 .47276 Mtetra
.51 .59 .871 r
.73206 .47276 .73983 .48669 .75666 .48611 .74904 .47404 Mtetra
.583 .662 .892 r
.74904 .47404 .75666 .48611 .77324 .48049 .76596 .47208 Mtetra
.708 .794 .918 r
.76596 .47208 .77324 .48049 .78967 .47169 .78258 .46469 Mtetra
.763 .847 .914 r
.78258 .46469 .78967 .47169 .80607 .46185 .79908 .45485 Mtetra
.75 .845 .922 r
.79908 .45485 .80607 .46185 .82272 .45425 .81568 .44558 Mtetra
.689 .785 .924 r
.81568 .44558 .82272 .45425 .83963 .44846 .83258 .43896 Mtetra
.656 .754 .922 r
.83258 .43896 .83963 .44846 .85671 .44352 .84972 .43372 Mtetra
.655 .748 .918 r
.84972 .43372 .85671 .44352 .87385 .43805 .86695 .42847 Mtetra
.663 .758 .92 r
.86695 .42847 .87385 .43805 .89108 .43258 .88425 .42284 Mtetra
.656 .752 .921 r
.88425 .42284 .89108 .43258 .90845 .42735 .90169 .41746 Mtetra
.652 .75 .921 r
.2814 .59669 .29054 .60468 .30462 .6004 .29552 .59246 Mtetra
.646 .751 .926 r
.29552 .59246 .30462 .6004 .31875 .59637 .3097 .5884 Mtetra
.662 .755 .92 r
.3097 .5884 .31875 .59637 .33299 .59198 .32399 .58378 Mtetra
.644 .746 .924 r
.32399 .58378 .33299 .59198 .34729 .5876 .33832 .57978 Mtetra
.579 .737 .951 r
.33832 .57978 .34729 .5876 .36162 .58454 .35264 .57758 Mtetra
.428 .702 .979 r
.35264 .57758 .36162 .58454 .37591 .58404 .36693 .57801 Mtetra
.464 .746 .99 r
.36693 .57801 .37591 .58404 .3903 .58414 .38139 .57737 Mtetra
.657 .791 .946 r
.38139 .57737 .3903 .58414 .40488 .58187 .39612 .57263 Mtetra
.76 .755 .848 r
.39612 .57263 .40488 .58187 .41973 .57436 .41111 .56256 Mtetra
.761 .713 .807 r
.41111 .56256 .41973 .57436 .43471 .56367 .42617 .55089 Mtetra
.731 .691 .812 r
.42617 .55089 .43471 .56367 .44973 .55268 .4412 .54125 Mtetra
.676 .696 .86 r
.4412 .54125 .44973 .55268 .46472 .54466 .45619 .53556 Mtetra
.622 .726 .921 r
.45619 .53556 .46472 .54466 .47972 .53952 .47122 .53215 Mtetra
.587 .76 .961 r
.47122 .53215 .47972 .53952 .49479 .53609 .48633 .5294 Mtetra
.618 .79 .964 r
.48633 .5294 .49479 .53609 .50995 .53305 .50156 .52559 Mtetra
.638 .776 .947 r
.50156 .52559 .50995 .53305 .52521 .52925 .51687 .52135 Mtetra
.649 .769 .936 r
.51687 .52135 .52521 .52925 .54055 .52501 .53228 .51676 Mtetra
.653 .763 .93 r
.53228 .51676 .54055 .52501 .55599 .52051 .54777 .51205 Mtetra
.655 .759 .926 r
.54777 .51205 .55599 .52051 .57152 .51585 .56336 .50726 Mtetra
.656 .758 .925 r
.56336 .50726 .57152 .51585 .58713 .51106 .57903 .50242 Mtetra
.57903 .50242 .58713 .51106 .60282 .50614 .59479 .49753 Mtetra
.657 .76 .926 r
.59479 .49753 .60282 .50614 .6186 .50105 .61063 .49256 Mtetra
.66 .765 .928 r
.61063 .49256 .6186 .50105 .63446 .49571 .62657 .48746 Mtetra
.668 .775 .93 r
.62657 .48746 .63446 .49571 .65039 .48991 .64258 .48202 Mtetra
.678 .789 .933 r
.64258 .48202 .65039 .48991 .66637 .48334 .65866 .47613 Mtetra
.704 .815 .934 r
.65866 .47613 .66637 .48334 .68244 .47715 .67478 .46915 Mtetra
.687 .791 .929 r
.67478 .46915 .68244 .47715 .69869 .47269 .691 .46283 Mtetra
.629 .727 .918 r
.691 .46283 .69869 .47269 .71521 .47119 .70744 .45884 Mtetra
.529 .63 .895 r
.70744 .45884 .71521 .47119 .73206 .47276 .72423 .4589 Mtetra
.481 .578 .875 r
.72423 .4589 .73206 .47276 .74904 .47404 .74131 .46109 Mtetra
.519 .615 .888 r
.74131 .46109 .74904 .47404 .76596 .47208 .75846 .46165 Mtetra
.65 .729 .906 r
.75846 .46165 .76596 .47208 .78258 .46469 .77534 .45673 Mtetra
.745 .82 .91 r
.77534 .45673 .78258 .46469 .79908 .45485 .79198 .44754 Mtetra
.769 .844 .908 r
.79198 .44754 .79908 .45485 .81568 .44558 .80858 .43721 Mtetra
.71 .803 .922 r
.80858 .43721 .81568 .44558 .83258 .43896 .82549 .4296 Mtetra
.666 .764 .923 r
.82549 .4296 .83258 .43896 .84972 .43372 .84265 .42385 Mtetra
.65 .747 .92 r
.84265 .42385 .84972 .43372 .86695 .42847 .85998 .41874 Mtetra
.664 .757 .92 r
.85998 .41874 .86695 .42847 .88425 .42284 .87735 .41303 Mtetra
.659 .755 .921 r
.87735 .41303 .88425 .42284 .90169 .41746 .89485 .40751 Mtetra
.65 .75 .923 r
.27217 .58864 .2814 .59669 .29552 .59246 .28632 .58445 Mtetra
.649 .752 .925 r
.28632 .58445 .29552 .59246 .3097 .5884 .30055 .58025 Mtetra
.662 .753 .918 r
.30055 .58025 .3097 .5884 .32399 .58378 .31489 .57558 Mtetra
.628 .744 .93 r
.31489 .57558 .32399 .58378 .33832 .57978 .32924 .57203 Mtetra
.527 .722 .963 r
.32924 .57203 .33832 .57978 .35264 .57758 .34354 .57095 Mtetra
.408 .705 .983 r
.34354 .57095 .35264 .57758 .36693 .57801 .35787 .57145 Mtetra
.535 .761 .98 r
.35787 .57145 .36693 .57801 .38139 .57737 .37243 .56969 Mtetra
.727 .784 .898 r
.37243 .56969 .38139 .57737 .39612 .57263 .38732 .56214 Mtetra
.769 .735 .822 r
.38732 .56214 .39612 .57263 .41111 .56256 .40241 .55065 Mtetra
.76 .712 .807 r
.40241 .55065 .41111 .56256 .42617 .55089 .41753 .539 Mtetra
.702 .697 .842 r
.41753 .539 .42617 .55089 .4412 .54125 .43255 .53172 Mtetra
.641 .724 .908 r
.43255 .53172 .4412 .54125 .45619 .53556 .44755 .52765 Mtetra
.584 .745 .954 r
.44755 .52765 .45619 .53556 .47122 .53215 .46261 .5251 Mtetra
.61 .779 .962 r
.46261 .5251 .47122 .53215 .48633 .5294 .4778 .52159 Mtetra
.637 .768 .942 r
.4778 .52159 .48633 .5294 .50156 .52559 .49308 .51739 Mtetra
.65 .763 .932 r
.49308 .51739 .50156 .52559 .51687 .52135 .50845 .51278 Mtetra
.653 .756 .925 r
.50845 .51278 .51687 .52135 .53228 .51676 .52392 .50809 Mtetra
.65 .754 .925 r
.52392 .50809 .53228 .51676 .54777 .51205 .53947 .50348 Mtetra
.652 .758 .927 r
.53947 .50348 .54777 .51205 .56336 .50726 .55511 .49874 Mtetra
.655 .762 .928 r
.55511 .49874 .56336 .50726 .57903 .50242 .57084 .49385 Mtetra
.659 .763 .927 r
.57084 .49385 .57903 .50242 .59479 .49753 .58666 .48881 Mtetra
.661 .761 .924 r
.58666 .48881 .59479 .49753 .61063 .49256 .60257 .48364 Mtetra
.659 .756 .922 r
.60257 .48364 .61063 .49256 .62657 .48746 .61857 .47855 Mtetra
.66 .758 .923 r
.61857 .47855 .62657 .48746 .64258 .48202 .63465 .47337 Mtetra
.67 .769 .925 r
.63465 .47337 .64258 .48202 .65866 .47613 .65081 .46777 Mtetra
.686 .783 .924 r
.65081 .46777 .65866 .47613 .67478 .46915 .66704 .46147 Mtetra
.709 .808 .927 r
.66704 .46147 .67478 .46915 .691 .46283 .68329 .45417 Mtetra
.671 .773 .927 r
.68329 .45417 .691 .46283 .70744 .45884 .69971 .44843 Mtetra
.587 .7 .921 r
.69971 .44843 .70744 .45884 .72423 .4589 .7164 .44596 Mtetra
.472 .592 .892 r
.7164 .44596 .72423 .4589 .74131 .46109 .73351 .448 Mtetra
.478 .593 .89 r
.73351 .448 .74131 .46109 .75846 .46165 .75079 .44992 Mtetra
.582 .673 .902 r
.75079 .44992 .75846 .46165 .77534 .45673 .76795 .4478 Mtetra
.721 .792 .908 r
.76795 .4478 .77534 .45673 .79198 .44754 .78476 .43966 Mtetra
.769 .832 .9 r
.78476 .43966 .79198 .44754 .80858 .43721 .80144 .42917 Mtetra
.737 .821 .917 r
.80144 .42917 .80858 .43721 .82549 .4296 .81832 .42028 Mtetra
.678 .772 .922 r
.81832 .42028 .82549 .4296 .84265 .42385 .83551 .41397 Mtetra
.65 .749 .922 r
.83551 .41397 .84265 .42385 .85998 .41874 .85292 .4088 Mtetra
.661 .754 .918 r
.85292 .4088 .85998 .41874 .87735 .41303 .87038 .40314 Mtetra
.661 .756 .92 r
.87038 .40314 .87735 .41303 .89485 .40751 .88794 .39745 Mtetra
.648 .75 .924 r
.26284 .58051 .27217 .58864 .28632 .58445 .27703 .57634 Mtetra
.654 .753 .922 r
.27703 .57634 .28632 .58445 .30055 .58025 .29132 .57194 Mtetra
.658 .75 .918 r
.29132 .57194 .30055 .58025 .31489 .57558 .3057 .56738 Mtetra
.613 .741 .937 r
.3057 .56738 .31489 .57558 .32924 .57203 .32007 .56425 Mtetra
.481 .706 .968 r
.32007 .56425 .32924 .57203 .34354 .57095 .33436 .56403 Mtetra
.432 .71 .982 r
.33436 .56403 .34354 .57095 .35787 .57145 .34874 .56424 Mtetra
.598 .766 .96 r
.34874 .56424 .35787 .57145 .37243 .56969 .3634 .56122 Mtetra
.76 .772 .863 r
.3634 .56122 .37243 .56969 .38732 .56214 .37845 .55146 Mtetra
.776 .735 .815 r
.37845 .55146 .38732 .56214 .40241 .55065 .39363 .53917 Mtetra
.749 .718 .822 r
.39363 .53917 .40241 .55065 .41753 .539 .40876 .52872 Mtetra
.679 .721 .881 r
.40876 .52872 .41753 .539 .43255 .53172 .42378 .52299 Mtetra
.601 .732 .936 r
.42378 .52299 .43255 .53172 .44755 .52765 .43881 .5201 Mtetra
.589 .759 .959 r
.43881 .5201 .44755 .52765 .46261 .5251 .45393 .51724 Mtetra
.629 .765 .944 r
.45393 .51724 .46261 .5251 .4778 .52159 .46917 .51328 Mtetra
.648 .761 .931 r
.46917 .51328 .4778 .52159 .49308 .51739 .48451 .50872 Mtetra
.65 .753 .925 r
.48451 .50872 .49308 .51739 .50845 .51278 .49994 .50411 Mtetra
.645 .753 .928 r
.49994 .50411 .50845 .51278 .52392 .50809 .51547 .49962 Mtetra
.649 .76 .931 r
.51547 .49962 .52392 .50809 .53947 .50348 .53108 .49498 Mtetra
.653 .762 .93 r
.53108 .49498 .53947 .50348 .55511 .49874 .54678 .49014 Mtetra
.655 .762 .928 r
.54678 .49014 .55511 .49874 .57084 .49385 .56257 .4852 Mtetra
.657 .762 .927 r
.56257 .4852 .57084 .49385 .58666 .48881 .57845 .48015 Mtetra
.662 .765 .927 r
.57845 .48015 .58666 .48881 .60257 .48364 .59442 .47492 Mtetra
.665 .766 .925 r
.59442 .47492 .60257 .48364 .61857 .47855 .61048 .46951 Mtetra
.661 .758 .922 r
.61048 .46951 .61857 .47855 .63465 .47337 .62663 .46423 Mtetra
.662 .757 .921 r
.62663 .46423 .63465 .47337 .65081 .46777 .64287 .4589 Mtetra
.676 .77 .921 r
.64287 .4589 .65081 .46777 .66704 .46147 .65917 .45295 Mtetra
.703 .788 .917 r
.65917 .45295 .66704 .46147 .68329 .45417 .67552 .44587 Mtetra
.701 .794 .922 r
.67552 .44587 .68329 .45417 .69971 .44843 .69194 .43882 Mtetra
.629 .739 .926 r
.69194 .43882 .69971 .44843 .7164 .44596 .70861 .43465 Mtetra
.493 .638 .919 r
.70861 .43465 .7164 .44596 .73351 .448 .72568 .43535 Mtetra
.446 .586 .899 r
.72568 .43535 .73351 .448 .75079 .44992 .74305 .43797 Mtetra
.519 .64 .909 r
.74305 .43797 .75079 .44992 .76795 .4478 .76042 .43803 Mtetra
.692 .765 .908 r
.76042 .43803 .76795 .4478 .78476 .43966 .7774 .43111 Mtetra
.762 .816 .895 r
.7774 .43111 .78476 .43966 .80144 .42917 .7942 .42081 Mtetra
.755 .821 .904 r
.7942 .42081 .80144 .42917 .81832 .42028 .81108 .41092 Mtetra
.69 .778 .918 r
.81108 .41092 .81832 .42028 .83551 .41397 .82831 .40405 Mtetra
.654 .752 .922 r
.82831 .40405 .83551 .41397 .85292 .4088 .84577 .39867 Mtetra
.658 .75 .918 r
.84577 .39867 .85292 .4088 .87038 .40314 .86332 .39311 Mtetra
.663 .756 .92 r
.86332 .39311 .87038 .40314 .88794 .39745 .88096 .3873 Mtetra
.647 .75 .924 r
.25342 .5723 .26284 .58051 .27703 .57634 .26766 .56813 Mtetra
.657 .753 .921 r
.26766 .56813 .27703 .57634 .29132 .57194 .282 .56357 Mtetra
.653 .749 .92 r
.282 .56357 .29132 .57194 .3057 .56738 .29641 .55914 Mtetra
.599 .738 .942 r
.29641 .55914 .3057 .56738 .32007 .56425 .3108 .55636 Mtetra
.448 .691 .969 r
.3108 .55636 .32007 .56425 .33436 .56403 .32509 .55671 Mtetra
.464 .715 .977 r
.32509 .55671 .33436 .56403 .34874 .56424 .33954 .55651 Mtetra
.654 .77 .934 r
.33954 .55651 .34874 .56424 .3634 .56122 .35432 .55186 Mtetra
.769 .757 .842 r
.35432 .55186 .3634 .56122 .37845 .55146 .36948 .54098 Mtetra
.781 .74 .816 r
.36948 .54098 .37845 .55146 .39363 .53917 .38474 .52838 Mtetra
.735 .727 .844 r
.38474 .52838 .39363 .53917 .40876 .52872 .39988 .51932 Mtetra
.654 .734 .908 r
.39988 .51932 .40876 .52872 .42378 .52299 .41491 .51469 Mtetra
.578 .736 .951 r
.41491 .51469 .42378 .52299 .43881 .5201 .42997 .51231 Mtetra
.611 .762 .952 r
.42997 .51231 .43881 .5201 .45393 .51724 .44516 .50887 Mtetra
.64 .758 .933 r
.44516 .50887 .45393 .51724 .46917 .51328 .46046 .50456 Mtetra
.651 .754 .925 r
.46046 .50456 .46917 .51328 .48451 .50872 .47586 .49989 Mtetra
.643 .75 .927 r
.47586 .49989 .48451 .50872 .49994 .50411 .49134 .49549 Mtetra
.647 .757 .93 r
.49134 .49549 .49994 .50411 .51547 .49962 .50692 .49089 Mtetra
.653 .758 .926 r
.50692 .49089 .51547 .49962 .53108 .49498 .52259 .48605 Mtetra
.656 .755 .923 r
.52259 .48605 .53108 .49498 .54678 .49014 .53836 .48109 Mtetra
.656 .753 .922 r
.53836 .48109 .54678 .49014 .56257 .4852 .55421 .4761 Mtetra
.656 .754 .922 r
.55421 .4761 .56257 .4852 .57845 .48015 .57015 .47107 Mtetra
.658 .756 .922 r
.57015 .47107 .57845 .48015 .59442 .47492 .58619 .46593 Mtetra
.664 .761 .923 r
.58619 .46593 .59442 .47492 .61048 .46951 .60231 .46053 Mtetra
.668 .764 .922 r
.60231 .46053 .61048 .46951 .62663 .46423 .61851 .45493 Mtetra
.661 .755 .92 r
.61851 .45493 .62663 .46423 .64287 .4589 .63482 .4496 Mtetra
.669 .76 .918 r
.63482 .4496 .64287 .4589 .65917 .45295 .65121 .4439 Mtetra
.689 .773 .915 r
.65121 .4439 .65917 .45295 .67552 .44587 .66765 .43731 Mtetra
.714 .794 .914 r
.66765 .43731 .67552 .44587 .69194 .43882 .68412 .42963 Mtetra
.659 .762 .926 r
.68412 .42963 .69194 .43882 .70861 .43465 .70079 .42424 Mtetra
.531 .68 .933 r
.70079 .42424 .70861 .43465 .72568 .43535 .71783 .4234 Mtetra
.424 .591 .912 r
.71783 .4234 .72568 .43535 .74305 .43797 .73525 .42623 Mtetra
.481 .628 .916 r
.73525 .42623 .74305 .43797 .76042 .43803 .75274 .42732 Mtetra
.655 .733 .907 r
.75274 .42732 .76042 .43803 .7774 .43111 .76993 .42197 Mtetra
.753 .803 .893 r
.76993 .42197 .7774 .43111 .7942 .42081 .78684 .412 Mtetra
.765 .815 .893 r
.78684 .412 .7942 .42081 .81108 .41092 .80376 .40142 Mtetra
.699 .78 .914 r
.80376 .40142 .81108 .41092 .82831 .40405 .82102 .39408 Mtetra
.658 .755 .922 r
.82102 .39408 .82831 .40405 .84577 .39867 .83854 .38845 Mtetra
.655 .75 .92 r
.83854 .38845 .84577 .39867 .86332 .39311 .85619 .38295 Mtetra
.664 .756 .919 r
.85619 .38295 .86332 .39311 .88096 .3873 .8739 .37703 Mtetra
.646 .749 .924 r
.2439 .56401 .25342 .5723 .26766 .56813 .25818 .55982 Mtetra
.659 .753 .92 r
.25818 .55982 .26766 .56813 .282 .56357 .27258 .55514 Mtetra
.649 .749 .923 r
.27258 .55514 .282 .56357 .29641 .55914 .28703 .55081 Mtetra
.587 .734 .945 r
.28703 .55081 .29641 .55914 .3108 .55636 .30143 .54831 Mtetra
.433 .682 .968 r
.30143 .54831 .3108 .55636 .32509 .55671 .31575 .54893 Mtetra
.492 .716 .97 r
.31575 .54893 .32509 .55671 .33954 .55651 .33025 .54834 Mtetra
.685 .769 .915 r
.33025 .54834 .33954 .55651 .35432 .55186 .34515 .54251 Mtetra
.777 .76 .837 r
.34515 .54251 .35432 .55186 .36948 .54098 .36041 .53093 Mtetra
.784 .749 .821 r
.36041 .53093 .36948 .54098 .38474 .52838 .37573 .51831 Mtetra
.723 .739 .865 r
.37573 .51831 .38474 .52838 .39988 .51932 .39088 .51026 Mtetra
.632 .737 .924 r
.39088 .51026 .39988 .51932 .41491 .51469 .40594 .50633 Mtetra
.576 .737 .952 r
.40594 .50633 .41491 .51469 .42997 .51231 .42105 .50394 Mtetra
.623 .753 .94 r
.42105 .50394 .42997 .51231 .44516 .50887 .4363 .50018 Mtetra
.646 .754 .928 r
.4363 .50018 .44516 .50887 .46046 .50456 .45166 .49565 Mtetra
.647 .75 .925 r
.45166 .49565 .46046 .50456 .47586 .49989 .46711 .49108 Mtetra
.642 .752 .929 r
.46711 .49108 .47586 .49989 .49134 .49549 .48265 .48665 Mtetra
.651 .755 .926 r
.48265 .48665 .49134 .49549 .50692 .49089 .49829 .48185 Mtetra
.657 .754 .921 r
.49829 .48185 .50692 .49089 .52259 .48605 .51402 .47683 Mtetra
.658 .751 .919 r
.51402 .47683 .52259 .48605 .53836 .48109 .52984 .47173 Mtetra
.656 .749 .918 r
.52984 .47173 .53836 .48109 .55421 .4761 .54575 .46669 Mtetra
.654 .748 .919 r
.54575 .46669 .55421 .4761 .57015 .47107 .56176 .46168 Mtetra
.655 .75 .92 r
.56176 .46168 .57015 .47107 .58619 .46593 .57786 .45661 Mtetra
.66 .755 .92 r
.57786 .45661 .58619 .46593 .60231 .46053 .59404 .45131 Mtetra
.668 .761 .92 r
.59404 .45131 .60231 .46053 .61851 .45493 .61032 .44565 Mtetra
.665 .759 .921 r
.61032 .44565 .61851 .45493 .63482 .4496 .62668 .44011 Mtetra
.665 .756 .918 r
.62668 .44011 .63482 .4496 .65121 .4439 .64314 .43452 Mtetra
.683 .766 .914 r
.64314 .43452 .65121 .4439 .66765 .43731 .65967 .42815 Mtetra
.714 .782 .906 r
.65967 .42815 .66765 .43731 .68412 .42963 .67621 .42037 Mtetra
.678 .77 .92 r
.67621 .42037 .68412 .42963 .70079 .42424 .69291 .41416 Mtetra
.563 .705 .937 r
.69291 .41416 .70079 .42424 .71783 .4234 .70994 .41216 Mtetra
.41 .602 .925 r
.70994 .41216 .71783 .4234 .73525 .42623 .72741 .41491 Mtetra
.451 .623 .926 r
.72741 .41491 .73525 .42623 .75274 .42732 .745 .4166 Mtetra
.626 .723 .917 r
.745 .4166 .75274 .42732 .76993 .42197 .76234 .41238 Mtetra
.745 .793 .891 r
.76234 .41238 .76993 .42197 .78684 .412 .77936 .40269 Mtetra
.768 .807 .884 r
.77936 .40269 .78684 .412 .80376 .40142 .79634 .39173 Mtetra
.706 .781 .91 r
.79634 .39173 .80376 .40142 .82102 .39408 .81366 .38399 Mtetra
.662 .757 .92 r
.81366 .38399 .82102 .39408 .83854 .38845 .83124 .37814 Mtetra
.653 .749 .921 r
.83124 .37814 .83854 .38845 .85619 .38295 .84897 .37265 Mtetra
.664 .756 .918 r
.84897 .37265 .85619 .38295 .8739 .37703 .86675 .36665 Mtetra
.646 .749 .924 r
.23429 .55563 .2439 .56401 .25818 .55982 .24862 .5514 Mtetra
.66 .753 .919 r
.24862 .5514 .25818 .55982 .27258 .55514 .26306 .54665 Mtetra
.646 .749 .924 r
.26306 .54665 .27258 .55514 .28703 .55081 .27755 .54235 Mtetra
.578 .73 .946 r
.27755 .54235 .28703 .55081 .30143 .54831 .29198 .54004 Mtetra
.433 .678 .966 r
.29198 .54004 .30143 .54831 .31575 .54893 .30632 .54069 Mtetra
.509 .713 .963 r
.30632 .54069 .31575 .54893 .33025 .54834 .32088 .53986 Mtetra
.699 .767 .904 r
.32088 .53986 .33025 .54834 .34515 .54251 .33587 .53339 Mtetra
.783 .767 .838 r
.33587 .53339 .34515 .54251 .36041 .53093 .35121 .52145 Mtetra
.788 .761 .829 r
.35121 .52145 .36041 .53093 .37573 .51831 .3666 .50885 Mtetra
.716 .752 .88 r
.3666 .50885 .37573 .51831 .39088 .51026 .38179 .5013 Mtetra
.621 .738 .93 r
.38179 .5013 .39088 .51026 .40594 .50633 .39689 .49768 Mtetra
.581 .733 .947 r
.39689 .49768 .40594 .50633 .42105 .50394 .41204 .49516 Mtetra
.627 .747 .933 r
.41204 .49516 .42105 .50394 .4363 .50018 .42735 .49125 Mtetra
.648 .751 .924 r
.42735 .49125 .4363 .50018 .45166 .49565 .44276 .4866 Mtetra
.644 .748 .925 r
.44276 .4866 .45166 .49565 .46711 .49108 .45827 .48208 Mtetra
.644 .75 .927 r
.45827 .48208 .46711 .49108 .48265 .48665 .47387 .47754 Mtetra
.653 .752 .922 r
.47387 .47754 .48265 .48665 .49829 .48185 .48957 .47262 Mtetra
.659 .752 .919 r
.48957 .47262 .49829 .48185 .51402 .47683 .50535 .46746 Mtetra
.658 .75 .918 r
.50535 .46746 .51402 .47683 .52984 .47173 .52123 .46231 Mtetra
.656 .749 .919 r
.52123 .46231 .52984 .47173 .54575 .46669 .53721 .4572 Mtetra
.654 .748 .919 r
.53721 .4572 .54575 .46669 .56176 .46168 .55327 .45216 Mtetra
.653 .749 .92 r
.55327 .45216 .56176 .46168 .57786 .45661 .56943 .44712 Mtetra
.658 .752 .919 r
.56943 .44712 .57786 .45661 .59404 .45131 .58569 .44183 Mtetra
.667 .757 .917 r
.58569 .44183 .59404 .45131 .61032 .44565 .60202 .43616 Mtetra
.667 .758 .918 r
.60202 .43616 .61032 .44565 .62668 .44011 .61846 .43046 Mtetra
.663 .754 .918 r
.61846 .43046 .62668 .44011 .64314 .43452 .63498 .4249 Mtetra
.681 .762 .913 r
.63498 .4249 .64314 .43452 .65967 .42815 .65158 .41856 Mtetra
.711 .774 .902 r
.65158 .41856 .65967 .42815 .67621 .42037 .6682 .41081 Mtetra
.686 .768 .914 r
.6682 .41081 .67621 .42037 .69291 .41416 .68496 .40416 Mtetra
.579 .717 .937 r
.68496 .40416 .69291 .41416 .70994 .41216 .70202 .40154 Mtetra
.398 .612 .936 r
.70202 .40154 .70994 .41216 .72741 .41491 .71953 .40415 Mtetra
.427 .626 .936 r
.71953 .40415 .72741 .41491 .745 .4166 .73719 .40611 Mtetra
.609 .723 .926 r
.73719 .40611 .745 .4166 .76234 .41238 .75464 .40244 Mtetra
.74 .786 .89 r
.75464 .40244 .76234 .41238 .77936 .40269 .77177 .39289 Mtetra
.767 .798 .878 r
.77177 .39289 .77936 .40269 .79634 .39173 .78883 .38178 Mtetra
.71 .779 .906 r
.78883 .38178 .79634 .39173 .81366 .38399 .8062 .37373 Mtetra
.664 .756 .919 r
.8062 .37373 .81366 .38399 .83124 .37814 .82386 .36774 Mtetra
.652 .749 .921 r
.82386 .36774 .83124 .37814 .84897 .37265 .84166 .36222 Mtetra
.664 .755 .918 r
.84166 .36222 .84897 .37265 .86675 .36665 .85953 .35614 Mtetra
.646 .749 .924 r
.22458 .54716 .23429 .55563 .24862 .5514 .23895 .54288 Mtetra
.66 .752 .919 r
.23895 .54288 .24862 .5514 .26306 .54665 .25345 .53808 Mtetra
.646 .749 .924 r
.25345 .53808 .26306 .54665 .27755 .54235 .26798 .53374 Mtetra
.579 .729 .945 r
.26798 .53374 .27755 .54235 .29198 .54004 .28246 .53139 Mtetra
.441 .673 .962 r
.28246 .53139 .29198 .54004 .30632 .54069 .29683 .532 Mtetra
.515 .705 .957 r
.29683 .532 .30632 .54069 .32088 .53986 .31142 .53113 Mtetra
.698 .763 .902 r
.31142 .53113 .32088 .53986 .33587 .53339 .32647 .52461 Mtetra
.786 .775 .843 r
.32647 .52461 .33587 .53339 .35121 .52145 .34188 .5126 Mtetra
.794 .775 .836 r
.34188 .5126 .35121 .52145 .3666 .50885 .35735 .49993 Mtetra
.719 .766 .89 r
.35735 .49993 .3666 .50885 .38179 .5013 .3726 .49232 Mtetra
.621 .74 .932 r
.3726 .49232 .38179 .5013 .39689 .49768 .38775 .48865 Mtetra
.584 .727 .942 r
.38775 .48865 .39689 .49768 .41204 .49516 .40295 .48608 Mtetra
.628 .742 .93 r
.40295 .48608 .41204 .49516 .42735 .49125 .4183 .48213 Mtetra
.649 .749 .923 r
.4183 .48213 .42735 .49125 .44276 .4866 .43378 .47742 Mtetra
.644 .747 .924 r
.43378 .47742 .44276 .4866 .45827 .48208 .44934 .47285 Mtetra
.44934 .47285 .45827 .48208 .47387 .47754 .46499 .46826 Mtetra
.653 .75 .921 r
.46499 .46826 .47387 .47754 .48957 .47262 .48075 .46329 Mtetra
.659 .752 .919 r
.48075 .46329 .48957 .47262 .50535 .46746 .4966 .45808 Mtetra
.658 .752 .919 r
.4966 .45808 .50535 .46746 .52123 .46231 .51254 .45286 Mtetra
.656 .751 .92 r
.51254 .45286 .52123 .46231 .53721 .4572 .52857 .44771 Mtetra
.654 .75 .921 r
.52857 .44771 .53721 .4572 .55327 .45216 .5447 .44261 Mtetra
.653 .75 .921 r
.5447 .44261 .55327 .45216 .56943 .44712 .56092 .43751 Mtetra
.658 .752 .919 r
.56092 .43751 .56943 .44712 .58569 .44183 .57724 .43216 Mtetra
.667 .755 .916 r
.57724 .43216 .58569 .44183 .60202 .43616 .59364 .42644 Mtetra
.59364 .42644 .60202 .43616 .61846 .43046 .61014 .42068 Mtetra
.663 .754 .918 r
.61014 .42068 .61846 .43046 .63498 .4249 .62673 .41506 Mtetra
.68 .76 .911 r
.62673 .41506 .63498 .4249 .65158 .41856 .6434 .40866 Mtetra
.71 .769 .898 r
.6434 .40866 .65158 .41856 .6682 .41081 .66009 .40084 Mtetra
.686 .761 .909 r
.66009 .40084 .6682 .41081 .68496 .40416 .67692 .39413 Mtetra
.579 .719 .939 r
.67692 .39413 .68496 .40416 .70202 .40154 .69404 .39146 Mtetra
.382 .619 .945 r
.69404 .39146 .70202 .40154 .71953 .40415 .71161 .39403 Mtetra
.411 .635 .947 r
.71161 .39403 .71953 .40415 .73719 .40611 .72933 .39594 Mtetra
.607 .733 .934 r
.72933 .39594 .73719 .40611 .75464 .40244 .74685 .39221 Mtetra
.739 .782 .888 r
.74685 .39221 .75464 .40244 .77177 .39289 .76405 .3826 Mtetra
.765 .79 .874 r
.76405 .3826 .77177 .39289 .78883 .38178 .7812 .37141 Mtetra
.71 .772 .901 r
.7812 .37141 .78883 .38178 .8062 .37373 .79866 .36329 Mtetra
.664 .755 .918 r
.79866 .36329 .8062 .37373 .82386 .36774 .81639 .35723 Mtetra
.652 .75 .921 r
.81639 .35723 .82386 .36774 .84166 .36222 .83428 .35165 Mtetra
.664 .755 .918 r
.83428 .35165 .84166 .36222 .85953 .35614 .85222 .3455 Mtetra
.646 .749 .924 r
.21478 .53859 .22458 .54716 .23895 .54288 .22919 .53426 Mtetra
.659 .752 .919 r
.22919 .53426 .23895 .54288 .25345 .53808 .24373 .52944 Mtetra
.649 .75 .923 r
.24373 .52944 .25345 .53808 .26798 .53374 .25832 .52497 Mtetra
.588 .73 .942 r
.25832 .52497 .26798 .53374 .28246 .53139 .27285 .52234 Mtetra
.451 .67 .957 r
.27285 .52234 .28246 .53139 .29683 .532 .28726 .52285 Mtetra
.511 .694 .951 r
.28726 .52285 .29683 .532 .31142 .53113 .30188 .52215 Mtetra
.685 .756 .906 r
.30188 .52215 .31142 .53113 .32647 .52461 .31694 .51616 Mtetra
.786 .783 .85 r
.31694 .51616 .32647 .52461 .34188 .5126 .33241 .50438 Mtetra
.8 .789 .843 r
.33241 .50438 .34188 .5126 .35735 .49993 .34797 .49154 Mtetra
.732 .782 .893 r
.34797 .49154 .35735 .49993 .3726 .49232 .36331 .48332 Mtetra
.631 .745 .93 r
.36331 .48332 .3726 .49232 .38775 .48865 .37852 .47924 Mtetra
.582 .72 .937 r
.37852 .47924 .38775 .48865 .40295 .48608 .39377 .47672 Mtetra
.626 .737 .927 r
.39377 .47672 .40295 .48608 .4183 .48213 .40917 .47281 Mtetra
.647 .746 .922 r
.40917 .47281 .4183 .48213 .43378 .47742 .4247 .46812 Mtetra
.647 .748 .923 r
.4247 .46812 .43378 .47742 .44934 .47285 .44031 .4634 Mtetra
.643 .744 .923 r
.44031 .4634 .44934 .47285 .46499 .46826 .45602 .45881 Mtetra
.652 .748 .92 r
.45602 .45881 .46499 .46826 .48075 .46329 .47184 .45385 Mtetra
.657 .751 .92 r
.47184 .45385 .48075 .46329 .4966 .45808 .48774 .44867 Mtetra
.658 .754 .921 r
.48774 .44867 .4966 .45808 .51254 .45286 .50374 .44341 Mtetra
.656 .753 .922 r
.50374 .44341 .51254 .45286 .52857 .44771 .51984 .4382 Mtetra
.654 .753 .922 r
.51984 .4382 .52857 .44771 .5447 .44261 .53603 .43303 Mtetra
.655 .753 .922 r
.53603 .43303 .5447 .44261 .56092 .43751 .55231 .42779 Mtetra
.66 .752 .918 r
.55231 .42779 .56092 .43751 .57724 .43216 .56869 .42232 Mtetra
.668 .754 .914 r
.56869 .42232 .57724 .43216 .59364 .42644 .58516 .41648 Mtetra
.665 .751 .915 r
.58516 .41648 .59364 .42644 .61014 .42068 .60173 .41076 Mtetra
.665 .754 .916 r
.60173 .41076 .61014 .42068 .62673 .41506 .61839 .405 Mtetra
.682 .758 .909 r
.61839 .405 .62673 .41506 .6434 .40866 .63512 .39845 Mtetra
.711 .765 .895 r
.63512 .39845 .6434 .40866 .66009 .40084 .65188 .39047 Mtetra
.677 .752 .907 r
.65188 .39047 .66009 .40084 .67692 .39413 .66879 .38407 Mtetra
.56 .712 .943 r
.66879 .38407 .67692 .39413 .69404 .39146 .68601 .38192 Mtetra
.361 .624 .953 r
.68601 .38192 .69404 .39146 .71161 .39403 .70364 .38454 Mtetra
.407 .652 .958 r
.70364 .38454 .71161 .39403 .72933 .39594 .7214 .38611 Mtetra
.622 .749 .938 r
.7214 .38611 .72933 .39594 .74685 .39221 .73895 .38171 Mtetra
.742 .78 .883 r
.73895 .38171 .74685 .39221 .76405 .3826 .75623 .3718 Mtetra
.761 .781 .869 r
.75623 .3718 .76405 .3826 .7812 .37141 .77346 .3606 Mtetra
.704 .763 .898 r
.77346 .3606 .7812 .37141 .79866 .36329 .79102 .35266 Mtetra
.662 .752 .917 r
.79102 .35266 .79866 .36329 .81639 .35723 .80884 .34662 Mtetra
.653 .751 .921 r
.80884 .34662 .81639 .35723 .83428 .35165 .8268 .34094 Mtetra
.664 .755 .918 r
.8268 .34094 .83428 .35165 .85222 .3455 .84483 .33474 Mtetra
.647 .749 .924 r
.20487 .52993 .21478 .53859 .22919 .53426 .21933 .52552 Mtetra
.657 .751 .919 r
.21933 .52552 .22919 .53426 .24373 .52944 .23391 .52073 Mtetra
.653 .751 .922 r
.23391 .52073 .24373 .52944 .25832 .52497 .24856 .51606 Mtetra
.6 .733 .938 r
.24856 .51606 .25832 .52497 .27285 .52234 .26316 .51306 Mtetra
.469 .675 .954 r
.26316 .51306 .27285 .52234 .28726 .52285 .27762 .51323 Mtetra
.501 .681 .946 r
.27762 .51323 .28726 .52285 .30188 .52215 .29225 .51284 Mtetra
.656 .744 .915 r
.29225 .51284 .30188 .52215 .31694 .51616 .30729 .50794 Mtetra
.78 .79 .861 r
.30729 .50794 .31694 .51616 .33241 .50438 .3228 .49674 Mtetra
.805 .803 .849 r
.3228 .49674 .33241 .50438 .34797 .49154 .33844 .48379 Mtetra
.755 .801 .89 r
.33844 .48379 .34797 .49154 .36331 .48332 .35391 .47442 Mtetra
.653 .756 .925 r
.35391 .47442 .36331 .48332 .37852 .47924 .36921 .46953 Mtetra
.585 .716 .933 r
.36921 .46953 .37852 .47924 .39377 .47672 .3845 .46692 Mtetra
.618 .727 .924 r
.3845 .46692 .39377 .47672 .40917 .47281 .39994 .46324 Mtetra
.642 .741 .921 r
.39994 .46324 .40917 .47281 .4247 .46812 .41552 .45868 Mtetra
.651 .748 .921 r
.41552 .45868 .4247 .46812 .44031 .4634 .4312 .45375 Mtetra
.643 .742 .921 r
.4312 .45375 .44031 .4634 .45602 .45881 .44696 .44909 Mtetra
.648 .743 .919 r
.44696 .44909 .45602 .45881 .47184 .45385 .46283 .44423 Mtetra
.654 .748 .919 r
.46283 .44423 .47184 .45385 .48774 .44867 .47879 .43911 Mtetra
.656 .752 .921 r
.47879 .43911 .48774 .44867 .50374 .44341 .49486 .43388 Mtetra
.656 .754 .922 r
.49486 .43388 .50374 .44341 .51984 .4382 .51101 .42861 Mtetra
.51101 .42861 .51984 .4382 .53603 .43303 .52726 .4233 Mtetra
.658 .753 .92 r
.52726 .4233 .53603 .43303 .55231 .42779 .54361 .41788 Mtetra
.664 .752 .916 r
.54361 .41788 .55231 .42779 .56869 .42232 .56005 .4122 Mtetra
.668 .75 .912 r
.56005 .4122 .56869 .42232 .58516 .41648 .57659 .40631 Mtetra
.661 .748 .915 r
.57659 .40631 .58516 .41648 .60173 .41076 .59322 .40069 Mtetra
.669 .754 .914 r
.59322 .40069 .60173 .41076 .61839 .405 .60994 .39469 Mtetra
.688 .757 .904 r
.60994 .39469 .61839 .405 .63512 .39845 .62674 .38779 Mtetra
.71 .758 .89 r
.62674 .38779 .63512 .39845 .65188 .39047 .64357 .37978 Mtetra
.659 .741 .91 r
.64357 .37978 .65188 .39047 .66879 .38407 .66059 .37409 Mtetra
.519 .698 .951 r
.66059 .37409 .66879 .38407 .68601 .38192 .67793 .373 Mtetra
.336 .629 .959 r
.67793 .373 .68601 .38192 .70364 .38454 .69562 .37563 Mtetra
.419 .677 .969 r
.69562 .37563 .70364 .38454 .7214 .38611 .7134 .37649 Mtetra
.653 .77 .935 r
.7134 .37649 .7214 .38611 .73895 .38171 .73095 .37084 Mtetra
.747 .776 .877 r
.73095 .37084 .73895 .38171 .75623 .3718 .74829 .3605 Mtetra
.754 .771 .867 r
.74829 .3605 .75623 .3718 .77346 .3606 .76563 .34954 Mtetra
.697 .758 .899 r
.76563 .34954 .77346 .3606 .79102 .35266 .78329 .34186 Mtetra
.659 .75 .918 r
.78329 .34186 .79102 .35266 .80884 .34662 .8012 .33591 Mtetra
.655 .752 .921 r
.8012 .33591 .80884 .34662 .8268 .34094 .81924 .33008 Mtetra
.664 .754 .917 r
.81924 .33008 .8268 .34094 .84483 .33474 .83735 .32384 Mtetra
.648 .749 .923 r
.19486 .52117 .20487 .52993 .21933 .52552 .20937 .51668 Mtetra
.654 .75 .92 r
.20937 .51668 .21933 .52552 .23391 .52073 .22399 .51195 Mtetra
.658 .753 .92 r
.22399 .51195 .23391 .52073 .24856 .51606 .2387 .50705 Mtetra
.613 .737 .933 r
.2387 .50705 .24856 .51606 .26316 .51306 .25337 .50361 Mtetra
.5 .686 .95 r
.25337 .50361 .26316 .51306 .27762 .51323 .26791 .50313 Mtetra
.489 .667 .942 r
.26791 .50313 .27762 .51323 .29225 .51284 .28254 .50309 Mtetra
.61 .722 .925 r
.28254 .50309 .29225 .51284 .30729 .50794 .29753 .49975 Mtetra
.765 .791 .874 r
.29753 .49975 .30729 .50794 .3228 .49674 .31305 .48954 Mtetra
.806 .814 .857 r
.31305 .48954 .3228 .49674 .33844 .48379 .32876 .47676 Mtetra
.783 .82 .882 r
.32876 .47676 .33844 .48379 .35391 .47442 .34438 .46586 Mtetra
.683 .774 .92 r
.34438 .46586 .35391 .47442 .36921 .46953 .3598 .45976 Mtetra
.603 .723 .929 r
.3598 .45976 .36921 .46953 .3845 .46692 .37516 .45653 Mtetra
.604 .711 .92 r
.37516 .45653 .3845 .46692 .39994 .46324 .39063 .45335 Mtetra
.634 .734 .92 r
.39063 .45335 .39994 .46324 .41552 .45868 .40625 .44903 Mtetra
.65 .745 .919 r
.40625 .44903 .41552 .45868 .4312 .45375 .42198 .44411 Mtetra
.65 .747 .92 r
.42198 .44411 .4312 .45375 .44696 .44909 .43781 .43913 Mtetra
.646 .74 .917 r
.43781 .43913 .44696 .44909 .46283 .44423 .45373 .43427 Mtetra
.65 .742 .917 r
.45373 .43427 .46283 .44423 .47879 .43911 .46975 .42925 Mtetra
.654 .747 .918 r
.46975 .42925 .47879 .43911 .49486 .43388 .48587 .42403 Mtetra
.656 .749 .918 r
.48587 .42403 .49486 .43388 .51101 .42861 .50209 .4187 Mtetra
.658 .75 .918 r
.50209 .4187 .51101 .42861 .52726 .4233 .5184 .41327 Mtetra
.662 .75 .915 r
.5184 .41327 .52726 .4233 .54361 .41788 .53481 .40764 Mtetra
.665 .747 .911 r
.53481 .40764 .54361 .41788 .56005 .4122 .55132 .40183 Mtetra
.662 .745 .912 r
.55132 .40183 .56005 .4122 .57659 .40631 .56792 .39614 Mtetra
.662 .751 .916 r
.56792 .39614 .57659 .40631 .59322 .40069 .58462 .3904 Mtetra
.676 .754 .91 r
.58462 .3904 .59322 .40069 .60994 .39469 .6014 .38404 Mtetra
.7 .756 .895 r
.6014 .38404 .60994 .39469 .62674 .38779 .61825 .37651 Mtetra
.697 .743 .887 r
.61825 .37651 .62674 .38779 .64357 .37978 .63518 .36901 Mtetra
.63 .73 .92 r
.63518 .36901 .64357 .37978 .66059 .37409 .65231 .36445 Mtetra
.454 .676 .96 r
.65231 .36445 .66059 .37409 .67793 .373 .66978 .36482 Mtetra
.321 .643 .967 r
.66978 .36482 .67793 .373 .69562 .37563 .68752 .36716 Mtetra
.455 .71 .977 r
.68752 .36716 .69562 .37563 .7134 .37649 .70532 .36687 Mtetra
.693 .787 .922 r
.70532 .36687 .7134 .37649 .73095 .37084 .72284 .35949 Mtetra
.751 .77 .869 r
.72284 .35949 .73095 .37084 .74829 .3605 .74023 .34867 Mtetra
.742 .76 .867 r
.74023 .34867 .74829 .3605 .76563 .34954 .7577 .33826 Mtetra
.688 .753 .901 r
.7577 .33826 .76563 .34954 .78329 .34186 .77548 .33092 Mtetra
.654 .748 .919 r
.77548 .33092 .78329 .34186 .8012 .33591 .79348 .3251 Mtetra
.657 .753 .921 r
.79348 .3251 .8012 .33591 .81924 .33008 .81159 .31908 Mtetra
.663 .753 .917 r
.81159 .31908 .81924 .33008 .83735 .32384 .82978 .31281 Mtetra
.65 .75 .923 r
.18474 .51233 .19486 .52117 .20937 .51668 .19931 .50772 Mtetra
.649 .748 .922 r
.19931 .50772 .20937 .51668 .22399 .51195 .21396 .5031 Mtetra
.662 .755 .919 r
.21396 .5031 .22399 .51195 .2387 .50705 .22873 .498 Mtetra
.629 .743 .929 r
.22873 .498 .2387 .50705 .25337 .50361 .24349 .49403 Mtetra
.54 .701 .944 r
.24349 .49403 .25337 .50361 .26791 .50313 .25814 .4926 Mtetra
.482 .656 .937 r
.25814 .4926 .26791 .50313 .28254 .50309 .27278 .49277 Mtetra
.571 .698 .928 r
.27278 .49277 .28254 .50309 .29753 .49975 .28771 .49064 Mtetra
.724 .769 .888 r
.28771 .49064 .29753 .49975 .31305 .48954 .30315 .48257 Mtetra
.799 .821 .869 r
.30315 .48257 .31305 .48954 .32876 .47676 .31891 .47046 Mtetra
.805 .838 .875 r
.31891 .47046 .32876 .47676 .34438 .46586 .33469 .4582 Mtetra
.723 .805 .916 r
.33469 .4582 .34438 .46586 .3598 .45976 .35026 .4504 Mtetra
.639 .747 .927 r
.35026 .4504 .3598 .45976 .37516 .45653 .36574 .44588 Mtetra
.596 .704 .919 r
.36574 .44588 .37516 .45653 .39063 .45335 .38124 .44291 Mtetra
.623 .72 .916 r
.38124 .44291 .39063 .45335 .40625 .44903 .39689 .43895 Mtetra
.641 .735 .917 r
.39689 .43895 .40625 .44903 .42198 .44411 .41266 .4343 Mtetra
.652 .746 .919 r
.41266 .4343 .42198 .44411 .43781 .43913 .42855 .42921 Mtetra
.653 .745 .917 r
.42855 .42921 .43781 .43913 .45373 .43427 .44454 .42404 Mtetra
.65 .739 .914 r
.44454 .42404 .45373 .43427 .46975 .42925 .46062 .41895 Mtetra
.653 .739 .913 r
.46062 .41895 .46975 .42925 .48587 .42403 .47679 .41372 Mtetra
.656 .741 .913 r
.47679 .41372 .48587 .42403 .50209 .4187 .49307 .40833 Mtetra
.659 .742 .912 r
.49307 .40833 .50209 .4187 .5184 .41327 .50945 .40279 Mtetra
.662 .742 .91 r
.50945 .40279 .5184 .41327 .53481 .40764 .52592 .3971 Mtetra
.659 .741 .911 r
.52592 .3971 .53481 .40764 .55132 .40183 .54249 .3915 Mtetra
.66 .748 .915 r
.54249 .3915 .55132 .40183 .56792 .39614 .55916 .38581 Mtetra
.67 .752 .912 r
.55916 .38581 .56792 .39614 .58462 .3904 .57592 .37967 Mtetra
.685 .75 .901 r
.57592 .37967 .58462 .3904 .6014 .38404 .59276 .37282 Mtetra
.704 .748 .886 r
.59276 .37282 .6014 .38404 .61825 .37651 .60967 .36495 Mtetra
.67 .731 .895 r
.60967 .36495 .61825 .37651 .63518 .36901 .6267 .35866 Mtetra
.58 .721 .94 r
.6267 .35866 .63518 .36901 .65231 .36445 .64396 .35571 Mtetra
.368 .657 .968 r
.64396 .35571 .65231 .36445 .66978 .36482 .66156 .35737 Mtetra
.331 .672 .976 r
.66156 .35737 .66978 .36482 .68752 .36716 .67934 .3589 Mtetra
.542 .762 .978 r
.67934 .3589 .68752 .36716 .70532 .36687 .69709 .35629 Mtetra
.719 .776 .898 r
.69709 .35629 .70532 .36687 .72284 .35949 .71462 .34754 Mtetra
.753 .762 .86 r
.71462 .34754 .72284 .35949 .74023 .34867 .73206 .33636 Mtetra
.725 .748 .87 r
.73206 .33636 .74023 .34867 .7577 .33826 .74968 .32683 Mtetra
.677 .748 .904 r
.74968 .32683 .7577 .33826 .77548 .33092 .76758 .31992 Mtetra
.65 .748 .921 r
.76758 .31992 .77548 .33092 .79348 .3251 .78567 .31418 Mtetra
.661 .756 .92 r
.78567 .31418 .79348 .3251 .81159 .31908 .80384 .30793 Mtetra
.661 .752 .917 r
.80384 .30793 .81159 .31908 .82978 .31281 .82213 .30166 Mtetra
.652 .75 .922 r
.17452 .5034 .18474 .51233 .19931 .50772 .18914 .49865 Mtetra
.646 .747 .922 r
.18914 .49865 .19931 .50772 .21396 .5031 .20383 .49409 Mtetra
.662 .753 .918 r
.20383 .49409 .21396 .5031 .22873 .498 .21865 .48894 Mtetra
.643 .748 .925 r
.21865 .48894 .22873 .498 .24349 .49403 .2335 .48442 Mtetra
.585 .719 .935 r
.2335 .48442 .24349 .49403 .25814 .4926 .24829 .48174 Mtetra
.489 .654 .933 r
.24829 .48174 .25814 .4926 .27278 .49277 .26296 .48178 Mtetra
.535 .671 .925 r
.26296 .48178 .27278 .49277 .28771 .49064 .27784 .4807 Mtetra
.661 .739 .908 r
.27784 .4807 .28771 .49064 .30315 .48257 .29315 .47541 Mtetra
.779 .82 .885 r
.29315 .47541 .30315 .48257 .31891 .47046 .3089 .46463 Mtetra
.81 .85 .88 r
.3089 .46463 .31891 .47046 .33469 .4582 .32478 .4522 Mtetra
.776 .85 .906 r
.32478 .4522 .33469 .4582 .35026 .4504 .34057 .44186 Mtetra
.684 .78 .923 r
.34057 .44186 .35026 .4504 .36574 .44588 .35619 .43557 Mtetra
.622 .724 .919 r
.35619 .43557 .36574 .44588 .38124 .44291 .37178 .43162 Mtetra
.604 .698 .909 r
.37178 .43162 .38124 .44291 .39689 .43895 .38745 .42835 Mtetra
.632 .723 .913 r
.38745 .42835 .39689 .43895 .41266 .4343 .40326 .42399 Mtetra
.643 .734 .915 r
.40326 .42399 .41266 .4343 .42855 .42921 .4192 .41917 Mtetra
.651 .744 .918 r
.4192 .41917 .42855 .42921 .44454 .42404 .43524 .414 Mtetra
.654 .746 .918 r
.43524 .414 .44454 .42404 .46062 .41895 .45138 .40869 Mtetra
.655 .743 .915 r
.45138 .40869 .46062 .41895 .47679 .41372 .46762 .4033 Mtetra
.656 .741 .913 r
.46762 .4033 .47679 .41372 .49307 .40833 .48396 .39786 Mtetra
.657 .742 .912 r
.48396 .39786 .49307 .40833 .50945 .40279 .50039 .39235 Mtetra
.658 .744 .914 r
.50039 .39235 .50945 .40279 .52592 .3971 .51693 .38676 Mtetra
.66 .749 .915 r
.51693 .38676 .52592 .3971 .54249 .3915 .53356 .38104 Mtetra
.668 .75 .911 r
.53356 .38104 .54249 .3915 .55916 .38581 .55029 .37495 Mtetra
.678 .746 .903 r
.55029 .37495 .55916 .38581 .57592 .37967 .56712 .3684 Mtetra
.699 .746 .888 r
.56712 .3684 .57592 .37967 .59276 .37282 .58401 .36073 Mtetra
.683 .726 .883 r
.58401 .36073 .59276 .37282 .60967 .36495 .60101 .35373 Mtetra
.629 .724 .916 r
.60101 .35373 .60967 .36495 .6267 .35866 .61816 .34912 Mtetra
.479 .697 .964 r
.61816 .34912 .6267 .35866 .64396 .35571 .63558 .34866 Mtetra
.3 .667 .973 r
.63558 .34866 .64396 .35571 .66156 .35737 .65325 .35038 Mtetra
.389 .72 .989 r
.65325 .35038 .66156 .35737 .67934 .3589 .67105 .35043 Mtetra
.642 .8 .958 r
.67105 .35043 .67934 .3589 .69709 .35629 .68872 .34483 Mtetra
.736 .767 .878 r
.68872 .34483 .69709 .35629 .71462 .34754 .70626 .33486 Mtetra
.748 .75 .854 r
.70626 .33486 .71462 .34754 .73206 .33636 .7238 .3237 Mtetra
.702 .735 .877 r
.7238 .3237 .73206 .33636 .74968 .32683 .74158 .31534 Mtetra
.666 .745 .909 r
.74158 .31534 .74968 .32683 .76758 .31992 .75959 .30887 Mtetra
.65 .749 .922 r
.75959 .30887 .76758 .31992 .78567 .31418 .77776 .30307 Mtetra
.664 .755 .918 r
.77776 .30307 .78567 .31418 .80384 .30793 .79601 .29663 Mtetra
.659 .751 .918 r
.79601 .29663 .80384 .30793 .82213 .30166 .81438 .29038 Mtetra
.655 .751 .921 r
.16419 .4944 .17452 .5034 .18914 .49865 .17887 .4895 Mtetra
.647 .747 .922 r
.17887 .4895 .18914 .49865 .20383 .49409 .1936 .48487 Mtetra
.657 .749 .918 r
.1936 .48487 .20383 .49409 .21865 .48894 .20846 .47986 Mtetra
.656 .753 .922 r
.20846 .47986 .21865 .48894 .2335 .48442 .2234 .47485 Mtetra
.615 .732 .929 r
.2234 .47485 .2335 .48442 .24829 .48174 .2383 .4712 Mtetra
.526 .679 .935 r
.2383 .4712 .24829 .48174 .26296 .48178 .25308 .4702 Mtetra
.511 .651 .921 r
.25308 .4702 .26296 .48178 .27784 .4807 .26794 .46981 Mtetra
.592 .699 .917 r
.26794 .46981 .27784 .4807 .29315 .47541 .28311 .46697 Mtetra
.729 .79 .901 r
.28311 .46697 .29315 .47541 .3089 .46463 .29876 .4587 Mtetra
.796 .851 .892 r
.29876 .4587 .3089 .46463 .32478 .4522 .31468 .44715 Mtetra
.804 .872 .897 r
.31468 .44715 .32478 .4522 .34057 .44186 .33065 .43527 Mtetra
.744 .838 .923 r
.33065 .43527 .34057 .44186 .35619 .43557 .34648 .42647 Mtetra
.67 .767 .923 r
.34648 .42647 .35619 .43557 .37178 .43162 .36221 .42064 Mtetra
.624 .714 .91 r
.36221 .42064 .37178 .43162 .38745 .42835 .37796 .41657 Mtetra
.614 .695 .902 r
.37796 .41657 .38745 .42835 .40326 .42399 .39379 .41289 Mtetra
.633 .717 .908 r
.39379 .41289 .40326 .42399 .4192 .41917 .40976 .40843 Mtetra
.644 .729 .911 r
.40976 .40843 .4192 .41917 .43524 .414 .42585 .4035 Mtetra
.65 .737 .914 r
.42585 .4035 .43524 .414 .45138 .40869 .44204 .39831 Mtetra
.653 .743 .915 r
.44204 .39831 .45138 .40869 .46762 .4033 .45834 .39294 Mtetra
.656 .745 .915 r
.45834 .39294 .46762 .4033 .48396 .39786 .47474 .38743 Mtetra
.659 .746 .914 r
.47474 .38743 .48396 .39786 .50039 .39235 .49124 .38179 Mtetra
.662 .746 .912 r
.49124 .38179 .50039 .39235 .51693 .38676 .50784 .37596 Mtetra
.667 .744 .907 r
.50784 .37596 .51693 .38676 .53356 .38104 .52454 .36986 Mtetra
.677 .741 .899 r
.52454 .36986 .53356 .38104 .55029 .37495 .54133 .36329 Mtetra
.692 .737 .886 r
.54133 .36329 .55029 .37495 .56712 .3684 .55821 .35592 Mtetra
.681 .72 .879 r
.55821 .35592 .56712 .3684 .58401 .36073 .57518 .34893 Mtetra
.643 .72 .903 r
.57518 .34893 .58401 .36073 .60101 .35373 .59228 .34373 Mtetra
.547 .719 .953 r
.59228 .34373 .60101 .35373 .61816 .34912 .60957 .34157 Mtetra
.354 .686 .98 r
.60957 .34157 .61816 .34912 .63558 .34866 .62712 .34257 Mtetra
.314 .704 .979 r
.62712 .34257 .63558 .34866 .65325 .35038 .64483 .34326 Mtetra
.518 .785 .993 r
.64483 .34326 .65325 .35038 .67105 .35043 .66259 .34062 Mtetra
.709 .793 .917 r
.66259 .34062 .67105 .35043 .68872 .34483 .68022 .33236 Mtetra
.743 .753 .86 r
.68022 .33236 .68872 .34483 .70626 .33486 .6978 .32155 Mtetra
.729 .735 .856 r
.6978 .32155 .70626 .33486 .7238 .3237 .71547 .31134 Mtetra
.685 .737 .89 r
.71547 .31134 .7238 .3237 .74158 .31534 .73339 .30386 Mtetra
.656 .744 .915 r
.73339 .30386 .74158 .31534 .75959 .30887 .75151 .29778 Mtetra
.655 .753 .922 r
.75151 .29778 .75959 .30887 .77776 .30307 .76975 .2917 Mtetra
.663 .752 .916 r
.76975 .2917 .77776 .30307 .79601 .29663 .78808 .28521 Mtetra
.657 .75 .919 r
.78808 .28521 .79601 .29663 .81438 .29038 .80655 .27899 Mtetra
.657 .753 .92 r
.15374 .48533 .16419 .4944 .17887 .4895 .16848 .4803 Mtetra
.65 .749 .922 r
.16848 .4803 .17887 .4895 .1936 .48487 .18327 .47551 Mtetra
.649 .747 .921 r
.18327 .47551 .1936 .48487 .20846 .47986 .19815 .47073 Mtetra
.663 .756 .92 r
.19815 .47073 .20846 .47986 .2234 .47485 .21316 .46542 Mtetra
.638 .744 .925 r
.21316 .46542 .2234 .47485 .2383 .4712 .22818 .46096 Mtetra
.582 .709 .93 r
.22818 .46096 .2383 .4712 .25308 .4702 .24314 .45831 Mtetra
.511 .646 .917 r
.24314 .45831 .25308 .4702 .26794 .46981 .25801 .45792 Mtetra
.547 .663 .913 r
.25801 .45792 .26794 .46981 .28311 .46697 .2731 .45651 Mtetra
.639 .728 .912 r
.2731 .45651 .28311 .46697 .29876 .4587 .28854 .45191 Mtetra
.76 .834 .908 r
.28854 .45191 .29876 .4587 .31468 .44715 .30442 .44222 Mtetra
.797 .878 .905 r
.30442 .44222 .31468 .44715 .33065 .43527 .32046 .43073 Mtetra
.792 .889 .915 r
.32046 .43073 .33065 .43527 .34648 .42647 .33652 .41957 Mtetra
.728 .833 .929 r
.33652 .41957 .34648 .42647 .36221 .42064 .35245 .41133 Mtetra
.671 .767 .922 r
.35245 .41133 .36221 .42064 .37796 .41657 .36834 .40537 Mtetra
.638 .718 .905 r
.36834 .40537 .37796 .41657 .39379 .41289 .38426 .4007 Mtetra
.626 .695 .894 r
.38426 .4007 .39379 .41289 .40976 .40843 .40027 .39646 Mtetra
.63 .702 .897 r
.40027 .39646 .40976 .40843 .42585 .4035 .41638 .39202 Mtetra
.643 .717 .902 r
.41638 .39202 .42585 .4035 .44204 .39831 .43263 .38705 Mtetra
.651 .726 .904 r
.43263 .38705 .44204 .39831 .45834 .39294 .44898 .38172 Mtetra
.656 .729 .904 r
.44898 .38172 .45834 .39294 .47474 .38743 .46544 .37615 Mtetra
.66 .731 .902 r
.46544 .37615 .47474 .38743 .49124 .38179 .482 .37034 Mtetra
.668 .732 .898 r
.482 .37034 .49124 .38179 .50784 .37596 .49866 .36416 Mtetra
.678 .73 .889 r
.49866 .36416 .50784 .37596 .52454 .36986 .51542 .35744 Mtetra
.68 .72 .88 r
.51542 .35744 .52454 .36986 .54133 .36329 .53227 .35052 Mtetra
.67 .711 .879 r
.53227 .35052 .54133 .36329 .55821 .35592 .54922 .34402 Mtetra
.642 .718 .903 r
.54922 .34402 .55821 .35592 .57518 .34893 .56628 .33883 Mtetra
.57 .729 .949 r
.56628 .33883 .57518 .34893 .59228 .34373 .58349 .33595 Mtetra
.403 .709 .985 r
.58349 .33595 .59228 .34373 .60957 .34157 .60092 .33608 Mtetra
.294 .709 .973 r
.60092 .33608 .60957 .34157 .62712 .34257 .61854 .33658 Mtetra
.42 .768 .996 r
.61854 .33658 .62712 .34257 .64483 .34326 .63627 .33526 Mtetra
.664 .823 .959 r
.63627 .33526 .64483 .34326 .66259 .34062 .65395 .3287 Mtetra
.731 .76 .876 r
.65395 .3287 .66259 .34062 .68022 .33236 .67159 .31883 Mtetra
.739 .736 .849 r
.67159 .31883 .68022 .33236 .6978 .32155 .68923 .30789 Mtetra
.701 .721 .865 r
.68923 .30789 .6978 .32155 .71547 .31134 .70708 .29926 Mtetra
.67 .739 .902 r
.70708 .29926 .71547 .31134 .73339 .30386 .72513 .2925 Mtetra
.65 .746 .92 r
.72513 .2925 .73339 .30386 .75151 .29778 .74335 .28661 Mtetra
.662 .757 .921 r
.74335 .28661 .75151 .29778 .76975 .2917 .76165 .28016 Mtetra
.661 .751 .916 r
.76165 .28016 .76975 .2917 .78808 .28521 .78007 .27371 Mtetra
.654 .75 .92 r
.78007 .27371 .78808 .28521 .80655 .27899 .79862 .2675 Mtetra
.66 .755 .92 r
.14318 .47623 .15374 .48533 .16848 .4803 .15798 .47104 Mtetra
.654 .751 .921 r
.15798 .47104 .16848 .4803 .18327 .47551 .17284 .46605 Mtetra
.647 .746 .921 r
.17284 .46605 .18327 .47551 .19815 .47073 .18775 .46129 Mtetra
.658 .75 .918 r
.18775 .46129 .19815 .47073 .21316 .46542 .2028 .45608 Mtetra
.655 .753 .922 r
.2028 .45608 .21316 .46542 .22818 .46096 .21793 .45096 Mtetra
.621 .73 .925 r
.21793 .45096 .22818 .46096 .24314 .45831 .23303 .44703 Mtetra
.552 .679 .923 r
.23303 .44703 .24314 .45831 .25801 .45792 .24804 .44532 Mtetra
.525 .642 .907 r
.24804 .44532 .25801 .45792 .2731 .45651 .2631 .44458 Mtetra
.576 .677 .909 r
.2631 .44458 .2731 .45651 .28854 .45191 .27841 .44221 Mtetra
.67 .756 .915 r
.27841 .44221 .28854 .45191 .30442 .44222 .29409 .43633 Mtetra
.762 .858 .921 r
.29409 .43633 .30442 .44222 .32046 .43073 .31011 .42655 Mtetra
.787 .899 .921 r
.31011 .42655 .32046 .43073 .33652 .41957 .32625 .41555 Mtetra
.778 .905 .929 r
.32625 .41555 .33652 .41957 .35245 .41133 .34241 .40496 Mtetra
.732 .849 .936 r
.34241 .40496 .35245 .41133 .36834 .40537 .3585 .39646 Mtetra
.682 .782 .926 r
.3585 .39646 .36834 .40537 .38426 .4007 .37457 .39 Mtetra
.658 .738 .909 r
.37457 .39 .38426 .4007 .40027 .39646 .39068 .38443 Mtetra
.644 .708 .894 r
.39068 .38443 .40027 .39646 .41638 .39202 .40686 .37935 Mtetra
.643 .697 .885 r
.40686 .37935 .41638 .39202 .43263 .38705 .42315 .37429 Mtetra
.647 .698 .883 r
.42315 .37429 .43263 .38705 .44898 .38172 .43955 .36898 Mtetra
.654 .702 .882 r
.43955 .36898 .44898 .38172 .46544 .37615 .45606 .36334 Mtetra
.66 .705 .88 r
.45606 .36334 .46544 .37615 .482 .37034 .47268 .35738 Mtetra
.664 .705 .877 r
.47268 .35738 .482 .37034 .49866 .36416 .48939 .35116 Mtetra
.664 .705 .878 r
.48939 .35116 .49866 .36416 .51542 .35744 .50621 .34495 Mtetra
.653 .711 .89 r
.50621 .34495 .51542 .35744 .53227 .35052 .52312 .33924 Mtetra
.631 .728 .917 r
.52312 .33924 .53227 .35052 .54922 .34402 .54014 .33443 Mtetra
.559 .738 .96 r
.54014 .33443 .54922 .34402 .56628 .33883 .5573 .3317 Mtetra
.418 .736 .991 r
.5573 .3317 .56628 .33883 .58349 .33595 .57464 .33111 Mtetra
.301 .73 .971 r
.57464 .33111 .58349 .33595 .60092 .33608 .59215 .33096 Mtetra
.388 .773 .99 r
.59215 .33096 .60092 .33608 .61854 .33658 .6098 .32959 Mtetra
.618 .833 .983 r
.6098 .32959 .61854 .33658 .63627 .33526 .62749 .32423 Mtetra
.719 .774 .896 r
.62749 .32423 .63627 .33526 .65395 .3287 .64516 .31525 Mtetra
.735 .737 .852 r
.64516 .31525 .65395 .3287 .67159 .31883 .66284 .30456 Mtetra
.716 .718 .851 r
.66284 .30456 .67159 .31883 .68923 .30789 .68062 .29485 Mtetra
.681 .726 .884 r
.68062 .29485 .68923 .30789 .70708 .29926 .69861 .28741 Mtetra
.656 .74 .912 r
.69861 .28741 .70708 .29926 .72513 .2925 .71678 .28121 Mtetra
.654 .753 .922 r
.71678 .28121 .72513 .2925 .74335 .28661 .73507 .27508 Mtetra
.664 .753 .917 r
.73507 .27508 .74335 .28661 .76165 .28016 .75344 .26848 Mtetra
.658 .749 .917 r
.75344 .26848 .76165 .28016 .78007 .27371 .77196 .2621 Mtetra
.652 .75 .921 r
.77196 .2621 .78007 .27371 .79862 .2675 .79061 .25593 Mtetra
.662 .755 .919 r
.1325 .46704 .14318 .47623 .15798 .47104 .14736 .46171 Mtetra
.657 .752 .92 r
.14736 .46171 .15798 .47104 .17284 .46605 .16228 .45657 Mtetra
.65 .749 .922 r
.16228 .45657 .17284 .46605 .18775 .46129 .17725 .45164 Mtetra
.648 .746 .92 r
.17725 .45164 .18775 .46129 .2028 .45608 .19232 .44674 Mtetra
.663 .757 .92 r
.19232 .44674 .2028 .45608 .21793 .45096 .20752 .44127 Mtetra
.645 .746 .923 r
.20752 .44127 .21793 .45096 .23303 .44703 .22275 .43642 Mtetra
.61 .717 .921 r
.22275 .43642 .23303 .44703 .24804 .44532 .23797 .43281 Mtetra
.543 .653 .907 r
.23797 .43281 .24804 .44532 .2631 .44458 .25309 .43148 Mtetra
.543 .643 .899 r
.25309 .43148 .2631 .44458 .27841 .44221 .26834 .4302 Mtetra
.591 .685 .907 r
.26834 .4302 .27841 .44221 .29409 .43633 .28384 .42723 Mtetra
.674 .774 .925 r
.28384 .42723 .29409 .43633 .31011 .42655 .29968 .42112 Mtetra
.75 .872 .936 r
.29968 .42112 .31011 .42655 .32625 .41555 .3158 .41184 Mtetra
.767 .914 .938 r
.3158 .41184 .32625 .41555 .34241 .40496 .33204 .40163 Mtetra
.76 .924 .943 r
.33204 .40163 .34241 .40496 .3585 .39646 .34832 .39158 Mtetra
.74 .889 .948 r
.34832 .39158 .3585 .39646 .37457 .39 .3646 .38255 Mtetra
.7 .824 .941 r
.3646 .38255 .37457 .39 .39068 .38443 .38086 .37524 Mtetra
.675 .779 .929 r
.38086 .37524 .39068 .38443 .40686 .37935 .39716 .36892 Mtetra
.663 .75 .915 r
.39716 .36892 .40686 .37935 .42315 .37429 .41354 .36302 Mtetra
.658 .733 .905 r
.41354 .36302 .42315 .37429 .43955 .36898 .43 .35727 Mtetra
.656 .725 .9 r
.43 .35727 .43955 .36898 .45606 .36334 .44657 .35157 Mtetra
.654 .724 .9 r
.44657 .35157 .45606 .36334 .47268 .35738 .46324 .34591 Mtetra
.649 .73 .908 r
.46324 .34591 .47268 .35738 .48939 .35116 .48 .34041 Mtetra
.638 .742 .924 r
.48 .34041 .48939 .35116 .50621 .34495 .49688 .33533 Mtetra
.604 .756 .951 r
.49688 .33533 .50621 .34495 .52312 .33924 .51385 .33125 Mtetra
.52 .763 .985 r
.51385 .33125 .52312 .33924 .54014 .33443 .53096 .32893 Mtetra
.398 .769 .993 r
.53096 .32893 .54014 .33443 .5573 .3317 .54822 .32765 Mtetra
.321 .76 .966 r
.54822 .32765 .5573 .3317 .57464 .33111 .56565 .32656 Mtetra
.4 .794 .987 r
.56565 .32656 .57464 .33111 .59215 .33096 .58322 .32454 Mtetra
.605 .843 .989 r
.58322 .32454 .59215 .33096 .6098 .32959 .60087 .31929 Mtetra
.71 .787 .912 r
.60087 .31929 .6098 .32959 .62749 .32423 .61854 .31081 Mtetra
.729 .736 .857 r
.61854 .31081 .62749 .32423 .64516 .31525 .63624 .30057 Mtetra
.721 .715 .843 r
.63624 .30057 .64516 .31525 .66284 .30456 .65401 .29036 Mtetra
.685 .709 .866 r
.65401 .29036 .66284 .30456 .68062 .29485 .67196 .28247 Mtetra
.664 .734 .902 r
.67196 .28247 .68062 .29485 .69861 .28741 .69007 .27586 Mtetra
.649 .747 .921 r
.69007 .27586 .69861 .28741 .71678 .28121 .70833 .26988 Mtetra
.662 .758 .921 r
.70833 .26988 .71678 .28121 .73507 .27508 .72668 .26331 Mtetra
.661 .75 .916 r
.72668 .26331 .73507 .27508 .75344 .26848 .74515 .25675 Mtetra
.655 .75 .919 r
.74515 .25675 .75344 .26848 .77196 .2621 .76375 .2504 Mtetra
.65 .75 .923 r
.76375 .2504 .77196 .2621 .79061 .25593 .7825 .24424 Mtetra
.661 .754 .919 r
.12172 .45771 .1325 .46704 .14736 .46171 .13662 .45238 Mtetra
.66 .755 .92 r
.13662 .45238 .14736 .46171 .16228 .45657 .1516 .44705 Mtetra
.655 .751 .921 r
.1516 .44705 .16228 .45657 .17725 .45164 .16664 .44189 Mtetra
.648 .746 .921 r
.16664 .44189 .17725 .45164 .19232 .44674 .18175 .43696 Mtetra
.654 .748 .918 r
.18175 .43696 .19232 .44674 .20752 .44127 .19698 .43175 Mtetra
.66 .756 .921 r
.19698 .43175 .20752 .44127 .22275 .43642 .21231 .42629 Mtetra
.639 .738 .921 r
.21231 .42629 .22275 .43642 .23797 .43281 .22766 .4216 Mtetra
.605 .706 .916 r
.22766 .4216 .23797 .43281 .25309 .43148 .24301 .41811 Mtetra
.548 .643 .896 r
.24301 .41811 .25309 .43148 .26834 .4302 .25829 .41664 Mtetra
.556 .644 .892 r
.25829 .41664 .26834 .4302 .28384 .42723 .27372 .41491 Mtetra
.596 .684 .903 r
.27372 .41491 .28384 .42723 .29968 .42112 .28939 .41171 Mtetra
.654 .765 .931 r
.28939 .41171 .29968 .42112 .3158 .41184 .30533 .40627 Mtetra
.724 .87 .95 r
.30533 .40627 .3158 .41184 .33204 .40163 .32154 .39794 Mtetra
.735 .916 .955 r
.32154 .39794 .33204 .40163 .34832 .39158 .33786 .3888 Mtetra
.726 .935 .956 r
.33786 .3888 .34832 .39158 .3646 .38255 .35426 .37959 Mtetra
.709 .931 .963 r
.35426 .37959 .3646 .38255 .38086 .37524 .37068 .37091 Mtetra
.698 .901 .969 r
.37068 .37091 .38086 .37524 .39716 .36892 .38714 .36302 Mtetra
.683 .863 .967 r
.38714 .36302 .39716 .36892 .41354 .36302 .40365 .35593 Mtetra
.667 .832 .963 r
.40365 .35593 .41354 .36302 .43 .35727 .42022 .34955 Mtetra
.65 .814 .962 r
.42022 .34955 .43 .35727 .44657 .35157 .43686 .34378 Mtetra
.628 .807 .968 r
.43686 .34378 .44657 .35157 .46324 .34591 .4536 .33864 Mtetra
.597 .811 .982 r
.4536 .33864 .46324 .34591 .48 .34041 .47043 .33421 Mtetra
.543 .819 .997 r
.47043 .33421 .48 .34041 .49688 .33533 .48737 .3306 Mtetra
.459 .818 .996 r
.48737 .3306 .49688 .33533 .51385 .33125 .50444 .32779 Mtetra
.37 .8 .968 r
.50444 .32779 .51385 .33125 .53096 .32893 .52164 .32553 Mtetra
.367 .8 .966 r
.52164 .32553 .53096 .32893 .54822 .32765 .539 .32323 Mtetra
.457 .827 .993 r
.539 .32323 .54822 .32765 .56565 .32656 .5565 .3201 Mtetra
.634 .853 .983 r
.5565 .3201 .56565 .32656 .58322 .32454 .5741 .31404 Mtetra
.707 .783 .911 r
.5741 .31404 .58322 .32454 .60087 .31929 .59176 .30567 Mtetra
.722 .731 .858 r
.59176 .30567 .60087 .31929 .61854 .31081 .60946 .29578 Mtetra
.719 .709 .841 r
.60946 .29578 .61854 .31081 .63624 .30057 .62723 .2856 Mtetra
.686 .698 .856 r
.62723 .2856 .63624 .30057 .65401 .29036 .64515 .27747 Mtetra
.669 .728 .894 r
.64515 .27747 .65401 .29036 .67196 .28247 .66322 .27057 Mtetra
.652 .742 .916 r
.66322 .27057 .67196 .28247 .69007 .27586 .68144 .26446 Mtetra
.657 .755 .922 r
.68144 .26446 .69007 .27586 .70833 .26988 .69977 .25807 Mtetra
.663 .751 .916 r
.69977 .25807 .70833 .26988 .72668 .26331 .7182 .2514 Mtetra
.657 .748 .917 r
.7182 .2514 .72668 .26331 .74515 .25675 .73676 .24494 Mtetra
.652 .75 .921 r
.73676 .24494 .74515 .25675 .76375 .2504 .75546 .23865 Mtetra
.651 .752 .924 r
.75546 .23865 .76375 .2504 .7825 .24424 .77429 .23236 Mtetra
.655 .75 .919 r
.11083 .44813 .12172 .45771 .13662 .45238 .12575 .44295 Mtetra
.662 .756 .92 r
.12575 .44295 .13662 .45238 .1516 .44705 .14079 .4375 Mtetra
.658 .753 .921 r
.14079 .4375 .1516 .44705 .16664 .44189 .1559 .43217 Mtetra
.652 .749 .921 r
.1559 .43217 .16664 .44189 .18175 .43696 .17108 .42701 Mtetra
.648 .745 .92 r
.17108 .42701 .18175 .43696 .19698 .43175 .18633 .42198 Mtetra
.658 .752 .92 r
.18633 .42198 .19698 .43175 .21231 .42629 .20171 .41655 Mtetra
.658 .754 .921 r
.20171 .41655 .21231 .42629 .22766 .4216 .21718 .41109 Mtetra
.637 .733 .918 r
.21718 .41109 .22766 .4216 .24301 .41811 .23267 .40638 Mtetra
.608 .7 .909 r
.23267 .40638 .24301 .41811 .25829 .41664 .24818 .40271 Mtetra
.561 .642 .887 r
.24818 .40271 .25829 .41664 .27372 .41491 .26364 .40077 Mtetra
.566 .641 .884 r
.26364 .40077 .27372 .41491 .28939 .41171 .27925 .39867 Mtetra
.594 .674 .896 r
.27925 .39867 .28939 .41171 .30533 .40627 .29507 .39549 Mtetra
.629 .732 .921 r
.29507 .39549 .30533 .40627 .32154 .39794 .31109 .39089 Mtetra
.677 .831 .957 r
.31109 .39089 .32154 .39794 .33786 .3888 .32734 .3843 Mtetra
.698 .896 .968 r
.32734 .3843 .33786 .3888 .35426 .37959 .34376 .37646 Mtetra
.684 .924 .971 r
.34376 .37646 .35426 .37959 .37068 .37091 .36025 .36847 Mtetra
.657 .932 .97 r
.36025 .36847 .37068 .37091 .38714 .36302 .37681 .36077 Mtetra
.627 .928 .971 r
.37681 .36077 .38714 .36302 .40365 .35593 .39343 .35358 Mtetra
.595 .917 .974 r
.39343 .35358 .40365 .35593 .42022 .34955 .41011 .34704 Mtetra
.559 .903 .976 r
.41011 .34704 .42022 .34955 .43686 .34378 .42686 .34122 Mtetra
.517 .886 .975 r
.42686 .34122 .43686 .34378 .4536 .33864 .4437 .33612 Mtetra
.473 .867 .969 r
.4437 .33612 .4536 .33864 .47043 .33421 .46064 .33169 Mtetra
.437 .85 .963 r
.46064 .33169 .47043 .33421 .48737 .3306 .47769 .32777 Mtetra
.428 .841 .967 r
.47769 .32777 .48737 .3306 .50444 .32779 .49487 .32415 Mtetra
.467 .847 .985 r
.49487 .32415 .50444 .32779 .52164 .32553 .51218 .32039 Mtetra
.573 .862 .996 r
.51218 .32039 .52164 .32553 .539 .32323 .52962 .31536 Mtetra
.675 .832 .959 r
.52962 .31536 .539 .32323 .5565 .3201 .54718 .30831 Mtetra
.706 .758 .893 r
.54718 .30831 .5565 .3201 .5741 .31404 .56482 .29981 Mtetra
.714 .72 .854 r
.56482 .29981 .5741 .31404 .59176 .30567 .58252 .29017 Mtetra
.711 .701 .839 r
.58252 .29017 .59176 .30567 .60946 .29578 .60029 .28035 Mtetra
.682 .691 .852 r
.60029 .28035 .60946 .29578 .62723 .2856 .61819 .27229 Mtetra
.669 .722 .888 r
.61819 .27229 .62723 .2856 .64515 .27747 .63623 .26528 Mtetra
.654 .738 .911 r
.63623 .26528 .64515 .27747 .66322 .27057 .6544 .25904 Mtetra
.654 .753 .923 r
.6544 .25904 .66322 .27057 .68144 .26446 .6727 .25276 Mtetra
.663 .755 .918 r
.6727 .25276 .68144 .26446 .69977 .25807 .69109 .24605 Mtetra
.659 .748 .916 r
.69109 .24605 .69977 .25807 .7182 .2514 .70962 .23947 Mtetra
.654 .75 .92 r
.70962 .23947 .7182 .2514 .73676 .24494 .72827 .23306 Mtetra
.65 .75 .923 r
.72827 .23306 .73676 .24494 .75546 .23865 .74707 .22677 Mtetra
.656 .755 .922 r
.74707 .22677 .75546 .23865 .77429 .23236 .76596 .22018 Mtetra
.651 .748 .92 r
.09983 .4384 .11083 .44813 .12575 .44295 .11478 .43332 Mtetra
.659 .753 .92 r
.11478 .43332 .12575 .44295 .14079 .4375 .12986 .42793 Mtetra
.661 .756 .92 r
.12986 .42793 .14079 .4375 .1559 .43217 .14504 .42241 Mtetra
.656 .752 .92 r
.14504 .42241 .1559 .43217 .17108 .42701 .16028 .41705 Mtetra
.651 .748 .92 r
.16028 .41705 .17108 .42701 .18633 .42198 .17559 .41185 Mtetra
.649 .745 .92 r
.17559 .41185 .18633 .42198 .20171 .41655 .19099 .40671 Mtetra
.659 .755 .921 r
.19099 .40671 .20171 .41655 .21718 .41109 .20652 .40113 Mtetra
.657 .753 .921 r
.20652 .40113 .21718 .41109 .23267 .40638 .22214 .39559 Mtetra
.639 .732 .915 r
.22214 .39559 .23267 .40638 .24818 .40271 .23779 .3907 Mtetra
.618 .702 .905 r
.23779 .3907 .24818 .40271 .26364 .40077 .25347 .38659 Mtetra
.581 .649 .882 r
.25347 .38659 .26364 .40077 .27925 .39867 .26915 .38388 Mtetra
.576 .638 .875 r
.26915 .38388 .27925 .39867 .29507 .39549 .28494 .38135 Mtetra
.591 .657 .882 r
.28494 .38135 .29507 .39549 .31109 .39089 .30089 .3782 Mtetra
.614 .693 .899 r
.30089 .3782 .31109 .39089 .32734 .3843 .31703 .37412 Mtetra
.636 .752 .932 r
.31703 .37412 .32734 .3843 .34376 .37646 .33334 .36912 Mtetra
.648 .822 .967 r
.33334 .36912 .34376 .37646 .36025 .36847 .34979 .36334 Mtetra
.658 .878 .98 r
.34979 .36334 .36025 .36847 .37681 .36077 .3664 .35668 Mtetra
.638 .897 .985 r
.3664 .35668 .37681 .36077 .39343 .35358 .38309 .35009 Mtetra
.609 .902 .986 r
.38309 .35009 .39343 .35358 .41011 .34704 .39986 .3438 Mtetra
.58 .899 .985 r
.39986 .3438 .41011 .34704 .42686 .34122 .41672 .33793 Mtetra
.558 .89 .986 r
.41672 .33793 .42686 .34122 .4437 .33612 .43367 .33246 Mtetra
.55 .881 .989 r
.43367 .33246 .4437 .33612 .46064 .33169 .45072 .3273 Mtetra
.562 .872 .994 r
.45072 .3273 .46064 .33169 .47769 .32777 .46789 .32221 Mtetra
.621 .868 .989 r
.46789 .32221 .47769 .32777 .49487 .32415 .48519 .31624 Mtetra
.668 .828 .96 r
.48519 .31624 .49487 .32415 .51218 .32039 .50261 .30947 Mtetra
.692 .77 .911 r
.50261 .30947 .51218 .32039 .52962 .31536 .52013 .30176 Mtetra
.701 .725 .868 r
.52013 .30176 .52962 .31536 .54718 .30831 .53774 .29309 Mtetra
.704 .702 .845 r
.53774 .29309 .54718 .30831 .56482 .29981 .55543 .28377 Mtetra
.698 .689 .838 r
.55543 .28377 .56482 .29981 .58252 .29017 .5732 .27461 Mtetra
.676 .688 .853 r
.5732 .27461 .58252 .29017 .60029 .28035 .59108 .26688 Mtetra
.667 .719 .888 r
.59108 .26688 .60029 .28035 .61819 .27229 .60908 .25993 Mtetra
.654 .736 .91 r
.60908 .25993 .61819 .27229 .63623 .26528 .62722 .25364 Mtetra
.652 .751 .922 r
.62722 .25364 .63623 .26528 .6544 .25904 .64548 .24738 Mtetra
.662 .756 .92 r
.64548 .24738 .6544 .25904 .6727 .25276 .66384 .24066 Mtetra
.66 .748 .915 r
.66384 .24066 .6727 .25276 .69109 .24605 .68232 .23399 Mtetra
.655 .749 .919 r
.68232 .23399 .69109 .24605 .70962 .23947 .70094 .22748 Mtetra
.651 .75 .922 r
.70094 .22748 .70962 .23947 .72827 .23306 .71969 .22113 Mtetra
.653 .754 .924 r
.71969 .22113 .72827 .23306 .74707 .22677 .73856 .21463 Mtetra
.66 .754 .92 r
.73856 .21463 .74707 .22677 .76596 .22018 .75753 .20779 Mtetra
.652 .748 .921 r
.08871 .42859 .09983 .4384 .11478 .43332 .10371 .42344 Mtetra
.652 .748 .92 r
.10371 .42344 .11478 .43332 .12986 .42793 .11881 .41823 Mtetra
.661 .756 .92 r
.11881 .41823 .12986 .42793 .14504 .42241 .13403 .41267 Mtetra
.66 .756 .921 r
.13403 .41267 .14504 .42241 .16028 .41705 .14935 .4071 Mtetra
.656 .751 .92 r
.14935 .4071 .16028 .41705 .17559 .41185 .16473 .40167 Mtetra
.651 .747 .92 r
.16473 .40167 .17559 .41185 .19099 .40671 .18019 .39639 Mtetra
.649 .744 .919 r
.18019 .39639 .19099 .40671 .20652 .40113 .19573 .39114 Mtetra
.659 .755 .921 r
.19573 .39114 .20652 .40113 .22214 .39559 .21141 .38549 Mtetra
.659 .754 .92 r
.21141 .38549 .22214 .39559 .23779 .3907 .22718 .37981 Mtetra
.646 .735 .914 r
.22718 .37981 .23779 .3907 .25347 .38659 .243 .3746 Mtetra
.63 .71 .904 r
.243 .3746 .25347 .38659 .26915 .38388 .25888 .36995 Mtetra
.609 .668 .882 r
.25888 .36995 .26915 .38388 .28494 .38135 .2748 .36607 Mtetra
.59 .639 .868 r
.2748 .36607 .28494 .38135 .30089 .3782 .29077 .36291 Mtetra
.596 .643 .867 r
.29077 .36291 .30089 .3782 .31703 .37412 .30689 .3595 Mtetra
.608 .66 .875 r
.30689 .3595 .31703 .37412 .33334 .36912 .32317 .35558 Mtetra
.623 .685 .888 r
.32317 .35558 .33334 .36912 .34979 .36334 .3396 .35103 Mtetra
.635 .713 .904 r
.3396 .35103 .34979 .36334 .3664 .35668 .35617 .34597 Mtetra
.644 .75 .926 r
.35617 .34597 .3664 .35668 .38309 .35009 .37286 .34051 Mtetra
.649 .777 .942 r
.37286 .34051 .38309 .35009 .39986 .3438 .38968 .33477 Mtetra
.653 .792 .949 r
.38968 .33477 .39986 .3438 .41672 .33793 .40662 .32883 Mtetra
.657 .793 .947 r
.40662 .32883 .41672 .33793 .43367 .33246 .42366 .32268 Mtetra
.665 .782 .936 r
.42366 .32268 .43367 .33246 .45072 .3273 .44082 .31624 Mtetra
.674 .759 .915 r
.44082 .31624 .45072 .3273 .46789 .32221 .4581 .30941 Mtetra
.68 .729 .887 r
.4581 .30941 .46789 .32221 .48519 .31624 .47548 .30204 Mtetra
.687 .71 .865 r
.47548 .30204 .48519 .31624 .50261 .30947 .49296 .29404 Mtetra
.691 .693 .847 r
.49296 .29404 .50261 .30947 .52013 .30176 .51054 .2855 Mtetra
.691 .683 .837 r
.51054 .2855 .52013 .30176 .53774 .29309 .52821 .27669 Mtetra
.679 .677 .841 r
.52821 .27669 .53774 .29309 .55543 .28377 .54596 .2686 Mtetra
.669 .692 .862 r
.54596 .2686 .55543 .28377 .5732 .27461 .56382 .26128 Mtetra
.663 .721 .892 r
.56382 .26128 .5732 .27461 .59108 .26688 .58179 .25453 Mtetra
.653 .737 .911 r
.58179 .25453 .59108 .26688 .60908 .25993 .59989 .24824 Mtetra
.653 .752 .922 r
.59989 .24824 .60908 .25993 .62722 .25364 .61811 .24193 Mtetra
.662 .757 .92 r
.61811 .24193 .62722 .25364 .64548 .24738 .63643 .2352 Mtetra
.66 .748 .915 r
.63643 .2352 .64548 .24738 .66384 .24066 .65488 .22848 Mtetra
.656 .748 .918 r
.65488 .22848 .66384 .24066 .68232 .23399 .67346 .22191 Mtetra
.652 .75 .922 r
.67346 .22191 .68232 .23399 .70094 .22748 .69216 .21548 Mtetra
.651 .753 .924 r
.69216 .21548 .70094 .22748 .71969 .22113 .711 .20903 Mtetra
.659 .756 .921 r
.711 .20903 .71969 .22113 .73856 .21463 .72994 .20219 Mtetra
.659 .751 .917 r
.72994 .20219 .73856 .21463 .75753 .20779 .749 .19529 Mtetra
.654 .75 .92 r
.07746 .41874 .08871 .42859 .10371 .42344 .09253 .41342 Mtetra
.651 .748 .92 r
.09253 .41342 .10371 .42344 .11881 .41823 .10766 .4082 Mtetra
.654 .749 .92 r
.10766 .4082 .11881 .41823 .13403 .41267 .12291 .40284 Mtetra
.661 .756 .921 r
.12291 .40284 .13403 .41267 .14935 .4071 .13828 .39718 Mtetra
.66 .755 .921 r
.13828 .39718 .14935 .4071 .16473 .40167 .15373 .39154 Mtetra
.656 .751 .92 r
.15373 .39154 .16473 .40167 .18019 .39639 .16926 .38602 Mtetra
.651 .746 .919 r
.16926 .38602 .18019 .39639 .19573 .39114 .18487 .38063 Mtetra
.649 .744 .919 r
.18487 .38063 .19573 .39114 .21141 .38549 .20056 .37527 Mtetra
.656 .753 .921 r
.20056 .37527 .21141 .38549 .22718 .37981 .21638 .36961 Mtetra
.66 .756 .921 r
.21638 .36961 .22718 .37981 .243 .3746 .23231 .36378 Mtetra
.653 .743 .916 r
.23231 .36378 .243 .3746 .25888 .36995 .24831 .35818 Mtetra
.642 .722 .906 r
.24831 .35818 .25888 .36995 .2748 .36607 .26438 .35298 Mtetra
.632 .695 .89 r
.26438 .35298 .2748 .36607 .29077 .36291 .28052 .34811 Mtetra
.62 .663 .87 r
.28052 .34811 .29077 .36291 .30689 .3595 .29675 .34362 Mtetra
.609 .643 .859 r
.29675 .34362 .30689 .3595 .32317 .35558 .31306 .33952 Mtetra
.614 .643 .856 r
.31306 .33952 .32317 .35558 .3396 .35103 .3295 .33517 Mtetra
.622 .651 .858 r
.3295 .33517 .3396 .35103 .35617 .34597 .34608 .33044 Mtetra
.631 .661 .86 r
.34608 .33044 .35617 .34597 .37286 .34051 .3628 .32528 Mtetra
.64 .67 .863 r
.3628 .32528 .37286 .34051 .38968 .33477 .37965 .31968 Mtetra
.648 .677 .863 r
.37965 .31968 .38968 .33477 .40662 .32883 .39663 .31366 Mtetra
.656 .68 .861 r
.39663 .31366 .40662 .32883 .42366 .32268 .41373 .30722 Mtetra
.663 .679 .855 r
.41373 .30722 .42366 .32268 .44082 .31624 .43095 .30034 Mtetra
.669 .676 .848 r
.43095 .30034 .44082 .31624 .4581 .30941 .44828 .29302 Mtetra
.673 .673 .841 r
.44828 .29302 .4581 .30941 .47548 .30204 .46571 .2853 Mtetra
.676 .67 .836 r
.46571 .2853 .47548 .30204 .49296 .29404 .48325 .27732 Mtetra
.669 .668 .84 r
.48325 .27732 .49296 .29404 .51054 .2855 .50087 .26972 Mtetra
.666 .681 .855 r
.50087 .26972 .51054 .2855 .52821 .27669 .51859 .26251 Mtetra
.664 .707 .88 r
.51859 .26251 .52821 .27669 .54596 .2686 .53641 .25562 Mtetra
.657 .727 .901 r
.53641 .25562 .54596 .2686 .56382 .26128 .55435 .24912 Mtetra
.652 .742 .916 r
.55435 .24912 .56382 .26128 .58179 .25453 .57241 .24287 Mtetra
.655 .755 .923 r
.57241 .24287 .58179 .25453 .59989 .24824 .59059 .23642 Mtetra
.662 .755 .92 r
.59059 .23642 .59989 .24824 .61811 .24193 .60887 .22966 Mtetra
.66 .747 .915 r
.60887 .22966 .61811 .24193 .63643 .2352 .62728 .22293 Mtetra
.656 .748 .917 r
.62728 .22293 .63643 .2352 .65488 .22848 .64582 .21632 Mtetra
.652 .75 .921 r
.64582 .21632 .65488 .22848 .67346 .22191 .66448 .20983 Mtetra
.651 .752 .924 r
.66448 .20983 .67346 .22191 .69216 .21548 .68328 .20334 Mtetra
.658 .756 .922 r
.68328 .20334 .69216 .21548 .711 .20903 .70218 .19653 Mtetra
.66 .751 .918 r
.70218 .19653 .711 .20903 .72994 .20219 .72121 .18958 Mtetra
.657 .749 .918 r
.72121 .18958 .72994 .20219 .749 .19529 .74037 .1827 Mtetra
.657 .753 .92 r
.06608 .40885 .07746 .41874 .09253 .41342 .0812 .40338 Mtetra
.654 .75 .92 r
.0812 .40338 .09253 .41342 .10766 .4082 .0964 .39799 Mtetra
.651 .747 .92 r
.0964 .39799 .10766 .4082 .12291 .40284 .11169 .39267 Mtetra
.654 .75 .92 r
.11169 .39267 .12291 .40284 .13828 .39718 .12708 .3872 Mtetra
.661 .757 .921 r
.12708 .3872 .13828 .39718 .15373 .39154 .14259 .38145 Mtetra
.66 .755 .921 r
.14259 .38145 .15373 .39154 .16926 .38602 .15819 .37572 Mtetra
.656 .751 .92 r
.15819 .37572 .16926 .38602 .18487 .38063 .17387 .37009 Mtetra
.653 .747 .919 r
.17387 .37009 .18487 .38063 .20056 .37527 .18963 .36455 Mtetra
.65 .744 .918 r
.18963 .36455 .20056 .37527 .21638 .36961 .20548 .35907 Mtetra
.652 .749 .921 r
.20548 .35907 .21638 .36961 .23231 .36378 .22144 .3535 Mtetra
.661 .758 .922 r
.22144 .3535 .23231 .36378 .24831 .35818 .23752 .34755 Mtetra
.658 .752 .919 r
.23752 .34755 .24831 .35818 .26438 .35298 .2537 .34165 Mtetra
.653 .737 .912 r
.2537 .34165 .26438 .35298 .28052 .34811 .26996 .33593 Mtetra
.646 .72 .902 r
.26996 .33593 .28052 .34811 .29675 .34362 .28631 .33041 Mtetra
.641 .701 .89 r
.28631 .33041 .29675 .34362 .31306 .33952 .30275 .32501 Mtetra
.638 .679 .873 r
.30275 .32501 .31306 .33952 .3295 .33517 .31929 .31964 Mtetra
.636 .664 .86 r
.31929 .31964 .3295 .33517 .34608 .33044 .33595 .3142 Mtetra
.636 .654 .851 r
.33595 .3142 .34608 .33044 .3628 .32528 .35272 .30864 Mtetra
.638 .651 .846 r
.35272 .30864 .3628 .32528 .37965 .31968 .36961 .3029 Mtetra
.644 .652 .843 r
.36961 .3029 .37965 .31968 .39663 .31366 .38663 .2968 Mtetra
.65 .655 .841 r
.38663 .2968 .39663 .31366 .41373 .30722 .40376 .29034 Mtetra
.653 .657 .841 r
.40376 .29034 .41373 .30722 .43095 .30034 .42101 .28371 Mtetra
.655 .663 .845 r
.42101 .28371 .43095 .30034 .44828 .29302 .43837 .27695 Mtetra
.658 .673 .853 r
.43837 .27695 .44828 .29302 .46571 .2853 .45583 .27011 Mtetra
.66 .688 .865 r
.45583 .27011 .46571 .2853 .48325 .27732 .4734 .2633 Mtetra
.66 .708 .883 r
.4734 .2633 .48325 .27732 .50087 .26972 .49107 .2566 Mtetra
.657 .724 .898 r
.49107 .2566 .50087 .26972 .51859 .26251 .50886 .2501 Mtetra
.653 .737 .911 r
.50886 .2501 .51859 .26251 .53641 .25562 .52676 .24377 Mtetra
.651 .749 .921 r
.52676 .24377 .53641 .25562 .55435 .24912 .54477 .2375 Mtetra
.66 .758 .923 r
.54477 .2375 .55435 .24912 .57241 .24287 .56291 .23083 Mtetra
.661 .752 .918 r
.56291 .23083 .57241 .24287 .59059 .23642 .58116 .22406 Mtetra
.658 .746 .915 r
.58116 .22406 .59059 .23642 .60887 .22966 .59953 .21734 Mtetra
.656 .748 .918 r
.59953 .21734 .60887 .22966 .62728 .22293 .61803 .21071 Mtetra
.652 .75 .921 r
.61803 .21071 .62728 .22293 .64582 .21632 .63665 .20417 Mtetra
.651 .753 .924 r
.63665 .20417 .64582 .21632 .66448 .20983 .6554 .19764 Mtetra
.657 .756 .923 r
.6554 .19764 .66448 .20983 .68328 .20334 .67427 .19082 Mtetra
.66 .752 .918 r
.67427 .19082 .68328 .20334 .70218 .19653 .69326 .18383 Mtetra
.657 .749 .918 r
.69326 .18383 .70218 .19653 .72121 .18958 .71238 .17689 Mtetra
.655 .75 .92 r
.71238 .17689 .72121 .18958 .74037 .1827 .73163 .17003 Mtetra
.66 .755 .92 r
.05455 .39894 .06608 .40885 .0812 .40338 .06974 .3933 Mtetra
.656 .752 .92 r
.06974 .3933 .0812 .40338 .0964 .39799 .08501 .38777 Mtetra
.654 .75 .92 r
.08501 .38777 .0964 .39799 .11169 .39267 .10035 .38229 Mtetra
.651 .747 .92 r
.10035 .38229 .11169 .39267 .12708 .3872 .11578 .37686 Mtetra
.654 .75 .92 r
.11578 .37686 .12708 .3872 .14259 .38145 .13131 .3713 Mtetra
.66 .757 .921 r
.13131 .3713 .14259 .38145 .15819 .37572 .14697 .36547 Mtetra
.66 .756 .921 r
.14697 .36547 .15819 .37572 .17387 .37009 .16272 .35963 Mtetra
.656 .752 .92 r
.16272 .35963 .17387 .37009 .18963 .36455 .17856 .35388 Mtetra
.654 .748 .919 r
.17856 .35388 .18963 .36455 .20548 .35907 .19448 .34817 Mtetra
.651 .744 .918 r
.19448 .34817 .20548 .35907 .22144 .3535 .21049 .34255 Mtetra
.21049 .34255 .22144 .3535 .23752 .34755 .2266 .3369 Mtetra
.654 .753 .922 r
.2266 .3369 .23752 .34755 .2537 .34165 .24282 .33111 Mtetra
.66 .758 .923 r
.24282 .33111 .2537 .34165 .26996 .33593 .25916 .32505 Mtetra
.658 .752 .919 r
.25916 .32505 .26996 .33593 .28631 .33041 .2756 .31902 Mtetra
.656 .742 .913 r
.2756 .31902 .28631 .33041 .30275 .32501 .29214 .31303 Mtetra
.653 .731 .907 r
.29214 .31303 .30275 .32501 .31929 .31964 .30878 .30708 Mtetra
.651 .721 .9 r
.30878 .30708 .31929 .31964 .33595 .3142 .32551 .30115 Mtetra
.651 .714 .894 r
.32551 .30115 .33595 .3142 .35272 .30864 .34236 .29518 Mtetra
.651 .708 .889 r
.34236 .29518 .35272 .30864 .36961 .3029 .35932 .28912 Mtetra
.652 .704 .885 r
.35932 .28912 .36961 .3029 .38663 .2968 .37639 .28295 Mtetra
.654 .704 .884 r
.37639 .28295 .38663 .2968 .40376 .29034 .39357 .27667 Mtetra
.655 .709 .887 r
.39357 .27667 .40376 .29034 .42101 .28371 .41086 .27029 Mtetra
.656 .716 .892 r
.41086 .27029 .42101 .28371 .43837 .27695 .42827 .26387 Mtetra
.656 .723 .898 r
.42827 .26387 .43837 .27695 .45583 .27011 .44578 .25746 Mtetra
.655 .732 .906 r
.44578 .25746 .45583 .27011 .4734 .2633 .46341 .2511 Mtetra
.653 .741 .914 r
.46341 .2511 .4734 .2633 .49107 .2566 .48115 .24478 Mtetra
.652 .75 .921 r
.48115 .24478 .49107 .2566 .50886 .2501 .49901 .23848 Mtetra
.658 .757 .923 r
.49901 .23848 .50886 .2501 .52676 .24377 .51699 .2319 Mtetra
.66 .755 .92 r
.51699 .2319 .52676 .24377 .54477 .2375 .53508 .22517 Mtetra
.66 .747 .915 r
.53508 .22517 .54477 .2375 .56291 .23083 .55329 .2184 Mtetra
.657 .746 .915 r
.55329 .2184 .56291 .23083 .58116 .22406 .57162 .21172 Mtetra
.655 .749 .919 r
.57162 .21172 .58116 .22406 .59953 .21734 .59008 .20507 Mtetra
.652 .75 .922 r
.59008 .20507 .59953 .21734 .61803 .21071 .60866 .19851 Mtetra
.652 .753 .924 r
.60866 .19851 .61803 .21071 .63665 .20417 .62737 .19192 Mtetra
.657 .756 .923 r
.62737 .19192 .63665 .20417 .6554 .19764 .6462 .18506 Mtetra
.66 .752 .918 r
.6462 .18506 .6554 .19764 .67427 .19082 .66515 .17803 Mtetra
.657 .749 .917 r
.66515 .17803 .67427 .19082 .69326 .18383 .68423 .17106 Mtetra
.655 .75 .919 r
.68423 .17106 .69326 .18383 .71238 .17689 .70344 .16413 Mtetra
.652 .75 .922 r
.70344 .16413 .71238 .17689 .73163 .17003 .72279 .15729 Mtetra
.658 .753 .92 r
.04291 .38886 .05455 .39894 .06974 .3933 .05814 .38323 Mtetra
.66 .755 .921 r
.05814 .38323 .06974 .3933 .08501 .38777 .07347 .3775 Mtetra
.656 .752 .92 r
.07347 .3775 .08501 .38777 .10035 .38229 .08888 .37187 Mtetra
.654 .749 .92 r
.08888 .37187 .10035 .38229 .11578 .37686 .10437 .36629 Mtetra
.652 .747 .919 r
.10437 .36629 .11578 .37686 .13131 .3713 .11995 .36076 Mtetra
.653 .749 .92 r
.11995 .36076 .13131 .3713 .14697 .36547 .13563 .35513 Mtetra
.659 .756 .922 r
.13563 .35513 .14697 .36547 .16272 .35963 .15143 .34924 Mtetra
.66 .757 .922 r
.15143 .34924 .16272 .35963 .17856 .35388 .16734 .34329 Mtetra
.658 .753 .921 r
.16734 .34329 .17856 .35388 .19448 .34817 .18333 .33739 Mtetra
.656 .75 .92 r
.18333 .33739 .19448 .34817 .21049 .34255 .19941 .33153 Mtetra
.654 .746 .918 r
.19941 .33153 .21049 .34255 .2266 .3369 .21559 .3257 Mtetra
.652 .743 .917 r
.21559 .3257 .2266 .3369 .24282 .33111 .23186 .31992 Mtetra
.652 .745 .918 r
.23186 .31992 .24282 .33111 .25916 .32505 .24824 .31409 Mtetra
.653 .751 .922 r
.24824 .31409 .25916 .32505 .2756 .31902 .26473 .30818 Mtetra
.656 .756 .924 r
.26473 .30818 .2756 .31902 .29214 .31303 .28132 .30212 Mtetra
.658 .757 .923 r
.28132 .30212 .29214 .31303 .30878 .30708 .29804 .29595 Mtetra
.657 .753 .921 r
.29804 .29595 .30878 .30708 .32551 .30115 .31485 .28976 Mtetra
.657 .749 .918 r
.31485 .28976 .32551 .30115 .34236 .29518 .33177 .28356 Mtetra
.656 .746 .916 r
.33177 .28356 .34236 .29518 .35932 .28912 .3488 .27734 Mtetra
.656 .744 .915 r
.3488 .27734 .35932 .28912 .37639 .28295 .36593 .27109 Mtetra
.655 .744 .915 r
.36593 .27109 .37639 .28295 .39357 .27667 .38318 .26482 Mtetra
.655 .746 .917 r
.38318 .26482 .39357 .27667 .41086 .27029 .40054 .25853 Mtetra
.654 .749 .919 r
.40054 .25853 .41086 .27029 .42827 .26387 .418 .25223 Mtetra
.654 .752 .922 r
.418 .25223 .42827 .26387 .44578 .25746 .43559 .2459 Mtetra
.656 .756 .924 r
.43559 .2459 .44578 .25746 .46341 .2511 .45329 .23946 Mtetra
.658 .757 .923 r
.45329 .23946 .46341 .2511 .48115 .24478 .47111 .23286 Mtetra
.659 .753 .92 r
.47111 .23286 .48115 .24478 .49901 .23848 .48904 .22618 Mtetra
.659 .748 .915 r
.48904 .22618 .49901 .23848 .51699 .2319 .5071 .21944 Mtetra
.657 .745 .915 r
.5071 .21944 .51699 .2319 .53508 .22517 .52527 .21275 Mtetra
.656 .747 .917 r
.52527 .21275 .53508 .22517 .55329 .2184 .54356 .20608 Mtetra
.654 .75 .92 r
.54356 .20608 .55329 .2184 .57162 .21172 .56197 .19944 Mtetra
.652 .751 .923 r
.56197 .19944 .57162 .21172 .59008 .20507 .58051 .19285 Mtetra
.652 .754 .924 r
.58051 .19285 .59008 .20507 .60866 .19851 .59918 .18619 Mtetra
.658 .756 .922 r
.59918 .18619 .60866 .19851 .62737 .19192 .61796 .17924 Mtetra
.659 .751 .918 r
.61796 .17924 .62737 .19192 .6462 .18506 .63687 .17219 Mtetra
.657 .749 .917 r
.63687 .17219 .6462 .18506 .66515 .17803 .65591 .16518 Mtetra
.655 .75 .919 r
.65591 .16518 .66515 .17803 .68423 .17106 .67508 .1582 Mtetra
.652 .75 .921 r
.67508 .1582 .68423 .17106 .70344 .16413 .6944 .15132 Mtetra
.654 .753 .923 r
.6944 .15132 .70344 .16413 .72279 .15729 .71384 .14432 Mtetra
.654 .749 .92 r
.03115 .37851 .04291 .38886 .05814 .38323 .04641 .37298 Mtetra
.658 .754 .921 r
.04641 .37298 .05814 .38323 .07347 .3775 .06179 .36725 Mtetra
.66 .755 .921 r
.06179 .36725 .07347 .3775 .08888 .37187 .07726 .36143 Mtetra
.656 .752 .92 r
.07726 .36143 .08888 .37187 .10437 .36629 .09282 .3557 Mtetra
.654 .75 .92 r
.09282 .3557 .10437 .36629 .11995 .36076 .10846 .35 Mtetra
.652 .747 .919 r
.10846 .35 .11995 .36076 .13563 .35513 .12419 .34434 Mtetra
.653 .748 .919 r
.12419 .34434 .13563 .35513 .15143 .34924 .14002 .33864 Mtetra
.657 .754 .922 r
.14002 .33864 .15143 .34924 .16734 .34329 .15597 .33274 Mtetra
.66 .757 .922 r
.15597 .33274 .16734 .34329 .18333 .33739 .17203 .3267 Mtetra
.659 .756 .921 r
.17203 .3267 .18333 .33739 .19941 .33153 .18818 .32064 Mtetra
.657 .752 .92 r
.18818 .32064 .19941 .33153 .21559 .3257 .20443 .31464 Mtetra
.656 .75 .919 r
.20443 .31464 .21559 .3257 .23186 .31992 .22077 .30864 Mtetra
.655 .747 .917 r
.22077 .30864 .23186 .31992 .24824 .31409 .23722 .30263 Mtetra
.653 .744 .916 r
.23722 .30263 .24824 .31409 .26473 .30818 .25377 .29663 Mtetra
.25377 .29663 .26473 .30818 .28132 .30212 .27042 .29061 Mtetra
.654 .746 .918 r
.27042 .29061 .28132 .30212 .29804 .29595 .28718 .28454 Mtetra
.654 .749 .92 r
.28718 .28454 .29804 .29595 .31485 .28976 .30405 .2784 Mtetra
.655 .752 .921 r
.30405 .2784 .31485 .28976 .33177 .28356 .32103 .2722 Mtetra
.655 .754 .922 r
.32103 .2722 .33177 .28356 .3488 .27734 .33812 .26593 Mtetra
.656 .755 .923 r
.33812 .26593 .3488 .27734 .36593 .27109 .35533 .25961 Mtetra
.656 .755 .922 r
.35533 .25961 .36593 .27109 .38318 .26482 .37265 .25323 Mtetra
.657 .754 .922 r
.37265 .25323 .38318 .26482 .40054 .25853 .39008 .24679 Mtetra
.657 .753 .92 r
.39008 .24679 .40054 .25853 .418 .25223 .40762 .24029 Mtetra
.658 .751 .919 r
.40762 .24029 .418 .25223 .43559 .2459 .42528 .23372 Mtetra
.658 .747 .916 r
.42528 .23372 .43559 .2459 .45329 .23946 .44306 .22709 Mtetra
.658 .745 .915 r
.44306 .22709 .45329 .23946 .47111 .23286 .46095 .22042 Mtetra
.656 .745 .915 r
.46095 .22042 .47111 .23286 .48904 .22618 .47896 .21377 Mtetra
.656 .747 .917 r
.47896 .21377 .48904 .22618 .5071 .21944 .49709 .2071 Mtetra
.655 .75 .919 r
.49709 .2071 .5071 .21944 .52527 .21275 .51533 .20044 Mtetra
.653 .751 .922 r
.51533 .20044 .52527 .21275 .54356 .20608 .53371 .19382 Mtetra
.652 .753 .924 r
.53371 .19382 .54356 .20608 .56197 .19944 .5522 .18717 Mtetra
.655 .756 .924 r
.5522 .18717 .56197 .19944 .58051 .19285 .57082 .18037 Mtetra
.659 .755 .921 r
.57082 .18037 .58051 .19285 .59918 .18619 .58957 .17337 Mtetra
.659 .75 .917 r
.58957 .17337 .59918 .18619 .61796 .17924 .60844 .1663 Mtetra
.657 .748 .917 r
.60844 .1663 .61796 .17924 .63687 .17219 .62743 .15927 Mtetra
.655 .75 .919 r
.62743 .15927 .63687 .17219 .65591 .16518 .64657 .15226 Mtetra
.652 .75 .922 r
.64657 .15226 .65591 .16518 .67508 .1582 .66583 .14533 Mtetra
.654 .754 .923 r
.66583 .14533 .67508 .1582 .6944 .15132 .68523 .13829 Mtetra
.658 .754 .921 r
.68523 .13829 .6944 .15132 .71384 .14432 .70476 .13103 Mtetra
.653 .749 .92 r
.01927 .36803 .03115 .37851 .04641 .37298 .03457 .36246 Mtetra
.654 .749 .92 r
.03457 .36246 .04641 .37298 .06179 .36725 .04998 .35682 Mtetra
.658 .754 .921 r
.04998 .35682 .06179 .36725 .07726 .36143 .0655 .35101 Mtetra
.659 .755 .921 r
.0655 .35101 .07726 .36143 .09282 .3557 .08112 .3451 Mtetra
.657 .753 .92 r
.08112 .3451 .09282 .3557 .10846 .35 .09683 .33924 Mtetra
.655 .75 .92 r
.09683 .33924 .10846 .35 .12419 .34434 .11262 .33341 Mtetra
.653 .748 .919 r
.11262 .33341 .12419 .34434 .14002 .33864 .12851 .32762 Mtetra
.652 .747 .919 r
.12851 .32762 .14002 .33864 .15597 .33274 .14449 .32182 Mtetra
.654 .751 .921 r
.14449 .32182 .15597 .33274 .17203 .3267 .16059 .31593 Mtetra
.658 .756 .922 r
.16059 .31593 .17203 .3267 .18818 .32064 .1768 .30985 Mtetra
.659 .757 .923 r
.1768 .30985 .18818 .32064 .20443 .31464 .19311 .30369 Mtetra
.659 .756 .922 r
.19311 .30369 .20443 .31464 .22077 .30864 .20953 .2975 Mtetra
.657 .753 .921 r
.20953 .2975 .22077 .30864 .23722 .30263 .22605 .29134 Mtetra
.656 .751 .92 r
.22605 .29134 .23722 .30263 .25377 .29663 .24266 .28517 Mtetra
.656 .749 .918 r
.24266 .28517 .25377 .29663 .27042 .29061 .25938 .27898 Mtetra
.655 .747 .917 r
.25938 .27898 .27042 .29061 .28718 .28454 .27621 .27276 Mtetra
.655 .745 .916 r
.27621 .27276 .28718 .28454 .30405 .2784 .29315 .26651 Mtetra
.29315 .26651 .30405 .2784 .32103 .2722 .3102 .26021 Mtetra
.655 .744 .915 r
.3102 .26021 .32103 .2722 .33812 .26593 .32736 .25386 Mtetra
.32736 .25386 .33812 .26593 .35533 .25961 .34463 .24746 Mtetra
.656 .744 .915 r
.34463 .24746 .35533 .25961 .37265 .25323 .36201 .24102 Mtetra
.36201 .24102 .37265 .25323 .39008 .24679 .37951 .23452 Mtetra
.656 .745 .915 r
.37951 .23452 .39008 .24679 .40762 .24029 .39712 .22798 Mtetra
.656 .746 .916 r
.39712 .22798 .40762 .24029 .42528 .23372 .41485 .2214 Mtetra
.656 .747 .917 r
.41485 .2214 .42528 .23372 .44306 .22709 .4327 .21478 Mtetra
.655 .749 .918 r
.4327 .21478 .44306 .22709 .46095 .22042 .45066 .20814 Mtetra
.655 .75 .92 r
.45066 .20814 .46095 .22042 .47896 .21377 .46874 .2015 Mtetra
.653 .752 .922 r
.46874 .2015 .47896 .21377 .49709 .2071 .48695 .19486 Mtetra
.653 .754 .924 r
.48695 .19486 .49709 .2071 .51533 .20044 .50528 .1882 Mtetra
.654 .756 .925 r
.50528 .1882 .51533 .20044 .53371 .19382 .52373 .18145 Mtetra
.658 .756 .923 r
.52373 .18145 .53371 .19382 .5522 .18717 .54231 .17449 Mtetra
.659 .752 .919 r
.54231 .17449 .5522 .18717 .57082 .18037 .56101 .16744 Mtetra
.658 .749 .917 r
.56101 .16744 .57082 .18037 .58957 .17337 .57984 .16037 Mtetra
.656 .749 .918 r
.57984 .16037 .58957 .17337 .60844 .1663 .59879 .15332 Mtetra
.655 .75 .92 r
.59879 .15332 .60844 .1663 .62743 .15927 .61788 .1463 Mtetra
.653 .751 .922 r
.61788 .1463 .62743 .15927 .64657 .15226 .63711 .13932 Mtetra
.654 .754 .923 r
.63711 .13932 .64657 .15226 .66583 .14533 .65646 .13222 Mtetra
.658 .754 .921 r
.65646 .13222 .66583 .14533 .68523 .13829 .67595 .12492 Mtetra
.658 .751 .918 r
.67595 .12492 .68523 .13829 .70476 .13103 .69556 .11756 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
[(-2)] .12586 .2075 1 .99877 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.56863 .04703 m
.57247 .05235 L
s
[(2)] .56094 .0364 .72324 1 Mshowa
.125 Mabswid
.18558 .19702 m
.18832 .19985 L
s
.23703 .17687 m
.23971 .17975 L
s
.28951 .15632 m
.29214 .15925 L
s
.39772 .11395 m
.40023 .11699 L
s
.4535 .09211 m
.45595 .0952 L
s
.51046 .06981 m
.51284 .07294 L
s
.08568 .23614 m
.08851 .23887 L
s
.62804 .02377 m
.63027 .02701 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 233.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00o?ooool2o`0006[ooooo003iooooo`?o000000?oooooo`000?ooool0
JOooool00?Oooooo0_l00004ooooo`;o0000JOooool00?Cooooo0ol00006ooooo`03o`000?oooooo
000006Sooooo003;ooooo`Go00008_ooool2o`0000Wooooo00?o0000ooooool00000J?ooool00<_o
oooo00GoV9RHob4Q8Oo^k^koooooodA4A00Oooooo`?o00002oooool01?l0003oooooooooool0001W
ooooo`00c?ooool00onHV9So8B4Qonk^kP0Mooooo`?o00003_ooool01Ol0003ooooooooooooooooo
000006Kooooo003=ooooo`03oiRHV?lQ8B7ok^k^01[ooooo0_l0000Aooooo`05o`000?oooooooooo
ooooool00000I_ooool00<kooooo00?oMgMgofIVI_ooool05_ooool3o`0001?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1Sooooo`00coooool00ol0003oooooooooo`0Cooooo`;o
00000_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0H_ooool00<_ooooo00Go0000okZj^_ooooooV9RHoa0@400Booooo`?o00006Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo06;ooooo003;ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`04?ooool2o`0001cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Qooooo`00
gOooool3o`0001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Qooooo`00fooo
ool2o`00027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Pooooo`00f?ooool3
o`0002?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Oooooo`00eOooool3o`00
02Kooooo00?o0000ooooooooool01?ooool2o`00067ooooo003Cooooo`;o0000:Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo05kooooo003@ooooo`?o000000?oooooo`000?ooool0
:?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05gooooo003>ooooo`;o00001Ooo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0GOoo
ool00<_ooooo0ol0000`ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0G?ooool0
0<Wooooo0_l0000cooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Foooool00<Ko
oooo0ol0000eooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Foooool00<Cooooo
0_l0000hooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0F_ooool00<7ooooo0ol0
000jooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03_ooool5o`0004Kooooo002n
ooooo`?o0000?Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00kooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A016ooooo`00_?ooool2o`0000?ooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo1_l00003ooooo`03oiRHV?lQ8B7o
k^k^04Oooooo002iooooo`?o0000@oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00kooooo00?oV9RHob4Q8Oo^k^h0A_ooool00;Oooooo0_l00016ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03oooool00omgMgOoIVIVooooo`15ooooo`00]?ooool3o`0004Sooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Cooooo
002booooo`;o0000Boooool00ol0003oooooooooo`0=ooooo`;o00003?ooool01Ol0003o^[Zjoooo
oonHV9So410@04Kooooo002_ooooo`?o0000COooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c016ooooo`00[Oooool2o`00053ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`1Dooooo`00Z_ooool4o`00057ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1Dooooo`00Z?ooool2o`0000Cooooo00?o0000oooo
ooooool0C_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05?ooooo001nooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h08_ooool3o`0005Oooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`1Booooo`00O_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01oooooo0ol0001Joooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool0D_ooool007kooooo00Go410@oooooooo
oooooooooa0@400Mooooo`;o0000GOooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
057ooooo001nooooo`05o`000?ooooooooooooooool000006_ooool3o`0005oooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`1@ooooo`00O_ooool01Ol0003ooooooooooooooooo0000
01Sooooo0_l0001Rooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0D?ooool007ko
oooo00Go410@oooooooooooooooooa0@400Eooooo`?o0000I?ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo04oooooo001nooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool2o`00
00?ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
04kooooo001nooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04?ooool3o`0006Sooooo00?oZ<3[o`00
0?ooool05_ooool00ol0003oooooooooo`1>ooooo`00TOooool2o`0006Sooooo1?nX`>/00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo04gooooo002>ooooo`?o0000J?ooool7ojS0j`03o`00
0?oooooooooo01Cooooo0ol0001>ooooo`00Roooool3o`0006Wooooo0_nX`N/7ojS0j`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool0C?ooool008Wooooo0_l0001Yooooo`KoZ<7[1_nX`>/0
0ol0003oZ<3[ooooo`0Gooooo`03o`000?oooooooooo04_ooooo0026ooooo`?o0000J?ooool00onW
`NcoZ<7[ojS1j`07ojS1j`GoZ<3[00?o0000ojS1joooool06?ooool00ol0003oooooooooo`1:oooo
o`00Q?ooool2o`0000;ooooo00?o0000ooooooooool0Hoooool5ojO1k0WoZ<7[0_nX`>/2ojS1j`03
o`000?nX`N_oZ<7[01Sooooo00?o0000ooooooooool0B_ooool0087ooooo0ol00005ooooo`03o`00
0?oooooooooo063ooooo2?nW`N`7ojS1j`03ojO1k?nX`N_oZ<7[00;oZ<7[00Co0000ojS1jonX`N_o
Z<7[6?ooool00ol0003oooooooooo`19ooooo`00Ooooool2o`0006Wooooo00?oYl3/ojO1k?nW`N`0
1onW`N`4ojS1j`GoYl7/0onX`N/00ol0003oZ<7[ojS1j`02ojS1jaSooooo00?o0000ooooooooool0
B?ooool007cooooo0ol0001Xooooo`GoYl3/2OnW`N`00onX`N_oYl7/ojO1k006ojO1k0;oZ<7[00Go
0000ojS1jonX`N_oZ<7[ojO0k00Hooooo`03o`000?oooooooooo04Sooooo001jooooo`;o0000Iooo
ool2ojNoj`SoYl3/1_nW`N`2ojJok0WoYl7/0_nX`N/00ol0003oZ<7[ojO0k003ojO0k1Sooooo00?o
0000ooooooooool0Aoooool007Oooooo0ol0001Vooooo`KoYko[2?nW`>`2ojO1k0KoY[o/2OnW`N`0
0onX`N_o0000ojO0k005ojO0k1Sooooo00?o0000ooooooooool0A_ooool007Cooooo0ol0001Voooo
o`[oYko[1_nW`>`2ojNoj`SoY[o/1_nW`N`2ojJoj`03ojO0k?l0003oYl3/00GoYl3/6?ooool00ol0
003oooooooooo`16ooooo`00L_ooool2o`0000;ooooo00?o0000ooooooooool0H_ooool=ojNoj`;o
Yl3/1_nW_n/8ojJok0;oYl7/1_nV_n/00ol0003oYl3/ojO0k005ojO0k1Sooooo00?o0000oooooooo
ool0AOooool006oooooo0ol0001Wooooo`koYko[00?oZ;oZojNojonW_n/01onW_n/6ojJok003ojNo
jonV_n_oY[o[00KoY[o[00?o0000ojO0k?nW`>`01?nW`>`00onV_ncoooooooooo`0Fooooo`03o`00
0?oooooooooo04Gooooo001]ooooo`;o0000Ioooool2ojRojPcoYko[1OnX_nX9ojNoj`;oY[o/1OnW
_n/7ojJoj`04o`000?nV_n_oYl3/ojO0k0GoY[o/5oooool2o`0004Kooooo001Zooooo`?o0000I_oo
ool6ojRojPWoYko[2?nX_nX7ojNoj`03ojRoj_nW_n_oYko[00KoYko[1_nV_n/00ol0003oYko[ojJo
k007ojJok1Sooooo00?o0000ooooooooool0@oooool006Sooooo0_l0001Vooooo`03ojS0jonX_n[o
Z;oZ00OoZ;oZ1_nW_n/:ojRojPCoYko[1OnX_nX8ojNoj`;oY[o[0onW_n/00ol0003oYko[ojNoj`08
ojJok1Oooooo00?o0000ooooooooool0@oooool006Gooooo0ol0001Vooooo`CoZ<3[2OnX_nX2ojNo
j`koZ;oZ00?oYko[ojRoj_nX_nX01_nX_nX6ojNoj`03ojRoj_nW_n_oYko[00?oYko[00Co0000ojNo
jonW_n_oYko[1_nV_n`00onW_n_oooooooooo`0Fooooo`03o`000?oooooooooo04;ooooo001Soooo
o`;o0000Ioooool7ojS0j`OoZ;oZ00?oZ<7[ojRoj_nX_nX03OnX_nX00onX`>_oZ;oZojRojP07ojRo
jPCoYko[1?nX_nX5ojNoj`04o`000?nW_n_oYko[ojNoj`;oY[o/1OnW_n/Hooooo`03o`000?oooooo
oooo047ooooo001Pooooo`?o000000?oooooo`000?ooool0I?ooool00onX`NcoZ<3[ojS0j`07ojS0
j`CoZ;oZ1?nX`N/;ojRojPGoZ<3[2OnX_nX00onW_n_oZ;oZojRojP05ojRojPCoYko[00Co0000ojNo
jonW_n_oZ;o[2?nW_n/Gooooo`03o`000?oooooooooo047ooooo000fooooo`Go00008oooool2o`00
06Oooooo1OnX`N`9ojS0j`03ojRoj_nX`N_oZ<7[00GoZ<7[1_nX_nX2ojS1k0SoZ<3[1_nX_nX2ojS0
j`SoZ;oZ1?nW_n/00ol0003oZ;o[ojRoj`02ojRoj`SoYko[5oooool00ol0003oooooooooo`10oooo
o`00=_ooool01OnHV9So8B4Qonk^k_ooooooA4A4023ooooo0ol0001Uooooo`;oYl7/2?nX`N`6ojS0
j`;oYl7/2OnX`N/2ojRojPKoZ<7/2?nX`>/2ojRojPKoZ<3[2?nX_nX01?nW_n_oZ;o[ojRojol00005
ojRoj`KoYko[00?oZ;o[ooooooooool05_ooool00ol0003oooooooooo`0oooooo`00;_ooool6o`00
00?ooooo00?oV9RHob4Q8Oo^k^h07_ooool3o`0006Gooooo1_nW`N`8ojS1k0;oZ<3[1_nW`N`7ojS1
j`03ojK1k?nX`NcoZ<7/00OoZ<7/1_nX`>/00onX`NcoZ<3[ojS0j`07ojS0j`KoZ;oZ00GoZ<3[ojRo
jonX_n_oZ;o[o`000005ojRoj`CoYko[1?nX_n/Gooooo`03o`000?oooooooooo03oooooo000hoooo
o`03oiRHV?lQ8B7ok^k^01_ooooo0_l0001Uooooo`[oYl7/1_nX`N`2ojK0k0SoYl7/1?nX`N/4ojK1
k0WoZ<7/0_nX`>/5ojS1k0WoZ<3[0_nX_nX5ojS0j`;oZ;o[00?o0000ojRojonX_n/01?nX_n/00onW
_n_oZ;o[ojRoj`05ojRojaOooooo00?o0000ooooooooool0?_ooool003Wooooo00?oMgMgofIVI_oo
ool05oooool3o`0006Cooooo3_nW`N`2ojS1k0KoY/3/2?nW`N`00onX`N_oY/7/ojK1k005ojK1k0Oo
Z<7/00?oY/3/ojS1k?nX`N`01_nX`N`6ojS0j`;oZ<7/2?nX`>/00onX_n_o0000ojRoj`03ojRoj`;o
Z<3[2?nX_n/Hooooo`03o`000?oooooooooo03gooooo000jooooo`03o`000?oooooooooo01Cooooo
0_l0001Tooooo`03ojO0k?nW`NcoYl7/00goYl7/00?oYl3/ojK0k?nV`>`01onV`>`6ojO1k003ojK0
k?nV`NcoY/7/00OoY/7/1?nX`N`4ojK0k0SoZ<7/0_nX`>/6ojS1k0SoZ<3[00?o0000ojRojonX`>/0
1OnX`>/8ojRojaOooooo00?o0000ooooooooool0?Oooool003Kooooo00Go0000okZj^_ooooooV9RH
oa0@400Cooooo`?o00000_ooool00ol0003oooooooooo`1Oooooo`CoYl3/2onW`N`5ojO0k0WoY/3/
0_nW`N`5ojK0k0WoY/7/00?oZ<7/ojK0k?nV`>`01OnV`>`6ojS1k003ojK0k?nX`NcoZ<7/00OoZ<7/
1_nX`>/00onX`Nco0000ojS0j`07ojS0j`KoZ;o[00?oZ<3Zooooooooool05_ooool00ol0003ooooo
ooooo`0looooo`00=_ooool01OnHV9So410@o`000?lQ8B7oc<c<017ooooo0_l0001Uooooo`OoYl3/
1onW`N`00onW_n_oYl3/ojO0k006ojO0k0KoY/3/0_nW_n/8ojK0k0KoY/7/0_nV_n`8ojK0k0CoZ<7/
1?nV`>`9ojS1k0;oZ<3[1?nX`N`00ol0003oZ<3[ojS0j`07ojS0j`;oZ;o[1OnX`>XFooooo`?o0000
?Oooool004Wooooo0ol0001Uooooo`03ojNojonW`>coYl3/00OoYl3/1?nW`N`4ojNoj`SoYl3/0_nV
`>`6ojNoj`SoY/3/0_nV`N`6ojJok0SoY/3/00?oZ<7/ojK0k?nV`>`01OnV`>`7ojS1k003ojK0k?nX
`NcoZ<7/00CoZ<7/00?o0000ojS1k?nX`>/01OnX`>/2ojS1j`SoZ<3Z5oooool00ol0003ooooooooo
o`0kooooo`00Aoooool2o`0006Gooooo1OnW_n/9ojO0k003ojO1k?nW_n_oYko[00GoYko[1_nW`>`2
ojNojPSoYko[1_nV`>`00onW_n_oY[o/ojJok007ojJok0KoY/3/00?oY[o[ojK0k?nV`>`01_nV`>`4
ojS1k0GoY/3/1OnX`N`00ol0003oZ<7/ojS1k002ojS0j`KoZ<7[2?nX`>XGooooo`03o`000?oooooo
oooo03[ooooo0014ooooo`?o0000I?ooool9ojNoj`KoYl3/0_nW_nX8ojNoj`CoYl3/1OnW_nX8ojNo
j`;oY/3/1OnW_n/9ojJok0;oY/3/1OnV_n/8ojK0k003ojS1k?nV`>coY/3/00KoY/3/1?nX`N`00ol0
003oZ<7/ojK0k009ojS1j`KoZ<3Z00?oZ<7[ooooooooool05_ooool00ol0003oooooooooo`0ioooo
o`00@Oooool3o`0006Cooooo3OnW_n/2ojO0k0KoYkoZ2?nW_n/00onW`>coYkoZojNojP06ojNojPKo
Yko[00?oZ;kZojNojonW_n/01_nW_n/6ojJok0;oYko[2?nV_n/6ojK0k0;oY[o[2OnV`>`2ojS1k003
ojK0k?l0003oY/3/00;oY/3/2OnX`N/2ojS0jPGoZ<7[5oooool00ol0003oooooooooo`0iooooo`00
?oooool3o`0006?ooooo00?oYkoZojNojonW_n/03?nW_n/2ojNnjPSoYkoZ1_nW_n/2ojRnjPWoYkoZ
0_nW_n/5ojRnjPSoYko[0_nV_n`6ojNoj`SoY[o[0_nV`>`6ojJoj`OoY/3/00GoY[o/ojK0k?nV`>co
Y/3/o`000004ojK0k0KoZ<7[0_nW`N`8ojS1jaOooooo00?o0000ooooooooool0>?ooool003cooooo
0ol00003ooooo`03o`000?oooooooooo05gooooo1OnW_nX:ojNoj`KoYkkZ2?nW_nX2ojNoj`KoZ;kZ
1onW_nX00onX_n[oZ;kZojRnjP06ojRnjPKoYko[0_nX_^X8ojNoj`KoY[o[00?oYkoZojJojonV_n/0
1onV_n/4ojK0k0CoY[o/0_nV`>`00ol0003oY/3/ojK0k003ojK0k0;oZ<7[1_nW`N`8ojS1jaKooooo
00?o0000ooooooooool01oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02cooooo000jooooo`;o0000
Hoooool00onW_^[oYkoZojNojP06ojNojPKoYko[0_nX_^X8ojNnjPKoYkoZ00?oZ;oZojRnj_nX_^X0
1onX_^X4ojNojPCoZ;oZ2?nX_^X2ojNoj`KoZ;kZ2?nW_n/2ojJoj`GoYkoZ2OnV_n/00onV`>coY[o/
ojJok005ojJok003ojK0k?l0003oY/3/00?oY/3/00?oY[o/ojO1k?nW`N`01onW`N`6ojS1j`03ojO1
k?oooooooooo01Gooooo00?o0000ooooooooool01_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02co
oooo000gooooo`?o0000Hoooool4ojNnjPSoYkoZ0_nW_n/6ojRnjPSoYkkZ0_nW_nX5ojRojPWoZ;kZ
00?oYkoZojRoj_nX_nX01OnX_nX6ojRnjP03ojW0jonX_^[oZ;kZ00OoZ;kZ1_nW_n/00onX_n[oYkoZ
ojNojP06ojNojPKoY[o[0_nW_n/8ojJok0;oY/3/00?o0000ojK0k?nV_n`00onV_n`9ojO1k0;oZ<7[
1OnW`N`Gooooo`03o`000?oooooooooo00Gooooo00Go410@oooooooooooooooooa0@400/ooooo`00
=Oooool2o`0006Cooooo1onW_^X6ojNojP03ojRoj_nX_^[oZ;kZ00OoZ;kZ1_nW_^X00onX`>_oZ;oZ
ojRojP06ojRojPKoZ;kZ0_nX`N/8ojRojPCoZ;kZ1?nY`>/9ojRnjP;oYko[1OnX_nX8ojNojP;oY[o[
1_nW_n/8ojJok003ojK0k?l0003oY[o/00GoY[o/1_nW`N`2ojJok0SoYl7/5_ooool00ol0003ooooo
ooooo`05ooooo`05o`000?ooooooooooooooool00000;?ooool003;ooooo0ol0001Tooooo`WoYkkZ
1?nW_nX4ojRojPWoZ;kZ0_nW_^X5ojS0j`SoZ;oZ0_nX_^X6ojS1j`SoZ;oZ00?oZ;kZojW0jonY`>/0
1OnY`>/7ojRnjP03ojW1jonX_n[oZ;oZ00KoZ;oZ1_nW_nX00onX_n[oYko[ojNoj`07ojNoj`KoY[o/
00?oYko[ojJok?l000001onV_n`2ojO1k0KoY[o/2?nW`N`Fooooo`03o`000?oooooooooo00Cooooo
00Go0000ooooooooooooooooo`00000/ooooo`00<?ooool2o`0006Cooooo3OnW_^X00onW_n[oZ;oZ
ojRojP05ojRojPOoZ;kZ00?oZ<7/ojS0jonX`>/01_nX`>/6ojRojP;oZ<7/2?nX`N/6ojRojP03ojS2
k?nY`>_oZL3[00KoZL3[1?nX_^X5ojW1j`SoZ;oZ0_nW_nX5ojRojPWoYko[0_nV_n`5ojNoj`03o`00
0?nV_ncoY[o/00CoY[o/00?oYko[ojJok?nV_n`01_nV_n`6ojO1k0;oY/3/5oooool00ol0003ooooo
ooooo`03ooooo`05oa0@4?ooooooooooooooool@4100;?ooool002gooooo0ol000000ooooooo0000
ooooo`1Pooooo`ooYkkZ0_nX`>/8ojRojPCoZ;kZ1?nX`N`8ojS0j`;oZ;oZ1_nX`N`8ojS1j`;oZ;oZ
1OnX`^`8ojW0j`03ojRnj_nY`N_oZL7[00KoZL7[1_nX_nX00onY`N_oZ;oZojRojP06ojRojPKoYko[
0_nX_nX7ojNoj`03o`000?nV_ncoY[o/00;oY[o/1?nW_n/8ojJok0;oYl7/1_nV`>`Fooooo`;o0000
1?ooool01OmgMgOoV9RHoooooonHV9SoMgMg02cooooo000Zooooo`?o0000Hoooool?ojNnjPKoZ<3[
2?nX_nX00onX_^[oZ<7/ojS1k005ojS1k0KoZ<3[0_nV_n/8ojS1k0KoZ<7[00?oY[o[ojS2k?nX`^`0
1_nX`^`6ojW0j`;oYl7/2OnY`N/2ojRojPGoZL7[2?nX_nX2ojNoj`KoZ;oZ1_nW_n/00ol0003oYko[
ojJok007ojNoj`KoY[o/00?oY[o[ojK0k?nV`>`01onV`>`Cooooo`;o000000?oooooo`000?ooool0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02cooooo000Xooooo`;o0000Hoooool?ojNnjP[oZ<3[
1_nX_nX00onW`NcoZ<7/ojS1k007ojS1k0;oZ<3[1_nV_n/8ojS1k0;oZ<7[1OnV_n/8ojS2k0;oZL3[
1_nW`N`7ojW1j`03ojO0k?nY`N_oZL7[00KoZL7[1_nX_nX00onY`N_oZ;oZojRojP07ojRojPGoYko[
00?o0000ojRoj_nW_n/02?nW_n/2ojJok0GoY[o[2OnV`>`Fooooo`03o`000?oooooooooo03;ooooo
000Uooooo`?o0000H_ooool?ojNnjPkoZ<3[0_nX_nX5ojO1k0OoZ<7/0_nW_NT8ojJoj`KoZ<7/00?o
YkcYojJojonV_n/01_nV_n/6ojS2k003ojJmj_nW`NcoYl7/00OoYl7/1?nY`N/4ojO0k0SoZL7[0_nX
_nX5ojW1j`WoZ;oZ0_nW_n/00onX_n[o0000o`000002ojRojPOoYko[00?oZ;oZojJojonV_n/01_nV
_n/6ojK0k0;oY[o/5_ooool00ol0003oooooooooo`0booooo`008oooool2o`0006;ooooo3onW_^X2
ojS1k0koZ<3[00?oYl3/ojO1k?nW`N`01_nW`N`4ojS1k0GoYkgY2?nV_n/2ojS1k0GoYkcY2?nV_n/2
ojS2k0GoY[gZ2OnW`N`00onY`N_oYl3/ojO0k005ojO0k0KoZL7[00?oY/3/ojW1jonY`N/01_nY`N/6
ojRojP;oZL7[0ol000000onX_n[o0000ojRojP02ojRojPCoYko[1?nX_nX8ojJoj`;oY/3/1_nV_n`F
ooooo`03o`000?oooooooooo037ooooo000Pooooo`?o0000HOooool?ojNnjPKoZ<7/2_nX`>/5ojO0
k0SoYl7/00?oZ<7/ojNmjOnW_NT01_nW_NT6ojJoj`03ojRiiOnW_>WoYkcY00KoYkcY1_nV_n/00onX
^^KoY[gZojJmjP06ojJmjPKoYl7/0_nW_>T9ojO0k0;oZL7[1OnV`>`8ojW1j`;oZ;oZ0_nY`N/3o`00
0003ojW1jonX_n[oZ;oZ00;oZ;oZ00Go0000ojRoj_nX_n[oZ;oZojNoj`07ojRojPKoY[o[00?oYko[
ojJok?nV_n`01_nV_n`Gooooo`03o`000?oooooooooo033ooooo000Oooooo`;o0000H?ooool?ojNn
jP;oYl7/2?nX`N`6ojS0j`03ojNojonW`>coYl3/00KoYl3/1_nW`N`2ojNki`WoYkgY0_nV_n/5ojRi
i@SoYkcY0_nV_n/5ojRjiPSoY[gZ0_nW`N`6ojNlj@OoYl3/00?oYkcXojK0k?nV`>`01_nV`>`6ojW1
j`03ojO0k?nY`N_o000000;o00001?nY`N/5ojRojP03o`000?nY`>[oZL3Z00WoZ;oZ0_nV_n/5ojNo
j`SoY[o/5_ooool00ol0003oooooooooo`0`ooooo`007oooool00ol0003oooooo`00001Mooooo`ko
YkkZ1_nW`N`8ojS1k0;oZ<3[1OnW_n/8ojO0k0;oYl7/1_nW^nL7ojNmj@03ojReh_nX^NGoZ;WU00Ko
Z;WU1_nW_>T00onY]>7oZ;[VojRjiP06ojRjiPKoY[gZ0_nY^>@8ojNlj@CoYl3/1?nW_>P8ojK0k0;o
ZL7[0_nW`>`3o`0000SoZL7[0_nX_nX3ojW0jP03o`000?nY`>[oZL3Z00OoZ;oZ00?oZKoZojNojonW
_n/01_nW_n/6ojJok003ojJojooooooooooo01Gooooo00?o0000ooooooooool0;oooool000cooooo
1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool01?l0003oooooooooool0001Joooo
o`goYkkZ2_nW`N`6ojS1k003ojNnj_nW_n_oYko[00KoYko[1_nW`>`2ojNii@SoYk_W1?nW_NT4ojRe
hPSoZ;WU0_nW_>T5ojVdh@SoZ;[V0_nV_NX6ojVhi0SoYkcY00?oYl3/ojNlj?nW_>P01OnW_>P6ojK0
k003ojNljOnW`>co000000;o00001?nW`>`6ojW1j`03ojS1k?nY`>[oZL3Z00?oZL3Z00Co0000ojW0
j_nY`>[oZL3Z1?nX_nX4ojVojPSoYko[0_nV_n`5ojJojaOooooo00?o0000ooooooooool0;_ooool0
00cooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_oo
ool2o`0000;ooooo00?o0000ooooooooool0EOooool=ojNnjPgoYl7/0_nX`N`5ojNnjPSoYko[0_nW
`>`6ojNii@SoYk_W00?oYkgYojReh_nX]N801OnX]N86ojRii@03ojZ^f_nY]>7oZKCQ00KoZKCQ1_nX
^^H00on[/McoZKSTojVhi007ojVhi0KoYkcY00?oZ[SSojNlj?nW_>P01onW_>P2ojK0k0;oYkcY0ol0
0008ojO0k0;oZL7[1OnX`N`5ojW0jP05o`000?nY`>[oZL3ZojW0j_nX_nX01onY_nX6ojNoj`03ojRo
j_nV_n_oY[o[00KoY[o[5_ooool00ol0003oooooooooo`0^ooooo`001?ooool6o`0000?ooooo00?o
V9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@00Gooooo0_l00004ooooo`03o`00
0?oooooooooo057ooooo3onW_^X=ojO1k0WoYkkZ1_nW_n/2ojNgi0SoYkWU1_nW^nL00onX/=goZ;GR
ojRehP06ojRehPCoZ;WU1?nZ[]X8ojVdh@;oZ;[V1On[/M`9ojVhi0;oYkcY1OnZ^><7ojNlj003oj^h
honW_>Wo000000;o00001?nW_>T6ojO0k003ojJmj_nX`NcoZ<7/00KoZ<7/1OnY`>X00ol0003oZL;[
ojW2j`09ojVojP;oYko[1OnX_nX8ojJojaKooooo00?o0000ooooooooool0;Oooool000kooooo00?o
V9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`1=oooooa3oYkkZ3?nW`N`=ojNnjP;oYko[1_nW]n@8ojNii@;oYk_W
1OnX/=d8ojRehP03ojRiiOnZ[][oZZkJ00GoZZkJ1_nY]>400on][MOoZk7Loj^ag006oj^ag0OoZKST
00?o[K3JojZhhonZ^><01_nZ^><4ojNlj0;oZkSS0_l00008ojNlj@;oYl3/1OnV_NX8ojS1k0;oZL3Z
0_nY`^/01?l0003oZL;[ojW2jonY`^/7ojVojP03ojW0j_nX_n[oZ;oZ00KoZ;oZ1_nV_n/00onW_n_o
ooooooooo`0Eooooo`03o`000?oooooooooo02cooooo000?ooooo`03ogMgMomVIVKooooo00;ooooo
00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0BOooool@ojNnjPcoYl7/3onW_^X00onW]N?oYkOTojNgi007ojNgi0KoYkWU00?oZ:cJojR`gOnX
/=d01_nX/=d6ojRehP03oj^[eonZ[][oZZkJ00KoZZkJ1?nY]>44ojf]e`OoZk7L1?nY^>@5ojf`fPSo
Z[SS00?oYkcXoj^hhol000000_l00003oj^hh`KoYkcY00?oZk[TojJmj_nV_NX01_nV_NX6ojS1k003
ojJojonY`^_oZL;[00?oZL;[00?o0000ojW2jonY`^/01?nY_nX5ojW0jPSoZ;oZ0_nV_n/5ojNojaGo
oooo0_l0000^ooooo`004?ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@oooooooo
ool00oooool2o`0000Oooooo00?o0000ooooooooool0A_ooool00onW_n[oYkkZojNnjP0<ojNnjP03
ojO0jonW`NcoYl7/00WoYl7/3onW_^X5ojNeh`WoYkOT0_nW^ND5ojR/fPSoZ;3M0_nX]N85oj^[e`So
ZZkJ00?oZKCQojf]eon][ML01?n][ML8oj^ag003ojVhi?n]/=[o[K3J00Ko[K3J1_nZ^><3o`0000Ko
ZkSS1?nW_>T4oj^ji0SoY[gZ0_nX`N`5ojJoj`GoZL;[00Co0000ojW2jonY`^_oZKoZ2?nY`>X6ojRo
jP03ojW0j_nW_n_oYko[00KoYko[5_ooool00ol0003oooooooooo`0[ooooo`003?ooool01Ol0003o
^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0@_ooool5ojNojP[oYkkZ1OnW`>/7ojO1k0ooYkkZ00?oYkCR
ojNehonW]N<01_nW]N<7ojNgi003ojNYf?nX[=[oZ:cJ00KoZ:cJ1_nX/=d00on]ZmKoZj_Goj^[e`06
oj^[e`KoZZkJ00?o/:kFojf]eon][ML01_n][ML6oj^ag003ok:`e_n]/=[o[K3J00So[K3J0_nZ^><3
o`0000;o[[3J2?n[^><00onW_>WoZk[Toj^ji005oj^ji0KoY[gZ00?oZK_VojJojonV_n/01_nV_n/5
ojW2j`03o`000?nW`>coZL3Z00WoZL3Z0_nX_nX5ojW0jPSoYko[5Oooool00ol0003oooooooooo`0[
ooooo`003?ooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0?_ooool2ojNoj`OoYkoZ1_nW
_^X2ojNoj`OoYl3[1?nW`N`>ojNnjPGoYkCR2?nW]N<4ojNgi0CoYjWH1onX[=X4ojR`g@Co[J_F1on[
ZmL4ojZ^fPCo/:kF1on][ML4oj^ag0Co/[3F2?n]/=X3o`0000Ko[[3J1_n[^><00on_/]_oZk[Toj^j
i007oj^ji0;oY[gZ1OnY^nH8ojJoj`;oZL;[0_nW`>`00ol0003oYl3/ojO0k008ojW0jP03ojW1jonY
`>[oZL3Z00GoZL3Z1_nW_n/2ojRojaKooooo00?o0000ooooooooool0:_ooool001kooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0jooooo`KoYko[1onW_nX2ojNnjPKoYko[1onW`>/0
0onW`NcoYkkZojNnjP0<ojNnjP03ojJdh_nW]>;oYkCR00GoYkCR2?nW]N<00onW]nCoYjWHojNYf004
ojNYf0SoZ:cJ00?oZ;3Mojf[e_n]ZmH01?n]ZmH8oj^[e`03ojZ^f_n`[]Ko/:kF00Co/:kF2?n][ML0
0on[/Mco/[3Fok:`eP05ok:`ePCo[K3J0ol00002okJcePSo[[3J0_n[^><5ojnbf`OoZk[T00?o[kGM
ojVki_nY^nH01_nY^nH6ojJoj`03ojNmjOnW`>coYl3/00?oYl3/00?o0000ojO0k?nW`>`01?nY`>X5
ojW1j`OoZL3Z0_nW_n/6ojRojaKooooo00?o0000ooooooooool0:Oooool001gooooo0ol0000;oooo
o`03o`000?oooooooooo03Kooooo0_nW`>/8ojNoj`GoYkoZ0_nW_^/8ojNoj`GoYl3[0_nX_n/;ojNn
jPGoY[CR1onW]>86ojNeh`03ojNXeonWZMSoYjWH00KoYjWH1_nX[=X00on/[=Oo[J_Fojf[eP06ojf[
ePKoZj_G00?o/;7Hok2^e_n`[]H01_n`[]H6ojf]e`03okBcf?nb/=Ko/[3F00Oo/[3F0ol00005okJc
ePOo[[3J00?o^;GGojnbfon_/]/01_n_/]/4oj^ji0Co[kGM2?nY^nH2ojJoj`GoYkgY1OnW`>`01?l0
003oYl3/ojO0k?nY`>X7ojW1j`OoZL3Z2?nX_n/Fooooo`03o`000?oooooooooo02Wooooo000Moooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool0<_ooool6ojO0j`SoYko[00?oYkoZojNn
jonW_^/01?nW_^/8ojNoj`03ojO0jonX_n_oZ;o[00CoZ;o[1onW_^X00onV]N?oY[CRojJdhP06ojJd
hPOoYkCR0_nW]N<5ojNXe`OoYjWH1?nX[=X4ojb/e`Oo[J_F1?n[ZmL4ok2af0Oo/:kF1?n][ML4okBc
f0Go/[3F0ol000000onb/=Ko[K3JokJceP06okJcePGo[[3J0onh]ML8ojnbf`03oj^ji?n_]Mgo[kGM
00Go[kGM1_nY^nH00on^^N;oYkgYojNmj@06ojNmj@GoYl3/00?o0000ojJnjonV_^/02?nY`N/7ojW0
jPSoZ;o[5_ooool00ol0003oooooooooo`0Xooooo`007Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo02oooooo00?oZ<3[ojO0jonW`>/01_nW`>/6ojNoj`03ojNnj_nW_^_oYkk[00Ko
Ykk[1_nW_n/00onX`>_oZ;o[ojRoj`06ojRoj`CoYkkZ1?nV]N<7ojJdhPKoYkCR00?oYZOGojNXeonW
Z=L01_nWZ=L7ojNYf003ojR/f_n/[=Oo[:cG00Co[:cG2?n]ZmH00on[ZmOo/;7Hok2af004ok2af0So
/:kF00?o[JgGokBcf?nd/mP01Ond/mP01?nb/=Ko0000o`000?l00003ok:`eP03okJhf_nf/mKo][?F
00Ko][?F0on^/=X6okRee`Ko[k;K00?o^;OGojnegOn_]Md01on_]Md2ojVkiPGo[[WR2?nW_NT2ojO0
k0;oY[k[00Co0000ojJnjonV_^_oY[k[1_nY`N/00onW`>coZL3ZojW0jP06ojW0jPKoZ;o[00?oZ<3[
ooooooooool05Oooool00ol0003oooooooooo`0Wooooo`007Oooool2o`0000oooooo00?o0000oooo
ooooool0:oooool5ojS0j`SoYl3[0_nW_n/5ojNnjPSoYkk[0_nW_n/5ojS0j`SoZ;o[00?oYkkZojJe
honV]N<01OnV]N<7ojJdhP;oYkCR1OnVYmL7ojNXe`KoYjWH00?oZjgIojb/eon/[=L01_n/[=L6ojf[
eP03ojnegOn`/MSo/;7H00Ko/;7H1_n`[]H00onc^Mko];?HokBcf005okBcf0;o00001?nb/=H4okJh
fPSo][?F00?o[[3JokReeonh]ML01Onh]ML4ojnbf`Co^;OG1on_]Md00ong]mWo[[WRojjihP06ojji
hPKoYkgY0_n[_NH4ojJnj`04o`000?nV_^_oY[k[ojJnj`;oZL7[1OnW`>`8ojW0jP;oZ;o[1OnX`>/F
ooooo`03o`000?oooooooooo02Oooooo000Mooooo`03o`000?oooooooooo00oooooo0_l0000Xoooo
o`;oZ<7/1onX`>/6ojO0j`WoYkkZ1_nW_^/2ojS1k0OoZ<3[1_nX_n/2ojJfi0OoY[GS1_nV]>800onT
Y]OoYZOGojJWe`05ojJWe`SoYjSG0_nWZMP5oj^]f@Oo[:cG1?n]ZmH4ojneg@Oo/;7H1?n`[]H4ok>i
gP?o];?H0ol00003okBcf003ok:`e_nf^=[o][SJ00Go][SJ1_nf/mH00onh^m_o^;GGokRee`07okRe
e`03ojnbfonh]mOo^;OG00Go^;OG1On_]Md3okNgf@So[[WR0_nW_NT6oj^miPCoY[k[00?o0000ojJn
jonW_^X02?nW`>`6ojW0jP03ojW1jonX`>_oZ<3[00KoZ<3[5_ooool00ol0003oooooooooo`0Voooo
o`007Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02;ooooo1_nX`N`7ojS0j`;o
Yl3[3OnW_^X2ojNnj`KoZ<7/1onX`>/2ojRoj`KoY[KT1onV]N<2ojJdhPGoY:KG1onVYmL6ojNXe`03
ojV]f_n[[MWoZjgI00KoZjgI1on/[=L00on]ZmKo[kGMojneg@05ojneg@Oo/;7H00?o/:kFok>ig_nc
^Mh01?nc^Mh3o`0000Go];?H00?o]<;TokJhf_nf^=X01_nf^=X4okJcePCo^;_K1onh]ML00onj_=_o
^;OGokRge`06okRge`?o[kGM1_ng]mT6ojjihP03ok>hgOn[_NKoZkgV00OoZkgV0_nV_^/2ojNnjP03
o`000?nW_^[oYkkZ00SoYl3/0_nY`>X5ojW1j`SoZ<3[5_ooool00ol0003oooooooooo`0Uooooo`00
7Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01kooooo2_nX`N`5ojS0j`;oYkoZ
3OnW_^X2ojO1k0SoZ<7/1OnX`>/2ojJhiPSoY[KT1OnV]N<00onSY]SoY:KGojBVe`05ojBVe`OoYZOG
1?nWZ=L4ojV]fPOoZjgI1_n/[=L00on^^^?o[kGMojneg@06ojneg@Ko/;7H0_naaNT3ok>igP?o0000
0_nc^Mh4okBcf0Co]<;T2?nf^=X00onf/mKo^;_KokRkf`05okRkf`Go^;GG0onj_=/8okRge`03ojne
gOng]mWo]kOI00Go]kOI1?n^^N84ok>hg@OoZkgV00?o[kcSojNnj_nW_^X00_nW_^X01?l0003oYkkZ
ojNnj_nW_^X6ojO0k003ojJok?nY`N_oZL7[00KoZL7[1_nX`>/00onY`>[oooooooooo`0Dooooo`;o
00009_ooool001cooooo0ol0000Dooooo`03o`000?oooooooooo01_ooooo3OnX`N`00onX`>_oYkoZ
ojNojP04ojNojPWoYkkZ1_nW`N`8ojS1k003ojS0jonV^>KoY[SV00CoY[SV2?nV]^@00onV]N?oXjKH
oj>Vf003oj>Vf0OoY:KG1onVYmL00onWZ=OoZJgJojV]fP05ojV]fPOoZjgI0_n/[=L5ojjjh`So[kGM
0_n`/MP5ok75j@?o00001_nc^Mh00ond/mSo]<;TokC2i005okC2i0Ko][SJ00?o]<SYokRkfonh^m/0
1_nh^m/3okRee`Ko^[cK1_nh]mL00onl_=[o]kOIokNgf@07okNgf@03ojjih_nc^=go/kSM00Go/kSM
1?n[_NH4ojnlh`CoYkkZ00Co0000ojNnj_nW_^[oYkkZ0_nW`>`5ojJok0SoZL7[0_nX`>/5ojW0jQCo
oooo00?o0000ooooool000009_ooool001cooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`0Iooooo`goZ<7/00?oYko[ojNoj_nW_nX01_nW_nX6ojNnjP03ojO0k?nW`NcoYl7/00KoYl7/
1_nX`N`00onW^nSoY[SVojJhiP06ojJhiPKoY[KT00?oXZOIoj>Vf?nSY]P01OnSY]P6ojBVe`KoYZOG
00?oYjkLojV]f_nY[MX01_nY[MX6oj^]f@03ojc2j_n^^^?o[[[S00Ko[[[S1_n_]Md2oj_Cm@?o/LGY
0ol00002ok75j@Ko/kWN00?o[=CeokC2i?nd`^@01_nd`^@4okJhfPCo]<SY2?nh^m/00onh]MOo^[cK
okZlf`05okZlf`Co^;OG1?nl_=X7okNgf@03okflfOnc^=go/kSM00Oo/kSM00?oZkgVojnlhon__><0
1On__><4ojNnjP03o`000?nW_^[oZ[kX00SoY[o/1onY`N/8ojW0jQKooooo00?o0000ooooooooool0
8oooool000[ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^1_ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo01Kooooo3?nX`N`5ojNoj`SoYkoZ0_nW_^X5ojO0
k0SoYl7/0_nX`N`5ojNkj0SoY[SV0_nV]^@5oj:Wf@KoXjKH1onTY]L2ojJWe`GoYjkL2?nY[MX3oj^]
f@Co[<;Z2?n^^^<3ojneg@CoZm?e0ol00006ok75j@;o/kWN1On/e?D8okC2i003okJhf_ndb>Wo]<SY
00Go]<SY1_nh^m/00onebNWo^[cKokZlf`07okZlf`03okRgeonl_=[o_;cJ00Go_;cJ1Ong]mT3okfl
f@Oo/kSM00?o^[cKojnlhon__><01on__><2ojNnjP03ojZnj?l0003oZ[kX00;oZ[kX2?nV_n`7ojW1
j`SoZL3Z5Oooool00ol0003oooooooooo`0Sooooo`003?ooool00ol0003oooooooooo`02ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
01;ooooo3?nX`N`2ojS0j`OoYko[1_nW_nX2ojJnj`OoYl3/1_nW`N`2ojNmj@OoYk_X1_nV^>H00onR
ZMcoXZOIoj:Wf@05oj:Wf@OoXjKH1OnTY]L00onU[McoYjkLojN^g006ojN^g0SoZJgJ00?oZjgIojc2
j_n/`^X01?n/`^X8ojjjh`03ojnegOn[doGoZm?e00?o00000_n[doD6ok75j@;oT]cn1on/e?D6okC2
i0;oX][k1ondb>T4okRkf`Co]LWY1onj_=/00onha^Go_;cJokblfP06okblfP?o]kOI1_nm_=T4ok>h
g@Co^[cK1on__><00onc_>3oZ[kXojZnj002ojZnj004o`000?nZ_^SoZ[kXojZnj0KoY[o/00?oY[o[
ojW1jonY`N/01OnY`N/8ojW0jQKooooo00?o0000ooooooooool08_ooool00003ooooool0003o0000
00Co00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool2
o`0001Wooooo00?o0000ooooooooool03_ooool3ojO0j`WoZ<7/1_nX`>/7ojNoj`;oYkoZ1_nV_^/7
ojO0k0;oYl7/1_nW_NT7ojNkj0;oY[SV1OnRZM`7oj:Wf@OoXjKH00?oY:KGojF]g?nU[M`00onU[M`8
ojN^g0KoZJgJ0_nZb>l7ojc2jPKo[[[S0_nNg_d2o`0000KoZm?e0_naaNT6oi;LoPOo[=Ce0_nd`^@6
oj;Jn`Oo]<SY00?o^;_KokG9jOnebNT01OnebNT4okZlf`Co^<KU2?nl_=X00ong]mWo_KcIokflf@06
okflf@03ok>hgOnj_=_o^[cK00Go^[cK1?n__><4ok>lh0CoZ[kX00Co0000ojZnj?nZ_^SoZ[kX0_nV
_n`5ojJoj`OoZL7[2?nY`>XFooooo`03o`000?oooooooooo027ooooo000<ooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool02_ooool7ojO0j`KoZ<7/00?oZ<7[ojS0jonX`>/01_nX`>/5ojNoj`;oY[kZ2?nV
_^/5ojO0k0?oZ<3[1onW_NT5ojNkj003oj>]gonRZMcoXZWL00GoXZWL1onRYmT6oj>Vf003oj>[g?nU
[McoYJgL00GoYJgL2?nW[]`2ojV]fPKoZ/S_1on/`^X2ojjjh`;oW]km0ol00002oikNo@?oZm?e1Omg
f?`7oi;LoP?o[=Ce1Omddoh7oj;Jn`?o]<SY1?nJeod8okG9j@03okZlfonha^Go^<KU00Go^<KU1_nl
_=X00onk`^3o_KcIokflf@06okflf@03okk0g?nj_=_o^[cK00Oo^[cK00?o[kcSok>lh?nc_>001?nc
_>05ojZnj003o`000?n]_nOo[KoW00OoY[o[1_nY`N/2ojS0j`SoZL3Z5Oooool00ol0003ooooooooo
o`0Qooooo`003?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001Ooo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Oooooo0onV_n/7ojO0j`;oZ<7/1OnX
`N/8ojS0j`03ojNojonV_^[oY[kZ00CoY[kZ2?nV_^/00onW`>coZ<3[ojS0j`05ojS0j`OoYkgY00?o
Yk_Xoj>]gonS[Ml00onS[Ml7oj:Yg0OoXZOI0_nSY]P5oj>[g0OoYJgL1_nW[]`2ojS;lPSoZ/S_0on/
`^X4ohoOoP?o00001?nNg_d3ofgGm`OoMmSl0onBg?h5oeg<m`OoM=?n0onRf_/4ofK;o0OoV]Om1_ne
bNT00onNeO_o^<KUokS6i@06okS6i@Co_;cJ1?nk`^06okflf@?o_/3L1onj_=/00ono_m[o/kcPok>l
h006ok>lh0;oZ[kX0_n]_nL01?l0003o[KoWojfoion]_nL7ojJoj`;oZL7[1_nX`>/6ojW0jP03ojW1
j_oooooooooo01Cooooo00?o0000ooooooooool08?ooool000cooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`03ooooo`OoY[o[1OnW`>/2ojS1k0OoZ<7[1_nX`>/2ojNnj`OoY[kZ1_nV_^/2ojS2k0SoZ<3[
0onW_NT3ojBch`OoXjgO1_nRZM`6oj:Wf@03oj6Yg?nSZmcoXj_L00KoXj_L1onU[M`2ojN^g0KoZ<_b
1_nZb>l3ohcQo@;oSmon0ol00002ohoOoP;oW]km1om]eoL3ogOHo0KoG/cg1_mMc?L3ogCCoPGoD/;g
1_mVbo`7oi[Go@;o]LWY1OnNeO/8okS6i@03okblf_nk`^3o^l;P00Go^l;P0onm_=T6okk0g0Go^[cK
0ono_mX6ok>lh003okVog_n]_nOo[KoW00?o[KoW00?o0000ojfoion]_nL01_nV_n/2ojNoj`SoZ<3[
0_nY`>X5ojW1jQKooooo00?o0000ooooooooool07oooool000cooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_l0000Nooooo`03o`000?ooooooYko[00;oYko[
2?nV_n/00onW`>_oZ<7/ojS1k004ojS1k0OoZ<7[0_nX`>/6ojNnj`OoY[kZ0_nV_^/6ojS2k0KoZ<3[
00?oYKSVojBchonT/n<01OnT/n<7oj>]g`KoXZWL0_nRYmT5oj6Yg0OoXj_L1_nU[M`2ojO:lPSoZ<_b
0_nZb>l5ohcQo@?o00000_n?goh6ofoImP?oKMOg1_medOh3oek<m`GoQL?l1omUa?h6oe;2m`KoI/_l
0onJeod4of?5o@OoW]Gk1_nha^D00onYd_Go^l;Pok_2h007ok_2h003okflfOnn`=co_/3L00Go_/3L
0onj_=/5oknofPGo/kcP0oni_mh5ojfoi`03o`000?n]_nOo[KoW00;oY[o[1_nW_n/6ojS0j`03ojO0
jonY`N[oZL7Z00KoZL7Z5Oooool00ol0003oooooooooo`0Oooooo`002_ooool00omEEEGoIVIVo`00
0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`0Looooo`OoYko[
1_nV_n/9ojS1k0GoZ<7[0_nW_n/8ojNnj`GoY[kZ0onW`>`7ojS2k0;oZ<3[1OnU^>H7ojBch`OoXjgO
0onRZM`2oinVf`SoXJWL1onSZm`2ojF]g0KoYl[b1_nXbo84ohkSo004ohcQoOl0003o0000o`0000Go
NMgh1?m_fOH5oh_Ao`CoMM7n1?nJ`O<7ohG3o0?oILCn1On?_?D7of^lo@KoCK[h1OmSaOd7oikEn`;o
^<KU1OnYd_D7ok_2h003okG;j_nn`=co_/3L00Oo_/3L00?o^[cKoknof_no_mX01?no_mX3ok>lh0Ko
^KoN1On]_nL00ol0003o/<3Vok30iP08ojNoj`;oZ<3[1OnW`>/8ojW1jQGooooo00?o0000oooooooo
ool07_ooool001_ooooo00?o0000ooooooooool06Oooool;ojNoj`;oY[o[3OnX`N`00onX`N_oYko[
ojNoj`04ojNoj`SoYkk[00?oY[kZojO0k?nW`>`01OnW`>`5ojS2k003ojNljOnU^>KoYKSV00KoYKSV
1_nT/n<6oj>]g`03oifTfonOY]_oWjKK00CoWjKK1onQZM`6oj>[g0?oY/Ka1onWb_82ojS;lPGoS^?l
0ol00002ohCRn@CoNMgh1OnHco/6oh_Ao`;oXkg/1onJ`O<3ohG3o0CoXK[Z2?n?_?D3of^lo@CoTK[b
1omW]O`2od^en@;oHlGm0onNeO/4of_4oPOoZM;e1?nk`^04okG;jPOo_/3L00?o_<CPoknof_no_mX0
1_no_mX00onc_>3o^KoNokVogP06okVogP;o[KoW0_n``>H01?l0003o/<3Vok30i_n``>H6ojNoj`03
ojRojonW`>_oYl3[00KoYl3[1_nY`NX00onY`N_oooooooooo`0Dooooo`03o`000?oooooooooo01go
oooo000Kooooo`03o`000?oooooooooo01Gooooo0_nX`>/>ojNoj`goZ<7/0_nX`>/7ojNoj`KoYkk[
0_nV_^/8ojO0k003ojS2k?nW_>WoYkcY00?oYkcY2?nU^>H6ojBch`;oXjgO1OnMY=/6oinVf`OoXJWL
0_nSZm`7ojK6l@GoYl[b1?nDi_`01?n>hoco0000o`000?l00005ohCRn@;oX<kg2?nHco/2oh_Ao`Ko
Xkg/1OnJ`O<2ojNfh`OoXK[Z1_n?_?D00onT]nOoTK[boi6jlP06oi6jlPOoIkGl1Om;]OT6of_4oPOo
ZM;e00?o^l;PokG;j_nebnX01OnebnX4okk0g0Co_<CP1_no_mX00oo0`mco^KoNokVogP06okVogP03
okg2gOn``>Ko/<3V00?o/<3V00Co0000ok30i_n``>Ko/<3V0_nW_n/5ojRoj`SoYl3[0_nY`NX5ojW1
jaCooooo0_l0000Oooooo`006oooool2o`0001?ooooo1_nX`>/>ojNoj`WoZ<7/1_nX`>/7ojNoj`;o
Ykk[1_nV_^/6ojO0k0;oZ<3[1_nW_>T8ojFhiP?oY;?S0_nKY=/8oifTf`KoWjKK1OnQZM`3ojBok@So
Y/Ka00?oYl[boiCVo?nDi_`01?nDi_`2o`0000?oSnOi0_n4h_T6oj3>m`KoV<ok00?oY[[Xoj>mk?nS
_N`01onS_N`00onJ`O?oYkKSojNfh`04ojNfh`OoXK[Z0_n?_?D5ojBgi`SoTK[b0omW]O`4ohbhl`?o
FZoj0_m;]OT6of_4oP?oZM;e1?n4b?h8okG;jP03okk0g?nla>3o_<CP00Go_<CP0ono_mX4ol33g0Ko
^KoN0onm`]d5ok30iP03o`000?n``>Ko//;V00SoZ;o[1onW`>/7ojW1jaKooooo00?o0000oooooooo
ool07?ooool001[ooooo00?o0000ooooooooool04?ooool2ojS1j`SoZ<3[1OnW_n/2ojJoj`OoYko[
2?nX`N`7ojS0j`GoYko[2_nV_^/2ojO0k0KoZ<3[1_nW_>T6ojFhiP03oijYg_nKY=_oVjCK00CoVjCK
1onMY=/7oinVf`03oj6Yg?nT_ngoY;o]00GoY;o]1_nVa_44oi_Vo004oiCVo?l0003o0000o`0000Co
SnOi0_nVd?H8oj3>m`;oV<ok1OnV^^P7oj>mk003ojVdh?nW]^?oYkKS00KoYkKS1OnQ^^X00on[]^7o
Y;OWojBgi`06ojBgi`KoTK[b0_nT^>L7ohbhl`KoFZoj1_m@]?X6ohC8oPKo]L_Z00?oY<ceokc4h?nl
a>001onla>000ono_m[o`<?Lol33g004ol33g0?o^KoN1_nm`]d4ok30iP04ok;2i_l0003o//;Vok;2
iPSoZ;o[1onW`>/7ojW1jaGooooo00?o0000ooooooooool07?ooool001[ooooo00?o0000oooooooo
ool03Oooool6ojS1j`SoZ<3[00?oYko[ojJojonV_n/01?nV_n/7ojNoj`SoZ<7/1onX`>/00onW_n_o
Y[k[ojJnj`0:ojJnj`;oZL;/2?nX`>/6ojNlj@;oYKSV1OnNZMh6oi^Tf`OoWJCK0onOY]/4oj:fi`So
Y;o]0_nVa_45oi_Vo0?o00000_nHj_T2ohoWn@KoY]3f1_nPc_L00onW^NKoY[[XojJjj006ojJjj0Co
Xkg/1?nY]>08ojNfh`03oj6jj_n[]^7oZkKQ00?oZkKQ2?nT]nL2oi6jlPKoY;SW1on<^?<6oeZ_nPKo
D;Cj1_n4b?h2okG;jPGoY<ce1onla>000onha^Go`<?Lol33g006ol33g003okVog_nm`]go_L;M00Ko
_L;M00Go/<3Vok;2i_nb`^Ko//;Vo`000002ok;2iPKoZ;o[0_nY`>X7ojO0j`SoZL7[5Oooool00ol0
003oooooooooo`0Kooooo`006_ooool00ol0003oooooooooo`0;ooooo`WoZ<7[1_nX`>/00onW_n_o
Y[o[ojJoj`06ojJoj`GoYko[2_nX`N`3ojS0j`GoYko[2?nV_^/6ojW2k0SoZ<3[0onW_>T2oj6ah`So
WZWN1_nKY=/5oifTf`03oin_honR]^OoX[KW00KoX[KW1_nT_nd4oj?Uo004oi_Vo?l0003o0000o`00
00GoV>[i0_nZe?H7ojK@mP;oX<kg1OnW^NH8ojJjj003oj>mk?nY]>3oZKCP00GoZKCP1_nW]^<00on^
^>7oZkKQoj^fh@05oj^fh@KoY;OW00?o[[SQojBhionT^>L01onT^>L3ohbhl`CoXKWZ1omj/_H5odbZ
n@KoHkSm1onTc?D4okc4h0Co^<KU1_o0`m`00oo0aMko_L;Mokg2g@06okg2g@03ol75gOnb`^Ko//;V
00?o//;V00?o0000ok;2i_nb`^H00_nX_n/6ojW0jPOoYl3[2?nY`N/Eooooo`03o`000?oooooooooo
00Kooooo1Ol0000?ooooo`006_ooool2o`0000Wooooo3OnX`N/2ojS0j`GoYko[2?nV_n/00onW_n_o
Z<7/ojS1k00:ojS1k0;oYl3[2?nW_n/5ojJnj`;oY[o[1onY`^`6ojS0j`03ojBhionQ/N?oXK7S00Co
XK7S1onNZMh7oi^Tf`03oifTfonO[n?oWjoS00?oWjoS2?nR]^L2ojBok@GoXnGl0ol00002oj3]n0?o
V>[i1_nZe?H5ojK@mPWoYkWV1_nV^^P9ojVdh0CoYkKS1?n^^>47oj^fh@;oY;OW1On^^>47ojBhi`03
ojjih_nQ^N[oXKWZ00KoXKWZ1omj/_H5odbZn@KoHkSm1onTc?D00onla>3o^<KUokS6i@04okS6i@Co
`<?L1?o0aMh6okg2g@?o`LGM1Onb`^H00ol0003o]<?UojW0jP07ojW0jPKoYl3[0_nV_n/8ojW1jaCo
oooo00?o0000ooooooooool01_ooool01OnHV9So8B4Qonk^k_ooooooA4A400oooooo000Jooooo`03
o`000?oooooooooo00Kooooo0_nW_n/<ojS1j`;oYl3[1onW_n/6ojJoj`?oYko[2?nX`N`6ojO0j`So
Yko[00?oY[k[ojJojonV_n/01?nV_n/7ojW2k0;oZ<3[1OnT^>L6oj6ah`OoWZWN0onKY=/3oi^Xg`Oo
WjoS1_nR]^L3ojSPnP;oXnGl0ol00005oj3]n0;o[]cg2?nZe?H00onVd?KoYkWVojNiiP0;ojNiiP;o
Y[[X3OnY]>000onW]^?o[[SQojjhh@05ojjhh@GoZkKQ00?o/KcRojjhhOn^^>401_n^^>44ojBhi`Co
[[WR2?nQ^NX3ogZbmP?oU;S`1?mNZ?L2odbZn@KoHkSm0onTc?D3oh[3nPSo^<KU00?o`<?Lol35g_o0
aMh01Oo0aMh3okg2g@Ko`LGM0onb`^H01?nd`nGo0000okC3iOnd`nD8ojW0jP;oYl3[1_nV_n/7ojW1
jaGooooo00?o0000ooooooooool01_ooool00onHV9So8B4Qonk^kP0@ooooo`006_ooool00ol0003o
ooooooooo`03ooooo`KoYko[2?nX`N/6ojO0j`OoYko[0_nV_n/7ojNoj`GoZ<7/0_nX`N/7ojO0j`Ko
Yko[00?oY[k[ojJojonV_n/01_nV_n/5ojW2k0;oYkkZ1onT^>L6oj6ah`GoWZWN00?oV:CMoi^XgonK
Z=l01OnKZ=l7oin_h`?oX[KW1?nXh?X3o`000003oj?Uo?nPkOSoX>gh00?oX>gh1On^g?L6oj[DmP03
ojRkionW^NKoYkWV00_oYkWV00?oZ;CQojVdh?nY]>003?nY]>000on]^^?o[[SQojjhh@06ojjhh@?o
ZkKQ1?na_>88ojjhh@03ojBhion^^N;o[[WR00Go[[WR1_nQ^NX00on[^nGoU;S`oiBhl005oiBhl0Ko
GZSg1OmD[?T7oh[3nPKo^<KU00?o/LW/ol35g_o0aMh01oo0aMh00onm`]go`LGMol75g@06ol75g@05
ok;2i_nd`nGo]<?UokC3iOl000000_nd`nD6ojW0jP;oZL7[2?nV_n/7ojW1jaGooooo00?o0000oooo
ooooool01_ooool00onHV9So8B4Qonk^kP0?ooooo`006_ooool00ol0003oooooooooo`0:ojNoj`Oo
Z<7[1onW`>/5ojNoj`?oY[o[2?nW_n/00onX`NcoZ<7[ojS1j`04ojS1j`OoYl3[0_nW_n/5ojJnj`So
Y[o[00?oZL;/ojNnj_nW_^X01?nW_^X6ojBhi`OoXK7S00?oWZWNoiRTgOnHY=d00onHY=d7oi^Xg`Oo
WjoS00?oX[KWojSPn_nXh?X00ol00002ojSPnPCoZ>kh00?oX>ghojkLmon^g?L01_n^g?L2oj[DmPGo
Z;_W2OnW^NH5ojRdh@[oZKCP1On]^^<8ojjhh@03oj^fhOna_>;o/KcR00Co/KcR1_n^^>400onb_^?o
[[WRojjihP07ojjihP;oXKWZ1On[^nD7oiBhl0KoGZSg1OmD[?T6oh[3nPCo^<KU1?nabN`7ol35gP03
oko6h?o1aMgo`LGM00Ko`LGM00?o`/ONokC3iOnd`nD00ond`nD00ol0003o]<?UokC3i@02ojW0jPKo
ZL7[1onV_n/7ojW1jaGooooo00?o0000ooooooooool01oooool00omgMgOoIVIVooooo`0>ooooo`00
6Oooool00ol0003oYko[ojNoj`0<ojNoj`OoZ<7[1onW`>/00onW_n_oY[o[ojJoj`05ojJoj`KoYko[
2OnX`N/5ojO0j`;oYko[1onV_^/6ojJoj`03ojS1jonW_^[oYkkZ00KoYkkZ1_nT^>L3oj6ah`?oUj?N
1onHY=d6oi^Xg`KoWjoS00CoYM;go`000?l0003o00000_nXh?X6ojS^n0?o/^Kh1_n^g?L2ojVojPOo
Z;_W1_nW^NH00onW/n7oZ;CQojRdh@05ojRdh@KoZKCP00?oZk_Uojfjhon]^^<01_n]^^<6ojjhh@03
ojfmi_na_>;o/KcR00Ko/KcR0_n^^>45ok:nh`Oo[[WR00?o];oRoj^kiOn[^nD01_n[^nD5oiBhl0;o
XK[[1_md[OD3oe:Tm`;oE:ci1_n:`oX00onha^Go/LW/ok79k005ok79k0Co`<GN1?noa^06ol75g@?o
`/ON1Ond`nD00ol0003o]LGVokG5iP08ojW1j`OoY[o[1onY`N/Eooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool03Oooool001Wooooo00?o0000ojNojonW_n/02onW_n/9ojS1j`GoYl3[
0onW_n/7ojJoj`;oYko[3OnX`N/00onW`>_oYko[ojNoj`04ojNoj`OoY[k[0_nV_n/5ojS1j`SoYkkZ
0onT^>L2oi^[h@OoUj?N1_nHY=d7oi^Xg`;oWjoS0_nUd_L2o`0000;oYM;g1?n_k?P2ojS^n0So/^Kh
00?o[]cgojVoj_nY_nX01?nY_nX7ojRki`;oYkWV1OnW/n47ojRdh@;oZKCP1On[^nD8ojfjh`;o[[SQ
1On]_NH6ok6lhP03ojfnionb_^?o/[kS00Ko/[kS1?n^^N84okBohPSoZk_U00?oU;S`oj6jjonQ^^/0
1?nQ^^/6ogB]m@GoDZCg1_md]OX8ok79k003ol35g_noa^3o_lKP00Go_lKP0oo1aMd6ol;7gP;o]<?U
0_neaNH01?l0003o]LGVokG5i_neaNH7ojW1j`OoY[o[2?nY`N/Cooooo`?o00001?ooool01Ol0003o
^[ZjoooooonHV9So410@00oooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0
003oooooojNoj`08ojNoj`goZ<7[00?oYl3[ojNojonW_n/01OnW_n/5ojJoj`;oYko[3OnX`N/2ojO0
j`OoYko[1OnV_^/3ojO0j`KoZ<7[1_nW_^X00onQ]NOoVj_Qoi^[h@04oi^[h@OoUj?N1_nHY=d3oi^X
g`CoX/3^0ol00002ojGBm`Ko[nch0onek_H6ok;Vn0;o[<O]1onY_nX3ojRki`?oYK;R2?nW/n45ojRd
h@;oZ;_V1on[^nD6ojfjh`03ojZnj?n]_NKo[KgV00Ko[KgV0ona_>84ojfni`So/[kS00?o[[WRokBo
h_nd_n801Ond_n86oj^ki@03ok:nhonQ^^_oXK[[00KoXK[[1_md[OD5oe:Tm`KoM;Gj1_nabN`00onW
aNoo_lKPoko6h007oko6h003ol75gOo2amko`/ON00Co`/ON00?o`l[OokG5i_neaNH00oneaNH01?l0
003o]LGVokG5i_neaNH7ojW1j`OoY[o[2?nY`N/Dooooo`03o`000?oooooooooo00;ooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c00?ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o
0000ooooooooool02?nW_n/;ojS1j`CoYl3[1onW_n/00onV_n_oYko[ojNoj`04ojNoj`WoZ<7[1_nW
`>/7ojNoj`03ojJnjonW`>_oYl3[00GoYl3[1_nX`N/2ojNnjPGoXKGW1_nKZn46oiNSgPGoV:CM0_nM
/NH3oj;0kP?o00000onR`>h00onUd_Oo[nchojo/n003ojo/n0Ko]Nkf0_nbi_P6ojc7k@GoZKoZ00?o
Y;;RojFbh_nU/^801OnU/^88ojNch@03ojRdhOnX^nKoZ;_V00CoZ;_V1on[^nD2ojfjh`GoZ[kX2?n]
_NH00ona_>;o[KkWojfni`04ojfni`Ko/[kS00?o[koVokBoh_nd_n801ond_n82oj^ki@Go/[kS1_nQ
^^/00onX_NSoQ;;cohBbl`05ohBbl`?oEZ7e0_mBY?L6ogBenP;o/LW/1OnWaNl7oko6h003okg7h_o2
amko`/ON00Co`/ON0oo3b]l5okG5iP03o`000?neaNKo]LOW00OoZL7[1_nV_n/2ojNoj`SoZL7[5?oo
ool00ol0003oooooooooo`0Eooooo`003_ooool01Ol@413ooooooooooooooooo410@00Kooooo0_l0
0002ooooo`SoYko[2?nX`N/7ojO0j`GoYko[0_nV_n/7ojNoj`SoZ<7[1onW`>/5ojNoj`?oY[k[1onW
`>/3ojS1j`?oYKcY1onQ]NL6oi^[h@KoUj?N00?oV:CMoifai_nM/NH00onM/NH3o`0000GoX/3^1?nb
iOL00on_k?So]NkfokG^mP05okG^mP;o/m;`2?n/and00onY_n[oY;;RojBbhP03ojBbhPOoYK;R1_nW
/n400onW^^OoZ;_VojRkiP06ojRkiPGoZk_U00?oZKkYojZnj?nZ_^P01_nZ_^P6ojfmiP;oZkoY1on]
_^L2ok:nh`Go[koV1ond_n800onc`NGo/[kSok:nh`06ok:nh`;oXK[[1OnX_NP7ohBbl`GoEZ7e1_m[
[OP7ojO5k`Co_lKP1?nman83ol;7gPKo`l[O1?neaNH01?neanOo0000okG7ioneanL7ojW1j`;oY[o[
1_nW_n/7ojW1jaGooooo00?o0000ooooooooool05?ooool000kooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo00?ooooo1onW_n/8ojS1j`OoYl3[00?oYko[ojJojonV_n/0
1?nV_n/7ojNoj`SoZ<7[1onW`>/00onW_n_oY[k[ojJnj`05ojJnj`GoYl3[0_nX`N/6ojFlj@KoXKGW
1onKZn43oiNSgP;oUjSQ0onM/NH3o`0000;oWK7V1?nR`>h5ok;Um`Co^Nod0_nek_H6ok?Bl0Ko[<O]
00?oY;GTojBbh_nT/^801OnT/^87ojFbhP;oYk?Q1OnW^^L8ojRkiP03oj^kiOnY_^WoZKkY00?oZKkY
2?nZ_^P2ojfmiPKoZkoY1On]_^L00on[`>Wo[koVojnoiP06ojnoiPCo];oR1?nc`ND6ok:nh`03okG2
honX_NSoZ;gX00KoZ;gX1on4/_<5oeJQm@KoJjgh1onWaNl00onoa^3o_LORokg7hP05okg7hP03ol;7
g_o3b]oo`l[O00Ko`l[O00Go]LGVokG7ioneanOo]LOWo`000002okG7i`SoZL7[2?nW_n/7ojW1jaCo
oooo00?o0000ooooooooool05?ooool000kooooo00Go0000ooooooooooooooooo`000005ooooo`03
o`000?oooooooooo00Gooooo1OnW_n/2ojS0j`SoZ<7[1OnW`>/2ojNoj`OoY[o[1OnW_n/3ojW1j`Oo
Z<7[0onW`>/<ojJnj`03ojO0jonX`N_oZ<7[00CoZ<7[1_nU_>T6oj6ei`?oVj_Q0onCXml5oiNXh@?o
00001_nM/NH00onR`>ko/^Ggok;Um`03ok;Um`Ko^Nod0_nmho87ok?Bl0;o[<O]1OnT]N@7ojBbhPGo
YK;R00?oY[WWojNjionW^^L01_nW^^L6ojRkiP03ojRnjOnY_^WoZKkY00GoZKkY1_nZ_^P2ojRojPSo
ZkoY00?o[KkWoj_0jOn[`>T00on[`>T8ojnoiP03okBoh_nc`NGo/l7U00Go/l7U0onb_^<4okG2h`So
Z;gX0on4/_<4ohnfl@?oG9oc0_mFXOD6of^]n0?oYlG_0onO_o07okg7hP03okg8hoo3b]oo`l[O00Ko
`l[O00?oa<cPokG7ioneanL00oneanL00ol0003o]LOWokG7i`08ojW1j`OoYko[1onY`N/Eooooo`03
o`000?oooooooooo01?ooooo000>ooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003o
ooooooooo`06ooooo`03ojNojonX`>_oZ<3[00CoZ<3[2?nX`N/00onW`>_oYko[ojNoj`04ojNoj`Oo
Y[o[00?oYko[ojW1jonY`N/01OnY`N/5ojS1j`;oYl3[3OnV_^/9ojS1j`KoYKcY0onQ]NL2oiBVh@Oo
Tj?O00CoUjSQo`000?l0003o00000_nGZ>46oifaiPCo[MCd0_nbiOL5okW_m0Go_N?b1Oncd_02ojRl
j0OoY;GT1onT/^800onU/^;oY[WWojJii`03ojJii`SoYk[W0_nX^nH5ojRnj@OoZKkY0_nZ_^P6ojRo
jPKoZkoY00?oZ;oZoj_0jOn[`>T01On[`>T6ojnoiP;o[L7X2?nc`ND00onb_^?o]L;SokG2h`04okG2
h`KoZ;gX0_n]`>P7ohnfl@GoG9oc1OmXY_D7oinol0Co_LOR1?nmb><6ol?:g`?oa<cP1OneanL00ol0
003o]<OXokC7j008ojW1j`OoYko[1onY`N/Eooooo`03o`000?oooooooooo01;ooooo000>ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2o`0000Sooooo1onX`>/6ojS1j`;oYl3[1onW_n/5ojJo
j`?oYko[1onY`N/00onX`N_oYl3[ojO0j`04ojO0j`WoY[k[3OnX`N/3ojFlj@;oW[?W1_nDY^44oi>S
g`?o00001_nGZ>42oifaiPOo[MCd1?nlj_@00onikoCo_N?bokgSlP06okgSlP03ok?Bl?nX_>SoZ;cX
00CoZ;cX1onT]N@3ojBbhP?oY;OV1onV^NL6ojNji`;oYkkZ1onX_^T5ojVnj@;oZ;kY2?nX_nX2oj^o
j@GoZ;oZ1on[`>T2ojnoiPKo[L7X1_nc`ND00on``NOo]L;SokG2h`06okG2h`;oZ;gX1_n]`>P7ohnf
l@GoG9oc1OmXY_D7oinol003okg7h_nmb>?o_LSS00Go_LSS0oo3b]l6olC<h0;o]LOW0_ndanP01?l0
003o]<OXokC7j?ndanP6ojW1j`03ojS1k?nW_n_oYko[00GoYko[1onY`N/Eooooo`03o`000?oooooo
oooo01;ooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`08
ooooo`OoZ<3[0_nX`N/6ojO0j`OoYko[00?oY[o[ojNojonW_n/01OnW_n/5ojW1j`;oZ<7[1onW`>/7
ojJnj`goZ<7[00?oXk_ZoijcionN/nL01?nN/nL6oiBVh@03oi>Sgol0003o000000?oTj?O1OnGZ>43
oj6kj`Go[MCd1Onlj_@3ol;/l@Ko_N?b0_n^b>d7ojRlj0GoY;GT00?oXK?UojBgi_nT]nH01OnT]nH7
ojJii`;oYk[W1_nW_^X7ojRnj@03ojVnjOnX_^WoZ;kY00CoZ;kY1_nX_nX00onX_NWoZ;oZojRojP06
ojRojPGoZl3Y0_nY`>X8ojg1j0;o/l7U1On``NL6okG2h`;o]/?U2?n]`>P3ohnfl@?oU;S`1?mQW_42
oebOl`GoJ:Ke1OnO_o000onK^noo_LSSokg8h`07okg8h`03ol?:goo4c>3oa<cP00Coa<cP00?oa<kR
okC7j?ndanP00ondanP01?l0003o]<OXokC7j?ndanP2ojW1j`GoZ<7/1onW_n/7ojW1jaGooooo00?o
0000ooooooooool04Oooool001Sooooo00?o0000ooooooooool02Oooool5ojS0j`?oZ<7[1onW`>/3
ojNoj`CoY[o[2?nW_n/00onY`N_oZ<7[ojS1j`04ojS1j`OoYl3[1onV_^/9ojS1j`GoXk_Z1_nN/nL3
oiBVh@?o00001_nCXml00onGZ>7oXK_[oj6kj`06oj6kj`03ojgDm?nlj_Co_>[d00Co_>[d1_o2k?40
0onmho;o[/S]ojk8k@04ojk8k@OoZ;cX00?oY;GToj6ciOnQ/nD00onQ/nD7ojBgiPGoY[WW2_nW_^X3
ojRnj@CoZ;gY1onX_^T2ojRojPGoZ;gY2?nX_nX00on[`>WoZL3ZojW0jP04ojW0jPKo[L7X00?oZl7Y
ok31ion``NL01_n``NL3okG2h`Go]/?U1_n]`>P00on_`^SoU;S`oiBhl005oiBhl0GoHIka1?mYX_82
ofRVm@03oinol?nK^nooVk__00?oVk__1onmb><2okg9h`Goa<cP0oo4c^85okC7j003o`000?ndanSo
//OY00OoZ<7/1_nW_n/00onX_n_oZL7[ojW1j`06ojW1jaGooooo00?o0000ooooooooool04?ooool0
01Sooooo00?o0000ooooooooool02_ooool00onX`>_oZ<7[ojS1j`05ojS1j`GoYl3[0_nW_n/7ojJo
j`KoYko[00?oZL7[ojS1jonX`N/01_nX`N/5ojO0j`?oY[o[1_nV_^/5ojS1j`?oZ<3[1_nS^nX5oijc
i`?o00001?nDY^43oi>Sg`?oV:cU1onQ^n/3okWNl`Co_>[d1_o2k?42ok_Ik`Oo[/S]0onX_>P3oj2a
i0OoXK?U1onT]nH00onV^NOoYkkZojNnjP0:ojNnjP03ojNmjOnX_NWoZ;gY00KoZ;gY1OnX_^T00onY
_NSoZ;gYojRmj@06ojRmj@KoZ;oZ0_nY_^T7ojW0jP;o[L7X1On[`NT8ok31i`03okG2honf`nGo]/?U
00Go]/?U0_n]`>P5ojo2j0KoU;S`1_mQW_45ofVRlPOoVk__1?nmb><5okg9h`?oa<cP1Oo4c^84okC7
j004ok;7jOl0003o//OYok;7j@OoZ<7/0_nW_n/5ojRoj`OoZL7[5Oooool2o`00017ooooo000Goooo
o`?o00003Oooool7ojS1j`03ojO0jonW_n_oYko[00CoYko[1onV_n/2ojNoj`GoZL7[2?nX`N/00onW
`>_oY[o[ojJoj`05ojJoj`KoY[k[00?oZ<7[ojS0jonX`>/01OnX`>/6oj>kjP05oijciol0003o0000
o`000?n?Y><01_n@Y>87oiR/i@CoXK_[1onig_<00onlj_Co`^caol;/l@03ol;/l@Go^mW_1On^b>d0
0onS]nOoX;7Toj2ai005oj2ai0OoXK?U0onT]nH4ojJlj@WoYkkZ1OnW_NT8ojRmj@03ojRnjOnY_NSo
ZKgX00?oZKgX2?nX_NT2ojRojPKoZKkY1OnY`>X00onY_n[oZl7Yoj_1j@06oj_1j@Ko/<7W00?o[/;X
okK3iOnf`nD01Onf`nD00onea>Go[l;Xojo2j005ojo2j0OoU;S`1OmQW_46ofVRlPOoVk__00?o_LSS
okg9honmbN<01_nmbN<00oo4c>3oa<kRolC>hP05olC>hP05okC7j?nbanWo//OYok;7jOl000000_nb
anT6ojS1k0;oYl3/1onX_n/7ojW1ja?ooooo00?o0000ooooool000004Oooool001Oooooo00?o0000
ooooooooool03_ooool5ojS1j`;oZ<3[1onW_n/5ojJoj`?oYko[1_nY`N/6ojS1j`;oYl3[2?nV_n/3
ojJnj`CoZ<7[1onX`>/3oj>kjP?o00001On?Y><6oi2ThPOoV:cU00?oXK_[okWNlonig_<01_nig_<4
olCYl003ol;/lOnkfNoo^mW_00Ko^mW_00?o[/S]oj>gionS]nL00onS]nL7oj2ai0GoXK?U0_nT^^T7
ojJlj@OoYkkZ1onW_NT7ojRmj@OoZKgX1_nX_NT2ojZoj@SoZKkY00?oZL3ZojVoj_nY_nX00onY_nX8
oj_1j@;o/<7W1On^`^P4okK3i@Co]LCU1on_`^P3oiBhl0CoU;O_0omUW>l2of6Nl@KoJJ;b0onK^nl4
oi^ik@Oo_LWS00?o_/_TolC>h_o4c^801Oo4c^800oo3d>Co//OYok;7j@03ok;7j@03o`000?nbanWo
//OY00;oZ<7/1_nW`>`5ojRoj`WoZL7[5?ooool00ol0003oooooooooo`0?ooooo`005oooool00ol0
003oooooooooo`0?ooooo`03ojS1jonX`>_oZ<3[00CoZ<3[1onW_n/00onV_n_oYko[ojNoj`05ojNo
j`KoZL7[0_nX`N/6ojO0j`KoY[o[00?oY[k[ojS1jonX`N/01_nX`N/5ojS0j`04oj>kjol0003o0000
o`0000?oVk?X1_n?Y><6oi2ThPGoV:cU0onW`nh5okWNl`Goa>W`0oo7ind6ok_Ik`03oj_4k?nS]nOo
XkOW00GoXkOW1onP/N@00onQ/nGoY;[YojBjj@04ojBjj@OoY[cY1onW_^X7ojNmj@OoZ;gY1onY_NP2
ojRmj@KoZ[oY1_nY_^T00on[_nWoZKoZojVojP05ojVojPKoZl7Y0_nZ`NX7ojk2j003okK3iOnea>Go
]LCU00Go]LCU1On_`^P2ojo4j@OoU;O_1OmUW>l5offPk`SoVkW]1?nmbN<4okk;i0Coa<kR1?o3d>@5
ok;7j@03o`000?n`an_o/<O[00SoYl3/00?oZ;o[ojW1jonY`N/02onY`N/Dooooo`03o`000?oooooo
oooo00kooooo000Gooooo`03o`000?oooooooooo013ooooo1onX`>/5ojNoj`?oY[o[1onW_n/3ojW1
j`CoZ<7[1onW`>/2ojJoj`GoY[k[2?nX`N/00onX`>_oXk_[o`000002o`000003oj>kjonK/nSoVk?X
00CoVk?X1_n?Y><6oi2ThP03oiR/iOnW`nkoYl?^00KoYl?^00?o^MkcolCYl?o4jO000oo4jO06olOW
k@;o^mW_1On[a>`7oj>gi`GoX;7T00?oX[OXojBjjOnT^^T01_nT^^T5ojJlj@03ojNnjonW_^[oYkkZ
00KoYkkZ1onW_NT7ojRmj@GoZKgX0_nY_nX8ojZoj@;oZKkY1On[_nT7ojVojP;oZl7Y1_nZ`NX5ojk2
j0;o[/;Y2?nea>D00on_`^So[lCYojo4j@04ojo4j@OoU;O_1OmUW>l5offPk`SoVkW]00?o_LWSokk;
i?nnbn@01Onnbn@00oo4c^;o`m3Tol?@i005ol?@i0;o//OY0on`an/00ol0003o/<O[ok37j`06ojO0
k003ojJok?nY`N_oZL7[00_oZL7[00?oZ<7[ooooooooool04oooool00ol0003oooooooooo`0=oooo
o`005oooool2o`0001;ooooo1onX`>/00onW_n_oY[o[ojJoj`05ojJoj`GoYko[0_nY`N/7ojS1j`Go
Yl3[0_nV_n/7ojJnj`KoZ<7[0ol00005oj>kj`GoVk?X1on?Y><3oi2ThPCoV:oW1_nW`nh4okoOk`;o
a>W`1_o7ind3ok[Ek@KoZlC/1onS]nL00onP/NCoX[OXoj:gj003oj:gj0SoY;[Y00?oY[cYojNnjonW
_^/00onW_^/8ojNnjPOoYkgY1onX_NT00onY_NSoZKoZojVojP04ojVojPKoZ[oY00?oZL3Zoj^ojOn[
_nT01_n[_nT5ojVojP;oZ/3Z2?nZ`NX00on^`^So[/;Yojk2j@04ojk2j@Ko]LCU00?o]/KVojo4jOn_
a>T01_n_a>T3oiBgk`?oT;C_1?mXV^`2ofFLk`GoKJ3_1_nK^Nd00onP^N[o_/_Tokk;i005okk;i0;o
`<gT1_o3d>@2ol7Bi`Co/<O[00Co0000ok37jon`an_o/<O[0_nW`>`5ojJok0WoZL7[1OnX`N/Doooo
o`03o`000?oooooooooo00gooooo000Gooooo`03o`000?oooooooooo01;ooooo1OnX`>/3ojNoj`Oo
Y[o[00?oYko[ojW1jonY`N/01?nY`N/7ojS1j`03ojO0jonV_n_oY[o[00CoY[o[1onV_^/3ojS1j`;o
00000onX`N/6oj>kj`GoVk?X0on?Y><3ohjTi0SoV:oW0onW`nh6okoOk`?obNK[0oo7ind6ok[Ek@Ko
ZlC/0onS]nL4oifaiPKoX[OX1_nT^^T2ojJnj`KoYkk[1_nW_^X9ojNmj@?oZ;gY1?nX_n/7ojVojP;o
Z[oY1OnY`>X8oj^oj@03ojVoj_nZ`>[oZ/3Z00CoZ/3Z1_nZ`NX00onY`N_o[/;Yojk2j@06ojk2j@;o
]LCU1Onfa^H6ojo4j@;o[LG[1_n@]>l5ofRJk0CoLio]0_m]X>l2oi^ik@GoX;WZ1Onnbn@4ol3=i0?o
`m3T1Oo1d^L4ok37j`03o`000?n`an_o[LG/00OoY[o/1onY`N/8ojS1jaCooooo00?o0000oooooooo
ool03?ooool001Oooooo00?o0000ooooooooool04oooool00onX`>_oYko[ojNoj`05ojNoj`OoY[o[
1onY`N/5ojS1j`?oYl3[1_nV_n/5ojJnj`04ojS0jol0003o0000o`0000KoZ<7[0onS^n/2oiZdjPKo
S:CU1_n>Y>@8oiR_i`03ojO3k_nognoo_mo_00Co_mo_1Oo9i^/00oo7ingo^]G]ok[Ek@06ok[Ek@?o
ZlC/0_nO]^P8oifaiPKoX[OX0_nT^^T6ojJnj`KoYkk[0_nW_^X;ojNmj@03ojNojonX_n_oZ;o[00Ko
Z;o[1OnY_nX00onX`>_oZL3ZojW0jP06ojW0jPKoZkoY00?oZl7Yoj[0j_nZ`>X01_nZ`>X2oj[1jPGo
ZL7[1_n^`^T00on^`nWo]/KVokK6iP06okK6iP;o[lCY1_n]aN/6oi2dk`GoJ9[/1OmcWnd7oj2ijP?o
_/_T1oo0cN@00oo3d>Co`M;Wol7Bi`05ol7Bi`;o/<O[0_n]aN`00ol0003o[LG/ojg5k007ojJok0Oo
ZL7[1_nX`N/00onW`>_oooooooooo`0Cooooo`03o`000?oooooooooo00_ooooo000Gooooo`03o`00
0?oooooooooo01Gooooo1onW_n/7ojJoj`OoZL7[00?oZ<7[ojO0jonW`>/01OnW`>/6ojJoj`03ojJn
jonX`>_o000000;o00000onX`>/5ojS1j`;oXkc[1OnJ]>X6ohbTi@KoSZCT1_nH[nL3ojc6k0?o_mo_
1_o9i^/3ol[SjPKo^]G]00?oZlC/oinfj?nO]^P01?nO]^P8oifaiP?oX[OX0onT^nX8ojJnj`?oYkk[
0onV_NT9ojNmj@GoYko[2?nX_n/00onY_n[oZ<3[ojS0j`03ojS0j`SoZL3Z0_n[_nT5oj_1j@KoZ/3Z
0_nZ`NX6ojW1j`Co[/;Y1?n^`nT6okK6iP;o]/SW2?n]aN/6oi2dk`GoJ9[/1OmcWnd7oj2ijP03okk;
i?o0cNCo`<gT00Go`<gT00?o`m3Uol7Bioo1d^L01Oo1d^L00onld^[o[LG/ojg5k003ojg5k003o`00
0?n]aNco[LG/00?oY[o/0onV_n/8ojW1j`;oZ<7[1OnW`>/Dooooo`03o`000?oooooooooo00_ooooo
000Fooooo`?o00005oooool5ojNoj`WoY[o[2?nY`N/7ojO0j`?oY[o[00CoYKk[o`000?l0003o0000
1onX`>/00onX`N_oXkc[oj>lj`04oj>lj`GoV[CZ1_n<Y>D6ohjTi0;oV:oW1on/a^`00onognoobNK[
olWVj`04olWVj`Gob^?Z0_njeNd5oj_4k0KoWkKX1_nM/NH00onQ^NWoY;_ZojBkjP05ojBkjPKoY[k[
00?oYkkZojJmjOnV_NT01OnV_NT6ojNmj@SoYko[1_nX_n/2ojO1k0KoZ<3[1_nY`>X2ojS0j`OoZl7Y
0_nZ`>X6oj[1jPKoZL7[00?o[/;Yojk3jOn^`nT01On^`nT3okK6iPGo]/SW1_n]aN/00onX`ngoQjk^
ohN^kP04ohN^kPCoK9OY0_mXV^`5og>Ok@?oX;WZ1?nW^nP6ol3=i0?o`m3U1?o1d^L4okcBjPCo[LG/
00?o0000ojg5k?nZ`n`01onV_n/6ojW1j`03ojW2jonW`>_oYl3[00KoYl3[5?ooool00ol0003ooooo
ooooo`0:ooooo`005_ooool00ol0003oooooooooo`0Hooooo`03ojNojonV_n_oY[o[00_oY[o[2?nY
`N/5ojO0j`03ojJojonU_^_o000000;o00001?nU_^/5ojS0j`03ojS1jonS_>_oXkc[00KoXkc[1OnJ
]>X6ohbTi@?oSZCT1?nG[nP6ojc6k0?o`m_[1?o9i^/5ol[SjP?o_]K/1_n[a>`6oinfj0;oWK7V1OnQ
^NT7ojBkjP;oY[k[1OnW_^X7ojJmj@;oYkgY3?nW_n/2ojRoj`KoYl7/1_nX`>/2ojW0jPKoZ<3[1On[
`NT:oj[1jPKoZL7[2?n^`nT00onfa^Ko]/SWokK8i`05okK8i`;o[LG[1OnX`nd6ohN^kPGoK9OY1Omk
X>X8ojNkj0?o`<gT1_o3d>D00oo1d^Oo_=;ZokcBjP05okcBjP;o[LG/0_nZ`n`00ol0003oZ/?/oj[3
k007ojJoj`;oZL7[1OnY`^/7ojO0ja?ooooo0ol0000;ooooo`001?ooool4o`000008oa0@4?oooooo
ooooonk^k_lb<S;o0000oc8b<_o^k^h6ooooo`03o`000?oooooooooo01[ooooo2_nV_n/4ojS0j`Oo
ZL7[00?oYl3[ojJojonV_n/00ol00008ojFnj`03ojS0jonX`N_oZ<7[00?oZ<7[2?nS_>/5oiZdjP?o
S:CU0_n;Y>H8oiN_j0?o[<K/1oo3fn/00oo9i^_ob^?Zol[SjP02ol[SjPKo_]K/1_n[a>`3oinfj0Co
V[;X1_nQ^NT5ojBkjP;oY[k[1onW_^X5ojJmj@;oY[gZ3?nW_n/:ojO1k0?oZ<3[0onW`>`8ojS0j`03
oj_1jOnZ`N[oZ/7Z00[oZ/7Z00?oZ/;[ojW1jonY`N/01OnY`N/6ojk3j@;o[/CY1_nfb>L2okK;j@Ko
Z<?]1_n7[^h6ofbGj@GoNj3Z2?nW^nP00oo0cNCo`m3Uol?@i@04ol?@i@03olCDi_nld^[o_=;Z00Go
_=;Z0_necN`4oj[3k003o`000?nZ`ncoY[o[00GoY[o[0_nW_n/7ojW2j`OoYl3[3oooool3o`0000;o
oooo00?o0000ooooooooool02Oooool000Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Kooooo00?o0000ooooooooool06oooool6ojJoj`SoZ<3[1OnY`N/01?nX`>_o
0000o`000?l00004ojJoj`KoYKk[0_nW_n/6ojS1j`KoXkc[00?oW;O[oh^Wj?n;YnP00on;YnP6oh^T
iPSoUjoX00?o[<K/ol?Kjoo3fn/01Oo3fn/4olcPi`03ol[Sj_nne^co_]K/00Ko_]K/0on[a>`2oini
j`SoV[;X1_nQ^NT00onT^n[oY[k[ojJnj`04ojJnj`OoYkkZ00?oY[gYojJmj_nV_NX01?nV_NX8ojNo
j`coYl7/2?nW`>`8ojS0j`WoZ/7Z1OnZ`^/7ojW1j`;o[/?Y1_n^a>T3okK8i`Go]/_Y1_nX`nd6ohN^
kPGoK9OY1_mkX>X6ojNkj003ok73j?o3d>Go`m3U00Co`m3U0oo4e>H4okcBjPGo]Lg/0onZ`n`00ol0
003oZ/?/oj[3k002ojJoj`KoYko[1OnY`^/2ojW1j`OoYl3[2oooool3o`0000Gooooo00?o0000oooo
ooooool02Oooool000Kooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@
00Kooooo0_l0000Mooooo`KoY[o[2?nX`>/00onY`N_oZ<3[o`000002o`0000;oZ<3[1_nV_n/2ojFn
j`KoYko[1_nX`N/2oj>lj`GoW;O[1On;YnP6oh^TiPKoUjoX0on[`NX4ol?Kj`Goc>3W0oo=gnD6okkF
k003ojo7k?nO^N_oWkW[00CoWkW[2?nJ/^P3oj6ij@?oY;cZ1onV_^/3ojNnjPCoYKgZ1onV_NX3ojNo
j`CoYl3[2OnW`N`<ojO0k0SoZ<3[1_nZ`NX8oj[2j`GoZL7[0_nZ`N/8ojk4j@03okK8ionfbnWo]/_Y
00Go]/_Y0onX`nd2oj6mk@KoOZ?[1?mbU^H2ofbGj@KoNj3Z0_nW^nP5ok73j0?o`m3U1_o4e>H00onl
d^[o]Lg/okG=k006okG=k0?oZ/?/00?o0000ojO1k?nW`N`02?nW_n/00onY`^_oZL7[ojW1j`04ojW1
j`OoYl3[1_ooool4o`0000Sooooo00?o0000ooooooooool02Oooool000Kooooo00?o0000oooooooo
ool00_ooool01Ol0003ooooooooooooooooo000000Gooooo0_l0000Oooooo`KoY[o[1_nX`>/00onY
`N_o0000o`000006ojS0j`?oY[o[1?nU_^/7ojNoj`?oZ<7[1?nU_^`6oibgj`GoRjOX1_n;Y>H2oiN_
j0OoZl7Z00?o`m_[olcPioo<h>L01?o<h>L5olgOi@;o_]K/1On_an`6oinij`KoV[;X00?oWkSZojBl
j_nT_>X01OnT_>X5ojJnj`;oY[o[1onU_NX5ojJmjP03ojNojonW`>_oYl3[00KoYl3[1OnW`N`>ojO0
k0;oYko[2?nX`>/6oj[1jPSoZ/;[00?oZL7[oj[1jonZ`N/01?nZ`N/6ojk4j@03ok35j_nfbnWo]/_Y
00Go]/_Y00?o/l_/oj6mkOnQ_Nd01?nQ_Nd6ogjSj`GoLYKV1on4XnP7ok73j003ol?@iOo4e>Koa=CV
00Coa=CV0_o4f>P7okG=k003ok38k?nW`NcoYl7/00;oYl7/00?o0000ojO1k?nW`N`01_nW_n/9ojW1
j`?oYl3[0onV_n/3ooooo`?o00003Oooool00ol0003oooooooooo`08ooooo`001_ooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`0Ooooo
o`KoY[o[0_nX`>/01?nY`N_o0000o`000?l00002ojW1j`GoZ<3[0_nW`>/7ojFnj`GoYko[0onY`N/6
ojFnk0GoW;O[1_n;YnP3oh^TiP?oTjgX1on[`NX3ol;Ej0Coc>3W1Oo=gnD3olKIi`Ko[lO/1_nO^N/2
oiZbj0GoWkSZ1onT_>X00onV_^_oY[o[ojJoj`04ojJoj`OoYKgZ00?oY[gZojNojonW_n/00onW_n/8
ojO0j`03ojO1k?nW`>coYl3/00coYl3/1_nW_n/7ojS0j`OoZ/7Z1onZ`^/8oj[1j`;o[/CY1On`aNX4
okK;j@Co/l_/1_nQ_Nd6ogjSj`GoLYKV1on4XnP5ok73j0?o^<[X0oo4e>H5olCHj0Co]Lg/1?n`b>`4
ojO1k003o`000?nW`NcoYl7/00;oYko[2onY`N/00onX`N_oY[o[ojJoj`05ojJoj`;o00004?ooool0
0ol0003oooooooooo`08ooooo`001_ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@41001Oooool00ol0003oooooooooo`0Pooooo`?oY[o[0_nW_n/3o`0000KoZL7[00?oZ<3[
ojO0jonW`>/01?nW`>/7ojFnj`03ojNojonY`N_oZL7[00GoZL7[1_nU_^`5oibgj`?oRjOX0on6Y>P6
oi>]j0GoZl7Z1_o2eNP00oo<h>OocMoUolgOi@03olgOi@Goa]WW1_n_an`3oinij`?oV;C[1onO^>X5
ojBljP;oY[k[1onV_n/5ojFmjP;oYKk[1_nW_n/6ojO0j`;oZ<7[2_nW`>`;ojNoj`OoZ<3[1onZ`NX7
oj[2j`KoZ/7[0_n[`^/7ok35jP03okK;jOncbnco/l_/00Co/l_/1onQ_Nd6ogjSj`GoLYKV1on4XnP0
0ona`nSo^<[XokS:j005okS:j003olCDi_o4f>Soa=SX00Goa=SX00?o]Lg/ok38k?n`b>`01?n`b>`4
ojO1k003o`000?nW`NcoY[o[00[oZL7[1OnX`N/7ojJoja7ooooo00?o0000ooooooooool02?ooool0
00Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_l0000R
ooooo`04ojNojol0003o0000o`0000?oYko[1OnY`N/3ojS1j`KoYl3[2?nU_^/7ojW1j`?oYKk/0_nN
^^`5ohf]k0OoQZCX1_nC[NP3oj_1jPKo`]GX0oo;fN@3olgOi@Ooa]WW0on_an`3oj>ok@KoV;C[1onO
^>X00onT_>[oY[k[ojJnj`04ojJnj`OoY[o[00?oYKgZojFnjonU_^/01?nU_^/6ojNoj`;oYl3[1_nX
`N/5ojO0k003ojO0jonW_n_oYko[00goYko[1onX`>/5oj[1jP;oZl;[1onZ`^/2oj[1j`KoZl;[1On`
aNX2ok?9jPOo/l_/0onQ_Nd3oiJcj`KoN9OT1?mjUn<2og:FiP?oQ:?X0onD[>H7okS:j003okkAj?o4
f>Soa=SX00Goa=SX00?o_mS/ok38k?n`b>`01_n`b>`2ojO1k0;oY[o[00?o0000ojJojonV_n/01_nY
`N/00onY`^_oZ<7[ojS1j`05ojS1j`KoY[o[00?oY[k[ooooooooool03oooool00ol0003ooooooooo
o`08ooooo`001?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool00ol0003oooooooooo`0Oooooo`?o00001onW_n/00onY`N_oZ<7[ojS1j`05ojS1j`KoYl3[2?nU
_^/5ojW1j`03ojO0k?nN^^coW[[/00CoW[[/1On=[N`7ohJTj0KoTjgX00?oZl7Zol;Ej?o2eNP01?o2
eNP5ol_Ii003olgOiOo6fNOoa]WW00Goa]WW0_nic^X6oj>ok@KoV;C[0onO^>X4oj:kj`OoY[k[0onV
_n/4ojBmj`OoYKk[0onW_n/3ojS0j`SoZ<7[00?oYl3/ojO0jonW`>/00onW`>/?ojNoj`OoZ<3[00?o
Z/7Zoj_2jon[`^/01?n[`^/5oj[2j`;oZL7[2?n[`^/00on`aN[o/lWZok?9jP04ok?9jPGo/l_/0_n[
aNd6oiJcj`KoN9OT1OmjUn<7oiB/iPCo^<[X1?nndNP4olCHj0Co_mS/1_n`b>`00on[aNcoY[o[ojJo
j`03ojJoj`03o`000?nV_n_oY[o[00;oZL7[1OnY`^/7ojS1j`;oY[o[1OnV_^/@ooooo`03o`000?oo
oooooooo00Sooooo000Eooooo`03o`000?oooooooooo01cooooo0ol00004ooooo`GoYko[0onY`N/7
ojS1j`?oYl3[1?nV_n`7ojFnj`03ojW1jonW`>coYl3/00?oYl3/1_nN^^`5ohf]k0OoQZCX0onC[NP4
oj>jj@?o`]GX1_o;fN@3oloIh@Coa]WW1Onic^X6oj>ok@?oV;C[0onJ]^/7oj:kj`GoY[k[00?oY[o[
ojBmjonT_N/01_nT_N/5ojFnj`03ojJojonX`>_oZ<3[00GoZ<3[1_nX`N/2ojS0j`KoYl3[3onW_n/3
ojS0j`?oZ<7[2?n[`^/00onZ`^_oZL7[ojW1j`04ojW1j`KoZl;[00?o[LG[ok?9j_ncbNX01_ncbNX0
0oncbncoZlG]oj_5k@04oj_5k@KoU[?[1_mhUn@5ogZGh`OoU:cV00?o^<[XokkAj?nndNP01OnndNP0
0oo4f>So_mS/okoHk005okoHk0;o/<S/1On[aN`5ojJoj`03o`000?nW_^_oZL;[00OoZL;[0onX`N/3
ojO0j`SoY[k[3oooool00ol0003oooooooooo`08ooooo`005Oooool00ol0003oooooooooo`0Ioooo
o`?o00002?ooool00onW_n_oZL7[ojW1j`05ojW1j`GoZ<7[00?oZ<3[ojJok?nV_n`01_nV_n`5ojFn
j`;oZ;o[1_nW`>`6oijjk0GoSJg/0on6Y>P3ohbYj@SoXk[Y00?o`]GXol_Ii?o;fN@01?o;fN@5oloI
h@03olKIionic^[o^LkZ00Ko^LkZ0onS_nd2oiZik@OoV[K[1onR^n/00onV_^_oY[o[ojJoj`03ojJo
j`SoY;g[00?oYKk[ojJojonV_n/00onV_n/7ojS0j`;oZ<7[1_nX`>/6ojO0j`koYko[1onX`N/6oj_2
j`;oZl?/1onY`N/2oj_2j`Go[LG[1_ncbNX3okG>k@KoZlG]1_nF/n/5ogRGi0GoNYOS1_nD[>H2ojJj
i`Ko_]7X0oo3f>T5okoHk0;o]]3]1on[aN`2ojJoj`;oYkk[00?o0000ojNnjonW_^/01_nY`^/00onY
`^coYl3[ojO0j`05ojO0j`OoY[k[3oooool00ol0003oooooooooo`08ooooo`005Oooool00ol0003o
ooooooooo`0Fooooo`?o00003Oooool7ojW1j`03ojS1jonX`>_oZ<3[00?oZ<3[2?nV_n`00onU_^_o
Z;o[ojRoj`04ojRoj`KoYl3/0onN^^`3oiBekPGoPZGZ1_n<ZNT6oj>jj@?o^/[V1?o;fN@5oloIh@?o
c]KO1_nic^X00on^a^_oV[W]oiZik@04oiZik@OoV[K[1OnR^n/2ojBmj`KoY[o[1_nT_N/2ojBnk0Ko
Y[o[3onX`>/3ojO0ja7oYko[1onX`N/2oj_2j`KoZl?/1onY`N/7ojg5j`;o/lWZ1onec^d3oj_5k@;o
XK[[1_n7XND4og^Cg`;oN9OT1OmjUn<2oiB/iPKoY[[W0onndNP6ol?Hj@03okoHk?nfd>go]]3]00Co
]]3]1On[aN`2ojO1k0CoYkk[00?o0000ojNnjonW_^/00_nY`^/5ojW2k0OoYl3[1onV_^/?ooooo`03
o`000?oooooooooo00Oooooo000Dooooo`;o00005Oooool3o`00017ooooo1onY`N/6ojS0j`KoY[o/
0_nU_^/7ojRoj`?oYl3/1?nS_^`5oiBekPGoPZGZ1_n<ZNT3oj>jj@Oo^/[V00?obmWToloIhOo?fN40
0oo?fN45olkFg`?o^LkZ1?n^a^/6oiZik@OoV[K[00?oX[_[ojBmjonT_N/01?nT_N/6ojJoj`;oY;g[
1_nT_^`6ojJoj`goZ<3[00?oZ;o[ojNojonW_n/04onW_n/5ojS1j`;oZL;/2?n[`n`7ojW1j`Go[LG[
0_n_b>`7okG>k@03ojo:kOnQ^^_oXK[[00CoXK[[1_n7XND5og^Cg`GoQ9gS2OnV^^L00onndNSo`mSY
ol?Hj@04ol?Hj@03ol?Lk?nfd>go]]3]00Ko]]3]00?oZlG/ojO1k?nW`N`01?nW`N`4ojNnj`03o`00
0?nY`^_oZL;[00OoZL;/1OnW`>/2ojJoj`KoY[k[3oooool00ol0003oooooooooo`07ooooo`005?oo
ool00ol0003oooooooooo`0Booooo`;o00005Oooool7ojW1j`KoZ<3[0_nV_n`6ojFnj`GoZ;o[0_nY
`N/7oj>nk0GoU;G^1On2YNX6ohbYj@03oj>jjOnjb^Ko^/[V00Go^/[V0oo7dN83oloIh@Ooc]KO00?o
^LkZojk6jon^a^/01?n^a^/6oiZik@?oV[K[1?nN^^`7ojBmj`?oY[o[0onU_n`8ojBnk0?oY[o[0onW
_n/9ojS0j`GoZ;o[5OnW_n/00onX`N_oZL;/ojW2k004ojW2k0KoZl?/00?oZL;/ojW1jonY`N/01_nY
`N/00on]aN_o[lS/ojo8k004ojo8k0Co]Lk]1?n_b^d6oj6jj`GoQj7U1_mkTml5ohBMh`OoY[[W0_ne
bn/4ol?Hj@Co`mc/1_nfd>d00on_bNgoYl7/ojO1k006ojO1k005ojNnjonY`^_oZL;[ojW2jol00000
0_nY`^/7ojW2k003ojO0jonV_n_oY[o[00CoY[o[1_nV_^/>ooooo`03o`000?oooooooooo00Oooooo
000Dooooo`03o`000?oooooooooo00oooooo0ol0000Hooooo`OoZL7[0onX`>/4ojO0j`OoYKk[00?o
Z;o[ojW1jonY`N/01?nY`N/7oj>nk0GoU;G^1On2YNX3ohbYj@?oUk;Z1_njb^H5olOAhP03oloIhOo>
e]ooc]KO00Goc]KO0oo8dN46ojk6j`?oV[W]1?nE]nh6oijjk0GoY;g[0_nU_^`6ojFok0KoY;k/0_nT
_n`6ojNoj`OoZ<3[1onX_n/AojNoj`CoZ<7/1onY`^`2oj_3k0GoZL;/1_nY`N/2oj_4k0Oo[lS/00?o
]Lk]ojo:kOn_b^d01?n_b^d7oj6jj`CoQj7U1_mkTml6ohBMh`CoY[[W1Onebn/00oo3f>Wo`mc/ol?L
k005ol?Lk0;o]]3]1On_bNd6ojO1k003ojJnjonY`^_oZL;[00;oZL;[00Co0000ojW2jonY`^_oZL;[
0onY`^`3ojS0j`SoY[o[0onV_^/3ojO0j`gooooo00?o0000ooooooooool01oooool001Cooooo00?o
0000ooooooooool03?ooool3o`0001cooooo1OnY`N/3ojS1j`KoYl3[1OnU_^/3ojJoj`KoZL7[1OnS
_^`00onM^ngoQZg_ohJ]k`03ohJ]k`GoPZK[1onG/^X3ok[:iPKoam7R0oo<d]h4olkFg`Kob=7Q0on^
a^/3ojO1k0OoUKO^1_nN^^`00onT_N_oYKk/ojFnk004ojFnk0KoYKo/0_nT_^`6ojBok0KoYko[1onX
`>/7ojRoj`coYko[0_nW`N`7ojS1k0GoZL;/0_nZa>`7ojW2k0;oZL7[1_n[a>`5ojo8k0?o]=3_1_n_
b^d3oj6jj`?oTZOT1?n1U=d00on7XNGoNi?Oog^Cg`04og^Cg`KoQ9gS00?oY[[WokG;jonebn/01?ne
bn/00onne^co`mc/ol?Lk005ol?Lk003okcJkon_bNgo[lW]00Ko[lW]0_nW`N`5ojJnj`CoZL;[00?o
0000ojW2jonY`^`01onX`>/6ojJoj`03ojJnjonW`>_oYl3[00GoYl3[3?ooool00ol0003ooooooooo
o`07ooooo`004oooool3o`0000[ooooo0ol0000Pooooo`03ojW1jonX`N_oZ<7[00GoZ<7[1_nW`>/0
0onU_^_oY[o[ojJoj`05ojJoj`KoZL7[00?oXkk/oifkkOnM^nd00onM^nd5ohJ]k`GoPZK[1onG/^X0
0onjb^Koam7RolOAhP04olOAhPGoc=;N00?oc]KOolSAhOo8dN401Oo8dN42ol7=h`KoYl7/1onE]nh3
oijjk0?oX;c]1onU_^`3ojFok0_oY;o/0onW_n/3ojO0k0OoZ<3[0onX_n/4ojS0j`SoYko[1_nW`N`7
ojS1k003ojW2k?nZa>coZ/C/00CoZ/C/1OnY`^`2ojS2k0SoZlC/00?o[lS/okC@kondd>l01Ondd>l3
ojo:k@;oY;_Y1onBYn@4oh6Dg@KoPYON1onEZN@4okG;j`Co_]K/1?o3g>`4okcJk`Ko[lW]00?oZL?/
ojJnjonV_^/01_nV_^/2ojW2j`;oZL;/00?o0000ojW2k?nY`^`01onX`>/2ojJoj`GoY[k[1onW`>/;
ooooo`03o`000?oooooooooo00Oooooo000Dooooo`03o`000?oooooooooo00Kooooo0ol0000Uoooo
o`OoZ<7[0onW`>/3ojJok0SoY[o[0onY`N/3ojO0k0KoWK_]1On6[Nl5oh:Vj`GoUk;Z0onY_NP4olOA
hPKoc=;N0_o>d=/5olSAh@Co`LgS1_nW`N`3oiFgkPCoU;S_1_nP_>d5ojFnk003ojJok?nT_ncoY;o/
00_oY;o/00?oY;o]ojO0k?nW`>`01OnW`>`5ojS0j`;oZ<7[1onX`>/5ojNoj`;oYl3/1onW`N`3ojS1
k0?oZL?]2?nZa>`00onY`^coZ<;/ojS2k004ojS2k0KoZlC/0_n]bNh6okC@k`03ojo:k_nT^nWoY;_Y
00CoY;_Y1_nBYn@5oh6Dg@KoPYON1onEZN@00onebn_o_]K/okkFk005okkFk003ol?Lk?nlf^oo_=[_
00Go_=[_0_n_bNd5ojW3k0KoY[k[00?oZ<3[ojW2k?nY`^`00_nY`^`00ol0003oZL;/ojW2k006ojS0
j`03ojNojonV_^_oY[k[00KoY[k[0onW`>/3ojS1j`_ooooo00?o0000ooooooooool01oooool001Co
oooo00?o0000ooooooooool00oooool3o`0002Wooooo1OnX`N/00onX`>_oY[o/ojJok005ojJok0Ko
Y[o[0_nX_n/6ojO0k0KoWK_]1On6[Nl5oh:Vj`03oiNbj_nY_NSoZKgX00KoZKgX00?oam7RolcBg_o<
d]h01?o<d]h4olk@f`?ob=7Q1_o1cN<3ojO1k0?oXKk^1onD^>l6oj2lk@03ojFnk?nV_ncoY[o/00?o
Y[o/2OnT_n`5ojBok@OoYl3/00?oZ<3[ojS1jonX`N/01?nX`N/7ojS0j`03ojNojonW`>coYl3/00Co
Yl3/1OnW`N`2ojS3k@KoZL?]1_nZa>`2ojS1k0OoZ<;/0_n[a>`6ojg9kP;o]=3_1On_b^h6ojBkj@Go
TZOT1_n1U=d6oh:GgPGoUJWT0_n[`^X6okkFk0?o`]k]1Onlf^l2ok7=kPOoZL?/0_nV_^/5ojS0j`Co
ZL;/00?o0000ojW2k?nY`^`00_nX`>/5ojNoj`KoY[k[00?oYko[ojS1jonX`N/01OnX`N/;ooooo`03
o`000?oooooooooo00Kooooo000Cooooo`04o`000?ooooooooooooooo`?o0000;Oooool00onX`N_o
Z<3[ojS0j`03ojS0j`OoY[o/0_nV_n/6ojRoj`KoYl3/0onM^nd2oiFhk`GoOJO^1_n8Zn`7ojVmj0;o
^LCS1Oo<d]h6olk@f`03olSAhOo1cN?o`LgS00Co`LgS00?o^lSToj6nk_nQ_^h01OnQ_^h7oiBhk`?o
X;c]0onP_Nh6ojJok0OoY;o/1onT_nd5ojO0k0;oY/7]1onX`N/3ojS0j`CoYl7/1onW`>`00onW`Nco
Z<?]ojS3k@04ojS3k@KoZL?]0_nZa>`6ojS1k0GoZ<;/0_n[a^h6ojg9kP;o/M7`1_n_b^h7ojBkj@Go
TZOT1On1U=d7oh:GgP03oiFYi?n[`^[oZl;Z00CoZl;Z0onne^`6ol;Nk@03okcJkonacNko/Lg^00Co
/Lg^1OnY`n`2ojJoj`OoZ<3[0onY`^`00onX`N_o0000ojS1j`08ojNoj`;oY[k[1OnW_n/7ojS1j`[o
oooo00?o0000ooooooooool01_ooool001?ooooo1?l0000booooo`GoZ<3[1OnV_n`3ojFok0OoZ;o[
0onW`>`3ojBok0GoUKS_1OmmYnh6ohR[k0CoZKgX1Onia><3olcBgPKoc]3K0oo>cMT3ol7=h`Co^lST
1onQ_^h3oiBhk`CoUK[a1_nP_Nh6ojJok0OoY;o/1onT_nd00onW`>coY/7]ojK1k@04ojK1k@GoZ<7[
0_nW`^d7ojO1k0GoYl3/0_nW`nd7ojS3k@?oZL?]0onY`^`8ojS1k003ojS2k?n[a^koZlK^00CoZlK^
0on]bNh5ok7Al0Ko[l[^0onT^nT3oiNVh0GoQiGJ1?n5U=/2oh6Dg@?oPYON0on>X>48oj_2jP03okkF
k?o2g^go`]k]00Co`]k]0_nogo07ok7=kP03ojW3k?nV_n_oY[o[00CoY[o[1OnX`>/2ojW2k0CoZ<7[
00?o0000ojS1jonW_n/01OnW_n/00onV_^_oYko[ojNoj`06ojNoj`?oZ<7[0onX`N`:ooooo`03o`00
0?oooooooooo00Kooooo000Cooooo`;o0000=Oooool5ojS0j`03ojJok?nU_ncoYKo/00GoYKo/1OnX
_n/2ojW0j`KoY;o/1OnE^>l5ogfWkPKoR:_/00?oZKgXokW4honia><01_nia><00oo<d]koc]3Kolk@
f`04olk@f`Goc/gI00?o`LgSok_8i?nkb>@01?nkb>@5oj6nkP?oW[g^1_nE^_46oj2mkP?oY[o/0onU
`>`7ojBok0?oY;o]1?nT`>d7ojK1k@03ojS1jonW`^goYl;]00CoYl;]1onW`N`00onW`>coYl?]ojO3
k@04ojO3k@OoZ<?]1_nY`^`6ojS1k003ojS3kOn[a^koZlK^00KoZlK^00?o[LW^ok7Al?nadO001Ona
dO03ojo:kP;oY;SW1onGY^05ohNEfPGoQICK1on>X>46oj_2jP;o^MC^1?o2g^d5okoOl0?o/Lg^0on[
aNd8ojJoj`03ojS0jonY`^coZL;/00CoZL;/0onX`N/00ol0003oZ<7[ojS1j`02ojNoj`GoY[k[1_nW
_n/00onX`N_oZ<7/ojS1k005ojS1k0Wooooo00?o0000ooooooooool01_ooool000Go00000oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0<oooool2ojS0j`CoYl3[1onU
_n`00onX_n_oZL3[ojW0j`04ojW0j`KoY;o/1OnE^>l5ogfWkP?oR:_/1?nB/^d6okW4h`?o`l[O0oo>
d=/7olk=f@03olc9eonkb>Co^lST00Go^lST00?oXKk^oijmk_nN_Nh01OnN_Nh6oiFjl@?oX;g^0onP
_nh6ojG0k0GoY;o/0_nU_n`7ojC0k@GoY/7]0_nU`Nh7ojO2k@?oYl7/0onW`nh8ojO3k@OoZ<?]1_nY
`^`2ojS1k0GoZ<?]1_n[a^h2ojg>l@Ko/M7`00?o[<G/ojBhionT^>L01?nT^>L6oiNVh0KoQiGJ1On5
U=/6ohjPh@CoZl;Z1Onie>h00oo2g^go_mo`okoOl004okoOl003ok;?kon[aNgoZlG]00GoZlG]1_nV
_n/00onW_n_oZL;/ojW2k006ojW2k0?oZ<7[00?o0000ojO0jonW`>/01onV_^/2ojNoj`GoZ<7[1onX
`N`8ooooo`03o`000?oooooooooo00Kooooo00001OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`09ooooo`03o`000?oooooooooo03?ooooo1_nW`>/7ojFok0OoZL3[
0onT_n`4oj6nk@GoR[?a1OmkYnl6oi:bk@?o^LCS1_o3b]l00oo>d=_oc/gIolk=f@05olk=f@?oc<WG
1Onkb>@2okS4h`SoW[g^0onE^_43oiBklPKoX;o^1_nU`>`00onT_ncoYKo/ojFok004ojFok0OoY<3]
00?oY/7]ojG1k_nU`Nh01?nU`Nh5ojO2k@;oY/;^1_nW`nh7ojO3k@SoZ<?]0onY`^`4ojS2k@KoZ<?]
0_n[a^h6ojg>l@;o/M7`1On/aN`6ojBhi`GoUjKP1_n7UMX6ohFDf`KoSZ3Q00?oZl;ZokWDk_nie>h0
1?nie>h3okoPl0?o_mo`1?nbcnl7oj_5k@;oY[o[1OnW_n/6ojW2k003ojS1k?nW`>_oYl3[00;oYl3[
00?o0000ojO0jonW`>/01_nV_^/7ojS1j`KoZ<7/00?oZ<3[ooooooooool01_ooool00ol0003ooooo
ooooo`06ooooo`0000CooooooiRHV?lQ8B7ok^k^1?ooool01Ol@413ooooooooooooooooo410@00[o
oooo00?o0000ooooooooool0<oooool6ojO0j`OoYKo/1OnY`>/2ojW1j`OoXKk]1On:/o45og^Wk`Ko
T[;]00?o^LCSol?:goo3b]l01?o3b]l3olO:g0Goc/gI1Oo<bML00onkb>Co^<CSokS4h`04okS4h`Ko
W[g^0_nN_>h6oiBklPKoX;o^0onU`>`3ojG1k@OoYKo/0onT`>d4ojBok@OoYL7^00?oYl;]ojK2k_nV
`^h01?nV`^h6ojO3kPOoYl?]1_nX`nd2ojO2k0OoZ<;]0onX`nd4oj[9l0Go[Lka0_n_c_06ojc5k0Oo
Y;SW1OnGY^06ohNEfPKoQICK0on>X>44ojBjj@?o^MC^1_noh?000onogo3o//o_ok;?k`04ok;?k`?o
ZlG]2onW_n/2ojW2k0GoZ<7/1?nW`>/00ol0003oYl3[ojO0j`06ojJnj`OoZ<7[0_nX`N`5ojS0j`Oo
oooo00?o0000ooooooooool01_ooool000;ooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooo
oooooooooooo000000_ooooo0_l0000dooooo`?oYl3[0onV_n`7ojFok003ojW0jonY`N_oZL7[00Co
ZL7[1onQ_^d5ohZcl@GoNjO_0onB/^d3oibhk0Go`l[O1Oo7b]`3olk=f@Goc<WG0_o;a]H7okS4h`;o
W[g^1_nN_>h6oiBklP?oX;o^0onO`?06ojG1k@GoYKo/0_nV`N`7ojBok@GoYL7^0_nU`>d7ojK2kP?o
Yl?^0onV`^d7ojO3k@;oZ<?]1_nW`^`5ojS2k@;oZ<O_1onZbO000on]c_7o[lk`ojo>l004ojo>l0Ko
[<G/0onT^>L3oiNOfPGoS9CF1_n9U=P6ohjNgPSoY;[Y00?o^MC^okoPl?noh?001?noh?02okkRl@Go
//o_0_n/a^d<ojNoj`03ojW2k?nX`NcoZ<7/00KoZ<7/0onW`>/00ol0003oY[k[ojJnj`07ojJnj`?o
Z<7[0onX`N`8ojS0j`Oooooo00?o0000ooooooooool01Oooool000?ooooo00?oMgMgofIVI_ooool0
0_ooool01Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool0<_ooool6ojJok0Go
YKo/0onV_n`6ojW1j`GoXKk]00?oW;c^ogn_lomo[o<00omo[o<6ogfZl@KoW;S/0oo3b]l7olO:g003
olk=fOo<bMOoc<WG00?oc<WG1?o;a]H5okS4h`?o]l3Q1onN_>h3oiBklP?oTkcc1_nO`?06ojG1k@03
ojFok?nV`NcoY/7/00CoY/7/1onT_nd00onU`NkoYL3]ojG0k@04ojG0k@GoY/;^0_nV`N`6ojK2k@Go
Yl?]2_nW`^`00onX`^goZ<O_ojS7k`04ojS7k`GoZ/W`0on]d_<6ojo>l0?o[<G/0_nR[n47oiNOfPGo
S9CF1_n9U=P6ohjNgPKoY;[Y0_nee?04okoPl0Go_^;a00?o//o_ojc6kOn/a^d01?n/a^d8ojNoj`Go
ZL;/1_nX`N`00onW`>_oY[k[ojJnj`02ojJnj`03o`000?nV_^_oY[k[00GoY[k[0_nX`>/6ojS1k0Ko
Z<3[00?oYko[ooooooooool01Oooool00ol0003oooooooooo`05ooooo`001?ooool01Ol0003ooooo
oooooooooooo410@00?ooooo00?o410@ooooooooool03?ooool00ol0003oooooooooo`0booooo`Ko
Y[o/00?oYKo/ojJok?nV_n`01OnV_n`6ojW1j`03oj6nkOnL_>koW;c^00?oW;c^1Omo[o<6ogfZl@Ko
W;S/00?o`l[OolO:g?o7b]`01Oo7b]`3olW8f@?oc<WG1_o;a]H00onha>?o]l3QokO0h@05okO0h@Go
W[c^0_nQ_>`6oi>ll`KoWl3`0onU`Nd3oj?2kPOoY/7/0onT_nd4ojK0k0OoYL3]00?oY/;^ojK1k?nV
`N`01?nV`N`6ojK2k@03ojO3kOnW`^coYl;/00[oYl;/00?oZ<K_ojS7konXanl01_nXanl00onZbO3o
[M;cojgBl`05ojgBl`?o[lk`0_nW^NH6oj:_h@OoUioJ1On<U=H6ohVDf0KoSYkN0_nT^^T6okGDl003
okoPl?nnh_7o_^;a00Co_^;a00?o/]3`ojc6kOn/a^d01_n/a^d6ojNoj`OoZL;/0_nX`N`5ojO0j`Co
Y[k[00Co0000ojJnjonV_^_oY[k[1_nX`>/6ojS1k0;oZ<3[1OnW_n/6ooooo`03o`000?oooooooooo
00Gooooo00001Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0?
ooooo`03o`000?oooooooooo03;ooooo3_nV_n`3ojW1j`?oZ<3[1_nL_>h5ogn_l`KoOJ[a0onL^>`3
ojNnjPKoal[L1Oo9b=T00oo<bMOoblKFol_6eP04ol_6eP;obL;D2?ng`>400onN_>koXKc/oj6lk004
oj6lk0KoTkcc0onO`?03oic3l`KoXl;^1OnV`N`2ojG2kPOoY/3/0onU`>d4ojO1k0OoY/7/0onV`^d3
ojO2k@WoYl;/1OnXa^l6ojS7k`;oZM7e1_n]d_<00on[`N[oYkWVojNiiP04ojNiiPKoXZoQ1_nGWmX5
ohbDePKoRICH1On>W]h2oj>kjPKo]MC`0onlh_82okkRl@Go/]3`1_n/a^d8ojNoj`GoZL;/00?oZ<;/
ojO0jonW`>/01_nW`>/4ojJnj`03o`000?nV_^_oZ<3[00OoZ<3[0onX`N`2ojS1j`SoYko[1Oooool0
0ol0003oooooooooo`05ooooo`0000GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h04?ooool2o`0003Cooooo2onV_n`2ojNoj`KoZ<3[1_nL_>h5ogn_l`?oOJ[a0_n0
[_87ojNnjP?oal[L1_o9b=T2olW6e`GoblKF1?o9`]@6okO0h@;o^KgM1onQ_>`6oi>ll`KoW<?c1_nS
`^h00onV`NcoYL;^ojG2kP04ojG2kPGoY/3/0_nV`nh7ojO1k0GoY/7/0_nW`nh6ojO2k@GoYl;/0_nW
a_07ojS6k`;oZ<O_1_nYdOD2ojgBl`GoZl7Z1_nW^NH6oj:_h@KoUioJ1On<U=H6ohVDf003ohjNg_nS
^n[oXk_Z00CoXk_Z0onee?04okcRlP;o^n;b1onbd?02ojc6k@coYko[00?oZL;/ojS2k?nX`^`00onX
`^`6ojO0j`03ojNojonV_^_oY[k[00;oY[k[00?o0000ojJnjonV_^/01_nX`>/00onX`NcoZ<7[ojS1
j`04ojS1j`KoYko[00?oY[o[ooooooooool00oooool00ol0003oooooooooo`05ooooo`007oooool0
0ol0003oooooooooo`0booooo`OoY[o/1_nW_n/6ojS0j`?oW;c^0onI^o05ogR/m0GoP:kb1onW_^X0
0oo7b]cobLSIolW8f@04olW8f@CobLKG0oo;a]H6olW2e0;o]l3Q1_ni_Md5oj6lk0;oYk_X1_nC_?<6
oic3l`?oXl;^1?nQ`o46ojG2kP03ojK0k?nV`nkoY/?^00CoY/?^1onW`N`00onV`NcoYl?^ojO3kP04
ojO3kPKoYl;]00?oYl;/ojO6l?nWa_001?nWa_05ojS6k`?oY/oe1OnYdOD2oj_6kPKoZl7Z1onW^NH3
oj:_h@;oUYOC1_n@U=<5ohnGe`KoTZ3M2?nS^nX01?nee?3o_>;bokcRl_nlh_85ok_RlPGo/]3`0_n[
aNd:ojNoj`?oZL;/1onX`^`2ojO0j`GoYko[1?nV_^/00ol0003oY[k[ojJnj`02ojS0j`GoZ<7/1_nX
`N/2ojNoj`GoY[o[1?ooool00ol0003oooooooooo`05ooooo`008?ooool00ol0003oooooooooo`0b
ooooo`?oY[o/0onU_n`7ojNoj`?oZ<3[0onW`>`6oiVkl0GoN:cd1On0[_85ojNnjP?o[l7W1?o9b=T6
olW6e`03ol_6e_o9`]CobL;D00GobL;D2Oni_Md00onQ_>coYk_XojNkj004ojNkj0KoTkcc0onL`o<3
oiK2m@OoXL?a0onU`^h3oj?4l@OoY/?^0onW`N`3ojK4k`SoYl?^0onW`^d4ojK6l0KoYlK`00?oZ<K_
ojK?mOnVcoD01OnVcoD00onYdOGoZlK^oj_6kP04oj_6kPKoZl7Z0onW^NH3oijPePKoUYOC1_n@U=<5
ohnGe`KoTZ3M1_nS^nX3okCHl`03okcRl_nkh_;o^n;b00Go^n;b00?o/]3`oj_5kOn[aNd01?n[aNd6
ojNoj`OoZL;/1OnX`^`2ojO0j`KoYko[1OnV_^/00ol0003oZ<3[ojS1k007ojS1k0?oZ<7[0_nW`>/8
ojJoj`?ooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool0<_ooool6ojFo
k0GoYko[0onX`>/5ojO0k0KoVK_`1Omh[?@5oh2^lP03ojNnj_n_`NOo[l7W00Ko[l7W00?obLSIolW6
eoo9a]L01?o9a]L00oo8a=KobL;DolW2e005olW2e0;ob;oB1oni_Md2okbjf0OoYk_X0onC_?<3oiVk
k`KoU/;e1OnQ`o42oic7mPKoXlCa1OnV`nh2oj?6lPKoY/C_1_nW`nh00onUb?;oY/K`ojK6l006ojK6
l0?oYlK`1?nUcoH5ojK?m@;oZLS`1on[a^h3oj_1jP;oXjSI1onNX=H5oiJGd`KoT9CC1_n?UmL6oi:P
g@;oXk_Z1Ondf?<2okWUm0Ko^n;b00?o/<k`oj_5kOn[aNd01_n[aNd6ojNoj`OoZL;/00?oZ<;/ojO0
jonW`>/01?nW`>/6ojNoj`;oY[k[0_nX`>/00ol0003oZ<3[ojS0j`06ojS1k003ojS1jonW`>_oYl3[
00CoYl3[1_nV_n/00onW_n_oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo000Rooooo`03
o`000?oooooooooo03;ooooo1_nU_n`00onW_n_oZ<3[ojS0j`05ojS0j`GoYl3/0onI^o04oiJjl@Go
Lj_d1On2/O<6ojo1i`;o//?V1Oo9a]L3olS4ePGobL;D1?o8_m84okVmg@Go_;[H1OnW^nP2ojfhh@Ko
VK__1_nF`_D00onQ`o7oW<Ofoic7mP04oic7mPKoXlCa00?oY/?^oj?6l_nSa_801?nSa_86ojK4k`;o
Yl?^1OnUb?86ojK6l0;oXlog1onUcoH00onVcoGoZLS`ojW8l004ojW8l0GoZlK^00?oYZgMoj>XfOnS
Z=T01?nSZ=T6oijPePKoUYOC1On@U=<6ohnGe`GoTZ3M0onWa>h3okCHl`Go^NGd0_nkh_85ok3>l0Ko
ZlG]00?oYkk[ojNojonW_n/01OnW_n/3ojW2k0?oZ<7/2?nW`>/3ojNoj`?oY[k[1?nX`>/00ol0003o
Z<3[ojS0j`02ojS1k0GoZ<7[1_nW`>/2ojJoj`GoYko[0oooool00ol0003oooooooooo`04ooooo`00
8oooool2o`0003?ooooo1onU_n`7ojS0j`;oYl3/1?nV_n`6oiJjl@GoLj_d1On2/O<3ojo1i`Go//?V
0oo9a]L5olS4eP?obL;D1_o8_m800oni_Mgo_;[Hokbjf006okbjf003ojNkj?n]^>7o[KSQ00Co[KSQ
1_nI^nl3oiK2m@CoUKkd1_nLaoH3oj?4l@CoW/[f1_nSa_83ojK4k`CoX/_e1_nUb?82ojK6l0KoXlog
0onUcoH4ojO7l@OoZLS`00?oZlK^ojJ]gOnV[Md00onV[Md6oj>Xf@GoWZ3F1_nFUm<6oi2Dd`KoSiOG
00?oTZ3MojO4k_nWa>h01OnWa>h00ondf??o^NGdokWUm003okWUm0?o]mgc1_n`c_02oj_5k@GoYkk[
1OnW_n/2ojW2k0KoZ<7/1_nW`>/00onW_^_oY[k[ojJnj`05ojJnj`?oZ<3[00?oZ<7/o`000?nX`N`0
2?nX`N/3ojO0j`;oYkk[2?nW_n/2ooooo`03o`000?oooooooooo00Cooooo000Uooooo`03o`000?oo
oooooooo03;ooooo1_nU_n`7ojS0j`KoY[o/1_nF^_45og>[m0GoP[7c00?o[l7Wok;3i_nb`nH01Onb
`nH00oo9a]Oob<CFolS4eP05olS4eP03olW2e?o8_m;ob;oB00Cob;oB0_o7_M07okbjf0;o_kOB1on]
^>43oiVkk`CoY;WX1_nE__@3oic7mPCoU/;f1_nNb_H3oj?6lPCoWL_g1_nRboD3ojG8lPCoX<kg1OnS
coL2ojG4l0OoYlOa0onYb?03ojN`g`KoYZgM1_nSZ=T6oijPePKoUYOC0on@U=<2oiBLf0OoUjSR1_nW
a>h3ok?NmP03okWUm?nggO?o]mgc00Go]mgc0on`c_02oj[3k0SoYkk[00?oYko[ojW2k?nY`^`01?nY
`^`6ojS1k0;oYl3[1OnW_^/5ojJnj`;oZ<7[1?nX`N`00ol0003oZ<7/ojS1j`05ojS1j`03ojO0jonW
_^_oYkk[00CoYkk[1_nW_n/01?nX`N_oooooooooool00006ooooo`009_ooool00ol0003ooooooooo
o`0booooo`KoYKo/1onX`>/6ojJok0?oU[[a0onD^_45og2/mPGoPkCd1_nb`nH00onba>Oob<CFolS4
eP05olS4eP;oa/;F1Oo8_m84olNmd0Co_;[H1Ono]m85ojfhh@;o/k;G1onT^NP3oiFnm0?oWkW[1onF
`_H3oik:mP?oVL?e1onMboL3oj;;m@CoWLWf1_nPc_L00onScoOoYLC`ojG4l004ojG4l0GoYlOa00?o
Yk7OojN`gonW/=l01OnW/=l5ojJ]g@OoXjSI0onNX=H2oiRGd@KoUISC1_nDW=P7oiNXhP;oYlC^1Onc
g_H2okKVmPKo]mgc00?o[L[_oj[3k?nZ`n`01?nZ`n`6ojNnj`03ojO0jonY`^coZL;/00KoZL;/0onX
`N`2ojO0j`SoYkk[00?oY[k[ojS1jonX`N/01?nX`N/3ojS1k003o`000?nX`NcoZ<7/00;oZ<7[1OnW
`>/6ojNnj`;oYko[1OnX`N/00ooooooo0000ooooo`05ooooo`009oooool00ol0003oooooooooo`0b
ooooo`KoYKo/1onX`>/3ojJok0?oYKo/1_nD^_45og2/mPGoPkCd0onb`nH4ok;4i`Gob<CF1?o6`]H3
olRodPKoakg@00?o_;[Hokngd_no]m801_no]m800on]^>7o/k;Gok>be`04ok>be`GoY;WX0_n]/]`6
oinij`GoU/;f0_nO^^/6oiW3m@GoWL_g0_nN`O47oig9mP?oX<kg1?nT_nd6ojG4l003ojO7lOnW/Moo
Yk7O00?oYk7O1_nW/=l6ojJ]g@?oXjSI0onKV<l6oiRGd@KoUISC1_nDW=P5oiNXhP?o[=7d0oncg_H5
okKVmP;o]mgc1On]b^l6oj[3k0;oYkk[1OnW`>/6ojW2k003ojS1k?nW`>_oYl3[00CoYl3[1_nW_^/0
0onV_^_oZ<7[ojS1j`06ojS1j`?oZ<7/00?o0000ojS1jonW`>/01onW`>/3ojNnj`CoYko[1_nX`N/0
0ol0003oooooooooo`04ooooo`00:?ooool2o`0003?ooooo1_nU_n`7ojS0j`KoYKo/1_nD^_45og2/
mPGoPkCd00?o//?Vok;4ionba>L01?nba>L3olS4ePKoa/;F00?ob;oBolNmd?o7_M001Oo7_M08okng
dP03ol:fc_nc/]Oo/k;G00Ko/k;G00?oY;WXojfbg?n]/]`01?n]/]`6oinij`03oiK2m_nO^^_oWk[[
00CoWk[[1_nI`oD00onMboOoW/7aoik1l@04oik1l@GoWLWf0_nU^NL7ojBok@?oYLC`0_nW[]`7ojNa
g`KoYk3O0onV[Md2oinJcPOoViS?1_nHUm45oiFHd`OoU9cH00?oUjSRojcAm?n/dO@01On/dO@00onc
g_Ko]^KfokKVmP03okKVmP;o/MCb1on]b^l3oj[3k0?oY[kZ1onW`>/2ojW2k0GoZ<7/1_nW`>/2ojNn
j`GoY[k[1_nX`N/00onX`NcoZ<7[ojS1j`02ojS1j`03o`000?nX`N_oYl3[00GoYl3[00?oYkk[ojNo
jonW_n/01_nW_n/3ojS1j`;ooooo00?o0000ooooooooool01?ooool002[ooooo00?o0000oooooooo
ool0<Oooool6ojFok0OoZ<3[1_nU_n`3oiBjl@?oTk[b1Om^[OL5oh:fmPOo//CW00?ob<CFolK2e_o6
`]H01?o6`]H00oo4`MOoakg@olNmd005olNmd0;oa[c@1_no]m83ol:fcPKo/k;G00?o^k3?ojfbg?n]
/]`01_n]/]`3oinij`?oZ[7M1onO^^/3oiW3m@CoXkSX1_nN`O400onMbOKoYKWWojFii`04ojFii`Go
Y;o]00?oZ:[HojN^g?nW[]`01?nW[]`7ojNag`?oYk3O0_nRVlh6oinJcPOoViS?1OnHUm45oiFHd`Ko
U9cH0_nQ_>`6ojcAm0?o/NGh00?o]^Kfok7Dl_nae?801?nae?85ojg:k`03ojS0jonV_^[oY[kZ00Go
Y[kZ1OnW`>/00onY`^coZ<7/ojS1k006ojS1k0?oYl3[2_nV_^/2ojS1j`GoZ<7/1?nX`N/01?l0003o
Z<7[ojO0jonW`>/5ojNnj`KoYko[1oooool00ol0003oooooooooo`03ooooo`00:oooool00ol0003o
ooooooooo`0aooooo`KoYKo/1onX`>/7ojFok0GoTk[b1Om^[OL5oh:fmPGo//CW0_n_a>X5olK2eP?o
a<7G1Oo7_M04olJld0?o_kOB1_o2]/h3ok>be`Co^k3?1_n]/]`00ond[=3oZ[7MojZag@05ojZag@Go
Wk[[00?oZZkKoj>hj?nS^>P01_nS^>P3oik1l@;oZ;7O2?nU^NL00onT_ngoZ:[HojRZf003ojRZf0Ko
YjkL1OnW/Ml00onUW<goXY_>oj:KcP04oj:KcPKoWi[>1_nKV<l6oiRGd@GoUISC0_nDW=P6oj6lk0;o
[=7d1OnaiOP2okCQmPOo/MCb00?o[L[_ojS0jonX`>/00onX`>/7ojJnjP03ojO0jonY`^coZL;/00?o
ZL;/1_nX`N`00onW_n_oY[k[ojJnj`0:ojJnj`WoZ<7/0onX`N/00ol0003oYko[ojNnj`07ojNnj`;o
Yko[2_ooool00ol0003oooooooooo`03ooooo`00;?ooool00ol0003oooooooooo`0aooooo`KoYKo/
1onX`>/7ojFok0GoTk[b1Om^[OL5oh:fmP03ok;4ion_a>[o[lCZ00Co[lCZ0oo6`]H5olC1e`?oakg@
1_o6_=000ono]m;o`[K>ol:fcP06ol:fcP03ok>beonk/<oo^k3?00Co^k3?0on]/]`4okB/d0OoZ[7M
00?oWk[[ojZ^fonZ[]/00onZ[]/6oj>hj003oj^Xe?nX/MooZ;7O00CoZ;7O1_nU^NL00onYYM;oZ:[H
ojRZf005ojRZf0KoYjkL00?oYk7OojFLcOnUW<d00onUW<d6oj:KcPGoWi[>1onKV<l3oiRGd@;oVj7I
1_nKZ^46oj6lk0?o[Mkh0onaiOP5okCQmP?o/MCb0on[aNd7ojS0j`?oY[kZ1?nX`^`6ojW2k0;oZ<7/
1OnW_n/8ojJnj`_oZ<7/00?oZ<3[ojNojonW_n/00_nW_n/00ol0003oYko[ojNnj`05ojNnj`gooooo
00?o0000ooooooooool00oooool002gooooo0_l0000booooo`KoYKo/1onX`>/5ojFok0;oY[o/1_nF
^o45ofj^m`GoOKOh1_n_a>X00oo6`]Koa<7GolC1e`05olC1e`03olNmd?o6_=3oa[c@00Coa[c@00?o
a;cBol:fc_o2]/h01oo2]/h8ok^`c`03ojfbg?nd[=3o]:c@00?o]:c@1_nZ/Md00onaZ<ooZZkKojZ^
f`05ojZ^f`;oXkSX1On[Z=@6ojRag`;oYKWW1OnYYM87ojRZf0?oYjkL0_nWWL`6ojFLc@KoXY_>1_nO
V/h3oi^Hc`?oWIkD1_nKXMT6oi^Zh@?oXKc/1_n]g_P00onaiOSo]>7fokCQmP03okCQmP;o[<_`1_n[
aNd5ojS0j`;oY[o[1onX`^`3ojW2k0?oZ<3[1onW_n/3ojJnj`CoYko[2?nX`N`5ojS0j`CoYko[00Co
0000ojNojonW_^_oYkk[4?ooool00ol0003oooooooooo`03ooooo`00;oooool00ol0003ooooooooo
o`0`ooooo`OoYKo/1_nX`>/00onU_ncoY[o/ojJok004ojJok0KoU[_a1Om^[_L5ogfgn0?o[lCZ0onW
aNl6olC1e`;o`/GL1Oo6_=03olBldPWo`[K>1_nk/<l00ono/Lco]:c@okB/d005okB/d0;oZ[7M1Ona
Z<l5ojZ^f`03ok6VcOn[Z=CoZjSD00GoZjSD1OnX/Ml00on/X/goZJGBojVUdP05ojVUdPKoZ:[H00?o
ZYk;ojNMc?nWWL`01?nWWL`6ojFLc@KoXY_>0onOV/h2oinMdPOoWIkD1OnKXMT7oi^Zh@03oj6lk?n]
g_So[Mkh00Co[Mkh0on_ioT00ondhOKo[<_`ojc;l004ojc;l0KoZlG]00?oZ<3[ojJojonV_n/01?nV
_n/6ojS2k0OoZ<3[1OnW_n/00onV_^[oYko[ojNoj`06ojNoj`GoZ<7/2?nX`>/3ojNoj`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool00oooool0033ooooo00?o0000ooooooooool0<Oooool6
ojFok0OoZ<3[1_nV_n`3oiJkl@?oVKca1Omb/?P5ogJgnPKoYlG_0oo4`ML5ol;5g0?oa[c@1Oo4_=88
ol:fcPGo^k3?0ono/L`5okB/d003ok^]c?naZ<oo/JS?00Go/JS?0onZ[]/4ok6Vc@OoZjSD00?oZ;7O
ojbRcOn/X/d00on/X/d7ojVUdP;oZ:[H1OnZW//5ojNMc0KoYIc=1OnRVlh00onRWM3oWigBoinMdP04
oinMdPKoWIkD1_nKXMT3oi^Zh@GoZ=Gg0_n]g_P5ojoWn@03ojkBlon/bo3o[<_`00Ko[<_`0on[aNd2
ojNnjPSoY[o[1_nX`^`7ojS0j`03ojNojonV_^[oY[kZ00?oY[kZ1_nW_n/7ojS1k0KoZ<3[1Oooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00?ooooo000aooooo`03o`000?oooooooooo
037ooooo1onU_n`6ojS0j`CoY[o/0onW_n/5oiVll@GoL[3h1Omf]oX6ojO5k`03olC1eoo2aMco`/GL
00Go`/GL00?oa[c@olBld_o4_=801Oo4_=87ol:fcP?o^k3?1Ono/L`4okB/d0?o^jg<1onaZ<l00onZ
[]_o/JK=ok6Vc@04ok6Vc@GoZjSD00?o/JC;ojbRcOn/X/d01On/X/d5ojVUdP03ojfQbonZW/_oZYk;
00GoZYk;1OnWWL`7ojFLc@03oj:Kc_nRWM3oXYg@00?oXYg@1_nOWM85oifNe0GoVj7I0onUb_<5ojSE
m`CoZ^Oj00?o[nOiojkBlon^d_<00on^d_<6ojc;l003ojS0jonW_^[oYkkZ00CoYkkZ1_nV_n/8ojS2
k0?oZ<3[0onW_n/7ojJnjP;oYko[2onX`N`2ojS0j`Wooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`03ooooo`00<_ooool2o`0003;ooooo1onU_n`6ojS0j`03ojJok?nW_n_oYko[00Co
Yko[1OnI_?45og:`n0GoM[Oj0onWaNl3oiW4m@Ko`/GL00?o^/SUolBld_o4_=801Oo4_=800oo2`MWo
`[K>ol:fcP06ol:fcP03ok^`cono/Lco_k7<00Co_k7<0ond[=05ok^]c0Go/JS?00?o^:[;ok6VcOna
Y/d01OnaY/d3oj^Xe0Co/JC;1_n/X/d3ojVUdPCo[J7;1_nZW//6ojNMc0?oYIc=0onUWll7oj:Md0Go
WigB1_nMW]@00onKXMWoYL[cojG:l`05ojG:l`03ojSEmonZio[oZ^Oj00CoZ^Oj0_n_g?L6ojkBl`;o
[<_`1OnX`>/6ojNnjP;oY[o[2_nX`^`2ojO0j`KoYko[1OnV_^X00onW`>_oZ<7/ojS1k009ojS1k0ko
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`00=?ooool00ol0003ooooo
ooooo`0`ooooo`OoYKo/1_nX`>/7ojNoj`;oVKca1?nL_Nl5og^dm`GoK[Gk1OnIa?D3ol;5g0Co^/SU
1Oo4_=83ol;1f@Ko`[K>00?o`KWBoknac?no/L`01_no/L`00ond[=3o^jg<ok^]c004ok^]c0?o/JS?
1?nhZ//7ok6Vc@03oj^Xe?naY<_o/JC;00Co/JC;1_n/X/d00onYYM;o[J7;ojfQb`03ojfQb`OoZYk;
1?nWWL`00onXXLooYIo?ojFOc`05ojFOc`KoXYg@1_nOWM83oifNe0CoXKk]1OnUb_<3ojGSn`;oZ^Oj
1_n_g?L3ojkBl`?oZL?]1onX`>/3ojNnjP_oZ<;/1_nW`>/6ojNoj`03ojJnj_nW`>_oYl3[00?oYl3[
1_nX`N`Booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool003Gooooo00?o
0000ooooooooool0<?ooool7ojFok0KoZ<3[1OnW_n/2ojRoj`KoW;g_1Omk]?L5ofjen`GoVLCe00?o
`/GLok[8iOnjb>D01?njb>D3olBldPGo`/7I0oo2]/h4ol6idPKo_k7<00?o_kC?ok^]c?nk[L`01_nk
[L`00onaZ<oo^:[;okRZb`04okRZb`Go/JK=00?o]ZW<ok6TbonaY</01OnaY</5ojbRc@03ok2Tc?n]
XL_o[J7;00Go[J7;1_nZW//00onWWLcoZ:7?ojRQc`03ojRQc`KoYIo?1onRWM03oinMdP;oXkSW2?nQ
_^d00onUb_?oYN?kojGSn`03ojGSn`?oZ^;j1On_g?L00onZanooZL?]ojW3k@05ojW3k@GoZ<3[00?o
Y[o[ojS2k?nX`^`02OnX`^`2ojS1j`SoYl3[0onW_n/3ojNnj`KoYl3[0_nX`N`Fooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool00_ooool003Kooooo00?o0000ooooooooool0<?ooool7
ojFok0KoZ<3[00?oYko[ojRojonX_n/01?nX_n/6oibmk`;oNkCg1?n6^?H4ofRdn`KoR<;j1_njb>D0
0oo4_=;o`/7Iol;1f@05ol;1f@03ol:fc_o1^M;o`KWB00Co`KWB0ono/L`4okndc`Ko^jg<00?o_;7?
okRZbonhZ//01OnhZ//3ok6Vc@Co]ZW<1onaY</00on/X/go/:C<ok2Tc003ok2Tc0Ko[J7;1OnZW//0
0on[Y=3oZ:7?ojRQc`05ojRQc`GoYIo?1_nRWM000onU]NCoXkSWoj>hi`04oj>hi`KoXKk]0onSh?`0
0onUho_oZ^;joj[RnP05oj[RnP03ojoLmonZanooZ/O_00?oZ/O_1onY`nd00onX`>_oY[o[ojJoj`03
ojJoj`OoZ<;/1_nX`N/6ojO0j`03ojNnj_nW_^_oYkk[00GoYkk[0onW`>/Kooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool00_ooool003Oooooo0_l0000booooo`KoYKo/0onX`>/4ojO0
k0KoZ;o[0onL_Nl4oj2nkPKoQ[Sf0omX]?/6ohS2nP?o^/SU0onXb_86ol;1f@03ok[:i_o1^M;o`KWB
00Ko`KWB00?o_k7<okndcono]<l01?no]<l3ok^]c0Co_;7?1onhZ//00onaY/go]ZW<okJYc004okJY
c0Go/JC;00?o]:[?ok2Tc?n`Y<`01On`Y<`6ojfQb`03ojZNbon[Y=3oZjC@00?oZjC@1_nXXLl6ojFO
c`;oXYg@1OnU]N@6oj>hi`;oXKk]1OnSh?`2ojCTo0KoZ^;j00?oZ/_aoj[7konZanl01OnZanl3ojW3
k@CoYkkZ1_nV_n/7ojS2k0KoZ<7[0_nW`>/5ojNnjPGoYkk[8?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00;ooooo000iooooo`03o`000?oooooooooo033ooooo1_nU_n`7ojO0k0?o
Z;o[0onY`>/7oj2nkP?oQ[Sf0onD_?<2offcnP04ofRdnon8`_[oR<;johS2nP?oM[km1_nXb_83ol;1
f@Co^/[V1_o1^M800onoaMoo_kC?okndc`06okndc`03ok^]c?nl/Loo_;7?00Co_;7?1OnhZ//00oni
/=3o]ZW<okJYc005okJYc0?o/JC;1?ndZ/l6ok2Tc0Go[J7;00?o[ZWBoj^Td?n[Y=001On[Y=06ojRQ
c`?oYIo?0onW]^<6ojFei0GoXkSW1?nQg?`00onSh?coY>ClojCTo004ojCTo0;oZ^;j1OnZbo45oj[7
k`WoYkkZ0onV_n/:ojS2k0?oZ<7[0onW_nX7ojNnjP03ojNnjooooooooooo027ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`02ooooo`00>_ooool00ol0003oooooooooo`0`ooooo`Ko
YKo/1OnW`>`2ojK0k0KoZL3[1OnP_^h2ojBnk0KoU;cc1?m]/oX5ogJno@KoZ<[b00?o`/7Iok[:i_nj
b^H01?njb^H3ol6idPCo_lGO1_no]<l00onn`Mgo_;7?okbac`05okbac`?o^:[;1?ni/=07okJYc003
ok6TbondZ/oo]:[?00Co]:[?1_n`Y<`00on]XL_o[ZWBojjYdP03ojjYdPKoZjC@1OnXXLl00onZ^^Go
YkKSojNfh`05ojNfh`KoYKGT00?oXkSWoj7Lo?nQg?`01?nQg?`3oigTo0?oY>Cl1?nYcO<6oj[;l@03
oj[7konW_^[oYkkZ00WoYkkZ00?oZ<;]ojS2k?nX`^`02_nX`^`00onW_n_oYkoZojNojP05ojNojP?o
YkkZ:?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00;ooooo000kooooo`03o`00
0?oooooooooo033ooooo1_nU_n`00onW`>coY/3/ojK0k004ojK0k0KoZL3[00?oX;k^ojBnk?nT_^`0
1?nT_^`6oiBll`CoKK?j1Omf__d3ojS:lPCoS<Sl1_njb^H00oo1^M;o_lGOoko5g`04oko5g`?o_kC?
1?nn`Md7okbac`03okRZboni/=3o^K3@00Co^K3@1OnfZL`00ong]MOo]:[?okBZc`05okBZc`Go/:C<
00?o/[?IojjYd_n^ZM801On^ZM86oj^Td003ojRQconZ^^GoZ[[U00?oZ[[U1onW]^<3ojFei0GoWm[l
00?oXMcloigTo?nMi?`00onMi?`2ojS?m0OoZLgc0onZbo43ojRoj`SoYkkZ1OnX`^d8ojS2k0GoYko[
1OnW_nX]ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00Oooool003cooooo00?o
0000ooooooooool0<?ooool3ojFok0?oY[o/1onV`>`3ojW0j`CoZL7[1_nT_^`3oiBll`CoWKg_1?mn
^?P5ofRjo@KoS<Sl0onjb^H3oio=n0Oo_lGO00?o_kC?okk1gOnn`Md01?nn`Md5okbac`03ok_2goni
/=3o^K3@00Go^K3@0onfZL`4okNee`Oo]:[?00?o/:C<ok:cfOnb/mT00onb/mT6ojjYdPGoZjC@0_n/
`^T6ojZji@GoYkKS0_nNf_`6oioJo0?oV>?m00?oWNClojS?m?nXco@01?nXco@5ojW=l`03ojS1jonX
_n_oZ;o[00GoZ;o[0onW_^X3ojO1k0OoZ<;]0onX`^`4ojS0j`KoYko[00?oYkoZooooooooool0;ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo007ooooo000mooooo`;o0000<Oooool6
ojJok0GoY/3/0_nU`>d7ojW1j`?oY;k/0onW_n/7oifmk`CoO[Sh1OmX^_d3ohc8o0CoLl?n1OnOcOP5
oko5g`;oZLod1onn`Md00onl/Loo^l;Ook_2g`03ok_2g`Oo^K3@00?o]ZW<okNeeong]ML01?ng]ML5
okBZc`03okC2iOnb/mWo/[?I00Go/[?I1_n^ZM800on[Y=3o[<;Yojc2j@04ojc2j@KoZ[[U00?oYkKS
oikJo?nNf_`01?nNf_`2oioJo0GoV>?m0_nVd?H7ojS?m003ojW=lonX`N_oZ<7[00?oZ<7[1OnX_n/2
ojO0k0KoYl7/1OnX`^d2ojS1k0OoZ<3[0onW_n/dooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool00Oooool003oooooo00?o0000ooooooooool0;oooool6ojJok003ojK0k?nU`>goYL3]
00CoYL3]1OnY`N/2ojO1k0KoYko[1OnM_Nl2oj>nk@GoT[gd1_m^]o`5og?3oPGoWlgh00?o_lGOojW?
m?nYco@01?nYco@5okk1g@;oZ]7d1_nk`]l5okV`d0;o^<SV1ong]ML00ondZ/oo]<;UokC2i@03okC2
i@Ko/[?I1On^ZM800on/c?7o[<;Yojc2j@06ojc2j@?oZ[[U1?nKfod3oikJo0GoTn7m00?oV>?mojK@
m_nVd?H01?nVd?H3ojS?m0CoZ<;/1_nX`N/00onX_n_oYl3/ojO0k004ojO0k0KoYl7/00?oZ<;]ojS1
k?nX`N`01?nX`N`5ojS0jcWooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`01oooo
o`00@?ooool00ol0003oooooooooo`0_ooooo`?oY[o/1?nV_n/6ojG0k@03ojW1jonW`NcoYl7/00Co
Yl7/1_nW_n/00onM_NooXkk]oj>nk@04oj>nk@GoT[gd0om^]o`4ohFkn0GoJKgm1Omnb_l6ojW?m003
okk1gOnZdOCoZ]7d00CoZ]7d1_nk`]l00oni/=3o^<SVokS8iP04okS8iPGo]kGG00?o[=7cokC2iOnd
`^D01Ond`^D6ok:cf@03ojjYd_n/c?7o[<ca00?o[<ca1_n/`^T2oiKLoPGoVm_m1?n>goh3oi?Qo@?o
Y=3g1OnVd?H2ojS2k@OoZ<;/0onX`N/3ojNoj`OoYl3/0onW`N`3ojS2k0OoZ<7/00?oZ<3[oooooooo
ool0>oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo007ooooo0011ooooo`03o`00
0?oooooooooo02oooooo1onV_n/3ojG0k@?oYKo/1onW`N`3ojNoj`CoZL7[1_nS_^d2oi:mm0CoW[k_
1_n5^oP5ofVmo@GoO/[o0onYco@4oh?>o`KoZ]7d0onk`]l4oj?Cn@Ko^<SV00?o]kGGojcAlon/dO<0
0on/dO<7okC2i@?o/[?I0onSdoP6ojc<l@;o[<;Y1_nFg?h00onKfogoS]onohkOoP04ohkOoP;oX/gf
1_nTd?L00onVd?KoZ<;]ojS2k@04ojS2k@GoZ<;/2?nW_n/5ojO0k0SoZ<;/0onX`Na1ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool00Oooool004;ooooo0_l0000`ooooo`GoY[o[0_nW
_n/6ojFok0GoYl7/0_nU`>d7ojW1j`?oXkk]0onW_nX6oijnk`?oQK_h0onJ__46ogfknPKoJL;n1On3
c_l3oj[Am0CoP]3o1_nSdoT3okS8iP?oU=Gn1_n/dO<3okC2i@CoU]Sn1_nSdoP3ojc<l@GoS]co0onF
g?h5ohcLoP03ohkOo_nRcOKoX/gf00CoX/gf0onTd?L4ojO2k@KoZ<;]00?oZ<;/ojNojonW_n/02_nW
_n/00onW`>coZ<;/ojS2k008ojS2k4Kooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`01ooooo`00A?ooool00ol0003oooooooooo`0^ooooo`03ojJojonW_n_oYko[00CoYko[1_nU_n`0
0onW`NcoYL3]ojG0k@04ojG0k@GoZL7[0_nX`N`6ojNojPCoW[k_0_nU_^/6oiZnl@KoOK_j0omY`_h4
ogbmn`GoK<Kn1_n2d?l3oj?Cn@?oNm7o1_nDeOh3ojcAl`CoQMOo1_nFf?h3oj?Cn0GoQ=[n0on>g?l4
ohgHo`?oS=cn1?nRboD5oj;=mP;oYl7]1onW`^d3ojS2k@?oYkoZ2OnW_n/4ojO2k@OoZ<;/B_ooool0
0ol0003oooooooooo`07ooooo`7o00000Oooool1ooooo`00AOooool00ol0003oooooooooo`0_oooo
o`KoYko[0onU_n`4ojJok0KoYL3]00?oZL7[ojS1k?nX`N`01?nX`N`6ojNojP03oijnkonU_^_oYKk[
00?oYKk[1_nJ__43ogfknPCoV;oc1_ml_O/5ofc6oP?oP]3o1?m`b?l5og_Ao`?oU=Gn1OmfdOl5ohGG
o`?oU]Sn1Omle_h3ohCJoPCoSm;n0on=f?l4oj;8l`KoX/_e00?oX/gfojO1kOnW`Nd01?nW`Nd5ojO2
k@SoYkoZ0onW_n/:ojO2k@?oZ<;/C_ooool00ol0003oooooooooo`06ooooo`7o00000Oooool1oooo
o`00A_ooool00ol0003oooooooooo`0`ooooo`;oYko[0onX_n/7ojJok0?oYL3]1?nU`>`6ojS1k0?o
YkoZ0onY`N/6ojFnj`?oV[ka1?nS_^`6oiRol`?oO;gk1?nI`?<5oh2on`?oL<So1?n:`_X6og[9o`?o
M]7o1?n9b?`6oh3@o`?oO=Kn1?nDb_X3ohoBoPCoX/Ga1_nRb?<3oj;;m@CoY/3/1_nW`Nd00onW`^go
YkoZojNojP08ojNojPgoYl;]D_ooool00ol0003oooooooooo`06ooooo`7o00000Oooool1ooooo`00
Aoooool2o`00037ooooo1OnX_n/5ojJok0;oYko[1onU`>`3ojS1k0?oYL7]1_nY`N/3ojFnj`CoZ<3[
1_nS_^`3oiRol`CoX[k]1_nI`?<2oh2on`CoW<7b1_n:`_X3og[9o`CoUl?f1_n9b?`3oh3@o`?oVlKe
1OnDb_X2ojC2k`OoX/Ga0onRb?<3ojNoj`OoY/3/0onW`Nd3ojNoj`OoYkoZ3OnW`^eFooooo`03o`00
0?oooooooooo00Gooooo0Ol00001ooooo`7ooooo0019ooooo`03o`000?oooooooooo02oooooo1OnX
_n/00onV_ncoYko[ojNoj`04ojNoj`GoYL3/0_nV_n`6ojG1k@CoZL7[0_nW`N`7ojS0j`?oXkk/0onX
_nX7oj:nk@?oVL3c0onS_^`6oic1lP?oR/;j1?nP`>l6oiO3mP?oRLSl0onP`_06oi_6m@03oiC:n_nT
`^ooY<;_00CoY<;_1OnRaO42ojNnjPKoYko[1OnV`>`00onX`>_oYko[ojNoj`05ojNoj`?oYkoZ3OnW
`^eJooooo`03o`000?oooooooooo00Cooooo0Ol00001ooooo`7ooooo001:ooooo`03o`000?oooooo
oooo02oooooo0_nX_n/4ojRojPKoYko[00?oYL3/ojJok?nV_n`01?nV_n`6ojG1k@03ojW1jonW`Nco
Yl7/00?oYl7/1OnX`>/2ojS2k0KoZ;oZ1OnR_^d00onX_n[oXkk/oj>nk005oj>nk0?oW<7b0onU_^/7
oj30k`?oUl?f0onT_nd6oj32l0?oVlKe1?nU_n`6ojC2k`03oj;5lOnW_^[oYkkZ00CoYkkZ1_nW_n/0
0onV`>coZ<3[ojS0j`03ojS0j`GoYko[3?nW`^ePooooo`03o`000?oooooooooo00?ooooo0Ol00001
ooooo`7ooooo001;ooooo`03o`000?oooooooooo02oooooo1_nX_nX3ojNoj`CoZ;o[1_nV_n`3ojG1
k@CoYKo/1OnW`N`00onX`>_oZ<;/ojS2k004ojS2k0KoZ;oZ00?oX[k]ojRoj_nX_nX00onX_nX5oj>n
k0;oZ;o[1_nU_^/5oj30k`;oYkkZ1_nT_nd3oj32l0?oYkkZ1onU_n`3ojC2k`[oYkkZ0onW_n/3ojS1
j`KoZ<3[00?oYko[ojO2kOnW`^d02OnW`^eTooooo`03o`000?oooooooooo00?ooooo0Ol00001oooo
o`7ooooo001<ooooo`;o0000<?ooool4ojRojP;oZL3Z1onX_n/3ojJok0?oYko[1onU_n`2ojO1k0Co
YL3]1_nX`^`3ojRojPCoZ<;/1OnX_nX00onS_^coZ;o[ojRoj`04ojRoj`KoYKk[00?oX<3_ojNnj_nW
_^X01?nW_^X4ojBok@;oZ;o[1_nW_^X5ojFok0;oZ<3[2_nW_^X2ojS2k0OoZ<7[0onX`>/;ojO2kFSo
oooo00?o0000ooooooooool00oooool1o`00007ooooo001>ooooo`03o`000?oooooooooo02kooooo
00?oZ;oZojW0j_nY`>X00onY`>X5ojRoj`;oZ;oZ1_nW_n/5ojFok003ojJojonU`>goYL3]00GoYL3]
0onX`^`3ojG0k@OoZ<;/0_nX_nX3ojS2k0OoZ;o[0onU_^/4ojS1j`KoYkkZ00?oY;o]ojRojonX_n/0
0onX_n/6ojNnjP03ojFok?nX`>_oZ<3[00CoZ<3[1OnW_^X00onW`^goZ<;/ojS2k004ojS2k0GoZ<7[
3?nW`^e/ooooo`03o`000?oooooooooo00;ooooo0Ol00001ooooo`00Coooool00ol0003ooooooooo
o`0_ooooo`GoZL3Z00?oZ;o[ojRoj_nX_nX01?nX_nX6ojNoj`03ojFok?nV_n_oY[o[00?oY[o[1OnU
`>d2ojJok0KoYL3]1OnX`^`00onV`NgoZ<;/ojS2k004ojS2k0GoZ;o[0_nW`^`7ojS1j`?oYkkZ0_nX
`^`7ojRoj`?oYkkZ1?nX`^`6ojS0j`03ojNnj_nW`^goYl;]00?oYl;]1_nX`^`00onX`N_oYl;]ojO2
k@09ojO2kG7ooooo00Go0000ooooooooooooooooo`000001ooooo`00D?ooool00ol0003ooooooooo
o`0_ooooo`;oZL3Z0onY`N/7ojRojP?oYko[1?nX_nX5ojJoj`03ojG0kOnV_ncoY[o/00CoY[o/1_nU
`>d00onX`^coY/7]ojK1k@03ojK1k@KoZ<;/00?oZ;o[ojO2k?nW`^`01?nW`^`5ojS1j`03ojK1kOnX
`^coZ<;/00CoZ<;/1OnX_n/2ojO2k@OoZ<;/0onX`>/3ojK2k@KoYl;]0onX`^`4ojO1k0OoYl;]M?oo
ool01Ol0003ooooooooooooooooo0000007ooooo001Aooooo`;o0000<?ooool5ojW1j`GoZ;oZ0_nY
`>X7ojRojP;oY[o[1?nW_nX6ojJok0?oYL3]1?nV_n`5ojK1k@?oZ<;/1?nV`Nd6ojO2k003ojS1jonV
`NgoY/7]00?oY/7]1_nX`^`00onX_n_oYl;]ojO2k@04ojO2k@GoZ<;/00?oY/7]ojK2kOnV`^d01OnV
`^d3ojO2k@[oYl7/0onW`^ehooooo`04o`000?ooooooooooo`00007ooooo001Cooooo`03o`000?oo
oooooooo02kooooo1OnY`N/00onX_n[oZL3ZojW0jP04ojW0jPGoZ;oZ00?oZKoZojNoj_nW_nX01OnW
_nX3ojJok0?oYko[1onV_n`2ojK1k@CoY[o/1_nV`Nd3ojO2k0?oY/3/1_nV`Nd3ojS2k0CoY/7]1_nW
`^d00onX`^coY/7]ojK1k@03ojK1k@GoY/;]0_nW`>`;ojO1k7gooooo00?o0000ooooool000000Ooo
ool005Cooooo00?o0000ooooooooool0;_ooool2ojW1j`CoYl7/1_nY`>X00onX_n[oZKoZojVojP03
ojVojPGoYkoZ0_nX_nX6ojNoj`GoY[o/00?oYko[ojJok?nV_n`01OnV_n`3ojK1k@?oYko[1_nV`>`3
ojK1k@CoY/3/1_nV`Nd3ojO2k@?oY/3/1_nV`Nd00onV`^goYl3/ojO0k004ojO0k0OoYl7/P?ooool0
0ol0003oooooo`000001ooooo`00EOooool00ol0003oooooooooo`0^ooooo`KoYl7/0onY`>X4ojS1
j`GoZKoZ00?oYkoZojRoj_nX_nX01?nX_nX6ojNoj`03ojJok?nW_n_oYko[00?oYko[1OnV_n`2ojNo
jPKoYko[1?nV`>`2ojNoj`OoY/3/0onV`Nd2ojNoj`OoY/3/0onV`Nd4ojNoj`KoYl3/0onW`Nb4oooo
o`7o00000Oooool1o`000000E_ooool2o`0002oooooo0onW`N`3ojK0k0OoZ<7[0_nY_nX4ojW1j`Ko
Z;oZ0onW_n/4ojRojPGoYko[00?oY[o/ojNoj_nW_nX01?nW_nX6ojNoj`03ojK0k?nW_n_oYko[00?o
Yko[1OnV`>`2ojNojPGoYko[1OnV`>`2ojNojPOoYko[0onW`>b:ooooo`;o0000001Hooooo`03o`00
0?oooooooooo02gooooo1_nV`>`5ojS1j`;oY/7/1_nY`N/3ojRojP?oZL7[1onX_nX2ojNoj`CoZ;oZ
1_nW_nX3ojNoj`?oZ;oZ1_nW_n/00onV`>coYkoZojNojP04ojNojPGoYko[00?oY/3/ojNoj_nW_nX0
1?nW_nX5ojNojhgooooo0ol0000005Wooooo00?o0000ooooooooool0;Oooool6ojK0k003ojS1jonV
`NcoY/7/00CoY/7/1?nY`N/2ojO1k0KoZL7[1OnX_nX00onY`N_oZ;oZojRojP05ojRojP?oYkoZ2OnX
_nX3ojNoj`CoZ;kZ1_nW_nX2ojNoj`CoZ;kZ1_nW_nX00onW_n_oooooooooo`2:ooooo`Co00000ooo
ool005[ooooo00?o0000ooooooooool0;Oooool7ojK0k0KoY/7/00?oZL7[ojO1k?nW`N`00onW`N`6
ojW1j`03ojRoj_nY`N_oZL7[00?oZL7[1OnX_nX2ojS1j`coZ;oZ1onX_^X3ojNojP?oZ;oZ1_nX_^X3
ojNojXcooooo0ol00007ooooo`00Foooool00ol0003oooooooooo`0^ooooo`KoY/3/0onV`N`3ojK0
k0KoYl7/0onY`N/4ojO1k0GoZL7[00?oZ;oZojS1jonX`N/01?nX`N/<ojRojPGoZ;kZ00?oZ<3[ojRo
j_nX_nX01OnX_nX3ojRnjXgooooo1?l0000:ooooo`00G?ooool2o`0002oooooo0onV`>`3ojNoj`Ko
Y/3/0onW`N`4ojK0k0KoYl7/0_nY`N/4ojO1k0KoZ<7[0onX_nX3ojS1j`KoZ;oZ00?oZ;kZojS0jonX
`>/00onX`>/5ojRojXgooooo1?l0000>ooooo`00G_ooool00ol0003oooooooooo`0]ooooo`KoYko[
1?nV`>`2ojNoj`OoY/3/0onW`N`2ojK0k0OoYl7/0onX`N/3ojO1k0KoZ<7[0onX_nX4ojO1k0GoZ<3[
00?oZ;oZooooooooool0R_ooool4o`0001;ooooo001Oooooo`03o`000?oooooooooo02gooooo1_nW
_n/00onV`>coYko[ojNoj`03ojNoj`GoY/3/0_nW`>/5ojK0k0GoYl7/0_nV`>`6ojO1k0?oZ<7[0onV
`N`7ojO1k0;oZ<3[Roooool4o`0001Kooooo001Pooooo`03o`000?oooooooooo02gooooo0onW_n/4
ojRojPGoYko[00?oY/3/ojO0jonW`>/01?nW`>/5ojK0k003ojO1k?nV`>coY/3/00CoY/3/1?nW`N`2
ojK0k0KoY/7/1OnW`Nb;ooooo`?o00006_ooool0067ooooo0_l0000_ooooo`KoZ;oZ0_nW_n/4ojRo
jPKoYl3[0_nV`>`4ojNoj`KoY/3/00?oYl7/ojK0k?nV`>`00onV`>`6ojK1k003ojO1k?oooooooooo
08Sooooo1?l0000Mooooo`00Hoooool00ol0003oooooooooo`0]ooooo`?oZ;oZ0_nX`>X7ojRojP?o
Yl3[0onW_nX6ojNoj`?oY/3/0onW_n/6ojK0k0?oY/7/ROooool4o`00027ooooo001Tooooo`03o`00
0?oooooooooo02gooooo1OnX`>X7ojRojPKoYkoZ0onW_n/4ojRojPGoYko[0onV`>b:ooooo`Co0000
9Oooool006Gooooo00?o0000ooooooooool0;Oooool5ojS0jPOoZ;oZ1?nW_nX9ojRojP;oYko[Rooo
ool4o`0002Wooooo001Vooooo`;o0000;_ooool2ojS0jPCoZ<7[1_nX_nX00onW_n[oZ;oZojRojP08
ojRojX_ooooo0ol0000]ooooo`00J?ooool00ol0003oooooooooo`0/ooooo`KoZ<7[0onX_nX3ojS1
j`OoZ;oZR_ooool4o`00033ooooo001Yooooo`03o`000?oooooooooo02cooooo0onX`N/4ojO0k0Go
Z<7[0onX_nZ9ooooo`Co0000=?ooool006[ooooo00?o0000ooooooooool0;?ooool7ojO0k0;oZ<7[
R_ooool4o`0003Sooooo001[ooooo`;o0000;Oooool5ojO0k8Wooooo1?l0000looooo`00KOooool0
0ol0003oooooooooo`0[ooooo`03ojO0k?oooooooooo08Oooooo0ol00010ooooo`00K_ooool00ol0
003oooooooooo`0Zooooo`03o`000?oooooooooo08?ooooo1?l00013ooooo`00Koooool00ol0003o
ooooooooo`0Yooooo`03o`000?oooooooooo07oooooo1?l00017ooooo`00L?ooool2o`0002Wooooo
00?o0000ooooooooool0Noooool4o`0004_ooooo001booooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool0Moooool4o`0004oooooo001cooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0M?ooool3o`0005?ooooo001dooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool0L?ooool4o`0005Kooooo001eooooo`03o`000?oooooooooo02?ooooo00?o0000oooooooo
ool0K?ooool4o`0005[ooooo001fooooo`;o00008oooool00ol0003oooooooooo`1Xooooo`Co0000
G_ooool007Sooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1Tooooo`Co0000H_oo
ool007Wooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`1Qooooo`?o0000I_ooool0
07[ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1Mooooo`Co0000JOooool007_o
oooo0_l0000Nooooo`03o`000?oooooooooo05Wooooo1?l0001]ooooo`00OOooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo05Gooooo1?l0001aooooo`00O_ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo057ooooo1?l0001eooooo`00Ooooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo04kooooo0ol0001iooooo`00P?ooool2o`0001Wooooo00?o0000oooo
ooooool0B_ooool4o`0007cooooo0022ooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool0A_ooool4o`00083ooooo0023ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
@_ooool4o`0008Cooooo0024ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0?_oo
ool4o`0008Sooooo0025ooooo`;o00004oooool00ol0003oooooooooo`0looooo`?o0000S?ooool0
08Oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0hooooo`Co0000Soooool008So
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0dooooo`Co0000Toooool008Wooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0`ooooo`Co0000Uoooool008[ooooo0_l0
000>ooooo`03o`000?oooooooooo02cooooo1?l0002Kooooo`00S?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo02Wooooo0ol0002Oooooo`00SOooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo02Gooooo1?l0002Rooooo`00S_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo027ooooo1?l0002Vooooo`00Soooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo01gooooo1?l0002Zooooo`00T?ooool2o`0000Sooooo00?o0000ooooooooool06Ooo
ool4o`000:kooooo002Booooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05_ooool3
o`000;;ooooo002Cooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04_ooool4o`00
0;Gooooo002Dooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03_ooool4o`000;Wo
oooo002Eooooo`;o00000oooool00ol0003oooooooooo`0:ooooo`Co0000_Oooool009Oooooo00Co
0000oooooooooooo00002?ooool4o`000<7ooooo002Hooooo`03o`000?oooooo000000Gooooo0ol0
0035ooooo`00VOooool2o`000003ooooool0003o000000;o0000b?ooool009[ooooo0_l0003<oooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0538698, 0.0432538, \
0.0035044, 0.0035044}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[.12586 .2075 -12 -8.99448 ]
[.12586 .2075 0 .00552 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.56094 .0364 -5.16972 -9 ]
[.56094 .0364 .83028 0 ]
[.75679 .08071 0 -6.17777 ]
[.75679 .08071 12 2.82223 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.9429 .3657 0 -5.9083 ]
[.9429 .3657 6 3.0917 ]
[.02494 .25992 -18 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.01611 .31527 -18 -2.78472 ]
[.01611 .31527 0 6.21528 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00254 .43215 -12 -2.88407 ]
[-0.00254 .43215 0 6.11593 ]
[-0.0124 .49393 -12 -2.93688 ]
[-0.0124 .49393 0 6.06312 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
[(-2)] .12586 .2075 1 .99877 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.56863 .04703 m
.57247 .05235 L
s
[(2)] .56094 .0364 .72324 1 Mshowa
.125 Mabswid
.18558 .19702 m
.18832 .19985 L
s
.23703 .17687 m
.23971 .17975 L
s
.28951 .15632 m
.29214 .15925 L
s
.39772 .11395 m
.40023 .11699 L
s
.4535 .09211 m
.45595 .0952 L
s
.51046 .06981 m
.51284 .07294 L
s
.08568 .23614 m
.08851 .23887 L
s
.62804 .02377 m
.63027 .02701 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.7445 .0853 m
.73835 .08759 L
s
[(-2)] .75679 .08071 -1 .37284 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.93037 .36962 m
.92411 .37158 L
s
[(2)] .9429 .3657 -1 .31296 Mshowa
.125 Mabswid
.7708 .12553 m
.7671 .12688 L
s
.79613 .16428 m
.79242 .1656 L
s
.82054 .20161 m
.81682 .20291 L
s
.86679 .27235 m
.86305 .2736 L
s
.88871 .30589 m
.88497 .30711 L
s
.9099 .3383 m
.90615 .3395 L
s
.71716 .04348 m
.71349 .04489 L
s
.95018 .39992 m
.94642 .40107 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(-20)] .02494 .25992 1 -0.39157 Mshowa
.02837 .31059 m
.0345 .30825 L
s
[(-10)] .01611 .31527 1 -0.38117 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.00981 .42772 m
.01599 .4255 L
s
[(10)] -0.00254 .43215 1 -0.3591 Mshowa
0 .48963 m
.0062 .48748 L
s
[(20)] -0.0124 .49393 1 -0.34736 Mshowa
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.656 .752 .921 r
.39362 .69486 .40169 .70187 .4152 .6981 .40717 .691 Mtetra
.658 .751 .919 r
.40717 .691 .4152 .6981 .42878 .69425 .42079 .68707 Mtetra
.658 .75 .918 r
.42079 .68707 .42878 .69425 .44242 .69035 .43448 .68313 Mtetra
.654 .749 .92 r
.43448 .68313 .44242 .69035 .45614 .68642 .44824 .67928 Mtetra
.653 .752 .922 r
.44824 .67928 .45614 .68642 .46992 .68256 .46207 .67543 Mtetra
.655 .754 .923 r
.46207 .67543 .46992 .68256 .48378 .67873 .47597 .67152 Mtetra
.656 .753 .921 r
.47597 .67152 .48378 .67873 .4977 .67485 .48994 .66755 Mtetra
.658 .752 .919 r
.48994 .66755 .4977 .67485 .5117 .67091 .50398 .6635 Mtetra
.659 .75 .918 r
.50398 .6635 .5117 .67091 .52577 .66693 .5181 .6594 Mtetra
.658 .748 .917 r
.5181 .6594 .52577 .66693 .53991 .66287 .53229 .65532 Mtetra
.654 .748 .918 r
.53229 .65532 .53991 .66287 .55412 .65878 .54655 .65134 Mtetra
.653 .751 .921 r
.54655 .65134 .55412 .65878 .56841 .65471 .56088 .64736 Mtetra
.653 .755 .924 r
.56088 .64736 .56841 .65471 .58277 .65068 .5753 .64335 Mtetra
.654 .756 .925 r
.5753 .64335 .58277 .65068 .59721 .64667 .58978 .63927 Mtetra
.655 .756 .924 r
.58978 .63927 .59721 .64667 .61172 .64263 .60434 .63515 Mtetra
.655 .755 .923 r
.60434 .63515 .61172 .64263 .62631 .63856 .61898 .631 Mtetra
.655 .753 .922 r
.61898 .631 .62631 .63856 .64097 .63447 .6337 .62683 Mtetra
.655 .753 .921 r
.6337 .62683 .64097 .63447 .65571 .63033 .64849 .62264 Mtetra
.656 .752 .921 r
.64849 .62264 .65571 .63033 .67053 .62616 .66336 .61842 Mtetra
.66336 .61842 .67053 .62616 .68543 .62197 .67831 .61418 Mtetra
.67831 .61418 .68543 .62197 .7004 .61773 .69334 .60992 Mtetra
.69334 .60992 .7004 .61773 .71545 .61347 .70845 .60562 Mtetra
.656 .753 .921 r
.70845 .60562 .71545 .61347 .73059 .60917 .72364 .60131 Mtetra
.656 .754 .922 r
.72364 .60131 .73059 .60917 .7458 .60483 .73891 .59697 Mtetra
.656 .755 .923 r
.73891 .59697 .7458 .60483 .76109 .60046 .75427 .59262 Mtetra
.656 .756 .924 r
.75427 .59262 .76109 .60046 .77646 .59607 .7697 .58821 Mtetra
.657 .757 .924 r
.7697 .58821 .77646 .59607 .79192 .59168 .78522 .58372 Mtetra
.658 .756 .922 r
.78522 .58372 .79192 .59168 .80747 .58735 .80081 .57921 Mtetra
.658 .752 .92 r
.80081 .57921 .80747 .58735 .8231 .58302 .8165 .57469 Mtetra
.655 .748 .918 r
.8165 .57469 .8231 .58302 .83882 .57867 .83227 .57027 Mtetra
.654 .747 .918 r
.83227 .57027 .83882 .57867 .85462 .57424 .84814 .56587 Mtetra
.654 .749 .919 r
.84814 .56587 .85462 .57424 .87051 .56975 .8641 .56142 Mtetra
.656 .751 .92 r
.8641 .56142 .87051 .56975 .88647 .5652 .88013 .55688 Mtetra
.656 .753 .921 r
.88013 .55688 .88647 .5652 .90252 .56059 .89625 .55227 Mtetra
.658 .755 .922 r
.89625 .55227 .90252 .56059 .91867 .55601 .91246 .54759 Mtetra
.657 .753 .921 r
.91246 .54759 .91867 .55601 .93491 .5515 .92875 .54291 Mtetra
.654 .749 .919 r
.92875 .54291 .93491 .5515 .95124 .54695 .94515 .53832 Mtetra
.94515 .53832 .95124 .54695 .96766 .54234 .96164 .53371 Mtetra
.655 .751 .92 r
.96164 .53371 .96766 .54234 .98417 .53766 .97822 .52903 Mtetra
.658 .752 .919 r
.38547 .68773 .39362 .69486 .40717 .691 .39906 .68378 Mtetra
.658 .75 .918 r
.39906 .68378 .40717 .691 .42079 .68707 .41273 .67983 Mtetra
.654 .749 .92 r
.41273 .67983 .42079 .68707 .43448 .68313 .42646 .67597 Mtetra
.653 .752 .923 r
.42646 .67597 .43448 .68313 .44824 .67928 .44026 .67211 Mtetra
.655 .754 .922 r
.44026 .67211 .44824 .67928 .46207 .67543 .45414 .66817 Mtetra
.656 .752 .921 r
.45414 .66817 .46207 .67543 .47597 .67152 .46808 .66417 Mtetra
.659 .752 .919 r
.46808 .66417 .47597 .67152 .48994 .66755 .4821 .66006 Mtetra
.658 .749 .917 r
.4821 .66006 .48994 .66755 .50398 .6635 .49619 .65595 Mtetra
.655 .748 .918 r
.49619 .65595 .50398 .6635 .5181 .6594 .51035 .65196 Mtetra
.653 .751 .921 r
.51035 .65196 .5181 .6594 .53229 .65532 .52459 .648 Mtetra
.653 .755 .925 r
.52459 .648 .53229 .65532 .54655 .65134 .5389 .64401 Mtetra
.655 .756 .924 r
.5389 .64401 .54655 .65134 .56088 .64736 .55329 .63991 Mtetra
.655 .754 .923 r
.55329 .63991 .56088 .64736 .5753 .64335 .56775 .63579 Mtetra
.655 .752 .921 r
.56775 .63579 .5753 .64335 .58978 .63927 .58228 .63166 Mtetra
.656 .752 .921 r
.58228 .63166 .58978 .63927 .60434 .63515 .5969 .62748 Mtetra
.657 .752 .92 r
.5969 .62748 .60434 .63515 .61898 .631 .61159 .62326 Mtetra
.656 .751 .92 r
.61159 .62326 .61898 .631 .6337 .62683 .62635 .61905 Mtetra
.655 .751 .92 r
.62635 .61905 .6337 .62683 .64849 .62264 .6412 .61483 Mtetra
.6412 .61483 .64849 .62264 .66336 .61842 .65613 .61059 Mtetra
.656 .752 .921 r
.65613 .61059 .66336 .61842 .67831 .61418 .67113 .60631 Mtetra
.656 .752 .92 r
.67113 .60631 .67831 .61418 .69334 .60992 .68621 .60199 Mtetra
.68621 .60199 .69334 .60992 .70845 .60562 .70138 .59764 Mtetra
.656 .751 .92 r
.70138 .59764 .70845 .60562 .72364 .60131 .71663 .59328 Mtetra
.655 .751 .92 r
.71663 .59328 .72364 .60131 .73891 .59697 .73196 .58893 Mtetra
.655 .752 .921 r
.73196 .58893 .73891 .59697 .75427 .59262 .74737 .58455 Mtetra
.656 .752 .921 r
.74737 .58455 .75427 .59262 .7697 .58821 .76286 .5801 Mtetra
.656 .753 .921 r
.76286 .5801 .7697 .58821 .78522 .58372 .77844 .57565 Mtetra
.656 .754 .922 r
.77844 .57565 .78522 .58372 .80081 .57921 .79411 .57117 Mtetra
.658 .757 .923 r
.79411 .57117 .80081 .57921 .8165 .57469 .80985 .56658 Mtetra
.80985 .56658 .8165 .57469 .83227 .57027 .82567 .56195 Mtetra
.657 .752 .92 r
.82567 .56195 .83227 .57027 .84814 .56587 .84159 .55736 Mtetra
.654 .747 .918 r
.84159 .55736 .84814 .56587 .8641 .56142 .85761 .55287 Mtetra
.653 .747 .919 r
.85761 .55287 .8641 .56142 .88013 .55688 .87372 .54839 Mtetra
.655 .751 .92 r
.87372 .54839 .88013 .55688 .89625 .55227 .88991 .54379 Mtetra
.656 .752 .921 r
.88991 .54379 .89625 .55227 .91246 .54759 .90618 .53913 Mtetra
.658 .755 .922 r
.90618 .53913 .91246 .54759 .92875 .54291 .92254 .53437 Mtetra
.657 .754 .921 r
.92254 .53437 .92875 .54291 .94515 .53832 .93899 .5296 Mtetra
.654 .749 .919 r
.93899 .5296 .94515 .53832 .96164 .53371 .95555 .52494 Mtetra
.95555 .52494 .96164 .53371 .97822 .52903 .97221 .52026 Mtetra
.658 .75 .918 r
.37724 .68049 .38547 .68773 .39906 .68378 .39088 .67651 Mtetra
.654 .749 .92 r
.39088 .67651 .39906 .68378 .41273 .67983 .40459 .67264 Mtetra
.653 .752 .923 r
.40459 .67264 .41273 .67983 .42646 .67597 .41836 .66877 Mtetra
.655 .754 .922 r
.41836 .66877 .42646 .67597 .44026 .67211 .43221 .6648 Mtetra
.657 .752 .92 r
.43221 .6648 .44026 .67211 .45414 .66817 .44613 .66076 Mtetra
.659 .751 .918 r
.44613 .66076 .45414 .66817 .46808 .66417 .46013 .65662 Mtetra
.658 .748 .917 r
.46013 .65662 .46808 .66417 .4821 .66006 .47419 .65253 Mtetra
.653 .748 .92 r
.47419 .65253 .4821 .66006 .49619 .65595 .48832 .64858 Mtetra
.652 .753 .924 r
.48832 .64858 .49619 .65595 .51035 .65196 .50253 .64462 Mtetra
.655 .756 .924 r
.50253 .64462 .51035 .65196 .52459 .648 .51682 .64054 Mtetra
.655 .754 .922 r
.51682 .64054 .52459 .648 .5389 .64401 .53118 .63643 Mtetra
.655 .752 .921 r
.53118 .63643 .5389 .64401 .55329 .63991 .54561 .6323 Mtetra
.657 .752 .92 r
.54561 .6323 .55329 .63991 .56775 .63579 .56012 .6281 Mtetra
.653 .75 .921 r
.56012 .6281 .56775 .63579 .58228 .63166 .57471 .624 Mtetra
.65 .751 .924 r
.57471 .624 .58228 .63166 .5969 .62748 .58938 .62 Mtetra
.646 .756 .929 r
.58938 .62 .5969 .62748 .61159 .62326 .60413 .6161 Mtetra
.64 .764 .938 r
.60413 .6161 .61159 .62326 .62635 .61905 .61897 .61229 Mtetra
.641 .777 .946 r
.61897 .61229 .62635 .61905 .6412 .61483 .63388 .60836 Mtetra
.644 .787 .95 r
.63388 .60836 .6412 .61483 .65613 .61059 .64887 .60424 Mtetra
.648 .793 .952 r
.64887 .60424 .65613 .61059 .67113 .60631 .66394 .59992 Mtetra
.654 .795 .95 r
.66394 .59992 .67113 .60631 .68621 .60199 .67908 .59539 Mtetra
.66 .792 .945 r
.67908 .59539 .68621 .60199 .70138 .59764 .69429 .59067 Mtetra
.665 .784 .937 r
.69429 .59067 .70138 .59764 .71663 .59328 .70957 .58583 Mtetra
.663 .771 .93 r
.70957 .58583 .71663 .59328 .73196 .58893 .72494 .58108 Mtetra
.661 .761 .924 r
.72494 .58108 .73196 .58893 .74737 .58455 .7404 .57641 Mtetra
.658 .754 .92 r
.7404 .57641 .74737 .58455 .76286 .5801 .75595 .57186 Mtetra
.655 .751 .92 r
.75595 .57186 .76286 .5801 .77844 .57565 .77159 .56741 Mtetra
.656 .752 .921 r
.77159 .56741 .77844 .57565 .79411 .57117 .78732 .56287 Mtetra
.78732 .56287 .79411 .57117 .80985 .56658 .80313 .55832 Mtetra
.656 .754 .922 r
.80313 .55832 .80985 .56658 .82567 .56195 .81902 .55373 Mtetra
.659 .757 .923 r
.81902 .55373 .82567 .56195 .84159 .55736 .835 .54901 Mtetra
.658 .755 .922 r
.835 .54901 .84159 .55736 .85761 .55287 .85106 .54428 Mtetra
.655 .749 .919 r
.85106 .54428 .85761 .55287 .87372 .54839 .86723 .53969 Mtetra
.653 .747 .918 r
.86723 .53969 .87372 .54839 .88991 .54379 .88349 .53515 Mtetra
.655 .75 .92 r
.88349 .53515 .88991 .54379 .90618 .53913 .89984 .5305 Mtetra
.656 .752 .921 r
.89984 .5305 .90618 .53913 .92254 .53437 .91627 .52577 Mtetra
.658 .755 .921 r
.91627 .52577 .92254 .53437 .93899 .5296 .93279 .52093 Mtetra
.657 .754 .921 r
.93279 .52093 .93899 .5296 .95555 .52494 .9494 .51609 Mtetra
.654 .749 .92 r
.9494 .51609 .95555 .52494 .97221 .52026 .96612 .51136 Mtetra
.655 .75 .92 r
.36894 .67319 .37724 .68049 .39088 .67651 .38262 .66928 Mtetra
.653 .752 .922 r
.38262 .66928 .39088 .67651 .40459 .67264 .39637 .6654 Mtetra
.655 .753 .922 r
.39637 .6654 .40459 .67264 .41836 .66877 .41019 .66142 Mtetra
.657 .752 .92 r
.41019 .66142 .41836 .66877 .43221 .6648 .42409 .65735 Mtetra
.659 .751 .918 r
.42409 .65735 .43221 .6648 .44613 .66076 .43805 .65319 Mtetra
.656 .748 .917 r
.43805 .65319 .44613 .66076 .46013 .65662 .45209 .64912 Mtetra
.652 .75 .921 r
.45209 .64912 .46013 .65662 .47419 .65253 .4662 .64517 Mtetra
.653 .755 .924 r
.4662 .64517 .47419 .65253 .48832 .64858 .48038 .64117 Mtetra
.655 .755 .923 r
.48038 .64117 .48832 .64858 .50253 .64462 .49464 .63706 Mtetra
.655 .752 .921 r
.49464 .63706 .50253 .64462 .51682 .64054 .50897 .63295 Mtetra
.657 .753 .921 r
.50897 .63295 .51682 .64054 .53118 .63643 .52338 .62874 Mtetra
.65 .749 .922 r
.52338 .62874 .53118 .63643 .54561 .6323 .53787 .62475 Mtetra
.639 .751 .93 r
.53787 .62475 .54561 .6323 .56012 .6281 .55243 .62112 Mtetra
.62 .762 .947 r
.55243 .62112 .56012 .6281 .57471 .624 .56709 .61791 Mtetra
.609 .786 .966 r
.56709 .61791 .57471 .624 .58938 .62 .58183 .61473 Mtetra
.6 .809 .98 r
.58183 .61473 .58938 .62 .60413 .6161 .59666 .61144 Mtetra
.595 .828 .988 r
.59666 .61144 .60413 .6161 .61897 .61229 .61157 .60794 Mtetra
.597 .84 .991 r
.61157 .60794 .61897 .61229 .63388 .60836 .62656 .60421 Mtetra
.602 .849 .991 r
.62656 .60421 .63388 .60836 .64887 .60424 .64163 .60023 Mtetra
.614 .858 .99 r
.64163 .60023 .64887 .60424 .66394 .59992 .65676 .59587 Mtetra
.629 .863 .986 r
.65676 .59587 .66394 .59992 .67908 .59539 .67197 .59113 Mtetra
.642 .862 .982 r
.67197 .59113 .67908 .59539 .69429 .59067 .68724 .58614 Mtetra
.654 .858 .977 r
.68724 .58614 .69429 .59067 .70957 .58583 .70259 .5809 Mtetra
.666 .85 .97 r
.70259 .5809 .70957 .58583 .72494 .58108 .71799 .57545 Mtetra
.675 .832 .959 r
.71799 .57545 .72494 .58108 .7404 .57641 .73347 .56989 Mtetra
.679 .807 .944 r
.73347 .56989 .7404 .57641 .75595 .57186 .74902 .56433 Mtetra
.669 .777 .93 r
.74902 .56433 .75595 .57186 .77159 .56741 .76468 .55921 Mtetra
.661 .757 .922 r
.76468 .55921 .77159 .56741 .78732 .56287 .78045 .55445 Mtetra
.655 .75 .92 r
.78045 .55445 .78732 .56287 .80313 .55832 .79633 .54991 Mtetra
.657 .753 .921 r
.79633 .54991 .80313 .55832 .81902 .55373 .81229 .54526 Mtetra
.656 .752 .921 r
.81229 .54526 .81902 .55373 .835 .54901 .82833 .54062 Mtetra
.658 .756 .922 r
.82833 .54062 .835 .54901 .85106 .54428 .84446 .53585 Mtetra
.659 .757 .922 r
.84446 .53585 .85106 .54428 .86723 .53969 .86068 .53103 Mtetra
.655 .75 .92 r
.86068 .53103 .86723 .53969 .88349 .53515 .877 .52632 Mtetra
.653 .747 .919 r
.877 .52632 .88349 .53515 .89984 .5305 .89342 .52171 Mtetra
.654 .749 .92 r
.89342 .52171 .89984 .5305 .91627 .52577 .90993 .517 Mtetra
.656 .752 .92 r
.90993 .517 .91627 .52577 .93279 .52093 .92652 .51218 Mtetra
.658 .755 .921 r
.92652 .51218 .93279 .52093 .9494 .51609 .9432 .50726 Mtetra
.657 .753 .921 r
.9432 .50726 .9494 .51609 .96612 .51136 .95998 .50236 Mtetra
.653 .751 .922 r
.36056 .6659 .36894 .67319 .38262 .66928 .37428 .66201 Mtetra
.655 .753 .922 r
.37428 .66201 .38262 .66928 .39637 .6654 .38807 .65803 Mtetra
.657 .752 .92 r
.38807 .65803 .39637 .6654 .41019 .66142 .40194 .65395 Mtetra
.66 .751 .918 r
.40194 .65395 .41019 .66142 .42409 .65735 .41588 .64976 Mtetra
.656 .748 .918 r
.41588 .64976 .42409 .65735 .43805 .65319 .42989 .64568 Mtetra
.652 .75 .922 r
.42989 .64568 .43805 .65319 .45209 .64912 .44397 .64173 Mtetra
.653 .755 .924 r
.44397 .64173 .45209 .64912 .4662 .64517 .45813 .63769 Mtetra
.655 .754 .922 r
.45813 .63769 .4662 .64517 .48038 .64117 .47236 .63357 Mtetra
.656 .752 .92 r
.47236 .63357 .48038 .64117 .49464 .63706 .48667 .62938 Mtetra
.652 .75 .921 r
.48667 .62938 .49464 .63706 .50897 .63295 .50105 .62532 Mtetra
.636 .748 .929 r
.50105 .62532 .50897 .63295 .52338 .62874 .51551 .62177 Mtetra
.606 .757 .951 r
.51551 .62177 .52338 .62874 .53787 .62475 .53005 .61897 Mtetra
.581 .786 .977 r
.53005 .61897 .53787 .62475 .55243 .62112 .54468 .61636 Mtetra
.553 .81 .993 r
.54468 .61636 .55243 .62112 .56709 .61791 .5594 .61382 Mtetra
.529 .823 .999 r
.5594 .61382 .56709 .61791 .58183 .61473 .57422 .6113 Mtetra
.525 .843 .999 r
.57422 .6113 .58183 .61473 .59666 .61144 .58912 .60837 Mtetra
.534 .858 .996 r
.58912 .60837 .59666 .61144 .61157 .60794 .60411 .605 Mtetra
.55 .868 .995 r
.60411 .605 .61157 .60794 .62656 .60421 .61918 .60123 Mtetra
.568 .875 .994 r
.61918 .60123 .62656 .60421 .64163 .60023 .63432 .59712 Mtetra
.585 .878 .993 r
.63432 .59712 .64163 .60023 .65676 .59587 .64954 .59273 Mtetra
.599 .883 .992 r
.64954 .59273 .65676 .59587 .67197 .59113 .66482 .58804 Mtetra
.611 .89 .989 r
.66482 .58804 .67197 .59113 .68724 .58614 .68018 .58301 Mtetra
.629 .895 .986 r
.68018 .58301 .68724 .58614 .70259 .5809 .6956 .57758 Mtetra
.652 .897 .982 r
.6956 .57758 .70259 .5809 .71799 .57545 .71106 .57169 Mtetra
.675 .892 .976 r
.71106 .57169 .71799 .57545 .73347 .56989 .72658 .56537 Mtetra
.685 .873 .969 r
.72658 .56537 .73347 .56989 .74902 .56433 .74217 .55907 Mtetra
.689 .852 .961 r
.74217 .55907 .74902 .56433 .76468 .55921 .75783 .55282 Mtetra
.689 .819 .945 r
.75783 .55282 .76468 .55921 .78045 .55445 .77358 .54675 Mtetra
.671 .778 .93 r
.77358 .54675 .78045 .55445 .79633 .54991 .78947 .54145 Mtetra
.659 .754 .921 r
.78947 .54145 .79633 .54991 .81229 .54526 .80548 .53667 Mtetra
.655 .751 .92 r
.80548 .53667 .81229 .54526 .82833 .54062 .82159 .53201 Mtetra
.656 .752 .921 r
.82159 .53201 .82833 .54062 .84446 .53585 .8378 .52728 Mtetra
.658 .755 .922 r
.8378 .52728 .84446 .53585 .86068 .53103 .85408 .52246 Mtetra
.659 .757 .922 r
.85408 .52246 .86068 .53103 .877 .52632 .87045 .51754 Mtetra
.656 .751 .92 r
.87045 .51754 .877 .52632 .89342 .52171 .88693 .51276 Mtetra
.653 .747 .919 r
.88693 .51276 .89342 .52171 .90993 .517 .90351 .50807 Mtetra
.655 .75 .92 r
.90351 .50807 .90993 .517 .92652 .51218 .92018 .50328 Mtetra
.657 .752 .92 r
.92018 .50328 .92652 .51218 .9432 .50726 .93694 .49837 Mtetra
.658 .755 .921 r
.93694 .49837 .9432 .50726 .95998 .50236 .95378 .49336 Mtetra
.654 .753 .922 r
.3521 .65859 .36056 .6659 .37428 .66201 .36586 .65462 Mtetra
.656 .752 .921 r
.36586 .65462 .37428 .66201 .38807 .65803 .3797 .65054 Mtetra
.66 .752 .918 r
.3797 .65054 .38807 .65803 .40194 .65395 .39362 .64633 Mtetra
.657 .749 .918 r
.39362 .64633 .40194 .65395 .41588 .64976 .4076 .64221 Mtetra
.651 .75 .922 r
.4076 .64221 .41588 .64976 .42989 .64568 .42165 .63825 Mtetra
.653 .755 .924 r
.42165 .63825 .42989 .64568 .44397 .64173 .43578 .63419 Mtetra
.655 .753 .922 r
.43578 .63419 .44397 .64173 .45813 .63769 .44999 .63006 Mtetra
.657 .752 .92 r
.44999 .63006 .45813 .63769 .47236 .63357 .46427 .62584 Mtetra
.647 .748 .923 r
.46427 .62584 .47236 .63357 .48667 .62938 .47862 .62195 Mtetra
.614 .747 .94 r
.47862 .62195 .48667 .62938 .50105 .62532 .49304 .61903 Mtetra
.574 .768 .97 r
.49304 .61903 .50105 .62532 .51551 .62177 .50754 .61676 Mtetra
.528 .792 .994 r
.50754 .61676 .51551 .62177 .53005 .61897 .52214 .61483 Mtetra
.489 .805 1 r
.52214 .61483 .53005 .61897 .54468 .61636 .53684 .613 Mtetra
.492 .831 .998 r
.53684 .613 .54468 .61636 .5594 .61382 .55163 .61057 Mtetra
.537 .853 .998 r
.55163 .61057 .5594 .61382 .57422 .6113 .5665 .6073 Mtetra
.607 .855 .991 r
.5665 .6073 .57422 .6113 .58912 .60837 .58146 .60312 Mtetra
.641 .828 .972 r
.58146 .60312 .58912 .60837 .60411 .605 .59649 .59862 Mtetra
.654 .798 .952 r
.59649 .59862 .60411 .605 .61918 .60123 .61159 .594 Mtetra
.656 .776 .937 r
.61159 .594 .61918 .60123 .63432 .59712 .62678 .58943 Mtetra
.654 .764 .93 r
.62678 .58943 .63432 .59712 .64954 .59273 .64206 .58499 Mtetra
.649 .762 .932 r
.64206 .58499 .64954 .59273 .66482 .58804 .65742 .58068 Mtetra
.645 .772 .941 r
.65742 .58068 .66482 .58804 .68018 .58301 .67287 .57642 Mtetra
.643 .795 .955 r
.67287 .57642 .68018 .58301 .6956 .57758 .68841 .57205 Mtetra
.642 .828 .972 r
.68841 .57205 .6956 .57758 .71106 .57169 .70402 .56734 Mtetra
.658 .871 .979 r
.70402 .56734 .71106 .57169 .72658 .56537 .71966 .5617 Mtetra
.676 .898 .976 r
.71966 .5617 .72658 .56537 .74217 .55907 .73532 .55521 Mtetra
.699 .899 .968 r
.73532 .55521 .74217 .55907 .75783 .55282 .75102 .54809 Mtetra
.705 .876 .961 r
.75102 .54809 .75783 .55282 .77358 .54675 .76678 .54106 Mtetra
.701 .847 .953 r
.76678 .54106 .77358 .54675 .78947 .54145 .78264 .53435 Mtetra
.687 .803 .937 r
.78264 .53435 .78947 .54145 .80548 .53667 .79863 .52831 Mtetra
.663 .762 .924 r
.79863 .52831 .80548 .53667 .82159 .53201 .81478 .52326 Mtetra
.655 .75 .92 r
.81478 .52326 .82159 .53201 .8378 .52728 .83105 .51854 Mtetra
.656 .752 .921 r
.83105 .51854 .8378 .52728 .85408 .52246 .84741 .51372 Mtetra
.658 .754 .921 r
.84741 .51372 .85408 .52246 .87045 .51754 .86385 .50883 Mtetra
.66 .757 .922 r
.86385 .50883 .87045 .51754 .88693 .51276 .88038 .50382 Mtetra
.655 .751 .92 r
.88038 .50382 .88693 .51276 .90351 .50807 .89702 .49898 Mtetra
.652 .747 .919 r
.89702 .49898 .90351 .50807 .92018 .50328 .91377 .49423 Mtetra
.655 .751 .92 r
.91377 .49423 .92018 .50328 .93694 .49837 .9306 .48933 Mtetra
.657 .753 .92 r
.9306 .48933 .93694 .49837 .95378 .49336 .94752 .48432 Mtetra
.656 .753 .921 r
.34355 .65118 .3521 .65859 .36586 .65462 .35736 .64711 Mtetra
.659 .752 .919 r
.35736 .64711 .36586 .65462 .3797 .65054 .37125 .6429 Mtetra
.658 .749 .917 r
.37125 .6429 .3797 .65054 .39362 .64633 .38521 .63871 Mtetra
.651 .749 .921 r
.38521 .63871 .39362 .64633 .4076 .64221 .39923 .63473 Mtetra
.653 .754 .924 r
.39923 .63473 .4076 .64221 .42165 .63825 .41333 .63067 Mtetra
.655 .753 .922 r
.41333 .63067 .42165 .63825 .43578 .63419 .42751 .62652 Mtetra
.657 .752 .92 r
.42751 .62652 .43578 .63419 .44999 .63006 .44176 .6223 Mtetra
.643 .747 .925 r
.44176 .6223 .44999 .63006 .46427 .62584 .45608 .61851 Mtetra
.596 .745 .948 r
.45608 .61851 .46427 .62584 .47862 .62195 .47046 .61603 Mtetra
.545 .77 .981 r
.47046 .61603 .47862 .62195 .49304 .61903 .48492 .61421 Mtetra
.479 .78 .997 r
.48492 .61421 .49304 .61903 .50754 .61676 .49947 .61297 Mtetra
.466 .807 .999 r
.49947 .61297 .50754 .61676 .52214 .61483 .51413 .61123 Mtetra
.544 .845 .999 r
.51413 .61123 .52214 .61483 .53684 .613 .52889 .6081 Mtetra
.64 .836 .976 r
.52889 .6081 .53684 .613 .55163 .61057 .54373 .60356 Mtetra
.678 .785 .931 r
.54373 .60356 .55163 .61057 .5665 .6073 .55865 .59829 Mtetra
.686 .739 .891 r
.55865 .59829 .5665 .6073 .58146 .60312 .57363 .59263 Mtetra
.689 .71 .864 r
.57363 .59263 .58146 .60312 .59649 .59862 .58867 .58659 Mtetra
.676 .679 .845 r
.58867 .58659 .59649 .59862 .61159 .594 .60379 .58094 Mtetra
.663 .658 .835 r
.60379 .58094 .61159 .594 .62678 .58943 .619 .57583 Mtetra
.651 .646 .832 r
.619 .57583 .62678 .58943 .64206 .58499 .63431 .57134 Mtetra
.639 .641 .836 r
.63431 .57134 .64206 .58499 .65742 .58068 .64972 .56746 Mtetra
.628 .643 .846 r
.64972 .56746 .65742 .58068 .67287 .57642 .66525 .56414 Mtetra
.62 .655 .863 r
.66525 .56414 .67287 .57642 .68841 .57205 .6809 .56121 Mtetra
.626 .686 .886 r
.6809 .56121 .68841 .57205 .70402 .56734 .69663 .55791 Mtetra
.633 .721 .91 r
.69663 .55791 .70402 .56734 .71966 .5617 .71244 .55421 Mtetra
.646 .776 .943 r
.71244 .55421 .71966 .5617 .73532 .55521 .7283 .54978 Mtetra
.674 .847 .966 r
.7283 .54978 .73532 .55521 .75102 .54809 .74416 .54391 Mtetra
.705 .894 .965 r
.74416 .54391 .75102 .54809 .76678 .54106 .76 .5366 Mtetra
.723 .892 .957 r
.76 .5366 .76678 .54106 .78264 .53435 .77586 .52876 Mtetra
.713 .857 .951 r
.77586 .52876 .78264 .53435 .79863 .52831 .79184 .5215 Mtetra
.698 .819 .939 r
.79184 .5215 .79863 .52831 .81478 .52326 .80794 .5149 Mtetra
.666 .767 .925 r
.80794 .5149 .81478 .52326 .83105 .51854 .82423 .50964 Mtetra
.655 .75 .92 r
.82423 .50964 .83105 .51854 .84741 .51372 .84066 .50484 Mtetra
.656 .752 .921 r
.84066 .50484 .84741 .51372 .86385 .50883 .85717 .49994 Mtetra
.658 .754 .921 r
.85717 .49994 .86385 .50883 .88038 .50382 .87378 .49495 Mtetra
.66 .756 .922 r
.87378 .49495 .88038 .50382 .89702 .49898 .89047 .48987 Mtetra
.654 .749 .92 r
.89047 .48987 .89702 .49898 .91377 .49423 .90728 .485 Mtetra
.653 .747 .919 r
.90728 .485 .91377 .49423 .9306 .48933 .92419 .48015 Mtetra
.656 .751 .92 r
.92419 .48015 .9306 .48933 .94752 .48432 .94119 .47515 Mtetra
.658 .752 .919 r
.33492 .64366 .34355 .65118 .35736 .64711 .34878 .63948 Mtetra
.66 .751 .917 r
.34878 .63948 .35736 .64711 .37125 .6429 .36272 .63521 Mtetra
.653 .748 .92 r
.36272 .63521 .37125 .6429 .38521 .63871 .37672 .63117 Mtetra
.651 .753 .924 r
.37672 .63117 .38521 .63871 .39923 .63473 .39078 .62714 Mtetra
.655 .754 .922 r
.39078 .62714 .39923 .63473 .41333 .63067 .40493 .62296 Mtetra
.657 .752 .92 r
.40493 .62296 .41333 .63067 .42751 .62652 .41916 .61872 Mtetra
.643 .747 .925 r
.41916 .61872 .42751 .62652 .44176 .6223 .43345 .61492 Mtetra
.588 .742 .95 r
.43345 .61492 .44176 .6223 .45608 .61851 .44778 .61264 Mtetra
.524 .765 .985 r
.44778 .61264 .45608 .61851 .47046 .61603 .46219 .61117 Mtetra
.45 .767 .997 r
.46219 .61117 .47046 .61603 .48492 .61421 .47669 .61036 Mtetra
.473 .809 .999 r
.47669 .61036 .48492 .61421 .49947 .61297 .49131 .60853 Mtetra
.62 .844 .985 r
.49131 .60853 .49947 .61297 .51413 .61123 .50605 .60433 Mtetra
.687 .789 .928 r
.50605 .60433 .51413 .61123 .52889 .6081 .52086 .5987 Mtetra
.712 .737 .871 r
.52086 .5987 .52889 .6081 .54373 .60356 .53574 .59168 Mtetra
.709 .692 .832 r
.53574 .59168 .54373 .60356 .55865 .59829 .55068 .5841 Mtetra
.692 .654 .807 r
.55068 .5841 .55865 .59829 .57363 .59263 .56567 .57688 Mtetra
.677 .629 .795 r
.56567 .57688 .57363 .59263 .58867 .58659 .58073 .57031 Mtetra
.663 .618 .794 r
.58073 .57031 .58867 .58659 .60379 .58094 .59587 .56455 Mtetra
.653 .613 .796 r
.59587 .56455 .60379 .58094 .619 .57583 .6111 .55946 Mtetra
.645 .609 .799 r
.6111 .55946 .619 .57583 .63431 .57134 .62643 .55491 Mtetra
.636 .605 .802 r
.62643 .55491 .63431 .57134 .64972 .56746 .64186 .55091 Mtetra
.624 .598 .804 r
.64186 .55091 .64972 .56746 .66525 .56414 .65741 .54757 Mtetra
.61 .592 .808 r
.65741 .54757 .66525 .56414 .6809 .56121 .67309 .54507 Mtetra
.598 .591 .816 r
.67309 .54507 .6809 .56121 .69663 .55791 .68892 .54323 Mtetra
.589 .607 .838 r
.68892 .54323 .69663 .55791 .71244 .55421 .70488 .54178 Mtetra
.597 .646 .87 r
.70488 .54178 .71244 .55421 .7283 .54978 .72092 .53976 Mtetra
.625 .708 .905 r
.72092 .53976 .7283 .54978 .74416 .54391 .737 .53634 Mtetra
.655 .782 .941 r
.737 .53634 .74416 .54391 .76 .5366 .75308 .53147 Mtetra
.711 .87 .957 r
.75308 .53147 .76 .5366 .77586 .52876 .76908 .52416 Mtetra
.736 .893 .951 r
.76908 .52416 .77586 .52876 .79184 .5215 .78506 .51577 Mtetra
.723 .859 .946 r
.78506 .51577 .79184 .5215 .80794 .5149 .80115 .50805 Mtetra
.704 .823 .938 r
.80115 .50805 .80794 .5149 .82423 .50964 .81738 .50114 Mtetra
.666 .767 .925 r
.81738 .50114 .82423 .50964 .84066 .50484 .83383 .4958 Mtetra
.655 .75 .92 r
.83383 .4958 .84066 .50484 .85717 .49994 .85042 .49091 Mtetra
.656 .752 .92 r
.85042 .49091 .85717 .49994 .87378 .49495 .8671 .48594 Mtetra
.659 .755 .921 r
.8671 .48594 .87378 .49495 .89047 .48987 .88386 .48082 Mtetra
.658 .755 .922 r
.88386 .48082 .89047 .48987 .90728 .485 .90072 .4757 Mtetra
.652 .748 .92 r
.90072 .4757 .90728 .485 .92419 .48015 .91771 .47081 Mtetra
.654 .749 .919 r
.91771 .47081 .92419 .48015 .94119 .47515 .93479 .46584 Mtetra
.66 .752 .918 r
.32622 .63604 .33492 .64366 .34878 .63948 .34013 .63174 Mtetra
.656 .749 .919 r
.34013 .63174 .34878 .63948 .36272 .63521 .3541 .62758 Mtetra
.65 .751 .923 r
.3541 .62758 .36272 .63521 .37672 .63117 .36814 .62357 Mtetra
.655 .754 .923 r
.36814 .62357 .37672 .63117 .39078 .62714 .38226 .61939 Mtetra
.656 .752 .92 r
.38226 .61939 .39078 .62714 .40493 .62296 .39645 .61514 Mtetra
.647 .748 .923 r
.39645 .61514 .40493 .62296 .41916 .61872 .41071 .61119 Mtetra
.592 .74 .947 r
.41071 .61119 .41916 .61872 .43345 .61492 .42501 .60881 Mtetra
.518 .756 .983 r
.42501 .60881 .43345 .61492 .44778 .61264 .43937 .60753 Mtetra
.437 .755 .995 r
.43937 .60753 .44778 .61264 .46219 .61117 .45381 .60704 Mtetra
.494 .81 1 r
.45381 .60704 .46219 .61117 .47669 .61036 .46839 .60504 Mtetra
.654 .826 .966 r
.46839 .60504 .47669 .61036 .49131 .60853 .4831 .60026 Mtetra
.712 .761 .891 r
.4831 .60026 .49131 .60853 .50605 .60433 .4979 .59347 Mtetra
.731 .715 .836 r
.4979 .59347 .50605 .60433 .52086 .5987 .51277 .58478 Mtetra
.712 .665 .802 r
.51277 .58478 .52086 .5987 .53574 .59168 .52769 .57616 Mtetra
.691 .638 .792 r
.52769 .57616 .53574 .59168 .55068 .5841 .54265 .56862 Mtetra
.677 .633 .798 r
.54265 .56862 .55068 .5841 .56567 .57688 .55768 .56209 Mtetra
.668 .638 .81 r
.55768 .56209 .56567 .57688 .58073 .57031 .57278 .55631 Mtetra
.662 .646 .824 r
.57278 .55631 .58073 .57031 .59587 .56455 .58796 .55107 Mtetra
.656 .652 .834 r
.58796 .55107 .59587 .56455 .6111 .55946 .60324 .54621 Mtetra
.652 .654 .839 r
.60324 .54621 .6111 .55946 .62643 .55491 .6186 .54161 Mtetra
.647 .652 .841 r
.6186 .54161 .62643 .55491 .64186 .55091 .63405 .53727 Mtetra
.639 .644 .839 r
.63405 .53727 .64186 .55091 .65741 .54757 .64961 .5333 Mtetra
.627 .63 .834 r
.64961 .5333 .65741 .54757 .67309 .54507 .66528 .52989 Mtetra
.612 .612 .826 r
.66528 .52989 .67309 .54507 .68892 .54323 .6811 .52724 Mtetra
.592 .592 .821 r
.6811 .52724 .68892 .54323 .70488 .54178 .69707 .52563 Mtetra
.57 .58 .823 r
.69707 .52563 .70488 .54178 .72092 .53976 .71322 .52514 Mtetra
.564 .598 .845 r
.71322 .52514 .72092 .53976 .737 .53634 .72952 .52473 Mtetra
.599 .667 .886 r
.72952 .52473 .737 .53634 .75308 .53147 .74582 .52241 Mtetra
.644 .742 .92 r
.74582 .52241 .75308 .53147 .76908 .52416 .7621 .51803 Mtetra
.711 .845 .946 r
.7621 .51803 .76908 .52416 .78506 .51577 .77825 .51078 Mtetra
.746 .887 .944 r
.77825 .51078 .78506 .51577 .80115 .50805 .79435 .50196 Mtetra
.729 .854 .94 r
.79435 .50196 .80115 .50805 .81738 .50114 .81058 .49393 Mtetra
.702 .816 .936 r
.81058 .49393 .81738 .50114 .83383 .4958 .82697 .48702 Mtetra
.663 .762 .924 r
.82697 .48702 .83383 .4958 .85042 .49091 .84359 .48173 Mtetra
.655 .751 .92 r
.84359 .48173 .85042 .49091 .8671 .48594 .86034 .47675 Mtetra
.656 .752 .92 r
.86034 .47675 .8671 .48594 .88386 .48082 .87719 .47169 Mtetra
.66 .756 .921 r
.87719 .47169 .88386 .48082 .90072 .4757 .89411 .46644 Mtetra
.656 .753 .921 r
.89411 .46644 .90072 .4757 .91771 .47081 .91115 .46135 Mtetra
.652 .747 .92 r
.91115 .46135 .91771 .47081 .93479 .46584 .92831 .4564 Mtetra
.66 .75 .917 r
.31743 .62829 .32622 .63604 .34013 .63174 .33138 .62397 Mtetra
.651 .749 .921 r
.33138 .62397 .34013 .63174 .3541 .62758 .34539 .61993 Mtetra
.653 .753 .924 r
.34539 .61993 .3541 .62758 .36814 .62357 .35948 .6158 Mtetra
.655 .752 .921 r
.35948 .6158 .36814 .62357 .38226 .61939 .37364 .61159 Mtetra
.654 .752 .922 r
.37364 .61159 .38226 .61939 .39645 .61514 .38788 .60738 Mtetra
.608 .741 .939 r
.38788 .60738 .39645 .61514 .41071 .61119 .40215 .60457 Mtetra
.528 .746 .975 r
.40215 .60457 .41071 .61119 .42501 .60881 .41646 .6033 Mtetra
.434 .742 .992 r
.41646 .6033 .42501 .60881 .43937 .60753 .43084 .60304 Mtetra
.487 .796 .999 r
.43084 .60304 .43937 .60753 .45381 .60704 .44536 .60136 Mtetra
.664 .818 .958 r
.44536 .60136 .45381 .60704 .46839 .60504 .46005 .59638 Mtetra
.728 .756 .875 r
.46005 .59638 .46839 .60504 .4831 .60026 .47485 .58863 Mtetra
.739 .706 .819 r
.47485 .58863 .4831 .60026 .4979 .59347 .48973 .57896 Mtetra
.715 .659 .793 r
.48973 .57896 .4979 .59347 .51277 .58478 .50464 .56986 Mtetra
.693 .646 .799 r
.50464 .56986 .51277 .58478 .52769 .57616 .51958 .56234 Mtetra
.68 .655 .819 r
.51958 .56234 .52769 .57616 .54265 .56862 .53458 .55604 Mtetra
.659 .666 .845 r
.53458 .55604 .54265 .56862 .55768 .56209 .54966 .55117 Mtetra
.649 .692 .876 r
.54966 .55117 .55768 .56209 .57278 .55631 .56483 .54689 Mtetra
.648 .724 .904 r
.56483 .54689 .57278 .55631 .58796 .55107 .58009 .54265 Mtetra
.65 .75 .922 r
.58009 .54265 .58796 .55107 .60324 .54621 .59542 .53825 Mtetra
.655 .764 .93 r
.59542 .53825 .60324 .54621 .6186 .54161 .61084 .5336 Mtetra
.661 .766 .928 r
.61084 .5336 .6186 .54161 .63405 .53727 .62634 .5287 Mtetra
.666 .755 .917 r
.62634 .5287 .63405 .53727 .64961 .5333 .64192 .52364 Mtetra
.664 .73 .899 r
.64192 .52364 .64961 .5333 .66528 .52989 .65759 .51861 Mtetra
.649 .692 .876 r
.65759 .51861 .66528 .52989 .6811 .52724 .67336 .51418 Mtetra
.617 .647 .858 r
.67336 .51418 .6811 .52724 .69707 .52563 .6893 .51121 Mtetra
.591 .615 .844 r
.6893 .51121 .69707 .52563 .71322 .52514 .70542 .50948 Mtetra
.559 .582 .834 r
.70542 .50948 .71322 .52514 .72952 .52473 .72176 .50938 Mtetra
.544 .579 .84 r
.72176 .50938 .72952 .52473 .74582 .52241 .73827 .50989 Mtetra
.578 .643 .878 r
.73827 .50989 .74582 .52241 .7621 .51803 .7548 .50845 Mtetra
.64 .732 .915 r
.7548 .50845 .7621 .51803 .77825 .51078 .77125 .50418 Mtetra
.72 .837 .937 r
.77125 .50418 .77825 .51078 .79435 .50196 .78753 .4965 Mtetra
.754 .879 .936 r
.78753 .4965 .79435 .50196 .81058 .49393 .80375 .48732 Mtetra
.73 .843 .934 r
.80375 .48732 .81058 .49393 .82697 .48702 .82012 .47918 Mtetra
.692 .8 .931 r
.82012 .47918 .82697 .48702 .84359 .48173 .83671 .47261 Mtetra
.657 .755 .922 r
.83671 .47261 .84359 .48173 .86034 .47675 .85352 .46748 Mtetra
.657 .753 .921 r
.85352 .46748 .86034 .47675 .87719 .47169 .87043 .46236 Mtetra
.658 .753 .92 r
.87043 .46236 .87719 .47169 .89411 .46644 .88744 .45714 Mtetra
.66 .756 .921 r
.88744 .45714 .89411 .46644 .91115 .46135 .90453 .45183 Mtetra
.653 .749 .92 r
.90453 .45183 .91115 .46135 .92831 .4564 .92176 .4468 Mtetra
.656 .749 .919 r
.30856 .62047 .31743 .62829 .33138 .62397 .32254 .61625 Mtetra
.65 .752 .924 r
.32254 .61625 .33138 .62397 .34539 .61993 .3366 .61219 Mtetra
.655 .754 .922 r
.3366 .61219 .34539 .61993 .35948 .6158 .35073 .60794 Mtetra
.656 .752 .92 r
.35073 .60794 .35948 .6158 .37364 .61159 .36495 .60362 Mtetra
.633 .744 .928 r
.36495 .60362 .37364 .61159 .38788 .60738 .37921 .60008 Mtetra
.55 .736 .962 r
.37921 .60008 .38788 .60738 .40215 .60457 .39347 .59857 Mtetra
.449 .735 .988 r
.39347 .59857 .40215 .60457 .41646 .6033 .40779 .59833 Mtetra
.448 .767 .997 r
.40779 .59833 .41646 .6033 .43084 .60304 .42223 .59748 Mtetra
.651 .819 .964 r
.42223 .59748 .43084 .60304 .44536 .60136 .43689 .59283 Mtetra
.732 .761 .875 r
.43689 .59283 .44536 .60136 .46005 .59638 .45169 .58488 Mtetra
.749 .711 .816 r
.45169 .58488 .46005 .59638 .47485 .58863 .46658 .57448 Mtetra
.722 .667 .795 r
.46658 .57448 .47485 .58863 .48973 .57896 .4815 .56497 Mtetra
.698 .66 .809 r
.4815 .56497 .48973 .57896 .50464 .56986 .49643 .55735 Mtetra
.67 .671 .842 r
.49643 .55735 .50464 .56986 .51958 .56234 .51141 .55187 Mtetra
.641 .698 .887 r
.51141 .55187 .51958 .56234 .53458 .55604 .52646 .54796 Mtetra
.626 .75 .936 r
.52646 .54796 .53458 .55604 .54966 .55117 .5416 .54436 Mtetra
.626 .785 .958 r
.5416 .54436 .54966 .55117 .56483 .54689 .55683 .54047 Mtetra
.632 .799 .963 r
.55683 .54047 .56483 .54689 .58009 .54265 .57216 .5363 Mtetra
.639 .805 .963 r
.57216 .5363 .58009 .54265 .59542 .53825 .58756 .53186 Mtetra
.647 .807 .96 r
.58756 .53186 .59542 .53825 .61084 .5336 .60305 .52717 Mtetra
.654 .81 .958 r
.60305 .52717 .61084 .5336 .62634 .5287 .61862 .52221 Mtetra
.662 .811 .955 r
.61862 .52221 .62634 .5287 .64192 .52364 .63426 .51699 Mtetra
.67 .811 .95 r
.63426 .51699 .64192 .52364 .65759 .51861 .64998 .51148 Mtetra
.68 .801 .94 r
.64998 .51148 .65759 .51861 .67336 .51418 .66577 .50567 Mtetra
.673 .765 .92 r
.66577 .50567 .67336 .51418 .6893 .51121 .68165 .50018 Mtetra
.635 .695 .889 r
.68165 .50018 .6893 .51121 .70542 .50948 .6977 .49627 Mtetra
.587 .634 .865 r
.6977 .49627 .70542 .50948 .72176 .50938 .71398 .49455 Mtetra
.546 .589 .849 r
.71398 .49455 .72176 .50938 .73827 .50989 .73051 .49478 Mtetra
.525 .575 .848 r
.73051 .49478 .73827 .50989 .7548 .50845 .74724 .49596 Mtetra
.573 .644 .882 r
.74724 .49596 .7548 .50845 .77125 .50418 .76395 .49463 Mtetra
.649 .74 .916 r
.76395 .49463 .77125 .50418 .78753 .4965 .78053 .48992 Mtetra
.741 .847 .929 r
.78053 .48992 .78753 .4965 .80375 .48732 .79689 .48126 Mtetra
.755 .866 .93 r
.79689 .48126 .80375 .48732 .82012 .47918 .81326 .47196 Mtetra
.725 .829 .929 r
.81326 .47196 .82012 .47918 .83671 .47261 .8298 .46394 Mtetra
.675 .776 .926 r
.8298 .46394 .83671 .47261 .85352 .46748 .84661 .45803 Mtetra
.655 .75 .92 r
.84661 .45803 .85352 .46748 .87043 .46236 .8636 .45292 Mtetra
.656 .752 .92 r
.8636 .45292 .87043 .46236 .88744 .45714 .88069 .44773 Mtetra
.661 .756 .921 r
.88069 .44773 .88744 .45714 .90453 .45183 .89785 .44233 Mtetra
.656 .753 .921 r
.89785 .44233 .90453 .45183 .92176 .4468 .91514 .43709 Mtetra
.652 .749 .921 r
.29959 .61259 .30856 .62047 .32254 .61625 .31362 .60847 Mtetra
.652 .753 .923 r
.31362 .60847 .32254 .61625 .3366 .61219 .32772 .60429 Mtetra
.655 .751 .921 r
.32772 .60429 .3366 .61219 .35073 .60794 .3419 .60001 Mtetra
.651 .751 .922 r
.3419 .60001 .35073 .60794 .36495 .60362 .35616 .59583 Mtetra
.588 .737 .946 r
.35616 .59583 .36495 .60362 .37921 .60008 .3704 .59349 Mtetra
.488 .735 .981 r
.3704 .59349 .37921 .60008 .39347 .59857 .38467 .59285 Mtetra
.422 .733 .991 r
.38467 .59285 .39347 .59857 .40779 .59833 .39903 .5928 Mtetra
.597 .807 .98 r
.39903 .5928 .40779 .59833 .42223 .59748 .41361 .58947 Mtetra
.721 .771 .892 r
.41361 .58947 .42223 .59748 .43689 .59283 .42839 .58223 Mtetra
.76 .728 .823 r
.42839 .58223 .43689 .59283 .45169 .58488 .44331 .57139 Mtetra
.734 .68 .798 r
.44331 .57139 .45169 .58488 .46658 .57448 .45824 .56115 Mtetra
.706 .673 .815 r
.45824 .56115 .46658 .57448 .4815 .56497 .47317 .55318 Mtetra
.663 .682 .857 r
.47317 .55318 .4815 .56497 .49643 .55735 .48812 .54817 Mtetra
.624 .722 .917 r
.48812 .54817 .49643 .55735 .51141 .55187 .50314 .54479 Mtetra
.611 .773 .958 r
.50314 .54479 .51141 .55187 .52646 .54796 .51825 .54142 Mtetra
.616 .791 .965 r
.51825 .54142 .52646 .54796 .5416 .54436 .53345 .53771 Mtetra
.628 .793 .961 r
.53345 .53771 .5416 .54436 .55683 .54047 .54874 .53368 Mtetra
.642 .794 .955 r
.54874 .53368 .55683 .54047 .57216 .5363 .56413 .52923 Mtetra
.649 .79 .949 r
.56413 .52923 .57216 .5363 .58756 .53186 .57959 .52456 Mtetra
.652 .786 .945 r
.57959 .52456 .58756 .53186 .60305 .52717 .59514 .51982 Mtetra
.653 .786 .945 r
.59514 .51982 .60305 .52717 .61862 .52221 .61078 .515 Mtetra
.658 .792 .946 r
.61078 .515 .61862 .52221 .63426 .51699 .6265 .50997 Mtetra
.669 .802 .946 r
.6265 .50997 .63426 .51699 .64998 .51148 .64229 .50451 Mtetra
.677 .807 .945 r
.64229 .50451 .64998 .51148 .66577 .50567 .65816 .49872 Mtetra
.685 .812 .943 r
.65816 .49872 .66577 .50567 .68165 .50018 .67409 .49258 Mtetra
.686 .796 .933 r
.67409 .49258 .68165 .50018 .6977 .49627 .6901 .48644 Mtetra
.646 .729 .909 r
.6901 .48644 .6977 .49627 .71398 .49455 .70628 .48196 Mtetra
.576 .643 .88 r
.70628 .48196 .71398 .49455 .73051 .49478 .72274 .4805 Mtetra
.525 .589 .861 r
.72274 .4805 .73051 .49478 .74724 .49596 .73949 .4814 Mtetra
.51 .578 .859 r
.73949 .4814 .74724 .49596 .76395 .49463 .75643 .48294 Mtetra
.588 .669 .895 r
.75643 .48294 .76395 .49463 .78053 .48992 .77327 .48079 Mtetra
.682 .766 .915 r
.77327 .48079 .78053 .48992 .79689 .48126 .78991 .47461 Mtetra
.759 .853 .92 r
.78991 .47461 .79689 .48126 .81326 .47196 .80634 .46501 Mtetra
.746 .844 .924 r
.80634 .46501 .81326 .47196 .8298 .46394 .82288 .456 Mtetra
.705 .807 .928 r
.82288 .456 .8298 .46394 .84661 .45803 .83965 .44873 Mtetra
.66 .758 .923 r
.83965 .44873 .84661 .45803 .8636 .45292 .8567 .44337 Mtetra
.657 .752 .92 r
.8567 .44337 .8636 .45292 .88069 .44773 .87385 .43812 Mtetra
.659 .753 .92 r
.87385 .43812 .88069 .44773 .89785 .44233 .8911 .43275 Mtetra
.659 .755 .921 r
.8911 .43275 .89785 .44233 .91514 .43709 .90845 .42731 Mtetra
.65 .751 .923 r
.29054 .60472 .29959 .61259 .31362 .60847 .30461 .60061 Mtetra
.654 .753 .922 r
.30461 .60061 .31362 .60847 .32772 .60429 .31876 .59632 Mtetra
.656 .752 .92 r
.31876 .59632 .32772 .60429 .3419 .60001 .33299 .59194 Mtetra
.633 .744 .928 r
.33299 .59194 .3419 .60001 .35616 .59583 .34726 .58834 Mtetra
.539 .73 .963 r
.34726 .58834 .35616 .59583 .3704 .59349 .3615 .58703 Mtetra
.433 .717 .984 r
.3615 .58703 .3704 .59349 .38467 .59285 .37578 .58718 Mtetra
.499 .77 .992 r
.37578 .58718 .38467 .59285 .39903 .5928 .39023 .58582 Mtetra
.691 .791 .927 r
.39023 .58582 .39903 .5928 .41361 .58947 .40495 .57998 Mtetra
.762 .748 .841 r
.40495 .57998 .41361 .58947 .42839 .58223 .41987 .56966 Mtetra
.752 .698 .8 r
.41987 .56966 .42839 .58223 .44331 .57139 .43485 .55841 Mtetra
.719 .683 .814 r
.43485 .55841 .44331 .57139 .45824 .56115 .4498 .54964 Mtetra
.67 .69 .86 r
.4498 .54964 .45824 .56115 .47317 .55318 .46473 .54428 Mtetra
.615 .726 .926 r
.46473 .54428 .47317 .55318 .48812 .54817 .4797 .54116 Mtetra
.603 .773 .962 r
.4797 .54116 .48812 .54817 .50314 .54479 .49477 .53796 Mtetra
.613 .783 .962 r
.49477 .53796 .50314 .54479 .51825 .54142 .50994 .5344 Mtetra
.641 .787 .952 r
.50994 .5344 .51825 .54142 .53345 .53771 .52521 .53004 Mtetra
.653 .774 .938 r
.52521 .53004 .53345 .53771 .54874 .53368 .54056 .52537 Mtetra
.655 .76 .927 r
.54056 .52537 .54874 .53368 .56413 .52923 .55599 .52064 Mtetra
.656 .754 .922 r
.55599 .52064 .56413 .52923 .57959 .52456 .57152 .51588 Mtetra
.656 .753 .922 r
.57152 .51588 .57959 .52456 .59514 .51982 .58713 .51109 Mtetra
.656 .753 .921 r
.58713 .51109 .59514 .51982 .61078 .515 .60282 .50627 Mtetra
.656 .754 .922 r
.60282 .50627 .61078 .515 .6265 .50997 .61861 .50142 Mtetra
.657 .76 .926 r
.61861 .50142 .6265 .50997 .64229 .50451 .63449 .49651 Mtetra
.663 .778 .934 r
.63449 .49651 .64229 .50451 .65816 .49872 .65044 .49128 Mtetra
.682 .8 .937 r
.65044 .49128 .65816 .49872 .67409 .49258 .66645 .48524 Mtetra
.691 .806 .936 r
.66645 .48524 .67409 .49258 .6901 .48644 .68252 .47882 Mtetra
.693 .801 .932 r
.68252 .47882 .6901 .48644 .70628 .48196 .69867 .47231 Mtetra
.637 .733 .917 r
.69867 .47231 .70628 .48196 .72274 .4805 .71503 .46808 Mtetra
.554 .638 .889 r
.71503 .46808 .72274 .4805 .73949 .4814 .73172 .46735 Mtetra
.495 .58 .87 r
.73172 .46735 .73949 .4814 .75643 .48294 .74872 .46921 Mtetra
.518 .598 .874 r
.74872 .46921 .75643 .48294 .77327 .48079 .76582 .47012 Mtetra
.622 .709 .908 r
.76582 .47012 .77327 .48079 .78991 .47461 .78272 .46644 Mtetra
.729 .808 .914 r
.78272 .46644 .78991 .47461 .80634 .46501 .79935 .4581 Mtetra
.764 .851 .916 r
.79935 .4581 .80634 .46501 .82288 .456 .81591 .44817 Mtetra
.731 .821 .921 r
.81591 .44817 .82288 .456 .83965 .44873 .83266 .43973 Mtetra
.675 .774 .925 r
.83266 .43973 .83965 .44873 .8567 .44337 .84971 .43367 Mtetra
.655 .75 .92 r
.84971 .43367 .8567 .44337 .87385 .43812 .86695 .42841 Mtetra
.657 .752 .92 r
.86695 .42841 .87385 .43812 .8911 .43275 .88428 .42306 Mtetra
.661 .756 .92 r
.88428 .42306 .8911 .43275 .90845 .42731 .90169 .4175 Mtetra
.651 .751 .923 r
.28139 .59679 .29054 .60472 .30461 .60061 .29551 .59262 Mtetra
.655 .752 .921 r
.29551 .59262 .30461 .60061 .31876 .59632 .3097 .58827 Mtetra
.654 .752 .921 r
.3097 .58827 .31876 .59632 .33299 .59194 .32398 .58392 Mtetra
.6 .738 .941 r
.32398 .58392 .33299 .59194 .34726 .58834 .33824 .58122 Mtetra
.495 .726 .975 r
.33824 .58122 .34726 .58834 .3615 .58703 .35249 .58059 Mtetra
.421 .715 .985 r
.35249 .58059 .3615 .58703 .37578 .58718 .3668 .58085 Mtetra
.611 .79 .967 r
.3668 .58085 .37578 .58718 .39023 .58582 .38139 .57736 Mtetra
.738 .766 .875 r
.38139 .57736 .39023 .58582 .40495 .57998 .39626 .56903 Mtetra
.77 .726 .812 r
.39626 .56903 .40495 .57998 .41987 .56966 .41129 .55709 Mtetra
.739 .695 .81 r
.41129 .55709 .41987 .56966 .43485 .55841 .42629 .54694 Mtetra
.695 .7 .85 r
.42629 .54694 .43485 .55841 .4498 .54964 .44123 .54022 Mtetra
.62 .717 .916 r
.44123 .54022 .4498 .54964 .46473 .54428 .45616 .53696 Mtetra
.595 .763 .959 r
.45616 .53696 .46473 .54428 .4797 .54116 .47119 .53402 Mtetra
.61 .774 .959 r
.47119 .53402 .4797 .54116 .49477 .53796 .48632 .5306 Mtetra
.647 .78 .945 r
.48632 .5306 .49477 .53796 .50994 .5344 .50155 .52609 Mtetra
.655 .76 .927 r
.50155 .52609 .50994 .5344 .52521 .53004 .51687 .52138 Mtetra
.647 .75 .924 r
.51687 .52138 .52521 .53004 .54056 .52537 .53228 .51694 Mtetra
.648 .757 .929 r
.53228 .51694 .54056 .52537 .55599 .52064 .54778 .51242 Mtetra
.651 .764 .932 r
.54778 .51242 .55599 .52064 .57152 .51588 .56336 .50775 Mtetra
.654 .769 .933 r
.56336 .50775 .57152 .51588 .58713 .51109 .57903 .50291 Mtetra
.658 .77 .932 r
.57903 .50291 .58713 .51109 .60282 .50627 .59479 .4979 Mtetra
.662 .768 .928 r
.59479 .4979 .60282 .50627 .61861 .50142 .61064 .49274 Mtetra
.664 .762 .923 r
.61064 .49274 .61861 .50142 .63449 .49651 .62657 .48749 Mtetra
.656 .753 .921 r
.62657 .48749 .63449 .49651 .65044 .49128 .64259 .48252 Mtetra
.661 .762 .925 r
.64259 .48252 .65044 .49128 .66645 .48524 .65871 .47735 Mtetra
.687 .793 .93 r
.65871 .47735 .66645 .48524 .68252 .47882 .67486 .47105 Mtetra
.699 .801 .929 r
.67486 .47105 .68252 .47882 .69867 .47231 .69107 .46427 Mtetra
.69 .793 .928 r
.69107 .46427 .69867 .47231 .71503 .46808 .70738 .45779 Mtetra
.602 .707 .918 r
.70738 .45779 .71503 .46808 .73172 .46735 .72398 .45485 Mtetra
.514 .62 .894 r
.72398 .45485 .73172 .46735 .74872 .46921 .74094 .45545 Mtetra
.472 .575 .878 r
.74094 .45545 .74872 .46921 .76582 .47012 .75819 .45793 Mtetra
.562 .652 .896 r
.75819 .45793 .76582 .47012 .78272 .46644 .77534 .45671 Mtetra
.679 .757 .91 r
.77534 .45671 .78272 .46644 .79935 .4581 .79222 .45048 Mtetra
.765 .835 .906 r
.79222 .45048 .79935 .4581 .81591 .44817 .80886 .44035 Mtetra
.746 .827 .914 r
.80886 .44035 .81591 .44817 .83266 .43973 .82562 .43111 Mtetra
.698 .794 .924 r
.82562 .43111 .83266 .43973 .84971 .43367 .84266 .42399 Mtetra
.657 .754 .922 r
.84266 .42399 .84971 .43367 .86695 .42841 .85997 .41861 Mtetra
.657 .752 .92 r
.85997 .41861 .86695 .42841 .88428 .42306 .87737 .4132 Mtetra
.66 .754 .92 r
.87737 .4132 .88428 .42306 .90169 .4175 .89487 .40761 Mtetra
.652 .752 .923 r
.27216 .58879 .28139 .59679 .29551 .59262 .28632 .58452 Mtetra
.655 .751 .921 r
.28632 .58452 .29551 .59262 .3097 .58827 .30056 .58011 Mtetra
.648 .749 .923 r
.30056 .58011 .3097 .58827 .32398 .58392 .31487 .57595 Mtetra
.566 .73 .952 r
.31487 .57595 .32398 .58392 .33824 .58122 .32912 .57407 Mtetra
.454 .71 .977 r
.32912 .57407 .33824 .58122 .35249 .58059 .34337 .57411 Mtetra
.465 .735 .986 r
.34337 .57411 .35249 .58059 .3668 .58085 .35777 .57362 Mtetra
.681 .785 .929 r
.35777 .57362 .3668 .58085 .38139 .57736 .3725 .56811 Mtetra
.767 .756 .842 r
.3725 .56811 .38139 .57736 .39626 .56903 .38751 .55743 Mtetra
.765 .717 .807 r
.38751 .55743 .39626 .56903 .41129 .55709 .4026 .54553 Mtetra
.729 .709 .832 r
.4026 .54553 .41129 .55709 .42629 .54694 .41761 .53662 Mtetra
.648 .708 .891 r
.41761 .53662 .42629 .54694 .44123 .54022 .43253 .5323 Mtetra
.591 .747 .951 r
.43253 .5323 .44123 .54022 .45616 .53696 .44751 .52959 Mtetra
.6 .765 .958 r
.44751 .52959 .45616 .53696 .47119 .53402 .46259 .52645 Mtetra
.642 .775 .944 r
.46259 .52645 .47119 .53402 .48632 .5306 .47779 .52209 Mtetra
.653 .755 .925 r
.47779 .52209 .48632 .5306 .50155 .52609 .49308 .51744 Mtetra
.642 .749 .927 r
.49308 .51744 .50155 .52609 .51687 .52138 .50845 .51316 Mtetra
.643 .761 .935 r
.50845 .51316 .51687 .52138 .53228 .51694 .52392 .50877 Mtetra
.648 .766 .935 r
.52392 .50877 .53228 .51694 .54778 .51242 .53947 .50418 Mtetra
.652 .766 .933 r
.53947 .50418 .54778 .51242 .56336 .50775 .55512 .49942 Mtetra
.655 .766 .931 r
.55512 .49942 .56336 .50775 .57903 .50291 .57085 .49453 Mtetra
.658 .767 .93 r
.57085 .49453 .57903 .50291 .59479 .4979 .58668 .48951 Mtetra
.661 .769 .93 r
.58668 .48951 .59479 .4979 .61064 .49274 .60258 .48432 Mtetra
.666 .771 .928 r
.60258 .48432 .61064 .49274 .62657 .48749 .61858 .47892 Mtetra
.668 .77 .926 r
.61858 .47892 .62657 .48749 .64259 .48252 .63465 .47342 Mtetra
.659 .755 .921 r
.63465 .47342 .64259 .48252 .65871 .47735 .65083 .46828 Mtetra
.665 .759 .92 r
.65083 .46828 .65871 .47735 .67486 .47105 .6671 .46284 Mtetra
.695 .791 .924 r
.6671 .46284 .67486 .47105 .69107 .46427 .68339 .45615 Mtetra
.705 .798 .923 r
.68339 .45615 .69107 .46427 .70738 .45779 .69974 .44902 Mtetra
.664 .77 .928 r
.69974 .44902 .70738 .45779 .72398 .45485 .71626 .44352 Mtetra
.543 .66 .913 r
.71626 .44352 .72398 .45485 .74094 .45545 .73318 .44273 Mtetra
.46 .59 .896 r
.73318 .44273 .74094 .45545 .75819 .45793 .75046 .44506 Mtetra
.5 .61 .893 r
.75046 .44506 .75819 .45793 .77534 .45671 .76783 .44615 Mtetra
.631 .721 .912 r
.76783 .44615 .77534 .45671 .79222 .45048 .78494 .44192 Mtetra
.747 .81 .902 r
.78494 .44192 .79222 .45048 .80886 .44035 .80172 .43246 Mtetra
.76 .832 .907 r
.80172 .43246 .80886 .44035 .82562 .43111 .81852 .42242 Mtetra
.718 .802 .917 r
.81852 .42242 .82562 .43111 .84266 .42399 .83555 .41435 Mtetra
.663 .76 .922 r
.83555 .41435 .84266 .42399 .85997 .41861 .8529 .40866 Mtetra
.656 .751 .92 r
.8529 .40866 .85997 .41861 .87737 .4132 .87039 .40321 Mtetra
.659 .753 .919 r
.87039 .40321 .87737 .4132 .89487 .40761 .88796 .39762 Mtetra
.653 .752 .922 r
.26283 .5807 .27216 .58879 .28632 .58452 .27704 .57634 Mtetra
.656 .752 .92 r
.27704 .57634 .28632 .58452 .30056 .58011 .29133 .57186 Mtetra
.637 .746 .927 r
.29133 .57186 .30056 .58011 .31487 .57595 .30566 .56801 Mtetra
.536 .722 .959 r
.30566 .56801 .31487 .57595 .32912 .57407 .31991 .56676 Mtetra
.433 .698 .976 r
.31991 .56676 .32912 .57407 .34337 .57411 .33418 .56716 Mtetra
.541 .753 .975 r
.33418 .56716 .34337 .57411 .35777 .57362 .34868 .5654 Mtetra
.714 .77 .896 r
.34868 .5654 .35777 .57362 .3725 .56811 .36354 .55839 Mtetra
.782 .75 .824 r
.36354 .55839 .3725 .56811 .38751 .55743 .37868 .54614 Mtetra
.76 .722 .817 r
.37868 .54614 .38751 .55743 .4026 .54553 .3938 .53493 Mtetra
.708 .722 .861 r
.3938 .53493 .4026 .54553 .41761 .53662 .4088 .52768 Mtetra
.608 .728 .93 r
.4088 .52768 .41761 .53662 .43253 .5323 .42373 .52464 Mtetra
.59 .755 .957 r
.42373 .52464 .43253 .5323 .44751 .52959 .43876 .52182 Mtetra
.624 .765 .947 r
.43876 .52182 .44751 .52959 .46259 .52645 .45391 .51803 Mtetra
.654 .758 .926 r
.45391 .51803 .46259 .52645 .47779 .52209 .46917 .51331 Mtetra
.64 .746 .926 r
.46917 .51331 .47779 .52209 .49308 .51744 .48451 .50909 Mtetra
.639 .758 .934 r
.48451 .50909 .49308 .51744 .50845 .51316 .49994 .50481 Mtetra
.647 .762 .933 r
.49994 .50481 .50845 .51316 .52392 .50877 .51546 .50025 Mtetra
.655 .761 .928 r
.51546 .50025 .52392 .50877 .53947 .50418 .53108 .49538 Mtetra
.66 .757 .922 r
.53108 .49538 .53947 .50418 .55512 .49942 .54678 .49031 Mtetra
.656 .75 .919 r
.54678 .49031 .55512 .49942 .57085 .49453 .56257 .48537 Mtetra
.652 .748 .92 r
.56257 .48537 .57085 .49453 .58668 .48951 .57846 .48056 Mtetra
.656 .756 .923 r
.57846 .48056 .58668 .48951 .60258 .48432 .59444 .47554 Mtetra
.663 .764 .925 r
.59444 .47554 .60258 .48432 .61858 .47892 .6105 .47022 Mtetra
.67 .769 .925 r
.6105 .47022 .61858 .47892 .63465 .47342 .62664 .46461 Mtetra
.671 .768 .923 r
.62664 .46461 .63465 .47342 .65083 .46828 .64287 .45893 Mtetra
.657 .752 .92 r
.64287 .45893 .65083 .46828 .6671 .46284 .65921 .45376 Mtetra
.68 .767 .917 r
.65921 .45376 .6671 .46284 .68339 .45615 .6756 .44763 Mtetra
.703 .789 .918 r
.6756 .44763 .68339 .45615 .69974 .44902 .69203 .4405 Mtetra
.697 .789 .922 r
.69203 .4405 .69974 .44902 .71626 .44352 .70855 .43359 Mtetra
.585 .714 .932 r
.70855 .43359 .71626 .44352 .73318 .44273 .72541 .43098 Mtetra
.471 .618 .913 r
.72541 .43098 .73318 .44273 .75046 .44506 .74268 .43248 Mtetra
.446 .588 .901 r
.74268 .43248 .75046 .44506 .76783 .44615 .7602 .43509 Mtetra
.593 .696 .914 r
.7602 .43509 .76783 .44615 .78494 .44192 .7775 .43231 Mtetra
.719 .78 .9 r
.7775 .43231 .78494 .44192 .80172 .43246 .79447 .42406 Mtetra
.766 .823 .897 r
.79447 .42406 .80172 .43246 .81852 .42242 .81131 .41353 Mtetra
.732 .804 .908 r
.81131 .41353 .81852 .42242 .83555 .41435 .82837 .40471 Mtetra
.672 .766 .921 r
.82837 .40471 .83555 .41435 .8529 .40866 .84576 .39858 Mtetra
.655 .751 .92 r
.84576 .39858 .8529 .40866 .87039 .40321 .86332 .39311 Mtetra
.658 .752 .92 r
.86332 .39311 .87039 .40321 .88796 .39762 .88098 .3875 Mtetra
.654 .752 .922 r
.2534 .57251 .26283 .5807 .27704 .57634 .26766 .56808 Mtetra
.656 .752 .92 r
.26766 .56808 .27704 .57634 .29133 .57186 .282 .56355 Mtetra
.622 .743 .933 r
.282 .56355 .29133 .57186 .30566 .56801 .29635 .56011 Mtetra
.517 .718 .964 r
.29635 .56011 .30566 .56801 .31991 .56676 .31062 .55917 Mtetra
.429 .691 .974 r
.31062 .55917 .31991 .56676 .33418 .56716 .32491 .55971 Mtetra
.595 .76 .957 r
.32491 .55971 .33418 .56716 .34868 .5654 .33952 .5568 Mtetra
.74 .767 .875 r
.33952 .5568 .34868 .5654 .36354 .55839 .35451 .54823 Mtetra
.785 .745 .816 r
.35451 .54823 .36354 .55839 .37868 .54614 .36974 .53543 Mtetra
.754 .732 .832 r
.36974 .53543 .37868 .54614 .3938 .53493 .38488 .52501 Mtetra
.68 .729 .888 r
.38488 .52501 .3938 .53493 .4088 .52768 .39988 .51928 Mtetra
.589 .737 .946 r
.39988 .51928 .4088 .52768 .42373 .52464 .41485 .51663 Mtetra
.596 .75 .951 r
.41485 .51663 .42373 .52464 .43876 .52182 .42993 .51366 Mtetra
.644 .763 .935 r
.42993 .51366 .43876 .52182 .45391 .51803 .44515 .50923 Mtetra
.647 .749 .924 r
.44515 .50923 .45391 .51803 .46917 .51331 .46046 .50474 Mtetra
.636 .753 .933 r
.46046 .50474 .46917 .51331 .48451 .50909 .47585 .50058 Mtetra
.643 .758 .932 r
.47585 .50058 .48451 .50909 .49994 .50481 .49134 .49611 Mtetra
.659 .759 .924 r
.49134 .49611 .49994 .50481 .51546 .50025 .50692 .49107 Mtetra
.666 .751 .914 r
.50692 .49107 .51546 .50025 .53108 .49538 .52259 .48574 Mtetra
.66 .74 .909 r
.52259 .48574 .53108 .49538 .54678 .49031 .53835 .48064 Mtetra
.656 .739 .911 r
.53835 .48064 .54678 .49031 .56257 .48537 .5542 .47565 Mtetra
.653 .738 .912 r
.5542 .47565 .56257 .48537 .57846 .48056 .57015 .47076 Mtetra
.646 .735 .914 r
.57015 .47076 .57846 .48056 .59444 .47554 .58619 .4661 Mtetra
.652 .747 .919 r
.58619 .4661 .59444 .47554 .6105 .47022 .60232 .46116 Mtetra
.666 .762 .921 r
.60232 .46116 .6105 .47022 .62664 .46461 .61853 .45563 Mtetra
.673 .767 .921 r
.61853 .45563 .62664 .46461 .64287 .45893 .63483 .44978 Mtetra
.664 .762 .923 r
.63483 .44978 .64287 .45893 .65921 .45376 .65122 .44427 Mtetra
.665 .755 .917 r
.65122 .44427 .65921 .45376 .6756 .44763 .66771 .43869 Mtetra
.7 .781 .914 r
.66771 .43869 .6756 .44763 .69203 .4405 .68422 .43161 Mtetra
.707 .786 .913 r
.68422 .43161 .69203 .4405 .70855 .43359 .70078 .42419 Mtetra
.629 .747 .933 r
.70078 .42419 .70855 .43359 .72541 .43098 .71762 .41992 Mtetra
.49 .646 .926 r
.71762 .41992 .72541 .43098 .74268 .43248 .73488 .42049 Mtetra
.417 .587 .911 r
.73488 .42049 .74268 .43248 .7602 .43509 .75248 .42356 Mtetra
.552 .669 .915 r
.75248 .42356 .7602 .43509 .7775 .43231 .76995 .42228 Mtetra
.695 .764 .905 r
.76995 .42228 .7775 .43231 .79447 .42406 .78709 .41512 Mtetra
.767 .813 .889 r
.78709 .41512 .79447 .42406 .81131 .41353 .80401 .40435 Mtetra
.739 .801 .902 r
.80401 .40435 .81131 .41353 .82837 .40471 .82112 .39509 Mtetra
.683 .773 .92 r
.82112 .39509 .82837 .40471 .84576 .39858 .83854 .38843 Mtetra
.655 .751 .92 r
.83854 .38843 .84576 .39858 .86332 .39311 .85618 .38289 Mtetra
.657 .752 .92 r
.85618 .38289 .86332 .39311 .88098 .3875 .87392 .37725 Mtetra
.655 .752 .921 r
.24389 .56423 .2534 .57251 .26766 .56808 .25819 .55973 Mtetra
.656 .752 .92 r
.25819 .55973 .26766 .56808 .282 .56355 .27258 .55518 Mtetra
.611 .74 .937 r
.27258 .55518 .282 .56355 .29635 .56011 .28694 .55202 Mtetra
.507 .712 .963 r
.28694 .55202 .29635 .56011 .31062 .55917 .30124 .55129 Mtetra
.436 .688 .971 r
.30124 .55129 .31062 .55917 .32491 .55971 .31557 .55179 Mtetra
.627 .759 .942 r
.31557 .55179 .32491 .55971 .33952 .5568 .33027 .54802 Mtetra
.756 .767 .863 r
.33027 .54802 .33952 .5568 .35451 .54823 .34537 .53839 Mtetra
.789 .752 .82 r
.34537 .53839 .35451 .54823 .36974 .53543 .36067 .52547 Mtetra
.752 .746 .847 r
.36067 .52547 .36974 .53543 .38488 .52501 .37585 .51557 Mtetra
.655 .735 .908 r
.37585 .51557 .38488 .52501 .39988 .51928 .39086 .51084 Mtetra
.585 .737 .948 r
.39086 .51084 .39988 .51928 .41485 .51663 .40587 .50826 Mtetra
.607 .747 .944 r
.40587 .50826 .41485 .51663 .42993 .51366 .42101 .50502 Mtetra
.652 .756 .926 r
.42101 .50502 .42993 .51366 .44515 .50923 .43629 .5003 Mtetra
.639 .746 .926 r
.43629 .5003 .44515 .50923 .46046 .50474 .45165 .49602 Mtetra
.637 .752 .931 r
.45165 .49602 .46046 .50474 .47585 .50058 .4671 .49178 Mtetra
.65 .755 .926 r
.4671 .49178 .47585 .50058 .49134 .49611 .48265 .48705 Mtetra
.67 .756 .915 r
.48265 .48705 .49134 .49611 .50692 .49107 .49829 .48154 Mtetra
.655 .742 .914 r
.49829 .48154 .50692 .49107 .52259 .48574 .51402 .4766 Mtetra
.645 .749 .925 r
.51402 .4766 .52259 .48574 .53835 .48064 .52984 .47199 Mtetra
.655 .765 .93 r
.52984 .47199 .53835 .48064 .5542 .47565 .54575 .46694 Mtetra
.666 .768 .926 r
.54575 .46694 .5542 .47565 .57015 .47076 .56175 .46146 Mtetra
.657 .753 .92 r
.56175 .46146 .57015 .47076 .58619 .4661 .57785 .4563 Mtetra
.642 .737 .918 r
.57785 .4563 .58619 .4661 .60232 .46116 .59405 .45172 Mtetra
.661 .753 .919 r
.59405 .45172 .60232 .46116 .61853 .45563 .61033 .44636 Mtetra
.673 .762 .918 r
.61033 .44636 .61853 .45563 .63483 .44978 .62669 .44049 Mtetra
.671 .763 .919 r
.62669 .44049 .63483 .44978 .65122 .44427 .64315 .43465 Mtetra
.659 .752 .919 r
.64315 .43465 .65122 .44427 .66771 .43869 .65971 .42925 Mtetra
.694 .77 .91 r
.65971 .42925 .66771 .43869 .68422 .43161 .6763 .42235 Mtetra
.709 .78 .907 r
.6763 .42235 .68422 .43161 .70078 .42419 .69294 .41475 Mtetra
.657 .76 .925 r
.69294 .41475 .70078 .42419 .71762 .41992 .70978 .40935 Mtetra
.503 .666 .935 r
.70978 .40935 .71762 .41992 .73488 .42049 .72706 .40927 Mtetra
.397 .595 .925 r
.72706 .40927 .73488 .42049 .75248 .42356 .74471 .41234 Mtetra
.517 .661 .926 r
.74471 .41234 .75248 .42356 .76995 .42228 .76231 .41204 Mtetra
.676 .756 .911 r
.76231 .41204 .76995 .42228 .78709 .41512 .7796 .40567 Mtetra
.765 .803 .884 r
.7796 .40567 .78709 .41512 .80401 .40435 .7966 .39484 Mtetra
.743 .797 .896 r
.7966 .39484 .80401 .40435 .82112 .39509 .81377 .38525 Mtetra
.69 .773 .915 r
.81377 .38525 .82112 .39509 .83854 .38843 .83124 .37818 Mtetra
.656 .752 .921 r
.83124 .37818 .83854 .38843 .85618 .38289 .84896 .37256 Mtetra
.657 .752 .92 r
.84896 .37256 .85618 .38289 .87392 .37725 .86678 .36688 Mtetra
.655 .751 .921 r
.23427 .55585 .24389 .56423 .25819 .55973 .24862 .5513 Mtetra
.24862 .5513 .25819 .55973 .27258 .55518 .26306 .54671 Mtetra
.606 .738 .938 r
.26306 .54671 .27258 .55518 .28694 .55202 .27745 .54369 Mtetra
.502 .705 .961 r
.27745 .54369 .28694 .55202 .30124 .55129 .29177 .54309 Mtetra
.447 .686 .967 r
.29177 .54309 .30124 .55129 .31557 .55179 .30614 .54346 Mtetra
.641 .755 .931 r
.30614 .54346 .31557 .55179 .33027 .54802 .32092 .53922 Mtetra
.763 .77 .858 r
.32092 .53922 .33027 .54802 .34537 .53839 .33611 .52904 Mtetra
.792 .763 .826 r
.33611 .52904 .34537 .53839 .36067 .52547 .35149 .51612 Mtetra
.752 .76 .858 r
.35149 .51612 .36067 .52547 .37585 .51557 .36672 .50644 Mtetra
.641 .74 .92 r
.36672 .50644 .37585 .51557 .39086 .51084 .38175 .50218 Mtetra
.585 .733 .945 r
.38175 .50218 .39086 .51084 .40587 .50826 .39681 .49957 Mtetra
.614 .744 .938 r
.39681 .49957 .40587 .50826 .42101 .50502 .41201 .49609 Mtetra
.654 .752 .922 r
.41201 .49609 .42101 .50502 .43629 .5003 .42735 .49128 Mtetra
.636 .745 .927 r
.42735 .49128 .43629 .5003 .45165 .49602 .44275 .48709 Mtetra
.638 .749 .929 r
.44275 .48709 .45165 .49602 .4671 .49178 .45826 .48276 Mtetra
.657 .754 .921 r
.45826 .48276 .4671 .49178 .48265 .48705 .47387 .47771 Mtetra
.669 .752 .912 r
.47387 .47771 .48265 .48705 .49829 .48154 .48957 .47218 Mtetra
.64 .743 .923 r
.48957 .47218 .49829 .48154 .51402 .4766 .50535 .46772 Mtetra
.632 .753 .935 r
.50535 .46772 .51402 .4766 .52984 .47199 .52123 .46348 Mtetra
.654 .771 .935 r
.52123 .46348 .52984 .47199 .54575 .46694 .53721 .45839 Mtetra
.677 .777 .926 r
.53721 .45839 .54575 .46694 .56175 .46146 .55327 .45242 Mtetra
.671 .765 .921 r
.55327 .45242 .56175 .46146 .57785 .4563 .56943 .44667 Mtetra
.642 .743 .922 r
.56943 .44667 .57785 .4563 .59405 .45172 .58569 .442 Mtetra
.655 .747 .918 r
.58569 .442 .59405 .45172 .61033 .44636 .60204 .43684 Mtetra
.672 .759 .916 r
.60204 .43684 .61033 .44636 .62669 .44049 .61847 .43096 Mtetra
.674 .761 .916 r
.61847 .43096 .62669 .44049 .64315 .43465 .63499 .42493 Mtetra
.658 .752 .919 r
.63499 .42493 .64315 .43465 .65971 .42925 .65162 .41952 Mtetra
.69 .764 .908 r
.65162 .41952 .65971 .42925 .6763 .42235 .66829 .41274 Mtetra
.708 .774 .903 r
.66829 .41274 .6763 .42235 .69294 .41475 .685 .40506 Mtetra
.67 .761 .919 r
.685 .40506 .69294 .41475 .70978 .40935 .70188 .39907 Mtetra
.508 .678 .942 r
.70188 .39907 .70978 .40935 .72706 .40927 .7192 .39865 Mtetra
.384 .605 .935 r
.7192 .39865 .72706 .40927 .74471 .41234 .7369 .40161 Mtetra
.492 .662 .937 r
.7369 .40161 .74471 .41234 .76231 .41204 .75459 .40177 Mtetra
.666 .753 .915 r
.75459 .40177 .76231 .41204 .7796 .40567 .77199 .39578 Mtetra
.761 .795 .88 r
.77199 .39578 .7796 .40567 .7966 .39484 .78909 .38496 Mtetra
.745 .792 .891 r
.78909 .38496 .7966 .39484 .81377 .38525 .80633 .37513 Mtetra
.694 .771 .911 r
.80633 .37513 .81377 .38525 .83124 .37818 .82386 .36781 Mtetra
.656 .752 .92 r
.82386 .36781 .83124 .37818 .84896 .37256 .84165 .36211 Mtetra
.84165 .36211 .84896 .37256 .86678 .36688 .85955 .35637 Mtetra
.655 .751 .921 r
.22456 .54738 .23427 .55585 .24862 .5513 .23896 .54278 Mtetra
.655 .751 .92 r
.23896 .54278 .24862 .5513 .26306 .54671 .25344 .53815 Mtetra
.606 .737 .938 r
.25344 .53815 .26306 .54671 .27745 .54369 .26788 .53508 Mtetra
.505 .701 .958 r
.26788 .53508 .27745 .54369 .29177 .54309 .28223 .53444 Mtetra
.455 .68 .962 r
.28223 .53444 .29177 .54309 .30614 .54346 .29664 .53478 Mtetra
.642 .749 .927 r
.29664 .53478 .30614 .54346 .32092 .53922 .31146 .53049 Mtetra
.764 .773 .86 r
.31146 .53049 .32092 .53922 .33611 .52904 .32673 .52025 Mtetra
.797 .775 .832 r
.32673 .52025 .33611 .52904 .35149 .51612 .34218 .50725 Mtetra
.756 .772 .866 r
.34218 .50725 .35149 .51612 .36672 .50644 .35747 .49752 Mtetra
.641 .746 .925 r
.35747 .49752 .36672 .50644 .38175 .50218 .37256 .4932 Mtetra
.587 .728 .941 r
.37256 .4932 .38175 .50218 .39681 .49957 .38767 .49055 Mtetra
.615 .738 .934 r
.38767 .49055 .39681 .49957 .41201 .49609 .40291 .48702 Mtetra
.654 .75 .921 r
.40291 .48702 .41201 .49609 .42735 .49128 .4183 .48216 Mtetra
.636 .745 .927 r
.4183 .48216 .42735 .49128 .44275 .48709 .43376 .47792 Mtetra
.639 .746 .926 r
.43376 .47792 .44275 .48709 .45826 .48276 .44932 .47353 Mtetra
.657 .752 .919 r
.44932 .47353 .45826 .48276 .47387 .47771 .46499 .46844 Mtetra
.669 .755 .915 r
.46499 .46844 .47387 .47771 .48957 .47218 .48075 .46284 Mtetra
.64 .746 .926 r
.48075 .46284 .48957 .47218 .50535 .46772 .49659 .45834 Mtetra
.633 .744 .928 r
.49659 .45834 .50535 .46772 .52123 .46348 .51253 .45405 Mtetra
.656 .751 .92 r
.51253 .45405 .52123 .46348 .53721 .45839 .52857 .44889 Mtetra
.677 .758 .912 r
.52857 .44889 .53721 .45839 .55327 .45242 .5447 .44287 Mtetra
.671 .756 .915 r
.5447 .44287 .55327 .45242 .56943 .44667 .56091 .43706 Mtetra
.642 .746 .925 r
.56091 .43706 .56943 .44667 .58569 .442 .57724 .43234 Mtetra
.654 .751 .921 r
.57724 .43234 .58569 .442 .60204 .43684 .59365 .42712 Mtetra
.671 .757 .914 r
.59365 .42712 .60204 .43684 .61847 .43096 .61015 .42118 Mtetra
.674 .757 .913 r
.61015 .42118 .61847 .43096 .63499 .42493 .62673 .41509 Mtetra
.658 .752 .919 r
.62673 .41509 .63499 .42493 .65162 .41952 .64343 .40962 Mtetra
.69 .763 .908 r
.64343 .40962 .65162 .41952 .66829 .41274 .66017 .40278 Mtetra
.708 .769 .9 r
.66017 .40278 .66829 .41274 .685 .40506 .67696 .39504 Mtetra
.67 .756 .915 r
.67696 .39504 .685 .40506 .70188 .39907 .69391 .38898 Mtetra
.504 .683 .947 r
.69391 .38898 .70188 .39907 .7192 .39865 .71129 .38851 Mtetra
.369 .611 .943 r
.71129 .38851 .7192 .39865 .7369 .40161 .72904 .39143 Mtetra
.482 .673 .948 r
.72904 .39143 .7369 .40161 .75459 .40177 .7468 .39155 Mtetra
.666 .757 .918 r
.7468 .39155 .75459 .40177 .77199 .39578 .76427 .38549 Mtetra
.76 .789 .877 r
.76427 .38549 .77199 .39578 .78909 .38496 .78146 .37459 Mtetra
.743 .784 .886 r
.78146 .37459 .78909 .38496 .80633 .37513 .79878 .36469 Mtetra
.694 .766 .908 r
.79878 .36469 .80633 .37513 .82386 .36781 .8164 .3573 Mtetra
.656 .752 .92 r
.8164 .3573 .82386 .36781 .84165 .36211 .83427 .35154 Mtetra
.83427 .35154 .84165 .36211 .85955 .35637 .85224 .34574 Mtetra
.655 .751 .921 r
.21475 .53881 .22456 .54738 .23896 .54278 .2292 .53417 Mtetra
.656 .751 .92 r
.2292 .53417 .23896 .54278 .25344 .53815 .24373 .52947 Mtetra
.612 .739 .936 r
.24373 .52947 .25344 .53815 .26788 .53508 .25822 .52619 Mtetra
.516 .701 .954 r
.25822 .52619 .26788 .53508 .28223 .53444 .27262 .52534 Mtetra
.458 .673 .956 r
.27262 .52534 .28223 .53444 .29664 .53478 .28705 .52573 Mtetra
.63 .739 .926 r
.28705 .52573 .29664 .53478 .31146 .53049 .3019 .52182 Mtetra
.758 .775 .868 r
.3019 .52182 .31146 .53049 .32673 .52025 .3172 .51201 Mtetra
.803 .787 .838 r
.3172 .51201 .32673 .52025 .34218 .50725 .33273 .49888 Mtetra
.764 .785 .87 r
.33273 .49888 .34218 .50725 .35747 .49752 .34811 .48879 Mtetra
.655 .757 .925 r
.34811 .48879 .35747 .49752 .37256 .4932 .36328 .48391 Mtetra
.589 .724 .937 r
.36328 .48391 .37256 .4932 .38767 .49055 .37843 .48119 Mtetra
.611 .731 .931 r
.37843 .48119 .38767 .49055 .40291 .48702 .39372 .4778 Mtetra
.652 .749 .92 r
.39372 .4778 .40291 .48702 .4183 .48216 .40917 .47293 Mtetra
.639 .746 .926 r
.40917 .47293 .4183 .48216 .43376 .47792 .42468 .4685 Mtetra
.638 .742 .924 r
.42468 .4685 .43376 .47792 .44932 .47353 .4403 .46411 Mtetra
.651 .747 .92 r
.4403 .46411 .44932 .47353 .46499 .46844 .45602 .45922 Mtetra
.67 .759 .917 r
.45602 .45922 .46499 .46844 .48075 .46284 .47184 .45354 Mtetra
.654 .754 .923 r
.47184 .45354 .48075 .46284 .49659 .45834 .48775 .44844 Mtetra
.646 .739 .917 r
.48775 .44844 .49659 .45834 .51253 .45405 .50374 .44367 Mtetra
.656 .733 .906 r
.50374 .44367 .51253 .45405 .52857 .44889 .51984 .43846 Mtetra
.666 .736 .903 r
.51984 .43846 .52857 .44889 .5447 .44287 .53603 .43281 Mtetra
.658 .743 .913 r
.53603 .43281 .5447 .44287 .56091 .43706 .55231 .42748 Mtetra
.641 .749 .927 r
.55231 .42748 .56091 .43706 .57724 .43234 .5687 .42273 Mtetra
.661 .757 .921 r
.5687 .42273 .57724 .43234 .59365 .42712 .58517 .41719 Mtetra
.672 .755 .912 r
.58517 .41719 .59365 .42712 .61015 .42118 .60173 .41115 Mtetra
.671 .753 .912 r
.60173 .41115 .61015 .42118 .62673 .41509 .61839 .40513 Mtetra
.659 .752 .919 r
.61839 .40513 .62673 .41509 .64343 .40962 .63516 .39956 Mtetra
.694 .763 .905 r
.63516 .39956 .64343 .40962 .66017 .40278 .65196 .39246 Mtetra
.707 .763 .896 r
.65196 .39246 .66017 .40278 .67696 .39504 .66882 .38467 Mtetra
.658 .746 .915 r
.66882 .38467 .67696 .39504 .69391 .38898 .68587 .37908 Mtetra
.489 .683 .953 r
.68587 .37908 .69391 .38898 .71129 .38851 .70333 .37886 Mtetra
.349 .615 .95 r
.70333 .37886 .71129 .38851 .72904 .39143 .72114 .38181 Mtetra
.491 .694 .958 r
.72114 .38181 .72904 .39143 .7468 .39155 .73893 .38137 Mtetra
.677 .764 .917 r
.73893 .38137 .7468 .39155 .76427 .38549 .75644 .3748 Mtetra
.76 .783 .872 r
.75644 .3748 .76427 .38549 .78146 .37459 .77371 .36374 Mtetra
.738 .774 .882 r
.77371 .36374 .78146 .37459 .79878 .36469 .79113 .35393 Mtetra
.689 .761 .906 r
.79113 .35393 .79878 .36469 .8164 .3573 .80884 .34666 Mtetra
.656 .751 .92 r
.80884 .34666 .8164 .3573 .83427 .35154 .82679 .34085 Mtetra
.657 .752 .92 r
.82679 .34085 .83427 .35154 .85224 .34574 .84485 .33497 Mtetra
.654 .751 .921 r
.20485 .53014 .21475 .53881 .2292 .53417 .21934 .52547 Mtetra
.656 .751 .92 r
.21934 .52547 .2292 .53417 .24373 .52947 .23391 .5207 Mtetra
.623 .742 .932 r
.23391 .5207 .24373 .52947 .25822 .52619 .24848 .51704 Mtetra
.529 .702 .949 r
.24848 .51704 .25822 .52619 .27262 .52534 .26293 .51591 Mtetra
.463 .668 .952 r
.26293 .51591 .27262 .52534 .28705 .52573 .27739 .51627 Mtetra
.605 .724 .929 r
.27739 .51627 .28705 .52573 .3019 .52182 .29223 .51314 Mtetra
.742 .775 .88 r
.29223 .51314 .3019 .52182 .3172 .51201 .30753 .50427 Mtetra
.807 .799 .845 r
.30753 .50427 .3172 .51201 .33273 .49888 .32315 .49111 Mtetra
.777 .8 .872 r
.32315 .49111 .33273 .49888 .34811 .48879 .33863 .48037 Mtetra
.683 .774 .92 r
.33863 .48037 .34811 .48879 .36328 .48391 .35391 .47437 Mtetra
.594 .722 .933 r
.35391 .47437 .36328 .48391 .37843 .48119 .36912 .4715 Mtetra
.604 .723 .929 r
.36912 .4715 .37843 .48119 .39372 .4778 .38444 .4683 Mtetra
.646 .743 .92 r
.38444 .4683 .39372 .4778 .40917 .47293 .39993 .46361 Mtetra
.647 .748 .923 r
.39993 .46361 .40917 .47293 .42468 .4685 .41551 .45886 Mtetra
.637 .739 .922 r
.41551 .45886 .42468 .4685 .4403 .46411 .43118 .45444 Mtetra
.645 .742 .92 r
.43118 .45444 .4403 .46411 .45602 .45922 .44695 .44972 Mtetra
.66 .752 .918 r
.44695 .44972 .45602 .45922 .47184 .45354 .46283 .4444 Mtetra
.666 .763 .923 r
.46283 .4444 .47184 .45354 .48775 .44844 .4788 .4388 Mtetra
.659 .751 .918 r
.4788 .4388 .48775 .44844 .50374 .44367 .49486 .43343 Mtetra
.656 .738 .91 r
.49486 .43343 .50374 .44367 .51984 .43846 .51101 .42816 Mtetra
.653 .737 .911 r
.51101 .42816 .51984 .43846 .53603 .43281 .52726 .42299 Mtetra
.646 .746 .923 r
.52726 .42299 .53603 .43281 .55231 .42748 .54361 .41806 Mtetra
.652 .759 .928 r
.54361 .41806 .55231 .42748 .5687 .42273 .56006 .41284 Mtetra
.667 .754 .916 r
.56006 .41284 .5687 .42273 .58517 .41719 .5766 .40701 Mtetra
.673 .752 .91 r
.5766 .40701 .58517 .41719 .60173 .41115 .59323 .40087 Mtetra
.664 .748 .913 r
.59323 .40087 .60173 .41115 .61839 .40513 .60995 .39507 Mtetra
.665 .754 .917 r
.60995 .39507 .61839 .40513 .63516 .39956 .62678 .38919 Mtetra
.698 .76 .9 r
.62678 .38919 .63516 .39956 .65196 .39246 .64365 .38179 Mtetra
.704 .757 .893 r
.64365 .38179 .65196 .39246 .66882 .38467 .66059 .37404 Mtetra
.63 .732 .921 r
.66059 .37404 .66882 .38467 .68587 .37908 .67776 .36949 Mtetra
.458 .678 .959 r
.67776 .36949 .68587 .37908 .70333 .37886 .69531 .36983 Mtetra
.329 .622 .957 r
.69531 .36983 .70333 .37886 .72114 .38181 .71318 .37269 Mtetra
.521 .724 .966 r
.71318 .37269 .72114 .38181 .73893 .38137 .73097 .37115 Mtetra
.696 .773 .911 r
.73097 .37115 .73893 .38137 .75644 .3748 .74851 .36365 Mtetra
.758 .776 .868 r
.74851 .36365 .75644 .3748 .77371 .36374 .76585 .35251 Mtetra
.732 .767 .881 r
.76585 .35251 .77371 .36374 .79113 .35393 .78338 .34289 Mtetra
.682 .754 .906 r
.78338 .34289 .79113 .35393 .80884 .34666 .8012 .33588 Mtetra
.655 .751 .92 r
.8012 .33588 .80884 .34666 .82679 .34085 .81923 .33003 Mtetra
.657 .752 .92 r
.81923 .33003 .82679 .34085 .84485 .33497 .83737 .32406 Mtetra
.653 .75 .921 r
.19484 .52136 .20485 .53014 .21934 .52547 .20937 .51667 Mtetra
.656 .751 .92 r
.20937 .51667 .21934 .52547 .23391 .5207 .22399 .51186 Mtetra
.637 .746 .928 r
.22399 .51186 .23391 .5207 .24848 .51704 .23864 .50769 Mtetra
.545 .705 .945 r
.23864 .50769 .24848 .51704 .26293 .51591 .25317 .50616 Mtetra
.474 .668 .948 r
.25317 .50616 .26293 .51591 .27739 .51627 .26767 .50632 Mtetra
.569 .702 .932 r
.26767 .50632 .27739 .51627 .29223 .51314 .28246 .50427 Mtetra
.714 .769 .896 r
.28246 .50427 .29223 .51314 .30753 .50427 .29772 .49686 Mtetra
.804 .808 .854 r
.29772 .49686 .30753 .50427 .32315 .49111 .31339 .48413 Mtetra
.794 .819 .872 r
.31339 .48413 .32315 .49111 .33863 .48037 .32901 .47245 Mtetra
.72 .795 .91 r
.32901 .47245 .33863 .48037 .35391 .47437 .34444 .4648 Mtetra
.608 .728 .931 r
.34444 .4648 .35391 .47437 .36912 .4715 .35971 .46143 Mtetra
.602 .716 .925 r
.35971 .46143 .36912 .4715 .38444 .4683 .37508 .45828 Mtetra
.63 .729 .918 r
.37508 .45828 .38444 .4683 .39993 .46361 .3906 .45415 Mtetra
.655 .75 .92 r
.3906 .45415 .39993 .46361 .41551 .45886 .40624 .44906 Mtetra
.64 .739 .92 r
.40624 .44906 .41551 .45886 .43118 .45444 .42197 .44449 Mtetra
.642 .737 .918 r
.42197 .44449 .43118 .45444 .44695 .44972 .43779 .43984 Mtetra
.648 .742 .918 r
.43779 .43984 .44695 .44972 .46283 .4444 .45372 .43491 Mtetra
.655 .754 .923 r
.45372 .43491 .46283 .4444 .4788 .4388 .46974 .42966 Mtetra
.66 .765 .928 r
.46974 .42966 .4788 .4388 .49486 .43343 .48587 .42421 Mtetra
.655 .763 .929 r
.48587 .42421 .49486 .43343 .51101 .42816 .50209 .41888 Mtetra
.651 .762 .93 r
.50209 .41888 .51101 .42816 .52726 .42299 .5184 .41368 Mtetra
.656 .764 .929 r
.5184 .41368 .52726 .42299 .54361 .41806 .53481 .40827 Mtetra
.663 .757 .92 r
.53481 .40827 .54361 .41806 .56006 .41284 .55132 .40255 Mtetra
.67 .749 .91 r
.55132 .40255 .56006 .41284 .5766 .40701 .56793 .39653 Mtetra
.67 .747 .908 r
.56793 .39653 .5766 .40701 .59323 .40087 .58462 .39043 Mtetra
.657 .744 .914 r
.58462 .39043 .59323 .40087 .60995 .39507 .60142 .38485 Mtetra
.68 .758 .911 r
.60142 .38485 .60995 .39507 .62678 .38919 .6183 .3783 Mtetra
.699 .752 .893 r
.6183 .3783 .62678 .38919 .64365 .38179 .63524 .37073 Mtetra
.694 .748 .893 r
.63524 .37073 .64365 .38179 .66059 .37404 .65226 .36336 Mtetra
.585 .714 .933 r
.65226 .36336 .66059 .37404 .67776 .36949 .66957 .36038 Mtetra
.405 .666 .966 r
.66957 .36038 .67776 .36949 .69531 .36983 .68724 .36157 Mtetra
.325 .644 .967 r
.68724 .36157 .69531 .36983 .71318 .37269 .70515 .36389 Mtetra
.572 .759 .967 r
.70515 .36389 .71318 .37269 .73097 .37115 .72292 .36072 Mtetra
.719 .779 .9 r
.72292 .36072 .73097 .37115 .74851 .36365 .74045 .35198 Mtetra
.753 .767 .864 r
.74045 .35198 .74851 .36365 .76585 .35251 .7579 .34092 Mtetra
.725 .76 .881 r
.7579 .34092 .76585 .35251 .78338 .34289 .77553 .3316 Mtetra
.671 .747 .908 r
.77553 .3316 .78338 .34289 .8012 .33588 .79347 .32501 Mtetra
.655 .751 .92 r
.79347 .32501 .8012 .33588 .81923 .33003 .81158 .31908 Mtetra
.658 .752 .92 r
.81158 .31908 .81923 .33003 .83737 .32406 .8298 .31301 Mtetra
.652 .749 .921 r
.18472 .51248 .19484 .52136 .20937 .51667 .1993 .50779 Mtetra
.655 .751 .92 r
.1993 .50779 .20937 .51667 .22399 .51186 .21397 .50296 Mtetra
.648 .75 .924 r
.21397 .50296 .22399 .51186 .23864 .50769 .2287 .49838 Mtetra
.571 .718 .942 r
.2287 .49838 .23864 .50769 .25317 .50616 .24331 .49613 Mtetra
.496 .673 .943 r
.24331 .49613 .25317 .50616 .26767 .50632 .25788 .49583 Mtetra
.524 .675 .933 r
.25788 .49583 .26767 .50632 .28246 .50427 .27261 .49499 Mtetra
.68 .755 .908 r
.27261 .49499 .28246 .50427 .29772 .49686 .28783 .48902 Mtetra
.782 .801 .868 r
.28783 .48902 .29772 .49686 .31339 .48413 .30348 .47775 Mtetra
.808 .834 .87 r
.30348 .47775 .31339 .48413 .32901 .47245 .31924 .46522 Mtetra
.757 .817 .899 r
.31924 .46522 .32901 .47245 .34444 .4648 .33483 .45576 Mtetra
.647 .755 .928 r
.33483 .45576 .34444 .4648 .35971 .46143 .35023 .45099 Mtetra
.601 .71 .921 r
.35023 .45099 .35971 .46143 .37508 .45828 .36564 .44786 Mtetra
.613 .716 .919 r
.36564 .44786 .37508 .45828 .3906 .45415 .38118 .4443 Mtetra
.646 .741 .918 r
.38118 .4443 .3906 .45415 .40624 .44906 .39687 .43947 Mtetra
.653 .75 .921 r
.39687 .43947 .40624 .44906 .42197 .44449 .41266 .43435 Mtetra
.643 .736 .916 r
.41266 .43435 .42197 .44449 .43779 .43984 .42854 .4296 Mtetra
.645 .735 .915 r
.42854 .4296 .43779 .43984 .45372 .43491 .44452 .42474 Mtetra
.65 .74 .915 r
.44452 .42474 .45372 .43491 .46974 .42966 .4606 .41966 Mtetra
.653 .746 .918 r
.4606 .41966 .46974 .42966 .48587 .42421 .47678 .41441 Mtetra
.656 .753 .921 r
.47678 .41441 .48587 .42421 .50209 .41888 .49306 .40902 Mtetra
.658 .753 .92 r
.49306 .40902 .50209 .41888 .5184 .41368 .50944 .4035 Mtetra
.662 .749 .915 r
.50944 .4035 .5184 .41368 .53481 .40827 .52592 .39781 Mtetra
.666 .745 .909 r
.52592 .39781 .53481 .40827 .55132 .40255 .54249 .39189 Mtetra
.668 .743 .906 r
.54249 .39189 .55132 .40255 .56793 .39653 .55916 .38585 Mtetra
.659 .741 .911 r
.55916 .38585 .56793 .39653 .58462 .39043 .57593 .38019 Mtetra
.665 .754 .916 r
.57593 .38019 .58462 .39043 .60142 .38485 .59279 .37423 Mtetra
.693 .757 .9 r
.59279 .37423 .60142 .38485 .6183 .3783 .60972 .36697 Mtetra
.7 .746 .887 r
.60972 .36697 .6183 .3783 .63524 .37073 .62672 .35926 Mtetra
.664 .732 .9 r
.62672 .35926 .63524 .37073 .65226 .36336 .64387 .35322 Mtetra
.52 .7 .952 r
.64387 .35322 .65226 .36336 .66957 .36038 .66133 .35198 Mtetra
.343 .653 .969 r
.66133 .35198 .66957 .36038 .68724 .36157 .6791 .35393 Mtetra
.383 .697 .982 r
.6791 .35393 .68724 .36157 .70515 .36389 .697 .35461 Mtetra
.623 .771 .951 r
.697 .35461 .70515 .36389 .72292 .36072 .71475 .34984 Mtetra
.742 .779 .883 r
.71475 .34984 .72292 .36072 .74045 .35198 .73228 .33973 Mtetra
.744 .755 .862 r
.73228 .33973 .74045 .35198 .7579 .34092 .74984 .32902 Mtetra
.711 .752 .884 r
.74984 .32902 .7579 .34092 .77553 .3316 .76761 .32031 Mtetra
.663 .747 .913 r
.76761 .32031 .77553 .3316 .79347 .32501 .78566 .31404 Mtetra
.656 .752 .921 r
.78566 .31404 .79347 .32501 .81158 .31908 .80385 .30801 Mtetra
.659 .753 .919 r
.80385 .30801 .81158 .31908 .8298 .31301 .82214 .30182 Mtetra
.651 .749 .921 r
.17451 .50351 .18472 .51248 .1993 .50779 .18913 .49881 Mtetra
.655 .751 .921 r
.18913 .49881 .1993 .50779 .21397 .50296 .20384 .49395 Mtetra
.654 .751 .921 r
.20384 .49395 .21397 .50296 .2287 .49838 .21864 .48907 Mtetra
.602 .731 .935 r
.21864 .48907 .2287 .49838 .24331 .49613 .23337 .4859 Mtetra
.528 .684 .937 r
.23337 .4859 .24331 .49613 .25788 .49583 .24803 .48484 Mtetra
.498 .655 .929 r
.24803 .48484 .25788 .49583 .27261 .49499 .26273 .48469 Mtetra
.628 .721 .914 r
.26273 .48469 .27261 .49499 .28783 .48902 .27784 .48069 Mtetra
.744 .791 .89 r
.27784 .48069 .28783 .48902 .30348 .47775 .29341 .4717 Mtetra
.812 .842 .873 r
.29341 .4717 .30348 .47775 .31924 .46522 .30927 .459 Mtetra
.785 .843 .895 r
.30927 .459 .31924 .46522 .33483 .45576 .32503 .44813 Mtetra
.711 .805 .924 r
.32503 .44813 .33483 .45576 .35023 .45099 .34063 .4408 Mtetra
.618 .724 .922 r
.34063 .4408 .35023 .45099 .36564 .44786 .35612 .43701 Mtetra
.609 .708 .914 r
.35612 .43701 .36564 .44786 .38118 .4443 .37169 .43355 Mtetra
.622 .716 .913 r
.37169 .43355 .38118 .4443 .39687 .43947 .38739 .42959 Mtetra
.651 .745 .919 r
.38739 .42959 .39687 .43947 .41266 .43435 .40324 .4245 Mtetra
.656 .749 .918 r
.40324 .4245 .41266 .43435 .42854 .4296 .41919 .4192 Mtetra
.648 .735 .913 r
.41919 .4192 .42854 .4296 .44452 .42474 .43523 .41418 Mtetra
.649 .734 .911 r
.43523 .41418 .44452 .42474 .4606 .41966 .45137 .40907 Mtetra
.652 .735 .91 r
.45137 .40907 .4606 .41966 .47678 .41441 .46761 .4038 Mtetra
.656 .738 .91 r
.46761 .4038 .47678 .41441 .49306 .40902 .48395 .39836 Mtetra
.659 .739 .908 r
.48395 .39836 .49306 .40902 .50944 .4035 .50039 .39273 Mtetra
.663 .739 .907 r
.50039 .39273 .50944 .4035 .52592 .39781 .51693 .38694 Mtetra
.664 .739 .906 r
.51693 .38694 .52592 .39781 .54249 .39189 .53356 .38107 Mtetra
.656 .738 .91 r
.53356 .38107 .54249 .39189 .55916 .38585 .5503 .37547 Mtetra
.661 .75 .916 r
.5503 .37547 .55916 .38585 .57593 .38019 .56713 .36965 Mtetra
.687 .757 .905 r
.56713 .36965 .57593 .38019 .59279 .37423 .58405 .36268 Mtetra
.694 .741 .887 r
.58405 .36268 .59279 .37423 .60972 .36697 .60104 .3552 Mtetra
.687 .735 .888 r
.60104 .3552 .60972 .36697 .62672 .35926 .61813 .34803 Mtetra
.599 .713 .924 r
.61813 .34803 .62672 .35926 .64387 .35322 .63544 .34449 Mtetra
.437 .698 .975 r
.63544 .34449 .64387 .35322 .66133 .35198 .65302 .34459 Mtetra
.297 .656 .971 r
.65302 .34459 .66133 .35198 .6791 .35393 .67087 .3466 Mtetra
.487 .763 .992 r
.67087 .3466 .6791 .35393 .697 .35461 .68872 .34482 Mtetra
.68 .783 .928 r
.68872 .34482 .697 .35461 .71475 .34984 .70644 .33788 Mtetra
.749 .763 .864 r
.70644 .33788 .71475 .34984 .73228 .33973 .724 .32692 Mtetra
.73 .743 .862 r
.724 .32692 .73228 .33973 .74984 .32902 .74168 .31688 Mtetra
.694 .743 .889 r
.74168 .31688 .74984 .32902 .76761 .32031 .7596 .30902 Mtetra
.657 .747 .916 r
.7596 .30902 .76761 .32031 .78566 .31404 .77775 .30292 Mtetra
.657 .752 .92 r
.77775 .30292 .78566 .31404 .80385 .30801 .79602 .2968 Mtetra
.66 .753 .919 r
.79602 .2968 .80385 .30801 .82214 .30182 .81439 .29049 Mtetra
.65 .749 .922 r
.16418 .49443 .17451 .50351 .18913 .49881 .17885 .48972 Mtetra
.655 .75 .92 r
.17885 .48972 .18913 .49881 .20384 .49395 .19361 .48481 Mtetra
.656 .751 .92 r
.19361 .48481 .20384 .49395 .21864 .48907 .20846 .47981 Mtetra
.633 .743 .928 r
.20846 .47981 .21864 .48907 .23337 .4859 .22333 .47561 Mtetra
.557 .696 .933 r
.22333 .47561 .23337 .4859 .24803 .48484 .23808 .47378 Mtetra
.504 .658 .929 r
.23808 .47378 .24803 .48484 .26273 .48469 .25282 .47344 Mtetra
.563 .68 .917 r
.25282 .47344 .26273 .48469 .27784 .48069 .26781 .47155 Mtetra
.69 .766 .909 r
.26781 .47155 .27784 .48069 .29341 .4717 .28325 .46501 Mtetra
.786 .832 .887 r
.28325 .46501 .29341 .4717 .30927 .459 .29909 .45385 Mtetra
.808 .867 .891 r
.29909 .45385 .30927 .459 .32503 .44813 .31503 .4417 Mtetra
.76 .841 .913 r
.31503 .4417 .32503 .44813 .34063 .4408 .33083 .43213 Mtetra
.677 .778 .926 r
.33083 .43213 .34063 .4408 .35612 .43701 .3465 .42608 Mtetra
.616 .711 .913 r
.3465 .42608 .35612 .43701 .37169 .43355 .36213 .42233 Mtetra
.618 .707 .909 r
.36213 .42233 .37169 .43355 .38739 .42959 .37787 .4185 Mtetra
.627 .714 .909 r
.37787 .4185 .38739 .42959 .40324 .4245 .39373 .41428 Mtetra
.647 .74 .917 r
.39373 .41428 .40324 .4245 .41919 .4192 .40973 .40924 Mtetra
.655 .75 .919 r
.40973 .40924 .41919 .4192 .43523 .41418 .42584 .40388 Mtetra
.656 .744 .914 r
.42584 .40388 .43523 .41418 .45137 .40907 .44204 .39844 Mtetra
.656 .738 .91 r
.44204 .39844 .45137 .40907 .46761 .4038 .45834 .39297 Mtetra
.656 .735 .908 r
.45834 .39297 .46761 .4038 .48395 .39836 .47474 .38746 Mtetra
.47474 .38746 .48395 .39836 .50039 .39273 .49124 .38191 Mtetra
.656 .738 .91 r
.49124 .38191 .50039 .39273 .51693 .38694 .50784 .37633 Mtetra
.657 .744 .914 r
.50784 .37633 .51693 .38694 .53356 .38107 .52454 .37068 Mtetra
.664 .753 .916 r
.52454 .37068 .53356 .38107 .5503 .37547 .54134 .3647 Mtetra
.682 .752 .904 r
.54134 .3647 .5503 .37547 .56713 .36965 .55823 .35788 Mtetra
.688 .735 .887 r
.55823 .35788 .56713 .36965 .58405 .36268 .57521 .35065 Mtetra
.688 .732 .884 r
.57521 .35065 .58405 .36268 .60104 .3552 .59227 .34333 Mtetra
.637 .717 .905 r
.59227 .34333 .60104 .3552 .61813 .34803 .60949 .33836 Mtetra
.513 .713 .962 r
.60949 .33836 .61813 .34803 .63544 .34449 .62694 .33699 Mtetra
.337 .678 .978 r
.62694 .33699 .63544 .34449 .65302 .34459 .64465 .33828 Mtetra
.345 .716 .985 r
.64465 .33828 .65302 .34459 .67087 .3466 .6625 .3386 Mtetra
.599 .798 .975 r
.6625 .3386 .67087 .3466 .68872 .34482 .68031 .33415 Mtetra
.726 .782 .897 r
.68031 .33415 .68872 .34482 .70644 .33788 .69798 .32491 Mtetra
.742 .745 .855 r
.69798 .32491 .70644 .33788 .724 .32692 .71563 .31402 Mtetra
.718 .739 .869 r
.71563 .31402 .724 .32692 .74168 .31688 .73344 .30465 Mtetra
.674 .736 .897 r
.73344 .30465 .74168 .31688 .7596 .30902 .75151 .29774 Mtetra
.655 .749 .919 r
.75151 .29774 .7596 .30902 .77775 .30292 .76975 .29164 Mtetra
.657 .751 .92 r
.76975 .29164 .77775 .30292 .79602 .2968 .7881 .28544 Mtetra
.661 .753 .918 r
.7881 .28544 .79602 .2968 .81439 .29049 .80655 .27903 Mtetra
.652 .75 .922 r
.15375 .48529 .16418 .49443 .17885 .48972 .16846 .48047 Mtetra
.653 .749 .92 r
.16846 .48047 .17885 .48972 .19361 .48481 .18327 .47558 Mtetra
.655 .751 .92 r
.18327 .47558 .19361 .48481 .20846 .47981 .19816 .47058 Mtetra
.651 .751 .923 r
.19816 .47058 .20846 .47981 .22333 .47561 .21314 .46569 Mtetra
.593 .719 .932 r
.21314 .46569 .22333 .47561 .23808 .47378 .22802 .4627 Mtetra
.536 .674 .926 r
.22802 .4627 .23808 .47378 .25282 .47344 .24286 .46147 Mtetra
.52 .649 .915 r
.24286 .46147 .25282 .47344 .26781 .47155 .25778 .46085 Mtetra
.625 .717 .913 r
.25778 .46085 .26781 .47155 .28325 .46501 .27308 .45682 Mtetra
.725 .797 .908 r
.27308 .45682 .28325 .46501 .29909 .45385 .28877 .44871 Mtetra
.803 .87 .897 r
.28877 .44871 .29909 .45385 .31503 .4417 .30478 .43686 Mtetra
.793 .88 .91 r
.30478 .43686 .31503 .4417 .33083 .43213 .32078 .42563 Mtetra
.744 .842 .925 r
.32078 .42563 .33083 .43213 .3465 .42608 .33668 .41676 Mtetra
.668 .764 .922 r
.33668 .41676 .3465 .42608 .36213 .42233 .35247 .41095 Mtetra
.624 .708 .906 r
.35247 .41095 .36213 .42233 .37787 .4185 .36827 .40683 Mtetra
.623 .703 .902 r
.36827 .40683 .37787 .4185 .39373 .41428 .38417 .40271 Mtetra
.632 .709 .902 r
.38417 .40271 .39373 .41428 .40973 .40924 .4002 .39824 Mtetra
.639 .725 .91 r
.4002 .39824 .40973 .40924 .42584 .40388 .41634 .39342 Mtetra
.65 .741 .916 r
.41634 .39342 .42584 .40388 .44204 .39844 .43259 .38816 Mtetra
.655 .748 .918 r
.43259 .38816 .44204 .39844 .45834 .39297 .44896 .38268 Mtetra
.656 .749 .918 r
.44896 .38268 .45834 .39297 .47474 .38746 .46542 .37711 Mtetra
.657 .75 .918 r
.46542 .37711 .47474 .38746 .49124 .38191 .48198 .37146 Mtetra
.662 .75 .915 r
.48198 .37146 .49124 .38191 .50784 .37633 .49865 .36557 Mtetra
.672 .748 .908 r
.49865 .36557 .50784 .37633 .52454 .37068 .51541 .35923 Mtetra
.678 .738 .896 r
.51541 .35923 .52454 .37068 .54134 .3647 .53228 .35255 Mtetra
.683 .728 .884 r
.53228 .35255 .54134 .3647 .55823 .35788 .54923 .3455 Mtetra
.682 .724 .882 r
.54923 .3455 .55823 .35788 .57521 .35065 .56627 .33844 Mtetra
.645 .714 .898 r
.56627 .33844 .57521 .35065 .59227 .34333 .58344 .33309 Mtetra
.548 .717 .951 r
.58344 .33309 .59227 .34333 .60949 .33836 .6008 .33087 Mtetra
.389 .71 .986 r
.6008 .33087 .60949 .33836 .62694 .33699 .61837 .33109 Mtetra
.29 .696 .973 r
.61837 .33109 .62694 .33699 .64465 .33828 .63615 .33197 Mtetra
.509 .804 .999 r
.63615 .33197 .64465 .33828 .6625 .3386 .65396 .32901 Mtetra
.683 .793 .933 r
.65396 .32901 .6625 .3386 .68031 .33415 .67173 .32187 Mtetra
.742 .758 .866 r
.67173 .32187 .68031 .33415 .69798 .32491 .68941 .31117 Mtetra
.725 .729 .854 r
.68941 .31117 .69798 .32491 .71563 .31402 .70718 .30107 Mtetra
.698 .733 .878 r
.70718 .30107 .71563 .31402 .73344 .30465 .72514 .29278 Mtetra
.66 .74 .909 r
.72514 .29278 .73344 .30465 .75151 .29774 .74334 .28646 Mtetra
.657 .753 .921 r
.74334 .28646 .75151 .29774 .76975 .29164 .76165 .28024 Mtetra
.659 .752 .919 r
.76165 .28024 .76975 .29164 .7881 .28544 .78008 .27389 Mtetra
.66 .751 .918 r
.78008 .27389 .7881 .28544 .80655 .27903 .79862 .26746 Mtetra
.655 .752 .921 r
.14319 .47614 .15375 .48529 .16846 .48047 .15797 .47112 Mtetra
.65 .748 .921 r
.15797 .47112 .16846 .48047 .18327 .47558 .17281 .46626 Mtetra
.655 .751 .92 r
.17281 .46626 .18327 .47558 .19816 .47058 .18776 .4612 Mtetra
.656 .751 .92 r
.18776 .4612 .19816 .47058 .21314 .46569 .2028 .45606 Mtetra
.633 .741 .926 r
.2028 .45606 .21314 .46569 .22802 .4627 .21785 .45172 Mtetra
.569 .691 .923 r
.21785 .45172 .22802 .4627 .24286 .46147 .23281 .4495 Mtetra
.527 .655 .916 r
.23281 .4495 .24286 .46147 .25778 .46085 .24777 .4486 Mtetra
.551 .66 .908 r
.24777 .4486 .25778 .46085 .27308 .45682 .2629 .44706 Mtetra
.662 .751 .917 r
.2629 .44706 .27308 .45682 .28877 .44871 .27846 .44155 Mtetra
.744 .826 .915 r
.27846 .44155 .28877 .44871 .30478 .43686 .29435 .43258 Mtetra
.798 .894 .912 r
.29435 .43258 .30478 .43686 .32078 .42563 .31047 .42104 Mtetra
.78 .89 .923 r
.31047 .42104 .32078 .42563 .33668 .41676 .32656 .41044 Mtetra
.737 .849 .933 r
.32656 .41044 .33668 .41676 .35247 .41095 .34259 .40179 Mtetra
.681 .775 .922 r
.34259 .40179 .35247 .41095 .36827 .40683 .35856 .39538 Mtetra
.639 .715 .903 r
.35856 .39538 .36827 .40683 .38417 .40271 .37454 .3906 Mtetra
.63 .7 .896 r
.37454 .3906 .38417 .40271 .4002 .39824 .39061 .38613 Mtetra
.637 .704 .895 r
.39061 .38613 .4002 .39824 .41634 .39342 .40679 .38136 Mtetra
.643 .709 .895 r
.40679 .38136 .41634 .39342 .43259 .38816 .42309 .37628 Mtetra
.649 .716 .896 r
.42309 .37628 .43259 .38816 .44896 .38268 .4395 .37093 Mtetra
.655 .721 .897 r
.4395 .37093 .44896 .38268 .46542 .37711 .45602 .3653 Mtetra
.661 .723 .895 r
.45602 .3653 .46542 .37711 .48198 .37146 .47265 .35938 Mtetra
.666 .721 .89 r
.47265 .35938 .48198 .37146 .49865 .36557 .48937 .35318 Mtetra
.671 .719 .885 r
.48937 .35318 .49865 .36557 .51541 .35923 .5062 .34668 Mtetra
.677 .719 .881 r
.5062 .34668 .51541 .35923 .53228 .35255 .52312 .33985 Mtetra
.669 .715 .883 r
.52312 .33985 .53228 .35255 .54923 .3455 .54014 .33334 Mtetra
.632 .712 .904 r
.54014 .33334 .54923 .3455 .56627 .33844 .55727 .32848 Mtetra
.556 .729 .955 r
.55727 .32848 .56627 .33844 .58344 .33309 .57455 .32589 Mtetra
.417 .734 .991 r
.57455 .32589 .58344 .33309 .6008 .33087 .59203 .32533 Mtetra
.297 .711 .974 r
.59203 .32533 .6008 .33087 .61837 .33109 .6097 .32575 Mtetra
.441 .797 .997 r
.6097 .32575 .61837 .33109 .63615 .33197 .62747 .32355 Mtetra
.641 .807 .963 r
.62747 .32355 .63615 .33197 .65396 .32901 .64526 .31781 Mtetra
.733 .777 .888 r
.64526 .31781 .65396 .32901 .67173 .32187 .66299 .30795 Mtetra
.73 .729 .849 r
.66299 .30795 .67173 .32187 .68941 .31117 .68075 .29741 Mtetra
.71 .725 .862 r
.68075 .29741 .68941 .31117 .70718 .30107 .69865 .28821 Mtetra
.672 .727 .891 r
.69865 .28821 .70718 .30107 .72514 .29278 .71677 .28119 Mtetra
.655 .747 .917 r
.71677 .28119 .72514 .29278 .74334 .28646 .73506 .27499 Mtetra
.656 .751 .92 r
.73506 .27499 .74334 .28646 .76165 .28024 .75346 .2687 Mtetra
.661 .753 .919 r
.75346 .2687 .76165 .28024 .78008 .27389 .77196 .26219 Mtetra
.656 .75 .919 r
.77196 .26219 .78008 .27389 .79862 .26746 .7906 .25584 Mtetra
.66 .754 .92 r
.13252 .46691 .14319 .47614 .15797 .47112 .14736 .46169 Mtetra
.651 .749 .921 r
.14736 .46169 .15797 .47112 .17281 .46626 .16226 .45675 Mtetra
.653 .749 .92 r
.16226 .45675 .17281 .46626 .18776 .4612 .17725 .45171 Mtetra
.655 .751 .921 r
.17725 .45171 .18776 .4612 .2028 .45606 .19233 .44658 Mtetra
.654 .752 .922 r
.19233 .44658 .2028 .45606 .21785 .45172 .2075 .44146 Mtetra
.611 .723 .925 r
.2075 .44146 .21785 .45172 .23281 .4495 .22262 .43779 Mtetra
.564 .677 .915 r
.22262 .43779 .23281 .4495 .24777 .4486 .23771 .43572 Mtetra
.533 .642 .903 r
.23771 .43572 .24777 .4486 .2629 .44706 .25282 .43472 Mtetra
.579 .673 .904 r
.25282 .43472 .2629 .44706 .27846 .44155 .26818 .43222 Mtetra
.671 .767 .922 r
.26818 .43222 .27846 .44155 .29435 .43258 .28392 .42624 Mtetra
.742 .848 .929 r
.28392 .42624 .29435 .43258 .31047 .42104 .29994 .41736 Mtetra
.784 .912 .927 r
.29994 .41736 .31047 .42104 .32656 .41044 .31615 .40644 Mtetra
.77 .907 .935 r
.31615 .40644 .32656 .41044 .34259 .40179 .33237 .39613 Mtetra
.734 .868 .943 r
.33237 .39613 .34259 .40179 .35856 .39538 .34855 .38746 Mtetra
.704 .812 .932 r
.34855 .38746 .35856 .39538 .37454 .3906 .36472 .38006 Mtetra
.665 .746 .911 r
.36472 .38006 .37454 .3906 .39061 .38613 .38091 .37416 Mtetra
.648 .713 .895 r
.38091 .37416 .39061 .38613 .40679 .38136 .39716 .36887 Mtetra
.646 .704 .889 r
.39716 .36887 .40679 .38136 .42309 .37628 .41351 .36362 Mtetra
.649 .703 .886 r
.41351 .36362 .42309 .37628 .4395 .37093 .42998 .35818 Mtetra
.654 .705 .884 r
.42998 .35818 .4395 .37093 .45602 .3653 .44655 .35248 Mtetra
.659 .706 .882 r
.44655 .35248 .45602 .3653 .47265 .35938 .46323 .34651 Mtetra
.662 .708 .882 r
.46323 .34651 .47265 .35938 .48937 .35318 .48001 .34036 Mtetra
.661 .709 .884 r
.48001 .34036 .48937 .35318 .5062 .34668 .49689 .33424 Mtetra
.647 .713 .895 r
.49689 .33424 .5062 .34668 .52312 .33985 .51386 .32874 Mtetra
.607 .724 .928 r
.51386 .32874 .52312 .33985 .54014 .33334 .53095 .32475 Mtetra
.543 .758 .977 r
.53095 .32475 .54014 .33334 .55727 .32848 .54818 .32205 Mtetra
.413 .754 .995 r
.54818 .32205 .55727 .32848 .57455 .32589 .56558 .32105 Mtetra
.31 .737 .972 r
.56558 .32105 .57455 .32589 .59203 .32533 .58315 .32069 Mtetra
.425 .806 .991 r
.58315 .32069 .59203 .32533 .6097 .32575 .60084 .31828 Mtetra
.621 .824 .978 r
.60084 .31828 .6097 .32575 .62747 .32355 .61861 .31288 Mtetra
.719 .784 .904 r
.61861 .31288 .62747 .32355 .64526 .31781 .63636 .30391 Mtetra
.73 .73 .85 r
.63636 .30391 .64526 .31781 .66299 .30795 .65413 .29336 Mtetra
.71 .713 .851 r
.65413 .29336 .66299 .30795 .68075 .29741 .67202 .28389 Mtetra
.686 .722 .877 r
.67202 .28389 .68075 .29741 .69865 .28821 .69008 .27605 Mtetra
.657 .738 .909 r
.69008 .27605 .69865 .28821 .71677 .28119 .70832 .26972 Mtetra
.657 .753 .921 r
.70832 .26972 .71677 .28119 .73506 .27499 .72669 .26338 Mtetra
.658 .752 .919 r
.72669 .26338 .73506 .27499 .75346 .2687 .74516 .25694 Mtetra
.66 .751 .917 r
.74516 .25694 .75346 .2687 .77196 .26219 .76375 .25038 Mtetra
.652 .748 .92 r
.76375 .25038 .77196 .26219 .7906 .25584 .78249 .2441 Mtetra
.66 .754 .92 r
.12173 .45758 .13252 .46691 .14736 .46169 .13663 .45228 Mtetra
.656 .753 .921 r
.13663 .45228 .14736 .46169 .16226 .45675 .15159 .44712 Mtetra
.65 .748 .921 r
.15159 .44712 .16226 .45675 .17725 .45171 .16662 .44212 Mtetra
.655 .751 .92 r
.16662 .44212 .17725 .45171 .19233 .44658 .18175 .43692 Mtetra
.656 .751 .92 r
.18175 .43692 .19233 .44658 .2075 .44146 .19699 .43165 Mtetra
.647 .746 .922 r
.19699 .43165 .2075 .44146 .22262 .43779 .21227 .42668 Mtetra
.6 .705 .918 r
.21227 .42668 .22262 .43779 .23771 .43572 .2275 .42336 Mtetra
.567 .669 .907 r
.2275 .42336 .23771 .43572 .25282 .43472 .24274 .42121 Mtetra
.545 .639 .894 r
.24274 .42121 .25282 .43472 .26818 .43222 .25803 .41986 Mtetra
.589 .68 .904 r
.25803 .41986 .26818 .43222 .28392 .42624 .27357 .41693 Mtetra
.667 .77 .927 r
.27357 .41693 .28392 .42624 .29994 .41736 .28944 .41105 Mtetra
.719 .85 .944 r
.28944 .41105 .29994 .41736 .31615 .40644 .30555 .40303 Mtetra
.759 .921 .943 r
.30555 .40303 .31615 .40644 .33237 .39613 .32185 .39302 Mtetra
.754 .929 .946 r
.32185 .39302 .33237 .39613 .34855 .38746 .3382 .38306 Mtetra
.73 .901 .955 r
.3382 .38306 .34855 .38746 .36472 .38006 .35454 .37424 Mtetra
.706 .866 .958 r
.35454 .37424 .36472 .38006 .38091 .37416 .3709 .36648 Mtetra
.689 .82 .945 r
.3709 .36648 .38091 .37416 .39716 .36887 .3873 .35949 Mtetra
.675 .779 .928 r
.3873 .35949 .39716 .36887 .41351 .36362 .40376 .35308 Mtetra
.664 .752 .916 r
.40376 .35308 .41351 .36362 .42998 .35818 .4203 .34705 Mtetra
.656 .739 .91 r
.4203 .34705 .42998 .35818 .44655 .35248 .43693 .34128 Mtetra
.649 .736 .913 r
.43693 .34128 .44655 .35248 .46323 .34651 .45366 .33578 Mtetra
.638 .743 .925 r
.45366 .33578 .46323 .34651 .48001 .34036 .47049 .33066 Mtetra
.617 .76 .947 r
.47049 .33066 .48001 .34036 .49689 .33424 .48742 .32613 Mtetra
.577 .785 .977 r
.48742 .32613 .49689 .33424 .51386 .32874 .50447 .32237 Mtetra
.497 .797 .999 r
.50447 .32237 .51386 .32874 .53095 .32475 .52165 .31972 Mtetra
.388 .777 .989 r
.52165 .31972 .53095 .32475 .54818 .32205 .53898 .31822 Mtetra
.328 .769 .964 r
.53898 .31822 .54818 .32205 .56558 .32105 .55647 .3168 Mtetra
.466 .836 .991 r
.55647 .3168 .56558 .32105 .58315 .32069 .57409 .31336 Mtetra
.626 .83 .979 r
.57409 .31336 .58315 .32069 .60084 .31828 .5918 .30774 Mtetra
.712 .786 .909 r
.5918 .30774 .60084 .31828 .61861 .31288 .60955 .29909 Mtetra
.727 .732 .854 r
.60955 .29909 .61861 .31288 .63636 .30391 .62734 .28878 Mtetra
.707 .705 .845 r
.62734 .28878 .63636 .30391 .65413 .29336 .64522 .27929 Mtetra
.692 .717 .868 r
.64522 .27929 .65413 .29336 .67202 .28389 .66324 .27097 Mtetra
.662 .726 .897 r
.66324 .27097 .67202 .28389 .69008 .27605 .68143 .26435 Mtetra
.655 .749 .918 r
.68143 .26435 .69008 .27605 .70832 .26972 .69976 .25803 Mtetra
.657 .751 .919 r
.69976 .25803 .70832 .26972 .72669 .26338 .71821 .25163 Mtetra
.661 .753 .918 r
.71821 .25163 .72669 .26338 .74516 .25694 .73676 .24501 Mtetra
.656 .749 .918 r
.73676 .24501 .74516 .25694 .76375 .25038 .75545 .23855 Mtetra
.652 .751 .922 r
.75545 .23855 .76375 .25038 .78249 .2441 .77428 .23222 Mtetra
.658 .752 .92 r
.11083 .44809 .12173 .45758 .13663 .45228 .12577 .44282 Mtetra
.66 .754 .92 r
.12577 .44282 .13663 .45228 .15159 .44712 .1408 .43745 Mtetra
.653 .75 .921 r
.1408 .43745 .15159 .44712 .16662 .44212 .15589 .43231 Mtetra
.652 .748 .92 r
.15589 .43231 .16662 .44212 .18175 .43692 .17106 .42717 Mtetra
.655 .751 .92 r
.17106 .42717 .18175 .43692 .19699 .43165 .18634 .42188 Mtetra
.657 .752 .92 r
.18634 .42188 .19699 .43165 .21227 .42668 .20171 .4165 Mtetra
.643 .741 .92 r
.20171 .4165 .21227 .42668 .2275 .42336 .21713 .41159 Mtetra
.598 .695 .91 r
.21713 .41159 .2275 .42336 .24274 .42121 .2325 .40828 Mtetra
.575 .665 .899 r
.2325 .40828 .24274 .42121 .25803 .41986 .24791 .40581 Mtetra
.557 .638 .887 r
.24791 .40581 .25803 .41986 .27357 .41693 .26338 .40404 Mtetra
.585 .672 .899 r
.26338 .40404 .27357 .41693 .28944 .41105 .27906 .40119 Mtetra
.651 .757 .927 r
.27906 .40119 .28944 .41105 .30555 .40303 .29504 .39579 Mtetra
.688 .827 .95 r
.29504 .39579 .30555 .40303 .32185 .39302 .31122 .38889 Mtetra
.714 .905 .963 r
.31122 .38889 .32185 .39302 .3382 .38306 .32758 .3805 Mtetra
.714 .938 .959 r
.32758 .3805 .3382 .38306 .35454 .37424 .34404 .37151 Mtetra
.701 .935 .964 r
.34404 .37151 .35454 .37424 .3709 .36648 .36054 .36289 Mtetra
.688 .917 .972 r
.36054 .36289 .3709 .36648 .3873 .35949 .37708 .35495 Mtetra
.668 .893 .979 r
.37708 .35495 .3873 .35949 .40376 .35308 .39366 .34786 Mtetra
.649 .875 .982 r
.39366 .34786 .40376 .35308 .4203 .34705 .41031 .34147 Mtetra
.63 .862 .986 r
.41031 .34147 .4203 .34705 .43693 .34128 .42703 .33564 Mtetra
.606 .855 .991 r
.42703 .33564 .43693 .34128 .45366 .33578 .44385 .33038 Mtetra
.569 .849 .997 r
.44385 .33038 .45366 .33578 .47049 .33066 .46076 .32582 Mtetra
.51 .839 .998 r
.46076 .32582 .47049 .33066 .48742 .32613 .47777 .32214 Mtetra
.438 .825 .987 r
.47777 .32214 .48742 .32613 .50447 .32237 .49491 .31914 Mtetra
.378 .809 .965 r
.49491 .31914 .50447 .32237 .52165 .31972 .51219 .31654 Mtetra
.411 .828 .969 r
.51219 .31654 .52165 .31972 .53898 .31822 .52962 .31333 Mtetra
.549 .86 .997 r
.52962 .31333 .53898 .31822 .55647 .3168 .54718 .30862 Mtetra
.651 .819 .964 r
.54718 .30862 .55647 .3168 .57409 .31336 .56485 .30238 Mtetra
.714 .778 .902 r
.56485 .30238 .57409 .31336 .5918 .30774 .58258 .29353 Mtetra
.72 .723 .853 r
.58258 .29353 .5918 .30774 .60955 .29909 .60037 .28354 Mtetra
.702 .698 .843 r
.60037 .28354 .60955 .29909 .62734 .28878 .61825 .27424 Mtetra
.692 .71 .862 r
.61825 .27424 .62734 .28878 .64522 .27929 .63625 .2658 Mtetra
.664 .718 .889 r
.63625 .2658 .64522 .27929 .66324 .27097 .6544 .25899 Mtetra
.655 .744 .915 r
.6544 .25899 .66324 .27097 .68143 .26435 .67269 .25265 Mtetra
.656 .752 .921 r
.67269 .25265 .68143 .26435 .69976 .25803 .6911 .24623 Mtetra
.659 .753 .919 r
.6911 .24623 .69976 .25803 .71821 .25163 .70963 .23962 Mtetra
.659 .75 .917 r
.70963 .23962 .71821 .25163 .73676 .24501 .72827 .23301 Mtetra
.652 .749 .92 r
.72827 .23301 .73676 .24501 .75545 .23855 .74705 .22663 Mtetra
.654 .753 .922 r
.74705 .22663 .75545 .23855 .77428 .23222 .76596 .22014 Mtetra
.656 .751 .92 r
.09982 .43848 .11083 .44809 .12577 .44282 .1148 .43322 Mtetra
.659 .754 .92 r
.1148 .43322 .12577 .44282 .1408 .43745 .12987 .42781 Mtetra
.658 .754 .921 r
.12987 .42781 .1408 .43745 .15589 .43231 .14504 .42241 Mtetra
.651 .748 .92 r
.14504 .42241 .15589 .43231 .17106 .42717 .16026 .41723 Mtetra
.653 .748 .92 r
.16026 .41723 .17106 .42717 .18634 .42188 .17558 .41196 Mtetra
.655 .751 .92 r
.17558 .41196 .18634 .42188 .20171 .4165 .191 .40658 Mtetra
.657 .752 .921 r
.191 .40658 .20171 .4165 .21713 .41159 .20652 .40111 Mtetra
.643 .738 .918 r
.20652 .40111 .21713 .41159 .2325 .40828 .22209 .3961 Mtetra
.605 .693 .905 r
.22209 .3961 .2325 .40828 .24791 .40581 .23763 .39247 Mtetra
.587 .665 .893 r
.23763 .39247 .24791 .40581 .26338 .40404 .25322 .38953 Mtetra
.571 .639 .88 r
.25322 .38953 .26338 .40404 .27906 .40119 .26888 .38721 Mtetra
.584 .655 .886 r
.26888 .38721 .27906 .40119 .29504 .39579 .28471 .38434 Mtetra
.622 .718 .915 r
.28471 .38434 .29504 .39579 .31122 .38889 .30077 .37998 Mtetra
.659 .786 .941 r
.30077 .37998 .31122 .38889 .32758 .3805 .31703 .3741 Mtetra
.672 .849 .967 r
.31703 .3741 .32758 .3805 .34404 .37151 .33344 .36745 Mtetra
.662 .901 .98 r
.33344 .36745 .34404 .37151 .36054 .36289 .34996 .36036 Mtetra
.647 .928 .972 r
.34996 .36036 .36054 .36289 .37708 .35495 .36659 .35286 Mtetra
.614 .927 .969 r
.36659 .35286 .37708 .35495 .39366 .34786 .38328 .34576 Mtetra
.583 .917 .97 r
.38328 .34576 .39366 .34786 .41031 .34147 .40004 .33924 Mtetra
.549 .904 .97 r
.40004 .33924 .41031 .34147 .42703 .33564 .41687 .33336 Mtetra
.511 .888 .968 r
.41687 .33336 .42703 .33564 .44385 .33038 .43379 .32812 Mtetra
.472 .871 .963 r
.43379 .32812 .44385 .33038 .46076 .32582 .45081 .32345 Mtetra
.447 .858 .96 r
.45081 .32345 .46076 .32582 .47777 .32214 .46795 .3192 Mtetra
.49 .871 .976 r
.46795 .3192 .47777 .32214 .49491 .31914 .48521 .31455 Mtetra
.562 .87 .995 r
.48521 .31455 .49491 .31914 .51219 .31654 .50261 .30945 Mtetra
.633 .838 .979 r
.50261 .30945 .51219 .31654 .52962 .31333 .52012 .30357 Mtetra
.686 .794 .932 r
.52012 .30357 .52962 .31333 .54718 .30862 .53775 .29614 Mtetra
.711 .749 .882 r
.53775 .29614 .54718 .30862 .56485 .30238 .55546 .28717 Mtetra
.708 .705 .845 r
.55546 .28717 .56485 .30238 .58258 .29353 .57324 .27763 Mtetra
.694 .691 .842 r
.57324 .27763 .58258 .29353 .60037 .28354 .59112 .26869 Mtetra
.687 .704 .861 r
.59112 .26869 .60037 .28354 .61825 .27424 .6091 .26045 Mtetra
.663 .714 .885 r
.6091 .26045 .61825 .27424 .63625 .2658 .62722 .25361 Mtetra
.655 .741 .913 r
.62722 .25361 .63625 .2658 .6544 .25899 .64548 .24725 Mtetra
.656 .752 .921 r
.64548 .24725 .6544 .25899 .67269 .25265 .66385 .24078 Mtetra
.658 .752 .919 r
.66385 .24078 .67269 .25265 .6911 .24623 .68233 .23418 Mtetra
.66 .751 .917 r
.68233 .23418 .6911 .24623 .70963 .23962 .70094 .22748 Mtetra
.654 .748 .919 r
.70094 .22748 .70963 .23962 .72827 .23301 .71968 .22101 Mtetra
.653 .752 .923 r
.71968 .22101 .72827 .23301 .74705 .22663 .73855 .21453 Mtetra
.656 .753 .921 r
.73855 .21453 .74705 .22663 .76596 .22014 .75754 .20788 Mtetra
.654 .75 .92 r
.0887 .42871 .09982 .43848 .1148 .43322 .10371 .42346 Mtetra
.656 .752 .92 r
.10371 .42346 .1148 .43322 .12987 .42781 .11883 .4181 Mtetra
.66 .755 .92 r
.11883 .4181 .12987 .42781 .14504 .42241 .13405 .41257 Mtetra
.657 .753 .921 r
.13405 .41257 .14504 .42241 .16026 .41723 .14934 .40714 Mtetra
.651 .747 .92 r
.14934 .40714 .16026 .41723 .17558 .41196 .16471 .40187 Mtetra
.654 .749 .92 r
.16471 .40187 .17558 .41196 .191 .40658 .18018 .39648 Mtetra
.655 .751 .92 r
.18018 .39648 .191 .40658 .20652 .40111 .19575 .39101 Mtetra
.657 .752 .92 r
.19575 .39101 .20652 .40111 .22209 .3961 .21142 .38544 Mtetra
.647 .739 .916 r
.21142 .38544 .22209 .3961 .23763 .39247 .22715 .3802 Mtetra
.619 .699 .902 r
.22715 .3802 .23763 .39247 .25322 .38953 .24288 .37599 Mtetra
.6 .67 .889 r
.24288 .37599 .25322 .38953 .26888 .38721 .25867 .37248 Mtetra
.591 .648 .875 r
.25867 .37248 .26888 .38721 .28471 .38434 .27454 .3693 Mtetra
.588 .642 .872 r
.27454 .3693 .28471 .38434 .30077 .37998 .29053 .36623 Mtetra
.604 .672 .888 r
.29053 .36623 .30077 .37998 .31703 .3741 .30669 .36251 Mtetra
.625 .721 .916 r
.30669 .36251 .31703 .3741 .33344 .36745 .32302 .35788 Mtetra
.649 .773 .939 r
.32302 .35788 .33344 .36745 .34996 .36036 .33952 .35226 Mtetra
.655 .809 .958 r
.33952 .35226 .34996 .36036 .36659 .35286 .35615 .34628 Mtetra
.648 .845 .976 r
.35615 .34628 .36659 .35286 .38328 .34576 .37288 .34017 Mtetra
.634 .866 .985 r
.37288 .34017 .38328 .34576 .40004 .33924 .38971 .3341 Mtetra
.621 .873 .989 r
.38971 .3341 .40004 .33924 .41687 .33336 .40664 .32815 Mtetra
.614 .871 .991 r
.40664 .32815 .41687 .33336 .43379 .32812 .42368 .32233 Mtetra
.619 .861 .989 r
.42368 .32233 .43379 .32812 .45081 .32345 .44082 .31655 Mtetra
.635 .841 .979 r
.44082 .31655 .45081 .32345 .46795 .3192 .45807 .31064 Mtetra
.655 .81 .957 r
.45807 .31064 .46795 .3192 .48521 .31455 .47544 .30437 Mtetra
.683 .784 .927 r
.47544 .30437 .48521 .31455 .50261 .30945 .49293 .29709 Mtetra
.697 .746 .889 r
.49293 .29709 .50261 .30945 .52012 .30357 .51053 .28888 Mtetra
.7 .709 .855 r
.51053 .28888 .52012 .30357 .53775 .29614 .52821 .27998 Mtetra
.691 .686 .84 r
.52821 .27998 .53775 .29614 .55546 .28717 .54598 .27118 Mtetra
.686 .687 .845 r
.54598 .27118 .55546 .28717 .57324 .27763 .56384 .2627 Mtetra
.678 .701 .864 r
.56384 .2627 .57324 .27763 .59112 .26869 .5818 .25492 Mtetra
.661 .714 .888 r
.5818 .25492 .59112 .26869 .6091 .26045 .59989 .24819 Mtetra
.655 .741 .913 r
.59989 .24819 .6091 .26045 .62722 .25361 .61811 .2418 Mtetra
.656 .752 .921 r
.61811 .2418 .62722 .25361 .64548 .24725 .63644 .23529 Mtetra
.658 .752 .919 r
.63644 .23529 .64548 .24725 .66385 .24078 .65489 .22869 Mtetra
.66 .751 .918 r
.65489 .22869 .66385 .24078 .68233 .23418 .67346 .22195 Mtetra
.655 .748 .918 r
.67346 .22195 .68233 .23418 .70094 .22748 .69216 .21538 Mtetra
.652 .751 .922 r
.69216 .21538 .70094 .22748 .71968 .22101 .71099 .20889 Mtetra
.655 .754 .922 r
.71099 .20889 .71968 .22101 .73855 .21453 .72994 .20222 Mtetra
.657 .752 .92 r
.72994 .20222 .73855 .21453 .75754 .20788 .74901 .19541 Mtetra
.653 .749 .92 r
.07745 .4188 .0887 .42871 .10371 .42346 .09251 .41354 Mtetra
.655 .75 .92 r
.09251 .41354 .10371 .42346 .11883 .4181 .10767 .40818 Mtetra
.657 .752 .92 r
.10767 .40818 .11883 .4181 .13405 .41257 .12293 .4027 Mtetra
.66 .755 .921 r
.12293 .4027 .13405 .41257 .14934 .40714 .13829 .39709 Mtetra
.656 .752 .92 r
.13829 .39709 .14934 .40714 .16471 .40187 .15372 .39159 Mtetra
.652 .747 .92 r
.15372 .39159 .16471 .40187 .18018 .39648 .16924 .38622 Mtetra
.654 .749 .92 r
.16924 .38622 .18018 .39648 .19575 .39101 .18485 .38074 Mtetra
.655 .751 .92 r
.18485 .38074 .19575 .39101 .21142 .38544 .20057 .37516 Mtetra
.656 .752 .92 r
.20057 .37516 .21142 .38544 .22715 .3802 .21639 .3695 Mtetra
.652 .744 .917 r
.21639 .3695 .22715 .3802 .24288 .37599 .23229 .36397 Mtetra
.637 .714 .903 r
.23229 .36397 .24288 .37599 .25867 .37248 .24825 .35897 Mtetra
.615 .68 .888 r
.24825 .35897 .25867 .37248 .27454 .3693 .26423 .35477 Mtetra
.609 .662 .876 r
.26423 .35477 .27454 .3693 .29053 .36623 .28032 .35076 Mtetra
.607 .647 .864 r
.28032 .35076 .29053 .36623 .30669 .36251 .29652 .34682 Mtetra
.606 .644 .862 r
.29652 .34682 .30669 .36251 .32302 .35788 .31283 .34288 Mtetra
.616 .661 .87 r
.31283 .34288 .32302 .35788 .33952 .35226 .32929 .3385 Mtetra
.628 .687 .886 r
.32929 .3385 .33952 .35226 .35615 .34628 .3459 .33362 Mtetra
.639 .712 .9 r
.3459 .33362 .35615 .34628 .37288 .34017 .36265 .3283 Mtetra
.647 .731 .91 r
.36265 .3283 .37288 .34017 .38971 .3341 .37952 .32261 Mtetra
.655 .743 .915 r
.37952 .32261 .38971 .3341 .40664 .32815 .39651 .3166 Mtetra
.662 .745 .912 r
.39651 .3166 .40664 .32815 .42368 .32233 .41363 .31026 Mtetra
.669 .739 .903 r
.41363 .31026 .42368 .32233 .44082 .31655 .43086 .30354 Mtetra
.675 .725 .887 r
.43086 .30354 .44082 .31655 .45807 .31064 .4482 .29637 Mtetra
.68 .707 .868 r
.4482 .29637 .45807 .31064 .47544 .30437 .46565 .2887 Mtetra
.683 .688 .848 r
.46565 .2887 .47544 .30437 .49293 .29709 .4832 .28056 Mtetra
.679 .675 .839 r
.4832 .28056 .49293 .29709 .51053 .28888 .50085 .27242 Mtetra
.678 .677 .842 r
.50085 .27242 .51053 .28888 .52821 .27998 .51858 .26433 Mtetra
.678 .689 .854 r
.51858 .26433 .52821 .27998 .54598 .27118 .53641 .25642 Mtetra
.666 .699 .872 r
.53641 .25642 .54598 .27118 .56384 .2627 .55435 .24931 Mtetra
.657 .721 .896 r
.55435 .24931 .56384 .2627 .5818 .25492 .57241 .24276 Mtetra
.655 .744 .916 r
.57241 .24276 .5818 .25492 .59989 .24819 .59058 .23631 Mtetra
.656 .752 .921 r
.59058 .23631 .59989 .24819 .61811 .2418 .60888 .22978 Mtetra
.658 .752 .919 r
.60888 .22978 .61811 .2418 .63644 .23529 .62729 .22314 Mtetra
.66 .751 .918 r
.62729 .22314 .63644 .23529 .65489 .22869 .64582 .21637 Mtetra
.656 .748 .918 r
.64582 .21637 .65489 .22869 .67346 .22195 .66448 .20974 Mtetra
.652 .75 .922 r
.66448 .20974 .67346 .22195 .69216 .21538 .68327 .2032 Mtetra
.655 .754 .923 r
.68327 .2032 .69216 .21538 .71099 .20889 .70218 .19652 Mtetra
.657 .752 .92 r
.70218 .19652 .71099 .20889 .72994 .20222 .72122 .1897 Mtetra
.658 .752 .919 r
.72122 .1897 .72994 .20222 .74901 .19541 .74037 .18277 Mtetra
.654 .75 .92 r
.06608 .40884 .07745 .4188 .09251 .41354 .08119 .40347 Mtetra
.653 .749 .92 r
.08119 .40347 .09251 .41354 .10767 .40818 .09639 .39811 Mtetra
.655 .751 .92 r
.09639 .39811 .10767 .40818 .12293 .4027 .11169 .39264 Mtetra
.657 .753 .92 r
.11169 .39264 .12293 .4027 .13829 .39709 .12709 .38706 Mtetra
.659 .755 .921 r
.12709 .38706 .13829 .39709 .15372 .39159 .1426 .38136 Mtetra
.656 .752 .92 r
.1426 .38136 .15372 .39159 .16924 .38622 .15819 .37575 Mtetra
.652 .747 .919 r
.15819 .37575 .16924 .38622 .18485 .38074 .17385 .37027 Mtetra
.653 .748 .92 r
.17385 .37027 .18485 .38074 .20057 .37516 .18961 .36472 Mtetra
.655 .751 .92 r
.18961 .36472 .20057 .37516 .21639 .3695 .20548 .35903 Mtetra
.655 .751 .921 r
.20548 .35903 .21639 .3695 .23229 .36397 .22145 .35334 Mtetra
.657 .75 .919 r
.22145 .35334 .23229 .36397 .24825 .35897 .23753 .34752 Mtetra
.65 .733 .91 r
.23753 .34752 .24825 .35897 .26423 .35477 .25368 .34193 Mtetra
.639 .704 .894 r
.25368 .34193 .26423 .35477 .28032 .35076 .2699 .33672 Mtetra
.626 .68 .881 r
.2699 .33672 .28032 .35076 .29652 .34682 .28619 .33195 Mtetra
.624 .667 .871 r
.28619 .33195 .29652 .34682 .31283 .34288 .30259 .32719 Mtetra
.625 .656 .86 r
.30259 .32719 .31283 .34288 .32929 .3385 .31912 .32231 Mtetra
.628 .651 .853 r
.31912 .32231 .32929 .3385 .3459 .33362 .33577 .31719 Mtetra
.632 .65 .85 r
.33577 .31719 .3459 .33362 .36265 .3283 .35255 .31181 Mtetra
.638 .653 .848 r
.35255 .31181 .36265 .3283 .37952 .32261 .36945 .30613 Mtetra
.645 .657 .847 r
.36945 .30613 .37952 .32261 .39651 .3166 .38648 .30003 Mtetra
.652 .66 .845 r
.38648 .30003 .39651 .3166 .41363 .31026 .40364 .29353 Mtetra
.656 .661 .842 r
.40364 .29353 .41363 .31026 .43086 .30354 .42091 .28672 Mtetra
.66 .662 .841 r
.42091 .28672 .43086 .30354 .4482 .29637 .43829 .27964 Mtetra
.664 .666 .842 r
.43829 .27964 .4482 .29637 .46565 .2887 .45578 .27232 Mtetra
.668 .674 .846 r
.45578 .27232 .46565 .2887 .4832 .28056 .47337 .26486 Mtetra
.67 .685 .856 r
.47337 .26486 .4832 .28056 .50085 .27242 .49107 .2574 Mtetra
.663 .694 .869 r
.49107 .2574 .50085 .27242 .51858 .26433 .50886 .25039 Mtetra
.658 .711 .887 r
.50886 .25039 .51858 .26433 .53641 .25642 .52676 .24375 Mtetra
.654 .734 .908 r
.52676 .24375 .53641 .25642 .55435 .24931 .54477 .23734 Mtetra
.657 .75 .919 r
.54477 .23734 .55435 .24931 .57241 .24276 .56291 .23079 Mtetra
.656 .752 .92 r
.56291 .23079 .57241 .24276 .59058 .23631 .58116 .22423 Mtetra
.658 .752 .919 r
.58116 .22423 .59058 .23631 .60888 .22978 .59954 .21753 Mtetra
.659 .751 .918 r
.59954 .21753 .60888 .22978 .62729 .22314 .61803 .21075 Mtetra
.655 .748 .918 r
.61803 .21075 .62729 .22314 .64582 .21637 .63665 .20408 Mtetra
.653 .75 .921 r
.63665 .20408 .64582 .21637 .66448 .20974 .6554 .1975 Mtetra
.654 .754 .923 r
.6554 .1975 .66448 .20974 .68327 .2032 .67427 .19079 Mtetra
.656 .753 .921 r
.67427 .19079 .68327 .2032 .70218 .19652 .69326 .18395 Mtetra
.658 .752 .919 r
.69326 .18395 .70218 .19652 .72122 .1897 .71238 .17698 Mtetra
.657 .75 .919 r
.71238 .17698 .72122 .1897 .74037 .18277 .73163 .17002 Mtetra
.658 .753 .92 r
.05456 .39887 .06608 .40884 .08119 .40347 .06974 .39331 Mtetra
.654 .75 .92 r
.06974 .39331 .08119 .40347 .09639 .39811 .08499 .38786 Mtetra
.653 .749 .92 r
.08499 .38786 .09639 .39811 .11169 .39264 .10034 .3824 Mtetra
.655 .751 .92 r
.10034 .3824 .11169 .39264 .12709 .38706 .11578 .37683 Mtetra
.657 .753 .921 r
.11578 .37683 .12709 .38706 .1426 .38136 .13133 .37116 Mtetra
.659 .755 .921 r
.13133 .37116 .1426 .38136 .15819 .37575 .14699 .36537 Mtetra
.657 .752 .92 r
.14699 .36537 .15819 .37575 .17385 .37027 .16272 .35963 Mtetra
.653 .747 .919 r
.16272 .35963 .17385 .37027 .18961 .36472 .17854 .35402 Mtetra
.652 .747 .919 r
.17854 .35402 .18961 .36472 .20548 .35903 .19446 .34839 Mtetra
.655 .751 .92 r
.19446 .34839 .20548 .35903 .22145 .35334 .21048 .34262 Mtetra
.655 .75 .92 r
.21048 .34262 .22145 .35334 .23753 .34752 .22661 .33681 Mtetra
.655 .752 .921 r
.22661 .33681 .23753 .34752 .25368 .34193 .24284 .33095 Mtetra
.657 .748 .917 r
.24284 .33095 .25368 .34193 .2699 .33672 .25917 .32501 Mtetra
.653 .734 .909 r
.25917 .32501 .2699 .33672 .28619 .33195 .27559 .31916 Mtetra
.648 .713 .895 r
.27559 .31916 .28619 .33195 .30259 .32719 .29211 .31342 Mtetra
.644 .696 .883 r
.29211 .31342 .30259 .32719 .31912 .32231 .30873 .30776 Mtetra
.64 .683 .875 r
.30873 .30776 .31912 .32231 .33577 .31719 .32545 .30219 Mtetra
.641 .677 .869 r
.32545 .30219 .33577 .31719 .35255 .31181 .34228 .29647 Mtetra
.644 .674 .864 r
.34228 .29647 .35255 .31181 .36945 .30613 .35924 .29054 Mtetra
.648 .673 .86 r
.35924 .29054 .36945 .30613 .38648 .30003 .37632 .28437 Mtetra
.652 .675 .859 r
.37632 .28437 .38648 .30003 .40364 .29353 .39352 .27796 Mtetra
.656 .679 .86 r
.39352 .27796 .40364 .29353 .42091 .28672 .41083 .27134 Mtetra
.659 .684 .863 r
.41083 .27134 .42091 .28672 .43829 .27964 .42825 .26455 Mtetra
.657 .689 .869 r
.42825 .26455 .43829 .27964 .45578 .27232 .44577 .25786 Mtetra
.657 .701 .879 r
.44577 .25786 .45578 .27232 .47337 .26486 .46341 .25125 Mtetra
.656 .716 .893 r
.46341 .25125 .47337 .26486 .49107 .2574 .48115 .24473 Mtetra
.654 .734 .908 r
.48115 .24473 .49107 .2574 .50886 .25039 .49901 .23832 Mtetra
.656 .748 .918 r
.49901 .23832 .50886 .25039 .52676 .24375 .51699 .2318 Mtetra
.656 .752 .92 r
.51699 .2318 .52676 .24375 .54477 .23734 .53508 .22524 Mtetra
.656 .751 .919 r
.53508 .22524 .54477 .23734 .56291 .23079 .55329 .21863 Mtetra
.659 .752 .919 r
.55329 .21863 .56291 .23079 .58116 .22423 .57162 .21187 Mtetra
.659 .749 .917 r
.57162 .21187 .58116 .22423 .59954 .21753 .59008 .20507 Mtetra
.654 .747 .918 r
.59008 .20507 .59954 .21753 .61803 .21075 .60866 .19841 Mtetra
.653 .751 .922 r
.60866 .19841 .61803 .21075 .63665 .20408 .62736 .19178 Mtetra
.655 .754 .923 r
.62736 .19178 .63665 .20408 .6554 .1975 .6462 .18502 Mtetra
.656 .753 .921 r
.6462 .18502 .6554 .1975 .67427 .19079 .66515 .17815 Mtetra
.658 .752 .919 r
.66515 .17815 .67427 .19079 .69326 .18395 .68423 .17115 Mtetra
.657 .75 .918 r
.68423 .17115 .69326 .18395 .71238 .17698 .70344 .16413 Mtetra
.654 .749 .92 r
.70344 .16413 .71238 .17698 .73163 .17002 .72279 .15721 Mtetra
.658 .753 .92 r
.04292 .38878 .05456 .39887 .06974 .39331 .05815 .38315 Mtetra
.05815 .38315 .06974 .39331 .08499 .38786 .07347 .37751 Mtetra
.654 .749 .92 r
.07347 .37751 .08499 .38786 .10034 .3824 .08887 .37196 Mtetra
.653 .749 .92 r
.08887 .37196 .10034 .3824 .11578 .37683 .10435 .3664 Mtetra
.655 .751 .92 r
.10435 .3664 .11578 .37683 .13133 .37116 .11995 .36074 Mtetra
.656 .753 .921 r
.11995 .36074 .13133 .37116 .14699 .36537 .13564 .35499 Mtetra
.659 .755 .921 r
.13564 .35499 .14699 .36537 .16272 .35963 .15145 .34912 Mtetra
.658 .754 .921 r
.15145 .34912 .16272 .35963 .17854 .35402 .16734 .34324 Mtetra
.654 .749 .919 r
.16734 .34324 .17854 .35402 .19446 .34839 .18332 .33747 Mtetra
.653 .746 .918 r
.18332 .33747 .19446 .34839 .21048 .34262 .19939 .33172 Mtetra
.653 .748 .92 r
.19939 .33172 .21048 .34262 .22661 .33681 .21557 .32592 Mtetra
.656 .751 .92 r
.21557 .32592 .22661 .33681 .24284 .33095 .23186 .31999 Mtetra
.23186 .31999 .24284 .33095 .25917 .32501 .24825 .31403 Mtetra
.655 .752 .921 r
.24825 .31403 .25917 .32501 .27559 .31916 .26474 .30804 Mtetra
.656 .75 .919 r
.26474 .30804 .27559 .31916 .29211 .31342 .28134 .30198 Mtetra
.656 .746 .916 r
.28134 .30198 .29211 .31342 .30873 .30776 .29804 .29586 Mtetra
.655 .738 .91 r
.29804 .29586 .30873 .30776 .32545 .30219 .31485 .28974 Mtetra
.654 .728 .904 r
.31485 .28974 .32545 .30219 .34228 .29647 .33177 .28359 Mtetra
.654 .722 .899 r
.33177 .28359 .34228 .29647 .35924 .29054 .34879 .27741 Mtetra
.654 .718 .896 r
.34879 .27741 .35924 .29054 .37632 .28437 .36593 .27116 Mtetra
.36593 .27116 .37632 .28437 .39352 .27796 .38318 .26486 Mtetra
.655 .722 .898 r
.38318 .26486 .39352 .27796 .41083 .27134 .40054 .25851 Mtetra
.655 .728 .903 r
.40054 .25851 .41083 .27134 .42825 .26455 .41801 .25213 Mtetra
.654 .737 .911 r
.41801 .25213 .42825 .26455 .44577 .25786 .43559 .24576 Mtetra
.655 .745 .916 r
.43559 .24576 .44577 .25786 .46341 .25125 .45329 .23932 Mtetra
.656 .751 .919 r
.45329 .23932 .46341 .25125 .48115 .24473 .47111 .2328 Mtetra
.656 .752 .92 r
.47111 .2328 .48115 .24473 .49901 .23832 .48904 .22625 Mtetra
.656 .751 .92 r
.48904 .22625 .49901 .23832 .51699 .2318 .50709 .21967 Mtetra
.658 .752 .919 r
.50709 .21967 .51699 .2318 .53508 .22524 .52527 .21294 Mtetra
.659 .75 .918 r
.52527 .21294 .53508 .22524 .55329 .21863 .54356 .20615 Mtetra
.657 .748 .917 r
.54356 .20615 .55329 .21863 .57162 .21187 .56197 .19939 Mtetra
.654 .748 .919 r
.56197 .19939 .57162 .21187 .59008 .20507 .58051 .19273 Mtetra
.653 .752 .922 r
.58051 .19273 .59008 .20507 .60866 .19841 .59917 .18605 Mtetra
.655 .754 .923 r
.59917 .18605 .60866 .19841 .62736 .19178 .61796 .17922 Mtetra
.656 .753 .921 r
.61796 .17922 .62736 .19178 .6462 .18502 .63688 .17231 Mtetra
.658 .752 .919 r
.63688 .17231 .6462 .18502 .66515 .17815 .65592 .16527 Mtetra
.657 .75 .918 r
.65592 .16527 .66515 .17815 .68423 .17115 .67508 .15821 Mtetra
.654 .749 .92 r
.67508 .15821 .68423 .17115 .70344 .16413 .69439 .15124 Mtetra
.654 .752 .922 r
.69439 .15124 .70344 .16413 .72279 .15721 .71383 .14424 Mtetra
.656 .752 .92 r
.03115 .37852 .04292 .38878 .05815 .38315 .04642 .3729 Mtetra
.658 .753 .921 r
.04642 .3729 .05815 .38315 .07347 .37751 .0618 .36718 Mtetra
.0618 .36718 .07347 .37751 .08887 .37196 .07726 .36144 Mtetra
.654 .75 .92 r
.07726 .36144 .08887 .37196 .10435 .3664 .09281 .35578 Mtetra
.653 .749 .92 r
.09281 .35578 .10435 .3664 .11995 .36074 .10844 .35012 Mtetra
.655 .75 .92 r
.10844 .35012 .11995 .36074 .13564 .35499 .12419 .34437 Mtetra
.656 .752 .921 r
.12419 .34437 .13564 .35499 .15145 .34912 .14003 .33854 Mtetra
.658 .755 .921 r
.14003 .33854 .15145 .34912 .16734 .34324 .15598 .3326 Mtetra
.15598 .3326 .16734 .34324 .18332 .33747 .17204 .32661 Mtetra
.657 .752 .92 r
.17204 .32661 .18332 .33747 .19939 .33172 .18818 .32062 Mtetra
.654 .747 .918 r
.18818 .32062 .19939 .33172 .21557 .32592 .20442 .31472 Mtetra
.653 .747 .918 r
.20442 .31472 .21557 .32592 .23186 .31999 .22076 .30881 Mtetra
.653 .748 .919 r
.22076 .30881 .23186 .31999 .24825 .31403 .2372 .30285 Mtetra
.655 .75 .92 r
.2372 .30285 .24825 .31403 .26474 .30804 .25375 .2968 Mtetra
.656 .751 .92 r
.25375 .2968 .26474 .30804 .28134 .30198 .27041 .29069 Mtetra
.27041 .29069 .28134 .30198 .29804 .29586 .28718 .28453 Mtetra
.656 .752 .921 r
.28718 .28453 .29804 .29586 .31485 .28974 .30405 .27834 Mtetra
.30405 .27834 .31485 .28974 .33177 .28359 .32104 .2721 Mtetra
.656 .751 .92 r
.32104 .2721 .33177 .28359 .34879 .27741 .33813 .26583 Mtetra
.33813 .26583 .34879 .27741 .36593 .27116 .35533 .25951 Mtetra
.35533 .25951 .36593 .27116 .38318 .26486 .37265 .25314 Mtetra
.37265 .25314 .38318 .26486 .40054 .25851 .39008 .24673 Mtetra
.656 .752 .92 r
.39008 .24673 .40054 .25851 .41801 .25213 .40762 .24028 Mtetra
.40762 .24028 .41801 .25213 .43559 .24576 .42528 .23379 Mtetra
.656 .751 .92 r
.42528 .23379 .43559 .24576 .45329 .23932 .44305 .22726 Mtetra
.657 .751 .919 r
.44305 .22726 .45329 .23932 .47111 .2328 .46094 .22065 Mtetra
.658 .751 .919 r
.46094 .22065 .47111 .2328 .48904 .22625 .47896 .21395 Mtetra
.658 .75 .918 r
.47896 .21395 .48904 .22625 .50709 .21967 .49708 .20719 Mtetra
.657 .748 .917 r
.49708 .20719 .50709 .21967 .52527 .21294 .51533 .20041 Mtetra
.654 .747 .918 r
.51533 .20041 .52527 .21294 .54356 .20615 .5337 .19372 Mtetra
.653 .75 .921 r
.5337 .19372 .54356 .20615 .56197 .19939 .5522 .18703 Mtetra
.654 .754 .923 r
.5522 .18703 .56197 .19939 .58051 .19273 .57082 .18027 Mtetra
.656 .754 .922 r
.57082 .18027 .58051 .19273 .59917 .18605 .58957 .17339 Mtetra
.657 .752 .92 r
.58957 .17339 .59917 .18605 .61796 .17922 .60844 .16642 Mtetra
.658 .752 .919 r
.60844 .16642 .61796 .17922 .63688 .17231 .62744 .15935 Mtetra
.657 .75 .918 r
.62744 .15935 .63688 .17231 .65592 .16527 .64657 .15226 Mtetra
.654 .749 .92 r
.64657 .15226 .65592 .16527 .67508 .15821 .66583 .14525 Mtetra
.654 .752 .922 r
.66583 .14525 .67508 .15821 .69439 .15124 .68523 .1382 Mtetra
.655 .753 .921 r
.68523 .1382 .69439 .15124 .71383 .14424 .70476 .13104 Mtetra
.655 .751 .92 r
.01926 .3681 .03115 .37852 .04642 .3729 .03457 .36246 Mtetra
.656 .752 .92 r
.03457 .36246 .04642 .3729 .0618 .36718 .04999 .35674 Mtetra
.658 .753 .921 r
.04999 .35674 .0618 .36718 .07726 .36144 .06551 .35093 Mtetra
.06551 .35093 .07726 .36144 .09281 .35578 .08112 .34509 Mtetra
.655 .75 .92 r
.08112 .34509 .09281 .35578 .10844 .35012 .09682 .3393 Mtetra
.654 .749 .92 r
.09682 .3393 .10844 .35012 .12419 .34437 .11261 .33353 Mtetra
.654 .75 .92 r
.11261 .33353 .12419 .34437 .14003 .33854 .1285 .3277 Mtetra
.656 .751 .92 r
.1285 .3277 .14003 .33854 .15598 .3326 .1445 .32178 Mtetra
.656 .753 .921 r
.1445 .32178 .15598 .3326 .17204 .32661 .1606 .3158 Mtetra
.658 .755 .922 r
.1606 .3158 .17204 .32661 .18818 .32062 .17681 .30971 Mtetra
.658 .755 .921 r
.17681 .30971 .18818 .32062 .20442 .31472 .19312 .30359 Mtetra
.657 .751 .92 r
.19312 .30359 .20442 .31472 .22076 .30881 .20953 .29746 Mtetra
.655 .748 .918 r
.20953 .29746 .22076 .30881 .2372 .30285 .22604 .29138 Mtetra
.654 .747 .918 r
.22604 .29138 .2372 .30285 .25375 .2968 .24265 .28528 Mtetra
.24265 .28528 .25375 .2968 .27041 .29069 .25937 .27915 Mtetra
.654 .748 .919 r
.25937 .27915 .27041 .29069 .28718 .28453 .2762 .27297 Mtetra
.655 .749 .919 r
.2762 .27297 .28718 .28453 .30405 .27834 .29313 .26673 Mtetra
.655 .75 .92 r
.29313 .26673 .30405 .27834 .32104 .2721 .31018 .26044 Mtetra
.655 .751 .92 r
.31018 .26044 .32104 .2721 .33813 .26583 .32734 .2541 Mtetra
.656 .751 .92 r
.32734 .2541 .33813 .26583 .35533 .25951 .34461 .2477 Mtetra
.34461 .2477 .35533 .25951 .37265 .25314 .362 .24125 Mtetra
.362 .24125 .37265 .25314 .39008 .24673 .3795 .23474 Mtetra
.657 .751 .919 r
.3795 .23474 .39008 .24673 .40762 .24028 .39711 .22818 Mtetra
.657 .75 .919 r
.39711 .22818 .40762 .24028 .42528 .23379 .41484 .22157 Mtetra
.657 .749 .918 r
.41484 .22157 .42528 .23379 .44305 .22726 .43269 .2149 Mtetra
.657 .748 .917 r
.43269 .2149 .44305 .22726 .46094 .22065 .45066 .20818 Mtetra
.656 .747 .917 r
.45066 .20818 .46094 .22065 .47896 .21395 .46875 .20145 Mtetra
.654 .748 .918 r
.46875 .20145 .47896 .21395 .49708 .20719 .48695 .19477 Mtetra
.654 .75 .921 r
.48695 .19477 .49708 .20719 .51533 .20041 .50528 .18806 Mtetra
.654 .753 .923 r
.50528 .18806 .51533 .20041 .5337 .19372 .52373 .18131 Mtetra
.655 .755 .923 r
.52373 .18131 .5337 .19372 .5522 .18703 .54231 .17446 Mtetra
.656 .753 .921 r
.54231 .17446 .5522 .18703 .57082 .18027 .56101 .16752 Mtetra
.657 .752 .92 r
.56101 .16752 .57082 .18027 .58957 .17339 .57984 .16049 Mtetra
.658 .751 .919 r
.57984 .16049 .58957 .17339 .60844 .16642 .5988 .15338 Mtetra
.656 .749 .918 r
.5988 .15338 .60844 .16642 .62744 .15935 .61788 .14629 Mtetra
.654 .75 .92 r
.61788 .14629 .62744 .15935 .64657 .15226 .6371 .13924 Mtetra
.654 .752 .922 r
.6371 .13924 .64657 .15226 .66583 .14525 .65646 .13214 Mtetra
.655 .753 .921 r
.65646 .13214 .66583 .14525 .68523 .1382 .67595 .12493 Mtetra
.657 .752 .92 r
.67595 .12493 .68523 .1382 .70476 .13104 .69557 .11763 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
[(-2)] .12586 .2075 1 .99877 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.56863 .04703 m
.57247 .05235 L
s
[(2)] .56094 .0364 .72324 1 Mshowa
.125 Mabswid
.18558 .19702 m
.18832 .19985 L
s
.23703 .17687 m
.23971 .17975 L
s
.28951 .15632 m
.29214 .15925 L
s
.39772 .11395 m
.40023 .11699 L
s
.4535 .09211 m
.45595 .0952 L
s
.51046 .06981 m
.51284 .07294 L
s
.08568 .23614 m
.08851 .23887 L
s
.62804 .02377 m
.63027 .02701 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 233.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00o?ooool2o`0006[ooooo003iooooo`?o000000?oooooo`000?ooool0
JOooool00?Oooooo0_l00004ooooo`;o0000JOooool00?Cooooo0ol00006ooooo`03o`000?oooooo
000006Sooooo003;ooooo`Go00008_ooool2o`0000Wooooo00?o0000ooooool00000J?ooool00<_o
oooo00GoV9RHob4Q8Oo^k^koooooodA4A00Oooooo`?o00002oooool01?l0003oooooooooool0001W
ooooo`00c?ooool00onHV9So8B4Qonk^kP0Mooooo`?o00003_ooool01Ol0003ooooooooooooooooo
000006Kooooo003=ooooo`03oiRHV?lQ8B7ok^k^01[ooooo0_l0000Aooooo`05o`000?oooooooooo
ooooool00000I_ooool00<kooooo00?oMgMgofIVI_ooool05_ooool3o`0001?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1Sooooo`00coooool00ol0003oooooooooo`0Cooooo`;o
00000_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0H_ooool00<_ooooo00Go0000okZj^_ooooooV9RHoa0@400Booooo`?o00006Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo06;ooooo003;ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`04?ooool2o`0001cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Qooooo`00
gOooool3o`0001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Qooooo`00fooo
ool2o`00027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Pooooo`00f?ooool3
o`0002?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Oooooo`00eOooool3o`00
02Kooooo00?o0000ooooooooool01?ooool2o`00067ooooo003Cooooo`;o0000:Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo05kooooo003@ooooo`?o000000?oooooo`000?ooool0
:?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05gooooo003>ooooo`;o00001Ooo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0GOoo
ool00<_ooooo0ol0000`ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0G?ooool0
0<Wooooo0_l0000cooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Foooool00<Ko
oooo0ol0000eooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Foooool00<Cooooo
0_l0000hooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0F_ooool00<7ooooo0ol0
000jooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03_ooool5o`0004Kooooo002n
ooooo`?o0000?Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00kooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A016ooooo`00_?ooool2o`0000?ooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo1_l00003ooooo`03oiRHV?lQ8B7o
k^k^04Oooooo002iooooo`?o0000@oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00kooooo00?oV9RHob4Q8Oo^k^h0A_ooool00;Oooooo0_l00016ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03oooool00omgMgOoIVIVooooo`15ooooo`00]?ooool3o`0004Sooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Cooooo
002booooo`;o0000Boooool00ol0003oooooooooo`0=ooooo`;o00003?ooool01Ol0003o^[Zjoooo
oonHV9So410@04Kooooo002_ooooo`?o0000COooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c016ooooo`00[Oooool2o`00053ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`1Dooooo`00Z_ooool4o`00057ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1Dooooo`00Z?ooool2o`0000Cooooo00?o0000oooo
ooooool0C_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05?ooooo001nooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h08_ooool3o`0005Oooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`1Booooo`00O_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01oooooo0ol0001Joooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool0D_ooool007kooooo00Go410@oooooooo
oooooooooa0@400Mooooo`;o0000GOooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
057ooooo001nooooo`05o`000?ooooooooooooooool000006_ooool3o`0005oooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`1@ooooo`00O_ooool01Ol0003ooooooooooooooooo0000
01Sooooo0_l0001Rooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0D?ooool007ko
oooo00Go410@oooooooooooooooooa0@400Eooooo`?o0000I?ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo04oooooo001nooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool2o`00
00?ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
04kooooo001nooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04?ooool3o`0006Sooooo00?oZ<3[o`00
0?ooool05_ooool00ol0003oooooooooo`1>ooooo`00TOooool2o`0006Sooooo1?nX`>/00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo04gooooo002>ooooo`?o0000J?ooool7ojS0j`03o`00
0?oooooooooo01Cooooo0ol0001>ooooo`00Roooool3o`0006Wooooo0_nW`>/7ojS0j`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool0C?ooool008Wooooo0_l0001Yooooo`KoYl3[1_nX`>/0
0ol0003oZ<3[ooooo`0Gooooo`03o`000?oooooooooo04_ooooo0026ooooo`?o0000J?ooool00onW
`>coYl3[ojO0j`07ojO0j`GoZ<3[00?o0000ojO0joooool06?ooool00ol0003oooooooooo`1:oooo
o`00Q?ooool2o`0000;ooooo00?o0000ooooooooool0Hoooool5ojO0k0WoYl3[0_nX`>/2ojO0j`03
o`000?nW`>_oYl3[01Sooooo00?o0000ooooooooool0B_ooool0087ooooo0ol00005ooooo`03o`00
0?oooooooooo063ooooo2?nW`>`7ojO0j`03ojO0k?nW`>_oYl3[00;oYl3[00Co0000ojO0jonW`>_o
Yl3[6?ooool00ol0003oooooooooo`19ooooo`00Ooooool2o`0006Wooooo00?oYko[ojO0k?nW`>`0
1onW`>`4ojO0j`GoYl3/0onW`>/00ol0003oYl3[ojO0j`02ojO0jaSooooo00?o0000ooooooooool0
B?ooool007cooooo0ol0001Xooooo`GoYko[2OnW`>`00onW`>_oYl3/ojO0k006ojO0k0;oYl3[00Go
0000ojO0jonW`>_oYl3[ojO0k00Hooooo`03o`000?oooooooooo04Sooooo001jooooo`;o0000Iooo
ool:ojNoj`KoYl3/0_nW_n/9ojO0k0;oYl3[00?o0000ojO0jonW`>`00onW`>`Hooooo`03o`000?oo
oooooooo04Oooooo001gooooo`?o0000I_ooool>ojNoj`;oYl3/1_nW_n/9ojO0k003ojO0jol0003o
Yl3/00GoYl3/6?ooool00ol0003oooooooooo`16ooooo`00M?ooool3o`0006Kooooo00?oZ<3[ojNo
jonW_n/03OnW_n/2ojRoj`SoYko[1_nW`>`2ojNoj`03ojO0k?l0003oYl3/00GoYl3/6?ooool00ol0
003oooooooooo`16ooooo`00L_ooool2o`0000;ooooo00?o0000ooooooooool0H_ooool4ojS0j`_o
Yko[1_nX_n/8ojNoj`;oYl3/1_nW_n/00ol0003oYl3/ojO0k005ojO0k1Sooooo00?o0000oooooooo
ool0AOooool006oooooo0ol0001Wooooo`OoZ<3[1onW_n/00onX`>_oZ;o[ojRoj`07ojRoj`KoYko[
00?oZ;o[ojNojonW_n/01_nW_n/00ol0003oYl3/ojO0k004ojO0k003ojNojooooooooooo01Kooooo
00?o0000ooooooooool0AOooool006gooooo0_l0001Wooooo`[oZ<3[1?nW_n/5ojS0j`WoZ;o[0_nW
_n/5ojRoj`OoYko[00Co0000ojNojonW`>coYl3/1OnW_n/Gooooo`;o0000A_ooool006[ooooo0ol0
001Vooooo`koZ<3[00?oYko[ojS0jonX`>/01_nX`>/7ojRoj`03ojS0jonX_n_oZ;o[00KoZ;o[1_nW
_n/00ol0003oZ;o[ojNoj`07ojNojaSooooo00?o0000ooooooooool0@oooool006Sooooo0_l0001V
ooooo`;oYl3[6?nX`>/4ojRoj`GoZ<3[2?nX_n/2ojNoj`?oZ;o[00?o0000ojRojonX_n/02?nW_n/G
ooooo`03o`000?oooooooooo04?ooooo001Uooooo`?o0000I_ooool5ojO0jaSoZ<3[00?oZ;o[ojS0
jonX`>/01_nX`>/6ojRoj`03ojS0jonX_n_oZ;o[00?oZ;o[00Co0000ojRojonX_n_oZ;o[1_nW_n/0
0onX_n_oooooooooo`0Fooooo`03o`000?oooooooooo04;ooooo001Sooooo`;o0000Ioooool8ojO0
j`KoZ<3[00?oYl7/ojS0jonX`>/03OnX`>/00onW`>_oZ<3[ojS0j`07ojS0j`CoZ;o[1?nX`>/5ojRo
j`04o`000?nX_n_oZ;o[ojRoj`;oYko[1OnX_n/Hooooo`03o`000?oooooooooo047ooooo001Poooo
o`?o000000?oooooo`000?ooool0I?ooool00onW`NcoYl3[ojO0j`08ojO0j`;oZ<3[1OnW`N`;ojS0
j`GoYl3[2OnX`>/00onX_n_oZ<3[ojS0j`05ojS0j`CoZ;o[00Co0000ojRojonX_n_oZ<3[2?nX_n/G
ooooo`03o`000?oooooooooo047ooooo000fooooo`Go00008oooool2o`0006Oooooo1OnW`N`8ojO0
j`WoYl7/1_nX`>/2ojO1k0SoYl3[1_nX`>/2ojO0j`SoZ<3[1?nX_n/00ol0003oZ<3[ojS0j`02ojS0
j`SoZ;o[5oooool00ol0003oooooooooo`10ooooo`00=_ooool01OnHV9So8B4Qonk^k_ooooooA4A4
023ooooo0ol0001Uooooo`;oYl3/2?nW`N`4ojO0j`goYl7/0_nX`>/6ojO1k0SoYl3[0_nX`>/6ojO0
j`SoZ<3[00CoZ;o[ojS0jonX`>_o00001OnX`>/6ojRoj`03ojS0jooooooooooo01Kooooo00?o0000
ooooooooool0?oooool002kooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^01kooooo0ol0001Uoooo
o`KoYl3/2?nW`N`00onW`>_oYl7/ojO1k00<ojO1k003ojO0k?nW`NcoYl7/00OoYl7/1_nW`>/00onW
`NcoYl3[ojO0j`07ojO0j`KoZ<3[00GoYl3[ojS0jonX`>_oZ<3[o`000005ojS0j`CoZ;o[1?nX`>/G
ooooo`03o`000?oooooooooo03oooooo000hooooo`03oiRHV?lQ8B7ok^k^01_ooooo0_l0001Uoooo
o`;oYko[2?nW`>`6ojO1k0;oYko[3?nW`N`4ojO0k0WoYl7/0_nW`>/5ojO1k0WoYl3[0_nX`>/5ojO0
j`;oZ<3[00?o0000ojS0jonX`>/01?nX`>/00onX_n_oZ<3[ojS0j`05ojS0jaOooooo00?o0000oooo
ooooool0?_ooool003Wooooo00?oMgMgofIVI_ooool05oooool3o`0006Cooooo1_nW_n/8ojO0k0;o
Yl7/1_nW_n/9ojO1k0OoYl3/1onW`N`00onW`>coYl7/ojO1k006ojO1k0KoYl3[0_nW`N`8ojO0j`03
ojS0jol0003oZ<3[00goZ<3[6?ooool00ol0003oooooooooo`0mooooo`00>_ooool00ol0003ooooo
ooooo`0Dooooo`;o0000I?ooool:ojNoj`KoYl3/2_nW_n/6ojO1k003ojNojonW`>coYl3/00OoYl3/
1?nW`N`4ojO0k0SoYl7/0_nW`>/6ojO1k0SoYl3[00?o0000ojS0jonX`>/03OnX`>/Gooooo`03o`00
0?oooooooooo03gooooo000fooooo`05o`000?nj^[[ooooooiRHV?l@41004oooool3o`0000;ooooo
00?o0000ooooooooool0Goooool=ojNoj`;oYl3/3_nW_n/2ojO1k0GoYko[2OnW`>`00onW`NcoYl3/
ojO0k005ojO0k0KoYl7/00?oYko[ojO1k?nW`N`01onW`N`6ojO0j`03ojO1k?l0003oZ<3[00koZ<3[
6?ooool00ol0003oooooooooo`0looooo`00=_ooool01OnHV9So410@o`000?lQ8B7oc<c<017ooooo
0_l0001Uooooo`koYko[00?oZ;oZojNojonW_n/03?nW_n/2ojRojPSoYko[1_nW`>`2ojNoj`SoYl3/
1?nW`N`4ojNoj`WoYl7/0_nW`>/4ojO1k003o`000?nX`>_oZ<3[00koZ<3[5_ooool3o`0003gooooo
0019ooooo`?o0000IOooool00onW_n[oYko[ojNoj`0;ojNoj`CoZ;oZ2_nW_n/6ojRojPSoYko[0_nW
`>`6ojNoj`SoYl3/00?oYl7/ojNojonW_n/01OnW_n/6ojO1k0;oY[o/1_nW`N`00ol0003oYl7/ojS0
j`05ojS0j`;oYl7/2?nX`>/Gooooo`03o`000?oooooooooo03_ooooo0017ooooo`;o0000IOooool5
ojNojP[oYko[1onX_nX6ojNoj`03ojRojonX_n[oZ;oZ00OoZ;oZ1_nW_n/00onX_n[oYko[ojNoj`07
ojNoj`KoYl3/2_nW_n/2ojO1k0KoY[o/1OnW`N`00ol0003oYl7/ojO1k002ojS0j`KoYl7/2?nX`>/G
ooooo`03o`000?oooooooooo03[ooooo0014ooooo`?o0000I?ooool00onX_n[oYkoZojNojP06ojNo
jPKoYko[0_nX_n/8ojRojPCoYko[1?nX_n/9ojRojP;oYko[1OnX_nX9ojNoj`;oYl3/3OnW_n/9ojJo
k0CoYl7/00?o0000ojO1k?nV`>`02OnW`N`6ojS0j`03ojO0jooooooooooo01Kooooo00?o0000oooo
ooooool0>Oooool0047ooooo0ol0001Tooooo`GoZ;oZ2?nW_nX2ojNoj`KoZ;o[2?nX_nX00onW_n_o
Z;o[ojRoj`05ojRoj`OoZ;oZ00?oZ<3[ojRoj_nX_nX01_nX_nX6ojNoj`;oZ<3[4?nW_n/9ojJok0;o
Yl7/00?oY/3/o`000?nV`>`00_nV`>`9ojO1k0;oZ<3[1OnW`>/Gooooo`03o`000?oooooooooo03Wo
oooo000oooooo`?o0000Hoooool00onX_n_oZ;oZojRojP06ojRojPKoYkoZ0_nX`>/8ojRoj`KoZ;oZ
0_nX`>/8ojRoj`CoZ;oZ1?nX`>/8ojRojP;oYko[1_nX`>/@ojNoj`OoY[o/00GoYko[ojK0k?nV`>co
Y/3/o`000004ojK0k0KoYl7/0_nW`>`8ojO0jaOooooo00?o0000ooooooooool0>?ooool003cooooo
0ol00003ooooo`03o`000?oooooooooo05kooooo1?nX_n/8ojRojP;oYkoZ1_nX`>/8ojRoj`;oZ;oZ
1_nX`>/8ojRoj`03ojRoj_nX`>_oZ<3[00GoZ<3[1_nX_nX:ojS0j`KoYko[00?oZ<3[ojNojonW_n/0
1onW_n/4ojJok0CoYko[0_nV`>`00ol0003oY/3/ojK0k003ojK0k0;oYl7/1_nW`>`8ojO0jaKooooo
00?o0000ooooooooool01oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02cooooo000jooooo`;o0000
IOooool7ojRoj`KoZ;oZ2_nX`>/6ojRoj`03ojO0jonX`>_oZ<3[00OoZ<3[1_nX_n/00onW`>_oZ<3[
ojS0j`07ojS0j`;oZ;oZ3_nX`>/2ojNoj`GoZ<3[2OnW_n/00onV_ncoYko[ojNoj`05ojNoj`03ojK0
k?l0003oY/3/00?oY/3/00?oYko[ojO0k?nW`>`01onW`>`6ojO0j`03ojO0k?oooooooooo01Gooooo
00?o0000ooooooooool01_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02cooooo000gooooo`?o0000
IOooool:ojRoj`;oZ;oZ3_nX`>/2ojRoj`GoYl3[2OnX`>/2ojRoj`GoYl3[1onX`>/00onW`>_oZ<3[
ojS0j`0FojS0j`KoYko[0_nX`>/8ojNoj`;oY/3/00?o0000ojK0k?nW_n/00onW_n/9ojO0k0;oYl3[
1OnW`>`Gooooo`03o`000?oooooooooo00Gooooo00Go410@oooooooooooooooooa0@400/ooooo`00
=Oooool2o`0006Gooooo3?nX_n/00onW`>_oZ<3[ojS0j`0=ojS0j`WoYl3[1_nX`>/:ojO0j`CoZ<3[
1?nW`>/HojS0j`;oYko[1_nX`>/8ojNoj`03ojK0k?l0003oYko[00GoYko[1_nW`>`2ojJoj`SoYl3/
5_ooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool00000;?ooool003;ooooo
0ol0001Tooooo`03ojS0jonX_n_oZ;o[00[oZ;o[1?nW`>/;ojS0j`goYl3[0_nX`>/>ojO0j`03ojS0
jonW`>_oYl3[00GoYl3[1onX`>/00onW`>_oZ<3[ojS0j`0FojS0j`KoYko[00?oZ<3ZojNojol00000
1onW_n/2ojO0k0KoY[o[2?nW`>`Fooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooo
ooooo`00000/ooooo`00<?ooool2o`0006Cooooo1OnX`>/9ojRoj`OoYl3[1onX`>/?ojO0j`;oYko[
3_nW`>/00onX_n_oYl3[ojO0j`06ojO0j`CoZ<3[1OnW`>/HojS0j`;oYko[1OnX`>X00ol0003oYko[
ojNoj`04ojNoj`03ojRoj_nV_n_oY[o[00KoY[o[1_nW`>`2ojK0k1Oooooo00?o0000ooooooooool0
0oooool01Ol@413ooooooooooooooooo410@02cooooo000]ooooo`?o000000?oooooo`000?ooool0
H?ooool00onW`>_oZ<3[ojS0j`06ojS0j`KoZ;o[2_nW`>/4ojS0j`koYl3[1_nW_n/:ojO0j`GoZ;o[
2?nW`>/00onX`>_oYl3[ojO0j`06ojO0j`KoZ<3[00?oYl3[ojS0jonX`>/03_nX`>/7ojS0jP03o`00
0?nW_n_oYko[00;oYko[1?nX_nX8ojJoj`;oYl3/1_nV`>`Fooooo`;o00001?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg02cooooo000Zooooo`?o0000Hoooool5ojO0j`SoZ<3[0_nX_n/>ojO0j`03ojS0
jonW`>_oYl3[00_oYl3[0_nW^nP8ojNoj`KoYl3[00?oYk_XojRojonX_n/01_nX_n/6ojO0j`;oYkkZ
2OnW`>/2ojS0j`GoYl3[4?nX`>/6ojS0jP03o`000?nX`>[oYko[00OoZ;oZ1_nV_n/00onW_n_oY/3/
ojK0k007ojK0k1?ooooo0_l000000ooooooo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h0;?ooool002Sooooo0_l0001Sooooo`WoYl3[1_nX`>/@ojO0j`03ojNnj_nW`>_oYl3[00WoYl3[
1_nW^nP8ojNoj`;oYl3[1OnW^nP8ojRoj`;oYl3[1_nW_^X7ojO0j`03ojNmjOnW`>_oYl3[00KoYl3[
1_nX`>/00onW`>_oZ<3[ojS0j`07ojS0j`GoZ<3Z00?o0000ojS0jonX_nX02?nX_nX2ojJoj`GoYko[
2OnV`>`Fooooo`03o`000?oooooooooo03;ooooo000Uooooo`?o0000H_ooool=ojO0j`;oZ<3[4?nW
`>/5ojNnjPOoYl3[00?oYkOTojNkj?nW^nP01onW^nP6ojNoj`03ojRfhonW^nSoYk_X00KoYk_X1_nX
_n/00onX^>GoYkkZojNnjP07ojNnjPCoYl3[1?nW_NT8ojO0j`;oZ<3[1OnW`>/9ojS0j`;oZ<3Z00?o
Z<3[o`000?l000000_nX`>/7ojRojP03ojW0jonW_n_oYko[00KoYko[1_nV`>`2ojJojaKooooo00?o
0000ooooooooool0<_ooool002?ooooo0_l0001RoooooaooYl3[00?oYkcYojNnj_nW_^X01_nW_^X4
ojO0j`CoYkOT2OnW^nP2ojNoj`GoZ;KS2?nW^nP2ojRoj`GoZ;SU2OnW_^X00onW`>_oYkgYojNmj@05
ojNmj@KoYl3[00?oYkgYojO0jonW`>/01_nW`>/6ojS0j`;oYl3[0ol000000onX`>_o0000ojS0j`02
ojS0j`CoZ;oZ1?nY`>/8ojNoj`;oY/3/1_nV_n/Fooooo`03o`000?oooooooooo037ooooo000Poooo
o`?o0000H_oooolNojO0j`GoYkcY2?nW_^X00onW`>_oYkOTojNgi005ojNgi0OoYk_X00?oZK7NojRf
honX]^<01_nX]^<6ojNkj003ojZbgonX^>GoZ;SU00KoZ;SU1_nW_^X2ojVfh`WoYkgY0_nW`>/5ojNm
j@SoYl3[0_nX`>/2ojO0j`?o000000?oYl3[ojS0jonX`>/00_nX`>/01Ol0003oZ<3[ojS0jonX`>_o
Z;oZ00OoZL3[1_nW_n/00onX`>[oY[o[ojJoj`06ojJojaOooooo00?o0000ooooooooool0<?ooool0
01oooooo0_l0001RoooooagoYl3[00?oYk[WojNljOnW_>T01_nW_>T6ojNnjP;oZ;?Q2?nW]n@4ojNk
j0CoZK7N2?nX]^<2ojNkj0GoZ[;O2?nX^>D2ojNnjPKoZKKS1onW_NT00onY]^;oYkgYojNmj@06ojNm
j@KoYl3[00?oYkkZojO0jol000000_l00004ojO0j`GoZ<3[00?o0000ojS0jonX`>/02?nY`>/4ojNo
j`CoZ<3Z2?nV_n/Fooooo`03o`000?oooooooooo033ooooo000Oooooo`03o`000?oooooo000005oo
oooo7?nW`>/5ojNji`SoYkcY0_nW_^X6ojRch@SoYkOT00?oYk_XojVag_nY/Mh01OnY/Mh6ojRfh`03
ojf`f_nZ/]ooZ[;O00KoZ[;O1_nX^>D00on]/mgoZKKSojVfh`07ojVfh`CoYkgY1?nY]^88ojNmj@;o
Yl3[0_nW_^X3o`0000SoYl3[1OnX`>/00ol0003oZ<3[ojS0j`08ojW0j`03ojNojonX`>[oZ<3Z00Go
Z<3Z1_nV_n/00onW_n_oooooooooo`0Eooooo`03o`000?oooooooooo02oooooo000<ooooo`Go0000
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00Co0000oooooooooooo0000FooooolLojO0
j`03ojNhiOnW^^OoYk[W00KoYk[W1_nW_>T00onX/=koZ;?QojRch@07ojRch@KoYkOT00?oZjoKojVa
g_nY/Mh01_nY/Mh4ojRfh`Co[K3J2?nZ/]l2ojRhi@Go[K?M2OnY]^<00onW_NWoZKKRojVfhP05ojVf
hPKoYkgY00?oZKOSojNnj_l000000_l00004ojNnjPKoYl3[00?oYko[ojS0jonX`>/00onX`>/01?l0
003oZ<3[ojS0jonX`>/6ojW0j`03ojS0jonX`>[oZ<3Z00OoZ<3Z0_nV_n/5ojNojaOooooo00?o0000
ooooooooool0;_ooool000cooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01_ooool2o`0000;ooooo00?o0000ooooooooool0EOooool2ojNoja[oYl3[1OnW
^>D8ojNji`;oYkcY1OnX/=h9ojRch@;oYkOT1On[[m/8ojVagP03ojRfhon]/=[o[K3J00Go[K3J1_nZ
/]l00on_[mSo[K?Mojfcg@06ojfcg@OoZKKS00?o[kCLojVfh_nY]^801_nY]^84ojNmj@04ojVghol0
003o0000o`0000SoYkkZ0_nW`>/5ojNoj`GoZ<3[00Co0000ojS0jonX`>_oZ<3[0_nY`>/5ojS0j`Oo
Z<3Z00?oZL3[ojNojonW_n/01_nW_n/Fooooo`03o`000?oooooooooo02kooooo0004ooooo`Ko0000
0oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41001Oooool2o`0000Co
oooo00?o0000ooooooooool0DOooool6ojNojaKoYl3[00?oYkOUojNhiOnW^>D01_nW^>D6ojNji`03
ojR_g?nX/=koZ;3N00KoZ;3N1onX/n400on[[=SoZjoKoj^_f`06oj^_f`KoZK7N00?o[JgGojf`f_n]
/=X01_n]/=X4ojZbg`Co[joH2?n]/md4ojVfh`Co[kCL2?nY]^801?nW_NWo0000o`000?l00004ojVg
h`KoYkkZ00?oZKWUojNojonW_n/01_nW_n/5ojS0j`03o`000?nX`>_oZ<3[00SoZ<3[1?nX`>X4ojW0
j`SoYko[5_ooool00ol0003oooooooooo`0]ooooo`003_ooool00onHV9So8B4Qonk^kP03ooooo`05
o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
04gooooo2_nW_n/BojO0j`GoYkOU2?nW^>D2ojNji`GoZ:oL2?nX/=h4ojRch@CoZjcH1on[[m/4ojVa
gPCo[JgG2?n]/=X00onZ/]oo[joHojn_f004ojn_f0Wo[K?M00?oZKKSojndg?n_]=`01On_]=`6ojVf
hP;o00002?nY]n<2ojNnjPGoZKWU2?nW_n/4ojS0j`03o`000?nX`>_oZ<3[00WoZ<3[00?oZ<3ZojW0
jonY`>/01OnY`>/6ojNoj`03ojS0jooooooooooo01Gooooo00?o0000ooooooooool0;?ooool000oo
oooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`19ooooo`koYko[3_nW`>/9ojNgi@KoYkSU00?oYjgLojR_
g?nX[m`01_nX[m`8ojR`gP03ojRchOn[[=SoZjcH00CoZjcH2?n[[m/00onY/Mko[JgGojf]e`05ojf]
e`Ko[K3J00?o/:oGojn_f?n_[mP01_n_[mP7ojfcg@03ok6`eon_]=co[kCL00Oo[kCL0_nY]^83o`00
00;o/KGL1onY]n<00ona]mkoZKWUojVii@06ojVii@KoYko[00?oZ;cXojS0jonX`>/00onX`>/00ol0
003oZ<3[ojS0j`06ojS0j`?oYl3[2?nY`>/2ojNoj`GoZ<3[5Oooool2o`0002kooooo000@ooooo`05
o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`03ooooo`;o00001oooool00ol0
003oooooooooo`16ooooo`ooYko[3?nW`>/<ojNgi@CoYkSU1?nW[M`8ojR_g0KoZ;3N00?oZJ[Goj^/
f?n[[=P01_n[[=P6oj^_f`03ojf/e_n][MOo[JgG00Ko[JgG1?n]/=X4ok2_e`Oo[joH1?n]/md5ok6`
e`Oo[kCL0ol00006ok6eg0CoZKOS1?na]mh8ojVii@;oYko[1OnX_>P5ojS0j`03o`000?nX`>_oZ<3[
00;oZ<3[1onW`>/6ojW0j`WoZ<3[5_ooool00ol0003oooooooooo`0[ooooo`003?ooool01Ol0003o
^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0@_ooool?ojNoj`coYl3[00?oYkSVojNgiOnW]nD03OnW]nD0
0onW^>GoYjgLojN]g005ojN]g0SoZ:oL0_nX/=h5ojVZe`OoZjcH1?n[[m/4ojf/ePSo[JgG00?o[K3J
ok2_eon`[mL01?n`[mL8ojn_f003ojfcgOna/=Oo/K3G00Ko/K3G0on_]=`3o`0000;o/k;G2?na]M`0
0onY]n?o/KONok6ggP05ok6ggPKoZKWU00?o[kSPojRlj?nX_>P01_nX_>P5ojS0j`03o`000?nW_n[o
Yl3[00WoYl3[0_nY`>/=ojS0jaGooooo00?o0000ooooooooool0:oooool000cooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo03kooooo3onW_n/=ojO0j`CoYkSV3OnW]nD00onV[=_oYjgLojN]
g006ojN]g0OoZ:oL00?oZ:WGojVZeonYZ]L01_nYZ]L7oj^/f003oj^_fon][=Ko[JcF00Go[JcF1_n]
[ML00onc]M[o/:oGok2_e`06ok2_e`Ko[joH00?o]KCHok6`eona/=L01ona/=L3o`0000Ko/k;G1_na
]M`00ond]=So/KONok6ggP06ok6ggPCoZKWU1?n_^>08ojRlj0;oZ<3[0_nW_nX00ol0003oYkoZojNo
jP08ojO0j`ooZ<3[00?oZL3[ooooooooool05?ooool00ol0003oooooooooo`0Zooooo`007_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo03[ooooo3onW_n/>ojO0j`OoYkSV2OnW]nD5
ojJ/f`SoYjgL1?nX[m`4ojRYe`OoZJ[G1_n[[=P00on^/=Wo[JcFojf/eP06ojf/ePCo[JgG1?nc]MX7
ok2_e`Co[joH1?ne]=P5ok6`e`?o000000?o/K3Gojndg?nc/]L01_nc/]L4ok6eg0Co];CH2?na]mh0
0onY^NGo[kSPojnhh005ojnhh0KoZ;cX00?o[;[TojNoj_nW_nX00onW_nX00ol0003oYkoZojNojP04
ojO0j`ooZ<3[1OnY`>/Fooooo`03o`000?oooooooooo02Wooooo000Mooooo`?o00002oooool00ol0
003oooooooooo`0fooooo`ooYko[3onW`>/2ojNji`SoYkSV1_nW]nD00onU[=coYZcKojJ/f`05ojJ/
f`SoYjgL00?oZ:oLojRYeonXZML01?nXZML8ojVZe`;oZjcH1On^/=T8ojf/eP03ojf]eonc]M[o/kGJ
00Co/kGJ2?n`[mL00on_[mSo]KCHokFdf005okFdf004ok6`eol0003o0000o`0000?o/K3G00?o^;WJ
ok>beonc/]L01onc/]L00ona]Mco];CHokBdf005okBdf0Ko/KON00?o]KKIojnhh?n_^>001on_^>02
ojRlj0Go[;[T1OnW_nX01?l0003oYkoZojNoj_nW`>/?ojS0j`OoZL3[5_ooool00ol0003ooooooooo
o`0Yooooo`007Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03;ooooo3onW_n/?
ojO0j`KoYk[W2?nW^>H2ojNgi@GoYJcL1onV[=/6ojN]g003ojNYeonXZMOoZ:WG00KoZ:WG1_nYZ]L0
0on^]=ko[[3Iojj`f@06ojj`f@Ko[JcF00?o/[kSok>ef_nc]MX01_nc]MX6ok2_e`03okJohOne]=So
]KCH00Co]KCH0ol00004ok6`e`Co^;WJ1onc/]L00onj^m[o];CHokBdf006okBdf0Co/KON1?ne]]T7
ojnhh003okFig?n/^^Co[;[T00Ko[;[T1OnW_nX00ol0003oZ;gXojRmj00@ojS0j`OoZL3[5_ooool0
0ol0003oooooooooo`0Xooooo`007Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
02oooooo3onW_n/?ojO0j`03ojNlj?nW^^OoYk[W00KoYk[W1_nW^>H00onT[=goYJcLojF/g006ojF/
g0OoYZcK0_nW[M`5ojNYe`OoZ:WG1?nYZ]L4ojjdgPOo[[3I1?n][=H4ok:nh`Oo/kGJ1?n`[mL4okJo
h@;o]KCH0ol00004okFdf003ok6`eonh^M[o^;WJ00Go^;WJ1Onc/]L3okZkfPSo];CH00?o/KONokFf
fOne]]T01One]]T4ojnhh0Co]KWL2?n/^^@2ojNojP;oZ;gX00Co0000ojRmj?nX_NSoZ;gX1_nX`>/0
0onW_n_oZ<3[ojS0j`06ojS0j`KoZL3[00?oZ<3[ooooooooool05Oooool00ol0003oooooooooo`0W
ooooo`007Oooool2o`0000oooooo00?o0000ooooooooool0:oooool?ojNoj`ooYl3[1OnW_>P8ojNj
i`;oYkSV1OnT[=d7ojF/g0KoYZcK00?oYZSHojNYeonWZML01_nWZML7ojRYe`03ojVZeon^]=ko[[CN
00Co[[CN2?n^/=T00on][=Ko/[kSok:nh`05ok:nh`Oo/kGJ00?o/:oGokJohOnf_n401?nf_n42o`00
00Ko]KCH00?o]/OVokRif_nh^MX01_nh^MX3ok>be`Ko^[_J1_nd]=P00onj^]Wo]KKIokFff@07okFf
f@03ojnhh?ne^Mco]KWL00Go]KWL1_n/^^@00onb^n3oZ;gXojRmj003ojRmj004o`000?nX_NSoZ;gX
ojRmj0;oZ<3[1OnW_n/8ojS0j`;oZL3[1OnX`>/Fooooo`03o`000?oooooooooo02Oooooo000Moooo
o`03o`000?oooooooooo00oooooo0_l0000Xooooo`;oZ<3[3onW_n/=ojO0j`;oYkkZ1onW_>P6ojNj
i`03ojB]g_nT[=goY:cM00KoY:cM1onU[=`2ojJ/f`GoYZSH1onWZML6ojRYe`03ojbihon^]=ko[[CN
00Ko[[CN1_n^/=T00on^b>go/[kSok:nh`06ok:nh`Ko/kGJ0_n_bnh3okJoh@?o00000_nf_n44okFd
f0Co]/OV2?nh^MX00onc/]Oo^[_JokZkfP05okZkfPCo];CH1?nj^]T7okFff@03okZjfOne^Mco]KWL
00Ko]KWL1?n/^^@4ok:kh0GoZ;gX00?o0000ojRmj?n/_>D02?nW_n/?ojS0jaKooooo00?o0000oooo
ooooool09_ooool001gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Rooooo`Ko
Z<3[3onW_n/9ojO0j`KoYkkZ1onW_>P2ojNji`GoY:gN1onT[=d6ojF/g003ojFXf?nVZ=SoYZSH00Go
YZSH2?nWZML2ojRYe`Go[;WS1on^]=h4ojj`f@Co[/S]2?nb_^<2ok>efPGo[l_^0ol00006okJoh@03
okFdf?nfanKo]/OV00Go]/OV1_nh^MX00onfbNSo^[_JokZkfP07okZkfP03okBdf?nj^]Wo^[[I00Go
^[[I1One]]T3okZjf@So]KWL00?o[;[Tok:kh?nb^n001Onb^n04ojRmj004ojbliOl0003o[;cUojbl
i@SoYko[3onX`>/Fooooo`03o`000?oooooooooo02Gooooo000Mooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool07_ooool2ojS1j`SoZ<3[3onW_n/5ojO0j`;oYko[2?nW_^X5ojNlj003
oj>^gonT[MkoY:gN00KoY:gN1onT[=d2ojF/g0GoYJSH1onVZ=P6ojNYe`03oj^mion/^N?o[;WS00Ko
[;WS1on^]=h00on^/=Wo[/S]ojk8k@05ojk8k@Ko/[kS0_nRe_X3ojo;kP?o00000_n_bnh6okJoh@03
ojKAm_nfanKo]/OV00Ko]/OV1?nh^MX4okK9j0Oo^[_J00?o^<SWokZjfOnj^]T01_nj^]T3okFff@Ko
^[[I1_ne^M`00oni^][o/[_Pok:kh007ok:kh005ojRmj?n/_>Go[;cUojbliOl000000on/_>D6ojNo
j`03ojRoj_nX`>_oZ<3[00goZ<3[5_ooool2o`0002Kooooo000Looooo`?o00005?ooool00ol0003o
ooooooooo`0Jooooo`KoZ<7[2?nX`>/?ojNoj`03ojO0jonW_n_oYko[00CoYko[2?nW_^X00onW_>So
XjkOoj>^g`03oj>^g`SoY:gN1OnT[=d00onSYmWoYJSHojFXf005ojFXf0OoYZSH1?nWZML4oj^mi`Oo
[;WS1_n^]=h3ojO?m0Oo[/S]0_nb_^<5oj;FnP?o00001_n_bnh2okJoh@GoY]7f2?nfanH00onh^M[o
]/WXokK9j005okK9j0Go^[_J0onhb>L8okZjf@03okFffOnj^]Wo^[[I00Go^[[I1?ne^M`4okVjfPOo
/[_P00?o]kgNojbliOn/_>D00on/_>D01?l0003o[;cUojbliOn/_>D2ojNoj`GoZ;oZ3onX`>/Doooo
o`03o`000?oooooo000002Kooooo000Looooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool05oooool2ojS1k0OoZ<7[1_nX`>/?ojNoj`03ojO0jonW_n_oYko[00KoYko[1_nW_^X00onT/^;o
XjkOoj>^g`05oj>^g`SoY:gN00?oY:cMoj>WfOnSYmT00onSYmT7ojFXf0OoYZSH00?oYjWGoj^mion[
_NL01On[_NL7ojbih`;o[[CN1onWco@5ojk8k@?oSmkn0_nRe_X3o`0000;oX]Kj1_n_bnh2ohcLo`Oo
Y]7f1_nfanH2oj3DnPOo]/WX0onj^mX6okS8i`Ko^[[I00?o^lKSokZjfOnj^]T01onj^]T00one^Mco
^K[JokVjfP05okVjfPCo/[_P1?ng_Mh5ojbli@03o`000?n/_>Go/KkS00SoZ;oZ1_nX`>/00onW`>_o
Z<3[ojS0j`06ojS0jaKooooo00?o0000ooooooooool08oooool000[ooooo1?l000002?l@413ooooo
ooooooo^k^ko<S8bo`000?lb<S;ok^k^1_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo01Cooooo1OnX`N`7ojS1j`;oZ<3[3onW_n/5ojO0j`SoYko[0_nW_^X5ojBbhPOoXjkO1_nT[Mh0
0onQY]WoXjOIoj>Wf@05oj>Wf@KoYJSH1_nVZ=P2ojVnj@SoZkgW1On/^N<3oj;GnPSoYlod00?o[/S]
ohoNo_n?g_h00on?g_h3o`0000KoX]Kj0_n_bnh6ohcLo`OoY]7f0_nfanH6oj3DnPOo]/WX00?o^[_J
okS8ionhb>L01Onhb>L4okZjf@Co^lKS1onj^]T00onm`]go^K[JokVjfP07okVjfP03ok:kh?ng_Mko
]kgN00Go]kgN1?n/_>D01?l0003o/KkSok6nhona_^<8ojRojP;oZ<3[1OnW`>/8ojS0jaGooooo00?o
0000ooooooooool08oooool000cooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Aooooo`SoZ<7/1OnX
`N/?ojNoj`WoYl3[1_nW_n/2ojFfi@OoY;;R1onS[]l2ojB]gPGoXJKI1_nSYmT7ojFXf0;oYZSH1_nY
_^T8oj^mi`03ojbihonReo[oX]Oj00GoX]Oj1_nWco@3oggNn@04ohoNo_l0003o0000o`0000?oSmkn
0onRe_X6ofWCn0KoS=co0onVdOH5ogOFo@OoX=Cj0onfbNP4oikBnPSo^<SW00?o^[[Iok_6honka^<0
1Onka^<5okZjf@?o_L;M1oni^]X00onm_][o]kgNokNmgP07okNmgP05ojbliOna_^?o/KkSok6nhol0
00000ona_^<6ojRojP03ojVojOnW`>_oYl3[00GoYl3[2?nX`>/Fooooo`03o`000?oooooooooo02;o
oooo00000ooooooo0000o`000004o`0000Gooooo00?o0000ooooooooool00_ooool01Ol@413ooooo
oooooooooooo410@00Kooooo0_l0000Iooooo`03o`000?oooooooooo00kooooo0onW`>/8ojS1k003
ojS1jonW_n_oYko[00goYko[3OnW`>/2ojNoj`KoYKKU1_nT/^86oj>^g`03oj2Vf_nQY]WoXJKI00Go
XJKI1onSYmT5ojFXf0;oYkkZ2?nY_^T6oj^mi`?oW]cm1onReoX2ojO?m0GoOMki0_l00003ohoNoPKo
H<og0omYdoP5of?6o@OoDlCf1_mge_d3oj3DnPCoK<km1onNd_X6okS8i`03ojC>m_nka^?o^lKS00Ko
^lKS0onj^]T6okg2g@Go^K[J0onm_]X7okNmgP03okZng?na_^?o/KkS00?o/KkS00Co0000ok6nhona
_^?o/KkS0_nX_nX5ojVoj@OoYl3[2?nX`>/Fooooo`03o`000?oooooooooo027ooooo000<ooooo`03
o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool02_ooool7ojO0j`KoZ<7/00?oZ<3[ojNojonW_n/02onW_n/?ojO0
j`;oYk_X2?nU]^D6ojBbhP;oXjkO1OnPY]X7oj6Vf@OoXjOI00?oYJSHojNnj_nW_^X01?nW_^X8ojVn
j@;oZkgW1onNg?d3oj;GnPKoL]_e00CoOMkio`000?l0003o00001Om`do`3of3?m`GoOlco1omSa_d3
oe?4mPGoJL7n1_m?_?P6ofc>o@OoW];j0_nhb>L5ojC>mPSo^lKS00?o^[[Iokg2gOnm`]d01Onm`]d3
okVjfPKo_KkJ1?ng_Mh4okZng0Go/KkS00?o0000ok6nhonf`>801onY_nT8ojO0j`SoZ<3[5Oooool0
0ol0003oooooooooo`0Qooooo`003?ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool000001Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Oooooo2_nW`>/2
ojS1k0GoZ<3[2OnW_n/?ojO0j`KoYk_X2?nU]^D3ojBbhP;oWjOL1onPY]X7oj6Vf@KoXjOI00?oYK_X
ojNnj_nW_^X01_nW_^X6ojVnj@?oWMkm1_nNg?d4ogSNmP?oL]_e00CoP]Koo`000?l0003o00000_n2
e_l3og3Co0GoTlSj1omoc?l3of?6o@GoRl;j1omY`Oh6odnln0KoK<km0onNd_X4og3<o`OoY<kf1_nk
a^<00on^bnko_L;Mokg2g@07okg2g@03okVjf_nm_][o_KkJ00Ko_KkJ00?o]kgNokZng?nj_]`01Onj
_]`4ok6nh`04o`000?nf`>;o]/3RokK0hPOoZKoY2?nW`>/7ojS0jaKooooo00?o0000ooooooooool0
8?ooool000cooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Gooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`03ooooo`coYl3[0_nX`N/7ojS0j`SoYko[
3OnW`>/00onX_n[oYk_XojNkj006ojNkj0KoYKKU00?oWj[NoinWg?nOYm`01?nOYm`7oj2VfPOoXJKI
0_nSYmT5ojFkj0SoYkkZ0_nY_^T7oigNo@;oW]cm1Omhg_H3oi7Io`?o00001?n2e_l3oig2lPOoTlSj
0omoc?l5oi^ik@OoRl;j0omY`Oh5ohjjm0KoJ[_m1_m<]_T6og3<o`OoY<kf0_nka^<5ojk;kPOo_L;M
00?o^LSUokfnf_nm_]X01_nm_]X00ono`mgo^[kLokZng007okZng005ok6nhonf`>;o]/3RokK0h_l0
00000_nf`>86ojVoj@;oZkoX2?nW`>/7ojS0jaKooooo00?o0000ooooooooool07oooool000cooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_l0000Nooooo`03
o`000?ooooooYko[00;oYko[2OnW`>/6ojS1j`OoZ<3[2?nW_n/9ojO0j`GoZ;oZ2?nW^nP2ojFfi@Go
Wj[N1_nOYm`6oj2VfPKoXJKI00?oXkKVojFkj?nU^nP01_nU^nP6ojNnjPCoW]om0onMg_d6oh;Sm`?o
Vm[m00CoTMWoo`000?l0003o00000onAfOl00on2e_ooWL;boig2lP05oig2lPGoTlSj00?oYKKUoi^i
kOnK^Nd01onK^Nd3oh_2nPCoXKKW2?n>^_@6ofZko@KoC;Ki1_m`c?l3ojC>mPCoP/go1on^bnh4okg2
g@Co^LSU1_nm_]X3oko3g@Oo^[kL00?o_/7LokK0h_nf`>800onf`>800ol0003o]/3RokK0hP02ojVo
j@KoZkoX1onW`>/8ojS0jaGooooo00?o0000ooooooooool07oooool000[ooooo00?oEEEEofIVI_l0
00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool07?ooool7ojNo
j`KoYl3[2OnX`N/5ojS0j`;oYkk[2?nW_n/8ojO0j`KoZ;oZ1_nW^nP00onP[^7oWj[NoinZgP05oinZ
gPOoWjOL1_nPY]X2oj6Vf@GoXkKV2?nU^nP2ojNnjPKoW]om1?n<ioP3oh;Sm`CoVm[m0ol00003oi7I
o`CoXkk/2?nM`_800onCb?[oYKKUojFfi@03ojFfi@OoVkW]00?oZkORoj6fionQ]^L01_nQ]^L6ohjj
m003ojFfiOn<]o?oS;Oc00KoS;Oc1_mS]O`6odZbn@KoP/go1on^bnh00onm`]go^LSUokW8i@05okW8
i@?o_KkJ1_no`md5okZng0?o_/7L1Onf`>800ol0003o^L;Qoj^oj008oj^oj0OoYl3[2?nX`>/Eoooo
o`03o`000?oooooooooo01kooooo000Kooooo`03o`000?oooooooooo01[ooooo2_nW_n/2ojO0j`go
Z<7[00?oZ<3[ojNnjonW_^/01?nW_^/8ojNoj`SoYl3[1_nX_nX2ojNkj0GoX:kQ1onOZ]h7oinWg0?o
X:KJ0onP[n87oj>fiPKoYK_X1?nRgO`2oikOo@OoS>Oh0onQg?`01?nKf_go0000o`000?l00002oi_J
o@03ojJljOnS_^coXkk/00KoXkk/1_nM`_800onY]N;oYKKUojFfi@05ojFfi@CoVkW]1?n[]n88oj6f
i`;oS[[d1OnU]^D8ohbgl`KoHkGl1_m:/_T6oh;=o`?o[/_^1?nIc?T8okW8i@03okfnf_no`mgo_l?M
00Go_l?M0onj_]`5okk1g0Co]/3R00Co^L;Qo`000?ni`^7o^L;Q1on[_nP00on^`NOoYl3[ojO0j`06
ojO0j`OoZ<3[5_ooool00ol0003oooooooooo`0Mooooo`006oooool00ol0003oooooooooo`0Goooo
o`coYko[0_nW`>/=ojS1j`;oYko[1onW_^/8ojNoj`SoYl3[0onX_nX3oj>di0OoX:kQ1_nOZ]h6oinW
g003oifYg_nP[n;oX:oR00GoX:oR1onS]^H2ojFkj0OoX]gl1?nEj_P2ohcWn0CoXMcl0ol00002oi_J
o@GoY[cY2?nS_^`2oig2lPGoZKGR1onU]^D00onK^NgoZkORoj^ghP05oj^ghPKoXKKW00?o[[WQojFf
iOnU]^D01_nU]^D6ohbgl`;oXkOW1on3]_H6oeJ]nPGoF;Ol1onIc?T6okW8i@03ojk8kOno`mgo_l?M
00Oo_l?M00?o^[kLokk1g?nn`M`01Onn`M`00onf`>;o^L;QokW2h@02okW2h@03o`000?ni`^7o^L;Q
00CoZkoX1?n^`NL8ojO0j`OoZ<3[5?ooool2o`0001oooooo000Kooooo`;o00005?ooool=ojNoj`Ko
Yl3[2OnX`N/6ojNoj`OoYkk[2?nW_n/6ojO0j`03ojJkj?nS]>CoXkCT00GoXkCT1_nP[^47oinZgP;o
WjOL1OnMZMh7oj2_hPGoXkKV0onUf?T5oj;Mo0GoUN[h0onVgo/2oj7Lo0;o00000_nQg?`00onW_NSo
Y[cYojJlj@06ojJlj@KoXkk/00?oZKGQojVeh_nY]N801_nY]N85ojFfi@;o[KSQ1on[]n84oj6fi`Co
[[WQ2?nU]^D2ohbgl`KoXkOW1on3]_H6oeJ]nPGoF;Ol1onIc?T2okW8i@Go[/S]1ono`md00onman;o
_/7Lokk1g005okk1g003ol34gOni`^7o^L;Q00Co^L;Q00Co0000okW2hOni`^7oZkoX1on^`NL7ojO0
j`OoZ<3[5_ooool00ol0003oooooooooo`0Looooo`006_ooool00ol0003oooooooooo`0@ooooo`;o
Z<3[3onW_n/7ojO0j`OoZ<7[2?nW_n/5ojNnj`?oYl3[1onW_n/2ojO0j`GoY[_X1onS]>@6oj2^h@?o
Wj[N0onKY=`8oifYgPOoX:oR00?oXkKVojGHnOnUf?T01_nUf?T00onRgOcoUN[hoiGZn002oiGZn0Go
Y]ok0ol000000onQg?coYkgXojNmj003ojNmj0SoY[cY0_nS_^`5ojVeh@SoZKGR00?oYKKUojfhhOn]
^>401?n]^>47oj^ghP03oj6fion^^N7o[[WQ00Go[[WQ1_nU]^D00on`^n;oXkOWoj>gi`07oj>gi`?o
PkKf0onI]^`6ofnbn@CoC:Oh0_mH]o`3oiW<n@?oO<?m2?n^b>d4oko3g@Co_LOR1Onn`M`3ol34g@Ko
^L;Q00?o0000ok_4hOnka>402?n^`NL7ojO0j`OoZ<3[5Oooool00ol0003oooooooooo`0Looooo`00
6_ooool00ol0003oooooooooo`0=ooooo`KoZ<3[3onW_n/7ojO0j`OoZ<7[2?nW_n/00onW_^_oYl3[
ojO0j`05ojO0j`GoYko[0_nX_n/7ojJkj0OoXkCT0onP[^42oi^Ug@OoVjCL1onMZMh6oj2_hP?oYloe
1_nUf?T3oig]n0?oZnCj0_nVgo/3o`0000;oY]ok00?oZL3ZojNmj?nW_NP01OnW_NP6ojJlj@03ojRd
hOnY]N7oZKGQ00KoZKGQ1_nY]N800on[^>;o[KSQojfhh@06ojfhh@GoZkOR00?o[[[RojjihOn^^N40
1on^^N42ojFfi@Go/;_R1onS]nL00on__>?oVKK/oiVfk005oiVfk0KoKk;i1_m<YoP6ogc3o@So[/S]
00?o_l?Mokg7h_nman801?nman83okk1g0Ko`<CM1?ni`^400onka>7o0000ok_4h@02ok_4h@Ko[/7W
00?o/<;WojO0jonW`>/01OnW`>/6ojS0j`;oYl3[5Oooool00ol0003oooooooooo`0Kooooo`006_oo
ool00ol0003oooooooooo`0;ooooo`WoZ<3[3onW_n/5ojO0j`WoZ<7[1_nW_n/3ojJoj`OoYl3[00?o
Yko[ojRojonX_n/01?nX_n/6ojJkj0KoXkCT00?oVjWPoi^UgOnKYMd01?nKYMd7oi^Tg0OoWJWN0_nP
[n87ojO?m@;oYMSi1?nMkOP4oj_TnP?o00000_nVgo/5ojW0jPOoYkgX0_nV_>T5ojRdh@SoZKGQ0_nY
]N85oj^hhPSo[KSQ00?oZkORojjjh_n^^^800on^^^87ojjih@03ok2lhon`^n;o/;_R00Ko/;_R1?nS
]nL4ojnlh`OoVKK/1_m_/_T6odbWn0KoO<?m1_n^b>d00onOaO?o_LORokg7hP06okg7hP03okk1g?o0
a=go`<CM00Ko`<CM00?o^L;Qok_4hOnka>400_nka>401?l0003o^lCQok_4hOnka>42ojk1i`Go/<;W
1onW`>/2ojS0j`KoYl3[5Oooool00ol0003oooooooooo`06ooooo`Go00003oooool001[ooooo0_l0
0009ooooo`goZ<3[3onW_n/00onW`>_oZ<7[ojS1j`0;ojS1j`;oYko[1onV_n/7ojO0j`OoZ;o[1_nV
^nP2oj>di0GoVjWP1_nKYMd6oi^Tg0KoWJWN0onVaO06ojO?m@CoYNgh0_nMkOP2oj_TnP?o00000_n[
i?X00on/angoZL3ZojW0jP06ojW0jPGoYkgX0_nW]>87ojRdh@KoZKGQ00?oZ[SSoj^hh_n[^>801_n[
^>86ojfhh@03ojfliOn^^^;o[[[R00Go[[[R1?n^^N44ok2lh`So/;_R00?oXkOWojnlhon__><01On_
_><5oiVfk003ojVki_n5/o?oQK?c00GoQK?c1_mGYoP4of:bn`;oO<?m0_n^b>d5oio5l`Ko_LOR00?o
^<OVol34gOo0a=d01_o0a=d00oo2a]ko^lCQok_4h@04ok_4h@03o`000?nka>7o_<KQ00Oo/<;W4?nW
`>/Dooooo`03o`000?oooooooooo00Kooooo00GoV9RHob4Q8Oo^k^koooooodA4A00?ooooo`006_oo
ool00ol0003oooooooooo`06ooooo`;oYl3[3?nX`>/?ojNoj`?oYl3[2_nX`N/4ojNoj`SoY[o[1onW
`>/7ojRoj`?oY[_X0_nM[^<7oi^Yh0OoVjGM1_nKY=`2oifYgPOoY/G`0onWcoD6ojG]n004ok3Zn?l0
003o0000o`0000;oZnCj1On/and8ojW0jP03ojNmj?nW]>;oYkCR00CoYkCR1onX]>42ojVeh@GoZ[SS
2?n[^>82ojfhh@Go[KcU1on^^^800on^^N7o/;cSok2lh`05ok2lh`Ko/;_R00?o/KgSojnlhon__><0
1on__><00onI]^coZK_VojVkiP03ojVkiPOoQK?c1_mGYoP5of:bn`OoWlGc1?nman84okS7iPKo`<CM
0oo2a]h5ok_4h@04o`000?nla^7o_<KQokc6h@Oo/<;W3onW`>/Eooooo`03o`000?oooooooooo00Ko
oooo00?oV9RHob4Q8Oo^k^h04?ooool001[ooooo00?o0000ooooooooool00oooool6ojO0j`SoZ<3[
3onW_n/7ojO0j`GoZ<7[0_nX`>/7ojNoj`KoY[o[2OnW`>/5ojRoj`03oj>fionM[^?oWJkS00CoWJkS
1onKZN07oi^Ug@?oVjCL1?nO^>X8ojK5l003ojO?mOnUkOSoYNgh00?oYNgh0ol00002ok3Zn0;o/=7a
1on/and6ojW0jP03ojJch_nW]>;oYkCR00KoYkCR1OnX]>400onY^NGoZ[SSojZhh`06ojZhh`KoZkSR
00?o[;oXojfliOn]_>D01_n]_>D5ojjjhP03ojk0ion`_>?o/;cS00Oo/;cS0_n`^n85ok6mh`Oo[kcS
00?o/kkSojVki_nY^nH01OnY^nH7ohFcl`KoEjOh1OmR/_/7oio5l`03okg7h_nhanKo^<OV00Go^<OV
0oo0a=d6ol;6gP?o^lCQ0_nla^400ol0003o_<KQokc6h@06ok32i`;o/LCX3onW`>/Eooooo`03o`00
0?oooooooooo00Kooooo00?oV9RHob4Q8Oo^k^h03oooool001[ooooo00?o0000ooooooooool02_nW
`>/7ojS0j`coYko[2onW`>/00onX`N_oZ<3[ojS0j`04ojS0j`OoYko[0_nV_n/=ojO0j`03ojRojonS
]^OoXkKW00?oXkKW1_nM[^<6oi^Yh0KoVjGM00?oVZcSoinhj_nO^>X01_nO^>X6ojK5l0CoZNKj0ol0
0003ok3Zn0Go/=7a1on/and2ojW0jPGoY[?R2?nW]>800onX]>7oZKWUojVii@03ojVii@SoZ[SS0_n[
^>85ojboj0So[KcU00?o[[[Rojk0ion^`>L00on^`>L7ok2lh`03ojo1iona_N?o/KgS00Ko/KgS1?n_
_><4ok>nh`OoZK_V0on5/o<4oiFfkPKoIj[g0omCY?L2of:bn`?oWlGc1?nB`_L8okS7iP03ol34gOo2
a]ko`/KN00Ko`/KN00?o^lCQokc6hOnla^400_nla^400ol0003o_<KQokc6h@02ok32i`Ko/LCX3_nW
`>/Eooooo`03o`000?oooooooooo00Oooooo00?oMgMgofIVI_ooool03_ooool001Wooooo00?o0000
ojO0jonW`>/03?nW`>/7ojS0j`SoYko[3OnW`>/00onX`N_oZ<3[ojS0j`06ojS0j`OoYko[3OnW`>/0
0onV_^[oXkKWoj>fi`05oj>fi`KoWJkS1_nKZN02oi^Ug@GoVZcS2?nO^>X2ojK5l0CoZNKj0ol00003
ok?_mP;o/>[h1on`dO45ojc7k@03ojFdhonV/n;oY[?R00KoY[?R1_nW]>800onW^>GoZKWUojVii@05
ojVii@KoZ[SS00?oZKoZojboj?n/_nP01_n/_nP6ojfli@03ojW0j_n^`>Oo[/3W00Go[/3W1?n`_><4
ojo1i`So/KgS00?o[kcSok>nhonc_^<01Onc_^<5ojVkiP;o/KoT1onE]^h6ofNZm`GoDjCg1onB`_L6
okS7iP03ok;5jOo2a]ko`/KN00Ko`/KN00?o`/SOokc6hOnla^401?nla^400ol0003o_/SRok74j008
ok74j0koYl3[5Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00gooooo000Ioooo
o`03o`000?nW`>_oYl3[00_oYl3[2OnX`>/8ojNoj`WoYl3[1OnX`N/8ojS0j`OoYko[2OnW`>/5ojJn
jPOoXkKW1_nM[^<3oi^Yh0?oUZCO1onJ[><6oinhjPCo[=Wg00?oZNKjo`000?l000001_nckoH3okCM
m@Oo/=7a00?o[<O]ojFdhonU]><00onU]><8ojJchP;oYkCR1OnW^>D7ojVii@;oZ[SS1OnY_nX8ojbo
j0;o[KcU1OnY`>X7ojk0i`03ok2lhon_`NOo[l7W00Go[l7W1_na_N<00ona`NKo/kkSok>nh`07ok>n
h`03ojVki_na_nCo/KoT00Co/KoT1onE]^h6ofNZm`GoDjCg1onB`_L2okS7iPGo//GY1_o2a]h3ol;8
g`Go_<KQ00?o0000okk8h_nnb>801onaa>P00onaaNWoYl3[ojO0j`0;ojO0j`;oZ<3[4oooool3o`00
00Cooooo00Go0000okZj^_ooooooV9RHoa0@400?ooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Kooooo00?o0000oooooonW`>/02?nW`>/=ojS0j`SoYko[1OnW`>/2ojS0j`OoZ<7[1_nX`>/2
ojJoj`OoYko[2?nW`>/6ojJnjPOoXkKW0onM[^<2oiNUg`OoUZCO1onJ[><2oinhjPGo[=Wg0ol00003
okK`m@;o/nof1ondgOD3ok3Al@?oYKKU1onU]><6ojJchP03ojJgiOnW^>GoYkSU00KoYkSU1OnY^ND2
ojRoj`OoZKoZ1_n/_nP00onX_^WoZL3ZojW0jP06ojW0jPGo[/3W0_nY_nX8ojo1i`;o/KgS1Ona`NH7
ok>nh`03ok;0i?na_nCo/KoT00Ko/KoT0onE]^h4oj6kj`KoMJge0omDWo@2oe>Tm`?oT/;g0on5^OL8
ok;5j@?o`/KN1Oo2b=l3okc6h@?o_/SR00?o0000okk8h_nnb>801?naa>P4ok75j@WoYl3[1_nX`>/D
ooooo`03o`000?oooooooooo00;ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00?ooooo`003_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool02?nW`>/;ojS0j`_oYko[00?o
Yl3[ojS0jonX`>/01?nX`>/7ojS1j`;oZ<3[1_nV_n/7ojNoj`SoYl3[1_nV_^X3oj>fi`?oVJ_S1_nG
YMl7oiJTg`GoVZcS0onXbO02ojcIm`?o000000?o[=WgokK`mOnfl?D00_nfl?D3ok[Vm0Ko]=ge00?o
Z[kYojFfiOnU]^D01OnU]^D7ojFdh`;oY[?R1OnV]nD8ojNhi@03ojViiOnX_n_oZ;o[00CoZ;o[1onY
_nX2ojboj0GoZ;kY2?nY`>X00on^`>OoZKoZojVojP04ojVojPKo[l7W00?oZ/7Zok71i_na`NH01_na
`NH4ok>nh`Co//3T1_na_n@00ond`NCoXK_[oj6kj`06oj6kj`KoMJge1OmDWo@6ohFim`So//GY00?o
`/KNol;8goo2b=l01Oo2b=l00onla^7o_/SRokk8hP03okk8hP04o`000?nnb>;o_/SRok74j0Ko/LGY
2?nW`>/8ojS0jaCooooo00?o0000ooooooooool05Oooool000kooooo00Go410@oooooooooooooooo
oa0@4006ooooo`;o00000_ooool8ojO0j`SoZ<3[3?nW_n/2ojO0j`OoZ<3[1OnX`N/3ojO0j`OoY[o[
1OnW_n/:ojO0j`?oY[kZ0_nN/^H7oiV[h`KoUjGO1onFY=l00onJ[>?oZ<W`ojS9l003ojS9l0?o0000
0_n/fOL4okK`m@Oo^^Kd00?o]=geojZnjOnZ_^T00onZ_^T7ojFfi@GoYKCS0_nT]ND7ojJgi@KoYkSU
00?oYko[ojRojonX_n/01_nX_n/5ojVojP03ojNlj?nX_^WoZ;kY00KoZ;kY1_nY`>X2ojNlj0OoZKoZ
0_n_`NL5oj[1jPSo/L7V00?o/kkSok;0i?nb`>@01?nb`>@4ok6oi0Co]<7T2?nQ^n/6ogF]m@GoE9od
1_n5^OL6ok;5j@03ojg3j_o2b=oo`/SO00Go`/SO0_o2bN06okk8hP03o`000?nnb^Co/LGY00Oo/LGY
2?nW`>/7ojS0jaGooooo00?o0000ooooooooool05?ooool000kooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo00?ooooo1onW`>/8ojS0j`SoYko[1_nW`>/7ojS0j`03ojS1
jonW`>_oYl3[00GoYl3[1onV_n/00onW_n_oYl3[ojO0j`0:ojO0j`03ojFmj_nN/^KoW[;V00CoW[;V
1onIZn<5oiNUg`KoUZCO0_nO]nX2ojS9l0?o00000onXbO000on/fOOo]_3eokK`m@02okK`m@Oo^^Kd
00?o]<o^ojZnjOnZ_^T01OnZ_^T7ojFfi@03ojFdhonT]NGoY;GU00CoY;GU1onV]nD2ojNhi@GoYko[
2?nX_n/00onY_n[oYkcXojNlj003ojNlj0SoZ;kY0_nY`>X6ojNlj0GoZKoZ00?oZ;gYoj[1j_nZ`NX0
1_nZ`NX6ok71iP;o[/;Y1onb`>@00ona_nCo]<7TokC1i005okC1i0KoXK_[00?oZ;kZogf^lomm[_<0
1?mm[_<4oeVMl`;oE9od1_n5^OL2ok;5j@Go[L?Z1?o2b=l5ol;9h0Co_/SR00Co_/[To`000?nnb^Co
_/[T1_naaNT2ok35jPSoYl3[1onX`>/Dooooo`03o`000?oooooooooo01Cooooo000>ooooo`05o`00
0?ooooooooooooooool000001Oooool00ol0003oooooooooo`05ooooo`GoYl3[2_nX`>/7ojNoj`Oo
Yl3[1OnX`>/3ojS1j`OoYl3[0onV_n/4ojNoj`WoYl3[1OnU_NX6oijbiPKoVJ_S1_nGYMl2oiJTg`Co
WkOZ0ol00005ojS9l0Co]^Of0oo1kO84ok[Vm0Co]<o^1onZ_^T3ojFfi@?oXkCU2?nT]ND5ojJgi@Wo
Yko[1_nX_n/8ojNlj0KoZ;kY0_nY_NL8ojNlj003ojVoj_nX_NWoZ;gY00?oZ;gY2?nZ`NX2ok71iPKo
[/;Y1Onb`>@00onb`^Ko]<7TokC1i007okC1i0;oXK_[1OnX_^X6ogf^l`GoFIgc1_mm/OD8ojg3jP03
ol;8goo2bN3o`/WP00Ko`/WP00?o_/SRokk:i?nnb^@00_nnb^@00ol0003o_/[Tokk:i002ok75j@Ko
/<GZ1onW`>/7ojS0jaGooooo00?o0000ooooooooool04oooool000kooooo00Go410@oooooooooooo
oooooa0@4005ooooo`03o`000?oooooooooo00Kooooo00?oYl3[ojS0jonX`>/03?nX`>/7ojNoj`Oo
Yl3[00?oZ<3[ojS1jonX`N/01OnX`N/5ojO0j`;oY[o[1onW_n/6ojO0j`03ojS0jonU_N[oYKgZ00Go
YKgZ1_nN/^H6oiV[h`?oUjGO0onEYn82oingjP?o00000onO]nX2ojS9l0Ko]^Of1Oo1kO800onji_Co
]<o^okC?kP05okC?kPGoZ[kY00?oXK?Uoj>diOnS]>D01OnS]>D8ojBei@03ojJgiOnW_n_oYko[00_o
Yko[0_nX_n/<ojNlj0;oZ;kY1_nY_NL6ojNlj003oj^nionX_NWoZ;gY00GoZ;gY1_nZ`NX2ojRnj@So
[/;Y00?o//3Tok;2i_nb`^H00onb`^H7okC1i0;o]<?U1onX_^X6ogf^l`GoFIgc1_mm/OD6ojg3jP03
oj[1joo2bN3o`/WP00Ko`/WP00?o`/_Qokk:i?nnb^@01?nnb^@00ol0003o_/cUokk<i@08ok35jPOo
Yl3[1onX`>/Eooooo`03o`000?oooooooooo01;ooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2o`0000Sooooo3OnX`>/9ojNoj`GoYl3[0onX`>/7ojS1j`03ojO0jonV_n_oY[o[00Co
Y[o[1onW_n/2ojO0j`GoZ<3[1_nU_NX7oijbiP?oVJ_S0_nBXn45oiFWhP?o00001OnO]nX3ok3Cl`Co
]^Of1_o1kO83ok_Nl@Oo]<o^00?oZ[kYoj6ciOnQ/nD00onQ/nD7oj>di@KoY;GU00?oY[gZojNojonW
_n/02onW_n/>ojNlj0;oZKgX2?nY_NL2ojNlj0GoZkkW1onX_NT2oj[1jPKoZ;kY1_n^`^T00onZ`N[o
//;Vok;2iP05ok;2iPCo]<7T1Ond`nD5ojRnjP03oj_1j_n1[_;oPJkb00CoPJkb1?mNW?42oeVMl`Ko
OK7e0_n]`nX5oj[1j`Ko`/WP0oo2bn44okk:i003okk<iOl0003o_/cU00;o_/cU1_n`aNX00on^aN_o
Yl3[ojO0j`05ojO0j`OoZ<3[5Oooool00ol0003oooooooooo`0Booooo`003_ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool02?ooool9ojS0j`goYko[00?oYl3[ojS0jonX
`>/01OnX`>/5ojS1j`;oYl3[1onV_n/5ojNoj`;oYl3[1onX`>/6ojFmjP?oW[;V0onFZ^@6oi:Sh@;o
UJOR0_l00003oiFWhP?oWkOZ1on`do<00onfioKo`Ngbol7]lP03ol7]lPKo^mka1Ondcnh00onS]nOo
XK?Uoj6ci@05oj6ci@OoXkCU0_nT]ND5ojJmjPWoYko[3_nW_>P6ojVmj0KoZKgW00?oZ[kXoj^nion[
_^L01_n[_^L5ojRmj@;oZkoX2?nX_^T2ojk2j@GoZ/7Z1onb`^H00ond`NCo]<?UokC3i@06okC3i@03
ojRnj_n[`N[oZl7Z00?oZl7Z1_n1[_85oejLl@KoNjcb2?nZ`N/3ol;9h0Ko`/_Q00?o_/[Tokk<iOnn
c>D00_nnc>D01?l0003o_/cUokk<iOnnc>D2ok35jPGo[/G[1onW`>/7ojS0jaGooooo00?o0000oooo
ooooool04Oooool001Sooooo00?o0000ooooooooool02Oooool8ojS0j`[oYko[1?nW`>/8ojS0j`03
ojS1jonW`>_oYl3[00CoYl3[1onV_n/00onW_n_oYl3[ojO0j`04ojO0j`OoZ<3[0onU_NX3oiZai`Ko
UZ[T1?nBXn43o`0000KoUJOR00?oWkOZok3Clon`do<01On`do<4ol;[l@;o`Ngb2?nkg_400ondcnko
XkOWoj>gi`03oj>gi`OoXK?U1OnS]>D2oj>ij0OoY[gZ1OnW_n/?ojNlj0;oZ;gX1onY_NP2ojVmi`Go
Z[kX2?n[_^L00onX_NWoZkoXoj^oj004oj^oj0KoZ;kY00?oZKoYoj[1j_nZ`NX01_nZ`NX5ok;2iP;o
/L?W1ond`nD00onea>KoZl7Zoj_1jP05oj_1jPKoPJkb1OmNW?46og^/lPSoZ/7[00?o`/WPol;;hOo2
bn401?o2bn400oo3cN;o_/cUokk<i@04okk<i@03o`000?nnc>Go_LgV00Oo[/G[1onW`>/8ojS0jaGo
oooo00?o0000ooooooooool04?ooool001Sooooo00?o0000ooooooooool02_ooool8ojS0j`OoYko[
1onW`>/6ojS0j`03ojS1jonW`>_oYl3[00KoYl3[1OnV_n/3ojNoj`KoYl3[1OnX`>/2ojBlj`KoV[7W
1_nFZ^@3o`0000?oTZ?Q1OnEYn83ojK1k@Co/=?c1_o2jo43olGXk`Ko^mka0_n^a^`6oj>gi`OoXK?U
00?oXkCUoj>ij?nS^NP01?nS^NP7ojJmjP03ojNojonW_>SoYkcX00goYkcX1_nX_NP5ojVmj003ojVo
j_nZ_^SoZ[kX00KoZ[kX1_n[_^L9oj^oj0;oZ;kY1OnY_nT8oj[1jP03ok;2i_na`nOo/L?W00Co/L?W
1?nd`nD4okG4iPOoZl7Z1_n1[_85oejLl@KoNjcb1_nZ`N/2oj[0jPGo`/_Q0oo3cN86okk<i@03o`00
0?nmcNKo_LgV00Oo[/G[1onW`>/7ojS0jaGooooo0_l0000Aooooo`005oooool3o`0000gooooo1onX
`>/7ojNoj`OoYl3[0_nX`>/5ojS1j`SoYl3[00?oY[o[ojNojonW_n/01OnW_n/6ojO0j`03ojS0jonT
_>_oY;c[00CoY;c[1_nJ/NL2oiJZi0?o00001onBXn400onEYn;oY/7]ojK1k@06ojK1k@03ok3Cloo2
jo7o`^_a00?o`^_a1_o5j>l2ok_Nl@Ko[/K/1_nS]nL3oj6ci@CoXKGV1onS^NP3ojJmjPCoYkkY3_nW
_>P8ojRmj003ojVmj?nY_n[oZKoZ00?oZKoZ2?nZ_^P2oj^ni`_oZkoX00?o[<3XojVojOnY_nT01_nY
_nT6oj[1jP03ojS0jona`nOo/L?W00Ko/L?W00?o]<?UokG4i_nea>H01?nea>H6oj_1jP;oZl;[1_n2
[O43of:Jk`;oGYca1_mk[?82oj[1j`KoZ/3Z0oo2bn45ol?=hP?o_/cU0_nmcNH00ol0003o_LgVokg=
iP06ojk5j`;o[<C[1onW`>/7ojS0ja?ooooo00?o0000ooooool000004Oooool001Oooooo00?o0000
ooooooooool03_ooool5ojS0j`WoYko[1OnW`>/3ojS0j`KoZ<7[1_nW`>/2ojJoj`SoYko[0onW`>/3
ojS0j`OoY;c[1?nJ/NL3o`0000CoUZ[T0onBXn44oiF/iPOoY/7]1?nhfO400oo2jo7oaNS_olGXk`05
olGXk`;o_=W^2?n^a^`3oj>gi`;oWk?V2?nQ]NH5oj>ij0;oYko[1onW_^T6ojNlj003ojJlj?nW_>So
YkcX00GoYkcX1_nX_NP00onX`>_oZKoZojVojP05ojVojPKoZ[kX0_nY`N/:oj^oj0Co[<3X2?nY_nT2
oj[1jPGoZ<3[1_na`nL2ok33j0Oo]LCV0_n[`NX6oj_2j`KoPZga1OmRV^l6ogfYk`SoZ/3Z00?o`/_Q
ol?=h_o3cN801Oo3cN800onnc>Go_LgVokg=iP02okg=iP03o`000?nmcNKo_LgV00;o[/G[1_n/a>/6
ojO0j`SoZ<3[5?ooool00ol0003oooooooooo`0?ooooo`005oooool00ol0003oooooooooo`0?oooo
o`03ojS0jonW_n_oYko[00_oYko[00?oYl3[ojS0jonX`>/01OnX`>/6ojS1j`;oYl3[1_nV_n/6ojNo
j`03ojO0jonX`>_oZ<3[00GoZ<3[1onT_>/3o`0000;oTj[V1_n>Xn<7oiF/iPCoY/7]1OnhfO43olSY
k@CoaNS_1OnlfNh6ojk6k003oineionO/nKoWk?V00CoWk?V2?nQ]NH00onS^NSoYko[ojNoj`04ojNo
j`OoYkkY0_nW_>P5ojJlj0OoYkcX0_nX_NP5ojS0j`OoZKoZ0_nZ_^P6ojW1j`SoZkoX1_n/`>P6ojVo
j@;oZl3Y1onX`>/2ok73i`Ko/<?X1Onea>H2okG6i`SoZl;[1_n2[O45of:Jk`KoOJW_1_nZ`>X00on]
`NWo`lgRol?=hP05ol?=hP03olC@honmcNKo_LgV00Co_LgV00?o0000ok_=j?nkcNP02?n/a>/6ojO0
j`SoZ<3[5?ooool00ol0003oooooooooo`0>ooooo`005oooool00ol0003oooooooooo`0@ooooo`oo
Yko[1onX`>/3ojS1j`CoZ<3[1onV_n/2ojNoj`GoYl3[1onX`>/3ojBlj`?o00001_nCZ^H6ohjSh`Oo
UJcV00?oY/7]okSIlOnhfO401?nhfO46olSYk@03olGXkonlfNko_=W^00Go_=W^0_n^a^`5oinei`Ko
Wk?V1_nQ]NH00onU_N[oYko[ojNoj`06ojNoj`GoYkkY00?oY[_YojJlj?nV_>P01_nV_>P5ojNlj003
ojO0jonX`>_oZ<3[00KoZ<3[1OnY_nX2ojO3k@SoZL7[0on[_nP4oj[1jPOo[<3X0_nY_nT6oj_0j@Ko
Z<3[2On``nP00onea>Ko]LKWokG6i`04okG6i`KoZl;[00?oZ<;/oh2Zkon0Z^l01?n0Z^l4ofFHk0;o
HY[_1_mmZNl2oj[0jPGo[L7Y1?o3cN84olC@h`Co_LgV0_nkcNP00ol0003o^lgXok_=j006ojc4j`03
ojW2k?nW`>_oYl3[00GoYl3[1_nX`>/00onX`N_oooooooooo`0Cooooo`03o`000?oooooooooo00go
oooo000Gooooo`;o00004_ooool?ojNoj`GoZ<3[0_nX`N/7ojS0j`GoY[o[0_nW_n/7ojO0j`GoZ<3[
00CoY;g[o`000?l0003o00001?nI/NP6oi>ZiPKoSZ?S1OnE[>H3oj[5k@Co^=Wa1_o8jNd3olOSk0Go
_=W^0_n[`n`7oinei`KoWk?V0_nQ]NH5ojFmjPSoYko[00?oYkkYojJkjOnV^nT00onV^nT8ojJlj003
ojNlj?nW`>_oYl3[00?oYl3[2?nX`>/00onY_n[oYl?]ojO3k@04ojO3k@KoZL7[00?oY/;]oj[1j_nZ
`NX01_nZ`NX5ojc0j0;o[<7Y2?n[`>T6ojS0j`So/<?X2?nea^L2oj_2j`GoZ<;/1_n0Z^l5ofFHk0Ko
Q:W]2?n]`NT00oo3cN;oa=3SolC@h`05olC@h`03okg=i_nkcNSo^lgX00;o^lgX00Co0000ok_=j?nk
cNSo^lgX0_n/a>/5ojW2k0OoYl3[0_nX`>/5ojS1jaCooooo00?o0000ooooooooool03Oooool001Oo
oooo00?o0000ooooooooool04_ooool?ojNoj`03ojS0jonX`N_oZ<7[00CoZ<7[1onX`>/00onV_n_o
Yko[ojNoj`04ojNoj`OoYl3[00?oZ<3[ojBmjonT_N/00_l00002ojBmj`KoVK7X1OnCZ^H7ohjSh`03
oiF/i_nZaNgoZ/G]00KoZ/G]00?o^=WaolSYkOo8jNd00oo8jNd6olOSk003okcIk_n[`ncoZl?/00Co
Zl?/1onO]NL3oinciPCoX;KX1_nU_NX6ojNoj`03ojFljOnV^nWoY[_Y00GoY[_Y1_nV_>P2ojNnj`Ko
Yl3[1_nX`>/2ojK3kPOoYl?]0_nY`N/5ojK2k@SoZ/7Z00?o[<3Xojc1jOn/`NT01?n/`NT6oj_0j@03
ojc1jOnX`>_oZ<3[00GoZ<3[2?n``nP6okG6i`;o]LOX1onX`^`5oh2Zk`KoIIS/1_n4ZNd6ojg1j@;o
/L?W1_o4d><2olCBi@Go^lgX00?o0000ok_=j?ngcNX02?nY`^`3ojO0j`?oZ<3[2?nX`N/Dooooo`03
o`000?oooooooooo00cooooo000Gooooo`03o`000?oooooooooo01?ooooo3OnW_n/2ojO0j`OoZ<7[
1OnX`>/3ojJoj`KoYko[1OnW`>/01?nX`>_o0000o`000?l00005ojBmj`KoVK7X1OnCZ^H3ohjSh`Co
UZkW1onZaNd4okgIk@03olSYkOo7hncoan?/00Goan?/0_nnen`7oj_3k0GoWkGW00?oW[CXoj2fj?nP
]^P01_nP]^P6ojFmjP;oYko[1OnU_>T7ojJkj@;oY[cX1_nW_^/6ojO0j`;oZ<3[1_nV`nh5ojO3k@;o
YKk/1onV`^d6oj[1jP03ojW1jon/`NWo[<7Y00Ko[<7Y0_n[`>T5ojc1j@OoZ<3[2?n``nP3okG6i`Go
]LOX1onX`^`5oh2Zk`GoIIS/1_n4ZNd4ojg1j@Go/L?W0oo4d><5olCBi@Co^lgX00Co]lgZo`000?ng
cN[o]lgZ1_nY`^`00onX`NcoZ<3[ojS0j`05ojS0j`KoZ<7[00?oZL7[ooooooooool04oooool00ol0
003oooooooooo`0;ooooo`005oooool00ol0003oooooooooo`0Eooooo`SoYko[1_nW`>/7ojS1j`03
ojS0jonV_n_oY[o[00GoY[o[1_nW_n/00onW`>_oZ<3[o`000002o`0000?oZ<3[1_nT_N/3oiVaj0;o
TJ_X1_n;Xn@7oiJ^i`CoZ/G]1OnmfNd3olcTj@Coan?/1Onnen`7oj_3k003oineionN]>SoW[CX00?o
W[CX2?nP]^P3ojFmjP?oYko[1onU_>T5ojJkj@;oY[gZ2?nW_^/3ojO0j`?oYl?]2?nV`nh00onW`ngo
YKk/ojFnk004ojFnk0OoY/;]0_nZ`NX5ojW1j`Ko[<7Y00?oZl7Yojc1jOn/`NT01On/`NT8ojS0j`So
/<?X00?o]LKWokG7j?neanP01OneanP3ojS2k0?oXKo^1OmmYNd4ofZFj@;oIIS/1_n4ZNd00on]`NWo
/L?Wok73i`06ok73i`03olC@hoo4d^Goa=;U00Goa=;U00?o^lgXokO=j_ngcNX00_ngcNX00ol0003o
]lgZokO=jP02ojW2k0GoZ<7/1onX`>/2ojS1j`GoZL7[5?ooool00ol0003oooooooooo`0;ooooo`00
5_ooool3o`0001Oooooo2?nW_n/6ojO0j`SoZ<7[1onV_n/3ojNoj`04ojO0jol0003o0000o`0000Oo
Z<3[0onT_N/2oiVdj`KoTJ_X1_n;Xn@7oiJ^i`03oj[5kOnmfNgo_MW]00Co_MW]1_o<i>T00oo7hnco
_]O/okkGk005okkGk0?oZl?/0onM]^T7oijdj0KoX;KX00?oY[k[ojNojonW_n/01OnW_n/7ojFlj@03
ojJkjOnV_N[oY[gZ00CoY[gZ1_nW_^/2ojS3k@KoYl?]1_nV`nh2ojNlj@OoYKk/0onV`^d4ojBok@Oo
ZL7[0_n/`NT5oj_1j@Oo[<7Y2?nX`>/6ok33j003ok75j?neanSo]LOX00Go]LOX00?o]<WYoj6ok_nQ
_nh01OnQ_nh5ogfUk@GoJYKY1on=ZnX7ok73i`03okS7i_o4d^Goa=;U00Goa=;U00?o`]CXokO=j_ng
cNX00ongcNX00ol0003o]lgZok;;k007ojS1k0OoZ<3[2?nY`N/Dooooo`03o`000?oooooooooo00[o
oooo000Fooooo`03o`000?oooooooooo01Sooooo2?nW_n/6ojO0j`SoZ<7[1_nV_n/01?nW`>_o0000
o`000?l00004ojO0j`GoZ<3[00?oYKk/oiVdjonI]>/01?nI]>/6oi6[j0KoRj?T1OnF[^L3oj_4k0Co
_MW]1_o<i>T3ol_Qj0Go_]O/0_n]and6oiffj@OoW[CX0_nP]^P5ojJnj`OoYko[0onU_>T4ojFljPOo
Y[gZ0_nW_^/6ojS3k@KoYl?]0_nV`nh6ojNlj@GoYKk/00?oZ;kYojBokOnT_nd01_nT_nd5ojW1j`03
ojO0jon[`NWoZl7Y00KoZl7Y1On/`NT2ojc2jPSoZ<3[0_n``nP5ok75j0Co]LOX1?ndbNT6oj6okPKo
OJG]1OmZU^T7ohf[jPCo/L?W1?nhanH4olCBi@Co`]CX1?ngcNX01?nbbnco0000ok;;k?nbbn`7ojS1
k0OoZ<3[1_nY`N/00onX`N_oooooooooo`0Aooooo`?o00002oooool000Cooooo1?l000002?l@413o
ooooooooooo^k^ko<S8bo`000?lb<S;ok^k^1_ooool00ol0003oooooooooo`0Jooooo`OoYko[0onW
`>/;ojS1j`?oY[o[0ol00008ojO0j`03ojS0jonU_^coYKk/00?oYKk/1_nI]>/6oi6[j0KoRj?T00?o
UZkWoj_4k?n[a>`01_n[a>`00onmfNgoc>CYolcTj@04olcTj@Gobn7X00?o_]O/ojg7kOn]and01?n]
and6oiffj@GoW[CX0_nO]nT7ojJnj`GoYko[00?oY;cZojFlj_nU_>X01_nU_>X5ojJmjP;oYl7/2?nX
`nd3ojO3k@?oYkcX2?nW_>T00onU_^coZ;kYojRnj@03ojRnj@SoY;o]00?oZL7[ojO0jonW`>/00onW
`>/8oj_1j@03ojc1jOn/`^[o[<;Z00Co[<;Z2?nX`>/7ok75j003okG7j?ndbNWo]<WY00Co]<WY1onQ
_nh6ogfUk@GoJYKY1on=ZnX00ona`nOo^<OVokS7iP05okS7iP03olCBiOo2e>So`]CX00Go`]CX00?o
]lgZok;;k?nbbn`00_nbbn`00ol0003o//_/ojS1k005ojS1k0;oYko[1onX`>/2ojW1j`GoZ<7[3ooo
ool3o`0000;ooooo00?o0000ooooooooool02Oooool000Kooooo00?o0000ooooooooool00_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool06oooool5ojNoj`03ojO0jonX
`N_oZ<7[00_oZ<7[00CoYko[o`000?l0003o00001?nV_n/8ojO0j`KoYKk/1_nI]>/6oi6[j0?oRj?T
0onD[>L7oj_4k0?o_]?Z0oo<i>T6ol_Qj0;o`]OY1on]and6oiffj@03oijdj?nO]nWoWkOY00CoWkOY
1onV_^/00onW_n_oY;cZojBljP03ojBljPSoYKcZ00?oY[gZojO1k?nW`N`01?nW`N`6ojS3k@03ojS0
jonW_>SoYkcX00GoYkcX1_nW_>T00onZ_>OoZ;kYojRnj@05ojRnj@KoY;o]0_nT_^`6ojO0j`KoZl7Y
2On/`^X8ojS0j`Go/LGX0_ncanT7okC9j@?oXKo^0onE]^h6ogRNj@CoLYKV0_mZU^T3ohf[jP?oUk;Y
1onhanH2oko?iPKo`]CX0_nndnT4ok;;k003o`000?nbbnco//_/00;oZ<7/1_nW_n/6ojS0j`SoZ<7[
2oooool3o`0000Gooooo00?o0000ooooooooool02Oooool000Kooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@00Kooooo0_l0000Mooooo`03ojNojonW`>_oYl3[00?oYl3[
2OnX`N/01?nW_n_o0000o`000?l00002ojNoj`KoY[o[2?nW`>/6ojFnk0?oVKC[0_n@[NX6ohRTi`Oo
U:cW1?n[a>`6okkCjP03olcTjOo;hNSobn7X00?obn7X1Oo2enT7ojg7k@?oWKKY0onK]NT7oingj@Go
Y[k[0_nW_n/6ojBljPKoYKcZ0_nU_N/7ojO1k0;oZ<?]1OnX`>/7ojNlj0;oYkcY1OnZ_>L7ojRnj@;o
Y;o]1_nT_^`6ojO0j`;oZl7Y2on/`^X2oj_3j`SoZ<3[00?o/LGXok?7jOncanT01?ncanT5okC9j@;o
//W/1_nE]^h6ogRNj@GoLYKV1onG/^T4okS7iPGo_loV0oo2e>P5okkCj@Co//_/00?o0000ojc6k?n/
a^`02?nW_n/6ojS0j`SoZ<7[1_ooool4o`0000Sooooo00?o0000ooooooooool02Oooool000Kooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Gooooo0_l0000Oooooo`Ko
Yl3[1onX`N/2o`0000KoYko[0onV_n/;ojO0j`?oYKk/0onL^N`5oi2]jPKoR:CW1onD[>L00on[a>co
_]?ZokkCjP05okkCjPCocMkU0_o;hNP7ol;Gj@?o[LO]1?nN^N`6oi^ej@OoWkOY00?oY[k[ojNojonW
_n/01?nW_n/6ojBljP;oYKcZ1_nU_N/5ojO1k003oj[3k?nX`>_oZ<3[00KoZ<3[1OnW_>P00onW^nOo
Z[cWojZli`06ojZli`GoZ;kY0_n[`NX8ojBnk0?oYl3[0onW_n/9ojc2jPKoZl?[1_nX`>/00onZ`N[o
/lOYok?7j@06ok?7j@03okC9jOnbbNco//W/00Co//W/1_nE]^h6ogRNj@GoLYKV1onG/^T00onhanKo
_loVoko?iP06oko?iP03ol;Dj?nndnWo_]?Y00Go_]?Y00Go//_/ojc6k?n/a^co[<K/o`000002ojc6
k0KoYko[2?nX`>/6ojS1j`04ojO0joooooooooooooooo`?o00003Oooool00ol0003oooooooooo`08
ooooo`001_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001Oooool0
0ol0003oooooooooo`0Oooooo`KoYl3[0onX`N/3o`0000;oZ<7[1OnW_n/2ojJoj`coYl3[0_nW`>`6
oibik0GoT:gZ1_n8Y>L5oiB/i`?oZL3Z1OnndnX5olgNi@?oc]gT1Oo2enT3okK>k0KoW[W/1_nK]NT3
oingj@CoYKg[1onW_n/3ojBljPCoY;c[1onU_N/00onW`NcoZ/?/oj[3k003oj[3k0SoZ<3[00?oYkcX
ojNkionW^nL00onW^nL8ojZli`03ojRnjOn[`N[oZl7Z00CoZl7Z1onT_^`7ojNoj`Ko[<;Z00?o[<?[
oj_3jon[`n/01_n[`n/2ojS0j`GoZ/7Z1_ncanT00oncbN_o//W/ok;9k006ok;9k0KoUKK^1_mhW^T5
og:FiPGoUk;Y0_nQ^>T7oko?iP03ol?EionndnWo_]?Y00Go_]?Y00?o^m;[ojc6k?n/a^`00on/a^`0
0ol0003o[<K/ojc6k002ojNoj`coZ<3[0_nX`N/5ojO0j`;o00004?ooool00ol0003oooooooooo`08
ooooo`001_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41001Oooool0
0ol0003oooooooooo`0Pooooo`?oYl3[0_nX`>/3o`0000KoZ<7[00?oYko[ojJojonV_n/01?nV_n/8
ojO0j`KoYl3/1_nL^N`5oi2]jPKoR:CW00?oU:cWojW0j_nY`>X01OnY`>X3okkCjPGocMkU1Oo>gN@0
0oo2enWo]/k/okK>k005okK>k0KoW[W/0onK]NT2oibgj`SoYKg[1OnW_n/00onS_N_oY;c[ojBlj`06
ojBlj`GoYKg[0_nX`>/6oj[3k0KoZ<3[00?oYKgZojNkionW^nL01OnW^nL6ojZli`;o[L;Y1on[`NX7
ojBnk0OoYko[0_n/`^X5ojc3j`KoZl?[0_nY`n`7oj[1jP;o/lOY1OncbN/6ok;9k003ojW5kOn;Z>Wo
RjSY00CoRjSY1_meUnD4ognLi0;oLYKV00?oUk;Yoj6hjOnQ^>T01?nQ^>T4oko?iPCo`mGW1?nndnT4
ok_Bj`Co[<K/00?o0000ojc6k?nX`^`02onX`>/3ojW1j`SoYl3[4Oooool00ol0003oooooooooo`08
ooooo`001_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
o`0002;ooooo00CoZ<3[o`000?l0003o00000onX`>/5ojS1j`?oYl3[1_nV_n/8ojO0j`KoYl3/1_nL
^N`5oi2]jP?oR:CW1?n=Z>P7ojW0jP03okkCj_o=g^GocMkU00;ocMkU1_o>gN@2olSGi@So]/k/0onN
^N`2oiVej`KoW;O[2?nU_N/00onW_n_oXkg[oj>mj`03oj>mj`SoY;c[00?oYKg[ojS0jonX`>/01?nX
`>/6oj[3k0;oZ<3[1OnU_NX7ojNki`;oZ[cW1_n]`^T5oj_1jP;oZl?[1onT_^`5ojNoj`;oZL3[1on/
`n/2oj_3j`KoZL?/1OnZ`NX2ojk4jPOo/lW[0_nbbN`5ojW5k@KoRjSY1_meUnD5ognLi0SoXKSY00?o
_loVol?Eioo3eNL01Oo3eNL00onndnWo^m;[ok_Bj`05ok_Bj`;o[<K/0_nX`^`00ol0003oZ<;/ojS2
k006ojS0j`03ojO0jonY`N_oZL7[00GoZL7[1_nW`>/00onW_n_oooooooooo`0?ooooo`03o`000?oo
oooooooo00Sooooo0004ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`03o`000?oooooooooo01oooooo0ol00007ojS0j`03ojS1jonW`>_oYl3[00GoYl3[1_nV
_n/8ojO0j`KoYl3/0onL^N`2oi6`k0GoQZOZ2?n=Z>P5ojW0jPCo^LcX00?ocMkUolkMi?o>gN@01?o>
gN@4olSGi@Ko]/k/00?oYL7]oiVejonI]N/01?nI]N/6oibgj`KoYKg[0_nW_n/6oj>mj`KoY;c[0_nU
_N/7ojS0j`?oZ/?/0onW`N`7ojFmjPGoYk_W0_nW`>/8ojg2j@03oj_1j_n[`n_oZl?[00CoZl?[1onT
_^`00onW_n_oZL3[ojW0j`04ojW0j`Go[<?[0_n/a>/8ojW3k003oj[1j_n^a>[o[/CZ00Co[/CZ1Onc
bN/2okC<k0OoZLG]1On;Z>T6ogFGi@KoOicT1_nQ^>T00on]`NSo`mGWol?Ei`05ol?Ei`;o`mWZ1_nk
d^/00ondc^goZ<;/ojS2k003ojS2k003o`000?nX`^coZ<;/00;oZ<3[1OnW`>/7ojW1j`;oYl3[1OnW
_n/@ooooo`03o`000?oooooooooo00Sooooo000Eooooo`03o`000?oooooooooo01cooooo0ol00004
ooooo`GoZ<3[0onX`N/7ojO0j`?oY[o[1?nW_n/7ojO0j`?oYl3/0onR_Nd5oi6`k0GoQZOZ2?n=Z>P0
0onY`>[o^LcXokW<j004okW<j0?obMCS1?o>gN@6olSGi@;o]/k/1OnU`Nd6oiVej`KoW;O[0_nU_N/6
ojNoj`KoXkg[0_nT_>/6ojFmj`GoZ<3[0_n[`^X6ojO1k0OoYKgZ00?oYk_WojO0jonW`>/01?nW`>/6
ojg2j@;o[LK]1on[`n/3ojBnk0?oY;c[2?nY`>/00on/`n_o[<C[ojc4j`04ojc4j`KoZL?/00?oZ<3[
ojk4j_n^a>X01_n^a>X00oncbN_o]<c/okC<k004okC<k0OoZLG]1On;Z>T5ogFGi@OoOicT0_nQ^>T5
ojg1j0Co`mGW1Oo3fNX2ok_Bj`Go]<k]1OnX`^`00ol0003oYko[ojO0j`06ojO0j`KoZL7[00?oZ<7[
ojNojonW_n/01_nW_n/?ooooo`03o`000?oooooooooo00Sooooo000Eooooo`03o`000?oooooooooo
01Wooooo0ol00008ooooo`03ojS0jonX`N_oZ<7[00GoZ<7[1OnW`>/00onV_n_oYko[ojNoj`06ojNo
j`OoYl3[1_nR_Nd5oi6`k0GoQZOZ1_n=Z>P2oingj@Go^LcX1_o9e><00oo>gNCob=OUolSGi@04olSG
i@?o`M7V1_nU`Nd6oiVej`?oW;O[1?nQ^^/7ojNoj`?oXkg[0onS_N`8ojFmj`03ojS0jon[`^[oZl;Z
00CoZl;Z1_nW`N`3ojFmjPCoX[k]1onW`>/2ojg2j@Ko[LK]1On[`n/00onX`>_oY;c[ojBlj`05ojBl
j`KoZL3[0_nZ`n/7ojc4j`;oZL?/1OnX`>/6ojk4jP;o/L[/1ondc>`3ojW5k@?oV[C[1On3W^@4ogRC
h0;oMIOU0omoW>@3ohnVi@So[L7X00?o`mGWol?Ij_o3fNX01?o3fNX2okkHk0Oo]<k]0_nX`^`2ojNo
j`03o`000?nW_n_oYko[00OoYl3[0_nY`N/5ojS1j`KoYko[00?oY[o[ooooooooool03Oooool00ol0
003oooooooooo`08ooooo`005Oooool00ol0003oooooooooo`0Fooooo`?o00003Oooool7ojS1j`03
ojO0jonV_n_oY[o[00?oY[o[2?nW_n/7ojO0j`KoX[g]1OnA/>`5ohJWjP;oSJSX1_nO]nT3okW<j0Ko
bMCS0oo?eml3olSGi@Ko`M7V1_nU`Nd3oiVej`?oV[O/1onQ^^/5ojNoj`;oYKo/1_nS_N`6ojFmj`;o
Y[o[1on[`^X3ojO1k0?oXkk]1onR_^d5ojO0j`;oYlG_2?n]a^d00on[`n_oZ<3[ojS0j`03ojS0j`Oo
Y;c[0_nY`>/6oj[3j`Go[<C[0_n[a>`7ojS0j`;o[/CZ1_nab^`5okC<k0;o/<_]1_nJ]>/5oh>Ni0Go
N9?P1on?Y^D6ojg1j0?o^/kY0oo3fNX5okkHk0Go]<k]0_n/a^d4ojNoj`03o`000?nW_n_oYko[00?o
Yl3[1?nX`>/7ojS1j`;oYko[1OnV_n/?ooooo`03o`000?oooooooooo00Oooooo000Dooooo`;o0000
5Oooool3o`00017ooooo1onX`N/6ojJoj`KoYko[2OnW`>/3oj:mk@?oUkS^1On9[>d6ohFVjPOoWkOY
00?o^LcXolWDhoo9e><01?o9e><5oloGg`03olSGiOo1dNKo`M7V00Ko`M7V0onU`Nd3oi^jkPKoV[O/
1onQ^^/00onW_n_oYKo/ojFok004ojFok0KoXkg/0_nU_N/6ojJoj`GoZl;Z00?oZl7Zoj>nkOnS_^d0
1OnS_^d7oj:nk@03ojO0jonWaNooYlG_00CoYlG_1_n]a^d00onZa>goZ<3[ojS0j`05ojS0j`GoY;c[
0_nV_n/8oj[3j`03ojc4jon[a>coZlC/00CoZlC/1OnX`>/2oj[2j`So/L[/00?o]<c/ok3;kOn`bnd0
1?n`bnd5oiZdj`KoPikT1OmhTn07ohnVi@?o[L7X1_njc^T00oo3fN[o_]S/okkHk005okkHk003okC>
kOn/a^go[<K]00Co[<K]1?nW_n/00ol0003oZ<3[ojS0j`07ojS0j`GoZ<7[0_nW`>/6ojJoj`oooooo
00?o0000ooooooooool01oooool001Cooooo00?o0000ooooooooool04_ooool2o`0001Gooooo1onX
`N/6ojJoj`;oYko[2onW`>/2ojK0k0KoUkS^1On9[>d6ohFVjPGoWkOY0on`a>P3olWDh`OocmOO0_o>
eMh6ol7AiP;o^<_X1_nK^^h6oiZgk0?oXK[[1?nU_^/7ojFok0KoXkg/2?nV_n/00on[`^[oZl7Zoj_1
jP03oj_1jPOoXkk]0onR_^d4oj70k`OoYlG_0_n]a^d5oj[4k@OoZ<3[00?oY;c[ojJojonV_n/01?nV
_n/6oj[3j`WoZlC/00?oZ<3[oj[2jonZ`^/01?nZ`^/6ok7:k003ok;=kOn`bngo/<_]00Ko/<_]1OnJ
]>/5oh>Ni0KoN9?P1on?Y^D00on]`NSo^/kYok[>j@04ok[>j@03ol;Jjonnf>co_]S/00Go_]S/00?o
^MC]ojc6kOn/a^d01_n/a^d01OnW_n_oZ<3[ojS0jonX`>_o000000WoZ<3[00?oZ<7[ojO0jonW`>/0
1?nW`>/6ojJoj`kooooo00?o0000ooooooooool01oooool001Cooooo00?o0000ooooooooool03ooo
ool3o`0001Sooooo1onX`N/7ojJoj`SoYl3[1_nV`>`6oiNhkPGoRJc]1_n5Y^X00onO]nWo/<CXok34
j005ok34j003olWDhoo?emoocmOO00GocmOO1?o>eMh3ol7AiPGo^<_X1_nK^^h3oiZgk0;oV[W]2?nU
_^/5ojFok003oj>nkOnS_NcoXkg/00GoXkg/1_nV_n/00onX`>_oZl7Zoj_1jP05oj_1jPGoXkk]0_nS
_^`7oj70k`GoYlG_0_nW`nh7oj[4k@?oZ<3[1?nU_>T7ojJoj`;oZ/?[2on[a>`2ojS1j`OoZ/;[0_na
b^`5ok;=k@Ko/<_]00?oXk_ZohfShon=Xn<00on=Xn<4ogjDgP;oPikT1_mhTn03ohnVi@CoWkGX1?nj
c^T4ol;Jj`Co_]S/1?nie>d6ojc6k@03ojS1k?nX`>_oZ<3[00;oZ<3[00?o0000ojS0jonX`>/01?nX
`>/3ojS1j`SoYl3[0onV_n/3ojNoj`gooooo00?o0000ooooooooool01oooool001Cooooo00?o0000
ooooooooool03?ooool3o`0001cooooo1OnX`N/3ojO0j`KoY[o[2?nW`>/6ojK0k0KoUkS^1On9[>d3
ohFVjP;oT:kZ1on`a>P3okk:h`GocmOO1_o>eMh00oo1dNKo^<_XokS;j005okS;j0?oVk[^0_nH^>h6
oiZik@SoYKk[00?oYKo/oj>nkOnS_^d00onS_^d7oj>mk0;oY[o[1OnX`>/7oj_1jP03oj>nkOnS_^co
Xkk/00CoXkk/1onQ`>l00onWaNooYl?^ojO3kP04ojO3kPGoZ/C]00?oYkcYojFljOnU_>T01_nU_>T5
ojJoj`;oZL?/2On[a>`6ojS1j`GoZ/;[0_n_bnh7ok;=k@;o/<_]1OnS^nX5ohfSh`GoOYCN1_n4VMl8
oinej003ok[>jOo2f^_o`][[00Go`][[00?o_]S/okWDkOnie>d01Onie>d2ojc6k@GoZ<7/1?nX`>/0
0ol0003oZ<3[ojO0j`07ojS1j`KoYl3[00?oY[o[ojNojonW_n/01OnW_n/<ooooo`03o`000?oooooo
oooo00Oooooo000Cooooo`?o00002_ooool3o`00023ooooo00?oZ<7[ojO0jonW`>/01OnW`>/6ojJo
j`SoYl3[1_nV`>`3oiNhkP;oS[;^1On1Z>d6oi2^jPGo/<CX1Onnb^<3oloGg`Koc]GN0oo;dMl5okS;
j003ojk6jonH^>koV;S^00CoV;S^1_nJ^Nd6ojFnj`;oY[o[1_nS_^d5oj>mk0;oXkk]1onX`>/5oj_1
jP;oZl3Y1onS_^`3oj70k`CoYKo/1onW`nh00onZa>goYkcYojNlj@03ojNlj@SoYKcY00?oY[o[ojW3
k?nY`n`01?nY`n`5oj_4k0;oZlG]2?nX`N/00onZ`^_o[l_^ojo;kP04ojo;kPGo//g]0_nacNh6oj>k
jPKoSJ?S1OmnU=h6ohBIg`KoWkGX00?o[/CZol;Jjoo2f^/01Oo2f^/2ol7MkPKo^MC]00?o/Lc^ojS1
k?nX`N`01_nX`N`2ojS0j`;oYl3[00?o0000ojO0jonW`>/01onX`N/2ojO0j`GoY[o[1onW_n/;oooo
o`03o`000?oooooooooo00Oooooo000Dooooo`03o`000?oooooooooo00Kooooo0ol0000Uooooo`Oo
Yl3[0onV_n/4ojNoj`OoYl3[0onV`>`3oj:nk@GoS[;^1On1Z>d6oi2^jP?o/<CX1onnb^<00oo?emoo
c]GNolkEgP04olkEgPGobm7O00?o^<_Xojk6jon^a^/00on^a^/6oiRhkPKoV[W]0_nU_^/6ojJoj`Ko
Xkk]00?oXkg/oj>nkOnS_^d01?nS_^d7ojS0j`03oj_1j_n[`>WoZl3Y00CoZl3Y1OnS_^`2ojNmj@Oo
YKo/1OnW`nh2ojNmj@KoYkcY1_nU_>T00onW`NcoZL?/ojW3k006ojW3k003oj_4k?n[aNgoZlG]00Co
ZlG]1_nX`N/00onY`nco[l_^ojo;kP06ojo;kP03ok;=kOnacNko/Lg^00Co/Lg^1_nS^nX5ohfSh`Ko
OYCN1On4VMl4oinej0Co[/CZ1?o2f^/5ol7MkP;o^MC]1Onac>h6ojS1k0GoYl3[00?o0000ojO0jonW
`>/01_nX`N/00onX`NcoY[o[ojJoj`06ojJoj`?oYko[0onW`>/;ooooo`03o`000?oooooooooo00Oo
oooo000Dooooo`03o`000?oooooooooo00?ooooo0ol0000Yooooo`GoYl3[00?oY[o/ojNojonW_n/0
1_nW_n/7ojO0j`KoX[k]1On>/^h5oh6Xk@KoT:kZ00?o/<CXokk:honnb^<01Onnb^<3olS=gP?oc]GN
1_o;dMl2olK<g`Ko[/K[1_nH^>h3oiZik@CoW;_^1onV_n/3oj>nk@?oX[k]1onS_^d3ojS0j`CoZ<7[
1on[`>T00onS_^coYkgYojNmj@04ojNmj@OoYKo/00?oYl?^ojNmjOnW_NT01?nW_NT6ojNlj@;oYKcY
1OnW`N`6ojW3k0;oZ/G]1on[aNd2ojS1j`GoZL?/1_n_bnh00on`c^oo/Lg^ok7=kP06ok7=kP?oXk_Z
0_nCY>44ohJFg0;oSJ?S1_mnU=h5ohBIg`03oinej?n^a>[o[/CZ00Go[/CZ00?o`][[ol7Mk_o1gNh0
1?o1gNh2ok[Gk`Oo/Lc^0_nX`N`9ojO0j`03o`000?nW`>_oYl3[00;oZ<7[1OnX`N`6ojJoj`03ojNo
jonW`>_oYl3[00GoYl3[2oooool00ol0003oooooooooo`06ooooo`004oooool01?l0003ooooooooo
ooooool3o`0002gooooo00?oYl3[ojJok?nV_n`00onV_n`8ojNoj`OoYl3[1_nR_^d5ohjbkPGoPJS]
0on@[^X4oj2hj@Co_/[S1_o8cMh00oo>eMkobm7Ool_Ag`04ol_Ag`Coa/cO1_n^a^/3oiRhkP?oU[W_
1onL^nh5ojJoj`;oYko[1_nR_^d5oj>nk@;oXko]1onX`N/5oj_0j@;oZl7Z1onW_NT3ojFok0CoZ;gX
1onW_NT3ojNlj@?oY[o[1onW`N`2ojW3k0KoZ/G]1On[aNd2ojO0j`OoZL?/0_n_bnh5ok3>k`Ko/Lg^
00?oYK[Xoi>ThOnCY>401?nCY>45ohJFg0KoPY?K1_nFZnD6ojk4jP?o_MS]0oo1gNh5ok[Gk`Go/Lc^
0_nY`n`:ojO0j`03ojS1jol0003oZ<7[00SoZ<7/0_nV_n/5ojNoj`OoYl3[2_ooool00ol0003ooooo
ooooo`06ooooo`004oooool4o`0003;ooooo1OnV_n`8ojNoj`OoYl3[0onR_^d2oiZkk`GoQjo_1_mo
Ynd8oj2hj@03okk:hoo8cMkob<gN00Cob<gN0oo=c]X4ol_Ag`Koa/cO0on^a^/3ojO1k0KoU[W_1onL
^nh00onV_n_oYko[ojNoj`04ojNoj`KoX[k]00?oXkk]oj>okOnS_nd01?nS_nd7ojS1j`03oj_0jOn[
`N[oZl7Z00CoZl7Z1OnW_NT00onZ`>WoZ;gXojRmj006ojRmj0GoYkgY0_nW_n/6ojJoj`GoYl7/0_nY
a>h8oj[5k@03oj_5kOnW`>_oYl3[00CoYl3[1OnY`n`2ojk<k`Oo/<k_0_nacNh5ojFjj0KoTjCQ1On6
U]`6oh:Cf`KoUZ_U0on^a>X6okgHk@03ol7Mk_njenoo^]O_00Go^]O_00?o/Lc^ojW3k?nY`n`01?nY
`n`7ojO0j`CoZ<7[00?o0000ojS1jonX`N`01OnX`N`9ojNoj`?oYl3[0onX`>/:ooooo`03o`000?oo
oooooooo00Kooooo000Cooooo`;o0000=Oooool5ojJok0SoYko[1_nW`>/6oiZkk`GoQjo_1_moYnd6
oj2hj@;o[/7X1Oo8cMh6olg>fP03ol_Agoo6c=ooa/cO00Coa/cO0_o3b=h6ojO1k0KoU[W_0onL^nh4
oiflk`OoYko[1_nR_^d7oj>ok@?oZ<7[1?nV`Nd7oj_1jP03ojNmjOnZ`>WoZ/3Y00?oZ/3Y2?nX_NP0
0onW_NWoYko[ojNoj`04ojNoj`KoY[o[00?oYl7/ojW4k_nYa>h01?nYa>h6oj[5k@03ojW3k?nW`>_o
Yl3[00KoYl3[00?oZL?/ojk<kon^c>l01?n^c>l5ok3>k`;o[l_^1_nU^^P6oi>Th@KoQYKL1On2Tm/7
oiJ[i@03ojk4j_nmf>go_MS]00Co_MS]0_o1hNl6ok[Gk`03ok?@konY`ncoZL?/00KoZL?/1onW`>/3
ojS1j`03o`000?nX`N_oZ<7[00;oZ<7/2onW_n/00onW`>_oZ<3[ojS0j`05ojS0j`Wooooo00?o0000
ooooooooool01_ooool000Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000
ooooooooool0<oooool6ojJok0OoYko[1_nW`>/6oiZkk`GoQjo_1_moYnd2oj2hj@Ko[/7X0oo8cMh6
olg>fP;oc/cH1Oo6c=l4ol?8gPKoYl7/0onF^Nl4oiJjl0KoWKc_1OnW_n/2ojO0k0KoX[k]1OnS_nd2
oj?0kPOoY/7]1On[`NX2ojS2k0KoZ/3Y1_nX_NP00onX`NcoYko[ojNoj`06ojNoj`?oY[o[1?nXa>h6
ojW4kP;oZ/G]1OnY`n`6ojO0j`03ojW7kon^c>oo[/c_00Ko[/c_00?o/<k_ojo;k_n_bnh01?n_bnh6
ojFjj0KoTjCQ1On6U]`6oh:Cf`?oUZ_U1?nV_NX4okgHk@Go`N7_0_njenl5ok?@k`KoZL?/00?oYko[
ojO0jonW`>/01_nW`>/3ojS1j`03o`000?nX`NcoZ<7/00WoYko[1OnW`>/7ojS0j`Sooooo00?o0000
ooooooooool01_ooool00005oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Wooooo00?o0000ooooooooool0<oooool6ojJok0GoYko[2?nW`>/6oiZkk`GoQjo_0omo
Ynd3ohJ/kPSo[/7X00?ob<gNolg>f_o=c]X01?o=c]X4olk<f0?oa/cO1_o3b=h3ojO1k0?oY;k/1onF
^_06oiflk`03ojNojonW`>coYl3/00CoYl3/1_nR_^d00onS_ngoXl3^oj?0kP04oj?0kPOoY/7]00?o
Zl7ZojS2k?nX`^`01?nX`^`6oj[0j@;oZ;gX1OnX`N`6ojNoj`03ojO4k_nXa>koZ<C^00KoZ<C^0onY
a>h3ojW4k@OoZL?/0_nW`>/5ojW7k`Ko[/c_0_n_co47ojo;kP?oYK[X0_nFX]d6oh^Ff@CoQY?I0_n6
U]`3oh:Cf`;oTZCQ2?nV_NX00onmf>go`N7_ol7Qk`04ol7Qk`03ok[Jl?ncd>oo/m3_00Ko/m3_0_nY
`n`5ojNoj`KoYl3[00?oZ<7[ojS1k?nX`N`00_nX`N`00ol0003oZ<7/ojS1k005ojNoj`03ojJojonW
`>_oYl3[00GoYl3[1_nX`>/00onX`N_oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo0000
1?ooooooV9RHob4Q8Oo^k^h4ooooo`05oa0@4?ooooooooooooooool@41002_ooool00ol0003ooooo
ooooo`0cooooo`KoY[o/00?oYko[ojO0jonW`>/02_nW`>/3oiZkk`CoT[Oa1Omn[?45ohJ/kPKo[/7X
0_nfa>D5olg>fPKoc/cH00?oa/cOol?8g_o3b=h01?o3b=h2ol75g@KoY;k/1onF^_03oiflk`?oWKk`
1onW`>`3oj:nk@?oXkk]1onS`>h3ojK1k@CoY<;^1onX`^`3oj[0j@?oYl;]1onX`N`2ojNoj`GoYlC^
1_nXa>h2ojS5kPKoZLC]1OnY`n`2ojS2k@OoZLO_0_n^c>l6ojo?l@?o[l_^0onR/N<6oiJRg@KoRiKI
1On6TmT6oi:Th@KoY[gZ0onhe^l3ol7Qk`Co^][`1_ncd>l00onZa>coYko[ojNoj`06ojNoj`;oYl3[
1OnX`N/4ojS1k004o`000?nX`NcoZ<7/ojNoj`GoY[o[1onW`>/2ojS0j`GoZ<7[1oooool00ol0003o
ooooooooo`06ooooo`000_ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool0
00002oooool2o`0003Cooooo0onV_n`3ojJoj`[oYl3[1?nU_n`6oi:gl@GoOZca1On6[>h3ojk1j0Go
]/CU0oo=c]X6olk<f0;ocLWF1Oo3b=h4ol75g@KoY;k/0onF^_04oiFkl@KoWKk`1OnW`>`2ojK1k@Ko
Xkk]1OnS`>h2oj;0kPOoY<;^1OnX`^`2ojG3kPKoYl;]1OnX`N`2ojK4kPOoYlC^0_nXa>h6ojS5kPKo
ZLC]00?oZL?/ojS2kOnX`^d01?nX`^d5ojW7k`?o[Lka1On_co400on/`n_oX[7Soj:ah`05oj:ah`Ko
UZ;M1_n;U]T5ohJCf@KoTZCQ0onV_NX6okSFk`03ol7Qkonjf_3o^][`00Co^][`0_ncd>l5oj[4k0Ko
Yko[00?oYl3[ojS1jonX`N/01_nX`N/3ojS1k003o`000?nW`>_oYl3[00OoY[o[0onW`>/3ojS0j`So
Z<7[1oooool00ol0003oooooooooo`05ooooo`000oooool00omgMgOoIVIVooooo`02ooooo`05o`00
0?ooooooooooooooool000003Oooool00ol0003oooooooooo`0booooo`KoY[o[2?nW`>/6ojFok0Ko
T[Oa1Omn[?45ohJ/kP03ojk1j?nfa>Go]/CU00Go]/CU00?ocLkJolk<f?o>c=P01?o>c=P4olg9eP?o
`lSN1_o1aMd3ojBnk0CoY;g[1_nE^o46oifnl003ojO0k?nV`NgoY/7]00CoY/7]1_nS_^d00onS`>ko
X/3^oj;0kP04oj;0kPOoY<;^00?oZ<;/ojG3k_nU`nh01?nU`nh6ojO2k@03ojS1k?nVa>koY/C^00Co
Y/C^1onWa>h8ojS5kP?oZLC]0onW`N`7ojS2k@03ojW7kon]c_7o[Lka00Go[Lka00?o[loaojc3jon/
`n/00on/`n/6oj:ah`KoUZ;M1_n;U]T5ohJCf@OoTZCQ00?oY[gZokSFkonhe^l01?nhe^l2okkSl@Go
^][`0ondd_06oj[4k0;oYko[1OnW`>/6ojS1j`03ojS1k?nW`>_oYl3[00;oYl3[00?o0000ojO0jonW
`>/01OnV_n/2ojNoj`KoZ<3[1_nX`N/00onX`>_oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo0004ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`0<ooooo`03
o`000?oooooooooo03;ooooo1_nV_n/8ojO0j`KoYKo/0onB]o42oh^dl@GoNJ_b1_nA/nh6okK4i@?o
_LKQ0oo>c=P7olg9eP03ol?8g_o1aMgo`LGM00Co`LGM0_o0`]/7ojBmj`KoUK_a0onM__03oi^ol@Oo
Y/7]0onS_^d3ojFok0OoX/3^0onT`^h3oj?2k`SoYL?^0onW`^d4ojG4k`KoY/C^1onWa>h6ojS5kP03
ojO0jonW`NcoYl7/00GoYl7/1OnX`^d3oj_=lPGo[Lka0_n^cO06ojc3j`KoX[7S1_nFX]d6oh^Ff@Go
QY?I0onBY>44oj>kjPCo^=K_1Onnho400onjf_3o]=;`okCBl005okCBl0?oZ/C/0onW_n/7ojO0j`;o
Z<7[1OnX`N`4ojO0j`04o`000?nW`>_oYl3[ojJoj`KoYko[1_nX`>/2ojS1j`GoZ<3[1_ooool00ol0
003oooooooooo`05ooooo`0000Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03oooool00ol0003oooooooooo`0booooo`OoY[o[1onW`>/3ojFok0?oXkk]1On;]?45
ogV[lPKoTK?^0onfa>D6okg6h@03olk<f?o=bMKocLWF00GocLWF0_o<a]@5ol75g@Co`<;K1onT_N/3
oiFkl@?oUKcb1_nK_o45ojK1k@;oY<?_1_nU_n`5oj;0kP;oXkk]1_nS`^l6ojG3kP;oY<;_1onUa>l3
ojK4kP?oY/?^1onWa>h2ojS5kPGoYl3[1onW`N`00onX`^goZlgboj_=lP05oj_=lP03ojg>lOn^cO3o
[/g`00Co[/g`1_n/`n/3oj:ah`;oUigH1_n?U=D6oh^De`KoTjCP1onS^nX00onhe^oo_^?aokkSl@04
okkSl@;o^M_b1_ndd_000onZa>coYko[ojNoj`05ojNoj`GoYl3[00?oZ<7[ojS1k?nX`N`01_nX`N`3
ojO0j`03ojNojol0003oYko[00SoYko[0onX`>/2ojS1j`SoZ<3[1Oooool00ol0003oooooooooo`05
ooooo`0000GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04?oo
ool2o`0003Cooooo1_nV_n/7ojO0j`KoXkk]1On;]?45ogV[lPKoTK?^00?o]/CUokg6hOnma^401?nm
a^43ol;6gPGocLWF1?o<a]@3ol75g@Ko`<;K0onT_N/4ojNlj0KoUKcb1_nK_o400onV`NgoY<?_ojC3
k`04ojC3k`KoYKo/00?oX/3^oj>nkOnS_^d01?nS_^d6oj?2k`;oYL?^1_nT`^l5ojG4k`;oYL7]1_nV
`nh5ojO4kP;oYl3/1onW`>/3ojO1k0CoZ<[b1_n[cO82oj_?l`Oo[/g`0on/`n/2oifUf`KoUigH1_n?
U=D6oh^De`KoTjCP1OnS^nX3okKHlP;o_^?a1_nifo82okCBl0GoZ/C/1onW_n/00onW`>_oZ<7[ojS1
j`03ojS1j`KoZ<7/00?oYl3[ojNojonW_n/00_nW_n/00ol0003oYko[ojNoj`06ojNoj`03ojO0jonX
`N_oZ<7[00CoZ<7[1_nX`>/00onW_n_oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo000O
ooooo`03o`000?oooooooooo03;ooooo1_nV_n/7ojO0j`KoXkk]1On;]?45ogV[lP?oTK?^0onJ^Nd5
okg6h@Go`/KN0oo=bMH6olc6e003ol75gOo0`]_o`<;K00Co`<;K00?o`;kHojNlj?nW_>P01_nW_>P6
oiFllP?oVkoa0onH_o<7ojC3k`?oYKo/0onW`^d7oj>nk@?oXl;_1?nT_nd7ojC2k`03ojG4konU`Ngo
YL7]00CoYL7]1_nV`nh00onWa>koYl3/ojO0k004ojO0k0GoYl3[0_nWbO47ojS:lP;oZlgb1_n[co<3
ojk=l0?oY[7P1_nMYM/5oiNMf0KoSiCE1_n;U=L7oi>Th003oj>kj_nff?;o]]Sb00?o]]Sb0onli?<5
okWKlP;o/]7`1onZa>`3ojNoj`?oYl3[1onX`N/2ojS1k0GoYl3[1?nW_n/00ol0003oYko[ojNoj`02
ojNoj`GoYl3[1_nX`N/2ojS0j`GoYko[1?ooool00ol0003oooooooooo`05ooooo`008?ooool00ol0
003oooooooooo`0booooo`?oY[o[0onW_n/7ojO0j`?oXkk]0onO_Nh5ohNclPGoMZ_c1_nJ^Nd3okg6
h@Oo`/KN00?ocLWFolc6e?o<a]@01?o<a]@2ol[3d`Go`<;K0oo0_]P8ojNlj0?oUKcb1?nF_?85oiRo
l`GoY<?_0_nO`o86ojO2k@GoXkk]0_nW`N`7ojBok@?oY<;_0onU_n`8ojG1k@?oY/?^1?nW`N`6ojO0
k003ojO0jonWbO7oYlWa00CoYlWa1OnXb_83ojW?m0GoZloc00?oZK[VojJah?nV/N001OnV/N06oifU
f`GoUigH1_n?U=D5oh^De`KoTjCP0_nT_N/3okKHlPKo_>Cc00?o^M_bok;Al?nbdO001?nbdO05oj[4
k003ojNojonW`>_oYl3[00GoYl3[1OnX`N/2ojS1k0OoYl3[1?nW_n/00ol0003oYko[ojO0j`07ojO0
j`GoZ<7[2?nW_n/3ooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo03;o
oooo1_nW_n/8ojO0j`GoWkg^1On7/o85ogJ[l`KoV[W]00?o_LKQol;6g_o2a]h01Oo2a]h2ol?5g0Go
c<KD1?o:`m<3ol32f`Go`;kH1_nW_>P2ojjjh`OoU[cb1OnH_o<00onT`nooWl?boio3lP04oio3lPKo
Yl;]00?oXkk]ojO1k?nW`N`01?nW`N`5ojBok@;oYl;]1_nU_n`6ojG1k@03ojO2kOnW`NcoYl7/00Ko
Yl7/0onW`>`4ojK9l@KoYlWa00?oZ<[bojW?m?nYco@01OnYco@00on[co?oZK[VojVjiP03ojVjiPKo
Y[7P1_nMYM/5oiNMf0KoSiCE1_n;U=L2oi>Th0KoY;g[00?o]]SbokcTlonli?<01?nli?<00onffo?o
/]7`ok;Al006ok;Al003oj[4k?nW_n_oYko[00?oYko[1onW`>/00onX`N_oZ<7/ojS1k004ojS1k0Go
Yl3[1OnW_n/00ol0003oYko[ojNoj`06ojO0j`OoZ<7[1onW_n/4ooooo`03o`000?oooooooooo00Co
oooo000Rooooo`03o`000?oooooooooo03;ooooo1_nW_n/8ojO0j`GoWkg^1On7/o85ogJ[l`?oV[W]
1?nQ_Nd4ol;6gPGo`lGL0oo<a]@6ol[3d`03ol32foo0_]So`;kH00Go`;kH0_nW_>P6ojjjh`GoU[cb
0_nK^^h6oiO1m0KoWl?b0onW`^d3ojC6l@OoYl7/00?oY;o]ojO2kOnW`^d01?nW`^d6ojFok0;oYL7]
1OnW`^d6ojO1k003ojK:l_nVbO7oY/Wa00KoY/Wa0onWbO44ojO?m@GoZLod00?oZ/7ZojVji_nY^^H0
1OnY^^H6ojJah0KoWJGK1OnGWMP6ohnDe@?oRiCG0onIZ^86ojBmj`;o]]kd1?nli?<4okKKl`Ko/]7`
00?oZL?/ojNojonW_n/01OnW_n/3ojO0j`_oZ<7/00?oYl3[ojNojonW_n/01onW_n/00ol0003oYko[
ojNoj`02ojO0j`_oZ<7[1onW_n/3ooooo`03o`000?oooooooooo00Cooooo000Sooooo`;o0000<ooo
ool3ojNoj`_oYl3[0_nO_Nh4oibmk`GoQ;?d1Ome[?@7oj6mk@03ol;6g_o3aMco`lGL00Go`lGL00?o
c<KDol[3doo:`m<01?o:`m<2olW0d@Ko`;kH0oo1^m@7ojjjh`03oiJll_nK^^koVk[^00CoVk[^1_nG
`O@3oio3lP?oVL?e1_nTa_45ojO1k0;oYLOa1onW`^d3ojFok0?oYlK`1onW`^d2ojO1k0GoY/[b1_nV
bO400onUc_GoYloeojO?m@06ojO?m@03ojW?m?nZ`N[oZ/7Z00?oZ/7Z1onY^^H3ojJah0;oW9cC1_nG
Um85oi6DdPKoT9WH1onIZ^83ojBmj`Go]]kd00?o_>CcokKKlonffo<01Onffo<2ok;Al0GoZL?/1OnW
_n/2ojO0j`coZ<7/2onW_n/00onW`>_o0000ojO0j`0;ojS1j`[oYko[0_ooool00ol0003ooooooooo
o`04ooooo`009Oooool00ol0003oooooooooo`0booooo`goYl3[1_nL_Nl5ohBcm0GoMJcd1OnQ_Nd2
ojBok@Ko`lGL0_o3aM/5ol[3d`CobL3A0oo0_]P6ol6ke0Go[[[S0_ne^=`7oi^jkP?oUl7d0onG_o<6
oiW3m@KoY<Ka00?oYl7/ojG7lOnUao401?nUao45ojO2k@;oY<Wc1_nWa_05ojO2k@?oY<_d1_nVb_82
ojK9l@GoYLke1_nWcoD00onYa>goZ/7Zoj[1jP05oj[1jP?oZK[V0onPXMD6oibLd`KoUiOB1OnAU=86
oi2If0OoVJ[R00?oY;g[okKNm?nfg_@00onfg_@3okWTm0Go]]_c00?o[lg_ojW3k?nY`n`01_nY`n`0
0onW_n_oYl3[ojO0j`04ojO0j`SoZ<7/3?nW_n/4ojO0j`03o`000?nW`>_oZ<7[00KoZ<7[3?nW_n/0
1?nW`>_oooooooooool00006ooooo`009_ooool00ol0003oooooooooo`0booooo`goYl3[1_nL_Nl5
ohBcm0GoMJcd00?oXKg]ojBokOnT_nd01?nT_nd3ol?5g0Go`lGK0oo:`m<6olW0d@03ol2nf?o1^mCo
`K_D00Ko`K_D00?o[[[SokFhg?ne^=`01?ne^=`5oi^jkP;oYKGT1_nG_o<6oiW3m@?oY<Ka1?nLa_D6
ojG7l@03ojO2kOnTbO?oY<Wc00CoY<Wc1_nWa_000onW`^goY<_dojC;m005ojC;m0?oY/[b1?nSc_H6
ojG>m@;oYloe1OnYa>d5oj[1jP03oj>Te_nPXMGoX:7E00GoX:7E1OnLW=<6oiNGdPKoTICB1_n@VMP3
oiVZhPCoYlS`0onfg_@6okWTm003okKKlon_cNoo[lg_00?o[lg_1_nY`n`9ojO0j`GoZ<7/3onW_n/3
ojO0j`03o`000?nW`>_oYl3[00OoZ<7[2?nW_n/5ojO0j`03ooooool0003ooooo00Gooooo000Woooo
o`03o`000?oooooooooo03;ooooo3OnW`>/3oibmk`?oVkc`1On1/oD5ogB^mPOoY;o]00?o`lGLol?5
foo3aM/01Oo3aM/00oo:`m?obL3AolW0d@05olW0d@So`K_D00?o`[SAokFhg?ne^=`01_ne^=`00onK
^^koYKGTojFei004ojFei0KoUkoc0onI`oD4oiS3m@KoW<Ke0onUao44oic8mPKoY<Wc0onWa_04oj3;
mPGoY<_d0_nQc?H7oj?>mP?oYLke1?nW`nh6ojW4k@03oj[1j_nSY=KoXjCF00?oXjCF1_nPXMD6oibL
d`GoUiOB1_nAU=85oi2If0;oWkGW1onWb?000onfg_Co^NCdokWTm004okWTm0;o/mSc1_n_cNl2ojW3
k0_oYl3[1onX`N`?ojNoj`?oYl3[00?o0000ojS1k?nX`N/01onX`N/6ojNoj`OoYl3[00?o0000oooo
ooooool01?ooool002Sooooo0_l0000cooooo`goYl3[1_nK_?05oh6cm@GoM:kf1OnT_nd2ojC1kPKo
`lGK00?o`LCLolW0dOo9`=401Oo9`=42olRnd0Ko`K_D0oo2^=46okFhg0;o^[GD1onU]N@3oiNol`Co
W[OZ1_nH`oD3oic6m@CoV/Gf1_nLb?H3ojC9l`CoWL[g1_nPboH00onTboCoXLcfoj7<mP04oj7<mPGo
Xlkf0_nV_n`7ojO3kP?oZLC]0_nUY]L7oj>TePGoX:7E1_nLW=<6oiNGdPKoTICB00?oT9WHoineionO
]NL01?nO]NL5ojO8l0?o]>Cg0_nii?@6ok?Hl`?o[lg_1?nX`N/8ojO0j`_oZ<7/3OnW_n/00onW`>_o
Z<7/ojS1k002ojS1k003o`000?nX`NcoZ<7[00GoZ<7[2?nW_n/5ojO0j`03ooooool0003ooooo00Go
oooo000Zooooo`03o`000?oooooooooo037ooooo3OnW`>/6oi^ll0GoPK?e1Omd[_H00onT_ngoY<7^
ojC1kP04ojC1kP?o`lGK1?o1a=`5olW0d@Cob;k@0oo1^m@6ol:hd@?o]KSL1Onj]M@5ojFei0;o/K?I
1onN]nX3oiS3m@CoWKW]1_nJaOH3oic8mPCoW<Ge1_nMb_L3oj3;mPCoX<Se1_nQc?H00onSc_KoY[o/
ojJok004ojJok0GoYl?^00?oYZOFojFVeonUY]L01?nUY]L6oj>TePKoX:7E1_nLW=<3oiNGdP;oUY_F
1_nHYMh8oinei`03ojO8l?ndi?Oo]>Cg00?o]>Cg0ondh?H5ok?Hl`03oj_7k_nX`N_oZ<7[00KoZ<7[
1OnW`>/;ojS1k0coYko[1OnW`>/4ojS1k004o`000?nX`NcoZ<7[ojS1j`coYko[00?oYl3[oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`00:oooool00ol0003oooooooooo`0aooooo`goYl3[
1_nK_?05oh2dmPGoLZog1onT`Nh00oo3aM_o`LCLol74g004ol74g0?obL3A1_o8_]000oo1^mCo`[SA
ol:hd@06ol:hd@03okFhg?nj]MCo^[GD00Go^[GD00?oYKGTok6cfOna/mT01?na/mT5oijgjP03oj^`
g?nM^NgoWKW]00KoWKW]0onJaOH2oinhjPSoW<Ge0onMb_L2oj2ok`SoX<Se0onQc?H3ojFii`OoY[o/
00?oYl?^ojJWe_nVYmH00onVYmH6ojFVe`KoXjCF0onPXMD2oibGcPKoVIO@1_nFVmH6oiRUgPKoWkGW
0on/f?L00ondi?Oo]>3fokCPmP05okCPmP03ok?Hlon[ankoZlO^00?oZlO^1_nX`N/00onX`>_oYl3[
ojO0j`04ojO0j`OoZ<7/3?nW_n/9ojO0j`?oZ<7/00?o0000ojS0jonW_n/02_nW_n/9ooooo`03o`00
0?oooooooooo00?ooooo000/ooooo`03o`000?oooooooooo037ooooo3OnW`>/6oi^ll0GoP;Cf1Omb
[oL5ojC1kP;oX<;a1oo1a=`00oo9`=7ob;k@olRnd004olRnd003olRod_o2^=7o`[SA00Ko`[SA00?o
`kO>okZee?nj]M@01Onj]M@00onm/Loo/K?Iok6cf@06ok6cf@03oijgj_n[/=coZk3L00?oZk3L1_nM
^Nd00onY[]_oWkSZoinhjP04oinhjPKoW<Ge00?oY;;Soj2okonP_nl01?nP_nl6oj38m@03ojJah?nU
^NOoYKWW00GoYKWW0onV_n`3ojNVe@OoYZOF1_nUY]L3oj>TeP;oWiW=1_nLUlh6oiVGd0KoUY_F1_nH
YMh2oinei`Go[=Sg0_nbi_L6okCPmP03ok3AlOn[ankoZlO^00GoZlO^0_nX`N/5ojS0j`KoYl3[1onX
`N`8ojNoj`_oYl3[00?oZ<7/ojS0jonX`>/00_nX`>/00ol0003oZ<3[ojNoj`05ojNoj`gooooo00?o
0000ooooooooool00oooool002gooooo0_l0000booooo`goYl3[1_nK_?05oh2dmPGoLZog00?oY<7^
oj32lOnP`_401?nP`_45ol74g0;o_LCO1Oo8_]03olRodPKo`[SA0oo3]lh5okZee0?o_K7?1_na/mT0
0onh[]3oZk3Loj^`g005oj^`g0;oWKW]1OnY[]/6oinhjP;oW<Ge1OnT/^<6oj2ok`;oX<Se1OnV/N05
ojFii`03ojVUd_nWY]GoYjKE00GoYjKE1_nVYmH5ojFVe`03oj:JcOnOVLgoWiW=00CoWiW=1OnLUlh6
oiVGd0KoUY_F1OnHYMh3ojG6l@?o[=Sg1Onbi_L2okCPmPGo/=7a1On[anh2ojNoj`OoZ<3[0onW`>/:
ojS1k0OoYko[2?nW`>/5ojS1k0CoZ<3[00Co0000ojS0jonW_n_oYko[4?ooool00ol0003ooooooooo
o`03ooooo`00;oooool00ol0003oooooooooo`0`ooooo`goYl3[0onK_?03oibmk`KoPKKf1Om_/?P6
oj32l@03ol74g?nma=oo_LCO00Co_LCO0oo8_]05olRodP?o`[SA1Oo3]lh3okZee0Go_K7?1?na/mT4
okR^d0GoZk3L00?o]:c@ojV^fonY[]/01OnY[]/5oinhjP;oZj_G1onT/^<3oj2ok`?oZ:[H1onV/N00
0onU^NOoZJGBojVUdP03ojVUdPKoYjKE1onVYmH00onUY]OoXY[=oj:Jc@03oj:Jc@GoWiW=1_nLUlh5
oiVGd0OoUY_F00?oV:GNojG6lOnUa_401OnUa_400on/f?Oo/^Kgok;Vm`03ok;Vm`?o/=[f1_n`dO40
0on[ankoYko[ojNoj`04ojNoj`GoZ<3[00?oYl7/ojS1k?nX`N`02_nX`N`9ojNoj`GoYl3[2?nX`N`3
ojS0j`03o`000?oooooooooo017ooooo00?o0000ooooooooool00oooool0033ooooo00?o0000oooo
ooooool0<Oooool=ojO0j`GoW;g_1_n1]_H5ofn`n0?oX<;a0onH`_@7okg4g`03olRnd?o8_m;ob;oB
00Gob;oB00?o`[SAol>gc_o3]lh01Oo3]lh00onj]MCo_K7?okfac`05okfac`03ok6cfOnh[]3o^:k@
00Co^:k@0on[/=`4okB/d0OoZJkK00?oWkSZoj^[eon[ZmL01?n[ZmL5ojBbh`03ojjWdOnXZ]SoZ:[H
00GoZ:[H1OnV/N000on[XlooZJGBojVUdP05ojVUdPKoYjKE0onVYmH3ojFKc0KoXY[=1_nOVLd5oibG
cPKoVIO@0onFVmH4oj:hj0KoYLKa0on]iOT00onbi_Oo/=[fok3JmP05ok3JmP?o/=7a0onY`N`7ojNo
j`03ojS0jonW`NcoYl7/00?oYl7/2?nX`N`;ojNoj`OoYl3[1_nX`N`5ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool00oooool0037ooooo00?o0000ooooooooool0<Oooool=ojO0j`Go
W;g_0on1]_H3ohBgmPGoKK3i1_nH`_@5okg4g`;o]/GU1_o8_m800oo4`MOo`kO>ol>gcP05ol>gcP03
olFiconm/Loo_K7?00Go_K7?00?o`;;<okR^d?nh[]001_nh[]000on[/=co]:c@okB/d004okB/d0Go
ZJkK00?o/ZS?oj^[eon[ZmL01_n[ZmL00onT/^?o[ZOAojjWd@03ojjWd@OoZ:[H00?oY[7Poj^Scon[
Xll00on[Xll6ojVUdPGoYjKE00?oYic;ojFKc?nUVl`01OnUVl`5oj:Jc@KoWiW=1_nLUlh3oiVGd0?o
X:oR1onR^>P2ojG6l@Go[NGi0_n_goP6ok3JmP03oj_6k_nY`NcoZL7/00GoZL7/0onW_n/3ojO0j`Oo
Yl7/0onX`N`4ojS0j`SoYko[2onW`>/2ojS1k0Wooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`03ooooo`00<_ooool2o`0003;ooooo3OnW`>/2oibmk`CoWkk^1On4]oH5off`n@KoV<;d
00?o_LCOokK5iOnfaND01?nfaND3olRodPCoa<7G1Oo3]lh3olFic`Go_K7?0oo0//`6okR^d003ok^^
c?nd[=3o]:c@00Ko]:c@00?oZJkKok:XconbZ<l00onbZ<l6oj^[e`03ok6Uc?n^Ym7o[ZOA00Go[ZOA
1OnXZ]P00on]X/coZj??oj^Sc`05oj^Sc`KoZJGB00?oYjKEojNLbonWW</00onWW</6ojFKc0KoXY[=
1_nOVLd3oibGcP;oWZOL1onP[n85oj:hj0CoZ=kj00?o[NGiojoOn?n_goP01?n_goP2ok3JmPGoZlK^
1OnY`N`8ojO0j`GoYl7/0_nX`N`7ojS0j`KoYko[2_nW`>/>ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool00_ooool003Cooooo00?o0000ooooooooool0<?ooool=ojO0j`OoWkk^1?n4
]oH5off`n@?oV<;d0on:`?T7okK5i@03olRod_o4`MOoa<7G00Coa<7G0oo3]lh5olFic`?o_K7?1Oo0
//`3okR^d0Co^jk<1_nd[=000onhZ/_o/ZS?ok:Xc`05ok:Xc`?oZj_G1?naYL`7ojjWd@03ojRZf?n]
X/co[J;<00?o[J;<1_n[Xll5ojVUdP03ojVNbonWW<_oYic;00CoYic;1_nUVl`6oj:Jc@?oWiW=0onP
Y=P6oijWg0OoX:oR00?oX[SXojSNn_nXg_X01?nXg_X2ojcTn@Go[moh0_n]c_47oj_6kP03ojW1k?nW
`>_oYl3[00[oYl3[00?oYl7/ojS1k?nX`N`01?nX`N`5ojS0j`SoYko[1OnW`>/Booooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool00_ooool003Gooooo00?o0000ooooooooool0<?ooool5
ojO0j`;oYl3/1_nW`>/5oinnkP;oXkk]1On9^?D5ofjbn@GoR/3i1OnfaND2ojk8k@Ooa<7G00?o`kO>
olFicoo5^Ll01Oo5^Ll00onm/Loo`;;<ol2bc005ol2bc003okR^d?nk[/co^jk<00Co^jk<0ond[=04
okRZb`Oo/ZS?00?oZj_Gok6Uc?naYL`01?naYL`5ojjWd@03ok2Sb_n]X/co[J;<00Go[J;<1_n[Xll0
0onYYM;oZIk;ojVNb`03ojVNb`KoYic;1_nUVl`3oj:Jc@;oXjCF1onPY=P6oijWg0GoX:oR0onTdoP2
ojSNnPKo[>Ci00?o[mohojg>lOn]c_401?n]c_45oj_6kPcoYl3[2_nX`N`00onX`>_oYko[ojNoj`0:
ojNoj`03ojO0jooooooooooo01Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02
ooooo`00=_ooool00ol0003oooooooooo`0`ooooo`03ojO0jonW`>coYl3/00CoYl3/1_nW`>/00onO
_^koXkk]oj>nk@04oj>nk@KoRKSe1?m^/_T5oh[0n@03okK5iOn^b>go[/S]00Co[/S]1Oo4`ML2okc4
g`KoaKW?00?o`koGol2bc?o0//`01Oo0//`00oo2^];o^jk<ok^^c006ok^^c003okB/d?nhZ/_o^:[;
00Co^:[;1OnbZ<l00ongZ<_o/JG<ok6Uc005ok6Uc0?o[ZOA1?n`XlX6ojfRc0GoZj??00?o[J7;ojVN
bonYW//01?nYW//6ojNLb`GoYI_<00?oYZGDoj>Te_nSY=H01?nSY=H6oj2Tf0OoWZOL00?oX:oRojCC
n?nTdoP00onTdoP3ojKUn`Go[>Ci0_n/e?D7ojg>l@03oj_6k_nW`>_oYl3[00WoYl3[00?oYl7/ojS1
k?nX`N`02?nX`N`=ojNoja_ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02oooo
o`00=oooool2o`00037ooooo1onW`>`7ojO0j`KoXkk]0on9^?D3oi2jl`GoM;Gj1?mg_?`7ojk8k@03
olC1eonla=oo_<CO00Co_<CO0oo5^Ll4ol>oe`Go`;;<0oo2^]86ok^^c003oknfd?nhZ/_o^:[;00Go
^:[;0onbZ<l4okNXb`Oo/JG<00?o[ZOAok2Sb_n`XlX00on`XlX7ojfRc003oj^Scon]XL_o[J7;00?o
[J7;1_nYW//6ojNLb`03ojFKc?nVYMCoYZGD00?oYZGD1_nSY=H6oj2Tf0?oWZOL1OnTbo@00onTdoSo
Y^GkojKUn`05ojKUn`03ojcTnOn/e?Go[=Ce00Co[=Ce0on]c_44ojS1j`SoYl3[1OnW`N`5ojS1k003
ojS0jonW_n_oYko[00[oYko[8?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;o
oooo000iooooo`03o`000?oooooooooo02oooooo1onW`>`7ojO0j`?oXkk]0onU_n`6oi2jl`GoM;Gj
1?mg_?`5ojk8k@;oW<[g1onla=l00oo5^Loo`koGol>oe`04ol>oe`?o`;;<1Oo2^]84ok^^c0?o_kK@
1onhZ//00onbZ<oo]jS;okNXb`04okNXb`Go/JG<00?o]Z[=ok2Sb_n`XlX01On`XlX5ojfRc003ok6W
c_n]XL_o[J7;00Co[J7;1_nYW//5ojNLb`03ojVXeOnVYMCoYZGD00GoYZGD1OnSY=H5oj2Tf0?oYLG`
1OnTbo@2oj7Uo0KoY^Gk0_nZfOP5ojcDm@;oZL;/1onX`N/6ojO0j`OoYl7/00?oZ<7/ojS0jonX`>/0
0onX`>/8ojNojb?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`02ooooo`00>_oo
ool00ol0003oooooooooo`0_ooooo`OoYl3/1onW`>/6ojFok0KoT;[c0_md]OX4ogjin@;oJkOl00?o
Mkclojk8kOnLb_L01OnLb_L5okc4g`03ok3:kOo3_mOo`koG00Ko`koG00?o`;;<ol:jd_o2^]801?o2
^]83ok^^c0Go_kK@1OnhZ//00onm]=7o]jS;okNXb`05okNXb`?o/JG<1?nfZ/d6ok2SbP?o[J;<1?na
Ylh6ojfQb`KoZIk;00?oYic;ojVXeOnYZ=D00onYZ=D6ojJUe0KoXjCF00?oX:CHojG5l?nUaO001OnU
aO000onTboCoXNGloj7Uo004oj7Uo0;oY^Gk1_nZfOP00on/e?GoZL;/ojW2k004ojW2k0GoZ<7[2?nW
`>/5ojO1k003ojS1k?nX`>_oZ<3[00GoZ<3[0onW_n/Xooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool00_ooool003_ooooo00?o0000ooooooooool0<?ooool6ojO0k0OoYl3[1_nU_n`3
oi2jl`CoVKc`1Omn^OT4of^go0KoW<[g00?o_<COok3:kOn`b^d00on`b^d6ol>oe`03okS5i?o2^];o
`[[B00Ko`[[B00?o^jk<oknfd?no]]001?no]]03okRZb`Co_KCA1ongZ</00onaYLco]Z[=okJZc@04
okJZc@Ko/:?:00?o[J;<ok6Wc_naYlh00onaYlh6ojfQb`GoZIk;00?o[JgHojVXeOnYZ=D01OnYZ=D6
ojJUe0?oXjCF1?nV`nh5ojG5l0?oW>?m0onQiO`5ojOKnP?oZ]Wh0onYaNh7ojW2k003ojS1jonW`>_o
Yl3[00[oYl3[00?oYl7/ojS1k?nX`N`00onX`N`5ojS0jbgooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`01ooooo`00??ooool00ol0003oooooooooo`0`ooooo`?oYl3/0onV`>`7ojO0
j`?oYKo/1?nW`>/6oiVll0GoO[Wi1?m[]o`3oic:m`?oOlGm1_n`b^d3ol>oe`Co^<GT1_o2^]800onk
`]oo_kK@oknfd006oknfd003okRZbonm]=7o_KCA00Co_KCA1OngZ</00onk]mKo]Z[=okJZc@05okJZ
c@Go/:?:00?o]K7Dok6Wc_naYlh01OnaYlh6ojfQb`03ojVNbon][MSo[JgH00?o[JgH1_nYZ=D5ojJU
e003ojO3k_nV`nkoY/?^00KoY/?^00?oYLG`oicSoOnLhod00onLhod3ojCLn`GoYm_j00?oZ/S_ojW5
k_nYaNh01OnYaNh3ojW2k0goYl3[2_nX`N`00onX`>_oooooooooo`0_ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool00Oooool003gooooo0_l0000aooooo`KoY/3/3_nW`>/3oiVll0?o
X[k]1_n9^_H4ofjgn`GoOlGm1_n`b^d00oo3_mOo^<GTokS5i004okS5i0?o`[[B1?nk`]l6oknfd003
ok[1gonm]=7o_KCA00Go_KCA0ongZ</4ok^gePOo]Z[=00?o/:?:okFae?ne/M@00one/M@6ok6WcPGo
[J7;00?o/;GMojf]f?n][MP01On][MP6ojVXe@03ojJUe?nW`nkoYl?^00?oYl?^1_nV`nh3oiWRo@03
oicSoOnTg?_oY=ck00GoY=ck00?oYm_joj[8konZb>l00onZb>l5ojW5kPgoYl3[0_nW`N`:ojS1k3Co
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`01ooooo`00?oooool00ol0003ooooo
ooooo`0_ooooo`KoY/3/3_nW`>/6oj:nk@KoRK[f1?m^]o/5ogo5o@?o/<[]1?nHc_X6okS5i003ol:j
d_nk`]oo^l;O00Co^l;O0ono]]04ok[1g`Oo_KCA00?o]jS;ok^ge_nk]mH01?nk]mH5okJZc@03okJl
g_ne/MCo]K7D00Go]K7D1_naYlh00on]XL_o/;GMok2eg@03ok2eg@Oo[JgH0onYZ=D3ojO6k`KoYl?^
0_nV`nh5oiWRo@;oXMcl1_nTg?/2ojS:l@KoZ/S_00?oZLG^ojO0jonW`>/02onW`>/6ojO1k0GoZ<7/
>Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo007ooooo0010ooooo`03o`000?oo
oooooooo02oooooo1onV`>`=ojO0j`KoX[k]0on9^_H4oiJllPCoO;ck1Om/^od6oiS>nP?o^<GT0onV
dOH7ok_2g`03oknfd?nj`Moo^/7O00Co^/7O1Onm]=400onf`^Co^kOFok^geP05ok^geP?o]Z[=1?nf
_=h6okFae0Go/JO>00?o[kgTok2egOn`]Md01?n`]Md6ojf]f003ojO<lonWa^ooYlK_00GoYlK_0onW
`nh5oiGPoP03oiWRoOnQg?coXMcl00CoXMcl0_nTg?/6ojS:l@?oZ/S_3OnW`>/:ojO1k003ojS1k?oo
oooooooo03_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`01ooooo`00@Oooool0
0ol0003oooooooooo`0_ooooo`OoY/3/0onW`>/3ojO0k0OoYl3[0onR_^d4ojK0k0KoU[cb1?ml_?/5
ofbko@?oV<kj1?mba?l5ojKAmPGo^l;O0_nYdOD7ok[1g`03okfddOnf`^Co]/;T00?o]/;T1onk]mH0
0onfZ/go][cNokJlgP03okJlgPOo]K7D00?o/JO>ojnmi?n__N@00on__N@6ok2eg@;o[JgH1OnWc?<5
ojO6k`CoTMon0onEh?h4oigKo@?oXMcl1?nWbo<5ojS:l@goYl3[2onW`Na1ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool00Oooool004;ooooo0_l0000`ooooo`OoY/3/1_nW`>`7ojO0
j`OoY/3/0onF_?83oj:nk@GoS;cf1_mb_?`5og;4o`GoY]7f00?o^l;OojWAmOnYdOD01?nYdOD5ok[1
g`;oYm?g1_nf`^@5ok^geP03ojo9kOnf_=ko][cN00Go][cN0one/M@3ojg8kPOo[kgT0on`]Md4ojCC
n0KoYlcc00?oYlK_oi7Oo_nAgoh01?nAgoh2oi[Io@GoWM_m0onUbo<6ojO;l`03ojS:lOnW`>_oYl3[
00_oYl3[2_nW`Na6ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00Oooool004Co
oooo00?o0000ooooooooool0;_ooool7ojK0k0KoYl3/1onW`>/5ojK0k0;oYl3[1_nR_^d5ohblmP?o
L[cl1?n7__T5ofnmo@KoO<_o1OnYdOD00onj`MooYm?gojOCm`04ojOCm`Ko]/;T00?o^kOFojo9kOn_
bNd00on_bNd5okJlgP;oXmKi1_n]b>h5ojnmi0?oVm[m1_nTdoP3ojO<l`GoS=kn00?oTMonoi[IoOnJ
fOd01?nJfOd00onMfogoYL_cojG;l`05ojG;l`?oYl_c4?nW`>/7ojO1k4[ooooo00?o0000oooooooo
ool01oooool1o`00007ooooo0Oooool004Gooooo00?o0000ooooooooool0;oooool6ojK0k0?oYl3/
1?nV`>`6ojO0j`03ojK0k?nW`>_oYl3[00CoYl3[1_nR_^d2ohblmPCoVkg`1_n7__T5ofnmo@?oO<_o
1?m_`Oh5ogk?o`KoYm?g0onf`^@3oikHo0Ko[lW]00?o][cNoj?FnOnSe_T01?nSe_T6ojg8kP03ojnm
i?nKf_goVm[m00GoVm[m0onTdoP5ohSKoP?oS=kn1?nHeod3oi[Io@CoY<Wc1OnUbo<EojO0j`?oYl7/
C_ooool00ol0003oooooooooo`06ooooo`7o00000Oooool1ooooo`00A_ooool00ol0003ooooooooo
o`0`ooooo`;oY/3/0onV_n/7ojK0k0?oYl3[1?nW`N`6ojO0j`?oX[k]0onW`>`6oi^ml0?oQkki1?nG
_O86ohC1n`GoKl7n1Omncol3ojOCm`?oNLoo1_nNf?`3ojo9k@CoRmSo1_nSe_T3ojg8kPGoRM[o0onK
f_d4ohKGo`?oR=_n1OnHdo`3oiSGo@CoY<Kb1_nTbO<00onUbo?oYl3[ojO0j`0EojO0je;ooooo00?o
0000ooooooooool01_ooool1o`00007ooooo0Oooool004Oooooo0_l0000aooooo`GoY[o[1onV`>`7
ojO1k0KoYl3[1_nW`>`3oi^ml0CoYKo/1_nG_O83ohC1n`CoU[gc1On6`o`5og?4o`GoNLoo0onNf?`5
ogO>o`GoRmSo0onSe_T5oggDo`?oRM[o1?n7d_l3ohKGo`CoVLoj1OnHdo`2oj?3l0OoY<Kb0onTbO<G
ojO0jeKooooo00?o0000ooooooooool01Oooool1o`00007ooooo0Oooool004Wooooo00?o0000oooo
ooooool0;oooool5ojJoj`OoY/3/1OnW`N`2ojO0k0KoYl3[1?nW`>`2ojO0j`OoYKo/0onG_O83ojBo
k0OoU[gc1On6`o`2og?4o`CoRlGk1_mjaol3ogO>o`CoQl[n1_mmc_l3oggDo`CoSLon0on7d_l4oi_9
m`KoVLoj00?oV=?loj?3l?nS`o001?nS`o05ojC6lQSoYl3[F_ooool00ol0003oooooooooo`04oooo
o`7o00000Oooool1ooooo`00B_ooool00ol0003oooooooooo`0_ooooo`;oY[o[1?nW_n/6ojK0k003
ojO1k?nW`>coYl3/00CoYl3/1_nW`>/00onW`>coYl3[ojO0j`03ojO0j`GoYKo/0_nX`>/6ojBok0Go
U[gc00?oY;o/oiRnl_nH__801?nH__86oh_5n`?oN/Oo1OnBa?P5ohO:oP?oOLko1?nDbOX3ohg?oPCo
W/?b1_nKbOL3oiW?nPCoYL7]1_nS`o000onTa_;oYl3[ojO0j`0EojO0jeoooooo00?o0000oooooooo
ool00oooool1o`00007ooooo0Oooool004_ooooo00?o0000ooooooooool0;oooool6ojNoj`?oY/3/
1?nV_n/6ojO0k0?oYl3[0onW`N`6ojO0j`03ojFok?nX`>_oZ<3[00CoZ<3[1_nT_n`00onF_O?oY;o/
ojBok003ojBok0KoV;kb0on;aO/4oifol0GoT/Ch0_nR_nd5oi_1l`GoU<Wj0_nS`>h7oik3lP?oVlWg
1?nV`>`6ojG1k@?oXl?`5onW`>]Rooooo`03o`000?oooooooooo00?ooooo0Ol00001ooooo`7ooooo
001<ooooo`;o0000<?ooool4ojNoj`;oZ;oZ1onV_n/3ojO0k0?oY/3/1_nW`N`3ojO0j`?oYl7/1onX
`>/3ojBok0CoZ<3[1OnT_n`3oiRnlPCoYKo/1_nM_o000onBa?SoX[o]oj:ok@04oj:ok@GoVl7c00?o
U<Wjoj?0k_nS`>h01?nS`>h5oik3lP;oYko[1onV`>`3ojG1k@;oZ<3[5onW`>]Vooooo`03o`000?oo
oooooooo00?ooooo0Ol00001ooooo`00C_ooool00ol0003oooooooooo`0^ooooo`03ojNojonX_n[o
Z;oZ00?oZ;oZ1OnV_n/2ojNoj`KoY/3/1?nW`N`2ojK0k0KoYl7/1OnX`>/2ojO0k0OoZ<3[0_nT_n`4
ojS0j`KoYKo/0onM_o04ojJoj`KoX[o]0_nK`O<4ojJok0KoXl3^00?oW/?bojNojonW_n/01?nW_n/5
ojK0k003ojO0jonX`>_oZ<3[00CoZ<3[1OnW`>/2ojO0k0[oYl3[K?ooool00ol0003oooooooooo`02
ooooo`7o00000Oooool004oooooo00?o0000ooooooooool0;oooool5ojRojP03ojJojonW_n_oYko[
00CoYko[1_nV`>`00onW`NcoY/3/ojK0k003ojK0k0KoYl7/00?oZ<3[ojO0k?nW`>`01?nW`>`5ojS0
j`03ojO0k?nX`>_oZ<3[00GoZ<3[0onU_n`3ojO0j`OoY[o[0onR_nd3ojS0j`KoY[o/0onS`>h4ojS0
j`KoYko[00?oY/3/ojO0jonW`>/00onW`>/6ojS0j`03ojO0jonW`>coYl3/00CoYl3/1OnW`>]aoooo
o`05o`000?ooooooooooooooool000000Oooool0053ooooo00?o0000ooooooooool0;oooool2ojRo
jP?oZ<3[1onW_n/3ojK0k0CoYko[1OnV`>`7ojO1k0KoYl3/00?oZ<3[ojO0k?nW`>`00onW`>`5ojS0
j`;oYl7/1_nW`>/5ojJoj`03ojO0jonX`>_oZ<3[00GoZ<3[0onV_n`3ojO0j`OoZ<3[0onW_n/9ojO0
j`?oZ<3[1?nW`N`6ojO0k003ojO0jooooooooooo07;ooooo00Go0000ooooooooooooooooo`000001
ooooo`00DOooool2o`00033ooooo1OnX`>/5ojNoj`;oZ<3Z1onW_n/2ojK0k0CoY[o[1_nW`N`3ojO0
k0CoYl7/1OnW`>`00onX`>_oYl7/ojO1k004ojO1k0KoYl3[00?oY[o[ojO0jonW`>/00onW`>/5ojS0
j`;oYl7/1_nW`>/5ojS0j`03ojO1k?nW`>_oYl3[00SoYl3[2_nW`N`3ojO0k7Sooooo00Co0000oooo
oooooooo00000Oooool005?ooooo00?o0000ooooooooool0;_ooool5ojS0j`03ojNojonX`>[oZ<3Z
00CoZ<3Z1OnW_n/00onX_n[oY[o[ojJoj`05ojJoj`?oYl7/0onV_n`7ojO1k0;oYl3/2_nW`N`3ojO0
j`?oYl7/1_nW`>/00onX`>_oYl7/ojO1k004ojO1k0KoYl3[00?oZ<3[ojO1k?nW`N`00onW`N`5ojO0
j`goYl7/OOooool00ol0003oooooo`000001ooooo`00E?ooool00ol0003oooooooooo`0^ooooo`Ko
Z<3[1_nX`>X00onW_n_oZ;oZojRojP03ojRojPGoY[o[0_nX_n/6ojJok0GoYl7/00?oY[o/ojO1k?nW
`N`04OnW`N`3ojO0j`[oYl7/0onW`>/9ojO1k003ojO0jonW`NcoYl7/00_oYl7/P?ooool00ol0003o
ooooo`000001ooooo`00EOooool00ol0003oooooooooo`0^ooooo`KoZ<3[0onX`>X4ojS0j`GoZ;oZ
00?oY[o[ojRojonX_n/01?nX_n/6ojJok003ojO1k?nV_ncoY[o/00?oY[o/1OnW`N`2ojJoj`[oYl7/
0_nV`>`SojO1k8Cooooo0Ol00001ooooo`7o0000001Fooooo`;o0000;oooool3ojS0j`?oYl3[1onX
`>/2ojRojPCoZ<3[1_nX_n/3ojJok0CoYko[1OnV_n`00onW`NcoY[o[ojJoj`04ojJoj`OoYl7/1OnV
`>`5ojO1k0;oYl3[2_nW`N`2ojO0j`[oYl7/R_ooool2o`000000F?ooool00ol0003oooooooooo`0]
ooooo`KoYl3[1OnX`>/2ojO0j`KoZ<3[0onX_n/3ojS0j`OoYko[0_nV_n`4ojNojPKoY[o[0onW`N`3
ojNoj`KoY/3/00?oYl7/ojO0jonW`>/01?nW`>/6ojO1k0KoYl3[1OnW`Nb=ooooo`?o0000001Ioooo
o`03o`000?oooooooooo02gooooo1_nW`>/00onX`>_oYl3[ojO0j`04ojO0j`coZ<3[1OnW_n/00onX
`>_oYkoZojNojP05ojNojP?oY[o[0onX_nX6ojNoj`?oY/3/1?nW_n/6ojO0j`;oYl7/1?nW_n/6ojO0
j`03ojO1k?oooooooooo08[ooooo1?l00003ooooo`00F_ooool00ol0003oooooooooo`0]ooooo`?o
Yl3[1?nW`>`6ojO0j`coZ<3[00?oYko[ojS0jonX`>/00onX`>/5ojNojP;oZ<3[1_nX_nX4ojNoj`;o
Z;oZ1onW_n/3ojO0j`?oZ;oZ1_nW_n/3ojO0jhcooooo0ol00007ooooo`00Foooool00ol0003ooooo
ooooo`0^ooooo`KoYl3/0onW`>/3ojO0k1;oZ<3[00?oYkoZojS0jonX`>/01?nX`>/6ojRojP03ojNo
jonX_n[oZ;oZ00?oZ;oZ1OnW_n/00onX_n_oZ;oZojRojP05ojRojP?oYko[SOooool4o`0000[ooooo
001Looooo`;o0000;oooool<ojO0k0?oZ<3[1?nW`>`BojS0j`?oZ;oZ0onX`>/6ojRojP03ojNojonX
_n_oZ;o[00?oZ;o[1OnX_nZ=ooooo`Co00003_ooool005kooooo00?o0000ooooooooool0;OoooolC
ojO0k0?oZ<3[0_nW`N`:ojS0j`?oYl3[1_nX`>/3ojRojPCoZ<3[1OnX_n/00onX_n[oooooooooo`2:
ooooo`Co00004_ooool005oooooo00?o0000ooooooooool0;OoooolCojO0k0GoYl7/1OnX`>/2ojO1
k0KoYl3[0onX`>/3ojO0j`OoZ<3[0_nX_n^;ooooo`Co00005_ooool0063ooooo00?o0000oooooooo
ool0;Oooool3ojO0k0CoYko[3?nW`>`5ojO1k003ojS0jonW`NcoYl7/00CoYl7/1?nW`>/2ojO1k0Ko
Yl3[1OnX`>^;ooooo`?o00006_ooool0067ooooo0_l0000_ooooo`KoYko[0_nW`>`4ojNoj`KoYl3/
0_nW`N`4ojO0k0KoYl7/00?oYl3[ojO1k?nW`N`00onW`N`6ojO0j`03ojS0jooooooooooo08Sooooo
1?l0000Mooooo`00Hoooool00ol0003oooooooooo`0]ooooo`?oYko[0_nX_n/7ojNoj`?oYl3/0onW
_n/6ojO0k0?oYl7/0onW`>`6ojO1k0?oYl3[ROooool4o`00027ooooo001Tooooo`03o`000?oooooo
oooo02gooooo1OnX_n/5ojNoj`;oZ;o[1_nW_n/3ojO0k0CoYko[1OnW`>`3ojO1k8[ooooo1?l0000U
ooooo`00IOooool00ol0003oooooooooo`0]ooooo`GoZ;o[00?oYko[ojRojonX_n/01?nX_n/4ojNo
j`;oZ;o[1onW_n/2ojO0k8_ooooo1?l0000Yooooo`00I_ooool2o`0002kooooo0_nX_n/4ojS0j`Ko
Z;o[00?oYko[ojRojonX_n/00onX_n/5ojNojh_ooooo0ol0000]ooooo`00J?ooool00ol0003ooooo
ooooo`0/ooooo`KoZ<3[0onX_n/3ojS0j`KoZ;o[00?oYko[ooooooooool0R?ooool4o`00033ooooo
001Yooooo`03o`000?oooooooooo02cooooo0onX`>/4ojO0j`GoZ<3[0onX_n^9ooooo`Co0000=?oo
ool006[ooooo00?o0000ooooooooool0;?ooool7ojO0j`;oZ<3[R_ooool4o`0003Sooooo001[oooo
o`;o0000;Oooool5ojO0jhWooooo1?l0000looooo`00KOooool00ol0003oooooooooo`0[ooooo`03
ojO0jooooooooooo08Oooooo0ol00010ooooo`00K_ooool00ol0003oooooooooo`0Zooooo`03o`00
0?oooooooooo08?ooooo1?l00013ooooo`00Koooool00ol0003oooooooooo`0Yooooo`03o`000?oo
oooooooo07oooooo1?l00017ooooo`00L?ooool2o`0002Wooooo00?o0000ooooooooool0Noooool4
o`0004_ooooo001booooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0Moooool4o`00
04oooooo001cooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0M?ooool3o`0005?o
oooo001dooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0L?ooool4o`0005Kooooo
001eooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0K?ooool4o`0005[ooooo001f
ooooo`;o00008oooool00ol0003oooooooooo`1Xooooo`Co0000G_ooool007Sooooo00?o0000oooo
ooooool08?ooool00ol0003oooooooooo`1Tooooo`Co0000H_ooool007Wooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`1Qooooo`?o0000I_ooool007[ooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`1Mooooo`Co0000JOooool007_ooooo0_l0000Nooooo`03o`000?oo
oooooooo05Wooooo1?l0001]ooooo`00OOooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo05Gooooo1?l0001aooooo`00O_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
057ooooo1?l0001eooooo`00Ooooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04ko
oooo0ol0001iooooo`00P?ooool2o`0001Wooooo00?o0000ooooooooool0B_ooool4o`0007cooooo
0022ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0A_ooool4o`00083ooooo0023
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0@_ooool4o`0008Cooooo0024oooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0?_ooool4o`0008Sooooo0025ooooo`;o
00004oooool00ol0003oooooooooo`0looooo`?o0000S?ooool008Oooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0hooooo`Co0000Soooool008Sooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0dooooo`Co0000Toooool008Wooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0`ooooo`Co0000Uoooool008[ooooo0_l0000>ooooo`03o`000?oooooooooo
02cooooo1?l0002Kooooo`00S?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Wo
oooo0ol0002Oooooo`00SOooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Gooooo
1?l0002Rooooo`00S_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo027ooooo1?l0
002Vooooo`00Soooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01gooooo1?l0002Z
ooooo`00T?ooool2o`0000Sooooo00?o0000ooooooooool06Oooool4o`000:kooooo002Booooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool05_ooool3o`000;;ooooo002Cooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool04_ooool4o`000;Gooooo002Dooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool03_ooool4o`000;Wooooo002Eooooo`;o00000oooool0
0ol0003oooooooooo`0:ooooo`Co0000_Oooool009Oooooo00Co0000oooooooooooo00002?ooool4
o`000<7ooooo002Hooooo`03o`000?oooooo000000Gooooo0ol00035ooooo`00VOooool2o`000003
ooooool0003o000000;o0000b?ooool009[ooooo0_l0003<ooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0538698, 0.0432538, \
0.0035044, 0.0035044}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[.12586 .2075 -12 -8.99448 ]
[.12586 .2075 0 .00552 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.56094 .0364 -5.16972 -9 ]
[.56094 .0364 .83028 0 ]
[.75679 .08071 0 -6.17777 ]
[.75679 .08071 12 2.82223 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.9429 .3657 0 -5.9083 ]
[.9429 .3657 6 3.0917 ]
[.02494 .25992 -18 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.01611 .31527 -18 -2.78472 ]
[.01611 .31527 0 6.21528 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00254 .43215 -12 -2.88407 ]
[-0.00254 .43215 0 6.11593 ]
[-0.0124 .49393 -12 -2.93688 ]
[-0.0124 .49393 0 6.06312 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
[(-2)] .12586 .2075 1 .99877 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.56863 .04703 m
.57247 .05235 L
s
[(2)] .56094 .0364 .72324 1 Mshowa
.125 Mabswid
.18558 .19702 m
.18832 .19985 L
s
.23703 .17687 m
.23971 .17975 L
s
.28951 .15632 m
.29214 .15925 L
s
.39772 .11395 m
.40023 .11699 L
s
.4535 .09211 m
.45595 .0952 L
s
.51046 .06981 m
.51284 .07294 L
s
.08568 .23614 m
.08851 .23887 L
s
.62804 .02377 m
.63027 .02701 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.7445 .0853 m
.73835 .08759 L
s
[(-2)] .75679 .08071 -1 .37284 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.93037 .36962 m
.92411 .37158 L
s
[(2)] .9429 .3657 -1 .31296 Mshowa
.125 Mabswid
.7708 .12553 m
.7671 .12688 L
s
.79613 .16428 m
.79242 .1656 L
s
.82054 .20161 m
.81682 .20291 L
s
.86679 .27235 m
.86305 .2736 L
s
.88871 .30589 m
.88497 .30711 L
s
.9099 .3383 m
.90615 .3395 L
s
.71716 .04348 m
.71349 .04489 L
s
.95018 .39992 m
.94642 .40107 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(-20)] .02494 .25992 1 -0.39157 Mshowa
.02837 .31059 m
.0345 .30825 L
s
[(-10)] .01611 .31527 1 -0.38117 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.00981 .42772 m
.01599 .4255 L
s
[(10)] -0.00254 .43215 1 -0.3591 Mshowa
0 .48963 m
.0062 .48748 L
s
[(20)] -0.0124 .49393 1 -0.34736 Mshowa
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.659 .751 .918 r
.39362 .69482 .40169 .70192 .4152 .69805 .40717 .69088 Mtetra
.656 .749 .918 r
.40717 .69088 .4152 .69805 .42878 .69414 .42079 .68703 Mtetra
.654 .751 .921 r
.42079 .68703 .42878 .69414 .44243 .69029 .43448 .68321 Mtetra
.653 .753 .923 r
.43448 .68321 .44243 .69029 .45614 .68649 .44824 .67939 Mtetra
.654 .754 .923 r
.44824 .67939 .45614 .68649 .46992 .68268 .46207 .67551 Mtetra
.658 .754 .92 r
.46207 .67551 .46992 .68268 .48378 .67882 .47597 .67147 Mtetra
.66 .75 .917 r
.47597 .67147 .48378 .67882 .4977 .67486 .48994 .66738 Mtetra
.657 .747 .916 r
.48994 .66738 .4977 .67486 .5117 .6708 .50398 .66336 Mtetra
.655 .748 .919 r
.50398 .66336 .5117 .6708 .52577 .66674 .5181 .6594 Mtetra
.654 .752 .922 r
.5181 .6594 .52577 .66674 .53991 .66275 .53229 .65545 Mtetra
.652 .754 .924 r
.53229 .65545 .53991 .66275 .55412 .65878 .54655 .65151 Mtetra
.653 .755 .925 r
.54655 .65151 .55412 .65878 .56841 .65481 .56089 .64753 Mtetra
.653 .756 .925 r
.56089 .64753 .56841 .65481 .58277 .65084 .5753 .6435 Mtetra
.657 .757 .924 r
.5753 .6435 .58277 .65084 .59721 .64684 .58978 .63934 Mtetra
.658 .754 .921 r
.58978 .63934 .59721 .64684 .61172 .6428 .60434 .63511 Mtetra
.658 .75 .918 r
.60434 .63511 .61172 .6428 .62631 .63873 .61898 .6309 Mtetra
.657 .747 .916 r
.61898 .6309 .62631 .63873 .64097 .63462 .63369 .62669 Mtetra
.657 .745 .915 r
.63369 .62669 .64097 .63462 .65572 .63048 .64849 .62249 Mtetra
.656 .745 .915 r
.64849 .62249 .65572 .63048 .67053 .62631 .66336 .61827 Mtetra
.66336 .61827 .67053 .62631 .68543 .62211 .67831 .61403 Mtetra
.67831 .61403 .68543 .62211 .70041 .61788 .69334 .60977 Mtetra
.69334 .60977 .70041 .61788 .71546 .61362 .70845 .60549 Mtetra
.656 .745 .916 r
.70845 .60549 .71546 .61362 .7306 .60933 .72364 .60121 Mtetra
.655 .746 .917 r
.72364 .60121 .7306 .60933 .74581 .605 .73891 .59694 Mtetra
.653 .748 .919 r
.73891 .59694 .74581 .605 .7611 .60063 .75427 .59268 Mtetra
.654 .753 .922 r
.75427 .59268 .7611 .60063 .77647 .59623 .76971 .58836 Mtetra
.657 .757 .924 r
.76971 .58836 .77647 .59623 .79193 .59179 .78523 .5839 Mtetra
.658 .758 .924 r
.78523 .5839 .79193 .59179 .80747 .58735 .80083 .57938 Mtetra
.658 .757 .923 r
.80083 .57938 .80747 .58735 .82309 .5829 .81651 .57482 Mtetra
.657 .755 .922 r
.81651 .57482 .82309 .5829 .83881 .57847 .83227 .57027 Mtetra
.657 .753 .921 r
.83227 .57027 .83881 .57847 .85461 .57412 .84813 .56573 Mtetra
.655 .748 .918 r
.84813 .56573 .85461 .57412 .87051 .56976 .86408 .56124 Mtetra
.653 .745 .918 r
.86408 .56124 .87051 .56976 .88648 .56529 .88013 .55682 Mtetra
.653 .748 .919 r
.88013 .55682 .88648 .56529 .90254 .56071 .89626 .55235 Mtetra
.657 .753 .921 r
.89626 .55235 .90254 .56071 .91868 .55608 .91247 .54771 Mtetra
.658 .755 .922 r
.91247 .54771 .91868 .55608 .9349 .55144 .92876 .543 Mtetra
.657 .754 .921 r
.92876 .543 .9349 .55144 .95123 .54683 .94514 .53827 Mtetra
.656 .752 .92 r
.94514 .53827 .95123 .54683 .96766 .5423 .96163 .53358 Mtetra
.654 .748 .919 r
.96163 .53358 .96766 .5423 .98417 .5377 .97821 .52898 Mtetra
.656 .749 .918 r
.38547 .68761 .39362 .69482 .40717 .69088 .39907 .68374 Mtetra
.653 .751 .921 r
.39907 .68374 .40717 .69088 .42079 .68703 .41273 .67992 Mtetra
.653 .753 .923 r
.41273 .67992 .42079 .68703 .43448 .68321 .42646 .67608 Mtetra
.655 .754 .922 r
.42646 .67608 .43448 .68321 .44824 .67939 .44026 .67217 Mtetra
.66 .753 .919 r
.44026 .67217 .44824 .67939 .46207 .67551 .45414 .66808 Mtetra
.66 .749 .916 r
.45414 .66808 .46207 .67551 .47597 .67147 .46809 .66397 Mtetra
.656 .747 .917 r
.46809 .66397 .47597 .67147 .48994 .66738 .4821 .65999 Mtetra
.654 .75 .921 r
.4821 .65999 .48994 .66738 .50398 .66336 .49619 .65605 Mtetra
.652 .753 .924 r
.49619 .65605 .50398 .66336 .5181 .6594 .51035 .65212 Mtetra
.652 .755 .925 r
.51035 .65212 .5181 .6594 .53229 .65545 .52459 .64817 Mtetra
.654 .756 .925 r
.52459 .64817 .53229 .65545 .54655 .65151 .5389 .64413 Mtetra
.66 .756 .922 r
.5389 .64413 .54655 .65151 .56089 .64753 .55329 .63987 Mtetra
.658 .75 .917 r
.55329 .63987 .56089 .64753 .5753 .6435 .56774 .63566 Mtetra
.656 .745 .915 r
.56774 .63566 .5753 .6435 .58978 .63934 .58228 .63152 Mtetra
.652 .746 .918 r
.58228 .63152 .58978 .63934 .60434 .63511 .5969 .62748 Mtetra
.65 .751 .924 r
.5969 .62748 .60434 .63511 .61898 .6309 .61159 .62351 Mtetra
.648 .758 .929 r
.61159 .62351 .61898 .6309 .63369 .62669 .62637 .61951 Mtetra
.649 .765 .934 r
.62637 .61951 .63369 .62669 .64849 .62249 .64122 .61545 Mtetra
.65 .771 .937 r
.64122 .61545 .64849 .62249 .66336 .61827 .65615 .61129 Mtetra
.653 .774 .938 r
.65615 .61129 .66336 .61827 .67831 .61403 .67116 .60701 Mtetra
.656 .775 .937 r
.67116 .60701 .67831 .61403 .69334 .60977 .68624 .60261 Mtetra
.658 .773 .934 r
.68624 .60261 .69334 .60977 .70845 .60549 .7014 .5981 Mtetra
.66 .769 .93 r
.7014 .5981 .70845 .60549 .72364 .60121 .71664 .59353 Mtetra
.661 .762 .925 r
.71664 .59353 .72364 .60121 .73891 .59694 .73196 .58894 Mtetra
.659 .754 .92 r
.73196 .58894 .73891 .59694 .75427 .59268 .74736 .5844 Mtetra
.656 .747 .917 r
.74736 .5844 .75427 .59268 .76971 .58836 .76285 .57997 Mtetra
.654 .744 .916 r
.76285 .57997 .76971 .58836 .78523 .5839 .77844 .57561 Mtetra
.652 .748 .92 r
.77844 .57561 .78523 .5839 .80083 .57938 .79412 .5713 Mtetra
.657 .756 .923 r
.79412 .5713 .80083 .57938 .81651 .57482 .80986 .56675 Mtetra
.658 .758 .923 r
.80986 .56675 .81651 .57482 .83227 .57027 .82569 .56212 Mtetra
.658 .757 .923 r
.82569 .56212 .83227 .57027 .84813 .56573 .8416 .55745 Mtetra
.658 .755 .922 r
.8416 .55745 .84813 .56573 .86408 .56124 .8576 .5528 Mtetra
.656 .751 .92 r
.8576 .5528 .86408 .56124 .88013 .55682 .8737 .54819 Mtetra
.653 .746 .918 r
.8737 .54819 .88013 .55682 .89626 .55235 .8899 .5437 Mtetra
.653 .746 .919 r
.8899 .5437 .89626 .55235 .91247 .54771 .90619 .53919 Mtetra
.656 .753 .921 r
.90619 .53919 .91247 .54771 .92876 .543 .92256 .53449 Mtetra
.658 .755 .921 r
.92256 .53449 .92876 .543 .94514 .53827 .93901 .5297 Mtetra
.658 .754 .921 r
.93901 .5297 .94514 .53827 .96163 .53358 .95555 .5249 Mtetra
.656 .752 .92 r
.95555 .5249 .96163 .53358 .97821 .52898 .97219 .52014 Mtetra
.653 .751 .921 r
.37725 .68044 .38547 .68761 .39907 .68374 .39088 .6766 Mtetra
.653 .753 .923 r
.39088 .6766 .39907 .68374 .41273 .67992 .40458 .67275 Mtetra
.655 .753 .922 r
.40458 .67275 .41273 .67992 .42646 .67608 .41836 .66881 Mtetra
.66 .753 .919 r
.41836 .66881 .42646 .67608 .44026 .67217 .43221 .66469 Mtetra
.659 .748 .916 r
.43221 .66469 .44026 .67217 .45414 .66808 .44614 .66059 Mtetra
.655 .748 .918 r
.44614 .66059 .45414 .66808 .46809 .66397 .46013 .65661 Mtetra
.653 .752 .922 r
.46013 .65661 .46809 .66397 .4821 .65999 .47419 .65267 Mtetra
.651 .753 .924 r
.47419 .65267 .4821 .65999 .49619 .65605 .48832 .64875 Mtetra
.652 .755 .925 r
.48832 .64875 .49619 .65605 .51035 .65212 .50253 .64477 Mtetra
.66 .757 .922 r
.50253 .64477 .51035 .65212 .52459 .64817 .51682 .64051 Mtetra
.659 .75 .917 r
.51682 .64051 .52459 .64817 .5389 .64413 .53118 .63629 Mtetra
.653 .744 .916 r
.53118 .63629 .5389 .64413 .55329 .63987 .54561 .63225 Mtetra
.644 .748 .925 r
.54561 .63225 .55329 .63987 .56774 .63566 .56013 .62848 Mtetra
.637 .759 .937 r
.56013 .62848 .56774 .63566 .58228 .63152 .57472 .62486 Mtetra
.63 .773 .949 r
.57472 .62486 .58228 .63152 .5969 .62748 .58941 .62132 Mtetra
.624 .787 .96 r
.58941 .62132 .5969 .62748 .61159 .62351 .60417 .6178 Mtetra
.614 .799 .97 r
.60417 .6178 .61159 .62351 .62637 .61951 .61902 .61434 Mtetra
.615 .818 .978 r
.61902 .61434 .62637 .61951 .64122 .61545 .63395 .61063 Mtetra
.619 .832 .982 r
.63395 .61063 .64122 .61545 .65615 .61129 .64896 .60663 Mtetra
.628 .84 .982 r
.64896 .60663 .65615 .61129 .67116 .60701 .66404 .60231 Mtetra
.64 .844 .979 r
.66404 .60231 .67116 .60701 .68624 .60261 .67918 .59767 Mtetra
.653 .841 .973 r
.67918 .59767 .68624 .60261 .7014 .5981 .69439 .59274 Mtetra
.665 .833 .964 r
.69439 .59274 .7014 .5981 .71664 .59353 .70967 .58754 Mtetra
.667 .815 .954 r
.70967 .58754 .71664 .59353 .73196 .58894 .72502 .58241 Mtetra
.669 .801 .945 r
.72502 .58241 .73196 .58894 .74736 .5844 .74046 .57729 Mtetra
.668 .785 .936 r
.74046 .57729 .74736 .5844 .76285 .57997 .75598 .57225 Mtetra
.665 .768 .927 r
.75598 .57225 .76285 .57997 .77844 .57561 .77159 .56735 Mtetra
.659 .753 .92 r
.77159 .56735 .77844 .57561 .79412 .5713 .7873 .56272 Mtetra
.654 .744 .916 r
.7873 .56272 .79412 .5713 .80986 .56675 .80312 .55828 Mtetra
.652 .747 .92 r
.80312 .55828 .80986 .56675 .82569 .56212 .81903 .55388 Mtetra
.658 .757 .923 r
.81903 .55388 .82569 .56212 .8416 .55745 .83501 .54919 Mtetra
.659 .758 .923 r
.83501 .54919 .8416 .55745 .8576 .5528 .85107 .54443 Mtetra
.658 .756 .922 r
.85107 .54443 .8576 .5528 .8737 .54819 .86722 .53968 Mtetra
.657 .753 .921 r
.86722 .53968 .8737 .54819 .8899 .5437 .88347 .53497 Mtetra
.653 .747 .919 r
.88347 .53497 .8899 .5437 .90619 .53919 .89983 .53038 Mtetra
.652 .746 .918 r
.89983 .53038 .90619 .53919 .92256 .53449 .91628 .52582 Mtetra
.656 .752 .921 r
.91628 .52582 .92256 .53449 .93901 .5297 .9328 .52105 Mtetra
.658 .755 .921 r
.9328 .52105 .93901 .5297 .95555 .5249 .94941 .51618 Mtetra
.658 .754 .921 r
.94941 .51618 .95555 .5249 .97219 .52014 .96611 .5113 Mtetra
.653 .752 .923 r
.36894 .67325 .37725 .68044 .39088 .6766 .38262 .66939 Mtetra
.654 .753 .922 r
.38262 .66939 .39088 .6766 .40458 .67275 .39637 .66546 Mtetra
.66 .753 .919 r
.39637 .66546 .40458 .67275 .41836 .66881 .41019 .66131 Mtetra
.659 .748 .916 r
.41019 .66131 .41836 .66881 .43221 .66469 .42409 .65719 Mtetra
.654 .748 .919 r
.42409 .65719 .43221 .66469 .44614 .66059 .43805 .65321 Mtetra
.652 .752 .923 r
.43805 .65321 .44614 .66059 .46013 .65661 .45209 .64927 Mtetra
.651 .754 .925 r
.45209 .64927 .46013 .65661 .47419 .65267 .4662 .64534 Mtetra
.656 .756 .924 r
.4662 .64534 .47419 .65267 .48832 .64875 .48038 .64123 Mtetra
.661 .754 .919 r
.48038 .64123 .48832 .64875 .50253 .64477 .49464 .63694 Mtetra
.655 .745 .916 r
.49464 .63694 .50253 .64477 .51682 .64051 .50897 .63286 Mtetra
.641 .747 .925 r
.50897 .63286 .51682 .64051 .53118 .63629 .52338 .6292 Mtetra
.627 .759 .942 r
.52338 .6292 .53118 .63629 .54561 .63225 .53787 .62588 Mtetra
.606 .774 .961 r
.53787 .62588 .54561 .63225 .56013 .62848 .55245 .62293 Mtetra
.574 .79 .981 r
.55245 .62293 .56013 .62848 .57472 .62486 .56712 .6204 Mtetra
.555 .819 .995 r
.56712 .6204 .57472 .62486 .58941 .62132 .58188 .61768 Mtetra
.542 .842 .999 r
.58188 .61768 .58941 .62132 .60417 .6178 .59672 .61465 Mtetra
.541 .857 .997 r
.59672 .61465 .60417 .6178 .61902 .61434 .61165 .61127 Mtetra
.556 .866 .996 r
.61165 .61127 .61902 .61434 .63395 .61063 .62666 .60753 Mtetra
.573 .872 .995 r
.62666 .60753 .63395 .61063 .64896 .60663 .64174 .60347 Mtetra
.588 .877 .993 r
.64174 .60347 .64896 .60663 .66404 .60231 .65689 .59912 Mtetra
.602 .881 .992 r
.65689 .59912 .66404 .60231 .67918 .59767 .67211 .59447 Mtetra
.615 .886 .989 r
.67211 .59447 .67918 .59767 .69439 .59274 .6874 .58949 Mtetra
.631 .891 .987 r
.6874 .58949 .69439 .59274 .70967 .58754 .70275 .58415 Mtetra
.648 .893 .983 r
.70275 .58415 .70967 .58754 .72502 .58241 .71816 .57844 Mtetra
.671 .883 .977 r
.71816 .57844 .72502 .58241 .74046 .57729 .73362 .57241 Mtetra
.688 .86 .964 r
.73362 .57241 .74046 .57729 .75598 .57225 .74914 .56618 Mtetra
.683 .823 .951 r
.74914 .56618 .75598 .57225 .77159 .56735 .76476 .56037 Mtetra
.676 .795 .939 r
.76476 .56037 .77159 .56735 .7873 .56272 .78049 .55492 Mtetra
.668 .772 .927 r
.78049 .55492 .7873 .56272 .80312 .55828 .79632 .54981 Mtetra
.657 .751 .919 r
.79632 .54981 .80312 .55828 .81903 .55388 .81228 .54514 Mtetra
.652 .743 .917 r
.81228 .54514 .81903 .55388 .83501 .54919 .82834 .54068 Mtetra
.655 .752 .921 r
.82834 .54068 .83501 .54919 .85107 .54443 .84448 .53603 Mtetra
.659 .758 .923 r
.84448 .53603 .85107 .54443 .86722 .53968 .86069 .53118 Mtetra
.659 .756 .922 r
.86069 .53118 .86722 .53968 .88347 .53497 .877 .52634 Mtetra
.657 .753 .921 r
.877 .52634 .88347 .53497 .89983 .53038 .8934 .52154 Mtetra
.653 .748 .919 r
.8934 .52154 .89983 .53038 .91628 .52582 .90991 .51688 Mtetra
.652 .746 .918 r
.90991 .51688 .91628 .52582 .9328 .52105 .92653 .51224 Mtetra
.657 .753 .921 r
.92653 .51224 .9328 .52105 .94941 .51618 .94321 .50738 Mtetra
.658 .755 .921 r
.94321 .50738 .94941 .51618 .96611 .5113 .95999 .50243 Mtetra
.654 .753 .923 r
.36055 .66601 .36894 .67325 .38262 .66939 .37428 .66208 Mtetra
.66 .753 .919 r
.37428 .66208 .38262 .66939 .39637 .66546 .38808 .65793 Mtetra
.66 .749 .916 r
.38808 .65793 .39637 .66546 .41019 .66131 .40195 .65377 Mtetra
.654 .748 .919 r
.40195 .65377 .41019 .66131 .42409 .65719 .41588 .64977 Mtetra
.652 .752 .923 r
.41588 .64977 .42409 .65719 .43805 .65321 .42989 .64584 Mtetra
.651 .754 .925 r
.42989 .64584 .43805 .65321 .45209 .64927 .44397 .64189 Mtetra
.658 .756 .923 r
.44397 .64189 .45209 .64927 .4662 .64534 .45813 .63769 Mtetra
.66 .751 .917 r
.45813 .63769 .4662 .64534 .48038 .64123 .47236 .63342 Mtetra
.647 .744 .92 r
.47236 .63342 .48038 .64123 .49464 .63694 .48667 .62957 Mtetra
.628 .751 .936 r
.48667 .62957 .49464 .63694 .50897 .63286 .50104 .62627 Mtetra
.598 .765 .959 r
.50104 .62627 .50897 .63286 .52338 .6292 .5155 .62358 Mtetra
.547 .778 .984 r
.5155 .62358 .52338 .6292 .53787 .62588 .53005 .62165 Mtetra
.512 .81 .999 r
.53005 .62165 .53787 .62588 .55245 .62293 .5447 .61957 Mtetra
.501 .833 .999 r
.5447 .61957 .55245 .62293 .56712 .6204 .55943 .61706 Mtetra
.532 .847 .998 r
.55943 .61706 .56712 .6204 .58188 .61768 .57426 .61398 Mtetra
.571 .851 .996 r
.57426 .61398 .58188 .61768 .59672 .61465 .58916 .61041 Mtetra
.603 .846 .99 r
.58916 .61041 .59672 .61465 .61165 .61127 .60414 .60646 Mtetra
.624 .836 .981 r
.60414 .60646 .61165 .61127 .62666 .60753 .6192 .60225 Mtetra
.635 .825 .974 r
.6192 .60225 .62666 .60753 .64174 .60347 .63434 .59792 Mtetra
.639 .819 .969 r
.63434 .59792 .64174 .60347 .65689 .59912 .64956 .59353 Mtetra
.64 .82 .969 r
.64956 .59353 .65689 .59912 .67211 .59447 .66487 .58907 Mtetra
.641 .827 .972 r
.66487 .58907 .67211 .59447 .6874 .58949 .68025 .58448 Mtetra
.644 .842 .976 r
.68025 .58448 .6874 .58949 .70275 .58415 .6957 .57963 Mtetra
.649 .86 .98 r
.6957 .57963 .70275 .58415 .71816 .57844 .71121 .5744 Mtetra
.659 .879 .98 r
.71121 .5744 .71816 .57844 .73362 .57241 .72678 .56866 Mtetra
.673 .893 .977 r
.72678 .56866 .73362 .57241 .74914 .56618 .74238 .56234 Mtetra
.689 .896 .972 r
.74238 .56234 .74914 .56618 .76476 .56037 .75802 .55556 Mtetra
.705 .872 .96 r
.75802 .55556 .76476 .56037 .78049 .55492 .77372 .54861 Mtetra
.691 .823 .946 r
.77372 .54861 .78049 .55492 .79632 .54981 .78954 .54243 Mtetra
.677 .79 .934 r
.78954 .54243 .79632 .54981 .81228 .54514 .8055 .53686 Mtetra
.663 .762 .923 r
.8055 .53686 .81228 .54514 .82834 .54068 .82158 .53185 Mtetra
.653 .745 .918 r
.82158 .53185 .82834 .54068 .84448 .53603 .8378 .52728 Mtetra
.654 .749 .92 r
.8378 .52728 .84448 .53603 .86069 .53118 .8541 .52263 Mtetra
.659 .757 .922 r
.8541 .52263 .86069 .53118 .877 .52634 .87047 .5177 Mtetra
.659 .756 .922 r
.87047 .5177 .877 .52634 .8934 .52154 .88693 .51277 Mtetra
.657 .753 .921 r
.88693 .51277 .8934 .52154 .90991 .51688 .90349 .50789 Mtetra
.653 .747 .919 r
.90349 .50789 .90991 .51688 .92653 .51224 .92017 .50318 Mtetra
.652 .746 .919 r
.92017 .50318 .92653 .51224 .94321 .50738 .93695 .49845 Mtetra
.657 .753 .921 r
.93695 .49845 .94321 .50738 .95999 .50243 .95379 .49348 Mtetra
.658 .753 .92 r
.35209 .65868 .36055 .66601 .37428 .66208 .36586 .65456 Mtetra
.661 .75 .916 r
.36586 .65456 .37428 .66208 .38808 .65793 .37971 .65034 Mtetra
.655 .748 .918 r
.37971 .65034 .38808 .65793 .40195 .65377 .39362 .64632 Mtetra
.652 .751 .923 r
.39362 .64632 .40195 .65377 .41588 .64977 .4076 .64236 Mtetra
.651 .753 .925 r
.4076 .64236 .41588 .64977 .42989 .64584 .42165 .63841 Mtetra
.658 .756 .922 r
.42165 .63841 .42989 .64584 .44397 .64189 .43578 .63417 Mtetra
.659 .75 .917 r
.43578 .63417 .44397 .64189 .45813 .63769 .44999 .62991 Mtetra
.642 .744 .923 r
.44999 .62991 .45813 .63769 .47236 .63342 .46426 .62623 Mtetra
.615 .753 .944 r
.46426 .62623 .47236 .63342 .48667 .62957 .4786 .62326 Mtetra
.558 .761 .973 r
.4786 .62326 .48667 .62957 .50104 .62627 .49301 .6214 Mtetra
.499 .785 .996 r
.49301 .6214 .50104 .62627 .5155 .62358 .50752 .61992 Mtetra
.477 .814 .999 r
.50752 .61992 .5155 .62358 .53005 .62165 .52214 .61797 Mtetra
.528 .835 .999 r
.52214 .61797 .53005 .62165 .5447 .61957 .53684 .61521 Mtetra
.593 .837 .991 r
.53684 .61521 .5447 .61957 .55943 .61706 .55163 .61159 Mtetra
.647 .82 .966 r
.55163 .61159 .55943 .61706 .57426 .61398 .5665 .60708 Mtetra
.681 .788 .931 r
.5665 .60708 .57426 .61398 .58916 .61041 .58143 .6017 Mtetra
.681 .743 .898 r
.58143 .6017 .58916 .61041 .60414 .60646 .59644 .59627 Mtetra
.674 .71 .875 r
.59644 .59627 .60414 .60646 .6192 .60225 .61152 .59106 Mtetra
.664 .688 .862 r
.61152 .59106 .6192 .60225 .63434 .59792 .62668 .5862 Mtetra
.654 .675 .858 r
.62668 .5862 .63434 .59792 .64956 .59353 .64194 .58175 Mtetra
.645 .672 .861 r
.64194 .58175 .64956 .59353 .66487 .58907 .65731 .57773 Mtetra
.638 .677 .871 r
.65731 .57773 .66487 .58907 .68025 .58448 .67277 .57406 Mtetra
.632 .694 .89 r
.67277 .57406 .68025 .58448 .6957 .57963 .68834 .5706 Mtetra
.629 .725 .917 r
.68834 .5706 .6957 .57963 .71121 .5744 .70401 .56712 Mtetra
.645 .778 .944 r
.70401 .56712 .71121 .5744 .72678 .56866 .71972 .56274 Mtetra
.663 .825 .962 r
.71972 .56274 .72678 .56866 .74238 .56234 .73546 .55746 Mtetra
.68 .864 .969 r
.73546 .55746 .74238 .56234 .75802 .55556 .75123 .5513 Mtetra
.699 .889 .967 r
.75123 .5513 .75802 .55556 .77372 .54861 .76702 .54429 Mtetra
.713 .892 .961 r
.76702 .54429 .77372 .54861 .78954 .54243 .78283 .53679 Mtetra
.711 .853 .95 r
.78283 .53679 .78954 .54243 .8055 .53686 .79874 .52966 Mtetra
.685 .801 .937 r
.79874 .52966 .8055 .53686 .82158 .53185 .81481 .52366 Mtetra
.668 .77 .926 r
.81481 .52366 .82158 .53185 .8378 .52728 .83104 .51838 Mtetra
.653 .747 .919 r
.83104 .51838 .8378 .52728 .8541 .52263 .84741 .5137 Mtetra
.653 .748 .919 r
.84741 .5137 .8541 .52263 .87047 .5177 .86387 .509 Mtetra
.66 .757 .922 r
.86387 .509 .87047 .5177 .88693 .51277 .88039 .50398 Mtetra
.659 .756 .922 r
.88039 .50398 .88693 .51277 .90349 .50789 .89702 .49897 Mtetra
.657 .753 .921 r
.89702 .49897 .90349 .50789 .92017 .50318 .91374 .49403 Mtetra
.652 .746 .919 r
.91374 .49403 .92017 .50318 .93695 .49845 .93059 .48927 Mtetra
.654 .748 .919 r
.93059 .48927 .93695 .49845 .95379 .49348 .94753 .48442 Mtetra
.661 .752 .917 r
.34355 .65119 .35209 .65868 .36586 .65456 .35737 .64694 Mtetra
.657 .748 .918 r
.35737 .64694 .36586 .65456 .37971 .65034 .37125 .64283 Mtetra
.652 .751 .922 r
.37125 .64283 .37971 .65034 .39362 .64632 .3852 .63885 Mtetra
.65 .753 .924 r
.3852 .63885 .39362 .64632 .4076 .64236 .39923 .6349 Mtetra
.657 .756 .922 r
.39923 .6349 .4076 .64236 .42165 .63841 .41333 .63067 Mtetra
.659 .75 .917 r
.41333 .63067 .42165 .63841 .43578 .63417 .42751 .62637 Mtetra
.639 .744 .925 r
.42751 .62637 .43578 .63417 .44999 .62991 .44175 .62276 Mtetra
.605 .752 .948 r
.44175 .62276 .44999 .62991 .46426 .62623 .45605 .62001 Mtetra
.527 .753 .979 r
.45605 .62001 .46426 .62623 .4786 .62326 .47042 .61872 Mtetra
.466 .782 .998 r
.47042 .61872 .4786 .62326 .49301 .6214 .48488 .61753 Mtetra
.491 .814 1 r
.48488 .61753 .49301 .6214 .50752 .61992 .49946 .6155 Mtetra
.577 .83 .993 r
.49946 .6155 .50752 .61992 .52214 .61797 .51413 .61225 Mtetra
.665 .816 .956 r
.51413 .61225 .52214 .61797 .53684 .61521 .52889 .60728 Mtetra
.705 .766 .9 r
.52889 .60728 .53684 .61521 .55163 .61159 .54372 .60092 Mtetra
.7 .708 .854 r
.54372 .60092 .55163 .61159 .5665 .60708 .55861 .59426 Mtetra
.689 .669 .826 r
.55861 .59426 .5665 .60708 .58143 .6017 .57356 .58771 Mtetra
.679 .65 .814 r
.57356 .58771 .58143 .6017 .59644 .59627 .58858 .58147 Mtetra
.668 .636 .808 r
.58858 .58147 .59644 .59627 .61152 .59106 .60367 .57578 Mtetra
.657 .625 .807 r
.60367 .57578 .61152 .59106 .62668 .5862 .61886 .57067 Mtetra
.646 .618 .808 r
.61886 .57067 .62668 .5862 .64194 .58175 .63414 .56617 Mtetra
.636 .614 .81 r
.63414 .56617 .64194 .58175 .65731 .57773 .64953 .56228 Mtetra
.626 .611 .815 r
.64953 .56228 .65731 .57773 .67277 .57406 .66504 .55898 Mtetra
.616 .611 .823 r
.66504 .55898 .67277 .57406 .68834 .5706 .68067 .55624 Mtetra
.61 .619 .835 r
.68067 .55624 .68834 .5706 .70401 .56712 .69642 .55382 Mtetra
.606 .634 .852 r
.69642 .55382 .70401 .56712 .71972 .56274 .71229 .55153 Mtetra
.609 .673 .886 r
.71229 .55153 .71972 .56274 .73546 .55746 .72825 .54895 Mtetra
.637 .747 .928 r
.72825 .54895 .73546 .55746 .75123 .5513 .74423 .54495 Mtetra
.676 .821 .953 r
.74423 .54495 .75123 .5513 .76702 .54429 .76018 .5392 Mtetra
.704 .868 .959 r
.76018 .5392 .76702 .54429 .78283 .53679 .77612 .53217 Mtetra
.724 .889 .955 r
.77612 .53217 .78283 .53679 .79874 .52966 .79206 .52427 Mtetra
.726 .868 .948 r
.79206 .52427 .79874 .52966 .81481 .52366 .80807 .51645 Mtetra
.691 .807 .936 r
.80807 .51645 .81481 .52366 .83104 .51838 .82427 .51012 Mtetra
.67 .772 .927 r
.82427 .51012 .83104 .51838 .84741 .5137 .84064 .50468 Mtetra
.653 .747 .919 r
.84064 .50468 .84741 .5137 .86387 .509 .85717 .49995 Mtetra
.654 .749 .919 r
.85717 .49995 .86387 .509 .88039 .50398 .87379 .49512 Mtetra
.66 .757 .922 r
.87379 .49512 .88039 .50398 .89702 .49897 .89048 .49001 Mtetra
.659 .755 .921 r
.89048 .49001 .89702 .49897 .91374 .49403 .90727 .48493 Mtetra
.655 .752 .921 r
.90727 .48493 .91374 .49403 .93059 .48927 .92417 .47997 Mtetra
.651 .746 .919 r
.92417 .47997 .93059 .48927 .94753 .48442 .94119 .47516 Mtetra
.659 .749 .917 r
.33493 .64355 .34355 .65119 .35737 .64694 .34879 .63934 Mtetra
.653 .75 .921 r
.34879 .63934 .35737 .64694 .37125 .64283 .36271 .6353 Mtetra
.65 .752 .924 r
.36271 .6353 .37125 .64283 .3852 .63885 .37671 .63134 Mtetra
.655 .755 .923 r
.37671 .63134 .3852 .63885 .39923 .6349 .39078 .6272 Mtetra
.661 .753 .918 r
.39078 .6272 .39923 .6349 .41333 .63067 .40494 .62281 Mtetra
.641 .744 .923 r
.40494 .62281 .41333 .63067 .42751 .62637 .41915 .61911 Mtetra
.603 .749 .947 r
.41915 .61911 .42751 .62637 .44175 .62276 .43341 .61642 Mtetra
.512 .746 .98 r
.43341 .61642 .44175 .62276 .45605 .62001 .44772 .61542 Mtetra
.449 .774 .998 r
.44772 .61542 .45605 .62001 .47042 .61872 .46213 .61448 Mtetra
.507 .81 1 r
.46213 .61448 .47042 .61872 .48488 .61753 .47666 .6124 Mtetra
.616 .82 .979 r
.47666 .6124 .48488 .61753 .49946 .6155 .49131 .6086 Mtetra
.713 .793 .915 r
.49131 .6086 .49946 .6155 .51413 .61225 .50606 .60199 Mtetra
.717 .72 .852 r
.50606 .60199 .51413 .61225 .52889 .60728 .52087 .59442 Mtetra
.708 .676 .817 r
.52087 .59442 .52889 .60728 .54372 .60092 .53573 .58657 Mtetra
.696 .653 .803 r
.53573 .58657 .54372 .60092 .55861 .59426 .55064 .57904 Mtetra
.683 .637 .798 r
.55064 .57904 .55861 .59426 .57356 .58771 .56561 .57219 Mtetra
.671 .629 .799 r
.56561 .57219 .57356 .58771 .58858 .58147 .58066 .56609 Mtetra
.659 .626 .805 r
.58066 .56609 .58858 .58147 .60367 .57578 .59579 .56079 Mtetra
.653 .628 .813 r
.59579 .56079 .60367 .57578 .61886 .57067 .61101 .55596 Mtetra
.649 .631 .818 r
.61101 .55596 .61886 .57067 .63414 .56617 .62632 .55141 Mtetra
.644 .628 .82 r
.62632 .55141 .63414 .56617 .64953 .56228 .64173 .54713 Mtetra
.634 .62 .818 r
.64173 .54713 .64953 .56228 .66504 .55898 .65724 .54332 Mtetra
.619 .607 .816 r
.65724 .54332 .66504 .55898 .68067 .55624 .67288 .54034 Mtetra
.605 .597 .817 r
.67288 .54034 .68067 .55624 .69642 .55382 .68867 .53811 Mtetra
.591 .594 .823 r
.68867 .53811 .69642 .55382 .71229 .55153 .7046 .53659 Mtetra
.584 .601 .835 r
.7046 .53659 .71229 .55153 .72825 .54895 .72067 .5354 Mtetra
.586 .623 .856 r
.72067 .5354 .72825 .54895 .74423 .54495 .73685 .53395 Mtetra
.601 .678 .895 r
.73685 .53395 .74423 .54495 .76018 .5392 .75309 .53155 Mtetra
.666 .785 .937 r
.75309 .53155 .76018 .5392 .77612 .53217 .76923 .52625 Mtetra
.707 .848 .95 r
.76923 .52625 .77612 .53217 .79206 .52427 .78532 .51918 Mtetra
.734 .881 .948 r
.78532 .51918 .79206 .52427 .80807 .51645 .80139 .51092 Mtetra
.734 .869 .944 r
.80139 .51092 .80807 .51645 .82427 .51012 .81752 .5027 Mtetra
.694 .805 .934 r
.81752 .5027 .82427 .51012 .84064 .50468 .83387 .4962 Mtetra
.668 .769 .926 r
.83387 .4962 .84064 .50468 .85717 .49995 .85041 .49075 Mtetra
.651 .746 .919 r
.85041 .49075 .85717 .49995 .87379 .49512 .86711 .48601 Mtetra
.657 .752 .92 r
.86711 .48601 .87379 .49512 .89048 .49001 .88388 .481 Mtetra
.66 .757 .922 r
.88388 .481 .89048 .49001 .90727 .48493 .90073 .4758 Mtetra
.658 .754 .921 r
.90073 .4758 .90727 .48493 .92417 .47997 .91769 .47067 Mtetra
.653 .749 .92 r
.91769 .47067 .92417 .47997 .94119 .47516 .93477 .46572 Mtetra
.655 .749 .919 r
.32623 .63585 .33493 .64355 .34879 .63934 .34013 .63174 Mtetra
.651 .751 .923 r
.34013 .63174 .34879 .63934 .36271 .6353 .35409 .62774 Mtetra
.651 .753 .925 r
.35409 .62774 .36271 .6353 .37671 .63134 .36813 .62372 Mtetra
.663 .756 .919 r
.36813 .62372 .37671 .63134 .39078 .6272 .38226 .61926 Mtetra
.648 .745 .92 r
.38226 .61926 .39078 .6272 .40494 .62281 .39645 .61532 Mtetra
.609 .746 .942 r
.39645 .61532 .40494 .62281 .41915 .61911 .41067 .6125 Mtetra
.517 .74 .976 r
.41067 .6125 .41915 .61911 .43341 .61642 .42493 .6115 Mtetra
.441 .761 .996 r
.42493 .6115 .43341 .61642 .44772 .61542 .43928 .61085 Mtetra
.51 .802 .998 r
.43928 .61085 .44772 .61542 .46213 .61448 .45377 .60889 Mtetra
.643 .814 .965 r
.45377 .60889 .46213 .61448 .47666 .6124 .4684 .60453 Mtetra
.728 .772 .888 r
.4684 .60453 .47666 .6124 .49131 .6086 .48314 .59704 Mtetra
.725 .701 .827 r
.48314 .59704 .49131 .6086 .50606 .60199 .49794 .58847 Mtetra
.716 .671 .804 r
.49794 .58847 .50606 .60199 .52087 .59442 .51279 .57972 Mtetra
.7 .65 .797 r
.51279 .57972 .52087 .59442 .53573 .58657 .52768 .57177 Mtetra
.677 .64 .806 r
.52768 .57177 .53573 .58657 .55064 .57904 .54263 .56542 Mtetra
.664 .651 .827 r
.54263 .56542 .55064 .57904 .56561 .57219 .55766 .56016 Mtetra
.659 .674 .853 r
.55766 .56016 .56561 .57219 .58066 .56609 .57277 .55537 Mtetra
.657 .698 .876 r
.57277 .55537 .58066 .56609 .59579 .56079 .58796 .55079 Mtetra
.656 .713 .89 r
.58796 .55079 .59579 .56079 .61101 .55596 .60324 .54624 Mtetra
.657 .721 .896 r
.60324 .54624 .61101 .55596 .62632 .55141 .6186 .54164 Mtetra
.658 .721 .895 r
.6186 .54164 .62632 .55141 .64173 .54713 .63404 .53698 Mtetra
.656 .713 .89 r
.63404 .53698 .64173 .54713 .65724 .54332 .64957 .53235 Mtetra
.651 .696 .879 r
.64957 .53235 .65724 .54332 .67288 .54034 .6652 .52794 Mtetra
.639 .665 .86 r
.6652 .52794 .67288 .54034 .68867 .53811 .68094 .524 Mtetra
.615 .629 .841 r
.68094 .524 .68867 .53811 .7046 .53659 .69684 .52118 Mtetra
.583 .595 .831 r
.69684 .52118 .7046 .53659 .72067 .5354 .71293 .51998 Mtetra
.565 .587 .834 r
.71293 .51998 .72067 .5354 .73685 .53395 .72921 .51962 Mtetra
.565 .603 .85 r
.72921 .51962 .73685 .53395 .75309 .53155 .7456 .5191 Mtetra
.584 .645 .877 r
.7456 .5191 .75309 .53155 .76923 .52625 .76206 .5175 Mtetra
.654 .755 .924 r
.76206 .5175 .76923 .52625 .78532 .51918 .7784 .51269 Mtetra
.712 .836 .941 r
.7784 .51269 .78532 .51918 .80139 .51092 .79463 .50539 Mtetra
.743 .873 .94 r
.79463 .50539 .80139 .51092 .81752 .5027 .81082 .49671 Mtetra
.735 .86 .939 r
.81082 .49671 .81752 .5027 .83387 .4962 .82709 .48838 Mtetra
.691 .797 .931 r
.82709 .48838 .83387 .4962 .85041 .49075 .84361 .48192 Mtetra
.663 .762 .924 r
.84361 .48192 .85041 .49075 .86711 .48601 .86033 .47662 Mtetra
.65 .744 .919 r
.86033 .47662 .86711 .48601 .88388 .481 .8772 .47185 Mtetra
.66 .756 .921 r
.8772 .47185 .88388 .481 .90073 .4758 .89413 .46661 Mtetra
.89413 .46661 .90073 .4758 .91769 .47067 .91115 .46135 Mtetra
.657 .753 .921 r
.91115 .46135 .91769 .47067 .93477 .46572 .92829 .45619 Mtetra
.652 .751 .922 r
.31744 .62818 .32623 .63585 .34013 .63174 .33137 .6241 Mtetra
.65 .752 .924 r
.33137 .6241 .34013 .63174 .35409 .62774 .34538 .6201 Mtetra
.659 .755 .921 r
.34538 .6201 .35409 .62774 .36813 .62372 .35948 .61576 Mtetra
.657 .748 .917 r
.35948 .61576 .36813 .62372 .38226 .61926 .37365 .61149 Mtetra
.621 .743 .934 r
.37365 .61149 .38226 .61926 .39645 .61532 .38785 .60833 Mtetra
.541 .739 .967 r
.38785 .60833 .39645 .61532 .41067 .6125 .40206 .60696 Mtetra
.442 .744 .992 r
.40206 .60696 .41067 .6125 .42493 .6115 .41635 .60663 Mtetra
.493 .787 .997 r
.41635 .60663 .42493 .6115 .43928 .61085 .43078 .60508 Mtetra
.64 .809 .964 r
.43078 .60508 .43928 .61085 .45377 .60889 .44537 .60084 Mtetra
.736 .77 .881 r
.44537 .60084 .45377 .60889 .4684 .60453 .46012 .59287 Mtetra
.735 .703 .82 r
.46012 .59287 .4684 .60453 .48314 .59704 .47493 .58352 Mtetra
.724 .674 .801 r
.47493 .58352 .48314 .59704 .49794 .58847 .48978 .57415 Mtetra
.699 .655 .803 r
.48978 .57415 .49794 .58847 .51279 .57972 .50466 .56638 Mtetra
.671 .658 .828 r
.50466 .56638 .51279 .57972 .52768 .57177 .51958 .56074 Mtetra
.659 .692 .87 r
.51958 .56074 .52768 .57177 .54263 .56542 .53458 .55607 Mtetra
.643 .722 .906 r
.53458 .55607 .54263 .56542 .55766 .56016 .54967 .55208 Mtetra
.635 .752 .932 r
.54967 .55208 .55766 .56016 .57277 .55537 .56485 .54822 Mtetra
.635 .778 .949 r
.56485 .54822 .57277 .55537 .58796 .55079 .58011 .54418 Mtetra
.639 .795 .957 r
.58011 .54418 .58796 .55079 .60324 .54624 .59546 .53985 Mtetra
.647 .805 .959 r
.59546 .53985 .60324 .54624 .6186 .54164 .61089 .5352 Mtetra
.657 .808 .956 r
.61089 .5352 .6186 .54164 .63404 .53698 .62639 .53024 Mtetra
.666 .803 .948 r
.62639 .53024 .63404 .53698 .64957 .53235 .64197 .52498 Mtetra
.673 .789 .936 r
.64197 .52498 .64957 .53235 .6652 .52794 .65762 .51953 Mtetra
.67 .763 .92 r
.65762 .51953 .6652 .52794 .68094 .524 .67336 .51421 Mtetra
.654 .726 .902 r
.67336 .51421 .68094 .524 .69684 .52118 .68922 .50958 Mtetra
.631 .68 .878 r
.68922 .50958 .69684 .52118 .71293 .51998 .70523 .50593 Mtetra
.585 .618 .851 r
.70523 .50593 .71293 .51998 .72921 .51962 .72147 .50446 Mtetra
.551 .585 .842 r
.72147 .50446 .72921 .51962 .7456 .5191 .73794 .50465 Mtetra
.547 .595 .853 r
.73794 .50465 .7456 .5191 .76206 .5175 .75455 .50484 Mtetra
.573 .638 .878 r
.75455 .50484 .76206 .5175 .7784 .51269 .77121 .50364 Mtetra
.658 .753 .92 r
.77121 .50364 .7784 .51269 .79463 .50539 .78769 .49861 Mtetra
.723 .835 .934 r
.78769 .49861 .79463 .50539 .81082 .49671 .80404 .49077 Mtetra
.752 .867 .932 r
.80404 .49077 .81082 .49671 .82709 .48838 .82034 .48166 Mtetra
.727 .841 .935 r
.82034 .48166 .82709 .48838 .84361 .48192 .8368 .4736 Mtetra
.683 .785 .928 r
.8368 .4736 .84361 .48192 .86033 .47662 .85351 .46738 Mtetra
.655 .753 .922 r
.85351 .46738 .86033 .47662 .8772 .47185 .87043 .46232 Mtetra
.653 .746 .918 r
.87043 .46232 .8772 .47185 .89413 .46661 .88746 .45732 Mtetra
.661 .756 .921 r
.88746 .45732 .89413 .46661 .91115 .46135 .90455 .45197 Mtetra
.659 .755 .921 r
.90455 .45197 .91115 .46135 .92829 .45619 .92175 .44667 Mtetra
.65 .751 .923 r
.30856 .62047 .31744 .62818 .33137 .6241 .32253 .61642 Mtetra
.651 .753 .924 r
.32253 .61642 .33137 .6241 .34538 .6201 .33659 .61232 Mtetra
.663 .754 .918 r
.33659 .61232 .34538 .6201 .35948 .61576 .35074 .60779 Mtetra
.639 .744 .925 r
.35074 .60779 .35948 .61576 .37365 .61149 .36493 .60409 Mtetra
.58 .743 .954 r
.36493 .60409 .37365 .61149 .38785 .60833 .37913 .60191 Mtetra
.459 .726 .983 r
.37913 .60191 .38785 .60833 .40206 .60696 .39335 .60175 Mtetra
.461 .764 .995 r
.39335 .60175 .40206 .60696 .41635 .60663 .4077 .60087 Mtetra
.603 .8 .975 r
.4077 .60087 .41635 .60663 .43078 .60508 .42223 .59755 Mtetra
.737 .783 .889 r
.42223 .59755 .43078 .60508 .44537 .60084 .43697 .5896 Mtetra
.744 .712 .822 r
.43697 .5896 .44537 .60084 .46012 .59287 .4518 .57976 Mtetra
.734 .683 .802 r
.4518 .57976 .46012 .59287 .47493 .58352 .46667 .56979 Mtetra
.701 .664 .81 r
.46667 .56979 .47493 .58352 .48978 .57415 .48153 .56207 Mtetra
.67 .677 .849 r
.48153 .56207 .48978 .57415 .50466 .56638 .49643 .55674 Mtetra
.642 .715 .901 r
.49643 .55674 .50466 .56638 .51958 .56074 .5114 .55278 Mtetra
.617 .749 .94 r
.5114 .55278 .51958 .56074 .53458 .55607 .52646 .54948 Mtetra
.608 .785 .966 r
.52646 .54948 .53458 .55607 .54967 .55208 .54161 .54607 Mtetra
.623 .808 .971 r
.54161 .54607 .54967 .55208 .56485 .54822 .55685 .54205 Mtetra
.636 .808 .966 r
.55685 .54205 .56485 .54822 .58011 .54418 .57217 .53769 Mtetra
.644 .802 .959 r
.57217 .53769 .58011 .54418 .59546 .53985 .58758 .53314 Mtetra
.649 .799 .955 r
.58758 .53314 .59546 .53985 .61089 .5352 .60308 .52845 Mtetra
.653 .8 .954 r
.60308 .52845 .61089 .5352 .62639 .53024 .61865 .52361 Mtetra
.656 .806 .955 r
.61865 .52361 .62639 .53024 .64197 .52498 .63431 .51859 Mtetra
.665 .817 .956 r
.63431 .51859 .64197 .52498 .65762 .51953 .65004 .51321 Mtetra
.682 .825 .952 r
.65004 .51321 .65762 .51953 .67336 .51421 .66583 .50722 Mtetra
.687 .808 .94 r
.66583 .50722 .67336 .51421 .68922 .50958 .6817 .5011 Mtetra
.671 .766 .922 r
.6817 .5011 .68922 .50958 .70523 .50593 .69767 .49565 Mtetra
.637 .713 .902 r
.69767 .49565 .70523 .50593 .72147 .50446 .71381 .49159 Mtetra
.583 .639 .872 r
.71381 .49159 .72147 .50446 .73794 .50465 .73021 .48998 Mtetra
.534 .586 .853 r
.73021 .48998 .73794 .50465 .75455 .50484 .74689 .4907 Mtetra
.533 .595 .862 r
.74689 .4907 .75455 .50484 .77121 .50364 .76371 .49131 Mtetra
.572 .647 .885 r
.76371 .49131 .77121 .50364 .78769 .49861 .78054 .48999 Mtetra
.681 .775 .922 r
.78054 .48999 .78769 .49861 .80404 .49077 .79711 .4839 Mtetra
.74 .84 .926 r
.79711 .4839 .80404 .49077 .82034 .48166 .81355 .47526 Mtetra
.756 .859 .926 r
.81355 .47526 .82034 .48166 .8368 .4736 .82997 .46584 Mtetra
.708 .811 .929 r
.82997 .46584 .8368 .4736 .85351 .46738 .84666 .45852 Mtetra
.67 .77 .925 r
.84666 .45852 .85351 .46738 .87043 .46232 .86358 .45276 Mtetra
.649 .746 .92 r
.86358 .45276 .87043 .46232 .88746 .45732 .8807 .44786 Mtetra
.659 .754 .92 r
.8807 .44786 .88746 .45732 .90455 .45197 .89787 .44251 Mtetra
.66 .756 .921 r
.89787 .44251 .90455 .45197 .92175 .44667 .91514 .43709 Mtetra
.649 .751 .924 r
.29959 .6127 .30856 .62047 .32253 .61642 .31361 .60864 Mtetra
.658 .754 .921 r
.31361 .60864 .32253 .61642 .33659 .61232 .32772 .60426 Mtetra
.656 .748 .918 r
.32772 .60426 .33659 .61232 .35074 .60779 .34191 .59996 Mtetra
.613 .742 .938 r
.34191 .59996 .35074 .60779 .36493 .60409 .3561 .59697 Mtetra
.509 .727 .971 r
.3561 .59697 .36493 .60409 .37913 .60191 .37028 .59619 Mtetra
.431 .737 .991 r
.37028 .59619 .37913 .60191 .39335 .60175 .38454 .59601 Mtetra
.548 .784 .986 r
.38454 .59601 .39335 .60175 .4077 .60087 .39899 .59383 Mtetra
.713 .792 .913 r
.39899 .59383 .4077 .60087 .42223 .59755 .41369 .58712 Mtetra
.75 .728 .831 r
.41369 .58712 .42223 .59755 .43697 .5896 .42853 .57721 Mtetra
.746 .697 .805 r
.42853 .57721 .43697 .5896 .4518 .57976 .44342 .56657 Mtetra
.712 .676 .813 r
.44342 .56657 .4518 .57976 .46667 .56979 .4583 .55825 Mtetra
.671 .688 .857 r
.4583 .55825 .46667 .56979 .48153 .56207 .47318 .55289 Mtetra
.629 .722 .914 r
.47318 .55289 .48153 .56207 .49643 .55674 .48811 .54937 Mtetra
.597 .759 .956 r
.48811 .54937 .49643 .55674 .5114 .55278 .50313 .54648 Mtetra
.61 .795 .97 r
.50313 .54648 .5114 .55278 .52646 .54948 .51824 .54291 Mtetra
.633 .795 .96 r
.51824 .54291 .52646 .54948 .54161 .54607 .53345 .53873 Mtetra
.646 .779 .944 r
.53345 .53873 .54161 .54607 .55685 .54205 .54875 .53429 Mtetra
.652 .771 .936 r
.54875 .53429 .55685 .54205 .57217 .53769 .56413 .52967 Mtetra
.655 .766 .931 r
.56413 .52967 .57217 .53769 .58758 .53314 .5796 .52496 Mtetra
.655 .763 .929 r
.5796 .52496 .58758 .53314 .60308 .52845 .59515 .52022 Mtetra
.59515 .52022 .60308 .52845 .61865 .52361 .61079 .51545 Mtetra
.656 .767 .931 r
.61079 .51545 .61865 .52361 .63431 .51859 .62652 .51059 Mtetra
.66 .773 .933 r
.62652 .51059 .63431 .51859 .65004 .51321 .64233 .50554 Mtetra
.666 .785 .938 r
.64233 .50554 .65004 .51321 .66583 .50722 .65822 .50023 Mtetra
.68 .809 .944 r
.65822 .50023 .66583 .50722 .6817 .5011 .67416 .4943 Mtetra
.697 .821 .941 r
.67416 .4943 .6817 .5011 .69767 .49565 .69016 .48767 Mtetra
.682 .786 .929 r
.69016 .48767 .69767 .49565 .71381 .49159 .70626 .48167 Mtetra
.636 .724 .911 r
.70626 .48167 .71381 .49159 .73021 .48998 .72256 .47754 Mtetra
.566 .641 .885 r
.72256 .47754 .73021 .48998 .74689 .4907 .73916 .47645 Mtetra
.514 .584 .863 r
.73916 .47645 .74689 .4907 .76371 .49131 .75607 .47777 Mtetra
.527 .605 .874 r
.75607 .47777 .76371 .49131 .78054 .48999 .77308 .47837 Mtetra
.601 .678 .895 r
.77308 .47837 .78054 .48999 .79711 .4839 .78999 .47567 Mtetra
.709 .799 .92 r
.78999 .47567 .79711 .4839 .81355 .47526 .80662 .4683 Mtetra
.756 .846 .919 r
.80662 .4683 .81355 .47526 .82997 .46584 .82314 .45881 Mtetra
.742 .843 .926 r
.82314 .45881 .82997 .46584 .84666 .45852 .83977 .44992 Mtetra
.689 .787 .925 r
.83977 .44992 .84666 .45852 .86358 .45276 .85669 .44332 Mtetra
.656 .754 .922 r
.85669 .44332 .86358 .45276 .8807 .44786 .87385 .43808 Mtetra
.654 .747 .918 r
.87385 .43808 .8807 .44786 .89787 .44251 .89112 .43293 Mtetra
.661 .756 .92 r
.89112 .43293 .89787 .44251 .91514 .43709 .90846 .42742 Mtetra
.65 .752 .924 r
.29053 .60487 .29959 .6127 .31361 .60864 .3046 .60076 Mtetra
.663 .755 .918 r
.3046 .60076 .31361 .60864 .32772 .60426 .31877 .59618 Mtetra
.641 .745 .924 r
.31877 .59618 .32772 .60426 .34191 .59996 .33297 .59233 Mtetra
.578 .739 .952 r
.33297 .59233 .34191 .59996 .3561 .59697 .34716 .59017 Mtetra
.447 .713 .98 r
.34716 .59017 .3561 .59697 .37028 .59619 .36134 .59027 Mtetra
.478 .753 .99 r
.36134 .59027 .37028 .59619 .38454 .59601 .37568 .58941 Mtetra
.649 .791 .95 r
.37568 .58941 .38454 .59601 .39899 .59383 .39026 .58499 Mtetra
.752 .758 .858 r
.39026 .58499 .39899 .59383 .41369 .58712 .4051 .57567 Mtetra
.757 .714 .812 r
.4051 .57567 .41369 .58712 .42853 .57721 .42003 .56458 Mtetra
.733 .691 .811 r
.42003 .56458 .42853 .57721 .44342 .56657 .43494 .55491 Mtetra
.68 .69 .852 r
.43494 .55491 .44342 .56657 .4583 .55825 .44981 .54903 Mtetra
.629 .723 .915 r
.44981 .54903 .4583 .55825 .47318 .55289 .46471 .54549 Mtetra
.586 .755 .959 r
.46471 .54549 .47318 .55289 .48811 .54937 .47968 .54288 Mtetra
.613 .791 .967 r
.47968 .54288 .48811 .54937 .50313 .54648 .49476 .53924 Mtetra
.639 .779 .948 r
.49476 .53924 .50313 .54648 .51824 .54291 .50994 .53501 Mtetra
.653 .767 .933 r
.50994 .53501 .51824 .54291 .53345 .53873 .52521 .5304 Mtetra
.656 .758 .925 r
.52521 .5304 .53345 .53873 .54875 .53429 .54056 .52567 Mtetra
.656 .752 .921 r
.54056 .52567 .54875 .53429 .56413 .52967 .556 .52093 Mtetra
.656 .751 .92 r
.556 .52093 .56413 .52967 .5796 .52496 .57152 .51618 Mtetra
.57152 .51618 .5796 .52496 .59515 .52022 .58713 .51139 Mtetra
.58713 .51139 .59515 .52022 .61079 .51545 .60283 .50656 Mtetra
.60283 .50656 .61079 .51545 .62652 .51059 .61862 .50172 Mtetra
.655 .752 .921 r
.61862 .50172 .62652 .51059 .64233 .50554 .6345 .49687 Mtetra
.657 .759 .925 r
.6345 .49687 .64233 .50554 .65822 .50023 .65047 .4919 Mtetra
.666 .772 .928 r
.65047 .4919 .65822 .50023 .67416 .4943 .66651 .48654 Mtetra
.68 .792 .934 r
.66651 .48654 .67416 .4943 .69016 .48767 .68261 .48057 Mtetra
.705 .818 .935 r
.68261 .48057 .69016 .48767 .70626 .48167 .69874 .47355 Mtetra
.682 .786 .929 r
.69874 .47355 .70626 .48167 .72256 .47754 .715 .46746 Mtetra
.623 .718 .914 r
.715 .46746 .72256 .47754 .73916 .47645 .73149 .46377 Mtetra
.53 .622 .888 r
.73149 .46377 .73916 .47645 .75607 .47777 .74836 .46397 Mtetra
.497 .586 .874 r
.74836 .46397 .75607 .47777 .77308 .47837 .76549 .46567 Mtetra
.537 .628 .889 r
.76549 .46567 .77308 .47837 .78999 .47567 .78265 .46558 Mtetra
.656 .737 .909 r
.78265 .46558 .78999 .47567 .80662 .4683 .79954 .46041 Mtetra
.74 .82 .914 r
.79954 .46041 .80662 .4683 .82314 .45881 .81621 .45155 Mtetra
.762 .843 .913 r
.81621 .45155 .82314 .45881 .83977 .44992 .83284 .44165 Mtetra
.71 .804 .924 r
.83284 .44165 .83977 .44992 .85669 .44332 .84975 .43408 Mtetra
.668 .767 .924 r
.84975 .43408 .85669 .44332 .87385 .43808 .86693 .42827 Mtetra
.65 .747 .92 r
.86693 .42827 .87385 .43808 .89112 .43293 .8843 .42322 Mtetra
.661 .755 .92 r
.8843 .42322 .89112 .43293 .90846 .42742 .90171 .41767 Mtetra
.654 .753 .922 r
.28138 .59697 .29053 .60487 .3046 .60076 .2955 .59268 Mtetra
.661 .751 .917 r
.2955 .59268 .3046 .60076 .31877 .59618 .30971 .58812 Mtetra
.623 .743 .933 r
.30971 .58812 .31877 .59618 .33297 .59233 .32393 .5848 Mtetra
.526 .725 .965 r
.32393 .5848 .33297 .59233 .34716 .59017 .3381 .58374 Mtetra
.43 .718 .985 r
.3381 .58374 .34716 .59017 .36134 .59027 .35232 .58386 Mtetra
.547 .767 .979 r
.35232 .58386 .36134 .59027 .37568 .58941 .36675 .58188 Mtetra
.721 .783 .901 r
.36675 .58188 .37568 .58941 .39026 .58499 .38151 .5747 Mtetra
.762 .734 .827 r
.38151 .5747 .39026 .58499 .4051 .57567 .39645 .56388 Mtetra
.756 .71 .809 r
.39645 .56388 .4051 .57567 .42003 .56458 .41144 .55267 Mtetra
.704 .695 .838 r
.41144 .55267 .42003 .56458 .43494 .55491 .42633 .54532 Mtetra
.646 .721 .903 r
.42633 .54532 .43494 .55491 .44981 .54903 .44121 .54113 Mtetra
.584 .743 .952 r
.44121 .54113 .44981 .54903 .46471 .54549 .45613 .53866 Mtetra
.606 .78 .964 r
.45613 .53866 .46471 .54549 .47968 .54288 .47117 .5353 Mtetra
.639 .771 .943 r
.47117 .5353 .47968 .54288 .49476 .53924 .48631 .5311 Mtetra
.655 .763 .929 r
.48631 .5311 .49476 .53924 .50994 .53501 .50155 .5264 Mtetra
.656 .752 .921 r
.50155 .5264 .50994 .53501 .52521 .5304 .51687 .52168 Mtetra
.645 .748 .924 r
.51687 .52168 .52521 .5304 .54056 .52567 .53228 .51731 Mtetra
.646 .758 .93 r
.53228 .51731 .54056 .52567 .556 .52093 .54778 .51284 Mtetra
.65 .767 .935 r
.54778 .51284 .556 .52093 .57152 .51618 .56337 .5082 Mtetra
.654 .772 .936 r
.56337 .5082 .57152 .51618 .58713 .51139 .57904 .50336 Mtetra
.659 .774 .934 r
.57904 .50336 .58713 .51139 .60283 .50656 .5948 .49833 Mtetra
.663 .771 .93 r
.5948 .49833 .60283 .50656 .61862 .50172 .61065 .49311 Mtetra
.666 .764 .924 r
.61065 .49311 .61862 .50172 .6345 .49687 .62658 .4878 Mtetra
.656 .751 .92 r
.62658 .4878 .6345 .49687 .65047 .4919 .64261 .48284 Mtetra
.656 .753 .921 r
.64261 .48284 .65047 .4919 .66651 .48654 .65873 .47785 Mtetra
.668 .767 .924 r
.65873 .47785 .66651 .48654 .68261 .48057 .67492 .47236 Mtetra
.688 .787 .925 r
.67492 .47236 .68261 .48057 .69874 .47355 .69116 .466 Mtetra
.71 .811 .928 r
.69116 .466 .69874 .47355 .715 .46746 .70743 .45872 Mtetra
.666 .769 .927 r
.70743 .45872 .715 .46746 .73149 .46377 .72388 .45319 Mtetra
.584 .694 .917 r
.72388 .45319 .73149 .46377 .74836 .46397 .74064 .45091 Mtetra
.487 .596 .888 r
.74064 .45091 .74836 .46397 .76549 .46567 .75781 .45261 Mtetra
.498 .602 .888 r
.75781 .45261 .76549 .46567 .78265 .46558 .77513 .45396 Mtetra
.59 .678 .901 r
.77513 .45396 .78265 .46558 .79954 .46041 .79231 .45156 Mtetra
.714 .791 .912 r
.79231 .45156 .79954 .46041 .81621 .45155 .80915 .44375 Mtetra
.761 .832 .906 r
.80915 .44375 .81621 .45155 .83284 .44165 .82587 .43373 Mtetra
.736 .824 .919 r
.82587 .43373 .83284 .44165 .84975 .43408 .84275 .42491 Mtetra
.682 .776 .922 r
.84275 .42491 .84975 .43408 .86693 .42827 .85995 .41845 Mtetra
.651 .75 .922 r
.85995 .41845 .86693 .42827 .8843 .42322 .87738 .41327 Mtetra
.658 .751 .919 r
.87738 .41327 .8843 .42322 .90171 .41767 .89489 .4078 Mtetra
.658 .753 .92 r
.27214 .58896 .28138 .59697 .2955 .59268 .28632 .58448 Mtetra
.654 .749 .919 r
.28632 .58448 .2955 .59268 .30971 .58812 .30056 .58012 Mtetra
.604 .74 .941 r
.30056 .58012 .30971 .58812 .32393 .5848 .31479 .57728 Mtetra
.479 .709 .971 r
.31479 .57728 .32393 .5848 .3381 .58374 .32895 .57706 Mtetra
.457 .725 .984 r
.32895 .57706 .3381 .58374 .35232 .58386 .34323 .57682 Mtetra
.615 .773 .956 r
.34323 .57682 .35232 .58386 .36675 .58188 .35778 .57339 Mtetra
.754 .768 .864 r
.35778 .57339 .36675 .58188 .38151 .5747 .37268 .56403 Mtetra
.77 .731 .817 r
.37268 .56403 .38151 .5747 .39645 .56388 .38772 .55233 Mtetra
.744 .712 .822 r
.38772 .55233 .39645 .56388 .41144 .55267 .40272 .54231 Mtetra
.679 .716 .877 r
.40272 .54231 .41144 .55267 .42633 .54532 .41761 .53665 Mtetra
.601 .73 .935 r
.41761 .53665 .42633 .54532 .44121 .54113 .43249 .53383 Mtetra
.586 .762 .962 r
.43249 .53383 .44121 .54113 .45613 .53866 .44747 .53109 Mtetra
.632 .77 .946 r
.44747 .53109 .45613 .53866 .47117 .5353 .46258 .52707 Mtetra
.654 .761 .928 r
.46258 .52707 .47117 .5353 .48631 .5311 .47778 .5224 Mtetra
.653 .75 .921 r
.47778 .5224 .48631 .5311 .50155 .5264 .49307 .51776 Mtetra
.639 .748 .928 r
.49307 .51776 .50155 .5264 .51687 .52168 .50845 .51358 Mtetra
.641 .764 .937 r
.50845 .51358 .51687 .52168 .53228 .51731 .52392 .50924 Mtetra
.65 .769 .936 r
.52392 .50924 .53228 .51731 .54778 .51284 .53948 .50454 Mtetra
.654 .765 .931 r
.53948 .50454 .54778 .51284 .56337 .5082 .55512 .49971 Mtetra
.655 .762 .928 r
.55512 .49971 .56337 .5082 .57904 .50336 .57086 .49482 Mtetra
.656 .763 .928 r
.57086 .49482 .57904 .50336 .5948 .49833 .58668 .48987 Mtetra
.658 .767 .93 r
.58668 .48987 .5948 .49833 .61065 .49311 .60259 .48479 Mtetra
.667 .774 .93 r
.60259 .48479 .61065 .49311 .62658 .4878 .61859 .47935 Mtetra
.671 .773 .927 r
.61859 .47935 .62658 .4878 .64261 .48284 .63466 .47374 Mtetra
.659 .755 .921 r
.63466 .47374 .64261 .48284 .65873 .47785 .65085 .46859 Mtetra
.657 .752 .92 r
.65085 .46859 .65873 .47785 .67492 .47236 .66712 .46347 Mtetra
.673 .768 .921 r
.66712 .46347 .67492 .47236 .69116 .466 .68346 .45768 Mtetra
.704 .792 .92 r
.68346 .45768 .69116 .466 .70743 .45872 .69982 .45059 Mtetra
.701 .798 .925 r
.69982 .45059 .70743 .45872 .72388 .45319 .71626 .44355 Mtetra
.629 .737 .925 r
.71626 .44355 .72388 .45319 .74064 .45091 .73297 .43942 Mtetra
.508 .64 .914 r
.73297 .43942 .74064 .45091 .75781 .45261 .75009 .43979 Mtetra
.468 .593 .895 r
.75009 .43979 .75781 .45261 .77513 .45396 .76751 .44194 Mtetra
.531 .643 .905 r
.76751 .44194 .77513 .45396 .79231 .45156 .78492 .44169 Mtetra
.681 .758 .909 r
.78492 .44169 .79231 .45156 .80915 .44375 .80196 .43528 Mtetra
.752 .816 .902 r
.80196 .43528 .80915 .44375 .82587 .43373 .8188 .42554 Mtetra
.754 .825 .907 r
.8188 .42554 .82587 .43373 .84275 .42491 .83568 .41574 Mtetra
.695 .783 .919 r
.83568 .41574 .84275 .42491 .85995 .41845 .8529 .40866 Mtetra
.657 .755 .922 r
.8529 .40866 .85995 .41845 .87738 .41327 .87038 .40317 Mtetra
.654 .748 .919 r
.87038 .40317 .87738 .41327 .89489 .4078 .88798 .3978 Mtetra
.661 .754 .919 r
.26281 .58087 .27214 .58896 .28632 .58448 .27704 .57623 Mtetra
.646 .747 .923 r
.27704 .57623 .28632 .58448 .30056 .58012 .29131 .57211 Mtetra
.584 .736 .948 r
.29131 .57211 .30056 .58012 .31479 .57728 .30555 .56974 Mtetra
.447 .697 .973 r
.30555 .56974 .31479 .57728 .32895 .57706 .31972 .57002 Mtetra
.495 .732 .978 r
.31972 .57002 .32895 .57706 .34323 .57682 .33407 .56923 Mtetra
.674 .775 .926 r
.33407 .56923 .34323 .57682 .35778 .57339 .34876 .56396 Mtetra
.764 .752 .842 r
.34876 .56396 .35778 .57339 .37268 .56403 .36377 .55342 Mtetra
.773 .734 .817 r
.36377 .55342 .37268 .56403 .38772 .55233 .37888 .54141 Mtetra
.725 .72 .845 r
.37888 .54141 .38772 .55233 .40272 .54231 .39387 .53298 Mtetra
.649 .731 .909 r
.39387 .53298 .40272 .54231 .41761 .53665 .40877 .5286 Mtetra
.573 .738 .954 r
.40877 .5286 .41761 .53665 .43249 .53383 .42368 .52637 Mtetra
.614 .768 .954 r
.42368 .52637 .43249 .53383 .44747 .53109 .43874 .52285 Mtetra
.647 .76 .931 r
.43874 .52285 .44747 .53109 .46258 .52707 .4539 .51839 Mtetra
.656 .753 .921 r
.4539 .51839 .46258 .52707 .47778 .5224 .46916 .51361 Mtetra
.636 .745 .927 r
.46916 .51361 .47778 .5224 .49307 .51776 .4845 .50952 Mtetra
.639 .761 .936 r
.4845 .50952 .49307 .51776 .50845 .51358 .49994 .50523 Mtetra
.652 .763 .931 r
.49994 .50523 .50845 .51358 .52392 .50924 .51546 .50047 Mtetra
.659 .756 .922 r
.51546 .50047 .52392 .50924 .53948 .50454 .53108 .49547 Mtetra
.661 .751 .917 r
.53108 .49547 .53948 .50454 .55512 .49971 .54678 .49037 Mtetra
.656 .744 .915 r
.54678 .49037 .55512 .49971 .57086 .49482 .56258 .48543 Mtetra
.651 .743 .917 r
.56258 .48543 .57086 .49482 .58668 .48987 .57846 .48065 Mtetra
.653 .748 .92 r
.57846 .48065 .58668 .48987 .60259 .48479 .59444 .47576 Mtetra
.658 .756 .922 r
.59444 .47576 .60259 .48479 .61859 .47935 .61051 .47064 Mtetra
.669 .769 .925 r
.61051 .47064 .61859 .47935 .63466 .47374 .62665 .46504 Mtetra
.674 .772 .924 r
.62665 .46504 .63466 .47374 .65085 .46859 .64288 .45923 Mtetra
.656 .751 .92 r
.64288 .45923 .65085 .46859 .66712 .46347 .65922 .45412 Mtetra
.663 .755 .919 r
.65922 .45412 .66712 .46347 .68346 .45768 .67565 .44868 Mtetra
.686 .772 .917 r
.67565 .44868 .68346 .45768 .69982 .45059 .69212 .44227 Mtetra
.716 .8 .917 r
.69212 .44227 .69982 .45059 .71626 .44355 .7086 .43453 Mtetra
.663 .767 .927 r
.7086 .43453 .71626 .44355 .73297 .43942 .72529 .42898 Mtetra
.551 .687 .929 r
.72529 .42898 .73297 .43942 .75009 .43979 .74235 .4276 Mtetra
.449 .598 .907 r
.74235 .4276 .75009 .43979 .76751 .44194 .75983 .42995 Mtetra
.495 .628 .91 r
.75983 .42995 .76751 .44194 .78492 .44169 .77738 .43081 Mtetra
.638 .721 .908 r
.77738 .43081 .78492 .44169 .80196 .43528 .79465 .42621 Mtetra
.74 .8 .9 r
.79465 .42621 .80196 .43528 .8188 .42554 .81161 .41694 Mtetra
.763 .819 .897 r
.81161 .41694 .8188 .42554 .83568 .41574 .82854 .40652 Mtetra
.707 .789 .915 r
.82854 .40652 .83568 .41574 .8529 .40866 .84579 .39884 Mtetra
.664 .76 .922 r
.84579 .39884 .8529 .40866 .87038 .40317 .86331 .393 Mtetra
.651 .748 .92 r
.86331 .393 .87038 .40317 .88798 .3978 .881 .38767 Mtetra
.663 .754 .918 r
.25339 .57267 .26281 .58087 .27704 .57623 .26767 .56794 Mtetra
.638 .746 .927 r
.26767 .56794 .27704 .57623 .29131 .57211 .28197 .56402 Mtetra
.561 .729 .953 r
.28197 .56402 .29131 .57211 .30555 .56974 .2962 .5622 Mtetra
.439 .696 .974 r
.2962 .5622 .30555 .56974 .31972 .57002 .3104 .56255 Mtetra
.529 .736 .969 r
.3104 .56255 .31972 .57002 .33407 .56923 .32483 .56119 Mtetra
.708 .773 .903 r
.32483 .56119 .33407 .56923 .34876 .56396 .33965 .55442 Mtetra
.774 .753 .834 r
.33965 .55442 .34876 .56396 .36377 .55342 .35477 .54305 Mtetra
.774 .74 .822 r
.35477 .54305 .36377 .55342 .37888 .54141 .36994 .53116 Mtetra
.706 .729 .868 r
.36994 .53116 .37888 .54141 .39387 .53298 .38492 .52406 Mtetra
.62 .733 .928 r
.38492 .52406 .39387 .53298 .40877 .5286 .39983 .52062 Mtetra
.576 .743 .956 r
.39983 .52062 .40877 .5286 .42368 .52637 .4148 .51822 Mtetra
.63 .758 .939 r
.4148 .51822 .42368 .52637 .43874 .52285 .42991 .51428 Mtetra
.654 .756 .924 r
.42991 .51428 .43874 .52285 .4539 .51839 .44514 .50953 Mtetra
.645 .747 .924 r
.44514 .50953 .4539 .51839 .46916 .51361 .46045 .50511 Mtetra
.633 .753 .935 r
.46045 .50511 .46916 .51361 .4845 .50952 .47584 .50104 Mtetra
.65 .761 .93 r
.47584 .50104 .4845 .50952 .49994 .50523 .49133 .49634 Mtetra
.664 .756 .919 r
.49133 .49634 .49994 .50523 .51546 .50047 .50692 .49113 Mtetra
.666 .748 .911 r
.50692 .49113 .51546 .50047 .53108 .49547 .52259 .48578 Mtetra
.659 .739 .909 r
.52259 .48578 .53108 .49547 .54678 .49037 .53835 .48071 Mtetra
.656 .74 .911 r
.53835 .48071 .54678 .49037 .56258 .48543 .5542 .47572 Mtetra
.654 .739 .912 r
.5542 .47572 .56258 .48543 .57846 .48065 .57015 .4708 Mtetra
.646 .734 .913 r
.57015 .4708 .57846 .48065 .59444 .47576 .58619 .46616 Mtetra
.648 .742 .917 r
.58619 .46616 .59444 .47576 .61051 .47064 .60233 .46138 Mtetra
.66 .755 .92 r
.60233 .46138 .61051 .47064 .62665 .46504 .61855 .4561 Mtetra
.676 .769 .921 r
.61855 .4561 .62665 .46504 .64288 .45923 .63484 .45016 Mtetra
.666 .764 .923 r
.63484 .45016 .64288 .45923 .65922 .45412 .65123 .44458 Mtetra
.657 .751 .919 r
.65123 .44458 .65922 .45412 .67565 .44868 .66774 .43933 Mtetra
.677 .764 .917 r
.66774 .43933 .67565 .44868 .69212 .44227 .6843 .43324 Mtetra
.712 .784 .908 r
.6843 .43324 .69212 .44227 .7086 .43453 .70086 .42556 Mtetra
.688 .779 .921 r
.70086 .42556 .7086 .43453 .72529 .42898 .71756 .41894 Mtetra
.59 .717 .932 r
.71756 .41894 .72529 .42898 .74235 .4276 .73459 .41609 Mtetra
.443 .611 .92 r
.73459 .41609 .74235 .4276 .75983 .42995 .75211 .4182 Mtetra
.464 .619 .917 r
.75211 .4182 .75983 .42995 .77738 .43081 .76976 .41981 Mtetra
.6 .704 .917 r
.76976 .41981 .77738 .43081 .79465 .42621 .78722 .41666 Mtetra
.728 .788 .9 r
.78722 .41666 .79465 .42621 .81161 .41694 .80432 .40788 Mtetra
.763 .811 .891 r
.80432 .40788 .81161 .41694 .82854 .40652 .82132 .39727 Mtetra
.72 .795 .911 r
.82132 .39727 .82854 .40652 .84579 .39884 .83859 .38892 Mtetra
.67 .763 .92 r
.83859 .38892 .84579 .39884 .86331 .393 .85617 .38275 Mtetra
.65 .748 .921 r
.85617 .38275 .86331 .393 .881 .38767 .87394 .37742 Mtetra
.663 .753 .917 r
.24387 .56438 .25339 .57267 .26767 .56794 .2582 .55958 Mtetra
.633 .745 .929 r
.2582 .55958 .26767 .56794 .28197 .56402 .27253 .55581 Mtetra
.544 .722 .956 r
.27253 .55581 .28197 .56402 .2962 .5622 .28678 .55434 Mtetra
.445 .692 .971 r
.28678 .55434 .2962 .5622 .3104 .56255 .30101 .55467 Mtetra
.554 .736 .96 r
.30101 .55467 .3104 .56255 .32483 .56119 .3155 .55283 Mtetra
.727 .771 .888 r
.3155 .55283 .32483 .56119 .33965 .55442 .33044 .54504 Mtetra
.78 .758 .833 r
.33044 .54504 .33965 .55442 .35477 .54305 .34565 .53316 Mtetra
.773 .749 .832 r
.34565 .53316 .35477 .54305 .36994 .53116 .36086 .52167 Mtetra
.694 .743 .889 r
.36086 .52167 .36994 .53116 .38492 .52406 .37587 .51528 Mtetra
.599 .732 .938 r
.37587 .51528 .38492 .52406 .39983 .52062 .3908 .51239 Mtetra
.588 .743 .95 r
.3908 .51239 .39983 .52062 .4148 .51822 .40582 .50967 Mtetra
.638 .752 .931 r
.40582 .50967 .4148 .51822 .42991 .51428 .421 .50546 Mtetra
.656 .753 .921 r
.421 .50546 .42991 .51428 .44514 .50953 .43629 .5006 Mtetra
.636 .745 .927 r
.43629 .5006 .44514 .50953 .46045 .50511 .45164 .49645 Mtetra
.639 .754 .932 r
.45164 .49645 .46045 .50511 .47584 .50104 .46709 .49215 Mtetra
.658 .755 .922 r
.46709 .49215 .47584 .50104 .49133 .49634 .48265 .48714 Mtetra
.671 .753 .912 r
.48265 .48714 .49133 .49634 .50692 .49113 .49829 .48158 Mtetra
.652 .741 .914 r
.49829 .48158 .50692 .49113 .52259 .48578 .51402 .47674 Mtetra
.642 .75 .927 r
.51402 .47674 .52259 .48578 .53835 .48071 .52984 .47222 Mtetra
.655 .769 .933 r
.52984 .47222 .53835 .48071 .5542 .47572 .54576 .46717 Mtetra
.668 .773 .928 r
.54576 .46717 .5542 .47572 .57015 .4708 .56176 .4616 Mtetra
.66 .756 .921 r
.56176 .4616 .57015 .4708 .58619 .46616 .57785 .45635 Mtetra
.641 .737 .918 r
.57785 .45635 .58619 .46616 .60233 .46138 .59405 .45181 Mtetra
.654 .748 .919 r
.59405 .45181 .60233 .46138 .61855 .4561 .61034 .44672 Mtetra
.671 .76 .917 r
.61034 .44672 .61855 .4561 .63484 .45016 .62671 .44092 Mtetra
.674 .765 .919 r
.62671 .44092 .63484 .45016 .65123 .44458 .64316 .43495 Mtetra
.656 .751 .92 r
.64316 .43495 .65123 .44458 .66774 .43933 .65973 .42971 Mtetra
.671 .758 .916 r
.65973 .42971 .66774 .43933 .6843 .43324 .67637 .42378 Mtetra
.705 .774 .906 r
.67637 .42378 .6843 .43324 .70086 .42556 .69302 .41633 Mtetra
.701 .78 .912 r
.69302 .41633 .70086 .42556 .71756 .41894 .70976 .40905 Mtetra
.612 .732 .931 r
.70976 .40905 .71756 .41894 .73459 .41609 .72681 .40534 Mtetra
.445 .632 .934 r
.72681 .40534 .73459 .41609 .75211 .4182 .74434 .40693 Mtetra
.439 .618 .927 r
.74434 .40693 .75211 .4182 .76976 .41981 .76208 .40895 Mtetra
.571 .696 .926 r
.76208 .40895 .76976 .41981 .78722 .41666 .77968 .40675 Mtetra
.719 .779 .9 r
.77968 .40675 .78722 .41666 .80432 .40788 .7969 .39836 Mtetra
.762 .803 .886 r
.7969 .39836 .80432 .40788 .82132 .39727 .81399 .38767 Mtetra
.727 .792 .904 r
.81399 .38767 .82132 .39727 .83859 .38892 .83131 .37884 Mtetra
.675 .764 .917 r
.83131 .37884 .83859 .38892 .85617 .38275 .84894 .3724 Mtetra
.649 .748 .922 r
.84894 .3724 .85617 .38275 .87394 .37742 .86679 .36704 Mtetra
.663 .753 .917 r
.23426 .556 .24387 .56438 .2582 .55958 .24864 .55115 Mtetra
.629 .744 .93 r
.24864 .55115 .2582 .55958 .27253 .55581 .263 .54743 Mtetra
.537 .717 .956 r
.263 .54743 .27253 .55581 .28678 .55434 .27727 .54612 Mtetra
.453 .688 .966 r
.27727 .54612 .28678 .55434 .30101 .55467 .29154 .54639 Mtetra
.568 .733 .953 r
.29154 .54639 .30101 .55467 .3155 .55283 .30609 .54427 Mtetra
.736 .77 .88 r
.30609 .54427 .3155 .55283 .33044 .54504 .32112 .53594 Mtetra
.785 .765 .835 r
.32112 .53594 .33044 .54504 .34565 .53316 .33641 .52381 Mtetra
.773 .761 .842 r
.33641 .52381 .34565 .53316 .36086 .52167 .35167 .51258 Mtetra
.688 .752 .9 r
.35167 .51258 .36086 .52167 .37587 .51528 .36672 .50648 Mtetra
.59 .73 .941 r
.36672 .50648 .37587 .51528 .3908 .51239 .38168 .5038 Mtetra
.596 .739 .944 r
.38168 .5038 .3908 .51239 .40582 .50967 .39676 .50086 Mtetra
.642 .75 .927 r
.39676 .50086 .40582 .50967 .421 .50546 .412 .4965 Mtetra
.656 .751 .92 r
.412 .4965 .421 .50546 .43629 .5006 .42734 .49159 Mtetra
.631 .744 .929 r
.42734 .49159 .43629 .5006 .45164 .49645 .44274 .48754 Mtetra
.643 .751 .928 r
.44274 .48754 .45164 .49645 .46709 .49215 .45825 .48305 Mtetra
.664 .754 .918 r
.45825 .48305 .46709 .49215 .48265 .48714 .47387 .47777 Mtetra
.669 .751 .912 r
.47387 .47777 .48265 .48714 .49829 .48158 .48957 .47224 Mtetra
.636 .742 .925 r
.48957 .47224 .49829 .48158 .51402 .47674 .50535 .46795 Mtetra
.628 .754 .938 r
.50535 .46795 .51402 .47674 .52984 .47222 .52123 .46383 Mtetra
.654 .773 .936 r
.52123 .46383 .52984 .47222 .54576 .46717 .53721 .45873 Mtetra
.679 .781 .927 r
.53721 .45873 .54576 .46717 .56176 .4616 .55328 .45265 Mtetra
.675 .769 .921 r
.55328 .45265 .56176 .4616 .57785 .45635 .56943 .44674 Mtetra
.643 .744 .923 r
.56943 .44674 .57785 .45635 .59405 .45181 .58569 .44206 Mtetra
.648 .744 .919 r
.58569 .44206 .59405 .45181 .61034 .44672 .60205 .43714 Mtetra
.668 .756 .917 r
.60205 .43714 .61034 .44672 .62671 .44092 .61848 .43141 Mtetra
.678 .763 .915 r
.61848 .43141 .62671 .44092 .64316 .43495 .635 .42523 Mtetra
.656 .751 .92 r
.635 .42523 .64316 .43495 .65973 .42971 .65163 .41993 Mtetra
.669 .756 .916 r
.65163 .41993 .65973 .42971 .67637 .42378 .66835 .41406 Mtetra
.701 .769 .905 r
.66835 .41406 .67637 .42378 .69302 .41633 .68508 .40672 Mtetra
.707 .775 .905 r
.68508 .40672 .69302 .41633 .70976 .40905 .70188 .3991 Mtetra
.621 .737 .93 r
.70188 .3991 .70976 .40905 .72681 .40534 .71898 .395 Mtetra
.449 .647 .943 r
.71898 .395 .72681 .40534 .74434 .40693 .73654 .3962 Mtetra
.419 .622 .936 r
.73654 .3962 .74434 .40693 .76208 .40895 .75435 .39836 Mtetra
.553 .696 .935 r
.75435 .39836 .76208 .40895 .77968 .40675 .77205 .39662 Mtetra
.713 .775 .901 r
.77205 .39662 .77968 .40675 .7969 .39836 .78937 .38841 Mtetra
.76 .795 .882 r
.78937 .38841 .7969 .39836 .81399 .38767 .80655 .37767 Mtetra
.73 .787 .897 r
.80655 .37767 .81399 .38767 .83131 .37884 .82393 .36856 Mtetra
.677 .763 .915 r
.82393 .36856 .83131 .37884 .84894 .3724 .84164 .36195 Mtetra
.649 .748 .922 r
.84164 .36195 .84894 .3724 .86679 .36704 .85957 .35653 Mtetra
.663 .753 .917 r
.22455 .54752 .23426 .556 .24864 .55115 .23897 .54263 Mtetra
.629 .744 .93 r
.23897 .54263 .24864 .55115 .263 .54743 .25338 .53886 Mtetra
.538 .715 .954 r
.25338 .53886 .263 .54743 .27727 .54612 .26769 .53751 Mtetra
.46 .683 .962 r
.26769 .53751 .27727 .54612 .29154 .54639 .282 .53775 Mtetra
.57 .726 .948 r
.282 .53775 .29154 .54639 .30609 .54427 .29658 .53559 Mtetra
.736 .769 .88 r
.29658 .53559 .30609 .54427 .32112 .53594 .31167 .5272 Mtetra
.789 .774 .84 r
.31167 .5272 .32112 .53594 .33641 .52381 .32704 .515 Mtetra
.778 .773 .849 r
.32704 .515 .33641 .52381 .35167 .51258 .34237 .50371 Mtetra
.689 .759 .905 r
.34237 .50371 .35167 .51258 .36672 .50648 .35747 .49755 Mtetra
.59 .73 .941 r
.35747 .49755 .36672 .50648 .38168 .5038 .37248 .49483 Mtetra
.598 .733 .938 r
.37248 .49483 .38168 .5038 .39676 .50086 .38761 .49184 Mtetra
.642 .747 .925 r
.38761 .49184 .39676 .50086 .412 .4965 .4029 .48743 Mtetra
.656 .751 .92 r
.4029 .48743 .412 .4965 .42734 .49159 .41829 .48246 Mtetra
.631 .743 .929 r
.41829 .48246 .42734 .49159 .44274 .48754 .43375 .47837 Mtetra
.643 .747 .925 r
.43375 .47837 .44274 .48754 .45825 .48305 .44932 .47383 Mtetra
.664 .754 .917 r
.44932 .47383 .45825 .48305 .47387 .47777 .46499 .46849 Mtetra
.669 .755 .915 r
.46499 .46849 .47387 .47777 .48957 .47224 .48075 .46291 Mtetra
.635 .744 .927 r
.48075 .46291 .48957 .47224 .50535 .46795 .49659 .45857 Mtetra
.63 .743 .929 r
.49659 .45857 .50535 .46795 .52123 .46383 .51253 .45439 Mtetra
.656 .751 .92 r
.51253 .45439 .52123 .46383 .53721 .45873 .52857 .44924 Mtetra
.679 .759 .911 r
.52857 .44924 .53721 .45873 .55328 .45265 .5447 .4431 Mtetra
.675 .757 .913 r
.5447 .4431 .55328 .45265 .56943 .44674 .56091 .43713 Mtetra
.642 .746 .925 r
.56091 .43713 .56943 .44674 .58569 .44206 .57724 .4324 Mtetra
.648 .749 .923 r
.57724 .4324 .58569 .44206 .60205 .43714 .59366 .42742 Mtetra
.668 .755 .916 r
.59366 .42742 .60205 .43714 .61848 .43141 .61016 .42164 Mtetra
.678 .759 .912 r
.61016 .42164 .61848 .43141 .635 .42523 .62674 .4154 Mtetra
.656 .751 .92 r
.62674 .4154 .635 .42523 .65163 .41993 .64345 .41003 Mtetra
.669 .756 .916 r
.64345 .41003 .65163 .41993 .66835 .41406 .66023 .4041 Mtetra
.701 .767 .903 r
.66023 .4041 .66835 .41406 .68508 .40672 .67704 .3967 Mtetra
.706 .768 .901 r
.67704 .3967 .68508 .40672 .70188 .3991 .69392 .38902 Mtetra
.621 .737 .929 r
.69392 .38902 .70188 .3991 .71898 .395 .71108 .38486 Mtetra
.443 .651 .948 r
.71108 .38486 .71898 .395 .73654 .3962 .7287 .38601 Mtetra
.405 .63 .946 r
.7287 .38601 .73654 .3962 .75435 .39836 .74656 .38813 Mtetra
.548 .705 .943 r
.74656 .38813 .75435 .39836 .77205 .39662 .76433 .38633 Mtetra
.713 .774 .9 r
.76433 .38633 .77205 .39662 .78937 .38841 .78173 .37805 Mtetra
.758 .789 .878 r
.78173 .37805 .78937 .38841 .80655 .37767 .799 .36724 Mtetra
.729 .779 .893 r
.799 .36724 .80655 .37767 .82393 .36856 .81646 .35805 Mtetra
.677 .76 .914 r
.81646 .35805 .82393 .36856 .84164 .36195 .83425 .35138 Mtetra
.649 .748 .922 r
.83425 .35138 .84164 .36195 .85957 .35653 .85226 .34589 Mtetra
.663 .753 .917 r
.21474 .53896 .22455 .54752 .23897 .54263 .22921 .53402 Mtetra
.632 .745 .929 r
.22921 .53402 .23897 .54263 .25338 .53886 .24367 .53011 Mtetra
.548 .716 .95 r
.24367 .53011 .25338 .53886 .26769 .53751 .25804 .52852 Mtetra
.465 .677 .957 r
.25804 .52852 .26769 .53751 .282 .53775 .27237 .52875 Mtetra
.564 .717 .945 r
.27237 .52875 .282 .53775 .29658 .53559 .28698 .52678 Mtetra
.727 .767 .885 r
.28698 .52678 .29658 .53559 .31167 .5272 .3021 .51882 Mtetra
.79 .783 .846 r
.3021 .51882 .31167 .5272 .32704 .515 .31753 .50674 Mtetra
.786 .787 .853 r
.31753 .50674 .32704 .515 .34237 .50371 .33296 .49504 Mtetra
.697 .768 .906 r
.33296 .49504 .34237 .50371 .35747 .49755 .34813 .4885 Mtetra
.599 .732 .938 r
.34813 .4885 .35747 .49755 .37248 .49483 .3632 .48546 Mtetra
.594 .724 .935 r
.3632 .48546 .37248 .49483 .38761 .49184 .37837 .4826 Mtetra
.639 .743 .924 r
.37837 .4826 .38761 .49184 .4029 .48743 .3937 .47825 Mtetra
.656 .751 .92 r
.3937 .47825 .4029 .48743 .41829 .48246 .40915 .47323 Mtetra
.636 .745 .927 r
.40915 .47323 .41829 .48246 .43375 .47837 .42467 .46893 Mtetra
.64 .742 .923 r
.42467 .46893 .43375 .47837 .44932 .47383 .44029 .46447 Mtetra
.658 .751 .919 r
.44029 .46447 .44932 .47383 .46499 .46849 .45601 .4593 Mtetra
.671 .76 .917 r
.45601 .4593 .46499 .46849 .48075 .46291 .47184 .45358 Mtetra
.652 .752 .923 r
.47184 .45358 .48075 .46291 .49659 .45857 .48774 .44858 Mtetra
.643 .736 .916 r
.48774 .44858 .49659 .45857 .51253 .45439 .50374 .4439 Mtetra
.656 .731 .904 r
.50374 .4439 .51253 .45439 .52857 .44924 .51984 .43869 Mtetra
.668 .735 .9 r
.51984 .43869 .52857 .44924 .5447 .4431 .53603 .43294 Mtetra
.66 .741 .91 r
.53603 .43294 .5447 .4431 .56091 .43713 .55231 .42752 Mtetra
.64 .748 .927 r
.55231 .42752 .56091 .43713 .57724 .4324 .5687 .42282 Mtetra
.654 .755 .924 r
.5687 .42282 .57724 .4324 .59366 .42742 .58518 .41756 Mtetra
.671 .756 .914 r
.58518 .41756 .59366 .42742 .61016 .42164 .60175 .41158 Mtetra
.674 .754 .911 r
.60175 .41158 .61016 .42164 .62674 .4154 .6184 .40543 Mtetra
.656 .751 .92 r
.6184 .40543 .62674 .4154 .64345 .41003 .63517 .40002 Mtetra
.671 .757 .914 r
.63517 .40002 .64345 .41003 .66023 .4041 .65202 .39391 Mtetra
.704 .765 .899 r
.65202 .39391 .66023 .4041 .67704 .3967 .66889 .38626 Mtetra
.7 .76 .898 r
.66889 .38626 .67704 .3967 .69392 .38902 .68586 .37878 Mtetra
.612 .732 .931 r
.68586 .37878 .69392 .38902 .71108 .38486 .70311 .37491 Mtetra
.423 .648 .952 r
.70311 .37491 .71108 .38486 .7287 .38601 .72081 .37636 Mtetra
.397 .643 .955 r
.72081 .37636 .7287 .38601 .74656 .38813 .73872 .37825 Mtetra
.56 .722 .949 r
.73872 .37825 .74656 .38813 .76433 .38633 .75652 .37589 Mtetra
.718 .775 .897 r
.75652 .37589 .76433 .38633 .78173 .37805 .77399 .36729 Mtetra
.757 .782 .874 r
.77399 .36729 .78173 .37805 .799 .36724 .79133 .35637 Mtetra
.724 .771 .89 r
.79133 .35637 .799 .36724 .81646 .35805 .8089 .34732 Mtetra
.675 .757 .913 r
.8089 .34732 .81646 .35805 .83425 .35138 .82678 .34069 Mtetra
.649 .749 .922 r
.82678 .34069 .83425 .35138 .85226 .34589 .84487 .33512 Mtetra
.663 .753 .917 r
.20483 .5303 .21474 .53896 .22921 .53402 .21935 .52533 Mtetra
.638 .747 .927 r
.21935 .52533 .22921 .53402 .24367 .53011 .23387 .52118 Mtetra
.565 .72 .946 r
.23387 .52118 .24367 .53011 .25804 .52852 .2483 .51915 Mtetra
.471 .673 .952 r
.2483 .51915 .25804 .52852 .27237 .52875 .26267 .51933 Mtetra
.549 .704 .942 r
.26267 .51933 .27237 .52875 .28698 .52678 .27728 .51776 Mtetra
.707 .761 .894 r
.27728 .51776 .28698 .52678 .3021 .51882 .29239 .51073 Mtetra
.787 .791 .855 r
.29239 .51073 .3021 .51882 .31753 .50674 .30787 .49902 Mtetra
.796 .8 .855 r
.30787 .49902 .31753 .50674 .33296 .49504 .32341 .48679 Mtetra
.716 .783 .905 r
.32341 .48679 .33296 .49504 .34813 .4885 .33869 .47941 Mtetra
.618 .74 .933 r
.33869 .47941 .34813 .4885 .3632 .48546 .35384 .47573 Mtetra
.586 .715 .932 r
.35384 .47573 .3632 .48546 .37837 .4826 .36904 .47311 Mtetra
.633 .738 .923 r
.36904 .47311 .37837 .4826 .3937 .47825 .38442 .46892 Mtetra
.655 .749 .919 r
.38442 .46892 .3937 .47825 .40915 .47323 .39992 .46391 Mtetra
.645 .748 .924 r
.39992 .46391 .40915 .47323 .42467 .46893 .4155 .45923 Mtetra
.635 .737 .922 r
.4155 .45923 .42467 .46893 .44029 .46447 .43116 .45491 Mtetra
.651 .747 .92 r
.43116 .45491 .44029 .46447 .45601 .4593 .44694 .44994 Mtetra
.664 .756 .919 r
.44694 .44994 .45601 .4593 .47184 .45358 .46282 .44446 Mtetra
.666 .764 .923 r
.46282 .44446 .47184 .45358 .48774 .44858 .4788 .43884 Mtetra
.659 .749 .917 r
.4788 .43884 .48774 .44858 .50374 .4439 .49486 .4335 Mtetra
.656 .735 .907 r
.49486 .4335 .50374 .4439 .51984 .43869 .51101 .42823 Mtetra
.653 .734 .908 r
.51101 .42823 .51984 .43869 .53603 .43294 .52726 .42303 Mtetra
.645 .744 .921 r
.52726 .42303 .53603 .43294 .55231 .42752 .54361 .41812 Mtetra
.647 .758 .93 r
.54361 .41812 .55231 .42752 .5687 .42282 .56006 .41306 Mtetra
.66 .755 .921 r
.56006 .41306 .5687 .42282 .58518 .41756 .57661 .40749 Mtetra
.675 .755 .911 r
.57661 .40749 .58518 .41756 .60175 .41158 .59323 .40125 Mtetra
.666 .747 .911 r
.59323 .40125 .60175 .41158 .6184 .40543 .60996 .39538 Mtetra
.657 .752 .92 r
.60996 .39538 .6184 .40543 .63517 .40002 .6268 .38983 Mtetra
.677 .757 .912 r
.6268 .38983 .63517 .40002 .65202 .39391 .64371 .38344 Mtetra
.709 .763 .894 r
.64371 .38344 .65202 .39391 .66889 .38626 .66064 .37543 Mtetra
.686 .749 .899 r
.66064 .37543 .66889 .38626 .68586 .37878 .67771 .3685 Mtetra
.588 .723 .937 r
.67771 .3685 .68586 .37878 .70311 .37491 .69507 .36537 Mtetra
.39 .643 .957 r
.69507 .36537 .70311 .37491 .72081 .37636 .71286 .36726 Mtetra
.4 .662 .965 r
.71286 .36726 .72081 .37636 .73872 .37825 .73081 .36865 Mtetra
.589 .745 .951 r
.73081 .36865 .73872 .37825 .75652 .37589 .74862 .36521 Mtetra
.726 .775 .892 r
.74862 .36521 .75652 .37589 .77399 .36729 .76613 .35608 Mtetra
.755 .775 .87 r
.76613 .35608 .77399 .36729 .79133 .35637 .78356 .34509 Mtetra
.715 .762 .889 r
.78356 .34509 .79133 .35637 .8089 .34732 .80124 .33638 Mtetra
.67 .753 .913 r
.80124 .33638 .8089 .34732 .82678 .34069 .81922 .32988 Mtetra
.65 .749 .922 r
.81922 .32988 .82678 .34069 .84487 .33512 .83739 .32423 Mtetra
.661 .752 .918 r
.19482 .52153 .20483 .5303 .21935 .52533 .20938 .51657 Mtetra
.646 .75 .925 r
.20938 .51657 .21935 .52533 .23387 .52118 .22397 .51212 Mtetra
.588 .726 .939 r
.22397 .51212 .23387 .52118 .2483 .51915 .23849 .50945 Mtetra
.48 .671 .948 r
.23849 .50945 .2483 .51915 .26267 .51933 .25289 .50948 Mtetra
.53 .689 .94 r
.25289 .50948 .26267 .51933 .27728 .51776 .2675 .50842 Mtetra
.674 .749 .907 r
.2675 .50842 .27728 .51776 .29239 .51073 .28256 .5028 Mtetra
.778 .796 .867 r
.28256 .5028 .29239 .51073 .30787 .49902 .29807 .4918 Mtetra
.803 .812 .859 r
.29807 .4918 .30787 .49902 .32341 .48679 .3137 .47931 Mtetra
.746 .807 .9 r
.3137 .47931 .32341 .48679 .33869 .47941 .32913 .47046 Mtetra
.648 .754 .927 r
.32913 .47046 .33869 .47941 .35384 .47573 .34439 .46574 Mtetra
.583 .71 .93 r
.34439 .46574 .35384 .47573 .36904 .47311 .35963 .46319 Mtetra
.623 .727 .921 r
.35963 .46319 .36904 .47311 .38442 .46892 .37503 .45933 Mtetra
.648 .744 .919 r
.37503 .45933 .38442 .46892 .39992 .46391 .39058 .45452 Mtetra
.656 .752 .92 r
.39058 .45452 .39992 .46391 .4155 .45923 .40623 .44937 Mtetra
.637 .736 .92 r
.40623 .44937 .4155 .45923 .43116 .45491 .42195 .44492 Mtetra
.642 .736 .917 r
.42195 .44492 .43116 .45491 .44694 .44994 .43778 .44027 Mtetra
.653 .748 .919 r
.43778 .44027 .44694 .44994 .46282 .44446 .45371 .43513 Mtetra
.659 .759 .924 r
.45371 .43513 .46282 .44446 .4788 .43884 .46974 .42975 Mtetra
.66 .766 .928 r
.46974 .42975 .4788 .43884 .49486 .4335 .48587 .42427 Mtetra
.655 .763 .929 r
.48587 .42427 .49486 .4335 .51101 .42823 .50209 .41894 Mtetra
.65 .761 .93 r
.50209 .41894 .51101 .42823 .52726 .42303 .5184 .41377 Mtetra
.652 .764 .931 r
.5184 .41377 .52726 .42303 .54361 .41812 .53482 .4085 Mtetra
.658 .759 .924 r
.53482 .4085 .54361 .41812 .56006 .41306 .55133 .40298 Mtetra
.67 .754 .914 r
.55133 .40298 .56006 .41306 .57661 .40749 .56793 .39697 Mtetra
.673 .747 .906 r
.56793 .39697 .57661 .40749 .59323 .40125 .58463 .39074 Mtetra
.656 .742 .913 r
.58463 .39074 .59323 .40125 .60996 .39538 .60143 .38523 Mtetra
.664 .754 .918 r
.60143 .38523 .60996 .39538 .6268 .38983 .61833 .37937 Mtetra
.685 .756 .906 r
.61833 .37937 .6268 .38983 .64371 .38344 .6353 .37252 Mtetra
.711 .757 .888 r
.6353 .37252 .64371 .38344 .66064 .37543 .6523 .36432 Mtetra
.664 .738 .905 r
.6523 .36432 .66064 .37543 .67771 .3685 .66948 .35834 Mtetra
.54 .707 .948 r
.66948 .35834 .67771 .3685 .69507 .36537 .68698 .35661 Mtetra
.355 .647 .965 r
.68698 .35661 .69507 .36537 .71286 .36726 .70485 .35866 Mtetra
.422 .69 .975 r
.70485 .35866 .71286 .36726 .73081 .36865 .72283 .35919 Mtetra
.633 .769 .945 r
.72283 .35919 .73081 .36865 .74862 .36521 .7406 .35417 Mtetra
.735 .773 .883 r
.7406 .35417 .74862 .36521 .76613 .35608 .75815 .34439 Mtetra
.751 .767 .866 r
.75815 .34439 .76613 .35608 .78356 .34509 .77568 .33343 Mtetra
.703 .752 .891 r
.77568 .33343 .78356 .34509 .80124 .33638 .7935 .32527 Mtetra
.664 .75 .914 r
.7935 .32527 .80124 .33638 .81922 .32988 .81157 .31897 Mtetra
.651 .75 .922 r
.81157 .31897 .81922 .32988 .83739 .32423 .82982 .31319 Mtetra
.658 .751 .919 r
.18471 .51266 .19482 .52153 .20938 .51657 .1993 .50775 Mtetra
.654 .752 .922 r
.1993 .50775 .20938 .51657 .22397 .51212 .21397 .50296 Mtetra
.606 .732 .934 r
.21397 .50296 .22397 .51212 .23849 .50945 .22858 .49974 Mtetra
.504 .683 .947 r
.22858 .49974 .23849 .50945 .25289 .50948 .24305 .49919 Mtetra
.512 .673 .937 r
.24305 .49919 .25289 .50948 .2675 .50842 .25765 .49861 Mtetra
.625 .727 .92 r
.25765 .49861 .2675 .50842 .28256 .5028 .27262 .49476 Mtetra
.762 .795 .88 r
.27262 .49476 .28256 .5028 .29807 .4918 .28812 .48485 Mtetra
.802 .819 .865 r
.28812 .48485 .29807 .4918 .3137 .47931 .30383 .47253 Mtetra
.779 .826 .889 r
.30383 .47253 .3137 .47931 .32913 .47046 .31944 .46193 Mtetra
.684 .776 .921 r
.31944 .46193 .32913 .47046 .34439 .46574 .33483 .4558 Mtetra
.603 .721 .928 r
.33483 .4558 .34439 .46574 .35963 .46319 .35015 .45256 Mtetra
.602 .707 .917 r
.35015 .45256 .35963 .46319 .37503 .45933 .36557 .44939 Mtetra
.638 .735 .919 r
.36557 .44939 .37503 .45933 .39058 .45452 .38115 .44493 Mtetra
.654 .749 .919 r
.38115 .44493 .39058 .45452 .40623 .44937 .39685 .43979 Mtetra
.653 .75 .921 r
.39685 .43979 .40623 .44937 .42195 .44492 .41265 .43467 Mtetra
.64 .733 .916 r
.41265 .43467 .42195 .44492 .43778 .44027 .42853 .43003 Mtetra
.644 .735 .915 r
.42853 .43003 .43778 .44027 .45371 .43513 .44451 .42521 Mtetra
.652 .746 .918 r
.44451 .42521 .45371 .43513 .46974 .42975 .46059 .42003 Mtetra
.655 .753 .922 r
.46059 .42003 .46974 .42975 .48587 .42427 .47678 .41471 Mtetra
.656 .758 .925 r
.47678 .41471 .48587 .42427 .50209 .41894 .49306 .40932 Mtetra
.657 .758 .925 r
.49306 .40932 .50209 .41894 .5184 .41377 .50944 .40387 Mtetra
.659 .754 .92 r
.50944 .40387 .5184 .41377 .53482 .4085 .52592 .39829 Mtetra
.668 .751 .913 r
.52592 .39829 .53482 .4085 .55133 .40298 .54249 .39232 Mtetra
.671 .744 .906 r
.54249 .39232 .55133 .40298 .56793 .39697 .55916 .38618 Mtetra
.659 .739 .909 r
.55916 .38618 .56793 .39697 .58463 .39074 .57593 .38052 Mtetra
.657 .752 .919 r
.57593 .38052 .58463 .39074 .60143 .38523 .5928 .37487 Mtetra
.673 .756 .913 r
.5928 .37487 .60143 .38523 .61833 .37937 .60976 .36854 Mtetra
.7 .756 .895 r
.60976 .36854 .61833 .37937 .6353 .37252 .62677 .36086 Mtetra
.696 .74 .885 r
.62677 .36086 .6353 .37252 .6523 .36432 .64387 .35325 Mtetra
.63 .728 .918 r
.64387 .35325 .6523 .36432 .66948 .35834 .66118 .3486 Mtetra
.468 .685 .961 r
.66118 .3486 .66948 .35834 .68698 .35661 .67884 .34855 Mtetra
.342 .662 .973 r
.67884 .34855 .68698 .35661 .70485 .35866 .69676 .3503 Mtetra
.466 .722 .981 r
.69676 .3503 .70485 .35866 .72283 .35919 .71474 .3496 Mtetra
.682 .788 .93 r
.71474 .3496 .72283 .35919 .7406 .35417 .73247 .34261 Mtetra
.743 .768 .873 r
.73247 .34261 .7406 .35417 .75815 .34439 .75007 .3322 Mtetra
.74 .757 .866 r
.75007 .3322 .75815 .34439 .77568 .33343 .76772 .32174 Mtetra
.692 .75 .896 r
.76772 .32174 .77568 .33343 .7935 .32527 .78566 .31404 Mtetra
.657 .747 .916 r
.78566 .31404 .7935 .32527 .81157 .31897 .80385 .30797 Mtetra
.654 .752 .922 r
.80385 .30797 .81157 .31897 .82982 .31319 .82216 .30201 Mtetra
.654 .75 .92 r
.17449 .50368 .18471 .51266 .1993 .50775 .18912 .49888 Mtetra
.661 .755 .92 r
.18912 .49888 .1993 .50775 .21397 .50296 .20386 .4938 Mtetra
.623 .739 .93 r
.20386 .4938 .21397 .50296 .22858 .49974 .21856 .48998 Mtetra
.542 .699 .942 r
.21856 .48998 .22858 .49974 .24305 .49919 .23314 .48848 Mtetra
.501 .662 .933 r
.23314 .48848 .24305 .49919 .25765 .49861 .24774 .4882 Mtetra
.58 .701 .925 r
.24774 .4882 .25765 .49861 .27262 .49476 .26264 .48576 Mtetra
.719 .771 .893 r
.26264 .48576 .27262 .49476 .28812 .48485 .27805 .47795 Mtetra
.792 .823 .877 r
.27805 .47795 .28812 .48485 .30383 .47253 .29378 .46641 Mtetra
.802 .842 .881 r
.29378 .46641 .30383 .47253 .31944 .46193 .30956 .45446 Mtetra
.727 .81 .916 r
.30956 .45446 .31944 .46193 .33483 .4558 .32513 .44648 Mtetra
.644 .751 .926 r
.32513 .44648 .33483 .4558 .35015 .45256 .34058 .44174 Mtetra
.595 .702 .918 r
.34058 .44174 .35015 .45256 .36557 .44939 .35603 .43876 Mtetra
.621 .717 .914 r
.35603 .43876 .36557 .44939 .38115 .44493 .37163 .43486 Mtetra
.643 .737 .917 r
.37163 .43486 .38115 .44493 .39685 .43979 .38737 .4301 Mtetra
.656 .751 .92 r
.38737 .4301 .39685 .43979 .41265 .43467 .40323 .42482 Mtetra
.656 .749 .918 r
.40323 .42482 .41265 .43467 .42853 .43003 .41918 .41951 Mtetra
.646 .732 .912 r
.41918 .41951 .42853 .43003 .44451 .42521 .43522 .41456 Mtetra
.648 .731 .91 r
.43522 .41456 .44451 .42521 .46059 .42003 .45136 .40951 Mtetra
.652 .737 .912 r
.45136 .40951 .46059 .42003 .47678 .41471 .4676 .40426 Mtetra
.656 .741 .912 r
.4676 .40426 .47678 .41471 .49306 .40932 .48394 .39882 Mtetra
.66 .742 .911 r
.48394 .39882 .49306 .40932 .50944 .40387 .50039 .39317 Mtetra
.664 .741 .907 r
.50039 .39317 .50944 .40387 .52592 .39829 .51693 .38733 Mtetra
.665 .737 .904 r
.51693 .38733 .52592 .39829 .54249 .39232 .53356 .38138 Mtetra
.656 .736 .908 r
.53356 .38138 .54249 .39232 .55916 .38618 .5503 .37579 Mtetra
.656 .749 .918 r
.5503 .37579 .55916 .38618 .57593 .38052 .56714 .37017 Mtetra
.668 .755 .916 r
.56714 .37017 .57593 .38052 .5928 .37487 .58407 .36402 Mtetra
.687 .752 .901 r
.58407 .36402 .5928 .37487 .60976 .36854 .60108 .35698 Mtetra
.703 .745 .884 r
.60108 .35698 .60976 .36854 .62677 .36086 .61816 .34899 Mtetra
.665 .727 .895 r
.61816 .34899 .62677 .36086 .64387 .35325 .63538 .3428 Mtetra
.575 .721 .942 r
.63538 .3428 .64387 .35325 .66118 .3486 .65283 .33993 Mtetra
.383 .67 .972 r
.65283 .33993 .66118 .3486 .67884 .34855 .67062 .34115 Mtetra
.362 .694 .982 r
.67062 .34115 .67884 .34855 .69676 .3503 .68858 .34199 Mtetra
.553 .769 .978 r
.68858 .34199 .69676 .3503 .71474 .3496 .7065 .33898 Mtetra
.713 .778 .903 r
.7065 .33898 .71474 .3496 .73247 .34261 .72422 .33041 Mtetra
.746 .76 .864 r
.72422 .33041 .73247 .34261 .75007 .3322 .74187 .31957 Mtetra
.723 .745 .869 r
.74187 .31957 .75007 .3322 .76772 .32174 .75967 .30996 Mtetra
.681 .747 .901 r
.75967 .30996 .76772 .32174 .78566 .31404 .77774 .30276 Mtetra
.651 .746 .919 r
.77774 .30276 .78566 .31404 .80385 .30797 .79603 .29687 Mtetra
.657 .754 .921 r
.79603 .29687 .80385 .30797 .82216 .30201 .81441 .29068 Mtetra
.65 .748 .921 r
.16417 .49459 .17449 .50368 .18912 .49888 .17883 .48988 Mtetra
.663 .754 .918 r
.17883 .48988 .18912 .49888 .20386 .4938 .19362 .48467 Mtetra
.641 .747 .926 r
.19362 .48467 .20386 .4938 .21856 .48998 .20842 .48021 Mtetra
.586 .717 .934 r
.20842 .48021 .21856 .48998 .23314 .48848 .22315 .4775 Mtetra
.505 .66 .93 r
.22315 .4775 .23314 .48848 .24774 .4882 .23779 .47713 Mtetra
.545 .675 .923 r
.23779 .47713 .24774 .4882 .26264 .48576 .25263 .47575 Mtetra
.654 .737 .91 r
.25263 .47575 .26264 .48576 .27805 .47795 .26787 .47069 Mtetra
.768 .817 .892 r
.26787 .47069 .27805 .47795 .29378 .46641 .28358 .46056 Mtetra
.803 .85 .886 r
.28358 .46056 .29378 .46641 .30956 .45446 .29945 .44859 Mtetra
.779 .853 .906 r
.29945 .44859 .30956 .45446 .32513 .44648 .31526 .4381 Mtetra
.691 .786 .923 r
.31526 .4381 .32513 .44648 .34058 .44174 .33087 .4315 Mtetra
.627 .728 .92 r
.33087 .4315 .34058 .44174 .35603 .43876 .34643 .42733 Mtetra
.602 .695 .909 r
.34643 .42733 .35603 .43876 .37163 .43486 .36204 .42411 Mtetra
.629 .72 .913 r
.36204 .42411 .37163 .43486 .38737 .4301 .37781 .41982 Mtetra
.645 .737 .916 r
.37781 .41982 .38737 .4301 .40323 .42482 .39371 .41492 Mtetra
.654 .749 .92 r
.39371 .41492 .40323 .42482 .41918 .41951 .40972 .40961 Mtetra
.657 .752 .92 r
.40972 .40961 .41918 .41951 .43522 .41456 .42583 .40418 Mtetra
.656 .742 .913 r
.42583 .40418 .43522 .41456 .45136 .40951 .44203 .39874 Mtetra
.656 .735 .908 r
.44203 .39874 .45136 .40951 .4676 .40426 .45833 .39328 Mtetra
.656 .732 .906 r
.45833 .39328 .4676 .40426 .48394 .39882 .47473 .38777 Mtetra
.656 .732 .905 r
.47473 .38777 .48394 .39882 .50039 .39317 .49124 .38222 Mtetra
.656 .735 .908 r
.49124 .38222 .50039 .39317 .51693 .38733 .50784 .37665 Mtetra
.655 .742 .914 r
.50784 .37665 .51693 .38733 .53356 .38138 .52454 .37106 Mtetra
.658 .752 .919 r
.52454 .37106 .53356 .38138 .5503 .37579 .54134 .36534 Mtetra
.667 .754 .915 r
.54134 .36534 .5503 .37579 .56714 .37017 .55824 .35921 Mtetra
.68 .749 .903 r
.55824 .35921 .56714 .37017 .58407 .36402 .57523 .35246 Mtetra
.7 .745 .886 r
.57523 .35246 .58407 .36402 .60108 .35698 .5923 .34461 Mtetra
.678 .723 .883 r
.5923 .34461 .60108 .35698 .61816 .34899 .60947 .33771 Mtetra
.622 .724 .92 r
.60947 .33771 .61816 .34899 .63538 .3428 .62682 .33329 Mtetra
.471 .698 .967 r
.62682 .33329 .63538 .3428 .65283 .33993 .64444 .33287 Mtetra
.328 .686 .979 r
.64444 .33287 .65283 .33993 .67062 .34115 .6623 .334 Mtetra
.428 .74 .992 r
.6623 .334 .67062 .34115 .68858 .34199 .68027 .33327 Mtetra
.651 .801 .955 r
.68027 .33327 .68858 .34199 .7065 .33898 .69811 .3273 Mtetra
.731 .765 .88 r
.69811 .3273 .7065 .33898 .72422 .33041 .71584 .3175 Mtetra
.742 .748 .857 r
.71584 .3175 .72422 .33041 .74187 .31957 .73358 .30663 Mtetra
.701 .734 .876 r
.73358 .30663 .74187 .31957 .75967 .30996 .75154 .29816 Mtetra
.668 .744 .907 r
.75154 .29816 .75967 .30996 .77774 .30276 .76974 .29149 Mtetra
.649 .748 .922 r
.76974 .29149 .77774 .30276 .79603 .29687 .78811 .28561 Mtetra
.661 .755 .92 r
.78811 .28561 .79603 .29687 .81441 .29068 .80657 .2792 Mtetra
.65 .748 .922 r
.15374 .4854 .16417 .49459 .17883 .48988 .16844 .48065 Mtetra
.658 .751 .918 r
.16844 .48065 .17883 .48988 .19362 .48467 .18327 .47555 Mtetra
.655 .753 .922 r
.18327 .47555 .19362 .48467 .20842 .48021 .19817 .47053 Mtetra
.615 .731 .928 r
.19817 .47053 .20842 .48021 .22315 .4775 .21303 .46687 Mtetra
.539 .684 .932 r
.21303 .46687 .22315 .4775 .23779 .47713 .22777 .46551 Mtetra
.522 .656 .92 r
.22777 .46551 .23779 .47713 .25263 .47575 .24258 .46476 Mtetra
.591 .698 .917 r
.24258 .46476 .25263 .47575 .26787 .47069 .25769 .46192 Mtetra
.713 .78 .905 r
.25769 .46192 .26787 .47069 .28358 .46056 .27327 .45437 Mtetra
.783 .845 .898 r
.27327 .45437 .28358 .46056 .29945 .44859 .28915 .4435 Mtetra
.8 .871 .9 r
.28915 .4435 .29945 .44859 .31526 .4381 .30512 .43186 Mtetra
.753 .847 .922 r
.30512 .43186 .31526 .4381 .33087 .4315 .32097 .42262 Mtetra
.678 .775 .924 r
.32097 .42262 .33087 .4315 .34643 .42733 .3367 .41646 Mtetra
.628 .719 .912 r
.3367 .41646 .34643 .42733 .36204 .42411 .35241 .4122 Mtetra
.611 .693 .901 r
.35241 .4122 .36204 .42411 .37781 .41982 .36818 .40859 Mtetra
.629 .714 .908 r
.36818 .40859 .37781 .41982 .39371 .41492 .38411 .40426 Mtetra
.644 .732 .913 r
.38411 .40426 .39371 .41492 .40972 .40961 .40016 .3993 Mtetra
.65 .743 .917 r
.40016 .3993 .40972 .40961 .42583 .40418 .41632 .39406 Mtetra
.654 .749 .92 r
.41632 .39406 .42583 .40418 .44203 .39874 .43258 .38863 Mtetra
.656 .751 .92 r
.43258 .38863 .44203 .39874 .45833 .39328 .44895 .3831 Mtetra
.44895 .3831 .45833 .39328 .47473 .38777 .46541 .37753 Mtetra
.46541 .37753 .47473 .38777 .49124 .38222 .48198 .37192 Mtetra
.658 .752 .92 r
.48198 .37192 .49124 .38222 .50784 .37665 .49864 .36621 Mtetra
.662 .752 .917 r
.49864 .36621 .50784 .37665 .52454 .37106 .51541 .36031 Mtetra
.668 .749 .911 r
.51541 .36031 .52454 .37106 .54134 .36534 .53228 .35412 Mtetra
.681 .745 .899 r
.53228 .35412 .54134 .36534 .55824 .35921 .54924 .34728 Mtetra
.693 .737 .884 r
.54924 .34728 .55824 .35921 .57523 .35246 .56629 .33971 Mtetra
.677 .717 .879 r
.56629 .33971 .57523 .35246 .5923 .34461 .58343 .33279 Mtetra
.635 .72 .908 r
.58343 .33279 .5923 .34461 .60947 .33771 .60072 .3278 Mtetra
.53 .718 .959 r
.60072 .3278 .60947 .33771 .62682 .33329 .61822 .32596 Mtetra
.36 .699 .984 r
.61822 .32596 .62682 .33329 .64444 .33287 .63596 .32661 Mtetra
.363 .73 .988 r
.63596 .32661 .64444 .33287 .6623 .334 .65386 .32649 Mtetra
.556 .795 .988 r
.65386 .32649 .6623 .334 .68027 .33327 .67178 .32297 Mtetra
.709 .787 .912 r
.67178 .32297 .68027 .33327 .69811 .3273 .68959 .31458 Mtetra
.738 .751 .863 r
.68959 .31458 .69811 .3273 .71584 .3175 .70735 .30399 Mtetra
.724 .734 .859 r
.70735 .30399 .71584 .3175 .73358 .30663 .72522 .29402 Mtetra
.685 .736 .889 r
.72522 .29402 .73358 .30663 .75154 .29816 .74333 .2864 Mtetra
.656 .743 .913 r
.74333 .2864 .75154 .29816 .76974 .29149 .76165 .2802 Mtetra
.653 .752 .923 r
.76165 .2802 .76974 .29149 .78811 .28561 .7801 .27408 Mtetra
.661 .752 .918 r
.7801 .27408 .78811 .28561 .80657 .2792 .79863 .26758 Mtetra
.651 .749 .921 r
.14319 .47613 .15374 .4854 .16844 .48065 .15795 .47129 Mtetra
.652 .748 .921 r
.15795 .47129 .16844 .48065 .18327 .47555 .1728 .46639 Mtetra
.663 .757 .92 r
.1728 .46639 .18327 .47555 .19817 .47053 .18778 .46104 Mtetra
.638 .744 .925 r
.18778 .46104 .19817 .47053 .21303 .46687 .20276 .45655 Mtetra
.59 .712 .928 r
.20276 .45655 .21303 .46687 .22777 .46551 .21767 .45363 Mtetra
.524 .654 .917 r
.21767 .45363 .22777 .46551 .24258 .46476 .23251 .45282 Mtetra
.551 .665 .913 r
.23251 .45282 .24258 .46476 .25769 .46192 .24754 .45126 Mtetra
.625 .72 .915 r
.24754 .45126 .25769 .46192 .27327 .45437 .26289 .44714 Mtetra
.744 .822 .912 r
.26289 .44714 .27327 .45437 .28915 .4435 .27871 .43818 Mtetra
.786 .869 .909 r
.27871 .43818 .28915 .4435 .30512 .43186 .29473 .42723 Mtetra
.79 .887 .915 r
.29473 .42723 .30512 .43186 .32097 .42262 .31079 .41615 Mtetra
.74 .844 .929 r
.31079 .41615 .32097 .42262 .3367 .41646 .32675 .40742 Mtetra
.678 .775 .924 r
.32675 .40742 .3367 .41646 .35241 .4122 .34262 .40116 Mtetra
.641 .723 .908 r
.34262 .40116 .35241 .4122 .36818 .40859 .35851 .39633 Mtetra
.623 .694 .895 r
.35851 .39633 .36818 .40859 .38411 .40426 .37446 .39219 Mtetra
.625 .699 .898 r
.37446 .39219 .38411 .40426 .40016 .3993 .39053 .38792 Mtetra
.64 .72 .906 r
.39053 .38792 .40016 .3993 .41632 .39406 .40673 .38301 Mtetra
.649 .731 .909 r
.40673 .38301 .41632 .39406 .43258 .38863 .42304 .37774 Mtetra
.653 .737 .911 r
.42304 .37774 .43258 .38863 .44895 .3831 .43947 .37226 Mtetra
.656 .74 .912 r
.43947 .37226 .44895 .3831 .46541 .37753 .45599 .36663 Mtetra
.659 .741 .911 r
.45599 .36663 .46541 .37753 .48198 .37192 .47262 .36084 Mtetra
.663 .74 .907 r
.47262 .36084 .48198 .37192 .49864 .36621 .48935 .35485 Mtetra
.67 .738 .901 r
.48935 .35485 .49864 .36621 .51541 .36031 .50619 .34848 Mtetra
.683 .735 .89 r
.50619 .34848 .51541 .36031 .53228 .35412 .52312 .34146 Mtetra
.682 .72 .878 r
.52312 .34146 .53228 .35412 .54924 .34728 .54014 .33431 Mtetra
.667 .71 .88 r
.54014 .33431 .54924 .34728 .56629 .33971 .55726 .32783 Mtetra
.635 .72 .909 r
.55726 .32783 .56629 .33971 .58343 .33279 .57451 .32282 Mtetra
.552 .728 .957 r
.57451 .32282 .58343 .33279 .60072 .3278 .59192 .32033 Mtetra
.398 .718 .988 r
.59192 .32033 .60072 .3278 .61822 .32596 .60955 .32027 Mtetra
.34 .733 .984 r
.60955 .32027 .61822 .32596 .63596 .32661 .62736 .32008 Mtetra
.475 .785 .998 r
.62736 .32008 .63596 .32661 .65386 .32649 .64526 .31788 Mtetra
.68 .817 .949 r
.64526 .31788 .65386 .32649 .67178 .32297 .66311 .3107 Mtetra
.728 .757 .875 r
.66311 .3107 .67178 .32297 .68959 .31458 .68092 .30085 Mtetra
.733 .734 .852 r
.68092 .30085 .68959 .31458 .70735 .30399 .69876 .29019 Mtetra
.697 .721 .868 r
.69876 .29019 .70735 .30399 .72522 .29402 .71681 .28169 Mtetra
.67 .738 .901 r
.71681 .28169 .72522 .29402 .74333 .2864 .73505 .27483 Mtetra
.649 .746 .92 r
.73505 .27483 .74333 .2864 .76165 .2802 .75347 .26884 Mtetra
.66 .757 .922 r
.75347 .26884 .76165 .2802 .7801 .27408 .77198 .26238 Mtetra
.66 .751 .917 r
.77198 .26238 .7801 .27408 .79863 .26758 .7906 .25583 Mtetra
.652 .75 .921 r
.13253 .46678 .14319 .47613 .15795 .47129 .14735 .46182 Mtetra
.65 .748 .921 r
.14735 .46182 .15795 .47129 .1728 .46639 .16224 .45693 Mtetra
.659 .751 .918 r
.16224 .45693 .1728 .46639 .18778 .46104 .17725 .45167 Mtetra
.656 .754 .922 r
.17725 .45167 .18778 .46104 .20276 .45655 .19234 .44648 Mtetra
.623 .73 .924 r
.19234 .44648 .20276 .45655 .21767 .45363 .2074 .44246 Mtetra
.565 .688 .923 r
.2074 .44246 .21767 .45363 .23251 .45282 .22239 .4403 Mtetra
.534 .649 .908 r
.22239 .4403 .23251 .45282 .24754 .45126 .2374 .43922 Mtetra
.574 .676 .909 r
.2374 .43922 .24754 .45126 .26289 .44714 .25264 .43687 Mtetra
.652 .74 .914 r
.25264 .43687 .26289 .44714 .27871 .43818 .26822 .43167 Mtetra
.747 .843 .923 r
.26822 .43167 .27871 .43818 .29473 .42723 .28419 .42256 Mtetra
.778 .887 .923 r
.28419 .42256 .29473 .42723 .31079 .41615 .30031 .41199 Mtetra
.778 .901 .928 r
.30031 .41199 .31079 .41615 .32675 .40742 .31648 .40139 Mtetra
.742 .859 .935 r
.31648 .40139 .32675 .40742 .34262 .40116 .33259 .39247 Mtetra
.687 .789 .928 r
.33259 .39247 .34262 .40116 .35851 .39633 .34864 .38578 Mtetra
.66 .743 .911 r
.34864 .38578 .35851 .39633 .37446 .39219 .36472 .3801 Mtetra
.641 .707 .895 r
.36472 .3801 .37446 .39219 .39053 .38792 .38086 .37512 Mtetra
.637 .694 .886 r
.38086 .37512 .39053 .38792 .40673 .38301 .3971 .37027 Mtetra
.641 .697 .887 r
.3971 .37027 .40673 .38301 .42304 .37774 .41346 .36522 Mtetra
.647 .705 .889 r
.41346 .36522 .42304 .37774 .43947 .37226 .42993 .35986 Mtetra
.654 .711 .889 r
.42993 .35986 .43947 .37226 .45599 .36663 .44651 .35416 Mtetra
.661 .714 .887 r
.44651 .35416 .45599 .36663 .47262 .36084 .46319 .34812 Mtetra
.667 .712 .882 r
.46319 .34812 .47262 .36084 .48935 .35485 .47999 .34176 Mtetra
.669 .708 .877 r
.47999 .34176 .48935 .35485 .50619 .34848 .49688 .3352 Mtetra
.666 .705 .876 r
.49688 .3352 .50619 .34848 .52312 .34146 .51386 .32877 Mtetra
.651 .711 .891 r
.51386 .32877 .52312 .34146 .54014 .33431 .53095 .32304 Mtetra
.626 .73 .922 r
.53095 .32304 .54014 .33431 .55726 .32783 .54816 .31834 Mtetra
.542 .737 .965 r
.54816 .31834 .55726 .32783 .57451 .32282 .56551 .31591 Mtetra
.411 .742 .993 r
.56551 .31591 .57451 .32282 .59192 .32033 .58305 .31521 Mtetra
.343 .75 .982 r
.58305 .31521 .59192 .32033 .60955 .32027 .60075 .3145 Mtetra
.449 .792 .998 r
.60075 .3145 .60955 .32027 .62736 .32008 .61859 .31233 Mtetra
.648 .828 .969 r
.61859 .31233 .62736 .32008 .64526 .31788 .63644 .30612 Mtetra
.717 .763 .889 r
.63644 .30612 .64526 .31788 .66311 .3107 .65428 .29698 Mtetra
.73 .735 .854 r
.65428 .29698 .66311 .3107 .68092 .30085 .67215 .28649 Mtetra
.709 .718 .856 r
.67215 .28649 .68092 .30085 .69876 .29019 .69013 .2771 Mtetra
.68 .729 .887 r
.69013 .2771 .69876 .29019 .71681 .28169 .70832 .26961 Mtetra
.655 .74 .912 r
.70832 .26961 .71681 .28169 .73505 .27483 .72668 .26334 Mtetra
.653 .753 .923 r
.72668 .26334 .73505 .27483 .75347 .26884 .74518 .25712 Mtetra
.661 .752 .918 r
.74518 .25712 .75347 .26884 .77198 .26238 .76376 .25052 Mtetra
.659 .75 .918 r
.76376 .25052 .77198 .26238 .7906 .25583 .78248 .24397 Mtetra
.655 .751 .921 r
.12176 .45738 .13253 .46678 .14735 .46182 .13663 .45228 Mtetra
.651 .748 .921 r
.13663 .45228 .14735 .46182 .16224 .45693 .15157 .44729 Mtetra
.651 .748 .92 r
.15157 .44729 .16224 .45693 .17725 .45167 .1666 .44227 Mtetra
.663 .757 .92 r
.1666 .44227 .17725 .45167 .19234 .44648 .18177 .43679 Mtetra
.647 .748 .923 r
.18177 .43679 .19234 .44648 .2074 .44246 .19697 .43184 Mtetra
.613 .719 .921 r
.19697 .43184 .2074 .44246 .22239 .4403 .21214 .42807 Mtetra
.557 .666 .91 r
.21214 .42807 .22239 .4403 .2374 .43922 .22724 .4262 Mtetra
.548 .648 .9 r
.22724 .4262 .2374 .43922 .25264 .43687 .24243 .42471 Mtetra
.588 .682 .906 r
.24243 .42471 .25264 .43687 .26822 .43167 .25787 .42182 Mtetra
.656 .753 .922 r
.25787 .42182 .26822 .43167 .28419 .42256 .27361 .41638 Mtetra
.737 .854 .935 r
.27361 .41638 .28419 .42256 .30031 .41199 .28969 .40764 Mtetra
.761 .899 .938 r
.28969 .40764 .30031 .41199 .31648 .40139 .3059 .39776 Mtetra
.762 .916 .941 r
.3059 .39776 .31648 .40139 .33259 .39247 .32218 .38768 Mtetra
.745 .891 .946 r
.32218 .38768 .33259 .39247 .34864 .38578 .33847 .37844 Mtetra
.706 .828 .94 r
.33847 .37844 .34864 .38578 .36472 .3801 .35472 .37087 Mtetra
.677 .78 .928 r
.35472 .37087 .36472 .3801 .38086 .37512 .37099 .36444 Mtetra
.663 .746 .912 r
.37099 .36444 .38086 .37512 .3971 .37027 .38734 .3585 Mtetra
.656 .724 .899 r
.38734 .3585 .3971 .37027 .41346 .36522 .40377 .35278 Mtetra
.654 .711 .89 r
.40377 .35278 .41346 .36522 .42993 .35986 .4203 .34708 Mtetra
.654 .706 .886 r
.4203 .34708 .42993 .35986 .44651 .35416 .43693 .34131 Mtetra
.655 .707 .885 r
.43693 .34131 .44651 .35416 .46319 .34812 .45367 .33548 Mtetra
.654 .711 .89 r
.45367 .33548 .46319 .34812 .47999 .34176 .47051 .32967 Mtetra
.649 .721 .901 r
.47051 .32967 .47999 .34176 .49688 .3352 .48745 .32407 Mtetra
.636 .737 .921 r
.48745 .32407 .49688 .3352 .51386 .32877 .50449 .31897 Mtetra
.597 .753 .952 r
.50449 .31897 .51386 .32877 .53095 .32304 .52165 .31503 Mtetra
.511 .762 .987 r
.52165 .31503 .53095 .32304 .54816 .31834 .53895 .31279 Mtetra
.399 .771 .993 r
.53895 .31279 .54816 .31834 .56551 .31591 .55641 .31143 Mtetra
.364 .777 .98 r
.55641 .31143 .56551 .31591 .58305 .31521 .57403 .30988 Mtetra
.46 .81 .998 r
.57403 .30988 .58305 .31521 .60075 .3145 .59179 .30718 Mtetra
.64 .837 .976 r
.59179 .30718 .60075 .3145 .61859 .31233 .60961 .3011 Mtetra
.711 .773 .901 r
.60961 .3011 .61859 .31233 .63644 .30612 .62746 .29239 Mtetra
.725 .733 .858 r
.62746 .29239 .63644 .30612 .65428 .29698 .64534 .28222 Mtetra
.714 .714 .849 r
.64534 .28222 .65428 .29698 .67215 .28649 .6633 .27241 Mtetra
.683 .714 .872 r
.6633 .27241 .67215 .28649 .69013 .2771 .68144 .26455 Mtetra
.662 .735 .903 r
.68144 .26455 .69013 .2771 .70832 .26961 .69976 .25789 Mtetra
.649 .747 .921 r
.69976 .25789 .70832 .26961 .72668 .26334 .71822 .25179 Mtetra
.66 .757 .922 r
.71822 .25179 .72668 .26334 .74518 .25712 .73678 .24519 Mtetra
.66 .751 .917 r
.73678 .24519 .74518 .25712 .76376 .25052 .75545 .23855 Mtetra
.657 .75 .919 r
.75545 .23855 .76376 .25052 .78248 .24397 .77426 .23201 Mtetra
.659 .754 .921 r
.11085 .44797 .12176 .45738 .13663 .45228 .12579 .44267 Mtetra
.653 .75 .921 r
.12579 .44267 .13663 .45228 .15157 .44729 .14079 .43755 Mtetra
.65 .747 .921 r
.14079 .43755 .15157 .44729 .1666 .44227 .15587 .43249 Mtetra
.655 .749 .919 r
.15587 .43249 .1666 .44227 .18177 .43679 .17105 .42724 Mtetra
.661 .757 .921 r
.17105 .42724 .18177 .43679 .19697 .43184 .18636 .42172 Mtetra
.641 .74 .921 r
.18636 .42172 .19697 .43184 .21214 .42807 .20167 .41691 Mtetra
.61 .71 .916 r
.20167 .41691 .21214 .42807 .22724 .4262 .21698 .41318 Mtetra
.56 .656 .9 r
.21698 .41318 .22724 .4262 .24243 .42471 .23224 .41122 Mtetra
.559 .648 .894 r
.23224 .41122 .24243 .42471 .25787 .42182 .24761 .40933 Mtetra
.593 .681 .903 r
.24761 .40933 .25787 .42182 .27361 .41638 .2632 .4062 Mtetra
.64 .746 .925 r
.2632 .4062 .27361 .41638 .28969 .40764 .27906 .40126 Mtetra
.715 .85 .946 r
.27906 .40126 .28969 .40764 .3059 .39776 .29522 .39331 Mtetra
.735 .898 .952 r
.29522 .39331 .3059 .39776 .32218 .38768 .31153 .38435 Mtetra
.734 .924 .955 r
.31153 .38435 .32218 .38768 .33847 .37844 .32791 .37509 Mtetra
.723 .924 .96 r
.32791 .37509 .33847 .37844 .35472 .37087 .34434 .36615 Mtetra
.711 .894 .963 r
.34434 .36615 .35472 .37087 .37099 .36444 .3608 .35792 Mtetra
.697 .851 .957 r
.3608 .35792 .37099 .36444 .38734 .3585 .37729 .35048 Mtetra
.676 .813 .948 r
.37729 .35048 .38734 .3585 .40377 .35278 .39383 .34388 Mtetra
.663 .79 .942 r
.39383 .34388 .40377 .35278 .4203 .34708 .41044 .33777 Mtetra
.655 .78 .94 r
.41044 .33777 .4203 .34708 .43693 .34131 .42715 .33194 Mtetra
.646 .777 .943 r
.42715 .33194 .43693 .34131 .45367 .33548 .44395 .32639 Mtetra
.63 .78 .953 r
.44395 .32639 .45367 .33548 .47051 .32967 .46085 .32133 Mtetra
.595 .787 .972 r
.46085 .32133 .47051 .32967 .48745 .32407 .47785 .31713 Mtetra
.543 .803 .994 r
.47785 .31713 .48745 .32407 .50449 .31897 .49497 .31371 Mtetra
.462 .81 .998 r
.49497 .31371 .50449 .31897 .52165 .31503 .51222 .31104 Mtetra
.392 .803 .979 r
.51222 .31104 .52165 .31503 .53895 .31279 .52961 .30871 Mtetra
.411 .812 .983 r
.52961 .30871 .53895 .31279 .55641 .31143 .54716 .30609 Mtetra
.507 .832 .999 r
.54716 .30609 .55641 .31143 .57403 .30988 .56485 .30245 Mtetra
.659 .841 .97 r
.56485 .30245 .57403 .30988 .59179 .30718 .58262 .29574 Mtetra
.707 .768 .9 r
.58262 .29574 .59179 .30718 .60961 .3011 .60046 .28715 Mtetra
.719 .729 .858 r
.60046 .28715 .60961 .3011 .62746 .29239 .61834 .27727 Mtetra
.712 .709 .846 r
.61834 .27727 .62746 .29239 .64534 .28222 .6363 .26744 Mtetra
.683 .704 .863 r
.6363 .26744 .64534 .28222 .6633 .27241 .65442 .25941 Mtetra
.667 .729 .896 r
.65442 .25941 .6633 .27241 .68144 .26455 .67269 .25249 Mtetra
.651 .742 .917 r
.67269 .25249 .68144 .26455 .69976 .25789 .69111 .24629 Mtetra
.657 .756 .923 r
.69111 .24629 .69976 .25789 .71822 .25179 .70964 .23981 Mtetra
.661 .751 .917 r
.70964 .23981 .71822 .25179 .73678 .24519 .72828 .23311 Mtetra
.658 .75 .918 r
.72828 .23311 .73678 .24519 .75545 .23855 .74704 .22647 Mtetra
.653 .749 .92 r
.74704 .22647 .75545 .23855 .77426 .23201 .76595 .22001 Mtetra
.661 .755 .92 r
.09982 .43848 .11085 .44797 .12579 .44267 .11482 .43304 Mtetra
.656 .752 .921 r
.11482 .43304 .12579 .44267 .14079 .43755 .12988 .42774 Mtetra
.652 .749 .92 r
.12988 .42774 .14079 .43755 .15587 .43249 .14502 .42256 Mtetra
.651 .747 .92 r
.14502 .42256 .15587 .43249 .17105 .42724 .16024 .41741 Mtetra
.658 .752 .92 r
.16024 .41741 .17105 .42724 .18636 .42172 .17558 .41196 Mtetra
.659 .755 .921 r
.17558 .41196 .18636 .42172 .20167 .41691 .19102 .40642 Mtetra
.639 .736 .918 r
.19102 .40642 .20167 .41691 .21698 .41318 .20647 .4016 Mtetra
.613 .706 .911 r
.20647 .4016 .21698 .41318 .23224 .41122 .22194 .3977 Mtetra
.571 .654 .893 r
.22194 .3977 .23224 .41122 .24761 .40933 .23737 .39533 Mtetra
.569 .646 .887 r
.23737 .39533 .24761 .40933 .2632 .4062 .25292 .39307 Mtetra
.592 .672 .896 r
.25292 .39307 .2632 .4062 .27906 .40126 .26867 .38991 Mtetra
.625 .72 .915 r
.26867 .38991 .27906 .40126 .29522 .39331 .28463 .38543 Mtetra
.671 .811 .95 r
.28463 .38543 .29522 .39331 .31153 .38435 .30083 .37911 Mtetra
.703 .88 .963 r
.30083 .37911 .31153 .38435 .32791 .37509 .31721 .37129 Mtetra
.699 .913 .969 r
.31721 .37129 .32791 .37509 .34434 .36615 .3337 .36315 Mtetra
.681 .927 .971 r
.3337 .36315 .34434 .36615 .3608 .35792 .35025 .35512 Mtetra
.663 .927 .973 r
.35025 .35512 .3608 .35792 .37729 .35048 .36686 .34741 Mtetra
.642 .918 .978 r
.36686 .34741 .37729 .35048 .39383 .34388 .38352 .34027 Mtetra
.623 .904 .985 r
.38352 .34027 .39383 .34388 .41044 .33777 .40025 .33375 Mtetra
.601 .89 .99 r
.40025 .33375 .41044 .33777 .42715 .33194 .41706 .32786 Mtetra
.57 .879 .993 r
.41706 .32786 .42715 .33194 .44395 .32639 .43395 .3226 Mtetra
.527 .869 .991 r
.43395 .3226 .44395 .32639 .46085 .32133 .45094 .31797 Mtetra
.476 .856 .982 r
.45094 .31797 .46085 .32133 .47785 .31713 .46804 .31392 Mtetra
.447 .845 .976 r
.46804 .31392 .47785 .31713 .49497 .31371 .48527 .3102 Mtetra
.448 .841 .98 r
.48527 .3102 .49497 .31371 .51222 .31104 .50263 .3066 Mtetra
.496 .847 .994 r
.50263 .3066 .51222 .31104 .52961 .30871 .52012 .30268 Mtetra
.601 .854 .992 r
.52012 .30268 .52961 .30871 .54716 .30609 .53775 .29725 Mtetra
.682 .815 .947 r
.53775 .29725 .54716 .30609 .56485 .30245 .55549 .28993 Mtetra
.705 .748 .885 r
.55549 .28993 .56485 .30245 .58262 .29574 .5733 .28125 Mtetra
.712 .719 .855 r
.5733 .28125 .58262 .29574 .60046 .28715 .59118 .27163 Mtetra
.705 .702 .844 r
.59118 .27163 .60046 .28715 .61834 .27727 .60914 .26209 Mtetra
.681 .698 .859 r
.60914 .26209 .61834 .27727 .6363 .26744 .62724 .25412 Mtetra
.668 .725 .892 r
.62724 .25412 .6363 .26744 .65442 .25941 .64547 .24708 Mtetra
.652 .739 .913 r
.64547 .24708 .65442 .25941 .67269 .25249 .66385 .24078 Mtetra
.654 .754 .923 r
.66385 .24078 .67269 .25249 .69111 .24629 .68234 .23437 Mtetra
.66 .754 .919 r
.68234 .23437 .69111 .24629 .70964 .23981 .70095 .22764 Mtetra
.659 .75 .917 r
.70095 .22764 .70964 .23981 .72828 .23311 .71968 .22093 Mtetra
.655 .749 .919 r
.71968 .22093 .72828 .23311 .74704 .22647 .73854 .21434 Mtetra
.651 .75 .922 r
.73854 .21434 .74704 .22647 .76595 .22001 .75754 .20789 Mtetra
.658 .753 .92 r
.08868 .42881 .09982 .43848 .11482 .43304 .10372 .4234 Mtetra
.661 .755 .92 r
.10372 .4234 .11482 .43304 .12988 .42774 .11885 .41788 Mtetra
.655 .751 .92 r
.11885 .41788 .12988 .42774 .14502 .42256 .13405 .41256 Mtetra
.652 .748 .92 r
.13405 .41256 .14502 .42256 .16024 .41741 .14932 .4073 Mtetra
.651 .747 .92 r
.14932 .4073 .16024 .41741 .17558 .41196 .16469 .40205 Mtetra
.659 .754 .92 r
.16469 .40205 .17558 .41196 .19102 .40642 .18018 .39647 Mtetra
.659 .755 .921 r
.18018 .39647 .19102 .40642 .20647 .4016 .19576 .39085 Mtetra
.641 .734 .916 r
.19576 .39085 .20647 .4016 .22194 .3977 .21137 .38585 Mtetra
.621 .707 .907 r
.21137 .38585 .22194 .3977 .23737 .39533 .22702 .3816 Mtetra
.589 .662 .888 r
.22702 .3816 .23737 .39533 .25292 .39307 .24266 .37853 Mtetra
.578 .644 .88 r
.24266 .37853 .25292 .39307 .26867 .38991 .25839 .37586 Mtetra
.591 .659 .885 r
.25839 .37586 .26867 .38991 .28463 .38543 .27428 .37267 Mtetra
.613 .692 .9 r
.27428 .37267 .28463 .38543 .30083 .37911 .29036 .3686 Mtetra
.635 .746 .928 r
.29036 .3686 .30083 .37911 .31721 .37129 .30661 .3636 Mtetra
.655 .816 .961 r
.30661 .3636 .31721 .37129 .3337 .36315 .32304 .35764 Mtetra
.67 .872 .975 r
.32304 .35764 .3337 .36315 .35025 .35512 .33961 .35073 Mtetra
.657 .896 .981 r
.33961 .35073 .35025 .35512 .36686 .34741 .35628 .34377 Mtetra
.633 .906 .983 r
.35628 .34377 .36686 .34741 .38352 .34027 .37303 .33702 Mtetra
.605 .906 .983 r
.37303 .33702 .38352 .34027 .40025 .33375 .38986 .33063 Mtetra
.577 .9 .983 r
.38986 .33063 .40025 .33375 .41706 .32786 .40677 .32469 Mtetra
.553 .891 .984 r
.40677 .32469 .41706 .32786 .43395 .3226 .42378 .31917 Mtetra
.538 .882 .986 r
.42378 .31917 .43395 .3226 .45094 .31797 .44088 .31403 Mtetra
.539 .873 .991 r
.44088 .31403 .45094 .31797 .46804 .31392 .4581 .3091 Mtetra
.561 .865 .996 r
.4581 .3091 .46804 .31392 .48527 .3102 .47544 .30413 Mtetra
.622 .86 .988 r
.47544 .30413 .48527 .3102 .50263 .3066 .49292 .2982 Mtetra
.67 .821 .956 r
.49292 .2982 .50263 .3066 .52012 .30268 .51051 .29128 Mtetra
.692 .765 .907 r
.51051 .29128 .52012 .30268 .53775 .29725 .52821 .28341 Mtetra
.701 .725 .868 r
.52821 .28341 .53775 .29725 .55549 .28993 .546 .27463 Mtetra
.703 .704 .848 r
.546 .27463 .55549 .28993 .5733 .28125 .56387 .26531 Mtetra
.694 .692 .844 r
.56387 .26531 .5733 .28125 .59118 .27163 .58183 .25637 Mtetra
.676 .696 .861 r
.58183 .25637 .59118 .27163 .60914 .26209 .5999 .24862 Mtetra
.666 .723 .892 r
.5999 .24862 .60914 .26209 .62724 .25412 .6181 .24163 Mtetra
.653 .738 .912 r
.6181 .24163 .62724 .25412 .64547 .24708 .63644 .23527 Mtetra
.653 .753 .923 r
.63644 .23527 .64547 .24708 .66385 .24078 .6549 .22887 Mtetra
.66 .755 .92 r
.6549 .22887 .66385 .24078 .68234 .23437 .67347 .22212 Mtetra
.659 .75 .917 r
.67347 .22212 .68234 .23437 .70095 .22764 .69216 .21536 Mtetra
.657 .75 .918 r
.69216 .21536 .70095 .22764 .71968 .22093 .71097 .20866 Mtetra
.651 .749 .921 r
.71097 .20866 .71968 .22093 .73854 .21434 .72993 .20216 Mtetra
.653 .753 .923 r
.72993 .20216 .73854 .21434 .75754 .20789 .74902 .19552 Mtetra
.654 .75 .92 r
.07744 .41893 .08868 .42881 .10372 .4234 .0925 .41363 Mtetra
.66 .755 .92 r
.0925 .41363 .10372 .4234 .11885 .41788 .10768 .40808 Mtetra
.659 .755 .921 r
.10768 .40808 .11885 .41788 .13405 .41256 .12295 .40251 Mtetra
.654 .75 .92 r
.12295 .40251 .13405 .41256 .14932 .4073 .13829 .39711 Mtetra
.652 .748 .92 r
.13829 .39711 .14932 .4073 .16469 .40205 .15371 .39176 Mtetra
.651 .747 .92 r
.15371 .39176 .16469 .40205 .18018 .39647 .16922 .3864 Mtetra
.658 .754 .921 r
.16922 .3864 .18018 .39647 .19576 .39085 .18485 .38074 Mtetra
.66 .755 .921 r
.18485 .38074 .19576 .39085 .21137 .38585 .20059 .375 Mtetra
.647 .738 .915 r
.20059 .375 .21137 .38585 .22702 .3816 .21637 .3697 Mtetra
.63 .713 .906 r
.21637 .3697 .22702 .3816 .24266 .37853 .2322 .36499 Mtetra
.613 .678 .888 r
.2322 .36499 .24266 .37853 .25839 .37586 .24808 .36092 Mtetra
.592 .647 .874 r
.24808 .36092 .25839 .37586 .27428 .37267 .264 .35765 Mtetra
.595 .648 .873 r
.264 .35765 .27428 .37267 .29036 .3686 .28005 .35422 Mtetra
.607 .665 .88 r
.28005 .35422 .29036 .3686 .30661 .3636 .29627 .3503 Mtetra
.621 .69 .893 r
.29627 .3503 .30661 .3636 .32304 .35764 .31264 .34576 Mtetra
.635 .723 .911 r
.31264 .34576 .32304 .35764 .33961 .35073 .32916 .34069 Mtetra
.644 .765 .937 r
.32916 .34069 .33961 .35073 .35628 .34377 .34581 .33519 Mtetra
.647 .8 .956 r
.34581 .33519 .35628 .34377 .37303 .33702 .36259 .32941 Mtetra
.645 .824 .969 r
.36259 .32941 .37303 .33702 .38986 .33063 .37948 .32347 Mtetra
.643 .835 .974 r
.37948 .32347 .38986 .33063 .40677 .32469 .39648 .31746 Mtetra
.645 .835 .974 r
.39648 .31746 .40677 .32469 .42378 .31917 .41359 .31136 Mtetra
.652 .825 .967 r
.41359 .31136 .42378 .31917 .44088 .31403 .43081 .30512 Mtetra
.663 .805 .951 r
.43081 .30512 .44088 .31403 .4581 .3091 .44814 .29858 Mtetra
.675 .775 .926 r
.44814 .29858 .4581 .3091 .47544 .30413 .46559 .29161 Mtetra
.683 .74 .894 r
.46559 .29161 .47544 .30413 .49292 .2982 .48316 .28409 Mtetra
.689 .716 .869 r
.48316 .28409 .49292 .2982 .51051 .29128 .50082 .27593 Mtetra
.692 .699 .851 r
.50082 .27593 .51051 .29128 .52821 .28341 .51858 .26727 Mtetra
.691 .688 .842 r
.51858 .26727 .52821 .28341 .546 .27463 .53642 .25841 Mtetra
.677 .682 .847 r
.53642 .25841 .546 .27463 .56387 .26531 .55436 .25036 Mtetra
.67 .7 .869 r
.55436 .25036 .56387 .26531 .58183 .25637 .57241 .24296 Mtetra
.662 .724 .895 r
.57241 .24296 .58183 .25637 .5999 .24862 .59058 .23614 Mtetra
.652 .739 .913 r
.59058 .23614 .5999 .24862 .6181 .24163 .60888 .22978 Mtetra
.654 .753 .923 r
.60888 .22978 .6181 .24163 .63644 .23527 .6273 .22332 Mtetra
.66 .755 .921 r
.6273 .22332 .63644 .23527 .6549 .22887 .64583 .21655 Mtetra
.659 .749 .917 r
.64583 .21655 .6549 .22887 .67347 .22212 .66448 .20975 Mtetra
.657 .749 .918 r
.66448 .20975 .67347 .22212 .69216 .21536 .68326 .203 Mtetra
.652 .749 .921 r
.68326 .203 .69216 .21536 .71097 .20866 .70218 .19641 Mtetra
.652 .753 .923 r
.70218 .19641 .71097 .20866 .72993 .20216 .72122 .18979 Mtetra
.657 .754 .921 r
.72122 .18979 .72993 .20216 .74902 .19552 .74038 .1829 Mtetra
.653 .749 .92 r
.06607 .40891 .07744 .41893 .0925 .41363 .08117 .40359 Mtetra
.655 .75 .92 r
.08117 .40359 .0925 .41363 .10768 .40808 .09638 .39817 Mtetra
.66 .756 .921 r
.09638 .39817 .10768 .40808 .12295 .40251 .11171 .39251 Mtetra
.659 .755 .921 r
.11171 .39251 .12295 .40251 .13829 .39711 .12712 .38688 Mtetra
.654 .75 .92 r
.12712 .38688 .13829 .39711 .15371 .39176 .1426 .38138 Mtetra
.652 .747 .919 r
.1426 .38138 .15371 .39176 .16922 .3864 .15817 .37592 Mtetra
.15817 .37592 .16922 .3864 .18485 .38074 .17383 .37045 Mtetra
.656 .753 .921 r
.17383 .37045 .18485 .38074 .20059 .375 .18961 .36478 Mtetra
.661 .757 .921 r
.18961 .36478 .20059 .375 .21637 .3697 .2055 .3589 Mtetra
.654 .744 .916 r
.2055 .3589 .21637 .3697 .2322 .36499 .22146 .35323 Mtetra
.641 .723 .908 r
.22146 .35323 .2322 .36499 .24808 .36092 .23748 .34802 Mtetra
.631 .699 .895 r
.23748 .34802 .24808 .36092 .264 .35765 .25357 .34315 Mtetra
.619 .669 .876 r
.25357 .34315 .264 .35765 .28005 .35422 .26974 .33868 Mtetra
.607 .648 .865 r
.26974 .33868 .28005 .35422 .29627 .3503 .28599 .33463 Mtetra
.611 .649 .863 r
.28599 .33463 .29627 .3503 .31264 .34576 .30237 .33038 Mtetra
.619 .658 .866 r
.30237 .33038 .31264 .34576 .32916 .34069 .31889 .32578 Mtetra
.628 .67 .872 r
.31889 .32578 .32916 .34069 .34581 .33519 .33555 .32079 Mtetra
.637 .683 .877 r
.33555 .32079 .34581 .33519 .36259 .32941 .35235 .31539 Mtetra
.645 .694 .881 r
.35235 .31539 .36259 .32941 .37948 .32347 .36928 .30964 Mtetra
.651 .701 .883 r
.36928 .30964 .37948 .32347 .39648 .31746 .38633 .30355 Mtetra
.658 .703 .88 r
.38633 .30355 .39648 .31746 .41359 .31136 .4035 .29713 Mtetra
.664 .701 .875 r
.4035 .29713 .41359 .31136 .43081 .30512 .42079 .29034 Mtetra
.669 .696 .866 r
.42079 .29034 .43081 .30512 .44814 .29858 .4382 .28315 Mtetra
.674 .689 .856 r
.4382 .28315 .44814 .29858 .46559 .29161 .45571 .27554 Mtetra
.678 .682 .847 r
.45571 .27554 .46559 .29161 .48316 .28409 .47333 .26758 Mtetra
.679 .678 .842 r
.47333 .26758 .48316 .28409 .50082 .27593 .49104 .25939 Mtetra
.671 .675 .845 r
.49104 .25939 .50082 .27593 .51858 .26727 .50885 .25163 Mtetra
.667 .688 .86 r
.50885 .25163 .51858 .26727 .53642 .25841 .52676 .24426 Mtetra
.664 .712 .883 r
.52676 .24426 .53642 .25841 .55436 .25036 .54477 .23723 Mtetra
.656 .728 .902 r
.54477 .23723 .55436 .25036 .57241 .24296 .56291 .23065 Mtetra
.651 .743 .917 r
.56291 .23065 .57241 .24296 .59058 .23614 .58116 .2243 Mtetra
.656 .756 .923 r
.58116 .2243 .59058 .23614 .60888 .22978 .59954 .21772 Mtetra
.66 .754 .92 r
.59954 .21772 .60888 .22978 .6273 .22332 .61803 .21092 Mtetra
.659 .749 .917 r
.61803 .21092 .6273 .22332 .64583 .21655 .63665 .2041 Mtetra
.657 .749 .918 r
.63665 .2041 .64583 .21655 .66448 .20975 .65539 .19731 Mtetra
.653 .749 .92 r
.65539 .19731 .66448 .20975 .68326 .203 .67426 .19066 Mtetra
.652 .752 .923 r
.67426 .19066 .68326 .203 .70218 .19641 .69327 .18401 Mtetra
.657 .755 .922 r
.69327 .18401 .70218 .19641 .72122 .18979 .71239 .17711 Mtetra
.658 .752 .919 r
.71239 .17711 .72122 .18979 .74038 .1829 .73164 .17009 Mtetra
.653 .749 .92 r
.05457 .3988 .06607 .40891 .08117 .40359 .06973 .3934 Mtetra
.06973 .3934 .08117 .40359 .09638 .39817 .08498 .38798 Mtetra
.655 .751 .92 r
.08498 .38798 .09638 .39817 .11171 .39251 .10033 .38245 Mtetra
.66 .756 .921 r
.10033 .38245 .11171 .39251 .12712 .38688 .1158 .3767 Mtetra
.659 .755 .921 r
.1158 .3767 .12712 .38688 .1426 .38138 .13136 .37097 Mtetra
.655 .75 .92 r
.13136 .37097 .1426 .38138 .15817 .37592 .14699 .36536 Mtetra
.653 .748 .919 r
.14699 .36536 .15817 .37592 .17383 .37045 .16271 .35978 Mtetra
.652 .746 .919 r
.16271 .35978 .17383 .37045 .18961 .36478 .17852 .35421 Mtetra
.653 .75 .921 r
.17852 .35421 .18961 .36478 .2055 .3589 .19444 .34855 Mtetra
.66 .758 .922 r
.19444 .34855 .2055 .3589 .22146 .35323 .21049 .34258 Mtetra
.659 .753 .92 r
.21049 .34258 .22146 .35323 .23748 .34802 .22662 .33664 Mtetra
.652 .738 .912 r
.22662 .33664 .23748 .34802 .25357 .34315 .24284 .3309 Mtetra
.644 .719 .903 r
.24284 .3309 .25357 .34315 .26974 .33868 .25913 .32543 Mtetra
.638 .701 .891 r
.25913 .32543 .26974 .33868 .28599 .33463 .27552 .3201 Mtetra
.634 .678 .875 r
.27552 .3201 .28599 .33463 .30237 .33038 .29201 .31484 Mtetra
.631 .663 .862 r
.29201 .31484 .30237 .33038 .31889 .32578 .3086 .3096 Mtetra
.628 .653 .855 r
.3086 .3096 .31889 .32578 .33555 .32079 .32531 .30441 Mtetra
.633 .654 .852 r
.32531 .30441 .33555 .32079 .35235 .31539 .34214 .29894 Mtetra
.639 .656 .851 r
.34214 .29894 .35235 .31539 .36928 .30964 .3591 .29313 Mtetra
.645 .659 .849 r
.3591 .29313 .36928 .30964 .38633 .30355 .3762 .28696 Mtetra
.651 .662 .847 r
.3762 .28696 .38633 .30355 .4035 .29713 .39341 .28044 Mtetra
.656 .663 .845 r
.39341 .28044 .4035 .29713 .42079 .29034 .41074 .27357 Mtetra
.661 .665 .844 r
.41074 .27357 .42079 .29034 .4382 .28315 .42819 .26641 Mtetra
.66 .666 .845 r
.42819 .26641 .4382 .28315 .45571 .27554 .44574 .2593 Mtetra
.661 .675 .853 r
.44574 .2593 .45571 .27554 .47333 .26758 .46339 .2522 Mtetra
.662 .689 .865 r
.46339 .2522 .47333 .26758 .49104 .25939 .48115 .24516 Mtetra
.662 .709 .883 r
.48115 .24516 .49104 .25939 .50885 .25163 .49901 .23827 Mtetra
.657 .724 .898 r
.49901 .23827 .50885 .25163 .52676 .24426 .51699 .23164 Mtetra
.653 .738 .912 r
.51699 .23164 .52676 .24426 .54477 .23723 .53508 .2252 Mtetra
.651 .75 .922 r
.53508 .2252 .54477 .23723 .56291 .23065 .55329 .2188 Mtetra
.658 .758 .923 r
.55329 .2188 .56291 .23065 .58116 .2243 .57163 .21206 Mtetra
.659 .752 .919 r
.57163 .21206 .58116 .2243 .59954 .21772 .59008 .20523 Mtetra
.658 .748 .917 r
.59008 .20523 .59954 .21772 .61803 .21092 .60866 .19839 Mtetra
.657 .749 .918 r
.60866 .19839 .61803 .21092 .63665 .2041 .62736 .19158 Mtetra
.653 .749 .92 r
.62736 .19158 .63665 .2041 .65539 .19731 .64619 .18489 Mtetra
.652 .752 .923 r
.64619 .18489 .65539 .19731 .67426 .19066 .66515 .1782 Mtetra
.656 .755 .922 r
.66515 .1782 .67426 .19066 .69327 .18401 .68424 .17128 Mtetra
.658 .752 .919 r
.68424 .17128 .69327 .18401 .71239 .17711 .70345 .16423 Mtetra
.658 .75 .918 r
.70345 .16423 .71239 .17711 .73164 .17009 .72278 .15714 Mtetra
.656 .751 .92 r
.04294 .38864 .05457 .3988 .06973 .3934 .05816 .38311 Mtetra
.653 .749 .92 r
.05816 .38311 .06973 .3934 .08498 .38798 .07346 .37761 Mtetra
.07346 .37761 .08498 .38798 .10033 .38245 .08885 .37209 Mtetra
.655 .751 .92 r
.08885 .37209 .10033 .38245 .1158 .3767 .10435 .36647 Mtetra
.66 .756 .921 r
.10435 .36647 .1158 .3767 .13136 .37097 .11996 .36064 Mtetra
.659 .755 .921 r
.11996 .36064 .13136 .37097 .14699 .36536 .13567 .35478 Mtetra
.655 .75 .92 r
.13567 .35478 .14699 .36536 .16271 .35978 .15145 .34905 Mtetra
.654 .748 .919 r
.15145 .34905 .16271 .35978 .17852 .35421 .16733 .34334 Mtetra
.652 .746 .919 r
.16733 .34334 .17852 .35421 .19444 .34855 .1833 .33764 Mtetra
.653 .747 .919 r
.1833 .33764 .19444 .34855 .21049 .34258 .19937 .3319 Mtetra
.654 .753 .922 r
.19937 .3319 .21049 .34258 .22662 .33664 .21556 .32605 Mtetra
.66 .758 .923 r
.21556 .32605 .22662 .33664 .24284 .3309 .23186 .31995 Mtetra
.658 .752 .919 r
.23186 .31995 .24284 .3309 .25913 .32543 .24826 .31388 Mtetra
.655 .74 .912 r
.24826 .31388 .25913 .32543 .27552 .3201 .26475 .30788 Mtetra
.651 .728 .905 r
.26475 .30788 .27552 .3201 .29201 .31484 .28134 .30198 Mtetra
.648 .716 .897 r
.28134 .30198 .29201 .31484 .3086 .3096 .29802 .29613 Mtetra
.647 .706 .89 r
.29802 .29613 .3086 .3096 .32531 .30441 .31482 .29024 Mtetra
.647 .695 .881 r
.31482 .29024 .32531 .30441 .34214 .29894 .33173 .28427 Mtetra
.648 .689 .874 r
.33173 .28427 .34214 .29894 .3591 .29313 .34875 .27817 Mtetra
.65 .686 .871 r
.34875 .27817 .3591 .29313 .3762 .28696 .36589 .27192 Mtetra
.652 .687 .87 r
.36589 .27192 .3762 .28696 .39341 .28044 .38315 .26553 Mtetra
.654 .691 .872 r
.38315 .26553 .39341 .28044 .41074 .27357 .40052 .25901 Mtetra
.656 .699 .878 r
.40052 .25901 .41074 .27357 .42819 .26641 .418 .25241 Mtetra
.658 .71 .886 r
.418 .25241 .42819 .26641 .44574 .2593 .43559 .24576 Mtetra
.657 .719 .894 r
.43559 .24576 .44574 .2593 .46339 .2522 .4533 .23916 Mtetra
.655 .729 .904 r
.4533 .23916 .46339 .2522 .48115 .24516 .47111 .23265 Mtetra
.653 .74 .913 r
.47111 .23265 .48115 .24516 .49901 .23827 .48904 .22621 Mtetra
.652 .75 .921 r
.48904 .22621 .49901 .23827 .51699 .23164 .50709 .2198 Mtetra
.657 .757 .924 r
.50709 .2198 .51699 .23164 .53508 .2252 .52527 .21313 Mtetra
.659 .755 .921 r
.52527 .21313 .53508 .2252 .55329 .2188 .54356 .20634 Mtetra
.659 .749 .917 r
.54356 .20634 .55329 .2188 .57163 .21206 .56197 .19949 Mtetra
.658 .748 .917 r
.56197 .19949 .57163 .21206 .59008 .20523 .58051 .19265 Mtetra
.656 .749 .918 r
.58051 .19265 .59008 .20523 .60866 .19839 .59917 .18582 Mtetra
.652 .749 .921 r
.59917 .18582 .60866 .19839 .62736 .19158 .61796 .17912 Mtetra
.652 .753 .923 r
.61796 .17912 .62736 .19158 .64619 .18489 .63688 .17237 Mtetra
.657 .755 .923 r
.63688 .17237 .64619 .18489 .66515 .1782 .65592 .1654 Mtetra
.658 .752 .919 r
.65592 .1654 .66515 .1782 .68424 .17128 .67509 .15832 Mtetra
.658 .75 .918 r
.67509 .15832 .68424 .17128 .70345 .16423 .69439 .15119 Mtetra
.656 .75 .919 r
.69439 .15119 .70345 .16423 .72278 .15714 .71382 .1441 Mtetra
.659 .754 .921 r
.03116 .37848 .04294 .38864 .05816 .38311 .04644 .37276 Mtetra
.655 .751 .92 r
.04644 .37276 .05816 .38311 .07346 .37761 .0618 .36713 Mtetra
.654 .749 .92 r
.0618 .36713 .07346 .37761 .08885 .37209 .07725 .36153 Mtetra
.653 .749 .92 r
.07725 .36153 .08885 .37209 .10435 .36647 .09279 .35591 Mtetra
.655 .75 .92 r
.09279 .35591 .10435 .36647 .11996 .36064 .10843 .3502 Mtetra
.659 .755 .921 r
.10843 .3502 .11996 .36064 .13567 .35478 .12419 .34431 Mtetra
.659 .756 .921 r
.12419 .34431 .13567 .35478 .15145 .34905 .14005 .33835 Mtetra
.657 .752 .92 r
.14005 .33835 .15145 .34905 .16733 .34334 .156 .33245 Mtetra
.654 .749 .919 r
.156 .33245 .16733 .34334 .1833 .33764 .17204 .32661 Mtetra
.654 .747 .918 r
.17204 .32661 .1833 .33764 .19937 .3319 .18817 .32076 Mtetra
.653 .746 .918 r
.18817 .32076 .19937 .3319 .21556 .32605 .2044 .3149 Mtetra
.653 .747 .919 r
.2044 .3149 .21556 .32605 .23186 .31995 .22074 .309 Mtetra
.654 .753 .922 r
.22074 .309 .23186 .31995 .24826 .31388 .23718 .30302 Mtetra
.658 .757 .923 r
.23718 .30302 .24826 .31388 .26475 .30788 .25375 .29687 Mtetra
.658 .756 .922 r
.25375 .29687 .26475 .30788 .28134 .30198 .27042 .29065 Mtetra
.657 .751 .919 r
.27042 .29065 .28134 .30198 .29802 .29613 .28719 .28442 Mtetra
.656 .744 .915 r
.28719 .28442 .29802 .29613 .31482 .29024 .30406 .27819 Mtetra
.655 .739 .911 r
.30406 .27819 .31482 .29024 .33173 .28427 .32105 .27194 Mtetra
.655 .735 .908 r
.32105 .27194 .33173 .28427 .34875 .27817 .33814 .26566 Mtetra
.655 .733 .907 r
.33814 .26566 .34875 .27817 .36589 .27192 .35534 .25934 Mtetra
.35534 .25934 .36589 .27192 .38315 .26553 .37266 .25298 Mtetra
.655 .735 .908 r
.37266 .25298 .38315 .26553 .40052 .25901 .39009 .24658 Mtetra
.654 .739 .911 r
.39009 .24658 .40052 .25901 .418 .25241 .40763 .24017 Mtetra
.654 .744 .916 r
.40763 .24017 .418 .25241 .43559 .24576 .42528 .23375 Mtetra
.653 .749 .92 r
.42528 .23375 .43559 .24576 .4533 .23916 .44305 .22733 Mtetra
.654 .755 .924 r
.44305 .22733 .4533 .23916 .47111 .23265 .46094 .22082 Mtetra
.658 .757 .924 r
.46094 .22082 .47111 .23265 .48904 .22621 .47895 .21414 Mtetra
.658 .754 .921 r
.47895 .21414 .48904 .22621 .50709 .2198 .49708 .20738 Mtetra
.658 .749 .917 r
.49708 .20738 .50709 .2198 .52527 .21313 .51533 .20056 Mtetra
.658 .748 .916 r
.51533 .20056 .52527 .21313 .54356 .20634 .5337 .19372 Mtetra
.657 .748 .917 r
.5337 .19372 .54356 .20634 .56197 .19949 .5522 .18688 Mtetra
.655 .749 .919 r
.5522 .18688 .56197 .19949 .58051 .19265 .57082 .18008 Mtetra
.652 .75 .922 r
.57082 .18008 .58051 .19265 .59917 .18582 .58957 .17333 Mtetra
.653 .754 .924 r
.58957 .17333 .59917 .18582 .61796 .17912 .60844 .16651 Mtetra
.657 .755 .922 r
.60844 .16651 .61796 .17912 .63688 .17237 .62744 .15948 Mtetra
.658 .751 .919 r
.62744 .15948 .63688 .17237 .65592 .1654 .64657 .15236 Mtetra
.658 .75 .918 r
.64657 .15236 .65592 .1654 .67509 .15832 .66583 .1452 Mtetra
.656 .75 .919 r
.66583 .1452 .67509 .15832 .69439 .15119 .68522 .13806 Mtetra
.653 .75 .921 r
.68522 .13806 .69439 .15119 .71382 .1441 .70476 .131 Mtetra
.658 .753 .92 r
.01925 .36816 .03116 .37848 .04644 .37276 .03458 .36242 Mtetra
.659 .754 .921 r
.03458 .36242 .04644 .37276 .0618 .36713 .05001 .35661 Mtetra
.656 .751 .92 r
.05001 .35661 .0618 .36713 .07725 .36153 .06552 .35087 Mtetra
.654 .749 .92 r
.06552 .35087 .07725 .36153 .09279 .35591 .08111 .34516 Mtetra
.653 .749 .92 r
.08111 .34516 .09279 .35591 .10843 .3502 .0968 .33943 Mtetra
.654 .75 .92 r
.0968 .33943 .10843 .3502 .12419 .34431 .1126 .33363 Mtetra
.657 .754 .921 r
.1126 .33363 .12419 .34431 .14005 .33835 .1285 .32771 Mtetra
.659 .756 .922 r
.1285 .32771 .14005 .33835 .156 .33245 .14451 .32165 Mtetra
.659 .754 .921 r
.14451 .32165 .156 .33245 .17204 .32661 .16063 .31558 Mtetra
.656 .75 .92 r
.16063 .31558 .17204 .32661 .18817 .32076 .17682 .30958 Mtetra
.655 .749 .919 r
.17682 .30958 .18817 .32076 .2044 .3149 .19312 .30359 Mtetra
.654 .747 .918 r
.19312 .30359 .2044 .3149 .22074 .309 .20952 .29758 Mtetra
.654 .746 .918 r
.20952 .29758 .22074 .309 .23718 .30302 .22603 .29154 Mtetra
.654 .747 .918 r
.22603 .29154 .23718 .30302 .25375 .29687 .24264 .28547 Mtetra
.654 .749 .92 r
.24264 .28547 .25375 .29687 .27042 .29065 .25935 .27934 Mtetra
.655 .753 .922 r
.25935 .27934 .27042 .29065 .28719 .28442 .27618 .27315 Mtetra
.655 .755 .923 r
.27618 .27315 .28719 .28442 .30406 .27819 .29312 .2669 Mtetra
.656 .757 .924 r
.29312 .2669 .30406 .27819 .32105 .27194 .31017 .2606 Mtetra
.31017 .2606 .32105 .27194 .33814 .26566 .32733 .25425 Mtetra
.32733 .25425 .33814 .26566 .35534 .25934 .3446 .24786 Mtetra
.3446 .24786 .35534 .25934 .37266 .25298 .36199 .24141 Mtetra
.36199 .24141 .37266 .25298 .39009 .24658 .37949 .23492 Mtetra
.657 .757 .924 r
.37949 .23492 .39009 .24658 .40763 .24017 .39711 .22837 Mtetra
.657 .756 .923 r
.39711 .22837 .40763 .24017 .42528 .23375 .41484 .22176 Mtetra
.657 .754 .921 r
.41484 .22176 .42528 .23375 .44305 .22733 .43269 .21509 Mtetra
.658 .751 .919 r
.43269 .21509 .44305 .22733 .46094 .22082 .45066 .20835 Mtetra
.658 .748 .917 r
.45066 .20835 .46094 .22082 .47895 .21414 .46874 .20157 Mtetra
.657 .747 .916 r
.46874 .20157 .47895 .21414 .49708 .20738 .48695 .19476 Mtetra
.657 .748 .917 r
.48695 .19476 .49708 .20738 .51533 .20056 .50528 .18793 Mtetra
.656 .749 .918 r
.50528 .18793 .51533 .20056 .5337 .19372 .52373 .1811 Mtetra
.653 .749 .92 r
.52373 .1811 .5337 .19372 .5522 .18688 .54231 .17433 Mtetra
.653 .752 .923 r
.54231 .17433 .5522 .18688 .57082 .18008 .56101 .16753 Mtetra
.655 .755 .923 r
.56101 .16753 .57082 .18008 .58957 .17333 .57984 .1606 Mtetra
.657 .754 .921 r
.57984 .1606 .58957 .17333 .60844 .16651 .5988 .15352 Mtetra
.658 .751 .919 r
.5988 .15352 .60844 .16651 .62744 .15948 .61788 .14636 Mtetra
.657 .75 .918 r
.61788 .14636 .62744 .15948 .64657 .15236 .6371 .13917 Mtetra
.656 .75 .919 r
.6371 .13917 .64657 .15236 .66583 .1452 .65645 .132 Mtetra
.653 .75 .921 r
.65645 .132 .66583 .1452 .68522 .13806 .67594 .12489 Mtetra
.654 .753 .922 r
.67594 .12489 .68522 .13806 .70476 .131 .69557 .11769 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
[(-2)] .12586 .2075 1 .99877 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.56863 .04703 m
.57247 .05235 L
s
[(2)] .56094 .0364 .72324 1 Mshowa
.125 Mabswid
.18558 .19702 m
.18832 .19985 L
s
.23703 .17687 m
.23971 .17975 L
s
.28951 .15632 m
.29214 .15925 L
s
.39772 .11395 m
.40023 .11699 L
s
.4535 .09211 m
.45595 .0952 L
s
.51046 .06981 m
.51284 .07294 L
s
.08568 .23614 m
.08851 .23887 L
s
.62804 .02377 m
.63027 .02701 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 233.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00o?ooool2o`0006[ooooo003iooooo`?o000000?oooooo`000?ooool0
JOooool00?Oooooo0_l00004ooooo`;o0000JOooool00?Cooooo0ol00006ooooo`03o`000?oooooo
000006Sooooo003;ooooo`Go00008_ooool2o`0000Wooooo00?o0000ooooool00000J?ooool00<_o
oooo00GoV9RHob4Q8Oo^k^koooooodA4A00Oooooo`?o00002oooool01?l0003oooooooooool0001W
ooooo`00c?ooool00onHV9So8B4Qonk^kP0Mooooo`?o00003_ooool01Ol0003ooooooooooooooooo
000006Kooooo003=ooooo`03oiRHV?lQ8B7ok^k^01[ooooo0_l0000Aooooo`05o`000?oooooooooo
ooooool00000I_ooool00<kooooo00?oMgMgofIVI_ooool05_ooool3o`0001?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1Sooooo`00coooool00ol0003oooooooooo`0Cooooo`;o
00000_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0H_ooool00<_ooooo00Go0000okZj^_ooooooV9RHoa0@400Booooo`?o00006Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo06;ooooo003;ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`04?ooool2o`0001cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Qooooo`00
gOooool3o`0001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Qooooo`00fooo
ool2o`00027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Pooooo`00f?ooool3
o`0002?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Oooooo`00eOooool3o`00
02Kooooo00?o0000ooooooooool01?ooool2o`00067ooooo003Cooooo`;o0000:Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo05kooooo003@ooooo`?o000000?oooooo`000?ooool0
:?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05gooooo003>ooooo`;o00001Ooo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0GOoo
ool00<_ooooo0ol0000`ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0G?ooool0
0<Wooooo0_l0000cooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Foooool00<Ko
oooo0ol0000eooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Foooool00<Cooooo
0_l0000hooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0F_ooool00<7ooooo0ol0
000jooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03_ooool5o`0004Kooooo002n
ooooo`?o0000?Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00kooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A016ooooo`00_?ooool2o`0000?ooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo1_l00003ooooo`03oiRHV?lQ8B7o
k^k^04Oooooo002iooooo`?o0000@oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00kooooo00?oV9RHob4Q8Oo^k^h0A_ooool00;Oooooo0_l00016ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03oooool00omgMgOoIVIVooooo`15ooooo`00]?ooool3o`0004Sooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Cooooo
002booooo`;o0000Boooool00ol0003oooooooooo`0=ooooo`;o00003?ooool01Ol0003o^[Zjoooo
oonHV9So410@04Kooooo002_ooooo`?o0000COooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c016ooooo`00[Oooool2o`00053ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`1Dooooo`00Z_ooool4o`00057ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1Dooooo`00Z?ooool2o`0000Cooooo00?o0000oooo
ooooool0C_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05?ooooo001nooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h08_ooool3o`0005Oooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`1Booooo`00O_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01oooooo0ol0001Joooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool0D_ooool007kooooo00Go410@oooooooo
oooooooooa0@400Mooooo`;o0000GOooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
057ooooo001nooooo`05o`000?ooooooooooooooool000006_ooool3o`0005oooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`1@ooooo`00O_ooool01Ol0003ooooooooooooooooo0000
01Sooooo0_l0001Rooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0D?ooool007ko
oooo00Go410@oooooooooooooooooa0@400Eooooo`?o0000I?ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo04oooooo001nooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool2o`00
00?ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
04kooooo001nooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04?ooool3o`0006Sooooo00?oYl3/o`00
0?ooool05_ooool00ol0003oooooooooo`1>ooooo`00TOooool2o`0006Sooooo1?nW`>`00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo04gooooo002>ooooo`?o0000J?ooool7ojO0k003o`00
0?oooooooooo01Cooooo0ol0001>ooooo`00Roooool3o`0006Wooooo0_nW_n/7ojO0k003o`000?oo
oooooooo01Kooooo00?o0000ooooooooool0C?ooool008Wooooo0_l0001Yooooo`KoYko[1_nW`>`0
0ol0003oYl3/ooooo`0Gooooo`03o`000?oooooooooo04_ooooo0026ooooo`?o0000J?ooool:ojNo
j`GoYl3/00?o0000ojNojoooool06?ooool00ol0003oooooooooo`1:ooooo`00Q?ooool2o`0000;o
oooo00?o0000ooooooooool0Hoooool>ojNoj`;oYl3/0_nW_n/00ol0003oYko[ojNoj`0Hooooo`03
o`000?oooooooooo04[ooooo0021ooooo`?o00001Oooool00ol0003oooooooooo`1PoooooaCoYko[
00Co0000ojNojonW_n_oYko[6?ooool00ol0003oooooooooo`19ooooo`00Ooooool2o`0006Wooooo
00?oZ;o[ojNojonW_n/04onW_n/00ol0003oYko[ojNoj`02ojNojaSooooo00?o0000ooooooooool0
B?ooool007cooooo0ol0001Xooooo`GoZ;o[5?nW_n/00ol0003oYko[ojNoj`02ojNojaSooooo00?o
0000ooooooooool0B?ooool007[ooooo0_l0001Wooooo`;oZ<3[2?nX_n/6ojNoj`;oZ;o[2onW_n/0
0ol0003oYko[ojNoj`03ojNojaSooooo00?o0000ooooooooool0Aoooool007Oooooo0ol0001Voooo
o`KoZ<3[2?nX_n/2ojNoj`KoZ;o[2_nW_n/00ol0003oYko[ojNoj`04ojNojaSooooo00?o0000oooo
ooooool0A_ooool007Cooooo0ol0001Vooooo`03ojS1jonX`>_oZ<3[00OoZ<3[1_nX_n/2ojS0j`So
Z;o[1_nW_n/2ojRoj`03ojNojol0003oYko[00GoYko[6?ooool00ol0003oooooooooo`16ooooo`00
L_ooool2o`0000;ooooo00?o0000ooooooooool0H_ooool4ojS1j`WoZ<3[0_nX_n/6ojS0j`SoZ;o[
0_nW_n/6ojRoj`03o`000?nW_n_oYko[00GoYko[6?ooool00ol0003oooooooooo`15ooooo`00Kooo
ool3o`0006Oooooo1onX`N/7ojS0j`03ojS1k?nX`>_oZ<3[00OoZ<3[1_nX_n/00onX`>_oZ;o[ojRo
j`06ojRoj`03o`000?nW_n_oYko[00CoYko[00?oZ;o[ooooooooool05_ooool00ol0003ooooooooo
o`15ooooo`00KOooool2o`0006Oooooo0_nW`N`8ojS1j`CoZ<3[1OnX`N`9ojS0j`;oZ;o[1OnX`>/7
ojRoj`04o`000?nX_n_oYko[ojNoj`GoZ;o[5oooool2o`0004Kooooo001Zooooo`?o0000I_ooool6
ojO1k0SoZ<7[00?oZ<3[ojS1k?nX`N`01_nX`N`7ojS0j`03ojS1k?nX`>_oZ<3[00KoZ<3[1_nX_n/0
0ol0003oZ<3[ojRoj`07ojRojaSooooo00?o0000ooooooooool0@oooool006Sooooo0_l0001Voooo
o`;oYl3/2?nW`N`6ojS1j`;oYl7/2?nX`N`4ojS0j`GoZ<7/2?nX`>/2ojRoj`?oZ<3[00?o0000ojS0
jonX`>/02?nX_n/Gooooo`03o`000?oooooooooo04?ooooo001Uooooo`?o0000IOooool6ojO0k0So
Yl7/0_nX`N/6ojO1k0SoZ<7/00?oZ<3[ojS1k?nX`N`01_nX`N`6ojS0j`03ojO1k?nX`>_oZ<3[00?o
Z<3[00Co0000ojS0jonX`>_oZ<3[1_nX_n/00onX`>_oooooooooo`0Fooooo`03o`000?oooooooooo
04;ooooo001Sooooo`;o0000IOooool00onW_n_oYl3/ojO0k007ojO0k0KoYl7/00?oY[o/ojO1k?nW
`N`01onW`N`6ojS1k003ojK0k?nX`NcoZ<7/00OoZ<7/1?nX`>/4ojO1k0GoZ<3[00Co0000ojS0jonX
`>_oZ<3[0_nX_n/5ojS0jaSooooo00?o0000ooooooooool0@Oooool0063ooooo0ol000000ooooooo
0000ooooo`1Rooooo`CoYko[2OnW`>`2ojO1k0GoY[o/2OnW`N`2ojS1k0GoY/3/2OnX`N`00onX`>_o
Yl7/ojO1k005ojO1k0CoZ<3[00Co0000ojS0jonX`>_oZ<7/2?nX`>/Gooooo`03o`000?oooooooooo
047ooooo000fooooo`Go00008oooool2o`0006Kooooo1onW_n/7ojO0k003ojNojonV_ncoY[o/00Ko
Y[o/1_nW`N`2ojJoj`SoY/3/1_nX`N`2ojK0k0SoYl7/1?nX`>/00ol0003oZ<7/ojS1k002ojS1k0So
Z<3[5oooool00ol0003oooooooooo`10ooooo`00=_ooool01OnHV9So8B4Qonk^k_ooooooA4A4023o
oooo0ol0001Uooooo`[oYko[1?nW`>`5ojNoj`SoY[o/0_nW`N`6ojJoj`SoY/3/0_nX`N`6ojK0k0So
Yl7/00CoZ<3[ojS1k?nX`Nco00001OnX`N`6ojS0j`03ojS1jooooooooooo01Kooooo00?o0000oooo
ooooool0?oooool002kooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^01kooooo0ol0001Uooooo`ko
Yko[00?oYl3/ojNojonW_n/01_nW_n/6ojJok003ojNojonV_n_oY[o[00OoY[o[1_nV`>`00onW_n_o
Y/3/ojK0k007ojK0k0KoYl7/00GoY/3/ojS1k?nX`NcoZ<7/o`000005ojS1k0CoZ<3[1?nX`N/Goooo
o`03o`000?oooooooooo03oooooo000hooooo`03oiRHV?lQ8B7ok^k^01_ooooo0_l0001Uooooo`;o
Z;oZ3_nW_n/2ojRojPSoYko[1?nV_n`4ojNoj`WoY[o[0_nV`>`5ojNoj`WoY/3/0_nW`N`5ojK0k0;o
Z<7/00?o0000ojS1k?nX`N`01?nX`N`00onX`>_oZ<7[ojS1j`05ojS1jaOooooo00?o0000oooooooo
ool0?_ooool003Wooooo00?oMgMgofIVI_ooool05oooool3o`0006Cooooo1_nX_nX:ojNoj`KoZ;oZ
2?nW_n/00onV_ncoYko[ojNoj`05ojNoj`OoY[o[00?oZ;o[ojNojonW_n/01_nW_n/6ojK0k0;oYko[
2?nV`>`00onX`Nco0000ojS1k003ojS1k0;oY/3/2?nX`N/Hooooo`03o`000?oooooooooo03gooooo
000jooooo`03o`000?oooooooooo01Cooooo0_l0001Tooooo`[oZ;oZ1_nW_n/:ojRojPKoYko[00?o
Z;oZojNojonW_n/01onW_n/4ojJoj`CoZ;o[2?nW_n/2ojK0k0KoYko[2?nV`>`00ol0003oZ<7/ojK0
k005ojK0k0SoZ<7[5oooool00ol0003oooooooooo`0mooooo`00=_ooool01Ol0003o^[ZjoooooonH
V9So410@01?ooooo0ol00002ooooo`03o`000?oooooooooo05oooooo3OnX_nX2ojNoj`koZ;oZ0_nW
_n/5ojRojPWoYko[00?oY[o[ojRojonX_n/01OnX_n/6ojNoj`03ojRojonW_n_oYko[00OoYko[1_nV
`>`00onV_n_o0000ojK0k007ojK0k0KoZ<7[00?oYl3/ooooooooool05_ooool00ol0003ooooooooo
o`0looooo`00=_ooool01OnHV9So410@o`000?lQ8B7oc<c<017ooooo0_l0001UooooobOoZ;oZ1_nW
_n/2ojRojPSoZ;o[1?nW_n/4ojRoj`WoYko[0_nV`>`4ojJoj`03o`000?nV`>coY/3/00OoY/3/0_nX
`N/5ojO0k1Kooooo0ol0000mooooo`00BOooool3o`0006Gooooo:_nX_nX2ojNoj`KoZ;oZ2?nX_n/0
0onW_n_oZ;o[ojRoj`05ojRoj`KoYko[0_nX_n/6ojJoj`03o`000?nV_n_oY/3/00GoY/3/0_nV_n/8
ojO0k1Oooooo00?o0000ooooooooool0>oooool004Oooooo0_l0001UoooooacoZ;oZ00?oZ<7[ojRo
j_nX_nX03OnX_nX00onX`>_oZ;oZojRojP07ojRojPKoZ;o[00?oZ;oZojRojonX_n/01onX_n/2ojNo
j`KoZ;o[1OnV_n/00ol0003oY[o[ojJoj`02ojK0k0KoY[o[2?nW`>`Gooooo`03o`000?oooooooooo
03[ooooo0014ooooo`?o0000I?ooool00onX`>_oZ;oZojRojP0<ojRojP;oZ<7[3?nX_nX4ojS1j`_o
Z;oZ1OnX`>/9ojRojP;oZ;o[1OnX_nX7ojRoj`03ojRoj_nX_n_oZ;o[00OoZ;o[1?nV_n/00ol0003o
Y[o[ojRoj`09ojJoj`KoYl3/00?oY[o/ooooooooool05_ooool00ol0003oooooooooo`0iooooo`00
@Oooool3o`0006Cooooo1OnX`>/:ojRojPKoZ<7[2OnX_nX7ojS1j`OoZ;oZ00?oZ<;/ojS0jonX`>/0
1_nX`>/6ojRojP;oZ<7[2?nX_nX4ojRoj`CoZ;oZ2OnX_n/2ojJoj`03ojRojol0003oZ;o[00;oZ;o[
2OnV_n/2ojO0k0GoY[o/5oooool00ol0003oooooooooo`0iooooo`00?oooool3o`0006?ooooo00?o
Z<7[ojS0jonX`>/01_nX`>/6ojRojP;oZ<7/2?nX`N/6ojRojP;oZ<7/2?nX`N/4ojRojPCoZ<;/2?nX
`>/2ojRojPKoZ<7[2?nX_nX00onX_n_oZ;oZojRojP05ojRojPOoZ;o[00GoZ;oZojRojonX_n_oZ;o[
o`000004ojRoj`KoY[o[0_nW_n/8ojJok1Oooooo00?o0000ooooooooool0>?ooool003cooooo0ol0
0003ooooo`03o`000?oooooooooo05kooooo1?nX`N/8ojS0j`;oZ;oZ1_nX`N`8ojS1j`;oZ;oZ1_nX
`N`8ojS1j`03ojRoj_nX`^coZ<;/00GoZ<;/1_nX`>/2ojO1k0SoZ<7[1_nX_nX00onX`N_oZ;oZojRo
jP07ojRojPCoZ;o[1?nX_nX2ojRoj`03o`000?nX_n_oZ;o[00?oZ;o[0_nV_n/6ojNoj`SoY[o/5_oo
ool00ol0003oooooooooo`07ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0;?ooool003[ooooo0_l0
001Uooooo`OoZ<7[1_nX`>/2ojO1k0SoZ<7/1_nX`N/00onV_n_oZ<7/ojS1k007ojS1k0KoZ<7[00?o
Y[o/ojS2k?nX`^`01onX`^`2ojS0j`KoYl7/2?nX`N/2ojRojPGoZ<7[2OnX_nX00onX_n_oZ;oZojRo
jP05ojRojP03ojRojol0003oZ;o[00?oZ;o[00?oZ;oZojNojonW_n/01onW_n/6ojJok003ojNojooo
oooooooo01Gooooo00?o0000ooooooooool01_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02cooooo
000gooooo`?o0000IOooool00onX`NcoZ<7[ojS1j`07ojS1j`;oZ<3[1_nW`N`8ojS1k0;oZ<7[1OnV
_n/9ojS1k0;oZ<7[1OnV_n`7ojS2k003ojJnj_nW`NcoYl7/00OoYl7/1_nX`N/00onW`>coZ<7[ojS1
j`06ojS1j`KoZ;oZ0_nX`N/8ojRojP;oZ;o[00?o0000ojRojonX_nX00onX_nX9ojNoj`;oY[o/1OnW
_n/Gooooo`03o`000?oooooooooo00Gooooo00Go410@oooooooooooooooooa0@400/ooooo`00=Ooo
ool2o`0006Gooooo1OnX`N`7ojS1j`;oYko[2?nW`N`6ojS1k003ojNmjOnV_n_oY[o[00KoY[o[1_nX
`N`2ojNlj@SoY[o/1?nX`^`4ojJnjPWoYl7/0_nX`N/5ojO0k0SoZ<7[0_nX_nX6ojS1j`SoZ;oZ00?o
Z;o[o`000?nX_nX01OnX_nX6ojNoj`;oZ;o[2?nW_n/Fooooo`03o`000?oooooooooo00Gooooo00Go
0000ooooooooooooooooo`00000/ooooo`00<_ooool3o`0006Cooooo2OnX`N`4ojS1j`GoYko[2?nW
`N`2ojS1k0GoYkgY2?nV_n/2ojS1k0KoYkcY2?nV_n`00onX`^coY[kZojJnjP05ojJnjPKoYl7/0_nV
_NT8ojO0k0KoZ<7[00?oYl3/ojS1jonX`N/01onX`N/6ojRojP03ojS1jonX_n[o000000OoZ;oZ0_nW
_n/6ojRoj`SoYko[5_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000
;?ooool0033ooooo0_l0001Tooooo`goZ<7/00?oZ<7[ojNojonW_n/01_nW_n/6ojO1k003ojNjionW
_NWoYkgY00KoYkgY1_nV_n/2ojRii@SoYkcY1_nV_n`00onW^^KoY[kZojJnjP07ojJnjP;oYl7/1_nV
_NT8ojO0k0;oZ<7[1OnW`>`9ojS1j`;oZ;oZ1OnX`N/00ol0003oZ;oZojRojP04ojRojP03ojW0j_nX
_n_oZ;o[00KoZ;o[1_nW_n/2ojRojaOooooo00?o0000ooooooooool00oooool01Ol@413ooooooooo
oooooooo410@02cooooo000]ooooo`?o000000?oooooo`000?ooool0H?ooool00onW`NcoZ<7/ojS1
k00<ojS1k0;oYkkZ2OnW_n/2ojO1k0GoYk[W2?nW_NT2ojJoj`KoZ;WU2?nW_>T2ojJok0GoYk[V1onV
_^X00onY^NGoY[gYojJmj@07ojJmj@KoYl3/00?oYkcYojO0k?nW`>`01_nW`>`6ojS1j`;oYl7/1onX
`N/00ol0003oZ;oZojRojP02ojRojPCoZL3Z2?nX_n/2ojNoj`KoZ;o[5_ooool2o`0000Cooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0/ooooo`00:_ooool3o`0006?ooooo1OnW`N`:ojS1k0KoYkkZ1onW
_n/00onX^>CoYk[WojNji`06ojNji`KoYkgY00?oZKGRojRiiOnX^ND01onX^ND6ojNlj@03ojVfh_nW
^^KoYk[V00KoYk[V1?nV_^X4ojVii@WoY[gY0_nW`>`5ojNlj@SoYl3/0_nX`N/6ojO1k0KoZ<7[00?o
0000ojS1jonX_nX01onY`>X6ojRoj`03ojS0j_nX_n_oZ;o[00OoZ;o[4oooool2o`000003ooooool0
003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0/ooooo`00:?ooool2o`0006?ooooo2OnW
`N`6ojS1k0;oYkgY2?nW_^X4ojNoj`CoZ;ST1onW^^L4ojNmj@CoZKGR2OnX^ND2ojNlj@GoZKKR2?nW
^^H00onV_^[oZKWUojVii@05ojVii@OoY[gY00?oZ[WTojNljOnW_>T01_nW_>T6ojO0k003ojJmjOnW
`NcoYl7/00OoYl7/1OnX`N/00ol0003oZ<7/ojW0jP07ojW0jPCoZ;o[1?nX`>X9ojRojaKooooo00?o
0000ooooooooool0<_ooool002Gooooo0ol0001Rooooo`goYl7/0_nX`N`6ojNmj@SoYkkZ00?oYko[
ojRhi?nX^>@01OnX^>@7ojNji`03ojNmjOnY]N;oZKGR00GoZKGR1onX^ND00onZ/=coZKKRojVfhP06
ojVfhPKoYk[V00?oZk?NojViiOnY^ND01onY^ND4ojJmj@CoZ[WT2?nW_>T2ojO0k0GoY[gY2OnW`N`2
ojS1j`03ojS1k?l0003o000000;oZ<7/2?nY`>X00onX_n_oZ<3ZojS0jP05ojS0jPSoZ;o[5_ooool0
0ol0003oooooooooo`0booooo`008oooool2o`0006;ooooo3onW`N`2ojNlj0SoYkgY1_nW_^X00onX
]N;oZ;STojRhi006ojRhi0KoYk[W0_nY/=d8ojVehPCoZ;WU1?nZ/=`8ojVfhP;oYk[V1On[/mh9ojVi
i@03ojJmjOnZ^NCoZ[WT00GoZ[WT1_nW_>T00on[^NCoY[gYojJmj@06ojJmj@KoYl7/0_nV_NX3o`00
0003ojS1k?l0003oZ<7/00;oZ<7/1_nY`>X00onX`NcoZ<3ZojS0jP07ojS0jPSoZ;o[5_ooool00ol0
003oooooooooo`0aooooo`008?ooool3o`0006;ooooo3_nW`N`6ojNlj0SoYkgY0_nW_^X5ojRehPSo
Z;ST0_nW^^L6ojV`g@SoZKGR00?oZ;WUojZ`g?nZ/=`01OnZ/=`6ojVfhP03ojf^f?n[/mkoZk?N00Ko
Zk?N1_nY^ND2ojfbg0SoZ[WT1?nW_>T4oj^ii0SoY[gY0_nW`N`2ojJmjP?o000000?oY[gZojS1k?nX
`N`00_nX`N`01?l0003oZ<7/ojS1k?nX`N`2ojW0jPGoZ<7/1onX`>X00onY`>_oZ;o[ojRoj`06ojRo
jaOooooo00?o0000ooooooooool0<?ooool001oooooo0_l0001Rooooo`goYl7/0_nW^nP8ojNlj0Ko
YkgY00?oYk;PojReh_nX]N801_nX]N86ojRhi003ojV/f_nY/=goZK3M00OoZK3M1_nY]N800on[[=So
Z[3LojZ`g006ojZ`g0CoZKKR1?n][]P8oj^cgP;oZKWU1_n]/]`8ojZii003ojNljOn[^NCoZkWT00Go
ZkWT1_nV_NT00onZ^^GoY[gZo`000002o`0000CoY[gZ1OnX`N`00ol0003oY[o[ojJoj`08ojS1k0Co
Z<3Z1?nY`>/8ojRojaKooooo00?o0000ooooooooool0<?ooool001oooooo00?o0000ooooool00000
Goooool<ojO1k0KoYk_X2?nW_>P2ojNmj@GoYk;P2?nX]N82ojRhi0GoZJcJ2OnY/=d2ojVehPGoZjcH
2?nZ/=`00onY]^;o[JkHojf^f005ojf^f0KoZk?N00?o/K7Hojfbg?n]/]`01on]/]`6ojZii003ojjb
fon[^NCoZkWT00OoZkWT0_nV_NT2ojZji@?o00002?nV_NX2ojS1k0?oY[o[00?o0000ojJojonV_n/0
2?nX`N`00onX`>[oZL3[ojW0j`05ojW0j`KoZ;o[00?oZ<3Zooooooooool05Oooool00ol0003ooooo
ooooo`0_ooooo`003?ooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`04o`00
0?ooooooooooo`0005_ooooo3?nW`N`:ojNkj0KoYkcX00?oYk3OojNbh?nW/^001_nW/^06ojRehP03
ojRZf?nY[=[oZJcJ00KoZJcJ1onY/=d00on][MOoZjcHoj^/f006oj^/f0KoZ[3L00?o/;3Gojf^f?n]
[]P01_n][]P4oj^cgPCo/K7H2On]/]`2ojZii0Go[[;K1on[^N@00on^]=coZ[[Uo`000002o`0000Co
Z[[U1_nV_NX00onY_>OoY[o[ojJoj`03ojJoj`04o`000?nV_n_oY[o[ojJoj`KoZ<7/00?oYl3/ojW0
jonY`>/01onY`>/2ojRoj`GoZ<3Z5oooool00ol0003oooooooooo`0^ooooo`003?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`;o00000_ooool0
0ol0003oooooooooo`1Eooooo`coYl7/3_nW^nP2ojNlj0GoYk3O1onW/^04ojRehPCoZ:[H2?nY[=X4
ojV`g@Co[JgG1on[[=P4ojZ`g0Co/;3G2?n][]P00on[/mko/K7Hok6af005ok6af0Oo[K;L00?o];?H
ojjbfon^/]/01_n^/]/4oj^ii004ojjdg?l0003o0000o`0000SoZ[[U0_nV_NX5ojVli`GoY[o[00Co
0000ojJojonV_n_oY[o[0_nX`N`5ojO0k0OoZL3[00?oZ<7/ojS0j_nX`>X01_nX`>XFooooo`03o`00
0?oooooooooo02kooooo0004ooooo`Ko00000oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?oo
ooooooooooooool@41001Oooool2o`0000Cooooo00?o0000ooooooooool0DOooool=ojO1k003ojNl
j?nW^nSoYk_X00coYk_X00?oYZoNojN`gonW/=l01_nW/=l7ojNbh003ojReh_nXZ]SoZ:[H00GoZ:[H
2?nY[=X00onY/=go[JgGojf]e`04ojf]e`SoZjcH00?oZ[3Lok2`eon`/=L01?n`/=L7ojf^f003ok>d
fOna/MSo/K7H00Ko/K7H1_n]/]`3okBcf0So[[;K00CoZkWTo`000?l0003o00001?n^]=`6ojZji@03
ojjfgonY_>OoZKcW00KoZKcW1OnV_n/00ol0003oYkgYojNmj@08ojO0k0CoZL3[1?nX`N`8ojS0jQKo
oooo00?o0000ooooooooool0;Oooool000kooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooo
oooooooooooo000000Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1=ooooo`ko
Yl7/1?nW_>P;ojNkj0CoYZoN1onW/=l6ojNbh003ojVZf?nXZ]SoZ:[H00KoZ:[H1onY[=X00on][]So
[JgGojf]e`06ojf]e`KoZjcH00?o/K;Iok2`eon`/=L01_n`/=L5ojf^f0?o/kCI2?na/MP3ojfbg0Ko
];?H1_n^/]/2o`0000Oo[[CL1?nZ^^D4ojjfg`SoZKcW0_nV_n/2ojNmj@04o`000?nW_NWoYkgYojNm
j@SoYl3/00?oZL3[ojS1k?nX`N`01OnX`N`6ojS0jP03ojW0jooooooooooo01Gooooo00?o0000oooo
ooooool0;?ooool000oooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo0000
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`19ooooo`ooYl7/1onW_>P8ojNk
j0KoYZoN2?nW/=l2ojNbh0GoZJ[H2?nXZ]P4ojV/fPCo[JkH1on][ML4oj^/f0Co/K;I1on`/=L3ojf^
f0Ko/kCI2?na/MP00on]/]co];?HokBcf005okBcf0?o[[;K0ol00002okJef0So[[CL00?oZ[[Uojjf
gon^]]l01On^]]l6ojVli`03ojjjhonW_NWoYkgY00?oYkgY00?o0000ojNmjOnW_NT01_nW`>`3ojJn
j`SoZ<7/0_nX`>X5ojW0jaGooooo0_l0000^ooooo`004?ooool01Ol0003ooooooooooooooooo410@
00?ooooo00?o410@ooooooooool00oooool2o`0000Oooooo00?o0000ooooooooool0A_ooool00onW
`>coYl7/ojO1k00<ojO1k003ojNmjOnW_>SoYkcX00KoYkcX1_nW^nP9ojJ_gPKoYk3O00?oYjWHojVZ
f?nYZ]P01_nYZ]P8ojRZf003ojV/f_n][]So[JkH00Co[JkH2?n][ML00on[[=So/K;Iok6bf@04ok6b
f@So/;3G00?o[JkHok>dfOnc]=T01Onc]=T7ok6af003okJhf_nd/mSo];?H00Ko];?H0ol00006okJe
f0Ko[[CL00?o][KIojjfgon^]]l01on^]]l2ojVli`Go[[[S1OnW_NT00ol0003oYkgYojNmj@02ojO0
k0OoY[k[1_nX`N`00onW`>coZL3[ojW0j`06ojW0jaKooooo00?o0000ooooooooool0:oooool000co
oooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo04;ooooo1OnW`>`:ojO1k0GoYkgY2?nW_>P2
ojNkj0coYZoN1?nW/=l4ojNYf0SoZJ[H1_nXZ]P00on//=_o[JkHojf^f006ojf^f0Ko[JgG00?o/;ON
ok6bfOna/]T01_na/]T6ok2`e`03ok>ig_nc]=Wo/kCI00Oo/kCI1?na/MP4okJhfPCo];?H0ol00000
0onh^]_o][GHokJef006okJef0Co[[CL1?nf]]T7ojjfg`03okFgfon^^^?o[[[S00Ko[[[S1OnW_NT0
0ol0003oZkcVojJnj`09ojJnj`;oZ<7/1OnW`>`8ojW0jaGooooo00?o0000ooooooooool0:oooool0
00cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03kooooo0_nW_n/7ojO0k0KoYl7/0_nW
_^X7ojNmj@KoYkcX00?oYK3OojJ_g_nV[mh03OnV[mh00onW/=ooYjWHojNYf005ojNYf0SoZJ[H0_nX
Z]P5ojb`f`Oo[JkH1?n][ML4ok2ggPOo/K;I1?n`/=L4ok>igPWo/kCI00?o/K7HokJhf_nf^=X01Onf
^=X3o`0000;o];?H0onh^]/8okJef003ojjdg?nf]]Wo][KI00Go][KI1On^]]l3okFgf`So[[[S0_nW
_NT2oj^liP03o`000?n[_>KoZkcV00SoY[k[00?oYkkYojO0k?nW`>`01_nW`>`6ojW0j`03ojW1jooo
oooooooo01Cooooo00?o0000ooooooooool0:_ooool001kooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0jooooo`KoYko[1onW`>`2ojO1k0KoYkkZ1onW_NT2ojNlj0GoYK3O3OnV[mh0
0onVZMSoYjWHojNYf006ojNYf0OoZJ[H00?oZk;Mojb`fon//=/01_n//=/7ojf^f003ojf]eon`]mko
/;ON00Go/;ON1ona/]T00on`/=Oo/kWNok>igP05ok>igPOo/kCI00?o];oRokJhf_nf^=X00onf^=X3
o`0000?o];?H1Onh^]/7okJef003okVkfonf]]Wo][KI00Ko][KI0on^]]l6okFgf`Ko[[[S00?o/[SN
oj^li_n[_>H00on[_>H00ol0003oZkcVoj^liP04ojJnj`GoYkkY2?nW`>`2ojW0j`GoZL7[5_ooool0
0ol0003oooooooooo`0Yooooo`007Oooool3o`0000_ooooo00?o0000ooooooooool0=_ooool:ojNo
j`GoYl3/0_nX`>/8ojNnjPGoYkgY00?oYK7QojF`gonU/=l01_nU/=l9ojJ_gPGoYZWH2?nWZMP4ojVZ
f0CoZk;M1on//=/6ojf^f003ojjmi?n`]mko/;ON00Ko/;ON1_na/]T00ona`nSo/kWNok>igP06ok>i
gPCo/kCI1Ond_n801?nf^=[o0000o`000?l00004okJhfP03okBcf?nh^]_o^;[K00Go^;[K1Onf]MP3
okVkf`So][KI00?o[[KOokFgfone]m/01One]m/4ojjjh`Co/[SN1On[_>H01?l0003oZkcVoj^li_nV
_^/7ojNnj@KoYl3/0_nV_n`7ojW1jaKooooo00?o0000ooooooooool0:Oooool001gooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0booooo`koYko[00?oYl3/ojS0jonX`>/01?nX`>/8
ojNnjP03ojNmjOnU/N7oYK7Q00?oYK7Q2?nU/=l6ojJ_gP03ojFXfOnVZMSoYZWH00GoYZWH2?nWZMP0
0onYZ]SoZk;Moj^bg@04oj^bg@So[;3K0_n][]P5ojjmi0So/;ON0_na/]T5ok73j0So/kWN00?o/kCI
okBoh_nd_n800ond_n83o`0000Ko][SJ00?o]<CVokRjfonh^]/01_nh^]/3okJef0Ko^K_K1_nf]]T0
0onj_=[o]KOKokFgf`07okFgf`03ojjjhonb^=ko/[SN00Go/[SN1On[_>H00ol0003o[kcSojNnj@08
ojNnj@;oYl3/1_nV_n`7ojW1jaKooooo00?o0000ooooooooool0:?ooool001gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0_ooooo`03ojNnjonW_n_oYko[00coYko[00?oZ<7/ojS0
jonX`>/01_nX`>/6ojNnjP03ojFdhonU/N7oYK7Q00GoYK7Q2?nU/=l2ojJ_gPGoYJSI1onVZMP6ojNY
f003ojVcgon[/]goZk;M00KoZk;M1_n//=/00on/a^go[[gTojjmi006ojjmi0Ko/;ON00?oZm;dok73
j?na`nP01_na`nP6ok>igP;o[]3b0_nd_n83o`0000?o];oR1?nf^=X4okC4iPSo^;[K00?o][GHokVk
foni^m/01Oni^m/4okJff@Co^[cJ1one]m/00onk^m[o/[SNok:hgP07ok:hgP;oZkcV0_n__><00ol0
003o[kcSojnlh`07ojNnj@03oj^nj?nV_ncoY[o/00KoY[o/1_nY`N/00onX`N_oooooooooo`0Eoooo
o`03o`000?oooooooooo02Oooooo000Mooooo`;o00003oooool00ol0003oooooooooo`0[ooooo`Go
Ykk[2_nW_n/5ojS1k0SoZ<3[0_nW_^X5ojFdh`OoYK7Q1_nU/=l00onSYmWoYJSIojFXf@06ojFXf@Oo
YZWH0_nWZMP5ojVcg`OoZk;M1?n//=/4ojc6k@Oo[[gT1?n`]mh4oj_Bm0So/L?X0_nc^Mh5ojk@lP;o
00001ond_n800onf^=[o]<CVokC4iP05okC4iPKo^;[K00?o]/GVokVkfoni^m/01oni^m/00onf]]Wo
^[cJokZlfP05okZlfPCo]KOK1?nk^mX7ok:hgP03okVkfon__>?o[kcS00?o[kcS00?o0000ojnlhon_
_><01?nW_^T4oj^nj0SoY[o/0_nY`N/5ojS1jaKooooo00?o0000ooooooooool09oooool001gooooo
00?o0000ooooooooool03oooool2o`0002Sooooo0_nW_n/7ojNnj`KoYko[2OnX`N`6ojS0j`;oYKOU
1onU]><7ojFah@;oYK3O1OnSYmT7ojFXf@KoYZWH00?oZ;?QojVcgonY/ml01_nY/ml7oj^bg@03ojb`
fon/a^go[<K]00Go[<K]1on^_N@00on`]mkoZm;doj_Bm005oj_Bm0Ko/L?X0onIf_d2ojk@lP?o0000
0_n^d?86okBohP03ojSGn?nda>Ko]<CV00Ko]<CV1?nh^]/4okK5iPOo^K_K00?o]l?SokZlf_nj_=X0
1onj_=X00one]m_o^k_Jok^kfP05ok^kfPGo/[SN0oni^m/5ojnlh`04o`000?n__>?o[kcSojNnj@Oo
ZkkX1_nV_n`00onV_^_oZ<7[ojS1j`06ojS1jaKooooo00?o0000ooooooooool09_ooool001gooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Rooooo`KoYko[1onW_^/2ojNoj`goZ<7/
0_nX`>/6ojFgi@KoYKCS1_nU/N400onRYm[oXjOIoj>Wf@06oj>Wf@OoYJSI0_nVZMP5ojRch@OoZK?O
1_n[/]d2ojW>l`Oo[<K]1_n^_N@3oioLo0OoZm;d0_na`nP5oiWJo@?o00001_n^d?82okBohPGoZ=Oh
2?nda>H00onh^]_o]/GVokK5iP05okK5iPCo^K_K1?ng`n<7okZlfP03ok[1gonk^m[o^k_J00Ko^k_J
0onb^=h6okVkf`Go[kcS00?o0000ok>kh?n[_^P02?n[_^P2ojJok0GoY[k[2?nX`N/Fooooo`03o`00
0?oooooooooo02Gooooo000Mooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool07_oo
ool:ojNoj`GoYkk[0_nW`>`=ojS1k0;oY[[W2?nU]nD6ojFdh`;oYK7Q1OnRYmX7oj>Wf@KoYJSI00?o
Y[?RojRchOnX/n401_nX/n47ojVcg`;oZk;M1_nYc_<7ojc6k@;o[[gT2?nOg?`3oj_Bm0CoO]Sn0_nI
f_d3o`0000?oVM[m0on^d?84oh7Do`OoZ=Oh1_nda>H2oj?Fn@So]/GV00?o^K_KokO3hong`n<01Ong
`n<5okZlfP?o^/7O2?nk^mX00onb^=ko^K_KokVkf`06okVkf`;o[kcS0_nc^n000ol0003o/k_Pok>k
h007oj^nj003ojjoi_nV_^_oY[k[00KoY[k[1_nX`N/00onW`>coooooooooo`0Dooooo`;o00009_oo
ool001cooooo0ol0000Dooooo`03o`000?oooooooooo01[ooooo3_nW_n/00onW_^_oYl3/ojO0k004
ojO0k0WoZ<7/1_nV^^L8ojFgi@?oYKCS0_nPYmX8oj:WfPOoXjOI0_nUZ=T5ojJchPOoZ;?Q1_nY/ml3
ojKCm`OoZLkc0on/a^d5ohoMoPOoWmcl0ombeoX4ogkHoP?o00000onIf_d5ofW?n`KoPMCo1onXeoP2
okC4iPKoXmKi1_nfaNH00onUdoSo]l?SokO3h`06okO3h`?o^[cJ1_nj`Ml6ok^kfP03okc0g?ni^m_o
^K_K00Ko^K_K00?o_KoKok>kh?nc^n000onc^n000ol0003o/k_Pok>kh004oj^nj0Co[[oV2?nV_^/2
ojS1j`GoYl3/5?ooool00ol0003oooooo`00000Vooooo`007?ooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo01Oooooo4?nW_n/8ojO0k0KoZ<7/00?oYkgYojJjionV^^L01_nV^^L6ojFg
i@03oj6Yg?nPYm[oX:OJ00CoX:OJ1onRYmX6oj>Wf@03ojFahOnV/n;oY[?R00KoY[?R1onX/n42ojVc
g`OoY]?g1OnYc_<3ohWOo@SoSmgn0_nOg?`7og;GnP?o00001OmTcOX7ofW?n`KoPMCo0onXeoP5ogG?
o`OoXmKi0_nfaNH5ojGCn0So]l?S00?o^[cJok[1gonj`Ml01Onj`Ml4ok^kfPCo_<3L1_ni^m/3okfo
f`Go/k_P00Co0000ok>kh?nc^n3oZkkX1on^_nH6ojJnj`03ojRoj_nW`>coYl3/00KoYl3/5_ooool0
0ol0003oooooooooo`0Sooooo`002_ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b
<_o^k^h6ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool04ooooolDojNoj`SoYl3/
0_nX`N`5ojNmj@SoY[[W0_nU]nD5oj6Yg0KoX:OJ1onRYmX2oj>Wf@GoYK7Q1onV/n86ojRch@?oYMGi
2?nVdoL00onYc_?oRMomohWOo@06ohWOo@?oSmgn1_mbf?T3og;GnP?o00000omfcol6ofC=nP?oJLok
1OmVaOh7oeg6nPKoMLoo0onSe_T4og;:o`OoYM?h1_ng`n<00on^dO;o^/7Ook[1g`07ok[1g`03ok^k
f_nl`=co_<3L00Go_<3L0oni^m/6okfof`Co/k_P00?o0000ok>kh?ni_]h02On^_nH2ojJnj`GoZ;oZ
2?nW`>`Eooooo`03o`000?oooooooooo02?ooooo000<ooooo`03o`000?oooooooooo00;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
3oooool2ojS1j`goYko[0_nW_^/7ojNoj`KoYl3/0_nX`>/7ojNmj@KoY[[W00?oXZgOoj6Yg?nQZM`0
1OnQZM`7oj2WfPGoXZOJ00?oXjkPojFahOnU/N401_nU/N47ojJchP;oZ;?Q1onUeOT6ojKCm`CoRN7l
0on9god6ogWKn`?oL]Si0on;cOh3o`0000GoM/oo0_nH`?<8oh;3o0KoI/Gn0omMa_X5ofVmoPKoEkok
1_mbb_l7ojGCn0;o]l?S1On^dO87ok[1g`03okG9jOnl`=co_<3L00Oo_<3L00?o^K_Kokfofonm_m/0
1Onm_m/4ok>kh004okVng_l0003o^KkNokVngPOo[[oV00?o/KoUojRoj_nX_nX01OnX_nX6ojO0k0;o
Y[o/5_ooool00ol0003oooooooooo`0Rooooo`0000?oooooo`000?l000001?l00005ooooo`03o`00
0?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`;o00006Oooool00ol0003o
ooooooooo`0<ooooo`GoZ<7[2OnW_n/6ojNnj`OoYko[0_nW`>`6ojS0j`OoYkgY0_nV^^L5oj:]g`Oo
XJWL1onPYmX00onRYm[oXjkPoj>^h003oj>^h0SoYK7Q1OnV/n83ojCEn@SoYMGi0_nVdoL6ohWQo0Co
Q]km0omifo/5oiS9n0;oRlgn0_l00003oh_=oP;oM/oo1_nH`?<6oh;3o003oj2jk?n:_?OoR[cg00Ko
R[cg1omY_Oh6oeNon`KoL/[o0onUdoP4ogW8o`Oo[]7b1?nj`Ml4okG9j@Oo_<3L00?o^l?Qokfofonm
_m/01onm_m/00onc^n3o^KkNokVngP02okVngP03o`000?ni_]ko^KkN00Co[[oV1?na_nD7ojRojP;o
Yl3/1_nV_n`Fooooo`03o`000?oooooooooo027ooooo000<ooooo`03o`000?oooooooooo00;ooooo
00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool02_ooool7ojS1j`OoYko[2?nW_^/5ojNoj`;oZ<;/2?nX`>/5ojNmj@03oj>ci?nR[MooXZgO00Ko
XZgO1_nQZM`6oj2WfP03oj2[gonS[^3oXjkP00GoXjkP2?nU/N400onV/n;oY=GiojCEn@05ojCEn@Ko
YMGi1?n=i?/2ohWQo0KoQ]km0onQao<5oiS9n0?o00000_n;cOh4oj:lj`SoV<3c0_n2`o`5oj2jk0So
R[cg0omY_Oh4ohfjm0OoIKOl1_mG^o/6ogW8o`Oo[]7b00?o^/7OokG9jOnebNT01OnebNT4okc0g0Co
^l?Q1onm_m/00onn`]go^KkNokVngP04okVngP04o`000?ni_]ko^KkNojjoiPKo/KoU1_nX_nX2ojVo
j@SoY[o/5Oooool00ol0003oooooooooo`0Qooooo`003?ooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
00Oooooo0onX`N`7ojS1j`OoYko[2?nW_^/00onW_n_oZ<;/ojS2k004ojS2k0SoZ<3[00?oYkgYoj>c
i?nS/n@00onS/n@7oj:]g`OoXJWL0_nPYmX5oj2[g`OoXjkP1_nU/N42ojGBn0SoY=Gi0_nUeOT6ohgT
n`CoTN7n0_n6g_d7oj77l`05oiS9n?l0003o0000o`000?nHbOP00_nV^>H7oj:lj`KoV<3c00?oY[KT
oj2jk?nP^^`01_nP^^`6ohZlm`;oX[SX1on=^_@7ofFgo0KoEk_k1_mib?l3ojkAlPCoS/_l2?nebNT0
0onl`=co^l?Qok_3h@05ok_3h@Co_KoK1?nn`]d5okVngP03o`000?ni_]ko_L7M00So/KoU0_nX_nX6
ojVoj@OoY[o/5_ooool00ol0003oooooooooo`0Pooooo`003?ooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo00?ooooo1onX`N`5ojS1j`WoYko[1_nW_^/2ojO0k0OoZ<;/1_nX`>/00onT^>OoXk?Toj>ci005
oj>ci0OoXZgO0onQZM`3oijXg@SoX:_O1onS[^02ojFah@KoYM;h1_nTeOT4oi?Vn`;oSNCk1onAhOh2
ojG6l@GoXLOc0ol000000onHbOSoY[SVojJhiP04ojJhiPOoX[c[0_nH`?<5ojJfi0SoX;[/0_n:_?L6
oj:hj0OoSK[d0omU]o`5ohNgm@KoG;;k1OmL^_`7ohk;o0Ko]LWY00?oY/gdok_3hOnk`n401onk`n40
0onm_m_o_/;Mokk2g@05okk2g@Co^KkN00Co_L7Mo`000?nm`Mgo_L7M1_na_nD00onc`>CoZKoYojVo
j@07ojVoj@OoY[o/5_ooool00ol0003oooooooooo`0Oooooo`003?ooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2o`0001kooooo00?o0000oooooonX`N/00_nX
`N/8ojS1k003ojS1jonW_n_oYko[00_oYko[0_nW_^/6ojO0k0OoZ<;/0_nX`>/5ojBhi`OoXk?T1OnR
[Ml00onLY]coWZSMoijXg@05oijXg@OoX:_O1_nS[^02ojG<m0SoYM;h0_nTeOT6oi?Vn`CoVN?m0onA
hOh6ojG6l@04oj77lol0003o0000o`0000;oXLOc00?oYkKSojJhi_nV^>H01_nV^>H5oj:lj`03ojZd
h?nV]^CoY[KT00KoY[KT1_nP^^`00onZ]N7oX[SXoj:hj007oj:hj0?oSK[d1?nR^>P8ohNgm@KoG;;k
1OmL^_`7ohk;o0;o]LWY1OnVcO@7ok_3h@03okK7ionn`]go_/;M00Oo_/;M00?o^KkNokg1gOnm`Md0
0_nm`Md00ol0003o_L7Mok6oi@03ok6oi@Co/l3T1onY_nT00on[`>WoY[o/ojJok006ojJok1Gooooo
00?o0000ooooooooool07oooool000[ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo00?o0000ooooooooool07?ooool7ojS1j`KoZ<7/0_nX`>/>ojNoj`SoYl3/
1OnX`^`2ojJlj@OoY;SW1onS/n@00onR[MooW:KLoibVg003oibVg0OoWZSM1onPZml2oj>^h0KoYLcd
1_nUd_P4oi[Wn`;oTnKk1onIhod2ojO7l0GoYLKa0ol00002oj77l`GoYkKS2?nV^>H00onR_>_oZ[CP
ojZdh003ojZdh0SoY[KT0_nP^^`5ojZeh@OoX[SX00?o[KOQoj:hj?nR^>P01_nR^>P6ohNgm@03oini
jomh/_OoN;;g00GoN;;g0omC[oX2oebjo0?oS/_l1?m]_Od7ojK=m0Co^l?Q1?nfanL7okk2g@03okk4
gonm`Mgo_L7M00Co_L7M00?o0000okg1gOna_nD01onc`>@4ojVoj@CoZl3Y2?nV_n`Eooooo`03o`00
0?oooooooooo01kooooo000Kooooo`03o`000?oooooooooo01[ooooo0onW_n/7ojS1j`;oZ<7/1_nX
`>/>ojNoj`SoYl3/00?oZ<;/ojJljOnV_>T01?nV_>T7ojBhi`?oXk?T0onKYMd7oibVg0OoWZSM1OnP
Zml3ojC3k`OoYLcd0_nUd_P7oi[Wn`CoWnOl0_nIhod6ojO7l004ojG6lOl0003o0000o`0000;oYLKa
00?oYkCRojNfhonW]^<01_nW]^<6ojJhiP03oj^eh?nZ]>3oZ[CP00GoZ[CP1_nV]^@00on^^>3oZ[GQ
ojZeh@06ojZeh@CoX[SX1?n]]n48oj:hj0;oQkOe1OnO^N/7ogRbm`KoDjoj1_m]_Od7ojK=m003ok_3
hOnfanOo]/OW00Go]/OW1Onn`]d3okk4g`Go_L7M00?o0000ol34gOo0a=d02?nc`>@00onY_nWoZl3Y
oj_0j@05oj_0j@OoY[o/5_ooool00ol0003oooooooooo`0Mooooo`006oooool00ol0003ooooooooo
o`0Gooooo`OoYko[1onX`N/8ojS0j`GoYko[0_nV_^/7ojNoj`KoYl3/0_nX`>/7ojJlj@GoY;SW00?o
WZ_Poi^UgOnKYMd01OnKYMd6oibVg0SoWZSM00?oX:_OojC3konT`nl01OnT`nl5ojG<m0CoX^Ok0onJ
io/6oioWo0?oZL[a1?nWao03o`0000;oYLKa1OnW]>88ojNfh`;oY[SV1On[]N07ojZdh0;oY[KT1On^
^>08ojZeh@03oj:hj?n]]n7o[KOQ00Go[KOQ1_nR^>P00on]^N;oWkW[oinij`06oinij`OoN;;g1_mC
[oX6offmo@?oY/gd0on=a?X8okK7i`?o_/;M1Onna=l4okg1g@;o`<CM00?o0000ol34gOo0a=d01_nc
`>@2okO3h`SoZl3Y1onV_n`Dooooo`;o00007oooool001_ooooo0_l0000Fooooo`[oYko[1onX`N/8
ojS0j`03ojNojonV_^_oY[k[00CoY[k[1onW_n/2ojO0k0KoZ<3[1onV_>T00onT^>OoWZ_Poij[h003
oij[h0OoVjGM1_nLY]`6oijXg@;oX[WY2?nT`nl00onUc?CoX^Okoj;Wn`05oj;Wn`CoY>_j0_nOio`7
ojW:l@03ojO7l?l0003o000000;oYlO`2OnW]>86ojNfh`03ojZfhOn[]N3oZkGP00KoZkGP1OnZ]>00
0on^_>?o[[SPojjhh006ojjhh0KoZ[GQ00?o/KcRojfghOn]]n401on]]n42oj:hj0Go[KWR2?nO^N/3
ogRbm`?oTkSa1_mRZoP6oeban`OoSLCj2?nfanL00onn`]go_/COokk4g`05okk4g`03okg1gOo0a=go
`<CM00?o`<CM00?o0000ol34gOo0a=d00_nc`>@6okO3h`KoZl3Y00?o[<7YojJok?nV_n`01OnV_n`F
ooooo`03o`000?oooooooooo01cooooo000Jooooo`03o`000?oooooooooo01?ooooo3?nW_n/9ojS1
j`KoZ<3[00?oYko[ojJnjonV_^/01_nV_^/5ojNoj`?oZ<;/1onX`>/3ojJlj@?oXK;U1onNZn06oi^U
g@OoW:KL0_nNZ=d6oj:ij@KoY<?_1?nXiO/2oj;Wn`OoY>_j0_n]d?85ojW:l@?o000000?oYlO`ojNd
h_nW]>802_nW]>84ojNfh`CoZ[KQ1on[]N03ojZdh0Co[[cS2?n^^>02ojZeh@Go/KcR1on]]n400onc
_^;o[KWRojfihP06ojfihPKoWkW[00?oZ[[Uoi>hlOnC^?401OnC^?46of:[n0KoG;7k1on=a?X6okK7
i`03ojk9k_nna=oo_/CO00Go_/CO00?o_<GRol34gOo0a=d01Oo0a=d00ol0003o`LKNokO3h`08okO3
h`;oZl3Y1On/`NT7ojJok1Gooooo00?o0000ooooooooool07?ooool001[ooooo00?o0000oooooooo
ool03oooool=ojNoj`goZ<7[0_nX`>/5ojNoj`SoY[k[00?oYko[ojS2k?nX`^`01OnX`^`5ojS0j`03
ojBij?nQ/^GoXK;U00GoXK;U1_nNZn07oi^Ug@?oW:KL0onN/>@9oj:ij@;oY<?_1_nXiO/4ojW]n@?o
Y>_j1_n]d?801?nYb_7o0000o`000?l00002ojW:l@03ojNfhonW]>;oYkCR00coYkCR00?oYkKSojZf
hOnZ]^401OnZ]^47oj^eh003ojZdh?n^_>?o[[cS00Co[[cS1_n^^>000on^_^Ko/KcRok6lhP06ok6l
hPCo[KOQ1?nc_^88ojfihP;oWkW[1OnZ^^D7oi>hl@KoHZ_h1_mL/O/7ohg4nP;o]/OW1On^bNh5okk4
g`?o_<GR1_o0a=d00ol0003o`LKNol76gP07okO3h`03okW5hon/`NWo[<7Y00Go[<7Y2?nV_n`Eoooo
o`03o`000?oooooooooo01_ooooo000Jooooo`03o`000?oooooooooo00_ooooo0_nW`>/>ojNoj`go
Z<7[2OnW_n/6ojJnj`?oYko[1onX`^`00onX`>_oY;WXojBij003ojBij0OoXK;U1_nNZn05oi^Ug@03
oi^ZhOnN/>CoW[3T00GoW[3T1onR^NT3oj_On@CoZ>Gk1_nYkOT2ok;Im0Go[M3b0ol00002ojW:l@Go
YkKS3?nW]>800onY]^?oZ[KQojZfh@06ojZfh@KoZkGP00?oZkcVojjlhon^_><01_n^_><3ojjhh0Co
[[kV2?na_>800on]]n7o/kkRok>nhP05ok>nhPKo[KWR00?o/kkRojZjiOnZ^^D01_nZ^^D3oi>hl@Co
XK[[1omg[oH5oeNYn@KoMkSk1on^bNh3okk4g`Ko_<GR0oo0a=d3ol76gP03o`000?o1a]ko`LKN00Co
]l?S1?niaN<7ojc1j@SoY[o/5Oooool00ol0003oooooooooo`06ooooo`Go00003oooool001[ooooo
0_l00009ooooo`KoYl3[3_nW_n/9ojS1j`goYko[0_nV_^/7ojNoj`GoZ<;/0_nW_^X6ojBij0KoXK;U
1onNZn000onKYMgoVj[Qoi^Zh@03oi^Zh@OoW[3T1?nR^NT7oj_On@03ojSUnonYkOWoZNgi00?oZNgi
1OnbfO@01?n]d?;o0000o`000?l00002ojg@lP03ojNii_nW]^?oYkKS00KoYkKS2?nW]>85ojVfh`So
Z[KQ0_n[]N05oj^liPSo[[cS00?o[[SPojjni_n^_^H01?n^_^H6ok6lhP03ojjoionc_^;o/kkR00Ko
/kkR1?n]^N84ok>nhPKoZ[[U00?o/[gRoj6jjonQ^^/01_nQ^^/7ogN_mPGoEjWi1_mg^?/7ojk9kP03
okk4gonlaN;o_<GR00Ko_<GR00?o`<CMol76g_o1a]h00oo1a]h01?l0003o`LKNol76g_ng`n<6okW5
h`Ko[<7Y0_n]`^T8ojJok1Cooooo00?o0000ooooooooool01_ooool01OnHV9So8B4Qonk^k_oooooo
A4A400oooooo000Jooooo`03o`000?oooooooooo00Kooooo0_nX`N/7ojO0j`koYko[2OnX`N/:ojNo
j`CoY[k[2?nW_n/00onX`^coYkkZojNnjP04ojNnjPKoY;WX1_nQ/^D3oij[h0?oV:GO1onKZ^47oij`
i003oj:ijOn[goWoZmoi00KoZmoi1?n^kOP00onYkOWo/]Wdok;Im003ok;Im0?o00000_n]d?85ojNi
iPSoYkKS0onW]>83ojNfh`OoZKKS1_nZ]^400onY_NSoZkcVoj^liP06oj^liPKo[[cS0_n[_nT7ojjn
iP;o/KcR1On^_nL8ok>nhP03ojfih_nc_^;o/kkR00Go/kkR0onZ^^D4ok:mhPSoXK[[0omg[oH4ohZd
lP?oFZGg0_mGZOT6ogNhn`?o[/W^1?nRa?47okc5hP03okW6i?o1a]ko`LKN00Co`LKN00?o0000ol76
g_o1b=l02?niaN<2ojc1j@Ko[L;Y1onV_n`Eooooo`03o`000?oooooooooo00Kooooo00?oV9RHob4Q
8Oo^k^h04?ooool001[ooooo00?o0000ooooooooool00oooool6ojS1j`OoYl3[3_nW_n/9ojS1j`Oo
Yko[1onV_^/6ojNoj`03ojW1jonW_^[oYkkZ00KoYkkZ1_nT^NP3oj6bi@;oUjGO1onHYMl7oi^Zh@Go
W[3T0onWd?H5oj_On@Go[^gh0onfi?H01?nbfOCo0000o`000?l00002ok;Im0;oZKkY1onW^NH6ojNf
h`03ojFdhonW]^?oYkKS00GoYkKS1onY]^<2ojZfh@GoZKgX2?n[_>H2ojjlh`KoZkoY1On^_^H00onZ
`N[o[[oWojjoi`06ojjoi`Ko/kkR0_n_`>H8ok>nhP03ojZjiOnb_N;o/[gR00Co/[gR1_nQ^^/2ojVl
i`OoR[Cb1OmJYOL6ofb`n@OoX/Ca1?nlaN84okW6i0Ko`LKN00?o0000ol78goo1b=l01_niaN<2ok[7
i0So[L;Y1onV_n`Eooooo`03o`000?oooooooooo00Kooooo00?oV9RHob4Q8Oo^k^h03oooool001[o
oooo00?o0000ooooooooool00_nX`>/8ojS1j`GoYl3[3_nW_n/;ojS1j`OoYko[1onV_^/2ojNoj`Go
ZL7[2?nW_^X3ojBij0;oW:gS1_nGYMl7oiRUg`OoVj[Q00?oW[3TojO@m_nWd?H01_nWd?H00on[goWo
[^ghojk]n003ojk]n0?o]^Cf0ol000000onfi?Ko/]WdojVnj@05ojVnj@OoYkWV0_nW]^<5ojFdh`Oo
YkKS1OnY]^<00onX_NWoZKgXojVmj006ojVmj0KoZkcV0_nY`>X8oj^oj@03ojjni_nZ`N[oZ/7Z00?o
Z/7Z2?n^_nL2ok>nhPKo[l3V1_nc_^800onc`NGo/[gRok:mhP06ok:mhP;oXK[[1_nY_>L7ohZdlPGo
FZGg1_m//?T7oj;4l@03okc5h_nia^Co^LKT00Go^LKT0oo1a]h3ol78g`03o`000?o1b=oo^LGS00?o
^LGS1Onjan@6ojg2j@03ojg3j_nV_ncoY[o/00GoY[o/5Oooool00ol0003oooooooooo`07ooooo`03
ogMgMomVIVKooooo00kooooo000Iooooo`03o`000?nX`>_oZ<3[00CoZ<3[2?nX`N/00onW`>_oYko[
ojNoj`0<ojNoj`goZ<7[2OnW_n/5ojJnj`;oYl3[1onY`N/6ojNnjP03oj6fionL[N?oW:gS00CoW:gS
1_nGYMl7oiRUg`?oVj[Q1OnR_^d6ojO@mPCo/^Wh0_n^kOP01?nfi?Ko0000o`000?l00003okKTmP03
ojg7kOnY_^WoZKkY00KoZKkY1OnW^NH00onT/^?oYKCSojFdh`06ojFdh`OoYkKS00?oZKKSojRmjOnX
_NT00onX_NT8ojVmj0;oZkcV1_nY`>X6oj^oj@03ojS0jonZ`N[oZ/7Z00GoZ/7Z1_n^_nL00on[`N[o
[l3Vojo0iP07ojo0iP;o/kkR1Onc`ND6ok:mhP03okK1honY_>OoZKcW00OoZKcW0on:]?83oiJik`Co
HjCd0_mJYOL6ofb`n@?oX/Ca0onF__<9okW6i003ol76g_o1b=oo`LSO00?o`LSO00?o0000ol78goni
aN<02?njan@2ojg2j@Go[L?Z1onV_n`Eooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool03Oooool001Wooooo00?o0000ojS0jonX`>/01OnX`>/6ojS1j`;oYl3[3?nW_n/3ojO0j`WoZ<7[
3OnW_n/00onV_^_oYl3[ojO0j`04ojO0j`OoZL7[0_nW_^X5oj6fi`KoW:gS1_nGYMl5oiRUg`;oW;7V
2?nR_^d2ojO@mPOo/^Wh00Co^Nceo`000?l0003o^Nce0_nfi?H5ojg7k@SoZKkY00?oYkWVojBbhonT
/^<00onT/^<7ojFdh`KoYkKS00?oYkgYojRmjOnX_NT01OnX_NT6ojVmj0;oZ<3[2?nY`>X2oj^oj@Go
Z<3[1onZ`NX2ojjoi`GoZl7Z1on_`>H00on/`NWo/l7Uok?1i@06ok?1i@?o/[gR1?nf`N<7ojVli`03
ojnoi_nF^NooU[W_00GoU[W_1_mSY?@5ofJYm`OoU[kc1onia^@00onga^Go`LSOol78g`04ol78g`03
o`000?o2bN3o^/OT00Oo^/OT00?o^/WUojg3j_n]`nX01On]`nX8ojJok1?ooooo0ol00004ooooo`05
o`000?nj^[[ooooooiRHV?l@41003oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06oooo
o`03o`000?ooooooZ<3[00KoZ<3[0_nX`N/6ojO0j`SoYko[1onW`>/7ojS1j`goYko[0_nV_n/7ojO0
j`GoZL7[0_nU_>X7oj6fi`KoW:gS1_nGYMl00onHYMooW;7VoibaiP04oibaiPKoX[k]0onchOH5ok;Y
n0?o00000_nik?D3okCCl0Ko[LO]1_nY_^T00onS/N;oY;;SojBbh`05ojBbh`OoYKCS0_nW]^<5ojNm
j@OoZ;gY0_nY_NP6ojS0j`KoZL3Z00?oYkgYojS0jonX`>/01_nX`>/5oj[1jP03ojNojon[`N[oZl7Z
00KoZl7Z1?n_`>H4ojc1j@So/l7U00?o/[gRokK1honf`N<01?nf`N<4ojVli`Co[koV1onF^Nl6of>T
m0GoIZWg1onF__<4okW6i0Co]lKU1Oo1b=l00oo2bN3o0000ol;9h006ok[7i0?o^/WU1on]`nX8ojJo
k1Cooooo00?o0000ooooooooool00_ooool01OnHV9So410@o`000?lQ8B7oc<c<00oooooo000>oooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`05ojS0j`?oZ<7[1onW`>/8
ojNoj`OoYl3[1onX`N/9ojNoj`KoY[o[1onW`>/00onY`N_oYKcZojFljP04ojFljPKoXKKW1onL[N<3
oiNUg`;oUjSR2?nL/NH3oj:nk@Oo/n7f0ol00003okW/m@Ko]=?`1_n]and2ojVnj@GoXk7R1_nT/^<6
ojFdh`;oYkcY1onW_NT5ojRmj@?oYl3[1onX`>/2ojW0jPGoYkgY2?nX`>/00onZ`N[oYko[ojNoj`03
ojNoj`SoZl7Z00?o[l3Vojc1jOn/`NT01On/`NT6ok?1i@03ojo1ionf`N?o]/7S00Ko]/7S00?oZKcW
ojnoi_n__nH01On__nH7oiJik`KoHjCd1OmVZOL7oiJnl`03okW6i?nga^Go]lKU00Co]lKU0oo1b=l4
ol;9h003o`000?o2bN3o^/OT00;o^/OT1OnjbND6ojg3jP;o[<?Z2?nV_n`Dooooo`03o`000?oooooo
oooo01Gooooo000>ooooo`05oa0@4?ooooooooooooooool@41001_ooool2o`0000;ooooo00?oZ<3[
ojS1jonX`N/01OnX`N/7ojO0j`SoYko[1OnW`>/9ojS1j`GoYko[2_nV_n/5ojO0j`?oZ<7[1_nU_>X6
oj6fi`?oW:gS0onCY>46oiNXhPSoW;7V00?oX[k]ok?Qm_nchOH00onchOH3o`0000?o^ncd0_nik?D8
okCCl0?o[LO]0_nT]>D8oj>ahPKoY;;S0_nU]><6ojNlj@OoYkgY00?oZ;gYojO0jonW`>/01OnW`>/5
ojS0j`03ojNlj?nW_NWoYkgY00KoYkgY1_nX`>/2ojNlj0KoYko[1_n[`NX2ojS0j`So[<7Y0_nc`ND5
ojo1i`Ko]/7S0_ne`n@8ojnoiP?oU[W_0onL^nh6ofbUl`CoIJCd0_mVZOL3oiJnl`?oSkSb2?nga^D0
0oo1b=oo`/WPol;9h004ol;9h003o`000?o2bN3o^/OT00Oo^/WU0_n]`nX6ojc3jPKoY[o/00?oY[o[
ooooooooool04oooool00ol0003oooooooooo`0Dooooo`003_ooool01Ol0003ooooooooooooooooo
000000Kooooo00?o0000ooooooooool00oooool7ojS1j`?oYl3[3?nW_n/00onW`>_oZ<7[ojS1j`0;
ojS1j`03ojNojonV_n_oY[o[00coY[o[00?oYl3[ojS1jonX`N/01OnX`N/6ojFljP?oXKKW0_nFZN<7
oi>Th@KoUjSR1_nL/NH3oj_?l`04ok?Qm_l0003o0000o`0000Ko^ncd0onni?86okCCl003ojRnjOnT
]>GoY;CU00CoY;CU2?nS/N83ojBbh`CoY[_X1onW_>T3ojNmj@coYl3[00?oZ<3[ojNlj?nW_>P00onW
_>P8ojNmj@;oZ<3[1_nW_>P6ojNoj`;oZl7Z1_nX`>/6ojc1j@03ojW1jon_`NOo[l7W00Go[l7W1?nf
`N<5okG3i0Ko[koV00?o/l;Uoibkk_nL^nh01OnL^nh6ofbUl`GoIJCd1on?^?86okO6i@;o]/KV1_o2
bN000ol0003o`/_Qok[9i@06ok[9i@;o^/[W2?n/`nX2ojJok0GoY[o[5?ooool00ol0003ooooooooo
o`0Dooooo`003_ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool01Ooo
ool5ojS1j`;oYl3[3OnW_n/2ojO0j`coZ<7[0onW_n/<ojJoj`[oZ<7[0onU_>X2oijdj0KoUZWS1onC
Y>46oiNXhP;oW;7V1?n[co<3o`000003oj_?lonchOKo^ncd00Co^ncd1_nni?82okCCl0GoZ;kY1_nT
]>D6oj>ahP03oj>hionV^nSoY[_X00KoY[_X1OnW_>T?ojO0j`03ojNkionW_>SoYkcX00GoYkcX1_nW
_NT00onZ_>OoYkcXojNlj007ojNlj0?oYko[0onX_NP8ojS0j`;o[<7Y1OnY`N/7ojo1i`03okK1hone
`nCo]L?T00Ko]L?T0_n__nH5ok?2i@OoW;_^1_m/YO<5ofFTm0OoSkSb0_nga^D6okK6iPCo`/WP0_o2
bn400ol0003o`/_Qok[9i@03ok[9i@Go^/[W1_n/`nX00on[`n_oY[o[ojJoj`05ojJojaGooooo00?o
0000ooooooooool04oooool000kooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oo
oooooooo00Kooooo00?oZ<7[ojO0jonW`>/01?nW`>/9ojNoj`KoYl3[2?nX`N/7ojNoj`SoY[o[3?nX
`N/00onT^n[oW[CXoijdj004oijdj0KoUZWS1_nCY>45oiNXhP?oWkSZ00CoZloco`000?l0003o0000
0on[co<4okcUl`03ok_/m?nni?;o_^Cb00Go_^Cb0_n_bNd7ojRnj@KoY;CU0_nS/N85oj>hi`SoY[_X
00?oYkcYojO0jonW`>/03OnW`>/5ojNki`OoYkcX0_nW_NT5ojZli`OoYkcX00?oZkkWojRmj?nX_NP0
1OnX_NP6ojS0j`03ojNmjOnY`N_oZL7[00KoZL7[1On_`NL2ojg1j@Oo]L?T00?o]<?Vok?2iOnc`^D0
1_nc`^D3oibkkPCoW[c]1OmaY_84ofNQlP;oIJCd0on?^?83ohbdl@Wo]/KV00?o`/WPol;;hOo2bn40
0oo2bn400ol0003o`/_Qok[9i@08ok[:i`;o[<?Z1On[`n/7ojJojaGooooo00?o0000ooooooooool0
4_ooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o00002?ooool7ojO0j`OoYko[
2?nW`>/8ojS1j`OoYko[1onV_n/9ojS1j`GoY;_Z1_nN]>P6oiJYh`KoTjCQ00?oUjSRoinhj_nO^>X0
0_nO^>X3o`0000CoZloc1OnliO<3ol?Zl0Co_^Cb1On_bNd7ojRnj@?oY;CU0onO/^D7oj>hi`KoY[_X
00?oYko[ojO0jonW`>/02onW`>/9ojNki`GoYkcX00?oZKgXojZlionZ_>L01_nZ_>L4ojNlj0CoZkkW
1onX_NP2ojS0j`GoYkgY2?nY`N/00on_`NOo[L7Yojg1j@04ojg1j@Co]L?T1?nd`nH6ok?2i@03okC4
i_nN_>goW[c]00KoW[c]1OmaY_85ofNQlPOoS;Ca2?nfa^H6ol;;h@03o`000?o3cN;o`lgR00Oo^/[W
00?o^<_Yoj_3jon[`n/01On[`n/7ojJojaGooooo00?o0000ooooooooool04_ooool000kooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo00Sooooo1onW`>/7ojNoj`SoYl3[
2?nX`N/5ojNoj`WoY[o[1onX`N/7ojBkjPGoW[CX1onFZN<3oi>Th@?oUjcU0_nO^>X2o`0000CoWkSZ
00?oZlocokcUlonliO<00onliO<7ol?Zl003okkTl_n_bNgo[lW]00Go[lW]1OnX_^T00onO/NGoWk;U
oinbi@05oinbi@OoXkSW0_nV^nP5ojNoj`WoYl3[3OnW^nL00onW_>SoZKgXojVmj003ojVmj0SoZ[cW
00?oYkcXoj^nion[_^L01On[_^L5ojRmj003ojboionW_NWoYkgY00KoYkgY1_nY`N/2ojS0j`Oo[L7Y
00?o]L?TokC3i_nd`nH01Ond`nH3ok?2i@Co]<CV2?nN_>d5og6VlPGoIj7b1on<]?48okK6iPGo`/_Q
00Co`lgRo`000?o3cN;o`lgR1?njb^L4okS;j@OoZl?[1onV_n/Eooooo`03o`000?oooooooooo017o
oooo000Hooooo`03o`000?oooooooooo00Wooooo1OnW`>/9ojNoj`KoYl3[2_nX`N/00onW_n_oY[o[
ojJoj`0;ojJoj`OoZ<7[1onT^nX5oijdj0?oUZWS0onAYN<5oiN/i@?o00001OnO^>X4okOIlP;o_>Gc
1oo3j_02okgKk`So[lW]00?oZ;kYoinaiOnO/ND00onO/ND7oinbi@GoXkSW00?oY[kZojNojonW_n/0
1_nW_n/5ojO0j`;oYkcX3OnW^nL2ojRmj@KoZKgX1_nZ_>L2oj_0j@SoZkkW00?oZ;gXojboion/_nL0
0on/_nL8ojNmj@;oZL7[1_nX`>/5ojg1j@03oj_1jOnd`nKo]<?V00Oo]<?V00?o/l;UokC4i_nda>H0
1?nda>H6oijlk@03oijlk_mbYO7oLZGa00;oLZGa0_maY_85ofNQlPOoS;Ca1onfa^H3ol;;h@Co`lgR
00Co0000ol?=h_o3cN;o^/[W1_nhbnT6oj_3j`03ojW2k?nV_n_oY[o[00KoY[o[5Oooool00ol0003o
ooooooooo`0@ooooo`006?ooool00ol0003oooooooooo`0:ooooo`03ojO0jonW_n_oYko[00_oYko[
0_nW`>/<ojS1j`03ojNojonV_n_oY[o[00_oY[o[2OnX`N/5ojBkjP03oibdjOnBYnCoTZOT00CoTZOT
1_nAYN<01?nG[>Go0000o`000?l00003oiN/i@?oWkSZ1_ngfO83ol;Vl0Co`n[`1Onmfnl6ojo9k@03
ojBij?nO/NGoWk7U00GoWk7U1onO/^D00onS^>OoY[kZojJnjP03ojJnjPSoYko[00?oYl3[ojNlj?nW
_>P01?nW_>P9ojNki`KoZ;gY1_nY_NP2ojZli`KoZl3Y1_n[_^L00on[`NWo[;oWojboi`05ojboi`Ko
YkgY0_nZ_nT8ojS0j`03ojg1jOn[`NWoZl7Y00?oZl7Y1ond`nH00onca>Oo]<CVokC4iP06okC4iP;o
W[c]1OnN_>h6og:Ul@?oJio_0_mWXO83ohbdl@CoSK;_1onfa^H00oo2bn7o`lgRol?=hP04ol?=hP03
o`000?o3cnCo^<_Y00Oo^<_Y0_n[`n/5ojW2k0KoY[o[00?oYko[ooooooooool04oooool2o`00017o
oooo000Gooooo`?o00003Oooool>ojNoj`WoZ<7[1OnW_n/9ojJoj`goZ<7[00?oY;_ZoibdjOnL]>T0
0onL]>T6oi:Wi0?oTJGS0ol00007oiN/i@03oinhj_ngfO;o]mWb00Co]mWb1Oo2i_000oo3j_3o_M__
okgKk`06okgKk`;o[lW]1OnT^NP6oinai@KoWk;U0_nT^nT6ojJnjPKoYko[0_nW_NT7ojNlj0GoYk_W
0_nW_NT8ojRmj@?oZKgX0onX`N/8oj_0j@;oZkkW1On[`NT7ojboi`;oYkgY1_nZ_nT6ojS0j`03ojO0
jon[`NWoZl7Y00GoZl7Y1?nd`nH4ok?4i`Ko]<CV0_nda^L7oijlkPKoLZGa1Om[Wnl7ohfbk`Go]/KV
0_nhanH6ol?=hP03o`000?o3cnCo`loT00Ko^<_Y0_ndbNX7ojW2k0;oY[o[1OnW_n/Cooooo`03o`00
0?oooooo0000017ooooo000Gooooo`03o`000?oooooooooo00kooooo3_nW_n/8ojS1j`KoYko[2?nV
_n/;ojS1j`;oXkc[1onL]>T5oi:Wi0?o00001?nAYN<3oiN/i@GoXkk/0ongfO86ol;Vl0?oanK]1_nm
fnl2ojg6k0OoY;WX1_nO/ND2oinbi@KoY;_Y1_nV_^X2ojNoj`KoYkgY1onW_>P00onW^nOoYkgYojNm
j@04ojNmj@KoZ;gY00?oZ<;/ojS1jonX`N/01OnX`N/6oj_0j@03ojS2k?n[`NWoZl7Y00KoZl7Y1On/
_nL2ojc1j@SoZ[oY0_nX`>/5ojO0j`OoZl7Y00?o]<?Vok?4ionca>L01Onca>L2okC4iPKo]<KW1onN
_>h6og:Ul@GoJio_1on=/^l00onfa^Ko^<OVokS7iP04okS7iP?o`lgR0oo3cn@00ol0003o`loTol??
i002okS;j@Ko]<WZ1OnY`^`00onX`NcoYko[ojNoj`06ojNojaCooooo00?o0000ooooooooool03ooo
ool001Oooooo00?o0000ooooooooool03oooool>ojNoj`SoZ<7[1_nW_n/8ojJoj`OoZ<7[1_nS_>/7
oibdj@04oi:Wi?l0003o0000o`0000;oTZOT0onAYN<3oiN^i`SoXkk/00?o]mWbol;Vl?o2i_000oo2
i_07olOVk@03okgKkon]a^co[LK/00Co[LK/1onT^NP3oinai@?oXKKX2?nT^nT3ojJnjPCoZ<3[1onW
_NT3ojNlj0CoY[cY1onW_NT2ojRmj@GoZ<;/1onX`N/2oj_0j@GoZ<;/2?n[`NT00on/_nOo[<7Yojc1
j@04ojc1j@KoZ[oY0_n/`NT6ojO0j`KoZl7Y0_n[`NX7ok?4i`Wo]<KW0onN_>h3oibkkPKoLJ7_1?m`
W^d2of^Ok`?oSK;_0onB/^d8okS7iP03ol?=h_o3cnCo`loT00?o`loT00?o0000ol?AiOo3dND02?nd
bNX00onY`^coZ<7/ojS1k003ojS1k0SoYko[5?ooool00ol0003oooooooooo`0>ooooo`005oooool0
0ol0003oooooooooo`0@ooooo`coYko[2_nX`N/3ojNoj`_oY[o[1onX`N/6oj>lj`CoW;CY0ol00003
oi:Wi0;oSjGT1onG[^L6oj>nk0Co_=[_0_o2i_07olOVk@;o_MS]1on]a^`3ojBij0?oW;7V1onQ]^P6
ojBkj@03ojNojonX`>_oZ<3[00KoZ<3[1OnW_NT00onU^nSoY[cYojJlj@06ojJlj@GoYkgY00?oYl;/
ojS2k?nX`^`01_nX`^`5ojS1j`;oY/?^1onX`^`6oj_1j@;oZ<7[1on/`NT2ojZoj@Ko[<7Y1_nW`>/2
oj_1j@KoZl7Z1onca>L7okC6i`03ok?7jOnL^nkoW;_^00GoW;_^1_maXNl5og2Nk@OoT[;]1_nhanH0
0onjbNKo`loTol??i004ol??i004ol?AiOl0003o`m7Uol?Ai@Ko]<WZ00?o/LS[ojS1k?nX`N`01OnX
`N`6ojNoj`03ojS0jooooooooooo01?ooooo00?o0000ooooooooool03Oooool001Oooooo0_l0000B
ooooo`SoYko[3?nX`N/2ojO0j`coY[o[0_nX`>/7ojS1j`KoXkc[0ol00003ohnWiPKoSjGT1onG[^L3
oj>nk0Ko_=[_0oo7hn`4olOVk@Go_MS]1On]a^`2oj2hj@KoW;7V1onQ]^P2ojBkj@GoYko[2?nX`>/0
0onW_NWoYK_XojFkj003ojFkj0SoY[cY00?oYkgYojO2k?nW`^`00onW`^`8ojS2k003ojS1jonV`nko
Y/?^00CoY/?^1onX`^`2oj_1j@KoZ<7[1On/`NT2oj_1j@So[<7Y1_nW`>/8oj_1jPOo/lCW1?nda^L4
ok?7j@KoW;_^1_maXNl6og2Nk@KoT[;]1?nhanH4ok[9iP?o`loT0oo3dND01?l0003o`m7Uol?AiOo3
dND2okC9jPGo/LS[1onX`N`2ojNoj`GoZ<3[5?ooool00ol0003oooooooooo`0=ooooo`005oooool0
0ol0003oooooooooo`0Booooo`SoYko[2?nX`N/6ojO0j`SoY[o[1_nX`>/7ojS1j`?oXkc[0_l00000
0onL]N[oSjOVohnWiP04ohnWiPKoSjGT1onG[^L00onS_^co_=[_okcJk`04okcJk`Goan?/00?oanK]
okgHkOnmf>d01_nmf>d00on]a^coX;SYoj2hj@04oj2hj@KoW;7V1OnQ]^P2ojFljPOoYko[1_nX`>/0
0onU^nWoYK_XojFkj005ojFkj0KoY[cY0_nW`>`6ojO2k0KoZ<;/0_nV`^h7ojK3kP?oZ<;/1?nU`^h8
ojS1j`03ojc1jOn[`NWoZl7Y00CoZl7Y1_n/`NT00on]`^WoYl3[ojO0j`05ojO0j`SoZl7Z1onca>L0
0onda^Oo/lOYok?7j@05ok?7j@KoW;_^1_maXNl5og2Nk@OoT[;]00?o^<OVok[9i_njbNH01OnjbNH0
0oo3cnCo`m7Uol?Ai@03ol?Ai@03o`000?o3dNGo`M?X00So/LS[0onX`N`3ojJok0SoZ<3[5?ooool0
0ol0003oooooooooo`0<ooooo`005oooool00ol0003oooooooooo`0Cooooo`SoYko[1OnX`N/2ojW1
j`OoYl3[2?nV_n/6ojS0j`GoZ<7[00CoY;g[o`000?l0003o00001?nL]NX6ohnWiPGoSjGT1_nG[^L3
ojO0k0?o_=[_1_o7hn`3ol[SjPKo_MS]0_n]a^`7oj2hj@KoW;7V00?oXKKXojFlj_nU_>X01?nU_>X7
ojNoj`;oZ<3[1OnU^nT7ojFkj0;oY[cY1_nW`>`6ojO2k0;oZ<;/1_nV`^h5ojK3kP;oYKk[1onU`^h6
ojS1j`03ojO1k?n[`NWoZl7Y00KoZl7Y0_n/`NT5ojg2j@OoYl3[2?n[`NX5ok?4i`;o]<KW2?ncanT3
oibkkP;oUkO^1_maW>/4ogJNjP;oL9k]0onB/^d4oiVdjPKo^/WV0_nmc>H6ol?Ai@03o`000?o1dnSo
`M?X00Ko/LS[00?o[/K/ojJok?nV_n`01OnV_n`6ojS0j`03ojW1jooooooooooo01?ooooo00?o0000
ooooooooool02oooool001Oooooo00?o0000ooooooooool05Oooool7ojNoj`03ojS1jonY`N_oZL7[
00CoZL7[1onW`>/8ojJoj`KoZ<3[00?oZ<7[ojBmjol000000_l00002ojBmj`KoW;GZ1On?YnH6ohnU
i0;oUjkW1onW`>`00onlf^ooan?/olOSk003olOSk0Oob^?Z00?o_MS]ojg6k?n]a^`01?n]a^`7oj2h
j@?oW;7V0onQ^>T7ojFljPOoYko[1onU^nT5ojFkj0;oY[k[2?nW`>`3ojO2k0?oYl?]2?nV`^h00onV
`nkoYKk[ojFnj`04ojFnj`OoYL;^0_nX`N/5ojO1k0KoZl7Y00?oZl7Zojg2jOn]`^T01On]`^T8ojO0
j`SoZl7Z00?o/lCWokC6ionda^L01?nda^L6ok?7j@03ok37jonG]nkoUkO^00CoUkO^1_maW>/5ogJN
jPSoVKCZ0onjbNH5okg<iP?o`m7U0oo1dnP00ol0003o`M?Xok78j`03ok78j`Co[/K/1onV_n`2ojS0
j`GoZL7[5?ooool00ol0003oooooooooo`0;ooooo`005_ooool3o`0001Oooooo1OnW_n/3ojS0j`Ko
ZL7[1OnW`>/:ojJoj`?oZ<3[00CoZL7[o`000?l0003o00001_nT_N/6oibejPGoSjOV0on?YN@4oiJ^
i`KoYl3/1?noen`2olOSk0Oob^?Z0_o0f>`7ojg6k0?oX;SY0onJ/NP7oj6hj@OoYKcZ1onW_n/7ojFk
j@03ojFkj?nV_^_oY[k[00CoY[k[1_nW`>`00onXa>goYl?]ojO3k@05ojO3k@KoY/;^0_nW^nP7ojFn
j`?oYL;^1?nS_nd7ojO1k0;oZl7Y1On[`NX7ojg2j@SoYl3[1_n[`NX00on[`^[o]<KWokC6i`06okC6
i`;o/lOY1On`an/6oiNgkPKoLIc[1OmfW^X8oiVdjP03ok[9i_nmc>Ko_LcV00Go_LcV00?o`m7Uol7C
j?o1dnP00_o1dnP01?l0003o`M?Xol7Cj?nab>/6ojk6k0KoY[o/0_nV_n/7ojW1jaCooooo00?o0000
ooooooooool02_ooool001Kooooo00?o0000ooooooooool06?ooool00onW_n_oZ<3[ojS0j`05ojS0
j`KoZL7[00?oYl3[ojJojonV_n/02_nV_n/00onW_n_oZL7[o`000002o`0000CoZL7[1_nT_N/3oibe
jP;oSZ[X1_n<YNH7oiJ^i`?oYl3/1_noen`3olWNj0Cob^?Z1Oo0f>`5ojg6k0;oX;[[1_nJ/NP7oj6h
j@?oYKcZ1?nW`>/7ojNoj`?oYK_Y1?nT_>X7ojJnj`;oYl3/1OnXa>d7ojO3k@;oY/;^1_nW^nP5ojFn
j`03ojRmj?nS_ngoXko]00KoXko]1OnW`N`00onU_ncoZl7Zoj_1jP06oj_1jPGo[L;Y0_n]`nX8ojO0
j`;oZl7Z1On[`^X6okC6i`03okK8j?n`an_o/<O[00Ko/<O[1_nG]nh6og6Lj`GoMYkZ1_nI]>X00onS
^>So_LcVokg<iP05okg<iP03ol3@i_o1dnSo`M?X00Co`M?X00?o0000okcBjon^a^`01on^a^`2ojJo
k0KoY[o[1_nY`N/Cooooo`?o00002oooool000Cooooo1?l000002?l@413oooooooooooo^k^ko<S8b
o`000?lb<S;ok^k^1_ooool00ol0003oooooooooo`0Jooooo`OoZ<3[0onY`N/4ojO0j`SoY[o[0_nW
_n/3o`0000SoZL7[0onT_N/2oibhj`KoSZ[X1_n<YNH7oiJ^i`03ojO0k?noenco_mO/00Co_mO/1Oo9
g^P00oo:hn[o`=S/ol3Hk006ol3Hk003ojg6k?nP^^_oX;[[00CoX;[[1_nJ/NP5oj6hj@;oY;cZ1onW
`>/5ojNoj`03oj>kj_nT_>[oY;cZ00KoY;cZ1OnV_^/2ojS2k0OoZ<C]1OnW`nd2ojNlj0SoYk_X00?o
YKk[ojRmj?nX_NP00onX_NP8oj>ok@03ojO1k?nU_ncoYKo/00?oYKo/2?n[`NX00on]`^Wo[L?Zojg3
jP04ojg3jPOoYl3[2?n[`^X2okC6i`Go]/SX1_n`an/00onYa>goSJo]ohf_k@04ohf_k@KoLYWX1?mn
X>P2ogJNjP;oVKCZ1OnS^>P4okg<iPCo`=3V1?o1dnP2okcBj`03o`000?nld^_o[/K/00Go[/K/0_n[
a>`8ojJoj`KoZL7[3oooool3o`0000;ooooo00?o0000ooooooooool02Oooool000Kooooo00?o0000
ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool06ooo
ool5ojS0j`03ojW1jonW`>_oYl3[00KoYl3[1_nV_n/3o`0000CoYko[1_nY`N/00onU_ncoW;S[oibh
j`04oibhj`KoSZ[X1_n<YNH5oiJ^i`?oY[gY0onoen`6olWNj0?oc=kV1_o0f>`2ok39k0OoX;[[1_nJ
/NP00onQ^>WoY;cZojBljP04ojBljPOoYl3[00?oYko[oj>kj_nS^nX00onS^nX8ojBljP03ojJnjonX
`^coZ<;/00CoZ<;/1onXa>d00onW`ngoYkcXojNlj004ojNlj0KoYk_X00?oZkcVojRmj?nX_NP01OnX
_NP6oj>ok@;oY;k/1_nU_n`8oj_1jPOo[L?Z1onW`>/6oj_2jP;o[L?Z1onfb>P2ok37j`GoZLC]1_n=
[nd6og:Ij0GoOZ3X2?nS^>P00onmc>Ko`=3Vol3@iP05ol3@iP03ol7Cj?nld^_o_=;[00;o_=;[00?o
0000okcBjonld^/00_n^a^`6oj_4k0KoY[o[00?oYko[ojW1jonY`N/01OnY`N/;ooooo`?o00001Ooo
ool00ol0003oooooooooo`09ooooo`001_ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooo
ooooooooool@41001_ooool2o`0001gooooo00?oZ<3[ojW1jonY`N/00onY`N/8ojO0j`;oY[o[0ol0
0002ojJoj`KoYko[0_nY`N/5ojFok0KoW;S[1_n>Z^P6ohbUiP03oiJ^ionV_NWoY[gY00GoY[gY00?o
_mO/olWNj?o9g^P01?o9g^P6olcNiP03ol3Hk?n`bNco/<W/00Co/<W/1onP^^/3oiZaj0?oW[OY1onT
_>X5ojO0j`;oYko[1_nS^nX6ojBljP;oYko[1onX`^`3ojS4k@CoZ;oZ1onW_>P2ojNkj0GoZkcV1onX
_NP2oj>ok@KoY;k/1_nU_n`8oj_1jPGo[L?Z0_n/`n/7ojO0j`?oZl;Z1On]`nX5okK8j0;o]lcZ1onY
a>d6ohf_k@KoLYWX1OmnX>P6oj>hj0;o[/;X1_o0d>H3ol;Di`Co_=;[00?o0000okG=k?necN`02?n[
a>`2ojJoj`GoYko[1onY`N/6ooooo`Co00002?ooool00ol0003oooooooooo`09ooooo`001_ooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001Oooool2o`0001oooooo1_nY
`N/6ojO0j`03ojNojol0003o000000KoY[o[0onW_n/4ojW1j`KoYKo/1_nL^>/3ohjZj0;oR:KX1onB
[NP6ojJmj@?o_];Y1?o9g^P6olcNiP;oam[W1on`bN`3oj2jj`?oV;?[1onN]nT7ojBljP03ojO0jonW
_n_oYko[00CoYko[1_nS^nX2ojBljPKoYko[1OnX`^`00onZ`ncoZ;oZojRojP06ojRojPGoYkcX00?o
Yk_Woj^li_n[_>H01_n[_>H5ojRmj0;o[<7Y2?nT_^`3ojFok0?oYKk[2?n[`NX00on]`n[o[<?[ojc3
j`04ojc3j`OoYl3[00?oZl;Zojg3j_n]`nX01On]`nX00onfb>So]lcZokO<jP04okO<jPOoZLC]1_n=
[nd6og:Ij0GoOZ3X0_nS^>P6ojk2j0?o`=3V1_o2e>L01Onld^_o]Lg/okG=k?necNco000000;o]Lg/
1_n[a>`00onW`NcoYko[ojNoj`05ojNoj`KoZL7[00CoZ<7[oooooooooooooooo0ol0000=ooooo`03
o`000?oooooooooo00Sooooo0006ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`000005ooooo`03o`000?oooooooooo01oooooo1_nY`N/2ojO0j`04ojNojol0003o0000o`00
00;oYko[1onV_n/7ojW1j`KoYKo/0onL^>/3oi2`k0GoR:KX1onB[NP3ojJmj@Oo_];Y00?obMkXolcN
i_o<g^H01?o<g^H4olOJi`Go/<W/0_nT`>d6oiRcj`OoW[OY0onT_>X;ojNoj`?oXk_Z1?nT_>X7ojNo
j`03ojS2k?nZ`ncoZ/?/00?oZ/?/2?nX_nX00onW_>SoYk_WojNki`03ojNki`SoZkcV00?oZ;gXojc1
jOn/`NT01?n/`NT7ojBnk0OoYKk[1_n[`NX00on[`^[o[<?[ojc3j`06ojc3j`?oYl3[0onX`>/7ojg3
jP;o[lGZ1ongc>X3ojW4k@?oXKc/1_n2XnT6ogNGi@GoQjCW2On^`^P00oo0d>Ko`]CWol;Di`04ol;D
i`03ol?GjOnecNco]Lg/00?o]Lg/00?o0000okG=k?necN`00_n[a>`5ojO1k0OoYko[0_nY`N/5ojS1
j`;o00004?ooool00ol0003oooooooooo`08ooooo`001_ooool00ol0003oooooooooo`02ooooo`05
oa0@4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`0Pooooo`?oZL7[0_nX`N/3o`00
00KoYko[1onV_n/7ojW1j`?oYKo/1?nO^^`5oi2`k0GoR:KX1onB[NP00onV_NWo_];YokkBj@05okkB
j@?ob=SU0oo<g^H7olOJi`03ok39k?nT`>goY<3]00CoY<3]1_nH/n/5oijgj@03oj>ljonW_n_oYko[
00_oYko[00?oXkc[ojBlj_nT_>X01_nT_>X5ojNoj`;oZL7[1_nZ`n`6ojRojP03ojBlj_nW^nOoYk_W
00GoYk_W1_n[_>H2ojg2j@Oo[<7Y1onT_^`7ojFnj`;oZl7Z1On[`^X6ojc3j`03oj[3k?nX`>_oZ<3[
00GoZ<3[1?n]`nX5ojo5jPGo]lcZ0_ncc>`6oj6lk0KoPZ?Y1_mgUnD5ohNTi`Oo[/;X00?o]/[Yol;D
ioo2e>L01?o2e>L3ol?Gj@Co]Lg/00?o0000okG=k?n`bN`02?nW`N`3ojNoj`_oZ<7[4Oooool00ol0
003oooooooooo`08ooooo`001_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2o`0002;ooooo00CoZ<7[o`000?l0003o00000onX`N/5ojNoj`WoY[o[1OnY`N/3
ojO1k0KoWk[/1On@/>`5ohRVj0GoTZgX0onO^>X5okkBj@Gob=SU00?oc=kVolOJioo7f^L01Oo7f^L2
ok[?jPOoY<3]1_nH/n/00onN]nWoXkc[oj>lj`03oj>lj`WoYko[1OnS_>/8ojBljP03ojNojonY`N_o
ZL7[00CoZL7[1_nZ`n`2ojRojPGoY;cZ1onW^nL2oj^liPKo[L;Y1On/`NT2ojc4j`OoY;k/1OnU_^/2
ojNoj`OoZl;Z0_n/`n/5oj[3k0OoZ<3[00?o[L?Zojo5j_n_aNX01_n_aNX00ongc>[o/lc/ok?<k004
ok?<k0KoXKc/1On2XnT6ogNGi@KoQjCW1?n^`^P4okK:j@?o`]CW1_o3enT2okG=k0;o/<W/00?o0000
ok39k?n`bN`01_nW`N`00onV_^_oZ<7[ojS1j`0<ojS1ja7ooooo00?o0000ooooooooool02?ooool0
00Cooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000
ooooooooool07oooool3o`0000OoZ<7[00?oYko[ojJojonV_n/02onV_n/00onY`N_oYl7/ojO1k005
ojO1k0KoWk[/1On@/>`5ohRVj003oi:]j?nO^>[oWkSZ00GoWkSZ0onnd^T5olSHi@?ocMWR1?o7f^L5
ok[?jPOoY<3]0onH/n/3oiZdjPKoXkc[1_nW_n/2ojO0j`KoXkc[1_nT_>X2ojJoj`OoZL7[0onZ`n`3
ojK0k0OoY;cZ1OnW^nL2ojO0j`So[L;Y00?o[<7Yojc4jon/a>/01?n/a>/7ojBnk003ojFnjonW_n_o
Yko[00CoYko[1On[`^X2ojg4j`OoZ/?/1OnX`>/2ojW1j`Oo[lGZ00?o]<[[ok?<k?ncc>`01_ncc>`3
oj6lk0;oUK7Z1?mlV><2oh:Sj@KoMiOU1_n7Y>L00on^`^So]/[YokK:j@05okK:j@03ol;Dioo3enWo
`mOY00Co`mOY00?o_MO]ok39k?n`bN`00on`bN`00ol0003o/<W/ok39k002ojO1k0GoY[k[3_nX`N/@
ooooo`03o`000?oooooooooo00Sooooo000Eooooo`03o`000?oooooooooo01cooooo0ol00004oooo
o`GoZ<7[0onW`>/:ojJoj`CoZ<3[1onW`N`3oinjk0;oUkK]1On6YnX6ohfZj@SoWkSZ00?o_];YolSH
iOo8f>D00oo8f>D6olgIhP03olOJionjcn[o^/oZ00Go^/oZ0onT`>d3oiZhk@OoV[CZ1_nS_>/2ojNo
j`KoYl3[1_nS_>/2ojBljPKoY[o[1OnY`N/00on[`^[oY/3/ojK0k005ojK0k0OoY;cZ00?oYk_WojO0
jonW`>/01?nW`>/6ojg2j@;o[LO]1on/a>/3ojBnk0?oY;c[2?nW_n/00on[`^[o[LC[ojg4j`04ojg4
j`OoZ/?/00?oZ<3[ojW1jonY`N/01?nY`N/4ojo5jPCo]<[[1_ncc>`00onZa>goUK7ZoiFajP04oiFa
jPGoO9SS1_moV^<6oiN]iPOo]/[Y0_nmdNT4ol?Gj@Co_MO]1On`bN`00ol0003oZlG/ojJnj`06ojJn
j`KoZ<7[00?oZL7[ojS1jonX`N/01_nX`N/?ooooo`03o`000?oooooooooo00Sooooo000Eooooo`03
o`000?oooooooooo01Wooooo0ol00008ooooo`03ojS1jonW`>_oYl3[00GoYl3[1_nV_n/8ojS0j`Go
Yl7/00?oXkk/oiNfkOnG]^d01?nG]^d5ohJWjPKoSJ[Y1_nO^>X3okK7i`?ob=SU1_o=fN83olgGh@Go
^/oZ0on_a^/5oiZhk@OoV[CZ0onS_>/4ojFnj`OoYl3[0onS_>/3oj:lk0SoY[o[00?oZL7[oj_2j_n[
`^X00on[`^X7ojK0k0?oY;cZ1?nQ_^d7ojO0j`;o[L;Y1_n]and5ojc4j`03ojS1jonT_>_oY;c[00Go
Y;c[1_nW_n/2ojS1j`Oo[LC[0onZ`n`3ojO0j`SoZL7[00?o[lGZokC:jondb^/01Ondb^/2ok?<k0Go
Z/C]1_nE/NX5ogbHh`KoOi[S1_nG[NH4okK:j@Go_M7Y00?o`mOYokgGkOnmend01Onmend2ok39k0;o
ZlG/00?o0000oj_5k?n[aN`01onV_^/2ojS1j`GoZL7[1_nX`N/00onX`>_oooooooooo`0=ooooo`03
o`000?oooooooooo00Sooooo000Eooooo`03o`000?oooooooooo01Kooooo0ol0000=ooooo`OoYl3[
1_nV_n/8ojS0j`03ojO1k?nS_^coXkk/00?oXkk/1_nG]^d5ohJWjPKoSJ[Y0_nO^>X7okK7i`03olSH
iOo=fN;ocMWR00CocMWR1Oo=en400onjcn[o[lK[ojo6j`05ojo6j`GoV[S]1OnJ]>X00onO^^_oYKk[
ojFnj`06ojFnj`GoYl3[00?oYKo/oj:lk?nR_>`01OnR_>`6ojJoj`;oZ<3[1_n[`^X5ojK0k0;oX[k]
1onQ_^d5ojO0j`;oYlG_2?n]and00on/a>_oZ<7[ojS1j`03ojS1j`OoY;c[0_nW_n/6ojS1j`Go[LC[
0_n/aN`6ojO0j`KoZL7[0_n/a>/6okC:j`;o]Lo]1_nZa>d6oiFajPKoO9SS1_moV^<6oiN]iP03okK:
jOnmdNWo_M7Y00Co_M7Y0_o1f>/6okgGk@;o]Lo]1?n[aN`00ol0003oZlG/oj_5k003ojJnj`CoYkk[
1onY`N/2ojS1j`GoZ<3[3oooool00ol0003oooooooooo`07ooooo`005?ooool2o`0001Gooooo0ol0
000Aooooo`GoYl3[2?nV_n/6ojS0j`;oZL7[1_nS_^`6oiNfk@GoQZOZ0on=Z^T4oiNbjPKo]/OW0oo4
dN@4olgIhPGocMOQ0oo7dn<7ojo6j`GoV[S]00?oV[CZoinjjonO^^/00onO^^/8ojFnj`03ojO0jonU
_ncoYKo/00?oYKo/1onR_>`2ojJoj`KoZ<3[1_n[`^X00onV`>coX[k]oj:nk@04oj:nk@OoXKk]00?o
Yl3[ojO5konWaNl01?nWaNl6ojg7k@03oj_5kOnX`N_oZ<7[00GoZ<7[1OnT_>/2ojFmjPSoZ<7[00?o
[LC[ojc5k?n/aN`01?n/aN`6ojO0j`;oZL7[1_n/a>/3okC:j`Go]Lo]1_nZa>d6oiFajPKoO9SS1_mo
V^<3oiN]iPCoYkcX0onmdNT5ol7Hj`?o_MO]1Onecnd4oj_5k003o`000?nW`>coYkk[00OoYkk[1OnY
`N/2ojS1j`OoZ<3[3_ooool00ol0003oooooooooo`07ooooo`005?ooool00ol0003oooooooooo`0B
ooooo`;o00005Oooool00onW`>_oY[o[ojJoj`0:ojJoj`;oZ<3[1_nY`N/6oj>nk0?oUkK]0on9[nh5
ohFWj`OoUk;Z0onfanL7olCAi003olgIh_o=en7ocMOQ00?ocMOQ1Oo7dn<5ojo6j`03ojG1kOnE]Nko
UKG^00CoUKG^1_nO^^/6ojFnj`;oYko[1_nU_n`5oj:lk0;oXkg/2?nX`>/3oj_2jP?oZl7Z1onR_^d3
oj6nk@CoX<7`1onWaNl2ojg7k@GoZlG]1onX`N/00onT_>_oYKgZojFmjP04ojFmjPKoZ<7[00?oZlC/
ojc5k?n/aN`01_n/aN`3ojO0j`?oZ<3[2?n/a>/00ondb^_o]Lo]okG?k@05okG?k@?oZ/C]0_nO]nT6
ohNOh`KoOiKO1_n9X><8ojNlj003okgAjOo1f>_o`MS[00Go`MS[00?o_MO]okG?kOnecnd01Onecnd0
1_n[aNcoYl3/ojO0k?nW`>co0000ojO0k0SoYkk[00?oZL7[ojS1jonX`N/01?nX`N/5ojS0j`03ojNo
jooooooooooo00cooooo00?o0000ooooooooool01oooool001Cooooo00?o0000ooooooooool03ooo
ool3o`0001Sooooo3_nV_n/7ojW1j`?oXkk/1?nM^nd5ohV_kPGoQJO[1onG/^X00onfanOoa=7TolCA
i005olCAi0?ob];P0oo=en47olOCh`03ojo6jonU`NgoYL7]00?oYL7]1_nE]Nh6oinjj`;oYKk[1_nW
_n/6ojFok003oj:lk?nS_NcoXkg/00CoXkg/1_nX`>/00onY`N[oZl7Zoj_1jP05oj_1jPGoX[k]0_nR
_N`7oj31l0GoYlG_0_nWa>h7oj_5k@?oZ<7[1?nU^nT7ojFmjP;oZ<7[1On[a>`6ojc5k003ojS1jonX
`>_oZ<3[00GoZ<3[1_n/a>/2ok39k0Ko]Lo]00?o[/W]oingjOnO]nT01?nO]nT6ohNOh`KoOiKO1_n9
X><6ojNlj003okG<joo1f>_o`MS[00Go`MS[0_o1fnd6okG?k@03ojk8kOnW`>coYl3/00;oYl3/00?o
0000ojO0k?nW`>`01_nW_^/9ojS1j`03ojS0jonW_n_oYko[00?oYko[3Oooool00ol0003ooooooooo
o`07ooooo`005?ooool00ol0003oooooooooo`0<ooooo`?o00007?ooool>ojJoj`GoZL7[0onW`>`6
oifkk@GoRJo^1On5Yn/5oiNbjP;oYkcX1_o4dN@5ol[Bh003olgGhOo7dn?oam?S00Goam?S0_nnc^H6
ojG1k@KoUKG^0onO^^/3oj:lk0SoYko[0onU_n`3oj:nk@OoXkg/0_nX`>/5ojW1jPOoZl7Z00?oX[k]
oj:mk?nR_N`01?nR_N`7oj31l003ojO5konWa>koYlC^00CoYlC^1On[aNd00onW_NWoYK_YojFkj@06
ojFkj@GoYKgZ0_nX`N`7oj_4k0;o[<G/1OnX`N/7ojS0j`;o[<C[1_n`bN`2okG?k@Go[/W]1_nO]nT6
ohNOh`GoOiKO1_n9X><4ojNlj0Co]Lc[1?o1f>/5ol7Kk@;o]Lo]1On^b>d4ojO0k003o`000?nW`>co
Yl3/00;oYkk[3?nX`N/7ojNoj`cooooo00?o0000ooooooooool01oooool001?ooooo0ol0000:oooo
o`?o00008?ooool>ojJoj`03ojW1jonW`>coYl3/00GoYl3/1_nM^nd5ohV_kPGoQJO[00?oUk;ZojNl
j?nW_>P01?nW_>P3olCAi0Kob];P0oo=dMd4olOCh`Go_/kV1_nU`Nd3oiFekP?oU[O^1_nR_>`6ojNo
j`;oYl3[1_nR_^d5oj>mk0;oY;o/1onY`NX5oj_1jP;oZl3Y1onR_N`3oj31l0CoY;o]1onWa>h00on[
aNgoYkgYojNmj@03ojNmj@SoYK_Y00?oYKgZojS1k?nX`N`01?nX`N`5oj_4k0;oZlG]1onX`N/5ojS0
j`;oZlC/1_n`bN`2okCAk`Oo[/W]1_nO]nT5ohNOh`GoOiKO1on9X><00onW_>So]Lc[okG<j`05okG<
j`03ol7Hjoo1fngo`M_]00Co`M_]00?o^]O_ojk8kOn^b>d01_n^b>d3ojO0k003ojJnjol0003oY[k[
00ooZ<7[1onW_n/;ooooo`03o`000?oooooooooo00Oooooo000Dooooo`03o`000?oooooooooo00Ko
oooo0ol0000Uooooo`_oY[o[0onX`>/7ojO0k0?oWK_]0_nF]nl5oh6XkPKoRjc/1onW_>P00oo4dNCo
b];Pol[Bh004ol[Bh0GocM7M00?oam?Sokk>i_nnc^H01_nnc^H3ojG1k@?oW[g^1_nF]nh6oj:lk0;o
Yko[1_nW`>/6oj:nk@03oj>mk?nT_ncoY;o/00CoY;o/1onY`NX00on[`N[oZl3Yoj_0j@04oj_0j@Go
X[g/0_nV_NT7ojBok@GoYlC^2?nW_NT6ojFkj@03ojNojonX`NcoZ<7/00KoZ<7/00?oZlC/oj_5kOn[
aNd01?n[aNd7ojS1j`03ojS0jon[a>coZlC/00CoZlC/0on`bN`5okCAk`Go[/W]00?oX[WYoi2Th_n@
Y>801?n@Y>84oh>Eg0;oQioS1OmoU]l3ohVPh`CoVJgU1_nec>/2okgGk@Co`M_]1?njenl6ojk8k@03
ojW3k?nV_^_oY[k[00;oY[k[00?o0000ojJnjonV_^/01_nX`N/00onX`NcoZ<7[ojS1j`06ojS1j`?o
Yko[0onV_^/;ooooo`03o`000?oooooooooo00Oooooo000Dooooo`03o`000?oooooooooo00?ooooo
0ol0000Yooooo`OoY[o[1onX`>/5ojO0k003ojBokOnF]nooU[O_00CoU[O_1On1Z>h6oh^/k0GoYkcX
0onhaN@4ol[Bh0GocM7M0oo=cm/6okk>iP;o]lSW1_nN_Nh6oiJgkP?oX[c/1?nS_^`7ojO0j`?oX[k]
0onQ_^d7ojBok0?oZL7Z1?nY`N/7oj_0j@03oj:mk?nV_NWoY[gY00CoY[gY1onT_nd00onWa>koYkgY
ojNmj@0:ojNmj@;oYK_Y1OnW_n/6ojS1k0;oZ/K^1on[aNd3ojS1j`?oYl3[2?n[a>`00on`bNco]=7_
okCAk`05okCAk`03ojk9kOnR^NWoX[WY00?oX[WY1_n@Y>85oh>Eg0GoQY[O2?nI[ND3okG<j`Go_MO]
00?o`M_]ok[Gkonjenl01Onjenl2ojk8k@GoZL?/1?nV_^/00ol0003oY[k[ojJnj`02ojS1j`GoZ<7/
1_nX`N/00onW`>_oY[k[ojJnj`05ojJnj`_ooooo00?o0000ooooooooool01_ooool001?ooooo00Co
0000oooooooooooooooo0ol0000]ooooo`?oY[o[0onV_n`8ojS0j`03ojO0k?nT_ngoY;o]00?oY;o]
1_nF]nl5oh6XkPKoRjc/00?oYkcXokS5i?nhaN@01_nhaN@00oo:d^3ocM7MolgAg@03olgAg@GocLoK
0onnc^H5okO8i`KoW[g^0onF]nh3oiRik`OoXkk/1onW`>/6oj6nk@GoY;o/0_nT`>d7ojW1j`OoZl3Y
1onV_NT3ojBok@CoZ;gX2_nW_NT3ojJnjPOoYko[0_nX`N`6oj[6kPGoZlG]2?nW`>/6oj_4k0;o[/[_
1_nddNl00on^bNgoX[WYoj:ij@05oj:ij@GoT:CR1_n3UM`5ohJJg`SoVJgU00?o]Lc[okgGkOnmend0
0onmend3ol3MkPGo^]O_0_n`c>h7ojW3k0?oY[k[00?oZ<3[o`000?nX`>/02?nX`N`2ojS1j`GoYl3[
1onV_^/:ooooo`03o`000?oooooooooo00Kooooo000Cooooo`Co0000<Oooool6ojJok0KoZ<3[0_nY
`N/6ojBok@KoU[O_1On1Z>h3oh^/k0?oU;?/1onhaN@3ol?;h@?ocM7M1oo=cm/00onnc^Ko]lSWokO8
i`05okO8i`?oW[g^0onI^o06oiRik`OoXkk/1onW`>/6oj6nk@03ojBok?nT`>goY<3]00CoY<3]1onY
`N/7oj_0j@GoY[gY00?oZ[oYojRmj?nX_NP01_nX_NP5ojNmj@;oYkkZ1_nV_^X5ojNoj`;oZ<C^2?nZ
a^h00on[aNgoYl3[ojO0j`0:ojO0j`;oZlC/1_n^b^l2okCAk`Go[/W]1_nR^NT5oi2ThPKoPiGL1_n6
V]l6oiV]i@;o[/K/0onmend6ol3MkP03ok[Gkon`c>ko/<c^00Co/<c^1OnY`n`2ojJnj`CoZ<3[00?o
0000ojS0jonX`N`01OnX`N`00onX`N_oYl3[ojO0j`06ojO0j`?oY[k[0onW_n/:ooooo`03o`000?oo
oooooooo00Kooooo000Cooooo`;o0000=?ooool6ojJok0;oZ<3[1_nY`N/6ojBok@?oU[O_0_n:/_45
oh2YkPOoU;?/1?nhaN@6ol?;h@03olgAgOo=cm_ocLoK00GocLoK0oo;c=X5okO8i`;o//CW1_nI^o06
oiRik`?oXkk/1?nT_n`7ojO0j`KoXKk]1onT`>d3ojW1j`CoZ<7/1on[`>T00onV_NWoZ[oYojZoj@03
ojZoj@SoZ;gX00?oYkgYojNnj_nW_^X01?nW_^X6ojJnjP03ojNojonXa>koZ<C^00CoZ<C^1_nZa^h0
0onZ`ncoYl3[ojO0j`09ojO0j`CoZ/G]1On^b^l2ok;Bl0Oo[/W]1_nR^NT5oi2ThPKoPiGL1_n6V]l2
oiV]i@Ko[/K/00?o_MO]ol3Mk_o0gNh01?o0gNh00onlg?3o/<c^ok3<kP06ok3<kP03ojW3k?nV_^_o
Y[k[00CoY[k[0onX`>/00ol0003oZ<3[ojS0j`02ojS1k0GoZ<7[1_nW`>/00onV_^_oYko[ojNoj`05
ojNoj`Wooooo00?o0000ooooooooool01_ooool000Go00000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Sooooo00?o0000ooooooooool0<_ooool3ojJok0CoY[o[1onY`N/3ojBok@?oWkg^1On:/_45
oh2YkPOoU;?/00?o^<GTol?;hOo3bn401Oo3bn42olO;g@KocLoK1Oo;c=X00ongb>Oo//CWok;4i`04
ok;4i`KoVK_`0onH^Nl4oiVkl0KoY;o/1onW`>/6oj6nk@GoY<3]0_nS`Nh7ojS1k0GoZl3Y0_nY`N/6
ojZoj@KoZ;gX00?oZL3ZojNnj_nW_^X01_nW_^X3ojJnjP?oYl?]1onXa>h2oj[6kPGoZ/?/1_nW`>/0
0onX`^coZ/G]oj[5k@06oj[5k@03ojk:konbd_3o/];`00Co/];`1On^bNd00onS]^KoUJ?OoiFSg`04
oiFSg`GoR9KJ1_n8V=`6oi:UhPOo[/K/0_nieNl4ol3MkPCo_=c`1_n`c>h00on[a>goY[k[ojJnj`06
ojJnj`?oZ<3[00?o0000ojS1k?nX`N`01onX`N/2ojO0j`GoY[k[1onW_n/8ooooo`03o`000?oooooo
oooo00Kooooo00001OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`09ooooo`03o`000?oooooooooo03?ooooo1_nV_n/7ojW1j`KoWkg^1On:/_45oh2YkPGoU;?/0onO
^^/5ol?;h@Coal_M0oo=cm/6ol_<fP;obLWJ1onba>L3oiVkl0?oUk[`1onI^o06ojBok0OoYl3[1_nQ
_^d00onT`>goXl7^oj?1kP04oj?1kPOoZ<7/00?oZl3YojW1jonY`N/01?nY`N/6ojZoj@;oZ;gX1OnY
`>X6ojNnjPSoYl?]1OnXa>h2ojW5kPOoZ/?/0_nW`>/5ojS2k0KoZ/G]0_n^co47ok;Bl003ojk9kOnS
]^KoXkKV00?oXkKV1_nEXml5ohRFfPKoR9SL1_nBYN84ojk6k0Go^MG_00?o`=g^okcLl?nlg?001Onl
g?02ok3<kPGoZlC]1_nV_^/00onW_n_oZ<7/ojS1k002ojS1k003o`000?nX`NcoZ<7/00GoZ<7[00?o
Z<3[ojJnjonV_^/01OnV_^/6ojNoj`03ojS0jooooooooooo00Kooooo00?o0000ooooooooool01_oo
ool00004oooooonHV9So8B4Qonk^kPCooooo00Go410@oooooooooooooooooa0@400:ooooo`03o`00
0?oooooooooo03?ooooo1_nV_n/7ojW1j`KoWkg^1On:/_45oh2YkP03oiBck?nO^^_oWk[[00GoWk[[
0oo3bn46olO;g@03olg?foo;c=[oblcJ00CoblcJ1?o9bMX5ok;4i`;o/<;W1_nG^_07oiVkl0?oY;o/
0onT_nd7ojO0j`?oXKk]0onR_^d7oj?1kP?oZ<7/1?nV`^h7ojW1j`?oZ[oY0onX`N`7ojW0jP;oYkkZ
3?nW`nd00onXa>koZLG^ojW5kP04ojW5kPGoZ/?/0_nW`>/7ojS2k0;oZ/G]1_n^co43ok;Bl0?oZlC/
1onS]^H5oiFSg`KoR9KJ1_n8V=`6oi:UhP03ojk6k?nieNoo^MG_00Co^MG_0_nngo06okcLl003ok7>
kon[a>goZlC]00KoZlC]0_nV_^/5ojNoj`CoZ<7/00Co0000ojS1k?nX`NcoZ<7[1OnX`>/7ojJnj`;o
Yko[1OnX`>/7ooooo`03o`000?oooooooooo00Kooooo0002ooooo`03oiRHV?lQ8B7ok^k^00?ooooo
00Go0000ooooooooooooooooo`00000;ooooo`;o0000=?ooool3ojJoj`?oYko[1onY`N/3oinmkPCo
Vk__1On1[_85oh>/k`OoWk[[00?o`l_QolO;gOo7bmd01?o7bmd3olW:fPCoblcJ1_o9bMX00onba>Oo
/<;Wok32i`04ok32i`KoUk[`0onI^o04oiRml@KoY;o]1onW`>/6oj:nk@GoXl7^0_nR`>l7ojK2kPGo
ZL7[0_nV`nh6ojS1k0GoZL3Z0_nW`nh:ojO3k@GoZ<K_1_nYaNh00onZ`ncoYl3[ojO0j`04ojO0j`Go
Z<;/0_nZb?06ojk?l@;o[lk`1_n[a>`6oj>fiPGoUJ?O1_n8U]X7ohRHg0?oTZGR1?nX`>/3okWEk`Go
_]o`0_nlg?05ok7>k`KoZlC]2OnW_n/3ojS1k003o`000?nX`NcoZ<7/00OoZ<3[1_nV_^/8ojS0j`Oo
oooo00?o0000ooooooooool01Oooool000?ooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooo
oooooooooooo000000gooooo00?o0000ooooooooool0<_ooool6ojNoj`GoZL7[0onW`>`6oi^kk`Go
PJkb1On3[>l5oinjj`;o[;oX1Oo7bmd6olW:fP03ol_<f_o9bM[obLWJ00CobLWJ0_o7aMT7ok32i`Oo
Uk[`1_nH_O46ojBok@OoYl3[1_nR_^d00onS`NkoX/3_oj;0k`04oj;0k`OoY/;^00?oZL7[ojK3k_nV
`nh01?nV`nh6ojS1k003ojW0j_nW`nkoYl?^00CoYl?^1OnW`nd2ojO5k`SoZ<K_0onYaNh:ojO0j`03
ojS2k?nZb?3oZ/S`00CoZ/S`0on^co45ojo>l0KoZlC/1_nS]^H5oiFSg`KoR9KJ0on8V=`3oi:Sh0So
Z<3[00?o^MG_okkOl?nngo000onngo02ok_Nl@Oo/Lk_0_n[a>d;ojNoj`GoZ<7/00?o0000ojS1k?nX
`N`01OnX`>/2ojNoj`KoY[k[1_nX`>/00onX`N_oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo0004ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`0<ooooo`03
o`000?oooooooooo03;ooooo1_nW_n/00onY`N_oYl3/ojO0k005ojO0k0KoVk__1On1[_85oh>/k`03
oinjjon/_nSo[;oX00Co[;oX0oo7bmd6olW:fP;ob/SH1Oo9bMX4olO5f@Go/<;W0_n``>H7oiNjl0Ko
V;ga0onT_nd3oj?0kPOoYl3[0onR_^d3ojFok0OoX/3_0onV`^h3oj?2k`SoY/?^0onX`N`4ojK4k`Ko
Yl?^00?oYl?]ojO5konWaNl01?nWaNl6ojS6k`goYl3[0_nXaNh7oj[8l003ojk?lOn_c_3o[lk`00Go
[lk`0on[a>`2oj6^h0KoUIkI1On=UML6ohbHfPOoTZ?P1_nX`>/2okKFl0?o_]o`1Onkg_45ok7>k`;o
ZlG]2OnW_n/9ojS1k004o`000?nX`NcoZ<7/ojS0j`KoYko[1_nV_^/2ojS0j`GoZ<7[1_ooool00ol0
003oooooooooo`05ooooo`0000Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03oooool00ol0003oooooooooo`0booooo`?oYko[1?nX`>/7ojO0k0?oVk__0_nF^O05
ogZ[lPKoQk3`1on/_nP00oo7bmgobL[JolW:fP04olW:fPCob/SH0oo9bMX6olO5f@03ok32ion``>Ko
/<3V00Co/<3V1onG^_03oiRml@?oU[kc1_nS`>h5ojO0j`;oYl7/1_nU_n`5oj;0k`;oX[k]1_nS`^l6
ojK3kP;oY<?_1onVa>l3ojO3kP?oY/C_1onWaNl2ojS6k`goYl3[1_nXaNh5oj[8l0?o[]?c1On_c_00
0onW^NKoXJkPoj6^h004oj6^h0KoUIkI1On=UML6ohbHfPOoTZ?P0_nX`>/6okKFl003okkOl?nkg_7o
^mka00Go^mka00?o/Lk_oj_5kOn[aNd01?n[aNd6ojNoj`_oZ<7/00?oZ<3[o`000?nX`>/02?nW_n/3
ojJnj`;oZ<3[2?nX`N/5ooooo`03o`000?oooooooooo00Gooooo00001OnHV9So410@o`000?lQ8B7o
c<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0@ooooo`;o0000=?ooool6ojS0j`GoYl3/0_nU
_n`5oiJil0GoNZ_b1_n7/?05ojboj0;o]<;T1Oo9b]X6ol[8f003olW9f_o7aMWoalGI00CoalGI0_o5
`]L7ok30iP?oUk[`1?nI^o06oiJnl`KoXl3^00?oYl3[ojO1k?nW`N`01?nW`N`6ojFok003oj;0konR
_^goX[k]00CoX[k]1_nS`^l2ojK3kPKoY<?_1OnVa>l2ojG2kPKoY/C_1OnWaNl<ojO0j`CoYlC^1onX
aNh00onZb?3o[]?cojkCl`05ojkCl`03ojo>l?nW^NKoYkWV00?oYkWV1_nQ[^05oiFNf@KoSIGG1_n<
V=X5oi:Sh0;oYl7/1_nfe_02ok_QlPKo^mka0_n`c^l7oj_5k@KoYko[1onX`N`4ojS0j`03o`000?nX
`>_oZ<3[00KoYko[00?oY[k[ojS0jonX`>/01?nX`>/7ojS1j`Gooooo00?o0000ooooooooool01Ooo
ool001oooooo00?o0000ooooooooool0<_ooool6ojS0j`03ojO0k?nU_ncoYKo/00CoYKo/1OnF^O05
ogZ[lPKoQk3`00?o[;oXokC2i?nd`^@01?nd`^@3olW:fPKob/SH0_o9a]L5olO5f@CoaL;G1On``>H3
ok6nh`KoVK_`1_nF__<3oj?0kP?oXL;`1onW`N`3ojFok0?oYl3[1onR_^d3oj?2k`CoXko]1onT`nl0
0onVa>ooYL;^ojG2kP04ojG2kPKoY/C_00?oYlG_ojO0jonW`>/02OnW`>/2ojO3k@OoYlC^0onXaNh4
oj[Am0Ko[]?c00?oZl?[ojNii_nW^NH01?nW^NH6oj6^h0GoUIkI1_n=UML7ohbHfP03oi:Sh?nW`Nco
Yl7/00CoYl7/0onfe_05ok_QlP;o^mka1_n`c^l3oj_5k@[oYko[1onX`N`4ojS0j`03o`000?nX`>_o
Z<3[00;oYko[1OnV_^/6ojS0j`OoZ<7[1?ooool00ol0003oooooooooo`05ooooo`008?ooool00ol0
003oooooooooo`0booooo`?oZ<3[0onY`>/7ojFok0GoU[W`1OmjZo83ohN`l0?oS;Ca1ond`^@00oo9
b][ob/SHol[8f004ol[8f0CobLKG0oo7aMT6olG2e`03ok30i_na_^?o/KkS00Go/KkS1_nI^o03oiJn
l`?oTkkd1_nQ`_05ojO1k0;oYL;^1_nW`>/5oj:nk@;oYko[1onS_nd3ojC3k`?oYKo/2?nU`^h3ojK4
k`_oYl3[1_nW`nd5ojO4kP;oYlkd1onZdO@2ojkCl`GoZl?[1_nW^NH6oj6^h0GoUIkI1_n=UML3ohbH
fP?oUJGP2?nW`N`00onfe_3o^n7bok_QlP03ok_QlP?o^Mkb1On`c^l00on[aNgoYko[ojNoj`0:ojNo
j`WoZ<7/0onX`>/00onW_n_o0000ojNoj`08ojJnj`?oZ<3[2_nX`N/3ooooo`03o`000?oooooooooo
00Gooooo000Qooooo`03o`000?oooooooooo03;ooooo1_nY`>/5ojFok0?oXko]1?n@^?85ogR/l`Ko
S;Ca1Ond`^@3ok[4hPCob/SH1_o9a]L00oo7aMWoaL;GolG2e`04olG2e`03olFoe?na_^?o/KkS00Oo
/KkS0onI^o03oijkk@KoTkkd1_nQ`_000onW`NcoYL;^ojG2kP04ojG2kPKoYl3[00?oX[k]ojNojonW
_n/01?nW_n/5oj>ok@;oYl3[1_nU_n`6ojG2kPgoYl3[2OnW`nd00onWa>koYlkdojO>m004ojO>m0Go
Z]7d0_n/bNl7oj_3j`?oYkWV0_nMXML6oiFHe0GoT9KE1_n@V]T7oiFUh0KoYl7/0ondfO<00onkhO;o
^MkbokWNlP05okWNlP03ok3>kon[aNgoZlG]00?oZlG]2?nW_n/;ojS1k003ojS0jonW_n_oYko[00;o
Yko[00?o0000ojNojonW_n/01_nV_^/00onW`>_oZ<7[ojS1j`0:ojS1j`03ojO0jooooooooooo00;o
oooo00?o0000ooooooooool01?ooool002;ooooo00?o0000ooooooooool0<_ooool6ojW0j`03ojFo
k?nS_ngoXko]00GoXko]1?n@^?85ogR/l`KoS;Ca00?o]<;Tok[4h_nja>801_nja>800oo:b=SobLKG
olW6e`04olW6e`;ob<?E1Oo5`]L3olFoe0Oo/KkS0_nd^]h6oijkk@KoTkkd0onQ`_03oig4m0OoYL;^
0onW`>/3ojO2k@OoYko[00?oXko]ojO0jonW`>/01?nW`>/6ojFok0;oYL;^3OnW`>/;ojO3k@?oYlcd
1_nWc_@00onZdOCo[<W_ojc9k`04ojc9k`GoZl?[00?oXj[LoifQeonMXML01?nMXML6oiFHe0GoT9KE
1_n@V]T7oiFUh0;oYl7/1OndfO<2okWSm0Ko^Mkb00?o[lg_oj_5kOn[aNd01On[aNd6ojNoj`WoZ<7/
1OnX`>/4ojNoj`03o`000?nW_n_oYko[00;oY[k[1OnW`>/8ojS1j`GoYl3[0oooool00ol0003ooooo
ooooo`04ooooo`008oooool2o`0003?ooooo0onY`>/4ojW0jPOoXko]1?n@^?85ogR/l`?oS;Ca0on@
]o47ok[4hP;o_<CQ1Oo9a]L4olS3e@?oaL;G1Oo5_m@4ok6nh`Go];[N1_nN^nd3oi>nm0?oT[cd1_nM
a?@5ojG2kP;oXLGb1_nW`^d5ojNoj`;oYl?]1onW`>/3ojFok0?oYl;/2_nW`>/4ojO4kPSoYl?]1onW
c?@3ojO>m0?oZ/gb1on/bNl00on[`n_oXj[Loj>Zg003oj>Zg0GoWJ7G1onEV=@5oi2Fe@KoT9[I1OnE
YN02oj[8k`Co]=Wc1Oniho@2okWNlPGo[lg_1On[aNd2ojNnj`KoYko[1onX`N`7ojS0j`?oYko[00?o
Y[k[o`000?nV_^/02?nW`>/5ojS1j`SoYl3[0_ooool00ol0003oooooooooo`04ooooo`009Oooool0
0ol0003oooooooooo`0booooo`KoZL3Z1OnS_nd2oj6nk@GoS;Oc1Omg[O@5oi2gl@Co^/CR1Onla>43
olW6e`Kob<?E00?oaL;GolFoe?o5_m@01Oo5_m@00ona_^?o];[NokBjgP06okBjgP?oW[_]0onV^nP6
oi:lm0KoWLCd00?oYL;^oj75l_nQaO801?nQaO86ojO2k@03ojNojonW`ngoYl?]00CoYl?]1OnW`>/2
ojO4kPKoYl;/1OnW`>/2ojK5k`OoYlC^0onW`nd4ojK<m0KoYlcd00?oZ<kdoj[=l_nZcO801OnZcO83
ojc9k`?oY[;Q1onSZ]`5oifQe`KoUISD1On@U]D7oi2Jf@03oiFUh?nZb>ooZ/S_00CoZ/S_00?o]=Wc
okWSm?niho@01?niho@00onff_?o[lg_ojo=k`06ojo=k`03oj_5kOnW_^_oYkk[00CoYkk[1_nW_n/7
ojS1k0GoZ<3[0_nW_n/4ojJnj`03o`000?nV_^_oYl3[00GoYl3[1onX`N/6ojO0j`04ojNojooooooo
ooooo`0000Kooooo000Vooooo`03o`000?oooooooooo03;ooooo1_nY`>X00onS_ngoXKk]oj6nk@04
oj6nk@GoS;Oc1Omg[O@5oi2gl@03ok[4h_nla>7o_<CQ00Ko_<CQ00?obLKGolS3eOo8`mD01?o8`mD0
0oo7`]GoaKoDolFoe005olFoe0;oa[gB1ond^]h2okVhf0KoY[_X1_nB_?@3oig4m0CoU/?f1_nQaO83
ojO2k@CoXlGa1_nW`nd00onW`>_oYlC^ojO4kP04ojO4kPKoYl;/00?oYl3[ojK5konVaNl01?nVaNl5
ojO4kP;oY<ge1onVc?@2ojO<m0GoZ<kd1OnZcO800onW]^?oY[;QojJbh@05ojJbh@KoXj[L1OnMXML7
oiFHe0GoT9KE0on@V]T4oiV]i@GoZ/S_0ondg_D3okWSm0Co]][c1_n_cNl00onY`ncoYkk[ojNnj`06
ojNnj`?oYko[0_nX`^`8ojS1k003ojS0jonW_n_oYko[00CoYko[0onV_^/00ol0003oY[k[ojJnj`02
ojO0j`_oZ<7[0_nW`>/5ojNoj`03ooooool0003ooooo00Gooooo000Wooooo`03o`000?oooooooooo
03;ooooo1_nY`>X7oj6nk@GoS;Oc1Omg[O@2oi2gl@CoTKWb1_nla>42okc5h@Gob<?E0oo7`]D5olFo
e0Coa[gB1?nd^]h5okVhf0KoY[_X0onB_?@4oiVjk`KoU/?f0onQaO83oi_7mPOoXlGa0onW`nd3oj?7
lPOoYlC^0onW`^`4ojG7l@KoY/G_00?oYlC^ojC=mOnTcOD01?nTcOD5ojK<m0?oYLke1_nXc_@00onZ
cO;oYkKSojNfh`03ojNfh`KoY[;Q1onSZ]`5oifQe`?oUISD0onEVMD6oiJOf`OoVJgU00?oZ/S_okCN
mOndg_D01Ondg_D00onihoCo]][cokKJl`04okKJl`;o[lg_1OnY`n`6ojNnj`03ojO0jonX`^coZ<;/
00CoZ<;/1_nX`N`00onX`>_oYko[ojNoj`06ojNoj`?oY[k[00?o0000ojO0jonX`N/02_nX`N/4ojO0
j`KoYko[00?o0000ooooooooool01?ooool002Sooooo0_l0000cooooo`KoZL3Z1OnQ_^d2oj6nkPGo
RKOd1Ome[_H6oi6ilP?o_<CQ1OnlaN43olS3e@Goal;E0oo5_m@6olJmdP03okBjg_ni^=So^KSH00Ko
^KSH0onV^nP3ojfgh0OoVK[_0onF`oH3oiFnl`KoVlOf1OnSaO42oic:m`KoXlOb1OnWa>h2oj;;m@Oo
YLOa0onVaNl4oj;>m`KoY<ge00?oY/cdojG>mOnUc_D01OnUc_D3ojS>m0?oZ;SU1_nW]^<6ojJbh@?o
Xj[L0onJV=45oiNHdPOoUIWE1_nFWm/5oiV]i@;o[M;c1_ndg_D2okKTmPGo]][c0on]b^l6ojW3k0;o
Ykk[1OnW`>/6ojS2k0;oZ<7/1OnX`>/6ojNoj`03ojNnjonW`>_oYl3[00;oYl3[00?o0000ojO0jonX
`N/01_nX`N/8ojO0j`?oYko[0_ooool00ol0003oooooooooo`04ooooo`00:_ooool00ol0003ooooo
ooooo`0aooooo`KoZL3Z00?oXKk]oj6nk_nQ_^h01?nQ_^h5ohVgm0GoMJkf1_nA^O800onla>7o_<GQ
okc5h@05okc5h@03olS3eOo7`]Goal;E00Goal;E00?oaKoDolJmd_o6_M801?o6_M800oo5^m7o^KSH
okVhf006okVhf003okjfd_n]]n3o[KOP00Go[KOP1OnI^^l2ojFhi`KoUKkc1_nKaoH00onSaO7oW<[g
oic:m`04oic:m`KoXlOb00?oYlC^oj;;mOnRboD01?nRboD5ojG7l@?oWlkh1_nRc_L3ojC=m@CoXl_d
1OnUc_D8ojRhi@KoYkKS0onV/^42oijKd0OoVYSA1OnGV=86oiFIe@OoUYoK00?oVJgUojgBlon]d_<0
1?n]d_<2okCNm@Ko]^Cf00?o]][cojg:kon]b^l01On]b^l3ojW3k0;oY[kZ2?nW`>/3ojS2k0CoZ<7/
1_nX`>/2ojNoj`GoYkk[1?nW`>/00ol0003oYl3[ojS1j`06ojS1j`KoYl3[1oooool00ol0003ooooo
ooooo`03ooooo`00:oooool00ol0003oooooooooo`0aooooo`OoZL3Z1_nQ_^h5ohVgm0GoMJkf0onA
^O83oi6kl`Ko_<GQ00?o^/GSolO2eOo7`]D01Oo7`]D2olK0e@Goa[gB0oo5^m46okVhf0?o_[KB1on]
]n000onI^^ooYKSWojFhi`04ojFhi`KoUKkc0onKaoH4oiK1m@KoW<[g0onSao84oic;n0KoX/_e00?o
YLOaoio>n?nOc_P01OnOc_P3oj;>m`?oX/Ob1onSbo@00onUc_GoZ;SUojRhi@0:ojRhi@?oYkKS0_nR
W]46oijKd0KoVYSA1_nGV=85oiFIe@KoUYoK00?oXko]ojgBlon]d_<01?n]d_<3ok;Sm`Go]^Cf0_n`
d_86ojg:k`03ojS0jonV_^[oY[kZ00CoY[kZ1_nW`>/00onX`^coZ<7/ojS1k006ojS1k0?oZ<3[2_nW
_^/3ojO0j`03o`000?nX`NcoZ<7[00OoZ<7[0_nW`>/:ooooo`03o`000?oooooooooo00?ooooo000/
ooooo`03o`000?oooooooooo037ooooo1onY`>X6oj6nkPGoRKOd1Omc/?L6oi6kl`?o_<GQ1?njaN<5
olO2e@Coa/3E0oo6_M85olFkd@?o^KSH1_nn]]85ojfgh0;o];7F1onU^>L3oiFnl`?oXKWZ1onF`OD3
oic:m`?oV<;d1onLboP3oj;;m@?oVlSg1_nOc_P00onR`>koX/Oboj;7lP05oj;7lP?oXl_d0onW]^<<
ojRhi@03ojBPdOnRW]7oXYkA00CoXYkA1_nNVm05oiZHd@KoUiSB1_nEVMD2oiJOf`GoXko]0on]d_<6
ok;Sm`03okKTm_n`d_;o/=;b00Co/=;b0_n]b^l5ojS0j`KoY[kZ0_nW`>/5ojS2k0KoZ<7/00?oYl3[
ojNnjonW_^/02_nW_^/00onX`>_oZ<7/ojS1k002ojS1k003o`000?nX`NcoZ<7[00GoZ<7[3Oooool0
0ol0003oooooooooo`03ooooo`00;Oooool2o`0003;ooooo1onY`>X6oj6nkPGoRKOd1Omc/?L6oi6k
l`03okc5hOnjaN?o^/GS00Co^/GS0oo7`]D6olK0e@03olJmd_o5^m7oaK_A00GoaK_A00?o^KSHokjf
d_nn]]801_nn]]800on]]n3o];7FokBaeP04okBaePGoYKSW00?o[[3Joj6ij_nQ^NX01OnQ^NX3oiK1
m@CoXKSY1_nH`_@3oic;n0CoWKo`1_nKb?L2oio>n0GoX/3^1OnRao800onX/^3oYkKSojNfh`05ojNf
h`SoZ;SU1OnTX=46oj:Nd@GoWY_@1_nJV=46oiNHdP?oUIWE0onK[>87oj>ok@03ojgBlonbhoOo/^?g
00Co/^?g0_ndgoD5ok3BlP;oZlG]1onX`>/3ojJnjP?oZ<7/1onX`^`2ojS1k0GoYl3[2?nW_^/5ojS0
j`CoZ<7/00Co0000ojS1k?nX`N_oZ<7[4?ooool00ol0003oooooooooo`03ooooo`00;oooool00ol0
003oooooooooo`0`ooooo`OoZL3Z1_nQ_^h5ohVgm0GoLk3g0onA^o<3ohflm@Oo^/GS00?oal;EolK0
eOo6`=D01?o6`=D00oo3`=OoaK_AolFkd@06olFkd@So_[KB00?o`KG?okBae_nd/MH01_nd/MH00onU
^>Oo[[3Jojj`fP03ojj`fPGoXKWZ0_n[/=/7oj6hj@?oV<;d0onT]nH7oifol0?oVlSg0onT^>L7oj;0
kP03oj;7l_nX/^3oZ;;P00?oZ;;P1onW]^<3ojRhi@?oYZ7A1_nTX=46oj:Nd@KoWY_@0onJV=42oibN
e@KoVj;J1onK[>85oj>ok@?o[]gh0_nbhoL6okCOm@03ok3Bl_n[aNgoZlG]00CoZlG]1OnX`>/00onV
_n_oZ<7/ojS1k005ojS1k0GoZ<;/00?oZ<7/ojO0jonW`>/01_nW`>/3ojNnj`;oYko[2?nX`>/3ojS1
k003o`000?oooooooooo017ooooo00?o0000ooooooooool00oooool0033ooooo00?o0000oooooooo
ool0<Oooool6ojW0jP?oXKk^1?nR_^d5oh^hm0GoLK7h1On=_?D5ok[5h`;o]LGW1Oo6`=D3ol?0e`So
aK_A1_nn]]83ol6ec`Ko];7F00?o^k3?ojj`f_n^/=X01On^/=X00onQ^N[oZk3Koj^`f`04oj^`f`Go
XKSY00?oZjgIojBgi_nT]nH01OnT]nH5oifol0;oZ;7N1_nT^>L5oj;0kP03ojR/f_nX/^3oZ;;P00Go
Z;;P1OnW]^<00onWX=3oYZ7AojJQd@05ojJQd@GoY:3A1onRW]43oijKd0;oWIcB1_nLW]D6oi^RfPOo
VjcR00?oXko]ojkMn?n^gOP00on^gOP3ok3Un0Go]=oe0_n]bo07oj_5k@03ojS0jonV_n_oY[o[00?o
Y[o[1onX`N`00onX`^coZ<7/ojS1k003ojS1k0KoYl3[00?oYkk[ojNojonW_n/01?nW_n/6ojS0j`Go
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`03ooooo`00<Oooool00ol0003ooooo
ooooo`0aooooo`OoZL3Z1_nR_^d5oh^hm0GoLK7h1On=_?D00onjaN?o]LGWokG5i`04okG5i`?oa/3E
1Oo3`=L8olFkd@?o_[KB1Oo1]Ll4okBaePCo^k3?1On^/=X00onf[M3oZk3Koj^`f`06oj^`f`03oj6h
jOn[[MWoZjgI00?oZjgI1onT]nH00onM_o3oZ;7NojRagP04ojRagPKoY;SW00?oX/3^ojR/f_nX[=X0
0onX[=X7ojRbh003ojNfhonWX=3oYj3@00?oYj3@1_nVXM46ojBPd@?oXYkA0onPW=06oifLdPKoW9kE
1_nKX]X3oi^/hPGoZM?f00?o[]ghok3Un?n`iOP01On`iOP00ondgoGo[L_`ojg;l004ojg;l0?oZlG]
0onW_^X7ojJoj`goZ<7/0_nW`>/5ojNnj`KoYko[0_nX`>/9ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool00oooool003;ooooo0_l0000booooo`OoZL3Z1_nR_^d2oh^hm0CoSk[c1?m`
/_T5ohNln0Oo]LGW00?oa/3Eol?0eoo3`=L01Oo3`=L8olFkd@03okjfd_o1]Loo`KG?00Go`KG?00?o
];7Fok^`conk/<l01?nk/<l3ojj`fPCo]Zg@1_n[/=/00oncZLooZjgIoj^]f@05oj^]f@GoY;OV00?o
ZjSCojRag_nX/Mh01_nX/Mh3ojBhi`;oZJKC1onX[=X5ojRbh003ojRPc_nWX=3oYj3@00GoYj3@1OnV
XM45ojBPd@03oj:MconPW=3oX9c@00GoX9c@1_nMW=85oibNe@GoVj;J0onUao45ojWCmP;o[>Cj1_n`
iOP2ojkBl`Go[L_`0_nX`>/6ojNnjPGoY[o[0_nX`^`:ojS1k0?oYko[1onW_^/3ojNoj`kooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`00=?ooool00ol0003oooooooooo`0`
ooooo`OoZL3Z0onR_^d3oj>nk@KoSk[c1?m`/_T5ohNln0Go]LGW0_n/a^d6ol?0e`;o`LCM1_o5^m40
0oo3^m?o`KG?ol6ec`05ol6ec`03ol6fconk/<oo^k3?00Ko^k3?00?o[[3JokJ]d?nf[M001?nf[M03
oj^`f`Co/jW?1on[[MT00onT]nKoZjSCoj^Xd`03oj^Xd`KoZ;7N00?o[J?>ojVVdonYY]<01?nYY]<7
ojR/fP03ojRbh?nXX<koZ:3>00?oZ:3>1_nWX=06ojJQd@03ojBPdOnRWLooXYg?00?oXYg?1_nPW=06
oifLdPKoW9kE00?oVj;JojG7lOnUao401OnUao400onYdoKo[>CjojcTnP04ojcTnP;o/>Gh1_n^d_<0
0on]bo3oZ<3[ojS0j`04ojS0j`KoYkkZ00?oY[o[ojS2k?nX`^`01?nX`^`5ojS1k003ojS0jonW_n_o
Yko[00GoYko[1OnW_^/Booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool0
03Gooooo00?o0000ooooooooool0<?ooool5ojW0jP;oZL7[1_nS_^d6ohnjl`CoL;;i1On7_?P00one
aNOo[<K]ojc6k@04ojc6k@?o`l3G1Oo1a=d3olFkd@Co`k_C1Oo1]Ll3ol6fc`Ko^k3?00?o_[;>okJ]
d?nf[M001_nf[M000on[/=_o/jW?ok>Yc`04ok>Yc`GoZjgI00?o/ZO=oj^Xdon[Z=<01On[Z=<3ojRa
gPCo[J?>1_nYY]<5ojR/fP03oj^Qc?nXX<koZ:3>00GoZ:3>1_nWX=03ojJQd@;oYIk>1_nRWLl6oj2L
d0OoWIcB0onLW]D3oj6ijPKoYLOa0_nXhOX5ojcTnP?o/=cf1On^d_<00onZa>goZ<3[ojS0j`06ojS0
j`?oYkkZ0_nX`N`8ojS2k003ojS1k?nX`>_oZ<3[00?oZ<3[1onW_n/00onW_^_oooooooooo`0Doooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool003Kooooo00?o0000oooooooo
ool0<?ooool00onY`>[oZL7[ojW1j`04ojW1j`KoXkk]0on?^_<4oiFllPCoL[;i1Omn^oX6ojc6k@03
ol?0eoo1a=go`LCM00Go`LCM00?oaK_Aol>kdoo3^m<01?o3^m<3ol6ec`Go`KK?0onk/<l4okjbcPKo
]Zg@00?o^jk=ok>YconcZLl01_ncZLl00on[[MWo/ZO=ok:Wc@03ok:Wc@OoZjSC00?oZ;7NojfSc_n]
Xlh01?n]Xlh6ojVVd`03ojR/f_n[XLcoZj7<00?oZj7<1_nXX<h5ojNPd003ojROc_nUW/koYIk>00Co
YIk>1_nRWLl6oj2Ld0?oWIcB0onQ/N<7oj6ijP;oYLOa1_nXhOX00on/i?[o/=cfok3LmP05ok3LmP03
ojkBlonZa>goZ/C]00?oZ/C]1_nX`>/00onV_n_oZ<7/ojS1k004ojS1k0KoZ<;/00?oZ<7/ojS0jonX
`>/01OnX`>/3ojNoja_ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`00
=oooool2o`00037ooooo1onY`N/3oj>nk@CoYKo/1_nE_?84og:bn@GoO[_j0on/a^d3oig5m0Ko`LCM
00?o^<SVol>kdoo3^m<01_o3^m<00oo1]Loo`KK?ol6fc`05ol6fc`03ok^`conn//ko_[;>00Co_[;>
0onf[M04ok^^c@Ko/jW?00?o^Jc=ok:WcOnbYld01OnbYld5oj^Xd`03ok>Vc?n]Xlko[J?>00Go[J?>
1OnYY]<00on^XlcoZj7<oj^Qc005oj^Qc0KoZ:3>00?oYj3@ojROc_nXWlh00onXWlh6ojFNcPGoXYg?
1OnPW=000onS[MkoXK7Soj6ah`05oj6ah`GoXKWZ0onVg?X5ojSQnP?oZn;j0on`g?H4oj_8k`KoZ/C]
0_nX`>/5ojJoj`KoZ<7/0_nX`^`5ojS1k0GoZ<3[8?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00;ooooo000iooooo`03o`000?oooooooooo02oooooo1onY`N/7ojFok0?oUKcb0onJ
_O05ogZen0CoM;Wk1_nMaO@3ol74g@Co^<SV1_o3^m<00oo0`]_o`KK?ol6fc`05ol6fc`03oknje?nn
//ko_[;>00Ko_[;>00?o]Zg@ok^^cOnk[/d01?nk[/d3ok>Yc`Co^Jc=1onbYld00on[Z=?o/jK<ok>V
c003ok>Vc0Oo[J?>00?oZJKCojjSc?n^Xl`00on^Xl`6oj^Qc0GoZ:3>00?oZj;>ojROc_nXWlh01OnX
Wlh5ojFNcPKoXYg?00?oX9c@oj>]g_nS[Mh00onS[Mh7oj6ah`03oj6ij_nVg?[oY]cj00GoY]cj00?o
Z>7joj_Rn_n[h_X00on[h_X2oj_=l@OoZlS_0onZa>d3ojNnjPOoY[o[3OnX`N`00onX`>_ooooooooo
o`0Qooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool003[ooooo00?o0000
ooooooooool0;oooool7ojW1j`GoYKo/0_nW_n/6oiZml0GoN[Gh1?md^O/6oig5m003ol74gOnhb>Ko
^<SV00Co^<SV0oo3^m<4ol32f`Go`KK?0ono^]@6okjbcP03okjfd_nk[/go^jk=00Ko^jk=00?o/jW?
okV/cOni[<d01?ni[<d5ok:Wc@03okN[cOncY/co/jK<00Go/jK<1On]Xlh00onbYlgo[Z?<ojjSc005
ojjSc0KoZj7<00?oZ:3>oj^Rc_n[X/h00on[X/h6ojROcPKoYIk>0onRWLl3ojF/g0KoXjgN1OnQ/N<2
ojCGn@KoY]cj0onUi?/00on[h_[oZlgaoj_=l@04oj_=l@GoZlS_00?oYkoZojNnj_nW_^X01OnW_^X5
ojJoj`03ojS2k?nX`NcoZ<7/00SoZ<7/:?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00;ooooo000kooooo`03o`000?oooooooooo033ooooo1_nY`N/00onU_ncoYko[ojNoj`04ojNo
j`KoV[g`1Omj]OP4ogBin`?oWLGd1?n<a?X6okS8iP03ol>kdoo0`]_o`<;K00Co`<;K0oo1]/l5oknj
e0Co_[;>0onn]]86ok^^c@03okbcdOni[<go^Jc=00Go^Jc=0onbYld4okN[c@Ko/jK<0on]Xlh4ok:W
c@Ko[Z?<1On[XL`00on]Y]3oZj;>oj^RcP05oj^RcPKoZ9o>0onUW/h2ojN/f`OoYJcL1_nS[Mh00onQ
/N?oY=OiojCGn@04ojCGn@;oY]cj1OnUi?/2oj[@m0OoZlga00?oZlS_ojNoj_nW_nX00onW_nX7ojNn
jP03ojJojonX`^coZ<;/00?oZ<;/1OnX`N`]ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool00Oooool003cooooo00?o0000ooooooooool0<?ooool3ojW1j`?oZ<3[1onW_n/3oiZml0Co
Wkk^1On6^OL4ofjgo0KoS<Cj0onhb>H3ojK:l`Oo`<;K00?o`KK?oknje?no^]@01?no^]@3okjbcPGo
_[KB1?nk[/d3okbcd@Oo^Jc=00?o/ZO=okN[cOngZld01?ngZld6ok>Vc003ojfSc_nbYlgo/ZO=00Co
/ZO=1_n^Xl`00on[XLco[JK@ojfVd003ojfVd0KoZj;>1OnXWlh00onY/=coYjcKojN/f`04ojN/f`Oo
YJcL0onS[Mh3ojCCn0GoY=Oi1?nQi?`00onUi?_oZ]3doj[@m004oj[@m0?oZlga0onX`N/7ojNojP?o
YkkZ1?nX`N`6ojS2k003ojS1k?oooooooooo02oooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`01ooooo`00?Oooool2o`00037ooooo1_nX`>/5ojNoj`;oZL3Z1onO_^h5ohJim`CoK[Ol
0on<a?X3og[0o@KoY/[c1Oo0`]/2okK:j@Oo_k[D00?o_[;>okjfd_nn]]801?nn]]83ok^^c@Go_;?A
1Oni[<d00oni/m?o]j_=okN[c@05okN[c@Go/jK<00?o]JgAok:WcOnbYld01OnbYld5ojjSc003ok2[
don]Y]3o[JK@00Co[JK@1on[X/h00onXWlkoZK3LojV`g003ojV`g0GoYjcK1_nU[=`2oj?An0KoY=?h
00?oY=Oioj7To?nQi?`01?nQi?`2oj[EmPGoZ]3d0_nY`n`6ojS1j`GoYkoZ0_nW`>`7ojS1k0?oZ<;/
=?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo007ooooo000oooooo`03o`000?oo
oooooooo02oooooo1_nX`>/00onW_n_oZL3ZojW0jP04ojW0jPGoWkk^0_nT_^`6oi>ml`CoL[Kj1Omj
`?d6ojK:l`03ol32fonfb^Wo]/[Y00Co]/[Y1Ono^]@2okc8h`Oo_[KB00?o^jk=okbcdOnl/m401?nl
/m43okV/c@Co^K?C1ongZld00oncY/co]JgAokF]d@03okF]d@Oo/ZO=00?o[Z?<ok2[don`Zm<00on`
Zm<5ojfVd0KoZj;>00?o[;GOojV`g?nY/=`01?nY/=`6ojN/f`;oYJcL1_nSdOP3ojCCn0GoWN;m00?o
XNCloj[Em_nZeOH01?nZeOH00onZd?CoZL?/ojW3k004ojW3k0KoZ<7[00?oYkoZojO0k?nW`>`01?nW
`>`5ojS1k3Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`01ooooo`00@?ooool0
0ol0003oooooooooo`0_ooooo`?oZ<3[1?nW`>`6ojW0jP03oinnk_nT_^coY;k/00CoY;k/1_nC_O<5
og:fnPCoN/3m0onVb_<4ohc8o0Ko]/[Y00?o_k[Dokc8honlb><01?nlb><5okjfdP03okc5hOnl/m7o
_;?A00Ko_;?A00?o^Jc=okVcdoni/m<01?ni/m<5okN[c@03okNhf_ne[M7o]JgA00Co]JgA1_nbYld0
0onc]M[o/:_Cok2[d`04ok2[d`Ko[JK@0_n[X/h5ojbeg`KoZK3L0onW[=/9oj?An0?oV^7m0onMh_d5
ojOGn@?oZ]Gf0onXa>h7ojW3k0?oZ<7[0onW_n/7ojO0k003ojS1k?oooooooooo03_ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`01ooooo`00@Oooool00ol0003oooooooooo`0_oooo
o`OoYl3/0onY`>X3ojW1j`OoY;k/0onC_O<4oibml0GoP[[h1?m^_?d6ohc8o0?o]/[Y0onJc?T7okc8
h`03okjfd_nlaN7o_<GQ00?o_<GQ1_nl/m400onjaN?o^K?CokVcd`05okVcd`?o]j_=1?ng^=X6okF]
d@;o/ZO=1Onc]MX5ok2[d`Go[JK@0_n^_^D6ojbeg`GoZK3L0onRdoT7oj?An0GoV^7m0onSf?X5ojOG
n@03ojS5konXa>koZ<C^00GoZ<C^1OnY`n`00onW_^[oYko[ojNoj`05ojNoj`?oYl3/@Oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo007ooooo0012ooooo`;o0000<?ooool5ojO0k0;o
Y/3/1_nY`N/5ojBnk0;oYko[1onL_O05oh:jn0CoK[cm0on<b?`4ogK3oPGoV/ci1Onlb><2oj??mPKo
_<GQ0onl/m44ok[5h`Oo^K?C00?o]j_=okNhf_ng^=X00ong^=X5okF]d@03okC4i_nc]M[o/kGJ00Go
/kGJ1_n`Zm<00on]Y]3o[[kUojjni@04ojjni@Ko[;GO00?oZK3Loj;CnOnRdoT01OnRdoT3oj?An0Co
U^3n00?oV^7moj?Hn_nSf?X01OnSf?X00onWeoWoZ<G_ojS5k`03ojS5k`OoZ<C^00?oZL?/ojNnj_nW
_^X00onW_^X5ojNojdKooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`01ooooo`00
A?ooool00ol0003oooooooooo`0^ooooo`03ojO0k?nV`>coY/3/00CoY/3/1_nY`N/00onT_^coYko[
ojNoj`04ojNoj`GoW;g`0_nS_^`6oiBnm0GoMKWk1Omf`oh5oi[<n@03okc8honScoKoXlof00CoXlof
1_nlaN400onl/m7o^/GSok[5h`04ok[5h`Go^K?C00?o]/_ZokNhf_ng^=X01?ng^=X3okF]d@Co]<CV
1onc]MX3ok2[d`?o[/W^1on^_^D3ojbeg`CoWmKk1OnRdoT3oi;OoP?oU^3n1OnPeo/3oj?HnP?oYlK_
1_nXaNl3ojS4kP[oYkkZ00?oYko[ooooooooool0B?ooool00ol0003oooooooooo`07ooooo`7o0000
0Oooool1ooooo`00AOooool00ol0003oooooooooo`0_ooooo`KoY/3/0onY`N/4ojS1j`KoYko[00?o
W;g`oj>nk?nS_^`01?nS_^`6oiBnm0;oMKWk1?n:_OL5og6no@GoO/Wo1_nScoH3okc5h@CoY=3g1_nj
aN<00oni/m?o]/_ZokK;jP03okK;jPKo]kSJ00?o]JgAokC4i_nda>H01?nda>H5ok>efP;oYM7g1_n^
bNh5ojjni@?oV]Sm1_nOe_/00onRdoWoT]onoi;OoP03oi;OoP?oW]Ck1OnPeo/00onWa_3oYlK_ojO6
k`05ojO6k`?oZ<G_3OnW_^Y>ooooo`03o`000?oooooooooo00Kooooo0Ol00001ooooo`7ooooo0016
ooooo`03o`000?oooooooooo033ooooo1OnV`>`7ojS1j`?oYko[1?nY`N/6oj>nk0?oU;kd0onN_^l6
ohZmm`GoLKkm1OmnbOl3oj??mPCoP/go1_nTd?L3ok[5h`?oWM7j1_nfbnX3okNhfPCoZ]3d1_nda>H0
0onc]M[oYM7gojGAm`04ojGAm`Ko[/W^00?o[[kUoi[HoOnJf?d01OnJf?d3oioFn`CoS]gn00?oT]on
oikDnonNe?/01OnNe?/00onPeo_oYlK`ojO6l003ojO6l0GoYlK_3OnW_^YBooooo`03o`000?oooooo
oooo00Kooooo0Ol00001ooooo`7ooooo0017ooooo`;o0000<Oooool5ojK0k0GoZ<7[0_nV`>`7ojW1
j`?oXkk/0onX_nX6oijnk`?oR[gg0onK__46ohBmn@KoL<;n1On2cOl3ojC@m`?oPLoo1_nMdOX3okK;
jPCoTmCn1_nZd?@3okC4iPCoUmKm1_nUdOL3ojk9kPCoT]Wn0onJf?d5oh[Ko`?oS]gn1OnMdOX3oikD
n`?oY/G_1_nWa_000onWa^ooYkkZojNnjP0;ojNnjUKooooo00?o0000ooooooooool01Oooool1o`00
007ooooo0Oooool004Wooooo00?o0000ooooooooool0;oooool5ojK0k003ojS1jonV`>coY/3/00Co
Y/3/1OnY`N/2ojS1j`KoZ;oZ1?nN_^l2ojFnj`KoVkka1_n4_OT3og32oPCoPkkj1_mba_l4oh7?o`?o
WM7j1?mmd?l6oi?DoP?oZ]3d1?n7eOl6oiOFo@?oYM7g1?n8f?l3oi;IoPGoR]Oo0on:fol4oig<n0Go
WM7j00?oY/?_ojK5konVaNl01OnVaNl3ojO6l0goYkkZF_ooool00ol0003oooooooooo`04ooooo`7o
00000Oooool1ooooo`00B_ooool00ol0003oooooooooo`0_ooooo`coY/3/00?oZL7[ojS1jonX`N/0
1?nX`N/6ojRojP03oijnkonU_^_oYKk[00?oYKk[1_nK__43ohBmn@CoV[ob1_n3__X3og;6o`?oQ/3j
1_mgb?l5ogg@o`?oTmCn1Omjd?l5ohOEo`?oUmKm1?n0eOl3ohSHo`GoS]7n0on:eol4oio9m@KoWLch
00?oWM7jojK3konV`nl00onV`nl5ojK5k`goYkkZGoooool00ol0003oooooooooo`03ooooo`7o0000
0Oooool1ooooo`00Boooool00ol0003oooooooooo`0_ooooo`coY/3/1onX`N/3ojRojP?oZL7[1_nU
_^/3oi^nl@CoY;k/1_nJ_o83oh>nnP?oV/3b1_n6`?X3ogO8o`CoS/;i1_mob?h3og[@o`?oS<Ok1_n3
col3oh3Eo`CoT/[k1On>dOh3oj75lPKoWlWe0onMc?P3ojG2k@KoY/?_00?oY/G_ojNnj_nW_^X02onW
_^YRooooo`03o`000?oooooooooo00?ooooo0Ol00001ooooo`7ooooo001<ooooo`;o0000<?ooool<
ojK0k0GoZ<7[0_nV`>`6ojW1j`?oYKk[0onY`>/7ojBnk0?oV[ob1?nS_^`5oi[0lP?oQ/3j1?nM`?46
ohk2n@?oOlSn1?nI`oD5ohc7n`?oPloo1?nKa_H6oi;:n`03ohkAo_nQaO;oXLGb00GoXLGb0onObOD2
ojK0k0OoYL;]0onV`nl4ojRnjPWoYkkZI_ooool00ol0003oooooooooo`03ooooo`7o00000Oooool0
04kooooo00?o0000ooooooooool0;_ooool<ojK0k003ojS1jonV`>coY/3/00CoY/3/1?nY`N/2ojO1
k0KoZL3[1OnT_^`2ojRojPOoXkk/0_nJ`?84ojBnk0KoWL3a0on>`_T4oj30k`KoVL?e0_n<ao/4oj32
l@KoVlKf0onBb_/4oj?2k`GoXLGb00?oY[k[ojK0k?nV`>`01?nV`>`5ojG2k@;oZ;oZ1onX_^X3ojNn
jVcooooo00?o0000ooooooooool00_ooool1o`00007ooooo001?ooooo`03o`000?oooooooooo02oo
oooo4_nV`>`00onY`N_oYl7/ojO1k003ojO1k0KoZL3[00?oY;k/ojRoj_nX_nX01?nX_nX5oj>nk003
ojRoj_nT_^coY;k/00GoY;k/0onM`?43ojFnj`OoX<3_0onI`oD3ojBok0KoX<;a0onKa_H4ojBok0Ko
Xl;_00?oXLGbojJnjonV_^/00onV_^/6ojK0k003ojG2kOnX_n[oZ;oZ00CoZ;oZ1OnX_^Yaooooo`05
o`000?ooooooooooooooool000000Oooool0053ooooo00?o0000ooooooooool0;oooool2ojK0k0Co
Yko[3OnV`>`5ojO1k0?oZL3[1?nX`N`6ojRojP03oj>nk?nX_n[oZ;oZ00?oZ;oZ1OnT_^`2ojS0jPKo
YKk[1OnP`>l00onW_^[oY;o/ojBok005ojBok0?oX<;a0onW_^X7ojBok0?oXl;_0onW_^X6ojJnj`?o
Y/3/1?nX_n/6ojRojP03ojRnj_oooooooooo07;ooooo00Go0000ooooooooooooooooo`000001oooo
o`00DOooool2o`00033ooooo1_nW_n/3ojK0k0?oYko[1onV`>`2ojO1k0CoY/3/1_nX`N`3ojRojPCo
Z<7/1OnX_nX00onT_^coZ<3ZojS0jP04ojS0jPKoYKk[00?oX<3_ojNnj_nW_^X00onW_^X5ojBok0;o
Z;oZ1_nW_^X5ojBok003ojRoj_nW_^[oYkkZ00GoYkkZ0onV_^/3ojS1j`OoZ;o[0onX_nYhooooo`04
o`000?ooooooooooo`00007ooooo001Cooooo`03o`000?oooooooooo02kooooo1?nW_n/2ojRojPKo
Yko[3OnV`>`3ojS1k0?oY/3/1onX`N`2ojRojPCoZ<7/1_nX`>X3ojFnj`?oZL7[1_nW_^X00onT_nco
Z;oZojRojP04ojRojPKoYkkZ00?oY;o/ojRoj_nX_nX00onX_nX5ojNnjP;oZ<7/1_nX`N/5ojRojggo
oooo00?o0000ooooool000000Oooool005Cooooo00?o0000ooooooooool0;_ooool00onW_n_oZ;oZ
ojRojP03ojRojPKoYko[4onV`>`5ojS1k003ojK1k?nX`NcoZ<7/00GoZ<7/0onX`>X3ojO1k0KoZL7[
0onW_^X4ojS1k0KoZ;oZ0onW_^X3ojS1k0KoZ;oZ00?oYkkZojS1k?nX`N`01?nX`N`6ojS1j`03ojRo
jooooooooooo07kooooo00?o0000ooooool000000Oooool005Gooooo00?o0000ooooooooool0;_oo
ool6ojRojP?oYko[1?nX_n/BojK0k003ojS1k?nV`NcoY/7/00?oY/7/1OnX`N`2ojK1k0KoYl7/1?nY
`N/2ojK1k0OoZ<7/0onX_nX2ojO1k0OoZ<7/0onX_nX4ojO1k0KoZ<7/0onX`N^4ooooo`7o00000Ooo
ool1o`000000E_ooool2o`0002oooooo0onX_nX3ojW0jPOoZ;o[0_nV`>`4ojNoj`goY/3/1OnV`N`0
0onX`NcoY/7/ojK1k004ojK1k0KoYl7/00?oZL7[ojK1k?nV`N`00onV`N`5ojS1k0;oY/7/1OnW`N`5
ojS1k0WoYl7/0onX`Nb:ooooo`;o0000001Hooooo`03o`000?oooooooooo02gooooo1_nY`>X5ojRo
j`;oZKoZ1_nW_n/3ojK0k0?oYko[1onV`>`2ojK1k0CoY/3/1_nV`N`3ojO1k0?oY/3/1_nV`N`00onX
`NcoY/7/ojK1k004ojK1k0GoYl7/00?oZ<7/ojO1k?nW`N`02OnW`Nb=ooooo`?o0000001Iooooo`03
o`000?oooooooooo02gooooo1_nY`>X00onX_n_oZKoZojVojP04ojVojPCoYko[0_nX_nX6ojNoj`Go
Y/3/00?oYko[ojK0k?nV`>`01OnV`>`3ojK1k0CoYl3/1OnV`>`3ojK1k0CoY/3/1_nV`N`2ojO1k0Co
Y/7/1onW`Nb<ooooo`Co00000oooool005[ooooo00?o0000ooooooooool0;Oooool3ojW0jPCoZ<3[
1_nY_nX00onW_n_oZ;oZojRojP03ojRojPKoYko[00?oY/3/ojNojonW_n/00onW_n/5ojK0k0;oYko[
1onW`>`2ojK0k0?oYko[1onV`>`3ojK1k0?oYl3/1_nV`N`3ojO1k8cooooo0ol00007ooooo`00Fooo
ool00ol0003oooooooooo`0]ooooo`OoZ<3[0onY_nX3ojS0j`KoZ;oZ0onW_n/4ojRojPGoYko[00?o
Y/3/ojNojonW_n/01?nW_n/5ojO0k003ojNoj_nW_n_oYko[00CoYko[1OnV`>`00onW_n_oYl3/ojO0
k005ojO0k0?oY/7/SOooool4o`0000[ooooo001Looooo`;o0000;_ooool5ojS0j`;oYl3/1_nX`>/3
ojRojPCoZ<3[1_nX_nX2ojNoj`CoZ;oZ1_nW_n/00onW`>coYkoZojNojP03ojNojPKoYko[00?oY/3/
ojNojonW_n/00onW_n/5ojO0k8gooooo1?l0000>ooooo`00G_ooool00ol0003oooooooooo`0/oooo
o`03ojS0jonW`>coYl3/00CoYl3/1?nX`>/2ojO0k0OoZ<3[0onX_nX2ojS0j`OoZ;oZ0onW_n/3ojRo
jPKoYkoZ0onW_n/4ojRojPGoYko[00?oYl3/ooooooooool0R_ooool4o`0001;ooooo001Oooooo`03
o`000?oooooooooo02gooooo1_nW`>`00onX`>_oYl3/ojO0k003ojO0k0GoZ<3[0_nW`>`5ojS0j`Go
Z;oZ0_nX`>/6ojRojP?oYkoZ2_nX_nX2ojNojh_ooooo1?l0000Fooooo`00H?ooool00ol0003ooooo
ooooo`0]ooooo`coYl3/00?oZ<3[ojO0k?nW`>`01?nW`>`5ojS0j`03ojRoj_nX`>_oZ<3[00CoZ<3[
1?nX_nX2ojS1j`_oZ;oZRoooool3o`0001[ooooo001Qooooo`;o0000;ooooolBojO0k0;oZ<3[1?nW
`N`6ojS0j`03ojRoj_nX`N_oZ<7[00?oZ<7[1onX_nZ:ooooo`Co00007Oooool006?ooooo00?o0000
ooooooooool0;Oooool3ojO0k0;oYl3[3OnW`>`6ojO1k0?oZ<3[0onW`N`6ojS1j`?oZ;oZROooool4
o`00027ooooo001Tooooo`03o`000?oooooooooo02gooooo1OnW`>/5ojO0k0;oYl3[1_nW`>`3ojO1
k0CoYl3/1OnW`N`3ojS1jh[ooooo1?l0000Uooooo`00IOooool00ol0003oooooooooo`0]ooooo`Go
Yl3[00?oYl3/ojO0jonW`>/01?nW`>/4ojO0k0;oYl3[1onW`>`2ojO1k8_ooooo1?l0000Yooooo`00
I_ooool2o`0002kooooo0_nW`>/4ojNoj`KoYl3[00?oYl3/ojO0jonW`>/00onW`>/5ojO0k8_ooooo
0ol0000]ooooo`00J?ooool00ol0003oooooooooo`0/ooooo`KoYko[0onW`>/3ojNoj`KoYl3[00?o
Yl3/ooooooooool0R?ooool4o`00033ooooo001Yooooo`03o`000?oooooooooo02cooooo0onW_n/4
ojS0j`GoYko[0onW`>^9ooooo`Co0000=?ooool006[ooooo00?o0000ooooooooool0;?ooool7ojS0
j`;oYko[R_ooool4o`0003Sooooo001[ooooo`;o0000;Oooool5ojS0jhWooooo1?l0000looooo`00
KOooool00ol0003oooooooooo`0[ooooo`03ojS0jooooooooooo08Oooooo0ol00010ooooo`00K_oo
ool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo08?ooooo1?l00013ooooo`00Koooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo07oooooo1?l00017ooooo`00L?ooool2o`00
02Wooooo00?o0000ooooooooool0Noooool4o`0004_ooooo001booooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool0Moooool4o`0004oooooo001cooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0M?ooool3o`0005?ooooo001dooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool0L?ooool4o`0005Kooooo001eooooo`03o`000?oooooooooo02?ooooo00?o0000
ooooooooool0K?ooool4o`0005[ooooo001fooooo`;o00008oooool00ol0003oooooooooo`1Xoooo
o`Co0000G_ooool007Sooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1Tooooo`Co
0000H_ooool007Wooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`1Qooooo`?o0000
I_ooool007[ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1Mooooo`Co0000JOoo
ool007_ooooo0_l0000Nooooo`03o`000?oooooooooo05Wooooo1?l0001]ooooo`00OOooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo05Gooooo1?l0001aooooo`00O_ooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo057ooooo1?l0001eooooo`00Ooooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo04kooooo0ol0001iooooo`00P?ooool2o`0001Wooooo00?o
0000ooooooooool0B_ooool4o`0007cooooo0022ooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool0A_ooool4o`00083ooooo0023ooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool0@_ooool4o`0008Cooooo0024ooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool0?_ooool4o`0008Sooooo0025ooooo`;o00004oooool00ol0003oooooooooo`0looooo`?o0000
S?ooool008Oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0hooooo`Co0000Sooo
ool008Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0dooooo`Co0000Toooool0
08Wooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0`ooooo`Co0000Uoooool008[o
oooo0_l0000>ooooo`03o`000?oooooooooo02cooooo1?l0002Kooooo`00S?ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo02Wooooo0ol0002Oooooo`00SOooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo02Gooooo1?l0002Rooooo`00S_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo027ooooo1?l0002Vooooo`00Soooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo01gooooo1?l0002Zooooo`00T?ooool2o`0000Sooooo00?o0000oooooooo
ool06Oooool4o`000:kooooo002Booooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
5_ooool3o`000;;ooooo002Cooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04_oo
ool4o`000;Gooooo002Dooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03_ooool4
o`000;Wooooo002Eooooo`;o00000oooool00ol0003oooooooooo`0:ooooo`Co0000_Oooool009Oo
oooo00Co0000oooooooooooo00002?ooool4o`000<7ooooo002Hooooo`03o`000?oooooo000000Go
oooo0ol00035ooooo`00VOooool2o`000003ooooool0003o000000;o0000b?ooool009[ooooo0_l0
003<ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0538698, 0.0432538, \
0.0035044, 0.0035044}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[.12586 .2075 -12 -8.99448 ]
[.12586 .2075 0 .00552 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.56094 .0364 -5.16972 -9 ]
[.56094 .0364 .83028 0 ]
[.75679 .08071 0 -6.17777 ]
[.75679 .08071 12 2.82223 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.9429 .3657 0 -5.9083 ]
[.9429 .3657 6 3.0917 ]
[.02494 .25992 -18 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.01611 .31527 -18 -2.78472 ]
[.01611 .31527 0 6.21528 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00254 .43215 -12 -2.88407 ]
[-0.00254 .43215 0 6.11593 ]
[-0.0124 .49393 -12 -2.93688 ]
[-0.0124 .49393 0 6.06312 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
[(-2)] .12586 .2075 1 .99877 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.56863 .04703 m
.57247 .05235 L
s
[(2)] .56094 .0364 .72324 1 Mshowa
.125 Mabswid
.18558 .19702 m
.18832 .19985 L
s
.23703 .17687 m
.23971 .17975 L
s
.28951 .15632 m
.29214 .15925 L
s
.39772 .11395 m
.40023 .11699 L
s
.4535 .09211 m
.45595 .0952 L
s
.51046 .06981 m
.51284 .07294 L
s
.08568 .23614 m
.08851 .23887 L
s
.62804 .02377 m
.63027 .02701 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.7445 .0853 m
.73835 .08759 L
s
[(-2)] .75679 .08071 -1 .37284 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.93037 .36962 m
.92411 .37158 L
s
[(2)] .9429 .3657 -1 .31296 Mshowa
.125 Mabswid
.7708 .12553 m
.7671 .12688 L
s
.79613 .16428 m
.79242 .1656 L
s
.82054 .20161 m
.81682 .20291 L
s
.86679 .27235 m
.86305 .2736 L
s
.88871 .30589 m
.88497 .30711 L
s
.9099 .3383 m
.90615 .3395 L
s
.71716 .04348 m
.71349 .04489 L
s
.95018 .39992 m
.94642 .40107 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(-20)] .02494 .25992 1 -0.39157 Mshowa
.02837 .31059 m
.0345 .30825 L
s
[(-10)] .01611 .31527 1 -0.38117 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.00981 .42772 m
.01599 .4255 L
s
[(10)] -0.00254 .43215 1 -0.3591 Mshowa
0 .48963 m
.0062 .48748 L
s
[(20)] -0.0124 .49393 1 -0.34736 Mshowa
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.659 .749 .917 r
.39362 .69476 .40169 .7019 .4152 .698 .40717 .69083 Mtetra
.653 .749 .92 r
.40717 .69083 .4152 .698 .42878 .69409 .42079 .68705 Mtetra
.651 .753 .924 r
.42079 .68705 .42878 .69409 .44243 .69031 .43448 .68331 Mtetra
.655 .755 .924 r
.43448 .68331 .44243 .69031 .45614 .68658 .44824 .67944 Mtetra
.657 .753 .921 r
.44824 .67944 .45614 .68658 .46992 .68274 .46207 .67546 Mtetra
.66 .751 .918 r
.46207 .67546 .46992 .68274 .48378 .67881 .47597 .67138 Mtetra
.66 .748 .915 r
.47597 .67138 .48378 .67881 .4977 .67479 .48994 .66729 Mtetra
.655 .746 .917 r
.48994 .66729 .4977 .67479 .5117 .67071 .50398 .66335 Mtetra
.651 .75 .922 r
.50398 .66335 .5117 .67071 .52577 .66666 .5181 .6595 Mtetra
.651 .756 .927 r
.5181 .6595 .52577 .66666 .53991 .66276 .53229 .65563 Mtetra
.654 .759 .926 r
.53229 .65563 .53991 .66276 .55412 .65889 .54655 .6516 Mtetra
.655 .756 .924 r
.54655 .6516 .55412 .65889 .56841 .65498 .56089 .64754 Mtetra
.655 .753 .921 r
.56089 .64754 .56841 .65498 .58277 .65097 .5753 .64346 Mtetra
.657 .752 .92 r
.5753 .64346 .58277 .65097 .59721 .64691 .58978 .63929 Mtetra
.657 .751 .919 r
.58978 .63929 .59721 .64691 .61172 .64282 .60434 .63511 Mtetra
.656 .749 .918 r
.60434 .63511 .61172 .64282 .62631 .63871 .61898 .63097 Mtetra
.655 .749 .919 r
.61898 .63097 .62631 .63871 .64097 .63458 .6337 .62684 Mtetra
.654 .75 .92 r
.6337 .62684 .64097 .63458 .65571 .63043 .64849 .6227 Mtetra
.655 .751 .921 r
.64849 .6227 .65571 .63043 .67053 .62625 .66337 .61852 Mtetra
.656 .752 .921 r
.66337 .61852 .67053 .62625 .68543 .62205 .67832 .61428 Mtetra
.657 .753 .921 r
.67832 .61428 .68543 .62205 .7004 .61783 .69335 .60998 Mtetra
.657 .752 .92 r
.69335 .60998 .7004 .61783 .71546 .61358 .70845 .60564 Mtetra
.657 .751 .919 r
.70845 .60564 .71546 .61358 .73059 .60931 .72364 .60128 Mtetra
.656 .749 .918 r
.72364 .60128 .73059 .60931 .74581 .60502 .73891 .59694 Mtetra
.655 .749 .919 r
.73891 .59694 .74581 .60502 .76111 .6007 .75427 .59263 Mtetra
.654 .75 .92 r
.75427 .59263 .76111 .6007 .77648 .59636 .76971 .58831 Mtetra
.656 .752 .921 r
.76971 .58831 .77648 .59636 .79194 .59196 .78523 .5839 Mtetra
.656 .753 .921 r
.78523 .5839 .79194 .59196 .80748 .58746 .80083 .57947 Mtetra
.656 .756 .924 r
.80083 .57947 .80748 .58746 .82309 .58291 .81652 .57501 Mtetra
.659 .76 .925 r
.81652 .57501 .82309 .58291 .8388 .57839 .83228 .57038 Mtetra
.659 .759 .923 r
.83228 .57038 .8388 .57839 .8546 .57402 .84813 .56572 Mtetra
.657 .751 .92 r
.84813 .56572 .8546 .57402 .8705 .56968 .86407 .56115 Mtetra
.653 .745 .917 r
.86407 .56115 .8705 .56968 .88648 .56528 .88012 .55673 Mtetra
.652 .746 .918 r
.88012 .55673 .88648 .56528 .90255 .56078 .89626 .5523 Mtetra
.655 .75 .92 r
.89626 .5523 .90255 .56078 .91869 .55617 .91247 .54775 Mtetra
.656 .753 .921 r
.91247 .54775 .91869 .55617 .93491 .55145 .92877 .5431 Mtetra
.659 .757 .922 r
.92877 .5431 .93491 .55145 .95122 .54678 .94515 .5383 Mtetra
.658 .755 .921 r
.94515 .5383 .95122 .54678 .96765 .54224 .96162 .53353 Mtetra
.654 .748 .919 r
.96162 .53353 .96765 .54224 .98417 .53768 .97821 .52892 Mtetra
.653 .749 .92 r
.38547 .68756 .39362 .69476 .40717 .69083 .39906 .68377 Mtetra
.651 .753 .924 r
.39906 .68377 .40717 .69083 .42079 .68705 .41272 .68002 Mtetra
.655 .755 .924 r
.41272 .68002 .42079 .68705 .43448 .68331 .42646 .67611 Mtetra
.658 .752 .92 r
.42646 .67611 .43448 .68331 .44824 .67944 .44026 .67211 Mtetra
.661 .751 .917 r
.44026 .67211 .44824 .67944 .46207 .67546 .45414 .66798 Mtetra
.659 .747 .915 r
.45414 .66798 .46207 .67546 .47597 .67138 .46809 .6639 Mtetra
.652 .746 .919 r
.46809 .6639 .47597 .67138 .48994 .66729 .4821 .66005 Mtetra
.65 .753 .925 r
.4821 .66005 .48994 .66729 .50398 .66335 .49619 .65621 Mtetra
.653 .758 .926 r
.49619 .65621 .50398 .66335 .5181 .6595 .51035 .65222 Mtetra
.655 .756 .924 r
.51035 .65222 .5181 .6595 .53229 .65563 .52459 .64816 Mtetra
.656 .752 .921 r
.52459 .64816 .53229 .65563 .54655 .6516 .5389 .64408 Mtetra
.658 .752 .919 r
.5389 .64408 .54655 .6516 .56089 .64754 .55329 .63988 Mtetra
.654 .749 .919 r
.55329 .63988 .56089 .64754 .5753 .64346 .56775 .63581 Mtetra
.649 .748 .922 r
.56775 .63581 .5753 .64346 .58978 .63929 .58229 .63189 Mtetra
.641 .753 .93 r
.58229 .63189 .58978 .63929 .60434 .63511 .59691 .6282 Mtetra
.634 .766 .942 r
.59691 .6282 .60434 .63511 .61898 .63097 .61162 .62462 Mtetra
.632 .783 .954 r
.61162 .62462 .61898 .63097 .6337 .62684 .62641 .62094 Mtetra
.632 .798 .962 r
.62641 .62094 .6337 .62684 .64849 .6227 .64128 .61709 Mtetra
.635 .809 .966 r
.64128 .61709 .64849 .6227 .66337 .61852 .65622 .61304 Mtetra
.641 .816 .967 r
.65622 .61304 .66337 .61852 .67832 .61428 .67124 .60876 Mtetra
.648 .818 .965 r
.67124 .60876 .67832 .61428 .69335 .60998 .68632 .60426 Mtetra
.656 .815 .96 r
.68632 .60426 .69335 .60998 .70845 .60564 .70148 .59954 Mtetra
.663 .807 .952 r
.70148 .59954 .70845 .60564 .72364 .60128 .7167 .59465 Mtetra
.668 .794 .942 r
.7167 .59465 .72364 .60128 .73891 .59694 .732 .58966 Mtetra
.667 .776 .931 r
.732 .58966 .73891 .59694 .75427 .59263 .74738 .58478 Mtetra
.661 .76 .923 r
.74738 .58478 .75427 .59263 .76971 .58831 .76286 .58012 Mtetra
.657 .751 .919 r
.76286 .58012 .76971 .58831 .78523 .5839 .77844 .57562 Mtetra
.654 .748 .919 r
.77844 .57562 .78523 .5839 .80083 .57947 .79411 .57124 Mtetra
.656 .751 .92 r
.79411 .57124 .80083 .57947 .81652 .57501 .80986 .56675 Mtetra
.656 .752 .921 r
.80986 .56675 .81652 .57501 .83228 .57038 .8257 .56222 Mtetra
.657 .756 .923 r
.8257 .56222 .83228 .57038 .84813 .56572 .84162 .55762 Mtetra
.66 .76 .924 r
.84162 .55762 .84813 .56572 .86407 .56115 .85761 .55286 Mtetra
.659 .756 .922 r
.85761 .55286 .86407 .56115 .88012 .55673 .87369 .54811 Mtetra
.653 .746 .918 r
.87369 .54811 .88012 .55673 .89626 .5523 .88989 .5436 Mtetra
.652 .745 .918 r
.88989 .5436 .89626 .5523 .91247 .54775 .90618 .53913 Mtetra
.654 .749 .919 r
.90618 .53913 .91247 .54775 .92877 .5431 .92256 .53452 Mtetra
.656 .752 .921 r
.92256 .53452 .92877 .5431 .94515 .5383 .93902 .52981 Mtetra
.659 .757 .922 r
.93902 .52981 .94515 .5383 .96162 .53353 .95555 .52492 Mtetra
.658 .755 .921 r
.95555 .52492 .96162 .53353 .97821 .52892 .97218 .52008 Mtetra
.651 .752 .924 r
.37725 .68045 .38547 .68756 .39906 .68377 .39088 .6767 Mtetra
.655 .755 .923 r
.39088 .6767 .39906 .68377 .41272 .68002 .40458 .67278 Mtetra
.658 .752 .92 r
.40458 .67278 .41272 .68002 .42646 .67611 .41836 .66875 Mtetra
.661 .751 .917 r
.41836 .66875 .42646 .67611 .44026 .67211 .43222 .6646 Mtetra
.658 .747 .916 r
.43222 .6646 .44026 .67211 .45414 .66798 .44614 .66054 Mtetra
.651 .748 .921 r
.44614 .66054 .45414 .66798 .46809 .6639 .46012 .6567 Mtetra
.65 .756 .927 r
.46012 .6567 .46809 .6639 .4821 .66005 .47419 .65284 Mtetra
.655 .757 .925 r
.47419 .65284 .4821 .66005 .49619 .65621 .48832 .64879 Mtetra
.655 .753 .922 r
.48832 .64879 .49619 .65621 .51035 .65222 .50253 .64472 Mtetra
.659 .753 .919 r
.50253 .64472 .51035 .65222 .52459 .64816 .51682 .64051 Mtetra
.653 .748 .92 r
.51682 .64051 .52459 .64816 .5389 .64408 .53118 .6365 Mtetra
.641 .747 .926 r
.53118 .6365 .5389 .64408 .55329 .63988 .54562 .63287 Mtetra
.619 .757 .945 r
.54562 .63287 .55329 .63988 .56775 .63581 .56014 .6298 Mtetra
.604 .784 .967 r
.56014 .6298 .56775 .63581 .58229 .63189 .57475 .62681 Mtetra
.59 .809 .984 r
.57475 .62681 .58229 .63189 .59691 .6282 .58945 .62375 Mtetra
.58 .828 .992 r
.58945 .62375 .59691 .6282 .61162 .62462 .60423 .62055 Mtetra
.573 .839 .995 r
.60423 .62055 .61162 .62462 .62641 .62094 .6191 .61724 Mtetra
.577 .853 .996 r
.6191 .61724 .62641 .62094 .64128 .61709 .63405 .6136 Mtetra
.585 .863 .995 r
.63405 .6136 .64128 .61709 .65622 .61304 .64907 .60962 Mtetra
.597 .871 .993 r
.64907 .60962 .65622 .61304 .67124 .60876 .66416 .60531 Mtetra
.613 .876 .991 r
.66416 .60531 .67124 .60876 .68632 .60426 .67932 .60065 Mtetra
.63 .878 .988 r
.67932 .60065 .68632 .60426 .70148 .59954 .69454 .59566 Mtetra
.648 .875 .983 r
.69454 .59566 .70148 .59954 .7167 .59465 .70982 .59033 Mtetra
.659 .866 .977 r
.70982 .59033 .7167 .59465 .732 .58966 .72517 .58487 Mtetra
.67 .855 .97 r
.72517 .58487 .732 .58966 .74738 .58478 .74058 .57927 Mtetra
.678 .836 .959 r
.74058 .57927 .74738 .58478 .76286 .58012 .75607 .57359 Mtetra
.681 .807 .943 r
.75607 .57359 .76286 .58012 .77844 .57562 .77163 .56799 Mtetra
.668 .773 .928 r
.77163 .56799 .77844 .57562 .79411 .57124 .78732 .56294 Mtetra
.659 .753 .92 r
.78732 .56294 .79411 .57124 .80986 .56675 .80312 .55829 Mtetra
.653 .748 .919 r
.80312 .55829 .80986 .56675 .8257 .56222 .81903 .55383 Mtetra
.656 .752 .92 r
.81903 .55383 .8257 .56222 .84162 .55762 .83501 .54923 Mtetra
.656 .753 .921 r
.83501 .54923 .84162 .55762 .85761 .55286 .85109 .5446 Mtetra
.66 .759 .924 r
.85109 .5446 .85761 .55286 .87369 .54811 .86723 .53978 Mtetra
.66 .759 .923 r
.86723 .53978 .87369 .54811 .88989 .5436 .88347 .53492 Mtetra
.654 .749 .919 r
.88347 .53492 .88989 .5436 .90618 .53913 .89981 .53029 Mtetra
.652 .745 .918 r
.89981 .53029 .90618 .53913 .92256 .53452 .91627 .52575 Mtetra
.654 .749 .919 r
.91627 .52575 .92256 .53452 .93902 .52981 .93281 .52108 Mtetra
.656 .752 .92 r
.93281 .52108 .93902 .52981 .95555 .52492 .94942 .51628 Mtetra
.66 .757 .922 r
.94942 .51628 .95555 .52492 .97218 .52008 .96612 .51132 Mtetra
.654 .755 .924 r
.36894 .67334 .37725 .68045 .39088 .6767 .38262 .66944 Mtetra
.658 .753 .92 r
.38262 .66944 .39088 .6767 .40458 .67278 .39637 .6654 Mtetra
.661 .751 .917 r
.39637 .6654 .40458 .67278 .41836 .66875 .4102 .66121 Mtetra
.658 .747 .916 r
.4102 .66121 .41836 .66875 .43222 .6646 .42409 .65715 Mtetra
.65 .748 .922 r
.42409 .65715 .43222 .6646 .44614 .66054 .43805 .65332 Mtetra
.651 .756 .926 r
.43805 .65332 .44614 .66054 .46012 .6567 .45208 .64941 Mtetra
.655 .756 .924 r
.45208 .64941 .46012 .6567 .47419 .65284 .4662 .64534 Mtetra
.657 .752 .92 r
.4662 .64534 .47419 .65284 .48832 .64879 .48038 .64119 Mtetra
.656 .75 .919 r
.48038 .64119 .48832 .64879 .50253 .64472 .49464 .63706 Mtetra
.642 .746 .924 r
.49464 .63706 .50253 .64472 .51682 .64051 .50897 .63338 Mtetra
.609 .751 .945 r
.50897 .63338 .51682 .64051 .53118 .6365 .52338 .63063 Mtetra
.581 .78 .974 r
.52338 .63063 .53118 .6365 .54562 .63287 .53788 .62813 Mtetra
.549 .806 .993 r
.53788 .62813 .54562 .63287 .56014 .6298 .55247 .62573 Mtetra
.523 .819 .999 r
.55247 .62573 .56014 .6298 .57475 .62681 .56715 .62339 Mtetra
.519 .839 .999 r
.56715 .62339 .57475 .62681 .58945 .62375 .58193 .62064 Mtetra
.531 .854 .997 r
.58193 .62064 .58945 .62375 .60423 .62055 .59678 .61744 Mtetra
.554 .863 .996 r
.59678 .61744 .60423 .62055 .6191 .61724 .61171 .61381 Mtetra
.582 .864 .995 r
.61171 .61381 .6191 .61724 .63405 .6136 .62672 .60983 Mtetra
.604 .862 .992 r
.62672 .60983 .63405 .6136 .64907 .60962 .64181 .60557 Mtetra
.614 .857 .99 r
.64181 .60557 .64907 .60962 .66416 .60531 .65697 .60122 Mtetra
.617 .858 .989 r
.65697 .60122 .66416 .60531 .67932 .60065 .67221 .59677 Mtetra
.622 .868 .989 r
.67221 .59677 .67932 .60065 .69454 .59566 .68753 .59205 Mtetra
.629 .88 .988 r
.68753 .59205 .69454 .59566 .70982 .59033 .7029 .58696 Mtetra
.639 .891 .985 r
.7029 .58696 .70982 .59033 .72517 .58487 .71833 .58144 Mtetra
.658 .896 .981 r
.71833 .58144 .72517 .58487 .74058 .57927 .73381 .57545 Mtetra
.68 .892 .974 r
.73381 .57545 .74058 .57927 .75607 .57359 .74933 .56904 Mtetra
.688 .872 .968 r
.74933 .56904 .75607 .57359 .77163 .56799 .76493 .56266 Mtetra
.691 .85 .959 r
.76493 .56266 .77163 .56799 .78732 .56294 .7806 .55638 Mtetra
.689 .814 .942 r
.7806 .55638 .78732 .56294 .80312 .55829 .79636 .55035 Mtetra
.667 .769 .926 r
.79636 .55035 .80312 .55829 .81903 .55383 .81229 .54526 Mtetra
.656 .75 .919 r
.81229 .54526 .81903 .55383 .83501 .54923 .82834 .54063 Mtetra
.655 .75 .92 r
.82834 .54063 .83501 .54923 .85109 .5446 .84448 .53602 Mtetra
.656 .752 .92 r
.84448 .53602 .85109 .5446 .86723 .53978 .86071 .53132 Mtetra
.659 .758 .923 r
.86071 .53132 .86723 .53978 .88347 .53492 .87701 .52646 Mtetra
.661 .759 .923 r
.87701 .52646 .88347 .53492 .89981 .53029 .8934 .5215 Mtetra
.655 .75 .92 r
.8934 .5215 .89981 .53029 .91627 .52575 .9099 .51678 Mtetra
.651 .745 .918 r
.9099 .51678 .91627 .52575 .93281 .52108 .92652 .51218 Mtetra
.654 .749 .919 r
.92652 .51218 .93281 .52108 .94942 .51628 .94322 .50743 Mtetra
.657 .753 .92 r
.94322 .50743 .94942 .51628 .96612 .51132 .96 .50253 Mtetra
.657 .753 .921 r
.36055 .66608 .36894 .67334 .38262 .66944 .37428 .66204 Mtetra
.661 .751 .917 r
.37428 .66204 .38262 .66944 .39637 .6654 .38808 .65784 Mtetra
.658 .748 .916 r
.38808 .65784 .39637 .6654 .4102 .66121 .40195 .65372 Mtetra
.65 .748 .922 r
.40195 .65372 .4102 .66121 .42409 .65715 .41588 .64989 Mtetra
.651 .756 .926 r
.41588 .64989 .42409 .65715 .43805 .65332 .42989 .64596 Mtetra
.655 .755 .923 r
.42989 .64596 .43805 .65332 .45208 .64941 .44397 .64187 Mtetra
.658 .752 .919 r
.44397 .64187 .45208 .64941 .4662 .64534 .45813 .63767 Mtetra
.652 .748 .92 r
.45813 .63767 .4662 .64534 .48038 .64119 .47236 .63367 Mtetra
.623 .744 .934 r
.47236 .63367 .48038 .64119 .49464 .63706 .48666 .63057 Mtetra
.58 .761 .964 r
.48666 .63057 .49464 .63706 .50897 .63338 .50103 .62832 Mtetra
.534 .79 .992 r
.50103 .62832 .50897 .63338 .52338 .63063 .51549 .62638 Mtetra
.492 .801 .999 r
.51549 .62638 .52338 .63063 .53788 .62813 .53006 .62465 Mtetra
.494 .826 .999 r
.53006 .62465 .53788 .62813 .55247 .62573 .54471 .62235 Mtetra
.544 .849 .998 r
.54471 .62235 .55247 .62573 .56715 .62339 .55945 .61915 Mtetra
.619 .849 .986 r
.55945 .61915 .56715 .62339 .58193 .62064 .57427 .61492 Mtetra
.654 .813 .96 r
.57427 .61492 .58193 .62064 .59678 .61744 .58916 .6103 Mtetra
.666 .777 .932 r
.58916 .6103 .59678 .61744 .61171 .61381 .60412 .60551 Mtetra
.666 .748 .911 r
.60412 .60551 .61171 .61381 .62672 .60983 .61916 .60074 Mtetra
.662 .729 .899 r
.61916 .60074 .62672 .60983 .64181 .60557 .63429 .59612 Mtetra
.656 .719 .895 r
.63429 .59612 .64181 .60557 .65697 .60122 .6495 .59172 Mtetra
.651 .717 .897 r
.6495 .59172 .65697 .60122 .67221 .59677 .6648 .58755 Mtetra
.646 .723 .904 r
.6648 .58755 .67221 .59677 .68753 .59205 .6802 .58352 Mtetra
.643 .74 .919 r
.6802 .58352 .68753 .59205 .7029 .58696 .69569 .57952 Mtetra
.643 .77 .94 r
.69569 .57952 .7029 .58696 .71833 .58144 .71126 .57535 Mtetra
.645 .811 .963 r
.71126 .57535 .71833 .58144 .73381 .57545 .7269 .57078 Mtetra
.662 .862 .975 r
.7269 .57078 .73381 .57545 .74933 .56904 .74256 .56517 Mtetra
.681 .893 .974 r
.74256 .56517 .74933 .56904 .76493 .56266 .75823 .55862 Mtetra
.703 .895 .967 r
.75823 .55862 .76493 .56266 .7806 .55638 .77393 .55148 Mtetra
.704 .87 .96 r
.77393 .55148 .7806 .55638 .79636 .55035 .78971 .54453 Mtetra
.7 .842 .951 r
.78971 .54453 .79636 .55035 .81229 .54526 .80558 .53789 Mtetra
.682 .793 .934 r
.80558 .53789 .81229 .54526 .82834 .54063 .8216 .53211 Mtetra
.659 .755 .921 r
.8216 .53211 .82834 .54063 .84448 .53602 .83779 .52726 Mtetra
.654 .748 .919 r
.83779 .52726 .84448 .53602 .86071 .53132 .8541 .52261 Mtetra
.656 .752 .92 r
.8541 .52261 .86071 .53132 .87701 .52646 .87048 .51783 Mtetra
.659 .757 .922 r
.87048 .51783 .87701 .52646 .8934 .5215 .88694 .51289 Mtetra
.661 .759 .923 r
.88694 .51289 .8934 .5215 .9099 .51678 .90348 .50784 Mtetra
.654 .749 .92 r
.90348 .50784 .9099 .51678 .92652 .51218 .92016 .50308 Mtetra
.651 .745 .918 r
.92016 .50308 .92652 .51218 .94322 .50743 .93694 .4984 Mtetra
.655 .75 .92 r
.93694 .4984 .94322 .50743 .96 .50253 .9538 .49355 Mtetra
.661 .752 .918 r
.35209 .65867 .36055 .66608 .37428 .66204 .36587 .65447 Mtetra
.66 .749 .916 r
.36587 .65447 .37428 .66204 .38808 .65784 .37971 .65027 Mtetra
.65 .747 .921 r
.37971 .65027 .38808 .65784 .40195 .65372 .39361 .64641 Mtetra
.65 .755 .926 r
.39361 .64641 .40195 .65372 .41588 .64989 .40759 .64249 Mtetra
.655 .755 .923 r
.40759 .64249 .41588 .64989 .42989 .64596 .42165 .63839 Mtetra
.658 .752 .919 r
.42165 .63839 .42989 .64596 .44397 .64187 .43578 .63416 Mtetra
.649 .747 .921 r
.43578 .63416 .44397 .64187 .45813 .63767 .44998 .63023 Mtetra
.607 .743 .941 r
.44998 .63023 .45813 .63767 .47236 .63367 .46424 .62755 Mtetra
.555 .765 .976 r
.46424 .62755 .47236 .63367 .48666 .63057 .47857 .62569 Mtetra
.49 .78 .996 r
.47857 .62569 .48666 .63057 .50103 .62832 .49299 .62438 Mtetra
.47 .802 .999 r
.49299 .62438 .50103 .62832 .51549 .62638 .50751 .62276 Mtetra
.536 .839 .999 r
.50751 .62276 .51549 .62638 .53006 .62465 .52213 .61985 Mtetra
.64 .836 .976 r
.52213 .61985 .53006 .62465 .54471 .62235 .53684 .61537 Mtetra
.68 .783 .928 r
.53684 .61537 .54471 .62235 .55945 .61915 .55162 .61008 Mtetra
.691 .736 .885 r
.55162 .61008 .55945 .61915 .57427 .61492 .56647 .60422 Mtetra
.694 .705 .856 r
.56647 .60422 .57427 .61492 .58916 .6103 .58137 .59794 Mtetra
.682 .673 .835 r
.58137 .59794 .58916 .6103 .60412 .60551 .59635 .59194 Mtetra
.67 .651 .823 r
.59635 .59194 .60412 .60551 .61916 .60074 .6114 .5864 Mtetra
.659 .637 .817 r
.6114 .5864 .61916 .60074 .63429 .59612 .62654 .58139 Mtetra
.648 .628 .816 r
.62654 .58139 .63429 .59612 .6495 .59172 .64178 .57694 Mtetra
.638 .623 .818 r
.64178 .57694 .6495 .59172 .6648 .58755 .65712 .57305 Mtetra
.629 .623 .826 r
.65712 .57305 .6648 .58755 .6802 .58352 .67258 .56969 Mtetra
.62 .629 .838 r
.67258 .56969 .6802 .58352 .69569 .57952 .68816 .56681 Mtetra
.614 .644 .857 r
.68816 .56681 .69569 .57952 .71126 .57535 .70385 .56422 Mtetra
.621 .677 .882 r
.70385 .56422 .71126 .57535 .7269 .57078 .71963 .56121 Mtetra
.631 .715 .907 r
.71963 .56121 .7269 .57078 .74256 .56517 .73547 .55763 Mtetra
.646 .774 .941 r
.73547 .55763 .74256 .56517 .75823 .55862 .75136 .55322 Mtetra
.679 .849 .964 r
.75136 .55322 .75823 .55862 .77393 .55148 .76723 .5472 Mtetra
.708 .892 .964 r
.76723 .5472 .77393 .55148 .78971 .54453 .78307 .53985 Mtetra
.721 .885 .956 r
.78307 .53985 .78971 .54453 .80558 .53789 .79894 .53217 Mtetra
.711 .852 .95 r
.79894 .53217 .80558 .53789 .8216 .53211 .81493 .52502 Mtetra
.692 .808 .937 r
.81493 .52502 .8216 .53211 .83779 .52726 .83107 .51872 Mtetra
.661 .759 .923 r
.83107 .51872 .83779 .52726 .8541 .52261 .8474 .51369 Mtetra
.654 .748 .919 r
.8474 .51369 .8541 .52261 .87048 .51783 .86387 .50897 Mtetra
.656 .752 .92 r
.86387 .50897 .87048 .51783 .88694 .51289 .88041 .50412 Mtetra
.66 .757 .922 r
.88041 .50412 .88694 .51289 .90348 .50784 .89703 .49907 Mtetra
.661 .758 .922 r
.89703 .49907 .90348 .50784 .92016 .50308 .91373 .49395 Mtetra
.652 .747 .919 r
.91373 .49395 .92016 .50308 .93694 .4984 .93058 .48918 Mtetra
.652 .746 .919 r
.93058 .48918 .93694 .4984 .9538 .49355 .94753 .4844 Mtetra
.661 .75 .916 r
.34355 .65111 .35209 .65867 .36587 .65447 .35737 .64685 Mtetra
.652 .747 .919 r
.35737 .64685 .36587 .65447 .37971 .65027 .37125 .64289 Mtetra
.649 .753 .926 r
.37125 .64289 .37971 .65027 .39361 .64641 .3852 .63901 Mtetra
.655 .756 .924 r
.3852 .63901 .39361 .64641 .40759 .64249 .39923 .63489 Mtetra
.658 .752 .919 r
.39923 .63489 .40759 .64249 .42165 .63839 .41333 .63065 Mtetra
.65 .748 .921 r
.41333 .63065 .42165 .63839 .43578 .63416 .4275 .6267 Mtetra
.6 .741 .943 r
.4275 .6267 .43578 .63416 .44998 .63023 .44172 .62418 Mtetra
.538 .762 .98 r
.44172 .62418 .44998 .63023 .46424 .62755 .456 .62262 Mtetra
.464 .769 .996 r
.456 .62262 .46424 .62755 .47857 .62569 .47037 .62172 Mtetra
.472 .803 .999 r
.47037 .62172 .47857 .62569 .49299 .62438 .48485 .62006 Mtetra
.607 .841 .988 r
.48485 .62006 .49299 .62438 .50751 .62276 .49945 .61619 Mtetra
.684 .795 .933 r
.49945 .61619 .50751 .62276 .52213 .61985 .51414 .61074 Mtetra
.71 .739 .875 r
.51414 .61074 .52213 .61985 .53684 .61537 .52889 .60396 Mtetra
.711 .698 .835 r
.52889 .60396 .53684 .61537 .55162 .61008 .5437 .59643 Mtetra
.696 .66 .81 r
.5437 .59643 .55162 .61008 .56647 .60422 .55856 .58913 Mtetra
.682 .637 .798 r
.55856 .58913 .56647 .60422 .58137 .59794 .57348 .58241 Mtetra
.668 .626 .799 r
.57348 .58241 .58137 .59794 .59635 .59194 .58848 .57655 Mtetra
.66 .625 .803 r
.58848 .57655 .59635 .59194 .6114 .5864 .60357 .57121 Mtetra
.654 .625 .809 r
.60357 .57121 .6114 .5864 .62654 .58139 .61874 .56631 Mtetra
.648 .624 .813 r
.61874 .56631 .62654 .58139 .64178 .57694 .634 .5618 Mtetra
.641 .621 .815 r
.634 .5618 .64178 .57694 .65712 .57305 .64936 .55769 Mtetra
.632 .615 .815 r
.64936 .55769 .65712 .57305 .67258 .56969 .66483 .55403 Mtetra
.623 .607 .814 r
.66483 .55403 .67258 .56969 .68816 .56681 .68042 .55089 Mtetra
.607 .597 .815 r
.68042 .55089 .68816 .56681 .70385 .56422 .69616 .54863 Mtetra
.595 .596 .822 r
.69616 .54863 .70385 .56422 .71963 .56121 .71203 .54697 Mtetra
.588 .611 .843 r
.71203 .54697 .71963 .56121 .73547 .55763 .72804 .54557 Mtetra
.6 .654 .874 r
.72804 .54557 .73547 .55763 .75136 .55322 .74413 .54341 Mtetra
.627 .712 .908 r
.74413 .54341 .75136 .55322 .76723 .5472 .76023 .5399 Mtetra
.662 .791 .943 r
.76023 .5399 .76723 .5472 .78307 .53985 .77631 .53478 Mtetra
.714 .873 .956 r
.77631 .53478 .78307 .53985 .79894 .53217 .7923 .52736 Mtetra
.733 .887 .951 r
.7923 .52736 .79894 .53217 .81493 .52502 .8083 .51915 Mtetra
.719 .853 .946 r
.8083 .51915 .81493 .52502 .83107 .51872 .82441 .5116 Mtetra
.697 .812 .937 r
.82441 .5116 .83107 .51872 .8474 .51369 .84068 .50502 Mtetra
.661 .759 .923 r
.84068 .50502 .8474 .51369 .86387 .50897 .85717 .49992 Mtetra
.654 .748 .919 r
.85717 .49992 .86387 .50897 .88041 .50412 .87379 .49512 Mtetra
.656 .752 .92 r
.87379 .49512 .88041 .50412 .89703 .49907 .8905 .49018 Mtetra
.661 .758 .922 r
.8905 .49018 .89703 .49907 .91373 .49395 .90728 .48499 Mtetra
.659 .757 .922 r
.90728 .48499 .91373 .49395 .93058 .48918 .92416 .47988 Mtetra
.651 .746 .919 r
.92416 .47988 .93058 .48918 .94753 .4844 .94118 .47508 Mtetra
.657 .748 .917 r
.33494 .64345 .34355 .65111 .35737 .64685 .34879 .63933 Mtetra
.648 .751 .924 r
.34879 .63933 .35737 .64685 .37125 .64289 .36271 .63547 Mtetra
.654 .756 .925 r
.36271 .63547 .37125 .64289 .3852 .63901 .37671 .63138 Mtetra
.657 .752 .92 r
.37671 .63138 .3852 .63901 .39923 .63489 .39078 .62716 Mtetra
.653 .749 .921 r
.39078 .62716 .39923 .63489 .41333 .63065 .40493 .62306 Mtetra
.605 .74 .94 r
.40493 .62306 .41333 .63065 .4275 .6267 .41911 .62043 Mtetra
.532 .754 .978 r
.41911 .62043 .4275 .6267 .44172 .62418 .43334 .61904 Mtetra
.451 .757 .995 r
.43334 .61904 .44172 .62418 .456 .62262 .44765 .61843 Mtetra
.479 .8 1 r
.44765 .61843 .456 .62262 .47037 .62172 .46209 .61677 Mtetra
.643 .832 .973 r
.46209 .61677 .47037 .62172 .48485 .62006 .47667 .61229 Mtetra
.704 .768 .902 r
.47667 .61229 .48485 .62006 .49945 .61619 .49134 .60598 Mtetra
.73 .724 .845 r
.49134 .60598 .49945 .61619 .51414 .61074 .50608 .59766 Mtetra
.715 .675 .809 r
.50608 .59766 .51414 .61074 .52889 .60396 .52087 .58921 Mtetra
.695 .646 .797 r
.52087 .58921 .52889 .60396 .5437 .59643 .53571 .58167 Mtetra
.68 .641 .803 r
.53571 .58167 .5437 .59643 .55856 .58913 .55061 .57514 Mtetra
.672 .648 .817 r
.55061 .57514 .55856 .58913 .57348 .58241 .56558 .56935 Mtetra
.665 .659 .833 r
.56558 .56935 .57348 .58241 .58848 .57655 .58063 .56412 Mtetra
.658 .666 .846 r
.58063 .56412 .58848 .57655 .60357 .57121 .59576 .55939 Mtetra
.655 .676 .858 r
.59576 .55939 .60357 .57121 .61874 .56631 .61099 .55484 Mtetra
.655 .683 .864 r
.61099 .55484 .61874 .56631 .634 .5618 .62629 .55028 Mtetra
.62629 .55028 .634 .5618 .64936 .55769 .64168 .54572 Mtetra
.65 .674 .859 r
.64168 .54572 .64936 .55769 .66483 .55403 .65716 .54134 Mtetra
.639 .658 .853 r
.65716 .54134 .66483 .55403 .68042 .55089 .67276 .53747 Mtetra
.626 .641 .846 r
.67276 .53747 .68042 .55089 .69616 .54863 .68847 .53416 Mtetra
.611 .62 .835 r
.68847 .53416 .69616 .54863 .71203 .54697 .70433 .5316 Mtetra
.591 .598 .828 r
.70433 .5316 .71203 .54697 .72804 .54557 .72036 .5301 Mtetra
.572 .588 .831 r
.72036 .5301 .72804 .54557 .74413 .54341 .73657 .52953 Mtetra
.569 .61 .854 r
.73657 .52953 .74413 .54341 .76023 .5399 .7529 .52886 Mtetra
.609 .681 .893 r
.7529 .52886 .76023 .5399 .77631 .53478 .76922 .52613 Mtetra
.649 .754 .926 r
.76922 .52613 .77631 .53478 .7923 .52736 .78551 .52154 Mtetra
.718 .855 .947 r
.78551 .52154 .7923 .52736 .8083 .51915 .80164 .51402 Mtetra
.742 .883 .944 r
.80164 .51402 .8083 .51915 .82441 .5116 .81776 .5054 Mtetra
.725 .849 .94 r
.81776 .5054 .82441 .5116 .84068 .50502 .834 .49757 Mtetra
.694 .806 .934 r
.834 .49757 .84068 .50502 .85717 .49992 .85043 .49101 Mtetra
.658 .756 .922 r
.85043 .49101 .85717 .49992 .87379 .49512 .8671 .48596 Mtetra
.655 .75 .92 r
.8671 .48596 .87379 .49512 .8905 .49018 .88388 .48104 Mtetra
.657 .752 .92 r
.88388 .48104 .8905 .49018 .90728 .48499 .90075 .47597 Mtetra
.662 .759 .922 r
.90075 .47597 .90728 .48499 .92416 .47988 .91769 .47066 Mtetra
.655 .752 .921 r
.91769 .47066 .92416 .47988 .94118 .47508 .93476 .46562 Mtetra
.649 .748 .921 r
.32623 .63577 .33494 .64345 .34879 .63933 .34012 .63185 Mtetra
.651 .754 .925 r
.34012 .63185 .34879 .63933 .36271 .63547 .35409 .62784 Mtetra
.655 .753 .922 r
.35409 .62784 .36271 .63547 .37671 .63138 .36813 .62367 Mtetra
.658 .752 .92 r
.36813 .62367 .37671 .63138 .39078 .62716 .38226 .61939 Mtetra
.619 .741 .933 r
.38226 .61939 .39078 .62716 .40493 .62306 .39641 .61633 Mtetra
.539 .744 .971 r
.39641 .61633 .40493 .62306 .41911 .62043 .41059 .61494 Mtetra
.45 .747 .992 r
.41059 .61494 .41911 .62043 .43334 .61904 .42484 .61451 Mtetra
.472 .787 .999 r
.42484 .61451 .43334 .61904 .44765 .61843 .43923 .61314 Mtetra
.652 .824 .966 r
.43923 .61314 .44765 .61843 .46209 .61677 .45378 .6085 Mtetra
.718 .76 .885 r
.45378 .6085 .46209 .61677 .47667 .61229 .46845 .60143 Mtetra
.738 .715 .829 r
.46845 .60143 .47667 .61229 .49134 .60598 .4832 .59224 Mtetra
.718 .668 .799 r
.4832 .59224 .49134 .60598 .50608 .59766 .49798 .58328 Mtetra
.695 .651 .802 r
.49798 .58328 .50608 .59766 .52087 .58921 .51281 .57583 Mtetra
.682 .66 .822 r
.51281 .57583 .52087 .58921 .53571 .58167 .52768 .56951 Mtetra
.663 .672 .848 r
.52768 .56951 .53571 .58167 .55061 .57514 .54263 .56458 Mtetra
.65 .697 .88 r
.54263 .56458 .55061 .57514 .56558 .56935 .55766 .56036 Mtetra
.646 .73 .911 r
.55766 .56036 .56558 .56935 .58063 .56412 .57278 .55628 Mtetra
.644 .76 .933 r
.57278 .55628 .58063 .56412 .59576 .55939 .58798 .55211 Mtetra
.647 .777 .943 r
.58798 .55211 .59576 .55939 .61099 .55484 .60327 .54774 Mtetra
.652 .785 .945 r
.60327 .54774 .61099 .55484 .62629 .55028 .61864 .54314 Mtetra
.658 .787 .943 r
.61864 .54314 .62629 .55028 .64168 .54572 .63409 .53831 Mtetra
.664 .782 .937 r
.63409 .53831 .64168 .54572 .65716 .54134 .64961 .53327 Mtetra
.667 .767 .925 r
.64961 .53327 .65716 .54134 .67276 .53747 .66521 .52814 Mtetra
.664 .737 .904 r
.66521 .52814 .67276 .53747 .68847 .53416 .6809 .52315 Mtetra
.646 .695 .881 r
.6809 .52315 .68847 .53416 .70433 .5316 .69672 .51888 Mtetra
.615 .651 .862 r
.69672 .51888 .70433 .5316 .72036 .5301 .71271 .51602 Mtetra
.591 .619 .848 r
.71271 .51602 .72036 .5301 .73657 .52953 .72888 .51433 Mtetra
.56 .588 .838 r
.72888 .51433 .73657 .52953 .7529 .52886 .74528 .51419 Mtetra
.552 .592 .848 r
.74528 .51419 .7529 .52886 .76922 .52613 .76183 .51432 Mtetra
.592 .661 .886 r
.76183 .51432 .76922 .52613 .78551 .52154 .77837 .51229 Mtetra
.647 .741 .918 r
.77837 .51229 .78551 .52154 .80164 .51402 .79482 .50776 Mtetra
.726 .848 .939 r
.79482 .50776 .80164 .51402 .81776 .5054 .81108 .49983 Mtetra
.748 .875 .938 r
.81108 .49983 .81776 .5054 .834 .49757 .82732 .49092 Mtetra
.726 .84 .935 r
.82732 .49092 .834 .49757 .85043 .49101 .84371 .48298 Mtetra
.685 .791 .931 r
.84371 .48298 .85043 .49101 .8671 .48596 .86034 .47675 Mtetra
.654 .75 .921 r
.86034 .47675 .8671 .48596 .88388 .48104 .8772 .47179 Mtetra
.656 .752 .92 r
.8772 .47179 .88388 .48104 .90075 .47597 .89414 .46672 Mtetra
.66 .755 .92 r
.89414 .46672 .90075 .47597 .91769 .47066 .91116 .46146 Mtetra
.661 .758 .922 r
.91116 .46146 .91769 .47066 .93476 .46562 .92828 .45611 Mtetra
.647 .752 .925 r
.31744 .62819 .32623 .63577 .34012 .63185 .33136 .62428 Mtetra
.655 .755 .923 r
.33136 .62428 .34012 .63185 .35409 .62784 .34538 .62009 Mtetra
.658 .752 .919 r
.34538 .62009 .35409 .62784 .36813 .62367 .35948 .61577 Mtetra
.641 .745 .924 r
.35948 .61577 .36813 .62367 .38226 .61939 .37362 .61202 Mtetra
.559 .734 .957 r
.37362 .61202 .38226 .61939 .39641 .61633 .38776 .6104 Mtetra
.464 .741 .988 r
.38776 .6104 .39641 .61633 .41059 .61494 .40196 .60995 Mtetra
.449 .765 .996 r
.40196 .60995 .41059 .61494 .42484 .61451 .41627 .60917 Mtetra
.635 .819 .971 r
.41627 .60917 .42484 .61451 .43923 .61314 .43078 .60497 Mtetra
.722 .763 .886 r
.43078 .60497 .43923 .61314 .45378 .6085 .44545 .59774 Mtetra
.747 .719 .826 r
.44545 .59774 .45378 .6085 .46845 .60143 .46021 .58794 Mtetra
.724 .673 .8 r
.46021 .58794 .46845 .60143 .4832 .59224 .475 .5786 Mtetra
.7 .663 .81 r
.475 .5786 .4832 .59224 .49798 .58328 .48981 .57103 Mtetra
.677 .676 .841 r
.48981 .57103 .49798 .58328 .51281 .57583 .50466 .56526 Mtetra
.647 .695 .881 r
.50466 .56526 .51281 .57583 .52768 .56951 .51958 .56118 Mtetra
.631 .741 .928 r
.51958 .56118 .52768 .56951 .54263 .56458 .53459 .55757 Mtetra
.626 .777 .953 r
.53459 .55757 .54263 .56458 .55766 .56036 .54968 .55382 Mtetra
.629 .792 .96 r
.54968 .55382 .55766 .56036 .57278 .55628 .56487 .54985 Mtetra
.634 .798 .961 r
.56487 .54985 .57278 .55628 .58798 .55211 .58013 .54566 Mtetra
.641 .801 .959 r
.58013 .54566 .58798 .55211 .60327 .54774 .59549 .54124 Mtetra
.648 .802 .957 r
.59549 .54124 .60327 .54774 .61864 .54314 .61092 .53659 Mtetra
.654 .804 .955 r
.61092 .53659 .61864 .54314 .63409 .53831 .62643 .53172 Mtetra
.661 .806 .953 r
.62643 .53172 .63409 .53831 .64961 .53327 .64203 .52662 Mtetra
.667 .808 .951 r
.64203 .52662 .64961 .53327 .66521 .52814 .65769 .52129 Mtetra
.673 .805 .946 r
.65769 .52129 .66521 .52814 .6809 .52315 .67343 .51573 Mtetra
.678 .792 .935 r
.67343 .51573 .6809 .52315 .69672 .51888 .68925 .51003 Mtetra
.667 .753 .915 r
.68925 .51003 .69672 .51888 .71271 .51602 .70517 .50479 Mtetra
.627 .687 .887 r
.70517 .50479 .71271 .51602 .72888 .51433 .72128 .50128 Mtetra
.586 .636 .867 r
.72128 .50128 .72888 .51433 .74528 .51419 .73761 .49962 Mtetra
.549 .593 .851 r
.73761 .49962 .74528 .51419 .76183 .51432 .7542 .49979 Mtetra
.536 .588 .854 r
.7542 .49979 .76183 .51432 .77837 .51229 .77097 .50045 Mtetra
.588 .662 .889 r
.77097 .50045 .77837 .51229 .79482 .50776 .78768 .49849 Mtetra
.658 .749 .917 r
.78768 .49849 .79482 .50776 .81108 .49983 .80426 .49341 Mtetra
.741 .851 .931 r
.80426 .49341 .81108 .49983 .82732 .49092 .82062 .48477 Mtetra
.749 .862 .932 r
.82062 .48477 .82732 .49092 .84371 .48298 .837 .47575 Mtetra
.721 .827 .931 r
.837 .47575 .84371 .48298 .86034 .47675 .85356 .46793 Mtetra
.668 .768 .925 r
.85356 .46793 .86034 .47675 .8772 .47179 .87043 .46233 Mtetra
.654 .748 .919 r
.87043 .46233 .8772 .47179 .89414 .46672 .88745 .45732 Mtetra
.656 .752 .92 r
.88745 .45732 .89414 .46672 .91116 .46146 .90457 .45216 Mtetra
.663 .758 .921 r
.90457 .45216 .91116 .46146 .92828 .45611 .92175 .44669 Mtetra
.651 .753 .925 r
.30855 .62057 .31744 .62819 .33136 .62428 .32253 .61651 Mtetra
.656 .752 .921 r
.32253 .61651 .33136 .62428 .34538 .62009 .33659 .61226 Mtetra
.655 .751 .92 r
.33659 .61226 .34538 .62009 .35948 .61577 .35073 .60801 Mtetra
.596 .737 .943 r
.35073 .60801 .35948 .61577 .37362 .61202 .36486 .60552 Mtetra
.498 .739 .98 r
.36486 .60552 .37362 .61202 .38776 .6104 .37901 .60473 Mtetra
.43 .736 .991 r
.37901 .60473 .38776 .6104 .40196 .60995 .39324 .6046 Mtetra
.585 .806 .984 r
.39324 .6046 .40196 .60995 .41627 .60917 .40767 .60156 Mtetra
.711 .775 .902 r
.40767 .60156 .41627 .60917 .43078 .60497 .42231 .59492 Mtetra
.755 .734 .832 r
.42231 .59492 .43078 .60497 .44545 .59774 .4371 .5848 Mtetra
.734 .685 .802 r
.4371 .5848 .44545 .59774 .46021 .58794 .45191 .57484 Mtetra
.707 .674 .815 r
.45191 .57484 .46021 .58794 .475 .5786 .46671 .56694 Mtetra
.673 .685 .853 r
.46671 .56694 .475 .5786 .48981 .57103 .48154 .56149 Mtetra
.634 .714 .905 r
.48154 .56149 .48981 .57103 .50466 .56526 .49642 .55786 Mtetra
.615 .762 .949 r
.49642 .55786 .50466 .56526 .51958 .56118 .5114 .55452 Mtetra
.616 .784 .962 r
.5114 .55452 .51958 .56118 .53459 .55757 .52646 .55096 Mtetra
.624 .789 .961 r
.52646 .55096 .53459 .55757 .54968 .55382 .54162 .54712 Mtetra
.639 .793 .956 r
.54162 .54712 .54968 .55382 .56487 .54985 .55686 .54283 Mtetra
.648 .787 .949 r
.55686 .54283 .56487 .54985 .58013 .54566 .57218 .5383 Mtetra
.651 .78 .942 r
.57218 .5383 .58013 .54566 .59549 .54124 .58759 .53368 Mtetra
.653 .777 .939 r
.58759 .53368 .59549 .54124 .61092 .53659 .60309 .52898 Mtetra
.654 .777 .939 r
.60309 .52898 .61092 .53659 .62643 .53172 .61867 .52422 Mtetra
.656 .782 .941 r
.61867 .52422 .62643 .53172 .64203 .52662 .63434 .51937 Mtetra
.661 .791 .944 r
.63434 .51937 .64203 .52662 .65769 .52129 .65008 .51428 Mtetra
.672 .803 .945 r
.65008 .51428 .65769 .52129 .67343 .51573 .6659 .50871 Mtetra
.679 .806 .943 r
.6659 .50871 .67343 .51573 .68925 .51003 .68178 .50287 Mtetra
.685 .805 .939 r
.68178 .50287 .68925 .51003 .70517 .50479 .69773 .49679 Mtetra
.678 .782 .928 r
.69773 .49679 .70517 .50479 .72128 .50128 .71378 .491 Mtetra
.634 .712 .904 r
.71378 .491 .72128 .50128 .73761 .49962 .73003 .48706 Mtetra
.577 .642 .879 r
.73003 .48706 .73761 .49962 .7542 .49979 .74655 .48565 Mtetra
.531 .593 .862 r
.74655 .48565 .7542 .49979 .77097 .50045 .76335 .48636 Mtetra
.525 .592 .864 r
.76335 .48636 .77097 .50045 .78768 .49849 .78033 .48727 Mtetra
.601 .683 .9 r
.78033 .48727 .78768 .49849 .80426 .49341 .79717 .48461 Mtetra
.687 .775 .918 r
.79717 .48461 .80426 .49341 .82062 .48477 .8138 .47822 Mtetra
.756 .855 .923 r
.8138 .47822 .82062 .48477 .837 .47575 .83024 .46878 Mtetra
.741 .842 .926 r
.83024 .46878 .837 .47575 .85356 .46793 .84681 .46001 Mtetra
.7 .806 .931 r
.84681 .46001 .85356 .46793 .87043 .46233 .86361 .45299 Mtetra
.656 .754 .922 r
.86361 .45299 .87043 .46233 .88745 .45732 .88069 .4478 Mtetra
.656 .751 .92 r
.88069 .4478 .88745 .45732 .90457 .45216 .89788 .4426 Mtetra
.66 .754 .919 r
.89788 .4426 .90457 .45216 .92175 .44669 .91515 .4372 Mtetra
.654 .754 .923 r
.29958 .61287 .30855 .62057 .32253 .61651 .31361 .60865 Mtetra
.658 .752 .919 r
.31361 .60865 .32253 .61651 .33659 .61226 .32772 .60426 Mtetra
.637 .744 .926 r
.32772 .60426 .33659 .61226 .35073 .60801 .34187 .60058 Mtetra
.543 .73 .961 r
.34187 .60058 .35073 .60801 .36486 .60552 .35599 .59924 Mtetra
.442 .724 .986 r
.35599 .59924 .36486 .60552 .37901 .60473 .37014 .59922 Mtetra
.496 .771 .993 r
.37014 .59922 .37901 .60473 .39324 .6046 .38447 .59791 Mtetra
.686 .795 .932 r
.38447 .59791 .39324 .6046 .40767 .60156 .39905 .59231 Mtetra
.753 .748 .848 r
.39905 .59231 .40767 .60156 .42231 .59492 .41383 .58277 Mtetra
.749 .7 .806 r
.41383 .58277 .42231 .59492 .4371 .5848 .42868 .57201 Mtetra
.718 .683 .815 r
.42868 .57201 .4371 .5848 .45191 .57484 .4435 .56344 Mtetra
.68 .693 .855 r
.4435 .56344 .45191 .57484 .46671 .56694 .45831 .55767 Mtetra
.628 .719 .912 r
.45831 .55767 .46671 .56694 .48154 .56149 .47316 .55421 Mtetra
.607 .764 .954 r
.47316 .55421 .48154 .56149 .49642 .55786 .48809 .55106 Mtetra
.61 .779 .962 r
.48809 .55106 .49642 .55786 .5114 .55452 .50312 .54765 Mtetra
.633 .786 .955 r
.50312 .54765 .5114 .55452 .52646 .55096 .51824 .5436 Mtetra
.648 .778 .943 r
.51824 .5436 .52646 .55096 .54162 .54712 .53345 .53912 Mtetra
.653 .764 .93 r
.53345 .53912 .54162 .54712 .55686 .54283 .54875 .53451 Mtetra
.654 .757 .926 r
.54875 .53451 .55686 .54283 .57218 .5383 .56413 .52989 Mtetra
.654 .756 .925 r
.56413 .52989 .57218 .5383 .58759 .53368 .5796 .52522 Mtetra
.656 .757 .924 r
.5796 .52522 .58759 .53368 .60309 .52898 .59516 .52048 Mtetra
.657 .757 .924 r
.59516 .52048 .60309 .52898 .61867 .52422 .6108 .51567 Mtetra
.657 .757 .923 r
.6108 .51567 .61867 .52422 .63434 .51937 .62653 .51081 Mtetra
.657 .758 .924 r
.62653 .51081 .63434 .51937 .65008 .51428 .64234 .50593 Mtetra
.659 .766 .928 r
.64234 .50593 .65008 .51428 .6659 .50871 .65825 .50093 Mtetra
.669 .784 .935 r
.65825 .50093 .6659 .50871 .68178 .50287 .67422 .49549 Mtetra
.685 .801 .937 r
.67422 .49549 .68178 .50287 .69773 .49679 .69024 .48938 Mtetra
.691 .804 .935 r
.69024 .48938 .69773 .49679 .71378 .491 .70634 .48301 Mtetra
.683 .788 .929 r
.70634 .48301 .71378 .491 .73003 .48706 .72253 .47694 Mtetra
.625 .716 .911 r
.72253 .47694 .73003 .48706 .74655 .48565 .73896 .47324 Mtetra
.558 .639 .887 r
.73896 .47324 .74655 .48565 .76335 .48636 .7557 .47241 Mtetra
.508 .587 .869 r
.7557 .47241 .76335 .48636 .78033 .48727 .77275 .47388 Mtetra
.536 .612 .876 r
.77275 .47388 .78033 .48727 .79717 .48461 .78987 .4741 Mtetra
.626 .713 .909 r
.78987 .4741 .79717 .48461 .8138 .47822 .80679 .47026 Mtetra
.729 .813 .917 r
.80679 .47026 .8138 .47822 .83024 .46878 .82342 .46196 Mtetra
.759 .853 .92 r
.82342 .46196 .83024 .46878 .84681 .46001 .84 .45229 Mtetra
.728 .822 .923 r
.84 .45229 .84681 .46001 .86361 .45299 .85676 .44398 Mtetra
.671 .771 .925 r
.85676 .44398 .86361 .45299 .88069 .4478 .87385 .43809 Mtetra
.653 .748 .919 r
.87385 .43809 .88069 .4478 .89788 .4426 .89112 .43294 Mtetra
.657 .752 .92 r
.89112 .43294 .89788 .4426 .91515 .4372 .90848 .4276 Mtetra
.655 .752 .921 r
.29052 .60501 .29958 .61287 .31361 .60865 .3046 .60071 Mtetra
.657 .752 .92 r
.3046 .60071 .31361 .60865 .32772 .60426 .31876 .59633 Mtetra
.601 .738 .94 r
.31876 .59633 .32772 .60426 .34187 .60058 .33289 .59366 Mtetra
.496 .729 .976 r
.33289 .59366 .34187 .60058 .35599 .59924 .34701 .593 Mtetra
.43 .723 .987 r
.34701 .593 .35599 .59924 .37014 .59922 .36121 .59308 Mtetra
.613 .793 .968 r
.36121 .59308 .37014 .59922 .38447 .59791 .37567 .58957 Mtetra
.732 .764 .878 r
.37567 .58957 .38447 .59791 .39905 .59231 .39039 .58165 Mtetra
.764 .727 .818 r
.39039 .58165 .39905 .59231 .41383 .58277 .40528 .57044 Mtetra
.736 .695 .812 r
.40528 .57044 .41383 .58277 .42868 .57201 .42015 .56066 Mtetra
.699 .701 .848 r
.42015 .56066 .42868 .57201 .4435 .56344 .43497 .55379 Mtetra
.633 .713 .905 r
.43497 .55379 .4435 .56344 .45831 .55767 .44979 .55015 Mtetra
.601 .757 .953 r
.44979 .55015 .45831 .55767 .47316 .55421 .46468 .54718 Mtetra
.606 .772 .96 r
.46468 .54718 .47316 .55421 .48809 .55106 .47966 .54393 Mtetra
.637 .781 .95 r
.47966 .54393 .48809 .55106 .50312 .54765 .49476 .53977 Mtetra
.651 .766 .933 r
.49476 .53977 .50312 .54765 .51824 .5436 .50994 .53523 Mtetra
.651 .755 .925 r
.50994 .53523 .51824 .5436 .53345 .53912 .52521 .53071 Mtetra
.651 .755 .926 r
.52521 .53071 .53345 .53912 .54875 .53451 .54056 .52616 Mtetra
.652 .758 .927 r
.54056 .52616 .54875 .53451 .56413 .52989 .556 .52154 Mtetra
.654 .76 .927 r
.556 .52154 .56413 .52989 .5796 .52522 .57153 .51684 Mtetra
.655 .761 .927 r
.57153 .51684 .5796 .52522 .59516 .52048 .58714 .51205 Mtetra
.657 .761 .927 r
.58714 .51205 .59516 .52048 .6108 .51567 .60285 .50718 Mtetra
.658 .761 .926 r
.60285 .50718 .6108 .51567 .62653 .51081 .61863 .50221 Mtetra
.66 .76 .924 r
.61863 .50221 .62653 .51081 .64234 .50593 .63451 .49718 Mtetra
.66 .758 .922 r
.63451 .49718 .64234 .50593 .65825 .50093 .65047 .49212 Mtetra
.659 .757 .923 r
.65047 .49212 .65825 .50093 .67422 .49549 .66653 .48708 Mtetra
.667 .771 .927 r
.66653 .48708 .67422 .49549 .69024 .48938 .68266 .48164 Mtetra
.69 .797 .931 r
.68266 .48164 .69024 .48938 .70634 .48301 .69883 .47527 Mtetra
.696 .8 .93 r
.69883 .47527 .70634 .48301 .72253 .47694 .71506 .46861 Mtetra
.679 .781 .927 r
.71506 .46861 .72253 .47694 .73896 .47324 .73142 .46261 Mtetra
.597 .696 .912 r
.73142 .46261 .73896 .47324 .7557 .47241 .74809 .45994 Mtetra
.524 .624 .892 r
.74809 .45994 .7557 .47241 .77275 .47388 .7651 .46027 Mtetra
.491 .587 .878 r
.7651 .46027 .77275 .47388 .78987 .4741 .78238 .46212 Mtetra
.571 .659 .897 r
.78238 .46212 .78987 .4741 .80679 .47026 .79956 .46058 Mtetra
.677 .756 .91 r
.79956 .46058 .80679 .47026 .82342 .46196 .81647 .45447 Mtetra
.76 .837 .911 r
.81647 .45447 .82342 .46196 .84 .45229 .83312 .4446 Mtetra
.744 .83 .917 r
.83312 .4446 .84 .45229 .85676 .44398 .84989 .43547 Mtetra
.697 .796 .926 r
.84989 .43547 .85676 .44398 .87385 .43809 .86695 .42843 Mtetra
.655 .752 .922 r
.86695 .42843 .87385 .43809 .89112 .43294 .88429 .42317 Mtetra
.656 .752 .92 r
.88429 .42317 .89112 .43294 .90848 .4276 .90173 .41781 Mtetra
.657 .752 .92 r
.28138 .59704 .29052 .60501 .3046 .60071 .2955 .59263 Mtetra
.649 .748 .922 r
.2955 .59263 .3046 .60071 .31876 .59633 .30969 .5885 Mtetra
.561 .729 .953 r
.30969 .5885 .31876 .59633 .33289 .59366 .32381 .58677 Mtetra
.454 .715 .98 r
.32381 .58677 .33289 .59366 .34701 .593 .33793 .58677 Mtetra
.481 .746 .987 r
.33793 .58677 .34701 .593 .36121 .59308 .35221 .58597 Mtetra
.685 .786 .927 r
.35221 .58597 .36121 .59308 .37567 .58957 .36682 .58035 Mtetra
.762 .752 .844 r
.36682 .58035 .37567 .58957 .39039 .58165 .3817 .57016 Mtetra
.759 .714 .811 r
.3817 .57016 .39039 .58165 .40528 .57044 .39664 .55893 Mtetra
.724 .706 .833 r
.39664 .55893 .40528 .57044 .42015 .56066 .41151 .5504 Mtetra
.657 .709 .886 r
.41151 .5504 .42015 .56066 .43497 .55379 .42632 .54577 Mtetra
.601 .744 .945 r
.42632 .54577 .43497 .55379 .44979 .55015 .44116 .54288 Mtetra
.599 .765 .958 r
.44116 .54288 .44979 .55015 .46468 .54718 .45611 .53984 Mtetra
.632 .774 .949 r
.45611 .53984 .46468 .54718 .47966 .54393 .47116 .53583 Mtetra
.651 .761 .93 r
.47116 .53583 .47966 .54393 .49476 .53977 .48631 .53128 Mtetra
.649 .752 .925 r
.48631 .53128 .49476 .53977 .50994 .53523 .50155 .52683 Mtetra
.649 .756 .927 r
.50155 .52683 .50994 .53523 .52521 .53071 .51687 .52233 Mtetra
.649 .757 .929 r
.51687 .52233 .52521 .53071 .54056 .52616 .53228 .51782 Mtetra
.651 .76 .929 r
.53228 .51782 .54056 .52616 .556 .52154 .54778 .5132 Mtetra
.653 .762 .929 r
.54778 .5132 .556 .52154 .57153 .51684 .56337 .50847 Mtetra
.655 .763 .929 r
.56337 .50847 .57153 .51684 .58714 .51205 .57905 .50363 Mtetra
.657 .763 .928 r
.57905 .50363 .58714 .51205 .60285 .50718 .59481 .49869 Mtetra
.659 .764 .927 r
.59481 .49869 .60285 .50718 .61863 .50221 .61066 .49363 Mtetra
.662 .764 .925 r
.61066 .49363 .61863 .50221 .63451 .49718 .6266 .48846 Mtetra
.662 .761 .924 r
.6266 .48846 .63451 .49718 .65047 .49212 .64262 .48327 Mtetra
.662 .76 .923 r
.64262 .48327 .65047 .49212 .66653 .48708 .65874 .47804 Mtetra
.659 .756 .921 r
.65874 .47804 .66653 .48708 .68266 .48164 .67495 .4729 Mtetra
.672 .768 .923 r
.67495 .4729 .68266 .48164 .69883 .47527 .69122 .4672 Mtetra
.695 .794 .926 r
.69122 .4672 .69883 .47527 .71506 .46861 .70753 .46051 Mtetra
.698 .795 .925 r
.70753 .46051 .71506 .46861 .73142 .46261 .72391 .45365 Mtetra
.654 .761 .928 r
.72391 .45365 .73142 .46261 .74809 .45994 .74049 .44857 Mtetra
.553 .663 .909 r
.74049 .44857 .74809 .45994 .7651 .46027 .75745 .44751 Mtetra
.482 .599 .893 r
.75745 .44751 .7651 .46027 .78238 .46212 .77477 .44927 Mtetra
.514 .615 .891 r
.77477 .44927 .78238 .46212 .79956 .46058 .79218 .44997 Mtetra
.627 .717 .911 r
.79218 .44997 .79956 .46058 .81647 .45447 .80934 .44595 Mtetra
.74 .809 .906 r
.80934 .44595 .81647 .45447 .83312 .4446 .82616 .43689 Mtetra
.759 .836 .91 r
.82616 .43689 .83312 .4446 .84989 .43547 .84296 .42698 Mtetra
.72 .806 .918 r
.84296 .42698 .84989 .43547 .86695 .42843 .85999 .41884 Mtetra
.662 .76 .923 r
.85999 .41884 .86695 .42843 .88429 .42317 .87737 .41322 Mtetra
.655 .75 .92 r
.87737 .41322 .88429 .42317 .90173 .41781 .89489 .40787 Mtetra
.658 .752 .919 r
.27214 .58898 .28138 .59704 .2955 .59263 .28632 .58448 Mtetra
.633 .744 .928 r
.28632 .58448 .2955 .59263 .30969 .5885 .30051 .58084 Mtetra
.527 .724 .963 r
.30051 .58084 .30969 .5885 .32381 .58677 .31463 .57975 Mtetra
.434 .704 .979 r
.31463 .57975 .32381 .58677 .33793 .58677 .32878 .58006 Mtetra
.565 .766 .973 r
.32878 .58006 .33793 .58677 .35221 .58597 .34318 .57777 Mtetra
.72 .768 .89 r
.34318 .57777 .35221 .58597 .36682 .58035 .35792 .5705 Mtetra
.775 .744 .825 r
.35792 .5705 .36682 .58035 .3817 .57016 .37292 .55885 Mtetra
.751 .717 .82 r
.37292 .55885 .3817 .57016 .39664 .55893 .38788 .5484 Mtetra
.703 .719 .861 r
.38788 .5484 .39664 .55893 .41151 .5504 .40275 .54146 Mtetra
.619 .728 .924 r
.40275 .54146 .41151 .5504 .42632 .54577 .41756 .53816 Mtetra
.594 .755 .955 r
.41756 .53816 .42632 .54577 .44116 .54288 .43245 .53532 Mtetra
.617 .765 .95 r
.43245 .53532 .44116 .54288 .45611 .53984 .44746 .53178 Mtetra
.649 .763 .932 r
.44746 .53178 .45611 .53984 .47116 .53583 .46257 .52729 Mtetra
.648 .752 .925 r
.46257 .52729 .47116 .53583 .48631 .53128 .47778 .52283 Mtetra
.647 .754 .928 r
.47778 .52283 .48631 .53128 .50155 .52683 .49307 .51839 Mtetra
.646 .756 .929 r
.49307 .51839 .50155 .52683 .51687 .52233 .50845 .51394 Mtetra
.65 .759 .929 r
.50845 .51394 .51687 .52233 .53228 .51782 .52392 .50932 Mtetra
.655 .76 .926 r
.52392 .50932 .53228 .51782 .54778 .5132 .53947 .50449 Mtetra
.656 .756 .923 r
.53947 .50449 .54778 .5132 .56337 .50847 .55512 .49961 Mtetra
.656 .753 .922 r
.55512 .49961 .56337 .50847 .57905 .50363 .57086 .49472 Mtetra
.655 .753 .922 r
.57086 .49472 .57905 .50363 .59481 .49869 .58668 .48982 Mtetra
.656 .756 .924 r
.58668 .48982 .59481 .49869 .61066 .49363 .6026 .48488 Mtetra
.66 .761 .925 r
.6026 .48488 .61066 .49363 .6266 .48846 .6186 .47971 Mtetra
.664 .764 .924 r
.6186 .47971 .6266 .48846 .64262 .48327 .63469 .47438 Mtetra
.664 .761 .923 r
.63469 .47438 .64262 .48327 .65874 .47804 .65086 .46903 Mtetra
.663 .76 .922 r
.65086 .46903 .65874 .47804 .67495 .4729 .66713 .46369 Mtetra
.661 .756 .92 r
.66713 .46369 .67495 .4729 .69122 .4672 .6835 .45839 Mtetra
.684 .774 .919 r
.6835 .45839 .69122 .4672 .70753 .46051 .6999 .45211 Mtetra
.701 .791 .921 r
.6999 .45211 .70753 .46051 .72391 .45365 .71635 .4451 Mtetra
.689 .785 .924 r
.71635 .4451 .72391 .45365 .74049 .44857 .73291 .43854 Mtetra
.593 .713 .928 r
.73291 .43854 .74049 .44857 .75745 .44751 .74981 .43574 Mtetra
.497 .629 .911 r
.74981 .43574 .75745 .44751 .77477 .44927 .76711 .43658 Mtetra
.467 .596 .897 r
.76711 .43658 .77477 .44927 .79218 .44997 .78468 .43868 Mtetra
.586 .686 .911 r
.78468 .43868 .79218 .44997 .80934 .44595 .80205 .43627 Mtetra
.706 .773 .904 r
.80205 .43627 .80934 .44595 .82616 .43689 .81908 .42867 Mtetra
.764 .827 .901 r
.81908 .42867 .82616 .43689 .84296 .42698 .83593 .41833 Mtetra
.735 .81 .911 r
.83593 .41833 .84296 .42698 .85999 .41884 .85298 .40942 Mtetra
.675 .771 .923 r
.85298 .40942 .85999 .41884 .87737 .41322 .87038 .40318 Mtetra
.653 .749 .92 r
.87038 .40318 .87737 .41322 .89489 .40787 .88798 .39782 Mtetra
.658 .752 .919 r
.26281 .58084 .27214 .58898 .28632 .58448 .27704 .57631 Mtetra
.612 .74 .936 r
.27704 .57631 .28632 .58448 .30051 .58084 .29123 .57324 Mtetra
.504 .718 .968 r
.29123 .57324 .30051 .58084 .31463 .57975 .30537 .57253 Mtetra
.436 .702 .977 r
.30537 .57253 .31463 .57975 .32878 .58006 .31955 .57284 Mtetra
.626 .772 .95 r
.31955 .57284 .32878 .58006 .34318 .57777 .33407 .56911 Mtetra
.747 .764 .866 r
.33407 .56911 .34318 .57777 .35792 .5705 .34895 .56016 Mtetra
.776 .737 .818 r
.34895 .56016 .35792 .5705 .37292 .55885 .36403 .54806 Mtetra
.742 .725 .836 r
.36403 .54806 .37292 .55885 .38788 .5484 .37901 .53854 Mtetra
.673 .725 .889 r
.37901 .53854 .38788 .5484 .40275 .54146 .39386 .53318 Mtetra
.598 .74 .944 r
.39386 .53318 .40275 .54146 .41756 .53816 .40871 .53035 Mtetra
.597 .753 .952 r
.40871 .53035 .41756 .53816 .43245 .53532 .42365 .52742 Mtetra
.639 .765 .939 r
.42365 .52742 .43245 .53532 .44746 .53178 .43873 .52324 Mtetra
.65 .753 .925 r
.43873 .52324 .44746 .53178 .46257 .52729 .4539 .5187 Mtetra
.646 .752 .926 r
.4539 .5187 .46257 .52729 .47778 .52283 .46915 .51427 Mtetra
.644 .753 .928 r
.46915 .51427 .47778 .52283 .49307 .51839 .4845 .50987 Mtetra
.65 .757 .928 r
.4845 .50987 .49307 .51839 .50845 .51394 .49994 .50524 Mtetra
.657 .756 .923 r
.49994 .50524 .50845 .51394 .52392 .50932 .51546 .50033 Mtetra
.658 .751 .919 r
.51546 .50033 .52392 .50932 .53947 .50449 .53108 .49538 Mtetra
.656 .749 .918 r
.53108 .49538 .53947 .50449 .55512 .49961 .54678 .49045 Mtetra
.54678 .49045 .55512 .49961 .57086 .49472 .56258 .48551 Mtetra
.56258 .48551 .57086 .49472 .58668 .48982 .57846 .48056 Mtetra
.654 .748 .919 r
.57846 .48056 .58668 .48982 .6026 .48488 .59444 .47563 Mtetra
.655 .75 .92 r
.59444 .47563 .6026 .48488 .6186 .47971 .61051 .47066 Mtetra
.661 .758 .922 r
.61051 .47066 .6186 .47971 .63469 .47438 .62666 .4654 Mtetra
.666 .763 .922 r
.62666 .4654 .63469 .47438 .65086 .46903 .6429 .4599 Mtetra
.664 .76 .921 r
.6429 .4599 .65086 .46903 .66713 .46369 .65924 .45444 Mtetra
.661 .757 .921 r
.65924 .45444 .66713 .46369 .6835 .45839 .67567 .44907 Mtetra
.669 .76 .918 r
.67567 .44907 .6835 .45839 .6999 .45211 .69217 .44335 Mtetra
.699 .784 .917 r
.69217 .44335 .6999 .45211 .71635 .4451 .7087 .43633 Mtetra
.701 .786 .917 r
.7087 .43633 .71635 .4451 .73291 .43854 .7253 .42919 Mtetra
.637 .75 .93 r
.7253 .42919 .73291 .43854 .74981 .43574 .74216 .42464 Mtetra
.52 .658 .922 r
.74216 .42464 .74981 .43574 .76711 .43658 .75943 .42441 Mtetra
.445 .597 .908 r
.75943 .42441 .76711 .43658 .78468 .43868 .77708 .42687 Mtetra
.542 .656 .91 r
.77708 .42687 .78468 .43868 .80205 .43627 .79464 .42609 Mtetra
.675 .753 .91 r
.79464 .42609 .80205 .43627 .81908 .42867 .81188 .41988 Mtetra
.763 .815 .894 r
.81188 .41988 .81908 .42867 .83593 .41833 .82881 .40944 Mtetra
.743 .809 .904 r
.82881 .40944 .83593 .41833 .85298 .40942 .8459 .40003 Mtetra
.69 .78 .92 r
.8459 .40003 .85298 .40942 .87038 .40318 .86332 .39308 Mtetra
.654 .751 .921 r
.86332 .39308 .87038 .40318 .88798 .39782 .881 .38765 Mtetra
.657 .752 .92 r
.25339 .57262 .26281 .58084 .27704 .57631 .26766 .56809 Mtetra
.594 .735 .942 r
.26766 .56809 .27704 .57631 .29123 .57324 .28186 .56547 Mtetra
.484 .708 .969 r
.28186 .56547 .29123 .57324 .30537 .57253 .29601 .56514 Mtetra
.456 .708 .976 r
.29601 .56514 .30537 .57253 .31955 .57284 .31024 .56514 Mtetra
.664 .771 .93 r
.31024 .56514 .31955 .57284 .33407 .56911 .32488 .56022 Mtetra
.763 .763 .852 r
.32488 .56022 .33407 .56911 .34895 .56016 .33989 .55003 Mtetra
.776 .743 .822 r
.33989 .55003 .34895 .56016 .36403 .54806 .35502 .53807 Mtetra
.738 .74 .853 r
.35502 .53807 .36403 .54806 .37901 .53854 .37003 .52917 Mtetra
.644 .73 .911 r
.37003 .52917 .37901 .53854 .39386 .53318 .38488 .52498 Mtetra
.591 .742 .948 r
.38488 .52498 .39386 .53318 .40871 .53035 .39977 .52226 Mtetra
.608 .751 .946 r
.39977 .52226 .40871 .53035 .42365 .52742 .41477 .519 Mtetra
.648 .756 .928 r
.41477 .519 .42365 .52742 .43873 .52324 .42991 .5145 Mtetra
.647 .75 .924 r
.42991 .5145 .43873 .52324 .4539 .5187 .44513 .51002 Mtetra
.644 .751 .927 r
.44513 .51002 .4539 .5187 .46915 .51427 .46044 .50562 Mtetra
.646 .754 .928 r
.46044 .50562 .46915 .51427 .4845 .50987 .47584 .50113 Mtetra
.657 .756 .923 r
.47584 .50113 .4845 .50987 .49994 .50524 .49134 .4962 Mtetra
.658 .751 .918 r
.49134 .4962 .49994 .50524 .51546 .50033 .50692 .49121 Mtetra
.656 .749 .919 r
.50692 .49121 .51546 .50033 .53108 .49538 .52259 .48626 Mtetra
.655 .75 .92 r
.52259 .48626 .53108 .49538 .54678 .49045 .53836 .48133 Mtetra
.656 .752 .921 r
.53836 .48133 .54678 .49045 .56258 .48551 .55421 .47634 Mtetra
.657 .752 .92 r
.55421 .47634 .56258 .48551 .57846 .48056 .57015 .47128 Mtetra
.656 .751 .92 r
.57015 .47128 .57846 .48056 .59444 .47563 .58619 .46624 Mtetra
.654 .749 .919 r
.58619 .46624 .59444 .47563 .61051 .47066 .60232 .46124 Mtetra
.655 .75 .92 r
.60232 .46124 .61051 .47066 .62666 .4654 .61855 .45618 Mtetra
.665 .759 .92 r
.61855 .45618 .62666 .4654 .6429 .4599 .63486 .45068 Mtetra
.667 .761 .921 r
.63486 .45068 .6429 .4599 .65924 .45444 .65125 .44508 Mtetra
.664 .758 .92 r
.65125 .44508 .65924 .45444 .67567 .44907 .66775 .43955 Mtetra
.663 .755 .919 r
.66775 .43955 .67567 .44907 .69217 .44335 .68433 .43404 Mtetra
.692 .771 .912 r
.68433 .43404 .69217 .44335 .7087 .43633 .70095 .42725 Mtetra
.705 .782 .912 r
.70095 .42725 .7087 .43633 .7253 .42919 .71762 .41989 Mtetra
.669 .766 .923 r
.71762 .41989 .7253 .42919 .74216 .42464 .73446 .41405 Mtetra
.537 .68 .931 r
.73446 .41405 .74216 .42464 .75943 .42441 .75174 .41305 Mtetra
.437 .612 .923 r
.75174 .41305 .75943 .42441 .77708 .42687 .76942 .41526 Mtetra
.502 .642 .919 r
.76942 .41526 .77708 .42687 .79464 .42609 .78714 .41566 Mtetra
.647 .738 .916 r
.78714 .41566 .79464 .42609 .81188 .41988 .80455 .41057 Mtetra
.755 .803 .891 r
.80455 .41057 .81188 .41988 .82881 .40944 .8216 .40036 Mtetra
.751 .809 .899 r
.8216 .40036 .82881 .40944 .8459 .40003 .83874 .39045 Mtetra
.701 .783 .914 r
.83874 .39045 .8459 .40003 .86332 .39308 .85618 .38291 Mtetra
.655 .752 .921 r
.85618 .38291 .86332 .39308 .881 .38765 .87393 .37737 Mtetra
.656 .751 .92 r
.24388 .56433 .25339 .57262 .26766 .56809 .25819 .5598 Mtetra
.581 .731 .946 r
.25819 .5598 .26766 .56809 .28186 .56547 .27241 .55748 Mtetra
.474 .7 .967 r
.27241 .55748 .28186 .56547 .29601 .56514 .28657 .55736 Mtetra
.481 .71 .97 r
.28657 .55736 .29601 .56514 .31024 .56514 .30086 .55701 Mtetra
.684 .767 .915 r
.30086 .55701 .31024 .56514 .32488 .56022 .3156 .55129 Mtetra
.773 .764 .845 r
.3156 .55129 .32488 .56022 .33989 .55003 .33071 .54031 Mtetra
.777 .751 .83 r
.33071 .54031 .33989 .55003 .35502 .53807 .3459 .52854 Mtetra
.73 .749 .867 r
.3459 .52854 .35502 .53807 .37003 .52917 .36093 .52025 Mtetra
.625 .736 .927 r
.36093 .52025 .37003 .52917 .38488 .52498 .37581 .51662 Mtetra
.591 .74 .947 r
.37581 .51662 .38488 .52498 .39977 .52226 .39074 .51388 Mtetra
.619 .75 .939 r
.39074 .51388 .39977 .52226 .41477 .519 .4058 .51028 Mtetra
.65 .752 .924 r
.4058 .51028 .41477 .519 .42991 .5145 .42099 .50568 Mtetra
.645 .75 .925 r
.42099 .50568 .42991 .5145 .44513 .51002 .43627 .50121 Mtetra
.643 .75 .927 r
.43627 .50121 .44513 .51002 .46044 .50562 .45163 .49681 Mtetra
.651 .753 .925 r
.45163 .49681 .46044 .50562 .47584 .50113 .46709 .49209 Mtetra
.659 .752 .919 r
.46709 .49209 .47584 .50113 .49134 .4962 .48265 .48705 Mtetra
.657 .75 .919 r
.48265 .48705 .49134 .4962 .50692 .49121 .49829 .48207 Mtetra
.652 .75 .921 r
.49829 .48207 .50692 .49121 .52259 .48626 .51402 .47722 Mtetra
.651 .753 .924 r
.51402 .47722 .52259 .48626 .53836 .48133 .52984 .47236 Mtetra
.656 .757 .925 r
.52984 .47236 .53836 .48133 .55421 .47634 .54576 .46731 Mtetra
.66 .759 .923 r
.54576 .46731 .55421 .47634 .57015 .47128 .56176 .46208 Mtetra
.659 .756 .921 r
.56176 .46208 .57015 .47128 .58619 .46624 .57786 .45683 Mtetra
.655 .751 .92 r
.57786 .45683 .58619 .46624 .60232 .46124 .59405 .45172 Mtetra
.653 .749 .92 r
.59405 .45172 .60232 .46124 .61855 .45618 .61034 .44667 Mtetra
.661 .753 .918 r
.61034 .44667 .61855 .45618 .63486 .45068 .62672 .44128 Mtetra
.668 .759 .919 r
.62672 .44128 .63486 .45068 .65125 .44508 .64318 .43558 Mtetra
.665 .757 .919 r
.64318 .43558 .65125 .44508 .66775 .43955 .65974 .42993 Mtetra
.662 .755 .919 r
.65974 .42993 .66775 .43955 .68433 .43404 .6764 .42441 Mtetra
.685 .764 .911 r
.6764 .42441 .68433 .43404 .70095 .42725 .6931 .41787 Mtetra
.705 .777 .908 r
.6931 .41787 .70095 .42725 .71762 .41989 .70984 .41042 Mtetra
.684 .77 .917 r
.70984 .41042 .71762 .41989 .73446 .41405 .72672 .40389 Mtetra
.553 .701 .938 r
.72672 .40389 .73446 .41405 .75174 .41305 .74402 .40215 Mtetra
.437 .625 .932 r
.74402 .40215 .75174 .41305 .76942 .41526 .76172 .40404 Mtetra
.47 .637 .928 r
.76172 .40404 .76942 .41526 .78714 .41566 .77955 .40515 Mtetra
.627 .731 .922 r
.77955 .40515 .78714 .41566 .80455 .41057 .79711 .4008 Mtetra
.748 .793 .889 r
.79711 .4008 .80455 .41057 .8216 .40036 .81427 .39083 Mtetra
.754 .802 .892 r
.81427 .39083 .8216 .40036 .83874 .39045 .83147 .38059 Mtetra
.708 .782 .909 r
.83147 .38059 .83874 .39045 .85618 .38291 .84897 .37263 Mtetra
.656 .753 .921 r
.84897 .37263 .85618 .38291 .87393 .37737 .86679 .36698 Mtetra
.655 .751 .921 r
.23427 .55594 .24388 .56433 .25819 .5598 .24862 .5514 Mtetra
.575 .729 .947 r
.24862 .5514 .25819 .5598 .27241 .55748 .26286 .54921 Mtetra
.472 .694 .965 r
.26286 .54921 .27241 .55748 .28657 .55736 .27705 .54917 Mtetra
.501 .709 .964 r
.27705 .54917 .28657 .55736 .30086 .55701 .2914 .54853 Mtetra
.691 .763 .906 r
.2914 .54853 .30086 .55701 .3156 .55129 .30621 .54244 Mtetra
.779 .768 .844 r
.30621 .54244 .3156 .55129 .33071 .54031 .32141 .53105 Mtetra
.779 .762 .837 r
.32141 .53105 .33071 .54031 .3459 .52854 .33666 .51938 Mtetra
.726 .758 .878 r
.33666 .51938 .3459 .52854 .36093 .52025 .35173 .51144 Mtetra
.616 .738 .933 r
.35173 .51144 .36093 .52025 .37581 .51662 .36664 .508 Mtetra
.593 .736 .944 r
.36664 .508 .37581 .51662 .39074 .51388 .38162 .5052 Mtetra
.625 .747 .934 r
.38162 .5052 .39074 .51388 .4058 .51028 .39674 .5014 Mtetra
.65 .75 .923 r
.39674 .5014 .4058 .51028 .42099 .50568 .41199 .49676 Mtetra
.645 .749 .925 r
.41199 .49676 .42099 .50568 .43627 .50121 .42732 .49225 Mtetra
.642 .749 .926 r
.42732 .49225 .43627 .50121 .45163 .49681 .44273 .48781 Mtetra
.653 .752 .922 r
.44273 .48781 .45163 .49681 .46709 .49209 .45825 .48295 Mtetra
.659 .752 .919 r
.45825 .48295 .46709 .49209 .48265 .48705 .47386 .47785 Mtetra
.655 .751 .92 r
.47386 .47785 .48265 .48705 .49829 .48207 .48956 .47286 Mtetra
.649 .75 .923 r
.48956 .47286 .49829 .48207 .51402 .47722 .50535 .46809 Mtetra
.65 .753 .925 r
.50535 .46809 .51402 .47722 .52984 .47236 .52123 .46324 Mtetra
.656 .756 .924 r
.52123 .46324 .52984 .47236 .54576 .46731 .53721 .45814 Mtetra
.661 .758 .922 r
.53721 .45814 .54576 .46731 .56176 .46208 .55328 .45279 Mtetra
.663 .757 .92 r
.55328 .45279 .56176 .46208 .57786 .45683 .56944 .44736 Mtetra
.657 .752 .92 r
.56944 .44736 .57786 .45683 .59405 .45172 .58569 .44214 Mtetra
.653 .75 .921 r
.58569 .44214 .59405 .45172 .61034 .44667 .60205 .43704 Mtetra
.658 .752 .919 r
.60205 .43704 .61034 .44667 .62672 .44128 .61849 .43169 Mtetra
.668 .757 .917 r
.61849 .43169 .62672 .44128 .64318 .43558 .63502 .42591 Mtetra
.666 .756 .918 r
.63502 .42591 .64318 .43558 .65974 .42993 .65164 .42019 Mtetra
.662 .754 .919 r
.65164 .42019 .65974 .42993 .6764 .42441 .66837 .41461 Mtetra
.681 .761 .912 r
.66837 .41461 .6764 .42441 .6931 .41787 .68515 .40816 Mtetra
.704 .772 .905 r
.68515 .40816 .6931 .41787 .70984 .41042 .70197 .40067 Mtetra
.689 .768 .912 r
.70197 .40067 .70984 .41042 .72672 .40389 .71891 .39383 Mtetra
.565 .711 .94 r
.71891 .39383 .72672 .40389 .74402 .40215 .73624 .39162 Mtetra
.434 .635 .94 r
.73624 .39162 .74402 .40215 .76172 .40404 .75399 .39329 Mtetra
.447 .638 .938 r
.75399 .39329 .76172 .40404 .77955 .40515 .77191 .39472 Mtetra
.618 .731 .927 r
.77191 .39472 .77955 .40515 .79711 .4008 .78955 .39064 Mtetra
.742 .786 .888 r
.78955 .39064 .79711 .4008 .81427 .39083 .80683 .38086 Mtetra
.754 .795 .886 r
.80683 .38086 .81427 .39083 .83147 .38059 .82411 .37043 Mtetra
.712 .778 .904 r
.82411 .37043 .83147 .38059 .84897 .37263 .84166 .36222 Mtetra
.657 .753 .921 r
.84166 .36222 .84897 .37263 .86679 .36698 .85956 .35647 Mtetra
.655 .751 .921 r
.22456 .54747 .23427 .55594 .24862 .5514 .23895 .54288 Mtetra
.575 .728 .946 r
.23895 .54288 .24862 .5514 .26286 .54921 .25324 .54065 Mtetra
.477 .69 .961 r
.25324 .54065 .26286 .54921 .27705 .54917 .26746 .54057 Mtetra
.507 .703 .958 r
.26746 .54057 .27705 .54917 .2914 .54853 .28184 .5399 Mtetra
.691 .761 .905 r
.28184 .5399 .2914 .54853 .30621 .54244 .29671 .53376 Mtetra
.78 .773 .847 r
.29671 .53376 .30621 .54244 .32141 .53105 .31198 .5223 Mtetra
.783 .773 .844 r
.31198 .5223 .32141 .53105 .33666 .51938 .3273 .51056 Mtetra
.728 .767 .884 r
.3273 .51056 .33666 .51938 .35173 .51144 .34243 .50257 Mtetra
.616 .739 .933 r
.34243 .50257 .35173 .51144 .36664 .508 .35739 .49907 Mtetra
.594 .731 .94 r
.35739 .49907 .36664 .508 .38162 .5052 .37242 .49623 Mtetra
.626 .742 .93 r
.37242 .49623 .38162 .5052 .39674 .5014 .38759 .49238 Mtetra
.65 .749 .922 r
.38759 .49238 .39674 .5014 .41199 .49676 .40289 .48769 Mtetra
.645 .748 .924 r
.40289 .48769 .41199 .49676 .42732 .49225 .41827 .48313 Mtetra
.643 .747 .925 r
.41827 .48313 .42732 .49225 .44273 .48781 .43374 .47864 Mtetra
.653 .75 .921 r
.43374 .47864 .44273 .48781 .45825 .48295 .44932 .47372 Mtetra
.659 .752 .919 r
.44932 .47372 .45825 .48295 .47386 .47785 .46499 .46857 Mtetra
.655 .751 .92 r
.46499 .46857 .47386 .47785 .48956 .47286 .48074 .46353 Mtetra
.649 .749 .923 r
.48074 .46353 .48956 .47286 .50535 .46809 .49659 .4587 Mtetra
.65 .749 .922 r
.49659 .4587 .50535 .46809 .52123 .46324 .51253 .4538 Mtetra
.656 .751 .92 r
.51253 .4538 .52123 .46324 .53721 .45814 .52857 .44865 Mtetra
.662 .753 .918 r
.52857 .44865 .53721 .45814 .55328 .45279 .5447 .44324 Mtetra
.663 .754 .918 r
.5447 .44324 .55328 .45279 .56944 .44736 .56092 .43775 Mtetra
.657 .751 .92 r
.56092 .43775 .56944 .44736 .58569 .44214 .57724 .43248 Mtetra
.653 .75 .921 r
.57724 .43248 .58569 .44214 .60205 .43704 .59366 .42732 Mtetra
.658 .752 .919 r
.59366 .42732 .60205 .43704 .61849 .43169 .61017 .42191 Mtetra
.668 .756 .916 r
.61017 .42191 .61849 .43169 .63502 .42591 .62676 .41607 Mtetra
.666 .755 .917 r
.62676 .41607 .63502 .42591 .65164 .42019 .64346 .4103 Mtetra
.662 .753 .918 r
.64346 .4103 .65164 .42019 .66837 .41461 .66025 .40465 Mtetra
.681 .76 .911 r
.66025 .40465 .66837 .41461 .68515 .40816 .67711 .39814 Mtetra
.703 .768 .902 r
.67711 .39814 .68515 .40816 .70197 .40067 .694 .39058 Mtetra
.689 .763 .908 r
.694 .39058 .70197 .40067 .71891 .39383 .71101 .38368 Mtetra
.565 .712 .94 r
.71101 .38368 .71891 .39383 .73624 .39162 .72841 .38142 Mtetra
.425 .641 .947 r
.72841 .38142 .73624 .39162 .75399 .39329 .74621 .38305 Mtetra
.436 .647 .947 r
.74621 .38305 .75399 .39329 .77191 .39472 .76419 .38443 Mtetra
.617 .737 .932 r
.76419 .38443 .77191 .39472 .78955 .39064 .78191 .38029 Mtetra
.742 .784 .887 r
.78191 .38029 .78955 .39064 .80683 .38086 .79927 .37043 Mtetra
.752 .787 .881 r
.79927 .37043 .80683 .38086 .82411 .37043 .81664 .35993 Mtetra
.711 .773 .901 r
.81664 .35993 .82411 .37043 .84166 .36222 .83428 .35165 Mtetra
.657 .752 .92 r
.83428 .35165 .84166 .36222 .85956 .35647 .85225 .34583 Mtetra
.656 .751 .92 r
.21475 .5389 .22456 .54747 .23895 .54288 .22919 .53424 Mtetra
.582 .729 .944 r
.22919 .53424 .23895 .54288 .25324 .54065 .24353 .53179 Mtetra
.486 .689 .957 r
.24353 .53179 .25324 .54065 .26746 .54057 .25779 .53156 Mtetra
.5 .692 .954 r
.25779 .53156 .26746 .54057 .28184 .5399 .27219 .5311 Mtetra
.683 .758 .908 r
.27219 .5311 .28184 .5399 .29671 .53376 .28709 .52523 Mtetra
.778 .778 .853 r
.28709 .52523 .29671 .53376 .31198 .5223 .30242 .51405 Mtetra
.79 .785 .849 r
.30242 .51405 .31198 .5223 .3273 .51056 .31782 .50208 Mtetra
.737 .778 .886 r
.31782 .50208 .3273 .51056 .34243 .50257 .33304 .49362 Mtetra
.624 .742 .931 r
.33304 .49362 .34243 .50257 .35739 .49907 .34806 .48984 Mtetra
.595 .726 .936 r
.34806 .48984 .35739 .49907 .37242 .49623 .36313 .48697 Mtetra
.622 .736 .928 r
.36313 .48697 .37242 .49623 .38759 .49238 .37834 .48322 Mtetra
.65 .748 .922 r
.37834 .48322 .38759 .49238 .40289 .48769 .3937 .47847 Mtetra
.646 .747 .923 r
.3937 .47847 .40289 .48769 .41827 .48313 .40913 .47385 Mtetra
.643 .746 .924 r
.40913 .47385 .41827 .48313 .43374 .47864 .42466 .46929 Mtetra
.651 .748 .921 r
.42466 .46929 .43374 .47864 .44932 .47372 .44029 .46442 Mtetra
.659 .753 .919 r
.44029 .46442 .44932 .47372 .46499 .46857 .45602 .45922 Mtetra
.657 .752 .92 r
.45602 .45922 .46499 .46857 .48074 .46353 .47183 .45407 Mtetra
.652 .749 .921 r
.47183 .45407 .48074 .46353 .49659 .4587 .48774 .44906 Mtetra
.652 .746 .919 r
.48774 .44906 .49659 .4587 .51253 .4538 .50374 .44404 Mtetra
.656 .746 .916 r
.50374 .44404 .51253 .4538 .52857 .44865 .51984 .43883 Mtetra
.66 .748 .915 r
.51984 .43883 .52857 .44865 .5447 .44324 .53603 .43342 Mtetra
.66 .749 .916 r
.53603 .43342 .5447 .44324 .56092 .43775 .55231 .42801 Mtetra
.655 .75 .92 r
.55231 .42801 .56092 .43775 .57724 .43248 .5687 .42273 Mtetra
.653 .751 .921 r
.5687 .42273 .57724 .43248 .59366 .42732 .58518 .41751 Mtetra
.661 .753 .919 r
.58518 .41751 .59366 .42732 .61017 .42191 .60175 .41195 Mtetra
.668 .754 .915 r
.60175 .41195 .61017 .42191 .62676 .41607 .61842 .40606 Mtetra
.665 .753 .916 r
.61842 .40606 .62676 .41607 .64346 .4103 .63518 .40024 Mtetra
.662 .752 .917 r
.63518 .40024 .64346 .4103 .66025 .40465 .65204 .39454 Mtetra
.685 .76 .909 r
.65204 .39454 .66025 .40465 .67711 .39814 .66896 .38781 Mtetra
.703 .763 .899 r
.66896 .38781 .67711 .39814 .694 .39058 .68593 .38017 Mtetra
.683 .756 .907 r
.68593 .38017 .694 .39058 .71101 .38368 .70302 .37344 Mtetra
.551 .706 .943 r
.70302 .37344 .71101 .38368 .72841 .38142 .72051 .37155 Mtetra
.408 .643 .953 r
.72051 .37155 .72841 .38142 .74621 .38305 .73839 .3733 Mtetra
.437 .663 .957 r
.73839 .3733 .74621 .38305 .76419 .38443 .75641 .37428 Mtetra
.625 .746 .934 r
.75641 .37428 .76419 .38443 .78191 .38029 .77418 .36974 Mtetra
.746 .784 .884 r
.77418 .36974 .78191 .38029 .79927 .37043 .7916 .35955 Mtetra
.749 .779 .878 r
.7916 .35955 .79927 .37043 .81664 .35993 .80906 .34909 Mtetra
.707 .767 .899 r
.80906 .34909 .81664 .35993 .83428 .35165 .8268 .34092 Mtetra
.656 .751 .92 r
.8268 .34092 .83428 .35165 .85225 .34583 .84486 .33507 Mtetra
.657 .752 .92 r
.20484 .53025 .21475 .5389 .22919 .53424 .21933 .52548 Mtetra
.595 .733 .94 r
.21933 .52548 .22919 .53424 .24353 .53179 .23374 .52265 Mtetra
.502 .691 .953 r
.23374 .52265 .24353 .53179 .25779 .53156 .24806 .52214 Mtetra
.49 .679 .95 r
.24806 .52214 .25779 .53156 .27219 .5311 .26246 .52195 Mtetra
.664 .747 .912 r
.26246 .52195 .27219 .5311 .28709 .52523 .27736 .51679 Mtetra
.769 .781 .863 r
.27736 .51679 .28709 .52523 .30242 .51405 .2927 .50628 Mtetra
.797 .797 .852 r
.2927 .50628 .30242 .51405 .31782 .50208 .3082 .49398 Mtetra
.751 .79 .884 r
.3082 .49398 .31782 .50208 .33304 .49362 .32353 .48478 Mtetra
.642 .752 .929 r
.32353 .48478 .33304 .49362 .34806 .48984 .33864 .48034 Mtetra
.597 .723 .933 r
.33864 .48034 .34806 .48984 .36313 .48697 .35375 .47739 Mtetra
.614 .728 .927 r
.35375 .47739 .36313 .48697 .37834 .48322 .369 .4739 Mtetra
.649 .746 .921 r
.369 .4739 .37834 .48322 .3937 .47847 .38441 .46914 Mtetra
.647 .747 .922 r
.38441 .46914 .3937 .47847 .40913 .47385 .3999 .46441 Mtetra
.644 .745 .922 r
.3999 .46441 .40913 .47385 .42466 .46929 .41548 .45976 Mtetra
.646 .745 .921 r
.41548 .45976 .42466 .46929 .44029 .46442 .43116 .455 Mtetra
.657 .752 .92 r
.43116 .455 .44029 .46442 .45602 .45922 .44695 .4498 Mtetra
.658 .753 .92 r
.44695 .4498 .45602 .45922 .47183 .45407 .46282 .44454 Mtetra
.656 .751 .92 r
.46282 .44454 .47183 .45407 .48774 .44906 .47879 .43933 Mtetra
.655 .748 .918 r
.47879 .43933 .48774 .44906 .50374 .44404 .49485 .43412 Mtetra
.656 .745 .916 r
.49485 .43412 .50374 .44404 .51984 .43883 .51101 .42886 Mtetra
.657 .746 .915 r
.51101 .42886 .51984 .43883 .53603 .43342 .52726 .42352 Mtetra
.656 .748 .918 r
.52726 .42352 .53603 .43342 .55231 .42801 .54361 .4182 Mtetra
.654 .751 .921 r
.54361 .4182 .55231 .42801 .5687 .42273 .56006 .41292 Mtetra
.655 .752 .922 r
.56006 .41292 .5687 .42273 .58518 .41751 .57661 .40758 Mtetra
.665 .754 .917 r
.57661 .40758 .58518 .41751 .60175 .41195 .59324 .40178 Mtetra
.667 .751 .914 r
.59324 .40178 .60175 .41195 .61842 .40606 .60998 .39589 Mtetra
.664 .751 .915 r
.60998 .39589 .61842 .40606 .63518 .40024 .62681 .39005 Mtetra
.663 .752 .917 r
.62681 .39005 .63518 .40024 .65204 .39454 .64374 .38425 Mtetra
.691 .761 .905 r
.64374 .38425 .65204 .39454 .66896 .38781 .66072 .37714 Mtetra
.702 .758 .896 r
.66072 .37714 .66896 .38781 .68593 .38017 .67776 .36945 Mtetra
.669 .747 .909 r
.67776 .36945 .68593 .38017 .70302 .37344 .69496 .3633 Mtetra
.525 .699 .949 r
.69496 .3633 .70302 .37344 .72051 .37155 .71255 .36205 Mtetra
.384 .642 .958 r
.71255 .36205 .72051 .37155 .73839 .3733 .73052 .36404 Mtetra
.456 .689 .966 r
.73052 .36404 .73839 .3733 .75641 .37428 .74855 .3642 Mtetra
.645 .759 .931 r
.74855 .3642 .75641 .37428 .77418 .36974 .76633 .3588 Mtetra
.75 .779 .877 r
.76633 .3588 .77418 .36974 .7916 .35955 .78381 .34821 Mtetra
.743 .77 .876 r
.78381 .34821 .7916 .35955 .80906 .34909 .80138 .33793 Mtetra
.699 .76 .899 r
.80138 .33793 .80906 .34909 .8268 .34092 .81923 .33004 Mtetra
.655 .75 .92 r
.81923 .33004 .8268 .34092 .84486 .33507 .83738 .32418 Mtetra
.658 .752 .919 r
.19482 .52151 .20484 .53025 .21933 .52548 .20937 .51665 Mtetra
.612 .739 .935 r
.20937 .51665 .21933 .52548 .23374 .52265 .22387 .51327 Mtetra
.523 .695 .947 r
.22387 .51327 .23374 .52265 .24806 .52214 .23825 .5123 Mtetra
.481 .668 .945 r
.23825 .5123 .24806 .52214 .26246 .52195 .25266 .51236 Mtetra
.633 .731 .919 r
.25266 .51236 .26246 .52195 .27736 .51679 .26751 .50831 Mtetra
.751 .781 .877 r
.26751 .50831 .27736 .51679 .2927 .50628 .28285 .49893 Mtetra
.802 .807 .855 r
.28285 .49893 .2927 .50628 .3082 .49398 .29844 .48635 Mtetra
.765 .803 .883 r
.29844 .48635 .3082 .49398 .32353 .48478 .31389 .47639 Mtetra
.675 .773 .924 r
.31389 .47639 .32353 .48478 .33864 .48034 .32912 .47067 Mtetra
.602 .723 .93 r
.32912 .47067 .33864 .48034 .35375 .47739 .34429 .46752 Mtetra
.605 .721 .926 r
.34429 .46752 .35375 .47739 .369 .4739 .35957 .46427 Mtetra
.642 .74 .92 r
.35957 .46427 .369 .4739 .38441 .46914 .37502 .45973 Mtetra
.65 .748 .921 r
.37502 .45973 .38441 .46914 .3999 .46441 .39057 .45483 Mtetra
.647 .745 .921 r
.39057 .45483 .3999 .46441 .41548 .45976 .40621 .45004 Mtetra
.645 .742 .92 r
.40621 .45004 .41548 .45976 .43116 .455 .42194 .44528 Mtetra
.651 .745 .919 r
.42194 .44528 .43116 .455 .44695 .4498 .43778 .44028 Mtetra
.657 .753 .92 r
.43778 .44028 .44695 .4498 .46282 .44454 .45371 .43499 Mtetra
.658 .754 .921 r
.45371 .43499 .46282 .44454 .47879 .43933 .46974 .42966 Mtetra
.656 .752 .92 r
.46974 .42966 .47879 .43933 .49485 .43412 .48587 .42435 Mtetra
.656 .751 .92 r
.48587 .42435 .49485 .43412 .51101 .42886 .50209 .41902 Mtetra
.655 .751 .92 r
.50209 .41902 .51101 .42886 .52726 .42352 .5184 .41368 Mtetra
.654 .751 .921 r
.5184 .41368 .52726 .42352 .54361 .4182 .53482 .40836 Mtetra
.654 .753 .922 r
.53482 .40836 .54361 .4182 .56006 .41292 .55133 .40299 Mtetra
.661 .754 .919 r
.55133 .40299 .56006 .41292 .57661 .40758 .56794 .39733 Mtetra
.666 .751 .913 r
.56794 .39733 .57661 .40758 .59324 .40178 .58464 .39142 Mtetra
.665 .749 .913 r
.58464 .39142 .59324 .40178 .60998 .39589 .60144 .38555 Mtetra
.662 .75 .915 r
.60144 .38555 .60998 .39589 .62681 .39005 .61834 .37977 Mtetra
.669 .755 .914 r
.61834 .37977 .62681 .39005 .64374 .38425 .63534 .37362 Mtetra
.697 .759 .899 r
.63534 .37362 .64374 .38425 .66072 .37714 .65237 .36615 Mtetra
.698 .753 .894 r
.65237 .36615 .66072 .37714 .67776 .36945 .66949 .35856 Mtetra
.638 .734 .917 r
.66949 .35856 .67776 .36945 .69496 .3633 .68683 .3536 Mtetra
.491 .696 .959 r
.68683 .3536 .69496 .3633 .71255 .36205 .70453 .35302 Mtetra
.359 .643 .963 r
.70453 .35302 .71255 .36205 .73052 .36404 .72258 .35518 Mtetra
.496 .723 .973 r
.72258 .35518 .73052 .36404 .74855 .3642 .74059 .35405 Mtetra
.675 .771 .923 r
.74059 .35405 .74855 .3642 .76633 .3588 .75837 .34738 Mtetra
.753 .773 .87 r
.75837 .34738 .76633 .3588 .78381 .34821 .77591 .33641 Mtetra
.734 .761 .875 r
.77591 .33641 .78381 .34821 .80138 .33793 .7936 .32648 Mtetra
.688 .752 .901 r
.7936 .32648 .80138 .33793 .81923 .33004 .81158 .31905 Mtetra
.654 .749 .92 r
.81158 .31905 .81923 .33004 .83738 .32418 .82982 .31317 Mtetra
.658 .752 .919 r
.18471 .51268 .19482 .52151 .20937 .51665 .1993 .50776 Mtetra
.632 .745 .929 r
.1993 .50776 .20937 .51665 .22387 .51327 .2139 .50371 Mtetra
.542 .701 .943 r
.2139 .50371 .22387 .51327 .23825 .5123 .22835 .50227 Mtetra
.484 .667 .944 r
.22835 .50227 .23825 .5123 .25266 .51236 .24279 .50226 Mtetra
.59 .708 .925 r
.24279 .50226 .25266 .51236 .26751 .50831 .25758 .49958 Mtetra
.721 .774 .894 r
.25758 .49958 .26751 .50831 .28285 .49893 .27285 .4918 Mtetra
.8 .814 .863 r
.27285 .4918 .28285 .49893 .29844 .48635 .2885 .47955 Mtetra
.786 .823 .882 r
.2885 .47955 .29844 .48635 .31389 .47639 .3041 .46851 Mtetra
.716 .795 .914 r
.3041 .46851 .31389 .47639 .32912 .47067 .3195 .46106 Mtetra
.618 .732 .928 r
.3195 .46106 .32912 .47067 .34429 .46752 .33474 .45734 Mtetra
.605 .716 .923 r
.33474 .45734 .34429 .46752 .35957 .46427 .35007 .45408 Mtetra
.625 .724 .918 r
.35007 .45408 .35957 .46427 .37502 .45973 .36553 .4501 Mtetra
.65 .746 .919 r
.36553 .4501 .37502 .45973 .39057 .45483 .38114 .44515 Mtetra
.649 .745 .92 r
.38114 .44515 .39057 .45483 .40621 .45004 .39684 .44022 Mtetra
.648 .743 .919 r
.39684 .44022 .40621 .45004 .42194 .44528 .41263 .43532 Mtetra
.647 .741 .918 r
.41263 .43532 .42194 .44528 .43778 .44028 .42852 .43039 Mtetra
.651 .745 .919 r
.42852 .43039 .43778 .44028 .45371 .43499 .44451 .4253 Mtetra
.656 .752 .921 r
.44451 .4253 .45371 .43499 .46974 .42966 .46059 .41998 Mtetra
.656 .754 .922 r
.46059 .41998 .46974 .42966 .48587 .42435 .47678 .4146 Mtetra
.47678 .4146 .48587 .42435 .50209 .41902 .49306 .40922 Mtetra
.655 .754 .922 r
.49306 .40922 .50209 .41902 .5184 .41368 .50944 .40382 Mtetra
.656 .754 .922 r
.50944 .40382 .5184 .41368 .53482 .40836 .52592 .39837 Mtetra
.661 .754 .919 r
.52592 .39837 .53482 .40836 .55133 .40299 .5425 .39269 Mtetra
.664 .75 .914 r
.5425 .39269 .55133 .40299 .56794 .39733 .55917 .38684 Mtetra
.664 .747 .912 r
.55917 .38684 .56794 .39733 .58464 .39142 .57594 .38096 Mtetra
.663 .748 .914 r
.57594 .38096 .58464 .39142 .60144 .38555 .59281 .3751 Mtetra
.661 .749 .915 r
.59281 .3751 .60144 .38555 .61834 .37977 .60978 .36926 Mtetra
.684 .757 .907 r
.60978 .36926 .61834 .37977 .63534 .37362 .62682 .36242 Mtetra
.697 .749 .892 r
.62682 .36242 .63534 .37362 .65237 .36615 .64393 .35483 Mtetra
.687 .745 .895 r
.64393 .35483 .65237 .36615 .66949 .35856 .66114 .3477 Mtetra
.592 .717 .931 r
.66114 .3477 .66949 .35856 .68683 .3536 .67864 .34441 Mtetra
.437 .684 .968 r
.67864 .34441 .68683 .3536 .70453 .35302 .69647 .34482 Mtetra
.349 .663 .973 r
.69647 .34482 .70453 .35302 .72258 .35518 .71456 .34653 Mtetra
.556 .76 .973 r
.71456 .34653 .72258 .35518 .74059 .35405 .73254 .34363 Mtetra
.707 .779 .908 r
.73254 .34363 .74059 .35405 .75837 .34738 .75029 .3354 Mtetra
.75 .764 .864 r
.75029 .3354 .75837 .34738 .77591 .33641 .76792 .32438 Mtetra
.726 .756 .877 r
.76792 .32438 .77591 .33641 .7936 .32648 .78572 .31482 Mtetra
.674 .745 .904 r
.78572 .31482 .7936 .32648 .81158 .31905 .80385 .30797 Mtetra
.653 .75 .921 r
.80385 .30797 .81158 .31905 .82982 .31317 .82216 .30202 Mtetra
.657 .752 .92 r
.17448 .50375 .18471 .51268 .1993 .50776 .18912 .49883 Mtetra
.649 .751 .924 r
.18912 .49883 .1993 .50776 .2139 .50371 .20382 .49418 Mtetra
.568 .713 .94 r
.20382 .49418 .2139 .50371 .22835 .50227 .21837 .49201 Mtetra
.502 .671 .94 r
.21837 .49201 .22835 .50227 .24279 .50226 .23287 .4916 Mtetra
.539 .679 .929 r
.23287 .4916 .24279 .50226 .25758 .49958 .24756 .49038 Mtetra
.685 .759 .907 r
.24756 .49038 .25758 .49958 .27285 .4918 .26277 .48419 Mtetra
.778 .806 .875 r
.26277 .48419 .27285 .4918 .2885 .47955 .2784 .47329 Mtetra
.801 .837 .878 r
.2784 .47329 .2885 .47955 .3041 .46851 .29414 .46132 Mtetra
.752 .818 .904 r
.29414 .46132 .3041 .46851 .3195 .46106 .30972 .45213 Mtetra
.657 .762 .927 r
.30972 .45213 .3195 .46106 .33474 .45734 .3251 .44694 Mtetra
.608 .715 .92 r
.3251 .44694 .33474 .45734 .35007 .45408 .34048 .44353 Mtetra
.612 .714 .918 r
.34048 .44353 .35007 .45408 .36553 .4501 .35596 .43997 Mtetra
.639 .733 .917 r
.35596 .43997 .36553 .4501 .38114 .44515 .3716 .43541 Mtetra
.652 .748 .919 r
.3716 .43541 .38114 .44515 .39684 .44022 .38736 .43029 Mtetra
.649 .743 .918 r
.38736 .43029 .39684 .44022 .41263 .43532 .40321 .42526 Mtetra
.65 .742 .917 r
.40321 .42526 .41263 .43532 .42852 .43039 .41916 .42018 Mtetra
.65 .74 .916 r
.41916 .42018 .42852 .43039 .44451 .4253 .43521 .41509 Mtetra
.652 .742 .916 r
.43521 .41509 .44451 .4253 .46059 .41998 .45135 .40987 Mtetra
.654 .746 .918 r
.45135 .40987 .46059 .41998 .47678 .4146 .4676 .40454 Mtetra
.656 .749 .919 r
.4676 .40454 .47678 .4146 .49306 .40922 .48394 .39909 Mtetra
.658 .75 .918 r
.48394 .39909 .49306 .40922 .50944 .40382 .50038 .39354 Mtetra
.66 .748 .915 r
.50038 .39354 .50944 .40382 .52592 .39837 .51693 .38786 Mtetra
.662 .745 .912 r
.51693 .38786 .52592 .39837 .5425 .39269 .53357 .38206 Mtetra
.662 .744 .911 r
.53357 .38206 .5425 .39269 .55917 .38684 .5503 .37624 Mtetra
.662 .746 .913 r
.5503 .37624 .55917 .38684 .57594 .38096 .56714 .37036 Mtetra
.659 .747 .915 r
.56714 .37036 .57594 .38096 .59281 .3751 .58408 .36458 Mtetra
.672 .754 .912 r
.58408 .36458 .59281 .3751 .60978 .36926 .60111 .35821 Mtetra
.693 .752 .897 r
.60111 .35821 .60978 .36926 .62682 .36242 .61821 .35083 Mtetra
.694 .743 .889 r
.61821 .35083 .62682 .36242 .64393 .35483 .63539 .34327 Mtetra
.655 .73 .905 r
.63539 .34327 .64393 .35483 .66114 .3477 .65273 .33752 Mtetra
.53 .708 .953 r
.65273 .33752 .66114 .3477 .67864 .34441 .67038 .33591 Mtetra
.376 .672 .974 r
.67038 .33591 .67864 .34441 .69647 .34482 .68833 .33717 Mtetra
.402 .711 .985 r
.68833 .33717 .69647 .34482 .71456 .34653 .70641 .33735 Mtetra
.616 .775 .957 r
.70641 .33735 .71456 .34653 .73254 .34363 .72436 .33267 Mtetra
.736 .78 .889 r
.72436 .33267 .73254 .34363 .75029 .3354 .74209 .32282 Mtetra
.742 .753 .861 r
.74209 .32282 .75029 .3354 .76792 .32438 .75983 .31208 Mtetra
.712 .749 .881 r
.75983 .31208 .76792 .32438 .78572 .31482 .77777 .30317 Mtetra
.662 .743 .91 r
.77777 .30317 .78572 .31482 .80385 .30797 .79602 .29682 Mtetra
.655 .752 .921 r
.79602 .29682 .80385 .30797 .82216 .30202 .81442 .29075 Mtetra
.655 .751 .92 r
.16415 .49473 .17448 .50375 .18912 .49883 .17883 .48982 Mtetra
.657 .753 .921 r
.17883 .48982 .18912 .49883 .20382 .49418 .19361 .48483 Mtetra
.603 .731 .935 r
.19361 .48483 .20382 .49418 .21837 .49201 .20829 .48159 Mtetra
.532 .683 .935 r
.20829 .48159 .21837 .49201 .23287 .4916 .22289 .48043 Mtetra
.508 .657 .927 r
.22289 .48043 .23287 .4916 .24756 .49038 .23753 .48003 Mtetra
.63 .721 .913 r
.23753 .48003 .24756 .49038 .26277 .48419 .25261 .47591 Mtetra
.738 .791 .895 r
.25261 .47591 .26277 .48419 .2784 .47329 .26814 .46724 Mtetra
.803 .843 .881 r
.26814 .46724 .2784 .47329 .29414 .46132 .28398 .45515 Mtetra
.78 .843 .9 r
.28398 .45515 .29414 .46132 .30972 .45213 .29973 .44454 Mtetra
.717 .808 .921 r
.29973 .44454 .30972 .45213 .3251 .44694 .31533 .43693 Mtetra
.63 .733 .922 r
.31533 .43693 .3251 .44694 .34048 .44353 .3308 .43266 Mtetra
.612 .71 .914 r
.3308 .43266 .34048 .44353 .35596 .43997 .34633 .42907 Mtetra
.619 .713 .913 r
.34633 .42907 .35596 .43997 .3716 .43541 .36198 .42519 Mtetra
.643 .737 .917 r
.36198 .42519 .3716 .43541 .38736 .43029 .37778 .42037 Mtetra
.653 .747 .919 r
.37778 .42037 .38736 .43029 .40321 .42526 .3937 .41514 Mtetra
.652 .744 .917 r
.3937 .41514 .40321 .42526 .41916 .42018 .40971 .40993 Mtetra
.652 .742 .916 r
.40971 .40993 .41916 .42018 .43521 .41509 .42581 .40469 Mtetra
.653 .741 .914 r
.42581 .40469 .43521 .41509 .45135 .40987 .44201 .39937 Mtetra
.654 .74 .913 r
.44201 .39937 .45135 .40987 .4676 .40454 .45832 .39396 Mtetra
.656 .741 .912 r
.45832 .39396 .4676 .40454 .48394 .39909 .47472 .38845 Mtetra
.658 .741 .911 r
.47472 .38845 .48394 .39909 .50038 .39354 .49123 .38285 Mtetra
.659 .742 .911 r
.49123 .38285 .50038 .39354 .51693 .38786 .50783 .37716 Mtetra
.66 .743 .912 r
.50783 .37716 .51693 .38786 .53357 .38206 .52454 .37138 Mtetra
.66 .745 .913 r
.52454 .37138 .53357 .38206 .5503 .37624 .54134 .36557 Mtetra
.659 .746 .915 r
.54134 .36557 .5503 .37624 .56714 .37036 .55825 .35977 Mtetra
.668 .752 .914 r
.55825 .35977 .56714 .37036 .58408 .36458 .57525 .35356 Mtetra
.688 .752 .9 r
.57525 .35356 .58408 .36458 .60111 .35821 .59234 .34638 Mtetra
.691 .738 .887 r
.59234 .34638 .60111 .35821 .61821 .35083 .6095 .3389 Mtetra
.677 .733 .892 r
.6095 .3389 .61821 .35083 .63539 .34327 .62678 .3321 Mtetra
.592 .715 .929 r
.62678 .3321 .63539 .34327 .65273 .33752 .64428 .32872 Mtetra
.452 .706 .976 r
.64428 .32872 .65273 .33752 .67038 .33591 .66206 .32843 Mtetra
.336 .68 .978 r
.66206 .32843 .67038 .33591 .68833 .33717 .68009 .3297 Mtetra
.504 .771 .991 r
.68009 .3297 .68833 .33717 .70641 .33735 .69812 .32747 Mtetra
.678 .785 .93 r
.69812 .32747 .70641 .33735 .72436 .33267 .71603 .32051 Mtetra
.745 .763 .867 r
.71603 .32051 .72436 .33267 .74209 .32282 .73378 .30968 Mtetra
.728 .741 .862 r
.73378 .30968 .74209 .32282 .75983 .31208 .75165 .2996 Mtetra
.693 .74 .888 r
.75165 .2996 .75983 .31208 .77777 .30317 .76975 .29166 Mtetra
.655 .746 .917 r
.76975 .29166 .77777 .30317 .79602 .29682 .78811 .28555 Mtetra
.656 .753 .921 r
.78811 .28555 .79602 .29682 .81442 .29075 .80658 .27934 Mtetra
.654 .75 .92 r
.15372 .48558 .16415 .49473 .17883 .48982 .16844 .48065 Mtetra
.658 .752 .919 r
.16844 .48065 .17883 .48982 .19361 .48483 .18327 .47555 Mtetra
.637 .745 .927 r
.18327 .47555 .19361 .48483 .20829 .48159 .19811 .47118 Mtetra
.56 .696 .931 r
.19811 .47118 .20829 .48159 .22289 .48043 .2128 .46923 Mtetra
.512 .66 .927 r
.2128 .46923 .22289 .48043 .23753 .48003 .22749 .46865 Mtetra
.563 .678 .917 r
.22749 .46865 .23753 .48003 .25261 .47591 .24241 .46673 Mtetra
.687 .765 .911 r
.24241 .46673 .25261 .47591 .26814 .46724 .25782 .46034 Mtetra
.774 .827 .894 r
.25782 .46034 .26814 .46724 .28398 .45515 .27361 .44986 Mtetra
.801 .864 .895 r
.27361 .44986 .28398 .45515 .29973 .44454 .28954 .43809 Mtetra
.758 .84 .914 r
.28954 .43809 .29973 .44454 .31533 .43693 .30534 .42861 Mtetra
.69 .789 .926 r
.30534 .42861 .31533 .43693 .3308 .43266 .32101 .42202 Mtetra
.627 .722 .915 r
.32101 .42202 .3308 .43266 .34633 .42907 .33662 .41783 Mtetra
.618 .708 .909 r
.33662 .41783 .34633 .42907 .36198 .42519 .35231 .41395 Mtetra
.624 .711 .908 r
.35231 .41395 .36198 .42519 .37778 .42037 .36813 .4098 Mtetra
.641 .732 .914 r
.36813 .4098 .37778 .42037 .3937 .41514 .38407 .40497 Mtetra
.652 .745 .918 r
.38407 .40497 .3937 .41514 .40971 .40993 .40014 .3997 Mtetra
.655 .746 .917 r
.40014 .3997 .40971 .40993 .42581 .40469 .41631 .39428 Mtetra
.654 .743 .915 r
.41631 .39428 .42581 .40469 .44201 .39937 .43257 .38885 Mtetra
.655 .742 .914 r
.43257 .38885 .44201 .39937 .45832 .39396 .44894 .38337 Mtetra
.656 .743 .914 r
.44894 .38337 .45832 .39396 .47472 .38845 .46541 .3778 Mtetra
.657 .743 .913 r
.46541 .3778 .47472 .38845 .49123 .38285 .48197 .37214 Mtetra
.658 .743 .913 r
.48197 .37214 .49123 .38285 .50783 .37716 .49864 .36644 Mtetra
.657 .744 .914 r
.49864 .36644 .50783 .37716 .52454 .37138 .51541 .36071 Mtetra
.66 .748 .915 r
.51541 .36071 .52454 .37138 .54134 .36557 .53228 .35484 Mtetra
.67 .751 .912 r
.53228 .35484 .54134 .36557 .55825 .35977 .54925 .34852 Mtetra
.684 .747 .899 r
.54925 .34852 .55825 .35977 .57525 .35356 .56631 .34149 Mtetra
.687 .733 .886 r
.56631 .34149 .57525 .35356 .59234 .34638 .58346 .33418 Mtetra
.68 .73 .888 r
.58346 .33418 .59234 .34638 .6095 .3389 .60071 .32718 Mtetra
.624 .718 .914 r
.60071 .32718 .6095 .3389 .62678 .3321 .61812 .32263 Mtetra
.513 .722 .967 r
.61812 .32263 .62678 .3321 .64428 .32872 .63577 .32105 Mtetra
.364 .692 .982 r
.63577 .32105 .64428 .32872 .66206 .32843 .65367 .32184 Mtetra
.395 .74 .992 r
.65367 .32184 .66206 .32843 .68009 .3297 .6717 .32134 Mtetra
.608 .796 .971 r
.6717 .32134 .68009 .3297 .69812 .32747 .68969 .31661 Mtetra
.726 .782 .898 r
.68969 .31661 .69812 .32747 .71603 .32051 .70754 .30726 Mtetra
.738 .743 .856 r
.70754 .30726 .71603 .32051 .73378 .30968 .72538 .29647 Mtetra
.715 .737 .868 r
.72538 .29647 .73378 .30968 .75165 .2996 .74338 .28708 Mtetra
.67 .733 .897 r
.74338 .28708 .75165 .2996 .76975 .29166 .76165 .2802 Mtetra
.653 .749 .92 r
.76165 .2802 .76975 .29166 .78811 .28555 .7801 .27408 Mtetra
.657 .752 .92 r
.7801 .27408 .78811 .28555 .80658 .27934 .79865 .26776 Mtetra
.651 .747 .92 r
.14318 .47624 .15372 .48558 .16844 .48065 .15794 .47139 Mtetra
.656 .751 .92 r
.15794 .47139 .16844 .48065 .18327 .47555 .1728 .46633 Mtetra
.655 .753 .922 r
.1728 .46633 .18327 .47555 .19811 .47118 .18775 .46127 Mtetra
.6 .723 .931 r
.18775 .46127 .19811 .47118 .2128 .46923 .20261 .45804 Mtetra
.544 .676 .924 r
.20261 .45804 .2128 .46923 .22749 .46865 .2174 .45658 Mtetra
.524 .65 .914 r
.2174 .45658 .22749 .46865 .24241 .46673 .23225 .4558 Mtetra
.618 .711 .912 r
.23225 .4558 .24241 .46673 .25782 .46034 .24748 .45198 Mtetra
.714 .792 .913 r
.24748 .45198 .25782 .46034 .27361 .44986 .26312 .44439 Mtetra
.791 .863 .902 r
.26312 .44439 .27361 .44986 .28954 .43809 .27909 .43316 Mtetra
.79 .877 .911 r
.27909 .43316 .28954 .43809 .30534 .42861 .29509 .4221 Mtetra
.744 .842 .924 r
.29509 .4221 .30534 .42861 .32101 .42202 .31099 .41318 Mtetra
.682 .78 .924 r
.31099 .41318 .32101 .42202 .33662 .41783 .32678 .40681 Mtetra
.632 .719 .91 r
.32678 .40681 .33662 .41783 .35231 .41395 .34256 .40233 Mtetra
.624 .706 .904 r
.34256 .40233 .35231 .41395 .36813 .4098 .35841 .39815 Mtetra
.629 .708 .903 r
.35841 .39815 .36813 .4098 .38407 .40497 .37439 .39373 Mtetra
.636 .72 .908 r
.37439 .39373 .38407 .40497 .40014 .3997 .39048 .38902 Mtetra
.648 .737 .914 r
.39048 .38902 .40014 .3997 .41631 .39428 .4067 .38382 Mtetra
.653 .744 .917 r
.4067 .38382 .41631 .39428 .43257 .38885 .42302 .37837 Mtetra
.655 .746 .917 r
.42302 .37837 .43257 .38885 .44894 .38337 .43945 .37282 Mtetra
.656 .746 .916 r
.43945 .37282 .44894 .38337 .46541 .3778 .45598 .36719 Mtetra
.657 .746 .916 r
.45598 .36719 .46541 .3778 .48197 .37214 .47261 .36148 Mtetra
.659 .747 .915 r
.47261 .36148 .48197 .37214 .49864 .36644 .48934 .35566 Mtetra
.664 .748 .913 r
.48934 .35566 .49864 .36644 .51541 .36071 .50618 .34959 Mtetra
.674 .746 .904 r
.50618 .34959 .51541 .36071 .53228 .35484 .52312 .34302 Mtetra
.679 .735 .893 r
.52312 .34302 .53228 .35484 .54925 .34852 .54015 .33615 Mtetra
.682 .727 .884 r
.54015 .33615 .54925 .34852 .56631 .34149 .55727 .32902 Mtetra
.675 .724 .886 r
.55727 .32902 .56631 .34149 .58346 .33418 .5745 .3222 Mtetra
.632 .718 .909 r
.5745 .3222 .58346 .33418 .60071 .32718 .59186 .3173 Mtetra
.543 .727 .959 r
.59186 .3173 .60071 .32718 .61812 .32263 .60941 .315 Mtetra
.403 .717 .987 r
.60941 .315 .61812 .32263 .63577 .32105 .62719 .31493 Mtetra
.339 .722 .984 r
.62719 .31493 .63577 .32105 .65367 .32184 .64515 .31505 Mtetra
.543 .81 .995 r
.64515 .31505 .65367 .32184 .6717 .32134 .66314 .31144 Mtetra
.688 .792 .929 r
.66314 .31144 .6717 .32134 .68969 .31661 .68108 .30394 Mtetra
.739 .755 .865 r
.68108 .30394 .68969 .31661 .70754 .30726 .69894 .29325 Mtetra
.721 .727 .855 r
.69894 .29325 .70754 .30726 .72538 .29647 .7169 .28325 Mtetra
.693 .731 .879 r
.7169 .28325 .72538 .29647 .74338 .28708 .73506 .27506 Mtetra
.656 .74 .911 r
.73506 .27506 .74338 .28708 .76165 .2802 .75347 .26878 Mtetra
.656 .754 .922 r
.75347 .26878 .76165 .2802 .7801 .27408 .77199 .26248 Mtetra
.66 .753 .919 r
.77199 .26248 .7801 .27408 .79865 .26776 .79061 .25595 Mtetra
.648 .746 .921 r
.13253 .4668 .14318 .47624 .15794 .47139 .14733 .46201 Mtetra
.655 .751 .92 r
.14733 .46201 .15794 .47139 .1728 .46633 .16224 .45692 Mtetra
.658 .752 .919 r
.16224 .45692 .1728 .46633 .18775 .46127 .17725 .45168 Mtetra
.641 .745 .924 r
.17725 .45168 .18775 .46127 .20261 .45804 .19229 .44704 Mtetra
.574 .694 .923 r
.19229 .44704 .20261 .45804 .2174 .45658 .20719 .44462 Mtetra
.535 .66 .916 r
.20719 .44462 .2174 .45658 .23225 .4558 .2221 .44344 Mtetra
.549 .659 .908 r
.2221 .44344 .23225 .4558 .24748 .45198 .23716 .4419 Mtetra
.651 .743 .916 r
.23716 .4419 .24748 .45198 .26312 .44439 .25265 .43675 Mtetra
.729 .814 .917 r
.25265 .43675 .26312 .44439 .27909 .43316 .26848 .42842 Mtetra
.788 .883 .915 r
.26848 .42842 .27909 .43316 .29509 .4221 .28457 .41739 Mtetra
.778 .886 .923 r
.28457 .41739 .29509 .4221 .31099 .41318 .30067 .40683 Mtetra
.738 .849 .932 r
.30067 .40683 .31099 .41318 .32678 .40681 .31669 .39812 Mtetra
.691 .789 .925 r
.31669 .39812 .32678 .40681 .34256 .40233 .33266 .3913 Mtetra
.645 .727 .908 r
.33266 .3913 .34256 .40233 .35841 .39815 .34861 .38625 Mtetra
.632 .706 .9 r
.34861 .38625 .35841 .39815 .37439 .39373 .36464 .38167 Mtetra
.635 .706 .897 r
.36464 .38167 .37439 .39373 .39048 .38902 .38078 .37694 Mtetra
.64 .708 .896 r
.38078 .37694 .39048 .38902 .4067 .38382 .39704 .37198 Mtetra
.645 .716 .899 r
.39704 .37198 .4067 .38382 .42302 .37837 .4134 .36677 Mtetra
.65 .724 .902 r
.4134 .36677 .42302 .37837 .43945 .37282 .42988 .36132 Mtetra
.656 .729 .903 r
.42988 .36132 .43945 .37282 .45598 .36719 .44647 .35562 Mtetra
.66 .73 .901 r
.44647 .35562 .45598 .36719 .47261 .36148 .46316 .34968 Mtetra
.665 .729 .897 r
.46316 .34968 .47261 .36148 .48934 .35566 .47996 .34348 Mtetra
.669 .725 .891 r
.47996 .34348 .48934 .35566 .50618 .34959 .49686 .33704 Mtetra
.673 .72 .885 r
.49686 .33704 .50618 .34959 .52312 .34302 .51386 .33036 Mtetra
.675 .72 .883 r
.51386 .33036 .52312 .34302 .54015 .33615 .53095 .32352 Mtetra
.665 .718 .889 r
.53095 .32352 .54015 .33615 .55727 .32902 .54815 .31715 Mtetra
.622 .717 .914 r
.54815 .31715 .55727 .32902 .5745 .3222 .56547 .31258 Mtetra
.55 .738 .963 r
.56547 .31258 .5745 .3222 .59186 .3173 .58295 .30994 Mtetra
.425 .738 .992 r
.58295 .30994 .59186 .3173 .60941 .315 .60062 .3092 Mtetra
.342 .733 .984 r
.60062 .3092 .60941 .315 .62719 .31493 .61849 .30898 Mtetra
.493 .81 1 r
.61849 .30898 .62719 .31493 .64515 .31505 .63644 .306 Mtetra
.655 .801 .953 r
.63644 .306 .64515 .31505 .66314 .31144 .6544 .29974 Mtetra
.732 .771 .884 r
.6544 .29974 .66314 .31144 .68108 .30394 .6723 .28974 Mtetra
.726 .727 .851 r
.6723 .28974 .68108 .30394 .69894 .29325 .69025 .27934 Mtetra
.707 .726 .865 r
.69025 .27934 .69894 .29325 .7169 .28325 .70835 .2702 Mtetra
.666 .726 .893 r
.70835 .2702 .7169 .28325 .73506 .27506 .72668 .26335 Mtetra
.653 .748 .919 r
.72668 .26335 .73506 .27506 .75347 .26878 .74518 .25712 Mtetra
.656 .752 .92 r
.74518 .25712 .75347 .26878 .77199 .26248 .76378 .25072 Mtetra
.663 .754 .918 r
.76378 .25072 .77199 .26248 .79061 .25595 .78248 .24398 Mtetra
.649 .748 .921 r
.12177 .45729 .13253 .4668 .14733 .46201 .13661 .45239 Mtetra
.651 .747 .92 r
.13661 .45239 .14733 .46201 .16224 .45692 .15156 .4474 Mtetra
.655 .751 .92 r
.15156 .4474 .16224 .45692 .17725 .45168 .16661 .44222 Mtetra
.658 .754 .921 r
.16661 .44222 .17725 .45168 .19229 .44704 .18176 .43692 Mtetra
.62 .731 .925 r
.18176 .43692 .19229 .44704 .20719 .44462 .19686 .43291 Mtetra
.569 .68 .915 r
.19686 .43291 .20719 .44462 .2221 .44344 .21189 .43064 Mtetra
.54 .648 .905 r
.21189 .43064 .2221 .44344 .23716 .4419 .22695 .42938 Mtetra
.57 .667 .904 r
.22695 .42938 .23716 .4419 .25265 .43675 .24222 .42713 Mtetra
.664 .759 .921 r
.24222 .42713 .25265 .43675 .26848 .42842 .2579 .42141 Mtetra
.728 .831 .929 r
.2579 .42141 .26848 .42842 .28457 .41739 .27386 .41311 Mtetra
.776 .898 .929 r
.27386 .41311 .28457 .41739 .30067 .40683 .29006 .40259 Mtetra
.77 .901 .933 r
.29006 .40259 .30067 .40683 .31669 .39812 .30628 .39229 Mtetra
.735 .864 .941 r
.30628 .39229 .31669 .39812 .33266 .3913 .32244 .38358 Mtetra
.706 .818 .934 r
.32244 .38358 .33266 .3913 .34861 .38625 .33861 .37606 Mtetra
.669 .755 .915 r
.33861 .37606 .34861 .38625 .36464 .38167 .35477 .36998 Mtetra
.648 .72 .901 r
.35477 .36998 .36464 .38167 .38078 .37694 .37098 .36465 Mtetra
.644 .708 .894 r
.37098 .36465 .38078 .37694 .39704 .37198 .3873 .35946 Mtetra
.645 .706 .891 r
.3873 .35946 .39704 .37198 .4134 .36677 .40372 .35417 Mtetra
.649 .707 .889 r
.40372 .35417 .4134 .36677 .42988 .36132 .42025 .34866 Mtetra
.654 .709 .888 r
.42025 .34866 .42988 .36132 .44647 .35562 .43689 .3429 Mtetra
.659 .711 .886 r
.43689 .3429 .44647 .35562 .46316 .34968 .45364 .33687 Mtetra
.663 .712 .884 r
.45364 .33687 .46316 .34968 .47996 .34348 .47049 .33063 Mtetra
.664 .713 .884 r
.47049 .33063 .47996 .34348 .49686 .33704 .48745 .32428 Mtetra
.661 .714 .888 r
.48745 .32428 .49686 .33704 .51386 .33036 .5045 .31807 Mtetra
.644 .718 .902 r
.5045 .31807 .51386 .33036 .53095 .32352 .52166 .31261 Mtetra
.603 .731 .935 r
.52166 .31261 .53095 .32352 .54815 .31715 .53893 .30862 Mtetra
.54 .763 .979 r
.53893 .30862 .54815 .31715 .56547 .31258 .55636 .30585 Mtetra
.424 .755 .995 r
.55636 .30585 .56547 .31258 .58295 .30994 .57395 .30471 Mtetra
.354 .755 .984 r
.57395 .30471 .58295 .30994 .60062 .3092 .59172 .30383 Mtetra
.483 .82 .999 r
.59172 .30383 .60062 .3092 .61849 .30898 .6096 .30068 Mtetra
.636 .813 .968 r
.6096 .30068 .61849 .30898 .63644 .306 .62754 .29488 Mtetra
.723 .781 .898 r
.62754 .29488 .63644 .306 .6544 .29974 .64546 .2855 Mtetra
.726 .727 .851 r
.64546 .2855 .6544 .29974 .6723 .28974 .66342 .27507 Mtetra
.708 .715 .854 r
.66342 .27507 .6723 .28974 .69025 .27934 .6815 .26565 Mtetra
.68 .721 .881 r
.6815 .26565 .69025 .27934 .70835 .2702 .69976 .25803 Mtetra
.654 .74 .913 r
.69976 .25803 .70835 .2702 .72668 .26335 .71822 .25173 Mtetra
.656 .754 .922 r
.71822 .25173 .72668 .26335 .74518 .25712 .73678 .24531 Mtetra
.66 .753 .919 r
.73678 .24531 .74518 .25712 .76378 .25072 .75546 .23867 Mtetra
.661 .75 .916 r
.75546 .23867 .76378 .25072 .78248 .24398 .77425 .23192 Mtetra
.656 .753 .921 r
.11086 .44787 .12177 .45729 .13661 .45239 .12579 .44266 Mtetra
.648 .746 .921 r
.12579 .44266 .13661 .45239 .15156 .4474 .14077 .43772 Mtetra
.654 .75 .92 r
.14077 .43772 .15156 .4474 .16661 .44222 .15586 .43253 Mtetra
.657 .752 .92 r
.15586 .43253 .16661 .44222 .18176 .43692 .17106 .42719 Mtetra
.653 .751 .922 r
.17106 .42719 .18176 .43692 .19686 .43291 .18633 .42198 Mtetra
.609 .713 .919 r
.18633 .42198 .19686 .43291 .21189 .43064 .20153 .41832 Mtetra
.571 .673 .908 r
.20153 .41832 .21189 .43064 .22695 .42938 .21672 .41595 Mtetra
.549 .644 .896 r
.21672 .41595 .22695 .42938 .24222 .42713 .23195 .41441 Mtetra
.58 .671 .902 r
.23195 .41441 .24222 .42713 .2579 .42141 .2474 .41176 Mtetra
.66 .761 .925 r
.2474 .41176 .2579 .42141 .27386 .41311 .26321 .40608 Mtetra
.709 .832 .941 r
.26321 .40608 .27386 .41311 .29006 .40259 .27927 .39848 Mtetra
.755 .905 .943 r
.27927 .39848 .29006 .40259 .30628 .39229 .29555 .38873 Mtetra
.755 .919 .945 r
.29555 .38873 .30628 .39229 .32244 .38358 .31189 .37883 Mtetra
.735 .893 .951 r
.31189 .37883 .32244 .38358 .33861 .37606 .32823 .36989 Mtetra
.71 .859 .953 r
.32823 .36989 .33861 .37606 .35477 .36998 .34457 .36202 Mtetra
.692 .815 .941 r
.34457 .36202 .35477 .36998 .37098 .36465 .36095 .35492 Mtetra
.676 .772 .923 r
.36095 .35492 .37098 .36465 .3873 .35946 .37739 .3484 Mtetra
.662 .742 .909 r
.37739 .3484 .3873 .35946 .40372 .35417 .39389 .3424 Mtetra
.656 .727 .902 r
.39389 .3424 .40372 .35417 .42025 .34866 .41049 .33658 Mtetra
.655 .722 .898 r
.41049 .33658 .42025 .34866 .43689 .3429 .42719 .33075 Mtetra
.42719 .33075 .43689 .3429 .45364 .33687 .44399 .3249 Mtetra
.65 .725 .904 r
.44399 .3249 .45364 .33687 .47049 .33063 .46089 .31923 Mtetra
.636 .733 .918 r
.46089 .31923 .47049 .33063 .48745 .32428 .47789 .31409 Mtetra
.616 .753 .943 r
.47789 .31409 .48745 .32428 .5045 .31807 .495 .30954 Mtetra
.578 .779 .974 r
.495 .30954 .5045 .31807 .52166 .31261 .51224 .30577 Mtetra
.503 .791 .997 r
.51224 .30577 .52166 .31261 .53893 .30862 .52961 .30311 Mtetra
.411 .78 .994 r
.52961 .30311 .53893 .30862 .55636 .30585 .54713 .30142 Mtetra
.374 .785 .98 r
.54713 .30142 .55636 .30585 .57395 .30471 .56481 .29961 Mtetra
.515 .842 .998 r
.56481 .29961 .57395 .30471 .59172 .30383 .58262 .29562 Mtetra
.64 .818 .968 r
.58262 .29562 .59172 .30383 .6096 .30068 .60052 .28964 Mtetra
.718 .781 .903 r
.60052 .28964 .6096 .30068 .62754 .29488 .61844 .28055 Mtetra
.723 .726 .852 r
.61844 .28055 .62754 .29488 .64546 .2855 .63641 .2703 Mtetra
.705 .707 .849 r
.63641 .2703 .64546 .2855 .66342 .27507 .65448 .26087 Mtetra
.686 .716 .872 r
.65448 .26087 .66342 .27507 .6815 .26565 .6727 .25276 Mtetra
.657 .729 .902 r
.6727 .25276 .6815 .26565 .69976 .25803 .69111 .24625 Mtetra
.655 .751 .921 r
.69111 .24625 .69976 .25803 .71822 .25173 .70964 .23985 Mtetra
.657 .752 .92 r
.70964 .23985 .71822 .25173 .73678 .24531 .72829 .23329 Mtetra
.663 .753 .917 r
.72829 .23329 .73678 .24531 .75546 .23867 .74704 .22646 Mtetra
.655 .748 .918 r
.74704 .22646 .75546 .23867 .77425 .23192 .76594 .21991 Mtetra
.661 .756 .92 r
.09983 .4384 .11086 .44787 .12579 .44266 .11483 .43295 Mtetra
.652 .749 .921 r
.11483 .43295 .12579 .44266 .14077 .43772 .12988 .4278 Mtetra
.649 .746 .92 r
.12988 .4278 .14077 .43772 .15586 .43253 .145 .42273 Mtetra
.655 .751 .92 r
.145 .42273 .15586 .43253 .17106 .42719 .16024 .4174 Mtetra
.658 .753 .92 r
.16024 .4174 .17106 .42719 .18633 .42198 .17558 .41194 Mtetra
.649 .747 .921 r
.17558 .41194 .18633 .42198 .20153 .41832 .19098 .40677 Mtetra
.607 .704 .913 r
.19098 .40677 .20153 .41832 .21672 .41595 .20632 .40312 Mtetra
.579 .669 .901 r
.20632 .40312 .21672 .41595 .23195 .41441 .22168 .40048 Mtetra
.56 .643 .889 r
.22168 .40048 .23195 .41441 .2474 .41176 .23709 .39854 Mtetra
.581 .666 .896 r
.23709 .39854 .2474 .41176 .26321 .40608 .25269 .39577 Mtetra
.644 .746 .924 r
.25269 .39577 .26321 .40608 .27927 .39848 .26861 .39064 Mtetra
.686 .813 .943 r
.26861 .39064 .27927 .39848 .29555 .38873 .28475 .38382 Mtetra
.715 .887 .96 r
.28475 .38382 .29555 .38873 .31189 .37883 .30108 .37557 Mtetra
.725 .925 .959 r
.30108 .37557 .31189 .37883 .32823 .36989 .31753 .36651 Mtetra
.717 .924 .962 r
.31753 .36651 .32823 .36989 .34457 .36202 .33402 .35769 Mtetra
.705 .903 .966 r
.33402 .35769 .34457 .36202 .36095 .35492 .35056 .34948 Mtetra
.684 .876 .971 r
.35056 .34948 .36095 .35492 .37739 .3484 .36712 .34218 Mtetra
.671 .857 .971 r
.36712 .34218 .37739 .3484 .39389 .3424 .38374 .33541 Mtetra
.66 .837 .968 r
.38374 .33541 .39389 .3424 .41049 .33658 .40044 .32911 Mtetra
.648 .824 .968 r
.40044 .32911 .41049 .33658 .42719 .33075 .41722 .32321 Mtetra
.633 .819 .972 r
.41722 .32321 .42719 .33075 .44399 .3249 .43409 .31773 Mtetra
.612 .823 .981 r
.43409 .31773 .44399 .3249 .46089 .31923 .45106 .3127 Mtetra
.58 .829 .992 r
.45106 .3127 .46089 .31923 .47789 .31409 .46814 .30823 Mtetra
.523 .824 1 r
.46814 .30823 .47789 .31409 .495 .30954 .48534 .30467 Mtetra
.459 .819 .996 r
.48534 .30467 .495 .30954 .51224 .30577 .50266 .30175 Mtetra
.409 .813 .982 r
.50266 .30175 .51224 .30577 .52961 .30311 .52013 .29909 Mtetra
.454 .836 .987 r
.52013 .29909 .52961 .30311 .54713 .30142 .53775 .29561 Mtetra
.574 .851 .996 r
.53775 .29561 .54713 .30142 .56481 .29961 .55549 .29068 Mtetra
.663 .809 .953 r
.55549 .29068 .56481 .29961 .58262 .29562 .57334 .28402 Mtetra
.715 .771 .896 r
.57334 .28402 .58262 .29562 .60052 .28964 .59125 .27492 Mtetra
.716 .718 .851 r
.59125 .27492 .60052 .28964 .61844 .28055 .60922 .26495 Mtetra
.7 .7 .846 r
.60922 .26495 .61844 .28055 .63641 .2703 .62729 .25569 Mtetra
.687 .711 .867 r
.62729 .25569 .63641 .2703 .65448 .26087 .64548 .24744 Mtetra
.66 .721 .894 r
.64548 .24744 .65448 .26087 .6727 .25276 .66385 .24075 Mtetra
.654 .748 .919 r
.66385 .24075 .6727 .25276 .69111 .24625 .68234 .23436 Mtetra
.656 .753 .921 r
.68234 .23436 .69111 .24625 .70964 .23985 .70096 .22782 Mtetra
.662 .754 .918 r
.70096 .22782 .70964 .23985 .72829 .23329 .71968 .22099 Mtetra
.659 .749 .916 r
.71968 .22099 .72829 .23329 .74704 .22646 .73853 .21424 Mtetra
.651 .748 .921 r
.73853 .21424 .74704 .22646 .76594 .21991 .75753 .2078 Mtetra
.661 .755 .92 r
.08869 .42879 .09983 .4384 .11483 .43295 .10373 .42331 Mtetra
.66 .755 .92 r
.10373 .42331 .11483 .43295 .12988 .4278 .11886 .4178 Mtetra
.65 .746 .92 r
.11886 .4178 .12988 .4278 .145 .42273 .13404 .41266 Mtetra
.651 .746 .92 r
.13404 .41266 .145 .42273 .16024 .4174 .14931 .40745 Mtetra
.656 .751 .92 r
.14931 .40745 .16024 .4174 .17558 .41194 .16469 .40202 Mtetra
.658 .754 .921 r
.16469 .40202 .17558 .41194 .19098 .40677 .18018 .39646 Mtetra
.649 .745 .919 r
.18018 .39646 .19098 .40677 .20632 .40312 .19573 .3912 Mtetra
.613 .702 .908 r
.19573 .3912 .20632 .40312 .22168 .40048 .21124 .38727 Mtetra
.589 .67 .895 r
.21124 .38727 .22168 .40048 .23709 .39854 .22677 .38421 Mtetra
.573 .645 .883 r
.22677 .38421 .23709 .39854 .25269 .39577 .24238 .38172 Mtetra
.582 .654 .886 r
.24238 .38172 .25269 .39577 .26861 .39064 .25813 .37889 Mtetra
.617 .712 .913 r
.25813 .37889 .26861 .39064 .28475 .38382 .27412 .37468 Mtetra
.66 .781 .938 r
.27412 .37468 .28475 .38382 .30108 .37557 .29034 .36877 Mtetra
.678 .841 .961 r
.29034 .36877 .30108 .37557 .31753 .36651 .30672 .36198 Mtetra
.679 .895 .975 r
.30672 .36198 .31753 .36651 .33402 .35769 .32323 .35458 Mtetra
.674 .924 .973 r
.32323 .35458 .33402 .35769 .35056 .34948 .33985 .34671 Mtetra
.653 .926 .974 r
.33985 .34671 .35056 .34948 .36712 .34218 .35653 .33913 Mtetra
.636 .918 .978 r
.35653 .33913 .36712 .34218 .38374 .33541 .37327 .33203 Mtetra
.616 .907 .984 r
.37327 .33203 .38374 .33541 .40044 .32911 .39008 .32549 Mtetra
.591 .896 .988 r
.39008 .32549 .40044 .32911 .41722 .32321 .40697 .31953 Mtetra
.561 .885 .989 r
.40697 .31953 .41722 .32321 .43409 .31773 .42394 .31416 Mtetra
.525 .874 .988 r
.42394 .31416 .43409 .31773 .45106 .3127 .44101 .30936 Mtetra
.487 .862 .982 r
.44101 .30936 .45106 .3127 .46814 .30823 .45819 .30505 Mtetra
.459 .853 .976 r
.45819 .30505 .46814 .30823 .48534 .30467 .47549 .30103 Mtetra
.499 .864 .986 r
.47549 .30103 .48534 .30467 .50266 .30175 .49294 .29656 Mtetra
.57 .863 .996 r
.49294 .29656 .50266 .30175 .52013 .29909 .51051 .29146 Mtetra
.636 .83 .975 r
.51051 .29146 .52013 .29909 .53775 .29561 .52821 .28547 Mtetra
.69 .792 .928 r
.52821 .28547 .53775 .29561 .55549 .29068 .54602 .27773 Mtetra
.711 .745 .878 r
.54602 .27773 .55549 .29068 .57334 .28402 .56391 .26857 Mtetra
.705 .704 .846 r
.56391 .26857 .57334 .28402 .59125 .27492 .58188 .25904 Mtetra
.694 .694 .846 r
.58188 .25904 .59125 .27492 .60922 .26495 .59994 .25007 Mtetra
.683 .706 .865 r
.59994 .25007 .60922 .26495 .62729 .25569 .61811 .24199 Mtetra
.659 .718 .892 r
.61811 .24199 .62729 .25569 .64548 .24744 .63644 .23526 Mtetra
.653 .745 .917 r
.63644 .23526 .64548 .24744 .66385 .24075 .6549 .22884 Mtetra
.656 .753 .922 r
.6549 .22884 .66385 .24075 .68234 .23436 .67347 .22227 Mtetra
.66 .753 .919 r
.67347 .22227 .68234 .23436 .70096 .22782 .69216 .21547 Mtetra
.661 .75 .916 r
.69216 .21547 .70096 .22782 .71968 .22099 .71097 .20858 Mtetra
.652 .746 .919 r
.71097 .20858 .71968 .22099 .73853 .21424 .72993 .20206 Mtetra
.651 .752 .924 r
.72993 .20206 .73853 .21424 .75753 .2078 .74902 .1955 Mtetra
.657 .752 .92 r
.07743 .419 .08869 .42879 .10373 .42331 .0925 .41358 Mtetra
.661 .756 .92 r
.0925 .41358 .10373 .42331 .11886 .4178 .10769 .40798 Mtetra
.658 .754 .921 r
.10769 .40798 .11886 .4178 .13404 .41266 .12296 .40246 Mtetra
.649 .746 .92 r
.12296 .40246 .13404 .41266 .14931 .40745 .13827 .39723 Mtetra
.651 .747 .92 r
.13827 .39723 .14931 .40745 .16469 .40202 .15369 .39189 Mtetra
.656 .751 .92 r
.15369 .39189 .16469 .40202 .18018 .39646 .16922 .38637 Mtetra
.658 .754 .921 r
.16922 .38637 .18018 .39646 .19573 .3912 .18486 .38072 Mtetra
.652 .745 .918 r
.18486 .38072 .19573 .3912 .21124 .38727 .20056 .37527 Mtetra
.625 .708 .905 r
.20056 .37527 .21124 .38727 .22677 .38421 .21627 .37078 Mtetra
.601 .674 .892 r
.21627 .37078 .22677 .38421 .24238 .38172 .232 .36719 Mtetra
.592 .653 .879 r
.232 .36719 .24238 .38172 .25813 .37889 .24781 .36393 Mtetra
.586 .644 .875 r
.24781 .36393 .25813 .37889 .27412 .37468 .26373 .36089 Mtetra
.601 .671 .889 r
.26373 .36089 .27412 .37468 .29034 .36877 .27982 .35721 Mtetra
.625 .723 .917 r
.27982 .35721 .29034 .36877 .30672 .36198 .2961 .35255 Mtetra
.652 .778 .94 r
.2961 .35255 .30672 .36198 .32323 .35458 .31257 .34678 Mtetra
.66 .819 .96 r
.31257 .34678 .32323 .35458 .33985 .34671 .32917 .34057 Mtetra
.654 .857 .977 r
.32917 .34057 .33985 .34671 .35653 .33913 .34587 .33417 Mtetra
.638 .881 .986 r
.34587 .33417 .35653 .33913 .37327 .33203 .36267 .32778 Mtetra
.617 .892 .988 r
.36267 .32778 .37327 .33203 .39008 .32549 .37957 .32154 Mtetra
.598 .893 .989 r
.37957 .32154 .39008 .32549 .40697 .31953 .39656 .31552 Mtetra
.586 .889 .99 r
.39656 .31552 .40697 .31953 .42394 .31416 .41365 .30973 Mtetra
.585 .881 .992 r
.41365 .30973 .42394 .31416 .44101 .30936 .43084 .30409 Mtetra
.599 .869 .993 r
.43084 .30409 .44101 .30936 .45819 .30505 .44815 .29846 Mtetra
.623 .848 .985 r
.44815 .29846 .45819 .30505 .47549 .30103 .46557 .29264 Mtetra
.651 .816 .963 r
.46557 .29264 .47549 .30103 .49294 .29656 .48312 .28637 Mtetra
.683 .788 .929 r
.48312 .28637 .49294 .29656 .51051 .29146 .5008 .27897 Mtetra
.699 .749 .89 r
.5008 .27897 .51051 .29146 .52821 .28547 .51857 .27056 Mtetra
.7 .71 .856 r
.51857 .27056 .52821 .28547 .54602 .27773 .53643 .26149 Mtetra
.691 .688 .842 r
.53643 .26149 .54602 .27773 .56391 .26857 .55438 .25262 Mtetra
.686 .691 .849 r
.55438 .25262 .56391 .26857 .58188 .25904 .57243 .24407 Mtetra
.674 .702 .868 r
.57243 .24407 .58188 .25904 .59994 .25007 .59059 .23642 Mtetra
.657 .719 .894 r
.59059 .23642 .59994 .25007 .61811 .24199 .60888 .22976 Mtetra
.654 .746 .917 r
.60888 .22976 .61811 .24199 .63644 .23526 .6273 .22329 Mtetra
.656 .754 .922 r
.6273 .22329 .63644 .23526 .6549 .22884 .64583 .21669 Mtetra
.66 .753 .919 r
.64583 .21669 .6549 .22884 .67347 .22227 .66449 .20988 Mtetra
.661 .75 .916 r
.66449 .20988 .67347 .22227 .69216 .21547 .68326 .20295 Mtetra
.654 .746 .918 r
.68326 .20295 .69216 .21547 .71097 .20858 .70217 .19631 Mtetra
.651 .752 .923 r
.70217 .19631 .71097 .20858 .72993 .20206 .72122 .18974 Mtetra
.654 .754 .923 r
.72122 .18974 .72993 .20206 .74902 .1955 .74039 .18297 Mtetra
.654 .75 .92 r
.06605 .40901 .07743 .419 .0925 .41358 .08117 .40364 Mtetra
.658 .753 .92 r
.08117 .40364 .0925 .41358 .10769 .40798 .09639 .39811 Mtetra
.661 .756 .921 r
.09639 .39811 .10769 .40798 .12296 .40246 .11172 .39241 Mtetra
.657 .753 .921 r
.11172 .39241 .12296 .40246 .13827 .39723 .12712 .38683 Mtetra
.65 .745 .919 r
.12712 .38683 .13827 .39723 .15369 .39189 .14258 .3815 Mtetra
.652 .747 .92 r
.14258 .3815 .15369 .39189 .16922 .38637 .15815 .37607 Mtetra
.656 .751 .92 r
.15815 .37607 .16922 .38637 .18486 .38072 .17383 .37045 Mtetra
.657 .754 .921 r
.17383 .37045 .18486 .38072 .20056 .37527 .18961 .36473 Mtetra
.656 .749 .919 r
.18961 .36473 .20056 .37527 .21627 .37078 .20548 .35903 Mtetra
.642 .722 .906 r
.20548 .35903 .21627 .37078 .232 .36719 .22141 .3538 Mtetra
.615 .684 .891 r
.22141 .3538 .232 .36719 .24781 .36393 .23734 .34956 Mtetra
.608 .665 .88 r
.23734 .34956 .24781 .36393 .26373 .36089 .25336 .34558 Mtetra
.604 .65 .868 r
.25336 .34558 .26373 .36089 .27982 .35721 .26949 .34171 Mtetra
.602 .647 .867 r
.26949 .34171 .27982 .35721 .2961 .35255 .28574 .33787 Mtetra
.613 .666 .877 r
.28574 .33787 .2961 .35255 .31257 .34678 .30214 .33359 Mtetra
.625 .697 .896 r
.30214 .33359 .31257 .34678 .32917 .34057 .31869 .32879 Mtetra
.637 .729 .915 r
.31869 .32879 .32917 .34057 .34587 .33417 .33538 .32353 Mtetra
.646 .757 .93 r
.33538 .32353 .34587 .33417 .36267 .32778 .35221 .31788 Mtetra
.652 .776 .939 r
.35221 .31788 .36267 .32778 .37957 .32154 .36916 .3119 Mtetra
.654 .784 .943 r
.36916 .3119 .37957 .32154 .39656 .31552 .38623 .30582 Mtetra
.656 .785 .943 r
.38623 .30582 .39656 .31552 .41365 .30973 .4034 .29962 Mtetra
.664 .78 .935 r
.4034 .29962 .41365 .30973 .43084 .30409 .4207 .2931 Mtetra
.672 .766 .92 r
.4207 .2931 .43084 .30409 .44815 .29846 .43811 .28618 Mtetra
.68 .744 .9 r
.43811 .28618 .44815 .29846 .46557 .29264 .45564 .27878 Mtetra
.685 .719 .875 r
.45564 .27878 .46557 .29264 .48312 .28637 .47327 .27086 Mtetra
.687 .695 .853 r
.47327 .27086 .48312 .28637 .5008 .27897 .49101 .26247 Mtetra
.682 .68 .842 r
.49101 .26247 .5008 .27897 .51857 .27056 .50884 .2541 Mtetra
.68 .681 .844 r
.50884 .2541 .51857 .27056 .53643 .26149 .52676 .24583 Mtetra
.678 .693 .857 r
.52676 .24583 .53643 .26149 .55438 .25262 .54478 .23781 Mtetra
.662 .701 .876 r
.54478 .23781 .55438 .25262 .57243 .24407 .56291 .23079 Mtetra
.654 .726 .902 r
.56291 .23079 .57243 .24407 .59059 .23642 .58116 .22425 Mtetra
.654 .749 .919 r
.58116 .22425 .59059 .23642 .60888 .22976 .59954 .21771 Mtetra
.656 .753 .922 r
.59954 .21771 .60888 .22976 .6273 .22329 .61804 .21107 Mtetra
.66 .753 .919 r
.61804 .21107 .6273 .22329 .64583 .21669 .63665 .20422 Mtetra
.661 .75 .916 r
.63665 .20422 .64583 .21669 .66449 .20988 .65539 .19726 Mtetra
.654 .746 .917 r
.65539 .19726 .66449 .20988 .68326 .20295 .67426 .19055 Mtetra
.651 .751 .923 r
.67426 .19055 .68326 .20295 .70217 .19631 .69326 .18395 Mtetra
.654 .754 .923 r
.69326 .18395 .70217 .19631 .72122 .18974 .71239 .17716 Mtetra
.657 .753 .921 r
.71239 .17716 .72122 .18974 .74039 .18297 .73164 .1702 Mtetra
.651 .747 .92 r
.05457 .39882 .06605 .40901 .08117 .40364 .06971 .39351 Mtetra
.655 .751 .92 r
.06971 .39351 .08117 .40364 .09639 .39811 .08497 .38801 Mtetra
.658 .753 .92 r
.08497 .38801 .09639 .39811 .11172 .39241 .10034 .38238 Mtetra
.661 .757 .921 r
.10034 .38238 .11172 .39241 .12712 .38683 .11581 .3766 Mtetra
.658 .753 .92 r
.11581 .3766 .12712 .38683 .14258 .3815 .13136 .37091 Mtetra
.65 .745 .919 r
.13136 .37091 .14258 .3815 .15815 .37607 .14698 .36546 Mtetra
.651 .746 .919 r
.14698 .36546 .15815 .37607 .17383 .37045 .16269 .35996 Mtetra
.655 .751 .92 r
.16269 .35996 .17383 .37045 .18961 .36473 .17852 .35424 Mtetra
.655 .752 .921 r
.17852 .35424 .18961 .36473 .20548 .35903 .19445 .3485 Mtetra
.659 .754 .92 r
.19445 .3485 .20548 .35903 .22141 .3538 .21049 .34259 Mtetra
.652 .739 .913 r
.21049 .34259 .22141 .3538 .23734 .34956 .2266 .33688 Mtetra
.64 .709 .897 r
.2266 .33688 .23734 .34956 .25336 .34558 .24278 .33157 Mtetra
.624 .681 .884 r
.24278 .33157 .25336 .34558 .26949 .34171 .25901 .32686 Mtetra
.62 .667 .873 r
.25901 .32686 .26949 .34171 .28574 .33787 .27535 .32222 Mtetra
.62 .656 .863 r
.27535 .32222 .28574 .33787 .30214 .33359 .29181 .31749 Mtetra
.623 .651 .857 r
.29181 .31749 .30214 .33359 .31869 .32879 .3084 .31259 Mtetra
.625 .652 .856 r
.3084 .31259 .31869 .32879 .33538 .32353 .32511 .30756 Mtetra
.632 .659 .858 r
.32511 .30756 .33538 .32353 .35221 .31788 .34195 .30216 Mtetra
.64 .668 .861 r
.34195 .30216 .35221 .31788 .36916 .3119 .35893 .29638 Mtetra
.648 .675 .862 r
.35893 .29638 .36916 .3119 .38623 .30582 .37604 .29022 Mtetra
.654 .677 .86 r
.37604 .29022 .38623 .30582 .4034 .29962 .39327 .28367 Mtetra
.66 .676 .854 r
.39327 .28367 .4034 .29962 .4207 .2931 .41063 .27674 Mtetra
.665 .673 .848 r
.41063 .27674 .4207 .2931 .43811 .28618 .4281 .26943 Mtetra
.666 .669 .843 r
.4281 .26943 .43811 .28618 .45564 .27878 .44567 .26198 Mtetra
.668 .67 .843 r
.44567 .26198 .45564 .27878 .47327 .27086 .46335 .25434 Mtetra
.67 .676 .847 r
.46335 .25434 .47327 .27086 .49101 .26247 .48113 .24662 Mtetra
.671 .687 .857 r
.48113 .24662 .49101 .26247 .50884 .2541 .499 .23895 Mtetra
.662 .696 .871 r
.499 .23895 .50884 .2541 .52676 .24583 .51699 .23188 Mtetra
.656 .714 .891 r
.51699 .23188 .52676 .24583 .54478 .23781 .53508 .22521 Mtetra
.653 .739 .913 r
.53508 .22521 .54478 .23781 .56291 .23079 .55329 .21874 Mtetra
.656 .753 .921 r
.55329 .21874 .56291 .23079 .58116 .22425 .57163 .2121 Mtetra
.57163 .2121 .58116 .22425 .59954 .21771 .59008 .20541 Mtetra
.66 .753 .919 r
.59008 .20541 .59954 .21771 .61804 .21107 .60866 .1985 Mtetra
.66 .749 .916 r
.60866 .1985 .61804 .21107 .63665 .20422 .62736 .19153 Mtetra
.654 .746 .917 r
.62736 .19153 .63665 .20422 .65539 .19726 .64619 .18479 Mtetra
.651 .751 .922 r
.64619 .18479 .65539 .19726 .67426 .19055 .66515 .17813 Mtetra
.654 .755 .924 r
.66515 .17813 .67426 .19055 .69326 .18395 .68424 .17131 Mtetra
.656 .753 .921 r
.68424 .17131 .69326 .18395 .71239 .17716 .70345 .16434 Mtetra
.66 .753 .919 r
.70345 .16434 .71239 .17716 .73164 .1702 .72279 .15716 Mtetra
.653 .749 .92 r
.04295 .38859 .05457 .39882 .06971 .39351 .05815 .38314 Mtetra
.651 .747 .92 r
.05815 .38314 .06971 .39351 .08497 .38801 .07344 .37772 Mtetra
.655 .751 .92 r
.07344 .37772 .08497 .38801 .10034 .38238 .08884 .37212 Mtetra
.658 .754 .921 r
.08884 .37212 .10034 .38238 .11581 .3766 .10436 .3664 Mtetra
.661 .757 .921 r
.10436 .3664 .11581 .3766 .13136 .37091 .11997 .36053 Mtetra
.659 .754 .92 r
.11997 .36053 .13136 .37091 .14698 .36546 .13568 .3547 Mtetra
.651 .746 .919 r
.13568 .3547 .14698 .36546 .16269 .35996 .15145 .34911 Mtetra
.65 .745 .919 r
.15145 .34911 .16269 .35996 .17852 .35424 .16731 .34352 Mtetra
.654 .75 .92 r
.16731 .34352 .17852 .35424 .19445 .3485 .18329 .33775 Mtetra
.656 .751 .92 r
.18329 .33775 .19445 .3485 .21049 .34259 .19938 .3319 Mtetra
.656 .754 .922 r
.19938 .3319 .21049 .34259 .2266 .33688 .21556 .32599 Mtetra
.658 .752 .919 r
.21556 .32599 .2266 .33688 .24278 .33157 .23186 .31996 Mtetra
.654 .737 .911 r
.23186 .31996 .24278 .33157 .25901 .32686 .24824 .31404 Mtetra
.648 .714 .896 r
.24824 .31404 .25901 .32686 .27535 .32222 .26472 .30828 Mtetra
.64 .693 .884 r
.26472 .30828 .27535 .32222 .29181 .31749 .28128 .30276 Mtetra
.635 .679 .875 r
.28128 .30276 .29181 .31749 .3084 .31259 .29793 .29734 Mtetra
.636 .673 .868 r
.29793 .29734 .3084 .31259 .32511 .30756 .31471 .2918 Mtetra
.638 .667 .861 r
.31471 .2918 .32511 .30756 .34195 .30216 .33162 .28606 Mtetra
.642 .665 .857 r
.33162 .28606 .34195 .30216 .35893 .29638 .34864 .28008 Mtetra
.646 .665 .854 r
.34864 .28008 .35893 .29638 .37604 .29022 .36579 .27383 Mtetra
.65 .666 .852 r
.36579 .27383 .37604 .29022 .39327 .28367 .38306 .26733 Mtetra
.654 .67 .853 r
.38306 .26733 .39327 .28367 .41063 .27674 .40045 .26058 Mtetra
.658 .675 .855 r
.40045 .26058 .41063 .27674 .4281 .26943 .41796 .25363 Mtetra
.661 .683 .86 r
.41796 .25363 .4281 .26943 .44567 .26198 .43557 .24655 Mtetra
.66 .689 .866 r
.43557 .24655 .44567 .26198 .46335 .25434 .45329 .23957 Mtetra
.656 .699 .878 r
.45329 .23957 .46335 .25434 .48113 .24662 .47111 .23282 Mtetra
.655 .717 .894 r
.47111 .23282 .48113 .24662 .499 .23895 .48904 .22622 Mtetra
.653 .737 .911 r
.48904 .22622 .499 .23895 .51699 .23188 .50709 .21974 Mtetra
.656 .751 .92 r
.50709 .21974 .51699 .23188 .53508 .22521 .52527 .21312 Mtetra
.656 .754 .922 r
.52527 .21312 .53508 .22521 .55329 .21874 .54356 .20645 Mtetra
.657 .752 .92 r
.54356 .20645 .55329 .21874 .57163 .2121 .56197 .19967 Mtetra
.661 .752 .918 r
.56197 .19967 .57163 .2121 .59008 .20541 .58051 .19271 Mtetra
.66 .748 .915 r
.58051 .19271 .59008 .20541 .60866 .1985 .59917 .18574 Mtetra
.653 .746 .918 r
.59917 .18574 .60866 .1985 .62736 .19153 .61796 .17901 Mtetra
.651 .751 .923 r
.61796 .17901 .62736 .19153 .64619 .18479 .63688 .17231 Mtetra
.654 .755 .924 r
.63688 .17231 .64619 .18479 .66515 .17813 .65592 .16544 Mtetra
.656 .753 .921 r
.65592 .16544 .66515 .17813 .68424 .17131 .6751 .15843 Mtetra
.66 .753 .919 r
.6751 .15843 .68424 .17131 .70345 .16434 .69439 .15122 Mtetra
.658 .749 .917 r
.69439 .15122 .70345 .16434 .72279 .15716 .71382 .14404 Mtetra
.658 .754 .921 r
.03117 .37841 .04295 .38859 .05815 .38314 .04645 .37271 Mtetra
.653 .749 .92 r
.04645 .37271 .05815 .38314 .07344 .37772 .0618 .36716 Mtetra
.651 .747 .92 r
.0618 .36716 .07344 .37772 .08884 .37212 .07723 .36164 Mtetra
.655 .751 .92 r
.07723 .36164 .08884 .37212 .10436 .3664 .09278 .35595 Mtetra
.657 .753 .921 r
.09278 .35595 .10436 .3664 .11997 .36053 .10844 .35015 Mtetra
.66 .757 .922 r
.10844 .35015 .11997 .36053 .13568 .3547 .12421 .34421 Mtetra
.659 .756 .921 r
.12421 .34421 .13568 .3547 .15145 .34911 .14007 .33825 Mtetra
.654 .748 .919 r
.14007 .33825 .15145 .34911 .16731 .34352 .156 .33244 Mtetra
.651 .744 .918 r
.156 .33244 .16731 .34352 .18329 .33775 .17202 .32672 Mtetra
.651 .747 .919 r
.17202 .32672 .18329 .33775 .19938 .3319 .18815 .32095 Mtetra
.655 .751 .92 r
.18815 .32095 .19938 .3319 .21556 .32599 .20439 .315 Mtetra
.656 .751 .92 r
.20439 .315 .21556 .32599 .23186 .31996 .22074 .309 Mtetra
.656 .753 .922 r
.22074 .309 .23186 .31996 .24824 .31404 .23719 .30297 Mtetra
.657 .753 .92 r
.23719 .30297 .24824 .31404 .26472 .30828 .25375 .29682 Mtetra
.657 .747 .916 r
.25375 .29682 .26472 .30828 .28128 .30276 .27042 .29065 Mtetra
.655 .735 .908 r
.27042 .29065 .28128 .30276 .29793 .29734 .28718 .2845 Mtetra
.653 .722 .899 r
.28718 .2845 .29793 .29734 .31471 .2918 .30405 .27835 Mtetra
.652 .712 .892 r
.30405 .27835 .31471 .2918 .33162 .28606 .32103 .27218 Mtetra
.651 .706 .887 r
.32103 .27218 .33162 .28606 .34864 .28008 .33812 .26593 Mtetra
.652 .703 .884 r
.33812 .26593 .34864 .28008 .36579 .27383 .35533 .25961 Mtetra
.653 .703 .884 r
.35533 .25961 .36579 .27383 .38306 .26733 .37265 .25321 Mtetra
.654 .707 .886 r
.37265 .25321 .38306 .26733 .40045 .26058 .39008 .24675 Mtetra
.654 .713 .891 r
.39008 .24675 .40045 .26058 .41796 .25363 .40762 .24026 Mtetra
.654 .722 .899 r
.40762 .24026 .41796 .25363 .43557 .24655 .42528 .23376 Mtetra
.654 .734 .909 r
.42528 .23376 .43557 .24655 .45329 .23957 .44305 .22728 Mtetra
.654 .746 .917 r
.44305 .22728 .45329 .23957 .47111 .23282 .46094 .22077 Mtetra
.656 .752 .921 r
.46094 .22077 .47111 .23282 .48904 .22622 .47895 .21414 Mtetra
.656 .753 .922 r
.47895 .21414 .48904 .22622 .50709 .21974 .49708 .20748 Mtetra
.656 .752 .92 r
.49708 .20748 .50709 .21974 .52527 .21312 .51533 .20076 Mtetra
.66 .752 .919 r
.51533 .20076 .52527 .21312 .54356 .20645 .53371 .19384 Mtetra
.66 .749 .916 r
.53371 .19384 .54356 .20645 .56197 .19967 .5522 .18687 Mtetra
.657 .746 .916 r
.5522 .18687 .56197 .19967 .58051 .19271 .57082 .17998 Mtetra
.652 .747 .919 r
.57082 .17998 .58051 .19271 .59917 .18574 .58956 .17323 Mtetra
.652 .753 .924 r
.58956 .17323 .59917 .18574 .61796 .17901 .60844 .16646 Mtetra
.655 .755 .924 r
.60844 .16646 .61796 .17901 .63688 .17231 .62744 .15953 Mtetra
.657 .753 .921 r
.62744 .15953 .63688 .17231 .65592 .16544 .64657 .15247 Mtetra
.659 .752 .919 r
.64657 .15247 .65592 .16544 .6751 .15843 .66583 .14523 Mtetra
.658 .749 .917 r
.66583 .14523 .6751 .15843 .69439 .15122 .68522 .13801 Mtetra
.653 .748 .919 r
.68522 .13801 .69439 .15122 .71382 .14404 .70475 .13093 Mtetra
.659 .754 .921 r
.01925 .36814 .03117 .37841 .04645 .37271 .03459 .36236 Mtetra
.658 .754 .921 r
.03459 .36236 .04645 .37271 .0618 .36716 .05002 .35656 Mtetra
.654 .749 .92 r
.05002 .35656 .0618 .36716 .07723 .36164 .06551 .35089 Mtetra
.652 .747 .919 r
.06551 .35089 .07723 .36164 .09278 .35595 .0811 .34526 Mtetra
.654 .75 .92 r
.0811 .34526 .09278 .35595 .10844 .35015 .09679 .3395 Mtetra
.657 .753 .921 r
.09679 .3395 .10844 .35015 .12421 .34421 .1126 .33362 Mtetra
.659 .756 .922 r
.1126 .33362 .12421 .34421 .14007 .33825 .12851 .32762 Mtetra
.66 .757 .922 r
.12851 .32762 .14007 .33825 .156 .33244 .14453 .32155 Mtetra
.658 .752 .92 r
.14453 .32155 .156 .33244 .17202 .32672 .16064 .3155 Mtetra
.653 .746 .918 r
.16064 .3155 .17202 .32672 .18815 .32095 .17682 .3096 Mtetra
.652 .744 .917 r
.17682 .3096 .18815 .32095 .20439 .315 .19311 .3037 Mtetra
.652 .747 .919 r
.19311 .3037 .20439 .315 .22074 .309 .2095 .29776 Mtetra
.655 .75 .92 r
.2095 .29776 .22074 .309 .23719 .30297 .22601 .29169 Mtetra
.656 .751 .92 r
.22601 .29169 .23719 .30297 .25375 .29682 .24263 .28554 Mtetra
.656 .752 .921 r
.24263 .28554 .25375 .29682 .27042 .29065 .25935 .27935 Mtetra
.656 .753 .922 r
.25935 .27935 .27042 .29065 .28718 .2845 .27618 .27312 Mtetra
.27618 .27312 .28718 .2845 .30405 .27835 .29312 .26685 Mtetra
.656 .752 .921 r
.29312 .26685 .30405 .27835 .32103 .27218 .31017 .26054 Mtetra
.656 .751 .92 r
.31017 .26054 .32103 .27218 .33812 .26593 .32733 .25419 Mtetra
.32733 .25419 .33812 .26593 .35533 .25961 .34461 .24779 Mtetra
.34461 .24779 .35533 .25961 .37265 .25321 .36199 .24135 Mtetra
.36199 .24135 .37265 .25321 .39008 .24675 .37949 .23487 Mtetra
.656 .752 .921 r
.37949 .23487 .39008 .24675 .40762 .24026 .39711 .22834 Mtetra
.656 .753 .922 r
.39711 .22834 .40762 .24026 .42528 .23376 .41484 .22177 Mtetra
.41484 .22177 .42528 .23376 .44305 .22728 .43269 .21516 Mtetra
.656 .752 .921 r
.43269 .21516 .44305 .22728 .46094 .22077 .45065 .2085 Mtetra
.657 .751 .92 r
.45065 .2085 .46094 .22077 .47895 .21414 .46874 .20176 Mtetra
.659 .752 .918 r
.46874 .20176 .47895 .21414 .49708 .20748 .48695 .19488 Mtetra
.659 .749 .917 r
.48695 .19488 .49708 .20748 .51533 .20076 .50528 .18794 Mtetra
.658 .746 .915 r
.50528 .18794 .51533 .20076 .53371 .19384 .52373 .18101 Mtetra
.653 .746 .917 r
.52373 .18101 .53371 .19384 .5522 .18687 .54231 .17422 Mtetra
.652 .75 .922 r
.54231 .17422 .5522 .18687 .57082 .17998 .56101 .16744 Mtetra
.653 .755 .924 r
.56101 .16744 .57082 .17998 .58956 .17323 .57984 .16058 Mtetra
.655 .755 .923 r
.57984 .16058 .58956 .17323 .60844 .16646 .5988 .15359 Mtetra
.657 .753 .921 r
.5988 .15359 .60844 .16646 .62744 .15953 .61789 .14646 Mtetra
.659 .752 .918 r
.61789 .14646 .62744 .15953 .64657 .15247 .6371 .13919 Mtetra
.657 .749 .917 r
.6371 .13919 .64657 .15247 .66583 .14523 .65645 .13194 Mtetra
.654 .749 .92 r
.65645 .13194 .66583 .14523 .68522 .13801 .67594 .12482 Mtetra
.653 .752 .922 r
.67594 .12482 .68522 .13801 .70475 .13093 .69557 .11766 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
[(-2)] .12586 .2075 1 .99877 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.56863 .04703 m
.57247 .05235 L
s
[(2)] .56094 .0364 .72324 1 Mshowa
.125 Mabswid
.18558 .19702 m
.18832 .19985 L
s
.23703 .17687 m
.23971 .17975 L
s
.28951 .15632 m
.29214 .15925 L
s
.39772 .11395 m
.40023 .11699 L
s
.4535 .09211 m
.45595 .0952 L
s
.51046 .06981 m
.51284 .07294 L
s
.08568 .23614 m
.08851 .23887 L
s
.62804 .02377 m
.63027 .02701 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 233.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00o?ooool2o`0006[ooooo003iooooo`?o000000?oooooo`000?ooool0
JOooool00?Oooooo0_l00004ooooo`;o0000JOooool00?Cooooo0ol00006ooooo`03o`000?oooooo
000006Sooooo003;ooooo`Go00008_ooool2o`0000Wooooo00?o0000ooooool00000J?ooool00<_o
oooo00GoV9RHob4Q8Oo^k^koooooodA4A00Oooooo`?o00002oooool01?l0003oooooooooool0001W
ooooo`00c?ooool00onHV9So8B4Qonk^kP0Mooooo`?o00003_ooool01Ol0003ooooooooooooooooo
000006Kooooo003=ooooo`03oiRHV?lQ8B7ok^k^01[ooooo0_l0000Aooooo`05o`000?oooooooooo
ooooool00000I_ooool00<kooooo00?oMgMgofIVI_ooool05_ooool3o`0001?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1Sooooo`00coooool00ol0003oooooooooo`0Cooooo`;o
00000_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0H_ooool00<_ooooo00Go0000okZj^_ooooooV9RHoa0@400Booooo`?o00006Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo06;ooooo003;ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`04?ooool2o`0001cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Qooooo`00
gOooool3o`0001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Qooooo`00fooo
ool2o`00027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Pooooo`00f?ooool3
o`0002?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Oooooo`00eOooool3o`00
02Kooooo00?o0000ooooooooool01?ooool2o`00067ooooo003Cooooo`;o0000:Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo05kooooo003@ooooo`?o000000?oooooo`000?ooool0
:?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05gooooo003>ooooo`;o00001Ooo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0GOoo
ool00<_ooooo0ol0000`ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0G?ooool0
0<Wooooo0_l0000cooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Foooool00<Ko
oooo0ol0000eooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Foooool00<Cooooo
0_l0000hooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0F_ooool00<7ooooo0ol0
000jooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03_ooool5o`0004Kooooo002n
ooooo`?o0000?Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00kooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A016ooooo`00_?ooool2o`0000?ooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo1_l00003ooooo`03oiRHV?lQ8B7o
k^k^04Oooooo002iooooo`?o0000@oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00kooooo00?oV9RHob4Q8Oo^k^h0A_ooool00;Oooooo0_l00016ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03oooool00omgMgOoIVIVooooo`15ooooo`00]?ooool3o`0004Sooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Cooooo
002booooo`;o0000Boooool00ol0003oooooooooo`0=ooooo`;o00003?ooool01Ol0003o^[Zjoooo
oonHV9So410@04Kooooo002_ooooo`?o0000COooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c016ooooo`00[Oooool2o`00053ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`1Dooooo`00Z_ooool4o`00057ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1Dooooo`00Z?ooool2o`0000Cooooo00?o0000oooo
ooooool0C_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05?ooooo001nooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h08_ooool3o`0005Oooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`1Booooo`00O_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01oooooo0ol0001Joooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool0D_ooool007kooooo00Go410@oooooooo
oooooooooa0@400Mooooo`;o0000GOooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
057ooooo001nooooo`05o`000?ooooooooooooooool000006_ooool3o`0005oooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`1@ooooo`00O_ooool01Ol0003ooooooooooooooooo0000
01Sooooo0_l0001Rooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0D?ooool007ko
oooo00Go410@oooooooooooooooooa0@400Eooooo`?o0000I?ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo04oooooo001nooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool2o`00
00?ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
04kooooo001nooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04?ooool3o`0006Sooooo00?oYl3/o`00
0?ooool05_ooool00ol0003oooooooooo`1>ooooo`00TOooool2o`0006Sooooo1?nW`>`00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo04gooooo002>ooooo`?o0000J?ooool7ojO0k003o`00
0?oooooooooo01Cooooo0ol0001>ooooo`00Roooool3o`0006Wooooo0_nW_n/7ojO0k003o`000?oo
oooooooo01Kooooo00?o0000ooooooooool0C?ooool008Wooooo0_l0001Yooooo`KoYko[1_nW`>`0
0ol0003oYl3/ooooo`0Gooooo`03o`000?oooooooooo04_ooooo0026ooooo`?o0000J?ooool00onX
_n[oYko[ojNoj`07ojNoj`GoYl3/00?o0000ojNojoooool06?ooool00ol0003oooooooooo`1:oooo
o`00Q?ooool2o`0000;ooooo00?o0000ooooooooool0Hoooool5ojRojPWoYko[0_nW`>`2ojNoj`03
o`000?nW_n_oYko[01Sooooo00?o0000ooooooooool0B_ooool0087ooooo0ol00005ooooo`03o`00
0?oooooooooo063ooooo2?nX_nX7ojNoj`03ojRoj_nW_n_oYko[00;oYko[00Co0000ojNojonW_n_o
Yko[6?ooool00ol0003oooooooooo`19ooooo`00Ooooool2o`0006Wooooo00?oZ<3[ojRoj_nX_nX0
1onX_nX4ojNoj`GoZ;oZ0onW_n/00ol0003oYko[ojNoj`02ojNojaSooooo00?o0000ooooooooool0
B?ooool007cooooo0ol0001Xooooo`GoZ<3[2OnX_nX00onW_n_oZ;oZojRojP06ojRojP;oYko[00Go
0000ojNojonW_n_oYko[ojRojP0Hooooo`03o`000?oooooooooo04Sooooo001jooooo`;o0000Iooo
ool:ojS0j`KoZ;oZ0_nX`>/9ojRojP;oYko[00?o0000ojNojonX_nX00onX_nXHooooo`03o`000?oo
oooooooo04Oooooo001gooooo`?o0000I_ooool>ojS0j`;oZ;oZ1_nX`>/9ojRojP03ojNojol0003o
Z;oZ00GoZ;oZ6?ooool00ol0003oooooooooo`16ooooo`00M?ooool3o`0006Kooooo00?oYl7/ojS0
jonX`>/05onX`>/6ojRojP;oZ<3[00?oZ;oZo`000?nX_nX01OnX_nXHooooo`03o`000?oooooooooo
04Kooooo001booooo`;o00000_ooool00ol0003oooooooooo`1Rooooo`CoYl7/6OnX`>/2ojRojPKo
Z<3[00?o0000ojRoj_nX_nX01OnX_nXHooooo`03o`000?oooooooooo04Gooooo001_ooooo`?o0000
Ioooool7ojO1k0OoZ<3[00?oYl7/ojS0jonX`>/03OnX`>/00onW`>_oZ<3[ojS0j`06ojS0j`03o`00
0?nX_n[oZ;oZ00CoZ;oZ00?oZ<3[ooooooooool05_ooool00ol0003oooooooooo`15ooooo`00KOoo
ool2o`0006Oooooo2_nW`N`4ojS0j`GoYl7/2onX`>/5ojO0j`OoZ<3[00Co0000ojS0jonX_n[oZ;oZ
1OnX`>/Gooooo`;o0000A_ooool006[ooooo0ol0001Vooooo`koYl7/00?oZ<3[ojO1k?nW`N`01_nW
`N`7ojS0j`03ojO1k?nW`>_oYl3[00KoYl3[1_nX`>/00ol0003oYl3[ojS0j`07ojS0jaSooooo00?o
0000ooooooooool0@oooool006Sooooo0_l0001Vooooo`;oY[o/3_nW`N`2ojK0k0SoYl7/1?nX`>/5
ojO1k0SoYl3[0_nX`>/3ojO0j`03o`000?nW`>_oYl3[00SoZ<3[5oooool00ol0003oooooooooo`13
ooooo`00IOooool3o`0006Gooooo1_nV_n`:ojO1k0KoY/3/2?nW`N`00onX`>_oYl7/ojO1k006ojO1
k0KoYl3[00?oYl7/ojO0jonW`>/00onW`>/01?l0003oYl3[ojO0jonW`>/7ojS0jaSooooo00?o0000
ooooooooool0@_ooool006?ooooo0_l0001Uooooo`03ojNnj_nV_ncoY[o/00OoY[o/1_nW`N`00onV
_n_oY/3/ojK0k007ojK0k0KoYl7/00?oY/3/ojO1k?nW`N`01onW`N`4ojO0j`CoYl7/1OnW`>/01?l0
003oYl3[ojO0jonW`>/7ojS0jaSooooo00?o0000ooooooooool0@Oooool0063ooooo0ol000000ooo
oooo0000ooooo`1Rooooo`CoYkkZ2OnV_n`2ojO1k0GoY[o[2OnV`>`2ojO1k0GoY/3/2OnW`N`00onW
`>_oYl7/ojO1k005ojO1k0CoYl3[00Co0000ojO0jonW`>_oYl7/2?nX`>/Gooooo`03o`000?oooooo
oooo047ooooo000fooooo`Go00008oooool2o`0006Kooooo1onW_^X7ojJok003ojRnj_nV_n_oY[o[
00KoY[o[1_nV`>`2ojNnj`SoY/3/1_nW`N`2ojK0k0SoYl7/1?nW`>/00ol0003oYl7/ojO1k002ojO1
k0SoZ<3[5oooool00ol0003oooooooooo`10ooooo`00=_ooool01OnHV9So8B4Qonk^k_ooooooA4A4
023ooooo0ol0001Uooooo`;oZ;kZ2?nW_^X4ojJok0GoZ;kZ2?nV_n/2ojK0k0KoYkk[2?nV`>`2ojO1
k0KoY/3/2?nW`N`01?nW`>_oYl7/ojO1k?l00005ojO1k0KoZ<3[00?oYl7/ooooooooool05_ooool0
0ol0003oooooooooo`0oooooo`00;_ooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h07_ooool3o`00
06Gooooo1_nX_^X8ojNnjP03ojJok?nX_^[oZ;kZ00KoZ;kZ1_nV_n/00onX_n[oYkk[ojNnj`07ojNn
j`KoY/3/00?oYkkZojK0k?nV`>`01onV`>`6ojO1k005ojK0k?nW`NcoYl7/ojO1k?l000001OnW`N`4
ojS0j`CoYl7/5oooool00ol0003oooooooooo`0oooooo`00>?ooool00onHV9So8B4Qonk^kP0Koooo
o`;o0000IOooool2ojRojPSoZ;kZ1_nW_^X2ojRojPSoZ;kZ1?nV_n/4ojRojPWoYkk[0_nV`>`5ojNn
jPWoY/3/0_nW`N`5ojK0k0;oYl7/00?o0000ojO1k?nW`N`01?nW`N`00onX`>_oYl7/ojO1k005ojO1
k1Oooooo00?o0000ooooooooool0?_ooool003Wooooo00?oMgMgofIVI_ooool05oooool3o`0006Co
oooo1_nX_nX8ojRnjP;oYkkZ1_nX_nX8ojRnjP03ojJojonX_n[oZ;oZ00GoZ;oZ1onW_^/00onX_n[o
YkkZojNnjP06ojNnjPKoY/3/0_nW_^X8ojK0k003ojO1k?l0003oYl7/00?oYl7/0_nV`>`8ojO1k1So
oooo00?o0000ooooooooool0?Oooool003[ooooo00?o0000ooooooooool05?ooool2o`0006Cooooo
00?oZ<3[ojRoj_nX_nX01onX_nX6ojRnjP03ojS0jonX_n[oZ;oZ00OoZ;oZ1_nX_^X00onY`>_oZ;oZ
ojRojP07ojRojPCoYkk[1?nX_nX8ojNnjP;oY/3/1_nW_^X8ojK0k003o`000?nW`NcoY/3/00GoY/3/
2?nW`N`Gooooo`03o`000?oooooooooo03gooooo000fooooo`05o`000?nj^[[ooooooiRHV?l@4100
4oooool3o`0000;ooooo00?o0000ooooooooool0Goooool4ojS0j`WoZ;oZ0_nX_^X5ojS0j`WoZ;oZ
0_nX_^X5ojW0j`WoZ;oZ00?oYkk[ojRoj_nX_nX01OnX_nX6ojNnjP03ojVoj_nW_^[oYkkZ00OoYkkZ
1_nV`>`00onW_^_o0000ojK0k007ojK0k0KoYl7/00?oY/3/ooooooooool05_ooool00ol0003ooooo
ooooo`0looooo`00=_ooool01OnHV9So410@o`000?lQ8B7oc<c<017ooooo0_l0001Uooooo`OoZ<3[
1onX_nX00onW`>_oZ<3[ojS0j`06ojS0j`KoZ;oZ0_nX`>/8ojW0j`KoZ;oZ0_nX`>/8ojRojPCoYkkZ
1?nY_nX9ojNnjP;oY/3/1?nW_^/00ol0003oY/3/ojK0k007ojK0k0;oYl7/1OnV`>`Fooooo`?o0000
?Oooool004Wooooo0ol0001Uooooo`[oZ<3[1?nX_nX4ojO0j`SoZ<3[0_nX_nX6ojS0j`SoZL3[0_nX
_nX6ojS0j`SoZ;oZ00?oYkkZojVoj_nY_nX01OnY_nX7ojNnjP03ojVoj_nW_^_oYkk[00CoYkk[00?o
0000ojNnjonV`>`01OnV`>`2ojJnj`SoY/3/5oooool00ol0003oooooooooo`0kooooo`00Aoooool2
o`0006Gooooo3_nX`>/00onX_n[oYl3[ojO0j`05ojO0j`KoZ<3[00?oYl7/ojS0jonX`>/01onX`>/6
ojW0j`03ojO0jonX`>_oZ<3[00OoZ<3[1_nX_nX00onX`>_oZKoZojVojP06ojVojPCoYkkZ1OnY_nX5
ojNnj`03o`000?nW_^_oYkk[00;oY/3/1_nV_^/8ojK0k1Oooooo00?o0000ooooooooool0>_ooool0
04Cooooo0ol0001Tooooo`03ojO0jonX`>_oZ<3[00coZ<3[0_nW`>`8ojO0j`CoZ<3[1?nW`N`9ojS0
j`;oZL3[1OnW`>/9ojS0j`;oZ;oZ1OnX`>/8ojVojP03ojNnj_nY_n[oZKoZ00KoZKoZ1?nW_^/00ol0
003oYkk[ojVojP09ojJnj`KoY/3/00?oY[o[ooooooooool05_ooool00ol0003oooooooooo`0ioooo
o`00@Oooool3o`0006Cooooo1OnW`>/:ojS0j`KoYl3/2?nW`>/00onX`>_oYl7/ojO1k005ojO1k0Oo
Z<3[2OnW`>/6ojS0j`;oYl3/2?nX`>/6ojVojP;oZ<3[2OnY_nX2ojNnj`03ojVoj_l0003oZKoZ00;o
ZKoZ2OnV_^/2ojK0k0GoY[o[5oooool00ol0003oooooooooo`0iooooo`00?oooool3o`0006?ooooo
00?oYl3/ojO0jonW`>/01_nW`>/6ojS0j`;oYl3[2?nW`>`8ojO0j`SoYl7/1?nX`>/<ojO0j`;oZ<3[
1_nW`>`8ojS0j`;oZKoZ1_nX`>/7ojVojP05ojS0jonY_n[oZKoZojVoj_l000001?nY_nX6ojJnj`;o
Z;oZ2?nV_n/Gooooo`03o`000?oooooooooo03Sooooo000looooo`?o00000oooool00ol0003ooooo
ooooo`1Nooooo`CoYl3/2?nW`>/2ojS0j`KoYl3[2?nW`>`8ojO0j`SoYl7/00?oZ<3[ojO0jonW`>/0
2onW`>/2ojNoj`SoYl3/1_nX`>/00onW`NcoZ<3[ojS0j`07ojS0j`CoZKoZ1?nX`>/2ojVojP03o`00
0?nY_n[oZKoZ00?oZKoZ0_nV_^/6ojRojPSoY[o[5_ooool00ol0003oooooooooo`07ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0;?ooool003[ooooo0_l0001Uooooo`OoYl3/1_nW`>/2ojNnjPSoYl3[
1_nW`>`00onW_>WoYl3[ojO0j`07ojO0j`KoYl7/00?oYkgYojO0jonW`>/02OnW`>/6ojNoj`SoYl3/
0_nX`>/5ojO1k0WoZ<3[00?oZKoZojS0jonX`>/01OnX`>/00onY_n[o0000ojVojP03ojVojP03ojW1
jonX_n[oZ;oZ00OoZ;oZ1_nV_n/00onW_n_oooooooooo`0Eooooo`03o`000?oooooooooo00Kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0/ooooo`00=oooool3o`0006Gooooo2_nW`>`2ojO0j`KoYkkZ
2?nW`>/2ojO0k0GoYkcY2OnW`>/2ojO1k0GoYkgY1onW`>/00onW^NKoYko[ojNoj`07ojNoj`KoYl3/
00?oYkkZojO1k?nW`N`01_nW`N`6ojS0j`;oYl3/2?nX`>/2ojVojP03o`000?nY_n[oZL7[00?oZL7[
2OnX_nX2ojJoj`GoYko[5oooool00ol0003oooooooooo`05ooooo`05oa0@4?ooooooooooooooool@
4100;?ooool003Gooooo0_l0001Uooooo`coYl3/00?oYk_XojNnj_nW_^X01onW_^X6ojO0j`03ojNg
i?nW_>WoYkcY00KoYkcY1_nW`>/2ojNfi0SoYkgY1?nW`>/4ojNiiPWoYko[0_nW`>`5ojNnjPSoYl7/
0_nX`>/6ojO0k0SoZ<3[00?oZKoZo`000?nY`N/01OnY`N/6ojRojP;oZL3Z2?nW_n/Fooooo`03o`00
0?oooooooooo00Gooooo00Go0000ooooooooooooooooo`00000/ooooo`00<_ooool3o`0006Cooooo
00?oYl3[ojO0k?nW`>`02_nW`>`4ojNkj0WoYkkZ0_nW`>/5ojNgi0SoYkcY0_nW`>/6ojNfi0SoYkgY
00?oYl3[ojNii_nW^NH01OnW^NH7ojNoj`03ojRhi?nW_^[oYkkZ00KoYkkZ1_nW`N`00onW_^[oYl3/
ojO0k007ojO0k0KoZ<3[00?oYl3[ojW1jol000001onY`N/2ojRojPKoZL3Z2?nW_n/Fooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000/ooooo`00<?ooool2o`0006Cooooo
1OnW`>/9ojO0k0OoYk_X1onW_^X00onW/^3oYkOTojNgi006ojNgi0KoYkcY00?oZK;NojNfi?nW]^@0
1onW]^@6ojNmj@03ojVch?nW^NKoYkWV00KoYkWV1?nW_n/5ojRhi0SoYkkZ0_nW`N`5ojNnjPWoYl3/
0_nX`>/5ojO0j`03o`000?nY`N_oZL7[00CoZL7[00?oZ<3[ojW0j_nY`>X01_nY`>X6ojNoj`;oZKoZ
5oooool00ol0003oooooooooo`03ooooo`05oa0@4?ooooooooooooooool@4100;?ooool002gooooo
0ol000000ooooooo0000ooooo`1Pooooo`WoYl3[1_nW`>`2ojNhiPSoYk_X1?nW_^X4ojNbh0SoYkOT
0_nW_>T5ojVbgPWoYkKT0_nW_NT5ojVch0SoYkWV00?oYko[ojRhi?nX^>@01_nX^>@6ojNnjP03ojRg
i?nW_^[oYkkZ00KoYkkZ1_nW`>`2ojNoj`OoYl3[00?o0000ojW1jonY`N/00_nY`N/4ojS0j`SoZL3Z
0_nW_n/6ojVojQKooooo0_l00004ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0;?ooool002[ooooo
0ol0001Sooooo`goYl3[0_nW`>`6ojNhiPSoYk_X00?oYkkZojNbh?nW/^001OnW/^06ojNgi003oj^_
fonY/]koZK;N00KoZK;N1onW]^@00on]/M_oZK?PojVch006ojVch0KoYkWV0_n//mh9ojRhi0;oYkkZ
1OnX]n@8ojNnjP;oYl3/1_nW_n/6ojO0j`03o`000?nW`>_oZL7[00OoZ<3[1_nY`>X00onX`>_oZKoZ
ojVojP07ojVojQ?ooooo0_l000000ooooooo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h0;?ooool002Sooooo0_l0001Sooooo`ooYl3[0_nW]^@8ojNhiPKoYk_X00?oZ;3MojNbh?nW/^00
1_nW/^04ojNgi0CoZjoK2?nY/]h4ojNfi0Co[K7K2?nY/n02ojNiiPKo[;?N1onX^>@00on^]=goZ;OT
ojRgi006ojRgi0KoYkkZ00?oZ;STojNojonW_n/01onW_n/5ojO0j`03o`000?nW`>_oZ<3[00OoZ<3[
1?nY`>X4ojS0j`WoZKoZ5_ooool00ol0003oooooooooo`0booooo`009Oooool3o`0006;ooooo3onW
`>/6ojNfi0SoYkSV0_nW^nP5ojR`g@SoYk;P00?oYkOToj^_fon[[m/01On[[m/8ojVbgP03ojNfi?n]
/M_o[K7K00Go[K7K1_nY/n000on_/=Wo[;?NojbcgP07ojbcgPCoZ;ST1?n^]=d8ojRgi0;oYkkZ1OnX
^>@9ojNoj`?oYl3[0_l00002ojO0j`SoZ<3[00?oZL3ZojS0jonX`>/01OnX`>/6ojVojP;oZL7[5_oo
ool00ol0003oooooooooo`0booooo`008oooool2o`0006;ooooo3onW`>/00onW]>;oYkKTojNfi007
ojNfi0KoYkSV00?oZJkLojR`gOnX/=d01_nX/=d6ojNbh003oj^]f?n[[m_oZjoK00KoZjoK1onY/]h0
0on^[]So[K7Kojfaf`06ojfaf`CoZK?P1?n_/=T9ojbcgP03ojRhi?n^]=go[[CM00Go[[CM1_nX]n@0
0on_]]goZ;STojRhi006ojRhi0KoYko[0_nX^^H3o`000003ojO0jol0003oYl3[00;oYl3[1_nX`>/0
0onW`NcoZ<3[ojS0j`07ojS0j`;oZKoZ1_nY`N/Fooooo`03o`000?oooooooooo037ooooo000Poooo
o`?o0000H_ooool>ojO0j`GoYkCR2OnW]^@2ojNhiPGoZJkL1onX/=d4ojNbh0CoZjgH2?n[[m/4ojVb
gPCo[ZkH2?n]/M/00onY/n3o[k3Iojn`f@05ojn`f@Oo[;?N00?o/K7HojjdgOn^]=d01_n^]=d4ojRg
i0Co[kKM2?nX^>@2ojNoj`;oZ;[V0ol000000onX^^KoYl3[ojO0j`02ojO0j`04o`000?nW`>_oYl3[
ojO0j`;oZ<3[1OnW`N`7ojS0j`03ojO0jonY`N_oZL7[00KoZL7[5oooool00ol0003oooooooooo`0`
ooooo`007oooool2o`0006;ooooo3OnW`>/00onW/n;oYkCRojNdhP06ojNdhPOoYkKT00?oZ:cJojV^
g?nY[]`01_nY[]`7ojR`g@03ojNbh?n[[MSoZjgH00GoZjgH2?n[[m/00onY/]ko[ZkHojj^f005ojj^
f0Ko[K7K00?o/;3Gojn`fOn_/=T01_n_/=T4ojbcgPGo/K7H2?n^]=d00onX]nCo[kKMojnfg@05ojnf
g@KoZ;ST00?o[kOOojRji_l000000_l00004ojRjiPGoYl3[00?o0000ojNmjOnW_NT02?nW`N`4ojS0
j`CoYl3[2?nY`N/Fooooo`03o`000?oooooooooo033ooooo000Oooooo`03o`000?oooooo000005oo
oooo3?nW`>/5ojNchPSoYkCR1?nW]^@4ojR/fPOoZJkL1_nX/=d00on[ZmOoZjgHoj^]f007oj^]f0Ko
ZjoK00?o[ZkGojj^f?n^[]P01_n^[]P4ojfaf`Co/;3G2?n_/=T00on//mko/K7Hok6af006ok6af0Ko
[[CM00?o/k?HojnfgOn_]]d01_n_]]d4ojRhi004ojnggol0003o0000o`0000SoZ;[V0_nW`>/3ojNm
j@03o`000?nW_NWoYkgY00SoYl7/00?oZ<3[ojO0jonW`>/01OnW`>/6ojW1j`03ojS0jooooooooooo
01Gooooo00?o0000ooooooooool0;oooool000cooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01_ooool01?l0003oooooooooool0001Kooooo`coYl3[00?oY[?RojNch_nW/n801_nW/n88
ojNdhP03ojNfi?nX[=[oZ:cJ00CoZ:cJ2?nY[]`2ojR`g@GoZj_G2On[[MP2oj^_f`Go[ZkG2?n^[]P0
0on]/M_o/;3Gok2`e`05ok2`e`Ko[k3I00?o];CHok6af?na/MP01ona/MP4ojjdg@Co/k?H2?n_]]d0
1?nX^>Co0000o`000?l00004ojngg`KoZ;[V00?o[[SQojNmjOnW_NT00onW_NT01?l0003oYkgYojNm
jOnW_NT6ojO1k003ojNojonW`>_oYl3[00OoYl3[0_nY`N/5ojS0jaOooooo00?o0000ooooooooool0
;_ooool000cooooo00GoV9RHob4Q8Oo^k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01_ooool2o`0000;ooooo00?o0000ooooooooool0EOooool=ojO0j`CoY[?R2?nW/n86ojNdhP03
ojN[f_nX[=[oZ:cJ00KoZ:cJ1_nY[]`00onZZmOoZj_Goj^[e`06oj^[e`OoZjgH00?o[k7Jojj^eon^
[]L01_n^[]L6ojj^f003ok>efon`/=Oo/;3G00Ko/;3G1?n_/=T4okBdf0Wo/K7H00?o[[CMok>cf?nc
/mP01Onc/mP5ojnfg@?o00002?n_]ml2ojRjiPGo[[SQ1OnW_NT01?l0003oYkgYojNmjOnW_NT2ojO1
k0GoYko[1onW`>/00onW`NcoZ<3[ojS0j`06ojS0jaKooooo00?o0000ooooooooool0;_ooool000Co
oooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4005oooo
o`;o00001?ooool00ol0003oooooooooo`1Aooooo`ooYl3[1_nV/n88ojNchP;oYkCR1OnWZmX7ojR/
fPCoZJkL1?nZZmL8oj^[e`CoZjgH1?n_/MX7ojj^e`Co[ZkH1?nc]M/8ok2`e`03ojn`fOnd]=So];CH
00Go];CH1ona/MP00ong]mWo/k?Hok>cf006ok>cf0;o[kKM0ol00003okBdf@Oo[kOO00?o]KOJojjh
hOn^^>401_n^^>45ojNmj@03o`000?nZ^NCoZ[WT00SoYko[1?nW`>/4ojO1k0SoZ<3[5_ooool00ol0
003oooooooooo`0]ooooo`003_ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooooooooooo
ool000001Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04gooooo0_nW`>`>ojO0
j`03ojJdhonV/n;oY[?R00KoY[?R1_nW/n800onVZ][oYj_JojN[fP06ojN[fPOoZ:cJ00?oZJkLojZ[
eonZZmL01OnZZmL8oj^[e`03oj^]f?n_/M[o[k7J00Co[k7J2?n^[]L00on^[]So/kGKok>ef`04ok>e
f`Oo/;3G00?o][kPokBdf?nd]=P01_nd]=P6ok6af0?o]kOI1onc/mP2o`0000Oo];CI1On_]ml3okFg
fPSo[[SQ0_nW_NT2ojZii004o`000?nZ^NCoZ[WTojZii0SoYko[00?oYl3[ojO1k?nW`N`01OnW`N`7
ojS0jaOooooo00?o0000ooooooooool0;?ooool000oooooo00?oMgMgofIVI_ooool00_ooool01Ol0
003ooooooooooooooooo000000Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`19
ooooo`KoYl3/2_nW`>/5ojJdh`SoY[?R0_nW/n85ojJZfPOoYj_J1_nX[=X00onZ[=WoZZ_GojZ[e`06
ojZ[e`OoZj_G00?o[kSOojnaf_n_/MX01_n_/MX6ojj^e`03ok:ohonc]M_o/kGK00Ko/kGK1On`/=L3
okJnh0So];CH0ona/MP5okNgf@Co/k?H0ol000000oni^M[o];CIokBdf@06okBdf@?o[kOO1_ne]mX6
ojjhh@03okBigOnZ^NCoZ[WT00?oZ[WT00?o0000ojZii?nZ^N@01_nW_n/3ojNmj@SoYl7/1onX`>/E
ooooo`;o0000;_ooool0013ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooo
oooo00?ooooo0_l00007ooooo`03o`000?oooooooooo04Kooooo2OnW`>`6ojO0j`03ojJfi?nV]>?o
Y[CS00KoY[CS1_nV/n800onUZ][oYZ[JojJZfP05ojJZfPSoYj_J0_nX[=X5ojZ/f@SoZZ_G1?n[ZmL4
ojnhg`Oo[k7J1?n^[]L4ok:oh`Oo/kGK0on`/=L6okJnh0So];CH00?o/K7HokNgfOng]mT01Ong]mT3
o`0000;o/k?H0oni^MX8okBdf@03ojnggone]m[o]KOJ00Go]KOJ1?n^^>44okBig@GoZ[WT00?o0000
ojZii?nZ^N@00_nW_n/7ojNmj@KoYl7/00?oYko[ojS0jonX`>/01_nX`>/Fooooo`03o`000?oooooo
oooo02_ooooo000<ooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`12ooooo`goYl3/0_nW
`>/5ojJfi0SoY[CS0_nV/n85ojFZfPOoYZ[J1_nWZmX00onX[M[oZZcIojZ/f@06ojZ/f@SoZZ_G00?o
Zj_Gojnhgon_^=l01?n_^=l8ojnafP03ojj^eonb_n?o/[oS00Go/[oS1onc]M/00on`/=Oo][kPokJn
h005okJnh0Oo];CH00?o]lGUokNgfOng]mT00ong]mT3o`0000?o/k?H1_ni^MX6okBdf@03okVjfOne
]m[o]KOJ00Oo]KOJ00?o[[SQokBigOnd^Md01Ond^Md5ojZii003o`000?na^n7oYkgY00WoYkgY0_nW
`N`5ojNoj`SoZ<3[5Oooool00ol0003oooooooooo`0[ooooo`003?ooool01OnHV9So410@o`000?lQ
8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0?_ooool2ojO0j`goYl3/0_nW^>H7ojJfi0KoY[CS00?oY:[KojFZf_nUZ]X0
1OnUZ]X7ojJZfPCoYj_J1?nX[MX8ojZ/f@KoZZ_G00?o[[kVojnhgon_^=l01_n_^=l6ojnafP03ojk9
kOnb_n?o/[oS00Ko/[oS1_nc]M/00on`b^go][kPokJnh007okJnh0Co];CH1?ngaND01?ng]mWo0000
o`000?l00004okNgf@03ok>cf?ni^M[o^KWJ00Go^KWJ1?nd]=T4okVjf@Oo]KOJ00?o^K[IokBigOnd
^Md01ond^Md2ojZii0;o/K_Q00?o0000ok6khOna^n402?nW_NT00on[^nGoYko[ojNoj`06ojNoj`Ko
Z<3[00?oYl3[ooooooooool05?ooool00ol0003oooooooooo`0Zooooo`007_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo03[ooooo1_nW`>/9ojO0k0KoYkSV1onV]^@2ojJdh`GoY:[K
1onUZ]X7ojJZfP03ojN[f_nX[M[oZ:gJ00GoZ:gJ2?nZ[=T2ojZ[e`Go[[kV1on_^=l4ojnafPCo[/W]
2?nb_n<2ok>ef`Go/<[]2Onf_^000ond]=So]lGUokO5i@02okO5i@?o00001_ng]mT00onganOo^KWJ
okVifP07okVifP03okBdfOni^]Wo^K[I00Go^K[I1One]mX3okVjf@Oo];WM00?o^;[Jok6khOna^n40
0ona^n400ol0003o/K_Qok6kh@04ojNmj@GoZk_U2?nW_n/2ojS0j`GoYl3[5_ooool00ol0003ooooo
ooooo`0Yooooo`007Oooool3o`0000_ooooo00?o0000ooooooooool0=_ooool:ojO0j`GoYl3/0_nW
_>P8ojNhiPGoY[KT00?oXj[LojBZfonTZ]/01_nTZ]/6ojFZfPKoYZ[J00?oYjgLojR]f_nX[MX01_nX
[MX7ojZ/f@03ojc4jon^_^Ko[[kV00Ko[[kV1on_^=l00on_/M[o[/W]ojk9k@05ojk9k@Ko/[oS00?o
X]Ciok3:kOn`b^d01_n`b^d6okJnh0;oZLoc0_ngaND3o`0000?o]lGU1?ng]mT4okO7i`Oo^KWJ00?o
^LOUokVjfOni^]T01_ni^]T3okFgfPKo^K[I1Ond^Md3okRjfPGo/K_Q00Co0000ok6khOna^n7oYkgY
1on[^nD6ojNoj`;oYkkZ1onW`>/Fooooo`03o`000?oooooooooo02Wooooo000Mooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool0<_ooool>ojO0j`03ojO0k?nW_>SoYkcX00CoYkcX2?nW
^>H00onV]^CoXj[Loj>Zg003oj>Zg0OoY:[K1onUZ]X2ojJZfPGoYjgL2?nX[MX4ojZ/f@Co[<C[1on^
_^H6ojnhg`;oY]3f2?n^bNd2ok:oh`GoX]Ci2?n`b^d2okJnh0CoZLoc0ol00007okO5i@03okNgfOng
anOo]lOW00Go]lOW1?ni^MX4okW7i@So^K[I00?o]KOJokVjfOni^]T01Oni^]T3okBig@Ko^;[J1Ona
^n400ol0003o]kcNoj^ki@08oj^ki@;oYko[1_nW_^X7ojO0jaKooooo00?o0000ooooooooool0:?oo
ool001gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0_ooooo`03ojNojonW`>_o
Yl3[00coYl3[00?oZ;oZojNlj?nW_>P01_nW_>P6ojNhiP03oj:/g_nSZ]coXj[L00GoXj[L1onTZ]/5
ojFZfP03ojF/g?nW[McoYjgL00KoYjgL2?nX[MX00onZ[=Wo[<C[ojc4j`05ojc4j`Oo[[kV0_n_^=l6
ojK@mPKo[/W]0_nAg?h7oj;Dn@Ko/<[]0onBfOh01?nYco?o0000o`000?l00003ojW?l`Ko]lGU0_nS
dOL8okO7i`03okVif_nianGo^LOU00Go^LOU1_ni^]T00onkaN;o^K[IokVjf@07okVjf@03okBigOnh
^][o^;[J00Go^;[J1?na^n401?ng_=ko0000okNlg_ng_=h7oj^ki@03ok6mhonW_^[oYkkZ00KoYkkZ
1onW`>/Gooooo`03o`000?oooooooooo02Oooooo000Mooooo`;o00003oooool00ol0003ooooooooo
o`0[ooooo`GoYko[2_nW`>/5ojRojPSoYkcX0_nW^>H5oj:/gPKoXj[L2?nTZ]/00onUZ][oYJcLojF/
g003ojF/g0SoYjgL1_nX[MX00onYanoo[<C[ojc4j`06ojc4j`Ko[[kV0_nOfO`8ojK@mP;o[/W]1_nA
g?h7oj;Dn@;o/<[]1OnBfOh2o`0000OoZLoc0_ngaND6oj?Am`Ko]lOW00?oX]3gokW7iOnianD01_ni
anD4okVjf@Co^lGR1oni^]T00onm`Mgo^;[JokRjfP07okRjfP03ok6khOng_=ko]kcN00;o]kcN00?o
0000okNlg_ng_=h01?n[^nD4ok6mh`SoYkkZ1onW`>/Fooooo`03o`000?oooooooooo02Oooooo000M
ooooo`03o`000?oooooooooo00oooooo0_l0000Xooooo`;oY[o[1onW_n/6ojO0j`;oZ<3[1onX_nX6
ojNlj003oj:]gonR[=koXZcN00GoXZcN1onSZ]`6ojBZf`03oj>[g?nU[=coYJcL00GoYJcL2?nW[M`2
ojR]fPGoZLO_2?n/a>/2ojjniPKoWmWl1_nVd?H3ogoMo0OoTMcn0onRe?T5ogCFo0;oT]Wn0ol00003
oi;IoP?oZLoc1On3eol7oj?Am`;o]lOW1OnRd?L8okW7i@03okVjfOnkaN;o^lGR00Go^lGR1?ni^]T4
okg1g@Oo^;[J00?o_;kKokNlg_ng_=h01?ng_=h01?l0003o]kcNokNlg_n[^nD7ok6mh`KoYkkZ00?o
ZKkXojO0jonW`>/01_nW`>/Fooooo`03o`000?oooooooooo02Kooooo000Mooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool08_ooool6ojJoj`OoYko[0_nW`>/6ojS0j`OoZ;oZ0_nW_>P5
oj:]g`OoXZcN1onSZ]`2ojBZf`GoXj_L1onU[=`6ojN]g0;oYlSa1onYanl6ojc4j`?oVMkn1onOfO`2
ojK@mPSoOmgl0onAg?h5ofS@n`CoM=Kl0ol00003oi;IoPGoGlSj1on3eol3oj?Am`CoNm7o1onRd?L6
okW7i@03ojO=lonkaN;o^lGR00Oo^lGR00?o^K[Iokg1gOnm`Md01Onm`Md5okRjfP?o_;kK1_ng_=h0
0ol0003o^[gLok6mh`08ok6mh`;oYkkZ1OnY_^P8ojO0jaKooooo00?o0000ooooooooool09Oooool0
01gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Nooooo`;oY[kZ2?nV_n/5ojNo
j`;oYl3/2?nX`>/5ojRojP03oj>ah_nR[MooXZgO00KoXZgO1_nR[=h6oj>Zg003oj6XfonSZmcoXj_L
00KoXj_L1onU[=`2ojN]g0KoYlSa1onYanl2ojc4j`OoVMkn0onOfO`6ogGJn@CoOmgl1_medOh3ofS@
n`?oP<[o0ol00006ofW7oPKoGlSj0on3eol5oe[1n`KoNm7o1onRd?L2okW7i@GoYlgc1onkaN800on`
b^go_L7Mokg1g@06okg1g@?o^;[J1_nl_]/4okNlgP04okZmg?l0003o^[gLokZmg0Oo/KgS00?o][oQ
ojVnj?nY_^P01_nY_^P6ojO0j`03ojNojooooooooooo01Cooooo0_l0000Vooooo`007?ooool3o`00
01Cooooo00?o0000ooooooooool06_ooool6ojJnjPSoY[o[00?oYko[ojO0k?nW`>`01?nW`>`8ojS0
j`03ojRoj_nS/N;oXk7R00?oXk7R2?nR[Ml6oj:/gP;oXj[L1OnQZ=/7oj>[g0KoYJcL2_nWb?43ojW7
k`KoUN7m1?nIg_h5ogcLn`CoMM[i1_n5d_l3ogGAoPGoTlOi00CoP<[oo`000?l0003o00000on0b_l3
ofW7oPGoR/?j1_m/`Oh7oe[1n`KoNm7o0onRd?L4ogk?o`OoYlgc1?nkaN84ok3:k@So_L7M00?o^;[J
okbnfonl_]/01_nl_]/00ong_=ko^[gLokZmg002okZmg003o`000?nj_Mco^[gL00Co/KgS1?nf_n48
ojVnj0;oYl3[1OnW_n/Dooooo`03o`000?oooooo000002Kooooo000Looooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool05oooool2ojNnj`OoY[kZ1_nV_n/00onW`>_oYl3/ojO0k006ojO0
k0KoZ<3[00?oYKKUoj>ah_nS/N801OnS/N88oj:]g`?oXZcN0_nOY]/8oj6Xf`OoXj_L0_nU[=`<ojO8
l@?oU^?m1onEhOd4ohKOo0?oO=ck1OnDe?d6ohGBo`;oWL3a1OnCaoT3o`0000?oP<[o1?nJ^nl8oh[3
nPKoK<7n0omJ`O/5ofblo@KoEk_k1_mncol7ojO=l`03ok_5h_n`b^go/<[]00Go/<[]1_nm`Md00oni
b>Go_;kKokbnf`06okbnf`03okk3gOnj_Mco^[gL00Co^[gL00Co0000okZmg?nj_Mco/KgS1onf_n46
ojVnj003ojbnionW_n_oYko[00KoYko[5_ooool00ol0003oooooooooo`0Sooooo`002_ooool4o`00
0008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h6ooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool04oooool6ojNnj`OoY[kZ0_nV_n/5ojO0j`SoYl3/0_nX`>/5ojFfi@OoXk7R
1_nR[Ml7oinVf`OoXJSK1_nSZm`3ojK6l0WoYlSa2?nFhod2oiGQo@KoQ]ol0_nLd_/8oiCDo@;oQM;o
1_nM`?401?nCaoWo0000o`000?l00002oi?7n@03ojBgi_nJ^nooV[__00KoV[__1_n:`oX00onO]nWo
S;cfohblmP06ohblmPOoK;cm1_mG^o/6ogk?o`?oYlgc1?n;coh7ok3:k@Co_L7M1?nib>D6okbnf`?o
_/?M1Onj_M`00ol0003o^[gLokg0g009okJoh@;oZKkX1On/_^L8ojNojaGooooo00?o0000oooooooo
ool08oooool000cooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Ko
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0?ooooo`;oZ<3[2?nW_^/5ojJnjPWo
Yl3[1_nW`>`2ojNlj@OoYKKU1onS/N82oj:]g`_oWjKK1onQZ=/2oj>[g0OoY/K`1OnWb?43oiWTo@Oo
U^?m1?n?h_d2ohKOo0KoW=;k1_nDe?d2oj:kj`GoWL3a0ol00002oi?7n@GoY;OV2?nJ^nl2oh[3nPGo
WkOY2?n<_?H3ofblo@CoRk[e1omW]o`5oeJhn`OoRlon1on`b^d00onm`Mgo^LSUokW8i@05okW8i@?o
_;kK1_nn`md5okZmg003o`000?nm`=co_L3L00Oo][oQ00?o^L7Pojbnion/_^L01On/_^L8ojNojaKo
oooo00?o0000ooooooooool08_ooool00003ooooool0003o000000Co00001Oooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool2o`0001Wooooo00?o0000oooooooo
ool02oooool6ojS0j`SoYkk[00?oY[kZojO0jonW`>/02onW`>/2ojO0k0KoYkcY1_nU]^D6oj>ahP03
oijWg?nOY]_oWjKK00coWjKK1OnQZ=/2ojG1kPWoY/K`00?oYlSaoiWToOnIi?d01_nIi?d2oiKSo@Ko
Sn;m0onRdOP7oicBn`;oU=Cm1_nR^n/2oig0l@;o00000_nM`?400onY]^?oY;OVojBgiP06ojBgiPKo
V[__00?oZ[OSoingjOnO]nT01_nO]nT6ohblmP;oXKOX1on;^_D7ofNgo0GoE[Sk1on;coh3ok3:k@Co
Vl_h2?nib>D00onl_]_o_/?Mokk3g@05okk3g@?o^[gL0onm`=`00ol0003o_L3Lokg0g004okJoh@Co
^L7P1on/_^L8ojNojaKooooo00?o0000ooooooooool08Oooool000cooooo00?o0000ooooooooool0
0_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`08ooooo`;oZ<7/1onX`>/6ojNnj`03ojJojonW`>_oYl3[00_oYl3[0_nX`>/8ojNlj@Ko
YKKU0_nS/N85oijWg0koWjKK00?oXJSKojG1k_nU`Nh01?nU`Nh7ojK6l0?oWNCl1_nIi?d4oiOUo0;o
Sn;m1onRdOP5oicBn`;oY[WW1_nR^n/3o`000003oig0lOnY]^?oZKKS00?oZKKS2?nT]nH2oiZkk`Go
Z[OS2?nO]nT2ohblmPKoXKOX1on;^_D3ofNgo0CoPkSg0omM/O/2oeJhn`?oRlon1?mU_Od7oi_;n0Ko
^LSU00?o[LS^okk3gOnn`md01onn`md00onj_Mco_L3Lokg0g003okg0g004o`000?nm`=co_L3LokJo
h@Ko^L7P1_n/_^L2ok30iPSoYko[5Oooool00ol0003oooooooooo`0Qooooo`003?ooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo00Gooooo1OnX`N`7ojS0j`;oYkk[1OnV_n/9ojO0j`KoZ<3[2?nW_>T3ojFf
i@;oWZ[O1onNYm`=oinVf`03oj>jj_nU`NkoYL7^00KoYL7^1?nVa_06oigTo0;oVNCm1_nGiO`3ojGB
m`SoX]7h00?oW=;kojJiionV^NL01?nV^NL2oj:kj`?o000000?oX[_[ojVfh_nY]^<01onY]^<6ojBg
iP03ojbhh_nZ]n?oZ[OS00KoZ[OS1_nO]nT00on/^N;oXKOXoj6gj007oj6gj0?oRk[e1?nO]nT7oh>h
m`KoGK7k1_mU_Od7oi_;n0;o^LSU1On]b>h7okk3g@03okc7honm`=co_L3L00Co_L3L00?o0000okg0
g?no`md02?ni`N02ojbni`Ko/<3V1onW_n/Fooooo`03o`000?oooooooooo023ooooo000<ooooo`03
o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool00_ooool8ojS1k0GoZ<3[0_nV_^/7ojJoj`KoYl3[0_nW`N`7ojS0
j`KoYkcY00?oWjkRoijZgonNZ]l01?nNZ]l7oijWg0WoWjKK1OnS^^X8ojG1kP03ojK6l?nMi?coWNCl
00GoWNCl1?nMj?/2oiOUo0OoYM;g1_nRdOP00onW^>GoY[WWojJii`04ojJii`?o00000_nR^n/4ojVf
hPSoZKKS0_nT]nH5ojbhhPSoZ[OS0_nO]nT5ojbihPOoXKOX00?o[[[SoingjOnO]nT01_nO]nT7oh>h
m`KoGK7k1_mU_Od3oi_;n0?oPLGm2?n]b>h4okk3g@Co_<OS1_nm`=`00ol0003o_l?Moko3g@06okW1
h003ok_2gon``>Ko/<3V00Oo/<3V1onW_n/Fooooo`03o`000?oooooooooo01oooooo000<ooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o00007_ooool00ol0
003oooooojS1k00:ojS1k003ojS0jonV_^_oY[k[00CoY[k[1onV_n/2ojO0j`KoYl7/1onX`>/2ojNl
j@GoWjkR1_nNZ]l6oijWg0KoWjKK0_nO/^D7oj>jjPKoYL7^1?nShO`2oigTo0OoWNSk0_nXe_L8ojGB
m`;oX]7h1OnW^>D2ojJii`?o00000onV^NL00onR^n_oZKKRojVfhP04ojVfhPKoZKKS2On/^>86ojZg
h`03ojjjh_n/^N;o[;WR00Ko[;WR1?nQ]nP4ojjjh`SoWkOY0on3^?L4oiNgk@OoLkCi1OmF[_X6oh75
o@So[LS^00?o_/?Mokc7honlan<01Onlan<3okg0g0?o_l?M00?o0000oko3gOni`N001?ni`N03ok_2
g`Oo/<3V00?o//;VojNojonW_n/01_nW_n/Eooooo`03o`000?oooooooooo01oooooo000:ooooo`03
oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo
01cooooo3OnX`N`2ojNoj`OoY[k[1OnV_n/2ojO0j`SoYl7/1OnX`>/00onS]NGoWjkRoin^hP06oin^
hPKoWZ[O1_nNYm`2oinVf`KoWk;U1onS^^X2ojG1kPOoXn7l1?nRjoX2oigXn`KoZ=Kg1_nUd_L7ojNh
i@?o00001OnV^NL9ojVfhP?oZKKS3?n/^>82ojZgh`Go[[[R2?n/^N800onQ]nSo[[[Sojjjh`05ojjj
h`KoWkOY00?o[K_ToiNgkOnG]nd01_nG]nd7og>dn@GoEZkj1_n1aOd6ojg8kP03oig6m?nlan?o_<OS
00Oo_<OS00?o_L3Loko3gOno`md00ono`md01?l0003o^L7PokW1h?ni`N06ok_2g`Co/<3V1?nb`^H8
ojNojaGooooo00?o0000ooooooooool07_ooool001_ooooo00?o0000ooooooooool06_ooool3ojS0
j`WoZ<7/1_nW_n/7ojJnj`03ojJojonW`>_oYl3[00CoYl3[2?nW`N`00onX`>_oXkGUoj>ei@03oj>e
i@OoWjkR1onNZ]l3oijWg0?oW:[P2?nO/^D5oj>jjPCoYm_j0onShO`6oj;[nP?oZm_h1onXe_L2ojGB
m`OoYkSU0ol00003ojNhi@;oY[WW3OnY]^800onY]^?o[;SRojbhhP0:ojbhhP03ojfli?n^^^;o[[[R
00Ko[[[R1_n/^N800on_^n;o[[[Sojjjh`07ojjjh`;oWkOY1On]^n@8oiNgk@?oLkCi0on7]O<4of2/
n@;oEZkj1_n1aOd2ojg8kPGoWLKd1onlan<00ondanSo_l?Moko3g@04oko3g@03o`000?no`mgo^L7P
00So^l;O00?o/<3Vok;2i_nb`^H01Onb`^H6ojNoj`03ojO0jooooooooooo01Cooooo00?o0000oooo
ooooool07Oooool001_ooooo00?o0000ooooooooool05oooool7ojS0j`GoZ<7/0_nX`N/8ojNoj`Go
Y[k[0_nW_n/7ojO0j`KoYl7/00?oY[gYoj>eiOnS]ND01OnS]ND7oin^hP?oWZ[O0onJYMd7oibZh0So
Wk;U00?oXk[ZojOKn_nWfoX01OnWfoX4ojO]n@;oX^_j1on[foP5ojSFm`;oYk[V1OnW^>D3o`0000Go
YkSU00?oZ;KRojVfh_nY]^803?nY]^800on[^NCo[;SRojbhhP09ojbhhPCo[KcT2?n^^^82ojbihPGo
[k_R1on^^^<00on`_>?o[K_Tojfki006ojfki0KoUkO]00?oYk[WohNelon7]O<01On7]O<6of2/n@Ko
I[Kl1onMa_@4okc7h`Co]<OX1_no`md00ol0003o^l;Ook_2g`06ok_2g`03okk5h?nb`^Ko//;V00Oo
//;V0_nW_n/5ojO0jaCooooo0_l0000Oooooo`006oooool2o`0001Kooooo0onW_n/7ojS0j`03ojS1
k?nX`N_oZ<7[00CoZ<7[2?nW_n/00onV_^_oYko[ojNoj`04ojNoj`OoYl3[0_nW`N`5ojJmj@OoXkGU
1OnO[^800onJY]koVZGMoiZUg@05oiZUg@OoW:[P1_nO/^D3ojSAm@CoYm_j1OnWkOT3ojoPn0SoZm_h
00?oZ=KgojNji_nW^^H01?nW^^H2ojNhi@;o00001OnW^>D5ojRfhP[oZKKR1On[^N@8ojbhhPOo[KcT
1_n^^^800on__nKo[k_RojnkhP06ojnkhPCo[[[S1?n`_><8ojfki0;oUkO]1OnW^^L7ohNel`KoH:ci
1_mV]_`7oig6m003okc7hondanSo]<OX00Co]<OX1?no`md3ol35gP03o`000?nk`]oo^l;O00Co^l;O
0onnaN07ok;2iP03okC4i_nW`>_oYl3[00GoYl3[5_ooool00ol0003oooooooooo`0Looooo`006_oo
ool00ol0003oooooooooo`0Cooooo`OoYko[1OnX`>/2ojS1k0OoZ<7[1_nW_n/00onV_^_oYko[ojNo
j`06ojNoj`GoYl3[0onX`N/6ojJmj@OoXkGU00?oWjkRoiZVg_nJY]h00onJY]h7oiZUg@OoW:[P0_nO
/^D7ojSAm@03ojOKn_nWkOWoYngi00?oYngi1_n_h?P6oj_Kn003ojVmj?nW^^KoYk[V00CoYk[V0ol0
0004ojNhi@03ojNehonX]^;oZ;KR00KoZ;KR1_nY]^800onZ^^GoZkWToj^ii006oj^ii0Go[;SR0_n/
_^L7ojfli0Co[[[R1?n__nH8ojnkhP03ojjjhon`_>?o/;cS00Go/;cS1_n]^n@00ona_^?oYk[WojNj
i`06ojNji`?oQkGc1?nG]nh6ofn_m`CoFJWi0_mV]_`3oig6m0?oS/;i2?ndanP00ono`mgo`<GNol35
gP04ol35gP04o`000?nk`]oo^l;Ook_2g`Ko_/GP1?nb`^H4okC4iPOoYl3[5Oooool00ol0003ooooo
ooooo`0Looooo`006_ooool00ol0003oooooooooo`0?ooooo`CoY[o[2?nW_n/00onX`>_oZ<7/ojS1
k004ojS1k0OoZ<7[0_nW_n/5ojJnj`SoYko[00?oYl3[ojS1jonX`N/01OnX`N/6ojJmj@?oXkGU0onK
Z^47oiZVgPKoVZGM1_nLZ^03ojK7l0KoZ=7e1?n/k?T2ojO]n@So[n3h0_n[foP5ojVmj0;oYk[V0ol0
0003ojNjiP03ojNhiOnW]N?oYkGS00?oYkGS2?nX]^82ojVfhPGoZ[[U2?n[^N@00on/^>;o[;kWojbn
i`04ojbni`Oo[KcT00?o[[[Rojnoi_n__nH01On__nH6ojnkhP03ok30i_n`_>?o/;cS00Oo/;cS0_n]
^n@5ok6nh`KoYk[W00?o[kkUoiNgk_nG]nh01_nG]nh6ofn_m`GoFJWi1on>`_T6okC7j003ojc5k?o0
aMko`<GN00Go`<GN00?o0000ol35g_nk`]l02?nnaN000onb`^Ko]<CVokC4iP04okC4iPKoYl3[0_nX
`>/Eooooo`03o`000?oooooooooo01_ooooo000Jooooo`03o`000?oooooooooo00_ooooo0_nW_n/7
ojJoj`KoYko[00?oZ<3[ojS1k?nX`N`01_nX`N`5ojS1j`WoY[k[1_nW_n/3ojO0j`OoZ<7[0onV_NT2
oif_i0OoVj[Q1_nJY]h7oiZUg@;oW:[P1onVao03ojSAm@Ko[>ci0ondioL6ojoPn0;o[LG/1OnY_NP3
o`0000GoYk[V00?oY[CSojNehonW]N<01OnW]N<6ojRfhP03ojRji_nZ^^GoZ[[U00KoZ[[U1_n[^N@0
0onY_nWo[;kWojbni`06ojbni`Go[KcT0_n[`>T8ojnoiP;o[k_R1On``>H7ok2lh`03ok70iOna_^?o
/KkS00Ko/KkS0onW^^L4ojnni@SoUkO^1_m_[oL5oeVYn@KoS/;i1?ndanP4ojc5k0Oo`<GN00?o0000
oko7h?nnaN001_nnaN000onoan3o]<CVokC4iP06okC4iP;oYl3[1_nX`>/Eooooo`03o`000?oooooo
oooo00Kooooo1Ol0000?ooooo`006_ooool2o`0000Wooooo1_nW_n/7ojJoj`;oYko[1OnX`>/8ojS1
k003ojS1jonV_^_oY[k[00_oY[k[0_nW_n/7ojO0j`GoZ<7[00?oY;SWoif_i?nM[n@01?nM[n@7oi^Z
h@KoVZKN1OnJYMd3oinijPSoY/O`00?oZ=7eojc/nOn/k?T00on/k?T6okCWm`;o[n3h1_n]aN`01?nY
_NSo0000o`000?l00003ojVmj0;oYk[V1OnV]><7ojNeh`;oZ;KR1OnX^^H8ojZji@;oZkWT1OnY_nT8
ojbni`03ojfli?n[`>WoZl3Y00CoZl3Y1_n__nH00on[`>Wo/<3Vok30iP06ok30iPCo/;cS1?na`>D8
ok6nh`03ojNjion__^Go[kkU00Co[kkU1_nG]nh00onS^n[oOK;eogfbm@05ogfbm@?oFjCf0_mIZOT6
ohk2n@03okC7j?n/aNco[<G/00Go[<G/1?o0aMh3oko7h003o`000?noan3o_/GP00?o_/GP1?noan06
okC4iP;o]/GV2?nX`>/Dooooo`03o`000?oooooooooo00Kooooo00GoV9RHob4Q8Oo^k^koooooodA4
A00?ooooo`006_ooool00ol0003oooooooooo`06ooooo`;oZ<7[1onW_n/5ojJoj`;oYl3[1onX`>/6
ojS1k0?oZ<7[2onV_^/;ojO0j`03ojS1jonT^>OoY;SW00?oY;SW1_nM[n@6oi^Zh@OoVZKN00?oVZGM
oinij_nO^NX01OnO^NX6ojK7l0Co[NGi00?o[>ciokCWmondioL01OndioL3ok7@l0Co[LG/0ol00003
ojVmj0?oYKCT2?nV]><5ojNeh`;oYk[W1onX^^H6ojZji@03ojRoj_nY_nWoZKoY00KoZKoY1_n/_^L2
ojRojPOoZl3Y0_n__nH5oj_0j@So/<3V00?o/;cSok70iOna`>D01Ona`>D6ok6nh`03ok:oi?n__^Go
[kkU00Ko[kkU0_nG]nh5oj>kjPOoOK;e1OmKY?H6ogjin@So[<G/00?o`<GNoko7h?noan000onoan00
1?l0003o_lOPoko7h?nnaN06oko7h0Co]<CV1OnfaNH7ojS0jaGooooo00?o0000ooooooooool01_oo
ool00onHV9So8B4Qonk^kP0@ooooo`006_ooool00ol0003oooooooooo`03ooooo`KoZ<7[1onW_n/0
0onV_n_oYl3[ojO0j`04ojO0j`OoZ<3[0_nX`N`7ojS1j`OoY[k[3OnW`>/00onW_n_oY;SWojBhi`05
ojBhi`KoWJoT1_nKZ^43oiZVgP?oVJ_S2OnO^NX2ojK7l0Ko[NGi1?ngk?H2okCWm`Oo/M3`0ol00002
ojg5k003ojBei?nU]>CoYKCT00GoYKCT2?nV]><00onW]N?oYk[WojNji`04ojNji`OoZ;[V0_nZ^^D5
ojRojPSoZKoY0_n/_^L6ojRojPGoZl3Y00?oZ;kZoj_0jOn[`>T01_n[`>T6ok30iP03ojc1jOna`>Go
/L3U00Oo/L3U0_na_^<5ok:oi0Ko[kkU00?o//3Toj>kj_nS^nX01_nS^nX7ogfbm@GoFjCf1_mn^OT6
ojc5k003ojG2k_noan3o_lOP00Go_lOP00?o0000okk8h_noan001onoan000onda>Ko]/GVokK5iP06
okK5iPOoZ<3[5Oooool00ol0003oooooooooo`06ooooo`03oiRHV?lQ8B7ok^k^00oooooo000Joooo
o`03o`000?oooooooooo00[oZ<7[1OnW_n/2ojJoj`OoYl3[1OnX`>/3ojW1j`SoZ<7[1onV_^/9ojO0
j`GoYko[1onT^>L6oif_i0?oVj[Q0_nFY=l7oiV[h`OoWkWZ0on]eoH4ojgUn@Ko]ncf0_nefo<4ok7@
l0?o000000?o/M3`ojg5k?nT]N@01?nT]N@7ojFdi0KoY[CS00?oY[WVojNjionW^^L01_nW^^L5ojRj
iP03ojRnj_nX_n[oZ;oZ00KoZ;oZ1_nY_nT2ojRnj@SoZ;oZ00?oZl3YojRnj_nX_^X00onX_^X8oj_0
j@;o/<3V1On/`NT7ok70i@03ojo1j?nb_nCo/[oT00Go/[oT1?n__^D4ok;0i0SoXk_Z0omm/_D4ohJb
lP?oHZCe0_mKY?H6ogjin@;o[<G/1OnU`^h6oko7h003okk8h_l0003o_/SR00Ko_lOP0_o0bN47okK5
iP03okK7ionX`>_oZ<3[00GoZ<3[5Oooool00ol0003oooooooooo`07ooooo`03ogMgMomVIVKooooo
00kooooo000Iooooo`03o`000?nX`N_oZ<7[00coZ<7[00?oYko[ojJojonV_n/01?nV_n/7ojO0j`03
ojS0jonY`N_oZL7[00GoZL7[1_nX`N/9ojJnj`GoYl3[0_nX`N/7ojNoj`OoY;SW0onM[n@2oiNWh@Ko
UZCO1onIZn<4oinijPOo[MOf00?o[NGiokO/m_ngk?H00ongk?H5okGKl`?o00000onad?000onU^>Ko
Y;GTojBei005ojBei0OoYKCT0_nV]><5ojJiiPSoYk[W00?oZ;[VojRnj_nX_^X00onX_^X8ojRojP;o
ZKoY1_nX_^T6ojRojP03ojRnjOnX_^[oZ;kZ00GoZ;kZ1_n[`>T00onX_n[o[<7Yojc1j@06ojc1j@Co
/L3U1?n_`NP7ok:oi003ojnniOnb`>Co//3T00Go//3T1_nS^nX2oj^oj0OoQ[;b1OmRY?D6ogB`m`Oo
YL;^0onoan04okk8hP03o`000?noan3o_lOP00;o_lOP1Oo0bN44okK5iPCo]/OW1onX`>/Eooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool03Oooool001Wooooo00?o0000ojS1jonX`N/0
2onX`N/2ojNoj`OoY[o[1OnW`>/3ojS1j`OoZL7[0_nX`N/=ojJnj`03ojO0jonX`N_oZ<7[00CoZ<7[
1onW_n/3ojBhi`?oVJcT1_nGYn46oiJTg`OoVJ_S00?oWkWZojgGm_n]eoH01_n]eoH4okW/m@03okO/
m_nefo?o]M_c00?o]M_c0_l000000onefo?o/M3`ok7@l005ojFhiPOoY;GT1OnU]>@00onU]nKoY[WV
ojJiiP06ojJiiPKoYk[W00?oYkkZojRnj_nX_^X01OnX_^X6ojRojP[oZ;kY0_nX_nX5ojRnj@OoZ;kZ
0_n[`>T5ojRojPSo[<7Y00?o/L3Uojo1j?n_`NP01On_`NP5ok:oi0;o//;V2?nb`>@2oj>kjPKoZkoX
1on6/_85of:Tm@KoM;3g1onU`^h00onoan3o_/SRokk8hP03okk8hP03o`000?nnb>;o_lOP00So`<WQ
00?o]/GVokK7ionfanL01?nfanL6ojS0j`;oYl3[4oooool3o`0000Cooooo00Go0000okZj^_oooooo
V9RHoa0@400?ooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooooonX
`N/02?nX`N/6ojNoj`OoY[o[00?oYl3[ojS1jonX`N/01OnX`N/5ojW1j`;oZ<3[3OnV_^/2ojO0j`Oo
Z<7[1OnW_n/00onO]NOoVJcToiV/i005oiV/i0KoUjOQ1_nFY=l5oiV[h`?oZ<O`1On]eoH5okW/m@?o
_>Cc00Co]M_co`000?l0003o00000_nefo<2oj_1jPOoYKSV1onT]N@00onU]>CoYKOVojFgiP03ojFg
iPSoY[WV0_nW^^L5ojNnjPOoZ;kZ0_nX_nXEojRnj@GoZ;kZ00?oZKkYojRoj_nX_nX01_nX_nX6ojc1
j@;oZKoZ2?n_`NP00onb_nCo//;Vok;2iP04ok;2iPKo//3T0_nc`^D8oj^oj0?oQ[;b0on=]?44ofRT
l`;oHZCe1_md/?L3ojG2kP?oWkk_1onnb>800ol0003o`<WQol39h@06ol39h@03ol7;h_nfanOo]/OW
00Ko]/OW0_nX`>/6ojO0jaCooooo00?o0000ooooooooool00_ooool01OnHV9So410@o`000?lQ8B7o
c<c<00oooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`08
ojS1j`OoYko[1OnV_n/3ojO0j`OoZ<7[00?oZL7[ojS0jonX`>/01?nX`>/9ojJnj`KoYl3[1onX`N/0
0onW_n_oWkGWoinei`03oinei`OoVJcT1OnGYn47oiJTg`03oiV[honXao3oZ<O`00KoZ<O`00?o[MOf
okW/mOnik?D00onik?D3okcTl`?o000000?o_>CcokGKlon[`NX01On[`NX7ojFhiP?oY;GT0onS]ND7
ojFgiPKoY[WV2OnW_^X5ojRnjQWoZ;kY00?oZ;kZojVnjOnY_^T00onY_^T8ojRojP;o[<7Y1_nY_nX6
ojo1j003oj_1jOnb`^Ko//;V00Ko//;V0_nb`>@6ok?2i@KoZkoX00?o[/7XohfdlOn=]?401On=]?45
ofRTl`KoKjWd1onO_^l4okk8hP?o_LSS00?o0000ol39hOo0bN401?o0bN43ol7;hPKo]/OW0_neb>P8
ojO0jaCooooo00?o0000ooooooooool05Oooool000kooooo00Go410@oooooooooooooooooa0@4006
ooooo`;o00000_ooool8ojS1j`OoYko[00?oY[o[ojO0jonW`>/01OnW`>/5ojS1j`;oZL7[1onX`>/5
ojJnj`;oY[o[2?nW`>/5ojS1j`03ojJnjonO]NOoWkGW00GoWkGW1_nI[>@6oiNWh@?oUZCO1?nM]^T7
ojS7l0Co]n?e0_nik?D01?nli??o0000o`000?l00003okcTl`;o]=7_1on[`NX5ojFhiP03oj:diOnS
]NGoXkGU00GoXkGU1onU]nH2ojJiiPgoYkkZ00?oZ;kZojRnjOnX_^T02_nX_^T00onX_NWoZ;kYojRn
j@0<ojRnj@SoZKkY1_nX_nX2ojVoj@SoZKoZ0_n_`NP5oj_1j@Ko//;V00?o/<;Wok?2iOnc`^D01onc
`^D2oj^oj0Go[/7X1_n=]?46ofRTl`KoKjWd1onO_^l00onnb>;o_LSSokg8h`04okg8h`04o`000?o0
bN7o`<WQol39h@Go`L_R1?nfanL5okG8j0OoYl3[5Oooool00ol0003oooooooooo`0Dooooo`003_oo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00oooool7ojS1j`?oYko[
1OnV_n/7ojO0j`03ojS1jonY`N_oZL7[00CoZL7[1onX`>/00onV_^_oY[o[ojJoj`04ojJoj`SoYl3[
00?oZ<7[ojJnjonV_^/00onV_^/7oinei`KoVJcT0onGYn43oiBWhPOoWKKY1?nXao06okOSm@?o0000
1?nli?<5okCAk`OoZl7Z00?oYKSVoj:diOnR]>D00onR]>D7oj>ei@GoYKOV3OnW_^X4ojNnj@WoZ;kY
1OnX_NT:ojRnj@coZKkY0_nX_nX6ojVoj@OoZKoZ1on[`NT4ok;2iPCo/<;W1onc`^D00onc`nKo[/7X
ojk1j005ojk1j0OoSKCa1_mXY?<5ofnYm0KoWkk_00?oWKc^okg8honmb><01Onmb><00ol0003o_LSS
ol39h@07ol7;hP03okK7ioneb>So]LSX00Ko]LSX1onW`>/Dooooo`03o`000?oooooooooo01Cooooo
000>ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`05ooooo`GoZ<7[
0_nW_n/8ojJoj`GoYl3[0_nX`>/7ojW1j`GoZ<3[0onV_^/6ojJoj`KoYl3[0_nX`N/6ojJnj`OoWkGW
0onI[>@2oi:UhPOoU:OR1onM]^T00onXao3o]n?eokOSm@03okOSm@?o00001?o1jo400onli??o]=7_
okCAk`06okCAk`?oZl7Z0onQ]>H7oj:di@OoXkGU00?oYKOVojNnj_nW_^X02_nW_^X00onW_NWoYkkY
ojNnj@06ojNnj@KoZ;kY2?nX_NT6ojRnj@koZKkY2_nY_nT7ojVojPOoZl7Y00?o//;Vok32ion``^L0
1On``^L4ok?2i@Co/l?V1on^`NP3ohfdl@CoT;K`1Om/Y?84ofnUlP;oKjWd0_nO_^l5oiflkPOo_LSS
00?o0000ol7;h_o1bn801Oo1bn82ol7=i0Oo]LSX00?o/lSYojO0jonW`>/01OnW`>/Eooooo`03o`00
0?oooooooooo01?ooooo000>ooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003ooooo
ooooo`06ooooo`03ojS1jonW_n_oYko[00CoYko[2?nV_n/00onW`>_oZ<3[ojS0j`04ojS0j`OoZL7[
00?oZ<3[ojJnjonV_^/01OnV_^/6ojJoj`;oYl3[1_nX`N/6ojJnj`?oWkGW0onFZnD6oi:UhPOoU:OR
1OnM]^T4ojo@l@?o00001_o1jo43okcMl0Ko]=7_00?oYK[Xoj6di_nQ]>H01OnQ]>H7oj:di@?oXkGU
1?nU_>T9ojNnjPGoYkgY2?nW_^T2ojRnj@coZ;gY0_nX_^T>ojVnj@coZKoY00?oZ[oYojVoj_nY_nX0
1_nY_nX5oj_1j@;oZL3Z2?n``^L00onc`^Go/l?Vok?3iP05ok?3iPGo[/7X0_n``nP7oi2fl0GoK:Cb
1_m_YO87oiflkPCo_LSS0onmbN<00ol0003o`L_Rol7;hP02ol7;hPGo`LgT1?neb>P4ok?8j@OoYl3[
5Oooool00ol0003oooooooooo`0Booooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo
0_l00008ooooo`OoYko[1_nV_n/2ojO0j`OoZ<3[1OnY`N/3ojS0j`OoY[k[0onV_n/4ojO0j`OoZ<7[
0onV_^/3oibcj0KoUZ_U1_nBYN87oiBWhP03oiffjOn_d?7o[m3a00;o[m3a0ol00003ol7Wl@Co`N_a
1onlgO000onddNooYK[XojFjj003ojFjj0OoXKCV1OnR]>D2oj:hj0OoYKcY1onW_^X7ojNmj@KoYkkY
00?oYkgYojRmjOnX_NT02onX_NT00onX_n[oZKkYojVnj@0<ojVnj@_oZKoY1OnZ_nT8ojVojP03oj_1
jOnY`>[oZL3Z00CoZL3Z1_n``^L00on_`^So/l?Vok?3iP07ok?3iP03ojk1j?n``nSo/<?X00Co/<?X
1on@]_05ofbTlPKoKjGb1onM_>h00onmb>?o_LWSokg9h`03okg9h`03o`000?nmbN?o`L_R00So`LgT
00?o]LSXok?8jOncb>T01?ncb>T7ojO0jaGooooo00?o0000ooooooooool04_ooool000kooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo00Sooooo1onW_n/2ojJoj`KoYl3[
1onX`>/00onY`N_oZ<3[ojS0j`05ojS0j`GoY[k[0_nV_n/7ojO0j`GoZ<7[0_nV_^/6oibcj0KoUZ_U
1_nBYN85oiBWhP?oY;k/00?o[m3ao`000?l000000_n_d?46ol7Wl@03ol7[lOnlgO3o_=g`00Go_=g`
00?o/<W/ojFjj?nU^^P01OnU^^P7oj6diP03oj:diOnR^>SoX[SX00CoX[SX1onU_>T7ojNnjPOoYkgY
0_nW_^T5ojNmj@WoZ;gY1OnX_nX:ojVnj@_oZKoY00?oZ/3YojZojOnZ_nT01_nZ_nT6ojVojPWoZL3Z
0_n``^L5ojo2j0Oo/l?V00?o/lCVok33j?n``nP01_n``nP6oi2fl0CoKj;`0_m/Y?86ofnUlP?oWKc^
1?nN^nd6okg9h`03o`000?nobn?o`LgT00Ko`LgT00?o`<oVok?8jOncb>T01_ncb>T7ojO0jaGooooo
00?o0000ooooooooool04Oooool001Sooooo00?o0000ooooooooool02Oooool5ojNoj`?oY[o[1onW
`>/3ojS0j`CoZL7[2?nX`>/00onV_^_oY[o[ojJoj`04ojJoj`OoYl3[00?oZ<7[ojJnjonV_^/01?nV
_^/6oibcj0GoUZ_U1onBYN800onDYn;oY;k/ojBnk002ojBnk0?o00000on_d?46ol7Wl@CoaNK^0_nl
gO05ok39k0KoYK[X1_nQ]>H00onQ]NOoX[SXoj:hj006oj:hj0GoYKcY2OnW_^X>ojNmj@KoZ;gY0_nX
_n/6ojRojPKoZKkY0_nY`N/9ojVoj@GoZ/3Y2?nZ_nT2ojVojPcoZL3Z2?n_`^P4ok?3iPCo/lCV1_n`
`nP2ok34j@KoT;K`1Om_X_06og:Sl0SoW[_]0onmbN<3oko;h`03o`000?nobn?o`LgT00?o`LgT1?o0
cnH6ok?8j@03ok37jonW`>_oYl3[00KoYl3[5Oooool00ol0003oooooooooo`0@ooooo`006?ooool0
0ol0003oooooooooo`0:ooooo`03ojNojonV_n_oY[o[00GoY[o[1OnW`>/2ojS0j`OoZL7[1_nX`>/0
0onV_^_oY[o[ojJoj`06ojJoj`GoYl3[0onX`N/6ojJnj`KoW;?X1OnFZnD3oi:UhPCoU:[U00CoY;k/
o`000?l0003o00001?nT_^`00on_d?7o`NOaol7Wl@03ol7Wl@GoaNK^0onlfNh6ok39k0KoYK[X0_nQ
]>H5oj6ei`SoX[SX00?oYKcYojNnj_nW_^X02onW_^X>ojNmj@;oZ;gY1_nX_n/6ojRojP;oZKkY1_nY
`N/6ojVoj@03ojW1jonZ`>WoZ/3Y00GoZ/3Y1_nZ_nT2oj[0j@koZL3Z2?n_`^P00onc`nKo/lCVok?4
iP05ok?4iP;o/<?X1_n`a>T6oi2fl0GoKj;`1_mbXo08oijkk@03okg9honobn?o_l_S00?o_l_S00?o
0000oko;hoo1cN@01oo0cnH2ok?8j@Go/<O[1_nW`>/00onW_n_oooooooooo`0Cooooo`;o00004Ooo
ool001Oooooo0ol0000=ooooo`OoY[o[00?oYl3[ojS0jonX`>/01?nX`>/7ojW1j`;oZ<3[1OnV_^/8
ojJoj`03ojO0jonX`N_oZ<7[00GoZ<7[1_nV_^/3oibcj0;oU:_V1_n?Y><4oiBZi@?o00001_nT_^`4
okGDl003ol7WlOo5i^koaNK^00?oaNK^1_nlfNh6ok39k0?oYK[X1?nO]>L6oj6ei`KoX[SX00?oY[k[
ojNnj_nW_^X02onW_^X>ojNmj@;oYko[2?nX_n/3ojRojP?oYl7/2?nY`N/2ojVoj@GoZL7[1onZ`>T2
ojZoj@KoZ/3Y1_nY`>X00onZ`>[oZL3ZojW0jP05ojW0jPKo[l;X0_n^`^T6ok?4iP03okC5ion`a>Wo
/<CY00Oo/<CY1_n@]_05ofnRl0KoLZ?`1_nN^nd00onP^nco_l_Soko;h`04oko;h`03o`000?o1cNCo
`<oV00Ko`<oV0_nncnL7ok37j`;oYl3[1OnW_n/Cooooo`03o`000?oooooo0000017ooooo000Goooo
o`03o`000?oooooooooo00kooooo1OnV_n/2ojNoj`OoZ<3[1OnY`N/3ojS1j`KoY[k[1_nV_n/2ojO0
j`SoZ<7[0onV_^/2oi^dj@KoU:_V1_n?Y><3o`0000CoU:[U0_nT_^`6okGDl0Coa^G]0_o5i^h8okcI
kP?o/<W/0_nQ^>P8oindi`KoXKGW0_nR^>P5ojJnj`WoYkkZ3_nW_NT6ojNoj`KoZ;o[2?nW`N`6ojW1
j`03ojO0k?nY`N_oZL7[00KoZL7[1OnZ`>T2oj[1jPSoZ/3Y0_nY`>X5oj[0jPOoZL3Z0_n_`^P6ojk2
j@?o/lCV1?ndaNL7ok34j@03ojo5j_n=/o3oSK?`00CoSK?`1?m_Wnh2ofnRl0KoLZ?`0_nN^nd5oj2k
k0Go_l_S00?o`LgTo`000?o1cN@01?o0cnH5okk?i`Go/<O[00?o[<G/ojNojonW_n/01_nW_n/Doooo
o`03o`000?oooooooooo00oooooo000Gooooo`03o`000?oooooooooo00oooooo00?oY[o[ojNojonW
_n/01?nW_n/7ojS0j`03ojW1jonX`N_oZ<7[00GoZ<7[1_nV_^/2ojJoj`KoYl3[1_nX`N/00onV_n_o
VkCYoi^dj@04oi^dj@KoU:_V0_n?Y><3o`000003ohnThonDZ^GoU:[U00?oU:[U0onX`^`5okGDl0Go
a^G]0_o7h^`7okcIkP03ojk7k?nQ^>SoXKSX00CoXKSX2?nO]>L3oj6ei`?oY;_Y1onV_^/5ojNnjP?o
Y[gZ2_nW_NT4ojNnj`OoYko[0_nX_n/<ojO1k0;oZL7[1OnW`>`8ojW1j`03oj[0jOnZ`N[oZ/7Z00Co
Z/7Z1_nZ`>T00on[`N[oZ/3Zoj[0jP05oj[0jPKoZL3Z0_nY`>/8ojk2j@03ok?4i_ndaNOo]<GW00Co
]<GW1?n`a>T4ojo5jPKoSK?`1Om_Wnh6ogRSk@OoX;_/0onobn<4ol7=i003o`000?o1cNCo`<oV00So
_/oW00?o/<O[ojc5k?n/aN`00on/aN`8ojNojaCooooo00?o0000ooooooooool03_ooool001Oooooo
00?o0000ooooooooool04?ooool7ojNoj`GoZ<3[0onY`N/7ojS1j`OoY[k[1onW`>/2ojS1j`GoY[o[
1_nK]>T4oiB[iP?o00001On?Y><00onDZ^GoZ<;/ojS2k005ojS2k0?o]MC`1Oo6iNd4olORk0Co_=W^
1?n^an`6oj6hj0KoWkCW00?oWkKXojBkjOnT^nT01OnT^nT7ojJnj`03ojNnj_nV_N[oY[gZ00GoY[gZ
1OnW_NT00onV_N[oYkk[ojNnj`06ojNnj`GoYko[3_nW`N`2ojO0j`OoYl3/1_nY`N/2ojO0k0OoZ/7Z
0_nZ`>T5oj_1jPOoZ/3Z0_nY`>X6ojW0j`Oo[/;Y2?ndaNL00on`a>Wo[lGZojo5jP04ojo5jPKoSK?`
1_m_Wnh6ogRSk@OoX;_/00?o_l_Sol7=i?o1cN@01?o1cN@00ol0003o`m3Tokk?i`06okk?i`03okc?
jOn/aNco[<G/00Go[<G/1onW_n/Eooooo`03o`000?oooooooooo00gooooo000Gooooo`;o00004_oo
ool7ojNoj`03ojS0jonY`N_oZL7[00GoZL7[1OnX`N/9ojJnj`GoYl3[0_nX`>/7ojJoj`GoVkCY00Co
U:_Vo`000?l0003o00000onDZnH3ohnTh`?oU:_V2?nX`^`00onee?3oa^G]olKUk@02olKUk@Ooan;/
00?o_=W^ojk7k?n^an`01On^an`6oj6hj0;oWkCW1OnO]^P7ojBkj@?oY[k[1?nV_^X8ojJmjP03ojNm
jOnV_N[oY[gZ00?oY[gZ2?nW_^/00onW_n_oYl7/ojO1k00<ojO1k0KoYl3[1onW`>`2ojW1j`KoYl3/
1OnZ`NX00onY`>_oZl7Zoj_1jP06oj_1jPGoZ/3Z0_nZ`NX8ojW0j`Oo[/;Y1_ndaNL2okC6j0Oo[lGZ
1_n=/o06ofnOkPKoN:?]0onP^n`4ojFljPGo`LgT00Co`m3To`000?o3d>Co`m3T1?nncnL4okc?j@Oo
[<G/1onW_n/Dooooo`03o`000?oooooooooo00gooooo000Gooooo`03o`000?oooooooooo01;ooooo
1OnW_n/3ojS0j`OoZL7[00?oZ<7[ojJnjonV_^/02onV_^/00onW`>_oZ<3[ojS0j`04ojS0j`OoY[o[
0onK]>T2o`0000?oU:_V0on<Y>D7oiB[iPKoZ<;/1?nje>d00oo6iNgoan;/olORk005olORk0?o_]O/
1on^an`3oj6hj0?oW[GX1onO]^P5ojBkj@;oYko[1onV_^X>ojJmjPKoYkk[3_nW`N`9ojO0j`?oYl3/
1?nW`>/8ojO0k003oj[1j_nY`>_oZL3[00?oZL3[2?n[`NX00onZ`>[oZ/7Zoj[1jP04oj[1jPKoZL3[
0_nY`N/7ojk2j@;o]<GW1_nda^P5ojo5jP03oj_4k?n9[^koRJk^00GoRJk^1Om_W>`6oh2Tj`SoYKcZ
0oo1cN@3ol?@i004o`000?o3d>Co`m3Tokk?i`Ko_<oY1_n/aN`00onY`^coYko[ojNoj`06ojNojaCo
oooo00?o0000ooooooooool03?ooool001Oooooo00?o0000ooooooooool04oooool00onW_n_oZ<3[
ojS0j`05ojS0j`GoZL7[0_nX`N/<ojJnj`?oYl3[1_nX`>/5ojJoj`04oi^fjol0003o0000o`0000?o
TZcX1_n<Y>D7oiB[iP;oZ<;/1_nje>d3olWRjPCoan;/1_nnen`5ojk7k003oj2hj_nN]NSoW[GX00Go
W[GX1onO]^P00onT^nWoYko[ojNoj`04ojNoj`OoY[kZ3_nV_NX2ojNnj`koYl7/2onW`>/00onW_n_o
Yl3[ojO0j`06ojO0j`KoYl3/00?oYl3[ojW0jonY`>/01OnY`>/7oj_1jPSoZ/7Z0_nY`>/6ojW1j`Go
[/;Y0_n_`nT8okC6j003ojo5j_n[a>coZlC/00?oZlC/1on9[^h5ofnLk0KoP:C[2?nU_>X00oo1cNCo
`m3Tol?@i003ol?@i003o`000?o3dnKo_<oY00Oo_<oY0_n/aN`5ojW2k0KoYko[00?oYl3[oooooooo
ool04oooool00ol0003oooooooooo`0;ooooo`005oooool00ol0003oooooooooo`0Eooooo`OoZ<3[
00?oZL7[ojS1jonX`N/01?nX`N/8ojJnj`OoYl3[1_nX`>/00onV_n_oVkK[o`000002o`000003oi^f
jonB[>SoTZcX00CoTZcX1_n<Y>D5oiB[iP?oZL;[1Onje>d6olWRjP03olORk?nnenco_]O/00Ko_]O/
00?o[/O/oj2hj_nP^>X00onP^>X7oijej0GoWkKX0_nT_>X7ojNoj`GoY[kZ3_nV_NX2ojO0j`_oYl7/
3?nW`>/5ojNoj`SoYl3[0_nW`>`5ojO0j`OoZL3[1on[`NX6oj[1jP;oZ/7[2?nY`N/00on^`^Wo[l?Y
ojo3j@04ojo3j@Ko]<KX00?o]<SYoj_4k?n[a>`01On[a>`7ohV^kPGoKic/1_n0Y>/6ojFljP03ojc0
j?o3d>Co`m3T00Co`m3T00?o`m?Vo`000?o3dnH01_nlcnT00onhc^_oZL;/ojW2k006ojW2k0;oYko[
1OnW`>/Dooooo`03o`000?oooooooooo00_ooooo000Fooooo`?o00005oooool5ojS0j`?oZL7[1_nX
`N/8ojJnj`OoYl3[0onX`>/01?nW`>co0000o`000?l00005oi^fj`KoTZcX1_n<Y>D00onDZnKoZL;[
ojW2j`05ojW2j`?o^]C]1_o9h^X3ol[Pj@Ko_]O/0_n`bNd6oj2hjPOoW[GX00?oWkKXojBlj_nT_>X0
1?nT_>X7ojNoj`03ojJnj_nV_N[oY[gZ00coY[gZ1_nW`>/6ojO1k0koYl3[0_nX_^X6ojNoj`KoYl3[
0_nW_n/7ojO0j`?oZL3[1?nX`>/7oj_1jP;oZ/7Z1_nZ`N/7ojW1j`So[l?Y0_nda^P5okC8j@OoZlC/
0on9[^h3ohFXk0CoLISX0_m_W>`6oh2Tj`;oYKcZ1On/`>P3ol?@i0?o`m?V00?o0000ol?Ci_o3dnH0
0_nlcnT5okS>j`KoZL;/0_nW`>`6ojO0jaGooooo00?o0000ooooooooool02_ooool001Kooooo00?o
0000ooooooooool06?ooool00onX`>_oZL7[ojW1j`05ojW1j`KoZ<7[2?nV_^/5ojO0j`03ojS0jonW
`>co000000;o00001?nW`>`5oi^fj`KoTZcX0on<Y>D3oi6Zi`SoZL;[00?o^]C]olWRj_o9h^X00oo9
h^X6ol[Pj@;o_]O/1_n`bNd6oj2hjP?oW[GX1?nN]^T7ojBljP?oYko[1?nV_^/:ojJmjPCoY[k[1onW
`>/2ojO1k0koYl3[1_nX_^X6ojNoj`;oYl3[1_nW_n/5ojO0j`03ojNojonX`>_oZ<3[00KoZ<3[1on[
`NX8oj[1j`OoZL7[1_n_`nT2ok75j@Oo]<SY0on[a>`3oj>okPOoQJS/1OmaV>P6ohZWj0So[<3X00?o
`m3Tol?Ci_o3dnH00oo3dnH00ol0003o`]KXokS>j`07okS>j`;oZL;/1_nW`>`6ojO0ja?ooooo0ol0
000;ooooo`001?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h6ooooo`03
o`000?oooooooooo01[ooooo1onY`N/3ojS1j`CoY[o[1onV_^/00onW`>_oZ<3[ojS0j`03o`0000So
Yl3/1OnK]^/3oi:/j0;oRZGW1onAZ^L6ojW2j`Co^]3Z0_o9h^X6ol[Pj@?o`]OY1on`bNd3oj2hjP?o
W;GY1onN]^T5ojBljP;oY[o[1onV_^/5ojJmjP03ojFmjonV_^_oY[k[00KoY[k[1OnW`>/00onX`N_o
Yl3[ojO0j`0;ojO0j`;oYkkZ2?nX_^X3ojNoj`?oZ;oZ2?nW_n/00onW`>_oYko[ojNoj`03ojNoj`So
Z<3[1on[`NX7oj[1j`OoZL7[1?n_`nT5ok75j@Go]<SY0_ncbNX6oj>okPKoQJS/1_maV>P6ohZWj0Ko
[<3X00?o]<GWol?Ci_o3dnH01?o3dnH00oo2e^So0000ol;Fj006okS>j`;o//_]2?nW`>`3ojO0j`?o
Z<3[3oooool3o`0000;ooooo00?o0000ooooooooool02Oooool000Kooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool06oooool6ojW1j`So
Y[o[1OnV_^/01?nW_n_o0000o`000?l00004ojS0j`KoYl3/00?oW[_/oi6^j_nA[^X00onA[^X6ohZU
i`OoTJ[W0onY`^/6ok[@jP?ob]cV0oo:h>T6ol;Gj@Go/<W]00?oXK_/oibejOnL]NT01OnL]NT7oijf
j@03ojBlj_nV_n_oY[o[00CoY[o[1onV_^/00onV_N[oYKg[ojFmj`03ojFmj`SoY[k[00?oYl3[ojS1
jonX`N/00onX`N/9ojO0j`KoYkkZ1_nX_^X8ojRojPKoYko[0_nX`>/6ojNoj`SoZ<3[1on[`NX7oj[1
j`OoZL7[00?o[l?Yok75jOnaaNT01_naaNT00ondb>Wo/lWZok?9jP04ok?9jPKoXko^1On5Z>`6og6H
j0OoRZOX0_n/`>P5okC5i`?o`m?V0oo2e^P00ol0003o`]KXol;Fj002okS>j`Ko//_]1_nW`>`00onW
_n_oZ<3[ojS0j`05ojS0j`_ooooo0ol00005ooooo`03o`000?oooooooooo00Wooooo0006ooooo`03
o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`;o00007Oooool6ojW1
j`SoY[o[00?oY[k[ojNojol000000_l00002ojNoj`KoZ<3[0_nW`>`5oijkk0GoTJkZ1_n:YNL7oi6Z
i`03ojW2jonjd>[o^]3Z00Co^]3Z1Oo:g>H00oo:h>Wo`]OYol;Gj@06ol;Gj@03ok39kOnQ^ncoXK_/
00?oXK_/1onL]NT5oijfj@;oXk_Z1onV_n/5ojJnj`03ojFnjonU_N_oYKg[00GoYKg[1_nV_^/2ojS0
j`KoZ<7[1_nW`>/2ojNoj`OoYkkZ0_nX_^X<ojRojP;oYko[1_nX`>/6ojNoj`SoZ<3[1On[`NX2oj_2
j`OoZ/7[1onY`N/7ok75j@03ok;8j_ncbN[o/lWZ00Ko/lWZ0onS_nh2oiNfk@CoOj7Y0_n5Z>`6og6H
j0?oRZOX0onF[nT8okC5i`03ol?Ci_o2e^So`]KX00?o`]KX00?o0000okkDj_nne>X02?nbbnd2ojO0
k0GoYko[1onX`>/6ooooo`Co00002?ooool00ol0003oooooooooo`09ooooo`001_ooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000001Oooool2o`0001oooooo1_nY`N/6ojJo
j`03ojFnjol0003o000000KoYko[0onX`>/4ojS1j`KoW[_/1OnA[^X6ohZUi`?oTJ[W1OnV_^X3ok[@
jPKob]cV0oo=gND6ol;Gj@;o]lk[1_nQ^n`7oibej@03oijfjOnS^n[oXk_Z00CoXk_Z1onV_n/00onV
_^_oYKk[ojFnj`03ojFnj`OoYKg[0_nV_^/6ojS0j`KoZ<7[0_nW`>/6ojNoj`KoYkkZ3OnX_nX2ojW1
j`SoZ<3[1_nW_n/8ojS0j`03oj_1j_n[`^_oZl;[00CoZl;[1onZ`N/7ojW1j`Co/LGY1?nbb>X6ok?9
jP03ok38k?nG]^goUkK]00CoUkK]1OmoXNT6ogNHi@OoUZoY1_ndaNL3okg?i`?o`]KX0_nne>X00ol0
003o_]CZokkDjP06ok;;k@03oj_5k?nW_n_oYko[00GoYko[1_nX`>/01?nX`N_oooooooooooooool3
o`0000gooooo00?o0000ooooooooool02?ooool000Kooooo00?o0000ooooooooool00_ooool01Ol0
003ooooooooooooooooo000000Gooooo00?o0000ooooooooool07oooool6ojW1j`;oY[o[00CoYKk[
o`000?l0003o00000_nU_^/5ojNoj`;oYl3[1onX`N/6oijkk0GoTJkZ0on:YNL3ohbXj0SoY[kZ00?o
^]3Zol[Li_o:g>H01?o:g>H6olgMi@03ol;GjOngc^_o]lk[00Co]lk[1_nQ^n`3oibej@CoW;K[1onS
^nX3ojJoj`CoY[k[1_nU_^/5ojFmj`?oY[k[1onX`>/3ojS1j`?oYl3[2?nW_n/6ojNnjPWoZ;oZ1_nY
`N/7ojS0j`OoYko[1_nX`>/00onY`>_oZl;[oj_2j`06oj_2j`?oZ/7[0onY`^/8ojW1j`03ok75jOnb
b>[o//SZ00Go//SZ0_ncbNX5ok38k0KoUkK]1OmoXNT6ogNHi@OoUZoY0ondaNL6okg?i`03ol;Fj?nn
e>[o_]CZ00;o_]CZ00?o0000okkDj_nne>X00_nbbnd5oj_5k0OoYko[0_nX`>/5ojS1j`;o00004?oo
ool00ol0003oooooooooo`08ooooo`001_ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooo
ooooooooool@41001Oooool00ol0003oooooooooo`0Pooooo`?oZL7[0_nW`>/3o`0000KoYKk[00?o
Yko[ojO0jonW`>/01?nW`>/7ojS1j`?oW[_/0onB/N`5ohRXjPKoS:SX1_nV_^X3okK:j@Cob]cV1_o=
gND2olOGiPOo]lk[0onQ^n`3oi^gj`OoW;K[1OnS^nX9ojJnj`KoYKk[00?oYKg[ojJnjonV_^/01OnV
_^/6ojS0j`OoYl3[1_nW_n/2ojJnj`KoYkkZ1_nX_nX2ojW0j`OoZL7[1onX`>/7ojNoj`;oZ<3[1OnY
`>/6oj_2j`03oj[2jonY`^_oZL;[00GoZL;[1_nY`N/2oj_2j`Ko//SZ0_ncb^/6ok38k0OoUkK]1Omo
XNT6ogNHi@OoUZoY00?o]<GWokg?ionmcnL01?nmcnL00oo2e^Wo_]CZokkDjP03okkDjP03o`000?nn
e>[o^];/00SoZlG/0onW_n/3ojO0j`SoZ<7[4Oooool00ol0003oooooooooo`08ooooo`001_ooool0
0ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2o`0002;ooooo00Co
Yl3[o`000?l0003o00000onW`>/5ojFnj`?oY[o[1_nW`>/5ojS1j`;oY;k/1_nB/N`5ohRXjPKoS:SX
0onV_^X7okK:j@03ol[Li_o=gNGocMgU00CocMgU1?o7enH5okO>j`03ojS3kOnK]n_oVkO[00GoVkO[
1onL]^/00onS^n[oY[k[ojJnj`0;ojJnj`?oYKk[0onU_N/8ojJnj`KoZ<3[1onW`>/2ojNoj`KoY[k[
1_nW_^X2ojRojPKoZL3[1onY`N/7ojS0j`OoYko[1onY`>/2oj_2j`GoZ/;[1onY`^/2ojW1j`KoZl;[
0onbb>X5ok?:j`Ko/<S/0onG]^d3ohfYj0CoNiWT0_moXNT6ogNHi@?oUZoY0onP]nT6okg?i`?o`]KY
1?nne>X01?njd^co0000ok[Bk?njd^`6oj_5k003ojO1k?nW`>_oYl3[00GoYl3[1_nX`N/00onY`^_o
ooooooooo`0?ooooo`03o`000?oooooooooo00Sooooo0004ooooo`03oeEEEOmVIVKo000000Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo01oooooo0ol00007ojO0j`03
ojFnjonV_n_oY[o[00GoY[o[1_nW`>/00onX`N_oY;k/ojBnk004ojBnk0KoT[7/1On8Z>X6ohbXj003
ojJnj_nfb^Wo]/[Y00Go]/[Y0oo6dn@3olgMi@OoamOV00?o]lk[ojS3kOnX`nd00onX`nd7oi^gj`Go
W;K[0_nO^N/<ojJnj`;oYKk[1_nU_N/6ojJnj`SoZ<3[1OnW`>/2ojJoj`SoY[k[0onW_^X3ojO0j`So
ZL3[1onY`N/7ojS0j`OoYko[1OnY`>/9oj[2j`GoZL;[0_nY`N/8oj_2j`03ok;8j_ncb^_o/l[[00Go
/l[[0on`b>`2ojO2k@OoSJWX1OmkVN@6oh>Mi0OoX;OY0onmcnL6ol;Fj@03okkDj_njd^co^];/00;o
^];/00?o0000ok[Bk?njd^`00_n[aN`5ojO1k0OoYl3[0_nX`N/5ojW2ja3ooooo00?o0000oooooooo
ool02?ooool001Gooooo00?o0000ooooooooool07?ooool3o`0000Cooooo1OnW`>/:ojJoj`?oYl3[
1?nX`>/6ojBnk0KoT[7/1On8Z>X3ohbXj0?oW[KY1_nfb^T5olKCi003olgMiOo7enKoamOV00GoamOV
0_o0dNL6ojS3k@OoVkO[00?oW;K[oinijonO^N/01?nO^N/8ojJnj`KoYKk[1_nU_N/2ojJnj`coZ<3[
00?oYl3[ojJojonV_n/01?nV_n/6ojJnj`03ojJok?nW`>_oYl3[00GoYl3[1_nY`>/2ojW2k0OoZL7[
0onX`>/3ojO0j`SoYko[00?oZL3[oj[2jonZ`^/02onZ`^/00onY`^_oZL7[ojW1j`04ojW1j`KoZl;[
00?o[lK[ok?:joncb^/01Oncb^/00onbbncoYl;]ojO2k@04ojO2k@OoSJWX1OmkVN@6oh>Mi0OoX;OY
00?o_LoWol;FjOo2e^T01?o2e^T00oo2f^_o^];/ok[Bk004ok[Bk003o`000?ncc^koYl7/00KoYl7/
1onW`>/8ojW2j`oooooo00?o0000ooooooooool02?ooool001Gooooo00?o0000ooooooooool06Ooo
ool3o`0000Sooooo00?oYl3[ojJojonV_n/02_nV_n/00onW`>_oZ<3[ojS0j`06ojS0j`KoY;k/0onB
/N`2oh^]k0GoQZKY1onN]^T3okK:j@Koa]?T0oo=en44olOGiPGo`=7W1_nX`nd3oi^gj`CoV[O/1onO
^N/3ojJnj`CoY[o[1onU_^/3ojFmj`?oYKk[3_nX`>/7ojJoj`;oY[k[1OnV_n`7ojO0j`;oZL3[1_nY
`^`5ojW1j`03ojS1jonW`>_oYl3[00GoYl3[2?nW_n/:oj[2j`?oZL;[2?nY`N/2oj_2j`Go[lK[1?nc
b^/4ok;;k0KoYl;]1_n=ZNP6og^Ii0GoPigT1_nP]nT3ojg1j0?o`]KY1?o2f^/4ok[Bk004ok?>k_l0
003o/lk^ok?>kPOoYl7/1onW`>/6ojW2j`03ojW2k?oooooooooo00gooooo00?o0000ooooooooool0
2?ooool001Gooooo00?o0000ooooooooool05_ooool3o`0000gooooo2?nV_n/5ojO0j`SoZ<3[0onT
_^`2oiVikPKoRjg/1On6Y^T7oijfj@03okK:jOo6dnCoa]?T00Coa]?T1_o=en400oo7enKo`=7Wol3A
i`05ol3Ai`?oZ<?]1?nN^nd6oiZgk0GoWkW[00?oY;g[ojJojonV_n/01_nV_n/5ojFnj`03ojBnk?nU
_^_oYKk[00GoYKk[3_nX`>/5ojJoj`WoY[o/1OnW`>/2ojO1k0SoZL;/00?oZL7[ojS1jonX`N/00onX
`N/7ojO0j`SoYko[1OnZ`^/00onZ`ncoZL;[ojW2j`05ojW2j`SoZL7[1on_a^/00oncb^_o//_/ok;;
k005ok;;k0KoYl;]1_n=ZNP6og^Ii0GoPigT0_nP]nT7ojg1j003ol;FjOo2f^_o`][[00Co`][[00?o
^];/ok?>k_ncc^h00_ncc^h00ol0003o/lk^ok?>kP03ojO1k0CoYko[1onW`>/2ojW2j`GoZL;/3ooo
ool00ol0003oooooooooo`07ooooo`005?ooool2o`0001Gooooo0ol0000Aooooo`GoY[o[0_nU_^/6
ojO0j`KoZ<3[0_nW`>`5oiVikPKoRjg/1On6Y^T5oijfj@?o[l?Y1?o6dn@6olgGh@?ocMKP1Oo0dNL3
okO;j@KoW[_]1_nJ]n`00onO^N_oY;g[ojBmj`03ojBmj`SoY[o[00?oYKk[ojBnk?nT_^`00onT_^`7
ojFnj`koZ<3[00?oY[o[ojJok?nV_n`02onV_n`00onW`>_oYl7/ojO1k004ojO1k0KoZL;/00?oZ<;/
ojS1jonX`N/01OnX`N/5ojO0j`[oYko[00?oZ/;[oj[3k?nZ`n`00onZ`n`7ojW2j`SoZL7[1On_a^/3
ok7;k@Go//_/00?o[LO]oiRbjOnH/^T01?nH/^T6ohJOi0KoOIKP1_nBZ>D7ojg1j003ok[@j_o2f^_o
`][[00Co`][[0onmend4ok?>kP03o`000?n[a>coYko[00OoYko[1OnW`>/2ojS1j`OoZL;/3_ooool0
0ol0003oooooooooo`07ooooo`005?ooool00ol0003oooooooooo`0Booooo`;o00005Oooool00onV
_n_oYKk[ojFnj`04ojFnj`KoYl3[0_nX`>/6ojO0k0GoVKW^1_n;[N`5ohJVj@03oijfjOn_`nWo[l?Y
00Ko[l?Y00?oa]?TolgGhOo=en401?o=en45olgFh003ol3AiongbnWo]l_Y00Go]l_Y1_nN^nd3oiZg
k0?oV[S]1_nT_N/6ojJoj`;oYKo/1_nT_^`5ojFnj`;oY[o[2onX`>/3ojO0j`[oY[o/1?nV`>`7ojO1
k0;oZL;/1OnX`^`7ojS1j`03ojO0jonW_n_oYko[00[oYko[00?oZL;/oj[3k?nZ`n`01OnZ`n`5ojW2
j`;oZL;/2?nY`N/00on_a^_o/L_]ok7;k@05ok7;k@03ok;;k?n]ango[LO]00?o[LO]1_nH/^T6ohJO
i0KoOIKP1_nBZ>D4ojg1j0Co^]3Z0oo2f^/6okgGk@06ok?>k_n[a>coZlC/oj_4k?l0003oZlC/2?nW
_n/00onW`>_oZ<7[ojS1j`04ojS1j`GoZL;/00?oYl3[ooooooooool03?ooool00ol0003ooooooooo
o`07ooooo`005?ooool00ol0003oooooooooo`0?ooooo`?o00006?ooool7ojFnj`OoYl3[1onW`>`5
oiVikP?oRjg/0_n3Z>d7oi2]jPKo[l?Y0onlb^D3olgGh@KocMKP0_o9d^48okO;j@?oW[_]0onJ^Nh6
oiZhk@KoY;g[0_nV_n/6ojFok0KoY;k/00?oYKk[ojJojonV_n/01?nV_n/7ojS0j`OoYl3[1onV_n`7
ojK0k0OoYl7/1onX`^`3ojS1j`CoYl3[2OnW_n/5ojW2k0OoZ/?/00?oZL;[ojW2k?nY`^`01?nY`^`6
ojW1j`03ojc4k?nabngo/L_]00Go/L_]00?o//c^ojg7kOn]and01On]and5oiRbj@KoQYoT1_mmU^07
oi:Xi@03ojg1j?njd>[o^]3Z00Go^]3Z00?o`][[okgGkOnmend01?nmend00onhdnkoZlC/oj_4k002
oj_4k003o`000?n[a>coZlC/00KoYko[00?oYl3[ojS1jonX`N/01_nX`N/00onY`^coYl3[ojO0j`03
ojO0j`gooooo00?o0000ooooooooool01oooool001Cooooo00?o0000ooooooooool03?ooool3o`00
01cooooo1OnU_^/2ojJoj`OoYl3[1OnW`>`00onS_^goSk;^ohnbkP04ohnbkPGoPjS]1on@[NX3ojo3
j@Ko_<[U00?ocMOQolgFh?o=e^001?o=e^04olWBh@Ko]l_Y0_n/aN`6oiZikPKoV[S]0onT_N/3ojJn
j`SoYKo/1_nT_^`7ojJoj`OoZ<3[1onW`>/7ojJok0OoY/3/1onW`N`5ojS2k003ojS0jonW`>_oYl3[
00KoYl3[1onW_n/7ojW2k0?oZ/?/2onY`^`2ojW1j`Go[<C/1?nabnd4ok;<kPOo[LO]1OnH/^T6ohJO
i0KoOIKP0onBZ>D3oj2fj0Oo^]3Z0_o1f^`4okgGk@Co^=?^1?n[a>`00ol0003oZlC/oj_4k002ojNo
j`GoYl3[1_nX`N/00onY`^coYl3[ojO0j`05ojO0j`cooooo00?o0000ooooooooool01oooool001?o
oooo0ol0000:ooooo`?o00008?ooool00onU_^_oY[o[ojJoj`04ojJoj`OoYl3[00?oYl3/oj>nkOnS
_^d00onS_^d6ohnbkPGoPjS]1on@[NX00on_`nWo_<[Uokc:i@04okc:i@?oalkO1?o=e^06olWBh@;o
]l_Y1_n/aN`6oiZikP?oV[S]0onM^^d6ojJnj`SoYKo/1_nT_^`5ojJoj`;oYko[1onX`>/7ojO0j`Oo
Y[o/1onV`>`7ojO1k003ojS2k?nX`>_oZ<3[00?oZ<3[2?nW`>/7ojNoj`GoZL;/0_nY`n`<ojW2k0;o
Z<7[1on/a>`00onabngo//c^ok;<kP05ok;<kP?o[LO]0onO]nT5ohjSh`KoPYKN1_n9W>07oj2fj0Co
^]3Z1Oo1f^`00onmengo^=?^okSCkP05okSCkP?oZlC/00?oYko[o`000?nW_n/02?nW`>/2ojS1j`Go
ZL;/1onW`>/;ooooo`03o`000?oooooooooo00Oooooo000Dooooo`03o`000?oooooooooo00Kooooo
0ol0000Uooooo`KoY[o[1OnW`>/3ojS0j`GoXkk]1_n?/^h5oh>Xk@?oT:gZ1?nQ^>T5okc:i@KoalkO
00?ocMKPolWBhOo9d^401?o9d^43ol?=hPOo[<G/0onJ^Nh2oiRikPOoWK[]1_nV_^/8ojFok0KoY;k/
00?oY[o[ojNojonW_n/01?nW_n/7ojS0j`OoYl3[1OnV_n`2ojJoj`OoY/3/1OnW`N`2ojO0j`KoZ<3[
1_nW`>/9ojNoj`03ojW2k?nY`ncoZL?/00CoZL?/2?nY`^`6ojS1j`Go[<C/0on`c>h5ok;<kP03ojk9
kOnO]nWoWkOY00GoWkOY1On>Xn<6oh:FgPKoRIcP1onP]^P00onjd>[o`M[/ol7Jk004ol7Jk0;o_mc^
1_nhdnh00on_b^koYko[ojNoj`02ojNoj`03o`000?nW_n_oYko[00KoYl3[00?oZ<3[ojW2k?nY`^`0
1_nY`^`3ojO0j`?oY[k[2oooool00ol0003oooooooooo`07ooooo`005?ooool00ol0003ooooooooo
o`03ooooo`?o0000:Oooool6ojJoj`03ojO0jonX`>_oZ<3[00GoZ<3[1OnS_^d3ohnbkP?oR:k_1On2
Z>d7oj6hj@?o_<[U1_o7c]l3olc@g0?obM;Q1_o3cN85ojc5k003ojC0kOnH^NkoV;W^00CoV;W^1onM
^^d3ojJnj`CoY[o/1onU_n`3ojBnk0?oY;o/1onW_n/7ojS0j`OoYl3[00?oY[o/ojJojonV_n/01?nV
_n/7ojK0k003ojO1k?nW`>_oYl3[00CoYl3[1_nX`>/2ojO0j`_oYko[0_nX`^`7ojW3k0KoZL;/2?nX
`N/00on/a>co/<c^ok3<kP05ok3<kP03ok;<k_n^bNgo[/W]00?o[/W]1_nO]nT6ohjSh`KoPYKN1_n9
W>05oj2fj0?o[lK[0oo1f^`5okoLkP;o^=?^1On_b^h4ojNoj`03o`000?nW_n_oYko[00;oYl3[1OnX
`>/6ojW2k003ojS1k?nV_^_oY[k[00GoY[k[2oooool00ol0003oooooooooo`06ooooo`004oooool0
1?l0003oooooooooooooool3o`0002gooooo0onV_n/3ojNoj`SoZ<3[0_nS_^d4oiZkk`GoR:k_1On2
Z>d7oj6hj@03okc:iOo7c]ooalkO00CoalkO1Oo<d=`00oo9d^7o`lgRol?=hP06ol?=hP03ojc5k?nT
`>goY<3]00?oY<3]1_nH^Nh5oifjk@03oinlkOnV_ncoY[o/00KoY[o/1onU_n`6ojBok0GoYko[0_nW
`>`7ojS0j`GoYl3[0_nX_n/7ojJoj`?oY/3/1?nW_n/7ojO0j`?oZ<3[3?nW_n/6ojS2k0GoZL?/2?nY
`^`6ojS1j`03oj[5kOn`c>ko/<c^00Go/<c^00?o/<g_ojk9kOn^bNd01On^bNd6oingj@KoSZ?S1On2
U]h7ohVLh003oj2fj?n_a^_o[lK[00Go[lK[00?o`M[/okoLk_nog>h00onog>h2okWGk`Oo[l[^1?nW
_n/00ol0003oYko[ojS0j`07ojS0j`;oZL;/1OnX`N`7ojJnj`[ooooo00?o0000ooooooooool01_oo
ool001?ooooo1?l0000aooooo`KoYko[2?nX`>/6oiZkk`GoR:k_1On2Z>d5oj6hj@?o[l;X0oo7c]l7
olc@g003olg>f_o3cN;o`lgR00Go`lgR0_o0b^86ojC0k@KoV;W^00?oWK[]oinlkOnO_>d00onO_>d8
ojJok0OoYKo/1_nT_n`00onW_n_oYl3/ojO0k004ojO0k0OoZ<3[00?oYl3[ojRojonX_n/01?nX_n/5
ojJoj`WoYko[1OnW`>/=ojNoj`;oYl7/2?nX`^`00onY`ncoZL;/ojW2k00:ojW2k0;oZ<7[1OnZaNd4
ok3<kPCo/<g_1on^bNd3oingj@;oTjCQ1_n7Um`4ohJGg@;oPYKN0on9W>03oiV^iPOo[lK[0_nmfNh3
okoLkPGo^MO_1On_b^h2ojS1k0CoYko[00?o0000ojNojonX`>/01OnX`>/00onY`^coZ<7/ojS1k006
ojS1k0KoY[k[2_ooool00ol0003oooooooooo`06ooooo`004oooool2o`0003Cooooo1_nW_n/8ojS0
j`KoV[__1On8[^l5oh:Xk@03oj6hjOn_`^So[l;X00Go[l;X00?oalkOolc@g?o<d=`01Oo<d=`3olg>
fPCo`lgR1Oo0b^86ojC0k@?oV;W^0onH^Nl6oinlk@SoY[o/1onU_n`3ojBok0?oY;o]1onW`>`7ojS0
j`OoZ;o[00?oY[o[ojNojonW_n/02onW_n/00onW`>_oYko[ojNoj`0;ojNoj`KoYl7/1_nX`^`00onY
`ncoZL;/ojW2k009ojW2k0?oZ<7/1onZaNd00on`c>ko/<g_ok3=k`05ok3=k`?o[/W]0onR]^L6oi>T
h@KoQiOL1On6Umd7oiV^iPCo[lK[1OnmfNh00onog>ko^MO_okWGk`05okWGk`03ojo:k_nX`NcoZ<7/
00CoZ<7/0onW_n/00ol0003oYko[ojNoj`02ojS0j`GoZL;/1_nX`N`00onV_n_oY[k[ojJnj`05ojJn
j`Wooooo00?o0000ooooooooool01_ooool000Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Sooooo00?o0000ooooooooool0<_ooool3ojNoj`CoYl3[1onX`>/3oiZkk`;oTKK`1On0Zo06ohV]
k@Ko[l;X0onha^@5olc@g0GocLkJ00?o`lgRol3:h_o0b^801_o0b^83ojC0k@?oWkg^1_nH^Nl6oinl
k@SoY[o/1_nU_n`7ojBok@GoYl3/0_nV`>`7ojS0j`GoZ;o[0_nX`>/HojNoj`?oYl3/1onW`N`2ojS2
k0GoZL?/1_nY`^`00onX`^coZ<7/ojS1k005ojS1k0GoZ/G]0on_cNl5ok3=k`03ojg8kOnR]^OoX[KW
00GoX[KW1_nCY>46ohNGg0GoQYOM1onI[^H00on_a^_o_MW^okgIkP04okgIkP;o_mo`1_nienl00ona
c^ooZ<7/ojS1k006ojS1k0?oYko[00?o0000ojO0jonW`>/01onY`^`2ojS1k0GoY[o[1onV_^/8oooo
o`03o`000?oooooooooo00Kooooo00001OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`09ooooo`03o`000?oooooooooo03?ooooo1_nW`>/5ojS0j`;oY/3/1OnA]_05
oh2[l0KoRJg]0on_`^P6okS6i0?oc=3L1Oo=c]X3olc<fPKo`<[R0_nlan86oinmkPKoV;W_0onO_>d4
oj2mkPOoY[o/1_nU_n`7ojBok@03ojO0k?nV`>coY/3/00CoY/3/1onX`>/00onX_n_oZ<3[ojS0j`04
ojS0ja?oYko[2?nW`>`5ojO1k0;oZ<?]1onY`n`2ojW2k0GoZ<;/1onX`N`00onZaNgo[lg_ojo=k`05
ojo=k`03ok3=kon]b>go[LS]00?o[LS]1_nR]^L6oi>Th@KoQiOL1On6Umd6oiV^iP;oZ;oZ1?nmfNh5
okoOl0;o^MO_1Onac^l6ojS1k003ojNojonW`>_oYl3[00;oYl3[00?o0000ojO0jonW`>/01_nY`^`7
ojJoj`KoY[k[00?oYko[ooooooooool01_ooool00ol0003oooooooooo`06ooooo`0000CooooooiRH
V?lQ8B7ok^k^1?ooool01Ol@413ooooooooooooooooo410@00[ooooo00?o0000ooooooooool0<ooo
ool6ojO0j`03ojS0jonV`>coY/3/00CoY/3/1OnA]_05oh2[l0KoRJg]00?o[l;XokS6i?nha^@01_nh
a^@00oo<d=cocLkJolg>fP03olg>fPGoc<cJ0oo0b^85okc7hPKoWkg^0onH^Nl3oiRkl0OoX;g^1onV
_n`6ojFok0OoY;o]1onV`>`3ojS0j`CoZ<7/1onX`>/3ojNoj`?oZ<3[2OnW_n/<ojO0k003ojO1k?nX
`ngoZ<?]00CoZ<?]1OnY`n`9ojS2k0?oZ<7/1?n[b>l6ojo=k`03ojo>l?n]b>go[LS]00Go[LS]1_nR
]^L6oi>Th@KoQiOL1On6Umd2oiV^iPKoZ;oZ00?o_MW^okoOl?nogo001?nogo000onifO3o/Lk_ok7>
k`06ok7>k`;oZ<7/1OnW_n/4ojO0j`03o`000?nW`>_oYl3[00KoZL;/1onV_n/2ojJnj`GoYko[1ooo
ool00ol0003oooooooooo`06ooooo`000_ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooo
ooooooooool000002oooool2o`0003Cooooo0onW`>/3ojS0j`OoY/3/1OnA]_05oh2[l0?oRJg]1?nG
]N`6okS6i0?o`<OP0oo=c]X7olc<fP03ol3:h_nlan;o_<OR00Go_<OR0onO_Nh3oifmkPKoV;_`1onP
_Nh7ojJok0KoYKo/1onT_nd5ojK0k0;oYL7]1onX`N`5ojS0j`;oZ<7/1_nX`>/5ojNoj`;oYl7/2_nW
`>`;ojS3k@03ojW3k?nX`^coZ<;/00WoZ<;/0_nXa>d7oj_8k`;o[lg_1On_c_07ojg8k@?oX[KW0_nF
X]d6ohbGf@KoRIKJ1_nFZN<6ojRojP?o^MW`0onogo04okWIl0Ko/Lk_00?oZL;/ojNojonW_n/01OnW
_n/4ojO0j`03o`000?nW`>_oZ<7/00OoZL;/0onV_n/3ojJnj`SoYko[1oooool00ol0003ooooooooo
o`05ooooo`000oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000003Ooo
ool00ol0003oooooooooo`0booooo`KoZ<3[1OnV`>`2oj6nk@KoR[?a1OmkZ_46oiNek0?o^<KT1_o0
an000oo=c][oc<cJolc<fP05olc<fP;ob/SI1_nlan82ok[4hPKoWKg^1_nH^o03oj2mkPCoWko_1onV
_n`6ojFok0OoY;o]00?oY/3/ojG1kOnU`Nd01?nU`Nd7ojS1k003ojS0jonX`NcoZ<7/00CoZ<7/1_nX
`>/00onW_n_oYl7/ojO1k004ojO1k0GoYl3/0_nW`nd<ojS3k@;oZ<;]2?nX`^`6ojS4k@GoZlS_0_n]
c_47ojo>l0?o[LS]0onP[n<6oiJRg@KoS9OI1_n9U]X6oiJYh`?oZ;oZ1_nifO000onogo3o^MW`okWI
l004okWIl0;o/Lk_1OnY`^`7ojNoj`;oYl3[0_nX`N`00ol0003oZ<7/ojS1k005ojW2k0;oYko[1_nV
_^/6ojNoj`03ojS0jooooooooooo00Gooooo00?o0000ooooooooool01Oooool000Cooooo00Go0000
oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00cooooo00?o0000ooooooooool0<_oo
ool6ojS0j`03ojK0k?nQ_^goXKk]00CoXKk]1_n:/o45og^Zl@KoUkG/00?o^<KTol37h?o0an001?o0
an02olC7g0Koc<cJ1?o:b=T3okc7hPGo^/CR1_nM_Nh3oiRkl0?oUkca1onO_nl5ojJok0;oY/3/1_nU
_n`5ojBok@;oY<3]1onU`Nd3ojS1k0?oY/7]2?nX`N`3ojS0j`?oYl;]1onW`N`00onW`>coYl?]ojO3
k@04ojO3k@SoZ<?]1_nX`^d7ojS2k0OoZ<C]00?oZlS_ojg>lOn]c_401?n]c_45ojo>l003oj[0j_nP
[n?oX:oS00GoX:oS1_nFX]d6ohbGf@GoRIKJ1onFZN<00onX_n[o^MW`okWIl004okWIl0;o_N;a1Oni
fO02ok;?k`OoZL;/0onW_n/4ojO0j`CoZ<7/00Co0000ojS1k?nX`NcoZL;/1_nW_n/6ojJnj`;oYko[
1OnX`>/6ooooo`03o`000?oooooooooo00Gooooo00001Ol0003o^[ZjoooooonHV9So410@00?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0?ooooo`03o`000?oooooooooo03;ooooo1onX`>/6oj6nk@Ko
R[?a1OmkZ_43oiNek0?oX[_[1Oo0an04olC7g0?oc<cJ1oo:b=T00onlan;o^/CRok[4hP05ok[4hP?o
WKg^0onM_>h6oiNll@OoWko_00?oY[o/ojK0k?nV`>`01?nV`>`6ojFok003ojBokOnT`>goY<3]00Co
Y<3]1OnU`Nd2ojC0k@KoY/7]1_nX`N`2ojK2k@KoYl;]1OnW`N`9ojO3k@?oZ<?]2onX`^d7ojS2k0Go
Z<C]0on/cO46ojg>l@03ojo>l?nZ`>[oZ/3Z00?oZ/3Z1_nP[n<6oiJRg@KoS9OI1_n9U]X3oiJYh`Co
YKg[1?nifO05okgRl@03okWIl?nbcnoo//o_00Co//o_1OnY`^`00onW_n_oYl3[ojO0j`06ojO0j`?o
Z<7/00?oZL;/o`000?nY`^`02?nW_n/3ojJnj`;oYko[2?nX`>/5ooooo`03o`000?oooooooooo00Go
oooo00001OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0@oooo
o`;o0000=?ooool6ojS0j`KoXKk]0on:/o42ohFalPGoNj_a1onR^n/3ol37h0Koa<OL00?oc<cJol[8
fOo:b=T01Oo:b=T2olS5f0Ko^/CR0_ni`^06oiflkPKoUkca0onO_nl4oijol0OoY/3/1onU_n`6ojC0
k@03ojG1kOnT`>goY<3]00CoY<3]1_nV`Nd2ojS1k0KoY/;]1_nW`^d00onW`NcoYl?]ojO3k@09ojO3
k@;oYl;]2_nX`^d3ojS1k0SoZ<;/00?oZ<C]ojc=lOn/cO401On/cO43ojg>l@;o[L[_1onZ`>X6oj2_
h`KoUZ;M1_n<UmT3ohVFfP?oUjWR1onU_N/00onifO3o_N;aokgRl@04okgRl@;o^=[b1onbcnl00onY
`^coYko[ojNoj`03ojNoj`KoYl3[00?oZ<7/ojW2k?nY`^`00_nY`^`00ol0003oZL;/ojW2k006ojNo
j`03ojJnjonW_n_oYko[00CoYko[1_nX`>/00onX`Ncoooooooooo`03ooooo`03o`000?oooooooooo
00Gooooo000Oooooo`03o`000?oooooooooo03;ooooo1_nX`>/3oj6nk@?oW;g_1On5/O85og^[l@Oo
X[_[00?o`<OPolC7g?o4am`01?o4am`3olO7fPGob/SI1?o8aMP3ok[4hPGo^L;P1_nM_>h3oiNll@Co
Ukgb1_nN_o05ojK0k0;oYL7]1onU_n`3ojC0k@?oYL3]1onT`>d3ojK1k@?oYL7]2?nV`^d3ojO2k@Co
Y/;]1onW`nd6ojO2k@GoZ<;]2?nX`N`6ojS2k0;oZL[a1_n/cO400on/c_;o[L[_ojg:k`04ojg:k`Oo
Z/3Z0onP[n<2oiNNf@KoSiKF1_n=UmT7oiNYhPGoYKg[0_ngf_84okgRl@Go^=[b0onbcnl3ojW2k0Oo
Yko[0_nW`>/5ojS1k0CoZL;/00?o0000ojW2k?nY`^`00_nW_n/5ojJnj`KoYko[0_nX`>/5ojS1k0Co
oooo00?o0000ooooooooool01Oooool0023ooooo00?o0000ooooooooool0<_ooool6ojS0j`KoW;g_
1On5/O85og^[l@GoX[_[0_nY_nT5olC7g0GoalOJ0oo:b=T6olS5f003ok[4h_ni`^3o^L;P00Go^L;P
0onM_>h3oinlk@OoUkgb1_nN_o000onV`>coYL7]ojG1k@04ojG1k@GoYKo/0_nV`>`6ojG0k@GoY<3]
2?nU`Nd6ojK2k@03ojK1kOnV`^goY/;]00KoY/;]0onW`nd:ojO2k@03ojS2kOnX`NcoZ<7/00[oZ<7/
0_nX`^`6ojW:l@;o[<ga1On/c_86ojg:k`?oZ/3Z0onMY]`6oiNNf@KoSiKF1_n=UmT7oiNYhP03ojFm
jongf_;o]m[b00Co]m[b00?o_N;aokSJl_nhf_801?nhf_800onac^ooZL;/ojW2k005ojW2k0GoYko[
0_nW`>/7ojS1k0?oZL;/00?oYko[o`000?nW_n/02?nV_^/3ojNoj`;oYl3[2?nX`N`3ooooo`03o`00
0?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo03;ooooo1_nX`>/6oibmk`GoQK7b1Omk
Zo400onR^n_oZKoYojVoj@04ojVoj@?oa<OL1oo7amX00oo:b=Wob<GHolS5f004olS5f0;oal?F1_ni
`^02okZog@KoWkc]1onG_O83oijol0CoVl3b1_nU`Nd00onU_ncoY/3/ojK0k004ojK0k0KoYL3]00?o
Y<3]ojG1kOnU`Nd02_nU`Nd2ojK2k@GoY/7]1onV`^d<ojO2k@;oYl7/2_nX`N`4ojO8l0GoZL[a0_nZ
c_<7ojc>lP?o[L[_0_nU/N47oifVg0KoUikI1_n?U]H5ohfGf@KoUjWR0_nV`Nd5okOJlP?o^n?c0onh
f_84ok7>k`OoZL;/00?oYko[ojO0jonW`>/01?nW`>/5ojS1k003ojW2k?nW_n_oYko[00;oYko[00?o
0000ojNojonW_n/01_nV_^/00onW_n_oYl3[ojO0j`04ojO0j`KoZ<7/00?oZ<7[ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`008_ooool00ol0003oooooooooo`0booooo`KoZ<3[0onL_Nl3
oiRkl0GoP;3c1Omm[O<7ojVoj@03olC7g?o7am[oalOJ00GoalOJ0_o7aMP5olS5f0Coal?F0oni`^05
okZog@KoWkc]2?nG_O86oi_0lP?oYL7]0onS`o07ojK0k0?oYL3]0onU`>`:ojG1k@[oY/7]1onV`^d8
ojO2k@KoYl7/1OnX`N`2ojO6l0OoYlS`00?oZL[aoj[>lonZc_<01?nZc_<5ojc>lP03ojVlionU/N7o
YK7Q00CoYK7Q1_nMY]`6oiNNf@KoSiKF1_n=UmT2oiNYhPKoY/7]00?o]m[bok_Slonkho<01Onkho<0
0onhf_;o/Lk_ok7>k`04ok7>k`?oZL;/0onW_n/8ojO0j`03ojS1k?nY`^coZL;/00?oZL;/1?nW_n/0
0ol0003oYko[ojNoj`02ojJnj`GoYko[1_nW`>/2ojS1k0GoZ<7[0oooool00ol0003oooooooooo`04
ooooo`008oooool2o`0003?ooooo1onX`>/5oiRkl0GoP;3c1Omm[O<5ojVoj@?o[/;X1Oo7amX4olO5
f0?ob<GH1_o7`mH00oni`^3o^[oMokZog@05okZog@?oWkc]1?nT^^T7oiNmlP?oVl3b0onH`?<6oj?3
l0GoY/3/0_nV`nh6ojG0k0GoYL7]0_nV`>`=ojK1k@OoY/;]0onW`^d;ojO1k003ojS1k?nWa_3oYlK`
00CoYlK`1OnWb?02ojW>l`OoZ/kc00?o[<kbojVlionY_>L00onY_>L6ojFah@KoWJKL1_nGW]T6ohnF
eP?oSIOI0_nK[^@7ojK1k@;o]]od1_nkho<2okKJl`Go/Lk_0_nX`N/6ojNoj`KoYl3[00?oZ<;/ojW2
k?nY`^`01OnY`^`3ojNoj`03ojJnjol0003oY[k[00SoYko[0onW`>/2ojS1k0SoZ<7[0_ooool00ol0
003oooooooooo`04ooooo`009Oooool00ol0003oooooooooo`0booooo`KoZ<3[1OnH^o05oh2`l`Go
OJgc00?oZKoYojk2j?n^`^P01On^`^P3olO7fPKoalGH00?ob<GHolO3e_o7`mH01?o7`mH2olK0e0Ko
^[oM0_nl_MX8ojBjj@?oUkgb0onI_O46oiS0l`KoXl?`00?oY/3/ojK3k_nV`nh01?nV`nh6ojG0k003
ojG1kOnV`>coY/3/00CoY/3/3OnV`Nd5ojK2k@;oYl7]3?nW`N`9ojO6l003ojO8l?nYc_?oZLkc00Co
ZLkc0onZc_<3oj[4k0OoZKcW1_nU/N43oifVg0;oUiWC1_nBU]@6oi6LfPKoVjkT1?nV`Nd5okKOm0;o
^n?c1_nff_<00onac^ooZ<7[ojS1j`04ojS1j`KoYko[0_nW`>/5ojS2k0GoZL;/0_nW_n/4ojJnj`03
o`000?nV_^_oYko[00GoYko[00?oYl3[ojS1k?nX`N`01?nX`N`6ojS1j`04ojNojoooooooooooo`00
00Kooooo000Vooooo`03o`000?oooooooooo03;ooooo1_nX`>/2oiRkl0CoU;[a1Oml/?@4ognam0So
[/;X00?oalOJolO5f?o7aMP01?o7aMP2olO4f0Goal?F1?o6`=@3okZog@Go_;gJ1_nT^^T2ojbih`Ko
VKga1_nH`?<3oj?3l0?oWL?c1onV`nh3ojG0k0?oY/;^1onV`>`3ojK1k@CoY/7/1_nV`Nd00onV`^go
Yl7]ojO1k@04ojO1k@SoYl7/2onWa_02ojO=m0GoZLkc0_nYb>l6oj[4k0OoZKcW0onU/N42oibNe@Ko
UiWC1_nBU]@6oi6LfPKoVjkT00?oY/7]okKOm?nfgo@01?nfgo@2okSRm0Ko]][c00?o[/__ojS1jonX
`N/01_nX`N/3ojNoj`;oYl3[2?nX`^`00onY`^coYko[ojNoj`04ojNoj`?oY[k[00?o0000ojJnjonV
_^/00_nW_n/5ojO0j`KoZ<7/0_nX`N/5ojNoj`03ooooool0003ooooo00Gooooo000Wooooo`03o`00
0?oooooooooo03;ooooo0onX`>/3ojO0j`KoU;[a1Oml/?@4ognam0Ko[/;X0_n``^L5olO5f0CoalCH
0oo7`mH6olK0e003okZogOnl_M[o_;gJ00Go_;gJ0_nT^^T6ojbih`KoVKga0onH`?<3oiS1m0KoWL?c
1OnV`nh2oj76lPKoY/;^1OnV`>`2ojK4kPOoY/7/0onV`Nd3ojO3kPOoYl7]0onW`N`4ojK7l@SoYlK`
1_nWcO@00onYc_?oZLS_ojW8k`04ojW8k`KoZ/C/0onY_>L3oj2Tf0KoW9kE1OnGVM<7oi:Fe0GoTIcJ
1OnK[^@3ojW:l@?o]]od1Onhh_@2okKJl`Go[/__1_nX`N/00onW_n_oYl3[ojO0j`04ojO0j`OoZ<;/
2?nW_n/3ojJnj`03o`000?nW_n_oYl3[00OoYl3[0onX`N`4ojS1j`KoYko[00?o0000ooooooooool0
1?ooool002Sooooo0_l0000cooooo`KoYl3[1_nD^_45ogb`m0CoOk7d0_n^`^P6ok32i`?oalGH1_o7
a=P00oo7`mKoa/3DolK0e004olK0e0;oa[kB1_nl_MX2okfiePSo[;WS0onI_O43oijjk0KoV<7d1_nM
`o<00onV`nkoXLKboj76lP04oj76lPKoY/;^00?oY/3/ojK4k_nVa>h01?nVa>h5ojK1k0;oYLOa1_nW
`nh5ojO1k@;oYLWb1onVao43ojO6l0CoYLgd1OnWcO@2ojS9l@OoZLS_0onZa>`2oj>XfPOoX:CH1_nL
W]D5oiNId`KoTYKD1_nAW=X00onK[^CoZL[aojW:l@05ojW:l@03okKOm?nhh_Co^>;d00?o^>;d0onc
eo<6ojk;k`;oZ<7[1OnW_n/6ojO0j`OoZ<;/1_nW_n/00onV_^_oYko[ojNoj`02ojNoj`03o`000?nW
_n_oYl3[00GoYl3[00?oZ<7/ojS1jonX`N/01_nX`N/3ojNoj`;ooooo00?o0000ooooooooool01?oo
ool002[ooooo00?o0000ooooooooool0<Oooool6ojO0j`?oU;[a0onC^_85ogZ`mPGoPK?e1on``^L0
0oo7aMSoalCHolO4f004olO4f0;oaL?H1Oo6`=@4olJndP?o_;gJ1Onm^MH6ojbih`;o/kSL1_nN^^`6
oiS1m0?oWL?c1?nI`oD6oj76lP?oY/;^1?nSao<6ojK4kP03ojK1k?nUao7oYLOa00CoYLOa1_nW`nh0
0onW`NgoYLWbojG9lP04ojG9lPGoY/Oa0onTcOD6ojG=m003ojO=m?nXbO7oZ<Wa00CoZ<Wa1OnYb>l0
0onV[=_oXjSJoj>XfP04oj>XfPKoX:CH1_nLW]D5oiNId`OoTYKD0onAW=X3oj2fj0KoZL[a0onei?H0
0onhh_Co/mOcok?Gl`05ok?Gl`?o[/__2_nW_n/3ojO0j`[oZ<;/0_nW_n/5ojJnj`CoYko[00Co0000
ojNojonW`>_oYl3[1OnX`N`6ojS1j`Oooooo00?o0000ooooooooool00oooool002_ooooo00?o0000
ooooooooool0<Oooool6ojO0j`KoTk[b1Omj/?H5oh6cm@Go/<;W0_n``nL5olO4f0CoaL?H0oo6`=@6
olJndP03okbmf_nm^MKo_KWF00Go_KWF0on/^N<5ok>hg0KoW[[/0onH`O@4oiVnl@KoVL?e0onQa_84
oi_5m@KoXlOc0onVa>h4oj;9m0KoYLOa0onW`nh4oj?;m0KoYLWb00?oY/OaojC=mOnTcOD01OnTcOD3
ojG=m0CoY/Sa1_nXbO400onYb>ooYZcKojJ/f`03ojJ/f`KoXjSJ1OnPY=P7oibNe@GoUiWC0onBU]@3
oiVWg`OoX;KX0_nYb_45okGTmP;o]=ke1_nceo<00onZa>goYko[ojNoj`0:ojNoj`03ojO0jonX`^co
Z<;/00WoZ<;/0_nW_^/8ojJnj`?oYko[00?o0000ojO0jonX`N`01onX`N`2ojS1j`[ooooo00?o0000
ooooooooool00oooool002cooooo00?o0000ooooooooool0<Oooool6ojO0j`KoTk[b1Omj/?H5oh6c
m@03ok32ion``nOo/<?W00Co/<?W0oo7a=P6olG3f003olK0e?o6_];oa[kB00Goa[kB2Onm^MH00on/
^N?o/kSLok>hg005ok>hg0?oW[[/1?nX]N86oiVnl@?oVL?e0_nI`O<8oi_5m@?oXlOc0_nLaoH8oj;9
m0?oYLOa0onObOH7oj?;m0?oYLWb1?nRc?H5ojC=m@03ojG6lOnVb?7oY/Sa00KoY/Sa0onXbO42ojN^
g@OoYZcK1_nSZ=X5oj2Tf0?oW9kE0onHV=85oiJLe`OoVJOO1OnP]^P3ojgImP?o]NCf1Ondg_D2ok?G
l`GoZ/C]2?nW_n/5ojO0j`KoZ<;/00?oZ<7/ojNnjonW_^/01?nW_^/6ojJnj`03ojNojonW`>_oYl3[
00;oYl3[00?o0000ojO0jonX`N`01OnX`N`=ooooo`03o`000?oooooooooo00?ooooo000]ooooo`;o
0000<_ooool6ojO0j`KoTk[b1Omh/OL6oh2emPKo/<?W00?oalCHolG3f?o5`mP01?o5`mP00oo3`m[o
a[kBolJndP05olJndP;oa[cA1onm^MH00oo0]m7o/kSLok>hg005ok>hg003okVdeOnX]N;oZ;GR00Ko
Z;GR0onI__42oj:fi`KoVL7c1_nKaOD00onK`oCoW<Ofoic7mP04oic7mPKoX/Wd00?oWLSfoio9m_nO
bOH01OnObOH3oj?;m0CoXL[e1onRc?H00onTcOGoYLKaojG6l@03ojG6l@KoY/Sa1onW[]d7ojJ/f`?o
XjSJ0_nOVm05oi^Hd0OoV9SB1OnFW=L7oiVWg`03oj2fj?n]fOKo[MWf00Go[MWf00?o]NCfokCNmOnd
g_D00ondg_D2ok3@l@OoZ/C]0onW_n/:ojO0j`;oZ<;/1OnX`N`6ojNnj`;oY[k[1OnW_n/4ojO0j`04
o`000?nW`>_oZ<7/ojS1k13ooooo00?o0000ooooooooool00oooool002oooooo00?o0000oooooooo
ool0<?ooool7ojO0j`GoTk[b1Omh/OL6oh2emP?o/<?W0on_a>X5olG3f0?o`l?J1Oo6_]84olJld@Co
_KWF1?o0]m44ok>hg0Co^KCE1_nX]N800onb/mWoX[KWoj:fi`04oj:fi`KoVL7c0_nKaOD5oi_3m0Ko
W<Of0_nRbO@5oig8mPGoWlWf0_nPa_<7oj7:m@?oX/cf1?nT`^h6ojG6l@;oY/Sa2_nW[]d6ojJ/f`03
oj6Md?nOVm3oWi_@00CoWi_@1OnKV=06oiRHdPKoUYcG1OnIYml2ojG6l0Ko[MWf0onciOL00ondg_Go
/=3aok3@l@04ok3@l@GoZ/C]00?oYko[ojO0jonW`>/02_nW`>/00onX`^coZ<7/ojS1k006ojS1k0?o
Ykk[0_nV_^/8ojNoj`?oYl3[00?o0000ooooooooool04Oooool00ol0003oooooooooo`03ooooo`00
<?ooool00ol0003oooooooooo`0aooooo`KoYl3[1OnC^_85ogRam`?oP;Gf0omk]OP6ojo4jP?oaL?H
1Oo3`mX3olJndPKoa[cA00?o_KWFol2gdOo0]m401Oo0]m400onc^=co^KCEokVde@04okVde@CoZ;GR
1?nb/mT6oj:fi`?oVL7c1?nP^>T6oi_3m0?oW<Of1?nM`o86oig8mP03oio9m_nPa_?oX<Kc00CoX<Kc
1OnQb_D2ojFjj@OoY<;^0onUa_42ojN]f`goYjkM0_nV[=/5oj6Md0GoWi_@1_nKV=05oiRHdPOoUYcG
00?oVJOOojG6l?nUa_001?nUa_02ojgImPGo/nGg00?o/=Weok3@lOn`d?401_n`d?400onZa>goYko[
ojNoj`03ojNoj`SoYl3[1OnX`^`6ojS1k003ojNnj_nV_^_oY[k[00CoY[k[1_nW_n/5ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool00oooool0037ooooo00?o0000ooooooooool0<Ooo
ool7ojO0j`GoU;_b1Omi/oL5og^en0Ko[lCZ00?oaL?Hol?3f_o3`mX01Oo3`mX00oo6_];oa[cAolJl
d@04olJld@03olJndoo0]m7o`;OA00Go`;OA00?o`[K?okVdeOni]=D01_ni]=D00onX]N;o/[?Iok:c
f@04ok:cf@GoX[KW0_n^/MX7oj2hj@?oVl?d1?nR]^L6oig3lP?oWLSf1?nQ_Nd6oj36l`03oj7:mOnU
^^WoYK[Y00CoYK[Y1OnT`^h00onXZ]SoYjgKojN]f`04ojN]f`[oYjkM0_nTW]07oj6Md0KoWi_@1OnK
V=06oiRHdP?oUYcG1?nQ]nP5ojG6l0Co[^Ci00?o/nGgok3ImOn`fOD00on`fOD6ok3@l@03ojS0jonW
_n_oYko[00GoYko[0onW`>/4ojS1k0KoZ<;/0_nX`N`5ojNnjPKoY[k[0_nW_n/9ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool00oooool003;ooooo0_l0000booooo`OoYl3[1OnD^o85
ogVcm`GoNkGh0on_a>X3ojW5kPKo`l?J0_no`md5olJld@?oa[kC1Oo0]m43ol:fc`Ko^KCE00?o_;7?
ok:cfOnb/mT01_nb/mT00onR]^Oo[[7JojjafP04ojjafPGoX;SY0_n/[mX7oj:fi`?oWL?b0onU/N47
oj6mk@?oX<Kc0onV/^47ojFjj@03ojC2k_nXZ]SoZ:[H00?oZ:[H1_nW[M/5ojN^g@03ojFOd?nTW]3o
Y9k@00CoY9k@1_nQWM06oinKd0KoViS@0onHV=83oij]h@OoXKOX00?oYLK`ojkTnOn^i?T01?n^i?T2
ok3Om`Ko/=We0_n`d?45ojS0j`GoYko[0_nW`>/7ojS1k0?oZ<;/0_nX`>/8ojNnjP?oY[k[3_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo000dooooo`03o`000?oooooooooo
033ooooo1onW`>/2oiBklPCoV;ca1?mk]OP5ogBen@KoZLG^0oo3`mX5oko3g@?oa[cA1Oo6_]<3ol2g
d@Go`[K?0oni]=D4okbac`Ko/[?I00?o]jk@ojjaf_n^/MX01_n^/MX00onP^>Wo[:oJojb_fP04ojb_
fPGoX[KW00?o[JgGojFahOnU/N401OnU/N45oj6mk@03ojV/fOnV/^7oY[;Q00GoY[;Q1OnU^^T00onZ
Z=GoZ:[HojRZf005ojRZf0KoYjgK00?oYjkMojFOd?nUWm000onUWm06ojBNd0KoXIg@1_nOVm03oi^H
d0;oWJCK1onN[N45oj6gj0;oZMci1?n^i?T5ok3Om`?o/=We1?n[aNd6ojS0j`03ojNojonW`>_oYl3[
00CoYl3[1OnX`N`00onX`^coZ<3[ojS0j`04ojS0j`KoYkkZ4_ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo00;ooooo000eooooo`03o`000?oooooooooo033ooooo1OnW`>/2ojS0j`Ko
V;ca1?mk]OP5ogBen@KoZLG^00?o`l?Joko3gOno`md01Ono`md00oo6_=7oa[kColJnd`05olJnd`03
ol2gdOo2]/oo`[K?00Go`[K?00?o^KCEokbaconl/Ll01?nl/Ll3ok:cf@Co]jk@1_n^/MX00ond[=3o
[:oJojb_fP06ojb_fP03oj:fion][MOo[JgG00?o[JgG1onU/N400onQ_NgoZJcIojV/f@03ojV/f@Oo
Y[;Q00?oYK[YojZXeOnZZ=D00onZZ=D7ojRZf0?oYjgK0_nWWll7ojFOd0GoY9k@1_nQWM03oinKd0?o
WZ7F1_nMY=/7oij]h@03oj6gj?nYg?WoZMci00CoZMci00?o[^Ciok3Omon`goL01?n`goL00on^c_7o
ZlG]oj_5k@06oj_5k@?oZ<3[2_nW`>/00onX`NcoZ<;/ojS2k003ojS2k0KoZ<3[0_nW_^XFooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool003Kooooo00?o0000ooooooooool0
<?ooool00onW`>_oZ<3[ojS0j`04ojS0j`KoV;ca1?mk]OP5ogBen@?oZLG^0onPaO<6oko3g@;o^<CS
1_o6_]<00oo3`=So`[K?ol:fc`05ol:fc`03ol>jdOnl/Loo_;7?00Ko_;7?00?o/[?IokN^d?ng[]00
1?ng[]03ojjafPCo]:c@1_n/[mX00oncZLoo[JgGojf]e`05ojf]e`GoYK7Q00?o[ZSBojV/fOnY[=T0
1OnY[=T5ojJbh@03ojbUdOnZZ=GoZZSE00GoZZSE1OnXZ]P00onXWlgoYio?ojNOc`04ojNOc`KoYIo@
1_nTW]03oj6Md0;oXIoC1onNXMH5oifTf`KoWZgQ0_nUcoH5ojWLn@Co[^Ci00?o/=ogojk>lOn^c_40
0on^c_46oj_5k@03ojNojonW`>_oYl3[00[oYl3[2?nX`^`3ojS0ja_ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`02ooooo`00=oooool2o`00037ooooo1onX`>/3oiRll@?oW;g_1On1
]oL5ofncnPGoX<Gc0ono`md5okS4h`?oa[kC1?o3`=P5ol:fc`?o`k[A1_nl/Ll00ono/lko]jk@okN^
d006okN^d003ojjaf_nd[=3o]:c@00Co]:c@0on/[mX4ok>Yc`Oo[JgG00?oYK7QojjXd_n^Z=800on^
Z=87ojV/f@03ojJbhOn/YM7o[:GA00?o[:GA1onZZ=D00onXZ]SoZ9o=ojROc@03ojROc@KoYio?1_nU
Wm03ojBNd0;oXioA1_nQWm<6oijQePKoWJCK0_nN[N46ojG?mP03ojWLnOn^i?Wo[^Ci00Co[^Ci0_n]
e_D6ojk>l@;oZlG]1OnW_n/8ojO0j`[oZ<;/8?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00;ooooo000iooooo`03o`000?oooooooooo02oooooo1onX`>/6oibmk`KoPKOg1?m_/oX5
oj35l`03oko3gOnha>?o^<CS00Go^<CS00?oa[kCol?0f?o3`=P01?o3`=P3ol:fc`Go`k[A0onl/Ll4
oknccPKo]jk@00?o^jo=okB/d?nd[=001_nd[=000on/[m[o/jW?ok>Yc`04ok>Yc`Go[JgG00?o/JK=
ojjXd_n^Z=801On^Z=85ojV/f@03ojjTcOn/YM7o[:GA00Go[:GA1OnZZ=D00on[X<coZ9o=ojROc@04
ojROc@KoYio?1OnUWm000onUX=3oXioAoj>Od@04oj>Od@KoXIoC1_nNXMH3oifTf`CoY<G`1OnUcoH3
ojSUn`;o[^Ci1_n]e_D3ojk>l@?oZ<3[1onW_n/3ojO0j`?oYl7/2?nX`^`Sooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool00_ooool003[ooooo00?o0000ooooooooool0;oooool7ojS0
j`KoW;g_0on1]oL3ohJimPGoKkCj1On@a?T5okS4h`03ojo9kOo3`=So`l3H00Ko`l3H00?o`[K?ol>j
dOo3^]401Oo3^]400onl/Loo_k?>oknccP04oknccP?o]jk@1?nk[ld6okB/d003okV/c?ncZLoo/jW?
00Ko/jW?00?o[JgGok6VcOnaY/d00onaY/d7ojjXdP03ojV/fOn^Y<go[ZC=00?o[ZC=1on/YM400onZ
Z=GoZj3<oj^Pc003oj^Pc0GoZ9o=1onWWll00onUWm3oYJ3@ojFPd003ojFPd0KoXioA1_nQWm<3oijQ
eP?oY;g[1onTaO000onUcoKoZ>GkojSUn`03ojSUn`?oZm[h1On]e_D00onY`^coZ<3[ojS0j`05ojS0
j`GoYko[00?oYl3[ojO1k?nW`N`01OnW`N`3ojS2k2Sooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`02ooooo`00>oooool00ol0003oooooooooo`0`ooooo`KoZ<3[0onL_Nl4oj:nk@Go
Q[Wf1Om_]?X5oi34n@03okS4hon_bNgo[lW]00?o[lW]1_o3`=P2ok_3h0Ko`k[A00?o`;oIokncc_no
/lh01_no/lh00ong[]3o^jo=ok^_c@04ok^_c@?o]:c@1?ni[<`6ok>Yc`03okN[c?naY/go/JK=00Go
/JK=1On^Z=800onaYLco[ZC=ojjTc@05ojjTc@Go[:GA00?o[Z?<oj^Pc?n[X<`01?n[X<`6ojROc@?o
Yio?0onXXm46ojFPd0KoXioA1OnQWm<00onU^NOoY;g[ojBmj`05ojBmj`GoY<G`0onSi?`00onXiO_o
Zm[hoj_Jn005oj_Jn003ojgFmOnY`^coZL;/00?oZL;/1onX`>/00onW_n_oYl3[ojO0j`03ojO0j`Go
Yl7/;Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo007ooooo000looooo`03o`00
0?oooooooooo033ooooo1_nX`>/7oj:nk@GoQ[Wf1Om_]?X2oi34n@?oNkkl1_n_bNd3ol?0f0Go^l?P
0oo3^]44ol2of@Ko_k?>00?o`K_Dok^_cOnk[ld01_nk[ld00ond[=3o^Jc<okV/c004okV/c0?o/jW?
1?ngZl`7ok6Vc@03ojjXd_naYLco/JG<00?o/JG<1on^Y<d00on/YM7o[Z?<ojjSc003ojjSc0GoZj3<
1OnXWld00on[Y];oZ:?AojRSd@05ojRSd@GoYJ3@1onSWm400onQWm?oYKWWojFii`03ojFii`OoY;g[
00?oY<G`oj?To?nSi?`00onSi?`2ojSMnPKoZm[h00?oZ/K^ojW2k?nY`^`01OnY`^`3ojS0j`[oYl3[
00?oYl7/ooooooooool0;oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo007ooooo
000mooooo`;o0000<Oooool6ojS0j`GoX[k]0_nV_n`6ohnjl`GoM;Oj1?mk__`6ojo9k@03ol?0f?nk
`n3o^l?P00Go^l?P00?o`k[Aol2ofOo0_mT01?o0_mT3oknccPCo`K_D1_nk[ld00ono^=?o^Jc<okV/
c006okV/c003ok>YcongZlco]j_<00Co]j_<1OnaY/d00ong[<oo/JG<ok6Uc004ok6Uc0Ko[ZC=00?o
/ZS?ojjSc?n^Xl`01?n^Xl`6oj^Pc003ojROcOn[Y];oZjKB00?oZjKB1_nXXm46ojFPd0?oXioA0onV
]nD7ojFii`?oY;g[1OnQhO`00onSi?coZ=gjojSMnP04ojSMnP;oZm[h1OnZa^h5ojW2k0;oYko[2_nW
`>/dooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00Oooool003oooooo00?o0000
ooooooooool0;oooool6ojS0j`03oj:nkOnV_ncoY[o/00CoY[o/1_n?^_<5ogBgnPCoNkkl0on_bNd4
oic;m`Go^l?P00?o[l_^ol2ofOo0_mT01_o0_mT00ono/lko`K_Dol6ke004ol6ke0?o^jo=1?no^=<6
okV/c003okbge?ngZlco]j_<00Go]j_<0onaY/d4okN/c`Go/JG<1?n^Y<d4ok:Xc`Go[Z?<1On[X<`0
0on^[=GoZjKBoj^VdP05oj^VdPGoZ:?A1OnUX=000onW^>GoY[OUojJgi@05ojJgi@GoYKWW0onOg_d5
oj7Qo0?oYMok0onXgOX4oj_;l@KoZ/K^00?oZL;/ojNojonW_n/01?nW_n/5ojO0jcWooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`01ooooo`00@?ooool00ol0003oooooooooo`0_oooo
o`OoZ<3[1_nV_n`3ohnjl`CoVKc`1Omn^_T4ofjio0KoW<_g00?o^l?Pojo;k_n_bnh00on_bnh6ol2o
f@03okK6i_o1^mCo`K_D00Ko`K_D00?o^jo=oknhdono^=<01?no^=<4okV/c0?o_;OD1ongZl`00ona
Y/go]jc?okN/c`03okN/c`Ko/JG<00?o[ZC=ok:XconbZ<l01?nbZ<l6ojjSc003oj^Pc?n^[=Go[ZcE
00?o[ZcE1_n[Y]86ojRSd@03ojFPd?nW^>GoYkSU00?oYkSU1onV]nD00onU^NOoWmkmoioNo@05oioN
o@03oj7Qo?nUgo_oYMok00?oYMok0_nYc_<7oj_;l@?oZ/K^2_nW_n/00onW`>_oooooooooo`0koooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00Oooool0047ooooo00?o0000oooooooo
ool0;oooool7ojS0j`?oY[o/0onX`>/7oiVll0GoO[[i1?m^^O`3oic;m`?oO/Gn1_n_bnh3ol2of@Co
]/KV1_o1^m@00onh`n;o_kSCoknhd`05oknhd`?o^Jc<1Onl]m@5okN[c003okZif?ng[<oo]jc?00Co
]jc?1OnaYL`00onf/]Go/ZS?ok:Xc`05ok:Xc`Go[Z?<00?o/KCKojj/eOn^[=D01On^[=D6oj^VdP?o
Z:?A0onY^^H6ojNhi@GoY[OU1?nMfod3oioNo@CoXN3l00?oYMokojW>lonYc_<01?nYc_<5oj_;l@_o
Yko[@Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo007ooooo0012ooooo`;o0000
<?ooool5ojS0j`;oYl3[1_nX`>/5oiVll0;oXkk]1_n;^_H4og6io0GoO/Gn1_n_bnh00oo0_mWo]/KV
okK6iP04okK6iP?o`K_D1?nh`n87oknhd`03okV/c?nl]mCo_;OD00Co_;OD0ongZl`4okZif0Ko]jc?
00?o/JG<okJbeOnf/]D00onf/]D7ok:Xc`;o[Z?<1?na]=/6ojj/e@GoZjKB0_nZ_nT6ojVjiPKoYkSU
00?oY[OUoigKoOnMfod01?nMfod2oicPo@GoXN3l0_nWd?D7ojW>l`03oj_;lOnW_n_oYko[00SoYko[
A_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo007ooooo0014ooooo`03o`000?oo
oooooooo02kooooo00?oZ<3[ojO0jonW`>/01?nW`>/6ojS0j`03oiVll?nS_^goXkk]00CoXkk]1_n;
^_H4og6io0GoO/Gn0on_bnh4oiG>n`Ko]/KV00?o`K_DokS3h_nh`n801?nh`n85oknhd`;o]l;R1onl
]m@00ongZlco^[WHokZif003okZif0Go]jc?00?o]KgOokJbeOnf/]D01Onf/]D6ok:Xc`03ojjSc?na
]=_o/KCK00Co/KCK1_n^[=D00on[Y];oZ[oYojZoj@04ojZoj@KoZK[V0onW^>D6oigKo@KoW>3m00?o
XN3lojO@mOnWd?D01?nWd?D3ojW>l`CoZ<3[1onW_n]:ooooo`03o`000?oooooooooo00Oooooo0Ol0
0001ooooo`7ooooo0015ooooo`03o`000?oooooooooo02oooooo1_nW`>/7ojS0j`KoXkk]0on;^_H4
oiRll@CoOkgj1_m^_?d5oiG>n`?o]/KV0onRdOP7okS3hP03oknhdong`^;o]l;R00Co]l;R1Onl]m@0
0onda>Ko^[WHokZif004okZif0?o]jc?1?ne_Ml6okJbe@Go/ZS?0_n`_>86ok6df`Go[ZcE0_nZa^h7
ojZoj@?oZK[V1?nJg?d3oigKo@GoV=kn0onLh?d4ojGAm`?oYm3e2_nX`>/3ojNojdkooooo00?o0000
ooooooooool01_ooool1o`00007ooooo0Oooool004Kooooo00?o0000ooooooooool0<?ooool2ojO0
j`?oYl7/1onX`>/3oj>nk@CoYl3[1_nH_?44ognmnP?oK[cm1?mf_O`5og;3oPGoX]7h1Onh`n82ojKB
m`Oo]l;R00?o_;ODokC4i_nda>H00onda>H6okZif003okN/cone_Moo]KgO00Co]KgO1_nf/]D00onb
Z<oo/;cRok2lhP04ok2lhPKo/KCK00?o[ZcEoj[6k_nZa^h01?nZa^h5ojZoj@;oU=gn1OnJg?d3oiGL
oPGoV=kn0_nTd?L5ojGAm`goZ<3[D_ooool00ol0003oooooooooo`06ooooo`7o00000Oooool1oooo
o`00Aoooool2o`00037ooooo1OnW`N`5ojS0j`WoYl3[0onH_?43ojBnk0GoSk_d1_mf_O`5og;3oPGo
X]7h00?o^<?RojKBmonVd_L01?nVd_L5okO2hP03ojCDnOnda>Ko]<CV00Co]<CV1Onj^MP2ojo;kPOo
]KgO0onf/]D3ojk8k@Oo/;cR0ona]=/3ojO@m@OoZ/K^00?oZ[oYoiCMo_nDgOh01?nDgOh00onJg?go
UMcnoiGLoP05oiGLoP03oiSNo_nTd?OoY=3g00CoY=3g00?oYM7gojS0jonX`>/02onX`>]Fooooo`03
o`000?oooooooooo00Gooooo0Ol00001ooooo`7ooooo0019ooooo`03o`000?oooooooooo02oooooo
1OnW`N`00onX`>_oYl3[ojO0j`09ojO0j`;oZ<3[1_nT_^`5ohnkm0?oM[gl1?n9__P5og>oo@KoN<Wo
1OnVd_L00ong`^;oY=CiojCDn@03ojCDn@Ko]<CV00?o^[WHojo;k_n_bnh01?n_bnh5okFmg`;oXmKi
1_n^b>d5ok2lhP;oW]Wl1_nWd?D3oj[6kPGoSMcn0onDgOh5oi?JoP?oUMcn1?nRcoL3ojC@m`?oYl3[
2_nX`>]Jooooo`03o`000?oooooooooo00Cooooo0Ol00001ooooo`7ooooo001:ooooo`03o`000?oo
oooooooo02oooooo0_nW`N`4ojK0k0OoYl3[1_nX`>/6ojBnk0;oSk_d1?nN_Nh6ohVnn0GoLkom0omh
bOl4og?1oPKoN/co1?nTe?T3okC4iPCoVmOl1_n_bnh00one_MooXmKioj?Fn@04oj?Fn@Ko[/S]00?o
/;cRoikIo?nNfO`01?nNfO`3ojO@m@GoQm[o0on=g?h5oi;FoP?oTm[n0onQc?H5oj;?m`SoYl3[1OnX
`>]Oooooo`03o`000?oooooooooo00?ooooo0Ol00001ooooo`7ooooo001;ooooo`03o`000?oooooo
oooo02oooooo1_nV`>`3ojO0j`?oYl7/1onX`>/3ojBnk0?oZ<3[1_nN_Nh3ohVnn0CoV[g`1_n8`OX5
og?1oP?oN/co0omfa?h6ogS=o`GoVmOl0on_bnh5ohWFo`GoXmKi0on^b>d4oh_Io`?oW]Wl1On4e_l3
ohOJo`GoU=?m0onBe_h3oj78m0KoXLcf00?oX/ogojO0jonW`>/02_nW`>/00onX`>_oooooooooo`1P
ooooo`03o`000?oooooooooo00?ooooo0Ol00001ooooo`7ooooo001<ooooo`;o0000<?ooool4ojK0
k0;oYL3/1_nW`N`5ojS0j`;oYl3/1_nX`>/3oijmkP?oYko[1onJ_O03ohS1nPCoVKga1On9`oX5ogK4
oP?oN<go1?mmaoh6ogS=o`?oRMKo0ommcOl6ogkCo`?oRmWo1On5dOl3ohCFo`CoUlok1OnDdod00onR
a?7oXLSdoj78m005oj78m0?oXLcf1?nW_n/9ojO0jfKooooo00?o0000ooooooooool00oooool1o`00
007ooooo001>ooooo`03o`000?oooooooooo02kooooo00?oY/3/ojG0k?nU`>`00onU`>`6ojO1k003
ojS0jonW`>coYl3/00CoYl3/1_nX`>/6ojNoj`GoV[g`0_nV_n/7oiVml@;oRL?j0onK__07ohk3n@Go
OLOn0omhcOl4ohS:o@GoOLgo0omndol5ohc>oP?oQM7o1?nJb?L6oiO?n`03oiCCoOnRa?7oX/Ca00?o
X/Ca1OnQb?@9ojNoj`?oYl3[K?ooool00ol0003oooooooooo`02ooooo`7o00000Oooool004oooooo
00?o0000ooooooooool0;oooool5ojG0k0?oYl7/1?nV`N`6ojO0k0KoZ<3[1_nW_n/00onJ_O3oY[o[
ojJoj`04ojJoj`GoVKga00?oY[o[oi^nl?nK__001?nK__05ohk3n@;oWkk_1onD`_H5ohS:o@;oOLgo
1OnDaoT3ohc>oPCoW/7a1_nJb?L3oiO?n`?oY<3^1_nRa?400onQb?CoYko[ojNoj`09ojNojg7ooooo
00Go0000ooooooooooooooooo`000001ooooo`00D?ooool00ol0003oooooooooo`0_ooooo`;oYL3/
1?nV_n/6ojK1k0?oYl3/1?nW`N`5ojS0j`?oYko[1?nX`>/6ojJoj`03oiVmlOnV_n_oY[o[00?oY[o[
1_nK__000on>`oWoWkk_oinnk`04oinnk`GoU<;f00?oY;k/oi_0lOnK`?401OnK`?43oiC7n@?oY;o]
1onN`O43oi[8m`?oY[o/1_nT`>h3oj;4l@_oYko[M?ooool01Ol0003ooooooooooooooooo0000007o
oooo001Aooooo`;o0000<?ooool6ojJoj`?oY/7/0onU`>`7ojO1k0;oZ<3[0onW`N`7ojS0j`?oY[o[
1?nX`>/5ojJoj`?oVkk`1?nV_n/6oinnk`03oiC2m_nT_^coY;k/00?oY;k/1OnK`?42ojNoj`KoY;o]
1OnN`O400onW_n_oY[o/ojJok005ojJok0?oY<3^0onX`>/:ojNojgSooooo00Co0000oooooooooooo
00000Oooool005?ooooo00?o0000ooooooooool0;_ooool4ojJoj`;oZ;oZ1_nU`>`5ojO1k003ojK0
kOnW`NcoYl7/00CoYl7/1OnX`>/2ojO1k0OoZ<3[0_nV_n/4ojS0j`KoY[o[0onO_^l3ojNoj`KoY;k/
00?oVl3aojNojonW_n/01?nW_n/6ojBok@03oik1lOnW_n_oYko[00?oYko[1OnV_n`8ojS0j`GoYko[
OOooool00ol0003oooooo`000001ooooo`00E?ooool00ol0003oooooooooo`0^ooooo`03ojJojonX
_n[oZ;oZ00?oZ;oZ1_nU`>`00onW`NcoY/3]ojK0k@03ojK0k@KoYl7/00?oZ<3[ojO1k?nW`N`01?nW
`N`5ojS0j`03ojO1k?nX`>_oZ<3[00GoZ<3[0onV_n/3ojS0j`KoYko[0onT_^`4ojS0j`KoYko[0onT
_nd3ojS0j`KoYko[00?oY[o/ojS0jonX`>/02_nX`>/00onW_n_oooooooooo`1nooooo`03o`000?oo
oooo0000007ooooo001Eooooo`03o`000?oooooooooo02kooooo1_nX_nX3ojG0k0CoY[o[1OnV`>d3
ojO1k0CoY/7]1_nW`N`00onX`>_oYl7/ojO1k003ojO1k0GoZ<3[0_nW`N`6ojS0j`CoYko[0_nW`>`7
ojS0j`?oYko[0_nW`>/7ojS0j`?oYko[1?nW`>/9ojS0jhCooooo0Ol00001ooooo`7o0000001Foooo
o`;o0000;oooool3ojRojP?oZKoZ1onV_n/2ojK0k@CoY[o[1_nV`Nd3ojO1k0CoY/7]1OnW`N`00onX
`>_oYl7/ojO1k004ojO1k0KoZ<3[00?oYko[ojO0k?nW`>`00onW`>`5ojS0j`;oYl7/1OnW`>/5ojS0
j`;oYl7/1onW`>/3ojS0jh[ooooo0_l0000005Sooooo00?o0000ooooooooool0;Oooool6ojVojPGo
Y[o[0_nX_nX6ojJoj`?oY/7]0onV_n`7ojK1k@;oYl7/1?nV`Nd6ojO1k0?oZ<3[0onW`N`6ojO0k003
ojS0jonW`NcoYl7/00CoYl7/1OnW`>/00onX`>_oYl7/ojO1k004ojO1k0GoYl3[SOooool3o`000000
FOooool00ol0003oooooooooo`0]ooooo`KoZKoZ00?oY[o[ojRoj_nX_nX01?nX_nX4ojJoj`;oZ;oZ
1_nV_n`5ojK1k@03ojJok?nV`NgoY/7]00GoY/7]0onW`N`4ojK1k@GoYl7/0onW`>`4ojO2k@KoYl7/
0_nW`>/4ojO2k@KoYl7/00?oYl3[ooooooooool0R_ooool4o`0000?ooooo001Jooooo`03o`000?oo
oooooooo02gooooo0onY_nX4ojW0j`KoZ;oZ00?oY[o[ojRoj_nX_nX00onX_nX6ojJok003ojK1kOnV
_ncoY[o/00?oY[o/1OnV`Nd2ojJoj`OoY/7]0_nW`N`3ojK0k0OoYl;]0onW`N`3ojK1k@KoYl;]0onW
`Nb<ooooo`?o00001oooool005_ooooo00?o0000ooooooooool0;Oooool7ojW0j`?oZ;oZ0onY`>X6
ojRojP?oY[o/1?nX_nX5ojJok003ojK1kOnV_n_oY[o[00CoY[o[1OnV`Nd00onV_^_oY/3/ojK0k004
ojK0k0GoYl;]00?oY[o/ojK1kOnV`Nd01OnV`Nd3ojO2kHgooooo1?l0000:ooooo`00G?ooool2o`00
02kooooo1OnY`>/2ojS0j`KoZL3Z0onX_nX4ojW0jPKoZ;oZ0_nV_n`4ojRojPKoY[o[00?oY/7]ojJn
jonV_^/00onV_^/6ojK0k003ojO2kOnV_ncoY[o/00?oY[o/1OnV`Nf=ooooo`Co00003_ooool005ko
oooo00?o0000ooooooooool0;?ooool00onY`>_oZ<3[ojS0j`04ojS0j`CoZL3Z0_nX`>/7ojW0jP?o
Z;oZ0_nY`>X7ojRojP?oY[o[0onX_nX6ojJnj`?oY/3/1?nW_^X5ojJok003ojK1kOoooooooooo08[o
oooo1?l0000Booooo`00Goooool00ol0003oooooooooo`0]ooooo`KoZ<3[00?oZL3ZojS0jonX`>/0
0onX`>/5ojW0jP;oZ<3[1OnY`>X5ojRojP;oZL3Z1_nX_nX3ojJnj`?oZ;oZ1onW_^X2ojJok8_ooooo
1?l0000Fooooo`00H?ooool00ol0003oooooooooo`0]ooooo`?oZ<3[1?nW`N`5ojS0j`03ojW0j_nX
`>_oZ<3[00CoZ<3[1OnY`>X00onX_n[oZL3ZojW0jP04ojW0jPCoZ;oZ0_nX`>/6ojRojPGoYkkZRooo
ool3o`0001[ooooo001Qooooo`;o0000;oooool6ojO1k0;oZ<3[1?nW`N`6ojS0j`;oZL3Z1?nX`>/6
ojW0jP03ojRoj_nX`>_oZ<3[00?oZ<3[1_nX_nX00onW_^[oooooooooo`28ooooo`Co00007Oooool0
06?ooooo00?o0000ooooooooool0;Oooool3ojO1k0;oY/3/1onW`N`3ojS0j`?oYl7/1_nX`>/3ojW0
jPWoZ<3[0onX_nZ9ooooo`Co00008Oooool006Cooooo00?o0000ooooooooool0;Oooool5ojK0k0Go
Yl7/0_nV`>`6ojO1k0?oZ<3[0onW`N`9ojS0jh[ooooo1?l0000Uooooo`00IOooool00ol0003ooooo
ooooo`0]ooooo`GoY/3/00?oYl7/ojK0k?nV`>`01?nV`>`4ojO1k0;oY/3/1_nW`N`4ojS0jh[ooooo
1?l0000Yooooo`00I_ooool2o`0002kooooo0_nV`>`4ojNoj`KoY/3/00?oYl7/ojK0k?nV`>`00onV
`>`6ojO1k003ojS0jooooooooooo08Oooooo0ol0000]ooooo`00J?ooool00ol0003oooooooooo`0/
ooooo`KoYko[0onV`>`3ojNoj`KoY/3/0onW`Nb8ooooo`Co0000<?ooool006Wooooo00?o0000oooo
ooooool0;?ooool3ojNoj`CoZ;oZ1OnW_n/3ojK0k8Wooooo1?l0000dooooo`00J_ooool00ol0003o
ooooooooo`0/ooooo`OoZ;oZ0_nW_n^:ooooo`Co0000>?ooool006_ooooo0_l0000]ooooo`GoZ;oZ
ROooool4o`0003cooooo001]ooooo`03o`000?oooooooooo02_ooooo00?oZ;oZooooooooool0Qooo
ool3o`00043ooooo001^ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0Poooool4
o`0004?ooooo001_ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0Ooooool4o`00
04Oooooo001`ooooo`;o0000:Oooool00ol0003oooooooooo`1kooooo`Co0000Boooool007;ooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`1gooooo`Co0000Coooool007?ooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`1dooooo`?o0000Doooool007Cooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`1`ooooo`Co0000E_ooool007Gooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`1/ooooo`Co0000F_ooool007Kooooo0_l0000Sooooo`03
o`000?oooooooooo06Sooooo1?l0001Nooooo`00N?ooool00ol0003oooooooooo`0Pooooo`03o`00
0?oooooooooo06Cooooo1?l0001Rooooo`00NOooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo067ooooo0ol0001Vooooo`00N_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo05gooooo1?l0001Yooooo`00Noooool2o`0001kooooo00?o0000ooooooooool0FOooool4o`00
06gooooo001mooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0EOooool4o`00077o
oooo001nooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0DOooool4o`0007Gooooo
001oooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0C_ooool3o`0007Wooooo0020
ooooo`;o00006Oooool00ol0003oooooooooo`1:ooooo`Co0000O?ooool008;ooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`16ooooo`Co0000P?ooool008?ooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`12ooooo`Co0000Q?ooool008Cooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`0nooooo`Co0000R?ooool008Gooooo0_l0000Cooooo`03o`000?oo
oooooooo03cooooo0ol0002<ooooo`00Qoooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo03Sooooo1?l0002?ooooo`00R?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
03Cooooo1?l0002Cooooo`00ROooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo033o
oooo1?l0002Gooooo`00R_ooool2o`0000kooooo00?o0000ooooooooool0;?ooool4o`0009_ooooo
002<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0:Oooool3o`0009oooooo002=
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool09Oooool4o`000:;ooooo002>oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08Oooool4o`000:Kooooo002?ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool07Oooool4o`000:[ooooo002@ooooo`;o0000
2?ooool00ol0003oooooooooo`0Iooooo`Co0000[_ooool009;ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Fooooo`?o0000/_ooool009?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0Booooo`Co0000]Oooool009Cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0>ooooo`Co0000^Oooool009Gooooo0_l00003ooooo`03o`000?oooooooooo00[o
oooo1?l0002mooooo`00Uoooool01?l0003oooooooooool00008ooooo`Co0000`Oooool009Sooooo
00?o0000ooooool000001Oooool3o`000<Gooooo002Iooooo`;o000000?oooooo`000?l000000_l0
0038ooooo`00V_ooool2o`000<cooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0538698, 0.0432538, \
0.0035044, 0.0035044}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[.12586 .2075 -12 -8.99448 ]
[.12586 .2075 0 .00552 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.56094 .0364 -5.16972 -9 ]
[.56094 .0364 .83028 0 ]
[.75679 .08071 0 -6.17777 ]
[.75679 .08071 12 2.82223 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.9429 .3657 0 -5.9083 ]
[.9429 .3657 6 3.0917 ]
[.02494 .25992 -18 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.01611 .31527 -18 -2.78472 ]
[.01611 .31527 0 6.21528 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00254 .43215 -12 -2.88407 ]
[-0.00254 .43215 0 6.11593 ]
[-0.0124 .49393 -12 -2.93688 ]
[-0.0124 .49393 0 6.06312 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
[(-2)] .12586 .2075 1 .99877 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.56863 .04703 m
.57247 .05235 L
s
[(2)] .56094 .0364 .72324 1 Mshowa
.125 Mabswid
.18558 .19702 m
.18832 .19985 L
s
.23703 .17687 m
.23971 .17975 L
s
.28951 .15632 m
.29214 .15925 L
s
.39772 .11395 m
.40023 .11699 L
s
.4535 .09211 m
.45595 .0952 L
s
.51046 .06981 m
.51284 .07294 L
s
.08568 .23614 m
.08851 .23887 L
s
.62804 .02377 m
.63027 .02701 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.7445 .0853 m
.73835 .08759 L
s
[(-2)] .75679 .08071 -1 .37284 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.93037 .36962 m
.92411 .37158 L
s
[(2)] .9429 .3657 -1 .31296 Mshowa
.125 Mabswid
.7708 .12553 m
.7671 .12688 L
s
.79613 .16428 m
.79242 .1656 L
s
.82054 .20161 m
.81682 .20291 L
s
.86679 .27235 m
.86305 .2736 L
s
.88871 .30589 m
.88497 .30711 L
s
.9099 .3383 m
.90615 .3395 L
s
.71716 .04348 m
.71349 .04489 L
s
.95018 .39992 m
.94642 .40107 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(-20)] .02494 .25992 1 -0.39157 Mshowa
.02837 .31059 m
.0345 .30825 L
s
[(-10)] .01611 .31527 1 -0.38117 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.00981 .42772 m
.01599 .4255 L
s
[(10)] -0.00254 .43215 1 -0.3591 Mshowa
0 .48963 m
.0062 .48748 L
s
[(20)] -0.0124 .49393 1 -0.34736 Mshowa
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.656 .75 .92 r
.39362 .69474 .40169 .70183 .4152 .69798 .40717 .69091 Mtetra
.653 .751 .922 r
.40717 .69091 .4152 .69798 .42878 .69416 .42079 .68713 Mtetra
.653 .753 .923 r
.42079 .68713 .42878 .69416 .44242 .69039 .43448 .68333 Mtetra
.657 .754 .921 r
.43448 .68333 .44242 .69039 .45614 .6866 .44824 .67936 Mtetra
.659 .751 .918 r
.44824 .67936 .45614 .6866 .46992 .68269 .46207 .67533 Mtetra
.657 .748 .917 r
.46207 .67533 .46992 .68269 .48378 .67869 .47597 .67134 Mtetra
.656 .749 .919 r
.47597 .67134 .48378 .67869 .4977 .67469 .48994 .66739 Mtetra
.653 .751 .921 r
.48994 .66739 .4977 .67469 .5117 .67073 .50398 .66349 Mtetra
.652 .753 .924 r
.50398 .66349 .5117 .67073 .52577 .66679 .5181 .65961 Mtetra
.652 .756 .926 r
.5181 .65961 .52577 .66679 .53991 .6629 .53229 .65569 Mtetra
.658 .758 .923 r
.53229 .65569 .53991 .6629 .55412 .659 .54655 .65153 Mtetra
.657 .752 .919 r
.54655 .65153 .55412 .659 .56841 .65505 .56088 .64741 Mtetra
.655 .747 .918 r
.56088 .64741 .56841 .65505 .58277 .65096 .5753 .64336 Mtetra
.651 .748 .921 r
.5753 .64336 .58277 .65096 .59721 .64682 .58978 .63942 Mtetra
.648 .754 .926 r
.58978 .63942 .59721 .64682 .61172 .64269 .60435 .63554 Mtetra
.646 .761 .933 r
.60435 .63554 .61172 .64269 .62631 .63858 .619 .63168 Mtetra
.645 .769 .938 r
.619 .63168 .62631 .63858 .64097 .63447 .63373 .62777 Mtetra
.645 .776 .943 r
.63373 .62777 .64097 .63447 .65571 .63035 .64853 .62379 Mtetra
.647 .782 .946 r
.64853 .62379 .65571 .63035 .67053 .62619 .66341 .61969 Mtetra
.65 .785 .946 r
.66341 .61969 .67053 .62619 .68543 .62199 .67837 .61545 Mtetra
.654 .787 .945 r
.67837 .61545 .68543 .62199 .7004 .61775 .6934 .61107 Mtetra
.657 .785 .942 r
.6934 .61107 .7004 .61775 .71545 .61347 .7085 .60658 Mtetra
.66 .78 .938 r
.7085 .60658 .71545 .61347 .73059 .60918 .72368 .602 Mtetra
.661 .774 .933 r
.72368 .602 .73059 .60918 .7458 .60489 .73894 .59738 Mtetra
.661 .766 .927 r
.73894 .59738 .7458 .60489 .7611 .60061 .75428 .59277 Mtetra
.66 .757 .922 r
.75428 .59277 .7611 .60061 .77648 .59635 .7697 .58822 Mtetra
.657 .75 .919 r
.7697 .58822 .77648 .59635 .79195 .59203 .78522 .58377 Mtetra
.655 .747 .918 r
.78522 .58377 .79195 .59203 .80749 .58757 .80083 .5794 Mtetra
.653 .75 .921 r
.80083 .5794 .80749 .58757 .82311 .58306 .81653 .57507 Mtetra
.658 .758 .924 r
.81653 .57507 .82311 .58306 .83881 .57853 .83229 .57049 Mtetra
.659 .758 .923 r
.83229 .57049 .83881 .57853 .85461 .57405 .84814 .56586 Mtetra
.658 .755 .922 r
.84814 .56586 .85461 .57405 .87049 .56958 .86408 .56125 Mtetra
.656 .751 .92 r
.86408 .56125 .87049 .56958 .88647 .56515 .88011 .55669 Mtetra
.655 .749 .919 r
.88011 .55669 .88647 .56515 .90254 .56072 .89624 .55216 Mtetra
.653 .747 .918 r
.89624 .55216 .90254 .56072 .91869 .5562 .91247 .54767 Mtetra
.654 .749 .92 r
.91247 .54767 .91869 .5562 .93492 .55154 .92878 .54312 Mtetra
.658 .755 .922 r
.92878 .54312 .93492 .55154 .95123 .54685 .94516 .53838 Mtetra
.658 .755 .921 r
.94516 .53838 .95123 .54685 .96765 .54222 .96163 .53362 Mtetra
.656 .752 .92 r
.96163 .53362 .96765 .54222 .98416 .53761 .9782 .5289 Mtetra
.653 .751 .922 r
.38547 .68764 .39362 .69474 .40717 .69091 .39906 .68384 Mtetra
.653 .753 .923 r
.39906 .68384 .40717 .69091 .42079 .68713 .41272 .68003 Mtetra
.658 .754 .921 r
.41272 .68003 .42079 .68713 .43448 .68333 .42646 .67603 Mtetra
.659 .75 .917 r
.42646 .67603 .43448 .68333 .44824 .67936 .44027 .67198 Mtetra
.657 .748 .917 r
.44027 .67198 .44824 .67936 .46207 .67533 .45414 .66799 Mtetra
.655 .75 .92 r
.45414 .66799 .46207 .67533 .47597 .67134 .46808 .66403 Mtetra
.652 .751 .922 r
.46808 .66403 .47597 .67134 .48994 .66739 .4821 .66017 Mtetra
.652 .754 .925 r
.4821 .66017 .48994 .66739 .50398 .66349 .49619 .65628 Mtetra
.657 .757 .924 r
.49619 .65628 .50398 .66349 .5181 .65961 .51035 .65217 Mtetra
.658 .752 .92 r
.51035 .65217 .5181 .65961 .53229 .65569 .52459 .64803 Mtetra
.653 .746 .918 r
.52459 .64803 .53229 .65569 .54655 .65153 .5389 .64406 Mtetra
.645 .75 .925 r
.5389 .64406 .54655 .65153 .56088 .64741 .55329 .64031 Mtetra
.637 .759 .936 r
.55329 .64031 .56088 .64741 .5753 .64336 .56776 .63673 Mtetra
.629 .771 .948 r
.56776 .63673 .5753 .64336 .58978 .63942 .58231 .63329 Mtetra
.616 .783 .961 r
.58231 .63329 .58978 .63942 .60435 .63554 .59695 .63004 Mtetra
.605 .8 .974 r
.59695 .63004 .60435 .63554 .619 .63168 .61168 .62684 Mtetra
.6 .821 .984 r
.61168 .62684 .619 .63168 .63373 .62777 .62648 .62342 Mtetra
.6 .838 .989 r
.62648 .62342 .63373 .62777 .64853 .62379 .64137 .61973 Mtetra
.604 .85 .991 r
.64137 .61973 .64853 .62379 .66341 .61969 .65632 .61575 Mtetra
.613 .858 .99 r
.65632 .61575 .66341 .61969 .67837 .61545 .67135 .61147 Mtetra
.625 .862 .987 r
.67135 .61147 .67837 .61545 .6934 .61107 .68645 .6069 Mtetra
.64 .861 .983 r
.68645 .6069 .6934 .61107 .7085 .60658 .70161 .60203 Mtetra
.655 .854 .976 r
.70161 .60203 .7085 .60658 .72368 .602 .71683 .59689 Mtetra
.669 .841 .966 r
.71683 .59689 .72368 .602 .73894 .59738 .73211 .59152 Mtetra
.673 .82 .954 r
.73211 .59152 .73894 .59738 .75428 .59277 .74748 .5862 Mtetra
.67 .799 .944 r
.74748 .5862 .75428 .59277 .7697 .58822 .76293 .58106 Mtetra
.668 .783 .935 r
.76293 .58106 .7697 .58822 .78522 .58377 .77847 .57605 Mtetra
.664 .767 .926 r
.77847 .57605 .78522 .58377 .80083 .5794 .79411 .57122 Mtetra
.658 .754 .92 r
.79411 .57122 .80083 .5794 .81653 .57507 .80985 .56661 Mtetra
.654 .746 .917 r
.80985 .56661 .81653 .57507 .83229 .57049 .82569 .56217 Mtetra
.654 .751 .921 r
.82569 .56217 .83229 .57049 .84814 .56586 .84162 .5577 Mtetra
.659 .758 .923 r
.84162 .5577 .84814 .56586 .86408 .56125 .85762 .55299 Mtetra
.659 .757 .922 r
.85762 .55299 .86408 .56125 .88011 .55669 .8737 .54825 Mtetra
.656 .752 .921 r
.8737 .54825 .88011 .55669 .89624 .55216 .88989 .5436 Mtetra
.655 .75 .92 r
.88989 .5436 .89624 .55216 .91247 .54767 .90617 .53899 Mtetra
.653 .747 .919 r
.90617 .53899 .91247 .54767 .92878 .54312 .92255 .53443 Mtetra
.654 .748 .919 r
.92255 .53443 .92878 .54312 .94516 .53838 .93902 .52982 Mtetra
.658 .755 .921 r
.93902 .52982 .94516 .53838 .96163 .53362 .95556 .52501 Mtetra
.95556 .52501 .96163 .53362 .9782 .5289 .97219 .52016 Mtetra
.653 .753 .923 r
.37724 .68053 .38547 .68764 .39906 .68384 .39088 .67671 Mtetra
.658 .754 .921 r
.39088 .67671 .39906 .68384 .41272 .68003 .40459 .67269 Mtetra
.659 .75 .917 r
.40459 .67269 .41272 .68003 .42646 .67603 .41837 .66862 Mtetra
.657 .749 .918 r
.41837 .66862 .42646 .67603 .44027 .67198 .43222 .66462 Mtetra
.654 .75 .92 r
.43222 .66462 .44027 .67198 .45414 .66799 .44613 .66068 Mtetra
.651 .752 .923 r
.44613 .66068 .45414 .66799 .46808 .66403 .46012 .65682 Mtetra
.653 .756 .925 r
.46012 .65682 .46808 .66403 .4821 .66017 .47418 .65286 Mtetra
.659 .756 .921 r
.47418 .65286 .4821 .66017 .49619 .65628 .48832 .64867 Mtetra
.655 .748 .918 r
.48832 .64867 .49619 .65628 .51035 .65217 .50253 .64464 Mtetra
.644 .748 .924 r
.50253 .64464 .51035 .65217 .52459 .64803 .51682 .64094 Mtetra
.631 .757 .938 r
.51682 .64094 .52459 .64803 .5389 .64406 .53118 .63758 Mtetra
.611 .769 .956 r
.53118 .63758 .5389 .64406 .55329 .64031 .54563 .63461 Mtetra
.576 .783 .977 r
.54563 .63461 .55329 .64031 .56776 .63673 .56017 .63219 Mtetra
.553 .813 .994 r
.56017 .63219 .56776 .63673 .58231 .63329 .57479 .62964 Mtetra
.537 .837 .999 r
.57479 .62964 .58231 .63329 .59695 .63004 .58951 .6268 Mtetra
.538 .851 .998 r
.58951 .6268 .59695 .63004 .61168 .62684 .60431 .62362 Mtetra
.555 .859 .997 r
.60431 .62362 .61168 .62684 .62648 .62342 .61918 .62009 Mtetra
.574 .863 .996 r
.61918 .62009 .62648 .62342 .64137 .61973 .63413 .61626 Mtetra
.589 .865 .994 r
.63413 .61626 .64137 .61973 .65632 .61575 .64916 .61218 Mtetra
.602 .867 .993 r
.64916 .61218 .65632 .61575 .67135 .61147 .66426 .60786 Mtetra
.611 .87 .991 r
.66426 .60786 .67135 .61147 .68645 .6069 .67944 .60332 Mtetra
.62 .875 .989 r
.67944 .60332 .68645 .6069 .70161 .60203 .69468 .59853 Mtetra
.63 .882 .988 r
.69468 .59853 .70161 .60203 .71683 .59689 .70999 .59343 Mtetra
.642 .888 .985 r
.70999 .59343 .71683 .59689 .73211 .59152 .72535 .58796 Mtetra
.657 .891 .981 r
.72535 .58796 .73211 .59152 .74748 .5862 .74076 .58214 Mtetra
.676 .882 .975 r
.74076 .58214 .74748 .5862 .76293 .58106 .75623 .57602 Mtetra
.691 .856 .961 r
.75623 .57602 .76293 .58106 .77847 .57605 .77176 .56977 Mtetra
.682 .816 .947 r
.77176 .56977 .77847 .57605 .79411 .57122 .78741 .56405 Mtetra
.673 .789 .936 r
.78741 .56405 .79411 .57122 .80985 .56661 .80316 .55873 Mtetra
.665 .767 .926 r
.80316 .55873 .80985 .56661 .82569 .56217 .81902 .55375 Mtetra
.657 .752 .92 r
.81902 .55375 .82569 .56217 .84162 .5577 .835 .54911 Mtetra
.653 .747 .919 r
.835 .54911 .84162 .5577 .85762 .55299 .85109 .54463 Mtetra
.658 .756 .922 r
.85109 .54463 .85762 .55299 .8737 .54825 .86725 .5399 Mtetra
.659 .758 .923 r
.86725 .5399 .8737 .54825 .88989 .5436 .88348 .53506 Mtetra
.657 .753 .921 r
.88348 .53506 .88989 .5436 .90617 .53899 .89982 .53031 Mtetra
.655 .75 .92 r
.89982 .53031 .90617 .53899 .92255 .53443 .91626 .52562 Mtetra
.653 .747 .919 r
.91626 .52562 .92255 .53443 .93902 .52982 .9328 .52099 Mtetra
.654 .748 .919 r
.9328 .52099 .93902 .52982 .95556 .52501 .94943 .5163 Mtetra
.658 .755 .921 r
.94943 .5163 .95556 .52501 .97219 .52016 .96613 .5114 Mtetra
.657 .754 .921 r
.36894 .67337 .37724 .68053 .39088 .67671 .38262 .66936 Mtetra
.659 .751 .917 r
.38262 .66936 .39088 .67671 .40459 .67269 .39637 .66526 Mtetra
.657 .749 .918 r
.39637 .66526 .40459 .67269 .41837 .66862 .4102 .66124 Mtetra
.654 .75 .921 r
.4102 .66124 .41837 .66862 .43222 .66462 .42409 .65729 Mtetra
.651 .752 .924 r
.42409 .65729 .43222 .66462 .44613 .66068 .43805 .65342 Mtetra
.655 .756 .924 r
.43805 .65342 .44613 .66068 .46012 .65682 .45209 .64939 Mtetra
.659 .753 .92 r
.45209 .64939 .46012 .65682 .47418 .65286 .4662 .64521 Mtetra
.65 .746 .92 r
.4662 .64521 .47418 .65286 .48832 .64867 .48038 .64132 Mtetra
.634 .75 .932 r
.48038 .64132 .48832 .64867 .50253 .64464 .49463 .63791 Mtetra
.61 .762 .952 r
.49463 .63791 .50253 .64464 .51682 .64094 .50896 .63503 Mtetra
.558 .77 .977 r
.50896 .63503 .51682 .64094 .53118 .63758 .52338 .63309 Mtetra
.52 .803 .997 r
.52338 .63309 .53118 .63758 .54563 .63461 .53789 .63111 Mtetra
.503 .828 1 r
.53789 .63111 .54563 .63461 .56017 .63219 .55249 .62873 Mtetra
.533 .842 .999 r
.55249 .62873 .56017 .63219 .57479 .62964 .56718 .62582 Mtetra
.574 .846 .996 r
.56718 .62582 .57479 .62964 .58951 .6268 .58195 .62236 Mtetra
.609 .839 .987 r
.58195 .62236 .58951 .6268 .60431 .62362 .5968 .61846 Mtetra
.633 .825 .974 r
.5968 .61846 .60431 .62362 .61918 .62009 .61173 .61425 Mtetra
.647 .809 .961 r
.61173 .61425 .61918 .62009 .63413 .61626 .62672 .60984 Mtetra
.654 .794 .95 r
.62672 .60984 .63413 .61626 .64916 .61218 .6418 .60533 Mtetra
.65 .782 .944 r
.6418 .60533 .64916 .61218 .66426 .60786 .65696 .60097 Mtetra
.645 .78 .946 r
.65696 .60097 .66426 .60786 .67944 .60332 .67221 .59678 Mtetra
.644 .791 .953 r
.67221 .59678 .67944 .60332 .69468 .59853 .68755 .59249 Mtetra
.646 .808 .961 r
.68755 .59249 .69468 .59853 .70999 .59343 .70296 .58799 Mtetra
.649 .829 .97 r
.70296 .58799 .70999 .59343 .72535 .58796 .71843 .58318 Mtetra
.655 .853 .976 r
.71843 .58318 .72535 .58796 .74076 .58214 .73396 .57791 Mtetra
.665 .875 .977 r
.73396 .57791 .74076 .58214 .75623 .57602 .74953 .57209 Mtetra
.679 .89 .975 r
.74953 .57209 .75623 .57602 .77176 .56977 .76514 .5657 Mtetra
.693 .891 .97 r
.76514 .5657 .77176 .56977 .78741 .56405 .78079 .55891 Mtetra
.705 .861 .956 r
.78079 .55891 .78741 .56405 .80316 .55873 .7965 .55204 Mtetra
.685 .81 .942 r
.7965 .55204 .80316 .55873 .81902 .55375 .81236 .54614 Mtetra
.673 .781 .931 r
.81236 .54614 .81902 .55375 .835 .54911 .82835 .54077 Mtetra
.661 .759 .922 r
.82835 .54077 .835 .54911 .85109 .54463 .84447 .53589 Mtetra
.653 .747 .918 r
.84447 .53589 .85109 .54463 .86725 .5399 .86071 .53131 Mtetra
.656 .753 .921 r
.86071 .53131 .86725 .5399 .88348 .53506 .87702 .52657 Mtetra
.66 .758 .923 r
.87702 .52657 .88348 .53506 .89982 .53031 .89341 .52165 Mtetra
.657 .754 .921 r
.89341 .52165 .89982 .53031 .91626 .52562 .90991 .51681 Mtetra
.655 .75 .92 r
.90991 .51681 .91626 .52562 .9328 .52099 .9265 .51204 Mtetra
.653 .747 .919 r
.9265 .51204 .9328 .52099 .94943 .5163 .94321 .50735 Mtetra
.654 .749 .919 r
.94321 .50735 .94943 .5163 .96613 .5114 .96 .50256 Mtetra
.66 .752 .918 r
.36055 .66602 .36894 .67337 .38262 .66936 .37428 .6619 Mtetra
.657 .749 .918 r
.37428 .6619 .38262 .66936 .39637 .66526 .38808 .65784 Mtetra
.654 .75 .92 r
.38808 .65784 .39637 .66526 .4102 .66124 .40194 .65387 Mtetra
.65 .751 .924 r
.40194 .65387 .4102 .66124 .42409 .65729 .41588 .64999 Mtetra
.655 .756 .924 r
.41588 .64999 .42409 .65729 .43805 .65342 .42989 .64593 Mtetra
.658 .752 .92 r
.42989 .64593 .43805 .65342 .45209 .64939 .44397 .64175 Mtetra
.646 .746 .922 r
.44397 .64175 .45209 .64939 .4662 .64521 .45813 .63797 Mtetra
.624 .752 .938 r
.45813 .63797 .4662 .64521 .48038 .64132 .47234 .63483 Mtetra
.576 .759 .965 r
.47234 .63483 .48038 .64132 .49463 .63791 .48663 .63269 Mtetra
.515 .778 .992 r
.48663 .63269 .49463 .63791 .50896 .63503 .50101 .6312 Mtetra
.482 .809 1 r
.50101 .6312 .50896 .63503 .52338 .63309 .51549 .62938 Mtetra
.522 .83 1 r
.51549 .62938 .52338 .63309 .53789 .63111 .53006 .62682 Mtetra
.587 .835 .992 r
.53006 .62682 .53789 .63111 .55249 .62873 .54472 .62338 Mtetra
.648 .82 .966 r
.54472 .62338 .55249 .62873 .56718 .62582 .55945 .6189 Mtetra
.687 .786 .926 r
.55945 .6189 .56718 .62582 .58195 .62236 .57425 .61338 Mtetra
.688 .736 .887 r
.57425 .61338 .58195 .62236 .5968 .61846 .58911 .60772 Mtetra
.68 .698 .86 r
.58911 .60772 .5968 .61846 .61173 .61425 .60404 .60219 Mtetra
.67 .672 .844 r
.60404 .60219 .61173 .61425 .62672 .60984 .61906 .59696 Mtetra
.66 .657 .835 r
.61906 .59696 .62672 .60984 .6418 .60533 .63416 .59212 Mtetra
.652 .649 .834 r
.63416 .59212 .6418 .60533 .65696 .60097 .64935 .58772 Mtetra
.643 .645 .837 r
.64935 .58772 .65696 .60097 .67221 .59678 .66465 .58375 Mtetra
.636 .646 .843 r
.66465 .58375 .67221 .59678 .68755 .59249 .68005 .58018 Mtetra
.629 .655 .857 r
.68005 .58018 .68755 .59249 .70296 .58799 .69556 .57692 Mtetra
.625 .677 .879 r
.69556 .57692 .70296 .58799 .71843 .58318 .71118 .57379 Mtetra
.625 .714 .91 r
.71118 .57379 .71843 .58318 .73396 .57791 .72689 .57053 Mtetra
.645 .774 .942 r
.72689 .57053 .73396 .57791 .74953 .57209 .74263 .56621 Mtetra
.666 .827 .961 r
.74263 .56621 .74953 .57209 .76514 .5657 .75838 .56084 Mtetra
.684 .865 .967 r
.75838 .56084 .76514 .5657 .78079 .55891 .77416 .55455 Mtetra
.702 .887 .965 r
.77416 .55455 .78079 .55891 .7965 .55204 .78994 .54749 Mtetra
.713 .885 .96 r
.78994 .54749 .7965 .55204 .81236 .54614 .80576 .54008 Mtetra
.704 .838 .947 r
.80576 .54008 .81236 .54614 .82835 .54077 .82171 .5333 Mtetra
.679 .791 .934 r
.82171 .5333 .82835 .54077 .84447 .53589 .83782 .52757 Mtetra
.664 .764 .924 r
.83782 .52757 .84447 .53589 .86071 .53131 .85408 .52247 Mtetra
.654 .748 .919 r
.85408 .52247 .86071 .53131 .87702 .52657 .87048 .5178 Mtetra
.656 .752 .92 r
.87048 .5178 .87702 .52657 .89341 .52165 .88695 .513 Mtetra
.66 .758 .922 r
.88695 .513 .89341 .52165 .90991 .51681 .9035 .50799 Mtetra
.657 .753 .921 r
.9035 .50799 .90991 .51681 .9265 .51204 .92016 .50308 Mtetra
.655 .75 .92 r
.92016 .50308 .9265 .51204 .94321 .50735 .93692 .49826 Mtetra
.653 .747 .919 r
.93692 .49826 .94321 .50735 .96 .50256 .95379 .4935 Mtetra
.658 .75 .917 r
.3521 .65854 .36055 .66602 .37428 .6619 .36587 .65443 Mtetra
.655 .75 .92 r
.36587 .65443 .37428 .6619 .38808 .65784 .37971 .65041 Mtetra
.65 .751 .923 r
.37971 .65041 .38808 .65784 .40194 .65387 .39361 .64652 Mtetra
.654 .755 .924 r
.39361 .64652 .40194 .65387 .41588 .64999 .40759 .64248 Mtetra
.659 .753 .92 r
.40759 .64248 .41588 .64999 .42989 .64593 .42165 .63826 Mtetra
.644 .746 .923 r
.42165 .63826 .42989 .64593 .44397 .64175 .43577 .63453 Mtetra
.617 .751 .942 r
.43577 .63453 .44397 .64175 .45813 .63797 .44995 .63155 Mtetra
.551 .753 .971 r
.44995 .63155 .45813 .63797 .47234 .63483 .46419 .62994 Mtetra
.484 .777 .996 r
.46419 .62994 .47234 .63483 .48663 .63269 .47853 .62874 Mtetra
.486 .808 1 r
.47853 .62874 .48663 .63269 .50101 .6312 .49296 .62692 Mtetra
.563 .827 .995 r
.49296 .62692 .50101 .6312 .51549 .62938 .5075 .62396 Mtetra
.654 .819 .963 r
.5075 .62396 .51549 .62938 .53006 .62682 .52214 .61935 Mtetra
.706 .775 .906 r
.52214 .61935 .53006 .62682 .54472 .62338 .53684 .61305 Mtetra
.704 .713 .855 r
.53684 .61305 .54472 .62338 .55945 .6189 .55159 .60631 Mtetra
.693 .672 .825 r
.55159 .60631 .55945 .6189 .57425 .61338 .56641 .59957 Mtetra
.684 .652 .812 r
.56641 .59957 .57425 .61338 .58911 .60772 .58129 .59308 Mtetra
.674 .638 .806 r
.58129 .59308 .58911 .60772 .60404 .60219 .59624 .58708 Mtetra
.664 .629 .804 r
.59624 .58708 .60404 .60219 .61906 .59696 .61128 .5816 Mtetra
.655 .622 .805 r
.61128 .5816 .61906 .59696 .63416 .59212 .6264 .57664 Mtetra
.647 .617 .806 r
.6264 .57664 .63416 .59212 .64935 .58772 .64162 .57218 Mtetra
.638 .613 .809 r
.64162 .57218 .64935 .58772 .66465 .58375 .65694 .56823 Mtetra
.629 .61 .812 r
.65694 .56823 .66465 .58375 .68005 .58018 .67237 .56479 Mtetra
.62 .608 .817 r
.67237 .56479 .68005 .58018 .69556 .57692 .68792 .5619 Mtetra
.61 .609 .824 r
.68792 .5619 .69556 .57692 .71118 .57379 .7036 .55951 Mtetra
.605 .617 .836 r
.7036 .55951 .71118 .57379 .72689 .57053 .71941 .55738 Mtetra
.603 .634 .854 r
.71941 .55738 .72689 .57053 .74263 .56621 .73533 .55527 Mtetra
.608 .677 .89 r
.73533 .55527 .74263 .56621 .75838 .56084 .75133 .55271 Mtetra
.644 .758 .932 r
.75133 .55271 .75838 .56084 .77416 .55455 .76731 .54844 Mtetra
.682 .829 .954 r
.76731 .54844 .77416 .55455 .78994 .54749 .78327 .54246 Mtetra
.708 .871 .959 r
.78327 .54246 .78994 .54749 .80576 .54008 .7992 .53531 Mtetra
.724 .884 .955 r
.7992 .53531 .80576 .54008 .82171 .5333 .81515 .52749 Mtetra
.717 .853 .946 r
.81515 .52749 .82171 .5333 .83782 .52757 .83119 .52008 Mtetra
.684 .796 .934 r
.83119 .52008 .83782 .52757 .85408 .52247 .84744 .51407 Mtetra
.665 .766 .925 r
.84744 .51407 .85408 .52247 .87048 .5178 .86385 .50884 Mtetra
.653 .748 .919 r
.86385 .50884 .87048 .5178 .88695 .513 .88041 .50411 Mtetra
.657 .753 .92 r
.88041 .50411 .88695 .513 .9035 .50799 .89704 .49919 Mtetra
.66 .757 .922 r
.89704 .49919 .9035 .50799 .92016 .50308 .91375 .49409 Mtetra
.656 .752 .921 r
.91375 .49409 .92016 .50308 .93692 .49826 .93058 .48914 Mtetra
.654 .749 .92 r
.93058 .48914 .93692 .49826 .95379 .4935 .94751 .48427 Mtetra
.656 .75 .919 r
.34356 .65102 .3521 .65854 .36587 .65443 .35737 .64695 Mtetra
.651 .75 .922 r
.35737 .64695 .36587 .65443 .37971 .65041 .37125 .64302 Mtetra
.652 .754 .925 r
.37125 .64302 .37971 .65041 .39361 .64652 .3852 .63904 Mtetra
.66 .755 .92 r
.3852 .63904 .39361 .64652 .40759 .64248 .39923 .63476 Mtetra
.646 .746 .922 r
.39923 .63476 .40759 .64248 .42165 .63826 .41332 .63096 Mtetra
.615 .749 .941 r
.41332 .63096 .42165 .63826 .43577 .63453 .42747 .62802 Mtetra
.539 .747 .972 r
.42747 .62802 .43577 .63453 .44995 .63155 .44166 .62665 Mtetra
.467 .77 .996 r
.44166 .62665 .44995 .63155 .46419 .62994 .45594 .62571 Mtetra
.495 .804 1 r
.45594 .62571 .46419 .62994 .47853 .62874 .47033 .62389 Mtetra
.597 .821 .985 r
.47033 .62389 .47853 .62874 .49296 .62692 .48485 .6205 Mtetra
.702 .801 .926 r
.48485 .6205 .49296 .62692 .5075 .62396 .49946 .61439 Mtetra
.719 .731 .86 r
.49946 .61439 .5075 .62396 .52214 .61935 .51415 .60698 Mtetra
.71 .681 .82 r
.51415 .60698 .52214 .61935 .53684 .61305 .52888 .59918 Mtetra
.7 .658 .805 r
.52888 .59918 .53684 .61305 .55159 .60631 .54367 .5916 Mtetra
.687 .643 .8 r
.54367 .5916 .55159 .60631 .56641 .59957 .55851 .58465 Mtetra
.675 .636 .803 r
.55851 .58465 .56641 .59957 .58129 .59308 .57343 .57849 Mtetra
.66 .634 .813 r
.57343 .57849 .58129 .59308 .59624 .58708 .58842 .57334 Mtetra
.657 .644 .826 r
.58842 .57334 .59624 .58708 .61128 .5816 .60351 .56852 Mtetra
.655 .654 .837 r
.60351 .56852 .61128 .5816 .6264 .57664 .61867 .56389 Mtetra
.653 .659 .843 r
.61867 .56389 .6264 .57664 .64162 .57218 .63392 .55938 Mtetra
.65 .658 .844 r
.63392 .55938 .64162 .57218 .65694 .56823 .64927 .55499 Mtetra
.646 .65 .84 r
.64927 .55499 .65694 .56823 .67237 .56479 .6647 .55079 Mtetra
.638 .636 .832 r
.6647 .55079 .67237 .56479 .68792 .5619 .68024 .54694 Mtetra
.618 .614 .825 r
.68024 .54694 .68792 .5619 .7036 .55951 .69593 .5441 Mtetra
.602 .601 .823 r
.69593 .5441 .7036 .55951 .71941 .55738 .71176 .54207 Mtetra
.589 .597 .828 r
.71176 .54207 .71941 .55738 .73533 .55527 .72775 .5407 Mtetra
.583 .605 .84 r
.72775 .5407 .73533 .55527 .75133 .55271 .74388 .53956 Mtetra
.588 .629 .86 r
.74388 .53956 .75133 .55271 .76731 .54844 .7601 .53806 Mtetra
.611 .694 .902 r
.7601 .53806 .76731 .54844 .78327 .54246 .77635 .53523 Mtetra
.674 .798 .941 r
.77635 .53523 .78327 .54246 .7992 .53531 .79248 .5296 Mtetra
.712 .855 .95 r
.79248 .5296 .7992 .53531 .81515 .52749 .80857 .52234 Mtetra
.733 .879 .948 r
.80857 .52234 .81515 .52749 .83119 .52008 .82464 .51416 Mtetra
.724 .855 .944 r
.82464 .51416 .83119 .52008 .84744 .51407 .84081 .50639 Mtetra
.686 .795 .932 r
.84081 .50639 .84744 .51407 .86385 .50884 .8572 .50024 Mtetra
.664 .764 .924 r
.8572 .50024 .86385 .50884 .88041 .50411 .87378 .49498 Mtetra
.652 .747 .919 r
.87378 .49498 .88041 .50411 .89704 .49919 .8905 .49021 Mtetra
.659 .755 .921 r
.8905 .49021 .89704 .49919 .91375 .49409 .90729 .48512 Mtetra
.66 .757 .922 r
.90729 .48512 .91375 .49409 .93058 .48914 .92417 .47998 Mtetra
.656 .752 .92 r
.92417 .47998 .93058 .48914 .94751 .48427 .94117 .47498 Mtetra
.653 .75 .921 r
.33493 .64348 .34356 .65102 .35737 .64695 .34878 .63947 Mtetra
.65 .752 .924 r
.34878 .63947 .35737 .64695 .37125 .64302 .3627 .63554 Mtetra
.659 .756 .921 r
.3627 .63554 .37125 .64302 .3852 .63904 .37671 .63126 Mtetra
.65 .747 .92 r
.37671 .63126 .3852 .63904 .39923 .63476 .39078 .62729 Mtetra
.62 .747 .937 r
.39078 .62729 .39923 .63476 .41332 .63096 .40489 .62423 Mtetra
.543 .744 .969 r
.40489 .62423 .41332 .63096 .42747 .62802 .41903 .62282 Mtetra
.459 .759 .994 r
.41903 .62282 .42747 .62802 .44166 .62665 .43325 .62213 Mtetra
.496 .796 .999 r
.43325 .62213 .44166 .62665 .45594 .62571 .4476 .62045 Mtetra
.616 .814 .977 r
.4476 .62045 .45594 .62571 .47033 .62389 .46209 .61678 Mtetra
.723 .787 .903 r
.46209 .61678 .47033 .62389 .48485 .6205 .4767 .60971 Mtetra
.726 .711 .836 r
.4767 .60971 .48485 .6205 .49946 .61439 .49138 .60143 Mtetra
.718 .676 .808 r
.49138 .60143 .49946 .61439 .51415 .60698 .50611 .5928 Mtetra
.703 .656 .8 r
.50611 .5928 .51415 .60698 .52888 .59918 .52088 .58486 Mtetra
.68 .645 .808 r
.52088 .58486 .52888 .59918 .54367 .5916 .5357 .57846 Mtetra
.665 .655 .831 r
.5357 .57846 .54367 .5916 .55851 .58465 .5506 .5733 Mtetra
.659 .683 .862 r
.5506 .5733 .55851 .58465 .57343 .57849 .56557 .56867 Mtetra
.655 .713 .89 r
.56557 .56867 .57343 .57849 .58842 .57334 .58063 .56429 Mtetra
.652 .73 .906 r
.58063 .56429 .58842 .57334 .60351 .56852 .59578 .55998 Mtetra
.653 .744 .916 r
.59578 .55998 .60351 .56852 .61867 .56389 .611 .5556 Mtetra
.656 .752 .92 r
.611 .5556 .61867 .56389 .63392 .55938 .62631 .55104 Mtetra
.66 .753 .919 r
.62631 .55104 .63392 .55938 .64927 .55499 .6417 .54632 Mtetra
.662 .747 .913 r
.6417 .54632 .64927 .55499 .6647 .55079 .65717 .54151 Mtetra
.659 .733 .904 r
.65717 .54151 .6647 .55079 .68024 .54694 .67273 .53678 Mtetra
.653 .712 .891 r
.67273 .53678 .68024 .54694 .69593 .5441 .68838 .5323 Mtetra
.64 .675 .868 r
.68838 .5323 .69593 .5441 .71176 .54207 .70416 .52835 Mtetra
.613 .632 .846 r
.70416 .52835 .71176 .54207 .72775 .5407 .7201 .52567 Mtetra
.582 .599 .835 r
.7201 .52567 .72775 .5407 .74388 .53956 .73626 .52457 Mtetra
.566 .592 .839 r
.73626 .52457 .74388 .53956 .7601 .53806 .75259 .52419 Mtetra
.57 .612 .855 r
.75259 .52419 .7601 .53806 .77635 .53523 .76903 .52349 Mtetra
.591 .66 .886 r
.76903 .52349 .77635 .53523 .79248 .5296 .78551 .52155 Mtetra
.669 .778 .931 r
.78551 .52155 .79248 .5296 .80857 .52234 .80182 .51612 Mtetra
.717 .845 .943 r
.80182 .51612 .80857 .52234 .82464 .51416 .81804 .50861 Mtetra
.741 .872 .941 r
.81804 .50861 .82464 .51416 .84081 .50639 .83423 .50006 Mtetra
.724 .847 .94 r
.83423 .50006 .84081 .50639 .8572 .50024 .85055 .49222 Mtetra
.683 .789 .93 r
.85055 .49222 .8572 .50024 .87378 .49498 .86712 .4861 Mtetra
.66 .759 .923 r
.86712 .4861 .87378 .49498 .8905 .49021 .88387 .48092 Mtetra
.653 .747 .919 r
.88387 .48092 .8905 .49021 .90729 .48512 .90076 .47605 Mtetra
.661 .757 .921 r
.90076 .47605 .90729 .48512 .92417 .47998 .91771 .47081 Mtetra
.658 .755 .921 r
.91771 .47081 .92417 .47998 .94117 .47498 .93476 .46564 Mtetra
.65 .751 .923 r
.32623 .6359 .33493 .64348 .34878 .63947 .34011 .63196 Mtetra
.656 .755 .923 r
.34011 .63196 .34878 .63947 .3627 .63554 .35409 .62779 Mtetra
.656 .75 .919 r
.35409 .62779 .3627 .63554 .37671 .63126 .36814 .62359 Mtetra
.629 .745 .931 r
.36814 .62359 .37671 .63126 .39078 .62729 .38222 .62024 Mtetra
.563 .743 .961 r
.38222 .62024 .39078 .62729 .40489 .62423 .39633 .61846 Mtetra
.462 .744 .989 r
.39633 .61846 .40489 .62423 .41903 .62282 .41049 .618 Mtetra
.482 .782 .997 r
.41049 .618 .41903 .62282 .43325 .62213 .42478 .61668 Mtetra
.612 .808 .975 r
.42478 .61668 .43325 .62213 .4476 .62045 .43923 .61315 Mtetra
.731 .784 .895 r
.43923 .61315 .4476 .62045 .46209 .61678 .45384 .60567 Mtetra
.734 .708 .827 r
.45384 .60567 .46209 .61678 .4767 .60971 .46853 .59671 Mtetra
.725 .679 .805 r
.46853 .59671 .4767 .60971 .49138 .60143 .48326 .58751 Mtetra
.704 .66 .804 r
.48326 .58751 .49138 .60143 .50611 .5928 .49801 .57959 Mtetra
.672 .657 .827 r
.49801 .57959 .50611 .5928 .52088 .58486 .51281 .57399 Mtetra
.659 .692 .87 r
.51281 .57399 .52088 .58486 .5357 .57846 .52768 .5694 Mtetra
.643 .726 .909 r
.52768 .5694 .5357 .57846 .5506 .5733 .54263 .56548 Mtetra
.633 .754 .936 r
.54263 .56548 .5506 .5733 .56557 .56867 .55767 .56176 Mtetra
.63 .779 .953 r
.55767 .56176 .56557 .56867 .58063 .56429 .5728 .55791 Mtetra
.632 .797 .961 r
.5728 .55791 .58063 .56429 .59578 .55998 .58802 .55382 Mtetra
.638 .806 .964 r
.58802 .55382 .59578 .55998 .611 .5556 .60331 .54948 Mtetra
.645 .811 .963 r
.60331 .54948 .611 .5556 .62631 .55104 .61869 .54488 Mtetra
.653 .813 .96 r
.61869 .54488 .62631 .55104 .6417 .54632 .63414 .54003 Mtetra
.661 .813 .956 r
.63414 .54003 .6417 .54632 .65717 .54151 .64967 .53491 Mtetra
.669 .808 .949 r
.64967 .53491 .65717 .54151 .67273 .53678 .66527 .52955 Mtetra
.674 .793 .938 r
.66527 .52955 .67273 .53678 .68838 .5323 .68095 .52406 Mtetra
.67 .766 .922 r
.68095 .52406 .68838 .5323 .70416 .52835 .69672 .51877 Mtetra
.654 .729 .905 r
.69672 .51877 .70416 .52835 .7201 .52567 .71261 .51414 Mtetra
.63 .68 .879 r
.71261 .51414 .7201 .52567 .73626 .52457 .72865 .51056 Mtetra
.58 .615 .852 r
.72865 .51056 .73626 .52457 .75259 .52419 .74496 .50935 Mtetra
.553 .59 .845 r
.74496 .50935 .75259 .52419 .76903 .52349 .76149 .50946 Mtetra
.554 .603 .857 r
.76149 .50946 .76903 .52349 .78551 .52155 .77815 .50937 Mtetra
.582 .65 .883 r
.77815 .50937 .78551 .52155 .80182 .51612 .79482 .50776 Mtetra
.674 .775 .926 r
.79482 .50776 .80182 .51612 .81804 .50861 .81128 .50208 Mtetra
.727 .843 .936 r
.81128 .50208 .81804 .50861 .83423 .50006 .82761 .4941 Mtetra
.747 .866 .934 r
.82761 .4941 .83423 .50006 .85055 .49222 .84393 .4852 Mtetra
.716 .829 .935 r
.84393 .4852 .85055 .49222 .86712 .4861 .86044 .47764 Mtetra
.677 .779 .927 r
.86044 .47764 .86712 .4861 .88387 .48092 .87719 .47171 Mtetra
.655 .752 .921 r
.87719 .47171 .88387 .48092 .90076 .47605 .89414 .46666 Mtetra
.656 .75 .919 r
.89414 .46666 .90076 .47605 .91771 .47081 .91118 .46158 Mtetra
.661 .757 .921 r
.91118 .46158 .91771 .47081 .93476 .46564 .92829 .45625 Mtetra
.65 .752 .925 r
.31743 .62833 .32623 .6359 .34011 .63196 .33136 .62434 Mtetra
.66 .755 .92 r
.33136 .62434 .34011 .63196 .35409 .62779 .34539 .61996 Mtetra
.642 .746 .924 r
.34539 .61996 .35409 .62779 .36814 .62359 .35946 .6162 Mtetra
.597 .745 .948 r
.35946 .6162 .36814 .62359 .38222 .62024 .37355 .61368 Mtetra
.48 .728 .98 r
.37355 .61368 .38222 .62024 .39633 .61846 .38765 .61329 Mtetra
.458 .762 .995 r
.38765 .61329 .39633 .61846 .41049 .618 .40187 .61251 Mtetra
.583 .799 .982 r
.40187 .61251 .41049 .618 .42478 .61668 .41626 .60961 Mtetra
.726 .789 .902 r
.41626 .60961 .42478 .61668 .43923 .61315 .43085 .60239 Mtetra
.741 .717 .829 r
.43085 .60239 .43923 .61315 .45384 .60567 .44556 .59301 Mtetra
.734 .687 .805 r
.44556 .59301 .45384 .60567 .46853 .59671 .4603 .58328 Mtetra
.706 .667 .81 r
.4603 .58328 .46853 .59671 .48326 .58751 .47505 .57539 Mtetra
.67 .674 .845 r
.47505 .57539 .48326 .58751 .49801 .57959 .48982 .57006 Mtetra
.646 .716 .899 r
.48982 .57006 .49801 .57959 .51281 .57399 .50466 .56601 Mtetra
.621 .747 .936 r
.50466 .56601 .51281 .57399 .52768 .5694 .51958 .56267 Mtetra
.611 .779 .961 r
.51958 .56267 .52768 .5694 .54263 .56548 .53459 .5593 Mtetra
.626 .8 .966 r
.53459 .5593 .54263 .56548 .55767 .56176 .54969 .55534 Mtetra
.639 .799 .959 r
.54969 .55534 .55767 .56176 .5728 .55791 .56488 .55105 Mtetra
.646 .789 .951 r
.56488 .55105 .5728 .55791 .58802 .55382 .58015 .54661 Mtetra
.65 .782 .944 r
.58015 .54661 .58802 .55382 .60331 .54948 .5955 .54205 Mtetra
.653 .778 .94 r
.5955 .54205 .60331 .54948 .61869 .54488 .61094 .53741 Mtetra
.655 .779 .94 r
.61094 .53741 .61869 .54488 .63414 .54003 .62646 .53267 Mtetra
.657 .784 .942 r
.62646 .53267 .63414 .54003 .64967 .53491 .64207 .52783 Mtetra
.659 .793 .946 r
.64207 .52783 .64967 .53491 .66527 .52955 .65775 .52283 Mtetra
.666 .807 .95 r
.65775 .52283 .66527 .52955 .68095 .52406 .67351 .51748 Mtetra
.682 .817 .948 r
.67351 .51748 .68095 .52406 .69672 .51877 .68932 .51154 Mtetra
.684 .801 .937 r
.68932 .51154 .69672 .51877 .71261 .51414 .70521 .50556 Mtetra
.667 .761 .921 r
.70521 .50556 .71261 .51414 .72865 .51056 .72122 .50029 Mtetra
.636 .711 .901 r
.72122 .50029 .72865 .51056 .74496 .50935 .7374 .49633 Mtetra
.578 .633 .87 r
.7374 .49633 .74496 .50935 .76149 .50946 .75387 .495 Mtetra
.538 .59 .854 r
.75387 .495 .76149 .50946 .77815 .50937 .77061 .49558 Mtetra
.542 .604 .865 r
.77061 .49558 .77815 .50937 .79482 .50776 .78747 .49582 Mtetra
.588 .66 .888 r
.78747 .49582 .79482 .50776 .81128 .50208 .8043 .49387 Mtetra
.69 .788 .925 r
.8043 .49387 .81128 .50208 .82761 .4941 .82086 .48742 Mtetra
.74 .846 .929 r
.82086 .48742 .82761 .4941 .84393 .4852 .83729 .47877 Mtetra
.75 .857 .929 r
.83729 .47877 .84393 .4852 .86044 .47764 .85374 .46967 Mtetra
.698 .801 .929 r
.85374 .46967 .86044 .47764 .87719 .47171 .87048 .46278 Mtetra
.667 .767 .924 r
.87048 .46278 .87719 .47171 .89414 .46666 .88744 .45718 Mtetra
.652 .748 .92 r
.88744 .45718 .89414 .46666 .91118 .46158 .90458 .45222 Mtetra
.661 .756 .921 r
.90458 .45222 .91118 .46158 .92829 .45625 .92177 .44683 Mtetra
.656 .754 .922 r
.30854 .62068 .31743 .62833 .33136 .62434 .32253 .61644 Mtetra
.655 .748 .919 r
.32253 .61644 .33136 .62434 .34539 .61996 .33659 .61224 Mtetra
.62 .745 .935 r
.33659 .61224 .34539 .61996 .35946 .6162 .35068 .6091 Mtetra
.528 .732 .968 r
.35068 .6091 .35946 .6162 .37355 .61368 .36474 .60801 Mtetra
.439 .74 .991 r
.36474 .60801 .37355 .61368 .38765 .61329 .37888 .60775 Mtetra
.535 .783 .989 r
.37888 .60775 .38765 .61329 .40187 .61251 .39319 .60581 Mtetra
.7 .795 .924 r
.39319 .60581 .40187 .61251 .41626 .60961 .40774 .59975 Mtetra
.747 .734 .84 r
.40774 .59975 .41626 .60961 .43085 .60239 .42245 .59035 Mtetra
.744 .699 .808 r
.42245 .59035 .43085 .60239 .44556 .59301 .43722 .58005 Mtetra
.715 .678 .812 r
.43722 .58005 .44556 .59301 .4603 .58328 .45198 .57163 Mtetra
.672 .684 .853 r
.45198 .57163 .4603 .58328 .47505 .57539 .46673 .56626 Mtetra
.637 .723 .91 r
.46673 .56626 .47505 .57539 .48982 .57006 .48153 .56254 Mtetra
.606 .755 .949 r
.48153 .56254 .48982 .57006 .50466 .56601 .49641 .55953 Mtetra
.612 .787 .965 r
.49641 .55953 .50466 .56601 .51958 .56267 .51139 .55604 Mtetra
.636 .791 .957 r
.51139 .55604 .51958 .56267 .53459 .5593 .52646 .5519 Mtetra
.647 .774 .941 r
.52646 .5519 .53459 .5593 .54969 .55534 .54162 .54754 Mtetra
.651 .766 .933 r
.54162 .54754 .54969 .55534 .56488 .55105 .55686 .54304 Mtetra
.653 .763 .93 r
.55686 .54304 .56488 .55105 .58015 .54661 .57219 .53847 Mtetra
.654 .761 .928 r
.57219 .53847 .58015 .54661 .5955 .54205 .5876 .53384 Mtetra
.655 .76 .927 r
.5876 .53384 .5955 .54205 .61094 .53741 .60309 .52915 Mtetra
.656 .761 .927 r
.60309 .52915 .61094 .53741 .62646 .53267 .61868 .5244 Mtetra
.657 .762 .927 r
.61868 .5244 .62646 .53267 .64207 .52783 .63435 .51959 Mtetra
.658 .764 .928 r
.63435 .51959 .64207 .52783 .65775 .52283 .6501 .51469 Mtetra
.661 .769 .93 r
.6501 .51469 .65775 .52283 .67351 .51748 .66594 .50967 Mtetra
.665 .78 .935 r
.66594 .50967 .67351 .51748 .68932 .51154 .68185 .50442 Mtetra
.681 .805 .942 r
.68185 .50442 .68932 .51154 .70521 .50556 .69782 .49849 Mtetra
.693 .811 .938 r
.69782 .49849 .70521 .50556 .72122 .50029 .71384 .49207 Mtetra
.675 .777 .927 r
.71384 .49207 .72122 .50029 .7374 .49633 .72998 .48637 Mtetra
.635 .721 .91 r
.72998 .48637 .7374 .49633 .75387 .495 .74633 .48234 Mtetra
.563 .635 .88 r
.74633 .48234 .75387 .495 .77061 .49558 .763 .48147 Mtetra
.521 .589 .864 r
.763 .48147 .77061 .49558 .78747 .49582 .77996 .48255 Mtetra
.538 .613 .876 r
.77996 .48255 .78747 .49582 .8043 .49387 .79701 .48274 Mtetra
.615 .693 .899 r
.79701 .48274 .8043 .49387 .82086 .48742 .81392 .47948 Mtetra
.714 .807 .923 r
.81392 .47948 .82086 .48742 .83729 .47877 .83054 .47193 Mtetra
.753 .849 .922 r
.83054 .47193 .83729 .47877 .85374 .46967 .84706 .46261 Mtetra
.734 .84 .93 r
.84706 .46261 .85374 .46967 .87048 .46278 .86373 .45413 Mtetra
.683 .782 .925 r
.86373 .45413 .87048 .46278 .88744 .45718 .88069 .44778 Mtetra
.657 .755 .922 r
.88069 .44778 .88744 .45718 .90458 .45222 .89787 .44253 Mtetra
.656 .749 .918 r
.89787 .44253 .90458 .45222 .92177 .44683 .91517 .43732 Mtetra
.66 .755 .92 r
.29957 .61294 .30854 .62068 .32253 .61644 .31362 .60852 Mtetra
.642 .746 .925 r
.31362 .60852 .32253 .61644 .33659 .61224 .3277 .60469 Mtetra
.588 .742 .949 r
.3277 .60469 .33659 .61224 .35068 .6091 .34178 .60234 Mtetra
.463 .718 .979 r
.34178 .60234 .35068 .6091 .36474 .60801 .35584 .60224 Mtetra
.476 .754 .991 r
.35584 .60224 .36474 .60801 .37888 .60775 .37005 .6014 Mtetra
.636 .792 .957 r
.37005 .6014 .37888 .60775 .39319 .60581 .38449 .5974 Mtetra
.749 .763 .865 r
.38449 .5974 .39319 .60581 .40774 .59975 .39919 .58852 Mtetra
.753 .714 .815 r
.39919 .58852 .40774 .59975 .42245 .59035 .41399 .57789 Mtetra
.733 .691 .811 r
.41399 .57789 .42245 .59035 .43722 .58005 .42878 .5683 Mtetra
.68 .686 .849 r
.42878 .5683 .43722 .58005 .45198 .57163 .44352 .56247 Mtetra
.637 .724 .911 r
.44352 .56247 .45198 .57163 .46673 .56626 .45829 .55872 Mtetra
.597 .752 .952 r
.45829 .55872 .46673 .56626 .48153 .56254 .47313 .55592 Mtetra
.615 .785 .963 r
.47313 .55592 .48153 .56254 .49641 .55953 .48807 .55238 Mtetra
.64 .778 .947 r
.48807 .55238 .49641 .55953 .51139 .55604 .50311 .5482 Mtetra
.649 .764 .933 r
.50311 .5482 .51139 .55604 .52646 .5519 .51824 .54379 Mtetra
.652 .759 .928 r
.51824 .54379 .52646 .5519 .54162 .54754 .53345 .53928 Mtetra
.653 .757 .926 r
.53345 .53928 .54162 .54754 .55686 .54304 .54875 .53473 Mtetra
.651 .756 .926 r
.54875 .53473 .55686 .54304 .57219 .53847 .56414 .53019 Mtetra
.653 .759 .927 r
.56414 .53019 .57219 .53847 .5876 .53384 .57961 .52557 Mtetra
.655 .761 .928 r
.57961 .52557 .5876 .53384 .60309 .52915 .59516 .52083 Mtetra
.658 .762 .927 r
.59516 .52083 .60309 .52915 .61868 .5244 .61081 .51597 Mtetra
.659 .761 .925 r
.61081 .51597 .61868 .5244 .63435 .51959 .62653 .51103 Mtetra
.658 .759 .924 r
.62653 .51103 .63435 .51959 .6501 .51469 .64235 .5061 Mtetra
.659 .759 .924 r
.64235 .5061 .6501 .51469 .66594 .50967 .65825 .50112 Mtetra
.661 .762 .925 r
.65825 .50112 .66594 .50967 .68185 .50442 .67424 .49604 Mtetra
.666 .769 .927 r
.67424 .49604 .68185 .50442 .69782 .49849 .69031 .49073 Mtetra
.681 .791 .933 r
.69031 .49073 .69782 .49849 .71384 .49207 .70643 .48476 Mtetra
.699 .81 .934 r
.70643 .48476 .71384 .49207 .72998 .48637 .72259 .47802 Mtetra
.675 .777 .927 r
.72259 .47802 .72998 .48637 .74633 .48234 .73889 .47224 Mtetra
.623 .716 .913 r
.73889 .47224 .74633 .48234 .763 .48147 .75543 .4686 Mtetra
.532 .618 .883 r
.75543 .4686 .763 .48147 .77996 .48255 .77237 .46884 Mtetra
.509 .592 .873 r
.77237 .46884 .77996 .48255 .79701 .48274 .78955 .47018 Mtetra
.548 .634 .888 r
.78955 .47018 .79701 .48274 .81392 .47948 .80675 .46974 Mtetra
.665 .747 .912 r
.80675 .46974 .81392 .47948 .83054 .47193 .82363 .46424 Mtetra
.739 .825 .917 r
.82363 .46424 .83054 .47193 .84706 .46261 .8403 .45543 Mtetra
.757 .844 .917 r
.8403 .45543 .84706 .46261 .86373 .45413 .85695 .44582 Mtetra
.704 .801 .925 r
.85695 .44582 .86373 .45413 .88069 .44778 .8739 .43854 Mtetra
.667 .765 .923 r
.8739 .43854 .88069 .44778 .89787 .44253 .89111 .4328 Mtetra
.652 .748 .92 r
.89111 .4328 .89787 .44253 .91517 .43732 .90849 .42768 Mtetra
.658 .751 .919 r
.29052 .60499 .29957 .61294 .31362 .60852 .3046 .60062 Mtetra
.625 .744 .933 r
.3046 .60062 .31362 .60852 .3277 .60469 .3187 .59727 Mtetra
.534 .728 .964 r
.3187 .59727 .3277 .60469 .34178 .60234 .33276 .59608 Mtetra
.44 .725 .986 r
.33276 .59608 .34178 .60234 .35584 .60224 .34686 .59604 Mtetra
.545 .769 .981 r
.34686 .59604 .35584 .60224 .37005 .6014 .36116 .59411 Mtetra
.717 .785 .906 r
.36116 .59411 .37005 .6014 .38449 .5974 .37577 .58723 Mtetra
.758 .733 .829 r
.37577 .58723 .38449 .5974 .39919 .58852 .39058 .57684 Mtetra
.752 .708 .811 r
.39058 .57684 .39919 .58852 .41399 .57789 .40544 .56605 Mtetra
.703 .693 .837 r
.40544 .56605 .41399 .57789 .42878 .5683 .42021 .55881 Mtetra
.65 .722 .901 r
.42021 .55881 .42878 .5683 .44352 .56247 .43495 .55455 Mtetra
.596 .743 .946 r
.43495 .55455 .44352 .56247 .45829 .55872 .44975 .55183 Mtetra
.609 .776 .961 r
.44975 .55183 .45829 .55872 .47313 .55592 .46465 .5485 Mtetra
.64 .772 .943 r
.46465 .5485 .47313 .55592 .48807 .55238 .47966 .54434 Mtetra
.649 .76 .931 r
.47966 .54434 .48807 .55238 .50311 .5482 .49476 .53993 Mtetra
.651 .756 .927 r
.49476 .53993 .50311 .5482 .51824 .54379 .50994 .53545 Mtetra
.646 .754 .928 r
.50994 .53545 .51824 .54379 .53345 .53928 .52521 .53111 Mtetra
.646 .759 .932 r
.52521 .53111 .53345 .53928 .54875 .53473 .54056 .52672 Mtetra
.649 .766 .934 r
.54056 .52672 .54875 .53473 .56414 .53019 .55601 .52218 Mtetra
.652 .768 .934 r
.55601 .52218 .56414 .53019 .57961 .52557 .57154 .5175 Mtetra
.654 .768 .933 r
.57154 .5175 .57961 .52557 .59516 .52083 .58716 .51271 Mtetra
.657 .769 .932 r
.58716 .51271 .59516 .52083 .61081 .51597 .60286 .50782 Mtetra
.66 .77 .931 r
.60286 .50782 .61081 .51597 .62653 .51103 .61865 .50278 Mtetra
.663 .77 .929 r
.61865 .50278 .62653 .51103 .64235 .5061 .63452 .49759 Mtetra
.664 .765 .925 r
.63452 .49759 .64235 .5061 .65825 .50112 .65048 .49234 Mtetra
.66 .758 .923 r
.65048 .49234 .65825 .50112 .67424 .49604 .66654 .48724 Mtetra
.661 .76 .923 r
.66654 .48724 .67424 .49604 .69031 .49073 .68268 .48206 Mtetra
.667 .766 .924 r
.68268 .48206 .69031 .49073 .70643 .48476 .6989 .47661 Mtetra
.687 .787 .927 r
.6989 .47661 .70643 .48476 .72259 .47802 .71516 .47033 Mtetra
.702 .805 .929 r
.71516 .47033 .72259 .47802 .73889 .47224 .73147 .46339 Mtetra
.663 .764 .925 r
.73147 .46339 .73889 .47224 .75543 .4686 .74796 .45804 Mtetra
.586 .693 .916 r
.74796 .45804 .75543 .4686 .77237 .46884 .76477 .45575 Mtetra
.5 .6 .885 r
.76477 .45575 .77237 .46884 .78955 .47018 .78199 .45714 Mtetra
.509 .607 .886 r
.78199 .45714 .78955 .47018 .80675 .46974 .79936 .45815 Mtetra
.596 .68 .9 r
.79936 .45815 .80675 .46974 .82363 .46424 .81656 .45555 Mtetra
.714 .794 .914 r
.81656 .45555 .82363 .46424 .8403 .45543 .83341 .44777 Mtetra
.757 .834 .911 r
.83341 .44777 .8403 .45543 .85695 .44582 .85014 .438 Mtetra
.732 .825 .922 r
.85014 .438 .85695 .44582 .8739 .43854 .86705 .42941 Mtetra
.68 .775 .923 r
.86705 .42941 .8739 .43854 .89111 .4328 .88428 .42307 Mtetra
.654 .752 .922 r
.88428 .42307 .89111 .4328 .90849 .42768 .90173 .41779 Mtetra
.651 .748 .921 r
.28138 .59695 .29052 .60499 .3046 .60062 .2955 .59277 Mtetra
.606 .742 .941 r
.2955 .59277 .3046 .60062 .3187 .59727 .3096 .58992 Mtetra
.483 .713 .972 r
.3096 .58992 .3187 .59727 .33276 .59608 .32364 .58963 Mtetra
.465 .733 .985 r
.32364 .58963 .33276 .59608 .34686 .59604 .3378 .58922 Mtetra
.619 .777 .957 r
.3378 .58922 .34686 .59604 .36116 .59411 .35223 .58572 Mtetra
.753 .767 .864 r
.35223 .58572 .36116 .59411 .37577 .58723 .367 .57655 Mtetra
.764 .727 .818 r
.367 .57655 .37577 .58723 .39058 .57684 .3819 .5653 Mtetra
.739 .708 .823 r
.3819 .5653 .39058 .57684 .40544 .56605 .39676 .5557 Mtetra
.675 .712 .876 r
.39676 .5557 .40544 .56605 .42021 .55881 .41152 .55029 Mtetra
.61 .733 .933 r
.41152 .55029 .42021 .55881 .43495 .55455 .42628 .54727 Mtetra
.593 .762 .959 r
.42628 .54727 .43495 .55455 .44975 .55183 .44112 .54441 Mtetra
.635 .772 .946 r
.44112 .54441 .44975 .55183 .46465 .5485 .45609 .54038 Mtetra
.648 .759 .93 r
.45609 .54038 .46465 .5485 .47966 .54434 .47116 .53599 Mtetra
.649 .755 .926 r
.47116 .53599 .47966 .54434 .49476 .53993 .48631 .53154 Mtetra
.641 .752 .929 r
.48631 .53154 .49476 .53993 .50994 .53545 .50154 .52734 Mtetra
.644 .761 .934 r
.50154 .52734 .50994 .53545 .52521 .53111 .51687 .52299 Mtetra
.655 .765 .931 r
.51687 .52299 .52521 .53111 .54056 .52672 .53228 .51824 Mtetra
.657 .758 .925 r
.53228 .51824 .54056 .52672 .55601 .52218 .54778 .5134 Mtetra
.657 .752 .92 r
.54778 .5134 .55601 .52218 .57154 .5175 .56337 .50854 Mtetra
.656 .749 .918 r
.56337 .50854 .57154 .5175 .58716 .51271 .57905 .5037 Mtetra
.655 .749 .919 r
.57905 .5037 .58716 .51271 .60286 .50782 .59481 .49888 Mtetra
.654 .751 .921 r
.59481 .49888 .60286 .50782 .61865 .50278 .61067 .49405 Mtetra
.656 .758 .925 r
.61067 .49405 .61865 .50278 .63452 .49759 .62662 .48913 Mtetra
.665 .769 .927 r
.62662 .48913 .63452 .49759 .65048 .49234 .64264 .48379 Mtetra
.669 .769 .925 r
.64264 .48379 .65048 .49234 .66654 .48724 .65875 .4783 Mtetra
.661 .758 .922 r
.65875 .4783 .66654 .48724 .68268 .48206 .67495 .47306 Mtetra
.663 .759 .922 r
.67495 .47306 .68268 .48206 .6989 .47661 .69125 .46775 Mtetra
.671 .766 .922 r
.69125 .46775 .6989 .47661 .71516 .47033 .70762 .46207 Mtetra
.699 .792 .922 r
.70762 .46207 .71516 .47033 .73147 .46339 .724 .45519 Mtetra
.695 .793 .926 r
.724 .45519 .73147 .46339 .74796 .45804 .74048 .44846 Mtetra
.634 .739 .924 r
.74048 .44846 .74796 .45804 .76477 .45575 .75721 .44418 Mtetra
.522 .644 .91 r
.75721 .44418 .76477 .45575 .78199 .45714 .77439 .44423 Mtetra
.483 .597 .891 r
.77439 .44423 .78199 .45714 .79936 .45815 .79186 .44602 Mtetra
.537 .642 .901 r
.79186 .44602 .79936 .45815 .81656 .45555 .80932 .44569 Mtetra
.678 .756 .91 r
.80932 .44569 .81656 .45555 .83341 .44777 .8264 .43945 Mtetra
.748 .818 .907 r
.8264 .43945 .83341 .44777 .85014 .438 .84325 .42997 Mtetra
.752 .828 .91 r
.84325 .42997 .85014 .438 .86705 .42941 .86014 .42033 Mtetra
.693 .784 .921 r
.86014 .42033 .86705 .42941 .88428 .42307 .87739 .41336 Mtetra
.66 .757 .922 r
.87739 .41336 .88428 .42307 .90173 .41779 .89488 .40777 Mtetra
.642 .747 .925 r
.27215 .58885 .28138 .59695 .2955 .59277 .28629 .58492 Mtetra
.58 .736 .95 r
.28629 .58492 .2955 .59277 .3096 .58992 .30039 .58271 Mtetra
.451 .706 .976 r
.30039 .58271 .3096 .58992 .32364 .58963 .31444 .58285 Mtetra
.506 .741 .979 r
.31444 .58285 .32364 .58963 .3378 .58922 .32868 .58181 Mtetra
.684 .779 .922 r
.32868 .58181 .3378 .58922 .35223 .58572 .34326 .57622 Mtetra
.762 .747 .839 r
.34326 .57622 .35223 .58572 .367 .57655 .35815 .5658 Mtetra
.766 .728 .817 r
.35815 .5658 .367 .57655 .3819 .5653 .37312 .55434 Mtetra
.716 .714 .847 r
.37312 .55434 .3819 .5653 .39676 .5557 .38796 .54654 Mtetra
.645 .731 .911 r
.38796 .54654 .39676 .5557 .41152 .55029 .40271 .54237 Mtetra
.584 .742 .952 r
.40271 .54237 .41152 .55029 .42628 .54727 .4175 .5399 Mtetra
.62 .77 .952 r
.4175 .5399 .42628 .54727 .44112 .54441 .43242 .53627 Mtetra
.644 .758 .932 r
.43242 .53627 .44112 .54441 .45609 .54038 .44745 .53197 Mtetra
.649 .754 .926 r
.44745 .53197 .45609 .54038 .47116 .53599 .46257 .52751 Mtetra
.64 .75 .929 r
.46257 .52751 .47116 .53599 .48631 .53154 .47777 .52334 Mtetra
.644 .76 .933 r
.47777 .52334 .48631 .53154 .50154 .52734 .49306 .51899 Mtetra
.657 .761 .927 r
.49306 .51899 .50154 .52734 .51687 .52299 .50845 .51413 Mtetra
.66 .751 .918 r
.50845 .51413 .51687 .52299 .53228 .51824 .52392 .50919 Mtetra
.658 .747 .916 r
.52392 .50919 .53228 .51824 .54778 .5134 .53947 .50429 Mtetra
.657 .747 .916 r
.53947 .50429 .54778 .5134 .56337 .50854 .55512 .49941 Mtetra
.656 .747 .917 r
.55512 .49941 .56337 .50854 .57905 .5037 .57085 .49452 Mtetra
.57085 .49452 .57905 .5037 .59481 .49888 .58668 .48962 Mtetra
.654 .746 .917 r
.58668 .48962 .59481 .49888 .61067 .49405 .60259 .48474 Mtetra
.653 .745 .918 r
.60259 .48474 .61067 .49405 .62662 .48913 .6186 .47991 Mtetra
.654 .749 .92 r
.6186 .47991 .62662 .48913 .64264 .48379 .63471 .47499 Mtetra
.666 .764 .924 r
.63471 .47499 .64264 .48379 .65875 .4783 .65088 .46955 Mtetra
.67 .769 .924 r
.65088 .46955 .65875 .4783 .67495 .47306 .66714 .46392 Mtetra
.662 .757 .921 r
.66714 .46392 .67495 .47306 .69125 .46775 .68351 .45859 Mtetra
.665 .759 .92 r
.68351 .45859 .69125 .46775 .70762 .46207 .69995 .45308 Mtetra
.681 .77 .918 r
.69995 .45308 .70762 .46207 .724 .45519 .71646 .44688 Mtetra
.709 .797 .92 r
.71646 .44688 .724 .45519 .74048 .44846 .73297 .43948 Mtetra
.667 .768 .926 r
.73297 .43948 .74048 .44846 .75721 .44418 .74968 .43382 Mtetra
.568 .696 .927 r
.74968 .43382 .75721 .44418 .77439 .44423 .76677 .4319 Mtetra
.469 .604 .903 r
.76677 .4319 .77439 .44423 .79186 .44602 .78429 .43381 Mtetra
.501 .624 .905 r
.78429 .43381 .79186 .44602 .80932 .44569 .80191 .43465 Mtetra
.629 .712 .907 r
.80191 .43465 .80932 .44569 .8264 .43945 .81925 .43049 Mtetra
.734 .801 .905 r
.81925 .43049 .8264 .43945 .84325 .42997 .83624 .42157 Mtetra
.76 .823 .901 r
.83624 .42157 .84325 .42997 .86014 .42033 .85318 .41138 Mtetra
.709 .796 .918 r
.85318 .41138 .86014 .42033 .87739 .41336 .87043 .40363 Mtetra
.667 .763 .921 r
.87043 .40363 .87739 .41336 .89488 .40777 .88797 .39768 Mtetra
.633 .746 .929 r
.26282 .58071 .27215 .58885 .28629 .58492 .27698 .57703 Mtetra
.549 .727 .957 r
.27698 .57703 .28629 .58492 .30039 .58271 .29108 .57549 Mtetra
.446 .706 .977 r
.29108 .57549 .30039 .58271 .31444 .58285 .30516 .57565 Mtetra
.548 .747 .969 r
.30516 .57565 .31444 .58285 .32868 .58181 .31948 .57388 Mtetra
.723 .775 .894 r
.31948 .57388 .32868 .58181 .34326 .57622 .33422 .5665 Mtetra
.771 .746 .83 r
.33422 .5665 .34326 .57622 .35815 .5658 .34921 .55524 Mtetra
.764 .732 .823 r
.34921 .55524 .35815 .5658 .37312 .55434 .36422 .5441 Mtetra
.691 .722 .873 r
.36422 .5441 .37312 .55434 .38796 .54654 .37904 .53785 Mtetra
.616 .734 .931 r
.37904 .53785 .38796 .54654 .40271 .54237 .39381 .53459 Mtetra
.589 .75 .954 r
.39381 .53459 .40271 .54237 .4175 .5399 .40865 .53189 Mtetra
.636 .76 .938 r
.40865 .53189 .4175 .5399 .43242 .53627 .42364 .52784 Mtetra
.648 .754 .927 r
.42364 .52784 .43242 .53627 .44745 .53197 .43872 .5234 Mtetra
.643 .75 .927 r
.43872 .5234 .44745 .53197 .46257 .52751 .45389 .51911 Mtetra
.638 .754 .932 r
.45389 .51911 .46257 .52751 .47777 .52334 .46914 .51493 Mtetra
.657 .761 .926 r
.46914 .51493 .47777 .52334 .49306 .51899 .4845 .51007 Mtetra
.66 .751 .917 r
.4845 .51007 .49306 .51899 .50845 .51413 .49994 .50507 Mtetra
.658 .748 .916 r
.49994 .50507 .50845 .51413 .52392 .50919 .51546 .50015 Mtetra
.654 .748 .919 r
.51546 .50015 .52392 .50919 .53947 .50429 .53108 .49536 Mtetra
.651 .751 .923 r
.53108 .49536 .53947 .50429 .55512 .49941 .54678 .49062 Mtetra
.656 .757 .925 r
.54678 .49062 .55512 .49941 .57085 .49452 .56258 .48568 Mtetra
.66 .759 .923 r
.56258 .48568 .57085 .49452 .58668 .48962 .57846 .48053 Mtetra
.658 .753 .92 r
.57846 .48053 .58668 .48962 .60259 .48474 .59443 .47545 Mtetra
.655 .749 .919 r
.59443 .47545 .60259 .48474 .6186 .47991 .6105 .47048 Mtetra
.652 .746 .919 r
.6105 .47048 .6186 .47991 .63471 .47499 .62667 .4656 Mtetra
.654 .749 .919 r
.62667 .4656 .63471 .47499 .65088 .46955 .64293 .46057 Mtetra
.671 .766 .921 r
.64293 .46057 .65088 .46955 .66714 .46392 .65925 .45485 Mtetra
.667 .764 .922 r
.65925 .45485 .66714 .46392 .68351 .45859 .67567 .44924 Mtetra
.663 .757 .92 r
.67567 .44924 .68351 .45859 .69995 .45308 .6922 .44377 Mtetra
.672 .762 .918 r
.6922 .44377 .69995 .45308 .71646 .44688 .70879 .4379 Mtetra
.704 .782 .912 r
.70879 .4379 .71646 .44688 .73297 .43948 .72539 .43063 Mtetra
.69 .782 .921 r
.72539 .43063 .73297 .43948 .74968 .43382 .74211 .42393 Mtetra
.613 .729 .928 r
.74211 .42393 .74968 .43382 .76677 .4319 .75914 .42031 Mtetra
.471 .622 .917 r
.75914 .42031 .76677 .4319 .78429 .43381 .77668 .42176 Mtetra
.472 .614 .91 r
.77668 .42176 .78429 .43381 .80191 .43465 .79441 .42338 Mtetra
.583 .689 .914 r
.79441 .42338 .80191 .43465 .81925 .43049 .81197 .42097 Mtetra
.719 .785 .904 r
.81197 .42097 .81925 .43049 .83624 .42157 .82912 .41271 Mtetra
.76 .814 .896 r
.82912 .41271 .83624 .42157 .85318 .41138 .84614 .40239 Mtetra
.725 .803 .913 r
.84614 .40239 .85318 .41138 .87043 .40363 .8634 .39383 Mtetra
.674 .766 .92 r
.8634 .39383 .87043 .40363 .88797 .39768 .88098 .38751 Mtetra
.625 .744 .933 r
.2534 .57252 .26282 .58071 .27698 .57703 .26759 .56904 Mtetra
.525 .718 .96 r
.26759 .56904 .27698 .57703 .29108 .57549 .28168 .56799 Mtetra
.456 .704 .974 r
.28168 .56799 .29108 .57549 .30516 .57565 .29581 .56804 Mtetra
.58 .749 .957 r
.29581 .56804 .30516 .57565 .31948 .57388 .31021 .56558 Mtetra
.745 .771 .874 r
.31021 .56558 .31948 .57388 .33422 .5665 .32508 .55686 Mtetra
.777 .75 .828 r
.32508 .55686 .33422 .5665 .34921 .55524 .34016 .5451 Mtetra
.756 .739 .837 r
.34016 .5451 .34921 .55524 .36422 .5441 .35519 .53482 Mtetra
.676 .74 .898 r
.35519 .53482 .36422 .5441 .37904 .53785 .37002 .52934 Mtetra
.594 .734 .941 r
.37002 .52934 .37904 .53785 .39381 .53459 .38481 .52662 Mtetra
.604 .752 .948 r
.38481 .52662 .39381 .53459 .40865 .53189 .39972 .52347 Mtetra
.641 .754 .93 r
.39972 .52347 .40865 .53189 .42364 .52784 .41476 .51922 Mtetra
.648 .752 .925 r
.41476 .51922 .42364 .52784 .43872 .5234 .4299 .51472 Mtetra
.637 .748 .929 r
.4299 .51472 .43872 .5234 .45389 .51911 .44511 .51059 Mtetra
.648 .756 .929 r
.44511 .51059 .45389 .51911 .46914 .51493 .46043 .50605 Mtetra
.661 .753 .918 r
.46043 .50605 .46914 .51493 .4845 .51007 .47584 .50099 Mtetra
.658 .749 .917 r
.47584 .50099 .4845 .51007 .49994 .50507 .49134 .49602 Mtetra
.649 .748 .922 r
.49134 .49602 .49994 .50507 .51546 .50015 .50692 .49137 Mtetra
.644 .754 .929 r
.50692 .49137 .51546 .50015 .53108 .49536 .52259 .48684 Mtetra
.651 .764 .932 r
.52259 .48684 .53108 .49536 .54678 .49062 .53836 .48202 Mtetra
.655 .764 .93 r
.53836 .48202 .54678 .49062 .56258 .48568 .55422 .47703 Mtetra
.659 .765 .928 r
.55422 .47703 .56258 .48568 .57846 .48053 .57016 .47186 Mtetra
.666 .768 .926 r
.57016 .47186 .57846 .48053 .59443 .47545 .58619 .46641 Mtetra
.662 .76 .922 r
.58619 .46641 .59443 .47545 .6105 .47048 .60232 .46106 Mtetra
.654 .749 .92 r
.60232 .46106 .6105 .47048 .62667 .4656 .61855 .45605 Mtetra
.651 .746 .919 r
.61855 .45605 .62667 .4656 .64293 .46057 .63487 .45111 Mtetra
.663 .754 .918 r
.63487 .45111 .64293 .46057 .65925 .45485 .65128 .44566 Mtetra
.673 .765 .92 r
.65128 .44566 .65925 .45485 .67567 .44924 .66776 .43977 Mtetra
.663 .756 .92 r
.66776 .43977 .67567 .44924 .6922 .44377 .68435 .43426 Mtetra
.668 .759 .918 r
.68435 .43426 .6922 .44377 .70879 .4379 .70102 .42849 Mtetra
.694 .771 .911 r
.70102 .42849 .70879 .4379 .72539 .43063 .71772 .42158 Mtetra
.704 .784 .914 r
.71772 .42158 .72539 .43063 .74211 .42393 .73447 .41421 Mtetra
.635 .745 .927 r
.73447 .41421 .74211 .42393 .75914 .42031 .75151 .40969 Mtetra
.488 .656 .935 r
.75151 .40969 .75914 .42031 .77668 .42176 .76903 .41014 Mtetra
.449 .613 .919 r
.76903 .41014 .77668 .42176 .79441 .42338 .78685 .41215 Mtetra
.544 .673 .922 r
.78685 .41215 .79441 .42338 .81197 .42097 .80459 .41104 Mtetra
.704 .773 .906 r
.80459 .41104 .81197 .42097 .82912 .41271 .82188 .40339 Mtetra
.756 .805 .892 r
.82188 .40339 .82912 .41271 .84614 .40239 .839 .39309 Mtetra
.735 .801 .904 r
.839 .39309 .84614 .40239 .8634 .39383 .85629 .38391 Mtetra
.68 .768 .917 r
.85629 .38391 .8634 .39383 .88098 .38751 .87392 .37726 Mtetra
.619 .742 .935 r
.24388 .56424 .2534 .57252 .26759 .56904 .2581 .56091 Mtetra
.51 .71 .961 r
.2581 .56091 .26759 .56904 .28168 .56799 .2722 .56016 Mtetra
.469 .703 .97 r
.2722 .56016 .28168 .56799 .29581 .56804 .28637 .56007 Mtetra
.604 .749 .947 r
.28637 .56007 .29581 .56804 .31021 .56558 .30086 .55701 Mtetra
.756 .769 .863 r
.30086 .55701 .31021 .56558 .32508 .55686 .31584 .54745 Mtetra
.782 .756 .83 r
.31584 .54745 .32508 .55686 .34016 .5451 .331 .53544 Mtetra
.75 .749 .851 r
.331 .53544 .34016 .5451 .35519 .53482 .34604 .52581 Mtetra
.663 .744 .911 r
.34604 .52581 .35519 .53482 .37002 .52934 .3609 .52085 Mtetra
.584 .733 .946 r
.3609 .52085 .37002 .52934 .38481 .52662 .37573 .51835 Mtetra
.617 .751 .941 r
.37573 .51835 .38481 .52662 .39972 .52347 .3907 .51484 Mtetra
.644 .751 .927 r
.3907 .51484 .39972 .52347 .41476 .51922 .4058 .51046 Mtetra
.646 .75 .925 r
.4058 .51046 .41476 .51922 .4299 .51472 .42098 .50598 Mtetra
.635 .748 .93 r
.42098 .50598 .4299 .51472 .44511 .51059 .43625 .50185 Mtetra
.655 .756 .924 r
.43625 .50185 .44511 .51059 .46043 .50605 .45163 .497 Mtetra
.661 .751 .917 r
.45163 .497 .46043 .50605 .47584 .50099 .4671 .4919 Mtetra
.654 .749 .92 r
.4671 .4919 .47584 .50099 .49134 .49602 .48265 .48703 Mtetra
.64 .748 .927 r
.48265 .48703 .49134 .49602 .50692 .49137 .49828 .48264 Mtetra
.654 .76 .928 r
.49828 .48264 .50692 .49137 .52259 .48684 .51402 .4777 Mtetra
.663 .755 .918 r
.51402 .4777 .52259 .48684 .53836 .48202 .52984 .4724 Mtetra
.656 .743 .914 r
.52984 .4724 .53836 .48202 .55422 .47703 .54576 .46736 Mtetra
.649 .74 .916 r
.54576 .46736 .55422 .47703 .57016 .47186 .56177 .46256 Mtetra
.657 .753 .921 r
.56177 .46256 .57016 .47186 .58619 .46641 .57787 .45741 Mtetra
.67 .766 .922 r
.57787 .45741 .58619 .46641 .60232 .46106 .59405 .4517 Mtetra
.657 .754 .921 r
.59405 .4517 .60232 .46106 .61855 .45605 .61034 .44647 Mtetra
.651 .748 .921 r
.61034 .44647 .61855 .45605 .63487 .45111 .62673 .44148 Mtetra
.657 .75 .919 r
.62673 .44148 .63487 .45111 .65128 .44566 .6432 .43623 Mtetra
.674 .762 .917 r
.6432 .43623 .65128 .44566 .66776 .43977 .65975 .43024 Mtetra
.665 .758 .92 r
.65975 .43024 .66776 .43977 .68435 .43426 .67641 .42459 Mtetra
.666 .757 .918 r
.67641 .42459 .68435 .43426 .70102 .42849 .69315 .41885 Mtetra
.687 .766 .912 r
.69315 .41885 .70102 .42849 .71772 .42158 .70994 .4122 Mtetra
.709 .781 .908 r
.70994 .4122 .71772 .42158 .73447 .41421 .72676 .4045 Mtetra
.65 .753 .925 r
.72676 .4045 .73447 .41421 .75151 .40969 .74382 .39933 Mtetra
.509 .675 .94 r
.74382 .39933 .75151 .40969 .76903 .41014 .76135 .39899 Mtetra
.431 .617 .928 r
.76135 .39899 .76903 .41014 .78685 .41215 .77924 .40116 Mtetra
.515 .666 .931 r
.77924 .40116 .78685 .41215 .80459 .41104 .79711 .4008 Mtetra
.691 .764 .907 r
.79711 .4008 .80459 .41104 .82188 .40339 .81453 .39367 Mtetra
.753 .798 .889 r
.81453 .39367 .82188 .40339 .839 .39309 .83174 .38341 Mtetra
.741 .797 .897 r
.83174 .38341 .839 .39309 .85629 .38391 .84908 .3738 Mtetra
.685 .768 .915 r
.84908 .3738 .85629 .38391 .87392 .37726 .86678 .36689 Mtetra
.616 .741 .936 r
.23427 .55588 .24388 .56424 .2581 .56091 .24852 .55259 Mtetra
.504 .705 .961 r
.24852 .55259 .2581 .56091 .2722 .56016 .26265 .55198 Mtetra
.479 .699 .965 r
.26265 .55198 .2722 .56016 .28637 .56007 .27686 .55177 Mtetra
.619 .748 .938 r
.27686 .55177 .28637 .56007 .30086 .55701 .29141 .54828 Mtetra
.76 .768 .859 r
.29141 .54828 .30086 .55701 .31584 .54745 .30647 .53838 Mtetra
.786 .764 .834 r
.30647 .53838 .31584 .54745 .331 .53544 .32171 .52623 Mtetra
.748 .759 .862 r
.32171 .52623 .331 .53544 .34604 .52581 .3368 .51693 Mtetra
.655 .747 .917 r
.3368 .51693 .34604 .52581 .3609 .52085 .35169 .51221 Mtetra
.581 .731 .945 r
.35169 .51221 .3609 .52085 .37573 .51835 .36656 .50975 Mtetra
.624 .747 .935 r
.36656 .50975 .37573 .51835 .3907 .51484 .38159 .50603 Mtetra
.645 .75 .925 r
.38159 .50603 .3907 .51484 .4058 .51046 .39674 .50156 Mtetra
.644 .748 .925 r
.39674 .50156 .4058 .51046 .42098 .50598 .41198 .49711 Mtetra
.636 .748 .929 r
.41198 .49711 .42098 .50598 .43625 .50185 .4273 .49291 Mtetra
.659 .754 .921 r
.4273 .49291 .43625 .50185 .45163 .497 .44273 .48789 Mtetra
.661 .752 .918 r
.44273 .48789 .45163 .497 .4671 .4919 .45826 .48275 Mtetra
.649 .749 .922 r
.45826 .48275 .4671 .4919 .48265 .48703 .47386 .47802 Mtetra
.641 .75 .928 r
.47386 .47802 .48265 .48703 .49828 .48264 .48956 .47356 Mtetra
.666 .758 .919 r
.48956 .47356 .49828 .48264 .51402 .4777 .50535 .46814 Mtetra
.671 .75 .91 r
.50535 .46814 .51402 .4777 .52984 .4724 .52123 .46244 Mtetra
.656 .737 .909 r
.52123 .46244 .52984 .4724 .54576 .46736 .53721 .45734 Mtetra
.64 .732 .915 r
.53721 .45734 .54576 .46736 .56177 .46256 .55328 .45284 Mtetra
.646 .742 .919 r
.55328 .45284 .56177 .46256 .57787 .45741 .56945 .44806 Mtetra
.67 .759 .918 r
.56945 .44806 .57787 .45741 .59405 .4517 .58569 .44231 Mtetra
.662 .758 .921 r
.58569 .44231 .59405 .4517 .61034 .44647 .60204 .43683 Mtetra
.651 .749 .921 r
.60204 .43683 .61034 .44647 .62673 .44148 .61849 .43177 Mtetra
.653 .749 .92 r
.61849 .43177 .62673 .44148 .6432 .43623 .63504 .42659 Mtetra
.673 .759 .915 r
.63504 .42659 .6432 .43623 .65975 .43024 .65166 .42056 Mtetra
.666 .757 .918 r
.65166 .42056 .65975 .43024 .67641 .42459 .66838 .41478 Mtetra
.666 .755 .917 r
.66838 .41478 .67641 .42459 .69315 .41885 .6852 .40901 Mtetra
.683 .762 .912 r
.6852 .40901 .69315 .41885 .70994 .4122 .70207 .40247 Mtetra
.711 .775 .903 r
.70207 .40247 .70994 .4122 .72676 .4045 .71896 .39462 Mtetra
.657 .755 .922 r
.71896 .39462 .72676 .4045 .74382 .39933 .73607 .38908 Mtetra
.519 .686 .943 r
.73607 .38908 .74382 .39933 .76135 .39899 .75363 .38829 Mtetra
.417 .623 .937 r
.75363 .38829 .76135 .39899 .77924 .40116 .77158 .39049 Mtetra
.5 .669 .939 r
.77158 .39049 .77924 .40116 .79711 .4008 .78953 .39037 Mtetra
.682 .759 .909 r
.78953 .39037 .79711 .4008 .81453 .39367 .80707 .38358 Mtetra
.75 .792 .886 r
.80707 .38358 .81453 .39367 .83174 .38341 .82438 .37333 Mtetra
.743 .791 .891 r
.82438 .37333 .83174 .38341 .84908 .3738 .84179 .36347 Mtetra
.687 .767 .912 r
.84179 .36347 .84908 .3738 .86678 .36689 .85956 .3564 Mtetra
.616 .741 .935 r
.22456 .5474 .23427 .55588 .24852 .55259 .23885 .54407 Mtetra
.506 .703 .959 r
.23885 .54407 .24852 .55259 .26265 .55198 .25301 .54342 Mtetra
.485 .694 .961 r
.25301 .54342 .26265 .55198 .27686 .55177 .26726 .54318 Mtetra
.62 .743 .934 r
.26726 .54318 .27686 .55177 .29141 .54828 .28186 .53964 Mtetra
.761 .771 .862 r
.28186 .53964 .29141 .54828 .30647 .53838 .29699 .52968 Mtetra
.789 .773 .838 r
.29699 .52968 .30647 .53838 .32171 .52623 .31229 .51746 Mtetra
.751 .77 .869 r
.31229 .51746 .32171 .52623 .3368 .51693 .32745 .5081 Mtetra
.655 .75 .92 r
.32745 .5081 .3368 .51693 .35169 .51221 .34239 .50333 Mtetra
.583 .727 .943 r
.34239 .50333 .35169 .51221 .36656 .50975 .3573 .50083 Mtetra
.624 .742 .931 r
.3573 .50083 .36656 .50975 .38159 .50603 .37238 .49706 Mtetra
.645 .748 .924 r
.37238 .49706 .38159 .50603 .39674 .50156 .38758 .49254 Mtetra
.644 .748 .924 r
.38758 .49254 .39674 .50156 .41198 .49711 .40288 .48804 Mtetra
.636 .745 .927 r
.40288 .48804 .41198 .49711 .4273 .49291 .41825 .4838 Mtetra
.659 .752 .919 r
.41825 .4838 .4273 .49291 .44273 .48789 .43374 .47871 Mtetra
.661 .753 .918 r
.43374 .47871 .44273 .48789 .45826 .48275 .44932 .47352 Mtetra
.649 .749 .923 r
.44932 .47352 .45826 .48275 .47386 .47802 .46498 .46874 Mtetra
.641 .747 .925 r
.46498 .46874 .47386 .47802 .48956 .47356 .48074 .46423 Mtetra
.666 .754 .917 r
.48074 .46423 .48956 .47356 .50535 .46814 .49659 .45875 Mtetra
.672 .756 .914 r
.49659 .45875 .50535 .46814 .52123 .46244 .51254 .453 Mtetra
.656 .751 .92 r
.51254 .453 .52123 .46244 .53721 .45734 .52857 .44785 Mtetra
.639 .746 .926 r
.52857 .44785 .53721 .45734 .55328 .45284 .5447 .44329 Mtetra
.646 .748 .924 r
.5447 .44329 .55328 .45284 .56945 .44806 .56093 .43845 Mtetra
.67 .756 .915 r
.56093 .43845 .56945 .44806 .58569 .44231 .57724 .43265 Mtetra
.662 .753 .918 r
.57724 .43265 .58569 .44231 .60204 .43683 .59365 .42711 Mtetra
.651 .75 .922 r
.59365 .42711 .60204 .43683 .61849 .43177 .61017 .42199 Mtetra
.653 .75 .921 r
.61017 .42199 .61849 .43177 .63504 .42659 .62679 .41675 Mtetra
.673 .757 .914 r
.62679 .41675 .63504 .42659 .65166 .42056 .64347 .41066 Mtetra
.666 .755 .916 r
.64347 .41066 .65166 .42056 .66838 .41478 .66026 .40482 Mtetra
.666 .755 .917 r
.66026 .40482 .66838 .41478 .6852 .40901 .67715 .39899 Mtetra
.683 .761 .911 r
.67715 .39899 .6852 .40901 .70207 .40247 .69409 .39239 Mtetra
.71 .77 .899 r
.69409 .39239 .70207 .40247 .71896 .39462 .71106 .38447 Mtetra
.658 .751 .919 r
.71106 .38447 .71896 .39462 .73607 .38908 .72824 .37888 Mtetra
.518 .689 .945 r
.72824 .37888 .73607 .38908 .75363 .38829 .74587 .37804 Mtetra
.405 .629 .945 r
.74587 .37804 .75363 .38829 .77158 .39049 .76387 .38019 Mtetra
.493 .677 .947 r
.76387 .38019 .77158 .39049 .78953 .39037 .78189 .38002 Mtetra
.683 .763 .912 r
.78189 .38002 .78953 .39037 .80707 .38358 .79951 .37317 Mtetra
.749 .787 .883 r
.79951 .37317 .80707 .38358 .82438 .37333 .8169 .36283 Mtetra
.742 .784 .887 r
.8169 .36283 .82438 .37333 .84179 .36347 .8344 .3529 Mtetra
.687 .764 .91 r
.8344 .3529 .84179 .36347 .85956 .3564 .85225 .34576 Mtetra
.619 .741 .934 r
.21475 .53882 .22456 .5474 .23885 .54407 .22909 .53535 Mtetra
.515 .703 .956 r
.22909 .53535 .23885 .54407 .25301 .54342 .24331 .5345 Mtetra
.486 .688 .956 r
.24331 .5345 .25301 .54342 .26726 .54318 .25758 .53429 Mtetra
.608 .734 .934 r
.25758 .53429 .26726 .54318 .28186 .53964 .27219 .5311 Mtetra
.758 .775 .867 r
.27219 .5311 .28186 .53964 .29699 .52968 .28736 .52136 Mtetra
.792 .782 .844 r
.28736 .52136 .29699 .52968 .31229 .51746 .30274 .50914 Mtetra
.76 .782 .871 r
.30274 .50914 .31229 .51746 .32745 .5081 .31799 .49933 Mtetra
.663 .756 .919 r
.31799 .49933 .32745 .5081 .34239 .50333 .333 .49422 Mtetra
.587 .725 .939 r
.333 .49422 .34239 .50333 .3573 .50083 .34797 .49158 Mtetra
.62 .735 .929 r
.34797 .49158 .3573 .50083 .37238 .49706 .36308 .48793 Mtetra
.645 .746 .923 r
.36308 .48793 .37238 .49706 .38758 .49254 .37834 .4834 Mtetra
.646 .748 .923 r
.37834 .4834 .38758 .49254 .40288 .48804 .39368 .47878 Mtetra
.636 .743 .925 r
.39368 .47878 .40288 .48804 .41825 .4838 .40911 .4745 Mtetra
.655 .749 .919 r
.40911 .4745 .41825 .4838 .43374 .47871 .42465 .46949 Mtetra
.661 .754 .919 r
.42465 .46949 .43374 .47871 .44932 .47352 .44029 .46422 Mtetra
.654 .751 .921 r
.44029 .46422 .44932 .47352 .46498 .46874 .45602 .45919 Mtetra
.641 .742 .923 r
.45602 .45919 .46498 .46874 .48074 .46423 .47182 .45465 Mtetra
.655 .748 .918 r
.47182 .45465 .48074 .46423 .49659 .45875 .48773 .44955 Mtetra
.663 .76 .922 r
.48773 .44955 .49659 .45875 .51254 .453 .50374 .44409 Mtetra
.655 .766 .931 r
.50374 .44409 .51254 .453 .52857 .44785 .51984 .43887 Mtetra
.647 .763 .933 r
.51984 .43887 .52857 .44785 .5447 .44329 .53603 .43391 Mtetra
.657 .758 .924 r
.53603 .43391 .5447 .44329 .56093 .43845 .55232 .4286 Mtetra
.67 .753 .912 r
.55232 .4286 .56093 .43845 .57724 .43265 .5687 .42271 Mtetra
.658 .748 .917 r
.5687 .42271 .57724 .43265 .59365 .42711 .58518 .41731 Mtetra
.651 .75 .922 r
.58518 .41731 .59365 .42711 .61017 .42199 .60176 .41215 Mtetra
.657 .752 .921 r
.60176 .41215 .61017 .42199 .62679 .41675 .61844 .40672 Mtetra
.674 .756 .912 r
.61844 .40672 .62679 .41675 .64347 .41066 .63519 .40055 Mtetra
.665 .752 .915 r
.63519 .40055 .64347 .41066 .66026 .40482 .65205 .39472 Mtetra
.666 .754 .916 r
.65205 .39472 .66026 .40482 .67715 .39899 .66901 .3888 Mtetra
.686 .761 .908 r
.66901 .3888 .67715 .39899 .69409 .39239 .68602 .38196 Mtetra
.707 .764 .896 r
.68602 .38196 .69409 .39239 .71106 .38447 .70306 .37406 Mtetra
.65 .745 .919 r
.70306 .37406 .71106 .38447 .72824 .37888 .72034 .36871 Mtetra
.501 .685 .949 r
.72034 .36871 .72824 .37888 .74587 .37804 .73805 .36822 Mtetra
.395 .638 .953 r
.73805 .36822 .74587 .37804 .76387 .38019 .75611 .37025 Mtetra
.497 .691 .954 r
.75611 .37025 .76387 .38019 .78189 .38002 .77418 .36975 Mtetra
.692 .771 .912 r
.77418 .36975 .78189 .38002 .79951 .37317 .79184 .36241 Mtetra
.749 .782 .88 r
.79184 .36241 .79951 .37317 .8169 .36283 .80931 .35192 Mtetra
.737 .777 .884 r
.80931 .35192 .8169 .36283 .8344 .3529 .82691 .34209 Mtetra
.684 .761 .909 r
.82691 .34209 .8344 .3529 .85225 .34576 .84485 .33498 Mtetra
.625 .743 .931 r
.20485 .53014 .21475 .53882 .22909 .53535 .21925 .52644 Mtetra
.532 .708 .951 r
.21925 .52644 .22909 .53535 .24331 .5345 .23352 .52521 Mtetra
.485 .68 .952 r
.23352 .52521 .24331 .5345 .25758 .53429 .24781 .52507 Mtetra
.59 .723 .936 r
.24781 .52507 .25758 .53429 .27219 .5311 .26243 .5224 Mtetra
.745 .772 .875 r
.26243 .5224 .27219 .5311 .28736 .52136 .27761 .51338 Mtetra
.792 .791 .851 r
.27761 .51338 .28736 .52136 .30274 .50914 .29305 .50129 Mtetra
.774 .795 .87 r
.29305 .50129 .30274 .50914 .31799 .49933 .30842 .49069 Mtetra
.678 .765 .917 r
.30842 .49069 .31799 .49933 .333 .49422 .32352 .48495 Mtetra
.596 .727 .936 r
.32352 .48495 .333 .49422 .34797 .49158 .33854 .482 Mtetra
.611 .726 .927 r
.33854 .482 .34797 .49158 .36308 .48793 .35369 .47862 Mtetra
.642 .744 .922 r
.35369 .47862 .36308 .48793 .37834 .4834 .36899 .47412 Mtetra
.649 .747 .922 r
.36899 .47412 .37834 .4834 .39368 .47878 .3844 .46936 Mtetra
.638 .742 .924 r
.3844 .46936 .39368 .47878 .40911 .4745 .39988 .46499 Mtetra
.648 .745 .92 r
.39988 .46499 .40911 .4745 .42465 .46949 .41547 .46018 Mtetra
.661 .754 .919 r
.41547 .46018 .42465 .46949 .44029 .46422 .43117 .45486 Mtetra
.658 .753 .92 r
.43117 .45486 .44029 .46422 .45602 .45919 .44695 .44962 Mtetra
.649 .747 .921 r
.44695 .44962 .45602 .45919 .47182 .45465 .46282 .44471 Mtetra
.646 .739 .917 r
.46282 .44471 .47182 .45465 .48773 .44955 .47878 .43991 Mtetra
.652 .749 .921 r
.47878 .43991 .48773 .44955 .50374 .44409 .49485 .43482 Mtetra
.655 .76 .927 r
.49485 .43482 .50374 .44409 .51984 .43887 .51101 .42956 Mtetra
.659 .761 .925 r
.51101 .42956 .51984 .43887 .53603 .43391 .52726 .42411 Mtetra
.666 .754 .916 r
.52726 .42411 .53603 .43391 .55232 .4286 .54361 .41837 Mtetra
.663 .745 .911 r
.54361 .41837 .55232 .4286 .5687 .42271 .56006 .41274 Mtetra
.654 .748 .919 r
.56006 .41274 .5687 .42271 .58518 .41731 .5766 .40744 Mtetra
.651 .751 .923 r
.5766 .40744 .58518 .41731 .60176 .41215 .59325 .40222 Mtetra
.663 .755 .919 r
.59325 .40222 .60176 .41215 .61844 .40672 .60999 .39647 Mtetra
.673 .753 .911 r
.60999 .39647 .61844 .40672 .63519 .40055 .62681 .39028 Mtetra
.663 .75 .915 r
.62681 .39028 .63519 .40055 .65205 .39472 .64375 .38447 Mtetra
.668 .754 .915 r
.64375 .38447 .65205 .39472 .66901 .3888 .66077 .3784 Mtetra
.693 .761 .904 r
.66077 .3784 .66901 .3888 .68602 .38196 .67784 .37116 Mtetra
.701 .757 .895 r
.67784 .37116 .68602 .38196 .70306 .37406 .69497 .36347 Mtetra
.635 .738 .922 r
.69497 .36347 .70306 .37406 .72034 .36871 .71235 .35865 Mtetra
.47 .674 .953 r
.71235 .35865 .72034 .36871 .73805 .36822 .73018 .35886 Mtetra
.39 .649 .961 r
.73018 .35886 .73805 .36822 .75611 .37025 .7483 .36065 Mtetra
.52 .713 .96 r
.7483 .36065 .75611 .37025 .77418 .36975 .76637 .35928 Mtetra
.704 .774 .906 r
.76637 .35928 .77418 .36975 .79184 .36241 .78406 .35128 Mtetra
.75 .777 .875 r
.78406 .35128 .79184 .36241 .80931 .35192 .80161 .3406 Mtetra
.73 .768 .883 r
.80161 .3406 .80931 .35192 .82691 .34209 .81933 .33105 Mtetra
.68 .757 .909 r
.81933 .33105 .82691 .34209 .84485 .33498 .83737 .32406 Mtetra
.633 .745 .929 r
.19484 .52138 .20485 .53014 .21925 .52644 .2093 .51738 Mtetra
.556 .715 .946 r
.2093 .51738 .21925 .52644 .23352 .52521 .22366 .51556 Mtetra
.486 .674 .948 r
.22366 .51556 .23352 .52521 .24781 .52507 .23798 .51547 Mtetra
.568 .708 .936 r
.23798 .51547 .24781 .52507 .26243 .5224 .25257 .51342 Mtetra
.721 .765 .887 r
.25257 .51342 .26243 .5224 .27761 .51338 .26772 .50565 Mtetra
.789 .798 .859 r
.26772 .50565 .27761 .51338 .29305 .50129 .28321 .49392 Mtetra
.79 .807 .866 r
.28321 .49392 .29305 .50129 .30842 .49069 .29872 .48232 Mtetra
.698 .778 .913 r
.29872 .48232 .30842 .49069 .32352 .48495 .31393 .47569 Mtetra
.615 .736 .932 r
.31393 .47569 .32352 .48495 .33854 .482 .32904 .4721 Mtetra
.599 .717 .927 r
.32904 .4721 .33854 .482 .35369 .47862 .34421 .46908 Mtetra
.638 .739 .922 r
.34421 .46908 .35369 .47862 .36899 .47412 .35955 .46469 Mtetra
.648 .746 .921 r
.35955 .46469 .36899 .47412 .3844 .46936 .37501 .45989 Mtetra
.643 .745 .923 r
.37501 .45989 .3844 .46936 .39988 .46499 .39055 .45525 Mtetra
.64 .739 .921 r
.39055 .45525 .39988 .46499 .41547 .46018 .40618 .45071 Mtetra
.657 .752 .919 r
.40618 .45071 .41547 .46018 .43117 .45486 .42194 .44548 Mtetra
.66 .756 .921 r
.42194 .44548 .43117 .45486 .44695 .44962 .43778 .4401 Mtetra
.657 .753 .92 r
.43778 .4401 .44695 .44962 .46282 .44471 .45372 .43481 Mtetra
.654 .745 .917 r
.45372 .43481 .46282 .44471 .47878 .43991 .46974 .42964 Mtetra
.652 .737 .912 r
.46974 .42964 .47878 .43991 .49485 .43482 .48586 .42452 Mtetra
.656 .739 .911 r
.48586 .42452 .49485 .43482 .51101 .42956 .50208 .41919 Mtetra
.66 .741 .909 r
.50208 .41919 .51101 .42956 .52726 .42411 .5184 .41366 Mtetra
.658 .739 .91 r
.5184 .41366 .52726 .42411 .54361 .41837 .53481 .40818 Mtetra
.655 .745 .916 r
.53481 .40818 .54361 .41837 .56006 .41274 .55133 .40281 Mtetra
.651 .751 .923 r
.55133 .40281 .56006 .41274 .5766 .40744 .56794 .39754 Mtetra
.654 .754 .923 r
.56794 .39754 .5766 .40744 .59325 .40222 .58465 .39211 Mtetra
.671 .756 .915 r
.58465 .39211 .59325 .40222 .60999 .39647 .60145 .38597 Mtetra
.667 .748 .911 r
.60145 .38597 .60999 .39647 .62681 .39028 .61835 .37994 Mtetra
.663 .751 .916 r
.61835 .37994 .62681 .39028 .64375 .38447 .63535 .37405 Mtetra
.672 .754 .912 r
.63535 .37405 .64375 .38447 .66077 .3784 .65244 .36775 Mtetra
.702 .761 .898 r
.65244 .36775 .66077 .3784 .67784 .37116 .66956 .36003 Mtetra
.688 .748 .897 r
.66956 .36003 .67784 .37116 .69497 .36347 .68679 .35288 Mtetra
.612 .731 .93 r
.68679 .35288 .69497 .36347 .71235 .35865 .7043 .34886 Mtetra
.424 .659 .958 r
.7043 .34886 .71235 .35865 .73018 .35886 .72225 .34999 Mtetra
.394 .668 .969 r
.72225 .34999 .73018 .35886 .7483 .36065 .74041 .35128 Mtetra
.563 .743 .961 r
.74041 .35128 .7483 .36065 .76637 .35928 .75845 .34849 Mtetra
.717 .774 .897 r
.75845 .34849 .76637 .35928 .78406 .35128 .77618 .33973 Mtetra
.75 .771 .871 r
.77618 .33973 .78406 .35128 .80161 .3406 .7938 .32888 Mtetra
.719 .759 .884 r
.7938 .32888 .80161 .3406 .81933 .33105 .81165 .31982 Mtetra
.674 .753 .91 r
.81165 .31982 .81933 .33105 .83737 .32406 .8298 .31303 Mtetra
.642 .748 .926 r
.18472 .51255 .19484 .52138 .2093 .51738 .19926 .5082 Mtetra
.584 .724 .939 r
.19926 .5082 .2093 .51738 .22366 .51556 .21372 .50562 Mtetra
.491 .671 .944 r
.21372 .50562 .22366 .51556 .23798 .51547 .22807 .50543 Mtetra
.543 .691 .936 r
.22807 .50543 .23798 .51547 .25257 .51342 .24264 .50404 Mtetra
.683 .751 .903 r
.24264 .50404 .25257 .51342 .26772 .50565 .2577 .49799 Mtetra
.78 .801 .87 r
.2577 .49799 .26772 .50565 .28321 .49392 .27322 .487 Mtetra
.799 .818 .867 r
.27322 .487 .28321 .49392 .29872 .48232 .28883 .47493 Mtetra
.736 .808 .909 r
.28883 .47493 .29872 .48232 .31393 .47569 .30422 .46661 Mtetra
.644 .751 .927 r
.30422 .46661 .31393 .47569 .32904 .4721 .31944 .462 Mtetra
.593 .713 .927 r
.31944 .462 .32904 .4721 .34421 .46908 .33464 .45912 Mtetra
.628 .729 .92 r
.33464 .45912 .34421 .46908 .35955 .46469 .35001 .45505 Mtetra
.646 .743 .92 r
.35001 .45505 .35955 .46469 .37501 .45989 .36552 .4503 Mtetra
.65 .746 .92 r
.36552 .4503 .37501 .45989 .39055 .45525 .38113 .44537 Mtetra
.641 .739 .92 r
.38113 .44537 .39055 .45525 .40618 .45071 .39682 .44075 Mtetra
.645 .739 .918 r
.39682 .44075 .40618 .45071 .42194 .44548 .41261 .43593 Mtetra
.658 .754 .921 r
.41261 .43593 .42194 .44548 .43778 .4401 .42851 .43059 Mtetra
.659 .756 .922 r
.42851 .43059 .43778 .4401 .45372 .43481 .44451 .42516 Mtetra
.658 .754 .921 r
.44451 .42516 .45372 .43481 .46974 .42964 .4606 .41977 Mtetra
.656 .75 .919 r
.4606 .41977 .46974 .42964 .48586 .42452 .47678 .4144 Mtetra
.656 .746 .916 r
.47678 .4144 .48586 .42452 .50208 .41919 .49306 .40901 Mtetra
.655 .745 .916 r
.49306 .40901 .50208 .41919 .5184 .41366 .50944 .40362 Mtetra
.654 .749 .92 r
.50944 .40362 .5184 .41366 .53481 .40818 .52592 .39823 Mtetra
.652 .752 .923 r
.52592 .39823 .53481 .40818 .55133 .40281 .5425 .39289 Mtetra
.654 .754 .924 r
.5425 .39289 .55133 .40281 .56794 .39754 .55918 .38746 Mtetra
.666 .757 .918 r
.55918 .38746 .56794 .39754 .58465 .39211 .57595 .38149 Mtetra
.67 .748 .909 r
.57595 .38149 .58465 .39211 .60145 .38597 .59281 .37532 Mtetra
.662 .745 .912 r
.59281 .37532 .60145 .38597 .61835 .37994 .60979 .36946 Mtetra
.666 .752 .915 r
.60979 .36946 .61835 .37994 .63535 .37405 .62686 .36341 Mtetra
.681 .755 .907 r
.62686 .36341 .63535 .37405 .65244 .36775 .644 .35666 Mtetra
.705 .755 .891 r
.644 .35666 .65244 .36775 .66956 .36003 .66119 .34866 Mtetra
.666 .737 .903 r
.66119 .34866 .66956 .36003 .68679 .35288 .67854 .34245 Mtetra
.561 .714 .944 r
.67854 .34245 .68679 .35288 .7043 .34886 .69621 .34005 Mtetra
.378 .662 .969 r
.69621 .34005 .7043 .34886 .72225 .34999 .71426 .34155 Mtetra
.418 .695 .978 r
.71426 .34155 .72225 .34999 .74041 .35128 .73243 .34197 Mtetra
.619 .772 .953 r
.73243 .34197 .74041 .35128 .75845 .34849 .75043 .33726 Mtetra
.73 .772 .887 r
.75043 .33726 .75845 .34849 .77618 .33973 .76818 .32769 Mtetra
.747 .764 .866 r
.76818 .32769 .77618 .33973 .7938 .32888 .78589 .31682 Mtetra
.704 .749 .887 r
.78589 .31682 .7938 .32888 .81165 .31982 .80389 .30844 Mtetra
.667 .75 .912 r
.80389 .30844 .81165 .31982 .8298 .31303 .82215 .30189 Mtetra
.651 .751 .923 r
.17449 .50366 .18472 .51255 .19926 .5082 .18911 .49897 Mtetra
.608 .732 .933 r
.18911 .49897 .19926 .5082 .21372 .50562 .20368 .49564 Mtetra
.511 .681 .943 r
.20368 .49564 .21372 .50562 .22807 .50543 .2181 .49495 Mtetra
.522 .675 .934 r
.2181 .49495 .22807 .50543 .24264 .50404 .23265 .49413 Mtetra
.629 .727 .918 r
.23265 .49413 .24264 .50404 .2577 .49799 .24758 .49012 Mtetra
.761 .798 .883 r
.24758 .49012 .2577 .49799 .27322 .487 .26308 .48027 Mtetra
.799 .824 .872 r
.26308 .48027 .27322 .487 .28883 .47493 .27877 .46828 Mtetra
.774 .829 .895 r
.27877 .46828 .28883 .47493 .30422 .46661 .29437 .458 Mtetra
.679 .773 .922 r
.29437 .458 .30422 .46661 .31944 .462 .30973 .45201 Mtetra
.611 .724 .925 r
.30973 .45201 .31944 .462 .33464 .45912 .32501 .44847 Mtetra
.607 .709 .917 r
.32501 .44847 .33464 .45912 .35001 .45505 .34039 .4451 Mtetra
.64 .737 .919 r
.34039 .4451 .35001 .45505 .36552 .4503 .35594 .44053 Mtetra
.649 .744 .919 r
.35594 .44053 .36552 .4503 .38113 .44537 .3716 .43558 Mtetra
.65 .746 .919 r
.3716 .43558 .38113 .44537 .39682 .44075 .38735 .43055 Mtetra
.642 .735 .916 r
.38735 .43055 .39682 .44075 .41261 .43593 .40319 .42579 Mtetra
.646 .739 .917 r
.40319 .42579 .41261 .43593 .42851 .43059 .41914 .42086 Mtetra
.656 .753 .921 r
.41914 .42086 .42851 .43059 .44451 .42516 .43519 .41552 Mtetra
.657 .756 .923 r
.43519 .41552 .44451 .42516 .4606 .41977 .45135 .41007 Mtetra
.45135 .41007 .4606 .41977 .47678 .4144 .4676 .40462 Mtetra
.656 .755 .923 r
.4676 .40462 .47678 .4144 .49306 .40901 .48394 .39917 Mtetra
.655 .755 .924 r
.48394 .39917 .49306 .40901 .50944 .40362 .50038 .39374 Mtetra
.654 .755 .924 r
.50038 .39374 .50944 .40362 .52592 .39823 .51692 .38829 Mtetra
.656 .756 .923 r
.51692 .38829 .52592 .39823 .5425 .39289 .53357 .38274 Mtetra
.666 .756 .918 r
.53357 .38274 .5425 .39289 .55918 .38746 .55031 .37677 Mtetra
.669 .747 .909 r
.55031 .37677 .55918 .38746 .57595 .38149 .56715 .37063 Mtetra
.661 .742 .91 r
.56715 .37063 .57595 .38149 .59281 .37532 .58409 .36475 Mtetra
.663 .75 .915 r
.58409 .36475 .59281 .37532 .60979 .36946 .60113 .35878 Mtetra
.671 .752 .911 r
.60113 .35878 .60979 .36946 .62686 .36341 .61826 .35244 Mtetra
.697 .756 .898 r
.61826 .35244 .62686 .36341 .644 .35666 .63545 .34484 Mtetra
.691 .739 .888 r
.63545 .34484 .644 .35666 .66119 .34866 .65273 .33741 Mtetra
.634 .729 .917 r
.65273 .33741 .66119 .34866 .67854 .34245 .67022 .33248 Mtetra
.485 .692 .959 r
.67022 .33248 .67854 .34245 .69621 .34005 .68806 .332 Mtetra
.36 .675 .977 r
.68806 .332 .69621 .34005 .71426 .34155 .70617 .3333 Mtetra
.466 .729 .983 r
.70617 .3333 .71426 .34155 .73243 .34197 .72435 .33241 Mtetra
.678 .791 .935 r
.72435 .33241 .73243 .34197 .75043 .33726 .74228 .32545 Mtetra
.738 .766 .875 r
.74228 .32545 .75043 .33726 .76818 .32769 .76006 .31516 Mtetra
.737 .754 .866 r
.76006 .31516 .76818 .32769 .78589 .31682 .7779 .3047 Mtetra
.69 .745 .893 r
.7779 .3047 .78589 .31682 .80389 .30844 .79604 .29697 Mtetra
.66 .747 .915 r
.79604 .29697 .80389 .30844 .82215 .30189 .81441 .29065 Mtetra
.658 .753 .921 r
.16415 .49472 .17449 .50366 .18911 .49897 .17884 .48973 Mtetra
.626 .74 .929 r
.17884 .48973 .18911 .49897 .20368 .49564 .19351 .4858 Mtetra
.55 .701 .94 r
.19351 .4858 .20368 .49564 .2181 .49495 .20805 .48409 Mtetra
.51 .664 .931 r
.20805 .48409 .2181 .49495 .23265 .49413 .2226 .48357 Mtetra
.581 .699 .923 r
.2226 .48357 .23265 .49413 .24758 .49012 .23744 .4811 Mtetra
.715 .771 .896 r
.23744 .4811 .24758 .49012 .26308 .48027 .25281 .4735 Mtetra
.787 .826 .882 r
.25281 .4735 .26308 .48027 .27877 .46828 .26853 .46226 Mtetra
.797 .844 .886 r
.26853 .46226 .27877 .46828 .29437 .458 .28431 .45062 Mtetra
.726 .812 .918 r
.28431 .45062 .29437 .458 .30973 .45201 .29986 .44263 Mtetra
.649 .752 .925 r
.29986 .44263 .30973 .45201 .32501 .44847 .31528 .43772 Mtetra
.604 .708 .917 r
.31528 .43772 .32501 .44847 .34039 .4451 .3307 .4344 Mtetra
.622 .717 .914 r
.3307 .4344 .34039 .4451 .35594 .44053 .34626 .43043 Mtetra
.644 .738 .918 r
.34626 .43043 .35594 .44053 .3716 .43558 .36196 .42562 Mtetra
.65 .744 .918 r
.36196 .42562 .3716 .43558 .38735 .43055 .37778 .42054 Mtetra
.651 .745 .918 r
.37778 .42054 .38735 .43055 .40319 .42579 .39369 .41537 Mtetra
.647 .736 .914 r
.39369 .41537 .40319 .42579 .41914 .42086 .40969 .41035 Mtetra
.648 .735 .913 r
.40969 .41035 .41914 .42086 .43519 .41552 .42579 .40527 Mtetra
.651 .743 .917 r
.42579 .40527 .43519 .41552 .45135 .41007 .442 .40003 Mtetra
.654 .75 .92 r
.442 .40003 .45135 .41007 .4676 .40462 .45831 .39464 Mtetra
.656 .754 .922 r
.45831 .39464 .4676 .40462 .48394 .39917 .47471 .38914 Mtetra
.658 .754 .921 r
.47471 .38914 .48394 .39917 .50038 .39374 .49122 .38351 Mtetra
.661 .752 .918 r
.49122 .38351 .50038 .39374 .51692 .38829 .50783 .37774 Mtetra
.664 .748 .913 r
.50783 .37774 .51692 .38829 .53357 .38274 .52454 .3718 Mtetra
.665 .741 .907 r
.52454 .3718 .53357 .38274 .55031 .37677 .54134 .3658 Mtetra
.66 .74 .909 r
.54134 .3658 .55031 .37677 .56715 .37063 .55825 .35994 Mtetra
.662 .748 .914 r
.55825 .35994 .56715 .37063 .58409 .36475 .57526 .354 Mtetra
.667 .75 .912 r
.57526 .354 .58409 .36475 .60113 .35878 .59236 .34777 Mtetra
.686 .753 .902 r
.59236 .34777 .60113 .35878 .61826 .35244 .60955 .34067 Mtetra
.697 .743 .887 r
.60955 .34067 .61826 .35244 .63545 .34484 .6268 .3329 Mtetra
.662 .728 .898 r
.6268 .3329 .63545 .34484 .65273 .33741 .64421 .32675 Mtetra
.576 .721 .941 r
.64421 .32675 .65273 .33741 .67022 .33248 .66186 .32376 Mtetra
.399 .682 .975 r
.66186 .32376 .67022 .33248 .68806 .332 .67984 .32456 Mtetra
.38 .706 .985 r
.67984 .32456 .68806 .332 .70617 .3333 .69799 .32497 Mtetra
.561 .776 .979 r
.69799 .32497 .70617 .3333 .72435 .33241 .7161 .32162 Mtetra
.713 .779 .904 r
.7161 .32162 .72435 .33241 .74228 .32545 .734 .31294 Mtetra
.741 .757 .865 r
.734 .31294 .74228 .32545 .76006 .31516 .75183 .3022 Mtetra
.719 .742 .87 r
.75183 .3022 .76006 .31516 .7779 .3047 .76983 .29267 Mtetra
.679 .745 .901 r
.76983 .29267 .7779 .3047 .79604 .29697 .7881 .28545 Mtetra
.654 .747 .918 r
.7881 .28545 .79604 .29697 .81441 .29065 .80658 .27933 Mtetra
.66 .754 .919 r
.15371 .48565 .16415 .49472 .17884 .48973 .16846 .48052 Mtetra
.642 .747 .925 r
.16846 .48052 .17884 .48973 .19351 .4858 .18322 .476 Mtetra
.594 .721 .932 r
.18322 .476 .19351 .4858 .20805 .48409 .19792 .47301 Mtetra
.515 .663 .928 r
.19792 .47301 .20805 .48409 .2226 .48357 .21251 .47235 Mtetra
.545 .674 .922 r
.21251 .47235 .2226 .48357 .23744 .4811 .22728 .47092 Mtetra
.645 .732 .912 r
.22728 .47092 .23744 .4811 .25281 .4735 .24246 .4662 Mtetra
.762 .817 .896 r
.24246 .4662 .25281 .4735 .26853 .46226 .25814 .4564 Mtetra
.797 .849 .89 r
.25814 .4564 .26853 .46226 .28431 .45062 .274 .44479 Mtetra
.78 .853 .906 r
.274 .44479 .28431 .45062 .29986 .44263 .28982 .43424 Mtetra
.692 .787 .923 r
.28982 .43424 .29986 .44263 .31528 .43772 .30541 .4276 Mtetra
.635 .735 .92 r
.30541 .4276 .31528 .43772 .3307 .4344 .32094 .42311 Mtetra
.608 .702 .91 r
.32094 .42311 .3307 .4344 .34626 .43043 .33652 .41961 Mtetra
.629 .72 .913 r
.33652 .41961 .34626 .43043 .36196 .42562 .35224 .41532 Mtetra
.645 .738 .916 r
.35224 .41532 .36196 .42562 .37778 .42054 .3681 .41037 Mtetra
.651 .743 .918 r
.3681 .41037 .37778 .42054 .39369 .41537 .38407 .40517 Mtetra
.653 .745 .917 r
.38407 .40517 .39369 .41537 .40969 .41035 .40013 .39987 Mtetra
.653 .74 .913 r
.40013 .39987 .40969 .41035 .42579 .40527 .4163 .39451 Mtetra
.652 .735 .91 r
.4163 .39451 .42579 .40527 .442 .40003 .43256 .38916 Mtetra
.653 .735 .909 r
.43256 .38916 .442 .40003 .45831 .39464 .44893 .38373 Mtetra
.656 .736 .909 r
.44893 .38373 .45831 .39464 .47471 .38914 .4654 .37816 Mtetra
.658 .737 .908 r
.4654 .37816 .47471 .38914 .49122 .38351 .48197 .37246 Mtetra
.659 .737 .907 r
.48197 .37246 .49122 .38351 .50783 .37774 .49864 .36667 Mtetra
.659 .737 .908 r
.49864 .36667 .50783 .37774 .52454 .3718 .51541 .36088 Mtetra
.659 .742 .911 r
.51541 .36088 .52454 .3718 .54134 .3658 .53228 .35504 Mtetra
.661 .748 .914 r
.53228 .35504 .54134 .3658 .55825 .35994 .54926 .34909 Mtetra
.666 .749 .912 r
.54926 .34909 .55825 .35994 .57526 .354 .56633 .34288 Mtetra
.68 .75 .904 r
.56633 .34288 .57526 .354 .59236 .34777 .58349 .336 Mtetra
.695 .743 .888 r
.58349 .336 .59236 .34777 .60955 .34067 .60073 .3283 Mtetra
.673 .725 .889 r
.60073 .3283 .60955 .34067 .6268 .3329 .61809 .32159 Mtetra
.621 .727 .923 r
.61809 .32159 .6268 .3329 .64421 .32675 .63563 .3171 Mtetra
.472 .698 .967 r
.63563 .3171 .64421 .32675 .66186 .32376 .65346 .31662 Mtetra
.353 .701 .984 r
.65346 .31662 .66186 .32376 .67984 .32456 .67151 .31727 Mtetra
.449 .751 .993 r
.67151 .31727 .67984 .32456 .69799 .32497 .68966 .31607 Mtetra
.661 .805 .952 r
.68966 .31607 .69799 .32497 .7161 .32162 .70768 .30961 Mtetra
.73 .763 .879 r
.70768 .30961 .7161 .32162 .734 .31294 .72559 .29972 Mtetra
.737 .745 .858 r
.72559 .29972 .734 .31294 .75183 .3022 .74351 .28899 Mtetra
.696 .731 .877 r
.74351 .28899 .75183 .3022 .76983 .29267 .76169 .28068 Mtetra
.667 .744 .907 r
.76169 .28068 .76983 .29267 .7881 .28545 .78008 .27394 Mtetra
.652 .749 .921 r
.78008 .27394 .7881 .28545 .80658 .27933 .79865 .26784 Mtetra
.656 .75 .919 r
.14317 .47636 .15371 .48565 .16846 .48052 .15795 .47132 Mtetra
.654 .752 .922 r
.15795 .47132 .16846 .48052 .18322 .476 .17281 .46631 Mtetra
.622 .734 .927 r
.17281 .46631 .18322 .476 .19792 .47301 .18764 .46241 Mtetra
.552 .691 .932 r
.18764 .46241 .19792 .47301 .21251 .47235 .20235 .46064 Mtetra
.527 .658 .919 r
.20235 .46064 .21251 .47235 .22728 .47092 .2171 .45973 Mtetra
.584 .693 .917 r
.2171 .45973 .22728 .47092 .24246 .4662 .23213 .45707 Mtetra
.699 .771 .907 r
.23213 .45707 .24246 .4662 .25814 .4564 .24764 .45009 Mtetra
.776 .842 .902 r
.24764 .45009 .25814 .4564 .274 .44479 .2635 .43961 Mtetra
.795 .869 .903 r
.2635 .43961 .274 .44479 .28982 .43424 .27947 .42821 Mtetra
.757 .852 .921 r
.27947 .42821 .28982 .43424 .30541 .4276 .29533 .41874 Mtetra
.68 .777 .924 r
.29533 .41874 .30541 .4276 .32094 .42311 .31104 .41247 Mtetra
.635 .727 .914 r
.31104 .41247 .32094 .42311 .33652 .41961 .32672 .40791 Mtetra
.615 .7 .905 r
.32672 .40791 .33652 .41961 .35224 .41532 .34246 .40408 Mtetra
.628 .715 .909 r
.34246 .40408 .35224 .41532 .3681 .41037 .35833 .39974 Mtetra
.645 .734 .914 r
.35833 .39974 .3681 .41037 .38407 .40517 .37434 .39472 Mtetra
.65 .741 .916 r
.37434 .39472 .38407 .40517 .40013 .39987 .39047 .38945 Mtetra
.653 .744 .916 r
.39047 .38945 .40013 .39987 .4163 .39451 .40669 .38405 Mtetra
.654 .745 .916 r
.40669 .38405 .4163 .39451 .43256 .38916 .42302 .37855 Mtetra
.655 .743 .915 r
.42302 .37855 .43256 .38916 .44893 .38373 .43945 .37299 Mtetra
.656 .742 .913 r
.43945 .37299 .44893 .38373 .4654 .37816 .45598 .36736 Mtetra
.657 .742 .913 r
.45598 .36736 .4654 .37816 .48197 .37246 .47261 .36166 Mtetra
.658 .744 .914 r
.47261 .36166 .48197 .37246 .49864 .36667 .48934 .35589 Mtetra
.659 .746 .914 r
.48934 .35589 .49864 .36667 .51541 .36088 .50618 .35002 Mtetra
.662 .747 .913 r
.50618 .35002 .51541 .36088 .53228 .35504 .52312 .34402 Mtetra
.667 .746 .91 r
.52312 .34402 .53228 .35504 .54926 .34909 .54016 .33776 Mtetra
.681 .747 .901 r
.54016 .33776 .54926 .34909 .56633 .34288 .55729 .3308 Mtetra
.689 .736 .887 r
.55729 .3308 .56633 .34288 .58349 .336 .57451 .32332 Mtetra
.672 .72 .885 r
.57451 .32332 .58349 .336 .60073 .3283 .59184 .31657 Mtetra
.633 .725 .914 r
.59184 .31657 .60073 .3283 .61809 .32159 .60932 .31157 Mtetra
.523 .715 .96 r
.60932 .31157 .61809 .32159 .63563 .3171 .62702 .30984 Mtetra
.371 .71 .986 r
.62702 .30984 .63563 .3171 .65346 .31662 .64496 .31013 Mtetra
.394 .744 .992 r
.64496 .31013 .65346 .31662 .67151 .31727 .66305 .30949 Mtetra
.582 .803 .984 r
.66305 .30949 .67151 .31727 .68966 .31607 .68114 .30525 Mtetra
.712 .782 .906 r
.68114 .30525 .68966 .31607 .70768 .30961 .69912 .29653 Mtetra
.735 .748 .862 r
.69912 .29653 .70768 .30961 .72559 .29972 .71707 .28596 Mtetra
.717 .731 .862 r
.71707 .28596 .72559 .29972 .74351 .28899 .73515 .27625 Mtetra
.681 .736 .892 r
.73515 .27625 .74351 .28899 .76169 .28068 .75346 .26876 Mtetra
.657 .744 .914 r
.75346 .26876 .76169 .28068 .78008 .27394 .77198 .2624 Mtetra
.655 .753 .921 r
.77198 .2624 .78008 .27394 .79865 .26784 .79062 .25607 Mtetra
.65 .748 .921 r
.13252 .46694 .14317 .47636 .15795 .47132 .14732 .46207 Mtetra
.661 .755 .92 r
.14732 .46207 .15795 .47132 .17281 .46631 .16225 .45678 Mtetra
.642 .745 .924 r
.16225 .45678 .17281 .46631 .18764 .46241 .1772 .45213 Mtetra
.603 .719 .926 r
.1772 .45213 .18764 .46241 .20235 .46064 .19211 .44878 Mtetra
.533 .66 .917 r
.19211 .44878 .20235 .46064 .2171 .45973 .2069 .44767 Mtetra
.549 .663 .912 r
.2069 .44767 .2171 .45973 .23213 .45707 .22185 .44612 Mtetra
.615 .712 .915 r
.22185 .44612 .23213 .45707 .24764 .45009 .23712 .44236 Mtetra
.73 .81 .914 r
.23712 .44236 .24764 .45009 .2635 .43961 .25288 .43404 Mtetra
.779 .863 .912 r
.25288 .43404 .2635 .43961 .27947 .42821 .26887 .42345 Mtetra
.787 .883 .916 r
.26887 .42345 .27947 .42821 .29533 .41874 .28494 .41249 Mtetra
.746 .85 .928 r
.28494 .41249 .29533 .41874 .31104 .41247 .3009 .40346 Mtetra
.68 .778 .924 r
.3009 .40346 .31104 .41247 .32672 .40791 .31676 .3971 Mtetra
.645 .73 .911 r
.31676 .3971 .32672 .40791 .34246 .40408 .33261 .39209 Mtetra
.625 .701 .9 r
.33261 .39209 .34246 .40408 .35833 .39974 .34853 .3878 Mtetra
.625 .703 .902 r
.34853 .3878 .35833 .39974 .37434 .39472 .36455 .38348 Mtetra
.64 .724 .909 r
.36455 .38348 .37434 .39472 .39047 .38945 .38071 .37854 Mtetra
.649 .735 .912 r
.38071 .37854 .39047 .38945 .40669 .38405 .39699 .37324 Mtetra
.652 .739 .913 r
.39699 .37324 .40669 .38405 .42302 .37855 .41337 .36776 Mtetra
.654 .742 .914 r
.41337 .36776 .42302 .37855 .43945 .37299 .42986 .36217 Mtetra
.656 .743 .914 r
.42986 .36217 .43945 .37299 .45598 .36736 .44645 .35647 Mtetra
.658 .743 .913 r
.44645 .35647 .45598 .36736 .47261 .36166 .46314 .35067 Mtetra
.66 .743 .912 r
.46314 .35067 .47261 .36166 .48934 .35589 .47994 .34475 Mtetra
.663 .743 .909 r
.47994 .34475 .48934 .35589 .50618 .35002 .49685 .33866 Mtetra
.67 .742 .904 r
.49685 .33866 .50618 .35002 .52312 .34402 .51385 .33219 Mtetra
.682 .739 .893 r
.51385 .33219 .52312 .34402 .54016 .33776 .53096 .3251 Mtetra
.68 .723 .882 r
.53096 .3251 .54016 .33776 .55729 .3308 .54815 .31795 Mtetra
.664 .715 .886 r
.54815 .31795 .55729 .3308 .57451 .32332 .56545 .31154 Mtetra
.633 .725 .914 r
.56545 .31154 .57451 .32332 .59184 .31657 .58288 .30649 Mtetra
.542 .725 .959 r
.58288 .30649 .59184 .31657 .60932 .31157 .6005 .30419 Mtetra
.403 .726 .99 r
.6005 .30419 .60932 .31157 .62702 .30984 .61834 .30388 Mtetra
.373 .747 .99 r
.61834 .30388 .62702 .30984 .64496 .31013 .63634 .30321 Mtetra
.515 .797 .997 r
.63634 .30321 .64496 .31013 .66305 .30949 .65442 .30022 Mtetra
.691 .81 .938 r
.65442 .30022 .66305 .30949 .68114 .30525 .67243 .29252 Mtetra
.727 .752 .872 r
.67243 .29252 .68114 .30525 .69912 .29653 .69042 .2825 Mtetra
.728 .732 .854 r
.69042 .2825 .69912 .29653 .71707 .28596 .70846 .27201 Mtetra
.69 .719 .872 r
.70846 .27201 .71707 .28596 .73515 .27625 .72671 .26382 Mtetra
.667 .739 .904 r
.72671 .26382 .73515 .27625 .75346 .26876 .74517 .25697 Mtetra
.651 .747 .92 r
.74517 .25697 .75346 .26876 .77198 .2624 .76378 .25078 Mtetra
.661 .756 .921 r
.76378 .25078 .77198 .2624 .79062 .25607 .78249 .24414 Mtetra
.65 .748 .921 r
.12175 .45743 .13252 .46694 .14732 .46207 .1366 .45251 Mtetra
.656 .749 .919 r
.1366 .45251 .14732 .46207 .16225 .45678 .15156 .44734 Mtetra
.656 .753 .921 r
.15156 .44734 .16225 .45678 .1772 .45213 .16662 .44213 Mtetra
.63 .735 .923 r
.16662 .44213 .1772 .45213 .19211 .44878 .18166 .43782 Mtetra
.58 .699 .924 r
.18166 .43782 .19211 .44878 .2069 .44767 .19663 .43515 Mtetra
.539 .653 .909 r
.19663 .43515 .2069 .44767 .22185 .44612 .21158 .43387 Mtetra
.568 .671 .908 r
.21158 .43387 .22185 .44612 .23712 .44236 .22674 .43167 Mtetra
.634 .727 .915 r
.22674 .43167 .23712 .44236 .25288 .43404 .24222 .42713 Mtetra
.738 .833 .923 r
.24222 .42713 .25288 .43404 .26887 .42345 .25814 .41842 Mtetra
.772 .879 .924 r
.25814 .41842 .26887 .42345 .28494 .41249 .27425 .40813 Mtetra
.777 .896 .928 r
.27425 .40813 .28494 .41249 .3009 .40346 .29042 .3976 Mtetra
.748 .863 .933 r
.29042 .3976 .3009 .40346 .31676 .3971 .30654 .3884 Mtetra
.688 .79 .928 r
.30654 .3884 .31676 .3971 .33261 .39209 .32257 .38163 Mtetra
.66 .746 .914 r
.32257 .38163 .33261 .39209 .34853 .3878 .33861 .37594 Mtetra
.641 .713 .899 r
.33861 .37594 .34853 .3878 .36455 .38348 .35472 .37093 Mtetra
.635 .699 .892 r
.35472 .37093 .36455 .38348 .38071 .37854 .37091 .36612 Mtetra
.638 .704 .894 r
.37091 .36612 .38071 .37854 .39699 .37324 .38722 .36118 Mtetra
.643 .714 .899 r
.38722 .36118 .39699 .37324 .41337 .36776 .40365 .35597 Mtetra
.65 .722 .902 r
.40365 .35597 .41337 .36776 .42986 .36217 .42019 .35049 Mtetra
.655 .728 .902 r
.42019 .35049 .42986 .36217 .44645 .35647 .43684 .34473 Mtetra
.661 .73 .9 r
.43684 .34473 .44645 .35647 .46314 .35067 .4536 .33869 Mtetra
.666 .728 .896 r
.4536 .33869 .46314 .35067 .47994 .34475 .47046 .33236 Mtetra
.67 .723 .889 r
.47046 .33236 .47994 .34475 .49685 .33866 .48743 .32577 Mtetra
.672 .716 .882 r
.48743 .32577 .49685 .33866 .51385 .33219 .50449 .31903 Mtetra
.666 .711 .881 r
.50449 .31903 .51385 .33219 .53096 .3251 .52166 .31249 Mtetra
.652 .716 .895 r
.52166 .31249 .53096 .3251 .54815 .31795 .53893 .30665 Mtetra
.624 .733 .925 r
.53893 .30665 .54815 .31795 .56545 .31154 .55632 .30188 Mtetra
.534 .733 .966 r
.55632 .30188 .56545 .31154 .58288 .30649 .57387 .29961 Mtetra
.414 .747 .994 r
.57387 .29961 .58288 .30649 .6005 .30419 .59161 .29873 Mtetra
.376 .762 .989 r
.59161 .29873 .6005 .30419 .61834 .30388 .60951 .29761 Mtetra
.485 .8 1 r
.60951 .29761 .61834 .30388 .63634 .30321 .62754 .29489 Mtetra
.671 .826 .958 r
.62754 .29489 .63634 .30321 .65442 .30022 .64555 .28787 Mtetra
.719 .757 .883 r
.64555 .28787 .65442 .30022 .67243 .29252 .66357 .27842 Mtetra
.726 .731 .854 r
.66357 .27842 .67243 .29252 .69042 .2825 .68162 .26799 Mtetra
.701 .716 .86 r
.68162 .26799 .69042 .2825 .70846 .27201 .69982 .25897 Mtetra
.675 .732 .893 r
.69982 .25897 .70846 .27201 .72671 .26382 .71821 .25164 Mtetra
.655 .742 .914 r
.71821 .25164 .72671 .26382 .74517 .25697 .73678 .24524 Mtetra
.656 .753 .921 r
.73678 .24524 .74517 .25697 .76378 .25078 .75547 .23879 Mtetra
.661 .751 .917 r
.75547 .23879 .76378 .25078 .78249 .24414 .77427 .23207 Mtetra
.653 .75 .921 r
.11086 .4479 .12175 .45743 .1366 .45251 .12577 .44281 Mtetra
.65 .747 .921 r
.12577 .44281 .1366 .45251 .15156 .44734 .14076 .4378 Mtetra
.66 .754 .92 r
.14076 .4378 .15156 .44734 .16662 .44213 .15588 .43241 Mtetra
.65 .749 .922 r
.15588 .43241 .16662 .44213 .18166 .43782 .17104 .42733 Mtetra
.622 .726 .921 r
.17104 .42733 .18166 .43782 .19663 .43515 .1862 .42322 Mtetra
.571 .679 .913 r
.1862 .42322 .19663 .43515 .21158 .43387 .20128 .42085 Mtetra
.55 .651 .901 r
.20128 .42085 .21158 .43387 .22674 .43167 .21641 .41923 Mtetra
.581 .676 .905 r
.21641 .41923 .22674 .43167 .24222 .42713 .23175 .41656 Mtetra
.638 .734 .918 r
.23175 .41656 .24222 .42713 .25814 .41842 .2474 .41176 Mtetra
.729 .842 .934 r
.2474 .41176 .25814 .41842 .27425 .40813 .26344 .40335 Mtetra
.757 .888 .937 r
.26344 .40335 .27425 .40813 .29042 .3976 .27964 .39365 Mtetra
.763 .909 .94 r
.27964 .39365 .29042 .3976 .30654 .3884 .29592 .38358 Mtetra
.747 .89 .944 r
.29592 .38358 .30654 .3884 .32257 .38163 .3122 .37422 Mtetra
.71 .828 .938 r
.3122 .37422 .32257 .38163 .33861 .37594 .32844 .36649 Mtetra
.676 .776 .925 r
.32844 .36649 .33861 .37594 .35472 .37093 .34468 .36007 Mtetra
.661 .743 .911 r
.34468 .36007 .35472 .37093 .37091 .36612 .36099 .3542 Mtetra
.653 .721 .898 r
.36099 .3542 .37091 .36612 .38722 .36118 .37738 .34857 Mtetra
.649 .708 .89 r
.37738 .34857 .38722 .36118 .40365 .35597 .39386 .34303 Mtetra
.65 .703 .886 r
.39386 .34303 .40365 .35597 .42019 .35049 .41046 .33738 Mtetra
.653 .703 .883 r
.41046 .33738 .42019 .35049 .43684 .34473 .42716 .33155 Mtetra
.657 .704 .882 r
.42716 .33155 .43684 .34473 .4536 .33869 .44397 .32553 Mtetra
.658 .706 .883 r
.44397 .32553 .4536 .33869 .47046 .33236 .46089 .31941 Mtetra
.656 .71 .888 r
.46089 .31941 .47046 .33236 .48743 .32577 .4779 .31336 Mtetra
.651 .72 .899 r
.4779 .31336 .48743 .32577 .50449 .31903 .49502 .30757 Mtetra
.637 .734 .919 r
.49502 .30757 .50449 .31903 .52166 .31249 .51225 .30233 Mtetra
.594 .747 .95 r
.51225 .30233 .52166 .31249 .53893 .30665 .5296 .29842 Mtetra
.509 .759 .986 r
.5296 .29842 .53893 .30665 .55632 .30188 .54709 .29617 Mtetra
.406 .773 .994 r
.54709 .29617 .55632 .30188 .57387 .29961 .56475 .29468 Mtetra
.395 .787 .988 r
.56475 .29468 .57387 .29961 .59161 .29873 .58257 .29282 Mtetra
.495 .815 1 r
.58257 .29282 .59161 .29873 .60951 .29761 .60052 .28965 Mtetra
.664 .833 .965 r
.60052 .28965 .60951 .29761 .62754 .29489 .61851 .28277 Mtetra
.713 .761 .89 r
.61851 .28277 .62754 .29489 .64555 .28787 .63653 .27369 Mtetra
.722 .729 .856 r
.63653 .27369 .64555 .28787 .66357 .27842 .65459 .26349 Mtetra
.706 .713 .854 r
.65459 .26349 .66357 .27842 .68162 .26799 .67276 .25404 Mtetra
.678 .719 .88 r
.67276 .25404 .68162 .26799 .69982 .25897 .69111 .24639 Mtetra
.66 .738 .907 r
.69111 .24639 .69982 .25897 .71821 .25164 .70963 .23972 Mtetra
.652 .749 .92 r
.70963 .23972 .71821 .25164 .73678 .24524 .72829 .23338 Mtetra
.661 .755 .92 r
.72829 .23338 .73678 .24524 .75547 .23879 .74705 .22662 Mtetra
.658 .75 .917 r
.74705 .22662 .75547 .23879 .77427 .23207 .76594 .21993 Mtetra
.656 .752 .92 r
.09985 .4383 .11086 .4479 .12577 .44281 .11482 .43305 Mtetra
.651 .748 .921 r
.11482 .43305 .12577 .44281 .14076 .4378 .12986 .42794 Mtetra
.652 .747 .92 r
.12986 .42794 .14076 .4378 .15588 .43241 .14499 .42276 Mtetra
.66 .755 .921 r
.14499 .42276 .15588 .43241 .17104 .42733 .16025 .41727 Mtetra
.646 .744 .921 r
.16025 .41727 .17104 .42733 .1862 .42322 .17555 .41226 Mtetra
.619 .719 .917 r
.17555 .41226 .1862 .42322 .20128 .42085 .19084 .40818 Mtetra
.572 .669 .904 r
.19084 .40818 .20128 .42085 .21641 .41923 .20606 .40575 Mtetra
.56 .65 .895 r
.20606 .40575 .21641 .41923 .23175 .41656 .22137 .40377 Mtetra
.586 .674 .901 r
.22137 .40377 .23175 .41656 .2474 .41176 .23688 .40085 Mtetra
.63 .728 .918 r
.23688 .40085 .2474 .41176 .26344 .40335 .25265 .39624 Mtetra
.705 .832 .943 r
.25265 .39624 .26344 .40335 .27964 .39365 .26876 .38872 Mtetra
.735 .887 .949 r
.26876 .38872 .27964 .39365 .29592 .38358 .28505 .37981 Mtetra
.739 .914 .953 r
.28505 .37981 .29592 .38358 .3122 .37422 .30143 .37048 Mtetra
.731 .916 .956 r
.30143 .37048 .3122 .37422 .32844 .36649 .31786 .36136 Mtetra
.719 .886 .957 r
.31786 .36136 .32844 .36649 .34468 .36007 .33431 .35293 Mtetra
.703 .838 .948 r
.33431 .35293 .34468 .36007 .36099 .3542 .35079 .34531 Mtetra
.676 .794 .937 r
.35079 .34531 .36099 .3542 .37738 .34857 .36729 .33876 Mtetra
.666 .772 .929 r
.36729 .33876 .37738 .34857 .39386 .34303 .38387 .33255 Mtetra
.66 .757 .922 r
.38387 .33255 .39386 .34303 .41046 .33738 .40054 .32653 Mtetra
.656 .75 .919 r
.40054 .32653 .41046 .33738 .42716 .33155 .41731 .32064 Mtetra
.652 .748 .92 r
.41731 .32064 .42716 .33155 .44397 .32553 .43418 .31485 Mtetra
.646 .753 .927 r
.43418 .31485 .44397 .32553 .46089 .31941 .45115 .30926 Mtetra
.635 .762 .939 r
.45115 .30926 .46089 .31941 .4779 .31336 .46822 .30402 Mtetra
.597 .768 .961 r
.46822 .30402 .4779 .31336 .49502 .30757 .4854 .29986 Mtetra
.546 .789 .988 r
.4854 .29986 .49502 .30757 .51225 .30233 .5027 .29654 Mtetra
.469 .803 .999 r
.5027 .29654 .51225 .30233 .5296 .29842 .52014 .29391 Mtetra
.41 .804 .987 r
.52014 .29391 .5296 .29842 .54709 .29617 .53773 .29152 Mtetra
.437 .815 .991 r
.53773 .29152 .54709 .29617 .56475 .29468 .55547 .28872 Mtetra
.543 .836 .999 r
.55547 .28872 .56475 .29468 .58257 .29282 .57335 .2845 Mtetra
.674 .829 .958 r
.57335 .2845 .58257 .29282 .60052 .28965 .5913 .27729 Mtetra
.709 .756 .889 r
.5913 .27729 .60052 .28965 .61851 .28277 .60931 .26835 Mtetra
.717 .724 .856 r
.60931 .26835 .61851 .28277 .63653 .27369 .62738 .25841 Mtetra
.705 .708 .85 r
.62738 .25841 .63653 .27369 .65459 .26349 .64554 .2489 Mtetra
.679 .709 .871 r
.64554 .2489 .65459 .26349 .67276 .25404 .66386 .24109 Mtetra
.663 .733 .902 r
.66386 .24109 .67276 .25404 .69111 .24639 .68234 .23422 Mtetra
.652 .745 .918 r
.68234 .23422 .69111 .24639 .70963 .23972 .70096 .22785 Mtetra
.659 .756 .921 r
.70096 .22785 .70963 .23972 .72829 .23338 .71969 .22114 Mtetra
.66 .75 .917 r
.71969 .22114 .72829 .23338 .74705 .22662 .73854 .21435 Mtetra
.656 .749 .919 r
.73854 .21435 .74705 .22662 .76594 .21993 .75753 .20769 Mtetra
.658 .754 .92 r
.0887 .42866 .09985 .4383 .11482 .43305 .10374 .42326 Mtetra
.655 .751 .92 r
.10374 .42326 .11482 .43305 .12986 .42794 .11884 .41795 Mtetra
.65 .747 .92 r
.11884 .41795 .12986 .42794 .14499 .42276 .13402 .41278 Mtetra
.654 .749 .919 r
.13402 .41278 .14499 .42276 .16025 .41727 .14931 .40743 Mtetra
.659 .755 .921 r
.14931 .40743 .16025 .41727 .17555 .41226 .16471 .40189 Mtetra
.644 .741 .919 r
.16471 .40189 .17555 .41226 .19084 .40818 .18014 .39685 Mtetra
.621 .715 .913 r
.18014 .39685 .19084 .40818 .20606 .40575 .19558 .39261 Mtetra
.581 .667 .897 r
.19558 .39261 .20606 .40575 .22137 .40377 .21099 .38982 Mtetra
.569 .649 .889 r
.21099 .38982 .22137 .40377 .23688 .40085 .22647 .38748 Mtetra
.587 .668 .895 r
.22647 .38748 .23688 .40085 .25265 .39624 .24214 .38445 Mtetra
.619 .71 .911 r
.24214 .38445 .25265 .39624 .26876 .38872 .25802 .38019 Mtetra
.664 .795 .944 r
.25802 .38019 .26876 .38872 .28505 .37981 .27416 .37415 Mtetra
.706 .871 .959 r
.27416 .37415 .28505 .37981 .30143 .37048 .29053 .36629 Mtetra
.709 .905 .965 r
.29053 .36629 .30143 .37048 .31786 .36136 .307 .35795 Mtetra
.699 .921 .968 r
.307 .35795 .31786 .36136 .33431 .35293 .32355 .3496 Mtetra
.686 .922 .971 r
.32355 .3496 .33431 .35293 .35079 .34531 .34015 .34151 Mtetra
.672 .911 .976 r
.34015 .34151 .35079 .34531 .36729 .33876 .35681 .33392 Mtetra
.664 .889 .979 r
.35681 .33392 .36729 .33876 .38387 .33255 .37352 .3269 Mtetra
.652 .869 .981 r
.37352 .3269 .38387 .33255 .40054 .32653 .3903 .32041 Mtetra
.636 .855 .983 r
.3903 .32041 .40054 .32653 .41731 .32064 .40716 .31445 Mtetra
.615 .848 .988 r
.40716 .31445 .41731 .32064 .43418 .31485 .4241 .30901 Mtetra
.585 .848 .994 r
.4241 .30901 .43418 .31485 .45115 .30926 .44115 .30412 Mtetra
.542 .849 .998 r
.44115 .30412 .45115 .30926 .46822 .30402 .4583 .2998 Mtetra
.485 .845 .992 r
.4583 .2998 .46822 .30402 .4854 .29986 .47557 .296 Mtetra
.454 .839 .985 r
.47557 .296 .4854 .29986 .5027 .29654 .49298 .29247 Mtetra
.458 .838 .988 r
.49298 .29247 .5027 .29654 .52014 .29391 .51052 .28893 Mtetra
.51 .844 .998 r
.51052 .28893 .52014 .29391 .53773 .29152 .52821 .28492 Mtetra
.619 .851 .987 r
.52821 .28492 .53773 .29152 .55547 .28872 .54603 .27906 Mtetra
.689 .803 .936 r
.54603 .27906 .55547 .28872 .57335 .2845 .56395 .27136 Mtetra
.706 .742 .879 r
.56395 .27136 .57335 .2845 .5913 .27729 .58194 .2624 Mtetra
.71 .715 .853 r
.58194 .2624 .5913 .27729 .60931 .26835 .6 .25271 Mtetra
.699 .701 .848 r
.6 .25271 .60931 .26835 .62738 .25841 .61816 .24345 Mtetra
.676 .704 .868 r
.61816 .24345 .62738 .25841 .64554 .2489 .63645 .23567 Mtetra
.664 .73 .898 r
.63645 .23567 .64554 .2489 .66386 .24109 .65489 .2287 Mtetra
.653 .743 .915 r
.65489 .2287 .66386 .24109 .68234 .23422 .67347 .22226 Mtetra
.657 .754 .922 r
.67347 .22226 .68234 .23422 .70096 .22785 .69217 .21559 Mtetra
.661 .751 .917 r
.69217 .21559 .70096 .22785 .71969 .22114 .71098 .20874 Mtetra
.656 .749 .918 r
.71098 .20874 .71969 .22114 .73854 .21435 .72993 .20201 Mtetra
.654 .75 .921 r
.72993 .20201 .73854 .21435 .75753 .20769 .74901 .19536 Mtetra
.66 .754 .92 r
.07743 .41894 .0887 .42866 .10374 .42326 .09252 .41343 Mtetra
.657 .753 .92 r
.09252 .41343 .10374 .42326 .11884 .41795 .10769 .40798 Mtetra
.654 .75 .92 r
.10769 .40798 .11884 .41795 .13402 .41278 .12294 .40261 Mtetra
.651 .747 .92 r
.12294 .40261 .13402 .41278 .14931 .40743 .13826 .39734 Mtetra
.655 .751 .92 r
.13826 .39734 .14931 .40743 .16471 .40189 .15369 .39186 Mtetra
.658 .754 .921 r
.15369 .39186 .16471 .40189 .18014 .39685 .16924 .38624 Mtetra
.646 .74 .918 r
.16924 .38624 .18014 .39685 .19558 .39261 .18482 .38104 Mtetra
.627 .716 .91 r
.18482 .38104 .19558 .39261 .21099 .38982 .20044 .37651 Mtetra
.598 .674 .894 r
.20044 .37651 .21099 .38982 .22647 .38748 .21605 .37307 Mtetra
.579 .648 .883 r
.21605 .37307 .22647 .38748 .24214 .38445 .23171 .37029 Mtetra
.588 .658 .885 r
.23171 .37029 .24214 .38445 .25802 .38019 .24753 .36716 Mtetra
.608 .687 .898 r
.24753 .36716 .25802 .38019 .27416 .37415 .26354 .36322 Mtetra
.632 .737 .924 r
.26354 .36322 .27416 .37415 .29053 .36629 .27974 .35831 Mtetra
.657 .811 .957 r
.27974 .35831 .29053 .36629 .307 .35795 .29612 .35228 Mtetra
.679 .871 .971 r
.29612 .35228 .307 .35795 .32355 .3496 .31268 .34512 Mtetra
.671 .897 .978 r
.31268 .34512 .32355 .3496 .34015 .34151 .32934 .33779 Mtetra
.653 .91 .98 r
.32934 .33779 .34015 .34151 .35681 .33392 .34607 .3306 Mtetra
.629 .912 .981 r
.34607 .3306 .35681 .33392 .37352 .3269 .36288 .32371 Mtetra
.605 .908 .982 r
.36288 .32371 .37352 .3269 .3903 .32041 .37977 .31724 Mtetra
.579 .901 .983 r
.37977 .31724 .3903 .32041 .40716 .31445 .39673 .31122 Mtetra
.554 .892 .984 r
.39673 .31122 .40716 .31445 .4241 .30901 .41379 .30565 Mtetra
.533 .882 .985 r
.41379 .30565 .4241 .30901 .44115 .30412 .43095 .3005 Mtetra
.521 .873 .987 r
.43095 .3005 .44115 .30412 .4583 .2998 .44822 .29566 Mtetra
.526 .866 .992 r
.44822 .29566 .4583 .2998 .47557 .296 .46561 .29096 Mtetra
.554 .86 .997 r
.46561 .29096 .47557 .296 .49298 .29247 .48313 .2861 Mtetra
.623 .857 .987 r
.48313 .2861 .49298 .29247 .51052 .28893 .50079 .28009 Mtetra
.674 .817 .951 r
.50079 .28009 .51052 .28893 .52821 .28492 .51857 .27293 Mtetra
.695 .758 .901 r
.51857 .27293 .52821 .28492 .54603 .27906 .53645 .26479 Mtetra
.701 .722 .865 r
.53645 .26479 .54603 .27906 .56395 .27136 .55441 .25579 Mtetra
.702 .703 .848 r
.55441 .25579 .56395 .27136 .58194 .2624 .57246 .24641 Mtetra
.689 .693 .849 r
.57246 .24641 .58194 .2624 .6 .25271 .59061 .2377 Mtetra
.673 .703 .869 r
.59061 .2377 .6 .25271 .61816 .24345 .60889 .23009 Mtetra
.663 .728 .898 r
.60889 .23009 .61816 .24345 .63645 .23567 .62729 .22315 Mtetra
.653 .742 .915 r
.62729 .22315 .63645 .23567 .65489 .2287 .64583 .21665 Mtetra
.656 .754 .922 r
.64583 .21665 .65489 .2287 .67347 .22226 .66449 .21 Mtetra
.66 .753 .918 r
.66449 .21 .67347 .22226 .69217 .21559 .68326 .20311 Mtetra
.657 .748 .917 r
.68326 .20311 .69217 .21559 .71098 .20874 .70217 .19631 Mtetra
.655 .75 .92 r
.70217 .19631 .71098 .20874 .72993 .20201 .72121 .18959 Mtetra
.652 .751 .922 r
.72121 .18959 .72993 .20201 .74901 .19536 .74038 .18291 Mtetra
.657 .752 .92 r
.06605 .40904 .07743 .41894 .09252 .41343 .08118 .40355 Mtetra
.659 .755 .92 r
.08118 .40355 .09252 .41343 .10769 .40798 .09641 .39796 Mtetra
.657 .752 .92 r
.09641 .39796 .10769 .40798 .12294 .40261 .11172 .39244 Mtetra
.654 .75 .92 r
.11172 .39244 .12294 .40261 .13826 .39734 .1271 .38699 Mtetra
.651 .746 .919 r
.1271 .38699 .13826 .39734 .15369 .39186 .14257 .38161 Mtetra
.655 .751 .92 r
.14257 .38161 .15369 .39186 .16924 .38624 .15815 .37605 Mtetra
.659 .754 .921 r
.15815 .37605 .16924 .38624 .18482 .38104 .17384 .37031 Mtetra
.65 .742 .917 r
.17384 .37031 .18482 .38104 .20044 .37651 .1896 .36487 Mtetra
.635 .721 .91 r
.1896 .36487 .20044 .37651 .21605 .37307 .20539 .35995 Mtetra
.619 .689 .893 r
.20539 .35995 .21605 .37307 .23171 .37029 .22124 .35558 Mtetra
.592 .652 .878 r
.22124 .35558 .23171 .37029 .24753 .36716 .2371 .35223 Mtetra
.594 .65 .876 r
.2371 .35223 .24753 .36716 .26354 .36322 .25309 .3488 Mtetra
.604 .664 .882 r
.25309 .3488 .26354 .36322 .27974 .35831 .26923 .34495 Mtetra
.618 .689 .894 r
.26923 .34495 .27974 .35831 .29612 .35228 .28554 .34049 Mtetra
.633 .725 .914 r
.28554 .34049 .29612 .35228 .31268 .34512 .30201 .33545 Mtetra
.643 .774 .943 r
.30201 .33545 .31268 .34512 .32934 .33779 .31862 .3299 Mtetra
.646 .817 .965 r
.31862 .3299 .32934 .33779 .34607 .3306 .33536 .32401 Mtetra
.643 .847 .978 r
.33536 .32401 .34607 .3306 .36288 .32371 .35221 .31788 Mtetra
.638 .865 .984 r
.35221 .31788 .36288 .32371 .37977 .31724 .36918 .31164 Mtetra
.627 .868 .988 r
.36918 .31164 .37977 .31724 .39673 .31122 .38624 .30555 Mtetra
.619 .866 .989 r
.38624 .30555 .39673 .31122 .41379 .30565 .4034 .29962 Mtetra
.626 .861 .987 r
.4034 .29962 .41379 .30565 .43095 .3005 .42068 .29358 Mtetra
.642 .847 .979 r
.42068 .29358 .43095 .3005 .44822 .29566 .43808 .2873 Mtetra
.66 .821 .961 r
.43808 .2873 .44822 .29566 .46561 .29096 .4556 .28066 Mtetra
.676 .784 .931 r
.4556 .28066 .46561 .29096 .48313 .2861 .47323 .27352 Mtetra
.685 .743 .895 r
.47323 .27352 .48313 .2861 .50079 .28009 .49097 .26576 Mtetra
.691 .717 .869 r
.49097 .26576 .50079 .28009 .51857 .27293 .50882 .25738 Mtetra
.693 .7 .852 r
.50882 .25738 .51857 .27293 .53645 .26479 .52676 .24855 Mtetra
.691 .69 .845 r
.52676 .24855 .53645 .26479 .55441 .25579 .54479 .23963 Mtetra
.674 .685 .853 r
.54479 .23963 .55441 .25579 .57246 .24641 .56292 .23173 Mtetra
.668 .707 .877 r
.56292 .23173 .57246 .24641 .59061 .2377 .58117 .22439 Mtetra
.66 .729 .901 r
.58117 .22439 .59061 .2377 .60889 .23009 .59954 .21757 Mtetra
.653 .743 .916 r
.59954 .21757 .60889 .23009 .62729 .22315 .61804 .21105 Mtetra
.656 .754 .922 r
.61804 .21105 .62729 .22315 .64583 .21665 .63666 .20434 Mtetra
.66 .753 .919 r
.63666 .20434 .64583 .21665 .66449 .21 .65539 .19742 Mtetra
.657 .748 .917 r
.65539 .19742 .66449 .21 .68326 .20311 .67426 .19058 Mtetra
.655 .75 .92 r
.67426 .19058 .68326 .20311 .70217 .19631 .69326 .1838 Mtetra
.653 .751 .922 r
.69326 .1838 .70217 .19631 .72121 .18959 .71239 .17707 Mtetra
.654 .753 .922 r
.71239 .17707 .72121 .18959 .74038 .18291 .73165 .17023 Mtetra
.653 .749 .92 r
.05456 .39891 .06605 .40904 .08118 .40355 .06971 .39352 Mtetra
.658 .753 .92 r
.06971 .39352 .08118 .40355 .09641 .39796 .08499 .38792 Mtetra
.659 .755 .921 r
.08499 .38792 .09641 .39796 .11172 .39244 .10036 .38224 Mtetra
.657 .752 .92 r
.10036 .38224 .11172 .39244 .1271 .38699 .11581 .37663 Mtetra
.654 .749 .92 r
.11581 .37663 .1271 .38699 .14257 .38161 .13134 .37107 Mtetra
.651 .746 .919 r
.13134 .37107 .14257 .38161 .15815 .37605 .14696 .36558 Mtetra
.653 .75 .92 r
.14696 .36558 .15815 .37605 .17384 .37031 .16268 .35999 Mtetra
.66 .756 .921 r
.16268 .35999 .17384 .37031 .1896 .36487 .17853 .35412 Mtetra
.654 .747 .918 r
.17853 .35412 .1896 .36487 .20539 .35995 .19445 .34841 Mtetra
.644 .729 .911 r
.19445 .34841 .20539 .35995 .22124 .35558 .21044 .34305 Mtetra
.633 .708 .9 r
.21044 .34305 .22124 .35558 .2371 .35223 .22649 .33805 Mtetra
.621 .676 .881 r
.22649 .33805 .2371 .35223 .25309 .3488 .24261 .33346 Mtetra
.606 .652 .87 r
.24261 .33346 .25309 .3488 .26923 .34495 .25879 .32945 Mtetra
.608 .652 .868 r
.25879 .32945 .26923 .34495 .28554 .34049 .27511 .32529 Mtetra
.615 .661 .871 r
.27511 .32529 .28554 .34049 .30201 .33545 .29156 .3208 Mtetra
.624 .674 .877 r
.29156 .3208 .30201 .33545 .31862 .3299 .30817 .31593 Mtetra
.634 .691 .885 r
.30817 .31593 .31862 .3299 .33536 .32401 .32491 .31066 Mtetra
.642 .706 .893 r
.32491 .31066 .33536 .32401 .35221 .31788 .34178 .30505 Mtetra
.648 .719 .9 r
.34178 .30505 .35221 .31788 .36918 .31164 .35878 .29915 Mtetra
.654 .728 .904 r
.35878 .29915 .36918 .31164 .38624 .30555 .37591 .29299 Mtetra
.659 .73 .902 r
.37591 .29299 .38624 .30555 .4034 .29962 .39315 .28657 Mtetra
.664 .724 .894 r
.39315 .28657 .4034 .29962 .42068 .29358 .41051 .27985 Mtetra
.669 .716 .884 r
.41051 .27985 .42068 .29358 .43808 .2873 .42799 .27279 Mtetra
.674 .706 .872 r
.42799 .27279 .43808 .2873 .4556 .28066 .44558 .26533 Mtetra
.678 .696 .859 r
.44558 .26533 .4556 .28066 .47323 .27352 .46328 .25746 Mtetra
.68 .687 .85 r
.46328 .25746 .47323 .27352 .49097 .26576 .48109 .24925 Mtetra
.681 .682 .844 r
.48109 .24925 .49097 .26576 .50882 .25738 .49899 .24088 Mtetra
.671 .679 .849 r
.49899 .24088 .50882 .25738 .52676 .24855 .51698 .23307 Mtetra
.666 .694 .866 r
.51698 .23307 .52676 .24855 .54479 .23963 .53508 .22569 Mtetra
.663 .719 .89 r
.53508 .22569 .54479 .23963 .56292 .23173 .55329 .21865 Mtetra
.656 .733 .906 r
.55329 .21865 .56292 .23173 .58117 .22439 .57163 .21197 Mtetra
.652 .746 .918 r
.57163 .21197 .58117 .22439 .59954 .21757 .59009 .20544 Mtetra
.658 .756 .922 r
.59009 .20544 .59954 .21757 .61804 .21105 .60866 .19863 Mtetra
.66 .752 .918 r
.60866 .19863 .61804 .21105 .63666 .20434 .62736 .19169 Mtetra
.657 .748 .917 r
.62736 .19169 .63666 .20434 .65539 .19742 .64619 .18481 Mtetra
.655 .75 .919 r
.64619 .18481 .65539 .19742 .67426 .19058 .66514 .17799 Mtetra
.653 .751 .922 r
.66514 .17799 .67426 .19058 .69326 .1838 .68423 .17121 Mtetra
.654 .753 .923 r
.68423 .17121 .69326 .1838 .71239 .17707 .70345 .16436 Mtetra
.658 .754 .921 r
.70345 .16436 .71239 .17707 .73165 .17023 .72279 .15726 Mtetra
.653 .749 .92 r
.04293 .38867 .05456 .39891 .06971 .39352 .05814 .38322 Mtetra
.05814 .38322 .06971 .39352 .08499 .38792 .07344 .37773 Mtetra
.658 .754 .921 r
.07344 .37773 .08499 .38792 .10036 .38224 .08886 .37202 Mtetra
.659 .755 .921 r
.08886 .37202 .10036 .38224 .11581 .37663 .10437 .36626 Mtetra
.657 .752 .92 r
.10437 .36626 .11581 .37663 .13134 .37107 .11997 .36054 Mtetra
.655 .75 .92 r
.11997 .36054 .13134 .37107 .14696 .36558 .13566 .35485 Mtetra
.652 .746 .919 r
.13566 .35485 .14696 .36558 .16268 .35999 .15143 .34925 Mtetra
.652 .747 .92 r
.15143 .34925 .16268 .35999 .17853 .35412 .1673 .3436 Mtetra
.658 .755 .922 r
.1673 .3436 .17853 .35412 .19445 .34841 .1833 .33769 Mtetra
.658 .752 .92 r
.1833 .33769 .19445 .34841 .21044 .34305 .19939 .33175 Mtetra
.652 .74 .914 r
.19939 .33175 .21044 .34305 .22649 .33805 .21556 .32597 Mtetra
.645 .724 .906 r
.21556 .32597 .22649 .33805 .24261 .33346 .23182 .32042 Mtetra
.639 .706 .895 r
.23182 .32042 .24261 .33346 .25879 .32945 .24815 .31506 Mtetra
.633 .682 .878 r
.24815 .31506 .25879 .32945 .27511 .32529 .26459 .30981 Mtetra
.626 .663 .866 r
.26459 .30981 .27511 .32529 .29156 .3208 .28112 .30477 Mtetra
.624 .655 .86 r
.28112 .30477 .29156 .3208 .30817 .31593 .29776 .29976 Mtetra
.628 .656 .858 r
.29776 .29976 .30817 .31593 .32491 .31066 .31453 .2945 Mtetra
.634 .659 .857 r
.31453 .2945 .32491 .31066 .34178 .30505 .33144 .28893 Mtetra
.64 .664 .857 r
.33144 .28893 .34178 .30505 .35878 .29915 .34847 .28303 Mtetra
.646 .668 .856 r
.34847 .28303 .35878 .29915 .37591 .29299 .36564 .27679 Mtetra
.652 .67 .854 r
.36564 .27679 .37591 .29299 .39315 .28657 .38293 .27021 Mtetra
.657 .671 .851 r
.38293 .27021 .39315 .28657 .41051 .27985 .40034 .2633 Mtetra
.662 .671 .848 r
.40034 .2633 .41051 .27985 .42799 .27279 .41787 .25607 Mtetra
.665 .671 .846 r
.41787 .25607 .42799 .27279 .44558 .26533 .43551 .24858 Mtetra
.664 .672 .847 r
.43551 .24858 .44558 .26533 .46328 .25746 .45325 .24111 Mtetra
.662 .678 .854 r
.45325 .24111 .46328 .25746 .48109 .24925 .47109 .23385 Mtetra
.662 .693 .868 r
.47109 .23385 .48109 .24925 .49899 .24088 .48904 .22669 Mtetra
.661 .714 .887 r
.48904 .22669 .49899 .24088 .51698 .23307 .50709 .21972 Mtetra
.657 .728 .902 r
.50709 .21972 .51698 .23307 .53508 .22569 .52527 .21298 Mtetra
.654 .741 .914 r
.52527 .21298 .53508 .22569 .55329 .21865 .54356 .20639 Mtetra
.654 .751 .921 r
.54356 .20639 .55329 .21865 .57163 .21197 .56198 .19976 Mtetra
.659 .756 .921 r
.56198 .19976 .57163 .21197 .59009 .20544 .58051 .19285 Mtetra
.659 .75 .917 r
.58051 .19285 .59009 .20544 .60866 .19863 .59917 .1859 Mtetra
.656 .748 .917 r
.59917 .1859 .60866 .19863 .62736 .19169 .61796 .17902 Mtetra
.655 .75 .92 r
.61796 .17902 .62736 .19169 .64619 .18481 .63687 .17216 Mtetra
.653 .751 .922 r
.63687 .17216 .64619 .18481 .66514 .17799 .65592 .16534 Mtetra
.654 .753 .923 r
.65592 .16534 .66514 .17799 .68423 .17121 .6751 .15844 Mtetra
.658 .754 .921 r
.6751 .15844 .68423 .17121 .70345 .16436 .6944 .15131 Mtetra
.658 .751 .918 r
.6944 .15131 .70345 .16436 .72279 .15726 .71383 .14413 Mtetra
.655 .751 .92 r
.03117 .37839 .04293 .38867 .05814 .38322 .04644 .37279 Mtetra
.653 .749 .92 r
.04644 .37279 .05814 .38322 .07344 .37773 .06179 .36724 Mtetra
.06179 .36724 .07344 .37773 .08886 .37202 .07723 .36165 Mtetra
.658 .754 .921 r
.07723 .36165 .08886 .37202 .10437 .36626 .0928 .35587 Mtetra
.659 .755 .921 r
.0928 .35587 .10437 .36626 .11997 .36054 .10846 .35 Mtetra
.657 .753 .92 r
.10846 .35 .11997 .36054 .13566 .35485 .12421 .34417 Mtetra
.656 .751 .92 r
.12421 .34417 .13566 .35485 .15143 .34925 .14005 .33836 Mtetra
.653 .747 .919 r
.14005 .33836 .15143 .34925 .1673 .3436 .15598 .3326 Mtetra
.652 .746 .919 r
.15598 .3326 .1673 .3436 .1833 .33769 .17201 .32684 Mtetra
.653 .751 .921 r
.17201 .32684 .1833 .33769 .19939 .33175 .18814 .32102 Mtetra
.659 .756 .922 r
.18814 .32102 .19939 .33175 .21556 .32597 .2044 .31493 Mtetra
.657 .751 .919 r
.2044 .31493 .21556 .32597 .23182 .32042 .22075 .30886 Mtetra
.654 .741 .913 r
.22075 .30886 .23182 .32042 .24815 .31506 .2372 .30286 Mtetra
.65 .729 .907 r
.2372 .30286 .24815 .31506 .26459 .30981 .25374 .29697 Mtetra
.647 .717 .899 r
.25374 .29697 .26459 .30981 .28112 .30477 .27038 .29112 Mtetra
.645 .704 .889 r
.27038 .29112 .28112 .30477 .29776 .29976 .28712 .28528 Mtetra
.644 .691 .879 r
.28712 .28528 .29776 .29976 .31453 .2945 .30398 .27937 Mtetra
.644 .681 .87 r
.30398 .27937 .31453 .2945 .33144 .28893 .32095 .27336 Mtetra
.645 .676 .865 r
.32095 .27336 .33144 .28893 .34847 .28303 .33805 .26721 Mtetra
.648 .675 .862 r
.33805 .26721 .34847 .28303 .36564 .27679 .35526 .26089 Mtetra
.65 .676 .861 r
.35526 .26089 .36564 .27679 .38293 .27021 .37259 .25441 Mtetra
.653 .679 .863 r
.37259 .25441 .38293 .27021 .40034 .2633 .39003 .24778 Mtetra
.655 .686 .867 r
.39003 .24778 .40034 .2633 .41787 .25607 .40759 .24103 Mtetra
.657 .695 .874 r
.40759 .24103 .41787 .25607 .43551 .24858 .42526 .23423 Mtetra
.658 .709 .885 r
.42526 .23423 .43551 .24858 .45325 .24111 .44305 .22742 Mtetra
.658 .721 .895 r
.44305 .22742 .45325 .24111 .47109 .23385 .46094 .22066 Mtetra
.656 .731 .905 r
.46094 .22066 .47109 .23385 .48904 .22669 .47895 .214 Mtetra
.654 .741 .914 r
.47895 .214 .48904 .22669 .50709 .21972 .49708 .2074 Mtetra
.653 .749 .92 r
.49708 .2074 .50709 .21972 .52527 .21298 .51533 .20082 Mtetra
.658 .756 .922 r
.51533 .20082 .52527 .21298 .54356 .20639 .53371 .19396 Mtetra
.659 .753 .919 r
.53371 .19396 .54356 .20639 .56198 .19976 .5522 .18703 Mtetra
.658 .748 .916 r
.5522 .18703 .56198 .19976 .58051 .19285 .57082 .18008 Mtetra
.656 .748 .918 r
.57082 .18008 .58051 .19285 .59917 .1859 .58956 .17319 Mtetra
.655 .75 .92 r
.58956 .17319 .59917 .1859 .61796 .17902 .60844 .16631 Mtetra
.653 .751 .922 r
.60844 .16631 .61796 .17902 .63687 .17216 .62744 .15944 Mtetra
.654 .753 .923 r
.62744 .15944 .63687 .17216 .65592 .16534 .64658 .15249 Mtetra
.658 .754 .921 r
.64658 .15249 .65592 .16534 .6751 .15844 .66583 .14532 Mtetra
.658 .75 .918 r
.66583 .14532 .6751 .15844 .6944 .15131 .68522 .1381 Mtetra
.656 .75 .919 r
.68522 .1381 .6944 .15131 .71383 .14413 .70475 .13091 Mtetra
.657 .753 .92 r
.01927 .36805 .03117 .37839 .04644 .37279 .03459 .36233 Mtetra
.655 .751 .92 r
.03459 .36233 .04644 .37279 .06179 .36724 .05 .35664 Mtetra
.653 .749 .92 r
.05 .35664 .06179 .36724 .07723 .36165 .0655 .35098 Mtetra
.0655 .35098 .07723 .36165 .0928 .35587 .08109 .34529 Mtetra
.657 .753 .921 r
.08109 .34529 .0928 .35587 .10846 .35 .0968 .33944 Mtetra
.659 .755 .921 r
.0968 .33944 .10846 .35 .12421 .34417 .11262 .33348 Mtetra
.658 .754 .921 r
.11262 .33348 .12421 .34417 .14005 .33836 .12852 .32752 Mtetra
.656 .752 .92 r
.12852 .32752 .14005 .33836 .15598 .3326 .14452 .32158 Mtetra
.655 .749 .919 r
.14452 .32158 .15598 .3326 .17201 .32684 .16062 .31564 Mtetra
.653 .746 .918 r
.16062 .31564 .17201 .32684 .18814 .32102 .17681 .30975 Mtetra
.17681 .30975 .18814 .32102 .2044 .31493 .1931 .30383 Mtetra
.653 .751 .921 r
.1931 .30383 .2044 .31493 .22075 .30886 .2095 .29784 Mtetra
.657 .755 .922 r
.2095 .29784 .22075 .30886 .2372 .30286 .22601 .29168 Mtetra
.658 .753 .921 r
.22601 .29168 .2372 .30286 .25374 .29697 .24264 .28545 Mtetra
.657 .748 .917 r
.24264 .28545 .25374 .29697 .27038 .29112 .25936 .27921 Mtetra
.655 .741 .913 r
.25936 .27921 .27038 .29112 .28712 .28528 .27619 .27298 Mtetra
.654 .735 .909 r
.27619 .27298 .28712 .28528 .30398 .27937 .29313 .26674 Mtetra
.654 .73 .905 r
.29313 .26674 .30398 .27937 .32095 .27336 .31018 .26046 Mtetra
.654 .726 .902 r
.31018 .26046 .32095 .27336 .33805 .26721 .32734 .25412 Mtetra
.654 .725 .901 r
.32734 .25412 .33805 .26721 .35526 .26089 .34461 .24773 Mtetra
.655 .725 .901 r
.34461 .24773 .35526 .26089 .37259 .25441 .362 .24127 Mtetra
.655 .727 .902 r
.362 .24127 .37259 .25441 .39003 .24778 .3795 .23475 Mtetra
.655 .73 .905 r
.3795 .23475 .39003 .24778 .40759 .24103 .39711 .2282 Mtetra
.655 .735 .909 r
.39711 .2282 .40759 .24103 .42526 .23423 .41484 .22163 Mtetra
.654 .741 .913 r
.41484 .22163 .42526 .23423 .44305 .22742 .43269 .21506 Mtetra
.654 .747 .918 r
.43269 .21506 .44305 .22742 .46094 .22066 .45065 .20849 Mtetra
.655 .752 .922 r
.45065 .20849 .46094 .22066 .47895 .214 .46874 .20184 Mtetra
.658 .756 .922 r
.46874 .20184 .47895 .214 .49708 .2074 .48695 .195 Mtetra
.659 .753 .92 r
.48695 .195 .49708 .2074 .51533 .20082 .50528 .1881 Mtetra
.658 .748 .916 r
.50528 .1881 .51533 .20082 .53371 .19396 .52373 .18116 Mtetra
.656 .747 .917 r
.52373 .18116 .53371 .19396 .5522 .18703 .54231 .17425 Mtetra
.655 .749 .919 r
.54231 .17425 .5522 .18703 .57082 .18008 .56101 .16734 Mtetra
.654 .751 .921 r
.56101 .16734 .57082 .18008 .58956 .17319 .57984 .16044 Mtetra
.653 .752 .922 r
.57984 .16044 .58956 .17319 .60844 .16631 .5988 .15353 Mtetra
.655 .754 .923 r
.5988 .15353 .60844 .16631 .62744 .15944 .61789 .14649 Mtetra
.658 .754 .92 r
.61789 .14649 .62744 .15944 .64658 .15249 .63711 .13928 Mtetra
.658 .75 .918 r
.63711 .13928 .64658 .15249 .66583 .14532 .65645 .13203 Mtetra
.656 .75 .919 r
.65645 .13203 .66583 .14532 .68522 .1381 .67594 .1248 Mtetra
.655 .751 .92 r
.67594 .1248 .68522 .1381 .70475 .13091 .69556 .11758 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
[(-2)] .12586 .2075 1 .99877 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.56863 .04703 m
.57247 .05235 L
s
[(2)] .56094 .0364 .72324 1 Mshowa
.125 Mabswid
.18558 .19702 m
.18832 .19985 L
s
.23703 .17687 m
.23971 .17975 L
s
.28951 .15632 m
.29214 .15925 L
s
.39772 .11395 m
.40023 .11699 L
s
.4535 .09211 m
.45595 .0952 L
s
.51046 .06981 m
.51284 .07294 L
s
.08568 .23614 m
.08851 .23887 L
s
.62804 .02377 m
.63027 .02701 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 233.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00o?ooool2o`0006[ooooo003iooooo`?o000000?oooooo`000?ooool0
JOooool00?Oooooo0_l00004ooooo`;o0000JOooool00?Cooooo0ol00006ooooo`03o`000?oooooo
000006Sooooo003;ooooo`Go00008_ooool2o`0000Wooooo00?o0000ooooool00000J?ooool00<_o
oooo00GoV9RHob4Q8Oo^k^koooooodA4A00Oooooo`?o00002oooool01?l0003oooooooooool0001W
ooooo`00c?ooool00onHV9So8B4Qonk^kP0Mooooo`?o00003_ooool01Ol0003ooooooooooooooooo
000006Kooooo003=ooooo`03oiRHV?lQ8B7ok^k^01[ooooo0_l0000Aooooo`05o`000?oooooooooo
ooooool00000I_ooool00<kooooo00?oMgMgofIVI_ooool05_ooool3o`0001?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1Sooooo`00coooool00ol0003oooooooooo`0Cooooo`;o
00000_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0H_ooool00<_ooooo00Go0000okZj^_ooooooV9RHoa0@400Booooo`?o00006Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo06;ooooo003;ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`04?ooool2o`0001cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Qooooo`00
gOooool3o`0001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Qooooo`00fooo
ool2o`00027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Pooooo`00f?ooool3
o`0002?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Oooooo`00eOooool3o`00
02Kooooo00?o0000ooooooooool01?ooool2o`00067ooooo003Cooooo`;o0000:Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo05kooooo003@ooooo`?o000000?oooooo`000?ooool0
:?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05gooooo003>ooooo`;o00001Ooo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0GOoo
ool00<_ooooo0ol0000`ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0G?ooool0
0<Wooooo0_l0000cooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Foooool00<Ko
oooo0ol0000eooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Foooool00<Cooooo
0_l0000hooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0F_ooool00<7ooooo0ol0
000jooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03_ooool5o`0004Kooooo002n
ooooo`?o0000?Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00kooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A016ooooo`00_?ooool2o`0000?ooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo1_l00003ooooo`03oiRHV?lQ8B7o
k^k^04Oooooo002iooooo`?o0000@oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00kooooo00?oV9RHob4Q8Oo^k^h0A_ooool00;Oooooo0_l00016ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03oooool00omgMgOoIVIVooooo`15ooooo`00]?ooool3o`0004Sooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Cooooo
002booooo`;o0000Boooool00ol0003oooooooooo`0=ooooo`;o00003?ooool01Ol0003o^[Zjoooo
oonHV9So410@04Kooooo002_ooooo`?o0000COooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c016ooooo`00[Oooool2o`00053ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`1Dooooo`00Z_ooool4o`00057ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1Dooooo`00Z?ooool2o`0000Cooooo00?o0000oooo
ooooool0C_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05?ooooo001nooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h08_ooool3o`0005Oooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`1Booooo`00O_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01oooooo0ol0001Joooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool0D_ooool007kooooo00Go410@oooooooo
oooooooooa0@400Mooooo`;o0000GOooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
057ooooo001nooooo`05o`000?ooooooooooooooool000006_ooool3o`0005oooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`1@ooooo`00O_ooool01Ol0003ooooooooooooooooo0000
01Sooooo0_l0001Rooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0D?ooool007ko
oooo00Go410@oooooooooooooooooa0@400Eooooo`?o0000I?ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo04oooooo001nooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool2o`00
00?ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
04kooooo001nooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04?ooool3o`0006Sooooo00?oYl3[o`00
0?ooool05_ooool00ol0003oooooooooo`1>ooooo`00TOooool2o`0006Sooooo1?nW`>/00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo04gooooo002>ooooo`?o0000J?ooool7ojO0j`03o`00
0?oooooooooo01Cooooo0ol0001>ooooo`00Roooool3o`0006Wooooo0_nW_n/7ojO0j`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool0C?ooool008Wooooo0_l0001Yooooo`KoYko[1_nW`>/0
0ol0003oYl3[ooooo`0Gooooo`03o`000?oooooooooo04_ooooo0026ooooo`?o0000J?ooool00onX
_n_oYko[ojNoj`07ojNoj`GoYl3[00?o0000ojNojoooool06?ooool00ol0003oooooooooo`1:oooo
o`00Q?ooool2o`0000;ooooo00?o0000ooooooooool0Hoooool5ojRoj`WoYko[0_nW`>/2ojNoj`03
o`000?nW_n_oYko[01Sooooo00?o0000ooooooooool0B_ooool0087ooooo0ol00005ooooo`03o`00
0?oooooooooo063ooooo2?nX_n/7ojNoj`03ojRojonW_n_oYko[00;oYko[00Co0000ojNojonW_n_o
Yko[6?ooool00ol0003oooooooooo`19ooooo`00Ooooool2o`0006Wooooo00?oZ<7[ojRojonX_n/0
1onX_n/4ojNoj`GoZ;o[0onW_n/00ol0003oYko[ojNoj`02ojNojaSooooo00?o0000ooooooooool0
B?ooool007cooooo0ol0001Xooooo`GoZ<7[2OnX_n/00onW_n_oZ;o[ojRoj`06ojRoj`;oYko[00Go
0000ojNojonW_n_oYko[ojS0j`0Hooooo`03o`000?oooooooooo04Sooooo001jooooo`;o0000Iooo
ool2ojO1k0SoZ<7[1_nX_n/2ojS1j`WoZ;o[0_nW_n/00ol0003oYko[ojS0j`03ojS0jaSooooo00?o
0000ooooooooool0Aoooool007Oooooo0ol0001Vooooo`KoYl7/2?nX`N/2ojRoj`KoZ<7[2OnX_n/0
0onW_n_o0000ojS0j`05ojS0jaSooooo00?o0000ooooooooool0A_ooool007Cooooo0ol0001Voooo
o`03ojO0k?nW`NcoYl7/00OoYl7/1_nX`N/2ojO0k0SoZ<7[1_nX_n/2ojS1j`03ojS0jol0003oZ<3[
00GoZ<3[6?ooool00ol0003oooooooooo`16ooooo`00L_ooool2o`0000;ooooo00?o0000oooooooo
ool0H_ooool4ojO0k0WoYl7/0_nX`N/6ojO0k0SoZ<7[0_nX_n/6ojS1j`03o`000?nX`>_oZ<3[00Go
Z<3[6?ooool00ol0003oooooooooo`15ooooo`00Koooool3o`0006Oooooo1onW`>`7ojO1k0[oYl3/
1_nX`N/00onW`>coZ<7[ojS1j`06ojS1j`03o`000?nX`>_oZ<3[00CoZ<3[00?oZ<7[ooooooooool0
5_ooool00ol0003oooooooooo`15ooooo`00KOooool2o`0006Oooooo0_nW`>/8ojO0k0CoYl7/3_nW
`>`2ojS1j`GoYl3/1onX`N/01?l0003oZ<7[ojS0jonX`>/5ojS1jaOooooo0_l00016ooooo`00J_oo
ool3o`0006Kooooo1_nW`>/8ojO0k003ojO1k?nW`>coYl3/01KoYl3/1_nX`N/00ol0003oYl3/ojS1
j`07ojS1jaSooooo00?o0000ooooooooool0@oooool006Sooooo0_l0001Vooooo`;oYko[2?nW`>/6
ojO0k0;oYko[6OnW`>`2ojS1j`?oYl3/00?o0000ojO0k?nW`>`02?nX`N/Gooooo`03o`000?oooooo
oooo04?ooooo001Uooooo`?o0000IOooool6ojNoj`SoYl3[0_nW`>`6ojNojagoYl3/00Co0000ojO0
k?nW`>coYl3/1_nX`N/00onW`>coooooooooo`0Fooooo`03o`000?oooooooooo04;ooooo001Soooo
o`;o0000IOooool00onW_n[oYko[ojNoj`07ojNoj`KoYl3[2_nW_n/6ojO0k003ojNojonW`>coYl3/
01CoYl3/00Co0000ojO0k?nW`>coYl3/0_nX`N/5ojO0k1Sooooo00?o0000ooooooooool0@Oooool0
063ooooo0ol000000ooooooo0000ooooo`1Rooooo`CoYkoZ2OnW_n/2ojO0j`koYko[0_nW`>`5ojNo
jaGoYl3/00?o0000ojO0k?nW`>`02OnW`>`Gooooo`03o`000?oooooooooo047ooooo000fooooo`Go
00008oooool2o`0006Kooooo1onW_nX7ojNoj`03ojRoj_nW_n_oYko[00coYko[0_nW_nX8ojNoj`Ko
Yl3/0_nW_n/<ojO0k003o`000?nW`>coYl3/00[oYl3/5oooool00ol0003oooooooooo`10ooooo`00
=_ooool01OnHV9So8B4Qonk^k_ooooooA4A4023ooooo0ol0001Uooooo`;oZ;oZ2?nW_nX4ojNoj`Go
Z;oZ2_nW_n/6ojNojPSoYko[0_nW`>`6ojNoj`_oYl3/00?o0000ojO0k?nW`>`02OnW`>`00onV`>co
ooooooooo`0Fooooo`03o`000?oooooooooo03oooooo000^ooooo`Ko00000oooool00onHV9So8B4Q
onk^kP0Nooooo`?o0000IOooool6ojRojPSoYkoZ00?oYko[ojRoj_nX_nX01_nX_nX6ojNoj`03ojRo
j_nW_n[oYkoZ00OoYkoZ1_nW_n/00onX_n[oYko[ojNoj`07ojNoj`KoYl3/00GoYko[ojO0k?nW`>co
Yl3/o`000009ojO0k0CoY/3/5oooool00ol0003oooooooooo`0oooooo`00>?ooool00onHV9So8B4Q
onk^kP0Kooooo`;o0000IOooool2ojS0j`SoZ;oZ1_nW_nX2ojS0j`SoZ;oZ1?nW_n/4ojRojPWoYkoZ
0_nW_n/5ojRojPWoYko[0_nW`>`5ojNoj`;oYl3/00?o0000ojO0k?nW`>`01OnW`>`7ojK0k1Oooooo
00?o0000ooooooooool0?_ooool003Wooooo00?oMgMgofIVI_ooool05oooool3o`0006Cooooo1_nX
`>/8ojRojP;oYkoZ1_nX`>/8ojRojP03ojNojonX_n[oZ;oZ00GoZ;oZ1onW_nX00onX`>_oZ;oZojRo
jP06ojRojPKoYko[0_nX_nX8ojNoj`03ojO0k?l0003oYl3/00?oYl3/0_nW_n/8ojK0k1Sooooo00?o
0000ooooooooool0?Oooool003[ooooo00?o0000ooooooooool05?ooool2o`0006Cooooo00?oZ<7/
ojS0jonX`>/01onX`>/6ojRojP03ojS1k?nX`>_oZ<3[00OoZ<3[1_nX_nX00onX`N_oZ;oZojRojP07
ojRojPCoYkoZ1?nX`>/8ojRojP;oYko[1_nX_nX8ojNoj`03o`000?nW`>coYko[00GoYko[2?nV`>`G
ooooo`03o`000?oooooooooo03gooooo000fooooo`05o`000?nj^[[ooooooiRHV?l@41004oooool3
o`0000;ooooo00?o0000ooooooooool0Goooool4ojS1k0WoZ<3[0_nX_nX5ojS1k0WoZ<3[0_nX_nX5
ojS1j`WoZ;oZ00?oYkoZojS0jonX`>/01OnX`>/6ojRojP03ojS0jonX_n[oZ;oZ00OoZ;oZ1_nW_n/0
0onX_n[o0000ojNoj`07ojNoj`KoY/3/00?oYko[ooooooooool05_ooool00ol0003oooooooooo`0l
ooooo`00=_ooool01OnHV9So410@o`000?lQ8B7oc<c<017ooooo0_l0001Uooooo`OoZ<7/1onX`>/0
0onW_n_oZ<7/ojS1k006ojS1k0KoZ<3[0_nW`>/8ojS1j`KoZ;oZ0_nX`N`8ojS0j`CoZ;oZ1?nX`>/9
ojRojP;oYko[1?nX_nX00ol0003oYko[ojNoj`07ojNoj`;oY/3/1OnW_n/Fooooo`?o0000?Oooool0
04Wooooo0ol0001Uooooo`03ojO0k?nX`NcoZ<7/00OoZ<7/1?nX`>/4ojNoj`SoZ<7/0_nX`>/6ojO0
j`SoZ<7[0_nX_nX6ojS1k0SoZ<3[00?oZ;oZojS0jonX`>/01OnX`>/7ojRojP03ojS0jonX_n[oZ;oZ
00CoZ;oZ00?o0000ojRoj_nW_n/03onW_n/Gooooo`03o`000?oooooooooo03_ooooo0017ooooo`;o
0000IOooool5ojO0k0WoZ<7/00?oZ<3[ojNojonW_n/01OnW_n/6ojS1k003ojNmjOnW`>_oYl3[00Oo
Yl3[1_nX`N/00onV_^_oZ<7/ojS1k007ojS1k0KoZ<3[00?oYl7/ojS0jonX`>/01_nX`>/4ojRojPGo
Z<3[1OnX_nX00ol0003oZ;oZojRojP0@ojNojaOooooo00?o0000ooooooooool0>_ooool004Cooooo
0ol0001Tooooo`03ojNojonW`>coYl3/00KoYl3/1_nX`N`2ojNmj@SoYko[1?nX`N`4ojNmj@WoYl3[
0_nX`N/5ojJnj`WoZ<7/0_nX`>/5ojO1k0SoZ<3[00?oZ;oZojS0jonX`>/01_nX`>/4ojRojP03o`00
0?nX_n[oZL3Z013oYko[6?ooool00ol0003oooooooooo`0iooooo`00@Oooool3o`0006Cooooo1OnW
_n/8ojO0k0;oZ<7/1_nW_NT8ojNoj`03ojS1k?nW_NWoYkgY00GoYkgY1onW`>/00onW^nOoY[k[ojJn
j`06ojJnj`KoZ<7/0_nW_^X8ojO1k0KoZ<3[0_nW`N`9ojS0j`;oZ;oZ00?oZL3Zo`000?nY`>X00_nY
`>X@ojNojaOooooo00?o0000ooooooooool0>Oooool003oooooo0ol0001Sooooo`03ojNmjOnW_n_o
Yko[00KoYko[1_nW`>`2ojNki`SoYkgY1_nW_n/2ojRjiPSoYkgY1?nW`>/4ojNki`SoY[k[0_nX`N`6
ojNnjPSoYl7/0_nX`>/6ojO1k0OoZ<3[00GoZ<7/ojW0j_nY`>[oZL3Zo`000004ojW0jPKoYko[0_nX
_nX8ojNojaOooooo00?o0000ooooooooool0>?ooool003cooooo0ol00003ooooo`03o`000?oooooo
oooo05kooooo1?nW_NT8ojNoj`;oYl3/1_nW^nL8ojNmj@;oYko[1_nX^^H8ojNmj@03ojO0jonW^nOo
Yk_W00GoYk_W1_nV_^/2ojRjiPSoYkkZ1_nW`N`00onW_N[oYl7/ojO1k007ojO1k0CoZ<3[1?nX`N`2
ojW0jP03o`000?nY`>[oZL3Z00?oZL3Z0_nW_n/6ojRojPSoYko[5_ooool00ol0003oooooooooo`07
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0;?ooool003[ooooo0_l0001Uooooo`OoYkgY1_nW_n/0
0onX^>GoYk_WojNki`07ojNki`KoYkgY00?oZKKSojRji_nX^^H01onX^^H6ojNmj@03ojVhhonW^nOo
Yk_W00OoYk_W0_nV_^/6ojRjiPSoYkkZ0_nW`N`5ojNmjPWoYl7/00?oZ<3[ojS1k?nX`N`01OnX`N`0
0onY`>[o0000ojW0jP03ojW0jP03ojS1jonX_n[oZ;oZ00OoZ;oZ1_nW_n/00onX_n[oooooooooo`0E
ooooo`03o`000?oooooooooo00Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0/ooooo`00=oooool3
o`0006Gooooo00?oYkcXojNmjOnW_NT01onW_NT2ojNoj`GoZ;SU2OnW^nL2ojNmj@GoZKKS2OnX^^H2
ojNmj@GoZKSS1onW^nL00on[]>3oZ;[VojRjiP07ojRjiPKoYkkZ00?oZK[UojNmj_nW_NX01_nW_NX6
ojO1k0;oYkkZ2?nX`N`2ojW0jP03o`000?nY`>[oZ<7[00?oZ<7[2OnX_nX2ojNoj`GoZ;oZ5oooool0
0ol0003oooooooooo`05ooooo`05oa0@4?ooooooooooooooool@4100;?ooool003Gooooo0_l0001U
ooooo`GoYkcX1onW_NT00onX]N;oZ;SUojRhi@06ojRhi@OoYk_W00?oZK7NojVfhonY]^<01_nY]^<6
ojRjiP;oZ[7M2?nY^><4ojNki`CoZkCP2OnX^^H2ojNnjPGoZK[U2?nW_NX2ojO1k0KoYkkZ2?nX`N`0
0onY`>[o0000ojS1j`05ojS1j`OoZ;oZ00?oZL7[ojRoj_nX_nX01_nX_nXFooooo`03o`000?oooooo
oooo00Gooooo00Go0000ooooooooooooooooo`00000/ooooo`00<_ooool3o`0006Cooooo00?oYk[W
ojNlj?nW_>P01_nW_>P4ojNmj@CoZ;GR2?nX^>D4ojNki`CoZK7N2?nY]^<2ojRjiPKoZ[7M2?nY^><0
0onW^nOoZkCPoj^dh005oj^dh0OoZ;[V00?o[;?NojVjiOnY^^D01_nY^^D6ojNmjP03ojVjiOnW_^[o
YkkZ00OoYkkZ1_nX`N`00onV_^_oZ<7[o`000006ojS1j`CoZ;oZ1OnY`N/8ojRojQKooooo00?o0000
ooooooooool01?ooool01Ol0003ooooooooooooooooo000002cooooo000`ooooo`;o0000I?ooool5
ojNji`SoYkcX00?oYkgYojReh_nX]N801OnX]N88ojRhi@03ojNkionY/MkoZK7N00GoZK7N1_nY]^<0
0on[[MWoZ[7MojZag@07ojZag@KoZKSS00?o[:oJoj^dh?n[]>001_n[]>04ojRjiPGo[;?N2?nY^^D2
ojNmjPGoZK[U2OnW_^X2ojS1k0GoY[k[00?o0000ojS1jonX`N/01OnX`N/00onX_n[oZL7[ojW1j`05
ojW1j`KoZ;oZ0_nY`>XGooooo`03o`000?oooooooooo00?ooooo00Go410@oooooooooooooooooa0@
400/ooooo`00;Oooool3o`000003ooooool0003ooooo063ooooo00?oYk[VojNjionW^^L01_nW^^L6
ojNlj003ojRagonX]N;oZ;GR00OoZ;GR1_nX^>D00onY[M[oZK7NojVagP06ojVagPCoZKKS1?n[[MT8
ojZag@CoZKSS1?n/[mX8oj^dh003ojRji_n//mko[;?N00Ko[;?N1_nY^^D00on]]=koZK[UojVji@06
ojVji@KoYkkZ0_nY^nH7ojJnj`03o`000?nX`N_oZ<7[00CoZ<7[00?oY[o[ojW1jonY`N/01onY`N/2
ojRojPKoZL3Z5_ooool2o`0000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0/ooooo`00:_ooool3
o`0006?ooooo1OnW^^H8ojNji`;oYkcX1OnX/Ml9ojRehP;oZ;SU1OnY[MX8ojVagP03ojVfhon[[MWo
ZjgI00GoZjgI2?nZ/Md00onY^>?o[:oJojb_fP05ojb_fPKoZkCP00?o/;7Iojbcg_n//mh01on//mh4
ojVji@Co[KCN2?nY^^D2ojNnjPKoZK_V1_nV_^/01?l0003oY[k[ojS1jonX`N/5ojJoj`OoZL7[00?o
Yl3[ojW0j_nY`>X01onY`>XCooooo`;o000000?oooooo`000?ooool00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^02cooooo000Xooooo`;o0000Hoooool00onW^NKoYk[VojNjiP06ojNjiPKoYk[W00?o
YjoMojRagonX/Ml01_nX/Ml7ojRehP03ojV/f?nY[M[oZJgJ00KoZJgJ1_nY/Mh00on^[]SoZjgIoj^]
f@06oj^]f@OoZ[7M00?o/;3Hojb_f_n/[mX01_n/[mX4oj^dh0Co/;7I2On//mh00onY^^Go[KCNojfd
gP05ojfdgPKoZK[U00?o[KGNojVki_nY^nH01onY^nH5ojJnj`03o`000?nX_>SoY[o[00OoY[o[1?nY
`N/4ojO0j`WoZL3Z5_ooool00ol0003oooooooooo`0booooo`009Oooool3o`0006;ooooo1OnW^NH8
ojNjiP;oYk[W1OnW[md8ojRag`CoZ;GR1?nY[=P7ojV]fPCoZK7N1?n^[]P8oj^]f@CoZ[7M1?n`/=P8
ojb_fP03oj^dh?n`/MWo/;7I00Go/;7I1on//mh00onb/mWo[KCNojfdgP06ojfdgPCoZK[U1?n]]Mh9
ojVkiP;oY[k[00?oZ;cXo`000?l000000_nX_>P8ojJoj`03ojW1jonW`>_oYl3[00GoYl3[1_nY`>X2
ojW1jaKooooo00?o0000ooooooooool0<_ooool002?ooooo0_l0001Rooooo`WoYkWV1_nW^^H00onW
[McoYjoMojN_g@06ojN_g@SoZ;7O00?oZ;GRojV/f?nY[=P01?nY[=P8ojV]fP03ojVag_n^[]So[ZkH
00Go[ZkH2?n[[MT00onZ/Mgo/;3Hok2`f005ok2`f0Ko[:oJ00?o/k?Iok2afOn`/MT01on`/MT4ojbc
gPCo/[?I2?n]]=h00onY^^Go[KGNojfegP05ojfegPOoZK_V00Ko[KSQo`000?l0003o0000ojRlj?l0
0003ojRlj0KoY[o[00?oYkgYojO0jonW`>/01onW`>/2ojW0jPKoZL7[5_ooool00ol0003ooooooooo
o`0aooooo`008?ooool3o`0006;ooooo2onW^NH4ojNjiPCoYjgL2?nW[md6ojRag`03ojZ[f?nY[=So
ZJcH00KoZJcH1_nY[MX00on^[mWo[ZkHojj^f006ojj^f0OoZjgI00?o/K?Jok2`f?n`/=P01_n`/=P4
ojb_fPCo/k?I2On`/MT00on//mko/[?Iok:cf@05ok:cf@Ko[KCN00?o];GIojfeg_n]]Mh01_n]]Mh4
ojVkiP05ojfhhOl0003o0000o`000?n]^>401?nX_>P01?l0003oZ;cXojRlj?nX_>P2ojJoj`GoYkgY
1onW`>/00onV_n_oZL7[ojW1j`06ojW1jaOooooo00?o0000ooooooooool0<?ooool001oooooo0_l0
001Rooooo`koYkWV00?oYk[VojN]g?nW[M`01OnW[M`8ojN_g@;oZ;7O1OnZZmP7ojV/f0CoZJgJ1?n^
[mT8ojj^f0CoZjgI1?na/mX8ok2`f003ojb_f_nc/mWo/k?I00Go/k?I1on`/MT00one]m[o/[?Iok:c
f@06ok:cf@Co[KCN1?nd]MT8ojfegP04ojVki_l0003o0000o`0000Go[KSQ1?nX_>P00ol0003oZ;cX
ojbki008ojNmj@CoYl3[1?nV_n/8ojW1jaKooooo00?o0000ooooooooool0<?ooool001oooooo00?o
0000ooooool00000Goooool?ojNiiP03ojJ]g?nW[McoYjgL00KoYjgL1onW[md00onYZmWoZZ_HojZ[
f006ojZ[f0OoZJcH00?oZJgJojj_fOn^[mT01On^[mT8ojj^f003oj^]fOna/m[o/K?J00Go/K?J1_n`
/=P00onc^=go/k?Iok>cf@06ok>cf@Co/;7I1One]mX8ok:cf@03ojfdg_nd]MWo];GI00Go];GI1On]
]Mh3o`0000Wo[KSQ0_nX_>P2ojbki003o`000?n/^nCo[;_T00SoYkgY00?oYl3[ojJojonV_n/01OnV
_n/6ojW1j`03ojO0jooooooooooo01Gooooo00?o0000ooooooooool0;oooool000cooooo1Ol00003
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool01?l0003oooooooooool0001Kooooo`ooYkWV
1OnV[M`8ojN]g0CoYjoM1?nYZmT7ojZ[f0KoZJcH00?o[K;Kojj_fOn^[mT01_n^[mT7ojj^f003ok2g
g_na/m[o/K?J00Ko/K?J1?n`/=P4ok>hg@So/k?I00?o/;7IokFgf_ne]mX01_ne]mX6ok:cf@03okNi
fond]MWo];GI00Ko];GI0_n]]Mh3o`0000?o];KJ2?n]^>400onc]mco[;_Tojbki002ojbki004o`00
0?n/^nCo[;_Tojbki0KoYkgY00?oZ[gWojJojonV_n/01onV_n/2ojW1j`GoYl3[5oooool00ol0003o
ooooooooo`0^ooooo`003?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`06ooooo`;o00000_ooool00ol0003oooooooooo`1Eooooo`;oYk[W3OnW^NH00onU
[=coYZgLojJ]g006ojJ]g0SoYjgL00?oYjoMojV[fOnYZmT01?nYZmT8ojZ[f0;oZJcH1On]/]/8ojj_
f@Co[ZkH1?n`]mh8ok6cfP03ok2`f?nc^=go/kSM00Go/kSM1_nc/mT00ond_N7o]KOJokFgfP07okFg
fPCo/[?I1?ng^M/6okBef@?o00001ond]]X4ojfhh@Go/kOL1?n/^n@01?l0003o[;_Tojbki?n/^n@2
ojNmj@GoZ[gW1onV_n/00onX_^WoYl3[ojO0j`06ojO0jaKooooo00?o0000ooooooooool0;_ooool0
00Cooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4005
ooooo`;o00001?ooool00ol0003oooooooooo`1Aooooo`KoYk[W2OnW^NH5ojF/g0SoYZgL1_nW[M`0
0onXZmWoZJ_IojV[f@06ojV[f@KoZZ_H00?o[;COojfbfon]/]/01_n]/]/8ojj_f@03ojj^f?n`]mko
/;ON00Go/;ON1_na/mX00ona`^Ko/kSMok>hg@06ok>hg@Co/k?I1?nd_N49okFgfP03ok:cfOng^M_o
]kWK00Go]kWK0_nd]MT3o`000003okBefOnh^]_o];KJ00So];KJ00?o[KSQok>gg?nc]m`01Onc]m`5
ojbki003o`000?n/^nCo/;SO00SoZ[gW1?nV_n/4ojRnj@SoYl3[5_ooool00ol0003oooooooooo`0]
ooooo`003_ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?ooooooooooooooool000001Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo04gooooo0_nW_>P8ojNji`KoYkWV00?oYJgM
ojF/g?nU[=`01OnU[=`8ojJ]g0;oYjgL1OnXZmT7ojV[f@CoZZ_H1?n/]=l8ojfbf`Ko[ZoI00?o[kkU
ok2gg_n`]mh01_n`]mh4ok6cfPCo/L;V2?nc^=d00onc/mWo];gQokBmh@05okBmh@Oo]KOJ00?o]L7S
okNifong^M/01_ng^M/2o`0000;o];GI1?nh^]/7okBffP03okVkf_nc]mco/kOL00Ko/kOL1?n/^n@0
0on`^=oo0000ok2hg`02ok2hg`SoZ[gW00?oY[o[ojRnjOnX_^T01OnX_^T6ojO0j`03ojJojooooooo
oooo01Gooooo00?o0000ooooooooool0;?ooool000oooooo00?oMgMgofIVI_ooool00_ooool01Ol0
003ooooooooooooooooo000000Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`19
ooooo`KoYkcX2?nW^^L2ojNiiPGoYJgM1onU[=`6ojJ]g003ojJ[f_nXZmWoZ:_I00KoZ:_I1onYZmT0
0onZZmSo[;COojbdg`05ojbdg`So[K;K0_n^[mT5ojnni@So/;ON00?o/K?Jok72i_na`^H01Ona`^H6
ok>hg@03ok3=kond_N7o];gQ00Oo];gQ1?ne]mX4okG1h`Co]kWK0ol000000ong^M_o];GIokRjf`06
okRjf`Go];KJ0oni^mX8ok>gg003ojbki?n`^=oo/;SO00;o/;SO00Co0000ok2hgon`^=oo/;SO1_nZ
_NL00on^_>CoZ;kYojRnj@07ojRnj@;oYl3[1OnV_n/Eooooo`;o0000;_ooool0013ooooo00Go0000
oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00?ooooo0_l00007ooooo`03o`000?oo
oooooooo04Kooooo00?oYkgYojNlj?nW_>P01_nW_>P6ojNji`03ojB^g_nU[MgoYJgM00KoYJgM1onU
[=`2ojJ]g0GoYZ_J1onXZmT6ojV[f@03oj^gh_n/]=oo[;CO00Ko[;CO1on]/]/00on]b>ko[kkUojnn
i@06ojnni@Ko/;ON00?o[=7cok72i_na`^H01_na`^H4ok>hg@Co/<g_2Ond_N400one]m[o]L7SokG1
h`05okG1h`?o00000ong^M/00onf`^?o^;[KokRjf`06okRjf`?o];KJ1_ni^mX6ok>gg003okZkf_n`
^=oo/;SO00Co/;SO00Co0000ok2hgon`^=oo/;SO0_nZ_NL5ojjli0OoZ;kY00?oZ[kXojJojonV_n/0
1_nV_n/Fooooo`03o`000?oooooooooo02_ooooo000<ooooo`05o`000?nj^[[ooooooiRHV?l@4100
0oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`12ooooo`GoYkgY2?nW_>P2ojNji`GoY:kN1onU[Md6ojF/g003ojF[fonVZm[oYZ_J00Go
YZ_J2?nXZmT2ojV[f@GoZkOR2?n/]=l4ojfbf`Co[LS^2?n__^D2ok2ggPGo[=7c2?na`^H00onc^=go
/<g_ok3=k`05ok3=k`Oo];gQ00?o[=CeokG1hone`N<00one`N<3o`0000Co]kWK1?nf`^<8okRjf`03
okBff_ni^m[o^K_J00Go^K_J1?nc]m`4okZkfPKo/;SO00?o0000ok2hgong^m`02?n^_>@4ojRnj@Co
Z[kX2?nV_n/Eooooo`03o`000?oooooooooo02_ooooo000<ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0nooooo`;oZ;oZ1onW_NT6ojNlj003ojB`hOnT[]koY:kN00KoY:kN1onU[Md2ojF/
g0GoYJ_K1onVZmX6ojR[f@03ojVii?n[]n;oZkOR00KoZkOR2?n/]=l00on]/]_o[LS^ojg8kP05ojg8
kPKo[kkU0_nOfo`7ojcAl`Ko/L;V0_nNfO`8ok3=k`Co];gQ1?n/e?D01?ne`N?o0000o`000?l00004
okG1h`03okNifonf`^?o]/;S00Go]/;S1_nh^]/00onh`N;o^K_JokVkfP07okVkfP03ok>gg?nj^m[o
^[_J00Go^[_J1?n`^=l00ong^mco0000okNkg002okNkg0So[[cT00?oZ;kYojZnj?nZ_^P01OnZ_^P6
ojJoj`03ojNojooooooooooo01Cooooo00?o0000ooooooooool0:_ooool001kooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0jooooo`KoZ;oZ1onW_NT2ojNlj0GoY;3Q1onT[]h6ojF]
g@03oj>YfonUZm_oYJ_K00GoYJ_K1onVZmX4ojR[f@CoZKWT2?n[]n86ojbdg`;oZ=;f2?n]b>h2ojnn
i@KoWm_l1on/dO<2ok72iPKoW]Wl2?n`cNl00ond_N7o[=CeojcDm@02ojcDm@?o00001_ne`N<00onY
eOOo]/;SokK2h`06okK2h`Co^;[K1?nh`N87okVkfP03ok[0gonj^m[o^[_J00Oo^[_J00?o/;SOokNk
g?ng^m`00_ng^m`00ol0003o]k_LokNkg006ojjli0;o/[_P2OnZ_^P2ojJoj`GoYko[5_ooool00ol0
003oooooooooo`0Yooooo`007Oooool3o`0000_ooooo00?o0000ooooooooool0=_ooool2ojS0j`So
Z;oZ1OnW_NT00onU]>?oY;3QojB`h@06ojB`h@OoY:kN0_nU[Md5oj>Yf`OoYJ_K1onVZmX00onXZmWo
ZKWTojVii005ojVii0SoZkOR0_n/]=l6ojSBmPKo[LS^0_n=g?l8oioKo0?o[=7c1On2f?l7oikIo0Co
/<g_1?n;e_l01?n/e?Go0000o`000?l00003ojcDm@Co]L7S1?nYeOL8okK2h`03okRjfonh`N;o^<7R
00Go^<7R1Oni^mX3ok[0g`Oo^[_J00?o_;oLokNkg?ng^m`01?ng^m`00ol0003o]k_LokNkg002ojjl
i0Ko/[_P1onZ_^P00on]_^KoYko[ojNoj`05ojNojaKooooo00?o0000ooooooooool0:Oooool001go
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0booooo`KoZ<3[2?nX_nX00onW_NWo
YKCSojFdh`03ojFdh`SoY;3Q1OnT[]h00onRZ=_oXjWKoj>Yf`06oj>Yf`KoYJ_K1_nVZmX2ojRjiPSo
ZKWT1_n[]n82ojCHnPSoZ=;f0_n]b>h6ohgLo`KoWm_l0omee_`7oh;Ho`?oW]Wl1Om_d?d4oh_Fo`?o
00001on/e?D00one`N?oZMGgojWEm`05ojWEm`Ko]/;S00?oZm?eokS1h_nh`N801_nh`N83okVkfPKo
^/3O1Onj^mX3okbog0Ko]k_L00?o0000okbnfonb^n001onb^n04ojZnj0Go[KkV1onW_n/Fooooo`03
o`000?oooooooooo02Sooooo000Mooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
;oooool00onX`NcoZ<3[ojS0j`06ojS0j`KoZ;oZ00?oYKOVojFdhonU]><01OnU]><8ojB`h@03ojB^
g_nRZ=_oXZSK00?oXZSK1onSZM/7ojF[f`;oYZ_J1_nX^^H8ojVii0;oZkOR1_nTf?X6ojSBmP?oQ]gm
1on=g?l2oioKo0OoMMKl0on2f?l5ofS=o0OoKm3m0ol00004oh_Fo`?o[=Ce1Omnd?l7ojWEm`;o]/;S
1On[doD8okS1hP03okVkf_nj`=oo^/3O00Go^/3O0onj^mX6okbog0Go]k_L00?o0000okbnfonl_]/0
2?nb^n000onZ_^So[KkVojfniP05ojfniPKoYko[00?oZ;oZooooooooool05Oooool00ol0003ooooo
ooooo`0Wooooo`007Oooool2o`0000oooooo00?o0000ooooooooool0:oooool5ojS1k0SoZ<3[0_nX
_nX5ojFgiPOoYKCS1_nT/>400onPYm_oXZSKoj:Xf`05oj:Xf`OoXjWK1OnUZm/2ojNji`SoZ;[V1_nY
^N@3oj3Lo0OoY=Sj0_nXd_H7ohKMo@?oSMco1_mde_`4ogGFo0CoN<go2?mXcO`3ofo@o@;o00000omW
aOh6ofG9o0OoO]3o0onYeOL4ogc<o`OoZm?e1_nh`N800on`co3o^/3Ook[0g`07ok[0g`03okZkf_nl
_mco_;oL00Go_;oL0ong^m`3okbnf`03o`000?nl_]_o_;kK00Ko/[_P00?o^;gNojfni_n]_^H01on]
_^H2ojNoj`GoZ;oZ5_ooool00ol0003oooooooooo`0Wooooo`007Oooool00ol0003oooooooooo`0?
ooooo`;o0000:?ooool2ojO0j`OoZ<7/1_nX`>/2ojJjj0OoYKOV1onU]><2ojB`h@GoX:OK1_nRZ=/8
oj>Yf`03ojF[fonW^^OoYk[W00CoYk[W2?nX^^H2ojVii0OoX=cl0onTf?X6ohGOo0?oQ]gm1_mlf?d4
ogCFo0GoRlWl1omhcOl3ofS=o0?oP/;l0ol00006ofO5oPKoILWl0omnd?l5of33o@KoO<co1on[doD2
okS1hPGo/<o`1onj`=l00onfb>Oo_;oLokbog007okbog003okNkg?nl_]_o_;kK00?o_;kK00?o0000
okbnfonb^n000onb^n04okRmgPOo[KkV00?o/;kTojRoj_nX_nX01_nX_nXFooooo`03o`000?oooooo
oooo02Kooooo000Mooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool08_ooool6ojO0
j`OoZ<7/0_nX`>/6ojJjj0KoYKOV1_nU]><00onOYmcoX:OKoj2Wf`05oj2Wf`OoXZSK1_nSZM/00onU
^>KoYk[WojNji`06ojNji`KoZ;[V0onNgOd6oj3Lo0?oR>7l1_n5go`3oh[Io`OoO=Sm0_nHa?H8oh_9
o0?oN<go1OnH_o<01?n2`_co0000o`000?l00003oh;2o0?oIlGn1On8^oL6ofVooPOoH<?m1_mlc?l3
oj_Cm@CoPlco1on`co04ok[0g`Co]/SW1onl_m`00onj`n7o_;kKokbnf`05okbnf`03o`000?nl_]_o
/[_P00Oo^;gN1?n]_^H4ok2ni0SoZ;oZ5_ooool00ol0003oooooooooo`0Uooooo`007Oooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo01kooooo0_nW_^/8ojO0j`GoZ<7/0_nW_NT8ojJj
j0KoYKOV0_nU]><5oinWg0OoX:OK1onRZ=/2oj>Yf`GoYKSV2?nW^^L2ojRjiPOoW]gm0_nPg?`8ohSQ
o003ohGOo?n:fOooR]Wo00KoR]Wo0_mlf?d6oiS4mPKoRlWl0_nS^n/5oiRol`?o00000on2`_`4oink
k0SoR;_g1_mY_oh3of33o@CoIkWm1_mO_od7oh?<o`Oo/<o`00?o^/3OokK8ionfb>L01Onfb>L4okbo
g0Co^/?Q1_nl_]/00ol0003o_L7MokRmgP08okRmgP03ojfni_n`_^Co/;kT00Go/;kT1_nX_nX00onZ
_nWoooooooooo`0Dooooo`;o00009_ooool001cooooo0ol0000Dooooo`03o`000?oooooooooo01[o
oooo1_nW_^/8ojO0j`03ojS1k?nW_NWoYkgY00CoYkgY2?nV^^P3ojFgiP;oX:WM1onOYm`7oj2Wf`Ko
XZSK00?oY;CTojFhi_nU^>H01_nU^>H6ojNji`?oX=kl1_nNgOd4ohgTn`CoR>7l1_nEfOh3oh[Io`Co
X/?`2?nHa?H2oh_9o0KoXk_[00CoV;oco`000?l0003o00000_nH_o<00onV]nGoWk_/oinkk006oink
k0KoR;_g00?oX[WYohZimOn:^OD01_n:^OD6ofNio@KoGkom1on3c?l3ok3?l0?oU<gk2Onfb>L00onl
_mco^/?Qok[3h@05ok[3h@Go_;kK00?o_L7Mo`000?nm`Md01onh_Mh00onl`Mgo/;kTok2ni007ok2n
i0;oZ;oZ1OnZ_nTDooooo`03o`000?oooooo000002Kooooo000Looooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool05oooool9ojNnj`KoYl3[00?oZ<3[ojNmjOnW_NT01_nW_NT6ojJjj003
oj:^h?nPZMgoX:WM00CoX:WM1onOYm`7oj2Wf`;oXZSK1OnT]>@8ojFhiP;oYk[W2?nPg_`00onNgOgo
SNCkohgTn`05ohgTn`?oWMWl1_nEfOh00onU`>goX/?`oj;3l006oj;3l0KoV<Cf00?oY[SVoj>kjonS
^n/01?nS^n/3o`0000;oV;oc1OnV]nD8oinkk0;oR;_g1OnR^NT8ohZim@KoIkWm1_mO_od3oh?<o`Co
I;km1_nDcO/7okK8i`03ojW>lonj`n7o^/?Q00Ko^/?Q0onl_]/4okg1g@03o`000?nm`Mgo^;gN00?o
^;gN1?nl`Md7ok2ni003okBohonZ_nWoZ[oY00KoZ[oY5_ooool00ol0003oooooooooo`0Sooooo`00
2_ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h6ooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool04oooool=ojNnj`;oYl3[1OnX`>/8ojNmj@;oY[[X1OnR[^06
oj2Yg@KoWjOL1_nPYm/2oj:`hPOoY;CT1_nU^>H3oj?Mn`OoX=kl1?nDi_/2ohgTn`OoWMWl0_nEfOh5
ojG0k@SoX/?`0_nHa?H5ojJhiP;oXk_[0ol00002oj>kj`03ojZfhOnV]nGoY[OU00KoY[OU1_nO^n`0
0onY]n;oX[WYoj:ij@06oj:ij@KoR[We0_nR^NT7ohFgm@KoG[Gl1_mT__d6oiC=n`Co]/SW1?nYc_<8
ok[3h@03okbnfonm`Mgo_L7M00?o_L7M00Co0000okg1gOnm`Mgo^;gN1onl`Md4ok2ni0Co];oS2?nZ
_nTEooooo`03o`000?oooooooooo02?ooooo000<ooooo`03o`000?oooooooooo00;ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool03ooo
ool2ojNoj`goYkk[0_nX`N`7ojS0j`KoYkgY00?oXkCUoj:^h?nR[^001OnR[^07oj2Yg@KoWjOL0_nP
Ym/6oj:`hPOoY;CT0_nU^>H8oj?Mn`;oX=kl1_nDi_/3oj;Jn`KoWMWl0_nV_n/7ojG0k@KoX/?`00?o
YkGSojJhi_nV^>H01?nV^>H3o`0000?oXk_[1?nZ]^48ojJgi@;oWk_/1OnY]n88oj:ij@;oR[We1_nR
^NT7ohFgm@KoG[Gl1_mT__d6oiC=n`03okK8ionYc_?oZLkc00GoZLkc1_nj`n400onfanOo_L7Mokg1
g@05okg1g@03o`000?nla=oo_<7M00So_<7M00?o/;kTokBohond_n<01Ond_n<6ojZoj@03ojc0j?oo
oooooooo01Cooooo00?o0000ooooooooool08_ooool00003ooooool0003o000000Co00001Oooool0
0ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool2o`0001Wooooo00?o
0000ooooooooool02oooool6ojNoj`WoYkk[1_nX`N`7ojS0j`;oYkgY1OnS]>D7oj:^h0OoX:WM0onO
Ym`3oin/h0SoX[3R1OnT]>@3ojCHnPOoXmgk1?nJj?/2oiCVn`SoX][k00?oWMWlojJojonV_n/01?nV
_n/7ojG0k@;oX/?`1OnW]N<3ojJhiP;o00000onV^>H00onS^n_oZ[KQojZfh@05ojZfh@KoY[OU00?o
[[WQojVgh_nY]n801_nY]n86oj:ij@03ojbhh_nR^NWoX[WY00OoX[WY0on5]oD4oijjk0OoN;;g1OmJ
/o/6og;0oPOoZLkc1?nj`n44okK7i`Ko_L7M00?o_<COo`000?nla=l01onl`Md00ono`mgo];oSokBo
h`07okBoh`;oZ[oY1On/`>PFooooo`03o`000?oooooooooo027ooooo000<ooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool02?ooool2ojO0j`OoYko[1_nW_^/00onW`>_oZ<7/ojS1k006ojS1k0GoZ<3[00?o
YKWWoj>diOnS]>D01_nS]>D6oj:^h0KoX:WM00?oWJWNoin/h?nO[>001OnO[>08oj:`hP03ojBdi?nT
f?[oY=Sj00KoY=Sj0_nSgO/6oi[Xn`?oY]kk1onRf_/00onW_n_oY[o[ojJoj`06ojJoj`GoYL3]0_nX
]>86ojNeh`?o00001?nV^>H00on/]n7oZ[KQojZfh@06ojZfh@CoY[OU1?n^^N48ojVghP;oX[WY1On/
^>87oj:ij@03ojbihonN^^coW[[/00KoW[[/1omh/_L5oeZcn`KoL/3n1onYc_<00onj`n7o]/OWokK7
i`05okK7i`?o_L7M1?nla=l00ol0003o_<COokc1g@04okc1g@?o_l?M1ond_n<00onh`^;o[<3Xojc0
j006ojc0j1Gooooo00?o0000ooooooooool08Oooool000cooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`05ooooo`GoYl3[1onW_n/2ojNnj`GoYl3[2?nX`N`00onX`>_oYKWWojFii`03ojFii`SoXkCU1_nR
[^02oj2Yg@GoWJWN1onO[>06oj:`hP;oYM7g1onTf?X4oj7Yn`;oV^Sk2?nVg_/2oj;Jn`GoYko[2?nV
_n/00onU`>goZ;CRojRdhP04ojRdhP;oYkGS0ol00002ojNeh`;oY[SV1On/]n48ojZfh@03ojJgiOn^
^N7o[[WQ00Go[[WQ1_nY]n800on`_>?o[;SRojbhhP06ojbhhPCoX[WY1?n/^N<8oijjk0?oN;;g0onC
^?04ofJ^n@;oF[?k1_mb`?h3ojW>l`CoSlKj2?nfanL00onm`Mgo_<COokc4g`03okc4g`03o`000?nl
a=oo_<7M00;o_<7M1Ono`md4okBoh`Go^<;R1_n/`>P00on^`NSoooooooooo`0Dooooo`03o`000?oo
oooooooo023ooooo000<ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4005ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool00_ooool8ojO0j`GoYko[0_nV
_^/7ojO0j`KoZ<7/0_nV_NT6ojFii`SoXkCU0onR[^02oi^VgPSoWJWN1onO[>02oj:`hPKoYM7g1?nT
f?X6oj7Yn`?oZN?j1_nVg_/00onX`NcoYko[ojNoj`06ojNoj`KoY[o[00?oZ;CQojRdh_nX]>801?nX
]>83o`0000CoYkGS0_n[^N<7ojbgh@KoZ[KQ00?o[[gTojjihOn^^N401_n^^N44ojVghPCo/;cS2?n/
^>800onR^NWo[;WSojbih`05ojbih`KoW[[/00?oZK[Uoi>hl?nC^?001OnC^?07ofJ^n@KoHKCl1_n?
a_X6okK7i`03ojg:konla=oo_<CO00Go_<CO00?o0000okc4gonl`Md01ono`md00ond_n?o^<;RokS2
hP05okS2hPCo[<3X1?n^`NPFooooo`03o`000?oooooooooo01oooooo000<ooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o00007_ooool00ol0003oooooojS1
j`02ojS1j`SoYl3[00?oYko[ojJnjonV_^/01?nV_^/7ojO0j`;oZ<7/1_nV_NT6ojFii`KoXkCU1onK
Y]h7oifYgPKoWjcP0onTa_47ojGAm`03ojCHn_nQjO_oXNWk00CoXNWk1_nYhoX2ojKNn`GoZ<7/2?nW
_n/2ojJoj`GoZ;CQ0_nX]>83o`0000?oZ;CR00?oYkGSoj^ihon[^N<01?n[^N<7ojbgh@;oZ[KQ1On^
_N@8ojjih@03ojVgh_n`_>?o/;cS00Go/;cS1_n/^>800ona_^?o[;WSojbih`07ojbih`;oW[[/1OnY
^^D7oi>hl0OoIZki1_mQ]?`6oho6nP;o]/OW1On]b^l7okc4g`03o`000?no`mgo_l?M00Go_l?M00?o
_lGNokS2h_nh`^801onh`^800on/`>So[/7Xojk1j005ojk1j1Gooooo00?o0000ooooooooool07ooo
ool000[ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o
0000ooooooooool07?ooool7ojS1j`KoYl3[0_nW_n/7ojJnj`GoYl3[0_nX`>/8ojJmj@KoYKWW0_nS
]>D;oi^VgPOoWJWN0_nO[>07ojC6l@GoYM7g1?nWj?X2oj7Yn`OoZN?j0_nZaNd7ojS1k0KoYko[00?o
Yk?RojRdhOnX]>401?nX]>43o`0000GoZ;CR00?oZ[[Uoj^ihon[^N<01_n[^N<5ojbgh@03oj^mion^
_NCo[[gT00Ko[[gT1_n^^N400on^_nKo/;cSok2lh`07ok2lh`;o[;SR1Ona_^<7ojbih`03ok:nhonY
^^GoZK[U00KoZK[U1OnC^?000onR^^[oO;7eogbam@05ogbam@KoG:cj1omg^_/7ojg:k`Co_<CO0onj
aN<00ol0003o_l?Moko3g@03oko3g@?o_lGN1onh`^82ok[4hPSo[/7X5Oooool00ol0003ooooooooo
o`0Nooooo`006oooool00ol0003oooooooooo`0Jooooo`[oZ<7[0_nW`>/6ojNoj`OoY[k[00?oYl3[
ojS0jonX`>/01?nX`>/8ojJmj@?oYKWW0_nN[N4>oi^VgPGoWJWN0onR^NT8ojC6l@03ojGAmonWj?[o
YnSj00GoYnSj1?n/jOT2ojWSnPKoZ/G]1onX`N`2ojNoj`GoYk?R0_nX]>43o`0000?oZ;CQ0_nX]>85
ojZji@SoZkWS00?o[;OQoj^mion[_NL00on[_NL8ojjmi0;o[[WQ1On^_nH7ok2lh`03ojjoiona_^?o
/KkS00Ko/KkS1?n/^N<4ok:nh`SoZK[U00?oTkS`oj:jj_nR^^X00onR^^X7ogbam@KoG:cj1omg^_/7
ojg:k`03okc4gonjaN?o^/GS00?o^/GS00Co0000oko3gOno`mgo_l?M1_noaMh4okS2hPGo^/CR1_n^
`NP00on_`^Soooooooooo`0Dooooo`03o`000?oooooooooo01gooooo000Kooooo`03o`000?oooooo
oooo01Oooooo3?nX`N/2ojO0j`SoYko[1OnV_^/2ojS1k0OoZ<3[1_nV_NT00onR]NKoWZgQoij]h@04
oij]h@koVjKN00?oWJWNoj:ijOnR^NT01OnR^NT6ojC6l@CoZnGj0_nWj?X7ojcYn@03ojg;konZaNgo
Z/G]00KoZ/G]1OnX`N`00onV/n;oYk?RojNchP04ojNchP?o00001OnX]>400onY^^KoZ[[UojZji@06
ojZji@KoZkWS00?oZKkXoj^mion[_NL01On[_NL6ojjmi003ojZnj?n^_nKo[[oV00Ko[[oV1?n`_><4
ojjoi`So/KkS00?o[;WSok:nhonb_^<01Onb_^<6ojVji@03ok2mhonR^^[oX[[Z00GoX[[Z1oml/OD6
oeb/nPOoMk[k0on]b^l3oik5l`Oo^/GS00?o0000oko3gOnoaMh01onoaMh00onh`^;o^/CRok[4hP06
ok[4hP;o[/7X1On_`^PDooooo`;o00007oooool001_ooooo0_l0000Fooooo`?oZ<3[2?nX`N/6ojO0
j`SoYko[00?oY[k[ojS1k?nX`N`01?nX`N`7ojS0j`;oY[gY1OnR]NH6oij]h@[oVjKN0onN/>@9oj:i
j@;oY<Ka1_n[iOX3ojo/n0Go[>Wi1?n]bnl8oj[5k@03ojS1k?nV/n;oY[?R00?oY[?R0onW/n82o`00
00?oYk?R0_nX]>45ojVjiPSoZ[[U0_n[^N<5ojVnj0OoZkgW0_n^_N@5ojZnj0So[[oV00?o/;cSojjo
ion^_nL01On^_nL6ok6nh`03ojo0i_nb_^?o/[kS00Oo/[kS0_nY^^D5ok2mh`OoX[[Z0oml/OD4ohnf
l@KoH:Wh1_m[/OX7oik5l`Ko^/GS00?o]lKUo`000?noaMh01_noaMh00onoa]oo^/CRok[4hP06ok[4
hP03okc6h_n_`^So[l;X00Go[l;X5_ooool00ol0003oooooooooo`0Looooo`006_ooool00ol0003o
ooooooooo`0Cooooo`OoZ<3[1OnX`N/2ojS0j`OoYl3[1_nW_n/00onV_n_oZ<7/ojS1k006ojS1k0Go
Z<3[0_nT^^T7oj:eiPKoWZgQ1OnKY]h00onJZN7oW[3Toij`i005oij`i0OoX[WY0on]g_P4oj_UnPOo
[nch00?o[>Wiojg;kon]bnl01On]bnl6oj[5k@03ojJehonV/n;oY[?R00CoY[?R0ol00004ojNchP03
ojNji_nY^^KoZK[V00KoZK[V1_nZ^^D00onX_^WoZKkXojVnj006ojVnj0GoZkgW0_nY_nT7ojZnj0Ko
[[oV00?oZ[oYojjoion^_nL01on^_nL2ok6nh`Go[l3V1onb_^<00onb`NGo/;gSok2mh`05ok2mh`Ko
X[[Z0_nZ_>L7ohnfl@KoH:Wh1_m[/OX6oik5l`Co^/GS1?nga^D00ol0003o_lGNoko5gP03oko5gP?o
_lKO1_nja>83okc6hPOo[l;X5Oooool00ol0003oooooooooo`0Looooo`006_ooool00ol0003ooooo
ooooo`0?ooooo`CoYko[2?nX`>/00onX`N_oZ<3[ojS0j`04ojS0j`OoYl3[0_nW_n/5ojJoj`SoZ<7/
00?oZ<3[ojBjjOnT^^T01?nT^^T6oj:eiPOoWZgQ00?oVjKNoiZYhOnJZN400onJZN47oij`i0CoX[WY
1on]g_P00on[iO[o[nchojo/n005ojo/n0;o/mKb2?n]bnl2oj[5k@GoY[GS0_nV/n83o`0000;oY[?R
0_nW/n85ojNjiPSoZK[V0_nZ^^D5ojRnj@SoZKkX00?oZkgWojVojOnY_nT01?nY_nT7ojZnj0;o[[oV
1OnZ_nT7ojjoi`03ojZojOn_`>Ko[l3V00Ko[l3V1?nb_^<4ok;1i@Oo/;gS0_nR^^X6ojZli`OoSkKa
1_mPZOP5of^anPOoW/Gc00?o^/GSokO6iOnga^D01?nga^D01?l0003o_lGNoko5g_noaMh6oko6g`?o
^/CR1Onla^86ojo2j0;o[l?X5Oooool00ol0003oooooooooo`0Kooooo`006_ooool00ol0003ooooo
ooooo`0;ooooo`WoYko[1_nX`>/00onX`N_oZ<3[ojS0j`06ojS0j`GoYl3[0_nV_^/7ojJoj`KoZ<7/
0_nW_n/7ojBjj@KoX[GV0onN[N43oiRVh0OoVZWQ1onN/>@00onR^NWo[MkhojgNn006ojgNn0Co/^_g
0_n_k?P6ok?FlPKo[L__00?oYkSUojJehonV]N<01?nV]N<3o`0000CoY[?R0_nV^>H7ojNjiPKoZK[V
2OnX_^T6ojVnj003ojRnjOnY_nWoZKoY00KoZKoY1OnZ_^P00onY_nWoZ[oYojZoj@06ojZoj@Co[[oW
1?nZ_nT8ojo0iP03ok:nhonb`NGo//7U00Go//7U1On`_N<00ond`NCoZ[cWojZli`07ojZli`?oSkKa
1?nL^nh6ofbXm@?oI:_h0_m[/OX3oik5l`CoT;kf1onga^D00ol0003o_lGNoko6g`07oko6g`03ok[4
h_nla^;o_<KR00Go_<KR0_n_`^P6ojo3j1Gooooo00?o0000ooooooooool01_ooool5o`0000oooooo
000Jooooo`;o00002Oooool=ojNoj`;oZ<3[1OnX`N/8ojS0j`03ojO0jonV_^_oY[k[00CoY[k[1onV
_n/2ojS1k0KoYko[1onT^^T3oj:eiP;oUjKP1onHY^07oiZYh@GoW[3T0onXco@5ojgNn0Go/^_g0onh
h_@7ok?FlP;o[L__1OnW^>D2ojJeh`?o00000onV]N<00onV/n;oY[SVojJhiP04ojJhiPOoYk[V0_nY
^^H=ojRnj@;oZKkX1OnX_^T8ojVoj@03ojZnj?nY_nWoZKoY00?oZKoY2?nZ_nT00on^_nOoZ[oYojZo
j@05ojZoj@Ko[l3V00?oZl3Yok;1iOnb`ND01onb`ND00on`_N?o]<7TokC1i003okC1i0OoZ[cW00?o
/;oUoibkk_nL^nh01_nL^nh6ofbXm@GoI:_h1on@__H6okO6i@03okC6iol0003o_lKO00Ko_lKO00?o
_lSQokc6h_nla^801Onla^800onmb>?o[l?Xojo3j007ojo3j1Cooooo00?o0000ooooooooool01_oo
ool01OnHV9So8B4Qonk^k_ooooooA4A400oooooo000Jooooo`03o`000?oooooooooo00Kooooo0_nW
`>/<ojNoj`WoZ<7[1_nX`>/3ojNoj`KoY[k[1OnV_n/3ojS1j`OoYko[1OnT^^T00onN/>CoUjKPoiNV
h004oiNVh0OoV:KP1onJZN400onN/>CoZ<odojS?m006ojS?m003ojgNn?nbjoOo/^_g00?o/^_g1_nh
h_@5ok?FlP;oZKkY1OnW^>D3o`0000GoY[GS00?oY;KVojJhi_nV^>H01_nV^>H5ojNjiP;oYkkY5_nX
_^T6ojVoj@03ojRmjOnY_nWoZKoY00GoZKoY1_nZ_nT2ojVoj@SoZ[oY0_n_`>H5oj_0j@Oo//7U00?o
[/7XokC1i?nd`N@01Ond`N@4ojZli`Co/;oU2?nL^nh6ofbXm@GoI:_h1on@__H2okO6i@Co]<KW00?o
0000okC6ionoa]l00onoa]l4oko8h@Go_<KR0onmb><7ojo3j003ojo4jOoooooooooo01?ooooo00?o
0000ooooooooool01_ooool00onHV9So8B4Qonk^kP0@ooooo`006_ooool00ol0003oooooooooo`03
ooooo`KoYl3[2?nW_n/=ojS1j`;oZ<3[1onW_n/6ojJnj`03ojJojonX`N_oZ<7[00GoZ<7[1onW_n/0
0onT^^WoW[3Toij`i003oij`i0KoUjKP1_nHY^06oiZYh@;oXKc/1onXco@4okGWm`;o/^_g2?nhh_@0
0once_;oZKkYojVnj@04ojVnj@04ojNhiOl0003o0000o`0000?oYkSU0_nV]N<5ojBfiPSoY[SV00?o
Yk[VojNnjOnW_^T01?nW_^TFojRnj@;oZKoY1OnX_NT7ojVoj@;oZ[oY1_nY_nT6ojZoj@03ojVoj_n[
`>WoZl3Y00KoZl3Y1?nb`ND4ojk1j0Oo]<7T00?oZ[cWok2oiOn`_nD01On`_nD6oibkkP03oj:lk?mh
[??oN:cc00CoN:cc1?mSY_H2ofB[n0?oT;kf0on5]_D7okC6i`03o`000?nda^Oo_lKO00Ko_lSQ0onl
a^86okg8h`Co[l?X1?n_a>TEooooo`03o`000?oooooooooo00Kooooo00?oV9RHob4Q8Oo^k^h03ooo
ool001[ooooo00?o0000ooooooooool00_nX`>/8ojO0j`OoYko[3?nX`N/3ojS0j`SoYko[0onV_^/4
ojNoj`OoZ<7[0onW_n/3oj:hj0OoW[3T1_nGY^06oiRVh0;oVZWQ1_nQ_>`4ojS?m0Ko]NOg0onkj_@6
okSRm0;o[LK/1?nY_^T3o`0000GoYkSU0_nS]>@7ojBfiPKoY[SV00?oYkgYojNnjOnW_^T01_nW_^T5
ojRnj@03ojRmjOnX_^WoZ;kY00coZ;kY00?oZ;cXojRmjOnX_NT01_nX_NT5ojVoj@;oZ;gX2?nY_nT2
ojZoj@GoZKoZ2?n[`>T00onb`NGo[/7Xojk1j004ojk1j0Ko]<7T0_nc`^D8ok2oi@;oW;_^1OnR_>`6
ogR/l`KoHjKf1_n5]_D7okC6i`03o`000?nob>7o_lSQ00Ko_lSQ00?o_<KRokg8honmb><01_nmb><0
0on_`nSo[lCYojo4j@04ojo4jAGooooo00?o0000ooooooooool01oooool00omgMgOoIVIVooooo`0>
ooooo`006Oooool00ol0003oZ<3[ojS0j`04ojS0j`SoYl3[1onW_n/8ojS1j`OoZ<3[1_nW_n/00onV
_^_oYko[ojNoj`06ojNoj`GoZ<7[0_nV_NX6oj:hj0KoW[3T1onGY^03oiRVh0CoVjoU1onQ_>`00onX
coCo]NOgokGWm`04okGWm`Ko^n[d0_nhh_@6ojg6k0?o00001?nY_^T00onW^>GoXkCToj>di004oj>d
i0OoY;KV0_nV^>H5ojNmj@SoYkkY00?oZ;kYojRmjOnX_NT00onX_NT:ojRnj@GoZ;cX2?nX_NT00onY
_nWoZ;gXojRmj004ojRmj0KoZKoY00?oZKgXojVoj_nY_nX01_nY_nX6oj_0j@;oZ/3Z1on^`NP2okC1
i0Ko/l;U1_n`_nD2ok?1i@KoX[c/1omh[?<6of>VmPKoQKKe1?nda^L3ok75j@03o`000?nob>7o_lSQ
00Co_lSQ0_nobN87okg8h`03okk:i?n_a>Wo[lCY00Ko[lCY5Oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00gooooo000Iooooo`03o`000?nX`>_oZ<3[00GoZ<3[1_nW`>/9ojNoj`So
Z<7[1onX`>/2ojNoj`GoY[k[2?nW_n/00onX`N_oY[gZojJmjP04ojJmjPKoX[SX1_nN/>@3oiNVh0?o
UZSR2?nK[nD5oj6lk0Co]=ke0_neioL7ok_Zm0?o]M?`1?n]a^`2o`000004ojg6k?nY_^WoZKkYojVn
j@?oX[;T2?nS]>@5ojBfiP03ojJmjOnW_NWoYkgY00KoYkgY1_nW_^T00onW_NWoZ;gYojRmj@05ojRm
j@KoZ;kY2OnX_>P6ojRmj@;oZ[gX1onX_NP2ojVoj@GoZKgX2?nY_nX2oj_0j@KoZ/3Z1On^`NP00on/
`NWo/l;Uok?2i@07ok?2i@;o/;oU1_nc`ND6oj:lk0?oN:cc0on0[o85ofFSl`;oHjKf1_n5]_D00ond
a^Oo/LGYok75j@03ok75j@03o`000?nob>7o_lSQ00;o_lSQ1OnobN84okg8h`Co_/[T1_n_a>T2ojo4
jQ?ooooo0ol00004ooooo`05o`000?nj^[[ooooooiRHV?l@41003oooool000kooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP06ooooo`03o`000?ooooooZ<3[00KoZ<3[0_nW`>/=ojNoj`SoZ<7[1OnX`>/2
ojNoj`OoY[k[1_nW_n/2ojS1j`OoY[gZ1_nR^>P3oij`i0;oU:GR1onFZ>88oi^_i@03oj6lk?ndg_Go
]=ke00Go]=ke1?nmjO<2ok_Zm0Oo]M?`0ol00002ojg6k003ojBfi_nR/^CoX[;T00GoX[;T2?nS]>@0
0onT]^KoY[gYojJmj@03ojJmj@SoYkgY0_nW_^T5ojNmj@OoZ;gY0_nX_^T=ojRlj0;oZ;gY1_nZ_NP5
ojRmj003oj^oj?nY_NSoZKgX00KoZKgX1_nY_nX2ojVnj@SoZ/3Z00?o[/7Xojc1jOn/`NT00on/`NT7
ok?2i@03ok72ionc`NGo/l7U00Oo/l7U0onR_>`3ojJnj`KoP:ob1_mUXo<6ogn`m0Oo/LGY00?o0000
oko8hOnobN801onobN800onmb>?o_/[Tokk:i005okk:i0;o[lCY1_n_a>XDooooo`03o`000?oooooo
oooo00;ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00?ooooo`003_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Kooooo00?o0000ooooooooool01OnX`>/3ojO0j`coYko[2_nX`N/00onX`>_oYko[ojNo
j`04ojNoj`OoY[k[0_nW_n/6ojS1j`OoY[gZ0onR^>P2oiV/i0KoU:GR1onFZ>86oi^_i@?oZL_a1?nd
g_D6okgYl`;o_n?a1?nedo03o`000003okGCl?n]a^coY;KV00CoY;KV1onR/^@6oj>di003ojJljOnV
_NWoY[gY00GoY[gY1_nW_NT00onW_^[oYkgYojNmj@06ojNmj@GoZ;gY3onX_>P2ojVoj@SoZ[gX00?o
Z;gXoj^oj?n[_nP00on[_nP8ojVmj0;oZKoZ1_nY_^T6oj[0jP03ojW0j_n/`NWo[<7Y00Go[<7Y1?nc
`^D4ok72i`Oo/l7U00?o]<?UojJnjonV_^/01OnV_^/6oh2_lPKoIJ?c1_mo/?@6ok75j@03ojk3jOl0
003o_lWR00Ko_lWR00?o_l[Rokk:i?nnb^@01Onnb^@00onmc>Go[lCZojo4jP07ojo4jQCooooo00?o
0000ooooooooool05Oooool000kooooo00Go410@oooooooooooooooooa0@4006ooooo`;o00000_oo
ool00onX`>_oYl3[ojO0j`05ojO0j`SoYko[3?nX`N/2ojS0j`OoYko[1OnV_^/3ojO0j`OoZ<7[1OnV
_NX00onP]nSoVJcToiV/i004oiV/i0KoU:GR1onFZ>82oi^_i@SoZL_a00?o]=keokgYlonmjO<01?nm
jO<4okoSl@?o00000onedo000onX_^WoY;KVojBfiP05ojBfiPOoX[;T0_nS]>@5ojJlj@OoY[gY0_nW
_NT5ojNnjPSoYkgY00?oZ;gYojRlj?nX_>P03OnX_>P6ojVoj@KoZ[gX00?oZ/7[oj^oj?n[_nP01On[
_nP6ojVmj0;oZkoX2?nY_^T2oj[0jPGoZL3Z1on/`NT00onc`^Go/L;Wok72i`05ok72i`Co/l7U1?nd
`nD7ojJnj`KoP:ob1_mUXo<6ogn`m0;o/LGY1On^`nT00ol0003o_lWRoko9hP03oko9hP?o_l[R1?nn
b^@4okg<i@Oo[lCZ00?o[/CZooooooooool04oooool00ol0003oooooooooo`0Dooooo`003_ooool0
1Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00oooool7ojO0j`SoYko[2?nX
`N/6ojS0j`OoYko[00?oY[k[ojO0jonW`>/01OnW`>/7ojS1j`03ojJmj_nP]nSoX;OX00?oX;OX1_nI
[>@6oiBUhPGoUZSR0onN]NT7ojW;l@?o_>?b0onmjO<3okoSl@?o000000?o_n?aokGCl?nedo001OnX
_^T7ojBfiPGoX[;T00?oXkWXojJljOnV_>T01_nV_>T5ojJmj@WoYkkZ1_nW_NT2ojNlj0coZ;cX0_nY
`>/8ojVoj@;oZ[gX1OnZ`N/7oj^oj0;oZKgX1_n[_nP6ojVnj@03ojZojOnY`>[oZL3Z00GoZL3Z1_n/
`NT2oj_1jPSo/L;W00?o/l7UokC3iOnd`nD01?nd`nD6ojJnj`;oZ<3[1_n4/?45ofNQl@KoOZgb1on^
`nT01?l0003o_lWRoko9h_nobN86oko:hP03okk:i?nmc>Go_LcU00Go_LcU1?n_a>X4ojk4jQCooooo
00?o0000ooooooooool05?ooool000kooooo00Go0000ooooooooooooooooo`000005ooooo`03o`00
0?oooooooooo00Gooooo1OnW`>/:ojNoj`OoZ<7[1onX`>/5ojNoj`?oY[k[1onW`>/3ojS1j`?oYKg[
1onP]nP6oiV/i0KoU:GR00?oUZSRoijejOnN]NT01OnN]NT4ojW;l@Ko_>?b00?o_NWcokoSlOl00000
0_l00003okoSl@?o/<[]1_nX_^T7ojBfiP03oj:bi?nS^NSoXkWX00?oXkWX2?nV_>T00onV_NWoYkkZ
ojNnjP0;ojNnjP;oYkgY1_nW_>P8ojRlj0KoZL3[1_nY_nT00onW`NcoZ/7[oj[1j`06oj[1j`GoZkoX
0_nZ`N/8oj^oj0;oZKkY1OnZ_nT7ojW0jP;o[<7Y1_n[`NX6ok72i`03ojo2j?nd`nGo]<?U00Ko]<?U
0_nV_^/6ojS0j`KoQ;3a1OmWXO46ogj]lPOo[/?Y00?o0000oko9h_nob^801Onob^800oo0c>?o_LcU
okg<i@07okg<i@03ojo4j_n^a>[o[/CZ00Co[/CZ5Oooool00ol0003oooooooooo`0Cooooo`003_oo
ool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool01_ooool00onW`>_oYko[
ojNoj`0<ojNoj`OoZ<7[1onX`>/00onW_n_oY[k[ojJnj`05ojJnj`GoYl3[0_nX`N/6ojFmj`KoX;OX
1onI[>@3oiBUhP?oUZ_U2?nN]NT00onYbo7o_>?bokcSlP05okcSlP?o000000?o`nS`okoSlOnoho40
1on`b^d6ojRnj@?oY;KV1?nO/nH6oj>ij0KoY[cY3OnW_^X;ojNlj0?oZ;cX1?nX`N/7ojW0j`;oZKoY
1OnW`N`8oj[1j`03oj^oj?nZ`N_oZ/7[00CoZ/7[1_n[_nP00on[`N[oZ[oYojZoj@06ojZoj@GoZL3Z
0_nY_nX8oj_1jP;o/L;W1On_`^P6okC3i@;o]LGV2?nX`>/6ohB`l@GoIj7a1_mn[O86ojk3j@03ojk2
j?l0003o_l[R00Co_l[R0oo0c><7okg<i@03okc=ion^a>[o[/CZ00Ko[/CZ5Oooool00ol0003ooooo
ooooo`0Booooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_l00008ooooo`goYko[
0_nX`>/7ojS1j`GoZ<3[0onW_n/7ojJnj`03ojO0jonX`N_oZ<7[00CoZ<7[1_nU_N/6oj2gj0?oVJcT
0onAY^<7oiJ[i@KoW[GY0onde?43okcSlP?o00001?o3j?02okoLkPSo/<[]0onX_^T:oinciPKoXkWX
0_nV_>T<ojNnjP03ojJlj?nW_>SoYkcX00_oYkcX00?oYl7/ojS1jonX`N/01_nX`N/5ojW0j`WoYl7/
1_nZ`N/2ojO1k0OoZ/7[0_n[_nP5oj_1jPSoZ[oY00?oZL3ZojVoj_nY_nX01?nY_nX6oj_1jP03oj[1
j_n_`^So[l;X00Ko[l;X0ond`nD5okG5iPKoZ<3[00?oZ<7/ohB_lOn4[o401?n4[o44ofZOk`;oIj7a
1_mn[O82ojk3j@Co[/;X00Co0000oko:h_nob^;o_l[R1_o0c><4okg<i@Co_<gW1_n^a>X00on/a>_o
ooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool00ol0003oooooooooo`08ooooo`WoYko[1_nX`>/7ojS1j`03ojS0jonW_n_oYko[00Go
Yko[1OnV_^/2ojO0j`OoZ<7[1_nU_N/3oj2gj0?oU:[U1_nAY^<7oiJ[i@?oW[GY1_nde?42o`0000Go
`nS`1Onog>h6ok3:k@03ojFjjOnO/nKoWk?V00coWk?V0onS^NP4ojJmjPWoYkkZ1OnV_>P9ojNlj0Go
Yl7/2?nX`N/00onY`>_oYl7/ojO1k00;ojO1k0;oZ/7[1_nW`N`5oj[1j`03ojO1k?n[`N[oZl7Z00Ko
Zl7Z1_nZ_nT2ojc0j@OoZKoZ0_n[`NX5oj[1jPSo[l;X00?o]<?UokG5i_neaNH01OneaNH2ojS0j`Go
Z<7/1_n4[o45ofZOk`OoOj_`1_n^`^P00ol0003o_l[Rol3<h`07ol3<h`03okg<iOnlcNOo_<gW00Go
_<gW0_n^a>X5ojc4jaGooooo00?o0000ooooooooool04Oooool001Sooooo00?o0000ooooooooool0
2Oooool8ojNoj`OoZ<3[0onX`N/4ojS0j`SoYko[00?oY[k[ojO0jonW`>/01?nW`>/7ojS1j`?oYKg[
0onN]nT6oiBZi@KoTJKS1onFZnD00onN]NWo]=CaokCDl@02okCDl@?o00001?o1hnl00oo3j?3o_mc^
okoLkP06okoLkP;o/<[]1OnU^^T<oinciP03ojFkjOnV_N[oY[gZ00KoY[gZ1OnW_^X00onW_NWoY[cX
ojJlj006ojJlj0GoYkcX0_nW_n/7ojO1k0KoZ<7[3_nW`N`2ojK0k0SoYl7/00?oZ/7[ojO1k?nW`N`0
0onW`N`8oj_1jP;oZ[oY1_n/`>T5ojVojP03oj[0j_nZ`N[oZ/7Z00KoZ/7Z1_n_`^P00on^`^Wo]LGV
okG5iP05okG5iP03okK6ionX`NcoZ<7/00GoZ<7/1_n4[o46ofZOk`OoOj_`1On^`^P00on``nSo0000
ol3<h`06ol3<h`03ol7>i?nlcNOo_<gW00Go_<gW00?o^LgYojc4jon/a>/01_n/a>/Eooooo`03o`00
0?oooooooooo013ooooo000Hooooo`03o`000?oooooooooo00[ooooo2?nW_n/5ojS0j`;oZ<7[1onX
`>/6ojNoj`03ojJojonW`>_oYl3[00KoYl3[1OnX`N/2ojBmj`KoW[OY1_nDZ^D6oi6Vh`?oUZ_U1OnQ
^^/3o`000003okCDlOo1hnoo`N?_00?o`N?_0oo6iNd6okoLkP;o[/O/1onU^^T8oinciPGoYK_Y2?nV
_NX00onW_^[oYkgYojNmj@03ojNmj@SoY[cX00?oYkcXojNojonW_n/01?nW_n/7ojO1k0;oZ<7[3_nW
`N`6ojK0k0KoYl7/00?oY/3/ojO1k?nW`N`01OnW`N`6oj_1jP;oZL7[2?n/`>T00onY_n[oZ/3Zoj[0
jP03oj[0jPSoZ/7Z0_n_`^P5ojk2j@Co]LGV1?nfa^L7ojS1k0KoQ:oa1OmZWnl8ogn[l003ojk2j?n`
`nSo/<?X00?o/<?X00?o0000ol3<hoo0c><00_o0c><4ol7>i0Co_<gW1?nicNT6ojc4j`03oj[3jooo
oooooooo01?ooooo0_l0000Aooooo`005oooool3o`0000gooooo1onW_n/00onX`>_oZ<7[ojS1j`04
ojS1j`OoZ<3[0_nW_n/5ojJoj`SoYl3[00?oZ<7[ojBmjonT_N/01?nT_N/6oijgj@KoU:[U0onAY^<3
oiJ/iPCoXK[[0ol000000onQ^^_o]=Caol7Sk`05ol7Sk`Koa^G]00?o_mc^ojk7k?n^an`01?n^an`6
ojFjj@GoWk?V0_nP]nP7ojFkj@KoY[gZ00?oYkkZojNmjOnW_NT01OnW_NT6ojJlj003ojJnj_nW_n_o
Yko[00KoYko[4_nW`N`3ojNoj`SoY/3/0_nW`N`5ojK0k0OoYl7/0_n[`NX6ojW1j`Ko[<3Y00?o[<7Y
oj[0j_nZ`>X01OnZ`>X8oj[1jPOo[/;Y00?o]LGVokK6ionfa^L01Onfa^L5ojS1k0;oY/3/1On2[?04
ofjMk@;oJYo_1?moZo03oh>ZkPKo/<?X00?o0000ok33j?o0c><01oo1c^@00onlcNOo^LgYokW=j@05
okW=j@;o[<C[1OnZ`n/Cooooo`03o`000?oooooo0000017ooooo000Gooooo`03o`000?oooooooooo
00kooooo1OnW_n/2ojS0j`OoZ<7[1OnX`>/3ojNoj`KoY[o[1_nW`>/2ojS1j`OoY;g[1_nN]nT3oiBZ
i@;oSjKU1onF[>H3o`0000?oXK[[0onjenl4ol7Sk`Koa^G]0_nnfNd7ojk7k0KoYK[Y00?oWk?Voj2g
j?nP]nP01?nP]nP7ojFkj@;oY[gZ1OnW_^X7ojNmj@;oY[cX1OnV_^X8ojNoj`goYl7/00?oYkkZojNo
jonW_n/01OnW_n/6ojK0k0;oYkkZ1onV`>`5ojO1k0;oY/3/2?nY`N/2ojc0j@Go[<7Y1onZ`>X8oj[1
jPGo[/;Y0_n^`nT8okK6i`03ojS1k?nV`>coY/3/00CoY/3/1On2[?06ofjMk@OoPj[^1_n``nP00ol0
003o`LkTol7>i005ol7>i0;o`]3U1_nicNT00onebn_oZ/?[oj[3j`06oj[3jaCooooo00?o0000oooo
ooooool03oooool001Oooooo00?o0000ooooooooool03oooool00onW_n_oZ<3[ojS0j`04ojS0j`Oo
Z<7[00?oZ<3[ojNojonW_n/01OnW_n/6ojJoj`;oYl3[1_nX`N/7ojBmj`?oW[OY0_nBZnL6ohnVi@?o
UZcV0ol000001?nF[>KoXK[[oj6jjonQ^^/7ok[Gk`03ol7Skoo6iNgoa^G]00?oa^G]1OnnfNd7ojk7
k0?oYK[Y0onM/nL7oj2gj0GoYK_Y0_nV_^/7ojNnjPGoYkgY0onU_>T6ojJnjPKoYko[0_nX`N`9ojO1
k0GoYkkZ1onW_n/2ojK0k0KoYkkZ1onV`>`00onW`NcoY/3/ojK0k004ojK0k0KoZL7[00?oZ<3[ojc1
jOn/`NT01On/`NT6oj[0jP[oZ/7Z00?o[/;Yojk3jOn^`nT01?n^`nT6okK6i`03okG7j?nV`>coY/3/
00KoY/3/1On2[?06ofjMk@KoPj[^1?n``nP3okC5i`03o`000?o1c^Co`LkT00;o`LkT1Oo2d>D3okW=
j@Co]L_[2?nZ`n/Dooooo`03o`000?oooooooooo00kooooo000Gooooo`03o`000?oooooooooo013o
oooo1onX`>/5ojS1j`?oZ<3[1onW_n/3ojJoj`CoYko[1onX`N/3ojBmj`?oW[SZ1_nBZnL5ohnVi@?o
00001OnF[>H00onQ^^_o^]O_ok[Gk`05ok[Gk`CoaN7/0_o6iNd7okkIk@?o[/O/0onR^^T7oifci`Oo
X;OX00?oYK_YojJnjonV_^/01?nV_^/7ojNnjP03ojNmjOnU_>WoYKcY00GoYKcY1_nV_^X2ojNoj`Ko
Z<7/1OnW`N`9ojNnjPGoYko[0_nX_NP8ojNnjP?oY/3/1?nW_n/7ojK0k0;oZL7[1OnX`>/7ojc1j@;o
Z/3Z3OnZ`NX8ojk3j@;o]/KW1OneanP6ojK0k003oj:nkOmlYnooO:O_00;oO:O_0_n2[?06ofjMk@Ko
Pj[^00?o/<?XokC5iondaNL01?ndaNL00ol0003o`LkTol;@i@07ol;@i@03okW=jOnebn_o]L_[00Co
]L_[1_nZ`n/00onX`Ncoooooooooo`0Cooooo`03o`000?oooooooooo00gooooo000Gooooo`;o0000
4_ooool7ojS0j`03ojS1jonX`>_oZ<3[00GoZ<3[1OnW_n/2ojJoj`OoYko[1OnX`N/2ojFnj`KoW[SZ
1_nBZnL01On?Y^Go0000o`000?l0003oSjKU00KoUZcV0onS^n/4ok[Gk`KoaN7/0_o9h^X6okkIk@;o
[/K/1_nR^^T7oifci`?oX;OX1?nU_>X7ojJnj`?oYkkZ3?nU_>T3ojJnjP_oZ<7/00?oYl7/ojNnj_nW
_^X02onW_^X00onW_n_oZ;gXojRmj004ojRmj0KoYkkZ00?oZKkYojNojonW_n/01_nW_n/5ojK0k003
ojJok?nX`>_oZ<3[00KoZ<3[1on/`NT?oj[1jPKo[/?Y0_n_a>T7okG7j0;oY/3/1OnR_^d5ogbWk`Ko
LYc[1on;[>`6okC5i`03o`000?nhb>Oo`]3U00Ko`]3U00?o`];VokG;jonebn/01_nebn/2oj[3j`Go
Z<7/5?ooool00ol0003oooooooooo`0=ooooo`005oooool00ol0003oooooooooo`0Booooo`GoZ<3[
0onX`N/7ojS0j`03ojNojonV_n_oY[o[00CoY[o[1onW_n/00onX`N_oYKk[ojFnj`04ojFnj`KoW[SZ
1?nBZnL2o`0000GoSjKU0_nF[>H7oj>kj`03ok[Gkoo5hNcoaN7/00GoaN7/1?o9h^X3okkIk@Go[/K/
1_nR^^T5oifci`;oXKSY1onU_>X7ojJnj`goYKcY00?oYl3[ojS1k?nX`N`02onX`N`2ojNoj`coYkkZ
2OnX_NP2ojNnjPGoZKkY2?nW_n/00onV`>coY[o/ojJok003ojJok0SoZ<3[1on/`NT6oj[1jP;oZ/7[
1_nZ`NX4ojk3j@Go[lCY1OneanP2okC8j@OoX[k]1OmlYnl6og:Lj`OoRjc/0ondaNL3okS8i`03o`00
0?nhb>Oo`]3U00?o`]3U1?o2d^H6okG;j`03ok78jonX`NcoZ<7/00KoZ<7/5?ooool00ol0003ooooo
ooooo`0<ooooo`005oooool00ol0003oooooooooo`0Cooooo`03ojS0jonX`N_oZ<7[00GoZ<7[1OnX
`>/2ojO0j`OoY[o[1OnW_n/3ojS1j`KoYKk[1_nN^>X3o`0000;oTZ_W0on?Y^D4oiB]i`KoXk_[0onl
eN`4olGQk0OobN;Z00?o_]W]ojk6k?n^a^`01On^a^`6oj:jj@03oifcionQ^>WoXKSY00CoXKSY1onU
_>X7ojJnj`WoYKcY1OnW`>/9ojS1k0KoYko[2?nW_^X;ojRmj003oj[1j_nY_^WoZKkY00KoZKkY1_nW
_n/00onX_n[oY[o/ojJok005ojJok0KoZ<3[00?oYko[ojc1jOn/`NT01_n/`NT2oj[1jPKoZ/7[1_nZ
`NX00on^`nWo[lCYojo4j@06ojo4j@03okG7j?ndb>Wo]<SY00Co]<SY1onR_^d5ogbWk`KoLYc[1on;
[>`00ondaNOo^<SWokS8i`03okS8i`03o`000?nhb>Oo`]3U00Oo`];V0_nebn/5ok78j`KoZ<7/00?o
Yl3/ooooooooool04oooool00ol0003oooooooooo`0;ooooo`005oooool00ol0003oooooooooo`0E
ooooo`OoZ<7[00?oZ<3[ojO0jonW`>/01?nW`>/7ojJoj`03ojNojonX`N_oZ<7[00GoZ<7[1_nU_^/2
oijhjP?o00001_n<Y^H7oiB]i`?oXk_[1onleN`00oo5hNcobN;ZolWRjP05olWRjP;o`M[[2?n^a^`3
oj:jj@?oVk?X1onQ^>T5ojFljPWoY[k[1OnU_>T00onU_N[oYl3[ojO0j`06ojO0j`GoZ<7/0_nX`N/8
ojNoj`?oYkkZ0onW_NT9ojRmj0GoZ/7Z2?nY_^T2ojNoj`GoZ;oZ1onV_n`2ojS0j`GoYko[1_n/`NT2
ojc2jPSoZ/7[0onZ`NX3oj[1j`Oo[lCY00?o/LGYokC8jOndb>T01_ndb>T3oj:nk@?oW;[]1?mhWnX2
ogbWk`KoLYc[0on;[>`3oiF`j@Oo^<SW00?o0000ol;Bi_o2d^H01Oo2d^H00oo0dnSo/LS[ok78j`06
ok78j`;oZ<7/1OnW`>`Dooooo`03o`000?oooooooooo00_ooooo000Fooooo`?o00005oooool8ojS1
j`KoYl3[2?nV_n/7ojS1j`?oYKk[00CoWkW[o`000?l0003o00001?nB[NT6ohbViPOoU:gW00?oXk_[
okcEk?nleN`01OnleN`3olOLj@CobN;Z1Oo1f^/6ojk6k003oj:ljonK/nSoVk?X00GoVk?X1onQ^>T0
0onU_>[oY[k[ojJnj`0;ojJnj`03ojFljOnU_N[oYKgZ00?oYKgZ2?nW`>/00onX`NcoZ<7[ojS1j`04
ojS1j`KoYko[00?oY[cYojNmjOnW_NT01OnW_NT6ojRmj003ojS2k?nZ`N[oZ/7Z00GoZ/7Z1_nY_^T2
oj_0j@OoZ;oZ1onV_n`7ojNoj`;o[<7Y1_n/`^X6oj[1j`03oj[2jonZ`N_oZ/7[00GoZ/7[1?n_a>T4
ok75j@Ko]<SY00?o/<S[oibjkOnL^^d01OnL^^d5ogROjPKoN9gX1onE/>T4okS8i`;o^lgW00?o0000
ok_=ioo2d^H00oo2d^H4ol3Cj0Ko/LS[0_n^a^`6ojO0k1Gooooo00?o0000ooooooooool02_ooool0
01Kooooo00?o0000ooooooooool06?ooool8ojS1j`KoYl3[2?nV_n/5ojS1j`03ojJok?nO^N_o0000
00;o00000onO^N/5oi:]j@KoS:KV1OnD[NL3oj:jjPGo_=G/1_o7g>T00oo9h^[o`M[[ol7Jj`05ol7J
j`;o[/K/1OnR_>/7oi^cj0?oXKSY1?nT_>/<ojJnj`;oY;cZ1_nU_NX6ojO0j`;oZ<7/1onX`N/2ojNo
j`GoY[cY1onW_NT2ojRmj0GoZ<;/1onZ`NX2ojVnj@KoZl3Y1OnX_nX00onY`>_oY[o/ojJok006ojJo
k0OoYko[2?n/`^X2oj[1j`GoZ/;[1onZ`N/00on_a>Wo/LGYok75j@04ok75j@Co]<SY1?n`b>/6oibj
k@KoN9oZ1_mhWNP7oiF`j@03okS8ionkcNOo^lgW00?o^lgW00?o0000ok_=ioo2d^H01oo0dnP2ok78
j`Ko[/K/1_nW`>`Cooooo`?o00002oooool000Cooooo1?l000002?l@413oooooooooooo^k^ko<S8b
o`000?lb<S;ok^k^1_ooool00ol0003oooooooooo`0Jooooo`OoZ<7[0onW`>/;ojJoj`03ojS1jonV
_ncoY[o/00?o00001onO^N/5oi:]j@KoS:KV00?oU:gWoj:jj_nR^^X01OnR^^X3okcEk0KoamcY0oo;
g^L5ol7Jj`?o/LW/1_nR_>/5oi^cj0;oWkOY1onT_>/8ojJnj`KoY;cZ1_nU_NX2ojO0j`KoZ<7/1OnX
`N/00onW_^[oY[cYojJlj@06ojJlj@GoYkgY0_nW`^d7ojS2k0GoZ/7Z0_nX`^`8oj_0j@03ojRoj_nY
`>_oZL3[00?oZL3[2?nV_n`7ojNoj`Ko[<;Z00?o[<?Zoj[2jonZ`^/01OnZ`^/6oj[1j`;oZl;[1ona
aNT00ondb>Wo/<S[ok38j`04ok38j`OoW;[]1OmhWnX6ogRMj0KoUK3Y00?oXKKXok_=ionkcNL01Onk
cNL00ol0003o_m7Xol3Cj005ol3Cj0;o^m?/2?n^a^`3ojO0k0?oY[o[3oooool3o`0000;ooooo00?o
0000ooooooooool02Oooool000Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Kooooo00?o0000ooooooooool06oooool5ojS1j`03ojO0jonV_n_oY[o[00_oY[o[00Co
Z<7[o`000?l0003o00001?nV_n`7oinij`GoTZgY0on<Y^H2oi6[j0WoX[[Z00?o_=G/olOLjOo7g>T0
1?o7g>T5ol_Ni`03ol7JjonabNco/LW/00Go/LW/1_nR_>/00onK/nSoWkOYoingj@04oingj@OoY;c[
1onV_^/7ojBljP?oYKgZ0onX`N/8ojS1k003ojS1jonW_^[oYkkZ00?oYkkZ2?nV_>T00onW_NWoYl;]
ojO2k@04ojO2k@OoZ<;/00?oZ/7ZojS2k?nX`^`01?nX`^`6oj_0j@03oj_1j_nY`>_oZL3[00GoZL3[
1_nV_n`2ojJoj`OoYko[0_n/`^X5ojc3jPOoZ/;[0_nZ`N/6oj_2j`Go/LGY0_ndb>T7ok38j`?oW;[]
0onA/^d4ogRJi`;oN9oZ1_mhWNP2oiF`j@GoXKKX1OnkcNL01?nodNSo0000okoAj?nodNP3ol3Cj0Go
^m?/1_n^a^`00onZ`ncoY[o[ojJoj`05ojJoj`_ooooo0ol00005ooooo`03o`000?oooooooooo00Wo
oooo0006ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`;o
00007Oooool00onX`N_oYl3[ojO0j`03ojO0j`WoY[o[00CoZ<7[o`000?l0003o00000_nX`N/6ojJo
k0?oWkW[0onD/^`5ohVWj0KoTJ_X1onR^^X3ok[?j@?oamcY1_o;g^L3olOJi`Oo/LW/0onR_>/3oiZe
jPOoWkOY1OnT_>/9ojJnj`GoY;cZ00?oYKg[ojS1jonX`N/01OnX`N/6ojS1k0;oZ<3[1_nW_^X6ojJl
j@;oY[o[1onW`^d3ojS2k0CoYL?^1onX`^`2oj_0j@GoZl7Z1onY`>/2ojJok0KoY[o[1OnW_n/00onX
_n_o[<?Zojc3jP06ojc3jPGoZ/;[0_nY`N/8oj_2j`03ok75jOndb>Wo]<SY00Co]<SY1On`b>/2oj[4
k@KoTK;]1OmhV^L6oh2Oi`SoXKKX0onkcNL3okoAj004o`000?nodNSo_m7Xol3Cj0Oo^m?/0_n^a^`5
oj[3k0OoY[o[1_ooool4o`0000Sooooo00?o0000ooooooooool02Oooool000Kooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000000Gooooo0_l0000Oooooo`KoYl3[1onV_n/2
o`0000KoZ<7[0onV_n`3oj6lk0KoU;;/1On9YnP6oi6[j0CoX[[Z1_njcnT00oo7g>WobmkWol_Ni`03
ol_Ni`Koam[W1OnabN`00onV`>coV[GZoiZejP05oiZejPOoWkOY00?oY;c[ojJnjonV_^/02onV_^/0
0onT_>[oYKg[ojFmj`03ojFmj`OoZ<7[0_nX`N`6ojS0j`KoYkkZ0_nV_>T6ojJoj`GoYl;]0_nWa>h7
ojG3kPGoZ<;/0_nU_n`7oj_1jPGoZL3[0_nY`^/8ojJoj`03ojNojonX_n_oZ;o[00?oZ;o[2?n/`nX0
0onZ`^_oZL7[ojW1j`04ojW1j`KoZl;[00?o[<?[okC8jOndb>T01_ndb>T00on`b>_oZ/C]oj[4k@04
oj[4k@KoTK;]1OmhV^L6oh2Oi`SoXKKX00?o^lgWokoAj?nodNP00onodNP00ol0003o`MGYok_Ck006
ok_Ck003okC=k?nZ`ncoZ/?/00GoZ/?/1_nV_n/01?nW_n_oooooooooooooool3o`0000gooooo00?o
0000ooooooooool02?ooool000Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000000Gooooo00?o0000ooooooooool07oooool6ojO0j`?oY[o[0ol00002ojJoj`GoZ<7[0_nW
`>/6oj6lk0KoU;;/1On9YnP6oi6[j003oj:jj_njcnWo^/oY00Go^/oY1?o6enH2ol_Ni`Soam[W00?o
/LW/ojK0k?nV`>`00onV`>`7oiZejP?oWkOY1?nS_>/<ojJnj`;oY;g[1_nU_N/8ojS1j`OoZ<3[0onW
_^X3ojFmjPSoY[o[00?oYl;]ojO4k_nWa>h01?nWa>h7ojG3kP03ojS2k?nU_ncoYKo/00CoYKo/1on[
`NX00onY`>_oZL;[ojW2j`04ojW2j`OoY[o[1onX_n/6ojc3jP03ojc3jonY`N_oZL7[00KoZL7[0_n[
`^/5ojc3j`Ko]<SY00?o]Lc[oj[4kOnZa>d01_nZa>d6oi6bk@GoN9[W1_n0WnL6oj6fj0;o[L7X1?no
dNP2ol7Ej@03o`000?o1eNWo^m?/00?o^m?/1?ndcN`7oj[3k0;oY[o[1OnW_n/2o`00013ooooo00?o
0000ooooooooool02?ooool000Kooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@00Gooooo00?o0000ooooooooool08?ooool3ojO0j`;oYko[0ol00006ojJoj`03ojS1jonW
`>_oYl3[00CoYl3[1_nQ_>`6oiBbk0GoRJOX0onAZnP4oiffjPCo^/oY1_o6enH3olcIh`Koam[W0_ni
cn/6ojK0k0GoV[GZ0_nK]NX7oj>lj`SoY[k[1_nT_N/6ojFmj`SoZ<7[1OnX`>/00onV_n_oYKgZojFm
jP05ojFmjPKoY[o[0_nY`^`7ojO4kP?oYL?^1?nS_^d7ojFok0?oZl7Z1?n[`^/7ojW2j`OoY[o[1onX
_n/2ojc3jPGo[<?[2?nY`N/7ojc3j`;o]<SY1Onec>/6oj[4k@03oj:mk?n5Y>SoQJCX00CoQJCX1?mk
V>@2ogRJi`KoP9oW0_nQ]^P6ojg1j003okoAj?o1eNWo`MGY00;o`MGY00Co0000ol7EjOo1eNWo^m?/
1ondcN`3oj[3k0?oZ<7/2?nW_n/Aooooo`03o`000?oooooooooo00Sooooo0006ooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o00008_ooool01?nW_n_o0000
o`000?l00003ojNoj`GoY[o[0onW_n/6ojO0j`KoXKc/0onD/^`2ohRXjPKoS:WY2?nM]^X00onjcnWo
a]OVolKGiP04olKGiPGoc=WS0_o7f^L6okW?j`KoY/3/00?oV[GZoi^ej_nK]NX01?nK]NX7oj>lj`Ko
Y[k[2?nT_N/3ojFmj`?oZ<3[2?nX`N/00onX`>_oY[o[ojJoj`03ojJoj`OoYKgZ0_nV_n/6ojW2k0Go
YlC^00?oYl3[oj>nkOnS_^d01_nS_^d5ojFok003ojFmjon[`^_oZl;[00KoZl;[1OnY`^/2ojS1j`Ko
Y[o[1_nX_n/2ojW1j`Oo[<?[2?nY`N/5ojc3j`;o[/G[1onec>/2oj[4k@GoX[g/1_n5Y>P5og^Hi0Ko
RJCV1on]`NP00onfbnWo`MGYol7Ej@04ol7Ej@03o`000?o1f>[o]<g/00Ko]<g/00?o[/S/ojS1k?nX
`N`01OnX`N`6ojNoj`03ojW1jooooooooooo00oooooo00?o0000ooooooooool02?ooool000Cooooo
00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000oooooooo
ool07oooool3o`0000OoYko[00?oY[o[ojNojonW_n/01OnW_n/6ojO0j`?oXKc/0_nJ^>d6ohRXjPKo
S:WY1_nM]^X3ok;5j0?oa]OV1_o<fN<3olcHhPOo^Lo[0onV`>`3oibik0OoVkGZ1OnS_>/2ojFnj`Ko
Y[k[1_nT_N/00onS_N_oZ<3[ojS0j`05ojS0j`KoZ<7[0_nX`>/6ojJoj`GoYKgZ0_nW_n/8ojW2k003
ojO4k_nW`>_oYl3[00?oYl3[2?nS_^d00onU_ncoYKg[ojFmj`03ojFmj`SoZl;[00?oZL;[ojS1jonX
`N/01?nX`N/6ojJoj`;oZ;o[1_nY`N/5ojc3j`;oZ/?/2?nY`N/00on/`n_o[/G[ojk5j`04ojk5j`Go
]Lc[0_nabnd7oj:mk0GoQJCX1_mkV>@6ohVTiPCo[L7X1?nfbnT4ol7Ej@;o`MSZ00?o0000ol7Hj_nd
cN`00ondcN`4ojk8k0OoZ<7/0_nW_n/5ojW1ja3ooooo00?o0000ooooooooool02?ooool001Gooooo
00?o0000ooooooooool07?ooool3o`0000Cooooo1OnW_n/3ojJoj`OoYko[0onW`>/3ojBnk0GoV[S]
1_n8Z>X6ohbYj@?oWKKZ1_nbaNP00oo6enKoc=WSolcIh`04olcIh`Goc=SR1Onicn/2ojg5k0KoW;W/
1onK]NX00onS_>_oYKk[ojFnj`04ojFnj`KoY[k[0_nT_N/5oj>mj`OoZ<3[0_nX`N/6ojS0j`KoY[o[
00?oYKgZojNojonW_n/01?nW_n/6ojW2k0;o[<7Y1_nW`>/6oj>nk@;oXk_Z1_nU_N/6oj_2j`03oj_4
k?nX`N_oZ<7[00KoZ<7[0onV_n/3ojJnj`SoZL7[00?o[<?[oj[3k?nZ`n`01?nZ`n`6ojW1j`03oj[2
jon^aN_o[/G[00Ko[/G[00?o]Lc[ok7;kOnabnd01?nabnd7oj:mk0CoQJCX1_mkV>@7ohVTiP03ojg1
j?nfbnWo]/_Y00Go]/_Y00?o`MGYol7Hj_o1f>X00oo1f>X00ol0003o`MSZokC=k006ojk8k0KoZ<7/
00?oY[o[ojW1jonY`N/01_nY`N/?ooooo`03o`000?oooooooooo00Sooooo000Eooooo`03o`000?oo
oooooooo01Wooooo0ol00008ooooo`03ojNojonV_n_oY[o[00GoY[o[1OnW_n/00onY`N_oY;k/ojBn
k005ojBnk0GoV[S]1_n8Z>X6ohbYj@03oiffj_nbaNSo//GX00Co//GX0oo3dND4olcIh`Ooc=SR00?o
^Lo[ojg5k?n]aN`01?n]aN`6oibik0?oVkGZ1?nP^^/7ojFnj`?oY[k[1?nT_^`6oj>mj`GoZ<3[0_nY
`N/8ojS0j`?oY[o[0onT_N`7ojNoj`;oZL;/1_n/`NT6ojO0j`;oXkk]1_nS^nX6ojFmj`;oZl;[1On[
a>`6ojS1j`;oYko[1_nV_^/6ojW1j`03oj_4jonZ`ncoZ/?/00KoZ/?/0_nY`N/5oj[2j`Ko[/G[00?o
//[/ok7;kOnabnd01_nabnd3oj:mk0?oU[7Z1?moVN800on5Y>SoNiSTog^Hi004og^Hi0?oRJCV1?nH
[^H6okK;j@?o_M?Z1?o1f>X00ol0003o^mO^ok_GkP07ojk8k0;oZ<7/1OnV_n/7ojW1j`oooooo00?o
0000ooooooooool02?ooool001Gooooo00?o0000ooooooooool05_ooool3o`0000gooooo1onV_n/0
0onW_n_oZL7[ojW1j`03ojW1j`OoY;k/1OnJ^>d3ohRXjP?oQZS[1_nE/NX5ok;5j0Ko`m7U00?oc=WS
olcHh_o<f>801Oo<f>82olKDi@Oo[LG/0onL^N`3oiNfk@OoX;[[1_nU_^/8ojBnk0KoXkg[00?oZ<3[
ojW1jonY`N/01?nY`N/6ojS0j`;oYl3[1_nT_N`5ojNoj`;oZ/7Z2?n/`NT3ojO0j`?oYkcX2?nS^nX3
ojFmj`?oZ<3[1on[a>`2ojS1j`KoYko[1_nV_^/2ojW1j`GoZlC[1_nZ`n`2ojW1j`OoZ/;[0_n^aN/5
ok;:k0Ko/L_]00?oZL?/oiJaj_nF/NX01OnF/NX4ognIhPKoPY_R2?nH[^H3okK;j@Ko_M?Z00Go`MSZ
ok_Gk_nkenko^mO^o`000002ok_GkP?o[/S/1?nZa>`7ojJoj`OoZL7[3oooool00ol0003ooooooooo
o`07ooooo`005?ooool2o`0001Gooooo0ol0000Aooooo`OoY[o[1_nY`N/5ojBnk0;oWk_]1On=/>h6
ohJXj`KoUK7Z0onbaNP6ol?Ai@?obM?Q1?o<f>85olKDi@Go[LG/0_nT`>d6oiNfk@OoX;[[1_nU_^/8
ojBnk0?oXkg[0onU_^/7ojW1j`;oZ<3[1_nW`>/6ojBmk003ojNojonZ`N[oZ/7Z00CoZ/7Z1_n/`NT0
0on[_nSoYkcXojNlj005ojNlj0KoXk_Z00?oY[gZojS0jonX`>/01OnX`>/5oj_4k0;oZL;/2?nW_n/3
ojJnj`?oYko[1on[a>/2oj[3k0KoZL7[1OnZ`^/2oj_4k0Oo//[/0_nabnd5ojW3k0KoU[7Z1OmoVN86
oh:KhPSoV:kV00?o]/_YokgCj_nmdnX01?nmdnX00oo0fNco^mO^ok_GkP03ok_GkP03o`000?nbcNgo
Z/C/00OoZ/C/1OnV_n/2ojNoj`OoZL7[3_ooool00ol0003oooooooooo`07ooooo`005?ooool00ol0
003oooooooooo`0Booooo`;o00005Oooool7ojJoj`KoZL7[00?oY;k/oinkkOnO^nd01?nO^nd5ohf`
kPKoQZS[1_nE/NX00onbaNSo`m7Uol?Ai@04ol?Ai@GobM?Q00?oc=SRolKDiOo6e>D01_o6e>D00on]
aNcoY<3]ojC0k@04ojC0k@KoUkK]1OnP^^/2oj>mk0KoYKk[1_nT_^`2oj>mk0KoYKk[1onY`N/8ojO0
j`?oY;g/0onT_n`7oj[1jP;o[<7Y1On[_nP7ojNlj0;oXk_Z1OnV_NX7ojS0j`03oj_4k?nY`^coZL;/
00CoZL;/1_nW_n/00onV_^_oYko[ojNoj`05ojNoj`GoZlC[0_n[a>`8ojW1j`03oj[2jon[a>coZlC/
00CoZlC/1Onbb^`2ok?>k@OoZL?/1OnF/NX6ognIhPKoPY_R1_nH[^H00onZ_nWo_M?ZokgCjP04okgC
jP?o`=W/0onkenh2ok;=k@03o`000?nbcNgoZ/C/00OoZ/C/00?oY[o[ojNojonW_n/01?nW_n/5ojW1
j`03ojS1jooooooooooo00cooooo00?o0000ooooooooool01oooool001Cooooo00?o0000oooooooo
ool03oooool3o`0001Sooooo1onV_n/3ojW1j`CoYl3/1_nO^nd5ohf`kPKoQZS[0onE/NX4ojFkj@Co
`m7U1Oo9dn43olcBg`Koa]CU0_nlc^P7ojC0k@KoUkK]00?oX;[[oj>mk?nS_N`01?nS_N`6ojFnj`;o
Y;k/1_nS_N`6ojFnj`OoZL7[1_nW`>/00onV_ncoY;o/ojBok005ojBok0GoZ/7Z00?oZ/;[oj^oj?n[
_nP01_n[_nP5ojNlj0;oYkkY1_nV_NX6ojS0j`;oZ/C]1onY`^`2ojNoj`GoY[k[1onW_n/00on[a>_o
ZlC/oj_4k004oj_4k0KoZL7[00?oZL;/oj_4k?n[a>`01_n[a>`00onbb^co/lk]ok?>k@04ok?>k@Go
ZL?/00?oWkOYohRNh_n8W^800_n8W^82oiJajPKoOiWR1_n2Vn82oiR^iPGoZ[oY0onmdnX6ol3Ik005
ok_Gk_nbcNgo//g]ok;=kOl000000_nbcNd6oj[4k003ojO0jonW_n_oYko[00KoYko[00?oZL7[ojS1
jonX`N/00onX`N/=ooooo`03o`000?oooooooooo00Oooooo000Dooooo`03o`000?oooooooooo00co
oooo0ol0000Looooo`GoY[o[0onW_n/6ojO0k0KoWk_]1On=/>h3ohJXj`;oRjc/2OnU^nT00oo3dNGo
bM?QolWCh@03olWCh@Goc=;O0oo6e>D5okc>j0OoY<3]0onG]^d3oiVgk@OoXkg/0onU_^/3ojJok0So
Xkg/0onU_^/3ojNoj`OoZL7[0_nW`>/5ojJok0OoY;o/00?oZ/7Zoj[2jonZ`^/00onZ`^/8oj^oj003
ojNlj?nW_^WoYkkY00CoYkkY1_nV_NX2ojS0j`KoZ/C]1OnY`^`2ojNoj`KoY[k[1_nW_n/2oj[3k0Oo
ZlC/0_nY`N/5ojW2k0KoZlC/00?o[lW]ok?>kOncc^d01_ncc^d00onY`ncoWkOYoingj@03oingj@Go
R9kR1_n2Uml6ohbRh`SoZ[oY00?o_M?Zol3Ik?o0fN`01?o0fN`00onofngo//g]ok;=k@03ok;=k@03
o`000?nbcNgo//g]00;oZ/C/1OnW`>/6ojNoj`03ojW1jonX`N_oZ<7[00GoZ<7[3?ooool00ol0003o
ooooooooo`07ooooo`004oooool3o`0000[ooooo0ol0000Pooooo`03ojJojonW_n_oYko[00GoYko[
1_nW`>`3oinkk@;oV;S^1On3ZNd6oh^/k0OoYK_Y0ongaND3olWCh@Ooc=;O00?oa]CUokc>j?nlc^P0
1Onlc^P3ojC0k@CoWKc^1_nI]nd5oj>mk0;oY;k/1_nV_n`6oj>mk003oj:nk?nW_n_oYko[00GoYko[
1OnY`N/2ojW0j`OoY[o/1OnT_n`2ojBok@KoZ/;[1_n[_nP2ojW1j`OoYkkY0onV_NX4ojS3k@OoZ/C]
00?oZL;/ojNojonW_n/01?nW_n/6ojJnj`;oYko[1_nZ`n`5oj_4k0WoZL;/0_n[a>`5ojo9k@Ko/lk]
00?o[<K]oingjOnO]nT01OnO]nT5ohRNhPKoPYOO1_n<X^<6ojZoj@;o]/k/1?o0fN`4okoKk@Go//g]
00?o0000ojg7kOnW`>/01onW`>/2ojNoj`GoZL7[1onX`N/;ooooo`03o`000?oooooooooo00Oooooo
000Dooooo`03o`000?oooooooooo00Kooooo0ol0000Uooooo`OoYko[0onW`>`3ojBok0GoV;S^1On3
ZNd6oh^/k0CoYK_Y1_ngaND00oo9dn7oc=;OolcBg`05olcBg`?oc=7M1Onlc^P3ok;7j@KoWKc^1_nI
]nd00onS_NcoY;k/ojBnk004ojBnk0KoY[o/0_nS_N`5oj:nk0OoYko[00?oZL7[ojW0jonY`>/01?nY
`>/7ojJok003ojBok?nT_ngoY;o]00CoY;o]1_nZ`^/2oj^oj0KoZL7[1OnW_^T2ojO3kPOoZ<?]0onZ
a>d3ojS0j`SoYko[0onV_^/3ojNoj`SoZ/?/00?oZlC/ojW2k?nY`^`02OnY`^`2oj[4k0Oo[lW]0_nc
c^d5ojc6k@KoWkOY1_n8W^86oh:Gg`KoS:;S0_nZ_nT6okK>k003ol3Ik?nofngo_m_]00Go_m_]0_nb
cNd2ojg7k@03o`000?n]ango[LO]00KoYl3[00?oYko[ojW1jonY`N/01_nY`N/3ojS1j`?oYl3[2ooo
ool00ol0003oooooooooo`07ooooo`005?ooool00ol0003oooooooooo`03ooooo`?o0000:Oooool5
ojNoj`03ojS1jonT_ncoY;o/00GoY;o/1OnH^>h5oh>Yk@KoRjc/00?oYK_YokO5iOngaND01OngaND3
ol;<hPGoc=;O1Oo<dMd00onlc^So//OYok;7j@05ok;7j@KoWKc^0onI]nd3oibik@OoY;k/0onV_n`4
ojFok0KoX[k/1OnW_n/2ojS0j`OoZL3[1onV_n`7ojBok@?oZ/;[0onW`^d8ojW1j`03ojNnjOnW`nko
Yl?^00CoYl?^1OnX`nd00onX`^coZ<3[ojS0j`05ojS0j`KoYko[0_nW_^/6ojNoj`KoZ/?/00?oZlC/
ojW2k?nY`^`01onY`^`6oj[4k0Go[lW]0onbcnl6ojc6k@KoWkOY1_n8W^86oh:Gg`?oS:;S0onM/NH6
okK>k0;o_MS]1_nofnd2okODk`Co[LO]00?o0000ojg7kOn]and00_nW`>/5ojNoj`KoZL7[00?oZ<7/
ojO0jonW`>/01OnW`>/;ooooo`03o`000?oooooooooo00Kooooo000Cooooo`04o`000?oooooooooo
ooooo`?o0000;Oooool00onW_n_oZ<7[ojS1j`03ojS1j`OoY;o/1OnH^>h5oh>Yk@?oRjc/1?nD/^`5
okO5i@Go`/cR0oo<d]l5olcAg@?ob/kM1onbanT3oiflkP?oV;[_1_nL^Nd5ojBnk003ojFnk?nU_nco
YKo/00KoYKo/1_nR_^`00onW_n_oZ<3[ojS0j`04ojS0j`OoZL3[1onV_n`5ojBok@;oXko]1_nW`^d6
ojW1j`;oY/?^1onW`nh00onX`ngoZ<;/ojS2k003ojS2k0OoZ<3[0_nW_n/6ojNnj`KoYko[0_nZ`n`5
oj_4k0OoZL;/2?nZa>`00on_bNgo//o_ok;?k`05ok;?k`?o[<K]0_nR^>P6oi2Rh@KoQIKM1_n9W>07
oifaiP?o]/k/1Onmf>d2okoKk@Ko]mC_0on]and00onX`^co0000ojS2k008ojNoj`;oZL7[1OnX`N`7
ojO0j`[ooooo00?o0000ooooooooool01_ooool001?ooooo1?l0000aooooo`KoZ<7[1OnT_n`2oj2m
k@KoS;?`1On2ZNh6oiBbk0?o]lGU1oo2c>800oo<d]ooc=7MolcAg@03olcAg@Gob/kM1OnbanT2ojg3
jPKoV;[_1_nL^Nd00onT_^coYKk/ojFnk003ojFnk0SoYKo/0onR_^`3oj:nk@OoZ<3[1onY`>/7ojJo
k003ojBokOnS_ngoXko]00CoXko]1_nW`^d2ojW1j`KoY/?^1OnW`nh2ojO1k0KoZ<;/1OnX`>/2ojNn
jPSoYkk[0onW_n/3oj[4k@OoZlC/1onY`^`6oj[4k0;o[/[^1_nbcnl00on/a^goX[SXoj:hj004oj:h
j0KoT:;Q1_n5U]d6ohVLh0OoWK7V00?o]/k/okgHkOnmf>d00onmf>d3okoMk`Go]mC_0_n^bNh4ojS2
k003o`000?nX`^coYko[00GoYko[00?oZ<7[ojS1k?nX`N`01_nX`N`3ojO0j`?oYko[2_ooool00ol0
003oooooooooo`06ooooo`004oooool2o`0003Cooooo1_nX`N/00onT_ncoX;g]oj2mk@04oj2mk@Ko
S;?`1On2ZNh6oiBbk003okO5iOo2c>;o`/cR00Go`/cR0oo7cMh3olcAg@Oob/kM00?o//OYojg3j_n]
`nX01?n]`nX6oiRjk`?oW;W]0onN_>d6ojFnk0KoYKo/0_nT_n`6oj:nk@GoZ<3[0_nX`N/7ojW0j`?o
Y[o/1?nW_n/7oj>ok@?oYl;]0onT`Nd8ojK3kP03ojO3k_nW`NcoYl7/00CoYl7/1_nX`^`00onX`>_o
YkkZojNnjP04ojNnjPKoYkk[00?oYl;/oj[4kOnZa>d01OnZa>d5oj_4k0;oZ<;/1onY`^`2oj[4k0Ko
[/[^0_nbcnl5ojc6k@KoX[SX1_n@X^45ohFFg@KoRIcP1_nM/NH2ok39k0?o_MS]1_nogNl00onge>oo
[/W^ojk9kP04ojk9kP?oZ<;/00?o0000ojS2k?nX`^`00_nW_n/5ojS1j`KoZ<7/00?oYl3[ojNojonW
_n/01OnW_n/9ooooo`03o`000?oooooooooo00Kooooo0005o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP08ooooo`03o`000?oooooooooo03;ooooo0onX`N/4ojS0j`KoX;g]1_n</o05oh:YkP?o
U;;/1?nQ^^/4ol;<hPKoalgN00?oc=7Mol[>gOo:c]d01Oo:c]d2olK;gPOo[L?Z0onH^^l3oiJil0Ko
W[c]1_nU_^`2ojFok0KoY;o/1_nR_^d00onX`>_oZ<7[ojS1j`04ojS1j`GoZL3[0_nY`>X7ojNoj`Go
Xko]0_nV_n`6ojC1k@KoY/?^00?oY/3/ojO1k?nW`N`01_nW`N`3ojS2k0?oYkoZ1onW_^X2ojNnj`Go
Yl;/1onZa>d00on[a>coZ<;/ojS2k004ojS2k0GoZL;/0_nZa>d6ojk:kP;o/Lo`1_n/a^d7oj:hj0Go
T:;Q1On5U]d7ohVLh0;oWK7V1_n`bN`00onmf>go_mg_okoMk`04okoMk`03okWHl?n^bNko[/W^00Ko
[/W^0onX`^`00ol0003oY[o[ojJoj`07ojS1j`;oZ<7/1OnW`>/7ojNoj`Sooooo00?o0000oooooooo
ool01_ooool00005oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Wooooo00?o0000ooooooooool0<oooool6ojS0j`KoX;g]0on</o02oh:^l@KoQJc_1onQ^^/00oo2
c>;oalgNolO=gP05olO=gP;obLcK1_o:c]d4olK;gPGo[L?Z0_nY`N/6oiJil0KoW[c]0onU_^`4ojFo
k0OoY;o/0onR_^d3oj:ok@OoZ<7[00?oZL3[ojW0j_nY`>X01?nY`>X7ojNoj`03oj>okOnV_ncoY[o/
00CoY[o/1_nT`Nd2ojK3kPGoY/3/1_nW`N`8ojNojPGoYkkZ0_nW`>/7ojO2k0?oZ/C]1?nY`n`7ojS2
k003ojW2k?nZa>goZ/C]00CoZ/C]0on^b^h5ok7?l0Ko[<K]0onR^>P3oi>RgPCoRIOJ0_n@X^45ohFF
g@?oRIcP0onFZ><7ok39k0;o^]O_1?nogNl4okWHl0Ko[/W^00?oZL?/ojJojonV_n/00_nV_n/00ol0
003oY[o[ojJoj`05ojS1j`03ojS1k?nW`>_oYl3[00GoYl3[1onW_n/8ooooo`03o`000?oooooooooo
00Kooooo00001?ooooooV9RHob4Q8Oo^k^h4ooooo`05oa0@4?ooooooooooooooool@41002_ooool0
0ol0003oooooooooo`0cooooo`KoZ<3[0onP_Nd3oi^kkPGoPZka1_n5[>l5oj6jj`?o[/3W1Oo7cMh4
olW<f`?ob/kM1oo6bmh00on]`n[oZL7[ojW1j`04ojW1j`KoU[W`0onN_>d3oinmkPOoYKo/1onT_n`6
oj:ok@GoZ<7[0_nW`N`7ojW0jP?oYko[1?nX_nX7ojJok0?oY<7]0onW_n/7ojK0k0;oYl7/3?nW_nX0
0onW_^[oYl3[ojO0j`04ojO0j`GoYl;/0_nYaNd7ojW3k0?oZ<;/0onY`n`8oj[4k@03ojk:k_naco3o
/Lo`00Go/Lo`0on/a^d2oj:fiPOoTj;N1On9UmX5ohZJg@OoUZSS1?n`bN`5ok[Gk`03okoMkonif?3o
^MS`00Go^MS`0_n^bNh5ojW3k0CoY[o[00Co0000ojJojonV_n_oZ<7[1OnX`N`7ojO0j`OoYko[1ooo
ool00ol0003oooooooooo`06ooooo`000_ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooo
ooooooooool000002oooool2o`0003Cooooo0onX`>/3ojK0k0KoVk_^1On2[_46ohF/k`03oj6jjon^
`>Oo[/3W00Go[/3W0oo7cMh6olW<f`03ol[>gOo6bmkoa/_N00Goa/_N0_o2b=h7ojW1j`?oU[W`0onE
^_46oinmkPOoYKo/1onT_n`6oj:ok@03ojS1jonW`NcoYl7/00CoYl7/1OnY`>X00onY`>_oZ;oZojRo
jP06ojRojPGoY[o/0_nX_nX6ojNoj`GoY/3/0_nX_nX:ojNojPCoYko[1onW`>/00onW`^coZLG]ojW5
k@04ojW5k@GoZL?/0_nX`^`6ojW3k0KoZ/C]0_n^c_46ok7?l003oj[2jonR]^KoX[KV00CoX[KV1_nC
X]h6ohVGfPGoRY[M1onFZ><00on`bNco^]O_ok[Gk`04ok[Gk`;o_Mo`1_nif?000on_bnkoZL?/ojW3
k005ojW3k0CoY[o[00?o0000ojJojonX`>/01onX`N`3ojO0j`_oYko[1oooool00ol0003ooooooooo
o`05ooooo`000oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000003Ooo
ool00ol0003oooooooooo`0booooo`KoY/3/1_nK^nh5oh:^l@?oQJc_0on;/>l8ojk0i`03olO=g_o9
c=_obLcK00CobLcK0oo:b]T4olK;gPGo`/SN1OnY`N/2ojNoj`KoUK[a1_nO_Nh7ojFok0OoY;o/0onR
_nd3oj:okPOoYl7/00?oZL3ZojW0jonY`>/00onY`>/8ojRojP03ojJok?nX_n[oZ;oZ00CoZ;oZ1_nW
_n/00onV`>coZ;oZojRojP04ojRojPGoYkoZ2OnW_n/5ojO0j`;oZ<G^1onYaNd00onY`ncoZ<;/ojS2
k004ojS2k0KoZL?/0_nZa>d6ojk>l@;o/Lo`1OnZ`^/6oj:fiPGoTj;N1_n9UmX6ohZJg@GoUZSS0on/
a^d3ok[Gk`Go_Mo`0_nif?05ojo;kPOoZL?/0_nV_n/2ojS0j`03o`000?nX`>_oZ<3[00GoZ<7/0_nX
`>/=ojNoj`Oooooo00?o0000ooooooooool01Oooool000Cooooo00Go0000oooooooooooooooooa0@
4003ooooo`03oa0@4?oooooooooo00cooooo00?o0000ooooooooool0<_ooool6ojK0k0?oVk_^1?nE
^O05ogf[l@GoRk3_1_n^`>L2okS3h`GobLcK1_o:b]T00oo6bmko`/SNol;8gP05ol;8gP03ojW1jonW
_n_oYko[00CoYko[1_nE^_43oinmkP?oWko_1onU_n`5ojBok0;oYKo/1_nR_nh5ojO1k0;oYL7]1_nY
`>/6ojRojP03ojS0j_nX_n[oZ;oZ00KoZ;oZ0onW_n/:ojRojP03ojNoj_nW_n_oYko[00_oYko[00?o
Yl3[ojS5k_nXaNh01?nXaNh5ojW5k@WoZ<;/0onY`n`4oj[7k`Go[/ka0_n_cNl6oj[2j`OoX[KV1OnC
X]h6ohVGfPKoRY[M00?oUZSSojc6kOn/a^d01On/a^d00onjenoo_Mo`okgOl003okgOl0;o^M[a1on_
bnh3ojW3k0?oYko[1OnX`>/01?l0003oZ<3[ojS0jonX`N`6ojS0j`goYko[1_ooool00ol0003ooooo
ooooo`05ooooo`0000Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03oooool00ol0003oooooooooo`0booooo`?oY/3/1?nT_nd6oiFil0GoOJ_a1On;/>l3ojk0i`Go
^<?S0oo9c=/6ol[:f@;ob/SH1_o2b=h2ol35gPOoYko[0onE^_43oiBkl@KoWko_1onU_n`00onT_nco
YKo/ojFok004ojFok0KoX[o^00?oYl7/ojG1kOnU`Nd01?nU`Nd6ojW0j`;oZ;oZ1OnX`>X6ojRojP;o
Z<3[2onX_nX2ojS0j`[oYko[0onXa>h8ojS5kP03ojW5kOnX`^coZ<;/00WoZ<;/0_nYa>h7oj[7k`03
ojk>lOn_cNoo[lg_00Co[lg_1_nZ`^/3oj:fiP?oU9gJ1On=UmP6ohfJf`KoU:KR1on/a^d2okOHl@?o
_Mo`1Onif_45ojo;kP03oj[4k?nW_n_oYko[00GoYko[1OnX`>/00ol0003oZ<;/ojS0j`07ojS0j`go
Yko[1Oooool00ol0003oooooooooo`05ooooo`0000GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h04?ooool2o`0003Cooooo1_nT_nd6oiFil0GoOJ_a1On;/>l00on^
`>Oo^<?SokS3h`05okS3h`03olW<foo:b]Wob/[I00Cob/[I1?o:b=P3ol;8gPGo`<GN1OnW_n/2ojNo
jPKoU;_a1_nO_nl3ojFok0CoY<3]1onU_n`3oj:okP?oXko]1onU`Nd3ojW0j`?oZ<;]1onX`>X2ojRo
jPKoZ<3[1onX_nX6ojS0j`GoYko[0_nWa>h6ojS4kPKoZ<G^2_nX`^`6ojW4kPGoZ/O_0_n^dO87ojo=
k`?oZ/;[0_nQ[^47oiBMfPGoSIOH1_n=V]/6oiBVhPCo[<K]1Ongf?400onmgo3o^M[aokWJl@05okWJ
l@03ojo;k_nZa>coZ/C/00?oZ/C/1onW_n/2ojS0j`;oZ<;/00?o0000ojS2k?nX`^`01_nX`>/=ojNo
j`03ojS1jooooooooooo00?ooooo00?o0000ooooooooool01Oooool001oooooo00?o0000oooooooo
ool0<_ooool6ojBok@?oUKW`0_n>]o85ogb/lPKoTKG_1_nh`n<3okk5g`?ob/[I1oo:b=P00oo2b=ko
`<GNol35gP05ol35gP03ojNojonW_n[oYkoZ00CoYkoZ1_nD^o43oinok`CoWL3`1_nT`>d5ojFok0;o
YL3/1_nS_nd5ojG1k@;oXl7^1_nX`^d5ojS0jP;oZ<;]2?nX`>/3ojRojP?oZ<;/1onX`>/00onW_n_o
YlC^ojO4kP04ojO4kPKoZ<C^0_nXaNh;ojS2k003ojS3kOnYa>koZLC^00KoZLC^00?oZ/O_ojkAl_n^
dO801?n^dO83ojo=k`?oYk[W1_nQ[^46oiBMfPKoSIOH1_n=V]/6oiBVhP03ojc6kOngf?7o]mSa00Co
]mSa0_nkhO86okWJl@03ojo;konZa>coZ/C/00GoZ/C/0onW_n/4ojO0j`CoZ<;/00?o0000ojS2k?nX
`^`00_nX`>/=ojNoj`GoZ<7[1?ooool00ol0003oooooooooo`05ooooo`008?ooool00ol0003ooooo
ooooo`0booooo`?oY;o]0onR_^d5ohjglPGoO:cb1_nA]Nl3okS3h`Ko_/GO00?ob/[Iol[8f?o:b=P0
1Oo:b=P2olW5ePKo`<GN0_no`]`7ojNojP?oU;_a0onE^o87oig0l0KoY<3]00?oYKo/ojG0k?nU`>`0
1?nU`>`6oj>ok@03ojG1kOnS`NkoXl7^00CoXl7^1_nX`^d00onX`>[oZ<;]ojS2k@04ojS2k@KoZ<3[
00?oYl?^ojS2k?nX`^`01OnX`^`5ojS0j`;oY/C_1onWa>h3ojS4kPCoZ<?]2?nX`^`5ojS3k@KoZLC^
0_nZc_<5ojkAlP03oj_4k?nW^^OoYk[W00GoYk[W1_nQ[^45oiBMfPKoSIOH1on=V]/3oiBVhP?oZlO^
1?ngf?45ok_QlP;o^M[a1On_bnl5oj[4k0;oYko[1onW`>/3ojS2k003ojS1jol0003oZ<7[00goYko[
2?nX`N/3ooooo`03o`000?oooooooooo00Gooooo000Qooooo`03o`000?oooooooooo03;ooooo1_nR
_^d5ohjglPGoO:cb1_nA]Nl00onh`n?o_/GOokk5g`04okk5g`?o`/KM1Oo:b=P4olW5eP?o`<GN1Ono
`]`5ojNojP;oZKkY1_nE^o87oig0l0?oY<3]0onT`Nh7ojG0k0?oXko]1?nT_nd6oj?1kP?oZ<;]1?nT
`^h6ojS2k@;oZ<3[1OnW`nh7ojS2k003ojS0jonVa>ooY/C_00CoY/C_1OnWa>h2ojO2k@OoZ<?]0onX
`^`:ojS3k@;oZLC^1_nZc_<00on^dO;oZlC/oj_4k003oj_4k0KoYk[W1onQ[^45oiBMfPKoSIOH0on=
V]/3oiNXhPOoZlO^00?o]mSaok_Ql_nkhO801?nkhO82okOJlPOo[l__00?oZ/C/ojNojonW_n/01?nW
_n/5ojO0j`03ojS2k?nX`N_oZ<7[00;oZ<7[00?o0000ojS1jonX`N/03OnW_n/7ojS1j`Cooooo00?o
0000ooooooooool01?ooool002;ooooo00?o0000ooooooooool0<_ooool6oj:nk@GoS[Ob1Oml[?83
oi6ek`?oUkW_1OnnaMl5ol;6g@?ob/SH1_o9aMH00oo0aMko_l;Loko2g005oko2g003ojNoj_nY_^Wo
ZKkY00CoZKkY1_nE^o83oig0l0CoV/3b1_nT`Nh5ojG0k0;oYL7]1onT_nd3oj?1kP?oXko]1onT`^h3
ojS2k@?oY<;_1onW`nh3ojS2k0_oY/C_00?oYlC^ojO2kOnW`^d01?nW`^d5ojS3k@;oYl;]2onX`nd3
ojS;lPGoZ/kc0_n/bo06oj_4k0KoYk[W0onQ[^43oiBIe@GoT9OF1_nAW=X7oiNXhPGoZlO^1?nff_<0
0onkhO;o]m[bokOJlP04okOJlP?o[l__0onY`n`8ojNoj`03ojO0jonX`^coZ<;/00?oZ<;/1?nX`N/0
0ol0003oZ<7[ojS1j`0=ojNoj`OoZ<7[0oooool00ol0003oooooooooo`04ooooo`008oooool2o`00
03?ooooo0onR_^d4oinnkPCoR;Gc1Oml[_<6oiNik`?o_/GO1oo2a]d00oo:b=SobLGFolW5eP04olW5
eP;obL?E1_no`]`2oknof@OoZKkY0onE^o84oiRkl0KoV/3b1_nT`Nh00onU`>coYL7]ojG1k@04ojG1
k@GoY;o]0_nV`Nd6oj>ok@GoY<;^0_nT`>d6ojC2k`GoYl?^0_nU`^h:ojK4k`_oYl;]00?oZ<?]ojO2
kOnW`^d01?nW`^d7ojS3k@OoZ<_b00?oZ/kcojc;l?n/bo001?n/bo06oj_4k0?oYk[W0_nLXMP7oiBI
e@GoT9OF1_nAW=X7oiNXhP03oj_7k_nff_?o]][c00Co]][c0_nih_@5okOJlP;o[L[_1_nY`n`6ojNo
j`03ojO0jonX`^coZ<;/00GoZ<;/0onX`N/00onW_n_o0000ojNoj`0;ojNoj`[oZ<7[0_ooool00ol0
003oooooooooo`04ooooo`009Oooool00ol0003oooooooooo`0booooo`KoWkk^1?n8]O<5ogb^l`Ko
UkW_00?o_/GOol;6gOo2a]d01Oo2a]d2ol;5g0GobLGF1?o9`mD3oko2g0Go_koI1OnY_^T3ojfmi@Ko
V;_`1_nJ`?83ojC1kPCoX/;`1_nU`Nd00onT_ngoY/7]ojK1k@04ojK1k@KoXko]00?oY<;^ojC0kOnT
`>d01?nT`>d6ojC2k`03ojO3k_nU`^koYL;^00CoYL;^1OnVa>l2ojK1kAGoYl;]0onX`nd3ojS8l@Ko
Z<_b00?oZlkbojc;l?n/bo001_n/bo03oj_4k0;oXjcN1_nLXMP6oiBIe@KoT9OF1_nAW=X5oiNXhP;o
[<c`1?nff_<5okWRm003okOJl_n]b^oo[L[_00Co[L[_1_nY`n`2ojNoj`GoYl3[1OnX`^`2ojS0j`Co
Yko[00?o0000ojNojonW_n/01_nW_n/<ojS1j`04ojO0joooooooooooo`0000Kooooo000Vooooo`03
o`000?oooooooooo03;ooooo1_nO_^h4ohRel`GoO:kc0onG^Nl3oi^kk`Ko`/KM1?o2aM`3olW5ePKo
bL?E00?o_l;LoknofOno_mT01Ono_mT00onY_^Wo[KgUojfmi@05ojfmi@KoV;_`0onJ`?83oiJom0Oo
X/;`0onU`Nd3ojC2kPOoY/7]0onS_nd3ojK1k@OoY<3]0onT`^l4ojG1k@KoYL;^00?oY/C_ojK1kOnV
`Nd01?nV`NdCojO2k@03ojO7l?nXb?7oZ<Sa00GoZ<Sa0_nXbo85oj_>lPKo[<_`00?oYkKToj>/g_nS
[=h01?nS[=h6oibQf0GoU9WE1_n@UmH7oi6LfP03oiNXh_n/c?3o[<c`00Co[<c`00?o]][cokWRm?ni
h_@01?nih_@00onde_;o[L[_ojg:k`06ojg:k`?oZL?/0_nW_n/8ojO0j`03ojS2k?nX`>_oZ<3[00Co
Z<3[0onW_n/00ol0003oYko[ojNoj`07ojNoj`SoZ<7[1OnW`>/00ooooooo0000ooooo`05ooooo`00
9oooool00ol0003oooooooooo`0booooo`?oWkk^0onN_Nl5oh>cm0GoO;3d1OnK^nl3ol;6g@Oo`/GL
00?obLGFolW3eOo9`mD01?o9`mD2olS1e0Ko_koI0_o1_MH8ojfmi@?oV;_`0onM^nh6oiJom0GoX/;`
0_nNaO<6ojC2kPGoY/7]0_nU`^h6ojK1k@GoY<3]0_nV`Nd7ojG1k@?oYL;^0onW`Nd7ojK1k@ooYl;]
1OnWao05ojS8l@?oZM3d1_n[c_82ojc;l0GoYkKT1_nS[=h5oibQf0KoU9WE1_n@UmH3oi6LfP?oW;7V
1_n/c?03okGNm@?o^N;d1?nde_86ojg:k`03ojW2k?nW_n_oYko[00CoYko[1_nW`>/00onX`^coZ<3[
ojS0j`06ojS0j`?oYko[00?o0000ojNojonW_n/01onW_n/7ojS1j`KoYl3[00?o0000ooooooooool0
1?ooool002Sooooo0_l0000cooooo`KoW[g_1On3/o@5ogb`m0GoVk__00?o`/KMol;5g?o2aM`01Oo2
aM`2ol;4f`GobL?E1?o8`M@3oknof@Go`KgF1_n]_ND2ok2hg`KoWK_^1_nF_o@00onR`_3oW/Gcoik5
l`04oik5l`KoY<;^00?oY/7]ojG2k_nU`^h01?nU`^h6ojK1k@03ojC0kOnV`NgoY/7]00CoY/7]1OnU
`Nd2ojK2k@KoYl7]1OnV`Nd2ojO3kP[oYl;]2_nWao000onXb?7oZM3dojW@m005ojW@m0?oZlkb0onX
^nL6ojNfi0OoXjcN1OnLXMP5oiBIe@?oT9OF0onFXM`7oibaiP?o[<c`1_neg_D00onih_Co]=KbokCF
lP04okCFlP;o[L[_1OnY`^`6ojNoj`;oYl3[1OnX`^`6ojS0j`GoYko[00?o0000ojNojonW_n/01OnW
_n/00onX`NcoZ<7[ojS1j`06ojS1j`?oYl3[0_ooool00ol0003oooooooooo`04ooooo`00:_ooool0
0ol0003oooooooooo`0aooooo`KoW[g_1On3/o@5ogb`m0;oVk__1?nN_^l5ol;5g0Co`/CK0oo9`mD6
olS1e003oknofOo1_MKo`KgF00Go`KgF0_n]_ND6ok2hg`KoWK_^0onF_o@4oiFml`KoW/Gc0onT`^h3
oj;5lPOoYL;^0onV`Nd4ojK2kPKoY/7]00?oYL7]ojK2kOnV`^d01?nV`^d6ojO1k@03ojK1kOnW`nko
Yl?^00CoYl?^1OnW`^d2ojK8l@[oYlO`1?nWd?D5ojW@m0;oZKoY1_nX^nL6ojNfi0?oXjcN0onJVM85
oiJHd`GoUI[G1onFXM`7oibaiP03ojc<l?neg_Go]Mke00Co]Mke0_nfh_D5okCFlP03ojc7k_nY`^co
ZL;/00KoZL;/0onW_n/3ojS1k0OoZ<;/0_nX`>/9ojNoj`04o`000?nW_n_oYko[ojNoj`GoZ<7/1_nX
`N/7ooooo`03o`000?oooooooooo00?ooooo000[ooooo`03o`000?oooooooooo037ooooo0onN_Nl3
oifmk`GoPK?e1Oml/OH6oijnk`?o`/GL1_o2a=/00oo9`mGob<7DolS1e004olS1e003olJodoo1_MKo
`KgF00Go`KgF00?o`k_Bok2hgon`^=l01on`^=l3oifkkPCoYK_Y1_nE_O<3oik5l`?oUl?e1_nRaO85
ojG2kP;oXlGa1onV`^h3ojK1k@?oY/?^1onV`^d3ojO1k@CoY/C^1_nW`nh00onW`^goY/SaojK8l@04
ojK8l@GoYlO`0onUcoH6ojO@m@03ojW@m?nY_nWoZKoY00CoZKoY1_nX^nL3ojNfi0;oWYgC1onJVM85
oiJHd`GoUI[G1_nFXM`6oibaiP?o[]Cd0_neg_D6okKRm@03okCFl_n/anko[<O^00?o[<O^1_nY`^`0
0onW_n_oZ<7/ojS1k005ojS1k0GoZ<;/00?oYl3[ojNojonW_n/02OnW_n/00ol0003oYko[ojS1k007
ojS1k0;oZ<7[2_ooool00ol0003oooooooooo`03ooooo`00;?ooool00ol0003oooooooooo`0aoooo
o`KoWKg_1On1/oD5ogbamPKoW[k_00?o`/GLol;4foo2a=/01?o2a=/2ol74g0Gob<7D0oo6_m<5ol6m
eP?o`k_B1on`^=l2okNff0OoYK_Y0onE_O<3oibkkPKoUl?e1_nRaO800onU`^koXlGaoj?5l@04oj?5
l@GoY/;^00?oXlObojK3k_nV`nh01OnV`nh5ojK2k@03ojG6l?nVa>koY/C^00KoY/C^0onW`nh4ojG9
l`KoY/Sa00?oYlO`ojG?m_nUcoH01OnUcoH3ojO@m@;oZ<3[2?nY_nT3ojRki`;oXj;D1_nNWM<6oiZI
dPKoUYSC1OnEV]L6oiJQg0;oW;7V1On^e?@2ok?Sm`Ko]^;e0_n_co46ojc7kP;oZL;/1OnW_n/7ojS1
k003ojS2k?nW`>_oYl3[00?oYl3[2onW_n/00ol0003oYko[ojS1k005ojS1k0gooooo00?o0000oooo
ooooool00oooool002gooooo0_l0000booooo`KoWKg_1On1/oD5ogbamP?oW[k_1?nN_o03ol;4f`Go
`LCL0oo8`M@5olJod`?o`KgF1Oo3^m84ok2hg`Go]kKH1OnU^nT00on/]^3oW;_^oibkkP05oibkkPKo
Ul?e0onRaO83oi_6mPOoXlGa00?oY/;^oj?7l_nSao800onSao87ojK3kP03ojK2kOnUa_3oYLK`00?o
YLK`1_nVa>h00onSc?GoYLWcojG9l`06ojG9l`?oY/Sa0onSc_H6ojG?mP03ojO0jonX`>_oZ<3[00Co
Z<3[1_nY_nT00onUY]OoXj;Doj>Re004oj>Re0KoWYgC1OnJVM86oiJHd`KoUI[G0onFXM`4ojC2kP?o
[]Cd1OnchoL2okKRm@Ko[loa0on/anh3ojS0j`OoYko[1onX`N`6ojO0j`_oYko[00Co0000ojNojonX
`NcoZ<7/4?ooool00ol0003oooooooooo`03ooooo`00;oooool00ol0003oooooooooo`0`ooooo`Ko
WKg_1On1]?H5ogZbm`OoW[o`00?o`/CKol74g?o1a=`01Oo1a=`00oo8`MCoa[oColJod`05olJod`03
ol6me_o3^m;o`k_B00Go`k_B00?o/;SOokNff?ng]]P01_ng]]P00onU^nWo[;KPojbfh003ojbfh0Oo
W;_^0onG`oD3oiRnlPKoVlKf0onSaO44oig8mPKoXlOb0onV`nh4oj;:m0KoYLK`0_nVa>h5oj?<m@Ko
YLWc0_nQc?H6oj?>mP;oYLof1OnW`>/6ojS0j`;oZKoY1OnUY]L5oj>Re0KoWYgC1_nJVM86oiJHd`?o
UI[G0_nK[N<8ojC2kP03ojkDm?nchoOo/n?g00?o/n?g0ondg?@5ojo?l@03oj[4kOnX`>_oZ<3[00Go
Z<3[1OnW_n/00onX`^coZ<7/ojS1k006ojS1k0?oYl3[3OnW_n/00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo00?ooooo000`ooooo`03o`000?oooooooooo037ooooo1OnM_Nl5oh6dmPGoN[;g
1OnN_o02oiZolPKo`LCL00?o_/GOolJodoo6_m<01Oo6_m<2olFne0Ko`k_B0_o4^]47okNff003okfe
d_n/]^3o[;KP00Go[;KP0onL^nh4ojJhiPKoV;kb0onKa_H4oiS0l`KoWLSf0onSao84oic9m`KoX/[d
0onUa_04oj3<m`KoXlce0_nUbO<6oj7<mP?oXlkf0onW_^X7ojO0j`?oZ<3[0_nVZ=P7ojFVe`GoXj;D
1onNWM<5oiZIdP?oUYSC0onJX]X6oi^]h`KoY<;^0on_gOL00onchoOo]=cdokCLm005okCLm003ojo?
lOnZa>goZ/C]00?oZ/C]1onX`>/00onW_n_oZ<;/ojS2k003ojS2k0KoZ<7/00?oYl3[ojNojonW_n/0
2_nW_n/5ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00oooool0037ooooo00?o
0000ooooooooool0<Oooool5oifmk`GoPKCf1Omj/_L00onN_o3oV[oboiZolP04oiZolP?o`LCL1?nn
aMl5olJod`CoaKkD0oo3^m85olBjd@Co]kKH1?nm]M85ojbfh0;o/k7F1onV^>H3oiRnlP?oXkWY1onH
`?<3oig8mP?oVl7b1onLbOL3oj;:m0CoW<Of1_nPc?L3oj?<m@CoXLOc1OnQc?H2ojJji`KoYkkZ1OnW
`>/00onWZ=OoYZSHojJXf004ojJXf0KoYJKG1_nSX]@3oijMd`?oW9_B1OnJWMH7oiZRfPKoVjgS0_nT
`^h5ojoMm`;o/NCh1_ndg?@00on/bNooZ/C]oj[4k@05oj[4k@?oZ<3[1?nW`>/6ojS2k0;oZ<7/1OnW
`>/8ojNoj`Wooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`03ooooo`00<_ooool2
o`0003;ooooo0_nM_Nl4oijmk`GoP[Gf1Omh/oP6oiZolP03ol74g?nnaMoo_/GO00Co_/GO0oo6_m<6
olFne003ol>kd_o4^]7oa;[A00Goa;[A00?o]kKHokfed_nm]M801?nm]M83ojbfh0Go/k7F1OnV^>H2
ojj_f@KoXkWY1OnH`?<2oj>ij0KoVl7b1OnLbOL2oijok`OoW<Of0onPc?L4oj;1k`KoXLOc00?oXLcf
ojJjionV^^L01?nV^^L6ojNnjP03ojO0jonWZ=OoYjSG00?oYjSG1_nVZ=P6ojFVe`?oXj;D0_nNVm47
oibKdPGoVYgF1_nJX]X5oi^]h`CoZ]?f00?o[mggok7Tn?nai?P01?nai?P2okCLm0Go[<W_1OnZa>d2
ojNnjPOoYl3[0onX`^`2ojS1k0SoYl3[0onW_n/>ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool00_ooool003Cooooo00?o0000ooooooooool0<?ooool6oijmk`GoP[Gf1Omh/oP3oiZo
lP?oU;od1onnaMl00oo6_m?oaKkDolFne004olFne003ol>oe_o4^]7oa;[A00Goa;[A00?o`k[Aokfe
d_nm]M801_nm]M800on/]^3o/k7Fok>aeP05ok>aeP03ojJhi_n^[mWo[ZoI00Co[ZoI1_nS^NT00onH
`??oXkWXoj>ij004oj>ij0KoVl7b00?oW<WgoijokonN_nl01?nN_nl5oic7mP;oY;WX1onR`Nl3oj77
l`?oYkKS1onV^^L3ojNnjP;oYjOF1onWZ=L6ojJXf0?oYJKG0_nQW<l6oijKd@KoW9_B1_nJWMH6oiZR
fP03oi^]honZdoKoZ]?f00CoZ]?f0_n]hoT5ok7Tn0?o[]3b1_n/bNl00onZa>goYkkZojNnjP04ojNn
jPGoYl3[00?oZ<;/ojS1k?nX`N`01?nX`N`6ojO0ja;ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`02ooooo`00=Oooool00ol0003oooooooooo`0`ooooo`KoW[g_0_n2]OH4ohJgm@Co
M;Ci1_nD_o@5okk5g`;o^LKT1Oo5_]@3ol>oePGoa;[A0oo3^]46okfedP03ol2econc/MKo/k7F00Go
/k7F00?o^k3?ojj_fOn^[mT01_n^[mT3oj>ij@?o[:oJ1onS^NP3oi_1lPCoYKOV1_nN_nl00onLaoKo
Y;WXojBij004ojBij0GoX/7_00?oZ:kLojNfhonW]^<01OnW]^<5ojJji`03ojRTdonWYmKoYjOF00Co
YjOF1_nWZ=L5ojJXf003oj>LconQW<ooXIc?00CoXIc?1_nNVm45oibKdPOoVYgF0onJX]X3ojG6l@Co
Z]?f1On]hoT00onai?So[]3bojk@lP05ojk@lP?o[<W_0_nX`N/8ojNnjP03ojO0jonX`^coZ<;/00?o
Z<;/1_nX`N`2ojO0jaKooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`00
=_ooool00ol0003oooooooooo`0`ooooo`?oW[g_1?nO_^h5ohJgm@CoM;Ci1_nD_o@00onnaMoo^LKT
okW6i004okW6i0?oaKkD1Oo3_mH3olBjd@Go`k[A0onm]M84ol2ec`Go/k7F0onk/<l6ojj_f@03okN]
con/[m[o[:oJ00Go[:oJ1OnS^NP2oj^/f0OoYKOV0onN_nl3ojRagPOoY;WX00?oX/7_ojR^g?nX[]`0
0onX[]`7ojNfh`03ojJjionXY=?oZ:CC00?oZ:CC1_nWYmH6ojNXe`03ojJXf?nSW<ooXic?00?oXic?
1_nQW<l5oijKd@KoW9_B0onJWMH3oinfj0OoYLKa00?oZ]?fojgSnOn]hoT01?n]hoT2ok3KmPKo[]3b
00?oZLC]ojS1jonX`N/01?nX`N/6ojNnjPSoZ<;/0onX`N`Kooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool00_ooool003Oooooo0_l0000aooooo`OoWkk^1On6]oD4ogBdn@?oU;od0on<
_oP7okW6i003olFne?o3_mKo`koF00Go`koF00?oa;[Aol>jdOo3^]401Oo3^]400onm]M;o`;G?ol2e
c`04ol2ec`?o/k7F1Onk/<l3ojj_f@Co]jg?1on/[mX00onS^NSoZjcHoj^/f004oj^/f0GoYKOV00?o
[:SCojRag_nX/Mh01OnX/Mh5ojBij003ojZWe?nX[]coZ:kL00GoZ:kL1OnW]^<00onXX]3oZ:CCojRT
d`04ojRTd`OoYjOF0onWZ=L2ojFMcPKoXic?1_nQW<l6oijKd@?oW9_B0onO[N46oinfj0GoYLKa1?nZ
goX00on]hoWo/=_fok3KmP04ok3KmP;o[]3b1OnYa>d6ojS1j`;oYkkZ2_nX`^`Pooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool00_ooool003Wooooo00?o0000ooooooooool0;oooool5
oinnkP;oX[k]1_n<^_@4og:dnPGoS;oh1Onia^@2ojo7k0Ko`koF00?o`<CMol>jdOo3^]401Oo3^]40
0oo2^mCo`;G?ol2ec`06ol2ec`03ok>ae_nk/<oo^k3?00Go^k3?00?o[ZoIokN]cong[Ll01?ng[Ll5
ojb_fP03okBZcon[[=SoZjcH00KoZjcH00?oYKOVojbXdon/Z=<00on/Z=<7ojRagP03ojBij?nZYmCo
ZZOD00?oZZOD1onX[]`00onW]^?oZ:;@ojRRd003ojRRd0GoZ:CC1_nWYmH00onWWlkoYIg>ojFMcP04
ojFMcPKoXic?1_nQW<l3oijKd@;oXJOK1onO[N46oinfj003ojG6lOnZgo[oZ]oj00CoZ]oj0_n]hOT5
ok3KmP;oZlS_1onYa>d3ojS1j`?oYko[2?nX`^`Sooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool00_ooool003[ooooo00?o0000ooooooooool0;oooool00onO_^koX[k]oj:nk@04oj:n
k@KoS;[d1Omb]?X4ohbon003okW6i?n_anco[lO/00Co[lO/0oo3_mH4ol34g@Go`k[A0oo2^m@6ol2e
c`03ol2fd?nk/<oo^k3?00Go^k3?00?o_[;>okN]cong[Ll01_ng[Ll00on/[m[o]:[?okBZc`03okBZ
c`KoZjcH00?o]:S=ojbXdon/Z=<01On/Z=<5ojRagP03ojjUc_nZYmCoZZOD00CoZZOD1_nX[]`00on/
X/goZ:;@ojRRd004ojRRd0KoZ:CC0_nWYmH5ojNOcPGoYIg>1_nSW<l5oj6Lc`03oj:UeonQYm_oXJOK
00CoXJOK1onO[N43oinfj0CoYm[i0_nZgoX6ojgQn@03ok3Km_n[b>ooZlS_00CoZlS_1OnYa>d8ojNo
j`?oZ<;/:?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00;ooooo000kooooo`03
o`000?oooooooooo033ooooo1_nR_^d3ohbjm0?oU;cc1Omc]?T5oh6mnPKo[lO/00?o`koFol34gOo0
a=d01?o0a=d3ol>jd@Go`[_D0oo0]Ll4ol2fd0Go^k3?0onn//h6okN]c`03ok^_c_ndZ/oo]:[?00Go
]:[?0on[[=P4okBXc@Oo[:SC00?oZ;7NojjUc_n^YLh00on^YLh6ojZWe0;oZ:kL1On/X/d5ojRRd0Go
Z:CC00?oZJ7=ojNOc_nWWlh01OnWWlh5ojFMcPOoXic?00?oXIc?oj:UeonRYML00onRYML6oj6Wf`Go
WjgQ0_nVe?P5ojOJn@CoZ>Ck0on]hOT3oj_<l@OoZlS_00?oZLC]ojNojonW_n/02?nW_n/]ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool00Oooool003cooooo00?o0000ooooooooool0
<?ooool3oj:nk@?oY;o/1_nD_?<5og>dn@GoPKgj0on_an`3oik6m0Oo`<CM00?o`k[Aol:ke?o2^m@0
1Oo2^m@00oo0]Loo`;K@ol2fd004ol2fd0?o^k3?1Onn//h4okN]c`?o^jo>1ondZ/l00on[[=So]:S=
okBXc@04okBXc@Go[:SC00?o/jO<ojjUc_n^YLh01?n^YLh5ojZWe003ojnTc?n/X/go[:;=00Go[:;=
1_nXX]000onXY=?oZJ7=ojVQc@03ojVQc@KoYio>1_nUWLh3oj>Lc`?oY:GF1_nRYML7oj6Wf`03oin]
hOnVe?SoY]Ch00CoY]Ch00?oYm[iojSTnonXi?/01?nXi?/00on/dOCoZlcaoj_<l@05oj_<l@?oZlS_
1?nX_n/7ojNojc7ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`01ooooo`00?Ooo
ool2o`00037ooooo1_nT_n`6oiBll`GoLkCi0_n1_OX4ogNko0GoW/Kd1Oo0a=d2okO8i`Ko`[_D00?o
_l?Mol2fd?o0]]001_o0]]000onk/<oo_[;>okjbcP04okjbcP?o]jg?1Onk[lh5okBZc`03okV]c_nd
Z<go]:S=00Go]:S=0on/Z=<4ok>Wc0Ko[ZG>00?oZZODojnTc?n_Y<`00on_Y<`6ojbRc@GoZ:;@00?o
[:?>ojVQcOnYXLd01OnYXLd6ojNOcP?oYIg>0_nVY]D7ojBUePGoXZGG1_nQYm/2ojG>mPGoY]Ch0onT
ho`2ojSTn`Go[=7d1On[c?42ojS1k0OoZ;o[0onW_n/dooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool00Oooool003oooooo00?o0000ooooooooool0;oooool6ojBok0?oU;cc1?nK_O05
og^fn0GoMk_l1OnNa_@00oo0a=go]lSWokO8i`04okO8i`?o`[_D1?no`md6ol2fd003oknkeonn//ko
_[;>00Ko_[;>00?o]jg?ok^_c_nk[lh01?nk[lh3okBZc`Co^Jg>1ondZ<d00on/Z=?o/jO<ok>Wc003
ok>Wc0Go[ZG>00?o/jS>ojnTc?n_Y<`01On_Y<`6ojbRc@03ojRRd?n/Xlko[:?>00?o[:?>1_nYXLd5
ojNOcP03ojRXeOnVY]GoYZKE00CoYZKE1_nTYMH6oj:Ue`;oXJOK1_nUc_H00onVe?SoY>?lojCSo003
ojCSo0?oZmOg1_n/dO@00on[c?7oZ<7/ojS1k004ojS1k0GoZ;o[>Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo007ooooo0010ooooo`03o`000?oooooooooo02oooooo0onT_n`4ojJo
j`KoVkg`1Omk]_P5ogNko0;oW/Kd0on;a?/7okO8i`03ol:ke?no`mgo_l?M00Co_l?M0oo0]]04oknk
e`Ko_[;>00?o_KODok^_c_nk[lh01_nk[lh00ondZ/oo^Jg>okV]cP04okV]cPGo]:S=00?o]jg>ok>W
c?ncYl`01?ncYl`3ojjUcPCo/jS>1_n_Y<`5ojbRc@03ojnVcon/Xlko[:?>00Go[:?>1_nYXLd00onW
WlkoZ:SEojRXe@03ojRXe@KoYZKE1_nTYMH3oj:Ue`CoY<[c1OnUc_H3oj7Qo003ojCSo?n[eoOoZmOg
00GoZmOg0on/dO@3ojW4k@OoZ<7/00?oZ;o[ooooooooool0>oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo007ooooo0011ooooo`03o`000?oooooooooo02oooooo1onV_n/3oi^ml0?o
Wkk^1_n8^_H5og2io0CoRlCk1Ongb>L2oj;:m0Oo_l?M00?o`;K@oknkeono^mL01?no^mL3okjbcPCo
_KOD1_nk[lh00onk]M?o^Jg>okV]cP05okV]cP?o]:S=1?ng[Lh6ok>Wc003ojjUc_ncZ<ko/jS>00Co
/jS>1_n_Y<`00on/X/go[jK?ojnVc`03ojnVc`Ko[:?>1OnYXLd00on[[=SoZ:SEojRXe@05ojRXe@Ko
YZKE0onTYMH4ojG7lPKoY<[c00?oYLkfoj7Qo?nQhO`00onQhO`3ojOJn@GoZmOg00?oZLK^ojW4kOnY
a>d01OnYa>d3ojS1k47ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`01ooooo`00
@_ooool2o`00033ooooo1OnV_n/2ojS0j`KoWkk^1_n8^_H5og2io0CoRlCk00?o]lSWoj;:m?nRb_@0
1?nRb_@5oko3g@;o/l_/1ono^mL00onn//ko_KODokfge004okfge0?o^jo>1?nk]M<7okV]cP03okBX
cOng[Lko]jg>00?o]jg>1OncYl`00one[]7o/jS>ok>XcP05ok>XcPGo[jC<00?o/JcCojnVcon_Y/l0
1On_Y/l6ojbScP03ojVQcOn[[=SoZjcH00?oZjcH1_nXZ=D5ojJVe@03ojK8lOnUao;oYLOb00KoYLOb
0onTb_<4oikOo@03oj7Qo?nWf_WoYm[i00GoYm[i00?oZmOgojW6k_nYa^h00onYa^h5ojW4kDKooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`01ooooo`00A?ooool00ol0003ooooooooo
o`0^ooooo`03ojJojonX`>_oZ<3[00CoZ<3[1_nO_^h3ohRjmPCoU[gb1Omf]oX4ogW1o@KoX/[d00?o
_l?Mok?;k?ncbn`01?ncbn`5oknke`03okW9i_nm]mCo_KOD00Ko_KOD00?o^jo>ok^edonk]M<01?nk
]M<5okV]cP03okVfe_ng[Lko]jg>00Go]jg>00?o/jO<okF^dOne[]400one[]47ok>XcP03ojnTc?na
[=?o/JcC00?o/JcC1_n_Y/l5ojbScP03ojjbg?n[[=SoZjcH00GoZjcH1_nXZ=D00onVY]GoY/SaojK8
l@03ojK8l@KoYLOb0onLg_d3oikOo@CoXmck0onWf_T4ojS7l0KoZLK^00?oZLC]ooooooooool0B?oo
ool00ol0003oooooooooo`07ooooo`7o00000Oooool1ooooo`00AOooool00ol0003oooooooooo`0_
ooooo`KoZ<3[0onO_^h4ojBnk0KoU[gb1Omf]oX4ogW1o@?oX/[d1?n8b?d6ok?;k003oknkeonibNKo
^LWV00?o^LWV1_nm]m@00onkb>Go^kGCok^ed`06ok^ed`03okV]c_ni]]Ko^KKF00?o^KKF1Ong[Lh0
0onh^mco]JkAokF^d@05okF^d@Go/jS>00?o];KJok6/dona[=<01Ona[=<6ojnVc`03ojbSc_n^/]co
[[;L00?o[[;L1on[[=P3ojRXe@?oYl_c1_nVb?42ojG7lPGoW=km0_nOg?`5oj?Ln`;oZ<Sa1onXao03
ojW6kTkooooo00?o0000ooooooooool01_ooool1o`00007ooooo0Oooool004Kooooo00?o0000oooo
ooooool0<?ooool2ojS0j`?oZ<7[1onT_^`3oiJmlP?oW[k_1_n7^oL4og2mo@KoR<Sm0oncbn`3oiG<
n`Ko^LWV0onm]m@4ok_8i@Ko^kGC00?o^LWWokVfe_ni]]H01?ni]]H3okN]cPCo^;_L1_ne[]43ok>X
cPCo];KJ1_na[=<5ojnVc`03ok2lhon^/]co[[;L00Go[[;L1On[[=P00onUcoKoYl_cojO;l`05ojO;
l`?oY/Sa1OnJgOh00onLg_goWmcloioLo004oioLo003oj?LnonXb?7oZ<Sa00CoZ<Sa1OnXao1Boooo
o`03o`000?oooooooooo00Kooooo0Ol00001ooooo`7ooooo0017ooooo`;o0000<Oooool5ojS1j`Go
Y;k/0_nW_n/6oijnk`KoQk_g1?m`_Od3ohS8o@CoML?n1OnEc?/6okW9iP03okfge?nkb>Go^lSU00Co
^lSU0onk]M<4okW9i`Ko^KKF00?o]jg>okRkg?nh^m`01?nh^m`6okF^d@03ok>Xc_nd]][o];KJ00Co
];KJ1_na[=<00on_Y/oo/;cSok2lh`03ok2lh`Oo[[;L00?oZjcHojG?m_nUcoH00onUcoH5ojO;l`Co
U]gn0onJgOh4oicKo@?oWmcl1?nWbO46ojS8l@03ojS7l?oooooooooo05Cooooo00?o0000oooooooo
ool01Oooool1o`00007ooooo0Oooool004Wooooo00?o0000ooooooooool0;oooool5ojS1j`03ojBn
k?nW_n_oYko[00CoYko[1_nN_^l3ohNkm`CoV;kb1Omj^_X5ogG3oPGoULck0onibNH4oic>n@Ko^lSU
00?o^kGCokW9ionibNL00onibNL5okVfeP;o/lg]1_nh^m`5okF^d@;o]<KW1_nd]]X5ok6/d`03ojo9
kOn`_>?o/;cS00Go/;cS0on^/]`4oj;Cn@KoYLof00?oYl_coiKMo_nFgOh01?nFgOh2oi[Io@GoW=_m
0_nVb?87ojO9l@?oZ<SaF_ooool00ol0003oooooooooo`04ooooo`7o00000Oooool1ooooo`00B_oo
ool00ol0003oooooooooo`0_ooooo`;oZ<7[1?nW`N`6ojNoj`?oW[k_1?nT_^`6oiRnlP;oN[[j1?n@
__H5ogJno@GoNlSo1_nLc_T3ok_8i@CoWM3j1OnibNL00oni]]Ko/lg]ok?=k@04ok?=k@Ko^;_L00?o
]JkAokC6ionda^L01?nda^L6okBffP03ok6/don_bNgo[lW]00?o[lW]1On`_><3oi_Fo0KoX]?i0onU
coH5oi;LoP03oiKMo_nJfOgoV]Wm00CoV]Wm00?oW=_mojK8l_nVb?801?nVb?85ojO9lEoooooo00?o
0000ooooooooool00oooool1o`00007ooooo0Oooool004_ooooo00?o0000ooooooooool0;oooool6
ojO1k0?oYko[0onX`N/7ojBnk0?oV;kb0onQ_^h6oi2nmPGoM[km1Omkb?l3oic>n@CoO/_o1_nMd?X2
okW9i`CoV=;l1_nccNd3okRkg0CoYm7f1_nda^L3okBffP?oYM7g1_n_bNd00on`_>?oVmKloi_Fo005
oi_Fo0?oX]?i1On>fol3oi;LoPCoVMKm0onJfOd4ojG8lPKoY/Sb00?oYlWaooooooooool0H?ooool0
0ol0003oooooooooo`03ooooo`7o00000Oooool1ooooo`00C?ooool2o`00033ooooo1?nW`N`2ojK0
k0KoZ<7[1OnT_^`2ojNoj`KoXKk^0on@__H3oijok`KoRkkh1_me`_h5ogk;o`?oWM3j0omncOl6oiSB
o0?o/lg]1?n@doh6ojOAmP?o]<KW0onFeOd6ojGAm`?o[lW]1OnBf?h3oi_Fo0GoRMWo0on>fol3oiWB
n`GoVMKm0onUa_46ojG8lP?oY/SbI_ooool00ol0003oooooooooo`03ooooo`7o00000Oooool004ko
oooo00?o0000ooooooooool0;_ooool00onW`NcoY/3/ojK0k003ojK0k0KoZ<7[00?oY;k/ojNojonW
_n/01?nW_n/4oj6nkP;oY[o[1_nN_nl6oh^nn0?oML;n1?n9_oP5ogO5oPGoO/go0onHd_`4ogc>o`Ko
T=?n0onWdOH3ohGDo`KoU]Gm0onUdOL5ohSGo`?oT]Sn1On9e_l3ohWIo`?oV/ci1_nId_/00onIe_go
YLKaojG6l@05ojG6l@?oYLSbK?ooool00ol0003oooooooooo`02ooooo`7o00000Oooool004oooooo
00?o0000ooooooooool0;oooool5ojK0k0?oZ<7[1?nW`N`6ojNoj`03oj6nk_nV_n_oY[o[00?oY[o[
1_nN_nl3oh^nn0CoWKo`1_n9_oP2ogO5oPCoSL3h1_mka_h5ogc>o`?oT=?n1Omkcol4ohGDo`?oU]Gm
1On0dol3ohSGo`GoSM3n0on9e_l3oig8mPKoV/ci0onId_/4ojG4l0GoYLKaLOooool01Ol0003ooooo
oooooooooooo0000007ooooo001@ooooo`03o`000?oooooooooo02oooooo1OnV`>`7ojO1k0?oYko[
1?nX`N/5ojJoj`?oW[o_1?nU_^`6oifol0?oRKoh0onM`?46ohg0n0?oNlKn1?nC`_L6oh?7o@?oNloo
0on>aOX6ohG=o`?oP=?o1?nCb?X5ohg@oP;oXLGb1_nMb?H3oi[<n@CoYL;^1_nUa?000onUa_7ooooo
ooooo`1booooo`05o`000?ooooooooooooooool000000Oooool0057ooooo0_l0000`ooooo`GoY/3/
1OnW`N`2ojK0k0OoZ<7[0_nV_n/3ojS1j`OoYKk/0onM_o04ojBnk0GoWL3a0on=`?P4oio0l0KoTl;g
0on3aod3oic3l`KoS/Gj0on5cOl4oic4m0KoTlSj00?oSM3noj75l_nQaO801?nQaO83oig8mP?oYL7]
1onU`^h3ojG4l7Sooooo00Co0000oooooooooooo00000Oooool005?ooooo00?o0000ooooooooool0
;_ooool5ojK0k003ojO1k?nV`>coY/3/00CoY/3/1OnX`N/00onV`NcoZ<7[ojS1j`04ojS1j`GoYKk/
0_nX`>/7ojBnk0;oWL3a1?nU_^`6oio0l0?oTl;g0onR_nh6oic3l`?oS/Gj1?nQ`O06oic4m0?oTlSj
0onS`^l5oj75lP;oY[o[1_nU`Nd5ojG2kWgooooo00?o0000ooooool000000Oooool005Cooooo00?o
0000ooooooooool0;_ooool2ojK0k0CoYko[1_nV`>`00onX`N_oY/7/ojK1k003ojK1k0KoZ<7[00?o
YKk/ojS0jonX`>/01?nX`>/5ojBnk003ojS0jonU_^coYKk/00GoYKk/0onO`?03ojJnj`KoX[o^0onL
`o<4ojBok0KoXL7`0onLa?@3ojFok0KoXl;_00?oXLGbojJojonV_n/01?nV_n/6ojG1k@03ojG2k_oo
oooooooo07kooooo00?o0000ooooool000000Oooool005Gooooo00?o0000ooooooooool0;_ooool6
ojNoj`?oY/3/1?nV_n`5ojK1k0?oZ<7[1?nW`N`6ojS0j`03ojBnk?nX`>_oZ<3[00?oZ<3[1OnU_^`2
ojS0j`KoY[k[1?nR_nh2ojNoj`OoY;o/0onQ`O02ojNnj`OoYKo/0onS`^l4ojNoj`KoY[o[0onU`Nf4
ooooo`7o00000Oooool1o`000000E_ooool2o`0002oooooo1_nW_n/7ojJok0;oY/7/1?nV`>`6ojO1
k0?oZ<3[1?nW`N`5ojS0j`03ojFnk?nX`>_oZ<3[00CoZ<3[1_nV_^/00onR_nkoYko[ojNoj`03ojNo
j`GoY;o/0_nX`>/5ojNnj`GoYKo/0_nX`>/7ojNoj`?oY[o[R_ooool2o`000000F?ooool00ol0003o
ooooooooo`0]ooooo`KoYko[1OnV_n`2ojNoj`KoY/3/0onW`N`3ojK0k0OoYl7/0_nX`>/4ojO1k0Ko
Z<3[0onV_^/3ojS1j`KoYko[00?oY;o/ojS0jonX`>/01?nX`>/5ojNnj`03ojFok?nX`>_oZ<3[00Co
Z<3[1OnW_n^=ooooo`?o0000001Iooooo`03o`000?oooooooooo02gooooo1_nW_n/00onV_ncoYko[
ojNoj`04ojNoj`CoY/3/0_nW_n/6ojK0k0GoYl7/00?oY/3/ojO1k?nW`N`01OnW`N`3ojS0j`?oYl7/
1_nX`N/3ojNoj`CoZ<7/1_nX`>/2ojNnj`CoZ<;/1_nX`>/00onW_n_oooooooooo`2:ooooo`Co0000
0oooool005[ooooo00?o0000ooooooooool0;Oooool3ojNoj`CoZ;oZ1_nW_n/00onV`>coYko[ojNo
j`03ojNoj`KoY/3/00?oYl7/ojK0k?nV`>`00onV`>`5ojO1k0;oY/3/1_nW`N`4ojS1j`;oY/7/1onX
`N`3ojS0j`?oY/7]1_nX`^`3ojS0jhcooooo0ol00007ooooo`00Foooool00ol0003oooooooooo`0]
ooooo`OoZ;oZ0onW_n/3ojRoj`KoYko[0onV`>`4ojNoj`GoY/3/00?oYl7/ojK0k?nV`>`01?nV`>`6
ojO1k003ojS1jonV`NcoY/7/00?oY/7/1OnX`N`00onV`>coY/7]ojK1k@05ojK1k@?oZ<;/SOooool4
o`0000[ooooo001Looooo`;o0000;_ooool5ojRojP;oZ<3[1_nX_n/3ojNoj`CoZ;o[1_nW_n/2ojK0
k0CoYko[1_nV`>`3ojO1k0?oY/3/1_nV`N`00onX`NcoY/3/ojK0k003ojK0k0GoY/7]SOooool4o`00
00kooooo001Nooooo`03o`000?oooooooooo02cooooo00?oZ;oZojS0jonX`>/01?nX`>/4ojRoj`;o
Z<3Z1onX_n/3ojNoj`;oZ;o[1onW_n/3ojK0k0?oYko[1_nV`>`3ojK1k0CoYl3[1OnV`>`00onV`Ngo
ooooooooo`2:ooooo`Co00004_ooool005oooooo00?o0000ooooooooool0;Oooool6ojS0j`03ojRo
jonX`>[oZ<3Z00?oZ<3Z1OnX_n/2ojRojPGoZ;o[1OnW_n/2ojRojPKoYko[0onV`>`4ojNoj`KoYl3[
0_nV`>b;ooooo`Co00005_ooool0063ooooo00?o0000ooooooooool0;Oooool3ojS0j`CoZ<7[1OnX
`>X00onX_n_oZ;oZojRojP04ojRojPGoZ;o[00?oYko[ojRoj_nX_nX01?nX_nX4ojNoj`;oZ;oZ1onW
_n/3ojO0jhcooooo0ol0000Jooooo`00HOooool2o`0002oooooo1_nX`N/2ojS0jPCoZ<7[1_nX_nX2
ojRoj`[oZ;oZ00?oYko[ojRoj_nX_nX00onX_nX5ojNojhcooooo1?l0000Mooooo`00Hoooool00ol0
003oooooooooo`0]ooooo`?oZ<7[0_nW`>`7ojS1j`?oZ;oZ0onX`N/9ojRojP?oZ<3[1_nX_nX00onW
_n_oooooooooo`29ooooo`Co00008Oooool006Cooooo00?o0000ooooooooool0;Oooool5ojO0k0Go
Z<7[0_nW`>`6ojS1j`?oZ;oZ0onX`N/6ojS0j`?oZ;oZR_ooool4o`0002Gooooo001Uooooo`03o`00
0?oooooooooo02gooooo1OnW`>`00onX`N_oYl3/ojO0k004ojO0k0CoZ<7[0_nW`>`6ojS1j`CoZ<3[
R_ooool4o`0002Wooooo001Vooooo`;o0000;_ooool<ojO0k003ojS1jonW`>coYl3/00?oYl3/1_nX
`N/00onX`>_oooooooooo`27ooooo`?o0000;Oooool006Sooooo00?o0000ooooooooool0;?oooolB
ojO0k0?oZ<7[R?ooool4o`00033ooooo001Yooooo`03o`000?oooooooooo02cooooo0onW`>`4ojNo
j`SoYl3/ROooool4o`0003Cooooo001Zooooo`03o`000?oooooooooo02cooooo1onW_n/2ojO0k8[o
oooo1?l0000hooooo`00Joooool2o`0002gooooo1OnW_n^9ooooo`Co0000??ooool006gooooo00?o
0000ooooooooool0:oooool00onW_n_oooooooooo`27ooooo`?o0000@?ooool006kooooo00?o0000
ooooooooool0:_ooool00ol0003oooooooooo`23ooooo`Co0000@oooool006oooooo00?o0000oooo
ooooool0:Oooool00ol0003oooooooooo`1oooooo`Co0000Aoooool0073ooooo0_l0000Yooooo`03
o`000?oooooooooo07_ooooo1?l0001;ooooo`00L_ooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo07Oooooo1?l0001?ooooo`00Loooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo07Cooooo0ol0001Cooooo`00M?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo
oooo073ooooo1?l0001Fooooo`00MOooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
06cooooo1?l0001Jooooo`00M_ooool2o`0002?ooooo00?o0000ooooooooool0J?ooool4o`0005ko
oooo001hooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0I?ooool4o`0006;ooooo
001iooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0HOooool3o`0006Kooooo001j
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0GOooool4o`0006Wooooo001koooo
o`;o00007_ooool00ol0003oooooooooo`1Iooooo`Co0000KOooool007gooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`1Eooooo`Co0000LOooool007kooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`1Aooooo`Co0000MOooool007oooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`1>ooooo`?o0000NOooool0083ooooo0_l0000Iooooo`03o`000?oooooo
oooo04[ooooo1?l0001looooo`00P_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
04Kooooo1?l00020ooooo`00Poooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04;o
oooo1?l00024ooooo`00Q?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo03kooooo
1?l00028ooooo`00QOooool2o`0001?ooooo00?o0000ooooooooool0??ooool3o`0008cooooo0027
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0>?ooool4o`0008oooooo0028oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0=?ooool4o`0009?ooooo0029ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool0<?ooool4o`0009Oooooo002:ooooo`;o0000
3_ooool00ol0003oooooooooo`0/ooooo`Co0000Voooool008cooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0Yooooo`?o0000Woooool008gooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0Uooooo`Co0000X_ooool008kooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0Qooooo`Co0000Y_ooool008oooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0Mooooo`Co0000Z_ooool0093ooooo0_l00008ooooo`03o`000?oooooooooo01Wooooo
1?l0002^ooooo`00T_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Kooooo0ol0
002booooo`00Toooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01;ooooo1?l0002e
ooooo`00U?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00kooooo1?l0002ioooo
o`00UOooool2o`0000?ooooo00?o0000ooooooooool02_ooool4o`000;gooooo002Gooooo`04o`00
0?ooooooooooo`0000Sooooo1?l00031ooooo`00V?ooool00ol0003oooooo`000005ooooo`?o0000
aOooool009Wooooo0_l000000ooooooo0000o`000002o`000<Sooooo002Jooooo`;o0000c?ooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0538698, 0.0432538, \
0.0035044, 0.0035044}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[.12586 .2075 -12 -8.99448 ]
[.12586 .2075 0 .00552 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.56094 .0364 -5.16972 -9 ]
[.56094 .0364 .83028 0 ]
[.75679 .08071 0 -6.17777 ]
[.75679 .08071 12 2.82223 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.9429 .3657 0 -5.9083 ]
[.9429 .3657 6 3.0917 ]
[.02494 .25992 -18 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.01611 .31527 -18 -2.78472 ]
[.01611 .31527 0 6.21528 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00254 .43215 -12 -2.88407 ]
[-0.00254 .43215 0 6.11593 ]
[-0.0124 .49393 -12 -2.93688 ]
[-0.0124 .49393 0 6.06312 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
[(-2)] .12586 .2075 1 .99877 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.56863 .04703 m
.57247 .05235 L
s
[(2)] .56094 .0364 .72324 1 Mshowa
.125 Mabswid
.18558 .19702 m
.18832 .19985 L
s
.23703 .17687 m
.23971 .17975 L
s
.28951 .15632 m
.29214 .15925 L
s
.39772 .11395 m
.40023 .11699 L
s
.4535 .09211 m
.45595 .0952 L
s
.51046 .06981 m
.51284 .07294 L
s
.08568 .23614 m
.08851 .23887 L
s
.62804 .02377 m
.63027 .02701 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.7445 .0853 m
.73835 .08759 L
s
[(-2)] .75679 .08071 -1 .37284 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.93037 .36962 m
.92411 .37158 L
s
[(2)] .9429 .3657 -1 .31296 Mshowa
.125 Mabswid
.7708 .12553 m
.7671 .12688 L
s
.79613 .16428 m
.79242 .1656 L
s
.82054 .20161 m
.81682 .20291 L
s
.86679 .27235 m
.86305 .2736 L
s
.88871 .30589 m
.88497 .30711 L
s
.9099 .3383 m
.90615 .3395 L
s
.71716 .04348 m
.71349 .04489 L
s
.95018 .39992 m
.94642 .40107 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(-20)] .02494 .25992 1 -0.39157 Mshowa
.02837 .31059 m
.0345 .30825 L
s
[(-10)] .01611 .31527 1 -0.38117 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.00981 .42772 m
.01599 .4255 L
s
[(10)] -0.00254 .43215 1 -0.3591 Mshowa
0 .48963 m
.0062 .48748 L
s
[(20)] -0.0124 .49393 1 -0.34736 Mshowa
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.652 .752 .923 r
.39362 .69478 .40169 .70177 .4152 .69802 .40717 .69104 Mtetra
.655 .754 .922 r
.40717 .69104 .4152 .69802 .42878 .69429 .42079 .68718 Mtetra
.658 .752 .92 r
.42079 .68718 .42878 .69429 .44242 .69046 .43448 .68323 Mtetra
.659 .75 .918 r
.43448 .68323 .44242 .69046 .45614 .68653 .44824 .67923 Mtetra
.658 .749 .917 r
.44824 .67923 .45614 .68653 .46992 .68255 .46207 .67524 Mtetra
.653 .748 .92 r
.46207 .67524 .46992 .68255 .48378 .67857 .47597 .6714 Mtetra
.651 .753 .924 r
.47597 .6714 .48378 .67857 .4977 .67468 .48994 .66759 Mtetra
.654 .757 .925 r
.48994 .66759 .4977 .67468 .5117 .67087 .50398 .66365 Mtetra
.656 .755 .922 r
.50398 .66365 .5117 .67087 .52577 .66702 .5181 .65961 Mtetra
.656 .75 .919 r
.5181 .65961 .52577 .66702 .53991 .66303 .53229 .65558 Mtetra
.658 .751 .919 r
.53229 .65558 .53991 .66303 .55412 .65899 .54655 .65147 Mtetra
.653 .749 .92 r
.54655 .65147 .55412 .65899 .56841 .65495 .56088 .64751 Mtetra
.647 .75 .924 r
.56088 .64751 .56841 .65495 .58277 .65086 .5753 .64371 Mtetra
.636 .756 .935 r
.5753 .64371 .58277 .65086 .59721 .64678 .5898 .64021 Mtetra
.628 .771 .949 r
.5898 .64021 .59721 .64678 .61172 .64276 .60438 .63682 Mtetra
.623 .79 .962 r
.60438 .63682 .61172 .64276 .62631 .63877 .61905 .63336 Mtetra
.62 .807 .972 r
.61905 .63336 .62631 .63877 .64098 .63478 .63379 .62975 Mtetra
.62 .821 .977 r
.63379 .62975 .64098 .63478 .65573 .63074 .64861 .62596 Mtetra
.624 .831 .98 r
.64861 .62596 .65573 .63074 .67055 .62663 .6635 .62195 Mtetra
.629 .837 .98 r
.6635 .62195 .67055 .62663 .68545 .62243 .67847 .61771 Mtetra
.638 .839 .978 r
.67847 .61771 .68545 .62243 .70042 .61814 .69351 .61325 Mtetra
.647 .838 .974 r
.69351 .61325 .70042 .61814 .71547 .61378 .70861 .60857 Mtetra
.656 .831 .967 r
.70861 .60857 .71547 .61378 .7306 .60937 .72378 .6037 Mtetra
.665 .82 .958 r
.72378 .6037 .7306 .60937 .74581 .60496 .73902 .59867 Mtetra
.67 .804 .947 r
.73902 .59867 .74581 .60496 .7611 .60058 .75433 .59357 Mtetra
.67 .784 .935 r
.75433 .59357 .7611 .60058 .77648 .59625 .76973 .58857 Mtetra
.663 .764 .925 r
.76973 .58857 .77648 .59625 .79194 .59194 .78523 .58387 Mtetra
.658 .753 .92 r
.78523 .58387 .79194 .59194 .80749 .58756 .80082 .57934 Mtetra
.654 .749 .919 r
.80082 .57934 .80749 .58756 .82312 .58319 .81652 .57495 Mtetra
.656 .75 .92 r
.81652 .57495 .82312 .58319 .83883 .57877 .83229 .57049 Mtetra
.655 .75 .92 r
.83229 .57049 .83883 .57877 .85462 .57419 .84816 .56602 Mtetra
.656 .755 .922 r
.84816 .56602 .85462 .57419 .87049 .56957 .8641 .56146 Mtetra
.659 .759 .923 r
.8641 .56146 .87049 .56957 .88646 .56503 .88012 .55675 Mtetra
.658 .755 .921 r
.88012 .55675 .88646 .56503 .90252 .56058 .89623 .55207 Mtetra
.654 .748 .919 r
.89623 .55207 .90252 .56058 .91868 .55613 .91245 .54753 Mtetra
.653 .747 .919 r
.91245 .54753 .91868 .55613 .93493 .55161 .92876 .54302 Mtetra
.654 .749 .919 r
.92876 .54302 .93493 .55161 .95125 .547 .94516 .53844 Mtetra
.656 .752 .92 r
.94516 .53844 .95125 .547 .96765 .54226 .96165 .53376 Mtetra
.658 .755 .922 r
.96165 .53376 .96765 .54226 .98415 .53755 .97821 .52895 Mtetra
.655 .754 .922 r
.38547 .68777 .39362 .69478 .40717 .69104 .39906 .6839 Mtetra
.658 .752 .919 r
.39906 .6839 .40717 .69104 .42079 .68718 .41273 .67992 Mtetra
.659 .75 .917 r
.41273 .67992 .42079 .68718 .43448 .68323 .42646 .6759 Mtetra
.657 .749 .917 r
.42646 .6759 .43448 .68323 .44824 .67923 .44027 .67191 Mtetra
.651 .749 .921 r
.44027 .67191 .44824 .67923 .46207 .67524 .45414 .6681 Mtetra
.651 .754 .925 r
.45414 .6681 .46207 .67524 .47597 .6714 .46808 .66427 Mtetra
.656 .757 .924 r
.46808 .66427 .47597 .6714 .48994 .66759 .4821 .66024 Mtetra
.656 .752 .92 r
.4821 .66024 .48994 .66759 .50398 .66365 .49619 .6562 Mtetra
.658 .751 .919 r
.49619 .6562 .50398 .66365 .5181 .65961 .51035 .6521 Mtetra
.652 .749 .92 r
.51035 .6521 .5181 .65961 .53229 .65558 .52459 .64816 Mtetra
.641 .749 .927 r
.52459 .64816 .53229 .65558 .54655 .65147 .5389 .64458 Mtetra
.618 .757 .945 r
.5389 .64458 .54655 .65147 .56088 .64751 .5533 .64159 Mtetra
.601 .783 .967 r
.5533 .64159 .56088 .64751 .5753 .64371 .56778 .63871 Mtetra
.585 .808 .984 r
.56778 .63871 .5753 .64371 .5898 .64021 .58235 .63579 Mtetra
.571 .823 .993 r
.58235 .63579 .5898 .64021 .60438 .63682 .59701 .63284 Mtetra
.564 .836 .996 r
.59701 .63284 .60438 .63682 .61905 .63336 .61175 .62975 Mtetra
.566 .849 .997 r
.61175 .62975 .61905 .63336 .63379 .62975 .62657 .62635 Mtetra
.573 .859 .996 r
.62657 .62635 .63379 .62975 .64861 .62596 .64146 .62264 Mtetra
.583 .867 .995 r
.64146 .62264 .64861 .62596 .6635 .62195 .65643 .61865 Mtetra
.594 .872 .993 r
.65643 .61865 .6635 .62195 .67847 .61771 .67147 .61438 Mtetra
.606 .876 .992 r
.67147 .61438 .67847 .61771 .69351 .61325 .68658 .60983 Mtetra
.621 .879 .989 r
.68658 .60983 .69351 .61325 .70861 .60857 .70176 .60499 Mtetra
.637 .88 .986 r
.70176 .60499 .70861 .60857 .72378 .6037 .71699 .59983 Mtetra
.654 .878 .981 r
.71699 .59983 .72378 .6037 .73902 .59867 .73229 .59437 Mtetra
.666 .868 .976 r
.73229 .59437 .73902 .59867 .75433 .59357 .74764 .58874 Mtetra
.673 .854 .969 r
.74764 .58874 .75433 .59357 .76973 .58857 .76307 .58307 Mtetra
.68 .836 .959 r
.76307 .58307 .76973 .58857 .78523 .58387 .77857 .57736 Mtetra
.681 .807 .942 r
.77857 .57736 .78523 .58387 .80082 .57934 .79415 .57175 Mtetra
.668 .773 .929 r
.79415 .57175 .80082 .57934 .81652 .57495 .80986 .56674 Mtetra
.659 .754 .921 r
.80986 .56674 .81652 .57495 .83229 .57049 .82569 .56209 Mtetra
.654 .749 .919 r
.82569 .56209 .83229 .57049 .84816 .56602 .84161 .55761 Mtetra
.655 .75 .92 r
.84161 .55761 .84816 .56602 .8641 .56146 .85763 .55306 Mtetra
.655 .752 .921 r
.85763 .55306 .8641 .56146 .88012 .55675 .87373 .5485 Mtetra
.659 .758 .923 r
.87373 .5485 .88012 .55675 .89623 .55207 .8899 .54372 Mtetra
.659 .757 .922 r
.8899 .54372 .89623 .55207 .91245 .54753 .90616 .53891 Mtetra
.655 .749 .919 r
.90616 .53891 .91245 .54753 .92876 .54302 .92253 .53429 Mtetra
.653 .747 .919 r
.92253 .53429 .92876 .54302 .94516 .53844 .93901 .52971 Mtetra
.654 .749 .919 r
.93901 .52971 .94516 .53844 .96165 .53376 .95557 .52506 Mtetra
.656 .751 .92 r
.95557 .52506 .96165 .53376 .97821 .52895 .97221 .5203 Mtetra
.658 .752 .92 r
.37724 .6806 .38547 .68777 .39906 .6839 .39088 .67661 Mtetra
.659 .75 .918 r
.39088 .67661 .39906 .6839 .41273 .67992 .40459 .67256 Mtetra
.657 .749 .918 r
.40459 .67256 .41273 .67992 .42646 .6759 .41837 .66856 Mtetra
.651 .749 .921 r
.41837 .66856 .42646 .6759 .44027 .67191 .43221 .66476 Mtetra
.651 .755 .925 r
.43221 .66476 .44027 .67191 .45414 .6681 .44613 .66089 Mtetra
.657 .756 .923 r
.44613 .66089 .45414 .6681 .46808 .66427 .46012 .65683 Mtetra
.657 .751 .919 r
.46012 .65683 .46808 .66427 .4821 .66024 .47419 .65276 Mtetra
.656 .75 .919 r
.47419 .65276 .4821 .66024 .49619 .6562 .48832 .6487 Mtetra
.644 .747 .924 r
.48832 .6487 .49619 .6562 .51035 .6521 .50253 .64503 Mtetra
.613 .751 .944 r
.50253 .64503 .51035 .6521 .52459 .64816 .51681 .64222 Mtetra
.585 .777 .971 r
.51681 .64222 .52459 .64816 .5389 .64458 .53118 .63974 Mtetra
.555 .802 .991 r
.53118 .63974 .5389 .64458 .5533 .64159 .54564 .63738 Mtetra
.528 .814 .998 r
.54564 .63738 .5533 .64159 .56778 .63871 .5602 .63511 Mtetra
.525 .834 1 r
.5602 .63511 .56778 .63871 .58235 .63579 .57483 .63246 Mtetra
.54 .848 .998 r
.57483 .63246 .58235 .63579 .59701 .63284 .58956 .62934 Mtetra
.571 .855 .996 r
.58956 .62934 .59701 .63284 .61175 .62975 .60435 .62575 Mtetra
.609 .853 .99 r
.60435 .62575 .61175 .62975 .62657 .62635 .61922 .62166 Mtetra
.628 .837 .981 r
.61922 .62166 .62657 .62635 .64146 .62264 .63417 .61741 Mtetra
.637 .824 .972 r
.63417 .61741 .64146 .62264 .65643 .61865 .64919 .61311 Mtetra
.64 .816 .968 r
.64919 .61311 .65643 .61865 .67147 .61438 .6643 .6088 Mtetra
.639 .816 .968 r
.6643 .6088 .67147 .61438 .68658 .60983 .67949 .60448 Mtetra
.637 .824 .972 r
.67949 .60448 .68658 .60983 .70176 .60499 .69476 .60011 Mtetra
.635 .839 .979 r
.69476 .60011 .70176 .60499 .71699 .59983 .7101 .59558 Mtetra
.642 .863 .983 r
.7101 .59558 .71699 .59983 .73229 .59437 .7255 .59054 Mtetra
.651 .881 .983 r
.7255 .59054 .73229 .59437 .74764 .58874 .74095 .58501 Mtetra
.666 .889 .979 r
.74095 .58501 .74764 .58874 .76307 .58307 .75644 .579 Mtetra
.685 .885 .972 r
.75644 .579 .76307 .58307 .77857 .57736 .77197 .57259 Mtetra
.689 .865 .965 r
.77197 .57259 .77857 .57736 .79415 .57175 .78758 .56626 Mtetra
.691 .844 .957 r
.78758 .56626 .79415 .57175 .80986 .56674 .80327 .56004 Mtetra
.686 .808 .94 r
.80327 .56004 .80986 .56674 .82569 .56209 .81906 .55415 Mtetra
.666 .767 .926 r
.81906 .55415 .82569 .56209 .84161 .55761 .83501 .54913 Mtetra
.656 .751 .92 r
.83501 .54913 .84161 .55761 .85763 .55306 .85108 .54451 Mtetra
.655 .75 .92 r
.85108 .54451 .85763 .55306 .87373 .5485 .86725 .53991 Mtetra
.86725 .53991 .87373 .5485 .8899 .54372 .8835 .53528 Mtetra
.659 .757 .922 r
.8835 .53528 .8899 .54372 .90616 .53891 .89983 .53045 Mtetra
.66 .758 .922 r
.89983 .53045 .90616 .53891 .92253 .53429 .91625 .52555 Mtetra
.655 .75 .92 r
.91625 .52555 .92253 .53429 .93901 .52971 .93278 .52085 Mtetra
.653 .747 .919 r
.93278 .52085 .93901 .52971 .95557 .52506 .94941 .5162 Mtetra
.654 .749 .919 r
.94941 .5162 .95557 .52506 .97221 .5203 .96614 .51147 Mtetra
.659 .751 .918 r
.36894 .6733 .37724 .6806 .39088 .67661 .38262 .66923 Mtetra
.658 .749 .917 r
.38262 .66923 .39088 .67661 .40459 .67256 .39638 .66519 Mtetra
.651 .749 .921 r
.39638 .66519 .40459 .67256 .41837 .66856 .41019 .66137 Mtetra
.652 .755 .925 r
.41019 .66137 .41837 .66856 .43221 .66476 .42408 .65749 Mtetra
.657 .755 .922 r
.42408 .65749 .43221 .66476 .44613 .66089 .43805 .65341 Mtetra
.657 .751 .919 r
.43805 .65341 .44613 .66089 .46012 .65683 .45209 .6493 Mtetra
.653 .749 .92 r
.45209 .6493 .46012 .65683 .47419 .65276 .4662 .64533 Mtetra
.629 .746 .932 r
.4662 .64533 .47419 .65276 .48832 .6487 .48037 .64211 Mtetra
.588 .758 .959 r
.48037 .64211 .48832 .6487 .50253 .64503 .49462 .63978 Mtetra
.549 .787 .987 r
.49462 .63978 .50253 .64503 .51681 .64222 .50895 .63775 Mtetra
.506 .797 .998 r
.50895 .63775 .51681 .64222 .53118 .63974 .52338 .63602 Mtetra
.505 .822 1 r
.52338 .63602 .53118 .63974 .54564 .63738 .5379 .63378 Mtetra
.551 .844 .998 r
.5379 .63378 .54564 .63738 .5602 .63511 .55251 .63068 Mtetra
.624 .842 .983 r
.55251 .63068 .5602 .63511 .57483 .63246 .56719 .62652 Mtetra
.659 .805 .953 r
.56719 .62652 .57483 .63246 .58956 .62934 .58195 .62189 Mtetra
.671 .766 .922 r
.58195 .62189 .58956 .62934 .60435 .62575 .59677 .617 Mtetra
.672 .736 .898 r
.59677 .617 .60435 .62575 .61922 .62166 .61167 .61206 Mtetra
.669 .717 .884 r
.61167 .61206 .61922 .62166 .63417 .61741 .62664 .60718 Mtetra
.664 .703 .875 r
.62664 .60718 .63417 .61741 .64919 .61311 .6417 .60247 Mtetra
.656 .692 .872 r
.6417 .60247 .64919 .61311 .6643 .6088 .65685 .59811 Mtetra
.648 .689 .875 r
.65685 .59811 .6643 .6088 .67949 .60448 .6721 .59411 Mtetra
.643 .695 .883 r
.6721 .59411 .67949 .60448 .69476 .60011 .68744 .59028 Mtetra
.641 .706 .894 r
.68744 .59028 .69476 .60011 .7101 .59558 .70288 .58652 Mtetra
.64 .725 .909 r
.70288 .58652 .7101 .59558 .7255 .59054 .7184 .5827 Mtetra
.643 .757 .932 r
.7184 .5827 .7255 .59054 .74095 .58501 .734 .57863 Mtetra
.647 .802 .957 r
.734 .57863 .74095 .58501 .75644 .579 .74966 .57407 Mtetra
.667 .855 .972 r
.74966 .57407 .75644 .579 .77197 .57259 .76534 .56844 Mtetra
.686 .886 .972 r
.76534 .56844 .77197 .57259 .78758 .56626 .78102 .5619 Mtetra
.704 .886 .964 r
.78102 .5619 .78758 .56626 .80327 .56004 .79673 .55483 Mtetra
.702 .86 .958 r
.79673 .55483 .80327 .56004 .81906 .55415 .81253 .54807 Mtetra
.697 .833 .948 r
.81253 .54807 .81906 .55415 .83501 .54913 .82842 .54159 Mtetra
.677 .786 .932 r
.82842 .54159 .83501 .54913 .85108 .54451 .84448 .53602 Mtetra
.659 .755 .921 r
.84448 .53602 .85108 .54451 .86725 .53991 .8607 .53121 Mtetra
.655 .749 .92 r
.8607 .53121 .86725 .53991 .8835 .53528 .87702 .52655 Mtetra
.655 .75 .92 r
.87702 .52655 .8835 .53528 .89983 .53045 .89344 .52185 Mtetra
.659 .756 .922 r
.89344 .52185 .89983 .53045 .91625 .52555 .90992 .51695 Mtetra
.66 .758 .922 r
.90992 .51695 .91625 .52555 .93278 .52085 .9265 .51197 Mtetra
.654 .749 .92 r
.9265 .51197 .93278 .52085 .94941 .5162 .94319 .50721 Mtetra
.653 .747 .919 r
.94319 .50721 .94941 .5162 .96614 .51147 .95999 .50248 Mtetra
.659 .75 .917 r
.36056 .66589 .36894 .6733 .38262 .66923 .37429 .66181 Mtetra
.651 .749 .921 r
.37429 .66181 .38262 .66923 .39638 .66519 .38808 .65795 Mtetra
.651 .754 .925 r
.38808 .65795 .39638 .66519 .41019 .66137 .40194 .65408 Mtetra
.657 .755 .922 r
.40194 .65408 .41019 .66137 .42408 .65749 .41588 .64998 Mtetra
.658 .751 .919 r
.41588 .64998 .42408 .65749 .43805 .65341 .42989 .64584 Mtetra
.65 .748 .921 r
.42989 .64584 .43805 .65341 .45209 .6493 .44397 .64194 Mtetra
.616 .745 .938 r
.44397 .64194 .45209 .6493 .4662 .64533 .4581 .63906 Mtetra
.567 .761 .97 r
.4581 .63906 .4662 .64533 .48037 .64211 .47231 .63708 Mtetra
.511 .781 .993 r
.47231 .63708 .48037 .64211 .49462 .63978 .4866 .63558 Mtetra
.485 .798 .999 r
.4866 .63558 .49462 .63978 .50895 .63775 .50099 .63398 Mtetra
.532 .831 .999 r
.50099 .63398 .50895 .63775 .52338 .63602 .51548 .63133 Mtetra
.634 .835 .978 r
.51548 .63133 .52338 .63602 .5379 .63378 .53006 .62706 Mtetra
.678 .787 .932 r
.53006 .62706 .5379 .63378 .55251 .63068 .54471 .62192 Mtetra
.693 .74 .887 r
.54471 .62192 .55251 .63068 .56719 .62652 .55942 .61606 Mtetra
.698 .707 .855 r
.55942 .61606 .56719 .62652 .58195 .62189 .57419 .60964 Mtetra
.687 .674 .832 r
.57419 .60964 .58195 .62189 .59677 .617 .58903 .6034 Mtetra
.676 .651 .818 r
.58903 .6034 .59677 .617 .61167 .61206 .60394 .59754 Mtetra
.665 .635 .81 r
.60394 .59754 .61167 .61206 .62664 .60718 .61893 .59215 Mtetra
.656 .625 .807 r
.61893 .59215 .62664 .60718 .6417 .60247 .634 .58725 Mtetra
.647 .62 .808 r
.634 .58725 .6417 .60247 .65685 .59811 .64917 .58284 Mtetra
.639 .616 .81 r
.64917 .58284 .65685 .59811 .6721 .59411 .66445 .57892 Mtetra
.63 .613 .814 r
.66445 .57892 .6721 .59411 .68744 .59028 .67984 .5755 Mtetra
.622 .615 .823 r
.67984 .5755 .68744 .59028 .70288 .58652 .69534 .57255 Mtetra
.615 .623 .836 r
.69534 .57255 .70288 .58652 .7184 .5827 .71097 .57 Mtetra
.61 .641 .857 r
.71097 .57 .7184 .5827 .734 .57863 .72671 .56764 Mtetra
.619 .678 .884 r
.72671 .56764 .734 .57863 .74966 .57407 .74253 .56472 Mtetra
.633 .72 .91 r
.74253 .56472 .74966 .57407 .76534 .56844 .7584 .56109 Mtetra
.65 .779 .943 r
.7584 .56109 .76534 .56844 .78102 .5619 .7743 .55654 Mtetra
.685 .851 .962 r
.7743 .55654 .78102 .5619 .79673 .55483 .79017 .55035 Mtetra
.709 .886 .962 r
.79017 .55035 .79673 .55483 .81253 .54807 .80601 .54305 Mtetra
.716 .873 .955 r
.80601 .54305 .81253 .54807 .82842 .54159 .82191 .53563 Mtetra
.707 .844 .948 r
.82191 .53563 .82842 .54159 .84448 .53602 .83793 .52869 Mtetra
.686 .799 .935 r
.83793 .52869 .84448 .53602 .8607 .53121 .8541 .52267 Mtetra
.66 .758 .922 r
.8541 .52267 .8607 .53121 .87702 .52655 .87047 .51771 Mtetra
.654 .749 .92 r
.87047 .51771 .87702 .52655 .89344 .52185 .88695 .51298 Mtetra
.655 .75 .92 r
.88695 .51298 .89344 .52185 .90992 .51695 .90353 .50821 Mtetra
.66 .756 .922 r
.90353 .50821 .90992 .51695 .9265 .51197 .92017 .5032 Mtetra
.659 .757 .922 r
.92017 .5032 .9265 .51197 .94319 .50721 .93691 .49816 Mtetra
.654 .749 .92 r
.93691 .49816 .94319 .50721 .95999 .50248 .95378 .49335 Mtetra
.653 .749 .92 r
.3521 .65843 .36056 .66589 .37429 .66181 .36587 .6545 Mtetra
.649 .753 .925 r
.36587 .6545 .37429 .66181 .38808 .65795 .3797 .65065 Mtetra
.657 .756 .923 r
.3797 .65065 .38808 .65795 .40194 .65408 .39361 .64653 Mtetra
.658 .751 .919 r
.39361 .64653 .40194 .65408 .41588 .64998 .4076 .64238 Mtetra
.651 .749 .921 r
.4076 .64238 .41588 .64998 .42989 .64584 .42165 .63845 Mtetra
.611 .744 .94 r
.42165 .63845 .42989 .64584 .44397 .64194 .43574 .63571 Mtetra
.553 .759 .974 r
.43574 .63571 .44397 .64194 .4581 .63906 .4499 .63398 Mtetra
.488 .772 .994 r
.4499 .63398 .4581 .63906 .47231 .63708 .46414 .63286 Mtetra
.482 .798 .999 r
.46414 .63286 .47231 .63708 .4866 .63558 .47849 .63129 Mtetra
.589 .834 .991 r
.47849 .63129 .4866 .63558 .50099 .63398 .49295 .62785 Mtetra
.675 .802 .943 r
.49295 .62785 .50099 .63398 .51548 .63133 .50751 .62275 Mtetra
.706 .747 .884 r
.50751 .62275 .51548 .63133 .53006 .62706 .52214 .61632 Mtetra
.714 .707 .842 r
.52214 .61632 .53006 .62706 .54471 .62192 .53682 .60887 Mtetra
.701 .667 .814 r
.53682 .60887 .54471 .62192 .55942 .61606 .55156 .60152 Mtetra
.686 .643 .801 r
.55156 .60152 .55942 .61606 .57419 .60964 .56635 .59472 Mtetra
.673 .634 .802 r
.56635 .59472 .57419 .60964 .58903 .6034 .58122 .58872 Mtetra
.666 .634 .808 r
.58122 .58872 .58903 .6034 .60394 .59754 .59616 .58322 Mtetra
.66 .636 .815 r
.59616 .58322 .60394 .59754 .61893 .59215 .61119 .57813 Mtetra
.655 .639 .822 r
.61119 .57813 .61893 .59215 .634 .58725 .6263 .57338 Mtetra
.65 .64 .826 r
.6263 .57338 .634 .58725 .64917 .58284 .6415 .56892 Mtetra
.645 .637 .828 r
.6415 .56892 .64917 .58284 .66445 .57892 .6568 .56474 Mtetra
.638 .631 .827 r
.6568 .56474 .66445 .57892 .67984 .5755 .6722 .56091 Mtetra
.63 .622 .824 r
.6722 .56091 .67984 .5755 .69534 .57255 .68771 .55749 Mtetra
.62 .612 .821 r
.68771 .55749 .69534 .57255 .71097 .57 .70334 .5546 Mtetra
.605 .601 .821 r
.70334 .5546 .71097 .57 .72671 .56764 .71913 .55251 Mtetra
.593 .6 .828 r
.71913 .55251 .72671 .56764 .74253 .56472 .73506 .551 Mtetra
.588 .618 .849 r
.73506 .551 .74253 .56472 .7584 .56109 .75112 .54961 Mtetra
.606 .666 .882 r
.75112 .54961 .7584 .56109 .7743 .55654 .76723 .5472 Mtetra
.634 .725 .913 r
.76723 .5472 .7743 .55654 .79017 .55035 .78334 .54342 Mtetra
.671 .803 .946 r
.78334 .54342 .79017 .55035 .80601 .54305 .79941 .53793 Mtetra
.714 .871 .955 r
.79941 .53793 .80601 .54305 .82191 .53563 .81541 .53051 Mtetra
.727 .876 .95 r
.81541 .53051 .82191 .53563 .83793 .52869 .83142 .5226 Mtetra
.714 .845 .945 r
.83142 .5226 .83793 .52869 .8541 .52267 .84756 .5153 Mtetra
.689 .802 .935 r
.84756 .5153 .8541 .52267 .87047 .51771 .86387 .50904 Mtetra
.66 .758 .923 r
.86387 .50904 .87047 .51771 .88695 .51298 .8804 .504 Mtetra
.654 .749 .92 r
.8804 .504 .88695 .51298 .90353 .50821 .89704 .4992 Mtetra
.655 .75 .92 r
.89704 .4992 .90353 .50821 .92017 .5032 .91378 .49435 Mtetra
.661 .758 .922 r
.91378 .49435 .92017 .5032 .93691 .49816 .93059 .48921 Mtetra
.658 .755 .922 r
.93059 .48921 .93691 .49816 .95378 .49335 .9475 .48415 Mtetra
.649 .751 .924 r
.34356 .65101 .3521 .65843 .36587 .6545 .35736 .64715 Mtetra
.655 .755 .924 r
.35736 .64715 .36587 .6545 .3797 .65065 .37124 .64309 Mtetra
.657 .751 .919 r
.37124 .64309 .3797 .65065 .39361 .64653 .3852 .63893 Mtetra
.653 .75 .921 r
.3852 .63893 .39361 .64653 .4076 .64238 .39923 .63489 Mtetra
.614 .743 .937 r
.39923 .63489 .4076 .64238 .42165 .63845 .41329 .63204 Mtetra
.548 .753 .972 r
.41329 .63204 .42165 .63845 .43574 .63571 .4274 .63045 Mtetra
.476 .762 .993 r
.4274 .63045 .43574 .63571 .4499 .63398 .44159 .62958 Mtetra
.483 .793 .999 r
.44159 .62958 .4499 .63398 .46414 .63286 .45589 .62808 Mtetra
.622 .829 .98 r
.45589 .62808 .46414 .63286 .47849 .63129 .47033 .62414 Mtetra
.696 .779 .915 r
.47033 .62414 .47849 .63129 .49295 .62785 .48487 .61832 Mtetra
.726 .732 .856 r
.48487 .61832 .49295 .62785 .50751 .62275 .49949 .61049 Mtetra
.718 .685 .817 r
.49949 .61049 .50751 .62275 .52214 .61632 .51416 .60218 Mtetra
.699 .653 .801 r
.51416 .60218 .52214 .61632 .53682 .60887 .52888 .59455 Mtetra
.684 .645 .805 r
.52888 .59455 .53682 .60887 .55156 .60152 .54365 .58794 Mtetra
.675 .652 .819 r
.54365 .58794 .55156 .60152 .56635 .59472 .55849 .58208 Mtetra
.667 .663 .837 r
.55849 .58208 .56635 .59472 .58122 .58872 .5734 .57688 Mtetra
.655 .672 .854 r
.5734 .57688 .58122 .58872 .59616 .58322 .58841 .5724 Mtetra
.654 .691 .872 r
.58841 .5724 .59616 .58322 .61119 .57813 .60349 .56802 Mtetra
.655 .707 .885 r
.60349 .56802 .61119 .57813 .6263 .57338 .61866 .56361 Mtetra
.657 .716 .891 r
.61866 .56361 .6263 .57338 .6415 .56892 .63392 .5591 Mtetra
.659 .716 .891 r
.63392 .5591 .6415 .56892 .6568 .56474 .64925 .55449 Mtetra
.659 .708 .884 r
.64925 .55449 .6568 .56474 .6722 .56091 .66466 .54985 Mtetra
.655 .692 .872 r
.66466 .54985 .6722 .56091 .68771 .55749 .68017 .54531 Mtetra
.639 .665 .86 r
.68017 .54531 .68771 .55749 .70334 .5546 .69579 .5415 Mtetra
.624 .644 .85 r
.69579 .5415 .70334 .5546 .71913 .55251 .71156 .53835 Mtetra
.608 .622 .839 r
.71156 .53835 .71913 .55251 .73506 .551 .72747 .53598 Mtetra
.588 .6 .832 r
.72747 .53598 .73506 .551 .75112 .54961 .74356 .53467 Mtetra
.573 .595 .837 r
.74356 .53467 .75112 .54961 .76723 .5472 .75982 .53406 Mtetra
.578 .625 .863 r
.75982 .53406 .76723 .5472 .78334 .54342 .77618 .53298 Mtetra
.618 .697 .9 r
.77618 .53298 .78334 .54342 .79941 .53793 .7925 .52985 Mtetra
.661 .772 .932 r
.7925 .52985 .79941 .53793 .81541 .53051 .80877 .52479 Mtetra
.72 .858 .948 r
.80877 .52479 .81541 .53051 .83142 .5226 .82491 .51719 Mtetra
.735 .873 .945 r
.82491 .51719 .83142 .5226 .84756 .5153 .84105 .50891 Mtetra
.718 .842 .94 r
.84105 .50891 .84756 .5153 .86387 .50904 .85732 .50137 Mtetra
.688 .797 .933 r
.85732 .50137 .86387 .50904 .8804 .504 .87379 .49512 Mtetra
.658 .755 .922 r
.87379 .49512 .8804 .504 .89704 .4992 .89049 .4901 Mtetra
.655 .75 .92 r
.89049 .4901 .89704 .4992 .91378 .49435 .9073 .4852 Mtetra
.656 .751 .92 r
.9073 .4852 .91378 .49435 .93059 .48921 .9242 .4802 Mtetra
.661 .758 .922 r
.9242 .4802 .93059 .48921 .9475 .48415 .94117 .47496 Mtetra
.652 .754 .924 r
.33493 .64361 .34356 .65101 .35736 .64715 .34878 .63963 Mtetra
.657 .753 .921 r
.34878 .63963 .35736 .64715 .37124 .64309 .36271 .63545 Mtetra
.656 .751 .92 r
.36271 .63545 .37124 .64309 .3852 .63893 .37671 .63128 Mtetra
.626 .743 .931 r
.37671 .63128 .3852 .63893 .39923 .63489 .39075 .62808 Mtetra
.554 .745 .965 r
.39075 .62808 .39923 .63489 .41329 .63204 .40481 .62648 Mtetra
.476 .754 .991 r
.40481 .62648 .41329 .63204 .4274 .63045 .41894 .62576 Mtetra
.476 .782 .998 r
.41894 .62576 .4274 .63045 .44159 .62958 .43319 .62451 Mtetra
.63 .822 .975 r
.43319 .62451 .44159 .62958 .45589 .62808 .4476 .62046 Mtetra
.706 .77 .902 r
.4476 .62046 .45589 .62808 .47033 .62414 .46214 .61413 Mtetra
.738 .727 .841 r
.46214 .61413 .47033 .62414 .48487 .61832 .47676 .60539 Mtetra
.722 .677 .806 r
.47676 .60539 .48487 .61832 .49949 .61049 .49143 .59649 Mtetra
.698 .655 .804 r
.49143 .59649 .49949 .61049 .51416 .60218 .50613 .58895 Mtetra
.686 .661 .82 r
.50613 .58895 .51416 .60218 .52888 .59455 .52088 .58252 Mtetra
.665 .672 .847 r
.52088 .58252 .52888 .59455 .54365 .58794 .5357 .57752 Mtetra
.649 .696 .881 r
.5357 .57752 .54365 .58794 .55849 .58208 .5506 .57344 Mtetra
.641 .734 .916 r
.5506 .57344 .55849 .58208 .5734 .57688 .56558 .56957 Mtetra
.637 .768 .943 r
.56558 .56957 .5734 .57688 .58841 .5724 .58065 .56565 Mtetra
.639 .786 .952 r
.58065 .56565 .58841 .5724 .60349 .56802 .59581 .56151 Mtetra
.643 .795 .956 r
.59581 .56151 .60349 .56802 .61866 .56361 .61104 .55715 Mtetra
.648 .8 .956 r
.61104 .55715 .61866 .56361 .63392 .5591 .62636 .5526 Mtetra
.654 .802 .954 r
.62636 .5526 .63392 .5591 .64925 .55449 .64175 .54785 Mtetra
.66 .801 .95 r
.64175 .54785 .64925 .55449 .66466 .54985 .65722 .54288 Mtetra
.668 .795 .943 r
.65722 .54288 .66466 .54985 .68017 .54531 .67277 .53768 Mtetra
.67 .779 .931 r
.67277 .53768 .68017 .54531 .69579 .5415 .68839 .53243 Mtetra
.666 .742 .907 r
.68839 .53243 .69579 .5415 .71156 .53835 .70411 .52739 Mtetra
.643 .694 .882 r
.70411 .52739 .71156 .53835 .72747 .53598 .71996 .52329 Mtetra
.611 .649 .863 r
.71996 .52329 .72747 .53598 .74356 .53467 .73601 .52064 Mtetra
.588 .617 .848 r
.73601 .52064 .74356 .53467 .75982 .53406 .75224 .51914 Mtetra
.56 .59 .841 r
.75224 .51914 .75982 .53406 .77618 .53298 .7687 .51905 Mtetra
.559 .605 .856 r
.7687 .51905 .77618 .53298 .7925 .52985 .78529 .51882 Mtetra
.607 .682 .895 r
.78529 .51882 .7925 .52985 .80877 .52479 .80182 .51612 Mtetra
.66 .759 .924 r
.80182 .51612 .80877 .52479 .82491 .51719 .81825 .51107 Mtetra
.727 .852 .94 r
.81825 .51107 .82491 .51719 .84105 .50891 .83451 .5031 Mtetra
.74 .866 .939 r
.83451 .5031 .84105 .50891 .85732 .50137 .85078 .49457 Mtetra
.719 .834 .936 r
.85078 .49457 .85732 .50137 .87379 .49512 .8672 .48693 Mtetra
.679 .784 .929 r
.8672 .48693 .87379 .49512 .89049 .4901 .88387 .48094 Mtetra
.655 .751 .92 r
.88387 .48094 .89049 .4901 .9073 .4852 .90075 .47596 Mtetra
.655 .75 .92 r
.90075 .47596 .9073 .4852 .9242 .4802 .91773 .47098 Mtetra
.659 .754 .92 r
.91773 .47098 .9242 .4802 .94117 .47496 .93478 .46579 Mtetra
.657 .755 .922 r
.32621 .63614 .33493 .64361 .34878 .63963 .34011 .63195 Mtetra
.658 .751 .919 r
.34011 .63195 .34878 .63963 .36271 .63545 .35409 .62772 Mtetra
.642 .746 .925 r
.35409 .62772 .36271 .63545 .37671 .63128 .36812 .62398 Mtetra
.571 .738 .954 r
.36812 .62398 .37671 .63128 .39075 .62808 .38214 .62213 Mtetra
.488 .748 .986 r
.38214 .62213 .39075 .62808 .40481 .62648 .39622 .62137 Mtetra
.461 .763 .995 r
.39622 .62137 .40481 .62648 .41894 .62576 .4104 .62056 Mtetra
.613 .815 .978 r
.4104 .62056 .41894 .62576 .43319 .62451 .42477 .61693 Mtetra
.708 .772 .902 r
.42477 .61693 .43319 .62451 .4476 .62046 .43929 .6105 Mtetra
.745 .73 .838 r
.43929 .6105 .4476 .62046 .46214 .61413 .45393 .60123 Mtetra
.727 .68 .804 r
.45393 .60123 .46214 .61413 .47676 .60539 .4686 .59195 Mtetra
.703 .665 .809 r
.4686 .59195 .47676 .60539 .49143 .59649 .4833 .58426 Mtetra
.683 .676 .836 r
.4833 .58426 .49143 .59649 .50613 .58895 .49802 .57821 Mtetra
.648 .69 .875 r
.49802 .57821 .50613 .58895 .52088 .58252 .51281 .57412 Mtetra
.63 .736 .924 r
.51281 .57412 .52088 .58252 .5357 .57752 .52768 .57062 Mtetra
.622 .775 .954 r
.52768 .57062 .5357 .57752 .5506 .57344 .54264 .56705 Mtetra
.624 .792 .963 r
.54264 .56705 .5506 .57344 .56558 .56957 .55769 .56326 Mtetra
.63 .797 .963 r
.55769 .56326 .56558 .56957 .58065 .56565 .57282 .55926 Mtetra
.637 .798 .96 r
.57282 .55926 .58065 .56565 .59581 .56151 .58804 .55503 Mtetra
.643 .799 .957 r
.58804 .55503 .59581 .56151 .61104 .55715 .60334 .55061 Mtetra
.648 .799 .955 r
.60334 .55061 .61104 .55715 .62636 .5526 .61872 .54601 Mtetra
.653 .801 .954 r
.61872 .54601 .62636 .5526 .64175 .54785 .63418 .54124 Mtetra
.658 .803 .952 r
.63418 .54124 .64175 .54785 .65722 .54288 .64972 .53627 Mtetra
.664 .806 .951 r
.64972 .53627 .65722 .54288 .67277 .53768 .66533 .53107 Mtetra
.67 .809 .95 r
.66533 .53107 .67277 .53768 .68839 .53243 .68102 .52565 Mtetra
.676 .807 .945 r
.68102 .52565 .68839 .53243 .70411 .52739 .69678 .52001 Mtetra
.679 .793 .935 r
.69678 .52001 .70411 .52739 .71996 .52329 .71261 .51428 Mtetra
.665 .748 .912 r
.71261 .51428 .71996 .52329 .73601 .52064 .72857 .50914 Mtetra
.619 .677 .883 r
.72857 .50914 .73601 .52064 .75224 .51914 .74474 .50602 Mtetra
.583 .631 .865 r
.74474 .50602 .75224 .51914 .7687 .51905 .76114 .50458 Mtetra
.549 .594 .851 r
.76114 .50458 .7687 .51905 .78529 .51882 .7778 .5048 Mtetra
.546 .6 .859 r
.7778 .5048 .78529 .51882 .80182 .51612 .7946 .50503 Mtetra
.605 .683 .897 r
.7946 .50503 .80182 .51612 .81825 .51107 .8113 .50234 Mtetra
.671 .766 .921 r
.8113 .50234 .81825 .51107 .83451 .5031 .82786 .49675 Mtetra
.739 .852 .933 r
.82786 .49675 .83451 .5031 .85078 .49457 .84422 .48822 Mtetra
.74 .855 .934 r
.84422 .48822 .85078 .49457 .8672 .48693 .86064 .47961 Mtetra
.713 .822 .932 r
.86064 .47961 .8672 .48693 .88387 .48094 .87723 .47212 Mtetra
.667 .767 .925 r
.87723 .47212 .88387 .48094 .90075 .47596 .89413 .46659 Mtetra
.654 .749 .92 r
.89413 .46659 .90075 .47596 .91773 .47098 .91118 .46157 Mtetra
.655 .75 .92 r
.91118 .46157 .91773 .47098 .93478 .46579 .92833 .4565 Mtetra
.657 .751 .92 r
.31742 .62846 .32621 .63614 .34011 .63195 .33137 .62423 Mtetra
.654 .751 .921 r
.33137 .62423 .34011 .63195 .35409 .62772 .34538 .62009 Mtetra
.602 .74 .941 r
.34538 .62009 .35409 .62772 .36812 .62398 .3594 .61749 Mtetra
.518 .744 .977 r
.3594 .61749 .36812 .62398 .38214 .62213 .37343 .61641 Mtetra
.449 .741 .99 r
.37343 .61641 .38214 .62213 .39622 .62137 .38754 .61609 Mtetra
.569 .8 .987 r
.38754 .61609 .39622 .62137 .4104 .62056 .40183 .61344 Mtetra
.7 .782 .915 r
.40183 .61344 .4104 .62056 .42477 .61693 .41633 .60742 Mtetra
.749 .739 .843 r
.41633 .60742 .42477 .61693 .43929 .6105 .43097 .59806 Mtetra
.736 .69 .806 r
.43097 .59806 .43929 .6105 .45393 .60123 .44567 .58825 Mtetra
.71 .674 .813 r
.44567 .58825 .45393 .60123 .4686 .59195 .46036 .58024 Mtetra
.68 .684 .847 r
.46036 .58024 .4686 .59195 .4833 .58426 .47506 .57445 Mtetra
.638 .706 .896 r
.47506 .57445 .4833 .58426 .49802 .57821 .48981 .57077 Mtetra
.614 .758 .947 r
.48981 .57077 .49802 .57821 .51281 .57412 .50465 .56757 Mtetra
.613 .783 .963 r
.50465 .56757 .51281 .57412 .52768 .57062 .51958 .56413 Mtetra
.621 .789 .962 r
.51958 .56413 .52768 .57062 .54264 .56705 .5346 .56042 Mtetra
.64 .792 .955 r
.5346 .56042 .54264 .56705 .55769 .56326 .5497 .55617 Mtetra
.65 .783 .945 r
.5497 .55617 .55769 .56326 .57282 .55926 .56489 .55166 Mtetra
.654 .771 .935 r
.56489 .55166 .57282 .55926 .58804 .55503 .58016 .54707 Mtetra
.655 .763 .929 r
.58016 .54707 .58804 .55503 .60334 .55061 .59551 .54244 Mtetra
.655 .759 .926 r
.59551 .54244 .60334 .55061 .61872 .54601 .61095 .5378 Mtetra
.61095 .5378 .61872 .54601 .63418 .54124 .62648 .53314 Mtetra
.655 .763 .929 r
.62648 .53314 .63418 .54124 .64972 .53627 .64209 .52844 Mtetra
.655 .772 .935 r
.64209 .52844 .64972 .53627 .66533 .53107 .65779 .52366 Mtetra
.661 .786 .941 r
.65779 .52366 .66533 .53107 .68102 .52565 .67356 .51862 Mtetra
.674 .802 .944 r
.67356 .51862 .68102 .52565 .69678 .52001 .68939 .51303 Mtetra
.681 .807 .943 r
.68939 .51303 .69678 .52001 .71261 .51428 .7053 .50714 Mtetra
.687 .806 .939 r
.7053 .50714 .71261 .51428 .72857 .50914 .72126 .50102 Mtetra
.675 .777 .927 r
.72126 .50102 .72857 .50914 .74474 .50602 .73734 .49537 Mtetra
.624 .699 .899 r
.73734 .49537 .74474 .50602 .76114 .50458 .75366 .49188 Mtetra
.573 .637 .876 r
.75366 .49188 .76114 .50458 .7778 .5048 .77025 .49068 Mtetra
.534 .594 .86 r
.77025 .49068 .7778 .5048 .7946 .50503 .78712 .49135 Mtetra
.542 .606 .867 r
.78712 .49135 .7946 .50503 .8113 .50234 .80411 .49159 Mtetra
.614 .698 .904 r
.80411 .49159 .8113 .50234 .82786 .49675 .82094 .48839 Mtetra
.695 .788 .922 r
.82094 .48839 .82786 .49675 .84422 .48822 .83756 .48168 Mtetra
.751 .854 .927 r
.83756 .48168 .84422 .48822 .86064 .47961 .85402 .47252 Mtetra
.733 .836 .928 r
.85402 .47252 .86064 .47961 .87723 .47212 .87062 .46413 Mtetra
.696 .801 .931 r
.87062 .46413 .87723 .47212 .89413 .46659 .88745 .45731 Mtetra
.657 .755 .922 r
.88745 .45731 .89413 .46659 .91118 .46157 .90456 .4521 Mtetra
.655 .751 .92 r
.90456 .4521 .91118 .46157 .92833 .4565 .92178 .44697 Mtetra
.658 .751 .919 r
.30854 .62068 .31742 .62846 .33137 .62423 .32254 .61638 Mtetra
.637 .745 .927 r
.32254 .61638 .33137 .62423 .34538 .62009 .33657 .61277 Mtetra
.552 .733 .96 r
.33657 .61277 .34538 .62009 .3594 .61749 .35056 .61127 Mtetra
.463 .733 .985 r
.35056 .61127 .3594 .61749 .37343 .61641 .36461 .61096 Mtetra
.495 .77 .993 r
.36461 .61096 .37343 .61641 .38754 .61609 .3788 .60971 Mtetra
.674 .797 .941 r
.3788 .60971 .38754 .61609 .40183 .61344 .39324 .60459 Mtetra
.744 .752 .858 r
.39324 .60459 .40183 .61344 .41633 .60742 .40787 .59583 Mtetra
.749 .706 .811 r
.40787 .59583 .41633 .60742 .43097 .59806 .4226 .58539 Mtetra
.719 .682 .814 r
.4226 .58539 .43097 .59806 .44567 .58825 .4373 .5768 Mtetra
.687 .691 .849 r
.4373 .5768 .44567 .58825 .46036 .58024 .452 .57069 Mtetra
.633 .711 .903 r
.452 .57069 .46036 .58024 .47506 .57445 .46671 .56716 Mtetra
.606 .76 .953 r
.46671 .56716 .47506 .57445 .48981 .57077 .48151 .56412 Mtetra
.608 .78 .963 r
.48151 .56412 .48981 .57077 .50465 .56757 .4964 .56082 Mtetra
.631 .785 .956 r
.4964 .56082 .50465 .56757 .51958 .56413 .51139 .55687 Mtetra
.651 .778 .941 r
.51139 .55687 .51958 .56413 .5346 .56042 .52646 .55236 Mtetra
.656 .76 .926 r
.52646 .55236 .5346 .56042 .5497 .55617 .54162 .54774 Mtetra
.654 .751 .921 r
.54162 .54774 .5497 .55617 .56489 .55166 .55686 .54321 Mtetra
.653 .752 .922 r
.55686 .54321 .56489 .55166 .58016 .54707 .57219 .53867 Mtetra
.654 .754 .923 r
.57219 .53867 .58016 .54707 .59551 .54244 .5876 .53407 Mtetra
.656 .756 .924 r
.5876 .53407 .59551 .54244 .61095 .5378 .6031 .52937 Mtetra
.657 .757 .923 r
.6031 .52937 .61095 .5378 .62648 .53314 .61868 .5246 Mtetra
.658 .756 .922 r
.61868 .5246 .62648 .53314 .64209 .52844 .63435 .51976 Mtetra
.658 .753 .92 r
.63435 .51976 .64209 .52844 .65779 .52366 .65011 .5149 Mtetra
.655 .751 .921 r
.65011 .5149 .65779 .52366 .67356 .51862 .66596 .51014 Mtetra
.657 .76 .926 r
.66596 .51014 .67356 .51862 .68939 .51303 .68189 .50526 Mtetra
.67 .784 .935 r
.68189 .50526 .68939 .51303 .7053 .50714 .69789 .4998 Mtetra
.685 .802 .937 r
.69789 .4998 .7053 .50714 .72126 .50102 .71393 .49368 Mtetra
.692 .805 .935 r
.71393 .49368 .72126 .50102 .73734 .49537 .73004 .48728 Mtetra
.679 .783 .928 r
.73004 .48728 .73734 .49537 .75366 .49188 .74626 .48138 Mtetra
.616 .702 .906 r
.74626 .48138 .75366 .49188 .77025 .49068 .76276 .47812 Mtetra
.557 .634 .883 r
.76276 .47812 .77025 .49068 .78712 .49135 .77957 .47743 Mtetra
.516 .59 .867 r
.77957 .47743 .78712 .49135 .80411 .49159 .79668 .47868 Mtetra
.553 .628 .88 r
.79668 .47868 .80411 .49159 .82094 .48839 .8138 .47821 Mtetra
.636 .724 .911 r
.8138 .47821 .82094 .48839 .83756 .48168 .83073 .47397 Mtetra
.729 .819 .921 r
.83073 .47397 .83756 .48168 .85402 .47252 .84736 .46569 Mtetra
.751 .85 .924 r
.84736 .46569 .85402 .47252 .87062 .46413 .86396 .45641 Mtetra
.723 .82 .925 r
.86396 .45641 .87062 .46413 .88745 .45731 .88075 .44833 Mtetra
.671 .771 .925 r
.88075 .44833 .88745 .45731 .90456 .4521 .89787 .44247 Mtetra
.654 .749 .92 r
.89787 .44247 .90456 .4521 .92178 .44697 .91516 .43731 Mtetra
.655 .751 .921 r
.29958 .61285 .30854 .62068 .32254 .61638 .31361 .60862 Mtetra
.601 .739 .941 r
.31361 .60862 .32254 .61638 .33657 .61277 .32762 .60599 Mtetra
.507 .735 .976 r
.32762 .60599 .33657 .61277 .35056 .61127 .34163 .60513 Mtetra
.449 .731 .987 r
.34163 .60513 .35056 .61127 .36461 .61096 .35571 .60495 Mtetra
.607 .792 .97 r
.35571 .60495 .36461 .61096 .3788 .60971 .37003 .60165 Mtetra
.723 .766 .887 r
.37003 .60165 .3788 .60971 .39324 .60459 .38461 .59435 Mtetra
.76 .73 .825 r
.38461 .59435 .39324 .60459 .40787 .59583 .39937 .5837 Mtetra
.736 .696 .812 r
.39937 .5837 .40787 .59583 .4226 .58539 .41411 .57402 Mtetra
.704 .699 .842 r
.41411 .57402 .4226 .58539 .4373 .5768 .42882 .56691 Mtetra
.638 .707 .897 r
.42882 .56691 .4373 .5768 .452 .57069 .44351 .56319 Mtetra
.601 .754 .951 r
.44351 .56319 .452 .57069 .46671 .56716 .45826 .5603 Mtetra
.604 .774 .961 r
.45826 .5603 .46671 .56716 .48151 .56412 .47311 .55713 Mtetra
.636 .781 .951 r
.47311 .55713 .48151 .56412 .4964 .56082 .48807 .55306 Mtetra
.655 .767 .932 r
.48807 .55306 .4964 .56082 .51139 .55687 .50311 .54846 Mtetra
.653 .751 .922 r
.50311 .54846 .51139 .55687 .52646 .55236 .51824 .54397 Mtetra
.65 .752 .924 r
.51824 .54397 .52646 .55236 .54162 .54774 .53346 .53957 Mtetra
.65 .758 .929 r
.53346 .53957 .54162 .54774 .55686 .54321 .54876 .53511 Mtetra
.65 .761 .931 r
.54876 .53511 .55686 .54321 .57219 .53867 .56414 .5306 Mtetra
.652 .764 .931 r
.56414 .5306 .57219 .53867 .5876 .53407 .57962 .52598 Mtetra
.655 .766 .931 r
.57962 .52598 .5876 .53407 .6031 .52937 .59517 .52125 Mtetra
.657 .767 .93 r
.59517 .52125 .6031 .52937 .61868 .5246 .61082 .51638 Mtetra
.66 .766 .929 r
.61082 .51638 .61868 .5246 .63435 .51976 .62655 .51142 Mtetra
.661 .765 .927 r
.62655 .51142 .63435 .51976 .65011 .5149 .64236 .50639 Mtetra
.661 .762 .925 r
.64236 .50639 .65011 .5149 .66596 .51014 .65826 .50131 Mtetra
.659 .755 .921 r
.65826 .50131 .66596 .51014 .68189 .50526 .67425 .49631 Mtetra
.656 .752 .921 r
.67425 .49631 .68189 .50526 .69789 .4998 .69035 .49142 Mtetra
.668 .771 .927 r
.69035 .49142 .69789 .4998 .71393 .49368 .7065 .486 Mtetra
.69 .798 .932 r
.7065 .486 .71393 .49368 .73004 .48728 .72269 .47963 Mtetra
.696 .802 .931 r
.72269 .47963 .73004 .48728 .74626 .48138 .73894 .47298 Mtetra
.675 .777 .927 r
.73894 .47298 .74626 .48138 .76276 .47812 .75533 .46717 Mtetra
.59 .684 .906 r
.75533 .46717 .76276 .47812 .77957 .47743 .77207 .46484 Mtetra
.527 .622 .889 r
.77207 .46484 .77957 .47743 .79668 .47868 .78915 .46519 Mtetra
.506 .595 .877 r
.78915 .46519 .79668 .47868 .8138 .47821 .80647 .46657 Mtetra
.585 .671 .899 r
.80647 .46657 .8138 .47821 .83073 .47397 .82365 .4645 Mtetra
.681 .761 .912 r
.82365 .4645 .83073 .47397 .84736 .46569 .84057 .45825 Mtetra
.754 .837 .915 r
.84057 .45825 .84736 .46569 .86396 .45641 .85724 .44874 Mtetra
.739 .829 .92 r
.85724 .44874 .86396 .45641 .88075 .44833 .87404 .4399 Mtetra
.696 .797 .927 r
.87404 .4399 .88075 .44833 .89787 .44247 .89112 .4329 Mtetra
.657 .754 .922 r
.89112 .4329 .89787 .44247 .91516 .43731 .90848 .42758 Mtetra
.645 .747 .924 r
.29053 .6049 .29958 .61285 .31361 .60862 .30458 .60097 Mtetra
.561 .731 .955 r
.30458 .60097 .31361 .60862 .32762 .60599 .31858 .59927 Mtetra
.466 .722 .98 r
.31858 .59927 .32762 .60599 .34163 .60513 .33259 .59904 Mtetra
.495 .753 .987 r
.33259 .59904 .34163 .60513 .35571 .60495 .34675 .598 Mtetra
.681 .786 .93 r
.34675 .598 .35571 .60495 .37003 .60165 .36123 .59264 Mtetra
.756 .752 .849 r
.36123 .59264 .37003 .60165 .38461 .59435 .37596 .58301 Mtetra
.755 .713 .813 r
.37596 .58301 .38461 .59435 .39937 .5837 .39077 .57217 Mtetra
.724 .703 .83 r
.39077 .57217 .39937 .5837 .41411 .57402 .40552 .56371 Mtetra
.662 .707 .881 r
.40552 .56371 .41411 .57402 .42882 .56691 .4202 .55895 Mtetra
.602 .743 .943 r
.4202 .55895 .42882 .56691 .44351 .56319 .43491 .55611 Mtetra
.598 .767 .96 r
.43491 .55611 .44351 .56319 .45826 .5603 .44972 .55312 Mtetra
.632 .776 .949 r
.44972 .55312 .45826 .5603 .47311 .55713 .46464 .54918 Mtetra
.656 .763 .929 r
.46464 .54918 .47311 .55713 .48807 .55306 .47966 .54455 Mtetra
.649 .749 .922 r
.47966 .54455 .48807 .55306 .50311 .54846 .49475 .54016 Mtetra
.646 .754 .928 r
.49475 .54016 .50311 .54846 .51824 .54397 .50994 .53583 Mtetra
.645 .758 .932 r
.50994 .53583 .51824 .54397 .53346 .53957 .52521 .53152 Mtetra
.647 .763 .933 r
.52521 .53152 .53346 .53957 .54876 .53511 .54056 .52708 Mtetra
.65 .766 .933 r
.54056 .52708 .54876 .53511 .56414 .5306 .55601 .52249 Mtetra
.653 .766 .932 r
.55601 .52249 .56414 .5306 .57962 .52598 .57154 .51779 Mtetra
.655 .765 .931 r
.57154 .51779 .57962 .52598 .59517 .52125 .58716 .513 Mtetra
.656 .766 .93 r
.58716 .513 .59517 .52125 .61082 .51638 .60287 .50813 Mtetra
.659 .767 .93 r
.60287 .50813 .61082 .51638 .62655 .51142 .61866 .50314 Mtetra
.662 .769 .929 r
.61866 .50314 .62655 .51142 .64236 .50639 .63454 .498 Mtetra
.665 .768 .927 r
.63454 .498 .64236 .50639 .65826 .50131 .6505 .49273 Mtetra
.664 .765 .925 r
.6505 .49273 .65826 .50131 .67425 .49631 .66655 .48747 Mtetra
.662 .759 .922 r
.66655 .48747 .67425 .49631 .69035 .49142 .68269 .48227 Mtetra
.655 .751 .92 r
.68269 .48227 .69035 .49142 .7065 .486 .69894 .47731 Mtetra
.672 .769 .923 r
.69894 .47731 .7065 .486 .72269 .47963 .71524 .47164 Mtetra
.695 .795 .927 r
.71524 .47164 .72269 .47963 .73894 .47298 .73157 .46499 Mtetra
.698 .798 .927 r
.73157 .46499 .73894 .47298 .75533 .46717 .74797 .45818 Mtetra
.649 .757 .928 r
.74797 .45818 .75533 .46717 .77207 .46484 .76459 .45333 Mtetra
.555 .659 .905 r
.76459 .45333 .77207 .46484 .78915 .46519 .78161 .45231 Mtetra
.495 .602 .889 r
.78161 .45231 .78915 .46519 .80647 .46657 .79899 .45377 Mtetra
.529 .623 .889 r
.79899 .45377 .80647 .46657 .82365 .4645 .81643 .45401 Mtetra
.632 .721 .911 r
.81643 .45401 .82365 .4645 .84057 .45825 .83361 .44982 Mtetra
.734 .809 .91 r
.83361 .44982 .84057 .45825 .85724 .44874 .85045 .4411 Mtetra
.753 .836 .915 r
.85045 .4411 .85724 .44874 .87404 .4399 .86727 .43151 Mtetra
.719 .808 .92 r
.86727 .43151 .87404 .4399 .89112 .4329 .88432 .42344 Mtetra
.665 .763 .923 r
.88432 .42344 .89112 .4329 .90848 .42758 .90171 .41769 Mtetra
.625 .743 .932 r
.28138 .59691 .29053 .6049 .30458 .60097 .29544 .59357 Mtetra
.528 .728 .966 r
.29544 .59357 .30458 .60097 .31858 .59927 .30944 .59246 Mtetra
.449 .715 .981 r
.30944 .59246 .31858 .59927 .33259 .59904 .32347 .5925 Mtetra
.579 .772 .971 r
.32347 .5925 .33259 .59904 .34675 .598 .33776 .58994 Mtetra
.718 .767 .891 r
.33776 .58994 .34675 .598 .36123 .59264 .35237 .58285 Mtetra
.769 .741 .827 r
.35237 .58285 .36123 .59264 .37596 .58301 .36723 .57171 Mtetra
.747 .713 .82 r
.36723 .57171 .37596 .58301 .39077 .57217 .38206 .56161 Mtetra
.703 .715 .859 r
.38206 .56161 .39077 .57217 .40552 .56371 .3968 .55476 Mtetra
.62 .725 .922 r
.3968 .55476 .40552 .56371 .4202 .55895 .41148 .55151 Mtetra
.593 .756 .956 r
.41148 .55151 .4202 .55895 .43491 .55611 .42623 .54874 Mtetra
.618 .767 .951 r
.42623 .54874 .43491 .55611 .44972 .55312 .4411 .54524 Mtetra
.654 .765 .931 r
.4411 .54524 .44972 .55312 .46464 .54918 .45609 .54064 Mtetra
.65 .749 .922 r
.45609 .54064 .46464 .54918 .47966 .54455 .47115 .53622 Mtetra
.644 .753 .929 r
.47115 .53622 .47966 .54455 .49475 .54016 .4863 .53195 Mtetra
.642 .757 .932 r
.4863 .53195 .49475 .54016 .50994 .53583 .50154 .52772 Mtetra
.647 .762 .933 r
.50154 .52772 .50994 .53583 .52521 .53152 .51687 .52328 Mtetra
.659 .764 .927 r
.51687 .52328 .52521 .53152 .54056 .52708 .53228 .51839 Mtetra
.66 .754 .92 r
.53228 .51839 .54056 .52708 .55601 .52249 .54778 .51345 Mtetra
.658 .747 .915 r
.54778 .51345 .55601 .52249 .57154 .51779 .56337 .50855 Mtetra
.656 .743 .913 r
.56337 .50855 .57154 .51779 .58716 .513 .57905 .50372 Mtetra
.654 .742 .914 r
.57905 .50372 .58716 .513 .60287 .50813 .59481 .49894 Mtetra
.652 .744 .917 r
.59481 .49894 .60287 .50813 .61866 .50314 .61067 .4942 Mtetra
.652 .752 .923 r
.61067 .4942 .61866 .50314 .63454 .498 .62662 .48941 Mtetra
.663 .765 .926 r
.62662 .48941 .63454 .498 .6505 .49273 .64265 .48417 Mtetra
.668 .769 .926 r
.64265 .48417 .6505 .49273 .66655 .48747 .65876 .47871 Mtetra
.666 .765 .924 r
.65876 .47871 .66655 .48747 .68269 .48227 .67496 .47329 Mtetra
.662 .759 .922 r
.67496 .47329 .68269 .48227 .69894 .47731 .69126 .46802 Mtetra
.657 .751 .92 r
.69126 .46802 .69894 .47731 .71524 .47164 .70767 .46292 Mtetra
.683 .775 .921 r
.70767 .46292 .71524 .47164 .73157 .46499 .7241 .4567 Mtetra
.7 .793 .922 r
.7241 .4567 .73157 .46499 .74797 .45818 .74056 .44972 Mtetra
.689 .786 .925 r
.74056 .44972 .74797 .45818 .76459 .45333 .75714 .4432 Mtetra
.595 .711 .925 r
.75714 .4432 .76459 .45333 .78161 .45231 .77409 .44041 Mtetra
.508 .631 .906 r
.77409 .44041 .78161 .45231 .79899 .45377 .79145 .441 Mtetra
.484 .602 .894 r
.79145 .441 .79899 .45377 .81643 .45401 .80906 .4427 Mtetra
.59 .686 .908 r
.80906 .4427 .81643 .45401 .83361 .44982 .82647 .4402 Mtetra
.699 .771 .907 r
.82647 .4402 .83361 .44982 .85045 .4411 .84354 .43297 Mtetra
.758 .827 .906 r
.84354 .43297 .85045 .4411 .86727 .43151 .86042 .423 Mtetra
.733 .812 .913 r
.86042 .423 .86727 .43151 .88432 .42344 .87748 .41421 Mtetra
.681 .777 .924 r
.87748 .41421 .88432 .42344 .90171 .41769 .89488 .40774 Mtetra
.601 .738 .941 r
.27215 .58892 .28138 .59691 .29544 .59357 .2862 .58622 Mtetra
.5 .721 .971 r
.2862 .58622 .29544 .59357 .30944 .59246 .3002 .58556 Mtetra
.458 .718 .98 r
.3002 .58556 .30944 .59246 .32347 .5925 .31428 .58543 Mtetra
.641 .777 .946 r
.31428 .58543 .32347 .5925 .33776 .58994 .3287 .58133 Mtetra
.747 .762 .865 r
.3287 .58133 .33776 .58994 .35237 .58285 .34346 .57243 Mtetra
.769 .732 .819 r
.34346 .57243 .35237 .58285 .36723 .57171 .35839 .5609 Mtetra
.737 .72 .836 r
.35839 .5609 .36723 .57171 .38206 .56161 .37323 .55174 Mtetra
.668 .721 .889 r
.37323 .55174 .38206 .56161 .3968 .55476 .38795 .54668 Mtetra
.596 .741 .945 r
.38795 .54668 .3968 .55476 .41148 .55151 .40266 .54395 Mtetra
.597 .756 .954 r
.40266 .54395 .41148 .55151 .42623 .54874 .41747 .54103 Mtetra
.644 .768 .939 r
.41747 .54103 .42623 .54874 .4411 .54524 .43241 .53673 Mtetra
.653 .752 .922 r
.43241 .53673 .4411 .54524 .45609 .54064 .44745 .53216 Mtetra
.644 .75 .927 r
.44745 .53216 .45609 .54064 .47115 .53622 .46256 .52789 Mtetra
.64 .754 .932 r
.46256 .52789 .47115 .53622 .4863 .53195 .47777 .52372 Mtetra
.648 .76 .931 r
.47777 .52372 .4863 .53195 .50154 .52772 .49306 .51923 Mtetra
.663 .76 .922 r
.49306 .51923 .50154 .52772 .51687 .52328 .50845 .51419 Mtetra
.662 .747 .913 r
.50845 .51419 .51687 .52328 .53228 .51839 .52392 .50914 Mtetra
.657 .742 .913 r
.52392 .50914 .53228 .51839 .54778 .51345 .53947 .50429 Mtetra
.656 .745 .916 r
.53947 .50429 .54778 .51345 .56337 .50855 .55512 .49944 Mtetra
.656 .748 .917 r
.55512 .49944 .56337 .50855 .57905 .50372 .57085 .49455 Mtetra
.57085 .49455 .57905 .50372 .59481 .49894 .58668 .48962 Mtetra
.656 .745 .916 r
.58668 .48962 .59481 .49894 .61067 .4942 .60259 .4847 Mtetra
.65 .74 .915 r
.60259 .4847 .61067 .4942 .62662 .48941 .61861 .47996 Mtetra
.649 .742 .917 r
.61861 .47996 .62662 .48941 .64265 .48417 .63471 .47523 Mtetra
.662 .76 .922 r
.63471 .47523 .64265 .48417 .65876 .47871 .6509 .46993 Mtetra
.67 .768 .924 r
.6509 .46993 .65876 .47871 .67496 .47329 .66716 .46431 Mtetra
.667 .763 .922 r
.66716 .46431 .67496 .47329 .69126 .46802 .68351 .45877 Mtetra
.658 .755 .921 r
.68351 .45877 .69126 .46802 .70767 .46292 .69998 .45355 Mtetra
.665 .756 .918 r
.69998 .45355 .70767 .46292 .7241 .4567 .71653 .44805 Mtetra
.698 .786 .919 r
.71653 .44805 .7241 .4567 .74056 .44972 .73307 .44111 Mtetra
.702 .789 .919 r
.73307 .44111 .74056 .44972 .75714 .4432 .74969 .43396 Mtetra
.643 .754 .93 r
.74969 .43396 .75714 .4432 .77409 .44041 .76657 .42922 Mtetra
.532 .66 .918 r
.76657 .42922 .77409 .44041 .79145 .441 .78389 .42872 Mtetra
.466 .604 .904 r
.78389 .42872 .79145 .441 .80906 .4427 .80157 .43071 Mtetra
.544 .652 .905 r
.80157 .43071 .80906 .4427 .82647 .4402 .8192 .42999 Mtetra
.664 .746 .912 r
.8192 .42999 .82647 .4402 .84354 .43297 .8365 .42427 Mtetra
.753 .814 .9 r
.8365 .42427 .84354 .43297 .86042 .423 .85348 .41437 Mtetra
.743 .815 .908 r
.85348 .41437 .86042 .423 .87748 .41421 .87058 .405 Mtetra
.697 .787 .92 r
.87058 .405 .87748 .41421 .89488 .40774 .88798 .39776 Mtetra
.578 .732 .948 r
.26281 .58091 .27215 .58892 .2862 .58622 .27686 .57874 Mtetra
.48 .712 .972 r
.27686 .57874 .2862 .58622 .3002 .58556 .29088 .57845 Mtetra
.489 .727 .977 r
.29088 .57845 .3002 .58556 .31428 .58543 .30502 .57782 Mtetra
.679 .774 .922 r
.30502 .57782 .31428 .58543 .3287 .58133 .31957 .5724 Mtetra
.764 .759 .848 r
.31957 .5724 .3287 .58133 .34346 .57243 .33446 .56212 Mtetra
.767 .735 .823 r
.33446 .56212 .34346 .57243 .35839 .5609 .34944 .55082 Mtetra
.729 .733 .854 r
.34944 .55082 .35839 .5609 .37323 .55174 .3643 .54248 Mtetra
.632 .725 .914 r
.3643 .54248 .37323 .55174 .38795 .54668 .379 .53875 Mtetra
.589 .745 .951 r
.379 .53875 .38795 .54668 .40266 .54395 .39375 .53611 Mtetra
.614 .756 .946 r
.39375 .53611 .40266 .54395 .41747 .54103 .40862 .53272 Mtetra
.655 .758 .925 r
.40862 .53272 .41747 .54103 .43241 .53673 .42363 .52805 Mtetra
.646 .747 .923 r
.42363 .52805 .43241 .53673 .44745 .53216 .43871 .52369 Mtetra
.639 .752 .93 r
.43871 .52369 .44745 .53216 .46256 .52789 .45388 .51951 Mtetra
.642 .756 .932 r
.45388 .51951 .46256 .52789 .47777 .52372 .46914 .51521 Mtetra
.663 .76 .922 r
.46914 .51521 .47777 .52372 .49306 .51923 .4845 .51012 Mtetra
.663 .747 .913 r
.4845 .51012 .49306 .51923 .50845 .51419 .49994 .50503 Mtetra
.655 .745 .916 r
.49994 .50503 .50845 .51419 .52392 .50914 .51546 .50023 Mtetra
.651 .75 .922 r
.51546 .50023 .52392 .50914 .53947 .50429 .53108 .49553 Mtetra
.65 .755 .926 r
.53108 .49553 .53947 .50429 .55512 .49944 .54678 .49083 Mtetra
.655 .761 .928 r
.54678 .49083 .55512 .49944 .57085 .49455 .56258 .48589 Mtetra
.661 .763 .926 r
.56258 .48589 .57085 .49455 .58668 .48962 .57846 .48071 Mtetra
.66 .758 .923 r
.57846 .48071 .58668 .48962 .60259 .4847 .59444 .47552 Mtetra
.657 .752 .92 r
.59444 .47552 .60259 .4847 .61861 .47996 .6105 .47045 Mtetra
.649 .743 .918 r
.6105 .47045 .61861 .47996 .63471 .47523 .62667 .46565 Mtetra
.649 .742 .918 r
.62667 .46565 .63471 .47523 .6509 .46993 .64294 .46086 Mtetra
.668 .762 .921 r
.64294 .46086 .6509 .46993 .66716 .46431 .65927 .45526 Mtetra
.67 .765 .921 r
.65927 .45526 .66716 .46431 .68351 .45877 .67569 .44953 Mtetra
.665 .76 .921 r
.67569 .44953 .68351 .45877 .69998 .45355 .69221 .44399 Mtetra
.657 .751 .919 r
.69221 .44399 .69998 .45355 .71653 .44805 .70884 .43876 Mtetra
.688 .769 .914 r
.70884 .43876 .71653 .44805 .73307 .44111 .72549 .4322 Mtetra
.705 .785 .914 r
.72549 .4322 .73307 .44111 .74969 .43396 .74217 .42486 Mtetra
.679 .774 .922 r
.74217 .42486 .74969 .43396 .76657 .42922 .75902 .41863 Mtetra
.553 .686 .928 r
.75902 .41863 .76657 .42922 .78389 .42872 .77632 .41718 Mtetra
.464 .621 .918 r
.77632 .41718 .78389 .42872 .80157 .43071 .79403 .41882 Mtetra
.501 .634 .913 r
.79403 .41882 .80157 .43071 .8192 .42999 .81183 .41943 Mtetra
.633 .728 .916 r
.81183 .41943 .8192 .42999 .8365 .42427 .82933 .41497 Mtetra
.742 .799 .898 r
.82933 .41497 .8365 .42427 .85348 .41437 .84645 .4055 Mtetra
.751 .814 .902 r
.84645 .4055 .85348 .41437 .87058 .405 .86359 .39564 Mtetra
.71 .79 .914 r
.86359 .39564 .87058 .405 .88798 .39776 .88101 .38772 Mtetra
.56 .727 .952 r
.25338 .57283 .26281 .58091 .27686 .57874 .26743 .57106 Mtetra
.469 .704 .971 r
.26743 .57106 .27686 .57874 .29088 .57845 .28147 .57098 Mtetra
.53 .734 .968 r
.28147 .57098 .29088 .57845 .30502 .57782 .2957 .56964 Mtetra
.699 .766 .904 r
.2957 .56964 .30502 .57782 .31957 .5724 .31035 .56336 Mtetra
.775 .759 .839 r
.31035 .56336 .31957 .5724 .33446 .56212 .32536 .55214 Mtetra
.766 .742 .832 r
.32536 .55214 .33446 .56212 .34944 .55082 .34038 .54119 Mtetra
.714 .74 .872 r
.34038 .54119 .34944 .55082 .3643 .54248 .35523 .53387 Mtetra
.611 .736 .934 r
.35523 .53387 .3643 .54248 .379 .53875 .36996 .53072 Mtetra
.591 .745 .95 r
.36996 .53072 .379 .53875 .39375 .53611 .38476 .52798 Mtetra
.631 .756 .938 r
.38476 .52798 .39375 .53611 .40862 .53272 .3997 .52408 Mtetra
.654 .752 .922 r
.3997 .52408 .40862 .53272 .42363 .52805 .41476 .51939 Mtetra
.642 .749 .927 r
.41476 .51939 .42363 .52805 .43871 .52369 .42989 .5151 Mtetra
.637 .751 .93 r
.42989 .5151 .43871 .52369 .45388 .51951 .44511 .51095 Mtetra
.654 .757 .926 r
.44511 .51095 .45388 .51951 .46914 .51521 .46043 .5062 Mtetra
.666 .751 .914 r
.46043 .5062 .46914 .51521 .4845 .51012 .47584 .50095 Mtetra
.655 .745 .916 r
.47584 .50095 .4845 .51012 .49994 .50503 .49134 .4961 Mtetra
.645 .749 .925 r
.49134 .4961 .49994 .50503 .51546 .50023 .50692 .49158 Mtetra
.643 .757 .931 r
.50692 .49158 .51546 .50023 .53108 .49553 .52259 .4871 Mtetra
.651 .766 .933 r
.52259 .4871 .53108 .49553 .54678 .49083 .53836 .48227 Mtetra
.655 .765 .93 r
.53836 .48227 .54678 .49083 .56258 .48589 .55422 .47728 Mtetra
.659 .766 .929 r
.55422 .47728 .56258 .48589 .57846 .48071 .57017 .47212 Mtetra
.667 .771 .927 r
.57017 .47212 .57846 .48071 .59444 .47552 .5862 .46662 Mtetra
.666 .764 .923 r
.5862 .46662 .59444 .47552 .6105 .47045 .60232 .46114 Mtetra
.657 .753 .921 r
.60232 .46114 .6105 .47045 .62667 .46565 .61854 .456 Mtetra
.646 .742 .919 r
.61854 .456 .62667 .46565 .64294 .46086 .63488 .45126 Mtetra
.658 .749 .917 r
.63488 .45126 .64294 .46086 .65927 .45526 .65129 .44602 Mtetra
.672 .763 .919 r
.65129 .44602 .65927 .45526 .67569 .44953 .66777 .44017 Mtetra
.668 .76 .919 r
.66777 .44017 .67569 .44953 .69221 .44399 .68435 .43444 Mtetra
.657 .754 .921 r
.68435 .43444 .69221 .44399 .70884 .43876 .70105 .42912 Mtetra
.676 .76 .914 r
.70105 .42912 .70884 .43876 .72549 .4322 .7178 .42298 Mtetra
.703 .78 .911 r
.7178 .42298 .72549 .4322 .74217 .42486 .73457 .41564 Mtetra
.693 .778 .916 r
.73457 .41564 .74217 .42486 .75902 .41863 .75144 .4087 Mtetra
.581 .718 .937 r
.75144 .4087 .75902 .41863 .77632 .41718 .76873 .40609 Mtetra
.47 .636 .928 r
.76873 .40609 .77632 .41718 .79403 .41882 .78645 .40725 Mtetra
.466 .625 .921 r
.78645 .40725 .79403 .41882 .81183 .41943 .80439 .40872 Mtetra
.611 .718 .921 r
.80439 .40872 .81183 .41943 .82933 .41497 .82203 .40506 Mtetra
.727 .783 .897 r
.82203 .40506 .82933 .41497 .84645 .4055 .8393 .39622 Mtetra
.754 .807 .895 r
.8393 .39622 .84645 .4055 .86359 .39564 .8565 .38602 Mtetra
.719 .79 .908 r
.8565 .38602 .86359 .39564 .88101 .38772 .87396 .37759 Mtetra
.548 .722 .954 r
.24385 .56465 .25338 .57283 .26743 .57106 .25792 .56312 Mtetra
.466 .698 .968 r
.25792 .56312 .26743 .57106 .28147 .57098 .27198 .56314 Mtetra
.558 .737 .959 r
.27198 .56314 .28147 .57098 .2957 .56964 .28629 .56124 Mtetra
.711 .765 .894 r
.28629 .56124 .2957 .56964 .31035 .56336 .30104 .55431 Mtetra
.781 .761 .835 r
.30104 .55431 .31035 .56336 .32536 .55214 .31614 .54257 Mtetra
.765 .751 .841 r
.31614 .54257 .32536 .55214 .34038 .54119 .3312 .53192 Mtetra
.701 .747 .887 r
.3312 .53192 .34038 .54119 .35523 .53387 .34607 .52531 Mtetra
.6 .736 .94 r
.34607 .52531 .35523 .53387 .36996 .53072 .36083 .52239 Mtetra
.594 .741 .946 r
.36083 .52239 .36996 .53072 .38476 .52798 .37567 .51957 Mtetra
.641 .755 .931 r
.37567 .51957 .38476 .52798 .3997 .52408 .39068 .5153 Mtetra
.652 .75 .922 r
.39068 .5153 .3997 .52408 .41476 .51939 .40579 .51066 Mtetra
.64 .749 .928 r
.40579 .51066 .41476 .51939 .42989 .5151 .42097 .5064 Mtetra
.638 .75 .929 r
.42097 .5064 .42989 .5151 .44511 .51095 .43624 .50217 Mtetra
.662 .757 .92 r
.43624 .50217 .44511 .51095 .46043 .5062 .45163 .49706 Mtetra
.663 .75 .915 r
.45163 .49706 .46043 .5062 .47584 .50095 .4671 .49189 Mtetra
.65 .749 .922 r
.4671 .49189 .47584 .50095 .49134 .4961 .48264 .4872 Mtetra
.637 .75 .93 r
.48264 .4872 .49134 .4961 .50692 .49158 .49828 .4829 Mtetra
.657 .762 .928 r
.49828 .4829 .50692 .49158 .52259 .4871 .51402 .47786 Mtetra
.666 .753 .915 r
.51402 .47786 .52259 .4871 .53836 .48227 .52984 .47243 Mtetra
.656 .738 .91 r
.52984 .47243 .53836 .48227 .55422 .47728 .54576 .46739 Mtetra
.646 .734 .913 r
.54576 .46739 .55422 .47728 .57017 .47212 .56177 .46273 Mtetra
.655 .75 .92 r
.56177 .46273 .57017 .47212 .5862 .46662 .57787 .45767 Mtetra
.672 .767 .922 r
.57787 .45767 .5862 .46662 .60232 .46114 .59405 .45187 Mtetra
.662 .758 .921 r
.59405 .45187 .60232 .46114 .61854 .456 .61034 .44647 Mtetra
.649 .748 .922 r
.61034 .44647 .61854 .456 .63488 .45126 .62673 .44154 Mtetra
.65 .746 .919 r
.62673 .44154 .63488 .45126 .65129 .44602 .64322 .43655 Mtetra
.671 .76 .917 r
.64322 .43655 .65129 .44602 .66777 .44017 .65977 .43066 Mtetra
.67 .76 .918 r
.65977 .43066 .66777 .44017 .68435 .43444 .67642 .4248 Mtetra
.66 .755 .92 r
.67642 .4248 .68435 .43444 .70105 .42912 .69318 .41933 Mtetra
.668 .756 .916 r
.69318 .41933 .70105 .42912 .7178 .42298 .71002 .41346 Mtetra
.702 .775 .908 r
.71002 .41346 .7178 .42298 .73457 .41564 .72686 .40609 Mtetra
.7 .775 .91 r
.72686 .40609 .73457 .41564 .75144 .4087 .74379 .39881 Mtetra
.603 .731 .935 r
.74379 .39881 .75144 .4087 .76873 .40609 .76108 .39534 Mtetra
.476 .65 .935 r
.76108 .39534 .76873 .40609 .78645 .40725 .77884 .39608 Mtetra
.441 .623 .929 r
.77884 .39608 .78645 .40725 .80439 .40872 .79687 .39799 Mtetra
.594 .712 .926 r
.79687 .39799 .80439 .40872 .82203 .40506 .81464 .39489 Mtetra
.716 .776 .9 r
.81464 .39489 .82203 .40506 .8393 .39622 .83204 .38653 Mtetra
.755 .801 .889 r
.83204 .38653 .8393 .39622 .8565 .38602 .84932 .37612 Mtetra
.725 .788 .902 r
.84932 .37612 .8565 .38602 .87396 .37759 .86683 .36732 Mtetra
.543 .719 .955 r
.23423 .55633 .24385 .56465 .25792 .56312 .24833 .5549 Mtetra
.467 .693 .965 r
.24833 .5549 .25792 .56312 .27198 .56314 .26242 .55494 Mtetra
.572 .734 .952 r
.26242 .55494 .27198 .56314 .28629 .56124 .27679 .55273 Mtetra
.719 .765 .89 r
.27679 .55273 .28629 .56124 .30104 .55431 .29161 .54537 Mtetra
.784 .765 .836 r
.29161 .54537 .30104 .55431 .31614 .54257 .3068 .53342 Mtetra
.765 .761 .849 r
.3068 .53342 .31614 .54257 .3312 .53192 .32191 .52292 Mtetra
.694 .753 .897 r
.32191 .52292 .3312 .53192 .34607 .52531 .33681 .51664 Mtetra
.597 .734 .94 r
.33681 .51664 .34607 .52531 .36083 .52239 .35161 .51379 Mtetra
.597 .737 .942 r
.35161 .51379 .36083 .52239 .37567 .51957 .36651 .5109 Mtetra
.646 .752 .926 r
.36651 .5109 .37567 .51957 .39068 .5153 .38157 .50642 Mtetra
.65 .749 .922 r
.38157 .50642 .39068 .5153 .40579 .51066 .39673 .50179 Mtetra
.639 .747 .927 r
.39673 .50179 .40579 .51066 .42097 .5064 .41196 .49752 Mtetra
.64 .749 .928 r
.41196 .49752 .42097 .5064 .43624 .50217 .42729 .4932 Mtetra
.666 .755 .917 r
.42729 .4932 .43624 .50217 .45163 .49706 .44273 .4879 Mtetra
.66 .751 .917 r
.44273 .4879 .45163 .49706 .4671 .49189 .45826 .48278 Mtetra
.644 .748 .925 r
.45826 .48278 .4671 .49189 .48264 .4872 .47386 .47823 Mtetra
.639 .751 .929 r
.47386 .47823 .48264 .4872 .49828 .4829 .48955 .4738 Mtetra
.671 .759 .917 r
.48955 .4738 .49828 .4829 .51402 .47786 .50535 .46817 Mtetra
.676 .748 .905 r
.50535 .46817 .51402 .47786 .52984 .47243 .52123 .46228 Mtetra
.656 .733 .906 r
.52123 .46228 .52984 .47243 .54576 .46739 .53721 .45717 Mtetra
.635 .726 .913 r
.53721 .45717 .54576 .46739 .56177 .46273 .55328 .45287 Mtetra
.641 .737 .918 r
.55328 .45287 .56177 .46273 .57787 .45767 .56945 .44831 Mtetra
.671 .759 .917 r
.56945 .44831 .57787 .45767 .59405 .45187 .5857 .44253 Mtetra
.667 .76 .92 r
.5857 .44253 .59405 .45187 .61034 .44647 .60204 .43687 Mtetra
.652 .75 .922 r
.60204 .43687 .61034 .44647 .62673 .44154 .61849 .43178 Mtetra
.646 .746 .922 r
.61849 .43178 .62673 .44154 .64322 .43655 .63505 .42688 Mtetra
.67 .758 .916 r
.63505 .42688 .64322 .43655 .65977 .43066 .65167 .42098 Mtetra
.671 .759 .917 r
.65167 .42098 .65977 .43066 .67642 .4248 .66839 .41501 Mtetra
.661 .754 .919 r
.66839 .41501 .67642 .4248 .69318 .41933 .68522 .40941 Mtetra
.665 .754 .917 r
.68522 .40941 .69318 .41933 .71002 .41346 .70213 .40365 Mtetra
.701 .771 .906 r
.70213 .40365 .71002 .41346 .72686 .40609 .71905 .39624 Mtetra
.71905 .39624 .72686 .40609 .74379 .39881 .73605 .38879 Mtetra
.615 .735 .932 r
.73605 .38879 .74379 .39881 .76108 .39534 .75339 .38486 Mtetra
.478 .66 .941 r
.75339 .38486 .76108 .39534 .77884 .39608 .77118 .38534 Mtetra
.426 .627 .937 r
.77118 .38534 .77884 .39608 .79687 .39799 .78928 .38734 Mtetra
.582 .711 .931 r
.78928 .38734 .79687 .39799 .81464 .39489 .80716 .38458 Mtetra
.71 .773 .902 r
.80716 .38458 .81464 .39489 .83204 .38653 .82467 .37643 Mtetra
.755 .794 .885 r
.82467 .37643 .83204 .38653 .84932 .37612 .84203 .3659 Mtetra
.727 .784 .898 r
.84203 .3659 .84932 .37612 .86683 .36732 .85961 .35688 Mtetra
.544 .717 .953 r
.22452 .54786 .23423 .55633 .24833 .5549 .23865 .54639 Mtetra
.472 .689 .962 r
.23865 .54639 .24833 .5549 .26242 .55494 .25277 .54639 Mtetra
.575 .729 .947 r
.25277 .54639 .26242 .55494 .27679 .55273 .26719 .54414 Mtetra
.719 .766 .89 r
.26719 .54414 .27679 .55273 .29161 .54537 .28207 .53673 Mtetra
.787 .773 .84 r
.28207 .53673 .29161 .54537 .3068 .53342 .29732 .52471 Mtetra
.769 .772 .855 r
.29732 .52471 .3068 .53342 .32191 .52292 .3125 .51415 Mtetra
.694 .76 .902 r
.3125 .51415 .32191 .52292 .33681 .51664 .32746 .50781 Mtetra
.597 .733 .939 r
.32746 .50781 .33681 .51664 .35161 .51379 .3423 .50492 Mtetra
.598 .733 .939 r
.3423 .50492 .35161 .51379 .36651 .5109 .35725 .50198 Mtetra
.646 .748 .924 r
.35725 .50198 .36651 .5109 .38157 .50642 .37236 .49746 Mtetra
.65 .749 .922 r
.37236 .49746 .38157 .50642 .39673 .50179 .38758 .49278 Mtetra
.639 .746 .926 r
.38758 .49278 .39673 .50179 .41196 .49752 .40286 .48846 Mtetra
.64 .746 .926 r
.40286 .48846 .41196 .49752 .42729 .4932 .41824 .48408 Mtetra
.666 .754 .916 r
.41824 .48408 .42729 .4932 .44273 .4879 .43374 .47873 Mtetra
.66 .753 .918 r
.43374 .47873 .44273 .4879 .45826 .48278 .44932 .47356 Mtetra
.644 .748 .924 r
.44932 .47356 .45826 .48278 .47386 .47823 .46498 .46895 Mtetra
.64 .746 .926 r
.46498 .46895 .47386 .47823 .48955 .4738 .48073 .46448 Mtetra
.671 .756 .914 r
.48073 .46448 .48955 .4738 .50535 .46817 .49659 .45878 Mtetra
.676 .758 .912 r
.49659 .45878 .50535 .46817 .52123 .46228 .51254 .45283 Mtetra
.656 .751 .92 r
.51254 .45283 .52123 .46228 .53721 .45717 .52857 .44768 Mtetra
.634 .744 .927 r
.52857 .44768 .53721 .45717 .55328 .45287 .5447 .44332 Mtetra
.64 .746 .925 r
.5447 .44332 .55328 .45287 .56945 .44831 .56093 .4387 Mtetra
.671 .756 .915 r
.56093 .4387 .56945 .44831 .5857 .44253 .57725 .43286 Mtetra
.667 .755 .916 r
.57725 .43286 .5857 .44253 .60204 .43687 .59365 .42715 Mtetra
.652 .75 .921 r
.59365 .42715 .60204 .43687 .61849 .43178 .61017 .422 Mtetra
.646 .748 .923 r
.61017 .422 .61849 .43178 .63505 .42688 .6268 .41704 Mtetra
.67 .756 .915 r
.6268 .41704 .63505 .42688 .65167 .42098 .64349 .41108 Mtetra
.671 .757 .915 r
.64349 .41108 .65167 .42098 .66839 .41501 .66027 .40506 Mtetra
.661 .753 .918 r
.66027 .40506 .66839 .41501 .68522 .40941 .67717 .3994 Mtetra
.665 .754 .917 r
.67717 .3994 .68522 .40941 .70213 .40365 .69416 .39357 Mtetra
.701 .767 .903 r
.69416 .39357 .70213 .40365 .71905 .39624 .71115 .3861 Mtetra
.71115 .3861 .71905 .39624 .73605 .38879 .72822 .37858 Mtetra
.615 .734 .931 r
.72822 .37858 .73605 .38879 .75339 .38486 .74563 .37459 Mtetra
.473 .665 .947 r
.74563 .37459 .75339 .38486 .77118 .38534 .76349 .37502 Mtetra
.414 .634 .945 r
.76349 .37502 .77118 .38534 .78928 .38734 .78165 .37698 Mtetra
.579 .719 .938 r
.78165 .37698 .78928 .38734 .80716 .38458 .79959 .37416 Mtetra
.71 .774 .902 r
.79959 .37416 .80716 .38458 .82467 .37643 .81719 .36594 Mtetra
.753 .788 .881 r
.81719 .36594 .82467 .37643 .84203 .3659 .83463 .35534 Mtetra
.726 .779 .895 r
.83463 .35534 .84203 .3659 .85961 .35688 .8523 .34624 Mtetra
.551 .718 .951 r
.21472 .53923 .22452 .54786 .23865 .54639 .2289 .53758 Mtetra
.479 .687 .958 r
.2289 .53758 .23865 .54639 .25277 .54639 .24305 .53749 Mtetra
.566 .719 .945 r
.24305 .53749 .25277 .54639 .26719 .54414 .25748 .53548 Mtetra
.711 .765 .894 r
.25748 .53548 .26719 .54414 .28207 .53673 .2724 .52839 Mtetra
.788 .78 .845 r
.2724 .52839 .28207 .53673 .29732 .52471 .28771 .51644 Mtetra
.775 .783 .859 r
.28771 .51644 .29732 .52471 .3125 .51415 .30298 .5056 Mtetra
.704 .769 .903 r
.30298 .5056 .3125 .51415 .32746 .50781 .31802 .49882 Mtetra
.601 .732 .937 r
.31802 .49882 .32746 .50781 .3423 .50492 .33291 .49578 Mtetra
.598 .729 .936 r
.33291 .49578 .3423 .50492 .35725 .50198 .3479 .49282 Mtetra
.642 .744 .923 r
.3479 .49282 .35725 .50198 .37236 .49746 .36306 .4884 Mtetra
.652 .75 .922 r
.36306 .4884 .37236 .49746 .38758 .49278 .37833 .48361 Mtetra
.64 .745 .925 r
.37833 .48361 .38758 .49278 .40286 .48846 .39367 .47919 Mtetra
.639 .744 .925 r
.39367 .47919 .40286 .48846 .41824 .48408 .4091 .47481 Mtetra
.662 .752 .917 r
.4091 .47481 .41824 .48408 .43374 .47873 .42465 .46954 Mtetra
.663 .755 .919 r
.42465 .46954 .43374 .47873 .44932 .47356 .44029 .46422 Mtetra
.65 .749 .922 r
.44029 .46422 .44932 .47356 .46498 .46895 .45601 .45937 Mtetra
.638 .741 .923 r
.45601 .45937 .46498 .46895 .48073 .46448 .47182 .45491 Mtetra
.657 .749 .917 r
.47182 .45491 .48073 .46448 .49659 .45878 .48773 .44971 Mtetra
.666 .764 .923 r
.48773 .44971 .49659 .45878 .51254 .45283 .50374 .44412 Mtetra
.655 .77 .934 r
.50374 .44412 .51254 .45283 .52857 .44768 .51984 .43891 Mtetra
.643 .766 .938 r
.51984 .43891 .52857 .44768 .5447 .44332 .53603 .43408 Mtetra
.654 .76 .928 r
.53603 .43408 .5447 .44332 .56093 .4387 .55232 .42886 Mtetra
.672 .754 .912 r
.55232 .42886 .56093 .4387 .57725 .43286 .5687 .42288 Mtetra
.662 .749 .914 r
.5687 .42288 .57725 .43286 .59365 .42715 .58518 .4173 Mtetra
.649 .748 .922 r
.58518 .4173 .59365 .42715 .61017 .422 .60176 .4122 Mtetra
.65 .751 .924 r
.60176 .4122 .61017 .422 .6268 .41704 .61845 .40704 Mtetra
.671 .755 .914 r
.61845 .40704 .6268 .41704 .64349 .41108 .6352 .40098 Mtetra
.67 .754 .914 r
.6352 .40098 .64349 .41108 .66027 .40506 .65206 .39493 Mtetra
.66 .751 .918 r
.65206 .39493 .66027 .40506 .67717 .3994 .66903 .38928 Mtetra
.668 .756 .916 r
.66903 .38928 .67717 .3994 .69416 .39357 .68608 .38323 Mtetra
.701 .764 .901 r
.68608 .38323 .69416 .39357 .71115 .3861 .70315 .37567 Mtetra
.698 .762 .901 r
.70315 .37567 .71115 .3861 .72822 .37858 .7203 .36818 Mtetra
.604 .727 .932 r
.7203 .36818 .72822 .37858 .74563 .37459 .73781 .36454 Mtetra
.459 .666 .952 r
.73781 .36454 .74563 .37459 .76349 .37502 .75574 .36514 Mtetra
.408 .644 .953 r
.75574 .36514 .76349 .37502 .78165 .37698 .77396 .36691 Mtetra
.588 .733 .944 r
.77396 .36691 .78165 .37698 .79959 .37416 .79194 .36364 Mtetra
.716 .776 .9 r
.79194 .36364 .79959 .37416 .81719 .36594 .8096 .35506 Mtetra
.751 .782 .878 r
.8096 .35506 .81719 .36594 .83463 .35534 .82713 .34443 Mtetra
.722 .773 .893 r
.82713 .34443 .83463 .35534 .8523 .34624 .84489 .33541 Mtetra
.563 .721 .947 r
.20482 .53046 .21472 .53923 .2289 .53758 .21906 .52848 Mtetra
.489 .686 .954 r
.21906 .52848 .2289 .53758 .24305 .53749 .23326 .52823 Mtetra
.548 .706 .944 r
.23326 .52823 .24305 .53749 .25748 .53548 .24768 .52669 Mtetra
.698 .762 .901 r
.24768 .52669 .25748 .53548 .2724 .52839 .2626 .52015 Mtetra
.784 .784 .853 r
.2626 .52015 .2724 .52839 .28771 .51644 .27796 .5086 Mtetra
.783 .794 .861 r
.27796 .5086 .28771 .51644 .30298 .5056 .29333 .49733 Mtetra
.721 .78 .899 r
.29333 .49733 .30298 .5056 .31802 .49882 .30848 .48972 Mtetra
.611 .735 .934 r
.30848 .48972 .31802 .49882 .33291 .49578 .32344 .48634 Mtetra
.598 .724 .933 r
.32344 .48634 .33291 .49578 .3479 .49282 .33846 .48338 Mtetra
.633 .737 .923 r
.33846 .48338 .3479 .49282 .36306 .4884 .35366 .47924 Mtetra
.654 .751 .921 r
.35366 .47924 .36306 .4884 .37833 .48361 .36898 .47429 Mtetra
.643 .745 .923 r
.36898 .47429 .37833 .48361 .39367 .47919 .38438 .46976 Mtetra
.638 .742 .924 r
.38438 .46976 .39367 .47919 .4091 .47481 .39986 .46535 Mtetra
.654 .747 .918 r
.39986 .46535 .4091 .47481 .42465 .46954 .41546 .46034 Mtetra
.666 .758 .919 r
.41546 .46034 .42465 .46954 .44029 .46422 .43117 .45482 Mtetra
.655 .752 .921 r
.43117 .45482 .44029 .46422 .45601 .45937 .44695 .4497 Mtetra
.645 .744 .921 r
.44695 .4497 .45601 .45937 .47182 .45491 .46282 .44492 Mtetra
.644 .737 .917 r
.46282 .44492 .47182 .45491 .48773 .44971 .47878 .44017 Mtetra
.652 .751 .922 r
.47878 .44017 .48773 .44971 .50374 .44412 .49484 .43507 Mtetra
.655 .765 .93 r
.49484 .43507 .50374 .44412 .51984 .43891 .51101 .42981 Mtetra
.659 .766 .929 r
.51101 .42981 .51984 .43891 .53603 .43408 .52726 .42437 Mtetra
.667 .756 .917 r
.52726 .42437 .53603 .43408 .55232 .42886 .54361 .41858 Mtetra
.666 .745 .909 r
.54361 .41858 .55232 .42886 .5687 .42288 .56006 .41282 Mtetra
.657 .747 .917 r
.56006 .41282 .5687 .42288 .58518 .4173 .5766 .40739 Mtetra
.645 .748 .924 r
.5766 .40739 .58518 .4173 .60176 .4122 .59326 .40237 Mtetra
.658 .755 .922 r
.59326 .40237 .60176 .4122 .61845 .40704 .61 .39684 Mtetra
.672 .754 .912 r
.61 .39684 .61845 .40704 .6352 .40098 .62683 .39068 Mtetra
.668 .752 .913 r
.62683 .39068 .6352 .40098 .65206 .39493 .64375 .38465 Mtetra
.657 .749 .918 r
.64375 .38465 .65206 .39493 .66903 .38928 .6608 .37903 Mtetra
.676 .759 .913 r
.6608 .37903 .66903 .38928 .68608 .38323 .67791 .37259 Mtetra
.701 .76 .898 r
.67791 .37259 .68608 .38323 .70315 .37567 .69505 .36491 Mtetra
.692 .756 .901 r
.69505 .36491 .70315 .37567 .7203 .36818 .71229 .35765 Mtetra
.581 .717 .936 r
.71229 .35765 .7203 .36818 .73781 .36454 .72992 .35476 Mtetra
.436 .664 .957 r
.72992 .35476 .73781 .36454 .75574 .36514 .74795 .35569 Mtetra
.416 .662 .962 r
.74795 .35569 .75574 .36514 .77396 .36691 .76619 .35692 Mtetra
.605 .745 .944 r
.76619 .35692 .77396 .36691 .79194 .36364 .7842 .35297 Mtetra
.726 .779 .894 r
.7842 .35297 .79194 .36364 .8096 .35506 .80189 .34377 Mtetra
.747 .775 .875 r
.80189 .34377 .8096 .35506 .82713 .34443 .81953 .3332 Mtetra
.716 .767 .892 r
.81953 .3332 .82713 .34443 .84489 .33541 .8374 .3244 Mtetra
.58 .726 .943 r
.19482 .52158 .20482 .53046 .21906 .52848 .20914 .51912 Mtetra
.504 .687 .95 r
.20914 .51912 .21906 .52848 .23326 .52823 .22339 .51858 Mtetra
.523 .689 .943 r
.22339 .51858 .23326 .52823 .24768 .52669 .23779 .51768 Mtetra
.679 .755 .908 r
.23779 .51768 .24768 .52669 .2626 .52015 .2527 .51191 Mtetra
.773 .786 .863 r
.2527 .51191 .2626 .52015 .27796 .5086 .26806 .50119 Mtetra
.792 .804 .862 r
.26806 .50119 .27796 .5086 .29333 .49733 .28354 .48942 Mtetra
.744 .793 .893 r
.28354 .48942 .29333 .49733 .30848 .48972 .29883 .48067 Mtetra
.63 .744 .93 r
.29883 .48067 .30848 .48972 .32344 .48634 .31387 .47661 Mtetra
.597 .719 .93 r
.31387 .47661 .32344 .48634 .33846 .48338 .32894 .47365 Mtetra
.62 .728 .924 r
.32894 .47365 .33846 .48338 .35366 .47924 .34416 .46993 Mtetra
.655 .75 .919 r
.34416 .46993 .35366 .47924 .36898 .47429 .35954 .4649 Mtetra
.646 .746 .922 r
.35954 .4649 .36898 .47429 .38438 .46976 .375 .46019 Mtetra
.64 .742 .922 r
.375 .46019 .38438 .46976 .39986 .46535 .39053 .45566 Mtetra
.643 .741 .92 r
.39053 .45566 .39986 .46535 .41546 .46034 .40617 .451 Mtetra
.663 .757 .919 r
.40617 .451 .41546 .46034 .43117 .45482 .42193 .44554 Mtetra
.663 .759 .922 r
.42193 .44554 .43117 .45482 .44695 .4497 .43778 .44007 Mtetra
.655 .75 .92 r
.43778 .44007 .44695 .4497 .46282 .44492 .45372 .43489 Mtetra
.651 .741 .915 r
.45372 .43489 .46282 .44492 .47878 .44017 .46974 .42981 Mtetra
.651 .735 .911 r
.46974 .42981 .47878 .44017 .49484 .43507 .48586 .42473 Mtetra
.656 .738 .91 r
.48586 .42473 .49484 .43507 .51101 .42981 .50208 .4194 Mtetra
.661 .74 .908 r
.50208 .4194 .51101 .42981 .52726 .42437 .5184 .41383 Mtetra
.661 .738 .907 r
.5184 .41383 .52726 .42437 .54361 .41858 .53481 .40825 Mtetra
.657 .743 .913 r
.53481 .40825 .54361 .41858 .56006 .41282 .55133 .40278 Mtetra
.649 .748 .922 r
.55133 .40278 .56006 .41282 .5766 .40739 .56794 .39759 Mtetra
.648 .754 .927 r
.56794 .39759 .5766 .40739 .59326 .40237 .58466 .3924 Mtetra
.668 .758 .918 r
.58466 .3924 .59326 .40237 .61 .39684 .60146 .38639 Mtetra
.67 .75 .91 r
.60146 .38639 .61 .39684 .62683 .39068 .61836 .38024 Mtetra
.665 .75 .913 r
.61836 .38024 .62683 .39068 .64375 .38465 .63536 .37427 Mtetra
.657 .749 .918 r
.63536 .37427 .64375 .38465 .6608 .37903 .65247 .36862 Mtetra
.687 .761 .908 r
.65247 .36862 .6608 .37903 .67791 .37259 .66963 .36162 Mtetra
.702 .756 .894 r
.66963 .36162 .67791 .37259 .69505 .36491 .68684 .35383 Mtetra
.678 .746 .903 r
.68684 .35383 .69505 .36491 .71229 .35765 .7042 .34715 Mtetra
.544 .703 .944 r
.7042 .34715 .71229 .35765 .72992 .35476 .72196 .34533 Mtetra
.407 .66 .963 r
.72196 .34533 .72992 .35476 .74795 .35569 .74009 .34665 Mtetra
.443 .691 .971 r
.74009 .34665 .74795 .35569 .76619 .35692 .75834 .34691 Mtetra
.629 .757 .94 r
.75834 .34691 .76619 .35692 .7842 .35297 .77636 .34203 Mtetra
.739 .78 .886 r
.77636 .34203 .7842 .35297 .80189 .34377 .79407 .33204 Mtetra
.741 .767 .874 r
.79407 .33204 .80189 .34377 .81953 .3332 .81182 .32165 Mtetra
.707 .759 .893 r
.81182 .32165 .81953 .3332 .8374 .3244 .82982 .31324 Mtetra
.602 .734 .937 r
.18471 .51262 .19482 .52158 .20914 .51912 .19913 .50954 Mtetra
.524 .692 .945 r
.19913 .50954 .20914 .51912 .22339 .51858 .21345 .50854 Mtetra
.505 .675 .941 r
.21345 .50854 .22339 .51858 .23779 .51768 .22783 .50808 Mtetra
.645 .735 .915 r
.22783 .50808 .23779 .51768 .2527 .51191 .24268 .50355 Mtetra
.753 .784 .878 r
.24268 .50355 .2527 .51191 .26806 .50119 .25802 .49411 Mtetra
.799 .813 .863 r
.25802 .49411 .26806 .50119 .28354 .48942 .2736 .48198 Mtetra
.762 .807 .889 r
.2736 .48198 .28354 .48942 .29883 .48067 .28902 .47227 Mtetra
.669 .773 .927 r
.28902 .47227 .29883 .48067 .31387 .47661 .30421 .46675 Mtetra
.601 .72 .928 r
.30421 .46675 .31387 .47661 .32894 .47365 .31934 .46361 Mtetra
.607 .719 .924 r
.31934 .46361 .32894 .47365 .34416 .46993 .33457 .46028 Mtetra
.647 .742 .919 r
.33457 .46028 .34416 .46993 .35954 .4649 .34999 .45552 Mtetra
.653 .751 .922 r
.34999 .45552 .35954 .4649 .375 .46019 .36551 .45049 Mtetra
.644 .742 .921 r
.36551 .45049 .375 .46019 .39053 .45566 .38111 .44577 Mtetra
.641 .738 .919 r
.38111 .44577 .39053 .45566 .40617 .451 .3968 .44114 Mtetra
.649 .743 .918 r
.3968 .44114 .40617 .451 .42193 .44554 .4126 .43618 Mtetra
.663 .759 .922 r
.4126 .43618 .42193 .44554 .43778 .44007 .42851 .43065 Mtetra
.662 .759 .922 r
.42851 .43065 .43778 .44007 .45372 .43489 .44451 .42511 Mtetra
.657 .751 .919 r
.44451 .42511 .45372 .43489 .46974 .42981 .4606 .41977 Mtetra
.656 .746 .916 r
.4606 .41977 .46974 .42981 .48586 .42473 .47678 .41443 Mtetra
.656 .742 .913 r
.47678 .41443 .48586 .42473 .50208 .4194 .49306 .40905 Mtetra
.49306 .40905 .50208 .4194 .5184 .41383 .50944 .40361 Mtetra
.655 .746 .916 r
.50944 .40361 .5184 .41383 .53481 .40825 .52592 .39819 Mtetra
.65 .748 .922 r
.52592 .39819 .53481 .40825 .55133 .40278 .5425 .39295 Mtetra
.649 .755 .927 r
.5425 .39295 .55133 .40278 .56794 .39759 .55918 .38771 Mtetra
.663 .76 .922 r
.55918 .38771 .56794 .39759 .58466 .3924 .57595 .38189 Mtetra
.67 .75 .91 r
.57595 .38189 .58466 .3924 .60146 .38639 .59282 .37573 Mtetra
.667 .747 .91 r
.59282 .37573 .60146 .38639 .61836 .38024 .60979 .36965 Mtetra
.659 .747 .915 r
.60979 .36965 .61836 .38024 .63536 .37427 .62687 .3639 Mtetra
.665 .755 .918 r
.62687 .3639 .63536 .37427 .65247 .36862 .64404 .35784 Mtetra
.696 .759 .9 r
.64404 .35784 .65247 .36862 .66963 .36162 .66126 .35033 Mtetra
.698 .751 .892 r
.66126 .35033 .66963 .36162 .68684 .35383 .67855 .34259 Mtetra
.644 .733 .913 r
.67855 .34259 .68684 .35383 .7042 .34715 .69606 .33731 Mtetra
.503 .702 .959 r
.69606 .33731 .7042 .34715 .72196 .34533 .71395 .33635 Mtetra
.379 .659 .968 r
.71395 .33635 .72196 .34533 .74009 .34665 .73217 .33794 Mtetra
.491 .728 .977 r
.73217 .33794 .74009 .34665 .75834 .34691 .75039 .33675 Mtetra
.664 .771 .929 r
.75039 .33675 .75834 .34691 .77636 .34203 .76839 .33045 Mtetra
.745 .772 .875 r
.76839 .33045 .77636 .34203 .79407 .33204 .78614 .31987 Mtetra
.733 .758 .873 r
.78614 .31987 .79407 .33204 .81182 .32165 .80401 .30984 Mtetra
.694 .752 .896 r
.80401 .30984 .81182 .32165 .82982 .31324 .82216 .30197 Mtetra
.625 .742 .931 r
.1745 .50363 .18471 .51262 .19913 .50954 .18903 .4998 Mtetra
.546 .699 .94 r
.18903 .4998 .19913 .50954 .21345 .50854 .20342 .49826 Mtetra
.5 .67 .939 r
.20342 .49826 .21345 .50854 .22783 .50808 .21782 .4979 Mtetra
.6 .711 .922 r
.21782 .4979 .22783 .50808 .24268 .50355 .23258 .49486 Mtetra
.719 .775 .896 r
.23258 .49486 .24268 .50355 .25802 .49411 .24783 .48716 Mtetra
.796 .818 .869 r
.24783 .48716 .25802 .49411 .2736 .48198 .26347 .4753 Mtetra
.782 .826 .886 r
.26347 .4753 .2736 .48198 .28902 .47227 .27906 .46449 Mtetra
.716 .798 .916 r
.27906 .46449 .28902 .47227 .30421 .46675 .29444 .45703 Mtetra
.618 .731 .927 r
.29444 .45703 .30421 .46675 .31934 .46361 .30964 .45327 Mtetra
.605 .714 .922 r
.30964 .45327 .31934 .46361 .33457 .46028 .32492 .44999 Mtetra
.626 .723 .917 r
.32492 .44999 .33457 .46028 .34999 .45552 .34034 .44596 Mtetra
.655 .75 .919 r
.34034 .44596 .34999 .45552 .36551 .45049 .35592 .4408 Mtetra
.65 .747 .92 r
.35592 .4408 .36551 .45049 .38111 .44577 .37158 .43581 Mtetra
.645 .74 .919 r
.37158 .43581 .38111 .44577 .3968 .44114 .38734 .43097 Mtetra
.643 .737 .917 r
.38734 .43097 .3968 .44114 .4126 .43618 .40318 .42618 Mtetra
.648 .743 .918 r
.40318 .42618 .4126 .43618 .42851 .43065 .41913 .42115 Mtetra
.659 .759 .924 r
.41913 .42115 .42851 .43065 .44451 .42511 .43519 .41567 Mtetra
.66 .762 .925 r
.43519 .41567 .44451 .42511 .4606 .41977 .45135 .41013 Mtetra
.658 .758 .924 r
.45135 .41013 .4606 .41977 .47678 .41443 .46759 .40463 Mtetra
.656 .755 .923 r
.46759 .40463 .47678 .41443 .49306 .40905 .48394 .39918 Mtetra
.653 .754 .924 r
.48394 .39918 .49306 .40905 .50944 .40361 .50038 .3938 Mtetra
.652 .756 .926 r
.50038 .3938 .50944 .40361 .52592 .39819 .51692 .38845 Mtetra
.652 .759 .928 r
.51692 .38845 .52592 .39819 .5425 .39295 .53357 .38304 Mtetra
.663 .76 .922 r
.53357 .38304 .5425 .39295 .55918 .38771 .55031 .37716 Mtetra
.668 .75 .911 r
.55031 .37716 .55918 .38771 .57595 .38189 .56715 .37106 Mtetra
.666 .744 .909 r
.56715 .37106 .57595 .38189 .59282 .37573 .58409 .36498 Mtetra
.662 .746 .913 r
.58409 .36498 .59282 .37573 .60979 .36965 .60113 .35906 Mtetra
.657 .749 .918 r
.60113 .35906 .60979 .36965 .62687 .3639 .61828 .35331 Mtetra
.683 .76 .909 r
.61828 .35331 .62687 .3639 .64404 .35784 .6355 .34639 Mtetra
.697 .748 .891 r
.6355 .34639 .64404 .35784 .66126 .35033 .65278 .3387 Mtetra
.686 .742 .894 r
.65278 .3387 .66126 .35033 .67855 .34259 .67017 .33148 Mtetra
.593 .716 .93 r
.67017 .33148 .67855 .34259 .69606 .33731 .68786 .32807 Mtetra
.448 .692 .97 r
.68786 .32807 .69606 .33731 .71395 .33635 .70588 .32814 Mtetra
.37 .677 .977 r
.70588 .32814 .71395 .33635 .73217 .33794 .72415 .32934 Mtetra
.559 .766 .975 r
.72415 .32934 .73217 .33794 .75039 .33675 .74233 .32622 Mtetra
.7 .779 .913 r
.74233 .32622 .75039 .33675 .76839 .33045 .76029 .31824 Mtetra
.744 .762 .867 r
.76029 .31824 .76839 .33045 .78614 .31987 .77812 .30743 Mtetra
.723 .752 .875 r
.77812 .30743 .78614 .31987 .80401 .30984 .79611 .29784 Mtetra
.679 .745 .9 r
.79611 .29784 .80401 .30984 .82216 .30197 .8144 .29062 Mtetra
.644 .749 .925 r
.16416 .49462 .1745 .50363 .18903 .4998 .17881 .49009 Mtetra
.57 .711 .937 r
.17881 .49009 .18903 .4998 .20342 .49826 .1933 .48786 Mtetra
.514 .675 .937 r
.1933 .48786 .20342 .49826 .21782 .4979 .20776 .48715 Mtetra
.55 .682 .926 r
.20776 .48715 .21782 .4979 .23258 .49486 .22241 .48561 Mtetra
.681 .757 .909 r
.22241 .48561 .23258 .49486 .24783 .48716 .23757 .47958 Mtetra
.771 .807 .881 r
.23757 .47958 .24783 .48716 .26347 .4753 .25317 .46913 Mtetra
.797 .839 .883 r
.25317 .46913 .26347 .4753 .27906 .46449 .26891 .45743 Mtetra
.753 .821 .905 r
.26891 .45743 .27906 .46449 .29444 .45703 .28449 .44819 Mtetra
.663 .766 .927 r
.28449 .44819 .29444 .45703 .30964 .45327 .29985 .44277 Mtetra
.608 .714 .92 r
.29985 .44277 .30964 .45327 .32492 .44999 .31518 .43933 Mtetra
.612 .713 .917 r
.31518 .43933 .32492 .44999 .34034 .44596 .33062 .43573 Mtetra
.639 .732 .916 r
.33062 .43573 .34034 .44596 .35592 .4408 .34622 .43114 Mtetra
.657 .752 .92 r
.34622 .43114 .35592 .4408 .37158 .43581 .36195 .42584 Mtetra
.65 .744 .918 r
.36195 .42584 .37158 .43581 .38734 .43097 .37777 .42077 Mtetra
.647 .739 .916 r
.37777 .42077 .38734 .43097 .40318 .42618 .39367 .41576 Mtetra
.646 .736 .914 r
.39367 .41576 .40318 .42618 .41913 .42115 .40968 .41077 Mtetra
.649 .738 .915 r
.40968 .41077 .41913 .42115 .43519 .41567 .42578 .40564 Mtetra
.652 .748 .92 r
.42578 .40564 .43519 .41567 .45135 .41013 .44199 .40035 Mtetra
.654 .756 .925 r
.44199 .40035 .45135 .41013 .46759 .40463 .4583 .39494 Mtetra
.656 .76 .926 r
.4583 .39494 .46759 .40463 .48394 .39918 .47471 .38943 Mtetra
.657 .76 .926 r
.47471 .38943 .48394 .39918 .50038 .3938 .49122 .38384 Mtetra
.66 .758 .923 r
.49122 .38384 .50038 .3938 .51692 .38845 .50783 .37811 Mtetra
.663 .752 .916 r
.50783 .37811 .51692 .38845 .53357 .38304 .52454 .37222 Mtetra
.665 .744 .909 r
.52454 .37222 .53357 .38304 .55031 .37716 .54135 .3662 Mtetra
.664 .742 .908 r
.54135 .3662 .55031 .37716 .56715 .37106 .55825 .36018 Mtetra
.662 .744 .911 r
.55825 .36018 .56715 .37106 .58409 .36498 .57526 .35422 Mtetra
.656 .746 .916 r
.57526 .35422 .58409 .36498 .60113 .35906 .59238 .34849 Mtetra
.672 .757 .915 r
.59238 .34849 .60113 .35906 .61828 .35331 .60959 .34203 Mtetra
.692 .751 .897 r
.60959 .34203 .61828 .35331 .6355 .34639 .62686 .33455 Mtetra
.694 .742 .888 r
.62686 .33455 .6355 .34639 .65278 .3387 .64421 .3269 Mtetra
.65 .727 .905 r
.64421 .3269 .65278 .3387 .67017 .33148 .66175 .32126 Mtetra
.529 .71 .955 r
.66175 .32126 .67017 .33148 .68786 .32807 .67959 .31957 Mtetra
.39 .683 .977 r
.67959 .31957 .68786 .32807 .70588 .32814 .69774 .32044 Mtetra
.426 .726 .988 r
.69774 .32044 .70588 .32814 .72415 .32934 .716 .32004 Mtetra
.622 .779 .956 r
.716 .32004 .72415 .32934 .74233 .32622 .73414 .31506 Mtetra
.73 .779 .892 r
.73414 .31506 .74233 .32622 .76029 .31824 .75207 .3054 Mtetra
.737 .751 .864 r
.75207 .3054 .76029 .31824 .77812 .30743 .77 .29484 Mtetra
.711 .747 .88 r
.77 .29484 .77812 .30743 .79611 .29784 .78813 .28583 Mtetra
.665 .741 .907 r
.78813 .28583 .79611 .29784 .8144 .29062 .80657 .27922 Mtetra
.655 .752 .922 r
.15372 .48555 .16416 .49462 .17881 .49009 .16845 .48062 Mtetra
.604 .73 .934 r
.16845 .48062 .17881 .49009 .1933 .48786 .18308 .47735 Mtetra
.542 .686 .933 r
.18308 .47735 .1933 .48786 .20776 .48715 .19764 .47591 Mtetra
.52 .662 .925 r
.19764 .47591 .20776 .48715 .22241 .48561 .21224 .47516 Mtetra
.625 .719 .914 r
.21224 .47516 .22241 .48561 .23757 .47958 .22726 .47118 Mtetra
.727 .788 .9 r
.22726 .47118 .23757 .47958 .25317 .46913 .24273 .46303 Mtetra
.796 .842 .886 r
.24273 .46303 .25317 .46913 .26891 .45743 .25854 .45139 Mtetra
.781 .846 .901 r
.25854 .45139 .26891 .45743 .28449 .44819 .27431 .44076 Mtetra
.725 .813 .92 r
.27431 .44076 .28449 .44819 .29985 .44277 .28992 .4328 Mtetra
.635 .737 .922 r
.28992 .4328 .29985 .44277 .31518 .43933 .30536 .42834 Mtetra
.611 .708 .914 r
.30536 .42834 .31518 .43933 .33062 .43573 .32084 .42475 Mtetra
.618 .712 .912 r
.32084 .42475 .33062 .43573 .34622 .43114 .33644 .42086 Mtetra
.643 .736 .917 r
.33644 .42086 .34622 .43114 .36195 .42584 .3522 .41602 Mtetra
.656 .752 .92 r
.3522 .41602 .36195 .42584 .37777 .42077 .36809 .41064 Mtetra
.653 .745 .917 r
.36809 .41064 .37777 .42077 .39367 .41576 .38406 .40536 Mtetra
.65 .74 .915 r
.38406 .40536 .39367 .41576 .40968 .41077 .40012 .40016 Mtetra
.651 .737 .913 r
.40012 .40016 .40968 .41077 .42578 .40564 .41629 .39491 Mtetra
.651 .736 .911 r
.41629 .39491 .42578 .40564 .44199 .40035 .43255 .38959 Mtetra
.653 .737 .911 r
.43255 .38959 .44199 .40035 .4583 .39494 .44892 .38416 Mtetra
.656 .739 .911 r
.44892 .38416 .4583 .39494 .47471 .38943 .46539 .37859 Mtetra
.658 .74 .91 r
.46539 .37859 .47471 .38943 .49122 .38384 .48196 .37289 Mtetra
.66 .739 .908 r
.48196 .37289 .49122 .38384 .50783 .37811 .49863 .36707 Mtetra
.661 .739 .908 r
.49863 .36707 .50783 .37811 .52454 .37222 .51541 .36118 Mtetra
.662 .741 .909 r
.51541 .36118 .52454 .37222 .54135 .3662 .53228 .35524 Mtetra
.659 .743 .912 r
.53228 .35524 .54135 .3662 .55825 .36018 .54926 .34937 Mtetra
.656 .746 .916 r
.54926 .34937 .55825 .36018 .57526 .35422 .56634 .3436 Mtetra
.668 .756 .916 r
.56634 .3436 .57526 .35422 .59238 .34849 .58352 .33728 Mtetra
.688 .752 .9 r
.58352 .33728 .59238 .34849 .60959 .34203 .60077 .32997 Mtetra
.692 .738 .886 r
.60077 .32997 .60959 .34203 .62686 .33455 .61811 .32236 Mtetra
.673 .73 .893 r
.61811 .32236 .62686 .33455 .64421 .3269 .63558 .31561 Mtetra
.582 .712 .932 r
.63558 .31561 .64421 .3269 .66175 .32126 .65329 .31247 Mtetra
.45 .71 .978 r
.65329 .31247 .66175 .32126 .67959 .31957 .67127 .31209 Mtetra
.362 .698 .983 r
.67127 .31209 .67959 .31957 .69774 .32044 .68949 .31278 Mtetra
.53 .782 .99 r
.68949 .31278 .69774 .32044 .716 .32004 .7077 .30988 Mtetra
.682 .784 .928 r
.7077 .30988 .716 .32004 .73414 .31506 .72578 .30265 Mtetra
.74 .76 .869 r
.72578 .30265 .73414 .31506 .75207 .3054 .74373 .29202 Mtetra
.723 .739 .864 r
.74373 .29202 .75207 .3054 .77 .29484 .76179 .28208 Mtetra
.692 .739 .887 r
.76179 .28208 .77 .29484 .78813 .28583 .78009 .27405 Mtetra
.657 .745 .915 r
.78009 .27405 .78813 .28583 .80657 .27922 .79865 .26773 Mtetra
.658 .752 .92 r
.14317 .47636 .15372 .48555 .16845 .48062 .15795 .47125 Mtetra
.637 .744 .926 r
.15795 .47125 .16845 .48062 .18308 .47735 .17275 .46686 Mtetra
.567 .698 .93 r
.17275 .46686 .18308 .47735 .19764 .47591 .1874 .46468 Mtetra
.525 .667 .926 r
.1874 .46468 .19764 .47591 .21224 .47516 .20205 .46372 Mtetra
.562 .678 .917 r
.20205 .46372 .21224 .47516 .22726 .47118 .21691 .46178 Mtetra
.676 .759 .913 r
.21691 .46178 .22726 .47118 .24273 .46303 .23225 .4558 Mtetra
.761 .82 .899 r
.23225 .4558 .24273 .46303 .25854 .45139 .24799 .446 Mtetra
.797 .862 .897 r
.24799 .446 .25854 .45139 .27431 .44076 .26391 .43444 Mtetra
.761 .844 .914 r
.26391 .43444 .27431 .44076 .28992 .4328 .27972 .42481 Mtetra
.701 .8 .926 r
.27972 .42481 .28992 .4328 .30536 .42834 .2954 .41776 Mtetra
.63 .726 .916 r
.2954 .41776 .30536 .42834 .32084 .42475 .31097 .4134 Mtetra
.616 .706 .909 r
.31097 .4134 .32084 .42475 .33644 .42086 .32662 .40955 Mtetra
.623 .71 .908 r
.32662 .40955 .33644 .42086 .3522 .41602 .34238 .40541 Mtetra
.64 .732 .915 r
.34238 .40541 .3522 .41602 .36809 .41064 .35829 .4006 Mtetra
.654 .75 .92 r
.35829 .4006 .36809 .41064 .38406 .40536 .37432 .3952 Mtetra
.657 .749 .918 r
.37432 .3952 .38406 .40536 .40012 .40016 .39046 .38967 Mtetra
.654 .742 .915 r
.39046 .38967 .40012 .40016 .41629 .39491 .40669 .38423 Mtetra
.653 .74 .913 r
.40669 .38423 .41629 .39491 .43255 .38959 .42301 .37877 Mtetra
.654 .739 .911 r
.42301 .37877 .43255 .38959 .44892 .38416 .43944 .37323 Mtetra
.656 .738 .91 r
.43944 .37323 .44892 .38416 .46539 .37859 .45597 .3676 Mtetra
.657 .739 .91 r
.45597 .3676 .46539 .37859 .48196 .37289 .4726 .36187 Mtetra
.658 .74 .91 r
.4726 .36187 .48196 .37289 .49863 .36707 .48934 .35607 Mtetra
.658 .741 .911 r
.48934 .35607 .49863 .36707 .51541 .36118 .50618 .35024 Mtetra
.655 .743 .914 r
.50618 .35024 .51541 .36118 .53228 .35524 .52312 .3445 Mtetra
.657 .749 .918 r
.52312 .3445 .53228 .35524 .54926 .34937 .54016 .33864 Mtetra
.671 .756 .914 r
.54016 .33864 .54926 .34937 .56634 .3436 .55731 .33216 Mtetra
.685 .747 .899 r
.55731 .33216 .56634 .3436 .58352 .33728 .57454 .32499 Mtetra
.688 .733 .886 r
.57454 .32499 .58352 .33728 .60077 .32997 .59186 .31752 Mtetra
.677 .728 .888 r
.59186 .31752 .60077 .32997 .61811 .32236 .60929 .31056 Mtetra
.612 .716 .919 r
.60929 .31056 .61811 .32236 .63558 .31561 .62691 .30635 Mtetra
.504 .726 .972 r
.62691 .30635 .63558 .31561 .65329 .31247 .64476 .3048 Mtetra
.375 .702 .984 r
.64476 .3048 .65329 .31247 .67127 .31209 .66287 .30526 Mtetra
.439 .76 .996 r
.66287 .30526 .67127 .31209 .68949 .31278 .68108 .30393 Mtetra
.625 .795 .964 r
.68108 .30393 .68949 .31278 .7077 .30988 .69924 .29865 Mtetra
.725 .779 .896 r
.69924 .29865 .7077 .30988 .72578 .30265 .71727 .28916 Mtetra
.732 .741 .859 r
.71727 .28916 .72578 .30265 .74373 .29202 .73531 .27862 Mtetra
.712 .737 .871 r
.73531 .27862 .74373 .29202 .76179 .28208 .75351 .26933 Mtetra
.67 .733 .897 r
.75351 .26933 .76179 .28208 .78009 .27405 .77198 .26233 Mtetra
.654 .748 .919 r
.77198 .26233 .78009 .27405 .79865 .26773 .79062 .25607 Mtetra
.657 .752 .92 r
.1325 .46708 .14317 .47636 .15795 .47125 .14733 .46196 Mtetra
.654 .752 .922 r
.14733 .46196 .15795 .47125 .17275 .46686 .16224 .45692 Mtetra
.606 .725 .93 r
.16224 .45692 .17275 .46686 .1874 .46468 .17706 .45349 Mtetra
.555 .682 .923 r
.17706 .45349 .1874 .46468 .20205 .46372 .19182 .45165 Mtetra
.531 .655 .914 r
.19182 .45165 .20205 .46372 .21691 .46178 .20661 .45061 Mtetra
.608 .704 .912 r
.20661 .45061 .21691 .46178 .23225 .4558 .22176 .4471 Mtetra
.7 .783 .915 r
.22176 .4471 .23225 .4558 .24799 .446 .23733 .44005 Mtetra
.778 .852 .907 r
.23733 .44005 .24799 .446 .26391 .43444 .25326 .42949 Mtetra
.789 .876 .911 r
.25326 .42949 .26391 .43444 .27972 .42481 .26927 .41846 Mtetra
.749 .846 .923 r
.26927 .41846 .27972 .42481 .2954 .41776 .28517 .40931 Mtetra
.693 .792 .926 r
.28517 .40931 .2954 .41776 .31097 .4134 .30097 .40248 Mtetra
.635 .724 .912 r
.30097 .40248 .31097 .4134 .32662 .40955 .31671 .39786 Mtetra
.622 .705 .905 r
.31671 .39786 .32662 .40955 .34238 .40541 .33252 .39372 Mtetra
.627 .708 .904 r
.33252 .39372 .34238 .40541 .35829 .4006 .34844 .38934 Mtetra
.634 .72 .909 r
.34844 .38934 .35829 .4006 .37432 .3952 .36449 .38466 Mtetra
.648 .741 .917 r
.36449 .38466 .37432 .3952 .39046 .38967 .38067 .37941 Mtetra
.655 .75 .92 r
.38067 .37941 .39046 .38967 .40669 .38423 .39696 .37387 Mtetra
.656 .75 .919 r
.39696 .37387 .40669 .38423 .42301 .37877 .41335 .36825 Mtetra
.656 .748 .917 r
.41335 .36825 .42301 .37877 .43944 .37323 .42985 .36258 Mtetra
.656 .746 .917 r
.42985 .36258 .43944 .37323 .45597 .3676 .44644 .35688 Mtetra
.44644 .35688 .45597 .3676 .4726 .36187 .46314 .35116 Mtetra
.656 .748 .917 r
.46314 .35116 .4726 .36187 .48934 .35607 .47993 .34539 Mtetra
.657 .75 .919 r
.47993 .34539 .48934 .35607 .50618 .35024 .49684 .33953 Mtetra
.663 .753 .917 r
.49684 .33953 .50618 .35024 .52312 .3445 .51385 .33339 Mtetra
.676 .75 .907 r
.51385 .33339 .52312 .3445 .54016 .33864 .53096 .32665 Mtetra
.68 .736 .893 r
.53096 .32665 .54016 .33864 .55731 .33216 .54816 .31961 Mtetra
.683 .728 .884 r
.54816 .31961 .55731 .33216 .57454 .32499 .56546 .31231 Mtetra
.672 .723 .887 r
.56546 .31231 .57454 .32499 .59186 .31752 .58287 .30549 Mtetra
.62 .716 .914 r
.58287 .30549 .59186 .31752 .60929 .31056 .60042 .30093 Mtetra
.531 .732 .967 r
.60042 .30093 .60929 .31056 .62691 .30635 .61818 .29874 Mtetra
.404 .721 .988 r
.61818 .29874 .62691 .30635 .64476 .3048 .63617 .29853 Mtetra
.384 .746 .992 r
.63617 .29853 .64476 .3048 .66287 .30526 .65432 .29784 Mtetra
.576 .812 .988 r
.65432 .29784 .66287 .30526 .68108 .30393 .67248 .29353 Mtetra
.696 .788 .921 r
.67248 .29353 .68108 .30393 .69924 .29865 .69058 .28555 Mtetra
.734 .75 .865 r
.69058 .28555 .69924 .29865 .71727 .28916 .70864 .275 Mtetra
.716 .726 .859 r
.70864 .275 .71727 .28916 .73531 .27862 .72681 .26523 Mtetra
.69 .731 .882 r
.72681 .26523 .73531 .27862 .75351 .26933 .74518 .25711 Mtetra
.657 .741 .911 r
.74518 .25711 .75351 .26933 .77198 .26233 .76377 .25066 Mtetra
.655 .752 .922 r
.76377 .25066 .77198 .26233 .79062 .25607 .7825 .24428 Mtetra
.657 .752 .92 r
.12172 .45768 .1325 .46708 .14733 .46196 .1366 .45251 Mtetra
.658 .752 .92 r
.1366 .45251 .14733 .46196 .16224 .45692 .15157 .44727 Mtetra
.642 .745 .923 r
.15157 .44727 .16224 .45692 .17706 .45349 .16657 .44255 Mtetra
.583 .7 .923 r
.16657 .44255 .17706 .45349 .19182 .45165 .18145 .43981 Mtetra
.547 .668 .917 r
.18145 .43981 .19182 .45165 .20661 .45061 .19632 .43822 Mtetra
.551 .66 .908 r
.19632 .43822 .20661 .45061 .22176 .4471 .21132 .43656 Mtetra
.637 .73 .915 r
.21132 .43656 .22176 .4471 .23733 .44005 .22672 .43193 Mtetra
.712 .801 .92 r
.22672 .43193 .23733 .44005 .25326 .42949 .24247 .42433 Mtetra
.779 .874 .917 r
.24247 .42433 .25326 .42949 .26927 .41846 .25853 .41374 Mtetra
.779 .886 .922 r
.25853 .41374 .26927 .41846 .28517 .40931 .27464 .40311 Mtetra
.743 .853 .931 r
.27464 .40311 .28517 .40931 .30097 .40248 .29067 .39417 Mtetra
.701 .8 .927 r
.29067 .39417 .30097 .40248 .31671 .39786 .30664 .38694 Mtetra
.647 .731 .91 r
.30664 .38694 .31671 .39786 .33252 .39372 .32256 .38178 Mtetra
.63 .706 .901 r
.32256 .38178 .33252 .39372 .34844 .38934 .33854 .37722 Mtetra
.632 .705 .899 r
.33854 .37722 .34844 .38934 .36449 .38466 .35463 .37259 Mtetra
.637 .709 .899 r
.35463 .37259 .36449 .38466 .38067 .37941 .37084 .36771 Mtetra
.642 .719 .904 r
.37084 .36771 .38067 .37941 .39696 .37387 .38716 .3626 Mtetra
.647 .731 .91 r
.38716 .3626 .39696 .37387 .41335 .36825 .4036 .35725 Mtetra
.652 .739 .913 r
.4036 .35725 .41335 .36825 .42985 .36258 .42015 .35168 Mtetra
.656 .744 .914 r
.42015 .35168 .42985 .36258 .44644 .35688 .4368 .34592 Mtetra
.66 .745 .913 r
.4368 .34592 .44644 .35688 .46314 .35116 .45357 .33996 Mtetra
.664 .743 .909 r
.45357 .33996 .46314 .35116 .47993 .34539 .47044 .33379 Mtetra
.668 .738 .902 r
.47044 .33379 .47993 .34539 .49684 .33953 .48741 .32737 Mtetra
.672 .73 .893 r
.48741 .32737 .49684 .33953 .51385 .33339 .50448 .32071 Mtetra
.675 .722 .885 r
.50448 .32071 .51385 .33339 .53096 .32665 .52166 .31379 Mtetra
.676 .721 .883 r
.52166 .31379 .53096 .32665 .54816 .31961 .53893 .30679 Mtetra
.663 .718 .89 r
.53893 .30679 .54816 .31961 .56546 .31231 .5563 .3004 Mtetra
.612 .716 .92 r
.5563 .3004 .56546 .31231 .58287 .30549 .57381 .29611 Mtetra
.539 .743 .97 r
.57381 .29611 .58287 .30549 .60042 .30093 .5915 .29359 Mtetra
.421 .739 .992 r
.5915 .29359 .60042 .30093 .61818 .29874 .60938 .2928 Mtetra
.374 .75 .99 r
.60938 .2928 .61818 .29874 .63617 .29853 .62744 .29201 Mtetra
.541 .821 .998 r
.62744 .29201 .63617 .29853 .65432 .29784 .64557 .28814 Mtetra
.671 .796 .941 r
.64557 .28814 .65432 .29784 .67248 .29353 .6637 .2812 Mtetra
.729 .763 .88 r
.6637 .2812 .67248 .29353 .69058 .28555 .68178 .27117 Mtetra
.72 .726 .855 r
.68178 .27117 .69058 .28555 .70864 .275 .69993 .26104 Mtetra
.702 .727 .869 r
.69993 .26104 .70864 .275 .72681 .26523 .71824 .25208 Mtetra
.666 .728 .896 r
.71824 .25208 .72681 .26523 .74518 .25711 .73678 .24516 Mtetra
.654 .748 .919 r
.73678 .24516 .74518 .25711 .76377 .25066 .75547 .23879 Mtetra
.655 .751 .921 r
.75547 .23879 .76377 .25066 .7825 .24428 .77429 .23233 Mtetra
.652 .748 .92 r
.11084 .44804 .12172 .45768 .1366 .45251 .12575 .44298 Mtetra
.657 .753 .92 r
.12575 .44298 .1366 .45251 .15157 .44727 .14077 .43771 Mtetra
.656 .753 .921 r
.14077 .43771 .15157 .44727 .16657 .44255 .15587 .43243 Mtetra
.627 .734 .924 r
.15587 .43243 .16657 .44255 .18145 .43981 .17095 .42818 Mtetra
.577 .687 .916 r
.17095 .42818 .18145 .43981 .19632 .43822 .18595 .42561 Mtetra
.55 .658 .907 r
.18595 .42561 .19632 .43822 .21132 .43656 .20097 .42396 Mtetra
.567 .666 .905 r
.20097 .42396 .21132 .43656 .22672 .43193 .21617 .42175 Mtetra
.649 .745 .919 r
.21617 .42175 .22672 .43193 .24247 .42433 .23175 .41657 Mtetra
.711 .812 .928 r
.23175 .41657 .24247 .42433 .25853 .41374 .24764 .40895 Mtetra
.769 .886 .929 r
.24764 .40895 .25853 .41374 .27464 .40311 .26381 .39877 Mtetra
.771 .898 .932 r
.26381 .39877 .27464 .40311 .29067 .39417 .28003 .38842 Mtetra
.74 .867 .94 r
.28003 .38842 .29067 .39417 .30664 .38694 .29621 .3795 Mtetra
.711 .826 .936 r
.29621 .3795 .30664 .38694 .32256 .38178 .31236 .37175 Mtetra
.672 .761 .917 r
.31236 .37175 .32256 .38178 .33854 .37722 .3285 .36549 Mtetra
.646 .72 .902 r
.3285 .36549 .33854 .37722 .35463 .37259 .34468 .36021 Mtetra
.64 .706 .895 r
.34468 .36021 .35463 .37259 .37084 .36771 .36094 .35514 Mtetra
.64 .704 .893 r
.36094 .35514 .37084 .36771 .38716 .3626 .37731 .35002 Mtetra
.645 .707 .892 r
.37731 .35002 .38716 .3626 .4036 .35725 .3938 .34464 Mtetra
.65 .71 .891 r
.3938 .34464 .4036 .35725 .42015 .35168 .4104 .33903 Mtetra
.654 .711 .89 r
.4104 .33903 .42015 .35168 .4368 .34592 .42711 .3332 Mtetra
.658 .713 .888 r
.42711 .3332 .4368 .34592 .45357 .33996 .44393 .32715 Mtetra
.663 .714 .887 r
.44393 .32715 .45357 .33996 .47044 .33379 .46086 .32086 Mtetra
.667 .715 .884 r
.46086 .32086 .47044 .33379 .48741 .32737 .47789 .31432 Mtetra
.667 .714 .883 r
.47789 .31432 .48741 .32737 .50448 .32071 .49502 .30771 Mtetra
.662 .715 .887 r
.49502 .30771 .50448 .32071 .52166 .31379 .51226 .30132 Mtetra
.64 .717 .903 r
.51226 .30132 .52166 .31379 .53893 .30679 .52959 .2959 Mtetra
.596 .733 .94 r
.52959 .2959 .53893 .30679 .5563 .3004 .54706 .29202 Mtetra
.529 .765 .984 r
.54706 .29202 .5563 .3004 .57381 .29611 .56468 .28933 Mtetra
.423 .756 .995 r
.56468 .28933 .57381 .29611 .5915 .29359 .58248 .28813 Mtetra
.385 .769 .99 r
.58248 .28813 .5915 .29359 .60938 .2928 .60045 .28676 Mtetra
.534 .831 .999 r
.60045 .28676 .60938 .2928 .62744 .29201 .61851 .28278 Mtetra
.657 .803 .953 r
.61851 .28278 .62744 .29201 .64557 .28814 .63662 .27629 Mtetra
.722 .77 .891 r
.63662 .27629 .64557 .28814 .6637 .2812 .65473 .26671 Mtetra
.72 .725 .854 r
.65473 .26671 .6637 .2812 .68178 .27117 .67288 .25653 Mtetra
.704 .718 .86 r
.67288 .25653 .68178 .27117 .69993 .26104 .69116 .24727 Mtetra
.676 .722 .884 r
.69116 .24727 .69993 .26104 .71824 .25208 .70963 .23975 Mtetra
.655 .742 .914 r
.70963 .23975 .71824 .25208 .73678 .24516 .72829 .23328 Mtetra
.655 .752 .922 r
.72829 .23328 .73678 .24516 .75547 .23879 .74707 .2268 Mtetra
.659 .754 .92 r
.74707 .2268 .75547 .23879 .77429 .23233 .76596 .22009 Mtetra
.649 .747 .921 r
.09985 .43829 .11084 .44804 .12575 .44298 .11479 .43327 Mtetra
.655 .75 .92 r
.11479 .43327 .12575 .44298 .14077 .43771 .12985 .42801 Mtetra
.657 .752 .92 r
.12985 .42801 .14077 .43771 .15587 .43243 .14501 .42265 Mtetra
.653 .751 .921 r
.14501 .42265 .15587 .43243 .17095 .42818 .16024 .4174 Mtetra
.617 .721 .92 r
.16024 .4174 .17095 .42818 .18595 .42561 .17542 .41342 Mtetra
.579 .68 .909 r
.17542 .41342 .18595 .42561 .20097 .42396 .19057 .41076 Mtetra
.557 .653 .899 r
.19057 .41076 .20097 .42396 .21617 .42175 .20576 .40888 Mtetra
.576 .668 .901 r
.20576 .40888 .21617 .42175 .23175 .41657 .22113 .4063 Mtetra
.647 .746 .921 r
.22113 .4063 .23175 .41657 .24764 .40895 .23686 .40111 Mtetra
.698 .812 .936 r
.23686 .40111 .24764 .40895 .26381 .39877 .25285 .39391 Mtetra
.747 .887 .943 r
.25285 .39391 .26381 .39877 .28003 .38842 .26909 .38457 Mtetra
.755 .912 .944 r
.26909 .38457 .28003 .38842 .29621 .3795 .28543 .3747 Mtetra
.74 .892 .948 r
.28543 .3747 .29621 .3795 .31236 .37175 .30178 .36555 Mtetra
.715 .859 .95 r
.30178 .36555 .31236 .37175 .3285 .36549 .31811 .35747 Mtetra
.696 .815 .939 r
.31811 .35747 .3285 .36549 .34468 .36021 .33447 .35019 Mtetra
.677 .768 .919 r
.33447 .35019 .34468 .36021 .36094 .35514 .35088 .3436 Mtetra
.657 .732 .905 r
.35088 .3436 .36094 .35514 .37731 .35002 .36734 .33776 Mtetra
.653 .718 .896 r
.36734 .33776 .37731 .35002 .3938 .34464 .38389 .33202 Mtetra
.653 .712 .892 r
.38389 .33202 .3938 .34464 .4104 .33903 .40055 .32623 Mtetra
.654 .711 .89 r
.40055 .32623 .4104 .33903 .42711 .3332 .41732 .32033 Mtetra
.656 .712 .889 r
.41732 .32033 .42711 .3332 .44393 .32715 .43419 .31432 Mtetra
.656 .714 .89 r
.43419 .31432 .44393 .32715 .46086 .32086 .45117 .30826 Mtetra
.654 .718 .896 r
.45117 .30826 .46086 .32086 .47789 .31432 .46825 .3023 Mtetra
.635 .724 .912 r
.46825 .3023 .47789 .31432 .49502 .30771 .48543 .29709 Mtetra
.613 .746 .94 r
.48543 .29709 .49502 .30771 .51226 .30132 .50273 .29259 Mtetra
.572 .775 .975 r
.50273 .29259 .51226 .30132 .52959 .2959 .52015 .2889 Mtetra
.496 .787 .997 r
.52015 .2889 .52959 .2959 .54706 .29202 .53771 .28632 Mtetra
.42 .783 .995 r
.53771 .28632 .54706 .29202 .56468 .28933 .55543 .28447 Mtetra
.417 .801 .99 r
.55543 .28447 .56468 .28933 .58248 .28813 .57331 .28211 Mtetra
.557 .842 .998 r
.57331 .28211 .58248 .28813 .60045 .28676 .59131 .27756 Mtetra
.66 .805 .953 r
.59131 .27756 .60045 .28676 .61851 .28278 .60939 .27095 Mtetra
.717 .77 .894 r
.60939 .27095 .61851 .28278 .63662 .27629 .62749 .26163 Mtetra
.717 .722 .854 r
.62749 .26163 .63662 .27629 .65473 .26671 .64565 .25157 Mtetra
.702 .71 .855 r
.64565 .25157 .65473 .26671 .67288 .25653 .66392 .24229 Mtetra
.681 .718 .876 r
.66392 .24229 .67288 .25653 .69116 .24727 .68234 .23436 Mtetra
.657 .733 .905 r
.68234 .23436 .69116 .24727 .70963 .23975 .70095 .22773 Mtetra
.655 .751 .921 r
.70095 .22773 .70963 .23975 .72829 .23328 .71969 .22121 Mtetra
.656 .752 .921 r
.71969 .22121 .72829 .23328 .74707 .2268 .73856 .21458 Mtetra
.661 .753 .918 r
.73856 .21458 .74707 .2268 .76596 .22009 .75752 .20768 Mtetra
.653 .75 .921 r
.08872 .42854 .09985 .43829 .11479 .43327 .10373 .42333 Mtetra
.65 .746 .92 r
.10373 .42333 .11479 .43327 .12985 .42801 .11881 .41821 Mtetra
.657 .752 .92 r
.11881 .41821 .12985 .42801 .14501 .42265 .13402 .41279 Mtetra
.657 .753 .92 r
.13402 .41279 .14501 .42265 .16024 .4174 .14932 .40733 Mtetra
.65 .747 .921 r
.14932 .40733 .16024 .4174 .17542 .41342 .16468 .40209 Mtetra
.615 .712 .915 r
.16468 .40209 .17542 .41342 .19057 .41076 .18 .39811 Mtetra
.584 .676 .903 r
.18 .39811 .19057 .41076 .20576 .40888 .19532 .39521 Mtetra
.566 .652 .893 r
.19532 .39521 .20576 .40888 .22113 .4063 .21068 .39296 Mtetra
.58 .664 .896 r
.21068 .39296 .22113 .4063 .23686 .40111 .22622 .3902 Mtetra
.633 .732 .919 r
.22622 .3902 .23686 .40111 .25285 .39391 .24205 .38544 Mtetra
.679 .798 .938 r
.24205 .38544 .25285 .39391 .26909 .38457 .25813 .37889 Mtetra
.711 .869 .956 r
.25813 .37889 .26909 .38457 .28543 .3747 .27442 .3709 Mtetra
.73 .914 .957 r
.27442 .3709 .28543 .3747 .30178 .36555 .29086 .36181 Mtetra
.725 .917 .959 r
.29086 .36181 .30178 .36555 .31811 .35747 .30735 .35282 Mtetra
.714 .897 .962 r
.30735 .35282 .31811 .35747 .33447 .35019 .32388 .34441 Mtetra
.694 .87 .965 r
.32388 .34441 .33447 .35019 .35088 .3436 .34042 .33684 Mtetra
.682 .847 .962 r
.34042 .33684 .35088 .3436 .36734 .33776 .35703 .3298 Mtetra
.672 .818 .953 r
.35703 .3298 .36734 .33776 .38389 .33202 .3737 .32319 Mtetra
.663 .797 .946 r
.3737 .32319 .38389 .33202 .40055 .32623 .39045 .31693 Mtetra
.655 .785 .944 r
.39045 .31693 .40055 .32623 .41732 .32033 .40729 .31096 Mtetra
.645 .782 .947 r
.40729 .31096 .41732 .32033 .43419 .31432 .42422 .30529 Mtetra
.632 .787 .956 r
.42422 .30529 .43419 .31432 .45117 .30826 .44126 .29997 Mtetra
.612 .8 .971 r
.44126 .29997 .45117 .30826 .46825 .3023 .4584 .29509 Mtetra
.579 .815 .989 r
.4584 .29509 .46825 .3023 .48543 .29709 .47566 .29075 Mtetra
.524 .816 .999 r
.47566 .29075 .48543 .29709 .50273 .29259 .49303 .28727 Mtetra
.465 .814 .998 r
.49303 .28727 .50273 .29259 .52015 .2889 .51055 .28438 Mtetra
.428 .814 .989 r
.51055 .28438 .52015 .2889 .53771 .28632 .52821 .28161 Mtetra
.493 .843 .995 r
.52821 .28161 .53771 .28632 .55543 .28447 .54602 .27773 Mtetra
.6 .842 .99 r
.54602 .27773 .55543 .28447 .57331 .28211 .56396 .27238 Mtetra
.675 .799 .941 r
.56396 .27238 .57331 .28211 .59131 .27756 .58199 .26519 Mtetra
.714 .76 .888 r
.58199 .26519 .59131 .27756 .60939 .27095 .60008 .25593 Mtetra
.711 .715 .852 r
.60008 .25593 .60939 .27095 .62749 .26163 .61824 .24613 Mtetra
.698 .704 .852 r
.61824 .24613 .62749 .26163 .64565 .25157 .6365 .23698 Mtetra
.682 .713 .872 r
.6365 .23698 .64565 .25157 .66392 .24229 .6549 .22892 Mtetra
.659 .726 .899 r
.6549 .22892 .66392 .24229 .68234 .23436 .67347 .22215 Mtetra
.654 .748 .919 r
.67347 .22215 .68234 .23436 .70095 .22773 .69217 .21561 Mtetra
.655 .752 .921 r
.69217 .21561 .70095 .22773 .71969 .22121 .711 .20901 Mtetra
.661 .754 .919 r
.711 .20901 .71969 .22121 .73856 .21458 .72993 .20208 Mtetra
.658 .749 .917 r
.72993 .20208 .73856 .21458 .75752 .20768 .749 .19524 Mtetra
.658 .754 .92 r
.07745 .4188 .08872 .42854 .10373 .42333 .09254 .41333 Mtetra
.651 .748 .92 r
.09254 .41333 .10373 .42333 .11881 .41821 .10768 .4081 Mtetra
.651 .747 .92 r
.10768 .4081 .11881 .41821 .13402 .41279 .12291 .40284 Mtetra
.657 .753 .92 r
.12291 .40284 .13402 .41279 .14932 .40733 .13826 .39732 Mtetra
.13826 .39732 .14932 .40733 .16468 .40209 .1537 .39176 Mtetra
.65 .746 .919 r
.1537 .39176 .16468 .40209 .18 .39811 .16921 .38644 Mtetra
.62 .71 .91 r
.16921 .38644 .18 .39811 .19532 .39521 .1847 .38221 Mtetra
.593 .677 .899 r
.1847 .38221 .19532 .39521 .21068 .39296 .20019 .37893 Mtetra
.579 .654 .888 r
.20019 .37893 .21068 .39296 .22622 .3902 .21575 .37618 Mtetra
.582 .656 .888 r
.21575 .37618 .22622 .3902 .24205 .38544 .23144 .37329 Mtetra
.611 .703 .91 r
.23144 .37329 .24205 .38544 .25813 .37889 .24735 .36926 Mtetra
.656 .771 .933 r
.24735 .36926 .25813 .37889 .27442 .3709 .26352 .36348 Mtetra
.678 .827 .955 r
.26352 .36348 .27442 .3709 .29086 .36181 .27986 .35674 Mtetra
.688 .884 .971 r
.27986 .35674 .29086 .36181 .30735 .35282 .29634 .34922 Mtetra
.691 .917 .971 r
.29634 .34922 .30735 .35282 .32388 .34441 .31295 .34109 Mtetra
.678 .922 .973 r
.31295 .34109 .32388 .34441 .34042 .33684 .32963 .33315 Mtetra
.666 .913 .977 r
.32963 .33315 .34042 .33684 .35703 .3298 .34636 .3256 Mtetra
.653 .901 .982 r
.34636 .3256 .35703 .3298 .3737 .32319 .36315 .31854 Mtetra
.637 .889 .986 r
.36315 .31854 .3737 .32319 .39045 .31693 .38001 .312 Mtetra
.618 .879 .99 r
.38001 .312 .39045 .31693 .40729 .31096 .39695 .30597 Mtetra
.595 .871 .993 r
.39695 .30597 .40729 .31096 .42422 .30529 .41397 .30046 Mtetra
.565 .865 .996 r
.41397 .30046 .42422 .30529 .44126 .29997 .4311 .29547 Mtetra
.53 .859 .996 r
.4311 .29547 .44126 .29997 .4584 .29509 .44833 .29097 Mtetra
.493 .852 .991 r
.44833 .29097 .4584 .29509 .47566 .29075 .46568 .28689 Mtetra
.47 .847 .986 r
.46568 .28689 .47566 .29075 .49303 .28727 .48317 .283 Mtetra
.513 .86 .992 r
.48317 .283 .49303 .28727 .51055 .28438 .5008 .27849 Mtetra
.585 .856 .995 r
.5008 .27849 .51055 .28438 .52821 .28161 .51856 .2732 Mtetra
.646 .819 .966 r
.51856 .2732 .52821 .28161 .54602 .27773 .53645 .26693 Mtetra
.695 .784 .919 r
.53645 .26693 .54602 .27773 .56396 .27238 .55444 .25886 Mtetra
.709 .738 .874 r
.55444 .25886 .56396 .27238 .58199 .26519 .57251 .2496 Mtetra
.702 .704 .849 r
.57251 .2496 .58199 .26519 .60008 .25593 .59067 .24019 Mtetra
.692 .7 .852 r
.59067 .24019 .60008 .25593 .61824 .24613 .60892 .23129 Mtetra
.678 .709 .871 r
.60892 .23129 .61824 .24613 .6365 .23698 .6273 .22337 Mtetra
.659 .723 .897 r
.6273 .22337 .6365 .23698 .6549 .22892 .64583 .21655 Mtetra
.654 .746 .918 r
.64583 .21655 .6549 .22892 .67347 .22215 .66449 .20998 Mtetra
.655 .752 .922 r
.66449 .20998 .67347 .22215 .69217 .21561 .68328 .20334 Mtetra
.66 .754 .92 r
.68328 .20334 .69217 .21561 .711 .20901 .70218 .19644 Mtetra
.66 .75 .917 r
.70218 .19644 .711 .20901 .72993 .20208 .7212 .18948 Mtetra
.653 .748 .919 r
.7212 .18948 .72993 .20208 .749 .19524 .74037 .18276 Mtetra
.659 .754 .92 r
.06606 .40896 .07745 .4188 .09254 .41333 .0812 .40341 Mtetra
.658 .753 .921 r
.0812 .40341 .09254 .41333 .10768 .4081 .09642 .39789 Mtetra
.651 .747 .92 r
.09642 .39789 .10768 .4081 .12291 .40284 .1117 .39259 Mtetra
.652 .748 .92 r
.1117 .39259 .12291 .40284 .13826 .39732 .12708 .3872 Mtetra
.657 .753 .92 r
.12708 .3872 .13826 .39732 .1537 .39176 .14257 .38159 Mtetra
.657 .753 .921 r
.14257 .38159 .1537 .39176 .16921 .38644 .15816 .37594 Mtetra
.652 .746 .919 r
.15816 .37594 .16921 .38644 .1847 .38221 .17383 .37044 Mtetra
.63 .716 .908 r
.17383 .37044 .1847 .38221 .20019 .37893 .18951 .36573 Mtetra
.604 .681 .896 r
.18951 .36573 .20019 .37893 .21575 .37618 .20519 .36198 Mtetra
.596 .661 .884 r
.20519 .36198 .21575 .37618 .23144 .37329 .22096 .35852 Mtetra
.587 .649 .879 r
.22096 .35852 .23144 .37329 .24735 .36926 .23681 .35539 Mtetra
.6 .671 .89 r
.23681 .35539 .24735 .36926 .26352 .36348 .25284 .3517 Mtetra
.624 .72 .915 r
.25284 .3517 .26352 .36348 .27986 .35674 .26906 .34706 Mtetra
.653 .774 .937 r
.26906 .34706 .27986 .35674 .29634 .34922 .28548 .34126 Mtetra
.663 .816 .957 r
.28548 .34126 .29634 .34922 .31295 .34109 .30205 .33493 Mtetra
.66 .859 .975 r
.30205 .33493 .31295 .34109 .32963 .33315 .31872 .32832 Mtetra
.647 .886 .984 r
.31872 .32832 .32963 .33315 .34636 .3256 .3355 .32164 Mtetra
.628 .9 .986 r
.3355 .32164 .34636 .3256 .36315 .31854 .35237 .31501 Mtetra
.608 .904 .985 r
.35237 .31501 .36315 .31854 .38001 .312 .36933 .30855 Mtetra
.586 .899 .985 r
.36933 .30855 .38001 .312 .39695 .30597 .38638 .30246 Mtetra
.566 .892 .986 r
.38638 .30246 .39695 .30597 .41397 .30046 .40351 .29675 Mtetra
.56 .887 .988 r
.40351 .29675 .41397 .30046 .4311 .29547 .42076 .2912 Mtetra
.568 .881 .992 r
.42076 .2912 .4311 .29547 .44833 .29097 .43812 .2857 Mtetra
.59 .869 .994 r
.43812 .2857 .44833 .29097 .46568 .28689 .45561 .28014 Mtetra
.621 .848 .986 r
.45561 .28014 .46568 .28689 .48317 .283 .47322 .27429 Mtetra
.652 .813 .961 r
.47322 .27429 .48317 .283 .5008 .27849 .49095 .2679 Mtetra
.684 .784 .926 r
.49095 .2679 .5008 .27849 .51856 .2732 .5088 .26033 Mtetra
.699 .746 .888 r
.5088 .26033 .51856 .2732 .53645 .26693 .52676 .25178 Mtetra
.699 .71 .856 r
.52676 .25178 .53645 .26693 .55444 .25886 .54481 .24264 Mtetra
.689 .691 .847 r
.54481 .24264 .55444 .25886 .57251 .2496 .56295 .23381 Mtetra
.686 .697 .855 r
.56295 .23381 .57251 .2496 .59067 .24019 .58118 .22528 Mtetra
.671 .706 .874 r
.58118 .22528 .59067 .24019 .60892 .23129 .59954 .21771 Mtetra
.657 .724 .899 r
.59954 .21771 .60892 .23129 .6273 .22337 .61803 .21094 Mtetra
.654 .747 .918 r
.61803 .21094 .6273 .22337 .64583 .21655 .63666 .20432 Mtetra
.655 .752 .922 r
.63666 .20432 .64583 .21655 .66449 .20998 .6554 .19765 Mtetra
.659 .754 .92 r
.6554 .19765 .66449 .20998 .68328 .20334 .67427 .19073 Mtetra
.66 .75 .917 r
.67427 .19073 .68328 .20334 .70218 .19644 .69325 .18371 Mtetra
.654 .747 .918 r
.69325 .18371 .70218 .19644 .7212 .18948 .71238 .17692 Mtetra
.653 .751 .922 r
.71238 .17692 .7212 .18948 .74037 .18276 .73164 .17015 Mtetra
.658 .753 .92 r
.05454 .39898 .06606 .40896 .0812 .40341 .06973 .39342 Mtetra
.659 .755 .921 r
.06973 .39342 .0812 .40341 .09642 .39789 .08501 .38778 Mtetra
.657 .753 .921 r
.08501 .38778 .09642 .39789 .1117 .39259 .10037 .38218 Mtetra
.651 .746 .92 r
.10037 .38218 .1117 .39259 .12708 .3872 .11579 .37677 Mtetra
.652 .748 .92 r
.11579 .37677 .12708 .3872 .14257 .38159 .13132 .3713 Mtetra
.657 .753 .921 r
.13132 .3713 .14257 .38159 .15816 .37594 .14696 .36559 Mtetra
.14696 .36559 .15816 .37594 .17383 .37044 .1627 .35987 Mtetra
.656 .749 .919 r
.1627 .35987 .17383 .37044 .18951 .36573 .17853 .35415 Mtetra
.643 .727 .909 r
.17853 .35415 .18951 .36573 .20519 .36198 .19441 .34884 Mtetra
.618 .691 .895 r
.19441 .34884 .20519 .36198 .22096 .35852 .2103 .34444 Mtetra
.608 .672 .885 r
.2103 .34444 .22096 .35852 .23681 .35539 .22627 .34039 Mtetra
.604 .656 .874 r
.22627 .34039 .23681 .35539 .25284 .3517 .24234 .33647 Mtetra
.601 .652 .872 r
.24234 .33647 .25284 .3517 .26906 .34706 .25853 .33263 Mtetra
.612 .671 .882 r
.25853 .33263 .26906 .34706 .28548 .34126 .27486 .32836 Mtetra
.624 .704 .902 r
.27486 .32836 .28548 .34126 .30205 .33493 .29136 .32357 Mtetra
.637 .739 .922 r
.29136 .32357 .30205 .33493 .31872 .32832 .30801 .31824 Mtetra
.65 .771 .937 r
.30801 .31824 .31872 .32832 .3355 .32164 .3248 .31236 Mtetra
.653 .791 .948 r
.3248 .31236 .3355 .32164 .35237 .31501 .34171 .3063 Mtetra
.652 .805 .956 r
.34171 .3063 .35237 .31501 .36933 .30855 .35873 .30017 Mtetra
.65 .813 .962 r
.35873 .30017 .36933 .30855 .38638 .30246 .37586 .29401 Mtetra
.37586 .29401 .38638 .30246 .40351 .29675 .3931 .28783 Mtetra
.652 .805 .956 r
.3931 .28783 .40351 .29675 .42076 .2912 .41045 .28157 Mtetra
.658 .792 .947 r
.41045 .28157 .42076 .2912 .43812 .2857 .42792 .27513 Mtetra
.672 .778 .929 r
.42792 .27513 .43812 .2857 .45561 .28014 .44551 .26812 Mtetra
.682 .754 .906 r
.44551 .26812 .45561 .28014 .47322 .27429 .46322 .26057 Mtetra
.687 .726 .88 r
.46322 .26057 .47322 .27429 .49095 .2679 .48104 .25248 Mtetra
.688 .701 .857 r
.48104 .25248 .49095 .2679 .5088 .26033 .49896 .24393 Mtetra
.682 .686 .847 r
.49896 .24393 .5088 .26033 .52676 .25178 .51698 .23547 Mtetra
.681 .687 .85 r
.51698 .23547 .52676 .25178 .54481 .24264 .53509 .22711 Mtetra
.677 .699 .863 r
.53509 .22711 .54481 .24264 .56295 .23381 .5533 .21909 Mtetra
.662 .706 .881 r
.5533 .21909 .56295 .23381 .58118 .22528 .57163 .212 Mtetra
.655 .73 .905 r
.57163 .212 .58118 .22528 .59954 .21771 .59008 .20532 Mtetra
.655 .749 .919 r
.59008 .20532 .59954 .21771 .61803 .21094 .60866 .19864 Mtetra
.655 .752 .922 r
.60866 .19864 .61803 .21094 .63666 .20432 .62737 .19192 Mtetra
.659 .754 .92 r
.62737 .19192 .63666 .20432 .6554 .19765 .64619 .18497 Mtetra
.66 .75 .917 r
.64619 .18497 .6554 .19765 .67427 .19073 .66514 .17792 Mtetra
.655 .747 .918 r
.66514 .17792 .67427 .19073 .69325 .18371 .68423 .17107 Mtetra
.653 .751 .922 r
.68423 .17107 .69325 .18371 .71238 .17692 .70345 .16425 Mtetra
.654 .753 .922 r
.70345 .16425 .71238 .17692 .73164 .17015 .7228 .15733 Mtetra
.656 .751 .92 r
.04291 .38882 .05454 .39898 .06973 .39342 .05813 .38328 Mtetra
.658 .753 .92 r
.05813 .38328 .06973 .39342 .08501 .38778 .07346 .37762 Mtetra
.659 .755 .921 r
.07346 .37762 .08501 .38778 .10037 .38218 .08888 .37188 Mtetra
.657 .753 .92 r
.08888 .37188 .10037 .38218 .11579 .37677 .10438 .36618 Mtetra
.651 .746 .919 r
.10438 .36618 .11579 .37677 .13132 .3713 .11996 .36066 Mtetra
.651 .747 .92 r
.11996 .36066 .13132 .3713 .14696 .36559 .13563 .35511 Mtetra
.657 .753 .921 r
.13563 .35511 .14696 .36559 .1627 .35987 .15142 .34932 Mtetra
.15142 .34932 .1627 .35987 .17853 .35415 .16731 .34351 Mtetra
.657 .752 .92 r
.16731 .34351 .17853 .35415 .19441 .34884 .1833 .33762 Mtetra
.652 .74 .914 r
.1833 .33762 .19441 .34884 .2103 .34444 .19938 .33189 Mtetra
.64 .713 .9 r
.19938 .33189 .2103 .34444 .22627 .34039 .21551 .32654 Mtetra
.623 .685 .887 r
.21551 .32654 .22627 .34039 .24234 .33647 .23169 .32182 Mtetra
.619 .671 .878 r
.23169 .32182 .24234 .33647 .25853 .33263 .24796 .31721 Mtetra
.618 .66 .868 r
.24796 .31721 .25853 .33263 .27486 .32836 .26436 .31255 Mtetra
.618 .655 .864 r
.26436 .31255 .27486 .32836 .29136 .32357 .28088 .30783 Mtetra
.622 .659 .865 r
.28088 .30783 .29136 .32357 .30801 .31824 .29753 .30294 Mtetra
.629 .669 .87 r
.29753 .30294 .30801 .31824 .3248 .31236 .31431 .2977 Mtetra
.637 .684 .877 r
.31431 .2977 .3248 .31236 .34171 .3063 .33124 .29211 Mtetra
.645 .696 .883 r
.33124 .29211 .34171 .3063 .35873 .30017 .34829 .2862 Mtetra
.652 .704 .885 r
.34829 .2862 .35873 .30017 .37586 .29401 .36548 .27996 Mtetra
.657 .706 .883 r
.36548 .27996 .37586 .29401 .3931 .28783 .38278 .27341 Mtetra
.663 .703 .877 r
.38278 .27341 .3931 .28783 .41045 .28157 .40021 .26652 Mtetra
.667 .696 .867 r
.40021 .26652 .41045 .28157 .42792 .27513 .41776 .25927 Mtetra
.67 .686 .856 r
.41776 .25927 .42792 .27513 .44551 .26812 .43542 .25167 Mtetra
.671 .679 .849 r
.43542 .25167 .44551 .26812 .46322 .26057 .45319 .24388 Mtetra
.671 .677 .847 r
.45319 .24388 .46322 .26057 .48104 .25248 .47105 .23603 Mtetra
.672 .682 .851 r
.47105 .23603 .48104 .25248 .49896 .24393 .48902 .22812 Mtetra
.672 .692 .86 r
.48902 .22812 .49896 .24393 .51698 .23547 .50709 .2203 Mtetra
.662 .699 .874 r
.50709 .2203 .51698 .23547 .53509 .22711 .52527 .21312 Mtetra
.657 .718 .894 r
.52527 .21312 .53509 .22711 .5533 .21909 .54356 .20631 Mtetra
.654 .741 .914 r
.54356 .20631 .5533 .21909 .57163 .212 .56197 .19966 Mtetra
.655 .752 .921 r
.56197 .19966 .57163 .212 .59008 .20532 .58051 .19293 Mtetra
.58051 .19293 .59008 .20532 .60866 .19864 .59918 .18617 Mtetra
.66 .754 .92 r
.59918 .18617 .60866 .19864 .62737 .19192 .61796 .17914 Mtetra
.66 .75 .917 r
.61796 .17914 .62737 .19192 .64619 .18497 .63687 .17207 Mtetra
.654 .747 .918 r
.63687 .17207 .64619 .18497 .66514 .17792 .65591 .16519 Mtetra
.653 .751 .922 r
.65591 .16519 .66514 .17792 .68423 .17107 .67509 .15833 Mtetra
.654 .753 .923 r
.67509 .15833 .68423 .17107 .70345 .16425 .6944 .15137 Mtetra
.656 .753 .921 r
.6944 .15137 .70345 .16425 .7228 .15733 .71384 .14428 Mtetra
.653 .748 .92 r
.03116 .37844 .04291 .38882 .05813 .38328 .04642 .37295 Mtetra
.656 .751 .92 r
.04642 .37295 .05813 .38328 .07346 .37762 .06178 .3673 Mtetra
.658 .753 .921 r
.06178 .3673 .07346 .37762 .08888 .37188 .07725 .36155 Mtetra
.659 .755 .921 r
.07725 .36155 .08888 .37188 .10438 .36618 .09282 .35572 Mtetra
.658 .753 .92 r
.09282 .35572 .10438 .36618 .11996 .36066 .10847 .3499 Mtetra
.653 .747 .919 r
.10847 .3499 .11996 .36066 .13563 .35511 .1242 .34424 Mtetra
.651 .746 .919 r
.1242 .34424 .13563 .35511 .15142 .34932 .14003 .33858 Mtetra
.655 .751 .92 r
.14003 .33858 .15142 .34932 .16731 .34351 .15596 .33277 Mtetra
.657 .753 .921 r
.15596 .33277 .16731 .34351 .1833 .33762 .17201 .32684 Mtetra
.656 .753 .921 r
.17201 .32684 .1833 .33762 .19938 .33189 .18815 .3209 Mtetra
.657 .75 .919 r
.18815 .3209 .19938 .33189 .21551 .32654 .20441 .31486 Mtetra
.652 .737 .911 r
.20441 .31486 .21551 .32654 .23169 .32182 .22074 .30897 Mtetra
.646 .714 .897 r
.22074 .30897 .23169 .32182 .24796 .31721 .23716 .30325 Mtetra
.636 .693 .886 r
.23716 .30325 .24796 .31721 .26436 .31255 .25366 .29784 Mtetra
.632 .68 .877 r
.25366 .29784 .26436 .31255 .28088 .30783 .27026 .29253 Mtetra
.632 .672 .87 r
.27026 .29253 .28088 .30783 .29753 .30294 .28698 .28712 Mtetra
.634 .666 .863 r
.28698 .28712 .29753 .30294 .31431 .2977 .30383 .28154 Mtetra
.637 .663 .859 r
.30383 .28154 .31431 .2977 .33124 .29211 .3208 .27574 Mtetra
.641 .663 .855 r
.3208 .27574 .33124 .29211 .34829 .2862 .3379 .26969 Mtetra
.645 .664 .853 r
.3379 .26969 .34829 .2862 .36548 .27996 .35512 .26337 Mtetra
.65 .666 .852 r
.35512 .26337 .36548 .27996 .38278 .27341 .37247 .25679 Mtetra
.654 .668 .851 r
.37247 .25679 .38278 .27341 .40021 .26652 .38994 .24996 Mtetra
.658 .672 .852 r
.38994 .24996 .40021 .26652 .41776 .25927 .40752 .24289 Mtetra
.661 .677 .854 r
.40752 .24289 .41776 .25927 .43542 .25167 .42522 .23565 Mtetra
.664 .684 .859 r
.42522 .23565 .43542 .25167 .45319 .24388 .44302 .2283 Mtetra
.663 .692 .867 r
.44302 .2283 .45319 .24388 .47105 .23603 .46094 .22105 Mtetra
.658 .701 .878 r
.46094 .22105 .47105 .23603 .48902 .22812 .47895 .21411 Mtetra
.656 .718 .894 r
.47895 .21411 .48902 .22812 .50709 .2203 .49708 .20734 Mtetra
.654 .737 .911 r
.49708 .20734 .50709 .2203 .52527 .21312 .51533 .2007 Mtetra
.656 .75 .919 r
.51533 .2007 .52527 .21312 .54356 .20631 .53371 .19396 Mtetra
.655 .753 .922 r
.53371 .19396 .54356 .20631 .56197 .19966 .5522 .1872 Mtetra
.657 .753 .921 r
.5522 .1872 .56197 .19966 .58051 .19293 .57082 .18032 Mtetra
.66 .753 .919 r
.57082 .18032 .58051 .19293 .59918 .18617 .58956 .17326 Mtetra
.658 .748 .916 r
.58956 .17326 .59918 .18617 .61796 .17914 .60843 .1662 Mtetra
.654 .747 .918 r
.60843 .1662 .61796 .17914 .63687 .17207 .62744 .15929 Mtetra
.653 .752 .922 r
.62744 .15929 .63687 .17207 .65591 .16519 .64657 .15238 Mtetra
.654 .753 .923 r
.64657 .15238 .65591 .16519 .67509 .15833 .66584 .14538 Mtetra
.656 .753 .921 r
.66584 .14538 .67509 .15833 .6944 .15137 .68523 .13825 Mtetra
.659 .753 .919 r
.68523 .13825 .6944 .15137 .71384 .14428 .70475 .13096 Mtetra
.654 .75 .92 r
.01928 .36799 .03116 .37844 .04642 .37295 .03459 .36238 Mtetra
.653 .748 .92 r
.03459 .36238 .04642 .37295 .06178 .3673 .04998 .35678 Mtetra
.655 .751 .92 r
.04998 .35678 .06178 .3673 .07725 .36155 .06549 .35105 Mtetra
.658 .753 .921 r
.06549 .35105 .07725 .36155 .09282 .35572 .08111 .34521 Mtetra
.659 .755 .921 r
.08111 .34521 .09282 .35572 .10847 .3499 .09682 .33929 Mtetra
.658 .754 .921 r
.09682 .33929 .10847 .3499 .1242 .34424 .11263 .33336 Mtetra
.655 .749 .919 r
.11263 .33336 .1242 .34424 .14003 .33858 .12853 .3275 Mtetra
.652 .746 .918 r
.12853 .3275 .14003 .33858 .15596 .33277 .14451 .32173 Mtetra
.652 .748 .92 r
.14451 .32173 .15596 .33277 .17201 .32684 .16059 .3159 Mtetra
.656 .752 .921 r
.16059 .3159 .17201 .32684 .18815 .3209 .17679 .30989 Mtetra
.657 .752 .921 r
.17679 .30989 .18815 .3209 .20441 .31486 .1931 .30382 Mtetra
.656 .753 .921 r
.1931 .30382 .20441 .31486 .22074 .30897 .20951 .29774 Mtetra
.657 .751 .919 r
.20951 .29774 .22074 .30897 .23716 .30325 .22602 .29157 Mtetra
.656 .743 .914 r
.22602 .29157 .23716 .30325 .25366 .29784 .24264 .28541 Mtetra
.653 .729 .905 r
.24264 .28541 .25366 .29784 .27026 .29253 .25936 .27929 Mtetra
.65 .715 .896 r
.25936 .27929 .27026 .29253 .28698 .28712 .27618 .27319 Mtetra
.649 .704 .887 r
.27618 .27319 .28698 .28712 .30383 .28154 .29311 .26707 Mtetra
.648 .696 .881 r
.29311 .26707 .30383 .28154 .3208 .27574 .31015 .26089 Mtetra
.649 .691 .876 r
.31015 .26089 .3208 .27574 .3379 .26969 .32731 .25461 Mtetra
.65 .689 .874 r
.32731 .25461 .3379 .26969 .35512 .26337 .34458 .24822 Mtetra
.651 .69 .873 r
.34458 .24822 .35512 .26337 .37247 .25679 .36197 .2417 Mtetra
.653 .693 .875 r
.36197 .2417 .37247 .25679 .38994 .24996 .37948 .23509 Mtetra
.654 .698 .879 r
.37948 .23509 .38994 .24996 .40752 .24289 .3971 .22841 Mtetra
.655 .706 .885 r
.3971 .22841 .40752 .24289 .42522 .23565 .41484 .22171 Mtetra
.655 .717 .894 r
.41484 .22171 .42522 .23565 .44302 .2283 .43269 .21503 Mtetra
.654 .73 .905 r
.43269 .21503 .44302 .2283 .46094 .22105 .45066 .20838 Mtetra
.654 .743 .915 r
.45066 .20838 .46094 .22105 .47895 .21411 .46874 .20173 Mtetra
.656 .75 .92 r
.46874 .20173 .47895 .21411 .49708 .20734 .48695 .195 Mtetra
.655 .753 .922 r
.48695 .195 .49708 .20734 .51533 .2007 .50528 .18824 Mtetra
.656 .752 .921 r
.50528 .18824 .51533 .2007 .53371 .19396 .52373 .18142 Mtetra
.659 .753 .92 r
.52373 .18142 .53371 .19396 .5522 .1872 .54231 .1744 Mtetra
.659 .75 .917 r
.54231 .1744 .5522 .1872 .57082 .18032 .56101 .16732 Mtetra
.656 .747 .917 r
.56101 .16732 .57082 .18032 .58956 .17326 .57984 .16031 Mtetra
.654 .748 .919 r
.57984 .16031 .58956 .17326 .60843 .1662 .5988 .15338 Mtetra
.653 .752 .922 r
.5988 .15338 .60843 .1662 .62744 .15929 .61789 .14641 Mtetra
.654 .753 .923 r
.61789 .14641 .62744 .15929 .64657 .15238 .63711 .13936 Mtetra
.656 .753 .921 r
.63711 .13936 .64657 .15238 .66584 .14538 .65646 .13218 Mtetra
.658 .752 .919 r
.65646 .13218 .66584 .14538 .68523 .13825 .67594 .12485 Mtetra
.657 .75 .918 r
.67594 .12485 .68523 .13825 .70475 .13096 .69556 .11751 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
[(-2)] .12586 .2075 1 .99877 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.56863 .04703 m
.57247 .05235 L
s
[(2)] .56094 .0364 .72324 1 Mshowa
.125 Mabswid
.18558 .19702 m
.18832 .19985 L
s
.23703 .17687 m
.23971 .17975 L
s
.28951 .15632 m
.29214 .15925 L
s
.39772 .11395 m
.40023 .11699 L
s
.4535 .09211 m
.45595 .0952 L
s
.51046 .06981 m
.51284 .07294 L
s
.08568 .23614 m
.08851 .23887 L
s
.62804 .02377 m
.63027 .02701 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 233.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00o?ooool2o`0006[ooooo003iooooo`?o000000?oooooo`000?ooool0
JOooool00?Oooooo0_l00004ooooo`;o0000JOooool00?Cooooo0ol00006ooooo`03o`000?oooooo
000006Sooooo003;ooooo`Go00008_ooool2o`0000Wooooo00?o0000ooooool00000J?ooool00<_o
oooo00GoV9RHob4Q8Oo^k^koooooodA4A00Oooooo`?o00002oooool01?l0003oooooooooool0001W
ooooo`00c?ooool00onHV9So8B4Qonk^kP0Mooooo`?o00003_ooool01Ol0003ooooooooooooooooo
000006Kooooo003=ooooo`03oiRHV?lQ8B7ok^k^01[ooooo0_l0000Aooooo`05o`000?oooooooooo
ooooool00000I_ooool00<kooooo00?oMgMgofIVI_ooool05_ooool3o`0001?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1Sooooo`00coooool00ol0003oooooooooo`0Cooooo`;o
00000_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0H_ooool00<_ooooo00Go0000okZj^_ooooooV9RHoa0@400Booooo`?o00006Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo06;ooooo003;ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`04?ooool2o`0001cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Qooooo`00
gOooool3o`0001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Qooooo`00fooo
ool2o`00027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Pooooo`00f?ooool3
o`0002?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Oooooo`00eOooool3o`00
02Kooooo00?o0000ooooooooool01?ooool2o`00067ooooo003Cooooo`;o0000:Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo05kooooo003@ooooo`?o000000?oooooo`000?ooool0
:?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05gooooo003>ooooo`;o00001Ooo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0GOoo
ool00<_ooooo0ol0000`ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0G?ooool0
0<Wooooo0_l0000cooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Foooool00<Ko
oooo0ol0000eooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Foooool00<Cooooo
0_l0000hooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0F_ooool00<7ooooo0ol0
000jooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03_ooool5o`0004Kooooo002n
ooooo`?o0000?Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00kooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A016ooooo`00_?ooool2o`0000?ooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo1_l00003ooooo`03oiRHV?lQ8B7o
k^k^04Oooooo002iooooo`?o0000@oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00kooooo00?oV9RHob4Q8Oo^k^h0A_ooool00;Oooooo0_l00016ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03oooool00omgMgOoIVIVooooo`15ooooo`00]?ooool3o`0004Sooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Cooooo
002booooo`;o0000Boooool00ol0003oooooooooo`0=ooooo`;o00003?ooool01Ol0003o^[Zjoooo
oonHV9So410@04Kooooo002_ooooo`?o0000COooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c016ooooo`00[Oooool2o`00053ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`1Dooooo`00Z_ooool4o`00057ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1Dooooo`00Z?ooool2o`0000Cooooo00?o0000oooo
ooooool0C_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05?ooooo001nooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h08_ooool3o`0005Oooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`1Booooo`00O_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01oooooo0ol0001Joooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool0D_ooool007kooooo00Go410@oooooooo
oooooooooa0@400Mooooo`;o0000GOooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
057ooooo001nooooo`05o`000?ooooooooooooooool000006_ooool3o`0005oooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`1@ooooo`00O_ooool01Ol0003ooooooooooooooooo0000
01Sooooo0_l0001Rooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0D?ooool007ko
oooo00Go410@oooooooooooooooooa0@400Eooooo`?o0000I?ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo04oooooo001nooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool2o`00
00?ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
04kooooo001nooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04?ooool3o`0006Sooooo00?oZ;o[o`00
0?ooool05_ooool00ol0003oooooooooo`1>ooooo`00TOooool2o`0006Sooooo1?nX_n/00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo04gooooo002>ooooo`?o0000J?ooool7ojRoj`03o`00
0?oooooooooo01Cooooo0ol0001>ooooo`00Roooool3o`0006Wooooo0_nX`>/7ojRoj`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool0C?ooool008Wooooo0_l0001Yooooo`KoZ<3[1_nX_n/0
0ol0003oZ;o[ooooo`0Gooooo`03o`000?oooooooooo04_ooooo0026ooooo`?o0000J?ooool00onW
`>_oZ<3[ojS0j`07ojS0j`GoZ;o[00?o0000ojS0joooool06?ooool00ol0003oooooooooo`1:oooo
o`00Q?ooool2o`0000;ooooo00?o0000ooooooooool0Hoooool5ojO0j`WoZ<3[0_nX_n/2ojS0j`03
o`000?nX`>_oZ<3[01Sooooo00?o0000ooooooooool0B_ooool0087ooooo0ol00005ooooo`03o`00
0?oooooooooo063ooooo2?nW`>/7ojS0j`03ojO0jonX`>_oZ<3[00;oZ<3[00Co0000ojS0jonX`>_o
Z<3[6?ooool00ol0003oooooooooo`19ooooo`00Ooooool2o`0006Wooooo00?oYl3/ojO0jonW`>/0
1onW`>/4ojS0j`GoYl3[0onX`>/00ol0003oZ<3[ojS0j`02ojS0jaSooooo00?o0000ooooooooool0
B?ooool007cooooo0ol0001Xooooo`GoYl3/2OnW`>/00onX`>_oYl3[ojO0j`06ojO0j`;oZ<3[00Go
0000ojS0jonX`>_oZ<3[ojO0j`0Hooooo`03o`000?oooooooooo04Sooooo001jooooo`;o0000Iooo
ool:ojO0k0KoYl3[0_nW`>`9ojO0j`;oZ<3[00?o0000ojS0jonW`>/00onW`>/Hooooo`03o`000?oo
oooooooo04Oooooo001gooooo`?o0000I_ooool>ojO0k0;oYl3[1_nW`>`9ojO0j`03ojS0jol0003o
Yl3[00GoYl3[6?ooool00ol0003oooooooooo`16ooooo`00M?ooool3o`0006Kooooo00?oYko[ojO0
k?nW`>`05onW`>`6ojO0j`;oYl3/00?oYl3[o`000?nW`>/01OnW`>/Hooooo`03o`000?oooooooooo
04Kooooo001booooo`;o00000_ooool00ol0003oooooooooo`1Rooooo`CoYko[6OnW`>`2ojO0j`Ko
Yl3/00?o0000ojO0jonW`>/01OnW`>/Hooooo`03o`000?oooooooooo04Gooooo001_ooooo`?o0000
Ioooool7ojNoj`OoYl3/00?oYko[ojO0k?nW`>`05_nW`>`00ol0003oYl3[ojO0j`04ojO0j`03ojO0
k?oooooooooo01Kooooo00?o0000ooooooooool0AOooool006gooooo0_l0001Wooooo`;oYkoZ2?nW
_n/4ojO0k0GoYko[5onW`>`01?l0003oYl3/ojO0jonW`>/5ojO0k1Oooooo0_l00016ooooo`00J_oo
ool3o`0006Kooooo1_nW_nX8ojNoj`03ojO0k?nW_n_oYko[00KoYko[1onW`>`00onW_n_oYl3/ojO0
k00<ojO0k003o`000?nW`>coYl3/00OoYl3/6?ooool00ol0003oooooooooo`13ooooo`00J?ooool2
o`0006Kooooo0_nX_nX8ojNojPKoYko[0_nX_nX8ojNoj`CoYl3/1OnW_n/=ojO0k003o`000?nW`>co
Yl3/00SoYl3/5oooool00ol0003oooooooooo`13ooooo`00IOooool3o`0006Gooooo1_nX_nX8ojNo
jP;oYko[1_nX_nX8ojNoj`03ojO0k?nW_n_oYko[00KoYko[1_nW`>`00onW_n_oYl3/ojO0k003ojO0
k003o`000?nW`>coYl3/00SoYl3/6?ooool00ol0003oooooooooo`12ooooo`00Hoooool2o`0006Go
oooo00?oZ<3[ojRoj_nX_nX01onX_nX6ojNojP03ojS0jonX_n[oZ;oZ00OoZ;oZ1_nW_n/00onX_n[o
Yko[ojNoj`07ojNoj`CoYl3/1?nW_n/5ojO0k003o`000?nW`>coYl3/00SoYl3/6?ooool00ol0003o
ooooooooo`11ooooo`00H?ooool3o`000003ooooool0003ooooo06;ooooo1?nX`>/9ojRojP;oYkoZ
1OnX`>/9ojRojP;oYko[1OnX_nX9ojNoj`03ojO0k?nW_n_oYko[00GoYko[1?nW`>`01?l0003oYl3/
ojO0k?nW_n/8ojO0k1Oooooo00?o0000ooooooooool0@Oooool003Kooooo1Ol0000Sooooo`;o0000
I_ooool7ojS0j`OoZ;oZ2OnX`>/6ojRojP;oZ<7[2?nX_nX6ojNoj`;oZ;oZ2?nW_n/4ojO0k003o`00
0?nW_n_oYko[00;oYko[2?nW`>`Gooooo`03o`000?oooooooooo043ooooo000fooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@08?ooool3o`0006Gooooo0_nW`>/8ojS0j`CoZ;oZ3OnX`>/2ojRojPKoZ<7[
2?nX_nX2ojNoj`KoZ;oZ2?nW_n/01?nW`>coYko[ojNojol00005ojNoj`KoYl3/00?oYko[oooooooo
ool05_ooool00ol0003oooooooooo`0oooooo`00;_ooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h0
7_ooool3o`0006Gooooo1_nW`>/8ojS0j`03ojRoj_nX`>_oZ<3[00coZ<3[00?oYl3[ojS1jonX`N/0
1onX`N/6ojRojP03ojS1jonX_n[oZ;oZ00OoZ;oZ1_nW_n/01OnX_n[oYko[ojNojonW_n_o000000Go
Yko[1?nW`>`4ojNojaOooooo00?o0000ooooooooool0?oooool003Sooooo00?oV9RHob4Q8Oo^k^h0
6oooool2o`0006Gooooo0_nW`>`8ojO0j`KoZ<3[0_nW`>`<ojS0j`CoYl3[2OnX`N/2ojRojPGoZ<7[
2OnX_nX2ojNoj`GoZ;oZ0_nW_n/00ol0003oYko[ojNoj`04ojNoj`03ojO0k?nW_n_oYko[00GoYko[
5oooool00ol0003oooooooooo`0nooooo`00>Oooool00omgMgOoIVIVooooo`0Gooooo`?o0000I?oo
ool6ojO0k0SoYl3[0_nX`>/6ojO0k0WoZ<3[1onW`>/7ojS1j`03ojO0k?nX`N_oZ<7[00KoZ<7[1_nX
_nX2ojS1j`SoZ;oZ00?oYko[o`000?nW_n/00onW_n/2ojRojPSoYko[6?ooool00ol0003ooooooooo
o`0mooooo`00>_ooool00ol0003oooooooooo`0Dooooo`;o0000I?ooool00onW_n_oYl3/ojO0k007
ojO0k0KoYl3[00?oYko[ojO0k?nW`>`01onW`>`6ojS0j`[oYl3[1?nX`N/4ojO0k0SoZ<7[0_nX_nX6
ojS1j`SoZ;oZ00?o0000ojNojonX_nX01OnX_nX8ojNojaOooooo00?o0000ooooooooool0?Oooool0
03Kooooo00Go0000okZj^_ooooooV9RHoa0@400Cooooo`?o00000_ooool00ol0003oooooooooo`1O
ooooo`CoYko[2OnW`>`2ojO0j`GoYko[2OnW`>`2ojS0j`koYl3[00?oZ<7[ojO0k?nW`>`01OnW`>`6
ojS1j`03ojO0k?nX`N_oZ<7[00OoZ<7[1_nX_nX00onX`N_o0000ojRojP07ojRojPKoYko[00?oZ;oZ
ooooooooool05_ooool00ol0003oooooooooo`0looooo`00=_ooool01OnHV9So410@o`000?lQ8B7o
c<c<017ooooo0_l0001Uooooo`OoYko[1onW`>`00onW_>WoYko[ojNoj`06ojNoj`KoYl3/0_nW_NT>
ojO0j`;oYko[2?nW`>`4ojS1j`CoYl3/2OnX`N/2ojRojPCoZ<7[00?o0000ojRoj_nX_nX01onX_nX2
ojNoj`GoZ;oZ5_ooool3o`0003gooooo0019ooooo`?o0000IOooool00onW_^[oYko[ojNoj`07ojNo
j`CoYl3/1?nW_>T8ojNoj`;oYl3/1_nW_NT:ojO0j`KoYko[2?nW`>`00onX`N_oYl3/ojO0k005ojO0
k0OoZ<7[00?oYl3/ojS1jonX`N/01?nX`N/00ol0003oZ<7[ojRojP05ojRojP;oZL7[2?nX_nXGoooo
o`03o`000?oooooooooo03_ooooo0017ooooo`;o0000IOooool5ojNnjPWoYko[00?oYl3/ojNljOnW
_>T01OnW_>T6ojNoj`03ojRgi?nW_NWoYkgY00OoYkgY1_nW`>/00onW^^OoYko[ojNoj`07ojNoj`Ko
Yl3/00?oYko[ojO0k?nW`>`01_nW`>`4ojS1j`GoYl3/1OnX`N/00ol0003oZ<7[ojS1j`02ojRojPKo
ZL7[2?nX_nXGooooo`03o`000?oooooooooo03[ooooo0014ooooo`?o0000I?ooool00onW^^OoYkkZ
ojNnjP06ojNnjPKoYko[0_nW]n@8ojNlj@CoYko[1?nX]n@9ojNmj@;oYl3[1OnW^^L9ojNoj`;oYl3/
1OnW_n/8ojO0k003ojS1jonW`>coYl3/00KoYl3/1?nX`N/00ol0003oZ<7[ojO0j`09ojW1j`KoZ;oZ
00?oZL3[ooooooooool05_ooool00ol0003oooooooooo`0iooooo`00@Oooool3o`0006Cooooo1OnW
^^L8ojNnjP;oYko[1_nW]n@8ojNlj@03ojNojonX]nCoZ;OT00GoZ;OT1onW_NT00onY]>7oYk[WojNj
i`06ojNji`KoYko[0_nX^NH8ojNoj`KoYl3/0_nW_^/9ojO0k0;oZ<7[00?oYl3[o`000?nW`>/00_nW
`>/9ojW1j`;oZ;oZ1OnY`>/Gooooo`03o`000?oooooooooo03Wooooo000oooooo`?o0000Hoooool0
0onW]nCoYk[WojNji`06ojNji`KoYkkZ00?oZ;?PojNgi?nW]n@01onW]n@6ojNlj@;oZK;O2?nX]n@4
ojNmj@CoZKCQ2?nW^^L2ojNoj`KoZ;WV2?nW_n/2ojO0k0KoYkk[1onW`>`01OnW_n_oYl3[ojO0jonW
`>_o000000CoYl3[1_nY`N/2ojO0j`SoZL3[5oooool00ol0003oooooooooo`0hooooo`00??ooool3
o`0000?ooooo00?o0000ooooooooool0G_ooool4ojNgi0SoYk[W0_nW_^X5ojRch0WoYkOT0_nW_>T6
ojVbg`SoZ;OT00?oYkgYojVdhOnY]>401OnY]>46ojNji`03oj^dgonX^NKoZ;WV00OoZ;WV1_nW_n/0
0onX^NGoYkk[ojNnj`07ojNnj`CoYl3/1?nW_n/2ojO0j`03o`000?nW`>_oYl3[00?oYl3[0_nY`N/6
ojO0j`SoZL3[5_ooool00ol0003oooooooooo`07ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0;?oo
ool003[ooooo0_l0001Uooooo`OoYkOT1_nW^^L00onY/MgoZ;?PojRch006ojRch0OoYkOT00?o[;7L
ojVbgonY/]l01onY/]l6ojRgi003ojfbg?nY]>7oZKCQ00KoZKCQ1?nW^^L4oj^dg`WoZ;WV0_nW_n/5
ojRii@WoYkk[00?oYl3/ojNojonW_n/01OnW_n/00onW`>_o0000ojO0j`0=ojO0j`KoZL3[00?oZ<7[
ooooooooool05Oooool00ol0003oooooooooo`06ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0;?oo
ool003Oooooo0ol0001Uooooo`03ojNdh_nW]nCoYkOT00KoYkOT1?nW^^L4ojVag@SoZ;?P1?nW]n@4
ojbag0WoZK;O0_nX]n@5ojfbg0SoZKCQ00?oYk[Woj^dgon[]=l01On[]=l7ojRiiP03ojfeg_nX^NGo
Z;WU00KoZ;WU1_nW_^/2ojRiiPSoYko[0_nW`>/00ol0003oYl3[ojO0j`0<ojO0j`;oZL3[1OnX`N/G
ooooo`03o`000?oooooooooo00Gooooo00Go410@oooooooooooooooooa0@400/ooooo`00=Oooool2
o`0006Gooooo1OnW]>88ojNgi003ojNjionY/MgoZK7M00GoZK7M2?nX/n000onW]nCo[;7Lojbag005
ojbag0OoZK;O00?o[ZoIojfbg?n]/]`01_n]/]`6ojVdh@03ojnbf_n[]=ooZkCO00OoZkCO1?nX^NH4
ojfegPSoZ;WU0_nW_^/6ojRiiPSoYko[00?oYl3[o`000?nW`>/02onW`>/2ojO0k0SoZ<7[5_ooool0
0ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool00000;?ooool003;ooooo0ol0001T
ooooo`03ojNbhOnW]>;oYkCR00KoYkCR1_nW]n@00onY[m_oZK7MojVag@07ojVag@KoZ;?P00?o[:kI
ojbag?n//M`01_n//M`4ojVbg`Go[ZoI1on]/]`4ojVdh@Co[k;J2On[]=l00onX^NKo[KGNojfegP05
ojfegPKoZ;WU00?o[[KOojRii_nX^NH01onX^NH6ojNoj`03ojRkionW`>_o000000WoYl3[1_nW`>`8
ojS1jaKooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000002cooooo000`
ooooo`;o0000I?ooool5ojNbh@SoYkCR0_nW]n@5ojV_f`WoZK7M0_nX/n05ojb^f@So[;7L00?oZK;O
ojj_fOn^[mT01On^[mT8ojfbg003ojVdhOn_/][o[k;J00Go[k;J1on[]=l00ona/m[o[KGNojfegP06
ojfegPCoZ;WU1?n^]]l9ojRiiP;oYko[1OnX^nL00ol0003oYl3[ojO0j`04ojO0j`03ojNmjOnW`>co
Yl3/00KoYl3/1_nX`N/2ojO0jaOooooo00?o0000ooooooooool00oooool01Ol@413ooooooooooooo
oooo410@02cooooo000]ooooo`?o000000?oooooo`000?ooool0H?ooool00onW/MooYk;QojNbh@06
ojNbh@KoYkCR00?oZJgJojV_fonY[m/01_nY[m/7ojVag@03oj^]f?n/[]Wo[:kI00Ko[:kI1_n//M`0
0on^[mSo[ZoIojj_f@07ojj_f@Ko[K;L00?o/;3Hojnbf_n_/]X01_n_/]X4oj^dg`Go/K?J2?n]]Mh0
0onX^NGo[[KOojjfg`05ojjfg`OoZ;WV00?o[[OPojRkionX^nL01OnX^nL00ol0003oYl3[ojO0j`02
ojO0j`CoYkgY2?nW`>`2ojS1j`KoYl3[5_ooool2o`0000Cooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0/ooooo`00:_ooool3o`0006?ooooo1OnW/Ml7ojNbh@CoYkCR1?nY[MX8ojV_f`CoZK7M1?n[[MP7
ojb^f@Co[;7L1?n^[mP8ojj_f@Co[K;L1?n`/=P8ojnbfP03oj^dgona/m[o/K?J00Ko/K?J1_n]]Mh0
0onb]=[o[[KOojjfg`06ojjfg`CoZ;WV1On^]n06ojRki`03o`000?nX^nOoYl3[00OoYkgY1_nW`>`0
0onW_n_oYl3[ojO0j`07ojO0ja?ooooo0_l000000ooooooo0000ooooo`03ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h0;?ooool002Sooooo0_l0001Sooooo`03ojJ`gonW/MooYk7O00KoYk7O1onW/^40
0onW]>;oZJgJojV]fP05ojV]fPSoZJoK00?oZK7Moj^]f?n[[MP01?n[[MP8ojb^f@03ojbag?n^[mSo
[ZoH00Go[ZoH2?n^[mT00on]/]co/;3Hok2`f005ok2`f0Ko[k;J00?o/kCIok6cf_na/mX01ona/mX4
ojfegPCo/[CJ2?n^]]l00onX^NKo[[OPojjgh006ojjgh0GoZ;_W00?o0000ojfhh_nW_NT01onW_NT4
ojO0k0CoYko[2OnW`>/Fooooo`03o`000?oooooooooo03;ooooo000Uooooo`?o0000Hoooool4ojJ`
g`OoYk7O1_nW/^400onX[=[oZJgJojV]fP06ojV]fPOoZJoK00?oZjgIoj^]f?n[[MP01_n[[MP6ojb^
f@03ok2cfon^[mSo[ZoH00Ko[ZoH1on^[mT00onb]M_o/;3Hok2`f006ok2`f0Co[k;J1?nc]=T9ok6c
fP03ojfeg_nb]=[o/[CJ00Go/[CJ1_n^]]l00onc]M[o[[OPojjgh008ojjgh0;oZ;_W00?o[KSRo`00
0?l000000_n]^>88ojNmj@03ojO0k?nW_n_oYko[00GoYko[1_nW`>/2ojO0k1Kooooo00?o0000oooo
ooooool0<_ooool002?ooooo0_l0001Tooooo`OoY[3O1onW/Ml2ojNbh@GoZ:cJ2?nY[MX4ojV_f`Co
ZjgI1on[[MP4ojb^f@Co/;?K2?n^[mP4ojj_f@Co/[GK2?n`/=P00on_/][o/kCIok>df@05ok>df@Oo
/K?J00?o][OJok:df_nb]=X01_nb]=X4ojjfg`Co/kGJ2?n^]n001_nd]mco0000o`000?l0003o[KSR
o`0000?o[KSR1_nW_NT00onZ^^GoYko[ojNoj`07ojNoj`;oYl3[1_nW`>`Fooooo`03o`000?oooooo
oooo037ooooo000Pooooo`?o0000I?ooool9ojJ`g`KoYk7O00?oYj_IojR/f_nX[=X01_nX[=X8ojV]
fP03ojV_fon[[MWoZjgI00CoZjgI2?n[[MP00on/[]Wo/;?Kok2cf`05ok2cf`So[ZoH00?o[ZoIok:e
fonb]M/01Onb]M/6ok2`f003okFlgonc]=Wo/kCI00Oo/kCI1?na/mX4okJgfPSo/[CJ00?o[[KOok>e
f_nc]MX01Onc]MX4ojjgh005okBgg?l0003o0000o`000?nd]m`01?n]^>801?l0003o[KSRojfhh_n]
^>82ojNmj@GoZ[[U1onW_n/00onX_NWoYl3/ojO0k006ojO0k1Oooooo00?o0000ooooooooool0<?oo
ool001oooooo0_l0001Sooooo`goY[3O0_nW/Ml5ojN[f@SoZ:cJ1_nY[MX00on[[m_oZjgIoj^]f@06
oj^]f@KoZjgH00?o[kWQok2cfon`/m/01_n`/m/7ojj_f003ok:nhonb]M_o/[GK00Ko/[GK1?n`/=P4
okFlg`Wo/kCI00?o/K?JokJgf_nf]mX01Onf]mX6ok:dfP03okNhf_nc]M[o/kGJ00Oo/kGJ00Co[[OP
o`000?l0003o00001Ond]m`4ojfhhP03o`000?n]^>;o/k[N00SoZ[[U1?nW_n/4ojRmj@SoYl3/5_oo
ool00ol0003oooooooooo`0`ooooo`007oooool00ol0003oooooo`00001Oooooo`03ojJ`h?nV/=oo
Y[3O00coY[3O00?oYZ[JojN[fOnWZmT01_nWZmT8ojR/fP;oZJgJ1On[[m/7oj^]f@CoZjgH1?n_^N48
ok2cf`Co[ZoH1?nb_^<8ok:ef`03ok2`f?ne_=oo]KcO00Go]KcO1onc]=T00onf`^?o][OJokJgfP06
okJgfPCo/[CJ1?ng^=X6ok>efP?o00002?nd]m`4ojfhhP04ok>jg_l0003o/k[Nok>jgPSoZ[[U00?o
Yko[ojRmjOnX_NT01OnX_NT6ojO0k003ojNojooooooooooo01Gooooo00?o0000ooooooooool0;ooo
ool000cooooo1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool01?l0003ooooooooo
ool0001Kooooo`GoY[3P2onV/=l4ojJZfPOoYj_I1onX[=X00onZ/]goZjoKoj^_f`06oj^_f`OoZjgI
00?oZjgHojnihOn_^N401On_^N48ok2cf`03ojj_f?nb_^?o/[kS00Go/[kS1_nb]M/00onab>_o]KcO
okFlg`06okFlg`Co/kCI1Onf`^<8okJgfP03ok:df_ng^=[o]kSJ00Go]kSJ0_nc]MX3o`0000?o^;WJ
2Ond]m`01On]^>;o/k[Nok>jg_nc^]ko000000?o/k[N1_nZ^^D00on`^n7oZ;gYojRmj@07ojRmj@;o
Yl3/1OnW_n/Gooooo`03o`000?oooooooooo02kooooo000<ooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo0_l00002ooooo`03o`000?oooooooooo
05Gooooo00?oYK;QojJ`h?nV/>001_nV/>08ojJ`g`OoYZ[J1onWZmT4ojR/fPCoZ[;M1on[[m/6oj^]
f@;o[/7W2?n_^N46ok2cf`03ojo8kOnb_^?o/[kS00Ko/[kS1?nb]M/4ok78j`So]KcO00?o/kCIokK2
honf`^<01_nf`^<6okJgfP03okO5i?ng^=[o]kSJ00Go]kSJ0ol000000onc]M[o^;WJokRifP04okRi
fPOo];OL00?o^;WJok>jg_nc^]h00onc^]h01?l0003o/k[Nok>jg_nc^]h2ojZji@Go/;_Q1onX_NT0
0on[^nGoYko[ojNoj`06ojNojaKooooo00?o0000ooooooooool0;_ooool000Cooooo1_l00003oooo
o`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4005ooooo`;o00001?ooool0
0ol0003oooooooooo`1Aooooo`GoYK;Q2?nV/>05ojJ`g`03ojFYf_nVZ][oYZ[J00KoYZ[J2?nWZmT0
0onX[=[oZ[;MojZbg@04ojZbg@SoZjoK0_n[[MT6ojk1i`So[kWQ0_n`/m/5ojo8k@So/[kS00?o/[GK
ok78jonab>/01Onab>/6okFlg`03ojc<l?nf`^?o]/;S00Oo]/;S1?nf]mX4okO5i0?o]kSJ0ol00002
okNhfP03ok>ef_nh^M[o^;WJ00Go^;WJ1?nd]m`5okRifPGo/k[N00?o0000ok>jg_ng^M/02?n`^n44
ojRmj@CoZk_U2?nW_n/Fooooo`03o`000?oooooooooo02gooooo000>ooooo`03oiRHV?lQ8B7ok^k^
00?ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0COooool00onV]>?oYK;QojFbh@06ojFbh@SoY[3P00?oY[3OojFYf_nUZMX00onUZMX8
ojJZfPKoYj_I00?oZK?PojZbgOnZ/]d01_nZ/]d6oj^_f`;o[<O]2?n^`NL6ojnih@03ojK@m_n_b>go
[lS]00Ko[lS]1_nb_^<00onUdOOo/LS[ok78j`06ok78j`Co]KcO1?n/c?09okK2h`03okJgf_ngaNCo
]lGT00Go]lGT0_l00004okNhfP03okS5i?nh^M[o^;WJ00Oo^;WJ00?o];OLokRif_nh^MX01_nh^MX4
ok>jgP04o`000?ng^M_o]kWKokNif`So/;_Q00?oZ;gYoj^kiOn[^nD01On[^nD6ojNoj`03ojRnj_oo
oooooooo01Gooooo00?o0000ooooooooool0;?ooool000oooooo00?oMgMgofIVI_ooool00_ooool0
1Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`19ooooo`GoY[CS2?nU/^46ojJ`h003ojBYf_nUZM[oYJWJ00GoYJWJ2?nVZ]X2ojN[f@GoZK?P1onZ
/]d4oj^_f`Go[<O]2?n^`NL2ojnih@GoY]3f2?n_b>d2ok:nh`GoYM7g2?nab>/00one_=oo[<c`ojc<
l005ojc<l0Oo]/;S00?oZ<kcokO5i?ngaN@00ongaN@3o`0000Co]kSJ1?nhaN@7okRifP03ok[3hOnh
^M[o^;WJ00Oo^;WJ0onc^]h2okNif`04o`000?ng^M_o]kWKokNif`Ko/;_Q00?o][cNoj^kiOn[^nD0
1on[^nD2ojNoj`GoZ;kZ5Oooool2o`0002kooooo000@ooooo`05o`000?ooooooooooooooool@4100
0oooool00ol@413oooooooooo`03ooooo`;o00001oooool00ol0003oooooooooo`16ooooo`03ojJg
iOnV]>?oY[CS00GoY[CS2?nU/^42ojJ`h0GoY:WJ1onUZMX6ojJZfP03ojRdh_nY/n3oZK?P00KoZK?P
1onZ/]d00on[[m_o[<O]ojc7k@06ojc7k@Ko[/7W0_nNfO`7ojK@mPKo[lS]0_nEfoh7ojGAm`Ko/LS[
0onIeod7ojc<l0Co]/;S1?nXc_<01?ngaNCo0000o`000?l00004okO5i003okNhf_nhaNCo^<GT00Go
^<GT1Onh^MX3ok[3h@Wo^;WJ00?o/k[NokNifong^M/00_ng^M/00ol0003o]kWKokNif`04ok2kh@Co
][cN1on[^nD00ona_N?oZ;kZojRnjP06ojRnjQKooooo00?o0000ooooooooool0:oooool000cooooo
00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo04;ooooo1OnV]nD7ojJdh`KoYK;Q00?oXjWKojBY
f_nTZMX01_nTZMX7ojFYfP;oYZ[J1OnX]>87ojVch0KoZ[;M0onXb_88ojc7k@;o[/7W1_nNfO`7ojK@
mP;o[lS]1_nEfoh7ojGAm`;o/LS[1onIeod7ojc<l003okK2honXc_?oZ<kc00;oZ<kc0ol00006okO5
i003ojS=lonhaNCo^<GT00Ko^<GT0onh^MX6ok[3h@Oo^;WJ00?o^koMokNifong^M/01?ng^M/01?l0
003o]kWKokNifon`^n47okJlgPCoZk_U1?na_N<8ojRnjQGooooo00?o0000ooooooooool0:oooool0
00cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03kooooo00?oYk[WojJgiOnV]nD01_nV
]nD7ojJdh`;oYK;Q1OnSZM/7ojBYfPKoYJWJ00?oY[CRojRdh_nX]>801_nX]>87ojVch0;oZ[;M1onX
b_86ojc7k@;oUmkn2?nNfO`3ojK@mPGoPmcm1onEfoh3ojGAm`GoO]On2?nIeod3ojc<l0CoS]Oo00Co
Z<kco`000?l0003o00001?nXc_<2okO5i0GoZ<gc2?nhaN@00onh^M[o^/?Qok[3h@05ok[3h@Co^;WJ
1Onk_md5okNif`03o`000?ng^M_o^kgK00Wo][cN00?oZk_Uok6mhona_N<01Ona_N<6ojRnjP03ojZm
j?oooooooooo01Cooooo00?o0000ooooooooool0:_ooool001kooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0jooooo`GoYk[W1onV]nD6ojJdh`03oj:Zg?nSZM_oXjWK00KoXjWK1onT
ZMX2ojFYfPGoY[CR1onX]>86ojVch0?oY/kd2?nXb_82ojc7k@KoUmkn1_nNfO`3ogSHo0OoPmcm0onE
foh5ofg@o@OoO]On1?nIeod5of[=o@?oS]Oo0ol00006ojS>l`;oR=Co1onXcO<6okS5i003oj_;l?nj
`n7o^/?Q00Oo^/?Q00?o^;WJok^ogOnk_md01Onk_md4okNif`;o^kgK00?o0000ok^mfonk_M/01onf
_=h00oni_Mgo/KgSok6mh`07ok6mh`;oZ;kZ1OnZ_NPFooooo`03o`000?oooooooooo02Wooooo000M
ooooo`?o00002oooool00ol0003oooooooooo`0fooooo`;oYkkY1onW^^L7ojJgi@;oY[CS1OnRZ]`7
oj>Yf`KoY:WJ00?oYK;RojJdh_nV]>801_nV]>87ojRdhP;oZK?P1onVc_@6ojS:lP?oTN7m1onGg_h2
oikIo0OoN=Sl0on3g?d6ogO@o`KoKM3m0omneoh5of_8oPOoJ/gm0ol00004ohkGo`;oZ<kc1_n8e?l7
ojS=l`;o^<GT1On[bo07ok[3h@03ok;9jonk_mgo^koM00Oo^koM00?o]kWKok^mfonk_M/00onk_M/0
0ol0003o^kgKokJlgP03okJlgPGo^KgM1ona_N<00onf_n7oZ[gXojZmj005ojZmj1Kooooo00?o0000
ooooooooool0:Oooool001gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0boooo
o`KoYkkY1onW^^L5ojJgi@03oj6/g_nRZ]coXZ[L00KoXZ[L1onSZM/2ojBYfPGoYK;R1onV]>86ojRd
hP?oY]3f2?nVc_@2ojS:lPOoTN7m0onGg_h6ogkJo@?oN=Sl1On6d?l6ogO@o`?oT/Ki1omnbOl7of_8
oP;oJ/gm0ol00003ofc1oPKoH/Cm1on8e?l3ojS=l`CoR];o1on[bo04ok[3h@Co//W[1onk_md00oni
anGo^kgKok^mf`05ok^mf`03o`000?nk_M_o][cN00Oo^KgM1?na_N<5okJoh@OoZ[gX5_ooool00ol0
003oooooooooo`0Xooooo`007Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02oo
oooo00?oZ<3[ojNnjOnW_^T01_nW_^T7ojNji`03ojJgiOnQ[=koXJcN00?oXJcN2?nRZ]`5oj>Yf`03
oj>_h?nU/^;oYK;R00KoYK;R1onV]>82ojRdhPOoY]3f1_nVc_@3ohoSo0KoTN7m1?n7foh3ogkJo@Go
U=3m2?n6d?l00omgd?ooT/Kioi;6n@05oi;6n@KoO/Wo0_nH^o04ohO3n`?o00001om/`Oh6of;4o@?o
R=Co1?mO_od7oh[Bo`OoZl_`00?o^/?Qok;9jonbbN/01OnbbN/5ok^og@?o^LOU1_nk_M/00ol0003o
_L;NokVmg@08okVmg@03ok6mhonf_n7o][oQ00Go][oQ1_nZ_NP00on]_^Koooooooooo`0Eooooo`03
o`000?oooooooooo02Oooooo000Mooooo`;o00003oooool00ol0003oooooooooo`0[ooooo`GoZ<3[
2?nW_^T3ojNji`?oXJkP1onQ[=h8oj:Zg003oj>YfonS[n3oXjoP00?oXjoP2?nU/^85ojJdhP_oY]3f
0_nVc_@7ohoSo0;oTN7m1_n7foh3oic<n0SoU=3m0on6d?l4oibnl0SoT/Ki0_mnbOl6oiRkl003ohO3
nol0003o000000CoQl?k0om/`Oh5ohVnn0KoJkgm1_mO_od7oh[Bo`?oZl_`1?nCco`7ok;9j`?o^koM
1_nianD5ok^mf`03okg2g_l0003o_L;N00Oo^KgM00?o_<3MokJohOnf_n401onf_n42ojZmj0Go[KkV
5_ooool00ol0003oooooooooo`0Wooooo`007Oooool00ol0003oooooooooo`0?ooooo`;o0000:?oo
ool2ojO0j`OoZ<3[1_nW_^T00onR/N;oXJkPoj6^h005oj6^h0OoXJcN1_nRZ]`00onQZmkoXjoPoj>_
h005oj>_h0SoYK;R00?oY[CRojK@m_nVd?H02onVd?H4oi3To0?oSn?l1_n@gOh2ohOKoPOoW<ch1_nD
d?d00onR^NWoW;k`oibnl006oibnl0KoT/Ki0_nS]nL5oiRkl0?o00000on7`o/4oibgj`SoRKkh1_m[
_Od6oenoo@?oR];o1?mR__d7oi??o0Oo//W[00?o^koMokW7iOnianD01OnianD3ok^mf`Co_L;N00?o
0000okg2g_ni_Md01?ni_Md3okc0g@Oo][oQ00?o^L3Oojfni_n]_^H01_n]_^HFooooo`03o`000?oo
oooooooo02Kooooo000Mooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool08_ooool6
ojO0j`OoZ<3[0_nW_^T5oj:ahPOoXJkP1onQ[=h2oj:Zg0GoXJ_N1onS[n06ojFbhP;oY/kd2_nVd?H6
oi3To0?oV=kn1on@gOh2oj79m0SoW<ch0_nDd?d5oj:ij@SoW;k`0_nBa_T6oj>gi`04oiRkl?l0003o
0000o`0000;oV;_`00?oZKOSoibgjonL]n/01_nL]n/6ohVnn003oijgjOn7^oOoQk_g00KoQk_g1_mW
^?`6of:no@OoTlol0onbbN/3oio;mPWo^LOU00?o^kgKokg2g_nm`]h01?nm`]h01?l0003o^KgMokVm
gOni_Md6okc0g@Go][oQ0oni`=l8ojfniQKooooo00?o0000ooooooooool09Oooool001gooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0Nooooo`;oZ<3[2?nW`>/5ojS0j`03ojFfiOnR
/N;oX[7R00KoX[7R1_nQ[^06oj6/gP03oinXgOnQZmkoXJ_N00KoXJ_N1onS[n02ojFbhPKoY/kd1_nV
d?H4oiKVo0;oT>Cl2?nHg_h2oi3MoPKoXLWd1_nLc?P00onW]nGoX[WYoj:ij@06oj:ij@KoW;k`00?o
ZKOSoj>gionS]nL01?nS]nL3o`0000;oV;_`1OnY]n<8oibgj`;oRKkh1OnN]nT8ohNkm`KoIkSl1_mR
__d3oi??o0?oL<;n1onOboH7okW7i@03ojk8kOnm`]ko_L;N00Go_L;N00?o0000okg2g_ni_Md01onl
`=d3okJoh@Ko^L3O1_n]_^H00ona`>Goooooooooo`0Dooooo`;o00009_ooool001cooooo0ol0000D
ooooo`03o`000?oooooooooo01_ooooo1OnX`>/8ojO0j`03ojS0jonU]^GoYKKU00?oYKKU2?nR/N86
oj6^h0;oXJcN1OnOZ=d7oj6[gPKoXjoP0_nWb_88ojK>m0;oY]3f1onFi_`3oikQo@KoV=kn0_nUb?88
oj79m0;oW<ch1OnW]nD8oj:ij@;oW;k`1OnY]n<2oj>gi`?o00000_nS]nL00on]^>;oZKOSojVgh`06
ojVgh`KoW;O[00?o[;WSoijgjOnN]nT01_nN]nT6ohNkm`;oW;O[1on1^OP6oencn`GoL<;n1onOboH4
okW7i@Co[/S]1onm`]h00ol0003o_<3Mokc0g@07okc0g@03okJohOni`=oo^L3O00Go^L3O1?n]_^H4
ok70iACooooo00?o0000ooooool000009_ooool001cooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`0Iooooo`OoZ<3[1_nW`>/00onV_>WoYKKUojFfi@05ojFfi@SoX[7R0onQ[^02oijW
g@SoWjSM1onQZmh2oj>_h0KoYl[b1_nVc_@4oi_Wo0?oU^Kl1onNhOd2oiSNoPKoYLSb1_nQbO@00onW
]^?oYkOUojNgi@06ojNgi@KoX[WY00?oZ[KRojVghonY]n<01?nY]n<3o`0000?oXkOW1?n]^>88ojVg
h`;oW;O[1On/^N<8oijgj@;oQk_g1_nL]n/7oh6in0KoGk?k1Om``_h7oio;mP03okW7iOn^b>go[/S]
00Go[/S]1?nm`]h3ok[7i003o`000?nl`=go_<3M00Go_<3M00?o_/?MokW0goni`=l01oni`=l00on]
_^Ko/L3Uok70i@05ok70iAKooooo00?o0000ooooooooool08oooool000[ooooo1?l000002?l@413o
ooooooooooo^k^ko<S8bo`000?lb<S;ok^k^1_ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo01Kooooo0onW`>/7ojS0j`;oYl3[1OnV_>T7ojFfi@KoX[7R00?oWZSNoijWgOnNYmd01?nN
Ymd7oinXg@KoXJ_N0_nVaNl8ojO:lP;oY/kd1onKio`3oj?So0KoW^7m0onWb?47ojG8lP;oXLWd1OnW
]^<8ojNgi@;oX[WY1OnZ]^82ojVgh`?o00000onY]n<00onS]nOo[KSRojfhhP05ojfhhPKoZKOS00?o
[[[Rojbihon/^N<01_n/^N<6oijgj@03ojfjhonL]n_oW;O[00OoW;O[0on1^OP4oiBfkPKoLkGj0omL
/_/2og32oP?oWl_f1?n7b?d8ojk8k@03okg2g_njanCo^/OT00?o^/OT00?o0000ok[7i?nl`=d00onl
`=d4okk3g@Oo^L3O00?o^l;Ook70iOna`>D01ona`>DEooooo`03o`000?oooooooooo02?ooooo000<
ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool04_ooool7ojO0j`GoZ<3[0_nX_n/7ojJlj@OoYKKU0_nR
/N85oijXgPKoWZOM1onOZ=d2oj6[gPKoY/G_1_nWb_84oj3Vo0?oVnOl1onSho`2oikQo@OoYlSa1OnU
b?89ojNfh`KoYkOU00?oZ[ORojZfh_nZ]^801?nZ]^83o`0000GoZKOS00?o[;SRojfhh_n]^>801_n]
^>84ojVgh`Co[[[R2?n/^N<2oijgj@Go[K[S1onL]n/00on/^^CoU;K^oiBfkP06oiBfkPKoLkGj1_mL
/_/6ohO8o@Ko[/S]00?oWlOdok[7i?njan@01Onjan@00ol0003o^/OTokc0g@07okk3g@Co^L3O1?nk
`]l7ok70i@03okC2i?oooooooooo01Cooooo00?o0000ooooooooool08_ooool00003ooooool0003o
000000Co00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_oo
ool2o`0001Wooooo00?o0000ooooooooool03_ooool3ojJoj`SoYl3[00?oZ<3[ojRojonX_n/01?nX
_n/6ojJlj@KoYKKU00?oWZ_PoijXg_nNZ=h01OnNZ=h7oijWg@GoWjSM0_nS_N`8ojK5k`?oYl[b1_nP
i_`3ojOVn`KoXn?l0onYc?88ojO8l@03ojG8l_nW]^?oYkKS00_oYkKS0_nW]nD5ojZghP?oZ[KR0_l0
0003ojZfhP;oZKOS1On/^>88ojfhhP03ojVghon^^^;o[[[R00Go[[[R1_n/^N<00on`^n;o[K[Sojfj
h`06ojfjh`CoW;O[1?n/^^@8oiBfkPKoLkGj1_mL/_/6ohO8o@;o[/S]1OnOao@7ok[7i003o`000?nn
`mgo_/?M00Oo_/?M00?o^L3Ook_2gonk`]l01Onk`]l4ok70i@Co]<;T5_ooool00ol0003ooooooooo
o`0Qooooo`003?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_oo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00[ooooo1onV_n/7ojO0j`SoZ;o[1_nV
_>T2ojFfi@GoWZ_P1onNZ=h7oijWg@03oinXgOnS_NcoXkg/00CoXkg/2?nVaNl00onWb_;oX>Kloj3V
o003oj3Vo0OoYnKk00?oXn?lojW<l_nYc?801OnYc?86ojO8l@koYkKS00?oZKKSojZgh_nZ]n801OnZ
]n83o`0000CoZ[KR00?o[;[Tojbhh_n/^>801_n/^>86ojfhhP03ojjli?n^^^;o[[[R00Ko[[[R1?n/
^N<4ok2khPSo[K[S00?oW;O[ojbji?n/^^@01On/^^@6oiBfkP03ojJjion7]OCoQkGd00CoQkGd1omS
[_X6offio0OoWlOd1?njan@3ok?7j@03o`000?nn`mgo_/?M00Go_/?M00?o_/GOok_2gonk`]l01onk
`]l00ona`>Go]<;TokC2i005okC2i1Gooooo00?o0000ooooooooool08Oooool000cooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`07ooooo`?oY[k[1onV_n/7ojO0j`SoZ;o[0onV_>T2oin_h`SoWZ_P1_nN
Z=h6oijWg@03oindi_nS_NcoXkg/00KoXkg/1_nVaNl4ojGRn`03oj3Vo?nWi__oYnKk00KoYnKk0_n/
dO<8ojW<lP;oYlSa3_nW]^<5ojVfh`?oZ[OR0ol00002ojZghP;oZ[KR1On/^^@8ojbhhP;o[KSR1On^
_>@8ojjjhP03ojbihon`^n;o/;_R00Go/;_R1_n]^^<00ona_>;o[;[Tojbji007ojbji0;oU;K^1OnV
^^L6ohNem0OoHjkj1_m]^O`7oio7m003ok[7i?ncanWo/lOY00?o/lOY00?o0000ok?7jOnn`md01?nn
`md3okk5g`Oo^l;O00?o_LCOokC2i?nd`^@01Ond`^@00onga>Coooooooooo`0Dooooo`03o`000?oo
oooooooo023ooooo000<ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4005ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool00oooool7ojJnj`GoY[o[0_nX
`>/7ojO0j`KoZ;o[00?oXkKVoin_honO[n<01?nO[n<8oij[h0KoWZSN0_nNYmd5oindiPSoXkg/0_nV
aNl6ojGRn`CoZ^Wj0onWi_/6ojcAl`KoZLcb00?oYkKTojNfhonW]^<03?nW]^<00onX]^?oZKKSojVf
h`04ojVfh`?o00001?nZ]n800on[_>Ko[;[Tojbji006ojbji0Ko[;SR00?o[KoXojjli?n^_>@01_n^
_>@6ojjjhP03ojnoi_n`^n;o/;_R00Oo/;_R0_n]^^<5ok6lhPOo[;[T00?o/KgSojJjionV^^L01OnV
^^L7ohNem0OoHjkj1_m]^O`3oio7m0?oSlCi1oncanT01?l0003o_/?Mokk3gOnn`md6okk5g`Co^l;O
1?nma=l4okC2i0Co]lCT5_ooool00ol0003oooooooooo`0Oooooo`003?ooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2o`0001kooooo00?o0000ojNojonW_n/0
0_nW_n/8ojJnj`03ojJojonX`>_oZ<3[00CoZ<3[1onW`>/2ojRoj`GoXkKV1_nO[n<8oij[h0?oWZSN
0onLZn47oindiPKoXkg/1?nXfoT2ojGRn`OoZ^Wj0on^f?H7ojcAl`;oZLcb1OnW]^@:ojNfh`GoZ;KS
0_nY]^<3o`0000;oZKKS0onZ]n84oj^liPOo[;[T1?n/^>84ojfoj0So[[cT0_n^^^85ojnoiPOo/;_R
00?o/<3Vok6lh_na_>801_na_>84ojbji0Co/KgS1onV^^L3ohNem0CoUkO^1_mb/OP6oej]nPOoSlCi
1oncanT00ol0003o_/?Mokk5g`07okk5g`03ok_2gonma=oo_LCO00Go_LCO00?o]<;TokO4i?nga>@0
1Onga>@Eooooo`03o`000?oooooooooo01oooooo000:ooooo`03oeEEEOmVIVKo000000Cooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo01[ooooo0_nX`N/7ojNoj`KoY[k[
0_nW`>/7ojS0j`GoYl3[0_nV_NT7oj>fiPKoWjoS1_nNZn000onIY]ooW:_Qoib[h@05oib[h@OoWkCV
0_nS_N`7ojSKn@?o[Nci1?nZjOX6ojkHmPGo[=7c0_nW]nD7ojNfi0OoYkKS1_nX]^<3o`0000KoZKKS
00?oZ[ORoj^li_n[_>H01?n[_>H7ojbji003ojbhh_n]_nSo[KoX00Go[KoX1_n^_>@00on[`NWo[koV
ojnoiP06ojnoiPCo/;_R1?n``>H8ok6lhP03ojbji?na_N?o/KgS00Go/KgS1OnV^^L00on__NCoUkO^
oiNgkP06oiNgkPKoL[7h1_mN[OX7oho4n@Ko/lOY00?oZLG]o`000?nnaMl01_nnaMl00onman;o_LCO
okg4g`05okg4g`03oko6gonga>Co]lCT00Oo]lCT5Oooool00ol0003oooooooooo`0Nooooo`006ooo
ool00ol0003oooooooooo`0Hooooo`GoZ<7[1onW_n/2ojJnj`KoYl3[1onX`>/00onW`>_oY[gYojJm
j@04ojJmj@OoXkKV1_nO[n<2oij[h0GoVJKO1onLZn45oindiP?oZM3d1OnXfoT6ojg/n@03oj[Yn_n^
f?Ko[]Sf00Oo[]Sf00?o[=7cojNgiOnW]nD01?nW]nD7ojNfi0OoYkKS0_nX]^<3o`0000;oZ;KS1_nY
]^<00onY_^SoZkcVoj^liP06oj^liPGo[;[T0_nY`>X8ojfoj0;o[[cT1On[`NT8ojnoiP03ok2kh_n`
`>Ko/<3V00Go/<3V1_na_>800ona`>Go/KgSok6mh`07ok6mh`03ojJjion__NCo[kgT00?o[kgT2?nG
]nh6og:an0KoGZgj1on?a?T2ok?7j@CoZLG]00?o0000ojW5kOnnaMl00onnaMl4okg7hPGo_LCO0ono
a]l7okO4i003okS5i?oooooooooo01Cooooo00?o0000ooooooooool07Oooool001_ooooo00?o0000
ooooooooool05oooool7ojS1j`GoYko[0_nV_^/8ojO0j`OoZ<3[1onV_NT7oj>fiP?oWjoS0_nJYml8
oiVVg`OoW:_Q00?oWkCVojW@m?nYd?@01_nYd?@00onXfoWo[Nciojg/n@05ojg/n@?o/Mkg1on^f?H0
0onX^nOoYkOUojNgi@06ojNgi@GoYkKT00?oY[GTojNfhonW]^<01?nW]^<3o`0000KoZ;KS0_nY]^<5
ojVnj0SoZkcV00?o[;[TojW0j_nY`>X01?nY`>X6ojfoj003ojRojon[`NWoZl7Y00KoZl7Y1_n__nH0
0on[`N[o/<3Vok30iP07ok30iP;o/KcR1Ona`>D7ok6mh`03ok:oi?n__NCo[kgT00Go[kgT1_nG]nh2
ojBkj@KoP;?e1_mQZ?L6ogfjnPOoZLG]00?o0000ojW5kOnnaMl01_nman83okg4g`Ko_lKO1?nga>@4
okS5i1Cooooo0_l0000Oooooo`006oooool2o`0001Kooooo2_nX`N/00onW_n_oY[k[ojJnj`04ojJn
j`SoYl3[1onX`>/7ojJmj@?oXkKV0onK[>86oiZWg`OoVJKO1_nLZn42ojO6k`OoZM3d1?n`j_P2ojg/
n@So/Mkg0_n^f?H5ojRki`SoYkOU00?oYkKTojJei?nV]N@00onV]N@3ojNfh`;o00000_nW]^<6ojRf
h`03ojRnjOnY_^SoZKkX00KoZKkX1_n[_>H2ojRoj`OoZL3Z0_n]_nP5ojRoj`SoZl7Y0_n__nH5oj_1
jPOo/<3V00?o[<7Zok70iOna`>D01_na`>D4ok6mh`Co/[oT1on__N@2oiNgkPKoY;_Y1_n0/oD6of6X
m`KoOK[j1_nYaNd00onQ`O3o0000okg7hP07okg7hP03okg4gonoa]oo_lKO00Ko_lKO00?o]lCTokS5
i?nhaN@01?nhaN@Fooooo`03o`000?oooooooooo01cooooo000Jooooo`03o`000?oooooooooo01?o
oooo3?nX`N/2ojNoj`OoY[k[1_nW`>/9ojS0j`GoY[gY00?oW[3Uoi^/h_nK[>801OnK[>86oiZWg`Oo
VJKO0_nLZn46ojO6k`CoZM3d1_n`j_P3okKUmPKo/Mkg00?o[LC[ojRkionX^nL01_nX^nL6ojNgi@03
ojFdi?nV]NCoY[GT00CoY[GT0ol00005ojNfh`;oZ;KS1OnX_^T8ojVnj0;oZkcV1_nX_n/5ojW0jP;o
YkkY1onX_n/6oj_1j@03ojNnj_n[`N[oZl7Z00KoZl7Z1?n``>H4ojc1jPSo/L3U00?o/KgSok:oi?nb
_n@01?nb_n@6ojnmi0;o//3T2?nT^nT6oh2cm@KoHJSg1_mm^_X2ojW5k@GoXL7`00?o0000okg7h_nm
an801?nman800onianCo_lKOoko6g`06oko6g`03ol38h?nhaNCo^<GT00Ko^<GT5Oooool00ol0003o
ooooooooo`0Looooo`006_ooool00ol0003oooooooooo`0@ooooo`?oZ<3[2OnX`N/6ojNoj`OoY[k[
0_nW`>/=ojS0j`03ojJmjOnN/>GoW[3U00?oW[3U1onK[>86oiZWg`GoVJKO0onO^>X7ojO6k`03ojW@
m?n`j_So/>[h00Co/>[h1_nfiOH2ok7Nm`Go[LC[2?nX^nL2ojNgi@GoYKCT0_nV]N@3o`000003ojJe
i?nW]^?oYkKS00CoYkKS0_nW_^T7ojRnj@KoZKkX0_nW_nX8ojRoj`03ojW0j_nW_^WoYkkY00CoYkkY
1onX_n/2oj_1j@GoYkkZ2?n[`NX00on``>Ko[<7Zojc1jP05ojc1jPKo/L3U00?o[/;Xok:oi?nb_n@0
1_nb_n@2ojnmi0Ko//3T1_nT^nT00on]_^OoRk?aoh^cl@05oh^cl@KoJ:Sf1_ma/?P6oj71l003o`00
0?nman;o_LOR00;o_LOR1?nian@6oko6g`?o`<SP1_nhaN@2okW7iAGooooo00?o0000ooooooooool0
6oooool001[ooooo00?o0000ooooooooool03Oooool7ojS0j`KoZ<7[00?oZ<3[ojNojonW_n/01_nW
_n/5ojJnj`ooZ<3[00?oY;[Xoij`iOnN/>D01OnN/>D6oi^/hPOoVZOO00?oVJKOoinhj_nO^>X01OnO
^>X5ojO6k`Co/>;h0_n`j_P7okKUmP;o/]3`1on]a>/6ojRki`03oj>di?nU]>CoYKCT00CoYKCT0ol0
0005ojJei0;oYkKS1_nW_^T7ojRnj@;oZKkX1_nW_nX6ojRoj`03ojRmjOnW_^WoYkkY00KoYkkY1OnX
_n/00onX_^WoYkkZojNnjP06ojNnjPKoZl7Z0_nW_^X8ojc1jP;o/L3U1On^`^P6ok:oi003ok;2i_nb
`>Co//3T00Oo//3T0_nT^nT5ojfni`OoRk?a1_mXZ?H6og6`n0KoXL7`00?o0000okg7h_nian@01_ni
an@3oko6g`Go`<SP1?nhaN@5okW7iAGooooo00?o0000ooooooooool01_ooool5o`0000oooooo000J
ooooo`;o00002oooool4ojO0j`OoZ<3[0_nX`N/5ojS0j`SoYko[00?oY[k[ojS0jonX`>/03OnX`>/5
ojBjj0OoW[3U1_nK[>83oiZWg`?oVJ_S2OnO^>X00onWa^oo/>;hok3Rn005ok3Rn0?o^N[e1?nfiOH5
ok;@l0Oo[LC[0_nX^nL5oj>di0;oYKCT0ol00002ojFdi0GoY[GT0onV_NT7ojNnj@?oZ;kY1?nW_^X8
ojNojP;oZ;o[1OnX_NT8ojNnj@03ojRojonX_^WoZ;kY00?oZ;kY2?nW_^X2oj_1jPKoYkkZ1_n/`NX0
0onX_n_o[/;Xojk2j006ojk2j0?o/[oT1?nb`^H7ok;0i003ok?1i?n]_^Oo[KkW00Ko[KkW1on;/o46
ofRXmPKoLK3h0onQ`O03oiZnl@03o`000?nianCo^LOT00Ko^LOT00?o_lKOol38h?o0b>001Oo0b>00
0onhaNCo^LOUokW7i@06okW7iACooooo00?o0000ooooooooool01_ooool01OnHV9So8B4Qonk^k_oo
ooooA4A400oooooo000Jooooo`03o`000?oooooooooo00Kooooo0_nW_n/7ojO0j`GoZ<3[0_nX`N/7
ojS0j`KoYko[0onV_n/;ojS0j`?oYko[1_nT^^P7oij`i@?oVjcR0_nFY^47oiV[h`OoWkSZ0on]do@4
ok3Rn0Oo^N[e00?o]^Gfok;@l?nbd?001Onbd?05ojg4j`;oXkCU1OnS]>@3o`0000KoYKCT00?oY[GT
ojJmjOnV_NT01OnV_NT5ojNnj@WoYkkZ1_nW_nX00onX_NSoZ;gYojRmj@06ojRmj@KoYkkY00?oZKgX
ojRnjOnX_^T01OnX_^T6ojNnjP;oZKkY2?nW_^X2ojc1jPGoZ;o[2?n^`^P00onb_nCo//;Vok;2iP04
ok;2iPCo//3T1?nc`N@8ojfni`?oRk?a0onD]nl7ofnYm0GoJZWf1_nJ__400ol0003o^LOTokW7i005
okW7i003okO6i_o0b>3o`<SP00Go`<SP00?o`<WQokW7iOnianD01_nianD00onjb>Goooooooooo`0C
ooooo`03o`000?oooooooooo00Kooooo00?oV9RHob4Q8Oo^k^h04?ooool001[ooooo00?o0000oooo
ooooool00oooool6ojNoj`OoYl3[00?oZ<3[ojS1jonX`N/01?nX`N/7ojS0j`;oYko[1onV_n/7ojS0
j`OoYko[1_nT^^P3oij`i@?oV:WR1_nFY^47oiV[h`CoWkSZ1on]do@00on`h_So^N[eokWZm@05okWZ
m@?o]m_c1onbd?000on]a>_oXkCUoj>di@04oj>di@04oj>di?l0003o0000o`0000?oXkCT0onU]>@4
ojFkj0SoY[gY00?oYkkYojNnj_nW_^X02onW_^X2ojNojPGoZ;gX2?nX_NT2ojNnj@GoZKgX1onX_^T2
ojNnjPKoZKkY1_nW_^X00onY_^WoZ;o[ojRoj`06ojRoj`Ko[/;X00?oZ/7[ok;2i_nb`^H01_nb`^H0
0onb`>Co/l7Tok?1i005ok?1i0Ko[KkW00?o/L7VoiBgkonD]nl01OnD]nl7ofnYm0GoJZWf1_nJ__40
0ol0003o^LOTokW7i002okW7i0Co]lKV1Oo0b>03ol39h@Ko^LOU0onjb>DEooooo`03o`000?oooooo
oooo00Kooooo00?oV9RHob4Q8Oo^k^h03oooool001[ooooo00?o0000ooooooooool02_nW_n/5ojO0
j`;oZ<3[1onX`N/5ojS0j`?oY[k[2?nV_n/7ojS0j`OoYko[0onT^^P2oiZ^i@OoV:WR1_nFY^47oiV[
h`03oinhj_n]doCo[M?d00Ko[M?d1?njjO@2okWZm@Oo]m_c0onbd?03ojFhiPGoXkCU0ol00005oj>d
i0;oY;SW1onU^nP6ojJmj@03ojNoj_nW_^[oYkkZ00_oYkkZ2OnX_NP6ojRmj@WoZKgX1OnX_^T2ojVm
j0SoZKkY0_nW_^X5ojVnj@SoZ;o[0_n^`^P5oj[1j`Ko//;V00?o[l;Xok?1i?nc`N@01onc`N@2ojfn
i`Go/L7V1onD]nl7ofnYm0GoJZWf1_nJ__400ol0003o^LOTokO6iP05okO6iP?o`<SP1_o0bN43okW7
i@Go^/SU5Oooool00ol0003oooooooooo`07ooooo`03ogMgMomVIVKooooo00kooooo000Iooooo`03
o`000?nW_n_oYko[00coYko[00?oYl3[ojS0jonX`>/01?nX`>/7ojS1j`03ojS0jonV_^_oY[k[00Go
Y[k[1_nV_n/9ojS0j`GoYko[00?oXKOXoiZ^iOnJ[^D01?nJ[^D7oiRYhPKoUZKQ1OnIZn<3ojO5kPGo
[M?d1OnjjO@3okgTlPKo]m_c0_n/`^X6ojFhiP04oj>diOl0003o0000o`0000CoXkCU00?oXkCTojBh
ionT^>L01?nT^>L7ojFkj0;oY[gY1OnW_nX9ojNnjPgoZ;gX0_nX_NT=ojVmj003ojRnjOnY_NSoZKgX
00CoZKgX1_nY_^T00onZ_^SoZKkYojVnj@06ojVnj@KoZ;o[0_nX_nX7oj[1j`;o//;V1On_`^P7ok?1
i003ok?2iOna`NKo/L7V00Ko/L7V0onD]nl3oiZjkPOoMJ[c1?mXY?<2ofZYmP?oV[ka0onF^o400ol0
003o]lKVokO6iP05okO6iP03ol38h?o0bN7o`<WQ00Ko`<WQ00?o^LOUok[8iOnjb>D01Onjb>DEoooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03Oooool001Wooooo00?o0000ojNojonW
_n/02onW_n/2ojO0j`OoZ<3[1OnX`N/3ojS0j`OoY[k[0_nV_n/=ojS0j`03ojNojonQ]nSoXKOX00?o
XKOX1_nJ[^D6oiRYhPOoUZKQ00?oVJ_SojO5k_nWaNh01_nWaNh00on]doCo^^Wdok[Ym004ok[Ym0Go
_NCb0ongfo<5ojc2jPCoYKSV0_l00006oj>di@03oj>ei_nT^>OoY;SW00KoY;SW1OnU^nP00onW_n_o
YkoZojNojP06ojNojPKoYkkZ00?oYkcXojRmj?nX_NP03?nX_NP>ojVmj0;oZ[kX1onY_NP2ojVnj@Go
Z[kX2?nY_^T2ojRoj`KoZ;oZ1OnZ`N/00onX_n_o[l;Xojo2j006ojo2j0Co/l7T1?nc`^D6ok71iP03
ok;3i_nJ^^koV[[^00GoV[[^1omeZ_<5ofRTl`KoU[_a00?o0000okO6i_nga^H01?nga^H2okG6iPOo
`<WQ00?o`L_Rok[8iOnjb>D01Onjb>D00onibNKoooooooooo`0Booooo`?o00001?ooool01Ol0003o
^[ZjoooooonHV9So410@00oooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0
003oooooojNoj`08ojNoj`KoYl3[1onX`>/00onX`N_oZ<3[ojS0j`05ojS0j`GoY[k[0_nV_n/=ojS0
j`03ojJnjonQ]nSoXKOX00GoXKOX1_nJ[^D6oiRYhP?oUZKQ1?nL/nP7ojO5kP?o]]kd1?njjO@7okgT
lP03okOKlon/`^[o[<;Z00Go[<;Z0ol00003ojFhiP;oXkCU1OnS]NH8ojBhi`03ojFkj?nW_n_oYko[
00?oYko[2?nW_nX2ojNnjPGoYkcX3_nX_NP:ojVmj0KoZ[kX1OnY_NP00on[_nWoZ[kXojZnj006ojZn
j0KoZKkY0_nZ_nP8ojRojP03oj[1jonX_n_oZ;o[00?oZ;o[2?n_`^P00onc`NCo/l;Uok?2i@05ok?2
i@?o/L7V1?nb`nH7oiZjkPKoMJ[c1_mXY?<6oiJkl@03o`000?nga^Ko]lKV00Ko]LKV1?o0bN44ol7;
hPCo^/SU1?nibNHEooooo`03o`000?oooooooooo00;ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00?
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool02?nW_n/7
ojO0j`GoZ<3[0onX`N/7ojS0j`03ojJnjonV_n_oY[o[00CoY[o[2OnX`>/5ojJnj`OoXKOX1_nJ[^D3
oiRYhP?oU:OS1onL/nP4ojO5kPOo]]kd00?o^^WdokgTl_nmi?801Onmi?82okKCk`Co[<;Z0ol00000
1?n/`^[oYKSVojFhi_nU^>H3oj6diPOoXkGV1_nT^>L8ojNoj`KoYkoZ00?oYkgYojNlj?nW_>P01_nW
_>P>ojRmj0KoZKgX0_nY`>X8ojZnj003ojVmj?n[_nWoZkoY00?oZkoY2?nZ_^P2ojVnj@KoZ[oX1_nX
_nX00onZ_nWoZ;o[ojRoj`05ojRoj`Ko[l;X0_n]`^T8ok?2i@03ok71i_nb`nKo//?V00Co//?V1onJ
^^h6ogFZl`KoJ:Cc0onF^o43oiBhl003o`000?nea^Ko]LKV00Ko]LKV00?o`<WQol7;h_o1bn801Oo1
bn800onjb>Go^LWVokW9iP05okW9iQGooooo00?o0000ooooooooool05Oooool000kooooo00Go410@
oooooooooooooooooa0@4006ooooo`;o00000_ooool8ojNoj`OoYl3[00?oZ<3[ojS1jonX`N/01OnX
`N/5ojS0j`;oY[k[1onV_n/7ojS0j`OoY[k[1onQ]nP3oiZ^i@WoU:OS1onL/nP00onWaNko]]kdokKN
m006okKNm0Co`NWa0_nmi?86okKCk`?o00000on/`^X8oj6diPOoXkGV0_nT^>L<ojNoj`;oYkoZ1OnW
_NT8ojNlj0koZ;gX0_nY_NP6ojW0jPKoZ[kX00?oZL;/oj^ojOn[_nT01On[_nT6ojZnj003oj^oj?nZ
_nSoZ[oX00OoZ[oX0_nX_nX5ojZoj@OoZ;o[0_n_`^P6ojg2j@Ko/l;U00?o/l?Vok;3i_nb`nH01_nb
`nH3oiZjkPCoWK_^1_miZ_85ofVRl@OoU;S`00?o0000okG6i_nea^H01?nea^H00oneaNKo`L_Rol7;
hP05ol7;hP;o`LgS2?nibNHEooooo`03o`000?oooooooooo01Cooooo000>ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`03ooooo`OoYko[0onW`>/5ojS0j`OoZ<7[00?o
Z<3[ojJnjonV_^/01?nV_^/7ojJoj`OoZ<3[1onV_^/3oj6gj0?oUjgV3OnDYn<5oibcj0?o[Lc`1Onf
g_@5ol7Yl@?o_Mg`0onfdnl3o`000003okKCkon/`^[o[<;Z00coXKCV1OnS]NH00onU_N[oYko[ojNo
j`0;ojNoj`WoYkgY1_nW_>P00onW_NWoZ;gXojRmj00;ojRmj0;oZ<;/2?nY`>X2ojZnj0GoZL;/1on[
_nT2ojZnj0GoZkoX1onZ_nP00on[_nSoZ[oYojZoj@05ojZoj@SoZ;o[2?n]`^T2ok?2i@Go/l?V1_nb
`nH2ok?4i`OoWK_^1_miZ_85ofVRl@KoU;S`00?o0000okG6i_nea^H00_nea^H4okG5iPGo`L_R1?o1
cN<6okW9iP03okS:j?oooooooooo01?ooooo00?o0000ooooooooool05?ooool000kooooo00Go0000
ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00Gooooo1OnW_n/2ojO0j`SoZ<3[1OnX
`N/2ojS0j`OoY[k[1OnV_n/9ojS0j`GoY[k[00?oW[GXoiN]i_nG[NH01OnG[NH=oiBWh`03oibcj?n]
c?3o[Lc`00Ko[Lc`00?o]]kdol7YlOo1jO400oo1jO45okgMl0?o00000onfdnl2ojFkj0koXKCV00?o
XkGVojFmj_nU_NX00onU_NX9ojNoj`goYkgY0_nW_>P5ojNmj@WoZ;gX1_nX`^`6ojW0jP03ojK2kOnY
`^coZL;/00KoZL;/1On[_nT00onY`^coZkoXoj^oj006oj^oj0CoZ[oX1?n[_nP7ojZoj@SoZ;o[1_n]
`^T00on[`N[o/l?Vok?3iP06ok?3iP;o//?V1_nca>L7oifkkPKoNJ[b1OmYX_46oiBhl003o`000?ne
a^Ko]LGV00Go]LGV0oo1bn87ol7=h`;o^LWV1Onhb^PEooooo`03o`000?oooooooooo01?ooooo000>
ooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`06ooooo`03ojNojonW
`>_oYl3[00CoYl3[2?nX`>/00onX`N_oZ<3[ojS0j`04ojS0j`OoY[k[00?oY[o[ojS0jonX`>/02onX
`>/00onV_^_oW[GXoijej003oijej0OoUjgV2onDYn<3oj:kj`Ko[Lc`1?noho42ol7Yl@?o_Mg`0ol0
0002okgMl003okKCkonU^nSoYK_X00CoYK_X3?nQ]>H00onR^>SoYKgZojFmjP05ojFmjPKoYko[0_nW
_NX<ojNmj@;oYkcY1onW_NT6ojRmj0;oZ<;]1onX`^`2ojW0jPGoY/;]2?nY`^`00on[_nWoZL;/ojW2
k003ojW2k0SoZkoX00?oZ[oXoj^oj?n[_nP01On[_nP5ojZoj@;oZl3Y2?nX_n/2ojg2j@GoZl7Z1_nc
`nH:ok?4i`?oWK_^0onM_>h6ogZXl0CoKJ3_0_mYX_43oiBhl0?oU;K^00?o0000okG5i_neaNH01One
aNH00oo1bn;o`LgSol7=h`05ol7=h`03ol7>iOnhb^So^<[X00Ko^<[X5Oooool00ol0003ooooooooo
o`0Booooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_l00008ooooo`OoYl3[1_nX
`>/2ojS1j`OoZ<3[1OnV_^/3ojJoj`[oZ<3[1?nV_^/5oijej0KoUjgV2?nDYn<7oj:kj`?o[Lc`1_no
ho42olGUkP?o00001?nmgO02ok?<k@OoYK_X2?nQ]>H5oj:hj0OoYKgZ0_nW_n/6ojNmjPSoYkgY1_nW
_>T7ojNmj@;oZ;gX1_nX`^d5ojS2k003ojK1kOnV`^goY/;]00KoY/;]1_nY`^`2ojK1k@KoZL;/1_n[
_nP2oj_2j`SoZkoX00?oZ[oYoj_0jOn[`>T01?n[`>T6ojRoj`03ojS0jon[`N[oZl7Z00KoZl7Z0onc
`nH;ok?4i`03ok?5ionM_>koWKc^00GoWKc^1_mjZ?05offPk`KoU;K^00?o0000oiBfk_neaNH01?ne
aNH2okO6iPKo`LgS0oo1c^D6okS:j003okG:jOoooooooooo01?ooooo00?o0000ooooooooool04_oo
ool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo00Sooooo1onW
`>/2ojS0j`KoZ<7[1onX`>/00onV_^_oY[o[ojJoj`05ojJoj`OoZ<3[1onV_^/5oijej0KoUjgV0onD
Yn<3oiBYi@WoX[_[00?o[Lc`okoSlOnoho401?noho400oo5iNko0000o`000002olGUkP;o_Mg`1_nc
c>d7ojFkj0?oXKCV0onP]NL7oj:hj0GoYKgZ0onX_n/7ojNmjP?oYkgY1?nV_>T7ojNlj@?oYkgY1?nW
`^d8ojS2k@03ojS2k?nV`NgoY/7]00?oY/7]2?nV`^d2ojW2k0KoY/7]1_nY`^`2oj^oj0KoZl;[1_n[
_nP2ojc1j@OoZl3Y0_nX_n/5ojS0j`SoZl7Z00?o/l?Vok?4ionca>L02?nca>L4ok?5i`KoWKc^1_mj
Z?06offPk`KoU;K^00?o0000oiBfk_neaNH01_nga^H3ol7=h`Go`LkU1?nhb^P4okG:jAGooooo00?o
0000ooooooooool04Oooool001Sooooo00?o0000ooooooooool02Oooool5ojO0j`?oZ<3[1onX`N/3
ojS0j`coY[o[1onX`>/7ojJnj`GoW[GX0onG[NH3oi2Vi0KoU:WU1onR^n/3ok;?k`?o_n?a0ol00003
olGUkP?o_][^1oncc>d3ojFkj0?oWkCW1onP]NL7oj:hj003ojFmj_nX_n_oZ;o[00GoZ;o[1OnW_NX9
ojJlj@GoYkcY0_nW`N`7ojO2k@KoZ<;]0_nW`N`6ojK1k@KoY/;]0_nV_n`8ojK1k@?oZL;/0onU`Nd8
oj_2j`;oZkoX1_n/`NT5oj_0j@03oj_1jOnX`>_oZ<3[00KoZ<3[1_n[`NX00onZ`N[o/lCWok?4i`07
ok?4i`Ko/lGW1onM_>h6ogZXl0KoKJ3_1?nD]^h2oiRfk@03o`000?nga^Ko]lKV00Ko]lKV00?o`LgS
ol7>iOo1c^D01Oo1c^D00onhb^So]L[YokG:j@05okG:jAGooooo00?o0000ooooooooool04?ooool0
01Sooooo00?o0000ooooooooool02_ooool00onW`>_oZ<3[ojS0j`05ojS0j`GoZ<7[0_nX`>/=ojJo
j`WoZ<3[1OnV_^/00onM]^[oUJgWoiF]i`04oiF]i`KoT:KT1_nDZND4oj:kj`Go//o_0ol00004olGU
kPKo_][^1Oncc>d2oj:ij@KoWkCW1onP]NL3oj:hj0CoYko[2?nX_n/00onW_N[oY[cYojJlj@0;ojJl
j@03ojNljOnW`NcoYl7/00CoYl7/1onW`^d2ojS2k@KoYl7/1_nV`Nd2ojK2k@KoY[o/1_nV`Nd00onV
_ncoYL7]ojG1k@05ojG1k@KoZl;[00?oZ<7/ojc1jOn/`NT01on/`NT00on[`>WoZl7Yoj_1j@03oj_1
j@SoZ<3[0_n[`NX5oj[1jPKo/lCW2OncaNL3oiflkPCoV[__1OmiY^l6og2Ok@OoV;K]00?o0000okO6
i_nga^H01?nga^H00onjb>Go`LkUol7>i@05ol7>i@;o`=3V1_neb^T00onbbN_oooooooooo`0Coooo
o`;o00004Oooool001Oooooo0ol0000=ooooo`OoZ<3[00?oZ<7[ojS0jonX`>/01?nX`>/9ojJoj`go
Z<3[00?oY[k[oiffj_nM]^X00onM]^X6oiF]i`KoT:KT1_nDZND00onR^n_o//o_ok;?k`02ok;?k`?o
00001?o4h^d2olGUkPSo_][^00?o/lc]oj:ijOnR^NT01?nR^NT6oindi`GoX;GW0_nS^nX7ojNoj`Ko
Z;o[00?oY[gZojJljOnV_>T02onV_>T00onV_n_oYl7/ojO1k006ojO1k0GoYl;]2_nW`N`3ojK1k@?o
YkkZ2?nV_n`2ojK1k@GoY[o/1onU`Nd2oj_2j`GoZ<7/1on/`NT8oj_1j@KoZ<3[0_nY`>/7oj[1jP;o
/lCW2oncaNL2ok?6j0OoV[__1OmiY^l6og2Ok@KoV;K]00?o0000okO6i_nga^H00_nga^H4ok[8i@Co
`LkU1Oo0d>H3okG:j@Co//W[4oooool00ol0003oooooo`00000Aooooo`005oooool00ol0003ooooo
ooooo`0>ooooo`GoZ<3[0_nX`N/7ojS0j`SoY[o[3?nX`>/00onV_n_oWKKZoiffjP05oiffjPKoUJgW
1_n@Y^@3oiBYi@CoYKk[0ol000000onbcnooa>;]olCRk@04olCRk@?oan;/1_nnf^h00onab^goX[WY
oj:ij@06oj:ij@KoWkCW00?oX;GWoj>kj_nS^nX01?nS^nX7ojNoj`;oZ;o[1OnV_NX9ojJlj@GoY[o[
2?nW`N`00onW`^goYl7/ojO1k00:ojO1k003ojNmjOnW_^[oYkkZ00GoYkkZ1_nV_n`2ojRnj@OoY[o/
1OnU`Nd2ojFok0OoZ<7/1?n/`NT;oj_1j@;oZ<3[1_nY`>/6oj[1jP[o/lGW1_nca^P7oiZkk`GoNJK_
1_m`Wnd6oiRfk@03o`000?nga^Ko^/SU00Ko^/SU00?o`LkUol3@i_o0d>H01_o0d>H00oneb^Wo//W[
ok;9j`04ok;9jaCooooo00?o0000ooooooooool03oooool001Oooooo00?o0000ooooooooool03ooo
ool00onX`>_oZ<7[ojS1j`04ojS1j`OoZ<3[2?nV_n/8ojS0j`GoY[o[1_nM]^X7oiF]i`?oT:KT0_nC
ZnH4ojFnj`?o00000_nU_^/00onbcnooa>;]olCRk@04olCRk@Koan;/00?o_][^ok7:kOnab^d00ona
b^d8oj:ij@?oWkCW0_nO]NP8oj>kjPGoYko[0_nW_^X7ojJmjPGoY[cY0onV_>X6ojJoj`KoYl7/0_nX
`^`9ojO1k0GoYkgY1onW_^X2ojJok0KoZ;kY1onV_n`00onU`NgoYKo/ojFok004ojFok0OoZ<7/00?o
[<7Yoj_1jOn[`NT02_n[`NT2oj_1jPSoZL3[1_nZ`NX7ok?5i`Wo/lKX0onJ^nl3oiBgk`CoN:;]0_mi
Y^l6og2Ok@?oV;K]0onL]n/00ol0003o^/SUok[8i@04ok[8i@;o_LcU1oo0d>H00onnd>So//W[ok;9
j`06ok;9jaCooooo00?o0000ooooooooool03_ooool001Oooooo00?o0000ooooooooool04?ooool7
ojS1j`GoZ<3[2_nV_n/7ojS0j`KoY[o[1_nM]^X3oiF]i`?oSZOV1_nCZnH3o`0000CoYKk[0onfcnd4
olCRk@Koan;/0_nof>`6ok7:k@KoX[WY00?oWKCXoinej?nO]NP01?nO]NP8oj>kjP03ojNojonW_^[o
YkkZ00CoYkkZ1onV_NX00onV_>WoY[cZojJljP05ojJljPKoY[o[0_nW`N`6ojS2k0GoYl7/2OnW_NT5
ojNnjP;oZKcX2?nX_^T3ojJok0CoZ;oZ1onU_n`3ojS1k0CoY/3/2On[`NT6oj_1jPKoZL3[00?oZL7[
oj[1j_nZ`NX01OnZ`NX4ok?5i`[o/lKX0_naanX6oiBgk`GoN:;]1_mgWn/7oibgj`04o`000?njb>Go
^/SUok[8i@Go_LcU1?o0d>H4okk@j0Ko//W[00?o[/K/ooooooooool04oooool00ol0003ooooooooo
o`0=ooooo`005oooool2o`0001;ooooo1onX`N/00onX`>_oY[o[ojJoj`0:ojJoj`WoZ<3[1_nV_n/3
oiffjP?oU:kX1_n>YnH2oi>[iP?o000000?oTj_VojFnjonU_^/00_nU_^/7okK?k@03olCRkOo7h^co
an;/00?oan;/1Onof>`6ok7:k@;oX[WY1OnM]>P6oinej0KoXk_Z0_nW`>/7ojNnjP?oY[gZ1?nU_>T8
ojJljP?oY[o[0onX`n`8ojS2k003ojO1k?nW_NWoYkgY00_oYkgY00?oYkkZojVlj?nY_>P01?nY_>P6
ojRnj@03ojZnj?nX_n[oZ;oZ00KoZ;oZ1OnU_n`00onV_ncoY/3/ojK0k006ojK0k0GoZl7Y2_n[`NX2
ojW0j`GoZL7[1onZ`NX00oncaNOo/lKXok?6j007ok?6j0Ko/LOZ1OnD]nl6ogRRk@KoMio[1_nL]n/0
0ol0003oW;O[ok[8i@07okg<i@03ol3@i_nnd>So_]3X00Go_]3X0_nbbN/5ojk6k1Cooooo00?o0000
ooooooooool03Oooool001Oooooo00?o0000ooooooooool04_ooool8ojS1j`SoY[o[3OnX`>/3ojJo
j`?oWKS[1_nD[^P5ohjWiP;o00001OnCZnH00onU_^_o]/o]okK?k@06okK?k@CoamoZ00?oan;/okoH
k?nof>`01_nof>`3ok7:k@?oXKWZ1onM]>P6oinej0;oXk_Z1_nW`>/5ojNnjP;oYKgZ1onU_>T6ojJl
jP03ojS2k?nX`ncoZ<?/00GoZ<?/1_nX`^`00onW_^[oYkgYojNmj@0;ojNmj@;oZKgX1onY_>P2ojRn
j@GoZ[kX2?nX_nX00onU_ncoY[o/ojJok003ojJok0SoY/3/00?oZl7Yoj_1j_n[`NX02_n[`NX00on[
`^[oZL7[ojW1j`05ojW1j`KoZ/7Z0_n[`NX6ok?6j003ok?7jOnaan[o/LOZ00Oo/LOZ1OnD]nl6ogRR
k@KoMio[1_nL]n/00ol0003o_LcUokg<i@05okg<i@03ol3@i_nnd>So_]3X00Go_]3X00?o^loYojk6
k?n^a^`01_n^a^`Dooooo`03o`000?oooooooooo00cooooo000Gooooo`03o`000?oooooooooo01?o
oooo2?nX`N/5ojJoj`;oY[k[3?nX`>/2ojO0j`KoWKS[1_nD[^P01On>YnKo0000o`000?l0003oSZOV
00GoTj_V0onV_^/5okK?k@GoamoZ0oo9h>T6okoHk003ok?<kOnQ^N[oXKWZ00GoXKWZ1onM]>P3oine
j0CoY;cZ1onW`>/00onW_^[oYKgZojFmjP04ojFmjPOoYKcY0_nV_>X5ojS2k0OoZ<?/0_nX`^`5ojNn
jPWoYkgY1_nY_NP5ojVlj003oj[1j_nZ_^SoZ[kX00KoZ[kX1_nX_nX00onY_nWoY[o/ojJok005ojJo
k0KoY/3/00?oYKo/oj_1j_n[`NX02?n[`NX5oj_2jPOoZL7[0_nZ`NX6oj_1jP?o/lKX1?ncanT7ok77
jP03ojg6k?n=[ngoSJo]00?oSJo]1OmfW^/2ogRRk@KoMio[0_nL]n/4oj:jjP03o`000?nmc>Go_LcU
00;o_LcU1?o0d>H4okk@j0Co^loY1_n^a^`00onZ`ncoooooooooo`0Cooooo`03o`000?oooooooooo
00_ooooo000Gooooo`03o`000?oooooooooo01Gooooo1onX`N/00onV_n_oY[k[ojJnj`04ojJnj`So
Z<3[1_nW`>/6oifhj`?oU:kX0ol00005ohjWiP03oi>[i_nV_^_oY[k[00KoY[k[00?o]/o]olOOj_o7
gnX01?o7gnX5olWPj@?o_mS/1?ncc>d7oj6ijPGoWKCX00?oW[KYojBlj_nT_>X01_nT_>X5ojO0j`03
ojJnjonU_N[oYKgZ00KoYKgZ1OnU_>T00onU_^_oZ<;/ojS2k006ojS2k0GoZ<?/0_nX`>/7ojNnjPGo
YkgY0_nW_>P8ojVmj003ojVlj?nZ`N[oZ/7Z00?oZ/7Z2?nZ_^P2ojRojPGoZKoY1onV_n`2ojK0k0Go
YKo/1_n[`NX9oj_2jPGoZL7[0_nX`N/8oj_1jP03ok?6j?ncanWo/lOY00Co/lOY1?naanX4ojg6k0Go
SJo]1_mfW^/6oh2Rj@OoX[[Z00?o0000okg<iOo0d>H01_o0d>H00onnd>So^loYok_?j@05ok_?j@;o
[/K/1OnZ`n`Dooooo`03o`000?oooooooooo00_ooooo000Fooooo`?o00005oooool5ojS1j`?oYko[
1_nV_^/8ojS0j`KoYl3[1OnM^>/3o`000003oiB^j?n<Z>SoS:SX00OoTJ[W1_nV_^/3okK=j`CoamoZ
1oo9h>T00onof>co/lc]ok?<k@04ok?<k@OoXKWZ00?oWKCXoijfjOnN]^T00onN]^T8ojBljP03ojO0
jonV_^_oY[k[00?oY[k[2?nU_NX00onU_>WoYKk[ojFnj`03ojFnj`SoZ<;/00?oZ<?/ojS0jonX`>/0
1?nX`>/7ojNnjP03ojNmjOnW_>SoYkcX00CoYkcX1_nY_NP00onXa>goZ/7Zoj[1jP05oj[1jPKoZ[kX
0_n/`NT7ojVoj@?oY[o/1?nV_n/7ojFok0;oZl7Z3On[`^X00onY`N_oZ<7[ojS1j`04ojS1j`KoZl7Z
00?o[L;Yok?7jOncanT01_ncanT00onaan[o[LK/ojg6k004ojg6k0KoSJo]1_mfW^/6oh2Rj@KoX[[Z
00?o0000ol3@i_o0d>H01Oo0d>H00oo2dnOo^loYok_?j@05ok_?j@;o^<k[1_nZ`n`Eooooo`03o`00
0?oooooooooo00[ooooo000Fooooo`03o`000?oooooooooo01Sooooo00?oZ<7[ojNojonW_n/01OnW
_n/6ojJnj`SoZ<3[1_nW`>/01OnM^>_o0000o`000?l0003oTjoZ00KoS:SX1onAZ^L3ojJnj`Oo]/g[
00?oamoZolWPjOo9h>T01Oo9h>T3ol;Hj@Ko/lc]0onQ^NX4oibej@KoW[KY1_nT_>X2ojS0j`KoY[k[
1_nU_NX2ojBljPKoYKk[1_nX`^`2ojW2k0OoZ<3[0onW_^X4ojJlj@OoYkcX0_nY_NP5ojS4k@OoZ/7Z
0_nZ_^P6ojc1j@GoZKoY00?oZ/7ZojJojonV_n/01_nV_n/5ojFok003ojFnk?n[`^[oZl;Z00coZl;Z
00?oZl;[ojS1jonX`N/01_nX`N/2oj_1jPGo[L;Y1_ncanT00ondb>Wo[LK/ojg6k006ojg6k0KoSJo]
1OmfW^/7oh2Rj@;oX[[Z1?nY_^T00ol0003o`=3Vol3@iP02ol3@iPCo`]?W1?nkcnT5okS>j`KoZ/?/
4oooool3o`0000_ooooo0004ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^
kPKooooo00?o0000ooooooooool06_ooool7ojNoj`?oY[k[1?nW_n/7ojS0j`?oYl3[0ol00005oi>_
jPKoS:SX1onAZ^L00onV_^_o]/g[okK=j`05okK=j`?oam[X1?o9h>T6ol;Hj@?o/lc]0onR_>`7oibe
j@KoW[KY0_nT_>X6ojS0j`KoY[k[0_nU_NX6ojBljPKoYKk[0_nX`^`6ojW2k0GoZ<3[00?oY[gZojJl
jOnV_>T01_nV_>T5ojNlj0;oYl?^1onXa>d5oj[1jP;oYl;]2?n/`NT00onY_nWoZ/7Zoj[1jP03oj[1
jPSoY[o[00?oYKo/ojFnk?nU_^`00onU_^`:oj_2jPGoZl;[2?nX`N/7ojg2j@;o/lOY1Ondb>T6ojg6
k003ojC1k_n8Z>_oR:S[00CoR:S[1?mgV^L2ogJNj`?oP:;Y0on;Y^L7ojVnj@03o`000?o0d>Ko`]?W
00Ko`]?W00?o^loYokS>jonhc^/01_nhc^/3oj[3k0?oZ<7/3oooool3o`0000;ooooo00?o0000oooo
ooooool02Oooool000Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Kooooo00?o0000ooooooooool06oooool5ojNoj`03ojJojonW_n_oYko[00KoYko[1OnX`>/01?nW
`>_o0000o`000?l00003oj2kk0KoTjoZ1_n<Z>P5oi6Zi`;oXk[Z1_nfcN/5olOJj003olWPjOo2f>Wo
`]SY00Go`]SY0_nid>/6oj:lk0OoW;GY0onN]^T4oj>kjPOoZ<3[0onV_^/4ojFmj`OoY;cZ0onU_^/;
ojW2k003ojS0jonV_N[oY[gZ00?oY[gZ2?nV_>T00onW_>SoYl?^ojO3kP04ojO3kPOoZ<C]00?oZ/7Z
ojO2kOnW`^d01?nW`^d6ojc1j@03oj_1j_nZ`N[oZ/7Z00GoZ/7Z1_nV_n/2ojJok0KoYKk/2?n[`^X7
oj_2j`SoZ<7[1On]`^T2ok34j@Oo]<SY0_n]a^`5ojC1kPKoR:S[1OmgV^L7oh^Vi`KoZKkY00?o0000
ok;5j?o2dnL01Oo2dnL2ol3FjPOo^<k[00?o//c]ojS1k?nX`N`01OnX`N`;ooooo`?o00001Oooool0
0ol0003oooooooooo`09ooooo`001_ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@41001_ooool2o`0001gooooo00?oYko[ojJojonV_n/00onV_n/8ojNoj`03ojS0jonW`>_o
000000;o000000?oYl3[oj2kk?nP^n`01?nP^n`6oi>_jPKoS:SX00?oTJ[Woj>jj_nS^^X01?nS^^X3
okK=j`Koam[X0oo<g>D4ol;Hj@Go^M3[1_nR_>`5oibej@03oibfj_nS^n[oXk_Z00KoXk_Z1OnX`>/0
0onV_n_oYKg[ojFmj`06ojFmj`GoY;cZ00?oY[k[ojW2k?nY`^`02onY`^`2ojNoj`KoY[gZ1_nV_>T2
ojK0k0OoYl?^0onXa>d4ojC4l0OoYl;]0_n/`NT5oj_1jPOoZ/7Z0_nV_n/6ojJok0KoYKk/2?n[`^X7
oj_2j`SoZ<7[00?o[L;Yok34jOn`a>T01?n`a>T5okC8j@;o/lW[1onT`Nh6ohRXj`GoMi[W1on;Y^L3
ojVnj@?o//GX00?o0000ok;5j?o2dnL00_o2dnL5ol3FjPCo^<k[1?nbc>d7ojS1k0Kooooo1?l00008
ooooo`03o`000?oooooooooo00Wooooo0006ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`000005ooooo`;o00007oooool6ojJoj`KoYko[00?oZ<3[o`000?l000001OnW`>/6
oj2kk0?oTjoZ0on<ZnX6ohfXj0OoXk[Z00?o]/g[olOJj?o7f^P01?o7f^P6olcLi@03ol;HjOnid>_o
^M3[00Go^M3[1_nR_>`00onL]NWoW;KZoibfjP03oibfjPSoXk_Z00?oZ<3[ojJojonV_n/00onV_n/8
ojFmj`03ojBlj_nV_^_oY[k[00?oY[k[2OnY`^`6ojNoj`KoY[gZ0_nV_>T6ojK0k0GoYl?^0_nWaNl7
ojC4l0GoYl;]00?oXkk/oj_1j_n[`NX01_n[`NX5oj[1jP;oZ/;[2?nV_n`3ojFnk0?oY[k[2?n[`^X7
oj_2j`KoZ<7[00?oZ<3[ok34jOn`a>T01_n`a>T00ondb>Wo/lW[ok?9j`04ok?9j`OoY<7^1_n8Z>/5
ogNJi`OoRjKW00?oZKkYok;5j?nbaNP00onbaNP00ol0003o//GXol;Ci`07ol3FjP03okS>jonbc>go
//c]00Co//c]1_nX`N`01?nW_n_oooooooooooooool3o`0000gooooo00?o0000ooooooooool02?oo
ool000Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Gooooo00?o
0000ooooooooool07oooool6ojJoj`;oYko[00CoZ<3[o`000?l0003o00000_nX`>/6ojO0j`?oX;_/
0onE/n`6ohb[jPKoSJSX1OnS^^X3ok?8jPCoam[X1_o<g>D2olOHiPSo^M3[0onR_>`3oi^fj`KoW;KZ
1_nS^nX2ojNoj`KoY[o[1_nU_N/2ojBlj`KoY[k[2?nY`^`7ojNoj`?oY[gZ0onT_>X8ojK0k003ojO3
k_nWaNooYlG_00CoYlG_1onTa?000onW`^goXkk/oj>nk003oj>nk0SoZl7Z00?oZ/7Zoj[2jonZ`^/0
1?nZ`^/7ojJok0OoY[k[1_n[`^X00on/`n_oZl;[oj_2j`06oj_2j`;oZ<7[1OnX`>/6ok34j@03ok;9
joncbN_o/lW[00Ko/lW[0onT`Nh3oiRfk0KoPZ7W1?mkV^@2ogNJi`?oRjKW0onG[nP7ok;5j003o`00
0?o0e^[o`=KZ00Go`=KZ00?o_MC[ok;<kOnbc>d01_nbc>d2ojS1k0GoYko[0_l0000@ooooo`03o`00
0?oooooooooo00Sooooo0006ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooo
oa0@4005ooooo`03o`000?oooooooooo023ooooo1OnV_n/3o`0000KoZ<3[0onW`>/4ojBnk0GoUK?/
1_n<ZnX6ohfXj003oj>jj_ncb>[o/lSZ00Ko/lSZ00?oam[XolcLiOo<g>D01?o<g>D4olOHiPKo^M3[
0_nYa>d6oi^fj`KoW;KZ0_nS^nX6ojNoj`KoY[o[0_nU_N/6ojBlj`KoY[k[2?nY`^`5ojNoj`03ojFn
jonT_>[oY;cZ00GoY;cZ1_nV`>`2oj[3k0OoYlG_0onTa?04oj:nk@KoXkk/1_n[`NX2oj_2jPOoZ/;[
1onV_n`7ojJnj`;oZl;Z1On/`n/6oj_2j`;oZ/;[1onX`>/2ok34j@Go//W[1_ncbN/2ok39k0KoV;K/
1_n2XNL5og^Ji0OoUjoX1?nbaNP2ok_?j003o`000?nkcnSo`=KZ00?o`=KZ1?nme>/6ok;<k@03oj_5
k?nW_n_oYko[00KoYko[4Oooool00ol0003oooooooooo`08ooooo`001_ooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2o`0002;ooooo00CoY[o[o`000?l0003o
00000onV_n/8ojS0j`KoY;k/1OnE/n`6ohb[jP?oSJSX1?nK]>T6ok?8jP?o`]7V1?o<g>D6olOHiP;o
^M3[1_nYa>d6oi^fj`?oW;KZ1?nP^NX7ojNoj`?oY[o[0onT_N/8ojBlj`?oY[k[0onY`N/8ojW2k003
ojNojonU_^_oYKk[00?oYKk[1onT_>X2ojK0k0KoZ/?/1OnWaNl00onW`>_oX[k]oj:nk@06oj:nk@Ko
Xkk/0_n[`NX6oj_2jPGoZ/;[0_nY`^/6ojJok0KoY[k[0_nX_nX7ojc3j`;oZl;[1_nZ`^/5ojS0j`;o
Z/7[1onbbN/2ok?9j`Ko/<W/1OnH]^`6oh:Qi`KoNi[T1onG[nP00onbaNSo^loXok_?j003ok_?j003
o`000?nkcnSo`=KZ00Oo_MC[0_nbc>d5oj_5k0KoYko[00?oYl3[ooooooooool03oooool00ol0003o
ooooooooo`08ooooo`001?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool00ol0003oooooooooo`0Oooooo`?o00001onV_n/8ojS0j`KoY;k/1OnE/n`3ohb[jP;o
QjOY2?nK]>T3ok?8jPOo`]7V00?oc=cUolOHi_o7f>H01?o7f>H3ol3Bi`OoZLC]0onK]^/2oiZfk0So
X;WZ1OnW_n/00onW`>coY;g[ojBmj`05ojBmj`KoY;c[00?oY;g[ojW1jonY`N/01OnY`N/6ojW2k0;o
Yl3[1_nU_^/5ojBljP;oZ;oZ2?nZ`n`00onWaNooYl3[ojO0j`03ojO0j`SoX[k]0onS_^`3ojBlj`So
Zl;Z00?oZ/;[ojW2jonY`^/01?nY`^/6ojJok0;oY[k[1_nX_nX5ojc3j`;oZl?[2?nZ`^/00onX`>_o
Z/7[oj[1j`04oj[1j`Go//W[0_ncbn`8ok39k0GoV;K/1_n2XNL6og^Ji0?oUjoX0onQ^>T7ok_?j003
o`000?o1e^[o_MC[00Go_MC[00?o^M7/oj_5k?n[aN`01_n[aN`2ojNoj`GoYl3[4?ooool00ol0003o
ooooooooo`08ooooo`005Oooool00ol0003oooooooooo`0Looooo`?o00001?ooool5ojJoj`[oZ<3[
0onT_^`2oi^ikPGoSZk/1_n7YnT8oi^dj@03ok?8j_o2dNKo`]7V00Go`]7V0oo;en83olOHiPKo`=;W
1OnYa>d00onN^ngoV[K/oiZfk004oiZfk0SoX;WZ00?oYko[ojO0k?nW`>`00onW`>`7ojBmj`;oY;c[
1OnT_N/7ojW1j`;oZL;/1_nW`>/6ojFnj`03ojBlj_nX_n[oZ;oZ00CoZ;oZ1_nZ`n`2ojg2j@KoYl3[
1_nR_^d2oj:ij@KoY;c[1_n[`^X00on/a>coZL;[ojW2j`06ojW2j`?oY[o/0onU_N/8ojRojP03ojc3
jon[`n_oZl?[00CoZl?[1_nZ`^/00onX`N_oZ/7[oj[1j`06oj[1j`03ok;9joncbnco/l_/00Co/l_/
1_n`bN`00onV`NgoSZSWohjXi`03ohjXi`KoOY[S1_n7Wn<7oj6hj@Co^loX0oo1e^X01?l0003o`MKZ
okgDjonme>/5okWAk0KoZlG/00?oZ<7/ojO0jonW`>/01_nW`>/?ooooo`03o`000?oooooooooo00So
oooo000Eooooo`03o`000?oooooooooo01Wooooo0ol00008ooooo`03ojJojonX`>_oZ<3[00[oZ<3[
00?oYl3/oi^ik_nK^Nh01?nK^Nh5ohj^k0KoQjOY1_nK]>T2ojg2j@Ko`]7V1Oo;en800oo7f>Ko`=;W
ol3Bi`06ol3Bi`03ojW4kOnN^ngoW[_]00?oW[_]1_nJ]^`6oj2ijP;oYKg[1_nW`>`5ojBmj`?oXkg/
1_nT_N/5ojW1j`;oZ/;[2?nW`>/3ojFnj`?oXkg/1onX_nX2oj[3k0Ko[L;Y1_nW`>/2oj:nk@KoX[WY
1_nT_>/2oj_2jPGo[<C/1_nY`^/2ojS0j`KoYKg[1_nX_nX9oj_3j`;oZ/;[1OnX`N/6oj[1j`03ojk6
joncbnco/l_/00Ko/l_/0_n`bN`5ojK1k@GoSZSW1_mnV^<6ohNOh`OoXKSY00?o^loXol7Fj_o1e^X0
0oo1e^X00ol0003o`=W/ol3Ik007okWAk0;oZlG/1OnX`N`6ojO0j`03ojNojooooooooooo00gooooo
00?o0000ooooooooool02?ooool001Gooooo00?o0000ooooooooool05_ooool3o`0000gooooo2?nX
`>/5ojO0k0KoVkW^1On>[^`6ohNWj@;oVkCY1_n]`^T3ol;AiPKobmOR0oo<e^86ol3Bi`;o]lcZ1_nN
^nd6oiZfk0;oX;WZ1_nU_N/6ojO0k003ojBmjonS_NcoXkg/00GoXkg/1_nT_N/00onY`N_oZ/;[oj[2
j`04oj[2j`KoYl3[00?oY[o/oj>mk?nS_N`01OnS_N`5ojRojP;oZl7Y2?n]`^T3ojO0j`?oYk_W2?nR
^NT3ojBlj`?oYko[1on/a>`2ojW2j`KoZ<3[1_nU_N/2ojRojP_oZl?[0_nZ`n`6ojS1j`CoZ/7[1?n^
a^/6ok?;k003ok;<kOnV`NgoY/7]00GoY/7]1_n>Z>L6ogjJh`KoQioS1OnQ^>T3ojk2j@?o`MKZ0_o0
fN`00ol0003o`=W/ol3Ik005okWAk0;o//g^1onX`N`2ojO0j`GoYko[3oooool00ol0003ooooooooo
o`07ooooo`005?ooool2o`0001Gooooo0ol0000Aooooo`OoZ<3[1_nW`>`6oi^ikPGoSZk/0on7YnT4
ohn]jPOo[L;Y00?o`]7Vol_Gh_o;en801?o;en86olcFhP03ol3Biongc>[o]lcZ00Co]lcZ1_nN^nd3
oiZfk0CoVkS/1onU_N/3ojO0k0?oYKk/2?nS_N`3ojBmj`?oYko[1onZ`^/2ojO0j`GoY[o/1onS_N`0
0onX_n[oZl7Yoj_1j@04oj_1j@Ko[L;Y00?o[KoWojNkionW^nL01OnW^nL6oj:ij@03ojFkjOnW_n_o
Yko[00GoYko[1On/a>`2oj[3k0SoZ<3[0onU_N/3ojJmj`WoZl?[1_nZ`n`6ojS1j`03oj[1jon^a^_o
[/K[00Go[/K[0_ncbn`5ok;<k@OoY/7]1_n>Z>L5ogjJh`OoQioS00?oXKSYojk2jOn^`^T01On^`^T0
0oo1e^[o`=W/ol3Ik002ol3Ik004o`000?o0fNco`=W/okWAk0Ko//g^1OnX`N`9ojNoj`kooooo00?o
0000ooooooooool01oooool001Cooooo00?o0000ooooooooool04_ooool2o`0001Gooooo1onX`>/6
ojO0k0?oVkW^0onA/^h5ohJZk@OoSjgZ1On]`^T3ok[9iPCobmOR1_o<e^82olSChPOo]lcZ0onN^nd3
oiVhk@OoVkS/1OnU_N/2ojNoj`KoYKk/1onS_N`7ojNoj`GoZ/;[0_nY`N/7ojJok0GoXkg/0_nS_^d7
oj_1j@;o[L;Y1On]_nL7ojNki`;oX[WY1OnU^nT7ojNoj`03ojc4k?nZ`ncoZ/?/00CoZ/?/1_nX`>/0
0onV_^_oY[g[ojJmj`05ojJmj`GoZl?[0_n[a>`8oj[3k0?oZ<7[1?nX`>/5ojk6j`;o/L_]1onbc>d3
ojK1k@?oUjoW1_n6Wn<4oh6Hh0;oOY[S0on7Wn<3oiF[iPOo[/;Y00?o^]7[ol3Ik?o0fN`01?o0fN`0
0ol0003o^mK]ok;=kP07ok;=kP03ojS1k?nW_n_oYko[00WoYko[00?oZ<7[ooooooooool03?ooool0
0ol0003oooooooooo`07ooooo`005?ooool00ol0003oooooooooo`0?ooooo`?o00006?ooool7ojS0
j`?oYl3/1?nS_^d5oi6bkPGoQZ[]1on?[NX00on]`^Wo^/WVok[9iP06ok[9iP03ol_Gh_o<e^;oc=KR
00Coc=KR1?o8dn85okO<jP;oZlG]1_nI^>d7oi^hk003ojFmjonW_n_oYko[00CoYko[1_nU_^`7oj>m
k0OoYko[00?oZ/;[ojW1jonY`N/01?nY`N/7ojJok003oj>mk?nS_^goXkk]00CoXkk]1On[`NT00on[
`^[o[KoWojfoi`06ojfoi`GoYk_W0_nW_>P6ojFkj@KoYko[0_nZaNd7oj[3k0;oZ<3[1OnV_^/7ojJm
j`03oj_3jon[a>coZlC/00CoZlC/1_nZ`n`00onY`^coZ<3[ojS0j`06ojS0j`03ojk6jonabngo/L_]
00Co/L_]1Onbc>d00on/a^goUjoWoiN_i`05oiN_i`KoQYoS1On1V>07oiF[iPCo[/;Y1?njdN/4ol3I
k004ok_FkOl0003o^mK]ok_Fk@Ko//g^00?oZ/C/ojNojonW_n/01onW_n/5ojS1j`gooooo00?o0000
ooooooooool01oooool001Cooooo00?o0000ooooooooool03?ooool3o`0001cooooo1onX`>/7oj>n
k@GoTK;^1On6Z^d5ohn]jP;oWkSY1onjbNH3olG>h@?oc=KR1oo8dn800ongc>[oZlG]oj_5k@04oj_5
k@KoVKS]0onK^>`4oijjk0OoYko[0onU_^`3ojBnk0OoXkg/1OnW_n/2ojW0jPOoZL7[0onV_n`4ojBo
k0OoXkk]00?oZl7Yoj_2j_n[`^X00on[`^X8ojfoi`03ojNkionW_>SoYkcX00CoYkcX1_nU^nT2ojNo
j`KoZ/G]1OnZ`n`2ojS0j`KoY[k[1_nV_N/2ojW2k0OoZlC/0_nZ`n`5ojW2k0KoZ<3[00?o[<C/ok7;
kOnabnd01_nabnd00onbc>go[<K]ojc6k@03ojc6k@OoUjoW1On6Wn<6oh6Hh0OoUJ_V00?o[/;Yok[A
jonjdN/01OnjdN/00oo0fNco^mK]ok_Fk@02ok_Fk@03o`000?nke^go^mK]00;o//g^1OnZa>`7ojNo
j`OoZ<7[3?ooool00ol0003oooooooooo`07ooooo`004oooool3o`0000[ooooo0ol0000Pooooo`Oo
Z<3[1onS_^d5oi6bkPGoQZ[]00?oSjgZoinhjOnO^>T01?nO^>T4ok[9iPKoaLkQ00?oc=KRolSCh_o8
dn801Oo8dn82ol?>h`OoZlG]0onI^>d4oiRhkPKoW[[/1OnW_n/00onW`>_oY;k/ojBnk005ojBnk0Oo
Xkg/00?oYko[ojW0j_nY`>X01?nY`>X5ojW1j`;oZ<3[1onT_n`5oj>nk@;oXl3]1_n[`^X6ojfoi`;o
Z/3Z1onW_>P3ojFkj@?oZ<C]2?nZaNd00onZ`ncoZ<3[ojS0j`04ojS0j`KoY[k[0_nV_N/6ojW2k0Go
ZlC/0_nZ`n`7ojW2k0;oZ<3[1On/a>`6ok7;k@03ok;=k_n/a^go[<K]00Go[<K]1onG[nL4ohJOh`Ko
PISP1_nEZnH00onR^NWo^]7[ok[Aj`05ok[Aj`;o`=[]1Onke^d00ol0003o]];^oj[4k007oj[4k0Oo
Yko[1onX`N/;ooooo`03o`000?oooooooooo00Oooooo000Dooooo`03o`000?oooooooooo00Kooooo
0ol0000Uooooo`KoZ<3[1OnS_^d00onJ^^ooRZo^ohZ_kP03ohZ_kPKoQJW/1onO^>T00onjbNKoaLkQ
olG>h@05olG>h@?obm7N1?o8dn85ol?>h`GoZlG]0onQ_^h6oiRhkPKoW[[/00?oYko[ojO0jonW`>/0
0onW`>/7ojBnk0?oXkg/1?nS_^`7ojW0jP03ojW1jonX`>_oZ<3[00CoZ<3[1onT_n`00onS_^goXl3]
oj?0k@04oj?0k@KoZl;Z0_n]_nL6oj[0jPGoYkcX0_nW`nh6ojS4k@KoZ/G]00?oZ<;/ojS0jonX`>/0
1_nX`>/3ojJnj`?oY[gZ2?nY`^`00on[a>coZ/?/oj[3k004oj[3k0GoZL;/0_nW`>/7ojc4k0;o/L_]
1OnbcNh7ojc6k@?oUjoW0on>X^84ohBGg@03ohJOhon1V>3oPISP00CoPISP0_nEZnH5oj:ij@Co^]7[
1Oo0f^d2ok_Fk@;o]];^00?o0000okKBk_nfd^h01_nZa>`00onW`>_oYko[ojNoj`06ojNoj`?oZ<7[
0onY`^`;ooooo`03o`000?oooooooooo00Oooooo000Dooooo`03o`000?oooooooooo00?ooooo0ol0
000Yooooo`KoZ<3[00?oXkk]oiZjkonJ^^l00onJ^^l5ohZ_kPKoQJW/1OnO^>T3ojk1j0GoaLkQ1_o;
dMh00oo8dn;o`lkSol?>h`05ol?>h`03oj_5kOnQ_^koXKk^00GoXKk^1_nH^>h3oijjk0?oX[c/1_nW
`>/5ojBnk0WoXkk/1OnY`>X2oj[1jPOoZ<3[1onT_n`7oj?0k@?oZl;Z0onX`nd8oj[0jP03ojNlj?nW
`nkoYl?^00CoYl?^1_nXa>d2oj[5k@GoZ<;/1_nX`>/8ojJmjPKoZL;/00?oZlC]oj[3k?nZ`n`01_nZ
`n`00onY`^coYl3[ojO0j`04ojO0j`Go[<C/0_n`c>h7ok;=kP?o[<K]0onM/nL7ohjRhPCoQ9OM1on=
X>47oj:ij@03ok[Ajoo0f^go`=[]00Co`=[]00?o_M[_okKBk_nfd^h00onfd^h00ol0003o]];^okKB
kP02oj[4k0GoYl3[1_nW_n/00onW`>_oZL;/ojW2k005ojW2k0_ooooo00?o0000ooooooooool01_oo
ool001?ooooo00Co0000oooooooooooooooo0ol0000]ooooo`?oZ<3[0onW`>`6oiZjk`GoRZo^1_n5
ZN`00onO^>Wo[/7Xojk1j005ojk1j0?oaLkQ1_o;dMh2olc@g0Ko`lkS0onnbn@7oj6nkP?oV;S^0_nI
^Nh7oj:lk0KoYl3[00?oY;k/oj>nk?nS_^`02onS_^`00onY`>[oZ/7Zoj[1jP04oj[1jPGoZ<3[0_nX
`>X7ojBok0GoXl3]0_nS_nh6ojS3k@KoZ/3Z0_nVa>h7ojO3kP?oZ<C]0onY`nd7ojS2k0;oZ<3[3?nV
_NX2ojW2k0GoZlC]1_nZ`n`00onY`^coYl3[ojO0j`06ojO0j`03ojc4k?n`c>ko/<c^00Co/<c^1Onb
cNh2ojg8k@KoWK?W1_n>X^85ohBGg@OoSJ3Q1OnR^NT3ok79k0?o`=[]1?nmf^l5okKBkP03o`000?n]
b>goYl3[00OoYl3[0_nW_n/5ojO0j`OoZL;/2_ooool00ol0003oooooooooo`06ooooo`004oooool4
o`00037ooooo1_nW`>`6oiZjk`GoRZo^0on5ZN`4ohb^k@Oo[/7X00?oaLkQol_Ag_o;dMh01?o;dMh4
olc@g0?o`lkS1_nnbn@5oj6nkP03oiblkonI^NkoVKW^00CoVKW^1onR_>`3ojO0j`?oY[o/2onS_^`3
oj>nk@OoZ/7Z00?oZ<3[ojS0j_nX`>X01?nX`>X7ojBok003oj?0kOnS_nkoXko^00CoXko^1_nX`nd2
oj[0jPKoY/C^1OnW`nh2ojO2k@KoZL?]1OnX`^`2ojNnjPcoY[gZ0_nY`nd7oj_4k@;oZ/?/1OnY`^`6
ojO0j`03oj_5kOn`c>ko/<c^00Ko/<c^00?o//g^ojg8kOn]b>d01?n]b>d5oifci`KoSZ;R1_n4Umd7
ohfPh@03oj:ijOnabNco/LW/00Go/LW/00?o`=[]okgJkonmf^l01?nmf^l2okKBkP?o[LS]00?o0000
ojg8kOnW`>/01OnW`>/00onW_n_oYl3[ojO0j`06ojO0j`?oZL;/0onX`N`:ooooo`03o`000?oooooo
oooo00Kooooo000Cooooo`;o0000=?ooool6ojO0k0?oV[[_0onA]^l6oh>/k`KoS:k]1On^`NP3okS6
i@?obm7N1oo<d=`00oo3c^?o_/_Tokk;i006okk;i003oj6nk_nL_>ooW;c_00?oW;c_1_nI^Nh5oj:l
k0;oY;k/1_nV_n`6oj>nk0SoXkk]1onZ`NX7ojS0jP?oY;o/1?nV_n`7oj>okP?oZ<?]0onT`Nh8ojK4
kP03ojO3k_nW`^goYl;]00CoYl;]1_nY`nd00onX`^coYkkZojNnjP04ojNnjPSoY[gZ1_nY`nd5oj_4
k@;oZL?/1onY`^`2ojO0j`GoZlG]1_n`c>h00onac^oo[LS]ojg8k@06ojg8k@GoWK?W1_n>X^86ohBG
g@?oSJ3Q0onM/^L7ok79k0;o_M[^1Onmf^l3okSEk`?o[LS]00?o0000ojg8kOn]b>d00_nW`>/5ojNo
j`KoYl3[00?oZL;/ojS1k?nX`N`01OnX`N`9ooooo`03o`000?oooooooooo00Kooooo0005o`0000?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo03;ooooo0onW`>`4ojBo
k0GoTKK_1_n3[>l6ohb^k@03ojk1j?nha^Go^<KU00Go^<KU00?obm7Nolc@g?o<d=`01Oo<d=`3ol[=
g0Ko_/_T0_nhanH6oiblk`KoVKW^00?oX[c/ojBnk?nT_^`01?nT_^`6ojJok0;oXkk/3?nS_^d7oj[1
jPGoZ<3Z0_nY_nX7ojJok0GoXko^0_nU_n`6ojC1kPKoY/C^00?oY/7]ojO2kOnW`^d01_nW`^d3ojW3
k@?oYkoZ1onW_^X3ojJmjPCoY/3/1onY`nd00on[a>goZL?/ojW3k004ojW3k0GoZL;/0_nW`>/7oj_5
k@;o/<c^1Onac^l6ojg8k@03oinbi_nBXn3oTZ?P00?oTZ?P1_n8V=`6ohZKg@OoWK;W1?nabN`5okgJ
kP03okgJkonheNoo^=G_00Go^=G_0on]b>d00ol0003oZ<7/ojS1k007ojNoj`;oYl3[1OnY`^`7ojS1
k0Sooooo00?o0000ooooooooool01_ooool00005oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Wooooo00?o0000ooooooooool0<oooool6ojBok0GoTKK_1_n3[>l3
ohb^k@?oVKK/1_nha^D3ol38h0Goc=3L1Oo:cM`2okk;i0Ko^<OV1_nL_>l3oiVikP?oVK[_1onT_^`7
ojJok0[oXkk]0onS_nd7oj[1jP03ojS0j_nY_n[oZKoZ00CoZKoZ1onV_n`00onS_nkoYKo/ojFok004
ojFok0KoY<7^0_nVa>h5ojK1k@KoYl;]2?nW_nX5ojNnjP;oY[kZ1onV`>`3ojW3k@?oZ/C]2?nY`n`0
0onY`^coYl3[ojO0j`04ojO0j`GoZlG]0on_cNl6ok7>k`;o[LS]1OnO/^H5oi:Sh0KoR9SL1_n:Vmd7
oifbi`03ok79k?nmf^ko_M[^00Co_M[^00?o_Mg`okSEkonheNl01OnheNl00on`c>koZ<7/ojS1k002
ojS1k003o`000?nX`NcoZ<7/00KoYko[2?nY`^`3ojS1k0?oYko[2?ooool00ol0003oooooooooo`06
ooooo`0000CooooooiRHV?lQ8B7ok^k^1?ooool01Ol@413ooooooooooooooooo410@00[ooooo00?o
0000ooooooooool0<oooool6ojBok0GoTKK_0on3[>l2ogn[l0OoVKK/0onha^D6ol38h0?oc=3L1Oo:
cM`3olS;g0Oo^<OV0onL_>l3oiVkk`KoVK[_1OnT_^`2ojFok0OoY[o/1OnS_^d8oj>ok@GoZ/7Z0_nY
`N/7ojVojP?oY[o/1?nW_^X7ojFok0?oY<7^0onV_n`7ojK1k@;oYl;]3?nW_nX00onW_^[oY[kZojJn
jP04ojJnjPGoY/3/0_nYa>d6oj[4k@KoZL?/00?oZ<7[ojO0jonW`>/01_nW`>/00on[aNgo[lg_ojo=
k`05ojo=k`?o/Lk_0on/a^d6oinbiPKoTZ?P1_n8V=`5ohZKg@KoWK;W0_n[a>/4okgJkPCo_Mg`1?nh
eNl4ok3<kPCoZ<7/00?o0000ojS1k?nX`N`01_nW_n/6ojW2k003ojS1k?nW_n_oYko[00GoYko[1ooo
ool00ol0003oooooooooo`06ooooo`000_ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooo
ooooooooool000002oooool2o`0003Cooooo0onT_n`3oinmkPGoRk;`1OmoZo07oiVfk003okS6iOo0
b>3o`<SP00Ko`<SP00?oc=3Lol[=g?o:cM`00oo:cM`5olS;g0Go^<OV0_nda>L6oiVkk`KoVK[_00?o
Y;k/ojFok?nU_n`01?nU_n`7ojJok003oj>nkOnS_ngoXko]00[oXko]00?oZ/7ZojW1jonY`N/01?nY
`N/5ojVojP03oj[0jOnW_^[oYkkZ00KoYkkZ1OnU_n`2ojNnjPKoY[o/1OnV`Nd2ojNnjP[oYkoZ1?nW
_NT7ojJnjP03ojK0k?nYa>goZLC]00CoZLC]1_nZa>d2ojW3k0GoZ<7[1_nW`>/00on[b>oo[lg_ojo=
k`05ojo=k`03ojo>l?n/a^go[<K]00Go[<K]1OnO/^H6oi:Sh0KoR9SL1_n:Vmd2oifbi`KoZlC[00?o
_M[^okgMl?nmgO001OnmgO000onheNoo/<c^ok3<kP05ok3<kP?oZ<7/00?o0000ojNojonW_n/01onW
_n/2ojW2k0GoZ<7/1onW_n/7ooooo`03o`000?oooooooooo00Gooooo0003ooooo`03ogMgMomVIVKo
oooo00;ooooo00Go0000ooooooooooooooooo`00000=ooooo`03o`000?oooooooooo03;ooooo1_nO
_Nh5oh^bl0GoOj_`1OnI]^`3ojFljPKo`<SP0oo5bM`3ol[=g0Oob<_L00?o^<OVokC4ionda>L01?nd
a>L6oiVkk`?oVK[_0onI^o07ojFok0OoY[o/3OnS_nd7ojW1j`03ojVoj_nZ`>WoZ/3Y00?oZ/3Y2?nW
_^X00onU_ncoYkkZojNnjP04ojNnjPKoY[o/00?oY/7]ojNnj_nW_^X01?nW_^X5ojNojP03ojNnjOnW
_NWoYkgY00KoYkgY1OnV_^X2ojS4kPOoZLC]0onZa>d3ojW3k0OoZ<7[0_nW`>/5oj_8k`Co[lg_1?n_
c_07ojc6k@GoWk;V1_nBXn06ohRHg0?oRY_M0onJ[^D6oj_4j`;o^][`1_nmgO02okOGl0Ko/<c^00?o
Z<;/ojNojonW_n/00_nW_n/00ol0003oYko[ojNoj`05ojNoj`SoZ<7/1onW_n/7ooooo`03o`000?oo
oooooooo00Gooooo0004ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413ooooooooo
o`0<ooooo`03o`000?oooooooooo03;ooooo1_nO_Nh5oh^bl0GoOj_`00?oVKK/ojFlj_nU_>X01OnU
_>X3ol38h0KoaLWL00?ob/gLolS;g?o8bm`01Oo8bm`2olK8f`Oo]<CW0onI^nl3oiRkl0KoVK_`1OnU
_n`2ojG0k@OoY[o/3OnS_nd5ojW1j`;oYl7]1_nZ`>T6ojNnjP03ojVojOnW_^[oYkkZ00KoYkkZ0onV
_n`3ojRmj@OoYkkZ00?oYkoZojNnjOnW_^T00onW_^T8ojNmj@03ojJnj_nXa>koZ<C^00CoZ<C^1OnY
a>d2ojW3k@KoZL?/1OnX`N/2ojS2k@OoZlS_00?o[lg_ojo>l?n_c_001On_c_03ojc6k@?oWZgR1OnE
XMd6ohbHf@KoRiWK1onJ[^D3oj_4j`Go^][`0_nmgO06okOGl0;o/<c^1OnX`^`4ojNoj`04o`000?nW
_n_oYko[ojNoj`coZ<7/1onW_n/6ooooo`03o`000?oooooooooo00Gooooo00001Ol0003o^[Zjoooo
oonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0?ooooo`03o`000?oooooooooo03;o
oooo0onO_Nh3oiZkk`KoQ[7a1On1[?07ojFljP03ol38h?o5bMcoaLWL00CoaLWL0_o8b=X6olS;g0Co
a/SK1Onda>L2ok72iPKoV;_`1_nI^o000onU_ncoYL3]ojG0k@04ojG0k@OoY[o/3OnS_nd00onY`N_o
Yl7]ojO1k@04ojO1k@KoZ/3Y0_nW_^X5ojVoj@KoYkkZ0_nY_nT6ojRmj@GoYkkZ0_nX_nX6ojNnj@Ko
YkgY00?oYlC^ojS4k_nXa>h01_nXa>h00onYa>goZL?]ojW3k@04ojW3k@KoZL?/00?oZ<7[ojS2kOnX
`^d01?nX`^d5oj_8k`?o[/ka1On_c_000onZ_nWoWZgRoij]hP05oij]hPGoUJ7M1_n<V=T6oh^If`Oo
VZkU00?oZlC[ok[Jl?njf_000onjf_03okcOl@Go]mO`00?o/<g_ojS2k?nX`^`01OnX`^`5ojNoj`03
o`000?nW_n_oZ<7/00[oZ<7/2_nW_n/5ooooo`03o`000?oooooooooo00Gooooo00001OnHV9So410@
o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0@ooooo`;o0000=?ooool5oiZk
k`KoQ[7a1On1[?05ojFljP;o[L7X1Oo5bM`4olS8fP?ob<_L1oo6b=/00onda>Oo/L;Vok72iP04ok72
iPKoV;_`0onI^o03oiRll@OoYL3]1onV_n`:oj>ok@?oXl3^1onW`Nd3oj[0j@?oZL;/1onY_nT2ojNn
jPKoZKoY1_nX_NT00onW_^[oZ;oZojRojP04ojRojPKoYkkY0_nW_NT5ojO4kPKoZ<C^00?oZ<C]ojW3
kOnY`nd01_nY`nd3ojW3k0CoYl3[1_nX`^d00on[b>oo[/kaojk>l@05ojk>l@03ojo>l?nZ_nWoZ[oY
00?oZ[oY1_nN[N86oiFQg@KoS9SI1On;VM/6oiZ^i@;oZ<;/0onjf_06okcOl@03okOGl?n`cNoo/<g_
00?o/<g_1onX`^`4ojNoj`03o`000?nW_n_oYko[00KoZ<7/00?oZ<;/ojNojonW_n/02onW_n/5oooo
o`03o`000?oooooooooo00Gooooo000Oooooo`03o`000?oooooooooo03;ooooo1OnJ^nl6ohJal@Go
PJc`00?oYKcZojg1j?n]`NP01?n]`NP3olG9g0Kob<SJ00?ob<_LolK8foo6b=/01Oo6b=/2olC5fPOo
/L;V1_nH^o06oiRll@GoYL3]0onT`Nh6ojJok0GoXko]0_nT_nd6oj?0kPGoYl7]0_nT`Nh6ojW2k0Go
ZKoY0_nY`^`8ojVoj@?oZ;gY0onX`N/7ojRojP?oYkkY1?nW`nh6ojO4kP;oZ<C^1OnXa>d6ojW3k@03
ojS0jonW`>_oYl3[00KoYl3[0onX`^d3ojc=l@Ko[/ka00?o[L__ojZojOnZ_nT01OnZ_nT5oij]hPKo
UJ7M1_n<V=T6oh^If`;oVZkU1_nX`^`00onjf_3o_=oaokcOl@04okcOl@03okKHlOn`cNoo/<g_00Go
/<g_0onX`^`8ojNoj`03o`000?nW_n_oYko[00;oZ<7/1OnX`^`=ojNoj`Cooooo00?o0000oooooooo
ool01Oooool0023ooooo00?o0000ooooooooool0<_ooool5oiZkk`?oQ[7a0_n1[o<6ohF`l@Oo[L7X
00?oaLWLolS8f_o8b=X01?o8b=X3olW7f0Goa/SK1?o4aMX5ok72iP;o/L3U1_nH^o06oiRll@03ojG0
kOnT`NkoY<7^00GoY<7^1_nV_n`00onS_ngoY;o]ojBok@04ojBok@KoXl3^00?oYl7]ojC1k_nT`Nh0
1?nT`Nh6ojW2k003ojVojOnY`^coZL;/00CoZL;/1_nY_nT00onX`ngoZ<7[ojS1j`05ojS1j`GoZ;oZ
0_nWa>h7ojO3kP?oYlC^1?nXa>h6ojS4k@;oZL?]1OnX`>/6ojO0j`03ojW9l?n/cO7o[<ga00Go[<ga
0_n^c_45ojg;k`OoZ[oY1OnN[N86oiFQg@KoS9SI0on;VM/3oi^^i@KoZ<;/0_nhfo84okcOl@Co]]Sa
1On`cNl2ojS2k0_oYko[00?o0000ojS1k?nX`^`01onX`^`=ojNoj`?ooooo00?o0000ooooooooool0
1Oooool0027ooooo00?o0000ooooooooool0<_ooool5oiBil@GoPJoc1_n5/?45ojg1j0;o//?V1Oo8
b=X5olW7f0?oa/SK1_o4aMX00ona`^Ko/L3Uok70i@04ok70i@KoV;_`0onH_?43oiRmlPSoY<7^0onV
_n`3ojO0k0OoY;o]1_nS`>h7ojC1kP?oZL;/0onU`^h7ojW2k0;oZKoY1OnX`nd7ojS1j`03ojRoj_nW
a>koYlC^00CoYlC^1OnW`nh2ojO4kPOoZ<C^0onXa>d3ojS1k0OoZ<3[0_nW`>/5ojW9l0Go[<ga0on]
c_46ojg;k`?oZ[oY0onLY]`5oiJMf@KoSiOG1_n?V]/7oi^^i@?oZ<;/1Onhfo800onlgo7o]]SaokKH
l@05okKHl@03ok3=konX`^coZ<;/00CoZ<;/2?nW_n/2ojS1k003o`000?nX`NcoZ<7/00KoZ<;/3OnW
_n/00onW`>_oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo000Rooooo`03o`000?oooooo
oooo03;ooooo1OnD^O45oh6_l`KoQK3a00?o[L7Xok;3i_nb`nH01?nb`nH3olS8fPOobLOH00?oa/SK
olC5f_o4aMX01?o4aMX2ol?2f@Oo/L3U0onH^o03oiVll0KoV;gb1_nT`Nh2oj71l0KoYl3/1OnT_nd2
ojFok0KoXl3^1OnT`Nh2oj?1kPKoYL;^1OnY`^`2ojG3kPOoZ<?]0onX`N/3ojK4kPSoYlC^00?oYl?^
ojO4k_nWa>h01?nWa>h5ojS4kPSoZ<7/1OnX`>/2ojO5k`OoZLW`00?o[<gaojg>lOn]c_401On]c_43
ojg;k`;oY;7Q1onLY]`5oiJMf@KoSiOG1_n?V]/7oi^^i@03ojS2k?nhfo;o^=_b00?o^=_b0_njh?<6
okKHl@03ojo<konX`^coZ<;/00KoZ<;/1_nW_n/4ojS1k003o`000?nX`NcoZ<7/00;oZ<;/3OnW_n/5
ojO0j`?ooooo00?o0000ooooooooool01?ooool002?ooooo0_l0000cooooo`GoU;Wa1On1[o<3ohF`
l@?oS;Ca1onb`nH00oo8b=[obLOHolW7f005olW7f0?obLGG0oo4aMX5ol?2f@Go/L3U0_nc_n<6oiVl
l0KoV;gb0_nT`Nh6oj71l0KoYl3/00?oY;o]ojFok?nU_n`01?nU_n`6oj?0kP03ojC1k_nS`NkoXl7^
00CoXl7^1_nU`^h00onY`^coYL?^ojG3kP04ojG3kPGoZ<?]0_nU`nh6ojK4kPKoYlC^00?oY/?^ojO4
k_nWa>h01_nWa>h00onXa>koZ<7/ojS1k00:ojS1k003ojS0jonWaNooYlG_00CoYlG_1OnYbO03oj_?
l`Go[Lka00?oZ[gXojBahOnT/N401?nT/N46oibVg0KoUYgI1On?UmL7ohnJf`?oVjkU1OnYaNh00onh
fo;o^^3cok[Pl`04ok[Pl`;o]]Sa1On_c>l6ojS2k0SoYko[0onX`N`00onX`^co0000ojS2k00=ojNo
j`SoYl3[0_ooool00ol0003oooooooooo`04ooooo`009Oooool00ol0003oooooooooo`0booooo`Co
T;Sb1Omm[o@6ohbdl@Go//?V0onf`n@5olW7f0GobLGG00?oa<GJol?2fOo3`]T01Oo3`]T00ona`>Go
/koSok>oh`04ok>oh`KoVKc`0onH_O84oiNnl`OoXL7`0onW`>`3ojO2k0OoYKo/0onS`>h4ojBok@Ko
Xl7^0onU`^h4ojC1kPKoYL?^00?oZ<?]ojG3k_nU`nh01?nU`nh6ojK4kP;oYlC^1OnV`nh6ojO4kP03
ojO1k?nX`NcoZ<7/00WoZ<7/0onW`nd7ojO5k`03ojW9l?n[co?oZloc00GoZloc00?o[LkaojZmj?nZ
_NP00onZ_NP6ojBah@GoW:KL1_nFWMT6ohnGe`?oSi[K0onN/^H7ojW5kP;o]]kd1Onjh?<3okCHlPKo
[lc_0_nX`^`:ojNoj`;oZ<7/1?nX`^`00ol0003oZ<;/ojNoj`0<ojNoj`KoYl3[00CoZ<7/oooooooo
oooo00001_ooool002Kooooo00?o0000ooooooooool0<_ooool4oi2hlPGoOJod1_n<]?400onb`nKo
]/?TokK3i005okK3i0?obLOH1_o9aML7ol?2f@;o`l3G1onc_n<3oiVll0CoW;c_1onG__<3oj71l0?o
WL7b1_nW`^`5ojFok0;oYl3/1onT_nd3oj?1kP?oY<3]1onT`Nh3ojG3kP?oYL;^1onU`nh3ojK4kPCo
Y/;^1_nV`nh2ojO4kPGoYl7/1_nX`N`00onW`^goYl?]ojO3k@05ojO3k@?oYlG_1?nYc_<6oj_?l`03
oj_7k_nZ_NSoZ[gX00CoZ[gX1onT/N45oibVg0KoUYgI0on?UmL2oi>Og0OoW[;V1?nYaNh5okKNm003
ok[Plondf?;o]=Sb00Go]=Sb0on_c>l2ojS1j`WoYko[1_nX`N`3ojS2k003o`000?nX`^coZ<;/00go
Yko[0_nW`>/5ojS1k003ooooool0003ooooo00Gooooo000Wooooo`03o`000?oooooooooo03;ooooo
1?n@^?85ogf_m0?oS;Ca1?n@^?47okK3i003olW7f?o9aMOobLGG00CobLGG0_o8`mH5ol?2f@Co`l3G
1Onc_n<3okJmg`KoW;c_0onG__<4oiJnl`KoWL7b1_nW`^`00onU_ncoYl3/ojO0k004ojO0k0GoY;o]
0_nV_n`6ojC0k@GoY<7^0_nU`Nd6ojG2kPGoYL?^0_nV`^d7ojK2kP?oY/?^2_nW`N`2ojS1k0GoYl;]
1OnW`nd2ojS=l`OoZLkc0_n[co<5oj_7kPKoZ[gX0onT/N43oi^OePGoUYWD1_nBV=H6oi>Og0OoW[;V
00?oZLG^okKNm?nfg_@01?nfg_@2okOOm0Ko]=Sb00?o[LW^ojS1jonX`N/01?nX`N/7ojNoj`SoZ<7/
0onX`^`00ol0003oYko[ojNoj`0:ojNoj`CoYl3[1_nX`N`00ol0003oooooooooo`04ooooo`00:?oo
ool2o`0003?ooooo1On=]o<5ogZ_m@KoT;Sa1Onf`n@2okS4h`GobLGG1?o8`mH3ol?2f@Ko`l3G00?o
/koSokJmgonf_Ml01Onf_Ml4oiblk`?oXKWY1_nF__<6oig1lP?oYl;/1?nTa?06ojO0k003ojBokOnV
_ncoY[o/00CoY[o/1_nT`>d00onT`NkoYL7]ojG1k@04ojG1k@KoYL;^00?oYL?^ojK2kOnV`^d01?nV
`^d5ojK2kP;oYl3/2onW`N`9ojO2k@03ojO3kOnXcO?oZ<gc00CoZ<gc1OnYc_<2oj_;l@OoZlO^0onZ
_NP2oinTf@OoVioF1OnFVM@6oi:HePKoTioL1OnN/^H3oj_=lP?o]]kd1Onggo@2okCHlPGo[LW^1_nX
`N/7ojNoj`OoZ<7/1?nW_n/00ol0003oYko[ojNoj`06ojNoj`SoYl3[0onX`N`2ooooo`03o`000?oo
oooooooo00Cooooo000Zooooo`03o`000?oooooooooo037ooooo1On=]o<5ogZ_m@KoT;Sa00?o]/?T
okS4honha><01?nha><3olW5e`Kob<?F00?o`l;Iol?0eoo3`=L01?o3`=L2olBme0So][gO00?oW;c_
oj6ijOnQ^NT01?nQ^NT6oiJnl`?oWL7b0onH`O@7ojC4l0?oYl3/0onW`nh7ojJok0?oY<3]0onV_n`7
ojG1k@?oYL;^1?nV`>`6ojK2k@03ojK2k_nW`>coYl3/00CoYl3/1onW`N`;ojO2k@?oYlgd1_nXcO<0
0onYc_?oZl_aoj_;l@04oj_;l@GoZlO^00?oXj[LoinTfOnOY=T01?nOY=T6oi^OePKoUYWD1OnBV=H7
oi>Og003oijbi_n[cO;oZlgb00GoZlgb00?o]]kdokOOm?nggo@00onggo@00onbeO;o[LW^ojg9kP06
ojg9kP?oZ<7[2_nW_n/7ojS1k0CoYko[00?o0000ojNojonW_n/01_nW_n/6ojO0j`Oooooo00?o0000
ooooooooool00oooool002_ooooo00?o0000ooooooooool0<Oooool5ohfgl`GoNZoe0on@^?43oi>j
lPOo^<CS00?obLGGolS3e_o8`mH01?o8`mH2olO2e@Go`l3G1?o4_M@6okJmg`;o^[_J1onQ^NT3oiJn
l`?oV;ga1_nH`O@5ojC4l0;oW/Cc1_nW`nh5ojJok0;oYl?]1_nV_n`5ojG1k@;oYl3/1onV`>`3ojK2
k@?oYl3[1onW`>`3ojO1k0CoYl?]1onW`^d7ojO=m0OoZ<gc1_n[bo400on[ankoXj[Loj>Zg003oj>Z
g0KoWjCI1OnKWmH6oiJIe0KoTYSF0onCWm`4oj:ij@KoZlgb0oneh_H00onggoCo/]Gbok;ElP03ok;E
lPKo[LW^00?oYl3[ojNojonW_n/02_nW_n/00onX`^coZ<7/ojS1k006ojS1k0?oYko[00?o0000ojNo
jonW_n/01onW_n/2ojO0j`[ooooo00?o0000ooooooooool00oooool002cooooo00?o0000oooooooo
ool0<Oooool5oh^gl`GoN;3f1_nC^_85okS4h`;o^<?S1Oo8`mH4olO2e@?o`l3G1_o4_M@2okJmg`Ko
^[_J1OnQ^NT2oj^hh`KoV;ga1_nH`O@00onTa?3oW/Ccoik4l`04oik4l`KoYl?^00?oY[o/ojO3kOnW
`nd01?nW`nd6ojJok003ojG1kOnW`>coYl3/00CoYl3/1OnV`>`00onW`^goYl3[ojO0j`05ojO0j`Go
Yl3/0_nWaNl7ojO3k@?oYl;]1?nUc?@6ojO=m0SoZ<gc0on[bo42ojNag`OoXj[L1OnOY=T6oi^OePKo
UYWD0onBV=H3oi^Zh@OoX[WY0_n[cO85okGRmP03ok?LmOnbeO;o/]Gb00Go/]Gb0_n]bNh5ojO0j`So
Yko[1OnX`^`6ojS1k0GoYko[00?o0000ojNojonW_n/01OnW_n/=ooooo`03o`000?oooooooooo00?o
oooo000]ooooo`;o0000<_ooool5oh^gl`GoN;3f1_nC^_800onha>?o^<?SokS3h`04okS3h`?ob<?F
1_o7`]D00oo3`=Ooa;gDolBme004olBme003olBld_nj^m[o^[_J00Oo^[_J00?oXKWYoj^hhon[^><0
1?n[^><6oiRml@?oV<7d0onG`O@7oik4l`?oYl?^0_nQa_88ojO3k@?oY[o/0onWa>h7ojO0k003ojK0
k?nW`^goYl;]00?oYl;]1onW`>/00onW`>coYlG_ojO5k`04ojO5k`GoYl?]00?oY<cdojG<m?nUc?@0
1_nUc?@6ojO=m0KoZ<gc00?oZ;GRojNagonW/Ml01?nW/Ml6oj>Zg0KoWjCI0onKWmH2oiNId`KoUYkI
1onKZ^45oj:ij@;o[mWf1?neh_H4ok?Lm@Go/]Gb0_nZa>d7ojO0j`?oYko[1?nW`>/6ojS2k0;oZ<7/
2OnW_n/01?l0003oYko[ojNojonW_n/@ooooo`03o`000?oooooooooo00?ooooo000_ooooo`03o`00
0?oooooooooo033ooooo1On;]o<5ogR`mP?oTk[b0onB^o<7okS3h`03olS3e_o7`]Goal;E00Coal;E
0_o6`]H5olBme0?oa;cB1onj^mX2okbhePOoZkSS0onH_O43oijik0KoUl7d0onNa?<3oiW4m@KoXLKb
1_nW`nd00onRao?oYlC^ojO4kP05ojO4kP?oYl3/0onVao07ojO2k@?oYl3[1?nVb?47ojO5k`03ojO3
kOnTc?CoY<cd00?oY<cd2?nUc?@6ojO=m0;oZ<gc1OnX]N85ojNag`OoXj[L0onOY=T2oiZIdPKoUiWC
1_nFW]T7oi^Zh@03oj:ijOn_fOKo[mWf00Co[mWf00?o]N;fok?LmOncg?D01Oncg?D00onbeO;oZ/C]
oj[4k@04oj[4k@GoYl3[00?oYko[ojO0jonW`>/01_nW`>/3ojS2k0;oZ<7[2onW_n/00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo00?ooooo000`ooooo`03o`000?oooooooooo037ooooo1?n;
^?@5ogNam`KoT[_c1Onh`n<2okK3i0Goal;E1?o6`]H3olBme0Goa;cB1?nj^mX5okbhePGoZkSS0_nc
]m/6oijik0?oUl7d0onJ__46oiW4m@KoXLKb0_nW`nd5oj;7l`GoYlC^0_nQb?@6ojK7l0GoYl;]0_nS
b_@7ojK8l@?oYlG_1?nSc?D6ojC<m0SoYLcd0onWcO@3ojRgi0KoZ;GR1_nW/Ml3oj>Zg0?oWYcB1_nJ
VM86oiNId`GoUYkI1_nKZ^42ojK7l@Go[mWf0ondh_H5ok?Lm@;o[lk`1onZa>d00onW`>_oYko[ojNo
j`03ojNoj`KoYl3[00?oZ<;/ojS1jonX`N/01?nX`N/6ojNoj`Gooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`03ooooo`00<Oooool00ol0003oooooooooo`0aooooo`CoRkSd1Omg/OL6
oi:kl`03okS3honf`nCo]/?T00Co]/?T0oo7`]D6olK2eP03olBme?o4_=;oa;cB00Goa;cB00?o^[_J
okbhe_nl^=H01_nl^=H00on[^>?o/kOKok>gf`04ok>gf`CoW[W/0_nY]>46oiZnl@KoVLCe0onQa_84
oi[6mPKoX/Oc00?oYlC^oj78m?nQb?@01?nQb?@6ojK7l003ojO2kOnSb_CoXl[d00CoXl[d1OnVb?43
oj7<mPKoXlce0onTc?@4ojC;m0GoYLcd2?nX]n@6ojRehP?oYk7O0_nQWm87oijLdPKoVYWB1OnGVM<6
oiJNf@;oVj[Q1_nVao400on_fOKo]>;fokCRmP05okCRmP03ok?LmOn_c_3o[lk`00Co[lk`0onZa>d:
ojNoj`;oYl3[1OnX`^`6ojS1j`;oYko[2Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo00?ooooo000booooo`;o0000<_ooool4oh^hm0GoMk7g0onB^o<3ohjlm@Oo]/?T00?oal;EolK2
e_o6`]H01?o6`]H00oo3`]Woa;cBolBldP05olBldP;oa;_A1onl^=H00ono]]7o/kOKok>gf`06ok>g
f`03oijik?nY]>7oZKCQ00?oZKCQ1_nJ__43oiW4m@CoVL7c1_nJa_H3oj;7l`CoVlOf1_nQb?@3ojK7
l0CoW/Wf1_nSb_@00onVb?7oXLcfoj7<mP05oj7<mP?oXlce1?nSbO<6ojC;m003ojG<m?nX]nCoZ;OT
00[oZ;OT0onX]N82oj>Qd`KoXIoB1_nNW=86oiZIdPKoUiWC0onFW]T4oj:hj0GoY/Oa0_n_h_P6okCR
mP;o/=Sd1On_c_02ojS1j`_oYko[00?oYl7/ojS2k?nX`^`01_nX`^`3ojS1j`kooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`02ooooo`00=?ooool00ol0003oooooooooo`0`ooooo`Go
S;Sd1Omg/_L5ohjlm@Go]/?T0_nba>L5olK2eP?o`l;I1Oo4_=84olBkd@Co_;SF1?no]]46ok>gf`03
okVce?nY]>7oZKCQ00GoZKCQ0onJ__44oj>di@KoVL7c0onJa_H4oi_2l`KoVlOf0onQb?@4oic8mPKo
W/Wf0onSb_@4oio:mPGoXLcf0_nSa?47oj?9l`?oY<_d0onW]>8;ojRgi003ojFSdonSXM?oXj7C00Co
Xj7C1_nQWm85oijLdPOoVYWB0onGVM<2oij]hPSoX[SX00?oY/OaojoRn?n_h_P01?n_h_P2okCRmPKo
/=Sd00?o[lk`ojS1jonX`N/01?nX`N/7ojNoj`GoYl7/1_nX`^`Booooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool00_ooool003Gooooo00?o0000ooooooooool0<?ooool6ohbhm0CoMk;g
1On>_?D00onf`nCo//CWok;4i`04ok;4i`?oa/;F1Oo3`]T3olBldPKoa;_A00?o_;SFoknfdOno]]40
1?no]]44ok>gf`Co^K?D1OnY]>42okBbe`OoXkCU0onI`O<4oj:fi`KoVl;c0onKaoH4oig2lPKoW<Sf
0onNbOH4oio6m0KoWl[f00?oXLcfoj?4lOnSa?401?nSa?45oj?9l`03ojN`gonW]>;oYkCR00GoYkCR
1onX]n@5ojFSd`KoXj7C1OnQWm86oijLdP?oVYWB0onLY=/6oij]hPKoX[SX0_nZf_P5ojoRn0Co/=gg
0on`f?@2oj_5k@SoZ<7[1_nW_n/6ojO1k0;oZ<;/5_ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00;ooooo000fooooo`03o`000?oooooooooo033ooooo0on<^?@3ohnjl`GoN;Ch1?n7
^oL7ok;4i`03olK2e_o3`]Wo`l;I00Go`l;I00?oa;cBolBkdOo4^m401?o4^m400oo4_M?o_kKAoknf
d@06oknfd@03ok>gfoni/mCo^K?D00Go^K?D00?oZKCQokBbeond/]L01?nd/]L5oj>di@;o[k3I1onR
]^L3oi_2l`?oXkCU1onM`_83oic8mPCoXKc/1_nOa_@3oio:mPCoY;_Z1_nSa?400onSbO?oYk3OojN`
g`03ojN`g`OoYkCR0onX]n@2ojJSd`KoYJ?C1_nSXM<6oj6OdP?oWYcB0_nMWmH7oibTf`KoWZgR0_nR
^>P6oj[Jn003ojoRn?n`gOOo/=gg00Co/=gg00?o[/kaoj_5kOn[aNd01?n[aNd6ojS1j`SoYko[0onW
`N`Kooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00_ooool003Oooooo0_l0000a
ooooo`KoSk[c1Omh]?P4ohNkm`Go//CW0_n]a^`6ol?2f@;o_l?M1Oo4^m43olBmd`Ko_kKA00?o`KK@
okVce?ni/m@01Oni/m@00onl//oo];;GokBbe`06okBbe`03oj>diOn_/=Wo[k3I00Co[k3I1OnR]^L0
0on^[mSoXkCUoj>di@05oj>di@GoWL;b0_nU/=l7oj6lk0?oWlKd0_nV/^48ojBkjP?oXlCa0_nW[=X6
ojN`g`KoYkCR00?oYj?BojJSdonVXm<01?nVXm<5ojFSd`OoXj7C0onQWm82oinMdPKoWIoF1_nLY=/5
oij]hP?oYLgd1OnZf_P3ojoRn0;o/=gg1On^c_46oj_5k@;oZ<7[2_nW_n/Pooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool00_ooool003Wooooo00?o0000ooooooooool0;oooool6ohnj
l`GoN;Ch1?n7^oL00onba>Oo[LK/ojg6k004ojg6k0?o`l;I1Ono`md3olBkd@Goa;gC0ono]]44ol6f
d0Go^K?D0onl//l6okBbe`03okR^d?n_/=Wo[k3I00Ko[k3I00?oX[KWojj_f?n^[mP00on^[mP7oj>d
i@03oig2l_nU/=ooYK3O00CoYK3O1OnQ_>`00onZ[=SoY[;QojJbh@04ojJbh@KoY;_Z00?oZZWFojN/
f_nW[=X01?nW[=X6ojN`g`;oYkCR1OnWXm85ojJSd`KoYJ?C0onSXM<3oj6Ld0KoWigB1_nMWmH6oibT
f`03oij]h_nUcOCoYLgd00GoYLgd00?oZ][hojoRn?n_h_P00on_h_P2ojkFm@Oo[/ka0on[aNd;ojNo
jb?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`02ooooo`00>_ooool00ol0003o
ooooooooo`0_ooooo`?oSk[c1?nC^o85ogZfn0CoOK[j1_n]a^`00oo3`]Wo_l?Moko3g@05oko3g@03
olBkdOo4_M?oa;gC00Goa;gC00?o_kKAol6fd?o1]]001?o1]]03okVce0Go_;;?0ond/]L4okR^d0Ko
[k3I00?o]Jc@ojj_f?n^[mP01On^[mP5oj>di@;o[ZgF1onU/=l00onQ_>coZZcHojZ/f003ojZ/f0Ko
Y[;Q0_nT^nX5ojZYePKoYjcJ0onW/=l2ojRRd0OoYj?B1_nVXm<3ojFSd`;oXig?1onQW=06oinMdPKo
WIoF0onLY=/3ojC1kPKoYLgd0onZhoX00on_h_So[]KeojkFm@04ojkFm@Go[/ka00?oZ<3[ojNojonW
_n/02?nW_n/Xooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00_ooool003_ooooo
00?o0000ooooooooool0<?ooool6oi>klPGoN[Kh1Omm^_X2ojg6k0?oY<Kb1_no`md00onga>Coa;gC
olBmd`05olBmd`03ol70fOo1]]3o`KK@00Ko`KK@00?o^K?Dokbbconl//l01Onl//l00ond/]Oo^:k@
okR^d004okR^d0?o[k3I1?ne[=07ojj_f003oj>diOn^[MKo[ZgF00Co[ZgF1OnU/=l00on_ZM7oZZcH
ojZ/f004ojZ/f0GoY[;Q00?o[:KAojZYe_nZZMH01OnZZMH5ojN/fP03ojZRc_nXX]3oZ:;@00CoZ:;@
1_nWXm85ojJSd`03ojFNc_nSWLooXig?00CoXig?1_nQW=06oinMdPGoWIoF00?oXkWXojC1k_nT`Nh0
1OnT`Nh2ojG=m0GoZ^?j0_n/f_P7ojkFm@03ojk>lOnX`>_oZ<3[00?oZ<3[1OnW_n/]ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool00Oooool003cooooo00?o0000ooooooooool0<?oo
ool3oi>klP?oVKc`1Omo^?P5ogFgnPGoY<Kb0ono`md4okO4i0Goa;gC0oo1`=T6ol6fd003ol:jdonl
//oo_;;?00Go_;;?00?o_kC?okR^d?nh[]001_nh[]000on_/=Wo]Jc@okF/d004okF/d0Go[ZoH00?o
/j[?ojj]e_n^[MH01_n^[MH00onU/=oo[jWAojnYd@03ojnYd@KoZZcH00?oY[;QojbVdOn/Y]400on/
Y]47ojZYeP03ojN/f_nZX/koZZ;>00?oZZ;>1_nXX]06ojNSdP03ojJSdonUW/koYIk>00?oYIk>1_nS
WLl5oj6Ld0OoWigB00?oWIoFoj>ij?nS^NP00onS^NP5ojC1kPCoY^7k00?oZ^?jojcJn?n/f_P01?n/
f_P3ojkFm@CoZL?/1_nX`>/00onW_n_oooooooooo`0_ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool00Oooool003gooooo0_l0000aooooo`KoVKc`1Omo^?P5ogFgnPGoY<Kb00?o_l?M
okO4i?nga>@01?nga>@3olBmd`Go`L3I0oo1]]04ol:jd`Go_;;?0ono]<l6okR^d003okb`c_ne[=3o
]Jc@00Ko]Jc@00?o[ZoHok>ZconcZ/l00oncZ/l6ojj]eP03ok:WcOn_ZM7o[jWA00Co[jWA1OnZ[=P0
0on_YLko[:KAojbVd@05ojbVd@GoZZWF00?o[:;=ojZRc_nZX/h01OnZX/h6ojRRd0?oYj?B0_nWWlh7
ojFNcPGoXig?1_nQW=03oinMdP?oY;CT1onS^NP00onT`NkoY^7kojKQn`04ojKQn`;oZ]ki1On/f_P2
oj_8k`OoZL?/0onX`>/dooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00Oooool0
03oooooo00?o0000ooooooooool0;oooool6oiVll0GoOkSh1Ome]oX2ojC6lPCoU<Gh1_nga>@00oo4
_M?o`L3Iol70f@05ol70f@03ol6fd?o2^]?o`[[C00Co`[[C0onl//l5okndc`?o^:k@1?nl/<h6okF/
d003okZ^cOncZ/oo/j[?00Go/j[?0on^[MH4ok:Wc@Ko[jWA00?oZZcHojnUc_n_YLh00on_YLh7ojbV
d@03ojZYe_n/X/go[:;=00?o[:;=1_nZX/h5ojRRd003ojZRconWWlkoYio>00CoYio>1_nUW/h6oj>M
c`?oXIc@0onT/N86ojBdi0GoXkWX1?nTg?/00onVhO_oZ]kioj[Nn@04oj[Nn@03ojcJn?n[b>ooZlS_
00CoZlS_1OnY`n`iooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00Oooool0043o
oooo00?o0000ooooooooool0;oooool3oiVll0CoWkk^1On7^_L5og:gn`KoU<Gh0_nga>@3ojk9kPKo
`L3I00?o^LCSol:jdoo2^]<01_o2^]<00onl//oo_kC?okndc`05okndc`03okR^d?nl/<ko_;3>00Co
_;3>1?ne[=03okZ^c@Oo/j[?00?o[ZgFok:WcOnbYld00onbYld5ojnYd@03ok:WcOn_YLko[jG>00Go
[jG>1On/Y]400on_Y<go[:;=ojbRc@05ojbRc@KoZZ;>00?oZ:;@ojZRconZX/l00onZX/l6ojNOcPKo
YIk>0onSWLl2ojF`g`OoY;7R1_nT]>@00onS^NSoY=ckojCLn`04ojCLn`;oYn3k1OnZg_T2oj_=lPOo
ZlS_00?oZL?/ooooooooool0>oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo007o
oooo0011ooooo`03o`000?oooooooooo02oooooo1onO_^h5ohNjm`GoL[Ok0onDaOP3ogk0o0Go[/W^
0oo1`=T4okW4h`Ko`[[C00?o_/3Kokndcono]<l01Ono]<l00ono_MOo_;3>okb`cP05okb`cP?o]Jc@
1Onj[/d5ok>Zc`03okR]c_nbYlgo/ZO=00Co/ZO=0on_ZM44ok:Wc@Ko[jG>0on/Y]44ojnTc@Ko[:;=
1OnZX/h00on]Y]7oZZ;?ojZRc`04ojZRc`KoYio>1OnUW/h00onW/MooYK3OojF`g`04ojF`g`OoY;7R
0onT]>@4oj;FnP;oY=ck1_nWh?/00onZg_WoZlgboj_=lP04oj_=lP?oZlS_@Oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo007ooooo0012ooooo`;o0000<?ooool5oinnkP;oYKo/1_n?
^o@5ogNhnPGoO/3l1On^bNh00oo1`=Wo^LCSokW4h`04okW4h`?o`[[C1?nn`=/5okndc`?o_kgG1onl
/<h00one[=3o^Zk=okZ^c@04okZ^c@?o/j[?1?nh[Lh6ok:Wc@03ojnYdOnbYlgo/ZO=00Co/ZO=1_n_
YLh00on/Y]7o[jC=ojnTc@04ojnTc@Ko[:;=00?oZZ;>ojfVdOn]Y]400on]Y]46ojZRc`KoYio>00?o
YIk>ojNagonW/Ml00onW/Ml6ojF`g`GoY;7R0_nSd_P5oj;FnPCoXn7l0onWh?/3oj[Am@GoZlgbA_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo007ooooo0014ooooo`03o`000?oooooo
oooo02kooooo00?oWkk^ojFok?nU_n`01?nU_n`6ohnkm0GoMkSj1Omn`?`2ojk9kPCoVl[h1_nia><0
0oo2^]?o_/3Kokk0f`04okk0f`?o_kC?1Ono_ML5okb`cP03okjje_nj[/go^Zk=00Ko^Zk=00?o/j[?
okR]c_nh[Lh00onh[Lh5ok:Wc@03okN_dOnbYlgo/ZO=00Go/ZO=1On_YLh00oncZ]3o[jC=ojnTc@05
ojnTc@Go[:;=00?o[jcDojfVdOn]Y]401On]Y]45ojZRc`GoYio>00?oZK?OojNagonW/Ml01?nW/Ml7
ojF`g`03ojBah_nSd_SoXm;h00CoXm;h00?oX]Kjoj?Qo?nShO`01?nShO`2ojODm`KoZ]7e00?oZlgb
ooooooooool0B?ooool00ol0003oooooooooo`07ooooo`7o00000Oooool1ooooo`00AOooool00ol0
003oooooooooo`0_ooooo`KoYKo/0on?^o@4oiVml0GoPKci1Omb^o`5oi_:n0?o^LCS0on/c?07okk0
f`03okndcono_MOo_kgG00Co_kgG0onl/<h4okjjePKo^Zk=00?o_;[GokR]c_nh[Lh01?nh[Lh3ok:W
c@Co]joA1onbYld00on_YLko/j[@ok>Zd003ok>Zd0Oo[jC=00?o[:;=ojn/e?n_[=@00on_[=@6ojfV
d@KoZZ;?00?oYio>ojVcgonY/ml00onY/ml6ojNag`?oYK3O1OnSd?L3oj?Bn0CoW^7m0_nShO`6ojOD
m`?oZ]7eC_ooool00ol0003oooooooooo`06ooooo`7o00000Oooool1ooooo`00A_ooool00ol0003o
ooooooooo`0`ooooo`;oYKo/0onW`>/7oiVml0GoPKci1Omb^o`2oi_:n0?oO/Gn1_n/c?05okk0f`;o
/lSZ1ono_ML00onl/<ko_[[FokjjeP04okjjeP?o^Zk=1?nl^]L6okR]cP03ok:WcOng[m7o]joA00Co
]joA1OnbYld00onf]=Oo/j[@ok>Zd005ok>Zd0Go[jC=00?o/[CJojn/e?n_[=@01?n_[=@7ojfVd@?o
ZZ;?0_n[]n86ojVcg`GoYk7O2?nSd?L2oi_Po@GoW^7m0onUe_T5ojODme;ooooo00?o0000oooooooo
ool01_ooool1o`00007ooooo0Oooool004Oooooo0_l0000aooooo`GoYl3[1OnI_O02oj>nk@KoSK_e
1Omf^o`4ogk5oPKo[<c`00?o_/3Kok?8j_ncb>X01?ncb>X5oknme`;o]LGV1onn^]H00onj[/go_;[G
okbje`03okbje`Go^:g>00?o^K_KokN_dOng[m401Ong[m43ok:Wc@Co][CG1_ncZ]03ojnTc@Co/[CJ
1On_[=@6ojfVd@03ojbliOn[]n;oZkOR00CoZkOR1_nY/ml00onW/MooXm3goj?@m`06oj?@m`KoVn3m
00?oW^7mojGFnOnUe_T01OnUe_T00onWe?Ooooooooooo`1Dooooo`03o`000?oooooooooo00Gooooo
0Ol00001ooooo`7ooooo0019ooooo`03o`000?oooooooooo02oooooo1OnW`>/00onI_O3oXkk]oj>n
k@04oj>nk@KoSK_e1Omf^o`4ogk5oP?o[<c`1?nAc?`6ok?8jP03oknmeoneaNKo]LGV00Co]LGV1Onn
^]H2okC5iPKo_;[G00?o^:g>okVkfoni^m/00oni^m/7okN_d@03ok:WcOnf]=Oo][CG00Co][CG1_nc
Z]000on_Y<go/[CJok:dfP03ok:dfPKo[jcD0_n]Y]45ojbli@KoZkOR0onY/ml5oj?Bn0?oXm3g1?nH
goh3oi_Po@GoXmKj0onUe_UJooooo`03o`000?oooooooooo00Cooooo0Ol00001ooooo`7ooooo001:
ooooo`03o`000?oooooooooo02oooooo0_nW`>/4ojS0j`KoXkk]0on=^oD4oiZml0GoQ;kj1Omb_Od5
oi7<o0?o/lSZ1?nLd?X6okG5iP03okjje_ndaNKo]<GV00Co]<GV1?nl^]L00onban[o^K_KokVkf`05
okVkf`Go]joA0_nd_n86okJde`Go/j[@00?o/KgSok:df_nb]=X01?nb]=X5ojn/e0;oZlC/1on/_>D3
oj^ghPCoX=Kk1OnSd_P2oiGMoPGoV=on0onQe_X5oj?FnUoooooo00?o0000ooooooooool00oooool1
o`00007ooooo0Oooool004_ooooo00?o0000ooooooooool0;oooool6ojS0j`?oXkk]0onW`>/7oiZm
l0GoQ;kj0_mb_Od4ogboo0GoM/?n1_nLd?X3okG5iP?oXM;i1ondaNH00onl^]Oo//OZok;7jP02ok;7
jPOo^K_K00?o]joAokBoh_nd_n801?nd_n86okJde`03ok>Zd?na_N?o/KgS00?o/KgS1_nb]=X00on_
[=CoZlC/oj_4k004oj_4k0Go[;cU0onKf_d6oj3Fn`03oj?Bn?nEgOkoUMgn00CoUMgn00?oV=onoj7F
n_nQe_X01OnQe_X00onSe_[oooooooooo`1Pooooo`03o`000?oooooooooo00?ooooo0Ol00001oooo
o`7ooooo001<ooooo`;o0000<?ooool6ojS0j`KoYl3[1OnJ_O02ojBnk0GoT[cd1_ml_o`5ogK3oP?o
W=3j1?mib?l5oj7Bn@Go]<GV00?oWmCjok;7j_nbanX01?nbanX5okVkf`;o[<ga1ond_n83okJde`;o
[LW^1ona_N<3ok:dfPCoZ<kc1_n[a>`00on/_>GoVm[moi_Jo@05oi_Jo@?oX=Kk1?nBfoh3oiGMoPGo
WmCj0onQe_YVooooo`03o`000?oooooooooo00?ooooo0Ol00001ooooo`00C_ooool00ol0003ooooo
ooooo`0^ooooo`KoZ<3[1_nW`>/00onJ_O3oY;k/ojBnk004ojBnk0GoT[cd0oml_o`4ohfnm`KoNL7m
1Omib?l5oj7Bn@03okC5i_nOe?[oWmCj00?oWmCj1_nbanX00oni^m_o[<gaojc=l@04ojc=l@Go];oR
00?oX]Gjojg9k_n]bNh01?n]bNh5ok6mh`?oWmOk1_nXc_<3oj_4k0GoT][n0onKf_d4oi3Io`?oT]_n
1?nNd_X5oioDnV_ooooo00?o0000ooooooooool00_ooool1o`00007ooooo001?ooooo`03o`000?oo
oooooooo02oooooo1OnX`>/3ojO0j`CoZ<3[1_nT_^`2oi:lm0CoX;k^1_n=__L3ogW1o@CoS<3h1Omi
`oh5og_;o`GoWmCj0onbanX4oiKEo@Ko[<ga00?o];oRoj;En_nReOX00onReOX6ojg9kP03ok6mhonO
eo_oWmOk00GoWmOk0onXc_<5oh[Io`?oT][n1?n@e_h3oi3Io`CoW/kh1_nNd_X00onOe?[ooooooooo
o`1]ooooo`05o`000?ooooooooooooooool000000Oooool0053ooooo00?o0000ooooooooool0;ooo
ool2ojS0j`?oZ<7/1onX`>/3ojBnk0CoYl3[1OnP_^h3ohfnm`CoWKk_1_n<`?P5ogW3oP;oNl_o1?ml
aOh6og_<o`GoU]Gm0on/cO45ohSDo`CoX]Gj0on]bNh5ohgHo`?oWmOk1On6eOl3oh[Io`?oT];n1On@
e_h3oio:mPKoW/kh0onNd_Ybooooo`05o`000?ooooooooooooooool000000Oooool0057ooooo0_l0
000`ooooo`GoZ<7/1onX`>/7ojO0j`;oX;k^1?nW_n/6oifnk`?oS<3h1?nL__05ohg2n@GoO<Gn0omk
c?l4oh;7oPKoO<co0on8e?l3oh7<o`KoPM;o0on=f?l5ohO@o`?oQ]Go0onEc_/6oi;BoP03oi3Fo_nO
b_KoWl[f00GoWl[f0onNc_Qhooooo`04o`000?ooooooooooo`00007ooooo001Cooooo`03o`000?oo
oooooooo02kooooo1OnX`N`7ojS0j`GoYl3[00?oZ<3[ojNojonW_n/01OnW_n/3oifnk`?oY[o[1onL
__02ohg2n@CoWKk`1_nA`_P5oh;7oP?oO<co1?n<bO`5oh7<o`?oPM;o1On>cOd3ohO@o`?oVLSg1_nE
c_/3oi;BoPCoX<Gb1OnOb_Imooooo`03o`000?oooooo0000007ooooo001Dooooo`03o`000?oooooo
oooo02kooooo0_nX`N`4ojK1k0KoZ<3[00?oYl3[ojS0jonX`>/00onX`>/5ojNoj`;oZ<3[1_nV_n/5
oibnl003ojJojonM__3oWKk`00GoWKk`0onA`_P3oj6nkPKoU/;e0on<bO`4oic0l@KoULKh0on>cOd3
oik1l@KoVLSg0onEc_/4oj;1k`KoX<Gb00?oWl[fooooooooool0O_ooool00ol0003oooooo`000001
ooooo`00EOooool00ol0003oooooooooo`0^ooooo`KoY/7/0onX`>/4ojO1k0GoZ<3[00?oYko[ojS0
jonX`>/01?nX`>/6ojJoj`03oibnl?nV_n_oY[o[00?oY[o[1OnM__02ojNoj`KoXKk^1?nF`_D2ojBo
k0OoW<3a0onEa_P2ojBok@OoW/7a0onIb?L4ojFok0KoX/7_0onPaO:4ooooo`7o00000Oooool1o`00
0000E_ooool2o`0002oooooo0onV`N`3ojK0k0OoYl7/0_nX`>/4ojS1k0KoZ<3[0onV_n/4ojS0j`Go
Y[o[00?oWKk`ojNojonW_n/01?nW_n/6oj6nkP03oiK2mOnT_ncoY;o/00?oY;o/1OnL`?42ojJoj`Go
Y;o]1OnN`O42ojNoj`OoYKo/0onR`Nn:ooooo`;o0000001Hooooo`03o`000?oooooooooo02gooooo
1_nV`>`5ojO1k0;oY/3/1_nX`N`3ojS0j`?oZ<7/1onX`>/2ojJoj`CoZ<3[1_nW_n/3oj6nkP?oYko[
1_nT_n`00onL`?7oY[o[ojJoj`04ojJoj`GoY;o]00?oW/7aojNojonW_n/01?nW_n/5ojFok8gooooo
0ol0000005Wooooo00?o0000ooooooooool0;Oooool6ojK0k003ojO1k?nV`>coY/3/00CoY/3/1?nX
`N`2ojK1k0KoZ<7/1OnX`>/00onX`NcoZ<3[ojS0j`05ojS0j`?oYko[0onX`>/6ojNoj`?oY;o/1?nX
`>/6ojJoj`;oY;o]1?nX`>/6ojNoj`03ojFok?oooooooooo08[ooooo1?l00003ooooo`00F_ooool0
0ol0003oooooooooo`0]ooooo`?oY/3/1?nW_n/6ojK0k003ojS1k?nV`NcoY/7/00?oY/7/1_nX`N`0
0onX`>_oZ<7/ojS1k003ojS1k0GoZ<3[0_nX`N`6ojS0j`CoYko[0_nW`>/7ojS0j`?oY[o[0_nW_n/7
ojS0j`?oYko[S?ooool3o`0000Oooooo001Kooooo`03o`000?oooooooooo02kooooo1_nW_n/3ojK0
k0?oY[o[1_nV`N`3ojS1k0CoY/7/1OnX`N`00onX`>_oZ<7/ojS1k004ojS1k0KoZ<3[00?oYko[ojO0
jonW`>/00onW`>/5ojS0j`03ojO1k?nW_n_oYko[00CoYko[1OnX`>^<ooooo`Co00002_ooool005co
oooo0_l0000_ooooo`?oYko[0onX_nX6ojJoj`?oY/7/1?nV_n/6ojK1k0;oZ<7/1?nV`N`6ojS1k0?o
Z<3[0onW`N`6ojO0j`03ojS0jonW`NcoYl7/00?oYl7/1_nW_n/00onX`>_oooooooooo`29ooooo`Co
00003_ooool005kooooo00?o0000ooooooooool0;Oooool6ojRojPCoY[o[0_nX_nX7ojJoj`?oY/7/
0_nV_n/7ojK1k0?oZ<7/0onV`N`6ojO1k0?oYl3[2OnW`N`3ojNojh[ooooo1?l0000Booooo`00Gooo
ool00ol0003oooooooooo`0]ooooo`KoZ;oZ00?oY[o[ojRoj_nX_nX00onX_nX5ojJoj`;oZ;o[1OnV
_n/5ojK1k0;oY[o[1_nV`N`3ojO1k0CoY/3/2?nW`Nb;ooooo`Co00005_ooool0063ooooo00?o0000
ooooooooool0;Oooool3ojRojPCoZ<3[1OnX_nX00onV_n_oZ;o[ojRoj`04ojRoj`GoY[o[00?oY/7/
ojJojonV_n/01?nV_n/4ojK1k0;oYko[1onV`>`3ojO1k8cooooo0ol0000Jooooo`00HOooool2o`00
02oooooo1_nX`>/2ojRojP[oZ;o[0_nV_n/4ojRojPKoY[o[00?oY/7/ojNojonW_n/00onW_n/5ojK0
k8cooooo1?l0000Mooooo`00Hoooool00ol0003oooooooooo`0]ooooo`GoZ<3[2_nX_n/9ojRojP?o
Y[o[0onX_nX6ojNoj`03ojK0k?oooooooooo08Wooooo1?l0000Qooooo`00I?ooool00ol0003ooooo
ooooo`0]ooooo`GoZ<3[1OnX_n/2ojS0j`WoZ;oZ1?nX_n/5ojRojP?oYko[R_ooool4o`0002Gooooo
001Uooooo`03o`000?oooooooooo02gooooo1OnX`>/00onX_n_oZ<3[ojS0j`04ojS0j`CoZ;oZ0_nX
`>/7ojRoj`;oZ;oZRoooool4o`0002Wooooo001Vooooo`;o0000;_ooool2ojS0j`CoYl7/1_nX`>/0
0onX_n[oZ<3[ojS0j`03ojS0j`GoZ;o[Roooool3o`0002gooooo001Xooooo`03o`000?oooooooooo
02cooooo1_nW`N`3ojS0j`?oYl7/1_nX`>/00onX_n_oooooooooo`28ooooo`Co0000<?ooool006Wo
oooo00?o0000ooooooooool0;?ooool3ojO1k0CoY/3/1OnW`N`3ojS0jhWooooo1?l0000dooooo`00
J_ooool00ol0003oooooooooo`0/ooooo`OoY/3/0_nW`Nb:ooooo`Co0000>?ooool006_ooooo0_l0
000]ooooo`GoY/3/ROooool4o`0003cooooo001]ooooo`03o`000?oooooooooo02_ooooo00?oY/3/
ooooooooool0Qoooool3o`00043ooooo001^ooooo`03o`000?oooooooooo02[ooooo00?o0000oooo
ooooool0Poooool4o`0004?ooooo001_ooooo`03o`000?oooooooooo02Wooooo00?o0000oooooooo
ool0Ooooool4o`0004Oooooo001`ooooo`;o0000:Oooool00ol0003oooooooooo`1kooooo`Co0000
Boooool007;ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1gooooo`Co0000Cooo
ool007?ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1dooooo`?o0000Doooool0
07Cooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1`ooooo`Co0000E_ooool007Go
oooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1/ooooo`Co0000F_ooool007Kooooo
0_l0000Sooooo`03o`000?oooooooooo06Sooooo1?l0001Nooooo`00N?ooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo06Cooooo1?l0001Rooooo`00NOooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo067ooooo0ol0001Vooooo`00N_ooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo05gooooo1?l0001Yooooo`00Noooool2o`0001kooooo00?o0000oooooooo
ool0FOooool4o`0006gooooo001mooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
EOooool4o`00077ooooo001nooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0DOoo
ool4o`0007Gooooo001oooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0C_ooool3
o`0007Wooooo0020ooooo`;o00006Oooool00ol0003oooooooooo`1:ooooo`Co0000O?ooool008;o
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`16ooooo`Co0000P?ooool008?ooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`12ooooo`Co0000Q?ooool008Cooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`0nooooo`Co0000R?ooool008Gooooo0_l0000C
ooooo`03o`000?oooooooooo03cooooo0ol0002<ooooo`00Qoooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo03Sooooo1?l0002?ooooo`00R?ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo03Cooooo1?l0002Cooooo`00ROooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo033ooooo1?l0002Gooooo`00R_ooool2o`0000kooooo00?o0000ooooooooool0;?oo
ool4o`0009_ooooo002<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0:Oooool3
o`0009oooooo002=ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool09Oooool4o`00
0:;ooooo002>ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08Oooool4o`000:Ko
oooo002?ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07Oooool4o`000:[ooooo
002@ooooo`;o00002?ooool00ol0003oooooooooo`0Iooooo`Co0000[_ooool009;ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Fooooo`?o0000/_ooool009?ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Booooo`Co0000]Oooool009Cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0>ooooo`Co0000^Oooool009Gooooo0_l00003ooooo`03o`00
0?oooooooooo00[ooooo1?l0002mooooo`00Uoooool01?l0003oooooooooool00008ooooo`Co0000
`Oooool009Sooooo00?o0000ooooool000001Oooool3o`000<Gooooo002Iooooo`;o000000?ooooo
o`000?l000000_l00038ooooo`00V_ooool2o`000<cooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
0000\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0538698, 0.0432538, \
0.0035044, 0.0035044}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[.12586 .2075 -12 -8.99448 ]
[.12586 .2075 0 .00552 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.56094 .0364 -5.16972 -9 ]
[.56094 .0364 .83028 0 ]
[.75679 .08071 0 -6.17777 ]
[.75679 .08071 12 2.82223 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.9429 .3657 0 -5.9083 ]
[.9429 .3657 6 3.0917 ]
[.02494 .25992 -18 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.01611 .31527 -18 -2.78472 ]
[.01611 .31527 0 6.21528 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00254 .43215 -12 -2.88407 ]
[-0.00254 .43215 0 6.11593 ]
[-0.0124 .49393 -12 -2.93688 ]
[-0.0124 .49393 0 6.06312 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
[(-2)] .12586 .2075 1 .99877 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.56863 .04703 m
.57247 .05235 L
s
[(2)] .56094 .0364 .72324 1 Mshowa
.125 Mabswid
.18558 .19702 m
.18832 .19985 L
s
.23703 .17687 m
.23971 .17975 L
s
.28951 .15632 m
.29214 .15925 L
s
.39772 .11395 m
.40023 .11699 L
s
.4535 .09211 m
.45595 .0952 L
s
.51046 .06981 m
.51284 .07294 L
s
.08568 .23614 m
.08851 .23887 L
s
.62804 .02377 m
.63027 .02701 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.7445 .0853 m
.73835 .08759 L
s
[(-2)] .75679 .08071 -1 .37284 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.93037 .36962 m
.92411 .37158 L
s
[(2)] .9429 .3657 -1 .31296 Mshowa
.125 Mabswid
.7708 .12553 m
.7671 .12688 L
s
.79613 .16428 m
.79242 .1656 L
s
.82054 .20161 m
.81682 .20291 L
s
.86679 .27235 m
.86305 .2736 L
s
.88871 .30589 m
.88497 .30711 L
s
.9099 .3383 m
.90615 .3395 L
s
.71716 .04348 m
.71349 .04489 L
s
.95018 .39992 m
.94642 .40107 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(-20)] .02494 .25992 1 -0.39157 Mshowa
.02837 .31059 m
.0345 .30825 L
s
[(-10)] .01611 .31527 1 -0.38117 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.00981 .42772 m
.01599 .4255 L
s
[(10)] -0.00254 .43215 1 -0.3591 Mshowa
0 .48963 m
.0062 .48748 L
s
[(20)] -0.0124 .49393 1 -0.34736 Mshowa
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.652 .754 .924 r
.39362 .69485 .40169 .70179 .4152 .69809 .40716 .69111 Mtetra
.658 .755 .921 r
.40716 .69111 .4152 .69809 .42877 .69436 .42079 .68715 Mtetra
.661 .75 .916 r
.42079 .68715 .42877 .69436 .44242 .69044 .43448 .6831 Mtetra
.657 .747 .916 r
.43448 .6831 .44242 .69044 .45614 .68642 .44824 .67917 Mtetra
.654 .749 .92 r
.44824 .67917 .45614 .68642 .46993 .68247 .46207 .6753 Mtetra
.651 .752 .923 r
.46207 .6753 .46993 .68247 .48378 .67859 .47597 .67152 Mtetra
.651 .755 .926 r
.47597 .67152 .48378 .67859 .4977 .67478 .48994 .66771 Mtetra
.657 .758 .925 r
.48994 .66771 .4977 .67478 .5117 .67099 .50398 .66367 Mtetra
.66 .753 .919 r
.50398 .66367 .5117 .67099 .52577 .66714 .5181 .65953 Mtetra
.655 .745 .916 r
.5181 .65953 .52577 .66714 .53991 .66303 .53229 .65554 Mtetra
.646 .747 .922 r
.53229 .65554 .53991 .66303 .55412 .65891 .54655 .65184 Mtetra
.637 .756 .934 r
.54655 .65184 .55412 .65891 .56841 .65489 .56089 .64835 Mtetra
.627 .77 .948 r
.56089 .64835 .56841 .65489 .58277 .65102 .57532 .64503 Mtetra
.608 .781 .964 r
.57532 .64503 .58277 .65102 .59722 .64726 .58983 .64203 Mtetra
.593 .802 .98 r
.58983 .64203 .59722 .64726 .61174 .64354 .60443 .63907 Mtetra
.584 .825 .99 r
.60443 .63907 .61174 .64354 .62634 .63982 .61912 .63591 Mtetra
.579 .843 .995 r
.61912 .63591 .62634 .63982 .64102 .63603 .63388 .6325 Mtetra
.579 .856 .996 r
.63388 .6325 .64102 .63603 .65578 .63214 .64871 .62882 Mtetra
.584 .866 .995 r
.64871 .62882 .65578 .63214 .67061 .6281 .66362 .62486 Mtetra
.593 .872 .993 r
.66362 .62486 .67061 .6281 .68552 .62391 .6786 .62062 Mtetra
.606 .876 .992 r
.6786 .62062 .68552 .62391 .70049 .61955 .69365 .61612 Mtetra
.621 .878 .989 r
.69365 .61612 .70049 .61955 .71554 .61504 .70876 .61134 Mtetra
.638 .875 .985 r
.70876 .61134 .71554 .61504 .73066 .61043 .72393 .60628 Mtetra
.656 .867 .979 r
.72393 .60628 .73066 .61043 .74586 .60575 .73916 .60095 Mtetra
.671 .852 .969 r
.73916 .60095 .74586 .60575 .76113 .60106 .75446 .59542 Mtetra
.677 .828 .956 r
.75446 .59542 .76113 .60106 .77649 .59642 .76983 .58992 Mtetra
.672 .801 .944 r
.76983 .58992 .77649 .59642 .79194 .59187 .78529 .58473 Mtetra
.669 .783 .934 r
.78529 .58473 .79194 .59187 .80748 .58748 .80085 .57972 Mtetra
.664 .765 .925 r
.80085 .57972 .80748 .58748 .82312 .58319 .81651 .57491 Mtetra
.657 .75 .918 r
.81651 .57491 .82312 .58319 .83884 .57889 .83229 .5704 Mtetra
.653 .744 .917 r
.83229 .5704 .83884 .57889 .85463 .57431 .84816 .56605 Mtetra
.654 .751 .921 r
.84816 .56605 .85463 .57431 .8705 .56967 .86411 .56159 Mtetra
.659 .759 .924 r
.86411 .56159 .8705 .56967 .88646 .56505 .88013 .55687 Mtetra
.66 .758 .923 r
.88013 .55687 .88646 .56505 .90251 .56049 .89624 .55213 Mtetra
.657 .753 .921 r
.89624 .55213 .90251 .56049 .91867 .55601 .91244 .54747 Mtetra
.655 .749 .919 r
.91244 .54747 .91867 .55601 .93492 .55159 .92875 .54288 Mtetra
.652 .745 .918 r
.92875 .54288 .93492 .55159 .95126 .54707 .94516 .5384 Mtetra
.653 .748 .919 r
.94516 .5384 .95126 .54707 .96766 .54234 .96166 .53383 Mtetra
.658 .755 .922 r
.96166 .53383 .96766 .54234 .98415 .53757 .97822 .52902 Mtetra
.658 .755 .921 r
.38546 .68784 .39362 .69485 .40716 .69111 .39906 .68387 Mtetra
.661 .75 .916 r
.39906 .68387 .40716 .69111 .42079 .68715 .41273 .67979 Mtetra
.657 .747 .916 r
.41273 .67979 .42079 .68715 .43448 .6831 .42646 .67585 Mtetra
.654 .75 .921 r
.42646 .67585 .43448 .6831 .44824 .67917 .44027 .67198 Mtetra
.65 .752 .924 r
.44027 .67198 .44824 .67917 .46207 .6753 .45414 .66822 Mtetra
.651 .756 .926 r
.45414 .66822 .46207 .6753 .47597 .67152 .46808 .66439 Mtetra
.661 .758 .922 r
.46808 .66439 .47597 .67152 .48994 .66771 .4821 .6602 Mtetra
.658 .748 .917 r
.4821 .6602 .48994 .66771 .50398 .66367 .49619 .65612 Mtetra
.647 .745 .921 r
.49619 .65612 .50398 .66367 .5181 .65953 .51035 .65241 Mtetra
.633 .754 .935 r
.51035 .65241 .5181 .65953 .53229 .65554 .52459 .64907 Mtetra
.613 .767 .954 r
.52459 .64907 .53229 .65554 .54655 .65184 .53891 .64613 Mtetra
.574 .779 .976 r
.53891 .64613 .54655 .65184 .56089 .64835 .55332 .64383 Mtetra
.548 .81 .994 r
.55332 .64383 .56089 .64835 .57532 .64503 .56782 .64145 Mtetra
.529 .834 .999 r
.56782 .64145 .57532 .64503 .58983 .64203 .5824 .63879 Mtetra
.536 .848 .998 r
.5824 .63879 .58983 .64203 .60443 .63907 .59707 .63574 Mtetra
.558 .855 .997 r
.59707 .63574 .60443 .63907 .61912 .63591 .61181 .63233 Mtetra
.581 .856 .995 r
.61181 .63233 .61912 .63591 .63388 .6325 .62664 .62861 Mtetra
.6 .853 .992 r
.62664 .62861 .63388 .6325 .64871 .62882 .64153 .62466 Mtetra
.613 .85 .988 r
.64153 .62466 .64871 .62882 .66362 .62486 .65651 .62054 Mtetra
.621 .848 .986 r
.65651 .62054 .66362 .62486 .6786 .62062 .67156 .61627 Mtetra
.626 .85 .985 r
.67156 .61627 .6786 .62062 .69365 .61612 .68668 .61186 Mtetra
.63 .855 .985 r
.68668 .61186 .69365 .61612 .70876 .61134 .70188 .60727 Mtetra
.634 .864 .985 r
.70188 .60727 .70876 .61134 .72393 .60628 .71714 .60244 Mtetra
.64 .874 .985 r
.71714 .60244 .72393 .60628 .73916 .60095 .73246 .5973 Mtetra
.649 .884 .983 r
.73246 .5973 .73916 .60095 .75446 .59542 .74784 .59178 Mtetra
.663 .89 .98 r
.74784 .59178 .75446 .59542 .76983 .58992 .76327 .58586 Mtetra
.679 .883 .974 r
.76327 .58586 .76983 .58992 .78529 .58473 .77874 .57965 Mtetra
.693 .855 .96 r
.77874 .57965 .78529 .58473 .80085 .57972 .79428 .57334 Mtetra
.681 .813 .946 r
.79428 .57334 .80085 .57972 .81651 .57491 .80994 .56768 Mtetra
.673 .786 .934 r
.80994 .56768 .81651 .57491 .83229 .5704 .82571 .56241 Mtetra
.664 .763 .924 r
.82571 .56241 .83229 .5704 .84816 .56605 .84161 .55753 Mtetra
.655 .747 .918 r
.84161 .55753 .84816 .56605 .86411 .56159 .85762 .55302 Mtetra
.651 .746 .919 r
.85762 .55302 .86411 .56159 .88013 .55687 .87374 .54862 Mtetra
.659 .758 .923 r
.87374 .54862 .88013 .55687 .89624 .55213 .88991 .54384 Mtetra
.66 .759 .923 r
.88991 .54384 .89624 .55213 .91244 .54747 .90617 .539 Mtetra
.658 .754 .921 r
.90617 .539 .91244 .54747 .92875 .54288 .92253 .53425 Mtetra
.655 .75 .92 r
.92253 .53425 .92875 .54288 .94516 .5384 .93899 .52957 Mtetra
.652 .745 .918 r
.93899 .52957 .94516 .5384 .96166 .53383 .95556 .52503 Mtetra
.654 .748 .919 r
.95556 .52503 .96166 .53383 .97822 .52902 .97222 .52038 Mtetra
.661 .751 .916 r
.37724 .68059 .38546 .68784 .39906 .68387 .39088 .67649 Mtetra
.657 .747 .917 r
.39088 .67649 .39906 .68387 .41273 .67979 .40459 .67252 Mtetra
.653 .75 .921 r
.40459 .67252 .41273 .67979 .42646 .67585 .41837 .66865 Mtetra
.649 .752 .924 r
.41837 .66865 .42646 .67585 .44027 .67198 .43221 .66488 Mtetra
.653 .756 .926 r
.43221 .66488 .44027 .67198 .45414 .66822 .44613 .66096 Mtetra
.661 .756 .92 r
.44613 .66096 .45414 .66822 .46808 .66439 .46012 .65675 Mtetra
.654 .745 .916 r
.46012 .65675 .46808 .66439 .4821 .6602 .47419 .65279 Mtetra
.637 .747 .928 r
.47419 .65279 .4821 .6602 .49619 .65612 .48832 .64935 Mtetra
.615 .759 .948 r
.48832 .64935 .49619 .65612 .51035 .65241 .50252 .64642 Mtetra
.564 .767 .974 r
.50252 .64642 .51035 .65241 .52459 .64907 .51681 .64446 Mtetra
.523 .798 .996 r
.51681 .64446 .52459 .64907 .53891 .64613 .53119 .64258 Mtetra
.502 .824 1 r
.53119 .64258 .53891 .64613 .55332 .64383 .54566 .64033 Mtetra
.536 .84 .999 r
.54566 .64033 .55332 .64383 .56782 .64145 .56022 .63748 Mtetra
.581 .842 .994 r
.56022 .63748 .56782 .64145 .5824 .63879 .57486 .63406 Mtetra
.62 .83 .981 r
.57486 .63406 .5824 .63879 .59707 .63574 .58957 .63013 Mtetra
.647 .811 .962 r
.58957 .63013 .59707 .63574 .61181 .63233 .60436 .62578 Mtetra
.667 .79 .94 r
.60436 .62578 .61181 .63233 .62664 .62861 .61921 .62099 Mtetra
.667 .761 .921 r
.61921 .62099 .62664 .62861 .64153 .62466 .63413 .61627 Mtetra
.662 .741 .908 r
.63413 .61627 .64153 .62466 .65651 .62054 .64914 .61173 Mtetra
.656 .73 .904 r
.64914 .61173 .65651 .62054 .67156 .61627 .66424 .60742 Mtetra
.65 .728 .906 r
.66424 .60742 .67156 .61627 .68668 .61186 .67944 .60334 Mtetra
.644 .735 .915 r
.67944 .60334 .68668 .61186 .70188 .60727 .69472 .59944 Mtetra
.639 .752 .93 r
.69472 .59944 .70188 .60727 .71714 .60244 .7101 .59561 Mtetra
.646 .784 .947 r
.7101 .59561 .71714 .60244 .73246 .5973 .72555 .59134 Mtetra
.652 .813 .961 r
.72555 .59134 .73246 .5973 .74784 .59178 .74105 .58663 Mtetra
.659 .842 .97 r
.74105 .58663 .74784 .59178 .76327 .58586 .7566 .58142 Mtetra
.669 .869 .975 r
.7566 .58142 .76327 .58586 .77874 .57965 .77219 .57561 Mtetra
.683 .887 .973 r
.77219 .57561 .77874 .57965 .79428 .57334 .7878 .56917 Mtetra
.696 .888 .968 r
.7878 .56917 .79428 .57334 .80994 .56768 .80346 .56235 Mtetra
.704 .855 .954 r
.80346 .56235 .80994 .56768 .82571 .56241 .81918 .55558 Mtetra
.683 .805 .94 r
.81918 .55558 .82571 .56241 .84161 .55753 .83507 .54981 Mtetra
.671 .776 .929 r
.83507 .54981 .84161 .55753 .85762 .55302 .85108 .54455 Mtetra
.658 .753 .92 r
.85108 .54455 .85762 .55302 .87374 .54862 .86724 .53983 Mtetra
.651 .743 .917 r
.86724 .53983 .87374 .54862 .88991 .54384 .88351 .53536 Mtetra
.658 .755 .922 r
.88351 .53536 .88991 .54384 .90617 .539 .89985 .53058 Mtetra
.661 .759 .923 r
.89985 .53058 .90617 .539 .92253 .53425 .91626 .52564 Mtetra
.658 .755 .921 r
.91626 .52564 .92253 .53425 .93899 .52957 .93277 .5208 Mtetra
.655 .75 .92 r
.93277 .5208 .93899 .52957 .95556 .52503 .9494 .51606 Mtetra
.651 .745 .918 r
.9494 .51606 .95556 .52503 .97222 .52038 .96614 .51146 Mtetra
.658 .748 .916 r
.36894 .67318 .37724 .68059 .39088 .67649 .38263 .66917 Mtetra
.654 .75 .921 r
.38263 .66917 .39088 .67649 .40459 .67252 .39637 .66527 Mtetra
.649 .752 .924 r
.39637 .66527 .40459 .67252 .41837 .66865 .41019 .6615 Mtetra
.653 .756 .925 r
.41019 .6615 .41837 .66865 .43221 .66488 .42408 .65755 Mtetra
.661 .755 .919 r
.42408 .65755 .43221 .66488 .44613 .66096 .43805 .65332 Mtetra
.651 .745 .918 r
.43805 .65332 .44613 .66096 .46012 .65675 .45208 .64946 Mtetra
.629 .749 .934 r
.45208 .64946 .46012 .65675 .47419 .65279 .46618 .64624 Mtetra
.588 .758 .96 r
.46618 .64624 .47419 .65279 .48832 .64935 .48035 .64393 Mtetra
.524 .772 .988 r
.48035 .64393 .48832 .64935 .50252 .64642 .49459 .64247 Mtetra
.485 .805 1 r
.49459 .64247 .50252 .64642 .51681 .64446 .50894 .64076 Mtetra
.522 .828 1 r
.50894 .64076 .51681 .64446 .53119 .64258 .52338 .63827 Mtetra
.588 .833 .991 r
.52338 .63827 .53119 .64258 .54566 .64033 .53791 .63491 Mtetra
.65 .816 .963 r
.53791 .63491 .54566 .64033 .56022 .63748 .55251 .63048 Mtetra
.69 .781 .921 r
.55251 .63048 .56022 .63748 .57486 .63406 .56717 .62491 Mtetra
.691 .73 .88 r
.56717 .62491 .57486 .63406 .58957 .63013 .5819 .61911 Mtetra
.684 .692 .851 r
.5819 .61911 .58957 .63013 .60436 .62578 .5967 .61336 Mtetra
.675 .666 .834 r
.5967 .61336 .60436 .62578 .61921 .62099 .61156 .60786 Mtetra
.666 .653 .827 r
.61156 .60786 .61921 .62099 .63413 .61627 .62651 .60269 Mtetra
.658 .644 .824 r
.62651 .60269 .63413 .61627 .64914 .61173 .64155 .5979 Mtetra
.65 .637 .824 r
.64155 .5979 .64914 .61173 .66424 .60742 .65667 .59354 Mtetra
.642 .634 .826 r
.65667 .59354 .66424 .60742 .67944 .60334 .6719 .5896 Mtetra
.635 .633 .831 r
.6719 .5896 .67944 .60334 .69472 .59944 .68724 .58605 Mtetra
.629 .636 .839 r
.68724 .58605 .69472 .59944 .7101 .59561 .70269 .58284 Mtetra
.624 .644 .85 r
.70269 .58284 .7101 .59561 .72555 .59134 .71824 .57988 Mtetra
.621 .667 .873 r
.71824 .57988 .72555 .59134 .74105 .58663 .7339 .57699 Mtetra
.623 .706 .905 r
.7339 .57699 .74105 .58663 .7566 .58142 .74965 .57387 Mtetra
.646 .769 .938 r
.74965 .57387 .7566 .58142 .77219 .57561 .76542 .56959 Mtetra
.668 .822 .958 r
.76542 .56959 .77219 .57561 .7878 .56917 .78119 .56421 Mtetra
.686 .862 .966 r
.78119 .56421 .7878 .56917 .80346 .56235 .79697 .55793 Mtetra
.704 .886 .964 r
.79697 .55793 .80346 .56235 .81918 .55558 .81276 .55083 Mtetra
.714 .879 .958 r
.81276 .55083 .81918 .55558 .83507 .54981 .82859 .54347 Mtetra
.698 .828 .945 r
.82859 .54347 .83507 .54981 .85108 .54455 .84457 .53696 Mtetra
.676 .786 .932 r
.84457 .53696 .85108 .54455 .86724 .53983 .86071 .53138 Mtetra
.66 .758 .922 r
.86071 .53138 .86724 .53983 .88351 .53536 .87701 .52646 Mtetra
.651 .744 .918 r
.87701 .52646 .88351 .53536 .89985 .53058 .89344 .52192 Mtetra
.657 .754 .921 r
.89344 .52192 .89985 .53058 .91626 .52564 .90994 .51707 Mtetra
.661 .759 .923 r
.90994 .51707 .91626 .52564 .93277 .5208 .92651 .51205 Mtetra
.658 .754 .921 r
.92651 .51205 .93277 .5208 .9494 .51606 .94318 .50714 Mtetra
.654 .75 .92 r
.94318 .50714 .9494 .51606 .96614 .51146 .95998 .50236 Mtetra
.654 .749 .92 r
.36056 .6658 .36894 .67318 .38263 .66917 .37429 .66187 Mtetra
.649 .751 .924 r
.37429 .66187 .38263 .66917 .39637 .66527 .38807 .65807 Mtetra
.652 .756 .925 r
.38807 .65807 .39637 .66527 .41019 .6615 .40193 .65415 Mtetra
.661 .755 .92 r
.40193 .65415 .41019 .6615 .42408 .65755 .41588 .64989 Mtetra
.649 .745 .919 r
.41588 .64989 .42408 .65755 .43805 .65332 .42988 .64605 Mtetra
.623 .749 .937 r
.42988 .64605 .43805 .65332 .45208 .64946 .44395 .64298 Mtetra
.565 .754 .966 r
.44395 .64298 .45208 .64946 .46618 .64624 .45806 .64114 Mtetra
.495 .772 .993 r
.45806 .64114 .46618 .64624 .48035 .64393 .47226 .63997 Mtetra
.484 .805 1 r
.47226 .63997 .48035 .64393 .49459 .64247 .48657 .63825 Mtetra
.558 .825 .996 r
.48657 .63825 .49459 .64247 .50894 .64076 .50098 .63543 Mtetra
.645 .817 .966 r
.50098 .63543 .50894 .64076 .52338 .63827 .51548 .63113 Mtetra
.704 .78 .91 r
.51548 .63113 .52338 .63827 .53791 .63491 .53006 .62498 Mtetra
.706 .718 .859 r
.53006 .62498 .53791 .63491 .55251 .63048 .54469 .61829 Mtetra
.696 .677 .827 r
.54469 .61829 .55251 .63048 .56717 .62491 .55938 .61151 Mtetra
.688 .657 .814 r
.55938 .61151 .56717 .62491 .5819 .61911 .57413 .60493 Mtetra
.678 .644 .808 r
.57413 .60493 .5819 .61911 .5967 .61336 .58894 .59878 Mtetra
.669 .635 .807 r
.58894 .59878 .5967 .61336 .61156 .60786 .60383 .59311 Mtetra
.662 .63 .808 r
.60383 .59311 .61156 .60786 .62651 .60269 .61881 .5879 Mtetra
.655 .627 .81 r
.61881 .5879 .62651 .60269 .64155 .5979 .63387 .58311 Mtetra
.648 .625 .813 r
.63387 .58311 .64155 .5979 .65667 .59354 .64902 .57869 Mtetra
.642 .622 .815 r
.64902 .57869 .65667 .59354 .6719 .5896 .66428 .57466 Mtetra
.634 .618 .816 r
.66428 .57466 .6719 .5896 .68724 .58605 .67963 .57104 Mtetra
.626 .614 .818 r
.67963 .57104 .68724 .58605 .70269 .58284 .69511 .56789 Mtetra
.617 .611 .822 r
.69511 .56789 .70269 .58284 .71824 .57988 .71071 .56523 Mtetra
.608 .611 .829 r
.71071 .56523 .71824 .57988 .7339 .57699 .72644 .56302 Mtetra
.603 .619 .84 r
.72644 .56302 .7339 .57699 .74965 .57387 .74229 .56102 Mtetra
.603 .637 .858 r
.74229 .56102 .74965 .57387 .76542 .56959 .75825 .55895 Mtetra
.61 .683 .894 r
.75825 .55895 .76542 .56959 .78119 .56421 .77429 .55634 Mtetra
.65 .766 .934 r
.77429 .55634 .78119 .56421 .79697 .55793 .79028 .55183 Mtetra
.684 .83 .953 r
.79028 .55183 .79697 .55793 .81276 .55083 .80624 .5458 Mtetra
.709 .871 .958 r
.80624 .5458 .81276 .55083 .82859 .54347 .82218 .53862 Mtetra
.723 .882 .954 r
.82218 .53862 .82859 .54347 .84457 .53696 .83813 .53085 Mtetra
.71 .842 .945 r
.83813 .53085 .84457 .53696 .86071 .53138 .85421 .52376 Mtetra
.68 .79 .932 r
.85421 .52376 .86071 .53138 .87701 .52646 .87049 .51793 Mtetra
.661 .76 .923 r
.87049 .51793 .87701 .52646 .89344 .52192 .88694 .51289 Mtetra
.651 .744 .918 r
.88694 .51289 .89344 .52192 .90994 .51707 .90354 .50829 Mtetra
.658 .755 .921 r
.90354 .50829 .90994 .51707 .92651 .51205 .92019 .50333 Mtetra
.661 .759 .922 r
.92019 .50333 .92651 .51205 .94318 .50714 .93692 .49823 Mtetra
.657 .753 .921 r
.93692 .49823 .94318 .50714 .95998 .50236 .95376 .49326 Mtetra
.65 .751 .923 r
.3521 .65845 .36056 .6658 .37429 .66187 .36586 .65461 Mtetra
.649 .754 .926 r
.36586 .65461 .37429 .66187 .38807 .65807 .37969 .65076 Mtetra
.662 .757 .92 r
.37969 .65076 .38807 .65807 .40193 .65415 .39361 .64646 Mtetra
.651 .745 .919 r
.39361 .64646 .40193 .65415 .41588 .64989 .40759 .64255 Mtetra
.622 .747 .936 r
.40759 .64255 .41588 .64989 .42988 .64605 .42162 .6395 Mtetra
.555 .749 .968 r
.42162 .6395 .42988 .64605 .44395 .64298 .43569 .63788 Mtetra
.478 .766 .994 r
.43569 .63788 .44395 .64298 .45806 .64114 .44984 .63695 Mtetra
.492 .801 .999 r
.44984 .63695 .45806 .64114 .47226 .63997 .4641 .63524 Mtetra
.588 .819 .987 r
.4641 .63524 .47226 .63997 .48657 .63825 .47848 .63207 Mtetra
.69 .803 .934 r
.47848 .63207 .48657 .63825 .50098 .63543 .49297 .62648 Mtetra
.718 .741 .869 r
.49297 .62648 .50098 .63543 .51548 .63113 .50753 .61932 Mtetra
.711 .688 .826 r
.50753 .61932 .51548 .63113 .53006 .62498 .52214 .61171 Mtetra
.702 .664 .81 r
.52214 .61171 .53006 .62498 .54469 .61829 .5368 .60421 Mtetra
.69 .65 .805 r
.5368 .60421 .54469 .61829 .55938 .61151 .55152 .59728 Mtetra
.677 .643 .809 r
.55152 .59728 .55938 .61151 .57413 .60493 .56631 .59118 Mtetra
.663 .644 .821 r
.56631 .59118 .57413 .60493 .58894 .59878 .58117 .58605 Mtetra
.66 .658 .837 r
.58117 .58605 .58894 .59878 .60383 .59311 .59612 .58127 Mtetra
.658 .672 .852 r
.59612 .58127 .60383 .59311 .61881 .5879 .61115 .57669 Mtetra
.657 .684 .864 r
.61115 .57669 .61881 .5879 .63387 .58311 .62627 .57219 Mtetra
.656 .69 .87 r
.62627 .57219 .63387 .58311 .64902 .57869 .64146 .56772 Mtetra
.655 .689 .87 r
.64146 .56772 .64902 .57869 .66428 .57466 .65674 .56329 Mtetra
.652 .682 .865 r
.65674 .56329 .66428 .57466 .67963 .57104 .67211 .55895 Mtetra
.647 .668 .856 r
.67211 .55895 .67963 .57104 .69511 .56789 .68758 .5548 Mtetra
.638 .649 .844 r
.68758 .5548 .69511 .56789 .71071 .56523 .70316 .55101 Mtetra
.618 .623 .834 r
.70316 .55101 .71071 .56523 .72644 .56302 .71888 .54821 Mtetra
.602 .608 .83 r
.71888 .54821 .72644 .56302 .74229 .56102 .73477 .54626 Mtetra
.589 .603 .834 r
.73477 .54626 .74229 .56102 .75825 .55895 .7508 .54491 Mtetra
.585 .612 .846 r
.7508 .54491 .75825 .55895 .77429 .55634 .76697 .54368 Mtetra
.591 .638 .866 r
.76697 .54368 .77429 .55634 .79028 .55183 .78323 .54201 Mtetra
.622 .709 .909 r
.78323 .54201 .79028 .55183 .80624 .5458 .79948 .53874 Mtetra
.678 .803 .942 r
.79948 .53874 .80624 .5458 .82218 .53862 .81562 .53296 Mtetra
.713 .857 .951 r
.81562 .53296 .82218 .53862 .83813 .53085 .8317 .52567 Mtetra
.731 .878 .948 r
.8317 .52567 .83813 .53085 .85421 .52376 .84778 .51755 Mtetra
.716 .844 .943 r
.84778 .51755 .85421 .52376 .87049 .51793 .86398 .51013 Mtetra
.682 .789 .931 r
.86398 .51013 .87049 .51793 .88694 .51289 .88042 .50418 Mtetra
.66 .758 .923 r
.88042 .50418 .88694 .51289 .90354 .50829 .89703 .49912 Mtetra
.65 .744 .918 r
.89703 .49912 .90354 .50829 .92019 .50333 .9138 .49447 Mtetra
.661 .758 .922 r
.9138 .49447 .92019 .50333 .93692 .49823 .9306 .48933 Mtetra
.66 .758 .922 r
.9306 .48933 .93692 .49823 .95376 .49326 .9475 .48417 Mtetra
.648 .752 .925 r
.34355 .6511 .3521 .65845 .36586 .65461 .35735 .64728 Mtetra
.66 .757 .922 r
.35735 .64728 .36586 .65461 .37969 .65076 .37124 .64304 Mtetra
.655 .746 .917 r
.37124 .64304 .37969 .65076 .39361 .64646 .3852 .63896 Mtetra
.626 .745 .933 r
.3852 .63896 .39361 .64646 .40759 .64255 .39919 .6358 Mtetra
.559 .746 .964 r
.39919 .6358 .40759 .64255 .42162 .6395 .41322 .63413 Mtetra
.471 .756 .992 r
.41322 .63413 .42162 .6395 .43569 .63788 .42731 .63342 Mtetra
.491 .794 .999 r
.42731 .63342 .43569 .63788 .44984 .63695 .44153 .63185 Mtetra
.602 .813 .981 r
.44153 .63185 .44984 .63695 .4641 .63524 .45588 .62851 Mtetra
.712 .792 .914 r
.45588 .62851 .4641 .63524 .47848 .63207 .47036 .62205 Mtetra
.725 .722 .847 r
.47036 .62205 .47848 .63207 .49297 .62648 .48492 .61412 Mtetra
.718 .682 .815 r
.48492 .61412 .49297 .62648 .50753 .61932 .49953 .60579 Mtetra
.705 .662 .805 r
.49953 .60579 .50753 .61932 .52214 .61171 .51418 .59795 Mtetra
.685 .652 .811 r
.51418 .59795 .52214 .61171 .5368 .60421 .52887 .59143 Mtetra
.667 .659 .833 r
.52887 .59143 .5368 .60421 .55152 .59728 .54364 .58624 Mtetra
.66 .687 .864 r
.54364 .58624 .55152 .59728 .56631 .59118 .55848 .58164 Mtetra
.654 .716 .893 r
.55848 .58164 .56631 .59118 .58117 .58605 .57341 .57736 Mtetra
.648 .734 .912 r
.57341 .57736 .58117 .58605 .59612 .58127 .58842 .57326 Mtetra
.648 .752 .925 r
.58842 .57326 .59612 .58127 .61115 .57669 .60352 .56909 Mtetra
.65 .765 .933 r
.60352 .56909 .61115 .57669 .62627 .57219 .6187 .56476 Mtetra
.654 .772 .936 r
.6187 .56476 .62627 .57219 .64146 .56772 .63395 .56025 Mtetra
.658 .774 .934 r
.63395 .56025 .64146 .56772 .65674 .56329 .64929 .55556 Mtetra
.663 .769 .929 r
.64929 .55556 .65674 .56329 .67211 .55895 .6647 .55071 Mtetra
.665 .758 .919 r
.6647 .55071 .67211 .55895 .68758 .5548 .68019 .54579 Mtetra
.66 .738 .908 r
.68019 .54579 .68758 .5548 .70316 .55101 .69577 .54105 Mtetra
.652 .715 .894 r
.69577 .54105 .70316 .55101 .71888 .54821 .71146 .53663 Mtetra
.638 .678 .871 r
.71146 .53663 .71888 .54821 .73477 .54626 .72727 .53281 Mtetra
.609 .634 .85 r
.72727 .53281 .73477 .54626 .7508 .54491 .74327 .53035 Mtetra
.582 .604 .84 r
.74327 .53035 .7508 .54491 .76697 .54368 .75948 .52925 Mtetra
.57 .601 .845 r
.75948 .52925 .76697 .54368 .78323 .54201 .77586 .52867 Mtetra
.575 .622 .861 r
.77586 .52867 .78323 .54201 .79948 .53874 .79233 .5277 Mtetra
.603 .678 .894 r
.79233 .5277 .79948 .53874 .81562 .53296 .80881 .52523 Mtetra
.676 .788 .934 r
.80881 .52523 .81562 .53296 .8317 .52567 .82512 .51954 Mtetra
.718 .848 .943 r
.82512 .51954 .8317 .52567 .84778 .51755 .84134 .512 Mtetra
.739 .872 .942 r
.84134 .512 .84778 .51755 .86398 .51013 .85753 .50354 Mtetra
.716 .837 .939 r
.85753 .50354 .86398 .51013 .88042 .50418 .87389 .49607 Mtetra
.679 .784 .929 r
.87389 .49607 .88042 .50418 .89703 .49912 .8905 .49014 Mtetra
.657 .754 .922 r
.8905 .49014 .89703 .49912 .9138 .49447 .90729 .48515 Mtetra
.652 .745 .918 r
.90729 .48515 .9138 .49447 .9306 .48933 .92421 .48033 Mtetra
.662 .758 .922 r
.92421 .48033 .9306 .48933 .9475 .48417 .94118 .47507 Mtetra
.655 .755 .924 r
.33492 .64374 .34355 .6511 .35735 .64728 .34878 .63965 Mtetra
.66 .751 .917 r
.34878 .63965 .35735 .64728 .37124 .64304 .36271 .63538 Mtetra
.635 .744 .928 r
.36271 .63538 .37124 .64304 .3852 .63896 .37668 .63194 Mtetra
.577 .745 .957 r
.37668 .63194 .3852 .63896 .39919 .6358 .39068 .62991 Mtetra
.475 .743 .987 r
.39068 .62991 .39919 .6358 .41322 .63413 .40471 .62939 Mtetra
.479 .781 .997 r
.40471 .62939 .41322 .63413 .42731 .63342 .41887 .62814 Mtetra
.598 .807 .98 r
.41887 .62814 .42731 .63342 .44153 .63185 .43318 .62493 Mtetra
.719 .789 .907 r
.43318 .62493 .44153 .63185 .45588 .62851 .44766 .61814 Mtetra
.732 .718 .838 r
.44766 .61814 .45588 .62851 .47036 .62205 .46222 .60965 Mtetra
.725 .685 .811 r
.46222 .60965 .47036 .62205 .48492 .61412 .47683 .60078 Mtetra
.708 .667 .807 r
.47683 .60078 .48492 .61412 .49953 .60579 .49147 .59276 Mtetra
.676 .659 .826 r
.49147 .59276 .49953 .60579 .51418 .59795 .50614 .58701 Mtetra
.662 .689 .865 r
.50614 .58701 .51418 .59795 .52887 .59143 .52088 .58232 Mtetra
.646 .722 .904 r
.52088 .58232 .52887 .59143 .54364 .58624 .5357 .57837 Mtetra
.633 .75 .932 r
.5357 .57837 .54364 .58624 .55848 .58164 .55061 .57474 Mtetra
.627 .776 .952 r
.55061 .57474 .55848 .58164 .57341 .57736 .5656 .57104 Mtetra
.628 .794 .962 r
.5656 .57104 .57341 .57736 .58842 .57326 .58068 .56715 Mtetra
.636 .804 .964 r
.58068 .56715 .58842 .57326 .60352 .56909 .59584 .56295 Mtetra
.642 .806 .962 r
.59584 .56295 .60352 .56909 .6187 .56476 .61108 .55854 Mtetra
.646 .806 .96 r
.61108 .55854 .6187 .56476 .63395 .56025 .6264 .55398 Mtetra
.65 .807 .959 r
.6264 .55398 .63395 .56025 .64929 .55556 .6418 .54929 Mtetra
.656 .81 .957 r
.6418 .54929 .64929 .55556 .6647 .55071 .65728 .54439 Mtetra
.665 .813 .954 r
.65728 .54439 .6647 .55071 .68019 .54579 .67283 .53917 Mtetra
.672 .807 .948 r
.67283 .53917 .68019 .54579 .69577 .54105 .68845 .53375 Mtetra
.675 .79 .936 r
.68845 .53375 .69577 .54105 .71146 .53663 .70415 .52826 Mtetra
.668 .761 .92 r
.70415 .52826 .71146 .53663 .72727 .53281 .71995 .52309 Mtetra
.65 .724 .903 r
.71995 .52309 .72727 .53281 .74327 .53035 .73588 .51866 Mtetra
.625 .674 .876 r
.73588 .51866 .74327 .53035 .75948 .52925 .75198 .51532 Mtetra
.577 .613 .852 r
.75198 .51532 .75948 .52925 .77586 .52867 .76836 .51431 Mtetra
.558 .598 .85 r
.76836 .51431 .77586 .52867 .79233 .5277 .78493 .5142 Mtetra
.562 .615 .863 r
.78493 .5142 .79233 .5277 .80881 .52523 .80162 .51372 Mtetra
.596 .668 .89 r
.80162 .51372 .80881 .52523 .82512 .51954 .81829 .51151 Mtetra
.68 .785 .929 r
.81829 .51151 .82512 .51954 .84134 .512 .83474 .50557 Mtetra
.727 .845 .937 r
.83474 .50557 .84134 .512 .85753 .50354 .85108 .4976 Mtetra
.744 .865 .936 r
.85108 .4976 .85753 .50354 .87389 .49607 .8674 .48884 Mtetra
.708 .82 .935 r
.8674 .48884 .87389 .49607 .8905 .49014 .88395 .48163 Mtetra
.673 .775 .927 r
.88395 .48163 .8905 .49014 .90729 .48515 .90074 .47588 Mtetra
.652 .749 .92 r
.90074 .47588 .90729 .48515 .92421 .48033 .91773 .471 Mtetra
.656 .75 .919 r
.91773 .471 .92421 .48033 .94118 .47507 .9348 .46592 Mtetra
.662 .756 .92 r
.32621 .63626 .33492 .64374 .34878 .63965 .34012 .63187 Mtetra
.647 .746 .921 r
.34012 .63187 .34878 .63965 .36271 .63538 .35408 .62803 Mtetra
.604 .746 .945 r
.35408 .62803 .36271 .63538 .37668 .63194 .36805 .62538 Mtetra
.494 .731 .978 r
.36805 .62538 .37668 .63194 .39068 .62991 .38203 .62482 Mtetra
.459 .763 .995 r
.38203 .62482 .39068 .62991 .40471 .62939 .39612 .62405 Mtetra
.575 .799 .984 r
.39612 .62405 .40471 .62939 .41887 .62814 .41038 .62134 Mtetra
.712 .791 .913 r
.41038 .62134 .41887 .62814 .43318 .62493 .42483 .61484 Mtetra
.738 .725 .839 r
.42483 .61484 .43318 .62493 .44766 .61814 .4394 .60601 Mtetra
.732 .691 .811 r
.4394 .60601 .44766 .61814 .46222 .60965 .45402 .59666 Mtetra
.71 .673 .811 r
.45402 .59666 .46222 .60965 .47683 .60078 .46866 .58862 Mtetra
.675 .673 .84 r
.46866 .58862 .47683 .60078 .49147 .59276 .48331 .58307 Mtetra
.653 .712 .891 r
.48331 .58307 .49147 .59276 .50614 .58701 .49802 .57882 Mtetra
.627 .74 .928 r
.49802 .57882 .50614 .58701 .52088 .58232 .51281 .57542 Mtetra
.614 .771 .956 r
.51281 .57542 .52088 .58232 .5357 .57837 .52768 .57212 Mtetra
.623 .794 .964 r
.52768 .57212 .5357 .57837 .55061 .57474 .54265 .56836 Mtetra
.635 .796 .959 r
.54265 .56836 .55061 .57474 .5656 .57104 .5577 .56424 Mtetra
.643 .787 .951 r
.5577 .56424 .5656 .57104 .58068 .56715 .57283 .55995 Mtetra
.649 .778 .943 r
.57283 .55995 .58068 .56715 .59584 .56295 .58805 .55553 Mtetra
.652 .775 .939 r
.58805 .55553 .59584 .56295 .61108 .55854 .60335 .55102 Mtetra
.654 .774 .937 r
.60335 .55102 .61108 .55854 .6264 .55398 .61873 .54642 Mtetra
.655 .774 .937 r
.61873 .54642 .6264 .55398 .6418 .54929 .6342 .54174 Mtetra
.657 .776 .937 r
.6342 .54174 .6418 .54929 .65728 .54439 .64975 .53697 Mtetra
.659 .782 .939 r
.64975 .53697 .65728 .54439 .67283 .53917 .66538 .53206 Mtetra
.662 .793 .944 r
.66538 .53206 .67283 .53917 .68845 .53375 .68108 .52698 Mtetra
.67 .806 .948 r
.68108 .52698 .68845 .53375 .70415 .52826 .69686 .52153 Mtetra
.683 .812 .945 r
.69686 .52153 .70415 .52826 .71995 .52309 .71269 .5156 Mtetra
.681 .792 .933 r
.71269 .5156 .71995 .52309 .73588 .51866 .7286 .50977 Mtetra
.66 .75 .917 r
.7286 .50977 .73588 .51866 .75198 .51532 .74466 .5048 Mtetra
.629 .702 .898 r
.74466 .5048 .75198 .51532 .76836 .51431 .7609 .50116 Mtetra
.573 .627 .867 r
.7609 .50116 .76836 .51431 .78493 .5142 .77744 .50009 Mtetra
.545 .598 .857 r
.77744 .50009 .78493 .5142 .80162 .51372 .79422 .50039 Mtetra
.553 .616 .869 r
.79422 .50039 .80162 .51372 .81829 .51151 .81111 .50017 Mtetra
.603 .678 .894 r
.81111 .50017 .81829 .51151 .83474 .50557 .82793 .49757 Mtetra
.693 .794 .927 r
.82793 .49757 .83474 .50557 .85108 .4976 .84449 .49101 Mtetra
.739 .848 .931 r
.84449 .49101 .85108 .4976 .8674 .48884 .86092 .48243 Mtetra
.744 .856 .932 r
.86092 .48243 .8674 .48884 .88395 .48163 .87739 .47359 Mtetra
.694 .797 .929 r
.87739 .47359 .88395 .48163 .90074 .47588 .89416 .46692 Mtetra
.664 .763 .924 r
.89416 .46692 .90074 .47588 .91773 .471 .91117 .46149 Mtetra
.65 .745 .919 r
.91117 .46149 .91773 .471 .9348 .46592 .92834 .45662 Mtetra
.658 .749 .917 r
.31742 .62845 .32621 .63626 .34012 .63187 .33137 .62419 Mtetra
.624 .744 .933 r
.33137 .62419 .34012 .63187 .35408 .62803 .34533 .62101 Mtetra
.538 .735 .966 r
.34533 .62101 .35408 .62803 .36805 .62538 .35929 .61975 Mtetra
.446 .741 .991 r
.35929 .61975 .36805 .62538 .38203 .62482 .3733 .61944 Mtetra
.533 .784 .99 r
.3733 .61944 .38203 .62482 .39612 .62405 .38748 .61755 Mtetra
.686 .795 .932 r
.38748 .61755 .39612 .62405 .41038 .62134 .40188 .61206 Mtetra
.743 .741 .85 r
.40188 .61206 .41038 .62134 .42483 .61484 .41646 .60321 Mtetra
.741 .702 .814 r
.41646 .60321 .42483 .61484 .4394 .60601 .4311 .59343 Mtetra
.719 .682 .813 r
.4311 .59343 .4394 .60601 .45402 .59666 .44574 .58491 Mtetra
.677 .681 .846 r
.44574 .58491 .45402 .59666 .46866 .58862 .46037 .5793 Mtetra
.646 .719 .901 r
.46037 .5793 .46866 .58862 .48331 .58307 .47505 .57531 Mtetra
.613 .748 .941 r
.47505 .57531 .48331 .58307 .49802 .57882 .4898 .57222 Mtetra
.609 .78 .963 r
.4898 .57222 .49802 .57882 .51281 .57542 .50464 .56894 Mtetra
.63 .791 .959 r
.50464 .56894 .51281 .57542 .52768 .57212 .51958 .56502 Mtetra
.642 .778 .946 r
.51958 .56502 .52768 .57212 .54265 .56836 .5346 .56083 Mtetra
.65 .77 .936 r
.5346 .56083 .54265 .56836 .5577 .56424 .5497 .55643 Mtetra
.653 .764 .931 r
.5497 .55643 .5577 .56424 .57283 .55995 .56489 .55191 Mtetra
.655 .76 .927 r
.56489 .55191 .57283 .55995 .58805 .55553 .58016 .54734 Mtetra
.655 .758 .925 r
.58016 .54734 .58805 .55553 .60335 .55102 .59552 .54273 Mtetra
.656 .757 .924 r
.59552 .54273 .60335 .55102 .61873 .54642 .61096 .53809 Mtetra
.61096 .53809 .61873 .54642 .6342 .54174 .62649 .53341 Mtetra
.656 .758 .925 r
.62649 .53341 .6342 .54174 .64975 .53697 .6421 .52869 Mtetra
.657 .761 .927 r
.6421 .52869 .64975 .53697 .66538 .53206 .6578 .52392 Mtetra
.659 .766 .929 r
.6578 .52392 .66538 .53206 .68108 .52698 .67358 .51903 Mtetra
.663 .774 .932 r
.67358 .51903 .68108 .52698 .69686 .52153 .68944 .51393 Mtetra
.669 .786 .937 r
.68944 .51393 .69686 .52153 .71269 .5156 .70537 .50854 Mtetra
.684 .807 .941 r
.70537 .50854 .71269 .5156 .7286 .50977 .72135 .5025 Mtetra
.689 .804 .936 r
.72135 .5025 .7286 .50977 .74466 .5048 .7374 .49625 Mtetra
.667 .764 .923 r
.7374 .49625 .74466 .5048 .7609 .50116 .75359 .49092 Mtetra
.627 .711 .906 r
.75359 .49092 .7609 .50116 .77744 .50009 .76999 .48724 Mtetra
.56 .628 .876 r
.76999 .48724 .77744 .50009 .79422 .50039 .78674 .48658 Mtetra
.532 .599 .866 r
.78674 .48658 .79422 .50039 .81111 .50017 .80374 .48723 Mtetra
.55 .624 .878 r
.80374 .48723 .81111 .50017 .82793 .49757 .82082 .48695 Mtetra
.627 .707 .904 r
.82082 .48695 .82793 .49757 .84449 .49101 .83771 .4832 Mtetra
.713 .809 .925 r
.83771 .4832 .84449 .49101 .86092 .48243 .85434 .47569 Mtetra
.751 .851 .925 r
.85434 .47569 .86092 .48243 .87739 .47359 .87087 .4665 Mtetra
.728 .837 .932 r
.87087 .4665 .87739 .47359 .89416 .46692 .88756 .45828 Mtetra
.681 .781 .926 r
.88756 .45828 .89416 .46692 .91117 .46149 .90456 .45206 Mtetra
.654 .751 .921 r
.90456 .45206 .91117 .46149 .92834 .45662 .92178 .44697 Mtetra
.645 .746 .923 r
.30855 .6206 .31742 .62845 .33137 .62419 .32251 .61675 Mtetra
.593 .743 .948 r
.32251 .61675 .33137 .62419 .34533 .62101 .33648 .61433 Mtetra
.47 .721 .979 r
.33648 .61433 .34533 .62101 .35929 .61975 .35042 .61415 Mtetra
.48 .758 .992 r
.35042 .61415 .35929 .61975 .3733 .61944 .3645 .61324 Mtetra
.628 .791 .96 r
.3645 .61324 .3733 .61944 .38748 .61755 .3788 .60951 Mtetra
.743 .768 .873 r
.3788 .60951 .38748 .61755 .40188 .61206 .39337 .60115 Mtetra
.749 .715 .821 r
.39337 .60115 .40188 .61206 .41646 .60321 .40803 .59111 Mtetra
.734 .694 .813 r
.40803 .59111 .41646 .60321 .4311 .59343 .42271 .58165 Mtetra
.685 .684 .843 r
.42271 .58165 .4311 .59343 .44574 .58491 .43733 .5756 Mtetra
.647 .721 .902 r
.43733 .5756 .44574 .58491 .46037 .5793 .45198 .57155 Mtetra
.606 .746 .944 r
.45198 .57155 .46037 .5793 .47505 .57531 .46669 .56863 Mtetra
.609 .778 .962 r
.46669 .56863 .47505 .57531 .4898 .57222 .48149 .56535 Mtetra
.633 .781 .953 r
.48149 .56535 .4898 .57222 .50464 .56894 .49639 .56141 Mtetra
.647 .768 .937 r
.49639 .56141 .50464 .56894 .51958 .56502 .51139 .55713 Mtetra
.653 .762 .93 r
.51139 .55713 .51958 .56502 .5346 .56083 .52646 .55264 Mtetra
.654 .756 .924 r
.52646 .55264 .5346 .56083 .5497 .55643 .54162 .54809 Mtetra
.652 .753 .924 r
.54162 .54809 .5497 .55643 .56489 .55191 .55686 .54361 Mtetra
.652 .755 .925 r
.55686 .54361 .56489 .55191 .58016 .54734 .57219 .5391 Mtetra
.654 .758 .926 r
.57219 .5391 .58016 .54734 .59552 .54273 .58761 .5345 Mtetra
.655 .76 .927 r
.58761 .5345 .59552 .54273 .61096 .53809 .60311 .52981 Mtetra
.657 .76 .926 r
.60311 .52981 .61096 .53809 .62649 .53341 .61869 .52503 Mtetra
.659 .76 .924 r
.61869 .52503 .62649 .53341 .6421 .52869 .63436 .52016 Mtetra
.659 .757 .923 r
.63436 .52016 .6421 .52869 .6578 .52392 .65012 .51526 Mtetra
.657 .754 .922 r
.65012 .51526 .6578 .52392 .67358 .51903 .66597 .51041 Mtetra
.658 .757 .923 r
.66597 .51041 .67358 .51903 .68944 .51393 .6819 .50551 Mtetra
.662 .765 .926 r
.6819 .50551 .68944 .51393 .70537 .50854 .69792 .5004 Mtetra
.67 .776 .929 r
.69792 .5004 .70537 .50854 .72135 .5025 .714 .49494 Mtetra
.686 .798 .934 r
.714 .49494 .72135 .5025 .7374 .49625 .73013 .48879 Mtetra
.694 .805 .933 r
.73013 .48879 .7374 .49625 .75359 .49092 .74632 .48226 Mtetra
.666 .765 .924 r
.74632 .48226 .75359 .49092 .76999 .48724 .76267 .47689 Mtetra
.616 .707 .91 r
.76267 .47689 .76999 .48724 .78674 .48658 .77927 .47357 Mtetra
.536 .616 .879 r
.77927 .47357 .78674 .48658 .80374 .48723 .79628 .47379 Mtetra
.523 .602 .875 r
.79628 .47379 .80374 .48723 .82082 .48695 .81349 .47463 Mtetra
.559 .643 .89 r
.81349 .47463 .82082 .48695 .83771 .4832 .83071 .47376 Mtetra
.67 .756 .915 r
.83071 .47376 .83771 .4832 .85434 .47569 .84759 .46807 Mtetra
.737 .825 .92 r
.84759 .46807 .85434 .47569 .87087 .4665 .86427 .45942 Mtetra
.754 .846 .92 r
.86427 .45942 .87087 .4665 .88756 .45828 .88093 .44998 Mtetra
.701 .799 .926 r
.88093 .44998 .88756 .45828 .90456 .45206 .89791 .44286 Mtetra
.665 .764 .924 r
.89791 .44286 .90456 .45206 .92178 .44697 .91515 .43723 Mtetra
.626 .744 .932 r
.29958 .61278 .30855 .6206 .32251 .61675 .31356 .60947 Mtetra
.536 .73 .964 r
.31356 .60947 .32251 .61675 .33648 .61433 .32749 .60826 Mtetra
.444 .73 .988 r
.32749 .60826 .33648 .61433 .35042 .61415 .34147 .60812 Mtetra
.551 .774 .981 r
.34147 .60812 .35042 .61415 .3645 .61324 .35565 .60608 Mtetra
.711 .784 .909 r
.35565 .60608 .3645 .61324 .3788 .60951 .37013 .59955 Mtetra
.752 .732 .834 r
.37013 .59955 .3788 .60951 .39337 .60115 .3848 .58971 Mtetra
.748 .708 .814 r
.3848 .58971 .39337 .60115 .40803 .59111 .39952 .57944 Mtetra
.707 .694 .835 r
.39952 .57944 .40803 .59111 .42271 .58165 .41418 .57207 Mtetra
.659 .719 .893 r
.41418 .57207 .42271 .58165 .43733 .5756 .4288 .56753 Mtetra
.606 .739 .939 r
.4288 .56753 .43733 .5756 .45198 .57155 .44347 .56464 Mtetra
.603 .771 .96 r
.44347 .56464 .45198 .57155 .46669 .56863 .45823 .56153 Mtetra
.632 .776 .949 r
.45823 .56153 .46669 .56863 .48149 .56535 .4731 .55763 Mtetra
.648 .765 .934 r
.4731 .55763 .48149 .56535 .49639 .56141 .48806 .5533 Mtetra
.653 .758 .926 r
.48806 .5533 .49639 .56141 .51139 .55713 .50311 .54879 Mtetra
.65 .752 .924 r
.50311 .54879 .51139 .55713 .52646 .55264 .51824 .54439 Mtetra
.648 .755 .927 r
.51824 .54439 .52646 .55264 .54162 .54809 .53346 .54001 Mtetra
.649 .761 .93 r
.53346 .54001 .54162 .54809 .55686 .54361 .54876 .53555 Mtetra
.652 .763 .931 r
.54876 .53555 .55686 .54361 .57219 .5391 .56415 .53097 Mtetra
.654 .763 .93 r
.56415 .53097 .57219 .5391 .58761 .5345 .57962 .52629 Mtetra
.655 .763 .929 r
.57962 .52629 .58761 .5345 .60311 .52981 .59518 .52155 Mtetra
.656 .763 .928 r
.59518 .52155 .60311 .52981 .61869 .52503 .61083 .51675 Mtetra
.658 .764 .928 r
.61083 .51675 .61869 .52503 .63436 .52016 .62656 .51186 Mtetra
.66 .766 .928 r
.62656 .51186 .63436 .52016 .65012 .51526 .64238 .50684 Mtetra
.662 .765 .926 r
.64238 .50684 .65012 .51526 .66597 .51041 .65828 .50173 Mtetra
.661 .759 .923 r
.65828 .50173 .66597 .51041 .6819 .50551 .67427 .49664 Mtetra
.658 .754 .921 r
.67427 .49664 .6819 .50551 .69792 .5004 .69036 .49167 Mtetra
.662 .76 .923 r
.69036 .49167 .69792 .5004 .714 .49494 .70653 .48651 Mtetra
.672 .773 .926 r
.70653 .48651 .714 .49494 .73013 .48879 .72276 .4809 Mtetra
.691 .794 .929 r
.72276 .4809 .73013 .48879 .74632 .48226 .73904 .47447 Mtetra
.696 .8 .929 r
.73904 .47447 .74632 .48226 .76267 .47689 .75537 .4678 Mtetra
.654 .754 .923 r
.75537 .4678 .76267 .47689 .77927 .47357 .77192 .46283 Mtetra
.581 .686 .913 r
.77192 .46283 .77927 .47357 .79628 .47379 .78879 .46078 Mtetra
.513 .607 .884 r
.78879 .46078 .79628 .47379 .81349 .47463 .80606 .46175 Mtetra
.523 .616 .886 r
.80606 .46175 .81349 .47463 .83071 .47376 .82346 .4623 Mtetra
.603 .685 .899 r
.82346 .4623 .83071 .47376 .84759 .46807 .84068 .45944 Mtetra
.71 .794 .916 r
.84068 .45944 .84759 .46807 .86427 .45942 .85756 .45187 Mtetra
.754 .836 .914 r
.85756 .45187 .86427 .45942 .88093 .44998 .8743 .44229 Mtetra
.73 .828 .925 r
.8743 .44229 .88093 .44998 .89791 .44286 .89122 .4338 Mtetra
.679 .776 .924 r
.89122 .4338 .89791 .44286 .91515 .43723 .90847 .42751 Mtetra
.604 .742 .942 r
.29052 .60506 .29958 .61278 .31356 .60947 .3045 .60231 Mtetra
.481 .715 .973 r
.3045 .60231 .31356 .60947 .32749 .60826 .31841 .60205 Mtetra
.474 .741 .986 r
.31841 .60205 .32749 .60826 .34147 .60812 .33246 .60144 Mtetra
.625 .779 .955 r
.33246 .60144 .34147 .60812 .35565 .60608 .34676 .5978 Mtetra
.749 .765 .866 r
.34676 .5978 .35565 .60608 .37013 .59955 .3614 .58897 Mtetra
.758 .725 .821 r
.3614 .58897 .37013 .59955 .3848 .58971 .37616 .57832 Mtetra
.736 .707 .824 r
.37616 .57832 .3848 .58971 .39952 .57944 .39089 .56903 Mtetra
.679 .709 .871 r
.39089 .56903 .39952 .57944 .41418 .57207 .40553 .56351 Mtetra
.62 .733 .927 r
.40553 .56351 .41418 .57207 .4288 .56753 .42016 .56025 Mtetra
.593 .759 .958 r
.42016 .56025 .4288 .56753 .44347 .56464 .43488 .55749 Mtetra
.627 .774 .951 r
.43488 .55749 .44347 .56464 .45823 .56153 .44971 .55372 Mtetra
.646 .763 .934 r
.44971 .55372 .45823 .56153 .4731 .55763 .46464 .54943 Mtetra
.653 .756 .925 r
.46464 .54943 .4731 .55763 .48806 .5533 .47965 .5449 Mtetra
.647 .75 .925 r
.47965 .5449 .48806 .5533 .50311 .54879 .49475 .5406 Mtetra
.646 .756 .93 r
.49475 .5406 .50311 .54879 .51824 .54439 .50993 .53627 Mtetra
.65 .761 .93 r
.50993 .53627 .51824 .54439 .53346 .54001 .52521 .53176 Mtetra
.653 .759 .928 r
.52521 .53176 .53346 .54001 .54876 .53555 .54056 .52712 Mtetra
.655 .757 .925 r
.54056 .52712 .54876 .53555 .56415 .53097 .55601 .52241 Mtetra
.656 .755 .923 r
.55601 .52241 .56415 .53097 .57962 .52629 .57154 .51765 Mtetra
.656 .754 .923 r
.57154 .51765 .57962 .52629 .59518 .52155 .58716 .51287 Mtetra
.656 .754 .922 r
.58716 .51287 .59518 .52155 .61083 .51675 .60287 .50805 Mtetra
.656 .755 .923 r
.60287 .50805 .61083 .51675 .62656 .51186 .61866 .50318 Mtetra
.657 .758 .924 r
.61866 .50318 .62656 .51186 .64238 .50684 .63454 .49824 Mtetra
.66 .762 .925 r
.63454 .49824 .64238 .50684 .65828 .50173 .65051 .49317 Mtetra
.664 .765 .925 r
.65051 .49317 .65828 .50173 .67427 .49664 .66657 .48791 Mtetra
.664 .762 .923 r
.66657 .48791 .67427 .49664 .69036 .49167 .68271 .48263 Mtetra
.658 .754 .921 r
.68271 .48263 .69036 .49167 .70653 .48651 .69895 .47756 Mtetra
.663 .759 .922 r
.69895 .47756 .70653 .48651 .72276 .4809 .71527 .47225 Mtetra
.675 .772 .923 r
.71527 .47225 .72276 .4809 .73904 .47447 .73166 .46641 Mtetra
.7 .796 .925 r
.73166 .46641 .73904 .47447 .75537 .4678 .74806 .45952 Mtetra
.687 .788 .927 r
.74806 .45952 .75537 .4678 .77192 .46283 .76457 .45312 Mtetra
.629 .733 .922 r
.76457 .45312 .77192 .46283 .78879 .46078 .78136 .44906 Mtetra
.532 .644 .905 r
.78136 .44906 .78879 .46078 .80606 .46175 .79858 .4489 Mtetra
.5 .606 .89 r
.79858 .4489 .80606 .46175 .82346 .4623 .81609 .45019 Mtetra
.545 .645 .899 r
.81609 .45019 .82346 .4623 .84068 .45944 .83359 .44962 Mtetra
.673 .754 .911 r
.83359 .44962 .84068 .45944 .85756 .45187 .8507 .44361 Mtetra
.743 .817 .91 r
.8507 .44361 .85756 .45187 .8743 .44229 .86758 .43442 Mtetra
.752 .832 .913 r
.86758 .43442 .8743 .44229 .89122 .4338 .88448 .42485 Mtetra
.694 .787 .922 r
.88448 .42485 .89122 .4338 .90847 .42751 .90173 .41787 Mtetra
.571 .735 .953 r
.28135 .5974 .29052 .60506 .3045 .60231 .29532 .59542 Mtetra
.45 .712 .979 r
.29532 .59542 .3045 .60231 .31841 .60205 .30925 .5955 Mtetra
.523 .752 .979 r
.30925 .5955 .31841 .60205 .33246 .60144 .32338 .59411 Mtetra
.692 .779 .918 r
.32338 .59411 .33246 .60144 .34676 .5978 .33785 .5883 Mtetra
.758 .744 .84 r
.33785 .5883 .34676 .5978 .3614 .58897 .3526 .57825 Mtetra
.759 .724 .82 r
.3526 .57825 .3614 .58897 .37616 .57832 .36742 .56743 Mtetra
.713 .711 .847 r
.36742 .56743 .37616 .57832 .39089 .56903 .38213 .5599 Mtetra
.65 .73 .907 r
.38213 .5599 .39089 .56903 .40553 .56351 .39677 .55562 Mtetra
.591 .743 .948 r
.39677 .55562 .40553 .56351 .42016 .56025 .41143 .55302 Mtetra
.614 .769 .954 r
.41143 .55302 .42016 .56025 .43488 .55749 .42621 .54963 Mtetra
.641 .761 .936 r
.42621 .54963 .43488 .55749 .44971 .55372 .4411 .54549 Mtetra
.653 .756 .926 r
.4411 .54549 .44971 .55372 .46464 .54943 .45608 .54097 Mtetra
.647 .75 .925 r
.45608 .54097 .46464 .54943 .47965 .5449 .47115 .53666 Mtetra
.644 .756 .93 r
.47115 .53666 .47965 .5449 .49475 .5406 .4863 .53237 Mtetra
.651 .759 .929 r
.4863 .53237 .49475 .5406 .50993 .53627 .50154 .52783 Mtetra
.654 .756 .925 r
.50154 .52783 .50993 .53627 .52521 .53176 .51687 .52314 Mtetra
.657 .754 .921 r
.51687 .52314 .52521 .53176 .54056 .52712 .53228 .51832 Mtetra
.657 .751 .919 r
.53228 .51832 .54056 .52712 .55601 .52241 .54778 .51348 Mtetra
.657 .749 .918 r
.54778 .51348 .55601 .52241 .57154 .51765 .56337 .50864 Mtetra
.656 .748 .917 r
.56337 .50864 .57154 .51765 .58716 .51287 .57905 .5038 Mtetra
.655 .747 .918 r
.57905 .5038 .58716 .51287 .60287 .50805 .59482 .49897 Mtetra
.654 .748 .918 r
.59482 .49897 .60287 .50805 .61866 .50318 .61067 .49413 Mtetra
.654 .75 .92 r
.61067 .49413 .61866 .50318 .63454 .49824 .62662 .48928 Mtetra
.657 .754 .921 r
.62662 .48928 .63454 .49824 .65051 .49317 .64266 .48428 Mtetra
.66 .758 .923 r
.64266 .48428 .65051 .49317 .66657 .48791 .65878 .47914 Mtetra
.666 .764 .924 r
.65878 .47914 .66657 .48791 .68271 .48263 .67498 .47374 Mtetra
.664 .762 .923 r
.67498 .47374 .68271 .48263 .69895 .47756 .69128 .46836 Mtetra
.659 .754 .92 r
.69128 .46836 .69895 .47756 .71527 .47225 .70768 .46319 Mtetra
.668 .762 .921 r
.70768 .46319 .71527 .47225 .73166 .46641 .72415 .45761 Mtetra
.685 .776 .92 r
.72415 .45761 .73166 .46641 .74806 .45952 .74067 .45127 Mtetra
.704 .797 .922 r
.74067 .45127 .74806 .45952 .76457 .45312 .75721 .44409 Mtetra
.662 .764 .926 r
.75721 .44409 .76457 .45312 .78136 .44906 .77396 .43864 Mtetra
.575 .696 .924 r
.77396 .43864 .78136 .44906 .79858 .4489 .79109 .43656 Mtetra
.49 .613 .901 r
.79109 .43656 .79858 .4489 .81609 .45019 .80864 .43791 Mtetra
.512 .627 .901 r
.80864 .43791 .81609 .45019 .83359 .44962 .82631 .43849 Mtetra
.622 .706 .906 r
.82631 .43849 .83359 .44962 .8507 .44361 .84371 .43467 Mtetra
.726 .798 .908 r
.84371 .43467 .8507 .44361 .86758 .43442 .86075 .42619 Mtetra
.758 .826 .905 r
.86075 .42619 .86758 .43442 .88448 .42485 .87769 .41615 Mtetra
.713 .803 .92 r
.87769 .41615 .88448 .42485 .90173 .41787 .89494 .40825 Mtetra
.535 .724 .961 r
.27209 .58972 .28135 .5974 .29532 .59542 .28604 .58851 Mtetra
.451 .714 .98 r
.28604 .58851 .29532 .59542 .30925 .5955 .30001 .5885 Mtetra
.571 .758 .966 r
.30001 .5885 .30925 .5955 .32338 .59411 .31423 .58623 Mtetra
.731 .774 .887 r
.31423 .58623 .32338 .59411 .33785 .5883 .32887 .57851 Mtetra
.766 .741 .83 r
.32887 .57851 .33785 .5883 .3526 .57825 .34372 .56766 Mtetra
.754 .727 .827 r
.34372 .56766 .3526 .57825 .36742 .56743 .35857 .55732 Mtetra
.688 .721 .874 r
.35857 .55732 .36742 .56743 .38213 .5599 .37325 .5513 Mtetra
.619 .735 .929 r
.37325 .5513 .38213 .5599 .39677 .55562 .3879 .54799 Mtetra
.591 .752 .954 r
.3879 .54799 .39677 .55562 .41143 .55302 .40261 .54527 Mtetra
.63 .762 .942 r
.40261 .54527 .41143 .55302 .42621 .54963 .41745 .54144 Mtetra
.649 .757 .928 r
.41745 .54144 .42621 .54963 .4411 .54549 .4324 .53701 Mtetra
.649 .751 .924 r
.4324 .53701 .4411 .54549 .45608 .54097 .44744 .53257 Mtetra
.643 .752 .929 r
.44744 .53257 .45608 .54097 .47115 .53666 .46255 .52833 Mtetra
.649 .757 .928 r
.46255 .52833 .47115 .53666 .4863 .53237 .47776 .52383 Mtetra
.655 .755 .923 r
.47776 .52383 .4863 .53237 .50154 .52783 .49306 .51911 Mtetra
.659 .753 .92 r
.49306 .51911 .50154 .52783 .51687 .52314 .50845 .51422 Mtetra
.658 .749 .917 r
.50845 .51422 .51687 .52314 .53228 .51832 .52392 .50935 Mtetra
.654 .748 .919 r
.52392 .50935 .53228 .51832 .54778 .51348 .53948 .50458 Mtetra
.655 .751 .921 r
.53948 .50458 .54778 .51348 .56337 .50864 .55512 .49977 Mtetra
.656 .753 .922 r
.55512 .49977 .56337 .50864 .57905 .5038 .57086 .49488 Mtetra
.657 .754 .921 r
.57086 .49488 .57905 .5038 .59482 .49897 .58668 .48992 Mtetra
.658 .752 .92 r
.58668 .48992 .59482 .49897 .61067 .49413 .6026 .48491 Mtetra
.654 .748 .919 r
.6026 .48491 .61067 .49413 .62662 .48928 .61861 .47999 Mtetra
.653 .747 .919 r
.61861 .47999 .62662 .48928 .64266 .48428 .63471 .4751 Mtetra
.657 .752 .92 r
.63471 .4751 .64266 .48428 .65878 .47914 .6509 .47004 Mtetra
.661 .757 .921 r
.6509 .47004 .65878 .47914 .67498 .47374 .66718 .46476 Mtetra
.667 .763 .922 r
.66718 .46476 .67498 .47374 .69128 .46836 .68354 .4592 Mtetra
.662 .758 .922 r
.68354 .4592 .69128 .46836 .70768 .46319 .69999 .45383 Mtetra
.661 .755 .92 r
.69999 .45383 .70768 .46319 .72415 .45761 .71655 .44847 Mtetra
.676 .766 .919 r
.71655 .44847 .72415 .45761 .74067 .45127 .73316 .44247 Mtetra
.702 .785 .915 r
.73316 .44247 .74067 .45127 .75721 .44409 .74978 .43531 Mtetra
.688 .782 .923 r
.74978 .43531 .75721 .44409 .77396 .43864 .76653 .42876 Mtetra
.617 .73 .926 r
.76653 .42876 .77396 .43864 .79109 .43656 .78359 .42501 Mtetra
.497 .635 .915 r
.78359 .42501 .79109 .43656 .80864 .43791 .80115 .42575 Mtetra
.486 .618 .906 r
.80115 .42575 .80864 .43791 .82631 .43849 .81893 .42705 Mtetra
.573 .679 .911 r
.81893 .42705 .82631 .43849 .84371 .43467 .83658 .4251 Mtetra
.706 .779 .908 r
.83658 .4251 .84371 .43467 .86075 .42619 .8538 .41746 Mtetra
.756 .816 .9 r
.8538 .41746 .86075 .42619 .87769 .41615 .87084 .40741 Mtetra
.731 .81 .913 r
.87084 .40741 .87769 .41615 .89494 .40825 .88807 .39859 Mtetra
.504 .713 .965 r
.26273 .58197 .27209 .58972 .28604 .58851 .27667 .58134 Mtetra
.47 .717 .977 r
.27667 .58134 .28604 .58851 .30001 .5885 .29069 .58108 Mtetra
.612 .76 .95 r
.29069 .58108 .30001 .5885 .31423 .58623 .30502 .57785 Mtetra
.752 .767 .866 r
.30502 .57785 .31423 .58623 .32887 .57851 .3198 .56871 Mtetra
.77 .743 .828 r
.3198 .56871 .32887 .57851 .34372 .56766 .33473 .55744 Mtetra
.743 .732 .842 r
.33473 .55744 .34372 .56766 .35857 .55732 .34958 .54813 Mtetra
.671 .737 .9 r
.34958 .54813 .35857 .55732 .37325 .5513 .36427 .54295 Mtetra
.596 .736 .942 r
.36427 .54295 .37325 .5513 .3879 .54799 .37894 .54024 Mtetra
.606 .755 .95 r
.37894 .54024 .3879 .54799 .40261 .54527 .39371 .5371 Mtetra
.639 .756 .933 r
.39371 .5371 .40261 .54527 .41745 .54144 .40862 .53298 Mtetra
.652 .754 .924 r
.40862 .53298 .41745 .54144 .4324 .53701 .42362 .5284 Mtetra
.643 .748 .926 r
.42362 .5284 .4324 .53701 .44744 .53257 .4387 .52414 Mtetra
.645 .754 .929 r
.4387 .52414 .44744 .53257 .46255 .52833 .45387 .51976 Mtetra
.653 .754 .924 r
.45387 .51976 .46255 .52833 .47776 .52383 .46914 .51508 Mtetra
.659 .753 .92 r
.46914 .51508 .47776 .52383 .49306 .51911 .4845 .51015 Mtetra
.657 .749 .918 r
.4845 .51015 .49306 .51911 .50845 .51422 .49994 .50529 Mtetra
.652 .749 .921 r
.49994 .50529 .50845 .51422 .52392 .50935 .51546 .50057 Mtetra
.652 .754 .924 r
.51546 .50057 .52392 .50935 .53948 .50458 .53108 .49582 Mtetra
.654 .756 .925 r
.53108 .49582 .53948 .50458 .55512 .49977 .54679 .49098 Mtetra
.655 .757 .925 r
.54679 .49098 .55512 .49977 .57086 .49488 .56258 .48604 Mtetra
.657 .758 .924 r
.56258 .48604 .57086 .49488 .58668 .48992 .57847 .481 Mtetra
.659 .758 .923 r
.57847 .481 .58668 .48992 .6026 .48491 .59444 .47587 Mtetra
.659 .756 .922 r
.59444 .47587 .6026 .48491 .61861 .47999 .61051 .4707 Mtetra
.655 .75 .92 r
.61051 .4707 .61861 .47999 .63471 .4751 .62667 .46568 Mtetra
.653 .748 .919 r
.62667 .46568 .63471 .4751 .6509 .47004 .64293 .46073 Mtetra
.658 .753 .92 r
.64293 .46073 .6509 .47004 .66718 .46476 .65928 .45551 Mtetra
.665 .759 .92 r
.65928 .45551 .66718 .46476 .68354 .4592 .67571 .44999 Mtetra
.667 .762 .921 r
.67571 .44999 .68354 .4592 .69999 .45383 .69222 .44435 Mtetra
.659 .753 .92 r
.69222 .44435 .69999 .45383 .71655 .44847 .70885 .43902 Mtetra
.67 .76 .918 r
.70885 .43902 .71655 .44847 .73316 .44247 .72555 .43321 Mtetra
.693 .773 .913 r
.72555 .43321 .73316 .44247 .74978 .43531 .74227 .4264 Mtetra
.703 .786 .916 r
.74227 .4264 .74978 .43531 .76653 .42876 .75905 .41912 Mtetra
.641 .748 .926 r
.75905 .41912 .76653 .42876 .78359 .42501 .77611 .41438 Mtetra
.52 .671 .931 r
.77611 .41438 .78359 .42501 .80115 .42575 .79363 .41395 Mtetra
.468 .618 .915 r
.79363 .41395 .80115 .42575 .81893 .42705 .81149 .41557 Mtetra
.532 .66 .918 r
.81149 .41557 .81893 .42705 .83658 .4251 .82934 .415 Mtetra
.685 .761 .909 r
.82934 .415 .83658 .4251 .8538 .41746 .84672 .40825 Mtetra
.75 .805 .897 r
.84672 .40825 .8538 .41746 .87084 .40741 .86388 .39837 Mtetra
.743 .809 .904 r
.86388 .39837 .87084 .40741 .88807 .39859 .88113 .38884 Mtetra
.483 .704 .967 r
.25328 .57411 .26273 .58197 .27667 .58134 .26722 .57386 Mtetra
.492 .719 .972 r
.26722 .57386 .27667 .58134 .29069 .58108 .2813 .57329 Mtetra
.648 .763 .933 r
.2813 .57329 .29069 .58108 .30502 .57785 .29575 .56896 Mtetra
.759 .759 .853 r
.29575 .56896 .30502 .57785 .3198 .56871 .31062 .55909 Mtetra
.774 .748 .83 r
.31062 .55909 .3198 .56871 .33473 .55744 .32563 .54765 Mtetra
.732 .74 .858 r
.32563 .54765 .33473 .55744 .34958 .54813 .34048 .53922 Mtetra
.652 .741 .914 r
.34048 .53922 .34958 .54813 .36427 .54295 .35519 .53474 Mtetra
.585 .737 .948 r
.35519 .53474 .36427 .54295 .37894 .54024 .36989 .53224 Mtetra
.62 .755 .943 r
.36989 .53224 .37894 .54024 .39371 .5371 .38473 .52868 Mtetra
.645 .754 .928 r
.38473 .52868 .39371 .5371 .40862 .53298 .39969 .52434 Mtetra
.65 .751 .923 r
.39969 .52434 .40862 .53298 .42362 .5284 .41474 .51979 Mtetra
.641 .75 .928 r
.41474 .51979 .42362 .5284 .4387 .52414 .42988 .51555 Mtetra
.649 .754 .926 r
.42988 .51555 .4387 .52414 .45387 .51976 .44511 .51099 Mtetra
.657 .753 .921 r
.44511 .51099 .45387 .51976 .46914 .51508 .46043 .50613 Mtetra
.659 .751 .918 r
.46043 .50613 .46914 .51508 .4845 .51015 .47584 .50115 Mtetra
.651 .748 .921 r
.47584 .50115 .4845 .51015 .49994 .50529 .49133 .49644 Mtetra
.65 .753 .925 r
.49133 .49644 .49994 .50529 .51546 .50057 .50692 .49174 Mtetra
.652 .755 .925 r
.50692 .49174 .51546 .50057 .53108 .49582 .52259 .48692 Mtetra
.655 .756 .924 r
.52259 .48692 .53108 .49582 .54679 .49098 .53836 .48198 Mtetra
.656 .755 .923 r
.53836 .48198 .54679 .49098 .56258 .48604 .55422 .47699 Mtetra
.656 .755 .922 r
.55422 .47699 .56258 .48604 .57847 .481 .57016 .47195 Mtetra
.659 .757 .922 r
.57016 .47195 .57847 .481 .59444 .47587 .5862 .46677 Mtetra
.661 .758 .922 r
.5862 .46677 .59444 .47587 .61051 .4707 .60233 .46149 Mtetra
.66 .756 .921 r
.60233 .46149 .61051 .4707 .62667 .46568 .61855 .45621 Mtetra
.653 .749 .92 r
.61855 .45621 .62667 .46568 .64293 .46073 .63487 .45119 Mtetra
.655 .749 .919 r
.63487 .45119 .64293 .46073 .65928 .45551 .65129 .44607 Mtetra
.662 .755 .919 r
.65129 .44607 .65928 .45551 .67571 .44999 .66779 .44062 Mtetra
.669 .761 .919 r
.66779 .44062 .67571 .44999 .69222 .44435 .68437 .43485 Mtetra
.661 .756 .921 r
.68437 .43485 .69222 .44435 .70885 .43902 .70107 .42938 Mtetra
.665 .756 .918 r
.70107 .42938 .70885 .43902 .72555 .43321 .71784 .4237 Mtetra
.684 .767 .914 r
.71784 .4237 .72555 .43321 .74227 .4264 .73467 .4172 Mtetra
.708 .784 .911 r
.73467 .4172 .74227 .4264 .75905 .41912 .7515 .4096 Mtetra
.66 .76 .924 r
.7515 .4096 .75905 .41912 .77611 .41438 .76857 .40404 Mtetra
.548 .693 .935 r
.76857 .40404 .77611 .41438 .79363 .41395 .78608 .40257 Mtetra
.456 .623 .924 r
.78608 .40257 .79363 .41395 .81149 .41557 .804 .40426 Mtetra
.507 .653 .924 r
.804 .40426 .81149 .41557 .82934 .415 .82197 .40435 Mtetra
.66 .741 .91 r
.82197 .40435 .82934 .415 .84672 .40825 .83954 .39864 Mtetra
.743 .797 .895 r
.83954 .39864 .84672 .40825 .86388 .39837 .85681 .38897 Mtetra
.751 .806 .896 r
.85681 .38897 .86388 .39837 .88113 .38884 .8741 .37894 Mtetra
.472 .697 .966 r
.24373 .56608 .25328 .57411 .26722 .57386 .25769 .56604 Mtetra
.509 .718 .967 r
.25769 .56604 .26722 .57386 .2813 .57329 .27183 .5652 Mtetra
.67 .763 .92 r
.27183 .5652 .2813 .57329 .29575 .56896 .28637 .56008 Mtetra
.765 .762 .85 r
.28637 .56008 .29575 .56896 .31062 .55909 .30134 .54974 Mtetra
.776 .755 .834 r
.30134 .54974 .31062 .55909 .32563 .54765 .31641 .53825 Mtetra
.723 .748 .872 r
.31641 .53825 .32563 .54765 .34048 .53922 .33128 .53045 Mtetra
.639 .742 .923 r
.33128 .53045 .34048 .53922 .35519 .53474 .34601 .52638 Mtetra
.585 .736 .947 r
.34601 .52638 .35519 .53474 .36989 .53224 .36075 .52385 Mtetra
.627 .75 .936 r
.36075 .52385 .36989 .53224 .38473 .52868 .37565 .52008 Mtetra
.648 .752 .925 r
.37565 .52008 .38473 .52868 .39969 .52434 .39067 .51558 Mtetra
.648 .749 .924 r
.39067 .51558 .39969 .52434 .41474 .51979 .40577 .51109 Mtetra
.642 .75 .927 r
.40577 .51109 .41474 .51979 .42988 .51555 .42096 .50677 Mtetra
.651 .752 .924 r
.42096 .50677 .42988 .51555 .44511 .51099 .43625 .50209 Mtetra
.659 .753 .919 r
.43625 .50209 .44511 .51099 .46043 .50613 .45163 .49709 Mtetra
.656 .75 .919 r
.45163 .49709 .46043 .50613 .47584 .50115 .46709 .49219 Mtetra
.649 .751 .924 r
.46709 .49219 .47584 .50115 .49133 .49644 .48264 .48749 Mtetra
.651 .753 .924 r
.48264 .48749 .49133 .49644 .50692 .49174 .49828 .48273 Mtetra
.657 .755 .922 r
.49828 .48273 .50692 .49174 .52259 .48692 .51402 .47768 Mtetra
.66 .751 .918 r
.51402 .47768 .52259 .48692 .53836 .48198 .52984 .47251 Mtetra
.656 .746 .916 r
.52984 .47251 .53836 .48198 .55422 .47699 .54576 .46747 Mtetra
.652 .745 .918 r
.54576 .46747 .55422 .47699 .57016 .47195 .56177 .46254 Mtetra
.654 .749 .92 r
.56177 .46254 .57016 .47195 .5862 .46677 .57787 .4575 Mtetra
.661 .756 .921 r
.57787 .4575 .5862 .46677 .60233 .46149 .59406 .45217 Mtetra
.662 .756 .92 r
.59406 .45217 .60233 .46149 .61855 .45621 .61034 .44677 Mtetra
.656 .753 .921 r
.61034 .44677 .61855 .45621 .63487 .45119 .62673 .44157 Mtetra
.653 .749 .92 r
.62673 .44157 .63487 .45119 .65129 .44607 .64321 .43647 Mtetra
.66 .753 .919 r
.64321 .43647 .65129 .44607 .66779 .44062 .65978 .43104 Mtetra
.668 .758 .918 r
.65978 .43104 .66779 .44062 .68437 .43485 .67644 .42524 Mtetra
.664 .757 .92 r
.67644 .42524 .68437 .43485 .70107 .42938 .69319 .41961 Mtetra
.663 .754 .918 r
.69319 .41961 .70107 .42938 .71784 .4237 .71005 .41398 Mtetra
.68 .763 .914 r
.71005 .41398 .71784 .4237 .73467 .4172 .72695 .4076 Mtetra
.707 .776 .906 r
.72695 .4076 .73467 .4172 .7515 .4096 .74387 .39992 Mtetra
.672 .764 .92 r
.74387 .39992 .7515 .4096 .76857 .40404 .76097 .39382 Mtetra
.568 .708 .936 r
.76097 .39382 .76857 .40404 .78608 .40257 .77848 .39159 Mtetra
.448 .63 .932 r
.77848 .39159 .78608 .40257 .804 .40426 .79647 .39322 Mtetra
.489 .652 .931 r
.79647 .39322 .804 .40426 .82197 .40435 .81453 .39368 Mtetra
.642 .736 .917 r
.81453 .39368 .82197 .40435 .83954 .39864 .83225 .38869 Mtetra
.738 .79 .894 r
.83225 .38869 .83954 .39864 .85681 .38897 .84963 .37919 Mtetra
.754 .8 .89 r
.84963 .37919 .85681 .38897 .8741 .37894 .86699 .36882 Mtetra
.468 .692 .964 r
.2341 .55784 .24373 .56608 .25769 .56604 .24809 .55787 Mtetra
.52 .716 .961 r
.24809 .55787 .25769 .56604 .27183 .5652 .26227 .55687 Mtetra
.68 .761 .913 r
.26227 .55687 .27183 .5652 .28637 .56008 .27689 .55132 Mtetra
.769 .766 .85 r
.27689 .55132 .28637 .56008 .30134 .54974 .29194 .54072 Mtetra
.779 .763 .839 r
.29194 .54072 .30134 .54974 .31641 .53825 .30707 .52921 Mtetra
.719 .756 .882 r
.30707 .52921 .31641 .53825 .33128 .53045 .32198 .52171 Mtetra
.632 .742 .928 r
.32198 .52171 .33128 .53045 .34601 .52638 .33675 .51781 Mtetra
.588 .734 .944 r
.33675 .51781 .34601 .52638 .36075 .52385 .35154 .51519 Mtetra
.629 .746 .932 r
.35154 .51519 .36075 .52385 .37565 .52008 .36649 .51131 Mtetra
.65 .751 .923 r
.36649 .51131 .37565 .52008 .39067 .51558 .38156 .50672 Mtetra
.646 .749 .924 r
.38156 .50672 .39067 .51558 .40577 .51109 .39671 .50223 Mtetra
.643 .749 .926 r
.39671 .50223 .40577 .51109 .42096 .50677 .41195 .49783 Mtetra
.652 .751 .922 r
.41195 .49783 .42096 .50677 .43625 .50209 .42729 .49307 Mtetra
.66 .753 .919 r
.42729 .49307 .43625 .50209 .45163 .49709 .44273 .48798 Mtetra
.654 .75 .92 r
.44273 .48798 .45163 .49709 .46709 .49219 .45825 .48311 Mtetra
.649 .75 .923 r
.45825 .48311 .46709 .49219 .48264 .48749 .47386 .47839 Mtetra
.652 .752 .923 r
.47386 .47839 .48264 .48749 .49828 .48273 .48956 .47352 Mtetra
.662 .754 .918 r
.48956 .47352 .49828 .48273 .51402 .47768 .50535 .46824 Mtetra
.662 .75 .915 r
.50535 .46824 .51402 .47768 .52984 .47251 .52123 .46292 Mtetra
.656 .746 .916 r
.52123 .46292 .52984 .47251 .54576 .46747 .53721 .45782 Mtetra
.65 .743 .918 r
.53721 .45782 .54576 .46747 .56177 .46254 .55328 .45294 Mtetra
.65 .746 .92 r
.55328 .45294 .56177 .46254 .57787 .4575 .56945 .44802 Mtetra
.659 .753 .919 r
.56945 .44802 .57787 .4575 .59406 .45217 .5857 .44268 Mtetra
.662 .755 .919 r
.5857 .44268 .59406 .45217 .61034 .44677 .60205 .4372 Mtetra
.658 .753 .92 r
.60205 .4372 .61034 .44677 .62673 .44157 .6185 .43187 Mtetra
.652 .749 .921 r
.6185 .43187 .62673 .44157 .64321 .43647 .63505 .42674 Mtetra
.659 .753 .919 r
.63505 .42674 .64321 .43647 .65978 .43104 .65169 .42129 Mtetra
.668 .756 .917 r
.65169 .42129 .65978 .43104 .67644 .42524 .66841 .41546 Mtetra
.665 .756 .918 r
.66841 .41546 .67644 .42524 .69319 .41961 .68523 .40971 Mtetra
.662 .754 .918 r
.68523 .40971 .69319 .41961 .71005 .41398 .70216 .40407 Mtetra
.678 .761 .913 r
.70216 .40407 .71005 .41398 .72695 .4076 .71914 .39769 Mtetra
.706 .772 .903 r
.71914 .39769 .72695 .4076 .74387 .39992 .73613 .39 Mtetra
.677 .763 .915 r
.73613 .39 .74387 .39992 .76097 .39382 .7533 .3836 Mtetra
.578 .716 .937 r
.7533 .3836 .76097 .39382 .77848 .39159 .77085 .38096 Mtetra
.441 .638 .939 r
.77085 .38096 .77848 .39159 .79647 .39322 .78888 .38249 Mtetra
.476 .655 .939 r
.78888 .38249 .79647 .39322 .81453 .39368 .80703 .38311 Mtetra
.631 .736 .923 r
.80703 .38311 .81453 .39368 .83225 .38869 .82486 .37845 Mtetra
.735 .785 .893 r
.82486 .37845 .83225 .38869 .84963 .37919 .84234 .36902 Mtetra
.755 .795 .885 r
.84234 .36902 .84963 .37919 .86699 .36882 .85977 .35846 Mtetra
.471 .689 .962 r
.22439 .54937 .2341 .55784 .24809 .55787 .2384 .54937 Mtetra
.524 .71 .957 r
.2384 .54937 .24809 .55787 .26227 .55687 .25262 .54832 Mtetra
.679 .758 .911 r
.25262 .54832 .26227 .55687 .27689 .55132 .26729 .54273 Mtetra
.771 .771 .853 r
.26729 .54273 .27689 .55132 .29194 .54072 .28241 .53206 Mtetra
.782 .772 .844 r
.28241 .53206 .29194 .54072 .30707 .52921 .29761 .52049 Mtetra
.721 .765 .888 r
.29761 .52049 .30707 .52921 .32198 .52171 .31258 .51293 Mtetra
.632 .744 .929 r
.31258 .51293 .32198 .52171 .33675 .51781 .32739 .50899 Mtetra
.589 .73 .941 r
.32739 .50899 .33675 .51781 .35154 .51519 .34223 .50632 Mtetra
.63 .743 .929 r
.34223 .50632 .35154 .51519 .36649 .51131 .35723 .50239 Mtetra
.65 .749 .922 r
.35723 .50239 .36649 .51131 .38156 .50672 .37235 .49775 Mtetra
.646 .748 .924 r
.37235 .49775 .38156 .50672 .39671 .50223 .38756 .49322 Mtetra
.643 .747 .925 r
.38756 .49322 .39671 .50223 .41195 .49783 .40285 .48877 Mtetra
.652 .75 .921 r
.40285 .48877 .41195 .49783 .42729 .49307 .41825 .48395 Mtetra
.66 .752 .919 r
.41825 .48395 .42729 .49307 .44273 .48798 .43374 .47881 Mtetra
.654 .751 .921 r
.43374 .47881 .44273 .48798 .45825 .48311 .44931 .47389 Mtetra
.649 .749 .923 r
.44931 .47389 .45825 .48311 .47386 .47839 .46498 .46911 Mtetra
.652 .75 .922 r
.46498 .46911 .47386 .47839 .48956 .47352 .48074 .46419 Mtetra
.662 .753 .918 r
.48074 .46419 .48956 .47352 .50535 .46824 .49659 .45886 Mtetra
.49659 .45886 .50535 .46824 .52123 .46292 .51253 .45348 Mtetra
.656 .751 .92 r
.51253 .45348 .52123 .46292 .53721 .45782 .52857 .44832 Mtetra
.649 .749 .922 r
.52857 .44832 .53721 .45782 .55328 .45294 .5447 .4434 Mtetra
.65 .749 .922 r
.5447 .4434 .55328 .45294 .56945 .44802 .56093 .43841 Mtetra
.659 .753 .919 r
.56093 .43841 .56945 .44802 .5857 .44268 .57725 .43302 Mtetra
.662 .754 .918 r
.57725 .43302 .5857 .44268 .60205 .4372 .59366 .42748 Mtetra
.658 .752 .919 r
.59366 .42748 .60205 .4372 .6185 .43187 .61017 .42209 Mtetra
.652 .75 .921 r
.61017 .42209 .6185 .43187 .63505 .42674 .62679 .41691 Mtetra
.659 .752 .919 r
.62679 .41691 .63505 .42674 .65169 .42129 .6435 .4114 Mtetra
.668 .756 .916 r
.6435 .4114 .65169 .42129 .66841 .41546 .66029 .40551 Mtetra
.665 .755 .917 r
.66029 .40551 .66841 .41546 .68523 .40971 .67718 .3997 Mtetra
.662 .753 .918 r
.67718 .3997 .68523 .40971 .70216 .40407 .69418 .394 Mtetra
.678 .759 .912 r
.69418 .394 .70216 .40407 .71914 .39769 .71123 .38755 Mtetra
.706 .769 .901 r
.71123 .38755 .71914 .39769 .73613 .39 .7283 .37979 Mtetra
.677 .759 .913 r
.7283 .37979 .73613 .39 .7533 .3836 .74554 .37333 Mtetra
.578 .717 .938 r
.74554 .37333 .7533 .3836 .77085 .38096 .76316 .37063 Mtetra
.433 .644 .946 r
.76316 .37063 .77085 .38096 .78888 .38249 .78126 .37212 Mtetra
.468 .662 .947 r
.78126 .37212 .78888 .38249 .80703 .38311 .79947 .37269 Mtetra
.631 .742 .928 r
.79947 .37269 .80703 .38311 .82486 .37845 .81737 .36797 Mtetra
.734 .782 .891 r
.81737 .36797 .82486 .37845 .84234 .36902 .83494 .35847 Mtetra
.753 .789 .882 r
.83494 .35847 .84234 .36902 .85977 .35846 .85246 .34783 Mtetra
.48 .689 .959 r
.21458 .54067 .22439 .54937 .2384 .54937 .22864 .54052 Mtetra
.521 .703 .953 r
.22864 .54052 .2384 .54937 .25262 .54832 .24288 .53957 Mtetra
.67 .753 .913 r
.24288 .53957 .25262 .54832 .26729 .54273 .25757 .53431 Mtetra
.77 .777 .858 r
.25757 .53431 .26729 .54273 .28241 .53206 .27274 .52378 Mtetra
.786 .781 .848 r
.27274 .52378 .28241 .53206 .29761 .52049 .28802 .51209 Mtetra
.729 .775 .89 r
.28802 .51209 .29761 .52049 .31258 .51293 .30308 .50412 Mtetra
.638 .747 .927 r
.30308 .50412 .31258 .51293 .32739 .50899 .31795 .49991 Mtetra
.588 .726 .939 r
.31795 .49991 .32739 .50899 .34223 .50632 .33283 .49724 Mtetra
.628 .74 .928 r
.33283 .49724 .34223 .50632 .35723 .50239 .34787 .49333 Mtetra
.649 .748 .922 r
.34787 .49333 .35723 .50239 .37235 .49775 .36305 .48868 Mtetra
.648 .749 .923 r
.36305 .48868 .37235 .49775 .38756 .49322 .37831 .48404 Mtetra
.642 .746 .924 r
.37831 .48404 .38756 .49322 .40285 .48877 .39365 .47957 Mtetra
.651 .749 .921 r
.39365 .47957 .40285 .48877 .41825 .48395 .4091 .47473 Mtetra
.659 .752 .919 r
.4091 .47473 .41825 .48395 .43374 .47881 .42465 .46957 Mtetra
.656 .752 .921 r
.42465 .46957 .43374 .47881 .44931 .47389 .44029 .46452 Mtetra
.65 .748 .922 r
.44029 .46452 .44931 .47389 .46498 .46911 .45601 .45966 Mtetra
.651 .748 .921 r
.45601 .45966 .46498 .46911 .48074 .46419 .47182 .45474 Mtetra
.657 .751 .919 r
.47182 .45474 .48074 .46419 .49659 .45886 .48773 .44953 Mtetra
.66 .756 .921 r
.48773 .44953 .49659 .45886 .51253 .45348 .50374 .4442 Mtetra
.656 .757 .924 r
.50374 .4442 .51253 .45348 .52857 .44832 .51984 .43898 Mtetra
.652 .756 .926 r
.51984 .43898 .52857 .44832 .5447 .4434 .53603 .43389 Mtetra
.654 .754 .923 r
.53603 .43389 .5447 .4434 .56093 .43841 .55232 .42868 Mtetra
.661 .752 .918 r
.55232 .42868 .56093 .43841 .57725 .43302 .5687 .42318 Mtetra
.662 .752 .917 r
.5687 .42318 .57725 .43302 .59366 .42748 .58518 .41761 Mtetra
.656 .75 .919 r
.58518 .41761 .59366 .42748 .61017 .42209 .60176 .41223 Mtetra
.653 .751 .922 r
.60176 .41223 .61017 .42209 .62679 .41691 .61844 .40696 Mtetra
.66 .753 .919 r
.61844 .40696 .62679 .41691 .6435 .4114 .63522 .40136 Mtetra
.668 .755 .915 r
.63522 .40136 .6435 .4114 .66029 .40551 .65208 .39538 Mtetra
.664 .753 .916 r
.65208 .39538 .66029 .40551 .67718 .3997 .66904 .38956 Mtetra
.663 .753 .918 r
.66904 .38956 .67718 .3997 .69418 .394 .68611 .38375 Mtetra
.68 .759 .911 r
.68611 .38375 .69418 .394 .71123 .38755 .70323 .37718 Mtetra
.706 .767 .899 r
.70323 .37718 .71123 .38755 .7283 .37979 .72037 .3693 Mtetra
.672 .753 .912 r
.72037 .3693 .7283 .37979 .74554 .37333 .7377 .36301 Mtetra
.566 .713 .941 r
.7377 .36301 .74554 .37333 .76316 .37063 .75542 .36062 Mtetra
.423 .648 .952 r
.75542 .36062 .76316 .37063 .78126 .37212 .77358 .36211 Mtetra
.467 .674 .954 r
.77358 .36211 .78126 .37212 .79947 .37269 .79184 .36242 Mtetra
.64 .752 .93 r
.79184 .36242 .79947 .37269 .81737 .36797 .80979 .35724 Mtetra
.736 .78 .888 r
.80979 .35724 .81737 .36797 .83494 .35847 .82743 .34752 Mtetra
.75 .782 .879 r
.82743 .34752 .83494 .35847 .85246 .34783 .84505 .33693 Mtetra
.495 .692 .956 r
.20469 .53175 .21458 .54067 .22864 .54052 .2188 .53132 Mtetra
.514 .694 .95 r
.2188 .53132 .22864 .54052 .24288 .53957 .23305 .53057 Mtetra
.65 .745 .919 r
.23305 .53057 .24288 .53957 .25757 .53431 .24774 .526 Mtetra
.765 .781 .865 r
.24774 .526 .25757 .53431 .27274 .52378 .26294 .51582 Mtetra
.789 .79 .853 r
.26294 .51582 .27274 .52378 .28802 .51209 .2783 .50405 Mtetra
.743 .787 .888 r
.2783 .50405 .28802 .51209 .30308 .50412 .29347 .49534 Mtetra
.652 .754 .924 r
.29347 .49534 .30308 .50412 .31795 .49991 .30842 .4906 Mtetra
.59 .723 .936 r
.30842 .4906 .31795 .49991 .33283 .49724 .32334 .48788 Mtetra
.624 .734 .926 r
.32334 .48788 .33283 .49724 .34787 .49333 .33842 .48409 Mtetra
.646 .745 .922 r
.33842 .48409 .34787 .49333 .36305 .48868 .35364 .4795 Mtetra
.65 .749 .922 r
.35364 .4795 .36305 .48868 .37831 .48404 .36896 .4747 Mtetra
.642 .744 .923 r
.36896 .4747 .37831 .48404 .39365 .47957 .38436 .47021 Mtetra
.649 .747 .921 r
.38436 .47021 .39365 .47957 .4091 .47473 .39986 .46539 Mtetra
.657 .751 .919 r
.39986 .46539 .4091 .47473 .42465 .46957 .41546 .46027 Mtetra
.659 .754 .92 r
.41546 .46027 .42465 .46957 .44029 .46452 .43116 .45503 Mtetra
.651 .748 .921 r
.43116 .45503 .44029 .46452 .45601 .45966 .44694 .45005 Mtetra
.651 .747 .92 r
.44694 .45005 .45601 .45966 .47182 .45474 .46281 .44508 Mtetra
.653 .748 .919 r
.46281 .44508 .47182 .45474 .48773 .44953 .47878 .44 Mtetra
.655 .752 .921 r
.47878 .44 .48773 .44953 .50374 .4442 .49485 .43478 Mtetra
.656 .757 .924 r
.49485 .43478 .50374 .4442 .51984 .43898 .51101 .42951 Mtetra
.51101 .42951 .51984 .43898 .53603 .43389 .52726 .42419 Mtetra
.659 .754 .92 r
.52726 .42419 .53603 .43389 .55232 .42868 .54362 .41874 Mtetra
.661 .75 .916 r
.54362 .41874 .55232 .42868 .5687 .42318 .56006 .41317 Mtetra
.66 .75 .916 r
.56006 .41317 .5687 .42318 .58518 .41761 .57661 .4076 Mtetra
.653 .749 .92 r
.57661 .4076 .58518 .41761 .60176 .41223 .59326 .4023 Mtetra
.655 .752 .921 r
.59326 .4023 .60176 .41223 .61844 .40696 .61 .39688 Mtetra
.662 .753 .918 r
.61 .39688 .61844 .40696 .63522 .40136 .62684 .39114 Mtetra
.669 .754 .914 r
.62684 .39114 .63522 .40136 .65208 .39538 .64377 .38507 Mtetra
.661 .75 .916 r
.64377 .38507 .65208 .39538 .66904 .38956 .66081 .3793 Mtetra
.665 .754 .916 r
.66081 .3793 .66904 .38956 .68611 .38375 .67794 .37331 Mtetra
.684 .758 .908 r
.67794 .37331 .68611 .38375 .70323 .37718 .69513 .3665 Mtetra
.706 .762 .896 r
.69513 .3665 .70323 .37718 .72037 .3693 .71235 .35856 Mtetra
.66 .746 .913 r
.71235 .35856 .72037 .3693 .7377 .36301 .72978 .35269 Mtetra
.542 .705 .946 r
.72978 .35269 .7377 .36301 .75542 .36062 .74762 .35096 Mtetra
.411 .654 .958 r
.74762 .35096 .75542 .36062 .77358 .36211 .76585 .35242 Mtetra
.476 .689 .961 r
.76585 .35242 .77358 .36211 .79184 .36242 .78414 .35225 Mtetra
.66 .765 .928 r
.78414 .35225 .79184 .36242 .80979 .35724 .80211 .34622 Mtetra
.739 .778 .884 r
.80211 .34622 .80979 .35724 .82743 .34752 .81981 .33618 Mtetra
.744 .775 .878 r
.81981 .33618 .82743 .34752 .84505 .33693 .83754 .32576 Mtetra
.517 .698 .952 r
.19471 .52266 .20469 .53175 .2188 .53132 .20889 .52177 Mtetra
.505 .684 .947 r
.20889 .52177 .2188 .53132 .23305 .53057 .22315 .52125 Mtetra
.618 .731 .927 r
.22315 .52125 .23305 .53057 .24774 .526 .23778 .51771 Mtetra
.756 .782 .875 r
.23778 .51771 .24774 .526 .26294 .51582 .253 .50815 Mtetra
.79 .797 .858 r
.253 .50815 .26294 .51582 .2783 .50405 .26843 .49642 Mtetra
.762 .799 .883 r
.26843 .49642 .2783 .50405 .29347 .49534 .28374 .48668 Mtetra
.672 .764 .92 r
.28374 .48668 .29347 .49534 .30842 .4906 .2988 .48115 Mtetra
.599 .725 .933 r
.2988 .48115 .30842 .4906 .32334 .48788 .31378 .47812 Mtetra
.613 .724 .925 r
.31378 .47812 .32334 .48788 .33842 .48409 .32888 .47465 Mtetra
.641 .741 .922 r
.32888 .47465 .33842 .48409 .35364 .4795 .34414 .47019 Mtetra
.653 .749 .92 r
.34414 .47019 .35364 .4795 .36896 .4747 .35952 .46526 Mtetra
.643 .744 .922 r
.35952 .46526 .36896 .4747 .38436 .47021 .37497 .46064 Mtetra
.646 .744 .92 r
.37497 .46064 .38436 .47021 .39986 .46539 .39052 .45591 Mtetra
.653 .749 .92 r
.39052 .45591 .39986 .46539 .41546 .46027 .40618 .45087 Mtetra
.659 .754 .92 r
.40618 .45087 .41546 .46027 .43116 .45503 .42193 .44557 Mtetra
.657 .753 .921 r
.42193 .44557 .43116 .45503 .44694 .45005 .43778 .44033 Mtetra
.652 .747 .919 r
.43778 .44033 .44694 .45005 .46281 .44508 .45371 .43524 Mtetra
.653 .746 .918 r
.45371 .43524 .46281 .44508 .47878 .44 .46974 .43011 Mtetra
.654 .746 .918 r
.46974 .43011 .47878 .44 .49485 .43478 .48586 .42489 Mtetra
.656 .748 .918 r
.48586 .42489 .49485 .43478 .51101 .42951 .50208 .41956 Mtetra
.658 .749 .917 r
.50208 .41956 .51101 .42951 .52726 .42419 .5184 .41413 Mtetra
.659 .748 .916 r
.5184 .41413 .52726 .42419 .54362 .41874 .53482 .40861 Mtetra
.66 .748 .915 r
.53482 .40861 .54362 .41874 .56006 .41317 .55133 .40304 Mtetra
.655 .748 .918 r
.55133 .40304 .56006 .41317 .57661 .4076 .56794 .39762 Mtetra
.653 .751 .922 r
.56794 .39762 .57661 .4076 .59326 .4023 .58465 .39226 Mtetra
.658 .754 .92 r
.58465 .39226 .59326 .4023 .61 .39688 .60147 .38664 Mtetra
.665 .753 .916 r
.60147 .38664 .61 .39688 .62684 .39114 .61837 .3807 Mtetra
.667 .751 .913 r
.61837 .3807 .62684 .39114 .64377 .38507 .63537 .37464 Mtetra
.659 .749 .917 r
.63537 .37464 .64377 .38507 .66081 .3793 .65248 .36889 Mtetra
.67 .755 .914 r
.65248 .36889 .66081 .3793 .67794 .37331 .66968 .36265 Mtetra
.692 .759 .903 r
.66968 .36265 .67794 .37331 .69513 .3665 .68692 .35539 Mtetra
.699 .754 .894 r
.68692 .35539 .69513 .3665 .71235 .35856 .70423 .34765 Mtetra
.642 .737 .918 r
.70423 .34765 .71235 .35856 .72978 .35269 .72179 .34248 Mtetra
.505 .692 .952 r
.72179 .34248 .72978 .35269 .74762 .35096 .73976 .3417 Mtetra
.404 .663 .965 r
.73976 .3417 .74762 .35096 .76585 .35242 .75805 .343 Mtetra
.496 .71 .966 r
.75805 .343 .76585 .35242 .78414 .35225 .77636 .34206 Mtetra
.686 .778 .921 r
.77636 .34206 .78414 .35225 .80211 .34622 .79431 .33484 Mtetra
.743 .775 .878 r
.79431 .33484 .80211 .34622 .81981 .33618 .81207 .32443 Mtetra
.735 .766 .878 r
.81207 .32443 .81981 .33618 .83754 .32576 .82993 .31438 Mtetra
.545 .708 .947 r
.18463 .51343 .19471 .52266 .20889 .52177 .1989 .51188 Mtetra
.498 .675 .944 r
.1989 .51188 .20889 .52177 .22315 .52125 .21317 .51155 Mtetra
.589 .715 .931 r
.21317 .51155 .22315 .52125 .23778 .51771 .22776 .50889 Mtetra
.73 .77 .885 r
.22776 .50889 .23778 .51771 .253 .50815 .24293 .50067 Mtetra
.787 .803 .865 r
.24293 .50067 .253 .50815 .26843 .49642 .25841 .48923 Mtetra
.782 .811 .876 r
.25841 .48923 .26843 .49642 .28374 .48668 .27388 .47832 Mtetra
.695 .778 .915 r
.27388 .47832 .28374 .48668 .2988 .48115 .28906 .47182 Mtetra
.619 .737 .931 r
.28906 .47182 .2988 .48115 .31378 .47812 .30412 .46809 Mtetra
.602 .716 .925 r
.30412 .46809 .31378 .47812 .32888 .47465 .31925 .46496 Mtetra
.634 .736 .922 r
.31925 .46496 .32888 .47465 .34414 .47019 .33455 .4607 Mtetra
.65 .746 .92 r
.33455 .4607 .34414 .47019 .35952 .46526 .34997 .45581 Mtetra
.649 .748 .922 r
.34997 .45581 .35952 .46526 .37497 .46064 .36549 .45091 Mtetra
.643 .741 .92 r
.36549 .45091 .37497 .46064 .39052 .45591 .38109 .44622 Mtetra
.65 .746 .919 r
.38109 .44622 .39052 .45591 .40618 .45087 .3968 .44125 Mtetra
.655 .75 .92 r
.3968 .44125 .40618 .45087 .42193 .44557 .4126 .43605 Mtetra
.659 .755 .921 r
.4126 .43605 .42193 .44557 .43778 .44033 .42851 .43068 Mtetra
.657 .753 .92 r
.42851 .43068 .43778 .44033 .45371 .43524 .4445 .42533 Mtetra
.654 .747 .918 r
.4445 .42533 .45371 .43524 .46974 .43011 .46059 .42007 Mtetra
.655 .746 .917 r
.46059 .42007 .46974 .43011 .48586 .42489 .47678 .41477 Mtetra
.656 .746 .916 r
.47678 .41477 .48586 .42489 .50208 .41956 .49306 .40938 Mtetra
.657 .746 .915 r
.49306 .40938 .50208 .41956 .5184 .41413 .50944 .40392 Mtetra
.658 .747 .916 r
.50944 .40392 .5184 .41413 .53482 .40861 .52592 .3984 Mtetra
.654 .747 .918 r
.52592 .3984 .53482 .40861 .55133 .40304 .5425 .39298 Mtetra
.653 .751 .922 r
.5425 .39298 .55133 .40304 .56794 .39762 .55918 .38758 Mtetra
.657 .754 .922 r
.55918 .38758 .56794 .39762 .58465 .39226 .57596 .382 Mtetra
.662 .752 .917 r
.57596 .382 .58465 .39226 .60147 .38664 .59283 .37618 Mtetra
.667 .752 .913 r
.59283 .37618 .60147 .38664 .61837 .3807 .6098 .37009 Mtetra
.662 .748 .914 r
.6098 .37009 .61837 .3807 .63537 .37464 .62688 .36418 Mtetra
.661 .752 .917 r
.62688 .36418 .63537 .37464 .65248 .36889 .64406 .35827 Mtetra
.676 .755 .911 r
.64406 .35827 .65248 .36889 .66968 .36265 .66132 .35171 Mtetra
.7 .758 .897 r
.66132 .35171 .66968 .36265 .68692 .35539 .67861 .34397 Mtetra
.685 .745 .897 r
.67861 .34397 .68692 .35539 .70423 .34765 .69603 .33683 Mtetra
.617 .732 .928 r
.69603 .33683 .70423 .34765 .72179 .34248 .71372 .33256 Mtetra
.456 .676 .959 r
.71372 .33256 .72179 .34248 .73976 .3417 .73183 .33287 Mtetra
.407 .679 .972 r
.73183 .33287 .73976 .3417 .75805 .343 .75018 .33374 Mtetra
.545 .741 .967 r
.75018 .33374 .75805 .343 .77636 .34206 .76845 .3313 Mtetra
.706 .775 .906 r
.76845 .3313 .77636 .34206 .79431 .33484 .78641 .32303 Mtetra
.746 .77 .872 r
.78641 .32303 .79431 .33484 .81207 .32443 .80423 .3123 Mtetra
.723 .757 .879 r
.80423 .3123 .81207 .32443 .82993 .31438 .82224 .30282 Mtetra
.578 .72 .94 r
.17444 .50412 .18463 .51343 .1989 .51188 .18883 .5017 Mtetra
.498 .67 .941 r
.18883 .5017 .1989 .51188 .21317 .51155 .20312 .50138 Mtetra
.559 .696 .932 r
.20312 .50138 .21317 .51155 .22776 .50889 .21767 .49956 Mtetra
.69 .755 .901 r
.21767 .49956 .22776 .50889 .24293 .50067 .23273 .49318 Mtetra
.777 .805 .875 r
.23273 .49318 .24293 .50067 .25841 .48923 .24823 .48243 Mtetra
.792 .821 .875 r
.24823 .48243 .25841 .48923 .27388 .47832 .26382 .4709 Mtetra
.732 .807 .911 r
.26382 .4709 .27388 .47832 .28906 .47182 .27919 .46274 Mtetra
.649 .754 .926 r
.27919 .46274 .28906 .47182 .30412 .46809 .29438 .45792 Mtetra
.599 .715 .925 r
.29438 .45792 .30412 .46809 .31925 .46496 .30954 .45482 Mtetra
.623 .725 .919 r
.30954 .45482 .31925 .46496 .33455 .4607 .32486 .4509 Mtetra
.643 .74 .919 r
.32486 .4509 .33455 .4607 .34997 .45581 .34033 .44622 Mtetra
.653 .749 .92 r
.34033 .44622 .34997 .45581 .36549 .45091 .3559 .44114 Mtetra
.647 .744 .92 r
.3559 .44114 .36549 .45091 .38109 .44622 .37156 .43626 Mtetra
.645 .741 .918 r
.37156 .43626 .38109 .44622 .3968 .44125 .38732 .4314 Mtetra
.652 .746 .919 r
.38732 .4314 .3968 .44125 .4126 .43605 .40318 .42629 Mtetra
.655 .75 .92 r
.40318 .42629 .4126 .43605 .42851 .43068 .41914 .42102 Mtetra
.658 .755 .922 r
.41914 .42102 .42851 .43068 .4445 .42533 .43519 .4156 Mtetra
.657 .754 .922 r
.43519 .4156 .4445 .42533 .46059 .42007 .45135 .41016 Mtetra
.657 .751 .92 r
.45135 .41016 .46059 .42007 .47678 .41477 .46759 .40472 Mtetra
.656 .749 .919 r
.46759 .40472 .47678 .41477 .49306 .40938 .48394 .39927 Mtetra
.655 .749 .919 r
.48394 .39927 .49306 .40938 .50944 .40392 .50038 .39383 Mtetra
.654 .751 .921 r
.50038 .39383 .50944 .40392 .52592 .3984 .51692 .38838 Mtetra
.654 .753 .923 r
.51692 .38838 .52592 .3984 .5425 .39298 .53357 .3829 Mtetra
.657 .755 .922 r
.53357 .3829 .5425 .39298 .55918 .38758 .55031 .37728 Mtetra
.66 .752 .918 r
.55031 .37728 .55918 .38758 .57596 .382 .56716 .37149 Mtetra
.666 .751 .914 r
.56716 .37149 .57596 .382 .59283 .37618 .5841 .36544 Mtetra
.664 .747 .912 r
.5841 .36544 .59283 .37618 .6098 .37009 .60114 .35941 Mtetra
.659 .748 .916 r
.60114 .35941 .6098 .37009 .62688 .36418 .61829 .35358 Mtetra
.668 .754 .915 r
.61829 .35358 .62688 .36418 .64406 .35827 .63553 .34733 Mtetra
.684 .754 .904 r
.63553 .34733 .64406 .35827 .66132 .35171 .65285 .3403 Mtetra
.7 .751 .891 r
.65285 .3403 .66132 .35171 .67861 .34397 .67022 .3324 Mtetra
.662 .735 .904 r
.67022 .3324 .67861 .34397 .69603 .33683 .68776 .32626 Mtetra
.567 .718 .943 r
.68776 .32626 .69603 .33683 .71372 .33256 .70562 .32358 Mtetra
.408 .678 .972 r
.70562 .32358 .71372 .33256 .73183 .33287 .72384 .32442 Mtetra
.429 .705 .98 r
.72384 .32442 .73183 .33287 .75018 .33374 .74221 .32447 Mtetra
.609 .772 .959 r
.74221 .32447 .75018 .33374 .76845 .3313 .76042 .31998 Mtetra
.722 .772 .892 r
.76042 .31998 .76845 .3313 .78641 .32303 .77838 .31071 Mtetra
.745 .762 .867 r
.77838 .31071 .78641 .32303 .80423 .3123 .79628 .29983 Mtetra
.707 .747 .883 r
.79628 .29983 .80423 .3123 .82224 .30282 .81445 .29114 Mtetra
.607 .731 .933 r
.16415 .49479 .17444 .50412 .18883 .5017 .17866 .49148 Mtetra
.514 .678 .939 r
.17866 .49148 .18883 .5017 .20312 .50138 .19302 .49073 Mtetra
.532 .677 .93 r
.19302 .49073 .20312 .50138 .21767 .49956 .20752 .48963 Mtetra
.634 .729 .917 r
.20752 .48963 .21767 .49956 .23273 .49318 .22243 .4854 Mtetra
.757 .8 .887 r
.22243 .4854 .23273 .49318 .24823 .48243 .2379 .47578 Mtetra
.792 .826 .879 r
.2379 .47578 .24823 .48243 .26382 .4709 .25357 .46428 Mtetra
.771 .83 .898 r
.25357 .46428 .26382 .4709 .27919 .46274 .26916 .45419 Mtetra
.684 .777 .921 r
.26916 .45419 .27919 .46274 .29438 .45792 .2845 .44798 Mtetra
.62 .729 .925 r
.2845 .44798 .29438 .45792 .30954 .45482 .29976 .44412 Mtetra
.606 .709 .917 r
.29976 .44412 .30954 .45482 .32486 .4509 .31509 .44075 Mtetra
.634 .732 .918 r
.31509 .44075 .32486 .4509 .34033 .44622 .33058 .43634 Mtetra
.648 .743 .919 r
.33058 .43634 .34033 .44622 .3559 .44114 .34621 .4314 Mtetra
.654 .749 .92 r
.34621 .4314 .3559 .44114 .37156 .43626 .36193 .4262 Mtetra
.647 .741 .918 r
.36193 .4262 .37156 .43626 .38732 .4314 .37775 .42122 Mtetra
.647 .74 .917 r
.37775 .42122 .38732 .4314 .40318 .42629 .39365 .41622 Mtetra
.651 .745 .918 r
.39365 .41622 .40318 .42629 .41914 .42102 .40967 .41102 Mtetra
.654 .748 .919 r
.40967 .41102 .41914 .42102 .43519 .4156 .42578 .40568 Mtetra
.655 .752 .921 r
.42578 .40568 .43519 .4156 .45135 .41016 .44199 .40027 Mtetra
.656 .754 .922 r
.44199 .40027 .45135 .41016 .46759 .40472 .4583 .3948 Mtetra
.656 .755 .923 r
.4583 .3948 .46759 .40472 .48394 .39927 .47471 .38929 Mtetra
.47471 .38929 .48394 .39927 .50038 .39383 .49122 .38375 Mtetra
.656 .754 .922 r
.49122 .38375 .50038 .39383 .51692 .38838 .50783 .37816 Mtetra
.658 .753 .92 r
.50783 .37816 .51692 .38838 .53357 .3829 .52454 .37248 Mtetra
.66 .751 .917 r
.52454 .37248 .53357 .3829 .55031 .37728 .54135 .36666 Mtetra
.664 .749 .913 r
.54135 .36666 .55031 .37728 .56716 .37149 .55826 .36063 Mtetra
.664 .745 .911 r
.55826 .36063 .56716 .37149 .5841 .36544 .57527 .35459 Mtetra
.658 .745 .914 r
.57527 .35459 .5841 .36544 .60114 .35941 .59239 .34875 Mtetra
.663 .752 .916 r
.59239 .34875 .60114 .35941 .61829 .35358 .6096 .34266 Mtetra
.675 .752 .909 r
.6096 .34266 .61829 .35358 .63553 .34733 .6269 .33601 Mtetra
.697 .753 .895 r
.6269 .33601 .63553 .34733 .65285 .3403 .64427 .32828 Mtetra
.684 .736 .89 r
.64427 .32828 .65285 .3403 .67022 .3324 .66174 .32105 Mtetra
.629 .73 .92 r
.66174 .32105 .67022 .3324 .68776 .32626 .67943 .31622 Mtetra
.493 .698 .96 r
.67943 .31622 .68776 .32626 .70562 .32358 .69746 .31542 Mtetra
.388 .692 .98 r
.69746 .31542 .70562 .32358 .72384 .32442 .71576 .3161 Mtetra
.478 .737 .984 r
.71576 .3161 .72384 .32442 .74221 .32447 .73412 .31485 Mtetra
.673 .792 .938 r
.73412 .31485 .74221 .32447 .76042 .31998 .75225 .30799 Mtetra
.734 .766 .878 r
.75225 .30799 .76042 .31998 .77838 .31071 .77024 .29784 Mtetra
.736 .752 .865 r
.77024 .29784 .77838 .31071 .79628 .29983 .78826 .28729 Mtetra
.69 .741 .89 r
.78826 .28729 .79628 .29983 .81445 .29114 .80659 .2794 Mtetra
.627 .74 .928 r
.15373 .48549 .16415 .49479 .17866 .49148 .16835 .48151 Mtetra
.552 .701 .939 r
.16835 .48151 .17866 .49148 .19302 .49073 .18284 .47971 Mtetra
.516 .664 .929 r
.18284 .47971 .19302 .49073 .20752 .48963 .19733 .47902 Mtetra
.586 .701 .922 r
.19733 .47902 .20752 .48963 .22243 .4854 .21213 .47635 Mtetra
.71 .77 .899 r
.21213 .47635 .22243 .4854 .2379 .47578 .22746 .46899 Mtetra
.78 .826 .888 r
.22746 .46899 .2379 .47578 .25357 .46428 .24314 .45821 Mtetra
.791 .843 .891 r
.24314 .45821 .25357 .46428 .26916 .45419 .2589 .44696 Mtetra
.732 .817 .918 r
.2589 .44696 .26916 .45419 .2845 .44798 .27447 .43874 Mtetra
.658 .758 .924 r
.27447 .43874 .2845 .44798 .29976 .44412 .28988 .43343 Mtetra
.611 .713 .918 r
.28988 .43343 .29976 .44412 .31509 .44075 .30526 .42985 Mtetra
.617 .712 .913 r
.30526 .42985 .31509 .44075 .33058 .43634 .32076 .42603 Mtetra
.639 .733 .917 r
.32076 .42603 .33058 .43634 .34621 .4314 .33641 .42138 Mtetra
.65 .744 .919 r
.33641 .42138 .34621 .4314 .36193 .4262 .35219 .41628 Mtetra
.654 .749 .919 r
.35219 .41628 .36193 .4262 .37775 .42122 .36807 .41098 Mtetra
.65 .742 .917 r
.36807 .41098 .37775 .42122 .39365 .41622 .38404 .40579 Mtetra
.649 .739 .915 r
.38404 .40579 .39365 .41622 .40967 .41102 .4001 .40063 Mtetra
.651 .741 .916 r
.4001 .40063 .40967 .41102 .42578 .40568 .41627 .39537 Mtetra
.653 .745 .917 r
.41627 .39537 .42578 .40568 .44199 .40027 .43254 .38997 Mtetra
.655 .747 .918 r
.43254 .38997 .44199 .40027 .4583 .3948 .44891 .38447 Mtetra
.656 .748 .918 r
.44891 .38447 .4583 .3948 .47471 .38929 .46538 .37891 Mtetra
.657 .749 .918 r
.46538 .37891 .47471 .38929 .49122 .38375 .48196 .37327 Mtetra
.658 .748 .916 r
.48196 .37327 .49122 .38375 .50783 .37816 .49863 .36753 Mtetra
.661 .748 .914 r
.49863 .36753 .50783 .37816 .52454 .37248 .51541 .36165 Mtetra
.663 .745 .912 r
.51541 .36165 .52454 .37248 .54135 .36666 .53228 .35567 Mtetra
.661 .743 .911 r
.53228 .35567 .54135 .36666 .55826 .36063 .54926 .34971 Mtetra
.658 .744 .914 r
.54926 .34971 .55826 .36063 .57527 .35459 .56634 .34386 Mtetra
.662 .751 .917 r
.56634 .34386 .57527 .35459 .59239 .34875 .58353 .33781 Mtetra
.672 .752 .911 r
.58353 .33781 .59239 .34875 .6096 .34266 .60081 .33128 Mtetra
.689 .75 .898 r
.60081 .33128 .6096 .34266 .6269 .33601 .61816 .3239 Mtetra
.691 .738 .887 r
.61816 .3239 .6269 .33601 .64427 .32828 .6356 .31627 Mtetra
.654 .727 .903 r
.6356 .31627 .64427 .32828 .66174 .32105 .6532 .31039 Mtetra
.569 .721 .945 r
.6532 .31039 .66174 .32105 .67943 .31622 .67106 .30752 Mtetra
.418 .696 .978 r
.67106 .30752 .67943 .31622 .69746 .31542 .68923 .30779 Mtetra
.409 .721 .988 r
.68923 .30779 .69746 .31542 .71576 .3161 .70756 .30761 Mtetra
.572 .78 .977 r
.70756 .30761 .71576 .3161 .73412 .31485 .72586 .30388 Mtetra
.709 .778 .906 r
.72586 .30388 .73412 .31485 .75225 .30799 .74395 .29526 Mtetra
.739 .756 .866 r
.74395 .29526 .75225 .30799 .77024 .29784 .76198 .28455 Mtetra
.717 .74 .869 r
.76198 .28455 .77024 .29784 .78826 .28729 .78017 .27498 Mtetra
.678 .744 .9 r
.78017 .27498 .78826 .28729 .80659 .2794 .79864 .26766 Mtetra
.645 .748 .925 r
.14318 .47627 .15373 .48549 .16835 .48151 .15791 .47164 Mtetra
.599 .722 .931 r
.15791 .47164 .16835 .48151 .18284 .47971 .17257 .4685 Mtetra
.52 .664 .927 r
.17257 .4685 .18284 .47971 .19733 .47902 .1871 .46768 Mtetra
.55 .675 .92 r
.1871 .46768 .19733 .47902 .21213 .47635 .20182 .4661 Mtetra
.639 .73 .914 r
.20182 .4661 .21213 .47635 .22746 .46899 .21693 .46157 Mtetra
.753 .814 .9 r
.21693 .46157 .22746 .46899 .24314 .45821 .23257 .4522 Mtetra
.788 .846 .895 r
.23257 .4522 .24314 .45821 .2589 .44696 .2484 .44107 Mtetra
.779 .851 .905 r
.2484 .44107 .2589 .44696 .27447 .43874 .26423 .43053 Mtetra
.7 .793 .923 r
.26423 .43053 .27447 .43874 .28988 .43343 .27982 .42356 Mtetra
.645 .744 .921 r
.27982 .42356 .28988 .43343 .30526 .42985 .29534 .41866 Mtetra
.613 .707 .912 r
.29534 .41866 .30526 .42985 .32076 .42603 .31087 .41494 Mtetra
.623 .714 .911 r
.31087 .41494 .32076 .42603 .33641 .42138 .32654 .41084 Mtetra
.64 .732 .915 r
.32654 .41084 .33641 .42138 .35219 .41628 .34235 .40604 Mtetra
.649 .743 .918 r
.34235 .40604 .35219 .41628 .36807 .41098 .35827 .40087 Mtetra
.654 .748 .919 r
.35827 .40087 .36807 .41098 .38404 .40579 .37431 .39548 Mtetra
.655 .746 .917 r
.37431 .39548 .38404 .40579 .4001 .40063 .39044 .39003 Mtetra
.652 .74 .914 r
.39044 .39003 .4001 .40063 .41627 .39537 .40667 .38464 Mtetra
.653 .739 .913 r
.40667 .38464 .41627 .39537 .43254 .38997 .423 .37921 Mtetra
.654 .74 .913 r
.423 .37921 .43254 .38997 .44891 .38447 .43943 .37368 Mtetra
.656 .741 .912 r
.43943 .37368 .44891 .38447 .46538 .37891 .45596 .36805 Mtetra
.658 .741 .912 r
.45596 .36805 .46538 .37891 .48196 .37327 .4726 .36232 Mtetra
.659 .741 .911 r
.4726 .36232 .48196 .37327 .49863 .36753 .48933 .35649 Mtetra
.659 .741 .91 r
.48933 .35649 .49863 .36753 .51541 .36165 .50617 .35061 Mtetra
.657 .742 .912 r
.50617 .35061 .51541 .36165 .53228 .35567 .52312 .34479 Mtetra
.658 .747 .915 r
.52312 .34479 .53228 .35567 .54926 .34971 .54016 .33891 Mtetra
.662 .751 .916 r
.54016 .33891 .54926 .34971 .56634 .34386 .55731 .33279 Mtetra
.67 .75 .91 r
.55731 .33279 .56634 .34386 .58353 .33781 .57456 .32631 Mtetra
.684 .747 .899 r
.57456 .32631 .58353 .33781 .60081 .33128 .5919 .3191 Mtetra
.69 .738 .887 r
.5919 .3191 .60081 .33128 .61816 .3239 .60932 .31148 Mtetra
.664 .725 .894 r
.60932 .31148 .61816 .3239 .6356 .31627 .62687 .30507 Mtetra
.612 .73 .929 r
.62687 .30507 .6356 .31627 .6532 .31039 .64461 .30077 Mtetra
.472 .702 .969 r
.64461 .30077 .6532 .31039 .67106 .30752 .66264 .30017 Mtetra
.387 .717 .988 r
.66264 .30017 .67106 .30752 .68923 .30779 .68089 .3002 Mtetra
.477 .76 .993 r
.68089 .3002 .68923 .30779 .70756 .30761 .69923 .29844 Mtetra
.668 .805 .948 r
.69923 .29844 .70756 .30761 .72586 .30388 .71742 .29164 Mtetra
.727 .762 .88 r
.71742 .29164 .72586 .30388 .74395 .29526 .73552 .28176 Mtetra
.734 .743 .859 r
.73552 .28176 .74395 .29526 .76198 .28455 .75363 .27104 Mtetra
.693 .729 .878 r
.75363 .27104 .76198 .28455 .78017 .27498 .77201 .26274 Mtetra
.665 .742 .908 r
.77201 .26274 .78017 .27498 .79864 .26766 .79061 .25598 Mtetra
.658 .754 .921 r
.1325 .46708 .14318 .47627 .15791 .47164 .14734 .46192 Mtetra
.625 .735 .926 r
.14734 .46192 .15791 .47164 .17257 .4685 .16213 .45788 Mtetra
.559 .695 .931 r
.16213 .45788 .17257 .4685 .1871 .46768 .17681 .45586 Mtetra
.53 .659 .918 r
.17681 .45586 .1871 .46768 .20182 .4661 .19149 .45484 Mtetra
.584 .693 .916 r
.19149 .45484 .20182 .4661 .21693 .46157 .20646 .45213 Mtetra
.687 .763 .909 r
.20646 .45213 .21693 .46157 .23257 .4522 .2219 .44565 Mtetra
.767 .837 .906 r
.2219 .44565 .23257 .4522 .2484 .44107 .23772 .43563 Mtetra
.787 .863 .906 r
.23772 .43563 .2484 .44107 .26423 .43053 .25366 .42464 Mtetra
.762 .855 .92 r
.25366 .42464 .26423 .43053 .27982 .42356 .26954 .41495 Mtetra
.689 .786 .924 r
.26954 .41495 .27982 .42356 .29534 .41866 .28525 .40832 Mtetra
.644 .738 .917 r
.28525 .40832 .29534 .41866 .31087 .41494 .30091 .40338 Mtetra
.619 .705 .907 r
.30091 .40338 .31087 .41494 .32654 .41084 .31661 .39937 Mtetra
.624 .71 .908 r
.31661 .39937 .32654 .41084 .34235 .40604 .33243 .39516 Mtetra
.641 .729 .913 r
.33243 .39516 .34235 .40604 .35827 .40087 .34839 .39027 Mtetra
.647 .738 .916 r
.34839 .39027 .35827 .40087 .37431 .39548 .36447 .38509 Mtetra
.652 .745 .918 r
.36447 .38509 .37431 .39548 .39044 .39003 .38066 .37967 Mtetra
.655 .748 .919 r
.38066 .37967 .39044 .39003 .40667 .38464 .39695 .37414 Mtetra
.655 .747 .917 r
.39695 .37414 .40667 .38464 .423 .37921 .41334 .36853 Mtetra
.656 .744 .915 r
.41334 .36853 .423 .37921 .43943 .37368 .42984 .36288 Mtetra
.656 .743 .914 r
.42984 .36288 .43943 .37368 .45596 .36805 .44643 .35719 Mtetra
.44643 .35719 .45596 .36805 .4726 .36232 .46313 .35145 Mtetra
.657 .745 .915 r
.46313 .35145 .4726 .36232 .48933 .35649 .47993 .34566 Mtetra
.657 .747 .916 r
.47993 .34566 .48933 .35649 .50617 .35061 .49684 .3398 Mtetra
.66 .75 .917 r
.49684 .3398 .50617 .35061 .52312 .34479 .51385 .33382 Mtetra
.664 .749 .914 r
.51385 .33382 .52312 .34479 .54016 .33891 .53096 .32759 Mtetra
.67 .746 .907 r
.53096 .32759 .54016 .33891 .55731 .33279 .54818 .32108 Mtetra
.684 .744 .897 r
.54818 .32108 .55731 .33279 .57456 .32631 .56548 .31385 Mtetra
.686 .732 .886 r
.56548 .31385 .57456 .32631 .5919 .3191 .58288 .30641 Mtetra
.665 .721 .891 r
.58288 .30641 .5919 .3191 .60932 .31148 .6004 .29992 Mtetra
.624 .729 .922 r
.6004 .29992 .60932 .31148 .62687 .30507 .61808 .29515 Mtetra
.513 .717 .965 r
.61808 .29515 .62687 .30507 .64461 .30077 .63599 .29352 Mtetra
.394 .726 .99 r
.63599 .29352 .64461 .30077 .66264 .30017 .65413 .29327 Mtetra
.431 .757 .995 r
.65413 .29327 .66264 .30017 .68089 .3002 .67241 .29203 Mtetra
.604 .806 .977 r
.67241 .29203 .68089 .3002 .69923 .29844 .69067 .28714 Mtetra
.711 .776 .903 r
.69067 .28714 .69923 .29844 .71742 .29164 .70883 .27831 Mtetra
.733 .747 .863 r
.70883 .27831 .71742 .29164 .73552 .28176 .72697 .26771 Mtetra
.713 .729 .863 r
.72697 .26771 .73552 .28176 .75363 .27104 .74525 .25812 Mtetra
.679 .736 .894 r
.74525 .25812 .75363 .27104 .77201 .26274 .76377 .25062 Mtetra
.654 .743 .915 r
.76377 .25062 .77201 .26274 .79061 .25598 .7825 .24428 Mtetra
.663 .756 .92 r
.1217 .45781 .1325 .46708 .14734 .46192 .13661 .45242 Mtetra
.646 .748 .924 r
.13661 .45242 .14734 .46192 .16213 .45788 .15153 .4476 Mtetra
.609 .722 .925 r
.15153 .4476 .16213 .45788 .17681 .45586 .16641 .44403 Mtetra
.54 .665 .918 r
.16641 .44403 .17681 .45586 .19149 .45484 .18115 .44266 Mtetra
.549 .663 .911 r
.18115 .44266 .19149 .45484 .20646 .45213 .19604 .44105 Mtetra
.61 .709 .915 r
.19604 .44105 .20646 .45213 .2219 .44565 .21124 .4374 Mtetra
.714 .797 .916 r
.21124 .4374 .2219 .44565 .23772 .43563 .22692 .42972 Mtetra
.769 .855 .914 r
.22692 .42972 .23772 .43563 .25366 .42464 .24288 .4196 Mtetra
.781 .876 .917 r
.24288 .4196 .25366 .42464 .26954 .41495 .25893 .40892 Mtetra
.752 .855 .926 r
.25893 .40892 .26954 .41495 .28525 .40832 .27491 .3996 Mtetra
.688 .787 .926 r
.27491 .3996 .28525 .40832 .30091 .40338 .29076 .39292 Mtetra
.652 .741 .915 r
.29076 .39292 .30091 .40338 .31661 .39937 .3066 .38758 Mtetra
.628 .707 .903 r
.3066 .38758 .31661 .39937 .33243 .39516 .32247 .38315 Mtetra
.625 .703 .902 r
.32247 .38315 .33243 .39516 .34839 .39027 .33845 .37881 Mtetra
.637 .719 .907 r
.33845 .37881 .34839 .39027 .36447 .38509 .35456 .37397 Mtetra
.646 .731 .911 r
.35456 .37397 .36447 .38509 .38066 .37967 .37079 .36875 Mtetra
.65 .737 .913 r
.37079 .36875 .38066 .37967 .39695 .37414 .38713 .36333 Mtetra
.653 .742 .915 r
.38713 .36333 .39695 .37414 .41334 .36853 .40358 .35777 Mtetra
.654 .745 .916 r
.40358 .35777 .41334 .36853 .42984 .36288 .42013 .35211 Mtetra
.656 .746 .916 r
.42013 .35211 .42984 .36288 .44643 .35719 .43679 .34635 Mtetra
.657 .747 .916 r
.43679 .34635 .44643 .35719 .46313 .35145 .45355 .34049 Mtetra
.659 .746 .914 r
.45355 .34049 .46313 .35145 .47993 .34566 .47042 .33453 Mtetra
.662 .745 .912 r
.47042 .33453 .47993 .34566 .49684 .3398 .4874 .32841 Mtetra
.665 .742 .908 r
.4874 .32841 .49684 .3398 .51385 .33382 .50447 .3221 Mtetra
.673 .74 .901 r
.50447 .3221 .51385 .33382 .53096 .32759 .52165 .3154 Mtetra
.682 .735 .891 r
.52165 .3154 .53096 .32759 .54818 .32108 .53893 .30818 Mtetra
.678 .722 .883 r
.53893 .30818 .54818 .32108 .56548 .31385 .55631 .30105 Mtetra
.658 .718 .893 r
.55631 .30105 .56548 .31385 .58288 .30641 .57379 .29483 Mtetra
.625 .73 .922 r
.57379 .29483 .58288 .30641 .6004 .29992 .59142 .28999 Mtetra
.53 .727 .964 r
.59142 .28999 .6004 .29992 .61808 .29515 .60925 .28785 Mtetra
.416 .738 .992 r
.60925 .28785 .61808 .29515 .63599 .29352 .62728 .28713 Mtetra
.414 .762 .995 r
.62728 .28713 .63599 .29352 .65413 .29327 .64548 .28586 Mtetra
.552 .804 .992 r
.64548 .28586 .65413 .29327 .67241 .29203 .66373 .28207 Mtetra
.695 .8 .93 r
.66373 .28207 .67241 .29203 .69067 .28714 .68193 .2741 Mtetra
.726 .751 .872 r
.68193 .2741 .69067 .28714 .70883 .27831 .7001 .264 Mtetra
.724 .73 .855 r
.7001 .264 .70883 .27831 .72697 .26771 .71834 .25362 Mtetra
.686 .72 .875 r
.71834 .25362 .72697 .26771 .74525 .25812 .7368 .24551 Mtetra
.663 .739 .906 r
.7368 .24551 .74525 .25812 .76377 .25062 .75546 .2387 Mtetra
.65 .748 .921 r
.75546 .2387 .76377 .25062 .7825 .24428 .7743 .23246 Mtetra
.655 .749 .919 r
.11082 .44817 .1217 .45781 .13661 .45242 .12575 .443 Mtetra
.66 .756 .921 r
.12575 .443 .13661 .45242 .15153 .4476 .14078 .43763 Mtetra
.635 .738 .923 r
.14078 .43763 .15153 .4476 .16641 .44403 .15579 .43313 Mtetra
.59 .705 .923 r
.15579 .43313 .16641 .44403 .18115 .44266 .17074 .43011 Mtetra
.542 .655 .909 r
.17074 .43011 .18115 .44266 .19604 .44105 .18563 .42869 Mtetra
.567 .67 .908 r
.18563 .42869 .19604 .44105 .21124 .4374 .20072 .42649 Mtetra
.626 .721 .915 r
.20072 .42649 .21124 .4374 .22692 .42972 .21612 .42221 Mtetra
.723 .818 .924 r
.21612 .42221 .22692 .42972 .24288 .4196 .23198 .4141 Mtetra
.764 .868 .925 r
.23198 .4141 .24288 .4196 .25893 .40892 .24805 .4042 Mtetra
.772 .887 .928 r
.24805 .4042 .25893 .40892 .27491 .3996 .2642 .39388 Mtetra
.752 .866 .932 r
.2642 .39388 .27491 .3996 .29076 .39292 .28034 .38446 Mtetra
.694 .798 .929 r
.28034 .38446 .29076 .39292 .3066 .38758 .29635 .37744 Mtetra
.664 .755 .918 r
.29635 .37744 .3066 .38758 .32247 .38315 .31238 .37154 Mtetra
.643 .72 .904 r
.31238 .37154 .32247 .38315 .33845 .37881 .32845 .3664 Mtetra
.634 .703 .895 r
.32845 .3664 .33845 .37881 .35456 .37397 .3446 .36159 Mtetra
.635 .705 .896 r
.3446 .36159 .35456 .37397 .37079 .36875 .36086 .3567 Mtetra
.64 .714 .901 r
.36086 .3567 .37079 .36875 .38713 .36333 .37724 .35161 Mtetra
.648 .724 .904 r
.37724 .35161 .38713 .36333 .40358 .35777 .39374 .34616 Mtetra
.653 .729 .905 r
.39374 .34616 .40358 .35777 .42013 .35211 .41035 .34049 Mtetra
.656 .732 .905 r
.41035 .34049 .42013 .35211 .43679 .34635 .42706 .33466 Mtetra
.658 .733 .904 r
.42706 .33466 .43679 .34635 .45355 .34049 .44389 .32868 Mtetra
.663 .733 .902 r
.44389 .32868 .45355 .34049 .47042 .33453 .46082 .32246 Mtetra
.669 .732 .897 r
.46082 .32246 .47042 .33453 .4874 .32841 .47787 .3159 Mtetra
.672 .726 .89 r
.47787 .3159 .4874 .32841 .50447 .3221 .49501 .3091 Mtetra
.672 .718 .883 r
.49501 .3091 .50447 .3221 .52165 .3154 .51225 .30224 Mtetra
.665 .714 .885 r
.51225 .30224 .52165 .3154 .53893 .30818 .52959 .29569 Mtetra
.648 .721 .902 r
.52959 .29569 .53893 .30818 .55631 .30105 .54705 .28992 Mtetra
.617 .738 .932 r
.54705 .28992 .55631 .30105 .57379 .29483 .56463 .28529 Mtetra
.524 .735 .971 r
.56463 .28529 .57379 .29483 .59142 .28999 .58239 .28311 Mtetra
.426 .756 .995 r
.58239 .28311 .59142 .28999 .60925 .28785 .60033 .28188 Mtetra
.417 .775 .995 r
.60033 .28188 .60925 .28785 .62728 .28713 .61843 .28024 Mtetra
.528 .808 .997 r
.61843 .28024 .62728 .28713 .64548 .28586 .63664 .27676 Mtetra
.68 .815 .948 r
.63664 .27676 .64548 .28586 .66373 .28207 .65484 .26932 Mtetra
.719 .754 .88 r
.65484 .26932 .66373 .28207 .68193 .2741 .67303 .25972 Mtetra
.724 .73 .855 r
.67303 .25972 .68193 .2741 .7001 .264 .69127 .24928 Mtetra
.696 .715 .863 r
.69127 .24928 .7001 .264 .71834 .25362 .70968 .24048 Mtetra
.672 .733 .896 r
.70968 .24048 .71834 .25362 .7368 .24551 .72828 .2332 Mtetra
.652 .743 .916 r
.72828 .2332 .7368 .24551 .75546 .2387 .74707 .22682 Mtetra
.656 .755 .922 r
.74707 .22682 .75546 .2387 .7743 .23246 .76597 .22022 Mtetra
.649 .746 .921 r
.09983 .43839 .11082 .44817 .12575 .443 .11477 .4334 Mtetra
.66 .754 .919 r
.11477 .4334 .12575 .443 .14078 .43763 .12986 .42796 Mtetra
.655 .752 .922 r
.12986 .42796 .14078 .43763 .15579 .43313 .145 .42269 Mtetra
.627 .73 .921 r
.145 .42269 .15579 .43313 .17074 .43011 .16013 .41837 Mtetra
.58 .688 .915 r
.16013 .41837 .17074 .43011 .18563 .42869 .17518 .41564 Mtetra
.551 .652 .902 r
.17518 .41564 .18563 .42869 .20072 .42649 .19024 .41393 Mtetra
.578 .674 .905 r
.19024 .41393 .20072 .42649 .21612 .42221 .20552 .41129 Mtetra
.63 .726 .916 r
.20552 .41129 .21612 .42221 .23198 .4141 .22109 .40676 Mtetra
.716 .825 .932 r
.22109 .40676 .23198 .4141 .24805 .4042 .23706 .39888 Mtetra
.751 .876 .936 r
.23706 .39888 .24805 .4042 .2642 .39388 .25323 .38944 Mtetra
.759 .897 .939 r
.25323 .38944 .2642 .39388 .28034 .38446 .26949 .37956 Mtetra
.747 .888 .943 r
.26949 .37956 .28034 .38446 .29635 .37744 .28577 .37019 Mtetra
.715 .833 .938 r
.28577 .37019 .29635 .37744 .31238 .37154 .30201 .36223 Mtetra
.679 .781 .927 r
.30201 .36223 .31238 .37154 .32845 .3664 .31823 .35567 Mtetra
.662 .747 .913 r
.31823 .35567 .32845 .3664 .3446 .36159 .3345 .34972 Mtetra
.652 .723 .901 r
.3345 .34972 .3446 .36159 .36086 .3567 .35085 .3441 Mtetra
.646 .708 .892 r
.35085 .3441 .36086 .3567 .37724 .35161 .36729 .33867 Mtetra
.647 .704 .888 r
.36729 .33867 .37724 .35161 .39374 .34616 .38384 .33315 Mtetra
.65 .705 .887 r
.38384 .33315 .39374 .34616 .41035 .34049 .4005 .32746 Mtetra
.654 .707 .886 r
.4005 .32746 .41035 .34049 .42706 .33466 .41728 .32156 Mtetra
.657 .708 .885 r
.41728 .32156 .42706 .33466 .44389 .32868 .43416 .31546 Mtetra
.66 .708 .883 r
.43416 .31546 .44389 .32868 .46082 .32246 .45115 .30918 Mtetra
.661 .709 .883 r
.45115 .30918 .46082 .32246 .47787 .3159 .46824 .3028 Mtetra
.657 .712 .888 r
.46824 .3028 .47787 .3159 .49501 .3091 .48544 .29662 Mtetra
.65 .722 .901 r
.48544 .29662 .49501 .3091 .51225 .30224 .50274 .29076 Mtetra
.634 .737 .922 r
.50274 .29076 .51225 .30224 .52959 .29569 .52015 .28553 Mtetra
.587 .748 .954 r
.52015 .28553 .52959 .29569 .54705 .28992 .53769 .28172 Mtetra
.509 .763 .988 r
.53769 .28172 .54705 .28992 .56463 .28529 .55538 .27936 Mtetra
.425 .78 .996 r
.55538 .27936 .56463 .28529 .58239 .28311 .57324 .27753 Mtetra
.434 .795 .996 r
.57324 .27753 .58239 .28311 .60033 .28188 .59126 .27528 Mtetra
.536 .82 .998 r
.59126 .27528 .60033 .28188 .61843 .28024 .6094 .27142 Mtetra
.676 .821 .953 r
.6094 .27142 .61843 .28024 .63664 .27676 .62757 .26412 Mtetra
.713 .755 .885 r
.62757 .26412 .63664 .27676 .65484 .26932 .64577 .25485 Mtetra
.721 .728 .856 r
.64577 .25485 .65484 .26932 .67303 .25972 .66402 .24459 Mtetra
.701 .711 .857 r
.66402 .24459 .67303 .25972 .69127 .24928 .6824 .23537 Mtetra
.675 .722 .885 r
.6824 .23537 .69127 .24928 .70968 .24048 .70096 .22777 Mtetra
.656 .738 .91 r
.70096 .22777 .70968 .24048 .72828 .2332 .71969 .22116 Mtetra
.652 .751 .922 r
.71969 .22116 .72828 .2332 .74707 .22682 .73856 .21471 Mtetra
.662 .755 .919 r
.73856 .21471 .74707 .22682 .76597 .22022 .75753 .20779 Mtetra
.65 .748 .921 r
.08872 .42856 .09983 .43839 .11477 .4334 .10371 .42345 Mtetra
.65 .746 .92 r
.10371 .42345 .11477 .4334 .12986 .42796 .1188 .41833 Mtetra
.663 .757 .921 r
.1188 .41833 .12986 .42796 .145 .42269 .13403 .41271 Mtetra
.65 .748 .921 r
.13403 .41271 .145 .42269 .16013 .41837 .1493 .4075 Mtetra
.624 .723 .918 r
.1493 .4075 .16013 .41837 .17518 .41564 .16456 .40321 Mtetra
.581 .678 .907 r
.16456 .40321 .17518 .41564 .19024 .41393 .17975 .40043 Mtetra
.56 .651 .896 r
.17975 .40043 .19024 .41393 .20552 .41129 .19499 .39839 Mtetra
.584 .673 .901 r
.19499 .39839 .20552 .41129 .22109 .40676 .21043 .3955 Mtetra
.626 .721 .915 r
.21043 .3955 .22109 .40676 .23706 .39888 .22614 .39104 Mtetra
.693 .814 .939 r
.22614 .39104 .23706 .39888 .25323 .38944 .24218 .38397 Mtetra
.732 .874 .947 r
.24218 .38397 .25323 .38944 .26949 .37956 .25844 .37522 Mtetra
.74 .902 .95 r
.25844 .37522 .26949 .37956 .28577 .37019 .2748 .36597 Mtetra
.735 .906 .954 r
.2748 .36597 .28577 .37019 .30201 .36223 .29122 .35683 Mtetra
.723 .88 .954 r
.29122 .35683 .30201 .36223 .31823 .35567 .30766 .34829 Mtetra
.704 .833 .944 r
.30766 .34829 .31823 .35567 .3345 .34972 .32412 .34063 Mtetra
.677 .79 .934 r
.32412 .34063 .3345 .34972 .35085 .3441 .34059 .33399 Mtetra
.667 .767 .925 r
.34059 .33399 .35085 .3441 .36729 .33867 .35714 .32772 Mtetra
.661 .749 .915 r
.35714 .32772 .36729 .33867 .38384 .33315 .37377 .32164 Mtetra
.657 .738 .909 r
.37377 .32164 .38384 .33315 .4005 .32746 .3905 .31565 Mtetra
.656 .733 .906 r
.3905 .31565 .4005 .32746 .41728 .32156 .40734 .30968 Mtetra
.654 .732 .907 r
.40734 .30968 .41728 .32156 .43416 .31546 .42427 .30374 Mtetra
.652 .736 .911 r
.42427 .30374 .43416 .31546 .45115 .30918 .44132 .29788 Mtetra
.646 .744 .921 r
.44132 .29788 .45115 .30918 .46824 .3028 .45846 .29222 Mtetra
.634 .756 .936 r
.45846 .29222 .46824 .3028 .48544 .29662 .47572 .28692 Mtetra
.598 .764 .958 r
.47572 .28692 .48544 .29662 .50274 .29076 .49308 .28267 Mtetra
.548 .784 .986 r
.49308 .28267 .50274 .29076 .52015 .28553 .51057 .27932 Mtetra
.48 .801 1 r
.51057 .27932 .52015 .28553 .53769 .28172 .52821 .27659 Mtetra
.439 .807 .994 r
.52821 .27659 .53769 .28172 .55538 .27936 .546 .27398 Mtetra
.47 .818 .998 r
.546 .27398 .55538 .27936 .57324 .27753 .56394 .27087 Mtetra
.576 .836 .994 r
.56394 .27087 .57324 .27753 .59126 .27528 .58201 .26606 Mtetra
.681 .815 .947 r
.58201 .26606 .59126 .27528 .6094 .27142 .60014 .25855 Mtetra
.709 .751 .884 r
.60014 .25855 .6094 .27142 .62757 .26412 .61834 .24941 Mtetra
.716 .724 .856 r
.61834 .24941 .62757 .26412 .64577 .25485 .63659 .23938 Mtetra
.7 .707 .853 r
.63659 .23938 .64577 .25485 .66402 .24459 .65495 .23008 Mtetra
.676 .713 .877 r
.65495 .23008 .66402 .24459 .6824 .23537 .67348 .22233 Mtetra
.66 .734 .905 r
.67348 .22233 .6824 .23537 .70096 .22777 .69216 .21552 Mtetra
.65 .747 .921 r
.69216 .21552 .70096 .22777 .71969 .22116 .711 .20913 Mtetra
.661 .758 .922 r
.711 .20913 .71969 .22116 .73856 .21471 .72994 .20221 Mtetra
.661 .75 .916 r
.72994 .20221 .73856 .21471 .75753 .20779 .749 .19526 Mtetra
.654 .75 .92 r
.07747 .4187 .08872 .42856 .10371 .42345 .09253 .4134 Mtetra
.649 .746 .92 r
.09253 .4134 .10371 .42345 .1188 .41833 .10766 .40823 Mtetra
.653 .747 .919 r
.10766 .40823 .1188 .41833 .13403 .41271 .1229 .40292 Mtetra
.662 .757 .921 r
.1229 .40292 .13403 .41271 .1493 .4075 .13827 .39723 Mtetra
.649 .745 .92 r
.13827 .39723 .1493 .4075 .16456 .40321 .15368 .39199 Mtetra
.626 .72 .915 r
.15368 .39199 .16456 .40321 .17975 .40043 .16909 .38757 Mtetra
.589 .677 .901 r
.16909 .38757 .17975 .40043 .19499 .39839 .18446 .38445 Mtetra
.569 .65 .89 r
.18446 .38445 .19499 .39839 .21043 .3955 .19987 .38205 Mtetra
.585 .667 .895 r
.19987 .38205 .21043 .3955 .22614 .39104 .21547 .37905 Mtetra
.616 .707 .91 r
.21547 .37905 .22614 .39104 .24218 .38397 .23129 .37485 Mtetra
.657 .781 .939 r
.23129 .37485 .24218 .38397 .25844 .37522 .24737 .36904 Mtetra
.706 .859 .955 r
.24737 .36904 .25844 .37522 .2748 .36597 .2637 .36123 Mtetra
.715 .894 .961 r
.2637 .36123 .2748 .36597 .29122 .35683 .28016 .35283 Mtetra
.71 .911 .965 r
.28016 .35283 .29122 .35683 .30766 .34829 .2967 .34433 Mtetra
.702 .912 .968 r
.2967 .34433 .30766 .34829 .32412 .34063 .31329 .33603 Mtetra
.691 .898 .971 r
.31329 .33603 .32412 .34063 .34059 .33399 .32993 .32818 Mtetra
.683 .871 .97 r
.32993 .32818 .34059 .33399 .35714 .32772 .34663 .32084 Mtetra
.673 .846 .966 r
.34663 .32084 .35714 .32772 .37377 .32164 .36338 .31398 Mtetra
.662 .826 .962 r
.36338 .31398 .37377 .32164 .3905 .31565 .38022 .30755 Mtetra
.651 .814 .962 r
.38022 .30755 .3905 .31565 .40734 .30968 .39713 .30152 Mtetra
.637 .81 .966 r
.39713 .30152 .40734 .30968 .42427 .30374 .41414 .29588 Mtetra
.619 .813 .975 r
.41414 .29588 .42427 .30374 .44132 .29788 .43124 .29068 Mtetra
.592 .821 .987 r
.43124 .29068 .44132 .29788 .45846 .29222 .44845 .28596 Mtetra
.553 .831 .997 r
.44845 .28596 .45846 .29222 .47572 .28692 .46578 .28177 Mtetra
.503 .836 .998 r
.46578 .28177 .47572 .28692 .49308 .28267 .48324 .27804 Mtetra
.473 .834 .994 r
.48324 .27804 .49308 .28267 .51057 .27932 .50083 .27452 Mtetra
.48 .835 .995 r
.50083 .27452 .51057 .27932 .52821 .27659 .51857 .27091 Mtetra
.531 .84 .999 r
.51857 .27091 .52821 .27659 .546 .27398 .53645 .26671 Mtetra
.635 .844 .98 r
.53645 .26671 .546 .27398 .56394 .27087 .55446 .26045 Mtetra
.691 .792 .928 r
.55446 .26045 .56394 .27087 .58201 .26606 .57256 .25255 Mtetra
.706 .739 .877 r
.57256 .25255 .58201 .26606 .60014 .25855 .59074 .2434 Mtetra
.709 .715 .853 r
.59074 .2434 .60014 .25855 .61834 .24941 .60898 .2336 Mtetra
.694 .701 .852 r
.60898 .2336 .61834 .24941 .63659 .23938 .62734 .22453 Mtetra
.674 .709 .874 r
.62734 .22453 .63659 .23938 .65495 .23008 .64584 .21679 Mtetra
.661 .731 .902 r
.64584 .21679 .65495 .23008 .67348 .22233 .66449 .20988 Mtetra
.65 .745 .919 r
.66449 .20988 .67348 .22233 .69216 .21552 .68328 .20343 Mtetra
.659 .757 .923 r
.68328 .20343 .69216 .21552 .711 .20913 .70219 .19657 Mtetra
.661 .75 .916 r
.70219 .19657 .711 .20913 .72994 .20221 .72121 .18955 Mtetra
.657 .748 .917 r
.72121 .18955 .72994 .20221 .749 .19526 .74037 .18266 Mtetra
.658 .753 .921 r
.06608 .40884 .07747 .4187 .09253 .4134 .08121 .40335 Mtetra
.654 .75 .92 r
.08121 .40335 .09253 .4134 .10766 .40823 .09641 .39797 Mtetra
.649 .745 .92 r
.09641 .39797 .10766 .40823 .1229 .40292 .11168 .39272 Mtetra
.654 .749 .92 r
.11168 .39272 .1229 .40292 .13827 .39723 .12707 .38727 Mtetra
.661 .757 .921 r
.12707 .38727 .13827 .39723 .15368 .39199 .14258 .3815 Mtetra
.65 .745 .919 r
.14258 .3815 .15368 .39199 .16909 .38757 .15814 .37612 Mtetra
.631 .721 .912 r
.15814 .37612 .16909 .38757 .18446 .38445 .17372 .37143 Mtetra
.604 .683 .898 r
.17372 .37143 .18446 .38445 .19987 .38205 .1893 .3677 Mtetra
.579 .651 .885 r
.1893 .3677 .19987 .38205 .21547 .37905 .2049 .36488 Mtetra
.586 .658 .887 r
.2049 .36488 .21547 .37905 .23129 .37485 .22065 .36178 Mtetra
.607 .687 .899 r
.22065 .36178 .23129 .37485 .24737 .36904 .23659 .35783 Mtetra
.632 .733 .92 r
.23659 .35783 .24737 .36904 .2637 .36123 .25274 .35292 Mtetra
.659 .804 .953 r
.25274 .35292 .2637 .36123 .28016 .35283 .26908 .34684 Mtetra
.686 .865 .967 r
.26908 .34684 .28016 .35283 .2967 .34433 .28562 .33951 Mtetra
.684 .892 .973 r
.28562 .33951 .2967 .34433 .31329 .33603 .30226 .33193 Mtetra
.671 .906 .977 r
.30226 .33193 .31329 .33603 .32993 .32818 .31898 .32439 Mtetra
.655 .91 .98 r
.31898 .32439 .32993 .32818 .34663 .32084 .33577 .3171 Mtetra
.637 .907 .983 r
.33577 .3171 .34663 .32084 .36338 .31398 .35264 .31016 Mtetra
.619 .902 .986 r
.35264 .31016 .36338 .31398 .38022 .30755 .36957 .30362 Mtetra
.598 .894 .989 r
.36957 .30362 .38022 .30755 .39713 .30152 .38659 .29752 Mtetra
.576 .886 .99 r
.38659 .29752 .39713 .30152 .41414 .29588 .4037 .29187 Mtetra
.553 .879 .991 r
.4037 .29187 .41414 .29588 .43124 .29068 .42091 .28663 Mtetra
.533 .871 .991 r
.42091 .28663 .43124 .29068 .44845 .28596 .43823 .28174 Mtetra
.522 .864 .992 r
.43823 .28174 .44845 .28596 .46578 .28177 .45568 .2771 Mtetra
.528 .859 .995 r
.45568 .2771 .46578 .28177 .48324 .27804 .47325 .27252 Mtetra
.557 .854 .997 r
.47325 .27252 .48324 .27804 .50083 .27452 .49095 .26769 Mtetra
.627 .851 .985 r
.49095 .26769 .50083 .27452 .51857 .27091 .5088 .26157 Mtetra
.676 .81 .947 r
.5088 .26157 .51857 .27091 .53645 .26671 .52676 .25428 Mtetra
.694 .754 .898 r
.52676 .25428 .53645 .26671 .55446 .26045 .54483 .24597 Mtetra
.703 .723 .866 r
.54483 .24597 .55446 .26045 .57256 .25255 .56298 .23679 Mtetra
.701 .704 .849 r
.56298 .23679 .57256 .25255 .59074 .2434 .58122 .2273 Mtetra
.685 .694 .852 r
.58122 .2273 .59074 .2434 .60898 .2336 .59956 .21872 Mtetra
.671 .708 .875 r
.59956 .21872 .60898 .2336 .62734 .22453 .61804 .21113 Mtetra
.66 .73 .902 r
.61804 .21113 .62734 .22453 .64584 .21679 .63665 .20423 Mtetra
.651 .744 .918 r
.63665 .20423 .64584 .21679 .66449 .20988 .6554 .19772 Mtetra
.658 .756 .923 r
.6554 .19772 .66449 .20988 .68328 .20343 .67427 .19087 Mtetra
.661 .752 .917 r
.67427 .19087 .68328 .20343 .70219 .19657 .69326 .1838 Mtetra
.658 .748 .917 r
.69326 .1838 .70219 .19657 .72121 .18955 .71237 .17685 Mtetra
.654 .749 .92 r
.71237 .17685 .72121 .18955 .74037 .18266 .73163 .17001 Mtetra
.661 .756 .921 r
.05455 .39896 .06608 .40884 .08121 .40335 .06975 .39328 Mtetra
.657 .752 .92 r
.06975 .39328 .08121 .40335 .09641 .39797 .08501 .38773 Mtetra
.653 .749 .92 r
.08501 .38773 .09641 .39797 .11168 .39272 .10035 .38227 Mtetra
.65 .745 .919 r
.10035 .38227 .11168 .39272 .12707 .38727 .11577 .37691 Mtetra
.653 .749 .92 r
.11577 .37691 .12707 .38727 .14258 .3815 .13131 .37138 Mtetra
.661 .757 .921 r
.13131 .37138 .14258 .3815 .15814 .37612 .14697 .36551 Mtetra
.653 .747 .918 r
.14697 .36551 .15814 .37612 .17372 .37143 .16269 .35991 Mtetra
.638 .725 .911 r
.16269 .35991 .17372 .37143 .1893 .3677 .17845 .35486 Mtetra
.622 .696 .898 r
.17845 .35486 .1893 .3677 .2049 .36488 .19425 .35035 Mtetra
.594 .657 .882 r
.19425 .35035 .2049 .36488 .22065 .36178 .21006 .34688 Mtetra
.591 .651 .878 r
.21006 .34688 .22065 .36178 .23659 .35783 .22598 .34349 Mtetra
.601 .666 .884 r
.22598 .34349 .23659 .35783 .25274 .35292 .24205 .33968 Mtetra
.618 .693 .897 r
.24205 .33968 .25274 .35292 .26908 .34684 .25831 .3352 Mtetra
.634 .73 .917 r
.25831 .3352 .26908 .34684 .28562 .33951 .27473 .33009 Mtetra
.646 .781 .946 r
.27473 .33009 .28562 .33951 .30226 .33193 .2913 .32442 Mtetra
.651 .828 .968 r
.2913 .32442 .30226 .33193 .31898 .32439 .308 .31828 Mtetra
.656 .862 .978 r
.308 .31828 .31898 .32439 .33577 .3171 .32484 .31164 Mtetra
.645 .875 .984 r
.32484 .31164 .33577 .3171 .35264 .31016 .34178 .30506 Mtetra
.631 .881 .987 r
.34178 .30506 .35264 .31016 .36957 .30362 .35881 .29867 Mtetra
.617 .881 .99 r
.35881 .29867 .36957 .30362 .38659 .29752 .37593 .29251 Mtetra
.605 .877 .992 r
.37593 .29251 .38659 .29752 .4037 .29187 .39315 .28658 Mtetra
.6 .871 .993 r
.39315 .28658 .4037 .29187 .42091 .28663 .41048 .28084 Mtetra
.603 .862 .992 r
.41048 .28084 .42091 .28663 .43823 .28174 .42792 .27516 Mtetra
.63 .855 .985 r
.42792 .27516 .43823 .28174 .45568 .2771 .44549 .26899 Mtetra
.656 .829 .966 r
.44549 .26899 .45568 .2771 .47325 .27252 .46319 .26233 Mtetra
.675 .791 .936 r
.46319 .26233 .47325 .27252 .49095 .26769 .481 .2551 Mtetra
.686 .748 .898 r
.481 .2551 .49095 .26769 .5088 .26157 .49893 .24721 Mtetra
.693 .721 .871 r
.49893 .24721 .5088 .26157 .52676 .25428 .51697 .23862 Mtetra
.694 .703 .854 r
.51697 .23862 .52676 .25428 .54483 .24597 .53509 .2296 Mtetra
.69 .692 .847 r
.53509 .2296 .54483 .24597 .56298 .23679 .55331 .22064 Mtetra
.672 .689 .857 r
.55331 .22064 .56298 .23679 .58122 .2273 .57164 .21273 Mtetra
.667 .712 .882 r
.57164 .21273 .58122 .2273 .59956 .21872 .59008 .20536 Mtetra
.657 .731 .904 r
.59008 .20536 .59956 .21872 .61804 .21113 .60866 .19855 Mtetra
.651 .745 .919 r
.60866 .19855 .61804 .21113 .63665 .20423 .62737 .19201 Mtetra
.658 .757 .923 r
.62737 .19201 .63665 .20423 .6554 .19772 .6462 .1851 Mtetra
.661 .752 .918 r
.6462 .1851 .6554 .19772 .67427 .19087 .66514 .17801 Mtetra
.658 .748 .916 r
.66514 .17801 .67427 .19087 .69326 .1838 .68422 .17101 Mtetra
.655 .749 .919 r
.68422 .17101 .69326 .1838 .71237 .17685 .70344 .1641 Mtetra
.651 .75 .922 r
.70344 .1641 .71237 .17685 .73163 .17001 .7228 .15731 Mtetra
.659 .754 .92 r
.0429 .38889 .05455 .39896 .06975 .39328 .05814 .38324 Mtetra
.661 .756 .921 r
.05814 .38324 .06975 .39328 .08501 .38773 .07348 .37747 Mtetra
.656 .752 .92 r
.07348 .37747 .08501 .38773 .10035 .38227 .08888 .37183 Mtetra
.654 .749 .92 r
.08888 .37183 .10035 .38227 .11577 .37691 .10437 .36626 Mtetra
.65 .745 .919 r
.10437 .36626 .11577 .37691 .13131 .37138 .11994 .36079 Mtetra
.651 .748 .92 r
.11994 .36079 .13131 .37138 .14697 .36551 .13561 .35524 Mtetra
.661 .758 .922 r
.13561 .35524 .14697 .36551 .16269 .35991 .15143 .34927 Mtetra
.657 .751 .919 r
.15143 .34927 .16269 .35991 .17845 .35486 .16732 .34343 Mtetra
.646 .733 .913 r
.16732 .34343 .17845 .35486 .19425 .35035 .18327 .33796 Mtetra
.634 .712 .903 r
.18327 .33796 .19425 .35035 .21006 .34688 .19927 .33288 Mtetra
.622 .681 .885 r
.19927 .33288 .21006 .34688 .22598 .34349 .21534 .32823 Mtetra
.603 .654 .873 r
.21534 .32823 .22598 .34349 .24205 .33968 .23146 .32427 Mtetra
.605 .653 .871 r
.23146 .32427 .24205 .33968 .25831 .3352 .2477 .3202 Mtetra
.612 .664 .876 r
.2477 .3202 .25831 .3352 .27473 .33009 .26409 .31581 Mtetra
.622 .681 .885 r
.26409 .31581 .27473 .33009 .2913 .32442 .28063 .31099 Mtetra
.633 .701 .895 r
.28063 .31099 .2913 .32442 .308 .31828 .29732 .30575 Mtetra
.641 .722 .907 r
.29732 .30575 .308 .31828 .32484 .31164 .31415 .30017 Mtetra
.647 .746 .921 r
.31415 .30017 .32484 .31164 .34178 .30506 .3311 .29432 Mtetra
.652 .763 .931 r
.3311 .29432 .34178 .30506 .35881 .29867 .34818 .28826 Mtetra
.655 .773 .936 r
.34818 .28826 .35881 .29867 .37593 .29251 .36537 .28203 Mtetra
.658 .774 .934 r
.36537 .28203 .37593 .29251 .39315 .28658 .38268 .27562 Mtetra
.663 .767 .927 r
.38268 .27562 .39315 .28658 .41048 .28084 .40011 .269 Mtetra
.668 .752 .914 r
.40011 .269 .41048 .28084 .42792 .27516 .41766 .26211 Mtetra
.672 .733 .896 r
.41766 .26211 .42792 .27516 .44549 .26899 .43533 .25487 Mtetra
.677 .718 .879 r
.43533 .25487 .44549 .26899 .46319 .26233 .45311 .2472 Mtetra
.682 .704 .864 r
.45311 .2472 .46319 .26233 .481 .2551 .471 .23907 Mtetra
.683 .693 .853 r
.471 .23907 .481 .2551 .49893 .24721 .48899 .23061 Mtetra
.683 .685 .846 r
.48899 .23061 .49893 .24721 .51697 .23862 .50708 .22203 Mtetra
.67 .681 .852 r
.50708 .22203 .51697 .23862 .53509 .2296 .52527 .21413 Mtetra
.666 .698 .87 r
.52527 .21413 .53509 .2296 .55331 .22064 .54356 .20666 Mtetra
.662 .722 .894 r
.54356 .20666 .55331 .22064 .57164 .21273 .56197 .19958 Mtetra
.654 .735 .909 r
.56197 .19958 .57164 .21273 .59008 .20536 .58051 .19288 Mtetra
.651 .749 .921 r
.58051 .19288 .59008 .20536 .60866 .19855 .59918 .1863 Mtetra
.66 .758 .923 r
.59918 .1863 .60866 .19855 .62737 .19201 .61796 .17928 Mtetra
.661 .751 .917 r
.61796 .17928 .62737 .19201 .6462 .1851 .63687 .17216 Mtetra
.658 .747 .916 r
.63687 .17216 .6462 .1851 .66514 .17801 .65591 .16514 Mtetra
.655 .749 .919 r
.65591 .16514 .66514 .17801 .68422 .17101 .67508 .15817 Mtetra
.651 .75 .922 r
.67508 .15817 .68422 .17101 .70344 .1641 .6944 .15134 Mtetra
.653 .754 .924 r
.6944 .15134 .70344 .1641 .7228 .15731 .71384 .14436 Mtetra
.653 .748 .92 r
.03115 .37852 .0429 .38889 .05814 .38324 .0464 .37302 Mtetra
.659 .754 .921 r
.0464 .37302 .05814 .38324 .07348 .37747 .06178 .36727 Mtetra
.661 .756 .921 r
.06178 .36727 .07348 .37747 .08888 .37183 .07727 .36141 Mtetra
.657 .752 .92 r
.07727 .36141 .08888 .37183 .10437 .36626 .09282 .35566 Mtetra
.654 .749 .92 r
.09282 .35566 .10437 .36626 .11994 .36079 .10846 .34997 Mtetra
.651 .745 .919 r
.10846 .34997 .11994 .36079 .13561 .35524 .12419 .34436 Mtetra
.651 .746 .919 r
.12419 .34436 .13561 .35524 .15143 .34927 .14001 .33872 Mtetra
.658 .755 .922 r
.14001 .33872 .15143 .34927 .16732 .34343 .15596 .33279 Mtetra
.66 .756 .921 r
.15596 .33279 .16732 .34343 .18327 .33796 .17202 .32675 Mtetra
.655 .744 .916 r
.17202 .32675 .18327 .33796 .19927 .33288 .18816 .32086 Mtetra
.645 .727 .908 r
.18816 .32086 .19927 .33288 .21534 .32823 .20437 .31526 Mtetra
.638 .708 .897 r
.20437 .31526 .21534 .32823 .23146 .32427 .22065 .30989 Mtetra
.631 .683 .88 r
.22065 .30989 .23146 .32427 .2477 .3202 .23703 .30469 Mtetra
.621 .662 .868 r
.23703 .30469 .2477 .3202 .26409 .31581 .25349 .29983 Mtetra
.619 .655 .863 r
.25349 .29983 .26409 .31581 .28063 .31099 .27006 .29499 Mtetra
.623 .658 .863 r
.27006 .29499 .28063 .31099 .29732 .30575 .28677 .28992 Mtetra
.63 .664 .865 r
.28677 .28992 .29732 .30575 .31415 .30017 .30361 .28456 Mtetra
.636 .671 .867 r
.30361 .28456 .31415 .30017 .3311 .29432 .32059 .27887 Mtetra
.642 .677 .868 r
.32059 .27887 .3311 .29432 .34818 .28826 .3377 .27288 Mtetra
.648 .682 .868 r
.3377 .27288 .34818 .28826 .36537 .28203 .35495 .26656 Mtetra
.654 .684 .866 r
.35495 .26656 .36537 .28203 .38268 .27562 .37231 .25994 Mtetra
.659 .684 .863 r
.37231 .25994 .38268 .27562 .40011 .269 .3898 .25299 Mtetra
.663 .682 .858 r
.3898 .25299 .40011 .269 .41766 .26211 .40741 .24572 Mtetra
.667 .679 .852 r
.40741 .24572 .41766 .26211 .43533 .25487 .42514 .23814 Mtetra
.67 .677 .848 r
.42514 .23814 .43533 .25487 .45311 .2472 .44297 .23033 Mtetra
.668 .676 .848 r
.44297 .23033 .45311 .2472 .471 .23907 .46091 .22252 Mtetra
.663 .679 .855 r
.46091 .22252 .471 .23907 .48899 .23061 .47894 .21505 Mtetra
.663 .695 .87 r
.47894 .21505 .48899 .23061 .50708 .22203 .49708 .20774 Mtetra
.661 .716 .889 r
.49708 .20774 .50708 .22203 .52527 .21413 .51533 .20066 Mtetra
.655 .73 .904 r
.51533 .20066 .52527 .21413 .54356 .20666 .53371 .19387 Mtetra
.652 .743 .916 r
.53371 .19387 .54356 .20666 .56197 .19958 .5522 .18723 Mtetra
.654 .754 .923 r
.5522 .18723 .56197 .19958 .58051 .19288 .57082 .18045 Mtetra
.66 .756 .921 r
.57082 .18045 .58051 .19288 .59918 .1863 .58957 .17339 Mtetra
.66 .749 .916 r
.58957 .17339 .59918 .1863 .61796 .17928 .60844 .16627 Mtetra
.657 .747 .916 r
.60844 .16627 .61796 .17928 .63687 .17216 .62743 .15922 Mtetra
.655 .749 .919 r
.62743 .15922 .63687 .17216 .65591 .16514 .64656 .15223 Mtetra
.651 .75 .922 r
.64656 .15223 .65591 .16514 .67508 .15817 .66583 .14534 Mtetra
.653 .754 .924 r
.66583 .14534 .67508 .15817 .6944 .15134 .68524 .13833 Mtetra
.659 .755 .921 r
.68524 .13833 .6944 .15134 .71384 .14436 .70476 .13104 Mtetra
.652 .748 .92 r
.01927 .36801 .03115 .37852 .0464 .37302 .03457 .36246 Mtetra
.653 .748 .92 r
.03457 .36246 .0464 .37302 .06178 .36727 .04997 .35686 Mtetra
.658 .754 .921 r
.04997 .35686 .06178 .36727 .07727 .36141 .06549 .35103 Mtetra
.66 .757 .921 r
.06549 .35103 .07727 .36141 .09282 .35566 .08112 .34508 Mtetra
.658 .753 .92 r
.08112 .34508 .09282 .35566 .10846 .34997 .09683 .3392 Mtetra
.655 .75 .92 r
.09683 .3392 .10846 .34997 .12419 .34436 .11263 .33338 Mtetra
.652 .746 .919 r
.11263 .33338 .12419 .34436 .14001 .33872 .12851 .32761 Mtetra
.651 .745 .918 r
.12851 .32761 .14001 .33872 .15596 .33279 .14449 .32186 Mtetra
.652 .75 .921 r
.14449 .32186 .15596 .33279 .17202 .32675 .16057 .31603 Mtetra
.66 .758 .923 r
.16057 .31603 .17202 .32675 .18816 .32086 .17679 .30989 Mtetra
.659 .754 .92 r
.17679 .30989 .18816 .32086 .20437 .31526 .19311 .30373 Mtetra
.655 .743 .914 r
.19311 .30373 .20437 .31526 .22065 .30989 .20951 .29766 Mtetra
.65 .729 .907 r
.20951 .29766 .22065 .30989 .23703 .30469 .22601 .29175 Mtetra
.646 .716 .899 r
.22601 .29175 .23703 .30469 .25349 .29983 .24259 .28593 Mtetra
.642 .7 .888 r
.24259 .28593 .25349 .29983 .27006 .29499 .25928 .28015 Mtetra
.64 .685 .876 r
.25928 .28015 .27006 .29499 .28677 .28992 .27609 .27434 Mtetra
.64 .674 .867 r
.27609 .27434 .28677 .28992 .30361 .28456 .293 .26845 Mtetra
.641 .668 .86 r
.293 .26845 .30361 .28456 .32059 .27887 .31004 .26243 Mtetra
.643 .665 .856 r
.31004 .26243 .32059 .27887 .3377 .27288 .3272 .25623 Mtetra
.645 .664 .854 r
.3272 .25623 .3377 .27288 .35495 .26656 .34449 .24984 Mtetra
.648 .665 .853 r
.34449 .24984 .35495 .26656 .37231 .25994 .36189 .24325 Mtetra
.651 .668 .853 r
.36189 .24325 .37231 .25994 .3898 .25299 .37941 .23648 Mtetra
.654 .673 .856 r
.37941 .23648 .3898 .25299 .40741 .24572 .39705 .22957 Mtetra
.656 .681 .861 r
.39705 .22957 .40741 .24572 .42514 .23814 .41481 .22258 Mtetra
.658 .691 .87 r
.41481 .22258 .42514 .23814 .44297 .23033 .43267 .21556 Mtetra
.659 .706 .882 r
.43267 .21556 .44297 .23033 .46091 .22252 .45065 .20856 Mtetra
.658 .721 .895 r
.45065 .20856 .46091 .22252 .47894 .21505 .46874 .20166 Mtetra
.655 .731 .905 r
.46874 .20166 .47894 .21505 .49708 .20774 .48695 .19491 Mtetra
.653 .742 .915 r
.48695 .19491 .49708 .20774 .51533 .20066 .50528 .18824 Mtetra
.652 .752 .923 r
.50528 .18824 .51533 .20066 .53371 .19387 .52373 .18155 Mtetra
.659 .758 .923 r
.52373 .18155 .53371 .19387 .5522 .18723 .54231 .17454 Mtetra
.66 .753 .919 r
.54231 .17454 .5522 .18723 .57082 .18045 .56101 .16743 Mtetra
.658 .747 .916 r
.56101 .16743 .57082 .18045 .58957 .17339 .57984 .16033 Mtetra
.656 .748 .917 r
.57984 .16033 .58957 .17339 .60844 .16627 .59879 .15328 Mtetra
.654 .749 .92 r
.59879 .15328 .60844 .16627 .62743 .15922 .61788 .14628 Mtetra
.652 .751 .922 r
.61788 .14628 .62743 .15922 .64656 .15223 .63711 .13934 Mtetra
.654 .755 .924 r
.63711 .13934 .64656 .15223 .66583 .14534 .65646 .13226 Mtetra
.658 .755 .921 r
.65646 .13226 .66583 .14534 .68524 .13833 .67595 .12493 Mtetra
.659 .75 .918 r
.67595 .12493 .68524 .13833 .70476 .13104 .69556 .11754 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
[(-2)] .12586 .2075 1 .99877 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.56863 .04703 m
.57247 .05235 L
s
[(2)] .56094 .0364 .72324 1 Mshowa
.125 Mabswid
.18558 .19702 m
.18832 .19985 L
s
.23703 .17687 m
.23971 .17975 L
s
.28951 .15632 m
.29214 .15925 L
s
.39772 .11395 m
.40023 .11699 L
s
.4535 .09211 m
.45595 .0952 L
s
.51046 .06981 m
.51284 .07294 L
s
.08568 .23614 m
.08851 .23887 L
s
.62804 .02377 m
.63027 .02701 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 233.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00o?ooool2o`0006[ooooo003iooooo`?o000000?oooooo`000?ooool0
JOooool00?Oooooo0_l00004ooooo`;o0000JOooool00?Cooooo0ol00006ooooo`03o`000?oooooo
000006Sooooo003;ooooo`Go00008_ooool2o`0000Wooooo00?o0000ooooool00000J?ooool00<_o
oooo00GoV9RHob4Q8Oo^k^koooooodA4A00Oooooo`?o00002oooool01?l0003oooooooooool0001W
ooooo`00c?ooool00onHV9So8B4Qonk^kP0Mooooo`?o00003_ooool01Ol0003ooooooooooooooooo
000006Kooooo003=ooooo`03oiRHV?lQ8B7ok^k^01[ooooo0_l0000Aooooo`05o`000?oooooooooo
ooooool00000I_ooool00<kooooo00?oMgMgofIVI_ooool05_ooool3o`0001?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1Sooooo`00coooool00ol0003oooooooooo`0Cooooo`;o
00000_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0H_ooool00<_ooooo00Go0000okZj^_ooooooV9RHoa0@400Booooo`?o00006Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo06;ooooo003;ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`04?ooool2o`0001cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Qooooo`00
gOooool3o`0001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Qooooo`00fooo
ool2o`00027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Pooooo`00f?ooool3
o`0002?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Oooooo`00eOooool3o`00
02Kooooo00?o0000ooooooooool01?ooool2o`00067ooooo003Cooooo`;o0000:Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo05kooooo003@ooooo`?o000000?oooooo`000?ooool0
:?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05gooooo003>ooooo`;o00001Ooo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0GOoo
ool00<_ooooo0ol0000`ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0G?ooool0
0<Wooooo0_l0000cooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Foooool00<Ko
oooo0ol0000eooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Foooool00<Cooooo
0_l0000hooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0F_ooool00<7ooooo0ol0
000jooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03_ooool5o`0004Kooooo002n
ooooo`?o0000?Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00kooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A016ooooo`00_?ooool2o`0000?ooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo1_l00003ooooo`03oiRHV?lQ8B7o
k^k^04Oooooo002iooooo`?o0000@oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00kooooo00?oV9RHob4Q8Oo^k^h0A_ooool00;Oooooo0_l00016ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03oooool00omgMgOoIVIVooooo`15ooooo`00]?ooool3o`0004Sooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Cooooo
002booooo`;o0000Boooool00ol0003oooooooooo`0=ooooo`;o00003?ooool01Ol0003o^[Zjoooo
oonHV9So410@04Kooooo002_ooooo`?o0000COooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c016ooooo`00[Oooool2o`00053ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`1Dooooo`00Z_ooool4o`00057ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1Dooooo`00Z?ooool2o`0000Cooooo00?o0000oooo
ooooool0C_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05?ooooo001nooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h08_ooool3o`0005Oooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`1Booooo`00O_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01oooooo0ol0001Joooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool0D_ooool007kooooo00Go410@oooooooo
oooooooooa0@400Mooooo`;o0000GOooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
057ooooo001nooooo`05o`000?ooooooooooooooool000006_ooool3o`0005oooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`1@ooooo`00O_ooool01Ol0003ooooooooooooooooo0000
01Sooooo0_l0001Rooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0D?ooool007ko
oooo00Go410@oooooooooooooooooa0@400Eooooo`?o0000I?ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo04oooooo001nooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool2o`00
00?ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
04kooooo001nooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04?ooool3o`0006Sooooo00?oZ;o[o`00
0?ooool05_ooool00ol0003oooooooooo`1>ooooo`00TOooool2o`0006Sooooo1?nX_n/00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo04gooooo002>ooooo`?o0000J?ooool7ojRoj`03o`00
0?oooooooooo01Cooooo0ol0001>ooooo`00Roooool3o`0006Wooooo0_nX`N/7ojRoj`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool0C?ooool008Wooooo0_l0001Yooooo`KoZ<7[1_nX_n/0
0ol0003oZ;o[ooooo`0Gooooo`03o`000?oooooooooo04_ooooo0026ooooo`?o0000J?ooool00onW
`NcoZ<7[ojS1j`07ojS1j`GoZ;o[00?o0000ojS1joooool06?ooool00ol0003oooooooooo`1:oooo
o`00Q?ooool2o`0000;ooooo00?o0000ooooooooool0Hoooool5ojO1k0WoZ<7[0_nX_n/2ojS1j`03
o`000?nX`N_oZ<7[01Sooooo00?o0000ooooooooool0B_ooool0087ooooo0ol00005ooooo`03o`00
0?oooooooooo063ooooo2?nW`N`7ojS1j`03ojO1k?nX`N_oZ<7[00;oZ<7[00Co0000ojS1jonX`N_o
Z<7[6?ooool00ol0003oooooooooo`19ooooo`00Ooooool2o`0006Wooooo00?oY/3/ojO1k?nW`N`0
1onW`N`4ojS1j`GoYl7/0onX`N/00ol0003oZ<7[ojS1j`02ojS1jaSooooo00?o0000ooooooooool0
B?ooool007cooooo0ol0001Xooooo`GoY/3/2OnW`N`00onX`N_oYl7/ojO1k006ojO1k0;oZ<7[00Go
0000ojS1jonX`N_oZ<7[ojO1k00Hooooo`03o`000?oooooooooo04Sooooo001jooooo`;o0000Iooo
ool2ojNoj`SoY/3/1_nW`N`2ojJok0WoYl7/0_nX`N/00ol0003oZ<7[ojO1k003ojO1k1Sooooo00?o
0000ooooooooool0Aoooool007Oooooo0ol0001Vooooo`KoYko[2?nV`>`2ojO1k0KoY[o/2OnW`N`0
0onX`N_o0000ojO1k005ojO1k1Sooooo00?o0000ooooooooool0A_ooool007Cooooo0ol0001Voooo
o`03ojNoj_nW_n_oYko[00OoYko[1_nV`>`2ojNoj`SoY[o/1_nW`N`2ojJok003ojO1k?l0003oYl7/
00GoYl7/6?ooool00ol0003oooooooooo`16ooooo`00L_ooool2o`0000;ooooo00?o0000oooooooo
ool0H_ooool4ojNojPWoYko[0_nV`>`6ojNoj`SoY[o/0_nW`N`6ojJok003o`000?nW`NcoYl7/00Go
Yl7/6?ooool00ol0003oooooooooo`15ooooo`00Koooool3o`0006Oooooo1onW_nX7ojNoj`03ojRo
j_nW_n_oYko[00OoYko[1_nV_n`00onW_n_oY[o/ojJok006ojJok003o`000?nW`NcoYl7/00CoYl7/
00?oY[o/ooooooooool05_ooool00ol0003oooooooooo`15ooooo`00KOooool2o`0006Oooooo0_nX
_nX8ojNojPCoYko[1OnX_nX9ojNoj`;oY[o/1OnW_n/7ojJok004o`000?nV_ncoYl7/ojO1k0GoY[o/
5oooool2o`0004Kooooo001Zooooo`?o0000I_ooool6ojRojPSoYkoZ00?oYko[ojRoj_nX_nX01_nX
_nX7ojNoj`03ojRoj_nW_n_oYko[00KoYko[1_nV_n`00ol0003oYko[ojJok007ojJok1Sooooo00?o
0000ooooooooool0@oooool006Sooooo0_l0001Vooooo`03ojS0jonX_n[oZ;oZ00OoZ;oZ1_nW_nX:
ojRojPCoYko[1OnX_nX8ojNoj`;oY[o/0onW_n/00ol0003oYko[ojNoj`08ojJok1Oooooo00?o0000
ooooooooool0@oooool006Gooooo0ol0001Vooooo`CoZ<3[2OnX_nX2ojNojPkoZ;oZ00?oYko[ojRo
j_nX_nX01_nX_nX6ojNoj`03ojRoj_nW_n_oYko[00?oYko[00Co0000ojNojonW_n_oYko[1_nV_n`0
0onW_n_oooooooooo`0Fooooo`03o`000?oooooooooo04;ooooo001Sooooo`;o0000Ioooool7ojS0
j`OoZ;oZ00?oZ<7[ojRoj_nX_nX03OnX_nX00onY`>[oZ;oZojRojP07ojRojPCoYko[1?nX_nX5ojNo
j`04o`000?nW_n_oYko[ojNoj`;oY[o/1OnW_n/Hooooo`03o`000?oooooooooo047ooooo001Poooo
o`?o000000?oooooo`000?ooool0I?ooool00onX`^coZ<3[ojS0j`07ojS0j`CoZ;oZ1?nX`N/;ojRo
jPGoZL3Z2OnX_nX00onW_n_oZ;oZojRojP05ojRojPCoYko[00Co0000ojNojonW_n_oZ;oZ2?nW_n/G
ooooo`03o`000?oooooooooo047ooooo000fooooo`Go00008oooool2o`0006Oooooo1OnX`^`9ojS0
j`03ojRoj_nX`N_oZ<7[00GoZ<7[1onX_nX00onX`^coZL3ZojW0jP06ojW0jPKoZ;oZ0_nY`>/8ojRo
jPCoYko[00?o0000ojRoj_nX_nX00_nX_nX8ojNojaOooooo00?o0000ooooooooool0@?ooool003Ko
oooo00GoV9RHob4Q8Oo^k^koooooodA4A00Pooooo`?o0000IOooool2ojK0k0SoZ<;/1_nX`>/2ojO1
k0SoZ<7[1?nX_nX5ojS2k0SoZL3Z0_nX_nX6ojW0j`SoZ;oZ00CoYko[ojRoj_nX_n[o00001OnX_nX6
ojNoj`03ojRoj_oooooooooo01Kooooo00?o0000ooooooooool0?oooool002kooooo1_l00003oooo
o`03oiRHV?lQ8B7ok^k^01kooooo0ol0001Uooooo`KoY/3/2?nX`^`2ojS0j`KoYl7/2?nX`N/00onX
_n[oZ<;/ojS2k006ojS2k0KoZL3Z00?oZ<7/ojW0jonY`>/01onY`>/6ojRojP05ojW0j_nX_n[oZ;oZ
ojRoj_l000001OnX_nX4ojNoj`CoZ;oZ5oooool00ol0003oooooooooo`0oooooo`00>?ooool00onH
V9So8B4Qonk^kP0Kooooo`;o0000IOooool2ojNmjPSoY/3/1_nX`^`2ojJnjPSoYl7/1_nX`N/2ojJo
j`WoZ<;/0_nY`>X5ojS1k0WoZL3[0_nX_nX5ojW0jP;oZ;oZ00?o0000ojRoj_nX_nX01?nX_nX00onW
_n_oZ;oZojRojP05ojRojQOooooo00?o0000ooooooooool0?_ooool003Wooooo00?oMgMgofIVI_oo
ool05oooool3o`0006Cooooo1_nW_NX8ojK0k0;oZ<;/1_nV_^X8ojO1k0;oZ<7[1_nV_n/7ojS2k003
ojJnjonX`NcoZ<7/00KoZ<7/1_nY`>/2ojS1k0SoZL3Z00?oZ;oZo`000?nX_nX00onX_nX2ojVojPSo
Z;oZ6?ooool00ol0003oooooooooo`0mooooo`00>_ooool00ol0003oooooooooo`0Dooooo`;o0000
I?ooool00onW^nOoYkgZojNmjP07ojNmjPKoY/3/00?oYk[WojJnj_nV_^X01onV_^X6ojO1k003ojNl
j?nV_n_oY[o[00OoY[o[1?nX`^`4ojJnj`SoZ<7/0_nY`>/6ojS1k0SoZL3Z00?o0000ojRoj_nY_nX0
1OnY_nX8ojRojQOooooo00?o0000ooooooooool0?Oooool003Kooooo00Go0000okZj^_ooooooV9RH
oa0@400Cooooo`?o00000_ooool00ol0003oooooooooo`1Oooooo`CoYk_W2OnW_NX2ojK0k0GoYk[W
2OnV_^X2ojO1k0GoYkcX2OnV_n/00onX`^coY[k[ojJnj`05ojJnj`KoZ<7/00?oY[k[ojS1k?nX`N`0
1onX`N`6ojW0jP03ojS1k?l0003oZKoZ00OoZKoZ1_nX_nX00onY_n[oooooooooo`0Fooooo`03o`00
0?oooooooooo03cooooo000fooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`04Oooool2o`0006Gooooo
1onW^nL7ojNmjP03ojVghonW^^OoYk[W00KoYk[W1_nV_^X2ojVhi0SoYkcX1_nV_n/2ojRki`SoY[k[
1?nX`N`4ojJnj`WoZ<7/0_nY`>X4ojS1k003o`000?nY_n[oZKoZ00OoZKoZ0_nX_nX5ojVojQKooooo
0ol0000mooooo`00BOooool3o`0006Gooooo00?oZ;SUojNkionW^nL01onW^nL4ojNmjPCoZKOS2?nW
^^L2ojJnjPKoZKST2?nW_>P2ojJoj`KoZ;_W2?nV_^/00onX`NcoY[k[ojJnj`05ojJnj`OoZ<7/00?o
Y[k[ojS1k?nX`N`01?nX`N`00ol0003oZ<7/ojVojP05ojVojP;oZL;/2?nY_nXGooooo`03o`000?oo
oooooooo03_ooooo0017ooooo`;o0000IOooool5ojRhi@WoYk_W00?oYkgZojVghonY]n<01OnY]n<6
ojNji`03ojZbg_nY^>CoZKST00OoZKST1_nW_>P00onZ]^7oZ;_WojRki`07ojRki`KoY[k[00?oZ;[V
ojJnjonV_^/01_nV_^/4ojS1k0GoY[k[1OnX`N`00ol0003oZ<7/ojS1k002ojVojPKoZL;/2?nY_nXG
ooooo`03o`000?oooooooooo03[ooooo0014ooooo`?o0000I?ooool00onX]>7oZ;SUojRhi@06ojRh
i@KoYk_W0_nY/Mh8ojVgh`CoYk[W1?nZ/]h8ojVhi0CoYkcX1?nZ]^49ojRki`;oY[k[1OnX^^H8ojJn
j`03ojS1k?nV_^_oY[k[00KoY[k[1?nX`N`00ol0003oZ<7/ojJoj`09ojW2k0KoZKoZ00?oZL7[oooo
ooooool05_ooool00ol0003oooooooooo`0iooooo`00@Oooool3o`0006Cooooo1OnX]>48ojRhi@;o
Yk_W1_nY/Mh8ojVgh`03ojNjionZ/]koZ[;N00GoZ[;N2?nY^>@00onW_>SoZ[KQojZfh@05ojZfh@Oo
Z;_W00?oZkGOojRji_nX^^H01_nX^^H6ojJnj`;oZK_V2OnV_^/2ojS1k003ojJojol0003oY[o[00;o
Y[o[2OnY`^`2ojVojPGoZL7[5oooool00ol0003oooooooooo`0iooooo`00?oooool3o`0006?ooooo
00?oZ;3NojRdhOnX]>401_nX]>46ojRhi@03ojV]f_nY/MkoZK7N00OoZK7N1_nY]n<00on[[][oZ[;N
ojZbgP07ojZbgPKoZKST00?o[;3KojZfhOnZ]^401_nZ]^44ojRki`GoZkGO2?nX^^H2ojJnj`KoZK_V
1onV_^/01OnX^nOoY[o[ojJojonV_n_o000000CoY[o[1_nY`^`2ojK0k0SoZL7[5oooool00ol0003o
ooooooooo`0hooooo`00??ooool3o`0000?ooooo00?o0000ooooooooool0G_ooool4ojR`gPOoZ;CQ
1?nX^>D4ojV]fPSoZK7N1?nY]n<4oj^^fPWoZ[;N0_nY^>@5ojb`f`SoZ[KQ00?oZ;_Woj^egon[]Ml0
1_n[]Ml6ojRjiP03ojbegonY^nKoZK_V00OoZK_V1?nV_^/4ojRki`;oY[o[00?o0000ojJojonV_n/0
0onV_n/2ojW2k0KoY/3/2?nY`N/Fooooo`03o`000?oooooooooo00Oooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0/ooooo`00>_ooool2o`0006Gooooo1onX/=h7ojRdh@03ojRhiOnY[M[oZJgJ00GoZJgJ
2?nY/Mh00onY]n?oZjkJoj^^fP05oj^^fPOoZ[;N00?o/;7Hojb`fon//=/01_n//=/6ojZfh@03ojna
f_n[]MooZkGO00OoZkGO1?nX^^H4ojbeg`WoZK_V00?oY[k[ojRkionX^nL01OnX^nL00onV_n_o0000
ojJoj`03ojJoj`03ojNlj?nV`>coY/3/00OoY/3/1_nY`N/00onW`Ncoooooooooo`0Eooooo`03o`00
0?oooooooooo00Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0/ooooo`00=oooool3o`0006Gooooo
00?oYjkLojR`g_nX/=h01_nX/=h6ojRdh@03oj^]fOnY[M[oZJgJ00KoZJgJ1onY/Mh00on^[mSoZjkJ
oj^^fP07oj^^fPCoZ[;N1?n`/MP8ojb`f`;oZ[KQ1On_/MX9oj^eg`03ojRji_n/]Moo[;GO00Go[;GO
1_nY^nH2ojffh0SoZ;_W0_nV_n/00ol0003oY[o[ojNlj003ojNlj0WoY/3/0_nY`N/5ojO1k1Oooooo
00?o0000ooooooooool01Oooool01Ol@413ooooooooooooooooo410@02cooooo000eooooo`;o0000
IOooool5ojN^g0SoZ;3N0_nX]>45oj^]f@SoZJgJ1?nY/Mh4ojj_f0WoZjkJ00?oZ[;Nok2af?n`/MP0
1?n`/MP7ojb`f`03ok>dfOn_/M[o[k7J00Ko[k7J1on[]Ml00ona/m[o[;GOojbeg`07ojbeg`;oZK_V
1_n]]^08ojRki`03ojJojol0003oYkcX00GoYkcX1_nV`>`2ojJnjPSoYl7/5_ooool00ol0003ooooo
ooooo`05ooooo`05o`000?ooooooooooooooool00000;?ooool003;ooooo0ol0001Tooooo`03ojN/
fonW[]coYjkL00KoYjkL1_nX/=h9oj^]f@SoZJgJ00?oZK7Nojj_f?n^[mP01On^[mP7oj^^fP03ok6c
f_n`/MSo/;7H00Ko/;7H1On//=/3ok>df@So[k7J1?n[]Ml4ok6cfPOo[;GO00?o/kCJojffh?n]]^00
1on]]^06ojRki`03ojbhh_nW_>So000000OoYkcX0_nV`>`6ojJnjPSoYl7/5_ooool00ol0003ooooo
ooooo`04ooooo`05o`000?ooooooooooooooool00000;?ooool0033ooooo0_l0001Uooooo`CoYjcK
1onW[]`4ojR`gPcoZjgI1_nY[MX00on^/M[o[ZoHojj_f006ojj_f0CoZjkJ1Ona/mX7ok2af0?o[;3K
1Onc]=T9ojnafP03oj^egona/m[o/K?J00Go/K?J1On/]Ml3ok>dfPWo[KKP0_nX^nL5ojbhhP03o`00
0?nW_>SoYkcX00CoYkcX00?o[;_UojJnj_nV_^X01_nV_^X6ojO1k0;oY[o[5oooool00ol0003ooooo
ooooo`03ooooo`05oa0@4?ooooooooooooooool@4100;?ooool002gooooo0ol000000ooooooo0000
ooooo`1Rooooo`KoYjcK2?nW[]`00onX/=koZjgIoj^]f@0=oj^]f@;oZJgJ1On^/MX8ojj_f003oj^^
f_na/m[o/K?J00Go/K?J2?n`/MP00on//=_o/kCIok>df@05ok>df@Oo[k7J00?o]KOJok6cf_na/mX0
1_na/mX3ojbeg`Ko/kCJ1on]]^000onc]]_o[;SRojbhhP05ojbhhP03o`000?nW_>SoYkcX00;oYkcX
1?n/^nD8ojJnjP;oYl7/1_nV_n/Fooooo`;o00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg02co
oooo000Zooooo`?o0000I_ooool00onVZm[oYjcKojN/f`06ojN/f`KoYjkL00?oZZgJoj^]fOn[[MT0
3On[[MT00on^]=go[[7JojjafP06ojjafPKo[ZoH00?o/KSNok6cf_na/mX01ona/mX6ok2af003ok>i
gOnc]=Wo/kCI00Ko/kCI1?n_/MX5okFgfPSo/K?J00?o[;GOok>df_nc]=X01Onc]=X4ojffh0Go/kKK
1_n/^>800ol0003o[;SRojNlj007ojbki@KoY[kZ00?oZKgWojJojonV_n/01onV_n/Cooooo`;o0000
00?oooooo`000?ooool00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02cooooo000Xooooo`;o0000
I_ooool5ojJ[fPOoYjcK1?nW[]`4ojZ]fPcoZjgI1?n^]=d7ojjafPCo[ZoH1?na^=h8ok6cfPCo/;7H
1?nc^Md8ok>df@03ojnaf_ne]m[o]KOJ00Ko]KOJ1_na/mX00ong^M_o/kCJok>dfP07ok>dfP03ojff
h?nc]]_o/kKK00Ko/kKK1On/^>800ol0003o/[OLojbki@07ojbki@CoY[kZ1?nY_NL9ojJojaKooooo
00?o0000ooooooooool0<_ooool002Gooooo0ol0001Uooooo`03ojFZf_nVZm[oYZ_J00KoYZ_J1onW
[=/00onW[]coZZgJojZ]fP05ojZ]fPWoZjgI1_n^]=d8ojjafP03ojj_f?na^=ko/KSN00Go/KSN2?na
/mX00on`/MSo/kWMok>ig@05ok>ig@Ko/kCI00?o];gPokFgf_ne]mX01one]mX4ok6cfPCo]kWK1onc
]=X00onh^]_o/kKKok>ff`07ok>ff`Co[;SR0_l00002ok:gg0So[;_U00?oY[kZojVmionY_NL01OnY
_NL6ojJoj`;oYkkZ5_ooool00ol0003oooooooooo`0booooo`008oooool2o`0006Gooooo1OnUZ]X7
ojJ[fPKoYjcK00?oZJkKojZ]f_nZ[MX01_nZ[MX7oj^]f@03ojfghOn^]=go[[CM00Ko[[CM1_n^/MX0
0on__nGo/KSNok6hgP06ok6hgPOo/K?J00?o/L7Uok>igOnc^Md01_nc^Md4ok>df@Co];gP2One]mX0
0ona/m[o]kWKokNif`05okNif`Go/kCJ0onh^]/9ok>ff`?o000000?o/[OLo`000?nb]m`00_nb]m`6
ojbki@03ojnhgonY_NOoZKgW00OoZKgW0_nV_n/6ojNnjQKooooo00?o0000ooooooooool0<Oooool0
023ooooo0ol0001Tooooo`03ojFYf_nUZ][oYJ[J00GoYJ[J2?nVZmX2ojN/f`GoZJkK2?nZ[MX4oj^]
f@Co[KOQ1on^]=d4ojjafPCo[koU2?na^=h4ok6cfPCo/L7U2?nc^Md00onc]=Wo];gPokBmh005okBm
h0Oo]KOJ00?o]L3RokNifong^M/01_ng^M/3ok>dfPKo^;[K1Onc]]/3o`0000Go/[OL00Co0000ok:g
g?nb]mco/[OL0_n/^nD5ojnhg`OoZKgW00?o[KcTojNnj_nW_^X01_nW_^XGooooo`03o`000?oooooo
oooo033ooooo000Oooooo`;o0000Hoooool5ojFYfPOoYJ[J1_nVZmX00onX[mcoZJkKojV^f`06ojV^
f`SoZZgJ00?oZjgIojfghOn]]n401On]]n47ojjdg@03ojjaf_n__nGo[koU00Go[koU2?na^=h00ona
/m[o/L7Uok71i@05ok71i@Ko/kWM00?o/<[]okBmh?nd_N001ond_N04okFgfPCo]L3R2?ng^M/00onc
]=[o^;[KokRjf`05okRjf`;o/kKK0ol00004okVjfPGo/[OL00?o0000ok:gg?ni^]X02?n_^=l4ojVm
i`Co[KcT2?nW_^XFooooo`03o`000?oooooooooo033ooooo000Oooooo`03o`000?oooooo000005oo
oooo00?oY:[KojFYf_nUZMX01OnUZMX7ojFZfPCoYZ_J1?nX[m`8ojV^f`KoZZgJ00?o[;_UojfghOn]
]n401_n]]n46ojjdg@;o[<[_2?n__nD6ok6hgP03ojg?l_na`NGo/L7U00Ko/L7U1?nc^Md4ok3:k@Wo
];gP00?o]KOJokG0h_ne`>801One`>86okNif`03okK1h_nh^]_o^;[K00Go^;[K0ol00008okVjfPGo
/[OL00?o0000okVjf_ni^]X02?n_^=l00onY_NOo[KcTojfli005ojfli0KoYkkZ00?oZ[gXoooooooo
ool05Oooool00ol0003oooooooooo`0_ooooo`003?ooool5o`0000?ooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP06ooooo`04o`000?ooooooooooo`0005_ooooo1OnTZ]/7ojFYfPOoYJ[J00?oYZ_JojR_
g?nX[m`01OnX[m`8ojV^f`;oZZgJ1On/^nD8ojfgh@;o[[CM1_n/b^l8ojnoi@;o/KSN1On]co88ok71
i@03ok>igOn`b^go/<[]00Go/<[]1ond_N000on^d?;o]L3RokG0hP06okG0hPCo]kWK1?nf`N83okRj
f`?o000000?o^;[KokS1hOni^]X02?ni^]X3ok:gg0;o^K[J00Co0000okVjf_ni^][o^K[J1_n_^=l0
0onf^]co[KcTojfli007ojfli0;oYkkZ1OnZ_NPGooooo`03o`000?oooooooooo02kooooo000<oooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo0_l0
0002ooooo`03o`000?oooooooooo05Gooooo00?oY:_LojBZfonTZ]/01OnTZ]/7ojFYfPKoYJ[J00?o
YjoMojR_g?nX[m`01_nX[m`7ojV^f`03oj_0jOn/^nGo[;_U00Ko[;_U1_n]]n42ojODm`So[<[_1_n_
_nD2oj3Io0Oo[Lob1_na`ND2oj;HnPOo/<[]1?nd_N05ojk@lPSo]L3R00?o]kWKokK1h_nf`N801?nf
`N83o`0000?o^;[K0onh`N49okVjfP03ok:gg?ni^][o^K[J00;o^K[J00?o0000okVjf_ni^]X01?n_
^=l4okJjg0Oo[KcT00?o/K[PojZmj?nZ_NP01_nZ_NPFooooo`03o`000?oooooooooo02kooooo0004
ooooo`Ko00000oooool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41001Ooo
ool2o`0000Cooooo00?o0000ooooooooool0DOooool5ojB[g0OoY:[K1onUZMX2ojFZfPGoYjoM2?nX
[m`4ojV^f`CoZl3Y1on/^nD4ojfgh@GoYmCg2?n/b^l2ojnoi@KoX=Wl1on]co82ok71i@KoX]Sj1on`
b^d00ond_N3o[]3bojk@lP06ojk@lPKo]L3R00?o[M;cokK1h_nf`N800_nf`N83o`000004okK1h_nh
^]_o^;[KokRjf`Ko^<7Q1oni^]X00oni`=oo^K[JokVjfP04okVjfP04o`000?ni^][o^K[Jojnhg`Oo
][[L1?n]_>@4ok6jh0SoZ[gX5_ooool00ol0003oooooooooo`0]ooooo`003_ooool00onHV9So8B4Q
onk^kP03ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo04gooooo00?oXjcMojB[g?nTZm`01_nTZm`6ojBZf`KoYJWJ00?oYJkNojN_gOnW
[md01_nW[md8ojR_g003ojV^fon[`>WoZl3Y00GoZl3Y1on/^nD00on]]n7oYmCgojODm`06ojODm`Ko
[<[_0_n>f_l8oj3Io0?o[Lob1On7eol7oj;HnP?o/<[]1OnCe_h8ojk@lP;o]L3R1On]d_<00onf`N;o
0000o`000005okK1hP03okRjfonh`N7o^<7Q00Go^<7Q1?ni^]X5okW0g`Go^K[J00?o0000okVjf_nk
_m`02Onf^]`00on]_>Co/K[Pok6jh005ok6jh0KoZ[gX00?o[KkVooooooooool05Oooool00ol0003o
ooooooooo`0/ooooo`003oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool0
00001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04Wooooo1OnS[=d7ojB[g0Oo
Y:[K0_nUZMX5ojF^gPSoYjoM1_nX[m`00onYa>goZl3Yoj_0j@06oj_0j@Ko[;_U0onQf_`8ojODm`;o
[<[_1_n>f_l6oj3Io0?oN]Gn1on7eol3oj;HnPCoN=7o2?nCe_h6ojk@lP;oRM7o1?n]d_<3o`0000Ko
]/7R00?o[]3bokS1hOnh`N401onh`N400oni^][o^L3OokW0g`06okW0g`Go^K[J00?o0000ok^og?nk
_m`01onf^]`00onk_]_o/K[Pok6jh006ok6jh0CoZ[gX1?n]_^HEooooo`;o0000;_ooool0013ooooo
00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00?ooooo0_l00007ooooo`03
o`000?oooooooooo04Kooooo00?oXjoPoj>/gOnS[=d01OnS[=d7ojB[g0GoY:[K00?oY:gNojF^g_nU
[]h01_nU[]h8ojN_g@;oZ:oL1OnYa>d8oj_0j@;o[;_U2?nQf_`3ojODm`GoQm_n1on>f_l2oj3Io0Oo
N]Gn0on7eol5og3>oPKoN=7o2?nCe_h2ojk@lPKoRM7o0ol00004ojgBl`;o]/7R1On^d?87okS1h@03
ok7<k_ni`=oo^L3O00Oo^L3O0oni^]X3ok^og003o`000?nk_mco^koL00Go][[L0onk_]/8ok6jh003
ojZmj?n]_^Ko[KkV00Go[KkV5_ooool00ol0003oooooooooo`0[ooooo`003?ooool01Ol0003o^[Zj
oooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0@_ooool5oj>_h0KoXjcM2?nTZm`00onTZ]_oY:gNojB]gP03ojB]
gPSoYJkN1_nW[md00onXa^ooZLC]ojW4k@06ojW4k@KoZl3Y0onJg?d7oj7Jo0?oQMgm1on7foh3ohkJ
o`KoNMGn0omjeOh5og[=o`OoL<kn1_mhdOl4oi?FoPGoKl_n0on9dOl3o`000004ohWAoon]d_?o[M;c
ojgBl`CoQlko1on^d?84okS1h@Co/Lc^2Oni`=l00oni^][o^koLok^og003ok^og003o`000?nk_mco
][[L00;o][[L1_nk_]/6ok6jh003okNmg_n]_^Ko[KkV00Oo[KkV5Oooool00ol0003oooooooooo`0[
ooooo`003?ooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0?_ooool00onT/n?oXjoPoj>_
h005oj>_h0OoXjcM1_nTZm`00onRZmgoY:gNojB]gP05ojB]gPSoYJkN0_nW[md5ojS6k`SoZLC]0_n[
`>T8oi[Lo@;oXM[l1on5gOd3ohOKoPKoP=Ko0omieOh5ohc8o0OoN/go0om`c_h5oh;3o0OoK<On1_m_
boh3o`000003ohWAoomZa_koJ/Kn00;oJ/Kn1on7c_l7ojk@lP03okS1hOnac>ko/Lc^00Go/Lc^1oni
`=l00onfa^Oo^koLok^og004ok^og004o`000?nk_mco^koLokJjg0Oo^kkK1?na^^04okNmgPOo[KkV
00?o/;gSooooooooool05?ooool00ol0003oooooooooo`0Zooooo`007_ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo03[ooooo1OnT/n<7oj>_h0OoXjcM0_nTZm`5oj:[g@OoY:gN1_nU
[]h00onWaNooZ<K_ojS6k`06ojS6k`KoZLC]0onIg_h7oi[Lo@CoR=km0on5gOd5ohgDo`KoP=Ko0onI
`oD7ohc8o0?oN/go1OnF_o@8oh;3o0?oK<On1?n6_?P01?m]`Oko0000o`000?l00003ofg1oPKoJ/Kn
1on7c_l3ojk@lPCoSLgm1onac>h4okW0g`Go]/KW1_nk_m`00ol0003o^/?Qok^nf`08ok^nf`03ok6j
h?ng_Mko]kgN00Go]kgN1?n]_^H4ok2mhaKooooo00?o0000ooooooooool0:Oooool001gooooo0ol0
000;ooooo`03o`000?oooooooooo03Kooooo00?oYKOVojBchonT/n<01_nT/n<6oj>_h0KoXjcM00?o
XJWMoj:[gOnRZmd01_nRZmd7ojB]gP;oYJkN1OnWaNl8ojS6k`;oZLC]2?nIg_h2oi[Lo@KoR=km0_nG
d_`8ohgDo`;oP=Ko1onI`oD5ohc8o0;oX[c/2?nF_o@6oh;3o0;oWKc^1?n6_?P3o`0000OoKL7n1_mZ
a_h3ohO>o`CoJL?n1on=cOd7ok7<kP03okW0gonfa^Oo]/KW00Go]/KW1?nk_m`3ok[3h@03o`000?nj
`n7o^kkK00Ko^kkK00?o_L7MokNmg_ng_Mh01ong_Mh00on]_^Ko/;gSok2mh`04ok2mhaKooooo00?o
0000ooooooooool0:Oooool001gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0b
ooooo`GoYKOV1onT/n<7oj>_h0;oXjcM1OnQZMd7oj:[g@KoY:gN0_nV`nh7ojO5k`KoZ<K_1?nJh?d4
oiWNoPKoSN7m0_n8g_d6oiOBo0KoSMCo0onR`Nl8oiW3m@03ohc8o?nR_>coX[c/00CoX[c/2?nF_o@2
oh;3o0KoWKc^0ol00004ohJln0?oKL7n1?n7^_H7ofZlo@KoJL?n1on=cOd3ok7<kP?oV/kj2Onfa^L0
0onk_mco^/?Qok[3h@04ok[3h@03o`000?nk_]_o^kkK00?o^kkK1?nm`Md7okNmgP03okc0gOn`_N?o
/;gS00Ko/;gS5_ooool00ol0003oooooooooo`0Xooooo`007Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo02oooooo00?oY[[XojFgi_nU]nH01OnU]nH7ojBch`?oXjoP0onOZ=`8oj6Y
g@OoXZ_M0_nT[Mh6ojK3kPOoYlG_0_nXa^l7oi[Po@?oTn;m1_n=hOd3oik@n@OoUm;l0_n=e?l7oj;1
k`KoVL?e00?oY[SVoj:lk?nR_>`01_nR_>`6oiJom003ojFhi_nM_>koWKc^00?oWKc^0ol000001?nM
_>koQ[chohJln?n6_?P4oinjk0OoQk[f1omZ_?d6ofW3oP?oSLgm1?m^`Oh6oi[>nPOo]/KW00?oZlkb
ok[3hOnj`n401Onj`n400ol0003o^kkKok^nf`02ok^nf`Go_L7M1?ng_Mh5okc0g@Ko/;gS00?o];oR
ooooooooool05Oooool00ol0003oooooooooo`0Wooooo`007Oooool2o`0000oooooo00?o0000oooo
ooooool0:oooool5ojJjj0OoYKOV1OnT/n<00onNYmcoWjSLoinXg005oinXg0OoXJWM1_nRZmd2ojFn
j`SoY/?^1OnWaNl4oigQo@?oV^3m1onCh_d2ohgQo@SoW]3i0onGd_`4ojFnj`SoX/7_0_nI`oD5ojJh
iPSoX[c/0_nF_o@5ojFhiP;oWKc^0_l00003oiflkP03ojRgi?nO^^coWk[/00KoWk[/1on7^_H3ofZl
o@GoPkOg1_mT^Od6ofk1oPKoV/kj1?nfa^L4oj_>lPOo^/?Q00?o0000ok^nfonm`Md01onm`Md00ong
_Mko_<3Mokc0g@05okc0g@Co/;gS1?nd_n8Fooooo`03o`000?oooooooooo02Oooooo000Mooooo`03
o`000?oooooooooo00oooooo0_l0000Xooooo`03ojNnjOnV^^SoY[[X00KoY[[X1onU]nH00onT/n?o
WZOLoijWg003oijWg0OoWjSL1onQZMd2oj:[g@KoYKk[2?nV`nh00onWaNooWN7moigQo@05oigQo@?o
VNCm1_nCh_d3oj??m`OoW]3i00?oY[cYojFnjonU_^/01_nU_^/6oj;1k`03ojRfhonV^>KoY[SV00Ko
Y[SV1_nR_>`00onZ]^;oYKSVojFhiP04ojFhiP?o00000onM_>h4ojRgi0SoWk[/0on7^_H4oinjk0So
PkOg1_mT^Od6ofk1oPKoV/kj00?o]/KWoj_>l_n[c_801On[c_86ok[3h@03okG7iol0003o_L7M00Ko
_L7M00?o^lCPokc0gOnl`=d01onl`=d00on`_N?o];oRokBohP05okBohQKooooo00?o0000oooooooo
ool09_ooool001gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Rooooo`GoYkkY
1onV^^P6ojFgiP03oijYg_nNYmcoWZOL00GoWZOL1onOZ=`5oj6Yg@;oY;SX2?nU_^/6ojK3kPCoXN7l
0_nMhOd8oiWTo@03oi?RoOnScoOoXlog00KoXlog0_nNd?T5ojJlj@SoYKk[0_nR`Nl5ojRfh`SoY[SV
0_nR_>`5ojZfhP;oYKSV0ol00003ojFhiP03oiflk_nX]nCoZ;OT00GoZ;OT1_nO^^`00onZ^>CoWk[/
oinjk006oinjk0KoPkOg00?oW;[]ogRcn?mh/oP01Omh/oP6of>go0KoN/;n2?n[c_82ok[3h@Go]LOW
00?o0000okg1gOnm`Md00onm`Md3ok_4h0Oo_<3M00?o_/?MokBoh_nd_n801ond_n8Fooooo`03o`00
0?oooooooooo02Gooooo000Mooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool07_oo
ool2ojS1j`OoYkkY1onV^^P2ojFgiPGoWZWN1_nNYm`8oinXg003oj6YgOnT^>SoY;SX00CoY;SX2?nU
_^/2ojK3kPKoXN7l0onNi_`7oiWTo@?oY]3f1_nScoL00onW^nSoY[cYojJlj@06ojJlj@KoYKk[00?o
ZKGRojRfhonX]^<01_nX]^<6ojJhiP03ojbgh_nZ]^;oZ[KR00CoZ[KR0ol00005ojFhiP03ojfhh_nX
]nCoZ;OT00OoZ;OT0_nO^^`5ojZhi0SoWk[/0_n3]oL5oibjk@OoN;?h1_mS]o`6og[2oPKoZlkb00?o
T/OjokG7ioneanL01OneanL01?l0003o_L7Mokg1gOnm`Md6ok_4h0Go_<3M0onn`md7okBohP03okW1
hOoooooooooo01Cooooo0_l0000Vooooo`007?ooool3o`0001Cooooo00?o0000ooooooooool06ooo
ool5ojS1j`OoYkkY1OnV^^P00onQ[^7oWZWNoijYgP05oijYgPOoWZOL1_nOZ=`00onR/nGoY;SXojBh
j006ojBhj0KoYKk[0onUgo/4oj7Qo0OoW^Kl0_nIi?d7ojK@mP;oXlog1OnW^nP8ojJlj@;oYKk[1OnY
]N88ojRfh`;oY[SV1On/]n82ojZfhP?o00000onZ]^82ojFhiPGo[KSR1onX]n@00on_^n;oZ[STojZh
i006ojZhi0KoWk[/00?oZKWToibjkOnL^^d01_nL^^d7ogRcn0KoHkOl1_mj`_h2oj_>lPGoT/Oj1one
anL00ol0003o_L7Mok_4h006ok_4h0?o_<3M1_nn`md4okBohPCo^L7Q5?ooool00ol0003oooooo`00
000Vooooo`007?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Wooooo1onX`N/7
ojNnj@03ojJjj?nQ[^7oXJkQ00?oXJkQ1onNZMh7oijWg0;oWjSL1OnR/nD8ojBhj0;oYKk[2?nUgo/0
0onQhOcoW^KloikVo005oikVo0?oZM?f1_nVd?H2ojNki`OoYk_X1_nV_>T00onX]N;oZKGRojVehP06
ojVehPKoZ;KS00?o[;WSojbgh_n/]n801?n/]n83o`0000GoZ[KR00?o[[cTojfhh_n]^>801_n]^>84
ojRgi0Co[k_R2?nZ^>@2oinjk0GoZKWT2?nL^^d3ogRcn0CoTKSa1om[/_X5ofRho0OoT/Oj1_neanL0
0on/b_3o0000ok_4h007ok_4h003okc0gOnn`mgo_/?M00Ko_/?M00?o];oRokW1hOni`N401Oni`N4F
ooooo`03o`000?oooooooooo02?ooooo000:ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0
003o<S8bonk^kPKooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Fooooo`?oZ<;/
1onX`N/3ojNnj@?oXkGU1onQ[^46oijYgPKoWZOL0_nO[^87oj:ci@KoY;SX0onWg?X7ojGOn`CoXnSk
0_nNi_`7ojWCmP;oY]3f1_nW^nL7ojNkj0;oY[cY1OnX]N87ojVehPCoZ;KS1?n/^N<2ojbghP?o0000
0on/]n82ojZfhPGo[[cT2?n]^>800onX]nCo[k_RojnkhP05ojnkhPKoZ[ST00?o/;cSojVii?nY^N@0
1_nY^N@6oibjk@;oYk[W1onA^?47of^bnPGoJ;Sl1onBaoX2okG7i`Co[<[`00?o0000ok_4h?nka>00
1Onka>000onhaNCo_/?Mokk3g@06okk3g@03okk5goni`N7o^L7Q00Oo^L7Q5Oooool00ol0003ooooo
ooooo`0Sooooo`003?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01;ooooo1onX`^`5ojS1j`03ojFj
j?nS]NGoXkGU00GoXkGU1onQ[^46oijYgP;oWZOL1_nO[^87oj:ci@;oY;SX2?nWg?X2ojGOn`KoXnSk
0on/f?L6ojWCmP;oZ;cX2?nW^nL5ojNkj0WoZ;GR1onY]N800onX]^?o[;WSojbih`03ojbih`?o0000
1On/]n800on/_NKo[[cTojjli006ojjli0Ko[KSR00?o[kkUojnkh_n_^n801_n_^n84ojZhi0Co/;cS
2?nY^N@2oibjk@KoYk[W1onA^?43of^bnP?oO[;e1?mS/OX2ofRho0?oT/Oj1?mj_?/6ojc:l003o`00
0?nka>3o^lCP00;o^lCP1?nhaN@6okk3g@?o_/GO1oni`N400onla>3oooooooooo`0Dooooo`03o`00
0?oooooooooo02;ooooo00000ooooooo0000o`000004o`0000Gooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@00Kooooo0_l0000Iooooo`03o`000?oooooooooo00kooooo
0onV_n/8ojS2k003ojS1jonU^^SoYK[X00?oYK[X1onS]ND7oj6^h@?oWZWN0onLZN08oin^hPGoX[?U
0onVdoL7ojOLnPCoYnSj0_nSj?/7ojcHm`?oZM?f1OnX_>P8ojNki`03ojNkj?nX]N;oZ;GR00[oZ;GR
1_nY]N800on[^nGo[;WSojbih`02ojbih`;o00000_n/^N<4ojbghPCo[;gV2?n^_>@2ojfhhPGo[kkU
2?n_^n800onZ^>Co/;cSok2lh`05ok2lh`KoZKWT00?o/;cSojNjionW^^L01onW^^L3oi6hl@?oXK[[
1omn/_D7of>anPKoN[ck1_n/b_000ol0003o^lCPokS5i006okS5i0?o_/?M1_nnaMl4okW1h@Co_<CP
5_ooool00ol0003oooooooooo`0Qooooo`003?ooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000001_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00[ooooo
1onV_n/6ojS2k003ojNnj_nU^^SoYK[X00GoYK[X1onS]ND3oj6^h@?oVZON1onLZN08oin^hP03oj:c
iOnVdoOoY]?g00KoY]?g0_nWg?X6ojOXnP?o[]kh2?n/f?L00onYdoKoZ;cXojRlj005ojRlj0KoYk_W
00?oYkCRojReh_nX]N803?nX]N82ojVehPGoZk_U0ol00005ojbih`03ojbgh_n/_NKo[;gV00Go[;gV
1_n^_>@00on[_^So[kkUojnni@06ojnni@Ko[k_R00?o[koVok2lhon`_><01on`_><2ojVii0Go/;cS
1onW^^L00on__>?oXK[[oj6jj`05oj6jj`OoO[;e1omS/OX6ogZln`?o[<[`0onKaOD00ol0003o^<GT
okS5i006okS5i003okk3gOnnaMoo_/GO00Ko_/GO00?o^L7Qokc4h?nla>001?nla>0Fooooo`03o`00
0?oooooooooo027ooooo000<ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`000005ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool01oooool3ojJnj`OoY[o[
0_nX`^`5ojNnjPOoYK[X1OnS]ND00onJYmooVZONoiZWgP05oiZWgPOoW:WP1_nO[^82ojG7lPOoY]?g
0on[ioX4ojOXnPKo[]kh1_n/f?L2ojVojPSoZ;cX0_nW^nL5ojNdhPcoZ;GR0_nY^nH3oj^ki@?o0000
00?oZk_Uojbihon/^N<01?n/^N<00onZ_NSo[;gVojbmiP06ojbmiPCo[[cT1?n[_^P8ojnni@;o[k_R
1On__nH7ok2lh`03ok2oiOn`_>?o/;cS00Ko/;cS1?nW^^L4ojnlh`OoXK[[0omn/_D4oi6gl@KoJ:gh
1_m]]?X6oi_5m@03o`000?nhaNCo^<GT00Go^<GT00?o]<KWokk5gonnaMl01_nnaMl00onna^3o_<CP
okc4h006okc4h1Kooooo00?o0000ooooooooool08?ooool000cooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`03ooooo`OoY[k[1OnV_n/2ojS1j`OoYkkZ1onU^^P00onS]NGoVZOOoiZWg`03oiZWg`OoVZON
1onLZN02oin^hPKoYLOb1?nVdoL7oj_WnP03ojOXn_n^g_So[]kh00Ko[]kh0_n/f?L6ojVojPKoZ;cX
00?oY[CSojNdh_nW]>801_nW]>88ojRehPGoZK_V0ol00005oj^ki@;o[;WS1OnZ_NP8ojbmiP03ojjl
i?n[_^SoZkkX00GoZkkX1_n__^D00on[_nSo[koVojnoiP06ojnoiPCo/;cS1?n`_nD8ok2lh`03ojNj
ion__>?o[kcS00Co[kcS1_nQ^^/00onY_>OoTKOaoi6gl@06oi6gl@KoJ:gh1_m]]?X6oi_5m@03o`00
0?nhaNCo^<GT00;o^<GT1?nda^L6okk5g`?o_/KP1_nla>000onna^3oooooooooo`0Eooooo`03o`00
0?oooooooooo01oooooo000<ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o00007_ooool00ol0003oooooojJnj`0:ojJnj`03ojJojonX`N_oZ<7[00CoZ<7[
1onW_^X3ojFjj0?oWjkR1onJYml6oiZWgPKoW:WP0_nR^^X8ojG7lP03ojKCmon[io[oZnOj00KoZnOj
0on`iOP6ojkNn0?oZ/C/1onY_nX2ojRlj0GoY[CS1onW]>86ojRehP04ojRkionY^nKoZK_VojVkiP?o
00000_nY^nH5oj^ki@;oZKkY1onZ_NP6ojbmiP;oZKoY2?n[_^P2ojnni@GoZkoX2?n__nH00on`_>?o
/;oUok2oi@05ok2oi@Ko/;cS00?o//3Uojnlhon__><01_n__><2oj6jj`GoZKcW2?nA]o46ofR]n0Ko
KKCj1_nKaOD00ol0003o^<GTokC6i`06okC6i`?o_/GO1Onna^04okc4h0Co_/KP5_ooool00ol0003o
ooooooooo`0Oooooo`002_ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool00ol0003oooooooooo`0Looooo`goY[k[0_nX`N`7ojS1j`GoYkkZ00?oX[KWoin^h_nO
[^801OnO[^86oiZWg`OoVZON0_nLZN06oj:jjPKoYLOb1?n_i?T3oj_WnPOo/>Gh0_n^g_P7oj[4k0Go
ZKoZ00?oYKCSojJdhonV]><01_nV]><7ojNdhP;oZ;GR1?nX^nL3o`0000KoZK_V00?oZk_UojVnjOnY
_^T01?nY_^T7ojZmj0;o[;gV1_nY_nT6oj^nj003ojW0j_n[_nSoZkoX00KoZkoX1_n__nH00on/`>Wo
/;oUok2oi@07ok2oi@;o/;cS1Onb`>D6ojnlh`03ok?0i?nY_>OoZKcW00KoZKcW1_nA]o400onM^ngo
M:geogB]m@05ogB]m@CoJ:gh0_m]]?X3oi_5m@?oRkgg00?o0000okC6ionda^L01_nda^L00onnaMoo
_/KPokk6h005okk6h003okc4h?nna^3o_/KP00Go_/KP5_ooool00ol0003oooooooooo`0Nooooo`00
6oooool00ol0003oooooooooo`0Iooooo`CoYko[2OnV_^/6ojS1k0OoZ<7[00?oYkkZoj:fionR]^L0
0onR]^L7oin^hPKoVZOO1OnJYmh2oijai@SoX[[Z0onUao86ojoTn@?o/nWg1_n`iOP3ojg:k`SoZ/C/
00?oZKoZojFdhonU]><00onU]><7ojJdh`KoYkCR00CoYk_WojRkionX^nOoZ;_W0ol00002ojRki`Ko
ZK_V00?oZ;kYojVnjOnY_^T01_nY_^T5ojZmj0;oZ;oZ2?nY_nT2oj^nj0GoZL3Z2?n[_nP2ojnoiPGo
[<3Y1on`_nD00on/`>So//3Uok;0i@06ok;0i@?o[kcS1?nc`>@8ojVli`;oTKOa1OnM^nd7ogB]m@Go
J:gh1_n;_OL00ol0003oRkggokC6i`05okC6i`03ojo7jonna^3o_/KP00Go_/KP00?o_LORokk6h?nn
a^001onna^0Fooooo`03o`000?oooooooooo01gooooo000Kooooo`03o`000?oooooooooo01Gooooo
0_nX`>/7ojNoj`OoY[k[2?nX`N`5ojS1j`;oYK_Y1_nR]^L7oin^hPKoVZOO00?oVZONoijaiOnN/ND0
1?nN/ND8oj:jjP03ojG7l_n_i?Wo[nCi00?o[nCi1oncjOL00on`iOSo[L[_ojg:k`05ojg:k`KoZ/C/
00?oYKGTojFdhonU]><01OnU]><7ojJdh`;oYkCR1?nW^nL3o`0000KoZ;_W0_nY^nH5ojRnj@SoZKkY
00?oZ[gXojRoj_nX_nX01?nX_nX6ojVoj@03ojRoj_nY`>[oZL3Z00KoZL3Z1_n[_nP00onY`>[o[<3Y
ojc0j@06ojc0j@Co/;oU1?n/`>P8ok;0i@03ojnlhonc`>Co/l3T00Co/l3T1_nY_>L2ojnni@OoWK_]
1omd[OD5ofR]n0KoRkgg00Co0000oh^mmonda^Oo]<KW1On_an/5okk6h0?o_LOR1onna^000onob>7o
ooooooooo`0Cooooo`;o00007oooool001_ooooo0_l0000Cooooo`KoZ<3[1onW_n/7ojJnj`SoZ<7/
00?oZ<7[ojFkjOnU^nT01?nU^nT6oj:fi`OoWjkR0onJYml3oiVZhPOoW[7U1_nR^^X4ojoMm`;o[nCi
1oncjOL2okCEl@So[L[_0_nZa>`5ojFei0OoYKCS1OnV]><00onW^^OoYk_WojNki`02ojNki`;o0000
0_nW^nL6ojRki`03ojRoj_nX_^WoZ;kY00KoZ;kY1_nY_^T9ojRojP;oZKoY1OnX_nX8ojW0jP;oZkoX
1OnY`>X8ojc0j@03ok2oiOn/`>So[<3X00Go[<3X1_nb`>D00on_`NOo/l3Tok?0i006ok?0i0;oZKcW
1_n__^D7oifkk@?oM:ge1?n1/O<3ofNYm`;oJ:gh1?n;_OL2ogjem`03o`000?n_an_o[lO[00Go[lO[
0onna^06okg7hPCo_/KP1?nob>4Fooooo`03o`000?oooooooooo01cooooo000Jooooo`03o`000?oo
oooooooo013ooooo0_nX`N/8ojS0j`GoYko[2OnV_^/6ojS1k003ojS0jonU^nWoYK_Y00KoYK_Y1_nR
]^L3oin^hP?oUjKP1onIZ^87oijai@;oX[[Z1on_gOL3okGYm`Co/nWg1OndeO46ojg:k`03ojJii_nU
]NCoYKGT00KoYKGT1onU]><00onV]>?oYk[WojNji`03ojNji`?o00001OnW^nL2ojRki`GoZ;oZ2?nX
_^T2ojVnj@_oZ;oZ0_nX_NT7ojRojPKoZL3Z00?oZ;kYojW0j_nY`>X01_nY`>X6ojc0j@;oZL3Z2?n/
`>P2ok;0i@Go[l7W1_nc`>@00onc`^Go[kkUojnni@07ojnni@?oWK_]1?nT_>/7oh6al`GoIjWg1_mn
]OL00ol0003o[lO[ojo7j`05ojo7j`03okk6h?nman;o_LOR00Ko_LOR00?o_/KPoko8hOnob>401Ono
b>4Eooooo`03o`000?oooooooooo01cooooo000Jooooo`03o`000?oooooooooo00gooooo1_nX`N/8
ojS0j`03ojNojonV_^_oY[k[00_oY[k[0_nX`N`5ojS0j`SoYK_Y0onR]^L2oiRXh@OoUjKP1onIZ^85
oijai@?oZ<gc1On_gOL6okGYm`03ok?YmondeO7o]=Ga00Ko]=Ga0_n]b^l5ojJiiPOoYKGT1_nU]><0
1?nU^NOoYk[WojNjionW^^L3o`000003ojNjionW^nOoYk_W00CoYk_W00?oYkkZojRoj_nX_nX01_nX
_nX6ojRnj@;oZ;kZ2OnX_nX6ojRmj@OoZ;oZ0_nY`>X5ojRnj@SoZL3Z0_n/`>T6ojW0jPKo[<3X00?o
Zl7Zojo1ion_`NL01On_`NL4ok?0i0Co/l;U1on__^D00onb`NCoY;c[ojBlj`06ojBlj`OoPK7c1OmW
ZOL5ogjem`03o`000?n_an_o[lO[00Co[lO[00?oZ<?]okg7h_nman801_nman800onlan?o_lSQoko8
h@05oko8h@03ol39hOoooooooooo01Cooooo00?o0000ooooooooool06oooool001[ooooo00?o0000
ooooooooool02oooool9ojS1j`KoZ<3[00?oYko[ojJnjonV_^/02onV_^/2ojW2k0OoZ<3[1_nU^nT0
0onO/^GoV:SQoiRXh@04oiRXh@OoUjKP1onIZ^800onN/NGoZ<gcojS=l`06ojS=l`03ojoMmonejOOo
]NWg00Go]NWg0onihO@6okCEl@;oZKoY1onV^NH7ojFei0;oYKCS1?nU^NL3o`0000GoYk[W0_nW^nL5
ojNnjPSoZ;oZ0_nX_^T6ojRnjPKoZ;oZ00?oZ;gXojRmjOnX_NT01_nX_NT5ojRojP03ojVnjOnX_^Wo
Z;kY00KoZ;kY1_nY`>X2ojRnj@SoZL3Z0_n/`>P5oj_1jPOo[l7W00?o/l3Tok?2iOnc`^D01Onc`^D4
ojnni@Co//7T2?nT_>/3oh6al`?oR[Cb1?mYYoD2ofNYm`GoO[Gg00?o0000ojo7jon_an/01OnX`nd6
okg7hP?o_<OS1Onob>43ol39hAKooooo00?o0000ooooooooool01_ooool5o`0000oooooo000Joooo
o`;o00002Oooool=ojS1j`;oZ<3[1OnW_n/9ojJnj`KoZL;/1onX`>/2ojFkj@GoWk;U1_nHZ>46oiNV
h0KoVJ[R0_nQ^n/7ojS=l`Co]nCf0_nejOL8okWQm003okCElOnY_nWoZKoY00CoZKoY1onV^NH3ojFe
i0?oXkKV0onU^NL3o`0000;oYKWW1OnW^^L9ojNnjPKoZ;oZ0_nW_^T8ojRnjP;oZ;oZ1OnX_NP8ojRm
j@03ojRoj_nY_^WoZKkY00?oZKkY2?nX_^T2ojW0jPKoZ;kY1_nY`>X00onX_n[oZl7Zoj_1jP06oj_1
jPGo[l7W0_n]`NT8ok?2i@03ojnniOnb`NCo//7T00Go//7T1_nT_>/00onX_^WoR[CbohZdlP05ohZd
lPKoJJOe1Omi/?H00ol0003oZ<?]ojS3k@05ojS3k@?o_LOR1Onlan<3oko8h@Ko`<WQ5Oooool00ol0
003oooooooooo`06ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@03oooool001[ooooo00?o0000oooo
ooooool01_ooool2ojNoj`coZ<7[0_nX`>/7ojNoj`KoY[k[0onV_n/6ojW2k0GoZ<3[0_nS^NT7oinb
i@KoV:SQ1_nGY^02oiVZhPKoXK_[1?nXcO<6okOTmP?o_>Od1_nihO@00on]angoZKoYojVoj@06ojVo
j@GoY[WV00?oX[CUoj>fi_nS]^H01?nS]^H3o`0000KoYKWW00?oYk[WojNnj_nW_^X02onW_^X2ojRo
jPKoYkkY1_nX_^X00onX_NWoZ;gXojRmj006ojRmj0KoZ;gY2?nY_^T6ojRnj@;oZKkY2?nX_^T2ojW0
jPGoZ;oZ2?n[`NX00on_`NOo[L7Yojg1j@04ojg1j@Ko/l;U00?o/L;Wok;1i?nb`N@01onb`N@2ojBl
j`GoZ;kY1_n:]?87ofVWm@CoNK3f00?o0000ogV`m_nX`nd01_nX`nd00onman;o_<OSokc7h`05okc7
h`03oko8hOo0bN7o`<WQ00Ko`<WQ5Oooool00ol0003oooooooooo`06ooooo`03oiRHV?lQ8B7ok^k^
013ooooo000Jooooo`03o`000?oooooooooo00?ooooo1_nW_n/8ojS1j`KoZ<3[1onW_n/2ojJnj`Oo
Y[o[1_nY`^`00onX`>_oXkWYoj>ij@04oj>ij@KoWk;U1onHZ>43oiNVh0?oVjoV2?nQ^n/00onXcO?o
]nCfokOTmP05okOTmPGo_>Od0_nihO@5ojg7k@SoZKoY00?oY[WVoj:diOnR]>D00onR]>D2oj>fiP?o
00000_nS]^H6ojFii`;oYkgZ3?nW_^X:ojNnj@;oZ;kZ1OnX_NT8ojRmj0;oZ;gY3?nY_^T2ojRnj@Ko
ZKkY1_nX_^T00onY_nWoZ;oZojRojP06ojRojPKoZl7Z00?oZL3Zojg1jOn]`NT01_n]`NT2ok?2i@Go
/L;W1onb`N@00ond`nGoZ;kYojRnj@05ojRnj@OoR[Cb1omYYoD4ogV`mP03o`000?mi/?KoZ<?]00;o
Z<?]0onS`>h7okc7h`03ok_8i?o0bN7o`<WQ00Ko`<WQ00?o`L_Rooooooooool05?ooool00ol0003o
ooooooooo`06ooooo`03oiRHV?lQ8B7ok^k^00oooooo000Jooooo`03o`000?oooooooooo00;oY[o[
2?nW_n/5ojS1j`;oZL7[1onX`>/5ojNoj`?oY[k[2?nV_n/3ojW2k0CoYko[1_nS^NT6oinbi@?oV:SQ
0onFZ><7oi^_iPKoXK_[0ondfo@4okOTmPKo_>Od0ongeO06ojg7k@KoZKoY00?oX[?Uoj:diOnR]>D0
0onR]>D3o`0000KoXkKV0_nU^NL6ojNmjPSoYkkZ3?nW_^T9ojRmj@KoZ;gX00?oZKoYojVnjOnY_^T0
2onY_^T2ojVoj@SoZKkY0_nX_^T5ojVoj@SoZ;oZ0_n[`NX5ojW0jPKo[L7Y00?oZl7Yok72iona`^L0
1_na`^L4ok;1i0Co]<?U1onX_^T3ohZdlPCoT;K`1_m/YO<5ogN/m003o`000?nS`>koXl3^00GoXl3^
1?nlan<4ok_8i0Ko`<WQ0oo1bn8Eooooo`03o`000?oooooooooo00Oooooo00?oMgMgofIVI_ooool0
3_ooool001Wooooo00?o0000ojJojonV_n/01?nV_n/8ojNoj`03ojS1jonY`N_oZL7[00CoZL7[1onX
`>/00onW_n_oY[k[ojJnj`05ojJnj`KoY[o[00?oZL7[ojNojonW_n/01_nW_n/6oj>ij@?oWk;U0_nD
Y^87oiJXh`OoVjoV0onQ^n/7okCKm003okOTm_nlioCo_>Od00?o_>Od1_ngeO06ojg7k@;oZKoY1OnR
/nD01?nR]>Go0000o`000?l00003oj:di@GoXkKV0onV_>T7ojNmjPOoYkkZ2OnW_^T=ojRmj@;oZ;gX
1OnY_nT9ojVnj@KoZKoY1_nY_^T00onZ`>WoZKoYojVoj@06ojVoj@KoZ;oZ00?oZKoYojW0j_nY`>X0
1OnY`>X4ojg1j@CoZl7Y2?na`^L00onb`NCo]<?UokC3i@04okC3i@KoZ;kY0_n/`>T7oi2fl0KoK:Gc
1Omg[?@00ol0003oXl3^oj?0kP05oj?0kP03okc7honkb>Co^lST00Go^lST0oo0bN45ol7;hQKooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0=ooooo`006Oooool00ol0003oY[o[ojJo
j`05ojJoj`KoYko[0onX`N/6ojW1j`GoZ<3[0onW_n/7ojJnj`;oY[o[1OnY`N/8ojNoj`?oXkWY0_nJ
[^D6oiBVhPOoUZSS1onK[nH00onQ^n_o]=_dokCKm005okCKm0Co_NKc0_nlio@8okOEl0?o[LO]0onT
^>L5oj:ci@;o00001onR]>D00onS]^KoY[cYojJlj@05ojJlj@GoYkgZ00?oYkoZojNnj_nW_^X01_nW
_^X6ojNnj@03ojNmjOnX_NWoZ;gY00_oZ;gY00?oZ;oZojVojOnY_nT01_nY_nT6ojVnj@;oZ<3Z1onY
_nT2ojVnj@GoZ/3Y2?nY_nT2ojRojPGoZKoY1onY`>X00on]`NWoZl7Yoj_1j@05oj_1j@Ko/L;W0_n_
`^P7okC3i@;oZ;kY1_n/`>T7oi2fl0GoK:Gc1Omg[?@00ol0003oXl3^oj?0kP04oj?0kP03oj6mkOnk
b>Co^lST00Oo^lST00?o`<WQol7;h_o1bn801Oo1bn8Dooooo`?o00001?ooool01Ol0003o^[Zjoooo
oonHV9So410@00oooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003ooooo
ojJoj`06ojJoj`;oYko[1onX`N/6ojW1j`03ojS0jonW_n_oYko[00GoYko[1OnV_^/2ojNoj`OoZL7[
1_nW_n/00onQ^>WoVZkUoiZ^i@04oiZ^i@KoU:KR1_nFZ><6oi^_iP?oZ<O`1?ndfo@6okgVl`?o_n?a
1_ngeO000onY`N_oY;SWojBhi`05ojBhi`04oj:ciOl0003o0000o`0000?oX[?U0onR]>D4ojFkj@So
Y[cY00?oYkgZojNoj_nW_nX00onW_nX8ojNnjP;oYkkY1OnW_NT9ojRmj@GoZ;oZ2?nY_nT2ojVnj@Ko
Z<3Z1OnY_nT00onX`>_oZ/3Yoj[0j@06oj[0j@KoZKoY00?oZ/3YojVojOnY_nT01_nY_nT5ojW0jP;o
Z;oZ2?n[`NT2ok72i`Ko[l;X1Ond`nD2okC4iPSo[<3Y0on@]_03oi>gl0CoKZCb0_m/YO<5ogN/m003
o`000?nS`>koXl3^00GoXKg]1onkb>@00onlb>Co`L_Rol7;hP05ol7;hP;o`LcS5Oooool00ol0003o
ooooooooo`02ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`03oooool000kooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`06ooooo`03o`000?oooooooooo00GoY[o[0onW_n/8ojS1j`?oZL7[1?nW`>/7ojNo
j`03ojJnjonW_n_oYko[00CoYko[1onY`N/2ojNoj`GoXKSY1_nJ[^D6oiBVhPKoUZSS0_nK[nH8ojS7
l003okCKm?nmi_?o_NKc00?o_NKc1_noho42okOEl0GoZL7[1?nT^>L3o`0000GoX[?U0_nS^>P7ojFk
j@KoY[cY00?oYko[ojNoj_nW_nX01OnW_nX6ojNnjPWoYkgY1OnX_NT2ojRoj`OoZ;oZ1_nY_nT2ojS0
j`SoZ<3Z00?oZKoYojS0jonX`>/00onX`>/8oj[0j@;oZKoY1OnZ`>T8ojVoj@03ojW0j_nX_n[oZ;oZ
00CoZ;oZ1_n[`NT00onZ`N[o[l;Xojo2j007ojo2j003okC3iOnda>Ko]<CV00Co]<CV1_n/`>T00on]
`^WoTkO`oi>gl005oi>gl0KoKZCb1OmgZO800ol0003oXKg]oj6mk@05oj6mk@Co^lST1?nlb>@4ol7;
hPGo`LcS5Oooool00ol0003oooooooooo`0Eooooo`003_ooool01Ol@413ooooooooooooooooo410@
00Kooooo0_l00002ooooo`03ojJojonW_n_oYko[00GoYko[1_nX`N/2ojW1j`OoYl3[1OnW_n/2ojJn
j`OoYko[1OnY`N/2ojJnj`OoXKSY1_nJ[^D6oiBVhP?oUZSS1?nM]>P7ojS7l0Co^mob00?o_NKcokoS
lOnoho401Onoho42ok7<k@OoZL7[0ol00004ojBhi`03oj:ciOnS^>SoXkSX00CoXkSX1onU^nT2ojJl
j@GoYko[1onW_nX2ojNnjPgoYkgY00?oZ;gYojRojonX_n/01?nX_n/7ojRojP;oZKoY1_nX`>/6ojS0
jP03ojS1k?nX`>_oZ<3[00GoZ<3[1_nZ`>T00onY`>[oZ/3Yoj[0j@06oj[0j@KoZKoY00?oZ/3YojRo
j_nX_nX01_nX_nX2oj_1j@GoZ/7Z1on_`^P00on^`^Wo]<CVokC4iP06okC4iP;o[<3Y1On]`^T7oi>g
l0KoKZCb1OmgZO800ol0003oXKg]oj6mk@05oj6mk@03ok_8i?nlb>Co_<ST00Go_<ST00?o`L_Rol7<
hoo1c><01_o1c><Eooooo`03o`000?oooooooooo01Cooooo000>ooooo`05o`000?oooooooooooooo
ool000001_ooool00ol0003oooooooooo`03ooooo`OoYko[0_nX`N/6ojW1j`OoYl3[00?oYko[ojJn
jonV_^/01?nV_^/7ojNoj`03ojW1jonV_^_oY[k[00CoY[k[1_nQ^>T7oiZ^i@?oU:KR0onEZ^D7oifd
j0CoZ<O`1Onkgo83ol;Ul0Co_n?a1Onac>d3ojW1j`?o000000CoZL7[ojBhionT^>OoY;SW0onO/nH8
oj>hj0GoYK_Y00?oY[k[ojNojonW_n/01_nW_n/5ojNojPooYkgY0_nW_n/7ojRoj`GoZ;oZ0_nW`N`8
ojS0j`;oZ<3Z1OnX`N`7ojS0j`;oZ/3Y1OnY`>X8oj[0j@;oZKoY1OnZ`>T6ojRojP03ojVoj_nZ`N[o
Z/7Z00KoZ/7Z1?n_`^P4ojk2j@Oo]<CV2?n]`^T7oi>gl0KoKZCb1?mgZO800ol0003oMjWboj6mk@02
oj6mk@CoXKc/1_nlb>@2okc:i0Oo`LcS00?o`<kUooooooooool04oooool00ol0003oooooooooo`0D
ooooo`003_ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool01Oooool5
ojNoj`;oZ<7[2?nY`N/5ojO0j`;oYko[1onV_^/5ojNoj`?oZL7[1_nV_^/6oj6hj@?oVZkU0onAY^<7
oiFZi@OoWKCX00?oZ<O`ok_Ol_nkgo801?nkgo86ol;Ul003okoSlOnac>go/Lc]00Co/Lc]0ol00003
ojW1j`;oX;CW1_nO/nH8oj>hj003ojFkjOnV_^_oY[k[00?oY[k[2?nW_n/00onW_n[oYkgYojNmj@0=
ojNmj@KoYko[1onX_n/00onX_n[oYl7/ojO1k004ojO1k0KoZ<3[00?oYl3/ojS1k?nX`N`01_nX`N`5
ojS0j`03ojS1k?nY`>[oZL3Z00KoZL3Z1_nZ`>T2oj[0jPOoZ/3Y0_nX_nX5ojVojPSoZ/7Z00?o[l;X
ojk2jOn^`^T01?n^`^T8okC4iPSo[L;Y0onC]o03oi>gk`KoL:?`1OmiYo000ol0003oXKc/oj6lk006
oj6lk0?o_<ST1Onlb^@4ol7<h`Co`<kU5Oooool00ol0003oooooooooo`0Cooooo`003_ooool01Ol@
413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool01_ooool00onW_n_oZ<7[ojS1j`04
ojS1j`SoZL7[00?oYl3[ojNojonW_n/01?nW_n/7ojJnj`03ojNojonY`N_oZL7[00GoZL7[1_nV_^/3
oj6hj@;oUZgV1onAY^<7oiFZi@GoWKCX0onad?04ok_OlPKo`^G`0oo0gNh2ok7<k@?o00000_nac>d0
0onY`N_oX;CWoj2di`04oj2di`KoWk?V1_nS^>P00onU_>[oY[k[ojJnj`05ojJnj`KoYko[00?oY[gY
ojNmjOnW_NT02onW_NT:ojNoj`?oZ;o[2onW`N`2ojS0j`GoYl3/2?nX`N`00onX`>_oZ<7/ojS1k003
ojS1k0SoZL3Z0_nZ`>T6oj[0jPGoZ/3Y00?oZl7YojVoj_nY_nX01_nY_nX6oj[1jP;oZL3[1on^`^T8
okC4iPKo[L;Y00?o[L?Zoi>gkonC]nl01OnC]nl6og2Sl0GoNJO`00?o0000oj6lk?nQ_>`01_nQ_>`0
0onlb>Co_<[Tokc:i005okc:i003ol7<hoo0c^Go`<kU00Go`<kU5Oooool00ol0003oooooooooo`0B
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_l00008ooooo`OoZ<7[1_nY`N/2
ojS0j`OoYko[1OnV_^/3ojNoj`OoZL7[0onV_^/3oj2hjPGoUZgV1onAY^<7oiFZi@03oifdj?nad?3o
/M3`00Ko/M3`00?o^mobol;Ul?o2iO000oo2iO04ol3MkP?o00001?nac>d00onV_N[oX;CWoj2di`06
oj2di`KoWk?V0_nS^>P5ojFljPOoY[k[0_nW_n/5ojJmj@WoYkgY3?nW_n/>ojO1k003ojO0jonW`>co
Yl3/00KoYl3/1_nX`N`2ojO0k0KoZ<7/1_nY`>X2ojS1j`SoZ/3Z00?oZ/3Yoj_1jOn[`NT00on[`NT8
ojVojP;oZ/7Z1_nY`>/5ojk2j@;o[L;Y2?nda>H2ojg2j@Go[L?Z1onC]nl5og2Sl0GoNJO`00?o0000
oj6lk?nQ_>`01?nQ_>`2ojBljPOo_<[T00?o_/cUol3>iOo0c^D01Oo0c^D00onncnOoooooooooo`0C
ooooo`03o`000?oooooooooo01;ooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool0
0ol0003oooooooooo`08ooooo`OoZ<7[0_nY`N/6ojS0j`OoYko[00?oY[k[ojNojonW_n/01OnW_n/5
ojW1j`;oY[k[1_nP^>X5oiJ]iPKoTJKS1_nEZ^D2oj2hjPOo/M3`1?o0h>l00oo2iO3o`=g^ol3MkP02
ol3MkP;o00000oo0gNh00onac>goY[gZojJmjP03ojJmjPSoX;CW0onO/nH3ojBjj@OoYKcZ1OnV_^/3
ojNnjPKoY[gY1_nW_NT2ojNnjPWoYko[3_nW`N`5ojO0j`SoYl3/0_nX`N`6ojO0k0KoZ<7/0_nY`>X6
ojS1j`KoZ/3Z00?oZL3[oj_1jOn[`NT01On[`NT6ojVojP;oZL3Z2?nY`>/00on^`^Wo[L;Yojg2j@04
ojg2j@Ko]<CV00?o]<GWojg3j_n]`nX01_n]`nX3oi>gk`?oTKG_1?mbXNh2og2Sl0GoNJO`00?o0000
oj6lk?nQ_>`01_nT_>X5okc:i0?o_/cU1Oo0c^D3okk?iaGooooo00?o0000ooooooooool04Oooool0
01Sooooo00?o0000ooooooooool02Oooool5ojS1j`?oZL7[1onX`>/3ojNoj`CoY[k[2?nW_n/00onY
`N_oY[k[ojJnj`04ojJnj`KoX;SZ1OnF[NH6oi6Vh`;oUJ[U1_nP^>X4ok7@l0Go`>3_0oo5hnd3o`00
00Co`=g^0_n`bNd6ojJmjPKoX;CW00?oWkGXojBjjOnT^^T01OnT^^T7ojFljP03ojJnjonW_^[oYkkZ
00GoYkkZ1_nV_NT2ojNmj@KoYkkZ1OnW_n/?ojO1k0;oYko[1_nW`>/6ojO0k0;oYko[2?nW`>`3ojS1
k0?oYl3/2?nX`N/2oj[0jPGoZL3[1on[`NT2ojVojPKoZL3Z1onY`>/8ojg2j@;o]<CV1OndaNL6ojg3
jP03ojc3jonA]NooTKG_00GoTKG_1OmbXNh6ogfVkP03o`000?nT_>[oY;cZ00GoY;cZ0onlb^@5okk<
i@?o`<kU1OnncnLFooooo`03o`000?oooooooooo013ooooo000Hooooo`03o`000?oooooooooo00[o
oooo00?oZ<7[ojW1jonY`N/01OnY`N/5ojS0j`;oYko[1onV_^/6ojNoj`03ojW1jonV_^_oY[k[00Ko
Y[k[1_nP^>X5oiJ]iP?oTJKS1?nE[>H7oj2hjP03ok7@l?o0h>oo`>3_00Co`>3_00CoaN?]o`000?l0
003o00000_o5hnd2ol3MkPKo/<W]1_nV_NX2oj2di`GoWkGX1onT^^T3ojFljPCoYko[2?nW_^X3ojJm
j@?oY[gZ2?nW_^X00onW_n_oYl7/ojO1k00=ojO1k0KoYko[1_nW`>/2ojO0k0KoYko[1_nW`>`00onW
_n_oYl3/ojO0k005ojO0k0KoZ<7[00?oYl3[ojW0jonY`>/01_nY`>/5oj_1j@;oZl7Z2?nY`>X7ojW0
j`Oo[L;Y2?ndaNL2ojg3jPGo[<?[1onA]Nl5og:QkPKoOJK^00?o0000ojBlj_nT_>X01OnT_>X00onl
b^Co_/cUokk<i@05okk<i@03ol3>iOnncnOo_/oW00Go_/oW5Oooool2o`00017ooooo000Gooooo`?o
00003Oooool7ojW1j`03ojS0jonW_n_oYko[00CoYko[1onV_^/2ojNoj`GoZL7[2?nV_^/3oj2hjP;o
U:gX1_n?Y^D7oiF/iPGoX;SZ0ongdnh3ol3Pk`?o00001?o5hnd3ol3Jk@Oo/<W]0onV_NX3oijdj0Oo
WkGX1OnT^^T2ojJnj`OoYko[1_nW_^X8ojJmjPKoYkkZ00?oYl3[ojO1k?nW`N`02onW`N`:ojNoj`?o
Yl3[0onX_nX8ojNoj`;oYl3/1OnW_n/7ojO0k0;oZ<7[1OnW`>/8ojW0j`03oj_1jOn[`N[oZl7Z00Co
Zl7Z1_nY`>X2oj[1jPKoZL3[2?n]`^T6okC5i`;o]<KW1on/`n/7oi6ek`GoLZ7^1OmmY^h00ol0003o
Y;cZojBljP04ojBljP03ojRmj?nnc>Go_/cU00Go_/cU0_noc^D6okk?i`;o^loY4oooool00ol0003o
ooooo`00000Aooooo`005oooool00ol0003oooooooooo`0>ooooo`GoZL7[0_nX`>/7ojNoj`GoY[k[
0onW_n/6ojW1j`KoY[k[00?oWkW[oiB]j?nD[NP01?nD[NP6ohnVi@OoUJcV00?oX;SZokOCk_ngdnh0
1?ngdnh3o`0000GoaN?]1_o0f^d5ok39k@03ojBlj_nN]>SoW[CX00GoW[CX1onO]NP00onT^^WoY[k[
ojJnj`04ojJnj`OoYko[0_nW_^X<ojJmjP;oYkkZ1OnW`>/9ojO1k0coYko[00?oZ;kZojRoj_nX_nX0
1OnX_nX6ojNoj`03ojRoj_nW_n_oYko[00KoYko[1OnW`>`2ojNoj`OoYl3[1_nY`>/00onX`>_oZl7Z
oj_1jP06oj_1jP;oZL3Z1_nZ`NX6ojW0j`So[L;Y0ondaNL5okC6i`Oo[<?[0onA]Nl3ohbak`CoM9o/
0_mbXNh5ogfVkP03o`000?nT_>[oY;cZ00GoZ;gX1?nnc>D5oko>i@?o_/oW1OnkcnTDooooo`03o`00
0?oooooooooo00oooooo000Gooooo`03o`000?oooooooooo00oooooo00?oZL7[ojS0jonX`>/01?nX
`>/7ojNoj`03ojJnjonW_n_oYko[00GoYko[1_nY`N/2ojJnj`GoWkW[1_nD[NP6ohnVi@GoUJcV0onQ
^NX2okOCkP?o000000?o]m?^ol?Nk?o3g^`00_o3g^`2olGSk@So`=[]00?o/<W]ojBlj_nT_>X00onT
_>X7oijdj0GoWkGX00?oXk_ZojJnjonV_^/01_nV_^/5ojNoj`koY[gZ0onW_n/6ojO0j`KoYl7/0_nX
`>/9ojNoj`GoZ;kZ1onX_nX2ojNoj`GoZ;oZ2?nW_n/00onW`>coYko[ojNoj`04ojNoj`OoYl3[0_nY
`>/5ojS0j`SoZl7Z2?nZ`NX3ojW0j`?oZL7[2?n]`^T00ondaNOo]<KWokC6i`05okC6i`?o[<?[0onX
`^`7ohbak`GoM9o/1_n1Yn`00ol0003oZ;gXojRmj005ojRmj003okk<iOnoc^Go_lkU00Ko_lkU00?o
_/oWok_?jOnkcnT01OnkcnTDooooo`03o`000?oooooooooo00kooooo000Gooooo`03o`000?oooooo
oooo017ooooo1_nX`>/5ojNoj`?oY[k[1onW_n/3ojW1j`CoY[o[1_nO^N/5oiB]j0OoSjKU00?oUJcV
oj6ij_nQ^NX00onQ^NX3o`0000;o]m?^1_o3g^`3olOPjPKo`=[]0_n`bN`6ojBljPOoW[CX00?oWkGX
oj>kj_nS^nX00onS^nX8ojJnj`03ojNojonV_N[oY[gZ00coY[gZ1onW_n/6ojO0j`;oYl7/1_nX`>/5
ojNoj`03ojNnj_nX_^[oZ;kZ00KoZ;kZ3_nX_nX6ojNoj`;oZ;oZ1onW_n/3ojO0j`CoYl3/1onX`>/8
oj_1jPKoZ/7Z00?oZ/7[ojW1jonY`N/01OnY`N/6ojg2j@03ojk3jOnda^Oo]<KW00Go]<KW00?o]LSY
ojS2k?nX`^`01OnX`^`6ohbak`KoM9o/1_n1Yn`00ol0003oZ;gXojRmj003ojRmj0;o[l;X1onoc^D0
0oo1d>Ko^loYok_?j@05ok_?j@03okK=jooooooooooo01?ooooo00?o0000ooooooooool03Oooool0
01Oooooo0_l0000Cooooo`KoZ<3[00?oYko[ojJnjonV_^/01OnV_^/5ojNoj`;oZL7[1onV_n/6oini
j`GoU:gX0on?Y^D3oi>/i`?oXKWZ0ol00003oj6ijP03okOCk_o3g^co`mk/00Co`mk/1Oo7h>X2ol3J
k@Ko/<W/1_nT_>X3oijdj0CoWkKY1_nS^nX6ojJnj`;oYko[3?nV_NX2ojJnj`SoYko[0onW`>/3ojS1
k0SoZ<3[00?oYko[ojNnj_nW_^X00onW_^X8ojRnjPkoZ;oZ0_nW_n/6ojRojPKoYko[2?nW`>`7ojS0
j`SoZl7Z0_nZ`NX5oj[1j`OoZL7[0_n]`^T5ojk3j@Co]<KW1?neb>T7ojS2k0KoS;7_1_mdWn`5oh6W
k003o`000?n1YncoZ;gX00Ko[l;X1?noc^D4ol7@iPCo^loY1?nfcN/Dooooo`03o`000?oooooooooo
00gooooo000Gooooo`03o`000?oooooooooo01?ooooo0onX`>/4ojNoj`OoY[k[00?oYko[ojW1jonY
`N/01?nY`N/7ojJoj`?oWkW[0_nD/>X6ohfViPKoTjcW0_l00005oj6ijP?o^M7/0oo3g^`6olOPjP?o
`m[[1on`bN`3ojBljP?oW;CY1onO]^T6oj>kjP;oY[k[1_nW_n/8ojJmjPKoY[k[1_nW_n/8ojS1k0Ko
Z<3[2?nW_^X6ojRnjPkoZ;oZ0_nY_nX8ojRojPKoYko[2?nW`>`7ojS0j`OoZl7Z1onZ`N/8ojW1j`Oo
[/?Y00?o]<KWokG8jOneb>T01Oneb>T5ojS2k003ojBokOn5ZnkoQJ_^00CoQJ_^1_mgW^X6ohRXj`03
o`000?n_`^So[l;X00Ko[l;X00?o_lkUol7@i_o1d>H01Oo1d>H00onkcnWo]/g[okK=j`05okK=jaCo
oooo00?o0000ooooooooool03?ooool001Oooooo00?o0000ooooooooool05?ooool7ojNoj`OoY[k[
1onY`N/5ojJoj`;oX;[[1OnD/>X6ohfViP;oTjcW0ol000000onC[>OoXKWZoj6ijP02oj6ijPKo^M7/
00?o`mk/olOPj_o7h>X01?o7h>X5ol?Jj`Go/<W/00?oYKk[oibdjOnL]>T01OnL]>T7oinfj@?oXk_Z
1?nV_^/7ojNoj`?oY[gZ1?nU_NX7ojJnj`;oYko[3?nX`N`2ojS0j`coYkkZ0_nX_^X>ojRojPKoZKoZ
1_nX_nX00onY`>[oYko[ojNoj`05ojNoj`KoYl3/00?oY[o[ojS0jonX`>/01_nX`>/7oj_1jPOoZ/7[
2?nY`N/5ojk3j@;o[lCY2?neb>T00onX`^coY;o]ojBok@03ojBok@KoQJ_^1_mgW^X6ohRXj`03o`00
0?n_`^So[l;X00Co[l;X00?o]<OXol7@i_o1d>H01Oo1d>H00oo2dnOo]/g[okK=j`05okK=j`03ok79
k?oooooooooo01?ooooo00?o0000ooooooooool02oooool001Oooooo00?o0000ooooooooool05Ooo
ool7ojNoj`OoY[k[1onY`N/00onV_n_oX;[[oj2jj`04oj2jj`GoU;3Z1?n=Y^H3o`0000GoTjcW00?o
XKWZokWAk?nidN`01OnidN`3olCJj@Coan3Z1oo3f^/00on`bNcoYKk[ojFnj`03ojFnj`OoW;CY1OnO
]^T00onS^n[oY[k[ojJnj`06ojJnj`GoYko[00?oYKg[ojFmj_nU_NX01_nU_NX5ojJnj`03ojNojonX
`NcoZ<7/00_oZ<7/0_nW_n/<ojNnjP;oYko[2onX_nX3ojS1j`SoZKoZ0_nX_nX5ojW0jPOoYko[0_nW
`>`5ojJoj`OoZ<3[2?n[`NX5oj[1j`[oZL7[00?o[/?Yojo4jOn_a>T01?n_a>T6okG8j@03ok?9j_nT
_ngoY;o]00GoY;o]1_n5Znh6ogNNjPKoR:S[00Co0000ojo2j?n_`^So[l;X1?ndanP4ol7@iPCo`]?W
1?nfcN/4ok79k1Cooooo00?o0000ooooooooool02oooool001Kooooo0ol0000Gooooo`GoYko[0onV
_n/6ojJnj`GoZL7[0onW`>`6oj2jj`GoU;3Z0ol00003ohfViP?oTjcW1?nP^>X4okWAk0Ooa=[Y00?o
an3Zol?Jjoo3f^/01Oo3f^/2ok?;k0KoYKk[1onL]>T00onO]^WoXk_Zoj>kjP03oj>kjPSoY[k[00?o
Yko[ojFmjonU_N/00onU_N/8ojFmjP03ojJnjonW_n_oYko[00?oYko[2OnX`N`6ojNoj`SoYkkZ1_nW
_n/6ojRojP03ojO1k?nX`N_oZ<7[00GoZ<7[1_nY_nX2ojW0j`OoZL3Z0onW_n/4ojS0j`OoY[o[1onX
`>/8oj_1jP03oj[1jonY`N_oZL7[00[oZL7[00?oZ/7[ojo4jOn_a>T01_n_a>T2okG8j@Go/lWZ1onT
_nd6ohF[kPKoMikZ1On8Z>/00ol0003o[l;XokC7j006okC7j003ol7@i_o2dnOo`]?W00Go`]?W00?o
]/g[ok79k?nabN`01OnabN`Dooooo`03o`000?oooooooooo00[ooooo000Fooooo`03o`000?oooooo
oooo01Sooooo00?oYko[ojJojonV_n/01OnV_n/6ojJnj`03ojW1jonW`>coYl3/00GoYl3/1_nP^^/0
1OnD/>[o0000o`000?l0003oU;3Z00?oSJKV0_nAZnP9oj2hjP03okWAk?o4f^Woa=[Y00Goa=[Y0oo9
g>L4ol?Jj`Go/l_/1_nU_^/3oibdj@CoWKKY1_nS^nX6ojJnj`;oYko[1_nU_N/6ojFmjP;oY[k[1_nW
_n/6ojS1k0;oZ<3[1onW_n/3ojNnjPCoYkk[1onW_n/2ojRojPGoYl7/1onX`N/2ojVojPKoZL3[1OnY
`>X00onY`N_oZ<3[ojS0j`06ojS0j`KoY[o[2?nX`>/6oj_1jP03oj_2jonY`N_oZL7[00SoZL7[1OnZ
`N/6ojo4j@03ok75jOncbN[o/lWZ00Ko/lWZ0onT_nd3oifjk@KoOj;Z1_mlW^L6oi:]j@03o`000?nd
anSo]<OX00Co]<OX0_nic>P6ol;Ci`;o`=CY1_nabN`00on]a^coooooooooo`0Aooooo`?o00002ooo
ool000Cooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^1_ooool00ol0003o
ooooooooo`0Jooooo`OoY[o[0onV_^/4ojS1j`OoYl3/0onP^^/3o`0000CoRZOX1_nAZnP7oj2hjP?o
]/cZ1?o4f^T6olWLi`03ol?Jjoncbnco/l_/00Ko/l_/0onU_^/3oibfj`OoWKKY1_nS^nX2ojJnj`Ko
Yko[1_nU_N/2ojFmjPKoY[k[1_nW_n/2ojS1k0KoZ<3[1OnW_n/9ojNnj`GoYko[2OnW`N`5ojS1j`;o
Yl7/2?nY`>/00onY`>[oZL7[ojW1j`03ojW1j`SoZ<3[1_nV_n/8ojS0j`;oZl7Z1On[`^/8ojW1j`Oo
Z/7[0_n_a>T5ok75j@Ko/lWZ0_n`b>`6oifjk@KoOj;Z1_mlW^L6oi:]j@04o`000?ndanSo]<OXokC7
j0Go^LcX0oo2dnL5ol3Dj@?o/LW/1?n]a^`?ooooo`?o00000_ooool00ol0003oooooooooo`09oooo
o`001_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0
003oooooooooo`0Kooooo`GoY[o[00?oY[k[ojS1jonX`N/01_nX`N/5ojO0k004oj:lk?l0003o0000
o`0000?oUkC/1On:YnP6oi6[j0CoX;SZ1_nfc>X00oo4f^WobMcWolWLi`05olWLi`?oamWW1_ncbn`2
ojS2k0KoW;K[1onM]^T3oj>kjPCoYKk[1onW_n/7ojFmj`OoY[k[0onW_n/3ojS1j`SoZ<3[00?oYko[
ojNnjonW_^/02onW_^/00onW_n_oYl7/ojO1k00;ojO1k003ojS1jonW`NcoYl7/00CoYl7/1_nY`>/0
0onX`>_oZL7[ojW1j`05ojW1j`SoZ<3[1_nV_n/8ojS0j`OoZl;[2?nY`N/5oj[1j`03oj_2jonaaNWo
/LGY00Ko/LGY0_ncbNX6ok38k0KoWK[]1OmoX^X6ogbNi`KoTZgY00?o0000okC7j?nic>P01onic>P0
0oo2dnOo`=CYol3Dj@05ol3Dj@03ok79k?n]a^co[LK/00Co[LK/2oooool3o`0000Gooooo00?o0000
ooooooooool02Oooool000Kooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@00Kooooo0_l0000Mooooo`03ojJojonV_^_oY[k[00?oY[k[2?nX`N/00onW`>coX[c/o`000002
o`000003oj:lk?nG]>coUkC/00CoUkC/1On:YnP6oi6[j003oj2hj_nfc>[o]/cZ00Go]/cZ0oo4e^L4
olWLi`OoamWW00?o/l_/ojS2k?nX`^`01?nX`^`6oibfj`GoWKKY00?oX[_[ojFnjonU_^/01_nU_^/5
ojNoj`03ojFnjonU_N_oYKg[00KoYKg[1OnV_^/00onW_n_oZ<7[ojS1j`05ojS1j`KoZ<3[0_nV_n/<
ojNnj`;oYl3[2_nW`N`4ojK1k@OoYl7/0_nY`>/5ojS0j`OoZL7[2?nX`>/6ojJoj`SoZ<3[1on[`^/8
ojW1j`03oj[1jon[`^_oZl;[00?oZl;[1_naaNT2ok?8jPSo/<S/1_nM^^d5ognRjPKoO9kW0onB[NT3
oindi`03o`000?nic>So^LcX00Go^LcX00?o_]7Xol3DjOo0e>T01Oo0e>T00onjdnco[LK/ojg6k006
ojg6k0Kooooo1?l00008ooooo`03o`000?oooooooooo00Wooooo0006ooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`000005ooooo`;o00007_ooool7ojJnj`OoZ<7[0_l00005
oj:lk0GoUkC/1_n:YnP3oi6[j0CoW;GZ1Onfc>X6olCFi`03olWLioo7fNOoamWW00GoamWW0_nkdN/7
ojS2k0KoW;K[00?oWKKYoj:kjonR^n/00onR^n/8ojFnj`03ojNojonU_^_oYKk[00?oYKk[2?nU_N/0
0onV_^_oYko[ojNoj`03ojNoj`OoZ<7[0_nX`>/6ojJoj`SoYkk[1_nW`>/6ojO1k0SoY/7]1OnW`N`2
ojJok0OoZ<3[1onY`N/8ojS0j`?oY[o[0onW_n/8ojS0j`OoZl;[1_nY`N/00onX`>_oZl;[oj_2j`05
oj_2j`?o/LGY1Oncb>X6ok38k003ojW3kOnC/^coTk;/00CoTk;/1OmmW>H6oh>PiPOoWkCW00?o0000
okW<j?nic>P00_nic>P4okkAj0Co`=CY1?njdn`6ojg6k004oj[3k?ooooooooooooooo`?o00003Ooo
ool00ol0003oooooooooo`08ooooo`001_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000001Oooool00ol0003oooooooooo`0Nooooo`OoY[k[0onX`N/3o`0000;oZ<7[1_nR
_>`5oiNdk0?oRZOX0on<ZNT7oibejP?o]/cZ1_o4e^L3olWHi@CoamWW1OnkdN/7ojS2k0?oW;K[0onK
]NX6oj:kj`KoYKk[0_nW_n/6ojFnj`KoYKg[0_nV_^/6ojNoj`GoZ<7[0onX`>/7ojJoj`?oYkk[0onW
_n/8ojO0j`KoYl7/2?nV`Nd00onW`NcoY[o/ojJok004ojJok0OoZ<3[1onY`N/6ojS0j`03ojO0jonW
_n_oYko[00GoYko[1_nX`>/00onY`N_oZl;[oj_2j`06oj_2j`;oZL7[1OnX`>/7oj_2j`03ok75jOnc
b>[o/lSZ00Go/lSZ0_n`b>`5ojW3k@KoTk;/1OmmW>H6oh>PiPOoWkCW00?o0000okW<j?nndNP01_nn
dNP00oo0e>Wo^]?/ok[Ck005ok[Ck0;o[LK/1OnZ`n`2o`00013ooooo00?o0000ooooooooool02?oo
ool000Kooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Gooooo00?o
0000ooooooooool07oooool5ojJnj`04ojNojol0003o0000o`0000KoZ<7[0onR_>`3oi^hk0GoRZ[[
1_n<ZNT7oibejP03okK<j_o4e^Ooa=KW00Coa=KW1_o9f>D00oo7fNOo^m7[ok_Aj`05ok_Aj`?oZ<;/
0onN^^`7oi^ejPKoX[_[0_nU_^/6ojNoj`KoYKk[0_nU_N/6ojJnj`KoYko[00?oZ<7[ojS0jonX`>/0
1OnX`>/6ojJoj`OoYko[1_nW`>/2ojS1j`KoYl7/1_nV`Nd9ojJok0OoZ<3[1onY`N/2ojS0j`GoYl3[
1onW_n/2ojS0j`GoZL7[1_n[`^/2oj[3j`KoZ<3[1_n[`^/00on]a>_o/lSZok?8jP05ok?8jP;o]<c/
1_nY`nd6oi>bk0KoOIcV1_n3X>H6oindi`03o`000?nndNSo_]7X00Go_]7X0_o1e^T6ok[Ck003ok?<
kOnZ`ncoZ/?/00KoZ/?/4Oooool00ol0003oooooooooo`08ooooo`001_ooool00ol0003ooooooooo
o`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2o`00027ooooo00?oY[k[ojNojol00000
0_l00003ojNoj`GoZ<7[0_nU_n`6oi^hk0GoRZ[[1_n<ZNT5oibejP?o[l?X1?o4e^L6olWHi@;ob]OT
1_nkdN/2ojo6j`KoW[[/1onK]NX3oj:kj`CoY;g[1onW_n/3ojFnj`?oY;g[2?nV_^/3ojNoj`?oZ<7[
2?nX`>/6ojJoj`OoYko[0_nW`>/6ojS1j`KoYl7/0_nV`Nd;ojJok003ojJnjonX`>_oZ<3[00KoZ<3[
1onY`N/6ojO0j`SoYko[1onY`N/2oj_2j`KoZ/?[1_nX`>/2oj_2j`Go[LC[1?ncb>X5okC<k0KoZL?]
1_nC/^`6ogfLiPKoPj3V0_nO]>L4ojc1j@03o`000?nndNSo_]7X00;o_]7X1Oo1e^T2ok[Ck0Go/lc]
1_nZ`n`00onW`>_oooooooooo`0?ooooo`03o`000?oooooooooo00Sooooo0004ooooo`03oeEEEOmV
IVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?oooooooooo01oooooo
0ol00007ojNoj`03ojS1jonU_ncoYKo/00CoYKo/1_nK^>`5ohZZj`KoS:WY00?oW;GZojo3j?n_`nP0
1_n_`nP00oo4e^OobMSUolWHi@04olWHi@Cob]OT0onkdN/5ojo6j`KoW[[/1OnK]NX00onO^N_oY;g[
ojBmj`06ojBmj`GoYko[00?oY[o/ojBmjonT_N/01OnT_N/6ojJnj`03ojNojonX`N_oZ<7[00GoZ<7[
1_nX`>/8ojJoj`GoYko[0_nX`>/8ojS1j`?oYl7/0onW`>/9ojJok0GoY[k[2?nX`>/7ojW1j`KoYl3[
2?nW_n/5ojW1j`;oZ/;[2?nZ`n/3ojS0j`?oZL7[1on]a>/00oncb>[o]<c/okC<k006okC<k0?oZL?]
0_nQ^n`6ohRTi`KoOi_S1_n;YNH7ojc1j@03o`000?nndNSo`MKY00Go`MKY00?o`MS[ok?<kOncc>d0
1_ncc>d2oj[3k0GoYl3[4?ooool00ol0003oooooooooo`08ooooo`005Oooool00ol0003ooooooooo
o`0Looooo`?o00001?ooool5ojNoj`?oZL7[1_nU_n`6oi^hk0GoRZ[[0on<ZNT3oiFajPOo[l?X0oo0
d>H3olWHi@Oob]OT00?o^m7[ojo6jon_a^/01On_a^/6oijjk003oi^ej_nO^N_oWkW[00?oWkW[2?nT
_N/00onW_n_oY[o/ojJok003ojJok0OoY;g[0_nV_^/5ojNoj`OoZ<7[0_nX`>/<ojJoj`03ojNojonX
`>_oZ<3[00CoZ<3[1_nX`N/00onY`>_oYl3[ojO0j`05ojO0j`KoY[o/2?nV_^/6ojS0j`WoZL7[0onW
`>/;ojNoj`03ojW1jonZ`^_oZ/;[00CoZ/;[1_nZ`n/00onY`^coZL7[ojW1j`05ojW1j`Go[LC[0on_
a^/6okC<k003ojo9kOnQ^ncoXK_/00CoXK_/1_n8Y>L6ognKh`KoRjGV1_n/`NT00onebn[o0000ol7F
j@03ol7Fj@Co`MS[1_ncc>d00on^angoYl3[ojO0j`06ojO0j`oooooo00?o0000ooooooooool02?oo
ool001Gooooo00?o0000ooooooooool06Oooool3o`0000Sooooo00?oYko[ojW1jonY`N/01OnY`N/6
ojFok0?oVkS/0_n?/Nh5ohNXj`OoUK7Z1?n_`nP6ol3@iP03olWHiOo:enCob]OT00Gob]OT0oo5e>D7
ojo6j`?oW[[/0onI]n`6oinij`KoY;g[0_nV_^/6ojJok0GoY;g[0onU_^/6ojNoj`OoZ<7[3_nV_n/7
ojS0j`;oZ<7[1OnY`>/7ojO0j`;oY[o/3?nV_^/2ojS0j`_oZL7[0_nX`N/<ojNoj`03ojS0jonZ`^_o
Z/;[00KoZ/;[0_nZ`n/5ojW2k0OoZL7[00?o[LC[ojo6jon_a^/01On_a^/2okC<k0Go[lW]1_nQ^n`6
ohRTi`KoOi_S1_n;YNH2ojc1j@Co]L_Z00?o0000okG;j_o1e^T01oo1f>/2ok?<k@Go[/O]1_nW`>/0
0onV_^_oooooooooo`0=ooooo`03o`000?oooooooooo00Sooooo000Eooooo`03o`000?oooooooooo
01Kooooo0ol0000=ooooo`OoZL7[0onU_n`3oinlk@GoSk7^1On7Z>/7oiFajP03ojo3j?o0d>Ko`=3V
00Go`=3V0oo7dn<4ol[Gi0OoaMCU0on_a^/3ojK1k@KoVKO/1_nO^N/2ojBmj`KoY[k[1_nV_n`00onT
_N_oYKk[ojFnj`05ojFnj`KoYko[1onX`N/6ojJoj`03ojJok?nV_n_oY[o[00GoY[o[1OnX`>/9ojW0
j`GoYl3[0_nW_^X;ojJnj`?oYko[2OnY`N/6ojS1j`SoYko[1OnX`>/6oj[2j`;oZ/?/1_nY`^`6ojW1
j`03oj_3jon_a^_o[lK[00Go[lK[00?o/l_/ojo9kOn_bNd01_n_bNd6oj6kk0KoR:CW1_moVn<3oh^U
iP?oVZoV1_nebnX00ol0003o_=?[ol7Hj`05ol7Hj`;o^]K^1on^and2ojO0j`GoY[k[3oooool00ol0
003oooooooooo`07ooooo`005?ooool2o`0001Gooooo0ol0000Aooooo`GoZL7[0_nX`N/6oinlk@Go
Sk7^1On7Z>/5oiFajP?oXk[Y1Oo0d>H6olOCh`03ol[Gi?o5e>GoaMCU00GoaMCU00?o^lkYojK1kOnV
`Nd01OnV`Nd6oiVgk0?oWkW[1?nR_>`7ojJnj`?oY[o/0onT_^`8ojFnj`?oYko[0onX`>/7ojS1j`;o
Y[o[1OnV_n`7ojJoj`03ojS0jonY`>_oZL3[00_oZL3[00?oYl3[ojNnj_nW_^X01?nW_^X7ojJnj`Oo
Yko[1OnY`N/2ojW2k0SoZ<7[1_nW_n/7ojS0j`;oZ/;[1_nZ`n`6ojW2k0;oZL7[1On[`n/4ojo6j`Co
/l_/1_n_bNd00onW`NcoU:oYoiB_j@04oiB_j@KoPi_R1_n5WN87oiZ_iP?o]L_Z0onldn/00ol0003o
_=?[ol7Hj`02ol7Hj`Go^]K^1On^and2ojW3k0KoY[k[3oooool00ol0003oooooooooo`07ooooo`00
5?ooool00ol0003oooooooooo`0Booooo`;o00005Oooool00onY`N_oZ<7[ojS1j`04ojS1j`KoWkc]
1On?/Nh5ohNXj`03oiFaj_nS^^WoXk[Y00GoXk[Y0oo0d>H6olOCh`?ob]?Q1?o5e>D4ok_>j@OoY/7]
0onI]n`2oiZgk0SoX[c/1OnV_^/00onW_n_oY;k/ojBnk005ojBnk0KoYKk[00?oY[o[ojS0jonX`>/0
1OnX`>/5ojS1j`;oYl3[1onV_n`5ojJoj`;oY[o/2_nY`>/4ojVojPOoYkkZ1onV_^/7ojNoj`03ojW1
jonY`^coZL;/00CoZL;/1_nX`N/8ojNoj`GoZ<3[0_nY`N/8oj[3k0?oZL;/0onX`N/7oj_3j`03ojo6
joncbnco/l_/00Go/l_/0_n_bNd5ojO1k0KoU:oY1_n3Vn86ohFMhPOoVZoV00?o]L_ZokcCjonldn/0
0onldn/00ol0003o_=?[ol7Hj`07ok[FkP03ojk7kOnY`ncoZL?/00CoZL?/1_nV_^/>ooooo`03o`00
0?oooooooooo00Oooooo000Dooooo`03o`000?oooooooooo00oooooo0ol0000Hooooo`OoZ<7[0onO
_>d3oiVhkPGoQJW]1_n<[>/7oj>jj@03ol3@i_o7dn?oam?S00Coam?S1Oo:dn400oo5e>Go^lkYok_>
j@05ok_>j@GoY/7]00?oW[c^oiZgk?nJ]n`01?nJ]n`8oj:lk003ojJnjonW_n_oYko[00?oYko[1onT
_^`2ojFnj`GoY[o[1onX`>/00onX`N_oYl3[ojO0j`04ojO0j`OoY[o/00?oY[o[ojJok?nV_n`01?nV
_n`5ojW0j`03ojW1jonY_n[oZKoZ00KoZKoZ1onW_^X6ojJnj`KoYko[0_nX`N`7ojW2k0;oZ<7[3?nW
_n/00onX`>_oZL7[ojW1j`04ojW1j`KoZ/?/00?oZL?/ojS1jonX`N/01OnX`N/5oj_3j`?o[<G/1Onc
bn`2ok;<k@KoYl7/1_nD[nT6oh>KhPKoQIgR1_nJ[nH00on[`N[o_=?[okcCj`04okcCj`03o`000?o0
fNco`=W/00Ko^]K^00?o/Lc]ojW3k?nY`n`01_nY`n`3ojJnj`?oYko[3Oooool00ol0003ooooooooo
o`07ooooo`005?ooool00ol0003oooooooooo`0<ooooo`?o00007?ooool5ojS1j`;oYKo/1_nI^>h5
ohFYk@KoS:c[1OnS^^T3okG5iPCoam?S1Oo:dn43ol[Bg`Oo^lkY00?oY/7]oijlk_nN_>h00onN_>h6
oiZgk0KoX[c/0_nT_N`6ojNoj`OoY;k/1onV_n/7ojS0j`OoYl3[3_nV_n`00onY`>_oZL7[ojW1j`03
ojW1j`SoZKoZ1onW_^X6ojJnj`;oYko[1_nX`N`5ojW2k0;oZ<7/3?nW_n/2ojS0j`OoZL7[0_nZ`n`5
ojW3k0OoZ<7[00?oZl?[ojc5k?n/aN`01On/aN`00oncbnco//c]ok;<k@04ok;<k@KoYl7/1_nD[nT6
oh>KhPKoQIgR0_nJ[nH5oj_1jPCo_=?[0_o0fN`00ol0003o`=W/ol3Ik002ok[FkPGo/Lc]1_nY`n`0
0onV_n_oYko[ojNoj`05ojNoj`cooooo00?o0000ooooooooool01oooool001?ooooo0ol0000:oooo
o`?o00008?ooool00onX`N_oYKo/ojFok004ojFok0KoVKS^1On5ZNd6ohb/j`03oj>jjOneaNKo]LGV
00Ko]LGV00?oam?Sol[ChOo:dn400oo:dn45ol[Bg`Go^lkY0_naanX6oijlkPKoV[O/0_nR_>`6ojBm
k0KoYko[1onT_^`7ojJoj`OoZ<3[1onW`>/<ojJok0;oY/3/1_nY`N/6ojVojP;oZ<3[1onW_^X3ojJn
j`?oYl7/2?nX`N`00onY`^coZ<7/ojS1k004ojS1k0SoYko[1_nX`>/5ojW1j`;oZ/?/1onY`n`3ojS1
j`?oZL;/1on/aN`00on`bngo//c]ok;<k@06ok;<k@?oYl7/0_nM]>P6ohVMh@KoQI[O1_n?Y><8oj_1
jP03okcCjoo0fNco`=W/00?o`=W/00?o0000okkKk_nac>d01onac>d2ojW3k0GoY[o[1onW_n/;oooo
o`03o`000?oooooooooo00Oooooo000Dooooo`03o`000?oooooooooo00Kooooo0ol0000Uooooo`Ko
YKo/1_nI^>h5ohFYk@?oS:c[0onF/n`7okG5iP?o`LcS0oo:dn47ol[Bg`03ok_>jOnaan[o/LOZ00Co
/LOZ1_nN_>h3oiZgk0CoW;W/1onT_N`3ojNoj`?oY[o/1onT_^`7ojJoj`OoZ<3[1onW`>/8ojJok0Ko
Y/3/1_nY`N/2ojVojPKoZ<3[1OnW_^X8ojO1k0KoZ<7/00?oZ<;/ojS1k?nX`N`01_nX`N`6ojNoj`So
Z<3[00?oZL7[oj[3k?nZ`n`01?nZ`n`5ojW3k003ojS1jonY`^coZL;/00GoZL;/1?n/aN`4ok3;k@Ko
//c]00?oZ/?/oifdj?nM]>P01?nM]>P6ohVMh@KoQI[O1_n?Y><6oj_1jP;o]/o/1?o0fN`01?nnfnko
0000okkKk_nnfnh6ok7<k@03ojc6kOnV_n_oY[o[00KoY[o[0onW_n/3ojW2k0_ooooo00?o0000oooo
ooooool01oooool001Cooooo00?o0000ooooooooool00oooool3o`0002Wooooo1_nU_n`3oiVhkP;o
SK?`1On4ZNd7oiJck0Co]LGV1_o1c><00oo:dn7ob];Ool[Bg`05ol[Bg`;ob<oP1onaanX3oijlkPCo
VKW^1_nL^N`5ojBmk0;oYKk/1_nV_n`8ojBnk0KoY[o[1onX`>/7ojO0j`OoY[o/1onV`>`3ojW1j`?o
Z<7/2?nX`>/00onW_^[oYl7/ojO1k00:ojO1k0;oZ<7/1OnX`^`6ojS1k0SoYko[1_nX`>/00onX`^co
Z/?/oj[3k006oj[3k003ojW3k?nX`N_oZ<7[00?oZ<7[1onY`^`00on/aNco/<_]ok3;k@05ok3;k@;o
//c]1OnZ`n`6oifdj0KoRIgQ1_n5V]l6ohnTh`;oZl7Z1_nfcn`00oo0fNco_]_^okkKkP02okkKkP03
o`000?nnfnko_]_^00;o/Lc]1On/a^d6ojJoj`03ojJnjonY`^coZL;/00GoZL;/2oooool00ol0003o
ooooooooo`06ooooo`004oooool01?l0003oooooooooooooool3o`0002gooooo0onU_n`3oj2mk@Go
SK?`1On4ZNd7oiJck003okG5i_o1c>?o`LcS00Go`LcS0oo6c]l4ol[Bg`Gob<oP1OnaanX3ojc3j`Ko
VKW^1_nL^N`00onT_NcoYKk/ojFnk004ojFnk0KoY[o/2?nT_^`6ojJoj`OoZ<3[1OnW`>/2ojNoj`Oo
Y[o/1onV`>`6ojS1k0KoZ<3[3?nW`N`:ojS2k0;oZ<7/3?nW_n/2ojS0j`GoZ<;/1_nZ`n`00onY`nco
Z<7[ojS1j`05ojS1j`GoZL;/0on/aNd5ok3;k@;o/Lk^1_nZ`n`6oifdj0KoRIgQ1_n5V]l5ohnTh`;o
X;CW1_nfcn`2okgIkPGo_]_^00?o0000okGAkon/a^d01on/a^d2ojJoj`GoY[k[1onY`^`:ooooo`03
o`000?oooooooooo00Kooooo000Cooooo`Co0000<Oooool6oj2mk@GoSK?`1On4ZNd5oiJck0?oX[[Z
1Oo1c><6olK>g`03ol[Bgoo8cn3ob<oP00Gob<oP00?o/LOZojc3jon/`n/01On/`n/6oiVikP?oW;W/
0onO^nd7ojFnk0?oY[o/0onU_n`8ojBnk0KoY[o[1onX`>/00onW`>_oYko[ojNoj`04ojNoj`OoY[o/
1onV`>`6ojS1k0;oZ<3[3OnW`N`;ojS2k0;oZ<3[2onW_n/3ojS1j`OoZ<;/0_nZ`n`5ojW3k0OoZ<7[
00?oZL;/ojc5kOn/aNd01On/aNd00on`bngo/Lk^ok7>kP04ok7>kPKoZ/?/1_nM]>P6ohVMh@KoQI[O
00?oSjCSoj2dionP]>L01?nP]>L3okK?k0Go_MW^0_nnfnh3okGAk`03o`000?nedNoo[<K]00Go[<K]
00?oZ<7/ojJnjonV_^/01_nV_^/3ojW2k0?oZ<;/2_ooool00ol0003oooooooooo`06ooooo`004ooo
ool2o`0003Cooooo1_nP_Nd5ohfcl0GoQ:W]00?oU[?/oj:jj_nR^^X01OnR^^X3ol7<h`Koa/kO0_o9
cMd6olS?h0;o`lcR2?n/`n/3oiVikP?oUkW_1_nO^nd5ojFnk0;oY[o/1_nU_n`6ojBnk0;oY;o/1_nV
_n/7ojS0j`OoYko[0onV_n`;ojK0k0?oZ<7/0onV`N`?ojO1k0OoZ<;/1_nX`>/7ojNoj`OoZ<7[1OnX
`^`9ojW3k0?oZ<7[1?nY`^`6ojc5k@03ojo<konac^ko/Lk^00Ko/Lk^0onZ`n`2oj2fi`KoSj3P1_n8
VMd6ohbOh0SoX;CW00?o]/o/okgIk_nmfNh00onmfNh2okkMk`Co]M7_00?o0000okGAkonedNl00_n/
a^d5ojS1k0KoY[k[00?oZL;/ojS2k?nX`^`01OnX`^`9ooooo`03o`000?oooooooooo00Kooooo0005
o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo03;ooooo0onP
_Nd3oi^kkPGoPjg`1_n8[Nh7oj:jjP03ol7<hoo6c]ooa/kO00Coa/kO1?o9cMd3olS?h0Go`lcR1_n/
`n/2ojK1k0KoUkW_1_nO^nd00onU_^coY[o/ojJok004ojJok0KoYKo/0_nT_^`6ojBok0KoY[o[1onX
`>/6ojNoj`ooY/3/1_nV`N`?ojO1k0?oZ<;/0onX`N/7ojS0j`OoYko[1onX`N/00onX`^coZL?/ojW3
k009ojW3k0;oZ<7[1onY`^`2ojc5k@Go[lc_1_nac^h00onZ`ncoX;KWoj2fi`04oj2fi`KoSj3P1_n8
VMd6ohbOh0KoX;CW0_nabnd3okgIkPGo_]g_1?nedNl00ol0003o[LS]ojg8k@07ojS1k0;oY[k[1OnY
`^`7ojS2k0Sooooo00?o0000ooooooooool01_ooool00005oiRHV?lQ8B7ok^k^oooooom4A4@00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Wooooo00?o0000ooooooooool0<_ooool6oi^kkPGoPjg`
1_n8[Nh5oj:jjP?o/<7V0oo6c]l7olW=g@03olS?h?o3c>;o`lcR00Go`lcR0_n/`n/6ojK1k0KoUkW_
0onO^nd3oj2mk@OoY[o/1onU_n`7ojBok0?oY[o[0onV`>`7ojS0j`KoYko[3onV`>`6ojK1k0goYl7/
00?oYl3/ojS1jonX`N/01OnX`N/5ojS0j`SoYko[1_nX`N/00onX`ncoZL?/ojW3k007ojW3k0KoZ<7[
1OnY`^`2oj_6k@Oo[lc_0_nac^h5oj[3k0KoX;KW1_n?X>05ohRIg@OoS9oP0_nP]>L6ok7;k@03okgI
k_nngNoo_]g_00Go_]g_00Go]M7_ojg8kOn]b>go[LS]o`000002ojg8k@GoZ<7/00?oY[k[ojW2k?nY
`^`01OnY`^`6ojS2k003ojS0jooooooooooo00Kooooo00?o0000ooooooooool01_ooool00004oooo
oonHV9So8B4Qonk^kPCooooo00Go410@oooooooooooooooooa0@400:ooooo`03o`000?oooooooooo
03;ooooo1_nK^nh5oh>]l0KoR:g^00?oX[[Zok31i_n``NH01On``NH00oo6c]oobLgMolW=g@05olW=
g@?ob/cK1Oo3c>83okk9h`OoY/7/0onG^Nl3oiJil0KoX;g]1onV_n`7ojFok0GoY;o/0_nT_nd6ojK0
k0OoZ<3[1_nW_n/6ojK0k0;oY[o[1onV`>`6ojK1k0WoYl7/1OnW`>`7ojS1j`03ojS0jonW_n_oYko[
00[oYko[0_nX`N/5ojS3k0KoZL?/00?oZL;/ojS1jonX`N/01_nX`N/00onY`^coZlK]oj_6k@04oj_6
k@Go[lc_0_n`cNl6oj[3k0OoX;KW1_n?X>05ohRIg@?oS9oP0onJ[N@7ok7;k@;o^]S_1_nngNl00ong
e_3o[LS]ojg8k@03ojg8k@04o`000?n]b>go[LS]ojS1k0GoY[k[1onY`^`2ojS2k0GoZ<3[1oooool0
0ol0003oooooooooo`06ooooo`000_ooool00onHV9So8B4Qonk^kP03ooooo`05o`000?oooooooooo
ooooool000002oooool2o`0003?ooooo1_nK^nh5oh>]l0?oR:g^0on?/^h6ok31iP?o^/GR1Oo9cMd5
ol[<f`03ol?<h_nnbN?o_/WS00Go_/WS1OnV`N`2oj>ok@KoU[W`1_nP_Nd7ojJok0OoYKo/00?oY;o/
ojBokOnT_nd01?nT_nd6ojK0k0OoZ<3[1_nW_n/2ojK0k0KoY[o[1OnV`>`2ojJoj`KoY/7/1OnW`N`2
ojO0j`OoYl3/0onX`N/>ojNoj`CoZ<;/1_nX`n`2ojW3k0GoZL;/1_nX`N/00onY`ngoZlK]oj_6k@06
oj_6k@03ojo<kon`cNoo/<g_00Co/<g_1_nZ`n`3oj2fi`?oTZ3M1_n;VM/5ohfMgPOoVZgT1?nabnd5
ok[Hk`;o_]g_1Onge_04ojg8k@03o`000?n]b>goZ<;/00OoY[k[1_nY`^`8ojS0j`Oooooo00?o0000
ooooooooool01Oooool000?ooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo
000000gooooo00?o0000ooooooooool0<Oooool3oi^kkP?oTkS`1OmoZo06ohnbkP?o/<7V1_njaN83
olW=g@Gob/cK0oo9b]X7okk9h`03ojK1k?nS_ngoXko]00CoXko]1_nF^O03oj2mk@?oXKk]1onV_n`7
ojFok0OoY;o]1_nV`>`7ojS0j`?oYko[0onX`>/8ojJoj`03ojK0k?nV_n_oY[o[00CoY[o[1_nV`N`0
0onW`NcoYl3[ojO0j`04ojO0j`GoYl3/0_nW_nX<ojNoj`;oYl7/1onX`^`3ojS3k0?oZL?]1onY`^`2
ojS1j`GoZL?]1_n[a^d2ojo>l0Oo/<g_0onZ`n`2oj6ci@OoTZ3M1_n;VM/5ohfMgPOoVZgT00?o/L_]
ok[Hkonjf>l01?njf>l00onmgo7o]mK`okOFl006okOFl0;o[LS]0_nX`^`00ol0003oZ<;/ojS2k005
ojJnj`;oZ<7[1_nY`^`6ojS0j`03ojNojooooooooooo00Gooooo00?o0000ooooooooool01Oooool0
00Cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00cooooo00?o0000
ooooooooool0<Oooool6oi>hl0GoOj_`1_n?/^h00on``NKo^/GRok[5hP06ok[5hP03olW=gOo:c=_o
b/cK00?ob/cK1Oo9b]X5okk9h`;o^/KS1onS_nd3oiJil0?oU[[`1_nQ_^d5ojJok0;oY/3/1onU_n`7
ojBok@KoY/3/3OnX`>/6ojJoj`03ojRojonV_n_oY[o[00KoY[o[0onV`N`3ojNoj`OoYl3[00?oYl3/
ojNoj_nW_nX01?nW_nX8ojNoj`KoYl7/1OnX`^`2ojS4k@KoZL?]1OnY`^`2ojS1k0OoZL?]0_n[a^d6
ojo>l0?o/<g_0onX_nX6oj6ci@KoTZ3M1_n;VM/6ohfMgPGoVZgT0on^b>d3ok[Hk`Co_Moa1_nge_02
ojk9kPCoZ<;/00Co0000ojS2k?nX`^coY[k[1_nX`N/6ojW2k0;oZ<3[1OnW_n/6ooooo`03o`000?oo
oooooooo00Gooooo00001Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0?ooooo`03o`000?oooooooooo037ooooo1_nC^?05ogn[l0?oSk;^1?nF]nh6ok[5hP?o`LSO
0oo:c=/7olW:fP03okk9honja^?o^/KS00Co^/KS1OnS_nd2oj6nk@KoU[[`1_nQ_^d00onV_ncoY/3/
ojK0k004ojK0k0OoYKo/1onT_nd6ojK0k0goZ<3[0_nV_n/5ojRoj`KoY[o[0_nX_nX6ojNoj`GoYl3[
0_nX_n/7ojNojP?oYko[2onW`N`00onX`^coZ<C]ojS4k@04ojS4k@KoZL?]00?oZL;/ojS1k?nX`N`0
1?nX`N`5ojW3k@?oZlW_1On_c_02ojk:kPKoZ;oZ1_nQ/nD5oi:Pg@KoRiWK1on=WMh00onJ[NCo[/S]
ojk8k@05ojk8k@03ok[Hkonmgo7o_Moa00Co_Moa0_nge_06ojk9kP?oZ<;/00?oY[k[o`000?nV_^/0
2?nX`N/3ojW2k0;oZ<7[2?nW_n/5ooooo`03o`000?oooooooooo00Gooooo00001OnHV9So410@o`00
0?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0@ooooo`;o0000<_ooool3oi>hl0?o
RkGb1_mo[?46oiJgkP?o^/GR1_o1b=l00oo:c=_obL[JolW:fP05olW:fP;obLOI1onja^<00onS_ngo
XKk]oj6nk@04oj6nk@KoU[[`0onQ_^d3oj6nkPOoY/3/1onU_n`7ojBok@?oY/3/0onV`Nd=ojS0j`Oo
Z;o[0_nV_n/6ojRojPKoYko[00?oYl3[ojRojonX_n/01?nX_n/5ojNojPkoYl7/00?oZ<?]ojS4kOnX
a>d01_nXa>d3ojW3k@[oZ<7/00?oZL?]oj_9kon[bNl01On[bNl00on_c_3o[/[^ojk:kP04ojk:kPKo
Z;oZ1_nQ/nD5oi:Pg@KoRiWK0on=WMh3oiR[h`Oo[/S]0_ngfO45okgOl@;o]mSa1_n^bNh00onY`^co
Y[k[ojJnj`02ojJnj`03o`000?nV_^_oY[k[00KoZ<7[00?oZL;/ojS1jonX`N/01?nX`N/6ojNoj`03
ojJnjooooooooooo00?ooooo00?o0000ooooooooool01Oooool001oooooo00?o0000ooooooooool0
<Oooool5oh^elPKoOjca1_nF]nh00onjaN;o`LSOol78g`04ol78g`;o`lOM1_o9b]X4olW7f@Go^/KS
0onh`n<6oj6nk@?oU[[`0onF^o46oj6nkPGoY/3/0onU`>`6ojFok0OoY;o]1_nV`Nd5ojS0j`;oYl7/
1_nX`>/5ojRoj`;oZ<3[2?nX_nX3ojNoj`?oZ<3[1onX_n/00onW_n[oYl7/ojO1k00<ojO1k0GoZ<?]
1_nXa>d=ojS1k0;oZLK^1_n[bNl00on^co7o[/[^ojk:kP06ojk:kP?oZ;oZ0_nO[>06oi>LfPGoSYWI
1_n?WM`7oiR[h`Co[/S]1OngfO400onmgo7o]mSaokOHl@04okOHl@;o[/W^1OnY`^`4ojJnj`03o`00
0?nV_^_oY[k[00;oZ<7[1OnY`^`6ojS1j`;oYko[1OnV_^/4ooooo`03o`000?oooooooooo00Gooooo
000Pooooo`03o`000?oooooooooo037ooooo1On;]O86ogn/l@?oU[O^0onN^nd5ol78g`Co`lOM0oo9
b]X7olW7f@03ok[6honh`n?o^<?S00Go^<?S0onQ_^d3oj6mk@KoU[_a1_nQ_^h00onV`>coYL3/ojG0
k005ojG0k0KoYKo/1onT_nd6ojK1k@03ojS0jonW`NcoYl7/00CoYl7/1_nX`>/00onX_n_oZ<3[ojS0
j`04ojS0j`KoZ;oZ00?oZ<7[ojS0jonX`>/01OnX`>/5ojRoj`coYl7/0onW`nd7ojS3k@;oZ<C]3OnX
`N`6ojW6kP;oZlW_1On^co46ojk:kP03ojJiionO[>3oWjcP00CoWjcP1_nCW=X5ohjIf@KoSigL1onH
Zn<00on^b>go]mWaokOIl@04okOIl@;o^n3b1Ongf?42ojk:kPKoZL;/1OnV_^/00ol0003oZ<7[ojW2
k007ojW2k0?oZ<7[0_nW_n/8ojJnj`?ooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000
ooooooooool0<Oooool5oh^elP?oOjca0_n1[o87oijkk@?o`LSO1_o3amd00oo9b][obLOIolW7f@05
olW7f@;ob<GH1_nh`n<2okS1h@KoXKg]1_nF^o43oj6nkP?oX;o_2?nU`>`3ojFok0?oY/3/1onT_nd3
ojK1k@?oYL7]1onW`N`3ojS0j`?oYl7/1onX`>/2ojRojPGoZ<7[1onX`>/00onX_n_oYl7/ojO1k009
ojO1k0SoYl?]1OnX`nd2ojS2k0[oZ<7/1?nXa>d5ojW6kP;oZlkb1on^co42ojk:kPGoY[WW1_nO[>05
oi>LfPKoSYWI1_n?WM`5oiR[h`;o[LW_1?ngfO45ok_PlP03okOHlOn^b^ko[/[^00Co[/[^1_nY`^`2
ojJnj`;oZ<7[00?o0000ojS1jonX`N/01_nY`^`00onX`N_oYko[ojNoj`04ojNoj`KoY[k[00?oYko[
ooooooooool00_ooool00ol0003oooooooooo`04ooooo`008_ooool00ol0003oooooooooo`0aoooo
o`GoQ;;c1On1[o87oijkk@03ol78goo3amgo`lOM00Co`lOM0oo5a]/5olW7f@Cob<GH0onh`n<5okS1
h@KoXKg]0onF^o43oiFllPKoX;o_1_nU`>`2ojG1k@KoY/3/1onT_nd6ojG1k@GoYl7/0_nV`Nd6ojO1
k0GoZ<3[0_nW`N`7ojS1j`?oZ<3[3?nW`N`<ojO3k@03ojS3kOnX`^coZ<;/00CoZ<;/1OnX`N`2ojS2
k@OoZ<C]00?oZLK^oj_>l_n[c_801?n[c_85ojk?l@;oZl;[1_nV^NL6oin/h0GoTicJ1_n>VMT7ohnM
g003oiR[hon]bNoo[LW_00Co[LW_00?o]mWaok_Pl_nkh?801?nkh?800oneeo7o[/[^ojk:kP06ojk:
kP?oZL;/0_nV_^/5ojS1j`03o`000?nX`N_oZ<7[00;oZL;/1OnX`N/6ojNoj`;oY[k[1OnW_n/3oooo
o`03o`000?oooooooooo00Cooooo000Sooooo`;o0000<_ooool5ohBbl`GoPJob1OnN^nd2ojJnj`Go
`lOM1Oo5a]/3olW7f@Kob<GH00?o^<?SokS1hOnh`N401Onh`N43oj6mk@?oXkg/1_nE_?86oj2ok`;o
YL3/1_nU`Nd6ojK0k0OoY;o]1_nU`Nd00onW`NcoY/7]ojK1k@04ojK1k@KoYl7/00?oZ<3[ojO1k?nW
`N`01?nW`N`5ojS1j`;oYl;]3?nW`N`00onW`nkoYl?]ojO3k@09ojO3k@CoZ<;]1_nX`^`00onX`Nco
Z<;]ojS2k@04ojS2k@GoZ<C]0_nYbo47oj_>lP03ojk?lOn[`^_oZl;[00CoZl;[1_nV^NL6oin/h0Go
TicJ1_n>VMT3ohnMg0CoVZgT1On]bNl2okKKl`Co^n3b1?neeo46ojk:kP03ojS2k?nV_^_oY[k[00Co
Y[k[1OnX`N/00ol0003oZL;/ojS1j`07ojS1j`?oYko[0_nV_^/8ojNoj`;ooooo00?o0000oooooooo
ool01?ooool002Gooooo00?o0000ooooooooool0<?ooool5ohBbl`GoPJob00?oW[_]ojJnjonV_^/0
1?nV_^/3ol?7g@OoaLKK00?obLOIolS5f?o8aMP01?o8aMP2olO3ePKo^<7Q0_ni_ml6oj>mk0KoUKcb
0onP_nl3oik1l@SoYL7]0onV`>`3ojK1k0OoY;o]0onU`Nd3ojC0k@OoY/7]0onW`N`4ojK2k@KoYl7/
00?oZ<7[ojO2kOnW`^d01?nW`^d8ojO1k0GoYl?^1_nW`nd00onW`^goZ<;]ojS2k@06ojS2k@?oZ<;/
0_nW`^`8ojS2k@03ojS4kOnYbo7oZL_a00CoZL_a1On[c_800on/b^ooZl;[oj_2j`06oj_2j`?oY[WW
0_nKX]T6oiBJe`GoTIWH1_nCWm`8oiZ]i003ojg9konffo?o]]_c00Co]]_c00?o^n3bokGGlOneeo40
1Oneeo42ojk:kPGoZ<;/1_nV_^/2ojS1j`?oZL;/00?o0000ojW2k?nX`N/01OnX`N/00onW_n_oY[k[
ojJnj`04ojJnj`KoYko[00CoZ<7/oooooooooooo00001_ooool002Kooooo00?o0000ooooooooool0
<Oooool4ogjam0GoPk7c1onV_^/00oo3amgoaLKKolG6f`05olG6f`;oaLGJ1Oo8aMP4olO3eP?o^<7Q
1Oni_ml6oj>mk0KoUKcb1_nN`O46ojG1k@;oXl7^1_nV`N`5ojBok@;oY/3/1_nT`>d5ojK1k@;oY<7^
1onV`^d3ojO1k0?oY/;^1onW`^d3ojO1k0CoY/?^1_nW`nh2ojO3k@GoYl;]1_nX`^d00onW`NcoYl;/
ojO2k004ojO2k0KoZ<;]0_nXb?07ojW;l@03oj_>l_n/b^oo[<[_00?o[<[_1_n[`^/00onS[MkoVj;I
oi^Rf@04oi^Rf@KoU9[G1OnAVMP6oi>Og0KoVZgT0_n]cO45okKKl`?o^N7d1Oneeo400on]bNkoZ<;/
ojS2k006ojS2k0?oY[k[1?nX`N`3ojW2k003o`000?nY`^coZL;/00;oZ<7[1OnW_n/6ojJnj`;oYko[
1OnX`N`00ooooooo0000ooooo`05ooooo`009oooool00ol0003oooooooooo`0aooooo`CoO[7d1On3
/O<5ojJnj`?oZl3Y1Oo5a]/4olG5fP?ob<GH1_o7`mH00onh`N7o^KoOokVog`05okVog`?oXkg/0onV
_NT6oiFllPKoW/7a0_nU`Nd6oj?1kPKoY/7/00?oY;o]ojK0k?nV`>`01?nV`>`6ojC0k@03ojK1kOnT
`NkoY<7^00CoY<7^1OnV`^d2ojG1kPKoY/;^1OnW`^d2ojK2kPOoY/?^0onW`nh:ojO2k@;oZ<;]1OnW
`N`6ojO2k0;oZ<;]1_nXb?03ojW;l@Co[<kb1_n/b^l2oj_2j`GoXjgN1_nKX]T5oiBJe`KoTIWH1_nC
Wm`2oiZ]i0Ko[Lga00?o]]_cokWQm?nihO@01OnihO@00oneeo7o[LW^ojg9kP03ojg9kPKoZ<;/00?o
Y[kZojS1k?nX`N`01_nX`N`3ojW2k003o`000?nX`N_oYko[00OoYko[0onV_^/3ojNoj`OoZ<7/00?o
0000ooooooooool01?ooool002Sooooo0_l0000booooo`CoO[7d1On3/O<00onV_^_oZl3Yoj_0j@05
oj_0j@?oaLKK1_o5aMX00oo8aMSoal?FolO3eP04olO3eP;oa/7E1_ni_ml2ok^mf`KoY[gY1_nE_?83
oik1l@CoVl7c1onS`Nh3ojK1k0?oY/7]1onV`>`3ojC0k@CoYKo/1_nT`Nh00onV`^goYL7^ojG1kP04
ojG1kPKoY/;^00?oYl;]ojK2k_nV`^h01?nV`^h5ojK3kP;oY/7/2onW`^d9ojO1k0?oYl;/1?nXa^l5
ojS8l0;oZ]3d1on/c_83ojc:k`?oY[OT1_nS[Mh6oi^Rf@GoU9[G1onAVMP3oi>Og0?oWkGX1_n]cO42
okGNm@Ko^N7d0_nbdo46ojg9kP;oZ<;/1OnV_^X6ojS1k003ojS2k?nX`N_oZ<7[00;oZ<7[00?o0000
ojS1jonW_n/01OnW_n/00onV_^_oYko[ojNoj`05ojNoj`GoZ<7/00?oooooo`000?ooool01Oooool0
02[ooooo00?o0000ooooooooool0<?ooool5ogZ`m@GoQK?c1on[`>T00oo5a]_oaLGJolG5fP04olG5
fP;oa<CI1Oo7`mH4olK1e@?o^KoO1Onk_M/6ojJmj@?oUKcb1?nH_?47oi_1l`?oXl7^0onQ`o46ojK1
k@GoY/3/0_nW`Nd7ojFok0?oY<7^0onU_n`7ojG1kP?oY/;^1?nU`Nd6ojK2kP03ojK3k_nV`NcoY/7/
00CoY/7/1onW`^d;ojO1k0;oYlK_1onXa^l00onXb?3oZ]3doj[@m004oj[@m0Go[<kb0_nX_>P6ojJg
i0GoXjgN1onKX]T5oiBJe`?oTIWH0onGXmd7oinej0?o[Lga1Oneg_D2okWQm0Ko/]?a0on]bNh3ojS0
j`OoY[kZ0_nX`N`5ojS2k0CoZ<7[00Co0000ojS1jonW_n_oYko[1OnV_^/7ojNoj`03ojS1k?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool002_ooooo00?o0000ooooooooool0<?ooool5ogZ`
m@GoQK?c1On[`>T2ojg2j@GoaLGJ1?o4a=T3olO3ePKoa/7E00?o^KoOok^mfonk_M/01Onk_M/3ojJm
j@CoZkcV1onH_?43oi_1l`?oUl3d1_nQ`o46ojK1k@03ojK0k?nW`NgoYl7]00CoYl7]1OnU_n`2ojO1
k0KoYKo/1OnU`Nh2ojK0k0OoYL7]0onV`^h3ojK0k0OoY/7/0onW`^d4ojO2k0OoYl7/1_nWa^l5ojS6
k`?oYlod1_nZd?@00on/c_;oZ;cXojRlj004ojRlj0KoY[OT1OnS[Mh3oi^Rf@?oUY[E1OnEW=P7oiNS
g@OoWkGX00?o[LgaokGNmOneg_D00oneg_D2okKQm@Ko/]?a00?oZlK]ojS0jonX`>/01OnX`>/5ojJn
jPWoZ<;/0onX`N/00ol0003oYko[ojJnj`07ojJnj`?oYko[2Oooool00ol0003oooooooooo`03oooo
o`00;?ooool00ol0003oooooooooo`0`ooooo`GoN[3e1On5/o<00on[`>Wo[L;Yojg2j@04ojg2j@?o
aLGJ1_o4a=T00oo7`mKoa/7EolK1e@04olK1e@03olJoe?nk_M_o^kgK00Go^kgK0_nn^mL7oj^liPGo
V;ca0_nN_>d6oiO0m0KoXL?a0onV`Nd4ojC2k`KoYl7]00?oYKo/ojO1k?nW`N`01?nW`N`6ojFok003
ojG1k_nV`>coY/3/00CoY/3/1OnU`Nd00onW`NcoY/3/ojK0k005ojK0k0GoY/7/0_nW`^d7ojO2k0?o
Yl7/2_nWa^l00onXa^ooYlodojO?m005ojO?m0?oZ]3d0_nZ`^/8ojRlj0?oY[OT0_nNWmD5oiZKe0Oo
UY[E1OnEW=P6oiNSg@KoWkGX0on_e?<00oneg_Go]^7eokKQm@04okKQm@;o/]?a1On[a^d7ojS0j`03
ojJnj_nX`^coZ<;/00WoZ<;/00?oZ<3[ojNojonW_n/00_nW_n/00ol0003oYko[ojJnj`05ojJnj`go
oooo00?o0000ooooooooool00oooool002gooooo0_l0000aooooo`GoN;3f1_n6]O@6ojg2j@03olG5
f_o4a=Woa<CI00Coa<CI0_o3`mT5olK1e@?oa[oD1Onk_M/4okjke`OoZkcV00?oV;caoijlkOnN_>d0
1?nN_>d6oiO0m0?oXL?a0_nMa?@8ojC2k`?oYl7]0_nU`nl8ojO1k0?oYKo/0_nW`^d8ojK0k003ojG1
kOnW`NcoYl7/00?oYl7/1onV`>`00onV`NcoYl;]ojO2k@04ojO2k@GoYl;/00?oY/K`ojO6konWa^l0
2OnWa^l3ojK>m@KoYlod00?oZLC]oj[2jonZ`^/01?nZ`^/6ojRlj003oj>Vf?nNWmGoWYoE00CoWYoE
1OnJVm@6oiJJe@KoUIcH1_nGXmd2oinej0Go[mCc0_ndh_H5okKQm@;o[/k`1on[a^d3ojS0j`CoY[k[
2?nX`^`5ojS0j`CoYko[00Co0000ojNojonV_^_oY[k[4?ooool00ol0003oooooooooo`03ooooo`00
;oooool00ol0003oooooooooo`0_ooooo`GoN;3f1_n6]O@3ojg2j@?o[/;Y1Oo4a=T4ol?3f@?oa/7E
1Oo6_m@3ok^mf`Ko_[_G1On[_>H3ok2hg`KoW[c]0onG`?@2oiNnlPKoWLCd1_nT`^l00onPa_?oYL?_
ojG3k`04ojG3k`KoYl7/00?oYL?_ojO2kOnW`^d01?nW`^d6ojK0k003ojO3k_nW`NcoYl7/00GoYl7/
0onV`>`4ojO3kPOoYl;]00?oYl;/ojK6l?nVa_000onVa_06ojO6k`03ojG>mOnVc_GoY/ke00GoY/ke
0_nWco@5ojW4k@KoZ/;[0_nX_>P5oj>Vf0GoWYoE1_nJVm@5oiJJe@OoUIcH0onGXmd4ojK4k`?o[mCc
1Ondh_H00onfhOGo[/k`ojk>l004ojk>l0GoZlK]00?oYko[ojJnjonV_^/01_nV_^/5ojS2k0SoZ<3[
0onW_n/00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00?ooooo000`ooooo`03o`000?oo
oooooooo02oooooo1Omh/?H3ohJem0?oQKOf1_n^`^T3olC4f@Ko`l?I00?oa/7EolJoe?o6_m@01Oo6
_m@00onk_M_o_[_Gokjke`06okjke`03oj^li_n`^=oo/;SO00Go/;SO0onN_>d3ojJjj0GoUkkb1_nM
a?@2ojC2k`GoX<Kc1_nU`nl2ojO1k0GoYL?_1_nW`^d2ojK0k0GoYl?^1OnW`N`2ojK5k`OoYl?^0onW
`^d3ojK7l@OoY/K`0_nWa^l5ojG>m@GoY/ke0_nXa^l7ojW4k@?oZ/;[0_nUZm/7oj>Vf0KoWYoE1OnJ
Vm@6oiJJe@?oUIcH0onL[^@8ojK4k`03ojoDlondh_Ko]>;f00?o]>;f0_ndf_@7ojk>l003oj_6kOnW
_n_oYko[00?oYko[1_nV_^/7ojS2k0KoZ<3[1Oooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo00?ooooo000aooooo`03o`000?oooooooooo033ooooo1?mg/OH6ohFgmPKo[/;Y00?oa<CI
ol?3fOo3`mT01?o3`mT2ol;2fPKoa[oD0oo5_]<6okjke`;o`K[C1_n`^=l00onf]]SoY[[XojJjj005
ojJjj0GoUkkb0onMa?@4oiO2m@KoX<Kc0onU`nl4oj76lPKoYL?_0onW`^d4ojG4k`KoYl?^00?oYl7/
ojK5konVaNl01?nVaNl5ojO3kP;oY<Wc1_nVao45ojK6l0?oY<kf1_nUc_D00onVc_GoZ<K_ojS6k`04
ojS6k`GoZLC]00?oYZkMojF[fonUZm/01?nUZm/6oj>Vf0KoWYoE1_nJVm@3oiJJe@;oVZ?K1onL[^@6
ojK4k`?o[mcg00?o]>;fokCJm?ndf_@01?ndf_@3ojk>l0?oZL?/1onW_n/2ojJnj`_oZ<;/0_nX`>/9
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00oooool003;ooooo0_l0000aoooo
o`CoMk7f1_n5]oH3ojk2j@?oZl?[1Oo3`mT4ol;2fP?oa[oD1_o5_]<3okjke`Go`K[C0on`^=l4okJf
f0OoY[[X0_nG__84oijkk@KoUl;e0onPa_<4oi[5m@KoXLKb0onU`nl3oj;7l`OoYLC_0onW`nh4ojC7
lPKoY/G_00?oYl?^ojC9lonTbO<01?nTbO<6ojK7l@03ojK6l?nTc_KoY<kf00GoY<kf0onUc_D4ojO5
k`KoZ<K_00?oZLC]ojJ^gOnV[]d00onV[]d6ojF[f`KoXjKH1_nNWmD3oiZKe0;oVYkG1_nJXm/7oib^
i0;oY/C_1On_g?L2ok;Sm`Go]=[d0_n/bNl6ojW3k0GoYko[00?oYl3[ojS2k?nX`^`02OnX`^`>oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool003Cooooo00?o0000oooooooo
ool0;oooool4ogNamP?oQKOf0on2]oL6oj_3j`?o`l?I1_o2`]X00oo6_mCoaKkColFnd`06olFnd`03
okjkeoo1^]?o`K[C00Go`K[C00?o/;SOokJff?nf]]P01?nf]]P5ojJjj003ojfeg_nN^ngoW[_]00Go
W[_]0onG`_D4oi^ml0KoV/Ge0onQa_83oi_7mPKoX/Oc1OnUa>l2oj7:m@OoY<Ob0onVaNl4oj;;m@Ko
Y<Wc0onVao44oj;=mPGoY<kf0_nV`nh7ojO5k`?oZ<K_0_nW/=h7ojJ^g@KoYJ_K0onSY]P2oifLdPKo
VicD1_nJW]L6oiZSf`GoW:kT0_n[d_D4ojoLm`Go/^?g00?o]=[dojc9kon/bNl01?n/bNl6ojW3k003
ojNojonW`>_oYl3[00?oYl3[1_nX`^`Booooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool00_ooool003Gooooo00?o0000ooooooooool0<?ooool4ogRbm`GoP[Og1_n[`n/00oo3`mWo`/;J
ol;2fP04ol;2fP03ol34gOo5_]?oaKkC00KoaKkC00?oa;gDol6jdoo1^]<01Oo1^]<00oo2^M7o][KH
okJff006okJff003ojJjj?n]]Mko[KGN00?o[KGN1OnN^nd2ojRhi0OoVkg`0onJaOD3oi^nl@KoVlOf
1_nRao<00onUa>ooXL[eoj7:m@04oj7:m@GoY<Ob0_nOboH7oj;;m@?oY<Wc1?nPboH6oj;=mP03ojC>
m_nV`nkoY/?^00CoY/?^1OnWaNl7ojN`gPOoYZkM0onUZm/2oj2Md@KoWIcB1_nKW=@5oiZNe`OoVZ?K
00?oW:kToj_BmOn[d_D01?n[d_D00on_g?Oo/^?gok;Sm`04ok;Sm`03ojk@l_n/bNoo[<W_00Ko[<W_
0onY`n`3ojNnjPKoYl3[0_nX`^`Fooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
0_ooool003Kooooo00?o0000ooooooooool0<?ooool5ogRbm`CoP[Og0on[`n/3ojG3kPGo`/;J0oo0
a=d6olFnd`?oa;gD1Oo1^]<3ol:id@Ko][KH00?o_;CBojfeg_n]]Mh01On]]Mh00onN^ngoZ;STojRh
i004ojRhi0GoVkg`0_nU^>H6oi^nl@KoVlOf0onRao<4oi_7mPKoXL[e00?oY<Oboio;m_nOboH01?nO
boH5oj;;m@?oX<Kc1_nPboH3oj;=mP?oYL3/1onV`nh00onWaNooYk3NojN`gP09ojN`gP?oYZkM0onR
W]06oj2Md@KoWIcB1OnKW=@6oiZNe`?oVZ?K1?nUa?05oj_Bm@Co[^?i00?o/^?gojk@l_n^d?800on^
d?86ojc9k`03ojRojonW_^[oYkkZ00GoYkkZ0onW`>/Kooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool00_ooool003Oooooo0_l0000aooooo`GoNkCg1?mm^?P6ojG3kP?o`/;J1Oo0a=d3
olFnd`Koa;gD0oo1^]<5ol:id@?o][KH1?nl]=85ojfegP;o];7E1onX^>@00onK_O3oYKSVojFhiP04
ojFhiPKoVkka0onKaoH4oibol0KoVlOf0onQb_D4oig5m0KoWl_f00?oX/_eoj36lonPa_<01OnPa_<3
oj3;mP;oYK_Y1onU`>`3ojK3kP?oZ:oM2onW/=h00onTWm3oXYk@oj:Nd005oj:Nd0GoX9gA1_nMW=86
oi^Le0?oVYkG0onO]>L7ojG4l003oj_BmOn^hoWo[^?i00Co[^?i0_naf_D6ojk@lP;o[<W_1OnX_n/5
ojNnjR3ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`02ooooo`00>Oooool00ol0
003oooooooooo`0_ooooo`GoNkCg1?mm^?P6ojG3kP03ol;2f_o0a=go`<CM00Go`<CM00?oaKkColBm
e?o4_M@01_o4_M@00oo1^]?o`[WAol:id@05ol:id@03okJff?nl]=;o_;CB00Co_;CB00?o[KGNokBa
eOnd/MD01?nd/MD5ojRhi0;o[joG1onU^>H3oi^nl@CoYKSV1_nL_o03oi_7mPCoX;g]1_nMaO@3oio;
mP?oX[o^1_nPa_<00onW]nCoYK_YojFkj@04ojFkj@GoYL3/00?oZ:cJojR_gOnX[md01OnX[md7ojN`
gPGoY9o@1_nRW]05oj2Md@OoWIcB0onKW=@2oijZg`OoWkCW1OnUa?03oj_Nn@;o[^?i1_naf_D3ojk@
lP?oZL?/1onX_n/00onW_^[oooooooooo`0Qooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool00_ooool003[ooooo00?o0000ooooooooool0;oooool5og^dm`CoOKSh0onU`nh4oic2l`Go
`<CM0onka^<6olBme0;o`[kG1_o2^M400oo2^M;o_;CBokbddP04okbddP03okned?nd/MGo];7E00Ko
];7E00?oZ;STojn_eon_[mL01?n_[mL5ojFhiP;o[JkH1onU^>H3oibol0?oYkKT1onP_Nd3oig5m0?o
YKSW1_nR_nh2oj36l`GoYkOT1_nU^nT00onU`>coZ:cJojR/fP03ojR/fPOoZ:oM0onW/=h2ojFOd0Ko
Y9o@1_nRW]06oj2Md@?oWIcB0onOY=T6oijZg`OoWkCW00?oYLC`oj_NnOn[g_T00on[g_T3ojgRn@Go
/M[e00?oZlS_ojW3k?nY`n`01OnY`n`3ojRojbSooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`02ooooo`00>oooool00ol0003oooooooooo`0_ooooo`KoPKKg1?mh]oX6oic2l`03ol34
gOnka^?o^lKS00Go^lKS0oo4_M@5ol:ne`?o`[WA1?o2^M84okbddP?o_kG@1_nd/MD00onk/M3o[joG
ojn_e`06ojn_e`03ojFhi_n][]So[JkH00Co[JkH1OnU^>H00on/[=OoYkKTojNfi005ojNfi0GoX;g]
00?oZK3MojFhionU^>L01OnU^>L3oj:okP?oZ:oM1onW]n@3ojFkj@;oZ:SF1onX[=X5ojR_g@03ojNP
conUWm3oYIo@00CoYIo@1_nTWm06oj:Nd0?oX9gA0_nQX]H7oinTf@KoWZ[O1OnO]>L3ojSGn003oj_N
nOn]h_Wo[N;i00Go[N;i00?o/M[eoj_8kon[b>l00on[b>l5ojW3k2gooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`01ooooo`00??ooool00ol0003oooooooooo`0_ooooo`KoPKKg1Omh
]oX2oic2l`CoT/;g1onka^<00oo4_MCo`[kGol:ne`05ol:ne`03ol:idOo2^M;o`[WB00?o`[WB0onl
]=85okned0?o];7E1?nk/M06ojn_e`03okR^d?n][]So[JkH00Ko[JkH00?oYKSVojb/eon/[=L00on/
[=L7ojNfi003oj2mkOnY/=goZK3M00?oZK3M1OnU^>L00onZZ=GoZ:oMojR_g@05ojR_g@GoYkOT00?o
ZJCBojRXe_nXZ=H01?nXZ=H7ojR/fP03ojR_gOnWX<ooYj3?00?oYj3?1_nUWm05ojBOd0GoXYk@00?o
XZ;Doj6Re_nQX]H01?nQX]H6oinTf@OoWZ[O00?oWkCWojSGn?nXeoP00onXeoP2ojWSnPKo[N;i0_n/
cO46oj_8k`03ojW3k?oooooooooo02oooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`01ooooo`00?Oooool2o`00033ooooo0on1]_L3ohRimPGoLkKj1_nB`_L5ok_6h`;o/LO[1_o2_]L0
0ono`mgo`[WBol:idP05ol:idP03okbdd_no]M3o_kG@00Go_kG@00?o];7Eok^ad?nk/M001?nk/M03
ojn_e`Co^:k@1_n][]P00one[<oo[:cGojb/e`05ojb/e`GoYkKT00?o[JSCojV`gOnY/=d01OnY/=d0
0onU^>OoZZSEojZXe@03ojZXe@OoZ:oM00?oYkOTojVTd_nYY=800onYY=86ojRXePGoZ:cJ00?oZJ7>
ojNPconWX<l01OnWX<l5ojFOd0KoY9o@00?oXYk@oj:Re?nRX]@00onRX]@6oj6RePKoWjCI0onNZ]l5
ojK@mP03ojSGn?nYho[oZN?j00CoZN?j0_n]h_T6ojc=l@?oZlS_=?ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo007ooooo000oooooo`03o`000?oooooooooo02oooooo1On8^OH5og>f
nPKoT/;g00?o^lKSok77jonaan/01?naan/3ol:ne`Co_l?M1Oo2^M82ol2ke@Ko_kG@00?o_kOBok^a
d?nk/M001_nk/M000on_[mOo^:k@okR^d004okR^d0?o[JkH1?ne[<l7ojb/e`03ojNfi?n]Z=?o[JSC
00?o[JSC1OnY/=d00on_Y/ooZZSEojZXe@05ojZXe@GoZ:oM00?o[JC?ojVTd_nYY=801OnYY=86ojRX
eP03ojR/f_nYXLkoZJ7>00?oZJ7>1_nWX<l6ojFOd0?oY9o@0_nTX]<7oj:Re0GoXJ;F1OnOY=T3ojG8
lPGoY]3f0_nVh_/5ojWSnP?o[M?d1On/cO4iooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool00Oooool0043ooooo00?o0000ooooooooool0;oooool5ohRimPGoLkKj0onB`_L3ohG0nPOo
/LO[00?o`[kGoko3gOno`md00ono`md3ol:idPGo`;_E0ono]M04okngdPKo^k7@00?o_K?@okR^d?nh
[]001_nh[]000on][]So]Jc?okF/c`04okF/c`Go[:cG00?o]J[>ojfXdon]Z=<01On]Z=<00onY/=go
[jK?ojnVc`03ojnVc`OoZZSE00?oZ:oMojfTcon]Y<l00on]Y<l6ojVTdPGoZ:SF00?oZj;>ojVQc_nY
XLh01OnYXLh6ojNPc`?oYIo@0_nVXm86ojBRd`KoXZ;D1_nQX]H00onOY=WoYLSbojG8lP05ojG8lP03
ojK@m_nVh__oY^;k00CoY^;k00?oZN?jojgCm?n]do@01On]do@00on/cO7oooooooooo`0kooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool00Oooool0047ooooo00?o0000ooooooooool0
;oooool6oi:ll`GoLkKj1On5`?X5ok77j`;oWlOd1_no`md00oo2^M;o`;_Eol2ke@05ol2ke@03okne
d?no]m;o_kOB00Co_kOB0onk/M04okfcd0Ko^:k@00?o^k3?okF/cone[<l01_ne[<l00on/[=Oo]J[>
okFZcP03okFZcPGo[JSC00?o]:W>ojnVcon_Y/l01On_Y/l5ojZXe@03ok2Vc_n]Y<oo[JC?00Go[JC?
1_nYY=800onXZ=KoZj;>oj^RcP03oj^RcPKoZJ7>1OnWX<l00onXY=;oYZ?BojJSdP04ojJSdPKoY:;C
1_nRX]@3oj6ReP?oXl3^1_nUb?83oj?Oo0?oY^;k1?n[f_P3ojgCm47ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`01ooooo`00@_ooool2o`00033ooooo1_nB_?<5og>fnPGoQL3j00?o
/LO[oio7m?nOao@01?nOao@4oko3g@;o]/SX1_o0^mD00onna=oo_kOBokngdP06okngdP03ok^ad?nm
/m3o_K?@00Co_K?@0onh[]04ok^`c`Ko]Jc?00?o^Jo?okFZc_neZ/h01?neZ/h3ojfXd`Co]:W>1_n_
Y/l3ojZXe@Co/:K>1_n]Y<l5ojVTdP03ojfTc_n[X/koZj;>00GoZj;>1_nYXLh00onWX<ooZ:CBojRT
dP03ojRTdPGoYZ?B1onTX]<3oj:Re0;oY;cZ1onS`>h2ojG8lPGoXmol0_nWgOX5oj_Jn4Kooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`01ooooo`00A?ooool00ol0003oooooooooo`0^
ooooo`?oT[cc1?nJ_O45og^gn@GoNKgl1_nOao@00ono`mgo]/SXokK8j003okK8j0?o`;_E1?nna=l6
okngdP03okjmfOnm/m3o_K?@00Ko_K?@00?o^:k@ok^`conk/<l01?nk/<l3okF/c`Co^Jo?1_neZ/h0
0on]Z=?o]:W>okBYcP04okBYcPKo[jK?00?oZZSEok2Vc_n`Y/h01?n`Y/h6ojfTc`03ojVTd_n]Y<ko
[JC>00?o[JC>1_n[X/h5ojVQcP03ojZWdonXY=;oZ:CB00CoZ:CB1OnVXm86ojBRd`03ojJjionT_>[o
Y;cZ00CoY;cZ1OnS`>h4oj;Mo003oj?Oo?nWgO[oYmgj00CoYmgj00?oZm[hooooooooool0B?ooool0
0ol0003oooooooooo`07ooooo`7o00000Oooool1ooooo`00AOooool00ol0003oooooooooo`0_oooo
o`KoV[ga1Omk]oT5ogVmo0?oWlOd0on=a_/6okK8j003ol2keOnna=oo_/CO00Co_/CO0ono]m84okjm
f@Ko_K?@00?o_;WFok^`conk/<l01_nk/<l00one[<oo^Jo?okV_c`03okV_c`Go]J[>00?o]jk@okBY
c_ndZLh01OndZLh5ojnVc`03ok>Ycon`Y/ko/:K>00Go/:K>1On]Y<l00on`Z=3o[JC>ojfTcP04ojfT
cPOoZj;>00?oZJ7>ojZWdonZYm<00onZYm<5ojRTdPKoYZ?B0_nTX]<5ojJji`KoY;cZ00?oXl3^oj;M
o?nRgO`01?nRgO`2oj?Oo0GoYmgjCOooool00ol0003oooooooooo`06ooooo`7o00000Oooool1oooo
o`00A_ooool00ol0003oooooooooo`0`ooooo`;oV[ga0onP_^h6ohVjmPGoLK[l1On=a_/4okK8j0;o
X<[e1onna=l00ono]m;o_[gIokjmf@04okjmf@?o_K?@1?nl^MH6ok^`c`03ok^ge_ni[loo^Jo?00Co
^Jo?0oneZ/h4okN^d0Oo]:W>00?o[jK?ok>YconcZLl00oncZLl7ok2VcP03ojfTcon`Z=3o/:S@00?o
/:S@1On]Y<h6oj^RcP03ojbZeOnZYm?oZZOC00CoZZOC1_nXY=83ojJSdP?oYk[W1onV^^L3ojBljPGo
XM[l00?oX]gloj?Oo?nSgo`01?nSgo`00onWgO[oooooooooo`1>ooooo`03o`000?oooooooooo00Ko
oooo0Ol00001ooooo`7ooooo0017ooooo`;o0000<Oooool5oj2nkPKoRK[f1Oma^_`5ohg6n`03okK8
j?nPb_GoX<[e00?oX<[e1Onna=l2ojo;kPOo_[gI00?o_K?@okbie_nl^MH01?nl^MH3ok^`c`Co^kOF
1_ni[ll00oneZ/ko]jk@okN^d004okN^d0Go]:W>00?o][3Cok>YconcZLl01OncZLl5ok2VcP03ok:]
don`Z=3o/:S@00Co/:S@1_n]Y<h2oj^RcPGo[:[E1OnZYm<5ojRTdP;oZKgX1_nW^^L5ojJji`;oX=Wl
1_nQf_`3oikPo@?oXmolE?ooool00ol0003oooooooooo`05ooooo`7o00000Oooool1ooooo`00BOoo
ool00ol0003oooooooooo`0_ooooo`GoX;k^0on9^_H4oiNnlPGoN;Sj1Omj`_d5oj3:m@03okk4gon_
bnko[l_^00Co[l_^1Onn_MT00onfb^Wo_;WFokbieP06okbieP03ok^`conk]mKo^kOF00Co^kOF1?ni
[ll00oni^=So]jk@okN^d005okN^d0?o]:W>1?nf/=<7ok>Yc`03ok2Vc_nb[M?o/ZgC00?o/ZgC1On`
Z=05ojfTcP03ojnafOn/Z]Go[:[E00Go[:[E1_nZYm<00onXY=;oZKgXojVmj004ojVmj0KoYk[W00?o
Y[[Woj3Io?nPfO`01?nPfO`2oj7Jo0GoW^3mFOooool00ol0003oooooooooo`04ooooo`7o00000Ooo
ool1ooooo`00B_ooool00ol0003oooooooooo`0_ooooo`;oX;k^1?nU_^`6oiNnlPGoN;Sj1Omj`_d2
oj3:m@CoR<Sm1_n_bnh00onn_MWo]/[YokK:j@03okK:j@Ko_;WF00?o^<WXok^ge_nk]mH01Onk]mH3
okV_c`?o^KSH1ong[]000ondZLko][3CokJ`d`04okJ`d`Go/jW?00?o];OKok:]donb[M<01?nb[M<6
ok2Xd003ojfTc_n_/MWo[k7I00?o[k7I1on/Z]D3ojZWd`CoZ/;[1_nY_NP3ojNji`CoW]Wl0onPfO`5
oi_Po@03oikPoOoooooooooo05_ooooo00?o0000ooooooooool00oooool1o`00007ooooo0Oooool0
04_ooooo00?o0000ooooooooool0;oooool6ojFnk0?oUkkb0onO_^h6ohVlm`GoL[gm1On8b?d3ojo;
kP?oTlck1_nfb^T3okbiePCo^<WX1onk]mH00oni[loo^KSHokVhf003okVhf0Go]jk@00?o]kgNokJ`
donf/=<01Onf/=<3ok>Yc`Co];OK1Onb[M<5ok2Xd0;o/;[Q1_n_/MT5ojbZe@;oZ/[`1onZ`^/3ojVm
j0?oW=Wl1OnNfO`4oiOOoP?oVn3mH?ooool00ol0003oooooooooo`03ooooo`7o00000Oooool1oooo
o`00C?ooool2o`00033ooooo1?nU_^`2ojRojPKoWkk^1_n9_?L5og:mo@;oR<Sm1?me`oh5oi?<n`Ko
]/[Y00?o_;WFokS9j?nhbNP01?nhbNP5ok^geP03okK:jOni^=So^KSH00Go^KSH00?o]jk@okNmg_ng
_Mh00ong_Mh7okJ`d`03ok>Ycond]m_o];OK00?o];OK1_nb[M<00on`Z=3o/;[Qok2jh@04ok2jh@Ko
[k7I00?o[:[Eoj[:l?nZb_001?nZb_05oj[2j`;oVM[m1_nLfO`00onNfOcoUmonoiOOoP04oiOOoVGo
oooo00?o0000ooooooooool00oooool1o`00007ooooo001>ooooo`03o`000?oooooooooo02kooooo
00?oYKk/ojRoj_nX_nX00onX_nX6oinnkP?oRKcg1?nJ__45ogjknPGoML?n1OnCc?/3okK:j@CoVLkj
1_nhbNP00onk]mKo]/[YokK:j@03okK:j@Go^KSH0_n`cNl6okNmgPGo][3C00?o]<OXokBgfond]m/0
1Ond]m/3ok:]d`?o/<O[1on`^^43ojnaf@CoYLof1_nZb_000onZ`^_oVM[moiWJo@04oiWJo@?oW=Wl
1OnEgOh00onGgokoooooooooo`1Wooooo`03o`000?oooooooooo00;ooooo0Ol00001ooooo`00Cooo
ool00ol0003oooooooooo`0_ooooo`GoZ;oZ0onO_^h4ojFnj`KoV[ka0_mn^oX4oi>nm0GoNKkl1_mj
aol5oiW>nP?o^<WX0onJd?/6okK:j@03okVhf?n`cNoo/<g_00Co/<g_1_ng_Mh00onf/=?o]<OXokC7
j003okC7j0Go];OK0_nVd?H6ok37j`Go/;[Q0onNe?/6ojG?mP?oZ/[`1?nDfoh3oiWJo@GoU=_n0onE
gOi]ooooo`05o`000?ooooooooooooooool000000Oooool0053ooooo00?o0000ooooooooool0;ooo
ool2ojRojP?oZL7[1onU_^/3oiZnl@CoX[k]1OnC__@5ogVno0?oN/Oo1?mh`Od5ogg;o`GoV]3k0onf
b^T4oiKAo0Ko/<g_0ong_Mh4ojGAm`Go]<OX00?o];OKojK@m_nVd?H01?nVd?H6ok37j`03ok2jhOnN
e?_oW]Ck00GoW]Ck0onUcoH4ohkJo`?oU=_n1OnDeoh3oiCKoW;ooooo00Go0000oooooooooooooooo
o`000001ooooo`00DOooool2o`00033ooooo1OnY`N/5ojFnj`;oZ<3Z1onR_^d2oi>nm0?oX;k^1_n?
__H6ogS1o@GoOL_o0_nJd?/4ogg=o`KoU]7l0on`cNl4ohkCoPKoYM7g0_ndanP4oiKEo@KoY]3f0on`
an/5oiCGoP?oW]Ck1?n9fOl3ohkJo`CoUM?m1OnDeoigooooo`04o`000?ooooooooooo`00007ooooo
001Cooooo`03o`000?oooooooooo02kooooo1OnY`N/00onU_^_oZ<3ZojS0jP04ojS0jPGoX[k]00?o
YkkZoj2nk_nP_^h01?nP_^h6ohnnmP?oN<7m1?n>_oL5og[4oPGoOLgo0onFdO`4og_>o`KoS]?n0onU
dOL3ohGCo`KoU]Gm0onVd?H5ohWGo`?oU=On1?n7eOl3ohWIo`CoUlgj1_nEdod00onDeokooooooooo
o`1iooooo`03o`000?oooooo0000007ooooo001Dooooo`03o`000?oooooooooo02kooooo0_nY`N/4
ojO1k0KoZ<3Z00?oX[k]ojNnj_nW_^X00onW_^X6oj2nkP?oSkkf1?nO_nl6ohjom`;oN/Cn1?n@`OL6
ogk5oPGoNlko0on>doh4ogc>o`GoQM?o0onFeOd5oh3Bo`?oRMOo1?n<coh3ohOEo`CoVlOf1_nGcOX3
oiGCoGkooooo00?o0000ooooool000000Oooool005Gooooo00?o0000ooooooooool0;_ooool6ojO1
k0?oZ<3Z1?nX`N`5ojNnjP?oX;k^1?nV_^/6oinok`?oS[og0onO_nl6oi31m`?oO/Gn1?nF`_D5ohK5
o0?oO<ko1?n@a?T6ohG<oP?oP=;o0onBaoT5ohc?oP?oX<Gb1_nKaoH3oiO=nXCooooo0Ol00001oooo
o`7o0000001Fooooo`;o0000;oooool3ojO1k0?oYL3/1onX`N`2ojNnjPCoZL7[1_nV_^/3oinok`Co
Y[k[1OnO_nl3oi31m`CoXKo_1_nF`_D2ohK5o0CoWL;b1_n@a?T3ohG<oP?oW<Cd1_nBaoT00on<coko
X<Gboj35lP05oj35lP?oVlOfR_ooool2o`000000F?ooool00ol0003oooooooooo`0]ooooo`KoYL3/
1OnX`N`2ojK1k@KoZL7[0onV_^/3ojW1j`OoY[k[0_nO_nl4ojJnj`KoXKo_0onF`_D3oj>ok@KoWL;b
0on@a?T4oj;1k`GoW<Cd0onBaoT4oj?1k`GoX<GbSOooool3o`000000FOooool00ol0003ooooooooo
o`0]ooooo`KoYL3/00?oZ<7/ojK1kOnV`Nd01?nV`Nd4ojW1j`;oY/7/1_nY`N/5ojJnj`03ojW1jonV
_^_oY[k[00GoY[k[0onQ_nl3ojNnjPKoXko]0onM`_84ojFnj`KoX/7_0_nLa?@4ojFok0KoXl7_00?o
X<Gbooooooooool0R_ooool4o`0000?ooooo001Jooooo`03o`000?oooooooooo02gooooo0onU`>`4
ojK0k0KoY/7]00?oZL7[ojK1k?nV`N`00onV`N`6ojW1j`03ojJnjonY`N_oZL7[00?oZL7[1OnV_^/2
ojW1j`KoYkkZ1?nS_nd2ojRojPOoYKk[0onR`Nl2ojNnjPOoYKo/0onS`Nn<ooooo`?o00001oooool0
05_ooooo00?o0000ooooooooool0;_ooool6ojK0k0?oY/7]0onV`>`6ojK1k0?oZL7[1?nW`N`5ojW1
j`03ojJnjonY`N_oZL7[00CoZL7[1_nW_^X00onS_ngoZ;oZojRojP03ojRojPGoYKk[00?oZ<3[ojNn
j_nW_^X01?nW_^X5ojFok8cooooo1?l0000:ooooo`00G?ooool2o`0002oooooo0onV`>`3ojNoj`Ko
Y/3/0onV`N`4ojK0k0KoYl7/0_nY`N/4ojO1k@KoZL7[0onW_^X3ojW2k0KoZ;oZ00?oYKk[ojS0jonX
`>/00onX`>/6ojNnjP03ojFok?oooooooooo08Wooooo1?l0000>ooooo`00G_ooool00ol0003ooooo
ooooo`0]ooooo`KoYko[1?nV`>`2ojNoj`OoY/3/0onW`N`2ojK0k0OoYl7]0onY`N/3ojK1k@KoZL;/
0onX_nX4ojS2k0GoZ<3[0onW_^Z:ooooo`Co00004_ooool005oooooo00?o0000ooooooooool0;Ooo
ool6ojNoj`03ojK0k?nW_n_oYko[00?oYko[1OnV`>`2ojNoj`GoY/3/1OnW`Nd2ojK0k0KoY/7]0onY
`^`3ojK1k@OoZ<;/0_nX`>^;ooooo`Co00005_ooool0063ooooo00?o0000ooooooooool0;Oooool3
ojNoj`CoZ;oZ1OnW_n/00onV`>coYko[ojNoj`04ojNoj`GoY/3/00?oYl7]ojK0k?nV`>`01?nV`>`4
ojK1k@;oY/3/1_nV`Nd5ojS2k8_ooooo0ol0000Jooooo`00HOooool2o`0002oooooo1_nX_nX2ojNo
j`CoZ;oZ1_nW_n/2ojK0k0CoYko[1_nV`>`00onV`NgoY/3/ojK0k003ojK0k0KoY/7]00?oZ<;/oooo
ooooool0R?ooool4o`0001gooooo001Sooooo`03o`000?oooooooooo02gooooo0onX_nX2ojW0jPOo
Z;oZ0onW_n/3ojRojPKoYko[0onV`>`3ojNoj`KoY/3/0onV`Nf9ooooo`Co00008Oooool006Cooooo
00?o0000ooooooooool0;Oooool5ojW0jPGoZ;oZ0_nY_nX6ojRojP?oYko[1?nX_nX5ojNoj`?oY/3/
R_ooool4o`0002Gooooo001Uooooo`03o`000?oooooooooo02gooooo1OnY`>X00onX_n[oZKoZojVo
jP04ojVojPCoZ;oZ0_nY_nX7ojRojP;oYko[Roooool4o`0002Wooooo001Vooooo`;o0000;_ooool2
ojW0jPCoZ<7[1_nY_nX00onX_n[oZKoZojVojP03ojVojPGoZ;oZRoooool3o`0002gooooo001Xoooo
o`03o`000?oooooooooo02cooooo1_nX`N/3ojVojP?oZ<7[1_nY_nX00onX_n[oooooooooo`28oooo
o`Co0000<?ooool006Wooooo00?o0000ooooooooool0;?ooool3ojS1j`CoY/7/1OnX`N/3ojVojXWo
oooo1?l0000dooooo`00J_ooool00ol0003oooooooooo`0/ooooo`OoY/7/0_nX`N^:ooooo`Co0000
>?ooool006_ooooo0_l0000]ooooo`GoY/7/ROooool4o`0003cooooo001]ooooo`03o`000?oooooo
oooo02_ooooo00?oY/7/ooooooooool0Qoooool3o`00043ooooo001^ooooo`03o`000?oooooooooo
02[ooooo00?o0000ooooooooool0Poooool4o`0004?ooooo001_ooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool0Ooooool4o`0004Oooooo001`ooooo`;o0000:Oooool00ol0003ooooo
ooooo`1kooooo`Co0000Boooool007;ooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`1gooooo`Co0000Coooool007?ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1d
ooooo`?o0000Doooool007Cooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1`oooo
o`Co0000E_ooool007Gooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1/ooooo`Co
0000F_ooool007Kooooo0_l0000Sooooo`03o`000?oooooooooo06Sooooo1?l0001Nooooo`00N?oo
ool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo06Cooooo1?l0001Rooooo`00NOooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo067ooooo0ol0001Vooooo`00N_ooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo05gooooo1?l0001Yooooo`00Noooool2o`0001ko
oooo00?o0000ooooooooool0FOooool4o`0006gooooo001mooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool0EOooool4o`00077ooooo001nooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool0DOooool4o`0007Gooooo001oooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool0C_ooool3o`0007Wooooo0020ooooo`;o00006Oooool00ol0003oooooooooo`1:oooo
o`Co0000O?ooool008;ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`16ooooo`Co
0000P?ooool008?ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`12ooooo`Co0000
Q?ooool008Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0nooooo`Co0000R?oo
ool008Gooooo0_l0000Cooooo`03o`000?oooooooooo03cooooo0ol0002<ooooo`00Qoooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo03Sooooo1?l0002?ooooo`00R?ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo03Cooooo1?l0002Cooooo`00ROooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo033ooooo1?l0002Gooooo`00R_ooool2o`0000kooooo00?o
0000ooooooooool0;?ooool4o`0009_ooooo002<ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool0:Oooool3o`0009oooooo002=ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool09Oooool4o`000:;ooooo002>ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool08Oooool4o`000:Kooooo002?ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
7Oooool4o`000:[ooooo002@ooooo`;o00002?ooool00ol0003oooooooooo`0Iooooo`Co0000[_oo
ool009;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Fooooo`?o0000/_ooool0
09?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Booooo`Co0000]Oooool009Co
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0>ooooo`Co0000^Oooool009Gooooo
0_l00003ooooo`03o`000?oooooooooo00[ooooo1?l0002mooooo`00Uoooool01?l0003ooooooooo
ool00008ooooo`Co0000`Oooool009Sooooo00?o0000ooooool000001Oooool3o`000<Gooooo002I
ooooo`;o000000?oooooo`000?l000000_l00038ooooo`00V_ooool2o`000<cooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0538698, 0.0432538, \
0.0035044, 0.0035044}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[.12586 .2075 -12 -8.99448 ]
[.12586 .2075 0 .00552 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.56094 .0364 -5.16972 -9 ]
[.56094 .0364 .83028 0 ]
[.75679 .08071 0 -6.17777 ]
[.75679 .08071 12 2.82223 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.9429 .3657 0 -5.9083 ]
[.9429 .3657 6 3.0917 ]
[.02494 .25992 -18 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.01611 .31527 -18 -2.78472 ]
[.01611 .31527 0 6.21528 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00254 .43215 -12 -2.88407 ]
[-0.00254 .43215 0 6.11593 ]
[-0.0124 .49393 -12 -2.93688 ]
[-0.0124 .49393 0 6.06312 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
[(-2)] .12586 .2075 1 .99877 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.56863 .04703 m
.57247 .05235 L
s
[(2)] .56094 .0364 .72324 1 Mshowa
.125 Mabswid
.18558 .19702 m
.18832 .19985 L
s
.23703 .17687 m
.23971 .17975 L
s
.28951 .15632 m
.29214 .15925 L
s
.39772 .11395 m
.40023 .11699 L
s
.4535 .09211 m
.45595 .0952 L
s
.51046 .06981 m
.51284 .07294 L
s
.08568 .23614 m
.08851 .23887 L
s
.62804 .02377 m
.63027 .02701 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.7445 .0853 m
.73835 .08759 L
s
[(-2)] .75679 .08071 -1 .37284 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.93037 .36962 m
.92411 .37158 L
s
[(2)] .9429 .3657 -1 .31296 Mshowa
.125 Mabswid
.7708 .12553 m
.7671 .12688 L
s
.79613 .16428 m
.79242 .1656 L
s
.82054 .20161 m
.81682 .20291 L
s
.86679 .27235 m
.86305 .2736 L
s
.88871 .30589 m
.88497 .30711 L
s
.9099 .3383 m
.90615 .3395 L
s
.71716 .04348 m
.71349 .04489 L
s
.95018 .39992 m
.94642 .40107 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(-20)] .02494 .25992 1 -0.39157 Mshowa
.02837 .31059 m
.0345 .30825 L
s
[(-10)] .01611 .31527 1 -0.38117 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.00981 .42772 m
.01599 .4255 L
s
[(10)] -0.00254 .43215 1 -0.3591 Mshowa
0 .48963 m
.0062 .48748 L
s
[(20)] -0.0124 .49393 1 -0.34736 Mshowa
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.656 .753 .921 r
.39361 .69489 .40169 .70188 .4152 .69813 .40717 .69103 Mtetra
.659 .752 .919 r
.40717 .69103 .4152 .69813 .42878 .69429 .42079 .68706 Mtetra
.659 .749 .917 r
.42079 .68706 .42878 .69429 .44242 .69034 .43448 .68307 Mtetra
.654 .748 .919 r
.43448 .68307 .44242 .69034 .45614 .68637 .44824 .67925 Mtetra
.651 .752 .923 r
.44824 .67925 .45614 .68637 .46992 .68252 .46207 .67547 Mtetra
.654 .756 .924 r
.46207 .67547 .46992 .68252 .48378 .67874 .47597 .67157 Mtetra
.655 .754 .922 r
.47597 .67157 .48378 .67874 .4977 .6749 .48994 .66763 Mtetra
.657 .753 .921 r
.48994 .66763 .4977 .6749 .5117 .67097 .50398 .66361 Mtetra
.654 .75 .921 r
.50398 .66361 .5117 .67097 .52577 .66703 .5181 .65967 Mtetra
.644 .749 .925 r
.5181 .65967 .52577 .66703 .53991 .66299 .53229 .65605 Mtetra
.62 .754 .942 r
.53229 .65605 .53991 .66299 .55412 .65905 .54656 .65306 Mtetra
.603 .778 .964 r
.54656 .65306 .55412 .65905 .56842 .65531 .56091 .65024 Mtetra
.585 .803 .983 r
.56091 .65024 .56842 .65531 .58279 .65192 .57535 .64744 Mtetra
.566 .817 .992 r
.57535 .64744 .58279 .65192 .59725 .64866 .58988 .64471 Mtetra
.556 .832 .997 r
.58988 .64471 .59725 .64866 .61179 .64536 .6045 .64183 Mtetra
.556 .846 .998 r
.6045 .64183 .61179 .64536 .6264 .64195 .61919 .63864 Mtetra
.562 .857 .997 r
.61919 .63864 .6264 .64195 .6411 .63839 .63396 .63516 Mtetra
.572 .864 .996 r
.63396 .63516 .6411 .63839 .65587 .63463 .64881 .63139 Mtetra
.583 .868 .995 r
.64881 .63139 .65587 .63463 .67072 .63065 .66372 .62738 Mtetra
.593 .872 .993 r
.66372 .62738 .67072 .63065 .68563 .62646 .67871 .62316 Mtetra
.603 .875 .992 r
.67871 .62316 .68563 .62646 .70062 .62205 .69377 .61871 Mtetra
.614 .878 .99 r
.69377 .61871 .70062 .62205 .71567 .61741 .7089 .61401 Mtetra
.627 .882 .988 r
.7089 .61401 .71567 .61741 .73079 .61259 .72409 .60903 Mtetra
.642 .883 .985 r
.72409 .60903 .73079 .61259 .74598 .60759 .73934 .60374 Mtetra
.659 .879 .98 r
.73934 .60374 .74598 .60759 .76123 .60248 .75464 .59814 Mtetra
.672 .868 .973 r
.75464 .59814 .76123 .60248 .77656 .59733 .77 .59237 Mtetra
.676 .851 .966 r
.77 .59237 .77656 .59733 .79197 .5923 .78544 .58667 Mtetra
.681 .832 .956 r
.78544 .58667 .79197 .5923 .80749 .58763 .80096 .58097 Mtetra
.68 .802 .94 r
.80096 .58097 .80749 .58763 .82311 .58315 .81656 .57543 Mtetra
.665 .768 .926 r
.81656 .57543 .82311 .58315 .83883 .57878 .8323 .57055 Mtetra
.658 .753 .92 r
.8323 .57055 .83883 .57878 .85463 .57429 .84815 .56598 Mtetra
.655 .751 .92 r
.84815 .56598 .85463 .57429 .87051 .56979 .86411 .5615 Mtetra
.656 .753 .921 r
.86411 .5615 .87051 .56979 .88648 .56521 .88014 .55692 Mtetra
.657 .754 .922 r
.88014 .55692 .88648 .56521 .90252 .56055 .89626 .55231 Mtetra
.659 .758 .923 r
.89626 .55231 .90252 .56055 .91866 .55595 .91245 .54756 Mtetra
.658 .754 .921 r
.91245 .54756 .91866 .55595 .93491 .55149 .92874 .54284 Mtetra
.653 .747 .919 r
.92874 .54284 .93491 .55149 .95125 .54699 .94515 .53831 Mtetra
.94515 .53831 .95125 .54699 .96767 .54237 .96165 .53375 Mtetra
.656 .751 .92 r
.96165 .53375 .96767 .54237 .98417 .53766 .97822 .52906 Mtetra
.659 .752 .919 r
.38547 .68777 .39361 .69489 .40717 .69103 .39906 .68377 Mtetra
.659 .749 .917 r
.39906 .68377 .40717 .69103 .42079 .68706 .41273 .67976 Mtetra
.653 .748 .919 r
.41273 .67976 .42079 .68706 .43448 .68307 .42646 .67595 Mtetra
.651 .753 .924 r
.42646 .67595 .43448 .68307 .44824 .67925 .44026 .67216 Mtetra
.655 .756 .924 r
.44026 .67216 .44824 .67925 .46207 .67547 .45414 .66822 Mtetra
.654 .752 .922 r
.45414 .66822 .46207 .67547 .47597 .67157 .46808 .66428 Mtetra
.657 .753 .921 r
.46808 .66428 .47597 .67157 .48994 .66763 .4821 .66022 Mtetra
.647 .748 .923 r
.4821 .66022 .48994 .66763 .50398 .66361 .49619 .6565 Mtetra
.62 .749 .939 r
.49619 .6565 .50398 .66361 .5181 .65967 .51035 .65355 Mtetra
.592 .771 .965 r
.51035 .65355 .5181 .65967 .53229 .65605 .52459 .65104 Mtetra
.562 .797 .987 r
.52459 .65104 .53229 .65605 .54656 .65306 .53892 .6487 Mtetra
.53 .808 .997 r
.53892 .6487 .54656 .65306 .56091 .65024 .55334 .64658 Mtetra
.523 .829 1 r
.55334 .64658 .56091 .65024 .57535 .64744 .56785 .64409 Mtetra
.538 .845 .999 r
.56785 .64409 .57535 .64744 .58988 .64471 .58244 .64111 Mtetra
.581 .853 .995 r
.58244 .64111 .58988 .64471 .6045 .64183 .59711 .63749 Mtetra
.622 .843 .984 r
.59711 .63749 .6045 .64183 .61919 .63864 .61184 .63337 Mtetra
.642 .82 .968 r
.61184 .63337 .61919 .63864 .63396 .63516 .62665 .62908 Mtetra
.651 .798 .953 r
.62665 .62908 .63396 .63516 .64881 .63139 .64153 .62472 Mtetra
.653 .783 .943 r
.64153 .62472 .64881 .63139 .66372 .62738 .6565 .62039 Mtetra
.652 .774 .938 r
.6565 .62039 .66372 .62738 .67871 .62316 .67155 .61612 Mtetra
.649 .773 .939 r
.67155 .61612 .67871 .62316 .69377 .61871 .68668 .61192 Mtetra
.646 .781 .945 r
.68668 .61192 .69377 .61871 .7089 .61401 .7019 .60773 Mtetra
.643 .796 .956 r
.7019 .60773 .7089 .61401 .72409 .60903 .7172 .60349 Mtetra
.641 .82 .969 r
.7172 .60349 .72409 .60903 .73934 .60374 .73257 .59907 Mtetra
.645 .85 .978 r
.73257 .59907 .73934 .60374 .75464 .59814 .748 .59414 Mtetra
.657 .877 .98 r
.748 .59414 .75464 .59814 .77 .59237 .76345 .58856 Mtetra
.671 .888 .977 r
.76345 .58856 .77 .59237 .78544 .58667 .77895 .58246 Mtetra
.689 .882 .97 r
.77895 .58246 .78544 .58667 .80096 .58097 .79449 .57598 Mtetra
.69 .859 .963 r
.79449 .57598 .80096 .58097 .81656 .57543 .81011 .56971 Mtetra
.69 .837 .954 r
.81011 .56971 .81656 .57543 .8323 .57055 .82582 .56359 Mtetra
.682 .798 .937 r
.82582 .56359 .8323 .57055 .84815 .56598 .84164 .55792 Mtetra
.663 .762 .924 r
.84164 .55792 .84815 .56598 .86411 .5615 .85763 .55304 Mtetra
.654 .75 .92 r
.85763 .55304 .86411 .5615 .88014 .55692 .87373 .54851 Mtetra
.657 .753 .921 r
.87373 .54851 .88014 .55692 .89626 .55231 .88991 .54384 Mtetra
.656 .753 .921 r
.88991 .54384 .89626 .55231 .91245 .54756 .90619 .53917 Mtetra
.659 .757 .922 r
.90619 .53917 .91245 .54756 .92874 .54284 .92254 .53435 Mtetra
.658 .755 .922 r
.92254 .53435 .92874 .54284 .94515 .53831 .93898 .52954 Mtetra
.653 .747 .919 r
.93898 .52954 .94515 .53831 .96165 .53375 .95555 .52493 Mtetra
.95555 .52493 .96165 .53375 .97822 .52906 .97221 .5203 Mtetra
.66 .75 .917 r
.37724 .68049 .38547 .68777 .39906 .68377 .39089 .67645 Mtetra
.653 .748 .919 r
.39089 .67645 .39906 .68377 .41273 .67976 .40459 .67262 Mtetra
.651 .753 .924 r
.40459 .67262 .41273 .67976 .42646 .67595 .41836 .66881 Mtetra
.655 .755 .924 r
.41836 .66881 .42646 .67595 .44026 .67216 .43221 .66486 Mtetra
.655 .752 .921 r
.43221 .66486 .44026 .67216 .45414 .66822 .44613 .66087 Mtetra
.44613 .66087 .45414 .66822 .46808 .66428 .46012 .65687 Mtetra
.637 .746 .927 r
.46012 .65687 .46808 .66428 .4821 .66022 .47418 .65345 Mtetra
.598 .753 .952 r
.47418 .65345 .4821 .66022 .49619 .6565 .4883 .651 Mtetra
.562 .781 .981 r
.4883 .651 .49619 .6565 .51035 .65355 .50251 .6489 Mtetra
.514 .792 .996 r
.50251 .6489 .51035 .65355 .52459 .65104 .5168 .64721 Mtetra
.504 .816 1 r
.5168 .64721 .52459 .65104 .53892 .6487 .53119 .64515 Mtetra
.543 .84 .999 r
.53119 .64515 .53892 .6487 .55334 .64658 .54567 .64223 Mtetra
.623 .841 .983 r
.54567 .64223 .55334 .64658 .56785 .64409 .56023 .63814 Mtetra
.662 .802 .95 r
.56023 .63814 .56785 .64409 .58244 .64111 .57485 .63349 Mtetra
.676 .76 .914 r
.57485 .63349 .58244 .64111 .59711 .63749 .58954 .6285 Mtetra
.679 .729 .888 r
.58954 .6285 .59711 .63749 .61184 .63337 .6043 .62333 Mtetra
.679 .708 .869 r
.6043 .62333 .61184 .63337 .62665 .62908 .61912 .61801 Mtetra
.671 .686 .856 r
.61912 .61801 .62665 .62908 .64153 .62472 .63403 .61296 Mtetra
.662 .672 .849 r
.63403 .61296 .64153 .62472 .6565 .62039 .64902 .60826 Mtetra
.654 .663 .846 r
.64902 .60826 .6565 .62039 .67155 .61612 .6641 .60394 Mtetra
.646 .66 .849 r
.6641 .60394 .67155 .61612 .68668 .61192 .67929 .60001 Mtetra
.639 .662 .856 r
.67929 .60001 .68668 .61192 .7019 .60773 .69458 .59643 Mtetra
.632 .671 .869 r
.69458 .59643 .7019 .60773 .7172 .60349 .70997 .59313 Mtetra
.635 .691 .885 r
.70997 .59313 .7172 .60349 .73257 .59907 .72545 .58968 Mtetra
.637 .714 .903 r
.72545 .58968 .73257 .59907 .748 .59414 .74101 .58605 Mtetra
.642 .749 .927 r
.74101 .58605 .748 .59414 .76345 .58856 .75665 .58209 Mtetra
.648 .799 .955 r
.75665 .58209 .76345 .58856 .77895 .58246 .77233 .57755 Mtetra
.671 .856 .97 r
.77233 .57755 .77895 .58246 .79449 .57598 .78801 .5718 Mtetra
.69 .886 .97 r
.78801 .5718 .79449 .57598 .81011 .56971 .80369 .56517 Mtetra
.706 .881 .962 r
.80369 .56517 .81011 .56971 .82582 .56359 .8194 .55813 Mtetra
.7 .852 .955 r
.8194 .55813 .82582 .56359 .84164 .55792 .83522 .55151 Mtetra
.694 .822 .944 r
.83522 .55151 .84164 .55792 .85763 .55304 .85115 .54523 Mtetra
.671 .775 .928 r
.85115 .54523 .85763 .55304 .87373 .54851 .86725 .53995 Mtetra
.656 .751 .92 r
.86725 .53995 .87373 .54851 .88991 .54384 .8835 .53526 Mtetra
.656 .752 .92 r
.8835 .53526 .88991 .54384 .90619 .53917 .89985 .53056 Mtetra
.656 .752 .921 r
.89985 .53056 .90619 .53917 .92254 .53435 .91628 .52581 Mtetra
.659 .757 .922 r
.91628 .52581 .92254 .53435 .93898 .52954 .93279 .52091 Mtetra
.658 .755 .922 r
.93279 .52091 .93898 .52954 .95555 .52493 .94939 .51602 Mtetra
.653 .747 .919 r
.94939 .51602 .95555 .52493 .97221 .5203 .96612 .51135 Mtetra
.654 .748 .919 r
.36895 .67313 .37724 .68049 .39089 .67645 .38262 .66925 Mtetra
.651 .752 .924 r
.38262 .66925 .39089 .67645 .40459 .67262 .39637 .66544 Mtetra
.655 .755 .924 r
.39637 .66544 .40459 .67262 .41836 .66881 .41019 .66147 Mtetra
.656 .752 .921 r
.41019 .66147 .41836 .66881 .43221 .66486 .42408 .65746 Mtetra
.654 .751 .921 r
.42408 .65746 .43221 .66486 .44613 .66087 .43805 .65349 Mtetra
.627 .745 .932 r
.43805 .65349 .44613 .66087 .46012 .65687 .45207 .65036 Mtetra
.581 .756 .961 r
.45207 .65036 .46012 .65687 .47418 .65345 .46615 .64822 Mtetra
.528 .779 .989 r
.46615 .64822 .47418 .65345 .4883 .651 .48031 .64661 Mtetra
.489 .792 .998 r
.48031 .64661 .4883 .651 .50251 .6489 .49457 .64514 Mtetra
.517 .824 1 r
.49457 .64514 .50251 .6489 .5168 .64721 .50893 .64281 Mtetra
.624 .839 .982 r
.50893 .64281 .5168 .64721 .53119 .64515 .52338 .63874 Mtetra
.676 .792 .936 r
.52338 .63874 .53119 .64515 .54567 .64223 .5379 .6337 Mtetra
.695 .743 .888 r
.5379 .6337 .54567 .64223 .56023 .63814 .55249 .62785 Mtetra
.702 .709 .854 r
.55249 .62785 .56023 .63814 .57485 .63349 .56713 .62131 Mtetra
.691 .674 .829 r
.56713 .62131 .57485 .63349 .58954 .6285 .58183 .61487 Mtetra
.68 .65 .814 r
.58183 .61487 .58954 .6285 .6043 .62333 .5966 .60878 Mtetra
.67 .635 .806 r
.5966 .60878 .6043 .62333 .61912 .61801 .61144 .60312 Mtetra
.661 .627 .805 r
.61144 .60312 .61912 .61801 .63403 .61296 .62637 .59794 Mtetra
.654 .623 .806 r
.62637 .59794 .63403 .61296 .64902 .60826 .64139 .59322 Mtetra
.648 .62 .809 r
.64139 .59322 .64902 .60826 .6641 .60394 .65649 .58885 Mtetra
.642 .618 .81 r
.65649 .58885 .6641 .60394 .67929 .60001 .6717 .58483 Mtetra
.634 .613 .812 r
.6717 .58483 .67929 .60001 .69458 .59643 .68701 .58128 Mtetra
.625 .61 .815 r
.68701 .58128 .69458 .59643 .70997 .59313 .70244 .57821 Mtetra
.617 .61 .821 r
.70244 .57821 .70997 .59313 .72545 .58968 .718 .57559 Mtetra
.61 .618 .835 r
.718 .57559 .72545 .58968 .74101 .58605 .73368 .57333 Mtetra
.606 .638 .856 r
.73368 .57333 .74101 .58605 .75665 .58209 .74947 .57119 Mtetra
.618 .678 .884 r
.74947 .57119 .75665 .58209 .77233 .57755 .76533 .56835 Mtetra
.634 .723 .912 r
.76533 .56835 .77233 .57755 .78801 .5718 .78123 .56469 Mtetra
.652 .786 .946 r
.78123 .56469 .78801 .5718 .80369 .56517 .79714 .56003 Mtetra
.691 .86 .963 r
.79714 .56003 .80369 .56517 .8194 .55813 .813 .55359 Mtetra
.712 .885 .961 r
.813 .55359 .8194 .55813 .83522 .55151 .82884 .54623 Mtetra
.712 .864 .954 r
.82884 .54623 .83522 .55151 .85115 .54523 .84476 .53901 Mtetra
.702 .834 .946 r
.84476 .53901 .85115 .54523 .86725 .53995 .86081 .53231 Mtetra
.678 .786 .931 r
.86081 .53231 .86725 .53995 .8835 .53526 .87703 .52664 Mtetra
.658 .754 .921 r
.87703 .52664 .8835 .53526 .89985 .53056 .89343 .52182 Mtetra
.656 .751 .92 r
.89343 .52182 .89985 .53056 .91628 .52581 .90993 .51705 Mtetra
.656 .752 .921 r
.90993 .51705 .91628 .52581 .93279 .52091 .92653 .51223 Mtetra
.66 .757 .922 r
.92653 .51223 .93279 .52091 .94939 .51602 .9432 .50723 Mtetra
.657 .754 .921 r
.9432 .50723 .94939 .51602 .96612 .51135 .95997 .5023 Mtetra
.65 .751 .923 r
.36056 .66586 .36895 .67313 .38262 .66925 .37428 .66204 Mtetra
.654 .755 .924 r
.37428 .66204 .38262 .66925 .39637 .66544 .38807 .65808 Mtetra
.655 .752 .921 r
.38807 .65808 .39637 .66544 .41019 .66147 .40194 .65405 Mtetra
.654 .751 .921 r
.40194 .65405 .41019 .66147 .42408 .65746 .41588 .65006 Mtetra
.623 .744 .934 r
.41588 .65006 .42408 .65746 .43805 .65349 .42986 .64703 Mtetra
.569 .755 .965 r
.42986 .64703 .43805 .65349 .45207 .65036 .4439 .64511 Mtetra
.505 .771 .991 r
.4439 .64511 .45207 .65036 .46615 .64822 .45801 .64387 Mtetra
.48 .79 .999 r
.45801 .64387 .46615 .64822 .48031 .64661 .47223 .64248 Mtetra
.567 .831 .995 r
.47223 .64248 .48031 .64661 .49457 .64514 .48656 .63947 Mtetra
.667 .811 .952 r
.48656 .63947 .49457 .64514 .50893 .64281 .50099 .63465 Mtetra
.702 .753 .891 r
.50099 .63465 .50893 .64281 .52338 .63874 .51549 .6285 Mtetra
.716 .714 .847 r
.51549 .6285 .52338 .63874 .5379 .6337 .53005 .6211 Mtetra
.704 .673 .817 r
.53005 .6211 .5379 .6337 .55249 .62785 .54466 .61371 Mtetra
.689 .647 .803 r
.54466 .61371 .55249 .62785 .56713 .62131 .55933 .60685 Mtetra
.676 .638 .805 r
.55933 .60685 .56713 .62131 .58183 .61487 .57407 .60083 Mtetra
.669 .641 .813 r
.57407 .60083 .58183 .61487 .5966 .60878 .58888 .59531 Mtetra
.664 .647 .823 r
.58888 .59531 .5966 .60878 .61144 .60312 .60377 .5902 Mtetra
.66 .654 .833 r
.60377 .5902 .61144 .60312 .62637 .59794 .61874 .5854 Mtetra
.657 .659 .841 r
.61874 .5854 .62637 .59794 .64139 .59322 .6338 .58081 Mtetra
.654 .661 .845 r
.6338 .58081 .64139 .59322 .65649 .58885 .64894 .57639 Mtetra
.65 .659 .846 r
.64894 .57639 .65649 .58885 .6717 .58483 .66417 .57214 Mtetra
.645 .654 .845 r
.66417 .57214 .6717 .58483 .68701 .58128 .6795 .56811 Mtetra
.638 .645 .84 r
.6795 .56811 .68701 .58128 .70244 .57821 .69493 .56439 Mtetra
.629 .632 .834 r
.69493 .56439 .70244 .57821 .718 .57559 .71048 .56108 Mtetra
.619 .618 .828 r
.71048 .56108 .718 .57559 .73368 .57333 .72616 .55829 Mtetra
.603 .604 .825 r
.72616 .55829 .73368 .57333 .74947 .57119 .74199 .55636 Mtetra
.591 .602 .831 r
.74199 .55636 .74947 .57119 .76533 .56835 .75798 .555 Mtetra
.588 .622 .854 r
.75798 .555 .76533 .56835 .78123 .56469 .77409 .55365 Mtetra
.611 .676 .887 r
.77409 .55365 .78123 .56469 .79714 .56003 .79022 .55103 Mtetra
.639 .734 .917 r
.79022 .55103 .79714 .56003 .813 .55359 .80635 .54706 Mtetra
.68 .817 .949 r
.80635 .54706 .813 .55359 .82884 .54623 .82241 .54122 Mtetra
.717 .876 .955 r
.82241 .54122 .82884 .54623 .84476 .53901 .83839 .53368 Mtetra
.723 .869 .95 r
.83839 .53368 .84476 .53901 .86081 .53231 .85443 .52597 Mtetra
.708 .836 .943 r
.85443 .52597 .86081 .53231 .87703 .52664 .8706 .51895 Mtetra
.681 .79 .932 r
.8706 .51895 .87703 .52664 .89343 .52182 .88696 .51307 Mtetra
.657 .754 .921 r
.88696 .51307 .89343 .52182 .90993 .51705 .90352 .50819 Mtetra
.656 .752 .92 r
.90352 .50819 .90993 .51705 .92653 .51223 .92019 .50333 Mtetra
.657 .753 .92 r
.92019 .50333 .92653 .51223 .9432 .50723 .93694 .4984 Mtetra
.66 .757 .922 r
.93694 .4984 .9432 .50723 .95997 .5023 .95377 .49332 Mtetra
.653 .754 .924 r
.35209 .6586 .36056 .66586 .37428 .66204 .36586 .65466 Mtetra
.654 .752 .922 r
.36586 .65466 .37428 .66204 .38807 .65808 .3797 .65065 Mtetra
.656 .752 .921 r
.3797 .65065 .38807 .65808 .40194 .65405 .39361 .64658 Mtetra
.626 .744 .932 r
.39361 .64658 .40194 .65405 .41588 .65006 .40756 .64345 Mtetra
.566 .75 .964 r
.40756 .64345 .41588 .65006 .42986 .64703 .42155 .64164 Mtetra
.494 .763 .991 r
.42155 .64164 .42986 .64703 .4439 .64511 .43562 .64063 Mtetra
.477 .785 .998 r
.43562 .64063 .4439 .64511 .45801 .64387 .44978 .63935 Mtetra
.599 .828 .987 r
.44978 .63935 .45801 .64387 .47223 .64248 .46409 .6359 Mtetra
.688 .789 .927 r
.46409 .6359 .47223 .64248 .48656 .63947 .4785 .63044 Mtetra
.723 .739 .864 r
.4785 .63044 .48656 .63947 .50099 .63465 .493 .62303 Mtetra
.721 .693 .823 r
.493 .62303 .50099 .63465 .51549 .6285 .50755 .61482 Mtetra
.702 .658 .803 r
.50755 .61482 .51549 .6285 .53005 .6211 .52215 .60715 Mtetra
.685 .649 .807 r
.52215 .60715 .53005 .6211 .54466 .61371 .53679 .60058 Mtetra
.677 .657 .823 r
.53679 .60058 .54466 .61371 .55933 .60685 .5515 .59478 Mtetra
.667 .67 .843 r
.5515 .59478 .55933 .60685 .57407 .60083 .56629 .58973 Mtetra
.655 .683 .864 r
.56629 .58973 .57407 .60083 .58888 .59531 .58116 .58541 Mtetra
.652 .706 .887 r
.58116 .58541 .58888 .59531 .60377 .5902 .59612 .58122 Mtetra
.652 .728 .904 r
.59612 .58122 .60377 .5902 .61874 .5854 .61116 .57701 Mtetra
.654 .744 .916 r
.61116 .57701 .61874 .5854 .6338 .58081 .62628 .57269 Mtetra
.656 .752 .921 r
.62628 .57269 .6338 .58081 .64894 .57639 .64148 .56823 Mtetra
.659 .753 .92 r
.64148 .56823 .64894 .57639 .66417 .57214 .65676 .56362 Mtetra
.662 .746 .913 r
.65676 .56362 .66417 .57214 .6795 .56811 .67211 .5589 Mtetra
.662 .731 .901 r
.67211 .5589 .6795 .56811 .69493 .56439 .68755 .55416 Mtetra
.658 .708 .885 r
.68755 .55416 .69493 .56439 .71048 .56108 .70308 .54955 Mtetra
.641 .677 .869 r
.70308 .54955 .71048 .56108 .72616 .55829 .71874 .54567 Mtetra
.624 .651 .856 r
.71874 .54567 .72616 .55829 .74199 .55636 .73454 .54256 Mtetra
.608 .626 .843 r
.73454 .54256 .74199 .55636 .75798 .555 .75049 .54025 Mtetra
.586 .602 .835 r
.75049 .54025 .75798 .555 .77409 .55365 .76664 .53907 Mtetra
.573 .599 .841 r
.76664 .53907 .77409 .55365 .79022 .55103 .78296 .53846 Mtetra
.585 .637 .869 r
.78296 .53846 .79022 .55103 .80635 .54706 .79934 .53705 Mtetra
.625 .708 .905 r
.79934 .53705 .80635 .54706 .82241 .54122 .81568 .53364 Mtetra
.671 .788 .936 r
.81568 .53364 .82241 .54122 .83839 .53368 .83193 .52816 Mtetra
.723 .865 .948 r
.83193 .52816 .83839 .53368 .85443 .52597 .84805 .52041 Mtetra
.73 .867 .945 r
.84805 .52041 .85443 .52597 .8706 .51895 .86421 .51235 Mtetra
.712 .833 .94 r
.86421 .51235 .8706 .51895 .88696 .51307 .88052 .50511 Mtetra
.679 .786 .93 r
.88052 .50511 .88696 .51307 .90352 .50819 .89705 .49924 Mtetra
.656 .752 .921 r
.89705 .49924 .90352 .50819 .92019 .50333 .91378 .49435 Mtetra
.657 .753 .921 r
.91378 .49435 .92019 .50333 .93694 .4984 .93061 .48938 Mtetra
.658 .753 .92 r
.93061 .48938 .93694 .4984 .95377 .49332 .94752 .48433 Mtetra
.655 .753 .922 r
.34355 .65122 .35209 .6586 .36586 .65466 .35736 .64719 Mtetra
.657 .752 .92 r
.35736 .64719 .36586 .65466 .3797 .65065 .37124 .64307 Mtetra
.636 .745 .927 r
.37124 .64307 .3797 .65065 .39361 .64658 .38517 .63963 Mtetra
.57 .743 .958 r
.38517 .63963 .39361 .64658 .40756 .64345 .39912 .63778 Mtetra
.495 .756 .988 r
.39912 .63778 .40756 .64345 .42155 .64164 .41313 .63687 Mtetra
.47 .775 .997 r
.41313 .63687 .42155 .64164 .43562 .64063 .42725 .63582 Mtetra
.606 .822 .983 r
.42725 .63582 .43562 .64063 .44978 .63935 .44152 .63231 Mtetra
.698 .78 .915 r
.44152 .63231 .44978 .63935 .46409 .6359 .45592 .62645 Mtetra
.735 .734 .85 r
.45592 .62645 .46409 .6359 .4785 .63044 .47042 .61817 Mtetra
.724 .685 .812 r
.47042 .61817 .4785 .63044 .493 .62303 .48498 .6094 Mtetra
.701 .659 .805 r
.48498 .6094 .493 .62303 .50755 .61482 .49956 .60184 Mtetra
.687 .663 .821 r
.49956 .60184 .50755 .61482 .52215 .60715 .51418 .59545 Mtetra
.668 .676 .848 r
.51418 .59545 .52215 .60715 .53679 .60058 .52887 .59039 Mtetra
.649 .698 .882 r
.52887 .59039 .53679 .60058 .5515 .59478 .54364 .58638 Mtetra
.639 .736 .919 r
.54364 .58638 .5515 .59478 .56629 .58973 .55849 .58264 Mtetra
.633 .77 .946 r
.55849 .58264 .56629 .58973 .58116 .58541 .57343 .57887 Mtetra
.637 .788 .955 r
.57343 .57887 .58116 .58541 .59612 .58122 .58845 .57484 Mtetra
.639 .795 .957 r
.58845 .57484 .59612 .58122 .61116 .57701 .60356 .57066 Mtetra
.643 .798 .957 r
.60356 .57066 .61116 .57701 .62628 .57269 .61874 .56631 Mtetra
.648 .8 .956 r
.61874 .56631 .62628 .57269 .64148 .56823 .634 .5618 Mtetra
.652 .801 .954 r
.634 .5618 .64148 .56823 .65676 .56362 .64934 .55714 Mtetra
.657 .802 .953 r
.64934 .55714 .65676 .56362 .67211 .5589 .66476 .5523 Mtetra
.661 .801 .95 r
.66476 .5523 .67211 .5589 .68755 .55416 .68026 .54732 Mtetra
.669 .798 .944 r
.68026 .54732 .68755 .55416 .70308 .54955 .69582 .54206 Mtetra
.671 .782 .932 r
.69582 .54206 .70308 .54955 .71874 .54567 .71147 .53677 Mtetra
.666 .745 .91 r
.71147 .53677 .71874 .54567 .73454 .54256 .72721 .53175 Mtetra
.641 .694 .884 r
.72721 .53175 .73454 .54256 .75049 .54025 .74311 .52779 Mtetra
.611 .651 .866 r
.74311 .52779 .75049 .54025 .76664 .53907 .7592 .5252 Mtetra
.586 .617 .85 r
.7592 .5252 .76664 .53907 .78296 .53846 .77549 .52382 Mtetra
.561 .594 .844 r
.77549 .52382 .78296 .53846 .79934 .53705 .79201 .5237 Mtetra
.566 .617 .863 r
.79201 .5237 .79934 .53705 .81568 .53364 .80863 .52311 Mtetra
.616 .696 .9 r
.80863 .52311 .81568 .53364 .83193 .52816 .82516 .52002 Mtetra
.671 .776 .929 r
.82516 .52002 .83193 .52816 .84805 .52041 .84157 .5145 Mtetra
.731 .859 .942 r
.84157 .5145 .84805 .52041 .86421 .51235 .85782 .5064 Mtetra
.734 .861 .94 r
.85782 .5064 .86421 .51235 .88052 .50511 .87411 .49814 Mtetra
.712 .826 .936 r
.87411 .49814 .88052 .50511 .89705 .49924 .89057 .49083 Mtetra
.672 .775 .927 r
.89057 .49083 .89705 .49924 .91378 .49435 .9073 .48518 Mtetra
.655 .75 .919 r
.9073 .48518 .91378 .49435 .93061 .48938 .9242 .48024 Mtetra
.657 .752 .921 r
.9242 .48024 .93061 .48938 .94752 .48433 .9412 .47519 Mtetra
.656 .752 .92 r
.33492 .64371 .34355 .65122 .35736 .64719 .34878 .63959 Mtetra
.647 .748 .923 r
.34878 .63959 .35736 .64719 .37124 .64307 .36269 .63576 Mtetra
.587 .74 .949 r
.36269 .63576 .37124 .64307 .38517 .63963 .37661 .6336 Mtetra
.508 .751 .983 r
.37661 .6336 .38517 .63963 .39912 .63778 .39057 .6326 Mtetra
.46 .759 .994 r
.39057 .6326 .39912 .63778 .41313 .63687 .40462 .63191 Mtetra
.59 .813 .985 r
.40462 .63191 .41313 .63687 .42725 .63582 .41885 .6288 Mtetra
.699 .781 .915 r
.41885 .6288 .42725 .63582 .44152 .63231 .43323 .62288 Mtetra
.741 .736 .846 r
.43323 .62288 .44152 .63231 .45592 .62645 .44775 .61413 Mtetra
.73 .686 .808 r
.44775 .61413 .45592 .62645 .47042 .61817 .4623 .60491 Mtetra
.703 .665 .81 r
.4623 .60491 .47042 .61817 .48498 .6094 .47688 .59731 Mtetra
.687 .677 .835 r
.47688 .59731 .48498 .6094 .49956 .60184 .49148 .59111 Mtetra
.651 .688 .872 r
.49148 .59111 .49956 .60184 .51418 .59545 .50614 .58696 Mtetra
.632 .732 .92 r
.50614 .58696 .51418 .59545 .52887 .59039 .52088 .58347 Mtetra
.624 .772 .951 r
.52088 .58347 .52887 .59039 .54364 .58638 .53571 .57995 Mtetra
.626 .788 .96 r
.53571 .57995 .54364 .58638 .55849 .58264 .55062 .57621 Mtetra
.631 .791 .959 r
.55062 .57621 .55849 .58264 .57343 .57887 .56561 .57227 Mtetra
.638 .789 .954 r
.56561 .57227 .57343 .57887 .58845 .57484 .58069 .56815 Mtetra
.645 .79 .951 r
.58069 .56815 .58845 .57484 .60356 .57066 .59586 .5638 Mtetra
.65 .787 .948 r
.59586 .5638 .60356 .57066 .61874 .56631 .6111 .55931 Mtetra
.651 .785 .946 r
.6111 .55931 .61874 .56631 .634 .5618 .62643 .55476 Mtetra
.653 .786 .945 r
.62643 .55476 .634 .5618 .64934 .55714 .64183 .55015 Mtetra
.655 .789 .946 r
.64183 .55015 .64934 .55714 .66476 .5523 .65732 .5454 Mtetra
.661 .795 .946 r
.65732 .5454 .66476 .5523 .68026 .54732 .67289 .54042 Mtetra
.666 .797 .945 r
.67289 .54042 .68026 .54732 .69582 .54206 .68853 .53524 Mtetra
.67 .802 .946 r
.68853 .53524 .69582 .54206 .71147 .53677 .70424 .52987 Mtetra
.676 .803 .943 r
.70424 .52987 .71147 .53677 .72721 .53175 .72002 .52426 Mtetra
.678 .789 .933 r
.72002 .52426 .72721 .53175 .74311 .52779 .73588 .51861 Mtetra
.662 .742 .909 r
.73588 .51861 .74311 .52779 .7592 .5252 .75187 .51363 Mtetra
.614 .672 .882 r
.75187 .51363 .7592 .5252 .77549 .52382 .7681 .51075 Mtetra
.583 .631 .865 r
.7681 .51075 .77549 .52382 .79201 .5237 .78455 .50933 Mtetra
.549 .594 .851 r
.78455 .50933 .79201 .5237 .80863 .52311 .80128 .50958 Mtetra
.556 .612 .864 r
.80128 .50958 .80863 .52311 .82516 .52002 .81811 .50938 Mtetra
.615 .696 .902 r
.81811 .50938 .82516 .52002 .84157 .5145 .83481 .50626 Mtetra
.682 .781 .926 r
.83481 .50626 .84157 .5145 .85782 .5064 .85134 .50023 Mtetra
.74 .858 .935 r
.85134 .50023 .85782 .5064 .87411 .49814 .86769 .49164 Mtetra
.733 .849 .935 r
.86769 .49164 .87411 .49814 .89057 .49083 .88414 .48337 Mtetra
.704 .814 .933 r
.88414 .48337 .89057 .49083 .9073 .48518 .90079 .47628 Mtetra
.663 .762 .924 r
.90079 .47628 .9073 .48518 .9242 .48024 .91772 .47093 Mtetra
.655 .75 .92 r
.91772 .47093 .9242 .48024 .9412 .47519 .93479 .46589 Mtetra
.655 .752 .921 r
.32621 .63615 .33492 .64371 .34878 .63959 .34011 .63202 Mtetra
.613 .742 .937 r
.34011 .63202 .34878 .63959 .36269 .63576 .35402 .62918 Mtetra
.535 .745 .972 r
.35402 .62918 .36269 .63576 .37661 .6336 .36794 .62788 Mtetra
.456 .741 .99 r
.36794 .62788 .37661 .6336 .39057 .6326 .38192 .62752 Mtetra
.547 .797 .991 r
.38192 .62752 .39057 .6326 .40462 .63191 .39607 .62528 Mtetra
.69 .79 .927 r
.39607 .62528 .40462 .63191 .41885 .6288 .41043 .6197 Mtetra
.744 .743 .851 r
.41043 .6197 .41885 .6288 .43323 .62288 .42495 .61095 Mtetra
.738 .695 .81 r
.42495 .61095 .43323 .62288 .44775 .61413 .43952 .60127 Mtetra
.709 .673 .813 r
.43952 .60127 .44775 .61413 .4623 .60491 .45409 .59338 Mtetra
.686 .686 .844 r
.45409 .59338 .4623 .60491 .47688 .59731 .46868 .58737 Mtetra
.643 .702 .89 r
.46868 .58737 .47688 .59731 .49148 .59111 .4833 .58358 Mtetra
.618 .753 .942 r
.4833 .58358 .49148 .59111 .50614 .58696 .49801 .58036 Mtetra
.618 .781 .959 r
.49801 .58036 .50614 .58696 .52088 .58347 .5128 .57689 Mtetra
.625 .784 .958 r
.5128 .57689 .52088 .58347 .53571 .57995 .52768 .5732 Mtetra
.64 .785 .951 r
.52768 .5732 .53571 .57995 .55062 .57621 .54265 .56907 Mtetra
.65 .778 .942 r
.54265 .56907 .55062 .57621 .56561 .57227 .5577 .56467 Mtetra
.653 .768 .933 r
.5577 .56467 .56561 .57227 .58069 .56815 .57283 .56019 Mtetra
.655 .76 .927 r
.57283 .56019 .58069 .56815 .59586 .5638 .58805 .55566 Mtetra
.655 .757 .925 r
.58805 .55566 .59586 .5638 .6111 .55931 .60335 .5511 Mtetra
.656 .756 .924 r
.60335 .5511 .6111 .55931 .62643 .55476 .61873 .5465 Mtetra
.61873 .5465 .62643 .55476 .64183 .55015 .6342 .54187 Mtetra
.656 .757 .924 r
.6342 .54187 .64183 .55015 .65732 .5454 .64975 .53721 Mtetra
.656 .761 .927 r
.64975 .53721 .65732 .5454 .67289 .54042 .66539 .53249 Mtetra
.657 .769 .932 r
.66539 .53249 .67289 .54042 .68853 .53524 .68112 .52769 Mtetra
.662 .782 .938 r
.68112 .52769 .68853 .53524 .70424 .52987 .69691 .52262 Mtetra
.673 .795 .94 r
.69691 .52262 .70424 .52987 .72002 .52426 .71277 .5171 Mtetra
.678 .8 .94 r
.71277 .5171 .72002 .52426 .73588 .51861 .7287 .51135 Mtetra
.685 .801 .937 r
.7287 .51135 .73588 .51861 .75187 .51363 .74469 .50532 Mtetra
.671 .77 .925 r
.74469 .50532 .75187 .51363 .7681 .51075 .76081 .49988 Mtetra
.618 .69 .895 r
.76081 .49988 .7681 .51075 .78455 .50933 .77718 .49671 Mtetra
.575 .638 .876 r
.77718 .49671 .78455 .50933 .80128 .50958 .79383 .49549 Mtetra
.536 .594 .859 r
.79383 .49549 .80128 .50958 .81811 .50938 .81077 .49614 Mtetra
.554 .618 .871 r
.81077 .49614 .81811 .50938 .83481 .50626 .82777 .49586 Mtetra
.623 .708 .906 r
.82777 .49586 .83481 .50626 .85134 .50023 .84461 .49229 Mtetra
.704 .801 .925 r
.84461 .49229 .85134 .50023 .86769 .49164 .86121 .48524 Mtetra
.749 .857 .93 r
.86121 .48524 .86769 .49164 .88414 .48337 .87767 .4762 Mtetra
.726 .832 .93 r
.87767 .4762 .88414 .48337 .90079 .47628 .8943 .46813 Mtetra
.688 .794 .93 r
.8943 .46813 .90079 .47628 .91772 .47093 .91119 .46164 Mtetra
.656 .753 .922 r
.91119 .46164 .91772 .47093 .93479 .46589 .92833 .45651 Mtetra
.642 .746 .925 r
.31742 .62841 .32621 .63615 .34011 .63202 .33134 .6247 Mtetra
.564 .735 .956 r
.33134 .6247 .34011 .63202 .35402 .62918 .34523 .623 Mtetra
.476 .737 .984 r
.34523 .623 .35402 .62918 .36794 .62788 .35915 .62252 Mtetra
.482 .765 .993 r
.35915 .62252 .36794 .62788 .38192 .62752 .37321 .62151 Mtetra
.664 .803 .949 r
.37321 .62151 .38192 .62752 .39607 .62528 .38751 .61676 Mtetra
.738 .755 .866 r
.38751 .61676 .39607 .62528 .41043 .6197 .40201 .60859 Mtetra
.748 .71 .816 r
.40201 .60859 .41043 .6197 .42495 .61095 .41661 .59847 Mtetra
.719 .683 .814 r
.41661 .59847 .42495 .61095 .43952 .60127 .43119 .58996 Mtetra
.692 .693 .846 r
.43119 .58996 .43952 .60127 .45409 .59338 .44577 .58366 Mtetra
.639 .707 .896 r
.44577 .58366 .45409 .59338 .46868 .58737 .46036 .57998 Mtetra
.611 .756 .948 r
.46036 .57998 .46868 .58737 .4833 .58358 .47503 .57689 Mtetra
.614 .778 .959 r
.47503 .57689 .4833 .58358 .49801 .58036 .48979 .57352 Mtetra
.63 .779 .953 r
.48979 .57352 .49801 .58036 .5128 .57689 .50464 .56972 Mtetra
.648 .777 .942 r
.50464 .56972 .5128 .57689 .52768 .5732 .51958 .56538 Mtetra
.654 .762 .929 r
.51958 .56538 .52768 .5732 .54265 .56907 .5346 .56091 Mtetra
.651 .754 .925 r
.5346 .56091 .54265 .56907 .5577 .56467 .5497 .55652 Mtetra
.651 .755 .926 r
.5497 .55652 .5577 .56467 .57283 .56019 .56489 .55212 Mtetra
.652 .759 .928 r
.56489 .55212 .57283 .56019 .58805 .55566 .58017 .54765 Mtetra
.653 .762 .929 r
.58017 .54765 .58805 .55566 .60335 .5511 .59553 .54309 Mtetra
.655 .763 .929 r
.59553 .54309 .60335 .5511 .61873 .5465 .61097 .53845 Mtetra
.656 .764 .929 r
.61097 .53845 .61873 .5465 .6342 .54187 .62649 .53372 Mtetra
.658 .763 .927 r
.62649 .53372 .6342 .54187 .64975 .53721 .64211 .52891 Mtetra
.66 .761 .925 r
.64211 .52891 .64975 .53721 .66539 .53249 .6578 .52402 Mtetra
.66 .758 .923 r
.6578 .52402 .66539 .53249 .68112 .52769 .67358 .51912 Mtetra
.657 .756 .923 r
.67358 .51912 .68112 .52769 .69691 .52262 .68946 .51429 Mtetra
.659 .764 .927 r
.68946 .51429 .69691 .52262 .71277 .5171 .70541 .50934 Mtetra
.672 .784 .934 r
.70541 .50934 .71277 .5171 .7287 .51135 .72143 .50383 Mtetra
.682 .795 .935 r
.72143 .50383 .7287 .51135 .74469 .50532 .7375 .49786 Mtetra
.689 .801 .934 r
.7375 .49786 .74469 .50532 .76081 .49988 .75364 .49161 Mtetra
.674 .776 .927 r
.75364 .49161 .76081 .49988 .77718 .49671 .7699 .48596 Mtetra
.61 .693 .902 r
.7699 .48596 .77718 .49671 .79383 .49549 .78646 .48299 Mtetra
.558 .634 .883 r
.78646 .48299 .79383 .49549 .81077 .49614 .80333 .48232 Mtetra
.523 .594 .867 r
.80333 .48232 .81077 .49614 .82777 .49586 .82049 .48335 Mtetra
.565 .64 .884 r
.82049 .48335 .82777 .49586 .84461 .49229 .83763 .48238 Mtetra
.644 .731 .913 r
.83763 .48238 .84461 .49229 .86121 .48524 .85455 .47785 Mtetra
.734 .828 .923 r
.85455 .47785 .86121 .48524 .87767 .4762 .87117 .4694 Mtetra
.746 .85 .927 r
.87117 .4694 .87767 .4762 .8943 .46813 .88779 .46037 Mtetra
.717 .817 .927 r
.88779 .46037 .8943 .46813 .91119 .46164 .90462 .4526 Mtetra
.667 .767 .924 r
.90462 .4526 .91119 .46164 .92833 .45651 .92178 .44693 Mtetra
.608 .74 .939 r
.30854 .62074 .31742 .62841 .33134 .6247 .32244 .61799 Mtetra
.52 .739 .974 r
.32244 .61799 .33134 .6247 .34523 .623 .33634 .61694 Mtetra
.451 .732 .987 r
.33634 .61694 .34523 .623 .35915 .62252 .35029 .61674 Mtetra
.596 .793 .975 r
.35029 .61674 .35915 .62252 .37321 .62151 .36448 .6137 Mtetra
.716 .767 .893 r
.36448 .6137 .37321 .62151 .38751 .61676 .37892 .60686 Mtetra
.758 .733 .829 r
.37892 .60686 .38751 .61676 .40201 .60859 .39354 .59661 Mtetra
.735 .695 .813 r
.39354 .59661 .40201 .60859 .41661 .59847 .40817 .58714 Mtetra
.705 .697 .84 r
.40817 .58714 .41661 .59847 .43119 .58996 .42276 .57999 Mtetra
.643 .704 .891 r
.42276 .57999 .43119 .58996 .44577 .58366 .43732 .57611 Mtetra
.608 .752 .946 r
.43732 .57611 .44577 .58366 .46036 .57998 .45194 .57313 Mtetra
.611 .773 .958 r
.45194 .57313 .46036 .57998 .47503 .57689 .46666 .56987 Mtetra
.633 .776 .949 r
.46666 .56987 .47503 .57689 .48979 .57352 .48148 .56599 Mtetra
.651 .769 .935 r
.48148 .56599 .48979 .57352 .50464 .56972 .49639 .56159 Mtetra
.651 .754 .925 r
.49639 .56159 .50464 .56972 .51958 .56538 .51139 .55722 Mtetra
.648 .754 .927 r
.51139 .55722 .51958 .56538 .5346 .56091 .52646 .55294 Mtetra
.648 .76 .931 r
.52646 .55294 .5346 .56091 .5497 .55652 .54162 .54859 Mtetra
.65 .763 .931 r
.54162 .54859 .5497 .55652 .56489 .55212 .55687 .54414 Mtetra
.652 .763 .931 r
.55687 .54414 .56489 .55212 .58017 .54765 .5722 .53959 Mtetra
.654 .763 .93 r
.5722 .53959 .58017 .54765 .59553 .54309 .58762 .53497 Mtetra
.655 .763 .929 r
.58762 .53497 .59553 .54309 .61097 .53845 .60312 .53028 Mtetra
.656 .763 .928 r
.60312 .53028 .61097 .53845 .62649 .53372 .61871 .52552 Mtetra
.657 .764 .928 r
.61871 .52552 .62649 .53372 .64211 .52891 .63438 .52069 Mtetra
.659 .765 .928 r
.63438 .52069 .64211 .52891 .6578 .52402 .65014 .51576 Mtetra
.661 .766 .928 r
.65014 .51576 .6578 .52402 .67358 .51912 .66598 .51072 Mtetra
.663 .764 .926 r
.66598 .51072 .67358 .51912 .68946 .51429 .68191 .50561 Mtetra
.66 .758 .922 r
.68191 .50561 .68946 .51429 .70541 .50934 .69793 .50059 Mtetra
.659 .757 .922 r
.69793 .50059 .70541 .50934 .72143 .50383 .71404 .49559 Mtetra
.671 .775 .928 r
.71404 .49559 .72143 .50383 .7375 .49786 .73021 .49006 Mtetra
.686 .793 .931 r
.73021 .49006 .7375 .49786 .75364 .49161 .74643 .48388 Mtetra
.692 .798 .931 r
.74643 .48388 .75364 .49161 .7699 .48596 .76271 .47741 Mtetra
.669 .771 .926 r
.76271 .47741 .7699 .48596 .78646 .48299 .77914 .47186 Mtetra
.589 .678 .903 r
.77914 .47186 .78646 .48299 .80333 .48232 .79594 .46968 Mtetra
.533 .622 .886 r
.79594 .46968 .80333 .48232 .82049 .48335 .81308 .46993 Mtetra
.516 .6 .876 r
.81308 .46993 .82049 .48335 .83763 .48238 .83045 .47101 Mtetra
.595 .68 .9 r
.83045 .47101 .83763 .48238 .85455 .47785 .84764 .46855 Mtetra
.686 .766 .913 r
.84764 .46855 .85455 .47785 .87117 .4694 .86455 .46213 Mtetra
.753 .841 .918 r
.86455 .46213 .87117 .4694 .88779 .46037 .88123 .45271 Mtetra
.733 .827 .923 r
.88123 .45271 .88779 .46037 .90462 .4526 .89806 .44416 Mtetra
.692 .794 .928 r
.89806 .44416 .90462 .4526 .92178 .44693 .91517 .43738 Mtetra
.568 .733 .953 r
.29955 .6132 .30854 .62074 .32244 .61799 .31344 .61139 Mtetra
.474 .727 .98 r
.31344 .61139 .32244 .61799 .33634 .61694 .32733 .61104 Mtetra
.492 .756 .989 r
.32733 .61104 .33634 .61694 .35029 .61674 .34137 .61004 Mtetra
.677 .789 .934 r
.34137 .61004 .35029 .61674 .36448 .6137 .35571 .60486 Mtetra
.751 .752 .853 r
.35571 .60486 .36448 .6137 .37892 .60686 .37031 .59564 Mtetra
.752 .711 .814 r
.37031 .59564 .37892 .60686 .39354 .59661 .38499 .58511 Mtetra
.72 .7 .83 r
.38499 .58511 .39354 .59661 .40817 .58714 .39962 .57692 Mtetra
.667 .707 .878 r
.39962 .57692 .40817 .58714 .42276 .57999 .41418 .57202 Mtetra
.608 .742 .94 r
.41418 .57202 .42276 .57999 .43732 .57611 .42876 .56908 Mtetra
.607 .768 .957 r
.42876 .56908 .43732 .57611 .45194 .57313 .44344 .56594 Mtetra
.629 .771 .948 r
.44344 .56594 .45194 .57313 .46666 .56987 .45822 .56217 Mtetra
.651 .765 .933 r
.45822 .56217 .46666 .56987 .48148 .56599 .4731 .55776 Mtetra
.648 .752 .925 r
.4731 .55776 .48148 .56599 .49639 .56159 .48806 .55347 Mtetra
.645 .755 .929 r
.48806 .55347 .49639 .56159 .51139 .55722 .50311 .54924 Mtetra
.647 .76 .931 r
.50311 .54924 .51139 .55722 .52646 .55294 .51824 .5449 Mtetra
.65 .761 .93 r
.51824 .5449 .52646 .55294 .54162 .54859 .53346 .54043 Mtetra
.653 .76 .928 r
.53346 .54043 .54162 .54859 .55687 .54414 .54876 .53585 Mtetra
.656 .758 .925 r
.54876 .53585 .55687 .54414 .5722 .53959 .56415 .53115 Mtetra
.656 .756 .923 r
.56415 .53115 .5722 .53959 .58762 .53497 .57962 .52641 Mtetra
.656 .754 .922 r
.57962 .52641 .58762 .53497 .60312 .53028 .59518 .52167 Mtetra
.655 .754 .922 r
.59518 .52167 .60312 .53028 .61871 .52552 .61083 .51693 Mtetra
.655 .756 .924 r
.61083 .51693 .61871 .52552 .63438 .52069 .62657 .51215 Mtetra
.657 .759 .925 r
.62657 .51215 .63438 .52069 .65014 .51576 .64239 .50726 Mtetra
.66 .762 .925 r
.64239 .50726 .65014 .51576 .66598 .51072 .6583 .50225 Mtetra
.662 .764 .926 r
.6583 .50225 .66598 .51072 .68191 .50561 .67429 .4971 Mtetra
.664 .766 .925 r
.67429 .4971 .68191 .50561 .69793 .50059 .69037 .49184 Mtetra
.663 .76 .923 r
.69037 .49184 .69793 .50059 .71404 .49559 .70654 .48664 Mtetra
.659 .755 .921 r
.70654 .48664 .71404 .49559 .73021 .49006 .7228 .48155 Mtetra
.674 .773 .925 r
.7228 .48155 .73021 .49006 .74643 .48388 .73912 .4758 Mtetra
.689 .79 .927 r
.73912 .4758 .74643 .48388 .76271 .47741 .75548 .4694 Mtetra
.694 .795 .928 r
.75548 .4694 .76271 .47741 .77914 .47186 .77191 .46278 Mtetra
.644 .751 .927 r
.77191 .46278 .77914 .47186 .79594 .46968 .78859 .45817 Mtetra
.562 .661 .903 r
.78859 .45817 .79594 .46968 .81308 .46993 .80565 .45698 Mtetra
.505 .604 .886 r
.80565 .45698 .81308 .46993 .83045 .47101 .82309 .45824 Mtetra
.539 .627 .887 r
.82309 .45824 .83045 .47101 .84764 .46855 .84056 .45816 Mtetra
.635 .723 .911 r
.84056 .45816 .84764 .46855 .86455 .46213 .85776 .45388 Mtetra
.734 .813 .913 r
.85776 .45388 .86455 .46213 .88123 .45271 .87461 .44521 Mtetra
.75 .838 .918 r
.87461 .44521 .88123 .45271 .89806 .44416 .89145 .43582 Mtetra
.715 .808 .922 r
.89145 .43582 .89806 .44416 .91517 .43738 .90852 .42795 Mtetra
.533 .732 .966 r
.29045 .60597 .29955 .6132 .31344 .61139 .30434 .60476 Mtetra
.452 .719 .982 r
.30434 .60476 .31344 .61139 .32733 .61104 .31825 .60473 Mtetra
.582 .776 .972 r
.31825 .60473 .32733 .61104 .34137 .61004 .33242 .6021 Mtetra
.717 .767 .892 r
.33242 .6021 .34137 .61004 .35571 .60486 .3469 .59515 Mtetra
.766 .739 .829 r
.3469 .59515 .35571 .60486 .37031 .59564 .36162 .58435 Mtetra
.742 .709 .821 r
.36162 .58435 .37031 .59564 .38499 .58511 .37632 .57465 Mtetra
.701 .714 .859 r
.37632 .57465 .38499 .58511 .39962 .57692 .39093 .56798 Mtetra
.624 .724 .918 r
.39093 .56798 .39962 .57692 .41418 .57202 .40549 .56466 Mtetra
.601 .758 .953 r
.40549 .56466 .41418 .57202 .42876 .56908 .42012 .56173 Mtetra
.619 .765 .949 r
.42012 .56173 .42876 .56908 .44344 .56594 .43486 .55827 Mtetra
.649 .766 .934 r
.43486 .55827 .44344 .56594 .45822 .56217 .4497 .5539 Mtetra
.648 .752 .925 r
.4497 .5539 .45822 .56217 .4731 .55776 .46463 .5496 Mtetra
.644 .754 .929 r
.46463 .5496 .4731 .55776 .48806 .55347 .47964 .5454 Mtetra
.647 .759 .931 r
.47964 .5454 .48806 .55347 .50311 .54924 .49475 .54107 Mtetra
.651 .759 .928 r
.49475 .54107 .50311 .54924 .51824 .5449 .50993 .53656 Mtetra
.657 .758 .924 r
.50993 .53656 .51824 .5449 .53346 .54043 .52521 .53181 Mtetra
.659 .752 .919 r
.52521 .53181 .53346 .54043 .54876 .53585 .54056 .52699 Mtetra
.658 .748 .916 r
.54056 .52699 .54876 .53585 .56415 .53115 .55601 .52219 Mtetra
.657 .746 .916 r
.55601 .52219 .56415 .53115 .57962 .52641 .57154 .5174 Mtetra
.656 .746 .916 r
.57154 .5174 .57962 .52641 .59518 .52167 .58715 .51262 Mtetra
.656 .745 .916 r
.58715 .51262 .59518 .52167 .61083 .51693 .60286 .50783 Mtetra
.654 .745 .916 r
.60286 .50783 .61083 .51693 .62657 .51215 .61866 .50305 Mtetra
.653 .746 .918 r
.61866 .50305 .62657 .51215 .64239 .50726 .63455 .4983 Mtetra
.654 .751 .921 r
.63455 .4983 .64239 .50726 .6583 .50225 .65053 .49347 Mtetra
.66 .758 .923 r
.65053 .49347 .6583 .50225 .67429 .4971 .66659 .48839 Mtetra
.663 .762 .924 r
.66659 .48839 .67429 .4971 .69037 .49184 .68273 .48314 Mtetra
.666 .765 .924 r
.68273 .48314 .69037 .49184 .70654 .48664 .69896 .47774 Mtetra
.663 .76 .923 r
.69896 .47774 .70654 .48664 .7228 .48155 .71528 .47244 Mtetra
.661 .756 .921 r
.71528 .47244 .7228 .48155 .73912 .4758 .73171 .46721 Mtetra
.682 .777 .923 r
.73171 .46721 .73912 .4758 .75548 .4694 .74816 .46104 Mtetra
.695 .789 .923 r
.74816 .46104 .75548 .4694 .77191 .46278 .76466 .45431 Mtetra
.685 .784 .926 r
.76466 .45431 .77191 .46278 .78859 .45817 .78127 .44797 Mtetra
.599 .709 .921 r
.78127 .44797 .78859 .45817 .80565 .45698 .79826 .4451 Mtetra
.52 .635 .904 r
.79826 .4451 .80565 .45698 .82309 .45824 .81566 .44538 Mtetra
.495 .604 .891 r
.81566 .44538 .82309 .45824 .84056 .45816 .83333 .44684 Mtetra
.592 .685 .906 r
.83333 .44684 .84056 .45816 .85776 .45388 .85077 .44431 Mtetra
.696 .77 .909 r
.85077 .44431 .85776 .45388 .87461 .44521 .86788 .43724 Mtetra
.756 .83 .909 r
.86788 .43724 .87461 .44521 .89145 .43582 .88476 .42742 Mtetra
.73 .813 .916 r
.88476 .42742 .89145 .43582 .90852 .42795 .90185 .41882 Mtetra
.501 .724 .972 r
.28125 .59882 .29045 .60597 .30434 .60476 .29513 .59814 Mtetra
.464 .726 .982 r
.29513 .59814 .30434 .60476 .31825 .60473 .3091 .59786 Mtetra
.649 .781 .944 r
.3091 .59786 .31825 .60473 .33242 .6021 .32341 .59354 Mtetra
.747 .759 .862 r
.32341 .59354 .33242 .6021 .3469 .59515 .33805 .58466 Mtetra
.764 .727 .819 r
.33805 .58466 .3469 .59515 .36162 .58435 .35284 .57354 Mtetra
.73 .716 .837 r
.35284 .57354 .36162 .58435 .37632 .57465 .36754 .56491 Mtetra
.665 .72 .889 r
.36754 .56491 .37632 .57465 .39093 .56798 .38212 .56004 Mtetra
.601 .743 .944 r
.38212 .56004 .39093 .56798 .40549 .56466 .39671 .55721 Mtetra
.606 .759 .952 r
.39671 .55721 .40549 .56466 .42012 .56173 .41139 .55411 Mtetra
.641 .766 .939 r
.41139 .55411 .42012 .56173 .43486 .55827 .4262 .54999 Mtetra
.65 .753 .925 r
.4262 .54999 .43486 .55827 .4497 .5539 .4411 .54559 Mtetra
.643 .751 .928 r
.4411 .54559 .4497 .5539 .46463 .5496 .45607 .54143 Mtetra
.645 .757 .93 r
.45607 .54143 .46463 .5496 .47964 .5454 .47114 .53713 Mtetra
.651 .757 .927 r
.47114 .53713 .47964 .5454 .49475 .54107 .4863 .53261 Mtetra
.66 .756 .922 r
.4863 .53261 .49475 .54107 .50993 .53656 .50154 .52776 Mtetra
.659 .749 .916 r
.50154 .52776 .50993 .53656 .52521 .53181 .51687 .5229 Mtetra
.653 .746 .917 r
.51687 .5229 .52521 .53181 .54056 .52699 .53228 .51824 Mtetra
.653 .751 .921 r
.53228 .51824 .54056 .52699 .55601 .52219 .54779 .51358 Mtetra
.654 .755 .924 r
.54779 .51358 .55601 .52219 .57154 .5174 .56337 .50883 Mtetra
.655 .758 .925 r
.56337 .50883 .57154 .5174 .58715 .51262 .57905 .50399 Mtetra
.657 .759 .925 r
.57905 .50399 .58715 .51262 .60286 .50783 .59482 .49906 Mtetra
.659 .757 .923 r
.59482 .49906 .60286 .50783 .61866 .50305 .61067 .49406 Mtetra
.659 .752 .919 r
.61067 .49406 .61866 .50305 .63455 .4983 .62661 .48903 Mtetra
.653 .745 .918 r
.62661 .48903 .63455 .4983 .65053 .49347 .64265 .48421 Mtetra
.652 .746 .919 r
.64265 .48421 .65053 .49347 .66659 .48839 .65879 .47939 Mtetra
.66 .757 .922 r
.65879 .47939 .66659 .48839 .68273 .48314 .67501 .47422 Mtetra
.665 .762 .922 r
.67501 .47422 .68273 .48314 .69896 .47774 .6913 .46882 Mtetra
.667 .764 .922 r
.6913 .46882 .69896 .47774 .71528 .47244 .70769 .46328 Mtetra
.661 .757 .921 r
.70769 .46328 .71528 .47244 .73171 .46721 .72417 .45798 Mtetra
.667 .759 .919 r
.72417 .45798 .73171 .46721 .74816 .46104 .74074 .45239 Mtetra
.692 .783 .921 r
.74074 .45239 .74816 .46104 .76466 .45431 .75732 .44573 Mtetra
.698 .788 .92 r
.75732 .44573 .76466 .45431 .78127 .44797 .77397 .43879 Mtetra
.646 .756 .929 r
.77397 .43879 .78127 .44797 .79826 .4451 .79087 .43394 Mtetra
.546 .667 .916 r
.79087 .43394 .79826 .4451 .81566 .44538 .80822 .43301 Mtetra
.48 .608 .901 r
.80822 .43301 .81566 .44538 .83333 .44684 .82596 .43469 Mtetra
.544 .647 .901 r
.82596 .43469 .83333 .44684 .85077 .44431 .84365 .43406 Mtetra
.657 .742 .912 r
.84365 .43406 .85077 .44431 .86788 .43724 .86101 .42867 Mtetra
.75 .816 .904 r
.86101 .42867 .86788 .43724 .88476 .42742 .87801 .41901 Mtetra
.742 .819 .912 r
.87801 .41901 .88476 .42742 .90185 .41882 .89511 .40975 Mtetra
.476 .714 .974 r
.27195 .59157 .28125 .59882 .29513 .59814 .28584 .59131 Mtetra
.509 .74 .978 r
.28584 .59131 .29513 .59814 .3091 .59786 .29989 .59028 Mtetra
.689 .773 .916 r
.29989 .59028 .3091 .59786 .32341 .59354 .31434 .58457 Mtetra
.765 .755 .844 r
.31434 .58457 .32341 .59354 .33805 .58466 .32911 .57422 Mtetra
.76 .729 .824 r
.32911 .57422 .33805 .58466 .35284 .57354 .34394 .56351 Mtetra
.719 .729 .858 r
.34394 .56351 .35284 .57354 .36754 .56491 .35864 .55586 Mtetra
.629 .726 .917 r
.35864 .55586 .36754 .56491 .38212 .56004 .37321 .55231 Mtetra
.598 .75 .95 r
.37321 .55231 .38212 .56004 .39671 .55721 .38784 .54947 Mtetra
.62 .758 .944 r
.38784 .54947 .39671 .55721 .41139 .55411 .40258 .54598 Mtetra
.651 .758 .928 r
.40258 .54598 .41139 .55411 .4262 .54999 .41745 .54152 Mtetra
.644 .749 .926 r
.41745 .54152 .4262 .54999 .4411 .54559 .4324 .53731 Mtetra
.643 .754 .93 r
.4324 .53731 .4411 .54559 .45607 .54143 .44743 .53308 Mtetra
.649 .756 .927 r
.44743 .53308 .45607 .54143 .47114 .53713 .46255 .52863 Mtetra
.66 .756 .921 r
.46255 .52863 .47114 .53713 .4863 .53261 .47776 .52376 Mtetra
.659 .749 .916 r
.47776 .52376 .4863 .53261 .50154 .52776 .49306 .51889 Mtetra
.651 .747 .92 r
.49306 .51889 .50154 .52776 .51687 .5229 .50845 .51431 Mtetra
.65 .755 .926 r
.50845 .51431 .51687 .5229 .53228 .51824 .52392 .50971 Mtetra
.652 .758 .927 r
.52392 .50971 .53228 .51824 .54779 .51358 .53948 .50499 Mtetra
.654 .758 .926 r
.53948 .50499 .54779 .51358 .56337 .50883 .55513 .50017 Mtetra
.655 .758 .925 r
.55513 .50017 .56337 .50883 .57905 .50399 .57086 .49528 Mtetra
.657 .759 .925 r
.57086 .49528 .57905 .50399 .59482 .49906 .58669 .49032 Mtetra
.658 .76 .925 r
.58669 .49032 .59482 .49906 .61067 .49406 .60261 .48527 Mtetra
.661 .76 .924 r
.60261 .48527 .61067 .49406 .62661 .48903 .61861 .48009 Mtetra
.661 .758 .922 r
.61861 .48009 .62661 .48903 .64265 .48421 .6347 .47489 Mtetra
.653 .748 .919 r
.6347 .47489 .64265 .48421 .65879 .47939 .6509 .46997 Mtetra
.652 .746 .919 r
.6509 .46997 .65879 .47939 .67501 .47422 .66719 .46506 Mtetra
.662 .757 .921 r
.66719 .46506 .67501 .47422 .6913 .46882 .68356 .45972 Mtetra
.667 .762 .921 r
.68356 .45972 .6913 .46882 .70769 .46328 .70001 .45415 Mtetra
.70001 .45415 .70769 .46328 .72417 .45798 .71655 .44855 Mtetra
.66 .754 .92 r
.71655 .44855 .72417 .45798 .74074 .45239 .73321 .4432 Mtetra
.683 .769 .916 r
.73321 .4432 .74074 .45239 .75732 .44573 .74989 .43684 Mtetra
.699 .783 .917 r
.74989 .43684 .75732 .44573 .77397 .43879 .76661 .4298 Mtetra
.681 .776 .923 r
.76661 .4298 .77397 .43879 .79087 .43394 .78347 .42349 Mtetra
.572 .697 .926 r
.78347 .42349 .79087 .43394 .80822 .43301 .80079 .42143 Mtetra
.484 .629 .916 r
.80079 .42143 .80822 .43301 .82596 .43469 .81853 .42257 Mtetra
.501 .627 .907 r
.81853 .42257 .82596 .43469 .84365 .43406 .83642 .42337 Mtetra
.624 .72 .915 r
.83642 .42337 .84365 .43406 .86101 .42867 .85399 .41932 Mtetra
.733 .795 .902 r
.85399 .41932 .86101 .42867 .87801 .41901 .87115 .41036 Mtetra
.751 .818 .905 r
.87115 .41036 .87801 .41901 .89511 .40975 .88829 .40055 Mtetra
.464 .706 .973 r
.26256 .58415 .27195 .59157 .28584 .59131 .27647 .58412 Mtetra
.559 .75 .966 r
.27647 .58412 .28584 .59131 .29989 .59028 .29062 .58214 Mtetra
.711 .766 .895 r
.29062 .58214 .29989 .59028 .31434 .58457 .30518 .57535 Mtetra
.775 .753 .833 r
.30518 .57535 .31434 .58457 .32911 .57422 .32008 .56406 Mtetra
.754 .734 .834 r
.32008 .56406 .32911 .57422 .34394 .56351 .33493 .55393 Mtetra
.698 .735 .879 r
.33493 .55393 .34394 .56351 .35864 .55586 .34961 .54748 Mtetra
.607 .737 .937 r
.34961 .54748 .35864 .55586 .37321 .55231 .3642 .54449 Mtetra
.602 .751 .949 r
.3642 .54449 .37321 .55231 .38784 .54947 .37888 .54149 Mtetra
.635 .758 .937 r
.37888 .54149 .38784 .54947 .40258 .54598 .39369 .53753 Mtetra
.65 .752 .924 r
.39369 .53753 .40258 .54598 .41745 .54152 .40861 .53307 Mtetra
.641 .751 .928 r
.40861 .53307 .41745 .54152 .4324 .53731 .42361 .5289 Mtetra
.645 .754 .928 r
.42361 .5289 .4324 .53731 .44743 .53308 .43869 .52455 Mtetra
.655 .755 .923 r
.43869 .52455 .44743 .53308 .46255 .52863 .45387 .51981 Mtetra
.661 .751 .917 r
.45387 .51981 .46255 .52863 .47776 .52376 .46914 .51483 Mtetra
.65 .746 .92 r
.46914 .51483 .47776 .52376 .49306 .51889 .48449 .51025 Mtetra
.649 .754 .926 r
.48449 .51025 .49306 .51889 .50845 .51431 .49993 .50568 Mtetra
.652 .756 .926 r
.49993 .50568 .50845 .51431 .52392 .50971 .51546 .50096 Mtetra
.656 .756 .923 r
.51546 .50096 .52392 .50971 .53948 .50499 .53108 .49606 Mtetra
.659 .754 .92 r
.53108 .49606 .53948 .50499 .55513 .50017 .54679 .49104 Mtetra
.656 .749 .919 r
.54679 .49104 .55513 .50017 .57086 .49528 .56258 .4861 Mtetra
.653 .748 .92 r
.56258 .4861 .57086 .49528 .58669 .49032 .57847 .48124 Mtetra
.655 .753 .921 r
.57847 .48124 .58669 .49032 .60261 .48527 .59445 .47626 Mtetra
.659 .757 .922 r
.59445 .47626 .60261 .48527 .61861 .48009 .61052 .4711 Mtetra
.662 .76 .922 r
.61052 .4711 .61861 .48009 .6347 .47489 .62668 .46578 Mtetra
.661 .758 .922 r
.62668 .46578 .6347 .47489 .6509 .46997 .64292 .46047 Mtetra
.651 .746 .92 r
.64292 .46047 .6509 .46997 .66719 .46506 .65928 .45557 Mtetra
.656 .75 .919 r
.65928 .45557 .66719 .46506 .68356 .45972 .67573 .45041 Mtetra
.665 .759 .92 r
.67573 .45041 .68356 .45972 .70001 .45415 .69225 .44486 Mtetra
.669 .762 .92 r
.69225 .44486 .70001 .45415 .71655 .44855 .70886 .43912 Mtetra
.661 .757 .921 r
.70886 .43912 .71655 .44855 .73321 .4432 .72558 .43366 Mtetra
.673 .76 .916 r
.72558 .43366 .73321 .4432 .74989 .43684 .74236 .42768 Mtetra
.696 .778 .915 r
.74236 .42768 .74989 .43684 .76661 .4298 .75917 .42071 Mtetra
.695 .781 .917 r
.75917 .42071 .76661 .4298 .78347 .42349 .77605 .41371 Mtetra
.604 .73 .934 r
.77605 .41371 .78347 .42349 .80079 .42143 .79333 .4103 Mtetra
.498 .648 .925 r
.79333 .4103 .80079 .42143 .81853 .42257 .81106 .41072 Mtetra
.467 .617 .914 r
.81106 .41072 .81853 .42257 .83642 .42337 .82909 .41239 Mtetra
.597 .704 .918 r
.82909 .41239 .83642 .42337 .85399 .41932 .84683 .40937 Mtetra
.712 .776 .902 r
.84683 .40937 .85399 .41932 .87115 .41036 .86419 .4013 Mtetra
.755 .812 .898 r
.86419 .4013 .87115 .41036 .88829 .40055 .88139 .39114 Mtetra
.461 .701 .971 r
.25308 .57651 .26256 .58415 .27647 .58412 .26702 .57657 Mtetra
.596 .753 .953 r
.26702 .57657 .27647 .58412 .29062 .58214 .28127 .57376 Mtetra
.73 .765 .881 r
.28127 .57376 .29062 .58214 .30518 .57535 .29595 .56593 Mtetra
.777 .751 .829 r
.29595 .56593 .30518 .57535 .32008 .56406 .31093 .55428 Mtetra
.749 .742 .845 r
.31093 .55428 .32008 .56406 .33493 .55393 .3258 .5447 Mtetra
.679 .739 .896 r
.3258 .5447 .33493 .55393 .34961 .54748 .34049 .53917 Mtetra
.599 .739 .942 r
.34049 .53917 .34961 .54748 .3642 .54449 .35511 .53634 Mtetra
.606 .746 .944 r
.35511 .53634 .3642 .54449 .37888 .54149 .36984 .53324 Mtetra
.645 .757 .93 r
.36984 .53324 .37888 .54149 .39369 .53753 .38472 .52892 Mtetra
.646 .749 .924 r
.38472 .52892 .39369 .53753 .40861 .53307 .39968 .52455 Mtetra
.641 .751 .928 r
.39968 .52455 .40861 .53307 .42361 .5289 .41473 .52032 Mtetra
.648 .753 .926 r
.41473 .52032 .42361 .5289 .43869 .52455 .42987 .51584 Mtetra
.661 .755 .92 r
.42987 .51584 .43869 .52455 .45387 .51981 .44511 .51086 Mtetra
.656 .749 .918 r
.44511 .51086 .45387 .51981 .46914 .51483 .46043 .50605 Mtetra
.647 .751 .925 r
.46043 .50605 .46914 .51483 .48449 .51025 .47583 .50151 Mtetra
.65 .754 .926 r
.47583 .50151 .48449 .51025 .49993 .50568 .49133 .49683 Mtetra
.659 .755 .921 r
.49133 .49683 .49993 .50568 .51546 .50096 .50692 .49179 Mtetra
.663 .751 .915 r
.50692 .49179 .51546 .50096 .53108 .49606 .52259 .4866 Mtetra
.658 .744 .913 r
.52259 .4866 .53108 .49606 .54679 .49104 .53836 .48154 Mtetra
.656 .743 .914 r
.53836 .48154 .54679 .49104 .56258 .4861 .55421 .47655 Mtetra
.654 .742 .915 r
.55421 .47655 .56258 .4861 .57847 .48124 .57016 .47162 Mtetra
.649 .74 .916 r
.57016 .47162 .57847 .48124 .59445 .47626 .5862 .46683 Mtetra
.653 .747 .919 r
.5862 .46683 .59445 .47626 .61052 .4711 .60234 .46188 Mtetra
.661 .756 .921 r
.60234 .46188 .61052 .4711 .62668 .46578 .61856 .45657 Mtetra
.664 .759 .921 r
.61856 .45657 .62668 .46578 .64292 .46047 .63487 .45112 Mtetra
.656 .754 .922 r
.63487 .45112 .64292 .46047 .65928 .45557 .65129 .44593 Mtetra
.651 .747 .92 r
.65129 .44593 .65928 .45557 .67573 .45041 .66781 .44092 Mtetra
.663 .756 .919 r
.66781 .44092 .67573 .45041 .69225 .44486 .6844 .43539 Mtetra
.669 .76 .918 r
.6844 .43539 .69225 .44486 .70886 .43912 .70108 .4296 Mtetra
.665 .758 .92 r
.70108 .4296 .70886 .43912 .72558 .43366 .71786 .42395 Mtetra
.665 .756 .918 r
.71786 .42395 .72558 .43366 .74236 .42768 .73473 .41824 Mtetra
.694 .773 .912 r
.73473 .41824 .74236 .42768 .75917 .42071 .75162 .41126 Mtetra
.7 .777 .911 r
.75162 .41126 .75917 .42071 .77605 .41371 .76857 .40399 Mtetra
.632 .746 .93 r
.76857 .40399 .77605 .41371 .79333 .4103 .78583 .3995 Mtetra
.513 .667 .931 r
.78583 .3995 .79333 .4103 .81106 .41072 .80357 .39925 Mtetra
.449 .618 .922 r
.80357 .39925 .81106 .41072 .82909 .41239 .82168 .40118 Mtetra
.569 .688 .921 r
.82168 .40118 .82909 .41239 .84683 .40937 .83959 .39913 Mtetra
.695 .766 .906 r
.83959 .39913 .84683 .40937 .86419 .4013 .8571 .39182 Mtetra
.756 .805 .893 r
.8571 .39182 .86419 .4013 .88139 .39114 .87438 .38147 Mtetra
.463 .697 .969 r
.24352 .56862 .25308 .57651 .26702 .57657 .25749 .56867 Mtetra
.618 .753 .942 r
.25749 .56867 .26702 .57657 .28127 .57376 .27182 .56525 Mtetra
.741 .766 .873 r
.27182 .56525 .28127 .57376 .29595 .56593 .28661 .55671 Mtetra
.78 .756 .831 r
.28661 .55671 .29595 .56593 .31093 .55428 .30166 .54491 Mtetra
.746 .751 .856 r
.30166 .54491 .31093 .55428 .3258 .5447 .31657 .53571 Mtetra
.663 .742 .909 r
.31657 .53571 .3258 .5447 .34049 .53917 .33126 .53078 Mtetra
.596 .738 .943 r
.33126 .53078 .34049 .53917 .35511 .53634 .34593 .52797 Mtetra
.611 .744 .94 r
.34593 .52797 .35511 .53634 .36984 .53324 .36071 .52471 Mtetra
.649 .753 .925 r
.36071 .52471 .36984 .53324 .38472 .52892 .37565 .52021 Mtetra
.643 .748 .925 r
.37565 .52021 .38472 .52892 .39968 .52455 .39066 .51589 Mtetra
.642 .75 .927 r
.39066 .51589 .39968 .52455 .41473 .52032 .40576 .51159 Mtetra
.651 .752 .924 r
.40576 .51159 .41473 .52032 .42987 .51584 .42095 .50695 Mtetra
.662 .753 .917 r
.42095 .50695 .42987 .51584 .44511 .51086 .43625 .50186 Mtetra
.651 .748 .921 r
.43625 .50186 .44511 .51086 .46043 .50605 .45162 .49718 Mtetra
.647 .751 .925 r
.45162 .49718 .46043 .50605 .47583 .50151 .46708 .49259 Mtetra
.654 .753 .923 r
.46708 .49259 .47583 .50151 .49133 .49683 .48264 .48773 Mtetra
.665 .754 .916 r
.48264 .48773 .49133 .49683 .50692 .49179 .49829 .4824 Mtetra
.656 .745 .916 r
.49829 .4824 .50692 .49179 .52259 .4866 .51402 .47742 Mtetra
.65 .75 .923 r
.51402 .47742 .52259 .4866 .53836 .48154 .52984 .47264 Mtetra
.655 .759 .926 r
.52984 .47264 .53836 .48154 .55421 .47655 .54576 .4676 Mtetra
.662 .761 .924 r
.54576 .4676 .55421 .47655 .57016 .47162 .56176 .46228 Mtetra
.656 .752 .92 r
.56176 .46228 .57016 .47162 .5862 .46683 .57786 .45717 Mtetra
.646 .742 .919 r
.57786 .45717 .5862 .46683 .60234 .46188 .59407 .45241 Mtetra
.658 .752 .919 r
.59407 .45241 .60234 .46188 .61856 .45657 .61036 .44718 Mtetra
.664 .757 .919 r
.61036 .44718 .61856 .45657 .63487 .45112 .62673 .44167 Mtetra
.661 .756 .92 r
.62673 .44167 .63487 .45112 .65129 .44593 .64321 .43624 Mtetra
.65 .747 .921 r
.64321 .43624 .65129 .44593 .66781 .44092 .65979 .43123 Mtetra
.661 .753 .918 r
.65979 .43123 .66781 .44092 .6844 .43539 .67646 .42575 Mtetra
.668 .758 .918 r
.67646 .42575 .6844 .43539 .70108 .4296 .69321 .41993 Mtetra
.667 .758 .918 r
.69321 .41993 .70108 .4296 .71786 .42395 .71005 .41411 Mtetra
.662 .754 .918 r
.71005 .41411 .71786 .42395 .73473 .41824 .72701 .40848 Mtetra
.691 .767 .91 r
.72701 .40848 .73473 .41824 .75162 .41126 .74398 .40157 Mtetra
.701 .774 .908 r
.74398 .40157 .75162 .41126 .76857 .40399 .761 .39416 Mtetra
.649 .753 .925 r
.761 .39416 .76857 .40399 .78583 .3995 .77828 .38894 Mtetra
.524 .68 .936 r
.77828 .38894 .78583 .3995 .80357 .39925 .79604 .38818 Mtetra
.437 .623 .931 r
.79604 .38818 .80357 .39925 .82168 .40118 .81421 .39015 Mtetra
.547 .683 .929 r
.81421 .39015 .82168 .40118 .83959 .39913 .83226 .38875 Mtetra
.682 .76 .91 r
.83226 .38875 .83959 .39913 .8571 .39182 .84991 .38196 Mtetra
.755 .799 .888 r
.84991 .38196 .8571 .39182 .87438 .38147 .86727 .3715 Mtetra
.468 .694 .966 r
.23388 .56044 .24352 .56862 .25749 .56867 .24788 .56046 Mtetra
.629 .75 .935 r
.24788 .56046 .25749 .56867 .27182 .56525 .26228 .55671 Mtetra
.747 .767 .87 r
.26228 .55671 .27182 .56525 .28661 .55671 .27715 .54778 Mtetra
.783 .764 .836 r
.27715 .54778 .28661 .55671 .30166 .54491 .29227 .53596 Mtetra
.747 .761 .864 r
.29227 .53596 .30166 .54491 .31657 .53571 .30722 .52687 Mtetra
.655 .746 .917 r
.30722 .52687 .31657 .53571 .33126 .53078 .32195 .52222 Mtetra
.596 .736 .942 r
.32195 .52222 .33126 .53078 .34593 .52797 .33666 .51938 Mtetra
.615 .742 .937 r
.33666 .51938 .34593 .52797 .36071 .52471 .35149 .51598 Mtetra
.65 .751 .923 r
.35149 .51598 .36071 .52471 .37565 .52021 .36648 .51139 Mtetra
.642 .747 .925 r
.36648 .51139 .37565 .52021 .39066 .51589 .38154 .50707 Mtetra
.643 .749 .926 r
.38154 .50707 .39066 .51589 .40576 .51159 .39669 .50271 Mtetra
.653 .751 .922 r
.39669 .50271 .40576 .51159 .42095 .50695 .41195 .49795 Mtetra
.662 .752 .917 r
.41195 .49795 .42095 .50695 .43625 .50186 .4273 .49282 Mtetra
.648 .748 .923 r
.4273 .49282 .43625 .50186 .45162 .49718 .44273 .48818 Mtetra
.648 .75 .924 r
.44273 .48818 .45162 .49718 .46708 .49259 .45824 .48351 Mtetra
.658 .753 .92 r
.45824 .48351 .46708 .49259 .48264 .48773 .47385 .47844 Mtetra
.665 .752 .915 r
.47385 .47844 .48264 .48773 .49829 .4824 .48956 .47308 Mtetra
.647 .746 .922 r
.48956 .47308 .49829 .4824 .51402 .47742 .50535 .46837 Mtetra
.642 .752 .929 r
.50535 .46837 .51402 .47742 .52984 .47264 .52123 .46381 Mtetra
.655 .763 .929 r
.52123 .46381 .52984 .47264 .54576 .4676 .53721 .45871 Mtetra
.668 .767 .924 r
.53721 .45871 .54576 .4676 .56176 .46228 .55328 .45307 Mtetra
.664 .76 .921 r
.55328 .45307 .56176 .46228 .57786 .45717 .56944 .44757 Mtetra
.647 .746 .922 r
.56944 .44757 .57786 .45717 .59407 .45241 .5857 .44274 Mtetra
.654 .748 .919 r
.5857 .44274 .59407 .45241 .61036 .44718 .60206 .43761 Mtetra
.663 .755 .918 r
.60206 .43761 .61036 .44718 .62673 .44167 .6185 .43206 Mtetra
.663 .755 .919 r
.6185 .43206 .62673 .44167 .64321 .43624 .63504 .42649 Mtetra
.65 .748 .922 r
.63504 .42649 .64321 .43624 .65979 .43123 .65169 .42141 Mtetra
.659 .752 .919 r
.65169 .42141 .65979 .43123 .67646 .42575 .66843 .41595 Mtetra
.668 .757 .917 r
.66843 .41595 .67646 .42575 .69321 .41993 .68525 .41008 Mtetra
.68525 .41008 .69321 .41993 .71005 .41411 .70216 .40416 Mtetra
.661 .753 .918 r
.70216 .40416 .71005 .41411 .72701 .40848 .71919 .3985 Mtetra
.689 .764 .909 r
.71919 .3985 .72701 .40848 .74398 .40157 .73624 .39162 Mtetra
.701 .771 .906 r
.73624 .39162 .74398 .40157 .761 .39416 .75334 .38414 Mtetra
.658 .754 .921 r
.75334 .38414 .761 .39416 .77828 .38894 .77066 .37852 Mtetra
.527 .688 .94 r
.77066 .37852 .77828 .38894 .79604 .38818 .78847 .37752 Mtetra
.429 .631 .939 r
.78847 .37752 .79604 .38818 .81421 .39015 .8067 .37941 Mtetra
.533 .685 .937 r
.8067 .37941 .81421 .39015 .83226 .38875 .82484 .37829 Mtetra
.676 .759 .914 r
.82484 .37829 .83226 .38875 .84991 .38196 .84261 .37174 Mtetra
.754 .794 .885 r
.84261 .37174 .84991 .38196 .86727 .3715 .86006 .36121 Mtetra
.472 .69 .962 r
.22415 .55198 .23388 .56044 .24788 .56046 .23818 .55196 Mtetra
.63 .746 .931 r
.23818 .55196 .24788 .56046 .26228 .55671 .25263 .54817 Mtetra
.747 .769 .871 r
.25263 .54817 .26228 .55671 .27715 .54778 .26756 .53918 Mtetra
.786 .772 .84 r
.26756 .53918 .27715 .54778 .29227 .53596 .28275 .52729 Mtetra
.749 .769 .869 r
.28275 .52729 .29227 .53596 .30722 .52687 .29777 .51814 Mtetra
.654 .75 .92 r
.29777 .51814 .30722 .52687 .32195 .52222 .31255 .51344 Mtetra
.597 .733 .939 r
.31255 .51344 .32195 .52222 .33666 .51938 .3273 .51056 Mtetra
.616 .739 .934 r
.3273 .51056 .33666 .51938 .35149 .51598 .34218 .50711 Mtetra
.65 .75 .922 r
.34218 .50711 .35149 .51598 .36648 .51139 .35722 .50247 Mtetra
.642 .747 .925 r
.35722 .50247 .36648 .51139 .38154 .50707 .37233 .49811 Mtetra
.643 .747 .925 r
.37233 .49811 .38154 .50707 .39669 .50271 .38754 .49369 Mtetra
.653 .75 .921 r
.38754 .49369 .39669 .50271 .41195 .49795 .40285 .48889 Mtetra
.662 .753 .918 r
.40285 .48889 .41195 .49795 .4273 .49282 .41825 .4837 Mtetra
.648 .749 .923 r
.41825 .4837 .4273 .49282 .44273 .48818 .43373 .47901 Mtetra
.43373 .47901 .44273 .48818 .45824 .48351 .44931 .47429 Mtetra
.658 .752 .919 r
.44931 .47429 .45824 .48351 .47385 .47844 .46498 .46917 Mtetra
.665 .754 .917 r
.46498 .46917 .47385 .47844 .48956 .47308 .48074 .46374 Mtetra
.647 .748 .923 r
.48074 .46374 .48956 .47308 .50535 .46837 .49659 .45899 Mtetra
.642 .747 .925 r
.49659 .45899 .50535 .46837 .52123 .46381 .51253 .45437 Mtetra
.656 .751 .92 r
.51253 .45437 .52123 .46381 .53721 .45871 .52857 .44922 Mtetra
.669 .755 .915 r
.52857 .44922 .53721 .45871 .55328 .45307 .5447 .44352 Mtetra
.664 .754 .917 r
.5447 .44352 .55328 .45307 .56944 .44757 .56092 .43797 Mtetra
.647 .748 .923 r
.56092 .43797 .56944 .44757 .5857 .44274 .57725 .43308 Mtetra
.654 .751 .921 r
.57725 .43308 .5857 .44274 .60206 .43761 .59367 .42789 Mtetra
.663 .754 .918 r
.59367 .42789 .60206 .43761 .6185 .43206 .61018 .42228 Mtetra
.61018 .42228 .6185 .43206 .63504 .42649 .62678 .41665 Mtetra
.65 .749 .922 r
.62678 .41665 .63504 .42649 .65169 .42141 .6435 .41152 Mtetra
.659 .752 .919 r
.6435 .41152 .65169 .42141 .66843 .41595 .66031 .406 Mtetra
.668 .756 .916 r
.66031 .406 .66843 .41595 .68525 .41008 .6772 .40007 Mtetra
.6772 .40007 .68525 .41008 .70216 .40416 .69418 .39408 Mtetra
.661 .753 .918 r
.69418 .39408 .70216 .40416 .71919 .3985 .71128 .38837 Mtetra
.689 .763 .909 r
.71128 .38837 .71919 .3985 .73624 .39162 .72841 .38142 Mtetra
.701 .767 .904 r
.72841 .38142 .73624 .39162 .75334 .38414 .74558 .37387 Mtetra
.658 .751 .919 r
.74558 .37387 .75334 .38414 .77066 .37852 .76298 .36819 Mtetra
.525 .691 .944 r
.76298 .36819 .77066 .37852 .78847 .37752 .78086 .36714 Mtetra
.421 .636 .945 r
.78086 .36714 .78847 .37752 .8067 .37941 .79915 .36898 Mtetra
.528 .693 .944 r
.79915 .36898 .8067 .37941 .82484 .37829 .81736 .36781 Mtetra
.676 .761 .915 r
.81736 .36781 .82484 .37829 .84261 .37174 .83521 .36119 Mtetra
.753 .789 .882 r
.83521 .36119 .84261 .37174 .86006 .36121 .85275 .35059 Mtetra
.477 .687 .959 r
.21435 .54323 .22415 .55198 .23818 .55196 .22841 .54317 Mtetra
.621 .738 .931 r
.22841 .54317 .23818 .55196 .25263 .54817 .24287 .53963 Mtetra
.742 .77 .876 r
.24287 .53963 .25263 .54817 .26756 .53918 .25785 .53091 Mtetra
.789 .78 .844 r
.25785 .53091 .26756 .53918 .28275 .52729 .27311 .51891 Mtetra
.754 .777 .872 r
.27311 .51891 .28275 .52729 .29777 .51814 .28821 .50953 Mtetra
.663 .757 .92 r
.28821 .50953 .29777 .51814 .31255 .51344 .30306 .50445 Mtetra
.598 .731 .937 r
.30306 .50445 .31255 .51344 .3273 .51056 .31785 .50151 Mtetra
.613 .735 .932 r
.31785 .50151 .3273 .51056 .34218 .50711 .33278 .49811 Mtetra
.649 .748 .922 r
.33278 .49811 .34218 .50711 .35722 .50247 .34787 .49346 Mtetra
.643 .747 .925 r
.34787 .49346 .35722 .50247 .37233 .49811 .36303 .48899 Mtetra
.642 .746 .924 r
.36303 .48899 .37233 .49811 .38754 .49369 .37829 .48454 Mtetra
.651 .749 .921 r
.37829 .48454 .38754 .49369 .40285 .48889 .39365 .47975 Mtetra
.662 .754 .918 r
.39365 .47975 .40285 .48889 .41825 .4837 .40911 .47451 Mtetra
.651 .75 .923 r
.40911 .47451 .41825 .4837 .43373 .47901 .42465 .46967 Mtetra
.648 .747 .922 r
.42465 .46967 .43373 .47901 .44931 .47429 .44028 .46492 Mtetra
.654 .75 .92 r
.44028 .46492 .44931 .47429 .46498 .46917 .456 .4599 Mtetra
.665 .757 .918 r
.456 .4599 .46498 .46917 .48074 .46374 .47183 .4544 Mtetra
.655 .753 .922 r
.47183 .4544 .48074 .46374 .49659 .45899 .48774 .44927 Mtetra
.65 .744 .918 r
.48774 .44927 .49659 .45899 .51253 .45437 .50374 .44432 Mtetra
.656 .74 .912 r
.50374 .44432 .51253 .45437 .52857 .44922 .51984 .43911 Mtetra
.662 .742 .91 r
.51984 .43911 .52857 .44922 .5447 .44352 .53603 .43363 Mtetra
.656 .746 .916 r
.53603 .43363 .5447 .44352 .56092 .43797 .55232 .42835 Mtetra
.646 .75 .925 r
.55232 .42835 .56092 .43797 .57725 .43308 .56871 .42342 Mtetra
.657 .754 .921 r
.56871 .42342 .57725 .43308 .59367 .42789 .58519 .41802 Mtetra
.664 .753 .917 r
.58519 .41802 .59367 .42789 .61018 .42228 .60176 .41233 Mtetra
.661 .752 .917 r
.60176 .41233 .61018 .42228 .62678 .41665 .61844 .40673 Mtetra
.65 .75 .923 r
.61844 .40673 .62678 .41665 .6435 .41152 .63522 .40155 Mtetra
.661 .754 .919 r
.63522 .40155 .6435 .41152 .66031 .406 .6521 .39589 Mtetra
.668 .755 .915 r
.6521 .39589 .66031 .406 .6772 .40007 .66905 .38988 Mtetra
.667 .754 .915 r
.66905 .38988 .6772 .40007 .69418 .39408 .68611 .38388 Mtetra
.662 .753 .918 r
.68611 .38388 .69418 .39408 .71128 .38837 .70328 .37807 Mtetra
.691 .763 .907 r
.70328 .37807 .71128 .38837 .72841 .38142 .72047 .37096 Mtetra
.7 .764 .902 r
.72047 .37096 .72841 .38142 .74558 .37387 .73773 .36336 Mtetra
.65 .745 .919 r
.73773 .36336 .74558 .37387 .76298 .36819 .75522 .35795 Mtetra
.516 .692 .948 r
.75522 .35795 .76298 .36819 .78086 .36714 .77319 .35704 Mtetra
.411 .64 .95 r
.77319 .35704 .78086 .36714 .79915 .36898 .79154 .35887 Mtetra
.534 .707 .95 r
.79154 .35887 .79915 .36898 .81736 .36781 .8098 .3573 Mtetra
.682 .766 .914 r
.8098 .3573 .81736 .36781 .83521 .36119 .82769 .35031 Mtetra
.751 .784 .879 r
.82769 .35031 .83521 .36119 .85275 .35059 .84532 .33962 Mtetra
.482 .684 .955 r
.20446 .53419 .21435 .54323 .22841 .54317 .21855 .53407 Mtetra
.603 .728 .932 r
.21855 .53407 .22841 .54317 .24287 .53963 .23301 .53104 Mtetra
.731 .77 .884 r
.23301 .53104 .24287 .53963 .25785 .53091 .24799 .52293 Mtetra
.791 .787 .849 r
.24799 .52293 .25785 .53091 .27311 .51891 .26332 .51095 Mtetra
.763 .789 .874 r
.26332 .51095 .27311 .51891 .28821 .50953 .27852 .50106 Mtetra
.68 .767 .917 r
.27852 .50106 .28821 .50953 .30306 .50445 .29347 .49528 Mtetra
.601 .729 .935 r
.29347 .49528 .30306 .50445 .31785 .50151 .30832 .49222 Mtetra
.61 .731 .931 r
.30832 .49222 .31785 .50151 .33278 .49811 .32328 .4889 Mtetra
.646 .745 .921 r
.32328 .4889 .33278 .49811 .34787 .49346 .33841 .48433 Mtetra
.646 .748 .923 r
.33841 .48433 .34787 .49346 .36303 .48899 .35363 .47971 Mtetra
.642 .744 .923 r
.35363 .47971 .36303 .48899 .37829 .48454 .36894 .47524 Mtetra
.648 .747 .921 r
.36894 .47524 .37829 .48454 .39365 .47975 .38435 .4705 Mtetra
.661 .753 .918 r
.38435 .4705 .39365 .47975 .40911 .47451 .39987 .46526 Mtetra
.656 .753 .921 r
.39987 .46526 .40911 .47451 .42465 .46967 .41547 .46019 Mtetra
.647 .746 .921 r
.41547 .46019 .42465 .46967 .44028 .46492 .43115 .45539 Mtetra
.651 .747 .92 r
.43115 .45539 .44028 .46492 .456 .4599 .44693 .45044 Mtetra
.659 .753 .919 r
.44693 .45044 .456 .4599 .47183 .4544 .46281 .44514 Mtetra
.663 .759 .922 r
.46281 .44514 .47183 .4544 .48774 .44927 .47879 .43967 Mtetra
.658 .752 .919 r
.47879 .43967 .48774 .44927 .50374 .44432 .49485 .43434 Mtetra
.656 .744 .914 r
.49485 .43434 .50374 .44432 .51984 .43911 .51101 .42907 Mtetra
.654 .743 .915 r
.51101 .42907 .51984 .43911 .53603 .43363 .52726 .42386 Mtetra
.649 .749 .922 r
.52726 .42386 .53603 .43363 .55232 .42835 .54362 .4188 Mtetra
.652 .756 .926 r
.54362 .4188 .55232 .42835 .56871 .42342 .56007 .41356 Mtetra
.661 .753 .919 r
.56007 .41356 .56871 .42342 .58519 .41802 .57661 .40797 Mtetra
.664 .752 .915 r
.57661 .40797 .58519 .41802 .60176 .41233 .59325 .40222 Mtetra
.656 .749 .918 r
.59325 .40222 .60176 .41233 .61844 .40673 .61 .39675 Mtetra
.651 .751 .923 r
.61 .39675 .61844 .40673 .63522 .40155 .62685 .39144 Mtetra
.663 .754 .918 r
.62685 .39144 .63522 .40155 .6521 .39589 .64379 .38562 Mtetra
.669 .754 .914 r
.64379 .38562 .6521 .39589 .66905 .38988 .66082 .37952 Mtetra
.665 .752 .915 r
.66082 .37952 .66905 .38988 .68611 .38388 .67795 .37356 Mtetra
.665 .754 .917 r
.67795 .37356 .68611 .38388 .70328 .37807 .69519 .36755 Mtetra
.693 .761 .904 r
.69519 .36755 .70328 .37807 .72047 .37096 .71245 .36024 Mtetra
.698 .76 .9 r
.71245 .36024 .72047 .37096 .73773 .36336 .72978 .35264 Mtetra
.633 .737 .923 r
.72978 .35264 .73773 .36336 .75522 .35795 .7474 .34785 Mtetra
.496 .688 .953 r
.7474 .34785 .75522 .35795 .77319 .35704 .76546 .34734 Mtetra
.402 .649 .957 r
.76546 .34734 .77319 .35704 .79154 .35887 .78388 .34904 Mtetra
.553 .726 .955 r
.78388 .34904 .79154 .35887 .8098 .3573 .80215 .34672 Mtetra
.695 .772 .91 r
.80215 .34672 .8098 .3573 .82769 .35031 .82008 .33906 Mtetra
.75 .778 .877 r
.82008 .33906 .82769 .35031 .84532 .33962 .83779 .32833 Mtetra
.49 .683 .952 r
.19449 .52488 .20446 .53419 .21855 .53407 .20862 .5246 Mtetra
.576 .713 .935 r
.20862 .5246 .21855 .53407 .23301 .53104 .22305 .52233 Mtetra
.711 .766 .896 r
.22305 .52233 .23301 .53104 .24799 .52293 .238 .51517 Mtetra
.789 .794 .856 r
.238 .51517 .24799 .52293 .26332 .51095 .25339 .50342 Mtetra
.775 .8 .873 r
.25339 .50342 .26332 .51095 .27852 .50106 .26871 .49285 Mtetra
.704 .779 .91 r
.26871 .49285 .27852 .50106 .29347 .49528 .28379 .48602 Mtetra
.608 .732 .933 r
.28379 .48602 .29347 .49528 .30832 .49222 .29869 .48271 Mtetra
.608 .727 .929 r
.29869 .48271 .30832 .49222 .32328 .4889 .3137 .47939 Mtetra
.637 .738 .921 r
.3137 .47939 .32328 .4889 .33841 .48433 .32886 .47509 Mtetra
.65 .749 .922 r
.32886 .47509 .33841 .48433 .35363 .47971 .34414 .47029 Mtetra
.642 .743 .923 r
.34414 .47029 .35363 .47971 .36894 .47524 .3595 .46577 Mtetra
.646 .745 .921 r
.3595 .46577 .36894 .47524 .38435 .4705 .37496 .46106 Mtetra
.656 .749 .919 r
.37496 .46106 .38435 .4705 .39987 .46526 .39052 .45596 Mtetra
.661 .755 .92 r
.39052 .45596 .39987 .46526 .41547 .46019 .40619 .45061 Mtetra
.65 .747 .92 r
.40619 .45061 .41547 .46019 .43115 .45539 .42193 .44566 Mtetra
.649 .745 .919 r
.42193 .44566 .43115 .45539 .44693 .45044 .43777 .44072 Mtetra
.652 .747 .919 r
.43777 .44072 .44693 .45044 .46281 .44514 .4537 .43563 Mtetra
.656 .754 .922 r
.4537 .43563 .46281 .44514 .47879 .43967 .46973 .43035 Mtetra
.658 .761 .925 r
.46973 .43035 .47879 .43967 .49485 .43434 .48586 .42495 Mtetra
.656 .759 .926 r
.48586 .42495 .49485 .43434 .51101 .42907 .50208 .41962 Mtetra
.653 .758 .927 r
.50208 .41962 .51101 .42907 .52726 .42386 .5184 .41438 Mtetra
.655 .76 .927 r
.5184 .41438 .52726 .42386 .54362 .4188 .53482 .409 Mtetra
.659 .755 .921 r
.53482 .409 .54362 .4188 .56007 .41356 .55133 .40344 Mtetra
.662 .751 .916 r
.55133 .40344 .56007 .41356 .57661 .40797 .56794 .39772 Mtetra
.662 .749 .915 r
.56794 .39772 .57661 .40797 .59325 .40222 .58465 .39201 Mtetra
.651 .747 .92 r
.58465 .39201 .59325 .40222 .61 .39675 .60147 .3867 Mtetra
.656 .754 .922 r
.60147 .3867 .61 .39675 .62685 .39144 .61838 .38113 Mtetra
.665 .753 .916 r
.61838 .38113 .62685 .39144 .64379 .38562 .63539 .37516 Mtetra
.669 .752 .913 r
.63539 .37516 .64379 .38562 .66082 .37952 .65249 .36899 Mtetra
.662 .749 .915 r
.65249 .36899 .66082 .37952 .67795 .37356 .6697 .3631 Mtetra
.673 .757 .914 r
.6697 .3631 .67795 .37356 .69519 .36755 .68699 .35669 Mtetra
.694 .757 .9 r
.68699 .35669 .69519 .36755 .71245 .36024 .70432 .34926 Mtetra
.693 .756 .9 r
.70432 .34926 .71245 .36024 .72978 .35264 .72174 .3418 Mtetra
.606 .725 .929 r
.72174 .3418 .72978 .35264 .7474 .34785 .7395 .33798 Mtetra
.467 .682 .959 r
.7395 .33798 .7474 .34785 .76546 .34734 .75769 .33806 Mtetra
.402 .663 .965 r
.75769 .33806 .76546 .34734 .78388 .34904 .77615 .33941 Mtetra
.583 .748 .955 r
.77615 .33941 .78388 .34904 .80215 .34672 .79441 .33597 Mtetra
.712 .777 .903 r
.79441 .33597 .80215 .34672 .82008 .33906 .81234 .32741 Mtetra
.746 .772 .874 r
.81234 .32741 .82008 .33906 .83779 .32833 .83016 .31671 Mtetra
.505 .685 .948 r
.18443 .51533 .19449 .52488 .20862 .5246 .19862 .51475 Mtetra
.543 .694 .938 r
.19862 .51475 .20862 .5246 .22305 .52233 .213 .51336 Mtetra
.688 .759 .905 r
.213 .51336 .22305 .52233 .238 .51517 .22791 .50719 Mtetra
.777 .791 .864 r
.22791 .50719 .238 .51517 .25339 .50342 .2433 .49627 Mtetra
.787 .81 .871 r
.2433 .49627 .25339 .50342 .26871 .49285 .25875 .48499 Mtetra
.733 .794 .901 r
.25875 .48499 .26871 .49285 .28379 .48602 .27399 .47682 Mtetra
.627 .741 .93 r
.27399 .47682 .28379 .48602 .29869 .48271 .28898 .47285 Mtetra
.605 .72 .926 r
.28898 .47285 .29869 .48271 .3137 .47939 .30402 .46961 Mtetra
.625 .73 .922 r
.30402 .46961 .3137 .47939 .32886 .47509 .31921 .46569 Mtetra
.651 .748 .92 r
.31921 .46569 .32886 .47509 .34414 .47029 .33454 .46078 Mtetra
.644 .744 .922 r
.33454 .46078 .34414 .47029 .3595 .46577 .34996 .45612 Mtetra
.644 .742 .921 r
.34996 .45612 .3595 .46577 .37496 .46106 .36547 .45144 Mtetra
.649 .746 .92 r
.36547 .45144 .37496 .46106 .39052 .45596 .38108 .44652 Mtetra
.66 .754 .92 r
.38108 .44652 .39052 .45596 .40619 .45061 .3968 .44117 Mtetra
.659 .755 .921 r
.3968 .44117 .40619 .45061 .42193 .44566 .41261 .43583 Mtetra
.651 .745 .919 r
.41261 .43583 .42193 .44566 .43777 .44072 .42851 .43078 Mtetra
.651 .744 .918 r
.42851 .43078 .43777 .44072 .4537 .43563 .4445 .42569 Mtetra
.653 .746 .918 r
.4445 .42569 .4537 .43563 .46973 .43035 .46058 .42049 Mtetra
.655 .749 .919 r
.46058 .42049 .46973 .43035 .48586 .42495 .47677 .41518 Mtetra
.656 .753 .922 r
.47677 .41518 .48586 .42495 .50208 .41962 .49306 .4098 Mtetra
.657 .754 .921 r
.49306 .4098 .50208 .41962 .5184 .41438 .50944 .40433 Mtetra
.659 .751 .918 r
.50944 .40433 .5184 .41438 .53482 .409 .52592 .39877 Mtetra
.661 .749 .915 r
.52592 .39877 .53482 .409 .55133 .40344 .5425 .39308 Mtetra
.661 .747 .914 r
.5425 .39308 .55133 .40344 .56794 .39772 .55917 .38736 Mtetra
.653 .746 .918 r
.55917 .38736 .56794 .39772 .58465 .39201 .57595 .38192 Mtetra
.652 .753 .924 r
.57595 .38192 .58465 .39201 .60147 .3867 .59284 .37649 Mtetra
.662 .755 .919 r
.59284 .37649 .60147 .3867 .61838 .38113 .60982 .37062 Mtetra
.667 .752 .914 r
.60982 .37062 .61838 .38113 .63539 .37516 .62689 .3645 Mtetra
.667 .75 .912 r
.62689 .3645 .63539 .37516 .65249 .36899 .64406 .35836 Mtetra
.66 .749 .916 r
.64406 .35836 .65249 .36899 .6697 .3631 .66135 .35246 Mtetra
.683 .759 .909 r
.66135 .35246 .6697 .3631 .68699 .35669 .67869 .34553 Mtetra
.696 .754 .897 r
.67869 .34553 .68699 .35669 .70432 .34926 .69609 .3379 Mtetra
.68 .745 .901 r
.69609 .3379 .70432 .34926 .72174 .3418 .71363 .33101 Mtetra
.566 .711 .939 r
.71363 .33101 .72174 .3418 .7395 .33798 .73155 .32846 Mtetra
.431 .674 .965 r
.73155 .32846 .7395 .33798 .75769 .33806 .74985 .32917 Mtetra
.431 .692 .974 r
.74985 .32917 .75769 .33806 .77615 .33941 .76832 .32953 Mtetra
.617 .76 .947 r
.76832 .32953 .77615 .33941 .79441 .33597 .78657 .32493 Mtetra
.73 .78 .892 r
.78657 .32493 .79441 .33597 .81234 .32741 .8045 .31531 Mtetra
.74 .764 .872 r
.8045 .31531 .81234 .32741 .83016 .31671 .82243 .30481 Mtetra
.527 .692 .943 r
.17429 .50559 .18443 .51533 .19862 .51475 .18855 .5045 Mtetra
.515 .676 .937 r
.18855 .5045 .19862 .51475 .213 .51336 .20289 .50381 Mtetra
.653 .74 .913 r
.20289 .50381 .213 .51336 .22791 .50719 .21773 .49897 Mtetra
.755 .787 .879 r
.21773 .49897 .22791 .50719 .2433 .49627 .23306 .48943 Mtetra
.796 .818 .869 r
.23306 .48943 .2433 .49627 .25875 .48499 .24863 .47759 Mtetra
.755 .808 .895 r
.24863 .47759 .25875 .48499 .27399 .47682 .26403 .4683 Mtetra
.666 .77 .927 r
.26403 .4683 .27399 .47682 .28898 .47285 .27918 .46288 Mtetra
.607 .721 .926 r
.27918 .46288 .28898 .47285 .30402 .46961 .29426 .45955 Mtetra
.615 .723 .923 r
.29426 .45955 .30402 .46961 .31921 .46569 .30947 .45594 Mtetra
.644 .74 .919 r
.30947 .45594 .31921 .46569 .33454 .46078 .32484 .45127 Mtetra
.65 .748 .921 r
.32484 .45127 .33454 .46078 .34996 .45612 .34032 .44632 Mtetra
.643 .741 .92 r
.34032 .44632 .34996 .45612 .36547 .45144 .35588 .4416 Mtetra
.646 .742 .919 r
.35588 .4416 .36547 .45144 .38108 .44652 .37154 .43674 Mtetra
.652 .747 .919 r
.37154 .43674 .38108 .44652 .3968 .44117 .38731 .43166 Mtetra
.66 .756 .921 r
.38731 .43166 .3968 .44117 .41261 .43583 .40318 .42621 Mtetra
.659 .755 .921 r
.40318 .42621 .41261 .43583 .42851 .43078 .41914 .42076 Mtetra
.653 .745 .917 r
.41914 .42076 .42851 .43078 .4445 .42569 .43519 .41552 Mtetra
.653 .743 .916 r
.43519 .41552 .4445 .42569 .46058 .42049 .45134 .41026 Mtetra
.654 .744 .916 r
.45134 .41026 .46058 .42049 .47677 .41518 .46759 .40491 Mtetra
.656 .745 .915 r
.46759 .40491 .47677 .41518 .49306 .4098 .48394 .39947 Mtetra
.658 .745 .915 r
.48394 .39947 .49306 .4098 .50944 .40433 .50038 .39393 Mtetra
.659 .745 .914 r
.50038 .39393 .50944 .40433 .52592 .39877 .51692 .3883 Mtetra
.51692 .3883 .52592 .39877 .5425 .39308 .53357 .38264 Mtetra
.653 .745 .918 r
.53357 .38264 .5425 .39308 .55917 .38736 .55031 .3772 Mtetra
.652 .752 .923 r
.55031 .3772 .55917 .38736 .57595 .38192 .56716 .37175 Mtetra
.66 .756 .921 r
.56716 .37175 .57595 .38192 .59284 .37649 .58411 .36593 Mtetra
.665 .751 .914 r
.58411 .36593 .59284 .37649 .60982 .37062 .60115 .35988 Mtetra
.667 .749 .912 r
.60115 .35988 .60982 .37062 .62689 .3645 .6183 .35368 Mtetra
.661 .747 .914 r
.6183 .35368 .62689 .3645 .64406 .35836 .63555 .34771 Mtetra
.667 .754 .915 r
.63555 .34771 .64406 .35836 .66135 .35246 .65289 .34144 Mtetra
.69 .756 .902 r
.65289 .34144 .66135 .35246 .67869 .34553 .67029 .33408 Mtetra
.695 .75 .894 r
.67029 .33408 .67869 .34553 .69609 .3379 .68777 .32641 Mtetra
.647 .733 .911 r
.68777 .32641 .69609 .3379 .71363 .33101 .70546 .3209 Mtetra
.522 .709 .956 r
.70546 .3209 .71363 .33101 .73155 .32846 .72352 .31939 Mtetra
.396 .669 .97 r
.72352 .31939 .73155 .32846 .74985 .32917 .74194 .32056 Mtetra
.485 .731 .98 r
.74194 .32056 .74985 .32917 .76832 .32953 .76037 .31935 Mtetra
.656 .772 .935 r
.76037 .31935 .76832 .32953 .78657 .32493 .77859 .31325 Mtetra
.742 .773 .879 r
.77859 .31325 .78657 .32493 .8045 .31531 .79654 .30277 Mtetra
.73 .755 .872 r
.79654 .30277 .8045 .31531 .82243 .30481 .8146 .29268 Mtetra
.552 .7 .938 r
.16404 .49573 .17429 .50559 .18855 .5045 .1784 .49401 Mtetra
.506 .669 .936 r
.1784 .49401 .18855 .5045 .20289 .50381 .19274 .49351 Mtetra
.604 .711 .92 r
.19274 .49351 .20289 .50381 .21773 .49897 .20746 .49032 Mtetra
.719 .776 .898 r
.20746 .49032 .21773 .49897 .23306 .48943 .22268 .48265 Mtetra
.793 .821 .874 r
.22268 .48265 .23306 .48943 .24863 .47759 .23832 .47101 Mtetra
.778 .828 .891 r
.23832 .47101 .24863 .47759 .26403 .4683 .25389 .46049 Mtetra
.714 .798 .917 r
.25389 .46049 .26403 .4683 .27918 .46288 .26924 .45311 Mtetra
.623 .733 .926 r
.26924 .45311 .27918 .46288 .29426 .45955 .28442 .44918 Mtetra
.611 .717 .92 r
.28442 .44918 .29426 .45955 .30947 .45594 .29966 .44565 Mtetra
.626 .725 .918 r
.29966 .44565 .30947 .45594 .32484 .45127 .31504 .44156 Mtetra
.651 .746 .919 r
.31504 .44156 .32484 .45127 .34032 .44632 .33057 .43653 Mtetra
.648 .745 .92 r
.33057 .43653 .34032 .44632 .35588 .4416 .3462 .43157 Mtetra
.645 .74 .918 r
.3462 .43157 .35588 .4416 .37154 .43674 .36191 .42671 Mtetra
.648 .742 .918 r
.36191 .42671 .37154 .43674 .38731 .43166 .37772 .42171 Mtetra
.652 .746 .919 r
.37772 .42171 .38731 .43166 .40318 .42621 .39364 .41652 Mtetra
.658 .755 .922 r
.39364 .41652 .40318 .42621 .41914 .42076 .40966 .41107 Mtetra
.659 .757 .922 r
.40966 .41107 .41914 .42076 .43519 .41552 .42578 .40555 Mtetra
.658 .752 .919 r
.42578 .40555 .43519 .41552 .45134 .41026 .442 .40004 Mtetra
.657 .747 .917 r
.442 .40004 .45134 .41026 .46759 .40491 .45831 .39454 Mtetra
.656 .745 .915 r
.45831 .39454 .46759 .40491 .48394 .39947 .47471 .38904 Mtetra
.655 .745 .916 r
.47471 .38904 .48394 .39947 .50038 .39393 .49122 .38352 Mtetra
.654 .746 .918 r
.49122 .38352 .50038 .39393 .51692 .3883 .50783 .37802 Mtetra
.653 .75 .921 r
.50783 .37802 .51692 .3883 .53357 .38264 .52454 .37253 Mtetra
.654 .755 .924 r
.52454 .37253 .53357 .38264 .55031 .3772 .54135 .36696 Mtetra
.66 .756 .921 r
.54135 .36696 .55031 .3772 .56716 .37175 .55826 .36113 Mtetra
.663 .75 .915 r
.55826 .36113 .56716 .37175 .58411 .36593 .57528 .35511 Mtetra
.666 .748 .912 r
.57528 .35511 .58411 .36593 .60115 .35988 .59239 .34893 Mtetra
.663 .746 .912 r
.59239 .34893 .60115 .35988 .6183 .35368 .60961 .34285 Mtetra
.661 .749 .916 r
.60961 .34285 .6183 .35368 .63555 .34771 .62693 .33684 Mtetra
.682 .757 .908 r
.62693 .33684 .63555 .34771 .65289 .34144 .64433 .32985 Mtetra
.692 .748 .894 r
.64433 .32985 .65289 .34144 .67029 .33408 .66179 .32228 Mtetra
.683 .742 .895 r
.66179 .32228 .67029 .33408 .68777 .32641 .67937 .3151 Mtetra
.596 .717 .929 r
.67937 .3151 .68777 .32641 .70546 .3209 .69724 .31149 Mtetra
.464 .7 .97 r
.69724 .31149 .70546 .3209 .72352 .31939 .71546 .31114 Mtetra
.383 .687 .979 r
.71546 .31114 .72352 .31939 .74194 .32056 .73393 .31199 Mtetra
.559 .771 .977 r
.73393 .31199 .74194 .32056 .76037 .31935 .75231 .30871 Mtetra
.697 .78 .915 r
.75231 .30871 .76037 .31935 .77859 .31325 .77047 .30075 Mtetra
.742 .761 .868 r
.77047 .30075 .77859 .31325 .79654 .30277 .78848 .28994 Mtetra
.719 .748 .875 r
.78848 .28994 .79654 .30277 .8146 .29268 .80668 .28039 Mtetra
.576 .712 .935 r
.15368 .48593 .16404 .49573 .1784 .49401 .16813 .48351 Mtetra
.521 .677 .936 r
.16813 .48351 .1784 .49401 .19274 .49351 .18254 .4826 Mtetra
.55 .681 .925 r
.18254 .4826 .19274 .49351 .20746 .49032 .19713 .48101 Mtetra
.678 .756 .91 r
.19713 .48101 .20746 .49032 .22268 .48265 .21225 .47508 Mtetra
.767 .807 .885 r
.21225 .47508 .22268 .48265 .23832 .47101 .22782 .46493 Mtetra
.795 .841 .886 r
.22782 .46493 .23832 .47101 .25389 .46049 .24355 .45343 Mtetra
.75 .821 .907 r
.24355 .45343 .25389 .46049 .26924 .45311 .25912 .44435 Mtetra
.669 .771 .926 r
.25912 .44435 .26924 .45311 .28442 .44918 .27447 .43869 Mtetra
.613 .717 .92 r
.27447 .43869 .28442 .44918 .29966 .44565 .28976 .43505 Mtetra
.618 .718 .917 r
.28976 .43505 .29966 .44565 .31504 .44156 .30517 .4312 Mtetra
.636 .73 .916 r
.30517 .4312 .31504 .44156 .33057 .43653 .32072 .42669 Mtetra
.653 .748 .919 r
.32072 .42669 .33057 .43653 .3462 .43157 .3364 .42151 Mtetra
.649 .743 .918 r
.3364 .42151 .3462 .43157 .36191 .42671 .35218 .41646 Mtetra
.647 .739 .917 r
.35218 .41646 .36191 .42671 .37772 .42171 .36805 .41145 Mtetra
.649 .741 .917 r
.36805 .41145 .37772 .42171 .39364 .41652 .38402 .40632 Mtetra
.652 .745 .918 r
.38402 .40632 .39364 .41652 .40966 .41107 .40009 .40106 Mtetra
.654 .75 .921 r
.40009 .40106 .40966 .41107 .42578 .40555 .41626 .39567 Mtetra
.656 .755 .923 r
.41626 .39567 .42578 .40555 .442 .40004 .43254 .39016 Mtetra
.656 .757 .924 r
.43254 .39016 .442 .40004 .45831 .39454 .44891 .3846 Mtetra
.44891 .3846 .45831 .39454 .47471 .38904 .46538 .37903 Mtetra
.655 .756 .924 r
.46538 .37903 .47471 .38904 .49122 .38352 .48195 .37346 Mtetra
.655 .757 .924 r
.48195 .37346 .49122 .38352 .50783 .37802 .49863 .36783 Mtetra
.658 .756 .922 r
.49863 .36783 .50783 .37802 .52454 .37253 .51541 .36208 Mtetra
.66 .753 .919 r
.51541 .36208 .52454 .37253 .54135 .36696 .53228 .35621 Mtetra
.663 .748 .914 r
.53228 .35621 .54135 .36696 .55826 .36113 .54926 .35019 Mtetra
.665 .747 .911 r
.54926 .35019 .55826 .36113 .57528 .35511 .56634 .34404 Mtetra
.663 .745 .911 r
.56634 .34404 .57528 .35511 .59239 .34893 .58353 .33794 Mtetra
.659 .746 .914 r
.58353 .33794 .59239 .34893 .60961 .34285 .60082 .33196 Mtetra
.674 .755 .912 r
.60082 .33196 .60961 .34285 .62693 .33684 .6182 .32529 Mtetra
.687 .748 .897 r
.6182 .32529 .62693 .33684 .64433 .32985 .63566 .31792 Mtetra
.69 .743 .892 r
.63566 .31792 .64433 .32985 .66179 .32228 .6532 .31034 Mtetra
.645 .726 .908 r
.6532 .31034 .66179 .32228 .67937 .3151 .67093 .30482 Mtetra
.535 .715 .955 r
.67093 .30482 .67937 .3151 .69724 .31149 .68897 .30284 Mtetra
.404 .69 .978 r
.68897 .30284 .69724 .31149 .71546 .31114 .70732 .30339 Mtetra
.442 .736 .99 r
.70732 .30339 .71546 .31114 .73393 .31199 .72577 .30256 Mtetra
.626 .781 .956 r
.72577 .30256 .73393 .31199 .75231 .30871 .7441 .29735 Mtetra
.729 .779 .892 r
.7441 .29735 .75231 .30871 .77047 .30075 .76221 .28758 Mtetra
.733 .748 .864 r
.76221 .28758 .77047 .30075 .78848 .28994 .78034 .27707 Mtetra
.708 .745 .881 r
.78034 .27707 .78848 .28994 .80668 .28039 .79868 .26813 Mtetra
.609 .732 .932 r
.14316 .47642 .15368 .48593 .16813 .48351 .15777 .47294 Mtetra
.551 .69 .931 r
.15777 .47294 .16813 .48351 .18254 .4826 .17228 .47122 Mtetra
.522 .662 .924 r
.17228 .47122 .18254 .4826 .19713 .48101 .18682 .47039 Mtetra
.619 .715 .914 r
.18682 .47039 .19713 .48101 .21225 .47508 .20177 .46659 Mtetra
.719 .785 .904 r
.20177 .46659 .21225 .47508 .22782 .46493 .21719 .45881 Mtetra
.791 .842 .89 r
.21719 .45881 .22782 .46493 .24355 .45343 .23299 .44746 Mtetra
.779 .848 .903 r
.23299 .44746 .24355 .45343 .25912 .44435 .24876 .43692 Mtetra
.728 .814 .918 r
.24876 .43692 .25912 .44435 .27447 .43869 .26436 .4288 Mtetra
.641 .742 .922 r
.26436 .4288 .27447 .43869 .28976 .43505 .27978 .42409 Mtetra
.615 .712 .914 r
.27978 .42409 .28976 .43505 .30517 .4312 .29522 .42031 Mtetra
.623 .717 .914 r
.29522 .42031 .30517 .4312 .32072 .42669 .31079 .41623 Mtetra
.639 .732 .916 r
.31079 .41623 .32072 .42669 .3364 .42151 .3265 .4115 Mtetra
.653 .747 .919 r
.3265 .4115 .3364 .42151 .35218 .41646 .34234 .40622 Mtetra
.651 .744 .917 r
.34234 .40622 .35218 .41646 .36805 .41145 .35827 .40097 Mtetra
.648 .739 .915 r
.35827 .40097 .36805 .41145 .38402 .40632 .37429 .3958 Mtetra
.65 .739 .915 r
.37429 .3958 .38402 .40632 .40009 .40106 .39042 .39055 Mtetra
.652 .742 .916 r
.39042 .39055 .40009 .40106 .41626 .39567 .40665 .38519 Mtetra
.653 .744 .916 r
.40665 .38519 .41626 .39567 .43254 .39016 .42298 .37973 Mtetra
.655 .747 .917 r
.42298 .37973 .43254 .39016 .44891 .3846 .43942 .37417 Mtetra
.656 .749 .918 r
.43942 .37417 .44891 .3846 .46538 .37903 .45595 .36854 Mtetra
.657 .749 .918 r
.45595 .36854 .46538 .37903 .48195 .37346 .47259 .36283 Mtetra
.658 .748 .916 r
.47259 .36283 .48195 .37346 .49863 .36783 .48933 .35704 Mtetra
.66 .746 .914 r
.48933 .35704 .49863 .36783 .51541 .36208 .50617 .35113 Mtetra
.662 .745 .912 r
.50617 .35113 .51541 .36208 .53228 .35621 .52312 .34511 Mtetra
.663 .744 .91 r
.52312 .34511 .53228 .35621 .54926 .35019 .54016 .33901 Mtetra
.66 .743 .911 r
.54016 .33901 .54926 .35019 .56634 .34404 .55731 .33298 Mtetra
.659 .746 .914 r
.55731 .33298 .56634 .34404 .58353 .33794 .57457 .32698 Mtetra
.671 .754 .913 r
.57457 .32698 .58353 .33794 .60082 .33196 .59192 .32041 Mtetra
.684 .748 .9 r
.59192 .32041 .60082 .33196 .6182 .32529 .60936 .31317 Mtetra
.689 .74 .89 r
.60936 .31317 .6182 .32529 .63566 .31792 .62688 .30561 Mtetra
.668 .73 .896 r
.62688 .30561 .63566 .31792 .6532 .31034 .64454 .29899 Mtetra
.578 .713 .935 r
.64454 .29899 .6532 .31034 .67093 .30482 .66245 .29589 Mtetra
.457 .713 .978 r
.66245 .29589 .67093 .30482 .68897 .30284 .68064 .2953 Mtetra
.38 .709 .986 r
.68064 .2953 .68897 .30284 .70732 .30339 .69906 .29557 Mtetra
.548 .789 .988 r
.69906 .29557 .70732 .30339 .72577 .30256 .71745 .29215 Mtetra
.687 .785 .925 r
.71745 .29215 .72577 .30256 .7441 .29735 .73571 .28458 Mtetra
.738 .758 .869 r
.73571 .28458 .7441 .29735 .76221 .28758 .75384 .27389 Mtetra
.718 .736 .865 r
.75384 .27389 .76221 .28758 .78034 .27707 .77212 .2641 Mtetra
.688 .738 .889 r
.77212 .2641 .78034 .27707 .79868 .26813 .79063 .25614 Mtetra
.642 .746 .925 r
.1325 .46704 .14316 .47642 .15777 .47294 .14727 .46246 Mtetra
.576 .703 .928 r
.14727 .46246 .15777 .47294 .17228 .47122 .1619 .45997 Mtetra
.533 .671 .926 r
.1619 .45997 .17228 .47122 .18682 .47039 .1765 .45877 Mtetra
.555 .673 .917 r
.1765 .45877 .18682 .47039 .20177 .46659 .19127 .45701 Mtetra
.668 .754 .915 r
.19127 .45701 .20177 .46659 .21719 .45881 .20654 .45131 Mtetra
.751 .813 .902 r
.20654 .45131 .21719 .45881 .23299 .44746 .22223 .44201 Mtetra
.793 .86 .899 r
.22223 .44201 .23299 .44746 .24876 .43692 .23816 .43066 Mtetra
.761 .845 .915 r
.23816 .43066 .24876 .43692 .26436 .4288 .25397 .42099 Mtetra
.708 .806 .926 r
.25397 .42099 .26436 .4288 .27978 .42409 .26965 .41365 Mtetra
.636 .732 .917 r
.26965 .41365 .27978 .42409 .29522 .42031 .28519 .40903 Mtetra
.619 .71 .91 r
.28519 .40903 .29522 .42031 .31079 .41623 .3008 .40503 Mtetra
.626 .715 .91 r
.3008 .40503 .31079 .41623 .3265 .4115 .31652 .40074 Mtetra
.638 .729 .914 r
.31652 .40074 .3265 .4115 .34234 .40622 .33238 .39598 Mtetra
.652 .746 .918 r
.33238 .39598 .34234 .40622 .35827 .40097 .34837 .39065 Mtetra
.655 .746 .917 r
.34837 .39065 .35827 .40097 .37429 .3958 .36447 .38517 Mtetra
.652 .74 .914 r
.36447 .38517 .37429 .3958 .39042 .39055 .38065 .37978 Mtetra
.651 .738 .913 r
.38065 .37978 .39042 .39055 .40665 .38519 .39694 .37436 Mtetra
.653 .739 .913 r
.39694 .37436 .40665 .38519 .42298 .37973 .41333 .36885 Mtetra
.654 .74 .913 r
.41333 .36885 .42298 .37973 .43942 .37417 .42983 .36326 Mtetra
.656 .741 .912 r
.42983 .36326 .43942 .37417 .45595 .36854 .44642 .35756 Mtetra
.657 .741 .912 r
.44642 .35756 .45595 .36854 .47259 .36283 .46312 .35177 Mtetra
.659 .741 .911 r
.46312 .35177 .47259 .36283 .48933 .35704 .47993 .34588 Mtetra
.66 .741 .91 r
.47993 .34588 .48933 .35704 .50617 .35113 .49683 .3399 Mtetra
.49683 .3399 .50617 .35113 .52312 .34511 .51385 .3339 Mtetra
.657 .742 .912 r
.51385 .3339 .52312 .34511 .54016 .33901 .53096 .32798 Mtetra
.66 .748 .915 r
.53096 .32798 .54016 .33901 .55731 .33298 .54818 .3219 Mtetra
.673 .753 .911 r
.54818 .3219 .55731 .33298 .57457 .32698 .5655 .31524 Mtetra
.681 .744 .899 r
.5655 .31524 .57457 .32698 .59192 .32041 .58291 .3081 Mtetra
.686 .736 .889 r
.58291 .3081 .59192 .32041 .60936 .31317 .60042 .30064 Mtetra
.672 .728 .892 r
.60042 .30064 .60936 .31317 .62688 .30561 .61804 .29381 Mtetra
.604 .716 .924 r
.61804 .29381 .62688 .30561 .64454 .29899 .63586 .28977 Mtetra
.502 .731 .975 r
.63586 .28977 .64454 .29899 .66245 .29589 .65392 .28813 Mtetra
.389 .711 .986 r
.65392 .28813 .66245 .29589 .68064 .2953 .67223 .28826 Mtetra
.469 .773 .997 r
.67223 .28826 .68064 .2953 .69906 .29557 .69062 .28628 Mtetra
.636 .793 .958 r
.69062 .28628 .69906 .29557 .71745 .29215 .70897 .28057 Mtetra
.728 .778 .892 r
.70897 .28057 .71745 .29215 .73571 .28458 .72717 .27075 Mtetra
.728 .738 .86 r
.72717 .27075 .73571 .28458 .75384 .27389 .7454 .26031 Mtetra
.707 .736 .874 r
.7454 .26031 .75384 .27389 .77212 .2641 .76382 .25118 Mtetra
.666 .733 .899 r
.76382 .25118 .77212 .2641 .79063 .25614 .7825 .24424 Mtetra
.655 .753 .921 r
.12172 .45769 .1325 .46704 .14727 .46246 .13659 .45257 Mtetra
.615 .731 .929 r
.13659 .45257 .14727 .46246 .1619 .45997 .1514 .44881 Mtetra
.565 .688 .923 r
.1514 .44881 .1619 .45997 .1765 .45877 .16612 .44666 Mtetra
.534 .657 .915 r
.16612 .44666 .1765 .45877 .19127 .45701 .18085 .4455 Mtetra
.597 .695 .911 r
.18085 .4455 .19127 .45701 .20654 .45131 .19591 .44235 Mtetra
.691 .776 .916 r
.19591 .44235 .20654 .45131 .22223 .44201 .21141 .43567 Mtetra
.767 .843 .909 r
.21141 .43567 .22223 .44201 .23816 .43066 .2273 .42562 Mtetra
.788 .874 .911 r
.2273 .42562 .23816 .43066 .25397 .42099 .24331 .41459 Mtetra
.749 .845 .923 r
.24331 .41459 .25397 .42099 .26965 .41365 .25921 .40545 Mtetra
.701 .8 .926 r
.25921 .40545 .26965 .41365 .28519 .40903 .27501 .39829 Mtetra
.64 .73 .914 r
.27501 .39829 .28519 .40903 .3008 .40503 .29072 .39345 Mtetra
.623 .709 .907 r
.29072 .39345 .3008 .40503 .31652 .40074 .30649 .38921 Mtetra
.63 .714 .907 r
.30649 .38921 .31652 .40074 .33238 .39598 .32237 .38469 Mtetra
.635 .721 .91 r
.32237 .38469 .33238 .39598 .34837 .39065 .33838 .37994 Mtetra
.647 .738 .916 r
.33838 .37994 .34837 .39065 .36447 .38517 .35452 .37471 Mtetra
.653 .747 .918 r
.35452 .37471 .36447 .38517 .38065 .37978 .37077 .3692 Mtetra
.655 .746 .917 r
.37077 .3692 .38065 .37978 .39694 .37436 .38712 .36358 Mtetra
.655 .743 .915 r
.38712 .36358 .39694 .37436 .41333 .36885 .40357 .35791 Mtetra
.656 .741 .913 r
.40357 .35791 .41333 .36885 .42983 .36326 .42013 .35219 Mtetra
.656 .74 .912 r
.42013 .35219 .42983 .36326 .44642 .35756 .43679 .34643 Mtetra
.43679 .34643 .44642 .35756 .46312 .35177 .45355 .34063 Mtetra
.656 .742 .913 r
.45355 .34063 .46312 .35177 .47993 .34588 .47042 .33478 Mtetra
.657 .744 .914 r
.47042 .33478 .47993 .34588 .49683 .3399 .48739 .32887 Mtetra
.659 .747 .916 r
.48739 .32887 .49683 .3399 .51385 .3339 .50447 .32286 Mtetra
.665 .751 .914 r
.50447 .32286 .51385 .3339 .53096 .32798 .52165 .31655 Mtetra
.675 .748 .906 r
.52165 .31655 .53096 .32798 .54818 .3219 .53894 .30976 Mtetra
.678 .736 .895 r
.53894 .30976 .54818 .3219 .5655 .31524 .55632 .30272 Mtetra
.682 .732 .888 r
.55632 .30272 .5655 .31524 .58291 .3081 .5738 .29537 Mtetra
.669 .725 .891 r
.5738 .29537 .58291 .3081 .60042 .30064 .59139 .28864 Mtetra
.612 .717 .92 r
.59139 .28864 .60042 .30064 .61804 .29381 .60915 .28429 Mtetra
.53 .738 .97 r
.60915 .28429 .61804 .29381 .63586 .28977 .62711 .28198 Mtetra
.41 .723 .989 r
.62711 .28198 .63586 .28977 .65392 .28813 .64531 .28162 Mtetra
.42 .763 .996 r
.64531 .28162 .65392 .28813 .67223 .28826 .66365 .28027 Mtetra
.597 .81 .982 r
.66365 .28027 .67223 .28826 .69062 .28628 .682 .27545 Mtetra
.704 .786 .915 r
.682 .27545 .69062 .28628 .70897 .28057 .70027 .26696 Mtetra
.731 .744 .862 r
.70027 .26696 .70897 .28057 .72717 .27075 .71851 .25637 Mtetra
.711 .725 .861 r
.71851 .25637 .72717 .27075 .7454 .26031 .73689 .24678 Mtetra
.684 .73 .885 r
.73689 .24678 .7454 .26031 .76382 .25118 .75548 .23886 Mtetra
.656 .743 .914 r
.75548 .23886 .76382 .25118 .7825 .24424 .77429 .23234 Mtetra
.656 .751 .919 r
.11083 .44815 .12172 .45769 .13659 .45257 .12576 .44294 Mtetra
.647 .748 .923 r
.12576 .44294 .13659 .45257 .1514 .44881 .14073 .43803 Mtetra
.595 .709 .923 r
.14073 .43803 .1514 .44881 .16612 .44666 .15559 .43489 Mtetra
.556 .675 .918 r
.15559 .43489 .16612 .44666 .18085 .4455 .17043 .43297 Mtetra
.548 .658 .908 r
.17043 .43297 .18085 .4455 .19591 .44235 .18535 .43137 Mtetra
.624 .718 .914 r
.18535 .43137 .19591 .44235 .21141 .43567 .20065 .42719 Mtetra
.701 .792 .921 r
.20065 .42719 .21141 .43567 .2273 .42562 .21633 .42002 Mtetra
.77 .864 .919 r
.21633 .42002 .2273 .42562 .24331 .41459 .23236 .40985 Mtetra
.78 .884 .921 r
.23236 .40985 .24331 .41459 .25921 .40545 .24848 .39918 Mtetra
.743 .851 .93 r
.24848 .39918 .25921 .40545 .27501 .39829 .2645 .39021 Mtetra
.707 .807 .927 r
.2645 .39021 .27501 .39829 .29072 .39345 .28047 .38272 Mtetra
.65 .737 .913 r
.28047 .38272 .29072 .39345 .30649 .38921 .29636 .37739 Mtetra
.632 .71 .903 r
.29636 .37739 .30649 .38921 .32237 .38469 .3123 .37275 Mtetra
.632 .709 .902 r
.3123 .37275 .32237 .38469 .33838 .37994 .32834 .36807 Mtetra
.637 .714 .903 r
.32834 .36807 .33838 .37994 .35452 .37471 .34451 .36314 Mtetra
.642 .723 .907 r
.34451 .36314 .35452 .37471 .37077 .3692 .36079 .35801 Mtetra
.646 .733 .912 r
.36079 .35801 .37077 .3692 .38712 .36358 .37719 .35266 Mtetra
.652 .742 .915 r
.37719 .35266 .38712 .36358 .40357 .35791 .3937 .34706 Mtetra
.655 .746 .917 r
.3937 .34706 .40357 .35791 .42013 .35219 .41032 .34132 Mtetra
.656 .747 .917 r
.41032 .34132 .42013 .35219 .43679 .34643 .42704 .33549 Mtetra
.657 .747 .916 r
.42704 .33549 .43679 .34643 .45355 .34063 .44387 .32958 Mtetra
.66 .747 .915 r
.44387 .32958 .45355 .34063 .47042 .33478 .4608 .32352 Mtetra
.665 .746 .911 r
.4608 .32352 .47042 .33478 .48739 .32887 .47785 .31721 Mtetra
.669 .741 .904 r
.47785 .31721 .48739 .32887 .50447 .32286 .49499 .31068 Mtetra
.672 .733 .896 r
.49499 .31068 .50447 .32286 .52165 .31655 .51224 .30393 Mtetra
.675 .728 .889 r
.51224 .30393 .52165 .31655 .53894 .30976 .5296 .29693 Mtetra
.675 .725 .887 r
.5296 .29693 .53894 .30976 .55632 .30272 .54705 .28987 Mtetra
.66 .72 .893 r
.54705 .28987 .55632 .30272 .5738 .29537 .56461 .2835 Mtetra
.605 .718 .925 r
.56461 .2835 .5738 .29537 .59139 .28864 .58232 .27935 Mtetra
.537 .749 .974 r
.58232 .27935 .59139 .28864 .60915 .28429 .6002 .27672 Mtetra
.425 .739 .992 r
.6002 .27672 .60915 .28429 .62711 .28198 .6183 .27586 Mtetra
.405 .766 .994 r
.6183 .27586 .62711 .28198 .64531 .28162 .63656 .2745 Mtetra
.57 .822 .993 r
.63656 .2745 .64531 .28162 .66365 .28027 .65487 .27005 Mtetra
.683 .793 .932 r
.65487 .27005 .66365 .28027 .682 .27545 .67317 .2625 Mtetra
.728 .756 .874 r
.67317 .2625 .682 .27545 .70027 .26696 .69143 .25225 Mtetra
.714 .722 .856 r
.69143 .25225 .70027 .26696 .71851 .25637 .70979 .24231 Mtetra
.696 .727 .874 r
.70979 .24231 .71851 .25637 .73689 .24678 .72831 .23362 Mtetra
.662 .73 .9 r
.72831 .23362 .73689 .24678 .75548 .23886 .74706 .22675 Mtetra
.655 .75 .919 r
.74706 .22675 .75548 .23886 .77429 .23234 .76597 .2202 Mtetra
.655 .751 .92 r
.09982 .43852 .11083 .44815 .12576 .44294 .11479 .43331 Mtetra
.657 .752 .92 r
.11479 .43331 .12576 .44294 .14073 .43803 .12985 .42799 Mtetra
.636 .739 .923 r
.12985 .42799 .14073 .43803 .15559 .43489 .14492 .42339 Mtetra
.586 .694 .917 r
.14492 .42339 .15559 .43489 .17043 .43297 .15989 .42049 Mtetra
.556 .664 .909 r
.15989 .42049 .17043 .43297 .18535 .43137 .17487 .41857 Mtetra
.562 .662 .904 r
.17487 .41857 .18535 .43137 .20065 .42719 .18998 .41649 Mtetra
.636 .731 .917 r
.18998 .41649 .20065 .42719 .21633 .42002 .20547 .41178 Mtetra
.7 .801 .927 r
.20547 .41178 .21633 .42002 .23236 .40985 .22129 .40457 Mtetra
.761 .874 .93 r
.22129 .40457 .23236 .40985 .24848 .39918 .23743 .39475 Mtetra
.771 .895 .931 r
.23743 .39475 .24848 .39918 .2645 .39021 .25366 .38441 Mtetra
.742 .865 .937 r
.25366 .38441 .2645 .39021 .28047 .38272 .26983 .37535 Mtetra
.712 .828 .936 r
.26983 .37535 .28047 .38272 .29636 .37739 .28597 .36753 Mtetra
.676 .766 .919 r
.28597 .36753 .29636 .37739 .3123 .37275 .30209 .36112 Mtetra
.646 .723 .904 r
.30209 .36112 .3123 .37275 .32834 .36807 .31822 .35582 Mtetra
.638 .709 .898 r
.31822 .35582 .32834 .36807 .34451 .36314 .33444 .35078 Mtetra
.33444 .35078 .34451 .36314 .36079 .35801 .35076 .34571 Mtetra
.645 .713 .898 r
.35076 .34571 .36079 .35801 .37719 .35266 .36721 .34035 Mtetra
.648 .716 .897 r
.36721 .34035 .37719 .35266 .3937 .34706 .38377 .33482 Mtetra
.651 .719 .898 r
.38377 .33482 .3937 .34706 .41032 .34132 .40044 .32911 Mtetra
.655 .722 .898 r
.40044 .32911 .41032 .34132 .42704 .33549 .41722 .32321 Mtetra
.658 .724 .897 r
.41722 .32321 .42704 .33549 .44387 .32958 .43411 .31713 Mtetra
.661 .723 .895 r
.43411 .31713 .44387 .32958 .4608 .32352 .45111 .31087 Mtetra
.664 .721 .892 r
.45111 .31087 .4608 .32352 .47785 .31721 .46821 .30443 Mtetra
.669 .722 .889 r
.46821 .30443 .47785 .31721 .49499 .31068 .48542 .29769 Mtetra
.669 .72 .887 r
.48542 .29769 .49499 .31068 .51224 .30393 .50274 .29091 Mtetra
.663 .718 .89 r
.50274 .29091 .51224 .30393 .5296 .29693 .52015 .2844 Mtetra
.637 .719 .907 r
.52015 .2844 .5296 .29693 .54705 .28987 .53768 .27901 Mtetra
.594 .737 .944 r
.53768 .27901 .54705 .28987 .56461 .2835 .55534 .27506 Mtetra
.525 .766 .985 r
.55534 .27506 .56461 .2835 .58232 .27935 .57316 .27238 Mtetra
.43 .758 .995 r
.57316 .27238 .58232 .27935 .6002 .27672 .59117 .27103 Mtetra
.415 .783 .994 r
.59117 .27103 .6002 .27672 .6183 .27586 .60934 .26916 Mtetra
.564 .831 .996 r
.60934 .26916 .6183 .27586 .63656 .2745 .62759 .26463 Mtetra
.672 .798 .942 r
.62759 .26463 .63656 .2745 .65487 .27005 .64588 .2575 Mtetra
.723 .762 .883 r
.64588 .2575 .65487 .27005 .67317 .2625 .66416 .24763 Mtetra
.715 .721 .854 r
.66416 .24763 .67317 .2625 .69143 .25225 .68251 .23757 Mtetra
.699 .719 .865 r
.68251 .23757 .69143 .25225 .70979 .24231 .701 .22851 Mtetra
.669 .723 .889 r
.701 .22851 .70979 .24231 .72831 .23362 .71969 .22119 Mtetra
.655 .744 .916 r
.71969 .22119 .72831 .23362 .74706 .22675 .73856 .21462 Mtetra
.657 .753 .921 r
.73856 .21462 .74706 .22675 .76597 .2202 .75754 .20792 Mtetra
.653 .749 .92 r
.0887 .42872 .09982 .43852 .11479 .43331 .10371 .42351 Mtetra
.654 .751 .92 r
.10371 .42351 .11479 .43331 .12985 .42799 .11881 .41822 Mtetra
.656 .753 .921 r
.11881 .41822 .12985 .42799 .14492 .42339 .13401 .41284 Mtetra
.627 .73 .921 r
.13401 .41284 .14492 .42339 .15989 .42049 .14919 .40847 Mtetra
.586 .687 .911 r
.14919 .40847 .15989 .42049 .17487 .41857 .1643 .4055 Mtetra
.562 .659 .902 r
.1643 .4055 .17487 .41857 .18998 .41649 .17944 .40338 Mtetra
.571 .663 .9 r
.17944 .40338 .18998 .41649 .20547 .41178 .19473 .40096 Mtetra
.634 .732 .918 r
.19473 .40096 .20547 .41178 .22129 .40457 .21036 .39621 Mtetra
.69 .8 .933 r
.21036 .39621 .22129 .40457 .23743 .39475 .2263 .38929 Mtetra
.74 .873 .942 r
.2263 .38929 .23743 .39475 .25366 .38441 .2425 .38027 Mtetra
.757 .905 .942 r
.2425 .38027 .25366 .38441 .26983 .37535 .25884 .37039 Mtetra
.744 .888 .945 r
.25884 .37039 .26983 .37535 .28597 .36753 .27519 .36108 Mtetra
.717 .853 .947 r
.27519 .36108 .28597 .36753 .30209 .36112 .29151 .35294 Mtetra
.697 .812 .936 r
.29151 .35294 .30209 .36112 .31822 .35582 .30784 .34561 Mtetra
.675 .764 .918 r
.30784 .34561 .31822 .35582 .33444 .35078 .32421 .33908 Mtetra
.654 .729 .904 r
.32421 .33908 .33444 .35078 .35076 .34571 .34063 .33331 Mtetra
.65 .715 .896 r
.34063 .33331 .35076 .34571 .36721 .34035 .35714 .32767 Mtetra
.649 .711 .893 r
.35714 .32767 .36721 .34035 .38377 .33482 .37375 .32199 Mtetra
.651 .711 .891 r
.37375 .32199 .38377 .33482 .40044 .32911 .39048 .31619 Mtetra
.654 .711 .89 r
.39048 .31619 .40044 .32911 .41722 .32321 .40732 .31022 Mtetra
.657 .713 .889 r
.40732 .31022 .41722 .32321 .43411 .31713 .42426 .30409 Mtetra
.659 .714 .889 r
.42426 .30409 .43411 .31713 .45111 .31087 .44132 .29783 Mtetra
.659 .715 .89 r
.44132 .29783 .45111 .31087 .46821 .30443 .45848 .29153 Mtetra
.656 .718 .894 r
.45848 .29153 .46821 .30443 .48542 .29769 .47574 .28536 Mtetra
.637 .723 .909 r
.47574 .28536 .48542 .29769 .50274 .29091 .49311 .27996 Mtetra
.613 .743 .938 r
.49311 .27996 .50274 .29091 .52015 .2844 .51059 .27537 Mtetra
.573 .772 .973 r
.51059 .27537 .52015 .2844 .53768 .27901 .5282 .27161 Mtetra
.498 .781 .995 r
.5282 .27161 .53768 .27901 .55534 .27506 .54596 .26905 Mtetra
.43 .783 .997 r
.54596 .26905 .55534 .27506 .57316 .27238 .56389 .26709 Mtetra
.451 .811 .996 r
.56389 .26709 .57316 .27238 .59117 .27103 .58197 .26426 Mtetra
.582 .837 .993 r
.58197 .26426 .59117 .27103 .60934 .26916 .60016 .25928 Mtetra
.673 .799 .942 r
.60016 .25928 .60934 .26916 .62759 .26463 .61842 .25206 Mtetra
.719 .761 .886 r
.61842 .25206 .62759 .26463 .64588 .2575 .6367 .24243 Mtetra
.713 .718 .854 r
.6367 .24243 .64588 .2575 .66416 .24763 .65505 .23245 Mtetra
.698 .712 .859 r
.65505 .23245 .66416 .24763 .68251 .23757 .67352 .22333 Mtetra
.675 .719 .882 r
.67352 .22333 .68251 .23757 .701 .22851 .69217 .21565 Mtetra
.655 .738 .91 r
.69217 .21565 .701 .22851 .71969 .22119 .711 .20901 Mtetra
.657 .753 .921 r
.711 .20901 .71969 .22119 .73856 .21462 .72994 .20227 Mtetra
.658 .752 .919 r
.72994 .20227 .73856 .21462 .75754 .20792 .74901 .19542 Mtetra
.651 .747 .92 r
.07746 .41876 .0887 .42872 .10371 .42351 .0925 .41358 Mtetra
.654 .75 .92 r
.0925 .41358 .10371 .42351 .11881 .41822 .10766 .40823 Mtetra
.655 .75 .92 r
.10766 .40823 .11881 .41822 .13401 .41284 .12291 .40281 Mtetra
.654 .75 .921 r
.12291 .40281 .13401 .41284 .14919 .40847 .13825 .39742 Mtetra
.625 .722 .917 r
.13825 .39742 .14919 .40847 .1643 .4055 .15356 .39305 Mtetra
.591 .684 .906 r
.15356 .39305 .1643 .4055 .17944 .40338 .16883 .38986 Mtetra
.571 .658 .896 r
.16883 .38986 .17944 .40338 .19473 .40096 .18415 .3874 Mtetra
.575 .66 .895 r
.18415 .3874 .19473 .40096 .21036 .39621 .1996 .38476 Mtetra
.622 .719 .915 r
.1996 .38476 .21036 .39621 .2263 .38929 .21534 .38037 Mtetra
.674 .788 .935 r
.21534 .38037 .2263 .38929 .2425 .38027 .23137 .374 Mtetra
.707 .855 .953 r
.23137 .374 .2425 .38027 .25884 .37039 .24762 .36621 Mtetra
.734 .906 .954 r
.24762 .36621 .25884 .37039 .27519 .36108 .26405 .35706 Mtetra
.732 .911 .956 r
.26405 .35706 .27519 .36108 .29151 .35294 .28054 .34791 Mtetra
.721 .89 .958 r
.28054 .34791 .29151 .35294 .30784 .34561 .29706 .33932 Mtetra
.7 .86 .958 r
.29706 .33932 .30784 .34561 .32421 .33908 .31359 .33162 Mtetra
.687 .832 .953 r
.31359 .33162 .32421 .33908 .34063 .33331 .33016 .32445 Mtetra
.677 .799 .94 r
.33016 .32445 .34063 .33331 .35714 .32767 .3468 .31771 Mtetra
.668 .774 .929 r
.3468 .31771 .35714 .32767 .37375 .32199 .36352 .31128 Mtetra
.662 .758 .922 r
.36352 .31128 .37375 .32199 .39048 .31619 .38033 .30508 Mtetra
.656 .749 .919 r
.38033 .30508 .39048 .31619 .40732 .31022 .39723 .29904 Mtetra
.651 .748 .92 r
.39723 .29904 .40732 .31022 .42426 .30409 .41423 .29318 Mtetra
.644 .752 .928 r
.41423 .29318 .42426 .30409 .44132 .29783 .43134 .28753 Mtetra
.633 .763 .941 r
.43134 .28753 .44132 .29783 .45848 .29153 .44855 .28221 Mtetra
.615 .78 .96 r
.44855 .28221 .45848 .29153 .47574 .28536 .46587 .27731 Mtetra
.584 .801 .982 r
.46587 .27731 .47574 .28536 .49311 .27996 .4833 .27296 Mtetra
.53 .805 .996 r
.4833 .27296 .49311 .27996 .51059 .27537 .50087 .26952 Mtetra
.472 .808 .999 r
.50087 .26952 .51059 .27537 .5282 .27161 .51858 .26667 Mtetra
.44 .814 .993 r
.51858 .26667 .5282 .27161 .54596 .26905 .53644 .26382 Mtetra
.518 .845 .998 r
.53644 .26382 .54596 .26905 .56389 .26709 .55445 .25959 Mtetra
.616 .834 .983 r
.55445 .25959 .56389 .26709 .58197 .26426 .57258 .2539 Mtetra
.685 .794 .932 r
.57258 .2539 .58197 .26426 .60016 .25928 .5908 .24619 Mtetra
.715 .751 .881 r
.5908 .24619 .60016 .25928 .61842 .25206 .60907 .23664 Mtetra
.707 .712 .852 r
.60907 .23664 .61842 .25206 .6367 .24243 .62742 .2269 Mtetra
.694 .706 .857 r
.62742 .2269 .6367 .24243 .65505 .23245 .64588 .21788 Mtetra
.676 .715 .878 r
.64588 .21788 .65505 .23245 .67352 .22333 .66449 .21007 Mtetra
.657 .732 .905 r
.66449 .21007 .67352 .22333 .69217 .21565 .68328 .20332 Mtetra
.656 .751 .92 r
.68328 .20332 .69217 .21565 .711 .20901 .70219 .19657 Mtetra
.657 .751 .919 r
.70219 .19657 .711 .20901 .72994 .20227 .72122 .18974 Mtetra
.66 .752 .918 r
.72122 .18974 .72994 .20227 .74901 .19542 .74037 .18272 Mtetra
.654 .75 .921 r
.06609 .40878 .07746 .41876 .0925 .41358 .0812 .40343 Mtetra
.651 .747 .92 r
.0812 .40343 .0925 .41358 .10766 .40823 .09638 .39816 Mtetra
.655 .751 .92 r
.09638 .39816 .10766 .40823 .12291 .40281 .11168 .39269 Mtetra
.656 .751 .92 r
.11168 .39269 .12291 .40281 .13825 .39742 .12708 .38717 Mtetra
.654 .749 .92 r
.12708 .38717 .13825 .39742 .15356 .39305 .14256 .38169 Mtetra
.629 .721 .913 r
.14256 .38169 .15356 .39305 .16883 .38986 .15803 .37709 Mtetra
.599 .684 .902 r
.15803 .37709 .16883 .38986 .18415 .3874 .17349 .37357 Mtetra
.583 .661 .891 r
.17349 .37357 .18415 .3874 .1996 .38476 .18899 .37059 Mtetra
.579 .654 .888 r
.18899 .37059 .1996 .38476 .21534 .38037 .20461 .36777 Mtetra
.603 .693 .906 r
.20461 .36777 .21534 .38037 .23137 .374 .22043 .364 Mtetra
.653 .763 .93 r
.22043 .364 .23137 .374 .24762 .36621 .23655 .35833 Mtetra
.678 .817 .95 r
.23655 .35833 .24762 .36621 .26405 .35706 .25285 .35161 Mtetra
.693 .876 .967 r
.25285 .35161 .26405 .35706 .28054 .34791 .26931 .344 Mtetra
.703 .912 .967 r
.26931 .344 .28054 .34791 .29706 .33932 .28591 .33562 Mtetra
.695 .917 .97 r
.28591 .33562 .29706 .33932 .31359 .33162 .30258 .32735 Mtetra
.687 .905 .973 r
.30258 .32735 .31359 .33162 .33016 .32445 .3193 .31943 Mtetra
.677 .889 .975 r
.3193 .31943 .33016 .32445 .3468 .31771 .33608 .31198 Mtetra
.665 .872 .977 r
.33608 .31198 .3468 .31771 .36352 .31128 .35292 .30503 Mtetra
.651 .858 .978 r
.35292 .30503 .36352 .31128 .38033 .30508 .36983 .29856 Mtetra
.639 .85 .981 r
.36983 .29856 .38033 .30508 .39723 .29904 .38682 .29246 Mtetra
.625 .846 .984 r
.38682 .29246 .39723 .29904 .41423 .29318 .4039 .28673 Mtetra
.602 .843 .99 r
.4039 .28673 .41423 .29318 .43134 .28753 .42109 .28148 Mtetra
.572 .843 .996 r
.42109 .28148 .43134 .28753 .44855 .28221 .43837 .27674 Mtetra
.536 .844 .999 r
.43837 .27674 .44855 .28221 .46587 .27731 .45578 .27247 Mtetra
.498 .842 .996 r
.45578 .27247 .46587 .27731 .4833 .27296 .47331 .26858 Mtetra
.475 .842 .991 r
.47331 .26858 .4833 .27296 .50087 .26952 .49098 .2648 Mtetra
.522 .857 .995 r
.49098 .2648 .50087 .26952 .51858 .26667 .50881 .26024 Mtetra
.595 .85 .993 r
.50881 .26024 .51858 .26667 .53644 .26382 .52676 .25479 Mtetra
.653 .811 .959 r
.52676 .25479 .53644 .26382 .55445 .25959 .54484 .24825 Mtetra
.7 .779 .912 r
.54484 .24825 .55445 .25959 .57258 .2539 .56302 .23976 Mtetra
.709 .732 .869 r
.56302 .23976 .57258 .2539 .5908 .24619 .58127 .23028 Mtetra
.698 .702 .85 r
.58127 .23028 .5908 .24619 .60907 .23664 .59962 .22093 Mtetra
.689 .703 .857 r
.59962 .22093 .60907 .23664 .62742 .2269 .61807 .21213 Mtetra
.673 .712 .878 r
.61807 .21213 .62742 .2269 .64588 .21788 .63666 .20442 Mtetra
.657 .729 .903 r
.63666 .20442 .64588 .21788 .66449 .21007 .6554 .19761 Mtetra
.656 .75 .919 r
.6554 .19761 .66449 .21007 .68328 .20332 .67427 .19084 Mtetra
.656 .752 .92 r
.67427 .19084 .68328 .20332 .70219 .19657 .69327 .184 Mtetra
.66 .753 .919 r
.69327 .184 .70219 .19657 .72122 .18974 .71238 .17695 Mtetra
.658 .749 .917 r
.71238 .17695 .72122 .18974 .74037 .18272 .73163 .16996 Mtetra
.659 .755 .92 r
.05456 .39886 .06609 .40878 .0812 .40343 .06975 .39324 Mtetra
.653 .749 .92 r
.06975 .39324 .0812 .40343 .09638 .39816 .085 .38783 Mtetra
.651 .747 .92 r
.085 .38783 .09638 .39816 .11168 .39269 .10033 .38244 Mtetra
.655 .751 .92 r
.10033 .38244 .11168 .39269 .12708 .38717 .11578 .37688 Mtetra
.656 .751 .92 r
.11578 .37688 .12708 .38717 .14256 .38169 .13132 .37127 Mtetra
.655 .75 .92 r
.13132 .37127 .14256 .38169 .15803 .37709 .14695 .36564 Mtetra
.638 .725 .912 r
.14695 .36564 .15803 .37709 .17349 .37357 .16261 .36062 Mtetra
.609 .688 .899 r
.16261 .36062 .17349 .37357 .18899 .37059 .17826 .35665 Mtetra
.598 .668 .888 r
.17826 .35665 .18899 .37059 .20461 .36777 .19397 .35304 Mtetra
.586 .651 .881 r
.19397 .35304 .20461 .36777 .22043 .364 .20976 .34987 Mtetra
.596 .666 .888 r
.20976 .34987 .22043 .364 .23655 .35833 .22571 .34628 Mtetra
.62 .714 .913 r
.22571 .34628 .23655 .35833 .25285 .35161 .24187 .34175 Mtetra
.653 .771 .936 r
.24187 .34175 .25285 .35161 .26931 .344 .25825 .33592 Mtetra
.666 .815 .955 r
.25825 .33592 .26931 .344 .28591 .33562 .27478 .32947 Mtetra
.667 .861 .973 r
.27478 .32947 .28591 .33562 .30258 .32735 .29143 .32264 Mtetra
.658 .892 .981 r
.29143 .32264 .30258 .32735 .3193 .31943 .30819 .31561 Mtetra
.649 .909 .981 r
.30819 .31561 .3193 .31943 .33608 .31198 .32505 .3084 Mtetra
.63 .909 .982 r
.32505 .3084 .33608 .31198 .35292 .30503 .34199 .30147 Mtetra
.611 .905 .984 r
.34199 .30147 .35292 .30503 .36983 .29856 .35901 .2949 Mtetra
.592 .898 .987 r
.35901 .2949 .36983 .29856 .38682 .29246 .37611 .28873 Mtetra
.571 .891 .988 r
.37611 .28873 .38682 .29246 .4039 .28673 .3933 .28297 Mtetra
.55 .883 .988 r
.3933 .28297 .4039 .28673 .42109 .28148 .4106 .27758 Mtetra
.536 .876 .989 r
.4106 .27758 .42109 .28148 .43837 .27674 .428 .27247 Mtetra
.551 .876 .992 r
.428 .27247 .43837 .27674 .45578 .27247 .44553 .26719 Mtetra
.581 .868 .995 r
.44553 .26719 .45578 .27247 .47331 .26858 .4632 .2617 Mtetra
.618 .847 .986 r
.4632 .2617 .47331 .26858 .49098 .2648 .48099 .25582 Mtetra
.652 .812 .96 r
.48099 .25582 .49098 .2648 .50881 .26024 .49892 .24931 Mtetra
.687 .782 .923 r
.49892 .24931 .50881 .26024 .52676 .25479 .51696 .24147 Mtetra
.7 .743 .884 r
.51696 .24147 .52676 .25479 .54484 .24825 .5351 .23266 Mtetra
.698 .707 .854 r
.5351 .23266 .54484 .24825 .56302 .23976 .55334 .2234 Mtetra
.687 .692 .849 r
.55334 .2234 .56302 .23976 .58127 .23028 .57167 .21457 Mtetra
.683 .701 .861 r
.57167 .21457 .58127 .23028 .59962 .22093 .5901 .2061 Mtetra
.666 .709 .88 r
.5901 .2061 .59962 .22093 .61807 .21213 .60866 .19869 Mtetra
.655 .731 .905 r
.60866 .19869 .61807 .21213 .63666 .20442 .62737 .1919 Mtetra
.656 .75 .919 r
.62737 .1919 .63666 .20442 .6554 .19761 .6462 .18508 Mtetra
.656 .752 .92 r
.6462 .18508 .6554 .19761 .67427 .19084 .66515 .1782 Mtetra
.66 .752 .919 r
.66515 .1782 .67427 .19084 .69327 .184 .68423 .17112 Mtetra
.658 .749 .917 r
.68423 .17112 .69327 .184 .71238 .17695 .70344 .16406 Mtetra
.653 .748 .92 r
.70344 .16406 .71238 .17695 .73163 .16996 .72279 .1572 Mtetra
.659 .754 .92 r
.04291 .38882 .05456 .39886 .06975 .39324 .05815 .38314 Mtetra
.659 .755 .921 r
.05815 .38314 .06975 .39324 .085 .38783 .07348 .37744 Mtetra
.653 .748 .92 r
.07348 .37744 .085 .38783 .10033 .38244 .08887 .37194 Mtetra
.651 .747 .92 r
.08887 .37194 .10033 .38244 .11578 .37688 .10435 .36645 Mtetra
.655 .751 .92 r
.10435 .36645 .11578 .37688 .13132 .37127 .11994 .36079 Mtetra
.655 .751 .921 r
.11994 .36079 .13132 .37127 .14695 .36564 .13563 .35512 Mtetra
.657 .752 .92 r
.13563 .35512 .14695 .36564 .16261 .36062 .15142 .3493 Mtetra
.647 .734 .913 r
.15142 .3493 .16261 .36062 .17826 .35665 .16727 .34384 Mtetra
.624 .7 .9 r
.16727 .34384 .17826 .35665 .19397 .35304 .18313 .3392 Mtetra
.61 .678 .889 r
.18313 .3392 .19397 .35304 .20976 .34987 .19905 .33504 Mtetra
.605 .66 .878 r
.19905 .33504 .20976 .34987 .22571 .34628 .21507 .33105 Mtetra
.598 .652 .875 r
.21507 .33105 .22571 .34628 .24187 .34175 .23118 .32728 Mtetra
.608 .67 .884 r
.23118 .32728 .24187 .34175 .25825 .33592 .24745 .32309 Mtetra
.622 .705 .905 r
.24745 .32309 .25825 .33592 .27478 .32947 .26388 .31835 Mtetra
.64 .746 .926 r
.26388 .31835 .27478 .32947 .29143 .32264 .28049 .3129 Mtetra
.652 .78 .942 r
.28049 .3129 .29143 .32264 .30819 .31561 .29724 .30689 Mtetra
.655 .805 .955 r
.29724 .30689 .30819 .31561 .32505 .3084 .31411 .30068 Mtetra
.652 .828 .968 r
.31411 .30068 .32505 .3084 .34199 .30147 .3311 .29438 Mtetra
.646 .842 .976 r
.3311 .29438 .34199 .30147 .35901 .2949 .34819 .28809 Mtetra
.64 .848 .98 r
.34819 .28809 .35901 .2949 .37611 .28873 .36538 .28186 Mtetra
.636 .847 .981 r
.36538 .28186 .37611 .28873 .3933 .28297 .38268 .27568 Mtetra
.638 .84 .978 r
.38268 .27568 .3933 .28297 .4106 .27758 .40009 .26951 Mtetra
.644 .826 .97 r
.40009 .26951 .4106 .27758 .428 .27247 .41762 .26326 Mtetra
.654 .805 .955 r
.41762 .26326 .428 .27247 .44553 .26719 .43527 .2568 Mtetra
.67 .786 .936 r
.43527 .2568 .44553 .26719 .4632 .2617 .45305 .24977 Mtetra
.684 .761 .91 r
.45305 .24977 .4632 .2617 .48099 .25582 .47095 .24201 Mtetra
.69 .73 .881 r
.47095 .24201 .48099 .25582 .49892 .24931 .48896 .23367 Mtetra
.69 .702 .857 r
.48896 .23367 .49892 .24931 .51696 .24147 .50706 .2249 Mtetra
.682 .687 .848 r
.50706 .2249 .51696 .24147 .5351 .23266 .52527 .21634 Mtetra
.68 .691 .853 r
.52527 .21634 .5351 .23266 .55334 .2234 .54357 .20794 Mtetra
.674 .703 .868 r
.54357 .20794 .55334 .2234 .57167 .21457 .56198 .2 Mtetra
.66 .713 .887 r
.56198 .2 .57167 .21457 .5901 .2061 .58051 .19291 Mtetra
.654 .736 .91 r
.58051 .19291 .5901 .2061 .60866 .19869 .59918 .18617 Mtetra
.657 .752 .92 r
.59918 .18617 .60866 .19869 .62737 .1919 .61796 .17928 Mtetra
.656 .751 .92 r
.61796 .17928 .62737 .1919 .6462 .18508 .63688 .17236 Mtetra
.66 .752 .919 r
.63688 .17236 .6462 .18508 .66515 .1782 .65591 .16525 Mtetra
.658 .749 .917 r
.65591 .16525 .66515 .1782 .68423 .17112 .67508 .15814 Mtetra
.653 .748 .919 r
.67508 .15814 .68423 .17112 .70344 .16406 .69439 .15123 Mtetra
.653 .753 .923 r
.69439 .15123 .70344 .16406 .72279 .1572 .71384 .14428 Mtetra
.656 .752 .92 r
.03115 .37856 .04291 .38882 .05815 .38314 .04642 .37294 Mtetra
.659 .755 .921 r
.04642 .37294 .05815 .38314 .07348 .37744 .0618 .36717 Mtetra
.0618 .36717 .07348 .37744 .08887 .37194 .07727 .36137 Mtetra
.653 .748 .92 r
.07727 .36137 .08887 .37194 .10435 .36645 .09281 .35575 Mtetra
.652 .747 .919 r
.09281 .35575 .10435 .36645 .11994 .36079 .10844 .35015 Mtetra
.655 .75 .92 r
.10844 .35015 .11994 .36079 .13563 .35512 .12418 .34441 Mtetra
.12418 .34441 .13563 .35512 .15142 .3493 .14002 .33862 Mtetra
.657 .752 .92 r
.14002 .33862 .15142 .3493 .16727 .34384 .15597 .33272 Mtetra
.654 .744 .916 r
.15597 .33272 .16727 .34384 .18313 .3392 .172 .32691 Mtetra
.643 .72 .904 r
.172 .32691 .18313 .3392 .19905 .33504 .1881 .32141 Mtetra
.624 .69 .891 r
.1881 .32141 .19905 .33504 .21507 .33105 .20423 .31661 Mtetra
.618 .676 .882 r
.20423 .31661 .21507 .33105 .23118 .32728 .22045 .31197 Mtetra
.617 .662 .872 r
.22045 .31197 .23118 .32728 .24745 .32309 .23679 .30734 Mtetra
.614 .655 .867 r
.23679 .30734 .24745 .32309 .26388 .31835 .25323 .30277 Mtetra
.618 .661 .869 r
.25323 .30277 .26388 .31835 .28049 .3129 .26981 .29802 Mtetra
.626 .676 .878 r
.26981 .29802 .28049 .3129 .29724 .30689 .28654 .29292 Mtetra
.634 .696 .89 r
.28654 .29292 .29724 .30689 .31411 .30068 .3034 .28747 Mtetra
.642 .714 .899 r
.3034 .28747 .31411 .30068 .3311 .29438 .32041 .2817 Mtetra
.649 .727 .906 r
.32041 .2817 .3311 .29438 .34819 .28809 .33754 .27565 Mtetra
.654 .735 .909 r
.33754 .27565 .34819 .28809 .36538 .28186 .35479 .26934 Mtetra
.659 .736 .907 r
.35479 .26934 .36538 .28186 .38268 .27568 .37217 .26277 Mtetra
.664 .732 .9 r
.37217 .26277 .38268 .27568 .40009 .26951 .38968 .25592 Mtetra
.669 .723 .89 r
.38968 .25592 .40009 .26951 .41762 .26326 .4073 .24874 Mtetra
.673 .71 .876 r
.4073 .24874 .41762 .26326 .43527 .2568 .42504 .2412 Mtetra
.675 .696 .861 r
.42504 .2412 .43527 .2568 .45305 .24977 .44289 .2333 Mtetra
.675 .684 .851 r
.44289 .2333 .45305 .24977 .47095 .24201 .46085 .22521 Mtetra
.672 .679 .849 r
.46085 .22521 .47095 .24201 .48896 .23367 .47891 .21717 Mtetra
.673 .685 .853 r
.47891 .21717 .48896 .23367 .50706 .2249 .49707 .20912 Mtetra
.672 .697 .864 r
.49707 .20912 .50706 .2249 .52527 .21634 .51533 .20122 Mtetra
.66 .704 .879 r
.51533 .20122 .52527 .21634 .54357 .20794 .53371 .19403 Mtetra
.656 .724 .899 r
.53371 .19403 .54357 .20794 .56198 .2 .5522 .18716 Mtetra
.655 .744 .916 r
.5522 .18716 .56198 .2 .58051 .19291 .57082 .18036 Mtetra
.656 .752 .921 r
.57082 .18036 .58051 .19291 .59918 .18617 .58957 .17344 Mtetra
.657 .751 .919 r
.58957 .17344 .59918 .18617 .61796 .17928 .60844 .16646 Mtetra
.659 .752 .918 r
.60844 .16646 .61796 .17928 .63688 .17236 .62744 .15932 Mtetra
.658 .749 .917 r
.62744 .15932 .63688 .17236 .65591 .16525 .64656 .15219 Mtetra
.653 .748 .919 r
.64656 .15219 .65591 .16525 .67508 .15814 .66583 .14524 Mtetra
.653 .753 .923 r
.66583 .14524 .67508 .15814 .69439 .15123 .68523 .13824 Mtetra
.656 .754 .922 r
.68523 .13824 .69439 .15123 .71384 .14428 .70476 .13108 Mtetra
.654 .75 .92 r
.01926 .36811 .03115 .37856 .04642 .37294 .03457 .3625 Mtetra
.656 .752 .92 r
.03457 .3625 .04642 .37294 .0618 .36717 .04998 .35678 Mtetra
.659 .755 .921 r
.04998 .35678 .0618 .36717 .07727 .36137 .06551 .35093 Mtetra
.06551 .35093 .07727 .36137 .09281 .35575 .08113 .34503 Mtetra
.655 .75 .92 r
.08113 .34503 .09281 .35575 .10844 .35015 .09683 .33925 Mtetra
.652 .747 .919 r
.09683 .33925 .10844 .35015 .12418 .34441 .11261 .33354 Mtetra
.653 .749 .92 r
.11261 .33354 .12418 .34441 .14002 .33862 .1285 .32774 Mtetra
.655 .751 .92 r
.1285 .32774 .14002 .33862 .15597 .33272 .14449 .32184 Mtetra
.655 .752 .921 r
.14449 .32184 .15597 .33272 .172 .32691 .16059 .31591 Mtetra
.657 .752 .919 r
.16059 .31591 .172 .32691 .1881 .32141 .1768 .30985 Mtetra
.653 .74 .914 r
.1768 .30985 .1881 .32141 .20423 .31661 .19309 .30389 Mtetra
.646 .718 .9 r
.19309 .30389 .20423 .31661 .22045 .31197 .20947 .29813 Mtetra
.635 .695 .889 r
.20947 .29813 .22045 .31197 .23679 .30734 .22591 .29274 Mtetra
.63 .682 .881 r
.22591 .29274 .23679 .30734 .25323 .30277 .24245 .28747 Mtetra
.629 .672 .872 r
.24245 .28747 .25323 .30277 .26981 .29802 .25911 .28215 Mtetra
.631 .665 .865 r
.25911 .28215 .26981 .29802 .28654 .29292 .2759 .2767 Mtetra
.633 .662 .86 r
.2759 .2767 .28654 .29292 .3034 .28747 .29281 .27105 Mtetra
.637 .662 .857 r
.29281 .27105 .3034 .28747 .32041 .2817 .30985 .26517 Mtetra
.641 .663 .856 r
.30985 .26517 .32041 .2817 .33754 .27565 .32702 .25904 Mtetra
.645 .665 .854 r
.32702 .25904 .33754 .27565 .35479 .26934 .34432 .25265 Mtetra
.65 .667 .853 r
.34432 .25265 .35479 .26934 .37217 .26277 .36175 .246 Mtetra
.654 .668 .852 r
.36175 .246 .37217 .26277 .38968 .25592 .37929 .23909 Mtetra
.657 .67 .851 r
.37929 .23909 .38968 .25592 .4073 .24874 .39696 .23195 Mtetra
.66 .673 .851 r
.39696 .23195 .4073 .24874 .42504 .2412 .41473 .22461 Mtetra
.663 .678 .854 r
.41473 .22461 .42504 .2412 .44289 .2333 .43263 .21712 Mtetra
.665 .686 .86 r
.43263 .21712 .44289 .2333 .46085 .22521 .45063 .20956 Mtetra
.664 .695 .869 r
.45063 .20956 .46085 .22521 .47891 .21717 .46873 .20213 Mtetra
.658 .704 .881 r
.46873 .20213 .47891 .21717 .49707 .20912 .48695 .19507 Mtetra
.656 .721 .897 r
.48695 .19507 .49707 .20912 .51533 .20122 .50528 .1882 Mtetra
.654 .741 .913 r
.50528 .1882 .51533 .20122 .53371 .19403 .52373 .18143 Mtetra
.657 .751 .92 r
.52373 .18143 .53371 .19403 .5522 .18716 .54231 .17451 Mtetra
.656 .752 .92 r
.54231 .17451 .5522 .18716 .57082 .18036 .56101 .16757 Mtetra
.658 .752 .919 r
.56101 .16757 .57082 .18036 .58957 .17344 .57984 .1605 Mtetra
.659 .751 .918 r
.57984 .1605 .58957 .17344 .60844 .16646 .59879 .15334 Mtetra
.657 .748 .917 r
.59879 .15334 .60844 .16646 .62744 .15932 .61788 .14622 Mtetra
.653 .749 .92 r
.61788 .14622 .62744 .15932 .64656 .15219 .6371 .13923 Mtetra
.653 .753 .923 r
.6371 .13923 .64656 .15219 .66583 .14524 .65646 .13218 Mtetra
.656 .754 .922 r
.65646 .13218 .66583 .14524 .68523 .13824 .67595 .12497 Mtetra
.657 .752 .92 r
.67595 .12497 .68523 .13824 .70476 .13108 .69557 .11764 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
[(-2)] .12586 .2075 1 .99877 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.56863 .04703 m
.57247 .05235 L
s
[(2)] .56094 .0364 .72324 1 Mshowa
.125 Mabswid
.18558 .19702 m
.18832 .19985 L
s
.23703 .17687 m
.23971 .17975 L
s
.28951 .15632 m
.29214 .15925 L
s
.39772 .11395 m
.40023 .11699 L
s
.4535 .09211 m
.45595 .0952 L
s
.51046 .06981 m
.51284 .07294 L
s
.08568 .23614 m
.08851 .23887 L
s
.62804 .02377 m
.63027 .02701 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 233.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00o?ooool2o`0006[ooooo003iooooo`?o000000?oooooo`000?ooool0
JOooool00?Oooooo0_l00004ooooo`;o0000JOooool00?Cooooo0ol00006ooooo`03o`000?oooooo
000006Sooooo003;ooooo`Go00008_ooool2o`0000Wooooo00?o0000ooooool00000J?ooool00<_o
oooo00GoV9RHob4Q8Oo^k^koooooodA4A00Oooooo`?o00002oooool01?l0003oooooooooool0001W
ooooo`00c?ooool00onHV9So8B4Qonk^kP0Mooooo`?o00003_ooool01Ol0003ooooooooooooooooo
000006Kooooo003=ooooo`03oiRHV?lQ8B7ok^k^01[ooooo0_l0000Aooooo`05o`000?oooooooooo
ooooool00000I_ooool00<kooooo00?oMgMgofIVI_ooool05_ooool3o`0001?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1Sooooo`00coooool00ol0003oooooooooo`0Cooooo`;o
00000_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0H_ooool00<_ooooo00Go0000okZj^_ooooooV9RHoa0@400Booooo`?o00006Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo06;ooooo003;ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`04?ooool2o`0001cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Qooooo`00
gOooool3o`0001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Qooooo`00fooo
ool2o`00027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Pooooo`00f?ooool3
o`0002?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Oooooo`00eOooool3o`00
02Kooooo00?o0000ooooooooool01?ooool2o`00067ooooo003Cooooo`;o0000:Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo05kooooo003@ooooo`?o000000?oooooo`000?ooool0
:?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05gooooo003>ooooo`;o00001Ooo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0GOoo
ool00<_ooooo0ol0000`ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0G?ooool0
0<Wooooo0_l0000cooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Foooool00<Ko
oooo0ol0000eooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Foooool00<Cooooo
0_l0000hooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0F_ooool00<7ooooo0ol0
000jooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03_ooool5o`0004Kooooo002n
ooooo`?o0000?Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00kooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A016ooooo`00_?ooool2o`0000?ooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo1_l00003ooooo`03oiRHV?lQ8B7o
k^k^04Oooooo002iooooo`?o0000@oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00kooooo00?oV9RHob4Q8Oo^k^h0A_ooool00;Oooooo0_l00016ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03oooool00omgMgOoIVIVooooo`15ooooo`00]?ooool3o`0004Sooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Cooooo
002booooo`;o0000Boooool00ol0003oooooooooo`0=ooooo`;o00003?ooool01Ol0003o^[Zjoooo
oonHV9So410@04Kooooo002_ooooo`?o0000COooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c016ooooo`00[Oooool2o`00053ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`1Dooooo`00Z_ooool4o`00057ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1Dooooo`00Z?ooool2o`0000Cooooo00?o0000oooo
ooooool0C_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05?ooooo001nooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h08_ooool3o`0005Oooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`1Booooo`00O_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01oooooo0ol0001Joooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool0D_ooool007kooooo00Go410@oooooooo
oooooooooa0@400Mooooo`;o0000GOooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
057ooooo001nooooo`05o`000?ooooooooooooooool000006_ooool3o`0005oooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`1@ooooo`00O_ooool01Ol0003ooooooooooooooooo0000
01Sooooo0_l0001Rooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0D?ooool007ko
oooo00Go410@oooooooooooooooooa0@400Eooooo`?o0000I?ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo04oooooo001nooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool2o`00
00?ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
04kooooo001nooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04?ooool3o`0006Sooooo00?oZ<3[o`00
0?ooool05_ooool00ol0003oooooooooo`1>ooooo`00TOooool2o`0006Sooooo1?nX`>/00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo04gooooo002>ooooo`?o0000J?ooool7ojS0j`03o`00
0?oooooooooo01Cooooo0ol0001>ooooo`00Roooool3o`0006Wooooo0_nW`N`7ojS0j`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool0C?ooool008Wooooo0_l0001Yooooo`KoYl7/1_nX`>/0
0ol0003oZ<3[ooooo`0Gooooo`03o`000?oooooooooo04_ooooo0026ooooo`?o0000J?ooool00onW
`>coYl7/ojO1k007ojO1k0GoZ<3[00?o0000ojO1k?ooool06?ooool00ol0003oooooooooo`1:oooo
o`00Q?ooool2o`0000;ooooo00?o0000ooooooooool0Hoooool5ojO0k0WoYl7/0_nX`>/2ojO1k003
o`000?nW`NcoYl7/01Sooooo00?o0000ooooooooool0B_ooool0087ooooo0ol00005ooooo`03o`00
0?oooooooooo063ooooo2?nW`>`7ojO1k003ojO0k?nW`NcoYl7/00;oYl7/00Co0000ojO1k?nW`Nco
Yl7/6?ooool00ol0003oooooooooo`19ooooo`00Ooooool2o`0006Wooooo00?oYko[ojO0k?nW`>`0
1onW`>`4ojO1k0GoYl3/0onW`N`00ol0003oYl7/ojO1k002ojO1k1Sooooo00?o0000ooooooooool0
B?ooool007cooooo0ol0001Xooooo`GoYko[2OnW`>`00onW`NcoYl3/ojO0k006ojO0k0;oYl7/00Go
0000ojO1k?nW`NcoYl7/ojO0k00Hooooo`03o`000?oooooooooo04Sooooo001jooooo`;o0000Iooo
ool2ojRojPSoYko[1_nW`>`2ojNoj`WoYl3/0_nW`N`00ol0003oYl7/ojO0k003ojO0k1Sooooo00?o
0000ooooooooool0Aoooool007Oooooo0ol0001Vooooo`KoZ;oZ2?nW_n/2ojO0k0KoYko[2OnW`>`0
0onW`Nco0000ojO0k005ojO0k1Sooooo00?o0000ooooooooool0A_ooool007Cooooo0ol0001Voooo
o`03ojS0jonX_n[oZ;oZ00OoZ;oZ1_nW_n/2ojRojPSoYko[1_nW`>`2ojNoj`03ojO0k?l0003oYl3/
00GoYl3/6?ooool00ol0003oooooooooo`16ooooo`00L_ooool2o`0000;ooooo00?o0000oooooooo
ool0H_ooool4ojS0j`WoZ;oZ0_nW_n/6ojRojPSoYko[0_nW`>`6ojNoj`03o`000?nW`>coYl3/00Go
Yl3/6?ooool00ol0003oooooooooo`15ooooo`00Koooool3o`0006Oooooo1onX`>/7ojRojP03ojS0
jonX_n[oZ;oZ00OoZ;oZ1_nW_n/00onX_n[oYko[ojNoj`06ojNoj`03o`000?nW`>coYl3/00CoYl3/
00?oYko[ooooooooool05_ooool00ol0003oooooooooo`15ooooo`00KOooool2o`0006Oooooo2_nX
`>/4ojRojPGoZ<3[2OnX_nX2ojNoj`GoZ;oZ1onW_n/01?l0003oYko[ojO0k?nW`>`5ojNojaOooooo
0_l00016ooooo`00J_ooool3o`0006Kooooo3_nX`>/00onX_n[oZ<3[ojS0j`06ojS0j`OoZ;oZ00?o
Z<3[ojRoj_nX_nX01_nX_nX6ojNoj`03o`000?nX_n[oYko[00OoYko[6?ooool00ol0003ooooooooo
o`13ooooo`00J?ooool2o`0006Kooooo00?oYl3[ojS0jonX`>/05onX`>/4ojRojPGoZ<3[2?nX_nX2
ojNoj`?oZ;oZ00?o0000ojRoj_nX_nX02?nW_n/Gooooo`03o`000?oooooooooo04?ooooo001Uoooo
o`?o0000I_ooool4ojO0jaWoZ<3[00?oZ;oZojS0jonX`>/01_nX`>/6ojRojP03ojS0jonX_n[oZ;oZ
00?oZ;oZ00Co0000ojRoj_nX_n[oZ;oZ1_nW_n/00onX_n[oooooooooo`0Fooooo`03o`000?oooooo
oooo04;ooooo001Sooooo`;o0000Ioooool7ojO0j`OoZ<3[00?oYl3[ojS0jonX`>/03OnX`>/00onW
`>_oZ<3[ojS0j`07ojS0j`CoZ;oZ1?nX`>/5ojRojP04o`000?nX_n[oZ;oZojRojP;oYko[1OnX_nXH
ooooo`03o`000?oooooooooo047ooooo001Pooooo`?o000000?oooooo`000?ooool0I?ooool00onX
`>_oYl3[ojO0j`07ojO0j`CoZ<3[1?nW`>/;ojS0j`GoYl3[2OnX`>/00onX_n[oZ<3[ojS0j`05ojS0
j`CoZ;oZ00Co0000ojRoj_nX_n[oZ<3[2?nX_nXGooooo`03o`000?oooooooooo047ooooo000foooo
o`Go00008oooool2o`0006Oooooo1OnX`>/9ojO0j`03ojS0jonW`>_oYl3[00GoYl3[2?nX`>/8ojO0
j`KoZ<3[0_nW`>/8ojS0j`CoZ;oZ00?o0000ojS0jonX`>/00_nX`>/8ojRojQOooooo00?o0000oooo
ooooool0@?ooool003Kooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Pooooo`?o0000IOooool2ojNm
j@SoZ<3[1_nW`>/2ojNnjPWoYl3[2?nX`>/8ojO0j`;oZ<3[1_nW`>/8ojS0j`04ojRoj_nX`>_oZ<3[
o`0000GoZ<3[1_nX_nX00onX`>_oooooooooo`0Fooooo`03o`000?oooooooooo03oooooo000^oooo
o`Ko00000oooool00onHV9So8B4Qonk^kP0Nooooo`?o0000IOooool6ojNmj@SoZ<3[0_nW`>/6ojNn
jPOoYl3[00?oYkcXojS0jonX`>/01onX`>/6ojO0j`03ojNojonW`>_oYl3[00OoYl3[1_nX`>/01OnW
`>_oZ<3[ojS0jonX`>_o000000GoZ<3[1?nX_nX4ojS0jaOooooo00?o0000ooooooooool0?oooool0
03Sooooo00?oV9RHob4Q8Oo^k^h06oooool2o`0006Gooooo00?oYkSUojNmjOnW_NT01onW_NT6ojS0
j`;oYkWV2?nW_^X4ojO0j`CoYkcX2OnX`>/2ojO0j`GoYko[2OnW`>/2ojS0j`GoYl3[0_nX`>/00ol0
003oZ<3[ojS0j`04ojS0j`03ojRoj_nX`>_oZ<3[00GoZ<3[5oooool00ol0003oooooooooo`0noooo
o`00>Oooool00omgMgOoIVIVooooo`0Gooooo`?o0000IOooool4ojNhi@WoYkgY0_nX`>/6ojNiiPSo
YkkZ00?oYl3[ojNlj?nW_>P01OnW_>P7ojS0j`03ojNkionW_n_oYko[00KoYko[1_nW`>/2ojNoj`So
Yl3[00?oZ<3[o`000?nX`>/03OnX`>/Hooooo`03o`000?oooooooooo03gooooo000jooooo`03o`00
0?oooooooooo01Cooooo0_l0001Vooooo`OoYkSU1onW_NT00onX]>7oYkWVojNiiP07ojNiiPKoYkkZ
00?oZ;KSojNlj?nW_>P01onW_>P4ojS0j`CoYk_W2?nW_n/2ojO0j`KoYko[2?nW`>/00ol0003oZ<3[
ojS0j`0=ojS0jaOooooo00?o0000ooooooooool0?Oooool003Kooooo00Go0000okZj^_ooooooV9RH
oa0@400Cooooo`?o00000_ooool00ol0003oooooooooo`1Qooooo`;oZ;CQ2?nW^>D4ojNmj@CoZ;CQ
2OnW^NH2ojNnjPGoZ;KS2OnW_>P00onX`>_oYk_WojNki`05ojNki`KoYko[00?oZ;[WojNojonW_n/0
1onW_n/7ojO0j`03o`000?nX`>_oZ<3[00goZ<3[6?ooool00ol0003oooooooooo`0looooo`00=_oo
ool01OnHV9So410@o`000?lQ8B7oc<c<017ooooo0_l0001Vooooo`KoZ;CQ2?nW^>D00onW_NWoZ;CQ
ojRdh@05ojRdh@OoYkWV00?o[;?NojRfhonX]^<01_nX]^<6ojNlj0;oZ[GQ2?nW^nL4ojNoj`CoZ;[W
2OnW_n/6ojO0j`03o`000?nX`>_oZ<3[00koZ<3[5_ooool3o`0003gooooo0019ooooo`?o0000IOoo
ool00onY/MkoZ;CQojRdh@07ojRdh@KoYkSU00?o[;;MojRdhOnX]>401_nX]>44ojNiiPGo[;?N2?nX
]^<2ojNlj0KoZ[GQ2?nW^nL00onW_n_oZ;[WojRji`05ojRji`OoYko[00?oZ;_WojO0jonW`>/01?nW
`>/00ol0003oYl3[ojS0j`0?ojS0jaOooooo00?o0000ooooooooool0>oooool004Oooooo0_l0001U
ooooo`GoZK7N2OnX]>42ojNhi@Go[;;M2?nX]>400onW^NKo[;?NojbcgP06ojbcgPKoZ;KS00?o[[?L
ojZehOnZ]N401onZ]N46ojNki`03ojbfh?nX^^OoZ;[W00KoZ;[W1?nW_n/5ojRki`GoYl3[00?o0000
ojO0jonW`>/04?nX`>/Gooooo`03o`000?oooooooooo03[ooooo0014ooooo`?o0000I?ooool00onZ
[mcoZK7NojVagP06ojVagPOoZ;CQ00?o[:oJojbbgOn//]d01_n//]d6ojRdh@03ojj`f_n//mko[;?N
00Oo[;?N1?nX]^<4ojjcg0WoZ[GQ0_nW^nL5ojbfh0SoZ;[W00?oYko[ojRkionX^nL01_nX^nL4ojO0
j`03o`000?nW`>_oYkcX013oZ<3[6?ooool00ol0003oooooooooo`0iooooo`00@Oooool3o`0006Go
oooo1?nZ[m`7ojVagPCoZ;CQ1On/[mX7ojbbg@CoZ;CQ1?n^/=X9ojbcgP03ojRfhon^/mco[[?L00Go
[[?L1onZ]N400on`/m_o[;KPojbfh006ojbfh0KoZ;[W0_n]]n09ojRki`;oYl3[00?oYkcXo`000?nW
_>P00_nW_>P@ojS0jaOooooo00?o0000ooooooooool0>Oooool003oooooo0ol0001Uooooo`KoZZoL
2?nY/Mh00onX]>7o[:oJojb_fP05ojb_fPSo[;;M00?oZ;CQojj`f_n^/=X01On^/=X7ojbcgP03ojna
fOn^/mco[[?L00Ko[[?L1?nZ]N45ok2cf`So[;KP0_nX^^L6ojfgh0OoZ;_W00Go[;SQojNlj?nW_>So
YkcXo`000004ojNlj0KoZ<3[0_nW_^X8ojS0jaOooooo00?o0000ooooooooool0>?ooool003cooooo
0ol00003ooooo`03o`000?oooooooooo063ooooo00?oZJgJojZ_g?nZ[m`01_nZ[m`6ojVagP03ojb]
fOn/[m[o[:oJ00Oo[:oJ1_n//]d00on^[mWo[[3Jojj`fP07ojj`fPCo[;?N1?n_/MT8ojjcg003ojZe
hOn`/m_o/;?K00Ko/;?K1_n/]^000ona]=_o[KOPojfgh007ojfgh0CoZ;_W1?n/^>42ojNlj003o`00
0?nW_>SoYkcX00?oYkcX0_nX`>/6ojNnjPSoZ<3[5_ooool00ol0003oooooooooo`07ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h0;?ooool003[ooooo0_l0001Wooooo`CoZJgJ1onZ[m`4ojVagPCo[:gI
2?n/[mX4ojbbg@Co[ZoI2On^/=X00on//mko[k7Iojnaf@05ojnaf@Ko[[?L00?o/[?Iok2cfon`/m/0
1on`/m/4ojbfh0Co/KCK2On]]n000onX^nOo[;SQojbhh@05ojbhh@03ojNlj?l0003oYkcX00?oYkcX
00?oZkWSojNnj_nW_^X01onW_^X6ojS0j`03ojNojooooooooooo01Gooooo00?o0000ooooooooool0
1_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02cooooo000gooooo`?o0000Ioooool7ojV]fPOoZZoL
00?oZK7Nojb]fOn/[MT01On/[MT8ojb_fP03ojbbgOn^[mWo[ZoI00Go[ZoI1on^/=X00onb]=[o[k7I
ojnaf@06ojnaf@Co[[?L1?nb/mT9ok2cf`03ojbfh?na]=_o/KCK00Go/KCK1on]]n000onb]]_o[;SQ
ojbhh@06ojbhh@;oYkcX00?o0000ojNlj?n[^N<00on[^N<9ojNnjP;oZ<3[1OnW_n/Gooooo`03o`00
0?oooooooooo00Gooooo00Go410@oooooooooooooooooa0@400/ooooo`00=Oooool2o`0006Sooooo
00?oZ:cIojV]f_nY[MX01_nY[MX6ojZ_g003ojb_fOn/[MWo[:gI00Ko[:gI1on/[mX00on`/m_o[ZoI
ojj_f@07ojj_f@Co[[3J1?nb]=X8ojnaf@03ojjcg?nb/mWo/[?I00Go/[?I1on`/m/00ond]][o/KCK
ok6df`06ok6df`Co[KOP1Onb]]/8ojbhh@03ojNlj?l0003oZkWS00GoZkWS1onW_^X00onY^^KoYko[
ojNoj`06ojNojaKooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000002co
oooo000booooo`?o0000Ioooool5ojR/f@SoZJgJ0_nZ[m`5ojb_f@So[:gI1?n/[mX4ok2cf`Wo[ZoI
00?o[[3Jok:df_nb]=X01?nb]=X7ojnaf@03okFkg_nb/mWo/[?I00Ko/[?I1_n`/m/3okBffPSo/KCK
00?o[KOPok:ffonb]]/01_nb]]/6ojbhh@03ok:hgOn[^N?o000000KoZkWS1?nW_^X5ojVjiPSoYko[
5_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000;?ooool0033ooooo
0_l0001Wooooo`03ojR[fOnX[=WoZ:cI00KoZ:cI1_nY[MX00on//]co[:oIojb_f@06ojb_f@So[:gI
00?o[:oJok2cfon`/m/01On`/m/7ojj_f@03ok>nh_nb]=[o/[CJ00Ko/[CJ1On_/MT3okFkgPSo/[?I
0on`/m/5okBffPOo/KCK00?o][OJok:ffonb]]/01onb]]/4ojbhh@Co/[SM00?o0000oj^ihon[^N<0
1On[^N<00onW_^[oZK[VojVjiP05ojVjiPKoYko[0_nW_^TGooooo`03o`000?oooooooooo00?ooooo
00Go410@oooooooooooooooooa0@400/ooooo`00;Oooool3o`000003ooooool0003ooooo06?ooooo
1OnXZmT7ojR/f@CoZJgJ1?n//]`8ojb_f@Ko[:gI00?o/;[Qok2cfon`/m/01_n`/m/4ojj_f@Go/kkR
1onb]=X3ojnaf@Go]K_N2Onb/mT00on`/m_o];KJokBffP05okBffPGo/KCK0onf]mX9ok:ff`03ojbh
hOnb^=go/[SM00Co/[SM00?o0000oj^ihon[^N<01?n[^N<00onb^]ooZK[VojVjiP07ojVjiP;oYko[
1_nW_^TFooooo`;o00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg02cooooo000Zooooo`?o0000
I_ooool00onWZm[oZ:_IojR[f@05ojR[f@SoZ:cI00?oZJgJojbbg?n//]`01On//]`8ojb_f@;o[:gI
1On`^^48ok2cf`03ojj_fOnc_^;o/kkR00Go/kkR2?nb]=X00on_/MWo]K_NokFkgP05okFkgPOo/[?I
00?o]l3QokBff_nd]]X01_nd]]X3ok6df`Ko][OJ1onb]]/00ong^=[o/[SMok:hg@05ok:hg@03o`00
0?n[^N?oZkWS00;oZkWS1?nb^]l7ojVjiP03ojnjh_nW_^WoYkkY00OoYkkY4oooool2o`000003oooo
ool0003ooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0/ooooo`00:?ooool2o`0006Oooooo
1?nWZmX7ojR[f@KoZ:cI00?o[;GPojbbg?n//]`01_n//]`7ojb_f@03ojo2j?n`^^7o/;[Q00Ko/;[Q
1_n`/m/00on_b>co/kkRok>nhP07ok>nhPKo/[CJ00?o/lOYokFkg_ne^mh01_ne^mh4ok:cf@Go]l3Q
2?nd]]X00ona]=_o][OJokJgfP05okJgfPCo/[KK1Ong^=X6ok:hg@03o`000?nb^=goZkWS00Oo/[[O
1?nY^^H4ojnjhPWoYkkY5_ooool00ol0003oooooooooo`0booooo`009Oooool3o`0006Oooooo1_nW
ZmX7ojR[f@CoZ:cI1?n/]N08ojbbg0Co[:oI1?n_`^P7ok2jh@Co/;?K1?n_b>`8ok>nhPCo/[CJ1?nc
anT8okFkgP03ok:cfOng`>7o]l3Q00Ko]l3Q1_nd]]X00onh`^;o][OJokJgfP07okJgfP03ok:ffong
^=[o]kSJ00Ko]kSJ1?nb^=d2o`000003okJhfonb^]oo/[[O00Oo/[[O00?oZK[Vojnjh_n_^^801On_
^^87ojNnj@03ojZki_oooooooooo01Cooooo00?o0000ooooooooool0<_ooool002?ooooo0_l0001X
ooooo`03ojJZf_nWZm[oYj_J00KoYj_J1onXZmT00onX[=Wo[;GPojbeh005ojbeh0So[;;L00?o[:oI
ojo2j?n_`^P01On_`^P7ok2jh@03ok2cfon_b>co[lS/00Go[lS/2?nc_^800onb]=[o/lOYok?7j@05
ok?7j@Ko]K_N0_n_bnh8okO0h@Co];KJ1?nh`^87okJgfP03okW3h_ng^=[o]kSJ00Oo]kSJ00Ko/[SM
o`000?l0003o0000okJhfol00002okJhf`Oo/[[O00?o][WLojnjh_n_^^801_n_^^84ojNnj@GoZ[_V
5_ooool00ol0003oooooooooo`0aooooo`008?ooool3o`0006Oooooo1OnVZ]X7ojN[fPKoZ:_I00?o
ZkWSojbeh?n/]N001on/]N06ojbbg003oj_9kon_`^So[l;X00Ko[l;X1_n`^^42ojK?m@So[lS/1_nc
_^82ojO?m@So/lOY0_ne^mh6ojo;kPSo]l3Q00?o];KJokS2h_nh`^801Onh`^85okJgfP?o^L?R1_ng
^=X3o`000003ok:hgOnf^=_o][SK00;o][SK00?o0000okJhfonf^=/01?nb^]l4okJig0So[k[R00?o
YkkYojZki_nZ^nH01OnZ^nHGooooo`03o`000?oooooooooo033ooooo000Oooooo`;o0000I_ooool0
0onUZ][oYZ[JojJZfP05ojJZfPSoYj_J0_nXZmT5oj^ih`Wo[;GP0_n//]`5oj_9k`So[l;X0_n`^^46
ojK?m@So[lS/0_nc_^86ojO?m@Ko/lOY00?oWMGkojo;k_n_bnh01on_bnh6okO0h@03ojc<lOnh`^;o
^<;R00Ko^<;R0onf]mX6okW3hP;o]kSJ0ol00002okNhfP03ok[1gonf^=_o][SK00Co][SK00Co0000
okJhfonf^=_o/[[O1onf^M`6ojnjhP03okBlgonZ^nKoZ[_V00OoZ[_V5_ooool00ol0003ooooooooo
o`0`ooooo`007oooool00ol0003oooooo`00001Rooooo`GoYJ[J1onVZ]X6ojN[fP03ojVki_n[^N?o
ZkWS00KoZkWS1on/]N000onWc_CoZlW_oj_9k`06oj_9k`Ko[l;X0onNf?`7ojK?m@Ko[lS/0_nHfOh8
ojO?m@;o/lOY1OnMeO/9ojo;kP;o]l3Q1On/c?48okS2hP03okJgf_ni`n;o^L?R00Co^L?R0ol00002
okNhfPGo^/7O1_nf^=/00ol0003o^kkLokJig007okJig0Co[k[R1?nd_=l7ojZkiP03ok2lhooooooo
oooo01Gooooo00?o0000ooooooooool0;oooool000cooooo1Ol00003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01_ooool01?l0003oooooooooool0001Nooooo`03ojBYfonUZ][oYJ[J00GoYJ[J1onV
Z]X4ojN[fPCoZK_V2?n[^N<4ojbeh0CoYlkd2?n[bNl2ojo2j0OoW]Sl1onVcoD2ojo8k0KoV=Wn1_nW
coD2ohCHo`OoWMGk1_n_bnh2oiCFoPSo[<ca1_nh`^800on/c?7o^L?RokW3hP02okW3hP?o00000_ni
`n800ong^=[o^/7Ook[1g`06ok[1g`Go][SK00?o0000ok^ng?nk_]`02?nf^M`00on_^^;o];cOokBl
g`05okBlg`CoZ[_V1?n`_><Gooooo`03o`000?oooooooooo02kooooo000<ooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo0_l00002ooooo`03o`00
0?oooooooooo05Sooooo1OnTZM/7ojFZfPOoYZ[J00?oYj_JojVki_nY^nH01OnY^nH8oj^ih`03ojbe
h?nWc_CoYlkd00GoYlkd1_n[bNl3oiCNoPSoW]Sl0onVcoD5ohGKoPOoV=Wn0_nWcoD6ohCHo`OoWMGk
0_n_bnh6oiCFoPSo[<ca0_nh`^85ojc<l@?o00001?ni`n800on^bnko^/7Ook[1g`07ok[1g`?o][SK
0onk_]`00ol0003o^kkLok^ng006okJig003okZlg?nd_=oo];cO00Oo];cO00?oZ[_Vok2lhon`_><0
1On`_><Fooooo`03o`000?oooooooooo02kooooo0004ooooo`Ko00000oooool00onHV9So8B4Qonk^
kP04ooooo`05oa0@4?ooooooooooooooool@41001Oooool2o`0000Cooooo00?o0000ooooooooool0
E?ooool00onSZM_oY:WKojBYf`05ojBYf`OoYJ[J1_nVZ]X2ojRlj0SoZK_V1_n[^N<2ojCCn0SoYlkd
0_n[bNl8oiCNoP?oW]Sl1Omieod7ohGKoP?oV=Wn1Om`d?h7ohCHo`?oWMGk1Omccoh7oiCFoPKo[<ca
0_n@e?h3ojc<l@?o000000?o[<caokW3h_ni`n800_ni`n84ojk;kPWo^/7O00?o][SKok^ng?nk_]`0
0onk_]`00ol0003o^kkLokJig003okJig0Co^[cL1ond_=l00ong_=go/;cSok2lh`07ok2lhaKooooo
00?o0000ooooooooool0;Oooool000kooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooo
oooooooo000000Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1@ooooo`GoXjWK
1onTZM/7ojFZfP;oYZ[J1_nX_>P8ojVkiP;oZkWS1_nTdoP6ojO>m0?oSN3m1onDg_h3ogoGoPOoNMOm
0on5foh5ogS>o`OoL=3n0on4f?l5ofk8o`SoLlon1_nDe_h2ojc<l@KoT=Cn0_l00005ojc<l@03okW3
h_n^bnko[/_^00Go[/_^1onj`Ml00ondbN[o^kkLok^ng004ok^ng004o`000?nk_]co^kkLokJig0Oo
^[cL1?nd_=l4okNlg@Oo/;cS00?o]KkQooooooooool05Oooool00ol0003oooooooooo`0/ooooo`00
3oooool00omgMgOoIVIVooooo`02ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo04cooooo00?oXZWLoj>YfonSZM/01_nSZM/6ojBYf`Ko
YJ[J0_nW_>P8ojRlj0KoZK_V0_nSeoX8ojCCn0;oYlkd2?n=h?d2oiCNoPOoOmOn0omieod5ohO>oPOo
N<ko0om`d?h5ogo7oPOoK/So1?mccoh5ofk2oPKoJ/Sn0on@e?h3o`000004oi3Do_n/c?7o[<caojc<
l@CoTM;n1on^bnh4ok[1g`Go]<WZ1_nk_]`00ol0003o^/OTokZlg008okZlg003okBlgong_=go]kcM
00Go]kcM1?n`_><4okFnhAGooooo0_l0000^ooooo`004?ooool01Ol0003ooooooooooooooooo410@
00?ooooo00?o410@ooooooooool00oooool2o`0000Oooooo00?o0000ooooooooool0B?ooool5oj:Y
g0OoXjWK1onTZM/2ojFZfPKoYkcX2?nX_>P2ojVkiPKoXmOj1_nTdoP4ohWPo@CoSN3m1_n9f?l3ogoG
oPGoULgk1on7c_h3ogS>o`GoT/Gi1omoaoh3ofk8o`GoQ/Cl2?m^`_h5of[8oP?o000000?oT=CnofO4
o_mWa?h00_mWa?h7oi7BoPOo[/_^00?o^/7OokC9j_ndbNX01_ndbNX5ok^ng003ok[7i?l0003o^/OT
00Oo^[cL00?o_<;NokNlgOng_=d01ong_=d00on`_>?o]KkQokFnh@05okFnhAKooooo00?o0000oooo
ooooool0:oooool000cooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04Cooooo00?oXJ[M
oj:Yg?nRZM`01_nRZM`7oj>Yf`GoY:WK0_nV^^L8ojNlj0KoZ;cX0onRf?/7oj?GnP;oY=?h1on9h?d3
oi;GoPKoRMSo0_nMaoD8oiG=n`?oQlkn1?nL__08oi;5n@?oOlOn1OnH_?48ohK4o0?oK/;n1?n9_oT0
1?m/_Ogo0000o`000?l00003ofbmo@KoIlCn1onAd_h3ojk;kPCoV<ok2?ndbNX3ok^ng0Co^/OT00?o
0000ok[7i?nj_=`01?nj_=`3okc2gPOo]kcM00?o^koMokFnhOne_^401one_^4Eooooo`03o`000?oo
oooooooo02_ooooo000<ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`10ooooo`GoXJ[M
1onRZM`8oj>Yf`03ojBYfonV^^OoY[[W00CoY[[W2?nW_>P2ojRlj0OoX]Sk0onSeoX6ohcRo0?oRN3m
1onBeoh2ohWHo`KoWLOe1_nEcO/2oj>ij0OoW;k`1_nBaOT2oj>hj0SoV;ca1_n6a?`2oiZgk0CoRKoi
0ol00007ofbmo@KoIlCn0onAd_h4of_3oPOoV<ok2?ndbNX00onk_]co^/OTok[7i003ok[7i003o`00
0?njanCo^[cL00;o^[cL1_nl`]h5okNlg@?o^koM1one_^400onh_mooooooooooo`0Dooooo`03o`00
0?oooooooooo02[ooooo000Nooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0?Ooo
ool00onQ[=ooXJ[Moj6Zg@05oj6Zg@OoXZWL1_nSZM/00onT]^KoY[[WojJji`06ojJji`KoYkcX0onS
fOX6oj;Hn`?oT^Cl1on<h_`3oi[Go@KoT]On0onR`o07oig7m@;oULgk1_nS^NP7oibnl0;oT/Gi1_nS
^>P8oiRll@;oQ/Cl1_nJ]n`3o`0000CoRKoi0om/_Od4ohNln0OoJ;Wm1_m[`oh7oiS?n`Co]<WZ0onR
boD7ok[7i003o`000?njanCo^[cL00Oo_<;N0ong_=d6ok^og@Go]KkQ0onh_mlFooooo`03o`000?oo
oooooooo02Wooooo000Mooooo`?o00002oooool00ol0003oooooooooo`0iooooo`GoXJcO1_nQZ]d8
oj:Yg0;oXjWK1OnT]^H8ojJji`;oYkcX2?nSfOX00onRf?_oT^Cloi;To006oi;To0;oS>;l1onJeod2
oi;GoPOoX/?`1OnMaoD2ojNgi0SoXkWX1OnL__02ojVgh`SoXkSX1_nH_?400onX^>CoV[O/oiZgk003
oiZgk0?o000000CoV[O/ohVonOn9_oWoRKoi1?nL]n/7ohNln0OoJ;Wm1_m[`oh3oiS?n`?oN<Go2?nR
boD6ok[7i003ojo8k?l0003o_<;N00So_<;N00?o]kcMok^ogOnk_md01Onk_md3okFnh@Ko^;oO5Ooo
ool00ol0003oooooooooo`0Yooooo`007Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo03Gooooo00?oXJkQoj6/gonQ[=l01_nQ[=l6oj6Zg@KoXZWL00?oX[;SojBfi_nT]^H01_nT]^H6
ojJji`?oYMOi1onSfOX3oiOUo0KoT^Cl0onOf?/6oi[Go@?oY<3]2?nR`o000onMaoGoYkOTojNgi004
ojNgi0SoXkWX00?oW;k`ojVghonY]n<01?nY]n<8oj>hj0;oV;ca1OnX^>@01?nJ]nco0000o`000?l0
0003oiZgk003oj^ii?nL]n_oW;O[00KoW;O[1on7_?P3ofRio@CoP;_i1_mS]_`6ogS5o`SoX/_e0_nj
an@5ojo8k003o`000?nl`]ko_<;N00Go_<;N00?o^/OTok^ogOnk_md01onk_md00one_^7o^;oOokRo
g`05okRogaKooooo00?o0000ooooooooool0:?ooool001gooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0aooooo`GoXJkQ1onQ[=l7oj6Zg@;oXZWL1OnR/^<8ojBfiP;oY[[W2?nUeoT2
oj?InPOoUnGl0_nBi?`7oioHn`;oV]Om1onT`>d6oj;3l003ojRghonW]nCoYkOT00KoYkOT1_nS^NP0
0on[^>?oZKOSojVgh`06ojVgh`KoXkSX00?o[;WSojRhi?nX^>@00onX^>@3o`0000CoV[O/1?n[^N@8
oibgj`?oQkch1?nJ]n`7oh2kn@KoHkKl1_mhaOl6oj;;m@03ohc9o?n_b>co[lS/00Go[lS/00?o0000
ojo8k?nl`]h00onl`]h4ok[7i0Oo^koM00?o_L;NokRogonh_ml01onh_mlFooooo`03o`000?oooooo
oooo02Oooooo000Mooooo`;o00003oooool00ol0003oooooooooo`0]ooooo`03oj:ahonQ[^7oXJkQ
00KoXJkQ1onQ[=l3oj6Zg@CoX:gP1onR/^<6ojBfiP?oY]?g1onUeoT3oicWn`KoUnGl0onSfO/6oioH
n`;oY[o[2OnT`>d2oj;3l0GoZ;OS2?nW]n@2oj>ij0GoZkSS2?nY]n<2oj>hj0Go[;WS0_nX^>@2o`00
00CoZ;ST00?oV[O/oj^ii?n[^N@01On[^N@6oibgj`03ojbji?nJ]ncoV[O/00KoV[O/1on0^oT6of>f
o0KoN<Go0_nRboD5ohc9o0Oo[lS/00?o0000ojo8k?nl`]h01onjan@4ok^og@Co_L;N1onh_ml00onj
`Mooooooooooo`0Dooooo`03o`000?oooooooooo02Oooooo000Mooooo`03o`000?oooooooooo00oo
oooo0_l0000Zooooo`GoX[7S2?nQ[^45oj6/g`03oijYg_nP[N3oX:gP00KoX:gP1onR/^<2ojBfiPOo
Y]?g1?nUeoT6oicWn`;oUnGl2?nSfO/00onOf?_oY[o[ojJoj`04ojJoj`OoY<3]00?oZ;KSojRghonX
]n<01_nX]n<6ojNgi0WoZkSS1_nY]n<00on/^^?o[;WSojbih`04ojbih`?o00001OnX^>@00on^^n?o
ZkWToj^ii007oj^ii0;oW;O[1On/^^@8oiZgk0?oP;_i1?nC]^l7ogBfnPKoHKGl1_n<bO`6ojo8k003
oj37m?l0003o^/OT00So^/OT00?o^koMokg2g_nm`]h01?nm`]h4okRog`Go^/7O5_ooool00ol0003o
ooooooooo`0Vooooo`007Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02?ooooo
1?nU]nH6oj:ah`SoXJkQ00?oXJcOoijYg_nNZMh00onNZMh8oj2]h0GoX[;S0onWc_@8ojKCm`03ojGG
nOnLio_oW>Ok00GoW>Ok0onVfoX7oj?In`03ojNojonV_n_oY[o[00KoY[o[1?nT`>d4ojRfh`OoZ;OS
1?nW]n@<oj^hh`;oZKOS1On/^^<2ojbih`?o00000on/^N<2ojRhi0Go[[_S1on[^N@00on__>?o[;[T
ojbji006ojbji0KoV[O/00?oZk[Uoi>fkonC]^l01_nC]^l7ogBfnPKoHKGl1_n<bO`2ojo8k0GoX<Od
00?o0000ok[7i?njan@01Onjan@00onban[o_L;Nokg2gP06okg2gP03okRogonj`Moo^/7O00Go^/7O
5oooool00ol0003oooooooooo`0Uooooo`007Oooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo01kooooo00?oYkgYojFgi_nU]nH01_nU]nH6oj:ah`KoXJkQ00?oWJOMoijYg_nNZMh01OnN
ZMh8oj2]h003oj:bhonWc_CoYlkd00GoYlkd1_nVdoL4oj7Xn`;oW>Ok2?nVfoX2oj?In`GoYko[2?nV
_n/00onT`>goZ;KSojRfh`05ojRfh`OoZ;OS00?oYkOToj^hhon[^><02on[^><00on/^nGo[;[Sojbj
h`04ojbjh`?o00001On/^N<00on]_>Go[[_Sojjkh`06ojjkh`CoZkWT1?n__><8ojbji0;oV[O/1On[
^^D8oi>fk`?oM;Kj1?n8]o@6ofN`nPKoLKcm1_nPao@00ol0003o^/OTok[7i002ok[7i0Go//OZ1_nm
`]h00onmaN7o^/7Ook[1g`07ok[1gaKooooo0_l0000Vooooo`007?ooool3o`0001Cooooo00?o0000
ooooooooool06oooool4ojNmj@SoYKOV1_nR/N<2oj6^h@GoWJOM1_nNZMh7oj2]h0;oY/Oa2?nWc_@2
ojKCm`OoXNSk0onZgoX6ojKKnP03ojW2k?nW_n_oYko[00KoYko[1_nV_n/9ojRfh`KoZ;OS00?oZKST
oj^hhon[^><02_n[^><4ojbki@;o[;[S0ol00003ojbjh`;o[;WS1On]_>D8ojjkh`03oj^ii?n__>?o
[kcS00Go[kcS1_n/^^@00on`_N?oZk[Uoj^ji@06oj^ji@KoTkK_0_nU^NP7ohRgm0KoIk3j1_ma_?d6
oj37m003o`000?njanCo//OZ00Ko//OZ1Onm`]h3okg5h@Oo^/7O00?o_L?Oooooooooool04oooool0
0ol0003oooooo`00000Vooooo`007?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
01Wooooo1_nW_NT8ojFgiP?oX[7S0_nMZMl8oifWg@KoWZWN1?nP[N05ojK7l@KoYlkd1?nVj?/3oj7X
n`OoZ]oj0_nVfoX5ojW2k0SoYko[0_nV_n/=ojRfh`;oZ;OS1OnY^>@9oj^hh`Go[;_U0ol00005ojbj
h`03ojboion]_>Go[KcU00Ko[KcU1_n^^n<00on^_^Ko[kcSojnlh`06ojnlh`Co[;[T1?n`_N<8oj^j
i@;oTkK_1_nU^NP7ohRgm0KoIk3j1_ma_?d3oj37m0?oSlGj00?o0000ok;7j_nbanX01OnbanX3okg2
gPKo_LGQ1?nj`Ml4okg3gaOooooo00?o0000ooooooooool08oooool000[ooooo1?l000002?l@413o
ooooooooooo^k^ko<S8bo`000?lb<S;ok^k^1_ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo01Kooooo0onX`>/6ojNmj@KoYKOV00?oWZgQoifYgonMZMl01?nMZMl7oifWg@OoWZWN00?o
X:gPojK7lOnVao401_nVao42ojO>m0OoY^Sk0on]hoT6oj[OnP;oZlK]1onY`^`6ojNoj`03ojNfhonX
]^?oZ;KS00coZ;KS00?oZKWUojVhi?nY^>@01_nY^>@6oj^hh`04oj^mion/^nGo[;_Uojbki@?o0000
0_n/^nD4ojbjh`Co[;oW2?n]_>D2ojjkh`Go[[kV2?n__><00on/^^Co/;gSok2mh`05ok2mh`KoZk[U
00?o/;kTojFij?nU^NP01onU^NP3ohRgm0?oV;O]1omf/oP6of:_nPGoSlGj00?o0000ok;7j_nbanX0
1_nbanX00onm`]ko_LGQokg5h@06okg5h@03ok[1gonm`moo_L?O00Go_L?O5_ooool00ol0003ooooo
ooooo`0Sooooo`003?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01;ooooo1onX`>/6ojNmj@;oYKOV
1OnN[N46oifYg`OoWJOM0onNZMh5oj>nk@KoY/Oa0onXi?/5ojKXn`Oo[N?i00?oZ]ojoj_6kOn[a^d0
1?n[a^d7ojW2k0;oYko[1OnW]^<:ojRfh`GoZKWU2?nY^>@2oj^hh`CoZkgW0ol00006ojbki@03ojbj
hon/_nOo[;oW00Go[;oW1_n]_>D00on/`>Wo[[kVojjniP06ojjniPKo[kcS00?o[koVok2mhon`_N<0
1on`_N<2oj^ji@Go/;kT1onU^NP00on^_NGoV;O]oiRgk@05oiRgk@OoM[?h1_mR[oX5oho5nP03o`00
0?nban[o//OZ00Co//OZ00?oYlG_okg5hOnmaN401_nmaN400onjanCo_L?Ookg3g`07okg3gaKooooo
00?o0000ooooooooool08_ooool00003ooooool0003o000000Co00001Oooool00ol0003ooooooooo
o`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool2o`0001Wooooo00?o0000ooooooooool0
3_ooool3ojO0j`SoZ<3[0onW_NT2oin`i0SoWZgQ1_nMZMl5oifWg@;oWkCW2?nS_^d3ojK7l@OoZ>Ck
00?oY^SkojgSnOn]hoT01_n]hoT00on]c?3oZlK]oj_6k@06oj_6k@GoZL;/0_nV]^@7ojNfh`KoZ;KS
0_nX^ND7ojVii@KoZKST00?oZ[kYoj^mion[_NL00_n[_NL2o`0000;oZkgW1_n/^nD00onZ`>Wo[;oW
ojboi`06ojboi`Co[KcU1?n/`>T8ojjniP;o[kcS1On__nH7ok2mh`03ojnoiOn`_^Co/;kT00Ko/;kT
1?nU^NP4ojjmi@OoV;O]1omf/oP6of:_nPGoSlGj00?o0000ok;7j_nbanX01OnWaNl6okg5h@?o^/OT
1onm`ml00onnaMooooooooooo`0Eooooo`03o`000?oooooooooo027ooooo000<ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool02_ooool7ojO0j`KoZ<3[00?oY;SWoin`i?nO/>@01?nO/>@7oij]h@OoWJWO
00?oWJOMoindionO]>L01?nO]>L8oj>nk@03ojK7lOnXi?_oZ>Ck00GoZ>Ck1?n_ioT3ojgSn@Go[Lc`
2?n[a^d00onY`^coY[KTojJfi004ojJfi0OoYkKS0_nX]^<6ojRii@OoZKWU0_nY^>@5ojZnj@?o0000
1On[_NL2ojbki@GoZ/3Y2?n/_nL00on]_>Go[<3Yojc0j@05ojc0j@Ko[[kV00?oZl7Yojnoi_n__nH0
1_n__nH4ok2mh`Co[koU2?n`_^@00onU^NSo[[gUojjmi@04ojjmi@KoV;O]00?oYK_YohFem?n5]O@0
1On5]O@7ofF[n0GoO;_j00?o0000ojO5konWaNl01OnWaNl3okg5h@Ko^/OT1?nm`ml4okk5gaKooooo
00?o0000ooooooooool08Oooool000cooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000Gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`07ooooo`[oYl3[
0_nX`>/5ojBhi`KoWk3T1onN[N43oifYg`?oVj_R2?nO]>L6oj>nk@CoZ]ci0_nXi?/7ojoWn@;o[mCc
1on]c?06oj_6k@WoY[KT1OnW]^<2ojNhi@SoZ;WU1OnY^ND2ojRojP?oZ[kY0ol000000onZ_^WoZkgW
oj^mi`04oj^mi`03ojRoj_nZ`>WoZ/3Y00KoZ/3Y1_n/_nL2ojRojPSo[<3Y0_n^_^H5oj_1j@So[koV
00?o/;gSojnoiOn__nD01On__nD6ok2ni003ok6oi?n^_NGo[[gU00Ko[[gU0_nH]nd5ojFkj@OoQKGd
1omUZoP4ogbknP03o`000?ml^o[oYlG_00KoYlG_00?o_LGQok[7i?njan@01_njan@00onm`moo_/GO
okk5g`04okk5gaOooooo00?o0000ooooooooool08?ooool000cooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`03ooooo`coYl3[0_nW_^X7ojBhi`KoWk3T1OnN[N400onIY]ooVj_Roi^[hP05oi^[hPSoWkCW
0_nS_^d7oj[Ln@?o/N[h1?n_ioT5ojoDl`Oo[Lc`0_n[a^d=ojJfi003ojNfhonW^>GoYkSU00CoYkSU
2?nX^ND00onY^NGoZ;oZojRojP03ojRojP?o00001OnZ_^T2oj^mi`GoZ;oZ2?nZ`>T2ojboi`KoZ;oZ
1_n/`>T00onX_^WoZl7Yoj_1j@06oj_1j@Ko[koV00?o[<7YojnoiOn__nD01on__nD2ok2ni0Go/KoT
1_n^_ND00ona_nCoYK_YojFkj@06ojFkj@OoQKGd1omUZoP4ogbknP03o`000?ml^o[oYlG_00;oYlG_
1?nM`_87ok[7i003okK6ionnaMoo_/GO00Ko_/GO5oooool00ol0003oooooooooo`0Oooooo`003?oo
ool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2o`0001kooooo
00?o0000oooooonW_n/00_nW_n/9ojO0j`KoYkkZ1_nT^>L7oin`i003oij]hOnIY]ooVJKO00?oVJKO
1onKZn86oindi`?oZ]3d1OnZg?T6ok7Zn003ojoWnOn_e??o[mCc00Ko[mCc0on]c?03ojJgi@koY[KT
00?oY[SUojNhiOnW^>D01_nW^>D6ojRii@CoZ;oZ0ol00002ojRojPGoZ[kY0_nX_^T7ojRojPKoZ/3Y
0_nX_NT8ojRojP;o[<3Y1OnX_^T8oj_1j@;o[koV1On/`NT7ojnoi@03ojk1j?na_nCo/KoT00Go/KoT
1?n^_ND4ok6oi0SoYK_Y0on5]O@4oi2fl0KoKZcg1Om^/OT00ol0003oWL;boig2lP06oig2lPCo^/OT
1?nfa^L6okk5g`03oko7h?oooooooooo01Gooooo00?o0000ooooooooool07oooool000[ooooo00?o
EEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0
7?ooool7ojNoj`KoYl3[0_nX`>/7ojNnjPKoY;SW0onO/>@3oiZXh0OoVJKO1onKZn82oindi`SoZ]3d
00?oZ]ciok7Zn?naj_P01Onaj_P3ok?Lm@Ko[mCc00?oYk[WojJgiOnV]nD01OnV]nD:ojJfi0GoY[SU
2?nW^>D2ojRii@CoZ;oZ0ol00006ojRojP03ojZnjOnX_^WoZ;kY00CoZ;kY1onX_nX2oj[0j@KoZ;gY
1_nX_nX9ojRnj@KoZl7Y00?oZ;kYojc1jOn/`NT01_n/`NT4ojnoi@Co[/7X1ona_n@00on^_NGo/KoT
ok6oi005ok6oi0KoYK_Y0_n^_^H7oi2fl0KoKZcg1Om^/OT00ol0003oWL;boig2lP06oig2lP03ok[7
i?nfa^Oo]/KW00Co]/KW1?nnaMl4oko7h1Oooooo00?o0000ooooooooool07_ooool001_ooooo00?o
0000ooooooooool06Oooool4ojJoj`OoYko[0_nW`>/6ojS0j`OoYkkZ0onT^>L2oib]h`OoVZSP1onI
Y]l5oi^[hP?oYlG_1onZd?@3ok?Ym`Co/N[h1oncg?D00on_e??oYk[WojNji`03ojNji`OoY[OU1_nV
]^@00onU]nGoY[SUojJhi@06ojJhi@KoYkSU00CoYkoZojRoj_nX_n[oZ;oZ0ol00008ojRojP03ojNm
jOnX_^WoZ;kY00KoZ;kY1OnX_nX2ojRmj0SoZ;gY0_nX_nX=ojRnj@;oZl7Y1OnX_^T8ojc1j@03ojno
iOn^`NSo[/7X00Go[/7X1Ona_n@00on``NKo/KoTok6oi007ok6oi0;oYK_Y1_n^_^H7oi2fl0KoKZcg
1?m^/OT00ol0003oWL;boig2lP04oig2lP;oUKod2?nfa^L00onnaMoo_lOPoko7h005oko7h1Oooooo
00?o0000ooooooooool07Oooool001_ooooo00?o0000ooooooooool05Oooool2ojNoj`OoY[o[1onW
_n/8ojS0j`GoYkkZ00?oWk?Voib]honL[N<01?nL[N<7oiZXh0OoVJKO00?oVj_RojO5konWaNl01OnW
aNl4oj[@m0Oo/nWg00?o/N[hok?LmOncg?D01Oncg?D00on/`n_oYk[WojNji`05ojNji`OoY[OU0_nV
]^@5ojFgi@SoY[SU0_nW^>D4ojNojP?o00002?nX_nX5ojNmj@SoZ;kY00?oZ;oZojRmj?nX_NP01?nX
_NP6ojRmj@03ojVnj?nX_^WoZ;kY00coZ;kY00?oZKkYojRnjOnX_^T01_nX_^T6ojc1j@;oZKoZ2?n^
`NP00ona_nCo/<7Vok31iP03ok31iPOo/KoT00?o//7Uojjni_n^_^H01on^_^H3oi2fl0CoVkW]1_mg
[_D3ofJYm`04ofjanOl0003oWL;boig2lPKoUKod1_nfa^L00onaaNSo_lOPoko7h007oko7h1Gooooo
0_l0000Oooooo`006oooool2o`0001?ooooo1_nW_n/7ojJoj`OoYko[2?nX`>/00onW_^[oWk?Voinc
iP03oinciPKoW:gS1_nJZ>06oiVVg`;oW[KY2?nWaNl00onZd?Co/nWgok?Ym`06ok?Ym`?o^>?e1?nc
g?D4ojc3j`OoYk[W1OnV]nD2ojFfi@OoYKOU1_nV^>D00onW_^[oYkoZojNojP02ojNojP;o00000_nW
_nX6ojRojPWoYkgY1_nX_^T9ojRmj0;oZ;gY1OnY_^P:ojRnj@GoZKkY2?nX_^T2ojc1j@KoZKoZ1_n^
`NP00onZ`N[o/<7Vok31iP05ok31iPCo/KoT1?nb`ND7ojjniP03ok71i_nK^NgoVkW]00KoVkW]1_mg
[_D4ofJYm`03o`000?nE_oCoUKod00GoUKod1?nfa^L4ok75j0Oo_lOP00?o`<SQooooooooool05Ooo
ool00ol0003oooooooooo`0Looooo`006_ooool00ol0003oooooooooo`0@ooooo`;oZ<7[2?nW_n/5
ojJoj`WoYko[1_nX`>/00onU^nWoWk?VoinciP05oinciPKoW:gS1_nJZ>02oiVVg`KoW[KY1_nWaNl4
ok7Pm`?o/nWg1onhhoD00oncg?Go[<?[ojc3j`05ojc3j`OoYk[W00?oY[OUojFfiOnU]^D01?nU]^D7
ojFgi@;oY[SU1OnW_^X3o`0000GoYkoZ0_nX_nX=ojNmj@;oZ;kY2onX_NP2ojVnj@OoZKkX1_nX_^T0
0onZ_nWoZKkYojVnj@06ojVnj@KoZ;kY0_nY_^T8ojVojP;o[/7X1OnZ`NX7ok31iP03ok6oi?nb`NGo
//7U00Go//7U1?n^_^H4ok71iPSoVkW]1_mg[_D4ofJYm`03o`000?nE_oCoUKod00GoUKod00?o]/KW
ok75j?naaNP01OnaaNP4oko7h0Co`<SQ5_ooool00ol0003oooooooooo`0Looooo`006_ooool00ol0
003oooooooooo`0=ooooo`KoZ<7[2?nW_n/00onV_n_oYko[ojNoj`0;ojNoj`;oZ<3[1OnU^nT7oinc
iPKoW:gS0onJZ>03oiRZh`SoW[KY0onWaNl6ok7Pm`?o^nWd1_nhhoD3ok;?k`Oo[<?[0onW^^L3oj>e
i@SoYKKU1OnU]nD2ojJmjP?oYkkZ0ol000000onW_^[oYkoZojNojP04ojNojPooYkgY00?oZ;gYojRm
j?nX_NP02OnX_NP5ojVnj@OoZKkX0_nX_^T5ojZoj@SoZKkY0_nX_^T6ojVnj@KoZKoZ00?oZKoYoj[1
j_nZ`NX01OnZ`NX6ok31iP;o[/;X2?nb`ND00on^_^Ko/L7Vok71iP05ok71iPKoVkW]00?oX[c/ogj`
lomn/?<01?mn/?<4ofJVm003o`000?mVZOOoUKod00;oUKod0on=^O@9ok75j003oko7h?o0b>7o`<SQ
00Go`<SQ5_ooool00ol0003oooooooooo`0Kooooo`006_ooool00ol0003oooooooooo`0;ooooo`Wo
Z<7[1_nW_n/00onV_n_oYko[ojNoj`0;ojNoj`;oZ<3[1onU^nT7oinciP?oW:gS0_nFY^47oiRZh`So
W[KY00?oYlG_ok7Pmonah?L01?nah?L6ok_Ym003okSSmOnbcnoo//o_00Go//o_1On/`n/8oj>ei@So
YKKU00?oYKOUojJmj_nV_NX00onV_NX3o`0000GoYkkZ0_nW_nX?ojNmj@GoZ;gY2OnX_NP7ojVnj@Go
ZKkX00?oZKoYojZojOnZ_nT01_nZ_nT6ojVnj@03ojZojOnY_^WoZKkY00OoZKkY0_nY_nX5ojVoj@Oo
Z/7Z0_n``NH6ojk2j0Ko//7U2_na`NH2oi^ik@GoX[c/1_mn/?<4ofJVm003o`000?mVY_CoSKWd00Go
SKWd1onaaNP00on^a>Wo`<SQol38h@05ol38h@03ol39hOoooooooooo01Gooooo00?o0000oooooooo
ool01_ooool5o`0000oooooo000Jooooo`;o00002Oooool=ojS1j`;oYko[1OnV_n/9ojNoj`KoZ<3[
1onU^nT3oinciP?oVJ_S1_nFY^47oiRZh`KoW[KY0on]dO<3ok7Pm`Oo^nWd0_ngf_88ok;?k`03ojc3
jonS]NGoXkGU00[oXkGU1_nU]^D01?nU^nWoY[gZojJmj_nV_NX3o`0000;oY[gZ1OnW_^X?ojNmj@Wo
Z;gY1_nX_NP2ojRnj@SoZKkY00?oZKkXojVojOnY_nT00onY_nT8ojZoj@;oZKkY1OnZ_nT7ojVnj@03
ojZojOnY_nWoZKoY00KoZKoY1OnZ`NX00onX_n[o[/;Xojk2j007ojk2j0;o//7U3?na`NH00onb`^Ko
X[c/oj:lk005oj:lk0KoO[3c1OmVY_@00ol0003oIZKdohfim005ohfim0Co/LGX1?n^a>T5ol38h@?o
`<WQ5_ooool00ol0003oooooooooo`06ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@03oooool001[o
oooo00?o0000ooooooooool01_ooool2ojO0j`coZ<7[0_nW_n/7ojJoj`KoYko[0onW`>/6ojS0j`Go
YK_Y00?oVk3VoiV[honIZn<01OnIZn<6oiJVh@OoV:[S0_nN]^T7ojgAl`03ok7PmonkjOCo^nWd00Co
^nWd1Ongf_86ok;?k`03ojFiionS]NGoXkGU00coXkGU0_nU]^D4ojFkj@?o00001_nV_NX00onW_^[o
YkgYojNmj@0=ojNmj@goZ;gY0_nX_NP6ojRnj@KoZKkY00?oZ<3[ojVojOnY_nT01OnY_nT6ojZoj@03
ojVoj_nZ_nWoZ[oY00KoZ[oY1?nY_^T4ojZoj@SoZKoY00?oZ/7ZojRoj_nX_nX00onX_nX7ojk2j003
ojc1jOna`NKo/L7V00[o/L7V1?nb`^H7oj:lk0KoO[3c1?mVY_@00ol0003oIZKdofJVm006ohfim003
ok75j?n^a>Wo[/CY00Go[/CY0oo0b>45ol39hAKooooo00?o0000ooooooooool01_ooool00onHV9So
8B4Qonk^kP0@ooooo`006_ooool00ol0003oooooooooo`03ooooo`KoYl3[2?nX`N/6ojNoj`OoY[o[
0_nW_n/7ojO0j`KoZ<3[00?oYK_Yoi^`i_nK/>H00onK/>H7oiV[h`KoUZKQ1OnHZ^<3ojO3kPKo[M7c
1?nkio@2ok_Ym0So]m[b0_nbcnl5ojFii`coXkGU0_nT^NP2ojFkj@?o00000_nU^nT6ojJmjP03ojNn
j_nW_NWoYkgY00koYkgY3?nX_NT2ojRojPSoZ;kY0_nY_^T5ojS0j`OoZKoY0_nZ_nT5ojVojPSoZ[oY
00?oZKkYojZojOnZ_nT01OnZ_nT6ojVoj@03ojZojOnX_n[oZ;oZ00GoZ;oZ1?n^`^P4ojc1j@Wo/L7V
1_nb`^H6oj:lk0;oY[k[1_n4/O84ofVSl`03o`000?mYXo?oR;Cc00GoR;Cc2On^a>T00oo0b>7o`<WQ
ol39h@05ol39hAKooooo00?o0000ooooooooool01_ooool00onHV9So8B4Qonk^kP0?ooooo`006_oo
ool00ol0003oooooooooo`02ojNoj`SoYl3[1onX`N/7ojNoj`GoY[o[2onW`>/3ojS0j`?oXkWY1_nK
/>H6oiV[h`OoUZKQ00?oV:[SojO3k_nW`nh01OnW`nh3ojgAl`Ko^nOd0onnho46okOJlP;o[LC[1onU
^NL8oj>ei@CoY;WX0ol00006ojFkj@;oY[gZ1OnW_^X@ojNmj@SoZ;gY1_nX_nX6ojRnj@03ojS1k?nX
`>_oZ<3[00KoZ<3[1OnY_nT00onX`N_oZKoZojVojP06ojVojPKoZ[oY0_nZ`>T8ojZoj@;oZKoY1OnZ
_nT7ojRojP03ojk2j?n/`NWo[<7Y00Go[<7Y1_na`NH2ok72i`Oo//;V0_nR_>`6ojJnj`KoQ;7b1?mY
Xo<00ol0003oJJ?cohRdl`05ohRdl`Ko[/CY0_n]`^X7ol39h@03ol7;h_oooooooooo01Cooooo00?o
0000ooooooooool01oooool00omgMgOoIVIVooooo`0>ooooo`006Oooool00ol0003oYko[ojNoj`04
ojNoj`SoYl3[1onX`N/7ojNoj`03ojJojonW`>_oYl3[00_oYl3[00?oYko[oj>ijOnS^NT01OnS^NT6
oi^`iPKoVJ_S0onFY^44oiZai`SoYl?^00?o[M7cok_Wm?nkio@00onkio@7okkSl@03okOJl_n]a>_o
[LC[00Co[LC[1onU^NL3oj>ei@?oXkKW0_nT^NP3o`0000?oY;WX1OnU^nT9ojNnjQ3oYkgY0onX_NT3
ojRoj`SoZ;oZ0_nX_^T5ojS1k0SoZ<3[00?oZKoYojS1jonX`N/00onX`N/8ojVojP;oZ[oY1_nZ`>T6
ojZoj@03oj[0jOnZ_nWoZ[oY00GoZ[oY1_nX_nX2ojVojPSo[<7Y0_na`NH6ok72i`Go//;V0_nc`nH8
ojJnj`KoQ;7b1?mYXo<00ol0003oR;CcohRdl`05ohRdl`;o[/CY1_n]`^X5ol39h@?o`L_R5_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00gooooo000Iooooo`03o`000?nW_n_oYko[
00GoYko[1_nW`>/9ojS1j`GoYko[0onV_n/9ojO0j`GoYko[1onS^NT6oi^`iP?oVJ_S0onDYn<7oiZa
i`KoYl?^1?ndf_<2ok_Wm0Oo_^?a0_nfdnl7ojg4j`GoYKWW0_nQ]NH5oj>fi`;o00001onT^NP00onU
^nWoYkkZojNnjP0;ojNnjPkoYkgY00?oYko[ojRojonX_n/01OnX_n/6ojRojP03ojO1k?nX`NcoZ<7/
00KoZ<7/1_nX`>/2ojO1k0KoZ<7[1_nY_nX2ojS1j`SoZ/3Y0_nZ_nT5oj[0j@OoZ[oY0_nX_nX6ojVo
jPKo[<7Y00?oZ/7Zok72iona`^L01ona`^L00onb`^Ko/l?Vok?3iP04ok?3iPKoY[k[00?oZ<3[ohJ`
lOn6/?401On6/?43of^Rl@03o`000?mYXo?oR;Cc00;oR;Cc0on7/O48ojg2jP?o`<WQ1_o1bn8Doooo
o`?o00001?ooool01Ol0003o^[ZjoooooonHV9So410@00oooooo000>ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01_ooool00ol0003oooooojNoj`06ojNoj`;oYl3[3OnX`N/00onW_n_oY[o[ojJoj`05
ojJoj`OoYl3[1onW_n/7oj>ij@?oVk3V0_nEZN@7oiBWh`OoV[7W0_nW`nh7okCJl`?o`NOa1?nnho45
okKCk`Oo[LC[00?oYKWWoj6ei_nQ]NH01?nQ]NH01?nS]^Oo0000o`000?l00002oj>fi`KoY;WX0_nW
_n/;ojNnjPgoYkgY1OnW_n/7ojRoj`;oZ;oZ1OnW`N`8ojS1k0;oZ<3[1_nW`N`6ojS1j`;oZKoZ1_nX
`N/6oj[0j@03ojW1jonZ`>WoZ/3Y00KoZ/3Y1OnZ_nT2oj_0j@SoZKoZ0_n/`NT5oj[1jPOo/L;W00?o
/<?Xok?3i_nc`nH01_nc`nH2ojJnj`GoZ<3[1on6/?43of^Rl@03o`000?m[X_7oQk7a00GoQk7a2?n]
`^X00oo0bN7o`L_Rol7;hP04ol7;hP03ol7<hooooooooooo01Cooooo00?o0000ooooooooool00_oo
ool01OnHV9So410@o`000?lQ8B7oc<c<00oooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1_ooool00ol0003oooooooooo`05ojNoj`?oYl3[2onX`N/4ojNoj`OoY[o[1onW`>/7ojNoj`?oXkWY
0onI[nH6oiFYi0OoU:OS1OnJ/NL3ojc9k`Go]=[c1_o1io400onnho7o]]?_okKCk`06okKCk`?o[LC[
0onQ]NL5oj6eiP?o00001_nS]^L2ojBij0KoYko[1_nW_^X00onV_>WoYkgYojNmj@0;ojNmj@03ojNo
j_nW_n_oYko[00KoYko[1OnX_n/9ojO1k0KoZ<7/0_nW_n/8ojO1k0?oZ<7[0onV`>`8ojS1j`;oZ/3Y
1OnY`N/8oj[0j@03ojZojOn[`>WoZl3Y00CoZl3Y1_nY_nX00onZ`>[oZ/7Zoj[1jP06oj[1jPCo/L;W
1?n``nP6ok?3iP03ok?4ionX`>_oZ<3[00KoZ<3[1on6/?43of^Rl@03o`000?m[X_7oQk7a00GoQk7a
1_n]`^X2ojg2j@Go`L_R0oo1c><Fooooo`03o`000?oooooooooo01Gooooo000>ooooo`05oa0@4?oo
ooooooooooooool@41001_ooool2o`0000;ooooo00?oYko[ojO0jonW`>/01OnW`>/8ojS1j`OoYko[
1OnV_n/9ojO0j`GoYko[00?oXKSYoiV_i_nI[nH01OnI[nH6oiFYi0OoU:OS00?oV[7Wojc9kon/bNl0
1_n/bNl00ondf_?o`NOaol7Wl@05ol7Wl@?o_Mg_1_nfdnl2ojJlj@KoXKGW00CoXKGVo`000?l0003o
00001?nQ]NH3oj>fi`CoYKcZ1onW_n/2ojNnjPGoY[cY2OnW_NT5ojNojPSoYko[00?oZ;o[ojO1k?nW
`N`02onW`N`2ojS1k0KoYko[1_nW`N`00onW_^_oY/3/ojK0k005ojK0k0KoZ<7[00?oY/3/ojW1jonY
`N/01_nY`N/6oj[0j@03oj[0j_n[`>WoZl3Y00KoZl3Y0_nY_nX5oj[0jPSoZ/7Z00?o/L;Wok33j?n`
`nP01?n``nP4ok?3iPCo/lCW2?nX`>/3ohJ`l@?oQ[3`1?m]XO000ol0003oJj;aohNal@05ohNal@;o
[L;Z1_n]`^T3ol7;hPGo`LcS5_ooool00ol0003oooooooooo`0Dooooo`003_ooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool00oooool7ojO0j`SoZ<7[1onW_n/00onV_n_o
Yl3[ojO0j`0;ojO0j`03ojNojonQ^>WoXKSY00?oXKSY1onI[nH6oiFYi0GoU:OS0onO^>X6ojc9k`?o
_Moa1?o1io47okgMk`03okKCkonV_>WoY[cY00CoY[cY0onQ]NL3o`0000KoXKGV00?oX[SXojFlj_nU
_>X01_nU_>X5ojNoj`03ojJmjOnV_>WoY[cY00KoY[cY1OnW_NT2ojNnjPOoYkoZ1_nW_n/>ojO1k0;o
Ykk[2?nW_n/2ojO1k0GoYkk[1onV`>`2ojS1j`GoY/3/2?nY`N/2oj[0j@GoZ/3Z1_n[`>T00on[`NWo
Z/3Zoj[0jP06oj[0jPKoZ/7Z00?oZL3[ok33j?n``nP01_n``nP00onc`nKo/lCWok?4i`05ok?4i`Ko
Z<3[00?oZ<7[ohJ`l?n6/?001On6/?03offQl003o`000?m]XO3oR:o_00KoR:o_2?n]`^T00oo1bn;o
`LcSol7<h`05ol7<haGooooo00?o0000ooooooooool05?ooool000kooooo00Go0000oooooooooooo
ooooo`000005ooooo`03o`000?oooooooooo00Gooooo1OnW`>/:ojS1j`GoYko[0_nV_n/<ojO0j`;o
Yko[1_nQ^>T6oiV_iPOoUJWT00?oU:OSoinhj_nO^>X01OnO^>X3ojc9k`Oo_Moa00?o`NOaokgMkonm
gNl01OnmgNl00ondc^goY[cYojJlj@05ojJlj@?o00001?nQ]NL2oj6eiPGoX[SX2?nU_>X00onW_n_o
Y[gYojJmj@03ojJmj@SoY[cY00?oYkgYojNnj_nW_^X01?nW_^X7ojNojP;oYko[3_nW`N`6ojNnj`Ko
Yko[00?oZ;kYojNnjonW_^/01_nW_^/5ojK0k0;oYkk[1onV`>`6ojW1j`;oYl7/1onZ`>X2oj_0j@Go
Zl7Y2?nZ`>X2oj[1jPGoZL3[2?n``nP8ok?4i`;oZ<3[1OnX`N/6ohJ`l0CoKJ7`00?o0000offQl?n8
[nl01_n8[nl6ojg2j@03ojk2j?o1c>?o`LcS00Go`LcS00?o`LkTooooooooool05?ooool00ol0003o
ooooooooo`0Cooooo`003_ooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000oooooooo
ool01_ooool00onW`>_oZ<7[ojS1j`0<ojS1j`03ojNojonV_n_oY[o[00CoY[o[2?nW`>/6ojNoj`Ko
XKSY1_nI[nH3oiFYi0?oTjSU2OnO^>X00on/bNoo_MoaokgOl@05okgOl@?oaNG^1?nmgNl4okC>k@?o
Y[cY0ol00002ojJlj@?oXKGW0onQ]^P7oj:hj0KoYKcZ00?oYkkZojJmjOnV_NT01OnV_NT6ojJlj@03
ojJmj_nW_^[oYkkZ00KoYkkZ1OnW_nX=ojO1k0CoYkkZ1onW_^/2ojNoj`GoZ;kY2?nW_^/00onV`>co
Ykk[ojNnj`04ojNnj`OoY/3/0_nY`N/6ojO1k0GoZ/3Z00?oZL7[oj_1jOn[`NT01_n[`NT6oj[0jP;o
Z/7Z1onY`>/8ok33j0Ko/lCW00?o/lGWojS1jonX`N/01_nX`N/6ohJ`l0CoKJ7`00?o0000ohR_kon8
[nl01_n8[nl2ojg2j@Go[/;X1?o1c><4ol7>i1Kooooo00?o0000ooooooooool04_ooool000kooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o00002?ooool=ojS1j`03ojNojonV_n_oY[o[00Ko
Y[o[2?nW`>/6ojNoj`KoXKSY0onI[nH3oi:Xi@KoTjSU1onO^>X3ok3<kPCo_Moa1oo5iNh00onmgNoo
]<k]okC>k@03okC>k@?o00001?nV_>T00onO]NSoXKKXoj6fj005oj6fj0OoX[SX0_nU_>X5ojNnjPOo
Y[gY0_nV_>T5ojJmjPSoYkkZ00?oYkoZojO1k?nW`N`02_nW`N`9ojNnjPGoYkk[2OnX_^T6ojNnj`;o
ZKoY1onW_^/3ojK0k0CoY[o[2?nW`N`00onZ`>[oZL7[ojW1j`03ojW1j`SoZl7Y0_nZ`>X6oj[1jPKo
ZL3[2On``nP2ok?4i`Go/lGW1_nX`N/00onV`>coQZk_ohJ^k`04ohJ^k`CoKio^00?o0000offQl?n8
[nl00on8[nl3ohb^k@So[/;X00?o`LcSol7>i?o1c^@01Oo1c^@Eooooo`03o`000?oooooooooo01;o
oooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`08ooooo`Wo
Z<7[1OnW_n/8ojJoj`SoYl3[1_nW_n/3oj6hj@?oUjoW1_nBZ>D6oi>Xi@CoWkSZ1_n`c>h00onmgo7o
aNG^olGUkP06olGUkP;o_]W^0ondc^d2o`0000;o]<k]0_nV_>T5oinej0OoXKKX1OnR^>P2ojJnj`Oo
YkkZ1OnV_NT9ojJmjPKoYkkZ2onW`N`=ojNnjP03ojNnjonX_^WoZ;kY00_oZ;kY0_nW_^/6ojVoj@Go
Ykk[00?oZKoZojJojonV_n/01_nV_n/6ojO1k003ojK0k?nY`N_oZL7[00GoZL7[1_n[`NT2oj_1jPSo
Z/7Z1_nY`>/8ok33j0So/lGW0_nX`N/5ojK0k0KoQZk_1?m_Wnh00ol0003oS:k]ohb^k@06ohb^k@Ko
[/;X00?o/LCWol7>i?o1c^@01Oo1c^@2ol7?iAGooooo00?o0000ooooooooool04Oooool001Sooooo
00?o0000ooooooooool02Oooool8ojS1j`KoYko[1_nV_n/:ojO0j`?oYko[0onO^>X6oiN_i`KoTZSU
1_nCZ>D00onO^>[o/<c^ok3<kP05ok3<kP?o`]o^1Oo5iNh4okkIkP?o00000ondc^d2oj>jj@OoWkGX
1onQ]^P00onR^>SoY[k[ojJnj`04ojJnj`OoYkkZ00?oY[gYojJmj_nV_NX02onV_NX2ojNnjP_oYl7/
0_nX_nX=ojNnjP03ojRnj_nX_^WoZ;kY00_oZ;kY0_nY_nX8ojVoj@03ojNnjonY_n[oZKoZ00?oZKoZ
2?nV_n/2ojO1k0GoY/3/1onY`N/2oj_1j@KoZl7Z1_nZ`NX00on[`N[oZL3[ojW0j`05ojW0j`So/<?X
1_ncaNL2ok?6j0OoY/3/1_n6[^l4ofnOkP03o`000?n<[^goS:k]00GoS:k]1?n^`^P4ok74i`Go`LkT
1?o1cnDEooooo`03o`000?oooooooooo013ooooo000Hooooo`03o`000?oooooooooo00[ooooo2?nX
`N/6ojNoj`;oY[o[3?nW`>/00onW_n_oWkSZoinhjP05oinhjPKoUjoW1_nBZ>D3oi>Xi@CoX[_[1On`
c>h6ol;OkP04olGUk_nnfNko_]W^okkIkP?o00000_nnfNh00ondc^goXk[Yoj>jj@04oj>jj@OoWkGX
0onQ]^P4oj>jj@OoY[k[0onW_^X4ojFmjP_oY[gZ0onW_n/9ojO1k0KoZ;oZ2OnW_^X5ojRnjPWoZ;kY
1_nY_nX6ojVoj@03ojW0j_nY_n[oZKoZ00GoZKoZ1_nV_n/2ojNoj`OoY/3/1onY`N/8oj_1jP;oZ/7Z
1On[`NX7ojW0j`So/<?X0oncaNL5ok?6j0OoY/3/1_n6[^l4ofnOkP03o`000?n<[^goS:k]00GoS:k]
00?o[/;Xok74ionaa>L01?naa>L3ol7>i0Oo`LoU5?ooool2o`00017ooooo000Gooooo`?o00003Ooo
ool7ojS1j`?oYko[1?nV_n/9ojO0j`GoYko[1onO^>X6oiN_i`?oTZSU0onBZNH7oj:kj`?o/<c^1_o2
gnh2olORj`?o00001?nnfNh3ok?<k@KoXk[Y1OnO]NP2oj2gj0OoXk[Y1OnV_^/2ojJnjPOoYKgZ1_nV
_NX00onV_^_oYko[ojNoj`05ojNoj`KoYl7/00?oZ<3[ojRoj_nX_nX01_nX_nX7ojNnjPOoZ;kZ1OnX
_^T2ojS0j`SoZKoZ0_nY_nT5ojW0jPOoZKoZ0_nV_n/6ojNoj`OoY/3/1onY`N/>oj_1jPSoZL3[2?n`
`nP00oncaNOo/lKXok?6j005ok?6j0?oY/3/0onQ_^h6oh>ZkPCoLYk/00?o0000ofnOk_n<[^d00_n<
[^d3oi6`j`So/LCW00?o`LkTol7?iOo1cnD01Oo1cnD00oo0dNOoooooooooo`0Aooooo`03o`000?oo
oooo0000017ooooo000Gooooo`03o`000?oooooooooo00kooooo1OnX`N/2ojNoj`OoY[o[1OnW`>/9
ojNoj`OoWkSZ0onG[nL2ohnXiPOoTZWV1onR^n/00on`c>ko`]o^ol;OkP03ol;OkP04olORjol0003o
0000o`0000?oan;[00?o_]W^ok?<kOncc>d01Oncc>d6oj>jj@03oinej?nP]nSoX;OX00CoX;OX1onS
^^T00onV_^_oY[kZojJnjP04ojJnjPOoYKgZ0_nV_NX5ojJnj`OoYko[0_nW`N`5ojS0j`SoZ;oZ1onW
_^X7ojRnjP03ojRnjOnX`>_oZ<3[00CoZ<3[1_nY_nX00onX`N_oZL3ZojW0jP06ojW0jPGoZKoZ0_nY
`>X8ojNoj`?oY/3/0onV_n`8ojW1j`koZl7Z2?nY`>/6ok33j003ok34j?nca^So/lKX00Go/lKX00?o
/lKYoj6nk_nQ_^h01OnQ_^h6oh>ZkPCoLYk/00?o0000oi6`jonA/>/01OnA/>/6ok74i`;o]/KV1_o1
cnD3ol3AiaCooooo00?o0000ooooooooool03oooool001Oooooo00?o0000ooooooooool03oooool0
0onX`N_oYko[ojNoj`04ojNoj`OoY[o[00?oYl3[ojNojonW_n/02onW_n/3oinhjP?oUZoY1_n?Z>H7
oi:YiPGoX[_[1?nccNd01?o2gnko0000o`000?l00005olORj`;o_mS/2?ncc>d3oj>jj@;oW[GX2?nP
]nP5oj>jj@03ojNojonV_^[oY[kZ00KoY[kZ1OnU_NX00onV_N[oY[k[ojJnj`06ojJnj`GoYko[0onX
`N`6ojS0j`KoZ;oZ2OnW_^X3ojRnjPCoZ<7[1onX`>/2ojVojPGoZ<7[2?nY`>X00onY_n[oZL3ZojW0
jP04ojW0jPKoYko[00?oZL3ZojJok?nV_n`01OnV_n`6ojW1j`03ojS0jon[`N[oZl7Z00goZl7Z2?nY
`>/2ok33j0Go/<CX1?nca^P4ok?6j@KoXKk^1_n3Z^h5og:Nk003o`000?nA/>_oTK3[00GoTK3[0_na
a>L6okK6iP?o`LoU1_o0dNLDooooo`03o`000?oooooooooo00kooooo000Gooooo`03o`000?oooooo
oooo013ooooo1onW_n/5ojJoj`goYko[0onP^^/6oiJ_j@KoSjSV1onBZNH00onR^n_o/lg]ok?=k@03
ok?=k@?o00000_o5gN/4olORj`Go_mS/1_ncc>d00onR^n[oW[GXoijej004oijej0SoX;OX00?oXk[Y
ojNojonW_n/00onW_n/8ojJnjP03ojFmj_nV_N[oY[gZ00?oY[gZ2?nV_^/00onW_n_oZ<7/ojS1k005
ojS1k0KoZ<3[0_nX_nX;ojNnjP03ojO0k?nX`N_oZ<7[00KoZ<7[1OnX`>/00onW`^goZ<7[ojS1j`06
ojS1j`KoZL3Z0_nY`>/7ojW0jP;oYko[1OnY`>X7ojJok0;oZL7[1OnX`>/?oj_1jPKoZL3[00?oZL7[
ok34j?n`a>P01_n`a>P00onca^So/lKYok?6j@04ok?6j@OoXKk^1_n3Z^h5og:Nk004o`000?nA/>_o
TK3[oi6`j`?oV;C[2Onfa^H00oo1cnGo`=7Wol3Ai`04ol3Ai`03okgAjOoooooooooo01?ooooo00?o
0000ooooooooool03Oooool001Oooooo0_l0000Booooo`OoYko[00?oY[o[ojNojonW_n/02_nW_n/2
ojO0j`KoX;[[1_nF[nT5ohnXiPKoTZWV0_nR^nX2ok?=k@?o000000?o/lg]olGMjoo5gN/00oo5gN/0
0oo7h^_o_mS/okoHk006okoHk0;o/lc]1OnR^nX6oijej0KoX;OX0_nS^nX6ojNoj`KoY[kZ00?oYKgZ
ojJmj_nV_NX01OnV_NX6ojJnj`[oZ<7/0onX`>/<ojNnjPGoYl3/2?nX`N/00onX`>_oYl;]ojO2k@03
ojO2k@SoZ<7[0_nY`>X6ojW0j`koZL3Z1onV_n`7ojS0j`ooZl7Z0_nY`>/5ojW1j`Ko/<CX0_naaNT7
ok?6j@?oXKk^1?nJ^^l5ognUk0GoMigY00?o0000oiRdjonH]>/01OnH]>/7okK6iP03ok_;i_o0dNOo
`=7W00Co`=7W0onmdNTDooooo`03o`000?oooooooooo00gooooo000Gooooo`03o`000?oooooooooo
01;ooooo1OnW_n/3ojJoj`SoYko[1_nW`>/6oj2jj`KoUZoY1On?Z>H2oi:YiPGoX[_Z0_l00002ok?=
k@KoaMg[0oo9gnT6okoHk0?o]Lk]1_nR^nX6oijej0;oX;OX1_nS^nX6ojNoj`;oY[kZ1OnU_NX7ojJm
jP;oY[k[3?nX`N`>ojNnjP03ojNojonW`>coYl3/00GoYl3/1_nX`N/8ojO2k@KoZ<7[0_nV`Nd8ojW0
j`koZL3Z1onV_n`7ojS0j`goZl7Z0_nZ`^/7ojW1j`;o/<CX1_naaNT5ok?6j@;o/LOZ1onJ^^l5ognU
k0GoMigY00?o0000oiRdjonH]>/01OnH]>/4okK6iPCo^l_V0oo0dNL5okgAjAGooooo00?o0000oooo
ooooool03?ooool001Oooooo00?o0000ooooooooool04oooool00onW_n_oY[o[ojJoj`05ojJoj`Go
Yko[2OnW`>/6oj2jj`?oUZoY0_n>ZNP7ohnYi`;oX[_Z0ol00002oj:kjP03ok?=kOo5gN_oaMg[00Co
aMg[1_o9gnT00onof>co]Lk]okG>k@05okG>k@KoX[_Z0onN]NP4oingj@OoXk_Z0onW_n/4ojJnj`Ko
YKgZ1OnV_NX3ojJnj`WoZ<7/3_nW_^X5ojNoj`OoYl3/0_nX`N/<ojO2k@;oZ<7[1_nV`Nd6ojW0j`03
ojS1jonY`>[oZL3Z00_oZL3Z00?oZL7[ojJok?nV_n`01_nV_n`7ojS0j`WoZl7Z1_nZ`^/5ojW1j`03
oj[1jonaaNWo/LGY00Oo/LGY00?o/lKYok77j_naanX01?naanX7oiZjk`GoOjG/1OmgWNT00ol0003o
V;C[oiRdj`05oiRdj`03okK6i_nkbnKo^l_V00Go^l_V00?o`=7WokgAjOnmdNT01OnmdNTEooooo`03
o`000?oooooooooo00_ooooo000Gooooo`03o`000?oooooooooo01Gooooo1onV_n/00onW_n_oYl3[
ojO0j`0;ojO0j`?oX;[[0onF/NX5ohjYj0GoSjWW0ol00004oj:kjP?o/l[[1?o5gN/6olWOj@?o`]SZ
1onec^d3oj:kjP;oWKKY2?nO]nT5oj>kjP03ojNojonV_^_oY[k[00KoY[k[1_nU_NX00onV_N[oY[k[
ojJnj`05ojJnj`GoZ<7/00?oZ<7[ojNnj_nW_^X02onW_^X2ojNnj`OoYko[1OnW`>`=ojO2k@?oY[o/
2?nV`Nd2ojW0j`GoZ<7[2OnY`>X5ojW1j`OoY[o/2?nX`>/5oj_1jP;oZl;[2?nZ`^/00onY`N_oZ/7[
oj[1j`03oj[1j`Oo/LGY00?o//OZok77j_naanX01_naanX3oiZjk`?oT[;]1?mkXNX2ognUk0GoMigY
00Co0000oiRdjonH]>_oV;C[0onO^>X7ok_;iP;o_m3W1_nmdNT00onjd>[oooooooooo`0Cooooo`03
o`000?oooooooooo00_ooooo000Fooooo`?o00005oooool5ojJoj`?oYko[2onW`>/2oj:mk0KoU[7Z
1On>ZNP01?n?ZNOo0000o`000?l00003ohnYi`03oj:kj_ncb^_o/l[[00Ko/l[[00?oaMg[olWOjOo9
gnT01?o9gnT5ol;HjPGo]Lk]00?oY;g/oiffjOnM]^T01?nM]^T8oingj@03oj>kj_nW_n_oYko[00?o
Yko[2?nV_^/3ojFmjP?oYKg[2?nV_^/00onX`NcoZ<7[ojS1j`03ojS1j`WoYkkZ1_nW_^/7ojNoj`03
ojO0k?nW`^goYl;]00[oYl;]00?oYkkZojJok?nV_n`01OnV_n`6ojK1k@;oYKo/1_nX`N/6ojW0jPWo
ZL7[1onV_n`8ojS0j`03oj_1j_n[`^_oZl;[00CoZl;[1onZ`^/7oj[1j`Co/LGY1?nbanX6ok77jP03
ojk6k?nB/^goT[;]00GoT[;]1OmkXNX5oh2Pj003o`000?nO^>[oWkSZ00GoWkSZ1?nkbnH5oko@i`;o
_M7Y1Onjd>XEooooo`03o`000?oooooooooo00[ooooo000Fooooo`03o`000?oooooooooo01Sooooo
00?oY[o[ojNojonW_n/01OnW_n/7ojO0j`KoX[g/1_nF/NX2ohjYj0?o00001On?ZNL3oingj@Ko/l[[
0oo4enP4olWOj@Oo`]SZ00?o]Lk]ojBmk?nT_N`00onT_N`6oiffj@KoWkOY00?oX[[ZojNojonW_n/0
1OnW_n/6ojJnj`SoYKg[1_nV_^/8ojS1j`KoYkkZ0_nV_^/7ojNnj`?oYko[1?nX`^`9ojO2k@GoYkkZ
1onV_n`2ojK1k@KoYKo/1_nX`N/2ojW0jPgoZL7[1onV_n`6ojS0j`03ojW0jon[`^_oZl;[00KoZl;[
1onZ`^/7oj[1j`03ok75jOnban[o//OZ00Go//OZ0_naanX5ojk6k0KoT[;]1_mkXNX5oh2Pj003o`00
0?nO^>[oWkSZ00GoWkSZ00?o^l_Voko@ionod>L01?nod>L2ol7Dj0Oo^]3Z4oooool3o`0000_ooooo
0004ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo00?o0000oooo
ooooool06_ooool7ojNoj`?oYl3[1?nX`>/6oj:mk0CoU[7Z0ol00004ohjYj003ohnYionO]nWoWkOY
00GoWkOY0oncb^/7olCGj003olWOjOo2f>[o`]SZ00Go`]SZ0_njd>/6ojBmk0KoWKKY0_nO]nT5oj:j
jPOoYko[0_nV_^/<ojFmj`;oY[k[3?nX`N/2ojNnjPKoY[k[1OnW_^/00onW`NcoZ<;/ojS2k006ojS2
k0GoYl;]0_nW_^T7ojNnjPGoY[o/0_nW_^X8ojFok0?oZ<7[0onW`>/?ojW1j`OoY[o/0_nX`>/5ojW0
j`SoZl;[1_nZ`^/6oj[1j`;o[<;Z1_nbanX2ok;8jPKo[/K/1onB/^d5og^QjPKoP:3X00?o0000oinh
j_nO^>X00onO^>X2ojRmj@Go_m3W1?o1e>P5ok[@jP;o]lk/3oooool3o`0000;ooooo00?o0000oooo
ooooool02Oooool000Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Kooooo00?o0000ooooooooool06oooool5ojNoj`03ojO0jonX`>_oZ<3[00KoZ<3[1_nR_N`3o`00
00;oSZc[1On<Z>P9oingj@03ok?:joo4enSoa=OX00Goa=OX0oo;g>H4ol;HjPGo^]3[1_nT_N`3oiff
j@CoW[OZ1_nR^^X5ojNoj`?oYKk[2onU_N/3ojJoj`[oZ<7[2onV_^/00onW_^_oYl7/ojO1k003ojO1
k0SoZ<;/00?oYl;]ojNnjOnW_^T01?nW_^T7ojNnjP03ojJok?nW_^[oYkkZ00CoYkkZ1onU_n`7ojO0
j`ooZL7[0onV_n`4ojJoj`OoZL3[2?n[`^/6oj[2j`;oZ/7[1_n/`^X3ok;7jPGo//SZ1_n^a^`3oi:b
k@?oRj[Z1?mjVnH2og^QjPGoP:3X00?o0000oinhj_nO^>X01_nX_NT3oko@i`Ko`MCX00?o^]3ZokO>
k?ngc^`01?ngc^`;ooooo`?o00001Oooool00ol0003oooooooooo`09ooooo`001_ooool00ol0003o
ooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_ooool2o`0001gooooo00?oYko[ojO0
jonW`>/00onW`>/8ojS0j`;oX[g/0ol00006ohj/j`GoS:SX1onO]nT3ok36jPCoa=OX1_o;g>H00oo2
f>[o^]3[ok[@j`06ok[@j`?oY;g/0onL]n/7oijgjPKoX[[Z00?oYko[ojFnjonU_^/01OnU_^/7ojFm
j`OoY[o[1_nX`N/=ojJnj`;oY[o[1_nW`N`6ojS2k0;oZ<3[1onW_^T3ojNnjPCoZKgX1onW_^X7ojFo
k0OoYl3[3_nY`N/8ojJoj`GoZL3[0_nY`N/8oj_2j`?oZ/;[0onY`N/8ojc2jP03ok;7j_nbb>[o//SZ
00Go//SZ0on^a^`3ojG1k@KoRj[Z1OmjVnH6oh^UiP03o`000?nX_NWoZ;gY00KoZ;gY00?o_m3Wol7D
j?o1e>P01?o1e>P00onoe^_o]lk/okO>k006okO>k0Kooooo1?l00008ooooo`03o`000?oooooooooo
00Wooooo0006ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000005oooo
o`;o00007oooool6ojO0j`KoZ<3[00?oYKo/o`000?l000001?nH]N`6ohj/j`GoS:SX1?nO]nT6ok36
jP03olCGj?o;g>KobmcV00GobmcV0oo7fNL6ok[@j`03oj_5kOnL]n_oW;O[00GoW;O[1onN]nX3oj:j
jP?oY[k[2?nU_^/6ojFmj`SoY[o[1_nX`N/9ojJnj`KoY[o[1_nW`N`2ojS2k0KoZ<3[1OnW_^T00onW
_NWoZKgXojVmj006ojVmj0GoYkkZ0_nY`NX7ojFok0GoYl3[0_nW_n/>ojW1j`SoY[o[00?oZL3[ojW1
jonY`N/01?nY`N/6oj_2j`03oj_3jonY`N_oZL7[00GoZL7[1_n/`^X00on^a>[o//SZok;8jP05ok;8
jP03ok;9jonU`NgoYL7]00GoYL7]1_n;Z^X5ogZKiPKoRjGV00?o0000ojRmjOnX_NT01?nX_NT2ok;5
j0Co`MCX1?noe^/6okO>k004ok7;kOooooooooooooooo`?o00003Oooool00ol0003oooooooooo`08
ooooo`001_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001Oooool0
0ol0003oooooooooo`0Oooooo`KoYl3[0_nX`>/01OnU_nco0000o`000?l0003oYKo/00KoV;G/1On>
[>/6ohbXj003oingjOn`a^[o/<KZ00Go/<KZ0oo0d>H4ol_LiPOoamWW00?o^]3[oj_5kOn[aNd00on[
aNd7oibgj`GoW[OZ00?oX;W[ojJnjonV_^/01OnV_^/6ojFnj`03ojBmjonU_N_oYKg[00GoYKg[1_nV
_n/8ojS1j`SoY[k[1onV_n/3ojO1k0?oZL;/2?nX`>/00onW_^WoYkgYojNmj@03ojNmj@SoZKgX00?o
YkkZojW1j_nY`NX01?nY`NX7ojFok003ojO0jonW_n_oYko[00CoYko[3_nY`N/7ojJoj`SoZL7[0_n[
`^/5oj_3j`OoZL7[0_n/`^X5ojk4jPCo//SZ1?nbbN/7ojG1k@GoRj[Z1_mjVnH6oh^UiP03o`000?nX
_NWoZ;gY00Ko//GX00?o`MCXokoFjonoe^/01Onoe^/2okO>k0Go/L_]0_l0000@ooooo`03o`000?oo
oooooooo00Sooooo0006ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4005ooooo`03o`000?oooooooooo023ooooo1OnW`>/3o`0000GoYKo/1_nH]N`5ohj/j`?oS:SX1?nH
/NT5ok36jPKo`=3V00?obmcVolOIioo7fNL01Oo7fNL2okoBj0KoZlG]1onL]n/00onN]n[oX;W[oj2i
j`03oj2ij`OoY[k[0_nU_^/5ojBmj`OoYKg[0_nV_n/<ojS1j`SoY[k[1OnV_n/00onX`>_oZL;/ojW2
k005ojW2k0KoZ<3[00?oY[k[ojNmjOnW_NT01OnW_NT6ojVmj0;oZl7Z1onY`NX3ojFok0CoYKk/1onW
_n/>ojW1j`OoY[o[1_nY`N/00onZ`^_oZl?[oj_3j`05oj_3j`KoZL7[00?oZ<7[ojk4j_n^a>X01_n^
a>X00onbb>[o//W[ok;9j`05ok;9j`?oYL7]0onI]N/4ohFRi`;oRj[Z1_mjVnH3oh^UiP;oUjoW00?o
0000ok;5j?nbaNP01OnbaNP00onkd>Wo_mK[okoFj`05okoFj`03ok_Ck?nabngo/L_]00Ko/L_]4Ooo
ool00ol0003oooooooooo`08ooooo`001_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2o`0002;ooooo00CoYl3[o`000?l0003o00000onW`>/6ojFok0?oV;G/
0on@/>`5ohRXjPOoV;7Y0on`a^X6ol3@iP?ob]OS1?o7fNL5okoBj0KoZlG]1onL]n/6oj2ij`GoY[k[
0onV_n/6ojBmj`GoYKg[0_nV_^/;ojS1j`?oY[o[2?nV_^/00onV_n_oZ<3[ojS0j`03ojS0j`OoZL;/
0_nX`>/5ojJnj`OoYkgY0_nY_NP6oj_1jPGoZL7Z00?oZL;[ojFnk?nU_^`01_nU_^`5ojNoj`;oZ<3[
3?nY`N/2ojO1k0OoY[o[0_nY`N/5oj[2j`OoZl?[0_nY`N/5ojS1j`Ko[/CZ0_nab>/6ok;9j`03ojo8
kOnI]N_oVKG[00GoVKG[1On5X^L6ogjJi0KoUjoW00?o0000ok;5j?nbaNP00_nbaNP4ok_@j@Co_mK[
1?nkdn`6ok7;k@03oj[4k?oooooooooo00oooooo00?o0000ooooooooool02?ooool000Cooooo00?o
EEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool0
7oooool3o`0000OoYl3[0onU_n`3oifkk@KoT;3/1On8Z>X7oiRaj@03ok36j_o0d>Ko`=3V00Co`=3V
1Oo:en<00oo7fNOo_m;XokoBj006okoBj0?oZlG]1?nO^nd6oibgj`KoX;W[00?oY[k[ojJojonV_n/0
1OnV_n/6ojBmj`03ojFmjonV_^_oY[k[00CoY[k[1_nX`N/00onY`N_oY[o[ojJoj`05ojJoj`KoY[k[
0_nV_n/6ojS0j`GoZL;/0_nW`>`7ojJnj`GoYkgY0_nW`>/8oj_1jP03ojW1j_nY`^_oZL;[00?oZL;[
2?nU_^`00onW_n_oZ<3[ojS0j`04ojS0j`SoZL7[1_nW`N`5ojJoj`;oYko[1onZ`^/5oj_3j`;oZ/?[
1onX`N/2ojk4jPKo/LS[0onbbN/4ojo8k@KoVKG[1_n5X^L6ogjJi0KoUjoW00?o0000ok;5j?nkd>T0
1_nkd>T00onoe^_o^m?/ok_Ck005ok_Ck0;o/L_]1OnZa>`@ooooo`03o`000?oooooooooo00Sooooo
000Eooooo`03o`000?oooooooooo01cooooo0ol00004ooooo`SoYl3[1OnM^nd6oi2`k0GoR:SZ1OnH
/NT3oj_1jPCo`=3V1Oo:en<3ol_GhPKo_m;X0_nfc>X7oinkk@KoW;O[0onP^N/3ojBmj`SoY[o[1_nT
_N/7ojJnj`;oZ<7[1OnY`N/7ojJoj`;oY[k[1_nV_n/6ojS0j`03ojW2k?nW`>coYl3/00CoYl3/1onV
_^/00onW_NWoYl3[ojO0j`04ojO0j`KoZl7Z0_n[a>`6ojW2j`KoYKk/00?oYKg[ojS0jonX`>/01_nX
`>/3ojW1j`?oZL;[2?nW`N`00onV_n_oYko[ojNoj`04ojNoj`OoZ/;[00?oZl?[oj[3jonZ`n/01?nZ
`n/5ojS1j`;oZ/;[2?nab>/00onbbN_o[lS]ojo8k@04ojo8k@KoVKG[1On5X^L6ogjJi0KoUjoW00?o
X[WYo`000?nkd>T01Onkd>T00oo0en_o^m?/ok_Ck005ok_Ck003okOAkOnZa>coZ/C/00KoZ/C/3ooo
ool00ol0003oooooooooo`08ooooo`005Oooool00ol0003oooooooooo`0Iooooo`?o00002?ooool8
ojO0j`GoWK_]1_n@/>`5ohRXjP03oiRajOn[`N[oZl7Z00KoZl7Z00?o`=3Vol[Ghoo:en<00oo:en<5
ol_GhP?o_m;X1Onfc>X7oinkk@?oW;O[0onM^N`6ojBmj`KoY[o[0_nT_^`6ojBmj`GoY[k[0onW_n/6
ojW1j`GoY[o[0_nU_^/8ojJoj`?oZ<3[0onZ`N/7ojO0k0?oY[k[1?nT_n`7ojO0j`;oZl7Z1_n[a>`6
ojW2j`;oYKk/1OnU_N/6ojS0j`;oZL7[1_nY`^/6ojO1k003ojJnjonW_n_oYko[00KoYko[0onZ`^/;
oj[3j`03ojS1jonZ`^_oZ/;[00CoZ/;[1_nab>/2ok79k0Oo[lS]0onI]N/2ohnYi`CoPI[R0_n5X^L6
ogjJi0;oUjoW1?nR^NT00ol0003o^m3Yok_@j@02ok_@j@Co`=O[1?nkdn`4okOAk@KoZ/C/00?oYl3/
ooooooooool03Oooool00ol0003oooooooooo`08ooooo`005Oooool00ol0003oooooooooo`0Foooo
o`?o00003Oooool7ojO0j`GoWK_]0on@/>`2ohR[k@KoSZcZ1on[`NX3okS8i`?ob]OS1oo;en800ono
d^So]/cZokK<jP05okK<jPGoWk_]00?oVkS]oifik?nM^N`01OnM^N`6ojBmj`;oY[o[1_nT_^`6ojBm
j`03ojJnjonW_n_oYko[00GoYko[1_nY`N/00onV_n_oYKk[ojFnj`04ojFnj`KoY[o[00?oYko[oj[1
jonZ`N/01OnZ`N/5ojO0k0;oYKo/1onT_n`5ojO0j`;oYl?]2?n[a>`3ojW2j`?oYl3[1onU_N/2ojS0
j`KoZL7[1_nY`^/2ojO1k0GoY[k[1_nW_n/00onY`N_oZ/?[oj[3j`0;oj[3j`03ojW1jonZ`^_oZ/;[
00KoZ/;[0_nab>/6ok79k0?o[lS]0onT`>d6ohnYi`GoPI[R1on9X><6oj:ij@03o`000?nkd>Wo`=O[
00Ko`=O[00?o^m?/okOAkOngdNd01OngdNd2oj[4k0GoYl3/3oooool00ol0003oooooooooo`07oooo
o`005?ooool2o`0001Gooooo0ol0000Aooooo`GoYl3[00?oY;k/oi>ckOnC/nd01?nC/nd5ohR[k@Ko
SZcZ1?n[`NX6okS8i`03ol[Ghoo;en;obmOR00GobmOR0oo7dn@7okK<jP03oinkkOnK^>goVkS]00?o
VkS]1onM^N`3ojBmj`CoY[o[1onT_^`3ojBmj`?oYKk[2?nW_n/3ojW1j`?oYl3[1onU_^/2ojJoj`Go
Yko[1onZ`N/00onW`>coYKo/ojFok004ojFok0OoY;o/00?oYl3[ojO3kOnW`nd01?nW`nd6oj_4k003
ojW2k?nW`>_oYl3[00GoYl3[1OnU_N/2ojNoj`SoZL7[0onY`^/3ojW2k0OoY[k[0_nW_n/5ojW1j`Wo
Z/?[1OnY`N/6oj[2j`03ojk6k?nabNco/LW/00Go/LW/00?o/L_]ojC0kOnT`>d01OnT`>d6ohnYi`Go
PI[R1on9X><5oj:ij@03ojo4jOl0003o`=O[00Go`=O[0onnfNd5okOAk@;o/<_^1_nW`>`?ooooo`03
o`000?oooooooooo00Oooooo000Dooooo`03o`000?oooooooooo01;ooooo0_l0000Eooooo`03ojO0
jonT_^coY;k/00?oY;k/1_nC/nd5ohR[k@KoSZcZ00?oZl7ZokS8ionhb>L01Onhb>L3olC>hPCobmOR
1_o7dn@3okK<jPCoZ/G]1_nK^>d5oifik003oinjk?nV_n_oY[o[00KoY[o[1_nT_^`7ojFnj`KoYko[
0_nY`>/6ojO0j`GoYKk[0_nU_n`7ojNoj`GoZ/7[0_nZ`NX7ojFok0?oY;o/1?nT`>d7ojO3k@;oZlC/
1OnY`^`7ojO0j`03ojFmjonW_n_oYko[00CoYko[1_nY`N/8ojW2k0OoY[k[1onY`N/5oj[3j`;oZ/?/
1onY`N/2oj[2j`Go[/K/1?nabN`4ok7;k@KoY<3]1_n?ZNL6oh6JhPOoRJ3S00?oX[WYojo4jOn_a>T0
0on_a>T01?l0003o`=O[ol3Gjoo0en/6okkIk@03okOAkOn`bnko/<_^00Co/<_^1_nW`>`>ooooo`03
o`000?oooooooooo00Oooooo000Dooooo`03o`000?oooooooooo00oooooo0ol0000Hooooo`KoY;k/
1_nC/nd5ohR[k@?oSZcZ1?nN]nT5okS8i`Koa<kR00?obmORolOCi?o7dn@01?o7dn@3ol7>i@KoZ/G]
1_nK^>d00onM^NcoWk[/oinjk003oinjk0SoY[o[1_nT_^`7ojFnj`;oYko[1_nY`>/6ojO0j`03ojFn
jonU_ncoYKo/00CoYKo/1onW_n/00onZ`N_oZ/7Zoj[1jP04oj[1jPGoYKo/0_nU_^`7ojC0k@GoYl?]
0_nW`^d7ojW2k0?oYl3[1?nV_NX7ojNoj`;oZL7[3?nY`^`7ojJnj`OoZL7[00?oZ/?[oj[3k?nZ`n`0
1?nZ`n`7ojW1j`Oo[/K/00?o/LW/ok7;kOnabnd01?nabnd7ojC0k@KoSjWW1_n1V^83ohVPh`?oV:kV
1_n_a>T00ol0003o[lCYol3Gj`06okkIk@03okWDk_n`bnko/<_^00Ko/<_^0onW`>`3ojNoj`gooooo
00?o0000ooooooooool01oooool001Cooooo00?o0000ooooooooool03?ooool3o`0001cooooo1_nT
_^`3oi>ck@?oSK3^1On5ZN`7oijgj@?o^<SW1_o4c^82ol_Bg`Goam?T1Oo1c^D6oj[5k@?oVkS]0onJ
^>d6oinjk0KoY[o[0_nV_n`6ojBnk0GoYKk[0_nU_n/8ojW0j`?oYl3[0onV_n`7ojFok0?oYko[1?nX
`>/7oj[1jP03ojFok?nU_^coYKk/00CoYKk/1onT`>d00onW`ngoYl;]ojO2k@04ojO2k@GoZL;/00?o
YkgZojJmj_nV_NX01_nV_NX5ojNoj`;oZ<7/3?nY`^`2ojNoj`OoY[k[0onY`N/;oj[3k0OoZL7[1On^
a^`3ok3:k@Ko/L_]0onT`>d3oiJ]i`KoR9oR1_n4VN07oiR^iPKo[lCY00?o0000ok_Ck?nnfNd00onn
fNd4okWDkPKo/<_^00?oZL?/ojNojonW_n/01OnW_n/<ooooo`03o`000?oooooooooo00Oooooo000C
ooooo`?o00002_ooool3o`00023ooooo0onT_^`3oi^kkPKoSK3^1On5ZN`7oijgj@03okS8ioo4c^;o
a<kR00Coa<kR1?o;d]l3olOCi0Oo`LkU0onZaNd3oj2mkPKoV[S]1_nO^^`2ojJoj`KoY[o/1_nT_^`0
0onU_^_oYKo[ojFoj`04ojFoj`KoZL3[00?oZL7[ojJok?nV_n`01OnV_n`6ojFok0SoZ<3[1OnZ`NX2
oj[0jPOoYKk/0onT`>d4ojJok0OoYl;]00?oZL;/ojNmj_nW_NX00onW_NX8ojJmjP03ojNojonX`Nco
Z<7/00CoZ<7/2?nY`^`6ojNoj`GoY[k[0_nX`N`<oj[3k003ojW2k?nY`N_oZL7[00KoZL7[00?o[/K/
ok3:kOn`b^d01On`b^d3ok7;k@?oZlG]1_nF[NL6ohROhPKoQ9WP1_nH[^H4ojo4j@?o^m?/00?o0000
ok_Ck?nnfNd01onie>h2ok3;kPGoZL?/1onW_n/;ooooo`03o`000?oooooooooo00Oooooo000Doooo
o`03o`000?oooooooooo00Kooooo0ol0000Uooooo`GoVk_^1_n=/>h5ohFYk0GoW[OY0on]`NP3olC>
hPOobm;O00?oam?Tol7>iOo1c^D01Oo1c^D2ok_;iPKoX;g^1_nJ^>d3oinjk0CoXkc[1onV_n`6ojBn
k0OoYKo[0_nY`>/5ojW1j`OoY[o/1_nU_n`8ojS0j`03oj[1j_nZ`>[oZ/3Z00CoZ/3Z1OnU_^`00onW
_^[oY[o/ojJok006ojJok0GoYl;]0_nW_^T6ojNmjPKoY[gZ00?oYl3[ojS1k?nX`N`01_nX`N`6ojW2
k0SoYko[00?oY[k[ojS1k?nX`N`01?nX`N`8oj[3k0GoZL;/1_nY`N/00on/aNco/<[]ok3:k@05ok3:
k@03ok7<k_n[aNgoZlG]00GoZlG]1_nF[NL6ohROhPGoQ9WP1onH[^H00on_a>Wo^m?/ok_Ck003ok_C
k003o`000?nofnko_m_^00Ko^MC^00?o]=3^ojW3k?nY`n`01_nY`n`3ojNoj`?oZ<3[2oooool00ol0
003oooooooooo`07ooooo`005?ooool00ol0003oooooooooo`03ooooo`?o0000:Oooool5oi^kkPKo
SK3^1On5ZN`00onN]nWo[L7Xojg1j005ojg1j003olC>h_o;d]oobm;O00Gobm;O0oo;dMh4ol7>i@Go
^l_V1_nP_Nh3oiZhk@CoVk[]1_nS_>/5ojJok0;oYKo/1_nT_^`5ojFoj`?oY[o[1_nY`N/5ojJok0So
YKo/2?nX`>/7oj[0jP03ojFnk?nW_^[oYkkZ00?oYkkZ2?nV_n`00onW`^goYkkYojNnj@04ojNnj@Ko
YkgZ0_nV_NX5ojO0j`KoZ<7/2?nY`^`6ojNoj`03ojJnjonX`NcoZ<7/00KoZ<7/1_nZ`n`7ojW2k0;o
ZL7[1On/aN`4ok3:k@Co/Lc^1on[aNd6oiJ]i`KoR9oR1On4VN03oiR^iPCoY;_Y1?nkdn`2okoKkP03
o`000?nofnko_m_^00;o^MC^1Ondd>h6ojW3k003ojNojonX`>_oZ<3[00GoZ<3[2oooool00ol0003o
ooooooooo`06ooooo`004oooool01?l0003oooooooooooooool3o`0002gooooo1OnK^nh3ohf`kP;o
QJg_1_n<[^`6ojg1j0?o^<KU1Oo;d]l6ol_AgP03ol7>iOnkbnKo^l_V00Go^l_V0onP_Nh3oi^kkPOo
Vk[]1_nS_>/00onV_ncoYKo/ojFok004ojFok0KoY;k/00?oYKo[ojJojonV_n/01OnV_n/6ojW1j`03
ojJok?nU_ncoYKo/00[oYKo/2?nX`>/5oj[0jP;oZ/7Z1_nW_^X6ojJok0;oZ;kY1onW_^T3ojNmjP?o
Yko[1onW`>/2ojS1k0coZL;/0_nW_n/5ojJnj`KoZ<7/00?oZL?/oj[3k?nZ`n`01OnZ`n`5ojW2k0;o
Z<7[1on/aN`00on`b^go/Lc^ok7<kP05ok7<kP?oZlG]0onL/NH6ohjRhPKoQISM1_n@Xn87ojBkj@03
ok_Ck?nofnko_m_^00?o_m_^00?o0000ok_Ikondd>h01ondd>h2ojW3k0GoYko[1onX`>/:ooooo`03
o`000?oooooooooo00Kooooo000Cooooo`Co0000<?ooool6oi>fk`GoQJg_1_n<[^`3ojg1j0Ko^<KU
0oo;d]l6ol_AgP;obLoN1_nkbnH00ondanSoVk_^oi^kkP05oi^kkPOoVk[]0onS_>/3ojFnj`OoYKo/
1_nT_^`8ojJoj`?oZL7[0onY`>/=ojFok0SoZ<3[00?oZ/3Zoj[1j_nZ`NX01?nZ`NX6ojNnjP;oY[o/
1_nX_^T5ojNnj@SoYko[1OnW`>/2ojS2k0_oZL;/0onW_^/7ojJnj`;oZ<7/1OnY`n`7oj[3k003ojW2
k?nX`N_oZ<7[00CoZ<7[1On/aN`3ojo;kPGo/Lc^00?o[<K]oibai_nL/NH01OnL/NH6ohjRhPKoQISM
1_n@Xn85ojBkj@?o]<g/0onofnh2ok_Ik`03o`000?nkfNoo]=3^00Go]=3^00?o[<K]ojNojonW_n/0
1OnW_n/7ojS0j`[ooooo00?o0000ooooooooool01_ooool001?ooooo0_l0000cooooo`KoTkK_1On5
[Nl6ohb^k003ojg1j?nha^Go^<KU00Ko^<KU00?obm;Ool_Ag_o;dMh01?o;dMh4olW?gP?o^l_V1?nd
anP7oi^kkP?oVk[]1?nL^nh6ojFnj`GoYKo/0_nT_n`6ojBnk0KoY[o[0_nW_n/6ojW0j`goYKo/1_nX
`>/2ojO0k0OoZ/7Z0onW_^X3ojW0jPSoZ;kY00?oYkkYojNojonW_n/02_nW_n/00onW`>_oZ<;/ojS2
k004ojS2k0KoZL;/00?oZ<3[ojNnjonW_^/01OnW_^/5ojJnj`;oZ<;/1onY`n`3oj[3k0?oZL;/2?nX
`N/00on/aNco[l_^ojo;kP05ojo;kP03ok7<k_n/a^go[<K]00?o[<K]1_nL/NH6ohjRhPKoQISM1on@
Xn800onT^nWo]<g/okC=k005okC=k005okoKk_nkfNoo^mW_ok_Ikol000000_nkfNl2okC@kPGo[<K]
1onW_n/7ojS0j`Wooooo00?o0000ooooooooool01_ooool000Go00000oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Sooooo00?o0000ooooooooool0<Oooool6oi>fk`GoQJg_0on<[^`4oiZfj`Ko^<KU
0oo1bN43ol_AgPOobLoN00?o^l_VokC7j?ndanP01?ndanP5oi^kkP;oVK[_1onL^nh6ojFnj`03ojFo
k?nT_ncoY;o/00CoY;o/1_nT_^`2ojJoj`KoYko[1_nY`>/=ojFok0;oZ<3[1_nW`>`5oj[1jP;oZ<7[
1_nY`>X6ojRnj@03ojS1jonW_n_oYko[00[oYko[2OnX`^`2ojW2k0GoZ<3[1onW_^/00onV_^_oZ<;/
ojS2k004ojS2k0GoZL?/0_nYa>`6ojW2k0KoZ<7[0_n[a^d6ojo;kP03ok3=kon/a^go[<K]00Go[<K]
1OnL/NH6ohjRhPKoQISM1_n@Xn800onO]NOo]<g/okC=k005okC=k0;o_M__1?nkfNl00ol0003o]]?_
okKCk`07ojc6k@?oYko[2onX`>/8ooooo`03o`000?oooooooooo00Kooooo00001OnHV9So8B4Qonk^
k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`09ooooo`03o`000?oooooooooo037o
oooo0onC]^l3ohfcl0KoPJ__1_nJ]^/3okS6i@Ko`LWQ00?obm7NolW?g_o9cmh01Oo9cmh3olK<g`Ko
]<OX00?oVk_^oiVjkonI^^l01?nI^^l7oibkkP?oYKk[0onV_n`7ojBok0?oY;k/1?nT_n`7ojNoj`?o
ZL3[0onY`>X:ojFok0?oYL3/2?nW`>`00onZ`N[oZ<7[ojS1j`04ojS1j`KoZL3Z0_nX_^T5ojS1j`So
Yko[2onX`^`2ojS1k0KoZ<3[1_nW_^/00onW`>_oZ<;/ojS2k006ojS2k003ojW3k?nYa>coZLC/00Co
ZLC/1_nY`^`2ojS1j`KoZlK]0_n_bnh5ok3=k`Oo[<K]1OnL/NH6ohjRhPKoQISM0_n@Xn85oinei`Co
]<g/1Onmfnl01OnkfNoo]]?_okKCkonfdnoo000000;o]]?_1On/a^d00onW`>_oZ<3[ojS0j`0;ojS0
j`03ojS1k?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00004oooooonHV9So8B4Qonk^
kPCooooo00Go410@oooooooooooooooooa0@400:ooooo`03o`000?oooooooooo03;ooooo1On=/o06
oh6[k`KoV[K[00?o^<KUol79hOo1bN401?o1bN43olK:g@CobLoN1_o6c=l3okC7j0Co[/CZ1_nI^^l5
oibkkP03oiblk_nV_ncoY[o/00GoY[o/3_nT_n`5ojNoj`;oYl3/1_nY`>X5ojFok0;oY[o[1_nU`>`6
ojO0k0;oY/7]1onX`N/3ojW0jP?oYl7/1onX`N/3ojNoj`CoYl;/2?nX`^`6ojS1k0KoZ<3[0_nW_^/5
ojO0j`KoZ<;/00?oZL?]ojW4k?nYa>`01_nYa>`3ojW2k0CoZ<7/1On[a^d2ojk;k`Oo/<g_0on/a^d3
oij`i@GoTj?P1_n9V=/6ohfNgPSoWkGW00?o]<g/okgKkonmfnl01?nmfnl00onkg?3o]]?_okKCk`03
okKCk`04o`000?nfdnoo]]?_ojc6k@GoYl3[2OnX`>/5ojS1k0Oooooo00?o0000ooooooooool01_oo
ool000;ooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000_ooooo0_l0
000cooooo`GoSK?`1_n1Znl3oiZfj`?oYkgY1Oo1bN46olK:g@03olW?g_o6c=ooa/cO00Coa/cO0oo3
bMl6ojk4jPKoVK[_00?oW;_^oiblk_nL_>h00onL_>h7ojJok0koY;o/00?oYko[ojO0k?nW`>`01?nW
`>`6ojW0jP03ojFok?nV_n_oY[o[00CoY[o[1_nU`>`2ojO0k0KoY/7]1OnX`N/2ojK1k@KoYl7/1OnX
`N/2ojO2k@OoYl;/1onX`^`7ojS1k0?oZ<3[0onW_^/7ojO0j`;oZ<;/1OnY`nd6ojW4k003ojS2k?nX
`NcoZ<7/00KoZ<7/00?oZlK]ojk;kon^bnl01?n^bnl5ok3=k`03oj_5k?nN/>GoW[3U00GoW[3U1OnC
Xn06ohVHf`KoSIkN1_nO]NL2ojk7k@Co_M__1?nkg?04okKCk`03o`000?nfdnoo[LW^00OoYl3[1_nX
`>/8ojS1k0Oooooo00?o0000ooooooooool01Oooool000?ooooo00?oMgMgofIVI_ooool00_ooool0
1Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool0<Oooool5ohfcl0?oPJ__0_n3
[Nl7ojNmj@?o`LWQ1_o6b]d2olW;f`Goa/cO1Oo3bMl6ojk4jP?oVK[_0onI^nl6oiblkPOoY[o/3?nT
_n`2ojBok@OoYl3/1_nY`>X7ojJoj`KoYL3/2?nV`Nd00onX`N_oY/7]ojK1k@04ojK1k@KoYl7/00?o
Z<7[ojO2kOnW`^d01?nW`^d7ojO2k0OoZ<;/1OnX`N`2ojNnjPKoYkk[1OnW`>/2ojS3k0OoZL?]0_nY
a>`5ojS2k0KoZ<7/00?o[<S_ojk;kon^bnl01_n^bnl00on`cNooZlG/oj_5k003oj_5k0KoW[3U1_nC
Xn06ohVHf`KoSIkN0_nO]NL6ojk7k@03okgKkonkg?3o^mc`00Go^mc`0_nfdnl2ojg9kP03o`000?n]
bNko[LW^00OoYl3[1_nX`>/6ojS1k003ojS1jooooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool000Cooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo00cooooo00?o
0000ooooooooool0<Oooool5ohJal@GoPjg_1onW_NT00oo1bN7oa/[MolK:g@04olK:g@CobL_K0oo6
c=l7ol?9g`?o[/CZ0onY`N/6oiVkk`KoW;c^1onV_n`8ojBok0KoY;o]1OnW`>`2ojK0k0KoZL3Z1OnV
_n/2ojNoj`KoYL3/3onV`Nd3ojO1k0?oY/;]1onW`^d7ojO2k0OoZ<;/00?oZ<7/ojNnj_nW_^X01?nW
_^X6ojNnj`03ojO0jonX`ncoZ<?/00CoZ<?/1onY`nd7ojS2k0;oZ<7/1On/b>l6ojk;k`03ojo=kon[
aNcoZlG/00GoZlG/1_nN/>D6oi>Sh0KoRISK0on=W]h3oifbiPKo[/O]0_nkfo46ok_Ll003okKEl?n]
bNko[LW^00?o[LW^00?o0000ojg9k_n]bNh01onW`>/6ojS0j`;oZ<7/1OnX`N/6ooooo`03o`000?oo
oooooooo00Gooooo00001Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0?ooooo`03o`000?oooooooooo037ooooo1On6/O45oh>]k`GoYkgY0on``^L4olK:g@KobL_K
00?oa/cOol?9goo3bMl01Oo3bMl2ol76g`KoZL7[1_nI^nl3oiblkP?oWKg_1onV_n`6ojBok0SoY;o]
00?oYl3/ojK0k?nV`>`01?nV`>`6ojW0jP03ojJojonW_n_oYko[00CoYko[1_nU`>`?ojK1k@KoY/;]
1OnW`^d2ojO1k0OoYl;/0onX`^`;ojNnjP?oYkk[1?nX`^`6ojS3k0OoZL?]1OnX`^`2ojS3k@Oo[<S_
0_n^bnl5ojo=k`OoZlG/0onN/>D2oiFQg@KoS9SI1_n>W=d7oifbiP?o[/O]1Onkfo42ok_Ll0Go]]G`
1On]bNh00ol0003oZ<7[ojO0j`07ojO0j`?oZ<3[0_nX`N`8ojS1j`Gooooo00?o0000ooooooooool0
1Oooool00005oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^013o
oooo0_l0000booooo`GoQ[7a1On3[Nl00onW_NWo/<;Wok32i`06ok32i`03olK:gOo9bm_obL_K00Co
bL_K0oo:bMT5ol?9g`Co`LKO1_nY`N/3oiVkk`?oV;_`1_nM_Nl5ojJok0;oY/3/1_nT_n`8ojBok@Oo
Y/3/0onY`>X3ojW1j`OoYko[0onU`>`3ojJnj`ooY/7]1_nV`^d00onW`^goYl7/ojO1k004ojO1k0Go
Yl;/3_nW_^X00onW`NcoZ<;/ojS2k006ojS2k0?oZ<?/0onYa>d7ojW3k@03ojS2k?nX`ngoZ<?]00Co
Z<?]1On/b>l3ojg<l0Ko[lg_0on[aN`3oif/h@KoUJ7M1_n<V=T6ohjLg@OoWK;V00?o[/O]ok_KlOnk
fo400onkfo42ok[Ml@Oo]]G`0_n]bNh2ojS1j`03o`000?nX`N_oZ<7[00OoYl3[1_nX`N`6ojS1j`03
ojNojooooooooooo00?ooooo00?o0000ooooooooool01Oooool001oooooo00?o0000ooooooooool0
<?ooool6oh6_lPGoRk7`1_n``^L2okK4i@GobL_K1Oo:bMT3ol?9g`Ko`LKO0onY`N/3ojNoj`KoV;_`
1_nM_Nl00onV_ncoY/3/ojK0k004ojK0k0KoY;o/2?nT_nd5ojK0k0;oYL3]1_nY`N/5ojNoj`;oZL3Z
1_nV_^/5ojK1k@;oY[o[2?nV`Nd3ojK2k@?oYl3[1onW`N`00onW`^coYkkZojNnjP0<ojNnjPGoYl7/
1_nX`^`00onX`ngoZLC]ojW4k@05ojW4k@GoZL?]0_nX`N`7ojS3k@03ojc8kon]c?3o[Lc`00Go[Lc`
0on_cNl2ojVmj0OoWJcQ1_nEXMd5ohbHf@KoSYcM1_nM/^H2oj_6k@?o^m_a1OnjgO45okKEl003ojk:
k_nX`N_oZ<7[00?oZ<7[00?o0000ojS1jonX`N/01onW`>/6ojS1k0;oZ<7[1OnW_n/4ooooo`03o`00
0?oooooooooo00Gooooo000Pooooo`03o`000?oooooooooo033ooooo1_n1[o85oh^al0?o/<;W1Onf
a>D3olW;f`Oob/WI00?o`lWOol76goo1a]l01?o1a]l2oko4gPKoYko[1_nH^o06oifmk`OoY/3/1onT
_n`7ojBok@03ojK0k?nU`>goYL3]00CoYL3]1_nY`N/00onW_n_oZL3ZojW0jP04ojW0jPKoY[k[00?o
Y/7]ojJojonV_n/01?nV_n/6ojK1k@03ojNnj_nW`>_oYl3[00GoYl3[1OnW`N`2ojRnjP[oYkkZ2_nW
`N`2ojS2k0GoZ<?]1onYa>d00onY`ngoZ<7/ojS1k004ojS1k0GoZ<?]0_n/bo06ojg<l003ojg9k_nY
_NSoZKgX00CoZKgX1_nM[>46oiFQg@GoS9SI1on>W=d2oifbiPKoZlK]00?o^m_aok[MlOnjgO401Onj
gO400onfeO3o[/[^ojk:kP03ojk:kPGoZ<7[00?o0000ojO0jonW`>/01onW`>/5ojS1k0SoYko[0ooo
ool00ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`0`ooooo`KoPJob1On;/O00
0on``^Oo]/CUokK4i@05okK4i@03olW;foo:bMWob/WI00Gob/WI0oo9amP3ol76g`Go_lCN1_nW_n/3
oiRkl0?oV;ca1_nM_Nl7ojK0k0SoY;o/0onT_nd3ojC0k@OoYL3]0onY`N/3ojO1k0OoZL3Z0onV_^/3
ojRojPOoY[o[0_nV`Nd5ojNnjPOoYl3[00?oYl7/ojRnj_nX_^X01?nX_^X5ojNnjPgoYl7/2OnX`nd3
ojW4k@?oZ<;/2?nX`N`00onX`ngo[<_`ojc;l004ojc;l0;o[Lc`1On]bNh6ojVmj0KoWJcQ1_nEXMd5
ohbHf@?oSYcM0onM/^H7oj_6k@;o^Mgb1_njgO42okGFl@Ko[/[^0_nX`N/2ojO0j`03o`000?nW`>_o
Yl3[00KoYl3[1onX`N`7ojNoj`Cooooo00?o0000ooooooooool01?ooool002;ooooo00?o0000oooo
ooooool0<?ooool3oh6_lP;oOJkc1_nC]^l6okK4i@;o^lGR1_o:bMT5olW7f003ol76gonoa=ko_lCN
00Go_lCN0onW_n/3ojNnjPKoV;ca1_nM_Nl7ojK0k0KoY;o/0_nU_n`6ojC0k@GoYL3]0_nU`Nd6ojO1
k0GoZL3Z0_nX`N/6ojRojPGoY[o[0_nX_nX7ojNnjP?oYl3[0onX_nX8ojRnjP03ojNnj_nW`NcoYl7/
00_oYl7/2onX`nd8ojS2k0KoZ<7/0_nYb?05ojc;l0;o[Lga1_n]bNh7ojVmj0?oWJcQ0_nFWMT6ohnH
f0GoT9gL1onM/^H4oj_6k@Go^Mgb0_njgO46okGFl@?o[/[^0onX`N/4ojO0j`03o`000?nW`>_oYl3[
00;oYl3[2onX`N`7ojNoj`?ooooo00?o0000ooooooooool01?ooool002?ooooo0_l0000aooooo`Go
OJkc1_nC]^l3okK4i@Go^lGR0oo:bMT6olW7f0;obLGG1_noa=h2oko2g@KoYkkZ1_nH_?43oifmk`Co
W;k`1_nV`>`2ojBok0KoYKo/1_nT`>d00onU`>goYL7]ojG1k@04ojG1k@KoYl7/00?oZL3ZojS1jonX
`N/01?nX`N/6ojRojP03ojJojonX_n[oZ;oZ00CoZ;oZ1OnW_^X2ojS0j`KoZ;oZ1_nX_^X<ojO1k0?o
Yl?]2?nX`nd<ojS2k0;oZ<7/1_nYb?000on/bo3o[Lgaojg=l@04ojg=l@Ko[LW^0onY_NP3oibVg@Ko
UYgI1_n?V=P5oi2Mg0OoWK;V00?oZlK]okWMl_nigO801?nigO82okWNl`Ko]MKa00?o[LW^ojS1jonX
`N/01OnX`N/4ojO0j`03o`000?nW`>_oZ<7/00[oZ<7/2_nW_n/2ooooo`03o`000?oooooooooo00Co
oooo000Uooooo`03o`000?oooooooooo02oooooo1Omm[_<6oi>fk`03okK4iOnkaN;o^lGR00Go^lGR
00?ob/WIolW7f?o9amP01?o9amP4olW5e`?o_lCN1Ono`]d6ojNnjPOoV;ca1_nL__03ojK0k0?oYL7^
2?nU_n`6ojC0k@OoYL7]0onW`N`3ojK1k@OoZ<7[0onX_nX3ojS1k0OoZ;oZ00?oYkkZojS0jonX`>/0
1?nX`>/6ojRojP;oZ;kZ2onW`N`8ojO3k@KoZ<?]2onX`^`4ojS4kPGoZLS`00?oZlgbojg=lOn]cO40
1_n]cO43ojg9kP;oY;7R1onLY]d6oiJMf@GoSiSH1_n@WM`5oifbiP?oZlW_0onigO85okWNl`;o]MKa
1On]bNh5ojS1j`KoYl3[00?o0000ojO0jonX`N`01_nX`N`<ojNoj`04ojO0joooooooooooo`0000Ko
oooo000Vooooo`03o`000?oooooooooo02oooooo1Omm[_<3oi>fk`?oV[[^1_nkaN83okg5h0CobLOH
1_o9aML00onoa=ko_l;Moko2g@05oko2g@?oYkkZ1?nY_NP6oiRll@?oW;k`0onK__46ojG1kPKoYKo/
0_nV`>`6ojC0k@GoYL7]0_nT`Nh6ojK1k@GoZ<7[0_nV`Nd6ojS1k0GoZ;oZ0_nX`^`7ojS0j`?oZ;oZ
0onW`^`9ojO1k0coYl?]1_nX`nd6ojS2k003ojO2kOnXa>koZ<C^00KoZ<C^00?oZLS`oj_=l_n[cO80
0on[cO86ojg=l@03ojZnj?nT/N;oY;7R00CoY;7R1_nLY]d6oiJMf@GoSiSH1on@WM`00onM/^KoZlW_
oj_9k`05oj_9k`03okWMl_nig_?o^Mkc00?o^Mkc00?o/mGbojg9k_n]bNh01_n]bNh00onX`N_oYl3[
ojO0j`07ojO0j`03o`000?nW`>_oYl3[00OoZ<7/2?nW_n/5ojO0j`03ooooool0003ooooo00Gooooo
000Wooooo`03o`000?oooooooooo033ooooo1?mk[o@6oiZjkP?o^lGR1onmaN000oo9amSobLGGolW5
e`04olW5e`;ob<?F1_no`]d2okk0f`OoZKgX0onH_?43oiVml@KoVkka1_nU`Nh2ojFok0KoY/3/1_nT
`>d00onU`NgoY<7^ojC1kP04ojC1kPKoY/7]00?oZ<7[ojK1kOnV`Nd01?nV`Nd6ojS1k003ojRoj_nX
`^coZ<;/00CoZ<;/1OnX`>/2ojO2k@KoYl;/1OnW`N`2ojO3kPkoYl?]1_nX`nd2ojS2k0GoYl;]1_nX
a>h2oj[<l@KoZlgb0_n]cO45ojZnj0KoY;7R1_nLY]d6oiJMf@GoSiSH0on@WM`4oinei`KoZlW_0ong
h?@00onig_?o/mGbok?ElP03ok?ElPKo[LW^3?nW`>/00ol0003oZ<7/ojS1k007ojS1k0KoYko[1onW
`>/00ol0003oooooooooo`04ooooo`00:?ooool2o`00037ooooo1?mk[o@6oiZjkP03ok_5h_nmaN3o
_LGP00Go_LGP0_noa=h5olW5e`Cob<?F0ono`]d5okk0f`GoZKgX0on]_ND5oiVml@KoVkka0onU`Nh4
oj;2k`OoY/3/0onT`>d3ojBok@OoY<7^0onV`Nd3ojG1kPOoY/7]0onX`N`4ojK2k@KoZ<;/00?oZ<3[
ojO2kOnW`^d01?nW`^d6ojO2k003ojO1k?nW`nkoYl?^00CoYl?^3_nW`nd3ojS3k@?oYl7/1onW`^d2
ojS4kPKoZ/ca0on[cO83oj_8kPKoZ[kX1onT/N83oibVg@;oUY[E1_nBVML6oiFSgPOoWkGW0_n[bNl5
okOPm0;o]]gd1_nceO82ojg9kPcoYl3[1?nX`N`00ol0003oZ<7/ojS1k005ojS1k0SoYko[1OnW`>/0
0ooooooo0000ooooo`05ooooo`00:_ooool00ol0003oooooooooo`0_ooooo`CoNjod0onJ^^h4oijl
kPCo_LGP1Onoa=h3olW5e`Kob<?F00?o_l;Mokk0fonn`=/01Onn`=/00onY_NSo[KgUojfmi@05ojfm
i@GoVKga0onK__43oi[0lPOoX/;_1OnV`>`2ojK2k@KoY;o]1OnT`Nh2ojC0k@KoYL7^1OnV`Nd2ojG2
kPOoY/;]0onX`^`3ojK2kPOoYl;]0onW`^`4ojK3kPKoYl?^3?nW`nd8ojO1k0GoYl;]0onYbo85oj[<
l@;oZlca1_n[b>h6ojZnj0?oY;7R0onKX=L6oiJJe@KoTYWG1_nEXmh5oinei`;o[]7b1?ngh?@5okKM
m0?o/mGb0on[a^d>ojO0j`CoZ<7/00Co0000ojS1k?nX`NcoZ<7/3?nW_n/00onW`>_oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo000[ooooo`03o`000?oooooooooo02oooooo1Omj[oD7oijl
kP03okg5h?noa=ko_lCN00Go_lCN00?obLGGolS3e_o8`mH01?o8`mH00oo7`MCo_/3Kokk0f`05okk0
f`?o_kgH1on]_ND2oiVml@CoVkc_1OnJ`?87oj;2k`03ojK0k?nV`^goY/;]00CoY/;]1_nT_nd00onT
`NkoY<3]ojC0k@04ojC0k@KoYL7^00?oY/7]ojG2k_nU`^h01?nU`^h5ojK2k@;oYL;^1_nV`^h5ojO2
k@WoY/?^0onW`nh;ojO3k@coYl7/00?oYl;]ojW;l_nYbo801OnYbo800onZc?7oZlcaoj_<l@04oj_<
l@KoZlS^0onZ_^P2oinVf`OoVj3G1_nFV]D5oi:Ie`OoUJ?N00?oWkGWojkAl_n^dO801?n^dO800ong
h?Co]]gdokKMm004okKMm003ok7BlOn[a^goZlK]00GoZlK]1OnW`>/00onX`>_oYl3[ojO0j`06ojO0
j`?oZ<7/00?o0000ojS1jonW_n/02_nW_n/9ooooo`03o`000?oooooooooo00?ooooo000/ooooo`03
o`000?oooooooooo02oooooo1Omj[oD5oijlkP;oXKk^2?noa=h5olS3eP?oal7D1Onn`=/5oknmf0Go
[KgU0_nb_>46oi^lk`GoV/3b0onR`^l4oik2l@OoY/;]0onT_nd4ojK0k0KoY<3]0onU`Nh4ojC1k@Ko
YL;^00?oY/;]ojG2k_nU`^h01?nU`^h6ojK2kP03ojO2kOnV`nkoY/?^00WoY/?^0_nV`^d:ojO3k@go
Yl7/1?nWbO85ojW;lP03ojW=lon[c?7oZlca00KoZlca0on[b>h2ojB]gPKoWjKK1_nKX=L6oiJJe@Ko
TYWG0onEXmh4oj>kjPGo[]7b0onfh_H3okKMm0Co/M;a1on[a^d00onW`>_oZ<3[ojS0j`03ojS0j`Ko
Yl3[00?oZ<;/ojS1jonX`N/00_nX`N/00ol0003oZ<7[ojNoj`05ojNoj`gooooo00?o0000oooooooo
ool00oooool002gooooo0_l0000`ooooo`GoNZoe00?oW[c^oj6nk_nQ_^h01?nQ_^h8oko4gP?ob<?F
1Oo7`M@3okk0f`Oo_kgH00?o[KgUok:lhOnb_>401?nb_>46oi^lk`;oV/3b1?nI_o<6oik2l@GoY/;]
00?oY<C`ojK0k?nV`>`01_nV`>`3ojC0k@;oYL3/2?nT`Nd3ojG2kP;oYL7]2?nU`^h3ojK2kP?oYL;^
2?nV`nh6ojK2k@GoYl?]3OnW`N`00onWbO7oYlWbojO9lP06ojO9lP03ojW;l_nYcO?oZLgc00?oZLgc
1_n[c?400onX]N;oY:gNojB]gP04ojB]gPKoWjKK1OnKX=L7oiJJe@?oTYWG0_nL[N<8oj>kjP03ojkA
l_nfh_Ko]^;f00Go]^;f00?o]]gdok7BlOnad_401?nad_43oj_6k@CoYko[1_nX`>/2ojO0j`GoZ<;/
1?nX`N/01?l0003oZ<7[ojNojonW_n/@ooooo`03o`000?oooooooooo00?ooooo000_ooooo`03o`00
0?oooooooooo02kooooo1Omh/?H7oj6nkPSo_lCN00?ob<?FolO1e?o7`M@01Oo7`M@00onn`=_o_kgH
oknmf005oknmf003ol6keOnb_>7o/[cQ00Ko/[cQ0onK_>l3oj6ijPKoVKoc1_nN`_400onV`^goY<C`
ojC4l003ojC4l0KoY/3/00?oY/C_ojG0k?nU`>`01?nU`>`6ojC1k@03ojG0k?nU`NgoYL7]00CoYL7]
1_nU`^h00onU`NgoYL;^ojG2kP05ojG2kP?oY/?^0onV`Nd8ojK2k@03ojO3kOnW`NcoYl7/00_oYl7/
1OnWbO46ojO9lP;oZ<gc1_nYcO<2oj_<l@GoZ;GR1OnT[Mh7oinVf`GoVj3G0onFV]D3oiJOfPKoW:gS
1_nS^nX2ok3LmPKo]^;f0_ncf_@5ok7Bl@03ojW3k?nW_n_oYko[00KoYko[0onX`>/2ojS1k0SoZ<;/
0onX`N/00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00?ooooo000`ooooo`03o`000?oo
oooooooo02kooooo1Omh/?H5oj6nkP;oXKo_1_noa=h00onma=ooal7DolO1e005olO1e0;oa/3D1_no
_MP3ol6ke@Ko/[cQ0_nh^]/6oj6ijPKoVKoc0onN`_43oi_2l`KoY<C`0_nV`>`5ojK4k`KoYL3/0_nT
`Nd5ojG0k0KoYL7]0_nU`^h5ojG1k@GoYL;^0_nV`N`6ojK1k@KoY/;]00?oYl;]ojO1k?nW`N`02?nW
`N`4ojK8lPKoYlWa0_nWbO86ojS=l`?oZLgc0onY^nH6ojRehPKoY:gN0onOY]/3oiZJd`GoUi[D1onF
WmX6oib]h`?oXk_Z1On`g?H2okKRmPKo/m[d00?o/M;aojW3k?nY`n`00onY`n`6ojNoj`03ojO0jonX
`NcoZ<7/00CoZ<7/1_nX`^`5ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00ooo
ool0037ooooo00?o0000ooooooooool0;_ooool5ogR`mP03oj6nk_nQ_nooXKo_00CoXKo_0onoa=h4
okg4g`Goal7D1?o6`=@3oknmf0Ko`K_E0onb_>45okRjf`KoXKWZ0onI_o<3oiVnl@KoVl;c0onTa?03
oik3lPOoY/C_0onU`>`3ojK3kPOoYL3/0onU`Nd4ojK1k0KoYL7]00?oYL;^ojK1k?nV`N`01?nV`N`6
ojK1k@;oY/;]1OnW`^d5ojO1k0;oY/Wb1onVb?83ojO9l@CoY/gd1OnXcO<2ojVnj@KoZK_V1_nX]N83
ojB]gP;oWYkC1onJV]<5oiNJe0KoUYoJ1onL[N<00onS^n[o/=cfok3LmP03ok3LmP;o]>7f1_ncf_@0
0on^c>ooZL?/ojW3k005ojW3k0;oYko[1OnW`>/6ojS1k0;oZ<;/2Oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00?ooooo000booooo`;o0000<?ooool5ogNam`KoXKo_00?o_lCNokg4
gonma=l01?nma=l3olO1e0Koa/3D00?o_kgHol6keOo1^mD01_o1^mD00onb_>7o^;[KokRjf`05okRj
f`?oXKWZ1?nZ^><5oiVnl@?oVl;c0onI`_<6oik3lPGoY/C_0_nQaO86ojK3kPGoYL3/0_nVa>l7ojK1
k0?oYL7]0onW`nd7ojK1k0?oY/7]1?nWa>h6ojO2k@03ojO1k?nVbO;oY/Wb00CoY/Wb1OnVb?83ojG<
m0KoY/gd00?oZ<gcojVnjOnY_^T01?nY_^T6ojVkiP?oZ;GR0_nQXMD6oijNd`KoVY[C1_nGV]@6oiJO
fP?oW:gS1OnVbO800on`g?Ko]>7fokCQmP04okCQmP;o/m[d1On^c>l5ojW3k0WoYl3[0onX`N`>oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool003Cooooo00?o0000oooooooo
ool0;_ooool5ogNam`?oXKo_0onN`?47okg4g`03olO1e?o6`=Coa/3D00Coa/3D0oo6`=D6ol6ke@;o
`[[B1_nh^]/2okZgePOoZ[SS0_nI__43oinij`KoVL;c1_nN`o800onVa>ooXLGboj75lP04oj75lPKo
Y/?^00?oYL3/ojK4konVa>l01?nVa>l5ojK1k0;oYLKa1_nW`nd5ojK1k0;oY/Oa1onWa>h3ojO2k@Co
YL[c1_nVbO800onVb?;oYLcdojG<m005ojG<m0?oY/gd0_nX`>/8ojVnj@?oZK_V0_nSYML6oj6Qe@Ko
WYkC1OnJV]<7oiNJe0?oUYoJ0_nR^NT7ojK9lP;o/>;h1OndhOH3ok3Fm0Ko[/c_00?oZL?/ojO0jonW
`>/02OnW`>/Booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool003Gooooo
00?o0000ooooooooool0;oooool4ogJbn0KoW/3a1Onma=l2ok[3h@Goa/3D1Oo6`=D3ol6ke@Go`[[B
0onh^]/5okZgePGoZ[SS0_nc]]/5oinij`KoVL;c0onN`o84oi_4m0KoXLGb0onV`nh4oj;6lPKoY/C_
00?oY/7/ojG6lOnUa_401?nUa_46ojO3k@03ojK1k?nVao7oY/Oa00CoY/Oa1OnWa>h2oj?9m0OoYL[c
0onVbO84ojC<m0GoYLcd00?oYl3[ojS0jonX`>/01?nX`>/6ojVnj@03ojFWf?nSYMOoXjGG00CoXjGG
1_nQXMD5oijNd`KoVY[C0onGV]@3oij]hPKoX[WY1?nVbO85ok3Rn003okCQm_n`e_Co/=Kd00Go/=Kd
0on^c>l3ojS0j`SoYl3[5_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo
000fooooo`03o`000?oooooooooo02oooooo1?mf/_P6oik0l@03okg4gonj`n7o^/?Q00Co^/?Q0oo6
`=@7olK0e@03ol6keOo2^];o`[[B00Go`[[B00?o^;[KokZge_nj]mH01Onj]mH00onZ^>?o/kKKok>f
f`04ok>ff`GoWkW[0onI`_<4oi^ml0KoVlCd0onQaO84oic5m@KoX/Kb0onVa>l4oj77l`KoYLKa0onW
`nd4oj?8l`KoY/Oa00?oYlC^oj?9m?nSbO@01?nSbO@5ojG:l`;oXl_d1onTc?@00onUc?CoYl3[ojO0
j`03ojO0j`KoZ<3[0_nY_^T5ojFWf0GoXjGG1_nQXMD6oijNd`?oVY[C0_nKXm/7oij]hPKoX[WY00?o
Y/Wbok3Rn?n`h_P01?n`h_P2ok3KmPKo/=Kd00?oZ/C]ojS0jonX`>/01OnX`>/3ojO0ja_ooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`00=oooool2o`00033ooooo1?mf/_P3
oik0l@?oV<3c1onj`n400oo6`=Coa/3EolK0e@05olK0e@03ol?1f?o2^];o`[[B00Go`[[B00?o`k[A
okZge_nj]mH01Onj]mH00onm]M;o/kKKok>ff`06ok>ff`;oWkW[1?nZ]>06oi^ml0?oVlCd1?nK`?86
oic5m@?oX/Kb1?nMaoD6oj77l`?oYLKa1?nOb?D6oj?8l`?oY/Oa1?nQb_D6oj?9m003ojG:lonSboCo
Xl_d00CoXl_d0onTc?@3ojNnjPOoYl3[0onX`>/2ojJXf0OoYJOH1OnSYML7oj6Qe@?oWYkC0_nLW]D6
oi^Sf`OoWZgR0onR^NT5oj_Kn003ok3Rn?n`foKo/=_f00Co/=_f0_n`e_@5oj[4k@GoZ<3[8?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo000iooooo`03o`000?oooooooooo
02kooooo1Omf/oP5oiS0l`Go^/?Q0onfa>D5olK0e@?o`l7H1Oo2^]83ol>jd@Go^[OF0onm]M86ok>f
f`03okRce?nZ]>3oZ[CP00GoZ[CP0onK_O03ojBdi0OoVl3b0onLaOD3oic1lPOoWLOe0onQao<4oik7
m@KoWlSe0onSb?<3oj39m@OoXL[e1_nSbO@5oj?;m0;oY[[W1_nW_^X5ojO0j`03ojNYf?nVZ=SoYZSH
00CoYZSH1_nUYmP6oj>Ue`?oXJ7E0onMW=86oibNe@KoVj?K1OnN[N82ojG<m0KoZm_h0_n`hOP5ok3K
mP;o[/g`1onZa>d00onX`>_oooooooooo`0Qooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool00_ooool003[ooooo00?o0000ooooooooool0;_ooool5ogJcn0GoV<3c00?o^/?QokK4iOnf
a>D01Onfa>D3olK0e@Go`l7H0oo2^]85ol>jd@?o^[OF1Onm]M83ok>ff`Co^;?D1OnZ]>000ond/]Oo
Y;CTojBdi005ojBdi0GoVl3b0_nS]>D6oic1lPGoWLOe0_nN`?47oik7m@?oWlSe0onOaO<6oj39m@?o
XL[e1?nRaO86oj?9m003oj?;m?nV^^OoY[[W00CoY[[W1_nW_^X00onW`>_oYjWHojNYf003ojNYf0Ko
YZSH1_nUYmP3oj>Ue`;oWic@1onMW=85oibNe@OoVj?K00?oWZgRojG<m?nUc?@01?nUc?@2oj_Kn0Ko
/>7h00?o/=_fojk=l?n^cO001?n^cO03oj[4kBSooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`02ooooo`00>oooool00ol0003oooooooooo`0^ooooo`GoM[?h0_nH`?<4ohnom`Oo]/CU
00?oa/3Eol?1f?o3`MP01Oo3`MP00oo2^];o`k[Aol>jd@05ol>jd@03okZge_nm]M;o_KGB00Go_KGB
00?o/kKKokRce?nh/m@00onh/m@3ojZdh0Co];;G1onT]>@00onK`?;oXkCUoj>di@04oj>di@KoW<7b
00?oWLOeoik0lOnN`?401?nN`?45oik7m@03oj6kjonOaO?oWlGc00GoWlGc0onPbOD3oj>lj`OoX/Gb
0onSbO@3ojJdh`OoY[[W0onW_^X2ojRXe`OoYjWH1_nVZ=P3ojFWf0;oXYc?1_nOW=06oifLdPKoW9kE
0onKXm/4ojBok@GoYLcd0on[hoX5ok3Qn0;o[]Cd1On^cO0]ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool00Oooool003cooooo00?o0000ooooooooool0;oooool5ogJdn@GoSkog1Onf
a>D2ok35jPKo`l7H0_no`]`6ol>jd@03olBme?nm]M;o_KGB00Go_KGB00?o`;K@okRce?nh/m@01Onh
/m@00onZ]>3o];;GokBbe`04okBbe`GoY;CT0_na/MP7oj>di@?oW<7b1?nT/n<6oik0l@03oik7mOnQ
^n_oXK_[00?oXK_[1OnOaO<2ojJbh@KoXkc[1OnRaO82ojN^g@KoY[CS1OnV^^L00onXYmGoZ:SGojRX
e`04ojRXe`OoYjWH0onVZ=P2ojBNc`KoXYc?1_nOW=05oifLdPGoW9kE0_nS]^L7ojBok@03ojG<m?n[
ho[oZn?j00GoZn?j00?o/>7hojkDm?n^e?@01?n^e?@00on^cO3oooooooooo`0_ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool00Oooool003gooooo0_l0000`ooooo`GoM[Ci1On?_oL0
0onfa>Go/<GZok35jP04ok35jP?o`l7H1Ono`]`3ol>jd@Coa;gD1Onm]M83ol2fd0Go^;?D00?o_;7@
okBbeond/]L01_nd/]L00onT]>Co/K7Hok6af004ok6af0GoXkCU0_n_[mP7ojBch`?oW/3a0_nV/=l7
oj6kj`03oio5lonV/^7oY[;Q00CoY[;Q1_nS_>/00onRaO;oYjkMojN^g@04ojN^g@KoY[CS00?oY[[W
ojRWeOnXYmD00onXYmD6ojRXe`GoYjWH00?oYIk?ojBNconTW/l01?nTW/l6oj:Lc`GoWic@1_nMW=80
0onLW]GoXkKWoj>fi`04oj>fi`GoY;o]0_nXh?X6oj_SnP?o[MWg0on^e?@dooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool00Oooool003oooooo00?o0000ooooooooool0;_ooool6ogVf
n@GoP[gj1_n`aNX00oo3`MSo_l;Loko2g005oko2g003ol>jdOo4_MCoa;gD00Coa;gD0onm]M84ol2f
d0?o^;?D1?nl/M06okBbe`03okR^d?na/MSo/K7H00Ko/K7H00?oXkCUojn_f?n_[mP01?n_[mP5ojBc
h`03ojn]eOnV/=ooY[3O00CoY[3O1OnQ^n/2oj^]f@OoY[;Q0onS_>/3ojZ[e`OoYjkM0onV]><2ojVU
dPOoZ:OE1_nXZ=L00onWZMSoYIk?ojFNc`03ojFNc`KoY9k?1OnRW<l6oinLd0?oWIcB0onR/>87oj>f
i`03ojBokOnXh?[oZ>3j00CoZ>3j0_n[hoX5ojgImcWooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`01ooooo`00@?ooool00ol0003oooooooooo`0^ooooo`KoNKKi1On2_OX3ok35jP?o
Y/Oa1_no`]`00onga>Coa;gDolBme006olBme003okfed_o0]]3o`;K@00Co`;K@00?o^;?Dokbad?nl
/M001?nl/M03okBbe`Co^:k@1_na/MP00one[=3o[joHojn_f006ojn_f003ojBchon_[MGo[jgE00?o
[jgE1_nV/=l00onQ^n_oZjgIoj^]f@04oj^]f@GoY[;Q00?o[JSBojZ[eonZZmL01OnZZmL5ojN^g@03
oj^Td?nYYM;oZJGB00CoZJGB1onXYmD3ojRXe`;oYio>1_nUW/l6ojBNc`KoXYc?0onOW=02oj6[gPOo
X[3R1OnS]^L3ojGInP?oZ>3j1On/g_T00on]fOOoooooooooo`0kooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool00Oooool0047ooooo00?o0000ooooooooool0;_ooool3ogVfn@?oP;Wh
1Omf^O/6ojK7l@?o_l;L1?nga>@6olBme003ol30f_o0]]3o`;K@00Co`;K@00?o`[_Dokbad?nl/M00
1_nl/M000ond/]Oo^:k@okR^d004okR^d0?o/K7H1?ne[=06ojn_f003ok>Zcon_[MGo[jgE00Co[jgE
1OnV/=l00on_ZM;oZjgIoj^]f@06oj^]f@03ojJbhOn]Z=;o[JSB00?o[JSB1onZZmL00onW[]goZjC@
oj^Td003oj^Td0GoZJGB1_nXYmD00onYX<koYio>ojNOcP04ojNOcPGoYIk?1onTW/l3oj:Lc`;oXjWK
1_nQZmh7oj:`hP03oj>fionUfO[oYMWj00?oYMWj0_nXhOX6ojcNnCoooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`01ooooo`00@_ooool2o`00033ooooo1On0^OP5ogJin`KoY/Oa00?o
_l;LokO4i?nga>@01?nga>@3olBme0Co`<3J0oo0]]04ol:ke0Ko_;7@00?o_kG@okR^d?nh[]001_nh
[]000ona/MSo]Jc@okF/d004okF/d0?o[joH1?ncZ/l6ojn]e@03ojJ`gon_ZM;o[jWB00?o[jWB1_n[
[MT00on_Y/ko[JSBojfXdP05ojfXdPGoZZ_G00?o[J?>oj^Td?n[Y=001?n[Y=06ojVUdP;oZ:OE1OnY
X<h5ojNOcPKoYIk?0onTW/l3ojFXf@KoXjWK1_nQZmh3oj:`hPGoY=7h00?oYMWjojSQn_nXhOX01?nX
hOX2ojcNnD?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`01ooooo`00A?ooool0
0ol0003oooooooooo`0^ooooo`GoP;Wh1Omf^O/3ojK7l@?oU<Kh1onga>@00oo4_MCo`<3Jol30fP04
ol30fP03ol2fd?o2^mCo`[_D00Co`[_D0onl/M04okned0Ko^:k@00?o_;7?okF/d?ne[=001_ne[=00
0on_[mSo/j[?ok>Zc`04ok>Zc`Co[jgE00?o/jS>ojnYd_n_ZM801On_ZM83oj^]f@Co[jK>1on]Z=80
0onZZmOo[J?>ojfScP03ojfScPGoZjC@1OnYYM800on[X/koZJ3>ojVPcP05ojVPcPGoYio>1OnUW/l0
0onWZMSoYJSIojFXf@05ojFXf@GoXjWK1OnQZmh3ojC;m0GoY=7h0_nTh_`5ojSQnTOooooo00?o0000
ooooooooool01oooool1o`00007ooooo0Oooool004Gooooo00?o0000ooooooooool0;_ooool6ohRk
m`GoLkSk1OnDa_P5okO4i0;o[LW_1Oo0`=X00onga>Co`[_Dol:ke006ol:ke003okbad?no]M3o_kG@
00Co_kG@0onh[]04okbac`Ko]Jc@00?o^Zo>ok>ZconcZ/l01_ncZ/l00on_[MGo/jS>ok>XcP02ok>X
cPOo[jWB00?oZjgIojnVc_n_Y/h01?n_Y/h5ojfXdP03ok2UcOn]Xlko[J?>00Co[J?>1_n[Y=000onY
YM;oZj;>oj^RcP03oj^RcPKoZJ3>1_nWWlh00onUW/ooYjWHojNYf003ojNYf0KoYJSI1_nSZM/00onQ
ZmkoY<_dojC;m005ojC;m003ojCAn?nTh_coY>;l00CoY>;l00?oZ>7jooooooooool0BOooool00ol0
003oooooooooo`06ooooo`7o00000Oooool1ooooo`00A_ooool00ol0003oooooooooo`0^ooooo`Ko
R;_g1Omc^?/5oiC6n003okO4i?n]bNoo[LW_00Co[LW_0oo0`=X3okO4i0Ko`[_D00?o_<7Mokned?no
]M001_no]M000onh[]3o_;7?okbac`04okbac`?o]Jc@1?nj[lh6ok>Zc`03okV_concZ<ko/jS>00Co
/jS>1On_ZM800oncZ<go[jK>ojnVcP05ojnVcP?o[JSB1?n`YLd5ojfScPGoZjC@00?o[ZK@oj^Rc_n[
X/h01On[X/h6ojVPcP?oYio>0_nY[=T7ojNYf0KoYJSI0onSZM/4ojG7l@GoY<_d0onPhO`3ojCRo4ko
oooo00?o0000ooooooooool01_ooool1o`00007ooooo0Oooool004Oooooo0_l0000_ooooo`?oR;_g
1?nA^o<5ogVjnPGoOL7m1_n]bNl00oo0`=[o]lCTokO4i003okO4i0?o`[_D1?nl`Md6okned003okjn
fOnl/Loo_;7?00Ko_;7?00?o]Jc@okZ_c_nj[lh01?nj[lh3ok>Zc`Co^Jo?1_ncZ<h00on_ZM;o/jS=
ok>Xc@03ok>Xc@Oo[jK>00?o[JSBok2UcOn`YLd00on`YLd6ojfScP03oj^Td?n^Y]3o[ZK@00?o[ZK@
1_n[X/h5ojVPcP03oj^_fonY[=WoZJcI00CoZJcI1_nWZMP5ojFXf@;oY/G`1onUao400onTboCoX>7l
oj3Qo003oj3Qo5?ooooo00?o0000ooooooooool01Oooool1o`00007ooooo0Oooool004Wooooo00?o
0000ooooooooool0;_ooool6oi6kl`GoNK[j1Omm`Od3ojg9k`CoV<_i1Onga>@00oo2^mCo_<7Mokc1
g@04okc1g@?o_kG@1?nn_]T6okbac`03okflf?nj[lko^Zo>00Ko^Zo>00?o/j[?okV_coni[ll00oni
[ll5ok>XcP03okRad_ncZ<go/jS=00Go/jS=1On_Y/h00ond[=7o/:G=ok2Uc@04ok2Uc@Go[J?>00?o
/:cDojjVd?n^Y]001On^Y]06oj^RcP03ojVPc_n[[m_oZjoK00?oZjoK1_nY[=T6ojNYf003ojFXfOnV
aO3oY/G`00CoY/G`0onUao45oigPo@03oj3Qo?oooooooooo05Gooooo00?o0000ooooooooool01?oo
ool1o`00007ooooo0Oooool004[ooooo00?o0000ooooooooool0;oooool2oi6kl`CoVkg`1On5_OT5
og>ko0KoV<_i0_nga>@3ojW=lPOo_<7M00?o_kG@okjnfOnn_]T01?nn_]T3okbac`Co_KcH1_nj[lh0
0onl^mWo^Jo?okV_c`04okV_c`?o/jS>1?nh/M87ok>Xc@03ojnVc_nd[=7o]:cA00?o]:cA1_n`YLd0
0on]Xlko/:cDok2/e003ok2/e0Ko[ZK@1On[X/h00on]]MkoZjoKoj^_f`05oj^_f`KoZJcI0onWZMP3
ojK6l0GoY/G`0onJgod5oigPoE[ooooo00?o0000ooooooooool00oooool1o`00007ooooo0Oooool0
04_ooooo00?o0000ooooooooool0;oooool6oi^ml0GoQKgi1Omc^o`3oiS;n@?oNl?n1OnYcO85okc1
g@;o/<[]1onn_]T00onl/Loo_KcHokflf004okflf0?o^Zo>1?nl^mT6okV_c`03ok>Xc_nh/M;o^;7B
00Co^;7B1OncZ<d00ong]]So]:cAokB/d@04okB/d@Go/:G=00?o/kGJok2/e?n`[=@01On`[=@6ojjV
d003oj^Rc_n]]Mko[KGN00?o[KGN1on[[m/3ojV/f@?oYlSa1_nVa_000onVaO3oV]omoi[Oo@05oi[O
o@03oigPoOoooooooooo05_ooooo00?o0000ooooooooool00oooool1o`00007ooooo0Oooool004co
oooo0_l0000`ooooo`CoVkg`0_nT_^`6oi2lm0GoNKck1Omk`oh5ojW=lP03okc1gOn`b^go/<[]00Co
/<[]1Onn_]T2ok;7jPOo_KcH00?o^Zo>okbkfOnl^mT00onl^mT5okV_c`03okVmgOnh/M;o^;7B00Go
^;7B0oncZ<d4okNff0Go]:cA0on`YLd4ok>efPKo/:cD1On^Y]02ojfjh`Ko[KGN1On[[m/00onVc??o
YlSaojO8l@05ojO8l@?oY/K`1OnGgoh3oi[OoF7ooooo00?o0000ooooooooool00oooool1o`00007o
oooo001>ooooo`03o`000?oooooooooo02kooooo00?oVkg`ojBnk?nT_^`00onT_^`6oi2lm0GoNKck
0_mk`oh4ogBmo@GoS<cm1_n`b^d00onn_]Wo//OZok;7jP04ok;7jPGo_KcH00?o//OZokbkfOnl^mT0
1Onl^mT00oni[loo^KgMokVmg@03okVmg@Oo^;7B00?o/jS=okNff?ng]]P00ong]]P6okB/d@03ok2U
cOnc]M[o/kGJ00Co/kGJ1_n`[=@00on^Y]3o[K[Sojfjh`04ojfjh`Ko[KGN00?oZjoKojK<lonVc?<0
0onVc?<5ojO8l@?oUMkn1OnGgoiVooooo`03o`000?oooooooooo00;ooooo0Ol00001ooooo`00Cooo
ool00ol0003oooooooooo`0_ooooo`GoY;k/0on@_?@4oibmk`GoR;kh1Omd_Od5ohc<o@?o/<[]1?nG
d?`6ok;7jP03okflf?nban[o//OZ00?o//OZ1Onl^mT00on`bNgo^KgMokVmg@05okVmg@Go^;7B0_nc
`>@5okNff0Go]:cA0_na_^<7ok>efP?o/:cD0on]`^T7ojfjh`?o[KGN0onTdOL6ojK<l`03ojO8lOnE
g_koUMkn00GoUMkn00?oUmonooooooooool0J?ooool01Ol0003ooooooooooooooooo0000007ooooo
001@ooooo`03o`000?oooooooooo02oooooo0_nT_^`3ojO0j`OoW;g_1On8__P2ogBmo@CoP/3k1Ome
`_h6oiO@o0?o//OZ1?nKd_/5ok;7jP03okbkfOn`bNgo/<W]00?o/<W]1oni_Md00onh/M;o/l3Tok?0
i004ok?0i0Go]kKH00?o]:cAok6nhona_^<01?na_^<5ok>efP;oZLgc1_n]`^T5ojfjh`;oWmOk1_nT
dOL3ojK<l`GoT]gn0onEg_i]ooooo`05o`000?ooooooooooooooool000000Oooool0057ooooo0_l0
000`ooooo`GoYl3[1OnL_Nl2ojFok0KoU[gb1On2`?/5ogG2oP?oUm3l1?mha_l6oi_Bn`;o//OZ0onI
do`6ok39k@Go^KgM0_nZco<7ok?0i0;o]kKH1?n]b^l6ok6nh`03ok>ef_nYcO?oZLgc00CoZLgc1_n]
`^T00on]^^?oWmOkoioGn`04oioGn`?oY=7g1On?fol3oi;MoW?ooooo00Co0000oooooooooooo0000
0Oooool005?ooooo00?o0000ooooooooool0;_ooool5ojO0j`03oibmkonU_ncoYKo/00CoYKo/1_nF
_O82oh;0n`CoTKke1_mn`O`5ogS6o`?oVm;k0omjb?l5oiWCo0Ko/<W]00?o^KgMoj[?lonZco<01?nZ
co<5ok?0i0;oWmKk1_n]b^l3ok6nh`CoWmOk1_nYcO<3ojg2j@CoU=[n0onOeo/5ohkHo`?oSm_oNOoo
ool00ol0003oooooo`000001ooooo`00E?ooool00ol0003oooooooooo`0^ooooo`KoYl3[1_nU_n`3
oiJmlP?oX[k]1_nA__D3ogk1o0CoT;of1_mn`od4og[8o`GoVM?l0on`bNd5oi7DoPGoZ/oc00?o/l3T
oioFnonOe_/01?nOe_/3ojg:k`CoRmOo1_nOeo/3ojW=l`CoRMSo0onDf_h4ohkDo`GoS]SoOOooool0
0ol0003oooooo`000001ooooo`00EOooool00ol0003oooooooooo`0^ooooo`KoYl3[0onU_n`4ojS0
j`GoX[k]0onA__D4oj2nkPKoT;of0omn`od3oi71m`KoPLGm1Omjb_l3oi7DoP?oOL[o1_n4d_l3oioF
n`CoPM3o1_n;eol3oioGn`CoQMCo0on9f?l4oi3Ao@KoS]Co00?oS]Soooooooooool0Ooooool1o`00
007ooooo0Ol0000005Kooooo0_l0000_ooooo`?oYl3[0onW`>`7ojS0j`;oX[k]1?nW`>/6oj2nkP?o
T;of1?nO_^l5oi71m`?oPLGm1?nD`OH6ohO7o@CoOL[o0on4d_l5oh?:oPGoPM3o0on;eol4ohO>o`?o
QMCo1?nEcO/6oi3Ao@?oS]CoQOooool2o`000000F?ooool00ol0003oooooooooo`0]ooooo`KoYl3/
1OnX`>/2ojO0k0KoYl3[0onP_^h3ojO0j`OoWkk_0_nA`OL4oj2nkPKoU<7f0on7aod3oiW0l`KoSlOk
0on3b_h4oiO5m`GoSlcl0on7c_l4oi[7mPKoULgk0on@dOf9ooooo`?o0000001Iooooo`03o`000?oo
oooooooo02gooooo1_nW`>`00onX`>_oYl3/ojO0k004ojO0k0coYl3[1OnO_^l00onW`>_oX;k^oj2n
kP05oj2nkP?oU<7f0onS_^d6oiW0l`?oSlOk1?nN_o06oiO5m`;oSlcl1?nN`O46oi[7mP?oULgkR_oo
ool4o`0000?ooooo001Jooooo`03o`000?oooooooooo02gooooo0onW`>`4ojO1k0KoYl3/3?nW`>/0
0onO_^ooYl3[ojO0j`03ojO0j`GoX;k^0_nW`>/6oj>nk@CoVL3c0_nU_n`7oijol0?oUlGg0onT_n`6
oik1l@?oV/OfS?ooool3o`0000Oooooo001Kooooo`03o`000?oooooooooo02kooooo1_nW`N`3ojO0
k0?oYl7/4_nW`>/00onP_^koYl3[ojO0j`04ojO0j`KoXkk]00?oVL3cojFok?nU_n`00onU_n`5oijo
l003ojNojonT_ncoY;o/00GoY;o/0onN`O6=ooooo`Co00002_ooool005cooooo0_l0000_ooooo`?o
Yl7/0onV`>`6ojO1k0?oYl3[1?nW`N`BojO0j`?oXkk]0onX`>/6ojFok003oijol?nW_n_oYko[00?o
Yko[1OnT_nb=ooooo`Co00003_ooool005kooooo00?o0000ooooooooool0;Oooool6ojK0k0CoYl7/
0_nV`>`7ojO1k0?oYl3[0_nW`N`:ojO0j`?oYl3/1_nX`>/3ojFok0CoZ<3[1OnW_n/00onT_ncooooo
ooooo`2:ooooo`Co00004_ooool005oooooo00?o0000ooooooooool0;Oooool6ojK0k003ojO1k?nV
`>coY/3/00?oY/3/1OnW`N`2ojK0k0GoYl7/1OnW`>/2ojO1k0KoYl3/0onX`>/3ojO1k0OoZ<3[0_nW
_n^;ooooo`Co00005_ooool0063ooooo00?o0000ooooooooool0;Oooool3ojK0k0CoYko[1OnV`>`0
0onW`NcoY/3/ojK0k004ojK0k0GoYl7/00?oYl3[ojO1k?nW`N`01?nW`N`4ojO0k0SoYl7/1OnX`>^;
ooooo`?o00006_ooool0067ooooo0_l0000_ooooo`KoYko[0_nV`>`4ojNoj`KoY/3/0_nW`N`4ojK0
k0KoYl7/00?oYl3/ojO1k?nW`N`02OnW`N`00onX`>_oooooooooo`28ooooo`Co00007Oooool006?o
oooo00?o0000ooooooooool0;Oooool3ojNoj`;oZ;oZ1onW_n/3ojK0k0?oYko[1_nV`>`3ojO1k0?o
Y/3/2OnW`Nb9ooooo`Co00008Oooool006Cooooo00?o0000ooooooooool0;Oooool5ojRojPGoYko[
0_nX_nX6ojNoj`?oY/3/1?nW_n/5ojK0k0?oYl7/R_ooool4o`0002Gooooo001Uooooo`03o`000?oo
oooooooo02gooooo1OnX_nX00onW_n_oZ;oZojRojP04ojRojPCoYko[0_nX_nX7ojNoj`;oY/3/Rooo
ool4o`0002Wooooo001Vooooo`;o0000;_ooool2ojRojPCoZ<3[1_nX_nX00onW_n_oZ;oZojRojP03
ojRojPGoYko[Roooool3o`0002gooooo001Xooooo`03o`000?oooooooooo02cooooo1_nX`>/3ojRo
jP?oZ<3[1_nX_nX00onW_n_oooooooooo`28ooooo`Co0000<?ooool006Wooooo00?o0000oooooooo
ool0;?ooool3ojS0j`CoYl3[1OnX`>/3ojRojXWooooo1?l0000dooooo`00J_ooool00ol0003ooooo
ooooo`0/ooooo`OoYl3[0_nX`>^:ooooo`Co0000>?ooool006_ooooo0_l0000]ooooo`GoYl3[ROoo
ool4o`0003cooooo001]ooooo`03o`000?oooooooooo02_ooooo00?oYl3[ooooooooool0Qoooool3
o`00043ooooo001^ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0Poooool4o`00
04?ooooo001_ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0Ooooool4o`0004Oo
oooo001`ooooo`;o0000:Oooool00ol0003oooooooooo`1kooooo`Co0000Boooool007;ooooo00?o
0000ooooooooool09_ooool00ol0003oooooooooo`1gooooo`Co0000Coooool007?ooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`1dooooo`?o0000Doooool007Cooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`1`ooooo`Co0000E_ooool007Gooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`1/ooooo`Co0000F_ooool007Kooooo0_l0000Sooooo`03o`00
0?oooooooooo06Sooooo1?l0001Nooooo`00N?ooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo06Cooooo1?l0001Rooooo`00NOooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo067ooooo0ol0001Vooooo`00N_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
05gooooo1?l0001Yooooo`00Noooool2o`0001kooooo00?o0000ooooooooool0FOooool4o`0006go
oooo001mooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0EOooool4o`00077ooooo
001nooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0DOooool4o`0007Gooooo001o
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0C_ooool3o`0007Wooooo0020oooo
o`;o00006Oooool00ol0003oooooooooo`1:ooooo`Co0000O?ooool008;ooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`16ooooo`Co0000P?ooool008?ooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`12ooooo`Co0000Q?ooool008Cooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`0nooooo`Co0000R?ooool008Gooooo0_l0000Cooooo`03o`000?oooooo
oooo03cooooo0ol0002<ooooo`00Qoooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
03Sooooo1?l0002?ooooo`00R?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03Co
oooo1?l0002Cooooo`00ROooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo033ooooo
1?l0002Gooooo`00R_ooool2o`0000kooooo00?o0000ooooooooool0;?ooool4o`0009_ooooo002<
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0:Oooool3o`0009oooooo002=oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool09Oooool4o`000:;ooooo002>ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool08Oooool4o`000:Kooooo002?ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool07Oooool4o`000:[ooooo002@ooooo`;o00002?oo
ool00ol0003oooooooooo`0Iooooo`Co0000[_ooool009;ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Fooooo`?o0000/_ooool009?ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0Booooo`Co0000]Oooool009Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0>ooooo`Co0000^Oooool009Gooooo0_l00003ooooo`03o`000?oooooooooo00[ooooo
1?l0002mooooo`00Uoooool01?l0003oooooooooool00008ooooo`Co0000`Oooool009Sooooo00?o
0000ooooool000001Oooool3o`000<Gooooo002Iooooo`;o000000?oooooo`000?l000000_l00038
ooooo`00V_ooool2o`000<cooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0538698, 0.0432538, \
0.0035044, 0.0035044}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[.12586 .2075 -12 -8.99448 ]
[.12586 .2075 0 .00552 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.56094 .0364 -5.16972 -9 ]
[.56094 .0364 .83028 0 ]
[.75679 .08071 0 -6.17777 ]
[.75679 .08071 12 2.82223 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.9429 .3657 0 -5.9083 ]
[.9429 .3657 6 3.0917 ]
[.02494 .25992 -18 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.01611 .31527 -18 -2.78472 ]
[.01611 .31527 0 6.21528 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00254 .43215 -12 -2.88407 ]
[-0.00254 .43215 0 6.11593 ]
[-0.0124 .49393 -12 -2.93688 ]
[-0.0124 .49393 0 6.06312 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
[(-2)] .12586 .2075 1 .99877 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.56863 .04703 m
.57247 .05235 L
s
[(2)] .56094 .0364 .72324 1 Mshowa
.125 Mabswid
.18558 .19702 m
.18832 .19985 L
s
.23703 .17687 m
.23971 .17975 L
s
.28951 .15632 m
.29214 .15925 L
s
.39772 .11395 m
.40023 .11699 L
s
.4535 .09211 m
.45595 .0952 L
s
.51046 .06981 m
.51284 .07294 L
s
.08568 .23614 m
.08851 .23887 L
s
.62804 .02377 m
.63027 .02701 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.7445 .0853 m
.73835 .08759 L
s
[(-2)] .75679 .08071 -1 .37284 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.93037 .36962 m
.92411 .37158 L
s
[(2)] .9429 .3657 -1 .31296 Mshowa
.125 Mabswid
.7708 .12553 m
.7671 .12688 L
s
.79613 .16428 m
.79242 .1656 L
s
.82054 .20161 m
.81682 .20291 L
s
.86679 .27235 m
.86305 .2736 L
s
.88871 .30589 m
.88497 .30711 L
s
.9099 .3383 m
.90615 .3395 L
s
.71716 .04348 m
.71349 .04489 L
s
.95018 .39992 m
.94642 .40107 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(-20)] .02494 .25992 1 -0.39157 Mshowa
.02837 .31059 m
.0345 .30825 L
s
[(-10)] .01611 .31527 1 -0.38117 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.00981 .42772 m
.01599 .4255 L
s
[(10)] -0.00254 .43215 1 -0.3591 Mshowa
0 .48963 m
.0062 .48748 L
s
[(20)] -0.0124 .49393 1 -0.34736 Mshowa
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.66 .751 .918 r
.39362 .69484 .40169 .70195 .4152 .69808 .40717 .69087 Mtetra
.657 .748 .917 r
.40717 .69087 .4152 .69808 .42878 .69413 .42079 .687 Mtetra
.654 .75 .921 r
.42079 .687 .42878 .69413 .44243 .69026 .43448 .68318 Mtetra
.652 .752 .923 r
.43448 .68318 .44243 .69026 .45614 .68645 .44824 .6794 Mtetra
.652 .754 .924 r
.44824 .6794 .45614 .68645 .46992 .68267 .46206 .67558 Mtetra
.659 .756 .922 r
.46206 .67558 .46992 .68267 .48378 .67887 .47597 .67151 Mtetra
.658 .749 .918 r
.47597 .67151 .48378 .67887 .4977 .67492 .48994 .66749 Mtetra
.648 .746 .921 r
.48994 .66749 .4977 .67492 .5117 .67085 .50398 .6638 Mtetra
.633 .753 .934 r
.50398 .6638 .5117 .67085 .52577 .66692 .5181 .66049 Mtetra
.616 .767 .952 r
.5181 .66049 .52577 .66692 .53991 .66328 .53229 .65753 Mtetra
.577 .776 .973 r
.53229 .65753 .53991 .66328 .55413 .65987 .54657 .65525 Mtetra
.552 .805 .992 r
.54657 .65525 .55413 .65987 .56843 .65665 .56094 .65293 Mtetra
.534 .829 .999 r
.56094 .65293 .56843 .65665 .58282 .65381 .5754 .65036 Mtetra
.543 .843 .999 r
.5754 .65036 .58282 .65381 .5973 .65099 .58993 .64741 Mtetra
.567 .848 .997 r
.58993 .64741 .5973 .65099 .61185 .648 .60455 .64409 Mtetra
.592 .846 .993 r
.60455 .64409 .61185 .648 .62649 .64478 .61924 .64046 Mtetra
.612 .84 .987 r
.61924 .64046 .62649 .64478 .6412 .6413 .63401 .63658 Mtetra
.625 .832 .98 r
.63401 .63658 .6412 .6413 .65598 .63757 .64885 .63253 Mtetra
.633 .825 .974 r
.64885 .63253 .65598 .63757 .67084 .6336 .66376 .62837 Mtetra
.637 .822 .971 r
.66376 .62837 .67084 .6336 .68577 .62941 .67876 .62414 Mtetra
.639 .822 .971 r
.67876 .62414 .68577 .62941 .70077 .625 .69383 .61985 Mtetra
.64 .827 .973 r
.69383 .61985 .70077 .625 .71583 .62035 .70898 .61544 Mtetra
.641 .837 .976 r
.70898 .61544 .71583 .62035 .73096 .61544 .7242 .61087 Mtetra
.644 .85 .979 r
.7242 .61087 .73096 .61544 .74615 .61027 .73948 .60604 Mtetra
.649 .864 .981 r
.73948 .60604 .74615 .61027 .76139 .60485 .75482 .60089 Mtetra
.657 .877 .98 r
.75482 .60089 .76139 .60485 .7767 .59925 .77022 .59535 Mtetra
.669 .883 .977 r
.77022 .59535 .7767 .59925 .79208 .59367 .78565 .58942 Mtetra
.682 .877 .971 r
.78565 .58942 .79208 .59367 .80756 .58847 .80114 .58322 Mtetra
.693 .849 .957 r
.80114 .58322 .80756 .58847 .82314 .58345 .81669 .57696 Mtetra
.679 .808 .944 r
.81669 .57696 .82314 .58345 .83882 .57866 .83238 .57139 Mtetra
.672 .784 .933 r
.83238 .57139 .83882 .57866 .85462 .57417 .84817 .56618 Mtetra
.663 .762 .924 r
.84817 .56618 .85462 .57417 .87052 .56982 .86409 .56135 Mtetra
.655 .748 .918 r
.86409 .56135 .87052 .56982 .88649 .56535 .88013 .55686 Mtetra
.652 .747 .919 r
.88013 .55686 .88649 .56535 .90254 .5607 .89627 .55243 Mtetra
.658 .756 .922 r
.89627 .55243 .90254 .5607 .91867 .55604 .91247 .54772 Mtetra
.659 .756 .922 r
.91247 .54772 .91867 .55604 .9349 .55141 .92876 .54296 Mtetra
.657 .754 .921 r
.92876 .54296 .9349 .55141 .95123 .54683 .94514 .53824 Mtetra
.655 .751 .92 r
.94514 .53824 .95123 .54683 .96766 .54233 .96162 .53358 Mtetra
.653 .747 .919 r
.96162 .53358 .96766 .54233 .98418 .53773 .97822 .52901 Mtetra
.657 .748 .918 r
.38547 .68761 .39362 .69484 .40717 .69087 .39907 .68371 Mtetra
.654 .75 .921 r
.39907 .68371 .40717 .69087 .42079 .687 .41273 .67988 Mtetra
.652 .752 .923 r
.41273 .67988 .42079 .687 .43448 .68318 .42646 .6761 Mtetra
.653 .754 .924 r
.42646 .6761 .43448 .68318 .44824 .6794 .44026 .67225 Mtetra
.661 .756 .92 r
.44026 .67225 .44824 .6794 .46206 .67558 .45414 .66812 Mtetra
.655 .747 .917 r
.45414 .66812 .46206 .67558 .47597 .67151 .46808 .66418 Mtetra
.639 .747 .927 r
.46808 .66418 .47597 .67151 .48994 .66749 .48209 .66074 Mtetra
.619 .758 .945 r
.48209 .66074 .48994 .66749 .50398 .6638 .49618 .65778 Mtetra
.575 .767 .97 r
.49618 .65778 .50398 .6638 .5181 .66049 .51034 .65567 Mtetra
.534 .792 .992 r
.51034 .65567 .5181 .66049 .53229 .65753 .52459 .65378 Mtetra
.512 .82 1 r
.52459 .65378 .53229 .65753 .54657 .65525 .53893 .65159 Mtetra
.541 .834 .999 r
.53893 .65159 .54657 .65525 .56094 .65293 .55336 .64884 Mtetra
.584 .837 .993 r
.55336 .64884 .56094 .65293 .5754 .65036 .56787 .64551 Mtetra
.624 .825 .978 r
.56787 .64551 .5754 .65036 .58993 .64741 .58245 .64162 Mtetra
.658 .805 .954 r
.58245 .64162 .58993 .64741 .60455 .64409 .5971 .63708 Mtetra
.674 .775 .926 r
.5971 .63708 .60455 .64409 .61924 .64046 .61181 .63215 Mtetra
.674 .743 .902 r
.61181 .63215 .61924 .64046 .63401 .63658 .62659 .62724 Mtetra
.669 .718 .886 r
.62659 .62724 .63401 .63658 .64885 .63253 .64146 .62247 Mtetra
.663 .702 .876 r
.64146 .62247 .64885 .63253 .66376 .62837 .65641 .61794 Mtetra
.656 .693 .872 r
.65641 .61794 .66376 .62837 .67876 .62414 .67144 .61367 Mtetra
.65 .69 .874 r
.67144 .61367 .67876 .62414 .69383 .61985 .68658 .60966 Mtetra
.644 .695 .882 r
.68658 .60966 .69383 .61985 .70898 .61544 .7018 .60588 Mtetra
.64 .708 .896 r
.7018 .60588 .70898 .61544 .7242 .61087 .71713 .60226 Mtetra
.636 .73 .916 r
.71713 .60226 .7242 .61087 .73948 .60604 .73255 .59866 Mtetra
.641 .765 .938 r
.73255 .59866 .73948 .60604 .75482 .60089 .74803 .59466 Mtetra
.653 .805 .956 r
.74803 .59466 .75482 .60089 .77022 .59535 .76356 .59 Mtetra
.662 .837 .967 r
.76356 .59 .77022 .59535 .78565 .58942 .77912 .58477 Mtetra
.673 .864 .972 r
.77912 .58477 .78565 .58942 .80114 .58322 .79472 .57894 Mtetra
.686 .881 .971 r
.79472 .57894 .80114 .58322 .81669 .57696 .81035 .57252 Mtetra
.697 .88 .966 r
.81035 .57252 .81669 .57696 .83238 .57139 .82601 .56577 Mtetra
.7 .844 .952 r
.82601 .56577 .83238 .57139 .84817 .56618 .84177 .55924 Mtetra
.681 .8 .939 r
.84177 .55924 .84817 .56618 .86409 .56135 .85768 .55358 Mtetra
.669 .774 .928 r
.85768 .55358 .86409 .56135 .88013 .55686 .87372 .5484 Mtetra
.657 .752 .92 r
.87372 .5484 .88013 .55686 .89627 .55243 .8899 .54374 Mtetra
.652 .745 .918 r
.8899 .54374 .89627 .55243 .91247 .54772 .9062 .53928 Mtetra
.658 .755 .922 r
.9062 .53928 .91247 .54772 .92876 .54296 .92256 .5345 Mtetra
.659 .757 .922 r
.92256 .5345 .92876 .54296 .94514 .53824 .939 .52966 Mtetra
.657 .754 .921 r
.939 .52966 .94514 .53824 .96162 .53358 .95554 .52486 Mtetra
.655 .751 .92 r
.95554 .52486 .96162 .53358 .97822 .52901 .97219 .52014 Mtetra
.654 .75 .921 r
.37725 .68041 .38547 .68761 .39907 .68371 .39088 .67656 Mtetra
.651 .752 .923 r
.39088 .67656 .39907 .68371 .41273 .67988 .40458 .67277 Mtetra
.653 .754 .924 r
.40458 .67277 .41273 .67988 .42646 .6761 .41836 .66889 Mtetra
.661 .755 .92 r
.41836 .66889 .42646 .6761 .44026 .67225 .43221 .66474 Mtetra
.652 .745 .918 r
.43221 .66474 .44026 .67225 .45414 .66812 .44613 .66088 Mtetra
.632 .748 .932 r
.44613 .66088 .45414 .66812 .46808 .66418 .46011 .65762 Mtetra
.6 .759 .955 r
.46011 .65762 .46808 .66418 .48209 .66074 .47415 .6551 Mtetra
.539 .768 .982 r
.47415 .6551 .48209 .66074 .49618 .65778 .48827 .65353 Mtetra
.502 .8 .999 r
.48827 .65353 .49618 .65778 .51034 .65567 .50249 .65182 Mtetra
.524 .822 .999 r
.50249 .65182 .51034 .65567 .52459 .65378 .5168 .64948 Mtetra
.584 .829 .991 r
.5168 .64948 .52459 .65378 .53893 .65159 .5312 .64628 Mtetra
.645 .815 .965 r
.5312 .64628 .53893 .65159 .55336 .64884 .54567 .64203 Mtetra
.69 .783 .922 r
.54567 .64203 .55336 .64884 .56787 .64551 .56021 .63651 Mtetra
.694 .731 .879 r
.56021 .63651 .56787 .64551 .58245 .64162 .57481 .63067 Mtetra
.687 .692 .848 r
.57481 .63067 .58245 .64162 .5971 .63708 .58947 .62479 Mtetra
.679 .667 .831 r
.58947 .62479 .5971 .63708 .61181 .63215 .6042 .61909 Mtetra
.672 .654 .823 r
.6042 .61909 .61181 .63215 .62659 .62724 .619 .61362 Mtetra
.664 .644 .819 r
.619 .61362 .62659 .62724 .64146 .62247 .63389 .60852 Mtetra
.657 .636 .818 r
.63389 .60852 .64146 .62247 .65641 .61794 .64886 .60381 Mtetra
.65 .631 .818 r
.64886 .60381 .65641 .61794 .67144 .61367 .66392 .59948 Mtetra
.643 .628 .82 r
.66392 .59948 .67144 .61367 .68658 .60966 .67909 .59555 Mtetra
.636 .627 .824 r
.67909 .59555 .68658 .60966 .7018 .60588 .69436 .59201 Mtetra
.629 .627 .83 r
.69436 .59201 .7018 .60588 .71713 .60226 .70974 .58885 Mtetra
.624 .633 .839 r
.70974 .58885 .71713 .60226 .73255 .59866 .72523 .58593 Mtetra
.62 .642 .851 r
.72523 .58593 .73255 .59866 .74803 .59466 .74083 .58319 Mtetra
.619 .664 .872 r
.74083 .58319 .74803 .59466 .76356 .59 .75653 .58043 Mtetra
.622 .706 .905 r
.75653 .58043 .76356 .59 .77912 .58477 .77231 .57734 Mtetra
.649 .772 .939 r
.77231 .57734 .77912 .58477 .79472 .57894 .7881 .57296 Mtetra
.671 .824 .957 r
.7881 .57296 .79472 .57894 .81035 .57252 .80388 .56749 Mtetra
.689 .861 .964 r
.80388 .56749 .81035 .57252 .82601 .56577 .81967 .56115 Mtetra
.705 .879 .963 r
.81967 .56115 .82601 .56577 .84177 .55924 .83546 .55412 Mtetra
.712 .867 .955 r
.83546 .55412 .84177 .55924 .85768 .55358 .85131 .54694 Mtetra
.691 .816 .942 r
.85131 .54694 .85768 .55358 .87372 .5484 .86733 .54073 Mtetra
.674 .782 .931 r
.86733 .54073 .87372 .5484 .8899 .54374 .8835 .53527 Mtetra
.659 .756 .922 r
.8835 .53527 .8899 .54374 .9062 .53928 .89983 .53043 Mtetra
.652 .745 .918 r
.89983 .53043 .9062 .53928 .92256 .5345 .91629 .5259 Mtetra
.658 .754 .921 r
.91629 .5259 .92256 .5345 .939 .52966 .93281 .52106 Mtetra
.659 .757 .922 r
.93281 .52106 .939 .52966 .95554 .52486 .94941 .51614 Mtetra
.657 .754 .921 r
.94941 .51614 .95554 .52486 .97219 .52014 .96611 .51127 Mtetra
.651 .752 .923 r
.36894 .67321 .37725 .68041 .39088 .67656 .38262 .6694 Mtetra
.652 .754 .924 r
.38262 .6694 .39088 .67656 .40458 .67277 .39636 .66554 Mtetra
.661 .755 .92 r
.39636 .66554 .40458 .67277 .41836 .66889 .41019 .66136 Mtetra
.651 .746 .919 r
.41019 .66136 .41836 .66889 .43221 .66474 .42408 .65751 Mtetra
.627 .748 .934 r
.42408 .65751 .43221 .66474 .44613 .66088 .43802 .65438 Mtetra
.581 .756 .961 r
.43802 .65438 .44613 .66088 .46011 .65762 .45203 .65225 Mtetra
.515 .768 .988 r
.45203 .65225 .46011 .65762 .47415 .6551 .4661 .65096 Mtetra
.492 .8 .999 r
.4661 .65096 .47415 .6551 .48827 .65353 .48028 .64931 Mtetra
.551 .821 .996 r
.48028 .64931 .48827 .65353 .50249 .65182 .49456 .6467 Mtetra
.63 .817 .972 r
.49456 .6467 .50249 .65182 .5168 .64948 .50893 .6428 Mtetra
.7 .788 .919 r
.50893 .6428 .5168 .64948 .5312 .64628 .52338 .6369 Mtetra
.707 .726 .866 r
.52338 .6369 .5312 .64628 .54567 .64203 .53789 .63034 Mtetra
.699 .683 .831 r
.53789 .63034 .54567 .64203 .56021 .63651 .55245 .62356 Mtetra
.692 .663 .816 r
.55245 .62356 .56021 .63651 .57481 .63067 .56707 .61688 Mtetra
.683 .648 .809 r
.56707 .61688 .57481 .63067 .58947 .62479 .58176 .61059 Mtetra
.674 .64 .808 r
.58176 .61059 .58947 .62479 .6042 .61909 .59652 .60477 Mtetra
.666 .636 .81 r
.59652 .60477 .6042 .61909 .619 .61362 .61135 .59941 Mtetra
.659 .635 .814 r
.61135 .59941 .619 .61362 .63389 .60852 .62627 .59448 Mtetra
.653 .635 .819 r
.62627 .59448 .63389 .60852 .64886 .60381 .64127 .58993 Mtetra
.65 .636 .823 r
.64127 .58993 .64886 .60381 .66392 .59948 .65637 .58555 Mtetra
.647 .635 .824 r
.65637 .58555 .66392 .59948 .67909 .59555 .67155 .58136 Mtetra
.64 .629 .823 r
.67155 .58136 .67909 .59555 .69436 .59201 .68684 .57754 Mtetra
.631 .622 .822 r
.68684 .57754 .69436 .59201 .70974 .58885 .70223 .57417 Mtetra
.622 .615 .823 r
.70223 .57417 .70974 .58885 .72523 .58593 .71775 .57125 Mtetra
.613 .612 .826 r
.71775 .57125 .72523 .58593 .74083 .58319 .7334 .56883 Mtetra
.605 .613 .833 r
.7334 .56883 .74083 .58319 .75653 .58043 .74919 .56682 Mtetra
.602 .623 .845 r
.74919 .56682 .75653 .58043 .77231 .57734 .76509 .56492 Mtetra
.604 .644 .863 r
.76509 .56492 .77231 .57734 .7881 .57296 .78109 .56281 Mtetra
.614 .693 .9 r
.78109 .56281 .7881 .57296 .80388 .56749 .79714 .56003 Mtetra
.658 .779 .938 r
.79714 .56003 .80388 .56749 .81967 .56115 .81313 .55519 Mtetra
.688 .835 .954 r
.81313 .55519 .81967 .56115 .83546 .55412 .82909 .54902 Mtetra
.71 .869 .957 r
.82909 .54902 .83546 .55412 .85131 .54694 .84503 .54184 Mtetra
.72 .874 .953 r
.84503 .54184 .85131 .54694 .86733 .54073 .861 .53427 Mtetra
.702 .828 .943 r
.861 .53427 .86733 .54073 .8835 .53527 .87713 .52756 Mtetra
.677 .786 .931 r
.87713 .52756 .8835 .53527 .89983 .53043 .89344 .52188 Mtetra
.66 .758 .922 r
.89344 .52188 .89983 .53043 .91629 .5259 .90992 .51693 Mtetra
.651 .745 .918 r
.90992 .51693 .91629 .5259 .93281 .52106 .92654 .51233 Mtetra
.659 .755 .921 r
.92654 .51233 .93281 .52106 .94941 .51614 .94322 .50739 Mtetra
.659 .756 .922 r
.94322 .50739 .94941 .51614 .96611 .51127 .95998 .50239 Mtetra
.651 .753 .924 r
.36056 .66601 .36894 .67321 .38262 .6694 .37427 .66216 Mtetra
.661 .755 .92 r
.37427 .66216 .38262 .6694 .39636 .66554 .38808 .65797 Mtetra
.653 .746 .918 r
.38808 .65797 .39636 .66554 .41019 .66136 .40194 .65407 Mtetra
.626 .747 .934 r
.40194 .65407 .41019 .66136 .42408 .65751 .41585 .65095 Mtetra
.573 .752 .962 r
.41585 .65095 .42408 .65751 .43802 .65438 .4298 .649 Mtetra
.5 .764 .99 r
.4298 .649 .43802 .65438 .45203 .65225 .44383 .64794 Mtetra
.494 .797 .999 r
.44383 .64794 .45203 .65225 .4661 .65096 .45796 .64633 Mtetra
.575 .816 .99 r
.45796 .64633 .4661 .65096 .48028 .64931 .47221 .64347 Mtetra
.675 .806 .945 r
.47221 .64347 .48028 .64931 .49456 .6467 .48657 .63846 Mtetra
.716 .753 .881 r
.48657 .63846 .49456 .6467 .50893 .6428 .50101 .63164 Mtetra
.712 .696 .833 r
.50101 .63164 .50893 .6428 .52338 .6369 .5155 .62421 Mtetra
.705 .671 .814 r
.5155 .62421 .52338 .6369 .53789 .63034 .53004 .61671 Mtetra
.693 .655 .807 r
.53004 .61671 .53789 .63034 .55245 .62356 .54464 .60971 Mtetra
.68 .647 .81 r
.54464 .60971 .55245 .62356 .56707 .61688 .5593 .60357 Mtetra
.665 .649 .824 r
.5593 .60357 .56707 .61688 .58176 .61059 .57403 .59848 Mtetra
.661 .666 .844 r
.57403 .59848 .58176 .61059 .59652 .60477 .58885 .59378 Mtetra
.659 .685 .864 r
.58885 .59378 .59652 .60477 .61135 .59941 .60375 .5893 Mtetra
.657 .703 .88 r
.60375 .5893 .61135 .59941 .62627 .59448 .61873 .58491 Mtetra
.657 .715 .891 r
.61873 .58491 .62627 .59448 .64127 .58993 .63379 .58052 Mtetra
.657 .72 .895 r
.63379 .58052 .64127 .58993 .65637 .58555 .64893 .5761 Mtetra
.658 .72 .895 r
.64893 .5761 .65637 .58555 .67155 .58136 .66415 .57165 Mtetra
.657 .715 .891 r
.66415 .57165 .67155 .58136 .68684 .57754 .67946 .5672 Mtetra
.654 .701 .881 r
.67946 .5672 .68684 .57754 .70223 .57417 .69486 .56284 Mtetra
.648 .681 .867 r
.69486 .56284 .70223 .57417 .71775 .57125 .71035 .5587 Mtetra
.638 .656 .851 r
.71035 .5587 .71775 .57125 .7334 .56883 .72596 .55496 Mtetra
.617 .626 .838 r
.72596 .55496 .7334 .56883 .74919 .56682 .74173 .55229 Mtetra
.599 .609 .833 r
.74173 .55229 .74919 .56682 .76509 .56492 .75767 .55051 Mtetra
.588 .606 .838 r
.75767 .55051 .76509 .56492 .78109 .56281 .77377 .54925 Mtetra
.587 .619 .851 r
.77377 .54925 .78109 .56281 .79714 .56003 .78998 .54794 Mtetra
.597 .65 .873 r
.78998 .54794 .79714 .56003 .81313 .55519 .80626 .54602 Mtetra
.634 .729 .916 r
.80626 .54602 .81313 .55519 .82909 .54902 .8225 .54223 Mtetra
.684 .812 .944 r
.8225 .54223 .82909 .54902 .84503 .54184 .83863 .53623 Mtetra
.714 .858 .95 r
.83863 .53623 .84503 .54184 .861 .53427 .85472 .5289 Mtetra
.727 .871 .948 r
.85472 .5289 .861 .53427 .87713 .52756 .87081 .521 Mtetra
.707 .831 .941 r
.87081 .521 .87713 .52756 .89344 .52188 .88706 .51399 Mtetra
.678 .785 .93 r
.88706 .51399 .89344 .52188 .90992 .51693 .90353 .5082 Mtetra
.659 .756 .922 r
.90353 .5082 .90992 .51693 .92654 .51233 .92017 .50322 Mtetra
.652 .745 .918 r
.92017 .50322 .92654 .51233 .94322 .50739 .93696 .49853 Mtetra
.659 .756 .921 r
.93696 .49853 .94322 .50739 .95998 .50239 .95379 .49348 Mtetra
.659 .755 .921 r
.35209 .65873 .36056 .66601 .37427 .66216 .36586 .6546 Mtetra
.656 .748 .918 r
.36586 .6546 .37427 .66216 .38808 .65797 .3797 .65055 Mtetra
.629 .745 .931 r
.3797 .65055 .38808 .65797 .40194 .65407 .39358 .64733 Mtetra
.576 .75 .959 r
.39358 .64733 .40194 .65407 .41585 .65095 .4075 .64534 Mtetra
.494 .755 .988 r
.4075 .64534 .41585 .65095 .4298 .649 .42147 .64446 Mtetra
.492 .789 .998 r
.42147 .64446 .4298 .649 .44383 .64794 .43555 .643 Mtetra
.586 .81 .985 r
.43555 .643 .44383 .64794 .45796 .64633 .44977 .64002 Mtetra
.697 .797 .927 r
.44977 .64002 .45796 .64633 .47221 .64347 .46412 .63426 Mtetra
.724 .735 .859 r
.46412 .63426 .47221 .64347 .48657 .63846 .47855 .62674 Mtetra
.719 .69 .821 r
.47855 .62674 .48657 .63846 .50101 .63164 .49304 .61859 Mtetra
.708 .668 .808 r
.49304 .61859 .50101 .63164 .5155 .62421 .50757 .61073 Mtetra
.69 .656 .811 r
.50757 .61073 .5155 .62421 .53004 .61671 .52215 .60404 Mtetra
.669 .659 .832 r
.52215 .60404 .53004 .61671 .54464 .60971 .53679 .59884 Mtetra
.661 .687 .864 r
.53679 .59884 .54464 .60971 .5593 .60357 .5515 .5943 Mtetra
.652 .718 .897 r
.5515 .5943 .5593 .60357 .57403 .59848 .5663 .59016 Mtetra
.644 .739 .918 r
.5663 .59016 .57403 .59848 .58885 .59378 .58118 .58627 Mtetra
.642 .76 .935 r
.58118 .58627 .58885 .59378 .60375 .5893 .59614 .58233 Mtetra
.642 .777 .945 r
.59614 .58233 .60375 .5893 .61873 .58491 .61119 .57825 Mtetra
.645 .788 .95 r
.61119 .57825 .61873 .58491 .63379 .58052 .62632 .57399 Mtetra
.649 .794 .952 r
.62632 .57399 .63379 .58052 .64893 .5761 .64152 .56952 Mtetra
.655 .795 .95 r
.64152 .56952 .64893 .5761 .66415 .57165 .6568 .56486 Mtetra
.661 .793 .945 r
.6568 .56486 .66415 .57165 .67946 .5672 .67216 .56002 Mtetra
.666 .784 .937 r
.67216 .56002 .67946 .5672 .69486 .56284 .68759 .55503 Mtetra
.668 .769 .926 r
.68759 .55503 .69486 .56284 .71035 .5587 .7031 .54998 Mtetra
.662 .745 .912 r
.7031 .54998 .71035 .5587 .72596 .55496 .71871 .54518 Mtetra
.652 .718 .896 r
.71871 .54518 .72596 .55496 .74173 .55229 .73442 .54079 Mtetra
.637 .677 .872 r
.73442 .54079 .74173 .55229 .75767 .55051 .75028 .53707 Mtetra
.605 .631 .85 r
.75028 .53707 .75767 .55051 .77377 .54925 .76634 .53489 Mtetra
.58 .605 .842 r
.76634 .53489 .77377 .54925 .78998 .54794 .78261 .53391 Mtetra
.573 .607 .849 r
.78261 .53391 .78998 .54794 .80626 .54602 .79903 .53324 Mtetra
.582 .633 .867 r
.79903 .53324 .80626 .54602 .8225 .54223 .81553 .53196 Mtetra
.618 .699 .903 r
.81553 .53196 .8225 .54223 .83863 .53623 .832 .52885 Mtetra
.683 .799 .937 r
.832 .52885 .83863 .53623 .85472 .5289 .84829 .52287 Mtetra
.719 .851 .944 r
.84829 .52287 .85472 .5289 .87081 .521 .86451 .5153 Mtetra
.733 .866 .943 r
.86451 .5153 .87081 .521 .88706 .51399 .88073 .50709 Mtetra
.707 .825 .938 r
.88073 .50709 .88706 .51399 .90353 .5082 .89714 .50003 Mtetra
.676 .78 .928 r
.89714 .50003 .90353 .5082 .92017 .50322 .91377 .49424 Mtetra
.656 .752 .921 r
.91377 .49424 .92017 .50322 .93696 .49853 .9306 .48932 Mtetra
.653 .747 .918 r
.9306 .48932 .93696 .49853 .95379 .49348 .94754 .48447 Mtetra
.66 .752 .918 r
.34355 .65125 .35209 .65873 .36586 .6546 .35736 .64705 Mtetra
.637 .745 .927 r
.35736 .64705 .36586 .6546 .3797 .65055 .37122 .64358 Mtetra
.591 .748 .952 r
.37122 .64358 .3797 .65055 .39358 .64733 .38511 .64128 Mtetra
.497 .744 .983 r
.38511 .64128 .39358 .64733 .4075 .64534 .39902 .64053 Mtetra
.483 .778 .997 r
.39902 .64053 .4075 .64534 .42147 .64446 .41305 .63934 Mtetra
.583 .804 .984 r
.41305 .63934 .42147 .64446 .43555 .643 .42723 .63649 Mtetra
.703 .794 .921 r
.42723 .63649 .43555 .643 .44977 .64002 .44156 .63047 Mtetra
.73 .73 .85 r
.44156 .63047 .44977 .64002 .46412 .63426 .456 .62245 Mtetra
.726 .691 .816 r
.456 .62245 .46412 .63426 .47855 .62674 .47049 .61377 Mtetra
.711 .67 .808 r
.47049 .61377 .47855 .62674 .49304 .61859 .48502 .60569 Mtetra
.681 .661 .823 r
.48502 .60569 .49304 .61859 .50757 .61073 .49957 .59969 Mtetra
.664 .685 .86 r
.49957 .59969 .50757 .61073 .52215 .60404 .51418 .59496 Mtetra
.646 .72 .902 r
.51418 .59496 .52215 .60404 .53679 .59884 .52887 .59105 Mtetra
.63 .748 .933 r
.52887 .59105 .53679 .59884 .5515 .5943 .54365 .58756 Mtetra
.623 .776 .954 r
.54365 .58756 .5515 .5943 .5663 .59016 .55851 .58405 Mtetra
.623 .796 .965 r
.55851 .58405 .5663 .59016 .58118 .58627 .57345 .58032 Mtetra
.636 .805 .964 r
.57345 .58032 .58118 .58627 .59614 .58233 .58848 .57616 Mtetra
.641 .802 .96 r
.58848 .57616 .59614 .58233 .61119 .57825 .60358 .57186 Mtetra
.646 .798 .956 r
.60358 .57186 .61119 .57825 .62632 .57399 .61877 .56745 Mtetra
.649 .796 .953 r
.61877 .56745 .62632 .57399 .64152 .56952 .63404 .56295 Mtetra
.651 .797 .952 r
.63404 .56295 .64152 .56952 .6568 .56486 .64939 .55835 Mtetra
.653 .8 .953 r
.64939 .55835 .6568 .56486 .67216 .56002 .66482 .55364 Mtetra
.656 .806 .955 r
.66482 .55364 .67216 .56002 .68759 .55503 .68033 .54878 Mtetra
.667 .815 .954 r
.68033 .54878 .68759 .55503 .7031 .54998 .6959 .54349 Mtetra
.674 .811 .949 r
.6959 .54349 .7031 .54998 .71871 .54518 .71153 .53797 Mtetra
.677 .793 .936 r
.71153 .53797 .71871 .54518 .73442 .54079 .72725 .53242 Mtetra
.667 .76 .92 r
.72725 .53242 .73442 .54079 .75028 .53707 .74308 .5273 Mtetra
.647 .72 .901 r
.74308 .5273 .75028 .53707 .76634 .53489 .75905 .523 Mtetra
.618 .666 .874 r
.75905 .523 .76634 .53489 .78261 .53391 .77521 .52002 Mtetra
.574 .612 .852 r
.77521 .52002 .78261 .53391 .79903 .53324 .79165 .51917 Mtetra
.56 .603 .852 r
.79165 .51917 .79903 .53324 .81553 .53196 .80828 .51897 Mtetra
.571 .626 .868 r
.80828 .51897 .81553 .53196 .832 .52885 .82499 .51811 Mtetra
.612 .69 .899 r
.82499 .51811 .832 .52885 .84829 .52287 .84164 .51519 Mtetra
.687 .796 .932 r
.84164 .51519 .84829 .52287 .86451 .5153 .85808 .50897 Mtetra
.727 .848 .938 r
.85808 .50897 .86451 .5153 .88073 .50709 .87441 .50101 Mtetra
.738 .86 .938 r
.87441 .50101 .88073 .50709 .89714 .50003 .89076 .49256 Mtetra
.7 .81 .934 r
.89076 .49256 .89714 .50003 .91377 .49424 .90736 .48572 Mtetra
.671 .773 .926 r
.90736 .48572 .91377 .49424 .9306 .48932 .92418 .48009 Mtetra
.653 .749 .92 r
.92418 .48009 .9306 .48932 .94754 .48447 .9412 .47522 Mtetra
.647 .746 .921 r
.33493 .6436 .34355 .65125 .35736 .64705 .34877 .63978 Mtetra
.609 .747 .943 r
.34877 .63978 .35736 .64705 .37122 .64358 .36263 .63705 Mtetra
.516 .738 .975 r
.36263 .63705 .37122 .64358 .38511 .64128 .3765 .63614 Mtetra
.469 .763 .994 r
.3765 .63614 .38511 .64128 .39902 .64053 .39047 .63531 Mtetra
.562 .796 .987 r
.39047 .63531 .39902 .64053 .41305 .63934 .40459 .6329 Mtetra
.695 .795 .926 r
.40459 .6329 .41305 .63934 .42723 .63649 .4189 .62716 Mtetra
.735 .735 .851 r
.4189 .62716 .42723 .63649 .44156 .63047 .43334 .61887 Mtetra
.733 .697 .816 r
.43334 .61887 .44156 .63047 .456 .62245 .44784 .60975 Mtetra
.716 .676 .81 r
.44784 .60975 .456 .62245 .47049 .61377 .46237 .60146 Mtetra
.678 .669 .834 r
.46237 .60146 .47049 .61377 .48502 .60569 .4769 .59578 Mtetra
.657 .706 .883 r
.4769 .59578 .48502 .60569 .49957 .59969 .49148 .59141 Mtetra
.628 .735 .924 r
.49148 .59141 .49957 .59969 .51418 .59496 .50614 .58807 Mtetra
.612 .768 .955 r
.50614 .58807 .51418 .59496 .52887 .59105 .52088 .5849 Mtetra
.62 .793 .965 r
.52088 .5849 .52887 .59105 .54365 .58756 .53571 .58127 Mtetra
.636 .795 .959 r
.53571 .58127 .54365 .58756 .55851 .58405 .55063 .5772 Mtetra
.645 .783 .947 r
.55063 .5772 .55851 .58405 .57345 .58032 .56562 .57295 Mtetra
.65 .771 .937 r
.56562 .57295 .57345 .58032 .58848 .57616 .5807 .56858 Mtetra
.653 .768 .933 r
.5807 .56858 .58848 .57616 .60358 .57186 .59586 .56413 Mtetra
.654 .765 .931 r
.59586 .56413 .60358 .57186 .61877 .56745 .61111 .55962 Mtetra
.655 .764 .93 r
.61111 .55962 .61877 .56745 .63404 .56295 .62643 .55507 Mtetra
.655 .764 .929 r
.62643 .55507 .63404 .56295 .64939 .55835 .64185 .55048 Mtetra
.656 .765 .93 r
.64185 .55048 .64939 .55835 .66482 .55364 .65734 .54583 Mtetra
.657 .769 .932 r
.65734 .54583 .66482 .55364 .68033 .54878 .67292 .5411 Mtetra
.659 .774 .934 r
.67292 .5411 .68033 .54878 .6959 .54349 .68858 .53625 Mtetra
.662 .788 .942 r
.68858 .53625 .6959 .54349 .71153 .53797 .70431 .53121 Mtetra
.672 .806 .947 r
.70431 .53121 .71153 .53797 .72725 .53242 .7201 .52571 Mtetra
.684 .813 .944 r
.7201 .52571 .72725 .53242 .74308 .5273 .73595 .51974 Mtetra
.681 .79 .932 r
.73595 .51974 .74308 .5273 .75905 .523 .75189 .51394 Mtetra
.656 .743 .914 r
.75189 .51394 .75905 .523 .77521 .52002 .76798 .50918 Mtetra
.625 .692 .892 r
.76798 .50918 .77521 .52002 .79165 .51917 .78428 .50577 Mtetra
.568 .619 .863 r
.78428 .50577 .79165 .51917 .80828 .51897 .8009 .50506 Mtetra
.549 .602 .859 r
.8009 .50506 .80828 .51897 .82499 .51811 .81774 .50523 Mtetra
.564 .627 .873 r
.81774 .50523 .82499 .51811 .84164 .51519 .83465 .50456 Mtetra
.619 .699 .902 r
.83465 .50456 .84164 .51519 .85808 .50897 .85144 .50125 Mtetra
.699 .803 .93 r
.85144 .50125 .85808 .50897 .87441 .50101 .86798 .49448 Mtetra
.737 .849 .933 r
.86798 .49448 .87441 .50101 .89076 .49256 .88443 .48603 Mtetra
.735 .85 .935 r
.88443 .48603 .89076 .49256 .90736 .48572 .90094 .47763 Mtetra
.69 .794 .929 r
.90094 .47763 .90736 .48572 .92418 .48009 .91775 .47114 Mtetra
.663 .762 .924 r
.91775 .47114 .92418 .48009 .9412 .47522 .93478 .46577 Mtetra
.626 .745 .932 r
.32622 .63603 .33493 .6436 .34877 .63978 .34007 .63284 Mtetra
.553 .74 .963 r
.34007 .63284 .34877 .63978 .36263 .63705 .35391 .63132 Mtetra
.466 .745 .989 r
.35391 .63132 .36263 .63705 .3765 .63614 .36781 .63082 Mtetra
.527 .782 .99 r
.36781 .63082 .3765 .63614 .39047 .63531 .38185 .62908 Mtetra
.668 .796 .943 r
.38185 .62908 .39047 .63531 .40459 .6329 .39611 .62426 Mtetra
.739 .751 .862 r
.39611 .62426 .40459 .6329 .4189 .62716 .41055 .61599 Mtetra
.74 .706 .819 r
.41055 .61599 .4189 .62716 .43334 .61887 .42507 .60654 Mtetra
.723 .685 .812 r
.42507 .60654 .43334 .61887 .44784 .60975 .43961 .59781 Mtetra
.68 .677 .84 r
.43961 .59781 .44784 .60975 .46237 .60146 .45412 .59205 Mtetra
.652 .716 .895 r
.45412 .59205 .46237 .60146 .4769 .59578 .46867 .58792 Mtetra
.615 .743 .937 r
.46867 .58792 .4769 .59578 .49148 .59141 .48329 .58487 Mtetra
.604 .777 .963 r
.48329 .58487 .49148 .59141 .50614 .58807 .498 .58178 Mtetra
.63 .793 .96 r
.498 .58178 .50614 .58807 .52088 .5849 .5128 .57788 Mtetra
.644 .778 .945 r
.5128 .57788 .52088 .5849 .53571 .58127 .52768 .57371 Mtetra
.651 .766 .933 r
.52768 .57371 .53571 .58127 .55063 .5772 .54265 .56935 Mtetra
.654 .76 .928 r
.54265 .56935 .55063 .5772 .56562 .57295 .5577 .56488 Mtetra
.655 .756 .924 r
.5577 .56488 .56562 .57295 .5807 .56858 .57284 .56038 Mtetra
.655 .754 .922 r
.57284 .56038 .5807 .56858 .59586 .56413 .58805 .55585 Mtetra
.655 .753 .922 r
.58805 .55585 .59586 .56413 .61111 .55962 .60335 .55129 Mtetra
.656 .753 .922 r
.60335 .55129 .61111 .55962 .62643 .55507 .61874 .5467 Mtetra
.656 .754 .922 r
.61874 .5467 .62643 .55507 .64185 .55048 .63421 .54206 Mtetra
.63421 .54206 .64185 .55048 .65734 .54583 .64976 .5374 Mtetra
.64976 .5374 .65734 .54583 .67292 .5411 .6654 .5327 Mtetra
.656 .757 .924 r
.6654 .5327 .67292 .5411 .68858 .53625 .68113 .52798 Mtetra
.658 .762 .926 r
.68113 .52798 .68858 .53625 .70431 .53121 .69694 .52315 Mtetra
.662 .77 .929 r
.69694 .52315 .70431 .53121 .7201 .52571 .71283 .51811 Mtetra
.668 .785 .936 r
.71283 .51811 .7201 .52571 .73595 .51974 .72879 .51279 Mtetra
.687 .81 .941 r
.72879 .51279 .73595 .51974 .75189 .51394 .74478 .50664 Mtetra
.689 .803 .936 r
.74478 .50664 .75189 .51394 .76798 .50918 .76085 .50044 Mtetra
.662 .757 .921 r
.76085 .50044 .76798 .50918 .78428 .50577 .77708 .49534 Mtetra
.622 .703 .903 r
.77708 .49534 .78428 .50577 .8009 .50506 .79354 .49193 Mtetra
.556 .62 .871 r
.79354 .49193 .8009 .50506 .81774 .50523 .81037 .49158 Mtetra
.539 .603 .866 r
.81037 .49158 .81774 .50523 .83465 .50456 .82742 .49201 Mtetra
.562 .636 .881 r
.82742 .49201 .83465 .50456 .85144 .50125 .84451 .49123 Mtetra
.641 .725 .909 r
.84451 .49123 .85144 .50125 .86798 .49448 .86137 .48687 Mtetra
.715 .815 .927 r
.86137 .48687 .86798 .49448 .88443 .48603 .878 .47929 Mtetra
.745 .849 .928 r
.878 .47929 .88443 .48603 .90094 .47763 .89455 .47037 Mtetra
.72 .829 .932 r
.89455 .47037 .90094 .47763 .91775 .47114 .91129 .46251 Mtetra
.679 .779 .926 r
.91129 .46251 .91775 .47114 .93478 .46577 .92831 .45639 Mtetra
.598 .745 .947 r
.3174 .62871 .32622 .63603 .34007 .63284 .33126 .6262 Mtetra
.488 .727 .977 r
.33126 .6262 .34007 .63284 .35391 .63132 .34509 .62576 Mtetra
.486 .76 .991 r
.34509 .62576 .35391 .63132 .36781 .63082 .35904 .62481 Mtetra
.612 .789 .966 r
.35904 .62481 .36781 .63082 .38185 .62908 .37321 .62151 Mtetra
.736 .774 .884 r
.37321 .62151 .38185 .62908 .39611 .62426 .38763 .61374 Mtetra
.746 .718 .826 r
.38763 .61374 .39611 .62426 .41055 .61599 .40217 .60414 Mtetra
.735 .695 .813 r
.40217 .60414 .41055 .61599 .42507 .60654 .41673 .59475 Mtetra
.69 .683 .838 r
.41673 .59475 .42507 .60654 .43961 .59781 .43124 .58842 Mtetra
.653 .718 .896 r
.43124 .58842 .43961 .59781 .45412 .59205 .44576 .58421 Mtetra
.609 .742 .94 r
.44576 .58421 .45412 .59205 .46867 .58792 .46034 .58132 Mtetra
.604 .776 .963 r
.46034 .58132 .46867 .58792 .48329 .58487 .47501 .57821 Mtetra
.634 .784 .954 r
.47501 .57821 .48329 .58487 .498 .58178 .48978 .57428 Mtetra
.648 .767 .935 r
.48978 .57428 .498 .58178 .5128 .57788 .50464 .57002 Mtetra
.654 .76 .927 r
.50464 .57002 .5128 .57788 .52768 .57371 .51958 .56558 Mtetra
.654 .754 .923 r
.51958 .56558 .52768 .57371 .54265 .56935 .5346 .56111 Mtetra
.65 .751 .924 r
.5346 .56111 .54265 .56935 .5577 .56488 .5497 .55677 Mtetra
.649 .756 .927 r
.5497 .55677 .5577 .56488 .57284 .56038 .5649 .55243 Mtetra
.65 .761 .93 r
.5649 .55243 .57284 .56038 .58805 .55585 .58017 .54799 Mtetra
.652 .765 .932 r
.58017 .54799 .58805 .55585 .60335 .55129 .59553 .54346 Mtetra
.654 .768 .933 r
.59553 .54346 .60335 .55129 .61874 .5467 .61098 .53881 Mtetra
.657 .768 .932 r
.61098 .53881 .61874 .5467 .63421 .54206 .62651 .53407 Mtetra
.659 .768 .93 r
.62651 .53407 .63421 .54206 .64976 .5374 .64212 .52922 Mtetra
.661 .765 .927 r
.64212 .52922 .64976 .5374 .6654 .5327 .65781 .52427 Mtetra
.661 .759 .923 r
.65781 .52427 .6654 .5327 .68113 .52798 .67359 .51931 Mtetra
.657 .754 .921 r
.67359 .51931 .68113 .52798 .69694 .52315 .68947 .51449 Mtetra
.657 .755 .922 r
.68947 .51449 .69694 .52315 .71283 .51811 .70543 .50964 Mtetra
.661 .762 .925 r
.70543 .50964 .71283 .51811 .72879 .51279 .72148 .5046 Mtetra
.668 .773 .928 r
.72148 .5046 .72879 .51279 .74478 .50664 .73759 .49922 Mtetra
.688 .801 .935 r
.73759 .49922 .74478 .50664 .76085 .50044 .75373 .49299 Mtetra
.693 .804 .933 r
.75373 .49299 .76085 .50044 .77708 .49534 .76994 .48652 Mtetra
.66 .758 .922 r
.76994 .48652 .77708 .49534 .79354 .49193 .78633 .4814 Mtetra
.608 .698 .907 r
.78633 .4814 .79354 .49193 .81037 .49158 .803 .47848 Mtetra
.538 .614 .876 r
.803 .47848 .81037 .49158 .82742 .49201 .82008 .47873 Mtetra
.533 .609 .875 r
.82008 .47873 .82742 .49201 .84451 .49123 .83733 .47923 Mtetra
.572 .654 .892 r
.83733 .47923 .84451 .49123 .86137 .48687 .85455 .47784 Mtetra
.678 .768 .918 r
.85455 .47784 .86137 .48687 .878 .47929 .87142 .47179 Mtetra
.734 .828 .922 r
.87142 .47179 .878 .47929 .89455 .47037 .88811 .46327 Mtetra
.747 .844 .924 r
.88811 .46327 .89455 .47037 .91129 .46251 .9048 .45418 Mtetra
.697 .796 .927 r
.9048 .45418 .91129 .46251 .92831 .45639 .92181 .44724 Mtetra
.544 .735 .963 r
.30849 .62157 .3174 .62871 .33126 .6262 .32231 .62021 Mtetra
.459 .737 .988 r
.32231 .62021 .33126 .6262 .34509 .62576 .33618 .61986 Mtetra
.549 .774 .982 r
.33618 .61986 .34509 .62576 .35904 .62481 .35023 .61788 Mtetra
.701 .785 .917 r
.35023 .61788 .35904 .62481 .37321 .62151 .36456 .61185 Mtetra
.748 .734 .84 r
.36456 .61185 .37321 .62151 .38763 .61374 .3791 .60254 Mtetra
.747 .709 .816 r
.3791 .60254 .38763 .61374 .40217 .60414 .3937 .5925 Mtetra
.71 .693 .832 r
.3937 .5925 .40217 .60414 .41673 .59475 .40824 .58498 Mtetra
.663 .714 .886 r
.40824 .58498 .41673 .59475 .43124 .58842 .42275 .58029 Mtetra
.61 .736 .935 r
.42275 .58029 .43124 .58842 .44576 .58421 .43729 .5774 Mtetra
.6 .77 .961 r
.43729 .5774 .44576 .58421 .46034 .58132 .45191 .57445 Mtetra
.634 .779 .951 r
.45191 .57445 .46034 .58132 .47501 .57821 .46665 .57054 Mtetra
.649 .763 .933 r
.46665 .57054 .47501 .57821 .48978 .57428 .48148 .56624 Mtetra
.654 .756 .925 r
.48148 .56624 .48978 .57428 .50464 .57002 .49639 .56178 Mtetra
.649 .751 .924 r
.49639 .56178 .50464 .57002 .51958 .56558 .51138 .55747 Mtetra
.645 .754 .929 r
.51138 .55747 .51958 .56558 .5346 .56111 .52646 .55329 Mtetra
.646 .763 .934 r
.52646 .55329 .5346 .56111 .5497 .55677 .54162 .549 Mtetra
.651 .767 .934 r
.54162 .549 .5497 .55677 .5649 .55243 .55687 .5445 Mtetra
.654 .765 .931 r
.55687 .5445 .5649 .55243 .58017 .54799 .57221 .53989 Mtetra
.655 .762 .928 r
.57221 .53989 .58017 .54799 .59553 .54346 .58762 .53524 Mtetra
.655 .76 .927 r
.58762 .53524 .59553 .54346 .61098 .53881 .60313 .53055 Mtetra
.60313 .53055 .61098 .53881 .62651 .53407 .61872 .52583 Mtetra
.656 .762 .928 r
.61872 .52583 .62651 .53407 .64212 .52922 .63439 .52105 Mtetra
.658 .766 .93 r
.63439 .52105 .64212 .52922 .65781 .52427 .65015 .51617 Mtetra
.663 .771 .93 r
.65015 .51617 .65781 .52427 .67359 .51931 .666 .51107 Mtetra
.665 .769 .927 r
.666 .51107 .67359 .51931 .68947 .51449 .68192 .50586 Mtetra
.662 .759 .923 r
.68192 .50586 .68947 .51449 .70543 .50964 .69794 .50078 Mtetra
.657 .753 .921 r
.69794 .50078 .70543 .50964 .72148 .5046 .71406 .49585 Mtetra
.661 .759 .923 r
.71406 .49585 .72148 .5046 .73759 .49922 .73026 .49075 Mtetra
.67 .77 .925 r
.73026 .49075 .73759 .49922 .75373 .49299 .74652 .48524 Mtetra
.693 .798 .93 r
.74652 .48524 .75373 .49299 .76994 .48652 .7628 .47875 Mtetra
.694 .799 .93 r
.7628 .47875 .76994 .48652 .78633 .4814 .77916 .47217 Mtetra
.649 .747 .921 r
.77916 .47217 .78633 .4814 .803 .47848 .79575 .46744 Mtetra
.577 .676 .907 r
.79575 .46744 .803 .47848 .82008 .47873 .81271 .46566 Mtetra
.52 .608 .881 r
.81271 .46566 .82008 .47873 .83733 .47923 .83003 .46651 Mtetra
.536 .624 .886 r
.83003 .46651 .83733 .47923 .85455 .47784 .84745 .46662 Mtetra
.614 .693 .9 r
.84745 .46662 .85455 .47784 .87142 .47179 .86468 .46332 Mtetra
.711 .797 .918 r
.86468 .46332 .87142 .47179 .88811 .46327 .88156 .45578 Mtetra
.749 .836 .918 r
.88156 .45578 .88811 .46327 .9048 .45418 .89833 .4465 Mtetra
.725 .826 .927 r
.89833 .4465 .9048 .45418 .92181 .44724 .91528 .43826 Mtetra
.492 .721 .973 r
.29947 .61457 .30849 .62157 .32231 .62021 .31327 .61412 Mtetra
.486 .747 .986 r
.31327 .61412 .32231 .62021 .33618 .61986 .3272 .61333 Mtetra
.622 .78 .957 r
.3272 .61333 .33618 .61986 .35023 .61788 .34138 .60984 Mtetra
.743 .767 .872 r
.34138 .60984 .35023 .61788 .36456 .61185 .35588 .60147 Mtetra
.755 .724 .824 r
.35588 .60147 .36456 .61185 .3791 .60254 .37051 .5912 Mtetra
.735 .705 .823 r
.37051 .5912 .3791 .60254 .3937 .5925 .38512 .58198 Mtetra
.68 .705 .866 r
.38512 .58198 .3937 .5925 .40824 .58498 .39963 .57643 Mtetra
.624 .731 .924 r
.39963 .57643 .40824 .58498 .42275 .58029 .41414 .57314 Mtetra
.59 .758 .958 r
.41414 .57314 .42275 .58029 .43729 .5774 .42872 .5705 Mtetra
.629 .778 .952 r
.42872 .5705 .43729 .5774 .45191 .57445 .44342 .5667 Mtetra
.648 .762 .932 r
.44342 .5667 .45191 .57445 .46665 .57054 .45822 .56243 Mtetra
.654 .755 .924 r
.45822 .56243 .46665 .57054 .48148 .56624 .4731 .55795 Mtetra
.646 .75 .925 r
.4731 .55795 .48148 .56624 .49639 .56178 .48806 .55376 Mtetra
.642 .756 .932 r
.48806 .55376 .49639 .56178 .51138 .55747 .50311 .54964 Mtetra
.649 .764 .934 r
.50311 .54964 .51138 .55747 .52646 .55329 .51824 .54523 Mtetra
.655 .762 .928 r
.51824 .54523 .52646 .55329 .54162 .549 .53346 .54061 Mtetra
.657 .755 .922 r
.53346 .54061 .54162 .549 .55687 .5445 .54876 .53591 Mtetra
.658 .752 .919 r
.54876 .53591 .55687 .5445 .57221 .53989 .56415 .53116 Mtetra
.657 .749 .918 r
.56415 .53116 .57221 .53989 .58762 .53524 .57962 .5264 Mtetra
.656 .748 .917 r
.57962 .5264 .58762 .53524 .60313 .53055 .59518 .52167 Mtetra
.655 .747 .918 r
.59518 .52167 .60313 .53055 .61872 .52583 .61083 .51695 Mtetra
.654 .748 .919 r
.61083 .51695 .61872 .52583 .63439 .52105 .62657 .51222 Mtetra
.655 .751 .92 r
.62657 .51222 .63439 .52105 .65015 .51617 .6424 .50744 Mtetra
.656 .755 .923 r
.6424 .50744 .65015 .51617 .666 .51107 .65831 .50258 Mtetra
.66 .764 .926 r
.65831 .50258 .666 .51107 .68192 .50586 .67431 .49751 Mtetra
.667 .77 .927 r
.67431 .49751 .68192 .50586 .69794 .50078 .69038 .49214 Mtetra
.665 .764 .924 r
.69038 .49214 .69794 .50078 .71406 .49585 .70655 .48683 Mtetra
.657 .753 .921 r
.70655 .48683 .71406 .49585 .73026 .49075 .72282 .48181 Mtetra
.662 .758 .921 r
.72282 .48181 .73026 .49075 .74652 .48524 .73917 .47659 Mtetra
.673 .77 .923 r
.73917 .47659 .74652 .48524 .7628 .47875 .75559 .47086 Mtetra
.701 .8 .927 r
.75559 .47086 .7628 .47875 .77916 .47217 .772 .46393 Mtetra
.684 .787 .928 r
.772 .46393 .77916 .47217 .79575 .46744 .78854 .45767 Mtetra
.627 .729 .92 r
.78854 .45767 .79575 .46744 .81271 .46566 .80538 .45373 Mtetra
.534 .639 .9 r
.80538 .45373 .81271 .46566 .83003 .46651 .82267 .45362 Mtetra
.511 .61 .887 r
.82267 .45362 .83003 .46651 .84745 .46662 .84022 .45462 Mtetra
.557 .651 .898 r
.84022 .45462 .84745 .46662 .86468 .46332 .85774 .45367 Mtetra
.675 .758 .913 r
.85774 .45367 .86468 .46332 .88156 .45578 .87487 .44761 Mtetra
.739 .818 .914 r
.87487 .44761 .88156 .45578 .89833 .4465 .89177 .43869 Mtetra
.747 .831 .916 r
.89177 .43869 .89833 .4465 .91528 .43826 .90869 .4294 Mtetra
.463 .721 .981 r
.29032 .60789 .29947 .61457 .31327 .61412 .30415 .60772 Mtetra
.533 .757 .979 r
.30415 .60772 .31327 .61412 .3272 .61333 .31816 .60616 Mtetra
.691 .78 .919 r
.31816 .60616 .3272 .61333 .34138 .60984 .33251 .60045 Mtetra
.753 .742 .842 r
.33251 .60045 .34138 .60984 .35588 .60147 .34713 .59081 Mtetra
.756 .721 .82 r
.34713 .59081 .35588 .60147 .37051 .5912 .36182 .58031 Mtetra
.712 .708 .845 r
.36182 .58031 .37051 .5912 .38512 .58198 .3764 .5729 Mtetra
.651 .728 .905 r
.3764 .5729 .38512 .58198 .39963 .57643 .39091 .56864 Mtetra
.592 .742 .948 r
.39091 .56864 .39963 .57643 .41414 .57314 .40544 .5661 Mtetra
.614 .771 .955 r
.40544 .5661 .41414 .57314 .42872 .5705 .42009 .56273 Mtetra
.644 .761 .934 r
.42009 .56273 .42872 .5705 .44342 .5667 .43485 .55857 Mtetra
.654 .756 .925 r
.43485 .55857 .44342 .5667 .45822 .56243 .4497 .55408 Mtetra
.645 .749 .925 r
.4497 .55408 .45822 .56243 .4731 .55795 .46463 .54988 Mtetra
.64 .756 .932 r
.46463 .54988 .4731 .55795 .48806 .55376 .47964 .54581 Mtetra
.651 .763 .931 r
.47964 .54581 .48806 .55376 .50311 .54964 .49474 .54133 Mtetra
.657 .757 .924 r
.49474 .54133 .50311 .54964 .51824 .54523 .50993 .53663 Mtetra
.66 .752 .918 r
.50993 .53663 .51824 .54523 .53346 .54061 .52521 .53179 Mtetra
.659 .748 .915 r
.52521 .53179 .53346 .54061 .54876 .53591 .54056 .52696 Mtetra
.658 .745 .914 r
.54056 .52696 .54876 .53591 .56415 .53116 .55601 .52216 Mtetra
.657 .745 .915 r
.55601 .52216 .56415 .53116 .57962 .5264 .57154 .51739 Mtetra
.656 .745 .916 r
.57154 .51739 .57962 .5264 .59518 .52167 .58715 .5126 Mtetra
.58715 .5126 .59518 .52167 .61083 .51695 .60286 .5078 Mtetra
.655 .744 .916 r
.60286 .5078 .61083 .51695 .62657 .51222 .61866 .50302 Mtetra
.653 .744 .916 r
.61866 .50302 .62657 .51222 .6424 .50744 .63455 .49828 Mtetra
.652 .745 .918 r
.63455 .49828 .6424 .50744 .65831 .50258 .65053 .49354 Mtetra
.655 .75 .92 r
.65053 .49354 .65831 .50258 .67431 .49751 .6666 .48866 Mtetra
.659 .758 .923 r
.6666 .48866 .67431 .49751 .69038 .49214 .68275 .48355 Mtetra
.669 .769 .925 r
.68275 .48355 .69038 .49214 .70655 .48683 .69897 .47803 Mtetra
.665 .764 .923 r
.69897 .47803 .70655 .48683 .72282 .48181 .71529 .47263 Mtetra
.658 .753 .92 r
.71529 .47263 .72282 .48181 .73917 .47659 .73173 .46752 Mtetra
.665 .76 .921 r
.73173 .46752 .73917 .47659 .75559 .47086 .74823 .46207 Mtetra
.684 .775 .92 r
.74823 .46207 .75559 .47086 .772 .46393 .76477 .45579 Mtetra
.704 .799 .924 r
.76477 .45579 .772 .46393 .78854 .45767 .78133 .44866 Mtetra
.661 .763 .926 r
.78133 .44866 .78854 .45767 .80538 .45373 .79811 .44328 Mtetra
.577 .695 .922 r
.79811 .44328 .80538 .45373 .82267 .45362 .81529 .44118 Mtetra
.5 .615 .897 r
.81529 .44118 .82267 .45362 .84022 .45462 .8329 .44231 Mtetra
.523 .631 .899 r
.8329 .44231 .84022 .45462 .85774 .45367 .8506 .44258 Mtetra
.623 .706 .905 r
.8506 .44258 .85774 .45367 .87487 .44761 .86803 .43875 Mtetra
.721 .797 .912 r
.86803 .43875 .87487 .44761 .89177 .43869 .88511 .43054 Mtetra
.752 .827 .909 r
.88511 .43054 .89177 .43869 .90869 .4294 .90208 .42085 Mtetra
.468 .725 .981 r
.28108 .60119 .29032 .60789 .30415 .60772 .29495 .60089 Mtetra
.583 .763 .964 r
.29495 .60089 .30415 .60772 .31816 .60616 .30907 .59837 Mtetra
.732 .773 .886 r
.30907 .59837 .31816 .60616 .33251 .60045 .32358 .59068 Mtetra
.762 .738 .831 r
.32358 .59068 .33251 .60045 .34713 .59081 .3383 .58017 Mtetra
.749 .722 .827 r
.3383 .58017 .34713 .59081 .36182 .58031 .35301 .57023 Mtetra
.685 .717 .873 r
.35301 .57023 .36182 .58031 .3764 .5729 .36756 .56442 Mtetra
.618 .734 .929 r
.36756 .56442 .3764 .5729 .39091 .56864 .38207 .56123 Mtetra
.591 .754 .956 r
.38207 .56123 .39091 .56864 .40544 .5661 .39665 .55854 Mtetra
.635 .765 .941 r
.39665 .55854 .40544 .5661 .42009 .56273 .41137 .55463 Mtetra
.652 .757 .927 r
.41137 .55463 .42009 .56273 .43485 .55857 .42619 .55019 Mtetra
.649 .75 .924 r
.42619 .55019 .43485 .55857 .4497 .55408 .44109 .54584 Mtetra
.638 .752 .931 r
.44109 .54584 .4497 .55408 .46463 .54988 .45607 .54182 Mtetra
.649 .761 .931 r
.45607 .54182 .46463 .54988 .47964 .54581 .47114 .53739 Mtetra
.658 .755 .922 r
.47114 .53739 .47964 .54581 .49474 .54133 .4863 .53264 Mtetra
.662 .751 .917 r
.4863 .53264 .49474 .54133 .50993 .53663 .50154 .52772 Mtetra
.659 .747 .915 r
.50154 .52772 .50993 .53663 .52521 .53179 .51687 .52288 Mtetra
.651 .745 .918 r
.51687 .52288 .52521 .53179 .54056 .52696 .53228 .51833 Mtetra
.65 .753 .924 r
.53228 .51833 .54056 .52696 .55601 .52216 .54779 .51374 Mtetra
.652 .76 .928 r
.54779 .51374 .55601 .52216 .57154 .51739 .56338 .50903 Mtetra
.655 .763 .929 r
.56338 .50903 .57154 .51739 .58715 .5126 .57906 .5042 Mtetra
.658 .764 .928 r
.57906 .5042 .58715 .5126 .60286 .5078 .59482 .49923 Mtetra
.66 .762 .925 r
.59482 .49923 .60286 .5078 .61866 .50302 .61067 .49414 Mtetra
.661 .756 .921 r
.61067 .49414 .61866 .50302 .63455 .49828 .62661 .48901 Mtetra
.653 .745 .917 r
.62661 .48901 .63455 .49828 .65053 .49354 .64265 .48418 Mtetra
.651 .744 .918 r
.64265 .48418 .65053 .49354 .6666 .48866 .65879 .47942 Mtetra
.654 .749 .919 r
.65879 .47942 .6666 .48866 .68275 .48355 .67502 .47449 Mtetra
.661 .757 .921 r
.67502 .47449 .68275 .48355 .69897 .47803 .69132 .46923 Mtetra
.671 .768 .923 r
.69132 .46923 .69897 .47803 .71529 .47263 .7077 .46354 Mtetra
.662 .759 .922 r
.7077 .46354 .71529 .47263 .73173 .46752 .72419 .45819 Mtetra
.659 .754 .92 r
.72419 .45819 .73173 .46752 .74823 .46207 .74078 .45292 Mtetra
.672 .764 .92 r
.74078 .45292 .74823 .46207 .76477 .45579 .75742 .44711 Mtetra
.701 .787 .917 r
.75742 .44711 .76477 .45579 .78133 .44866 .77406 .44002 Mtetra
.689 .785 .924 r
.77406 .44002 .78133 .44866 .79811 .44328 .79083 .43343 Mtetra
.621 .731 .925 r
.79083 .43343 .79811 .44328 .81529 .44118 .80792 .42956 Mtetra
.509 .638 .912 r
.80792 .42956 .81529 .44118 .8329 .44231 .82552 .43001 Mtetra
.498 .619 .902 r
.82552 .43001 .8329 .44231 .8506 .44258 .84336 .43107 Mtetra
.573 .675 .909 r
.84336 .43107 .8506 .44258 .86803 .43875 .86106 .42921 Mtetra
.7 .776 .911 r
.86106 .42921 .86803 .43875 .88511 .43054 .87832 .4219 Mtetra
.749 .816 .905 r
.87832 .4219 .88511 .43054 .90208 .42085 .8954 .41226 Mtetra
.49 .729 .978 r
.27175 .59426 .28108 .60119 .29495 .60089 .28568 .59362 Mtetra
.632 .767 .944 r
.28568 .59362 .29495 .60089 .30907 .59837 .29992 .58987 Mtetra
.75 .761 .862 r
.29992 .58987 .30907 .59837 .32358 .59068 .31457 .58081 Mtetra
.766 .739 .827 r
.31457 .58081 .32358 .59068 .3383 .58017 .32936 .56988 Mtetra
.735 .726 .843 r
.32936 .56988 .3383 .58017 .35301 .57023 .34407 .56113 Mtetra
.665 .734 .902 r
.34407 .56113 .35301 .57023 .36756 .56442 .35862 .55629 Mtetra
.592 .737 .944 r
.35862 .55629 .36756 .56442 .38207 .56123 .37315 .55373 Mtetra
.611 .76 .95 r
.37315 .55373 .38207 .56123 .39665 .55854 .3878 .55048 Mtetra
.644 .757 .931 r
.3878 .55048 .39665 .55854 .41137 .55463 .40257 .54626 Mtetra
.654 .753 .923 r
.40257 .54626 .41137 .55463 .42619 .55019 .41744 .54172 Mtetra
.639 .747 .927 r
.41744 .54172 .42619 .55019 .44109 .54584 .43239 .53766 Mtetra
.643 .757 .932 r
.43239 .53766 .44109 .54584 .45607 .54182 .44742 .53342 Mtetra
.656 .756 .923 r
.44742 .53342 .45607 .54182 .47114 .53739 .46255 .52869 Mtetra
.662 .752 .917 r
.46255 .52869 .47114 .53739 .4863 .53264 .47776 .52372 Mtetra
.658 .747 .916 r
.47776 .52372 .4863 .53264 .50154 .52772 .49306 .51891 Mtetra
.646 .747 .922 r
.49306 .51891 .50154 .52772 .51687 .52288 .50845 .51448 Mtetra
.647 .758 .93 r
.50845 .51448 .51687 .52288 .53228 .51833 .52392 .50996 Mtetra
.653 .762 .93 r
.52392 .50996 .53228 .51833 .54779 .51374 .53948 .50521 Mtetra
.655 .76 .927 r
.53948 .50521 .54779 .51374 .56338 .50903 .55513 .50036 Mtetra
.655 .758 .925 r
.55513 .50036 .56338 .50903 .57906 .5042 .57087 .49548 Mtetra
.656 .758 .925 r
.57087 .49548 .57906 .5042 .59482 .49923 .58669 .49055 Mtetra
.657 .761 .926 r
.58669 .49055 .59482 .49923 .61067 .49414 .60261 .48552 Mtetra
.663 .765 .926 r
.60261 .48552 .61067 .49414 .62661 .48901 .61861 .48026 Mtetra
.664 .764 .924 r
.61861 .48026 .62661 .48901 .64265 .48418 .6347 .4749 Mtetra
.654 .749 .92 r
.6347 .4749 .64265 .48418 .65879 .47942 .6509 .46994 Mtetra
.65 .744 .918 r
.6509 .46994 .65879 .47942 .67502 .47449 .66719 .46512 Mtetra
.655 .75 .92 r
.66719 .46512 .67502 .47449 .69132 .46923 .68358 .46006 Mtetra
.667 .76 .92 r
.68358 .46006 .69132 .46923 .7077 .46354 .70003 .4545 Mtetra
.671 .766 .922 r
.70003 .4545 .7077 .46354 .72419 .45819 .71657 .44875 Mtetra
.658 .753 .92 r
.71657 .44875 .72419 .45819 .74078 .45292 .73323 .44349 Mtetra
.666 .757 .919 r
.73323 .44349 .74078 .45292 .75742 .44711 .74996 .43788 Mtetra
.688 .772 .915 r
.74996 .43788 .75742 .44711 .77406 .44002 .76672 .43127 Mtetra
.705 .79 .918 r
.76672 .43127 .77406 .44002 .79083 .43343 .78351 .42394 Mtetra
.648 .753 .926 r
.78351 .42394 .79083 .43343 .80792 .42956 .80057 .41895 Mtetra
.538 .678 .929 r
.80057 .41895 .80792 .42956 .82552 .43001 .81812 .41804 Mtetra
.481 .619 .91 r
.81812 .41804 .82552 .43001 .84336 .43107 .83604 .41943 Mtetra
.535 .656 .914 r
.83604 .41943 .84336 .43107 .86106 .42921 .85394 .41889 Mtetra
.671 .75 .91 r
.85394 .41889 .86106 .42921 .87832 .4219 .87141 .41279 Mtetra
.741 .805 .902 r
.87141 .41279 .87832 .4219 .8954 .41226 .88861 .40339 Mtetra
.516 .732 .972 r
.26234 .58703 .27175 .59426 .28568 .59362 .27633 .58597 Mtetra
.672 .769 .923 r
.27633 .58597 .28568 .59362 .29992 .58987 .29071 .5809 Mtetra
.758 .755 .849 r
.29071 .5809 .29992 .58987 .31457 .58081 .30546 .57105 Mtetra
.768 .742 .829 r
.30546 .57105 .31457 .58081 .32936 .56988 .32032 .55999 Mtetra
.719 .732 .861 r
.32032 .55999 .32936 .56988 .34407 .56113 .33501 .55238 Mtetra
.641 .738 .919 r
.33501 .55238 .34407 .56113 .35862 .55629 .34957 .54835 Mtetra
.582 .74 .951 r
.34957 .54835 .35862 .55629 .37315 .55373 .36413 .54595 Mtetra
.629 .761 .942 r
.36413 .54595 .37315 .55373 .3878 .55048 .37885 .54217 Mtetra
.65 .754 .926 r
.37885 .54217 .3878 .55048 .40257 .54626 .39369 .53774 Mtetra
.649 .75 .923 r
.39369 .53774 .40257 .54626 .41744 .54172 .4086 .53332 Mtetra
.636 .75 .931 r
.4086 .53332 .41744 .54172 .43239 .53766 .42359 .52931 Mtetra
.651 .757 .927 r
.42359 .52931 .43239 .53766 .44742 .53342 .43869 .52474 Mtetra
.661 .753 .918 r
.43869 .52474 .44742 .53342 .46255 .52869 .45387 .51979 Mtetra
.661 .749 .915 r
.45387 .51979 .46255 .52869 .47776 .52372 .46914 .51481 Mtetra
.645 .745 .922 r
.46914 .51481 .47776 .52372 .49306 .51891 .48449 .51041 Mtetra
.646 .757 .93 r
.48449 .51041 .49306 .51891 .50845 .51448 .49993 .50592 Mtetra
.654 .759 .927 r
.49993 .50592 .50845 .51448 .52392 .50996 .51546 .50111 Mtetra
.659 .754 .921 r
.51546 .50111 .52392 .50996 .53948 .50521 .53108 .49611 Mtetra
.66 .75 .917 r
.53108 .49611 .53948 .50521 .55513 .50036 .54679 .49104 Mtetra
.656 .745 .915 r
.54679 .49104 .55513 .50036 .57087 .49548 .56258 .4861 Mtetra
.652 .743 .917 r
.56258 .4861 .57087 .49548 .58669 .49055 .57847 .48129 Mtetra
.653 .748 .919 r
.57847 .48129 .58669 .49055 .60261 .48552 .59445 .47641 Mtetra
.657 .754 .921 r
.59445 .47641 .60261 .48552 .61861 .48026 .61053 .47134 Mtetra
.664 .762 .923 r
.61053 .47134 .61861 .48026 .6347 .4749 .62668 .46595 Mtetra
.666 .763 .923 r
.62668 .46595 .6347 .4749 .6509 .46994 .64292 .46046 Mtetra
.651 .747 .92 r
.64292 .46046 .6509 .46994 .66719 .46512 .65928 .45555 Mtetra
.651 .746 .919 r
.65928 .45555 .66719 .46512 .68358 .46006 .67574 .4506 Mtetra
.66 .753 .919 r
.67574 .4506 .68358 .46006 .70003 .4545 .69227 .44528 Mtetra
.673 .765 .919 r
.69227 .44528 .70003 .4545 .71657 .44875 .70887 .43938 Mtetra
.662 .759 .922 r
.70887 .43938 .71657 .44875 .73323 .44349 .72559 .43387 Mtetra
.661 .754 .919 r
.72559 .43387 .73323 .44349 .74996 .43788 .74241 .42839 Mtetra
.677 .764 .917 r
.74241 .42839 .74996 .43788 .76672 .43127 .75928 .42222 Mtetra
.709 .787 .912 r
.75928 .42222 .76672 .43127 .78351 .42394 .77612 .41461 Mtetra
.67 .768 .924 r
.77612 .41461 .78351 .42394 .80057 .41895 .79319 .40868 Mtetra
.571 .705 .932 r
.79319 .40868 .80057 .41895 .81812 .41804 .81069 .40648 Mtetra
.472 .626 .919 r
.81069 .40648 .81812 .41804 .83604 .41943 .82867 .40789 Mtetra
.51 .648 .919 r
.82867 .40789 .83604 .41943 .85394 .41889 .8467 .40806 Mtetra
.64 .728 .912 r
.8467 .40806 .85394 .41889 .87141 .41279 .86439 .40324 Mtetra
.733 .794 .901 r
.86439 .40324 .87141 .41279 .88861 .40339 .88172 .39418 Mtetra
.539 .734 .965 r
.25285 .57948 .26234 .58703 .27633 .58597 .26691 .57801 Mtetra
.697 .768 .907 r
.26691 .57801 .27633 .58597 .29071 .5809 .2814 .57188 Mtetra
.765 .756 .844 r
.2814 .57188 .29071 .5809 .30546 .57105 .29625 .56147 Mtetra
.768 .747 .834 r
.29625 .56147 .30546 .57105 .32032 .55999 .31117 .55051 Mtetra
.704 .739 .878 r
.31117 .55051 .32032 .55999 .33501 .55238 .32585 .54378 Mtetra
.623 .738 .929 r
.32585 .54378 .33501 .55238 .34957 .54835 .34042 .5403 Mtetra
.589 .742 .949 r
.34042 .5403 .34957 .54835 .36413 .54595 .35504 .53768 Mtetra
.636 .752 .932 r
.35504 .53768 .36413 .54595 .37885 .54217 .36982 .53368 Mtetra
.652 .753 .923 r
.36982 .53368 .37885 .54217 .39369 .53774 .38471 .52911 Mtetra
.643 .748 .925 r
.38471 .52911 .39369 .53774 .4086 .53332 .39967 .52486 Mtetra
.639 .752 .93 r
.39967 .52486 .4086 .53332 .42359 .52931 .41471 .52069 Mtetra
.656 .754 .922 r
.41471 .52069 .42359 .52931 .43869 .52474 .42987 .51591 Mtetra
.663 .752 .916 r
.42987 .51591 .43869 .52474 .45387 .51979 .44511 .51083 Mtetra
.652 .747 .919 r
.44511 .51083 .45387 .51979 .46914 .51481 .46043 .50613 Mtetra
.642 .752 .929 r
.46043 .50613 .46914 .51481 .48449 .51041 .47583 .50177 Mtetra
.653 .757 .926 r
.47583 .50177 .48449 .51041 .49993 .50592 .49133 .49698 Mtetra
.663 .755 .918 r
.49133 .49698 .49993 .50592 .51546 .50111 .50692 .49179 Mtetra
.665 .748 .912 r
.50692 .49179 .51546 .50111 .53108 .49611 .52259 .48649 Mtetra
.659 .74 .91 r
.52259 .48649 .53108 .49611 .54679 .49104 .53836 .48143 Mtetra
.656 .741 .912 r
.53836 .48143 .54679 .49104 .56258 .4861 .55421 .47643 Mtetra
.654 .74 .913 r
.55421 .47643 .56258 .4861 .57847 .48129 .57016 .47152 Mtetra
.647 .736 .914 r
.57016 .47152 .57847 .48129 .59445 .47641 .5862 .46683 Mtetra
.649 .742 .918 r
.5862 .46683 .59445 .47641 .61053 .47134 .60234 .46203 Mtetra
.658 .753 .92 r
.60234 .46203 .61053 .47134 .62668 .46595 .61857 .45683 Mtetra
.668 .762 .921 r
.61857 .45683 .62668 .46595 .64292 .46046 .63487 .4512 Mtetra
.659 .757 .923 r
.63487 .4512 .64292 .46046 .65928 .45555 .65128 .4459 Mtetra
.649 .746 .92 r
.65128 .4459 .65928 .45555 .67574 .4506 .66781 .44099 Mtetra
.656 .75 .919 r
.66781 .44099 .67574 .4506 .69227 .44528 .68442 .43577 Mtetra
.67 .759 .917 r
.68442 .43577 .69227 .44528 .70887 .43938 .7011 .42992 Mtetra
.668 .761 .92 r
.7011 .42992 .70887 .43938 .72559 .43387 .71787 .42415 Mtetra
.659 .753 .919 r
.71787 .42415 .72559 .43387 .74241 .42839 .73476 .4187 Mtetra
.673 .76 .916 r
.73476 .4187 .74241 .42839 .75928 .42222 .75172 .41264 Mtetra
.704 .775 .907 r
.75172 .41264 .75928 .42222 .77612 .41461 .76866 .40516 Mtetra
.684 .773 .918 r
.76866 .40516 .77612 .41461 .79319 .40868 .78575 .39855 Mtetra
.598 .723 .932 r
.78575 .39855 .79319 .40868 .81069 .40648 .80323 .39532 Mtetra
.47 .636 .927 r
.80323 .39532 .81069 .40648 .82867 .40789 .82125 .39651 Mtetra
.49 .643 .924 r
.82125 .39651 .82867 .40789 .8467 .40806 .8394 .39717 Mtetra
.614 .717 .919 r
.8394 .39717 .8467 .40806 .86439 .40324 .85726 .39335 Mtetra
.724 .786 .901 r
.85726 .39335 .86439 .40324 .88172 .39418 .87472 .3846 Mtetra
.556 .734 .958 r
.24327 .57162 .25285 .57948 .26691 .57801 .25739 .56983 Mtetra
.711 .767 .896 r
.25739 .56983 .26691 .57801 .2814 .57188 .272 .56296 Mtetra
.77 .76 .843 r
.272 .56296 .2814 .57188 .29625 .56147 .28693 .55219 Mtetra
.768 .754 .84 r
.28693 .55219 .29625 .56147 .31117 .55051 .30189 .5414 Mtetra
.693 .746 .892 r
.30189 .5414 .31117 .55051 .32585 .54378 .3166 .53521 Mtetra
.611 .737 .935 r
.3166 .53521 .32585 .54378 .34042 .5403 .33119 .53204 Mtetra
.596 .741 .945 r
.33119 .53204 .34042 .5403 .35504 .53768 .34586 .5292 Mtetra
.64 .75 .929 r
.34586 .5292 .35504 .53768 .36982 .53368 .3607 .52504 Mtetra
.653 .752 .922 r
.3607 .52504 .36982 .53368 .38471 .52911 .37564 .5204 Mtetra
.639 .747 .927 r
.37564 .5204 .38471 .52911 .39967 .52486 .39064 .51624 Mtetra
.643 .751 .928 r
.39064 .51624 .39967 .52486 .41471 .52069 .40575 .51189 Mtetra
.659 .753 .92 r
.40575 .51189 .41471 .52069 .42987 .51591 .42095 .50696 Mtetra
.663 .752 .916 r
.42095 .50696 .42987 .51591 .44511 .51083 .43625 .50184 Mtetra
.645 .747 .923 r
.43625 .50184 .44511 .51083 .46043 .50613 .45162 .49735 Mtetra
.645 .753 .927 r
.45162 .49735 .46043 .50613 .47583 .50177 .46708 .49282 Mtetra
.658 .754 .921 r
.46708 .49282 .47583 .50177 .49133 .49698 .48264 .48779 Mtetra
.669 .753 .913 r
.48264 .48779 .49133 .49698 .50692 .49179 .49829 .4823 Mtetra
.654 .742 .915 r
.49829 .4823 .50692 .49179 .52259 .48649 .51402 .47739 Mtetra
.645 .75 .925 r
.51402 .47739 .52259 .48649 .53836 .48143 .52984 .47277 Mtetra
.655 .765 .93 r
.52984 .47277 .53836 .48143 .55421 .47643 .54576 .46772 Mtetra
.665 .768 .926 r
.54576 .46772 .55421 .47643 .57016 .47152 .56176 .46225 Mtetra
.658 .754 .921 r
.56176 .46225 .57016 .47152 .5862 .46683 .57786 .45706 Mtetra
.642 .738 .918 r
.57786 .45706 .5862 .46683 .60234 .46203 .59407 .45246 Mtetra
.653 .748 .919 r
.59407 .45246 .60234 .46203 .61857 .45683 .61036 .4474 Mtetra
.665 .756 .918 r
.61036 .4474 .61857 .45683 .63487 .4512 .62674 .44183 Mtetra
.666 .759 .92 r
.62674 .44183 .63487 .4512 .65128 .4459 .6432 .43621 Mtetra
.649 .747 .921 r
.6432 .43621 .65128 .4459 .66781 .44099 .65979 .43124 Mtetra
.653 .749 .92 r
.65979 .43124 .66781 .44099 .68442 .43577 .67647 .42606 Mtetra
.667 .756 .917 r
.67647 .42606 .68442 .43577 .7011 .42992 .69323 .42029 Mtetra
.671 .761 .918 r
.69323 .42029 .7011 .42992 .71787 .42415 .71007 .41431 Mtetra
.658 .753 .92 r
.71007 .41431 .71787 .42415 .73476 .4187 .72703 .40883 Mtetra
.67 .758 .916 r
.72703 .40883 .73476 .4187 .75172 .41264 .74406 .40283 Mtetra
.7 .771 .907 r
.74406 .40283 .75172 .41264 .76866 .40516 .76109 .39547 Mtetra
.692 .773 .913 r
.76109 .39547 .76866 .40516 .78575 .39855 .77823 .38843 Mtetra
.615 .733 .93 r
.77823 .38843 .78575 .39855 .80323 .39532 .79573 .38452 Mtetra
.471 .647 .935 r
.79573 .38452 .80323 .39532 .82125 .39651 .81379 .38543 Mtetra
.474 .644 .932 r
.81379 .38543 .82125 .39651 .8394 .39717 .83203 .38634 Mtetra
.595 .712 .926 r
.83203 .38634 .8394 .39717 .85726 .39335 .85003 .38318 Mtetra
.718 .78 .902 r
.85003 .38318 .85726 .39335 .87472 .3846 .86761 .37467 Mtetra
.565 .731 .953 r
.23362 .56346 .24327 .57162 .25739 .56983 .24779 .56147 Mtetra
.718 .766 .89 r
.24779 .56147 .25739 .56983 .272 .56296 .26247 .55421 Mtetra
.774 .765 .845 r
.26247 .55421 .272 .56296 .28693 .55219 .27749 .54324 Mtetra
.768 .762 .847 r
.27749 .54324 .28693 .55219 .30189 .5414 .2925 .5326 Mtetra
.69 .754 .901 r
.2925 .5326 .30189 .5414 .3166 .53521 .30724 .52658 Mtetra
.605 .736 .937 r
.30724 .52658 .3166 .53521 .33119 .53204 .32187 .52354 Mtetra
.601 .739 .941 r
.32187 .52354 .33119 .53204 .34586 .5292 .33659 .52054 Mtetra
.642 .749 .927 r
.33659 .52054 .34586 .5292 .3607 .52504 .35148 .51628 Mtetra
.653 .751 .921 r
.35148 .51628 .3607 .52504 .37564 .5204 .36647 .51159 Mtetra
.637 .746 .927 r
.36647 .51159 .37564 .5204 .39064 .51624 .38153 .50745 Mtetra
.645 .75 .925 r
.38153 .50745 .39064 .51624 .40575 .51189 .39668 .50297 Mtetra
.66 .753 .919 r
.39668 .50297 .40575 .51189 .42095 .50696 .41195 .49795 Mtetra
.662 .752 .917 r
.41195 .49795 .42095 .50696 .43625 .50184 .4273 .4928 Mtetra
.642 .747 .925 r
.4273 .4928 .43625 .50184 .45162 .49735 .44272 .48838 Mtetra
.648 .751 .925 r
.44272 .48838 .45162 .49735 .46708 .49282 .45824 .48371 Mtetra
.663 .754 .918 r
.45824 .48371 .46708 .49282 .48264 .48779 .47385 .47844 Mtetra
.668 .751 .913 r
.47385 .47844 .48264 .48779 .49829 .4823 .48956 .47296 Mtetra
.64 .744 .924 r
.48956 .47296 .49829 .4823 .51402 .47739 .50535 .4685 Mtetra
.634 .753 .934 r
.50535 .4685 .51402 .47739 .52984 .47277 .52123 .46419 Mtetra
.655 .769 .933 r
.52123 .46419 .52984 .47277 .54576 .46772 .53721 .45909 Mtetra
.675 .775 .926 r
.53721 .45909 .54576 .46772 .56176 .46225 .55328 .4532 Mtetra
.67 .765 .921 r
.55328 .4532 .56176 .46225 .57786 .45706 .56944 .44746 Mtetra
.644 .745 .922 r
.56944 .44746 .57786 .45706 .59407 .45246 .5857 .44274 Mtetra
.649 .745 .92 r
.5857 .44274 .59407 .45246 .61036 .4474 .60206 .43781 Mtetra
.663 .754 .918 r
.60206 .43781 .61036 .4474 .62674 .44183 .61851 .43227 Mtetra
.669 .758 .917 r
.61851 .43227 .62674 .44183 .6432 .43621 .63504 .42647 Mtetra
.649 .749 .922 r
.63504 .42647 .6432 .43621 .65979 .43124 .65169 .42141 Mtetra
.652 .749 .921 r
.65169 .42141 .65979 .43124 .67647 .42606 .66844 .41622 Mtetra
.665 .755 .917 r
.66844 .41622 .67647 .42606 .69323 .42029 .68527 .41046 Mtetra
.673 .759 .916 r
.68527 .41046 .69323 .42029 .71007 .41431 .70217 .40436 Mtetra
.658 .752 .919 r
.70217 .40436 .71007 .41431 .72703 .40883 .71921 .39882 Mtetra
.668 .756 .916 r
.71921 .39882 .72703 .40883 .74406 .40283 .73632 .39282 Mtetra
.697 .768 .906 r
.73632 .39282 .74406 .40283 .76109 .39547 .75343 .3855 Mtetra
.696 .77 .909 r
.75343 .3855 .76109 .39547 .77823 .38843 .77064 .37822 Mtetra
.621 .736 .929 r
.77064 .37822 .77823 .38843 .79573 .38452 .78819 .37403 Mtetra
.472 .658 .942 r
.78819 .37403 .79573 .38452 .81379 .38543 .80628 .37466 Mtetra
.462 .648 .939 r
.80628 .37466 .81379 .38543 .83203 .38634 .8246 .37567 Mtetra
.583 .713 .932 r
.8246 .37567 .83203 .38634 .85003 .38318 .84272 .3728 Mtetra
.714 .777 .902 r
.84272 .3728 .85003 .38318 .86761 .37467 .8604 .36439 Mtetra
.567 .727 .949 r
.22388 .55501 .23362 .56346 .24779 .56147 .2381 .55297 Mtetra
.718 .765 .89 r
.2381 .55297 .24779 .56147 .26247 .55421 .25283 .54566 Mtetra
.776 .771 .848 r
.25283 .54566 .26247 .55421 .27749 .54324 .26791 .53463 Mtetra
.771 .771 .852 r
.26791 .53463 .27749 .54324 .2925 .5326 .28299 .52393 Mtetra
.69 .759 .904 r
.28299 .52393 .2925 .5326 .30724 .52658 .29779 .51785 Mtetra
.605 .736 .937 r
.29779 .51785 .30724 .52658 .32187 .52354 .31246 .51476 Mtetra
.602 .735 .938 r
.31246 .51476 .32187 .52354 .33659 .52054 .32723 .51173 Mtetra
.642 .747 .925 r
.32723 .51173 .33659 .52054 .35148 .51628 .34217 .50742 Mtetra
.653 .75 .921 r
.34217 .50742 .35148 .51628 .36647 .51159 .35721 .50267 Mtetra
.637 .746 .927 r
.35721 .50267 .36647 .51159 .38153 .50745 .37232 .49848 Mtetra
.646 .748 .924 r
.37232 .49848 .38153 .50745 .39668 .50297 .38753 .49396 Mtetra
.66 .752 .919 r
.38753 .49396 .39668 .50297 .41195 .49795 .40285 .48888 Mtetra
.662 .753 .918 r
.40285 .48888 .41195 .49795 .4273 .4928 .41825 .48368 Mtetra
.642 .747 .925 r
.41825 .48368 .4273 .4928 .44272 .48838 .43373 .47921 Mtetra
.648 .749 .923 r
.43373 .47921 .44272 .48838 .45824 .48371 .4493 .47449 Mtetra
.663 .754 .917 r
.4493 .47449 .45824 .48371 .47385 .47844 .46498 .46916 Mtetra
.668 .755 .916 r
.46498 .46916 .47385 .47844 .48956 .47296 .48074 .46363 Mtetra
.64 .746 .926 r
.48074 .46363 .48956 .47296 .50535 .4685 .49659 .45911 Mtetra
.635 .744 .927 r
.49659 .45911 .50535 .4685 .52123 .46419 .51253 .45476 Mtetra
.656 .751 .92 r
.51253 .45476 .52123 .46419 .53721 .45909 .52857 .4496 Mtetra
.675 .757 .913 r
.52857 .4496 .53721 .45909 .55328 .4532 .5447 .44365 Mtetra
.67 .756 .915 r
.5447 .44365 .55328 .4532 .56944 .44746 .56092 .43785 Mtetra
.644 .747 .924 r
.56092 .43785 .56944 .44746 .5857 .44274 .57725 .43308 Mtetra
.648 .749 .923 r
.57725 .43308 .5857 .44274 .60206 .43781 .59367 .42809 Mtetra
.663 .754 .918 r
.59367 .42809 .60206 .43781 .61851 .43227 .61018 .42249 Mtetra
.669 .756 .916 r
.61018 .42249 .61851 .43227 .63504 .42647 .62678 .41663 Mtetra
.649 .749 .922 r
.62678 .41663 .63504 .42647 .65169 .42141 .6435 .41152 Mtetra
.652 .75 .921 r
.6435 .41152 .65169 .42141 .66844 .41622 .66032 .40627 Mtetra
.665 .755 .917 r
.66032 .40627 .66844 .41622 .68527 .41046 .67722 .40045 Mtetra
.673 .757 .914 r
.67722 .40045 .68527 .41046 .70217 .40436 .69419 .39428 Mtetra
.658 .752 .919 r
.69419 .39428 .70217 .40436 .71921 .39882 .7113 .38868 Mtetra
.668 .756 .916 r
.7113 .38868 .71921 .39882 .73632 .39282 .72848 .38262 Mtetra
.697 .766 .905 r
.72848 .38262 .73632 .39282 .75343 .3855 .74567 .37524 Mtetra
.696 .766 .906 r
.74567 .37524 .75343 .3855 .77064 .37822 .76296 .36789 Mtetra
.621 .736 .929 r
.76296 .36789 .77064 .37822 .78819 .37403 .78058 .36364 Mtetra
.468 .661 .946 r
.78058 .36364 .78819 .37403 .80628 .37466 .79874 .36422 Mtetra
.455 .654 .946 r
.79874 .36422 .80628 .37466 .8246 .37567 .81712 .36518 Mtetra
.581 .719 .938 r
.81712 .36518 .8246 .37567 .84272 .3728 .83531 .36226 Mtetra
.714 .776 .901 r
.83531 .36226 .84272 .3728 .8604 .36439 .85307 .35378 Mtetra
.563 .72 .947 r
.21407 .54626 .22388 .55501 .2381 .55297 .2283 .54434 Mtetra
.711 .763 .893 r
.2283 .54434 .2381 .55297 .25283 .54566 .24307 .53732 Mtetra
.776 .777 .853 r
.24307 .53732 .25283 .54566 .26791 .53463 .25821 .52635 Mtetra
.777 .779 .855 r
.25821 .52635 .26791 .53463 .28299 .52393 .27338 .51537 Mtetra
.695 .765 .905 r
.27338 .51537 .28299 .52393 .29779 .51785 .28824 .50903 Mtetra
.611 .737 .935 r
.28824 .50903 .29779 .51785 .31246 .51476 .30297 .50572 Mtetra
.6 .73 .936 r
.30297 .50572 .31246 .51476 .32723 .51173 .31778 .50274 Mtetra
.64 .745 .925 r
.31778 .50274 .32723 .51173 .34217 .50742 .33276 .49845 Mtetra
.653 .75 .921 r
.33276 .49845 .34217 .50742 .35721 .50267 .34786 .49365 Mtetra
.639 .746 .926 r
.34786 .49365 .35721 .50267 .37232 .49848 .36301 .48934 Mtetra
.644 .746 .923 r
.36301 .48934 .37232 .49848 .38753 .49396 .37827 .48484 Mtetra
.659 .752 .919 r
.37827 .48484 .38753 .49396 .40285 .48888 .39364 .47976 Mtetra
.663 .754 .918 r
.39364 .47976 .40285 .48888 .41825 .48368 .40911 .47448 Mtetra
.645 .748 .924 r
.40911 .47448 .41825 .48368 .43373 .47921 .42464 .46984 Mtetra
.646 .746 .922 r
.42464 .46984 .43373 .47921 .4493 .47449 .44027 .46515 Mtetra
.659 .752 .919 r
.44027 .46515 .4493 .47449 .46498 .46916 .456 .45996 Mtetra
.669 .759 .918 r
.456 .45996 .46498 .46916 .48074 .46363 .47183 .4543 Mtetra
.654 .753 .923 r
.47183 .4543 .48074 .46363 .49659 .45911 .48774 .44924 Mtetra
.646 .739 .917 r
.48774 .44924 .49659 .45911 .51253 .45476 .50374 .44445 Mtetra
.656 .734 .907 r
.50374 .44445 .51253 .45476 .52857 .4496 .51984 .43924 Mtetra
.665 .738 .904 r
.51984 .43924 .52857 .4496 .5447 .44365 .53603 .4336 Mtetra
.658 .743 .913 r
.53603 .4336 .5447 .44365 .56092 .43785 .55232 .42824 Mtetra
.642 .749 .927 r
.55232 .42824 .56092 .43785 .57725 .43308 .56871 .42348 Mtetra
.653 .754 .924 r
.56871 .42348 .57725 .43308 .59367 .42809 .58519 .41825 Mtetra
.665 .754 .917 r
.58519 .41825 .59367 .42809 .61018 .42249 .60177 .4125 Mtetra
.666 .752 .915 r
.60177 .4125 .61018 .42249 .62678 .41663 .61844 .4067 Mtetra
.649 .749 .923 r
.61844 .4067 .62678 .41663 .6435 .41152 .63522 .40156 Mtetra
.653 .751 .922 r
.63522 .40156 .6435 .41152 .66032 .40627 .65211 .3962 Mtetra
.667 .755 .916 r
.65211 .3962 .66032 .40627 .67722 .40045 .66907 .39024 Mtetra
.671 .755 .914 r
.66907 .39024 .67722 .40045 .69419 .39428 .68612 .38408 Mtetra
.658 .752 .919 r
.68612 .38408 .69419 .39428 .7113 .38868 .7033 .37842 Mtetra
.67 .756 .915 r
.7033 .37842 .7113 .38868 .72848 .38262 .72055 .37223 Mtetra
.699 .765 .903 r
.72055 .37223 .72848 .38262 .74567 .37524 .73781 .36467 Mtetra
.692 .76 .904 r
.73781 .36467 .74567 .37524 .76296 .36789 .75519 .35743 Mtetra
.615 .733 .93 r
.75519 .35743 .76296 .36789 .78058 .36364 .7729 .35335 Mtetra
.456 .66 .949 r
.7729 .35335 .78058 .36364 .79874 .36422 .79114 .35411 Mtetra
.452 .664 .953 r
.79114 .35411 .79874 .36422 .81712 .36518 .80958 .35488 Mtetra
.59 .73 .941 r
.80958 .35488 .81712 .36518 .83531 .36226 .82781 .35154 Mtetra
.717 .776 .899 r
.82781 .35154 .83531 .36226 .85307 .35378 .84565 .34282 Mtetra
.553 .711 .945 r
.20417 .5372 .21407 .54626 .2283 .54434 .21842 .53553 Mtetra
.696 .758 .9 r
.21842 .53553 .2283 .54434 .24307 .53732 .23318 .52915 Mtetra
.774 .782 .859 r
.23318 .52915 .24307 .53732 .25821 .52635 .24836 .51841 Mtetra
.783 .788 .857 r
.24836 .51841 .25821 .52635 .27338 .51537 .26362 .50713 Mtetra
.71 .776 .904 r
.26362 .50713 .27338 .51537 .28824 .50903 .27859 .50013 Mtetra
.622 .742 .932 r
.27859 .50013 .28824 .50903 .30297 .50572 .29339 .49642 Mtetra
.595 .724 .934 r
.29339 .49642 .30297 .50572 .31778 .50274 .30823 .49358 Mtetra
.637 .742 .924 r
.30823 .49358 .31778 .50274 .33276 .49845 .32325 .48935 Mtetra
.653 .749 .921 r
.32325 .48935 .33276 .49845 .34786 .49365 .3384 .48453 Mtetra
.643 .747 .925 r
.3384 .48453 .34786 .49365 .36301 .48934 .35362 .48003 Mtetra
.64 .743 .923 r
.35362 .48003 .36301 .48934 .37827 .48484 .36892 .47561 Mtetra
.656 .751 .92 r
.36892 .47561 .37827 .48484 .39364 .47976 .38435 .47057 Mtetra
.663 .755 .918 r
.38435 .47057 .39364 .47976 .40911 .47448 .39987 .46523 Mtetra
.652 .752 .922 r
.39987 .46523 .40911 .47448 .42464 .46984 .41546 .46027 Mtetra
.643 .743 .922 r
.41546 .46027 .42464 .46984 .44027 .46515 .43114 .45565 Mtetra
.654 .749 .92 r
.43114 .45565 .44027 .46515 .456 .45996 .44693 .4506 Mtetra
.663 .756 .919 r
.44693 .4506 .456 .45996 .47183 .4543 .46281 .44514 Mtetra
.665 .763 .923 r
.46281 .44514 .47183 .4543 .48774 .44924 .47879 .43956 Mtetra
.659 .75 .918 r
.47879 .43956 .48774 .44924 .50374 .44445 .49485 .43422 Mtetra
.656 .738 .91 r
.49485 .43422 .50374 .44445 .51984 .43924 .51101 .42895 Mtetra
.653 .738 .911 r
.51101 .42895 .51984 .43924 .53603 .4336 .52726 .42376 Mtetra
.646 .746 .922 r
.52726 .42376 .53603 .4336 .55232 .42824 .54362 .4188 Mtetra
.648 .757 .929 r
.54362 .4188 .55232 .42824 .56871 .42348 .56007 .41372 Mtetra
.658 .755 .921 r
.56007 .41372 .56871 .42348 .58519 .41825 .57662 .40824 Mtetra
.668 .754 .915 r
.57662 .40824 .58519 .41825 .60177 .4125 .59326 .40231 Mtetra
.659 .748 .916 r
.59326 .40231 .60177 .4125 .61844 .4067 .61 .39671 Mtetra
.648 .75 .924 r
.61 .39671 .61844 .4067 .63522 .40156 .62685 .39151 Mtetra
.656 .753 .921 r
.62685 .39151 .63522 .40156 .65211 .3962 .6438 .386 Mtetra
.67 .756 .915 r
.6438 .386 .65211 .3962 .66907 .39024 .66083 .37984 Mtetra
.668 .752 .913 r
.66083 .37984 .66907 .39024 .68612 .38408 .67796 .37376 Mtetra
.659 .752 .919 r
.67796 .37376 .68612 .38408 .7033 .37842 .69521 .36801 Mtetra
.673 .756 .914 r
.69521 .36801 .7033 .37842 .72055 .37223 .71253 .36164 Mtetra
.703 .765 .9 r
.71253 .36164 .72055 .37223 .73781 .36467 .72986 .35382 Mtetra
.683 .754 .905 r
.72986 .35382 .73781 .36467 .75519 .35743 .74733 .34689 Mtetra
.597 .726 .934 r
.74733 .34689 .75519 .35743 .7729 .35335 .76516 .34336 Mtetra
.439 .661 .955 r
.76516 .34336 .7729 .35335 .79114 .35411 .7835 .34432 Mtetra
.455 .676 .959 r
.7835 .34432 .79114 .35411 .80958 .35488 .80198 .34473 Mtetra
.609 .745 .942 r
.80198 .34473 .80958 .35488 .82781 .35154 .82022 .3406 Mtetra
.723 .776 .895 r
.82022 .3406 .82781 .35154 .84565 .34282 .83811 .3315 Mtetra
.539 .7 .944 r
.1942 .52781 .20417 .5372 .21842 .53553 .20844 .52648 Mtetra
.672 .75 .909 r
.20844 .52648 .21842 .53553 .23318 .52915 .22316 .52107 Mtetra
.768 .785 .867 r
.22316 .52107 .23318 .52915 .24836 .51841 .23838 .51078 Mtetra
.787 .796 .86 r
.23838 .51078 .24836 .51841 .26362 .50713 .25373 .49928 Mtetra
.731 .79 .9 r
.25373 .49928 .26362 .50713 .27859 .50013 .26883 .49127 Mtetra
.64 .75 .928 r
.26883 .49127 .27859 .50013 .29339 .49642 .28372 .48691 Mtetra
.589 .719 .934 r
.28372 .48691 .29339 .49642 .30823 .49358 .29859 .4842 Mtetra
.632 .738 .924 r
.29859 .4842 .30823 .49358 .32325 .48935 .31365 .48009 Mtetra
.65 .747 .92 r
.31365 .48009 .32325 .48935 .3384 .48453 .32884 .47531 Mtetra
.649 .749 .922 r
.32884 .47531 .3384 .48453 .35362 .48003 .34413 .47054 Mtetra
.637 .74 .923 r
.34413 .47054 .35362 .48003 .36892 .47561 .35948 .46619 Mtetra
.652 .748 .92 r
.35948 .46619 .36892 .47561 .38435 .47057 .37495 .46125 Mtetra
.661 .754 .919 r
.37495 .46125 .38435 .47057 .39987 .46523 .39052 .45594 Mtetra
.661 .756 .92 r
.39052 .45594 .39987 .46523 .41546 .46027 .40619 .45059 Mtetra
.645 .743 .921 r
.40619 .45059 .41546 .46027 .43114 .45565 .42192 .44583 Mtetra
.647 .742 .918 r
.42192 .44583 .43114 .45565 .44693 .4506 .43776 .44097 Mtetra
.655 .75 .92 r
.43776 .44097 .44693 .4506 .46281 .44514 .4537 .43579 Mtetra
.659 .759 .924 r
.4537 .43579 .46281 .44514 .47879 .43956 .46973 .43041 Mtetra
.66 .765 .927 r
.46973 .43041 .47879 .43956 .49485 .43422 .48586 .42494 Mtetra
.655 .762 .928 r
.48586 .42494 .49485 .43422 .51101 .42895 .50208 .41962 Mtetra
.651 .76 .93 r
.50208 .41962 .51101 .42895 .52726 .42376 .5184 .41443 Mtetra
.652 .762 .93 r
.5184 .41443 .52726 .42376 .54362 .4188 .53482 .40916 Mtetra
.657 .758 .925 r
.53482 .40916 .54362 .4188 .56007 .41372 .55133 .40369 Mtetra
.664 .753 .916 r
.55133 .40369 .56007 .41372 .57662 .40824 .56794 .39789 Mtetra
.666 .748 .912 r
.56794 .39789 .57662 .40824 .59326 .40231 .58465 .39199 Mtetra
.651 .745 .918 r
.58465 .39199 .59326 .40231 .61 .39671 .60147 .38668 Mtetra
.651 .752 .924 r
.60147 .38668 .61 .39671 .62685 .39151 .61839 .38133 Mtetra
.66 .754 .92 r
.61839 .38133 .62685 .39151 .6438 .386 .6354 .37559 Mtetra
.673 .755 .912 r
.6354 .37559 .6438 .386 .66083 .37984 .6525 .36925 Mtetra
.662 .749 .914 r
.6525 .36925 .66083 .37984 .67796 .37376 .66971 .36332 Mtetra
.661 .753 .918 r
.66971 .36332 .67796 .37376 .69521 .36801 .68703 .35741 Mtetra
.677 .756 .911 r
.68703 .35741 .69521 .36801 .71253 .36164 .70441 .3508 Mtetra
.706 .763 .897 r
.70441 .3508 .71253 .36164 .72986 .35382 .7218 .34272 Mtetra
.669 .746 .908 r
.7218 .34272 .72986 .35382 .74733 .34689 .73939 .33634 Mtetra
.567 .715 .941 r
.73939 .33634 .74733 .34689 .76516 .34336 .75737 .33375 Mtetra
.422 .664 .962 r
.75737 .33375 .76516 .34336 .7835 .34432 .77579 .33483 Mtetra
.468 .694 .966 r
.77579 .33483 .7835 .34432 .80198 .34473 .7943 .33465 Mtetra
.637 .762 .938 r
.7943 .33465 .80198 .34473 .82022 .3406 .81253 .32938 Mtetra
.729 .775 .889 r
.81253 .32938 .82022 .3406 .83811 .3315 .83046 .3198 Mtetra
.525 .689 .942 r
.18415 .51808 .1942 .52781 .20844 .52648 .19839 .51711 Mtetra
.636 .736 .92 r
.19839 .51711 .20844 .52648 .22316 .52107 .21304 .51294 Mtetra
.757 .786 .877 r
.21304 .51294 .22316 .52107 .23838 .51078 .22826 .50335 Mtetra
.788 .802 .863 r
.22826 .50335 .23838 .51078 .25373 .49928 .24368 .49183 Mtetra
.755 .803 .891 r
.24368 .49183 .25373 .49928 .26883 .49127 .25895 .48255 Mtetra
.665 .762 .922 r
.25895 .48255 .26883 .49127 .28372 .48691 .27396 .47726 Mtetra
.596 .721 .932 r
.27396 .47726 .28372 .48691 .29859 .4842 .28888 .4743 Mtetra
.619 .724 .922 r
.28888 .4743 .29859 .4842 .31365 .48009 .30395 .47063 Mtetra
.645 .744 .921 r
.30395 .47063 .31365 .48009 .32884 .47531 .31919 .46598 Mtetra
.654 .75 .92 r
.31919 .46598 .32884 .47531 .34413 .47054 .33453 .46098 Mtetra
.64 .742 .923 r
.33453 .46098 .34413 .47054 .35948 .46619 .34994 .45648 Mtetra
.644 .741 .919 r
.34994 .45648 .35948 .46619 .37495 .46125 .36545 .45178 Mtetra
.657 .751 .92 r
.36545 .45178 .37495 .46125 .39052 .45594 .38107 .44659 Mtetra
.662 .757 .92 r
.38107 .44659 .39052 .45594 .40619 .45059 .3968 .44114 Mtetra
.658 .754 .921 r
.3968 .44114 .40619 .45059 .42192 .44583 .41261 .43585 Mtetra
.647 .74 .918 r
.41261 .43585 .42192 .44583 .43776 .44097 .4285 .43095 Mtetra
.648 .741 .917 r
.4285 .43095 .43776 .44097 .4537 .43579 .44449 .42596 Mtetra
.654 .749 .919 r
.44449 .42596 .4537 .43579 .46973 .43041 .46058 .42071 Mtetra
.655 .754 .922 r
.46058 .42071 .46973 .43041 .48586 .42494 .47677 .41538 Mtetra
.656 .758 .925 r
.47677 .41538 .48586 .42494 .50208 .41962 .49305 .40999 Mtetra
.49305 .40999 .50208 .41962 .5184 .41443 .50944 .40456 Mtetra
.658 .754 .921 r
.50944 .40456 .5184 .41443 .53482 .40916 .52592 .39903 Mtetra
.663 .752 .916 r
.52592 .39903 .53482 .40916 .55133 .40369 .5425 .39325 Mtetra
.665 .747 .911 r
.5425 .39325 .55133 .40369 .56794 .39789 .55917 .38737 Mtetra
.654 .743 .915 r
.55917 .38737 .56794 .39789 .58465 .39199 .57595 .38189 Mtetra
.649 .752 .924 r
.57595 .38189 .58465 .39199 .60147 .38668 .59284 .37656 Mtetra
.655 .755 .923 r
.59284 .37656 .60147 .38668 .61839 .38133 .60983 .37097 Mtetra
.667 .755 .916 r
.60983 .37097 .61839 .38133 .6354 .37559 .6269 .36487 Mtetra
.671 .75 .91 r
.6269 .36487 .6354 .37559 .6525 .36925 .64407 .35856 Mtetra
.658 .747 .916 r
.64407 .35856 .6525 .36925 .66971 .36332 .66136 .35276 Mtetra
.666 .754 .916 r
.66136 .35276 .66971 .36332 .68703 .35741 .67874 .34659 Mtetra
.688 .758 .905 r
.67874 .34659 .68703 .35741 .70441 .3508 .69617 .3394 Mtetra
.701 .753 .892 r
.69617 .3394 .70441 .3508 .7218 .34272 .71365 .33146 Mtetra
.648 .737 .914 r
.71365 .33146 .7218 .34272 .73939 .33634 .73138 .32593 Mtetra
.524 .7 .95 r
.73138 .32593 .73939 .33634 .75737 .33375 .74952 .32454 Mtetra
.412 .673 .968 r
.74952 .32454 .75737 .33375 .77579 .33483 .76801 .32551 Mtetra
.493 .715 .97 r
.76801 .32551 .77579 .33483 .7943 .33465 .78653 .32449 Mtetra
.671 .777 .929 r
.78653 .32449 .7943 .33465 .81253 .32938 .80472 .31779 Mtetra
.735 .772 .882 r
.80472 .31779 .81253 .32938 .83046 .3198 .8227 .30772 Mtetra
.514 .679 .94 r
.17403 .50803 .18415 .51808 .19839 .51711 .18826 .50732 Mtetra
.599 .717 .927 r
.18826 .50732 .19839 .51711 .21304 .51294 .20284 .50434 Mtetra
.733 .776 .887 r
.20284 .50434 .21304 .51294 .22826 .50335 .218 .49603 Mtetra
.785 .806 .87 r
.218 .49603 .22826 .50335 .24368 .49183 .23347 .48482 Mtetra
.778 .815 .882 r
.23347 .48482 .24368 .49183 .25895 .48255 .24892 .47418 Mtetra
.692 .778 .917 r
.24892 .47418 .25895 .48255 .27396 .47726 .26407 .4678 Mtetra
.617 .734 .93 r
.26407 .4678 .27396 .47726 .28888 .4743 .27908 .4641 Mtetra
.603 .714 .923 r
.27908 .4641 .28888 .4743 .30395 .47063 .29417 .46092 Mtetra
.638 .738 .921 r
.29417 .46092 .30395 .47063 .31919 .46598 .30943 .45647 Mtetra
.652 .748 .92 r
.30943 .45647 .31919 .46598 .33453 .46098 .32483 .45148 Mtetra
.649 .748 .922 r
.32483 .45148 .33453 .46098 .34994 .45648 .34031 .44658 Mtetra
.639 .738 .92 r
.34031 .44658 .34994 .45648 .36545 .45178 .35586 .44201 Mtetra
.65 .745 .919 r
.35586 .44201 .36545 .45178 .38107 .44659 .37153 .43701 Mtetra
.658 .753 .92 r
.37153 .43701 .38107 .44659 .3968 .44114 .38731 .43169 Mtetra
.662 .758 .922 r
.38731 .43169 .3968 .44114 .41261 .43585 .40318 .42618 Mtetra
.659 .754 .92 r
.40318 .42618 .41261 .43585 .4285 .43095 .41914 .42074 Mtetra
.651 .741 .915 r
.41914 .42074 .4285 .43095 .44449 .42596 .43519 .41561 Mtetra
.651 .739 .914 r
.43519 .41561 .44449 .42596 .46058 .42071 .45134 .41043 Mtetra
.653 .742 .915 r
.45134 .41043 .46058 .42071 .47677 .41538 .46759 .40512 Mtetra
.656 .745 .915 r
.46759 .40512 .47677 .41538 .49305 .40999 .48393 .39968 Mtetra
.659 .746 .915 r
.48393 .39968 .49305 .40999 .50944 .40456 .50038 .3941 Mtetra
.661 .745 .912 r
.50038 .3941 .50944 .40456 .52592 .39903 .51692 .38838 Mtetra
.661 .742 .91 r
.51692 .38838 .52592 .39903 .5425 .39325 .53357 .38263 Mtetra
.653 .741 .914 r
.53357 .38263 .5425 .39325 .55917 .38737 .55031 .37717 Mtetra
.65 .751 .923 r
.55031 .37717 .55917 .38737 .57595 .38189 .56716 .37178 Mtetra
.654 .756 .924 r
.56716 .37178 .57595 .38189 .59284 .37656 .58411 .36621 Mtetra
.661 .754 .919 r
.58411 .36621 .59284 .37656 .60983 .37097 .60116 .3603 Mtetra
.671 .752 .911 r
.60116 .3603 .60983 .37097 .6269 .36487 .6183 .35394 Mtetra
.662 .745 .912 r
.6183 .35394 .6269 .36487 .64407 .35856 .63555 .34792 Mtetra
.66 .752 .918 r
.63555 .34792 .64407 .35856 .66136 .35276 .65292 .34199 Mtetra
.672 .755 .913 r
.65292 .34199 .66136 .35276 .67874 .34659 .67036 .33549 Mtetra
.699 .759 .898 r
.67036 .33549 .67874 .34659 .69617 .3394 .68784 .32767 Mtetra
.686 .743 .895 r
.68784 .32767 .69617 .3394 .71365 .33146 .70543 .32037 Mtetra
.621 .731 .926 r
.70543 .32037 .71365 .33146 .73138 .32593 .7233 .31585 Mtetra
.469 .683 .959 r
.7233 .31585 .73138 .32593 .74952 .32454 .74161 .31576 Mtetra
.416 .689 .975 r
.74161 .31576 .74952 .32454 .76801 .32551 .76014 .31628 Mtetra
.541 .744 .97 r
.76014 .31628 .76801 .32551 .78653 .32449 .77863 .31381 Mtetra
.7 .779 .913 r
.77863 .31381 .78653 .32449 .80472 .31779 .7968 .30574 Mtetra
.739 .767 .875 r
.7968 .30574 .80472 .31779 .8227 .30772 .81484 .29525 Mtetra
.511 .674 .938 r
.16383 .49771 .17403 .50803 .18826 .50732 .17808 .49707 Mtetra
.567 .698 .929 r
.17808 .49707 .18826 .50732 .20284 .50434 .19259 .49499 Mtetra
.69 .755 .901 r
.19259 .49499 .20284 .50434 .218 .49603 .20762 .48862 Mtetra
.773 .807 .88 r
.20762 .48862 .218 .49603 .23347 .48482 .22309 .47817 Mtetra
.79 .824 .879 r
.22309 .47817 .23347 .48482 .24892 .47418 .23868 .46683 Mtetra
.732 .809 .912 r
.23868 .46683 .24892 .47418 .26407 .4678 .25403 .45868 Mtetra
.65 .754 .926 r
.25403 .45868 .26407 .4678 .27908 .4641 .26919 .45379 Mtetra
.599 .713 .924 r
.26919 .45379 .27908 .4641 .29417 .46092 .28431 .45066 Mtetra
.624 .724 .918 r
.28431 .45066 .29417 .46092 .30943 .45647 .29959 .44668 Mtetra
.646 .742 .919 r
.29959 .44668 .30943 .45647 .32483 .45148 .31502 .44187 Mtetra
.654 .75 .92 r
.31502 .44187 .32483 .45148 .34031 .44658 .33056 .43673 Mtetra
.646 .743 .92 r
.33056 .43673 .34031 .44658 .35586 .44201 .34618 .43187 Mtetra
.642 .736 .918 r
.34618 .43187 .35586 .44201 .37153 .43701 .36189 .42714 Mtetra
.652 .747 .919 r
.36189 .42714 .37153 .43701 .38731 .43169 .37771 .42198 Mtetra
.657 .753 .921 r
.37771 .42198 .38731 .43169 .40318 .42618 .39364 .41659 Mtetra
.66 .758 .923 r
.39364 .41659 .40318 .42618 .41914 .42074 .40967 .41106 Mtetra
.659 .757 .922 r
.40967 .41106 .41914 .42074 .43519 .41561 .42578 .40552 Mtetra
.657 .749 .917 r
.42578 .40552 .43519 .41561 .45134 .41043 .442 .40001 Mtetra
.656 .743 .914 r
.442 .40001 .45134 .41043 .46759 .40512 .45831 .39453 Mtetra
.656 .74 .912 r
.45831 .39453 .46759 .40512 .48393 .39968 .47472 .38902 Mtetra
.47472 .38902 .48393 .39968 .50038 .3941 .49122 .3835 Mtetra
.654 .742 .914 r
.49122 .3835 .50038 .3941 .51692 .38838 .50783 .37799 Mtetra
.653 .747 .919 r
.50783 .37799 .51692 .38838 .53357 .38263 .52454 .37251 Mtetra
.652 .754 .925 r
.52454 .37251 .53357 .38263 .55031 .37717 .54135 .36703 Mtetra
.655 .756 .925 r
.54135 .36703 .55031 .37717 .56716 .37178 .55827 .3614 Mtetra
.66 .754 .92 r
.55827 .3614 .56716 .37178 .58411 .36621 .57528 .35554 Mtetra
.669 .753 .913 r
.57528 .35554 .58411 .36621 .60116 .3603 .5924 .34923 Mtetra
.665 .744 .909 r
.5924 .34923 .60116 .3603 .6183 .35394 .60961 .34305 Mtetra
.658 .747 .916 r
.60961 .34305 .6183 .35394 .63555 .34792 .62694 .33716 Mtetra
.665 .754 .916 r
.62694 .33716 .63555 .34792 .65292 .34199 .64437 .33091 Mtetra
.683 .755 .906 r
.64437 .33091 .65292 .34199 .67036 .33549 .66186 .32381 Mtetra
.7 .75 .891 r
.66186 .32381 .67036 .33549 .68784 .32767 .67941 .31581 Mtetra
.661 .733 .903 r
.67941 .31581 .68784 .32767 .70543 .32037 .69714 .30962 Mtetra
.568 .718 .943 r
.69714 .30962 .70543 .32037 .7233 .31585 .71519 .3068 Mtetra
.419 .686 .973 r
.71519 .3068 .7233 .31585 .74161 .31576 .73362 .30731 Mtetra
.443 .716 .982 r
.73362 .30731 .74161 .31576 .76014 .31628 .75218 .30693 Mtetra
.609 .775 .96 r
.75218 .30693 .76014 .31628 .77863 .31381 .77059 .3023 Mtetra
.718 .771 .895 r
.77059 .3023 .77863 .31381 .7968 .30574 .78875 .29316 Mtetra
.739 .76 .869 r
.78875 .29316 .7968 .30574 .81484 .29525 .80687 .28248 Mtetra
.524 .681 .937 r
.15352 .48735 .16383 .49771 .17808 .49707 .16783 .48634 Mtetra
.541 .68 .929 r
.16783 .48634 .17808 .49707 .19259 .49499 .18229 .48498 Mtetra
.632 .728 .917 r
.18229 .48498 .19259 .49499 .20762 .48862 .19715 .4808 Mtetra
.751 .799 .892 r
.19715 .4808 .20762 .48862 .22309 .47817 .21258 .47155 Mtetra
.788 .827 .883 r
.21258 .47155 .22309 .47817 .23868 .46683 .22824 .46032 Mtetra
.772 .832 .899 r
.22824 .46032 .23868 .46683 .25403 .45868 .24383 .45018 Mtetra
.687 .779 .921 r
.24383 .45018 .25403 .45868 .26919 .45379 .25916 .44384 Mtetra
.623 .731 .924 r
.25916 .44384 .26919 .45379 .28431 .45066 .27438 .43984 Mtetra
.604 .707 .917 r
.27438 .43984 .28431 .45066 .29959 .44668 .28965 .43652 Mtetra
.637 .733 .918 r
.28965 .43652 .29959 .44668 .31502 .44187 .30511 .43199 Mtetra
.65 .745 .919 r
.30511 .43199 .31502 .44187 .33056 .43673 .3207 .42696 Mtetra
.654 .75 .92 r
.3207 .42696 .33056 .43673 .34618 .43187 .33639 .42171 Mtetra
.646 .74 .918 r
.33639 .42171 .34618 .43187 .36189 .42714 .35216 .41675 Mtetra
.644 .736 .916 r
.35216 .41675 .36189 .42714 .37771 .42198 .36803 .41186 Mtetra
.651 .745 .918 r
.36803 .41186 .37771 .42198 .39364 .41659 .384 .40667 Mtetra
.655 .752 .921 r
.384 .40667 .39364 .41659 .40967 .41106 .40008 .40125 Mtetra
.657 .756 .923 r
.40008 .40125 .40967 .41106 .42578 .40552 .41626 .39574 Mtetra
.658 .758 .924 r
.41626 .39574 .42578 .40552 .442 .40001 .43254 .39017 Mtetra
.657 .758 .924 r
.43254 .39017 .442 .40001 .45831 .39453 .44891 .38459 Mtetra
.656 .757 .924 r
.44891 .38459 .45831 .39453 .47472 .38902 .46538 .37903 Mtetra
.655 .756 .925 r
.46538 .37903 .47472 .38902 .49122 .3835 .48195 .37347 Mtetra
.654 .757 .925 r
.48195 .37347 .49122 .3835 .50783 .37799 .49863 .3679 Mtetra
.655 .757 .925 r
.49863 .3679 .50783 .37799 .52454 .37251 .5154 .36228 Mtetra
.656 .756 .923 r
.5154 .36228 .52454 .37251 .54135 .36703 .53228 .35656 Mtetra
.661 .754 .919 r
.53228 .35656 .54135 .36703 .55827 .3614 .54927 .35061 Mtetra
.668 .75 .912 r
.54927 .35061 .55827 .3614 .57528 .35554 .56635 .34434 Mtetra
.665 .743 .908 r
.56635 .34434 .57528 .35554 .5924 .34923 .58353 .33814 Mtetra
.657 .744 .913 r
.58353 .33814 .5924 .34923 .60961 .34305 .60083 .33223 Mtetra
.662 .752 .917 r
.60083 .33223 .60961 .34305 .62694 .33716 .61822 .3261 Mtetra
.673 .753 .911 r
.61822 .3261 .62694 .33716 .64437 .33091 .63571 .31944 Mtetra
.698 .755 .896 r
.63571 .31944 .64437 .33091 .66186 .32381 .65325 .31153 Mtetra
.682 .734 .891 r
.65325 .31153 .66186 .32381 .67941 .31581 .67091 .3043 Mtetra
.627 .729 .921 r
.67091 .3043 .67941 .31581 .69714 .30962 .68879 .29948 Mtetra
.493 .699 .961 r
.68879 .29948 .69714 .30962 .71519 .3068 .70704 .29861 Mtetra
.403 .703 .983 r
.70704 .29861 .71519 .3068 .73362 .30731 .72554 .29888 Mtetra
.496 .747 .984 r
.72554 .29888 .73362 .30731 .75218 .30693 .74409 .29713 Mtetra
.675 .793 .938 r
.74409 .29713 .75218 .30693 .77059 .3023 .7624 .29008 Mtetra
.73 .764 .88 r
.7624 .29008 .77059 .3023 .78875 .29316 .78059 .28005 Mtetra
.732 .75 .867 r
.78059 .28005 .78875 .29316 .80687 .28248 .79881 .26962 Mtetra
.56 .703 .937 r
.14306 .47729 .15352 .48735 .16783 .48634 .15751 .47525 Mtetra
.526 .669 .927 r
.15751 .47525 .16783 .48634 .18229 .48498 .17196 .47427 Mtetra
.586 .7 .922 r
.17196 .47427 .18229 .48498 .19715 .4808 .1867 .47158 Mtetra
.7 .765 .902 r
.1867 .47158 .19715 .4808 .21258 .47155 .20196 .46466 Mtetra
.773 .824 .892 r
.20196 .46466 .21258 .47155 .22824 .46032 .21761 .45429 Mtetra
.789 .844 .893 r
.21761 .45429 .22824 .46032 .24383 .45018 .23337 .44317 Mtetra
.738 .823 .917 r
.23337 .44317 .24383 .45018 .25916 .44384 .24895 .43466 Mtetra
.664 .762 .923 r
.24895 .43466 .25916 .44384 .27438 .43984 .26434 .42912 Mtetra
.613 .714 .918 r
.26434 .42912 .27438 .43984 .28965 .43652 .27968 .42544 Mtetra
.614 .709 .912 r
.27968 .42544 .28965 .43652 .30511 .43199 .29512 .42169 Mtetra
.641 .735 .917 r
.29512 .42169 .30511 .43199 .3207 .42696 .31074 .41694 Mtetra
.651 .745 .919 r
.31074 .41694 .3207 .42696 .33639 .42171 .32648 .41177 Mtetra
.655 .75 .92 r
.32648 .41177 .33639 .42171 .35216 .41675 .34233 .40642 Mtetra
.65 .741 .916 r
.34233 .40642 .35216 .41675 .36803 .41186 .35826 .40123 Mtetra
.646 .735 .914 r
.35826 .40123 .36803 .41186 .384 .40667 .37428 .39616 Mtetra
.648 .739 .916 r
.37428 .39616 .384 .40667 .40008 .40125 .3904 .39098 Mtetra
.653 .747 .919 r
.3904 .39098 .40008 .40125 .41626 .39574 .40664 .38557 Mtetra
.655 .751 .921 r
.40664 .38557 .41626 .39574 .43254 .39017 .42297 .38004 Mtetra
.656 .754 .922 r
.42297 .38004 .43254 .39017 .44891 .38459 .43941 .37445 Mtetra
.656 .755 .923 r
.43941 .37445 .44891 .38459 .46538 .37903 .45594 .36882 Mtetra
.45594 .36882 .46538 .37903 .48195 .37347 .47258 .36315 Mtetra
.657 .754 .922 r
.47258 .36315 .48195 .37347 .49863 .3679 .48932 .35742 Mtetra
.659 .752 .919 r
.48932 .35742 .49863 .3679 .5154 .36228 .50617 .35156 Mtetra
.664 .751 .915 r
.50617 .35156 .5154 .36228 .53228 .35656 .52312 .34548 Mtetra
.665 .745 .91 r
.52312 .34548 .53228 .35656 .54927 .35061 .54016 .33927 Mtetra
.662 .74 .908 r
.54016 .33927 .54927 .35061 .56635 .34434 .55732 .33318 Mtetra
.657 .743 .913 r
.55732 .33318 .56635 .34434 .58353 .33814 .57458 .32725 Mtetra
.661 .752 .917 r
.57458 .32725 .58353 .33814 .60083 .33223 .59194 .32114 Mtetra
.67 .752 .912 r
.59194 .32114 .60083 .33223 .61822 .3261 .6094 .31459 Mtetra
.691 .753 .899 r
.6094 .31459 .61822 .3261 .63571 .31944 .62693 .307 Mtetra
.689 .736 .886 r
.62693 .307 .63571 .31944 .65325 .31153 .64455 .29932 Mtetra
.649 .725 .905 r
.64455 .29932 .65325 .31153 .67091 .3043 .66235 .29356 Mtetra
.56 .719 .947 r
.66235 .29356 .67091 .3043 .68879 .29948 .68042 .29085 Mtetra
.422 .704 .981 r
.68042 .29085 .68879 .29948 .70704 .29861 .6988 .29088 Mtetra
.433 .734 .99 r
.6988 .29088 .70704 .29861 .72554 .29888 .71733 .29013 Mtetra
.59 .786 .973 r
.71733 .29013 .72554 .29888 .74409 .29713 .73579 .28582 Mtetra
.709 .776 .904 r
.73579 .28582 .74409 .29713 .7624 .29008 .75408 .27708 Mtetra
.734 .754 .868 r
.75408 .27708 .7624 .29008 .78059 .28005 .77231 .26653 Mtetra
.713 .739 .871 r
.77231 .26653 .78059 .28005 .79881 .26962 .79071 .25705 Mtetra
.603 .723 .929 r
.13247 .46735 .14306 .47729 .15751 .47525 .14709 .46403 Mtetra
.531 .67 .926 r
.14709 .46403 .15751 .47525 .17196 .47427 .16158 .46288 Mtetra
.552 .676 .92 r
.16158 .46288 .17196 .47427 .1867 .47158 .17624 .46117 Mtetra
.628 .724 .916 r
.17624 .46117 .1867 .47158 .20196 .46466 .19127 .457 Mtetra
.743 .808 .904 r
.19127 .457 .20196 .46466 .21761 .45429 .20685 .44813 Mtetra
.782 .843 .898 r
.20685 .44813 .21761 .45429 .23337 .44317 .22267 .43733 Mtetra
.779 .852 .906 r
.22267 .43733 .23337 .44317 .24895 .43466 .2385 .42676 Mtetra
.709 .802 .923 r
.2385 .42676 .24895 .43466 .26434 .42912 .2541 .41938 Mtetra
.652 .75 .922 r
.2541 .41938 .26434 .42912 .27968 .42544 .2696 .41422 Mtetra
.614 .708 .912 r
.2696 .41422 .27968 .42544 .29512 .42169 .28509 .41044 Mtetra
.62 .711 .911 r
.28509 .41044 .29512 .42169 .31074 .41694 .3007 .40642 Mtetra
.642 .734 .916 r
.3007 .40642 .31074 .41694 .32648 .41177 .31647 .40153 Mtetra
.65 .744 .918 r
.31647 .40153 .32648 .41177 .34233 .40642 .33236 .3963 Mtetra
.655 .749 .919 r
.33236 .3963 .34233 .40642 .35826 .40123 .34836 .39085 Mtetra
.655 .745 .916 r
.34836 .39085 .35826 .40123 .37428 .39616 .36446 .38538 Mtetra
.65 .737 .912 r
.36446 .38538 .37428 .39616 .3904 .39098 .38064 .38004 Mtetra
.65 .734 .911 r
.38064 .38004 .3904 .39098 .40664 .38557 .39693 .37468 Mtetra
.652 .737 .912 r
.39693 .37468 .40664 .38557 .42297 .38004 .41332 .36922 Mtetra
.654 .741 .914 r
.41332 .36922 .42297 .38004 .43941 .37445 .42981 .36364 Mtetra
.656 .743 .914 r
.42981 .36364 .43941 .37445 .45594 .36882 .44641 .35795 Mtetra
.658 .744 .913 r
.44641 .35795 .45594 .36882 .47258 .36315 .46312 .35214 Mtetra
.66 .743 .911 r
.46312 .35214 .47258 .36315 .48932 .35742 .47992 .34621 Mtetra
.661 .741 .909 r
.47992 .34621 .48932 .35742 .50617 .35156 .49683 .34017 Mtetra
.661 .738 .907 r
.49683 .34017 .50617 .35156 .52312 .34548 .51384 .33411 Mtetra
.657 .739 .91 r
.51384 .33411 .52312 .34548 .54016 .33927 .53096 .32819 Mtetra
.657 .746 .915 r
.53096 .32819 .54016 .33927 .55732 .33318 .54818 .32223 Mtetra
.661 .752 .917 r
.54818 .32223 .55732 .33318 .57458 .32725 .56551 .31605 Mtetra
.669 .751 .912 r
.56551 .31605 .57458 .32725 .59194 .32114 .58294 .30952 Mtetra
.687 .75 .899 r
.58294 .30952 .59194 .32114 .6094 .31459 .60045 .30208 Mtetra
.689 .735 .886 r
.60045 .30208 .6094 .31459 .62693 .307 .61805 .29439 Mtetra
.659 .723 .896 r
.61805 .29439 .62693 .307 .64455 .29932 .6358 .28811 Mtetra
.6 .729 .935 r
.6358 .28811 .64455 .29932 .66235 .29356 .65375 .28411 Mtetra
.467 .708 .973 r
.65375 .28411 .66235 .29356 .68042 .29085 .672 .28342 Mtetra
.407 .73 .99 r
.672 .28342 .68042 .29085 .6988 .29088 .69045 .28298 Mtetra
.506 .77 .991 r
.69045 .28298 .6988 .29088 .71733 .29013 .70897 .28056 Mtetra
.678 .804 .942 r
.70897 .28056 .71733 .29013 .73579 .28582 .72733 .27325 Mtetra
.725 .759 .88 r
.72733 .27325 .73579 .28582 .75408 .27708 .74562 .26334 Mtetra
.729 .742 .862 r
.74562 .26334 .75408 .27708 .77231 .26653 .76394 .25283 Mtetra
.69 .729 .879 r
.76394 .25283 .77231 .26653 .79071 .25705 .78253 .24456 Mtetra
.627 .736 .926 r
.12173 .45757 .13247 .46735 .14709 .46403 .13649 .45344 Mtetra
.57 .701 .93 r
.13649 .45344 .14709 .46403 .16158 .46288 .15114 .45107 Mtetra
.537 .664 .918 r
.15114 .45107 .16158 .46288 .17624 .46117 .16578 .44977 Mtetra
.581 .69 .916 r
.16578 .44977 .17624 .46117 .19127 .457 .18068 .44715 Mtetra
.671 .751 .911 r
.18068 .44715 .19127 .457 .20685 .44813 .19602 .44127 Mtetra
.756 .83 .909 r
.19602 .44127 .20685 .44813 .22267 .43733 .21179 .43175 Mtetra
.783 .86 .907 r
.21179 .43175 .22267 .43733 .2385 .42676 .22772 .42097 Mtetra
.768 .857 .917 r
.22772 .42097 .2385 .42676 .2541 .41938 .24363 .41095 Mtetra
.695 .792 .925 r
.24363 .41095 .2541 .41938 .2696 .41422 .25933 .40405 Mtetra
.65 .744 .918 r
.25933 .40405 .2696 .41422 .28509 .41044 .27497 .39886 Mtetra
.619 .706 .908 r
.27497 .39886 .28509 .41044 .3007 .40642 .29062 .39481 Mtetra
.62 .707 .908 r
.29062 .39481 .3007 .40642 .31647 .40153 .30638 .3907 Mtetra
.641 .731 .914 r
.30638 .3907 .31647 .40153 .33236 .3963 .32231 .38574 Mtetra
.648 .741 .917 r
.32231 .38574 .33236 .3963 .34836 .39085 .33835 .38048 Mtetra
.653 .747 .919 r
.33835 .38048 .34836 .39085 .36446 .38538 .3545 .375 Mtetra
.655 .749 .919 r
.3545 .375 .36446 .38538 .38064 .38004 .37075 .36942 Mtetra
.655 .745 .916 r
.37075 .36942 .38064 .38004 .39693 .37468 .38711 .36378 Mtetra
.655 .741 .913 r
.38711 .36378 .39693 .37468 .41332 .36922 .40357 .35811 Mtetra
.655 .738 .91 r
.40357 .35811 .41332 .36922 .42981 .36364 .42012 .3524 Mtetra
.656 .737 .909 r
.42012 .3524 .42981 .36364 .44641 .35795 .43678 .34664 Mtetra
.43678 .34664 .44641 .35795 .46312 .35214 .45355 .34083 Mtetra
.656 .738 .91 r
.45355 .34083 .46312 .35214 .47992 .34621 .47042 .33498 Mtetra
.656 .741 .912 r
.47042 .33498 .47992 .34621 .49683 .34017 .48739 .32909 Mtetra
.657 .746 .916 r
.48739 .32909 .49683 .34017 .51384 .33411 .50447 .32315 Mtetra
.659 .75 .918 r
.50447 .32315 .51384 .33411 .53096 .32819 .52165 .3171 Mtetra
.663 .751 .915 r
.52165 .3171 .53096 .32819 .54818 .32223 .53894 .31082 Mtetra
.669 .748 .909 r
.53894 .31082 .54818 .32223 .56551 .31605 .55634 .30423 Mtetra
.687 .747 .897 r
.55634 .30423 .56551 .31605 .58294 .30952 .57382 .29677 Mtetra
.685 .73 .885 r
.57382 .29677 .58294 .30952 .60045 .30208 .5914 .28923 Mtetra
.66 .72 .893 r
.5914 .28923 .60045 .30208 .61805 .29439 .60911 .28285 Mtetra
.617 .73 .927 r
.60911 .28285 .61805 .29439 .6358 .28811 .62699 .27823 Mtetra
.5 .716 .968 r
.62699 .27823 .6358 .28811 .65375 .28411 .64513 .27681 Mtetra
.407 .735 .992 r
.64513 .27681 .65375 .28411 .672 .28342 .66347 .27622 Mtetra
.464 .769 .996 r
.66347 .27622 .672 .28342 .69045 .28298 .68194 .27433 Mtetra
.628 .808 .969 r
.68194 .27433 .69045 .28298 .70897 .28056 .70037 .26867 Mtetra
.712 .769 .897 r
.70037 .26867 .70897 .28056 .72733 .27325 .71871 .25961 Mtetra
.729 .744 .864 r
.71871 .25961 .72733 .27325 .74562 .26334 .73705 .24914 Mtetra
.707 .728 .867 r
.73705 .24914 .74562 .26334 .76394 .25283 .75554 .23977 Mtetra
.677 .737 .896 r
.75554 .23977 .76394 .25283 .78253 .24456 .77428 .23221 Mtetra
.647 .748 .923 r
.11084 .44802 .12173 .45757 .13649 .45344 .12573 .44314 Mtetra
.613 .724 .924 r
.12573 .44314 .13649 .45344 .15114 .45107 .14057 .4394 Mtetra
.553 .675 .919 r
.14057 .4394 .15114 .45107 .16578 .44977 .15529 .43758 Mtetra
.552 .665 .912 r
.15529 .43758 .16578 .44977 .18068 .44715 .17012 .43585 Mtetra
.603 .703 .914 r
.17012 .43585 .18068 .44715 .19602 .44127 .18524 .43242 Mtetra
.696 .781 .917 r
.18524 .43242 .19602 .44127 .21179 .43175 .20082 .42545 Mtetra
.759 .846 .916 r
.20082 .42545 .21179 .43175 .22772 .42097 .21674 .41577 Mtetra
.778 .872 .917 r
.21674 .41577 .22772 .42097 .24363 .41095 .23278 .40521 Mtetra
.76 .862 .925 r
.23278 .40521 .24363 .41095 .25933 .40405 .24879 .39552 Mtetra
.694 .793 .926 r
.24879 .39552 .25933 .40405 .27497 .39886 .26463 .38858 Mtetra
.657 .747 .917 r
.26463 .38858 .27497 .39886 .29062 .39481 .28045 .38303 Mtetra
.628 .709 .904 r
.28045 .38303 .29062 .39481 .30638 .3907 .29627 .37856 Mtetra
.623 .701 .901 r
.29627 .37856 .30638 .3907 .32231 .38574 .3122 .37427 Mtetra
.635 .72 .909 r
.3122 .37427 .32231 .38574 .33835 .38048 .32826 .36947 Mtetra
.646 .734 .913 r
.32826 .36947 .33835 .38048 .3545 .375 .34445 .3642 Mtetra
.65 .741 .916 r
.34445 .3642 .3545 .375 .37075 .36942 .36075 .35873 Mtetra
.653 .746 .918 r
.36075 .35873 .37075 .36942 .38711 .36378 .37717 .35312 Mtetra
.655 .748 .919 r
.37717 .35312 .38711 .36378 .40357 .35811 .39368 .34741 Mtetra
.656 .749 .919 r
.39368 .34741 .40357 .35811 .42012 .3524 .4103 .34164 Mtetra
.4103 .34164 .42012 .3524 .43678 .34664 .42703 .33581 Mtetra
.656 .749 .918 r
.42703 .33581 .43678 .34664 .45355 .34083 .44386 .32993 Mtetra
.657 .75 .918 r
.44386 .32993 .45355 .34083 .47042 .33498 .46079 .32399 Mtetra
.659 .75 .917 r
.46079 .32399 .47042 .33498 .48739 .32909 .47784 .31794 Mtetra
.661 .748 .915 r
.47784 .31794 .48739 .32909 .50447 .32315 .49498 .31175 Mtetra
.665 .746 .911 r
.49498 .31175 .50447 .32315 .52165 .3171 .51224 .30535 Mtetra
.675 .744 .903 r
.51224 .30535 .52165 .3171 .53894 .31082 .5296 .29846 Mtetra
.683 .737 .891 r
.5296 .29846 .53894 .31082 .55634 .30423 .54706 .29106 Mtetra
.677 .721 .883 r
.54706 .29106 .55634 .30423 .57382 .29677 .56461 .28383 Mtetra
.654 .718 .895 r
.56461 .28383 .57382 .29677 .5914 .28923 .58229 .27769 Mtetra
.619 .732 .928 r
.58229 .27769 .5914 .28923 .60911 .28285 .60011 .27297 Mtetra
.515 .725 .968 r
.60011 .27297 .60911 .28285 .62699 .27823 .61816 .27108 Mtetra
.418 .747 .994 r
.61816 .27108 .62699 .27823 .64513 .27681 .6364 .27011 Mtetra
.447 .774 .998 r
.6364 .27011 .64513 .27681 .66347 .27622 .65479 .26825 Mtetra
.588 .81 .984 r
.65479 .26825 .66347 .27622 .68194 .27433 .67322 .26359 Mtetra
.7 .789 .92 r
.67322 .26359 .68194 .27433 .70037 .26867 .69159 .25525 Mtetra
.724 .747 .871 r
.69159 .25525 .70037 .26867 .71871 .25961 .70996 .24512 Mtetra
.717 .728 .859 r
.70996 .24512 .71871 .25961 .73705 .24914 .72841 .23505 Mtetra
.684 .723 .879 r
.72841 .23505 .73705 .24914 .75554 .23977 .74708 .22697 Mtetra
.663 .739 .907 r
.74708 .22697 .75554 .23977 .77428 .23221 .76595 .22006 Mtetra
.66 .755 .921 r
.09981 .43855 .11084 .44802 .12573 .44314 .1148 .43316 Mtetra
.637 .74 .923 r
.1148 .43316 .12573 .44314 .14057 .4394 .12979 .42854 Mtetra
.6 .711 .922 r
.12979 .42854 .14057 .4394 .15529 .43758 .14472 .42515 Mtetra
.55 .662 .91 r
.14472 .42515 .15529 .43758 .17012 .43585 .15956 .42342 Mtetra
.566 .67 .908 r
.15956 .42342 .17012 .43585 .18524 .43242 .17458 .4212 Mtetra
.617 .713 .914 r
.17458 .4212 .18524 .43242 .20082 .42545 .1899 .41721 Mtetra
.705 .8 .924 r
.1899 .41721 .20082 .42545 .21674 .41577 .20566 .40982 Mtetra
.755 .858 .926 r
.20566 .40982 .21674 .41577 .23278 .40521 .2217 .4003 Mtetra
.77 .882 .927 r
.2217 .4003 .23278 .40521 .24879 .39552 .23785 .39006 Mtetra
.755 .872 .932 r
.23785 .39006 .24879 .39552 .26463 .38858 .25399 .38046 Mtetra
.703 .807 .93 r
.25399 .38046 .26463 .38858 .28045 .38303 .27001 .37306 Mtetra
.667 .76 .92 r
.27001 .37306 .28045 .38303 .29627 .37856 .28601 .36701 Mtetra
.644 .723 .905 r
.28601 .36701 .29627 .37856 .3122 .37427 .30204 .36182 Mtetra
.632 .702 .897 r
.30204 .36182 .3122 .37427 .32826 .36947 .31814 .35707 Mtetra
.632 .704 .898 r
.31814 .35707 .32826 .36947 .34445 .3642 .33435 .35228 Mtetra
.637 .717 .905 r
.33435 .35228 .34445 .3642 .36075 .35873 .35068 .34725 Mtetra
.648 .731 .909 r
.35068 .34725 .36075 .35873 .37717 .35312 .36714 .34176 Mtetra
.652 .735 .911 r
.36714 .34176 .37717 .35312 .39368 .34741 .38371 .33611 Mtetra
.654 .738 .912 r
.38371 .33611 .39368 .34741 .4103 .34164 .40039 .33032 Mtetra
.656 .74 .912 r
.40039 .33032 .4103 .34164 .42703 .33581 .41718 .32443 Mtetra
.658 .741 .911 r
.41718 .32443 .42703 .33581 .44386 .32993 .43407 .31842 Mtetra
.66 .74 .91 r
.43407 .31842 .44386 .32993 .46079 .32399 .45107 .31229 Mtetra
.663 .739 .907 r
.45107 .31229 .46079 .32399 .47784 .31794 .46818 .30598 Mtetra
.672 .739 .901 r
.46818 .30598 .47784 .31794 .49498 .31175 .48541 .29921 Mtetra
.675 .73 .891 r
.48541 .29921 .49498 .31175 .51224 .30535 .50273 .29218 Mtetra
.674 .72 .884 r
.50273 .29218 .51224 .30535 .5296 .29846 .52015 .28511 Mtetra
.664 .714 .886 r
.52015 .28511 .5296 .29846 .54706 .29106 .53768 .27848 Mtetra
.645 .722 .904 r
.53768 .27848 .54706 .29106 .56461 .28383 .55532 .27272 Mtetra
.607 .738 .938 r
.55532 .27272 .56461 .28383 .58229 .27769 .5731 .26834 Mtetra
.514 .74 .976 r
.5731 .26834 .58229 .27769 .60011 .27297 .59107 .26622 Mtetra
.427 .763 .996 r
.59107 .26622 .60011 .27297 .61816 .27108 .60922 .26477 Mtetra
.448 .786 .998 r
.60922 .26477 .61816 .27108 .6364 .27011 .62752 .26261 Mtetra
.569 .814 .991 r
.62752 .26261 .6364 .27011 .65479 .26825 .64591 .25824 Mtetra
.689 .802 .935 r
.64591 .25824 .65479 .26825 .67322 .26359 .66428 .25035 Mtetra
.718 .75 .877 r
.66428 .25035 .67322 .26359 .69159 .25525 .68267 .24062 Mtetra
.719 .728 .857 r
.68267 .24062 .69159 .25525 .70996 .24512 .7011 .23034 Mtetra
.69 .715 .868 r
.7011 .23034 .70996 .24512 .72841 .23505 .71973 .22177 Mtetra
.67 .734 .898 r
.71973 .22177 .72841 .23505 .74708 .22697 .73855 .21446 Mtetra
.652 .743 .916 r
.73855 .21446 .74708 .22697 .76595 .22006 .75754 .20795 Mtetra
.659 .753 .919 r
.08868 .42886 .09981 .43855 .1148 .43316 .10371 .42344 Mtetra
.656 .753 .921 r
.10371 .42344 .1148 .43316 .12979 .42854 .11882 .41811 Mtetra
.63 .732 .921 r
.11882 .41811 .12979 .42854 .14472 .42515 .13392 .41365 Mtetra
.592 .699 .917 r
.13392 .41365 .14472 .42515 .15956 .42342 .14895 .41049 Mtetra
.557 .659 .904 r
.14895 .41049 .15956 .42342 .17458 .4212 .16396 .40853 Mtetra
.576 .672 .905 r
.16396 .40853 .17458 .4212 .1899 .41721 .17917 .40592 Mtetra
.621 .717 .914 r
.17917 .40592 .1899 .41721 .20566 .40982 .19465 .40168 Mtetra
.699 .805 .931 r
.19465 .40168 .20566 .40982 .2217 .4003 .21053 .39446 Mtetra
.744 .863 .935 r
.21053 .39446 .2217 .4003 .23785 .39006 .22667 .38533 Mtetra
.758 .89 .938 r
.22667 .38533 .23785 .39006 .25399 .38046 .24292 .37553 Mtetra
.75 .887 .941 r
.24292 .37553 .25399 .38046 .27001 .37306 .2592 .36602 Mtetra
.722 .839 .937 r
.2592 .36602 .27001 .37306 .28601 .36701 .27545 .35776 Mtetra
.681 .783 .927 r
.27545 .35776 .28601 .36701 .30204 .36182 .29164 .35108 Mtetra
.662 .748 .914 r
.29164 .35108 .30204 .36182 .31814 .35707 .30788 .34509 Mtetra
.65 .721 .901 r
.30788 .34509 .31814 .35707 .33435 .35228 .32418 .33953 Mtetra
.642 .705 .893 r
.32418 .33953 .33435 .35228 .35068 .34725 .34058 .33422 Mtetra
.642 .702 .889 r
.34058 .33422 .35068 .34725 .36714 .34176 .35708 .32885 Mtetra
.646 .706 .891 r
.35708 .32885 .36714 .34176 .38371 .33611 .37369 .32332 Mtetra
.65 .711 .892 r
.37369 .32332 .38371 .33611 .40039 .33032 .39042 .31758 Mtetra
.654 .715 .893 r
.39042 .31758 .40039 .33032 .41718 .32443 .40726 .31161 Mtetra
.658 .716 .891 r
.40726 .31161 .41718 .32443 .43407 .31842 .42422 .30542 Mtetra
.662 .716 .888 r
.42422 .30542 .43407 .31842 .45107 .31229 .44129 .29902 Mtetra
.664 .713 .885 r
.44129 .29902 .45107 .31229 .46818 .30598 .45846 .29245 Mtetra
.664 .71 .882 r
.45846 .29245 .46818 .30598 .48541 .29921 .47573 .28582 Mtetra
.659 .711 .887 r
.47573 .28582 .48541 .29921 .50273 .29218 .49311 .27943 Mtetra
.65 .721 .9 r
.49311 .27943 .50273 .29218 .52015 .28511 .5106 .27347 Mtetra
.632 .737 .924 r
.5106 .27347 .52015 .28511 .53768 .27848 .5282 .26822 Mtetra
.578 .747 .957 r
.5282 .26822 .53768 .27848 .55532 .27272 .54593 .26459 Mtetra
.501 .766 .99 r
.54593 .26459 .55532 .27272 .5731 .26834 .56383 .26223 Mtetra
.435 .784 .997 r
.56383 .26223 .5731 .26834 .59107 .26622 .5819 .26019 Mtetra
.465 .802 .999 r
.5819 .26019 .59107 .26622 .60922 .26477 .60012 .25748 Mtetra
.576 .823 .992 r
.60012 .25748 .60922 .26477 .62752 .26261 .61844 .25281 Mtetra
.685 .807 .94 r
.61844 .25281 .62752 .26261 .64591 .25824 .63679 .24505 Mtetra
.713 .749 .881 r
.63679 .24505 .64591 .25824 .66428 .25035 .65518 .23559 Mtetra
.717 .726 .858 r
.65518 .23559 .66428 .25035 .68267 .24062 .67363 .22544 Mtetra
.694 .712 .862 r
.67363 .22544 .68267 .24062 .7011 .23034 .69222 .2165 Mtetra
.674 .727 .89 r
.69222 .2165 .7011 .23034 .71973 .22177 .71099 .2089 Mtetra
.656 .739 .911 r
.71099 .2089 .71973 .22177 .73855 .21446 .72994 .2022 Mtetra
.653 .751 .922 r
.72994 .2022 .73855 .21446 .75754 .20795 .74902 .19558 Mtetra
.652 .748 .92 r
.07744 .41892 .08868 .42886 .10371 .42344 .09249 .41371 Mtetra
.661 .756 .92 r
.09249 .41371 .10371 .42344 .11882 .41811 .10767 .40812 Mtetra
.652 .75 .921 r
.10767 .40812 .11882 .41811 .13392 .41365 .12291 .40283 Mtetra
.628 .727 .918 r
.12291 .40283 .13392 .41365 .14895 .41049 .13813 .39837 Mtetra
.592 .69 .91 r
.13813 .39837 .14895 .41049 .16396 .40853 .15331 .39517 Mtetra
.565 .657 .898 r
.15331 .39517 .16396 .40853 .17917 .40592 .1685 .3929 Mtetra
.581 .671 .901 r
.1685 .3929 .17917 .40592 .19465 .40168 .18387 .39004 Mtetra
.618 .712 .913 r
.18387 .39004 .19465 .40168 .21053 .39446 .19949 .38582 Mtetra
.679 .794 .935 r
.19949 .38582 .21053 .39446 .22667 .38533 .21545 .37927 Mtetra
.727 .861 .944 r
.21545 .37927 .22667 .38533 .24292 .37553 .23167 .37077 Mtetra
.739 .892 .949 r
.23167 .37077 .24292 .37553 .2592 .36602 .24802 .3616 Mtetra
.739 .901 .951 r
.24802 .3616 .2592 .36602 .27545 .35776 .26443 .35233 Mtetra
.728 .88 .951 r
.26443 .35233 .27545 .35776 .29164 .35108 .28087 .34361 Mtetra
.707 .832 .942 r
.28087 .34361 .29164 .35108 .30788 .34509 .29731 .3358 Mtetra
.678 .787 .932 r
.29731 .3358 .30788 .34509 .32418 .33953 .31376 .32909 Mtetra
.666 .761 .921 r
.31376 .32909 .32418 .33953 .34058 .33422 .33026 .32281 Mtetra
.659 .74 .91 r
.33026 .32281 .34058 .33422 .35708 .32885 .34686 .31674 Mtetra
.656 .727 .902 r
.34686 .31674 .35708 .32885 .37369 .32332 .36355 .31076 Mtetra
.654 .719 .896 r
.36355 .31076 .37369 .32332 .39042 .31758 .38034 .30477 Mtetra
.654 .716 .894 r
.38034 .30477 .39042 .31758 .40726 .31161 .39724 .29874 Mtetra
.655 .716 .894 r
.39724 .29874 .40726 .31161 .42422 .30542 .41425 .29265 Mtetra
.654 .719 .896 r
.41425 .29265 .42422 .30542 .44129 .29902 .43137 .28656 Mtetra
.652 .726 .903 r
.43137 .28656 .44129 .29902 .45846 .29245 .44859 .28054 Mtetra
.646 .736 .914 r
.44859 .28054 .45846 .29245 .47573 .28582 .46592 .27476 Mtetra
.634 .75 .932 r
.46592 .27476 .47573 .28582 .49311 .27943 .48335 .26939 Mtetra
.596 .759 .957 r
.48335 .26939 .49311 .27943 .5106 .27347 .5009 .26515 Mtetra
.544 .78 .986 r
.5009 .26515 .5106 .27347 .5282 .26822 .51859 .26185 Mtetra
.478 .799 1 r
.51859 .26185 .5282 .26822 .54593 .26459 .53642 .2591 Mtetra
.455 .81 .997 r
.53642 .2591 .54593 .26459 .56383 .26223 .55442 .25628 Mtetra
.499 .821 1 r
.55442 .25628 .56383 .26223 .5819 .26019 .57256 .25278 Mtetra
.607 .834 .986 r
.57256 .25278 .5819 .26019 .60012 .25748 .59082 .24728 Mtetra
.688 .8 .934 r
.59082 .24728 .60012 .25748 .61844 .25281 .60914 .23938 Mtetra
.709 .745 .88 r
.60914 .23938 .61844 .25281 .63679 .24505 .62752 .23004 Mtetra
.712 .722 .857 r
.62752 .23004 .63679 .24505 .65518 .23559 .64597 .22008 Mtetra
.694 .708 .859 r
.64597 .22008 .65518 .23559 .67363 .22544 .66454 .21106 Mtetra
.674 .719 .883 r
.66454 .21106 .67363 .22544 .69222 .2165 .68328 .20333 Mtetra
.658 .736 .907 r
.68328 .20333 .69222 .2165 .71099 .2089 .70218 .19646 Mtetra
.651 .749 .921 r
.70218 .19646 .71099 .2089 .72994 .2022 .72123 .18987 Mtetra
.659 .756 .921 r
.72123 .18987 .72994 .2022 .74902 .19558 .74038 .18289 Mtetra
.652 .748 .92 r
.06607 .40887 .07744 .41892 .09249 .41371 .08117 .4036 Mtetra
.08117 .4036 .09249 .41371 .10767 .40812 .09637 .39826 Mtetra
.661 .757 .921 r
.09637 .39826 .10767 .40812 .12291 .40283 .1117 .39257 Mtetra
.651 .747 .92 r
.1117 .39257 .12291 .40283 .13813 .39837 .12707 .38723 Mtetra
.629 .724 .916 r
.12707 .38723 .13813 .39837 .15331 .39517 .14245 .38264 Mtetra
.599 .688 .905 r
.14245 .38264 .15331 .39517 .1685 .3929 .1578 .37914 Mtetra
.573 .657 .893 r
.1578 .37914 .1685 .3929 .18387 .39004 .17316 .37653 Mtetra
.584 .667 .896 r
.17316 .37653 .18387 .39004 .19949 .38582 .18869 .37352 Mtetra
.612 .701 .908 r
.18869 .37352 .19949 .38582 .21545 .37927 .20444 .36946 Mtetra
.648 .764 .934 r
.20444 .36946 .21545 .37927 .23167 .37077 .22043 .36399 Mtetra
.703 .845 .951 r
.22043 .36399 .23167 .37077 .24802 .3616 .23673 .35635 Mtetra
.717 .883 .958 r
.23673 .35635 .24802 .3616 .26443 .35233 .25316 .34797 Mtetra
.716 .903 .962 r
.25316 .34797 .26443 .35233 .28087 .34361 .26968 .33936 Mtetra
.711 .907 .964 r
.26968 .33936 .28087 .34361 .29731 .3358 .28627 .33083 Mtetra
.702 .892 .966 r
.28627 .33083 .29731 .3358 .31376 .32909 .30291 .32272 Mtetra
.694 .86 .961 r
.30291 .32272 .31376 .32909 .33026 .32281 .31959 .31511 Mtetra
.684 .829 .953 r
.31959 .31511 .33026 .32281 .34686 .31674 .33632 .30798 Mtetra
.672 .804 .946 r
.33632 .30798 .34686 .31674 .36355 .31076 .35312 .3013 Mtetra
.661 .787 .941 r
.35312 .3013 .36355 .31076 .38034 .30477 .37 .29501 Mtetra
.656 .78 .94 r
.37 .29501 .38034 .30477 .39724 .29874 .38698 .2889 Mtetra
.649 .779 .942 r
.38698 .2889 .39724 .29874 .41425 .29265 .40405 .28298 Mtetra
.637 .78 .95 r
.40405 .28298 .41425 .29265 .43137 .28656 .42122 .27745 Mtetra
.619 .788 .963 r
.42122 .27745 .43137 .28656 .44859 .28054 .4385 .27237 Mtetra
.593 .802 .98 r
.4385 .27237 .44859 .28054 .46592 .27476 .45588 .26779 Mtetra
.555 .818 .995 r
.45588 .26779 .46592 .27476 .48335 .26939 .47339 .26372 Mtetra
.505 .828 1 r
.47339 .26372 .48335 .26939 .5009 .26515 .49104 .26008 Mtetra
.481 .831 .996 r
.49104 .26008 .5009 .26515 .51859 .26185 .50882 .25653 Mtetra
.497 .834 .998 r
.50882 .25653 .51859 .26185 .53642 .2591 .52676 .25276 Mtetra
.553 .837 .998 r
.52676 .25276 .53642 .2591 .55442 .25628 .54484 .24824 Mtetra
.652 .836 .971 r
.54484 .24824 .55442 .25628 .57256 .25278 .56304 .24149 Mtetra
.693 .779 .917 r
.56304 .24149 .57256 .25278 .59082 .24728 .58133 .23329 Mtetra
.706 .735 .874 r
.58133 .23329 .59082 .24728 .60914 .23938 .59969 .22398 Mtetra
.706 .714 .855 r
.59969 .22398 .60914 .23938 .62752 .23004 .61813 .21424 Mtetra
.689 .703 .857 r
.61813 .21424 .62752 .23004 .64597 .22008 .6367 .20541 Mtetra
.673 .715 .88 r
.6367 .20541 .64597 .22008 .66454 .21106 .6554 .19767 Mtetra
.659 .733 .905 r
.6554 .19767 .66454 .21106 .68328 .20333 .67426 .19071 Mtetra
.651 .746 .919 r
.67426 .19071 .68328 .20333 .70218 .19646 .69327 .18411 Mtetra
.659 .757 .922 r
.69327 .18411 .70218 .19646 .72123 .18987 .71239 .17712 Mtetra
.659 .751 .917 r
.71239 .17712 .72123 .18987 .74038 .18289 .73163 .17005 Mtetra
.654 .75 .92 r
.05458 .39877 .06607 .40887 .08117 .4036 .06974 .39336 Mtetra
.652 .748 .92 r
.06974 .39336 .08117 .4036 .09637 .39826 .08498 .388 Mtetra
.653 .749 .92 r
.08498 .388 .09637 .39826 .1117 .39257 .10032 .38253 Mtetra
.661 .757 .921 r
.10032 .38253 .1117 .39257 .12707 .38723 .11579 .37675 Mtetra
.652 .747 .919 r
.11579 .37675 .12707 .38723 .14245 .38264 .13132 .37128 Mtetra
.633 .725 .914 r
.13132 .37128 .14245 .38264 .1578 .37914 .14686 .36646 Mtetra
.611 .693 .902 r
.14686 .36646 .1578 .37914 .17316 .37653 .16241 .36241 Mtetra
.583 .658 .889 r
.16241 .36241 .17316 .37653 .18869 .37352 .17796 .3594 Mtetra
.586 .66 .889 r
.17796 .3594 .18869 .37352 .20444 .36946 .19364 .35622 Mtetra
.605 .684 .898 r
.19364 .35622 .20444 .36946 .22043 .36399 .20952 .35233 Mtetra
.629 .724 .916 r
.20952 .35233 .22043 .36399 .23673 .35635 .2256 .3475 Mtetra
.657 .793 .947 r
.2256 .3475 .23673 .35635 .25316 .34797 .24189 .34153 Mtetra
.689 .855 .962 r
.24189 .34153 .25316 .34797 .26968 .33936 .2584 .33415 Mtetra
.692 .885 .969 r
.2584 .33415 .26968 .33936 .28627 .33083 .27502 .32641 Mtetra
.684 .901 .974 r
.27502 .32641 .28627 .33083 .30291 .32272 .29173 .31862 Mtetra
.672 .907 .977 r
.29173 .31862 .30291 .32272 .31959 .31511 .30851 .311 Mtetra
.66 .906 .98 r
.30851 .311 .31959 .31511 .33632 .30798 .32536 .30363 Mtetra
.646 .899 .983 r
.32536 .30363 .33632 .30798 .35312 .3013 .34227 .29665 Mtetra
.633 .89 .987 r
.34227 .29665 .35312 .3013 .37 .29501 .35927 .29007 Mtetra
.618 .881 .99 r
.35927 .29007 .37 .29501 .38698 .2889 .37634 .2839 Mtetra
.599 .875 .993 r
.37634 .2839 .38698 .2889 .40405 .28298 .39351 .27814 Mtetra
.575 .871 .995 r
.39351 .27814 .40405 .28298 .42122 .27745 .41077 .27279 Mtetra
.549 .867 .995 r
.41077 .27279 .42122 .27745 .4385 .27237 .42815 .26782 Mtetra
.53 .862 .995 r
.42815 .26782 .4385 .27237 .45588 .26779 .44564 .26312 Mtetra
.522 .857 .995 r
.44564 .26312 .45588 .26779 .47339 .26372 .46326 .25859 Mtetra
.532 .853 .997 r
.46326 .25859 .47339 .26372 .49104 .26008 .48102 .25402 Mtetra
.566 .848 .997 r
.48102 .25402 .49104 .26008 .50882 .25653 .49892 .24909 Mtetra
.636 .843 .98 r
.49892 .24909 .50882 .25653 .52676 .25276 .51696 .24273 Mtetra
.68 .801 .94 r
.51696 .24273 .52676 .25276 .54484 .24824 .53511 .23518 Mtetra
.695 .747 .892 r
.53511 .23518 .54484 .24824 .56304 .24149 .55337 .22666 Mtetra
.701 .721 .865 r
.55337 .22666 .56304 .24149 .58133 .23329 .57171 .21739 Mtetra
.699 .705 .852 r
.57171 .21739 .58133 .23329 .59969 .22398 .59014 .20794 Mtetra
.68 .697 .858 r
.59014 .20794 .59969 .22398 .61813 .21424 .60869 .19953 Mtetra
.67 .715 .882 r
.60869 .19953 .61813 .21424 .6367 .20541 .62737 .19191 Mtetra
.658 .732 .904 r
.62737 .19191 .6367 .20541 .6554 .19767 .64619 .18495 Mtetra
.651 .746 .919 r
.64619 .18495 .6554 .19767 .67426 .19071 .66516 .17829 Mtetra
.658 .756 .923 r
.66516 .17829 .67426 .19071 .69327 .18411 .68424 .1713 Mtetra
.659 .751 .918 r
.68424 .1713 .69327 .18411 .71239 .17712 .70344 .16419 Mtetra
.657 .749 .918 r
.70344 .16419 .71239 .17712 .73163 .17005 .72278 .15711 Mtetra
.656 .752 .92 r
.04294 .38864 .05458 .39877 .06974 .39336 .05816 .38307 Mtetra
.654 .749 .92 r
.05816 .38307 .06974 .39336 .08498 .388 .07346 .37757 Mtetra
.652 .747 .92 r
.07346 .37757 .08498 .388 .10032 .38253 .08885 .3721 Mtetra
.653 .749 .92 r
.08885 .3721 .10032 .38253 .11579 .37675 .10433 .36656 Mtetra
.661 .757 .921 r
.10433 .36656 .11579 .37675 .13132 .37128 .11996 .36068 Mtetra
.655 .748 .919 r
.11996 .36068 .13132 .37128 .14686 .36646 .13564 .35501 Mtetra
.639 .728 .913 r
.13564 .35501 .14686 .36646 .16241 .36241 .15136 .34986 Mtetra
.624 .704 .902 r
.15136 .34986 .16241 .36241 .17796 .3594 .16712 .34523 Mtetra
.599 .667 .887 r
.16712 .34523 .17796 .3594 .19364 .35622 .18288 .34152 Mtetra
.592 .656 .882 r
.18288 .34152 .19364 .35622 .20952 .35233 .19874 .33803 Mtetra
.601 .668 .887 r
.19874 .33803 .20952 .35233 .2256 .3475 .21476 .3342 Mtetra
.616 .692 .898 r
.21476 .3342 .2256 .3475 .24189 .34153 .23095 .32975 Mtetra
.633 .728 .917 r
.23095 .32975 .24189 .34153 .2584 .33415 .24731 .32464 Mtetra
.647 .781 .945 r
.24731 .32464 .2584 .33415 .27502 .32641 .26383 .31891 Mtetra
.66 .831 .965 r
.26383 .31891 .27502 .32641 .29173 .31862 .28052 .31246 Mtetra
.665 .863 .975 r
.28052 .31246 .29173 .31862 .30851 .311 .29734 .30556 Mtetra
.656 .878 .981 r
.29734 .30556 .30851 .311 .32536 .30363 .31425 .29867 Mtetra
.642 .886 .985 r
.31425 .29867 .32536 .30363 .34227 .29665 .33125 .29193 Mtetra
.627 .889 .988 r
.33125 .29193 .34227 .29665 .35927 .29007 .34834 .28542 Mtetra
.612 .887 .99 r
.34834 .28542 .35927 .29007 .37634 .2839 .36552 .27918 Mtetra
.598 .883 .992 r
.36552 .27918 .37634 .2839 .39351 .27814 .38279 .27322 Mtetra
.589 .876 .993 r
.38279 .27322 .39351 .27814 .41077 .27279 .40017 .26749 Mtetra
.587 .869 .994 r
.40017 .26749 .41077 .27279 .42815 .26782 .41767 .26192 Mtetra
.594 .86 .994 r
.41767 .26192 .42815 .26782 .44564 .26312 .43528 .25635 Mtetra
.621 .851 .986 r
.43528 .25635 .44564 .26312 .46326 .25859 .45303 .25034 Mtetra
.655 .83 .967 r
.45303 .25034 .46326 .25859 .48102 .25402 .47092 .24358 Mtetra
.676 .79 .935 r
.47092 .24358 .48102 .25402 .49892 .24909 .48893 .23619 Mtetra
.687 .747 .897 r
.48893 .23619 .49892 .24909 .51696 .24273 .50705 .22812 Mtetra
.693 .721 .871 r
.50705 .22812 .51696 .24273 .53511 .23518 .52527 .2194 Mtetra
.694 .704 .856 r
.52527 .2194 .53511 .23518 .55337 .22666 .54358 .21031 Mtetra
.687 .695 .852 r
.54358 .21031 .55337 .22666 .57171 .21739 .562 .20144 Mtetra
.672 .696 .864 r
.562 .20144 .57171 .21739 .59014 .20794 .58052 .19349 Mtetra
.666 .719 .888 r
.58052 .19349 .59014 .20794 .60869 .19953 .59917 .18606 Mtetra
.656 .733 .906 r
.59917 .18606 .60869 .19953 .62737 .19191 .61796 .17916 Mtetra
.651 .747 .92 r
.61796 .17916 .62737 .19191 .64619 .18495 .63688 .17247 Mtetra
.658 .757 .923 r
.63688 .17247 .64619 .18495 .66516 .17829 .65592 .16542 Mtetra
.659 .751 .918 r
.65592 .16542 .66516 .17829 .68424 .1713 .67509 .15828 Mtetra
.658 .749 .918 r
.67509 .15828 .68424 .1713 .70344 .16419 .69439 .15116 Mtetra
.655 .75 .919 r
.69439 .15116 .70344 .16419 .72278 .15711 .71382 .1441 Mtetra
.66 .755 .921 r
.03115 .37851 .04294 .38864 .05816 .38307 .04644 .37276 Mtetra
.656 .752 .92 r
.04644 .37276 .05816 .38307 .07346 .37757 .06181 .3671 Mtetra
.654 .749 .92 r
.06181 .3671 .07346 .37757 .08885 .3721 .07726 .36149 Mtetra
.652 .747 .919 r
.07726 .36149 .08885 .3721 .10433 .36656 .09279 .35591 Mtetra
.653 .748 .92 r
.09279 .35591 .10433 .36656 .11996 .36068 .10842 .35028 Mtetra
.66 .756 .921 r
.10842 .35028 .11996 .36068 .13564 .35501 .12419 .34435 Mtetra
.657 .752 .92 r
.12419 .34435 .13564 .35501 .15136 .34986 .14004 .33847 Mtetra
.647 .736 .914 r
.14004 .33847 .15136 .34986 .16712 .34523 .15594 .33293 Mtetra
.635 .716 .906 r
.15594 .33293 .16712 .34523 .18288 .34152 .1719 .3278 Mtetra
.624 .688 .889 r
.1719 .3278 .18288 .34152 .19874 .33803 .18793 .32304 Mtetra
.604 .66 .878 r
.18793 .32304 .19874 .33803 .21476 .3342 .20398 .31901 Mtetra
.604 .658 .876 r
.20398 .31901 .21476 .3342 .23095 .32975 .22016 .31493 Mtetra
.611 .668 .88 r
.22016 .31493 .23095 .32975 .24731 .32464 .23649 .31054 Mtetra
.621 .685 .889 r
.23649 .31054 .24731 .32464 .26383 .31891 .25298 .30574 Mtetra
.632 .707 .9 r
.25298 .30574 .26383 .31891 .28052 .31246 .26961 .3005 Mtetra
.641 .734 .916 r
.26961 .3005 .28052 .31246 .29734 .30556 .28639 .29491 Mtetra
.647 .763 .934 r
.28639 .29491 .29734 .30556 .31425 .29867 .30329 .28903 Mtetra
.65 .787 .947 r
.30329 .28903 .31425 .29867 .33125 .29193 .32032 .28295 Mtetra
.651 .803 .956 r
.32032 .28295 .33125 .29193 .34834 .28542 .33747 .27673 Mtetra
.651 .812 .96 r
.33747 .27673 .34834 .28542 .36552 .27918 .35473 .27042 Mtetra
.653 .812 .96 r
.35473 .27042 .36552 .27918 .38279 .27322 .37211 .26402 Mtetra
.656 .805 .954 r
.37211 .26402 .38279 .27322 .40017 .26749 .38961 .25749 Mtetra
.662 .791 .943 r
.38961 .25749 .40017 .26749 .41767 .26192 .40722 .25075 Mtetra
.669 .77 .926 r
.40722 .25075 .41767 .26192 .43528 .25635 .42496 .24372 Mtetra
.674 .745 .904 r
.42496 .24372 .43528 .25635 .45303 .25034 .44281 .23631 Mtetra
.679 .724 .883 r
.44281 .23631 .45303 .25034 .47092 .24358 .46078 .22846 Mtetra
.683 .709 .868 r
.46078 .22846 .47092 .24358 .48893 .23619 .47886 .22017 Mtetra
.684 .697 .856 r
.47886 .22017 .48893 .23619 .50705 .22812 .49704 .21157 Mtetra
.683 .69 .85 r
.49704 .21157 .50705 .22812 .52527 .2194 .51533 .20289 Mtetra
.67 .686 .857 r
.51533 .20289 .52527 .2194 .54358 .21031 .53371 .19495 Mtetra
.667 .704 .875 r
.53371 .19495 .54358 .21031 .562 .20144 .5522 .18737 Mtetra
.661 .725 .896 r
.5522 .18737 .562 .20144 .58052 .19349 .57082 .1802 Mtetra
.654 .737 .911 r
.57082 .1802 .58052 .19349 .59917 .18606 .58957 .17338 Mtetra
.652 .75 .921 r
.58957 .17338 .59917 .18606 .61796 .17916 .60844 .16659 Mtetra
.659 .756 .922 r
.60844 .16659 .61796 .17916 .63688 .17247 .62744 .15949 Mtetra
.659 .75 .917 r
.62744 .15949 .63688 .17247 .65592 .16542 .64657 .15232 Mtetra
.657 .749 .917 r
.64657 .15232 .65592 .16542 .67509 .15828 .66583 .14517 Mtetra
.655 .75 .919 r
.66583 .14517 .67509 .15828 .69439 .15116 .68522 .13806 Mtetra
.652 .75 .921 r
.68522 .13806 .69439 .15116 .71382 .1441 .70476 .13103 Mtetra
.657 .753 .92 r
.01925 .36819 .03115 .37851 .04644 .37276 .03458 .36245 Mtetra
.659 .755 .921 r
.03458 .36245 .04644 .37276 .06181 .3671 .05001 .35661 Mtetra
.657 .752 .92 r
.05001 .35661 .06181 .3671 .07726 .36149 .06552 .35084 Mtetra
.654 .749 .92 r
.06552 .35084 .07726 .36149 .09279 .35591 .08112 .34512 Mtetra
.653 .747 .919 r
.08112 .34512 .09279 .35591 .10842 .35028 .0968 .33942 Mtetra
.652 .747 .919 r
.0968 .33942 .10842 .35028 .12419 .34435 .11259 .33369 Mtetra
.657 .754 .922 r
.11259 .33369 .12419 .34435 .14004 .33847 .12849 .32777 Mtetra
.659 .755 .921 r
.12849 .32777 .14004 .33847 .15594 .33293 .14451 .32171 Mtetra
.654 .745 .916 r
.14451 .32171 .15594 .33293 .1719 .3278 .1606 .31579 Mtetra
.645 .728 .909 r
.1606 .31579 .1719 .3278 .18793 .32304 .17676 .31017 Mtetra
.637 .711 .9 r
.17676 .31017 .18793 .32304 .20398 .31901 .193 .30479 Mtetra
.63 .686 .884 r
.193 .30479 .20398 .31901 .22016 .31493 .20932 .29961 Mtetra
.619 .665 .873 r
.20932 .29961 .22016 .31493 .23649 .31054 .22571 .29482 Mtetra
.617 .659 .869 r
.22571 .29482 .23649 .31054 .25298 .30574 .24222 .29005 Mtetra
.621 .663 .869 r
.24222 .29005 .25298 .30574 .26961 .3005 .25886 .28507 Mtetra
.627 .67 .872 r
.25886 .28507 .26961 .3005 .28639 .29491 .27565 .27981 Mtetra
.633 .679 .876 r
.27565 .27981 .28639 .29491 .30329 .28903 .29257 .27425 Mtetra
.64 .688 .88 r
.29257 .27425 .30329 .28903 .32032 .28295 .30963 .26841 Mtetra
.646 .696 .882 r
.30963 .26841 .32032 .28295 .33747 .27673 .32681 .26229 Mtetra
.651 .701 .883 r
.32681 .26229 .33747 .27673 .35473 .27042 .34413 .2559 Mtetra
.656 .702 .881 r
.34413 .2559 .35473 .27042 .37211 .26402 .36157 .24925 Mtetra
.66 .701 .877 r
.36157 .24925 .37211 .26402 .38961 .25749 .37914 .24231 Mtetra
.664 .698 .871 r
.37914 .24231 .38961 .25749 .40722 .25075 .39682 .23509 Mtetra
.668 .693 .864 r
.39682 .23509 .40722 .25075 .42496 .24372 .41463 .22755 Mtetra
.671 .688 .858 r
.41463 .22755 .42496 .24372 .44281 .23631 .43255 .21973 Mtetra
.673 .684 .852 r
.43255 .21973 .44281 .23631 .46078 .22846 .45057 .21168 Mtetra
.671 .682 .851 r
.45057 .21168 .46078 .22846 .47886 .22017 .4687 .20364 Mtetra
.665 .684 .858 r
.4687 .20364 .47886 .22017 .49704 .21157 .48693 .19599 Mtetra
.664 .699 .873 r
.48693 .19599 .49704 .21157 .51533 .20289 .50527 .18853 Mtetra
.662 .72 .892 r
.50527 .18853 .51533 .20289 .53371 .19495 .52373 .1813 Mtetra
.656 .731 .905 r
.52373 .1813 .53371 .19495 .5522 .18737 .54231 .17438 Mtetra
.652 .744 .917 r
.54231 .17438 .5522 .18737 .57082 .1802 .56101 .1676 Mtetra
.655 .754 .923 r
.56101 .1676 .57082 .1802 .58957 .17338 .57984 .16066 Mtetra
.659 .755 .921 r
.57984 .16066 .58957 .17338 .60844 .16659 .5988 .15351 Mtetra
.658 .749 .917 r
.5988 .15351 .60844 .16659 .62744 .15949 .61788 .14632 Mtetra
.657 .749 .918 r
.61788 .14632 .62744 .15949 .64657 .15232 .6371 .13914 Mtetra
.655 .75 .919 r
.6371 .13914 .64657 .15232 .66583 .14517 .65645 .132 Mtetra
.653 .751 .922 r
.65645 .132 .66583 .14517 .68522 .13806 .67594 .12492 Mtetra
.654 .754 .923 r
.67594 .12492 .68522 .13806 .70476 .13103 .69557 .11772 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
[(-2)] .12586 .2075 1 .99877 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.56863 .04703 m
.57247 .05235 L
s
[(2)] .56094 .0364 .72324 1 Mshowa
.125 Mabswid
.18558 .19702 m
.18832 .19985 L
s
.23703 .17687 m
.23971 .17975 L
s
.28951 .15632 m
.29214 .15925 L
s
.39772 .11395 m
.40023 .11699 L
s
.4535 .09211 m
.45595 .0952 L
s
.51046 .06981 m
.51284 .07294 L
s
.08568 .23614 m
.08851 .23887 L
s
.62804 .02377 m
.63027 .02701 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 233.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00o?ooool2o`0006[ooooo003iooooo`?o000000?oooooo`000?ooool0
JOooool00?Oooooo0_l00004ooooo`;o0000JOooool00?Cooooo0ol00006ooooo`03o`000?oooooo
000006Sooooo003;ooooo`Go00008_ooool2o`0000Wooooo00?o0000ooooool00000J?ooool00<_o
oooo00GoV9RHob4Q8Oo^k^koooooodA4A00Oooooo`?o00002oooool01?l0003oooooooooool0001W
ooooo`00c?ooool00onHV9So8B4Qonk^kP0Mooooo`?o00003_ooool01Ol0003ooooooooooooooooo
000006Kooooo003=ooooo`03oiRHV?lQ8B7ok^k^01[ooooo0_l0000Aooooo`05o`000?oooooooooo
ooooool00000I_ooool00<kooooo00?oMgMgofIVI_ooool05_ooool3o`0001?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1Sooooo`00coooool00ol0003oooooooooo`0Cooooo`;o
00000_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0H_ooool00<_ooooo00Go0000okZj^_ooooooV9RHoa0@400Booooo`?o00006Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo06;ooooo003;ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`04?ooool2o`0001cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Qooooo`00
gOooool3o`0001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Qooooo`00fooo
ool2o`00027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Pooooo`00f?ooool3
o`0002?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Oooooo`00eOooool3o`00
02Kooooo00?o0000ooooooooool01?ooool2o`00067ooooo003Cooooo`;o0000:Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo05kooooo003@ooooo`?o000000?oooooo`000?ooool0
:?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05gooooo003>ooooo`;o00001Ooo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0GOoo
ool00<_ooooo0ol0000`ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0G?ooool0
0<Wooooo0_l0000cooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Foooool00<Ko
oooo0ol0000eooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Foooool00<Cooooo
0_l0000hooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0F_ooool00<7ooooo0ol0
000jooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03_ooool5o`0004Kooooo002n
ooooo`?o0000?Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00kooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A016ooooo`00_?ooool2o`0000?ooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo1_l00003ooooo`03oiRHV?lQ8B7o
k^k^04Oooooo002iooooo`?o0000@oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00kooooo00?oV9RHob4Q8Oo^k^h0A_ooool00;Oooooo0_l00016ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03oooool00omgMgOoIVIVooooo`15ooooo`00]?ooool3o`0004Sooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Cooooo
002booooo`;o0000Boooool00ol0003oooooooooo`0=ooooo`;o00003?ooool01Ol0003o^[Zjoooo
oonHV9So410@04Kooooo002_ooooo`?o0000COooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c016ooooo`00[Oooool2o`00053ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`1Dooooo`00Z_ooool4o`00057ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1Dooooo`00Z?ooool2o`0000Cooooo00?o0000oooo
ooooool0C_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05?ooooo001nooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h08_ooool3o`0005Oooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`1Booooo`00O_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01oooooo0ol0001Joooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool0D_ooool007kooooo00Go410@oooooooo
oooooooooa0@400Mooooo`;o0000GOooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
057ooooo001nooooo`05o`000?ooooooooooooooool000006_ooool3o`0005oooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`1@ooooo`00O_ooool01Ol0003ooooooooooooooooo0000
01Sooooo0_l0001Rooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0D?ooool007ko
oooo00Go410@oooooooooooooooooa0@400Eooooo`?o0000I?ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo04oooooo001nooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool2o`00
00?ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
04kooooo001nooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04?ooool3o`0006Sooooo00?oYl7/o`00
0?ooool05_ooool00ol0003oooooooooo`1>ooooo`00TOooool2o`0006Sooooo1?nW`N`00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo04gooooo002>ooooo`?o0000J?ooool7ojO1k003o`00
0?oooooooooo01Cooooo0ol0001>ooooo`00Roooool3o`0006Wooooo0_nW`>`7ojO1k003o`000?oo
oooooooo01Kooooo00?o0000ooooooooool0C?ooool008Wooooo0_l0001Yooooo`KoYl3/1_nW`N`0
0ol0003oYl7/ooooo`0Gooooo`03o`000?oooooooooo04_ooooo0026ooooo`?o0000J?ooool00onW
_n_oYl3/ojO0k007ojO0k0GoYl7/00?o0000ojJojoooool06?ooool00ol0003oooooooooo`1:oooo
o`00Q?ooool2o`0000;ooooo00?o0000ooooooooool0Hoooool5ojNoj`WoYl3/0_nW`N`2ojJoj`03
o`000?nV_n_oY[o[01Sooooo00?o0000ooooooooool0B_ooool0087ooooo0ol00005ooooo`03o`00
0?oooooooooo063ooooo2?nW_n/7ojO0k003ojNojonV_n_oY[o[00;oY[o[00Co0000ojJojonV_n_o
Y[o[6?ooool00ol0003oooooooooo`19ooooo`00Ooooool2o`0006Wooooo00?oZ;o[ojNojonW_n/0
1onW_n/4ojO0k0GoYko[0onV_n/00ol0003oY[o[ojJoj`02ojJojaSooooo00?o0000ooooooooool0
B?ooool007cooooo0ol0001Xooooo`GoZ;o[2OnW_n/00onW`>coYko[ojNoj`06ojNoj`;oY[o[00Go
0000ojJojonV_n_oY[o[ojNoj`0Hooooo`03o`000?oooooooooo04Sooooo001jooooo`;o0000Iooo
ool2ojRojPSoZ;o[1_nW_n/2ojRojPWoYko[0_nV_n/00ol0003oY[o[ojNoj`03ojNojaSooooo00?o
0000ooooooooool0Aoooool007Oooooo0ol0001Vooooo`KoZ;oZ2?nX_n/2ojNoj`KoZ;oZ2OnW_n/0
0onV_n_o0000ojNoj`05ojNojaSooooo00?o0000ooooooooool0A_ooool007Cooooo0ol0001Voooo
o`03ojS1jonX_n[oZ;oZ00OoZ;oZ1_nX_n/:ojRojPKoYko[0_nX_n/00onW_n_o0000ojNoj`05ojNo
jaSooooo00?o0000ooooooooool0A_ooool007;ooooo0_l00002ooooo`03o`000?oooooooooo06;o
oooo1?nX`N/9ojRojP;oZ;o[3_nX_nX2ojNoj`KoZ;o[00?o0000ojNojonW_n/01OnW_n/Hooooo`03
o`000?oooooooooo04Gooooo001_ooooo`?o0000Ioooool7ojS1j`OoZ;oZ00?oZ<7/ojRoj_nX_nX0
3OnX_nX00onX`>_oZ;o[ojRoj`06ojRoj`03o`000?nW_n_oYko[00CoYko[00?oZ;o[ooooooooool0
5_ooool00ol0003oooooooooo`15ooooo`00KOooool2o`0006Oooooo0_nW`N`8ojS1j`CoZ;oZ1OnX
`N`;ojRojPGoZ<3[1onX_n/01?l0003oZ;o[ojNojonW_n/5ojRojaOooooo0_l00016ooooo`00J_oo
ool3o`0006Kooooo1_nW`N`8ojS1j`03ojRoj_nX`NcoZ<7/00KoZ<7/1onX_nX00onX`NcoZ<3[ojS0
j`06ojS0j`KoZ;o[00?o0000ojS0jonX_n/01onX_n/Hooooo`03o`000?oooooooooo04?ooooo001X
ooooo`;o0000I_ooool2ojJnjPSoYl7/1_nX`N/2ojJoj`SoZ<7/1?nX_nX5ojS1k0SoZ<3[0_nX_n/3
ojS0j`03o`000?nX`>_oZ<3[00SoZ;o[5oooool00ol0003oooooooooo`13ooooo`00IOooool3o`00
06Gooooo1_nV_^X8ojO1k0;oZ<7[1_nV_n/8ojS1k003ojRoj_nX`NcoZ<7/00KoZ<7/1_nX`>/00onX
`NcoZ<3[ojS0j`03ojS0j`04o`000?nX`>_oZ<3[ojS0j`KoZ;o[00?oZ<3Zooooooooool05_ooool0
0ol0003oooooooooo`12ooooo`00Hoooool2o`0006Gooooo00?oYk_WojJnj_nV_^X01onV_^X6ojO1
k003ojNljOnV_n_oY[o[00OoY[o[1_nX`N`00onV_n_oZ<7/ojS1k007ojS1k0CoZ<3[1?nX`N`5ojS0
j`04o`000?nX`>_oZ<3[ojS0j`;oZ;o[1OnX`>XHooooo`03o`000?oooooooooo047ooooo001Poooo
o`?o000000?oooooo`000?ooool0H_ooool4ojNki`WoY[kZ0_nW`N`5ojNlj@WoY[o[0_nX`N`5ojJo
j`WoZ<7/00?oZ<3[ojS1k?nX`N`01OnX`N`4ojS0j`04o`000?nX`>_oZ<3[ojS1k0SoZ<3Z5oooool0
0ol0003oooooooooo`11ooooo`00=_ooool5o`0002?ooooo0_l0001Vooooo`OoYk_W1onV_^X00onY
^NGoYkcYojNlj@06ojNlj@KoY[o[0_nW^nL8ojJoj`KoZ<7/0_nV_^/8ojS1k0CoZ<3[00?o0000ojS1
k?nX`N`00_nX`N`8ojS0jQOooooo00?o0000ooooooooool0@?ooool003Kooooo00GoV9RHob4Q8Oo^
k^koooooodA4A00Pooooo`?o0000IOooool2ojVhi0SoYk_W1?nV_^X5ojVii@SoYkcY0_nV_n/6ojNk
i`SoY[o[0_nX`N`6ojJnj`SoZ<7/00CoZ<3[ojS1k?nX`Nco00001OnX`N`6ojS0jP03ojS1jooooooo
oooo01Kooooo00?o0000ooooooooool0?oooool002kooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^
01kooooo0ol0001Uooooo`KoZKST2?nW^nL00onV_^[oZKWUojVii@06ojVii@KoYkcY00?oZ[SSojNk
ionW^nL01onW^nL6ojJoj`03ojRkionV_^_oY[k[00OoY[k[1_nX`N`01OnV_^_oZ<7/ojS1k?nX`Nco
000000GoZ<7/1?nX`>X4ojS1jaOooooo00?o0000ooooooooool0?oooool003Sooooo00?oV9RHob4Q
8Oo^k^h06oooool2o`0006Gooooo00?oZK;OojVhi?nY^>@01onY^>@6ojNki`03ojZdgonY^NGoZKWU
00OoZKWU1?nW_>T4ojZhh`WoYk_W0_nV_n/5ojRki`WoY[k[0_nX`N`5ojJnj`;oZ<7/00?o0000ojS1
k?nX`N`01?nX`N`00onX`>[oZ<7[ojS1j`05ojS1jaOooooo00?o0000ooooooooool0?_ooool003Wo
oooo00?oMgMgofIVI_ooool05oooool3o`0006Gooooo1?nY/]l9ojVhi0;oYk_W1OnZ]=l9ojVii@03
ojNljOnZ^>?oZ[SS00GoZ[SS1onW^nL00on[]n7oZ;_WojRki`06ojRki`KoY[k[0_nX^nL8ojJnj`03
ojS1k?l0003oZ<7/00?oZ<7/0_nV_n/8ojS1jaSooooo00?o0000ooooooooool0?Oooool003[ooooo
00?o0000ooooooooool05?ooool2o`0006Kooooo1onY/]l7ojVhi003oj^_fonZ]=ooZ[CO00KoZ[CO
1onY^ND00on//]goZ[SSojZhh`07ojZhh`CoYk_W1?n[]n48ojRki`;oY[k[1_nX^nL8ojJnj`03o`00
0?nX`NcoY[o[00GoY[o[2?nX`N/Gooooo`03o`000?oooooooooo03gooooo000fooooo`05o`000?nj
^[[ooooooiRHV?l@41004oooool3o`0000;ooooo00?o0000ooooooooool0HOooool00onZ[m_oZK;O
ojVbg`07ojVbg`CoZKST1?n[[m/8ojZdg`CoZKWU1?n//]d9ojZhh`03ojNkion[]n7oZkOQ00GoZkOQ
1_nX^nL00on/]n7oZ;_WojRki`07ojRki`KoY[k[00?oZ;cXo`000?nV_n/01onV_n/6ojS1j`03ojO0
k?oooooooooo01Kooooo00?o0000ooooooooool0??ooool003Kooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c00Aooooo`;o0000I_ooool5ojZ_f`WoZK;O00?oZKSToj^_fon[[m/01?n[[m/9ojZdg`03ojVi
iOn//]go[;;M00Go[;;M1onZ^><00on^/]_oZkOQoj^gh@06oj^gh@CoZ;_W1?n/]n49ojRki`;oY[k[
1?nX_>P00ol0003oY[o[ojJoj`07ojJoj`;oZ<7[1OnW`>`Fooooo`?o0000?Oooool004Wooooo0ol0
001Uooooo`03oj^^fOnZ[m_oZZoK00KoZZoK1onY/]l00on^/=WoZjoKoj^_f`06oj^_f`OoZ[CO00?o
[k7JojbbgOn//]d01_n//]d4ojZhh`Go[[;K2?n[]n400onX^nOo[;OQojbgh@05ojbgh@OoZ;_W00?o
[;SRojRlj?nX_>P01?nX_>P00ol0003oZ;cXojJoj`05ojJoj`;oYkgY2?nW`>`Gooooo`03o`000?oo
oooooooo03_ooooo0017ooooo`;o0000I_ooool4oj^^f@SoZZoK1?nY/]l4ojj`f@OoZjoK1?nZ]=l5
ojnafPSo[;;M00?oZ[SSojjbfon^/]/01_n^/]/6oj^gh@03ok2cfon/]n7o[;OQ00Oo[;OQ1?nX^nL4
ojbhhPGoZ;cX00?o0000ojRlj?nX_>P00_nV_n/6ojNmj@SoYl3/5oooool00ol0003oooooooooo`0j
ooooo`00A?ooool3o`0006Kooooo1_n[[]T9ojZ_f`03ojVbgon^/=Wo[[3I00Co[[3I2?n[[m/00onZ
]=oo[k7JojnafP06ojnafPKo[;;M00?o/[CJojjbfon^/]/01on^/]/4oj^gh@Co/;?K2On/]n400onX
^nOo[;SRojbhhP05ojbhhPCoZ;cX00?o0000ojRlj?n/^^<02OnW_NT6ojO0k003ojJnj_oooooooooo
01Kooooo00?o0000ooooooooool0>Oooool0047ooooo0ol0001Wooooo`03ojb_f_n[[]WoZjkI00Ko
ZjkI1onZ[m/00on_/]_o[[3Iojj`f@06ojj`f@KoZjoK00?o/KCKojnaf_n_/MX01on_/MX4ojbbg@Co
/[CJ2On^/]/00on[]n7o/;?Kok2cf`05ok2cf`Oo[;OQ00?o/KGKojbhh_n/^>801_n/^>84ojRlj004
o`000?n/^^?o[;[Sojbjh`WoYkgY0_nW`>`5ojJnjQOooooo00?o0000ooooooooool0>Oooool003oo
oooo0ol0001Wooooo`Co[:oJ1on[[]T4ojZ_f`Go[k;K1on^/=T4oj^_f`Co/KCK2On_/MX00on//]go
/[CJok:dfP05ok:dfPOo[[;K00?o];KJok2cfon`/m/01_n`/m/4ojbgh@Go/KGK2?n/^>801?nX_>So
[;[Sojbjhol00004ojbjh`OoYkgY00?oZk_UojJnj_nV_^X01_nV_^XGooooo`03o`000?oooooooooo
03Sooooo000looooo`?o00000oooool00ol0003oooooooooo`1Rooooo`Ko[:oJ2?n[[]T00onZ[m_o
[k;Kojnbf`05ojnbf`So[[3I00?oZjoKok6dfona]=/01Ona]=/7ojnafP03ok>hgOnb]=[o/[CJ00Ko
/[CJ1?n^/]/5okBffPSo/;?K00?o[;OQok6efona]M/01_na]M/6ojbhhP05ok6fg?n/^^?o[;[Sojbj
hol000001?n/^^<4ojNmj@GoZk_U2?nV_^XFooooo`03o`000?oooooooooo00Oooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0/ooooo`00>_ooool2o`0006Wooooo00?oZk3Kojb_f_n/[mX01_n/[mX6oj^^
f@03ojjeg_n_/]_o[k;K00Oo[k;K1_n^/=T00ona^=ko/KCKok6df`07ok6df`Co[k7J1?nc^=d8ok:d
fP03ojjbfond]][o];KJ00Ko];KJ1_n`/m/00onf^=_o/KGKok6ef`07ok6ef`Co[;SR1?na]]`2ojbj
h`03o`000?n/^^?o[;[S00?o[;[S00?oYkgYoj^kiOn[^nD01_n[^nD6ojJnjP03ojVmj?oooooooooo
01Gooooo00?o0000ooooooooool01_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02cooooo000goooo
o`?o0000JOooool4oj^`f`Oo[:oJ1?n[[]T4ojjegPSo[k;K1?n^/=T4ok6hgPWo/KCK00?o[k7Jok>h
gOnc^=d01Onc^=d6ok:dfP03okBlgond]][o];KJ00Oo];KJ1?n`/m/4okJhf`Wo/KGK00?o[;SRok6f
g?na]]`01Ona]]`2ojbjh`05o`000?n/^^?o[;[Sojbjhon`]mh02_n[^nD2ojJnjPGoZKgX5oooool0
0ol0003oooooooooo`05ooooo`05oa0@4?ooooooooooooooool@4100;?ooool003Gooooo0_l0001Z
ooooo`KoZk3K2?n/[mX00on[[]Wo[[GNojjegP05ojjegPSo[k;K00?o[[3Iok6hg_na^=h01Ona^=h7
ok6df`03ok6oi?nc^=go/kSM00Ko/kSM1?nb]=X4okBlg`Wo];KJ00?o/;?KokJhfonf^=/01Onf^=/7
ok6ef`03okNifona]]co/KKL00Oo/KKL00?o[;[So`000?n`]mh01?n`]mh8oj^ki@03ojnihOnY_NSo
ZKgX00KoZKgX5_ooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool00000;?oo
ool003;ooooo0ol0001Zooooo`03oj^agOn[/=_oZk3K00KoZk3K1_n/[mX00on]^N;o[[GNojjegP07
ojjegPKo[k;K00?o[koUok6hg_na^=h01ona^=h4ok6df`Co/KoT2?nc^=d00onb]=[o];cOokBlg`05
okBlg`Oo];KJ00?o]KkQokJhfonf^=/01_nf^=/4ok6ef`Go]kWK1ona]]`00onh^]_o/;ONo`000006
ok2ggPCoZk_U1On_^N48ojVmj1Kooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooo
oooo000002cooooo000`ooooo`;o0000J_ooool5oj^ag@OoZk3K1?n/[mX4ojfihPWo[[GN0_n_/]/5
ojnoi@Wo/KSN00?o/KCKok6oi?na_n@01Ona_n@6ok>hg@03ok77j_nd_=oo];cO00Ko];cO1_nd]]X3
okFnh@So][SK00?o/KGKokNifong^M/01_ng^M/5ok6fg0?o^;[K00?o0000ok2gg_n`]mh01On`]mh0
0on[^nGo[kWQojnih@05ojnih@OoZKgX00?o[KcUooooooooool05Oooool00ol0003oooooooooo`03
ooooo`05oa0@4?ooooooooooooooool@4100;?ooool002gooooo0ol000000ooooooo0000ooooo`1V
ooooo`03ojVbg_n[/MgoZk7M00KoZk7M1on[/=/00on/[m[o[KWRojfihP05ojfihPOo[[GN00?o[L[_
ojnoiOn__nD01_n__nD7ok6hgP03ojk=l?na_nCo/KoT00Ko/KoT1?nc^=d4ok77jPSo];cO0ond]]X6
okFnh@Ko][SK00?o][oQokNifong^M/01ong^M/3ok6fg0Go^;[K00?o0000ok2gg_n`]mh01?n`]mh0
0ong^]_o[kWQojnih@06ojnih@CoZKgX1On]_>DFooooo`;o00001?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg02cooooo000Zooooo`?o0000J_ooool4ojVbgPOoZk7M1_n[/=/2ojbni`So[KWR1?n^]Mh4
ojg:k`Oo[koU1?na^=h5ojk=l0So/KoT00?o/kSMok77j_naanX01OnaanX8okBlg`03okBff_ne_^7o
]KkQ00Go]KkQ1?nf^=/4okJoh@Wo]kWK00?o/KKLokRjfonh^]/01?nh^]/00ol0003o/;ONok2ggP03
ok2ggP?o]k[K2?n_^N400onY_NSo[KcUojfli@06ojfliA?ooooo0_l000000ooooooo0000ooooo`03
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0;?ooool002Sooooo0_l0001[ooooo`OoZK;N1on[/Md2
oj^`f`Ko[;kW2?n]^N800on^]Mko[L[_ojg:k`05ojg:k`Oo[koU00?o/KSNojk=l?n^cO001_n^cO06
ok6oi003ojKFn?naan[o/LOZ00Ko/LOZ1_nd_=l2ok3<k`Wo]KkQ00?o][SKokJohOnf_n401Onf_n47
okNif`03okNoh?nh^]_o^;[K00Go^;[K00Co0000ok2gg_n`]mko/;ON1_ng^]/6ojnih@03okBjgOn]
_>Go[KcU00So[KcU5_ooool00ol0003oooooooooo`0booooo`009Oooool3o`0006_ooooo00?oZ;?P
ojVbg_nY/]h01_nY/]h6oj^ag@;oZlG]2?n/_^L6ojfihP03ojODmon]b^oo[L[_00Ko[L[_1_n__nD3
oj;GnPOo[/g`1?na_n@4ojKFn0So/LOZ0_nd_=l6ok3<k`Oo]KkQ00?o[lk`okJohOnf_n401_nf_n44
okNif`Go]koP1Onh^]/2o`000003okRjfon`]mko]k[K00Ko]k[K1?n_^N44okBjg@So[KcU00?o/;[Q
ooooooooool05?ooool00ol0003oooooooooo`0booooo`008oooool2o`0006_ooooo1OnX/n08ojVb
gP;oZk7M1_n[aNd8ojbni`;o[KWR1OnWe?L8ojg:k`;o[koU1onReoX7ojk=l003ok6oi?nVe_SoY]Kh
00GoY]Kh1_naanX2oi_Eo0So/<c_1?ne_^44ojo>l0So][oQ00?o]kWKokNoh?ng_n001_ng_n001onh
^]_o0000o`000?l0003o^;[Ko`000?ni_mh02Ong^]/00on_^N7o];[MokBjg@05okBjg@Co[KcU1On`
^^4Fooooo`03o`000?oooooooooo037ooooo000Pooooo`?o0000J_ooool00onW/n7oZ;?PojRch006
ojRch0KoZK;N0_nYb_48oj_5k@Ko[;kW0_nNfO`7ojODm`Ko[L[_0on@fOl8oj;GnP?o[/g`1On=e_l7
ojKFn0;o/LOZ1_nKeO`8ok3<k`03okFnhOn_c_3o[lk`00Go[lk`1_nf_n400on`cNoo]koPokNoh005
okNoh0?o00000onh^]/2okVogP03o`000?ni_mko]k[K00Ko]k[K00?o^[kMokBjgOnd^]d01ond^]d0
0on]_>Go/;[Qok2jh@05ok2jhAOooooo00?o0000ooooooooool0<?ooool001oooooo0_l0001Yoooo
o`GoYk?Q1onX/n04ojVbgPGoZL[a2?n[aNd2ojbni`KoW]Wl1onWe?L2ojg:k`SoT=Wo0onReoX5ogoE
o`OoSMKo0onVe_P4ogoBo`SoVmGl1_n`c>l2oi?Bo@Oo[lk`1?nf_n44ok3=k`?o]koP0ol00003okNo
h003okRjfoni_mko^KoN00?o^KoN00?o0000okVog_ng^]/00ong^]/4okZng@Oo];[M00?o^[gLok2j
hOn`^^401_n`^^4Gooooo`03o`000?oooooooooo033ooooo000Oooooo`03o`000?oooooo000006Go
oooo00?oY[?RojNchOnW/n401_nW/n47ojRch003ojVbg_nYb_7oZL[a00KoZL[a1_n[aNd2oiSLoPSo
W]Wl0onWe?L5ohSJo`OoT=Wo0omke?h7ogoEo`?oSMKo1Omdcol6ogoBo`SoVmGl0_n`c>l6oi?Bo@Oo
[lk`00?o][oQok3=kon`cNl01?n`cNl3o`0000Go]koP00?o/lW[okVog_ni_mh01Oni_mh00ol0003o
^KoNokNjf`07okZng@Go];[M0onj_M`8ok2jhAOooooo00?o0000ooooooooool0;oooool000cooooo
1Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool01?l0003oooooooooool0001Qoooo
o`GoY[?R1onW/n46ojRch0?oYlkd2?nYb_42oj_5k@KoV=cn1_nNfO`3ohGKoPSoR=[o0_n@fOl7og_D
oP?oOmGo1Omjc?l7ogC?o`KoOm;o1?nKeO`5ogO=o`OoTm;m0on_c_04oi7@o@?o/<g_0ol000000on`
cNoo]koPokNoh002okNoh0Go/lW[1_ni_mh00ol0003o]/CUokZng@07okZng@?o];[M1_nj_M`6ok2j
h@03okJmg_oooooooooo01Kooooo00?o0000ooooooooool0;_ooool000cooooo00GoV9RHob4Q8Oo^
k^koooooodA4A003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool2o`0000;ooooo00?o0000
ooooooooool0Foooool00onU/^7oY[?RojJchP06ojJchPOoYk?Q0_nX/n07ojO>m0KoZL[a0onFg_h7
oiSLoP;oW]Wl2?n5foh3ohSJo`KoPM?o0omke?h5oh_7o0OoN/co0omdcol5oh34o@KoKlSo2?mgcOl3
oi?Bo@CoL/Wo1_nAd?d3o`0000Go/<g_00?o]koPok?9joncbN/01_ncbN/5okVogP03okK4iOl0003o
]/CU00So^[kM00?o];[MokZmg?nj_M`01Onj_M`4ok2jh@Co][gN5oooool00ol0003oooooooooo`0^
ooooo`001?ooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo
410@00Gooooo0_l00004ooooo`03o`000?oooooooooo05Oooooo1OnU/^47ojJchPKoYk?Q0onWcoD8
ojO>m0;oZL[a1onFg_h3oiSLoPKoQmcn1?n5foh5ohkAoPKoPM?o0_nH`_@8oh_7o0?oN/co1?nC_o@8
oh34o@OoKlSo0omgcOl5ofg3oPKoL/Wo0_nAd?d3o`0000;oTM3m0on`cNl4oiK?n`So/lW[0oni_mh4
okK4i@03o`000?nfa>Go^[kM00Go^[kM00?o^L;QokZmg?nj_M`01onj_M`00on`^^7o][gNokJmgP05
okJmgQOooooo00?o0000ooooooooool0;Oooool000kooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0
003ooooooooooooooooo000000Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1C
ooooo`03oj>`hOnU/^7oYK;Q00KoYK;Q1onV/n82ojNch@OoYloe1_nWc_@3oiKPoPKoU]kn0on<gOh7
ohOLoP;oUlgj2?n>dOh2oh7Co`KoV<;d1_n;ao`00onQ_>coTkodoi>om006oi>om0KoP<Cm0_nK_?08
oh>mn@OoKL?n1OmbbOl2o`0000;oTM3m1?mba_l7oiK?n`So/lW[00?o^KoNokK4iOnfa>D00onfa>D0
0ol0003o]/CUokZng@03okZng@Co^L;Q1onj_M`00onk`Mko][gNokJmgP07okJmgQOooooo00?o0000
ooooooooool0;?ooool000oooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo
000000Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1?ooooo`GoXk3Q1onU/^46
ojJchP?oY/oe2?nWcoD2ojO>m0OoU^3n0_nFg_h8ohcMoP;oQmcn1_nGcOX6ohkAoP;oX[o^2?nH`_@2
oh_7o0GoXKc/2?nC_o@2oh34o@KoVkc`2?n3_OT3ofg3oPCoPkWg00CoJkono`000?l0003o00000om[
_oh6og;6o`OoU/ok1?ncbN/3oj3>n0Oo]/CU00?o0000okK4iOnj_]d01oni`^44okZmg0Co^l7N1onf
_Mh00onk_mgoooooooooo`0Dooooo`;o0000;_ooool0013ooooo00Go0000oooooooooooooooooa0@
4003ooooo`03oa0@4?oooooooooo00?ooooo0_l00007ooooo`03o`000?oooooooooo04_ooooo00?o
XZgPoj>`hOnS/>401_nS/>47ojFbh@;oY[?R1onVcoD6ojO?m@?oVN;m1_nFh?h4oi?NoPCoS=gn1?nN
bOH8oiO=nP;oS]7n1_nR_nh6oiS2m003ojJhi_nQ_>coXKc/00KoXKc/1_nC_o@2ojFhi`SoVkc`1_n3
_OT2oijkk@CoPkWg0ol00007of^ooPKoL/Ko0onFco/4ogK4oPOoX<kh1onfa>D00ol0003o^L;QokW2
h@07okW2h@03okZmg?nk`Mko^l7N00Go^l7N1?nf_Mh4ok^ogAOooooo00?o0000ooooooooool0:ooo
ool000cooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04Oooooo1OnR[N08oj>`h@GoYK;Q
0onVcO@8ojK?m@;oYloe1onIh_d2oiKPoPOoTmkn00?oXlOcoik9m_nNbOH01_nNbOH6oiO=nP;oYKcY
2?nR_nh2oiS2m0GoY[SV2?nQ_>`2oi>om0KoYKSW2?nK_?02oh>mn@KoW[_]0ol00004oh>im`?oJkon
1?mo]oL6ofRlo@OoM/Cn1onPc_P4okK4i@?o[Lga00?o0000okW2hOni`^401Oni`^400onea^Oo^l7N
ok_1gP07ok_1gP03okJmg_nk_mgo^koM00Go^koM5_ooool00ol0003oooooooooo`0[ooooo`003?oo
ool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool0@oooool00onPZmooXZgPoj:]h006oj:]h0So
Xk3Q00?oYK;QojK=m?nVcO@01OnVcO@6ojK?m@?oW>?m1_nIh_d4oiWOoP?oTmkn1OnSao<8oik9mP;o
Ulgj1_nU_>T6oj:okP03ojRfhonV^>KoY[SV00KoY[SV1_nQ_>`2ojVfhPSoYKSW1_nK_?02ojNgi@Co
W[_]0ol000001?nN^ngoPkWgoh>imon3^OL4oifjk@OoOkOg1_mX_?d7ogK4oPOoX<kh00?o]/CUojg=
lOn]cO400on]cO400ol0003o[LgaokW2h@03okW2h@Co]LKW1onk`Mh00onj`n7o^koMok^og@07ok^o
gAKooooo00?o0000ooooooooool0:_ooool001kooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0oooooo`GoX:_O2?nR[N06oj>`h@;oY/Wb2?nVcO@2ojK?m@SoW>?m00?oVN;moiWOo_nI
goh01OnIgoh00onVao7oXlOcoj?7l`06oj?7l`KoW/Wf00?oY[WWojFljOnU_>T01onU_>T2oj:okPGo
Z;KS2?nV^>H2oj6lk0KoZKKR2?nU^>L2oi^ll0KoYkOU0ol00003oijkk@03ojRhi?nM^^goWK[]00Ko
WK[]1omo]oL6ofRlo@?oM/Cn1?mX^_d6oh75o@Oo[Lga00?o0000ojg=lOni`^401onea^L5ok_1gP?o
^/?Q1onk_md00onm`]koooooooooo`0Eooooo`03o`000?oooooooooo02Wooooo000Mooooo`?o0000
2oooool00ol0003oooooooooo`0looooo`03oijYg_nPZmooX:_O00GoX:_O2?nR[N02oj>`h@KoY/Wb
1_nVcO@3oj3So0OoW>?m1?nNhOd2oiWOoPGoY/Oa2?nSao<2oik9mPGoY[WW1onU_>T00onY]N7oZ;KS
ojRfh`06ojRfh`KoY[SV00?o[;SRojVfh_nY]^801onY]^86ojFhi`03ojfhh_nW]nGoYkOU00?oYkOU
0ol000000onW]nGoW[_]oijkk@05ojRhi0SoWK[]0omo]oL4oiVjk`OoMkGi1_mX^_d6oh75o@Ko[Lga
00?oUlWio`000?nea^L01onea^L3ok_1gPKo^/?Q1Onk_md3okg2gQKooooo00?o0000ooooooooool0
:Oooool001gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0hooooo`GoWZWN1onP
Zml6oj:]h003ojG3konVbO;oY/Wb00OoY/Wb0_nVcO@8oj3So0;oW>?m1_nNhOd2ojO7l0OoY/Oa1_nS
ao<2ojNhi@OoY[WW1?nU_>T4ojVeh@SoZ;KS0onV^>H4ojbhhPWoZKKR0_nU^>L5ojfhhP04ojNgiOl0
003o0000o`0000?oYkOU00?o[k[RojRhi?nX^>@01_nX^>@6oifjk@03ojRiiOnI^^ooVK[_00KoVK[_
1omg]OT6ofRjo@KoPLGm0_n]cO45oiO9n@03o`000?nea^Oo]LKW00Ko]LKW00?o^l7Nok[3hOnj`n40
1Onj`n43ok^og@Ko_L;N5_ooool00ol0003oooooooooo`0Xooooo`007Oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo03;ooooo0onMZ=h8oijYgPOoX:_O0_nR[N05ojG3k`OoY/Wb0onT
h_`7oj3So0CoX^?l0_nNhOd6ojO7l0OoY/Oa0_nSao<6ojNhi@OoY[WW00?oYKcYojVehOnY]N401OnY
]N48ojRfh`03ojJhi_n/^>;o[;SR00Co[;SR1onY]^800on^_>Co[KSRojfhhP03ojfhhP?o00001?nW
]nD4ojnjhPSoZ;ST0_nM^^d5ojRii@SoVK[_0omg]OT4ohnhlPKoK;Ck1_m^^od6oiO9n@03o`000?nG
bOWo]LKW00Go]LKW00?o[<_`ok[3hOnj`n401onj`n400onk_mgo_L;Nokg2gP05okg2gQOooooo00?o
0000ooooooooool09oooool001gooooo0_l0000?ooooo`03o`000?oooooooooo02gooooo00?oWZ[O
oifXg_nMZ=h01OnMZ=h7oijYgPKoX:_O0_nT^nX7ojG3k`CoY/Wb1onTh_`2oj3So0KoX^?l0_nYbO08
ojO7l0GoY/Oa0_nW]n@8ojNhi@GoY[WW0_nY]^88ojVeh@KoZ;KS00?o[;[Tojbhh_n/^>801_n/^>84
ojVfhPCo[[cT0_n]^>82o`0000Co[KSR00?oYkOUojnjh_n_^^801On_^^86ojRhi003ok2lh_nX^NGo
Z;WU00KoZ;WU1_nI^^l00onV^NOoSkSbohnhlP06ohnhlPKoK;Ck1_m^^od6oiO9n@04o`000?nGbOWo
]LKWokG6i`Go[<_`1onj`n400ongaNGo_L;Nokg2gP07okg2gQKooooo00?o0000ooooooooool09ooo
ool001gooooo00?o0000ooooooooool03oooool2o`0002[ooooo1OnNZ]l7oifXgPOoWZWN0_nPZml6
ojBkjPOoYL?_00?oY/WbojCRo?nTh_`01_nTh_`3ojGVn`CoX^?l1OnYbO08ojO7l003ojK7lOnW]nCo
YkOT00CoYkOT2?nW^>D00onV^NOoZKKRojVfhP04ojVfhPSoZKGQ0_nX]^<5ojbji0So[;SR00?oZKKR
ojjli?n^_>@00on^_>@3o`0000Go[KSR00?o[koUojnjh_n_^^801_n_^^84ojRhi0Co/;cR2?nX^ND2
oiVjk`GoY[WW2?n?^?86ofbdn`KoK[_m1?nGbOT2ogjon`03o`000?n/bo3o[<_`00Ko[<_`1?nj`n44
okO5i@Oo_L;N00?o_LCOooooooooool05Oooool00ol0003oooooooooo`0Vooooo`007Oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo02Gooooo00?oXJoRoijZgonNZ]l01OnNZ]l7oifX
gPGoWZWN0_nQ]>H8ojBkjPGoYL?_1?nWh?/3ojCRo0SoYNKk00?oX^?lojW9l?nYbO001OnYbO06ojO7
l0WoYkOT1_nW^>D00onY]n?oZKKRojVfhP06ojVfhPKoZKGQ00?o[;gVojbji?n/^^@01_n/^^@6ojbh
hP04ojbnion^_>Co[[cTojjli0?o00000_n^_>@4ojfhhPCo[koU2?n_^^800onX^>Co/;cRok2lhP05
ok2lhPKoZ;WU00?o/;cRojJiionV^NL01_nV^NL6ohnhlP;oX;[[1omn/_H5ofNcn`KoO[ok00?o0000
ojc;l?n/bo001_n/bo000onj`n7o]lGUokO5i@04okO5i@Co_L;N1Onma=lGooooo`03o`000?oooooo
oooo02Gooooo000Mooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool08Oooool5oj6_
hPKoWZ[O2?nMZ=h00onNZMkoXKCVoj6diP04oj6diPSoY;_Z00?oYL?_ojOPnonWh?/01OnWh?/3ojSW
nPOoYNKk0_n/cO88ojW9l0;oYlO`3OnW]n@2ojNhi@GoZKOS2?nY]^82ojVeh@Go[;gV2?n/^^@2ojbh
hPCo[;kW0ol00006ojjli003ojfhh_n__nGo[koU00Go[koU1_n_^^800on__nKo/;cRok2lhP06ok2l
hPCoZ;WU1?n`_>88ojJii`;oSkSb1_nP^^/7ogjbmPGoIk?k1Omn_o/00ol0003o[<_`ojc;l004ojc;
l0;oVlKe2?ngaND00onm`]ko_LCOokg4g`05okg4gaOooooo0_l0000Vooooo`007?ooool3o`0001Co
oooo00?o0000ooooooooool07Oooool00onS]^KoXJoRoj6_hP06oj6_hPKoWZ[O1_nMZ=h00onN[n?o
XKCVoj6diP06oj6diPKoY;_Z0onZg?T4ojOPn`OoZ>Oj0_nUi_/6ojc=lPKoZLW`00?oYkSUojNgi?nW
]n@03?nW]n@00onX]nCoZKOSojVgh`06ojVgh`KoZKKR00?oZKgXojbmi_n/_NH01_n/_NH6ojbji004
ojZnjOn/_^Oo[;kWojbni`?o00000_n/_^L6ojjli003oj^oj?n__nGo[koU00Oo[koU0_n_^^85ojno
iPSo/;cR00?oZ;WUok2lh_n`_>801On`_>86ojJii`03ojjki?nP^^_oX;[[00OoX;[[0omn/_H3oi6g
l@CoJjoi0_mW/o/5ogjon`03o`000?n/bo3o[<_`00KoVlKe1_ngaND00oncanWo_LCOokg4g`07okg4
gaGooooo00?o0000ooooool000009_ooool001cooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`0Iooooo`GoXkKV2?nQ[n86oijZg`;oWJSN1OnN[n<8oj6diP;oY;_Z2?nZg?T00onWh?_o
Z>OjojSWnP05ojSWnP?o[mCc1on/cO82ojW9l0GoYkSU2_nW]n@5ojRgi0SoZKOS0_nY]^85ojVmj0So
[;gV0_n/^^@4ojZnj@?o00001_n/_^L2ojjli0GoZkoX1on__nD00on[`>Wo[koVojnoiP06ojnoiPKo
/;cR00?o/<3Vok2lh_n`_>801on`_>82ojJii`Go[[_T1onP^^/00onY^nOoTKOaoi6gl@05oi6gl@Ko
Jjoi1Oma]o/00ol0003oVlKeoi_6m@05oi_6m@Co]lGU1?ncanT7okg4g`03okc5hOoooooooooo01Ko
oooo00?o0000ooooooooool08oooool000[ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`00
0?lb<S;ok^k^1_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01Kooooo0_nU^^P6
oj>fiPSoXJoR0onNZ]l2oib[h@SoWZoS1_nQ]>H3ojSDm`OoZ]ci1?n/j?X2ojSWnPOo[mCc1On/cO82
ojNjiPOoYkSU1onW]n@8ojRgi0KoZKOS00?oZ;gXojVmj?nY_NP01_nY_NP6ojbmiP04ojVoj_nZ_^Wo
Z[kYojZnj@?o00000_nZ_^T6ojbni`03ojW0j_n[_nSoZkoX00KoZkoX1?n__nD4oj_0j@So[koV0_n`
_>85ok30iPOo/;cR00?o//7Uojjki?n^^n@01_n^^n@4oj2jj`CoZK_W1_nA]o47of^_n@CoLKOk00?o
0000og6gnonKa_D01_nKa_D00ongaNGo/lOYok?7j@05ok?7j@Co_LCO1?nlaN4Gooooo`03o`000?oo
oooooooo02?ooooo000<ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`06ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool04_ooool6ojFjj0KoXkKV1_nQ
[n800onJZ>3oW:_Qoib[h@04oib[h@OoWZoS1?nQ]>H7ojSDm`;oZ]ci1_n/j?X3ok7LmPSo[mCc00?o
[<gbojNji_nW^^H01?nW^^H7ojNhi@OoYkOT2?nX]n@2ojVgh`GoZ;gX2?nY_NP2ojbmiPCoZKoZ0ol0
0006ojZnj@;o[;kW1OnY`>X8oj^oj003ojnoiOn[`>WoZl3Y00GoZl3Y1_n__nH00on[`>Wo/<3Vok30
iP06ok30iPCo/;cR1?nb`ND8ojjki003oj2jjonY^nOoZK_W00CoZK_W1onA]o47of^_n@CoLKOk00?o
0000og6gnonKa_D00_nKa_D4ohZnn0So/lOY00?o_LCOokc5hOnlaN401OnlaN4Gooooo`03o`000?oo
oooooooo02;ooooo00000ooooooo0000o`000004o`0000Gooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@00Kooooo0_l0000Iooooo`03o`000?oooooooooo00kooooo0_nW
_^X8ojFjj0KoXkKV0_nQ[n85oiZXh0KoW:_Q1onN[n<00onQ]>KoZ=CgojSDm`06ojSDm`?o[nKi1?n/
j?X6ok7LmPKo[mCc00?oZ;gXojNji_nW^^H01_nW^^H5ojNhi@;oY[KT1onW]n@6ojRgi0;oZ;gY1onX
_NP6ojVmj003ojRoj_nY_n[oZKoZ00;oZKoZ0_l00002ojVojPKoZ[kY00?oZ;o[ojW0j_nY`>X01_nY
`>X6oj^oj0;oZL3Z2?n[`>T2ojnoiPGoZl3Y2?n``>H00on`_>;o//7Uok;1i@05ok;1i@Ko[[_T00?o
/koTojVkionY^nL01_nY^nL3oi6gl@CoW[_]1omh[_D4ofZ`n@03o`000?mZ/?WoR[kh00KoR[kh1_nc
anT00on[a^go_<GQokc5h@07okc5hAOooooo00?o0000ooooooooool08Oooool000cooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0:ooooo`KoYkkZ2?nU^^P3oj>fiP[oVZSP1_nLZn45oij_h`?oYLOa1OnX
e?L7ojoVn@03ojcXn_nag?Ko/Mcf00Ko/Mcf0_n_e?<5ojRmj0SoYk[V00?oYkSUojJfi?nV]^@01?nV
]^@7ojNgi0;oZ;OT1_nX_NT7ojRmj0;oZKgX1OnX_nX3o`0000GoZKoZ0_nZ_^T5ojRoj`SoZL3Z0_n[
_nP6ojW0jPKoZl3Y00?oZL3Zoj_0jOn[`>T01_n[`>T6ok30iP03ojc0jOnb`NGo//7U00Oo//7U0_n^
^n@5ok>oi0KoZK_W00?o[kkUoijkkOnN^nd01_nN^nd7ogR^m@CoJ[3i00?o0000ofZ`nOn:__P01_n:
__P2ok?7j@GoZlK]1onlaN400onja^?oooooooooo`0Eooooo`03o`000?oooooooooo027ooooo000<
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool01oooool3ojS1j`KoYkkZ1_nU^^P00onO/>?oVZSPoiZX
h00;oiZXh0OoW:_Q00?oWZoSojG7lOnUao401_nUao400onXe?Oo[nKiojoVn@06ojoVn@?o/nCg1_na
g?H00onZ`^_oZ;gXojRmj006ojRmj0KoYk[V00?oYKCTojJfi?nV]^@01_nV]^@5ojNgi0;oYkgY2?nX
_NT5ojRmj0;oZ;o[0onX_nX3o`000003ojRoj_nY_n[oZKoZ00CoZKoZ00?oZ;kZojRojonX_n/01_nX
_n/6ojW0jP;oZ;kZ2?nY`>X2oj_0j@GoZL3Z2?n[`>T2ok30iPGo[<3Y1onb`ND00on^`NOo/koTok>o
i005ok>oi0CoZK_W1?n__^D8oijkk@?oN:ke0on6/o<4ofV/m`03o`000?mZ/?WoJ[3i00?oR[kh0omn
]oP8oj_6k@Co_<GQ1?nja^<Gooooo`03o`000?oooooooooo023ooooo000<ooooo`03o`000?oooooo
oooo00;ooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool00oooool7ojS1j`KoYkkZ0_nU^^P5oin`h`goVZSP0onLZn45oj:jjPKoYLOa0ona
h_P5ojoVn@Ko/nCg0_nag?H5oj[2j`SoZ;gX0_nW^^H5ojFdi0SoY[KT00?oYkOTojNmjOnW_NT01?nW
_NT8ojRmj@03ojRmj?nX_n_oZ;o[00?oZ;o[0ol00005ojRojP;oZKoZ1OnX_^X8ojRoj`;oZL3Z1_nX
_^X6ojW0jP03ojRnjOnY`>[oZL3Z00KoZL3Z1_n[`>T00onY`>[o[<3Yojc0j@06ojc0j@Co//7U1?n^
`NL7ok>oi003ojVkion__^Go[kkU00Go[kkU1_nN^nd00onU_>WoQ[?cohJcl`05ohJcl`CoJJcg00?o
0000ofV/momn]oP01_mn]oP8oj_6k@03okc5hOnja^?o^/KS00Co^/KS6?ooool00ol0003ooooooooo
o`0Oooooo`003?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2o`0001kooooo00?o0000oooooonX`N`00_nX`N`8ojS1j`?oYkkZ0onR]nL7oin`h`_oVZSP0_nM
/ND8oj:jjP?oYLOa1onah_P00on_i_Wo/nCgok?Tm`05ok?Tm`;o[LW^1onZ`^/6ojRmj003ojBchonU
]>CoYKCT00KoYKCT1_nV]^@00onW_>WoYkgYojNmj@06ojNmj@KoZ;gY00CoYko[ojRojonX_n_oZ;o[
0ol00002ojRoj`GoZ;oZ0_nW_NT7ojRnjPKoZ;o[00?oZ;gXojRnj_nX_^X01onX_^X2ojW0jPGoZ;kY
2?nY`>X2oj_0j@GoZL3Z2?n/`>T00onb`NGo[/7Wojk1i`04ojk1i`Ko/koT00?o//;UojnniOn__^D0
1on__^D2oijkk@GoYKcY1on6/o<4ofV/m`03o`000?mY[?OoO[Oh00KoO[Oh1_n[a^d00onS`o3o^/KS
ok[6h`06ok[6haOooooo00?o0000ooooooooool07oooool000[ooooo00?oEEEEofIVI_l000001?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool07?ooool7ojS1k0KoZ<7[
00?oYKcYoj:gionR]nL01OnR]nL6oin`h`SoVZSP1_nM/ND8oj:jjP03ojG7lOnah_So/N;h00Go/N;h
1?nfj?H2ok?Tm`Ko[LW^1onZ`^/2ojRmj0GoY;?S2?nU]>@2ojJfi0GoYkcY2?nW_NT2ojRmj@CoYko[
0ol00006ojRoj`03ojRoj_nW_NWoYkgY00CoYkgY1onX_^X2ojRoj`GoZ;gX1onX_^X00onY_NSoZ;kY
ojRnj@06ojRnj@KoZL3Z00?oZ;kYojW0j_nY`>X01_nY`>X6ojc0j@;oZ/7Z1on^`NL2ok>oi0Go//;U
1on__^D00onc`>CoYKcYojFlj@06ojFlj@OoQ[?c1?mY[?L00ol0003oJJcgogjgn006ogjgn0;oZlK]
1OnS`o06ok[6h`03okW6iOoooooooooo01Kooooo00?o0000ooooooooool07_ooool001_ooooo00?o
0000ooooooooool06_ooool3ojJoj`OoZ<7/0_nX`N/5ojFlj@OoX[OW1_nO/><3oiZXh0?oVJ_S2?nM
/ND6oj:jjP?o/=[f1?nah_P6okKXmP;o]=Ca1on]bNh5oj[2j`;oY;CT1onT/n<6ojFdi003ojJljOnW
_>WoYkcY00KoYkcY1_nW_NT4ojNoj`?o00000_nW_n/6ojRoj`03ojNlj?nW_NWoYkgY00KoYkgY1OnX
_^X00onY_>SoZ;gXojRmj006ojRmj0CoZ;kZ1?nY_NP8ojRnj@;oZL3Z1OnX_^T8ojW0jP;o[<3Y1_nZ
`NX5ojk1i`03ojc1jOnb`^Go//;U00Ko//;U1?n__^D4ok?0i0SoYKcY0on6/o<4oi6gl0?oK:Wf00?o
0000ofbYm_m/ZOH01_mg/OL7oj?3l0Co^/KS1?nia^DHooooo`03o`000?oooooooooo01gooooo000K
ooooo`03o`000?oooooooooo01Oooooo1onV_n/5ojS1k0;oZ<3[1onU_>T7oj:gi`?oWk3S0_nGYn47
oiV[h`SoWK7U0_nR^^X7ok3JmP03ok7Rn?nfj?Ko]^Sf00Co]^Sf1Onde?47ojg9kP03oj[2jonT]>Co
Y;CT00CoY;CT1onT/n<2ojFdi0GoY[cY2?nW_>T2ojNmj@CoYko[0ol00006ojNoj`;oZ;o[1OnW_>P8
ojNmj@03ojRnj_nY_>SoZKcX00?oZKcX2?nX_NP00onX_^[oZKgXojVmj005ojVmj0KoZ;kY00?oZ[kX
ojRnjOnX_^T01_nX_^T6ojW0jP;oZ;oZ2?nZ`NX00on^`NOo[<7Yojc1j@03ojc1j@So//;U00?o[kkU
ok?0i?nc`>@01Onc`>@6ojFlj@;oZkkX1onA]o03ofbYmP03o`000?m/ZOKoK:Wf00KoMk7g1onS`o00
0onja^?o^LKUokW6i@05okW6iAKooooo0_l0000Oooooo`006oooool2o`0001Cooooo1OnW_n/7ojJo
j`03ojS1k?nX`>_oZ<3[00CoZ<3[1onU_>T5oj:gi`03oiVZhonGYn7oUjOQ00CoUjOQ1onIZn<6oifa
i@?oZ<_b1_n`f_H4okOWmP;o]^Sf2?nde?43ojg9kP?oY[SV2?nT]>@5ojBch`;oYK_X1onV_>T6ojNl
j@GoYko[0_l00008ojNoj`WoYkcX1_nW_NT00onY_NSoZKcXojVlj005ojVlj0KoZ;gX0_nZ_^P8ojVm
j0;oZ;kY1OnZ_^P8ojRnj@;oZL3Z1_nX_nX6oj[1jP03ojS0jon/`NWo[<7Y00Go[<7Y1_nb`^D2ok32
i`So/l3T0_nU_>T6oj^nj0OoTKO`0om/ZOH00ol0003oK:WfofbYmP06ogNam`?oXl?`0onK__49okW6
iAOooooo00?o0000ooooooooool07?ooool001[ooooo00?o0000ooooooooool04?ooool:ojNoj`Go
Y[o[0_nX`N/7ojS0j`OoYKcY00?oX[OWoiVZhonIZ^<00onIZ^<6oiNWh@OoVJ_S0_nM/ND8ojS;lP03
ok3Jm_ngioKo]nOf00Go]nOf0onjhO<6okCDl@03ojVojOnV^>KoY[SV00GoY[SV2?nT]>@00onT/n?o
YK_XojFkj004ojFkj0OoY[cY0_nW_>T5ojNoj`?o00001onW_n/=ojNlj0;oYkgY1OnY_NP7ojVlj0;o
Z;gX1_nZ_^P6ojVmj003oj^ojOnZ_^SoZ[kX00KoZ[kX1_nX_^T2ojZnj0SoZ;oZ0_nZ`NX5ojS0j`Oo
[<7Y0_nb`^D6ok32i`Ko/l3T0_nd`nD8oj^nj0?oTKO`0onH^Nl4og2Ym003o`000?m`ZOCoM:ge00Go
M:ge1onK__47okW6i@;o]lKV5_ooool00ol0003oooooooooo`0Looooo`006_ooool00ol0003ooooo
ooooo`0=ooooo`koYko[00?oY[o[ojS1jonX`N/01?nX`N/7ojS0j`?oYKcY0onO]>H7oiVZh`KoUjOQ
1OnIZn<3oj6ijPOoZ<_b0ongh_D4okOWmPKo^^7c0onde?44ojVoj@OoY[SV1_nT]>@00onS]nOoYK_X
ojFkj006ojFkj0GoY[cY1OnW_n/3o`0000OoYko[3onW_>P00onX_^WoZKgXojVmj006ojVmj0GoZKcX
0onY`>X7ojZnj0;oZKgX1On[_nT8ojZnj0;oZ;kY1_nZ_^P6ojRojP03ojVnjOnX`>_oZ<3[00GoZ<3[
1_n/`NT00onZ`N[o/<;Wok32i`07ok32i`;o/l3T1_nd`nD6oj^nj003ojk1ionH^NooV;W_00GoV;W_
0om`ZO@00ol0003oL:Wdog2Ym006ogB]m@OoVkka1?nia^D5okO6iQKooooo00?o0000ooooooooool0
6oooool001[ooooo00?o0000ooooooooool02oooool2ojS0j`koYko[2?nX`N/5ojS0j`;oXk[Y1_nO
]>H7oiVZh`KoUjOQ00?oVJ_Soj6ij_nQ^NX01OnQ^NX4ojS;lPOo]n;e00?o]nOfok[QlonjhO<01_nj
hO<00onde?7oZKoYojVoj@04ojVoj@OoY[SV0_nT]>@5oj>gi`SoYK_X00?oY[cYojNojonW_n/00onW
_n/3o`0000OoYko[3onW_>P5ojRnj@SoZKgX00?oZKcXojW0j_nY`>X01OnY`>X5ojZnj003ojW1jon[
_nWoZkoY00KoZkoY1_nZ_^P00on[`>WoZ[kXojZnj007ojZnj0;oZ;oZ1OnY_^T7ojS0j`;o[<7Y1OnZ
`NX7ok32i`03ojg1jOnd`nGo]<?U00Oo]<?U0_n[_^P5ojk1i`OoV;W_0om`ZO@00ol0003oL:Wdog2Y
m006ogB]m@OoVkka00?o^LKUokO6i_nga^H01_nga^HFooooo`03o`000?oooooooooo00Kooooo1Ol0
000?ooooo`006_ooool2o`0000Wooooo1_nX`>/>ojNoj`SoZ<7[00?oZ<3[oj>jjOnS^^T01?nS^^T6
oindiPOoVJ[S0onGYn43oiZ_i@SoXKWZ00?oZ<_bokORmOngh_D01_ngh_D3okgVl`Ko^^7c0_n^b>d7
ojVoj@GoY[SV0_nQ]>D7oj>gi`KoYK_X00CoYkk[ojNojonW_n_oYko[0ol00007ojNoj`ooYkcX2OnX
_^T6ojVmj0;oZ<3[2?nY`>X00onZ_^SoZL7[ojW1j`03ojW1j`SoZkoY0_nZ_^P5oj_0j@OoZ[kX00?o
Zl3YojVnjOnY_^T01_nY_^T5ojS0j`03ojRoj_nZ`N[oZ/7Z00KoZ/7Z1?n``^L4ojg1j@Oo]<?U00?o
/l?Vojk1ion^`NL01On^`NL6oiRik`03oifkk_mdZ?;oM:Sb00;oM:Sb00?o0000og2Ym?m`ZO@01_md
[OD3oi^nl@CoUk[`1onga^H00onfa^Koooooooooo`0Dooooo`03o`000?oooooooooo00Kooooo00Go
V9RHob4Q8Oo^k^koooooodA4A00?ooooo`006_ooool00ol0003oooooooooo`06ooooo`;oZ<7[1onX
`>/5ojNoj`;oY[o[1onW_n/6ojS1j`;oYko[1onS^^T6oindiP?oVJ[S0onFZ><7oiZ_i@KoXKWZ0onc
f?<5okORm@Ko_NKc0_njhO<6ojk8k@OoZKoY00?oY[SVoj6diOnQ]>D01?nQ]>D7oj>gi`;oYK_X1?nW
_^/3o`0000OoYko[3onW_>P=ojRnj@;oZKgX1_nX`>/6ojW0jP03ojO1k?nY`N_oZL7[00GoZL7[1_n[
_nT00onX`N_oZl3Yoj_0j@06oj_0j@CoZ[kX1?n[`>T8ojVnj@03ojS0jonX_n[oZ;oZ00?oZ;oZ2?nZ
`NX00on``^Oo[L7Yojg1j@05ojg1j@Co]<?U1?nc`nH7ojk1i`;oV;W_1OnM^nh3ogBXlP03o`000?md
Z?;oM:Sb00KoLjWc2?nG^_04okO6iPCo]/KV5_ooool00ol0003oooooooooo`06ooooo`03oiRHV?lQ
8B7ok^k^013ooooo000Jooooo`03o`000?oooooooooo00?ooooo1_nX`N/7ojS0j`03ojNojonV_n_o
Y[o[00CoY[o[1onW_n/2ojS1j`KoYko[1onS^^T3oindiP;oUJSS1onFZ><7oiZ_i@?oXKWZ1oncf?<0
0ongh_Go_NKcokgVl`05okgVl`?o^=K_1on^b>d3ojVoj@?oXK?U2?nQ]>D5oj>gi`;oY[gZ0_nW_^/3
o`0000;oYkk[1_nW_n/00onW_NWoYkcXojNlj00;ojNlj0;oYkkY3OnX_^T2ojS1k0SoZ<3[0_nY`>X5
ojO1k0OoZL7[0_n[_nT5ojS1j`SoZl3Y00?oZ[kXoj_0jOn[`>T01On[`>T6ojVnj@03oj^oj?nX_n[o
Z;oZ00GoZ;oZ1_nZ`NX2ojW0j`So[L7Y00?o]<?Uok?3i_nc`nH01?nc`nH6ojk1i`;o/L;W1onM^nh3
ogBXlP03o`000?mdZ?;oM:Sb00KoLjWc2?nG^_000onga^Ko]/KVokK6iP04okK6iQOooooo00?o0000
ooooooooool01_ooool00onHV9So8B4Qonk^kP0?ooooo`006_ooool00ol0003oooooooooo`02ojS0
j`SoZ<7[1OnX`>/2ojNoj`OoY[o[1OnW_n/3ojW1j`OoYko[1OnS^^T00onL/NKoUJSSoiFXh`04oiFX
h`OoUZSS1onJ[nD00onQ^N[o/mScok?Hl`05ok?Hl`?o_NCb1?nmi_<6okSFk`Go[/S]0_nT^NL6oj6c
i@SoXKCU00?oXkOWojJmj_nV_NX00_nV_NX3o`0000KoYkk[0_nW_n/5ojNmj@WoYkcX1_nW_^T9ojRn
j@KoZ<7/1_nX`>/9ojO1k0GoZL7[00?oYl7/ojS1jonX`N/01_nX`N/6oj_0j@;oZL7[2?n[`>T2ojVn
j@GoZkoX1onX_nX2oj[1jPKoZL3[1_n]`NT00on/`NWo/l?Vok?3iP06ok?3iP;o[/7W1_na`^L7oifk
kP?oM:Sb00?o0000ogBXl_mdZ?801_mcZO<4oiNjl0?oU;S`2?nfa^HFooooo`03o`000?oooooooooo
00Oooooo00?oMgMgofIVI_ooool03_ooool001Wooooo00?o0000ojS0jonX`>/01?nX`>/8ojS1j`03
ojS0jonW_n_oYko[00CoYko[1onV_n/00onW_n_oZL7[ojW1j`05ojW1j`OoYko[00?oXk[Yoibai_nL
/NH00onL/NH6oiFXh`KoUZSS1_nJ[nD3ojG3k`Co/mSc1onmi?800onmi_?o^=K_okSFk`06okSFk`03
ojk8kOnT^NOoY;WW00CoY;WW1_nQ/nD6oj6di@03ojFkjOnV_N[oY[gZ00?o00000onV_NX5ojNnj`;o
YkkZ1onW_NT6ojNlj0;oYkgY1onW_^T5ojRnj@;oYl7/2?nX`N`2ojS0j`goYl7/00?oZL7[ojO1k?nW
`N`00onW`N`8ojS1j`;oZl3Y1_nY`N/6oj_0j@03oj[1j_n[_nSoZkoX00GoZkoX1_nX_nX2ojVoj@So
ZL3[0_n]`NT5ojc1j@Ko/l?V00?o//?Wok72iona`^L01ona`^L3oifkkPCoW[c]0omgZO800ol0003o
MjWbogBWlP05ogBWlPSoU;S`1onfa^HGooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool03Oooool001Wooooo00?o0000ojS0jonX`>/01OnX`>/6ojS1j`;oYl3[1onW_n/5ojJoj`?oYko[
1onY`N/3ojNoj`?oX[WY1onL/NH6oiFXh`KoUZSS0_nJ[nD7ojG3k`03ok?Hlonmi?;o_NCb00Ko_NCb
0onoho06okSFk`03oj[2jonT^NOoY;WW00KoY;WW1_nQ/nD2oj6di@CoYK_Y0_l00007ojJmjP03ojNn
jonW_^[oYkkZ00CoYkkZ1onW_NT2ojNlj0KoYkgY1onW_^T00onX_^WoYl7/ojO1k004ojO1k0KoZ<7/
3onW`N`2ojK1k0KoYl7/1_nX`N/2ojO1k0SoZL7[0_n[`>T5oj[1jPOoZkoX0_nX_nX6ojVoj@KoZL3[
00?oZ<3[ojc1jOn/`NT01_n/`NT3ok?3iPCo//?W1ona`^L00onba>OoW[c]oijlk@06oijlk@;oMjWb
00?o0000ogNYl_mgZO801_mdYo87oiBhl0So]/KV5Oooool3o`0000Cooooo00Go0000okZj^_oooooo
V9RHoa0@400?ooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooooonX
`>/01_nX`>/2ojS1j`KoYl3[1onW_n/00onV_n_oYko[ojNoj`05ojNoj`GoZL7[0_nV_n/6oj:ij@Oo
W;7V1_nEZ><3oiJXh`CoW;?X1_nU`nl3ok[Ll@Go_NCb1_noho02okSFk`GoZ/;[2?nT^NL3oj6ci@?o
X[SX0_nU^nT3o`0000;oYK_Y1_nV_NX2ojNoj`OoYkkZ1OnW_NT2ojJlj@SoYkgY0onW_^T;ojO1k0;o
Z<7/3onW`N`6ojK1k0KoYl7/0_nX`N/6ojO1k0KoZL7[00?oYl7/oj[1j_nZ`NX01_nZ`NX5oj^oj0;o
[<7Y2?nY_nT2ojW0j`GoZ<3[2?n/`NT00onc`nKo//?Wok;3i`04ok;3i`Co/L;W1?nba>L8oijlk@;o
MjWb00?o0000ogNYl_mgZO801_mdYo87oiBhl0So]/KV5_ooool00ol0003oooooooooo`02ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`03oooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06oooo
o`03o`000?oooooooooo00GoZ<3[0onX`N/7ojO0j`GoYko[0onV_n/7ojNoj`03ojW1jonV_n_oY[o[
00CoY[o[1_nR^NT7oibaiP?oUJSS0onEZ^D7oibcj0?oYL?_1onjg?400onmi?;o_n?`okoSl005okoS
l0?o/lk^1_nZ`^/6ojBii`03oinci_nR^>SoX[SX00?oX[SX0ol00006ojFkj@;oY[gZ1_nW_n/7ojNn
jP03ojNmjOnV_>WoY[cY00CoY[cY1_nW_NTMojO1k0;oYko[2?nV`N`3ojO1k0?oY/3/2?nW`N`2ojW1
j`GoYl7/2?nZ`NX00on[_nSo[<7Yojc1j@04ojc1j@KoZKoY00?oZl3YojS0jonX`>/01_nX`>/6ojc1
j@03oj_1j_nb`nOo//?W00Ko//?W00?o/L;Wok;4ionba>L01Onba>L7oijlk@?oN:Sa00?o0000ogNY
l_mgZO801_mdYo83oiBhl0CoUKK^2?nfa^HFooooo`03o`000?oooooooooo01Gooooo000>ooooo`05
oa0@4?ooooooooooooooool@41001_ooool2o`0000;ooooo00?oZ<3[ojS1jonX`N/01OnX`N/7ojO0
j`03ojNojonV_n_oY[o[00GoY[o[1OnW_n/2ojW1j`OoY[o[1_nR^NT3oibaiP?oTZST1onEZ^D7oibc
j003ojG3konjg?7o^]ca00Go^]ca1?o2ho02okoSl0Oo/lk^1_nZ`^/2ojBii`GoWk?V00CoX[SXo`00
0?l0003o00000onR^>P5ojFkj@[oYko[0onW_^X4ojJkj@OoY[cY0_nW_NTMojO1k0KoYko[1_nV`N`0
0onW_NWoY/3/ojK0k005ojK0k0KoYl7/00?oY/3/ojO1k?nW`N`01_nW`N`6oj[1jP03ojS1jon/`NWo
[<7Y00Ko[<7Y0_nY_nT5oj_0j@SoZ<3[0_n/`NT5oj_1jPKo//?W2_nba>L7oijlk@?oN:Sa00?o0000
ogRXlOmfYO001OmfYO08oiFfkPKo]/KV00?o]lOVooooooooool05Oooool00ol0003oooooooooo`0D
ooooo`003_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00oooool7
ojS1j`?oYl3[1OnW_n/7ojJoj`03ojNojonY`N_oZL7[00CoZL7[1onV_n/3oj:ij@;oVK3W1onBZ>@7
oiFZi@GoW;?X0on]bnl4ok[Ll@Ko`^?`0oo1gnh7ok?>kP?oZ/;[0onP]NL4oinciP?o00001onR^>P0
0onU^nWoYko[ojNoj`0:ojNoj`03ojJljOnV^nWoY[_Y00KoY[_Y1OnV_>T2ojO0ja_oYl7/0_nW_NT8
ojNoj`;oY/7/1OnW_NT7ojK0k0;oYl7/1OnV`>`8ojO1k0;oZ/7Z1OnX`N/6ojc1j@03oj_1j_n[`>Wo
Zl3Y00KoZl3Y1onX`>/8oj_1jP;o//?W3?nba>L00onbaNSoW[c]oijlk@05oijlk@?oN:Sa00?o0000
ogRXlOmhZ?401_mfYO08oiFfkP;o]/KV1OnganHFooooo`03o`000?oooooooooo01Cooooo000>oooo
o`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`05ooooo`GoZ<7[0_nW`>/8
ojNoj`GoY[o[0_nW_n/7ojW1j`GoY[o[0_nQ^NX5oiV`i`OoTZST1onEZ^D00onL/nSo[L__ojg;k`06
ojg;k`03ok[LlOo2ho3o`^?`00Co`^?`1Oo1gnh5ok?>kP03ojRoj_nP]NOoX;GW00GoX;GW0ol00004
oinciP?oX[SX1?nU_NX9ojNoj`GoY[cY2?nV^nT00onV_>WoYl3[ojO0j`04ojO0jaOoYl7/1_nW_NT6
ojNoj`03ojVmj?nW_NWoYkgY00KoYkgY1OnV`>`2ojNnjPOoY/3/1_nW`N`2ojK0k0OoZ<7[0_n/`NT5
oj_1jPSoZl3Y1onX`>/7oj_1jP_o//CW1OnbaNP7oijlk@?oN:Sa00?o0000ogRXlOmhZ?401_mfYO04
oiFfkP?oV;K]2?nganHFooooo`03o`000?oooooooooo01?ooooo000>ooooo`05oa0@4?oooooooooo
ooooool@41001Oooool00ol0003oooooooooo`06ooooo`03ojS1jonW`>_oYl3[00CoYl3[2?nW_n/0
0onV_n_oYko[ojNoj`04ojNoj`OoZL7[00?oY[o[oj6ij_nQ^NX01?nQ^NX5oiV`i`KoTZST1_nEZ^D2
oijfj@Oo[L__0onng>l4ol;Sl0Oo`Mo^00?o/lk^ojRoj_nX_nX00onX_nX3oj2ei`?o000000?oX;GW
oinci_nO/nH00onO/nH2ojBkj@OoYKgZ1_nW_n/00onW_^[oY[cYojJlj@05ojJlj@KoY[_Y00?oYko[
ojO0jonW`>/01_nW`>/5ojO1k0;oZ<;/2onW`N`;ojNmj@;oYko[1OnY_NP8ojNmj@03ojK0k?nW_^[o
YkkZ00CoYkkZ1onV`>`2ojO1k0KoY/3/1OnX`N/00onW`>_oZl7Zoj_1jP06oj_1jPKoZl3Y0_n[`NT7
ojS0j`OoZl7Z2?nba>L8ok;5j0?oW[c]0onM^nh4ogRUk`03o`000?mhYNooNJC^00GoNJC^2?nH]^d6
okO7iP03okW9i_oooooooooo01Gooooo00?o0000ooooooooool04_ooool000kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o00002?ooool7ojO0j`KoYko[00?oY[o[ojNojonW_n/01_nW_n/5
ojW1j`;oY[o[1onQ^NX5oiV`i`KoTZST0_nEZ^D6oijfj@Co[L__1onng>l00oo2ho3o`Mo^ol7OkP05
ol7OkP03ok7;kOnX_n[oZ;oZ00CoZ;oZ0ol00005oj2ei`03oinci_nT^nWoY;_Y00CoY;_Y1onU_NX2
ojNoj`GoYkkZ1onV_>T2ojJkj@GoYko[2?nW`>/00onW`NcoZ<;/ojS2k004ojS2k0KoYl7/3_nW_NT0
0onY_^WoZKgXojVmj006ojVmj0KoYkgY0_nZ_nT7ojNnjP?oY/3/1?nV_^/8ojK0k003ojS1jonW`>_o
Yl3[00?oYl3[2?n[`NX2oj_0j@KoZl7Y1_nX`>/8oj_1jPSo//CW1_nbaNP00onaaNWoWK_^oifkkP05
oifkkP?oN:G_00?o0000ogRUkomhYNl01_miY>h7oiRfk@Co]lOV1?nibNHFooooo`03o`000?oooooo
oooo01;ooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`08
ooooo`OoYl3[0_nW_n/5ojJoj`SoYko[00?oZL7[ojJojonV_n/01?nV_n/7oj6ijPGoVK3W0onBZ>@3
oiB[iPSoW[KY00?o[L__okkLkonng>l01_nng>l3olGQk@Co`Mo^1?nabnd3ojRojP;o00000_nX_nX3
oj2ei`?oW[CX2?nT^nT5ojFmjP03ojNojonW_^[oYkkZ00KoYkkZ1OnV_>T2ojFmjPOoYko[1_nW`>/9
ojS2k0;oYl7/3_nW_NT5ojVnj@SoZKgX0_nW_NT6ojZoj@GoYkkZ00?oZ[oYojJnjonV_^/01_nV_^/6
ojK0k003ojFok?nW`>_oYl3[00GoYl3[1_n[`NX2oj[1jPSoZl7Y1_nX`>/8oj_1jPOo//CW1?nbaNP4
ok75j@OoWK_^0omhYNl00ol0003oN:G_ogRUk`06ogVTkPOoV;K]00?o]lOVokW9i_nibNH01OnibNHF
ooooo`03o`000?oooooooooo017ooooo000Hooooo`03o`000?oooooooooo00Wooooo1OnW`>/3ojNo
j`KoY[o[1_nW_n/2ojW1j`OoY[o[1OnQ^NX00onG/>SoT:SUoi2Xi@04oi2Xi@KoU:_V1_nN]^T3ok;>
kPGo_]c_1_o5hNd00oo1gnko/L_]ok7;k@04ok7;k@?o00000onX_nX8oijdj0SoY;_Y00?oYKgZojNo
jonW_n/00onW_n/8ojNnjP03ojJljOnU_N[oYKgZ00CoYKgZ1onW_n/2ojO0j`_oZ<;/0_nW_^T=ojNm
j@03ojRnj_nY_^WoZKkY00GoZKkY1_nY_NP2ojW0jPSoZ[oY00?oYkkZojZojOnZ_nT00onZ_nT8ojJn
j`;oY/3/1OnU_n`7ojO0j`;oZl7Z1_nZ`NX6oj_1j@03ojc1jOnX`>_oZ<3[00GoZ<3[2?n[`NX7ok;4
i`03ok;5j?naaNWo/LGY00Go/LGY1onM^nh3ogRUk`03o`000?mhYNooN:G_00KoNJC^0onH]^d3oifg
j`Oo^LWV0_nkbnHFooooo`03o`000?oooooooooo013ooooo000Hooooo`03o`000?oooooooooo00[o
oooo00?oYl3[ojNojonW_n/01OnW_n/6ojJoj`;oYko[1_nY`N/7ojJoj`03oj6ij_nG/>SoUk3X00?o
Uk3X1_n@Z>D6oiB[iP?oW[KY1onbc^h00onng>ooaN7]olGQk@05olGQk@?o`]c/0_nabnd3o`0000;o
/L_]00?oZ;oZoijdj?nN]>P02_nN]>P6ojBkj@;oY[k[1_nW_n/6ojNnjP;oYKcY1onU_NX5ojNoj`;o
Z<7/2OnX`^`6ojNnj@WoYkgY1OnX_^X7ojVnj@;oZKgX1_nY`>X6ojZoj@03ojW0j_nZ_nWoZ[oY00Go
Z[oY1_nV_^/2ojRojPOoYKo/1OnW`>/2ojO0k0SoZ/7Z0_n[`NT5ojc1j@OoZ<3[2?n[`NX5ok;4i`;o
/lGX2?naaNT3oifkkP?oVKW^1?mhX^d00ol0003oN:;]ogfTk005ogfTk0OoWKO[1?nibNH5ok_;iQGo
oooo0_l0000Aooooo`005oooool3o`0000gooooo1onW_n/7ojJoj`OoZL7[0onV_n/3oj2jj`OoUk3X
1_n@Z>D6oiB[iP03oijfjOnbc^ko//k^00Go//k^0oo1fnd4olGQk@Co`]c/0ol00004ok7;k@;oY[k[
3OnN]>P2ojBkj@KoY[k[1_nW_n/2ojNnjPKoYKcY1onU_NX00onW_n_oZ<7/ojS1k004ojS1k0KoZ<;/
00?oZ;oZojNnjOnW_^T01_nW_^T5ojNmj@03ojNnj_nX_^[oZ;kZ00KoZ;kZ1OnY_^T2ojS1j`SoZL3Z
0_nZ_nT5ojW0jPOoZ[oY0_nV_^/6ojRojPOoYKo/00?oYl3[ojO0k?nW`>`01?nW`>`7oj[1jPOo[<7Y
2?nX`>/8oj_1jP03ok;4ioncaNSo/lGX00Co/lGX1_naaNT00on_aN_oVKW^oiVikP05oiVikP?oN:;]
00?o0000ogRRkOmhX^d01_mmY>`7oifgj`03okW9i_nkbnKo^l_V00Ko^l_V4oooool00ol0003ooooo
o`00000Aooooo`005oooool00ol0003oooooooooo`0>ooooo`GoYko[2OnV_n/5ojW1j`;oY[o[1_nP
^^/6oiN`j0OoT:SU0onDZnH4oijgj@Co//k^1oo1fnd00oo5hNgo`]c/ol;Lk003o`0000?o`]c/00?o
/L_]ojJnjonV_^/01?nV_^/:oijdj0CoY;_Z1onV_^/3ojNoj`CoY[gZ1onU_>T3ojFmjPCoYl3[1onX
`N`2ojS2k0GoZ;oZ2?nW_^T00onW_NWoYkkZojNnjP03ojNnjPSoZ;kZ00?oZKkYojS1jonX`N/01?nX
`N/6ojW0jP03ojS2k?nY`>[oZL3Z00KoZL3Z1OnZ_nT2oj_1jPSoZ;oZ0onU_n`3ojJok0SoYl3/1onZ
`NX7ojc1j@SoZ<3[1_n[`NX00on[`^[o/lGXok?5j006ok?5j0;o/LGY1On_aN/7oiVikP?oN:;]00?o
0000ogRRkOmmY>`01OmmY>`6oifgj`;oXk[Y1onkbnH00onmc^Koooooooooo`0Cooooo`03o`000?oo
oooooooo00oooooo000Gooooo`03o`000?oooooooooo00oooooo00?oYko[ojJojonV_n/02onV_n/0
0onY`N_oY[o[ojJoj`04ojJoj`KoX;[[1_nG/>P3oi2Xi@?oTjcW2OnN]nT00onbc^ko`M_]ol7Kk@05
ol7Kk@04olOOj_l0003o0000o`0000Go`]c/0_nab^`7ojJnj`GoW[CX00?oW[KYojBkj_nT^nX01_nT
^nX5ojJnj`03ojNojonV_N[oY[gZ00KoY[gZ1OnU_>T00onV_^_oYl3[ojO0j`06ojO0j`SoZ<7/1_nX
_nX6ojNnj@;oYkgZ1_nW_^X6ojRnjP;oYl;/1onX`N/2ojW0jPGoZ<;/2?nY`>X00onZ_nWoZl7Zoj_1
jP04oj_1jPKoZ;oZ00?oZ/3ZojJok?nV_n`01OnV_n`6ojO0k003ojJojonZ`N[oZ/7Z00KoZ/7Z1On/
`NT2ojc2jPSoZ<3[0_n[`NX5oj_2jPKo/lGX00?o]<KXojo5jon_aN/01_n_aN/3oiVikP?oT[C^1?mh
X>/00ol0003oN:;]ogfTk005ogfTk0;oWKO[1_nS^^T4ok_;iPCo_LkV5Oooool00ol0003ooooooooo
o`0>ooooo`005oooool00ol0003oooooooooo`0@ooooo`coY[o[0onY`N/6ojJoj`KoX;[[0onG/>P3
ohjXi`KoTjcW1onN]nT3okC<k0Co`M_]0ol00003olOOjP;o`]c/1_nab^`7ojJnj`03oijdj?nN]^Wo
W[KY00?oW[KY2?nT^nX00onV_^_oYko[ojNoj`03ojNoj`SoY[gZ00?oYKcYojJnjonV_^/00onV_^/8
ojO0j`SoZ<7/1_nX_nX2ojNnj@KoYkgZ1_nW_^X2ojRnjPKoYl;/1OnX`N/00onV`nkoZ<;/ojS2k006
ojS2k0KoZL3Z0_nX`N/7oj_1jP;oZ;oZ1OnZ`>X7ojJok0;oYl3/1OnV_n/8oj[1jP03ojc1jOn/`^[o
[<;Z00Co[<;Z1onX`>/8oj_2jP;o/lGX1Onda^P6ojo5j`03oj_4k?nB]>koT[C^00GoT[C^1?mhX>/0
0ol0003oPZG[oh:Uj`04oh:Uj`WoXk[Y00?o^l_Vokg>i_nmc^H01Onmc^HEooooo`03o`000?oooooo
oooo00gooooo000Gooooo`;o00004_ooool8ojJoj`OoZL7[1_nV_n/3oj2jj`?oUk;Z1_n>Z>L6oi>/
i`CoW[OY1_ndc>`3o`0000GoamoZ0oo4fnX7ok7:k0?oY[k[0onM]NT7oijfj@KoY;_Z00?oY[k[ojNo
jonW_n/01OnW_n/6ojJmjP03ojBlj_nV_^_oY[k[00GoY[k[1_nW`>/2ojS2k0SoZ<7/0onX_nX3ojJm
j@SoYkgZ0onW_^X;ojO2k003ojS1jonV`nkoY/?^00?oY/?^2?nX`^`2ojW0jPKoZ<7[1On[`NX00onZ
`N[oZ/3Zoj[0jP06oj[0jPOoY[o/1onV_n/7oj[1jPSo[<;Z1onX`>/6oj_2jP03ojc2j_nda^So]<KX
00Ko]<KX0_n_aN/5oj_4k0OoT[C^0omhX>/00ol0003oN:3[oh:Uj`05oh:Uj`OoXk[Y00?oZkoXokg>
i_nmc^H01Onmc^H00onod>Ooooooooooo`0Cooooo`03o`000?oooooooooo00gooooo000Gooooo`03
o`000?oooooooooo01;ooooo2?nV_n/7ojW1j`?oY[o[0onQ^n/6oiNbjPKoSZSW1_nC[>L00onN]nWo
]<c/okC<k004okC<k0;o00000_o2f>X4olOOjPKoa=_Z1Onab^`2ojJok0KoWKGY1onN]^T2ojBkjPGo
Y[k[1onW_n/2ojJmjPGoY;cZ1onV_^/2ojO0j`KoZ<;/1_nX`N`00onV_N[oY[gYojJmj@05ojJmj@Ko
YkgZ00?oYl7/ojO2k?nW`^`02onW`^`2ojK2kPKoY/?^1_nX`^`2ojG1k@SoZ<7[00?oZl7Zoj[1j_nZ
`NX00onZ`NX8oj[0jPOoY[o/1onV_n/7oj[1jPKo[<;Z0_n[`^/7ojS0j`;oZl;Z1On/`^X6okC6j0;o
]LWY1on[a>`7oi:dkP?oN:3[00?o0000ogRPjon2YN/01On2YN/4oj>jj@CoZkoX1Onmc^H3oko@iaGo
oooo00?o0000ooooooooool03?ooool001Oooooo00?o0000ooooooooool04oooool8ojJoj`GoZL7[
0_nW`>/6oj6kj`KoUk;Z1_n>Z>L3oi>/i`CoWKKY0_ndc>`3o`0000Ko`]SZ00?oamoZolCKj_o4fnX0
1_o4fnX00onab^coY[o/ojJok004ojJok0KoWKGY1OnN]^T3ojBljPKoY[k[1OnW_n/3ojFmj`KoY;cZ
1OnV_^/3ojS0j`OoZ<;/0_nX`N`5ojJmjPOoY[gY0_nW_NX5ojO1k0WoYl;/1_nV`^h6ojK3kP;oZ<;/
1_nU`Nd6ojS1j`03ojO1k?nZ`N[oZ/7Z00GoZ/7Z1_nZ`>X00on[`N[oY[o/ojJok006ojJok0OoY[o[
1onZ`NX2ojc2jPKoZl;[1_nX`>/8ojc2jP?o]<KX1OnebNT7oj_4k0?oT[C^0on9[Nd4og^Nj003o`00
0?mhX>_oPZG[00GoPZG[00?oXk[Yoj^oj?n[_nP01?n[_nP3okg>iPKo_m3W5Oooool00ol0003ooooo
ooooo`0;ooooo`005oooool00ol0003oooooooooo`0Eooooo`OoY[o[00?oZL7[ojO0jonW`>/01?nW
`>/6oj6kj`KoUk;Z0on>Z>L3oi2[j0GoWKKY0ol00002okC<k0Ko`]SZ0oo8g>P6olCKjP?o]Lg/1_nV
_n`6oifej@03oijfjOnT_>[oY;cZ00GoY;cZ1_nV_^/00onW_n_oYKg[ojFmj`05ojFmj`KoY;cZ00?o
Y[k[ojS0jonX`>/01OnX`>/5ojS2k003ojS1jonV_N[oY[gZ00KoY[gZ1OnV_NT2ojNoj`OoYl7/1OnW
`^`2ojO3k@SoY/;^0onV`nh3ojFnk0SoYL7]0_nX`N/5ojO1k0OoZ/7Z0_nZ`>X5oj_1jPOoY[o/2?nV
_n/7oj[1jPSoZl;[1_nX`>/8ojc2jP03okC6j?nebNWo]LWY00Go]LWY0on[a>`3ojG0k@OoRJg]1?mk
W^P00ol0003oR:OYohRWj@04ohRWj@SoZkoX00?o_LkVoko@ionod>L01?nod>L00oo0dnSooooooooo
o`0Cooooo`03o`000?oooooooooo00_ooooo000Fooooo`?o00005oooool5ojJoj`?oZ<3[1_nW`>/6
oj6kj`?oUk;Z0on<ZNP6oi2[j004oiffjOl0003o0000o`0000?oWKKY00?o]<c/ol;Hj_o2f>X01?o2
f>X6olSLj003olCKj_necNco]Lg/00Go]Lg/1_nV_n`6oifej@SoY;cZ0onV_^/3ojNoj`SoYKg[0onT
_>X3ojJoj`SoZ<3[00?oZ<;/ojS1jonX`N/00onX`N/8ojJmjP03ojJmjOnW_n_oYko[00CoYko[1onW
`N`00onW`^coYl?]ojO3k@04ojO3k@KoY/;^00?oYkcYojFnk?nU_^`01OnU_^`6ojG1k@;oY;o]1_nW
`N`6oj[1jP;oZL7[1on[`NX7ojJok0SoY[o[1onZ`NX7oj_2j`OoZ<3[1_n/`^X00on]`n[o]LWYokG9
j@05okG9j@03okC:jonU`>goYL3]00GoYL3]1_n9[Nd4og^Nj003o`000?mkW^SoR:OY00GoR:OY1_n[
_nP00onca^Wo_m3Woko@i`04oko@i`?o`=?X5Oooool00ol0003oooooooooo`0:ooooo`005_ooool0
0ol0003oooooooooo`0Hooooo`03ojJojonX`>_oZ<3[00GoZ<3[1_nW`>/3oj6kj`;oVKK/1on<ZNP3
oi2[j0?o00001OnM]^T3ok;7jPCo`]SZ1_o8g>P2olOJi`So]Lg/0onV_n`2oibfj`OoWKGY1_nT_>X0
0onV_^_oYko[ojNoj`05ojNoj`KoYKg[00?oY;c[ojJojonV_n/01OnV_n/6ojS0j`;oZL;/1_nX`N/6
ojJmjP;oYKgZ1onW_n/3ojO1k0CoZ<?]1onW`nd2ojK2kPGoYkcY1onU_^`2ojG1k@KoY;o]1_nW`N`2
oj[1jPKoZL7[1On[`NX2oj_2jPOoY[o/1_nV_n/00onW_n_oZ/7Zoj[1jP06oj[1jPOoZl;[1onX`>/2
ojc2jPGo[L?Z1?nebNT4okC:j`OoYL3]1_n9[Nd4og^Nj003o`000?n8YnWoR:OY00GoR:OY0_n[_nP5
ok?6j@?o_m3W1_o0dnPCooooo`?o00002oooool000Cooooo1?l000002?l@413oooooooooooo^k^ko
<S8bo`000?lb<S;ok^k^1_ooool00ol0003oooooooooo`0Jooooo`OoZ<3[0onW`>/2oj>mk0KoVKK/
1_n<ZNP3o`0000CoT:_X00?oWKKYok;7j_nbanX01_nbanX00oo2f>[ob=cXolSLj004olSLj0Coam[W
1_necN`00onY`ncoW;K[oibfj`04oibfj`OoWKGY0_nT_>X5ojJnj`OoYko[0_nU_N/5ojBlj`OoY[o[
0_nX`>/6ojW2k0KoZ<7[0_nV_NX6ojFmjPGoYko[00?oZ<;/ojS3kOnX`nd01_nX`nd5ojO3k@;oYkcX
1onW_>T5ojFnk0;oZ;kY2?nT_nd3ojO1k0?oYKo/2?nY`N/00on[`N[oZl;Zoj_2jP04oj_2jPOoY[o/
0_nV_n/5ojNoj`KoZ/7Z00?oZl;Zoj_2jon[`^/01On[`^/6ojS0j`;oZL7[1on]`nX00onebNWo]<[[
okC:j`05okC:j`?oYL3]0onN^n`6oh:Sj@CoOikV00?oNikXo`000?n8YnT00_n8YnT4oi:/j0Oo/lKY
00?o_m3Wol3Cj?o0dnP01?o0dnP2okoDjPoooooo0ol00002ooooo`03o`000?oooooooooo00Wooooo
0006ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`00
0?oooooooooo01_ooooo1OnX`>/00onX`N_oXkg/oj>mk004oj>mk0KoVKK/0_n<ZNP3o`0000;oS:WX
0on@ZnP3oiZcj@Oo//OZ0oo1e>P3olSLj0Ooam[W0_necN`5ojW3k0KoW;K[1OnM]NT3oj>kj`KoY[k[
1OnW_n/3ojFnj`KoY;c[1OnV_n/3ojS0j`OoZL;/0onX`N/3ojFmj`SoYKgZ00?oYko[ojS2k?nX`^`0
0onX`^`8ojS3k@03ojO3kOnW_>SoYkcX00CoYkcX1onW_>T00onU_^coZ;kYojRnj@04ojRnj@KoY;o]
00?oY;o/ojFok?nU_n`01OnU_n`8ojW1j`OoZl;Z0onV_n`4ojJoj`OoYko[0_nZ`NX5oj_2jPOoZl;[
0_nX`>/6ojW1j`Go[L?Z0_n`aNX6okC:j`03ok38k?nN^ncoW[_/00GoW[_/1_n2XnT4ognNiP03o`00
0?nB[>SoTZcX00KoTZcX1Onca^T3okS<j@?o`=?X1Onoe>X;ooooo`?o00001Oooool00ol0003ooooo
ooooo`09ooooo`001_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100
1_ooool2o`0001gooooo00?oZ<3[ojS1jonX`N/00onX`N/6oj>mk0CoVKK/0ol00002ohbYj0?oSJ[Y
1onJ/nT4ok;7jPKo`MCX00?ob=cXolOJioo7f^L01Oo7f^L3okcBjPKoZL?/1_nL]^/00onM]NWoXk_[
oj>kj`05oj>kj`KoY[k[00?oYko[ojFnjonU_^/01OnU_^/6ojBlj`03ojJojonX`>_oZ<3[00GoZ<3[
1OnY`^`00onX`N_oYKg[ojFmj`05ojFmj`KoYKgZ0_nW_n/6ojS2k0KoZ<?]0_nX_n/7ojNlj0?oYkcY
1?nZ_>L7ojRnj@;oY;o]1OnT_n`7ojFok0SoZL7[1On[`^X00onZ`^_oY[o[ojJoj`06ojJoj`KoYko[
2?n[`^X5oj_2j`;oZL;/2?nY`N/00on]`n[o/<GZok35jP04ok35jP?o]<[[1?n`b>`7oijkk0KoPZ?Y
1?moW^H00ol0003oTZcXoi:/j006oi:/j003ok?6jOnhc>Wo^<cY00Go^<cY00?o`=?XokoDj_noe>X0
1Onoe>X6ooooo`Co00002?ooool00ol0003oooooooooo`09ooooo`001_ooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000001Oooool2o`0001oooooo1_nX`N/6oj>mk003oiVf
k?l0003o000000?oSJc[1_n=Z^T7oiZcj@03ok;7j_o1e>So`MCX00Go`MCX0oo8enD4olOJi`Ko_=;Z
1_nY`n`3oibfj`CoV[CZ1onS^n/3ojJnj`?oYko[2?nU_^/3ojBlj`?oY[k[2?nX`>/00onY`^coZ<7[
ojS1j`03ojS1j`OoYKg[0_nU_NX6ojNoj`KoZ<;/0_nX`nd6ojRoj`GoYkcX00?oYk_XojZlionZ_>L0
1_nZ_>L5ojRnj@;oZl7Z1onT_n`5ojFok0;oY[k[2?nY`N/00on[`^[oZ/;[oj[2j`03oj[2j`SoY[o[
1_nW_n/8oj_2jP03oj_2jonY`^coZL;/00CoZL;/1_nY`N/00onZ`N_o/<GZok35jP06ok35jP03okC:
jon`b>co/<S/00Co/<S/1onN^n`5oh:Sj@GoOikV00?o0000oi:/j?nB[>P01?nB[>P00onO]>Oo^<cY
okS<j@05okS<j@03okgAjOnoe>[o_mCZ00Go_mCZ00Co^M?]oooooooooooooooo0ol0000=ooooo`03
o`000?oooooooooo00Sooooo0006ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`000005ooooo`03o`000?oooooooooo01oooooo1_nX`N/3oj>mk0?o000000?oW;W/ohf/jon=
[>/00on=[>/6ohfZj@GoV[?Y0on[`>T4ol7Dj0Oob=OU00?oam[WokcBj_nld^X01_nld^X3ojW3k0?o
Wk_/1onJ]>X5oj>kj`03ojFmjonW_n_oYko[00GoYko[1_nU_^/00onS_>_oY[k[ojJnj`05ojJnj`Ko
Z<3[0_nY`N/6ojS1j`SoYKg[1onW_n/3ojS2k0?oZ/?/2?nX_n/00onW_>SoYk_XojNkj003ojNkj0So
Z[cW00?oZ;kYoj_1j_n[`NX01?n[`NX7ojBok003ojFok?nV_^_oY[k[00CoY[k[1_nY`N/00onZ`N_o
Z/;[oj[2j`05oj[2j`KoY[o[00?oY[k[ojNojonW_n/01OnW_n/6oj_2jP03ojc3jonY`^coZL;/00Ko
ZL;/0_nY`N/5oj[1j`Ko/<GZ00?o/lWZok38k?n`b>`01_n`b>`3oijkk0?oTk7/1?moWND2oh:Sj@Go
OikV00?o0000oi:/j?nB[>P01OnO]>L4okS<j@Co_M7Y1?noe>X4okWCk@;o00004?ooool00ol0003o
ooooooooo`08ooooo`001_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@
41001Oooool00ol0003oooooooooo`0Pooooo`?oZ<7[0_nU_n`3o`0000GoW;W/1On=[>/6ohfZj@03
oiZcjOn[`>WoZl3Y00KoZl3Y00?o`MCXolSGiOo8enD01Oo8enD3olWHi0Ko_=;Z0_n_an/6oinkk0Oo
V[CZ00?oXk_[ojFmjonU_N/00onU_N/7ojNoj`;oYKk[1OnS_>/7ojJnj`;oZ<3[1_nY`N/6ojS1j`So
YKg[1OnW_n/00onY`N_oZ/?/oj[3k005oj[3k0KoZ;o[00?oYKgZojNkj?nW^nP01OnW^nP6ojZli`;o
[<7Y1on[`NX3ojBok0CoY;k/1onV_^/2ojW1j`GoZ/7[1onZ`^/2ojJoj`GoY[k[1onW_n/2oj_2jPGo
[<?[1_nY`^`00onX`>_oZ/7[oj[1j`06oj[1j`;o/<GZ1OncbNX6ok38k003ojW3kOnC/NcoTk7/00Go
Tk7/1OmoWND5ohFQiP03o`000?nO]>OoWkCW00KoWkCW00?o^<cYokgAjOnmdNT01OnmdNT00onoe>[o
^M?]okWCk@05okWCkA7ooooo00?o0000ooooooooool02?ooool000Kooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_l0000Rooooo`04ojFok?l0003o0000o`00
00?oYKo/1_nL^N`5ohf/j`?oSJ[Y0onD/>X7oj_0j@?o_/kW1Oo8enD6olWHi003okcBj_n_an_o[lO[
00Co[lO[1_nO^n`3oiZdjPCoWkW[1_nU_N/5ojNoj`?oY[o/1_nS_>/5ojJnj`;oZ<3[2?nY`N/3ojS1
j`?oYKk[2?nU_N/00onW_n_oZL7[ojW1j`03ojW1j`OoZ/?/0_nX_n/5ojFmjPOoYk_X0_nZ_>L6ojc1
j@GoZl7Z00?oZl?[ojBnk?nT_^`01_nT_^`5ojJnj`;oYko[1_nZ`N/6oj[2j`;oZ<7/1onV_^/3ojNo
j`CoZ<3[1on/`n/2ojW2k0GoZ<3[1_nZ`N/2ojc3j`Oo/lWZ0_n`b>`5ojW3k@KoTk7/1_moWND5ohFQ
iP03o`000?nO]>OoWkCW00CoWkCW00?o[<;YokgAjOnmdNT01OnmdNT00onoe^_o^M?]okWCk@05okWC
k@03ok;;kOoooooooooo00oooooo00?o0000ooooooooool02?ooool000Cooooo00?oEEEEofIVI_l0
00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool07oooool3o`00
00OoYKo/0onL^N`2oi6ckPKoRJW[1_nD/>X5oj_0j@Go_/kW0oo8enD6olWHi0;oaMCV1on_an/3oink
k0?oVKK/1onO^N/6ojFmj`03ojNojonV_ncoY[o/00GoY[o/1_nS_>/00onV_^_oZ<3[ojS0j`04ojS0
j`OoZL7[1onU_^/6ojFmj`03ojNojonY`N_oZL7[00GoZL7[1OnZ`n`2ojO0k0OoYKgZ1OnW^nP2ojO0
j`So[<7Y00?oZl7Zoj_3jon[`n/00on[`n/8ojBnk003ojJnjonW_n_oYko[00CoYko[1_nZ`N/2oj[2
j`KoZ<7/1_nV_^/8ojS0j`Go[<?[0_n[a>`7ojS0j`;oZ/7[1_n/`n/5ok?9jP;o]<c/1onY`nd6oi>a
k0GoOigU1_n5XNH00ol0003oWkCWoindi`05ojc2j@Co_M7Y1?noe^/4okWCk@Co//_]4?ooool00ol0
003oooooooooo`08ooooo`005Oooool00ol0003oooooooooo`0Looooo`?o00001?ooool5ojFok0;o
X;c]1OnA/nh6ohVYj`KoU;3Z0on[`>T7okk>i`03olSGiOo9f>CobMST00CobMST1?o5e>H5ojo7j`;o
Y/7]1_nI]^`7oinij`?oYKg[0onV_n/8ojJok0?oXkc[0onT_N/7ojS0j`OoZL7[1onU_^/2ojFmj`Go
Yko[1onY`N/00onZ`ncoYl3/ojO0k004ojO0k0OoYKgZ00?oYk_XojO0jonW`>/01?nW`>/6ojc1j@;o
[<K]1_n[`n/6ojBnk003ojBljonW_n_oYko[00KoYko[0onZ`N/3oj_3j`SoZ<7/1_nV_^/8ojS0j`03
ojc3jon[a>coZlC/00CoZlC/1OnX`>/2ojS1j`So[<?[00?o/lWZokC<k?ndc>`01?ndc>`5ojW3k@03
oj2jjon8XnKoR:?V00CoR:?V1?n2W><2ognMi@?oQJ7V0on>Y^D00ol0003o[<;Yojc2j@05ojc2j@03
okgAjOnoe^_o_mK[00Go_mK[00?o^M?]ok;;kOnbbnd01Onbbnd?ooooo`03o`000?oooooooooo00So
oooo000Eooooo`03o`000?oooooooooo01Wooooo0ol00008ooooo`03ojFok?nP_>goX;c]00CoX;c]
1OnA/nh6ohVYj`KoU;3Z00?oZl3Yokk>ionnc^L01Onnc^L3olGBi0?obMST1oo5e>H00on_an_oY/7]
ojK1k@04ojK1k@KoVKK/1OnO^N/00onS_>_oY[o[ojJoj`05ojJoj`KoY[o/00?oXkg/ojBmjonT_N/0
1OnT_N/5ojS0j`WoZL7[1OnU_^/2ojBnk0OoYko[1OnY`N/2oj_2j`OoYl3/0onU_NX4oj:nk@OoYl3[
0_n/`NT6ojc6k@KoZl?[0_nT_^`5ojBlj`KoYko[00?oZ<3[oj_3jon[`n/01On[`n/6ojS1k003ojJo
jonV_^_oY[k[00GoY[k[1_nX`>/00onZ`^_oZlC/oj_4k006oj_4k003ojS0jonX`N_oZ<7[00CoZ<7[
1_n/`n/00on_a^_o]<c/okC<k006okC<k003ojW3kOnP^^_oX;[[00?oX;[[1_n8XnH5oh:Lh`KoSZKU
00?o0000ojc2jOn/`^T01?n/`^T00onfc>_o_mK[okoFj`05okoFj`;o_mS/1_nbbnd00on]angooooo
ooooo`0=ooooo`03o`000?oooooooooo00Sooooo000Eooooo`03o`000?oooooooooo01Kooooo0ol0
000=ooooo`KoX;c]1OnA/nh6ohVYj`?oU;3Z1?nP^NX4okk>i`KoaM;T00?obMSTolGDi_o5e>H01Oo5
e>H2ok_?j@OoY/7]1_nI]^`00onO^N_oXkc[oj>lj`03oj>lj`OoY[o[0_nV_n`5oj>mk0OoY;g[00?o
Z<3[ojW1jonY`N/02onY`N/00onU_^_oY;k/ojBnk004ojBnk0OoYko[00?oZL7[oj_2jon[`^/01?n[
`^/5ojO0k0;oXkk]1onR_^d5ojO0j`;oYlC^2?n/a^d3oj_3j`?oZ<7[1onT_>/2ojNoj`GoZ<3[1on[
`n/2ojS1k0GoY[o[1onV_^/2ojS0j`GoZ/;[1_n[a>`00onY`^coZ<7[ojS1j`06ojS1j`;o[<?[1On_
a^/6okC<k003ojo9kOnP^^_oX;[[00GoX;[[1_n8XnH5oh:Lh`KoSZKU00Co0000ojc2jOn/`^Wo[<;Y
1?nfc>/4okoFj`Go_mS/0_nbbnd5ojg7k@oooooo00?o0000ooooooooool01oooool001Cooooo0_l0
000Eooooo`?o00004Oooool6oj2lk@GoTK?^0on9ZN/3ohf]j`OoX;WZ00?o_/kWolGBi?o5d^@01Oo5
d^@3olWChPCoaMCV1OnkcnT7ojK1k@?oVKK/0onJ]^`6oj>lj`GoY[o[0onW_n/6oj>mk0GoY;g[0_nV
_n/;ojW1j`?oY/3/1onT_^`3ojNoj`CoZ<3[1on[`^/00onW`>coXkk]oj>nk@04oj>nk@OoX[k]00?o
Yl3[ojO4k_nWa>h01?nWa>h6ojc6k@03oj[4kOnX`N_oZ<7[00GoZ<7[1OnT_>/2ojJmj`OoZ<3[1On[
`n/2oj[3k0OoY[o[0onV_^/4ojNoj`OoZ/;[0_n[a>`5ojW2k0KoZ<7[00?oZ/;[ojo6jon_a^/01_n_
a^/2okC<k0Go[lW]1onP^^/5ohRSiPKoPYcS1_n>Y^D00ol0003o[<;YokK<j`05okK<j`03okoFjono
f>co_mS/00Co_mS/0_nhe>h7ojg7k@kooooo00?o0000ooooooooool01oooool001Cooooo00?o0000
ooooooooool04_ooool2o`0001Gooooo0onP_>d2oiZik@KoQj_]1_n=[N/5oj2ijP?o/l?V1?o5d^@7
olWChP03olGDi_nkcnWo^loY00Go^loY0onV`Nd4oifkkPKoV[K/1_nS_>/00onV_n_oYko[ojNoj`05
ojNoj`KoXkg/00?oY;g[ojJojonV_n/01?nV_n/8ojW1j`KoY/3/1OnT_^`2ojFnk0OoZ<3[1On[`^/2
oj_1jPOoXkk]0onR_^d4oj;0k`OoYlC^0_n/a^d5oj[4k@OoZ<7[00?oY;c[ojJmjonV_N/01?nV_N/7
ojS0j`03oj_3jonZ`ncoZ/?/00CoZ/?/1OnV_n/2ojJnj`OoYko[1OnZ`^/2oj_4k0OoZL;/0_nX`N/5
oj[2j`Ko[lK[00?o/lc]ojo9kOn_bNd01_n_bNd3oj2jj`?oTjgX1?n5Vn42ohRSiPKoPYcS0on>Y^D3
oifaiP03o`000?nfc>_o]/c[00?o]/c[0onkdn`3okoHk0Go^=C^1On]and00onY`ncoooooooooo`0<
ooooo`03o`000?oooooooooo00Oooooo000Dooooo`03o`000?oooooooooo00oooooo0ol0000Hoooo
o`GoV[W]1_n7Znd6ohf]j`03oj2ij_nc`nKo/l?V00Ko/l?V00?oaM;TolWCh_o9dn801Oo9dn83ol[B
h@Go^loY0onaanX6oifkkPKoV[K/0onS_>/3ojFnj`SoYko[1_nS_N`7ojJoj`SoZL7[1_nV`>`00onT
_^coYKk/ojFnk004ojFnk0OoZ<3[00?oZl;[oj_1j_n[`NX01?n[`NX5oj>nk@;oXkk/1onR`>l5ojO4
kP;oYl?^1onZa>d3ojS1j`CoYKcY1onV_N/3ojS0j`?oZL?/2?nZ`n`00onV_n_oY[k[ojJnj`04ojJn
j`OoYko[00?oZ/;[oj_4k?n[a>`01?n[a>`5ojW2k0;oZ<3[1onZ`^/2ojo6j`Go/lc]1_n_bNd00onV
_n_oTjgXoi>]j005oi>]j0GoQI_Q1_n9Wn86oifaiP04o`000?nfc>_o]/c[okK<j`Ko^m?/00?o_mS/
okSDk_nhe>h01Onhe>h00on]angoZL?/ojW3k003ojW3k0gooooo00?o0000ooooooooool01oooool0
01Cooooo00?o0000ooooooooool03?ooool3o`0001cooooo1OnJ^Nd6ohN[k@?oSJg[0onF/n`7ok?3
iP?o`<cT1Oo9dn85ol[Bh@03ok_?jOnaan[o/LOZ00Go/LOZ1_nM^nh3oiZfk0?oW[W/1_nU_^/6ojNo
j`;oY[o/1_nS_N`5ojJoj`;oYl3[2?nY`N/3ojK0k0?oYKo/1onU_^`3ojS0j`CoZL7Z1on[`NX00onS
_^goXkk/oj>nk004oj>nk0OoX/3_00?oYlC^ojO3k_nW`nh01?nW`nh5oj[4k@03ojNmjOnU_>WoYKcY
00KoYKcY1OnV_N/2ojS1j`KoZL?/1_nZ`n`2ojNoj`OoY[k[0onW_n/3ojW1j`SoZlC/00?oZL;/ojS0
jonX`>/01?nX`>/5oj[2j`;o[<G/1oncc>d2ojo9k@GoY[o[1_nC[NP6ohFKh@KoRIoR1_nM/NH00ol0
003o]/c[ok_Ck005ok_Ck003okkIkOnhe>ko^=C^00Go^=C^00?o/<_]ojW3k?nY`n`01OnY`n`<oooo
o`03o`000?oooooooooo00Oooooo000Cooooo`?o00002_ooool3o`00023ooooo1OnJ^Nd3ohN[k@?o
QZ_]1_nF/n`5ok?3iPGo`<cT0oo9dn85ol[Bh@?oam3Q1onaanX3oifkkP;oV;S^1onN^N`6ojFnj`;o
Yko[1_nV_n`6oj>mk003ojJojonW`>_oYl3[00CoYl3[1onY`N/7ojFok0GoYKk/00?oYKo/ojW1j_nY
`NX01_nY`NX5oj_1jP;oZl3Y1onS_^`3oj;0k`CoYKo/1onW`nh00onZa>goYkgYojNmj@03ojNmj@So
YKcY00?oY[g[ojS1jonX`N/01?nX`N/6ojW3k0;oZ/?/1_nW_n/5ojJnj`03ojNojonY`N_oZL7[00Go
ZL7[1_n[a>`00onZ`ncoZ<3[ojS0j`06ojS0j`03oj[2jon/aNco[<G/00Co[<G/1Oncc>d2ok7<kPOo
Y[o[1OnC[NP6ohFKh@KoRIoR1_nM/NH00on]a>_o0000ok_Ck003ok_Ck0Co_]W]1?nhe>h4ok3;k@Oo
ZL?/2oooool00ol0003oooooooooo`07ooooo`005?ooool00ol0003oooooooooo`06ooooo`?o0000
9?ooool6ohnck`GoQZ_]1_nF/n`3ok?3iPOo`<cT00?obM?Rol[BhOo:d^400oo:d^45olO@h@Go/LOZ
00?oZ/?/oiRhk_nH^>h01?nH^>h7oijik0?oYKk[1?nV_n/7ojJok0?oXkg/0onS_^`7ojO0j`OoZL7[
1onU_n`00onU_^coYKo/ojFok003ojFok0SoZL7Z00?oZl7Zoj_0jOn[`>T01?n[`>T5oj>nk003ojNm
j_nU_ncoYKo/00KoYKo/1OnW`nh8ojNmj@KoYKcY00?oYko[ojS1jonX`N/01_nX`N/6ojW3k0SoYko[
00?oY[k[ojNojonW_n/00onW_n/7ojW1j`;oZlC/1OnZ`n`6ojS0j`03ojW2jon/aNco[<G/00Ko[<G/
00?o/lc]ok7<k_nac>h01?nac>h7ojJoj`GoTjgX1_n5Vn46ohVOhP;oWK7V1?n]a>/00ol0003o[LC[
ok_Ck007okkIk@03okSDk_n`bngo/<_]00Go/<_]0onY`n`3ojNoj`_ooooo00?o0000ooooooooool0
1oooool001Cooooo00?o0000ooooooooool00oooool3o`0002Sooooo1_n?/nl5ohJ[k@KoU[?/00?o
/l?Vol3<i?o0c>@01Oo0c>@3olG>h@?ob];Q1oo7d>400onaan[oZ/?/oj[3k003oj[3k0KoV;S^1OnN
^N`3oj6lk0KoY[o[1OnV_n`2ojBok0KoXkk/1OnW`>/3ojS0j`KoZL7[1OnU_n`2ojBok0KoYKo/1_nY
`NX2ojW1j`OoZl3Y00?oXkk/ojNmj_nW_NX00onW_NX8ojFok003ojO3k_nW_NWoYkgY00[oYkgY0_nU
_>T5ojNoj`KoZ<7[0_nY`nd6ojW3k0KoYko[00?oY[k[ojNojonW_n/01OnW_n/5ojW1j`;oZlC/1onZ
`n`2ojS0j`GoZL;[1_n/aN`9ok7<kP?oY[o[0onK/^P5ohVMh0KoR9_O1_nBYn@7ojg4j`03o`000?ng
d>go_]W]00Go_]W]0_nlfNl6ok3;k@03oj_5kOnW_n_oYko[00GoYko[2oooool00ol0003ooooooooo
o`06ooooo`004oooool01?l0003oooooooooooooool3o`0002cooooo1_n?/nl5ohJ[k@?oU[?/1?nQ
^^X4ol3<i0KoaLkQ00?ob];QolO@hOo7d>401Oo7d>42ol7=i0KoZ/?/1_nH^>h00onN^NcoXKc/oj6l
k005oj6lk0KoY[o[00?oY[o/ojBok?nT_n`01?nT_n`6oj>nk003ojO0jonX`>_oZ<3[00GoZ<3[1_nY
`N/00onU_ncoY;o/ojBok004ojBok0KoYKo/0_nY`NX6ojW1j`OoZl3Y1_nW_NX6ojFok0;oZ;gX2_nW
_NT3ojJnjPOoYko[0_nX`N/6ojW3k@KoZL?/0_nW_n/5ojJnj`OoYko[00?oZL7[oj_4k?n[a>`01?n[
a>`5oj[3k0;oZ<3[1onY`^/2ojc5k0_o/Lc^00?oZ<;/oi^bj?nK/^P01OnK/^P5ohVMh0KoR9_O1_nB
Yn@4ojg4j`?o]m3]00Co0000okO@kOnnfNgo_]W]1_nlfNl2ok3;k@GoZlG]1onW_n/:ooooo`03o`00
0?oooooooooo00Kooooo000Cooooo`Co0000<?ooool3ohnck`;oQZk_1_n:[^d7oj6jjP03ol3<i?o5
c^7oaLkQ00GoaLkQ0oo8c]h4olO@h@Go`LgT1_nZ`n`3oiRhkP?oU[S_2?nQ_>`3ojJoj`?oYko[1onT
_n`3oj>nk0?oY;k/2?nX`>/3ojW1j`?oZL3[1onT_n`3ojFok0?oYL3/2?nY`N/7oj_0j@KoYkgZ0_nU
_n`6ojRmj0GoYkgY00?oYkkZojJnj_nV_^X01OnV_^X5ojNoj`;oZ<;]2?nY`nd3ojW3k0?oYkkZ1onV
_^/3ojNoj`CoZ<;/1on[a>`00onZ`ncoZ<3[ojS0j`04ojS0j`GoZL;[0_n[aN`9ok7<kPGoZ<;/1_nK
/^P6ohVMh0KoR9_O1_nBYn@00on]a>_o]m3]okO@k@04okO@k@03o`000?nlfNoo_=W_00Go_=W_00?o
/lo_oj_5kOn[aNd01_n[aNd6ojNoj`[ooooo00?o0000ooooooooool01_ooool001?ooooo0_l0000c
ooooo`GoQZk_1_n:[^d5oj6jjP?o/<7V1Oo5c^46olS>gP03olO@hOo1cNCo`LgT00Go`LgT0onZ`n`3
oj>ok@KoU[S_1_nQ_>`00onS_NcoYko[ojNoj`05ojNoj`GoY;o/00?oXkk]ojBnk?nT_^`01OnT_^`8
ojS0j`KoZL3[1onT_n`6ojG0k0KoZL7[0_nX`N/7oj_0j@?oYkgZ0onZ_nT8ojRmj003ojNmjOnW_^[o
YkkZ00?oYkkZ1onV_^X00onW_n_oZ<;]ojS2k@04ojS2k@KoZL?]00?oZL7[ojNnj_nW_^X01OnW_^X5
ojJnj`;oYko[1onX`^`3oj_4k0?oZ/?/2?nX`>/00onY`^_oZlG/oj_5k004oj_5k0Go/Lc^0_nacNh7
ojS2k0KoVk;X1_n9WN06ohRKg`?oTZOT1?nT^NP3okO@k@;o_=W^00?o0000okcIk_nlfNl00onlfNl4
ok??k`KoZlG]00?oYl3[ojNojonW_n/01OnW_n/9ooooo`03o`000?oooooooooo00Kooooo0005o`00
00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08ooooo`03o`000?oooooooooo037ooooo1On6[^l6
ohZ^k@03oj6jj_n``NKo/<7V00Go/<7V0oo5c^46olS>gP;obLgL1_o1cN@2ok_:iPKoXko]1_nF^>l2
oj6lk0GoXkg/1onW_n/00onT_ncoXkk]oj>nk@03oj>nk@OoY;k/2?nX`>/6ojW0j`OoY;o/1_nU`>`2
ojW1j`KoZ<7[1On[`>T2ojW1j`KoZ[oY1_nX_NP00onX_n[oYkkZojNnjP05ojNnjPGoY[kZ0_nW`^`7
ojS2k@;oZL?]1OnY`N/7ojNnjP03ojJnjonW_n_oYko[00CoYko[1OnX`^`2oj[5k@KoZ/?/1_nX`>/0
0onY`^coZlG/oj_5k006oj_5k003ok7<k_nacNko/Lg^00Co/Lg^1OnX`^`00onO/nOoSYkNohjNgP04
ohjNgPKoRI[M1_n?X^48ojBij003okO@kOnlfNko_=W^00;o_=W^00?o0000okcIk_nlfNl01onccnl2
oj_5k@GoYl3[1onW_n/8ooooo`03o`000?oooooooooo00Kooooo00001OnHV9So8B4Qonk^k_oooooo
A4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`09ooooo`03o`000?oooooooooo037ooooo1On6
[^l3ohZ^k@?oTK;]2?n``NH00oo5c^7ob<kNolS>gP04olS>gPCobLgL0oo1cN@5ok_:iPKoXko]0onF
^>l4oiRik`KoXkg/1onW_n/6oj>nk@GoY;k/0onU_n`7ojS0j`?oZL3[0onY`>X7ojBok0?oYL3/0onU
`>d8ojS1j`03oj_0jOnY`N_oZL7[00CoZL7[1_nZ_nT2ojRmj0GoZ;oZ1onW_^X00onV_^[oYl;/ojO2
k004ojO2k0GoZ<;]0_nX`n`6ojW1j`KoYkkZ00?oY[k[ojNojonW_n/01_nW_n/00onX`^coZ/G]oj[5
k@04oj[5k@KoZ/?/0_nX`>/5ojW2k0KoZlG/0_n`cNl7ok7=kP03ojS2k?nO/nOoWk?W00?oWk?W1_n>
W]h6ohVJg@KoSj;Q1_nT^NP2ok;=kPGo_=W^00?o0000okcLl?nlg?001Onccnl00on]angoYl3[ojO0
j`05ojO0j`KoYko[00?oZ<7[ooooooooool01_ooool00ol0003oooooooooo`06ooooo`0000Cooooo
oiRHV?lQ8B7ok^k^1?ooool01Ol@413ooooooooooooooooo410@00[ooooo00?o0000ooooooooool0
<Oooool5oh:/l0KoTK;]1_n``NH3ok_6h`?ob<kN1oo9cM`00oo1cNCo^l[Vok_:iP05ok_:iP?oXko]
1?nO_Nh6oiRik`KoXkg/1onW_n/6oj>nk@03ojBnk?nU_ncoYKo/00GoYKo/1onX`>/6ojW0jPGoY;o/
0_nU_n`6ojG0k@KoZ<7[0_nW`Nd7ojW1j`?oZ[oY0onX`N/7ojRojP?oYkkZ2onW`^`00onX`^goZ<?/
ojS3k004ojS3k0KoZL7[0_nW_^X5ojJnj`KoYko[00?oZ<?]oj[5kOnZaNd01_nZaNd3oj[3k0?oZ<3[
1onY`^`2oj_5k0Ko/<g_0onacNh3ojW1j`OoWk?W1_n>W]h5ohVJg@KoSj;Q1?nT^NP5ok;=kP03okcI
k_nlg?3o_=c`00;o_=c`00Co0000okcLl?nlg?3o/lo_1On]and7ojO0j`;oYko[1OnX`N/7ooooo`03
o`000?oooooooooo00Kooooo0002ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooooooo
ooooo`00000;ooooo`;o0000<_ooool5oh:/l0KoTK;]0on``NH6ok_6h`03olS>g_o9cMcobLgL00Go
bLgL0_o9bm`6ok_:iP?o]LKW1_nO_Nh6oiRik`?oXkg/0onS_^`7ojNoj`KoXkk]2?nU_n`7ojS0j`Ko
ZL3Z00?oY;o/ojFok?nU_n`01?nU_n`6ojG0k@;oZ<7[1_nW`Nd5ojW1j`;oYl;]1_nX`N/5ojRojP;o
Yl;]3?nW`^`2ojS3k@OoZ<?/0onY`N/3ojNnjPOoY[k[0_nW_n/5ojS3k@KoZ/G]00?oZL;/ojS0jonX
`>/01OnX`>/5ojW2k0?oZlG]1on`cNl6ojW1j`KoWk?W1_n>W]h5ohVJg@OoSj;Q00?oY;WXok;=k_nb
cNh01?nbcNh00onjfO3o_=c`okcLl003okcLl003o`000?nlg?3o]=?`00Oo[LO]0onW`>/3ojJnj`So
Z<7[1oooool00ol0003oooooooooo`05ooooo`000oooool00omgMgOoIVIVooooo`02ooooo`05o`00
0?ooooooooooooooool000003Oooool00ol0003oooooooooo`0`ooooo`GoPZc`1_nA/^d00on``NKo
^lKSok_6h`04ok_6h`?o`LWP1Oo9cM`4olW;g0?o^l[V1_nea^L6oinmkP?oV;W_0onI^^l6oj>nk0Oo
Yko[1_nS_^d8ojFok0OoZ<3[1_nY`>X7ojFok0?oYL3]0onT`>d8ojO1k@03ojW1jonW`^goYl;]00Co
Yl;]1_nX`N/00onX_n[oYl;]ojO2k@04ojO2k@SoYl;/1_nX`nd5ojS3k0SoYkkZ1OnV_^/2ojO1k0Oo
Z<?]0_nZaNd5ojW2k0OoZ<3[00?oZL;/oj_5kOn[aNd01On[aNd7ok3=k`KoZL7[1_nO/nL6ohjNgPGo
RI[M0on?X^44oijbiPCo//g^1?njfO04okcLl004okCCl?l0003o]=?`okCCl0Go[LO]0_nX`N`6ojJn
j`KoZ<7[00?oZ<7/ooooooooool01Oooool00ol0003oooooooooo`05ooooo`001?ooool01Ol0003o
oooooooooooooooo410@00?ooooo00?o410@ooooooooool03?ooool00ol0003oooooooooo`0`oooo
o`GoPZc`0onA/^d3oiVgk@Go^lKS1Oo1bN03olW=g0KobL_L00?o^l[VokG6ionea^L01_nea^L3oinm
kP?oW;c_1_nI^^l6oj>nk0OoYko[1_nS_^d8ojFok0KoZ<3[1onY`>X5ojFok0;oY[o[1_nT`>d6ojO1
k@03ojG1k_nW`^goYl;]00KoYl;]0onX`N/3ojO3kPOoYl;]0onW`^`4ojO3k@OoZ<?]00?oZ<?/ojNn
j_nW_^X02_nW_^X00onV_^_oYl7/ojO1k004ojO1k0GoZ<?]0_nZa>d7ojW2k0?oZ<3[1?nY`n`6oj_5
k@03ojo?l?n`cNoo/<g_00Ko/<g_0onY`N/2oinai0KoTIkL1_n<V]/6oi2Pg`OoW[;V00?o//g^ok[I
l?njfO001OnjfO000onlg?3o]=?`okCCl002okCCl004o`000?nddo3o]=?`ojg7k@KoZ<7/1_nV_^/2
ojS1j`GoZ<7/1_ooool00ol0003oooooooooo`05ooooo`0000Go0000okZj^_ooooooV9RHoa0@4003
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03oooool00ol0003oooooooooo`0`ooooo`GoPjg`1_nI
]nd3ok_6h`Oo`LWP00?obLgLolW;g?o9bm`01?o9bm`3olS9f`Ko]LKW0_na`nL6oiblk`KoVK[_0onS
_^`3ojBok0OoYko[1_nS_^d8ojFok0KoZ<3[1onY`>X00onU_ncoY[o[ojJoj`04ojJoj`KoY<3]0_nW
`Nd5ojG1kPKoYl;]0_nU`^h6ojO3kPGoYl;]0_nV`^d7ojO3k@?oZ<?]3_nW_^X3ojO0j`OoYl7/00?o
Z<?]oj[4kOnZa>d01?nZa>d5ojW2k0;oZ<7/1onY`n`2oj_5k@Go[lo`1_n`cNl00onW_^WoWk7Toina
i004oinai0KoTIkL1_n<V]/6oi2Pg`GoW[;V0_n_bnh6ok[Il0;o^mga1Onddo000ol0003o[LS^ojS1
k007ojS1k0?oY[k[0_nX`N/8ojS1k0Gooooo00?o0000ooooooooool01Oooool00005oiRHV?l@413o
0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^013ooooo0_l0000aooooo`GoPjg`
1_nI]nd00onka^?o`LWPol79h005ol79h0?oa<SM0oo9bm`7olS9f`03okG6iona`nOo/L?W00Co/L?W
1_nL_>l3oiVjk`?oV[c`1_nT_n`5ojNoj`;oYl3[1_nS_^d6ojFok0;oY<3]1_nX`>/7ojW0jPOoY[o[
0onT`>d3ojFnk0OoYL7^0_nW`^d6ojG2kPKoYl?^00?oYl;]ojK2kOnV`^d01?nV`^d5ojO3k@koYkkZ
00?oYko[ojO0jonW`>/01OnW`>/5ojO1k0;oZLG^1onZa>d00onY`^coZ<7/ojS1k004ojS1k0GoZL?/
0_n[b>l7ojo?l0;o/<g_1OnW_^T6oinai0GoTIkL1_n<V]/7oi2Pg`03oijbi_n_bnko[l_^00Co[l_^
0_njfO06ok_Ml@;o]=?`0_n]b>h00ol0003o[LS^ojg8kP06ojS1k003ojJnjonX`N_oZ<7[00CoZ<7[
1_nX`N`00onX`N_oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo000Oooooo`03o`000?oo
oooooooo02oooooo1On3[O03oiVgk@CoX[c[1?o1bN06olC8g@03olW;g?o8bM_ob<WK00Gob<WK0_o6
amX7ok73i`?oW;c_0onJ_>l6oiZll0KoY;o/00?oYko[ojO0jonW`>/01?nW`>/6oj>nk@;oYKo/1_nT
`>d6ojS0j`OoZL3Z1OnV_n/2ojVojPKoYKk/1OnU`Nh2ojFok0SoYL;^0onW`nh3ojK0k0OoY/;]00?o
Yl?]ojNnj_nW_^X03?nW_^X5ojNoj`OoYl3[00?oYl7/ojW5k_nYaNh01?nYaNh5oj[4k@;oZ<7[1onX
`N`00onY`ncoZlS_oj_8k`04oj_8k`Go[lo`0_n^b^h6ojNnj@KoWk7T1OnAW]`7ohbJf`?oT:3O0onL
/>H6ojo;kP?o^=Wa1OnkgO400onde?3o[LS^ojg8kP03ojg8kP03o`000?n]b>ko[LS^00;oZ<7/1OnV
_^/6ojS1j`;oZ<7/1OnX`N/4ooooo`03o`000?oooooooooo00Gooooo000Pooooo`03o`000?oooooo
oooo02oooooo1_n6/?47oj:lj`03ol79h?o4b=goa<SM00Coa<SM0_o6b=/6olS9f`Coa/OJ1Ona`nL2
ok32i`KoV[c_1_nJ_?03ojBok0?oY;o]1onW`>/3oj>nk@CoXko]1onT`>d3ojS0j`?oYl7/1onY`>X0
0onV_n_oZKoZojVojP04ojVojPKoYKk/00?oYL7^ojFok?nU_n`01?nU_n`6ojG2kP03ojJnjonV`>co
Y/3/00GoY/3/1OnV`^d2ojRnjP[oYkkZ2_nW_n/3ojO0j`CoZ<C^1onYaNh00onZa>goZ<7[ojS1j`04
ojS1j`GoZ<7/00?oZLG]oj_8kon[b>l01_n[b>l00on_co3o[/[^ojk:kP04ojk:kPKoYkkY1_nO/N@5
oi6Ng0?oS9[K0onBX=h7oib`iP?o[l_^1_nhfO400onkgO7o]=C`okCDl003okCDl0Go[LS^00?o0000
ojS2k?nV_^/01onV_^/3ojS1j`;oZ<7/2?nX`N/3ooooo`03o`000?oooooooooo00Gooooo000Qoooo
o`03o`000?oooooooooo02oooooo1_n6/?45oj:lj`;o[;oX1Oo4b=d4olK8f`?ob<WK1oo6amX00ona
`nOo/<;Wok32i`04ok32i`KoV[c_0onJ_?03oiVml0KoY;o]1OnW`>/2ojO0k0OoXko]1OnT`>d2oj?0
kPKoYl7/1OnY`>X2ojW0j`OoZKoZ0onU_^`3ojRojPOoYKo/0_nU`^h5ojJnj`OoY/3/00?oY/;]ojRn
j_nX_^X01?nX_^X5ojNnjP;oYkoZ2onW_n/2ojO3k@OoZ<C^0onYaNh3ojW2k0SoZ<7[00?oZ<7/ojW5
kOnYaNd00onYaNd6oj_8k`;o[m3a1on^b^h3ojNnj@;oWZ[O1_nBW=X5ohnJfPOoTZ3N1onL/>H00on_
bnko^=WaokSIl@04okSIl@;o^]kb1_nde?02ojg8kP;oZ<;/00?o0000ojS2k?nX`^`01_nV_^/00onX
`N_oZ<7/ojS1k004ojS1k0KoZ<7[00?oYl3[ooooooooool00_ooool00ol0003oooooooooo`04oooo
o`008_ooool00ol0003oooooooooo`0_ooooo`KoQ[3a00?oX[c[ojboj?n/_nP01?n/_nP3olC8g@Ko
a/SK00?ob<WKolK7f_o6amX01Oo6amX2olG5fPOo/<;W1_nJ_>l6oiVml0KoY;o]00?oYl3[ojO0k?nW
`>`01?nW`>`7oj>ok@03ojC0kOnS`>koXl3^00CoXl3^1_nW`N`00onY`>[oZL3[ojW0j`04ojW0j`Go
ZKoZ0_nY`>X6ojRojPGoYKo/0_nX_nX7ojJnj`?oY/3/0onX_^T8ojRnjP03ojNnj_nW_n[oYkoZ00Co
YkoZ1onW_n/6ojO3k@GoZ<C^0_nY`nd6ojW2k0KoZ<7[00?oZ<?]ojW5kOnYaNd01OnYaNd2oj_8k`Ko
[m3a0on^b^h3ojFhiPKoWZ[O1_nBW=X5ohnJfPKoTZ3N1_nL/>H2ojk<k`Co^=Wa1Onjg_83okCDl0?o
[LW^1?nX`^`00ol0003oZ<;/ojS2k002ojJnj`GoZ<7[1_nX`N`2ojS1j`GoYl3[0oooool00ol0003o
ooooooooo`04ooooo`008oooool2o`00033ooooo0on6/?43ohVcl@Oo[;oX00?oa<SMolK8foo6b=/0
1?o6b=/3olK6fPGoa/OJ1?o5aMX5ok32i`;o/<7V1_nJ_>l6oiVml0?oY;o]0onS_nd7ojO0k0?oXko]
1OnT_n`6oj?0kP?oYl7/1?nV`Nd6ojW0j`03ojVoj_nY`>[oZL3Z00CoZL3Z1_nX_nX00onU_ncoZ;oZ
ojRojP04ojRojPGoY[k[0_nX_nX6ojRnj@KoZ;kZ00?oZ;o[ojNoj_nW_nX01_nW_nX3ojNoj`?oYl;]
1onW`nd00onXa>koZL?]ojW3k@04ojW3k@KoZL;/0_nX`N/5ojS3k@GoZLG]0on/c_85ojo@l@03oj[2
jonU^>KoYKSV00GoYKSV1_nNZ]l5oi:LfPKoSi[J1_nBX=h2oib`iPKo[/c_00?o^=Waok[Nl_njg_80
1?njg_800oncdo7o[LW^ojg9kP05ojg9kP?oZ<;/00?oY[k[o`000?nV_^/02?nX`N/3ojS1k0;oZ<7[
2?nW`>/2ooooo`03o`000?oooooooooo00Cooooo000Uooooo`03o`000?oooooooooo02kooooo1_n9
/o45ojboj0;o//;V1Oo6b=/5olK6fP?oa/OJ1_o5aMX00on``^Oo/<7Vok31iP04ok31iPKoV[c_0onI
_O03oiRml@KoXko]1OnW`>`2ojK0k0SoY;o/0onS`>h3oj:okPOoY/7]0onY`>/3ojO1k0OoZL3Z0onX
_nX3ojW0jPOoZ;oZ00?oY[k[ojRoj_nX_nX01?nX_nX6ojRnj@;oZ;kZ1OnX_n/6ojNojPSoYl;]1OnW
`nd00onXa>koZL?]ojW3k@06ojW3k@?oZL;/1?nW`N`6ojS3k@03ojW5kOn/c_;o[<kb00Go[<kb00?o
[m3aoj[2jonZ`^/00onZ`^/6ojFhiPKoWZ[O1_nBW=X6ohnJfP?oTZ3N1?nN/^L5ojk<k`;o]]_c1?nj
g_84ok?Cl@Go[LW^0_nX`N`4ojJnj`03o`000?nV_^_oZ<7[00GoZ<7[00?oZ<7/ojS1jonX`N/01?nX
`N/6ojO0j`04ojNojoooooooooooo`0000Kooooo000Vooooo`03o`000?oooooooooo02kooooo1_n9
/o400on/_nSo//;Vok;2iP04ok;2iP?oa/SK1oo6a]X00oo6am[oaLGJolG5fP04olG5fP;oa<?H1on`
`NH3oiZlk`?oW;c_1_nH_O46oj>ok@03ojO0k?nV`>coY/3/00CoY/3/1_nT_n`2ojJok0KoX[o^1OnV
`Nd2ojC1kPKoYl7/1OnY`>X2ojS1k0KoZL3Z1OnX_nX2ojS0j`OoZ;oZ0onX_^T3ojS0j`OoZ;o[0_nW
_nX<ojO2k@03ojO3kOnXa>koZ<C^00?oZ<C^1_nY`nd9ojO1k0?oZ<?]0onYbO46ojc>lP03ojg;konZ
`^_oZ/;[00GoZ/;[1_nU^>H6oijZg`?oTYcJ0_nBVmT6oiBRg@SoW[;W00?o[/c_okKKlonffo<01?nf
fo<00onjg_;o/m?aok?Cl@05ok?Cl@03ojg9k_nX`NcoZ<7/00CoZ<7/0onV_^/00ol0003oY[k[ojJn
j`02ojS1j`GoZ<7/1_nX`N/2ojO0j`GoYko[00?oooooo`000?ooool01Oooool002Oooooo00?o0000
ooooooooool0;_ooool3ohVcl@?oSKKa1onb`^H00oo6b=_oa/KJolK6fP05olK6fP;oa/GI1Oo5aMX4
olC3f0Go/<7V0_na_^@6oiblk`KoV;ga0onS_nd4oj;0kPKoY/3/0_nT_n`6ojJok0KoX[o^00?oY/7]
ojC1k_nT`Nh01?nT`Nh6ojO1k003ojW0j_nX`NcoZ<7/00CoZ<7/1_nY`>X00onX_n[oZ<3[ojS0j`04
ojS0j`GoZ;oZ0_nX`N`6ojS0j`GoZ;o[0_nW`nd:ojO2k@[oZ<C^0_nY`nd;ojO1k003ojS6konYbO7o
ZLWa00GoZLWa0_n/c_85ojg;k`OoZ/;[0onU^>H2oiZQf@KoU9[G1_nBVmT6oiBRg@KoW[;W0_n_co45
okKKl`;o^=oc1_ncdo400on/b>koZ<7/ojS1k006ojS1k0?oY[k[00?o0000ojS1k?nX`N`01onX`N`3
ojS1j`CoYl3[1_nW_n/00ol0003oooooooooo`04ooooo`00:?ooool2o`0002oooooo1_n=]_45ok;2
iP?o]/?T1Oo6a]X4olK5f@?oaLGJ1_o4`mP00on``NKo/KkTok6ni004ok6ni0KoW;c_0onH_O43oiJm
lPOoX/3^0onV`>`4ojK1k@OoY[o/0onR_nh3oj>ok@OoY<7^0onW`N`3ojK2kPOoZ<7/0onY`>X4ojS1
k0KoZ<3[00?oZ;oZojS1k?nX`N`01?nX`N`6ojS0j`03ojRojonW`ngoYl?]00CoYl?]1OnW`^d2ojO4
kP[oZ<C^3?nW`N`5ojS6k`GoZLWa0on/co86ojg;k`?oZ/;[0onS[Ml6oiZQf@KoU9[G1_nBVmT6oiBR
g@;oW[;W1_n_co400onffo?o^=ocokSOl`04okSOl`;o/m?a1On/b>h6ojS1k003ojJnjonX`NcoZ<7/
00;oZ<7/00?o0000ojS1k?nX`N`01OnX`N`00onX`N_oYl3[ojO0j`06ojO0j`?oYko[0_ooool00ol0
003oooooooooo`04ooooo`00:_ooool00ol0003oooooooooo`0]ooooo`KoSKKa00?o//;VokK3i?nf
`n@01Onf`n@3olK6fPKoa/GI00?oaLGJolC3f?o4`mP01?o4`mP2olC1e`Oo/KkT0onL_>l3oinlk@Ko
U[gb1OnR`>h2oj72l@OoY/7]1OnV_n`2ojO0k0KoXko]1OnT`Nh2oj?0kPKoY/;^1OnX`N`2ojK3kPOo
Z<7/0onX`>/3ojO3k@OoZ<7/0onX`>/4ojO3kPKoYl?]00?oYl;]ojO4k_nWa>h01?nWa>h5ojS4kPgo
Yl7/0_nXa>h7ojS6k`03ojW9lOn/co;o[<ob00Go[<ob0on]bnl2ojJgi@OoXjgO1_nJXMT5oiBJe`Ko
TY_I1OnDX]d00onR^^[o[loaojo?l@05ojo?l@;o]Mkd1Onhgo<2ok3@l@Oo[<S^0_nX`N`5ojJnj`Co
Z<7/00Co0000ojS1k?nX`NcoZ<7/1OnX`N/6ojO0j`Oooooo00?o0000ooooooooool00oooool002_o
oooo00?o0000ooooooooool0;Oooool3ohffl@CoT;Sb1onf`n@00oo6a][oa/GIolK5f@04olK5f@;o
a/?H1Oo4`mP4olC1e`Go/KkT0ond_N05oinlk@KoU[gb00?oX/3^oj72lOnQ`_401?nQ`_47ojK1k@03
ojJok?nW`>coYl3/00CoYl3/1_nS_nd00onT`NkoXl3^oj?0kP04oj?0kPKoY/;^00?oZ<7/ojK3k_nV
`nh01?nV`nh5ojS1k0;oY/?_1_nW`nd5ojS1k0;oY/C_1onW`nh3ojO3k@?oY/?^1onWa>h00onXa>ko
Yl7/ojO1k00;ojO1k0KoZ<C^1OnXa^l3oj[@m0Go[<ob00?oZKkYojJgiOnV]nD01?nV]nD6oj>]g`Ko
VZ7I1_nDV]L6oi:Kf@03oiBRgOnR^^[oX[[Z00?oX[[Z1?n_co45okGNm003okSOlon`d?7o/=3a00Co
/=3a1On/b>h00onX`>_oY[k[ojJnj`06ojJnj`?oZ<7/00?o0000ojS1k?nX`N/01onX`N/2ojO0j`[o
oooo00?o0000ooooooooool00oooool002cooooo00?o0000ooooooooool0;_ooool6oi2hlPGo]/?T
0_ng`n<5olK5f@Coa/?H0oo4`mP6olC1e`03ok6ni?nd_N3o];gP00Go];gP1OnO_>d3oiJmlPCoU;gc
1_nQ`_43ojK1k@?oY<7^2?nW`>`3oj>ok@CoY[o/1_nS`>h3ojK2kPCoXl7^1_nV`nh00onX`NcoY/?_
ojK3k`04ojK3k`KoYl?]00?oZ<7/ojK4konVa>l01?nVa>l5ojO3kP;oY/;^1_nV`nh5ojO4kP;oYl3/
2_nW`N`4ojO3kPKoZ<C^00?oZ<K_oj[@m?nZd?@01OnZd?@00on/co;oZKkYojVnj@03ojVnj@KoY[OU
1_nS[Ml6oiZQf@?oU9[G0_nFW]T6oiRVg`OoX[[Z00?o[loaokGNm?neg_@01?neg_@2okKMm0Oo/=3a
00?o[<S^ojS0jonX`>/00onX`>/6ojJnj`GoZ<7/00?o0000ojS1k?nX`N/01OnX`N/=ooooo`03o`00
0?oooooooooo00?ooooo000]ooooo`;o0000;oooool6oi2hlP03okK3i?ng`n?o]l?S00Co]l?S0oo6
aMT6olK3f003olC3f?o4`MOoa<7G00Coa<7G0oo4_mD7okBmh0;oWkc]1?nT_>/7oiBml`;oXL;a0onL
`_<6ojC1kPKoYl3/00?oY/7]ojJok?nV_n`01_nV_n`3oj?0kP;oYKo/2?nS`Nh3ojK3kP;oY<7^2?nV
`nl3ojO3k@?oYL?_1onVa>l00onW`nkoY/;^ojK2kP04ojK2kPKoY/?^00?oYlC^ojO0k?nW`>`01?nW
`>`5ojO1k003ojO3kOnW`nkoYl?^00KoYl?^0onXa>h3ojO>m0KoZ]3d00?oZlC]ojVnjOnY_^T01?nY
_^T7ojJgi@?oXjgO0_nIVmD6oiJKePKoUYkI1_nHY]l5oj:jjP?o/=Gd0oneg_@5okKMm0?o/=3a1?n[
a^d6ojS0j`;oY[k[2OnX`N`01?l0003oZ<7/ojS1jonX`N/@ooooo`03o`000?oooooooooo00?ooooo
000_ooooo`03o`000?oooooooooo02gooooo0on@^?83oi6jlPOo]l?S00?oa/GIolK3f?o6`mP01?o6
`mP2olG2e`Goa<7G1Oo4_mD5okBmh0;o^;_L1onT_>/3oiBml`?oUkca1OnL`_<6ojC1kP;oYl3/1OnV
`Nd6ojJok003ojO1k?nU_ncoYKo/00CoYKo/1_nS`Nh00onU_ncoY<7^ojC1kP04ojC1kPKoY/?_00?o
YL7]ojG3konU`nl01OnU`nl3ojK4k`?oY/7]2?nV`^h3ojK3kP[oYl3/00?oYl7/ojO3kOnW`nd00onW
`nd6ojO3kP03ojO<lonWc_CoYlkd00GoYlkd0_nZd?@5oj_4k@KoZKkY0onV]nD3oifPePKoVI_E1_nF
VmH6oiJNf@KoV:KO00?oX[[Zok3Em?n`eO@01On`eO@00oneg_Co]]gdokKMm003okKMm003ojk<l?n[
a^goZlK]00KoZlK]0onX`>/2ojJoj`_oZ<7/00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`03ooooo`00<?ooool00ol0003oooooooooo`0]ooooo`KoTK[b1Ong`n<2okO4h`Goa/?H1?o5`]L3
olC1e`Ooa;oE00?o];gPokRkg?nh^m`01?nh^m`5ojBlj`;oZ[_V1_nG_?45oic2l`?oY<7^1?nR`o06
ojK1k@;oY[o/1OnW`N`6ojFok0;oXl7^1OnU_n`6ojC1kP;oY/?_1OnU`Nd5ojG3k`;oY/3/1_nV`Nd6
ojK2kP03ojO1k?nW`>coYl3/00SoYl3/0onW`nh7ojO3k@;oYl?^1OnWc?<5ojO>m0?oZ/S_1_n[a>d3
ojVnj@;oXjOI1onMX=H6oiVKe@GoUY_F1_nFW]T5oiRVg`;oZ<O`1_n`eO@3okCQmP03okKMm?n^c?3o
[/c`00?o[/c`1_n[a^d00onW_n_oY[o[ojJoj`04ojJoj`KoZ<7/1Oooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo00?ooooo000aooooo`03o`000?oooooooooo02gooooo1_nA^_800ong
`n?o]lCSokO4h`04okO4h`?oa/?H1_o5`]L00oo4`MOoa;oEolBoe@05olBoe@03olBme?nh^mco^;_L
00Ko^;_L00?oY;c[ojZki_nZ^nH01?nZ^nH6oiNll@;oW<;c0onG`O@7oj;3l0?oY/7]0onT`^l7ojO1
k0?oYKo/0onW`N`7ojFok0?oY<7^1?nV`>`6ojG1k@03ojG3konV`>coY/3/00CoY/3/1_nV`Nd2ojK2
kPGoYl7/1OnW`>`8ojO3kPGoYl?]0onVc?<6ojO<l`03ojO>m?nZb>ooZ/S_00GoZ/S_0on[a>d2ojF^
g@KoXjOI1_nMX=H6oiVKe@KoUY_F1_nFW]T00onHY]ooZ<O`ojS7l004ojS7l0;o/=Gd1OndhOH00onc
f??o[/c`ojk<l005ojk<l0;oZlK]1OnW_n/6ojJoj`;oZ<7/2Oooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo00?ooooo000booooo`;o0000;_ooool3oi6jlP?oT;_c1onga><00oo6`mSo
aL;GolG2e`04olG2e`?o`l7H1Oo4_mD3olBme0Ko^;_L0_nl^ML7ojZkiP?oUkca1?nN^nd4oiO1m0Go
X/?`0_nMaO@6ojC2k`GoYl7/0_nU`nh6ojO1k0GoYKo/0_nW`N`7ojK0k0?oYL7]0onW`N`7ojK0k0?o
Y/7]2_nW`N`00onW`>coYl?^ojO3kP0:ojO3kP03ojO3kOnVc??oY/cc00GoY/cc0onWc?<4ojW;l@Go
Z/S_00?oYk?QojF^gOnU[]d01?nU[]d6oj>Wf@GoWJ3F1onIVmD3oiJKeP;oVZCL1onM/NH5ojS7l0?o
/=cf0_ndhOH5ok?Hl`Go[/c`0_nY`n`7ojNoj`?oY[o[3_ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo00;ooooo000dooooo`03o`000?oooooooooo02gooooo1On@^o<5okO4h`;o]/CU
1Oo5`]L5ol?1f0?oa;oE1Oo4_M@3okRkg0Go_;WG1OnZ^nH2ojngg`OoW[_]1?nG`O@00onR`o3oWLGd
oig5m004oig5m0KoY<;_00?oYl7/ojG3k_nU`nh01?nU`nh6ojO1k003ojFok?nW`NcoYl7/00CoYl7/
1OnV`>`2ojO2k@KoYl7/1OnV`>`2ojO2k@[oYl7/0onWa>h:ojO3kPCoY/_c1OnVc?<2ojO;l`OoZL_a
00?oZ/S_ojNchOnW/n400onW/n46ojF^g@GoXjOI1_nMX=H3oiVKe@?oVYoH1_nJY=`7oifaiP03ojS7
l?n`g?Ko/=cf00?o/=cf0onbhOL6ok?Hl`03ojk<l?nY`ncoZL?/00CoZL?/1OnW_n/Booooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool00_ooool003Gooooo00?o0000ooooooooool0;Ooo
ool5oi2kl`03okO4honfa>Go]/CU00Co]/CU0oo5`]L7ol?1f003olBoeOo4_MCoa;gD00Goa;gD00?o
^;_Lokbieonl^ML01Onl^ML00onZ^nKo[kOOojngg`04ojngg`GoW[_]0_nV^^L5oiNmlPKoWLGd0onT
`^l4oj77l`KoYL?^0onW`N`4ojK3kPKoYl7/00?oY/3/ojO2kOnW`^d01?nW`^d6ojO1k003ojK0k?nW
`^goYl;]00CoYl;]1OnW`N`2ojK5k`KoYlC^1OnW`nh3ojG<m0KoY/_c00?oY/ccojO;lonWbo<01?nW
bo<3ojW;l@?oZ;OT1_nW/n47ojF^g@GoXjOI0onMX=H2oiZLe@OoVYoH1_nJY=`5oifaiP;oZm;d0on`
g?H6ok;Qm`?o/mSc0on/b>h7ojW3k003ojNojooooooooooo01Cooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`02ooooo`00=_ooool00ol0003oooooooooo`0^ooooo`CoS[_e1onfa>D0
0oo5`]Oo`l7Hol?1f005ol?1f003ol;1fOo4_MCoa;gD00Goa;gD0_o4_M<6okbie`;o_kSC1on_]ml0
0onN^ngoY[[WojJji`04ojJji`GoUkgb0onMaO@4oiO2m@KoXLOc0onU`nh3oj;7l`OoY/?^0onW`N`3
ojG4k`OoYl;]0onW`N`4ojK4kPKoYl;]00?oYl7/ojK5konVaNl01?nVaNl6ojO4kP03ojO3k_nUc?Co
YLcd00GoYLcd1_nVbo<5ojO;l`03ojRhiOnX]nCoZ;OT00GoZ;OT1_nW/n43ojF^g@?oWigB1OnLW=<6
oiZLe@KoVYoH1onJY=`00onM/NKoZm;doj_Bm004oj_Bm003ok3Lm_nbhOOo/^7g00Co/^7g00?o[Lka
ojc8k_n/b>h01On/b>h3ojW3k1_ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02
ooooo`00=oooool2o`0002oooooo1?n>^oD5okK4i@;o//CX1_o3`MP3ol;1f@Goa;gD1?o4_M<3okbi
e`Go_kSC1On_]ml2okJef0OoY[[W0_nG_O84oinkk0KoUl;e0onQao<3oiW5mPKoX/Oc1OnV`nh2oj;8
m0KoYLC_1OnW`^d2ojC7l@OoY/C^0onW`^d4ojG8lPKoY/G_0onWa>h3ojC=m@KoYLcd0_nUbO<6ojK;
l`03ojO;lonX^>GoZ;SU00?oZ;SU1onX]n@3ojNch@;oXIoB1onOWM85oibLd`KoVYcE1_nJWmP3oiZT
g0CoY/G`1On[d_@3ojoQn0;o/^7g1On]c_45ojc8kR3ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`02ooooo`00>Oooool00ol0003oooooooooo`0]ooooo`CoS[_e00?o]/CUok;4j?nb
a>P01?nba>P3ol?1f0Ko`/7I0oo4_M@6olBmd`03okbieono^=?o_kSC00Go_kSC00?o[kOOokJef?nf
]MP01?nf]MP5ojJji`03ojjdgOnO^ncoWk_/00GoWk_/0onG`_D3oiblk`KoVLGf1_nRao<00onV`nko
X/Sdoj;8m004oj;8m0KoYLC_00?oYl;]ojC7lOnTao401?nTao45ojK4kP03oj;;mOnUb?;oYLSb00Ko
YLSb0onVaNl3oj;>mPKoY<ge0_nUc?@6ojG9l`?oY/_c2OnX^>D5ojRgi003oj>Qd_nQWm;oXIoB00Co
XIoB1_nOWM85oibLd`OoVYcE0onJWmP2oindi`SoY/G`00?oZm;dojoQn?n_hOP00on_hOP2ok7Im0Oo
[Lka00?o[<S^ooooooooool08Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;o
oooo000jooooo`03o`000?oooooooooo02gooooo1On9^oL6ok;4j003ol?1f?o2`MWo`/7I00Ko`/7I
00?oa;gDolBmdoo4_M<01?o4_M<00oo3_=Co_kSCoknhd`05oknhd`03ol6hdOnf]MSo][GH00Ko][GH
00?oY[[WojjdgOn^]=d00on^]=d5oinkk0;oZKKR1_nL_>l6oiW5mP?oX/Oc1?nJa_H6oj;8m0?oYLC_
1?nQboD6ojC7l@03ojK4k_nRboGoX/_e00?oX/_e1_nUb?82oio;m`KoX/kf0onTcOD4ojC6l@GoYLWc
00?oZ;OTojRhiOnX^>D02onX^>D00onX]nCoXj7Boj>QdP03oj>QdPKoXIoB1OnOWM86oibLd`?oVYcE
0onNZMl6oindi`KoY/G`0on/gOP00on_hOSo/MWdok7Im004ok7Im0?o[Lka:?ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00;ooooo000kooooo`03o`000?oooooooooo02gooooo1_n9
^oL2ok;4j0Co[<C/1_o2`MT2oko2g0Goa;gC0oo3_=@5oknhd`?o`KSA1_nf]MP00onl]=;o[[CMojjd
g@05ojjdg@03oinkk?nY]^;oZKKR00CoZKKR1_nL_>l3oiW5mPCoVkg`1_nJa_H3oj;8m0CoV/Kf1_nQ
boD3ojC7l@?oW/_g1_nRboD2ojG8lPKoWl_g0onRc_H4ojC2k`KoY<Ka00?oYLWcojRgi?nX]n@00onX
]n@:ojRhi@;oYJ;B1onSXM85oj6OdPKoWigB0onLW=<2oijTf@OoWZWO1_nO]>L2ojK5l0Go[=gh0_n^
h?P5ok7Im2gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`01ooooo`00??ooool0
0ol0003oooooooooo`0]ooooo`?oRK_g0on4^oP6ojc4k0?o`/7I1Ono`]`3olBmd`Go`kcD0ono^=<5
ol6hd@?o][GH1?nl]=85ojjdg@;o]K7D1onY]^83oiblk`CoYkOU1_nK_O03oi[6mPCoWKk_1_nJa_H3
oj7;m@?oW<Cd1_nNboL3oj;;m@CoWlKd1OnOboL2ojBmj`OoY<;_0onTa_43ojRch@KoZ;OT1OnX^>D0
0onVX];oYJ;BojFRdP04ojFRdPKoXj7B1_nQWm83oinMdP;oWj;F1_nNY=T6oijYg`GoWkCW1?nYe_L0
0on/gOSo[^3hojkPn004ojkPn003ok7Im?oooooooooo02oooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`01ooooo`00?Oooool2o`0002oooooo1On4^oP6ojc4k003ol;1fOno`]co_l;L
00Go_l;L00?oa;gCol>le?o3_=@01Oo3_=@00ono^=?o`KSAol6hd@05ol6hd@03okJef?nl]=;o_;CB
00?o_;CB0on^]=d5okFae0GoZKKR0_n`[]H7ojNgi@?oVkg`0onV]nD7oifnk`?oV/Kf0onP_>`6oic4
m0?oW/_g1?nQ_nh6oio6m003oio;monT_N_oY;g[00CoY;g[1OnT`^l00onX[mgoZ;?QojRch@05ojRc
h@KoZ;OT00?oZ;SUojJRd_nVX]800onVX]85ojFRdPOoXj7B0onQWm82oj6Pe0KoWj;F1_nNY=T6oijY
g`03oindionYe_OoZMKg00CoZMKg0_n[h_X5ojkPn3?ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`01ooooo`00?oooool00ol0003oooooooooo`0]ooooo`GoQ;_h0on/a>`3oj74l@Ko
_l;L0_nkaN86ol>le003ol2meoo1^=7o`KSA00Go`KSA00?o`KWBokbdd_nl]=801Onl]=800on^]=go
]K7DokFae005okFae003ojVfh_n`[]Ko/:kF00Co/:kF1OnW]nD00on^[MOoY[OUojJgi@05ojJgi@Go
WKk_00?oZ;CRoj2lk?nP_>`01OnP_>`3oic4m0?oYKSV1onQ_nh3oio6m0?oY[OU1onT_N/00onT`^oo
Z:oMojR_g@03ojR_g@OoZ;?Q0onX]n@2ojNRd@KoYZ;B1OnUX]86oj>QdP03oj:Pd_nQX=CoXJ3D00Co
XJ3D1_nOX]H6oijTf@?oWZWO0onWc_@4ojWFm`GoZn;j00?o[^3hooooooooool0=Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo007ooooo0010ooooo`03o`000?oooooooooo02kooooo
1Omm^_X5oj74l@?o_l;L1OnkaN83ol>le0Co`;gG1Oo1^=43ol6idPGo_;CB00?o_kG@okFae?ne/M@0
1One/M@00onl/M3o/:kFok2^eP06ok2^eP03ojNgiOn^[MOo[ZgG00?o[ZgG1onV]nD00onM_^ooZ;CR
ojRdhP03ojRdhPGoX;c/0_nY[m`6ojFhiPGoXKo^0_nY[md6ojJgi@GoY;g[00?oZJ[HojR_gOnX[md0
1?nX[md6ojRch@03ojRRd?nWX]7oYj;A00CoYj;A1OnVX]86ojFRdP;oXj7B1OnRX=85oj6Pe0KoWj;F
1OnNY=T2ojC3l0KoYlkd00?oZMKgoj_Rn_n[h_X01?n[h_Xjooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool00Oooool0047ooooo00?o0000ooooooooool0;_ooool5ogfjnPGoXLCa00?o
_l;Lok_5h_nkaN801OnkaN800oo3_=Co`;gGol2me`04ol2me`?o`KSA1Oo1^M83okbddP?o_kG@1One
/M@3okbad0Ko/:kF00?o^Jo?ojj]eon^[ML01On^[ML5ojJgi@;o[J_E1_nX]>800onP_>coZJoLojV_
g004ojV_g0KoYKSV00?oXKo^ojV_gOnY[md01?nY[md6ojJgi@03ojBmjonYZ]SoZJ[H00?oZJ[H1_nX
[md2ojRch@GoZ:;@1OnWX]46ojJRdP?oYJ;B0_nTX=47oj:PdPGoXJ3D1onOX]H00onNY=WoY<?`ojC3
l004ojC3l0?oYlkd1OnXh?X00on[h_[oooooooooo`0kooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool00Oooool004;ooooo0_l0000_ooooo`GoMkWk1_nE`oH5ok_5hP;o/<O[1oo0_ML0
0oo1^=7o`KWBol6idP05ol6idP03okbdd_no]M3o_kG@00?o_kG@0one/M@5okbad0?o/:kF1?ni[ll7
ojj]e`03ojJgiOn]ZmGo[J_E00Co[J_E1?nX]>800on^ZM;oZJoLojV_g006ojV_g0?oYKSV0on[Z=@7
ojV_g@?oY[OU0_nZY]86ojVZf0GoZ:oM00?oZZ;?ojRRd?nXX]001OnXX]06ojNRd@?oYZ;B0_nVXM46
ojBPd@KoXZ3B1_nQX=@3oinRePCoX[[Z1OnT`o02ojKMn`KoZ>3j@?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo007ooooo0014ooooo`03o`000?oooooooooo02gooooo1Omg^O/6oiG3
mP03ok_5h_n`an_o/<O[00Co/<O[1Oo0_ML2okk4g`Ko`KWB00?o_k_Gokned?no]M001Ono]M000one
/MCo_;7@okbad005okbad003ok2^e_ni[loo^Jo?00Co^Jo?1On^[ML00ong[Loo[J_Eojf[e@06ojf[
e@03ojRdh_n^ZM;o[ZWB00;o[ZWB1_nY[m`00on`YlooZjSDoj^Xe005oj^Xe0GoZJoM00?o[ZG?ojZV
d_nZY]801?nZY]86ojVZf003ojR_gOnZX/ooZZ;?00?oZZ;?1_nXX]05ojNRd@03ojRRdOnVXM7oYZ7A
00CoYZ7A1_nTX=46oj:PdP?oXJ3D0onS]ND7oj:jjP03ojC3l?nVgO_oY]gk00CoY]gk0_nXh?Y4oooo
o`03o`000?oooooooooo00Oooooo0Ol00001ooooo`7ooooo0015ooooo`03o`000?oooooooooo02go
oooo1Omg^O/3oiG3mP?oR<7j1on`an/00oo0_MOo_/COokk4g`04okk4g`?o`KWB1?no^mL5okned003
okjgdonl/M3o_;7@00Go_;7@00?o_KCAokV_coni[ll01_ni[ll00on^[MOo]jg?okN]c`03okN]c`Ko
[J_E00?o]Z_>ojjYd_n^ZM801?n^ZM83ojV_g0Co/:O?1on[Z=@00onY[mgo[ZG?ojjUc`03ojjUc`Go
ZZKB1OnYZ]P00on/XlkoZZ;?ojZRc`05ojZRc`KoZ:;@00?oYj;AojRRdOnXX]400onXX]46ojJQd@Ko
Y:3A0onRX=83ojBah@KoXkGU1OnR^^X2ojCInPGoY]gkB?ooool00ol0003oooooooooo`06ooooo`7o
00000Oooool1ooooo`00A_ooool00ol0003oooooooooo`0^ooooo`GoM[Sk1On8`OX5ok37j`;oWlOd
1onna=l00oo1^M;o_k_Goknke`03oknke`?o_kG@1?nn]m<5okbad0?o_KCA1_ni[ll00onk/]3o]jg?
okN]c`05okN]c`?o[J_E1?nfZlh6ojjYdP03ojV_g?n`Yloo/:O?00Co/:O?1On[Z=@00onaYlko[ZG?
ojjUc`04ojjUc`KoZZKB00?oZJ[HojbSc_n/Xlh00on/Xlh6ojZRc`GoZ:;@00?oZJCAojRRdOnXX]40
1OnXX]45ojJQd@GoY:3A00?oY[3OojBahOnT/N401OnT/N46oj>ei@03oj:jj_nTfO[oY=Wj00CoY=Wj
00?oY]gkooooooooool0BOooool00ol0003oooooooooo`06ooooo`7o00000Oooool1ooooo`00Aooo
ool2o`0002oooooo1Omf^?/5ohS1nP03ok37jonOaoCoWlOd00CoWlOd1Onna=l2ok?8jPKo_k_G00?o
_kG@okjgdonn]m<01?nn]m<3okbad0Go_KCA1?ni[ll3ok^bd0Oo]jg?00?o[J_EokJ[c_nfZlh00onf
Zlh5ojjYdP03okF[c_n`Yloo/:O?00Go/:O?0on[Z=@4ok6WcPGo[ZG?1OnZY]800on^YLoo[:?>ojbS
cP05ojbScPKoZZ;?00?oZ:;@ojVTdOnYY=400onYY=46ojRRd@KoYZ7A00?oY:3AojJ`gonV/=l00onV
/=l7ojBah@?oXkGU1?nTe_T3ojCInToooooo00?o0000ooooooooool01Oooool1o`00007ooooo0Ooo
ool004Wooooo00?o0000ooooooooool0;_ooool5ogfhn@GoO;ol1_nOao@00onna=oo/lSZok?8jP04
ok?8jPCo_k_G0_nla^87okjgd`03okbad?nm]=7o_KCA00Co_KCA0oni[ll5ok^bd0Go]jg?00?o^K3@
okJ[c_nfZlh01OnfZlh00on^ZM;o]J_>okF[cP03okF[cPOo/:O?00?oZjSDok6Wc_naYlh00onaYlh6
ojjUc`03ojZVd_n^YLoo[ZG?00?o[ZG?1_n/Xlh5ojZRc`03ojbWd_nYY=7oZJCA00GoZJCA1_nXX]43
ojJQd@;oYk7O1_nV/=l6ojBah@;oXm?i1OnTe_UDooooo`03o`000?oooooooooo00Cooooo0Ol00001
ooooo`7ooooo001:ooooo`03o`000?oooooooooo02oooooo1?mm^?T5ogboo0?oWlOd0on<a_/7ok?8
jP03oknkeonla^;o_<KR00?o_<KR1Onn]m<2okg0g0Oo_KCA00?o^Jo?ok^bd?nk/]001?nk/]03okN]
c`Co^K3@1OnfZlh00onh/=;o]J_>okF[cP05okF[cPGo/:O?00?o]:_@ok6Wc_naYlh01?naYlh5ojjU
c`03ok6Yd?n^YLoo[ZG?00Go[ZG?1_n/Xlh00onZX/oo[:OBojbWdP03ojbWdPKoZJCA1OnXX]400onY
/n3oYk7OojNag`04ojNag`KoY[3O0_nT/N46oj?Cn@03ojCFnOoooooooooo05Kooooo00?o0000oooo
ooooool00oooool1o`00007ooooo0Oooool004_ooooo00?o0000ooooooooool0;oooool5oh^lmPGo
MKcl1On<a_/5ok?8jP03oic9monla^;o_<KR00Go_<KR00?o_[OCokg0g?nm`=`01?nm`=`5okfdd@;o
_;cI1onk/]000ong[Loo^K3@okV`d003okV`d0?o]Z_>1?nh/=87okF[cP03ok2WcondZm3o]:_@00?o
]:_@1_naYlh00on^YLoo/JW@ok6Yd003ok6Yd0Ko[ZG?1On/Xlh00on]Z]Co[:OBojbWdP05ojbWdPKo
ZJCA00?oZ:;AojVch?nY/n000onY/n06ojNag`?oY[3O1?nSd_P5oj?CnE[ooooo00?o0000oooooooo
ool00oooool1o`00007ooooo0Oooool004cooooo0_l0000`ooooo`GoRkcf1Ome_?`5ohc6n`03ok?8
j_nLbOOoW<Wg00?oW<Wg1Onla^82oj_;l@Oo_L3L00?o_KCAokblfOnl_=T01?nl_=T5ok^bd003okZj
fOni/=3o^K3@00Go^K3@00?o]Z_>okR`d_nh/=801?nh/=85okF[cP03okJbeOndZm3o]:_@00Co]:_@
1OnaYlh00onb[]Co/JW@ok6Yd005ok6Yd0Ko[ZG?00?o[:?>ojfZe?n]Z]@00on]Z]@7ojbWdP?oZJCA
0_n[]n86ojVch0GoYk7O2OnSd_P00onSdoWoooooooooo`1Looooo`03o`000?oooooooooo00?ooooo
0Ol00001ooooo`00C_ooool00ol0003oooooooooo`0^ooooo`;oRkcf1?nI__85ogbjnPGoO<;m1OnL
bOL00onla^;oZl_aoj_;l@04oj_;l@Go_L3L0_nabnd7okblf@03ok^bd?nj^]Wo^[[I00?o^[[I1Oni
/=000oni_=_o^;3BokR`dP05okR`dP?o]J_>1?nf/]D6okB[d003ok6Wc_nb[]Co/ZkD00?o/ZkD1_na
ZM05ojjUc`03ojnafOn]Z]Co[J[D00Go[J[D1On/Ym800on/_^KoZkORoj^ghP04oj^ghPKoZK?P00?o
Yk7Ooj?Bn?nSd_P02?nSd_QRooooo`03o`000?oooooooooo00;ooooo0Ol00001ooooo`00Coooool0
0ol0003oooooooooo`0_ooooo`GoVKkb1Oml^_X5ogc2o@;oW<Wg1?n6b?d6oj_;l@03okg0g?nabngo
/L_]00Co/L_]1Onl_=T00oncbn_o^[[IokZjf@04okZjf@?o^K3@1?ni_=/7okR`dP03okF[c_nf/]Go
][;E00Co][;E1?ndZm000ond^Mgo/ZkDok:^e005ok:^e0Ko/JW@00?o[ZG?ojnafOn_/MT00on_/MT7
ojfZe003ojbWd_n/_^Ko[;kV00?o[;kV1_n[]n83ojVch0CoX]?i1OnSd_QWooooo`05o`000?oooooo
ooooooooool000000Oooool0053ooooo00?o0000ooooooooool0;oooool2oiVnlP?oX;k^1_n=_OH6
ogNno@CoQ/Sm0on[bo44oho;o0Ko/L_]00?o_;cIok?;joncbn/00oncbn/6okZjf@03okV`d?ni_=_o
^KcK00Co^KcK1Onh/=800ong`>7o][;EokJbe@05okJbe@?o]:_@0ond^Md7ok:^e0?o/JW@0ona^n46
ojnaf@Go[J[D00?o[<K]ojbni_n/_^H01?n/_^H5oj^ghP?oWmCj1_nRdoT00onSd_Soooooooooo`1X
ooooo`05o`000?ooooooooooooooool000000Oooool0057ooooo0_l0000`ooooo`GoX;k^1_n=_OH3
ogNno@CoQ;ci1?mh`oh6oho;o0?o/L_]0onEcO/6ok?;j`Co^[[I0_nbc>d7okVlf`03okR`d_ng`>7o
]l3Q00?o]l3Q1onf/]D00ondZm3o];WMokBig@03okBig@Go/ZkD00?o/<S/ok6khOna^n401Ona^n46
ojnaf@03ojfZe?n/a^go[<K]00?o[<K]1_n/_^H00on[]n;oWmCjoioDnP05oioDnP?oX]?iK_ooool0
1?l0003oooooooooool00001ooooo`00Doooool00ol0003oooooooooo`0^ooooo`GoX;k^0on=_OH4
oi^ol@KoQ;ci1?mh`oh3oho;o0CoNlOo1OnEcO/6ok?;j`03okZjfOnbc>go//c]00?o//c]1Oni_=/2
ojc>l@Ko]l3Q1Onf/]D00oncbN_o];WMokBig@05okBig@03ok:^e?n`b>co/<S/00?o/<S/1ona^n43
ojnaf@?oZ<kd1_n/a^d3ojbniPGoW=Ol0onOe?Ydooooo`03o`000?oooooo0000007ooooo001Doooo
o`03o`000?oooooooooo02kooooo0_nP_^h4ojFnj`KoVkoa0on4_?T3oiNol`KoOkkk1Omkaol5oiG=
n`?o/l_[0onFco`6ok;<k@03okVlfon/c_7o[<ka00Co[<ka1_ng`>400onf/]Go/lW[ok?9j`03ok?9
j`Go];WM0_nUd?L6ok38k0Go/K_Q0_nOdoX6ojS>m0?o[<K]1OnGf?h3oicGo7Wooooo00?o0000oooo
ool000000Oooool005Gooooo00?o0000ooooooooool0;Oooool7ojFnj`?oVkoa1?nS_^d5oiNol`?o
Okkk1?nC_oD5ogk1o0KoOLWo1?nFco`3ok;<k@CoTm3m1_n/c_43okO0h@?oXM7h1_ncbN/00ond^Mgo
YM3gojG@m`04ojG@m`Ko/<S/00?o/K_QoioCn_nOdoX01?nOdoX3ojS>m0GoTMWo0onGf?ioooooo`7o
00000Oooool1o`000000E_ooool2o`0002kooooo1OnU_^/2ojS0j`OoXkk]0_nG_o<4oj6nkPKoTkoe
1Omn`O`3ogg9o`?oOl?m1_mnc?l5oi?@o@?o[<ka0on=d_h6oj7An0?o/lW[1?nEe?d6ojG@m`?o/<S/
1?nEe_h3oioCnPGoRmOo0onAfOn5ooooo`;o0000001Hooooo`03o`000?oooooooooo02cooooo00?o
YKk[ojS0jonX`>/01?nX`>/5oj>nk@;oYko[1_nQ_^h3oi>om@?oX;o_1_nB`?H5ogo3o@?oO/co1?n3
a?`6ogg<o`CoSM;n0onQdOP5ohKBo`GoUMCm0onUd?L4oh[Eo`?oUMKn1On8e?l3oh_GohWooooo0ol0
000005Wooooo00?o0000ooooooooool0;Oooool6ojS0j`03oj>nkOnW_n_oYko[00CoYko[1?nQ_^h2
ojNnj`KoX;o_1_nB`?H2ogo3o@CoU<7f1_n3a?`3ogg<o`?oRLCk1_n0c?l3ohKBo`CoR<[m1On3dOl3
oh[Eo`GoSLkm0on8e?n:ooooo`Co00000oooool005[ooooo00?o0000ooooooooool0;Oooool3ojS0
j`CoZ<7[1_nW_n/00onQ_^koYkk[ojNnj`03ojNnj`KoX;o_0onB`?H3oj2ok`KoU<7f0on3a?`4oiW2
m0GoRLCk0on0c?l4oi?4n0KoR<[m0_n3dOl5oi?6n@?oSLkmS?ooool3o`0000Oooooo001Kooooo`03
o`000?oooooooooo02gooooo1onX`N/3ojNoj`?oZL7[1_nW_^/3oj2ok`CoY[k[1OnP_nl3oiC1mPCo
XKo^1_nI`_@2ohW4n`CoW/;a1_nCa?P3ohS:o@?oWLCc1OnCa_V<ooooo`Co00002_ooool005cooooo
0_l0000^ooooo`GoZ<7[0_nV`>`6ojW1j`?oYkk[0onY`N/7ojJnj`;oX;o_1?nV_^/6oj6okP?oVL;d
0onS_nd6oik2l@?oTlCh0onR`>l6oig4l`03oi?6nOoooooooooo08Wooooo1?l0000>ooooo`00G_oo
ool00ol0003oooooooooo`0/ooooo`03ojS1jonV`>coY/3/00CoY/3/1?nY`N/2ojK1k0KoZL7[1OnV
_^/00onY`N_oY[k[ojJnj`05ojJnj`?oXKo^0onW_nX6oj>ok@?oW/;a1?nU_^/5oj;0k`?oWLCcR_oo
ool4o`0001;ooooo001Oooooo`03o`000?oooooooooo02gooooo1_nV`>`00onY`N_oY/7/ojK1k003
ojK1k0KoZL7[00?oY[k[ojW1jonY`N/00onY`N/5ojJnj`;oZL7[1_nW_nX3oj>ok@?oZ;o[1onU_^/2
oj;0kh_ooooo1?l0000Fooooo`00H?ooool00ol0003oooooooooo`0]ooooo`OoY/3/1OnV`N`3ojW1
j`CoYl7/1OnY`N/00onV_^_oZL7[ojW1j`04ojW1j`CoYkoZ0_nX`N`6ojRoj`GoYKk[Roooool3o`00
01[ooooo001Qooooo`;o0000;oooool6ojK0k0;oY/7/1?nV`>`6ojO1k0;oZL7[1?nW`N`6ojW1j`03
ojNoj_nX`NcoZ<7/00?oZ<7/1_nX_n/00onU_^_oooooooooo`28ooooo`Co00007Oooool006?ooooo
00?o0000ooooooooool0;Oooool3ojK0k0;oYko[1onV`>`3ojO1k0?oY/3/1_nW`N`3ojW1j`?oY/7/
1_nX`N`3ojRojhWooooo1?l0000Qooooo`00I?ooool00ol0003oooooooooo`0]ooooo`GoYko[1OnV
`>`2ojNoj`KoY/3/0onW`N`4ojK0k0GoY/7/0onX`Nb:ooooo`Co00009Oooool006Gooooo00?o0000
ooooooooool0;Oooool5ojNoj`03ojK0k?nW_n_oYko[00CoYko[1?nV`>`2ojNoj`OoY/3/0_nV`Nb;
ooooo`Co0000:Oooool006Kooooo0_l0000^ooooo`;oYko[1?nX_n/6ojNoj`03ojK0k?nW_n_oYko[
00?oYko[1OnV`>b;ooooo`?o0000;Oooool006Sooooo00?o0000ooooooooool0;?ooool6ojRoj`?o
Yko[0onX_nX6ojNoj`03ojK0k?oooooooooo08Sooooo1?l0000`ooooo`00JOooool00ol0003ooooo
ooooo`0/ooooo`?oZ;o[1?nX`>/5ojRojP?oYko[ROooool4o`0003Cooooo001Zooooo`03o`000?oo
oooooooo02cooooo1onX`>/2ojRojX[ooooo1?l0000hooooo`00Joooool2o`0002gooooo1OnX`>^9
ooooo`Co0000??ooool006gooooo00?o0000ooooooooool0:oooool00onX`>_oooooooooo`27oooo
o`?o0000@?ooool006kooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`23ooooo`Co
0000@oooool006oooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1oooooo`Co0000
Aoooool0073ooooo0_l0000Yooooo`03o`000?oooooooooo07_ooooo1?l0001;ooooo`00L_ooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo07Oooooo1?l0001?ooooo`00Loooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo07Cooooo0ol0001Cooooo`00M?ooool00ol0003o
ooooooooo`0Tooooo`03o`000?oooooooooo073ooooo1?l0001Fooooo`00MOooool00ol0003ooooo
ooooo`0Sooooo`03o`000?oooooooooo06cooooo1?l0001Jooooo`00M_ooool2o`0002?ooooo00?o
0000ooooooooool0J?ooool4o`0005kooooo001hooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool0I?ooool4o`0006;ooooo001iooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool0HOooool3o`0006Kooooo001jooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool0GOooool4o`0006Wooooo001kooooo`;o00007_ooool00ol0003oooooooooo`1Iooooo`Co0000
KOooool007gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Eooooo`Co0000LOoo
ool007kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1Aooooo`Co0000MOooool0
07oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1>ooooo`?o0000NOooool0083o
oooo0_l0000Iooooo`03o`000?oooooooooo04[ooooo1?l0001looooo`00P_ooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo04Kooooo1?l00020ooooo`00Poooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo04;ooooo1?l00024ooooo`00Q?ooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo03kooooo1?l00028ooooo`00QOooool2o`0001?ooooo00?o0000oooo
ooooool0??ooool3o`0008cooooo0027ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool0>?ooool4o`0008oooooo0028ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
=?ooool4o`0009?ooooo0029ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0<?oo
ool4o`0009Oooooo002:ooooo`;o00003_ooool00ol0003oooooooooo`0/ooooo`Co0000Voooool0
08cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Yooooo`?o0000Woooool008go
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Uooooo`Co0000X_ooool008kooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Qooooo`Co0000Y_ooool008oooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Mooooo`Co0000Z_ooool0093ooooo0_l00008
ooooo`03o`000?oooooooooo01Wooooo1?l0002^ooooo`00T_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo01Kooooo0ol0002booooo`00Toooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo01;ooooo1?l0002eooooo`00U?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00kooooo1?l0002iooooo`00UOooool2o`0000?ooooo00?o0000ooooooooool02_oo
ool4o`000;gooooo002Gooooo`04o`000?ooooooooooo`0000Sooooo1?l00031ooooo`00V?ooool0
0ol0003oooooo`000005ooooo`?o0000aOooool009Wooooo0_l000000ooooooo0000o`000002o`00
0<Sooooo002Jooooo`;o0000c?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0538698, 0.0432538, \
0.0035044, 0.0035044}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[.12586 .2075 -12 -8.99448 ]
[.12586 .2075 0 .00552 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.56094 .0364 -5.16972 -9 ]
[.56094 .0364 .83028 0 ]
[.75679 .08071 0 -6.17777 ]
[.75679 .08071 12 2.82223 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.9429 .3657 0 -5.9083 ]
[.9429 .3657 6 3.0917 ]
[.02494 .25992 -18 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.01611 .31527 -18 -2.78472 ]
[.01611 .31527 0 6.21528 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00254 .43215 -12 -2.88407 ]
[-0.00254 .43215 0 6.11593 ]
[-0.0124 .49393 -12 -2.93688 ]
[-0.0124 .49393 0 6.06312 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
[(-2)] .12586 .2075 1 .99877 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.56863 .04703 m
.57247 .05235 L
s
[(2)] .56094 .0364 .72324 1 Mshowa
.125 Mabswid
.18558 .19702 m
.18832 .19985 L
s
.23703 .17687 m
.23971 .17975 L
s
.28951 .15632 m
.29214 .15925 L
s
.39772 .11395 m
.40023 .11699 L
s
.4535 .09211 m
.45595 .0952 L
s
.51046 .06981 m
.51284 .07294 L
s
.08568 .23614 m
.08851 .23887 L
s
.62804 .02377 m
.63027 .02701 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.7445 .0853 m
.73835 .08759 L
s
[(-2)] .75679 .08071 -1 .37284 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.93037 .36962 m
.92411 .37158 L
s
[(2)] .9429 .3657 -1 .31296 Mshowa
.125 Mabswid
.7708 .12553 m
.7671 .12688 L
s
.79613 .16428 m
.79242 .1656 L
s
.82054 .20161 m
.81682 .20291 L
s
.86679 .27235 m
.86305 .2736 L
s
.88871 .30589 m
.88497 .30711 L
s
.9099 .3383 m
.90615 .3395 L
s
.71716 .04348 m
.71349 .04489 L
s
.95018 .39992 m
.94642 .40107 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(-20)] .02494 .25992 1 -0.39157 Mshowa
.02837 .31059 m
.0345 .30825 L
s
[(-10)] .01611 .31527 1 -0.38117 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.00981 .42772 m
.01599 .4255 L
s
[(10)] -0.00254 .43215 1 -0.3591 Mshowa
0 .48963 m
.0062 .48748 L
s
[(20)] -0.0124 .49393 1 -0.34736 Mshowa
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.66 .749 .916 r
.39362 .69475 .40169 .70192 .4152 .69799 .40718 .69078 Mtetra
.653 .747 .919 r
.40718 .69078 .4152 .69799 .42878 .69404 .42079 .68703 Mtetra
.65 .753 .925 r
.42079 .68703 .42878 .69404 .44243 .69028 .43448 .68335 Mtetra
.654 .757 .925 r
.43448 .68335 .44243 .69028 .45614 .6866 .44824 .67947 Mtetra
.656 .753 .921 r
.44824 .67947 .45614 .6866 .46992 .68278 .46207 .67554 Mtetra
.658 .752 .919 r
.46207 .67554 .46992 .68278 .48378 .67886 .47597 .67151 Mtetra
.65 .748 .921 r
.47597 .67151 .48378 .67886 .4977 .67487 .48994 .66775 Mtetra
.625 .747 .935 r
.48994 .66775 .4977 .67487 .5117 .67094 .50397 .66472 Mtetra
.594 .766 .961 r
.50397 .66472 .5117 .67094 .52577 .66731 .51809 .66227 Mtetra
.564 .794 .986 r
.51809 .66227 .52577 .66731 .53992 .66436 .5323 .65998 Mtetra
.53 .805 .996 r
.5323 .65998 .53992 .66436 .55415 .66165 .54659 .65793 Mtetra
.525 .825 .999 r
.54659 .65793 .55415 .66165 .56846 .65899 .56097 .65554 Mtetra
.543 .842 .999 r
.56097 .65554 .56846 .65899 .58286 .65642 .57543 .65263 Mtetra
.594 .849 .993 r
.57543 .65263 .58286 .65642 .59735 .65368 .58996 .64895 Mtetra
.635 .831 .976 r
.58996 .64895 .59735 .65368 .61192 .65064 .60457 .64478 Mtetra
.654 .802 .954 r
.60457 .64478 .61192 .65064 .62656 .64727 .61924 .6404 Mtetra
.661 .775 .933 r
.61924 .6404 .62656 .64727 .64128 .64363 .63399 .63593 Mtetra
.662 .754 .918 r
.63399 .63593 .64128 .64363 .65607 .63977 .64881 .63149 Mtetra
.66 .739 .908 r
.64881 .63149 .65607 .63977 .67093 .63573 .66371 .62713 Mtetra
.657 .731 .905 r
.66371 .62713 .67093 .63573 .68587 .63154 .6787 .62291 Mtetra
.653 .73 .906 r
.6787 .62291 .68587 .63154 .70088 .62721 .69378 .6188 Mtetra
.649 .736 .912 r
.69378 .6188 .70088 .62721 .71597 .6227 .70894 .61479 Mtetra
.647 .749 .924 r
.70894 .61479 .71597 .6227 .73111 .61796 .72419 .61081 Mtetra
.645 .77 .939 r
.72419 .61081 .73111 .61796 .74632 .61294 .73953 .60674 Mtetra
.644 .799 .957 r
.73953 .60674 .74632 .61294 .76158 .60759 .75493 .60245 Mtetra
.648 .836 .972 r
.75493 .60245 .76158 .60759 .77689 .60192 .77038 .59765 Mtetra
.662 .87 .978 r
.77038 .59765 .77689 .60192 .79226 .59606 .78586 .59207 Mtetra
.675 .884 .975 r
.78586 .59207 .79226 .59606 .80771 .59029 .80136 .58596 Mtetra
.691 .879 .968 r
.80136 .58596 .80771 .59029 .82324 .58456 .81691 .57947 Mtetra
.69 .856 .961 r
.81691 .57947 .82324 .58456 .83886 .57906 .83254 .57323 Mtetra
.69 .833 .952 r
.83254 .57323 .83886 .57906 .85463 .57426 .84826 .56714 Mtetra
.679 .792 .935 r
.84826 .56714 .85463 .57426 .87051 .56977 .86412 .56162 Mtetra
.661 .758 .922 r
.86412 .56162 .87051 .56977 .88649 .56533 .88013 .55686 Mtetra
.654 .748 .919 r
.88013 .55686 .88649 .56533 .90255 .56081 .89626 .55238 Mtetra
.656 .751 .92 r
.89626 .55238 .90255 .56081 .91869 .5562 .91248 .54779 Mtetra
.656 .753 .921 r
.91248 .54779 .91869 .5562 .9349 .55143 .92878 .54314 Mtetra
.66 .759 .923 r
.92878 .54314 .9349 .55143 .95122 .54673 .94514 .53828 Mtetra
.658 .756 .922 r
.94514 .53828 .95122 .54673 .96765 .54223 .96161 .53349 Mtetra
.653 .747 .919 r
.96161 .53349 .96765 .54223 .98417 .53771 .9782 .52892 Mtetra
.38548 .68752 .39362 .69475 .40718 .69078 .39907 .68375 Mtetra
.649 .753 .925 r
.39907 .68375 .40718 .69078 .42079 .68703 .41272 .68006 Mtetra
.655 .757 .925 r
.41272 .68006 .42079 .68703 .43448 .68335 .42646 .67615 Mtetra
.656 .752 .921 r
.42646 .67615 .43448 .68335 .44824 .67947 .44026 .6722 Mtetra
.658 .752 .919 r
.44026 .6722 .44824 .67947 .46207 .67554 .45414 .66817 Mtetra
.644 .746 .924 r
.45414 .66817 .46207 .67554 .47597 .67151 .46808 .6646 Mtetra
.603 .748 .946 r
.46808 .6646 .47597 .67151 .48994 .66775 .48208 .66213 Mtetra
.567 .776 .977 r
.48208 .66213 .48994 .66775 .50397 .66472 .49616 .66005 Mtetra
.521 .792 .995 r
.49616 .66005 .50397 .66472 .51809 .66227 .51033 .65834 Mtetra
.508 .812 1 r
.51033 .65834 .51809 .66227 .5323 .65998 .52459 .65635 Mtetra
.543 .835 .999 r
.52459 .65635 .5323 .65998 .54659 .65793 .53894 .65357 Mtetra
.625 .839 .982 r
.53894 .65357 .54659 .65793 .56097 .65554 .55336 .64953 Mtetra
.665 .799 .946 r
.55336 .64953 .56097 .65554 .57543 .65263 .56786 .64487 Mtetra
.679 .755 .908 r
.56786 .64487 .57543 .65263 .58996 .64895 .58242 .63981 Mtetra
.685 .725 .88 r
.58242 .63981 .58996 .64895 .60457 .64478 .59704 .63439 Mtetra
.683 .7 .859 r
.59704 .63439 .60457 .64478 .61924 .6404 .61173 .62886 Mtetra
.675 .677 .844 r
.61173 .62886 .61924 .6404 .63399 .63593 .62649 .62356 Mtetra
.667 .661 .835 r
.62649 .62356 .63399 .63593 .64881 .63149 .64133 .61857 Mtetra
.659 .65 .83 r
.64133 .61857 .64881 .63149 .66371 .62713 .65625 .61392 Mtetra
.652 .644 .829 r
.65625 .61392 .66371 .62713 .6787 .62291 .67127 .60964 Mtetra
.645 .64 .831 r
.67127 .60964 .6787 .62291 .69378 .6188 .68639 .60573 Mtetra
.638 .641 .837 r
.68639 .60573 .69378 .6188 .70894 .61479 .70161 .60218 Mtetra
.632 .646 .846 r
.70161 .60218 .70894 .61479 .72419 .61081 .71694 .59894 Mtetra
.627 .657 .86 r
.71694 .59894 .72419 .61081 .73953 .60674 .73238 .59593 Mtetra
.628 .678 .878 r
.73238 .59593 .73953 .60674 .75493 .60245 .74791 .59282 Mtetra
.634 .707 .899 r
.74791 .59282 .75493 .60245 .77038 .59765 .76351 .58935 Mtetra
.641 .742 .923 r
.76351 .58935 .77038 .59765 .78586 .59207 .77918 .58548 Mtetra
.649 .794 .952 r
.77918 .58548 .78586 .59207 .80136 .58596 .79488 .58097 Mtetra
.675 .854 .968 r
.79488 .58097 .80136 .58596 .81691 .57947 .81057 .57516 Mtetra
.692 .883 .969 r
.81057 .57516 .81691 .57947 .83254 .57323 .82626 .56852 Mtetra
.704 .875 .961 r
.82626 .56852 .83254 .57323 .84826 .56714 .84199 .56159 Mtetra
.699 .848 .954 r
.84199 .56159 .84826 .56714 .86412 .56162 .85782 .55502 Mtetra
.692 .815 .941 r
.85782 .55502 .86412 .56162 .88013 .55686 .87376 .54884 Mtetra
.666 .767 .926 r
.87376 .54884 .88013 .55686 .89626 .55238 .88991 .54379 Mtetra
.654 .749 .919 r
.88991 .54379 .89626 .55238 .91248 .54779 .90619 .53922 Mtetra
.656 .751 .92 r
.90619 .53922 .91248 .54779 .92878 .54314 .92256 .53456 Mtetra
.656 .752 .921 r
.92256 .53456 .92878 .54314 .94514 .53828 .93902 .52985 Mtetra
.661 .759 .923 r
.93902 .52985 .94514 .53828 .96161 .53349 .95555 .52491 Mtetra
.658 .756 .922 r
.95555 .52491 .96161 .53349 .9782 .52892 .97218 .52004 Mtetra
.649 .752 .925 r
.37725 .68043 .38548 .68752 .39907 .68375 .39088 .67673 Mtetra
.655 .756 .925 r
.39088 .67673 .39907 .68375 .41272 .68006 .40458 .67282 Mtetra
.656 .752 .92 r
.40458 .67282 .41272 .68006 .42646 .67615 .41836 .66884 Mtetra
.657 .751 .919 r
.41836 .66884 .42646 .67615 .44026 .6722 .43221 .66482 Mtetra
.635 .745 .927 r
.43221 .66482 .44026 .6722 .45414 .66817 .44612 .66151 Mtetra
.588 .751 .955 r
.44612 .66151 .45414 .66817 .46808 .6646 .46008 .65933 Mtetra
.538 .779 .987 r
.46008 .65933 .46808 .6646 .48208 .66213 .47412 .65762 Mtetra
.496 .788 .997 r
.47412 .65762 .48208 .66213 .49616 .66005 .48824 .65619 Mtetra
.516 .818 1 r
.48824 .65619 .49616 .66005 .51033 .65834 .50247 .65401 Mtetra
.617 .837 .984 r
.50247 .65401 .51033 .65834 .52459 .65635 .5168 .65016 Mtetra
.674 .795 .939 r
.5168 .65016 .52459 .65635 .53894 .65357 .53119 .64524 Mtetra
.695 .744 .89 r
.53119 .64524 .53894 .65357 .55336 .64953 .54566 .6395 Mtetra
.703 .712 .855 r
.54566 .6395 .55336 .64953 .56786 .64487 .56017 .63297 Mtetra
.694 .677 .829 r
.56017 .63297 .56786 .64487 .58242 .63981 .57475 .62648 Mtetra
.683 .653 .814 r
.57475 .62648 .58242 .63981 .59704 .63439 .58939 .62029 Mtetra
.674 .64 .808 r
.58939 .62029 .59704 .63439 .61173 .62886 .6041 .61453 Mtetra
.664 .633 .809 r
.6041 .61453 .61173 .62886 .62649 .62356 .61889 .60931 Mtetra
.659 .633 .812 r
.61889 .60931 .62649 .62356 .64133 .61857 .63376 .60443 Mtetra
.655 .633 .816 r
.63376 .60443 .64133 .61857 .65625 .61392 .64871 .59983 Mtetra
.65 .632 .819 r
.64871 .59983 .65625 .61392 .67127 .60964 .66376 .5955 Mtetra
.645 .63 .82 r
.66376 .5955 .67127 .60964 .68639 .60573 .6789 .59144 Mtetra
.639 .626 .82 r
.6789 .59144 .68639 .60573 .70161 .60218 .69414 .58768 Mtetra
.633 .621 .82 r
.69414 .58768 .70161 .60218 .71694 .59894 .70949 .58424 Mtetra
.623 .614 .821 r
.70949 .58424 .71694 .59894 .73238 .59593 .72496 .58137 Mtetra
.614 .612 .825 r
.72496 .58137 .73238 .59593 .74791 .59282 .74056 .57894 Mtetra
.608 .619 .837 r
.74056 .57894 .74791 .59282 .76351 .58935 .75629 .57682 Mtetra
.605 .64 .859 r
.75629 .57682 .76351 .58935 .77918 .58548 .77213 .57475 Mtetra
.619 .681 .886 r
.77213 .57475 .77918 .58548 .79488 .58097 .78801 .5719 Mtetra
.636 .725 .913 r
.78801 .5719 .79488 .58097 .81057 .57516 .80394 .5682 Mtetra
.656 .791 .946 r
.80394 .5682 .81057 .57516 .82626 .56852 .81986 .5634 Mtetra
.694 .861 .962 r
.81986 .5634 .82626 .56852 .84199 .56159 .83572 .55687 Mtetra
.713 .88 .959 r
.83572 .55687 .84199 .56159 .85782 .55502 .85157 .54956 Mtetra
.709 .857 .953 r
.85157 .54956 .85782 .55502 .87376 .54884 .86751 .54251 Mtetra
.699 .829 .945 r
.86751 .54251 .87376 .54884 .88991 .54379 .88357 .53593 Mtetra
.672 .777 .929 r
.88357 .53593 .88991 .54379 .90619 .53922 .89984 .53052 Mtetra
.655 .75 .92 r
.89984 .53052 .90619 .53922 .92256 .53456 .91628 .52584 Mtetra
.655 .751 .92 r
.91628 .52584 .92256 .53456 .93902 .52985 .93281 .52112 Mtetra
.656 .752 .92 r
.93281 .52112 .93902 .52985 .95555 .52491 .94943 .51632 Mtetra
.661 .759 .923 r
.94943 .51632 .95555 .52491 .97218 .52004 .96611 .51129 Mtetra
.654 .756 .925 r
.36894 .67337 .37725 .68043 .39088 .67673 .38261 .66947 Mtetra
.656 .752 .921 r
.38261 .66947 .39088 .67673 .40458 .67282 .39637 .66549 Mtetra
.657 .751 .92 r
.39637 .66549 .40458 .67282 .41836 .66884 .41019 .66144 Mtetra
.632 .744 .929 r
.41019 .66144 .41836 .66884 .43221 .66482 .42406 .65822 Mtetra
.578 .751 .959 r
.42406 .65822 .43221 .66482 .44612 .66151 .43798 .65624 Mtetra
.518 .772 .989 r
.43798 .65624 .44612 .66151 .46008 .65933 .45197 .65486 Mtetra
.486 .787 .998 r
.45197 .65486 .46008 .65933 .47412 .65762 .46606 .65353 Mtetra
.553 .825 .996 r
.46606 .65353 .47412 .65762 .48824 .65619 .48026 .65084 Mtetra
.66 .816 .958 r
.48026 .65084 .48824 .65619 .50247 .65401 .49456 .64625 Mtetra
.698 .758 .899 r
.49456 .64625 .50247 .65401 .5168 .65016 .50894 .64043 Mtetra
.716 .721 .853 r
.50894 .64043 .5168 .65016 .53119 .64524 .52338 .63324 Mtetra
.706 .68 .822 r
.52338 .63324 .53119 .64524 .54566 .6395 .53787 .62594 Mtetra
.692 .653 .807 r
.53787 .62594 .54566 .6395 .56017 .63297 .55242 .61909 Mtetra
.679 .645 .809 r
.55242 .61909 .56017 .63297 .57475 .62648 .56703 .61305 Mtetra
.672 .648 .818 r
.56703 .61305 .57475 .62648 .58939 .62029 .58171 .60752 Mtetra
.667 .656 .83 r
.58171 .60752 .58939 .62029 .6041 .61453 .59647 .60242 Mtetra
.663 .666 .842 r
.59647 .60242 .6041 .61453 .61889 .60931 .61131 .59763 Mtetra
.659 .672 .851 r
.61131 .59763 .61889 .60931 .63376 .60443 .62623 .59307 Mtetra
.656 .677 .858 r
.62623 .59307 .63376 .60443 .64871 .59983 .64123 .58869 Mtetra
.656 .682 .863 r
.64123 .58869 .64871 .59983 .66376 .5955 .65632 .58431 Mtetra
.655 .682 .863 r
.65632 .58431 .66376 .5955 .6789 .59144 .67149 .57995 Mtetra
.651 .675 .86 r
.67149 .57995 .6789 .59144 .69414 .58768 .68675 .57575 Mtetra
.645 .666 .856 r
.68675 .57575 .69414 .58768 .70949 .58424 .70211 .57179 Mtetra
.638 .655 .85 r
.70211 .57179 .70949 .58424 .72496 .58137 .71758 .56815 Mtetra
.628 .64 .842 r
.71758 .56815 .72496 .58137 .74056 .57894 .73316 .56495 Mtetra
.618 .624 .834 r
.73316 .56495 .74056 .57894 .75629 .57682 .74888 .56227 Mtetra
.602 .609 .831 r
.74888 .56227 .75629 .57682 .77213 .57475 .76477 .56042 Mtetra
.592 .608 .837 r
.76477 .56042 .77213 .57475 .78801 .5719 .7808 .55906 Mtetra
.59 .631 .86 r
.7808 .55906 .78801 .5719 .80394 .5682 .79695 .55759 Mtetra
.617 .686 .892 r
.79695 .55759 .80394 .5682 .81986 .5634 .81309 .55473 Mtetra
.642 .742 .921 r
.81309 .55473 .81986 .5634 .83572 .55687 .82924 .55061 Mtetra
.686 .826 .951 r
.82924 .55061 .83572 .55687 .85157 .54956 .84529 .54451 Mtetra
.718 .875 .955 r
.84529 .54451 .85157 .54956 .86751 .54251 .86127 .53699 Mtetra
.719 .862 .95 r
.86127 .53699 .86751 .54251 .88357 .53593 .87733 .52949 Mtetra
.705 .832 .943 r
.87733 .52949 .88357 .53593 .89984 .53052 .89352 .52261 Mtetra
.675 .781 .929 r
.89352 .52261 .89984 .53052 .91628 .52584 .90993 .51702 Mtetra
.655 .75 .92 r
.90993 .51702 .91628 .52584 .93281 .52112 .92653 .51227 Mtetra
.655 .751 .92 r
.92653 .51227 .93281 .52112 .94943 .51632 .94322 .50746 Mtetra
.657 .753 .92 r
.94322 .50746 .94943 .51632 .96611 .51129 .96 .50255 Mtetra
.656 .753 .921 r
.36055 .66611 .36894 .67337 .38261 .66947 .37428 .66211 Mtetra
.658 .752 .919 r
.37428 .66211 .38261 .66947 .39637 .66549 .38807 .65803 Mtetra
.635 .744 .927 r
.38807 .65803 .39637 .66549 .41019 .66144 .40192 .6547 Mtetra
.574 .747 .958 r
.40192 .6547 .41019 .66144 .42406 .65822 .41579 .65281 Mtetra
.508 .765 .989 r
.41579 .65281 .42406 .65822 .43798 .65624 .42973 .65164 Mtetra
.481 .782 .997 r
.42973 .65164 .43798 .65624 .45197 .65486 .44377 .65043 Mtetra
.582 .823 .99 r
.44377 .65043 .45197 .65486 .46606 .65353 .45794 .64737 Mtetra
.681 .797 .937 r
.45794 .64737 .46606 .65353 .48026 .65084 .47223 .64224 Mtetra
.717 .744 .873 r
.47223 .64224 .48026 .65084 .49456 .64625 .4866 .63532 Mtetra
.721 .701 .831 r
.4866 .63532 .49456 .64625 .50894 .64043 .50104 .62737 Mtetra
.705 .665 .808 r
.50104 .62737 .50894 .64043 .52338 .63324 .51551 .61974 Mtetra
.688 .653 .81 r
.51551 .61974 .52338 .63324 .53787 .62594 .53004 .61317 Mtetra
.679 .661 .825 r
.53004 .61317 .53787 .62594 .55242 .61909 .54463 .60736 Mtetra
.669 .673 .845 r
.54463 .60736 .55242 .61909 .56703 .61305 .55928 .60234 Mtetra
.655 .687 .868 r
.55928 .60234 .56703 .61305 .58171 .60752 .57403 .59809 Mtetra
.651 .713 .893 r
.57403 .59809 .58171 .60752 .59647 .60242 .58885 .59403 Mtetra
.649 .738 .914 r
.58885 .59403 .59647 .60242 .61131 .59763 .60376 .58998 Mtetra
.648 .758 .929 r
.60376 .58998 .61131 .59763 .62623 .59307 .61875 .58585 Mtetra
.65 .771 .937 r
.61875 .58585 .62623 .59307 .64123 .58869 .63382 .58159 Mtetra
.653 .777 .939 r
.63382 .58159 .64123 .58869 .65632 .58431 .64897 .57717 Mtetra
.657 .778 .938 r
.64897 .57717 .65632 .58431 .67149 .57995 .66419 .5726 Mtetra
.661 .774 .934 r
.66419 .5726 .67149 .57995 .68675 .57575 .67949 .56789 Mtetra
.664 .763 .924 r
.67949 .56789 .68675 .57575 .70211 .57179 .69487 .56309 Mtetra
.664 .743 .909 r
.69487 .56309 .70211 .57179 .71758 .56815 .71033 .55831 Mtetra
.659 .716 .89 r
.71033 .55831 .71758 .56815 .73316 .56495 .72589 .55371 Mtetra
.64 .681 .873 r
.72589 .55371 .73316 .56495 .74888 .56227 .74158 .5499 Mtetra
.623 .654 .86 r
.74158 .5499 .74888 .56227 .76477 .56042 .75742 .54689 Mtetra
.607 .628 .847 r
.75742 .54689 .76477 .56042 .7808 .55906 .77343 .54467 Mtetra
.585 .606 .839 r
.77343 .54467 .7808 .55906 .79695 .55759 .78963 .54356 Mtetra
.577 .607 .847 r
.78963 .54356 .79695 .55759 .81309 .55473 .80599 .54278 Mtetra
.594 .651 .877 r
.80599 .54278 .81309 .55473 .82924 .55061 .82239 .54096 Mtetra
.631 .717 .909 r
.82239 .54096 .82924 .55061 .84529 .54451 .83873 .53731 Mtetra
.679 .8 .94 r
.83873 .53731 .84529 .54451 .86127 .53699 .85497 .5315 Mtetra
.723 .866 .949 r
.85497 .5315 .86127 .53699 .87733 .52949 .87109 .52375 Mtetra
.725 .861 .945 r
.87109 .52375 .87733 .52949 .89352 .52261 .88727 .51594 Mtetra
.708 .83 .94 r
.88727 .51594 .89352 .52261 .90993 .51702 .9036 .50886 Mtetra
.673 .777 .928 r
.9036 .50886 .90993 .51702 .92653 .51227 .92018 .50328 Mtetra
.654 .749 .919 r
.92018 .50328 .92653 .51227 .94322 .50746 .93695 .49848 Mtetra
.655 .751 .92 r
.93695 .49848 .94322 .50746 .96 .50255 .95381 .49359 Mtetra
.658 .752 .919 r
.35209 .65872 .36055 .66611 .37428 .66211 .36586 .6546 Mtetra
.643 .746 .924 r
.36586 .6546 .37428 .66211 .38807 .65803 .37968 .65098 Mtetra
.579 .74 .953 r
.37968 .65098 .38807 .65803 .40192 .6547 .39351 .64905 Mtetra
.508 .759 .986 r
.39351 .64905 .40192 .6547 .41579 .65281 .40741 .64796 Mtetra
.475 .772 .996 r
.40741 .64796 .41579 .65281 .42973 .65164 .42139 .64696 Mtetra
.588 .818 .987 r
.42139 .64696 .42973 .65164 .44377 .65043 .43553 .64386 Mtetra
.69 .788 .925 r
.43553 .64386 .44377 .65043 .45794 .64737 .4498 .63839 Mtetra
.728 .739 .86 r
.4498 .63839 .45794 .64737 .47223 .64224 .46418 .63072 Mtetra
.725 .694 .82 r
.46418 .63072 .47223 .64224 .4866 .63532 .47861 .62223 Mtetra
.704 .665 .808 r
.47861 .62223 .4866 .63532 .50104 .62737 .49308 .61464 Mtetra
.689 .665 .821 r
.49308 .61464 .50104 .62737 .51551 .61974 .50758 .6082 Mtetra
.673 .678 .847 r
.50758 .6082 .51551 .61974 .53004 .61317 .52215 .60298 Mtetra
.651 .696 .879 r
.52215 .60298 .53004 .61317 .54463 .60736 .53679 .59894 Mtetra
.64 .733 .916 r
.53679 .59894 .54463 .60736 .55928 .60234 .55151 .59524 Mtetra
.633 .767 .944 r
.55151 .59524 .55928 .60234 .57403 .59809 .56631 .59156 Mtetra
.634 .785 .954 r
.56631 .59156 .57403 .59809 .58885 .59403 .5812 .58769 Mtetra
.636 .792 .957 r
.5812 .58769 .58885 .59403 .60376 .58998 .59617 .58369 Mtetra
.64 .796 .957 r
.59617 .58369 .60376 .58998 .61875 .58585 .61122 .57953 Mtetra
.644 .797 .956 r
.61122 .57953 .61875 .58585 .63382 .58159 .62636 .57522 Mtetra
.648 .798 .955 r
.62636 .57522 .63382 .58159 .64897 .57717 .64157 .57076 Mtetra
.652 .8 .953 r
.64157 .57076 .64897 .57717 .66419 .5726 .65685 .56615 Mtetra
.656 .801 .952 r
.65685 .56615 .66419 .5726 .67949 .56789 .67222 .56138 Mtetra
.66 .802 .951 r
.67222 .56138 .67949 .56789 .69487 .56309 .68766 .55646 Mtetra
.664 .801 .948 r
.68766 .55646 .69487 .56309 .71033 .55831 .70318 .5514 Mtetra
.67 .796 .942 r
.70318 .5514 .71033 .55831 .72589 .55371 .71876 .54614 Mtetra
.671 .779 .93 r
.71876 .54614 .72589 .55371 .74158 .5499 .73443 .54089 Mtetra
.663 .741 .908 r
.73443 .54089 .74158 .5499 .75742 .54689 .75021 .53599 Mtetra
.636 .689 .883 r
.75021 .53599 .75742 .54689 .77343 .54467 .76615 .53229 Mtetra
.608 .65 .866 r
.76615 .53229 .77343 .54467 .78963 .54356 .7823 .52985 Mtetra
.584 .618 .851 r
.7823 .52985 .78963 .54356 .80599 .54278 .79865 .5286 Mtetra
.565 .601 .848 r
.79865 .5286 .80599 .54278 .82239 .54096 .81522 .52829 Mtetra
.578 .633 .87 r
.81522 .52829 .82239 .54096 .83873 .53731 .83184 .52717 Mtetra
.624 .706 .905 r
.83184 .52717 .83873 .53731 .85497 .5315 .84838 .52377 Mtetra
.68 .79 .932 r
.84838 .52377 .85497 .5315 .87109 .52375 .86477 .5179 Mtetra
.73 .861 .943 r
.86477 .5179 .87109 .52375 .88727 .51594 .88102 .50983 Mtetra
.728 .855 .941 r
.88102 .50983 .88727 .51594 .9036 .50886 .89734 .50183 Mtetra
.708 .823 .936 r
.89734 .50183 .9036 .50886 .92018 .50328 .91382 .49469 Mtetra
.666 .767 .925 r
.91382 .49469 .92018 .50328 .93695 .49848 .9306 .48932 Mtetra
.654 .748 .919 r
.9306 .48932 .93695 .49848 .95381 .49359 .94754 .48445 Mtetra
.651 .749 .921 r
.34355 .6512 .35209 .65872 .36586 .6546 .35735 .64731 Mtetra
.596 .74 .945 r
.35735 .64731 .36586 .6546 .37968 .65098 .37116 .64498 Mtetra
.52 .754 .981 r
.37116 .64498 .37968 .65098 .39351 .64905 .385 .64382 Mtetra
.468 .758 .993 r
.385 .64382 .39351 .64905 .40741 .64796 .39893 .64311 Mtetra
.573 .809 .988 r
.39893 .64311 .40741 .64796 .42139 .64696 .41302 .64038 Mtetra
.691 .788 .925 r
.41302 .64038 .42139 .64696 .43553 .64386 .42727 .63487 Mtetra
.734 .74 .856 r
.42727 .63487 .43553 .64386 .4498 .63839 .44165 .6268 Mtetra
.731 .695 .816 r
.44165 .6268 .4498 .63839 .46418 .63072 .45609 .61788 Mtetra
.706 .67 .812 r
.45609 .61788 .46418 .63072 .47861 .62223 .47055 .61023 Mtetra
.69 .677 .832 r
.47055 .61023 .47861 .62223 .49308 .61464 .48504 .60391 Mtetra
.659 .689 .867 r
.48504 .60391 .49308 .61464 .50758 .6082 .49957 .59947 Mtetra
.637 .725 .911 r
.49957 .59947 .50758 .6082 .52215 .60298 .51418 .59591 Mtetra
.624 .765 .947 r
.51418 .59591 .52215 .60298 .53679 .59894 .52887 .59248 Mtetra
.624 .784 .958 r
.52887 .59248 .53679 .59894 .55151 .59524 .54365 .58887 Mtetra
.628 .789 .959 r
.54365 .58887 .55151 .59524 .56631 .59156 .55852 .5851 Mtetra
.636 .789 .956 r
.55852 .5851 .56631 .59156 .5812 .58769 .57346 .58112 Mtetra
.646 .79 .951 r
.57346 .58112 .5812 .58769 .59617 .58369 .58849 .57682 Mtetra
.649 .784 .946 r
.58849 .57682 .59617 .58369 .61122 .57953 .6036 .57243 Mtetra
.652 .779 .942 r
.6036 .57243 .61122 .57953 .62636 .57522 .61879 .56797 Mtetra
.653 .777 .939 r
.61879 .56797 .62636 .57522 .64157 .57076 .63406 .56347 Mtetra
.654 .777 .939 r
.63406 .56347 .64157 .57076 .65685 .56615 .64941 .55892 Mtetra
.654 .78 .941 r
.64941 .55892 .65685 .56615 .67222 .56138 .66485 .5543 Mtetra
.655 .786 .944 r
.66485 .5543 .67222 .56138 .68766 .55646 .68036 .54958 Mtetra
.663 .795 .946 r
.68036 .54958 .68766 .55646 .70318 .5514 .69595 .54455 Mtetra
.668 .799 .945 r
.69595 .54455 .70318 .5514 .71876 .54614 .71161 .5393 Mtetra
.672 .802 .944 r
.71161 .5393 .71876 .54614 .73443 .54089 .72734 .53387 Mtetra
.677 .8 .94 r
.72734 .53387 .73443 .54089 .75021 .53599 .74314 .52826 Mtetra
.675 .78 .93 r
.74314 .52826 .75021 .53599 .76615 .53229 .75903 .52277 Mtetra
.654 .73 .905 r
.75903 .52277 .76615 .53229 .7823 .52985 .77507 .51819 Mtetra
.61 .667 .88 r
.77507 .51819 .7823 .52985 .79865 .5286 .79136 .51552 Mtetra
.581 .629 .864 r
.79136 .51552 .79865 .5286 .81522 .52829 .80788 .51425 Mtetra
.554 .6 .854 r
.80788 .51425 .81522 .52829 .83184 .52717 .82465 .51431 Mtetra
.569 .628 .871 r
.82465 .51431 .83184 .52717 .84838 .52377 .84148 .51351 Mtetra
.623 .707 .905 r
.84148 .51351 .84838 .52377 .86477 .5179 .85819 .51005 Mtetra
.69 .794 .929 r
.85819 .51005 .86477 .5179 .88102 .50983 .8747 .50371 Mtetra
.739 .859 .937 r
.8747 .50371 .88102 .50983 .89734 .50183 .89106 .49522 Mtetra
.727 .844 .936 r
.89106 .49522 .89734 .50183 .91382 .49469 .90753 .48719 Mtetra
.699 .811 .935 r
.90753 .48719 .91382 .49469 .9306 .48932 .92422 .48036 Mtetra
.66 .758 .923 r
.92422 .48036 .9306 .48932 .94754 .48445 .94119 .47517 Mtetra
.62 .742 .934 r
.33492 .64368 .34355 .6512 .35735 .64731 .34872 .64071 Mtetra
.542 .745 .97 r
.34872 .64071 .35735 .64731 .37116 .64498 .36253 .63934 Mtetra
.468 .746 .989 r
.36253 .63934 .37116 .64498 .385 .64382 .37639 .63882 Mtetra
.534 .792 .992 r
.37639 .63882 .385 .64382 .39893 .64311 .39041 .63686 Mtetra
.681 .796 .936 r
.39041 .63686 .39893 .64311 .41302 .64038 .40463 .63166 Mtetra
.735 .747 .861 r
.40463 .63166 .41302 .64038 .42727 .63487 .41901 .62361 Mtetra
.738 .702 .818 r
.41901 .62361 .42727 .63487 .44165 .6268 .43346 .61429 Mtetra
.712 .677 .814 r
.43346 .61429 .44165 .6268 .45609 .61788 .44792 .60636 Mtetra
.692 .686 .84 r
.44792 .60636 .45609 .61788 .47055 .61023 .46239 .60006 Mtetra
.65 .697 .881 r
.46239 .60006 .47055 .61023 .48504 .60391 .47689 .59603 Mtetra
.624 .743 .932 r
.47689 .59603 .48504 .60391 .49957 .59947 .49147 .59278 Mtetra
.618 .775 .956 r
.49147 .59278 .49957 .59947 .51418 .59591 .50613 .58942 Mtetra
.621 .783 .959 r
.50613 .58942 .51418 .59591 .52887 .59248 .52088 .58589 Mtetra
.636 .786 .953 r
.52088 .58589 .52887 .59248 .54365 .58887 .53571 .58193 Mtetra
.648 .78 .944 r
.53571 .58193 .54365 .58887 .55852 .5851 .55063 .57763 Mtetra
.653 .768 .934 r
.55063 .57763 .55852 .5851 .57346 .58112 .56563 .57322 Mtetra
.655 .759 .926 r
.56563 .57322 .57346 .58112 .58849 .57682 .5807 .56876 Mtetra
.655 .756 .924 r
.5807 .56876 .58849 .57682 .6036 .57243 .59587 .5643 Mtetra
.655 .755 .923 r
.59587 .5643 .6036 .57243 .61879 .56797 .61111 .5598 Mtetra
.656 .755 .923 r
.61111 .5598 .61879 .56797 .63406 .56347 .62644 .55525 Mtetra
.62644 .55525 .63406 .56347 .64941 .55892 .64185 .55065 Mtetra
.657 .755 .923 r
.64185 .55065 .64941 .55892 .66485 .5543 .65735 .54601 Mtetra
.656 .756 .923 r
.65735 .54601 .66485 .5543 .68036 .54958 .67293 .54137 Mtetra
.656 .759 .925 r
.67293 .54137 .68036 .54958 .69595 .54455 .6886 .53668 Mtetra
.658 .77 .932 r
.6886 .53668 .69595 .54455 .71161 .5393 .70435 .53187 Mtetra
.665 .785 .938 r
.70435 .53187 .71161 .5393 .72734 .53387 .72016 .52672 Mtetra
.676 .798 .94 r
.72016 .52672 .72734 .53387 .74314 .52826 .73604 .52112 Mtetra
.679 .801 .94 r
.73604 .52112 .74314 .52826 .75903 .52277 .75198 .51534 Mtetra
.683 .795 .934 r
.75198 .51534 .75903 .52277 .77507 .51819 .768 .50944 Mtetra
.664 .755 .918 r
.768 .50944 .77507 .51819 .79136 .51552 .78416 .50433 Mtetra
.61 .679 .891 r
.78416 .50433 .79136 .51552 .80788 .51425 .80061 .50156 Mtetra
.573 .634 .874 r
.80061 .50156 .80788 .51425 .82465 .51431 .81732 .50049 Mtetra
.543 .601 .861 r
.81732 .50049 .82465 .51431 .84148 .51351 .83431 .50087 Mtetra
.568 .635 .877 r
.83431 .50087 .84148 .51351 .85819 .51005 .85131 .49997 Mtetra
.631 .717 .909 r
.85131 .49997 .85819 .51005 .8747 .50371 .86815 .49609 Mtetra
.709 .81 .928 r
.86815 .49609 .8747 .50371 .89106 .49522 .88473 .48884 Mtetra
.744 .857 .932 r
.88473 .48884 .89106 .49522 .90753 .48719 .90122 .48004 Mtetra
.723 .831 .932 r
.90122 .48004 .90753 .48719 .92422 .48036 .91786 .47212 Mtetra
.683 .789 .93 r
.91786 .47212 .92422 .48036 .94119 .47517 .93479 .46586 Mtetra
.57 .736 .954 r
.3262 .63643 .33492 .64368 .34872 .64071 .33997 .63464 Mtetra
.486 .741 .984 r
.33997 .63464 .34872 .64071 .36253 .63934 .35378 .63401 Mtetra
.483 .764 .993 r
.35378 .63401 .36253 .63934 .37639 .63882 .36771 .63303 Mtetra
.653 .804 .955 r
.36771 .63303 .37639 .63882 .39041 .63686 .38187 .62863 Mtetra
.729 .757 .875 r
.38187 .62863 .39041 .63686 .40463 .63166 .39623 .6211 Mtetra
.746 .716 .824 r
.39623 .6211 .40463 .63166 .41901 .62361 .4107 .61147 Mtetra
.721 .686 .815 r
.4107 .61147 .41901 .62361 .43346 .61429 .42518 .60299 Mtetra
.697 .692 .841 r
.42518 .60299 .43346 .61429 .44792 .60636 .43964 .59641 Mtetra
.648 .702 .886 r
.43964 .59641 .44792 .60636 .46239 .60006 .45411 .59245 Mtetra
.617 .749 .94 r
.45411 .59245 .46239 .60006 .47689 .59603 .46865 .58933 Mtetra
.613 .774 .958 r
.46865 .58933 .47689 .59603 .49147 .59278 .48327 .58609 Mtetra
.623 .778 .955 r
.48327 .58609 .49147 .59278 .50613 .58942 .49799 .58252 Mtetra
.645 .78 .946 r
.49799 .58252 .50613 .58942 .52088 .58589 .5128 .57831 Mtetra
.653 .765 .931 r
.5128 .57831 .52088 .58589 .53571 .58193 .52768 .57392 Mtetra
.653 .755 .924 r
.52768 .57392 .53571 .58193 .55063 .57763 .54265 .56954 Mtetra
.652 .754 .924 r
.54265 .56954 .55063 .57763 .56563 .57322 .55771 .56516 Mtetra
.653 .756 .925 r
.55771 .56516 .56563 .57322 .5807 .56876 .57284 .56074 Mtetra
.653 .758 .926 r
.57284 .56074 .5807 .56876 .59587 .5643 .58806 .55626 Mtetra
.654 .759 .927 r
.58806 .55626 .59587 .5643 .61111 .5598 .60336 .55173 Mtetra
.655 .76 .927 r
.60336 .55173 .61111 .5598 .62644 .55525 .61875 .54713 Mtetra
.656 .76 .926 r
.61875 .54713 .62644 .55525 .64185 .55065 .63422 .54248 Mtetra
.657 .76 .926 r
.63422 .54248 .64185 .55065 .65735 .54601 .64978 .53776 Mtetra
.658 .76 .925 r
.64978 .53776 .65735 .54601 .67293 .54137 .66541 .53299 Mtetra
.659 .758 .923 r
.66541 .53299 .67293 .54137 .6886 .53668 .68114 .52817 Mtetra
.658 .756 .922 r
.68114 .52817 .6886 .53668 .70435 .53187 .69695 .52335 Mtetra
.657 .756 .923 r
.69695 .52335 .70435 .53187 .72016 .52672 .71285 .51855 Mtetra
.66 .767 .929 r
.71285 .51855 .72016 .52672 .73604 .52112 .72884 .51355 Mtetra
.676 .79 .935 r
.72884 .51355 .73604 .52112 .75198 .51534 .74486 .5079 Mtetra
.684 .797 .935 r
.74486 .5079 .75198 .51534 .768 .50944 .76095 .5019 Mtetra
.686 .797 .933 r
.76095 .5019 .768 .50944 .78416 .50433 .77711 .49576 Mtetra
.665 .764 .924 r
.77711 .49576 .78416 .50433 .80061 .50156 .79342 .49047 Mtetra
.602 .681 .897 r
.79342 .49047 .80061 .50156 .81732 .50049 .81006 .4879 Mtetra
.558 .632 .88 r
.81006 .4879 .81732 .50049 .83431 .50087 .82699 .48731 Mtetra
.533 .603 .869 r
.82699 .48731 .83431 .50087 .85131 .49997 .84419 .48794 Mtetra
.578 .654 .888 r
.84419 .48794 .85131 .49997 .86815 .49609 .86133 .4864 Mtetra
.651 .738 .914 r
.86133 .4864 .86815 .49609 .88473 .48884 .87825 .4816 Mtetra
.733 .832 .926 r
.87825 .4816 .88473 .48884 .90122 .48004 .89487 .4732 Mtetra
.742 .847 .929 r
.89487 .4732 .90122 .48004 .91786 .47212 .91151 .4644 Mtetra
.714 .816 .929 r
.91151 .4644 .91786 .47212 .93479 .46586 .92836 .4568 Mtetra
.525 .741 .973 r
.31734 .6298 .3262 .63643 .33997 .63464 .33112 .62868 Mtetra
.46 .736 .987 r
.33112 .62868 .33997 .63464 .35378 .63401 .34495 .62836 Mtetra
.59 .793 .977 r
.34495 .62836 .35378 .63401 .36771 .63303 .35901 .6255 Mtetra
.709 .77 .9 r
.35901 .6255 .36771 .63303 .38187 .62863 .37331 .61912 Mtetra
.754 .736 .836 r
.37331 .61912 .38187 .62863 .39623 .6211 .3878 .60945 Mtetra
.734 .697 .815 r
.3878 .60945 .39623 .6211 .4107 .61147 .40231 .60016 Mtetra
.707 .696 .837 r
.40231 .60016 .4107 .61147 .42518 .60299 .41678 .59296 Mtetra
.655 .704 .883 r
.41678 .59296 .42518 .60299 .43964 .59641 .43123 .58867 Mtetra
.614 .746 .939 r
.43123 .58867 .43964 .59641 .45411 .59245 .44573 .58563 Mtetra
.609 .77 .957 r
.44573 .58563 .45411 .59245 .46865 .58933 .46031 .58249 Mtetra
.626 .776 .953 r
.46031 .58249 .46865 .58933 .48327 .58609 .475 .57887 Mtetra
.649 .773 .939 r
.475 .57887 .48327 .58609 .49799 .58252 .48978 .57459 Mtetra
.653 .757 .926 r
.48978 .57459 .49799 .58252 .5128 .57831 .50463 .5702 Mtetra
.651 .753 .924 r
.50463 .5702 .5128 .57831 .52768 .57392 .51958 .56589 Mtetra
.651 .756 .926 r
.51958 .56589 .52768 .57392 .54265 .56954 .5346 .56154 Mtetra
.65 .757 .928 r
.5346 .56154 .54265 .56954 .55771 .56516 .54971 .55718 Mtetra
.651 .759 .929 r
.54971 .55718 .55771 .56516 .57284 .56074 .5649 .55276 Mtetra
.652 .761 .929 r
.5649 .55276 .57284 .56074 .58806 .55626 .58018 .54827 Mtetra
.654 .762 .929 r
.58018 .54827 .58806 .55626 .60336 .55173 .59554 .5437 Mtetra
.655 .763 .929 r
.59554 .5437 .60336 .55173 .61875 .54713 .61098 .53906 Mtetra
.656 .763 .929 r
.61098 .53906 .61875 .54713 .63422 .54248 .62651 .53434 Mtetra
.657 .763 .928 r
.62651 .53434 .63422 .54248 .64978 .53776 .64213 .52955 Mtetra
.659 .763 .927 r
.64213 .52955 .64978 .53776 .66541 .53299 .65783 .52468 Mtetra
.66 .762 .926 r
.65783 .52468 .66541 .53299 .68114 .52817 .67361 .51975 Mtetra
.66 .761 .924 r
.67361 .51975 .68114 .52817 .69695 .52335 .68948 .51481 Mtetra
.66 .759 .923 r
.68948 .51481 .69695 .52335 .71285 .51855 .70544 .50983 Mtetra
.658 .755 .922 r
.70544 .50983 .71285 .51855 .72884 .51355 .72149 .50491 Mtetra
.66 .759 .923 r
.72149 .50491 .72884 .51355 .74486 .5079 .73763 .49989 Mtetra
.675 .782 .93 r
.73763 .49989 .74486 .5079 .76095 .5019 .75382 .49419 Mtetra
.687 .795 .932 r
.75382 .49419 .76095 .5019 .77711 .49576 .77005 .48798 Mtetra
.689 .795 .931 r
.77005 .48798 .77711 .49576 .79342 .49047 .78635 .48166 Mtetra
.657 .759 .925 r
.78635 .48166 .79342 .49047 .81006 .4879 .80285 .47662 Mtetra
.587 .673 .899 r
.80285 .47662 .81006 .4879 .82699 .48731 .81971 .4746 Mtetra
.538 .622 .883 r
.81971 .4746 .82699 .48731 .84419 .48794 .83691 .47476 Mtetra
.529 .61 .877 r
.83691 .47476 .84419 .48794 .86133 .4864 .8543 .47535 Mtetra
.604 .69 .903 r
.8543 .47535 .86133 .4864 .87825 .4816 .8715 .47252 Mtetra
.688 .772 .915 r
.8715 .47252 .87825 .4816 .89487 .4732 .88841 .46599 Mtetra
.749 .842 .921 r
.88841 .46599 .89487 .4732 .91151 .4644 .9051 .45678 Mtetra
.73 .827 .925 r
.9051 .45678 .91151 .4644 .92836 .4568 .92195 .44839 Mtetra
.48 .731 .981 r
.30837 .62337 .31734 .6298 .33112 .62868 .32215 .62292 Mtetra
.496 .759 .989 r
.32215 .62292 .33112 .62868 .34495 .62836 .33607 .62186 Mtetra
.674 .791 .936 r
.33607 .62186 .34495 .62836 .35901 .6255 .35028 .61683 Mtetra
.745 .752 .858 r
.35028 .61683 .35901 .6255 .37331 .61912 .36474 .60816 Mtetra
.749 .712 .817 r
.36474 .60816 .37331 .61912 .3878 .60945 .37929 .59803 Mtetra
.72 .698 .829 r
.37929 .59803 .3878 .60945 .40231 .60016 .3938 .58996 Mtetra
.674 .707 .872 r
.3938 .58996 .40231 .60016 .41678 .59296 .40825 .58476 Mtetra
.617 .736 .931 r
.40825 .58476 .41678 .59296 .43123 .58867 .42271 .58167 Mtetra
.606 .765 .956 r
.42271 .58167 .43123 .58867 .44573 .58563 .43725 .57863 Mtetra
.622 .771 .952 r
.43725 .57863 .44573 .58563 .46031 .58249 .4519 .57511 Mtetra
.649 .77 .937 r
.4519 .57511 .46031 .58249 .475 .57887 .46665 .57081 Mtetra
.652 .754 .925 r
.46665 .57081 .475 .57887 .48978 .57459 .48148 .56646 Mtetra
.65 .753 .925 r
.48148 .56646 .48978 .57459 .50463 .5702 .49639 .56217 Mtetra
.648 .756 .928 r
.49639 .56217 .50463 .5702 .51958 .56589 .51138 .55788 Mtetra
.648 .758 .929 r
.51138 .55788 .51958 .56589 .5346 .56154 .52646 .55356 Mtetra
.65 .76 .93 r
.52646 .55356 .5346 .56154 .54971 .55718 .54163 .54914 Mtetra
.654 .761 .928 r
.54163 .54914 .54971 .55718 .5649 .55276 .55687 .54455 Mtetra
.656 .758 .925 r
.55687 .54455 .5649 .55276 .58018 .54827 .57221 .5399 Mtetra
.656 .756 .923 r
.57221 .5399 .58018 .54827 .59554 .5437 .58762 .53522 Mtetra
.656 .754 .922 r
.58762 .53522 .59554 .5437 .61098 .53906 .60313 .53054 Mtetra
.655 .754 .922 r
.60313 .53054 .61098 .53906 .62651 .53434 .61872 .52583 Mtetra
.655 .755 .924 r
.61872 .52583 .62651 .53434 .64213 .52955 .6344 .52111 Mtetra
.656 .758 .925 r
.6344 .52111 .64213 .52955 .65783 .52468 .65016 .51631 Mtetra
.659 .763 .926 r
.65016 .51631 .65783 .52468 .67361 .51975 .66601 .51135 Mtetra
.662 .764 .926 r
.66601 .51135 .67361 .51975 .68948 .51481 .68194 .50628 Mtetra
.662 .762 .924 r
.68194 .50628 .68948 .51481 .70544 .50983 .69796 .50117 Mtetra
.661 .76 .923 r
.69796 .50117 .70544 .50983 .72149 .50491 .71407 .49607 Mtetra
.659 .756 .921 r
.71407 .49607 .72149 .50491 .73763 .49989 .73027 .49103 Mtetra
.66 .757 .922 r
.73027 .49103 .73763 .49989 .75382 .49419 .74657 .48592 Mtetra
.679 .78 .926 r
.74657 .48592 .75382 .49419 .77005 .48798 .7629 .48001 Mtetra
.69 .793 .928 r
.7629 .48001 .77005 .48798 .78635 .48166 .77927 .47359 Mtetra
.688 .791 .928 r
.77927 .47359 .78635 .48166 .80285 .47662 .79574 .46721 Mtetra
.635 .738 .923 r
.79574 .46721 .80285 .47662 .81971 .4746 .81247 .46302 Mtetra
.564 .659 .9 r
.81247 .46302 .81971 .4746 .83691 .47476 .8296 .46181 Mtetra
.516 .609 .884 r
.8296 .46181 .83691 .47476 .8543 .47535 .84707 .46276 Mtetra
.552 .635 .887 r
.84707 .46276 .8543 .47535 .8715 .47252 .86456 .46223 Mtetra
.637 .725 .911 r
.86456 .46223 .8715 .47252 .88841 .46599 .88179 .45788 Mtetra
.732 .815 .916 r
.88179 .45788 .88841 .46599 .9051 .45678 .89865 .44935 Mtetra
.746 .839 .921 r
.89865 .44935 .9051 .45678 .92195 .44839 .91551 .44016 Mtetra
.46 .725 .983 r
.29931 .61694 .30837 .62337 .32215 .62292 .31311 .61676 Mtetra
.588 .78 .971 r
.31311 .61676 .32215 .62292 .33607 .62186 .32716 .61403 Mtetra
.715 .766 .893 r
.32716 .61403 .33607 .62186 .35028 .61683 .34152 .60728 Mtetra
.76 .738 .833 r
.34152 .60728 .35028 .61683 .36474 .60816 .3561 .59702 Mtetra
.739 .708 .823 r
.3561 .59702 .36474 .60816 .37929 .59803 .37067 .58764 Mtetra
.703 .713 .856 r
.37067 .58764 .37929 .59803 .3938 .58996 .38516 .58092 Mtetra
.633 .721 .911 r
.38516 .58092 .3938 .58996 .40825 .58476 .3996 .57738 Mtetra
.603 .755 .951 r
.3996 .57738 .40825 .58476 .42271 .58167 .4141 .57449 Mtetra
.613 .765 .952 r
.4141 .57449 .42271 .58167 .43725 .57863 .4287 .57125 Mtetra
.646 .77 .938 r
.4287 .57125 .43725 .57863 .4519 .57511 .44341 .56701 Mtetra
.652 .754 .925 r
.44341 .56701 .4519 .57511 .46665 .57081 .45821 .56264 Mtetra
.649 .752 .925 r
.45821 .56264 .46665 .57081 .48148 .56646 .47309 .55836 Mtetra
.646 .755 .928 r
.47309 .55836 .48148 .56646 .49639 .56217 .48806 .55412 Mtetra
.648 .758 .929 r
.48806 .55412 .49639 .56217 .51138 .55788 .5031 .54981 Mtetra
.654 .76 .928 r
.5031 .54981 .51138 .55788 .52646 .55356 .51824 .54526 Mtetra
.657 .756 .923 r
.51824 .54526 .52646 .55356 .54163 .54914 .53346 .54057 Mtetra
.658 .751 .919 r
.53346 .54057 .54163 .54914 .55687 .54455 .54876 .53585 Mtetra
.657 .749 .918 r
.54876 .53585 .55687 .54455 .57221 .5399 .56415 .53114 Mtetra
.656 .748 .918 r
.56415 .53114 .57221 .5399 .58762 .53522 .57962 .52642 Mtetra
.57962 .52642 .58762 .53522 .60313 .53054 .59518 .52168 Mtetra
.59518 .52168 .60313 .53054 .61872 .52583 .61083 .51692 Mtetra
.655 .748 .918 r
.61083 .51692 .61872 .52583 .6344 .52111 .62657 .51216 Mtetra
.654 .748 .918 r
.62657 .51216 .6344 .52111 .65016 .51631 .6424 .5074 Mtetra
.654 .75 .92 r
.6424 .5074 .65016 .51631 .66601 .51135 .65831 .50261 Mtetra
.657 .756 .923 r
.65831 .50261 .66601 .51135 .68194 .50628 .67432 .49768 Mtetra
.662 .763 .925 r
.67432 .49768 .68194 .50628 .69796 .50117 .6904 .4925 Mtetra
.664 .763 .924 r
.6904 .4925 .69796 .50117 .71407 .49607 .70657 .48725 Mtetra
.662 .76 .923 r
.70657 .48725 .71407 .49607 .73027 .49103 .72283 .48203 Mtetra
.659 .756 .921 r
.72283 .48203 .73027 .49103 .74657 .48592 .73919 .4769 Mtetra
.662 .758 .921 r
.73919 .4769 .74657 .48592 .7629 .48001 .75564 .47163 Mtetra
.686 .783 .924 r
.75564 .47163 .7629 .48001 .77927 .47359 .7721 .46533 Mtetra
.694 .79 .924 r
.7721 .46533 .77927 .47359 .79574 .46721 .78862 .45865 Mtetra
.678 .778 .926 r
.78862 .45865 .79574 .46721 .81247 .46302 .80528 .45262 Mtetra
.596 .702 .917 r
.80528 .45262 .81247 .46302 .8296 .46181 .82233 .44991 Mtetra
.528 .638 .902 r
.82233 .44991 .8296 .46181 .84707 .46276 .83977 .44998 Mtetra
.51 .612 .89 r
.83977 .44998 .84707 .46276 .86456 .46223 .85747 .45099 Mtetra
.596 .687 .906 r
.85747 .45099 .86456 .46223 .88179 .45788 .87495 .44834 Mtetra
.693 .769 .91 r
.87495 .44834 .88179 .45788 .89865 .44935 .89208 .44147 Mtetra
.752 .831 .913 r
.89208 .44147 .89865 .44935 .91551 .44016 .90899 .4319 Mtetra
.476 .735 .984 r
.29014 .61055 .29931 .61694 .31311 .61676 .304 .61002 Mtetra
.657 .783 .941 r
.304 .61002 .31311 .61676 .32716 .61403 .3182 .60551 Mtetra
.745 .757 .863 r
.3182 .60551 .32716 .61403 .34152 .60728 .33271 .59687 Mtetra
.758 .725 .821 r
.33271 .59687 .34152 .60728 .3561 .59702 .34736 .58628 Mtetra
.727 .714 .838 r
.34736 .58628 .3561 .59702 .37067 .58764 .36193 .57794 Mtetra
.669 .719 .886 r
.36193 .57794 .37067 .58764 .38516 .58092 .3764 .573 Mtetra
.607 .743 .941 r
.3764 .573 .38516 .58092 .3996 .57738 .39085 .57008 Mtetra
.603 .759 .953 r
.39085 .57008 .3996 .57738 .4141 .57449 .4054 .5671 Mtetra
.636 .768 .942 r
.4054 .5671 .4141 .57449 .4287 .57125 .42007 .56316 Mtetra
.652 .755 .925 r
.42007 .56316 .4287 .57125 .44341 .56701 .43484 .55875 Mtetra
.648 .751 .925 r
.43484 .55875 .44341 .56701 .45821 .56264 .44969 .55447 Mtetra
.646 .754 .928 r
.44969 .55447 .45821 .56264 .47309 .55836 .46462 .55025 Mtetra
.647 .756 .929 r
.46462 .55025 .47309 .55836 .48806 .55412 .47964 .54595 Mtetra
.655 .759 .926 r
.47964 .54595 .48806 .55412 .5031 .54981 .49474 .54132 Mtetra
.658 .753 .92 r
.49474 .54132 .5031 .54981 .51824 .54526 .50993 .53657 Mtetra
.657 .749 .918 r
.50993 .53657 .51824 .54526 .53346 .54057 .52521 .53185 Mtetra
.656 .749 .918 r
.52521 .53185 .53346 .54057 .54876 .53585 .54056 .52715 Mtetra
.655 .75 .92 r
.54056 .52715 .54876 .53585 .56415 .53114 .55601 .52243 Mtetra
.655 .752 .921 r
.55601 .52243 .56415 .53114 .57962 .52642 .57154 .51769 Mtetra
.656 .752 .921 r
.57154 .51769 .57962 .52642 .59518 .52168 .58716 .5129 Mtetra
.58716 .5129 .59518 .52168 .61083 .51692 .60287 .50807 Mtetra
.656 .752 .92 r
.60287 .50807 .61083 .51692 .62657 .51216 .61866 .50321 Mtetra
.656 .751 .92 r
.61866 .50321 .62657 .51216 .6424 .5074 .63455 .49833 Mtetra
.655 .749 .919 r
.63455 .49833 .6424 .5074 .65831 .50261 .65053 .49347 Mtetra
.654 .748 .919 r
.65053 .49347 .65831 .50261 .67432 .49768 .6666 .48865 Mtetra
.656 .752 .921 r
.6666 .48865 .67432 .49768 .6904 .4925 .68276 .48369 Mtetra
.663 .762 .923 r
.68276 .48369 .6904 .4925 .70657 .48725 .69899 .4784 Mtetra
.665 .762 .923 r
.69899 .4784 .70657 .48725 .72283 .48203 .71532 .47303 Mtetra
.663 .759 .922 r
.71532 .47303 .72283 .48203 .73919 .4769 .73174 .46771 Mtetra
.659 .754 .921 r
.73174 .46771 .73919 .4769 .75564 .47163 .74826 .46251 Mtetra
.67 .762 .919 r
.74826 .46251 .75564 .47163 .7721 .46533 .76484 .45682 Mtetra
.693 .786 .922 r
.76484 .45682 .7721 .46533 .78862 .45865 .78144 .45014 Mtetra
.694 .788 .923 r
.78144 .45014 .78862 .45865 .80528 .45262 .79812 .44338 Mtetra
.642 .752 .928 r
.79812 .44338 .80528 .45262 .82233 .44991 .81507 .43871 Mtetra
.554 .668 .913 r
.81507 .43871 .82233 .44991 .83977 .44998 .83245 .43759 Mtetra
.497 .614 .899 r
.83245 .43759 .83977 .44998 .85747 .45099 .85023 .43883 Mtetra
.55 .648 .899 r
.85023 .43883 .85747 .45099 .87495 .44834 .86796 .43806 Mtetra
.651 .737 .912 r
.86796 .43806 .87495 .44834 .89208 .44147 .88537 .43296 Mtetra
.744 .815 .908 r
.88537 .43296 .89208 .44147 .90899 .4319 .90241 .42365 Mtetra
.532 .752 .977 r
.28089 .60393 .29014 .61055 .304 .61002 .29485 .60245 Mtetra
.696 .771 .91 r
.29485 .60245 .304 .61002 .3182 .60551 .30918 .59653 Mtetra
.762 .751 .843 r
.30918 .59653 .3182 .60551 .33271 .59687 .32383 .58644 Mtetra
.753 .725 .827 r
.32383 .58644 .33271 .59687 .34736 .58628 .33851 .5763 Mtetra
.714 .726 .859 r
.33851 .5763 .34736 .58628 .36193 .57794 .35307 .56898 Mtetra
.633 .726 .915 r
.35307 .56898 .36193 .57794 .3764 .573 .36752 .56537 Mtetra
.599 .75 .95 r
.36752 .56537 .3764 .573 .39085 .57008 .38202 .56255 Mtetra
.616 .759 .947 r
.38202 .56255 .39085 .57008 .4054 .5671 .39663 .5592 Mtetra
.65 .76 .93 r
.39663 .5592 .4054 .5671 .42007 .56316 .41136 .55483 Mtetra
.649 .751 .924 r
.41136 .55483 .42007 .56316 .43484 .55875 .42618 .5505 Mtetra
.646 .753 .927 r
.42618 .5505 .43484 .55875 .44969 .55447 .44108 .54625 Mtetra
.645 .754 .929 r
.44108 .54625 .44969 .55447 .46462 .55025 .45606 .542 Mtetra
.654 .757 .925 r
.45606 .542 .46462 .55025 .47964 .54595 .47114 .53738 Mtetra
.659 .752 .919 r
.47114 .53738 .47964 .54595 .49474 .54132 .4863 .53259 Mtetra
.656 .749 .918 r
.4863 .53259 .49474 .54132 .50993 .53657 .50154 .52787 Mtetra
.655 .75 .92 r
.50154 .52787 .50993 .53657 .52521 .53185 .51687 .52318 Mtetra
.652 .751 .922 r
.51687 .52318 .52521 .53185 .54056 .52715 .53228 .51857 Mtetra
.653 .755 .925 r
.53228 .51857 .54056 .52715 .55601 .52243 .54779 .5139 Mtetra
.654 .757 .926 r
.54779 .5139 .55601 .52243 .57154 .51769 .56338 .50915 Mtetra
.655 .759 .926 r
.56338 .50915 .57154 .51769 .58716 .5129 .57906 .50431 Mtetra
.657 .759 .925 r
.57906 .50431 .58716 .5129 .60287 .50807 .59482 .49939 Mtetra
.658 .759 .924 r
.59482 .49939 .60287 .50807 .61866 .50321 .61068 .49438 Mtetra
.659 .757 .922 r
.61068 .49438 .61866 .50321 .63455 .49833 .62662 .48932 Mtetra
.657 .753 .921 r
.62662 .48932 .63455 .49833 .65053 .49347 .64266 .48432 Mtetra
.655 .75 .92 r
.64266 .48432 .65053 .49347 .6666 .48865 .65879 .47936 Mtetra
.653 .748 .919 r
.65879 .47936 .6666 .48865 .68276 .48369 .67502 .47447 Mtetra
.657 .752 .92 r
.67502 .47447 .68276 .48369 .69899 .4784 .69133 .4694 Mtetra
.665 .761 .922 r
.69133 .4694 .69899 .4784 .71532 .47303 .70772 .46396 Mtetra
.70772 .46396 .71532 .47303 .73174 .46771 .72421 .4585 Mtetra
.662 .758 .921 r
.72421 .4585 .73174 .46771 .74826 .46251 .74079 .45313 Mtetra
.661 .754 .919 r
.74079 .45313 .74826 .46251 .76484 .45682 .75747 .44779 Mtetra
.685 .773 .918 r
.75747 .44779 .76484 .45682 .78144 .45014 .77417 .44139 Mtetra
.697 .785 .919 r
.77417 .44139 .78144 .45014 .79812 .44338 .79091 .43442 Mtetra
.678 .775 .924 r
.79091 .43442 .79812 .44338 .81507 .43871 .80781 .42827 Mtetra
.58 .699 .924 r
.80781 .42827 .81507 .43871 .83245 .43759 .82515 .42597 Mtetra
.503 .636 .913 r
.82515 .42597 .83245 .43759 .85023 .43883 .84292 .42663 Mtetra
.509 .628 .904 r
.84292 .42663 .85023 .43883 .86796 .43806 .86086 .42727 Mtetra
.617 .713 .914 r
.86086 .42727 .86796 .43806 .88537 .43296 .8785 .42355 Mtetra
.722 .789 .905 r
.8785 .42355 .88537 .43296 .90241 .42365 .89573 .41514 Mtetra
.588 .761 .961 r
.27155 .59694 .28089 .60393 .29485 .60245 .28563 .59432 Mtetra
.72 .764 .887 r
.28563 .59432 .29485 .60245 .30918 .59653 .3001 .58713 Mtetra
.769 .746 .832 r
.3001 .58713 .30918 .59653 .32383 .58644 .31485 .57624 Mtetra
.746 .729 .837 r
.31485 .57624 .32383 .58644 .33851 .5763 .32954 .56677 Mtetra
.691 .731 .881 r
.32954 .56677 .33851 .5763 .35307 .56898 .34409 .56074 Mtetra
.61 .739 .937 r
.34409 .56074 .35307 .56898 .36752 .56537 .35855 .55771 Mtetra
.601 .752 .95 r
.35855 .55771 .36752 .56537 .38202 .56255 .3731 .55479 Mtetra
.634 .76 .939 r
.3731 .55479 .38202 .56255 .39663 .5592 .38778 .55091 Mtetra
.652 .753 .924 r
.38778 .55091 .39663 .5592 .41136 .55483 .40257 .54646 Mtetra
.647 .751 .925 r
.40257 .54646 .41136 .55483 .42618 .5505 .41743 .54216 Mtetra
.644 .752 .928 r
.41743 .54216 .42618 .5505 .44108 .54625 .43238 .53794 Mtetra
.65 .756 .927 r
.43238 .53794 .44108 .54625 .45606 .542 .44742 .53345 Mtetra
.659 .754 .92 r
.44742 .53345 .45606 .542 .47114 .53738 .46255 .52863 Mtetra
.657 .749 .918 r
.46255 .52863 .47114 .53738 .4863 .53259 .47776 .52387 Mtetra
.654 .75 .921 r
.47776 .52387 .4863 .53259 .50154 .52787 .49306 .5192 Mtetra
.65 .752 .924 r
.49306 .5192 .50154 .52787 .51687 .52318 .50844 .51464 Mtetra
.652 .756 .926 r
.50844 .51464 .51687 .52318 .53228 .51857 .52392 .50998 Mtetra
.655 .757 .925 r
.52392 .50998 .53228 .51857 .54779 .5139 .53948 .50514 Mtetra
.656 .755 .923 r
.53948 .50514 .54779 .5139 .56338 .50915 .55513 .50027 Mtetra
.656 .753 .921 r
.55513 .50027 .56338 .50915 .57906 .50431 .57087 .49538 Mtetra
.655 .753 .922 r
.57087 .49538 .57906 .50431 .59482 .49939 .58669 .49048 Mtetra
.656 .755 .923 r
.58669 .49048 .59482 .49939 .61068 .49438 .60261 .48554 Mtetra
.659 .759 .923 r
.60261 .48554 .61068 .49438 .62662 .48932 .61862 .48042 Mtetra
.661 .759 .923 r
.61862 .48042 .62662 .48932 .64266 .48432 .63471 .4752 Mtetra
.658 .754 .921 r
.63471 .4752 .64266 .48432 .65879 .47936 .6509 .47008 Mtetra
.655 .751 .92 r
.6509 .47008 .65879 .47936 .67502 .47447 .66719 .46506 Mtetra
.653 .748 .919 r
.66719 .46506 .67502 .47447 .69133 .4694 .68358 .46009 Mtetra
.661 .754 .92 r
.68358 .46009 .69133 .4694 .70772 .46396 .70005 .45478 Mtetra
.667 .761 .921 r
.70005 .45478 .70772 .46396 .72421 .4585 .71659 .4492 Mtetra
.664 .758 .92 r
.71659 .4492 .72421 .4585 .74079 .45313 .73324 .44369 Mtetra
.66 .755 .921 r
.73324 .44369 .74079 .45313 .75747 .44779 .74999 .43833 Mtetra
.673 .761 .917 r
.74999 .43833 .75747 .44779 .77417 .44139 .7668 .43237 Mtetra
.696 .781 .917 r
.7668 .43237 .77417 .44139 .79091 .43442 .78362 .4254 Mtetra
.693 .781 .919 r
.78362 .4254 .79091 .43442 .80781 .42827 .80054 .41855 Mtetra
.615 .735 .932 r
.80054 .41855 .80781 .42827 .82515 .42597 .81783 .4148 Mtetra
.52 .657 .921 r
.81783 .4148 .82515 .42597 .84292 .42663 .83558 .41465 Mtetra
.482 .62 .91 r
.83558 .41465 .84292 .42663 .86086 .42727 .85365 .41602 Mtetra
.585 .691 .914 r
.85365 .41602 .86086 .42727 .8785 .42355 .87149 .41352 Mtetra
.697 .768 .907 r
.87149 .41352 .8785 .42355 .89573 .41514 .88893 .40622 Mtetra
.629 .765 .944 r
.26214 .58958 .27155 .59694 .28563 .59432 .27634 .58591 Mtetra
.74 .762 .871 r
.27634 .58591 .28563 .59432 .3001 .58713 .29094 .57755 Mtetra
.77 .744 .829 r
.29094 .57755 .3001 .58713 .31485 .57624 .30576 .56642 Mtetra
.738 .736 .849 r
.30576 .56642 .31485 .57624 .32954 .56677 .32047 .55761 Mtetra
.667 .735 .9 r
.32047 .55761 .32954 .56677 .34409 .56074 .335 .55263 Mtetra
.601 .741 .943 r
.335 .55263 .34409 .56074 .35855 .55771 .34949 .54979 Mtetra
.605 .749 .946 r
.34949 .54979 .35855 .55771 .3731 .55479 .36409 .54675 Mtetra
.646 .759 .931 r
.36409 .54675 .3731 .55479 .38778 .55091 .37884 .54244 Mtetra
.65 .75 .923 r
.37884 .54244 .38778 .55091 .40257 .54646 .39367 .53802 Mtetra
.645 .751 .926 r
.39367 .53802 .40257 .54646 .41743 .54216 .40859 .53374 Mtetra
.644 .752 .928 r
.40859 .53374 .41743 .54216 .43238 .53794 .42359 .52945 Mtetra
.657 .755 .923 r
.42359 .52945 .43238 .53794 .44742 .53345 .43869 .52469 Mtetra
.659 .751 .918 r
.43869 .52469 .44742 .53345 .46255 .52863 .45387 .51985 Mtetra
.655 .75 .92 r
.45387 .51985 .46255 .52863 .47776 .52387 .46914 .51512 Mtetra
.649 .75 .923 r
.46914 .51512 .47776 .52387 .49306 .5192 .48449 .51057 Mtetra
.651 .755 .925 r
.48449 .51057 .49306 .5192 .50844 .51464 .49993 .50589 Mtetra
.657 .755 .922 r
.49993 .50589 .50844 .51464 .52392 .50998 .51546 .50099 Mtetra
.658 .751 .919 r
.51546 .50099 .52392 .50998 .53948 .50514 .53108 .49602 Mtetra
.658 .749 .917 r
.53108 .49602 .53948 .50514 .55513 .50027 .54679 .49105 Mtetra
.656 .747 .917 r
.54679 .49105 .55513 .50027 .57087 .49538 .56258 .48611 Mtetra
.654 .747 .918 r
.56258 .48611 .57087 .49538 .58669 .49048 .57847 .48121 Mtetra
.654 .748 .919 r
.57847 .48121 .58669 .49048 .60261 .48554 .59445 .47629 Mtetra
.655 .75 .92 r
.59445 .47629 .60261 .48554 .61862 .48042 .61052 .47131 Mtetra
.66 .756 .921 r
.61052 .47131 .61862 .48042 .63471 .4752 .62669 .46611 Mtetra
.662 .759 .922 r
.62669 .46611 .63471 .4752 .6509 .47008 .64293 .46076 Mtetra
.657 .753 .921 r
.64293 .46076 .6509 .47008 .66719 .46506 .65928 .4556 Mtetra
.653 .75 .92 r
.65928 .4556 .66719 .46506 .68358 .46009 .67573 .45056 Mtetra
.655 .75 .919 r
.67573 .45056 .68358 .46009 .70005 .45478 .69228 .44542 Mtetra
.666 .759 .92 r
.69228 .44542 .70005 .45478 .71659 .4492 .7089 .4398 Mtetra
.7089 .4398 .71659 .4492 .73324 .44369 .72561 .43417 Mtetra
.662 .756 .92 r
.72561 .43417 .73324 .44369 .74999 .43833 .74243 .42867 Mtetra
.664 .755 .918 r
.74243 .42867 .74999 .43833 .7668 .43237 .75934 .42305 Mtetra
.694 .775 .914 r
.75934 .42305 .7668 .43237 .78362 .4254 .77624 .4161 Mtetra
.698 .779 .914 r
.77624 .4161 .78362 .4254 .80054 .41855 .79321 .40894 Mtetra
.645 .753 .928 r
.79321 .40894 .80054 .41855 .81783 .4148 .81047 .40399 Mtetra
.538 .677 .928 r
.81047 .40399 .81783 .4148 .83558 .41465 .82821 .40304 Mtetra
.469 .624 .919 r
.82821 .40304 .83558 .41465 .85365 .41602 .84636 .40456 Mtetra
.554 .673 .917 r
.84636 .40456 .85365 .41602 .87149 .41352 .86438 .40318 Mtetra
.674 .754 .911 r
.86438 .40318 .87149 .41352 .88893 .40622 .88202 .39686 Mtetra
.655 .764 .93 r
.25265 .58187 .26214 .58958 .27634 .58591 .26696 .57736 Mtetra
.752 .763 .861 r
.26696 .57736 .27634 .58591 .29094 .57755 .28167 .56814 Mtetra
.771 .749 .833 r
.28167 .56814 .29094 .57755 .30576 .56642 .29655 .55709 Mtetra
.734 .747 .862 r
.29655 .55709 .30576 .56642 .32047 .55761 .31128 .5487 Mtetra
.646 .737 .915 r
.31128 .5487 .32047 .55761 .335 .55263 .32581 .54447 Mtetra
.597 .741 .945 r
.32581 .54447 .335 .55263 .34949 .54979 .34035 .54167 Mtetra
.615 .749 .941 r
.34035 .54167 .34949 .54979 .36409 .54675 .35501 .53834 Mtetra
.65 .753 .925 r
.35501 .53834 .36409 .54675 .37884 .54244 .36981 .53386 Mtetra
.647 .749 .924 r
.36981 .53386 .37884 .54244 .39367 .53802 .38469 .52948 Mtetra
.643 .75 .926 r
.38469 .52948 .39367 .53802 .40859 .53374 .39966 .5252 Mtetra
.648 .752 .926 r
.39966 .5252 .40859 .53374 .42359 .52945 .41471 .52074 Mtetra
.659 .753 .919 r
.41471 .52074 .42359 .52945 .43869 .52469 .42987 .51584 Mtetra
.657 .75 .919 r
.42987 .51584 .43869 .52469 .45387 .51985 .4451 .51102 Mtetra
.651 .75 .922 r
.4451 .51102 .45387 .51985 .46914 .51512 .46042 .50638 Mtetra
.649 .753 .925 r
.46042 .50638 .46914 .51512 .48449 .51057 .47583 .50178 Mtetra
.657 .755 .922 r
.47583 .50178 .48449 .51057 .49993 .50589 .49133 .49686 Mtetra
.66 .751 .918 r
.49133 .49686 .49993 .50589 .51546 .50099 .50692 .49181 Mtetra
.659 .749 .917 r
.50692 .49181 .51546 .50099 .53108 .49602 .52259 .48676 Mtetra
.656 .747 .917 r
.52259 .48676 .53108 .49602 .54679 .49105 .53836 .48178 Mtetra
.656 .748 .918 r
.53836 .48178 .54679 .49105 .56258 .48611 .55421 .47679 Mtetra
.55421 .47679 .56258 .48611 .57847 .48121 .57016 .47178 Mtetra
.653 .746 .918 r
.57016 .47178 .57847 .48121 .59445 .47629 .5862 .46685 Mtetra
.652 .747 .919 r
.5862 .46685 .59445 .47629 .61052 .47131 .60234 .46191 Mtetra
.655 .75 .92 r
.60234 .46191 .61052 .47131 .62669 .46611 .61857 .45685 Mtetra
.662 .757 .92 r
.61857 .45685 .62669 .46611 .64293 .46076 .63488 .45145 Mtetra
.66 .756 .921 r
.63488 .45145 .64293 .46076 .65928 .4556 .65129 .44609 Mtetra
.655 .751 .92 r
.65129 .44609 .65928 .4556 .67573 .45056 .66781 .44092 Mtetra
.653 .749 .92 r
.66781 .44092 .67573 .45056 .69228 .44542 .68442 .43582 Mtetra
.663 .755 .918 r
.68442 .43582 .69228 .44542 .7089 .4398 .70111 .43027 Mtetra
.667 .759 .919 r
.70111 .43027 .7089 .4398 .72561 .43417 .71789 .42452 Mtetra
.664 .756 .919 r
.71789 .42452 .72561 .43417 .74243 .42867 .73478 .41888 Mtetra
.661 .753 .919 r
.73478 .41888 .74243 .42867 .75934 .42305 .75176 .41333 Mtetra
.688 .766 .911 r
.75176 .41333 .75934 .42305 .77624 .4161 .76876 .40658 Mtetra
.7 .776 .911 r
.76876 .40658 .77624 .4161 .79321 .40894 .78581 .39927 Mtetra
.665 .762 .922 r
.78581 .39927 .79321 .40894 .81047 .40399 .80306 .39343 Mtetra
.549 .691 .933 r
.80306 .39343 .81047 .40399 .82821 .40304 .82082 .39193 Mtetra
.465 .635 .929 r
.82082 .39193 .82821 .40304 .84636 .40456 .83901 .39324 Mtetra
.527 .665 .924 r
.83901 .39324 .84636 .40456 .86438 .40318 .85719 .39265 Mtetra
.654 .745 .916 r
.85719 .39265 .86438 .40318 .88202 .39686 .875 .38712 Mtetra
.671 .763 .919 r
.24309 .57387 .25265 .58187 .26696 .57736 .25748 .56877 Mtetra
.76 .764 .856 r
.25748 .56877 .26696 .57736 .28167 .56814 .27229 .55898 Mtetra
.771 .755 .839 r
.27229 .55898 .28167 .56814 .29655 .55709 .28722 .54802 Mtetra
.73 .753 .871 r
.28722 .54802 .29655 .55709 .31128 .5487 .30199 .53997 Mtetra
.632 .739 .925 r
.30199 .53997 .31128 .5487 .32581 .54447 .31654 .53617 Mtetra
.597 .74 .944 r
.31654 .53617 .32581 .54447 .34035 .54167 .33112 .53334 Mtetra
.622 .748 .937 r
.33112 .53334 .34035 .54167 .35501 .53834 .34583 .52977 Mtetra
.651 .751 .923 r
.34583 .52977 .35501 .53834 .36981 .53386 .36069 .52521 Mtetra
.646 .749 .924 r
.36069 .52521 .36981 .53386 .38469 .52948 .37562 .52081 Mtetra
.643 .749 .926 r
.37562 .52081 .38469 .52948 .39966 .5252 .39063 .51651 Mtetra
.651 .752 .924 r
.39063 .51651 .39966 .5252 .41471 .52074 .40574 .5119 Mtetra
.66 .752 .918 r
.40574 .5119 .41471 .52074 .42987 .51584 .42095 .50694 Mtetra
.655 .751 .92 r
.42095 .50694 .42987 .51584 .4451 .51102 .43624 .50211 Mtetra
.648 .75 .923 r
.43624 .50211 .4451 .51102 .46042 .50638 .45162 .49751 Mtetra
.652 .753 .924 r
.45162 .49751 .46042 .50638 .47583 .50178 .46708 .49275 Mtetra
.659 .752 .919 r
.46708 .49275 .47583 .50178 .49133 .49686 .48264 .4877 Mtetra
.661 .751 .917 r
.48264 .4877 .49133 .49686 .50692 .49181 .49828 .48256 Mtetra
.654 .748 .919 r
.49828 .48256 .50692 .49181 .52259 .48676 .51402 .47766 Mtetra
.651 .752 .923 r
.51402 .47766 .52259 .48676 .53836 .48178 .52984 .47283 Mtetra
.655 .758 .925 r
.52984 .47283 .53836 .48178 .55421 .47679 .54576 .46779 Mtetra
.66 .76 .923 r
.54576 .46779 .55421 .47679 .57016 .47178 .56177 .46252 Mtetra
.658 .754 .921 r
.56177 .46252 .57016 .47178 .5862 .46685 .57787 .45733 Mtetra
.651 .747 .92 r
.57787 .45733 .5862 .46685 .60234 .46191 .59407 .45237 Mtetra
.653 .748 .92 r
.59407 .45237 .60234 .46191 .61857 .45685 .61036 .44733 Mtetra
.66 .753 .919 r
.61036 .44733 .61857 .45685 .63488 .45145 .62674 .442 Mtetra
.663 .756 .92 r
.62674 .442 .63488 .45145 .65129 .44609 .64321 .43649 Mtetra
.656 .752 .92 r
.64321 .43649 .65129 .44609 .66781 .44092 .65979 .43122 Mtetra
.652 .749 .921 r
.65979 .43122 .66781 .44092 .68442 .43582 .67648 .42607 Mtetra
.66 .753 .918 r
.67648 .42607 .68442 .43582 .70111 .43027 .69324 .42057 Mtetra
.668 .758 .918 r
.69324 .42057 .70111 .43027 .71789 .42452 .71009 .41474 Mtetra
.664 .756 .918 r
.71009 .41474 .71789 .42452 .73478 .41888 .72704 .409 Mtetra
.66 .754 .919 r
.72704 .409 .73478 .41888 .75176 .41333 .7441 .40342 Mtetra
.683 .763 .912 r
.7441 .40342 .75176 .41333 .76876 .40658 .76119 .39681 Mtetra
.7 .773 .909 r
.76119 .39681 .76876 .40658 .78581 .39927 .77831 .38942 Mtetra
.677 .765 .917 r
.77831 .38942 .78581 .39927 .80306 .39343 .7956 .38303 Mtetra
.559 .702 .936 r
.7956 .38303 .80306 .39343 .82082 .39193 .81339 .38107 Mtetra
.465 .644 .935 r
.81339 .38107 .82082 .39193 .83901 .39324 .83163 .38217 Mtetra
.507 .662 .931 r
.83163 .38217 .83901 .39324 .85719 .39265 .84992 .38206 Mtetra
.64 .74 .921 r
.84992 .38206 .85719 .39265 .875 .38712 .86787 .37705 Mtetra
.678 .761 .913 r
.23343 .56564 .24309 .57387 .25748 .56877 .2479 .5602 Mtetra
.764 .767 .855 r
.2479 .5602 .25748 .56877 .27229 .55898 .26279 .55011 Mtetra
.772 .763 .844 r
.26279 .55011 .27229 .55898 .28722 .54802 .27778 .53919 Mtetra
.727 .759 .878 r
.27778 .53919 .28722 .54802 .30199 .53997 .29259 .53135 Mtetra
.626 .742 .93 r
.29259 .53135 .30199 .53997 .31654 .53617 .30717 .52767 Mtetra
.598 .737 .941 r
.30717 .52767 .31654 .53617 .33112 .53334 .3218 .52478 Mtetra
.626 .745 .933 r
.3218 .52478 .33112 .53334 .34583 .52977 .33656 .52107 Mtetra
.651 .751 .922 r
.33656 .52107 .34583 .52977 .36069 .52521 .35147 .51647 Mtetra
.646 .749 .924 r
.35147 .51647 .36069 .52521 .37562 .52081 .36645 .51203 Mtetra
.643 .748 .926 r
.36645 .51203 .37562 .52081 .39063 .51651 .38152 .50769 Mtetra
.653 .751 .922 r
.38152 .50769 .39063 .51651 .40574 .5119 .39668 .50296 Mtetra
.659 .752 .919 r
.39668 .50296 .40574 .5119 .42095 .50694 .41195 .49796 Mtetra
.655 .751 .92 r
.41195 .49796 .42095 .50694 .43624 .50211 .42729 .4931 Mtetra
.647 .749 .924 r
.42729 .4931 .43624 .50211 .45162 .49751 .44272 .48849 Mtetra
.654 .752 .922 r
.44272 .48849 .45162 .49751 .46708 .49275 .45824 .48361 Mtetra
.66 .752 .918 r
.45824 .48361 .46708 .49275 .48264 .4877 .47385 .47846 Mtetra
.659 .751 .918 r
.47385 .47846 .48264 .4877 .49828 .48256 .48956 .47331 Mtetra
.648 .748 .923 r
.48956 .47331 .49828 .48256 .51402 .47766 .50535 .46857 Mtetra
.647 .753 .927 r
.50535 .46857 .51402 .47766 .52984 .47283 .52123 .46382 Mtetra
.655 .759 .926 r
.52123 .46382 .52984 .47283 .54576 .46779 .53721 .45872 Mtetra
.664 .762 .923 r
.53721 .45872 .54576 .46779 .56177 .46252 .55328 .45327 Mtetra
.663 .758 .921 r
.55328 .45327 .56177 .46252 .57787 .45733 .56944 .44781 Mtetra
.652 .75 .921 r
.56944 .44781 .57787 .45733 .59407 .45237 .5857 .44275 Mtetra
.652 .748 .921 r
.5857 .44275 .59407 .45237 .61036 .44733 .60206 .43771 Mtetra
.658 .752 .919 r
.60206 .43771 .61036 .44733 .62674 .442 .61851 .43238 Mtetra
.664 .755 .918 r
.61851 .43238 .62674 .442 .64321 .43649 .63505 .42678 Mtetra
.657 .752 .92 r
.63505 .42678 .64321 .43649 .65979 .43122 .65169 .42142 Mtetra
.653 .75 .921 r
.65169 .42142 .65979 .43122 .67648 .42607 .66844 .41621 Mtetra
.659 .752 .919 r
.66844 .41621 .67648 .42607 .69324 .42057 .68528 .41071 Mtetra
.668 .757 .917 r
.68528 .41071 .69324 .42057 .71009 .41474 .7022 .40481 Mtetra
.665 .755 .918 r
.7022 .40481 .71009 .41474 .72704 .409 .71922 .39901 Mtetra
.66 .753 .919 r
.71922 .39901 .72704 .409 .7441 .40342 .73635 .39336 Mtetra
.681 .761 .912 r
.73635 .39336 .7441 .40342 .76119 .39681 .75353 .38679 Mtetra
.699 .77 .907 r
.75353 .38679 .76119 .39681 .77831 .38942 .77073 .37935 Mtetra
.681 .764 .914 r
.77073 .37935 .77831 .38942 .7956 .38303 .78808 .37272 Mtetra
.566 .71 .939 r
.78808 .37272 .7956 .38303 .81339 .38107 .80591 .37043 Mtetra
.463 .651 .94 r
.80591 .37043 .81339 .38107 .83163 .38217 .8242 .37137 Mtetra
.493 .665 .938 r
.8242 .37137 .83163 .38217 .84992 .38206 .84258 .37147 Mtetra
.633 .739 .925 r
.84258 .37147 .84992 .38206 .86787 .37705 .86064 .36669 Mtetra
.678 .758 .911 r
.22369 .55719 .23343 .56564 .2479 .5602 .2382 .5517 Mtetra
.765 .77 .857 r
.2382 .5517 .2479 .5602 .26279 .55011 .25317 .54155 Mtetra
.775 .77 .848 r
.25317 .54155 .26279 .55011 .27778 .53919 .26822 .53057 Mtetra
.728 .766 .883 r
.26822 .53057 .27778 .53919 .29259 .53135 .28309 .52267 Mtetra
.626 .743 .931 r
.28309 .52267 .29259 .53135 .30717 .52767 .29772 .51894 Mtetra
.599 .734 .939 r
.29772 .51894 .30717 .52767 .3218 .52478 .31238 .51601 Mtetra
.626 .743 .931 r
.31238 .51601 .3218 .52478 .33656 .52107 .3272 .51225 Mtetra
.651 .75 .922 r
.3272 .51225 .33656 .52107 .35147 .51647 .34216 .5076 Mtetra
.646 .748 .924 r
.34216 .5076 .35147 .51647 .36645 .51203 .35719 .50311 Mtetra
.643 .747 .925 r
.35719 .50311 .36645 .51203 .38152 .50769 .37231 .49872 Mtetra
.653 .75 .921 r
.37231 .49872 .38152 .50769 .39668 .50296 .38753 .49395 Mtetra
.659 .752 .919 r
.38753 .49395 .39668 .50296 .41195 .49796 .40284 .4889 Mtetra
.655 .751 .921 r
.40284 .4889 .41195 .49796 .42729 .4931 .41824 .48399 Mtetra
.647 .749 .923 r
.41824 .48399 .42729 .4931 .44272 .48849 .43372 .47932 Mtetra
.654 .751 .921 r
.43372 .47932 .44272 .48849 .45824 .48361 .4493 .47439 Mtetra
.66 .753 .919 r
.4493 .47439 .45824 .48361 .47385 .47846 .46498 .46918 Mtetra
.659 .752 .919 r
.46498 .46918 .47385 .47846 .48956 .47331 .48074 .46398 Mtetra
.648 .749 .923 r
.48074 .46398 .48956 .47331 .50535 .46857 .49659 .45918 Mtetra
.647 .749 .923 r
.49659 .45918 .50535 .46857 .52123 .46382 .51253 .45438 Mtetra
.656 .751 .92 r
.51253 .45438 .52123 .46382 .53721 .45872 .52857 .44923 Mtetra
.664 .754 .917 r
.52857 .44923 .53721 .45872 .55328 .45327 .5447 .44372 Mtetra
.663 .754 .917 r
.5447 .44372 .55328 .45327 .56944 .44781 .56093 .43821 Mtetra
.652 .75 .921 r
.56093 .43821 .56944 .44781 .5857 .44275 .57725 .43309 Mtetra
.651 .75 .922 r
.57725 .43309 .5857 .44275 .60206 .43771 .59367 .42799 Mtetra
.658 .752 .92 r
.59367 .42799 .60206 .43771 .61851 .43238 .61019 .42261 Mtetra
.664 .754 .917 r
.61019 .42261 .61851 .43238 .63505 .42678 .62679 .41695 Mtetra
.657 .752 .92 r
.62679 .41695 .63505 .42678 .65169 .42142 .6435 .41153 Mtetra
.653 .75 .921 r
.6435 .41153 .65169 .42142 .66844 .41621 .66032 .40626 Mtetra
.659 .752 .919 r
.66032 .40626 .66844 .41621 .68528 .41071 .67723 .4007 Mtetra
.668 .756 .916 r
.67723 .4007 .68528 .41071 .7022 .40481 .69422 .39474 Mtetra
.665 .755 .917 r
.69422 .39474 .7022 .40481 .71922 .39901 .71131 .38887 Mtetra
.66 .753 .919 r
.71131 .38887 .71922 .39901 .73635 .39336 .72852 .38317 Mtetra
.681 .761 .912 r
.72852 .38317 .73635 .39336 .75353 .38679 .74576 .37653 Mtetra
.699 .767 .905 r
.74576 .37653 .75353 .38679 .77073 .37935 .76304 .36902 Mtetra
.681 .76 .912 r
.76304 .36902 .77073 .37935 .78808 .37272 .78047 .36232 Mtetra
.566 .711 .939 r
.78047 .36232 .78808 .37272 .80591 .37043 .79837 .35998 Mtetra
.458 .655 .945 r
.79837 .35998 .80591 .37043 .8242 .37137 .81672 .36087 Mtetra
.487 .671 .945 r
.81672 .36087 .8242 .37137 .84258 .37147 .83518 .36092 Mtetra
.633 .743 .927 r
.83518 .36092 .84258 .37147 .86064 .36669 .85331 .35607 Mtetra
.671 .753 .912 r
.21386 .54852 .22369 .55719 .2382 .5517 .2284 .54327 Mtetra
.762 .773 .862 r
.2284 .54327 .2382 .5517 .25317 .54155 .24341 .5333 Mtetra
.779 .778 .852 r
.24341 .5333 .25317 .54155 .26822 .53057 .25854 .52216 Mtetra
.734 .773 .884 r
.25854 .52216 .26822 .53057 .28309 .52267 .27348 .51393 Mtetra
.631 .745 .93 r
.27348 .51393 .28309 .52267 .29772 .51894 .28817 .50999 Mtetra
.6 .731 .937 r
.28817 .50999 .29772 .51894 .31238 .51601 .30288 .50703 Mtetra
.623 .739 .93 r
.30288 .50703 .31238 .51601 .3272 .51225 .31774 .50332 Mtetra
.652 .749 .921 r
.31774 .50332 .3272 .51225 .34216 .5076 .33275 .49862 Mtetra
.646 .748 .923 r
.33275 .49862 .34216 .5076 .35719 .50311 .34783 .49407 Mtetra
.643 .747 .924 r
.34783 .49407 .35719 .50311 .37231 .49872 .363 .48962 Mtetra
.651 .749 .921 r
.363 .48962 .37231 .49872 .38753 .49395 .37827 .48485 Mtetra
.659 .753 .919 r
.37827 .48485 .38753 .49395 .40284 .4889 .39365 .47974 Mtetra
.655 .751 .92 r
.39365 .47974 .40284 .4889 .41824 .48399 .4091 .47475 Mtetra
.648 .749 .923 r
.4091 .47475 .41824 .48399 .43372 .47932 .42464 .47 Mtetra
.652 .749 .921 r
.42464 .47 .43372 .47932 .4493 .47439 .44027 .46508 Mtetra
.659 .753 .919 r
.44027 .46508 .4493 .47439 .46498 .46918 .456 .45987 Mtetra
.66 .754 .919 r
.456 .45987 .46498 .46918 .48074 .46398 .47182 .45457 Mtetra
.654 .751 .921 r
.47182 .45457 .48074 .46398 .49659 .45918 .48773 .44951 Mtetra
.651 .745 .919 r
.48773 .44951 .49659 .45918 .51253 .45438 .50374 .44452 Mtetra
.656 .744 .915 r
.50374 .44452 .51253 .45438 .52857 .44923 .51984 .43931 Mtetra
.661 .746 .913 r
.51984 .43931 .52857 .44923 .5447 .44372 .53603 .43387 Mtetra
.658 .748 .916 r
.53603 .43387 .5447 .44372 .56093 .43821 .55232 .42851 Mtetra
.651 .75 .922 r
.55232 .42851 .56093 .43821 .57725 .43309 .56871 .42339 Mtetra
.653 .752 .922 r
.56871 .42339 .57725 .43309 .59367 .42799 .58519 .41818 Mtetra
.659 .753 .919 r
.58519 .41818 .59367 .42799 .61019 .42261 .60177 .41267 Mtetra
.663 .753 .917 r
.60177 .41267 .61019 .42261 .62679 .41695 .61844 .40698 Mtetra
.656 .751 .92 r
.61844 .40698 .62679 .41695 .6435 .41153 .63522 .40153 Mtetra
.652 .75 .921 r
.63522 .40153 .6435 .41153 .66032 .40626 .65211 .39621 Mtetra
.66 .753 .919 r
.65211 .39621 .66032 .40626 .67723 .4007 .66908 .39053 Mtetra
.668 .755 .915 r
.66908 .39053 .67723 .4007 .69422 .39474 .68614 .38452 Mtetra
.664 .754 .917 r
.68614 .38452 .69422 .39474 .71131 .38887 .70331 .3786 Mtetra
.66 .752 .918 r
.70331 .3786 .71131 .38887 .72852 .38317 .72059 .37283 Mtetra
.683 .761 .91 r
.72059 .37283 .72852 .38317 .74576 .37653 .7379 .36602 Mtetra
.699 .764 .902 r
.7379 .36602 .74576 .37653 .76304 .36902 .75526 .35844 Mtetra
.677 .756 .911 r
.75526 .35844 .76304 .36902 .78047 .36232 .77278 .35184 Mtetra
.557 .707 .941 r
.77278 .35184 .78047 .36232 .79837 .35998 .79078 .34972 Mtetra
.448 .658 .95 r
.79078 .34972 .79837 .35998 .81672 .36087 .8092 .35067 Mtetra
.49 .683 .952 r
.8092 .35067 .81672 .36087 .83518 .36092 .8277 .35041 Mtetra
.64 .749 .928 r
.8277 .35041 .83518 .36092 .85331 .35607 .84589 .34521 Mtetra
.656 .746 .916 r
.20394 .53961 .21386 .54852 .2284 .54327 .21848 .53487 Mtetra
.755 .775 .869 r
.21848 .53487 .2284 .54327 .24341 .5333 .23351 .52535 Mtetra
.784 .786 .854 r
.23351 .52535 .24341 .5333 .25854 .52216 .24873 .51398 Mtetra
.743 .781 .884 r
.24873 .51398 .25854 .52216 .27348 .51393 .26377 .5053 Mtetra
.645 .753 .928 r
.26377 .5053 .27348 .51393 .28817 .50999 .27854 .50084 Mtetra
.601 .729 .934 r
.27854 .50084 .28817 .50999 .30288 .50703 .29329 .49781 Mtetra
.618 .734 .929 r
.29329 .49781 .30288 .50703 .31774 .50332 .30818 .49425 Mtetra
.651 .748 .921 r
.30818 .49425 .31774 .50332 .33275 .49862 .32324 .48953 Mtetra
.647 .748 .923 r
.32324 .48953 .33275 .49862 .34783 .49407 .33838 .4849 Mtetra
.644 .746 .923 r
.33838 .4849 .34783 .49407 .363 .48962 .3536 .48037 Mtetra
.648 .747 .921 r
.3536 .48037 .363 .48962 .37827 .48485 .36892 .47566 Mtetra
.659 .753 .919 r
.36892 .47566 .37827 .48485 .39365 .47974 .38435 .47051 Mtetra
.657 .752 .92 r
.38435 .47051 .39365 .47974 .4091 .47475 .39986 .46542 Mtetra
.651 .749 .922 r
.39986 .46542 .4091 .47475 .42464 .47 .41546 .46052 Mtetra
.649 .747 .921 r
.41546 .46052 .42464 .47 .44027 .46508 .43114 .45566 Mtetra
.657 .752 .92 r
.43114 .45566 .44027 .46508 .456 .45987 .44693 .45047 Mtetra
.66 .754 .92 r
.44693 .45047 .456 .45987 .47182 .45457 .46281 .44515 Mtetra
.659 .755 .921 r
.46281 .44515 .47182 .45457 .48773 .44951 .47878 .43983 Mtetra
.656 .749 .919 r
.47878 .43983 .48773 .44951 .50374 .44452 .49485 .43458 Mtetra
.656 .745 .915 r
.49485 .43458 .50374 .44452 .51984 .43931 .51101 .42931 Mtetra
.51101 .42931 .51984 .43931 .53603 .43387 .52726 .42403 Mtetra
.653 .748 .92 r
.52726 .42403 .53603 .43387 .55232 .42851 .54362 .41881 Mtetra
.652 .753 .923 r
.54362 .41881 .55232 .42851 .56871 .42339 .56007 .4136 Mtetra
.655 .753 .922 r
.56007 .4136 .56871 .42339 .58519 .41818 .57662 .40825 Mtetra
.662 .754 .918 r
.57662 .40825 .58519 .41818 .60177 .41267 .59326 .40256 Mtetra
.661 .75 .917 r
.59326 .40256 .60177 .41267 .61844 .40698 .61 .39691 Mtetra
.655 .751 .92 r
.61 .39691 .61844 .40698 .63522 .40153 .62685 .39145 Mtetra
.653 .751 .922 r
.62685 .39145 .63522 .40153 .65211 .39621 .64381 .38605 Mtetra
.663 .754 .918 r
.64381 .38605 .65211 .39621 .66908 .39053 .66085 .38019 Mtetra
.667 .753 .915 r
.66085 .38019 .66908 .39053 .68614 .38452 .67798 .37414 Mtetra
.664 .753 .916 r
.67798 .37414 .68614 .38452 .70331 .3786 .69522 .36819 Mtetra
.661 .752 .918 r
.69522 .36819 .70331 .3786 .72059 .37283 .71257 .36233 Mtetra
.688 .762 .908 r
.71257 .36233 .72059 .37283 .7379 .36602 .72995 .35526 Mtetra
.698 .761 .9 r
.72995 .35526 .7379 .36602 .75526 .35844 .74738 .34762 Mtetra
.665 .749 .913 r
.74738 .34762 .75526 .35844 .77278 .35184 .76502 .34145 Mtetra
.542 .705 .946 r
.76502 .34145 .77278 .35184 .79078 .34972 .78312 .33968 Mtetra
.435 .659 .955 r
.78312 .33968 .79078 .34972 .8092 .35067 .80163 .34076 Mtetra
.503 .7 .958 r
.80163 .34076 .8092 .35067 .8277 .35041 .82015 .3399 Mtetra
.654 .758 .926 r
.82015 .3399 .8277 .35041 .84589 .34521 .83836 .33404 Mtetra
.633 .735 .922 r
.19394 .5304 .20394 .53961 .21848 .53487 .20845 .52642 Mtetra
.743 .775 .879 r
.20845 .52642 .21848 .53487 .23351 .52535 .22347 .51766 Mtetra
.788 .793 .857 r
.22347 .51766 .23351 .52535 .24873 .51398 .23878 .50607 Mtetra
.753 .79 .883 r
.23878 .50607 .24873 .51398 .26377 .5053 .25393 .49685 Mtetra
.668 .765 .923 r
.25393 .49685 .26377 .5053 .27854 .50084 .26881 .49152 Mtetra
.604 .728 .933 r
.26881 .49152 .27854 .50084 .29329 .49781 .28362 .48837 Mtetra
.61 .728 .929 r
.28362 .48837 .29329 .49781 .30818 .49425 .29853 .48502 Mtetra
.647 .746 .921 r
.29853 .48502 .30818 .49425 .32324 .48953 .31363 .48036 Mtetra
.65 .749 .922 r
.31363 .48036 .32324 .48953 .33838 .4849 .32883 .4756 Mtetra
.645 .746 .922 r
.32883 .4756 .33838 .4849 .3536 .48037 .3441 .47097 Mtetra
.645 .745 .922 r
.3441 .47097 .3536 .48037 .36892 .47566 .35947 .46633 Mtetra
.657 .751 .919 r
.35947 .46633 .36892 .47566 .38435 .47051 .37495 .46121 Mtetra
.658 .753 .92 r
.37495 .46121 .38435 .47051 .39986 .46542 .39052 .456 Mtetra
.655 .751 .92 r
.39052 .456 .39986 .46542 .41546 .46052 .40618 .4509 Mtetra
.649 .746 .92 r
.40618 .4509 .41546 .46052 .43114 .45566 .42192 .44599 Mtetra
.652 .747 .919 r
.42192 .44599 .43114 .45566 .44693 .45047 .43776 .44094 Mtetra
.657 .753 .921 r
.43776 .44094 .44693 .45047 .46281 .44515 .4537 .43566 Mtetra
.658 .755 .922 r
.4537 .43566 .46281 .44515 .47878 .43983 .46973 .43032 Mtetra
.657 .756 .923 r
.46973 .43032 .47878 .43983 .49485 .43458 .48586 .42496 Mtetra
.656 .754 .922 r
.48586 .42496 .49485 .43458 .51101 .42931 .50208 .41964 Mtetra
.654 .754 .923 r
.50208 .41964 .51101 .42931 .52726 .42403 .5184 .41434 Mtetra
.654 .755 .924 r
.5184 .41434 .52726 .42403 .54362 .41881 .53482 .40904 Mtetra
.655 .754 .923 r
.53482 .40904 .54362 .41881 .56007 .4136 .55133 .40366 Mtetra
.66 .754 .92 r
.55133 .40366 .56007 .4136 .57662 .40825 .56795 .39805 Mtetra
.662 .75 .915 r
.56795 .39805 .57662 .40825 .59326 .40256 .58466 .3923 Mtetra
.657 .748 .917 r
.58466 .3923 .59326 .40256 .61 .39691 .60147 .38674 Mtetra
.653 .75 .921 r
.60147 .38674 .61 .39691 .62685 .39145 .61839 .38128 Mtetra
.655 .752 .921 r
.61839 .38128 .62685 .39145 .64381 .38605 .63541 .37573 Mtetra
.666 .754 .916 r
.63541 .37573 .64381 .38605 .66085 .38019 .65251 .36968 Mtetra
.666 .751 .914 r
.65251 .36968 .66085 .38019 .67798 .37414 .66972 .36362 Mtetra
.662 .751 .917 r
.66972 .36362 .67798 .37414 .69522 .36819 .68704 .3577 Mtetra
.664 .754 .917 r
.68704 .3577 .69522 .36819 .71257 .36233 .70446 .35164 Mtetra
.693 .762 .905 r
.70446 .35164 .71257 .36233 .72995 .35526 .72189 .34423 Mtetra
.696 .757 .899 r
.72189 .34423 .72995 .35526 .74738 .34762 .73941 .33661 Mtetra
.646 .739 .918 r
.73941 .33661 .74738 .34762 .76502 .34145 .75718 .33122 Mtetra
.522 .702 .952 r
.75718 .33122 .76502 .34145 .78312 .33968 .7754 .3299 Mtetra
.421 .661 .96 r
.7754 .3299 .78312 .33968 .80163 .34076 .79399 .33108 Mtetra
.528 .721 .962 r
.79399 .33108 .80163 .34076 .82015 .3399 .81252 .32932 Mtetra
.674 .767 .921 r
.81252 .32932 .82015 .3399 .83836 .33404 .83073 .32253 Mtetra
.602 .72 .928 r
.18387 .52083 .19394 .5304 .20845 .52642 .19832 .51782 Mtetra
.722 .771 .892 r
.19832 .51782 .20845 .52642 .22347 .51766 .2133 .51014 Mtetra
.787 .799 .862 r
.2133 .51014 .22347 .51766 .23878 .50607 .22867 .49867 Mtetra
.768 .803 .881 r
.22867 .49867 .23878 .50607 .25393 .49685 .24395 .48866 Mtetra
.696 .779 .915 r
.24395 .48866 .25393 .49685 .26881 .49152 .25898 .48215 Mtetra
.612 .732 .931 r
.25898 .48215 .26881 .49152 .28362 .48837 .27385 .47871 Mtetra
.608 .725 .928 r
.27385 .47871 .28362 .48837 .29853 .48502 .2888 .47539 Mtetra
.637 .736 .92 r
.2888 .47539 .29853 .48502 .31363 .48036 .30392 .47107 Mtetra
.652 .749 .921 r
.30392 .47107 .31363 .48036 .32883 .4756 .31918 .46618 Mtetra
.647 .746 .921 r
.31918 .46618 .32883 .4756 .3441 .47097 .33451 .46143 Mtetra
.644 .744 .921 r
.33451 .46143 .3441 .47097 .35947 .46633 .34992 .45676 Mtetra
.651 .746 .919 r
.34992 .45676 .35947 .46633 .37495 .46121 .36545 .45181 Mtetra
.659 .754 .92 r
.36545 .45181 .37495 .46121 .39052 .456 .38108 .44652 Mtetra
.657 .752 .92 r
.38108 .44652 .39052 .456 .40618 .4509 .39679 .44129 Mtetra
.654 .75 .92 r
.39679 .44129 .40618 .4509 .42192 .44599 .4126 .43615 Mtetra
.65 .745 .919 r
.4126 .43615 .42192 .44599 .43776 .44094 .4285 .43111 Mtetra
.652 .747 .919 r
.4285 .43111 .43776 .44094 .4537 .43566 .44449 .42597 Mtetra
.656 .752 .921 r
.44449 .42597 .4537 .43566 .46973 .43032 .46058 .42064 Mtetra
.656 .754 .922 r
.46058 .42064 .46973 .43032 .48586 .42496 .47677 .41528 Mtetra
.656 .755 .923 r
.47677 .41528 .48586 .42496 .50208 .41964 .49306 .40989 Mtetra
.655 .755 .923 r
.49306 .40989 .50208 .41964 .5184 .41434 .50944 .40449 Mtetra
.656 .754 .922 r
.50944 .40449 .5184 .41434 .53482 .40904 .52592 .39904 Mtetra
.66 .754 .92 r
.52592 .39904 .53482 .40904 .55133 .40366 .5425 .39341 Mtetra
.661 .75 .916 r
.5425 .39341 .55133 .40366 .56795 .39805 .55918 .38768 Mtetra
.658 .747 .916 r
.55918 .38768 .56795 .39805 .58466 .3923 .57596 .38204 Mtetra
.655 .75 .92 r
.57596 .38204 .58466 .3923 .60147 .38674 .59284 .37649 Mtetra
.653 .751 .922 r
.59284 .37649 .60147 .38674 .61839 .38128 .60983 .371 Mtetra
.661 .754 .92 r
.60983 .371 .61839 .38128 .63541 .37573 .62691 .36516 Mtetra
.667 .752 .914 r
.62691 .36516 .63541 .37573 .65251 .36968 .64409 .35902 Mtetra
.664 .75 .914 r
.64409 .35902 .65251 .36968 .66972 .36362 .66137 .35296 Mtetra
.66 .75 .917 r
.66137 .35296 .66972 .36362 .68704 .3577 .67876 .34705 Mtetra
.673 .757 .914 r
.67876 .34705 .68704 .3577 .70446 .35164 .69623 .34053 Mtetra
.694 .756 .899 r
.69623 .34053 .70446 .35164 .72189 .34423 .71374 .33297 Mtetra
.691 .753 .899 r
.71374 .33297 .72189 .34423 .73941 .33661 .73135 .32551 Mtetra
.616 .728 .926 r
.73135 .32551 .73941 .33661 .75718 .33122 .74928 .32123 Mtetra
.49 .695 .959 r
.74928 .32123 .75718 .33122 .7754 .3299 .76763 .32062 Mtetra
.415 .673 .968 r
.76763 .32062 .7754 .3299 .79399 .33108 .78628 .32156 Mtetra
.565 .746 .962 r
.78628 .32156 .79399 .33108 .81252 .32932 .80479 .31854 Mtetra
.697 .775 .912 r
.80479 .31854 .81252 .32932 .83073 .32253 .82298 .31061 Mtetra
.563 .7 .933 r
.17373 .51085 .18387 .52083 .19832 .51782 .1881 .50893 Mtetra
.695 .762 .904 r
.1881 .50893 .19832 .51782 .2133 .51014 .20302 .50245 Mtetra
.777 .797 .869 r
.20302 .50245 .2133 .51014 .22867 .49867 .2184 .49166 Mtetra
.781 .813 .878 r
.2184 .49166 .22867 .49867 .24395 .48866 .23382 .48084 Mtetra
.728 .794 .905 r
.23382 .48084 .24395 .48866 .25898 .48215 .24903 .4729 Mtetra
.631 .742 .928 r
.24903 .4729 .25898 .48215 .27385 .47871 .26399 .46877 Mtetra
.607 .721 .926 r
.26399 .46877 .27385 .47871 .2888 .47539 .27898 .46546 Mtetra
.623 .727 .922 r
.27898 .46546 .2888 .47539 .30392 .47107 .29412 .4616 Mtetra
.651 .747 .92 r
.29412 .4616 .30392 .47107 .31918 .46618 .30942 .45668 Mtetra
.649 .747 .921 r
.30942 .45668 .31918 .46618 .33451 .46143 .32481 .4518 Mtetra
.646 .745 .921 r
.32481 .4518 .33451 .46143 .34992 .45676 .34028 .447 Mtetra
.646 .743 .92 r
.34028 .447 .34992 .45676 .36545 .45181 .35585 .44219 Mtetra
.655 .75 .92 r
.35585 .44219 .36545 .45181 .38108 .44652 .37153 .437 Mtetra
.659 .754 .921 r
.37153 .437 .38108 .44652 .39679 .44129 .38731 .43163 Mtetra
.656 .752 .92 r
.38731 .43163 .39679 .44129 .4126 .43615 .40317 .42633 Mtetra
.655 .749 .919 r
.40317 .42633 .4126 .43615 .4285 .43111 .41913 .42106 Mtetra
.652 .744 .917 r
.41913 .42106 .4285 .43111 .44449 .42597 .43519 .41586 Mtetra
.653 .745 .917 r
.43519 .41586 .44449 .42597 .46058 .42064 .45134 .41059 Mtetra
.654 .748 .918 r
.45134 .41059 .46058 .42064 .47677 .41528 .46758 .40524 Mtetra
.656 .75 .919 r
.46758 .40524 .47677 .41528 .49306 .40989 .48393 .39979 Mtetra
.657 .75 .918 r
.48393 .39979 .49306 .40989 .50944 .40449 .50038 .39426 Mtetra
.659 .749 .917 r
.50038 .39426 .50944 .40449 .52592 .39904 .51692 .38863 Mtetra
.66 .747 .915 r
.51692 .38863 .52592 .39904 .5425 .39341 .53357 .38294 Mtetra
.657 .746 .915 r
.53357 .38294 .5425 .39341 .55918 .38768 .55031 .37732 Mtetra
.655 .749 .919 r
.55031 .37732 .55918 .38768 .57596 .38204 .56716 .37172 Mtetra
.653 .751 .921 r
.56716 .37172 .57596 .38204 .59284 .37649 .58411 .3662 Mtetra
.657 .754 .921 r
.58411 .3662 .59284 .37649 .60983 .371 .60117 .36048 Mtetra
.665 .753 .916 r
.60117 .36048 .60983 .371 .62691 .36516 .61832 .35437 Mtetra
.665 .749 .913 r
.61832 .35437 .62691 .36516 .64409 .35902 .63557 .34825 Mtetra
.662 .75 .915 r
.63557 .34825 .64409 .35902 .66137 .35296 .65292 .34221 Mtetra
.661 .751 .917 r
.65292 .34221 .66137 .35296 .67876 .34705 .67039 .33619 Mtetra
.685 .759 .908 r
.67039 .33619 .67876 .34705 .69623 .34053 .68791 .32908 Mtetra
.695 .752 .896 r
.68791 .32908 .69623 .34053 .71374 .33297 .70549 .32139 Mtetra
.677 .744 .902 r
.70549 .32139 .71374 .33297 .73135 .32551 .72322 .31452 Mtetra
.575 .714 .937 r
.72322 .31452 .73135 .32551 .74928 .32123 .74132 .31161 Mtetra
.452 .687 .966 r
.74132 .31161 .74928 .32123 .76763 .32062 .7598 .31172 Mtetra
.437 .698 .976 r
.7598 .31172 .76763 .32062 .78628 .32156 .77847 .31182 Mtetra
.607 .763 .954 r
.77847 .31182 .78628 .32156 .80479 .31854 .79694 .30742 Mtetra
.721 .779 .899 r
.79694 .30742 .80479 .31854 .82298 .31061 .81511 .29822 Mtetra
.528 .679 .934 r
.16353 .50046 .17373 .51085 .1881 .50893 .17783 .49945 Mtetra
.66 .744 .912 r
.17783 .49945 .1881 .50893 .20302 .50245 .19266 .49432 Mtetra
.753 .789 .882 r
.19266 .49432 .20302 .50245 .2184 .49166 .20797 .48491 Mtetra
.791 .82 .875 r
.20797 .48491 .2184 .49166 .23382 .48084 .22352 .47349 Mtetra
.751 .809 .898 r
.22352 .47349 .23382 .48084 .24903 .4729 .23889 .46438 Mtetra
.67 .772 .926 r
.23889 .46438 .24903 .4729 .26399 .46877 .25403 .45878 Mtetra
.611 .723 .925 r
.25403 .45878 .26399 .46877 .27898 .46546 .26908 .45528 Mtetra
.613 .721 .922 r
.26908 .45528 .27898 .46546 .29412 .4616 .28423 .45169 Mtetra
.64 .737 .919 r
.28423 .45169 .29412 .4616 .30942 .45668 .29955 .44712 Mtetra
.653 .749 .92 r
.29955 .44712 .30942 .45668 .32481 .4518 .315 .44206 Mtetra
.648 .745 .92 r
.315 .44206 .32481 .4518 .34028 .447 .33054 .43713 Mtetra
.646 .743 .919 r
.33054 .43713 .34028 .447 .35585 .44219 .34616 .43224 Mtetra
.648 .743 .919 r
.34616 .43224 .35585 .44219 .37153 .437 .36188 .42728 Mtetra
.656 .751 .92 r
.36188 .42728 .37153 .437 .38731 .43163 .37771 .42197 Mtetra
.658 .755 .921 r
.37771 .42197 .38731 .43163 .40317 .42633 .39364 .41652 Mtetra
.657 .752 .92 r
.39364 .41652 .40317 .42633 .41913 .42106 .40966 .41111 Mtetra
.656 .75 .919 r
.40966 .41111 .41913 .42106 .43519 .41586 .42578 .40571 Mtetra
.655 .747 .917 r
.42578 .40571 .43519 .41586 .45134 .41059 .44199 .40029 Mtetra
.655 .745 .916 r
.44199 .40029 .45134 .41059 .46758 .40524 .4583 .39484 Mtetra
.656 .744 .915 r
.4583 .39484 .46758 .40524 .48393 .39979 .47471 .38933 Mtetra
.656 .745 .915 r
.47471 .38933 .48393 .39979 .50038 .39426 .49122 .38378 Mtetra
.49122 .38378 .50038 .39426 .51692 .38863 .50783 .37818 Mtetra
.656 .747 .917 r
.50783 .37818 .51692 .38863 .53357 .38294 .52454 .37257 Mtetra
.655 .75 .92 r
.52454 .37257 .53357 .38294 .55031 .37732 .54135 .36697 Mtetra
.653 .751 .922 r
.54135 .36697 .55031 .37732 .56716 .37172 .55827 .36139 Mtetra
.656 .754 .922 r
.55827 .36139 .56716 .37172 .58411 .3662 .57529 .35568 Mtetra
.664 .754 .917 r
.57529 .35568 .58411 .3662 .60117 .36048 .5924 .34962 Mtetra
.665 .748 .913 r
.5924 .34962 .60117 .36048 .61832 .35437 .60962 .34346 Mtetra
.663 .748 .914 r
.60962 .34346 .61832 .35437 .63557 .34825 .62695 .33735 Mtetra
.659 .748 .916 r
.62695 .33735 .63557 .34825 .65292 .34221 .64438 .33137 Mtetra
.67 .755 .914 r
.64438 .33137 .65292 .34221 .67039 .33619 .66191 .32487 Mtetra
.691 .754 .9 r
.66191 .32487 .67039 .33619 .68791 .32908 .67948 .31734 Mtetra
.691 .748 .895 r
.67948 .31734 .68791 .32908 .70549 .32139 .69715 .30972 Mtetra
.643 .732 .913 r
.69715 .30972 .70549 .32139 .72322 .31452 .71504 .30426 Mtetra
.531 .713 .956 r
.71504 .30426 .72322 .31452 .74132 .31161 .7333 .30244 Mtetra
.417 .683 .972 r
.7333 .30244 .74132 .31161 .7598 .31172 .7519 .30306 Mtetra
.491 .736 .981 r
.7519 .30306 .7598 .31172 .77847 .31182 .77053 .3016 Mtetra
.649 .772 .939 r
.77053 .3016 .77847 .31182 .79694 .30742 .78896 .29565 Mtetra
.737 .774 .883 r
.78896 .29565 .79694 .30742 .81511 .29822 .80713 .28537 Mtetra
.515 .671 .934 r
.15324 .48981 .16353 .50046 .17783 .49945 .16753 .48908 Mtetra
.609 .713 .918 r
.16753 .48908 .17783 .49945 .19266 .49432 .18222 .48571 Mtetra
.716 .777 .9 r
.18222 .48571 .19266 .49432 .20797 .48491 .19742 .47814 Mtetra
.787 .822 .88 r
.19742 .47814 .20797 .48491 .22352 .47349 .21302 .46693 Mtetra
.774 .829 .895 r
.21302 .46693 .22352 .47349 .23889 .46438 .22857 .45662 Mtetra
.717 .8 .916 r
.22857 .45662 .23889 .46438 .25403 .45878 .24393 .44907 Mtetra
.631 .738 .925 r
.24393 .44907 .25403 .45878 .26908 .45528 .25908 .44483 Mtetra
.612 .717 .92 r
.25908 .44483 .26908 .45528 .28423 .45169 .27427 .44125 Mtetra
.622 .721 .918 r
.27427 .44125 .28423 .45169 .29955 .44712 .2896 .4373 Mtetra
.649 .744 .919 r
.2896 .4373 .29955 .44712 .315 .44206 .30509 .43231 Mtetra
.652 .748 .92 r
.30509 .43231 .315 .44206 .33054 .43713 .32069 .42718 Mtetra
.649 .744 .919 r
.32069 .42718 .33054 .43713 .34616 .43224 .33637 .42214 Mtetra
.647 .742 .918 r
.33637 .42214 .34616 .43224 .36188 .42728 .35214 .41713 Mtetra
.649 .742 .918 r
.35214 .41713 .36188 .42728 .37771 .42197 .36802 .41204 Mtetra
.654 .75 .92 r
.36802 .41204 .37771 .42197 .39364 .41652 .384 .4067 Mtetra
.657 .754 .922 r
.384 .4067 .39364 .41652 .40966 .41111 .40008 .40121 Mtetra
.657 .754 .921 r
.40008 .40121 .40966 .41111 .42578 .40571 .41626 .39567 Mtetra
.657 .752 .92 r
.41626 .39567 .42578 .40571 .44199 .40029 .43254 .39015 Mtetra
.656 .751 .92 r
.43254 .39015 .44199 .40029 .4583 .39484 .44891 .38461 Mtetra
.656 .75 .919 r
.44891 .38461 .4583 .39484 .47471 .38933 .46538 .37904 Mtetra
.656 .75 .92 r
.46538 .37904 .47471 .38933 .49122 .38378 .48195 .37344 Mtetra
.655 .751 .92 r
.48195 .37344 .49122 .38378 .50783 .37818 .49863 .36784 Mtetra
.654 .751 .921 r
.49863 .36784 .50783 .37818 .52454 .37257 .5154 .36223 Mtetra
.654 .753 .922 r
.5154 .36223 .52454 .37257 .54135 .36697 .53228 .35659 Mtetra
.657 .755 .922 r
.53228 .35659 .54135 .36697 .55827 .36139 .54927 .35079 Mtetra
.663 .753 .917 r
.54927 .35079 .55827 .36139 .57529 .35568 .56635 .34473 Mtetra
.664 .747 .912 r
.56635 .34473 .57529 .35568 .5924 .34962 .58354 .33858 Mtetra
.662 .746 .913 r
.58354 .33858 .5924 .34962 .60962 .34346 .60083 .33246 Mtetra
.66 .748 .915 r
.60083 .33246 .60962 .34346 .62695 .33735 .61823 .32643 Mtetra
.662 .752 .917 r
.61823 .32643 .62695 .33735 .64438 .33137 .63574 .32024 Mtetra
.685 .757 .906 r
.63574 .32024 .64438 .33137 .66191 .32487 .65331 .31298 Mtetra
.691 .746 .893 r
.65331 .31298 .66191 .32487 .67948 .31734 .67095 .30531 Mtetra
.676 .739 .898 r
.67095 .30531 .67948 .31734 .69715 .30972 .68873 .29833 Mtetra
.592 .718 .931 r
.68873 .29833 .69715 .30972 .71504 .30426 .70681 .29476 Mtetra
.474 .706 .971 r
.70681 .29476 .71504 .30426 .7333 .30244 .72523 .29407 Mtetra
.407 .701 .982 r
.72523 .29407 .7333 .30244 .7519 .30306 .74389 .29435 Mtetra
.565 .774 .977 r
.74389 .29435 .7519 .30306 .77053 .3016 .76246 .29083 Mtetra
.694 .78 .918 r
.76246 .29083 .77053 .3016 .78896 .29565 .78082 .28292 Mtetra
.738 .76 .87 r
.78082 .28292 .78896 .29565 .80713 .28537 .79904 .27221 Mtetra
.527 .678 .934 r
.14284 .47917 .15324 .48981 .16753 .48908 .15719 .47809 Mtetra
.554 .682 .924 r
.15719 .47809 .16753 .48908 .18222 .48571 .17173 .47636 Mtetra
.676 .756 .912 r
.17173 .47636 .18222 .48571 .19742 .47814 .18681 .47049 Mtetra
.759 .805 .89 r
.18681 .47049 .19742 .47814 .21302 .46693 .20234 .46079 Mtetra
.79 .839 .89 r
.20234 .46079 .21302 .46693 .22857 .45662 .21805 .44959 Mtetra
.75 .821 .908 r
.21805 .44959 .22857 .45662 .24393 .44907 .23361 .44051 Mtetra
.679 .778 .925 r
.23361 .44051 .24393 .44907 .25908 .44483 .24897 .43443 Mtetra
.619 .722 .92 r
.24897 .43443 .25908 .44483 .27427 .44125 .26422 .43055 Mtetra
.617 .717 .917 r
.26422 .43055 .27427 .44125 .2896 .4373 .27958 .42672 Mtetra
.631 .725 .915 r
.27958 .42672 .2896 .4373 .30509 .43231 .29507 .42238 Mtetra
.651 .746 .919 r
.29507 .42238 .30509 .43231 .32069 .42718 .31072 .41722 Mtetra
.652 .747 .919 r
.31072 .41722 .32069 .42718 .33637 .42214 .32647 .41199 Mtetra
.65 .744 .918 r
.32647 .41199 .33637 .42214 .35214 .41713 .3423 .40682 Mtetra
.649 .741 .917 r
.3423 .40682 .35214 .41713 .36802 .41204 .35823 .40166 Mtetra
.649 .741 .916 r
.35823 .40166 .36802 .41204 .384 .4067 .37426 .39645 Mtetra
.652 .746 .919 r
.37426 .39645 .384 .4067 .40008 .40121 .3904 .39112 Mtetra
.655 .752 .921 r
.3904 .39112 .40008 .40121 .41626 .39567 .40663 .38562 Mtetra
.656 .754 .922 r
.40663 .38562 .41626 .39567 .43254 .39015 .42297 .38005 Mtetra
.42297 .38005 .43254 .39015 .44891 .38461 .43941 .37444 Mtetra
.43941 .37444 .44891 .38461 .46538 .37904 .45595 .36881 Mtetra
.655 .754 .922 r
.45595 .36881 .46538 .37904 .48195 .37344 .47258 .36316 Mtetra
.655 .754 .923 r
.47258 .36316 .48195 .37344 .49863 .36784 .48932 .35747 Mtetra
.657 .754 .922 r
.48932 .35747 .49863 .36784 .5154 .36223 .50617 .35171 Mtetra
.66 .754 .919 r
.50617 .35171 .5154 .36223 .53228 .35659 .52312 .34577 Mtetra
.662 .749 .915 r
.52312 .34577 .53228 .35659 .54927 .35079 .54017 .33971 Mtetra
.662 .745 .912 r
.54017 .33971 .54927 .35079 .56635 .34473 .55732 .33359 Mtetra
.661 .745 .912 r
.55732 .33359 .56635 .34473 .58354 .33858 .57458 .32748 Mtetra
.659 .747 .915 r
.57458 .32748 .58354 .33858 .60083 .33246 .59195 .32142 Mtetra
.66 .75 .916 r
.59195 .32142 .60083 .33246 .61823 .32643 .60942 .31529 Mtetra
.679 .756 .909 r
.60942 .31529 .61823 .32643 .63574 .32024 .62697 .30831 Mtetra
.688 .745 .895 r
.62697 .30831 .63574 .32024 .65331 .31298 .64461 .3008 Mtetra
.686 .741 .893 r
.64461 .3008 .65331 .31298 .67095 .30531 .66234 .29332 Mtetra
.635 .725 .913 r
.66234 .29332 .67095 .30531 .68873 .29833 .68028 .2881 Mtetra
.535 .721 .959 r
.68028 .2881 .68873 .29833 .70681 .29476 .69853 .28599 Mtetra
.42 .7 .979 r
.69853 .28599 .70681 .29476 .72523 .29407 .71708 .28612 Mtetra
.468 .748 .99 r
.71708 .28612 .72523 .29407 .74389 .29435 .73572 .28469 Mtetra
.629 .781 .954 r
.73572 .28469 .74389 .29435 .76246 .29083 .75424 .27927 Mtetra
.727 .779 .894 r
.75424 .27927 .76246 .29083 .78082 .28292 .77255 .2695 Mtetra
.73 .747 .865 r
.77255 .2695 .78082 .28292 .79904 .27221 .79088 .25903 Mtetra
.555 .69 .929 r
.13233 .46849 .14284 .47917 .15719 .47809 .14679 .46663 Mtetra
.528 .664 .923 r
.14679 .46663 .15719 .47809 .17173 .47636 .16128 .4656 Mtetra
.616 .712 .914 r
.16128 .4656 .17173 .47636 .18681 .47049 .17617 .4619 Mtetra
.711 .782 .908 r
.17617 .4619 .18681 .47049 .20234 .46079 .19153 .45449 Mtetra
.783 .838 .894 r
.19153 .45449 .20234 .46079 .21805 .44959 .20729 .44363 Mtetra
.777 .848 .904 r
.20729 .44363 .21805 .44959 .23361 .44051 .22305 .43316 Mtetra
.731 .816 .918 r
.22305 .43316 .23361 .44051 .24897 .43443 .23866 .42488 Mtetra
.654 .754 .923 r
.23866 .42488 .24897 .43443 .26422 .43055 .25408 .41965 Mtetra
.618 .715 .915 r
.25408 .41965 .26422 .43055 .27958 .42672 .26948 .41571 Mtetra
.621 .715 .913 r
.26948 .41571 .27958 .42672 .29507 .42238 .285 .41167 Mtetra
.634 .727 .915 r
.285 .41167 .29507 .42238 .31072 .41722 .30065 .40711 Mtetra
.651 .746 .919 r
.30065 .40711 .31072 .41722 .32647 .41199 .31645 .40185 Mtetra
.654 .747 .919 r
.31645 .40185 .32647 .41199 .3423 .40682 .33235 .39648 Mtetra
.651 .744 .917 r
.33235 .39648 .3423 .40682 .35823 .40166 .34834 .39118 Mtetra
.651 .742 .916 r
.34834 .39118 .35823 .40166 .37426 .39645 .36443 .38583 Mtetra
.651 .74 .915 r
.36443 .38583 .37426 .39645 .3904 .39112 .38062 .38047 Mtetra
.652 .741 .915 r
.38062 .38047 .3904 .39112 .40663 .38562 .39691 .37503 Mtetra
.653 .744 .916 r
.39691 .37503 .40663 .38562 .42297 .38005 .41331 .36951 Mtetra
.655 .747 .918 r
.41331 .36951 .42297 .38005 .43941 .37444 .42981 .36389 Mtetra
.656 .749 .918 r
.42981 .36389 .43941 .37444 .45595 .36881 .44641 .3582 Mtetra
.657 .749 .918 r
.44641 .3582 .45595 .36881 .47258 .36316 .46311 .35242 Mtetra
.658 .748 .916 r
.46311 .35242 .47258 .36316 .48932 .35747 .47992 .34656 Mtetra
.66 .746 .914 r
.47992 .34656 .48932 .35747 .50617 .35171 .49683 .3406 Mtetra
.66 .744 .912 r
.49683 .3406 .50617 .35171 .52312 .34577 .51384 .33457 Mtetra
.66 .743 .912 r
.51384 .33457 .52312 .34577 .54017 .33971 .53096 .32852 Mtetra
.66 .745 .913 r
.53096 .32852 .54017 .33971 .55732 .33359 .54819 .32242 Mtetra
.658 .746 .915 r
.54819 .32242 .55732 .33359 .57458 .32748 .56552 .31638 Mtetra
.66 .75 .916 r
.56552 .31638 .57458 .32748 .59195 .32142 .58295 .31022 Mtetra
.676 .755 .91 r
.58295 .31022 .59195 .32142 .60942 .31529 .60048 .30335 Mtetra
.685 .745 .896 r
.60048 .30335 .60942 .31529 .62697 .30831 .6181 .29592 Mtetra
.686 .738 .89 r
.6181 .29592 .62697 .30831 .64461 .3008 .63581 .28838 Mtetra
.657 .728 .901 r
.63581 .28838 .64461 .3008 .66234 .29332 .65367 .28217 Mtetra
.571 .718 .942 r
.65367 .28217 .66234 .29332 .68028 .2881 .6718 .2791 Mtetra
.462 .718 .979 r
.6718 .2791 .68028 .2881 .69853 .28599 .6902 .27831 Mtetra
.409 .725 .989 r
.6902 .27831 .69853 .28599 .71708 .28612 .70881 .27795 Mtetra
.567 .793 .984 r
.70881 .27795 .71708 .28612 .73572 .28469 .72738 .27401 Mtetra
.689 .785 .923 r
.72738 .27401 .73572 .28469 .75424 .27927 .74582 .26619 Mtetra
.734 .755 .869 r
.74582 .26619 .75424 .27927 .77255 .2695 .76416 .25556 Mtetra
.716 .735 .866 r
.76416 .25556 .77255 .2695 .79088 .25903 .78263 .24577 Mtetra
.581 .705 .928 r
.12168 .45799 .13233 .46849 .14679 .46663 .13626 .45534 Mtetra
.54 .674 .925 r
.13626 .45534 .14679 .46663 .16128 .4656 .15081 .45391 Mtetra
.555 .673 .917 r
.15081 .45391 .16128 .4656 .17617 .4619 .16552 .4521 Mtetra
.661 .748 .915 r
.16552 .4521 .17617 .4619 .19153 .45449 .18073 .44668 Mtetra
.739 .806 .905 r
.18073 .44668 .19153 .45449 .20729 .44363 .19635 .43794 Mtetra
.786 .855 .902 r
.19635 .43794 .20729 .44363 .22305 .43316 .21225 .42698 Mtetra
.762 .846 .914 r
.21225 .42698 .22305 .43316 .23866 .42488 .22807 .41722 Mtetra
.717 .811 .924 r
.22807 .41722 .23866 .42488 .25408 .41965 .24376 .40947 Mtetra
.646 .741 .919 r
.24376 .40947 .25408 .41965 .26948 .41571 .25929 .40448 Mtetra
.621 .713 .911 r
.25929 .40448 .26948 .41571 .285 .41167 .27485 .40036 Mtetra
.625 .714 .91 r
.27485 .40036 .285 .41167 .30065 .40711 .29053 .3961 Mtetra
.633 .724 .913 r
.29053 .3961 .30065 .40711 .31645 .40185 .30633 .39149 Mtetra
.65 .744 .918 r
.30633 .39149 .31645 .40185 .33235 .39648 .32228 .38619 Mtetra
.654 .748 .919 r
.32228 .38619 .33235 .39648 .34834 .39118 .33834 .3807 Mtetra
.653 .745 .917 r
.33834 .3807 .34834 .39118 .36443 .38583 .35449 .37521 Mtetra
.653 .743 .916 r
.35449 .37521 .36443 .38583 .38062 .38047 .37074 .36971 Mtetra
.653 .742 .915 r
.37074 .36971 .38062 .38047 .39691 .37503 .38709 .36416 Mtetra
.654 .741 .914 r
.38709 .36416 .39691 .37503 .41331 .36951 .40355 .35854 Mtetra
.655 .741 .913 r
.40355 .35854 .41331 .36951 .42981 .36389 .42011 .35286 Mtetra
.656 .741 .912 r
.42011 .35286 .42981 .36389 .44641 .3582 .43677 .3471 Mtetra
.657 .741 .912 r
.43677 .3471 .44641 .3582 .46311 .35242 .45354 .34126 Mtetra
.658 .742 .912 r
.45354 .34126 .46311 .35242 .47992 .34656 .47041 .33536 Mtetra
.658 .743 .912 r
.47041 .33536 .47992 .34656 .49683 .3406 .48738 .32939 Mtetra
.659 .744 .913 r
.48738 .32939 .49683 .3406 .51384 .33457 .50447 .32336 Mtetra
.658 .745 .914 r
.50447 .32336 .51384 .33457 .53096 .32852 .52165 .31732 Mtetra
.657 .746 .916 r
.52165 .31732 .53096 .32852 .54819 .32242 .53895 .31128 Mtetra
.661 .75 .916 r
.53895 .31128 .54819 .32242 .56552 .31638 .55635 .30504 Mtetra
.677 .753 .909 r
.55635 .30504 .56552 .31638 .58295 .31022 .57385 .29809 Mtetra
.682 .741 .895 r
.57385 .29809 .58295 .31022 .60048 .30335 .59144 .29076 Mtetra
.683 .734 .889 r
.59144 .29076 .60048 .30335 .6181 .29592 .60912 .28329 Mtetra
.664 .727 .896 r
.60912 .28329 .6181 .29592 .63581 .28838 .62694 .2767 Mtetra
.593 .718 .931 r
.62694 .2767 .63581 .28838 .65367 .28217 .64498 .27295 Mtetra
.499 .733 .977 r
.64498 .27295 .65367 .28217 .6718 .2791 .66325 .27128 Mtetra
.411 .724 .989 r
.66325 .27128 .6718 .2791 .6902 .27831 .68177 .27088 Mtetra
.504 .784 .995 r
.68177 .27088 .6902 .27831 .70881 .27795 .70034 .26818 Mtetra
.646 .79 .951 r
.70034 .26818 .70881 .27795 .72738 .27401 .71886 .26204 Mtetra
.727 .774 .89 r
.71886 .26204 .72738 .27401 .74582 .26619 .73725 .25211 Mtetra
.724 .737 .861 r
.73725 .25211 .74582 .26619 .76416 .25556 .75569 .24176 Mtetra
.704 .735 .875 r
.75569 .24176 .76416 .25556 .78263 .24577 .77431 .23265 Mtetra
.621 .734 .928 r
.11083 .44812 .12168 .45799 .13626 .45534 .12561 .44413 Mtetra
.568 .689 .922 r
.12561 .44413 .13626 .45534 .15081 .45391 .14028 .44183 Mtetra
.54 .662 .915 r
.14028 .44183 .15081 .45391 .16552 .4521 .15497 .44043 Mtetra
.59 .69 .912 r
.15497 .44043 .16552 .4521 .18073 .44668 .16994 .43748 Mtetra
.683 .77 .917 r
.16994 .43748 .18073 .44668 .19635 .43794 .18538 .43111 Mtetra
.753 .832 .912 r
.18538 .43111 .19635 .43794 .21225 .42698 .2012 .42168 Mtetra
.782 .868 .912 r
.2012 .42168 .21225 .42698 .22807 .41722 .2172 .41092 Mtetra
.751 .847 .922 r
.2172 .41092 .22807 .41722 .24376 .40947 .23311 .40162 Mtetra
.711 .81 .926 r
.23311 .40162 .24376 .40947 .25929 .40448 .24892 .39403 Mtetra
.648 .74 .916 r
.24892 .39403 .25929 .40448 .27485 .40036 .26461 .38885 Mtetra
.626 .712 .908 r
.26461 .38885 .27485 .40036 .29053 .3961 .28033 .38449 Mtetra
.629 .712 .907 r
.28033 .38449 .29053 .3961 .30633 .39149 .29617 .37999 Mtetra
.632 .717 .908 r
.29617 .37999 .30633 .39149 .32228 .38619 .31213 .37532 Mtetra
.644 .735 .915 r
.31213 .37532 .32228 .38619 .33834 .3807 .32821 .37017 Mtetra
.652 .746 .918 r
.32821 .37017 .33834 .3807 .35449 .37521 .34442 .36465 Mtetra
.655 .748 .918 r
.34442 .36465 .35449 .37521 .37074 .36971 .36074 .35901 Mtetra
.655 .746 .917 r
.36074 .35901 .37074 .36971 .38709 .36416 .37716 .35331 Mtetra
.655 .744 .915 r
.37716 .35331 .38709 .36416 .40355 .35854 .39368 .34759 Mtetra
.39368 .34759 .40355 .35854 .42011 .35286 .4103 .34183 Mtetra
.656 .744 .914 r
.4103 .34183 .42011 .35286 .43677 .3471 .42702 .336 Mtetra
.657 .744 .914 r
.42702 .336 .43677 .3471 .45354 .34126 .44385 .33011 Mtetra
.44385 .33011 .45354 .34126 .47041 .33536 .46079 .32418 Mtetra
.656 .745 .915 r
.46079 .32418 .47041 .33536 .48738 .32939 .47783 .31822 Mtetra
.657 .747 .916 r
.47783 .31822 .48738 .32939 .50447 .32336 .49498 .3122 Mtetra
.659 .749 .916 r
.49498 .3122 .50447 .32336 .52165 .31732 .51224 .30606 Mtetra
.667 .751 .913 r
.51224 .30606 .52165 .31732 .53895 .31128 .5296 .29953 Mtetra
.677 .746 .903 r
.5296 .29953 .53895 .31128 .55635 .30504 .54707 .29252 Mtetra
.678 .734 .892 r
.54707 .29252 .55635 .30504 .57385 .29809 .56463 .28531 Mtetra
.68 .731 .889 r
.56463 .28531 .57385 .29809 .59144 .29076 .58229 .27796 Mtetra
.662 .725 .896 r
.58229 .27796 .59144 .29076 .60912 .28329 .60008 .27144 Mtetra
.6 .719 .928 r
.60008 .27144 .60912 .28329 .62694 .2767 .61804 .26738 Mtetra
.521 .743 .976 r
.61804 .26738 .62694 .2767 .64498 .27295 .63622 .2651 Mtetra
.425 .733 .99 r
.63622 .2651 .64498 .27295 .66325 .27128 .65463 .26435 Mtetra
.464 .778 .998 r
.65463 .26435 .66325 .27128 .68177 .27088 .67315 .26223 Mtetra
.613 .805 .973 r
.67315 .26223 .68177 .27088 .70034 .26818 .69168 .25695 Mtetra
.709 .784 .91 r
.69168 .25695 .70034 .26818 .71886 .26204 .71014 .24809 Mtetra
.727 .741 .863 r
.71014 .24809 .71886 .26204 .73725 .25211 .72857 .23759 Mtetra
.709 .726 .864 r
.72857 .23759 .73725 .25211 .75569 .24176 .74716 .228 Mtetra
.68 .729 .887 r
.74716 .228 .75569 .24176 .77431 .23265 .76596 .22016 Mtetra
.651 .75 .922 r
.09982 .4385 .11083 .44812 .12561 .44413 .11477 .43343 Mtetra
.601 .714 .924 r
.11477 .43343 .12561 .44413 .14028 .44183 .1296 .43003 Mtetra
.563 .679 .917 r
.1296 .43003 .14028 .44183 .15497 .44043 .1444 .42786 Mtetra
.549 .659 .908 r
.1444 .42786 .15497 .44043 .16994 .43748 .15925 .42617 Mtetra
.614 .709 .913 r
.15925 .42617 .16994 .43748 .18538 .43111 .17446 .42231 Mtetra
.692 .784 .921 r
.17446 .42231 .18538 .43111 .2012 .42168 .19008 .41548 Mtetra
.756 .85 .921 r
.19008 .41548 .2012 .42168 .2172 .41092 .20605 .40591 Mtetra
.776 .878 .921 r
.20605 .40591 .2172 .41092 .23311 .40162 .22215 .39542 Mtetra
.746 .853 .929 r
.22215 .39542 .23311 .40162 .24892 .39403 .23818 .38629 Mtetra
.712 .816 .93 r
.23818 .38629 .24892 .39403 .26461 .38885 .25415 .37857 Mtetra
.66 .751 .917 r
.25415 .37857 .26461 .38885 .28033 .38449 .27003 .37283 Mtetra
.635 .716 .906 r
.27003 .37283 .28033 .38449 .29617 .37999 .28593 .36802 Mtetra
.631 .71 .903 r
.28593 .36802 .29617 .37999 .31213 .37532 .30193 .36334 Mtetra
.635 .712 .903 r
.30193 .36334 .31213 .37532 .32821 .37017 .31805 .35847 Mtetra
.639 .721 .907 r
.31805 .35847 .32821 .37017 .34442 .36465 .33428 .3534 Mtetra
.644 .733 .913 r
.33428 .3534 .34442 .36465 .36074 .35901 .35063 .3481 Mtetra
.652 .743 .916 r
.35063 .3481 .36074 .35901 .37716 .35331 .3671 .34246 Mtetra
.654 .747 .918 r
.3671 .34246 .37716 .35331 .39368 .34759 .38368 .33671 Mtetra
.655 .747 .918 r
.38368 .33671 .39368 .34759 .4103 .34183 .40037 .33088 Mtetra
.656 .748 .917 r
.40037 .33088 .4103 .34183 .42702 .336 .41716 .32498 Mtetra
.657 .748 .917 r
.41716 .32498 .42702 .336 .44385 .33011 .43405 .31902 Mtetra
.658 .748 .917 r
.43405 .31902 .44385 .33011 .46079 .32418 .45106 .31299 Mtetra
.659 .748 .916 r
.45106 .31299 .46079 .32418 .47783 .31822 .46817 .30684 Mtetra
.667 .748 .911 r
.46817 .30684 .47783 .31822 .49498 .3122 .48539 .30034 Mtetra
.671 .742 .904 r
.48539 .30034 .49498 .3122 .51224 .30606 .50272 .2936 Mtetra
.673 .733 .895 r
.50272 .2936 .51224 .30606 .5296 .29953 .52015 .28665 Mtetra
.676 .727 .888 r
.52015 .28665 .5296 .29953 .54707 .29252 .53768 .2795 Mtetra
.672 .725 .889 r
.53768 .2795 .54707 .29252 .56463 .28531 .55531 .27248 Mtetra
.651 .721 .9 r
.55531 .27248 .56463 .28531 .58229 .27796 .57307 .2664 Mtetra
.598 .726 .934 r
.57307 .2664 .58229 .27796 .60008 .27144 .59098 .26234 Mtetra
.528 .753 .979 r
.59098 .26234 .60008 .27144 .61804 .26738 .60908 .25975 Mtetra
.437 .747 .993 r
.60908 .25975 .61804 .26738 .63622 .2651 .62739 .25857 Mtetra
.45 .782 .998 r
.62739 .25857 .63622 .2651 .65463 .26435 .64584 .25645 Mtetra
.593 .816 .985 r
.64584 .25645 .65463 .26435 .67315 .26223 .66433 .25151 Mtetra
.691 .789 .925 r
.66433 .25151 .67315 .26223 .69168 .25695 .68281 .24348 Mtetra
.726 .75 .871 r
.68281 .24348 .69168 .25695 .71014 .24809 .70127 .23317 Mtetra
.711 .722 .858 r
.70127 .23317 .71014 .24809 .72857 .23759 .71983 .22333 Mtetra
.692 .726 .877 r
.71983 .22333 .72857 .23759 .74716 .228 .73857 .21475 Mtetra
.659 .732 .903 r
.73857 .21475 .74716 .228 .76596 .22016 .75754 .2079 Mtetra
.658 .753 .92 r
.08868 .42884 .09982 .4385 .11477 .43343 .10371 .42344 Mtetra
.643 .744 .922 r
.10371 .42344 .11477 .43343 .1296 .43003 .11877 .41856 Mtetra
.59 .698 .917 r
.11877 .41856 .1296 .43003 .1444 .42786 .1337 .41548 Mtetra
.563 .67 .911 r
.1337 .41548 .1444 .42786 .15925 .42617 .14863 .41331 Mtetra
.561 .662 .904 r
.14863 .41331 .15925 .42617 .17446 .42231 .16367 .4112 Mtetra
.625 .721 .915 r
.16367 .4112 .17446 .42231 .19008 .41548 .17907 .40685 Mtetra
.692 .791 .926 r
.17907 .40685 .19008 .41548 .20605 .40591 .19483 .39994 Mtetra
.748 .859 .93 r
.19483 .39994 .20605 .40591 .22215 .39542 .21091 .39066 Mtetra
.767 .887 .931 r
.21091 .39066 .22215 .39542 .23818 .38629 .22712 .3805 Mtetra
.745 .866 .936 r
.22712 .3805 .23818 .38629 .25415 .37857 .2433 .37129 Mtetra
.716 .831 .936 r
.2433 .37129 .25415 .37857 .27003 .37283 .25943 .36331 Mtetra
.682 .776 .922 r
.25943 .36331 .27003 .37283 .28593 .36802 .27554 .35662 Mtetra
.649 .73 .908 r
.27554 .35662 .28593 .36802 .30193 .36334 .29164 .35118 Mtetra
.639 .713 .901 r
.29164 .35118 .30193 .36334 .31805 .35847 .30781 .3461 Mtetra
.637 .71 .899 r
.30781 .3461 .31805 .35847 .33428 .3534 .32409 .34103 Mtetra
.642 .712 .898 r
.32409 .34103 .33428 .3534 .35063 .3481 .34049 .33574 Mtetra
.645 .715 .899 r
.34049 .33574 .35063 .3481 .3671 .34246 .357 .3303 Mtetra
.648 .721 .901 r
.357 .3303 .3671 .34246 .38368 .33671 .37363 .32468 Mtetra
.652 .726 .903 r
.37363 .32468 .38368 .33671 .40037 .33088 .39036 .31889 Mtetra
.655 .729 .904 r
.39036 .31889 .40037 .33088 .41716 .32498 .40721 .31293 Mtetra
.658 .731 .903 r
.40721 .31293 .41716 .32498 .43405 .31902 .42418 .30679 Mtetra
.661 .73 .9 r
.42418 .30679 .43405 .31902 .45106 .31299 .44125 .30048 Mtetra
.664 .727 .896 r
.44125 .30048 .45106 .31299 .46817 .30684 .45842 .29399 Mtetra
.666 .722 .891 r
.45842 .29399 .46817 .30684 .48539 .30034 .47571 .28733 Mtetra
.67 .722 .889 r
.47571 .28733 .48539 .30034 .50272 .2936 .4931 .28045 Mtetra
.669 .721 .888 r
.4931 .28045 .50272 .2936 .52015 .28665 .5106 .27358 Mtetra
.661 .72 .893 r
.5106 .27358 .52015 .28665 .53768 .2795 .5282 .26707 Mtetra
.631 .722 .913 r
.5282 .26707 .53768 .2795 .55531 .27248 .54591 .26182 Mtetra
.588 .743 .95 r
.54591 .26182 .55531 .27248 .57307 .2664 .56378 .25789 Mtetra
.519 .765 .986 r
.56378 .25789 .57307 .2664 .59098 .26234 .5818 .25524 Mtetra
.443 .765 .996 r
.5818 .25524 .59098 .26234 .60908 .25975 .60002 .25357 Mtetra
.459 .797 .999 r
.60002 .25357 .60908 .25975 .62739 .25857 .61839 .25101 Mtetra
.59 .824 .988 r
.61839 .25101 .62739 .25857 .64584 .25645 .63683 .24601 Mtetra
.682 .793 .933 r
.63683 .24601 .64584 .25645 .66433 .25151 .6553 .23836 Mtetra
.722 .755 .879 r
.6553 .23836 .66433 .25151 .68281 .24348 .67377 .22836 Mtetra
.711 .72 .856 r
.67377 .22836 .68281 .24348 .70127 .23317 .69232 .21841 Mtetra
.697 .721 .868 r
.69232 .21841 .70127 .23317 .71983 .22333 .71102 .20938 Mtetra
.664 .723 .892 r
.71102 .20938 .71983 .22333 .73857 .21475 .72994 .2022 Mtetra
.653 .746 .918 r
.72994 .2022 .73857 .21475 .75754 .2079 .74902 .19556 Mtetra
.656 .752 .92 r
.07742 .41903 .08868 .42884 .10371 .42344 .09249 .41366 Mtetra
.658 .754 .921 r
.09249 .41366 .10371 .42344 .11877 .41856 .10767 .40818 Mtetra
.635 .737 .922 r
.10767 .40818 .11877 .41856 .1337 .41548 .12283 .40351 Mtetra
.59 .691 .912 r
.12283 .40351 .1337 .41548 .14863 .41331 .13789 .40037 Mtetra
.567 .665 .904 r
.13789 .40037 .14863 .41331 .16367 .4112 .15298 .39801 Mtetra
.569 .662 .9 r
.15298 .39801 .16367 .4112 .17907 .40685 .1682 .39559 Mtetra
.624 .721 .916 r
.1682 .39559 .17907 .40685 .19483 .39994 .18375 .39116 Mtetra
.684 .79 .93 r
.18375 .39116 .19483 .39994 .21091 .39066 .19963 .38449 Mtetra
.73 .857 .941 r
.19963 .38449 .21091 .39066 .22712 .3805 .21577 .37589 Mtetra
.754 .894 .941 r
.21577 .37589 .22712 .3805 .2433 .37129 .23209 .36618 Mtetra
.746 .884 .943 r
.23209 .36618 .2433 .37129 .25943 .36331 .24844 .35678 Mtetra
.719 .852 .945 r
.24844 .35678 .25943 .36331 .27554 .35662 .26475 .34853 Mtetra
.699 .815 .937 r
.26475 .34853 .27554 .35662 .29164 .35118 .28107 .34108 Mtetra
.676 .768 .92 r
.28107 .34108 .29164 .35118 .30781 .3461 .29741 .33447 Mtetra
.654 .732 .906 r
.29741 .33447 .30781 .3461 .32409 .34103 .31378 .32868 Mtetra
.648 .717 .899 r
.31378 .32868 .32409 .34103 .34049 .33574 .33025 .32308 Mtetra
.647 .712 .895 r
.33025 .32308 .34049 .33574 .357 .3303 .34682 .31748 Mtetra
.648 .711 .894 r
.34682 .31748 .357 .3303 .37363 .32468 .3635 .31178 Mtetra
.651 .712 .892 r
.3635 .31178 .37363 .32468 .39036 .31889 .38029 .30592 Mtetra
.654 .713 .891 r
.38029 .30592 .39036 .31889 .40721 .31293 .3972 .29988 Mtetra
.657 .714 .89 r
.3972 .29988 .40721 .31293 .42418 .30679 .41422 .29367 Mtetra
.66 .715 .889 r
.41422 .29367 .42418 .30679 .44125 .30048 .43134 .2873 Mtetra
.661 .716 .889 r
.43134 .2873 .44125 .30048 .45842 .29399 .44858 .28082 Mtetra
.66 .717 .89 r
.44858 .28082 .45842 .29399 .47571 .28733 .46592 .27434 Mtetra
.656 .72 .896 r
.46592 .27434 .47571 .28733 .4931 .28045 .48337 .26805 Mtetra
.636 .725 .912 r
.48337 .26805 .4931 .28045 .5106 .27358 .50092 .26258 Mtetra
.61 .745 .941 r
.50092 .26258 .5106 .27358 .5282 .26707 .5186 .25797 Mtetra
.57 .773 .975 r
.5186 .25797 .5282 .26707 .54591 .26182 .53641 .25419 Mtetra
.499 .779 .995 r
.53641 .25419 .54591 .26182 .56378 .25789 .55437 .25158 Mtetra
.448 .788 .998 r
.55437 .25158 .56378 .25789 .5818 .25524 .57251 .24931 Mtetra
.491 .82 1 r
.57251 .24931 .5818 .25524 .60002 .25357 .59079 .24591 Mtetra
.603 .828 .986 r
.59079 .24591 .60002 .25357 .61839 .25101 .60917 .24053 Mtetra
.683 .794 .933 r
.60917 .24053 .61839 .25101 .63683 .24601 .62762 .23282 Mtetra
.718 .754 .881 r
.62762 .23282 .63683 .24601 .6553 .23836 .64608 .22303 Mtetra
.709 .717 .855 r
.64608 .22303 .6553 .23836 .67377 .22836 .66464 .21315 Mtetra
.696 .715 .863 r
.66464 .21315 .67377 .22836 .69232 .21841 .68331 .20404 Mtetra
.669 .719 .886 r
.68331 .20404 .69232 .21841 .71102 .20938 .70218 .19652 Mtetra
.654 .741 .914 r
.70218 .19652 .71102 .20938 .72994 .2022 .72122 .18982 Mtetra
.655 .753 .922 r
.72122 .18982 .72994 .2022 .74902 .19556 .74039 .18301 Mtetra
.654 .75 .92 r
.06605 .40904 .07742 .41903 .09249 .41366 .08116 .40367 Mtetra
.656 .752 .92 r
.08116 .40367 .09249 .41366 .10767 .40818 .09638 .3982 Mtetra
.657 .753 .921 r
.09638 .3982 .10767 .40818 .12283 .40351 .11169 .39266 Mtetra
.632 .73 .918 r
.11169 .39266 .12283 .40351 .13789 .40037 .12698 .38799 Mtetra
.594 .688 .907 r
.12698 .38799 .13789 .40037 .15298 .39801 .14221 .38466 Mtetra
.575 .664 .898 r
.14221 .38466 .15298 .39801 .1682 .39559 .15747 .38197 Mtetra
.574 .66 .895 r
.15747 .38197 .1682 .39559 .18375 .39116 .17285 .37931 Mtetra
.614 .709 .913 r
.17285 .37931 .18375 .39116 .19963 .38449 .18851 .37518 Mtetra
.669 .779 .932 r
.18851 .37518 .19963 .38449 .21577 .37589 .20449 .36897 Mtetra
.702 .84 .949 r
.20449 .36897 .21577 .37589 .23209 .36618 .22068 .36143 Mtetra
.734 .893 .952 r
.22068 .36143 .23209 .36618 .24844 .35678 .23709 .35238 Mtetra
.735 .902 .953 r
.23709 .35238 .24844 .35678 .26475 .34853 .25357 .34321 Mtetra
.724 .883 .954 r
.25357 .34321 .26475 .34853 .28107 .34108 .27007 .33452 Mtetra
.704 .854 .954 r
.27007 .33452 .28107 .34108 .29741 .33447 .28659 .3267 Mtetra
.691 .826 .948 r
.28659 .3267 .29741 .33447 .31378 .32868 .30314 .31941 Mtetra
.679 .792 .934 r
.30314 .31941 .31378 .32868 .33025 .32308 .31975 .31257 Mtetra
.67 .764 .921 r
.31975 .31257 .33025 .32308 .34682 .31748 .33644 .30605 Mtetra
.662 .745 .912 r
.33644 .30605 .34682 .31748 .3635 .31178 .35321 .29978 Mtetra
.656 .733 .906 r
.35321 .29978 .3635 .31178 .38029 .30592 .37007 .29367 Mtetra
.655 .73 .904 r
.37007 .29367 .38029 .30592 .3972 .29988 .38704 .28757 Mtetra
.655 .729 .904 r
.38704 .28757 .3972 .29988 .41422 .29367 .40411 .28145 Mtetra
.65 .731 .908 r
.40411 .28145 .41422 .29367 .43134 .2873 .42129 .27551 Mtetra
.643 .738 .918 r
.42129 .27551 .43134 .2873 .44858 .28082 .43857 .26981 Mtetra
.633 .752 .934 r
.43857 .26981 .44858 .28082 .46592 .27434 .45596 .26445 Mtetra
.615 .771 .955 r
.45596 .26445 .46592 .27434 .48337 .26805 .47346 .25953 Mtetra
.585 .793 .979 r
.47346 .25953 .48337 .26805 .50092 .26258 .49109 .25517 Mtetra
.533 .8 .995 r
.49109 .25517 .50092 .26258 .5186 .25797 .50885 .25169 Mtetra
.483 .806 1 r
.50885 .25169 .5186 .25797 .53641 .25419 .52676 .24871 Mtetra
.464 .816 .997 r
.52676 .24871 .53641 .25419 .55437 .25158 .54483 .24562 Mtetra
.547 .845 .998 r
.54483 .24562 .55437 .25158 .57251 .24931 .56304 .24099 Mtetra
.629 .823 .975 r
.56304 .24099 .57251 .24931 .59079 .24591 .58136 .235 Mtetra
.692 .788 .924 r
.58136 .235 .59079 .24591 .60917 .24053 .59976 .22685 Mtetra
.713 .745 .877 r
.59976 .22685 .60917 .24053 .62762 .23282 .61822 .21717 Mtetra
.704 .711 .854 r
.61822 .21717 .62762 .23282 .64608 .22303 .63677 .20749 Mtetra
.693 .71 .861 r
.63677 .20749 .64608 .22303 .66464 .21315 .65544 .19846 Mtetra
.671 .715 .882 r
.65544 .19846 .66464 .21315 .68331 .20404 .67427 .19081 Mtetra
.654 .736 .91 r
.67427 .19081 .68331 .20404 .70218 .19652 .69327 .18405 Mtetra
.655 .753 .921 r
.69327 .18405 .70218 .19652 .72122 .18982 .7124 .1772 Mtetra
.657 .752 .92 r
.7124 .1772 .72122 .18982 .74039 .18301 .73165 .17023 Mtetra
.649 .746 .92 r
.05457 .39879 .06605 .40904 .08116 .40367 .06971 .39355 Mtetra
.655 .751 .92 r
.06971 .39355 .08116 .40367 .09638 .3982 .08497 .38805 Mtetra
.656 .752 .92 r
.08497 .38805 .09638 .3982 .11169 .39266 .10033 .38247 Mtetra
.657 .752 .92 r
.10033 .38247 .11169 .39266 .12698 .38799 .11578 .37685 Mtetra
.636 .729 .915 r
.11578 .37685 .12698 .38799 .14221 .38466 .13123 .37197 Mtetra
.601 .688 .904 r
.13123 .37197 .14221 .38466 .15747 .38197 .14664 .36832 Mtetra
.587 .667 .894 r
.14664 .36832 .15747 .38197 .17285 .37931 .1621 .36516 Mtetra
.578 .656 .889 r
.1621 .36516 .17285 .37931 .18851 .37518 .17764 .3623 Mtetra
.6 .688 .904 r
.17764 .3623 .18851 .37518 .20449 .36897 .19339 .3586 Mtetra
.648 .755 .927 r
.19339 .3586 .20449 .36897 .22068 .36143 .20944 .35308 Mtetra
.678 .807 .944 r
.20944 .35308 .22068 .36143 .23709 .35238 .2257 .34638 Mtetra
.696 .865 .962 r
.2257 .34638 .23709 .35238 .25357 .34321 .24214 .33877 Mtetra
.711 .902 .964 r
.24214 .33877 .25357 .34321 .27007 .33452 .25872 .3303 Mtetra
.706 .908 .966 r
.25872 .3303 .27007 .33452 .28659 .3267 .27538 .32186 Mtetra
.7 .895 .968 r
.27538 .32186 .28659 .3267 .30314 .31941 .29209 .31373 Mtetra
.69 .877 .968 r
.29209 .31373 .30314 .31941 .31975 .31257 .30885 .30605 Mtetra
.675 .857 .969 r
.30885 .30605 .31975 .31257 .33644 .30605 .32565 .29896 Mtetra
.666 .843 .968 r
.32565 .29896 .33644 .30605 .35321 .29978 .34253 .29221 Mtetra
.658 .832 .967 r
.34253 .29221 .35321 .29978 .37007 .29367 .3595 .28575 Mtetra
.649 .823 .967 r
.3595 .28575 .37007 .29367 .38704 .28757 .37655 .27958 Mtetra
.639 .82 .97 r
.37655 .27958 .38704 .28757 .40411 .28145 .3937 .27368 Mtetra
.626 .822 .976 r
.3937 .27368 .40411 .28145 .42129 .27551 .41095 .26808 Mtetra
.608 .826 .983 r
.41095 .26808 .42129 .27551 .43857 .26981 .4283 .26284 Mtetra
.578 .827 .992 r
.4283 .26284 .43857 .26981 .45596 .26445 .44577 .25817 Mtetra
.543 .831 .998 r
.44577 .25817 .45596 .26445 .47346 .25953 .46335 .25398 Mtetra
.509 .834 .999 r
.46335 .25398 .47346 .25953 .49109 .25517 .48108 .25011 Mtetra
.491 .838 .996 r
.48108 .25011 .49109 .25517 .50885 .25169 .49894 .24628 Mtetra
.54 .853 .998 r
.49894 .24628 .50885 .25169 .52676 .24871 .51696 .24158 Mtetra
.606 .841 .989 r
.51696 .24158 .52676 .24871 .54483 .24562 .53512 .23595 Mtetra
.659 .804 .952 r
.53512 .23595 .54483 .24562 .56304 .24099 .55339 .22911 Mtetra
.702 .773 .907 r
.55339 .22911 .56304 .24099 .58136 .235 .57176 .22038 Mtetra
.707 .728 .867 r
.57176 .22038 .58136 .235 .59976 .22685 .5902 .21077 Mtetra
.696 .703 .852 r
.5902 .21077 .59976 .22685 .61822 .21717 .60874 .20145 Mtetra
.689 .706 .861 r
.60874 .20145 .61822 .21717 .63677 .20749 .62739 .19262 Mtetra
.668 .712 .881 r
.62739 .19262 .63677 .20749 .65544 .19846 .6462 .18504 Mtetra
.654 .734 .908 r
.6462 .18504 .65544 .19846 .67427 .19081 .66515 .17823 Mtetra
.655 .752 .921 r
.66515 .17823 .67427 .19081 .69327 .18405 .68424 .17135 Mtetra
.656 .752 .92 r
.68424 .17135 .69327 .18405 .7124 .1772 .70345 .16438 Mtetra
.661 .753 .918 r
.70345 .16438 .7124 .1772 .73165 .17023 .72278 .15713 Mtetra
.653 .749 .92 r
.04295 .38854 .05457 .39879 .06971 .39355 .05815 .38312 Mtetra
.65 .745 .92 r
.05815 .38312 .06971 .39355 .08497 .38805 .07343 .37776 Mtetra
.655 .751 .92 r
.07343 .37776 .08497 .38805 .10033 .38247 .08884 .37216 Mtetra
.656 .752 .921 r
.08884 .37216 .10033 .38247 .11578 .37685 .10434 .3665 Mtetra
.658 .753 .92 r
.10434 .3665 .11578 .37685 .13123 .37197 .11995 .36074 Mtetra
.643 .733 .914 r
.11995 .36074 .13123 .37197 .14664 .36832 .13558 .35547 Mtetra
.61 .692 .901 r
.13558 .35547 .14664 .36832 .1621 .36516 .15118 .35139 Mtetra
.598 .672 .892 r
.15118 .35139 .1621 .36516 .17764 .3623 .16684 .34772 Mtetra
.588 .656 .884 r
.16684 .34772 .17764 .3623 .19339 .3586 .18257 .34443 Mtetra
.595 .667 .889 r
.18257 .34443 .19339 .3586 .20944 .35308 .19845 .34084 Mtetra
.617 .711 .913 r
.19845 .34084 .20944 .35308 .2257 .34638 .21454 .33637 Mtetra
.653 .769 .934 r
.21454 .33637 .2257 .34638 .24214 .33877 .23088 .3305 Mtetra
.669 .812 .952 r
.23088 .3305 .24214 .33877 .25872 .3303 .24737 .32394 Mtetra
.674 .858 .97 r
.24737 .32394 .25872 .3303 .27538 .32186 .264 .31693 Mtetra
.674 .89 .977 r
.264 .31693 .27538 .32186 .29209 .31373 .28075 .30952 Mtetra
.668 .905 .978 r
.28075 .30952 .29209 .31373 .30885 .30605 .2976 .30197 Mtetra
.655 .906 .981 r
.2976 .30197 .30885 .30605 .32565 .29896 .31452 .29466 Mtetra
.643 .9 .984 r
.31452 .29466 .32565 .29896 .34253 .29221 .33152 .28766 Mtetra
.629 .893 .987 r
.33152 .28766 .34253 .29221 .3595 .28575 .34859 .28104 Mtetra
.614 .886 .99 r
.34859 .28104 .3595 .28575 .37655 .27958 .36574 .2748 Mtetra
.595 .88 .992 r
.36574 .2748 .37655 .27958 .3937 .27368 .38299 .26894 Mtetra
.575 .875 .994 r
.38299 .26894 .3937 .27368 .41095 .26808 .40034 .26346 Mtetra
.554 .87 .994 r
.40034 .26346 .41095 .26808 .4283 .26284 .41779 .2583 Mtetra
.537 .867 .994 r
.41779 .2583 .4283 .26284 .44577 .25817 .43537 .25338 Mtetra
.546 .866 .995 r
.43537 .25338 .44577 .25817 .46335 .25398 .45308 .24833 Mtetra
.58 .863 .995 r
.45308 .24833 .46335 .25398 .48108 .25011 .47093 .24287 Mtetra
.618 .843 .985 r
.47093 .24287 .48108 .25011 .49894 .24628 .48892 .23695 Mtetra
.653 .808 .958 r
.48892 .23695 .49894 .24628 .51696 .24158 .50703 .23033 Mtetra
.689 .781 .921 r
.50703 .23033 .51696 .24158 .53512 .23595 .52527 .22227 Mtetra
.7 .741 .883 r
.52527 .22227 .53512 .23595 .55339 .22911 .5436 .2133 Mtetra
.697 .707 .855 r
.5436 .2133 .55339 .22911 .57176 .22038 .56203 .20399 Mtetra
.688 .696 .852 r
.56203 .20399 .57176 .22038 .5902 .21077 .58055 .19506 Mtetra
.683 .705 .864 r
.58055 .19506 .5902 .21077 .60874 .20145 .59919 .18654 Mtetra
.662 .711 .884 r
.59919 .18654 .60874 .20145 .62739 .19262 .61796 .17922 Mtetra
.653 .735 .91 r
.61796 .17922 .62739 .19262 .6462 .18504 .63688 .17241 Mtetra
.656 .752 .921 r
.63688 .17241 .6462 .18504 .66515 .17823 .65592 .16548 Mtetra
.65592 .16548 .66515 .17823 .68424 .17135 .6751 .15848 Mtetra
.661 .753 .919 r
.6751 .15848 .68424 .17135 .70345 .16438 .69439 .1512 Mtetra
.658 .748 .916 r
.69439 .1512 .70345 .16438 .72278 .15713 .71382 .14399 Mtetra
.66 .755 .921 r
.03117 .37841 .04295 .38854 .05815 .38312 .04646 .37266 Mtetra
.652 .748 .92 r
.04646 .37266 .05815 .38312 .07343 .37776 .0618 .36714 Mtetra
.65 .745 .919 r
.0618 .36714 .07343 .37776 .08884 .37216 .07723 .36168 Mtetra
.655 .751 .92 r
.07723 .36168 .08884 .37216 .10434 .3665 .09278 .35599 Mtetra
.656 .752 .92 r
.09278 .35599 .10434 .3665 .11995 .36074 .10843 .35023 Mtetra
.658 .754 .92 r
.10843 .35023 .11995 .36074 .13558 .35547 .12419 .34435 Mtetra
.65 .74 .916 r
.12419 .34435 .13558 .35547 .15118 .35139 .14001 .33875 Mtetra
.627 .706 .902 r
.14001 .33875 .15118 .35139 .16684 .34772 .15583 .33395 Mtetra
.61 .68 .892 r
.15583 .33395 .16684 .34772 .18257 .34443 .17168 .32976 Mtetra
.604 .664 .881 r
.17168 .32976 .18257 .34443 .19845 .34084 .18764 .32573 Mtetra
.597 .655 .878 r
.18764 .32573 .19845 .34084 .21454 .33637 .20368 .32196 Mtetra
.607 .672 .886 r
.20368 .32196 .21454 .33637 .23088 .3305 .21989 .31778 Mtetra
.621 .709 .908 r
.21989 .31778 .23088 .3305 .24737 .32394 .23626 .31303 Mtetra
.643 .753 .929 r
.23626 .31303 .24737 .32394 .264 .31693 .25283 .30742 Mtetra
.656 .787 .944 r
.25283 .30742 .264 .31693 .28075 .30952 .26955 .30126 Mtetra
.659 .817 .96 r
.26955 .30126 .28075 .30952 .2976 .30197 .28639 .29484 Mtetra
.655 .843 .972 r
.28639 .29484 .2976 .30197 .31452 .29466 .30334 .28832 Mtetra
.646 .86 .981 r
.30334 .28832 .31452 .29466 .33152 .28766 .3204 .28181 Mtetra
.636 .869 .985 r
.3204 .28181 .33152 .28766 .34859 .28104 .33755 .27537 Mtetra
.627 .872 .988 r
.33755 .27537 .34859 .28104 .36574 .2748 .35481 .26907 Mtetra
.621 .87 .989 r
.35481 .26907 .36574 .2748 .38299 .26894 .37217 .26288 Mtetra
.619 .864 .989 r
.37217 .26288 .38299 .26894 .40034 .26346 .38964 .25678 Mtetra
.624 .853 .986 r
.38964 .25678 .40034 .26346 .41779 .2583 .40722 .25068 Mtetra
.635 .837 .978 r
.40722 .25068 .41779 .2583 .43537 .25338 .42493 .24448 Mtetra
.649 .814 .963 r
.42493 .24448 .43537 .25338 .45308 .24833 .44276 .23802 Mtetra
.666 .791 .941 r
.44276 .23802 .45308 .24833 .47093 .24287 .46073 .23099 Mtetra
.685 .767 .913 r
.46073 .23099 .47093 .24287 .48892 .23695 .47882 .22308 Mtetra
.691 .734 .883 r
.47882 .22308 .48892 .23695 .50703 .23033 .49702 .21457 Mtetra
.691 .705 .858 r
.49702 .21457 .50703 .23033 .52527 .22227 .51532 .20564 Mtetra
.682 .69 .851 r
.51532 .20564 .52527 .22227 .5436 .2133 .53371 .19695 Mtetra
.681 .695 .856 r
.53371 .19695 .5436 .2133 .56203 .20399 .55221 .18842 Mtetra
.672 .704 .871 r
.55221 .18842 .56203 .20399 .58055 .19506 .57082 .18049 Mtetra
.658 .716 .891 r
.57082 .18049 .58055 .19506 .59919 .18654 .58957 .17338 Mtetra
.653 .741 .914 r
.58957 .17338 .59919 .18654 .61796 .17922 .60844 .16654 Mtetra
.656 .753 .921 r
.60844 .16654 .61796 .17922 .63688 .17241 .62745 .15957 Mtetra
.656 .752 .92 r
.62745 .15957 .63688 .17241 .65592 .16548 .64658 .15251 Mtetra
.661 .753 .918 r
.64658 .15251 .65592 .16548 .6751 .15848 .66583 .14521 Mtetra
.659 .748 .916 r
.66583 .14521 .6751 .15848 .69439 .1512 .68522 .13796 Mtetra
.652 .747 .919 r
.68522 .13796 .69439 .1512 .71382 .14399 .70475 .13092 Mtetra
.66 .755 .921 r
.01925 .36816 .03117 .37841 .04646 .37266 .03459 .36235 Mtetra
.659 .755 .921 r
.03459 .36235 .04646 .37266 .0618 .36714 .05002 .35651 Mtetra
.653 .748 .92 r
.05002 .35651 .0618 .36714 .07723 .36168 .06552 .35086 Mtetra
.65 .745 .919 r
.06552 .35086 .07723 .36168 .09278 .35599 .08109 .34529 Mtetra
.654 .75 .92 r
.08109 .34529 .09278 .35599 .10843 .35023 .09679 .33954 Mtetra
.656 .752 .92 r
.09679 .33954 .10843 .35023 .12419 .34435 .11259 .33367 Mtetra
.657 .754 .921 r
.11259 .33367 .12419 .34435 .14001 .33875 .1285 .32772 Mtetra
.655 .748 .918 r
.1285 .32772 .14001 .33875 .15583 .33395 .1445 .3218 Mtetra
.645 .724 .906 r
.1445 .3218 .15583 .33395 .17168 .32976 .16055 .31621 Mtetra
.624 .693 .894 r
.16055 .31621 .17168 .32976 .18764 .32573 .17663 .31136 Mtetra
.617 .677 .885 r
.17663 .31136 .18764 .32573 .20368 .32196 .19279 .30676 Mtetra
.614 .664 .875 r
.19279 .30676 .20368 .32196 .21989 .31778 .20906 .30219 Mtetra
.611 .658 .871 r
.20906 .30219 .21989 .31778 .23626 .31303 .22543 .2977 Mtetra
.615 .665 .875 r
.22543 .2977 .23626 .31303 .25283 .30742 .24195 .29302 Mtetra
.624 .685 .887 r
.24195 .29302 .25283 .30742 .26955 .30126 .25861 .28797 Mtetra
.633 .709 .901 r
.25861 .28797 .26955 .30126 .28639 .29484 .27543 .28256 Mtetra
.641 .732 .914 r
.27543 .28256 .28639 .29484 .30334 .28832 .29238 .27683 Mtetra
.647 .751 .925 r
.29238 .27683 .30334 .28832 .3204 .28181 .30946 .27084 Mtetra
.652 .764 .932 r
.30946 .27084 .3204 .28181 .33755 .27537 .32666 .26463 Mtetra
.655 .771 .935 r
.32666 .26463 .33755 .27537 .35481 .26907 .34399 .25825 Mtetra
.659 .772 .933 r
.34399 .25825 .35481 .26907 .37217 .26288 .36144 .25168 Mtetra
.663 .768 .928 r
.36144 .25168 .37217 .26288 .38964 .25678 .37901 .24491 Mtetra
.668 .757 .917 r
.37901 .24491 .38964 .25678 .40722 .25068 .39671 .23786 Mtetra
.673 .743 .903 r
.39671 .23786 .40722 .25068 .42493 .24448 .41452 .23049 Mtetra
.677 .725 .886 r
.41452 .23049 .42493 .24448 .44276 .23802 .43246 .22273 Mtetra
.679 .706 .868 r
.43246 .22273 .44276 .23802 .46073 .23099 .4505 .21461 Mtetra
.678 .69 .854 r
.4505 .21461 .46073 .23099 .47882 .22308 .46866 .20626 Mtetra
.675 .684 .851 r
.46866 .20626 .47882 .22308 .49702 .21457 .48691 .19799 Mtetra
.675 .689 .855 r
.48691 .19799 .49702 .21457 .51532 .20564 .50527 .18974 Mtetra
.672 .699 .867 r
.50527 .18974 .51532 .20564 .53371 .19695 .52373 .18174 Mtetra
.659 .706 .882 r
.52373 .18174 .53371 .19695 .55221 .18842 .54231 .17448 Mtetra
.654 .727 .903 r
.54231 .17448 .55221 .18842 .57082 .18049 .56101 .16754 Mtetra
.654 .747 .918 r
.56101 .16754 .57082 .18049 .58957 .17338 .57984 .16064 Mtetra
.655 .753 .922 r
.57984 .16064 .58957 .17338 .60844 .16654 .5988 .15363 Mtetra
.657 .752 .92 r
.5988 .15363 .60844 .16654 .62745 .15957 .61789 .14649 Mtetra
.661 .752 .918 r
.61789 .14649 .62745 .15957 .64658 .15251 .6371 .13916 Mtetra
.658 .747 .916 r
.6371 .13916 .64658 .15251 .66583 .14521 .65645 .13189 Mtetra
.653 .748 .919 r
.65645 .13189 .66583 .14521 .68522 .13796 .67594 .12481 Mtetra
.653 .753 .923 r
.67594 .12481 .68522 .13796 .70475 .13092 .69557 .11769 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
[(-2)] .12586 .2075 1 .99877 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.56863 .04703 m
.57247 .05235 L
s
[(2)] .56094 .0364 .72324 1 Mshowa
.125 Mabswid
.18558 .19702 m
.18832 .19985 L
s
.23703 .17687 m
.23971 .17975 L
s
.28951 .15632 m
.29214 .15925 L
s
.39772 .11395 m
.40023 .11699 L
s
.4535 .09211 m
.45595 .0952 L
s
.51046 .06981 m
.51284 .07294 L
s
.08568 .23614 m
.08851 .23887 L
s
.62804 .02377 m
.63027 .02701 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 233.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00o?ooool2o`0006[ooooo003iooooo`?o000000?oooooo`000?ooool0
JOooool00?Oooooo0_l00004ooooo`;o0000JOooool00?Cooooo0ol00006ooooo`03o`000?oooooo
000006Sooooo003;ooooo`Go00008_ooool2o`0000Wooooo00?o0000ooooool00000J?ooool00<_o
oooo00GoV9RHob4Q8Oo^k^koooooodA4A00Oooooo`?o00002oooool01?l0003oooooooooool0001W
ooooo`00c?ooool00onHV9So8B4Qonk^kP0Mooooo`?o00003_ooool01Ol0003ooooooooooooooooo
000006Kooooo003=ooooo`03oiRHV?lQ8B7ok^k^01[ooooo0_l0000Aooooo`05o`000?oooooooooo
ooooool00000I_ooool00<kooooo00?oMgMgofIVI_ooool05_ooool3o`0001?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1Sooooo`00coooool00ol0003oooooooooo`0Cooooo`;o
00000_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0H_ooool00<_ooooo00Go0000okZj^_ooooooV9RHoa0@400Booooo`?o00006Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo06;ooooo003;ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`04?ooool2o`0001cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Qooooo`00
gOooool3o`0001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Qooooo`00fooo
ool2o`00027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Pooooo`00f?ooool3
o`0002?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Oooooo`00eOooool3o`00
02Kooooo00?o0000ooooooooool01?ooool2o`00067ooooo003Cooooo`;o0000:Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo05kooooo003@ooooo`?o000000?oooooo`000?ooool0
:?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05gooooo003>ooooo`;o00001Ooo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0GOoo
ool00<_ooooo0ol0000`ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0G?ooool0
0<Wooooo0_l0000cooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Foooool00<Ko
oooo0ol0000eooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Foooool00<Cooooo
0_l0000hooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0F_ooool00<7ooooo0ol0
000jooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03_ooool5o`0004Kooooo002n
ooooo`?o0000?Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00kooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A016ooooo`00_?ooool2o`0000?ooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo1_l00003ooooo`03oiRHV?lQ8B7o
k^k^04Oooooo002iooooo`?o0000@oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00kooooo00?oV9RHob4Q8Oo^k^h0A_ooool00;Oooooo0_l00016ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03oooool00omgMgOoIVIVooooo`15ooooo`00]?ooool3o`0004Sooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Cooooo
002booooo`;o0000Boooool00ol0003oooooooooo`0=ooooo`;o00003?ooool01Ol0003o^[Zjoooo
oonHV9So410@04Kooooo002_ooooo`?o0000COooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c016ooooo`00[Oooool2o`00053ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`1Dooooo`00Z_ooool4o`00057ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1Dooooo`00Z?ooool2o`0000Cooooo00?o0000oooo
ooooool0C_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05?ooooo001nooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h08_ooool3o`0005Oooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`1Booooo`00O_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01oooooo0ol0001Joooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool0D_ooool007kooooo00Go410@oooooooo
oooooooooa0@400Mooooo`;o0000GOooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
057ooooo001nooooo`05o`000?ooooooooooooooool000006_ooool3o`0005oooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`1@ooooo`00O_ooool01Ol0003ooooooooooooooooo0000
01Sooooo0_l0001Rooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0D?ooool007ko
oooo00Go410@oooooooooooooooooa0@400Eooooo`?o0000I?ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo04oooooo001nooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool2o`00
00?ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
04kooooo001nooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04?ooool3o`0006Sooooo00?oYl3/o`00
0?ooool05_ooool00ol0003oooooooooo`1>ooooo`00TOooool2o`0006Sooooo1?nW`>`00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo04gooooo002>ooooo`?o0000J?ooool7ojO0k003o`00
0?oooooooooo01Cooooo0ol0001>ooooo`00Roooool3o`0006Wooooo0_nW_n/7ojO0k003o`000?oo
oooooooo01Kooooo00?o0000ooooooooool0C?ooool008Wooooo0_l0001Yooooo`KoYko[1_nW`>`0
0ol0003oYl3/ooooo`0Gooooo`03o`000?oooooooooo04_ooooo0026ooooo`?o0000J?ooool00onX
_n[oYko[ojNoj`07ojNoj`GoYl3/00?o0000ojJojoooool06?ooool00ol0003oooooooooo`1:oooo
o`00Q?ooool2o`0000;ooooo00?o0000ooooooooool0Hoooool5ojRojPWoYko[0_nW`>`2ojJoj`03
o`000?nV_n_oY[o[01Sooooo00?o0000ooooooooool0B_ooool0087ooooo0ol00005ooooo`03o`00
0?oooooooooo063ooooo2?nX_nX7ojNoj`03ojRoj_nV_n_oY[o[00;oY[o[00Co0000ojJojonV_n_o
Y[o[6?ooool00ol0003oooooooooo`19ooooo`00Ooooool2o`0006Wooooo00?oZL3[ojRoj_nX_nX0
1onX_nX4ojNoj`GoZ;oZ0onV_n/00ol0003oY[o[ojJoj`02ojJojaSooooo00?o0000ooooooooool0
B?ooool007cooooo0ol0001Xooooo`GoZL3[2OnX_nX00onW_n_oZ;oZojRojP06ojRojP;oY[o[00Go
0000ojJojonV_n_oY[o[ojRojP0Hooooo`03o`000?oooooooooo04Sooooo001jooooo`;o0000Iooo
ool2ojS0j`SoZL3[1_nX_nX2ojW0j`WoZ;oZ0_nV_n/00ol0003oY[o[ojRojP03ojRojQSooooo00?o
0000ooooooooool0Aoooool007Oooooo0ol0001Vooooo`KoZ<3[2?nY`>/2ojRojPKoZL3[2OnX_nX0
0onV_n_o0000ojRojP05ojRojQSooooo00?o0000ooooooooool0A_ooool007Cooooo0ol0001Voooo
o`03ojO0k?nX`>_oZ<3[00OoZ<3[1_nY`>/2ojO0j`SoZL3[1_nX_nX2ojW0j`03ojRoj_l0003oZ;oZ
00GoZ;oZ6?ooool00ol0003oooooooooo`16ooooo`00L_ooool2o`0000;ooooo00?o0000oooooooo
ool0H_ooool4ojO0k0WoZ<3[0_nY`>/6ojO0j`SoZL3[0_nX_nX6ojW0j`03o`000?nX_n[oZ;oZ00Go
Z;oZ6?ooool00ol0003oooooooooo`15ooooo`00Koooool3o`0006Oooooo1onW`>`7ojS0j`[oYl3[
1_nY`>/00onW`>_oZL3[ojW0j`06ojW0j`03o`000?nX_n[oZ;oZ00CoZ;oZ00?oZL3[ooooooooool0
5_ooool00ol0003oooooooooo`15ooooo`00KOooool2o`0006Oooooo0_nW_n/8ojO0k0CoZ<3[3_nW
`>/2ojW0j`GoYl3[1onY`>/01?l0003oZL3[ojRoj_nX_nX5ojW0jaOooooo0_l00016ooooo`00J_oo
ool3o`0006Kooooo1_nW_n/8ojO0k003ojS0jonW`>_oYl3[01KoYl3[1_nY`>/00ol0003oYl3[ojW0
j`07ojW0jaSooooo00?o0000ooooooooool0@oooool006Sooooo0_l0001Vooooo`03ojNjionW_n_o
Yko[00OoYko[1_nW`>`2ojNmjAWoYl3[0_nY`>/3ojO0j`03o`000?nW`>_oYl3[00SoZL3[5oooool0
0ol0003oooooooooo`13ooooo`00IOooool3o`0006Kooooo1?nW^^L9ojNoj`;oYl3/1_nW_NTMojO0
j`04o`000?nW`>_oYl3[ojO0j`KoZL3[00?oZ<3[ooooooooool05_ooool00ol0003oooooooooo`12
ooooo`00Hoooool2o`0006Oooooo1onW^^L7ojNoj`03ojRgi?nW_NWoYkgY00OoYkgY1_nW`>/00onW
_>SoYl3[ojO0j`0DojO0j`04o`000?nW`>_oYl3[ojO0j`;oZL3[1OnX`>/Hooooo`03o`000?oooooo
oooo047ooooo001Pooooo`?o000000?oooooo`000?ooool0I?ooool00onX]>7oYk[WojNji`07ojNj
i`CoYko[1?nX]n@9ojNmj@;oYl3[1OnW_>PEojO0j`04o`000?nW`>_oYl3[ojO0j`SoZ<3[5oooool0
0ol0003oooooooooo`11ooooo`00=_ooool5o`0002?ooooo0_l0001Wooooo`GoZ;CQ2OnW^^L00onW
_n_oZ;OTojRgi005ojRgi0OoYkgY00?oZKKRojNlj?nW_>P01_nW_>P6ojO0j`;oYk_X3?nW`>/00ol0
003oYl3[ojO0j`02ojO0j`SoZ<3[5oooool00ol0003oooooooooo`10ooooo`00=_ooool01OnHV9So
8B4Qonk^k_ooooooA4A4023ooooo0ol0001Vooooo`03ojbbgOnX]>7oZ;CQ00KoZ;CQ1_nW^^L2ojbd
gPSoZ;OT1?nW_NT5ojVfhPSoYkcX0_nW`>/6ojNkj0_oYl3[00?o0000ojO0jonW`>/00onW`>/6ojS0
j`03ojO0k?oooooooooo01Kooooo00?o0000ooooooooool0?oooool002kooooo1_l00003ooooo`03
oiRHV?lQ8B7ok^k^01kooooo0ol0001Vooooo`Go[;;M2?nX]>42ojNji`Ko[;CN2?nX]n@00onW_NWo
ZKKRojVfhP06ojVfhPKoYkcX00?oZkKQojNkj?nW^nP01onW^nP6ojO0j`05ojNlj?nW`>_oYl3[ojO0
jol000001OnW`>/4ojS0j`CoYl3/5oooool00ol0003oooooooooo`0oooooo`00>?ooool00onHV9So
8B4Qonk^kP0Kooooo`;o0000Ioooool8ojbbg@KoZ;CQ00?o[[7Kojbdg_n/]=h01on/]=h6ojRgi003
ojjdgOnY]^;oZKKR00OoZKKR1?nW_>P4oj^fh@WoYk_X0_nW`>/5ojNlj0;oYl3[00?o0000ojO0jonW
`>/01?nW`>/00onX`>_oYl3/ojO0k005ojO0k1Oooooo00?o0000ooooooooool0?_ooool003Wooooo
00?oMgMgofIVI_ooool05oooool3o`0006Oooooo00?o[;3JojbbgOn//]d01on//]d4ojRdh@Co[[7K
2?n/]=h4ojRgi0Co[[CM2OnY]^800onW_>SoZkKQoj^fh@05oj^fh@OoYk_X00?oZkOQojNlj?nW_>P0
1_nW_>P00onW`>_o0000ojO0j`03ojO0j`;oYkgY2?nW`>`Hooooo`03o`000?oooooooooo03gooooo
000jooooo`03o`000?oooooooooo01Cooooo0_l0001Wooooo`Go[;3J2On//]d00onX]>7o[[7Kojja
f`05ojjaf`So[;CN00?oZ;OTojjdgOn^]=d01On^]=d7ojVfhP03ok2dg?n[]^7oZkKQ00KoZkKQ1?nW
^nP5oj^gh@SoYkcX00?o0000ojO0jonW_NT01OnW_NT8ojO0k1Oooooo00?o0000ooooooooool0?Ooo
ool003Kooooo00Go0000okZj^_ooooooV9RHoa0@400Cooooo`?o00000_ooool00ol0003ooooooooo
o`1Qooooo`03ojb_fOn//=[o[;3J00Ko[;3J1on//]d00on^/=Wo[[7Kojjaf`06ojjaf`Oo[;CN00?o
/;;JojjdgOn^]=d01on^]=d4ojVfhPCo/;CL2?n[]^400onW^nSoZkOQoj^gh@06oj^gh@KoYkcX00?o
ZkSRo`000?nW_NT01onW_NT6ojO0k003ojNnjooooooooooo01Kooooo00?o0000ooooooooool0??oo
ool003Kooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Aooooo`;o0000Ioooool4ojb_f@So[;3J1?n/
/]d4ojj`f@So[[7K1?n/]=h4ok2bfPWo[[CM00?oZKKRok2dg?n`]=`01On`]=`6oj^fh@03ok6eg?n[
]n7oZkOQ00OoZkOQ1?nW_>P3oj^hhP03o`000?nW_NWoYkgY00OoYkgY0_nW`>`5ojNnjaKooooo0ol0
000mooooo`00BOooool3o`0006Oooooo1on/[mT8ojb`fP03ojbbgOn^/=Wo[[3I00Co[[3I2On^/M/0
0on/]=ko/;;Jok2bfP05ok2bfPOo[[CM00?o/[?Jok2dg?n`]=`01_n`]=`4oj^fh@Co/KGL2On[]n40
0onW_>SoZkSRoj^hhP03oj^hhP03o`000?n[^>;oYkgY00GoYkgY0_nY^N@8ojNnjaOooooo00?o0000
ooooooooool0>oooool004Oooooo0_l0001Xooooo`03ojf`f_n/[mWo[:oI00Ko[:oI1on//=X00on`
]=_o[[3Iojj`f@06ojj`f@Oo[[7K00?o/[CJok2bf_n`/]X01_n`/]X4ojjdg@Go/[?J2?n`]=`00on[
]^7o/KGLok6eg005ok6eg0OoZkOQ00?o/[OLoj^hh_n[^>801?n[^>800ol0003oZkSRoj^hhP02ojNm
j@KoZKWT2?nW_^/Gooooo`03o`000?oooooooooo03[ooooo0014ooooo`?o0000J?ooool4ojf`fPSo
[:oI1?n//=X4ok2df`Oo[[3I1?n^/M/5ok:dfPSo/;;J00?o[[CMok:cf_nb/mX01_nb/mX6ok2dg003
okBff_na]Mco/KGL00Oo/KGL1?n[]n44ok:gg0GoZkSR00?o0000oj^hh_nb^=h02OnY^N@6ojNnj`03
ojRkiooooooooooo01Kooooo00?o0000ooooooooool0>Oooool0047ooooo0ol0001Yooooo`Ko[K3J
2On/[mT00on//=[o/;CKok2df`04ok2df`So[[3I00?o[[7Kok:df_nb]=X01_nb]=X6ok2bfP03okBj
gOnb/m[o/[?J00Oo/[?J1?n`]=`4okBffPWo/KGL00?oZkOQok:gg?nb]m`01Onb]m`4oj^hhP04o`00
0?nb^=ko/[SNok:hgPWoZKWT0_nW_^/5ojRkiaOooooo00?o0000ooooooooool0>Oooool003oooooo
0ol0001Yooooo`03ojfdg_n]/=[o[K3J00Ko[K3J1on/[mT00on`^n;o/;CKok2df`06ok2df`Ko[[3I
00?o/kgRok:df_nb]=X01onb]=X4ok2bfPCo];[M2Onb/mX00on`]=co];KJokBffP05okBffPOo/KGL
00?o]KOJok:gg?nb]m`01onb]m`01?n[^>;o/[SNok:hg_l00004ok:hgPOoZKWT00?o/KWPojRkionX
^nL01_nX^nLGooooo`03o`000?oooooooooo03Sooooo000looooo`?o00000oooool00ol0003ooooo
ooooo`1Tooooo`Co[KCN1on]/=X4ojb_f@Go/;_R1on`]=/4ojj`f@Co/kgR2Onb]=X00on`/][o];[M
okBjg@05okBjg@Oo/[?J00?o][kPokBff_nd]]X01_nd]]X4ok6eg0Go]KOJ1onb]m`01Onf^=_o/[SN
ok:hg_nb^=ko000000Co/[SN1?nY^N@5ok6ih0SoZ;_W5_ooool00ol0003oooooooooo`07ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h0;?ooool003[ooooo0_l0001[ooooo`Ko[KCN2?n]/=X00on/[mWo
/;_Rok2khP06ok2khPOo/;CK00?o[[3Iok>mh_nc_N801Onc_N87ok:dfP03ok?5j?nd^]go];[M00Oo
];[M1?nb/mX4okJnh0So];KJ00?o/KGLokFgf_ne]mX01_ne]mX5ok:gg0?o][SK0_nb^=h00ol0003o
/[SNok:hgP03ok:hgP03ojVii?na^N3o/KWP00Ko/KWP1_nX^nL00on^^^?oooooooooo`0Eooooo`03
o`000?oooooooooo00Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0/ooooo`00=oooool3o`0006_o
oooo00?o[KWRojfdg_n]]=h01_n]]=h6ojf`fP03ojo4jOn`^n;o/;_R00Oo/;_R1_n`]=/2ok37j`So
/kgR1?nb]=X4ok?5j0Wo];[M00?o/[?JokJnh?nf_^001Onf_^06okBffP03okO1hOne]m[o]KOJ00Oo
]KOJ0onb]m`6okJhf`;o/[SN00Go0000ok:hg_nb^=ko/[SNokJhf`09ok6ih0CoZ;_W1?n^^^<Goooo
o`03o`000?oooooooooo00Gooooo00Go410@oooooooooooooooooa0@400/ooooo`00=Oooool2o`00
06cooooo1?n]^N87ojfdgPCo[K3J1?n_a>T9ok2khP;o/;CK1_n`an/8ok>mhP03ok:df_ncaNSo/lGX
00Go/lGX1ond^]d00onabNco][kPokJnh006okJnh0Co];KJ1?ng`N49okFgfP03ok:gg?nf^=_o][SK
00Go][SK0_nb^=h00ol0003o/[SNokJhf`03okJhf`Wo/KWP00?oZ;_Wojjjhon^^^<01On^^^<Foooo
o`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`00000/ooooo`00<_ooool3o`00
06cooooo1on]^N87ojfdgP03ojf`f_n_a>Wo[lCY00Go[lCY1on`^n800onWc_Go/<O[ok37j`07ok37
j`Ko/kgR00?oZ<gcok?5j?ncaNP01_ncaNP4okBjg@Go/LW/2?nf_^000ond]][o]l7QokO1h@05okO1
h@Oo]KOJ00?o^<7QokJhfonf^=/01onf^=/00onb^=ko0000okJhf`05okJhf`Oo/KWP00?o]KWMojjj
hon^^^<01on^^^<Fooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000/
ooooo`00<?ooool2o`0006gooooo00?o[;kWojfih_n]^N801_n]^N86ojfdgP;oZ/[`2?n_a>T4ok2k
hPCoYlke2On`an/2ok>mhPGoZ<gc2?ncaNP00ond^]go/LW/ok79k006ok79k0Ko][kP00?o[/_^okO1
hOng`N401_ng`N44okFgfPGo^<7Q1onf^=/00oni_mko][SKo`000006okJhf`Co/KWP1One^Md7ojjj
h`03okBlgooooooooooo01Gooooo00?o0000ooooooooool00oooool01Ol@413ooooooooooooooooo
410@02cooooo000]ooooo`?o000000?oooooo`000?ooool0JOooool5ojbni`So[KWR0_n]]=h6oj[:
l0So[lCY00?o/;_RojO>mOnWc_D01OnWc_D6ok37j`;oVmOm2?nXcO<6ok?5j003oj7BnOnabNco/LW/
00Oo/LW/1?nf_^04ojk;kPSo]l7Q00?o]KOJokS1hOnh`N401_nh`N45okJhf`?o^KoN00?o0000okJh
fonf^=/01Onf^=/00ona^N3o]KWMokFig@05okFig@Co[[[S1Ond_=lFooooo`;o00001?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg02cooooo000Zooooo`?o0000Joooool2oj_1jPSo[;kW1_n]^N82ojK@
mPSoZ/[`1_n_a>T2oikGo0SoYlke0_n`an/6oi_Go@SoZ<gc0_ncaNP5oj7Bn@Wo/LW/00?o][kPojk;
k_n^bnh01On^bnh6okO1h@03ojk;k_nh`N7o^<7Q00Oo^<7Q0onf^=/5okVogP03o`000?nf^=_o][SK
00Co][SK00?o^[gLokFigOne^Md01one^Md00on^^^?o];cOokBlg`06okBlga?ooooo0_l000000ooo
oooo0000ooooo`03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0;?ooool002Sooooo0_l0001[oooo
o`KoZl7Z2?n/_^L2ojfihPKoY]3f2?nZb_02ojo4j@KoW]Ol1_nWc_D3oh[Jo`OoVmOm1_nXcO<2ohcH
o`OoXM;i1_nabN`2oi[Co0So[/_^1?ng`N44ojk;kPWo^<7Q00?o][SKokVog_ni_mh01?ni_mh00ol0
003o][SKokJhf`03okJhf`?o^[gL1one^Md00oni_=co];cOokBlg`07okBlgaOooooo00?o0000oooo
ooooool0<_ooool002Gooooo0ol0001Zooooo`;oZLC]2?n[`NX6ojbni`?oX]Kj1onVd?H6oj[:l0?o
U=cn1onNeo`2ojO>m@OoR][o1onKeod2ojS=l`KoS=So1onQd_T2ok79k0KoV]?l2?n^bnh00ong`N7o
[/_^ojk;kP05ojk;kPOo^<7Q00?o/<W/okVog_ni_mh01?ni_mh2o`0000?o][SK1_nj_M`5okFig@?o
^KcL2Ond_=lFooooo`03o`000?oooooooooo03;ooooo000Sooooo`;o0000Joooool5ojW4k@SoZl7Z
0_n/_^L7oj;FnPOoY]3f0_nZb_07oiCLoP?oW]Ol1Omme_h8oh[Jo`?oVmOm1Omfd?l7ohcHo`?oXM;i
1OmmdOl7oi[Co0Ko[/_^0_nGd_`7ojk;kPCo^<7Q1On`bN`2okVogP?o000000Co^KoNo`000?ni_mko
][SK1onj_M`3okFig@Ko^KcL1ond_=l00ong_=goooooooooo`0Eooooo`03o`000?oooooooooo037o
oooo000Pooooo`?o0000K?ooool7ojW4k@KoZl7Z0onOf_`8oj;FnP?oY]3f1On;gOh6oiCLoP?oP]Go
2?mme_h3oh[Jo`GoNlko1omfd?l3ohcHo`GoL/Wo2?mmdOl6oi[Co0;o[/_^1_nGd_`7ojk;kP03okS1
hOn`bNco/<W/00Co/<W/0ol00005okVogP03o`000?nj_Mco^[gL00Oo^[gL00?o]KWMokVlg?ni_=`0
1Oni_=`4okBlg`Go]kcM5oooool00ol0003oooooooooo`0`ooooo`007oooool2o`0006cooooo00?o
Z<G^ojW4kOnYa>d01onYa>d2oj_1jPOoWm[l1_nRe_X3ohWMoPOoRmgn0_nDg?h8oh;Eo`?oOMKn1On8
c?h7og_>o`?oM]3o1Omoaoh7og;9o`CoOM7o1Oma`oh6ogG<o`OoUm;l0on^bnh4oiO@o0?o/<W/0ol0
0002ok39k0Co^KoN0oneb>P00ol0003o^[gLokZmg005okZmg003ok[6honi_=co^KcL00Oo^KcL00?o
];cOokNlgOng_=d01Ong_=dGooooo`03o`000?oooooooooo033ooooo000Oooooo`03o`000?oooooo
000006Sooooo1OnXaNh7ojW4k@?oW]gm2?nOf_`2oj;FnPOoRMgn0on;gOh6oh_Do`CoP]Go1OnEboX7
ohS<oP?oNlko1OnAaOT7ogo7oP?oL/Wo1On4`o`8og73oPKoMLco0onGd_`4og?8o`KoUm3l0ol00006
ok39k003okVog_neb>So]LSX00Co]LSX00?o0000okZmg?nj_M`00_nj_M`4ok[6h`Oo^KcL00?o^l7N
okNlgOng_=d01ong_=dGooooo`03o`000?oooooooooo02oooooo000<ooooo`Go00000oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Kooooo00Co0000oooooooooooo0000I?ooool00onWaNooZ<G^ojS5
kP06ojS5kPCoZLC]1_nNgOd6oioJo0?oSMkn1_n9gOh3oi?Co@OoRmCo0_nMaO@8oiG;nP?oR<cn1?nL
__08oi75n@?oOlOn1?nF__<9ohC3o0?oLL?n1?n7`?X7ofnooPKoLlSo0_nGd?`3o`0000;oUm3l1?n`
bN`4oic>n@Ko]LSX00?o0000okG8j?nj_M`01onja^<5okVlg0?o^l7N1ong_=d00onj_mgooooooooo
o`0Fooooo`03o`000?oooooooooo02kooooo000<ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo0_l00002ooooo`03o`000?oooooooooo05kooooo
1OnWaNl8ojS5kP03ojW4kOnNgOgoW]gm00OoW]gm0_nOf_`7ohgNoP;oRMgn2?nCdod2oh_Do`KoWLGd
1_nEboX00onR^NWoW;k`oibnl006oibnl0KoTLGi00?oXKSYoiJnlonF__<01_nF__<6ohC3o0?oVKW_
1on7`?X7ofnooPCoLlSo0ol00002oiO@o0CoM/Oo2?nLc_T6okG8j003o`000?nja^?o^/KS00Ko^/KS
0oni_=`6ok_1gPGo]kcM0onj_mdGooooo`03o`000?oooooooooo02kooooo0004ooooo`Ko00000ooo
ool00onHV9So8B4Qonk^kP04ooooo`05oa0@4?ooooooooooooooool@41001Oooool2o`0000Cooooo
00?o0000ooooooooool0F_ooool00onV`nkoYlG_ojO5k`06ojO5k`KoZ<G^0onNg_d7oikMo@CoTmon
0on=g_h5oi_Cn`OoTm?m0_nR`>l8oig5m0;oUL_j1OnR^NT8oibnl0;oTLGi1OnQ^>T8oiJnl`;oQ<?l
1onI^Nl7ohO0nP?oKkon1?n5__T3o`0000CoK;_m1_mfaol8oic>n@;o]LSX1?nUb_<00ol0003o^/KS
ok[6h`06ok[6h`03okVlg?nk`Mko^l7N00Go^l7N0ong_=d6okZogAOooooo00?o0000ooooooooool0
;Oooool000kooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003ooooooooooooooooo000000Gooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Fooooo`GoY/?^2?nWaNl2ojS5kPSoW]km
0_nNgOd6oi?OoP?oX=;i2?nKdo/2oi?Co@KoX/3_1_nMaO@00onW^>GoX[WYoj:ij@06oj:ij@KoW;k`
00?oZKSToj6hjOnQ^>T01_nQ^>T6oiJnl`;oY[SV2OnI^Nl3ohO0nPCoVKS]1?n5__T2o`000003ohFn
nOm/^ogoK;_m00GoK;_m1_mfaol4oic>n@?oPLSn1_nUb_<00ol0003oYL[cok[6h`05ok[6h`03ok38
k?nk`Mko^l7N00Oo^l7N00?o]kcMokZogOnj_md01Onj_mdHooooo`03o`000?oooooooooo02cooooo
000?ooooo`03ogMgMomVIVKooooo00;ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0D_ooool2ojG0k0OoY/?^1_nWaNl3oj3Oo0OoW]km
1?nHhOd2oi?OoPOoX=;i1_nKdo/00onT_>_oX/3_oj;0k`07oj;0k`;oWLGd1OnW^>D8oj:ij@;oW;k`
1OnY^>@8oj6hj@;oU[kc1_nV^>H7oiVik`03ojViiOnI^>goVKS]00KoVKS]0ol00004ohFnn@?oK;_m
1?mo^oX6ofVio@OoPLSn1_nUb_<01?l0003oYL[cok[6honja^<5ok38k0Oo^l7N00?o^/OTokZogOnj
_md01onj_mdFooooo`;o0000;_ooool0013ooooo00Go0000oooooooooooooooooa0@4003ooooo`03
oa0@4?oooooooooo00?ooooo0_l00007ooooo`03o`000?oooooooooo04kooooo1_nU`>`7ojK3kP;o
YlG_2?nPgo`2oikNo@KoV>7m0onSdOP8oj3Bn@;oVm?k1OnT_>/7oj;0k`03ojRghonW^>GoYkSU00Ko
YkSU1_nR^NT00on[^>?oZKSTojVhi006ojVhi0KoXKSY0_n/^N<8ojJhiPCoVKW_1?nY^ND4oiVhk@?o
000000CoVKS]ohFnnOn5__WoQKki1?nG]nh7ognknPKoJKWm1on1b?h6ojG:l`03o`000?n`b>co/<S/
00Ko/<S/1?nk`Mh4ok[7i0Oo^[oM00?o_<;Nooooooooool05_ooool00ol0003oooooooooo`0[oooo
o`003?ooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0B_ooool2ojBkj@SoYL3/1OnV`nh3
oj;No0OoX=ol1?nMh_d2oiSQo@OoXm7h1_nPd_T00onV^nSoY;c[ojBlj`06ojBlj`CoX/3_1?nX]n<7
ojNhi@CoX[WY1?n[^><8ojVhi0;oXKSY1_n/^N<8ojJhiP03oiVikonY^NGoZKWU00GoZKWU0ol00003
oiVhk@03ojVjiOnG]nkoUkO^00KoUkO^1omo^oX6ofVio@OoPLSn0_nUb_<4oi7;n`03o`000?n`b>co
/<S/00Ko/<S/00?o^l7Nok[7i?njan@01Onjan@4okZog@Co_<;N5oooool00ol0003oooooooooo`0[
ooooo`003?ooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0A_ooool6ojBkj@SoYL3/00?o
Y/?^oj;No?nRg_`01_nRg_`2oj3Oo0OoWN;m0_nVd_L8oj?An0;oX=;i1OnV^nP8ojBlj`03oj;0konX
]n?oZ;OS00GoZ;OS1onW^>D00onR^NWoZkSSoj^hh`05oj^hh`KoZKST00?o[K[Sojbihon/^N<01on/
^N<6ojJhiP03ojjkhonY^NGoZKWU00?oZKWU0ol000000onY^NGoVKS]oiVhk@05ojVji@SoUkO^0omo
^oX4oi:gl@OoM[Oj1_mX^Od5oi7;n`03o`000?nAbo_o/<S/00Go/<S/00?oXLOdok[7i?njan@01onj
an@00onj_mgo_<;Nokc2gP05okc2gQOooooo00?o0000ooooooooool0:_ooool001kooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`12ooooo`;oX[GV2?nT^nT6ojG0k0?oYMck1_nRg_`4
oj7To0?oWN;m1_nVd_L6oj?An003ojNjionV^nSoY[_X00KoY[_X1_nT_>/00onY]n?oZ;OSojRgh`06
ojRgh`KoYkSU2On[^><4ojVhi0Co[K[S2On/^N<2ojJhiPGo[[_S00CoZKWUo`000?l0003o00000onY
^ND00on^^n?oZK[UojVji@06ojVji@KoUkO^00?oZ;[Voi:glOnB]o401_nB]o47ogJgnPKoJ;Wm1OnA
bo/01?l0003oTL_kok38k?n`b>`5oj77m0Oo^/OT00?o/LO[okc2g_nl`]h01onl`]hGooooo`03o`00
0?oooooooooo02Wooooo000Mooooo`?o00002oooool00ol0003oooooooooo`0nooooo`KoX[GV2?nT
^nT2ojG0k0OoYMck0_nRg_`7oj7To0;oZ=Cg2?nVd_L2oj?An0GoYk[W2?nV^nP2ojBlj`GoZKOS2?nX
]n<2ojNhi@goZkSS00?oZKSTojfjhon]^^<01On]^^<7ojbih`03ojfki?n^^n?o[[_S00?o[[_S0ol0
0004ojVii@Co[[_S2?nY^^D2oiNgkPGoZ;[V2?nB]o43ogJgnPCoR;Se1_m[/oX5ogNoo@03o`000?nQ
aoCoXLOd00KoXLOd1?njan@4ok77j`Oo_<;N00?o_<KRooooooooool05Oooool00ol0003ooooooooo
o`0Yooooo`007Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03_ooooo00?oWjoS
oj:ei_nR]NH01_nR]NH6ojBkj@?oYmOh1_nUg?/3ojCVn`GoXNCl1OnXe?L6ojKBm`WoYk[W1_nV^nP2
ojRgh`OoZKOS1_nX]n<2ojZhi0goZkSS0_n/^nD8ojfjh`Co[;WS1?n]^n@01?n^^n?o0000o`000?l0
0004ojjkh`03ojViiOn^^n?o[[_S00Go[[_S1_nY^^D00on__>?oZ;[VojRjiP06ojRjiPKoT[Oa00?o
X[WYohRhmOn8^?D01_n8^?D6of^cnPGoMkom00?o0000oj77m?nQao@01_nQao@00onjanCo/LO[ok77
j`05ok77j`Go_<;N0onla^8Gooooo`03o`000?oooooooooo02Sooooo000Mooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool0=oooool5oin_h`SoX[GV0_nT^nT8ojOGn003ojGLnonTi__o
Y>Kk00KoY>Kk00?oXNClojSDmonXe?L01_nXe?L2ojKBm`goYk[W0_nV^nP6ojRgh`OoZKOS0_nX]n<6
ojZhi0WoZkSS1_n/^nD8ojfjh`03ojbihon]^nCo[K_T00;o[K_T0ol00006ojjkh`03ojjmiOn^^n?o
[[_S00Ko[[_S1?nY^^D4ojnlh`SoZ;[V0_nB]o45oj:ij@SoR;Se1_m[/oX4ogNoo@03o`000?mg_ogo
XLOd00?oXLOd0on@a_X8ok77j`?o_<;N1_nla^8Gooooo`03o`000?oooooooooo02Oooooo000Moooo
o`;o00003oooool00ol0003oooooooooo`0aooooo`?oWJ[O2?nO[n<6oj:eiP?oZ=7e1onWeoP3ojOW
n`KoY>Kk0onZeoL6ojSDm`;oYk_W3OnW^^L2ojRfh`SoZ;OS1OnY]n<2ojVji@SoZ[ST1_n[^><00on[
_NOo[;_Uojbki@06ojbki@Ko[K[S00Co[KkWojfki?n]^nCo[K_T0_l00003ojfki0Co[[_S1?n^_ND8
ojjkh`03ojVjiOn__>?o[kcS00Go[kcS1_nX^^H00on__NCoX[WYoj:ij@06oj:ij@KoR;Se00?oUkO^
ogVdn?mi]?P01Omi]?P4ofRcn`03o`000?mX/o_oT<Kj00KoT<Kj2?naan/00onl`]ko_<KRokc6hP05
okc6hQOooooo00?o0000ooooooooool09oooool001gooooo00?o0000ooooooooool03oooool2o`00
02gooooo00?oW:SNoifZgonMZ]l01OnMZ]l7oin_h`CoX[GV1_nXdOD4ojOGn0KoYnOk0_nTi_/8oj[G
m`03ojSDmonW^nOoYk_W00CoYk_W2OnW^^L6ojRfh`SoZ;OS00?oZKOSojVjiOnY^^D01?nY^^D8ojZh
i0;oZkSS1On[_NL8ojbki@;o[K[S1?n]_^L3o`0000Ko[K_T00?o[[_SojjmiOn^_ND01On^_ND6ojjk
h`03ojnniOn__>?o[kcS00Oo[kcS0_nX^^H5ojnmi0SoX[WY0_n8^?D5oiNgkPOoNKCh1?mX/o/00ol0
003oJ;?koi36nP06oi36nPKo/LO[00?oY/G`okc6h_nla^801onla^8Gooooo`03o`000?oooooooooo
02Kooooo000Mooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool09oooool5oibXgPOo
WJ[O1onO[n<00onR]NKoZ=7eojSAm@07ojSAm@03ojOGn?nWio_oYnOk00GoYnOk0on/foP7oj[Gm`03
ojVnjOnW^nOoYk_W00KoYk_W1_nW^^L00onW]^CoZ;KSojRfh`06ojRfh`KoZ;OS00?oZK[VojVjiOnY
^^D01_nY^^D6ojZhi003ojZojOn[_NOoZkgW00KoZkgW1_n/^nD01?nZ`>Wo[KkWojfnion]_^L3o`00
00;o[KkW1_n]^n@00on]`>So[[gUojjmi@07ojjmi@;o[[_S1On__^D7ojnlh`03ok2niOn__NCo[kgT
00Ko[kgT1_nR^NT2ojfmi@OoUkO^1omi]?P4ofRcn`03o`000?mX/o_oT<Kj00KoT<Kj0_naan/5ojK5
l0Oo_<KR00?o^<OVooooooooool05_ooool00ol0003oooooooooo`0Uooooo`007Oooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo02;ooooo0onMZMl7oibXgPOoWJ[O1OnO[n<3ojO9l@Oo
Z=7e1?n[ioX2ojOWn`So[=_h0_nZeoL5ojVnj@SoYk_W0_nW^^L5ojNfi0SoZ;KS0_nX]n<5ojVjiPSo
ZK[U0_nZ^>@5ojZoj@SoZkgW0_n/^nD4oj[0j@?o00001_n]_^L2ojfki0Go[L3X1on^_ND00on]`NSo
[kkUojnni@06ojnni@Co[kcS1?n`_^D8ojnmi0;oX[WY1_n]_ND7oiNgkP?oNKCh1?n7]_@3ofZ^n003
o`000?mZ[_SoJZkh00KoOKck2?nVaO04okc6hPCo^<OV5oooool2o`0002Kooooo000Looooo`?o0000
5?ooool00ol0003oooooooooo`0Mooooo`03oif]h_nMZMooWJWO00GoWJWO1_nLZ=h8oifZg`03oin_
honWbO7oYlWa00KoYlWa0_nXdOD7oj_WnP?o/>3g1_n/foP2oj_3j`OoZKkY1_nW^nL00onV]^CoYkKT
ojNfi006ojNfi0KoZ;KS00?oZ;_WojVji_nY^^H01_nY^^H6ojVji@03ojRoj_nZ_nWoZ[oY00KoZ[oY
1_n[_NL01?nX_n[oZ/3Yoj[0jOnZ`>T3o`0000;oZ/3Y1_n]_^L00onY_n[o[L3Xojg0j006ojg0j0Co
[[gU1?n]`NP8ojnni@03ojnlhon`_^Go/;kU00Go/;kU1_n__N@00on`_^Co[KgUojfmi@07ojfmi@?o
UkO^0onT^nT8ohNfm0?oJZkh00?o0000ofZ^n?mZ[_P01_mm_?/8ojK5l003okc6h_nhanKo^<OV00Co
^<OV5_ooool00ol0003oooooo`00000Vooooo`007?ooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo01Wooooo1OnM[N87oifYg`KoW:SN1_nMZ]l2ojC0k@OoYlWa0on/hoX5oj_WnPKo/>3g
0_n/foP6oj_3j`OoZKkY0_nW^nL5ojJfi0OoYkKT1?nX]^<4ojRki`OoZK[V1?nY^^D4ojRojPSoZ[oY
0_n[_NL4ojRojP?o00001_nZ`>T2ojfni`GoZKoZ2?n]`>P00on^_NGo[L7Xojg1j005ojg1j0Ko[kkU
00?o[L7Xok2niOn`_^D01_n`_^D4ojnmi0Co/;kT1on]_ND00on`_nGoY;_YojBkj@05ojBkj@SoQkKd
0omZ[_P00ol0003oJZkhofZ^n006ogfln`CoY/G`0onK`o@8okS7iQSooooo00?o0000ooooooooool0
8oooool000[ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^1_ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo01Kooooo00?oWk7Toif]h_nM[N801OnM[N86oifY
g`OoW:SN0_nMZ]l6ojC0k@CoYlWa1on/hoX00on[io[o/>3gok3Pm`05ok3Pm`;o[L[_2?n[`n/5ojVn
j@03ojFfi?nV]^CoY[KT00KoY[KT1onW]^@00onX]^?oZ;_WojRki`05ojRki`OoZK[V00?oZK[UojRo
j_nX_nX01OnX_nX6ojZoj@CoZ;oZ0ol00002ojRojPKoZ/3Y00?oZ;kZojVoj_nY_nX01_nY_nX6ojg0
j0;oZ;oZ2?n]`NP2ojnni@Go[L7X2?n`_^D00on__NCo/;kTok2ni005ok2ni0Co[KgU1?n`_nD7ojBk
j@CoQkKd0onC]^l3og>_m`04o`000?mc[oOoLjogog>_m`KoKk;i1onK`o@6okS7iP03ok;6jOoooooo
oooo01Kooooo00?o0000ooooooooool08oooool000cooooo00?o0000ooooooooool00_ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0B
ooooo`GoWk7T1_nM[N87oifYg`?oW:SN1OnN]NP7ojC0k@03ojO9lOn/ho[o[>?j00Ko[>?j0onciOL4
ok3Pm`Go[L[_2?n[`n/00onY_^WoYKKTojFfi003ojFfi0OoY[KT1_nW]^@00onW^^OoZ;_WojRki`06
ojRki`KoZK[V2_nX_nX2ojZoj@CoZ;oZ0ol00006ojRojP;oZ/3Y1OnX_^X8ojVojP;o[L3X1_nX_nX6
ojg1j003ojRoj_n]`NSo[L7X00Ko[L7X1_n`_^D00on_`NOo/;kTok2ni007ok2ni003ojfmiOn`_nGo
/;oU00Co/;oU1_nT^nT00on]_^KoTkK_oi>fk`06oi>fk`?oLjog00Co0000og>_momc[oOoLjog1_m_
/_T7oi_3m0;o^<OV1Onba^THooooo`03o`000?oooooooooo02;ooooo00000ooooooo0000o`000004
o`0000Gooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Kooooo0_l0
000Iooooo`03o`000?oooooooooo00kooooo0_nU^NL7oinai0KoWJgR1OnMZMl00onK[>;oW[GXoije
j007oijej0GoY<3]0on/foP5ojcSnPOo/nGg00?o/>3gojg:kon]b^l01On]b^l6oj_3j`03ojFfiOnU
]^CoYKKT00GoYKKT1onV]^@2ojNfi0GoYk[W2?nX^nL2ojVjiPcoZ;oZ00?oYkkZojRoj_nX_nX00_nX
_nX2o`0000SoZ;oZ00?oZ;kYojRnj_nX_^X01_nX_^X6ojVojP;oZ;kZ2?nX_nX2ojg1j0GoZ;oZ2?n]
`NP2ok2ni@Go[l7W1on`_^@00on``NKo/;oUok2oi@06ok2oi@;oY;_Y1On]_^H8oi>fk`?oLjog00Co
0000og>_momc[oOoLjog1_m_/_T3oi_3m0?oT;kf2?nba^THooooo`03o`000?oooooooooo027ooooo
000<ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool02_ooool6ojFii`KoWk7T1onM[N800onMZMooVjcR
oi^/hP03oi^/hPWoW[GX00?oY<3]ojcKn?n/foP01_n/foP00on/ho[o/nGgok?Um`06ok?Um`;o/=?b
2?n]b^l2oj_3j`GoYKKU1onU]^@5ojJfi0;oY[WW1onW^^L6ojRki`coZ;oZ1OnW_^X3o`0000OoZ;oZ
1OnX_^T8ojRnjP;oZKoZ1_nX_^X?ojRojPKo[L7X00?oZL3Zojo1ion_`NL01_n_`NL4ok2ni0Co/<7V
1_n`_nD00ona`>Go[KkVojfniP06ojfniPKoTkK_00?oWK[]ogfamOmm/OD00_mm/OD00ol0003oOK7e
ogfam@06ofZ/m`OoT;kf2?nba^TGooooo`03o`000?oooooooooo027ooooo000<ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool01oooool2ojNoj`OoYKWW1_nO/N@3oif]hP?oV:OP1onK[>87oijej0?oZloc
1_n/foP4okCXm`?o/nGg1_n`do86ojg:k`03ojFgi_nU]^GoYKKU00KoYKKU1onU]^@00onV]^CoY[WW
ojJii`04ojJii`OoYk[W0_nX^nL<ojRojP;oZ;kY0onW_^X3o`000003ojNnj_nX_n[oZ;oZ00CoZ;oZ
2OnX_^T6ojRnjP03ojRnjOnX_^[oZ;kZ00OoZ;kZ3onX_nX2ojg1j0GoZL3Z2?n_`NL00on`_^Co/<7V
ok31iP04ok31iPCo/;oU1?na`>D8ojfniP;oTkK_1OnM^^d3ogfam@04o`000?mm/OGoOK7eogfam@Ko
JZcg1on@__H6ok;6j@03ojc4jooooooooooo01Kooooo00?o0000ooooooooool08?ooool000cooooo
00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`03ooooo`KoYko[1onU^NL3oinai0;oVZWQ1onHYn07oi^/hPCo
W[GX1on[co<00on/foSo]>SgokCXm`05okCXm`?o]=[d1on`do82ojg:k`GoYKOV2?nU]^D3ojFfi0?o
YKSV2?nV^NL5ojNji`?oYkoZ2OnX_nX5ojRnj@?o00001OnW_^X2ojRojPgoZ;kY0_nX_^X5ojRnj@Oo
Z;kZ00?oZKkYojRoj_nX_nX03OnX_nX8ojW0jPKo[l7W0_n[`NT7ok31iP03ok2oiOna`>Go/L3U00Go
/L3U1_n]_^H00on``>KoWK[]oifjk@06oifjk@?oOK7e00Co0000ogfamOmm/OGoOK7e1_mZ[?L7oi2n
mP;o//KY1On/a>/Hooooo`03o`000?oooooooooo01oooooo000<ooooo`03o`000?oooooooooo00;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o00007_ooool00ol0003oooooojS1j`02ojS1
j`OoYko[1OnU^NL00onL[^CoVZWQoiZYh@04oiZYh@OoV:OP1onK[>800onN]NSoZlocoj_?l`06oj_?
l`?o]^Kf1?ndj?L6okCJm0Go/=?b0_nW^nL7ojFgiPKoYKKU00?oYKOVojFhi_nU^>H01OnU^>H8ojJi
i`03ojNjionW_n[oYkoZ00GoYkoZ1_nX_nX4ojRnj@?o00000_nX_^T5ojNnjQSoZ;kY1?nX_^X4ojVn
j@ooZ;oZ2?nY`>X2ojo1i`KoZl7Y1On``NH00on_`^So/L3Uok70i@07ok70i@;o[KkV1On``>H8oifj
k@?oOK7e00?o0000ohFclon5/o<01Om[ZOD2ofZ/m`?oT;kf0on7^?H8ojc4jaOooooo00?o0000oooo
ooooool07oooool000[ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo00?o0000ooooooooool07?ooool7ojS1j`OoYko[00?oYKWWoib^i?nL[^@00onL[^@6oiZY
h@OoV:OP1OnK[>83ojO4k`GoZloc1_nfi_H00ondj?Oo]=[dokCJm007okCJm003ok3Cl_nW^nOoYk_W
00CoYk_W1onU]nH2ojFfi@GoYKOV1onU^>H6ojJii`;oYko[2?nW_nX2ojRojPCoZ;kY0ol00006ojRn
j@03ojNnj_nX_^WoZ;kY01[oZ;kY00?oZ;kZojVnjOnY_^T01OnY_^T6ojRojP03ojVnjOnX_n[oZ;oZ
00KoZ;oZ1_nY`>X00onX_n[oZl7Yoj_1j@07oj_1j@03ok31i_n_`^So[l;X00?o[l;X1ona`>D00ona
`NKo/<3Vok30iP06ok30iPKoWK[]0_nU_N/3ohFcl`03o`000?n5/o?oQK?c00KoJjWe1on7^?H8ojc4
jaOooooo00?o0000ooooooooool07_ooool001_ooooo00?o0000ooooooooool06_ooool3ojO0j`Oo
Z<7[0onW_n/3oj2diPOoW:kT1_nJZN47oiRWh003oi^/h_nWa>ooYlC_00KoYlC_00?oZlocokKVm_nf
i_H01Onfi_H3okWRm0Oo]=[d00?o[LC[ojNkionW^nL01_nW^nL5ojFgiP03ojBfiOnU]nKoYKOV00Ko
YKOV1onU^>H2ojJii`KoYko[1_nW_nX01?nW_^WoZ;kYojRnjOnX_^T3o`0000SoZ;kY00?oZ;gYojRn
jOnX_^T06_nX_^T:ojVnj@;oZ;oZ1OnY_^T8ojRojP;oZL3Z1OnX_nX7oj_1j@03ojW0j_n_`^So[l;X
00Go[l;X1?na`>D4ok71iPSo/<3V0_nM^^d6ojFmj`;oQK?c00Co0000ohFclon5/o?oQK?c1_m[ZOD6
ohNhmPKo[<C[0_nW`^dHooooo`03o`000?oooooooooo01gooooo000Kooooo`03o`000?oooooooooo
01Oooooo1onW`>/5ojS1j`03ojJmj_nP]>KoX;CV00GoX;CV1onL[^@6oiZYh@?oV:OP1?nM]^T7ojO4
k`?o/]gf1?nfi_H7okWRm0;o]=[d1On]a>/8ojNki`03ojFgi_nT]^GoY;KU00?oY;KU1onU]nH6ojFh
iP[oYko[0_nW_nX4ojNnj@?o00002?nX_^T5ojRmjASoZ;kY3?nY_^T00onY_nWoZKkYojVnj@06ojVn
j@KoZ;oZ00?oZKoYojRoj_nX_nX01_nX_nX4oj_1j@CoZL3Z1on_`^P00ona`>Go/L7Vok71iP05ok71
iPKo/<3V0_nb`NH8ojFmj`;oQK?c00Co0000ohFclon5/o?oQK?c1_m[ZOD6ohNhmP;o[<C[1_nW`^dF
ooooo`;o00007oooool001_ooooo0_l0000Fooooo`?oYko[1onW`>/00onX`N_oY[gZojJmjP03ojJm
jPOoX;CV1onL[^@3oiZYh@?oV:[S1onM]^T4ojO4k`Oo/]gf00?o]^KfokWRm?nih_@01Onih_@2ok;@
k`Oo[LC[1_nW^nL00onS]NKoY;KUojBfi@05ojBfi@OoYKOV0_nU^>H<ojNoj`03ojNnj_nW_^WoYkkY
00;oYkkY0_l00002ojNnj@KoZ;kY2OnX_NTDojRnj@;oZKoZ2_nY_^T5ojVoj@SoZKkY0_nX_nX5ojVo
j@SoZ;oZ00?oZl7YojW0j_nY`>X01?nY`>X6ojo2j003ojc1jOna`NKo/L7V00Oo/L7V0_n``>H6ok;1
iPKoYKg[00GoZ[oYohZdl_n:]?;oR[Cbo`000002ohZdlPOoKjSd1_n0/oD7ojO2kASooooo00?o0000
ooooooooool07?ooool001[ooooo00?o0000ooooooooool04oooool7ojNoj`GoYl3[0_nX`N/6ojJm
jPOoX;CV0onL[^@3oiJWhPOoV:[S1onM]^T00onWa>oo/]gfok;MmP06ok;MmP?o_>Kc1?nih_@5ok;@
k`Oo[LC[0_nW^nL5oj>eiPOoY;KU1OnU]nH3ojJnjPWoYko[1OnW_^X3o`0000GoYkkY0_nX_^T=ojRm
jA3oZ;kY1_nY_nX6ojVnj@03ojW0j_nY_nWoZKoY00KoZKoY1_nY_^T00onZ_nWoZKoYojVoj@06ojVo
j@KoZ;oZ00?oZKoZojW0j_nY`>X01_nY`>X2ojo2j0Go[<7Y1ona`NH00ona`nOo//7Vok;1iP07ok;1
iP;oYKg[1OnZ_nT3ohZdlP03o`000?n:]?;oR[Cb00OoKjSd1_n0/oD7ojO2kAOooooo00?o0000oooo
ooooool07?ooool001[ooooo00?o0000ooooooooool03oooool4ojJnj`SoYko[00?oYl3[ojS1jonX
`N/01?nX`N/6ojJmjPGoX;CV00?oVJcToiJWh_nFYn801OnFYn87oiRZh`GoWKKY0on]c_45ok;MmPOo
_>Kc00?o^N;dok;@konbd>l01Onbd>l5ojg4j`;oXkKV1onS]NH7ojBfi@03ojFgi_nV_^[oY[kZ00Go
Y[kZ1OnW_n/5ojNnjP?o000000?oYkkZojNnjOnW_^T01?nW_^T00onW_NWoZ;gYojRmj@0<ojRmj@03
ojRoj_nX_^WoZ;kY00_oZ;kY0onX`N/7ojVojP;oZKkY1OnY`>X8ojVoj@;oZKkY1OnZ_nT8ojVoj@;o
Z;oZ1OnY_nX6ojW0jP03ojRoj_n/`NWo[<7Y00Ko[<7Y1?na`NH4ok73i`Oo//7V00?o//;VojZojOnZ
_nT01OnZ_nT3ohZdlP04o`000?n:]?;oR[CbohZdlPOoKjSd1_n0/oD3ojO2k@CoXko]5oooool00ol0
003oooooooooo`0Kooooo`006_ooool00ol0003oooooooooo`0;ooooo`;oYko[1onV_^/6ojNoj`03
ojO0jonX`N_oZ<7[00KoZ<7[1_nV_NX00onP]>KoVJcToiV/i003oiV/i0OoUZOR1onHZ^<00onM]^Wo
[Lkaojg>l@06ojg>l@03ok;Mm_nli_?o_>Kc00Ko_>Kc0onhf_47ok;@k`03ojg4jonS]^KoXkKV00Co
XkKV1onS]NH3ojBfi@CoY;_Y2?nV_^X00onW_n_oYkkZojNnjP03ojNnjP?o00001OnW_^X2ojNnj@Go
YkgY2_nX_NT5ojRojPWoZ;kY1onX`N/5ojVojP03ojS1k?nY`>[oZL3Z00KoZL3Z1_nY_nT00onY`N[o
Z[oYojZoj@06ojZoj@KoZKoY0_nZ_nT7ojVojP;oZL3Z1OnX_nX8ojc1j@03ok71i_na`nOo/L?W00Go
/L?W1?nb`NH4ok;2iPOoZ[oY0on:]?800ol0003oS[C`ohjdl007og:Xl`KoOJkc2?nS_ndGooooo`03
o`000?oooooooooo00Kooooo1Ol0000?ooooo`006_ooool2o`0000Wooooo1_nW_n/7ojJnj`;oYko[
1OnW`>/8ojS1j`?oY[gZ0onL/NH6oiV/i0KoUZOR1_nHZ^<3ojG1k@Ko[Lka1?nki?<3okcVl`Oo^=[a
0onbd>l3ojJjj0SoXkKV1OnS]NH2oj>hj0OoY;_Y1_nV_^X4ojNnjP?o00001onW_^X9ojNmj@KoZ;gY
00?oZ;o[ojRoj_nX_nX01_nX_nX6ojRnj@;oZ<7/2?nX`N/00onY_n[oZ<7/ojS1k003ojS1k0SoZL3Z
0_nY_nT5ojW1jPSoZ[oY0_nY_nT6ojZoj@GoZKoZ00?oZKoYojRoj_nX_nX01_nX_nX6ojc1j@;oZL7Z
2?na`nL00onb`NKo//;Vok;2iP04ok;2iPKoZ[oY0_n]`NT3ohjdl003o`000?n>]?3oS[C`00OoLZSc
1_mm[_<8oj>okAKooooo00?o0000ooooooooool01_ooool01OnHV9So8B4Qonk^k_ooooooA4A400oo
oooo000Jooooo`03o`000?oooooooooo00Kooooo0_nX`N/7ojNoj`GoY[k[2OnW`>/6ojS1j`;oY;_Y
1_nL/NH6oiV/i0KoUZOR0_nHZ^<7ojG1k@?o[Lka1_nki?<3okkRl@Ko^=[a0_n^a^`6ojJjj0SoXkKV
00?oXkGVoj>hj?nS^>P01?nS^>P7ojBkj@;oY[kZ1?nW_^X3o`0000OoYkkZ3OnW_NT2ojRmj@GoZ;o[
2?nX_nX2ojRnj@KoZ<7/1_nX`N/00onW`>coZ<7/ojS1k005ojS1k0KoZL3Z00?oYl7/ojW1j_nY`NX0
1_nY`NX6ojZoj@;oZ/3Z2?nZ_nT00onY_n[oZKoYojVoj@03ojVoj@SoZ;oZ0_n/`NT6ojW1jPKo/L?W
00?o/<?Xok;2i_nb`^H01_nb`^H2ojZoj@Ko[L7Y0_n>]?001?l0003oS[C`ohjdl?n>]?06og:Xl`Ko
OJkc1_nS_nd2oj:nkAOooooo00?o0000ooooooooool01_ooool00onHV9So8B4Qonk^kP0@ooooo`00
6_ooool00ol0003oooooooooo`03ooooo`KoZ<7[1onW_n/00onV_^_oYl3[ojO0j`0;ojO0j`;oZ<7[
1_nT^nT6oibaiPKoVJcT0onFYn83oiV`i`WoYL7]00?o[Lkaok_Tlonki?<01?nki?<5okkRl@?o^=[a
1On^a^`6ojJjj0KoXkKV00?oX[KWoj>hj?nS^>P01_nS^>P5ojBkj@;oYko[0_nW_^X3o`0000SoYkkZ
3_nW_NT2ojNoj`OoZ;o[1_nX_nX2ojO1k0SoZ<7/0_nX`N/5ojO0k0OoZ<7/0_nY`>X5ojO1k0SoZL7Z
0_nZ_nT6oj[0jPKoZ[oY00?oZ/3YojVojOnY_nT01OnY_nT6ojRojP;oZL3Z2?nY`NX2ok73i`Go/<?X
1_nb`^H00onb`nKo[L7Yojg1j@07ojg1j@;oS[C`00Co0000ohjdl?n>]?3oS[C`1_mbZ?<6ogf^l`;o
Xko]1_nR_^dGooooo`03o`000?oooooooooo00Kooooo00?oV9RHob4Q8Oo^k^h03oooool001[ooooo
00?o0000ooooooooool02_nX`N/5ojNoj`;oY[k[3?nW`>/2ojS0j`SoY;_Y1_nL/NH3oiV/i0;oTjOS
1onI/>L7ojG1k@?o/mOb1?nki?<7okkRl@03okSJlOn^a^co[/K/00Go[/K/1_nV^^P2oj>fiPGoX[KW
2?nS^>P00onT^nWoYko[ojNoj`02ojNoj`?o00002?nW_^X>ojNmj@KoYko[1onX_n/2ojRojPKoYl7/
1_nX`N`00onW`>_oYl3/ojO0k006ojO0k0GoZ<7/00?oYl3/ojO1k?nW`N`01_nW`N`6ojW1jP;oZ<7[
2?nZ`>X2ojZoj@GoZ/3Y1onY_nT2ojRojPKoZL3Z1_nY`NX00onY`>_o/<?Xok33j005ok33j0Co//;V
1?nb`nH7ojg1j@05ojk2jOn@]_3oT;K`oi2fl?l000000on@]_06ogFWl@KoO:_a1onR_^dGooooo`03
o`000?oooooooooo00Oooooo00?oMgMgofIVI_ooool03_ooool001Wooooo00?o0000ojS1jonX`N/0
3?nX`N/00onW_n_oY[k[ojJnj`04ojJnj`SoYl3[1_nX`>/8ojBkj@?oW;7V0_nFZ^@6oi>Wh`OoVK3W
1?nU`Nd7ok?GlP03ok_Tlonnh_7o_^;a00Go_^;a0_nge>l8ojk6k0?oY[[X0onQ]NL7oj:fi`KoXkSX
00?oY[k[ojNojonW_n/00ol00003ojNoj`GoYkkZ0_nW_NX=ojNmj@WoYko[1OnX_n/:ojO1k0;oZ<7/
1OnW`>/8ojO0k003ojS1k?nW`>coYl3/00?oYl3/2?nW`N`2ojW1jPKoZ<7[1_nZ`>X00onY`N_oZ/3Y
oj[0j@05oj[0j@KoZKoY0_nZ`>T8ojW0jP;oZL7Z1OnY`>/7ok33j003ok;2i_nb`nKo//?V00Go//?V
1?n]`NT4ojk2j@?oT;K`00Co0000oi2fl?n@]_3oT;K`1_meYo46ogb[l@OoX[k]5oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00gooooo000Iooooo`03o`000?nX`N_oZ<7[00_oZ<7[
0_nV_n/7ojJnj`SoYl3[1_nX`>/6ojBkj@03oiV`ionFZ^CoUZ[T00CoUZ[T1_nCYn<7oiV`i`03ojG1
kOnceo;o/mOb00Ko/mOb1?o1i?02okkRl@Ko]mC_1_n^a^`00onR]nOoXKGWoj6ei`05oj6ei`OoX[KW
0_nS^>P4ojJnj`;o00001onW_n/00onW_^[oYkgZojNmjP04ojNmjPWoYkgY3OnW_n/00onX_n_oYl7/
ojO1k00:ojO1k0WoYl3[1_nW`>`2ojNoj`KoYl3/1_nW`N`2ojO0j`SoZ<7[0_nZ`>X5ojW1j`OoZ/3Y
0_nY_nT6oj[0j@OoZL3Z2?nY`>/5ok33j0;o[/;X2?nb`nH00on]`NWo[/;Yojk2j@04ojk2j@?oT;K`
00?o0000oi2fl?n@]_000_n@]_06ogFWl@KoO:_a0onR_^d4oj:mk1Gooooo0ol00004ooooo`05o`00
0?nj^[[ooooooiRHV?l@41003oooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03
o`000?ooooooZ<7[00SoZ<7[1_nV_n/7ojJnj`SoYl3[1_nX`>/2ojBkj@GoVK3W1_nFZ^@6oi>Wh`Go
VK3W0on[anh5ok?GlPGo`NC`0onngNl7okODk`;o[/K/1OnR]nL7oj6ei`GoX[KW0_nT_>X2ojJnj`?o
00000_nV_^/6ojNoj`03ojNnj_nW_N[oYkgZ00KoYkgZ1OnW_NT2ojNnjP_oYko[3OnW`N`=ojO0j`;o
Yl3/1_nW_n/6ojO0k0;oYl7/1_nW`>/6ojS1j`03ojO0k?nY`N_oZL7[00KoZL7[1OnZ`>T2oj[1jPSo
Z/3Y1onY`>X8ojW0j`03ok33j?n^`^So[/;X00Co[/;X1_nb`nH2ok;4i`Oo[/;Y0on@]_001?l0003o
T;G`oi2el?n@]O06ogJVl0KoOZ[`2?nR_N`Fooooo`03o`000?oooooooooo00;ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c00?ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000
ooooooooool02?nX`N/7ojJoj`GoY[k[2_nW`>/3ojS0j`?oX[[Z1onI/>L5oiJZi0OoTjOS00?oVK3W
oj_7k_n[anh01_n[anh00onceo;o`NC`ol7Tl004ol7Tl0Go_]g_1Onge>l2ojS0jPOoX[OW1onQ]NL0
0onR]^OoY;cZojBljP02ojBljP?o00001_nV_^/2ojNoj`GoYkkZ2?nW_NX00onW_NWoYkkZojNnjP04
ojNnjPKoYko[3_nW`N`2ojNoj`goYl3[0_nW_nX8ojNoj`?oYl3/0onW_n/8ojO0j`;oZ<7[1OnW`>`8
ojW1j`03oj[0jOnZ`N[oZ/7Z00CoZ/7Z1_nZ`>T00onZ`>[oZL3ZojW0jP06ojW0jPKoZL3[00?oZ<3[
ojk2j?n^`^P01_n^`^P2ok;3iPKo//CW1On^`^T2ojk3j@?oT;G`00Co0000oi2el?n@]O3oT;G`1_mf
Y_06ogjZl0SoX[g/5_ooool00ol0003oooooooooo`0Eooooo`003_ooool01Ol@413ooooooooooooo
oooo410@00Kooooo0_l00002ooooo`SoZ<7[1onV_n/00onV_^_oYl3[ojO0j`0:ojO0j`;oZ<3[1_nR
^^X6oiV`i`KoUZ[T0onCYn<5oifej@KoZlO^0onjfo04ol7Tl0Oo_]g_00?o]mC_ojS0j_nX`>X01?nX
`>X7oj:gi`?oXKGW1?nQ]nP01?nT_>[o0000o`000?l00003ojBljPGoY[k[2OnW_^X6ojNmjP;oY[gZ
1onW_^X2ojNoj`koYl7/1_nW_n/9ojO0j`KoYkoZ1_nW_n/00onX_^[oYko[ojNoj`05ojNoj`KoYl3[
00?oYko[ojO0k?nW`>`01_nW`>`6ojW1j`03ojO0jonZ`N[oZ/7Z00KoZ/7Z0_nZ`>T5oj[0jPSoZL3Z
0_nY`>/5ojS0j`Ko[/;X00?o[/;Yok;4ionba>L01onba>L00on^`^Wo[/?Yojk3j@04ojk3j@?oT;G`
00?o0000oi2el?n@]O001_mfY_07ogjZl0KoX[g/00?oXkg[ooooooooool05Oooool00ol0003ooooo
ooooo`0Dooooo`003_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0
0oooool7ojS1j`?oY[o[1OnV_^/8ojO0j`KoZ<3[1_nR^^X6oiV`i`?oUZ[T0onBZ>D8oifej@?oZlO^
1onjfo000oo1i?3o_]g_okkMk`05okkMk`?o]]3^1_nX`>X5oj:gi`;oXKKX1?nQ]nP3o`0000OoY;cZ
00?oY[k[ojNnj_nW_^X02onW_^X2ojNmjPKoY[gZ1OnW_^X?ojO1k0WoYko[1OnW`>/2ojNnjPSoYkoZ
0_nW_n/5ojRnjPOoYko[0_nW`>/5ojNoj`SoYl3/0_nY`N/5ojO0j`KoZ/7Z00?oZL7[oj[0j_nZ`>X0
1_nZ`>X6ojW0jP03ojW1j_nX`>_oZ<3[00KoZ<3[0_n^`^P5ojk2j@Oo//CW00?o//GXojk3jOn^`nT0
1_n^`nT2oi2el004o`000?n@]O3oT;G`oi2el0KoMZK`1omnZ_02oj:mk0GoXkg[5_ooool00ol0003o
ooooooooo`0Dooooo`003_ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000oooooooo
ool01Oooool5ojS1j`;oYko[2?nV_^/7ojO0j`OoZ<3[1_nR^^X3oiV`i`;oTjWU1onBZ>D8oifej@03
oj_7k_njfo3o^]_`00Go^]_`1?o4hnh2okkMk`Oo]]3^1_nX`>X00onR]nOoXKKXoj6fj004oj6fj0?o
00001?nQ]nP3ojBljPCoYko[2onW_^X;ojJmjP03ojNnj_nW`NcoYl7/00goYl7/3OnW_n/00onW`>_o
YkkZojNnjP04ojNnjPKoYkoZ00?oZ;oZojRnj_nX_^X01_nX_^X5ojNoj`03ojRoj_nW_n_oYko[00Ko
Yko[1_nW`>`2ojNoj`OoYl3[0_nZ`NX5ojW1j`SoZ/3Z0_nY`>X5ojW1jPOoZ<3[2?n^`^T4ok;4i`Co
//GX1_n^`nT01On]`n[oSk?_ohnckon?/noo000000?oSk?_1OmgY>l7oh6YkPOoXkg[5oooool00ol0
003oooooooooo`0Cooooo`003_ooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000oooo
ooooool01_ooool00onX`N_oYko[ojNoj`04ojNoj`SoY[k[1onW`>/7ojS0j`?oX[[Z0onH/>P5oi>Y
i@OoTZSU1_nM]NT3ojo:kPCo^]_`1_o4hnh2okkJk@So]]3^0onX`>X2oj2fj0CoXKKX0ol000000onQ
]^SoXKOXoj6gj003oj6gj0;oY[k[1onW_n/6ojNnjPkoY[gZ00?oYl3[ojO1k?nW`N`02onW`N`2ojO0
j`goYko[2OnW_^X2ojNojPGoZ;oZ2?nX_^X00onW_n_oZ;oZojRojP03ojRojPSoYko[0_nW`>`6ojNo
j`GoYl3[00?oYl3/ojW1jonY`N/01_nY`N/6oj[0jP;oZl7Z1onY`NX7ojS0j`So[/;Y00?o//CWok;5
j?nbaNP01?nbaNP4ojk3j@Co[L?Z0on?/nl01?l0003oSk?_ohnckon?/nl5ogNTk`OoPJW^1onS_N/G
ooooo`03o`000?oooooooooo01;ooooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
o`0000Sooooo1onW_n/6ojJnj`WoYl3[1OnX`>/2oj6jj`KoV;3X1OnCZND7oi:Xi@;oWKGY1on_b^h0
0onjfo3oa>?^olCSkP05olCSkPCo_][]1_nfd>h00onU_N[oX;KXoj2fj004oj2fj0?o00001OnQ]^P0
0onQ]nSoY[k[ojJnj`04ojJnj`OoYko[0_nW_^X>ojJmjPGoYl3[2OnW`N`6ojO0j`WoYko[2onW_^X9
ojRojPKoZ;kZ0_nY_nX6ojRojPKoYko[0_nX_nX8ojNoj`03ojO0jonW`>coYl3/00?oYl3/2?nY`N/2
oj[0jPKoZl7Z1OnY`NX00onZ`N[oZ<3[ojS0j`06ojS0j`Oo[/;Y2?nbaNP00on^`nWo[L?Zojg3jP05
ojg3jP;oSk?_00?o0000ohnckon?/nl00_n?/nl5ogNTk`KoPJW^1_nS_N/00onW_^[oooooooooo`0E
ooooo`03o`000?oooooooooo01;ooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool0
0ol0003oooooooooo`08ooooo`OoYko[0_nV_^/=ojO0j`03ojS0jonQ^^_oXK[[00CoXK[[1_nH/>P5
oi>Yi@GoTZSU0onO^>X6ojo:kP?o_m_^1?o4hnh7okkJk@;o]]3^1OnU_NX3oj2fj0;o000000?oX;KX
oj6fj?nQ]^P01?nQ]^P00onR^NWoY[k[ojJnj`06ojJnj`GoYko[00?oY[kZojJmj_nV_NX02onV_NX2
ojJnj`OoYl3[1_nW`N`2ojS0j`OoYl3[0onW_n/=ojNnjPgoZ;oZ0_nX_^X6ojVojPKoZ;oZ0_nW_n/6
ojRojPKoYko[00?oYl3[ojO0k?nW`>`01OnW`>`6ojW1j`;oZ<3[2?n[`NX00onY`N[oZ/7Zoj[1jP03
oj[1jPSoZ<3[1on^`^T6ok;5j0;o/lGX2?n]`nX2ohnck`04o`000?n</>koS;3^ohb`kPCoMj;]0_mg
Y>l6oh6YkP;oXkg[1OnW_^XGooooo`03o`000?oooooooooo017ooooo000Hooooo`03o`000?oooooo
oooo00Wooooo1OnW_n/3ojJnj`coYl3[0_nX`>/7oj6jj`KoV;3X1OnCZND00onBZ>GoWkSZoinhjP05
oinhjP?o[l[^1onofnh00oo4hnko_][]okkJk@05okkJk@;o]/o]1_nU_NX3o`0000CoX;KX0_nQ]^P5
oj:ij@SoY[k[00?oYko[ojJnj_nV_^X00onV_^X9ojJmjPKoY[k[1onW`>/2ojO1k0KoZ<3[1OnW`>/?
ojNnjP03ojRojonX_n[oZ;oZ00_oZ;oZ0_nX`N/8ojVojP?oZ;oZ0onY_nX8ojRojP;oYko[1OnW`>/7
ojO0k0;oZL7[1_nX`>/7oj_1jPOoZ/7Z2?nX`>/7ojk2j@;o//GX1_ncaNP6ojg3jP05oj[3k?n</>ko
S;3^ohb`k_l000000on</>h5ogNRk@KoQZ[/2?nW_^XGooooo`03o`000?oooooooooo013ooooo000H
ooooo`03o`000?oooooooooo00[ooooo00?oYko[ojJnjonV_^/01OnV_^/8ojO0j`KoZ<3[1onQ^^/3
oiR`j0;oTJ[W1onAZNH7oinhjP03ojo:k_nofnko_m_^00Go_m_^0oo6h>/4okkJk@Go]/o]0_nU_NX3
o`0000;oYKgZ0onP]^P3oinfj0OoX[WY1_nV_^/2ojNoj`KoY[kZ2?nV_NX7ojJnj`GoYl3[0_nX`N/8
ojS0j`03ojO0jonW_^[oYkkZ00goYkkZ1OnX_n/9ojRojPKoZ<7[1_nY_nX00onX`N_oZKoZojVojP05
ojVojPKoZ;oZ00?oZKoZojO0jonW`>/01_nW`>/5ojO0k0;oY[o[2?nX`>/7oj_1jPOoZ/7Z2?nX`>/5
ojk2j@;o[/?Y2?ncaNP2ojg3jPGoZ/?/0on</>h00ol0003oS;3^ohb`kP06ogNRk@KoQZ[/1_nW_^X2
ojc1jAKooooo0_l0000Aooooo`005oooool3o`0000gooooo1onV_^/7ojO0j`OoZ<3[0onQ^^/3oiN`
j@KoTJ[W1onAZNH5oinhjP?o/L[]1?nofnh7olKPj`03okkJkOnfcngo]/o]00?o]/o]0ol00004ojFm
jP;oW[KY1_nO]^P7oj:ij@;oY[k[1_nW_n/6ojJnjPSoY[gZ1onV_^/00onW`>_oZ<7[ojS1j`04ojS1
j`KoZ<3[00?oYkoZojNnj_nW_^X02onW_^X2ojNoj`OoZ;o[1OnX_nX2ojO1k0SoZ<7[0_nY_nX5ojS1
j`OoZKoZ0_nX_nX5ojVojPSoYl3[00?oYl3/ojJojonV_n/01?nV_n/7ojS0j`OoZl7Z1_nZ`NX2oj[1
j`SoZ<3[00?o[/;Yojk3jOn^`nT01?n^`nT6ok?5j003ok?6jOnZ`ncoZ/?/00KoZ/?/0_n</>h01?l0
003oS;3^ohb`k_n</>h5ogNRk@OoQZ[/0_nW_^X6ojc1jACooooo00?o0000ooooool000004Oooool0
01Oooooo00?o0000ooooooooool03_ooool5ojJnj`;oYko[1onW`>/5ojS0j`;oX[c/1_nG/>T6oi6Z
i`OoTJWV00?oWkSZok7:kOnab^d01_nab^d00onofnkoa^3[olKPj`05olKPj`?o`=S/00Co]/o]o`00
0?l0003o00000onfcnd00onU_N[oW[KYoijfj@04oijfj@KoWkKX1OnR^NT3ojJnj`OoYko[0onV_^X;
ojJmjP?oY[k[1?nX`N`7ojS1j`;oZ<3[1OnW_nX9ojNnjPKoYko[1onX_n/00onX_n[oYl7/ojO1k004
ojO1k0KoZ<7[00?oYl7/ojS1jonX`N/01_nX`N/5ojVojP;oZL7[1onY_nX7ojO0j`SoY[o[1onX`>/7
oj_1jP;oZ/7Z1_nZ`N/6ojS0j`03ojS1jon^`nWo[/?Y00Ko[/?Y0_ncaNP5ok?6j@KoZ/?/00GoYL3]
ohV]kOn9[NgoRJg]o`000002ohV]k@CoN9o[0_mgX^d3ohJZk0?oSJcZ2On/`NTEooooo`03o`000?oo
oooooooo00oooooo000Gooooo`03o`000?oooooooooo00oooooo00?oY[k[ojNojonW_n/01?nW_n/7
ojO0j`03ojS0jonR_>coX[c/00CoX[c/1_nG/>T5oi6Zi`KoTJWV0_nO^>X7ok7:k@?o`MW[1?o6h>/3
ol3Hk0?o000000Co`=S/okK?kOnfcngo]/o]0onU_N/7oijfj@KoWkKX00?oX[WYojJnjonV_^/01OnV
_^/5ojNoj`03ojJnjonV_N[oY[gZ00_oY[gZ00?oYko[ojS1k?nX`N`01_nX`N`5ojS1j`;oYko[1onW
_nX6ojNnjPWoYko[0onX_n/;ojO1k0;oZ<7[1OnW`N`8ojS1j`03ojVoj_nY`N_oZL7[00CoZL7[1onY
_nX7ojO0j`KoY[o[00?oYko[ojS0jonX`>/01_nX`>/7oj_1jPSoZ/7[0_nX`>/5ojS1j`Ko[/?Y00?o
/<CYok?6jOnca^T01_nca^T2oj[3k0GoYL3]0on9[Nd00ol0003oRJg]ohV]k@05ogROj`OoSJcZ1on/
`NT00onba>Soooooooooo`0Dooooo`03o`000?oooooooooo00kooooo000Gooooo`03o`000?oooooo
oooo013ooooo1onW_n/5ojO0j`?oZ<7[1_nR_>`5oiN`j@KoTJ[W0_nAZNH6oinhjPCo/L[]1oo1fN/0
0oo6h>_o`=S/o`000002o`0000?o`=S/00?o]lo/ojFmjonU_N/01OnU_N/7oijfj@?oWkKX0onR^^X8
ojJnj`03ojNojonV_^_oY[k[00?oY[k[2OnV_NX5ojNoj`SoZ<7/00?oZ<7[ojNojonW_n/01?nW_n/7
ojNojP;oYkkZ2onW_n/GojO1k0KoZ<7[0_nW`>`7ojW1j`?oZKoZ1?nY`>X7ojO0j`;oY[o[1OnW_n/8
ojS0j`OoZl7Z1_nZ`N/00onY`N_oZ<7[ojS1j`05ojS1j`Co[/?Y1?n`a>T6ok?6j@;o//OY1onU`>d3
ohV]k@03o`000?n9[NgoRJg]00GoN9o[1on=[>X4ojc1j@Co//CX5_ooool00ol0003oooooooooo`0=
ooooo`005oooool2o`0001;ooooo1onW_n/00onW`>_oZ<7[ojS1j`05ojS1j`KoX[c/1OnG/>T3oi6Z
i`?oSjWW2?nO^>X00onab^go`MW[ol7Ij`06ol7Ij`?o00001?o0f>`4okO?k0OoYKg[0onN]^T3oijg
j@OoX[[Z1_nV_^/00onV_n_oY[k[ojJnj`05ojJnj`KoY[gZ00?oY[g[ojNojonW_n/01OnW_n/6ojS1
k0;oZ<3[1onW_n/5ojNojP;oYkkZ2OnW_n/KojO1k0;oZ<7[1_nW`>`5ojW1j`03ojS0jonY`>[oZL3Z
00KoZL3Z1OnW`>/2ojS0j`OoYko[1onX`>/8oj_1jP;oZ/7[1OnY`N/7ojS1j`03ojk3jOn`a>Wo/<CY
00Co/<CY1?nca^T5ok;7j@OoYL3]0_n9[Nd01?l0003oRJg]ohV]kOn9[Nd5ogROj`OoSJcZ00?o[<7Y
ok;4j?nba>P01Onba>PEooooo`03o`000?oooooooooo00gooooo000Gooooo`03o`000?oooooooooo
01;ooooo1OnW_n/3ojO0j`OoZ<7[0onR_>`2oiNbjPKoT:_Y1_n?ZNL6oinhjP?o/LS[1Oo1fN/2o`00
00Cob=kY00?o`=S/okO?k?ngcn`01Ongcn`5ojFmj`;oW[OZ1_nN]nT7oj:jjP;oY[k[1OnV_n/7ojJn
j`;oY[gZ1OnV_N/7ojNoj`;oZ<7/1_nX`>/7ojNoj`03ojNoj_nW_^[oYkkZ00CoYkkZ1_nW_n/LojO1
k0;oY/3/2?nW`>`00onY`N_oZ<3[ojS0j`03ojS0j`SoZL3Z00?oYl3[ojS0jonX`>/01?nX`>/7ojNo
j`OoZ<3[1_n[`NX2oj_2j`KoZL7[1_nX`N/2ojW0j`Oo/<CY00?o/lKYok;7jOnbanT01_nbanT3ojG0
k@?oWKc^0on5Z>/00ol0003oQJS[ohFXj`04og^Nj0;oN9o[0on=[>X3oiF`j@Oo//CX00?o^<WWoooo
ooooool05?ooool00ol0003oooooooooo`0<ooooo`005oooool00ol0003oooooooooo`0Cooooo`03
ojNojonW`>_oYl3[00GoYl3[1OnX`N/2ojBnk0GoUk;Z1_n@ZnT6ohnYi`?oWkSZ1_nab>/01?o1fN_o
0000o`000?l00005olSNj@?o`mSY1ongcn`00onU_N_oW[OZoijgjP04oijgjPKoW[OY1OnR^^X3ojJn
j`KoY[o[1OnV_^/3ojFmj`KoY[g[1OnW_n/3ojS1j`OoZ<3[0onW_n/4ojJnjPOoYkkZ0_nW_n/LojO1
k0KoY/3/1onW`>`7ojS0j`KoZL3Z00?oZL7ZojS0jonX`>/01_nX`>/7ojNoj`OoZ<3[0_n[`NX6oj_2
j`KoZL7[0_nX`N/6ojW0j`Go/<CY0_naa^T7ok;7j@03ok77jonM_>koWKc^00GoWKc^0on5Z>/00ol0
003oQJS[ohFXj`05og^Nj0OoUK3Y1?nba>P4okS9iaKooooo00?o0000ooooooooool02oooool001Oo
oooo00?o0000ooooooooool05Oooool7ojO0j`03ojS1jonT_^coY;k/00CoY;k/1OnG/^X6oi2[j@Ko
SjWW00?oWkSZok78jonab>/00onab>/3o`000003ol7Ijoo8g^Wob=kY00?ob=kY1_o3f>T5okO?k003
ojO1k?nN]n[oW[OZ00KoW[OZ1_nN]nT00onR^^[oY[k[ojJnj`05ojJnj`KoY[o[00?oY[k[ojFmjonU
_N/01OnU_N/6ojJmj`03ojNojonX`N_oZ<7[00GoZ<7[1OnX`>/00onW_n_oY[kZojJnjP06ojJnjPGo
YkkZ0_nW`>/IojO1k0?oYko[2?nV`>`7ojO0k0OoZ<3[0_nY`>X5ojW1jPOoZ<3[2?nW_n/7ojS0j`So
Zl;[1_nY`N/8ojW0j`03ok34jOnaa^Wo/LKY00Co/LKY1?nbanT4ok77j`KoWKc^1?n5Z>/00ol0003o
QJS[og^Nj005og^Nj0OoUK3Y00?o//CXokS9ionhbNL01OnhbNLEooooo`03o`000?oooooooooo00_o
oooo000Fooooo`?o00005oooool5ojO0j`?oZ<3[1_nT_^`5oiNbjPKoT:_Y0on?ZNL4oifej@04ok78
jol0003o0000o`0000;o/LS[1?o0e>T2olSNj@So`mSY00?o]lo/ojO1k?nW`N`00onW`N`8oijgjP?o
W[OY0onQ^NX8ojJnj`?oY[o[0onV_^/8ojFmj`?oY[g[0onW`>/8ojS1j`03ojS0jonW_n_oYko[00?o
Yko[2?nV_^X00onW_^[oYl3[ojO0j`04ojO0jaCoYl7/00?oYkkZojNojonW_n/01OnW_n/6ojK0k0;o
Y[o/1_nW`>`8ojS0j`OoZL7Z1onX`>/8ojNoj`OoZ<3[1_n[`^/00onZ`^_oZL7[ojW1j`05ojW1j`Ko
ZL3[00?oZL7[ok76jOnaa^T01_naa^T00onbanWo/LO[ok77j`04ok77j`OoWKc^0on5Z>/00ol0003o
QJS[ohFXj`06og^Nj0?oUK3Y1?nM]^T6okS9i`;o_]3X5Oooool00ol0003oooooooooo`0:ooooo`00
5_ooool00ol0003oooooooooo`0Hooooo`03ojO0jonX`>_oZ<3[00GoZ<3[1_nT_^`5oiNbjP?oT:_Y
0_n<Z>P5oifej@?o00000onab>/6ol3Dj@?obM[V1_o3f>T2ok_@j`KoYl7/1_nN]nX00onM]n[oXKWZ
oj6ijP05oj6ijPKoY[k[00?oY[o[ojJnjonV_^/01OnV_^/6ojFmj`03ojFnjonW`>_oYl3[00GoYl3[
1_nX`N/2ojO0j`KoYko[1_nV_^X2ojJoj`OoYl3[0onW`N`4ojS1k0WoYl7/1OnW_^X7ojNoj`;oY/3/
1_nV_n`6ojO0k0SoZ<3[1OnY`NX00onY`N_oZ<3[ojS0j`06ojS0j`KoYko[00?oY[o[ojS0jonX`>/0
1_nX`>/2oj_2j`GoZ/;[1onY`N/2ojW0j`GoZL7[1_naa^T00onban[o/LO[ok77j`06ok77j`?oWKc^
0onD/^`4oh2Rj@03o`000?n0X^WoPZ3W00GoPZ3W2?nM]^T3okS9i`Go_]3X4oooool3o`0000_ooooo
0004ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo00?o0000oooo
ooooool06_ooool7ojS0j`?oY;k/0_nI]^`5oi2]jPKoS:SX00CoWKGYo`000?l0003o00001?nM]NT0
0onab>_o`=CYol3Dj@04ol3Dj@KobM[V00?o`mSYok_@jonkd>/01?nkd>/6ojO1k0;oW[OZ1OnM]nX7
oj6ijP;oY[k[1OnV_n/7ojJnj`;oYKg[1OnU_^/7ojO0j`;oZ<7[1_nW`>/6ojNoj`;oY[kZ1_nV_n/5
ojO0j`WoZ<7/1OnW`N`9ojNnjPGoYko[0_nX_nX8ojJok0?oYl3/0onV_n`8ojS0j`03ojW1j_nY`N_o
ZL7[00?oZL7[2?nX`>/2ojNoj`GoY[o[1_nX`>/00onY`N_oZ/;[oj[2j`05oj[2j`ooZL7[0_naa^T5
ok;7jPKo/LO[0_n]a^`6oiBbk0CoP:;Y00?o0000oh2RjOn2X>L01On2X>L8oiffj@03okS9ionnd>So
_]3X00Go_]3X3oooool3o`0000;ooooo00?o0000ooooooooool02Oooool000Kooooo00?o0000oooo
ooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool06oooool5
ojS0j`03ojJok?nI]^coVKK/00CoVKK/1On@[NX3ohbXj0?o00001_nM]NT3ojk5jP?o`=CY1oo9f^H2
olKIi`Oo^m3[0onW`N`4oijhj`KoWKOZ1OnQ^NX3ojJnj`KoY[o[1OnV_^/9ojFnj`GoYl3[0onX`N/7
ojO0j`?oYko[0onV_^/8ojJoj`03ojO0jonX`NcoZ<7/00_oZ<7/00?oYl7/ojNnj_nW_^X02onW_^X0
0onW_n_oZ;oZojRojP04ojRojPKoY[o/00?oY[o[ojJok?nV_n`01OnV_n`8ojS0j`KoZL7[1_nX`>/2
ojO0j`OoY[o[0_nX`>/5ojW1j`OoZ/;[3OnY`N/2ojc2jPOo//OZ0_naan/6ojg6k0KoU;;/0on0X^T0
0ol0003oP:;Yoh2Rj@06oh:Pi`KoWKKY00?oY[cYokk@j?nnd>P01Onnd>P00oo0e>Woooooooooo`0:
ooooo`?o00001Oooool00ol0003oooooooooo`09ooooo`001_ooool00ol0003oooooooooo`02oooo
o`05oa0@4?ooooooooooooooool@41001_ooool2o`0001gooooo00?oZ<3[ojJok?nV_n`00onV_n`6
oiVfk0CoT:gZ0ol00004ohbXj0;oWKGY1on^aNX00oo0e>WobM[VolWJiP05olWJiPCoa]WW1Onkd>/3
ojg7k0KoW[S[1_nM]nX00onQ^N[oY[k[ojJnj`05ojJnj`KoY[o[00?oY[k[ojFnjonU_^/02onU_^/0
0onW`>_oZ<7[ojS1j`05ojS1j`GoYl3[00?oYko[ojJnjonV_^/01OnV_^/6ojJoj`;oZ<3[3?nX`N`2
ojNoj`[oYkkZ1?nY_^T7ojRojP;oY[o/1OnV_n/7ojJok0SoZ<3[1_nY`N/2ojS0j`KoYl3[1OnV_n/0
0onW_n_oZL7[ojW1j`06ojW1j`OoZ/;[2OnY`N/6ojc2jPGo//OZ0_nbb>/8ojg6k0KoU;;/0on0X^T0
0ol0003oP:;Yoh2Rj@06oh:Pi`;oWKKY1OnV_>T4okk@j0Co`=CY1oooool4o`0000Sooooo00?o0000
ooooooooool02Oooool000Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo
000000Gooooo0_l0000Oooooo`KoY[o/1_nI]^`00on@[N[o0000o`000002oi2]jP?oS:SX1?nG/>T6
ojk5jP?o_LkW1?o9f^H7olKIi`03ok_@jon]anco[LO/00Go[LO/1_nN^>/3oifgjP?oWkS[2?nV_^/3
ojJoj`koYKk[0onW_n/8ojS1j`03ojO0jonW_n_oYko[00?oYko[1onV_^/2ojJoj`KoZ<3[2?nX`N`6
ojNoj`KoYkkZ2?nY_^T5ojRojP;oZL7Z1onV_n/5ojJok0;oY[o[2?nX`>/6ojW1j`SoYl3[00?oY[o[
ojNojonW_n/00onW_n/8ojW1j`OoZ/;[1_nY`N/00onX`N_o[<;Zojc2jP06ojc2jP03ok;7j_nbb>_o
//S[00Co//S[1_n]a^`00onT`>goSJ_Yohf[j@04ohf[j@CoOigV00?o0000ognMi_n<YNH01On<YNH8
ojJlj@03okk@j?o0e>Wo`=CY00Go`=CY0oooool3o`0000gooooo00?o0000ooooooooool02?ooool0
00Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000
ooooooooool07oooool6ojJok0?oVKK/0ol00005ohZYjPOoUk3Y0on^aNX7okg>i`03olWJi_o6fNOo
a]WW00Goa]WW0onod^P7ojg7k0?oW[S[0_nL]n/7oinhj`KoY[k[00?oYko[ojFnjonU_^/03?nU_^/7
ojNoj`KoZ<7[0_nX`>/6ojNoj`GoY[k[0onV_n/7ojS0j`?oZ<7/0onX`N/8ojNoj`KoYkkZ2?nY_^T0
0onX_n[oZL7ZojW1jP04ojW1jPOoY[o[00?oY[o/ojJojonV_n/01?nV_n/7ojS0j`OoZL7[1onW`>/7
ojNoj`KoZL7[2OnZ`^/2ojW1j`GoZ<7[1_n/`^X00on_aN_o//S[ok;8j`06ok;8j`;o[LK/1OnT`>d6
ohf[j@CoOigV00?o0000ognMi_n<YNH01On<YNH6ojJlj@03ok74j?o0e>Wo`=CY00Go`=CY00Co_]K[
o`000?l0003o00004?ooool00ol0003oooooooooo`08ooooo`001_ooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`0Pooooo`?oY[o/0_nN
^nd3o`0000CoTK3/1On:ZNX7oiN`j@03ojk5j_nmc^Oo_LkW00Go_LkW0oo8e^@4olKIi`Ko_m;X1On]
an`00onQ_>coW;O[oibgj`04oibgj`OoWkS[0_nV_^/5ojNoj`koYKk[1onW_n/2ojS1j`KoZ<3[1_nW
_n/00onV_^_oY[o[ojJoj`05ojJoj`GoZ<3[2?nX`N/6ojNoj`03ojJnjonW_^[oYkkZ00GoYkkZ1_nY
_^T9ojW1jPkoY[o[1onX`>/7ojW1j`OoYl3[1onW_n/2ojW1j`_oZ/;[00?oZL;[ojS1jonX`N/01_nX
`N/2ojc2jPGo[lG[1_nbb>/00onabNcoY<3]ojC0k@05ojC0k@KoSJ_Y1?moWNH00ol0003oOigVohbU
iP05ohbUiPCoY[cY1?naa>P4ol3Dj@Co_]K[4_ooool00ol0003oooooooooo`08ooooo`001_ooool0
0ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2o`0002;ooooo00Co
W[_]o`000?l0003o00000_nN^nd6oi6`k0GoRZWZ1OnG/>T3ojVojPGo_LkW1_o8e^@00oo6fNOo_m;X
okoBj006okoBj003ojg7k?nQ_>coXKc/00?oXKc/1_nL]n/5oinhj`?oXkc[1_nW_n/>ojFnj`GoYko[
0_nX`N/8ojS0j`?oYko[0onV_^/8ojJoj`03ojS0jonX`N_oZ<7[00[oZ<7[0_nW_n/5ojJnj`OoYkkZ
0_nY_^T;ojW1jP03ojW2jonV_n_oY[o[00_oY[o[0_nW_n/6ojS0j`KoZL7[0_nX`N/7ojO0j`OoYko[
2OnZ`^/5ojW2j`KoZ<7[0_nY`N/7ojo5j`;o//S[1OnabN`7ojC0k@KoSJ_Y1?moWNH00ol0003oOigV
ohbUiP05ohbUiP03ojJljOnaa>So/LCX00Go/LCX00?o`=CYokkFjonne^/01Onne^/Aooooo`03o`00
0?oooooooooo00Sooooo0004ooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`03o`000?oooooooooo01oooooo0ol00006oijkk@KoTK3/1On:ZNX00onG/>WoZKoZ
ojVojP05ojVojP?o_LkW1_o8e^@3ol[Fh`Ko_m;X0_ngc>X6oj6lk0KoW;O[00?oWkS[oj>ljonS_>/0
1OnS_>/6ojNoj`koYKk[00?oYko[ojS1jonX`N/01?nX`N/6ojS0j`03ojO0jonV_^_oY[k[00GoY[k[
1_nV_n/2ojS0j`_oZ<7[0_nW`>/7ojJnj`GoYkkZ0_nW`>/9ojW1jPGoZL;[2OnV_n/6ojNoj`KoZ<3[
0_nY`N/6ojS1j`GoYl3[2OnW_n/7oj[2j`OoZL;[0_nX`N/6ojW1j`Go[lG[2OnabN`3ojC0k@?oV;?Z
1_n7XnH5oh:Lh`03o`000?nH[nOoV:oW00CoV:oW1onaa>P2ok_@jPKo_]K[0_njdn`@ooooo`03o`00
0?oooooooooo00Sooooo000Eooooo`03o`000?oooooooooo01cooooo0ol00004ooooo`KoW[_]0onA
/>`3ohZ/k0KoSZcZ1onY_nX00onmc^Oob=KTolSFi004olSFi0Gob]KS0_nod^P6okO<jPKoXKc/0onL
]n/4oibhk0OoXkc[0onW_n/3ojJoj`_oYKk[0onV_^/7ojS1j`;oZ<3[1OnW`>/7ojJnj`;oY[o[1_nX
`>/7ojS1j`KoYl3[1onV_^/00onW_^[oYl3[ojO0j`04ojO0j`KoZL7Z0_nY`n`6ojW2j`OoY[o[2?nW
_n/3ojS0j`?oZL7[2?nX`N/00onW`>_oYko[ojNoj`0;ojNoj`OoZ/;[1onY`^/8ojW1j`03ojo5jona
bNco/LW/00Wo/LW/00?o[LO]oiRcj_nH/nX01OnH/nX6ohNSiPGoPYcS00?o0000oiR_ionH[nL01?nH
[nL4ok74j0Go^m3Z0_nne^/6ok[Ck0oooooo00?o0000ooooooooool02?ooool001Gooooo00?o0000
ooooooooool06Oooool3o`0000Sooooo0onN^nd3oiBdk@KoRZc/1_n>[>X5ojVojP?o]/SX0oo8e^@6
ol[Fh`?oa]CU1ongc>X3oj6lk0CoW;W/1_nL^>`5oj>lj`SoY[o[1_nU_^/00onT_^_oY[k[ojJnj`05
ojJnj`GoZ<7[0onX`>/6ojO0j`GoY[k[0_nV_n/8ojS0j`KoZ<7[1onW`>/3ojJnj`CoYKo/1onW`>/2
ojW1jPKoZL?/1_nY`^/7ojJoj`OoYko[1onY`N/6ojS1j`03ojS0jonW_n_oYko[00_oYko[00?oZL7[
oj[2jonZ`^/01_nZ`^/7ojW2j`KoZL7[00?oZl?[ok79k?nabN`01onabN`5ojg7k@OoV;?Z1_n7XnH4
oh:Lh`03o`000?nH[nOoV:oW00GoV:oW00?o/LCXok_@j_nkd>X01?nkd>X00onoen_o^]?/ok[Ck005
ok[Ck003okK@kOoooooooooo00gooooo00?o0000ooooooooool02?ooool001Gooooo00?o0000oooo
ooooool05_ooool3o`0000gooooo1OnD]>d6ohZ/k0KoSZcZ00?oZKoZokK8j?nfb>P01Onfb>P00oo8
e^Cob]KSol[Fh`04ol[Fh`Goa]CU1Ongc>X00on[aNgoW;W/oibik006oibik0KoW;S/00?oXkc[ojJo
jonV_n/02_nV_n/2ojFnj`GoY;k[1onV_^/00onX`N_oZ<3[ojS0j`05ojS0j`KoYl3[00?oY[k[ojJo
jonV_n/01?nV_n/7ojS0j`OoZ<7[1OnW`>/9ojFok0GoYl3[0_nW`^d8ojW3k0?oZL;[0onX`N/7ojJo
j`OoYko[1onY`N/2ojS1j`GoZ<3[2OnW_n/5ojW1j`KoZ/;[00?oZ/;/ojW2jonY`^/01_nY`^/2ojW1
j`GoZl?[1_nabN`00onab^co[LO]ojg7k@05ojg7k@OoV;?Z1_n7XnH4oh:Lh`04o`000?nH[nOoV:oW
oiR_i`CoXkWY1Onkd>X3okoGj`Co^]?/1?nfd>d?ooooo`03o`000?oooooooooo00Oooooo000Doooo
o`;o00005Oooool3o`00017ooooo1OnD]>d6ohZ/k0?oSZcZ0onM]^T6okK8j0?o`/kS1?o:e^<7olKD
i@03okO<j_n[aNgoZlG]00?oZlG]2?nL^N`3oibhk0?oWk[/2onV_n/3ojFnj`KoY;k[1OnV_^/:ojS0
j`?oYl3[0onV_n`7ojJoj`OoZ<3[1onX`N/00onW`>_oYKo/ojFok00;ojFok003ojO0jonW`^goYl;]
00CoYl;]1_nY`n`00onX`^coZ<7[ojS1j`05ojS1j`OoY[o[1onW_n/5ojW1j`;oZL;/1onX`>/7ojNo
j`OoZL7[0_nZ`^/5oj[2k0KoZL;[00?oZ<7[oj_3jon[`n/01_n[`n/2ok79k0Go/L[/1on]and3oiRc
jP?oT:SV1_n4Vn85ohfRh`03o`000?nS^NWoXkWY00GoXkWY0onkd>X5okoGj`03ok[Ck?nfd>go]]3]
00Co]]3]3oooool00ol0003oooooooooo`07ooooo`005?ooool00ol0003oooooooooo`0Booooo`;o
00005Oooool5oiBdk@?oRZc/0_n7ZN`7oiffj@?o]/SX1oo2c^<00oo:e^?oa]CUolKDi@05olKDi@;o
`<oU1_n[aNd6oibik003oi^hkOnO^^coWk[/00GoWk[/1onV_n/7ojFnj`KoY;k[00?oY[k[ojS0jonX
`>/02onX`>/7ojJok0OoY[o[1onX`>/5ojS1j`;oZ<3[2_nU_n`4ojG0k@OoYl;]0_nY`n`5ojS2k0Oo
Z<7[1onV_n/7ojNoj`03ojW1jonY`^coZL;/00CoZL;/1OnX`>/2ojO0j`OoYko[1OnY`N/9oj[2k0;o
ZL;[1OnX`N/6oj_3j`03ojo8k?nab^co/L[/00Ko/L[/0on]and3oj:lk0OoT:SV1_n4Vn85ohfRh`03
o`000?nS^NWoXkWY00GoXkWY00?o^m3ZokoGjonoen/00onoen/2okgHk@Oo]]3]3_ooool00ol0003o
ooooooooo`07ooooo`005?ooool00ol0003oooooooooo`0?ooooo`?o00005oooool5ohj`k@KoQjW/
1onM]^T00onfb>So`/kSol;>h`05ol;>h`?obM;Q1?o6e>D5ol3?i@KoZlG]0_nL^N`5oi^hk@OoWk[/
1_nV_n/8ojFnj`?oY;k[0onU_^`>ojS0j`OoY[o/1onV_n/7ojS0j`03ojS1jonX`>_oZ<3[00CoZ<3[
1_nU_n`8ojG0k@GoYl;]0_nW`^`6ojS2k0KoZ<7[0_nW_^/7ojJoj`?oYko[0onX`N/8ojW2k003ojS0
jonW`>_oYl3[00CoYl3[1onW_n/00onY`N_oZ/;/oj[2k009oj[2k0;oZL;/1onX`N/2oj_3j`Go[lS/
1_nab^`2ok3:k@KoX[c/1_n@Z>H6ohBKhPGoSJ;S00?o0000oj>ijOnS^NT01?nS^NT2ok35jP?o_mO[
1Onmf>d5okK@k@;o[/W^3Oooool00ol0003oooooooooo`07ooooo`005?ooool00ol0003ooooooooo
o`0<ooooo`?o00006oooool5ohj`k@KoQjW/1OnM]^T3ojg1j@Go`/kS1_o9d^400oo6e>Go`<oUol3?
i@05ol3?i@?oZlG]1?nQ_Nd6oi^hk@GoWk[/0_nS_>/6ojJoj`KoYKk[2?nU_^`>ojS0j`GoY[o/0_nU
_n`7ojJoj`koZ<3[1_nU_n`8ojG0k@03ojO2kOnW`^coYl;/00CoYl;/1_nX`^`2ojS1j`KoYkk[1OnV
_n/2ojNoj`KoZ<7[1_nY`^`2ojS1j`OoYl3[0onW_n/3ojS0j`WoZ/;/1_nY`^`5ojS1j`;oZL;[1on_
b>`2ok7:k0Ko/<[]1_nR_>`5oi2XiPKoQ9_R1_n=X^<00ol0003oXkWYoj>ij@06ok35jP03okoGjonm
f>go_MS]00Go_MS]00?o]]3]ojk9k_n^bNh01?n^bNh<ooooo`03o`000?oooooooooo00Oooooo000C
ooooo`?o00002_ooool3o`0001oooooo1On>/>d6ohNYk003oiffjOn]`NWo[L7Y00Go[L7Y0oo2c^<6
olWBh@;ob]7O1_o0cnD3ok[;i`KoXKg]1_nK^>d00onO^^coXkc[oj>lj`04oj>lj`KoY[o[0_nU_^/<
ojFnk0koZ<3[00?oY[o/ojFok?nU_n`01?nU_n`5ojJoj`03ojO0jonX`>_oZ<3[00goZ<3[1_nU_n`6
ojG0k@;oY/3/1onW`^`3ojS2k0?oYko[2?nW_^/00onV_n_oYko[ojNoj`04ojNoj`KoZ<7[0_nY`^`6
ojS1j`GoYl3[00?oYko[ojS0jonX`>/01OnX`>/6oj[2k003oj[3k?nY`^coZL;/00KoZL;/00?oZ<7[
ojW2jonY`^/01?nY`^/5ojo8k0;o/<_]2?n`b^d3oj:lk0;oUZcV1?n9Wn82oi2XiPKoQ9_R0on=X^<3
oiZ`i`03o`000?n`aN[o/<GZ00Co/<GZ0_nke>d6okgHk@;o^MC^1on^bNh;ooooo`03o`000?oooooo
oooo00Oooooo000Dooooo`03o`000?oooooooooo00Kooooo0ol0000Sooooo`GoS[3]0on7ZN`4ohf^
k0Oo[L7Y00?o`/kSolWBhOo9d^401?o9d^44ol[Ag`?o`<oU1_njbnL6oj6mk@?oVkS]0onK^Nd7oj>l
j`?oY[o[1?nV_n`:ojFnk0?oYKo[2_nX`>/4ojO0j`OoYKo/00?oY[o[ojO0jonW`>/00onW`>/?ojS0
j`KoYKo/0_nU`>d6ojK0k0GoYl;/2?nW_n/6ojNnj`WoYko[0onX`N/3ojW2k0SoZ<7[00?oYl3[ojNo
jonW_n/00onW_n/7ojS0j`;oZ/;/1OnZ`n`6ojW2k003ojS1jonY`^_oZL;[00KoZL;[00?o[lS/ok3;
kOn`bnd01?n`bnd6ok3:k@03ojS2k?nF[>KoUZcV00CoUZcV1On9Wn86ohNLh0KoV[3W00?o0000ok35
j_n`aNX00_n`aNX5ok_Dk@;o_MS]1_nie>h3ojk9kP?oZ<;/2oooool00ol0003oooooooooo`07oooo
o`005?ooool00ol0003oooooooooo`03ooooo`?o00009oooool6ohJ]k`KoSJk/1On]`NT3okO6iP?o
bM;Q1oo:dMl00oo0cnGo^/_Wok[;i`06ok[;i`?oXKg]0onL^nh6oi^ik@GoXkc[0_nU_^/7ojJok0Go
YKk/00?oY;k/ojFojonU_n/01OnU_n/8ojS0j`KoYl3[1onU_n`6ojO0j`ooZ<3[0onU_n`3ojNoj`So
Y/3/00?oYl;/ojNojonW_n/02_nW_n/2ojNnj`_oYko[0_nX`^`6ojW2k0KoZ<7[2?nW_n/5ojS0j`;o
ZL?/1onZ`n`2ojW2k0GoZ<7[1_nY`^/00on]ango/<_]ok3;k@06ok3;k@;o/<[]1OnX`^`6oiJ/iPGo
RIoR1_n7W>06oiZ`i`03o`000?n`aN[o^mC]00Go^mC]00?o_]_^okWDk_nie>h01Onie>h00onbcnoo
Z<;/ojS2k005ojS2k0_ooooo00?o0000ooooooooool01_ooool001?ooooo00Co0000oooooooooooo
oooo0ol0000[ooooo`KoQZg_1_n=[^`00on]`NWo]lKVokO6iP05okO6iP03olWBhOo:dMoob]7O00Go
b]7O0oo7d>06ok[;i`;o//OZ1_nL^nh6oi^ik@03oj>ljonU_^_oYKk[00CoYKk[1onV_n`00onU_^co
Y;k/ojBnk003ojBnk0OoYKo[2?nX`>/6ojO0j`OoYKo/1_nW`>/=ojS0j`;oZL3Z1_nW_n/6ojK0k0;o
YkoZ5_nW_n/6ojS2k0KoZL;/0_nX`N/<ojNoj`03ojS0jonY`ncoZL?/00CoZL?/1OnZ`n`2ojW2k0Oo
Z<7[0_nY`^/5ojg7k@Ko/<_]00?o/<_^ojS2k?nX`^`01OnX`^`6oiJ/iPKoRIoR1_n7W>03oiZ`i`?o
Y[cY00?o0000ok_DkOnke>d00_nke>d4okkKkPCo^MC^1?nbcnl7ojS2k0[ooooo00?o0000oooooooo
ool01_ooool001?ooooo1?l0000_ooooo`KoQZg_0on=[^`3oi^fj`Ko]lKV0oo0bN44ol[Ag`Ooam3P
00?o^/_Wok;7j_nbanX01?nbanX6oibkkP?oVkW]0onL^^d7ojFnj`GoY[o/0_nU_n`6ojBnk0GoYKo[
0_nV_n/8ojS0j`KoYl3[1onU_n`3ojO0j`?oYl3/2OnX`>/6ojW0jPKoYko[0_nV`>`6ojNojPGoYko[
00?oYkoZojNojonW_n/02_nW_n/2ojO1k0SoZ<;/0onY`^`3ojS0j`[oYko[0onW`>/8ojW3k003oj[3
k?nY`^coZL;/00CoZL;/1OnX`N/2ojS1k0Oo[LO]0_n`bnd5ok3;kPOoZ<;/1_nF[>H6ohVOhP?oQicP
0_nCYn<7ojJlj@03o`000?nke>go_]_^00Ko_]_^00?o^MC^ok;?konbcnl01Onbcnl3ojS2k0?oYko[
2_ooool00ol0003oooooooooo`06ooooo`004oooool2o`0003;ooooo0on6[Nl2oh>[k`OoVkK[0ong
a^H7ol39h@03ol[Agoo7d>3oam3P00Goam3P0_o4cN47ok;7jP?oW;_^0onJ^^h6oibjk@OoYKk[00?o
Y[o/ojFok?nU_n`01?nU_n`6ojBnk003ojFojonV_n_oY[o[00CoY[o[2?nX`>/6ojO0j`OoYKo/1_nW
`>`8ojS0j`OoZL3Z0onW_n/3ojRojPSoYkoZ00?oYko[ojNoj_nW_nX00onW_nX8ojNoj`KoYl7/1_nX
`^`00onX`NcoZ<3[ojS0j`05ojS0j`OoYko[1_nW`>/7ojW3k0SoZL;/00?oZ<7[ojS1k?nX`N`01?nX
`N`5ojg7k@;o[l_^1on`bnh3ojS2k0?oVZkU1_n>XN46ohRJgPKoTjOS1_nV_>T00ol0003o]Lo]okkK
kP05okkKkP;o^]S_1_nbcnl00onZa>coYko[ojNoj`05ojNoj`Wooooo00?o0000ooooooooool01_oo
ool000Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000ooooooooool0<?oo
ool5oh>[k`OoVkK[00?o]lKVol39hOo0bN401Oo0bN42olK<gPKoam3P1?o4cN45ok;7jP;oZl?/1_nJ
^^h6oibjk@?oYKk[1?nV_n/7ojFok0?oY;k/0onT_n`7ojJoj`SoZ<3[1_nW`>/7ojFok0KoYl3/2?nX
`>/5ojW0jP;oZ<3[1_nX_nX6ojNojP03ojRoj_nW_n[oYkoZ00GoYkoZ1OnW_n/2ojO0k0OoYl7/0_nX
`^`5ojS1k0OoZ<3[1onW_n/6ojO0j`OoZL?/1_nY`^`00onX`N_oZ<7/ojS1k006ojS1k003ojg7kOn_
bnko[l_^00Co[l_^1On`bnh00onZ`ncoVZkUoiZ^i@05oiZ^i@KoSZ7Q1_n8V]h6oi>Wh`?oY[cY0one
cnd01?l0003o]Lo]okkKk_nnfnh6ok[Hk`;o//o_1OnZa>`7ojNoj`Sooooo00?o0000ooooooooool0
1_ooool00005oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Wo
oooo00?o0000ooooooooool0<?ooool5oh>[k`GoVkK[0onX_^T5ol39h@Coa/cN0oo7d>07olC=h@03
ok;7j_n[`ncoZl?/00CoZl?/1_nJ^^h3oibjk@CoW[_]1_nV_n/7ojFok0KoY;o/1OnV_n/3ojNoj`Oo
Z<3[1_nW`>/7ojFok0?oYl3/0onV`>`8ojS0j`03ojW0j_nX`>_oZ<3[00CoZ<3[1_nX_nX2ojNojPGo
Z;oZ1onW_nX00onW_n_oYl3/ojO0k004ojO0k0GoYl7/0_nX`^`6ojS1k0KoZ<3[2OnW_n/3ojO0j`[o
ZL?/0_nY`^`5ojS1j`KoZ<7/00?o[<S^ojo;k_n_bnh01_n_bnh00on`bnkoZ/?/oj[3k003oj[3k0Ko
VZkU1_n>XN46ohRJgPOoTjOS00?oY[cYokG?kOnecnd00onecnd00ol0003o_M__ok[Hk`05ok[Hk`03
okGBkonZa>coZ/C/00GoZ/C/1_nW_n/00onW`>_oooooooooo`06ooooo`03o`000?oooooooooo00Ko
oooo00001?ooooooV9RHob4Q8Oo^k^h4ooooo`05oa0@4?ooooooooooooooool@41002_ooool00ol0
003oooooooooo`0`ooooo`GoPj__00?oVkK[ojRnjOnX_^T01OnX_^T3ol39h@Koa/cN00?oam3PolC=
hOo4cN401Oo4cN42ol3:hPOoZl?/0onJ^^h3oiVjk`OoW[_]1_nV_n/7ojFok0KoY;o/00?oY[o[ojNo
jonW_n/01OnW_n/7ojS0j`KoYl3[1onU_n`6ojK0k0KoZ<3[0_nX`N`7ojS0j`?oZ;oZ0onX`>/7ojRo
jP?oYkoZ0onW`>/8ojO0k003ojO1k?nX`^coZ<;/00CoZ<;/1_nX`N`2ojS0j`_oYko[00?oZ<7/ojW3
k?nY`n`02_nY`n`2ojW2k0OoZ<7[0_nX`N`5ojc8kPKo[l_^00?o[lc^oj[3k?nZ`n`01OnZ`n`6oiZ^
i@KoSZ7Q1_n8V]h3oi>Wh`CoXKOX0onecnd3okgKk`03o`000?nmfnoo^]S_00;o^]S_1?ned^l7oj[4
k0;oYko[1OnW`>/7ooooo`03o`000?oooooooooo00Kooooo0002ooooo`03oiRHV?lQ8B7ok^k^00?o
oooo00Go0000ooooooooooooooooo`00000;ooooo`;o0000<Oooool6ohN]k`OoZ;kY00?o`<WQolK<
g_o6c=h01?o6c=h3olW<g0Coa<gQ1Oo0b^85oj_3k0;oYL3]1_nI^^l7oijkk@KoY[o[1onU_n`6ojBo
k0SoYko[1onX`>/6ojO0j`OoYKo/1_nV`>`2ojS0j`KoZ<7/1OnX`>/00onX`NcoZ<3[ojS0j`05ojS0
j`GoZ;oZ0_nW`N`6ojO0j`KoYl3/2OnX`^`3ojS1k0?oYl3[2OnW_n/5ojS1k0SoZL?/1_nY`^`5ojS1
j`;oZ<;/1on/b>h2ojo;kPGo[lc^1onZ`n`3oiZ^i@;oTZ;O1_n;VM`6oi6Rh0SoXKOX00?o]Lo]okgK
konmfnl00_nmfnl01?l0003o_M__okgKkonjf>l6okGBk`?oZ/C/0onW_n/8ojO0j`Oooooo00?o0000
ooooooooool01Oooool000?ooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo
000000gooooo00?o0000ooooooooool0;oooool6ohN]k`GoZ;kY0_na`nL5olK<gPKobLcL00?oa<gQ
ol3:h_o0b^801Oo0b^800on[`ncoYL3]ojG0k@04ojG0k@KoVK[_1OnN^nd2oinmkPKoY[o[1onU_n`6
ojBok0KoYko[0_nW`>`7ojS0j`KoYl3[1onU_n`6ojK0k0SoZ<7/00?oZ<3[ojS1k?nX`N`00onX`N`7
ojS0j`03ojRoj_nW`NcoYl7/00CoYl7/1_nW`>/2ojO0k0_oZ<;/2?nW`>/7ojNoj`OoZ<7/1onY`n`7
ojW2k003ojS1jonX`^coZ<;/00CoZ<;/1On/b>h3ojo<k`Ko[lc^0onZ`n`3oib]i0KoTZ;O1_n;VM`6
oi6Rh0KoXKOX0_n`bnd5okgKk`03o`000?njf_3o^][`00Go]M;_0_n/a^d6ojNoj`KoYl3[00?oZ<3[
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`001?ooool01Ol0003ooooooooooooooooo
410@00?ooooo00?o410@ooooooooool03?ooool00ol0003oooooooooo`0_ooooo`KoQjg_00?oZ;kY
ok73iona`nL01?na`nL3olK<gPKobLcL0_o9bm/6ol3:hP?o_/OR1_nU`>d6oiVjk`03oijkkOnO_Nko
Wkg^00CoWkg^1_nV_n/7ojFok0KoY;o/0_nW_n/6ojO0k0OoZ<3[1_nW`>/5ojFok0;oY[o/1_nV`>`6
ojS1k003ojK1k?nX`NcoZ<7/00GoZ<7/1OnX`>/9ojO1k0?oYl3[1?nW`^d8ojS2k0coYl3[1onW_n/5
ojS1k0;oZL?]1onY`n`3ojW2k0?oZ<7/2?nX`^`00on/b>ko[lc_ojo<k`05ojo<k`?o[lc^0onY`N/6
oib]i0KoTZ;O1_n;VM`5oi6Rh0CoXKOX1On`bnd2okgKk`?o^][`00Co0000ok[Jl?njf_3o]M;_1_n/
a^d6ojNoj`;oYl3[1OnX`>/6ooooo`03o`000?oooooooooo00Gooooo00001Ol0003o^[ZjoooooonH
V9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0?ooooo`03o`000?oooooooooo02oooooo
0on7[Nl3oi2ckPOo/L?W00?oa/cNolW<g?o9c=`01?o9c=`4olW;f`?o`<[R1_nnan86ojG0k@?oVK[_
0onI^nl7oinmkP?oY[o[0onV_n`7ojFok0?oY;o/0onT_nd8ojO0k0OoZ<3[1_nW`>/00onU_ncoY[o/
ojJok004ojJok0KoY/3/0_nX`N`5ojK1k0OoZ<7/00?oZ<3[ojO1k?nW`N`02OnW`N`2ojO1k@OoYl;]
0onX`^`>ojO0j`[oYko[00?oZ<7/ojW3kOnY`nd01?nY`nd5ojW3k0;oZ<;/1_nX`N`6ojS2k0;o[L[_
1_n_c>l00on^bnooZL7[ojW1j`05ojW1j`GoW:gT1_nBX]l6oh^Ig0KoTJ;P00?oXKOXok3;kOn`bnd0
1?n`bnd00onjg?7o^][`ok[Jl004ok[Jl003o`000?nee?3o[<K]00Oo[<K]0onW_n/2ojO0j`SoZ<3[
1Oooool00ol0003oooooooooo`05ooooo`0000GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h04?ooool2o`00033ooooo1_n@/nh5ok73i`?o^<GT1?o9c=`6olW;f`03
ol3:h_nnan;o_/OR00Ko_/OR0onU`>d3oj6nkPKoVK__1OnO_Nh2oj2nkPKoY[o/1onU_n`6ojBok@Ko
Yl3/0_nV`>`7ojS0j`?oYl3[0onX_n/7ojJok0?oY/3/0onV_n`7ojK1k0?oZ<7/1OnV`Nd7ojO1k0Ko
Yl7]1OnW`^d>ojO0j`goYko[0_nX`nd7ojW3k@03ojW3k?nX`^coZ<;/00CoZ<;/1_nX`N`2ojS2k0Ko
[L[_0_n_c>l5ojk;k`OoZL7[1OnL[N@6oi:Rg`KoRiWL0onAX^04oindi`?o/<_]1?njg?44ok[Jl004
okGDl?l0003o]MC`okGDl0Ko[<K]00?oYko[ojO0jonW`>/01?nW`>/6ojS0j`03ojW2k?oooooooooo
00?ooooo00?o0000ooooooooool01Oooool001oooooo00?o0000ooooooooool0;_ooool6oi2ckP03
ok73ionhaNCo^<GT00Ko^<GT00?obLcLolW;foo9bm/01?o9bm/3olS9fPKo_/OR0_nkaN86oj6nkPKo
VK__00?oWkg^oj2nk_nP_^h01?nP_^h6ojJok0OoYKo/1_nT_nd2ojO0k0KoY/3/1_nX`>/7ojRoj`Go
Y[o/0_nW_n/6ojJok0GoY/7/0_nV`>`8ojK1k@KoYl7/1onW`Nd00onW`^goYl3[ojO0j`0<ojO0j`go
Yko[1_nX`nd5ojW3k@WoZ<;/0onX`N`4ojS4k@Go[L[_0_n]cO07ojk;k`?oZL7[0onLZ^45oiBQg@Ko
SIWJ1_nAX=h8oindi`03ok3;kOnjg?7o^]ca00Co^]ca00?o^][`okGDl?nee?000_nee?000ol0003o
]MC`okGDl002ojc6k@GoYko[1_nW`>/2ojS0j`GoZL;/1?ooool00ol0003oooooooooo`05ooooo`00
8?ooool00ol0003oooooooooo`0^ooooo`?oT;?^1?nJ^>d6okS5i0;o_/KQ1Oo9bm/5olS9fP?o_/OR
1OnkaN86oj6nkP?oVK__0onI^o07oj2nkP?oY[o/0onV`>`7ojFok0OoY;o]1onV`>`6ojS0j`OoZ;o[
00?oY[o/ojNojonW_n/01?nW_n/6ojJok003ojK1k?nV`>coY/3/00CoY/3/1_nV`Nd00onV`>coYl7/
ojO1k005ojO1k0GoYl7]3?nW`>/=ojNoj`?oYl;/2?nX`nd00onY`ngoZ<;/ojS2k009ojS2k003ojS1
k?nXa>goZ<C]00KoZ<C]00?o[L[_ojg=l?n]cO001?n]cO05ojk;k`03ojNjionLZ^7oW:[Q00GoW:[Q
1OnDXMd6ohfIfPKoTJ3N1_nO]>L2ojk:kPGo^]ca0_nig?45okGDl003o`000?n/angoYko[00OoYko[
1OnW`>/8ojW2k0?ooooo00?o0000ooooooooool01Oooool0027ooooo00?o0000ooooooooool0;ooo
ool6oiZhk@?o^<GT1Onna^43olW;f`Oob<WJ00?o_/ORok_5h_nkaN801OnkaN83oj6nkP?oX;k^1_nI
^o07oj2nkPKoY/3/1onU_n`7ojBok@GoY/3/0_nU`>d6ojS0j`GoZ;o[0_nX`>/7ojNoj`?oY[o/0onW
_n/7ojK0k0;oY/7]1OnV`>`7ojO1k003ojO1kOnW`>_oYl3[00WoYl3[3OnW_n/2ojO1k0KoYl;/1onX
`nd9ojS2k0GoZ<7/1_nXa>d00on]c?3o[Lg`ojg=l006ojg=l003ojk;konW^^OoYk[W00?oYk[W1_nL
Z^46oiBQg@GoSIWJ1onAX=h2oindi`Ko[/[^00?o^]caokWLlOnig?401?nig?42okGDl0;o[<O]00?o
0000ojc7kOn/and01_nW_n/7ojO0j`KoZL;/00?oZ<7/ooooooooool00_ooool00ol0003ooooooooo
o`04ooooo`008_ooool00ol0003oooooooooo`0_ooooo`KoV[S]00?o^<GTokk6hOnna^401Onna^40
0oo9bm_ob<WJolS9fP05olS9fP;oalOJ1_nkaN82ok[4hPKoX;k^1_nI^o07oj2nkPKoY/3/1onU_n`7
ojBok@03ojK0k?nU`>goYL3]00CoYL3]1_nX`>/00onX_n_oZ<3[ojS0j`04ojS0j`GoYko[0_nX_n/6
ojNoj`GoY/3/0_nW_n/7ojK0k0?oYl7/0onW_n/9ojO0j`goYko[1_nW`N`6ojO2k0OoZ<?]1_nX`^`8
ojS1k0;oZ<C]1On]c?06ojg=l003ojc7k_nW^^OoYk[W00GoYk[W1OnLZ^46oiBQg@KoSIWJ0onAX=h3
oindi`Oo[/[^0_nigO85okWLl@;o]=Ca1?n/and00ol0003o[<O]ojc7k@02ojNoj`_oYl3[0_nY`^`5
ojS1k0?ooooo00?o0000ooooooooool01?ooool002?ooooo0_l0000`ooooo`?oV[S]0onR_>`6okk6
h@?o`LKN1?o8bMX5olO7fP?o^lGR1Onja>86oj2nkP?oVK_`1?nI_?06oj2nkPKoY/3/1onU_n`7ojBo
k@OoYL3]0onX`>/4ojS1k0KoZ<3[00?oYko[ojRojonX_n/01?nX_n/6ojNoj`03ojK0k?nW_n_oYko[
00CoYko[1OnV`>`8ojNoj`KoYl3[3?nW_n/:ojO1k0?oYl;/2_nX`nd2ojS2k0[oZ<7/0_nZb?07ojg<
l0;o[Lg`1On/anh7ojNji`GoW:[Q1_nDXMd3ohfIfP;oTj;N1onO]>L4ojk:kPGo^Mgb00?o^McaokCD
lOnde?401?nde?43ojc7k@03ojNojol0003oYko[00_oYl3[0onY`^`7ojS1k0;ooooo00?o0000oooo
ooooool01?ooool002Gooooo00?o0000ooooooooool0;Oooool7oj:lk0?o_/KQ1_o1a]h00oo8bM[o
alOJolO7fP06olO7fP03ok_5h_nja>;o^/CR00Go^/CR0onP_^h4oj2mkPKoVKc`0onP_^h3oinok`Ko
Y/3/1onU_n`7ojBok@GoYL3]0_nT`>d7ojS1k0?oZ<3[0onX`N/7ojRoj`goYko[00?oY/3/ojNojonW
_n/02_nW_n/2ojO0j`_oYko[3OnW`N`<ojS3k@?oZ<;/2?nX`N`6oj[8l0So[Lc`1_n/anh3ojNji`?o
VjKM1OnEW]T6oi2If@KoTj;N1onO]>L00on^b^ko^MgbokWMlP04okWMlP;o^=cc1Onde?42ojc6k@Co
Yko[00?o0000ojNojonW`>/01_nW`>/7ojW2k0?oZ<7/0onW_n/2ooooo`03o`000?oooooooooo00Co
oooo000Vooooo`03o`000?oooooooooo02gooooo1onR_>`00onna^7o`LKNol76gP04ol76gP?o`lGL
1_o7amX3olK5f@Go^/CR0_nj`^07oj2mkP?oVKc`0onH_O46oinok`KoY/3/1onU_n`7ojBok@03ojG0
kOnT`>goY<3]00CoY<3]1OnX`N`2ojK1k@KoZ<7[1OnX_n/2ojS0j`_oYko[0_nX_n/:ojNoj`?oZ;o[
2OnW_n/=ojO1k0_oZ<?]2?nX`^`5ojS1k0?oZ<G^1_nZb?08ojg<l0?o[<O^0_nR/>87oi^Vg@GoUIkI
1_n@VMT6oi>RgPGoWkCW0_n]c?04okWMlPGo^=cc00?o]=Caojc6kOn/a^d01?n/a^d3ojNoj`03o`00
0?nW_n_oYko[00OoYl3[1OnY`^`2ojS1k0KoYko[00?oooooo`000?ooool01Oooool002Oooooo00?o
0000ooooooooool0;Oooool5oj:lk0;oYkkZ1Oo1a]h5ol?5g0?oalOJ1_o6aMT00onja>;o^/;Pok[2
h004ok[2h0GoX;g^0_nQ_N`6oiRml@KoWko_1_nV`>`7ojFok0?oY;o]1OnU`>d6ojC0k@03ojS1k?nV
`NgoY/7]00CoY/7]1_nX`N/00onX_n_oZ<3[ojS0j`04ojS0j`OoYko[1_nX_n/5ojNoj`;oZ<3[1_nX
_n/5ojNoj`coYl7/0onW`nd9ojS3k@coZ<;/00?oZ<7/ojS5k_nXaNh01OnXaNh3oj[8l0?o[<ga1_n]
c?000onY_NSoX[3Roj:`hP04oj:`hPKoVjKM1_nEW]T5oi2If@OoTj;N00?oWkCWojg<l?n]c?001?n]
c?000onigO;o^=ccokSLl`04okSLl`03ok;DlOn/a^go[<K]00Ko[<K]0onW_n/00ol0003oYl3[ojO0
j`07ojO0j`03ojW2k?nX`NcoZ<7/00CoZ<7/1_nW_n/00ol0003oooooooooo`04ooooo`00:?ooool2
o`0002kooooo00?oX[c/ojNnj_nW_^X01?nW_^X3ol76gPOo`lGL00?oalOJolK5fOo6aMT01?o6aMT2
olG3f0Oo^/;P00?oX;g^oj6mk?nQ_N`01?nQ_N`6oiRml@?oWko_0onM_o06ojK0k0GoYKo/0onV_n`7
ojG0k@KoY<3]1onV`Nd3ojS1j`?oYl7/1onX`>/3ojNoj`CoZ<3[1_nX_n/00onW_n_oZ<3[ojS0j`04
ojS0j`KoZ;o[00?oYko[ojO1k?nW`N`02OnW`N`8ojO3k@KoZ<?]00?oZ<;]ojS2k?nX`^`02?nX`^`4
ojO2k0KoZ<G^00?oZlcaojc=lOn/cO401On/cO42ojg<l0GoZKgX1_nR/>85oi^Vg@KoUIkI1_n@VMT3
oi>RgPCoXKOX1On]c?02okOOm0Co^=cc1?nbe?46ojc6k@03ojNojonW`>_oYl3[00;oYl3[00?o0000
ojO0jonW`>/01OnW`>/00onX`^coZ<7/ojS1k006ojS1k0?oYko[0_ooool00ol0003oooooooooo`04
ooooo`00:_ooool00ol0003oooooooooo`0/ooooo`OoYkkZ00?o`LKNol?5g?o3aM`01Oo3aM`2ol?5
f`Goa/GI1?o5`mP5ok[2h0;o^/3N1onQ_N`6oiRml@KoWKo`1_nV`>`00onU_ncoY[o/ojJok005ojJo
k0GoYL3]0_nU`>`6ojC0k@GoY/7]0_nU`Nd6ojO1k0GoZ<3[0_nW`^d7ojS0j`?oZ;o[0onX`N`7ojS0
j`?oZ;o[0onW`^`8ojO1k0coYl?]0_nX`nd5ojS2k@GoZ<;/0_nW`N`7ojO2k0;oZ<G^1On[c?45ojc=
l@;oZlO^1_nY_NP7oj:`hPGoVjKM1_nEW]T3oi2If@;oV:KP2?nQ]nP00on]c?3o]modokOOm004okOO
m003okSLlonbe?7o/]Ca00Go/]Ca0_n/a^d5ojNoj`CoYl3[00Co0000ojO0jonW`>_oYl3[1OnX`^`6
ojS1k0Oooooo00?o0000ooooooooool00oooool002_ooooo00?o0000ooooooooool0;?ooool5ojNn
jP?oZl3Y1Oo3aM`4ol?5f`?oa/GI1_o5`mP00onj`^3o^/3Nok[0gP04ok[0gPGoXKg/0onU_>X5oiRm
l@KoWKo`0onV`>`4ojG2kPOoY[o/00?oYL3]ojG0k?nU`>`01?nU`>`6ojC0k@03ojK1kOnU`NgoYL7]
00CoYL7]1_nW`N`00onX`>_oYl;]ojO2k@04ojO2k@GoZ<3[0_nW`^d6ojS1k0GoZ<3[0_nW`^d6ojO2
k0GoYl7/3?nW`nd4ojO2k@KoZ<;]00?oZ<;/ojO1k?nW`N`01?nW`N`5ojO2k0;oZL_b1on[c?400on/
cO7oZlO^oj_7kP04oj_7kPKoZKgX0onR/>83oi^Pf0GoUI_F1_nCVmP6oiRVh0KoXKOX0_n_do<5okOO
m0?o]M_c1Onbe?400onZa>goYko[ojNoj`06ojNoj`?oYl3[00?o0000ojO0jonX`^`01onX`^`2ojS1
k0[ooooo00?o0000ooooooooool00oooool002cooooo00?o0000ooooooooool0;?ooool00onW_^[o
Zl3Yoj_0j@05oj_0j@?o`lGL1_o3aM/00oo6aMWoaL?HolG3f004olG3f003olG1e_nj`=ko^/3N00Ko
^/3N00?oXKg/ojFlj_nU_>X01OnU_>X5oiRml@?oWKo`0onJ_o87ojG2kP?oY[o/0onV`>`8ojG0k0?o
Y<3]0onU`>d7ojG1k@?oYl7/0onU`Nd7ojO2k@03ojS0jonW`^goYl;]00CoYl;]1_nX`N`00onX`>_o
Yl;]ojO2k@04ojO2k@KoYl;/00?oYl7/ojO3kOnW`nd02OnW`nd9ojO2k@?oZ<;]0onX`N`7ojO1k003
ojO2k?nYbo;oZL_b00CoZL_b1On[c?42oj_;l@OoZlO^0onY_NP2oinWg0OoVj3H1OnEVmH6oi>Kf0Ko
V:KP0_nQ]nP6ojoCl`03okOOm?nefo?o]M_c00Go]M_c00?o/]Caoj[4kOnZa>d00onZa>d6ojNoj`Go
Yl3[00?o0000ojO0jonX`^`01OnX`^`=ooooo`03o`000?oooooooooo00?ooooo000]ooooo`;o0000
;_ooool7oj_0j@03ol?5g?o3aM_o`lGK00Co`lGK0_o3a=X5olG3f0?oaL7F1_nj`=h3ok^og0OoYKcZ
0_nH_O44oiVml@GoV[ob1OnU`^h2oj;2l0KoY/3/1_nU`>`00onV`>coYL3]ojG0k@05ojG0k@goYL7]
1OnW`^d00onU`^goYl;]ojO2k@06ojO2k@?oZ<7/0_nV`^h8ojO2k@?oYl;/1?nV`^d7ojO3k@_oYl;]
00?oYl7/ojS1k?nX`N`01OnX`N`5ojO1k0;oYlWa1onYbo800on[c?7oZl_aoj_;l@04oj_;l@?oZlO^
0onS[]l6oinWg0KoVj3H1_nEVmH5oi>Kf0GoV:KP0onT_N/5ojoCl`;o]^7e1_nefo<2ok7@l0KoZ/C]
0_nW_n/9ojO0j`04o`000?nW`>_oZ<;/ojS2k13ooooo00?o0000ooooooooool00oooool002oooooo
00?o0000ooooooooool0;?ooool5oj_0j@;o[L;Y1Oo3aM/4ol?4fP?oaL?H1Oo5`MH3ok[0gPKo^koL
1OnU_>X2ojZliPKoVKga1OnJ_o800onU`^koX/;`oj;2l004oj;2l0KoY/3/0_nU`>`5ojK0k0OoYL3]
3OnU`Nd00onW`^goYL;]ojG2k@03ojG2k@KoYl;]00?oYL;]ojK2k_nV`^h01?nV`^h6ojO2k@WoY/;]
0onW`nd;ojO2k@GoYl7/1onX`N`00onW`NcoYlWaojO9l@04ojO9l@?oZL_b1?nYcO85oj_;l@03ojRg
honS[]ooXjkO00GoXjkO1_nOYm`5oi^Pf0KoUI_F1_nCVmP00onHY^3oY;g[ojBmj`05ojBmj`03ojoC
lonfhOGo]^7e00Co]^7e0_nefo<6ok7@l0?oZ/C]0_nW_n/;ojO0j`03o`000?oooooooooo017ooooo
00?o0000ooooooooool00oooool0033ooooo00?o0000ooooooooool0;?ooool00on[`>Wo[L;Yojg2
j@04ojg2j@?o`lGK1_o3a=X00oo5`mSoaL7FolG1eP05olG1eP03ok[0g_nk_mco^koL00Ko^koL00?o
YKcZojZli_nZ_>H01?nZ_>H6oiVml@;oV[ob1?nI`?<6oj;2l0?oY/3/0onV`^h7ojK0k0?oYL3]1?nU
`>`=ojG1k@KoYL;]0_nW`^d5ojG2k@KoY/;^0_nW`^d;ojK2k@_oYl;]2_nW`N`3ojS1k0CoYlO`1OnW
bO42ojS=l`OoZLgb00?oZl_aojRghonX]n<00onX]n<6oj>^g`KoWjOL1_nKX=P6oiFKeP?oTi_H0_nM
[n@7ojBmj`;o/Mcf1OnfhOD2ok;Im0Ko/M3`00?oZL;/ojNojonW_n/01?nW_n/6ojO0j`Gooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`03ooooo`00<Oooool00ol0003oooooooooo`0]
ooooo`Ko[L;Y00?o`lGKol?4f_o3a=X01?o3a=X2ol;3f`KoaL7F0oo5_mD6ok^og0;o_;cI1onZ_>H3
oiVml@CoW;g_1_nI`?<2oj;2l0?oWL;b1_nV`^h5ojK0k0;oY/7/1onU`>`3ojG1k@?oY/3/1onU`Nd3
ojG2k@?oYL7]1onU`^d3ojK2kPCoY/7]2?nV`^d:ojO2k@goYl7/0_nWa_07ojO7l003ojO9lOnXcO?o
Z<gc00CoZ<gc1OnYcO82ojVnj0KoZ;OS1_nS[]l6oinWg0?oVj3H0_nGVmH6oiNQg0KoWJoT1?nT_N/5
ok7LmP03okKQmOnbfOCo/]Wd00Co/]Wd0_nad?05ojW2k0KoYko[0_nW`>/9ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool00oooool003;ooooo0_l0000^ooooo`Oo[L;Y0oo3a=X5ol;3
f`?oaL7F1_o5_mD3ok^og0Go_;cI1OnZ_>H2ok2kh@OoW;g_0onI`?<3oiVol`GoWL;b1_nV`^h00onV
`>coY/7/ojK1k004ojK1k0GoYL3/0_nV`N`6ojK0k0GoYL7]0_nV`>`6ojG1k@GoYL;]2OnV`Nd3ojK2
k@CoYl7/1onW`^d=ojO1k0KoYlK`1OnWao03ojO=l`KoZ<gc00?oZLgbojVnj?nY_^P01?nY_^P6ojRg
h`?oXjkO0_nNWmD6oiZKe0KoUi_F1_nGXM`6oif_i003ojBmjonag?Ko/Mcf00Co/Mcf0_ndgoH5ok;I
m0;o[L[_1onY`^`3ojNoj`kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02oooo
o`00=?ooool00ol0003oooooooooo`0/ooooo`Oo[L;Y00?o`lCJol;3foo2`m/01Oo2`m/00oo5`MKo
aKoEolFoe@06olFoe@03ok^og?nl_=Wo_;cI00Go_;cI00?oZ[cVok2khOn`^n401?n`^n45oibmk`;o
X[WZ1_nI_o<5oig2lP?oY/;^1?nRa?46ojK1k003ojG0k?nV`NcoY/7/00CoY/7/1_nV`>`00onU`Ngo
Y/3/ojK0k004ojK0k0KoYL7]00?oYL;]ojK1kOnV`Nd02OnV`Nd2ojK1k0OoYl7/0onW`^d=ojO1k0[o
YlK`00?oYlO`ojO=lonWcO<01OnWcO<3ojS=l`;oZL?/2?nY_^P3ojRgh`;oX:?G1_nNWmD6oiZKe0Go
Ui_F1onGXM`3oif_i0CoYl[b0_nag?H6okCOmP03ok;Im?n]b^oo[L[_00Co[L[_1OnY`^`Booooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool003Gooooo00?o0000ooooooooool0
;?ooool5ojg2j@;oZl?[1_o2`m/3ol33g0KoaKoE0_o5_]@6okblf@;o_[[F1on`^n400onL_NooX[WZ
oj:ijP04oj:ijPKoVKoc0_nM`_84oi[2l`KoX/Ca0onV`N`3ojG5l0OoY/7/0onV`>`4ojK1k0KoY/3/
0onU`Nd4ojK0k0OoY/7]1_nV`N`5ojO1k0;oYl;]2onW`N`2ojK7l@[oYlK`0onVc?<6ojO=l`03ojW6
konY`ncoZL?/00CoZL?/1_nY_^P00onSYmWoX:?Goj2Se`04oj2Se`KoWYoE1OnJVm@5oiNKePKoUj7L
00?oX[WYojO:l_nWb_801?nWb_83ok7Rn0Go]=of0_n`eO<7ojg:k`03ojW2k?oooooooooo01Cooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`00=_ooool00ol0003ooooooooo
o`0/ooooo`03ojg2jOn[`n_oZl?[00CoZl?[0oo2`m/6ol33g0?oaKoE1Oo5_]@3okblf@Go_[[F1On`
^n42okJif`OoX[WZ0onI_o<3oi^nl0KoV/;c0onRa?43oic3l`KoYLG`1OnV`N`2ojK5k`OoY/7/0onV
`>`3ojO1k@OoY/3/0onV`Nd4ojO1k0KoY/7/00?oYl7/ojO2kOnW`^d01?nW`^d7ojO1k0KoY/Oa1OnW
a_02ojG<m0KoY/cc0_nWcO<5ojW6k`KoZL?/0_nY_^P5oj>Wf@GoX:?G1_nNWmD5oiZKe0KoUi_F0_nG
XM`5oj:ij@?oYl[b1_nah_P00ondgoKo/=Gcok3El`04ok3El`?o[L[_6oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00;ooooo000gooooo`;o0000;_ooool6oj_3j`03ol;3foo0`mco
`<?L00Ko`<?L00?oaKoEolFne?o5_]@01Oo5_]@00onl_=Wo_[[FokjjeP05okjjeP03ok2khOnf^M_o
][WK00Co][WK1OnR^NX2oj^hhPKoVkk`0onJ`_<3oi[1l`KoW<?c1_nUaO000onV`NcoY/G_ojK5k`04
ojK5k`GoY/7/0_nVaO06ojO1k@GoY/3/0_nW`nh7ojO1k0?oY/7/0onWa>l7ojO2k@?oYl7/0onVb?87
ojK7l@03ojO6l?nUc?CoYLcd00CoYLcd0onVc?<4ojS7l0KoZLK_0onY`n`2ojFZf`OoXjOI1OnPXmL7
oijOe@GoVY_D0onGVmH3oij^hPOoX[WY00?oYl[bok7Rn?nah_P01?nah_P2ok3KmPGo/=Gc8?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo000iooooo`03o`000?oooooooooo
02cooooo1?n[`n/3ojO3kPKo`<?L00?o_L?NolFne?o5_]@01Oo5_]@2olBne0Ko_[[F0_o0^M<7okJi
f`03oj:ij_n[^>;oZkSR00CoZkSR1?nK__02oj:hj@KoV/7c1_nL`o<3ojG5l0CoWlGc1_nVaNl00onV
`NcoY/G`ojK5l004ojK5l0KoYl7]00?oY/3/ojO3k_nW`nh01?nW`nh5ojO1k003ojG7lOnWa>ooYlC_
00GoYlC_1OnW`^d00onUb_?oY/SbojK8lP05ojK8lP?oY/Oa1?nTc?@5ojG<m0;oYlK`1onXao03ojW6
k`;oYZcL1_nUZ]/6oj>Wf@KoX:?G0onNWmD3oi^NePGoVZ?K1onN[^85oj:ij@?o[=[g0_nah_P6ok3K
mP03ok3Elooooooooooo027ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`02oooo
o`00>_ooool00ol0003oooooooooo`0/ooooo`03oj_3jonW`nkoYl?^00CoYl?^0oo0`m`4okg3gPGo
aKkD1?o4_]@3okjjePGo`;WC1Onf^M/2okZfePOoZkSR00?oVkk`oj:hjOnR^>T00onR^>T6oi[1l`?o
W<?c1?nK`o@6oio5l`?oY/G_1?nPa_<6ojK5l0?oYl7]1?nUao86ojO3kP03ojO1k?nUao7oYLOa00?o
YLOa1onWa>l00onW`^goYL[cojG:l`03ojG:l`GoY/Sb0onSbo@6ojC<m003ojG<m?nWa_3oYlK`00Co
YlK`1OnXao000onW[]coYZcLojJ/g004ojJ/g0KoYJ[K1_nSYmT3oj2Se`;oWIcC1onKW]H5oiZSf`Oo
WZkR00?oX[WYojcJmon/f_L00on/f_L2ok3Qm`Ko/=_f9_ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00;ooooo000kooooo`03o`000?oooooooooo02cooooo1onW`nh00oo0`mco_L?N
okg3gP04okg3gP?oaKkD1_o4_]@00onn^]Ko`;WCol2id`05ol2id`03okJifonj]]Ko^[KF00Co^[KF
1On[^>82ok>ff`KoX[SY0onJ`O<4oiflkPKoVl?d0onOaO<4oi_5m0KoX<Kc0onVaO04oio7m0KoYLOb
0onW`nh3oj;9l`KoYLOa0onWa>l4oj;9m0KoYL[c00?oY/Sboj?;m?nSbo@01OnSbo@3ojC<m0CoY/G_
1_nWa_000onXao3oYjkLojN^g003ojN^g0KoYZcL1_nUZ]/3oj>Wf@;oWigB1_nMW=<6oi^NePKoVZ?K
0onN[^85ojK;l`03ojcJmon`hOOo/>7g00Co/>7g0_n`foHZooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool00Oooool003cooooo00?o0000ooooooooool0;?ooool5ojO3kP;oXL?a1onm
`mh00oo5_]Coa;kDolBne004olBne003ol?0eoo0^M?o`;WC00Go`;WC00?o`[WBokZfe_nj]]H01_nj
]]H00on[^>;o/kKKok>ff`04ok>ff`CoX[SY0_n/]=l7oiflkP?oVl?d0onM__07oi_5m0?oX<Kc0onL
a_D7oio7m0?oYLOb0_nNb?D7oj;9l`?oYLOa1?nPbOD6oj;9m0?oYL[c1?nRb_@5oj?;m003ojG2kOnV
aNooY/G_00KoY/G_0onWa_08ojN^g0OoYZcL0onUZ]/2oj:Nd@KoWigB1_nMW=<6oi^NeP?oVZ?K1?nT
_N`5ojK;l`;o[>;i1On`hOL^ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00Ooo
ool003gooooo0_l0000]ooooo`03ojO3k_nQ`o7oXL?a00CoXL?a1Onm`mh2okS3h`Goa;kD0oo3`=L5
ol2id`?o`[WB1_nj]]H2okfedPOo/kKK00?oX[SYojbdgon/]=l00on/]=l5oiflkP;oYkCR1_nM__05
oi_5m0;oWKo`1_nLa_D5oio7m003oik6m?nNb?GoW/Se00CoW/Se1OnRbO<3oio8m@KoX<We0onRbO@4
oj;8m0KoX/[d00?oXl_dojG2kOnU`^d00onU`^d6ojK5k`03ojN]fonW[]coYjkL00[oYjkL0onV[=`3
oj>Pd@KoXYkA1_nOWM85oifLd`GoVikF00?oX[CVojBmk?nT_N`01_nT_N`00onVbo?o[>;iojcRn@04
ojcRn@03ok3Qmooooooooooo02oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`01
ooooo`00?oooool00ol0003oooooooooo`0/ooooo`KoXL?a00?o_L?NokS3honh`n<01?nh`n<3olBn
e0Go`l3G0oo0^M<5ol:idP?o^[KF1Onm]M85ok>ff`03okRbe?n/]=oo[;CO00Go[;CO00?oWKc^ojNd
h_nW]>801?nW]>86oifnl003oi_5m?nM_o3oWKo`00CoWKo`1_nLa_D00onOaoCoW/Kdoik6m003oik6
m0KoW/Se00?oX/Wcoio8mOnOb?D01OnOb?D3oj39m@CoX/Ca1_nRb?@3oj;:m0?oY[cY1_nU`^d2ojK5
k`GoYjgK2_nW[]`00onUXM7oXj3Aoj>Pd@05oj>Pd@GoXYkA1_nOWM86oifLd`03oi^Ne_nR]>KoX[CV
00?oX[CV1_nT_N`2ojWNnPGo[>;i=?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
007ooooo0010ooooo`03o`000?oooooooooo02cooooo0onQ`o43oiK2mPOo^<?S00?oa;kDol?0eoo3
`=L01Oo3`=L00oo0^M?o`[WBol:idP05ol:idP03okZfe_nm]M;o_KGB00Go_KGB00?o/kKKokRbe?nh
/]@00onh/]@5ojbdg`;o];;F1onW]>83oifnl0CoYK?R1_nM_o03oic6m@?oWkk^1_nNa_@3oik8m@Co
Wl?b1OnOb?D2oj>kjPOoX/Ca0onRb?@2ojJfi0OoY[cY0onU`^d2ojR/f@OoYjgK1onW[]`5ojFQd@Ko
Xj3A1OnRW]47oinMdP?oWIcC0_nP[N07oj:diP;oY;g/1_nYg_X00on/h_Woooooooooo`0fooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool00Oooool0047ooooo00?o0000ooooooooool0
;Oooool5oiK2mPGo^<?S0_nbaNP6ol?0e`03okk1g?o2^M;o`[WB00Go`[WB00?o`[cEokfed_nm]M80
1Onm]M800ono]]7o^;;DokRbe005okRbe003ojbdgond/]Ko];;F00Co];;F1OnW]>82ok:ae`OoYK?R
0onM_o04ojJbh@GoWkk^0onNa_@4oj>ij@KoWl?b00?oWlSeoj>kj_nS^nX01?nS^nX5oj;4l@03ojN_
g_nV]^CoY[KT00CoY[KT1OnV_>T00onYZ]OoZ:cIojR/f@04ojR/f@OoYjgK0onW[]`2ojJQd@OoYJ7A
1OnSX=46oj:Nd@?oWigB0onPZ=`6oj2]h0GoX[CV0onUe_P5ojWNnS[ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`01ooooo`00@_ooool2o`0002kooooo1OnF`_H00onh`n?o//GXok;5
j004ok;5j0?o`l3G1?nn`M`5ol:idP?o`[cE1Onm]M83oknfd@Go^;;D00?o^k;@okBbe_nd/]H01_nd
/]H00onW]>;o/[7Gok:ae`04ok:ae`GoYK?R00?o/JoGojJbhOnV/^401_nV/^42oinnkP?oZ;3M1onS
^NT3oio3lP?oY[;Q1onS^nX00onRa?7oYjoNojN_gP03ojN_gPKoY[KT00?oY[cYojVZeonYZ]L00onY
Z]L6ojR/f@GoYjgK00?oYj;@ojJQdOnVXM401?nVXM46ojFQd@KoXj3A0onRW]42oj6Uf0OoX:SL1_nP
[N000onR]>KoYMKhojGFn005ojGFn003ojWNn_oooooooooo03cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`01ooooo`00A?ooool00ol0003oooooooooo`0/ooooo`KoR<3j1_nbaNP0
0oo3`=Oo_/7Lokk1g004okk1g0?o`[WB1Oo2_=D3okfedPCo_kKA0onh/]@4ok^bd0Ko];;F00?o^:o@
ok:aeonb/ML01_nb/ML00onU/n;o/JoGok6_e`03ok6_e`KoY[;Q00?o/:gDojR`gOnX/=d01?nX/=d5
oj>ij@03ojb]f?nV/^7oY[;Q00GoY[;Q1OnS^nX00on[[=SoYjoNojN_gP04ojN_gPGoY[KT00?oZZOD
ojVZeonYZ]L01OnYZ]L6ojR/f@03ojN]fonWX]3oYj;@00?oYj;@1_nVXM46ojFQd@?oXj3A0_nSY=H6
oj6Uf0OoX:SL0onP[N03ojC<m0KoYMKh@Oooool00ol0003oooooooooo`07ooooo`7o00000Oooool1
ooooo`00AOooool00ol0003oooooooooo`0/ooooo`KoR<3j0onbaNP3ojS8l0Oo_/7L00?o`[WBol:l
eOo2_=D01Oo2_=D00onm]M;o_kKAoknfd@04oknfd@03okRbe?nk/]3o^k;@00Co^k;@0ond/]H4okR_
d0Ko/[7G00?o]Zg@ok6_eona[mL01Ona[mL3ojJbh@Co/:gD1_nX/=d00onS^NWo[:gHojb]f003ojb]
f0OoY[;Q00?oXk_Zoj^/f?n[[=P00on[[=P6ojN_gP03ojJfi?nZYmCoZZOD00?oZZOD1onYZ]L3ojR/
f@;oZ:;?1onWX]06ojJQd@?oYJ7A0_nUXm@6oj>TePKoXJGH1OnPZ=`2ojG5l0KoY<cd0_nUe_Q5oooo
o`03o`000?oooooooooo00Kooooo0Ol00001ooooo`7ooooo0016ooooo`03o`000?oooooooooo02co
oooo0on8`?X3ogVln`KoZ<S`1Onn`M`2okO4i0Ko`[cE00?o_/3KoknfdOno]]401Ono]]48ok^bd003
okBbe_nh[m3o^:o@00Co^:o@0onb/ML4okJ]d0Oo/JoG00?oY[;Qok2]e?n`[M@00on`[M@5ojR`g@03
ok2Zd_n/[MSo[:gH00Go[:gH1OnV/^400on]ZM?oZjcHoj^/f004oj^/f0GoYjoN00?o[:GAojZWe?nZ
Ym@01OnZYm@5ojVZe`03ojVRconXX/ooZ:;?00CoZ:;?1_nWX]05ojJQd@03ojJTe?nUXmCoYJ?D00Co
YJ?D1_nSY=H6oj6Uf003oj2Xg?nUaO3oYLG`00CoYLG`0onTc?A9ooooo`03o`000?oooooooooo00Ko
oooo0Ol00001ooooo`7ooooo0017ooooo`;o0000;_ooool5ogVln`KoZ<S`00?o_/7LokO4i?nga>@0
1?nga>@3ol:le@Co_/3K1Ono]]42ol6lePKo^k;@00?o_[OBokR_d?nh[m001_nh[m000onb/MOo]Zg@
okJ]d004okJ]d0Go/JoG00?o]:_?ok2]e?n`[M@01On`[M@00onX/=go/:[Bok2ZdP03ok2ZdPOo[:gH
00?oY[;QojfYdon]ZM<00on]ZM<6oj^/f003ojN_g_n/YM7o[:GA00?o[:GA1onZYm@00onYZ]OoZJ;?
ojVRc`03ojVRc`KoZ:;?1_nWX]000onVXM7oYZCDojJTe003ojJTe0GoYJ?D1onSY=H3oj6Uf0?oYKo/
1OnUaO1>ooooo`03o`000?oooooooooo00Gooooo0Ol00001ooooo`7ooooo0019ooooo`03o`000?oo
oooooooo02cooooo1Omi_?/3ojS8l0?oU/Oh1onga>@00oo2_=Go_/3Kokk0f`04okk0f`?o_kKA1?o1
_=H3ok^bd0Co_[OB1_nh[m000onl/m7o]Zg@okJ]d006okJ]d003ok6_eondZloo]:_?00?o]:_?1On`
[M@00ondZ/ko/:[Bok2ZdP05ok2ZdPGo[:gH00?o/:O?ojfYdon]ZM<01?n]ZM<5oj^/f003ojfUcon/
YM7o[:GA00Go[:GA1OnZYm@00on/XlkoZJ;?ojVRc`05ojVRc`KoZ:;?0onWX]02ojRVe0KoYZCD1_nU
Xm@3oj>TeP?oY[cY1onU_n`00onUaO3oooooooooo`1@ooooo`03o`000?oooooooooo00Cooooo0Ol0
0001ooooo`7ooooo001:ooooo`03o`000?oooooooooo02gooooo1Ome^O/5oiK7n0Go]lCT0_n/b^l7
okk0f`03oknfdOo1_=Ko`KcF00Co`KcF00?o^k;@okjgd_nn]m801?nn]m83okR_d0Co_;?A1_nf[M00
0onk/M3o]:_?okB[c`04okB[c`?o/:gD1?ndZ/h7ok2ZdP03ojb]f?n`Yloo/:O?00?o/:O?1_n]ZM<0
0on[[=So[JG?ojfUc`03ojfUc`Oo[:GA00?oZZODojbSc_n/Xlh00on/Xlh6ojVRc`GoZ:;?00?oZZWE
ojRVe?nXY]@01?nXY]@5ojJTe0GoYJ?D0_nW^^L6ojJlj@GoYKo/EOooool00ol0003oooooooooo`03
ooooo`7o00000Oooool1ooooo`00Boooool00ol0003oooooooooo`0]ooooo`GoMKWk1OnFaoP00ong
a>Co[<[_ojc:k`04ojc:k`Go_/3K00?o]LGVol6le_o1_=H01?o1_=H00onj`Moo_[OBokjgdP06okjg
dP03okR_d?nl/m7o_;?A00Co_;?A0onf[M04ok^ad0Ko]:_?00?o/:gDokBZc_ndZ/h01?ndZ/h5ok2Z
dP03okBZc_n`Yloo/:O?00Co/:O?1On]ZM<00onaYlko[JG?ojfUc`05ojfUc`Go[:GA00?o[ZO@ojbS
c_n/Xlh01On/Xlh6ojVRc`03ojRRconZZMGoZZWE00?oZZWE1OnXY]@6ojJTe003ojFSe?nW^^OoYk[W
00CoYk[W1_nV_>T00onU_ncoooooooooo`1Fooooo`03o`000?oooooooooo00?ooooo0Ol00001oooo
o`7ooooo001<ooooo`;o0000;oooool5ogZkn`GoO/;m1_n/b^l00onn`=_o]LGVokG5iP03okG5iP?o
`KcF1?nj`Ml6okjgdP03okbog?nl/m7o_;?A00Ko_;?A00?o]Zg@ok^ad?nk/M000onk/M05okB[c`03
okVadOndZ/ko]:[>00Ko]:[>00?o/:[BokBZc_ndZ/h00ondZ/h6ok2Wc`03ojfYdonaYlko/JO>00?o
/JO>1on]YLl00on/YM7o[ZO@ojjWd003ojjWd0Ko[:?>1OnYX/l00on/[MSoZZWEojZYe@04ojZYe@Ko
Z:KD0onVY=@3ojRki`OoYk[W0onV_>ULooooo`03o`000?oooooooooo00?ooooo0Ol00001ooooo`00
C_ooool00ol0003oooooooooo`0^ooooo`CoN[_k1Omn`_d3ojc:k`CoUl_j1OneaNH00oo1_=Ko^/7O
ok[1g`04ok[1g`?o_[OB1?nl_m`6okbcd@03ok^mfonk/M3o^k7@00Co^k7@0ondZll4okVad@Ko]:[>
00?o^;?DokBZc_ndZ/h01OndZ/h4ok2Wc`03okB^d_naYlko/JO>00Go/JO>1On]YLl00ona[MCo[ZO@
ojjWd005ojjWd0Ko[:?>00?oZJ;?ojb]f?n/[MP00on/[MP5ojZYe@GoZ:KD0_nX_NP6ojRki`GoYk[W
HOooool00ol0003oooooooooo`02ooooo`7o00000Oooool004oooooo00?o0000ooooooooool0;ooo
ool4ohJmn@GoMKcl1_nGboX2okG5iP?oYlgd1onj`Ml00onn]m;o_;oLokbog004okbog0?o_;?A1?nk
_M/6ok^ad003okB[coni/M7o^K7A00Co^K7A0ondZ/h4okRce0Oo]:[>00?o/:O?okB^d_nd[]800_nd
[]87ok6WcP03ojfUcona[MCo/JgD00?o/JgD1_n^Ym05ojbScP03ojjcfon/[MSo[:gH00Co[:gH1_nZ
ZMD00onXY]CoZ;gXojRmj004ojRmj0KoZ;_W00?oYk[Wooooooooool0Hoooool01Ol0003ooooooooo
oooooooo0000007ooooo001@ooooo`03o`000?oooooooooo02oooooo1?n6_OT5ogFlo0?oUl_j1?mk
`oh4ojO=m0Go^/7O0_n^bnl7okbog003okbcdOnk_M_o^kgK00Co^kgK1?nk/M02okZmg0Oo^K7A00?o
]:[>okRce?nh/m@01?nh/m@5okBZcP03okNhf_nd[];o]:kB00Co]:kB1OnaYlh00onc]][o/JgDok6]
e005ok6]e0Ko[ZO@00?o[:?>ojjcfon^/m/00on^/m/6ojb]f0?oZZWE0onY`N/7ojRmj0?oZ;_WJ?oo
ool01Ol0003ooooooooooooooooo0000007ooooo001Aooooo`;o0000<?ooool5oi6lm0KoO;gk1Omk
`oh4ojO=m003ok[1gon^bnoo[/__00Co[/__1Onl_m`2ok39k0Oo^kgK00?o^k7@okZmg?nj_M`00onj
_M`5okVad@03okNngonh/mCo^;?D00Go^;?D0ondZ/h4okNhfPGo]:kB0onaYlh4ok>ffPKo/JgD1On^
Ym000on_^N7o[[?Kojjcf`04ojjcf`Go[:gH0_nYa^h6ojW1j`GoZ;gXKOooool01?l0003ooooooooo
ool00001ooooo`00Doooool00ol0003oooooooooo`0^ooooo`GoTKcd0oml_O/4ohZnn0GoMkkm1?n8
b_d6ojk;k`03okbog?n`bNco/<W/00Co/<W/1Onk_M/00on`bNco^[gLokZmg005okZmg003okVadOng
_]oo]kkO00?o]kkO1onh/m@00ondZ/ko]kSJokNhfP03okNhfPKo]:kB00?o/JO>ok>ff_nc]]X01?nc
]]X6ok6]e003ojjWd?n_^N7o[kWQ00?o[kWQ1_n^/m/00on/[MSoZLK^ojW6kP04ojW6kPKoZL7[00?o
Z;gXooooooooool0Koooool00ol0003oooooo`000001ooooo`00E?ooool00ol0003oooooooooo`0^
ooooo`;oTKcd1?nN_Nl6ohZnn0GoMkkm1?n8b_d3ojk;k`CoT/ol1_n`bN`00onk_M_o/<W/ok39k003
ok39k0Go^[gL0_n^c>l6okNng`Go^;?D00?o//;VokNhf_ng^=X01Ong^=X3okB^dP?o/KkS1onc]]X3
ok6]e0;o[L7X1on_^N43ojjcf`CoYlgd1_nYa^h3ojW1jgCooooo00?o0000ooooool000000Oooool0
05Gooooo00?o0000ooooooooool0;_ooool6oijmk`?oR[kh1?nH_O44ohG1n`KoMl;n1OnBco`3ok39
k0CoU]7l1On`bN`00onj_Mco[/c_ojk<k`04ojk<k`Ko]kkO00?o^;?Dok;2i_nb`^H00onb`^H5okNh
fP;o[<_`1_na_^<5ok>ffP03oj[<l_n]`NSo[L7X00Co[L7X1On_^N43oj;Dn@KoYlgd0onYa^ijoooo
o`7o00000Oooool1o`000000E_ooool2o`0002oooooo0onN_Nl3ojJoj`OoV;ga1?n5`O/3ogO2oPCo
P/;l1OmiaOh6oiKAo0;o/<W/1?nDd_d6ojk<k`?o]kkO0onXd?D6ok;2iP03okNhf_n/bo3o[<_`00Co
[<_`1_na_^<00onc]][oZ/cboj[<lP03oj[<lPKo[L7X00?o[kWQoj;DnOnRe?T01OnRe?T3ojO=m83o
oooo0_l0000005Sooooo00?o0000ooooooooool0;Oooool6ojJoj`GoV;ga0_nT_^`5oiBml`KoP/;l
1OmiaOh3oiKAo0?oNlSo1_nDd_d3ojk<k`CoSM?n1OnXd?D3ok;2iPCoWMKk1_n/bo03ok6nh`?oWmKk
1_nZc?83ojg1j0GoV=Wn0onRe?V4ooooo`?o0000001Iooooo`03o`000?oooooooooo02gooooo1_nV
_n/00onH_O7oY;k/ojBnk004ojBnk0GoU;gc0on2`_`4oi:om@KoP/?m1?mkb?l3oiCBo@CoO<Wo1_n=
doh2ojS@m@CoQ=7o1_nMe_/3ojc;l0?oRmGo1_nOe_/3oj[<lPGoRmOo0onHfOj5ooooo`Co00000ooo
ool005[ooooo00?o0000ooooooooool0;Oooool3ojJoj`CoZ<3[1_nT_^`2oiBml`CoX[k]1_nB_oD3
oh;3o@?oTl3e1_n4aOd5ogc9o`?oSM?n1?mnbOl5ohCAo`?oWMKk1On2col4oh_Eo`?oWmKk1On6dol3
oh_GohOooooo0ol00007ooooo`00Foooool00ol0003oooooooooo`0]ooooo`OoZ<3[0onT_^`3ojS0
j`KoX[k]0onB_oD4oj6nk@GoTl3e0on4aOd4oiK0m0KoRLOl0_mnbOl4oi76nPKoQL[n0on2col3oi3;
o0KoQlkn0on6don8ooooo`Co00002_ooool005cooooo0_l0000^ooooo`GoZ<3[0_nW`>/6ojS0j`?o
X[k]1?nX`>/6oj6nk@;oTl3e1?nR_^d6oiK0m0?oRLOl0onJ_o86oi76nP?oQL[n0onHa?H6oi3;o0?o
QlknROooool4o`0000kooooo001Nooooo`03o`000?oooooooooo02cooooo00?oZ<3[ojO0jonW`>/0
1?nW`>/4ojS0j`;oYl3[1onX`>/3oj6nk@;oZ<3[1onR_^d3oiK0m0?oY;k/1_nJ_o83oi76nPCoWko_
1OnHa?H3oi3;o8[ooooo1?l0000Booooo`00Goooool00ol0003oooooooooo`0]ooooo`KoYl3[00?o
Z<3[ojO0jonW`>/00onW`>/5ojS0j`;oYl3[1OnX`>/5oj:nk@;oZ<3[1_nT_^`3oiZolP?oY[o[1onO
_nl2oiS4mX_ooooo1?l0000Fooooo`00H?ooool00ol0003oooooooooo`0]ooooo`?oYl3[1?nW`N`5
ojO0j`03ojS0jonW`>_oYl3[00CoYl3[1OnX`>/00onR_^goZ<3[ojS0j`04ojS0j`CoY;k/0_nX`>/6
ojJoj`GoWko_Roooool3o`0001[ooooo001Qooooo`;o0000;oooool6ojO1k0;oYl3[1?nW`N`6ojO0
j`;oZ<3[1?nW`>/6ojS0j`03ojBnk?nX`>_oZ<3[00?oZ<3[1_nV_n/00onO_nooooooooooo`28oooo
o`Co00007Oooool006?ooooo00?o0000ooooooooool0;Oooool3ojO1k0;oY/3/1onW`N`3ojO0j`?o
Yl7/1_nW`>/3ojS0j`?oYl3[1_nX`>/3ojJojhWooooo1?l0000Qooooo`00I?ooool00ol0003ooooo
ooooo`0]ooooo`GoY/3/1OnW`N`2ojK0k0KoYl7/0onW`>/3ojO1k0KoYl3[0onX`>^:ooooo`Co0000
9Oooool006Gooooo00?o0000ooooooooool0;Oooool5ojK0k003ojO1k?nV`>coY/3/00CoY/3/1?nW
`N`2ojK0k0KoYl7/1?nW`>^:ooooo`Co0000:Oooool006Kooooo0_l0000^ooooo`;oY/3/1?nW_n/6
ojK0k003ojO1k?nV`>coY/3/00?oY/3/1_nW`N`00onW`>_oooooooooo`27ooooo`?o0000;Oooool0
06Sooooo00?o0000ooooooooool0;?ooool6ojNoj`?oY/3/0onW_n/6ojK0k0?oYl7/R?ooool4o`00
033ooooo001Yooooo`03o`000?oooooooooo02cooooo0onW_n/4ojRojPGoYko[0onV`>b9ooooo`Co
0000=?ooool006[ooooo00?o0000ooooooooool0;?ooool7ojRojP;oYko[R_ooool4o`0003Sooooo
001[ooooo`;o0000;Oooool5ojRojXWooooo1?l0000looooo`00KOooool00ol0003oooooooooo`0[
ooooo`03ojRoj_oooooooooo08Oooooo0ol00010ooooo`00K_ooool00ol0003oooooooooo`0Zoooo
o`03o`000?oooooooooo08?ooooo1?l00013ooooo`00Koooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo07oooooo1?l00017ooooo`00L?ooool2o`0002Wooooo00?o0000ooooooooool0
Noooool4o`0004_ooooo001booooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0Mooo
ool4o`0004oooooo001cooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0M?ooool3
o`0005?ooooo001dooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0L?ooool4o`00
05Kooooo001eooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0K?ooool4o`0005[o
oooo001fooooo`;o00008oooool00ol0003oooooooooo`1Xooooo`Co0000G_ooool007Sooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`1Tooooo`Co0000H_ooool007Wooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`1Qooooo`?o0000I_ooool007[ooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`1Mooooo`Co0000JOooool007_ooooo0_l0000Nooooo`03
o`000?oooooooooo05Wooooo1?l0001]ooooo`00OOooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo05Gooooo1?l0001aooooo`00O_ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo057ooooo1?l0001eooooo`00Ooooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo04kooooo0ol0001iooooo`00P?ooool2o`0001Wooooo00?o0000ooooooooool0B_ooool4o`00
07cooooo0022ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0A_ooool4o`00083o
oooo0023ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0@_ooool4o`0008Cooooo
0024ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0?_ooool4o`0008Sooooo0025
ooooo`;o00004oooool00ol0003oooooooooo`0looooo`?o0000S?ooool008Oooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0hooooo`Co0000Soooool008Sooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0dooooo`Co0000Toooool008Wooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0`ooooo`Co0000Uoooool008[ooooo0_l0000>ooooo`03o`000?oo
oooooooo02cooooo1?l0002Kooooo`00S?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo02Wooooo0ol0002Oooooo`00SOooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
02Gooooo1?l0002Rooooo`00S_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo027o
oooo1?l0002Vooooo`00Soooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01gooooo
1?l0002Zooooo`00T?ooool2o`0000Sooooo00?o0000ooooooooool06Oooool4o`000:kooooo002B
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05_ooool3o`000;;ooooo002Coooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04_ooool4o`000;Gooooo002Dooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool03_ooool4o`000;Wooooo002Eooooo`;o0000
0oooool00ol0003oooooooooo`0:ooooo`Co0000_Oooool009Oooooo00Co0000oooooooooooo0000
2?ooool4o`000<7ooooo002Hooooo`03o`000?oooooo000000Gooooo0ol00035ooooo`00VOooool2
o`000003ooooool0003o000000;o0000b?ooool009[ooooo0_l0003<ooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0538698, 0.0432538, \
0.0035044, 0.0035044}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[.12586 .2075 -12 -8.99448 ]
[.12586 .2075 0 .00552 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.56094 .0364 -5.16972 -9 ]
[.56094 .0364 .83028 0 ]
[.75679 .08071 0 -6.17777 ]
[.75679 .08071 12 2.82223 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.9429 .3657 0 -5.9083 ]
[.9429 .3657 6 3.0917 ]
[.02494 .25992 -18 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.01611 .31527 -18 -2.78472 ]
[.01611 .31527 0 6.21528 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00254 .43215 -12 -2.88407 ]
[-0.00254 .43215 0 6.11593 ]
[-0.0124 .49393 -12 -2.93688 ]
[-0.0124 .49393 0 6.06312 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
[(-2)] .12586 .2075 1 .99877 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.56863 .04703 m
.57247 .05235 L
s
[(2)] .56094 .0364 .72324 1 Mshowa
.125 Mabswid
.18558 .19702 m
.18832 .19985 L
s
.23703 .17687 m
.23971 .17975 L
s
.28951 .15632 m
.29214 .15925 L
s
.39772 .11395 m
.40023 .11699 L
s
.4535 .09211 m
.45595 .0952 L
s
.51046 .06981 m
.51284 .07294 L
s
.08568 .23614 m
.08851 .23887 L
s
.62804 .02377 m
.63027 .02701 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.7445 .0853 m
.73835 .08759 L
s
[(-2)] .75679 .08071 -1 .37284 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.93037 .36962 m
.92411 .37158 L
s
[(2)] .9429 .3657 -1 .31296 Mshowa
.125 Mabswid
.7708 .12553 m
.7671 .12688 L
s
.79613 .16428 m
.79242 .1656 L
s
.82054 .20161 m
.81682 .20291 L
s
.86679 .27235 m
.86305 .2736 L
s
.88871 .30589 m
.88497 .30711 L
s
.9099 .3383 m
.90615 .3395 L
s
.71716 .04348 m
.71349 .04489 L
s
.95018 .39992 m
.94642 .40107 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(-20)] .02494 .25992 1 -0.39157 Mshowa
.02837 .31059 m
.0345 .30825 L
s
[(-10)] .01611 .31527 1 -0.38117 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.00981 .42772 m
.01599 .4255 L
s
[(10)] -0.00254 .43215 1 -0.3591 Mshowa
0 .48963 m
.0062 .48748 L
s
[(20)] -0.0124 .49393 1 -0.34736 Mshowa
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.656 .749 .919 r
.39362 .6947 .40169 .70182 .4152 .69794 .40717 .69087 Mtetra
.652 .751 .922 r
.40717 .69087 .4152 .69794 .42878 .69412 .42079 .68714 Mtetra
.651 .754 .925 r
.42079 .68714 .42878 .69412 .44242 .69039 .43447 .68342 Mtetra
.659 .757 .923 r
.43447 .68342 .44242 .69039 .45614 .68668 .44824 .6794 Mtetra
.656 .749 .918 r
.44824 .6794 .45614 .68668 .46992 .68274 .46207 .67547 Mtetra
.644 .747 .924 r
.46207 .67547 .46992 .68274 .48378 .67876 .47596 .67193 Mtetra
.625 .755 .94 r
.47596 .67193 .48378 .67876 .4977 .67503 .48993 .66887 Mtetra
.586 .764 .964 r
.48993 .66887 .4977 .67503 .5117 .67167 .50396 .66663 Mtetra
.541 .786 .988 r
.50396 .66663 .5117 .67167 .52577 .66867 .51809 .6648 Mtetra
.514 .815 1 r
.51809 .6648 .52577 .66867 .53992 .6664 .5323 .66274 Mtetra
.537 .831 .999 r
.5323 .66274 .53992 .6664 .55417 .66419 .5466 .66013 Mtetra
.582 .835 .993 r
.5466 .66013 .55417 .66419 .5685 .66175 .56098 .65691 Mtetra
.626 .823 .976 r
.56098 .65691 .5685 .66175 .58291 .65892 .57544 .65307 Mtetra
.666 .802 .948 r
.57544 .65307 .58291 .65892 .59739 .6557 .58995 .64839 Mtetra
.681 .766 .915 r
.58995 .64839 .59739 .6557 .61196 .65213 .60453 .64329 Mtetra
.679 .729 .887 r
.60453 .64329 .61196 .65213 .62659 .64827 .61918 .63818 Mtetra
.674 .701 .867 r
.61918 .63818 .62659 .64827 .6413 .64422 .6339 .63319 Mtetra
.667 .682 .855 r
.6339 .63319 .6413 .64422 .65608 .64007 .6487 .62841 Mtetra
.66 .669 .848 r
.6487 .62841 .65608 .64007 .67094 .63588 .66358 .62389 Mtetra
.654 .662 .845 r
.66358 .62389 .67094 .63588 .68588 .63169 .67856 .61966 Mtetra
.648 .659 .847 r
.67856 .61966 .68588 .63169 .7009 .62751 .69363 .61571 Mtetra
.643 .662 .853 r
.69363 .61571 .7009 .62751 .716 .62329 .7088 .61203 Mtetra
.638 .67 .864 r
.7088 .61203 .716 .62329 .73117 .61897 .72406 .60856 Mtetra
.635 .686 .881 r
.72406 .60856 .73117 .61897 .74642 .61445 .73943 .60523 Mtetra
.632 .712 .904 r
.73943 .60523 .74642 .61445 .76172 .60964 .75489 .60187 Mtetra
.638 .752 .931 r
.75489 .60187 .76172 .60964 .77708 .60446 .77041 .5981 Mtetra
.654 .8 .953 r
.77041 .5981 .77708 .60446 .79248 .59888 .78596 .59348 Mtetra
.664 .835 .965 r
.78596 .59348 .79248 .59888 .80793 .59289 .80154 .58821 Mtetra
.676 .863 .971 r
.80154 .58821 .80793 .59289 .82342 .58665 .81715 .58231 Mtetra
.689 .88 .969 r
.81715 .58231 .82342 .58665 .83899 .58046 .83278 .57584 Mtetra
.699 .875 .964 r
.83278 .57584 .83899 .58046 .8547 .57502 .84845 .56911 Mtetra
.696 .834 .949 r
.84845 .56911 .8547 .57502 .87053 .56994 .86423 .56279 Mtetra
.677 .792 .936 r
.86423 .56279 .87053 .56994 .88648 .56523 .88018 .55731 Mtetra
.666 .767 .926 r
.88018 .55731 .88648 .56523 .90255 .56077 .89626 .55231 Mtetra
.656 .75 .919 r
.89626 .55231 .90255 .56077 .9187 .55628 .91247 .54771 Mtetra
.653 .748 .919 r
.91247 .54771 .9187 .55628 .93492 .55154 .92879 .54321 Mtetra
.659 .758 .923 r
.92879 .54321 .93492 .55154 .95123 .54681 .94516 .5384 Mtetra
.659 .757 .922 r
.94516 .5384 .95123 .54681 .96764 .54218 .96162 .53357 Mtetra
.656 .752 .92 r
.96162 .53357 .96764 .54218 .98416 .5376 .9782 .52886 Mtetra
.651 .751 .922 r
.38547 .6876 .39362 .6947 .40717 .69087 .39906 .68386 Mtetra
.65 .754 .925 r
.39906 .68386 .40717 .69087 .42079 .68714 .41272 .68012 Mtetra
.659 .757 .922 r
.41272 .68012 .42079 .68714 .43447 .68342 .42646 .67607 Mtetra
.655 .748 .918 r
.42646 .67607 .43447 .68342 .44824 .6794 .44026 .67218 Mtetra
.638 .748 .928 r
.44026 .67218 .44824 .6794 .46207 .67547 .45412 .6688 Mtetra
.613 .757 .947 r
.45412 .6688 .46207 .67547 .47596 .67193 .46805 .66602 Mtetra
.551 .761 .975 r
.46805 .66602 .47596 .67193 .48993 .66887 .48205 .66441 Mtetra
.509 .794 .997 r
.48205 .66441 .48993 .66887 .50396 .66663 .49614 .66279 Mtetra
.518 .818 .999 r
.49614 .66279 .50396 .66663 .51809 .6648 .51032 .66061 Mtetra
.576 .828 .993 r
.51032 .66061 .51809 .6648 .5323 .66274 .52459 .6576 Mtetra
.639 .816 .968 r
.52459 .6576 .5323 .66274 .5466 .66013 .53894 .65355 Mtetra
.692 .787 .923 r
.53894 .65355 .5466 .66013 .56098 .65691 .55335 .64804 Mtetra
.697 .732 .878 r
.55335 .64804 .56098 .65691 .57544 .65307 .56783 .64213 Mtetra
.69 .69 .845 r
.56783 .64213 .57544 .65307 .58995 .64839 .58236 .63613 Mtetra
.683 .667 .828 r
.58236 .63613 .58995 .64839 .60453 .64329 .59695 .63024 Mtetra
.676 .653 .82 r
.59695 .63024 .60453 .64329 .61918 .63818 .61162 .62459 Mtetra
.669 .644 .816 r
.61162 .62459 .61918 .63818 .6339 .63319 .62636 .61928 Mtetra
.662 .637 .814 r
.62636 .61928 .6339 .63319 .6487 .62841 .64118 .61432 Mtetra
.656 .632 .815 r
.64118 .61432 .6487 .62841 .66358 .62389 .65609 .6097 Mtetra
.65 .629 .816 r
.65609 .6097 .66358 .62389 .67856 .61966 .67109 .60541 Mtetra
.644 .626 .818 r
.67109 .60541 .67856 .61966 .69363 .61571 .68619 .60147 Mtetra
.637 .624 .82 r
.68619 .60147 .69363 .61571 .7088 .61203 .70139 .59787 Mtetra
.631 .623 .824 r
.70139 .59787 .7088 .61203 .72406 .60856 .7167 .59463 Mtetra
.625 .623 .829 r
.7167 .59463 .72406 .60856 .73943 .60523 .73213 .59173 Mtetra
.62 .628 .837 r
.73213 .59173 .73943 .60523 .75489 .60187 .74767 .58909 Mtetra
.617 .638 .849 r
.74767 .58909 .75489 .60187 .77041 .5981 .76331 .58656 Mtetra
.617 .661 .87 r
.76331 .58656 .77041 .5981 .78596 .59348 .77906 .58396 Mtetra
.621 .706 .906 r
.77906 .58396 .78596 .59348 .80154 .58821 .79488 .58094 Mtetra
.652 .777 .94 r
.79488 .58094 .80154 .58821 .81715 .58231 .81068 .57644 Mtetra
.674 .828 .957 r
.81068 .57644 .81715 .58231 .83278 .57584 .82647 .57087 Mtetra
.692 .863 .964 r
.82647 .57087 .83278 .57584 .84845 .56911 .84225 .56442 Mtetra
.706 .878 .962 r
.84225 .56442 .84845 .56911 .86423 .56279 .85805 .55738 Mtetra
.711 .858 .952 r
.85805 .55738 .86423 .56279 .88018 .55731 .87392 .55032 Mtetra
.684 .803 .938 r
.87392 .55032 .88018 .55731 .89626 .55231 .88998 .54445 Mtetra
.67 .774 .928 r
.88998 .54445 .89626 .55231 .91247 .54771 .90619 .53919 Mtetra
.657 .753 .921 r
.90619 .53919 .91247 .54771 .92879 .54321 .92255 .53447 Mtetra
.652 .747 .919 r
.92255 .53447 .92879 .54321 .94516 .5384 .93903 .52992 Mtetra
.66 .758 .922 r
.93903 .52992 .94516 .5384 .96162 .53357 .95556 .52502 Mtetra
.659 .757 .922 r
.95556 .52502 .96162 .53357 .9782 .52886 .97219 .52012 Mtetra
.65 .753 .925 r
.37724 .68054 .38547 .6876 .39906 .68386 .39087 .6768 Mtetra
.659 .756 .922 r
.39087 .6768 .39906 .68386 .41272 .68012 .40459 .67273 Mtetra
.654 .747 .918 r
.40459 .67273 .41272 .68012 .42646 .67607 .41836 .66885 Mtetra
.634 .748 .93 r
.41836 .66885 .42646 .67607 .44026 .67218 .43219 .66556 Mtetra
.598 .755 .953 r
.43219 .66556 .44026 .67218 .45412 .6688 .44608 .66314 Mtetra
.529 .762 .982 r
.44608 .66314 .45412 .6688 .46805 .66602 .46003 .66182 Mtetra
.491 .796 .999 r
.46003 .66182 .46805 .66602 .48205 .66441 .47408 .6603 Mtetra
.54 .818 .997 r
.47408 .6603 .48205 .66441 .49614 .66279 .48823 .65791 Mtetra
.617 .818 .977 r
.48823 .65791 .49614 .66279 .51032 .66061 .50247 .65431 Mtetra
.695 .795 .926 r
.50247 .65431 .51032 .66061 .52459 .6576 .5168 .64868 Mtetra
.708 .734 .871 r
.5168 .64868 .52459 .6576 .53894 .65355 .53119 .64217 Mtetra
.701 .687 .833 r
.53119 .64217 .53894 .65355 .55335 .64804 .54563 .63541 Mtetra
.694 .666 .817 r
.54563 .63541 .55335 .64804 .56783 .64213 .56013 .62869 Mtetra
.685 .652 .811 r
.56013 .62869 .56783 .64213 .58236 .63613 .57469 .62236 Mtetra
.677 .644 .81 r
.57469 .62236 .58236 .63613 .59695 .63024 .58932 .6165 Mtetra
.668 .642 .814 r
.58932 .6165 .59695 .63024 .61162 .62459 .60402 .61115 Mtetra
.659 .643 .822 r
.60402 .61115 .61162 .62459 .62636 .61928 .61881 .60641 Mtetra
.657 .651 .832 r
.61881 .60641 .62636 .61928 .64118 .61432 .63368 .60186 Mtetra
.656 .657 .84 r
.63368 .60186 .64118 .61432 .65609 .6097 .64863 .59744 Mtetra
.654 .66 .844 r
.64863 .59744 .65609 .6097 .67109 .60541 .66366 .59311 Mtetra
.652 .659 .845 r
.66366 .59311 .67109 .60541 .68619 .60147 .67879 .58887 Mtetra
.649 .654 .842 r
.67879 .58887 .68619 .60147 .70139 .59787 .694 .58475 Mtetra
.644 .645 .836 r
.694 .58475 .70139 .59787 .7167 .59463 .7093 .58083 Mtetra
.631 .63 .831 r
.7093 .58083 .7167 .59463 .73213 .59173 .72474 .57753 Mtetra
.621 .62 .828 r
.72474 .57753 .73213 .59173 .74767 .58909 .7403 .57475 Mtetra
.611 .614 .83 r
.7403 .57475 .74767 .58909 .76331 .58656 .75599 .57247 Mtetra
.603 .614 .835 r
.75599 .57247 .76331 .58656 .77906 .58396 .77182 .57057 Mtetra
.601 .624 .847 r
.77182 .57057 .77906 .58396 .79488 .58094 .78777 .56876 Mtetra
.604 .647 .866 r
.78777 .56876 .79488 .58094 .81068 .57644 .80381 .56667 Mtetra
.618 .703 .905 r
.80381 .56667 .81068 .57644 .82647 .57087 .81989 .56371 Mtetra
.664 .789 .941 r
.81989 .56371 .82647 .57087 .84225 .56442 .83588 .55864 Mtetra
.691 .841 .955 r
.83588 .55864 .84225 .56442 .85805 .55738 .85184 .55233 Mtetra
.711 .871 .957 r
.85184 .55233 .85805 .55738 .87392 .55032 .86777 .54509 Mtetra
.718 .869 .953 r
.86777 .54509 .87392 .55032 .88998 .54445 .88376 .53763 Mtetra
.694 .815 .94 r
.88376 .53763 .88998 .54445 .90619 .53919 .89993 .53129 Mtetra
.672 .778 .929 r
.89993 .53129 .90619 .53919 .92255 .53447 .91628 .52585 Mtetra
.657 .754 .921 r
.91628 .52585 .92255 .53447 .93903 .52992 .9328 .52103 Mtetra
.653 .746 .918 r
.9328 .52103 .93903 .52992 .95556 .52502 .94944 .5164 Mtetra
.66 .757 .922 r
.94944 .5164 .95556 .52502 .97219 .52012 .96613 .51141 Mtetra
.658 .756 .922 r
.36893 .67345 .37724 .68054 .39087 .6768 .38262 .6694 Mtetra
.655 .748 .918 r
.38262 .6694 .39087 .6768 .40459 .67273 .39637 .66546 Mtetra
.634 .747 .93 r
.39637 .66546 .40459 .67273 .41836 .66885 .41017 .66218 Mtetra
.591 .752 .955 r
.41017 .66218 .41836 .66885 .43219 .66556 .42401 .65992 Mtetra
.514 .759 .985 r
.42401 .65992 .43219 .66556 .44608 .66314 .43791 .65882 Mtetra
.489 .792 .998 r
.43791 .65882 .44608 .66314 .46003 .66182 .45192 .65737 Mtetra
.56 .814 .993 r
.45192 .65737 .46003 .66182 .47408 .6603 .46604 .65478 Mtetra
.659 .809 .955 r
.46604 .65478 .47408 .6603 .48823 .65791 .48026 .65028 Mtetra
.715 .764 .891 r
.48026 .65028 .48823 .65791 .50247 .65431 .49458 .64368 Mtetra
.713 .703 .838 r
.49458 .64368 .50247 .65431 .5168 .64868 .50896 .6364 Mtetra
.707 .675 .817 r
.50896 .6364 .5168 .64868 .53119 .64217 .52338 .62897 Mtetra
.696 .659 .81 r
.52338 .62897 .53119 .64217 .54563 .63541 .53786 .62199 Mtetra
.682 .651 .813 r
.53786 .62199 .54563 .63541 .56013 .62869 .55239 .61587 Mtetra
.666 .654 .828 r
.55239 .61587 .56013 .62869 .57469 .62236 .567 .61086 Mtetra
.661 .674 .851 r
.567 .61086 .57469 .62236 .58932 .6165 .58169 .60628 Mtetra
.658 .697 .875 r
.58169 .60628 .58932 .6165 .60402 .61115 .59646 .60194 Mtetra
.656 .719 .895 r
.59646 .60194 .60402 .61115 .61881 .60641 .61131 .5977 Mtetra
.655 .731 .905 r
.61131 .5977 .61881 .60641 .63368 .60186 .62624 .59347 Mtetra
.655 .74 .912 r
.62624 .59347 .63368 .60186 .64863 .59744 .64125 .5892 Mtetra
.657 .745 .915 r
.64125 .5892 .64863 .59744 .66366 .59311 .65634 .58482 Mtetra
.659 .746 .914 r
.65634 .58482 .66366 .59311 .67879 .58887 .67151 .58034 Mtetra
.66 .741 .91 r
.67151 .58034 .67879 .58887 .694 .58475 .68675 .57582 Mtetra
.659 .732 .904 r
.68675 .57582 .694 .58475 .7093 .58083 .70208 .5713 Mtetra
.656 .719 .895 r
.70208 .5713 .7093 .58083 .72474 .57753 .7175 .56689 Mtetra
.65 .694 .878 r
.7175 .56689 .72474 .57753 .7403 .57475 .73303 .56272 Mtetra
.639 .664 .858 r
.73303 .56272 .7403 .57475 .75599 .57247 .74867 .55899 Mtetra
.616 .631 .843 r
.74867 .55899 .75599 .57247 .77182 .57057 .76448 .55639 Mtetra
.598 .613 .837 r
.76448 .55639 .77182 .57057 .78777 .56876 .78047 .55469 Mtetra
.588 .61 .842 r
.78047 .55469 .78777 .56876 .80381 .56667 .79661 .55345 Mtetra
.589 .624 .855 r
.79661 .55345 .80381 .56667 .81989 .56371 .81287 .55209 Mtetra
.6 .658 .879 r
.81287 .55209 .81989 .56371 .83588 .55864 .82918 .55002 Mtetra
.644 .745 .923 r
.82918 .55002 .83588 .55864 .85184 .55233 .84541 .5458 Mtetra
.689 .821 .946 r
.84541 .5458 .85184 .55233 .86777 .54509 .86153 .53959 Mtetra
.716 .862 .951 r
.86153 .53959 .86777 .54509 .88376 .53763 .87761 .53218 Mtetra
.725 .868 .948 r
.87761 .53218 .88376 .53763 .89993 .53129 .89372 .52439 Mtetra
.698 .818 .939 r
.89372 .52439 .89993 .53129 .91628 .52585 .91002 .51779 Mtetra
.673 .777 .928 r
.91002 .51779 .91628 .52585 .9328 .52103 .92653 .51225 Mtetra
.657 .753 .921 r
.92653 .51225 .9328 .52103 .94944 .5164 .94321 .50739 Mtetra
.654 .747 .919 r
.94321 .50739 .94944 .5164 .96613 .51141 .96001 .50264 Mtetra
.657 .75 .919 r
.36055 .66607 .36893 .67345 .38262 .6694 .37428 .66204 Mtetra
.637 .746 .928 r
.37428 .66204 .38262 .6694 .39637 .66546 .38805 .65866 Mtetra
.594 .75 .952 r
.38805 .65866 .39637 .66546 .41017 .66218 .40186 .65634 Mtetra
.509 .751 .983 r
.40186 .65634 .41017 .66218 .42401 .65992 .41571 .65539 Mtetra
.486 .785 .998 r
.41571 .65539 .42401 .65992 .43791 .65882 .42966 .65408 Mtetra
.57 .809 .989 r
.42966 .65408 .43791 .65882 .45192 .65737 .44375 .65143 Mtetra
.682 .802 .939 r
.44375 .65143 .45192 .65737 .46604 .65478 .45797 .64626 Mtetra
.724 .746 .869 r
.45797 .64626 .46604 .65478 .48026 .65028 .47228 .63901 Mtetra
.719 .694 .825 r
.47228 .63901 .48026 .65028 .49458 .64368 .48665 .63108 Mtetra
.71 .672 .811 r
.48665 .63108 .49458 .64368 .50896 .6364 .50106 .6233 Mtetra
.693 .66 .813 r
.50106 .6233 .50896 .6364 .52338 .62897 .51552 .61652 Mtetra
.67 .661 .832 r
.51552 .61652 .52338 .62897 .53786 .62199 .53004 .61135 Mtetra
.661 .689 .866 r
.53004 .61135 .53786 .62199 .55239 .61587 .54462 .60688 Mtetra
.651 .721 .9 r
.54462 .60688 .55239 .61587 .567 .61086 .55929 .60284 Mtetra
.642 .743 .922 r
.55929 .60284 .567 .61086 .58169 .60628 .57404 .59906 Mtetra
.638 .764 .939 r
.57404 .59906 .58169 .60628 .59646 .60194 .58888 .59525 Mtetra
.638 .78 .95 r
.58888 .59525 .59646 .60194 .61131 .5977 .60379 .59133 Mtetra
.639 .792 .955 r
.60379 .59133 .61131 .5977 .62624 .59347 .61879 .58726 Mtetra
.643 .798 .957 r
.61879 .58726 .62624 .59347 .64125 .5892 .63387 .58301 Mtetra
.647 .802 .957 r
.63387 .58301 .64125 .5892 .65634 .58482 .64902 .57859 Mtetra
.652 .803 .956 r
.64902 .57859 .65634 .58482 .67151 .58034 .66425 .57401 Mtetra
.657 .803 .953 r
.66425 .57401 .67151 .58034 .68675 .57582 .67955 .56925 Mtetra
.662 .799 .948 r
.67955 .56925 .68675 .57582 .70208 .5713 .69493 .56433 Mtetra
.667 .789 .94 r
.69493 .56433 .70208 .5713 .7175 .56689 .71038 .55928 Mtetra
.669 .774 .929 r
.71038 .55928 .7175 .56689 .73303 .56272 .72592 .55422 Mtetra
.663 .75 .915 r
.72592 .55422 .73303 .56272 .74867 .55899 .74155 .54941 Mtetra
.652 .721 .899 r
.74155 .54941 .74867 .55899 .76448 .55639 .75729 .54503 Mtetra
.636 .679 .873 r
.75729 .54503 .76448 .55639 .78047 .55469 .77318 .54138 Mtetra
.601 .63 .852 r
.77318 .54138 .78047 .55469 .79661 .55345 .7893 .53938 Mtetra
.581 .609 .845 r
.7893 .53938 .79661 .55345 .81287 .55209 .80563 .53841 Mtetra
.575 .613 .853 r
.80563 .53841 .81287 .55209 .82918 .55002 .82209 .53762 Mtetra
.586 .64 .871 r
.82209 .53762 .82918 .55002 .84541 .5458 .83862 .53615 Mtetra
.629 .717 .91 r
.83862 .53615 .84541 .5458 .86153 .53959 .85507 .53253 Mtetra
.689 .809 .939 r
.85507 .53253 .86153 .53959 .87761 .53218 .87136 .52629 Mtetra
.721 .855 .945 r
.87136 .52629 .87761 .53218 .89372 .52439 .88756 .51864 Mtetra
.73 .864 .944 r
.88756 .51864 .89372 .52439 .91002 .51779 .9038 .51058 Mtetra
.697 .812 .936 r
.9038 .51058 .91002 .51779 .92653 .51225 .92026 .50394 Mtetra
.671 .774 .927 r
.92026 .50394 .92653 .51225 .94321 .50739 .93694 .49841 Mtetra
.655 .751 .92 r
.93694 .49841 .94321 .50739 .96001 .50264 .9538 .49355 Mtetra
.643 .746 .924 r
.35209 .65862 .36055 .66607 .37428 .66204 .36584 .65503 Mtetra
.606 .749 .946 r
.36584 .65503 .37428 .66204 .38805 .65866 .37962 .65241 Mtetra
.513 .741 .977 r
.37962 .65241 .38805 .65866 .40186 .65634 .39342 .65155 Mtetra
.479 .775 .996 r
.39342 .65155 .40186 .65634 .41571 .65539 .40732 .65047 Mtetra
.566 .803 .988 r
.40732 .65047 .41571 .65539 .42966 .65408 .42136 .64796 Mtetra
.688 .798 .933 r
.42136 .64796 .42966 .65408 .44375 .65143 .43557 .64256 Mtetra
.729 .74 .86 r
.43557 .64256 .44375 .65143 .45797 .64626 .44988 .63486 Mtetra
.725 .695 .821 r
.44988 .63486 .45797 .64626 .47228 .63901 .46426 .62644 Mtetra
.713 .674 .811 r
.46426 .62644 .47228 .63901 .48665 .63108 .47866 .61844 Mtetra
.686 .664 .823 r
.47866 .61844 .48665 .63108 .50106 .6233 .4931 .61226 Mtetra
.665 .683 .857 r
.4931 .61226 .50106 .6233 .51552 .61652 .50759 .60753 Mtetra
.649 .721 .901 r
.50759 .60753 .51552 .61652 .53004 .61135 .52215 .60359 Mtetra
.632 .747 .93 r
.52215 .60359 .53004 .61135 .54462 .60688 .53679 .6001 Mtetra
.624 .772 .951 r
.53679 .6001 .54462 .60688 .55929 .60284 .55152 .59664 Mtetra
.626 .791 .961 r
.55152 .59664 .55929 .60284 .57404 .59906 .56633 .59295 Mtetra
.637 .798 .96 r
.56633 .59295 .57404 .59906 .58888 .59525 .58122 .58888 Mtetra
.643 .793 .954 r
.58122 .58888 .58888 .59525 .60379 .59133 .59619 .58467 Mtetra
.647 .787 .949 r
.59619 .58467 .60379 .59133 .61879 .58726 .61125 .58036 Mtetra
.65 .783 .944 r
.61125 .58036 .61879 .58726 .63387 .58301 .62638 .57597 Mtetra
.652 .78 .942 r
.62638 .57597 .63387 .58301 .64902 .57859 .64159 .57151 Mtetra
.654 .781 .942 r
.64159 .57151 .64902 .57859 .66425 .57401 .65689 .56698 Mtetra
.655 .784 .943 r
.65689 .56698 .66425 .57401 .67955 .56925 .67226 .56237 Mtetra
.656 .79 .946 r
.67226 .56237 .67955 .56925 .69493 .56433 .68772 .55766 Mtetra
.658 .798 .949 r
.68772 .55766 .69493 .56433 .71038 .55928 .70325 .55281 Mtetra
.668 .808 .95 r
.70325 .55281 .71038 .55928 .72592 .55422 .71884 .54756 Mtetra
.674 .806 .945 r
.71884 .54756 .72592 .55422 .74155 .54941 .73451 .54208 Mtetra
.675 .788 .934 r
.73451 .54208 .74155 .54941 .75729 .54503 .75025 .53661 Mtetra
.665 .757 .919 r
.75025 .53661 .75729 .54503 .77318 .54138 .7661 .53161 Mtetra
.646 .719 .901 r
.7661 .53161 .77318 .54138 .7893 .53938 .78211 .52741 Mtetra
.613 .661 .872 r
.78211 .52741 .7893 .53938 .80563 .53841 .79833 .5247 Mtetra
.575 .613 .854 r
.79833 .5247 .80563 .53841 .82209 .53762 .81483 .52388 Mtetra
.564 .609 .855 r
.81483 .52388 .82209 .53762 .83862 .53615 .83151 .52351 Mtetra
.576 .634 .872 r
.83151 .52351 .83862 .53615 .85507 .53253 .84825 .52241 Mtetra
.625 .708 .906 r
.84825 .52241 .85507 .53253 .87136 .52629 .86488 .51894 Mtetra
.694 .806 .935 r
.86488 .51894 .87136 .52629 .88756 .51864 .8813 .51245 Mtetra
.729 .853 .94 r
.8813 .51245 .88756 .51864 .9038 .51058 .89763 .50445 Mtetra
.734 .857 .939 r
.89763 .50445 .9038 .51058 .92026 .50394 .914 .49619 Mtetra
.691 .799 .932 r
.914 .49619 .92026 .50394 .93694 .49841 .93065 .48977 Mtetra
.666 .767 .925 r
.93065 .48977 .93694 .49841 .9538 .49355 .94752 .48435 Mtetra
.618 .747 .938 r
.34354 .65136 .35209 .65862 .36584 .65503 .3573 .64845 Mtetra
.534 .74 .97 r
.3573 .64845 .36584 .65503 .37962 .65241 .37106 .64728 Mtetra
.469 .761 .994 r
.37106 .64728 .37962 .65241 .39342 .65155 .3849 .64651 Mtetra
.548 .794 .99 r
.3849 .64651 .39342 .65155 .40732 .65047 .39888 .64437 Mtetra
.679 .798 .938 r
.39888 .64437 .40732 .65047 .42136 .64796 .41306 .63926 Mtetra
.734 .745 .861 r
.41306 .63926 .42136 .64796 .43557 .64256 .42737 .63133 Mtetra
.731 .7 .82 r
.42737 .63133 .43557 .64256 .44988 .63486 .44176 .62252 Mtetra
.717 .68 .812 r
.44176 .62252 .44988 .63486 .46426 .62644 .45617 .61427 Mtetra
.682 .671 .832 r
.45617 .61427 .46426 .62644 .47866 .61844 .47058 .6084 Mtetra
.66 .701 .877 r
.47058 .6084 .47866 .61844 .4931 .61226 .48504 .60398 Mtetra
.634 .734 .92 r
.48504 .60398 .4931 .61226 .50759 .60753 .49957 .60051 Mtetra
.617 .763 .949 r
.49957 .60051 .50759 .60753 .52215 .60359 .51418 .59731 Mtetra
.621 .787 .961 r
.51418 .59731 .52215 .60359 .53679 .6001 .52888 .59377 Mtetra
.637 .791 .956 r
.52888 .59377 .53679 .6001 .55152 .59664 .54366 .58978 Mtetra
.645 .779 .945 r
.54366 .58978 .55152 .59664 .56633 .59295 .55852 .58562 Mtetra
.65 .769 .936 r
.55852 .58562 .56633 .59295 .58122 .58888 .57347 .58135 Mtetra
.652 .765 .932 r
.57347 .58135 .58122 .58888 .59619 .58467 .58849 .57699 Mtetra
.654 .763 .93 r
.58849 .57699 .59619 .58467 .61125 .58036 .6036 .57258 Mtetra
.654 .762 .928 r
.6036 .57258 .61125 .58036 .62638 .57597 .61879 .56812 Mtetra
.655 .761 .928 r
.61879 .56812 .62638 .57597 .64159 .57151 .63406 .56362 Mtetra
.656 .761 .928 r
.63406 .56362 .64159 .57151 .65689 .56698 .64942 .55907 Mtetra
.656 .762 .928 r
.64942 .55907 .65689 .56698 .67226 .56237 .66485 .55447 Mtetra
.657 .764 .929 r
.66485 .55447 .67226 .56237 .68772 .55766 .68037 .54982 Mtetra
.658 .767 .93 r
.68037 .54982 .68772 .55766 .70325 .55281 .69598 .54508 Mtetra
.66 .772 .932 r
.69598 .54508 .70325 .55281 .71884 .54756 .71166 .54022 Mtetra
.663 .785 .939 r
.71166 .54022 .71884 .54756 .73451 .54208 .72742 .53519 Mtetra
.673 .802 .944 r
.72742 .53519 .73451 .54208 .75025 .53661 .74323 .52969 Mtetra
.682 .805 .941 r
.74323 .52969 .75025 .53661 .7661 .53161 .7591 .52384 Mtetra
.676 .781 .929 r
.7591 .52384 .7661 .53161 .78211 .52741 .77508 .51826 Mtetra
.653 .739 .913 r
.77508 .51826 .78211 .52741 .79833 .5247 .79121 .51365 Mtetra
.619 .684 .889 r
.79121 .51365 .79833 .5247 .81483 .52388 .80756 .51052 Mtetra
.567 .618 .863 r
.80756 .51052 .81483 .52388 .83151 .52351 .82425 .50988 Mtetra
.555 .608 .861 r
.82425 .50988 .83151 .52351 .84825 .52241 .84113 .50983 Mtetra
.57 .635 .876 r
.84113 .50983 .84825 .52241 .86488 .51894 .85807 .50889 Mtetra
.632 .716 .908 r
.85807 .50889 .86488 .51894 .8813 .51245 .87484 .50502 Mtetra
.704 .811 .932 r
.87484 .50502 .8813 .51245 .89763 .50445 .89137 .49804 Mtetra
.737 .852 .935 r
.89137 .49804 .89763 .50445 .914 .49619 .90781 .4896 Mtetra
.727 .846 .937 r
.90781 .4896 .914 .49619 .93065 .48977 .92436 .48156 Mtetra
.684 .787 .929 r
.92436 .48156 .93065 .48977 .94752 .48435 .94121 .47534 Mtetra
.568 .742 .959 r
.33488 .64443 .34354 .65136 .3573 .64845 .34862 .64264 Mtetra
.476 .744 .987 r
.34862 .64264 .3573 .64845 .37106 .64728 .3624 .6421 Mtetra
.517 .78 .992 r
.3624 .6421 .37106 .64728 .3849 .64651 .37631 .64055 Mtetra
.651 .797 .952 r
.37631 .64055 .3849 .64651 .39888 .64437 .39043 .63629 Mtetra
.736 .759 .871 r
.39043 .63629 .39888 .64437 .41306 .63926 .40474 .62842 Mtetra
.738 .708 .823 r
.40474 .62842 .41306 .63926 .42737 .63133 .41914 .61932 Mtetra
.724 .687 .814 r
.41914 .61932 .42737 .63133 .44176 .62252 .43356 .61068 Mtetra
.685 .677 .837 r
.43356 .61068 .44176 .62252 .45617 .61427 .44796 .60473 Mtetra
.657 .712 .888 r
.44796 .60473 .45617 .61427 .47058 .6084 .46239 .60045 Mtetra
.623 .74 .93 r
.46239 .60045 .47058 .6084 .48504 .60398 .47688 .59725 Mtetra
.608 .769 .957 r
.47688 .59725 .48504 .60398 .49957 .60051 .49145 .59421 Mtetra
.63 .79 .959 r
.49145 .59421 .49957 .60051 .51418 .59731 .50612 .5904 Mtetra
.643 .777 .945 r
.50612 .5904 .51418 .59731 .52888 .59377 .52088 .58633 Mtetra
.649 .766 .934 r
.52088 .58633 .52888 .59377 .54366 .58978 .53571 .5821 Mtetra
.652 .761 .929 r
.53571 .5821 .54366 .58978 .55852 .58562 .55063 .57778 Mtetra
.653 .758 .927 r
.55063 .57778 .55852 .58562 .57347 .58135 .56563 .5734 Mtetra
.654 .757 .925 r
.56563 .5734 .57347 .58135 .58849 .57699 .58071 .56898 Mtetra
.653 .756 .925 r
.58071 .56898 .58849 .57699 .6036 .57258 .59587 .56456 Mtetra
.654 .757 .926 r
.59587 .56456 .6036 .57258 .61879 .56812 .61112 .56008 Mtetra
.655 .759 .926 r
.61112 .56008 .61879 .56812 .63406 .56362 .62645 .55553 Mtetra
.657 .759 .925 r
.62645 .55553 .63406 .56362 .64942 .55907 .64186 .55091 Mtetra
.657 .758 .924 r
.64186 .55091 .64942 .55907 .66485 .55447 .65736 .54624 Mtetra
.65736 .54624 .66485 .55447 .68037 .54982 .67294 .54155 Mtetra
.67294 .54155 .68037 .54982 .69598 .54508 .6886 .53683 Mtetra
.658 .76 .925 r
.6886 .53683 .69598 .54508 .71166 .54022 .70436 .53205 Mtetra
.66 .764 .927 r
.70436 .53205 .71166 .54022 .72742 .53519 .72019 .52717 Mtetra
.663 .77 .929 r
.72019 .52717 .72742 .53519 .74323 .52969 .7361 .52212 Mtetra
.668 .785 .936 r
.7361 .52212 .74323 .52969 .7591 .52384 .75208 .5168 Mtetra
.687 .807 .939 r
.75208 .5168 .7591 .52384 .77508 .51826 .76809 .51069 Mtetra
.683 .793 .933 r
.76809 .51069 .77508 .51826 .79121 .51365 .7842 .50473 Mtetra
.657 .75 .919 r
.7842 .50473 .79121 .51365 .80756 .51052 .80047 .49987 Mtetra
.616 .694 .899 r
.80047 .49987 .80756 .51052 .82425 .50988 .81699 .49675 Mtetra
.557 .619 .87 r
.81699 .49675 .82425 .50988 .84113 .50983 .83389 .49642 Mtetra
.546 .61 .868 r
.83389 .49642 .84113 .50983 .85807 .50889 .85098 .49659 Mtetra
.57 .643 .883 r
.85098 .49659 .85807 .50889 .87484 .50502 .86809 .4955 Mtetra
.653 .741 .914 r
.86809 .4955 .87484 .50502 .89137 .49804 .88493 .49064 Mtetra
.719 .821 .929 r
.88493 .49064 .89137 .49804 .90781 .4896 .90155 .48294 Mtetra
.743 .851 .93 r
.90155 .48294 .90781 .4896 .92436 .48156 .91811 .47414 Mtetra
.712 .822 .933 r
.91811 .47414 .92436 .48156 .94121 .47534 .93489 .46664 Mtetra
.501 .73 .975 r
.32612 .6378 .33488 .64443 .34862 .64264 .33983 .6372 Mtetra
.482 .76 .992 r
.33983 .6372 .34862 .64264 .3624 .6421 .35367 .63631 Mtetra
.599 .789 .972 r
.35367 .63631 .3624 .6421 .37631 .64055 .36769 .63333 Mtetra
.729 .779 .892 r
.36769 .63333 .37631 .64055 .39043 .63629 .38198 .62605 Mtetra
.743 .72 .83 r
.38198 .62605 .39043 .63629 .40474 .62842 .39639 .61684 Mtetra
.734 .697 .815 r
.39639 .61684 .40474 .62842 .41914 .61932 .41083 .60767 Mtetra
.695 .684 .836 r
.41083 .60767 .41914 .61932 .43356 .61068 .42523 .60116 Mtetra
.658 .714 .889 r
.42523 .60116 .43356 .61068 .44796 .60473 .43963 .5968 Mtetra
.618 .74 .933 r
.43963 .5968 .44796 .60473 .46239 .60045 .45409 .59372 Mtetra
.606 .77 .958 r
.45409 .59372 .46239 .60045 .47688 .59725 .46863 .59068 Mtetra
.633 .784 .954 r
.46863 .59068 .47688 .59725 .49145 .59421 .48326 .58685 Mtetra
.646 .766 .937 r
.48326 .58685 .49145 .59421 .50612 .5904 .49799 .58273 Mtetra
.651 .761 .93 r
.49799 .58273 .50612 .5904 .52088 .58633 .5128 .57846 Mtetra
.652 .757 .926 r
.5128 .57846 .52088 .58633 .53571 .5821 .52768 .57412 Mtetra
.65 .755 .926 r
.52768 .57412 .53571 .5821 .55063 .57778 .54266 .56985 Mtetra
.649 .757 .928 r
.54266 .56985 .55063 .57778 .56563 .5734 .55771 .56555 Mtetra
.651 .761 .93 r
.55771 .56555 .56563 .5734 .58071 .56898 .57285 .56119 Mtetra
.652 .764 .931 r
.57285 .56119 .58071 .56898 .59587 .56456 .58807 .55673 Mtetra
.653 .764 .931 r
.58807 .55673 .59587 .56456 .61112 .56008 .60338 .55221 Mtetra
.655 .765 .93 r
.60338 .55221 .61112 .56008 .62645 .55553 .61876 .54761 Mtetra
.656 .765 .93 r
.61876 .54761 .62645 .55553 .64186 .55091 .63424 .54295 Mtetra
.657 .766 .93 r
.63424 .54295 .64186 .55091 .65736 .54624 .64979 .53821 Mtetra
.659 .766 .929 r
.64979 .53821 .65736 .54624 .67294 .54155 .66543 .53339 Mtetra
.661 .764 .926 r
.66543 .53339 .67294 .54155 .6886 .53683 .68115 .52848 Mtetra
.66 .761 .924 r
.68115 .52848 .6886 .53683 .70436 .53205 .69696 .52356 Mtetra
.659 .758 .923 r
.69696 .52356 .70436 .53205 .72019 .52717 .71286 .5187 Mtetra
.659 .759 .924 r
.71286 .5187 .72019 .52717 .7361 .52212 .72885 .51376 Mtetra
.663 .765 .926 r
.72885 .51376 .7361 .52212 .75208 .5168 .74491 .50867 Mtetra
.669 .774 .928 r
.74491 .50867 .75208 .5168 .76809 .51069 .76105 .50328 Mtetra
.688 .801 .935 r
.76105 .50328 .76809 .51069 .7842 .50473 .77721 .49707 Mtetra
.687 .795 .932 r
.77721 .49707 .7842 .50473 .80047 .49987 .79345 .49088 Mtetra
.655 .751 .92 r
.79345 .49088 .80047 .49987 .81699 .49675 .80989 .48601 Mtetra
.602 .689 .904 r
.80989 .48601 .81699 .49675 .83389 .49642 .82663 .48336 Mtetra
.543 .616 .875 r
.82663 .48336 .83389 .49642 .85098 .49659 .84376 .4835 Mtetra
.541 .615 .876 r
.84376 .4835 .85098 .49659 .86809 .4955 .86105 .48371 Mtetra
.583 .662 .892 r
.86105 .48371 .86809 .4955 .88493 .49064 .87828 .48191 Mtetra
.685 .777 .921 r
.87828 .48191 .88493 .49064 .90155 .48294 .89514 .47561 Mtetra
.735 .832 .925 r
.89514 .47561 .90155 .48294 .91811 .47414 .91183 .4671 Mtetra
.742 .844 .927 r
.91183 .4671 .91811 .47414 .93489 .46664 .92854 .45826 Mtetra
.464 .738 .987 r
.31721 .63187 .32612 .6378 .33983 .6372 .33096 .63147 Mtetra
.543 .775 .984 r
.33096 .63147 .33983 .6372 .35367 .63631 .34488 .62962 Mtetra
.692 .787 .923 r
.34488 .62962 .35367 .63631 .36769 .63333 .35908 .624 Mtetra
.745 .737 .845 r
.35908 .624 .36769 .63333 .38198 .62605 .37349 .61506 Mtetra
.744 .709 .819 r
.37349 .61506 .38198 .62605 .39639 .61684 .38796 .60535 Mtetra
.712 .693 .831 r
.38796 .60535 .39639 .61684 .41083 .60767 .40239 .59778 Mtetra
.666 .709 .88 r
.40239 .59778 .41083 .60767 .42523 .60116 .41678 .59303 Mtetra
.62 .736 .93 r
.41678 .59303 .42523 .60116 .43963 .5968 .4312 .5899 Mtetra
.602 .765 .957 r
.4312 .5899 .43963 .5968 .45409 .59372 .4457 .58698 Mtetra
.632 .779 .952 r
.4457 .58698 .45409 .59372 .46863 .59068 .4603 .58317 Mtetra
.646 .763 .934 r
.4603 .58317 .46863 .59068 .48326 .58685 .475 .57904 Mtetra
.651 .758 .928 r
.475 .57904 .48326 .58685 .49799 .58273 .48977 .57475 Mtetra
.65 .755 .926 r
.48977 .57475 .49799 .58273 .5128 .57846 .50463 .57049 Mtetra
.647 .755 .928 r
.50463 .57049 .5128 .57846 .52768 .57412 .51957 .5663 Mtetra
.648 .76 .931 r
.51957 .5663 .52768 .57412 .54266 .56985 .5346 .56202 Mtetra
.653 .763 .93 r
.5346 .56202 .54266 .56985 .55771 .56555 .54971 .55755 Mtetra
.655 .76 .927 r
.54971 .55755 .55771 .56555 .57285 .56119 .5649 .55299 Mtetra
.656 .757 .924 r
.5649 .55299 .57285 .56119 .58807 .55673 .58018 .54839 Mtetra
.656 .754 .922 r
.58018 .54839 .58807 .55673 .60338 .55221 .59554 .54376 Mtetra
.656 .753 .921 r
.59554 .54376 .60338 .55221 .61876 .54761 .61099 .53912 Mtetra
.61099 .53912 .61876 .54761 .63424 .54295 .62652 .53446 Mtetra
.655 .754 .922 r
.62652 .53446 .63424 .54295 .64979 .53821 .64214 .52978 Mtetra
.656 .757 .924 r
.64214 .52978 .64979 .53821 .66543 .53339 .65784 .52506 Mtetra
.657 .761 .926 r
.65784 .52506 .66543 .53339 .68115 .52848 .67363 .52024 Mtetra
.661 .766 .927 r
.67363 .52024 .68115 .52848 .69696 .52356 .6895 .51523 Mtetra
.663 .765 .926 r
.6895 .51523 .69696 .52356 .71286 .5187 .70546 .51011 Mtetra
.661 .759 .923 r
.70546 .51011 .71286 .5187 .72885 .51376 .7215 .50508 Mtetra
.66 .758 .923 r
.7215 .50508 .72885 .51376 .74491 .50867 .73764 .50007 Mtetra
.663 .762 .924 r
.73764 .50007 .74491 .50867 .76105 .50328 .75386 .49489 Mtetra
.67 .771 .926 r
.75386 .49489 .76105 .50328 .77721 .49707 .77015 .48937 Mtetra
.692 .798 .931 r
.77015 .48937 .77721 .49707 .79345 .49088 .78645 .48293 Mtetra
.686 .791 .93 r
.78645 .48293 .79345 .49088 .80989 .48601 .80285 .4767 Mtetra
.646 .743 .92 r
.80285 .4767 .80989 .48601 .82663 .48336 .81949 .47212 Mtetra
.576 .669 .903 r
.81949 .47212 .82663 .48336 .84376 .4835 .83651 .4705 Mtetra
.528 .612 .88 r
.83651 .4705 .84376 .4835 .86105 .48371 .85388 .47111 Mtetra
.544 .629 .886 r
.85388 .47111 .86105 .48371 .87828 .48191 .87133 .47095 Mtetra
.623 .701 .901 r
.87133 .47095 .87828 .48191 .89514 .47561 .88856 .46732 Mtetra
.712 .802 .92 r
.88856 .46732 .89514 .47561 .91183 .4671 .90545 .45972 Mtetra
.747 .838 .921 r
.90545 .45972 .91183 .4671 .92854 .45826 .92222 .45057 Mtetra
.486 .749 .987 r
.30821 .62594 .31721 .63187 .33096 .63147 .32202 .62515 Mtetra
.616 .781 .96 r
.32202 .62515 .33096 .63147 .34488 .62962 .33607 .62184 Mtetra
.741 .769 .876 r
.33607 .62184 .34488 .62962 .35908 .624 .35044 .61374 Mtetra
.751 .723 .826 r
.35044 .61374 .35908 .624 .37349 .61506 .36494 .60385 Mtetra
.734 .705 .823 r
.36494 .60385 .37349 .61506 .38796 .60535 .37943 .59479 Mtetra
.68 .701 .863 r
.37943 .59479 .38796 .60535 .40239 .59778 .39382 .58928 Mtetra
.632 .732 .92 r
.39382 .58928 .40239 .59778 .41678 .59303 .40821 .5858 Mtetra
.596 .755 .954 r
.40821 .5858 .41678 .59303 .4312 .5899 .42267 .5831 Mtetra
.629 .778 .952 r
.42267 .5831 .4312 .5899 .4457 .58698 .43723 .57939 Mtetra
.645 .762 .934 r
.43723 .57939 .4457 .58698 .4603 .58317 .4519 .57528 Mtetra
.65 .757 .927 r
.4519 .57528 .4603 .58317 .475 .57904 .46664 .57099 Mtetra
.648 .753 .926 r
.46664 .57099 .475 .57904 .48977 .57475 .48147 .56679 Mtetra
.645 .756 .929 r
.48147 .56679 .48977 .57475 .50463 .57049 .49638 .56263 Mtetra
.65 .761 .93 r
.49638 .56263 .50463 .57049 .51957 .5663 .51138 .55825 Mtetra
.656 .759 .926 r
.51138 .55825 .51957 .5663 .5346 .56202 .52646 .55368 Mtetra
.657 .753 .921 r
.52646 .55368 .5346 .56202 .54971 .55755 .54163 .54906 Mtetra
.657 .75 .919 r
.54163 .54906 .54971 .55755 .5649 .55299 .55687 .54442 Mtetra
.656 .749 .919 r
.55687 .54442 .5649 .55299 .58018 .54839 .5722 .53977 Mtetra
.5722 .53977 .58018 .54839 .59554 .54376 .58762 .5351 Mtetra
.58762 .5351 .59554 .54376 .61099 .53912 .60312 .53041 Mtetra
.60312 .53041 .61099 .53912 .62652 .53446 .61871 .5257 Mtetra
.61871 .5257 .62652 .53446 .64214 .52978 .63439 .52097 Mtetra
.655 .749 .919 r
.63439 .52097 .64214 .52978 .65784 .52506 .65016 .51623 Mtetra
.655 .75 .92 r
.65016 .51623 .65784 .52506 .67363 .52024 .66601 .51147 Mtetra
.656 .753 .921 r
.66601 .51147 .67363 .52024 .6895 .51523 .68196 .50666 Mtetra
.66 .76 .924 r
.68196 .50666 .6895 .51523 .70546 .51011 .69798 .50164 Mtetra
.664 .766 .925 r
.69798 .50164 .70546 .51011 .7215 .50508 .71409 .4964 Mtetra
.663 .761 .923 r
.71409 .4964 .7215 .50508 .73764 .50007 .73028 .49121 Mtetra
.66 .757 .922 r
.73028 .49121 .73764 .50007 .75386 .49489 .74658 .48609 Mtetra
.664 .762 .923 r
.74658 .48609 .75386 .49489 .77015 .48937 .76295 .48079 Mtetra
.673 .771 .924 r
.76295 .48079 .77015 .48937 .78645 .48293 .77939 .47507 Mtetra
.698 .8 .928 r
.77939 .47507 .78645 .48293 .80285 .4767 .79582 .46829 Mtetra
.678 .78 .927 r
.79582 .46829 .80285 .4767 .81949 .47212 .81241 .46232 Mtetra
.627 .727 .919 r
.81241 .46232 .81949 .47212 .83651 .4705 .82929 .45844 Mtetra
.539 .638 .896 r
.82929 .45844 .83651 .4705 .85388 .47111 .84663 .45827 Mtetra
.521 .614 .886 r
.84663 .45827 .85388 .47111 .87133 .47095 .86423 .45899 Mtetra
.563 .654 .897 r
.86423 .45899 .87133 .47095 .88856 .46732 .88179 .45786 Mtetra
.678 .762 .915 r
.88179 .45786 .88856 .46732 .90545 .45972 .89892 .4517 Mtetra
.737 .821 .916 r
.89892 .4517 .90545 .45972 .92222 .45057 .91583 .44287 Mtetra
.535 .761 .98 r
.29913 .61974 .30821 .62594 .32202 .62515 .31302 .61814 Mtetra
.691 .781 .92 r
.31302 .61814 .32202 .62515 .33607 .62184 .32725 .61253 Mtetra
.751 .74 .843 r
.32725 .61253 .33607 .62184 .35044 .61374 .34174 .60314 Mtetra
.751 .719 .822 r
.34174 .60314 .35044 .61374 .36494 .60385 .35629 .59304 Mtetra
.71 .706 .845 r
.35629 .59304 .36494 .60385 .37943 .59479 .37075 .5858 Mtetra
.654 .728 .903 r
.37075 .5858 .37943 .59479 .39382 .58928 .38514 .58153 Mtetra
.601 .743 .944 r
.38514 .58153 .39382 .58928 .40821 .5858 .39955 .57879 Mtetra
.615 .769 .954 r
.39955 .57879 .40821 .5858 .42267 .5831 .41407 .57548 Mtetra
.642 .761 .935 r
.41407 .57548 .42267 .5831 .43723 .57939 .42869 .57145 Mtetra
.65 .757 .928 r
.42869 .57145 .43723 .57939 .4519 .57528 .44341 .56718 Mtetra
.647 .753 .926 r
.44341 .56718 .4519 .57528 .46664 .57099 .45821 .56297 Mtetra
.644 .755 .93 r
.45821 .56297 .46664 .57099 .48147 .56679 .47309 .55884 Mtetra
.652 .76 .929 r
.47309 .55884 .48147 .56679 .49638 .56263 .48805 .5544 Mtetra
.657 .756 .923 r
.48805 .5544 .49638 .56263 .51138 .55825 .5031 .54977 Mtetra
.657 .751 .919 r
.5031 .54977 .51138 .55825 .52646 .55368 .51824 .54512 Mtetra
.656 .75 .919 r
.51824 .54512 .52646 .55368 .54163 .54906 .53346 .54047 Mtetra
.53346 .54047 .54163 .54906 .55687 .54442 .54876 .53583 Mtetra
.654 .751 .921 r
.54876 .53583 .55687 .54442 .5722 .53977 .56415 .5312 Mtetra
.655 .752 .922 r
.56415 .5312 .5722 .53977 .58762 .5351 .57962 .52653 Mtetra
.656 .754 .922 r
.57962 .52653 .58762 .5351 .60312 .53041 .59519 .5218 Mtetra
.657 .754 .922 r
.59519 .5218 .60312 .53041 .61871 .5257 .61083 .51699 Mtetra
.657 .753 .921 r
.61083 .51699 .61871 .5257 .63439 .52097 .62657 .51214 Mtetra
.656 .751 .92 r
.62657 .51214 .63439 .52097 .65016 .51623 .64239 .5073 Mtetra
.656 .75 .919 r
.64239 .5073 .65016 .51623 .66601 .51147 .65831 .50247 Mtetra
.655 .749 .919 r
.65831 .50247 .66601 .51147 .68196 .50666 .67431 .49764 Mtetra
.655 .75 .92 r
.67431 .49764 .68196 .50666 .69798 .50164 .69041 .49279 Mtetra
.659 .757 .922 r
.69041 .49279 .69798 .50164 .71409 .4964 .7066 .48773 Mtetra
.666 .765 .924 r
.7066 .48773 .71409 .4964 .73028 .49121 .72285 .48237 Mtetra
.663 .761 .923 r
.72285 .48237 .73028 .49121 .74658 .48609 .73921 .47707 Mtetra
.661 .757 .921 r
.73921 .47707 .74658 .48609 .76295 .48079 .75566 .47184 Mtetra
.667 .762 .922 r
.75566 .47184 .76295 .48079 .77939 .47507 .77218 .46635 Mtetra
.684 .775 .92 r
.77218 .46635 .77939 .47507 .79582 .46829 .78874 .4601 Mtetra
.697 .795 .925 r
.78874 .4601 .79582 .46829 .81241 .46232 .80533 .45326 Mtetra
.659 .76 .925 r
.80533 .45326 .81241 .46232 .82929 .45844 .82216 .448 Mtetra
.581 .695 .92 r
.82216 .448 .82929 .45844 .84663 .45827 .83937 .44582 Mtetra
.512 .619 .895 r
.83937 .44582 .84663 .45827 .86423 .45899 .85703 .44666 Mtetra
.53 .632 .896 r
.85703 .44666 .86423 .45899 .88179 .45786 .87478 .44676 Mtetra
.624 .705 .904 r
.87478 .44676 .88179 .45786 .89892 .4517 .89225 .44293 Mtetra
.719 .799 .914 r
.89225 .44293 .89892 .4517 .91583 .44287 .90934 .43485 Mtetra
.589 .767 .964 r
.28997 .61309 .29913 .61974 .31302 .61814 .30397 .61047 Mtetra
.734 .773 .884 r
.30397 .61047 .31302 .61814 .32725 .61253 .31837 .60274 Mtetra
.758 .734 .831 r
.31837 .60274 .32725 .61253 .34174 .60314 .33296 .59254 Mtetra
.744 .719 .828 r
.33296 .59254 .34174 .60314 .35629 .59304 .34753 .58303 Mtetra
.682 .715 .874 r
.34753 .58303 .35629 .59304 .37075 .5858 .36196 .57745 Mtetra
.622 .736 .928 r
.36196 .57745 .37075 .5858 .38514 .58153 .37634 .57417 Mtetra
.597 .755 .953 r
.37634 .57417 .38514 .58153 .39955 .57879 .3908 .57139 Mtetra
.634 .766 .942 r
.3908 .57139 .39955 .57879 .41407 .57548 .40539 .56754 Mtetra
.647 .757 .929 r
.40539 .56754 .41407 .57548 .42869 .57145 .42007 .56331 Mtetra
.648 .753 .926 r
.42007 .56331 .42869 .57145 .44341 .56718 .43484 .55903 Mtetra
.643 .752 .929 r
.43484 .55903 .44341 .56718 .45821 .56297 .44968 .55493 Mtetra
.65 .758 .928 r
.44968 .55493 .45821 .56297 .47309 .55884 .46462 .55052 Mtetra
.657 .755 .922 r
.46462 .55052 .47309 .55884 .48805 .5544 .47964 .54586 Mtetra
.657 .75 .919 r
.47964 .54586 .48805 .5544 .5031 .54977 .49474 .54119 Mtetra
.656 .75 .919 r
.49474 .54119 .5031 .54977 .51824 .54512 .50993 .53655 Mtetra
.652 .75 .922 r
.50993 .53655 .51824 .54512 .53346 .54047 .52521 .53201 Mtetra
.651 .754 .925 r
.52521 .53201 .53346 .54047 .54876 .53583 .54057 .52746 Mtetra
.653 .758 .927 r
.54057 .52746 .54876 .53583 .56415 .5312 .55601 .52282 Mtetra
.654 .759 .927 r
.55601 .52282 .56415 .5312 .57962 .52653 .57155 .5181 Mtetra
.655 .759 .926 r
.57155 .5181 .57962 .52653 .59519 .5218 .58717 .51331 Mtetra
.656 .76 .926 r
.58717 .51331 .59519 .5218 .61083 .51699 .60288 .50846 Mtetra
.658 .76 .925 r
.60288 .50846 .61083 .51699 .62657 .51214 .61867 .50352 Mtetra
.659 .76 .924 r
.61867 .50352 .62657 .51214 .64239 .5073 .63455 .4985 Mtetra
.66 .757 .922 r
.63455 .4985 .64239 .5073 .65831 .50247 .65052 .49345 Mtetra
.656 .751 .92 r
.65052 .49345 .65831 .50247 .67431 .49764 .66659 .48852 Mtetra
.655 .75 .92 r
.66659 .48852 .67431 .49764 .69041 .49279 .68275 .48361 Mtetra
.655 .749 .92 r
.68275 .48361 .69041 .49279 .7066 .48773 .69901 .47868 Mtetra
.66 .756 .921 r
.69901 .47868 .7066 .48773 .72285 .48237 .71535 .4735 Mtetra
.667 .764 .923 r
.71535 .4735 .72285 .48237 .73921 .47707 .73176 .468 Mtetra
.662 .759 .922 r
.73176 .468 .73921 .47707 .75566 .47184 .74827 .46266 Mtetra
.663 .758 .921 r
.74827 .46266 .75566 .47184 .77218 .46635 .76488 .45728 Mtetra
.672 .765 .92 r
.76488 .45728 .77218 .46635 .78874 .4601 .78155 .4515 Mtetra
.697 .786 .92 r
.78155 .4515 .78874 .4601 .80533 .45326 .79822 .4446 Mtetra
.685 .782 .925 r
.79822 .4446 .80533 .45326 .82216 .448 .81502 .43821 Mtetra
.626 .733 .924 r
.81502 .43821 .82216 .448 .83937 .44582 .83213 .4342 Mtetra
.522 .643 .909 r
.83213 .4342 .83937 .44582 .85703 .44666 .84977 .4343 Mtetra
.507 .622 .899 r
.84977 .4343 .85703 .44666 .87478 .44676 .86766 .43515 Mtetra
.571 .671 .906 r
.86766 .43515 .87478 .44676 .89225 .44293 .88543 .43343 Mtetra
.696 .775 .912 r
.88543 .43343 .89225 .44293 .90934 .43485 .90272 .42634 Mtetra
.646 .772 .94 r
.28074 .60598 .28997 .61309 .30397 .61047 .29488 .60187 Mtetra
.75 .756 .857 r
.29488 .60187 .30397 .61047 .31837 .60274 .30942 .59281 Mtetra
.761 .734 .827 r
.30942 .59281 .31837 .60274 .33296 .59254 .32408 .58226 Mtetra
.727 .722 .846 r
.32408 .58226 .33296 .59254 .34753 .58303 .33863 .57408 Mtetra
.66 .734 .904 r
.33863 .57408 .34753 .58303 .36196 .57745 .35305 .56949 Mtetra
.599 .74 .943 r
.35305 .56949 .36196 .57745 .37634 .57417 .36745 .56678 Mtetra
.615 .762 .949 r
.36745 .56678 .37634 .57417 .3908 .57139 .38198 .56347 Mtetra
.643 .757 .932 r
.38198 .56347 .3908 .57139 .40539 .56754 .39662 .55937 Mtetra
.65 .754 .926 r
.39662 .55937 .40539 .56754 .42007 .56331 .41136 .55504 Mtetra
.643 .75 .927 r
.41136 .55504 .42007 .56331 .43484 .55903 .42617 .55091 Mtetra
.646 .756 .929 r
.42617 .55091 .43484 .55903 .44968 .55493 .44107 .54663 Mtetra
.657 .756 .923 r
.44107 .54663 .44968 .55493 .46462 .55052 .45606 .54196 Mtetra
.657 .751 .919 r
.45606 .54196 .46462 .55052 .47964 .54586 .47114 .53725 Mtetra
.655 .75 .92 r
.47114 .53725 .47964 .54586 .49474 .54119 .4863 .5326 Mtetra
.649 .75 .923 r
.4863 .5326 .49474 .54119 .50993 .53655 .50154 .52813 Mtetra
.65 .756 .927 r
.50154 .52813 .50993 .53655 .52521 .53201 .51687 .52359 Mtetra
.656 .758 .925 r
.51687 .52359 .52521 .53201 .54057 .52746 .53228 .51881 Mtetra
.657 .754 .922 r
.53228 .51881 .54057 .52746 .55601 .52282 .54779 .51398 Mtetra
.657 .751 .919 r
.54779 .51398 .55601 .52282 .57155 .5181 .56338 .50914 Mtetra
.656 .749 .918 r
.56338 .50914 .57155 .5181 .58717 .51331 .57906 .50431 Mtetra
.655 .749 .919 r
.57906 .50431 .58717 .51331 .60288 .50846 .59483 .49947 Mtetra
.655 .75 .92 r
.59483 .49947 .60288 .50846 .61867 .50352 .61069 .49463 Mtetra
.655 .754 .922 r
.61069 .49463 .61867 .50352 .63455 .4985 .62663 .48973 Mtetra
.66 .76 .924 r
.62663 .48973 .63455 .4985 .65052 .49345 .64267 .48459 Mtetra
.662 .759 .923 r
.64267 .48459 .65052 .49345 .66659 .48852 .65879 .47938 Mtetra
.657 .752 .92 r
.65879 .47938 .66659 .48852 .68275 .48361 .67501 .47435 Mtetra
.654 .75 .92 r
.67501 .47435 .68275 .48361 .69901 .47868 .69133 .46937 Mtetra
.655 .75 .92 r
.69133 .46937 .69901 .47868 .71535 .4735 .70774 .46434 Mtetra
.664 .758 .92 r
.70774 .46434 .71535 .4735 .73176 .468 .72423 .45893 Mtetra
.667 .763 .922 r
.72423 .45893 .73176 .468 .74827 .46266 .7408 .45334 Mtetra
.661 .756 .92 r
.7408 .45334 .74827 .46266 .76488 .45728 .75748 .44797 Mtetra
.667 .76 .92 r
.75748 .44797 .76488 .45728 .78155 .4515 .77424 .44233 Mtetra
.685 .771 .917 r
.77424 .44233 .78155 .4515 .79822 .4446 .79103 .43589 Mtetra
.7 .789 .92 r
.79103 .43589 .79822 .4446 .81502 .43821 .80785 .4288 Mtetra
.652 .755 .925 r
.80785 .4288 .81502 .43821 .83213 .4342 .82494 .42365 Mtetra
.554 .686 .927 r
.82494 .42365 .83213 .4342 .84977 .4343 .84249 .42225 Mtetra
.494 .623 .907 r
.84249 .42225 .84977 .4343 .86766 .43515 .86046 .42336 Mtetra
.535 .651 .909 r
.86046 .42336 .86766 .43515 .88543 .43343 .87843 .42294 Mtetra
.661 .741 .909 r
.87843 .42294 .88543 .43343 .90272 .42634 .89598 .41731 Mtetra
.689 .772 .915 r
.27144 .59846 .28074 .60598 .29488 .60187 .28574 .5928 Mtetra
.759 .75 .844 r
.28574 .5928 .29488 .60187 .30942 .59281 .30038 .58292 Mtetra
.761 .736 .83 r
.30038 .58292 .30942 .59281 .32408 .58226 .31509 .57239 Mtetra
.707 .727 .866 r
.31509 .57239 .32408 .58226 .33863 .57408 .32962 .56551 Mtetra
.636 .738 .922 r
.32962 .56551 .33863 .57408 .35305 .56949 .34404 .56172 Mtetra
.591 .745 .95 r
.34404 .56172 .35305 .56949 .36745 .56678 .35848 .55911 Mtetra
.631 .761 .941 r
.35848 .55911 .36745 .56678 .38198 .56347 .37307 .55531 Mtetra
.647 .754 .928 r
.37307 .55531 .38198 .56347 .39662 .55937 .38777 .55105 Mtetra
.647 .751 .925 r
.38777 .55105 .39662 .55937 .41136 .55504 .40255 .54677 Mtetra
.641 .752 .929 r
.40255 .54677 .41136 .55504 .42617 .55091 .41742 .54264 Mtetra
.654 .756 .925 r
.41742 .54264 .42617 .55091 .44107 .54663 .43237 .53806 Mtetra
.658 .752 .919 r
.43237 .53806 .44107 .54663 .45606 .54196 .44742 .53331 Mtetra
.656 .75 .919 r
.44742 .53331 .45606 .54196 .47114 .53725 .46255 .52861 Mtetra
.649 .75 .923 r
.46255 .52861 .47114 .53725 .4863 .5326 .47776 .52413 Mtetra
.65 .755 .926 r
.47776 .52413 .4863 .5326 .50154 .52813 .49306 .51957 Mtetra
.657 .756 .923 r
.49306 .51957 .50154 .52813 .51687 .52359 .50844 .51472 Mtetra
.658 .751 .918 r
.50844 .51472 .51687 .52359 .53228 .51881 .52392 .50982 Mtetra
.657 .748 .917 r
.52392 .50982 .53228 .51881 .54779 .51398 .53948 .50493 Mtetra
.53948 .50493 .54779 .51398 .56338 .50914 .55512 .50005 Mtetra
.656 .748 .918 r
.55512 .50005 .56338 .50914 .57906 .50431 .57086 .49516 Mtetra
.655 .748 .918 r
.57086 .49516 .57906 .50431 .59483 .49947 .58669 .49027 Mtetra
.655 .747 .918 r
.58669 .49027 .59483 .49947 .61069 .49463 .60261 .48538 Mtetra
.654 .747 .918 r
.60261 .48538 .61069 .49463 .62663 .48973 .61862 .4805 Mtetra
.654 .749 .92 r
.61862 .4805 .62663 .48973 .64267 .48459 .63472 .47557 Mtetra
.661 .757 .922 r
.63472 .47557 .64267 .48459 .65879 .47938 .65091 .47035 Mtetra
.662 .759 .922 r
.65091 .47035 .65879 .47938 .67501 .47435 .66719 .46504 Mtetra
.656 .752 .92 r
.66719 .46504 .67501 .47435 .69133 .46937 .68357 .45995 Mtetra
.654 .75 .92 r
.68357 .45995 .69133 .46937 .70774 .46434 .70005 .45491 Mtetra
.658 .752 .919 r
.70005 .45491 .70774 .46434 .72423 .45893 .71662 .44969 Mtetra
.668 .762 .92 r
.71662 .44969 .72423 .45893 .7408 .45334 .73326 .444 Mtetra
.664 .759 .921 r
.73326 .444 .7408 .45334 .75748 .44797 .75 .43848 Mtetra
.664 .757 .919 r
.75 .43848 .75748 .44797 .77424 .44233 .76684 .43291 Mtetra
.675 .764 .918 r
.76684 .43291 .77424 .44233 .79103 .43589 .78374 .42686 Mtetra
.703 .784 .915 r
.78374 .42686 .79103 .43589 .80785 .4288 .80063 .41956 Mtetra
.674 .771 .923 r
.80063 .41956 .80785 .4288 .82494 .42365 .81771 .41348 Mtetra
.591 .715 .929 r
.81771 .41348 .82494 .42365 .84249 .42225 .83519 .41063 Mtetra
.49 .632 .916 r
.83519 .41063 .84249 .42225 .86046 .42336 .8532 .4116 Mtetra
.51 .641 .914 r
.8532 .4116 .86046 .42336 .87843 .42294 .87132 .41193 Mtetra
.625 .715 .912 r
.87132 .41193 .87843 .42294 .89598 .41731 .88911 .40782 Mtetra
.716 .77 .895 r
.26206 .59059 .27144 .59846 .28574 .5928 .2765 .58365 Mtetra
.765 .75 .84 r
.2765 .58365 .28574 .5928 .30038 .58292 .29124 .57321 Mtetra
.759 .74 .836 r
.29124 .57321 .30038 .58292 .31509 .57239 .30598 .56299 Mtetra
.688 .734 .885 r
.30598 .56299 .31509 .57239 .32962 .56551 .3205 .55712 Mtetra
.617 .738 .933 r
.3205 .55712 .32962 .56551 .34404 .56172 .33493 .55387 Mtetra
.6 .748 .948 r
.33493 .55387 .34404 .56172 .35848 .55911 .34943 .55099 Mtetra
.638 .753 .932 r
.34943 .55099 .35848 .55911 .37307 .55531 .36408 .54699 Mtetra
.649 .752 .925 r
.36408 .54699 .37307 .55531 .38777 .55105 .37883 .54262 Mtetra
.643 .749 .926 r
.37883 .54262 .38777 .55105 .40255 .54677 .39366 .53842 Mtetra
.645 .753 .928 r
.39366 .53842 .40255 .54677 .41742 .54264 .40858 .53411 Mtetra
.657 .753 .921 r
.40858 .53411 .41742 .54264 .43237 .53806 .42359 .52937 Mtetra
.657 .751 .919 r
.42359 .52937 .43237 .53806 .44742 .53331 .43869 .5246 Mtetra
.651 .75 .922 r
.43869 .5246 .44742 .53331 .46255 .52861 .45387 .52001 Mtetra
.648 .752 .926 r
.45387 .52001 .46255 .52861 .47776 .52413 .46913 .51552 Mtetra
.657 .756 .923 r
.46913 .51552 .47776 .52413 .49306 .51957 .48449 .51066 Mtetra
.659 .751 .918 r
.48449 .51066 .49306 .51957 .50844 .51472 .49993 .5057 Mtetra
.658 .749 .917 r
.49993 .5057 .50844 .51472 .52392 .50982 .51546 .50079 Mtetra
.655 .749 .919 r
.51546 .50079 .52392 .50982 .53948 .50493 .53108 .49594 Mtetra
.653 .751 .921 r
.53108 .49594 .53948 .50493 .55512 .50005 .54679 .49113 Mtetra
.656 .754 .922 r
.54679 .49113 .55512 .50005 .57086 .49516 .56258 .48619 Mtetra
.658 .755 .921 r
.56258 .48619 .57086 .49516 .58669 .49027 .57847 .48112 Mtetra
.657 .752 .92 r
.57847 .48112 .58669 .49027 .60261 .48538 .59445 .47609 Mtetra
.654 .749 .919 r
.59445 .47609 .60261 .48538 .61862 .4805 .61052 .47112 Mtetra
.653 .747 .919 r
.61052 .47112 .61862 .4805 .63472 .47557 .62669 .46619 Mtetra
.654 .749 .92 r
.62669 .46619 .63472 .47557 .65091 .47035 .64295 .46118 Mtetra
.663 .758 .921 r
.64295 .46118 .65091 .47035 .66719 .46504 .65929 .45577 Mtetra
.66 .756 .921 r
.65929 .45577 .66719 .46504 .68357 .45995 .67573 .45046 Mtetra
.655 .751 .92 r
.67573 .45046 .68357 .45995 .70005 .45491 .69228 .44534 Mtetra
.655 .75 .92 r
.69228 .44534 .70005 .45491 .71662 .44969 .70892 .44019 Mtetra
.665 .756 .918 r
.70892 .44019 .71662 .44969 .73326 .444 .72563 .43458 Mtetra
.667 .76 .92 r
.72563 .43458 .73326 .444 .75 .43848 .74244 .42885 Mtetra
.662 .755 .919 r
.74244 .42885 .75 .43848 .76684 .43291 .75935 .42329 Mtetra
.671 .76 .918 r
.75935 .42329 .76684 .43291 .78374 .42686 .77634 .41735 Mtetra
.697 .773 .911 r
.77634 .41735 .78374 .42686 .80063 .41956 .79332 .41023 Mtetra
.688 .776 .918 r
.79332 .41023 .80063 .41956 .81771 .41348 .81042 .40348 Mtetra
.621 .734 .928 r
.81042 .40348 .81771 .41348 .83519 .41063 .82787 .39946 Mtetra
.494 .647 .925 r
.82787 .39946 .83519 .41063 .8532 .4116 .8459 .4 Mtetra
.491 .637 .919 r
.8459 .4 .8532 .4116 .87132 .41193 .86413 .4008 Mtetra
.592 .7 .918 r
.86413 .4008 .87132 .41193 .88911 .40782 .88214 .39794 Mtetra
.733 .768 .881 r
.25261 .58247 .26206 .59059 .2765 .58365 .26717 .57456 Mtetra
.769 .753 .838 r
.26717 .57456 .2765 .58365 .29124 .57321 .28198 .56378 Mtetra
.753 .746 .847 r
.28198 .56378 .29124 .57321 .30598 .56299 .29675 .55413 Mtetra
.677 .745 .902 r
.29675 .55413 .30598 .56299 .3205 .55712 .31128 .54877 Mtetra
.604 .737 .939 r
.31128 .54877 .3205 .55712 .33493 .55387 .32573 .54585 Mtetra
.61 .749 .943 r
.32573 .54585 .33493 .55387 .34943 .55099 .34029 .54266 Mtetra
.642 .752 .929 r
.34029 .54266 .34943 .55099 .36408 .54699 .355 .53851 Mtetra
.649 .751 .924 r
.355 .53851 .36408 .54699 .37883 .54262 .3698 .53409 Mtetra
.641 .748 .927 r
.3698 .53409 .37883 .54262 .39366 .53842 .38467 .52993 Mtetra
.65 .753 .925 r
.38467 .52993 .39366 .53842 .40858 .53411 .39965 .52543 Mtetra
.658 .752 .919 r
.39965 .52543 .40858 .53411 .42359 .52937 .41472 .5206 Mtetra
.656 .751 .92 r
.41472 .5206 .42359 .52937 .43869 .5246 .42987 .51583 Mtetra
.648 .749 .923 r
.42987 .51583 .43869 .5246 .45387 .52001 .4451 .51133 Mtetra
.652 .754 .924 r
.4451 .51133 .45387 .52001 .46913 .51552 .46042 .50662 Mtetra
.66 .752 .918 r
.46042 .50662 .46913 .51552 .48449 .51066 .47583 .50162 Mtetra
.658 .75 .918 r
.47583 .50162 .48449 .51066 .49993 .5057 .49133 .49666 Mtetra
.652 .749 .92 r
.49133 .49666 .49993 .5057 .51546 .50079 .50692 .49188 Mtetra
.649 .752 .925 r
.50692 .49188 .51546 .50079 .53108 .49594 .52259 .48718 Mtetra
.653 .758 .927 r
.52259 .48718 .53108 .49594 .54679 .49113 .53836 .4823 Mtetra
.655 .759 .926 r
.53836 .4823 .54679 .49113 .56258 .48619 .55422 .47731 Mtetra
.658 .759 .925 r
.55422 .47731 .56258 .48619 .57847 .48112 .57017 .47221 Mtetra
.661 .761 .924 r
.57017 .47221 .57847 .48112 .59445 .47609 .5862 .46692 Mtetra
.659 .756 .921 r
.5862 .46692 .59445 .47609 .61052 .47112 .60233 .46171 Mtetra
.654 .749 .92 r
.60233 .46171 .61052 .47112 .62669 .46619 .61856 .45669 Mtetra
.652 .748 .92 r
.61856 .45669 .62669 .46619 .64295 .46118 .63489 .4517 Mtetra
.659 .752 .919 r
.63489 .4517 .64295 .46118 .65929 .45577 .6513 .44641 Mtetra
.663 .758 .92 r
.6513 .44641 .65929 .45577 .67573 .45046 .6678 .4409 Mtetra
.656 .752 .92 r
.6678 .4409 .67573 .45046 .69228 .44534 .68441 .43568 Mtetra
.654 .75 .92 r
.68441 .43568 .69228 .44534 .70892 .44019 .70113 .4305 Mtetra
.661 .753 .918 r
.70113 .4305 .70892 .44019 .72563 .43458 .71792 .42499 Mtetra
.669 .76 .918 r
.71792 .42499 .72563 .43458 .74244 .42885 .73479 .41911 Mtetra
.662 .755 .919 r
.73479 .41911 .74244 .42885 .75935 .42329 .75178 .41351 Mtetra
.668 .758 .917 r
.75178 .41351 .75935 .42329 .77634 .41735 .76884 .40761 Mtetra
.691 .769 .911 r
.76884 .40761 .77634 .41735 .79332 .41023 .78592 .4007 Mtetra
.696 .777 .913 r
.78592 .4007 .79332 .41023 .81042 .40348 .80307 .3935 Mtetra
.635 .744 .927 r
.80307 .3935 .81042 .40348 .82787 .39946 .82054 .38884 Mtetra
.507 .669 .936 r
.82054 .38884 .82787 .39946 .8459 .4 .83857 .38867 Mtetra
.477 .638 .926 r
.83857 .38867 .8459 .4 .86413 .4008 .85689 .38971 Mtetra
.564 .69 .925 r
.85689 .38971 .86413 .4008 .88214 .39794 .87507 .38775 Mtetra
.743 .767 .873 r
.24306 .57418 .25261 .58247 .26717 .57456 .25773 .56562 Mtetra
.773 .758 .84 r
.25773 .56562 .26717 .57456 .28198 .56378 .27262 .55465 Mtetra
.748 .753 .856 r
.27262 .55465 .28198 .56378 .29675 .55413 .28741 .54541 Mtetra
.668 .748 .91 r
.28741 .54541 .29675 .55413 .31128 .54877 .30196 .54037 Mtetra
.597 .736 .942 r
.30196 .54037 .31128 .54877 .32573 .54585 .31645 .5376 Mtetra
.617 .747 .939 r
.31645 .5376 .32573 .54585 .34029 .54266 .33107 .53418 Mtetra
.644 .75 .927 r
.33107 .53418 .34029 .54266 .355 .53851 .34582 .52992 Mtetra
.648 .75 .924 r
.34582 .52992 .355 .53851 .3698 .53409 .36067 .52548 Mtetra
.64 .749 .927 r
.36067 .52548 .3698 .53409 .38467 .52993 .3756 .52129 Mtetra
.653 .753 .923 r
.3756 .52129 .38467 .52993 .39965 .52543 .39063 .51664 Mtetra
.658 .752 .919 r
.39063 .51664 .39965 .52543 .41472 .5206 .40575 .51176 Mtetra
.654 .75 .921 r
.40575 .51176 .41472 .5206 .42987 .51583 .42095 .507 Mtetra
.647 .75 .925 r
.42095 .507 .42987 .51583 .4451 .51133 .43623 .50249 Mtetra
.656 .754 .922 r
.43623 .50249 .4451 .51133 .46042 .50662 .45161 .4976 Mtetra
.66 .751 .918 r
.45161 .4976 .46042 .50662 .47583 .50162 .46708 .49254 Mtetra
.656 .75 .919 r
.46708 .49254 .47583 .50162 .49133 .49666 .48264 .48761 Mtetra
.647 .749 .924 r
.48264 .48761 .49133 .49666 .50692 .49188 .49828 .48298 Mtetra
.655 .756 .924 r
.49828 .48298 .50692 .49188 .52259 .48718 .51402 .47802 Mtetra
.66 .753 .919 r
.51402 .47802 .52259 .48718 .53836 .4823 .52984 .47284 Mtetra
.656 .746 .916 r
.52984 .47284 .53836 .4823 .55422 .47731 .54576 .46779 Mtetra
.652 .745 .918 r
.54576 .46779 .55422 .47731 .57017 .47221 .56177 .46288 Mtetra
.656 .752 .92 r
.56177 .46288 .57017 .47221 .5862 .46692 .57787 .45776 Mtetra
.664 .76 .921 r
.57787 .45776 .5862 .46692 .60233 .46171 .59406 .45229 Mtetra
.656 .752 .921 r
.59406 .45229 .60233 .46171 .61856 .45669 .61035 .44712 Mtetra
.652 .749 .921 r
.61035 .44712 .61856 .45669 .63489 .4517 .62674 .44208 Mtetra
.655 .75 .92 r
.62674 .44208 .63489 .4517 .6513 .44641 .64323 .43688 Mtetra
.664 .757 .919 r
.64323 .43688 .6513 .44641 .6678 .4409 .65979 .43128 Mtetra
.657 .753 .921 r
.65979 .43128 .6678 .4409 .68441 .43568 .67647 .42593 Mtetra
.654 .75 .921 r
.67647 .42593 .68441 .43568 .70113 .4305 .69325 .42069 Mtetra
.659 .752 .919 r
.69325 .42069 .70113 .4305 .71792 .42499 .71012 .41523 Mtetra
.67 .759 .917 r
.71012 .41523 .71792 .42499 .73479 .41911 .72706 .40928 Mtetra
.663 .756 .919 r
.72706 .40928 .73479 .41911 .75178 .41351 .74411 .40358 Mtetra
.667 .756 .917 r
.74411 .40358 .75178 .41351 .76884 .40761 .76126 .39769 Mtetra
.686 .765 .911 r
.76126 .39769 .76884 .40761 .78592 .4007 .77843 .39091 Mtetra
.701 .775 .909 r
.77843 .39091 .78592 .4007 .80307 .3935 .79564 .38344 Mtetra
.645 .749 .925 r
.79564 .38344 .80307 .3935 .82054 .38884 .81315 .37834 Mtetra
.521 .682 .939 r
.81315 .37834 .82054 .38884 .83857 .38867 .83119 .37762 Mtetra
.466 .641 .932 r
.83119 .37762 .83857 .38867 .85689 .38971 .84959 .37875 Mtetra
.544 .686 .931 r
.84959 .37875 .85689 .38971 .87507 .38775 .8679 .37737 Mtetra
.747 .768 .869 r
.23342 .56579 .24306 .57418 .25773 .56562 .24817 .55689 Mtetra
.775 .764 .843 r
.24817 .55689 .25773 .56562 .27262 .55465 .26313 .5458 Mtetra
.747 .76 .864 r
.26313 .5458 .27262 .55465 .28741 .54541 .27796 .53676 Mtetra
.663 .75 .915 r
.27796 .53676 .28741 .54541 .30196 .54037 .29255 .53186 Mtetra
.594 .735 .942 r
.29255 .53186 .30196 .54037 .31645 .5376 .30708 .52911 Mtetra
.621 .745 .935 r
.30708 .52911 .31645 .5376 .33107 .53418 .32175 .52555 Mtetra
.644 .749 .925 r
.32175 .52555 .33107 .53418 .34582 .52992 .33656 .52122 Mtetra
.648 .749 .924 r
.33656 .52122 .34582 .52992 .36067 .52548 .35145 .51675 Mtetra
.64 .748 .927 r
.35145 .51675 .36067 .52548 .3756 .52129 .36643 .51251 Mtetra
.654 .752 .922 r
.36643 .51251 .3756 .52129 .39063 .51664 .38151 .50776 Mtetra
.658 .752 .919 r
.38151 .50776 .39063 .51664 .40575 .51176 .39669 .50284 Mtetra
.653 .75 .921 r
.39669 .50284 .40575 .51176 .42095 .507 .41194 .49808 Mtetra
.647 .75 .924 r
.41194 .49808 .42095 .507 .43623 .50249 .42728 .49351 Mtetra
.658 .753 .92 r
.42728 .49351 .43623 .50249 .45161 .4976 .44272 .48849 Mtetra
.66 .752 .918 r
.44272 .48849 .45161 .4976 .46708 .49254 .45824 .48339 Mtetra
.653 .75 .921 r
.45824 .48339 .46708 .49254 .48264 .48761 .47385 .47853 Mtetra
.647 .751 .925 r
.47385 .47853 .48264 .48761 .49828 .48298 .48955 .47384 Mtetra
.662 .755 .919 r
.48955 .47384 .49828 .48298 .51402 .47802 .50535 .46857 Mtetra
.665 .751 .914 r
.50535 .46857 .51402 .47802 .52984 .47284 .52123 .46313 Mtetra
.656 .743 .914 r
.52123 .46313 .52984 .47284 .54576 .46779 .53721 .45803 Mtetra
.647 .74 .917 r
.53721 .45803 .54576 .46779 .56177 .46288 .55328 .45327 Mtetra
.65 .746 .919 r
.55328 .45327 .56177 .46288 .57787 .45776 .56945 .44834 Mtetra
.664 .756 .919 r
.56945 .44834 .57787 .45776 .59406 .45229 .5857 .44283 Mtetra
.659 .755 .921 r
.5857 .44283 .59406 .45229 .61035 .44712 .60206 .43749 Mtetra
.652 .75 .921 r
.60206 .43749 .61035 .44712 .62674 .44208 .61851 .43238 Mtetra
.653 .75 .92 r
.61851 .43238 .62674 .44208 .64323 .43688 .63506 .4272 Mtetra
.664 .755 .918 r
.63506 .4272 .64323 .43688 .65979 .43128 .6517 .42154 Mtetra
.659 .753 .92 r
.6517 .42154 .65979 .43128 .67647 .42593 .66844 .41608 Mtetra
.654 .75 .921 r
.66844 .41608 .67647 .42593 .69325 .42069 .68528 .41078 Mtetra
.657 .752 .92 r
.68528 .41078 .69325 .42069 .71012 .41523 .70223 .40531 Mtetra
.67 .757 .916 r
.70223 .40531 .71012 .41523 .72706 .40928 .71924 .3993 Mtetra
.663 .755 .918 r
.71924 .3993 .72706 .40928 .74411 .40358 .73636 .39352 Mtetra
.666 .756 .917 r
.73636 .39352 .74411 .40358 .76126 .39769 .75358 .38759 Mtetra
.684 .763 .911 r
.75358 .38759 .76126 .39769 .77843 .39091 .77084 .38085 Mtetra
.702 .772 .906 r
.77084 .38085 .77843 .39091 .79564 .38344 .78812 .37325 Mtetra
.65 .75 .923 r
.78812 .37325 .79564 .38344 .81315 .37834 .80569 .36788 Mtetra
.527 .689 .941 r
.80569 .36788 .81315 .37834 .83119 .37762 .82377 .36685 Mtetra
.458 .646 .939 r
.82377 .36685 .83119 .37762 .84959 .37875 .84224 .36798 Mtetra
.532 .686 .937 r
.84224 .36798 .84959 .37875 .8679 .37737 .86066 .36685 Mtetra
.748 .768 .87 r
.22368 .55734 .23342 .56579 .24817 .55689 .23849 .54838 Mtetra
.778 .77 .846 r
.23849 .54838 .24817 .55689 .26313 .5458 .25351 .53723 Mtetra
.749 .768 .869 r
.25351 .53723 .26313 .5458 .27796 .53676 .26841 .52813 Mtetra
.663 .753 .917 r
.26841 .52813 .27796 .53676 .29255 .53186 .28305 .52318 Mtetra
.595 .733 .94 r
.28305 .52318 .29255 .53186 .30708 .52911 .29762 .52039 Mtetra
.622 .741 .932 r
.29762 .52039 .30708 .52911 .32175 .52555 .31234 .51678 Mtetra
.645 .748 .924 r
.31234 .51678 .32175 .52555 .33656 .52122 .32719 .5124 Mtetra
.648 .749 .923 r
.32719 .5124 .33656 .52122 .35145 .51675 .34214 .50789 Mtetra
.64 .747 .926 r
.34214 .50789 .35145 .51675 .36643 .51251 .35717 .5036 Mtetra
.654 .751 .921 r
.35717 .5036 .36643 .51251 .38151 .50776 .3723 .49879 Mtetra
.658 .752 .919 r
.3723 .49879 .38151 .50776 .39669 .50284 .38753 .49382 Mtetra
.653 .75 .921 r
.38753 .49382 .39669 .50284 .41194 .49808 .40284 .48901 Mtetra
.647 .749 .924 r
.40284 .48901 .41194 .49808 .42728 .49351 .41823 .4844 Mtetra
.658 .752 .919 r
.41823 .4844 .42728 .49351 .44272 .48849 .43372 .47932 Mtetra
.66 .752 .919 r
.43372 .47932 .44272 .48849 .45824 .48339 .44931 .47417 Mtetra
.653 .75 .921 r
.44931 .47417 .45824 .48339 .47385 .47853 .46498 .46926 Mtetra
.647 .749 .923 r
.46498 .46926 .47385 .47853 .48955 .47384 .48073 .46451 Mtetra
.662 .753 .918 r
.48073 .46451 .48955 .47384 .50535 .46857 .49659 .45919 Mtetra
.665 .754 .917 r
.49659 .45919 .50535 .46857 .52123 .46313 .51253 .4537 Mtetra
.656 .751 .92 r
.51253 .4537 .52123 .46313 .53721 .45803 .52857 .44854 Mtetra
.646 .748 .923 r
.52857 .44854 .53721 .45803 .55328 .45327 .5447 .44373 Mtetra
.65 .749 .922 r
.5447 .44373 .55328 .45327 .56945 .44834 .56093 .43874 Mtetra
.664 .754 .917 r
.56093 .43874 .56945 .44834 .5857 .44283 .57725 .43317 Mtetra
.659 .752 .919 r
.57725 .43317 .5857 .44283 .60206 .43749 .59367 .42777 Mtetra
.652 .75 .921 r
.59367 .42777 .60206 .43749 .61851 .43238 .61019 .4226 Mtetra
.653 .75 .921 r
.61019 .4226 .61851 .43238 .63506 .4272 .62681 .41736 Mtetra
.664 .754 .917 r
.62681 .41736 .63506 .4272 .6517 .42154 .64351 .41165 Mtetra
.659 .752 .919 r
.64351 .41165 .6517 .42154 .66844 .41608 .66031 .40613 Mtetra
.654 .751 .921 r
.66031 .40613 .66844 .41608 .68528 .41078 .67723 .40077 Mtetra
.657 .752 .92 r
.67723 .40077 .68528 .41078 .70223 .40531 .69424 .39524 Mtetra
.67 .756 .916 r
.69424 .39524 .70223 .40531 .71924 .3993 .71133 .38917 Mtetra
.663 .754 .918 r
.71133 .38917 .71924 .3993 .73636 .39352 .72853 .38332 Mtetra
.666 .755 .917 r
.72853 .38332 .73636 .39352 .75358 .38759 .74582 .37733 Mtetra
.684 .762 .911 r
.74582 .37733 .75358 .38759 .77084 .38085 .76315 .37053 Mtetra
.701 .768 .904 r
.76315 .37053 .77084 .38085 .78812 .37325 .78051 .36286 Mtetra
.65 .748 .921 r
.78051 .36286 .78812 .37325 .80569 .36788 .79815 .35743 Mtetra
.526 .691 .943 r
.79815 .35743 .80569 .36788 .82377 .36685 .81631 .35634 Mtetra
.451 .651 .945 r
.81631 .35634 .82377 .36685 .84224 .36798 .83484 .35743 Mtetra
.529 .692 .943 r
.83484 .35743 .84224 .36798 .86066 .36685 .85333 .35624 Mtetra
.743 .768 .873 r
.21383 .54883 .22368 .55734 .23849 .54838 .22868 .5401 Mtetra
.779 .776 .85 r
.22868 .5401 .23849 .54838 .25351 .53723 .24377 .52894 Mtetra
.755 .776 .871 r
.24377 .52894 .25351 .53723 .26841 .52813 .25875 .51953 Mtetra
.668 .756 .917 r
.25875 .51953 .26841 .52813 .28305 .52318 .27345 .51433 Mtetra
.598 .732 .938 r
.27345 .51433 .28305 .52318 .29762 .52039 .28807 .51143 Mtetra
.619 .737 .931 r
.28807 .51143 .29762 .52039 .31234 .51678 .30283 .50788 Mtetra
.644 .747 .924 r
.30283 .50788 .31234 .51678 .32719 .5124 .31773 .50348 Mtetra
.648 .749 .923 r
.31773 .50348 .32719 .5124 .34214 .50789 .33273 .49888 Mtetra
.64 .746 .925 r
.33273 .49888 .34214 .50789 .35717 .5036 .34781 .49455 Mtetra
.653 .749 .921 r
.34781 .49455 .35717 .5036 .3723 .49879 .36299 .48974 Mtetra
.658 .752 .919 r
.36299 .48974 .3723 .49879 .38753 .49382 .37828 .48472 Mtetra
.654 .751 .921 r
.37828 .48472 .38753 .49382 .40284 .48901 .39364 .4798 Mtetra
.647 .748 .923 r
.39364 .4798 .40284 .48901 .41823 .4844 .40909 .47514 Mtetra
.657 .751 .919 r
.40909 .47514 .41823 .4844 .43372 .47932 .42464 .47009 Mtetra
.66 .753 .919 r
.42464 .47009 .43372 .47932 .44931 .47417 .44028 .46487 Mtetra
.656 .752 .921 r
.44028 .46487 .44931 .47417 .46498 .46926 .456 .45978 Mtetra
.647 .746 .922 r
.456 .45978 .46498 .46926 .48073 .46451 .47182 .455 Mtetra
.655 .749 .919 r
.47182 .455 .48073 .46451 .49659 .45919 .48773 .44987 Mtetra
.66 .756 .921 r
.48773 .44987 .49659 .45919 .51253 .4537 .50374 .44453 Mtetra
.655 .76 .926 r
.50374 .44453 .51253 .4537 .52857 .44854 .51984 .43931 Mtetra
.651 .758 .928 r
.51984 .43931 .52857 .44854 .5447 .44373 .53603 .43424 Mtetra
.656 .755 .923 r
.53603 .43424 .5447 .44373 .56093 .43874 .55232 .42894 Mtetra
.664 .752 .916 r
.55232 .42894 .56093 .43874 .57725 .43317 .5687 .4233 Mtetra
.656 .749 .918 r
.5687 .4233 .57725 .43317 .59367 .42777 .58519 .41796 Mtetra
.652 .75 .922 r
.58519 .41796 .59367 .42777 .61019 .4226 .60177 .41275 Mtetra
.655 .752 .921 r
.60177 .41275 .61019 .4226 .62681 .41736 .61846 .40738 Mtetra
.664 .753 .917 r
.61846 .40738 .62681 .41736 .64351 .41165 .63523 .4016 Mtetra
.658 .751 .919 r
.63523 .4016 .64351 .41165 .66031 .40613 .6521 .39607 Mtetra
.654 .751 .921 r
.6521 .39607 .66031 .40613 .67723 .40077 .66909 .39066 Mtetra
.659 .753 .919 r
.66909 .39066 .67723 .40077 .69424 .39524 .68617 .38501 Mtetra
.67 .755 .915 r
.68617 .38501 .69424 .39524 .71133 .38917 .70333 .37887 Mtetra
.663 .753 .917 r
.70333 .37887 .71133 .38917 .72853 .38332 .7206 .37299 Mtetra
.667 .755 .916 r
.7206 .37299 .72853 .38332 .74582 .37733 .73796 .36691 Mtetra
.686 .761 .909 r
.73796 .36691 .74582 .37733 .76315 .37053 .75537 .35993 Mtetra
.7 .764 .902 r
.75537 .35993 .76315 .37053 .78051 .36286 .77281 .35226 Mtetra
.645 .744 .921 r
.77281 .35226 .78051 .36286 .79815 .35743 .79055 .34697 Mtetra
.516 .688 .946 r
.79055 .34697 .79815 .35743 .81631 .35634 .80879 .3461 Mtetra
.446 .658 .951 r
.80879 .3461 .81631 .35634 .83484 .35743 .82739 .34708 Mtetra
.535 .703 .948 r
.82739 .34708 .83484 .35743 .85333 .35624 .84592 .34553 Mtetra
.733 .767 .88 r
.20388 .54022 .21383 .54883 .22868 .5401 .21874 .53203 Mtetra
.779 .782 .855 r
.21874 .53203 .22868 .5401 .24377 .52894 .23389 .52094 Mtetra
.764 .785 .87 r
.23389 .52094 .24377 .52894 .25875 .51953 .24898 .51098 Mtetra
.677 .762 .915 r
.24898 .51098 .25875 .51953 .27345 .51433 .26376 .50537 Mtetra
.605 .734 .936 r
.26376 .50537 .27345 .51433 .28807 .51143 .27844 .50223 Mtetra
.614 .732 .93 r
.27844 .50223 .28807 .51143 .30283 .50788 .29322 .49882 Mtetra
.642 .745 .924 r
.29322 .49882 .30283 .50788 .31773 .50348 .30817 .49443 Mtetra
.649 .748 .922 r
.30817 .49443 .31773 .50348 .33273 .49888 .32323 .48976 Mtetra
.641 .745 .924 r
.32323 .48976 .33273 .49888 .34781 .49455 .33835 .48535 Mtetra
.65 .747 .921 r
.33835 .48535 .34781 .49455 .36299 .48974 .35359 .4806 Mtetra
.658 .752 .919 r
.35359 .4806 .36299 .48974 .37828 .48472 .36893 .47552 Mtetra
.656 .752 .92 r
.36893 .47552 .37828 .48472 .39364 .4798 .38435 .47049 Mtetra
.648 .748 .922 r
.38435 .47049 .39364 .4798 .40909 .47514 .39985 .46573 Mtetra
.653 .748 .92 r
.39985 .46573 .40909 .47514 .42464 .47009 .41545 .46077 Mtetra
.66 .754 .92 r
.41545 .46077 .42464 .47009 .44028 .46487 .43115 .4555 Mtetra
.658 .753 .92 r
.43115 .4555 .44028 .46487 .456 .45978 .44693 .45027 Mtetra
.652 .749 .921 r
.44693 .45027 .456 .45978 .47182 .455 .46281 .44523 Mtetra
.65 .744 .918 r
.46281 .44523 .47182 .455 .48773 .44987 .47878 .44026 Mtetra
.654 .75 .921 r
.47878 .44026 .48773 .44987 .50374 .44453 .49484 .43511 Mtetra
.656 .756 .924 r
.49484 .43511 .50374 .44453 .51984 .43931 .51101 .42984 Mtetra
.658 .757 .923 r
.51101 .42984 .51984 .43931 .53603 .43424 .52726 .42446 Mtetra
.662 .753 .918 r
.52726 .42446 .53603 .43424 .55232 .42894 .54362 .41889 Mtetra
.659 .747 .915 r
.54362 .41889 .55232 .42894 .5687 .4233 .56007 .41339 Mtetra
.654 .75 .92 r
.56007 .41339 .5687 .4233 .58519 .41796 .57662 .40809 Mtetra
.652 .751 .922 r
.57662 .40809 .58519 .41796 .60177 .41275 .59327 .40281 Mtetra
.659 .753 .92 r
.59327 .40281 .60177 .41275 .61846 .40738 .61001 .39723 Mtetra
.663 .752 .916 r
.61001 .39723 .61846 .40738 .63523 .4016 .62685 .39143 Mtetra
.656 .75 .919 r
.62685 .39143 .63523 .4016 .6521 .39607 .6438 .38591 Mtetra
.654 .751 .921 r
.6438 .38591 .6521 .39607 .66909 .39066 .66086 .38043 Mtetra
.661 .754 .919 r
.66086 .38043 .66909 .39066 .68617 .38501 .678 .37461 Mtetra
.669 .754 .914 r
.678 .37461 .68617 .38501 .70333 .37887 .69523 .36843 Mtetra
.662 .752 .917 r
.69523 .36843 .70333 .37887 .7206 .37299 .71258 .36252 Mtetra
.668 .755 .915 r
.71258 .36252 .7206 .37299 .73796 .36691 .73002 .3563 Mtetra
.69 .762 .906 r
.73002 .3563 .73796 .36691 .75537 .35993 .74748 .34906 Mtetra
.695 .759 .901 r
.74748 .34906 .75537 .35993 .77281 .35226 .76502 .34153 Mtetra
.636 .74 .924 r
.76502 .34153 .77281 .35226 .79055 .34697 .78286 .33656 Mtetra
.497 .682 .949 r
.78286 .33656 .79055 .34697 .80879 .3461 .80122 .33613 Mtetra
.444 .666 .957 r
.80122 .33613 .80879 .3461 .82739 .34708 .81988 .33692 Mtetra
.551 .719 .951 r
.81988 .33692 .82739 .34708 .84592 .34553 .83842 .33468 Mtetra
.715 .763 .89 r
.19384 .53144 .20388 .54022 .21874 .53203 .20867 .52412 Mtetra
.777 .787 .861 r
.20867 .52412 .21874 .53203 .23389 .52094 .22387 .51324 Mtetra
.776 .793 .867 r
.22387 .51324 .23389 .52094 .24898 .51098 .23908 .50258 Mtetra
.692 .77 .912 r
.23908 .50258 .24898 .51098 .26376 .50537 .25397 .49635 Mtetra
.617 .738 .933 r
.25397 .49635 .26376 .50537 .27844 .50223 .26871 .49279 Mtetra
.606 .726 .93 r
.26871 .49279 .27844 .50223 .29322 .49882 .28353 .48959 Mtetra
.639 .742 .923 r
.28353 .48959 .29322 .49882 .30817 .49443 .29852 .48525 Mtetra
.649 .747 .921 r
.29852 .48525 .30817 .49443 .32323 .48976 .31362 .48055 Mtetra
.644 .746 .924 r
.31362 .48055 .32323 .48976 .33835 .48535 .3288 .476 Mtetra
.646 .745 .921 r
.3288 .476 .33835 .48535 .35359 .4806 .34408 .47135 Mtetra
.657 .752 .92 r
.34408 .47135 .35359 .4806 .36893 .47552 .35947 .46624 Mtetra
.35947 .46624 .36893 .47552 .38435 .47049 .37495 .46111 Mtetra
.651 .75 .922 r
.37495 .46111 .38435 .47049 .39985 .46573 .39051 .45617 Mtetra
.648 .746 .92 r
.39051 .45617 .39985 .46573 .41545 .46077 .40616 .45132 Mtetra
.658 .752 .92 r
.40616 .45132 .41545 .46077 .43115 .4555 .42192 .44608 Mtetra
.659 .755 .921 r
.42192 .44608 .43115 .4555 .44693 .45027 .43776 .44075 Mtetra
.657 .753 .921 r
.43776 .44075 .44693 .45027 .46281 .44523 .4537 .43546 Mtetra
.655 .748 .918 r
.4537 .43546 .46281 .44523 .47878 .44026 .46973 .43023 Mtetra
.653 .743 .916 r
.46973 .43023 .47878 .44026 .49484 .43511 .48586 .42504 Mtetra
.656 .744 .915 r
.48586 .42504 .49484 .43511 .51101 .42984 .50208 .41971 Mtetra
.658 .745 .914 r
.50208 .41971 .51101 .42984 .52726 .42446 .5184 .41426 Mtetra
.657 .744 .914 r
.5184 .41426 .52726 .42446 .54362 .41889 .53482 .40883 Mtetra
.654 .748 .918 r
.53482 .40883 .54362 .41889 .56007 .41339 .55133 .40347 Mtetra
.653 .752 .922 r
.55133 .40347 .56007 .41339 .57662 .40809 .56795 .39814 Mtetra
.654 .753 .922 r
.56795 .39814 .57662 .40809 .59327 .40281 .58466 .39272 Mtetra
.663 .754 .918 r
.58466 .39272 .59327 .40281 .61001 .39723 .60147 .38691 Mtetra
.66 .749 .916 r
.60147 .38691 .61001 .39723 .62685 .39143 .61838 .38118 Mtetra
.655 .751 .92 r
.61838 .38118 .62685 .39143 .6438 .38591 .63541 .37564 Mtetra
.655 .751 .921 r
.63541 .37564 .6438 .38591 .66086 .38043 .65253 .37008 Mtetra
.665 .755 .917 r
.65253 .37008 .66086 .38043 .678 .37461 .66974 .36404 Mtetra
.667 .752 .914 r
.66974 .36404 .678 .37461 .69523 .36843 .68705 .35788 Mtetra
.662 .752 .917 r
.68705 .35788 .69523 .36843 .71258 .36252 .70447 .35189 Mtetra
.671 .755 .914 r
.70447 .35189 .71258 .36252 .73002 .3563 .72197 .3455 Mtetra
.696 .762 .903 r
.72197 .3455 .73002 .3563 .74748 .34906 .7395 .33792 Mtetra
.687 .753 .902 r
.7395 .33792 .74748 .34906 .76502 .34153 .75714 .3307 Mtetra
.62 .734 .928 r
.75714 .3307 .76502 .34153 .78286 .33656 .77511 .32626 Mtetra
.469 .674 .953 r
.77511 .32626 .78286 .33656 .80122 .33613 .7936 .32645 Mtetra
.447 .679 .963 r
.7936 .32645 .80122 .33613 .81988 .33692 .8123 .3269 Mtetra
.579 .739 .952 r
.8123 .3269 .81988 .33692 .83842 .33468 .83083 .32362 Mtetra
.688 .754 .902 r
.18372 .52238 .19384 .53144 .20867 .52412 .19847 .51627 Mtetra
.771 .79 .869 r
.19847 .51627 .20867 .52412 .22387 .51324 .2137 .50583 Mtetra
.783 .801 .867 r
.2137 .50583 .22387 .51324 .23908 .50258 .22902 .49473 Mtetra
.717 .789 .908 r
.22902 .49473 .23908 .50258 .25397 .49635 .24406 .48736 Mtetra
.635 .747 .929 r
.24406 .48736 .25397 .49635 .26871 .49279 .2589 .48315 Mtetra
.598 .721 .93 r
.2589 .48315 .26871 .49279 .28353 .48959 .27374 .48015 Mtetra
.635 .738 .923 r
.27374 .48015 .28353 .48959 .29852 .48525 .28876 .47592 Mtetra
.647 .746 .921 r
.28876 .47592 .29852 .48525 .31362 .48055 .30391 .47122 Mtetra
.647 .747 .922 r
.30391 .47122 .31362 .48055 .3288 .476 .31916 .46649 Mtetra
.642 .743 .922 r
.31916 .46649 .3288 .476 .34408 .47135 .33448 .46192 Mtetra
.654 .749 .92 r
.33448 .46192 .34408 .47135 .35947 .46624 .34992 .45688 Mtetra
.658 .753 .92 r
.34992 .45688 .35947 .46624 .37495 .46111 .36545 .45167 Mtetra
.656 .752 .92 r
.36545 .45167 .37495 .46111 .39051 .45617 .38108 .4465 Mtetra
.649 .746 .92 r
.38108 .4465 .39051 .45617 .40616 .45132 .39678 .44156 Mtetra
.651 .746 .919 r
.39678 .44156 .40616 .45132 .42192 .44608 .41259 .43652 Mtetra
.658 .753 .921 r
.41259 .43652 .42192 .44608 .43776 .44075 .42849 .4312 Mtetra
.658 .755 .921 r
.42849 .4312 .43776 .44075 .4537 .43546 .44449 .42581 Mtetra
.657 .754 .921 r
.44449 .42581 .4537 .43546 .46973 .43023 .46059 .42043 Mtetra
.656 .751 .92 r
.46059 .42043 .46973 .43023 .48586 .42504 .47677 .41506 Mtetra
.656 .749 .918 r
.47677 .41506 .48586 .42504 .50208 .41971 .49306 .40967 Mtetra
.655 .748 .918 r
.49306 .40967 .50208 .41971 .5184 .41426 .50944 .40428 Mtetra
.654 .751 .921 r
.50944 .40428 .5184 .41426 .53482 .40883 .52592 .39888 Mtetra
.653 .752 .923 r
.52592 .39888 .53482 .40883 .55133 .40347 .5425 .3935 Mtetra
.654 .754 .923 r
.5425 .3935 .55133 .40347 .56795 .39814 .55918 .38806 Mtetra
.661 .755 .92 r
.55918 .38806 .56795 .39814 .58466 .39272 .57596 .38231 Mtetra
.662 .749 .915 r
.57596 .38231 .58466 .39272 .60147 .38691 .59284 .37647 Mtetra
.656 .748 .918 r
.59284 .37647 .60147 .38691 .61838 .38118 .60982 .37085 Mtetra
.654 .751 .921 r
.60982 .37085 .61838 .38118 .63541 .37564 .62692 .36528 Mtetra
.658 .753 .92 r
.62692 .36528 .63541 .37564 .65253 .37008 .64411 .35953 Mtetra
.668 .754 .915 r
.64411 .35953 .65253 .37008 .66974 .36404 .66138 .35329 Mtetra
.664 .749 .914 r
.66138 .35329 .66974 .36404 .68705 .35788 .67877 .3472 Mtetra
.664 .753 .916 r
.67877 .3472 .68705 .35788 .70447 .35189 .69626 .34108 Mtetra
.674 .755 .912 r
.69626 .34108 .70447 .35189 .72197 .3455 .71383 .33445 Mtetra
.7 .761 .899 r
.71383 .33445 .72197 .3455 .7395 .33792 .73142 .32655 Mtetra
.673 .746 .905 r
.73142 .32655 .7395 .33792 .75714 .3307 .74919 .31989 Mtetra
.589 .723 .936 r
.74919 .31989 .75714 .3307 .77511 .32626 .76731 .31651 Mtetra
.442 .676 .963 r
.76731 .31651 .77511 .32626 .7936 .32645 .78591 .31704 Mtetra
.46 .696 .969 r
.78591 .31704 .7936 .32645 .8123 .3269 .80464 .31691 Mtetra
.617 .76 .947 r
.80464 .31691 .8123 .3269 .83083 .32362 .82313 .31224 Mtetra
.649 .739 .915 r
.17351 .51296 .18372 .52238 .19847 .51627 .18816 .50834 Mtetra
.76 .79 .878 r
.18816 .50834 .19847 .51627 .2137 .50583 .20339 .49861 Mtetra
.786 .807 .869 r
.20339 .49861 .2137 .50583 .22902 .49473 .2188 .48736 Mtetra
.747 .805 .899 r
.2188 .48736 .22902 .49473 .24406 .48736 .23402 .47855 Mtetra
.66 .759 .924 r
.23402 .47855 .24406 .48736 .2589 .48315 .24898 .47342 Mtetra
.603 .723 .929 r
.24898 .47342 .2589 .48315 .27374 .48015 .26387 .47023 Mtetra
.622 .726 .921 r
.26387 .47023 .27374 .48015 .28876 .47592 .27891 .4664 Mtetra
.644 .743 .921 r
.27891 .4664 .28876 .47592 .30391 .47122 .29411 .46177 Mtetra
.65 .747 .921 r
.29411 .46177 .30391 .47122 .31916 .46649 .30941 .45689 Mtetra
.643 .743 .922 r
.30941 .45689 .31916 .46649 .33448 .46192 .32478 .45222 Mtetra
.647 .743 .919 r
.32478 .45222 .33448 .46192 .34992 .45688 .34026 .44738 Mtetra
.657 .752 .92 r
.34026 .44738 .34992 .45688 .36545 .45167 .35585 .44215 Mtetra
.657 .753 .92 r
.35585 .44215 .36545 .45167 .38108 .4465 .37154 .43687 Mtetra
.655 .751 .92 r
.37154 .43687 .38108 .4465 .39678 .44156 .38731 .43165 Mtetra
.65 .744 .919 r
.38731 .43165 .39678 .44156 .41259 .43652 .40316 .4266 Mtetra
.651 .746 .919 r
.40316 .4266 .41259 .43652 .42849 .4312 .41912 .42147 Mtetra
.656 .753 .921 r
.41912 .42147 .42849 .4312 .44449 .42581 .43518 .41611 Mtetra
.657 .755 .922 r
.43518 .41611 .44449 .42581 .46059 .42043 .45133 .41068 Mtetra
.45133 .41068 .46059 .42043 .47677 .41506 .46758 .40524 Mtetra
.656 .755 .923 r
.46758 .40524 .47677 .41506 .49306 .40967 .48393 .39979 Mtetra
.655 .754 .923 r
.48393 .39979 .49306 .40967 .50944 .40428 .50038 .39435 Mtetra
.50038 .39435 .50944 .40428 .52592 .39888 .51692 .38889 Mtetra
.51692 .38889 .52592 .39888 .5425 .3935 .53357 .38336 Mtetra
.661 .754 .92 r
.53357 .38336 .5425 .3935 .55918 .38806 .55032 .37759 Mtetra
.662 .749 .915 r
.55032 .37759 .55918 .38806 .57596 .38231 .56716 .37174 Mtetra
.657 .746 .916 r
.56716 .37174 .57596 .38231 .59284 .37647 .58411 .36606 Mtetra
.654 .751 .92 r
.58411 .36606 .59284 .37647 .60982 .37085 .60117 .36044 Mtetra
.655 .752 .921 r
.60117 .36044 .60982 .37085 .62692 .36528 .61833 .35477 Mtetra
.664 .754 .918 r
.61833 .35477 .62692 .36528 .64411 .35953 .63558 .34869 Mtetra
.667 .75 .912 r
.63558 .34869 .64411 .35953 .66138 .35329 .65293 .34242 Mtetra
.661 .749 .915 r
.65293 .34242 .66138 .35329 .67877 .3472 .6704 .33637 Mtetra
.667 .753 .915 r
.6704 .33637 .67877 .3472 .69626 .34108 .68796 .33005 Mtetra
.685 .757 .906 r
.68796 .33005 .69626 .34108 .71383 .33445 .70558 .32289 Mtetra
.696 .752 .894 r
.70558 .32289 .71383 .33445 .73142 .32655 .72325 .31506 Mtetra
.653 .738 .912 r
.72325 .31506 .73142 .32655 .74919 .31989 .74116 .30923 Mtetra
.543 .708 .947 r
.74116 .30923 .74919 .31989 .76731 .31651 .75947 .30723 Mtetra
.426 .682 .97 r
.75947 .30723 .76731 .31651 .78591 .31704 .77815 .30781 Mtetra
.487 .717 .973 r
.77815 .30781 .78591 .31704 .80464 .31691 .79689 .3068 Mtetra
.66 .778 .936 r
.79689 .3068 .80464 .31691 .82313 .31224 .81532 .30044 Mtetra
.604 .718 .925 r
.16324 .50309 .17351 .51296 .18816 .50834 .17778 .49991 Mtetra
.736 .78 .889 r
.17778 .49991 .18816 .50834 .20339 .49861 .19294 .49145 Mtetra
.783 .81 .874 r
.19294 .49145 .20339 .49861 .2188 .48736 .2084 .48043 Mtetra
.774 .817 .887 r
.2084 .48043 .2188 .48736 .23402 .47855 .22383 .47013 Mtetra
.688 .776 .919 r
.22383 .47013 .23402 .47855 .24898 .47342 .23894 .46388 Mtetra
.622 .735 .928 r
.23894 .46388 .24898 .47342 .26387 .47023 .25393 .46 Mtetra
.607 .717 .922 r
.25393 .46 .26387 .47023 .27891 .4664 .26897 .45663 Mtetra
.638 .738 .92 r
.26897 .45663 .27891 .4664 .29411 .46177 .2842 .45215 Mtetra
.648 .745 .92 r
.2842 .45215 .29411 .46177 .30941 .45689 .29954 .44728 Mtetra
.649 .747 .921 r
.29954 .44728 .30941 .45689 .32478 .45222 .31499 .44235 Mtetra
.643 .741 .92 r
.31499 .44235 .32478 .45222 .34026 .44738 .33051 .4376 Mtetra
.651 .746 .919 r
.33051 .4376 .34026 .44738 .35585 .44215 .34614 .43253 Mtetra
.657 .753 .92 r
.34614 .43253 .35585 .44215 .37154 .43687 .36188 .42719 Mtetra
.36188 .42719 .37154 .43687 .38731 .43165 .37772 .42184 Mtetra
.656 .751 .92 r
.37772 .42184 .38731 .43165 .40316 .4266 .39364 .4165 Mtetra
.652 .745 .917 r
.39364 .4165 .40316 .4266 .41912 .42147 .40966 .41128 Mtetra
.652 .744 .917 r
.40966 .41128 .41912 .42147 .43518 .41611 .42577 .40603 Mtetra
.653 .748 .919 r
.42577 .40603 .43518 .41611 .45133 .41068 .44198 .40069 Mtetra
.655 .752 .921 r
.44198 .40069 .45133 .41068 .46758 .40524 .45829 .39526 Mtetra
.656 .753 .922 r
.45829 .39526 .46758 .40524 .48393 .39979 .4747 .38975 Mtetra
.657 .754 .921 r
.4747 .38975 .48393 .39979 .50038 .39435 .49121 .38417 Mtetra
.658 .753 .92 r
.49121 .38417 .50038 .39435 .51692 .38889 .50783 .3785 Mtetra
.66 .75 .917 r
.50783 .3785 .51692 .38889 .53357 .38336 .52454 .37274 Mtetra
.66 .746 .914 r
.52454 .37274 .53357 .38336 .55032 .37759 .54135 .36695 Mtetra
.656 .746 .916 r
.54135 .36695 .55032 .37759 .56716 .37174 .55826 .36126 Mtetra
.655 .75 .92 r
.55826 .36126 .56716 .37174 .58411 .36606 .57528 .3556 Mtetra
.654 .752 .921 r
.57528 .3556 .58411 .36606 .60117 .36044 .59241 .34991 Mtetra
.66 .754 .919 r
.59241 .34991 .60117 .36044 .61833 .35477 .60964 .34395 Mtetra
.667 .752 .914 r
.60964 .34395 .61833 .35477 .63558 .34869 .62696 .33765 Mtetra
.662 .747 .913 r
.62696 .33765 .63558 .34869 .65293 .34242 .64439 .33152 Mtetra
.663 .751 .916 r
.64439 .33152 .65293 .34242 .6704 .33637 .66193 .32534 Mtetra
.672 .753 .912 r
.66193 .32534 .6704 .33637 .68796 .33005 .67955 .31874 Mtetra
.695 .758 .9 r
.67955 .31874 .68796 .33005 .70558 .32289 .69722 .31098 Mtetra
.683 .742 .896 r
.69722 .31098 .70558 .32289 .72325 .31506 .71501 .30374 Mtetra
.626 .732 .924 r
.71501 .30374 .72325 .31506 .74116 .30923 .73306 .29894 Mtetra
.485 .691 .958 r
.73306 .29894 .74116 .30923 .75947 .30723 .75156 .29839 Mtetra
.427 .697 .977 r
.75156 .29839 .75947 .30723 .77815 .30781 .7703 .29859 Mtetra
.536 .746 .972 r
.7703 .29859 .77815 .30781 .79689 .3068 .78901 .29614 Mtetra
.696 .783 .918 r
.78901 .29614 .79689 .3068 .81532 .30044 .80738 .28814 Mtetra
.571 .698 .928 r
.15292 .49272 .16324 .50309 .17778 .49991 .16738 .49053 Mtetra
.689 .755 .901 r
.16738 .49053 .17778 .49991 .19294 .49145 .18238 .48414 Mtetra
.771 .809 .883 r
.18238 .48414 .19294 .49145 .2084 .48043 .19784 .47384 Mtetra
.786 .826 .883 r
.19784 .47384 .2084 .48043 .22383 .47013 .21341 .46279 Mtetra
.73 .81 .914 r
.21341 .46279 .22383 .47013 .23894 .46388 .22875 .45471 Mtetra
.653 .755 .925 r
.22875 .45471 .23894 .46388 .25393 .46 .24387 .44971 Mtetra
.607 .717 .923 r
.24387 .44971 .25393 .46 .26897 .45663 .25896 .44629 Mtetra
.624 .723 .918 r
.25896 .44629 .26897 .45663 .2842 .45215 .27419 .44228 Mtetra
.644 .741 .919 r
.27419 .44228 .2842 .45215 .29954 .44728 .28958 .43752 Mtetra
.65 .746 .92 r
.28958 .43752 .29954 .44728 .31499 .44235 .30508 .43248 Mtetra
.648 .744 .92 r
.30508 .43248 .31499 .44235 .33051 .4376 .32066 .42752 Mtetra
.645 .74 .918 r
.32066 .42752 .33051 .4376 .34614 .43253 .33634 .42263 Mtetra
.653 .748 .919 r
.33634 .42263 .34614 .43253 .36188 .42719 .35213 .41742 Mtetra
.657 .753 .921 r
.35213 .41742 .36188 .42719 .37772 .42184 .36802 .412 Mtetra
.36802 .412 .37772 .42184 .39364 .4165 .38401 .40656 Mtetra
.656 .751 .92 r
.38401 .40656 .39364 .4165 .40966 .41128 .40009 .40111 Mtetra
.656 .748 .918 r
.40009 .40111 .40966 .41128 .42577 .40603 .41626 .39565 Mtetra
.654 .744 .916 r
.41626 .39565 .42577 .40603 .44198 .40069 .43253 .39021 Mtetra
.655 .743 .915 r
.43253 .39021 .44198 .40069 .45829 .39526 .44891 .38473 Mtetra
.656 .744 .915 r
.44891 .38473 .45829 .39526 .4747 .38975 .46538 .37916 Mtetra
.657 .744 .914 r
.46538 .37916 .4747 .38975 .49121 .38417 .48195 .37351 Mtetra
.48195 .37351 .49121 .38417 .50783 .3785 .49863 .36782 Mtetra
.656 .745 .915 r
.49863 .36782 .50783 .3785 .52454 .37274 .5154 .36213 Mtetra
.656 .748 .918 r
.5154 .36213 .52454 .37274 .54135 .36695 .53228 .35644 Mtetra
.655 .751 .921 r
.53228 .35644 .54135 .36695 .55826 .36126 .54927 .35075 Mtetra
.655 .752 .921 r
.54927 .35075 .55826 .36126 .57528 .3556 .56636 .34502 Mtetra
.659 .754 .92 r
.56636 .34502 .57528 .3556 .59241 .34991 .58355 .33908 Mtetra
.666 .752 .915 r
.58355 .33908 .59241 .34991 .60964 .34395 .60084 .33281 Mtetra
.663 .746 .912 r
.60084 .33281 .60964 .34395 .62696 .33765 .61824 .3266 Mtetra
.661 .749 .915 r
.61824 .3266 .62696 .33765 .64439 .33152 .63575 .32046 Mtetra
.667 .752 .914 r
.63575 .32046 .64439 .33152 .66193 .32534 .65335 .31403 Mtetra
.683 .754 .905 r
.65335 .31403 .66193 .32534 .67955 .31874 .67103 .30683 Mtetra
.694 .748 .893 r
.67103 .30683 .67955 .31874 .69722 .31098 .68877 .29899 Mtetra
.659 .734 .905 r
.68877 .29899 .69722 .31098 .71501 .30374 .7067 .29278 Mtetra
.572 .719 .942 r
.7067 .29278 .71501 .30374 .73306 .29894 .72495 .28977 Mtetra
.435 .695 .974 r
.72495 .28977 .73306 .29894 .75156 .29839 .74357 .28986 Mtetra
.452 .722 .983 r
.74357 .28986 .75156 .29839 .7703 .29859 .76234 .2892 Mtetra
.61 .778 .961 r
.76234 .2892 .7703 .29859 .78901 .29614 .78095 .28444 Mtetra
.716 .771 .896 r
.78095 .28444 .78901 .29614 .80738 .28814 .79931 .27527 Mtetra
.543 .68 .927 r
.14253 .48185 .15292 .49272 .16738 .49053 .15693 .48041 Mtetra
.628 .726 .918 r
.15693 .48041 .16738 .49053 .18238 .48414 .17173 .47634 Mtetra
.748 .8 .894 r
.17173 .47634 .18238 .48414 .19784 .47384 .18714 .46725 Mtetra
.784 .828 .886 r
.18714 .46725 .19784 .47384 .21341 .46279 .20278 .4563 Mtetra
.77 .832 .9 r
.20278 .4563 .21341 .46279 .22875 .45471 .21837 .4462 Mtetra
.688 .78 .921 r
.21837 .4462 .22875 .45471 .24387 .44971 .23367 .43981 Mtetra
.631 .736 .924 r
.23367 .43981 .24387 .44971 .25896 .44629 .24887 .43552 Mtetra
.607 .711 .918 r
.24887 .43552 .25896 .44629 .27419 .44228 .2641 .43205 Mtetra
.636 .733 .918 r
.2641 .43205 .27419 .44228 .28958 .43752 .27952 .42751 Mtetra
.647 .742 .919 r
.27952 .42751 .28958 .43752 .30508 .43248 .29506 .42256 Mtetra
.651 .746 .919 r
.29506 .42256 .30508 .43248 .32066 .42752 .31071 .4174 Mtetra
.648 .743 .918 r
.31071 .4174 .32066 .42752 .33634 .42263 .32645 .41233 Mtetra
.646 .739 .917 r
.32645 .41233 .33634 .42263 .35213 .41742 .34228 .4073 Mtetra
.651 .746 .919 r
.34228 .4073 .35213 .41742 .36802 .412 .35821 .40205 Mtetra
.656 .752 .921 r
.35821 .40205 .36802 .412 .38401 .40656 .37426 .39657 Mtetra
.657 .753 .921 r
.37426 .39657 .38401 .40656 .40009 .40111 .3904 .39104 Mtetra
.3904 .39104 .40009 .40111 .41626 .39565 .40664 .38548 Mtetra
.656 .752 .92 r
.40664 .38548 .41626 .39565 .43253 .39021 .42298 .37991 Mtetra
.656 .75 .919 r
.42298 .37991 .43253 .39021 .44891 .38473 .43941 .3743 Mtetra
.656 .749 .918 r
.43941 .3743 .44891 .38473 .46538 .37916 .45595 .36867 Mtetra
.45595 .36867 .46538 .37916 .48195 .37351 .47259 .36301 Mtetra
.656 .75 .919 r
.47259 .36301 .48195 .37351 .49863 .36782 .48933 .35733 Mtetra
.655 .751 .92 r
.48933 .35733 .49863 .36782 .5154 .36213 .50617 .35162 Mtetra
.655 .752 .921 r
.50617 .35162 .5154 .36213 .53228 .35644 .52312 .3459 Mtetra
.656 .753 .921 r
.52312 .3459 .53228 .35644 .54927 .35075 .54017 .3401 Mtetra
.66 .754 .919 r
.54017 .3401 .54927 .35075 .56636 .34502 .55733 .33408 Mtetra
.665 .751 .914 r
.55733 .33408 .56636 .34502 .58355 .33908 .57458 .32783 Mtetra
.663 .745 .911 r
.57458 .32783 .58355 .33908 .60084 .33281 .59195 .32161 Mtetra
.66 .747 .914 r
.59195 .32161 .60084 .33281 .61824 .3266 .60942 .31547 Mtetra
.664 .751 .915 r
.60942 .31547 .61824 .3266 .63575 .32046 .627 .30912 Mtetra
.673 .751 .909 r
.627 .30912 .63575 .32046 .65335 .31403 .64467 .30234 Mtetra
.695 .754 .897 r
.64467 .30234 .65335 .31403 .67103 .30683 .66239 .29444 Mtetra
.676 .735 .894 r
.66239 .29444 .67103 .30683 .68877 .29899 .68025 .28737 Mtetra
.626 .731 .922 r
.68025 .28737 .68877 .29899 .7067 .29278 .69833 .28248 Mtetra
.497 .701 .961 r
.69833 .28248 .7067 .29278 .72495 .28977 .71679 .28144 Mtetra
.42 .712 .984 r
.71679 .28144 .72495 .28977 .74357 .28986 .73549 .28131 Mtetra
.505 .752 .984 r
.73549 .28131 .74357 .28986 .76234 .2892 .75424 .27925 Mtetra
.678 .796 .937 r
.75424 .27925 .76234 .2892 .78095 .28444 .77274 .27194 Mtetra
.728 .763 .88 r
.77274 .27194 .78095 .28444 .79931 .27527 .79112 .26185 Mtetra
.529 .669 .926 r
.13207 .47066 .14253 .48185 .15693 .48041 .14646 .46956 Mtetra
.583 .698 .921 r
.14646 .46956 .15693 .48041 .17173 .47634 .16113 .46693 Mtetra
.691 .76 .904 r
.16113 .46693 .17173 .47634 .18714 .46725 .17633 .46033 Mtetra
.768 .823 .895 r
.17633 .46033 .18714 .46725 .20278 .4563 .19196 .45023 Mtetra
.784 .843 .896 r
.19196 .45023 .20278 .4563 .21837 .4462 .20771 .43933 Mtetra
.741 .826 .917 r
.20771 .43933 .21837 .4462 .23367 .43981 .22329 .43066 Mtetra
.668 .765 .923 r
.22329 .43066 .23367 .43981 .24887 .43552 .23866 .42495 Mtetra
.621 .722 .919 r
.23866 .42495 .24887 .43552 .2641 .43205 .25397 .42093 Mtetra
.615 .71 .913 r
.25397 .42093 .2641 .43205 .27952 .42751 .26937 .41713 Mtetra
.64 .734 .917 r
.26937 .41713 .27952 .42751 .29506 .42256 .28494 .41238 Mtetra
.648 .742 .918 r
.28494 .41238 .29506 .42256 .31071 .4174 .30064 .40729 Mtetra
.652 .746 .919 r
.30064 .40729 .31071 .4174 .32645 .41233 .31644 .40203 Mtetra
.65 .743 .917 r
.31644 .40203 .32645 .41233 .34228 .4073 .33233 .39678 Mtetra
.648 .739 .916 r
.33233 .39678 .34228 .4073 .35821 .40205 .34832 .39161 Mtetra
.65 .742 .917 r
.34832 .39161 .35821 .40205 .37426 .39657 .36441 .38633 Mtetra
.654 .749 .92 r
.36441 .38633 .37426 .39657 .3904 .39104 .3806 .38086 Mtetra
.656 .752 .921 r
.3806 .38086 .3904 .39104 .40664 .38548 .3969 .37527 Mtetra
.656 .753 .921 r
.3969 .37527 .40664 .38548 .42298 .37991 .4133 .36963 Mtetra
.4133 .36963 .42298 .37991 .43941 .3743 .4298 .36396 Mtetra
.4298 .36396 .43941 .3743 .45595 .36867 .4464 .35827 Mtetra
.4464 .35827 .45595 .36867 .47259 .36301 .46311 .35255 Mtetra
.656 .753 .922 r
.46311 .35255 .47259 .36301 .48933 .35733 .47991 .3468 Mtetra
.656 .753 .921 r
.47991 .3468 .48933 .35733 .50617 .35162 .49683 .34099 Mtetra
.658 .753 .92 r
.49683 .34099 .50617 .35162 .52312 .3459 .51384 .33508 Mtetra
.662 .752 .917 r
.51384 .33508 .52312 .3459 .54017 .3401 .53096 .32896 Mtetra
.664 .747 .912 r
.53096 .32896 .54017 .3401 .55733 .33408 .54819 .32272 Mtetra
.661 .743 .911 r
.54819 .32272 .55733 .33408 .57458 .32783 .56552 .31656 Mtetra
.66 .746 .914 r
.56552 .31656 .57458 .32783 .59195 .32161 .58296 .31041 Mtetra
.663 .75 .915 r
.58296 .31041 .59195 .32161 .60942 .31547 .6005 .30407 Mtetra
.671 .75 .91 r
.6005 .30407 .60942 .31547 .627 .30912 .61814 .29738 Mtetra
.69 .752 .899 r
.61814 .29738 .627 .30912 .64467 .30234 .63585 .28971 Mtetra
.683 .734 .889 r
.63585 .28971 .64467 .30234 .66239 .29444 .65367 .28224 Mtetra
.646 .729 .909 r
.65367 .28224 .66239 .29444 .68025 .28737 .67167 .27651 Mtetra
.556 .719 .949 r
.67167 .27651 .68025 .28737 .69833 .28248 .68996 .27385 Mtetra
.433 .713 .983 r
.68996 .27385 .69833 .28248 .71679 .28144 .70855 .27351 Mtetra
.451 .742 .991 r
.70855 .27351 .71679 .28144 .73549 .28131 .72727 .27237 Mtetra
.603 .791 .971 r
.72727 .27237 .73549 .28131 .75424 .27925 .74592 .26758 Mtetra
.71 .773 .902 r
.74592 .26758 .75424 .27925 .77274 .27194 .76439 .25863 Mtetra
.732 .752 .869 r
.76439 .25863 .77274 .27194 .79112 .26185 .78282 .24805 Mtetra
.538 .675 .926 r
.1215 .45944 .13207 .47066 .14646 .46956 .13594 .45804 Mtetra
.551 .674 .919 r
.13594 .45804 .14646 .46956 .16113 .46693 .15054 .45633 Mtetra
.62 .719 .917 r
.15054 .45633 .16113 .46693 .17633 .46033 .16549 .45242 Mtetra
.734 .802 .906 r
.16549 .45242 .17633 .46033 .19196 .45023 .18101 .44395 Mtetra
.776 .84 .901 r
.18101 .44395 .19196 .45023 .20771 .43933 .19681 .43344 Mtetra
.777 .851 .907 r
.19681 .43344 .20771 .43933 .22329 .43066 .21263 .42297 Mtetra
.716 .809 .923 r
.21263 .42297 .22329 .43066 .23866 .42495 .22824 .4153 Mtetra
.658 .755 .922 r
.22824 .4153 .23866 .42495 .25397 .42093 .24372 .40988 Mtetra
.621 .715 .914 r
.24372 .40988 .25397 .42093 .26937 .41713 .25918 .40582 Mtetra
.619 .711 .911 r
.25918 .40582 .26937 .41713 .28494 .41238 .27474 .40178 Mtetra
.641 .734 .916 r
.27474 .40178 .28494 .41238 .30064 .40729 .29047 .3969 Mtetra
.648 .741 .917 r
.29047 .3969 .30064 .40729 .31644 .40203 .30632 .39171 Mtetra
.652 .745 .918 r
.30632 .39171 .31644 .40203 .33233 .39678 .32227 .38635 Mtetra
.653 .745 .917 r
.32227 .38635 .33233 .39678 .34832 .39161 .33832 .38091 Mtetra
.651 .74 .915 r
.33832 .38091 .34832 .39161 .36441 .38633 .35447 .37553 Mtetra
.65 .739 .914 r
.35447 .37553 .36441 .38633 .3806 .38086 .37072 .37013 Mtetra
.652 .742 .916 r
.37072 .37013 .3806 .38086 .3969 .37527 .38707 .36463 Mtetra
.653 .746 .918 r
.38707 .36463 .3969 .37527 .4133 .36963 .40353 .35904 Mtetra
.655 .748 .919 r
.40353 .35904 .4133 .36963 .4298 .36396 .42009 .35336 Mtetra
.656 .75 .919 r
.42009 .35336 .4298 .36396 .4464 .35827 .43676 .3476 Mtetra
.657 .75 .919 r
.43676 .3476 .4464 .35827 .46311 .35255 .45353 .34176 Mtetra
.658 .75 .917 r
.45353 .34176 .46311 .35255 .47991 .3468 .4704 .33583 Mtetra
.66 .748 .915 r
.4704 .33583 .47991 .3468 .49683 .34099 .48738 .32981 Mtetra
.661 .745 .912 r
.48738 .32981 .49683 .34099 .51384 .33508 .50446 .32369 Mtetra
.661 .742 .91 r
.50446 .32369 .51384 .33508 .53096 .32896 .52165 .31754 Mtetra
.659 .742 .912 r
.52165 .31754 .53096 .32896 .54819 .32272 .53895 .31144 Mtetra
.66 .747 .915 r
.53895 .31144 .54819 .32272 .56552 .31656 .55635 .30526 Mtetra
.663 .749 .914 r
.55635 .30526 .56552 .31656 .58296 .31041 .57386 .2989 Mtetra
.669 .749 .91 r
.57386 .2989 .58296 .31041 .6005 .30407 .59147 .29222 Mtetra
.687 .75 .899 r
.59147 .29222 .6005 .30407 .61814 .29738 .60916 .28466 Mtetra
.684 .734 .888 r
.60916 .28466 .61814 .29738 .63585 .28971 .62695 .27712 Mtetra
.654 .726 .902 r
.62695 .27712 .63585 .28971 .65367 .28224 .6449 .27096 Mtetra
.592 .728 .938 r
.6449 .27096 .65367 .28224 .67167 .27651 .66307 .26713 Mtetra
.47 .715 .976 r
.66307 .26713 .67167 .27651 .68996 .27385 .68153 .26621 Mtetra
.427 .739 .992 r
.68153 .26621 .68996 .27385 .70855 .27351 .70018 .26535 Mtetra
.527 .777 .989 r
.70018 .26535 .70855 .27351 .72727 .27237 .71889 .26237 Mtetra
.686 .801 .936 r
.71889 .26237 .72727 .27237 .74592 .26758 .73743 .25465 Mtetra
.725 .757 .878 r
.73743 .25465 .74592 .26758 .76439 .25863 .75591 .24459 Mtetra
.725 .739 .863 r
.75591 .24459 .76439 .25863 .78282 .24805 .77444 .23418 Mtetra
.581 .707 .929 r
.11073 .4489 .1215 .45944 .13594 .45804 .12536 .44617 Mtetra
.54 .665 .918 r
.12536 .44617 .13594 .45804 .15054 .45633 .13994 .44476 Mtetra
.576 .686 .916 r
.13994 .44476 .15054 .45633 .16549 .45242 .15476 .44226 Mtetra
.658 .742 .912 r
.15476 .44226 .16549 .45242 .18101 .44395 .17 .43688 Mtetra
.749 .825 .911 r
.17 .43688 .18101 .44395 .19681 .43344 .18574 .42767 Mtetra
.777 .855 .909 r
.18574 .42767 .19681 .43344 .21263 .42297 .20165 .41714 Mtetra
.768 .856 .916 r
.20165 .41714 .21263 .42297 .22824 .4153 .21756 .40709 Mtetra
.702 .799 .925 r
.21756 .40709 .22824 .4153 .24372 .40988 .23326 .39989 Mtetra
.656 .75 .92 r
.23326 .39989 .24372 .40988 .25918 .40582 .24888 .39445 Mtetra
.625 .714 .91 r
.24888 .39445 .25918 .40582 .27474 .40178 .26451 .39015 Mtetra
.62 .708 .908 r
.26451 .39015 .27474 .40178 .29047 .3969 .28022 .386 Mtetra
.641 .731 .914 r
.28022 .386 .29047 .3969 .30632 .39171 .2961 .38103 Mtetra
.647 .739 .916 r
.2961 .38103 .30632 .39171 .32227 .38635 .3121 .37578 Mtetra
.651 .744 .917 r
.3121 .37578 .32227 .38635 .33832 .38091 .3282 .37035 Mtetra
.653 .746 .918 r
.3282 .37035 .33832 .38091 .35447 .37553 .34442 .36481 Mtetra
.654 .744 .916 r
.34442 .36481 .35447 .37553 .37072 .37013 .36073 .3592 Mtetra
.654 .741 .914 r
.36073 .3592 .37072 .37013 .38707 .36463 .37715 .35354 Mtetra
.654 .739 .912 r
.37715 .35354 .38707 .36463 .40353 .35904 .39366 .34787 Mtetra
.39366 .34787 .40353 .35904 .42009 .35336 .41029 .34213 Mtetra
.656 .739 .911 r
.41029 .34213 .42009 .35336 .43676 .3476 .42701 .3363 Mtetra
.657 .74 .911 r
.42701 .3363 .43676 .3476 .45353 .34176 .44385 .33039 Mtetra
.658 .74 .911 r
.44385 .33039 .45353 .34176 .4704 .33583 .46078 .32441 Mtetra
.657 .74 .911 r
.46078 .32441 .4704 .33583 .48738 .32981 .47783 .31841 Mtetra
.658 .742 .912 r
.47783 .31841 .48738 .32981 .50446 .32369 .49498 .31236 Mtetra
.658 .745 .914 r
.49498 .31236 .50446 .32369 .52165 .31754 .51224 .30624 Mtetra
.66 .748 .915 r
.51224 .30624 .52165 .31754 .53895 .31144 .5296 .3 Mtetra
.664 .748 .913 r
.5296 .3 .53895 .31144 .55635 .30526 .54707 .29358 Mtetra
.67 .747 .908 r
.54707 .29358 .55635 .30526 .57386 .2989 .56465 .28686 Mtetra
.686 .747 .897 r
.56465 .28686 .57386 .2989 .59147 .29222 .58232 .27929 Mtetra
.68 .73 .887 r
.58232 .27929 .59147 .29222 .60916 .28466 .60009 .27187 Mtetra
.656 .724 .899 r
.60009 .27187 .60916 .28466 .62695 .27712 .61799 .2656 Mtetra
.609 .731 .932 r
.61799 .2656 .62695 .27712 .6449 .27096 .63608 .26115 Mtetra
.497 .72 .971 r
.63608 .26115 .6449 .27096 .66307 .26713 .65443 .25965 Mtetra
.425 .744 .993 r
.65443 .25965 .66307 .26713 .68153 .26621 .67298 .25866 Mtetra
.487 .775 .995 r
.67298 .25866 .68153 .26621 .70018 .26535 .69165 .25632 Mtetra
.646 .81 .962 r
.69165 .25632 .70018 .26535 .71889 .26237 .71025 .25 Mtetra
.714 .765 .892 r
.71025 .25 .71889 .26237 .73743 .25465 .72878 .24065 Mtetra
.726 .742 .864 r
.72878 .24065 .73743 .25465 .75591 .24459 .74731 .23014 Mtetra
.701 .726 .869 r
.74731 .23014 .75591 .24459 .77444 .23418 .76603 .22099 Mtetra
.621 .729 .924 r
.0998 .43867 .11073 .4489 .12536 .44617 .11462 .43465 Mtetra
.562 .683 .921 r
.11462 .43465 .12536 .44617 .13994 .44476 .12931 .43248 Mtetra
.551 .665 .912 r
.12931 .43248 .13994 .44476 .15476 .44226 .14406 .43073 Mtetra
.596 .697 .914 r
.14406 .43073 .15476 .44226 .17 .43688 .1591 .42751 Mtetra
.682 .768 .917 r
.1591 .42751 .17 .43688 .18574 .42767 .17459 .42111 Mtetra
.753 .84 .917 r
.17459 .42111 .18574 .42767 .20165 .41714 .19047 .41171 Mtetra
.773 .867 .918 r
.19047 .41171 .20165 .41714 .21756 .40709 .2065 .40135 Mtetra
.761 .862 .924 r
.2065 .40135 .21756 .40709 .23326 .39989 .22252 .39158 Mtetra
.701 .8 .927 r
.22252 .39158 .23326 .39989 .24888 .39445 .23836 .38435 Mtetra
.66 .753 .919 r
.23836 .38435 .24888 .39445 .26451 .39015 .25414 .37864 Mtetra
.633 .717 .908 r
.25414 .37864 .26451 .39015 .28022 .386 .26994 .37393 Mtetra
.625 .705 .903 r
.26994 .37393 .28022 .386 .2961 .38103 .28582 .36951 Mtetra
.634 .72 .909 r
.28582 .36951 .2961 .38103 .3121 .37578 .30184 .36472 Mtetra
.646 .734 .913 r
.30184 .36472 .3121 .37578 .3282 .37035 .31799 .35943 Mtetra
.65 .74 .915 r
.31799 .35943 .3282 .37035 .34442 .36481 .33425 .35395 Mtetra
.652 .743 .916 r
.33425 .35395 .34442 .36481 .36073 .3592 .35062 .34835 Mtetra
.654 .745 .917 r
.35062 .34835 .36073 .3592 .37715 .35354 .36709 .34264 Mtetra
.655 .746 .917 r
.36709 .34264 .37715 .35354 .39366 .34787 .38368 .33687 Mtetra
.655 .745 .916 r
.38368 .33687 .39366 .34787 .41029 .34213 .40036 .33103 Mtetra
.656 .745 .915 r
.40036 .33103 .41029 .34213 .42701 .3363 .41715 .32514 Mtetra
.41715 .32514 .42701 .3363 .44385 .33039 .43405 .31919 Mtetra
.657 .746 .915 r
.43405 .31919 .44385 .33039 .46078 .32441 .45105 .31317 Mtetra
.658 .747 .916 r
.45105 .31317 .46078 .32441 .47783 .31841 .46816 .30708 Mtetra
.659 .747 .915 r
.46816 .30708 .47783 .31841 .49498 .31236 .48538 .3009 Mtetra
.662 .746 .913 r
.48538 .3009 .49498 .31236 .51224 .30624 .50271 .29458 Mtetra
.665 .745 .91 r
.50271 .29458 .51224 .30624 .5296 .3 .52015 .28806 Mtetra
.675 .744 .903 r
.52015 .28806 .5296 .3 .54707 .29358 .53769 .28102 Mtetra
.681 .736 .892 r
.53769 .28102 .54707 .29358 .56465 .28686 .55533 .27361 Mtetra
.673 .722 .886 r
.55533 .27361 .56465 .28686 .58232 .27929 .57307 .26647 Mtetra
.652 .723 .901 r
.57307 .26647 .58232 .27929 .60009 .27187 .59094 .26035 Mtetra
.611 .734 .933 r
.59094 .26035 .60009 .27187 .61799 .2656 .60897 .2558 Mtetra
.511 .729 .972 r
.60897 .2558 .61799 .2656 .63608 .26115 .62723 .25386 Mtetra
.432 .754 .995 r
.62723 .25386 .63608 .26115 .65443 .25965 .64568 .25255 Mtetra
.471 .78 .998 r
.64568 .25255 .65443 .25965 .67298 .25866 .66428 .25027 Mtetra
.612 .813 .977 r
.66428 .25027 .67298 .25866 .69165 .25632 .68289 .24487 Mtetra
.704 .78 .911 r
.68289 .24487 .69165 .25632 .71025 .25 .70144 .23615 Mtetra
.723 .744 .869 r
.70144 .23615 .71025 .25 .72878 .24065 .71999 .22589 Mtetra
.712 .726 .862 r
.71999 .22589 .72878 .24065 .74731 .23014 .73866 .21602 Mtetra
.679 .725 .884 r
.73866 .21602 .74731 .23014 .76603 .22099 .75755 .20808 Mtetra
.643 .744 .922 r
.08869 .42874 .0998 .43867 .11462 .43465 .10365 .4239 Mtetra
.612 .719 .921 r
.10365 .4239 .11462 .43465 .12931 .43248 .11858 .4201 Mtetra
.555 .666 .911 r
.11858 .4201 .12931 .43248 .14406 .43073 .13337 .41816 Mtetra
.563 .667 .908 r
.13337 .41816 .14406 .43073 .1591 .42751 .14831 .416 Mtetra
.608 .706 .913 r
.14831 .416 .1591 .42751 .17459 .42111 .16355 .41227 Mtetra
.691 .785 .923 r
.16355 .41227 .17459 .42111 .19047 .41171 .17922 .40545 Mtetra
.749 .85 .926 r
.17922 .40545 .19047 .41171 .2065 .40135 .19522 .39615 Mtetra
.766 .876 .927 r
.19522 .39615 .2065 .40135 .22252 .39158 .21135 .38608 Mtetra
.756 .871 .931 r
.21135 .38608 .22252 .39158 .23836 .38435 .22749 .37645 Mtetra
.71 .814 .93 r
.22749 .37645 .23836 .38435 .25414 .37864 .24352 .36875 Mtetra
.669 .764 .921 r
.24352 .36875 .25414 .37864 .26994 .37393 .25949 .3626 Mtetra
.647 .729 .909 r
.25949 .3626 .26994 .37393 .28582 .36951 .27549 .35727 Mtetra
.633 .708 .9 r
.27549 .35727 .28582 .36951 .30184 .36472 .29154 .35243 Mtetra
.632 .708 .901 r
.29154 .35243 .30184 .36472 .31799 .35943 .30771 .3476 Mtetra
.638 .72 .907 r
.30771 .3476 .31799 .35943 .33425 .35395 .324 .34252 Mtetra
.648 .732 .911 r
.324 .34252 .33425 .35395 .35062 .34835 .34041 .33701 Mtetra
.651 .737 .912 r
.34041 .33701 .35062 .34835 .36709 .34264 .35694 .33135 Mtetra
.653 .74 .913 r
.35694 .33135 .36709 .34264 .38368 .33687 .37358 .32557 Mtetra
.655 .741 .914 r
.37358 .32557 .38368 .33687 .40036 .33103 .39033 .3197 Mtetra
.656 .742 .914 r
.39033 .3197 .40036 .33103 .41715 .32514 .40718 .31373 Mtetra
.657 .743 .913 r
.40718 .31373 .41715 .32514 .43405 .31919 .42415 .30768 Mtetra
.658 .743 .912 r
.42415 .30768 .43405 .31919 .45105 .31317 .44122 .30153 Mtetra
.66 .742 .911 r
.44122 .30153 .45105 .31317 .46816 .30708 .4584 .29526 Mtetra
.663 .741 .908 r
.4584 .29526 .46816 .30708 .48538 .3009 .47569 .28884 Mtetra
.672 .741 .902 r
.47569 .28884 .48538 .3009 .50271 .29458 .49309 .28197 Mtetra
.675 .733 .894 r
.49309 .28197 .50271 .29458 .52015 .28806 .51059 .27485 Mtetra
.673 .723 .887 r
.51059 .27485 .52015 .28806 .53769 .28102 .5282 .26773 Mtetra
.662 .718 .89 r
.5282 .26773 .53769 .28102 .55533 .27361 .54591 .26109 Mtetra
.643 .727 .909 r
.54591 .26109 .55533 .27361 .57307 .26647 .56374 .25529 Mtetra
.598 .737 .942 r
.56374 .25529 .57307 .26647 .59094 .26035 .58173 .25107 Mtetra
.512 .744 .979 r
.58173 .25107 .59094 .26035 .60897 .2558 .59991 .24885 Mtetra
.441 .769 .997 r
.59991 .24885 .60897 .2558 .62723 .25386 .61827 .2471 Mtetra
.472 .79 .999 r
.61827 .2471 .62723 .25386 .64568 .25255 .63678 .24457 Mtetra
.596 .818 .985 r
.63678 .24457 .64568 .25255 .66428 .25027 .65535 .23947 Mtetra
.696 .792 .924 r
.65535 .23947 .66428 .25027 .68289 .24487 .67391 .23116 Mtetra
.718 .746 .874 r
.67391 .23116 .68289 .24487 .70144 .23615 .69248 .2212 Mtetra
.716 .726 .858 r
.69248 .2212 .70144 .23615 .71999 .22589 .71112 .21097 Mtetra
.683 .714 .873 r
.71112 .21097 .71999 .22589 .73866 .21602 .72997 .20268 Mtetra
.666 .736 .902 r
.72997 .20268 .73866 .21602 .75755 .20808 .74901 .19545 Mtetra
.657 .753 .921 r
.07743 .41899 .08869 .42874 .10365 .4239 .0925 .41358 Mtetra
.637 .737 .921 r
.0925 .41358 .10365 .4239 .11858 .4201 .10758 .40886 Mtetra
.603 .709 .919 r
.10758 .40886 .11858 .4201 .13337 .41816 .12261 .40527 Mtetra
.56 .662 .905 r
.12261 .40527 .13337 .41816 .14831 .416 .13756 .40316 Mtetra
.572 .669 .904 r
.13756 .40316 .14831 .416 .16355 .41227 .15268 .40064 Mtetra
.613 .708 .913 r
.15268 .40064 .16355 .41227 .17922 .40545 .16808 .39666 Mtetra
.685 .789 .929 r
.16808 .39666 .17922 .40545 .19522 .39615 .18387 .38996 Mtetra
.74 .855 .934 r
.18387 .38996 .19522 .39615 .21135 .38608 .19998 .38101 Mtetra
.755 .882 .936 r
.19998 .38101 .21135 .38608 .22749 .37645 .21622 .37132 Mtetra
.751 .883 .939 r
.21622 .37132 .22749 .37645 .24352 .36875 .23249 .3618 Mtetra
.726 .841 .936 r
.23249 .3618 .24352 .36875 .25949 .3626 .24874 .35332 Mtetra
.682 .784 .927 r
.24874 .35332 .25949 .3626 .27549 .35727 .26491 .34657 Mtetra
.662 .75 .915 r
.26491 .34657 .27549 .35727 .29154 .35243 .28111 .34056 Mtetra
.649 .724 .904 r
.28111 .34056 .29154 .35243 .30771 .3476 .29737 .33501 Mtetra
.641 .709 .896 r
.29737 .33501 .30771 .3476 .324 .34252 .31371 .32972 Mtetra
.641 .706 .894 r
.31371 .32972 .324 .34252 .34041 .33701 .33017 .32439 Mtetra
.643 .712 .897 r
.33017 .32439 .34041 .33701 .35694 .33135 .34674 .31893 Mtetra
.647 .718 .9 r
.34674 .31893 .35694 .33135 .37358 .32557 .36342 .31328 Mtetra
.651 .724 .902 r
.36342 .31328 .37358 .32557 .39033 .3197 .38022 .30745 Mtetra
.655 .727 .902 r
.38022 .30745 .39033 .3197 .40718 .31373 .39713 .30141 Mtetra
.659 .728 .901 r
.39713 .30141 .40718 .31373 .42415 .30768 .41416 .29518 Mtetra
.662 .727 .898 r
.41416 .29518 .42415 .30768 .44122 .30153 .4313 .28876 Mtetra
.665 .725 .894 r
.4313 .28876 .44122 .30153 .4584 .29526 .44855 .28214 Mtetra
.666 .72 .889 r
.44855 .28214 .4584 .29526 .47569 .28884 .4659 .27539 Mtetra
.666 .716 .886 r
.4659 .27539 .47569 .28884 .49309 .28197 .48336 .26859 Mtetra
.66 .716 .89 r
.48336 .26859 .49309 .28197 .51059 .27485 .50093 .26206 Mtetra
.65 .724 .903 r
.50093 .26206 .51059 .27485 .5282 .26773 .5186 .25598 Mtetra
.63 .739 .926 r
.5186 .25598 .5282 .26773 .54591 .26109 .53639 .25065 Mtetra
.572 .744 .958 r
.53639 .25065 .54591 .26109 .56374 .25529 .55433 .2471 Mtetra
.502 .768 .991 r
.55433 .2471 .56374 .25529 .58173 .25107 .57244 .24462 Mtetra
.451 .787 .998 r
.57244 .24462 .58173 .25107 .59991 .24885 .59071 .24233 Mtetra
.487 .805 1 r
.59071 .24233 .59991 .24885 .61827 .2471 .60914 .23929 Mtetra
.602 .825 .985 r
.60914 .23929 .61827 .2471 .63678 .24457 .62765 .23393 Mtetra
.693 .795 .929 r
.62765 .23393 .63678 .24457 .65535 .23947 .64619 .22575 Mtetra
.713 .745 .877 r
.64619 .22575 .65535 .23947 .67391 .23116 .66477 .21604 Mtetra
.714 .724 .857 r
.66477 .21604 .67391 .23116 .69248 .2212 .68341 .20588 Mtetra
.687 .711 .866 r
.68341 .20588 .69248 .2212 .71112 .21097 .70222 .19723 Mtetra
.669 .731 .896 r
.70222 .19723 .71112 .21097 .72997 .20268 .72122 .18974 Mtetra
.654 .742 .914 r
.72122 .18974 .72997 .20268 .74901 .19545 .74039 .18297 Mtetra
.659 .753 .92 r
.06604 .40912 .07743 .41899 .0925 .41358 .08117 .4036 Mtetra
.655 .751 .921 r
.08117 .4036 .0925 .41358 .10758 .40886 .09638 .39818 Mtetra
.634 .733 .919 r
.09638 .39818 .10758 .40886 .12261 .40527 .11158 .39346 Mtetra
.603 .701 .913 r
.11158 .39346 .12261 .40527 .13756 .40316 .12675 .38984 Mtetra
.567 .66 .9 r
.12675 .38984 .13756 .40316 .15268 .40064 .14187 .38745 Mtetra
.577 .668 .9 r
.14187 .38745 .15268 .40064 .16808 .39666 .15716 .38468 Mtetra
.611 .705 .911 r
.15716 .38468 .16808 .39666 .18387 .38996 .17271 .38067 Mtetra
.667 .777 .932 r
.17271 .38067 .18387 .38996 .19998 .38101 .18858 .37457 Mtetra
.723 .852 .942 r
.18858 .37457 .19998 .38101 .21622 .37132 .20477 .3662 Mtetra
.739 .884 .946 r
.20477 .3662 .21622 .37132 .23249 .3618 .2211 .35706 Mtetra
.741 .894 .948 r
.2211 .35706 .23249 .3618 .24874 .35332 .2375 .34777 Mtetra
.73 .877 .949 r
.2375 .34777 .24874 .35332 .26491 .34657 .25393 .33895 Mtetra
.709 .829 .939 r
.25393 .33895 .26491 .34657 .28111 .34056 .27036 .33104 Mtetra
.678 .783 .929 r
.27036 .33104 .28111 .34056 .29737 .33501 .28677 .32433 Mtetra
.665 .756 .918 r
.28677 .32433 .29737 .33501 .31371 .32972 .30324 .31806 Mtetra
.657 .736 .908 r
.30324 .31806 .31371 .32972 .33017 .32439 .31979 .31205 Mtetra
.653 .723 .9 r
.31979 .31205 .33017 .32439 .34674 .31893 .33643 .30612 Mtetra
.652 .715 .895 r
.33643 .30612 .34674 .31893 .36342 .31328 .35318 .3002 Mtetra
.652 .712 .891 r
.35318 .3002 .36342 .31328 .38022 .30745 .37004 .29422 Mtetra
.654 .711 .89 r
.37004 .29422 .38022 .30745 .39713 .30141 .38701 .28811 Mtetra
.656 .712 .889 r
.38701 .28811 .39713 .30141 .41416 .29518 .40409 .28188 Mtetra
.656 .713 .89 r
.40409 .28188 .41416 .29518 .4313 .28876 .42128 .27558 Mtetra
.656 .717 .893 r
.42128 .27558 .4313 .28876 .44855 .28214 .43858 .26929 Mtetra
.653 .723 .9 r
.43858 .26929 .44855 .28214 .4659 .27539 .45599 .26309 Mtetra
.647 .733 .911 r
.45599 .26309 .4659 .27539 .48336 .26859 .4735 .25713 Mtetra
.635 .746 .929 r
.4735 .25713 .48336 .26859 .50093 .26206 .49113 .25163 Mtetra
.595 .755 .954 r
.49113 .25163 .50093 .26206 .5186 .25598 .50887 .24735 Mtetra
.544 .777 .984 r
.50887 .24735 .5186 .25598 .53639 .25065 .52676 .244 Mtetra
.484 .799 .999 r
.52676 .244 .53639 .25065 .55433 .2471 .5448 .24115 Mtetra
.471 .81 .999 r
.5448 .24115 .55433 .2471 .57244 .24462 .563 .23814 Mtetra
.518 .821 1 r
.563 .23814 .57244 .24462 .59071 .24233 .58135 .23437 Mtetra
.628 .833 .979 r
.58135 .23437 .59071 .24233 .60914 .23929 .5998 .22825 Mtetra
.694 .788 .923 r
.5998 .22825 .60914 .23929 .62765 .23393 .61831 .21997 Mtetra
.71 .74 .876 r
.61831 .21997 .62765 .23393 .64619 .22575 .63688 .21039 Mtetra
.71 .719 .857 r
.63688 .21039 .64619 .22575 .66477 .21604 .65552 .20038 Mtetra
.687 .707 .863 r
.65552 .20038 .66477 .21604 .68341 .20588 .67431 .19164 Mtetra
.67 .724 .89 r
.67431 .19164 .68341 .20588 .70222 .19723 .69327 .18402 Mtetra
.656 .739 .911 r
.69327 .18402 .70222 .19723 .72122 .18974 .71239 .17712 Mtetra
.653 .751 .921 r
.71239 .17712 .72122 .18974 .74039 .18297 .73165 .17031 Mtetra
.65 .747 .92 r
.05455 .39892 .06604 .40912 .08117 .4036 .0697 .39362 Mtetra
.66 .755 .921 r
.0697 .39362 .08117 .4036 .09638 .39818 .08498 .38796 Mtetra
.654 .75 .92 r
.08498 .38796 .09638 .39818 .11158 .39346 .10033 .38249 Mtetra
.635 .731 .917 r
.10033 .38249 .11158 .39346 .12675 .38984 .11568 .37765 Mtetra
.608 .699 .908 r
.11568 .37765 .12675 .38984 .14187 .38745 .13101 .37375 Mtetra
.575 .66 .895 r
.13101 .37375 .14187 .38745 .15716 .38468 .14632 .37103 Mtetra
.581 .664 .896 r
.14632 .37103 .15716 .38468 .17271 .38067 .16176 .36807 Mtetra
.606 .695 .906 r
.16176 .36807 .17271 .38067 .18858 .37457 .17744 .36416 Mtetra
.641 .751 .928 r
.17744 .36416 .18858 .37457 .20477 .3662 .19336 .35893 Mtetra
.698 .833 .948 r
.19336 .35893 .20477 .3662 .2211 .35706 .2096 .35146 Mtetra
.719 .875 .954 r
.2096 .35146 .2211 .35706 .2375 .34777 .22602 .34305 Mtetra
.722 .896 .958 r
.22602 .34305 .2375 .34777 .25393 .33895 .24253 .33432 Mtetra
.718 .899 .961 r
.24253 .33432 .25393 .33895 .27036 .33104 .25911 .32565 Mtetra
.71 .883 .961 r
.25911 .32565 .27036 .33104 .28677 .32433 .27573 .31738 Mtetra
.7 .849 .954 r
.27573 .31738 .28677 .32433 .30324 .31806 .29239 .30961 Mtetra
.687 .814 .943 r
.29239 .30961 .30324 .31806 .31979 .31205 .3091 .30239 Mtetra
.67 .785 .935 r
.3091 .30239 .31979 .31205 .33643 .30612 .32586 .29581 Mtetra
.663 .771 .929 r
.32586 .29581 .33643 .30612 .35318 .3002 .3427 .28943 Mtetra
.659 .761 .925 r
.3427 .28943 .35318 .3002 .37004 .29422 .35963 .28317 Mtetra
.656 .756 .923 r
.35963 .28317 .37004 .29422 .38701 .28811 .37667 .27699 Mtetra
.653 .755 .924 r
.37667 .27699 .38701 .28811 .40409 .28188 .39381 .27089 Mtetra
.649 .758 .929 r
.39381 .27089 .40409 .28188 .42128 .27558 .41106 .26491 Mtetra
.642 .764 .937 r
.41106 .26491 .42128 .27558 .43858 .26929 .42842 .25914 Mtetra
.621 .769 .951 r
.42842 .25914 .43858 .26929 .45599 .26309 .44587 .25401 Mtetra
.596 .786 .971 r
.44587 .25401 .45599 .26309 .4735 .25713 .46344 .24944 Mtetra
.559 .806 .991 r
.46344 .24944 .4735 .25713 .49113 .25163 .48114 .24539 Mtetra
.512 .821 1 r
.48114 .24539 .49113 .25163 .50887 .24735 .49898 .24175 Mtetra
.49 .827 .999 r
.49898 .24175 .50887 .24735 .52676 .244 .51697 .23817 Mtetra
.508 .831 .999 r
.51697 .23817 .52676 .244 .5448 .24115 .53511 .23429 Mtetra
.569 .835 .995 r
.53511 .23429 .5448 .24115 .563 .23814 .55339 .22944 Mtetra
.663 .829 .963 r
.55339 .22944 .563 .23814 .58135 .23437 .57179 .22229 Mtetra
.696 .769 .908 r
.57179 .22229 .58135 .23437 .5998 .22825 .59026 .21378 Mtetra
.706 .732 .871 r
.59026 .21378 .5998 .22825 .61831 .21997 .60882 .20425 Mtetra
.704 .713 .855 r
.60882 .20425 .61831 .21997 .63688 .21039 .62746 .19446 Mtetra
.683 .702 .862 r
.62746 .19446 .63688 .21039 .65552 .20038 .64623 .18588 Mtetra
.669 .721 .888 r
.64623 .18588 .65552 .20038 .67431 .19164 .66516 .17824 Mtetra
.657 .737 .909 r
.66516 .17824 .67431 .19164 .69327 .18402 .68424 .17126 Mtetra
.652 .749 .92 r
.68424 .17126 .69327 .18402 .71239 .17712 .70346 .16446 Mtetra
.66 .756 .921 r
.70346 .16446 .71239 .17712 .73165 .17031 .72279 .15726 Mtetra
.651 .748 .92 r
.04294 .38863 .05455 .39892 .0697 .39362 .05814 .38324 Mtetra
.651 .747 .92 r
.05814 .38324 .0697 .39362 .08498 .38796 .07342 .37783 Mtetra
.66 .756 .921 r
.07342 .37783 .08498 .38796 .10033 .38249 .08885 .37207 Mtetra
.654 .749 .92 r
.08885 .37207 .10033 .38249 .11568 .37765 .10435 .36647 Mtetra
.638 .731 .915 r
.10435 .36647 .11568 .37765 .13101 .37375 .11986 .36143 Mtetra
.62 .704 .906 r
.11986 .36143 .13101 .37375 .14632 .37103 .13539 .35702 Mtetra
.585 .662 .891 r
.13539 .35702 .14632 .37103 .16176 .36807 .15089 .35388 Mtetra
.585 .66 .889 r
.15089 .35388 .16176 .36807 .17744 .36416 .1665 .35072 Mtetra
.601 .681 .897 r
.1665 .35072 .17744 .36416 .19336 .35893 .1823 .34692 Mtetra
.625 .717 .913 r
.1823 .34692 .19336 .35893 .2096 .35146 .19831 .3422 Mtetra
.653 .784 .943 r
.19831 .3422 .2096 .35146 .22602 .34305 .21455 .33634 Mtetra
.692 .85 .958 r
.21455 .33634 .22602 .34305 .24253 .33432 .23103 .32888 Mtetra
.698 .88 .966 r
.23103 .32888 .24253 .33432 .25911 .32565 .24763 .32095 Mtetra
.695 .897 .97 r
.24763 .32095 .25911 .32565 .27573 .31738 .26433 .31292 Mtetra
.687 .902 .973 r
.26433 .31292 .27573 .31738 .29239 .30961 .2811 .30499 Mtetra
.678 .899 .976 r
.2811 .30499 .29239 .30961 .3091 .30239 .29794 .29731 Mtetra
.668 .889 .978 r
.29794 .29731 .3091 .30239 .32586 .29581 .31484 .28999 Mtetra
.661 .872 .978 r
.31484 .28999 .32586 .29581 .3427 .28943 .3318 .28303 Mtetra
.652 .859 .979 r
.3318 .28303 .3427 .28943 .35963 .28317 .34885 .27643 Mtetra
.641 .85 .98 r
.34885 .27643 .35963 .28317 .37667 .27699 .36598 .27018 Mtetra
.627 .846 .983 r
.36598 .27018 .37667 .27699 .39381 .27089 .3832 .26429 Mtetra
.608 .846 .989 r
.3832 .26429 .39381 .27089 .41106 .26491 .40053 .25876 Mtetra
.585 .849 .994 r
.40053 .25876 .41106 .26491 .42842 .25914 .41796 .2536 Mtetra
.555 .853 .998 r
.41796 .2536 .42842 .25914 .44587 .25401 .4355 .2488 Mtetra
.532 .852 .998 r
.4355 .2488 .44587 .25401 .46344 .24944 .45318 .24426 Mtetra
.523 .85 .997 r
.45318 .24426 .46344 .24944 .48114 .24539 .47099 .23983 Mtetra
.534 .848 .998 r
.47099 .23983 .48114 .24539 .49898 .24175 .48894 .2353 Mtetra
.57 .844 .996 r
.48894 .2353 .49898 .24175 .51697 .23817 .50703 .2303 Mtetra
.644 .84 .976 r
.50703 .2303 .51697 .23817 .53511 .23429 .52527 .22367 Mtetra
.683 .794 .933 r
.52527 .22367 .53511 .23429 .55339 .22944 .54362 .21586 Mtetra
.696 .743 .887 r
.54362 .21586 .55339 .22944 .57179 .22229 .56206 .20707 Mtetra
.701 .719 .863 r
.56206 .20707 .57179 .22229 .59026 .21378 .5806 .19763 Mtetra
.697 .705 .853 r
.5806 .19763 .59026 .21378 .60882 .20425 .59922 .18814 Mtetra
.675 .697 .863 r
.59922 .18814 .60882 .20425 .62746 .19446 .61798 .17993 Mtetra
.667 .721 .889 r
.61798 .17993 .62746 .19446 .64623 .18588 .63688 .17238 Mtetra
.656 .736 .909 r
.63688 .17238 .64623 .18588 .66516 .17824 .65592 .16538 Mtetra
.652 .748 .92 r
.65592 .16538 .66516 .17824 .68424 .17126 .6751 .15855 Mtetra
.66 .756 .921 r
.6751 .15855 .68424 .17126 .70346 .16446 .6944 .15133 Mtetra
.659 .749 .917 r
.6944 .15133 .70346 .16446 .72279 .15726 .71382 .14408 Mtetra
.655 .751 .92 r
.03118 .37835 .04294 .38863 .05814 .38324 .04644 .37275 Mtetra
.652 .747 .92 r
.04644 .37275 .05814 .38324 .07342 .37783 .06179 .36726 Mtetra
.651 .747 .92 r
.06179 .36726 .07342 .37783 .08885 .37207 .07722 .36175 Mtetra
.659 .755 .921 r
.07722 .36175 .08885 .37207 .10435 .36647 .09279 .35591 Mtetra
.656 .751 .92 r
.09279 .35591 .10435 .36647 .11986 .36143 .10844 .35016 Mtetra
.644 .734 .915 r
.10844 .35016 .11986 .36143 .13539 .35702 .12413 .34482 Mtetra
.629 .713 .907 r
.12413 .34482 .13539 .35702 .15089 .35388 .13985 .33999 Mtetra
.604 .675 .891 r
.13985 .33999 .15089 .35388 .1665 .35072 .15558 .33605 Mtetra
.591 .658 .884 r
.15558 .33605 .1665 .35072 .1823 .34692 .17137 .33254 Mtetra
.598 .667 .887 r
.17137 .33254 .1823 .34692 .19831 .3422 .18731 .32876 Mtetra
.613 .69 .898 r
.18731 .32876 .19831 .3422 .21455 .33634 .20344 .32437 Mtetra
.631 .725 .915 r
.20344 .32437 .21455 .33634 .23103 .32888 .21974 .31929 Mtetra
.647 .78 .945 r
.21974 .31929 .23103 .32888 .24763 .32095 .23622 .31352 Mtetra
.667 .834 .963 r
.23622 .31352 .24763 .32095 .26433 .31292 .25288 .3068 Mtetra
.673 .866 .972 r
.25288 .3068 .26433 .31292 .2811 .30499 .26968 .29962 Mtetra
.666 .883 .978 r
.26968 .29962 .2811 .30499 .29794 .29731 .28658 .29241 Mtetra
.655 .891 .982 r
.28658 .29241 .29794 .29731 .31484 .28999 .30356 .28531 Mtetra
.641 .893 .985 r
.30356 .28531 .31484 .28999 .3318 .28303 .32062 .27843 Mtetra
.626 .892 .987 r
.32062 .27843 .3318 .28303 .34885 .27643 .33777 .27182 Mtetra
.611 .889 .99 r
.33777 .27182 .34885 .27643 .36598 .27018 .355 .2655 Mtetra
.597 .884 .991 r
.355 .2655 .36598 .27018 .3832 .26429 .37234 .25949 Mtetra
.584 .878 .993 r
.37234 .25949 .3832 .26429 .40053 .25876 .38977 .25375 Mtetra
.575 .872 .995 r
.38977 .25375 .40053 .25876 .41796 .2536 .40732 .24823 Mtetra
.574 .866 .996 r
.40732 .24823 .41796 .2536 .4355 .2488 .42498 .24283 Mtetra
.584 .858 .995 r
.42498 .24283 .4355 .2488 .45318 .24426 .44278 .23739 Mtetra
.613 .85 .988 r
.44278 .23739 .45318 .24426 .47099 .23983 .46072 .23148 Mtetra
.655 .832 .968 r
.46072 .23148 .47099 .23983 .48894 .2353 .47879 .22462 Mtetra
.678 .79 .934 r
.47879 .22462 .48894 .2353 .50703 .2303 .49699 .21704 Mtetra
.688 .745 .895 r
.49699 .21704 .50703 .2303 .52527 .22367 .51531 .20874 Mtetra
.694 .72 .87 r
.51531 .20874 .52527 .22367 .54362 .21586 .53372 .1998 Mtetra
.694 .704 .856 r
.53372 .1998 .54362 .21586 .56206 .20707 .55223 .19057 Mtetra
.684 .695 .854 r
.55223 .19057 .56206 .20707 .5806 .19763 .57084 .18177 Mtetra
.67 .7 .869 r
.57084 .18177 .5806 .19763 .59922 .18814 .58958 .17386 Mtetra
.664 .725 .895 r
.58958 .17386 .59922 .18814 .61798 .17993 .60844 .16646 Mtetra
.655 .738 .91 r
.60844 .16646 .61798 .17993 .63688 .17238 .62744 .15949 Mtetra
.653 .749 .921 r
.62744 .15949 .63688 .17238 .65592 .16538 .64658 .15259 Mtetra
.66 .756 .921 r
.64658 .15259 .65592 .16538 .6751 .15855 .66583 .14534 Mtetra
.659 .749 .917 r
.66583 .14534 .6751 .15855 .6944 .15133 .68522 .13805 Mtetra
.656 .748 .918 r
.68522 .13805 .6944 .15133 .71382 .14408 .70475 .13086 Mtetra
.658 .754 .921 r
.01927 .36805 .03118 .37835 .04644 .37275 .0346 .36229 Mtetra
.656 .751 .92 r
.0346 .36229 .04644 .37275 .06179 .36726 .05001 .35659 Mtetra
.652 .747 .919 r
.05001 .35659 .06179 .36726 .07722 .36175 .0655 .35098 Mtetra
.651 .746 .919 r
.0655 .35098 .07722 .36175 .09279 .35591 .08108 .34537 Mtetra
.657 .754 .921 r
.08108 .34537 .09279 .35591 .10844 .35016 .09679 .33949 Mtetra
.658 .753 .92 r
.09679 .33949 .10844 .35016 .12413 .34482 .1126 .33356 Mtetra
.65 .74 .916 r
.1126 .33356 .12413 .34482 .13985 .33999 .12848 .3279 Mtetra
.638 .722 .908 r
.12848 .3279 .13985 .33999 .15558 .33605 .1444 .32261 Mtetra
.626 .695 .894 r
.1444 .32261 .15558 .33605 .17137 .33254 .16038 .31772 Mtetra
.604 .664 .881 r
.16038 .31772 .17137 .33254 .18731 .32876 .17638 .31361 Mtetra
.602 .659 .878 r
.17638 .31361 .18731 .32876 .20344 .32437 .19249 .30955 Mtetra
.608 .668 .882 r
.19249 .30955 .20344 .32437 .21974 .31929 .20875 .30523 Mtetra
.619 .686 .891 r
.20875 .30523 .21974 .31929 .23622 .31352 .22517 .30046 Mtetra
.63 .71 .903 r
.22517 .30046 .23622 .31352 .25288 .3068 .24175 .29524 Mtetra
.641 .743 .923 r
.24175 .29524 .25288 .3068 .26968 .29962 .25847 .28962 Mtetra
.647 .778 .943 r
.25847 .28962 .26968 .29962 .28658 .29241 .27534 .28366 Mtetra
.649 .808 .959 r
.27534 .28366 .28658 .29241 .30356 .28531 .29233 .27748 Mtetra
.648 .829 .97 r
.29233 .27748 .30356 .28531 .32062 .27843 .30943 .27116 Mtetra
.644 .842 .976 r
.30943 .27116 .32062 .27843 .33777 .27182 .32665 .26479 Mtetra
.641 .848 .979 r
.32665 .26479 .33777 .27182 .355 .2655 .34398 .25841 Mtetra
.64 .848 .98 r
.34398 .25841 .355 .2655 .37234 .25949 .36143 .25201 Mtetra
.643 .842 .977 r
.36143 .25201 .37234 .25949 .38977 .25375 .37898 .24556 Mtetra
.65 .83 .969 r
.37898 .24556 .38977 .25375 .40732 .24823 .39666 .23897 Mtetra
.659 .811 .956 r
.39666 .23897 .40732 .24823 .42498 .24283 .41446 .23215 Mtetra
.669 .785 .936 r
.41446 .23215 .42498 .24283 .44278 .23739 .43239 .22499 Mtetra
.676 .755 .91 r
.43239 .22499 .44278 .23739 .46072 .23148 .45043 .21741 Mtetra
.681 .728 .886 r
.45043 .21741 .46072 .23148 .47879 .22462 .4686 .20936 Mtetra
.685 .711 .869 r
.4686 .20936 .47879 .22462 .49699 .21704 .48687 .20084 Mtetra
.686 .699 .857 r
.48687 .20084 .49699 .21704 .51531 .20874 .50525 .19204 Mtetra
.683 .692 .852 r
.50525 .19204 .51531 .20874 .53372 .1998 .52373 .18328 Mtetra
.669 .69 .861 r
.52373 .18328 .53372 .1998 .55223 .19057 .54231 .17531 Mtetra
.665 .709 .881 r
.54231 .17531 .55223 .19057 .57084 .18177 .56101 .16773 Mtetra
.659 .729 .901 r
.56101 .16773 .57084 .18177 .58958 .17386 .57984 .16052 Mtetra
.654 .741 .914 r
.57984 .16052 .58958 .17386 .60844 .16646 .5988 .15358 Mtetra
.654 .752 .921 r
.5988 .15358 .60844 .16646 .62744 .15949 .61789 .14658 Mtetra
.66 .755 .921 r
.61789 .14658 .62744 .15949 .64658 .15259 .63711 .13929 Mtetra
.659 .749 .917 r
.63711 .13929 .64658 .15259 .66583 .14534 .65645 .13198 Mtetra
.656 .748 .918 r
.65645 .13198 .66583 .14534 .68522 .13805 .67594 .12475 Mtetra
.654 .75 .921 r
.67594 .12475 .68522 .13805 .70475 .13086 .69556 .11757 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
[(-2)] .12586 .2075 1 .99877 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.56863 .04703 m
.57247 .05235 L
s
[(2)] .56094 .0364 .72324 1 Mshowa
.125 Mabswid
.18558 .19702 m
.18832 .19985 L
s
.23703 .17687 m
.23971 .17975 L
s
.28951 .15632 m
.29214 .15925 L
s
.39772 .11395 m
.40023 .11699 L
s
.4535 .09211 m
.45595 .0952 L
s
.51046 .06981 m
.51284 .07294 L
s
.08568 .23614 m
.08851 .23887 L
s
.62804 .02377 m
.63027 .02701 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 233.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00o?ooool2o`0006[ooooo003iooooo`?o000000?oooooo`000?ooool0
JOooool00?Oooooo0_l00004ooooo`;o0000JOooool00?Cooooo0ol00006ooooo`03o`000?oooooo
000006Sooooo003;ooooo`Go00008_ooool2o`0000Wooooo00?o0000ooooool00000J?ooool00<_o
oooo00GoV9RHob4Q8Oo^k^koooooodA4A00Oooooo`?o00002oooool01?l0003oooooooooool0001W
ooooo`00c?ooool00onHV9So8B4Qonk^kP0Mooooo`?o00003_ooool01Ol0003ooooooooooooooooo
000006Kooooo003=ooooo`03oiRHV?lQ8B7ok^k^01[ooooo0_l0000Aooooo`05o`000?oooooooooo
ooooool00000I_ooool00<kooooo00?oMgMgofIVI_ooool05_ooool3o`0001?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1Sooooo`00coooool00ol0003oooooooooo`0Cooooo`;o
00000_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0H_ooool00<_ooooo00Go0000okZj^_ooooooV9RHoa0@400Booooo`?o00006Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo06;ooooo003;ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`04?ooool2o`0001cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Qooooo`00
gOooool3o`0001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Qooooo`00fooo
ool2o`00027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Pooooo`00f?ooool3
o`0002?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Oooooo`00eOooool3o`00
02Kooooo00?o0000ooooooooool01?ooool2o`00067ooooo003Cooooo`;o0000:Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo05kooooo003@ooooo`?o000000?oooooo`000?ooool0
:?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05gooooo003>ooooo`;o00001Ooo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0GOoo
ool00<_ooooo0ol0000`ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0G?ooool0
0<Wooooo0_l0000cooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Foooool00<Ko
oooo0ol0000eooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Foooool00<Cooooo
0_l0000hooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0F_ooool00<7ooooo0ol0
000jooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03_ooool5o`0004Kooooo002n
ooooo`?o0000?Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00kooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A016ooooo`00_?ooool2o`0000?ooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo1_l00003ooooo`03oiRHV?lQ8B7o
k^k^04Oooooo002iooooo`?o0000@oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00kooooo00?oV9RHob4Q8Oo^k^h0A_ooool00;Oooooo0_l00016ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03oooool00omgMgOoIVIVooooo`15ooooo`00]?ooool3o`0004Sooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Cooooo
002booooo`;o0000Boooool00ol0003oooooooooo`0=ooooo`;o00003?ooool01Ol0003o^[Zjoooo
oonHV9So410@04Kooooo002_ooooo`?o0000COooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c016ooooo`00[Oooool2o`00053ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`1Dooooo`00Z_ooool4o`00057ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1Dooooo`00Z?ooool2o`0000Cooooo00?o0000oooo
ooooool0C_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05?ooooo001nooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h08_ooool3o`0005Oooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`1Booooo`00O_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01oooooo0ol0001Joooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool0D_ooool007kooooo00Go410@oooooooo
oooooooooa0@400Mooooo`;o0000GOooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
057ooooo001nooooo`05o`000?ooooooooooooooool000006_ooool3o`0005oooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`1@ooooo`00O_ooool01Ol0003ooooooooooooooooo0000
01Sooooo0_l0001Rooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0D?ooool007ko
oooo00Go410@oooooooooooooooooa0@400Eooooo`?o0000I?ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo04oooooo001nooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool2o`00
00?ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
04kooooo001nooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04?ooool3o`0006Sooooo00?oYko[o`00
0?ooool05_ooool00ol0003oooooooooo`1>ooooo`00TOooool2o`0006Sooooo1?nW_n/00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo04gooooo002>ooooo`?o0000J?ooool7ojNoj`03o`00
0?oooooooooo01Cooooo0ol0001>ooooo`00Roooool3o`0006Wooooo2OnW_n/00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo04cooooo0029ooooo`;o0000JOooool<ojNoj`03o`000?nW_n_o
oooo01Oooooo00?o0000ooooooooool0Boooool008Kooooo0ol0001Xooooo`03ojRoj_nW_n_oYko[
00coYko[00?o0000ojNojoooool06?ooool00ol0003oooooooooo`1:ooooo`00Q?ooool2o`0000;o
oooo00?o0000ooooooooool0Hoooool5ojRojPgoYko[00?o0000ojNojonW_n/06?ooool00ol0003o
ooooooooo`1:ooooo`00POooool3o`0000Gooooo00?o0000ooooooooool0H?ooool8ojRojPOoYko[
00?oZ;oZojNojonW_n/00_nW_n/01?l0003oYko[ojNojonW_n/Hooooo`03o`000?oooooooooo04Wo
oooo001oooooo`;o0000JOooool00onX`N_oZ;oZojRojP07ojRojPCoYko[1OnX_nX3ojNoj`03o`00
0?nW_n_oYko[00;oYko[6?ooool00ol0003oooooooooo`18ooooo`00O?ooool3o`0006Sooooo1OnX
`N/9ojRojP03ojNojonX_n[oZ;oZ00KoZ;oZ0_nW_n/01Ol0003oYko[ojNojonW_n_oZ;oZ01Sooooo
00?o0000ooooooooool0B?ooool007[ooooo0_l0001Wooooo`;oYl3[2?nX`N/6ojRojP;oZ<7[2OnX
_nX2ojNoj`03o`000?nW_n_oZ;oZ00?oZ;oZ6?ooool00ol0003oooooooooo`17ooooo`00Moooool3
o`0006Kooooo1_nW`>/8ojS1j`;oZ;oZ1_nX`N/9ojRojP03ojNojol0003oZ;oZ00GoZ;oZ6?ooool0
0ol0003oooooooooo`16ooooo`00M?ooool3o`0006Kooooo00?oYkgYojO0jonW`>/01onW`>/6ojS1
j`;oYko[2?nX`N/6ojRojP;oZ<7[00?oZ;oZo`000?nX_nX01OnX_nXHooooo`03o`000?oooooooooo
04Kooooo001booooo`;o00000_ooool00ol0003oooooooooo`1Rooooo`CoYkgY2OnW`>/2ojS1j`Ko
Yko[2?nX`N/2ojRojPKoZ<7[00?o0000ojRoj_nX_nX01OnX_nXHooooo`03o`000?oooooooooo04Go
oooo001_ooooo`?o0000Ioooool7ojNmj@OoYl3[00?oYkcXojNojonW_n/01onW_n/6ojS1j`03ojJo
jonX`N_oZ<7[00KoZ<7[00?o0000ojRoj_nX_nX01?nX_nX00onX`N_oooooooooo`0Fooooo`03o`00
0?oooooooooo04Gooooo001]ooooo`;o0000Ioooool2ojRjiPSoYkgY1?nW`>/5ojNlj0WoYko[0_nX
`N/5ojJoj`OoZ<7[00Co0000ojS1jonX_n[oZ;oZ1OnX`N/Gooooo`;o0000A_ooool006[ooooo0ol0
001Vooooo`KoZ;[V2?nW_NT00onW`>_oYkcXojNlj006ojNlj0OoYko[00?oYkcXojJojonV_n/01_nV
_n/6ojS1j`03o`000?nV_n_oZ<7[00OoZ<7[6?ooool00ol0003oooooooooo`13ooooo`00J?ooool2
o`0006Kooooo00?oZ[GQojRji_nX^^H01onX^^H6ojNmj@;oZKWU2?nW_>P4ojNoj`GoYkcX2?nV_n/2
ojS1j`?oY[o[00?o0000ojJojonV_n/02?nX`N/Gooooo`03o`000?oooooooooo04?ooooo001Uoooo
o`?o0000I_ooool4ojZeh@WoZ;[V0_nW_NT6ojVii@SoYkcX00?oYko[ojNlj?nW_>P01_nW_>P6ojJo
j`03ojRlj?nV_n_oY[o[00?oY[o[00Co0000ojJojonV_n_oY[o[1_nX`N/00onW`>_oooooooooo`0F
ooooo`03o`000?oooooooooo04;ooooo001Sooooo`;o0000Ioooool7ojZeh@OoZ;[V00?oZk?NojVi
iOnY^ND01onY^ND6ojNlj003ojZhhonW_>SoYkcX00OoYkcX1?nV_n/4ojRlj0GoY[o[00Co0000ojJo
jonV_n_oY[o[0_nX`N/5ojO0jaSooooo00?o0000ooooooooool0@Oooool0063ooooo0ol000000ooo
oooo0000ooooo`1Tooooo`03oj^`g?nZ]N7oZ[GQ00OoZ[GQ1?nX^^H4oj^cgPWoZKWU0_nW_>P5ojZh
h`WoYkcX00?oY[o[ojRlj?nX_>P01OnX_>P4ojJoj`04o`000?nV_n_oY[o[ojNmj@SoYl3[5oooool0
0ol0003oooooooooo`11ooooo`00=_ooool5o`0002?ooooo0_l0001Wooooo`GoZk3L2OnZ]N400onX
^^KoZk?Noj^cgP05oj^cgPOoZKWU00?o[;;LojZhhonZ^><01_nZ^><6ojNlj0;oZkSS2?nX_>P4ojJo
j`03o`000?nW_NWoYkgY00;oYkgY2?nW`>/Gooooo`03o`000?oooooooooo043ooooo000fooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@08?ooool3o`0006Kooooo00?o[[7Joj^`g?n[/=`01_n[/=`7ojZe
h@03ojnaf_n[/mkoZk?N00KoZk?N1?nY^ND5ojbbg0SoZ[SS0_nW_>P6oj^hh`SoZ;cX00CoY[o[ojNm
jOnW_NWo00001OnW_NT6ojO0j`03ojNmjOoooooooooo01Kooooo00?o0000ooooooooool0?oooool0
02kooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^01kooooo0ol0001Vooooo`Go[[7J1on[/=`4ojZe
h@Go[k7J2?n[/mh00onY^NGo[;;Lojbbg006ojbbg0KoZ[SS00?o[[?Loj^hhon[^><01on[^><6ojRl
j005oj^ihonW_NWoYkgYojNmjOl000001OnW_NT4ojO0j`CoYkgY5oooool00ol0003oooooooooo`0o
ooooo`00>?ooool00onHV9So8B4Qonk^kP0Kooooo`;o0000Ioooool7ojjafPSoZk3L00?oZ[GQojna
f_n_/MX01_n_/MX6oj^cgP03ok:df_n//]co[;;L00Oo[;;L1?nZ^><4ojjcg0WoZkSS0_nX_>P5oj^i
h`;oYkgY00?o0000ojNmjOnW_NT01?nW_NT00onW`>_oYkgYojNmj@05ojNmjAOooooo00?o0000oooo
ooooool0?_ooool003Wooooo00?oMgMgofIVI_ooool05oooool3o`0006Oooooo00?o[k;Kojjaf_n^
/MX01on^/MX6oj^`g003ok6dfon_/M[o[k7J00Oo[k7J1?n[/mh4ok:dfPWo[;;L00?oZ[SSojjcg?n^
/m`01On^/m`7oj^hh`03ojndg?n[^N?oZkWS00KoZkWS00?oYkgYo`000?nW_NT00onW_NT2oj^ki@So
YkgY6?ooool00ol0003oooooooooo`0mooooo`00>_ooool00ol0003oooooooooo`0Dooooo`;o0000
J?ooool4ojnbf`So[[7J1?n[/=`4ok6df`Wo[k7J00?oZk?Nok:df_nb]=X01Onb]=X7ojbbg003okBf
f_n^/mco[[?L00Ko[[?L1?n[^><5ojndg0SoZkWS00?o0000ojNmjOn[^nD01On[^nD8ojNmjAOooooo
00?o0000ooooooooool0?Oooool003Kooooo00Go0000okZj^_ooooooV9RHoa0@400Cooooo`?o0000
0_ooool00ol0003oooooooooo`1Sooooo`Oo[k;K2?n^/MX00on[/=co/KCKok6df`05ok6df`Oo[k7J
00?o/kSLok:df_nb]=X01_nb]=X6ojbbg0?o];KJ2?n^/m`00on[^>?o[kCLojndg006ojndg0KoZkWS
00?o[kKMo`000?n[^nD01on[^nD6ojNmj@03ojZli_oooooooooo01Kooooo00?o0000ooooooooool0
??ooool003Kooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Aooooo`;o0000JOooool00on_]]ko[k;K
ojnbf`06ojnbf`Oo[[7J00?o/KSNok6dfona]=/01_na]=/6ojnafP?o/kSL2?nb]=X3ojbbg0Go];KJ
1on^/m`00one^=_o[kCLojndg007ojndg0CoZkWS0on_]]d00ol0003oZk_Uoj^ki@07oj^ki@;oYkgY
1OnZ_>HFooooo`?o0000?Oooool004Wooooo0ol0001Yooooo`Co[kKN2?n_/]/4ojjafPCo/KSN2?na
]=/3ojnafPGo/kSL2Onb]=X00on//]co];KJokBffP05okBffPGo[[?L0one^=/9ojndg003oj^ihon_
]]go[kKM00?o[kKM00?o0000ojnfgOn[^nD01_n[^nD00on^]]ooZ[cVojZliP06ojZliQOooooo00?o
0000ooooooooool0>oooool004Oooooo0_l0001Zooooo`Oo[kKN2?n_/]/00on^/M[o/KSNok6hgP04
ok6hgPWo/KCK00?o[k7Jok>hg?nc^=`01Onc^=`7ok:dfP03okBkg_nd]][o];KJ00Ko];KJ0on^/m`6
okFhf`Oo[kCL00?o][WKojnfgOn_]]d01?n_]]d00ol0003o[kKMoj^ki@03oj^ki@Go[[KO2?nZ_>HG
ooooo`03o`000?oooooooooo03[ooooo0014ooooo`?o0000J_ooool00on^^^;o[kKNojnfgP06ojnf
gPOo[k;K00?o/;kUok6hg_na^=h01_na^=h7ok6df`03ok:nhonc^=co/kSL00Ko/kSL1?nb]=X5okBk
gPSo];KJ00?o[[?LokFhfone^=/01One^=/6ojndg0?o][WK1On_]]d01?l0003o[kKMojnfgOn[^nD8
ojjfg`KoZ[cV00?o[KWRooooooooool05_ooool00ol0003oooooooooo`0iooooo`00@Oooool3o`00
06_ooooo1?n^^^88ojnfgPCo[k;K1?n`_^D7ok6hgPCo/KCK1Onb_^<8ok>hg003ok:df_nd^mko];_N
00Ko];_N1_nd]]X00one_N3o]KSKokFhf`07okFhf`?o[kCL1_nf^M/4ojnfg@03o`000?n_]]go]kWK
00Wo[[KO1?nZ_>H4ojfihQOooooo00?o0000ooooooooool0>Oooool003oooooo0ol0001[ooooo`Ko
[[[R2On_]]h00on_/]_o/;kUok2ni@05ok2ni@Oo/KSN00?o/KCKok:nhonb_^<01_nb_^<6ok>hg003
ok;4j?nd^mko];_N00Oo];_N1?nd]]X4okFmh0Wo]KSK00?o[kCLokJifonf^M/01Onf^M/4ojnfg@04
o`000?ng^M_o]kWKokNif`Wo[[KO00?oZ[cVojfih_n]^N801On]^N8Gooooo`03o`000?oooooooooo
03Sooooo000looooo`?o00000oooool00ol0003oooooooooo`1Vooooo`03ojg1j?n^^^;o[[[R00Ko
[[[R1on_]]h00on]b^oo/;kUok2ni@06ok2ni@Ko/KSN0_n^bnh8ok:nh`Co/kSL1?nba>P9okBkgP03
okBff_ne_N3o]KgP00Go]KgP1one^=/00onf_^3o][WKokJif`07okJif`04ojnfgOng^M_o]kWKo`00
00Co]kWK1on^]]l00onf^Mco[KWRojfihP07ojfihQKooooo00?o0000ooooooooool01oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^02cooooo000jooooo`;o0000KOooool4ojg1j0Oo[[[R1?n_]]h5ojg:
k`So/;kU0_na^=h6ojk;kPSo/[kS00?o/kSLok;4j?nba>P01Onba>P7okBkgP03ok79k?ne_N3o]KgP
00Ko]KgP1?ne^=/5okJnh0Oo][WK00Go]kkOokNifong^M_o]kWKo`000004okNif`Co[[KO1Onf^M`7
ojfihP03ok>ig_oooooooooo01Gooooo00?o0000ooooooooool01_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg02cooooo000gooooo`?o0000KOooool7ojg1j0Oo[[[R00?o[kKNojg:kon]b^l01_n]b^l6
ok2ni@;oY=Oi2?n^bnh6ok:nh`03ojWDm_nba>So//CX00Oo//CX1?nd^mh4ok79k0So]KgP00?o]KSK
okJnh?nf_^001_nf_^05okJif`?o]kkO0ong^M/00ol0003o]kWKokNif`02okNif`03ojjfgonf^Mco
][WL00Ko][WL1?n]^N84ok>igQOooooo00?o0000ooooooooool01Oooool01Ol@413ooooooooooooo
oooo410@02cooooo000eooooo`;o0000K_ooool00on[b>oo[L7Xojg1j006ojg1j0Ko[[[R0onWe?L8
ojg:k`;o/;kU1_nTeoT8ojk;kP;o/[kS1OnYe?H9ok;4j003okBkg_nabNco/LW/00Go/LW/1_ne_N00
0onabngo][kPokJnh007okJnh0?o][WK1_ng_]l2okNif`05o`000?ng^M_o]kWKokNifoni_]h02_nf
^M`00on]^N;o/kWNok>igP05ok>igQKooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooo
oooooooo000002cooooo000booooo`?o0000KOooool5oj_8k`So[L7X0_n^^^87ojODm`Ko[L[_0_nA
f?h8ojCGn@Ko[/_^0_nAeOh7ojWDmPKo//CX0_nPeOX8ok79k0Co]KgP1?nabnd9okJnh003okJifong
_]oo]kkO00Go]kkO0_ng^M/00ol0003o]kWKokVngP03okVngPSo][WL00?o^KgMok>ig_nc^Mh01_nc
^MhGooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000/ooooo`00<?oo
ool2o`0006cooooo0_nXco@8oj_8k`Ko[L7X0onLfO`8ojODm`;o[L[_1_nAf?h8ojCGn@;o[/_^1_nA
eOh7ojWDmP;o//CX1_nPeOX8ok79k003okFmh?nabngo/L_]00Go/L_]1onf_^000onbb^co]kkOokNn
g`07okNng`03okNifol0003o^KkN00Go^KkN1Onf^M`4okVmg@So/kWN5oooool00ol0003ooooooooo
o`03ooooo`05oa0@4?ooooooooooooooool@4100;?ooool002gooooo0ol000000ooooooo0000oooo
o`1Xooooo`KoZ<od2?n[b>l2ojg1j0OoW=Wl1_nWe?L3ohSIo`OoTMSn1?nTeoT5oh;Do`OoTMGn0onY
e?H4ohCBo`SoX=Gj1_nabN`2oi[Co0Oo/L_]1?nf_^05ok;:k0Oo]kkO00?o]<OYokVng_l000001_ni
_]h4okJig0Ko^KgM1_nc^Mh00oni_Mcoooooooooo`0Eooooo`;o00001?ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg02cooooo000Zooooo`?o0000Joooool2ojKDn0SoZ<od1_n[b>l3oiGKoPSoW=Wl0_nW
e?L7ohSIo`?oTMSn1Ommdol8oh;Do`?oTMGn1Omhcol6ohCBo`SoX=Gj0_nabN`6oi[Co0Oo/L_]00?o
][kPok;:k?nbb^`01_nbb^`4okNng`Co]<OY00?o0000okVng_ni_]h01Oni_]h00onf^Mco^KgMokVm
g@06okVmg@Co/kWN1?ni_M`Dooooo`;o000000?oooooo`000?ooool00oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^02cooooo000Xooooo`;o0000K?ooool5ojKDn0SoZ<od0_n[b>l8oiGKoP?oW=Wl1On5
fOl6ohSIo`?oPm;o2?mmdol3oh;Do`GoNlco1omhcol6ohCBo`CoX=Gj1Omlc_l7oi[Co0?o/L_]1?nH
dO`9ok;:k003okNngondanWo]<OY00Co]<OY00?o0000okVng_ni_]h01?ni_]h00onf`nCo^KgMokVm
g@08okVmg@03ok>ig_ni_Mco^KgL00Go^KgL5oooool00ol0003oooooooooo`0booooo`009Oooool3
o`0006cooooo2?nVe?P6ojS?m0?oT]gn1onEfoh3ohSJo`OoQMWo0_n8fOl8oh?Bo`?oOM?o1On;a_/7
og_<o`?oN<oo1?n0a?d7og?9o`SoO<ko0onJdo`4ogS:o`OoV=7l1_nbb^`2oic@nPKo]<OY0_l00004
okVngPCo]/?T2?ni_Md00oni`N3o^KgLokVmg006okVmg1Oooooo00?o0000ooooooooool0<_ooool0
02?ooooo0_l0001]ooooo`?oY=Oj2?nVe?P2ojS?m0SoT]gn0_nEfoh7ohSJo`?oQMWo1On?c_d7oh?B
o`;oV<7d2?n;a_/3og_<o`CoT[ke1on0a?d8og?9o`?oO<ko1Om`a?l6ogS:o`OoV=7l0_nbb^`6oic@
nP;o]<OY0ol000001?ndanWo0000okC7jOni_]h7okK3i0Go^KgM1?ni`N08okVmg1Oooooo00?o0000
ooooooooool0<Oooool0023ooooo0ol0001/ooooo`SoY=Oj0onVe?P6oi?OoPCoT]gn1On>f_l6ohSJ
o`?oV<Wh2?n?c_d2oh?Bo`KoV<7d1_n;a_/00onQ_NgoT[keoi:nm@06oi:nm@OoP<Cm1?mcbOl5oh>n
nPOoL<Co1_mhb_l3oiSAo0CoN<Oo1_nLd?X3o`0000Go]<OY00?o0000okK3i?nf`n@01_nf`n@4okVm
g@Go^L7P1oni_M`00onk`=koooooooooo`0Fooooo`03o`000?oooooooooo033ooooo000Oooooo`;o
0000K?ooool3oj?InPKoY=Oj0onEh?h7oi?OoP?oUMWn1on>f_l2ohSJo`OoV<Wh1_n?c_d2oj:nk@So
V<7d0_n;a_/5oj6mk@SoT[ke0on0a?d5oiVll@SoPkkj0om`a?l4oh:jn0OoK/7n1_mhaol2oic@nP?o
00000onLd?X2okC7j@CoYLof00?o0000okK3i?nf`n@01_nf`n@00oni_Mgo^L7PokW1h005okW1h0Co
^KgL1Onk`=hGooooo`03o`000?oooooooooo033ooooo000Oooooo`03o`000?oooooo000006Sooooo
1onSfOX2ojCGnPSoUN3n0_nCgoh7oiGIoP?oS][o1OnNa?<8oiS9n0;oSlkm1_nR_^d6oiS1m003ojJi
ionQ_NgoXKg]00KoXKg]1_nB__D00onT^^SoVKcaoiVll@07oiVll@KoPkkj0_nL^nh7oh:jn0OoK/7n
1?mhaol3o`0000?oW=3j1?mla_h6ojG?mP03o`000?nf`nCo]/?T00Co]/?T00?o[lg_okW1h?ni`N00
1oni`N000oni_Mco^l3Nok_0gP06ok_0gQOooooo00?o0000ooooooooool0;oooool000cooooo1Ol0
0003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool01?l0003oooooooooool0001Tooooo`?o
Y=Wj1_nSfOX3oiSRo@OoUN3n0onKf?d6oiGIoP;oY<?_2?nNa?<6oiS9n0;oYK_Y2?nR_^d2oiS1m0Go
Y[WW2?nQ_Nd2oi:nm@GoY;[X2OnI_?42oh>nnPKoW;_^1on2^_P3ofk1oPCoOkSh0ol00003ofbnoPSo
O<Kn1OnUcoH01?l0003oYLofokK3i?nf`n@5ojo=k`Oo^L7P00?o]LGVok_0g_nk`=h02?nk`=hGoooo
o`03o`000?oooooooooo02kooooo000<ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Kooooo0_l00002ooooo`03o`000?oooooooooo05kooooo1onTfOX2
oj?InPSoV>;m0_nEh?h7oi_Ho@;oUMWn1_nT`nl8oik4l`;oV<Wh1_nU^nT6oj:nk@03ojRghonV^NOo
Y[WW00KoY[WW1_nQ_Nd00onY]n?oY;[XojBjj006ojBjj0KoVKca0_nV^NH9oibkkP?oP[[h1?nK^nh3
ognhn0?o000000?oOkShofbno_m/__h01?m/__h8ogc6oP?oYLof0_n6a_d00ol0003o[lg_ojo=k`06
ojo=k`Co^L7P1?neaNH8ok_0gP03ok[3hOoooooooooo01Gooooo00?o0000ooooooooool0;_ooool0
00Cooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4005
ooooo`;o00001?ooool00ol0003oooooooooo`1Jooooo`;oY=Oi1onTfOX3oicSo@OoV>;m0onPf?/6
oi_Ho@;oY/;]2?nT`nl6oik4l`03ojNii_nU^nWoYK_Y00OoYK_Y0_nR_^d5ojRgh`SoY[WW0_nQ_Nd5
ojVgh`SoY;[X0_nI_?46ojJiiPOoW;_^00?oYkWVoi^kk_nK^nh01OnK^nh3o`0000GoOkSh1_m/__h4
ogc6oP?oKKgm1_n6a_d00ol0003o[lg_ojo=k`06ojo=k`03okW1h?neaNKo]LGV00Go]LGV1Onk`=h4
ok[3hAOooooo00?o0000ooooooooool0;Oooool000kooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0
003ooooooooooooooooo000000Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1F
ooooo`KoY=Oi1?nTfOX7oicSo@;oV>;m2?nPf?/00onKf?goY/;]ojK2k@04ojK2k@SoY<?_0_nNa?<5
ojNiiPOoYK_Y00?oZ[ORojRghonX]n<01_nX]n<6ojJii`03ojbihonY]n?oZKOS00KoZKOS1_nT^^P2
ojbhhPSoY[WV1?nL^nh4ojNiiPCoVk_^0_l00002oi^kkP?oOkSh1?nG^_07ogRgn@KoKKgm1On6a_d0
0ol0003oQ/Kmojo=k`05ojo=k`03oi[:n?neaNKo]LGV00Ko]LGV1?nk`=h5ok[3hASooooo00?o0000
ooooooooool0;?ooool000oooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo
000000Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Booooo`?oYMCh1onTeoT0
0onTfO[oW>?moicSo@06oicSo@?oY=Wj1onPf?/00onW`NcoY/;]ojK2k@06ojK2k@KoY<?_00?oYkOT
ojNii_nW^NH01_nW^NH4ojFkj@CoZ[OR1onX]n<4ojJii`Co[;WS2?nY]n<2ojBjj0Ko[;SR2?nV^NH0
0onL^nkoYkWVojNiiP05ojNiiP?o00000onK^nh00onW^NKoUk[`oiNjl006oiNjl0OoN;Oi1_m]_Od5
ohK6o@04o`000?n6a_go[lg_ojo=k`GoV/[h2?neaNH00onk`=ko^/?Qok[3h@05ok[3hAOooooo0_l0
000^ooooo`004?ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@ooooooooool00ooo
ool2o`0000Oooooo00?o0000ooooooooool0Coooool6ojGDn0GoY=Oi1?nPi?`3oicSo@SoY=Wj0_nP
f?/5ojO1k0SoY/;]0_nT`nl5ojNgi0SoYkWV00?oYK_YojZgh_nZ]n801OnZ]n87ojRgh`03ojJiion/
^N?o[;WS00Go[;WS1_nY]n<00on^_>Co[;SRojbhhP07ojbhhPKoY[WV00?o[[[SojNii_nW^NH00onW
^NH3o`000003ojNii_nK^nkoVk_^00GoYkWV2?nG^_03ogRgn@CoS[Sb1_m^]_/5og>mo@03o`000?mc
_OgoV/[h00KoV/[h1_neaNH00on]bnoo^/?Qok[3h@07ok[3hASooooo00?o0000ooooooooool0:ooo
ool000cooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04cooooo2OnUe?P00onTeoWoX>Cl
oj3To005oj3To0?oY]_j1onTfOX9ojO1k0KoY/;]00?oYkKSojNgi?nW]n@01_nW]n@6ojNiiP03ojZh
honZ]n;oZ[OR00KoZ[OR1_nX]n<00on/^nCo[;WSojbih`06ojbih`CoZKOS1?n^_>@9ojbhhP;oY[WV
1On^^^<01?nW^NKo0000o`000?l00003ojNiiP03ojnkhonW^NKoYkWV00KoYkWV1_nG^_000onU^^So
S[SbohjhlP06ohjhlPKoK[Kk1Omc_Od00ol0003oLkgmoi[:n006oi[:n0;o]LGV1On]bnl7ok[3h@03
okO5iOoooooooooo01Kooooo00?o0000ooooooooool0:oooool000cooooo00GoV9RHoa0@4?l0003o
8B4Qolc<c003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo04Wooooo0onVc_D7ojGDn0CoY>Cl0_nPi?`8ojKKnP;oY=Wj3OnW`N`2ojK2
k@GoYkKS2?nW]n@2ojNiiPGoZ[SS2?nZ]n82ojRgh`Go[;_T2?n/^N<00onY]n?o[[cTojjli005ojjl
i0Oo[;SR00?o[koUojjjhon^^^<00on^^^<3o`0000CoYkWV1?n_^n<8ojNiiP;oUk[`1OnU^^P8ohjh
lPKoK[Kk1?mc_Od00ol0003oLkgmog>mo@03oi[:n0CoPL3k1on]bnl4ok[3h@Co]lGU6?ooool00ol0
003oooooooooo`0Zooooo`007_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo04Go
oooo2?nVc_D2ojGDn0KoY>Cl0onYgoX7ojKKnP03ojS2k?nW`NcoYl7/00coYl7/2OnW]^<6ojNgi003
ojZii?nZ^>?oZ[SS00KoZ[SS1_nZ]n82ojbmiPOo[;_T1_n/^N<2ojbni`So[[cT1?n/^>84ojnoi@04
ojjjhol0003o0000o`0000Co[[[S00?oYkWVojnkhon_^n<01On_^n<6ojNiiP03ojjkhonU^^SoYK[X
00KoYK[X1_n>^?800onP^ncoOk?fogncmP05ogncmPCoJkKk00?o0000of^fnon1`?/01on1`?/7ojg;
k`03ok[3hOngaNGo]lGU00Go]lGU6?ooool00ol0003oooooooooo`0Yooooo`007Oooool3o`0000_o
oooo00?o0000ooooooooool0@Oooool3ojG7l@OoY/ke0onWi?/4ojCTo0KoZMoj1?nVfoX4ojS2k0[o
Yl7/3OnW]^<2ojNgi0GoZ[WT2?nZ^><2ojZghPKo[;gV1on/^n@2ojbih`Ko[;kW2?n^_>@00on/^>;o
[koUojnoi@02ojnoi@?o00001_n^^^<00on__nKo[k_Sojnkh`06ojnkh`CoYkWV1?n^^n<8ojFjj0;o
S[Sb1OnP^n`7ogncmPCoJkKk00?o0000of^fnon1`?/01on1`?/3ojg;k`?oW<Of2OngaNDGooooo`03
o`000?oooooooooo02Wooooo000Mooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
?Oooool7ojG7l@CoY/ke1onWi?/00onTi?coZMojojWOnP06ojWOnP03ojKKn_nX`^coZ<;/00GoZ<;/
1_nW`N`?ojNfh`03ojVjiOnZ^NCoZ[WT00KoZ[WT1_nZ^><2ojVmj0So[;gV1On/^n@2ojZnj0So[;kW
1_n^_>@00on[_nSo[koUojnoi@03o`0000?o[koU1?n^^^<4ojnoiPSo[k_S00?oYkWVojjkhon^^n<0
1On^^n<6ojFjj003ojfli?nP^ncoX;_/00KoX;_/1omo/oH4of^fn`03o`000?m[]__oPL3k00?oPL3k
0omc^?/7oic7mPOo]lGU00?o//S[ooooooooool05_ooool00ol0003oooooooooo`0Xooooo`007Ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03[ooooo0_nT_^`8ojG7l@03ojK>mOnW
i?_oYnCk00KoYnCk0on[hoX6ojWOnP?oZLG]1onX`^`2ojO1k13oYkKS1?nY^^D7ojZii0CoZ[SS1OnY
_NP8ojbmiP03ojbki?nZ_^SoZ[kX00CoZ[kX2?n/_^L2ojjli0?oZkoX0ol00007ojnoi@03ojjjhon_
_nKo[koV00Go[koV1_n_^n<00on``>Ko[[_Sojjkh`07ojjkh`;oYK[X1On]_>@8oj2kk0?oOk?f1?nB
^?43ofnan@03o`000?m_/OWoKk7i00OoLkSk1onLaoH4okO5i@Co//S[6?ooool00ol0003ooooooooo
o`0Wooooo`007Oooool2o`0000oooooo00?o0000ooooooooool0=_ooool6ojBnk0KoYLOa1?nZh_X3
ojOTn`OoZn?j0_nYgoX7ojW5k@GoZ<;/00?oY[KTojNfhonW]^<03_nW]^<7ojVji@OoZ[WT00?oZ[SS
ojVmj?nY_NP01_nY_NP6ojbmiP03ojVnjOnZ_^SoZ[kX00KoZ[kX1_n/_^L01?nY_nWoZkoXoj^oj?n[
_nP2o`0000?oZkoX1_n__nD00on[_nSo[koVojnoiP07ojnoiP;o[k_S1On``>H7ojjkh`03ok71iOn]
_>Co[KcT00Ko[KcT1_nP^n`2ojRki`OoT[Sa0om_/OT00ol0003oKk7iofnan@06og>hn`SoW<Of00?o
]lGUok;8jonbb>/01Onbb>/Gooooo`03o`000?oooooooooo02Oooooo000Mooooo`03o`000?oooooo
oooo00oooooo0_l0000aooooo`GoXKGW1onT_^`2ojG7l@OoZ^;j0on]i_T6oj_SnP?oZlS_2?nYaNd0
0onX`^coY[KTojJfi003ojJfi0goYkKS0_nX^^H8ojVji@GoZ[WT0_nX_NT9ojVmj0;o[;gV1OnY_^T8
ojZnj0;o[;kW1?nY_nT3o`0000KoZkoX0_n__nD5oj^oj0Oo[koV00?oZkoXok30i_n``>H01_n``>H4
ojjkh`Co/L7U2?n]_>@2oj2kk0KoZ;_W1onB^?43ofnan@03o`000?m_/OWoKk7i00KoLkSk1?nLaoH3
ohVnn0Wo//S[5oooool00ol0003oooooooooo`0Vooooo`007Oooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo02[ooooo00?oWZoToj6eionQ]NL01onQ]NL5ojBnk0?o[=gh1OnZh_X7ojgV
n@03oj_Sn_n[b>ooZlS_00GoZlS_1_nYaNd00onV]nGoY[KTojJfi005ojJfi0WoYkKS1_nX^^H8ojVj
i@03ojZii?nX_NWoZ;gY00CoZ;gY1onY_NP00onX_n[oZKkYojVnj@06ojVnj@KoZ[kX00CoZ;oZojVo
jOnY_nWoZKoY0ol00002ojVoj@KoZkoX00?oZKoYoj^oj?n[_nP01_n[_nP4ojnoiPCoZkoX2?n``>H0
0on^^n?o/L7Uok71i@05ok71i@Ko[KcT00?o/KoTojRkionX^nL01onX^nL3oi:hl@CoX;_/0oml/?D0
0ol0003oO;3eogb`m@06offbnPOoRKkh1_nbb>/2ojS7kaSooooo00?o0000ooooooooool09Oooool0
01gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Vooooo`GoWZoT2OnQ]NL00onT
_^co[=ghojcMn006ojcMn003oj[Rn_n]i_Wo[NKi00Ko[NKi0_n_d?48oj_8k`;oZLG]1OnV]nD7ojJf
i0KoYkKS00?oYk[VojRji_nX^^H01_nX^^H6ojVji@03ojRnjOnX_NWoZ;gY00KoZ;gY1?nY_NP4ojRo
jPSoZKkY0_nZ_^P4ojRojP?o00001_nY_nT2oj^oj0GoZKoY2?n[_nP00on__nKoZkoXoj^oj005oj^o
j0Ko/<3V00?o[<3Xok71iOna`ND01ona`ND2ojfli0Go/KoT1onX^nL00on^_NGoX;_/oj2kk006oj2k
k0;oO;3e00Co0000ogb`mOml/?GoO;3e1_m]/_X7ohVnn0;o//S[1_nXanlGooooo`;o00009_ooool0
01cooooo0ol0000Dooooo`03o`000?oooooooooo027ooooo0onKZn47oij_i0OoXKGW0onZeOH6ojcM
n0Co[nKi0on]i_T6ojo@l@KoZlS_00?oYkWVojJgiOnV]nD01_nV]nD7ojJfi0;oYkKS1OnW^^H8ojRj
iP;oZK[U1OnX_^T8ojRmj@03ojVmj?nX_n[oZ;oZ00GoZ;oZ1_nY_^T01?nX_^WoZ;oZojRoj_nX_nX3
o`0000;oZ;oZ1_nY_nT00onX_n[oZKoYojVoj@06ojVoj@KoZkoX0_nY_nX8oj^oj0;o/<3V1On/`>P7
ok71i@03ojk1iona_nCo/KoT00Ko/KoT1?nX^nL4ojjmi@SoX;_/0_ml/?D01?l0003oO;3eogb`mOml
/?D6offbnP?oRKkh0oml]oT8ojS7kaKooooo00?o0000ooooool000009_ooool001cooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`0Looooo`03oiZXh?nKZn7oVj_Q00GoVj_Q1onN[n@4
oj6ei`KoZ]Gf0on/gOP6ojoVn@?o/mWd1on_d?42oj_8k`GoYkWV1onV]nD6ojJfi003ojJii_nW^^Ko
Yk[V00KoYk[V1_nX^^H9ojRnj@KoZ;gY2_nX_nX2ojVnj@CoZ;kY0ol00006ojRojP;oZKoY1OnX_nX8
ojVoj@;oZkoX1_nY_nX6oj^oj003ojW0j_n/`>So[<3X00Ko[<3X1?na`ND4ojk1i`So/KoT00?oZ;_W
ojjmiOn^_ND01?n^_ND6oj2kk0;oYkcY0on;]O800ol0003oRkGboh^elP07off^n0KoO;Oi2?nXanlH
ooooo`03o`000?oooooooooo02?ooooo000:ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0
003o<S8bonk^kPKooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Hooooo`GoVZSP
1onKZn47oij_i003oj6eionZeOKoZ]Gf00OoZ]Gf00?o[=ghojoVnOn_i_T00on_i_T6ok?Im0Go[m3a
0_nX_>P7ojNiiPOoY[OU0_nV]^@5ojJiiPSoYk[V0_nX^^H=ojRnj@;oZ;gY3?nX_nX01?nX_NWoZ;kY
ojRnjOnX_^T3o`0000;oZ;kY1_nX_nX00onX_NWoZ;oZojRojP06ojRojPKoZKoY00?oZ;kYojVoj_nY
_nX01onY_nX2oj^oj0GoZL3Z2?n/`>P00ona`NGo[/7Wojk1i`05ojk1i`Ko/KoT00?o/L;VojjmiOn^
_ND01_n^_ND2oj2kk0KoYkcY0_n;]O801?l0003oRkGboh^el_n;]O87off^n0KoO;Oi1_nXanl00onM
`_;oooooooooo`0Fooooo`03o`000?oooooooooo02?ooooo000<ooooo`03o`000?oooooooooo00;o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool04oooool3oiZYh@OoVZSP1_nKZn46oij_i0?oYLOa1onZeOH4ok7Un003ojoVnOncfOCo/mWd
00Oo/mWd00?o[m3aojRlj?nX_>P01?nX_>P7ojNiiPGoY[OU0_nU]nH7ojJiiPKoYk[V00?oYkgYojRn
jOnX_^T03?nX_^T2ojRnjP[oZ;oZ1?nX_NT3o`0000KoZ;kY0_nX_nX5ojRmj@SoZ;oZ0_nY_nT5ojRn
j@OoZKoZ00?oZ;oYojW0j_nY`>X01_nY`>X6ojc0j003oj[0jOn^`NOo[/7W00Ko[/7W1?na_n@4ok72
iPKo[[gU00?o//3TojNljOnW_>T01_nW_>T3oh^elP04o`000?n;]O;oRkGboh^elPOoKJkh1_ml]oT2
ojS7k`GoWL;b6?ooool00ol0003oooooooooo`0Rooooo`0000?oooooo`000?l000001?l00005oooo
o`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`;o00006Oooool0
0ol0003oooooooooo`0>ooooo`03oj2ai?nJZN7oVZWQ00GoVZWQ1onJZ>06oi^[h@;oWZoT2?nUao42
oj[EmPKo/NGh0oneh_H7ok?Im003oj[1jonX_>SoZ;cX00KoZ;cX1onW^NH00onV]nGoYKOVojFgiP04
ojFgiPOoY[WV0_nW^^H5ojNmj@[oZ;kY1_nX_^X6ojRojPGoZ;gY0_l00002ojRmj@KoZ;kY00?oZKgX
ojRmjOnX_NT01_nX_NT6ojRojP03ojVnjOnX_^WoZ;kY00KoZ;kY1?nY_nX4ojRoj@SoZL3Z0_n/`>P5
oj[0j@So[/7W00?o/KoTok72i_na`^H01?na`^H4ojjmi@Co//3T2?nW_>T3oh^elP04o`000?nF^Noo
U[W_oiJik`KoLJgf1ome/_P7oig2lQSooooo00?o0000ooooooooool08Oooool000cooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0:ooooo`GoX;7T1onJZN47oiZXh0?oVj_Q1?nQ^NX7ojG7l@?o/^7g1?na
iOP7okGRmP;o/mWd1OnZ`N/8ojRlj0?oYkWV0onT]^D8ojFgiPGoY[WV2OnW_NT6ojRnj@?oYkkZ1onX
_^X2ojRojPGoZ;gY0ol00005ojRmj@;oZ;kY1OnY_NP8ojRmj@;oZ;oZ1OnY_^T8ojRnj@03ojVoj_nX
_nWoZ;oY00GoZ;oY1_nY`>X00onY_n[oZ/3Yoj[0j@06oj[0j@Ko[/7W00?o[<3Yok72i_na`^H01_na
`^H00on^_NGo//3Tok;0i005ok;0i0KoYkcY00?o[;kWoiJikonF^Nl00_nF^Nl01?l0003oU[W_oiJi
konF^Nl6og6]mPOoMK;h1onM`_8Gooooo`03o`000?oooooooooo027ooooo000<ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool01oooool2oj>hj0KoX;7T1_nJZN46oiZXh003oib`iOnQ^N[oXKWZ00KoXKWZ
1?nUao47ok;Qm`03ok7Un?neh_Ko]N;f00Go]N;f0_n]b>d7oj[1j`KoZ;cX00?oY;CTojBfiOnT]^D0
1OnT]^D8ojFgiP03ojJii_nW_NWoYkgY00_oYkgY0_nX_^T7ojNnjPGoZ;kZ1OnX_NT3o`0000OoZ;gY
00?oZKkYojVmj?nY_NP01_nY_NP6ojRmj@03ojVojOnY_^WoZKkY00KoZKkY1_nX_^T2ojVnj@SoZ;oY
0_nY`>X5ojVojPSoZ/3Y0_n^`NL5ojc0j@Ko/L;V00?o[l7Wok;0i?nb`>@01onb`>@2ojNlj@Go[;kW
0onF^Nl00ol0003oU[W_oiJik`02oiJik`KoLJgf1ome/_P3oig2lP?oU;gc6?ooool00ol0003ooooo
ooooo`0Pooooo`003?ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100
1Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00?ooooo1_nS^>P6oj2ai0KoVZWQ
0_nJZ>05oib`i@SoXKWZ00?oYLOaok;QmonbhOL01_nbhOL3okOVmPCo]N;f1On]b>d7oj[1j`;oZ;cX
1OnT]>@7ojBfi@KoYKOV3_nW_NT;ojNnjP03ojRnj_nX_NWoZ;gY00?oZ;gY0ol00007ojRmj@GoZKkY
2?nY_NP2ojRmj@GoZKoY2?nY_^T2ojRnj@KoZKkY1_nX_nT00onY_^WoZKoZojVojP06ojVojPKoZ/3Y
00?oZL3Zojc0jOn/`>T01_n/`>T2ok72iPGo[l7W1onb`>@00onc`^Ko[;kWojbni`06ojbni`?oU[W_
00Co0000oiJikonF^NooW[_]1omh[?<6og:]mPOoU;gc6?ooool00ol0003oooooooooo`0Oooooo`00
3?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2o`0001ko
oooo00Co0000oooooonV_N[oY[gZ2?nS^>P6oj2ai0?oVZWQ0onIZ^<7oib`i@KoXKWZ0onafOD5ok;Q
m`Oo]nKf00?o]N;fojg8kOn]b>d01On]b>d5oj[1j`03ojBeiOnT]>CoY;CT00KoY;CT1onT]^D2ojFg
iPkoYkgY3OnW_^X4ojRmj@?o00001onX_NT2ojRojPOoZKkY1_nY_NP00onY`>[oZKoYojVoj@06ojVo
j@KoZKkY0_nZ`>T8ojVnj@;oZ;oY1OnY_^T8ojVojP;oZ/3Y1OnY`>X6ojc0j@03oj[0j_n_`NOo[l7W
00Ko[l7W1?nb`>@4ok?2iPSo[;kW0_nF^Nl00onN^ngo0000oijkk@02oijkk@OoN:cc1_mb[OH7oiBm
laOooooo00?o0000ooooooooool07oooool000[ooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool07?ooool6ojJmjPSoXkSX0onP/N@2oiNX
hPOoVJ[S1onL/>D3oj6ijPOo/MWe00?o/^7gokOVm_ngi_H01_ngi_H2okGDl0So[LS]00?oZ/7[ojBe
iOnT]ND00onT]ND7ojBdi0KoY;KU00?oY[cYojNmjOnW_NT03?nW_NT<ojNnjPCoZ;gY0ol00007ojRm
j@KoZ;oZ1onY_^T2ojVmj0GoZL3Z2?nY_nT2ojVnj@KoZ/3Y1_nY_^T00onZ`>[oZKkYojVnj@06ojVn
j@KoZKoZ00?oZKoYojW0j_nY`>X01_nY`>X3ojc0j@CoZ/3Z2?n_`NL00onb`>Co/l;Vok?2iP05ok?2
iPKo[;kW0_n_`>H3oijkk@04o`000?nN^ngoW[_]oijkk@OoN:cc1Omb[OH8oiBmlaOooooo00?o0000
ooooooooool07_ooool001_ooooo00?o0000ooooooooool06_ooool3ojS0j`KoY[gZ1_nS^>P00onJ
[>CoUjSRoiNXhP04oiNXhPOoVJ[S1onL/>D00onQ^N[o/MWeok7Im@05ok7Im@Co^>Ge0ongi_H6okGD
l0Ko[LS]00?oY[WWojBeiOnT]ND01OnT]ND7ojBdi0;oY;KU1OnV_>T:ojNmj@coYkkZ00CoYkgYojRm
jOnX_NWoZ;gY0ol00008ojRmj@WoZ;oZ1OnY_^T00onX`>_oZL3ZojW0jP06ojW0jPKoZKoY0_nX`N/8
oj[0j@;oZKkY1OnZ`>X8ojVnj@;oZKoZ1OnY_nT8ojW0jP03ojc0jOnZ`>[oZ/3Z00CoZ/3Z1_n_`NL0
0on/`NWo/l;Vok?2iP07ok?2iP;o[;kW1_n_`>H2oijkk@03o`000?nN^ngoW[_]00;oW[_]0omh[?<3
ogn^lPCoLJ[d0_mb[OH4oiBml`?oSKSc6?ooool00ol0003oooooooooo`0Mooooo`006oooool00ol0
003oooooooooo`0Gooooo`OoZ<3[1_nV_NX2oj>hj0GoVZcT1_nGZ>87oiVZh`?oW;3U1OnWb?44ok7I
m@Ko^>Ge0onjh?87okGDl0;o[LS]1OnV^NL7ojBei@GoY;CT0_nU^nT7ojJlj@KoYkgY3?nW_^X4ojNm
j@?o00002?nX_NT=ojRojP03ojVnjOnX`>_oZ<3[00?oZ<3[2?nY`>X2ojVoj@KoZ<7[1_nZ`>T00onX
`N_oZ/3Zoj[0jP06oj[0jPKoZKkY00?oZ/3YojVojOnY_nT01_nY_nT6ojW0jP03ojVoj_nZ`>[oZ/3Z
00KoZ/3Z0_n_`NL5ojc1j@Oo/l;V00?o//?Wojo0i_n_`>H01on_`>H2oijkk@04o`000?nR_NcoX[g/
oj:mk0OoOjkb1_maZ_@7ohfhlaKooooo0_l0000Oooooo`006oooool2o`0001Kooooo0onX`N/7ojS0
j`?oY[gZ0onQ]^P7oiZ/i0KoUjSR1OnIZ^<2oingj@WoYlSa00?o/MWeokSUmOnhiOD00onhiOD6ok[P
lPGo]MC`0_nY_nX7ojJii`OoY;GU00?oY;CTojFkjOnU^nT01?nU^nT7ojJlj@;oYkgY3?nW_^X5ojNm
j@;o00000_nW_NT6ojRmj@03ojRojonX_n[oZ;oZ00coZ;oZ00?oYl3[ojS0jonX`>/01OnX`>/6ojW0
jP;oYl3[2?nX`N/2oj[0j@GoZ<7[2?nZ`>X2ojVnj@GoZ/3Y2?nY_nT2ojW0jPGoZKoZ1_nZ`>X00onY
`>[o[<7Yojc1j@06ojc1j@Co/l;V1?nb`nL7ojo0iP05ok72i_nR_NcoX[g/oj:mk?l000000onR_N`7
ogn^lPKoLJ[d1_n=^?<Hooooo`03o`000?oooooooooo01cooooo000Jooooo`03o`000?oooooooooo
01?ooooo1onX`N/5ojS0j`03ojBkj_nQ]^SoXKKX00GoXKKX1_nJ[>@7oiNXhP03oiVZhonO]nWoWkOY
00CoWkOY1onWb?44okSOm003okSUmOnjh?;o^^3b00Oo^^3b00?o]MC`ojVoj_nY_nX01?nY_nX7ojJi
i`?oY;GU1?nS^>P7ojFkj@GoY[cY3?nW_^X5ojNmj@?o00001OnW_NT2ojRmj@GoZ;o[2_nX_nX5ojO0
j`OoZ<3[0_nY`>X6ojO0j`KoZ<7[00?oYl3[ojS1jonX`N/01_nX`N/6oj[0jP03ojS1jonZ`>WoZ/3Y
00KoZ/3Y1_nY_nT00onZ_nWoZKoZojVojP06ojVojP;oZ/3Z1OnY`>X8ojc1j@03ok?2i_nb`nOo//?W
00Go//?W1?n_`>H4ok72iP?oX[g/00Co0000oj:mk?nR_NcoX[g/1omo[_86og6Zm0KoSKSc5oooool0
0ol0003oooooooooo`0Looooo`006_ooool00ol0003oooooooooo`0?ooooo`CoY[k[2?nX`N/00onX
`>_oY;_ZojBkjP03ojBkjPOoXKKX1_nJ[>@3oiNXhP?oVJkU2?nO]nT4ojO8l@Go^=od0onmi?87ok[P
lP03ojk8kOnY_n[oZKoZ00KoZKoZ1OnV^NL2oj6eiPOoXkSX1onU^nT00onV_>WoYkkZojNnjP0:ojNn
jPGoYkgY0ol00007ojNmj@03ojNojonX_n_oZ;o[00KoZ;o[1_nX_nX00onW`>coYl3[ojO0j`06ojO0
j`GoZ<3[2_nW`>/2ojS1j`GoYl3[2?nX`N/2oj[0jPGoZ<7[2?nZ`>T2ojVoj@GoZ[oY1_nY_nX00onY
_nWoZL3ZojW0jP06ojW0jPKo[<7Y0_n[`NT8ok;3i`03ojo0i_na`^Ko/L;V00Co/L;V0onR_N`01?l0
003oX[g/oj:mk?nU_^/7ohB`lPKoLZSc1on8/o8Gooooo`03o`000?oooooooooo01_ooooo000Joooo
o`03o`000?oooooooooo00_ooooo0_nV_n/7ojJnj`KoZ<7[00?oYl3[ojBkj_nT^nX01OnT^nX7oj6f
j0?oVZcT0_nEZ><7oiV^i@SoWkOY00?oYlSaokSOm?nhgo@01?nhgo@6okgTlP;o^^3b1On^b>d8ojVo
jP03ojJiionQ]NKoXKGV00CoXKGV1onS^>P3ojFkj@CoY[kZ2OnW_^X5ojNmj@?o00001onW_NT5ojNo
j`SoZ;o[0_nX_nX5ojO0k0SoYl3[00?oZ<3[ojO0jonW`>/04onW`>/6ojS1j`03ojO0jonX`N_oZ<7[
00KoZ<7[1_nZ`>T2ojW1j`OoZ[oY0_nY_nX5ojVoj@SoZL3Z0_n/`NT6oj_1j@Ko//?W00?o/<?Wok72
i_na`^H01_na`^H2oj:mk003ojFnjol0003oYKk[00;oYKk[1on4/?86og:Xl`OoR;?b5oooool00ol0
003oooooooooo`06ooooo`Go00003oooool001[ooooo0_l00009ooooo`KoY[o[1onV_^/2ojS1j`Go
Yl3[1onT^nX5oj6fj003oiFYi?nEZ>?oUJSS00CoUJSS1onI[^D6oingj@?o/]Gb1?nhgo@6okgTlP?o
^MO_1_n^b>d6ojVojP03oj:ei_nQ]NKoXKGV00KoXKGV1OnS^>P2ojJmjPOoY[kZ1_nW_^X4ojNmj@?o
00001onW_NT9ojNoj`KoZ;o[00?oYl3[ojO0k?nW`>`01_nW`>`NojO0j`;oZ<7[1OnW`>/8ojS1j`;o
Z/3Y1_nY`N/5ojZoj@03oj_1j_nY_nWoZKoY00KoZKoY2?nY`>X8oj_1j@;o//?W1On``nL6ok72iP03
ok?3i_nU_^_oYKk[00;oYKk[00Co0000ojFnjonU_^_oYKk[1on4/?85og:Xl`SoR;?b5_ooool00ol0
003oooooooooo`06ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@03oooool001[ooooo00?o0000oooo
ooooool01_ooool2ojO0j`OoY[o[1OnV_^/2ojS1j`OoYl3[1onT^nX00onQ]^SoUJWToiFYi003oiFY
i0KoUJSS1onI[^D2oingj@So/]Gb00?o^=odokgTl_nmi?800onmi?86okWGk`Ko[/S]0_nY_nX5oj:e
iPSoXKGV00?oXkSXojJmj_nV_NX01?nV_NX7ojJnjP;oYkkZ1?nW_NT3o`0000OoYkgY3OnW_n/2ojRo
j`GoYl3[2?nW`>`>ojO0j`03ojNojonW`>_oYl3[00_oYl3[00?oYko[ojO0jonW`>/01_nW`>/6ojS1
j`;oYl3[2?nY`N/00onZ_nWoZl7Zoj_1jP03oj_1jPSoZKoY2?nY`>X6oj_1j@03oj_1j_n``nOo/<?W
00Go/<?W1?na`^H4ok?3iP?oYKk[00?o0000ojFnjonU_^/00_nU_^/3ohB`lP?oQ[3a1?mcY_42og:X
l`CoR;?b0on7/O4Gooooo`03o`000?oooooooooo00Kooooo00?oV9RHob4Q8Oo^k^h04?ooool001[o
oooo00?o0000ooooooooool00oooool6ojO0j`OoY[o[00?oY[k[ojS1jonX`N/01?nX`N/7ojO0j`?o
Y;_Z0onN]>L7oiFYi0KoUJSS1OnI[^D3ojC0k@Oo/]Gb1?nmh_82okgTlPSo^MO_0on^b>d3ojFjj0Oo
X[GV1_nQ]NH00onU^nWoY[gZojJmjP06ojJmjPGoY[kZ0_nW_^X2ojNmj@?o00002?nW_NT00onW_^_o
Yko[ojNoj`0;ojNoj`WoYl3[1_nW`>`2ojNoj`[oYl3[1OnW_n/9ojO0j`GoYko[2?nW`>/2ojS1j`Ko
Yl3[1_nY`N/00onX`>_oZl7Zoj_1jP05oj_1jPKoZKoY0_nZ`>T8ojW0jP;oZl7Y1On[`NX7ok33i`03
ok72i_nc`nKo/l?V00Go/l?V0onU_^/01?l0003oYKk[ojFnjonV_n/7ohJ`l@KoLjKa1on7/O4Goooo
o`03o`000?oooooooooo00Kooooo00?oV9RHob4Q8Oo^k^h03oooool001[ooooo00?o0000oooooooo
ool00_nX`N/8ojO0j`OoY[o[1onX`N/5ojO0j`;oXk_Z1_nN]>L7oiFYi0KoUJSS00?oVJkUojC0kOnT
`>d01OnT`>d4ok;ElPKo_N;b0_o0h_07okWGk`03oj_3jonU^^SoYK[X00GoYK[X1onR]NH2oj6eiPGo
YK_Y2?nV_NX00onV_^[oYkkZojNnjP02ojNnjP?o00002?nW_NT5ojNnj`WoYko[3OnW`>/2ojO0k0Ko
Yko[1_nW`>/00onW_^[oYko[ojNoj`06ojNoj`GoYl3[00?oYkkZojNojonW_n/01_nW_n/@ojO0j`;o
ZL7[1OnX`>/7oj_1jP;oZKoY1_nZ`>T7ojW0jPOoZl7Z1_n``nL2ojo2j0So/l?V0_nU_^/00onV_n_o
0000ojJoj`02ojJoj`OoQ[3a1_mcY_46ohNalAOooooo00?o0000ooooooooool01oooool00omgMgOo
IVIVooooo`0>ooooo`006Oooool00ol0003oZ<7[ojS1j`04ojS1j`SoYl3[1onV_n/7ojS1j`03ojO0
jonS^n[oXk_Z00CoXk_Z1_nN]>L7oiFYi0?oUJSS1?nK/NL7ojC0k@03ok;El_nmh_;o_N;b00Co_N;b
1Oo0h_04okWGk`CoZl?[1onU^^P5oj:eiP;oX[SX1onU^nT6ojJmjP03ojNnjonW_^[oYkkZ00?o0000
0onW_^X5ojNmj@;oY[gZ1onW_^/6ojNoj`goYl3[2onW_n/2ojO0j`GoYkkZ2?nW_n/00onW`>_oYkkZ
ojNnjP03ojNnjPSoYko[3onW`>/7ojS0j`KoZl7Z00?oZ/7Zoj[0jOnZ`>T01onZ`>T7ojW0jPOoZl7Z
0_n``nL6ojo2j0Ko/l?V0_nca>L3ojJoj`04o`000?nV_n_oY[o[ojJoj`OoQ[3a1_mcY_46ohNalAOo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0=ooooo`006Oooool00ol0003oZ<7[
ojS1j`05ojS1j`KoYl3[2OnV_n/5ojS1j`;oYko[1onS^nX6oijdi`?oUJWT0onDZND8oi^ai`GoY<3]
1?nif_42okgRlPSo`>;`00?o^MO_oj_3jon[`n/01On[`n/7ojFjj003oj:ei_nR^>SoX[SX00CoX[SX
1onU^nT2ojJmjPCoYkk[0_l00007ojNnjP03ojNmjOnV_N[oY[gZ00CoY[gZ1onW_^/2ojNoj`coYl3[
3_nW_n/00onX_^WoYkkZojNnjP06ojNnjPKoYko[00?oZ;kYojNnj_nW_^X01OnW_^X6ojNoj`;oZ;kZ
3onW`>/7ojS0j`;oZl7Z1OnZ`NX7oj[0j@03oj_1jOnY`>[oZL3Z00KoZL3Z1On[`NX2oj[1jPSo[l;X
0_nc`nH6ok?4i`;oY[o[00Co0000ojJojonV_n_oY[o/1on6/?06ogFUl0OoR:o_5Oooool3o`0000Co
oooo00Go0000okZj^_ooooooV9RHoa0@400?ooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Kooooo00?o0000oooooonX`N/01_nX`N/2ojO0j`goY[o[00?oZ<7[ojNojonW_n/01?nW_n/7oj>k
jP?oW[CW0_nCZ>D7oiBYi@SoVk7W00?oY<3]okWJlOnif_401Onif_43ol7Qk`Ko`>;`0oned>h7oj_3
j`?oYK[X0onO]>L8oj:hj0GoYK_Y0_nV_^X2ojNnj`?o00000_nW_^/6ojNnjP03ojJmjOnV_N[oY[gZ
00KoY[gZ1OnW_^/<ojO0j`koYko[1OnX_^T8ojNnjP;oYko[1OnX_^T7ojNnjP;oYko[1_nX_^X6ojO0
j`03ojNojonW`>_oYl3[00KoYl3[1OnX`>/2ojO0j`OoZ/7Z1?nZ`>T4oj_1j@SoZL3Z00?oZl7Zoj[1
j_nZ`NX01?nZ`NX6ojo2j003ojo3jOnca>Oo/lCW00Oo/lCW00?oY[o[ojJok?l000000onV_n`7ohJ`
l0KoMJG`1on8[nlFooooo`03o`000?oooooooooo00;ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00?
ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool01OnX`N/3
ojO0j`coY[o[0onX`N/6ojNoj`GoXk_Z00?oVk;Xoi>XiOnCZ>D01?nCZ>D7oiBYi@KoVk7W0onZa^h5
okWJl@Ko`N7_00?o`>;`okG@k_ned>h01Oned>h5oj_3j`;oX[OX1_nO]>L8oj:hj003ojFkjOnV_^[o
Y[kZ00;oY[kZ0ol00006ojNnj`;oYkkZ1OnV_NT8ojJmjP03ojNnjonW`>_oYl3[00[oYl3[3_nW_n/9
ojRnj@KoYkkZ0_nX_nX7ojRnj@GoYkkZ0_nY_nX8ojRnjP;oYl3[1OnW_n/8ojO0j`03ojS0jonW`>_o
Yl3[00CoYl3[1onZ`NX00onZ`>WoZl7Yoj_1j@05oj_1j@OoZL3Z2?nZ`NX2ojo2j0Go[l?Y1onca>L0
1OncaNOoY[o/ojJok?nV_nco000000?oY[o/1_n6/?06ogFUl0SoR:o_5_ooool00ol0003ooooooooo
o`0Eooooo`003_ooool01Ol@413ooooooooooooooooo410@00Kooooo0_l00002ooooo`03ojS1jonW
`>_oYl3[00GoYl3[2?nV_n/7ojS1j`KoYko[00?oXk_Zoi^bj?nK/^P00onK/^P6oi>Xi@KoU:WU1?nK
/NL6oj[6kP?o^M[a1_o1hNl3ol7NkPOo]M3^00?oZl?[oj:gj?nR]nP01?nR]nP6oindi`KoX[SX0_nU
_NX01?nV_^[o0000o`000?l00003ojJnjPGoYkk[0onV_NX6ojJmj@KoY[gZ2onW`>/>ojNoj`goZ;kY
0_nW_^X6ojRojPOoZ;kY00?oYkkZojVoj_nY_nX01?nY_nX6ojRnjP03ojVoj_nW_n_oYko[00KoYko[
3onW`>/3oj[1jPCoZL7[2?n[`NT7ojW0jPOoZ/7Z2?n_`nT4ok?4i`Co/lGW0onV_n`01?l0003oY[o/
ojJok?nV_n`6ohJ`l0KoMJG`1?n8[nl3oh^_kQOooooo00?o0000ooooooooool05?ooool000kooooo
00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00?ooooo1onW`>/8ojJoj`Oo
Z<7[0onW_n/3oj:kjPKoVk;X1_nCZ>D6oiBYi@03oi^aionZa^koZ/K^00OoZ/K^00?o^M[aol7Qkoo1
hNl00oo1hNl6ol7NkPGo]M3^0_nX`>/7oj:gj0KoWkCW0_nR^>P3ojFmjP?o00001onV_^X00onW_^_o
Y[gZojJmjP05ojJmjPKoY[gY0_nV_NX=ojO0j`goYko[00?oYkkZojRnjOnX_^T02onX_^T2ojS0j`So
Z;oZ0onX_^T4ojW1j`OoZKoZ0_nX_^X5ojVojPSoYko[3_nW`>/8ojW1j`KoZl7Y00?oZl7ZojW0j_nY
`>X01_nY`>X7oj[1jPSo[l?Y00?o/lCWok?5ioncaNL01?ncaNL3ojJok003o`000?nV_ncoY[o/00;o
YKo/1_n5[_05ogNTkPSoRjo^5_ooool00ol0003oooooooooo`0Dooooo`003_ooool01Ol0003ooooo
oooooooooooo000000Gooooo00?o0000ooooooooool01Oooool5ojO0j`[oY[o[1OnX`N/2ojNoj`Ko
X[_Z1_nK/^P6oi>Xi@?oU:WU1?nL]>T7oj[6kPCo_M[_0_o1hNl8ol7NkP03okG@k_nX`>_oZ<3[00Co
Z<3[1onR]nP3oindi`CoY;_Y0ol00004ojFmjP?oY[kZ1?nW_^X8ojJmjP?oY[gY0onW_n/?ojO0j`Wo
Yko[1OnW_^X9ojRnj@KoZ<3[1_nX_nX00onW`NcoZL7[ojW1j`06ojW1j`GoZKoZ00?oZL7[ojVoj_nY
_nX01_nY_nX6ojNoj`;oZ;oZ3_nW`>/8ojW1j`;oZl7Y1On[`NX6ojW0jP03ojW1jonZ`N[oZ/7Z00Ko
Z/7Z1on_`nT8ok?5i`;oY[o/00?oYKo/o`000?nU_n`00onU_n`6ohF^l0GoMjC^1on;[nhGooooo`03
o`000?oooooooooo01?ooooo000>ooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003o
ooooooooo`06ooooo`03ojO0jonV_n_oY[o[00coY[o[00?oZ<7[ojNojonW_n/01?nW_n/6oj:kjPKo
Vk;X0onCZ>D3oi>[iPOoW;CY1?nZa^h6okgJk`?oa>3]1_o1g^h2ok?<k@OoZ<3[1OnR]nP00onN]NSo
Y;_YojBkj@02ojBkj@?o000000?oY;_YojFmj_nU_NX00onU_NX2ojJnj`OoYkkZ1onV_NX7ojNoj`Ko
Yl3[00?oZ<3[ojO0jonW`>/01_nW`>/5ojNoj`WoYkkZ1_nX_^T2ojS1j`OoZ<3[0_nX_nX5ojO1k0So
ZL7[00?oZKoZojW1jonY`N/00onY`N/8ojVojP;oYko[1_nX_nX5ojO0j`03ojNojonW`>_oYl3[00Ko
Yl3[1_nY`N/00onX`>_oZl7Zoj_1jP06oj_1jP;oZL3Z1OnY`N/8oj[1jPOo[l?Y1_ncaNL2ok?6j0?o
YKo/00?o0000ojFok?nU_n`00_nU_n`6ohF^l0GoMjC^1on;[nhGooooo`03o`000?oooooooooo01;o
oooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2o`0000Sooooo3OnV_n/00onX`N_o
Yko[ojNoj`06ojNoj`KoX[_Z0onK/^P3oi6XiPKoTj_V1onL]>T00onZa^ko_M[_okgJk`05okgJk`Go
a>3]0_o1g^h6ok?<k@OoZ<3[00?oX[OXoijej?nN]NP00onN]NP3o`0000GoY;_Y00?oYKgZojJnjonV
_^/01?nV_^/7ojNnjPOoY[gZ1onW_n/2ojO0j`GoZ<3[2?nW`>/00onW_n_oYkkZojNnjP0;ojNnjP;o
Z;kY1_nX`N/5ojS0j`WoYl7/1_nY`N/00onW`NcoZL7[ojW1j`05ojW1j`KoZKoZ0_nY`N/8ojRojP03
ojO0jonW_n_oYko[00?oYko[2?nW`>/2ojW1j`GoZ<3[1on[`NX8ojW1j`OoZ/7Z2?n_`nT2ok?5i`Ko
/lKX0_nU_n`01Ol0003oYKo/ojFok?nU_ncoX[k]00KoPJ__1?mjXnd2ogNTkP?oRjo^0on@/>`Goooo
o`03o`000?oooooooooo01;ooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0
003oooooooooo`08ooooo`WoY[o[1OnX`N/8ojNoj`?oX[_Z0_nJ/nT7oi6XiPKoTj_V1OnL]>T3ojo9
k@Co_M[_1_o4h>d3ol;Lk0Oo/lc]0onX`>/3oinfj0CoW[GX0_l000000onN]NSoY;_YojBkj@04ojBk
j@03ojFmj_nV_^_oY[k[00KoY[k[1OnW_^X00onU_N[oY[gZojJmjP06ojJmjPGoYko[2OnX`>/6ojO0
j`koYkkZ0_nW`>`8ojS1j`03ojS0jonW`NcoYl7/00_oYl7/0_nY`N/5ojO1k0OoZL7[0_nY_nX6ojW1
j`KoZ;oZ00?oZL3ZojNojonW_n/01OnW_n/8ojO0j`OoZ<3[1on[`NX8ojW1j`OoZ/7Z2?n_`nT8ok?6
j0;oYKo/00?o0000oj:nkOnR_^d00_nR_^d6oh6[k`GoNZ?]1on@/>`Gooooo`03o`000?oooooooooo
017ooooo000Hooooo`03o`000?oooooooooo00Wooooo2?nV_n/6ojS1j`KoYko[00?oX[_[oiZcjOnJ
/nT01?nJ/nT7oi6XiPKoTj_V00?oW;CYojo9kOn_bNd01_n_bNd00onmf^ooa>3]olCPk@04olCPk@Go
`]c/1Oncc>d2ojNoj`KoWkKX0ol00004oijej0;oY;_Y1OnU_NX8ojJnj`03ojNnj_nU_N[oYKgZ00?o
YKgZ2?nV_NX00onW_n_oZ<3[ojS0j`0;ojS0j`;oYl3[3_nW_^X6ojO0k0KoZ<7[3_nW`N`2ojO0k0Oo
Yl7/1OnY`N/2ojO0k0SoZL7[0_nX_nX5ojW0jPOoYko[2?nW`>/7ojS0j`OoZl7Z2?nY`N/7oj[1jPSo
[l?Y1_nca^P01Onba^WoX[k]oj:nkOnR_^go000000?oX[k]1_n1Znl6ogZSk@OoT;3/5oooool00ol0
003oooooooooo`0@ooooo`006?ooool00ol0003oooooooooo`0:ooooo`SoY[o[1_nX`N/2ojNoj`Go
X[_[1_nJ/nT7oi6XiP?oTj_V1?nL]NT6ojo9k@?o_mW]1?o4h>d7ol;Lk003ok?<kOnW_n_oYko[00Co
Yko[0_nO]^P3o`000003oinfj?nN]NSoW[GX00?oW[GX0_nT^nX7ojFmjPKoY[k[00?oY[kZojFmj_nU
_NX01OnU_NX6ojJmjP;oYl3[3?nX`>/2ojNoj`_oYkkZ1?nW`>/7ojO0k0;oZ<7[3_nW`N`6ojO0k0Oo
Yl7/00?oZL7[ojO0k?nW`>`01?nW`>`6ojW1j`03ojS0jonY`>[oZL3Z00KoZL3Z1OnW_n/2ojS0j`So
Yl3[1_nX`>/8oj_1jPSoZL7[1_nZ`NX9ojo3j@;o/lKX1Onba^T3oj:nk@04o`000?nR_^goX[k]oj:n
k@KoPJ__1_mjXnd3oi2`k0?oUk?[5oooool2o`00017ooooo000Gooooo`?o00003Oooool7ojJoj`?o
Z<7[1?nW`>/6oj:kj`KoV[?Y0onAZ>H3oi:[i`SoW;GY0on_bNd7okoIk@03olCPkOo2g>co`]c/00Go
`]c/0oncc>`4ojNoj`?o00001OnO]^P00onN]NSoY;_ZojBkjP04ojBkjPOoYKgZ0_nV_^/5ojJnjPOo
YKgZ0_nV_NX6ojO0j`SoZ<3[1_nW_n/6ojNnjP03ojNojonW`>_oYl3[00KoYl3[1OnW`>`>ojO1k0;o
Yl3[2?nW`>`3ojO1k0_oYl3/0_nY`N/5ojS0j`SoZL3Z00?oYko[ojS0jonX`>/01?nX`>/7ojO0j`Oo
Z<3[2?n[`NX8ojW1j`KoZ/7Z1on_`nT00on`a>Wo//KYok;6j@06ok;6j@;oX[k]00Co0000oijkkOnN
^ngoW[_]1_mnYN`6ogfSj`OoUk?[5Oooool00ol0003oooooo`00000Aooooo`005oooool00ol0003o
ooooooooo`0>ooooo`GoY[o[0_nX`>/7ojO0j`KoX[_[0onJ/nT2ohnYi`OoTZ_W2?nL]NT00on_bNgo
_mW]okoIk@05okoIk@?oaMg[1?o2g>`6ok?<k0?o00000onW_n/3oinfj0CoW[KY1_nT^nX5ojFmjP?o
Y[k[1_nV_^X5ojFmjP?oY[k[1onW`>/3ojS0j`CoYl3[1onW_n/2ojNnjPGoYko[2?nW`>/00onW`>co
Yl7/ojO1k00<ojO1k0KoYl3[1_nW`>`00onW_n_oYl3/ojO0k00;ojO0k0;oY/3/1onX`>/7ojW0jPSo
Z<3[1onW`>/7ojS0j`SoZl7Z1onY`N/7oj[1jPCo[l?Y1?n`a>T6ok;6j@05ok36jonN^ngoW[_]oijk
kOl000000onN^nd6ogjUk0KoOJ?[1onG/n/Fooooo`03o`000?oooooooooo00oooooo000Gooooo`03
o`000?oooooooooo00oooooo00?oY[o[ojS0jonX`>/01?nX`>/7ojO0j`?oX[_[0onJ]N/5ohnYi`Oo
TZ_W1_nL]NT3ok38k0Co_mW]1oo5gN/00oo2g>co/lc/ok?<k002ok?<k0?o000000Co/lc/ojNojonW
_n_oYko[0_nN]nT8oijfj@KoY;_Z00?oYKgZojJnjonV_^/01OnV_^/6ojJnjP03ojFmj_nV_^_oY[k[
00GoY[k[1OnW`>/00onX`>_oYl3[ojO0j`06ojO0j`GoYko[0_nV_^X7ojNoj`KoYl3[0_nX`N`:ojO1
k0CoYko[1onW`>/2ojO0k0GoYko[2OnW`>`6ojK0k0OoZ<3[1onY`>X7ojS0j`SoYl3[1onX`>/8oj_1
jPOoZL7[1onZ`NX00on_`nWo/<CYok34j@04ok34j@Co//KY1?n`a^/3oijkk@04o`000?nN^ngoW[_]
oijkk@KoOZG/1_mmXn/7oiNcjaKooooo00?o0000ooooooooool03_ooool001Oooooo00?o0000oooo
ooooool04?ooool7ojS0j`GoYl3[0_nS_>/6oiZej`GoSjWW1onBZnL2oibej@Oo/<S/00?o_mW]olGM
joo5gN/01_o5gN/3olCKjP?o00000oncc>`00onX`NcoW[OYoijgj@04oijgj@SoW[KY0onT^nX3ojFm
j`SoY[k[0onV_^X3ojFmjPSoY[k[00?oYl3[ojS0jonX`>/00onX`>/8ojO0j`03ojNojonV_^[oY[kZ
00CoY[kZ1onW_n/2ojO0j`KoZ<7/1OnW`N`9ojNoj`GoYl3[00?oZ;kYojNojonW_n/01_nW_n/6ojO0
k0;oYko[1onV`>`3ojS0j`CoYl3[1onY`>X7ojS0j`SoYl3[1onX`>/6oj_1jP03oj_2j_nY`N_oZL7[
00GoZL7[1_nZ`NX2oj_2jPOo/<CY00?o//KYok36jon`a^/01On`a^/3oijkk@04o`000?nN^ngoW[_]
oijkk@KoOZG/1_mmXn/3oiNcj`?oWkOY5oooool00ol0003oooooooooo`0=ooooo`005oooool2o`00
01;ooooo1onX`>/00onW`>_oXkc[oj>lj`04oj>lj`KoV[G[1On?ZNL5oi:[i`?oVkCY1_n`b>`3ol3G
jPGoaMg[0_o4fnX3o`000003olCKj_ncc>co/lc/00GoZ<7/1_nN]nT6oijfj@03oj>kj_nU_N_oYKg[
00GoYKg[1_nV_^/00onU_^_oYKgZojFmjP05ojFmjPKoY[k[2?nX`>/6ojO0j`WoY[kZ1OnW_n/:ojS1
k003ojO1k?nW_n_oYko[00_oYko[00?oYl3[ojRnjOnX_^T00onX_^T8ojNoj`;oYl3/1_nW_n/5ojK0
k003ojJok?nW`>_oYl3[00KoYl3[1OnY`>X2ojW1jPOoZ<3[1_nW`>/00onW_n_oZ<3[ojS0j`06ojS0
j`;oZl7Z1On[`^X7ojW1j`;oZ/7Z1_n[`^X5ok34j@;o//GY2?n`a^/2oijkk@04o`000?nG]ngoUkO]
oiNgk@KoOJ7Z1_n2Y>T7oingjAKooooo00?o0000ooooooooool03Oooool001Oooooo00?o0000oooo
ooooool04_ooool8ojS0j`KoXkc[1_nJ]N/5ohnYi`03oi:[ionK]>WoVkCY00GoVkCY0on`b>`7ol3G
jP03olGMjoo4fn[oa=_Z00;o00000oo4fnX2okO?k0OoZ<7/1_nN]nT2oijfj@GoXk_Z1onU_N/2ojJn
j`GoYKk[1onU_NX2ojJnj`coZ<3[0_nW`>/=ojJnjP03ojNojonX`NcoZ<7/00[oZ<7/00?oYl3[ojNo
jonW_n/02onW_n/8ojRnj@KoYko[0_nX_nX8ojNoj`03ojK0k?nV_ncoY[o/00?oY[o/2?nW`>/00onY
`>[oZL7ZojW1jP04ojW1jPOoZ<3[0_nW`>/5ojNoj`OoZ<3[1on[`^X8ojW1j`SoZl;Z00?o/<CYok;5
jOnbaNT01?nbaNT6ok36j`05ojc5k?nG]ngoUkO]oiNgkOl000000onG]nd6ogfQjPKoPZCY1onO]nTF
ooooo`03o`000?oooooooooo00cooooo000Gooooo`03o`000?oooooooooo01?ooooo2?nX`>/6oj>l
j`?oV[G[0_n>Z^T7oi2Zj0OoVkCY00?o/<S/ol3Gj_o0enX01Oo0enX01?o6f^So0000o`000?l00003
olCKjPGo]lo/1onX`N`3oijgj@CoWKGY1_nS^nX5ojFmj`?oY[k[1_nU_^/5ojFmjP?oYko[2onX`>/3
ojO0j`[oY[kZ1?nW`>/9ojS1k0GoYl3[2OnW_n/<ojRnj@;oYko[1_nX_nX7ojNoj`OoY[o/1_nW`>/0
0onW_n_oZL7ZojW1jP06ojW1jPOoZ<3[1onW_n/7ojS0j`OoZl;Z2?nY`N/6oj_2jP03oj_2jonbaNWo
//GY00Ko//GY0_n`a^/5ojc5k0?oUkO]00?o0000oiNgkOnG]nd01_mmXNX6oh:Tj@KoWkOY00?oZKgX
ooooooooool05Oooool00ol0003oooooooooo`0;ooooo`005oooool00ol0003oooooooooo`0Eoooo
o`OoZ<3[0onS_>/3oibhj`GoSZ[Y1on@Z^P5oi^dj@?o[/CZ1?o0enX3o`0000Coa][X00?oa=_ZokO?
k?ngcn`01Ongcn`5ojS1k003oijhjonM]NWoWKGY00KoWKGY1_nS^nX00onU_N_oY[k[ojJnj`05ojJn
j`KoYKk[00?oYKgZojNojonW_n/01OnW_n/7ojS0j`OoYl3[1OnV_^X00onV_^_oYl3[ojO0j`06ojO0
j`GoZ<7/0_nX`N/7ojO0j`GoYko[0_nW_^X;ojRnj@?oZL3[2?nX_nX7ojNoj`OoY[o/0_nW`>/5ojNo
j`KoZL7Z00?oZL7[ojS0jonX`>/01_nX`>/6ojNoj`SoZ<3[1On[`^X2oj_2j`SoZL7[0_n[`^X5oj_2
j`Ko//GY00?o/lSZojc5k?n/aN`01_n/aN`3oiNgk@03o`000?nG]ngoUkO]00KoOJ7Z1_n2Y>T2oing
j@GoZKgX5_ooool00ol0003oooooooooo`0;ooooo`005_ooool3o`0001Oooooo1OnX`>/2ojBnk0Ko
W;S[1On>Z^T7oi2Zj003oi^djOn^a>[o[/CZ00Go[/CZ0ol00006olKJj0?oa]WX1ongcn`00onX`Nco
W[S[oijhj`03oijhj`SoWKGY0onS^nX3ojFmj`SoY[k[0onU_^/3ojFmj`SoYko[1_nX`>/8ojO0j`03
ojJnj_nV_^_oY[k[00?oY[k[2?nW`>/00onX`NcoZ<7[ojS1j`04ojS1j`OoYl3[00?oYko[ojNnj_nW
_^X01?nW_^X6ojRnj@03ojS1k?nY`>_oZL3[00GoZL3[1_nX_nX2ojW0jPKoYko[1_nV_n`2ojJoj`Oo
Yko[0_nY`NX5ojW1j`SoZ<3[1_nW_n/8ojS0j`03oj_2j_n[`^_oZl;[00CoZl;[1onY`N/8oj_2j`;o
//GY1Oncb>X6ojc5k005ojK1k?n=[ngoSJo]ohf_kOl000000_n=[nd6ogjOj0OoR:KX1onY_NPFoooo
o`03o`000?oooooooooo00[ooooo000Fooooo`03o`000?oooooooooo01Sooooo00?oZ<3[ojBnk?nT
_^`01?nT_^`6oibhj`GoSZ[Y1On@Z^P00onH/^Wo[/CZojk4jP03ojk4jP?o000000?o[/CZol3Gj_o6
f^P01?o6f^P6olKIj0Go]lo/0_n[`n`6oijhj`KoWKGY00?oX[_[ojFmjonU_N/01OnU_N/6ojJnj`03
ojFnjonU_N_oYKg[00GoYKg[1_nW_n/8ojS0j`KoYl3[2?nV_^/6ojO0j`WoZ<7[0onW`>/;ojNnjP;o
Z;kY1OnX`N`7ojW0j`;oZ;oZ1_nY`>X6ojNoj`;oY[o/1_nV_n/6ojNoj`SoZL7[1onX`>/7ojNoj`Ko
Z<3[00?oZL3[oj_2jon[`^/01_n[`^/7ojW1j`KoZl;[00?o[<?[ok?8j_ncb>X01_ncb>X2ojc5k0Go
Y/7/0on=[nd00ol0003oSJo]ohf_k@06ogjOj0OoR:KX1OnY_NP2ok;6jACooooo0ol0000;ooooo`00
1?ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h6ooooo`03o`000?oooooo
oooo01[ooooo1_nT_^`6oibhj`GoSZ[Y00?oT:[XoiRbjOnH/^T00onH/^T01?n^a>[o0000o`000?l0
0003ojk4jPCo_m?Y0_o6f^P8olKIj003okO?k?n[`ncoZl?/00CoZl?/1_nN^>/2oifej@GoX[_[1onU
_N/2ojJnj`GoYKk[1onU_N/2ojNoj`coZ<3[0_nW`>/<ojJnj`;oYl3[2onX`N/00onW_n_oYkkZojNn
jP0;ojNnjP;oYl7/1onX`N`5ojW0j`;oYl7/2?nY`>X3ojNoj`?oZ<3[2?nV_n/6ojNoj`SoZL7[1onX
`>/7ojNoj`;oZ<3[1OnY`>/6oj_2j`;oZ/;[1onY`N/2oj_2j`Go[<?[1_ncb>X2ok?9j`KoY/7/1?n=
[nd00ol0003oSJo]ogjOj006ogjOj0OoR:KX00?oZKgXok;6jOnba^T01?nba^T@ooooo`?o00000_oo
ool00ol0003oooooooooo`09ooooo`001_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01_ooool00ol0003oooooooooo`0Kooooo`KoY;k/0onL^>/2ohn^j`KoSJ[Y0onH
/^T3o`0000Co[/CZ1_nodnT2olKGiPOoa]WX0_nmdnX7oj_3k0?oW[S[0onK]^/7oj:kj`GoYKg[0_nV
_^/7ojFnj`GoYKg[0onV_^/;ojS0j`?oYl3[2onV_^/2ojS0j`WoZ<7[1OnW_n/9ojNnjPKoYl7/1onX
`N`00onY`>_oYl7/ojO1k004ojO1k0KoZL3Z00?oZL7ZojS0jonX`>/01OnX`>/8ojJoj`KoYko[2?nY
`N/7ojS0j`OoYko[1onY`>/2oj_2j`KoZ/;[1_nY`N/8ojc3j`;o/lSZ1_ncbN/6ojK1k0?oSJo]00?o
0000ohf_kOn=[nd01omnWnP3ohRVj0?oTZ_W2?nba^T<ooooo`?o00001Oooool00ol0003ooooooooo
o`09ooooo`001_ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41001_oo
ool2o`0001gooooo0onT_^`2oijjk0KoSjk[1On=Z^T3o`0000CoV;;Y00?o[/CZokoCjOnodnT01Ono
dnT4olKGiPCoa]WX1OnmdnX5oj_3k0;oXKc/1_nK]^/7oj:kj`03ojFmjonV_^_oY[k[00CoY[k[1onU
_^/00onU_N_oY[k[ojJnj`05ojJnj`OoZ<3[1onW`>/7ojJnj`KoZ<3[1_nX`N/00onX`>_oYko[ojNo
j`05ojNoj`KoYkkZ0_nW_n/7ojO1k0?oZ<7/1?nV`^d7ojO1k0;oZL3Z1OnY`NX7ojS0j`SoY[o[1_nW
_n/8ojW1j`GoZ<3[00?oYl3[ojNojonW_n/01_nW_n/5ojW0j`;oZ/7[2?nZ`^/6ojW1j`Ko[<?[0_n_
aNX8ok?9j`?oY/7/0_nP^n`4ohFTj003o`000?n5Y>SoPIoV00KoPIoV1onBZnL6ok;6j@03okS<jOoo
oooooooo00Kooooo1?l00008ooooo`03o`000?oooooooooo00Wooooo0006ooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000005ooooo`;o00007_ooool6oijjk0KoSjk[0_n=
Z^T2o`0000;oSJ[Y0onH/^T4ojRmj@Co_m?Y1oo6enH00oo6fNSo_M?ZokgCjP06okgCjP03oj_3k?nQ
_>coXKc/00CoXKc/1_nK]^/5oj:kj`;oY;g[1onV_^/5ojFnj`;oY;g[2?nV_^/6ojS0j`SoYl3[1_nV
_^/7ojS0j`;oZ<7[1OnX`>/7ojNoj`;oYkkZ1_nW_n/5ojO1k003ojO2kOnV`^goY/;]00KoY/;]1OnW
`N`00onV_ncoZL7ZojW1jP06ojW1jPGoZ<3[0_nX`N/8ojJoj`KoYko[2?nY`N/00onX`>_oYl3[ojO0
j`03ojO0j`SoYko[00?oZL3[oj[1jonZ`N/01?nZ`N/6oj[2j`03ojW2jonY`N_oZL7[00GoZL7[0on/
`n/5ojo5jPKo/lW[00?o[lS/oj2kk?nP^n`01?nP^n`4ohFTj003o`000?n5Y>SoPIoV00KoPIoV1_nB
ZnL4ok;6j@Co^<cY1?ooool3o`0000gooooo00?o0000ooooooooool02?ooool000Kooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool07_oo
ool6oijjk0CoSjk[0ol00002ohfZj@?oTjoZ2?nX_NT00onodnWoa]OVolKGiP05olKGiP?ob=OU1_nm
dnX3ok37j`KoXKc/1_nK]^/00onR^n_oY;g[ojBmj`04ojBmj`OoY[k[00?oYKk[ojBmjonT_N/01?nT
_N/6ojJnj`SoZ<3[1_nW`>/8ojJnj`GoZ<3[0onX`N/6ojS0j`GoYko[0_nV_^/8ojNoj`03ojO1k?nW
`^goYl;]00?oYl;]2?nV`^d00onW`NcoY[o/ojJok003ojJok0SoZL7Z00?oZ<3[ojS1jonX`N/01?nX
`N/7ojJoj`OoYko[1_nY`N/00onY`^_oYl3[ojO0j`05ojO0j`OoYko[2?nZ`N/2oj[2j`GoZL;[1onY
`N/00on/`n_o[lGZojo5jP05ojo5jP;o/lW[1On_b>`6oj2kk0CoQJCX00?o0000ohFTj?n1WnH01On1
WnH7oi:[i`03ok;6jOnhc>Wo^<cY00Go^<cY0ol0000@ooooo`03o`000?oooooooooo00Sooooo0006
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oo
oooooooo01oooooo1_nN^^`3o`0000?oRZ[[1_nC[nX6ojRmj@?o^lgW1?o6enH7olSGi@03okgCj_n`
an_o/<O[00Go/<O[1_nQ_>`3oi^fj`?oWkW[1onT_N/3ojJnj`CoY[o[1onT_N/2ojJnj`coZ<3[0_nW
`>/<ojJnj`03ojS0jonX`N_oZ<7[00GoZ<7[1_nX`>/00onW_n_oY[k[ojJnj`04ojJnj`KoYko[0_nX
`N/6ojO2k@KoY/;]0_nU_n`6ojJok0KoZL7Z0_nY`N/7ojS1j`OoY[o[1onW_n/2ojW1j`GoZL;[1onW
`>/7ojNoj`KoZ/7[00?oZl?[ojW2jonY`^/01_nY`^/3ojW1j`?oZ/;[1on_aNX00onbbN_o[lS/ojo8
k006ojo8k0KoX;_/0on5Y>P00ol0003oQJCXohFTj006oh6OiP?oTZ_W0onO]>L7okS<j@;o_=;Z4_oo
ool00ol0003oooooooooo`08ooooo`001_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2o`00027ooooo0_nN^^`3o`000003oiBdkOn:Z^_oRZ[[00CoRZ[[1_nC
[nX3ojRmj@Oo^lgW00?oa]OVolSGiOo8enD01Oo8enD2olGDiPSo/<O[0onQ_>`3oi^gk0KoWkW[1OnT
_N/3ojFnj`KoY[o[1OnT_N/3ojFnj`_oZ<3[0_nW`>/<ojJnj`;oZ<3[2?nX`N/3ojS0j`?oY[o[1onV
_^/2ojNoj`KoZ<7[1_nW`^d2ojK2k@KoYKo/1_nV_n`2ojW1jPKoZL7[1OnX`N/2ojO0j`KoY[o[1_nW
_n/2ojS0j`OoZL;[1onW`>/7ojNoj`;oZ/7[1On[`n/6ojW2j`03ojW1jonZ`^_oZ/;[00GoZ/;[1?n_
aNX4ok;9j`Ko[lS/00?oZ<;/oiBajonD/N/01?nD/N/4oh>Ni@03o`000?n3W^GoQj7U00GoQj7U1onO
]>L4okS<j@Go_=;Z4Oooool00ol0003oooooooooo`08ooooo`001?ooool00omEEEGoIVIVo`000004
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`0Oooooo`?o00001OnD
]>d6ohZZj`KoTjoZ00?oZ;gYok_=ionkcNL01OnkcNL3olCBi@Cob=OU1Oo5e>H6ok37j`03ojO1k?nK
]ncoVkO/00GoVkO/1_nO^N/00onT_N_oYKk[ojFnj`05ojFnj`KoY[o[00?oY;g[ojFnjonU_^/01OnU
_^/7ojS0j`KoYl3[2?nV_^/6ojS0j`KoZ<7[0_nX`>/6ojJoj`GoY[k[0_nW_n/8ojS1j`?oYl;]0onW
`>/8ojFok0?oY[o/0onV_^/8ojW1j`03ojS1jonW`>_oYl3[00CoYl3[1_nV_n/2ojNoj`KoZ<3[1OnY
`^/00onX`N_oYl3[ojO0j`06ojO0j`GoYko[0_nX`>/7oj_3j`;oZL;[1OnY`N/7oj[2j`03ojo5j_nb
bN_o//W[00Go//W[0_n_b>`5ojS2k0KoU;7[1?n3W^D00ol0003oPikUohNQi@05ohNQi@OoWkCW00?o
^<cYokcBj_nld^X01?nld^X00onoe^_oooooooooo`0?ooooo`03o`000?oooooooooo00Sooooo000E
ooooo`03o`000?oooooooooo01cooooo0ol00004ooooo`GoU;C]1_n:Z^/3oi>_jPCoW[SZ1OnkcNL6
olCBi@03olSGiOo5e>KoaMCV00GoaMCV0_n`an/5ojO1k0OoVkO/0onO^N/4oj>lj`OoYKk[0onV_n/3
ojBnk0SoYKk[1_nX`>/7ojO0j`?oY[k[1?nU_^/7ojS0j`;oZ<7[1_nX`>/6ojJoj`03ojJnjonW_n_o
Yko[00CoYko[1_nX`N/00onZ`N[oYl3[ojO0j`05ojO0j`KoYKo/00?oYKgZojJnjonV_^/01OnV_^/6
ojW1j`03ojW2jonW`>_oYl3[00KoYl3[1_nV_n/8ojS0j`03ojW2jonX`N_oZ<7[00?oZ<7[2?nW`>/0
0onW_n_oZ<3[ojS0j`04ojS0j`GoZl?[0_nZ`n`7ojW1j`GoZ/;[0_n/`n/6ok;9j`;o//_/1_nX`^`6
oiBaj`GoPikU00?o0000ohNQiOn7XND01?n7XND6oindi`;o[L?Z1?nld^X4okoFja3ooooo00?o0000
ooooooooool02?ooool001Gooooo00?o0000ooooooooool06Oooool3o`0000Sooooo1OnD]>d3ohZZ
j`;oSJc[2?nN^>X3ok_=i`Koa=;U0oo8dn85olGDiP?o^/oY1_nW`N`6oi^gk0SoXkc[1OnU_^/00onV
_n_oY;k/ojBnk005ojBnk0KoYKk[00?oYko[ojS0jonX`>/01OnX`>/5ojO0j`?oY[o/1_nU_^/5ojS0
j`;oZ<7[2?nX`>/3ojJoj`?oYKk/1onW_n/2ojS1j`GoZ/7Z1onW`>/2ojFok0GoYKgZ1onV_^/2ojW1
j`GoZL;[1_nW`>/00onW_n_oY[o[ojJoj`05ojJoj`KoZ<3[00?oZL;[ojS1jonX`N/01OnX`N/6ojO0
j`03ojNojonX`>_oZ<3[00KoZ<3[00?oZl?[oj[3k?nZ`n`01?nZ`n`7ojW1j`03oj[2jon/`n_o[<?[
00Co[<?[0onbbN/5ok;;k0KoZ<;/1_nD/N/4oh>Ni@03o`000?n3W^GoQj7U00GoQj7U0_nO]>L6ojg3
jP03okcBj_noe^_o_mK[00Go_mK[3oooool00ol0003oooooooooo`08ooooo`005Oooool00ol0003o
ooooooooo`0Fooooo`?o00003?ooool4ohV/k@KoSJc[2?nN^>X00onkcNOoa=;UolCBi@04olCBi@Go
b=?R00?oaMCVok[?jOnjcnT01OnjcnT6ojO1k0KoVkO/2?nS_>/00onU_^_oY[o[ojJoj`03ojJoj`Oo
Y;k/0_nU_^/5ojNoj`OoZ<3[00?oYl3[ojJok?nV_n`01OnV_n`6ojFnj`03ojS0jonX`N_oZ<7[00Co
Z<7[1_nX`>/00onW`>_oYKk/ojFnk005ojFnk0GoYko[0_nY`>/7oj[1jPGoYl3[0_nW_^T7ojFmjPGo
Y[k[0_nW`>/7ojW2j`;oYl3[1OnW_n/7ojJoj`;oZ<3[1OnY`^/7ojS1j`;oYl3[1OnW_n/6ojS0j`03
ojW2jonZ`ncoZ/?/00KoZ/?/0onY`N/3ojW2j`So[<?[00?o//W[ok;;k?nbbn`01Onbbn`3ojS2k0;o
X;[[1_n9XnD5ohFMhP03o`000?n@YnGoT:OU00GoT:OU1_n]`nX2okK=j`Ko_mK[00?o_MS]oooooooo
ool03_ooool00ol0003oooooooooo`07ooooo`005?ooool2o`0001Gooooo0ol0000@ooooo`CoRJc]
1_n=[>/6oijhjP?o/<;W0oo4d^D6olSChP?obM?R1onjcnT3ojO1k0?oWkc]1_nK]n`6oj>lj`;oY;k[
1_nV_n/8ojBnk0KoYko[1onX`>/8ojJok0?oYKk[0onW_n/7ojS1j`;oZ<3[1OnW`>/7ojFnk003ojNo
jonY`>_oZL3[00CoZL3[1onZ`NX00onW`>_oYkkYojNnj@04ojNnj@OoYKgZ00?oY[k[ojO0jonW`>/0
1?nW`>/5ojW2j`;oZ<7[1onW_n/5ojJoj`;oYko[1onY`^/3ojS1j`CoYl3[1onW_n/2ojS0j`GoZL;[
1_nZ`n`00onY`^coZL;[ojW2j`05ojW2j`Ko[<?[0_n_a^/6ok;;k003ojg7kOnP^^_oX;[[00CoX;[[
1_n9XnD5ohFMhP03o`000?n@YnGoT:OU00GoT:OU0on]`nX5okK=j`?o_mK[1?nmf>d?ooooo`03o`00
0?oooooooooo00Oooooo000Dooooo`03o`000?oooooooooo01;ooooo0_l0000Dooooo`CoRJc]1_n=
[>/2oijhjPOo/<;W00?oa=;UolSCh_o8dn801?o8dn85olWChPGo^/oY0_n`a^/6oinlk@KoVkO/0_nS
_>/6ojBnj`KoY[o[2?nT_^`6ojNoj`OoZ<3[1_nV_n`00onU_ncoYko[ojNoj`05ojNoj`GoZ<7[0_nX
`>/7ojO0j`GoYKk/0_nU_n`7ojW0j`?oZ/7Z1?nZ`>T7ojNnj@?oYKgZ0onV_^/8ojO0j`03ojW2jonX
`N_oZ<7[00CoZ<7[1onW_n/00onV_n_oYko[ojNoj`04ojNoj`GoZL;[0_nY`^`7ojO0j`OoYko[1onY
`^/2oj[3k0GoZL;/1onY`^/2ojc3j`Ko[lK[0_nbbn`5ojg7k@KoX;[[1_n9XnD5ohFMhP03o`000?n@
YnGoT:OU00GoT:OU00?o[L?ZokK=jonfcN/01OnfcN/00onoe^_o_MS]okgHk@04okgHk@kooooo00?o
0000ooooooooool01oooool001Cooooo00?o0000ooooooooool03oooool3o`0001Oooooo1?n9[>d3
ohf/j`CoUK;[1_n``^L3oko<i0Cob=?R1oo9dn800onjcnWo/<K[ok36j`04ok36j`KoWkc]0onK]n`4
oinij`OoY;k[0onV_n/3ojFok0SoY;k/0onW_n/:ojS0j`;oY[o/1OnU_n`7ojNoj`03ojS1jonX`>_o
Z<3[00CoZ<3[1onW`>/00onU_^coYKo/ojFok004ojFok0GoZL3[00?oZL7[oj[0jOnZ`>T01_nZ`>T5
ojNnj@;oYkkZ1_nV_^/6ojO0j`;oZL;/1onX`N/>ojNoj`03ojW2jonY`^coZL;/00CoZL;/1onW`>/7
ojNoj`GoZL;[0_nZ`n`6ojW2k0KoZL;[0_nZ`n`6ojo6j`;o//c]1_n]and7oj2jj`KoRJ?U1?n5WN80
0ol0003oQIgRoi2Wi@02oi2Wi@?oWk?V1onfcN/2okcDk0Go_MS]0_nfd^h=ooooo`03o`000?oooooo
oooo00Oooooo000Dooooo`03o`000?oooooooooo00cooooo0ol0000Jooooo`KoQj_]1_nE/^/3ok32
i`Oo_lcT00?ob=?RolWCh_o9dn801Oo9dn82olKAh`Oo/<K[0onO_>d4oiZik@KoWkW[1OnT_^/00onU
_^_oYKo/ojFok005ojFok0KoY;k/00?oYKk[ojS0jonX`>/02_nX`>/2ojO0j`OoYKo/1OnW_n/9ojS0
j`?oYl3[1?nW_n/7ojFok003ojW0jonY`N_oZL7[00?oZL7[2?nZ`>T00onW_^WoYkkZojNnjP04ojNn
jPKoY[k[0_nW`>/6ojW2k0GoZ<7[3_nW_n/2ojW1k0OoZL;/0onW`>/;ojNoj`03ojW2jonZ`ncoZ/?/
00CoZ/?/1_nY`^`2ojW2j`KoZ/?/0on_a^/5ok;<k@Ko[LO]0onP^^/3oi>[i`KoQicQ1On;XN800ol0
003oWk?VoinciP05oinciPCo]/g[1Onle>`00onmf>go]];^okKBkP04okKBkPcooooo00?o0000oooo
ooooool01oooool001?ooooo0ol0000:ooooo`?o00007_ooool6ohN[k@KoUK;[00?o/<;Woko<i?no
c>@01Onoc>@3olG?hPCobM?R1Oo6dN<5ok36j`?oZ<;/1_nJ^Nd6oinij`03ojBnjonU_^_oYKk[00?o
YKk[1onU_n`2ojBnk0GoYKk[2?nX`>/6ojO0j`OoYKo/00?oYko[ojS0jonX`>/02onX`>/7ojNoj`Go
YKo/0_nU`>`6ojW1j`KoZ/3Y0_nX`>/7ojNnjP?oY[k[0onX`^`8ojW2k003ojS1jonW_n_oYko[00co
Yko[1_nY`N`5ojW2k003ojS0jonW_n_oYko[00_oYko[00?oZ<7[oj[3k?nZ`n`01_nZ`n`3ojW2k0?o
ZL7[2?nZ`n`00on_a^_o//c]ok;<k@05ok;<k@?o[LO]0onU_^/6oi>[i`KoQicQ1On;XN800ol0003o
Wk?VoinciP05oinciP03okK=jonle>co_=C/00Co_=C/00?o_]W^okKBk_nfd^h01_nfd^h;ooooo`03
o`000?oooooooooo00Oooooo000Dooooo`03o`000?oooooooooo00Kooooo0ol0000Rooooo`KoQj_]
0onE/^/4oj2ij`Go_lcT1_o5cn800oo9dn;oa]7SolKAh`05olKAh`03ok36jonX`^coZ<;/00GoZ<;/
1_nJ^Nd3oinij`?oX[c/1_nU_^/5ojFok0?oY;k/1_nU_^/7ojS0j`OoYl3[1onU_n`>ojS0j`OoYko[
00?oYKo/ojG0k?nU`>`01?nU`>`6ojW1j`;oZ/3Y1_nX`>/5ojNnjP;oYl;]1_nX`^`6ojW2k003ojS0
jonW_n_oYko[00coYko[2?nY`N`00onY`^coZ<3[ojS0j`03ojS0j`WoYko[1OnX`N/6oj[3k003ojW2
k?nY`N_oZL7[00GoZL7[1_nZ`n`2ojc5k0Ko//c]00?o[l[^ojFnjonU_^/01OnU_^/5oi>[i`KoQicQ
1On;XN800ol0003oWk?VoinciP04oinciP;o[lK[1?nle>`4okkIkPKo]];^00?o[lW]ooooooooool0
2Oooool00ol0003oooooooooo`07ooooo`005?ooool00ol0003oooooooooo`03ooooo`?o00009_oo
ool3ohN[k@?oRjk]1onP^N/3oko<i0KoaLoR0_o8cml6olKAh`?o_lkV1onX`^`3oiZik@;oVKS^1onR
_>`6ojFnj`03ojFok?nT_^coY;k/00GoY;k/1_nU_^/7ojS0j`SoYl3[1_nU_n`>ojS0j`OoYko[1onU
`>`3ojW1j`?oYl7/2?nX`>/00onW_^[oYl;]ojO2k@04ojO2k@KoZ<;/0_nY`^`5ojS0j`koYko[1_nY
`N`00onY`^coZ<3[ojS0j`05ojS0j`OoYko[1onX`N/2oj[3k0GoZL;/1onY`N/2oj[3k0Ko[<G/0_nb
c>d5ojo:kPOoYKk[1?nCZnL6ohNLh@KoRj7R00?o0000oinci_nO/nH01_n_a^/00onle>co_]W^okkI
kP05okkIkP;o]];^1On_bNd;ooooo`03o`000?oooooooooo00Kooooo000Cooooo`04o`000?oooooo
ooooooooo`?o0000:_ooool6oh^^k@OoX;W[00?o_lcTolG?h_o5cn801?o5cn84olS?g`?oa]7S1_no
c^H5ojS2k003oj:okOnI^>koVKS^00CoVKS^1onR_>`3ojFnj`CoY[o[1onT_^`3ojFnj`?oY[o[1onX
`>/8ojO0j`KoYKo/3OnX`>/8ojNoj`GoYL3/0_nU_n`6ojO1k0KoZ<3[2OnW`^d3ojS2k0?oZ<7[1onX
`>/>ojNoj`;oZL7/1OnY`^`7ojS0j`OoYko[1OnX`N/2oj[3k0OoZL;/0onY`N/3ojW3k0Oo[<G/00?o
/Lc^ojo:k_n_b^h01_n_b^h3ojFnj`?oV[3W1?n;WMl00onCZnOoQicQohNLh@04ohNLh@?oRj7R0onE
ZN@00ol0003o[lK[ojo6j`04ojo6j`03okSBkOnnfNko_]W^00Go_]W^00?o^]S_ojo9kOn_bNd01_n_
bNd:ooooo`03o`000?oooooooooo00Kooooo000Cooooo`Co0000;_ooool6oh^^k@GoX;W[0on``NH3
olG?hPOob<oO00?oa]7Soko>i_noc^H01_noc^H00onX`^coX[o]oj:ok@03oj:ok@KoVKS^1OnR_>`2
oj>mk0OoY[o[1onT_^`6ojJoj`OoZ<3[2?nW`>/6ojFok0goZ<3[2?nW_n/00onU`>coYKo/ojFok004
ojFok0KoYl7/0_nX`>/;ojO2k@;oYl7/1_nX`N/5ojS0j`koYko[0_nX`^`7ojW2k0?oZ<3[2onW_n/0
0onX`N_oZ/?/oj[3k004oj[3k0GoZL;/0_nX`N`6ojW3k0Co[<G/1?nac>h6ojo:kP03ojO0jonJ/>Oo
V[3W00GoV[3W1?n;WMl6ohZMh0OoUJWT00Co0000ojo6jon_a^_o[lK[1?nhd^d4okkIkPCo^]S_1_n_
bNd00onZa>coooooooooo`08ooooo`03o`000?oooooooooo00Kooooo000Cooooo`;o0000<Oooool6
oh^^k@03oj2ijon``NKo/<7V00Go/<7V00?oaLoRolS?goo8cml01Oo8cml3olW>gPKo_lkV0_ngbNP6
oj:ok@KoVKS^00?oX[c/oj>mk?nS_N`01?nS_N`7ojJoj`OoY;k/1_nV_n/7ojS0j`KoYl3[0_nW_n/6
ojFok0goZ<3[2?nW_n/7ojFok0?oYl7/0onV`>`9ojO2k@KoYl7/1_nX`N/00onX`>_oYko[ojNoj`0<
ojNoj`KoZ<;/1OnY`^`2ojO0j`coYko[00?oZ<7/oj[3k?nZ`n`01_nZ`n`00onY`^coZ<7/ojS1k004
ojS1k0KoZL?/00?o[<G/ok7<k_nac>h01Onac>h2ojo:kPGoYl3[1_nJ/>L5oh^Mg`KoRYgP1_nEZN@0
0ol0003o[lK[okSBk@06okSBk@03okkIk_njf>oo^]S_00Go^]S_0_n_bNd5oj[4k0Wooooo00?o0000
ooooooooool01_ooool000Go00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Sooooo00?o0000
ooooooooool0;oooool3oh^^k@?oT[;]1_n``NH3okc7h`Gob<oO1_o9c]h00onoc^Ko]lWXokO9j004
okO9j0KoX[o]0onI^>h3oi^ikPOoXkg/0onV_n/4ojJok0OoY;k/0onV_n/3ojNoj`OoZ<3[0_nW`>/6
ojNoj`KoYKo/3OnX`>/8ojNoj`GoYKo/0_nV_n/6ojK0k0KoYl;]00?oYl3[ojO1k?nW`N`01_nW`N`3
ojS1j`goYko[0onW`N`8ojS2k003ojW2k?nW`>_oYl3[00CoYl3[2?nW_n/5ojS1k0KoZ/?/00?oZL;/
ojS1k?nX`N`01_nX`N`3ojW3k0CoZlG]1Onac>h2ojo;kPKoYl3[1_nJ/>L6oh^Mg`KoRYgP1OnEZN@0
0onW_NWo0000ojNmj@05okSBk@;o_=[_1_njf>l00on`c>koZ/C/oj[4k006oj[4k0Sooooo00?o0000
ooooooooool01_ooool00005oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Wooooo00?o0000ooooooooool0;oooool6oi:bk@?o/<7V1_nlan<3olS?g`KobLkN0_o8
cMd7okO9j0?oX[o]0onM_>h6oi^ikPGoXkg/0onT_^`6ojJok0GoY;k/0_nS_^`6ojNoj`SoZ<3[1onW
_n/6ojFok0goZ<3[2?nW_n/00onU_ncoY[o[ojJoj`04ojJoj`KoY/3/0_nW`^d5ojO0j`KoYl7/3onW
_n/6ojO1k0KoZ<;/00?oZ<7/ojO0jonW`>/01_nW`>/6ojNoj`OoZ<7/0_nZ`n`5ojW2k0KoZ<7/00?o
ZL?/oj_5kOn[aNd01_n[aNd00onac>ko[l_^ojo;kP04ojo;kPKoYl3[1_nJ/>L6oh^Mg`KoRYgP00?o
UJWTojNmjOnW_NT00onW_NT00ol0003oYkgYokSBk@06okcJk`;o^]S_1On`c>h6oj[4k003ojO0jooo
oooooooo00Kooooo00?o0000ooooooooool01_ooool00004oooooonHV9So8B4Qonk^kPCooooo00Go
410@oooooooooooooooooa0@400:ooooo`03o`000?oooooooooo02oooooo1_nB/^d00on``NKo_<OS
okc7h`06okc7h`03olS?goo9c]kobLkN00CobLkN1?o8cMd5okO9j0;o/LGY1_nM_>h6oi^ikP03oj>m
k?nT_^coY;k/00GoY;k/1_nV_n`00onT_^coXkk/oj>nk004oj>nk0KoYko[2?nX`>/7ojNoj`KoYKo/
1OnX`>/2ojO1k0KoZ<3[1_nW_n/2ojRoj`OoY[o[0onV`>`3ojNoj`OoYl3[0_nW`N`CojNoj`KoYl7/
0_nX`^`5ojS1k0KoYl3[2?nW_n/5ojS1k0;oZLC/1onY`^`2ojS1k0GoZL?/1_n[aNd00on`cNoo[l_^
ojo;kP06ojo;kP?oYl3[0_nM/NH6ohjNgPKoRicN1_nAY>87ojNmj@03o`000?nlf^oo_=[_00Co_=[_
0_nkfo07ok3<kP;oZ/C/1OnW`>/7ooooo`03o`000?oooooooooo00Kooooo0002ooooo`03oiRHV?lQ
8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00000;ooooo`;o0000<?ooool3oi:bk@CoV[O/
1_nlan<3ol;:h0?obLkN1oo8cMd00ongbNSo/LGYok75j@04ok75j@KoWKc^0onK^Nh4oifkkPOoY;k/
0onV_n`3ojFok0OoXkk/0onW_n/3ojO0j`SoZ<3[1onW_n/6ojFok003ojS0jonW`NcoYl7/00CoYl7/
1_nX`>/2ojNoj`KoZ;o[1OnV_n/2ojRojPKoYko[1OnW`>/2ojRojQGoYko[0onW`N`3ojS2k0OoZ<7/
0_nW`>/<ojNoj`03ojS1k?nYa>coZLC/00CoZLC/1OnY`^`2ojS2k0OoZL?/0_n[aNd5ok3=k`Ko[l_^
00?oZ;o[oifai_nM/NH01?nM/NH6ohjNgPKoRicN1_nAY>84ojNmj@;o]<o^00?o0000okC?k_nlf^l0
0_nlf^l5ok_Kl0?o/<c^0on[a^d8ojO0j`Oooooo00?o0000ooooooooool01Oooool000?ooooo00?o
MgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool0
;_ooool7oiZgk0?o_<OS1_o2b^000oo9c]kob<gMolS=g@05olS=g@;oa/_M1onaaNT3oiflkPCoV[__
1_nM^nh5ojBnk0;oY;o/1_nU_n`5oj>nk0;oXko]1_nW`>/8ojS0j`OoYko[1_nU_n`7ojO1k0KoZ<3[
2?nX_n/00onV_n_oZ;oZojRojP04ojRojPKoYko[00?oYl3[ojRoj_nX_nX01?nX_nXCojNoj`SoZ<;/
1OnX`N`<ojNoj`?oZ<;/2?nYa>`00onY`^coZ<;/ojS2k004ojS2k0GoZL?/0_n[a^d7ok3=k`;o[l_^
1OnX_n/6oifaiPKoSYkN1On;W=h7oi6ThP03ojNmjOndcnko]<o^00?o]<o^00?o0000okC?k_nlf^l0
1Onkfo02ok;?k`KoZlK]1_nW`>/00onW_n_oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
0004ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`0<ooooo`03o`00
0?oooooooooo02kooooo1onJ]n`00onlan?o`/[Pol;:h004ol;:h0?oaL[N1Oo8cMd4olK;g@Go/LGY
0on]`nX6oiZkk`KoWK_^00?oY;k/ojBok?nT_n`01?nT_n`6ojFok003oj>nk?nS_ngoXko]00CoXko]
1_nW`>/8ojS0j`OoYko[1_nU_n`5ojO1k0;oY/7/1_nX`>/6ojRoj`03ojS0jonX_n[oZ;oZ00KoZ;oZ
0onW_n/:ojRojPooYko[3?nX`^`00onX`NcoYko[ojNoj`09ojNoj`;oYl3[1_nX`^`6ojW4k003ojW2
k?nX`^coZ<;/00KoZ<;/00?oZL?/oj_6kOn[a^d01?n[a^d5ok3=k`;o[/_^1_nX_n/7oifaiPKoSYkN
1On;W=h3oi6ThPCoXKOX1_ndcnh00ol0003o^][`ok_Kl002ok_Kl0Go//o_1_n[a^d2ojO0j`GoYko[
1_ooool00ol0003oooooooooo`05ooooo`0000Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL03oooool00ol0003oooooooooo`0^ooooo`GoV[O/0_nV_NX5ol;:h0Go
aL[N0oo8cMd6olK;g@03ok75jOn]`n[o[L?Z00Go[L?Z1_nJ^nl3oifkkP?oW[c^1onT_n`6ojFok0Oo
Xko]0onW`>/3ojO0k0SoZ<3[1onW_n/6ojFok003ojO1k?nV`NcoY/7/00CoY/7/1_nX`>/2ojRoj`Go
Z<3[1_nX_nX00onX`>_oZ;oZojRojP0:ojRojP;oZ<3[3?nW_n/00onW`^goZ<;/ojS2k009ojS2k0?o
Yl3[2?nW_n/6ojO0j`KoZ<;/0_nYa>`5ojW2k0KoZ<;/00?oZL?]oj_6kOn[a^d01_n[a^d00on`cNoo
[/_^ojk;kP04ojk;kPKoZ;o[0onM/NH3oi6Ng0KoSY_L1OnAX^08oj6gj0;o]<o^1?njf_000ol0003o
^][`ok_Kl007ok;?k`?oZlK]0_nX`>/8ojNoj`Gooooo00?o0000ooooooooool01Oooool00005oiRH
V?l@413o0000ob4Q8Oo<c<`00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^013ooooo0_l0000_oooo
o`03oiZgk?nV_N[oY[gZ00CoY[gZ0oo2b^07olG:gP03olS=gOo6bmgoa/_M00Coa/_M0oo3b=h7ojg3
jP?oV[__0onI^o06oijlkPGoY;o/2?nU_n`7oj>ok@KoYl3/2?nX`>/7ojNoj`KoYKo/1onV`N`3ojS0
j`?oZ<7/1onX`>/2ojRojPGoZ<3[2?nX_nX6ojS0j`SoYko[1OnW`^d6ojS2k003ojS0jonW`>_oYl3[
00GoYl3[1onW_n/7ojO0j`?oZ<;/1?nY`nd6ojW2k0;oZ<;/1OnY`nd6oj_6k@;o[lk`1on^bnh3ojRo
j`;oWZoS1onAW]`6ohjKg0GoTJ;P1_nQ]nP2ok7>k`Go^][`00?o0000ok[MlOnjgO401_nbcnl00on/
a^goZ<3[ojS0j`04ojS0j`KoYko[00?oZ<7/ooooooooool00oooool00ol0003oooooooooo`05oooo
o`007oooool00ol0003oooooooooo`0]ooooo`OoY[gZ00?o`/[PolG:g_o5b]h01Oo5b]h3olK9g0?o
a/_M1_o3b=h5ojg3jP;oZl7Z1_nI^o06oijlkP03ojBok?nU_ncoYKo/00[oYKo/1onS_nd6ojO0k0So
Z<3[1OnW_n/2ojO0j`KoYKo/1OnV`N`2ojG0k@KoZ<7/1OnX`>/2ojS1k0OoZ<3[1OnX_nX2ojS1k0Oo
Z<3[0onW_n/:ojO2k@;oZ<;/1OnX`>/7ojO0j`OoYko[1OnW`>/2ojW4k@OoZL?]0onY`^`3ojS2k0Oo
ZL?]0_n[a^d6ojo>l0?o[/_^0onW_NT6oij_h`KoTIkL1_n>Vm`6oi6Rh0?oXKOX1Onac^l2ok[Jl0?o
^]ga00?o0000ok[MlOnjgO400_nbcnl5ojc6k@KoZ<3[0_nW_n/5ojS1k0Cooooo00?o0000oooooooo
ool01Oooool0023ooooo00?o0000ooooooooool0;Oooool5ojJmjP?o/<7V1?o5b]h6olK9g003olK;
gOo3b=ko`lSN00Ko`lSN00?o[L?Zoj_1j_n[`NX01?n[`NX6oiVkl0?oW[c^0onO_Nh=ojFok0OoXko]
1onW`>`7ojS0j`03ojNojonW`>_oYl3[00CoYl3[1_nU_n`00onV`NcoYL3]ojG0k@04ojG0k@KoZ<7/
00?oZ<3[ojS1k?nX`N`01?nX`N`7ojS0j`03ojRoj_nX`NcoZ<7/00CoZ<7/1OnX`>/=ojO2k@;oZ<7/
1onX`>/3ojO0j`_oYko[00?oYl3[ojW4kOnYa>d01?nYa>d5ojW3k@SoZ<;/1OnY`nd3oj_8k`Go[lk`
00?o[LO]ojNmjOnW_NT01OnW_NT6oij_h`GoTIkL1_n>Vm`7oi6Rh003oj6gj?nac^oo/Lk_00?o/Lk_
0_nhf_45ok[Ml@03o`000?nbdO3o[<K]00Oo[<K]0onX`>/2ojNnj`SoZ<7/0oooool00ol0003ooooo
ooooo`05ooooo`008Oooool00ol0003oooooooooo`0]ooooo`03ojJmj_n``NKo/<7V00Ko/<7V00?o
aL[NolK9g?o6bM`01?o6bM`3olO8fPKo`lSN0_o1a]h7oj_1jP?oVK_`0onH^o06oinmkPGoYKo/0_nT
_n`6ojFok0OoXko]1onW`>`7ojS0j`OoYl3[0onU_n`3ojJok0OoYL3]0onX`N`3ojK1k@OoZ<7/0onX
`>/4ojO2k0OoZ<7/00?oZ<3[ojO2kOnW`^d02onW`^d6ojS1k0GoZ<3[3_nW_n/00onX`^goZLC]ojW4
k@06ojW4k@03ojW3kOnX`^coZ<;/00[oZ<;/00?oZL?]oj_8kon[b>l01On[b>l00on_c_3o[LO]ojg7
k@03ojg7k@KoYkgY1onN[n<5oi6Ng0KoSY_L0onAX^04oinei`?o/Lk_1Onhf_42ok[Ml@;o/]7`00?o
0000ok;Al?nbdO001_n/a^d00onX`N_oYkk[ojNnj`04ojNnj`OoZ<7/1?ooool00ol0003ooooooooo
o`04ooooo`008_ooool00ol0003oooooooooo`0^ooooo`Ko/<7V0_ng`n<5olK9g0GoalSJ0oo3b=h5
ol76gPGoZl7Z0_nY`>X6oiRkl0KoWkg^00?oYKo/ojBok?nT_n`01?nT_n`6ojFok0OoXko]1onW`>`7
ojS0j`GoYl3[0_nX`>/6ojJok0GoYL3]0_nV_n`6ojK1k@GoZ<7/0_nV`Nd7ojO2k0?oZ<7/3_nW`^d4
ojO1k0KoZ<7/00?oZ<3[ojNojonW_n/03?nW_n/5ojS2k@KoZLC]2onX`^`4ojW5k@KoZlS_00?o[/k`
ojg7kOn]and01On]and6ojNmj@?oWZoS0onCW=X5oi2KfPKoTj;O2?nO]NL00onac^oo^=[aokSJl@03
okSJl@03okWNl_nbdO3o/]7`00?o/]7`00?o0000ok;Al?nbdO000_n/a^d5ojS1j`KoYkk[1onX`N`3
ooooo`03o`000?oooooooooo00Cooooo000Sooooo`;o0000;oooool3ok31iPGo]l?S0oo6bM`7olO8
fP03ol?8g_o1a]ko`LKN00Go`LKN00?oZl7ZojW0j_nY`>X01?nY`>X6oiRkl0?oWkg^0onN_^l7ojBo
k0KoYKo/1onS_nd3ojO0k0CoY/3/1onX`>/00onW`>_oZ<3[ojS0j`04ojS0j`KoY[o/00?oYL3]ojJo
k?nV_n`01?nV_n`6ojK1k@03ojS1k?nV`NgoY/7]00CoY/7]1OnW`^`2ojK1k0coYl;]00?oYl3/ojO1
k?nW`N`01_nW`N`3ojS1k0goYko[1?nW`N`6ojS2k@;oZLC]2_nX`^`2ojS3k@OoZLG]0_n[b>l5ojk>
l0Go[LO]00?oYKSVoibYgonLZMl01?nLZMl7oi>LfPGoT9_J1_nCX]l6oinei`;o/<o`0onhf_44okWN
lPGo/]7`00?o0000ojc7kOnX`N/01onX`N/3ojNnj`;oZ<;/2?nX`N`2ooooo`03o`000?oooooooooo
00Cooooo000Uooooo`03o`000?oooooooooo02gooooo00?o/<7VokO3hong`n<01Ong`n<00oo6bMco
alSJolO8fP05olO8fP;oalKI1_o1a]h2oko4gPOoZL3Z0onH^o03oiRll@KoW[k_1OnT_n`2ojBok@Ko
YKo/1OnS_nd2ojBok@OoY/3/3_nX`>/3ojJok0?oYko[1onV_n`3ojK1k@?oY[o/1onV`Nd00onW`^co
Y/7/ojK1k004ojK1k0SoYl;]1OnW`>`6ojO1k0goYko[2OnW`N`3ojS2k@?oZL?]2?nX`^`6ojS3k@Go
ZLG]0_n/cO47ojk>l003ojg7kOnU^>KoYKSV00?oYKSV1_nLZMl6oi>LfPKoT9_J1_nCX]l2oinei`Ko
/<o`00?o^=[aokWNl_nig_801?nig_82ok;Al0?o[<O]00?o0000ojc7kOnX`N/01OnX`N/00onV_n_o
Z<;/ojS2k004ojS2k0KoZ<7/00CoYl3[oooooooooooo00001_ooool002Kooooo00?o0000oooooooo
ool0;Oooool6okO3h`;o^lCQ1_o7b=X4olO6f@?o`LKN1Onoa=h5ojW0jP;oZKoZ1_nH_?46oijnk`03
ojBok?nT_ngoY;o]00CoY;o]1_nU_n`00onS_ngoY;o]ojBok@04ojBok@OoY/3/3_nX`>/6ojNoj`Go
Y[o/0_nW_n/6ojJok0GoY/7]0_nV_n`7ojK1k0?oYl;]0onW`>/7ojO0k0;oYl7/3OnW_n/;ojO1k003
ojS4kOnY`ngoZL?]00GoZL?]1onX`^`7ojS3k@03ojW5kOn/cO7o[<ga00Co[<ga1On^c_000onZ`N_o
YKSVojFhiP05ojFhiPGoW:WO1_nCW=X7oi2KfP?oTj;O0_nQ]nP7ok3?l0;o]mcc1Onig_83ok7@l0?o
[<O]00?o0000ojc7kOn/and00_nX`N/5ojJoj`KoZ<;/0_nX`N`5ojO0j`03ooooool0003ooooo00Go
oooo000Wooooo`03o`000?oooooooooo02gooooo0ong`n<5ok_4h@?oalSJ1oo7a]T00oo1a]ko_lCN
oko4gP05oko4gP03ojW0j_nY_n[oZKoZ00CoZKoZ1_nH_?43oijnk`?oWKo`1onT_nd3ojFok0?oY/3/
1onT_nd3ojK0k0CoYL3]3_nX`>/6ojNoj`03ojJok?nW_n_oYko[00CoYko[1_nV_n`00onV`NgoY[o/
ojJok004ojJok0GoY/7/0_nW_n/6ojO0j`GoYl3/3?nW_n/3ojO0j`WoYl7/1OnXa>d7ojW3k@OoZ<;/
1OnX`nd2ojW8l0Oo[<ga00?o[/k`oj[1jonZ`N/00onZ`N/7ojFhiPGoW:WO1_nCW=X3oi2KfP?oUZ?N
1_nQ]nP4ok3?l0Go]mcc00?o^Mkbok7@l?nad?001Onad?03ojc7k@03o`000?nX`>_oY[o[00OoY[o[
0onX`^`4ojS1k0KoYl3[00?o0000ooooooooool01?ooool002Sooooo0_l0000^ooooo`03okO3honk
a>7o^lCQ00Go^lCQ00?oalSJolO6fOo7a]T01Oo7a]T2olO5f0Ko_lCN0_no`]d7ojVojPKoV;ca1_nM
_o05ojBok@;oY<3]1_nV`>`7ojBok@OoYL3]1OnX`>/2ojO1k0OoZ<3[0onW_n/3ojS0j`OoYko[0onV
_n`4ojNoj`KoY[o/00?oY/7/ojNojonW_n/01?nW_n/6ojO0j`03ojO0k?nW_n_oYko[00WoYko[2?nW
`>/6ojO1k003ojS4k_nXa>goZ<C]00GoZ<C]0onY`nd;ojS2k003ojS3kOnYb?3oZLS`00CoZLS`0on/
cO44ojc9k`KoZ/7[0onU^>H3oiVQfPGoU9_H1_nCW=X7oiJSgPKoXKOX00?o/<o`okOLlongg?<01?ng
g?<2okONl`Ko/M3`00?oZlK]ojS0jonX`>/00_nX`>/00ol0003oZ<3[ojJoj`05ojJoj`03ojS2k?nX
`NcoZ<7/00KoZ<7/0onW`>/2ooooo`03o`000?oooooooooo00Cooooo000Zooooo`03o`000?oooooo
oooo02cooooo1_nka>43okk4g`GoalKI1?o7aMP3oko4gPGo_l;M1OnY_nX2oj^oj0KoV;ca1_nM_o00
0onT_ngoY<3]ojC0k@04ojC0k@KoY/3/1onT_nd7ojG0k@03ojS0jonW`NcoYl7/00CoYl7/1OnX`>/2
ojS1k0KoZ<3[1OnW_n/2ojRoj`OoYko[0onV_n`:ojNoj`?oYl3[2onW_n/<ojO0j`;oYl7/1OnXa>h5
ojS4k@coZ<;/1?nXaNh5ojW8l0;o[<ka1on/bNl3oj[1j`;oXZgO1onIXMX5oiBKf0KoTicJ1_nFXmh5
oj6gj0Co/=;b00?o]mccokONlongg_<01?ngg_<2ok7@l0GoZlK]1?nX`>/01?l0003oZ<3[ojJojonV
_n/5ojS2k0KoZ<7/1oooool00ol0003oooooooooo`03ooooo`00:oooool00ol0003oooooooooo`0/
ooooo`?o^lCQ1_nna=l3olO6f@KoalGH00?o_lCNoko2gOno`]d01Ono`]d00onY_n[oZkoXoj^oj004
oj^oj0KoV;ca0onM_o04oibol@KoY<3]1onV`>`6ojBok@?oYL3]1OnT`>d6ojO1k003ojS0jonX`Nco
Z<7/00CoZ<7/1_nX`>/00onW_n_oZ;o[ojRoj`04ojRoj`GoYko[0_nX`>/;ojNoj`;oZ;o[2onW_n/2
ojO1k0[oYl3[1?nW`nh6ojS4kP03ojS4kOnX`^coZ<;/00WoZ<;/0_nXa>h7ojS5kP03ojW8l?n/c_7o
[<ka00Co[<ka1On/bNl00onV^>KoXZgOoj:]g`04oj:]g`KoVJ7J1_nDVmP5oi>LfPOoUZ?N00?oXKOX
ok3Bl_n`d_801?n`d_82okKNm0Go]mkc00?o[lg`oj_6kOn[a^d01_n[a^d3ojS0j`03o`000?nW_n_o
Z<;/00OoZ<;/0_nX`N`:ooooo`03o`000?oooooooooo00?ooooo000/ooooo`03o`000?oooooooooo
02cooooo00?o^lCQokk4gonna=l01_nna=l00oo7a]WoalGHolO5f004olO5f0;oa/?G1_no`]d3oko0
f`KoZkoX0onH_?44oiZll0KoW;oa0onT`>d3oj?0kPOoY/3/0onT_nd3ojG0k0SoY<3]0onW`N`3ojG1
k@OoZ<7/0onX`>/3ojS1k0OoZ;o[00?oYko[ojS0jonX`>/01?nX`>/7ojNoj`KoZ;o[1onW_n/6ojO1
k0GoYl3[2OnW`nh3ojS4kP_oZ<;/1_nXa>h5ojS5kP03oj_>lon/c_7o[<ka00Ko[<ka00?o[<W_ojJh
i_nV^>H00onV^>H6oj:]g`GoVJ7J1_nDVmP6oi>LfP?oUZ?N1?nT_^`4ok3BlPGo]]kd00?o]mkcojo=
l?n_cO000on_cO06oj_6k@GoYko[00?o0000ojNojonX`^`01OnX`^`=ooooo`03o`000?oooooooooo
00?ooooo000]ooooo`;o0000;_ooool6okk4g`?o_lCN0oo7aMP5olK3e`?o_l;M1_no`=/4oj^oj0?o
[KkV1onJ_?02oibol@CoVKob1OnS`>h5ojK0k0;oYL7]1_nU`>`6ojC0k@03ojBokOnU`NgoYL7]00Go
YL7]1OnX`N`00onV`^goZ<7/ojS1k005ojS1k0GoZ;o[00?oZ<7/ojS0jonX`>/01_nX`>/3ojNoj`;o
Z<3[2?nX_n/3ojNoj`[oYl7/00?oYl3[ojO3k_nW`nh02OnW`nh=ojS2k003ojS3kOnXa>koZ<C^00Ko
Z<C^00?oZ<G^oj_>lon[c_<00on[c_<6ojc>l@03ojVoj_nV^>KoY[SV00CoY[SV1_nR[Ml6oiVQfPKo
U9_H0onCW=X3oiVXh@OoY;k/00?o/=;bokKNm?nfg_@01?nfg_@00onffo?o[lg`ojo=l005ojo=l0;o
ZlK]2OnW_n/01?l0003oYko[ojS2k?nX`^`@ooooo`03o`000?oooooooooo00?ooooo000_ooooo`03
o`000?oooooooooo02cooooo0onna=l6oko4gP03olO5f?o6`mOoa/?G00Goa/?G00?o_l;Moko0fono
`=/01_no`=/00on[_nSo[KkVojfniP04ojfniPGoV[c`0_nM_>h6oiVolPGoXl3^00?oY/3/ojG1kOnU
`Nd01?nU`Nd6ojG0k0;oY<3]1OnT_nd7ojG1k@03ojS1k?nV`^goY/;]00?oY/;]1onX`N`00onX_n_o
Z<7/ojS1k003ojS1k0KoZ<3[00?oYl;]ojS0jonX`>/01?nX`>/6ojRoj`03ojO2kOnW`NcoYl7/00Wo
Yl7/2onW`nh=ojS2k0GoZ<?]1_nXa>h2ojS<lPKoZlkc0_n/c_45ojVojPKoY[SV1_nR[Ml3oiVQfP;o
UYcG1_nFWmX7oiVXh@GoY;k/0_n`eo@4okKNm0Co]]_c1On_cO000onZa>goYko[ojNoj`09ojNoj`03
o`000?oooooooooo017ooooo00?o0000ooooooooool00oooool0033ooooo00?o0000ooooooooool0
;?ooool00onna=oo_lCNoko4gP06oko4gPKoa/?G0oo5`]L6oko0f`;o`;kH1on]_^H00onJ_?3oWKc^
oiflkP04oiflkPKoVKob0_nS`>h4oj72l0KoYL7]0onU`>`3ojK1k@OoY;o]0onU`Nd3ojC0k@OoY/;]
0onX`N`4ojK2k@KoZ<7/0_nX`>/5ojO2k@KoZ<3[0_nX_n/5ojO2k@KoYl7/00?oY/?^ojO3k_nW`nh0
2_nW`nh00onW`^goZ<;/ojS2k008ojS2k0CoYl?]1_nX`nd2ojS4kPKoZ<cb0on[c_<4oj_6k@KoZKoZ
0onV^>H2oifQe`KoVIcF1_nFW=L6oiJOfPOoVJSQ00?oY;k/ok3Gm?n`eo@01?n`eo@00onfg_Co]]_c
okKKl`05okKKl`03ojo=l?nZa>goZ/C]00?oZ/C]1_nW_n/5ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool00oooool0037ooooo00?o0000ooooooooool0;Oooool8oko4gP?oa/?G1_o5
`]L3oko0f`Go`;kH1On]_^H3ok2khPKoWKc^0onI_o83oiNnl`KoXL;`1?nU`Nd2ojC1kPKoY/7]1OnT
_nd2ojG0k@KoY<3]1OnV`^d2ojC1kPOoY/;]0onX`N`3ojK2kPOoYl;]0onX`>/4ojO3kPKoYl;]0_nW
`N`5ojK3kPSoYl?^1OnW`^d5ojS2k0;oYl;]1onW`nd3ojS3k@CoYl[b1OnXc?82oj[9l0OoZlK]0onY
_nX2oj>Yf`KoWJ7G1_nIW=H6oiJLe`GoUYoJ1_nIZ>42ojW9l0Go/=Od0ondh?H3okKKl`Co[L[_1_nZ
a>d2ojNoj`Wooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`03ooooo`00<_ooool2
o`0002kooooo2?noa=h00oo6`mOoaL;GolG2e`06olG2e`03oko0foo0_]So`;kH00Go`;kH00?o[KkV
ok2kh_n`^n801On`^n83oiflkP?oX[c/1_nG__<6oj72l003ojG1kOnT`NkoY<7^00?oY<7^1_nV`Nd0
0onT_ngoYL3]ojG0k@04ojG0k@KoY<3]00?oY/;]ojC1k_nT`Nh01?nT`Nh5ojK2k@;oYL7]1_nV`^h5
ojO2k@;oYL;^1onW`nh3ojO2k@?oY/;^1onV`nh3ojO3kPCoYl7]1_nW`^d00onX`^coYl;]ojO2k@04
ojO2k@GoYl?]0_nWb?47ojO:lP03ojS<l_nZbO3oZ/W`00CoZ/W`1On[a^d00onV/N3oXjWKoj>Yf`04
oj>Yf`KoWJ7G1OnIW=H6oiJLe`KoUYoJ0_nIZ>46ojW9l003ok3Gm?ndh?Ko]>3f00?o]>3f0_nbeO87
ojg:k`?oZ/C]3_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo000doooo
o`03o`000?oooooooooo02cooooo1_noa=h2okk4g`OoaL;G0_o4`=H6ol2nf0;o`[gF1_n`^n82okBj
g@KoX[c/1_nG__<3oj72l0CoWL?b1OnT`Nh3ojK1k@CoYL7]1_nU`>d3ojC0k@CoYL3]1_nT`Nh00onV
`^goYL7]ojG1k@04ojG1k@KoY/;^00?oYl;]ojG2k_nU`^h01?nU`^h5ojO3kP;oY/7]1_nV`^h5ojK3
kP;oYl7/1onW`Nd=ojO2k@03ojO3kOnWb?7oYlSa00CoYlSa1OnWb_82ojW<lPOoZ/W`00?oZlK]ojJa
h?nV/N000onV/N06oj>Yf`GoWJ7G1_nIW=H6oiJLe`?oUYoJ1?nN/nL5ojW9l0;o/Mcf0ondh?H5ok;E
lPGo[L[_4_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo000eooooo`03
o`000?oooooooooo02cooooo0onoa=h5okk4g`CoaL;G1Oo4`=H3ol2nf0Go`[gF0on`^n85okBjg@Ko
X[c/0onG__<4oiVml@KoWL?b0_nT`Nh3oj;4l@OoYL7]0onU`>d3ojK1k@OoYL3]0onT`Nh3ojG0k@Oo
YL7]0onV`^h4ojG1k@KoYL;^00?oYl?^ojK1kOnV`Nd01?nV`Nd6ojK2kP03ojK3k_nW`NcoYl7/00Co
Yl7/1OnW`Nd2ojO3k@[oYl;]0onWao47ojO8l@03ojO:l_nYc?;oZLcb00CoZLcb0onZbO03ojNhi@Ko
Y[7P1_nSZM/6oifQe`?oVIcF0_nIWmP6oiZUg@SoW[?W00?oZLW`ok7Lm_nag?H01?nag?H00ondh?Ko
/]Gbok;ElP05ok;ElP03ojg:kooooooooooo01Cooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`02ooooo`00=_ooool00ol0003oooooooooo`0/ooooo`03oko4g_nna=oo_/CO00Go_/CO
00?oaL;GolC0e_o4`=H01_o4`=H00oo0_]So`[gFol:meP05ol:meP03ok2kh_nd^]go];[M00Go];[M
0onR_>`4ojRki`KoVKga0onM`o82oiS1l`KoX/Ca1OnU`Nd2ojC2k`KoY/7]1OnU`>d2ojK1k@KoYL3]
1OnU`Nd2ojK1k@OoYL7]0onU`^h:ojK1k@?oY/;^2_nW`N`00onW`NgoYl?]ojO3k@04ojO3k@GoYl;]
00?oY/OaojO7lOnWao401OnWao43ojO8l@CoZ<gc1OnYc?800onX^nOoYkSUojNhi@05ojNhi@GoY[7P
1onSZM/3oifQe`;oVYgE1_nIWmP6oiZUg@KoW[?W0_n/do@5ok7LmP;o/]of1_nbeO8Iooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool00_ooool003Oooooo0_l0000^ooooo`Go_/CO0_nk
a>47olC0eP;o`koG1_o2_MH2ol:le0Ko];[M0_nj^=P7ojRki`?oVKga0onO_>d5oiS1l`KoX/Ca00?o
YL7]ojC2konT`^l01?nT`^l6ojK1k@03ojG0kOnV`NgoY/7]00CoY/7]1_nU`>d00onU`NgoY/7]ojK1
k@04ojK1k@GoYL7]3OnV`Nd2ojO2k@[oYl7/0onW`nh7ojO3k@03ojO2kOnVao7oY/Oa00?oY/Oa1OnW
ao43ojK=m0KoZ<gc00?oZLcbojRkionX^nL00onX^nL7ojNhi@GoY[7P0onSZM/3oibMe0KoVYgE1_nI
WmP6oiZUg@;oW[?W1_n/do@00onag?Ko/]ofok;OmP04ok;OmP;o/]Gb7Oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00;ooooo000iooooo`03o`000?oooooooooo02cooooo0onna=l4
ok_4h@Goa<3F1?o3_mL3ol:mePGo`[cD0ond^]d5okZhf0GoZ;_W0_n^]ml6oinlk@GoV<7c0onRa?44
oig4m0KoY<;_0onV`Nd4ojG3k`KoY/7]0onU`>d4ojK2k@KoY/7]00?oYL7]ojK1kOnV`Nd02onV`Nd6
ojO2k@GoYl7/00?oY/?^ojO3k_nW`nh01OnW`nh3ojO3k@CoY/Sa1_nVao400onWao7oY/gdojK=m005
ojK=m0?oZ<gc0onX_NP6ojRki`GoYkSU00?oXJ7DoijNdonNW]<00onNW]<7oibMe0GoVYgE1_nIWmP5
oiZUg@;oY/K`1_n/do@3ok3Qn0?o/]of8Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00;ooooo000jooooo`03o`000?oooooooooo02cooooo00?o_/COok_4hOnka>401?nka>43olC0
ePKo`koG00?o`[gFol:le?o2_=@01Oo2_=@00ond^]go^[SHokZhf005okZhf003ojRkion^]moo[[OO
00Co[[OO1_nO_>d2oiS1l`CoVKka1_nMa?@3ojC2k`?oXLOc1onU`nl3ojK1k@?oYL?_1onV`^d3ojK1
k@CoY/;^2OnV`Nd3ojK2k@OoYl;]00?oYl7/ojK3k_nV`nh00onV`nh5ojO3kP;oYLWb1onVb?43ojK7
l@CoYLgd1OnVcO@00onX_^WoZ;gXojRmj005ojRmj0KoZ;_W00?oYkSUoj6Qe?nQXM@00onQXM@5oijN
d`KoW9gD1OnJWMD7oiVOf003oiZUgOnVa_3oY/K`00CoY/K`0_n/do@5ok3Qn2Kooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`02ooooo`00>oooool00ol0003oooooooooo`0/ooooo`Oo
^lCQ00?oa<3Fol>oeoo3_mL01?o3_mL00oo2_mSo`[cDol:le005ol:le003ol:kdonj^=So^[SH00Go
^[SH00?o_[SCojjggon^]ml01_n^]ml3oinlk@CoYk[W1OnI__43oig4m0?oV<7d1_nQao<5ojG3k`;o
XLOc1_nU`nl5ojK2k@;oYLC_1onV`^h3ojK1k@;oY/C_1onV`^d3ojO2k@CoY/C_1_nV`nh00onW`nko
YLWbojG9lP04ojG9lPGoY/Sa0onTc?@6ojG=m003ojK=m?nX_^WoZ;kY00?oZ;kY1onX_NP3ojRki`;o
Y:GF1_nQXM@6oijNd`GoW9gD1_nJWMD3oiVOf0CoW[CW1OnVa_03ojgLn0?o/>7h:Oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo007ooooo000looooo`03o`000?oooooooooo02cooooo
1Onka>42okO5i@Go`koG0oo2_mP5ol:le0?o`[_C1Onj^=P3okjhd`Ko[[OO0_ne]=P7ojNji`;oVKka
0onQ^n/6oiS1m0KoXLOc00?oYL?_oj77lonQao<01?nQao<6ojG3k`03ojK2kOnUa>ooYLC_00CoYLC_
1OnV`^h00onTa_7oY/C_ojK4k`04ojK4k`GoY/;]0_nUao47ojK4k`?oY/?^1?nTbo@6ojG9lP03ojK8
lOnTc?CoY<cd00GoY<cd0onUcO@2ojRnjPOoZ;kY0onX_NP3ojJWe`KoY:GF1OnQXM@7oijNd`GoW9gD
0onJWMD3oifYgPOoW[CW00?oY/K`ojgLn?n]g?P01On]g?P00on`hOSoooooooooo`0Yooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool00Oooool003gooooo0_l0000]ooooo`03ok_4hOng
aNGo]lGU00Co]lGU0oo3_mL5ol:of0?o`[cD1Oo2^m<3okZhf0Go_[SC0on^]ml5okFdf0GoYk[W00?o
[[?Loj6kjonQ^n/01?nQ^n/6oiS1m0?oXLOc1?nJ`o@6oj77l`?oYL?_1?nRb?@6ojG4k`03ojK2k_nT
a_7oY<Ka00?oY<Ka1_nVa>l00onV`^goYLOaojG7l@04ojG7l@GoY/C_0onSc?D6ojC;m0?oYLWb1?nS
b_@5ojC<m003ojNmjOnX_^[oZ;kZ00CoZ;kZ1OnX_^T00onVZ=SoYZOGojJWe`05ojJWe`GoY:GF1_nQ
XM@3oijNd`?oWZ3F1OnMXmT7oifYgPGoW[CW0_nYeOL6ojgLn2gooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`01ooooo`00?oooool00ol0003oooooooooo`0[ooooo`Oo]lGU00?o`koG
ol:of?o2_mP01Oo2_mP00oo2_=Co`[_Col:kd`05ol:kd`03okZhf?nn^=?o_[SC00Go_[SC00?o[[OO
okFdf?ne]=P01One]=P00onW^^Oo[[?Lojjcg003ojjcg0KoXK_[0onH`O@4oijlkPKoV/?d0onQao<4
oi_5m@KoX/Sd0onUa>l3oj7:m@KoY<Ka0onVa>l4oj?:m0KoYLOa00?oY/C_oj?<mOnSc?D01OnSc?D3
ojC;m0?oXlOc1onSb_@00onTc?CoYkgYojNmj@03ojNmj@KoZ;kZ00?oZ;kYojJXf?nVZ=P00onVZ=P6
ojJWe`KoY:GF0onQXM@2oinOe0OoWZ3F1OnMXmT7oifYgP03oijdionYeOOoZMGg00CoZMGg0_n]g?Pa
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00Oooool0043ooooo00?o0000oooo
ooooool0:oooool5okO5i@;o/<GZ1_o2_mP2oko1f`Ko`[_C0_o2^m@6okjhd`;o`;SB1_ne]=P00onk
]=;o[[?Lojjcg005ojjcg0?oXK_[1?nZ]N46oijlkP?oV/?d1?nN_Nh6oi_5m@?oX/Sd0onKa?@6oj7:
m@?oY<Ka1?nNbOH6oj?:m0?oYLOa1?nPb_H5oj?<m@03oj?3l?nSao?oXlOc00GoXlOc0onSb_@3ojNk
i`OoYkgY0onX_^X2ojNXf0OoYZSH1_nVYmL3ojBUeP;oXIoB1_nOWm@6oijPePKoWJ?I0onMZMh4ojO<
l`GoZMGg=Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo007ooooo0011ooooo`03
o`000?oooooooooo02_ooooo00?o]lGUok35j_n`aNX01?n`aNX3ol:of0Go_l7K0oo2^m<5ol:ke0?o
_[SC1Oo0^=83okFdf0Co^kCB1On^/m`00onf/MCoZ[GQojZeh@06ojZeh@?oW[c^0onX]^<7oijmkP?o
VlGe1?nO_Nh5oi_4m0?oXL[e1?nM`o86oik9mP?oXl[d1?nOaO<6oj3:mP03oj?<mOnS`o3oXl?`00?o
Xl?`1OnSao<2ojNhi@KoYk_W1OnW_NT00onWZ=OoYjSHojNXf004ojNXf0KoYZSH1OnVYmL00onSWm7o
XIoBoj6OdP04oj6OdPKoWioD1OnNX=H5oifSf@;oXl3^1onWc?<00onYeOOoooooooooo`0fooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool00Oooool004;ooooo0_l0000]ooooo`Ko/<GZ
00?o`[oHoko1fono`M/01Ono`M/00oo2^m?o`[_Dol:ke005ol:ke003okjhdoo0^=;o`;SB00Go`;SB
00?o]KCHok^dd_nk]=801?nk]=83ojjcg0?o][7D1_nZ]N400ona[mKoZ;KSojRfh`05ojRfh`GoW[g^
0_nX]^<7oinmkP;oVlCd0onR^n/7oig3lP?oW/Wf1?nQ_nh6oio5l`?oX<[f0onT_^`6oj?3l003oj?7
lonW^>GoYkSU00CoYkSU1_nW^nL00onW_NWoYjSGojNXe`03ojNXe`KoYjSH1_nVZ=P00onVYmOoXioA
oj>Od@03oj>Od@KoXIoB1OnOWm@6oijPeP03oifSfOnS`>koXl3^00CoXl3^1OnWc?<kooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool00Oooool004Cooooo00?o0000ooooooooool0:ooo
ool3ok35jP?oYLG`1_no`M/2ok_5hPKo`[_D00?o`;gGol2hd_o0^=801Oo0^=800oo0^M?o^kCBok^d
dP06ok^ddP03ojjcg?nf/MCo][7D00?o][7D0onZ]N44ok6_ePOoZ;KS00?oW[g^ojRfhonX]^<01?nX
]^<5oinmkP03ojRch?nR^n_oX[_[00CoX[_[1OnM`o82ojJhiPOoXKo^0onOaO<2ojJhiPOoY;k/0onS
`o03ojRbg`OoYkSU0onW^nL2ojRVe0OoYjSG1_nWZ=P3ojJXf0;oY:3A1onSWm45oj6OdPKoWioD0onN
X=H4oj6fi`KoXl3^00?oYlccooooooooool0?Oooool00ol0003oooooooooo`07ooooo`7o00000Ooo
ool1ooooo`00AOooool00ol0003oooooooooo`0[ooooo`KoYLG`0ono`M/5ok_5hP?o`[_D1?o0_ML5
ol2hdP?o`;WC1_nk]=800onn]M7o][7DokJae005okJae003ojZehOna[mKo/JoF00Co/JoF1OnX]^<2
ojn]ePOoZ;KS00?oWkg^ojRch?nX/n000onX/n06oj:kj`03oig3l_nV^>KoY[SV00CoY[SV1OnQ_nh0
0onY/=goY[SVojJhiP04ojJhiPGoY;k/00?oZJcIojRbgonX/]l01OnX/]l5ojNhi@03ojRTd_nXY]Co
Z:KD00CoZ:KD1onWZ=L3ojNXf0;oYZ7@1_nTX=46oj>Od@KoXIoB0onOWm@2oj:_h@SoXKKW0onS`>i3
ooooo`03o`000?oooooooooo00Kooooo0Ol00001ooooo`7ooooo0016ooooo`03o`000?oooooooooo
02_ooooo1_nUaO000ono`M_o^lGRok_5hP05ok_5hP03ol:ke?o0_MOo`;gG00Co`;gG0oo0^=85ol2i
d`?o^kCB1?nn]M45okJae003ok^bd?na[mKo/JoF00Ko/JoF00?oZ;KSojn]e_n_[MH01?n_[MH5ojRf
h`03ojj[e?nX/n3oZ;?P00GoZ;?P0onR^n/3ojZ^f`OoY[SV00?oXKo^ojV`gOnY/=d00onY/=d6ojJh
iP03ojBnk?nY[=WoZJcI00?oZJcI1onX/]l00onW^>GoZ:CBojRTdP03ojRTdPKoZ:KD1OnWZ=L00onW
XM3oYZ7@ojJQd004ojJQd0GoY:3A1onSWm43oj6OdP;oXj_M1_nR[n46oj6fidOooooo00?o0000oooo
ooooool01_ooool1o`00007ooooo0Oooool004Oooooo0_l0000/ooooo`?oYLG`1?nFa?H5ok_5hP03
ok37joo0_MOo`;gG00Ko`;gG00?o`;SBol2idoo0^M<01Oo0^M<00onk]=;o_[GAokjed@03okjed@?o
][7D1?nk/]06ok6_eP03okV_d?n_[MKo[jgF00Ko[jgF00?oZ;KSojj[e?n^Zm@00on^Zm@5ojRch003
ojnYd_nZ[]_oZZkK00GoZZkK1OnV^>H00on[ZMCoZK3MojV`g@05ojV`g@?oY[SV0_nZYm<7ojV/f@Go
Z;;O00?oZjC@ojRTd_nXY=801OnXY=86ojRVe003ojNXeonWXM3oYj7@00?oYj7@1OnVXM06ojBPd@?o
XioA0onTZMX6oj>[g@KoXZoQ0_nQ]^M;ooooo`03o`000?oooooooooo00Gooooo0Ol00001ooooo`7o
oooo0019ooooo`03o`000?oooooooooo02_ooooo1_nFa?H00onkaN;o/<O[ok37j`03ok37j`Ko`;gG
0_nma>06ol2id`03okjlf?nn]M7o_[GA00Go_[GA00?o][7Dok^bd?nk/]001?nk/]03ok6_ePCo^Jo@
1_n_[MH00ong[/oo[Z_Dojj[e005ojj[e003ojRch?n_ZM;o[jWB00?o[jWB1onZ[]/00onV^>KoZjWD
oj^Ye003oj^Ye0GoZK3M00?o[ZK@ojZWdonZYm<01?nZYm<7ojV/f@03ojRbgon[Y=3oZjC@00?oZjC@
1_nXY=85ojRVe003ojVSd?nWXM3oYj7@00CoYj7@1OnVXM05ojBPd@03ojFXf?nTZM[oY:WJ00GoY:WJ
1OnSZmd5oj:_hDoooooo00?o0000ooooooooool01?ooool1o`00007ooooo0Oooool004[ooooo00?o
0000ooooooooool0:oooool3oiK4mP?oR<;j1_n`an/3ol2me`Go_LCP0oo0^M<4okjlf0Go_[GA00?o
_[SDok^bd?nk/]001_nk/]000ona[mKo^Jo@okV_d004okV_d0?o[jgF1?ng[/l5ojj[e003okJ/con_
ZM;o[jWB00Go[jWB1OnZ[]/00onaZ=3oZjWDoj^Ye004oj^Ye0?oZK3M1?n^Y]06ojZWd`GoZJcI00?o
[JC?oj^Td?n[Y=001On[Y=06ojRTdP03ojRVe?nYXm3oZJ?@00?oZJ?@1OnWXM06ojJQd003ojBPdOnU
Z=SoYJSH00?oYJSH1_nTZMX6oj>[g@03oj:_hOoooooooooo057ooooo00?o0000ooooooooool00ooo
ool1o`00007ooooo0Oooool004_ooooo00?o0000ooooooooool0;?ooool5ohS2nPKo/<O[00?o`;gG
okg4h?nma>001Onma>000oo0^M?o_[cHokjlf004okjlf0?o_[GA0onn^=@6ok^bd003okbed_ni[m3o
^Jo@00Ko^Jo@00?o[jgFokN^cong[/l00ong[/l3ojj[e0Co]Zc?1on_ZM800onZ[]_o/JS@ok6Xd003
ok6Xd0KoZjWD00?oZK3MojjVd?n^Y]001?n^Y]06ojZWd`03ojV/fOn]Y<oo[JC?00?o[JC?1on[Y=03
ojRTdP;oZjC@1_nYXm06ojNQd0?oYZ7@0_nWZMP7ojFXf0KoY:WJ0onSZmeFooooo`03o`000?oooooo
oooo00?ooooo0Ol00001ooooo`7ooooo001<ooooo`;o0000;Oooool5ohS2nP?o/<O[1?nMaoD5okg4
h0;o/LW/1onn_=P00onn]M7o_[SDokjhe003okjhe0?o^k;@1?nl]M86okV_d003ok^cdOng[/oo]jk?
00Go]jk?00?o[Z_DokJ/conf[<l01?nf[<l5ojnYdP03okF/conaZ=3o/JS@00Go/JS@1?n[ZM@00onb
Z<oo[ZK@ojjVd005ojjVd0GoZZOC00?o[jK?ojfTcon]Y<l01On]Y<l5oj^Td003ojfWdOn[Y=3oZjC@
00CoZjC@1OnYXm05ojNQd003ojR[fOnWZMSoYjWH00CoYjWH1onUZ=P3ojBYfUcooooo00?o0000oooo
ooooool00oooool1o`00007ooooo001>ooooo`03o`000?oooooooooo02cooooo1Oml_o`6oig7m@03
okg4h?nabNco/LW/00Co/LW/1Onn_=P00onjanCo_[SDokjhe005okjhe003ok^bd?nl]M;o_;GB00Co
_;GB0oni[m04ok^cd@Go]jk?00?o^K7BokJ/conf[<l01Onf[<l3ojnYdPCo]Jc?1onaZ=000on[ZMCo
/ZS?ok:Xc`02ok:Xc`Oo[ZK@00?oZZOCojnVcon_Y/l00on_Y/l7ojfTc`03oj^Td?n]Ym7o[JOA00?o
[JOA1On[Y=06ojVSd003ojNQd?nXZmWoZ:_I00?oZ:_I1_nWZMP5ojFXf67ooooo00?o0000oooooooo
ool00_ooool1o`00007ooooo001?ooooo`03o`000?oooooooooo02cooooo1Oml_o`3oig7m@CoRlKk
1_nabN`00onn_=So^/OTok[7i003ok[7i0Go_[SD0_nl`]h7okbedP03okV_d?nk/m7o^k?A00Co^k?A
0ong[/l3okVadPOo]Zc?00?o[jWBokF/cone[<l01?ne[<l5ok6Xd003okB/dOnbZ<oo/ZS?00Co/ZS?
1On^Y]000onaZ]7o[jK?ojnVc`05ojnVc`Go[JC?00?o[Z[CojfWdOn]Ym401?n]Ym46oj^Td0?oZJ?@
0_nZ[]X7ojR[f@KoYjWH00?oYJSHooooooooool0Hoooool01Ol0003ooooooooooooooooo0000007o
oooo001@ooooo`03o`000?oooooooooo02gooooo1Omf_?`6oh_6n`?o/LW/0onIbOP6ok[7i003okjh
e?nl`]ko_<;N00Co_<;N1Onl]M800onk_]co^k?Aok^cd@06ok^cd@03okN^coni/M;o^K7B00?o^K7B
1Onf[<l00onh/M?o]Jc?okF/c`06okF/c`03ok6Xd?nd[=7o]:cA00?o]:cA1_nbZ<l00on^Y]3o/J[A
ok6Zd@03ok6Zd@Oo[jK?00?o[JC?ojjZdon^Z]<00on^Z]<5ojfWd@GoZjC@00?o[;?MojZ^f_nZ[]X0
1?nZ[]X7ojR[f@?oYjWHJ?ooool01Ol0003ooooooooooooooooo0000007ooooo001Aooooo`;o0000
;oooool4ogJlo0?oRlKk1?mk`_d5oiW9n0Co^/OT0_nVc?<7okc2gP03okbed_nk_]co^kkL00?o^kkL
1_nk/m400onj_Mco^K7BokVadP05okVadP03okJ/conh/M?o^;7C00?o^;7C1_ne[<l00onf/mKo]:cA
okB/d@04okB/d@Go/ZS?00?o/joEok6ZdOnaZ]401OnaZ]45ojnVc`03ok2`f?n^Z]?o[Z[C00Co[Z[C
1_n]Ym400on[Y=3o[;?Mojbcg@03ojbcg@KoZZkJ1OnXZmU]ooooo`04o`000?ooooooooooo`00007o
oooo001Cooooo`03o`000?oooooooooo02kooooo1?n0^_T6og_2o@GoVLWh00?o^/OTojK<lonVc?<0
0onVc?<5okc2gP;o[Lc`1_nk_]`3ok^cd@Co^[gL1Oni/M800oni_]ko^;7CokRad`05okRad`?o]Jc?
1?nf/mH6okB/d@03ok:Xconc[mGo/joE00?o/joE1onaZ]400on_Y/oo/;3Hok2`f003ok2`f0Go[Z[C
1On]Ym42ojfjh`Ko[;?M1_nZ[]X00onXZmWoooooooooo`1_ooooo`03o`000?oooooo0000007ooooo
001Dooooo`03o`000?oooooooooo02kooooo1?n0^_T3og_2o@CoNKkl1?n4aod6ojK<l`03okc2g_n]
c?3o[Lc`00Co[Lc`1_nk_]`00onk/m7o^[gLokZmg003okZmg0?o^K7B1?ni_]h7okRad`03okF/conf
/mKo][?F00?o][?F1Ond[=400one^mko/joEok>_e@05ok>_e@Go/J[A00?o/[_Pok2`f?n`/=P01?n`
/=P6ojjZd`03ojfWdOn]^^?o[K[S00Co[K[S1_n//md3ojZ^fWCooooo00?o0000ooooool000000Ooo
ool005Gooooo00?o0000ooooooooool0;Oooool6oi6mm@KoNKkl1?n4aod3ojK<l`CoS<_m1_n]c?03
ok^ng0;o/<c^1onj_M`00oni/M;o^KkNokVngP04okVngPGo^;7C00?o]l?TokJce_nf/mH01?nf/mH3
okB/d@Co]K_N1onc[mD00onaZ]7o/[_Pok:kh003ok:kh0Go/;3H1On^Z]<2ojk4jPOo[K[S0on//mej
ooooo`7o00000Oooool1o`000000E_ooool2o`0002kooooo1_nA_OD3ogVno0CoR;gh1?mh`_h6ohc;
o@?o[Lc`1?n@cO`4ok3<kPGo^[gL0_n^cO07okVngP03okRadong`nCo]l?T00?o]l?T1_nf/mH00ond
[=7o]K_NokFkgP04okFkgPGo/joE00?o/LW/ok:kh?nb^n001?nb^n06ok2`f003ojjZdon^a>[o[/CZ
00Co[/CZ1On]^^=oooooo`;o0000001Hooooo`03o`000?oooooooooo02cooooo0onA_OD4oijol0Ko
R;gh1?mh`_h3ohc;o@CoN/Kn1_n@cO`4ok3<kP03okZmg?n^cO3o[/g`00Co[/g`1Oni_]h2ojS?m0Go
]l?T1Onf/mH2ok7;k@Oo]K_N00?o/joEok79k?nabN`00onabN`6ok:kh0?o/;3H1?nZcO86ojk4jP03
ojfjhooooooooooo07oooooo0ol0000005Wooooo00?o0000ooooooooool0;Oooool6oijol0?oR;gh
1?nK_o85oh>mnPGoN/Kn0on@cO`4ogc8o`CoTLom1_n^cO000oni_]koZ<odojS?m004ojS?m0Go]l?T
00?o][?Fok7;kOnabnd01?nabnd5okFkgP03oj?@monabNco/LW/00Go/LW/0onb^n04oj3Bn@KoZ/gb
0on^a>Z0ooooo`Co00000oooool005[ooooo00?o0000ooooooooool0;Oooool3oijol0CoY;k/1_nK
_o82oh>mnPCoV;oc1_n2`?/5ogc8o`CoTLom0on^cO04oho@oPKoZ<od0_ng`n@4oigAnPKo/L_]00?o
]K_Noj?@monSd?L00onSd?L5ok79k0?oU=Gn1_nPd_T3oj[=lX;ooooo0ol00007ooooo`00Foooool0
0ol0003oooooooooo`0]ooooo`OoY;k/0onK_o83oj>nk@KoV;oc0on2`?/4oiO0m0CoPl;l1_mmb_l5
oho@oP?oZ<od1?n:dOl5oigAnP?o/L_]1OnCdoh4oj?@m`03ok79k?nDeOkoU=Gn00GoU=Gn0onPd_V3
ooooo`Co00002_ooool005cooooo0_l0000^ooooo`GoY;k/0_nX_n/6oj>nk@?oV;oc1?nR_nh6oiO0
m0CoPl;l0ommb_l4ohO3n`KoOL_o0_n:dOl4oh;;o`KoQ=7o0onCdoh3oh?@o`KoRMCo0onDeOj4oooo
o`Co00003_ooool005kooooo00?o0000ooooooooool0;?ooool00onT_^coZ;o[ojRoj`04ojRoj`Co
Xkk]0_nW_n/7oj:okP?oUl3d0_nR_nh7oiW1l`GoQl?k0ommbol4ohg2n@GoP/_o0on4dOl4oh[9o0Go
Pm3o0on9e?n5ooooo`Co00004_ooool005oooooo00?o0000ooooooooool0;Oooool6ojRoj`03oj>n
kOnW_n_oYko[00?oYko[1OnR_nh2ojNoj`GoX[o^1OnI`O<2oj>ok@GoW<7b1On=`_T2oio1l0OoU/?f
0_n:bOb;ooooo`Co00005_ooool0063ooooo00?o0000ooooooooool0;Oooool3ojRoj`CoZ<7/1OnW
_n/00onR_nkoYko[ojNoj`04ojNoj`GoX[o^00?oVL7coj>okOnS_nd01?nS_nd5oic1lP03ohg2nOnO
`O3oWl7`00CoWl7`1OnF`oJ;ooooo`?o00006_ooool0067ooooo0_l0000_ooooo`KoZ<7/0_nW_n/4
ojS1k0KoYko[0_nR_nh4ojNoj`KoXko]0_nL`O84ojBok0KoWl7`00?oU/?fooooooooool0R?ooool4
o`0001gooooo001Sooooo`03o`000?oooooooooo02gooooo0onX`N`2ojK0k0OoZ<7/0onW_n/3ojS1
k0KoYko[0onS_nd3ojNoj`KoY;o/0onO`O29ooooo`Co00008Oooool006Cooooo00?o0000oooooooo
ool0;Oooool5ojK0k0GoZ<7/0_nV`N`6ojS1k0?oYko[0onX`N`6ojNoj`?oY;o/R_ooool4o`0002Go
oooo001Uooooo`03o`000?oooooooooo02gooooo1OnV`>`00onX`NcoY/7/ojK1k004ojK1k0CoZ<7/
0_nV`N`6ojS1k0CoYko[R_ooool4o`0002Wooooo001Vooooo`;o0000;_ooool6ojK0k0KoY/7/00?o
Z<7/ojK1k?nV`N`00onV`N`6ojS1k003ojNojooooooooooo08Oooooo0ol0000]ooooo`00J?ooool0
0ol0003oooooooooo`0/ooooo`KoY/3/0onV`N`3ojK0k0KoY/7/0onX`Nb8ooooo`Co0000<?ooool0
06Wooooo00?o0000ooooooooool0;?ooool3ojK0k0CoYko[1OnV`>`3ojK1k8Wooooo1?l0000doooo
o`00J_ooool00ol0003oooooooooo`0/ooooo`OoYko[0_nV`>b:ooooo`Co0000>?ooool006_ooooo
0_l0000]ooooo`GoYko[ROooool4o`0003cooooo001]ooooo`03o`000?oooooooooo02_ooooo00?o
Yko[ooooooooool0Qoooool3o`00043ooooo001^ooooo`03o`000?oooooooooo02[ooooo00?o0000
ooooooooool0Poooool4o`0004?ooooo001_ooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool0Ooooool4o`0004Oooooo001`ooooo`;o0000:Oooool00ol0003oooooooooo`1kooooo`Co
0000Boooool007;ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1gooooo`Co0000
Coooool007?ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1dooooo`?o0000Dooo
ool007Cooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1`ooooo`Co0000E_ooool0
07Gooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1/ooooo`Co0000F_ooool007Ko
oooo0_l0000Sooooo`03o`000?oooooooooo06Sooooo1?l0001Nooooo`00N?ooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo06Cooooo1?l0001Rooooo`00NOooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo067ooooo0ol0001Vooooo`00N_ooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo05gooooo1?l0001Yooooo`00Noooool2o`0001kooooo00?o0000oooo
ooooool0FOooool4o`0006gooooo001mooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool0EOooool4o`00077ooooo001nooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
DOooool4o`0007Gooooo001oooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0C_oo
ool3o`0007Wooooo0020ooooo`;o00006Oooool00ol0003oooooooooo`1:ooooo`Co0000O?ooool0
08;ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`16ooooo`Co0000P?ooool008?o
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`12ooooo`Co0000Q?ooool008Cooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0nooooo`Co0000R?ooool008Gooooo0_l0
000Cooooo`03o`000?oooooooooo03cooooo0ol0002<ooooo`00Qoooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo03Sooooo1?l0002?ooooo`00R?ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo03Cooooo1?l0002Cooooo`00ROooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo033ooooo1?l0002Gooooo`00R_ooool2o`0000kooooo00?o0000ooooooooool0
;?ooool4o`0009_ooooo002<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0:Ooo
ool3o`0009oooooo002=ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool09Oooool4
o`000:;ooooo002>ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08Oooool4o`00
0:Kooooo002?ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07Oooool4o`000:[o
oooo002@ooooo`;o00002?ooool00ol0003oooooooooo`0Iooooo`Co0000[_ooool009;ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Fooooo`?o0000/_ooool009?ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0Booooo`Co0000]Oooool009Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0>ooooo`Co0000^Oooool009Gooooo0_l00003ooooo`03
o`000?oooooooooo00[ooooo1?l0002mooooo`00Uoooool01?l0003oooooooooool00008ooooo`Co
0000`Oooool009Sooooo00?o0000ooooool000001Oooool3o`000<Gooooo002Iooooo`;o000000?o
ooooo`000?l000000_l00038ooooo`00V_ooool2o`000<cooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0538698, 0.0432538, \
0.0035044, 0.0035044}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.11022e-16 1.04977 -0.0679587 1.04977 [
[.12586 .2075 -12 -8.99448 ]
[.12586 .2075 0 .00552 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.56094 .0364 -5.16972 -9 ]
[.56094 .0364 .83028 0 ]
[.75679 .08071 0 -6.17777 ]
[.75679 .08071 12 2.82223 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.9429 .3657 0 -5.9083 ]
[.9429 .3657 6 3.0917 ]
[.02494 .25992 -18 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.01611 .31527 -18 -2.78472 ]
[.01611 .31527 0 6.21528 ]
[.00696 .37264 -6 -2.83339 ]
[.00696 .37264 0 6.16661 ]
[-0.00254 .43215 -12 -2.88407 ]
[-0.00254 .43215 0 6.11593 ]
[-0.0124 .49393 -12 -2.93688 ]
[-0.0124 .49393 0 6.06312 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
[(-2)] .12586 .2075 1 .99877 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.56863 .04703 m
.57247 .05235 L
s
[(2)] .56094 .0364 .72324 1 Mshowa
.125 Mabswid
.18558 .19702 m
.18832 .19985 L
s
.23703 .17687 m
.23971 .17975 L
s
.28951 .15632 m
.29214 .15925 L
s
.39772 .11395 m
.40023 .11699 L
s
.4535 .09211 m
.45595 .0952 L
s
.51046 .06981 m
.51284 .07294 L
s
.08568 .23614 m
.08851 .23887 L
s
.62804 .02377 m
.63027 .02701 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.7445 .0853 m
.73835 .08759 L
s
[(-2)] .75679 .08071 -1 .37284 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(0)] .8565 .23339 -1 .34028 Mshowa
.93037 .36962 m
.92411 .37158 L
s
[(2)] .9429 .3657 -1 .31296 Mshowa
.125 Mabswid
.7708 .12553 m
.7671 .12688 L
s
.79613 .16428 m
.79242 .1656 L
s
.82054 .20161 m
.81682 .20291 L
s
.86679 .27235 m
.86305 .2736 L
s
.88871 .30589 m
.88497 .30711 L
s
.9099 .3383 m
.90615 .3395 L
s
.71716 .04348 m
.71349 .04489 L
s
.95018 .39992 m
.94642 .40107 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(-20)] .02494 .25992 1 -0.39157 Mshowa
.02837 .31059 m
.0345 .30825 L
s
[(-10)] .01611 .31527 1 -0.38117 Mshowa
.01926 .36808 m
.02541 .3658 L
s
[(0)] .00696 .37264 1 -0.37036 Mshowa
.00981 .42772 m
.01599 .4255 L
s
[(10)] -0.00254 .43215 1 -0.3591 Mshowa
0 .48963 m
.0062 .48748 L
s
[(20)] -0.0124 .49393 1 -0.34736 Mshowa
.125 Mabswid
.03543 .26607 m
.0391 .26464 L
s
.03368 .27708 m
.03735 .27566 L
s
.03193 .28817 m
.0356 .28676 L
s
.03016 .29934 m
.03383 .29793 L
s
.02658 .32192 m
.03026 .32053 L
s
.02477 .33334 m
.02845 .33195 L
s
.02295 .34483 m
.02663 .34345 L
s
.02111 .35641 m
.0248 .35504 L
s
.0174 .37983 m
.02109 .37847 L
s
.01552 .39167 m
.01922 .39032 L
s
.01363 .4036 m
.01733 .40225 L
s
.01173 .41561 m
.01543 .41428 L
s
.00788 .43991 m
.01159 .43859 L
s
.00593 .4522 m
.00964 .45089 L
s
.00397 .46458 m
.00768 .46328 L
s
.00199 .47706 m
.00571 .47576 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.651 .752 .923 r
.39362 .69475 .4017 .70174 .4152 .69799 .40717 .69106 Mtetra
.655 .755 .924 r
.40717 .69106 .4152 .69799 .42878 .69431 .42079 .68721 Mtetra
.656 .752 .921 r
.42079 .68721 .42878 .69431 .44242 .69049 .43448 .68332 Mtetra
.657 .751 .92 r
.43448 .68332 .44242 .69049 .45614 .6866 .44824 .67938 Mtetra
.646 .748 .924 r
.44824 .67938 .45614 .6866 .46992 .68267 .46206 .67581 Mtetra
.612 .749 .943 r
.46206 .67581 .46992 .68267 .48378 .67894 .47594 .67316 Mtetra
.577 .772 .971 r
.47594 .67316 .48378 .67894 .4977 .67583 .4899 .67101 Mtetra
.534 .79 .991 r
.4899 .67101 .4977 .67583 .51169 .67333 .50395 .66921 Mtetra
.516 .807 .998 r
.50395 .66921 .51169 .67333 .52577 .67103 .51808 .6673 Mtetra
.541 .829 .998 r
.51808 .6673 .52577 .67103 .53994 .669 .53231 .6647 Mtetra
.621 .837 .983 r
.53231 .6647 .53994 .669 .55419 .66668 .54661 .66081 Mtetra
.664 .799 .947 r
.54661 .66081 .55419 .66668 .56852 .66386 .56098 .65624 Mtetra
.681 .756 .908 r
.56098 .65624 .56852 .66386 .58293 .66021 .57541 .65119 Mtetra
.69 .726 .878 r
.57541 .65119 .58293 .66021 .5974 .65606 .5899 .64563 Mtetra
.687 .698 .854 r
.5899 .64563 .5974 .65606 .61194 .65163 .60445 .63993 Mtetra
.679 .673 .837 r
.60445 .63993 .61194 .65163 .62655 .64708 .61908 .63442 Mtetra
.671 .656 .827 r
.61908 .63442 .62655 .64708 .64124 .64251 .63377 .62918 Mtetra
.663 .644 .821 r
.63377 .62918 .64124 .64251 .656 .63801 .64855 .62427 Mtetra
.657 .636 .818 r
.64855 .62427 .656 .63801 .67085 .63366 .66341 .61969 Mtetra
.65 .631 .817 r
.66341 .61969 .67085 .63366 .68577 .62947 .67837 .61545 Mtetra
.644 .628 .819 r
.67837 .61545 .68577 .62947 .70079 .62545 .69342 .61155 Mtetra
.638 .628 .823 r
.69342 .61155 .70079 .62545 .7159 .62157 .70858 .60799 Mtetra
.632 .63 .83 r
.70858 .60799 .7159 .62157 .7311 .61776 .72384 .60476 Mtetra
.627 .637 .841 r
.72384 .60476 .7311 .61776 .74638 .61395 .73922 .60182 Mtetra
.622 .65 .856 r
.73922 .60182 .74638 .61395 .76175 .61 .7547 .59907 Mtetra
.624 .673 .876 r
.7547 .59907 .76175 .61 .77718 .60578 .77028 .59619 Mtetra
.633 .706 .899 r
.77028 .59619 .77718 .60578 .79265 .60103 .78591 .59279 Mtetra
.641 .743 .923 r
.78591 .59279 .79265 .60103 .80814 .59544 .8016 .5889 Mtetra
.651 .796 .952 r
.8016 .5889 .80814 .59544 .82366 .58932 .81732 .58432 Mtetra
.679 .855 .967 r
.81732 .58432 .82366 .58932 .83921 .5829 .83301 .57841 Mtetra
.695 .878 .967 r
.83301 .57841 .83921 .5829 .85487 .57674 .84871 .57177 Mtetra
.702 .866 .96 r
.84871 .57177 .85487 .57674 .87061 .57076 .86446 .565 Mtetra
.697 .841 .952 r
.86446 .565 .87061 .57076 .8865 .56542 .88031 .55858 Mtetra
.687 .806 .939 r
.88031 .55858 .8865 .56542 .90254 .56071 .8963 .55266 Mtetra
.664 .765 .925 r
.8963 .55266 .90254 .56071 .91869 .5562 .91247 .5477 Mtetra
.655 .75 .92 r
.91247 .5477 .91869 .5562 .93493 .55164 .92877 .54311 Mtetra
.656 .751 .92 r
.92877 .54311 .93493 .55164 .95125 .54701 .94517 .53847 Mtetra
.656 .752 .921 r
.94517 .53847 .95125 .54701 .96765 .54222 .96165 .53378 Mtetra
.659 .757 .922 r
.96165 .53378 .96765 .54222 .98415 .53751 .9782 .52891 Mtetra
.655 .755 .924 r
.38546 .68778 .39362 .69475 .40717 .69106 .39906 .68393 Mtetra
.656 .752 .92 r
.39906 .68393 .40717 .69106 .42079 .68721 .41272 .68002 Mtetra
.656 .751 .92 r
.41272 .68002 .42079 .68721 .43448 .68332 .42646 .67608 Mtetra
.641 .747 .926 r
.42646 .67608 .43448 .68332 .44824 .67938 .44025 .67263 Mtetra
.597 .749 .95 r
.44025 .67263 .44824 .67938 .46206 .67581 .45409 .67032 Mtetra
.556 .776 .98 r
.45409 .67032 .46206 .67581 .47594 .67316 .46801 .66844 Mtetra
.508 .784 .995 r
.46801 .66844 .47594 .67316 .4899 .67101 .48202 .66701 Mtetra
.518 .812 .999 r
.48202 .66701 .4899 .67101 .50395 .66921 .49612 .66497 Mtetra
.604 .833 .987 r
.49612 .66497 .50395 .66921 .51808 .6673 .51031 .66145 Mtetra
.668 .8 .946 r
.51031 .66145 .51808 .6673 .53231 .6647 .52459 .65675 Mtetra
.693 .75 .896 r
.52459 .65675 .53231 .6647 .54661 .66081 .53893 .6512 Mtetra
.706 .718 .859 r
.53893 .6512 .54661 .66081 .56098 .65624 .55332 .64469 Mtetra
.697 .682 .831 r
.55332 .64469 .56098 .65624 .57541 .65119 .56778 .63814 Mtetra
.687 .656 .814 r
.56778 .63814 .57541 .65119 .5899 .64563 .58229 .63184 Mtetra
.676 .643 .809 r
.58229 .63184 .5899 .64563 .60445 .63993 .59687 .62606 Mtetra
.668 .639 .811 r
.59687 .62606 .60445 .63993 .61908 .63442 .61152 .62076 Mtetra
.663 .64 .817 r
.61152 .62076 .61908 .63442 .63377 .62918 .62626 .61578 Mtetra
.659 .642 .822 r
.62626 .61578 .63377 .62918 .64855 .62427 .64107 .61106 Mtetra
.656 .644 .827 r
.64107 .61106 .64855 .62427 .66341 .61969 .65597 .60658 Mtetra
.652 .645 .83 r
.65597 .60658 .66341 .61969 .67837 .61545 .67096 .60229 Mtetra
.648 .643 .831 r
.67096 .60229 .67837 .61545 .69342 .61155 .68604 .5982 Mtetra
.643 .639 .831 r
.68604 .5982 .69342 .61155 .70858 .60799 .70121 .59434 Mtetra
.638 .633 .829 r
.70121 .59434 .70858 .60799 .72384 .60476 .71648 .59075 Mtetra
.631 .625 .826 r
.71648 .59075 .72384 .60476 .73922 .60182 .73187 .58749 Mtetra
.622 .617 .825 r
.73187 .58749 .73922 .60182 .7547 .59907 .74738 .58473 Mtetra
.612 .613 .828 r
.74738 .58473 .7547 .59907 .77028 .59619 .76303 .58249 Mtetra
.606 .62 .839 r
.76303 .58249 .77028 .59619 .78591 .59279 .77881 .58053 Mtetra
.604 .643 .862 r
.77881 .58053 .78591 .59279 .8016 .5889 .79469 .57853 Mtetra
.622 .688 .891 r
.79469 .57853 .8016 .5889 .81732 .58432 .8106 .57557 Mtetra
.639 .733 .917 r
.8106 .57557 .81732 .58432 .83301 .57841 .82654 .57173 Mtetra
.663 .801 .949 r
.82654 .57173 .83301 .57841 .84871 .57177 .84246 .56667 Mtetra
.696 .862 .961 r
.84246 .56667 .84871 .57177 .86446 .565 .85832 .56007 Mtetra
.712 .874 .957 r
.85832 .56007 .86446 .565 .88031 .55858 .87418 .55283 Mtetra
.704 .847 .951 r
.87418 .55283 .88031 .55858 .8963 .55266 .89015 .54603 Mtetra
.695 .819 .941 r
.89015 .54603 .8963 .55266 .91247 .5477 .90625 .53967 Mtetra
.668 .77 .927 r
.90625 .53967 .91247 .5477 .92877 .54311 .92256 .53448 Mtetra
.655 .751 .92 r
.92256 .53448 .92877 .54311 .94517 .53847 .93902 .52981 Mtetra
.656 .751 .92 r
.93902 .52981 .94517 .53847 .96165 .53378 .95557 .52509 Mtetra
.656 .752 .92 r
.95557 .52509 .96165 .53378 .9782 .52891 .97221 .52032 Mtetra
.656 .752 .921 r
.37724 .68063 .38546 .68778 .39906 .68393 .39088 .6767 Mtetra
.656 .751 .92 r
.39088 .6767 .39906 .68393 .41272 .68002 .40458 .67275 Mtetra
.638 .746 .927 r
.40458 .67275 .41272 .68002 .42646 .67608 .41834 .66937 Mtetra
.589 .749 .953 r
.41834 .66937 .42646 .67608 .44025 .67263 .43215 .66723 Mtetra
.537 .772 .985 r
.43215 .66723 .44025 .67263 .45409 .67032 .44602 .66565 Mtetra
.497 .782 .996 r
.44602 .66565 .45409 .67032 .46801 .66844 .45998 .66435 Mtetra
.538 .817 .997 r
.45998 .66435 .46801 .66844 .48202 .66701 .47405 .662 Mtetra
.647 .821 .967 r
.47405 .662 .48202 .66701 .49612 .66497 .48823 .65775 Mtetra
.692 .768 .91 r
.48823 .65775 .49612 .66497 .51031 .66145 .50248 .65227 Mtetra
.716 .729 .861 r
.50248 .65227 .51031 .66145 .52459 .65675 .51681 .64532 Mtetra
.709 .687 .827 r
.51681 .64532 .52459 .65675 .53893 .6512 .53118 .63806 Mtetra
.695 .658 .809 r
.53118 .63806 .53893 .6512 .55332 .64469 .54561 .63116 Mtetra
.681 .648 .81 r
.54561 .63116 .55332 .64469 .56778 .63814 .56009 .62508 Mtetra
.675 .652 .82 r
.56009 .62508 .56778 .63814 .58229 .63184 .57465 .61954 Mtetra
.669 .662 .834 r
.57465 .61954 .58229 .63184 .59687 .62606 .58928 .61445 Mtetra
.664 .672 .848 r
.58928 .61445 .59687 .62606 .61152 .62076 .60399 .60975 Mtetra
.657 .68 .861 r
.60399 .60975 .61152 .62076 .62626 .61578 .61878 .60546 Mtetra
.656 .694 .874 r
.61878 .60546 .62626 .61578 .64107 .61106 .63366 .60122 Mtetra
.657 .705 .883 r
.63366 .60122 .64107 .61106 .65597 .60658 .64861 .59694 Mtetra
.657 .711 .887 r
.64861 .59694 .65597 .60658 .67096 .60229 .66364 .59261 Mtetra
.658 .711 .887 r
.66364 .59261 .67096 .60229 .68604 .5982 .67876 .58822 Mtetra
.658 .706 .882 r
.67876 .58822 .68604 .5982 .70121 .59434 .69395 .5838 Mtetra
.656 .694 .874 r
.69395 .5838 .70121 .59434 .71648 .59075 .70923 .57942 Mtetra
.647 .676 .864 r
.70923 .57942 .71648 .59075 .73187 .58749 .72461 .57545 Mtetra
.637 .661 .856 r
.72461 .57545 .73187 .58749 .74738 .58473 .74011 .57188 Mtetra
.627 .644 .847 r
.74011 .57188 .74738 .58473 .76303 .58249 .75574 .56879 Mtetra
.616 .626 .838 r
.75574 .56879 .76303 .58249 .77881 .58053 .77151 .56624 Mtetra
.6 .61 .834 r
.77151 .56624 .77881 .58053 .79469 .57853 .78744 .56454 Mtetra
.591 .611 .841 r
.78744 .56454 .79469 .57853 .8106 .57557 .80353 .56322 Mtetra
.593 .639 .866 r
.80353 .56322 .8106 .57557 .82654 .57173 .81971 .56161 Mtetra
.623 .698 .898 r
.81971 .56161 .82654 .57173 .84246 .56667 .83587 .55849 Mtetra
.649 .756 .928 r
.83587 .55849 .84246 .56667 .85832 .56007 .85201 .5541 Mtetra
.693 .837 .952 r
.85201 .5541 .85832 .56007 .87418 .55283 .86804 .54772 Mtetra
.717 .873 .954 r
.86804 .54772 .87418 .55283 .89015 .54603 .88403 .54025 Mtetra
.713 .852 .948 r
.88403 .54025 .89015 .54603 .90625 .53967 .90012 .53304 Mtetra
.7 .824 .941 r
.90012 .53304 .90625 .53967 .92256 .53448 .91635 .5264 Mtetra
.67 .773 .927 r
.91635 .5264 .92256 .53448 .93902 .52981 .9328 .52104 Mtetra
.655 .751 .92 r
.9328 .52104 .93902 .52981 .95557 .52509 .94943 .51629 Mtetra
.94943 .51629 .95557 .52509 .97221 .52032 .96614 .5115 Mtetra
.657 .751 .92 r
.36894 .67337 .37724 .68063 .39088 .6767 .38262 .66938 Mtetra
.64 .747 .926 r
.38262 .66938 .39088 .6767 .40458 .67275 .39635 .66592 Mtetra
.586 .745 .953 r
.39635 .66592 .40458 .67275 .41834 .66937 .41011 .66385 Mtetra
.528 .767 .985 r
.41011 .66385 .41834 .66937 .43215 .66723 .42394 .66246 Mtetra
.49 .777 .996 r
.42394 .66246 .43215 .66723 .44602 .66565 .43785 .66128 Mtetra
.561 .817 .993 r
.43785 .66128 .44602 .66565 .45998 .66435 .45189 .65866 Mtetra
.668 .805 .948 r
.45189 .65866 .45998 .66435 .47405 .662 .46605 .65394 Mtetra
.71 .751 .884 r
.46605 .65394 .47405 .662 .48823 .65775 .4803 .64752 Mtetra
.723 .711 .839 r
.4803 .64752 .48823 .65775 .50248 .65227 .49462 .63976 Mtetra
.709 .672 .812 r
.49462 .63976 .50248 .65227 .51681 .64532 .50898 .63209 Mtetra
.69 .656 .811 r
.50898 .63209 .51681 .64532 .53118 .63806 .52338 .62548 Mtetra
.681 .662 .824 r
.52338 .62548 .53118 .63806 .54561 .63116 .53785 .61963 Mtetra
.67 .675 .846 r
.53785 .61963 .54561 .63116 .56009 .62508 .55238 .61463 Mtetra
.654 .689 .871 r
.55238 .61463 .56009 .62508 .57465 .61954 .567 .6105 Mtetra
.648 .718 .899 r
.567 .6105 .57465 .61954 .58928 .61445 .58169 .60662 Mtetra
.644 .747 .924 r
.58169 .60662 .58928 .61445 .60399 .60975 .59647 .60276 Mtetra
.642 .771 .942 r
.59647 .60276 .60399 .60975 .61878 .60546 .61134 .59883 Mtetra
.643 .783 .948 r
.61134 .59883 .61878 .60546 .63366 .60122 .62628 .59476 Mtetra
.646 .79 .951 r
.62628 .59476 .63366 .60122 .64861 .59694 .64129 .59052 Mtetra
.649 .793 .951 r
.64129 .59052 .64861 .59694 .66364 .59261 .65639 .58615 Mtetra
.653 .794 .95 r
.65639 .58615 .66364 .59261 .67876 .58822 .67156 .58164 Mtetra
.658 .794 .947 r
.67156 .58164 .67876 .58822 .69395 .5838 .68681 .57696 Mtetra
.662 .789 .942 r
.68681 .57696 .69395 .5838 .70923 .57942 .70213 .57214 Mtetra
.666 .778 .933 r
.70213 .57214 .70923 .57942 .72461 .57545 .71752 .56723 Mtetra
.666 .755 .916 r
.71752 .56723 .72461 .57545 .74011 .57188 .733 .56236 Mtetra
.66 .722 .895 r
.733 .56236 .74011 .57188 .75574 .56879 .74858 .55772 Mtetra
.639 .683 .875 r
.74858 .55772 .75574 .56879 .77151 .56624 .76431 .55398 Mtetra
.621 .654 .861 r
.76431 .55398 .77151 .56624 .78744 .56454 .7802 .55111 Mtetra
.605 .628 .847 r
.7802 .55111 .78744 .56454 .80353 .56322 .79626 .54903 Mtetra
.583 .606 .841 r
.79626 .54903 .80353 .56322 .81971 .56161 .81252 .54805 Mtetra
.579 .615 .852 r
.81252 .54805 .81971 .56161 .83587 .55849 .82893 .54717 Mtetra
.603 .667 .884 r
.82893 .54717 .83587 .55849 .85201 .5541 .84533 .54493 Mtetra
.639 .731 .915 r
.84533 .54493 .85201 .5541 .86804 .54772 .86167 .54093 Mtetra
.688 .815 .943 r
.86167 .54093 .86804 .54772 .88403 .54025 .87788 .53475 Mtetra
.723 .866 .949 r
.87788 .53475 .88403 .54025 .90012 .53304 .89401 .52704 Mtetra
.718 .851 .945 r
.89401 .52704 .90012 .53304 .91635 .5264 .91022 .51954 Mtetra
.702 .822 .939 r
.91022 .51954 .91635 .5264 .9328 .52104 .92659 .51273 Mtetra
.668 .77 .926 r
.92659 .51273 .9328 .52104 .94943 .51629 .94321 .50737 Mtetra
.655 .75 .92 r
.94321 .50737 .94943 .51629 .96614 .5115 .96 .50255 Mtetra
.645 .748 .924 r
.36056 .66601 .36894 .67337 .38262 .66938 .37426 .66238 Mtetra
.592 .743 .949 r
.37426 .66238 .38262 .66938 .39635 .66592 .38799 .66018 Mtetra
.529 .761 .982 r
.38799 .66018 .39635 .66592 .41011 .66385 .40177 .65885 Mtetra
.485 .769 .994 r
.40177 .65885 .41011 .66385 .42394 .66246 .41563 .65786 Mtetra
.567 .812 .991 r
.41563 .65786 .42394 .66246 .43785 .66128 .42963 .65522 Mtetra
.678 .797 .938 r
.42963 .65522 .43785 .66128 .45189 .65866 .44378 .65023 Mtetra
.722 .746 .871 r
.44378 .65023 .45189 .65866 .46605 .65394 .45803 .64312 Mtetra
.727 .703 .827 r
.45803 .64312 .46605 .65394 .4803 .64752 .47234 .63483 Mtetra
.708 .67 .81 r
.47234 .63483 .4803 .64752 .49462 .63976 .48669 .62715 Mtetra
.691 .665 .819 r
.48669 .62715 .49462 .63976 .50898 .63209 .50108 .62063 Mtetra
.677 .678 .844 r
.50108 .62063 .50898 .63209 .52338 .62548 .51552 .61528 Mtetra
.651 .693 .876 r
.51552 .61528 .52338 .62548 .53785 .61963 .53004 .61128 Mtetra
.639 .731 .916 r
.53004 .61128 .53785 .61963 .55238 .61463 .54463 .6077 Mtetra
.63 .768 .946 r
.54463 .6077 .55238 .61463 .567 .6105 .5593 .60416 Mtetra
.631 .786 .956 r
.5593 .60416 .567 .6105 .58169 .60662 .57406 .60041 Mtetra
.633 .792 .959 r
.57406 .60041 .58169 .60662 .59647 .60276 .5889 .59653 Mtetra
.638 .794 .957 r
.5889 .59653 .59647 .60276 .61134 .59883 .60382 .59251 Mtetra
.642 .793 .955 r
.60382 .59251 .61134 .59883 .62628 .59476 .61882 .58834 Mtetra
.646 .793 .953 r
.61882 .58834 .62628 .59476 .64129 .59052 .6339 .58405 Mtetra
.649 .794 .952 r
.6339 .58405 .64129 .59052 .65639 .58615 .64906 .57963 Mtetra
.652 .795 .951 r
.64906 .57963 .65639 .58615 .67156 .58164 .66429 .5751 Mtetra
.655 .796 .95 r
.66429 .5751 .67156 .58164 .68681 .57696 .67961 .57043 Mtetra
.659 .799 .95 r
.67961 .57043 .68681 .57696 .70213 .57214 .695 .56562 Mtetra
.662 .801 .949 r
.695 .56562 .70213 .57214 .71752 .56723 .71046 .56066 Mtetra
.666 .802 .948 r
.71046 .56066 .71752 .56723 .733 .56236 .726 .55556 Mtetra
.672 .799 .943 r
.726 .55556 .733 .56236 .74858 .55772 .7416 .55025 Mtetra
.672 .781 .931 r
.7416 .55025 .74858 .55772 .76431 .55398 .75729 .54496 Mtetra
.663 .74 .907 r
.75729 .54496 .76431 .55398 .7802 .55111 .77309 .5401 Mtetra
.631 .684 .882 r
.77309 .5401 .7802 .55111 .79626 .54903 .78909 .53664 Mtetra
.606 .648 .866 r
.78909 .53664 .79626 .54903 .81252 .54805 .80529 .53436 Mtetra
.581 .615 .851 r
.80529 .53436 .81252 .54805 .82893 .54717 .82171 .53331 Mtetra
.568 .607 .852 r
.82171 .53331 .82893 .54717 .84533 .54493 .83832 .5329 Mtetra
.588 .649 .878 r
.83832 .5329 .84533 .54493 .86167 .54093 .85495 .53129 Mtetra
.634 .721 .91 r
.85495 .53129 .86167 .54093 .87788 .53475 .87148 .52748 Mtetra
.69 .805 .937 r
.87148 .52748 .87788 .53475 .89401 .52704 .88784 .52122 Mtetra
.729 .861 .943 r
.88784 .52122 .89401 .52704 .91022 .51954 .9041 .51321 Mtetra
.721 .846 .941 r
.9041 .51321 .91022 .51954 .92659 .51273 .92045 .50554 Mtetra
.7 .815 .937 r
.92045 .50554 .92659 .51273 .94321 .50737 .93698 .49876 Mtetra
.664 .764 .924 r
.93698 .49876 .94321 .50737 .96 .50255 .95379 .49348 Mtetra
.606 .743 .942 r
.35208 .6588 .36056 .66601 .37426 .66238 .36578 .65626 Mtetra
.541 .755 .975 r
.36578 .65626 .37426 .66238 .38799 .66018 .37952 .65484 Mtetra
.48 .757 .991 r
.37952 .65484 .38799 .66018 .40177 .65885 .39332 .65408 Mtetra
.553 .803 .991 r
.39332 .65408 .40177 .65885 .41563 .65786 .40728 .65176 Mtetra
.678 .796 .938 r
.40728 .65176 .41563 .65786 .42963 .65522 .4214 .64676 Mtetra
.728 .747 .868 r
.4214 .64676 .42963 .65522 .44378 .65023 .43565 .6393 Mtetra
.732 .703 .823 r
.43565 .6393 .44378 .65023 .45803 .64312 .44997 .6306 Mtetra
.71 .673 .812 r
.44997 .6306 .45803 .64312 .47234 .63483 .46432 .62283 Mtetra
.693 .675 .829 r
.46432 .62283 .47234 .63483 .48669 .62715 .47869 .6164 Mtetra
.664 .687 .862 r
.47869 .6164 .48669 .62715 .50108 .62063 .4931 .61176 Mtetra
.638 .719 .906 r
.4931 .61176 .50108 .62063 .51552 .61528 .50758 .60824 Mtetra
.623 .763 .946 r
.50758 .60824 .51552 .61528 .53004 .61128 .52215 .60493 Mtetra
.623 .783 .958 r
.52215 .60493 .53004 .61128 .54463 .6077 .53679 .60141 Mtetra
.628 .788 .959 r
.53679 .60141 .54463 .6077 .5593 .60416 .55153 .59772 Mtetra
.637 .787 .954 r
.55153 .59772 .5593 .60416 .57406 .60041 .56634 .59377 Mtetra
.648 .786 .948 r
.56634 .59377 .57406 .60041 .5889 .59653 .58123 .58951 Mtetra
.652 .777 .94 r
.58123 .58951 .5889 .59653 .60382 .59251 .5962 .58516 Mtetra
.654 .77 .934 r
.5962 .58516 .60382 .59251 .61882 .58834 .61126 .58076 Mtetra
.654 .765 .931 r
.61126 .58076 .61882 .58834 .6339 .58405 .62639 .57632 Mtetra
.655 .762 .929 r
.62639 .57632 .6339 .58405 .64906 .57963 .6416 .57186 Mtetra
.6416 .57186 .64906 .57963 .66429 .5751 .6569 .56738 Mtetra
.655 .765 .93 r
.6569 .56738 .66429 .5751 .67961 .57043 .67228 .56286 Mtetra
.655 .77 .934 r
.67228 .56286 .67961 .57043 .695 .56562 .68775 .5583 Mtetra
.656 .778 .939 r
.68775 .5583 .695 .56562 .71046 .56066 .70329 .55364 Mtetra
.663 .79 .943 r
.70329 .55364 .71046 .56066 .726 .55556 .71891 .54865 Mtetra
.669 .797 .943 r
.71891 .54865 .726 .55556 .7416 .55025 .73459 .54341 Mtetra
.673 .801 .944 r
.73459 .54341 .7416 .55025 .75729 .54496 .75034 .53798 Mtetra
.678 .8 .94 r
.75034 .53798 .75729 .54496 .77309 .5401 .76616 .53233 Mtetra
.674 .779 .929 r
.76616 .53233 .77309 .5401 .78909 .53664 .78207 .52689 Mtetra
.648 .721 .902 r
.78207 .52689 .78909 .53664 .80529 .53436 .79816 .52259 Mtetra
.606 .662 .878 r
.79816 .52259 .80529 .53436 .82171 .53331 .81451 .52014 Mtetra
.578 .624 .862 r
.81451 .52014 .82171 .53331 .83832 .5329 .8311 .51909 Mtetra
.558 .605 .856 r
.8311 .51909 .83832 .5329 .85495 .53129 .84792 .51903 Mtetra
.58 .643 .878 r
.84792 .51903 .85495 .53129 .87148 .52748 .86475 .51769 Mtetra
.634 .721 .91 r
.86475 .51769 .87148 .52748 .88784 .52122 .88144 .51381 Mtetra
.698 .808 .933 r
.88144 .51381 .88784 .52122 .9041 .51321 .89793 .5071 Mtetra
.736 .859 .938 r
.89793 .5071 .9041 .51321 .92045 .50554 .9143 .49874 Mtetra
.72 .835 .936 r
.9143 .49874 .92045 .50554 .93698 .49876 .93081 .49107 Mtetra
.692 .802 .933 r
.93081 .49107 .93698 .49876 .95379 .49348 .94755 .48455 Mtetra
.556 .745 .965 r
.3435 .65217 .35208 .6588 .36578 .65626 .35719 .6506 Mtetra
.485 .75 .988 r
.35719 .6506 .36578 .65626 .37952 .65484 .37094 .64989 Mtetra
.52 .786 .993 r
.37094 .64989 .37952 .65484 .39332 .65408 .38483 .64822 Mtetra
.667 .801 .947 r
.38483 .64822 .39332 .65408 .40728 .65176 .39891 .64352 Mtetra
.728 .752 .872 r
.39891 .64352 .40728 .65176 .4214 .64676 .41316 .63612 Mtetra
.738 .71 .824 r
.41316 .63612 .4214 .64676 .43565 .6393 .42749 .62706 Mtetra
.715 .679 .814 r
.42749 .62706 .43565 .6393 .44997 .6306 .44184 .61902 Mtetra
.695 .684 .835 r
.44184 .61902 .44997 .6306 .46432 .62283 .4562 .61255 Mtetra
.656 .694 .874 r
.4562 .61255 .46432 .62283 .47869 .6164 .47058 .60834 Mtetra
.626 .736 .926 r
.47058 .60834 .47869 .6164 .4931 .61176 .48503 .60512 Mtetra
.617 .773 .955 r
.48503 .60512 .4931 .61176 .50758 .60824 .49956 .60185 Mtetra
.621 .782 .959 r
.49956 .60185 .50758 .60824 .52215 .60493 .51417 .59839 Mtetra
.636 .784 .952 r
.51417 .59839 .52215 .60493 .53679 .60141 .52888 .5945 Mtetra
.65 .778 .942 r
.52888 .5945 .53679 .60141 .55153 .59772 .54366 .59022 Mtetra
.655 .765 .93 r
.54366 .59022 .55153 .59772 .56634 .59377 .55852 .58584 Mtetra
.656 .755 .923 r
.55852 .58584 .56634 .59377 .58123 .58951 .57347 .58144 Mtetra
.653 .752 .922 r
.57347 .58144 .58123 .58951 .5962 .58516 .58849 .5771 Mtetra
.654 .753 .923 r
.58849 .5771 .5962 .58516 .61126 .58076 .6036 .57271 Mtetra
.655 .755 .923 r
.6036 .57271 .61126 .58076 .62639 .57632 .61879 .56827 Mtetra
.656 .756 .924 r
.61879 .56827 .62639 .57632 .6416 .57186 .63407 .56376 Mtetra
.656 .756 .923 r
.63407 .56376 .6416 .57186 .6569 .56738 .64942 .5592 Mtetra
.657 .756 .922 r
.64942 .5592 .6569 .56738 .67228 .56286 .66486 .55458 Mtetra
.658 .755 .921 r
.66486 .55458 .67228 .56286 .68775 .5583 .68038 .54991 Mtetra
.656 .752 .921 r
.68038 .54991 .68775 .5583 .70329 .55364 .69599 .5453 Mtetra
.656 .755 .923 r
.69599 .5453 .70329 .55364 .71891 .54865 .71168 .54067 Mtetra
.657 .765 .93 r
.71168 .54067 .71891 .54865 .73459 .54341 .72746 .53593 Mtetra
.665 .783 .937 r
.72746 .53593 .73459 .54341 .75034 .53798 .7433 .53079 Mtetra
.676 .796 .939 r
.7433 .53079 .75034 .53798 .76616 .53233 .7592 .52521 Mtetra
.68 .801 .939 r
.7592 .52521 .76616 .53233 .78207 .52689 .77516 .51943 Mtetra
.682 .793 .933 r
.77516 .51943 .78207 .52689 .79816 .52259 .7912 .51358 Mtetra
.658 .745 .915 r
.7912 .51358 .79816 .52259 .81451 .52014 .80741 .50875 Mtetra
.605 .671 .887 r
.80741 .50875 .81451 .52014 .8311 .51909 .82393 .50626 Mtetra
.57 .629 .871 r
.82393 .50626 .8311 .51909 .84792 .51903 .84071 .5054 Mtetra
.548 .605 .862 r
.84071 .5054 .84792 .51903 .86475 .51769 .85774 .50561 Mtetra
.581 .65 .883 r
.85774 .50561 .86475 .51769 .88144 .51381 .87474 .50413 Mtetra
.641 .73 .913 r
.87474 .50413 .88144 .51381 .89793 .5071 .89157 .49983 Mtetra
.715 .821 .931 r
.89157 .49983 .89793 .5071 .9143 .49874 .90813 .49235 Mtetra
.738 .855 .935 r
.90813 .49235 .9143 .49874 .93081 .49107 .92464 .48382 Mtetra
.717 .826 .933 r
.92464 .48382 .93081 .49107 .94755 .48455 .94132 .47619 Mtetra
.504 .746 .982 r
.33479 .6461 .3435 .65217 .35719 .6506 .34849 .64524 Mtetra
.487 .762 .992 r
.34849 .64524 .35719 .6506 .37094 .64989 .36229 .64429 Mtetra
.636 .803 .963 r
.36229 .64429 .37094 .64989 .38483 .64822 .37632 .64039 Mtetra
.719 .761 .885 r
.37632 .64039 .38483 .64822 .39891 .64352 .39054 .63352 Mtetra
.745 .723 .831 r
.39054 .63352 .39891 .64352 .41316 .63612 .40489 .62423 Mtetra
.724 .688 .815 r
.40489 .62423 .41316 .63612 .42749 .62706 .41925 .6157 Mtetra
.7 .689 .836 r
.41925 .6157 .42749 .62706 .44184 .61902 .43361 .60896 Mtetra
.654 .699 .879 r
.43361 .60896 .44184 .61902 .4562 .61255 .44796 .6048 Mtetra
.618 .742 .935 r
.44796 .6048 .4562 .61255 .47058 .60834 .46236 .60174 Mtetra
.613 .774 .958 r
.46236 .60174 .47058 .60834 .48503 .60512 .47686 .59853 Mtetra
.621 .778 .956 r
.47686 .59853 .48503 .60512 .49956 .60185 .49145 .59508 Mtetra
.647 .781 .945 r
.49145 .59508 .49956 .60185 .51417 .59839 .50612 .59089 Mtetra
.654 .764 .93 r
.50612 .59089 .51417 .59839 .52888 .5945 .52088 .58652 Mtetra
.653 .752 .923 r
.52088 .58652 .52888 .5945 .54366 .59022 .53571 .58221 Mtetra
.651 .752 .924 r
.53571 .58221 .54366 .59022 .55852 .58584 .55063 .57796 Mtetra
.651 .757 .927 r
.55063 .57796 .55852 .58584 .57347 .58144 .56563 .57367 Mtetra
.651 .761 .93 r
.56563 .57367 .57347 .58144 .58849 .5771 .58071 .56932 Mtetra
.652 .762 .93 r
.58071 .56932 .58849 .5771 .6036 .57271 .59588 .56492 Mtetra
.653 .763 .93 r
.59588 .56492 .6036 .57271 .61879 .56827 .61113 .56044 Mtetra
.655 .764 .93 r
.61113 .56044 .61879 .56827 .63407 .56376 .62646 .55589 Mtetra
.656 .764 .929 r
.62646 .55589 .63407 .56376 .64942 .5592 .64187 .55127 Mtetra
.657 .764 .929 r
.64187 .55127 .64942 .5592 .66486 .55458 .65737 .54658 Mtetra
.658 .764 .928 r
.65737 .54658 .66486 .55458 .68038 .54991 .67295 .54183 Mtetra
.659 .764 .927 r
.67295 .54183 .68038 .54991 .69599 .5453 .68861 .53701 Mtetra
.66 .76 .924 r
.68861 .53701 .69599 .5453 .71168 .54067 .70436 .53215 Mtetra
.658 .754 .921 r
.70436 .53215 .71168 .54067 .72746 .53593 .7202 .52736 Mtetra
.656 .753 .922 r
.7202 .52736 .72746 .53593 .7433 .53079 .73613 .52262 Mtetra
.659 .766 .929 r
.73613 .52262 .7433 .53079 .7592 .52521 .75214 .51769 Mtetra
.677 .791 .935 r
.75214 .51769 .7592 .52521 .77516 .51943 .76819 .51201 Mtetra
.683 .797 .935 r
.76819 .51201 .77516 .51943 .7912 .51358 .7843 .50606 Mtetra
.686 .797 .933 r
.7843 .50606 .7912 .51358 .80741 .50875 .80048 .49995 Mtetra
.659 .755 .921 r
.80048 .49995 .80741 .50875 .82393 .50626 .81684 .49496 Mtetra
.597 .673 .893 r
.81684 .49496 .82393 .50626 .84071 .5054 .83354 .49266 Mtetra
.557 .627 .877 r
.83354 .49266 .84071 .5054 .85774 .50561 .85055 .49223 Mtetra
.541 .608 .869 r
.85055 .49223 .85774 .50561 .87474 .50413 .86779 .4926 Mtetra
.592 .669 .893 r
.86779 .4926 .87474 .50413 .89157 .49983 .88491 .49048 Mtetra
.661 .75 .916 r
.88491 .49048 .89157 .49983 .90813 .49235 .90181 .48524 Mtetra
.733 .835 .928 r
.90181 .48524 .90813 .49235 .92464 .48382 .91843 .47689 Mtetra
.735 .842 .931 r
.91843 .47689 .92464 .48382 .94132 .47619 .93511 .46842 Mtetra
.472 .74 .987 r
.32598 .64019 .33479 .6461 .34849 .64524 .3397 .63972 Mtetra
.577 .79 .98 r
.3397 .63972 .34849 .64524 .36229 .64429 .35362 .63715 Mtetra
.699 .775 .91 r
.35362 .63715 .36229 .64429 .37632 .64039 .36779 .63127 Mtetra
.75 .74 .843 r
.36779 .63127 .37632 .64039 .39054 .63352 .38214 .62211 Mtetra
.735 .699 .816 r
.38214 .62211 .39054 .63352 .40489 .62423 .39654 .61289 Mtetra
.709 .693 .833 r
.39654 .61289 .40489 .62423 .41925 .6157 .4109 .60561 Mtetra
.662 .702 .877 r
.4109 .60561 .41925 .6157 .43361 .60896 .42523 .60109 Mtetra
.616 .74 .934 r
.42523 .60109 .43361 .60896 .44796 .6048 .4396 .59809 Mtetra
.61 .771 .957 r
.4396 .59809 .44796 .6048 .46236 .60174 .45406 .59497 Mtetra
.624 .774 .953 r
.45406 .59497 .46236 .60174 .47686 .59853 .46861 .59146 Mtetra
.65 .774 .939 r
.46861 .59146 .47686 .59853 .49145 .59508 .48326 .5872 Mtetra
.655 .755 .924 r
.48326 .5872 .49145 .59508 .50612 .59089 .49799 .58282 Mtetra
.649 .75 .923 r
.49799 .58282 .50612 .59089 .52088 .58652 .5128 .57864 Mtetra
.648 .756 .928 r
.5128 .57864 .52088 .58652 .53571 .58221 .52769 .57444 Mtetra
.648 .76 .931 r
.52769 .57444 .53571 .58221 .55063 .57796 .54266 .5702 Mtetra
.65 .762 .931 r
.54266 .5702 .55063 .57796 .56563 .57367 .55771 .56589 Mtetra
.651 .763 .931 r
.55771 .56589 .56563 .57367 .58071 .56932 .57285 .56149 Mtetra
.653 .763 .93 r
.57285 .56149 .58071 .56932 .59588 .56492 .58808 .55701 Mtetra
.654 .762 .929 r
.58808 .55701 .59588 .56492 .61113 .56044 .60338 .55247 Mtetra
.655 .762 .928 r
.60338 .55247 .61113 .56044 .62646 .55589 .61877 .54787 Mtetra
.656 .762 .928 r
.61877 .54787 .62646 .55589 .64187 .55127 .63424 .54323 Mtetra
.657 .763 .928 r
.63424 .54323 .64187 .55127 .65737 .54658 .6498 .53852 Mtetra
.658 .765 .928 r
.6498 .53852 .65737 .54658 .67295 .54183 .66545 .53373 Mtetra
.66 .765 .928 r
.66545 .53373 .67295 .54183 .68861 .53701 .68117 .52885 Mtetra
.661 .765 .927 r
.68117 .52885 .68861 .53701 .70436 .53215 .69698 .52389 Mtetra
.662 .764 .926 r
.69698 .52389 .70436 .53215 .7202 .52736 .71287 .51888 Mtetra
.662 .76 .923 r
.71287 .51888 .7202 .52736 .73613 .52262 .72885 .51386 Mtetra
.657 .752 .921 r
.72885 .51386 .73613 .52262 .75214 .51769 .74494 .50903 Mtetra
.659 .757 .922 r
.74494 .50903 .75214 .51769 .76819 .51201 .76111 .50408 Mtetra
.676 .783 .93 r
.76111 .50408 .76819 .51201 .7843 .50606 .77731 .49835 Mtetra
.686 .794 .932 r
.77731 .49835 .7843 .50606 .80048 .49995 .79356 .49221 Mtetra
.688 .795 .931 r
.79356 .49221 .80048 .49995 .81684 .49496 .80989 .48594 Mtetra
.65 .749 .922 r
.80989 .48594 .81684 .49496 .83354 .49266 .82644 .48123 Mtetra
.584 .667 .896 r
.82644 .48123 .83354 .49266 .85055 .49223 .84337 .47939 Mtetra
.539 .619 .88 r
.84337 .47939 .85055 .49223 .86779 .4926 .86063 .47959 Mtetra
.541 .617 .878 r
.86063 .47959 .86779 .4926 .88491 .49048 .87805 .47976 Mtetra
.615 .7 .905 r
.87805 .47976 .88491 .49048 .90181 .48524 .89524 .47649 Mtetra
.694 .781 .918 r
.89524 .47649 .90181 .48524 .91843 .47689 .91214 .46975 Mtetra
.744 .842 .924 r
.91214 .46975 .91843 .47689 .93511 .46842 .92885 .46078 Mtetra
.497 .759 .989 r
.31706 .6345 .32598 .64019 .3397 .63972 .33085 .63345 Mtetra
.666 .793 .942 r
.33085 .63345 .3397 .63972 .35362 .63715 .34493 .62877 Mtetra
.739 .754 .865 r
.34493 .62877 .35362 .63715 .36779 .63127 .35925 .62061 Mtetra
.749 .714 .82 r
.35925 .62061 .36779 .63127 .38214 .62211 .37368 .61072 Mtetra
.72 .696 .827 r
.37368 .61072 .38214 .62211 .39654 .61289 .38807 .60267 Mtetra
.679 .706 .867 r
.38807 .60267 .39654 .61289 .4109 .60561 .40241 .59728 Mtetra
.621 .73 .925 r
.40241 .59728 .4109 .60561 .42523 .60109 .41674 .59417 Mtetra
.606 .765 .955 r
.41674 .59417 .42523 .60109 .4396 .59809 .43116 .59118 Mtetra
.621 .77 .952 r
.43116 .59118 .4396 .59809 .45406 .59497 .44568 .58776 Mtetra
.65 .771 .937 r
.44568 .58776 .45406 .59497 .46861 .59146 .4603 .58347 Mtetra
.653 .753 .923 r
.4603 .58347 .46861 .59146 .48326 .5872 .47499 .57914 Mtetra
.647 .751 .925 r
.47499 .57914 .48326 .5872 .49799 .58282 .48977 .575 Mtetra
.646 .758 .93 r
.48977 .575 .49799 .58282 .5128 .57864 .50463 .57085 Mtetra
.647 .76 .931 r
.50463 .57085 .5128 .57864 .52769 .57444 .51957 .56663 Mtetra
.65 .761 .93 r
.51957 .56663 .52769 .57444 .54266 .5702 .5346 .56228 Mtetra
.656 .761 .927 r
.5346 .56228 .54266 .5702 .55771 .56589 .54971 .55771 Mtetra
.658 .756 .923 r
.54971 .55771 .55771 .56589 .57285 .56149 .5649 .55306 Mtetra
.658 .751 .919 r
.5649 .55306 .57285 .56149 .58808 .55701 .58018 .5484 Mtetra
.657 .748 .917 r
.58018 .5484 .58808 .55701 .60338 .55247 .59554 .54375 Mtetra
.656 .746 .916 r
.59554 .54375 .60338 .55247 .61877 .54787 .61099 .53911 Mtetra
.655 .746 .916 r
.61099 .53911 .61877 .54787 .63424 .54323 .62652 .53448 Mtetra
.654 .747 .918 r
.62652 .53448 .63424 .54323 .6498 .53852 .64214 .52985 Mtetra
.654 .75 .921 r
.64214 .52985 .6498 .53852 .66545 .53373 .65785 .52522 Mtetra
.655 .756 .924 r
.65785 .52522 .66545 .53373 .68117 .52885 .67364 .5205 Mtetra
.66 .762 .926 r
.67364 .5205 .68117 .52885 .69698 .52389 .68952 .51556 Mtetra
.662 .765 .926 r
.68952 .51556 .69698 .52389 .71287 .51888 .70548 .51048 Mtetra
.663 .765 .925 r
.70548 .51048 .71287 .51888 .72885 .51386 .72152 .50534 Mtetra
.663 .763 .924 r
.72152 .50534 .72885 .51386 .74494 .50903 .73765 .50017 Mtetra
.658 .754 .921 r
.73765 .50017 .74494 .50903 .76111 .50408 .75388 .4952 Mtetra
.659 .755 .921 r
.75388 .4952 .76111 .50408 .77731 .49835 .77021 .49017 Mtetra
.679 .781 .927 r
.77021 .49017 .77731 .49835 .79356 .49221 .78656 .48425 Mtetra
.69 .792 .928 r
.78656 .48425 .79356 .49221 .80989 .48594 .80295 .47788 Mtetra
.686 .79 .929 r
.80295 .47788 .80989 .48594 .82644 .48123 .81944 .4716 Mtetra
.629 .729 .92 r
.81944 .4716 .82644 .48123 .84337 .47939 .83624 .4677 Mtetra
.564 .655 .897 r
.83624 .4677 .84337 .47939 .86063 .47959 .85343 .46658 Mtetra
.522 .609 .881 r
.85343 .46658 .86063 .47959 .87805 .47976 .87096 .4674 Mtetra
.563 .644 .888 r
.87096 .4674 .87805 .47976 .89524 .47649 .88846 .46642 Mtetra
.644 .731 .912 r
.88846 .46642 .89524 .47649 .91214 .46975 .90569 .46181 Mtetra
.731 .819 .919 r
.90569 .46181 .91214 .46975 .92885 .46078 .92256 .45335 Mtetra
.586 .78 .972 r
.30805 .62847 .31706 .6345 .33085 .63345 .32198 .62583 Mtetra
.708 .767 .898 r
.32198 .62583 .33085 .63345 .34493 .62877 .3362 .61946 Mtetra
.757 .74 .836 r
.3362 .61946 .34493 .62877 .35925 .62061 .35065 .60958 Mtetra
.738 .707 .822 r
.35065 .60958 .35925 .62061 .37368 .61072 .3651 .60033 Mtetra
.705 .711 .853 r
.3651 .60033 .37368 .61072 .38807 .60267 .37948 .59354 Mtetra
.636 .717 .906 r
.37948 .59354 .38807 .60267 .40241 .59728 .3938 .59 Mtetra
.603 .755 .951 r
.3938 .59 .40241 .59728 .41674 .59417 .40817 .58715 Mtetra
.612 .766 .953 r
.40817 .58715 .41674 .59417 .43116 .59118 .42264 .58397 Mtetra
.648 .772 .939 r
.42264 .58397 .43116 .59118 .44568 .58776 .43723 .57974 Mtetra
.653 .753 .923 r
.43723 .57974 .44568 .58776 .4603 .58347 .45189 .57539 Mtetra
.646 .751 .925 r
.45189 .57539 .4603 .58347 .47499 .57914 .46664 .57126 Mtetra
.645 .757 .93 r
.46664 .57126 .47499 .57914 .48977 .575 .48147 .56714 Mtetra
.647 .759 .931 r
.48147 .56714 .48977 .575 .50463 .57085 .49638 .56292 Mtetra
.654 .76 .928 r
.49638 .56292 .50463 .57085 .51957 .56663 .51138 .55841 Mtetra
.66 .756 .921 r
.51138 .55841 .51957 .56663 .5346 .56228 .52646 .55369 Mtetra
.66 .748 .915 r
.52646 .55369 .5346 .56228 .54971 .55771 .54162 .54897 Mtetra
.657 .744 .915 r
.54162 .54897 .54971 .55771 .5649 .55306 .55687 .54434 Mtetra
.656 .746 .916 r
.55687 .54434 .5649 .55306 .58018 .5484 .5722 .53973 Mtetra
.656 .748 .918 r
.5722 .53973 .58018 .5484 .59554 .54375 .58762 .53508 Mtetra
.656 .749 .919 r
.58762 .53508 .59554 .54375 .61099 .53911 .60312 .53039 Mtetra
.656 .75 .919 r
.60312 .53039 .61099 .53911 .62652 .53448 .61871 .52566 Mtetra
.657 .748 .918 r
.61871 .52566 .62652 .53448 .64214 .52985 .63439 .52089 Mtetra
.656 .746 .916 r
.63439 .52089 .64214 .52985 .65785 .52522 .65015 .51614 Mtetra
.653 .743 .916 r
.65015 .51614 .65785 .52522 .67364 .5205 .66601 .51148 Mtetra
.652 .746 .918 r
.66601 .51148 .67364 .5205 .68952 .51556 .68196 .50682 Mtetra
.656 .755 .923 r
.68196 .50682 .68952 .51556 .70548 .51048 .698 .50194 Mtetra
.663 .763 .925 r
.698 .50194 .70548 .51048 .72152 .50534 .71411 .49677 Mtetra
.665 .765 .924 r
.71411 .49677 .72152 .50534 .73765 .50017 .7303 .49149 Mtetra
.664 .763 .923 r
.7303 .49149 .73765 .50017 .75388 .4952 .74659 .4862 Mtetra
.658 .754 .921 r
.74659 .4862 .75388 .4952 .77021 .49017 .76298 .48115 Mtetra
.66 .756 .921 r
.76298 .48115 .77021 .49017 .78656 .48425 .77946 .47597 Mtetra
.686 .785 .926 r
.77946 .47597 .78656 .48425 .80295 .47788 .79594 .46969 Mtetra
.694 .791 .925 r
.79594 .46969 .80295 .47788 .81944 .4716 .81248 .46306 Mtetra
.676 .777 .927 r
.81248 .46306 .81944 .4716 .83624 .4677 .82916 .45714 Mtetra
.594 .696 .914 r
.82916 .45714 .83624 .4677 .85343 .46658 .84627 .4546 Mtetra
.532 .636 .899 r
.84627 .4546 .85343 .46658 .87096 .4674 .86378 .45463 Mtetra
.52 .616 .888 r
.86378 .45463 .87096 .4674 .88846 .46642 .88152 .45536 Mtetra
.604 .694 .906 r
.88152 .45536 .88846 .46642 .90569 .46181 .899 .45242 Mtetra
.693 .771 .911 r
.899 .45242 .90569 .46181 .92256 .45335 .91615 .44554 Mtetra
.656 .784 .942 r
.29899 .62188 .30805 .62847 .32198 .62583 .31307 .61747 Mtetra
.741 .757 .865 r
.31307 .61747 .32198 .62583 .3362 .61946 .32744 .60913 Mtetra
.755 .723 .822 r
.32744 .60913 .3362 .61946 .35065 .60958 .34197 .59885 Mtetra
.725 .711 .836 r
.34197 .59885 .35065 .60958 .3651 .60033 .35641 .59066 Mtetra
.67 .716 .884 r
.35641 .59066 .3651 .60033 .37948 .59354 .37075 .58573 Mtetra
.607 .743 .941 r
.37075 .58573 .37948 .59354 .3938 .59 .38508 .58287 Mtetra
.605 .762 .954 r
.38508 .58287 .3938 .59 .40817 .58715 .39951 .57987 Mtetra
.637 .768 .942 r
.39951 .57987 .40817 .58715 .42264 .58397 .41405 .57597 Mtetra
.655 .755 .924 r
.41405 .57597 .42264 .58397 .43723 .57974 .42869 .57155 Mtetra
.646 .749 .924 r
.42869 .57155 .43723 .57974 .45189 .57539 .4434 .56743 Mtetra
.644 .755 .93 r
.4434 .56743 .45189 .57539 .46664 .57126 .4582 .56333 Mtetra
.646 .758 .93 r
.4582 .56333 .46664 .57126 .48147 .56714 .47308 .55911 Mtetra
.657 .759 .925 r
.47308 .55911 .48147 .56714 .49638 .56292 .48805 .5545 Mtetra
.661 .752 .918 r
.48805 .5545 .49638 .56292 .51138 .55841 .50311 .54971 Mtetra
.657 .745 .915 r
.50311 .54971 .51138 .55841 .52646 .55369 .51824 .54506 Mtetra
.654 .747 .918 r
.51824 .54506 .52646 .55369 .54162 .54897 .53346 .54051 Mtetra
.653 .752 .922 r
.53346 .54051 .54162 .54897 .55687 .54434 .54876 .53595 Mtetra
.653 .755 .925 r
.54876 .53595 .55687 .54434 .5722 .53973 .56415 .53136 Mtetra
.654 .757 .926 r
.56415 .53136 .5722 .53973 .58762 .53508 .57963 .52671 Mtetra
.655 .759 .926 r
.57963 .52671 .58762 .53508 .60312 .53039 .59519 .52197 Mtetra
.657 .759 .925 r
.59519 .52197 .60312 .53039 .61871 .52566 .61084 .51715 Mtetra
.658 .759 .924 r
.61084 .51715 .61871 .52566 .63439 .52089 .62657 .51226 Mtetra
.658 .757 .923 r
.62657 .51226 .63439 .52089 .65015 .51614 .64239 .50734 Mtetra
.658 .754 .921 r
.64239 .50734 .65015 .51614 .66601 .51148 .65831 .50241 Mtetra
.655 .748 .918 r
.65831 .50241 .66601 .51148 .68196 .50682 .67431 .49758 Mtetra
.651 .743 .917 r
.67431 .49758 .68196 .50682 .698 .50194 .69042 .49289 Mtetra
.654 .75 .92 r
.69042 .49289 .698 .50194 .71411 .49677 .70661 .48801 Mtetra
.664 .762 .923 r
.70661 .48801 .71411 .49677 .7303 .49149 .72287 .48273 Mtetra
.666 .764 .923 r
.72287 .48273 .7303 .49149 .74659 .4862 .73922 .47733 Mtetra
.665 .762 .923 r
.73922 .47733 .74659 .4862 .76298 .48115 .75566 .47194 Mtetra
.657 .752 .92 r
.75566 .47194 .76298 .48115 .77946 .47597 .77222 .46685 Mtetra
.669 .76 .919 r
.77222 .46685 .77946 .47597 .79594 .46969 .78883 .46123 Mtetra
.691 .786 .923 r
.78883 .46123 .79594 .46969 .81248 .46306 .80545 .45466 Mtetra
.694 .79 .924 r
.80545 .45466 .81248 .46306 .82916 .45714 .82215 .44793 Mtetra
.641 .751 .928 r
.82215 .44793 .82916 .45714 .84627 .4546 .83913 .44334 Mtetra
.558 .667 .91 r
.83913 .44334 .84627 .4546 .86378 .45463 .85657 .44216 Mtetra
.506 .616 .895 r
.85657 .44216 .86378 .45463 .88152 .45536 .8744 .4432 Mtetra
.557 .65 .897 r
.8744 .4432 .88152 .45536 .899 .45242 .89217 .44222 Mtetra
.652 .738 .913 r
.89217 .44222 .899 .45242 .91615 .44554 .9096 .43711 Mtetra
.695 .771 .909 r
.28988 .6144 .29899 .62188 .31307 .61747 .30409 .60856 Mtetra
.76 .75 .843 r
.30409 .60856 .31307 .61747 .32744 .60913 .31861 .59869 Mtetra
.749 .721 .827 r
.31861 .59869 .32744 .60913 .34197 .59885 .33316 .58889 Mtetra
.712 .723 .858 r
.33316 .58889 .34197 .59885 .35641 .59066 .3476 .58177 Mtetra
.631 .725 .915 r
.3476 .58177 .35641 .59066 .37075 .58573 .36192 .57829 Mtetra
.6 .752 .951 r
.36192 .57829 .37075 .58573 .38508 .58287 .37629 .57549 Mtetra
.619 .761 .947 r
.37629 .57549 .38508 .58287 .39951 .57987 .39077 .57212 Mtetra
.653 .762 .929 r
.39077 .57212 .39951 .57987 .41405 .57597 .40538 .56772 Mtetra
.648 .749 .923 r
.40538 .56772 .41405 .57597 .42869 .57155 .42006 .56349 Mtetra
.643 .754 .929 r
.42006 .56349 .42869 .57155 .4434 .56743 .43483 .5594 Mtetra
.644 .756 .93 r
.43483 .5594 .4434 .56743 .4582 .56333 .44967 .55522 Mtetra
.656 .758 .925 r
.44967 .55522 .4582 .56333 .47308 .55911 .46461 .55062 Mtetra
.662 .752 .917 r
.46461 .55062 .47308 .55911 .48805 .5545 .47964 .54578 Mtetra
.656 .745 .916 r
.47964 .54578 .48805 .5545 .50311 .54971 .49474 .54118 Mtetra
.652 .75 .921 r
.49474 .54118 .50311 .54971 .51824 .54506 .50993 .53667 Mtetra
.65 .754 .926 r
.50993 .53667 .51824 .54506 .53346 .54051 .52521 .53221 Mtetra
.65 .757 .928 r
.52521 .53221 .53346 .54051 .54876 .53595 .54057 .52767 Mtetra
.653 .76 .928 r
.54057 .52767 .54876 .53595 .56415 .53136 .55601 .52303 Mtetra
.654 .76 .928 r
.55601 .52303 .56415 .53136 .57963 .52671 .57155 .51831 Mtetra
.655 .76 .927 r
.57155 .51831 .57963 .52671 .59519 .52197 .58717 .51352 Mtetra
.656 .76 .926 r
.58717 .51352 .59519 .52197 .61084 .51715 .60288 .50867 Mtetra
.658 .761 .926 r
.60288 .50867 .61084 .51715 .62657 .51226 .61868 .50374 Mtetra
.66 .762 .926 r
.61868 .50374 .62657 .51226 .64239 .50734 .63456 .49869 Mtetra
.661 .761 .924 r
.63456 .49869 .64239 .50734 .65831 .50241 .65053 .49358 Mtetra
.659 .757 .922 r
.65053 .49358 .65831 .50241 .67431 .49758 .66659 .4885 Mtetra
.657 .751 .92 r
.66659 .4885 .67431 .49758 .69042 .49289 .68275 .48352 Mtetra
.65 .743 .918 r
.68275 .48352 .69042 .49289 .70661 .48801 .69901 .47878 Mtetra
.655 .75 .919 r
.69901 .47878 .70661 .48801 .72287 .48273 .71536 .4738 Mtetra
.665 .762 .922 r
.71536 .4738 .72287 .48273 .73922 .47733 .73178 .46837 Mtetra
.667 .763 .922 r
.73178 .46837 .73922 .47733 .75566 .47194 .74828 .46285 Mtetra
.663 .76 .922 r
.74828 .46285 .75566 .47194 .77222 .46685 .76489 .45747 Mtetra
.658 .752 .919 r
.76489 .45747 .77222 .46685 .78883 .46123 .78161 .45226 Mtetra
.683 .773 .919 r
.78161 .45226 .78883 .46123 .80545 .45466 .79834 .44597 Mtetra
.696 .786 .92 r
.79834 .44597 .80545 .45466 .82215 .44793 .8151 .43907 Mtetra
.679 .777 .924 r
.8151 .43907 .82215 .44793 .83913 .44334 .83201 .43288 Mtetra
.585 .7 .922 r
.83201 .43288 .83913 .44334 .85657 .44216 .84939 .43048 Mtetra
.513 .638 .91 r
.84939 .43048 .85657 .44216 .8744 .4432 .86721 .4309 Mtetra
.516 .628 .9 r
.86721 .4309 .8744 .4432 .89217 .44222 .8852 .43143 Mtetra
.618 .712 .913 r
.8852 .43143 .89217 .44222 .9096 .43711 .90288 .42772 Mtetra
.723 .763 .884 r
.28071 .60634 .28988 .6144 .30409 .60856 .29507 .59907 Mtetra
.765 .741 .831 r
.29507 .59907 .30409 .60856 .31861 .59869 .30969 .58845 Mtetra
.74 .725 .837 r
.30969 .58845 .31861 .59869 .33316 .58889 .32425 .5794 Mtetra
.685 .727 .882 r
.32425 .5794 .33316 .58889 .3476 .58177 .33865 .57373 Mtetra
.607 .74 .939 r
.33865 .57373 .3476 .58177 .36192 .57829 .35298 .57082 Mtetra
.603 .755 .951 r
.35298 .57082 .36192 .57829 .37629 .57549 .3674 .56787 Mtetra
.638 .762 .938 r
.3674 .56787 .37629 .57549 .39077 .57212 .38196 .56391 Mtetra
.653 .752 .923 r
.38196 .56391 .39077 .57212 .40538 .56772 .39662 .55948 Mtetra
.644 .75 .926 r
.39662 .55948 .40538 .56772 .42006 .56349 .41135 .55536 Mtetra
.642 .753 .93 r
.41135 .55536 .42006 .56349 .43483 .5594 .42616 .55124 Mtetra
.651 .757 .927 r
.42616 .55124 .43483 .5594 .44967 .55522 .44107 .54678 Mtetra
.663 .754 .918 r
.44107 .54678 .44967 .55522 .46461 .55062 .45606 .5419 Mtetra
.656 .747 .916 r
.45606 .5419 .46461 .55062 .47964 .54578 .47114 .53724 Mtetra
.651 .75 .923 r
.47114 .53724 .47964 .54578 .49474 .54118 .4863 .53275 Mtetra
.647 .753 .927 r
.4863 .53275 .49474 .54118 .50993 .53667 .50154 .52834 Mtetra
.65 .758 .928 r
.50154 .52834 .50993 .53667 .52521 .53221 .51687 .5238 Mtetra
.659 .76 .924 r
.51687 .5238 .52521 .53221 .54057 .52767 .53229 .51891 Mtetra
.659 .752 .919 r
.53229 .51891 .54057 .52767 .55601 .52303 .54779 .51399 Mtetra
.658 .747 .915 r
.54779 .51399 .55601 .52303 .57155 .51831 .56338 .50911 Mtetra
.656 .743 .914 r
.56338 .50911 .57155 .51831 .58717 .51352 .57906 .50427 Mtetra
.654 .743 .915 r
.57906 .50427 .58717 .51352 .60288 .50867 .59483 .49948 Mtetra
.653 .745 .917 r
.59483 .49948 .60288 .50867 .61868 .50374 .61069 .49473 Mtetra
.652 .75 .921 r
.61069 .49473 .61868 .50374 .63456 .49869 .62664 .48994 Mtetra
.66 .76 .924 r
.62664 .48994 .63456 .49869 .65053 .49358 .64268 .48481 Mtetra
.663 .762 .924 r
.64268 .48481 .65053 .49358 .66659 .4885 .6588 .47953 Mtetra
.661 .758 .922 r
.6588 .47953 .66659 .4885 .68275 .48352 .67501 .47433 Mtetra
.656 .752 .921 r
.67501 .47433 .68275 .48352 .69901 .47878 .69133 .4693 Mtetra
.649 .744 .919 r
.69133 .4693 .69901 .47878 .71536 .4738 .70775 .4645 Mtetra
.659 .753 .92 r
.70775 .4645 .71536 .4738 .73178 .46837 .72425 .45927 Mtetra
.667 .762 .921 r
.72425 .45927 .73178 .46837 .74828 .46285 .74082 .45367 Mtetra
.667 .761 .921 r
.74082 .45367 .74828 .46285 .76489 .45747 .75749 .44808 Mtetra
.658 .754 .921 r
.75749 .44808 .76489 .45747 .78161 .45226 .77428 .44279 Mtetra
.669 .758 .917 r
.77428 .44279 .78161 .45226 .79834 .44597 .79112 .43702 Mtetra
.694 .781 .918 r
.79112 .43702 .79834 .44597 .8151 .43907 .80797 .43018 Mtetra
.694 .784 .92 r
.80797 .43018 .8151 .43907 .83201 .43288 .8249 .42328 Mtetra
.623 .74 .931 r
.8249 .42328 .83201 .43288 .84939 .43048 .8422 .41927 Mtetra
.532 .66 .918 r
.8422 .41927 .84939 .43048 .86721 .4309 .85999 .4188 Mtetra
.492 .621 .907 r
.85999 .4188 .86721 .4309 .8852 .43143 .87811 .41999 Mtetra
.583 .684 .91 r
.87811 .41999 .8852 .43143 .90288 .42772 .89602 .41769 Mtetra
.744 .76 .866 r
.27148 .59795 .28071 .60634 .29507 .59907 .28598 .58938 Mtetra
.765 .739 .829 r
.28598 .58938 .29507 .59907 .30969 .58845 .30066 .57867 Mtetra
.732 .733 .851 r
.30066 .57867 .30969 .58845 .32425 .5794 .31522 .57032 Mtetra
.656 .73 .904 r
.31522 .57032 .32425 .5794 .33865 .57373 .3296 .56585 Mtetra
.599 .744 .946 r
.3296 .56585 .33865 .57373 .35298 .57082 .34396 .56309 Mtetra
.611 .752 .945 r
.34396 .56309 .35298 .57082 .3674 .56787 .35844 .55994 Mtetra
.651 .76 .929 r
.35844 .55994 .3674 .56787 .38196 .56391 .37306 .55554 Mtetra
.648 .749 .923 r
.37306 .55554 .38196 .56391 .39662 .55948 .38776 .55124 Mtetra
.642 .752 .929 r
.38776 .55124 .39662 .55948 .41135 .55536 .40254 .54713 Mtetra
.644 .754 .929 r
.40254 .54713 .41135 .55536 .42616 .55124 .41741 .5429 Mtetra
.661 .757 .921 r
.41741 .5429 .42616 .55124 .44107 .54678 .43237 .53807 Mtetra
.66 .749 .916 r
.43237 .53807 .44107 .54678 .45606 .5419 .44742 .53325 Mtetra
.651 .749 .921 r
.44742 .53325 .45606 .5419 .47114 .53724 .46255 .52873 Mtetra
.646 .752 .926 r
.46255 .52873 .47114 .53724 .4863 .53275 .47776 .52434 Mtetra
.651 .757 .927 r
.47776 .52434 .4863 .53275 .50154 .52834 .49306 .51975 Mtetra
.662 .757 .921 r
.49306 .51975 .50154 .52834 .51687 .5238 .50844 .51473 Mtetra
.662 .747 .913 r
.50844 .51473 .51687 .5238 .53229 .51891 .52392 .50971 Mtetra
.657 .744 .914 r
.52392 .50971 .53229 .51891 .54779 .51399 .53948 .50484 Mtetra
.656 .745 .916 r
.53948 .50484 .54779 .51399 .56338 .50911 .55512 .49998 Mtetra
.656 .747 .917 r
.55512 .49998 .56338 .50911 .57906 .50427 .57086 .49509 Mtetra
.57086 .49509 .57906 .50427 .59483 .49948 .58669 .49017 Mtetra
.655 .745 .916 r
.58669 .49017 .59483 .49948 .61069 .49473 .60261 .48527 Mtetra
.651 .741 .916 r
.60261 .48527 .61069 .49473 .62664 .48994 .61862 .48051 Mtetra
.65 .743 .918 r
.61862 .48051 .62664 .48994 .64268 .48481 .63473 .47575 Mtetra
.66 .756 .922 r
.63473 .47575 .64268 .48481 .6588 .47953 .65092 .47057 Mtetra
.664 .761 .922 r
.65092 .47057 .6588 .47953 .67501 .47433 .6672 .46516 Mtetra
.66 .756 .921 r
.6672 .46516 .67501 .47433 .69133 .4693 .68357 .45989 Mtetra
.652 .749 .921 r
.68357 .45989 .69133 .4693 .70775 .4645 .70005 .45492 Mtetra
.651 .746 .919 r
.70005 .45492 .70775 .4645 .72425 .45927 .71664 .44996 Mtetra
.666 .759 .92 r
.71664 .44996 .72425 .45927 .74082 .45367 .73328 .44438 Mtetra
.668 .761 .92 r
.73328 .44438 .74082 .45367 .75749 .44808 .75002 .43867 Mtetra
.663 .758 .921 r
.75002 .43867 .75749 .44808 .77428 .44279 .76686 .43314 Mtetra
.66 .753 .919 r
.76686 .43314 .77428 .44279 .79112 .43702 .78381 .42772 Mtetra
.69 .774 .915 r
.78381 .42772 .79112 .43702 .80797 .43018 .80075 .42099 Mtetra
.698 .781 .915 r
.80075 .42099 .80797 .43018 .8249 .42328 .81774 .41384 Mtetra
.656 .76 .926 r
.81774 .41384 .8249 .42328 .8422 .41927 .83498 .40846 Mtetra
.551 .681 .925 r
.83498 .40846 .8422 .41927 .85999 .4188 .85275 .40714 Mtetra
.483 .628 .916 r
.85275 .40714 .85999 .4188 .87811 .41999 .87093 .40833 Mtetra
.548 .664 .913 r
.87093 .40833 .87811 .41999 .89602 .41769 .88905 .40729 Mtetra
.757 .759 .854 r
.26216 .58938 .27148 .59795 .28598 .58938 .27678 .57982 Mtetra
.763 .742 .834 r
.27678 .57982 .28598 .58938 .30066 .57867 .2915 .56931 Mtetra
.724 .741 .865 r
.2915 .56931 .30066 .57867 .31522 .57032 .30608 .56157 Mtetra
.631 .733 .921 r
.30608 .56157 .31522 .57032 .3296 .56585 .32045 .55796 Mtetra
.598 .745 .947 r
.32045 .55796 .3296 .56585 .34396 .56309 .33486 .55517 Mtetra
.623 .753 .94 r
.33486 .55517 .34396 .56309 .35844 .55994 .3494 .55163 Mtetra
.655 .753 .922 r
.3494 .55163 .35844 .55994 .37306 .55554 .36408 .54708 Mtetra
.644 .748 .925 r
.36408 .54708 .37306 .55554 .38776 .55124 .37882 .5429 Mtetra
.641 .751 .928 r
.37882 .5429 .38776 .55124 .40254 .54713 .39365 .53876 Mtetra
.65 .754 .925 r
.39365 .53876 .40254 .54713 .41741 .5429 .40857 .53427 Mtetra
.664 .753 .917 r
.40857 .53427 .41741 .5429 .43237 .53807 .42359 .52928 Mtetra
.654 .748 .918 r
.42359 .52928 .43237 .53807 .44742 .53325 .43869 .52463 Mtetra
.647 .751 .925 r
.43869 .52463 .44742 .53325 .46255 .52873 .45386 .52021 Mtetra
.647 .754 .927 r
.45386 .52021 .46255 .52873 .47776 .52434 .46913 .51573 Mtetra
.663 .758 .921 r
.46913 .51573 .47776 .52434 .49306 .51975 .48449 .51067 Mtetra
.662 .748 .914 r
.48449 .51067 .49306 .51975 .50844 .51473 .49993 .5056 Mtetra
.656 .746 .916 r
.49993 .5056 .50844 .51473 .52392 .50971 .51546 .50074 Mtetra
.653 .75 .921 r
.51546 .50074 .52392 .50971 .53948 .50484 .53108 .49599 Mtetra
.651 .753 .924 r
.53108 .49599 .53948 .50484 .55512 .49998 .54679 .49124 Mtetra
.655 .759 .926 r
.54679 .49124 .55512 .49998 .57086 .49509 .56259 .4863 Mtetra
.66 .76 .924 r
.56259 .4863 .57086 .49509 .58669 .49017 .57847 .48117 Mtetra
.659 .756 .922 r
.57847 .48117 .58669 .49017 .60261 .48527 .59445 .47604 Mtetra
.656 .751 .92 r
.59445 .47604 .60261 .48527 .61862 .48051 .61052 .47102 Mtetra
.65 .744 .918 r
.61052 .47102 .61862 .48051 .63473 .47575 .62669 .4662 Mtetra
.649 .743 .918 r
.62669 .4662 .63473 .47575 .65092 .47057 .64296 .46139 Mtetra
.663 .758 .921 r
.64296 .46139 .65092 .47057 .6672 .46516 .6593 .45597 Mtetra
.664 .759 .921 r
.6593 .45597 .6672 .46516 .68357 .45989 .67573 .4505 Mtetra
.658 .754 .921 r
.67573 .4505 .68357 .45989 .70005 .45492 .69227 .44525 Mtetra
.648 .745 .92 r
.69227 .44525 .70005 .45492 .71664 .44996 .70893 .44035 Mtetra
.661 .752 .918 r
.70893 .44035 .71664 .44996 .73328 .44438 .72566 .43492 Mtetra
.668 .76 .919 r
.72566 .43492 .73328 .44438 .75002 .43867 .74246 .42914 Mtetra
.667 .759 .919 r
.74246 .42914 .75002 .43867 .76686 .43314 .75936 .42339 Mtetra
.657 .752 .92 r
.75936 .42339 .76686 .43314 .78381 .42772 .77639 .41801 Mtetra
.681 .763 .913 r
.77639 .41801 .78381 .42772 .80075 .42099 .79343 .41158 Mtetra
.698 .778 .913 r
.79343 .41158 .80075 .42099 .81774 .41384 .8105 .40436 Mtetra
.679 .77 .92 r
.8105 .40436 .81774 .41384 .83498 .40846 .82773 .39797 Mtetra
.568 .7 .93 r
.82773 .39797 .83498 .40846 .85275 .40714 .84549 .39591 Mtetra
.485 .641 .925 r
.84549 .39591 .85275 .40714 .87093 .40833 .86371 .39677 Mtetra
.518 .653 .919 r
.86371 .39677 .87093 .40833 .88905 .40729 .882 .39665 Mtetra
.766 .76 .848 r
.25275 .58072 .26216 .58938 .27678 .57982 .26748 .57048 Mtetra
.761 .748 .84 r
.26748 .57048 .27678 .57982 .2915 .56931 .28224 .56022 Mtetra
.712 .746 .878 r
.28224 .56022 .2915 .56931 .30608 .56157 .29681 .55317 Mtetra
.616 .739 .934 r
.29681 .55317 .30608 .56157 .32045 .55796 .3112 .54992 Mtetra
.6 .744 .945 r
.3112 .54992 .32045 .55796 .33486 .55517 .32566 .54704 Mtetra
.633 .753 .934 r
.32566 .54704 .33486 .55517 .3494 .55163 .34027 .54316 Mtetra
.653 .751 .922 r
.34027 .54316 .3494 .55163 .36408 .54708 .35499 .53862 Mtetra
.642 .75 .927 r
.35499 .53862 .36408 .54708 .37882 .5429 .36978 .53443 Mtetra
.642 .75 .928 r
.36978 .53443 .37882 .5429 .39365 .53876 .38466 .53023 Mtetra
.656 .754 .922 r
.38466 .53023 .39365 .53876 .40857 .53427 .39965 .52549 Mtetra
.662 .751 .916 r
.39965 .52549 .40857 .53427 .42359 .52928 .41472 .52053 Mtetra
.651 .749 .922 r
.41472 .52053 .42359 .52928 .43869 .52463 .42986 .51595 Mtetra
.645 .75 .926 r
.42986 .51595 .43869 .52463 .45386 .52021 .44509 .51155 Mtetra
.656 .755 .923 r
.44509 .51155 .45386 .52021 .46913 .51573 .46042 .50672 Mtetra
.665 .751 .914 r
.46042 .50672 .46913 .51573 .48449 .51067 .47583 .50152 Mtetra
.657 .747 .916 r
.47583 .50152 .48449 .51067 .49993 .5056 .49133 .49661 Mtetra
.648 .749 .923 r
.49133 .49661 .49993 .5056 .51546 .50074 .50692 .492 Mtetra
.646 .755 .929 r
.50692 .492 .51546 .50074 .53108 .49599 .52259 .48742 Mtetra
.652 .763 .93 r
.52259 .48742 .53108 .49599 .54679 .49124 .53836 .48257 Mtetra
.655 .762 .928 r
.53836 .48257 .54679 .49124 .56259 .4863 .55422 .47757 Mtetra
.658 .763 .927 r
.55422 .47757 .56259 .4863 .57847 .48117 .57017 .47245 Mtetra
.665 .767 .926 r
.57017 .47245 .57847 .48117 .59445 .47604 .58621 .46704 Mtetra
.663 .761 .923 r
.58621 .46704 .59445 .47604 .61052 .47102 .60233 .46166 Mtetra
.655 .751 .92 r
.60233 .46166 .61052 .47102 .62669 .4662 .61856 .45658 Mtetra
.647 .743 .919 r
.61856 .45658 .62669 .4662 .64296 .46139 .63489 .4518 Mtetra
.656 .748 .918 r
.63489 .4518 .64296 .46139 .6593 .45597 .65131 .44663 Mtetra
.666 .759 .92 r
.65131 .44663 .6593 .45597 .67573 .4505 .66781 .44103 Mtetra
.661 .755 .92 r
.66781 .44103 .67573 .4505 .69227 .44525 .68441 .4356 Mtetra
.65 .749 .922 r
.68441 .4356 .69227 .44525 .70893 .44035 .70113 .43057 Mtetra
.655 .749 .919 r
.70113 .43057 .70893 .44035 .72566 .43492 .71794 .4253 Mtetra
.668 .759 .918 r
.71794 .4253 .72566 .43492 .74246 .42914 .73481 .41947 Mtetra
.73481 .41947 .74246 .42914 .75936 .42339 .75178 .41362 Mtetra
.658 .754 .921 r
.75178 .41362 .75936 .42339 .77639 .41801 .76888 .40813 Mtetra
.674 .759 .915 r
.76888 .40813 .77639 .41801 .79343 .41158 .78602 .40193 Mtetra
.697 .774 .911 r
.78602 .40193 .79343 .41158 .8105 .40436 .80318 .39471 Mtetra
.688 .773 .916 r
.80318 .39471 .8105 .40436 .82773 .39797 .82045 .38783 Mtetra
.587 .72 .935 r
.82045 .38783 .82773 .39797 .84549 .39591 .8382 .38493 Mtetra
.49 .653 .931 r
.8382 .38493 .84549 .39591 .86371 .39677 .85644 .38541 Mtetra
.494 .647 .926 r
.85644 .38541 .86371 .39677 .882 .39665 .87486 .38591 Mtetra
.771 .762 .845 r
.24323 .57208 .25275 .58072 .26748 .57048 .25806 .5614 Mtetra
.76 .754 .847 r
.25806 .5614 .26748 .57048 .28224 .56022 .27286 .55133 Mtetra
.703 .751 .889 r
.27286 .55133 .28224 .56022 .29681 .55317 .28745 .54475 Mtetra
.608 .738 .937 r
.28745 .54475 .29681 .55317 .3112 .54992 .30187 .54168 Mtetra
.603 .742 .942 r
.30187 .54168 .3112 .54992 .32566 .54704 .31638 .5387 Mtetra
.64 .752 .93 r
.31638 .5387 .32566 .54704 .34027 .54316 .33104 .53458 Mtetra
.651 .75 .922 r
.33104 .53458 .34027 .54316 .35499 .53862 .34582 .53006 Mtetra
.642 .749 .927 r
.34582 .53006 .35499 .53862 .36978 .53443 .36066 .52584 Mtetra
.643 .75 .927 r
.36066 .52584 .36978 .53443 .38466 .53023 .37558 .52157 Mtetra
.66 .754 .92 r
.37558 .52157 .38466 .53023 .39965 .52549 .39063 .51665 Mtetra
.659 .751 .918 r
.39063 .51665 .39965 .52549 .41472 .52053 .40575 .51172 Mtetra
.649 .75 .923 r
.40575 .51172 .41472 .52053 .42986 .51595 .42095 .50717 Mtetra
.645 .75 .926 r
.42095 .50717 .42986 .51595 .44509 .51155 .43623 .50271 Mtetra
.662 .755 .919 r
.43623 .50271 .44509 .51155 .46042 .50672 .45161 .4976 Mtetra
.663 .75 .915 r
.45161 .4976 .46042 .50672 .47583 .50152 .46709 .49245 Mtetra
.652 .749 .921 r
.46709 .49245 .47583 .50152 .49133 .49661 .48264 .48766 Mtetra
.641 .75 .927 r
.48264 .48766 .49133 .49661 .50692 .492 .49828 .48322 Mtetra
.657 .76 .926 r
.49828 .48322 .50692 .492 .52259 .48742 .51402 .47819 Mtetra
.664 .753 .916 r
.51402 .47819 .52259 .48742 .53836 .48257 .52984 .47284 Mtetra
.656 .74 .912 r
.52984 .47284 .53836 .48257 .55422 .47757 .54576 .46779 Mtetra
.648 .737 .915 r
.54576 .46779 .55422 .47757 .57017 .47245 .56177 .46305 Mtetra
.655 .75 .92 r
.56177 .46305 .57017 .47245 .58621 .46704 .57788 .458 Mtetra
.669 .764 .922 r
.57788 .458 .58621 .46704 .60233 .46166 .59406 .45234 Mtetra
.659 .755 .921 r
.59406 .45234 .60233 .46166 .61856 .45658 .61035 .44703 Mtetra
.649 .748 .922 r
.61035 .44703 .61856 .45658 .63489 .4518 .62674 .44209 Mtetra
.65 .746 .92 r
.62674 .44209 .63489 .4518 .65131 .44663 .64324 .4371 Mtetra
.666 .757 .918 r
.64324 .4371 .65131 .44663 .66781 .44103 .6598 .43145 Mtetra
.663 .756 .92 r
.6598 .43145 .66781 .44103 .68441 .4356 .67647 .42589 Mtetra
.652 .751 .922 r
.67647 .42589 .68441 .4356 .70113 .43057 .69325 .4207 Mtetra
.652 .748 .92 r
.69325 .4207 .70113 .43057 .71794 .4253 .71013 .41552 Mtetra
.667 .757 .917 r
.71013 .41552 .71794 .4253 .73481 .41947 .72708 .40965 Mtetra
.668 .758 .918 r
.72708 .40965 .73481 .41947 .75178 .41362 .74412 .40372 Mtetra
.66 .754 .92 r
.74412 .40372 .75178 .41362 .76888 .40813 .76129 .3981 Mtetra
.67 .757 .916 r
.76129 .3981 .76888 .40813 .78602 .40193 .77852 .39205 Mtetra
.696 .771 .91 r
.77852 .39205 .78602 .40193 .80318 .39471 .79576 .38482 Mtetra
.693 .771 .912 r
.79576 .38482 .80318 .39471 .82045 .38783 .81309 .37765 Mtetra
.602 .728 .934 r
.81309 .37765 .82045 .38783 .8382 .38493 .83086 .37415 Mtetra
.495 .662 .936 r
.83086 .37415 .8382 .38493 .85644 .38541 .84914 .37431 Mtetra
.476 .646 .932 r
.84914 .37431 .85644 .38541 .87486 .38591 .86767 .37516 Mtetra
.774 .766 .845 r
.23361 .56352 .24323 .57208 .25806 .5614 .24852 .5526 Mtetra
.761 .761 .853 r
.24852 .5526 .25806 .5614 .27286 .55133 .26338 .54262 Mtetra
.699 .755 .896 r
.26338 .54262 .27286 .55133 .28745 .54475 .278 .53625 Mtetra
.606 .737 .938 r
.278 .53625 .28745 .54475 .30187 .54168 .29246 .53321 Mtetra
.605 .739 .94 r
.29246 .53321 .30187 .54168 .31638 .5387 .30701 .53017 Mtetra
.643 .75 .927 r
.30701 .53017 .31638 .5387 .33104 .53458 .32173 .52591 Mtetra
.65 .75 .922 r
.32173 .52591 .33104 .53458 .34582 .53006 .33655 .52137 Mtetra
.641 .748 .926 r
.33655 .52137 .34582 .53006 .36066 .52584 .35144 .51712 Mtetra
.643 .749 .926 r
.35144 .51712 .36066 .52584 .37558 .52157 .36642 .51278 Mtetra
.662 .754 .918 r
.36642 .51278 .37558 .52157 .39063 .51665 .38151 .50774 Mtetra
.658 .751 .919 r
.38151 .50774 .39063 .51665 .40575 .51172 .39669 .50282 Mtetra
.647 .749 .924 r
.39669 .50282 .40575 .51172 .42095 .50717 .41194 .49826 Mtetra
.646 .75 .925 r
.41194 .49826 .42095 .50717 .43623 .50271 .42727 .49372 Mtetra
.665 .755 .917 r
.42727 .49372 .43623 .50271 .45161 .4976 .44272 .48845 Mtetra
.661 .751 .917 r
.44272 .48845 .45161 .4976 .46709 .49245 .45824 .48332 Mtetra
.648 .749 .923 r
.45824 .48332 .46709 .49245 .48264 .48766 .47385 .47865 Mtetra
.643 .751 .928 r
.47385 .47865 .48264 .48766 .49828 .48322 .48955 .4741 Mtetra
.668 .758 .917 r
.48955 .4741 .49828 .48322 .51402 .47819 .50535 .46857 Mtetra
.673 .749 .908 r
.50535 .46857 .51402 .47819 .52984 .47284 .52123 .46282 Mtetra
.656 .736 .909 r
.52123 .46282 .52984 .47284 .54576 .46779 .53721 .45772 Mtetra
.639 .73 .914 r
.53721 .45772 .54576 .46779 .56177 .46305 .55328 .45327 Mtetra
.643 .739 .919 r
.55328 .45327 .56177 .46305 .57788 .458 .56945 .44861 Mtetra
.668 .758 .918 r
.56945 .44861 .57788 .458 .59406 .45234 .58571 .44295 Mtetra
.664 .758 .92 r
.58571 .44295 .59406 .45234 .61035 .44703 .60205 .43741 Mtetra
.651 .75 .922 r
.60205 .43741 .61035 .44703 .62674 .44209 .61851 .43234 Mtetra
.647 .746 .922 r
.61851 .43234 .62674 .44209 .64324 .4371 .63507 .42741 Mtetra
.665 .755 .918 r
.63507 .42741 .64324 .4371 .6598 .43145 .6517 .42173 Mtetra
.664 .756 .919 r
.6517 .42173 .6598 .43145 .67647 .42589 .66844 .41606 Mtetra
.654 .751 .921 r
.66844 .41606 .67647 .42589 .69325 .4207 .68528 .41077 Mtetra
.65 .748 .921 r
.68528 .41077 .69325 .4207 .71013 .41552 .70224 .40558 Mtetra
.667 .756 .917 r
.70224 .40558 .71013 .41552 .72708 .40965 .71926 .39968 Mtetra
.669 .757 .917 r
.71926 .39968 .72708 .40965 .74412 .40372 .73637 .39367 Mtetra
.661 .754 .919 r
.73637 .39367 .74412 .40372 .76129 .3981 .75361 .38796 Mtetra
.667 .756 .916 r
.75361 .38796 .76129 .3981 .77852 .39205 .77092 .38195 Mtetra
.695 .768 .908 r
.77092 .38195 .77852 .39205 .79576 .38482 .78824 .37466 Mtetra
.78824 .37466 .79576 .38482 .81309 .37765 .80564 .36735 Mtetra
.61 .732 .932 r
.80564 .36735 .81309 .37765 .83086 .37415 .82346 .36351 Mtetra
.496 .669 .94 r
.82346 .36351 .83086 .37415 .84914 .37431 .84179 .36348 Mtetra
.464 .648 .938 r
.84179 .36348 .84914 .37431 .86767 .37516 .8604 .36445 Mtetra
.776 .77 .847 r
.22388 .55506 .23361 .56352 .24852 .5526 .23885 .54408 Mtetra
.763 .769 .858 r
.23885 .54408 .24852 .5526 .26338 .54262 .25377 .53404 Mtetra
.699 .76 .899 r
.25377 .53404 .26338 .54262 .278 .53625 .26845 .52762 Mtetra
.606 .737 .937 r
.26845 .52762 .278 .53625 .29246 .53321 .28295 .52453 Mtetra
.605 .736 .938 r
.28295 .52453 .29246 .53321 .30701 .53017 .29755 .52145 Mtetra
.643 .748 .925 r
.29755 .52145 .30701 .53017 .32173 .52591 .31231 .51714 Mtetra
.65 .75 .922 r
.31231 .51714 .32173 .52591 .33655 .52137 .32718 .51255 Mtetra
.641 .747 .926 r
.32718 .51255 .33655 .52137 .35144 .51712 .34212 .50826 Mtetra
.643 .748 .925 r
.34212 .50826 .35144 .51712 .36642 .51278 .35715 .50386 Mtetra
.662 .753 .918 r
.35715 .50386 .36642 .51278 .38151 .50774 .3723 .49878 Mtetra
.658 .752 .919 r
.3723 .49878 .38151 .50774 .39669 .50282 .38753 .49381 Mtetra
.647 .749 .923 r
.38753 .49381 .39669 .50282 .41194 .49826 .40283 .48919 Mtetra
.646 .748 .924 r
.40283 .48919 .41194 .49826 .42727 .49372 .41822 .48461 Mtetra
.665 .754 .917 r
.41822 .48461 .42727 .49372 .44272 .48845 .43373 .47929 Mtetra
.661 .753 .918 r
.43373 .47929 .44272 .48845 .45824 .48332 .44931 .4741 Mtetra
.648 .749 .923 r
.44931 .4741 .45824 .48332 .47385 .47865 .46497 .46937 Mtetra
.643 .747 .925 r
.46497 .46937 .47385 .47865 .48955 .4741 .48073 .46477 Mtetra
.668 .755 .915 r
.48073 .46477 .48955 .4741 .50535 .46857 .49659 .45918 Mtetra
.673 .757 .914 r
.49659 .45918 .50535 .46857 .52123 .46282 .51253 .45338 Mtetra
.656 .751 .92 r
.51253 .45338 .52123 .46282 .53721 .45772 .52857 .44822 Mtetra
.638 .745 .926 r
.52857 .44822 .53721 .45772 .55328 .45327 .5447 .44372 Mtetra
.643 .747 .925 r
.5447 .44372 .55328 .45327 .56945 .44861 .56094 .439 Mtetra
.668 .755 .916 r
.56094 .439 .56945 .44861 .58571 .44295 .57725 .43328 Mtetra
.664 .754 .917 r
.57725 .43328 .58571 .44295 .60205 .43741 .59367 .42769 Mtetra
.651 .75 .922 r
.59367 .42769 .60205 .43741 .61851 .43234 .61019 .42257 Mtetra
.647 .748 .923 r
.61019 .42257 .61851 .43234 .63507 .42741 .62681 .41758 Mtetra
.665 .755 .917 r
.62681 .41758 .63507 .42741 .6517 .42173 .64351 .41183 Mtetra
.664 .754 .918 r
.64351 .41183 .6517 .42173 .66844 .41606 .66031 .40611 Mtetra
.654 .751 .921 r
.66031 .40611 .66844 .41606 .68528 .41077 .67723 .40075 Mtetra
.65 .749 .922 r
.67723 .40075 .68528 .41077 .70224 .40558 .69426 .39551 Mtetra
.667 .755 .916 r
.69426 .39551 .70224 .40558 .71926 .39968 .71135 .38955 Mtetra
.669 .756 .916 r
.71135 .38955 .71926 .39968 .73637 .39367 .72854 .38348 Mtetra
.661 .753 .918 r
.72854 .38348 .73637 .39367 .75361 .38796 .74584 .3777 Mtetra
.667 .756 .916 r
.74584 .3777 .75361 .38796 .77092 .38195 .76323 .37162 Mtetra
.695 .766 .906 r
.76323 .37162 .77092 .38195 .78824 .37466 .78063 .36427 Mtetra
.694 .766 .907 r
.78063 .36427 .78824 .37466 .80564 .36735 .79811 .35689 Mtetra
.61 .731 .931 r
.79811 .35689 .80564 .36735 .82346 .36351 .816 .353 Mtetra
.493 .673 .944 r
.816 .353 .82346 .36351 .84179 .36348 .8344 .35291 Mtetra
.458 .654 .945 r
.8344 .35291 .84179 .36348 .8604 .36445 .85308 .35384 Mtetra
.775 .773 .851 r
.21402 .54672 .22388 .55506 .23885 .54408 .22905 .53585 Mtetra
.768 .777 .86 r
.22905 .53585 .23885 .54408 .25377 .53404 .24405 .5256 Mtetra
.706 .767 .9 r
.24405 .5256 .25377 .53404 .26845 .52762 .2588 .51886 Mtetra
.609 .737 .936 r
.2588 .51886 .26845 .52762 .28295 .52453 .27335 .51566 Mtetra
.605 .734 .936 r
.27335 .51566 .28295 .52453 .29755 .52145 .28799 .51254 Mtetra
.64 .745 .924 r
.28799 .51254 .29755 .52145 .31231 .51714 .3028 .50828 Mtetra
.651 .75 .922 r
.3028 .50828 .31231 .51714 .32718 .51255 .31772 .50361 Mtetra
.642 .746 .925 r
.31772 .50361 .32718 .51255 .34212 .50826 .33271 .49925 Mtetra
.643 .746 .924 r
.33271 .49925 .34212 .50826 .35715 .50386 .34779 .49483 Mtetra
.66 .752 .918 r
.34779 .49483 .35715 .50386 .3723 .49878 .36299 .48975 Mtetra
.659 .753 .919 r
.36299 .48975 .3723 .49878 .38753 .49381 .37828 .48468 Mtetra
.649 .749 .923 r
.37828 .48468 .38753 .49381 .40283 .48919 .39364 .47997 Mtetra
.645 .747 .923 r
.39364 .47997 .40283 .48919 .41822 .48461 .40908 .47536 Mtetra
.662 .752 .917 r
.40908 .47536 .41822 .48461 .43373 .47929 .42464 .47009 Mtetra
.662 .755 .919 r
.42464 .47009 .43373 .47929 .44931 .4741 .44028 .46478 Mtetra
.652 .75 .922 r
.44028 .46478 .44931 .4741 .46497 .46937 .456 .45983 Mtetra
.642 .743 .922 r
.456 .45983 .46497 .46937 .48073 .46477 .47181 .45524 Mtetra
.657 .749 .918 r
.47181 .45524 .48073 .46477 .49659 .45918 .48773 .45004 Mtetra
.664 .762 .923 r
.48773 .45004 .49659 .45918 .51253 .45338 .50374 .44452 Mtetra
.655 .767 .932 r
.50374 .44452 .51253 .45338 .52857 .44822 .51984 .43931 Mtetra
.645 .764 .935 r
.51984 .43931 .52857 .44822 .5447 .44372 .53603 .43441 Mtetra
.654 .759 .926 r
.53603 .43441 .5447 .44372 .56094 .439 .55232 .42918 Mtetra
.669 .753 .914 r
.55232 .42918 .56094 .439 .57725 .43328 .56871 .42335 Mtetra
.66 .749 .916 r
.56871 .42335 .57725 .43328 .59367 .42769 .58519 .41787 Mtetra
.649 .749 .922 r
.58519 .41787 .59367 .42769 .61019 .42257 .60177 .41276 Mtetra
.65 .751 .923 r
.60177 .41276 .61019 .42257 .62681 .41758 .61846 .4076 Mtetra
.666 .754 .916 r
.61846 .4076 .62681 .41758 .64351 .41183 .63523 .40177 Mtetra
.663 .752 .917 r
.63523 .40177 .64351 .41183 .66031 .40611 .6521 .39603 Mtetra
.653 .75 .921 r
.6521 .39603 .66031 .40611 .67723 .40075 .66909 .39067 Mtetra
.652 .751 .922 r
.66909 .39067 .67723 .40075 .69426 .39551 .68618 .3853 Mtetra
.667 .755 .916 r
.68618 .3853 .69426 .39551 .71135 .38955 .70335 .37925 Mtetra
.668 .755 .915 r
.70335 .37925 .71135 .38955 .72854 .38348 .72061 .37313 Mtetra
.66 .752 .918 r
.72061 .37313 .72854 .38348 .74584 .3777 .73799 .36733 Mtetra
.67 .756 .916 r
.73799 .36733 .74584 .3777 .76323 .37162 .75545 .36108 Mtetra
.695 .764 .905 r
.75545 .36108 .76323 .37162 .78063 .36427 .77292 .35364 Mtetra
.693 .763 .905 r
.77292 .35364 .78063 .36427 .79811 .35689 .79049 .34628 Mtetra
.602 .727 .932 r
.79049 .34628 .79811 .35689 .816 .353 .80848 .3426 Mtetra
.484 .674 .948 r
.80848 .3426 .816 .353 .8344 .35291 .82696 .34261 Mtetra
.458 .663 .951 r
.82696 .34261 .8344 .35291 .85308 .35384 .84569 .3433 Mtetra
.771 .777 .857 r
.20405 .53845 .21402 .54672 .22905 .53585 .21911 .5279 Mtetra
.773 .784 .862 r
.21911 .5279 .22905 .53585 .24405 .5256 .23421 .51733 Mtetra
.717 .774 .897 r
.23421 .51733 .24405 .5256 .2588 .51886 .24906 .51001 Mtetra
.616 .739 .934 r
.24906 .51001 .2588 .51886 .27335 .51566 .26367 .50654 Mtetra
.604 .73 .933 r
.26367 .50654 .27335 .51566 .28799 .51254 .27835 .50343 Mtetra
.635 .741 .925 r
.27835 .50343 .28799 .51254 .3028 .50828 .29319 .49932 Mtetra
.653 .75 .921 r
.29319 .49932 .3028 .50828 .31772 .50361 .30817 .49454 Mtetra
.643 .746 .924 r
.30817 .49454 .31772 .50361 .33271 .49925 .32321 .4901 Mtetra
.642 .745 .924 r
.32321 .4901 .33271 .49925 .34779 .49483 .33834 .48566 Mtetra
.657 .75 .919 r
.33834 .48566 .34779 .49483 .36299 .48975 .35358 .48067 Mtetra
.662 .755 .919 r
.35358 .48067 .36299 .48975 .37828 .48468 .36893 .47545 Mtetra
.651 .749 .922 r
.36893 .47545 .37828 .48468 .39364 .47997 .38434 .47061 Mtetra
.645 .746 .922 r
.38434 .47061 .39364 .47997 .40908 .47536 .39984 .46595 Mtetra
.656 .749 .919 r
.39984 .46595 .40908 .47536 .42464 .47009 .41544 .46087 Mtetra
.665 .757 .919 r
.41544 .46087 .42464 .47009 .44028 .46478 .43115 .4554 Mtetra
.657 .752 .921 r
.43115 .4554 .44028 .46478 .456 .45983 .44694 .45022 Mtetra
.648 .746 .921 r
.44694 .45022 .456 .45983 .47181 .45524 .46281 .44534 Mtetra
.647 .74 .917 r
.46281 .44534 .47181 .45524 .48773 .45004 .47877 .4405 Mtetra
.653 .751 .922 r
.47877 .4405 .48773 .45004 .50374 .44452 .49484 .43537 Mtetra
.655 .763 .929 r
.49484 .43537 .50374 .44452 .51984 .43931 .511 .43011 Mtetra
.658 .764 .928 r
.511 .43011 .51984 .43931 .53603 .43441 .52726 .4247 Mtetra
.665 .755 .918 r
.52726 .4247 .53603 .43441 .55232 .42918 .54362 .419 Mtetra
.663 .746 .912 r
.54362 .419 .55232 .42918 .56871 .42335 .56007 .41335 Mtetra
.655 .748 .918 r
.56007 .41335 .56871 .42335 .58519 .41787 .57661 .40798 Mtetra
.647 .749 .924 r
.57661 .40798 .58519 .41787 .60177 .41276 .59327 .40291 Mtetra
.656 .754 .923 r
.59327 .40291 .60177 .41276 .61846 .4076 .61002 .39745 Mtetra
.666 .753 .915 r
.61002 .39745 .61846 .4076 .63523 .40177 .62685 .39155 Mtetra
.661 .751 .917 r
.62685 .39155 .63523 .40177 .6521 .39603 .6438 .38583 Mtetra
.65 .749 .922 r
.6438 .38583 .6521 .39603 .66909 .39067 .66086 .3805 Mtetra
.655 .753 .922 r
.66086 .3805 .66909 .39067 .68618 .3853 .67802 .37493 Mtetra
.668 .754 .915 r
.67802 .37493 .68618 .3853 .70335 .37925 .69525 .36879 Mtetra
.69525 .36879 .70335 .37925 .72061 .37313 .71259 .36263 Mtetra
.659 .751 .918 r
.71259 .36263 .72061 .37313 .73799 .36733 .73005 .35682 Mtetra
.674 .758 .914 r
.73005 .35682 .73799 .36733 .75545 .36108 .74757 .35031 Mtetra
.696 .762 .903 r
.74757 .35031 .75545 .36108 .77292 .35364 .76511 .34275 Mtetra
.687 .757 .905 r
.76511 .34275 .77292 .35364 .79049 .34628 .78278 .33554 Mtetra
.587 .719 .935 r
.78278 .33554 .79049 .34628 .80848 .3426 .80089 .33235 Mtetra
.47 .673 .953 r
.80089 .33235 .80848 .3426 .82696 .34261 .81947 .33258 Mtetra
.465 .677 .957 r
.81947 .33258 .82696 .34261 .84569 .3433 .83824 .33282 Mtetra
.763 .778 .866 r
.19396 .5302 .20405 .53845 .21911 .5279 .20904 .52022 Mtetra
.78 .792 .863 r
.20904 .52022 .21911 .5279 .23421 .51733 .22423 .50927 Mtetra
.733 .783 .892 r
.22423 .50927 .23421 .51733 .24906 .51001 .23921 .50114 Mtetra
.629 .744 .93 r
.23921 .50114 .24906 .51001 .26367 .50654 .2539 .4972 Mtetra
.603 .726 .932 r
.2539 .4972 .26367 .50654 .27835 .50343 .26861 .49411 Mtetra
.626 .735 .925 r
.26861 .49411 .27835 .50343 .29319 .49932 .28348 .49024 Mtetra
.655 .75 .92 r
.28348 .49024 .29319 .49932 .30817 .49454 .29851 .48535 Mtetra
.644 .746 .923 r
.29851 .48535 .30817 .49454 .32321 .4901 .3136 .48083 Mtetra
.642 .744 .923 r
.3136 .48083 .32321 .4901 .33834 .48566 .32878 .47634 Mtetra
.651 .747 .92 r
.32878 .47634 .33834 .48566 .35358 .48067 .34407 .47151 Mtetra
.664 .755 .919 r
.34407 .47151 .35358 .48067 .36893 .47545 .35948 .46616 Mtetra
.654 .751 .921 r
.35948 .46616 .36893 .47545 .38434 .47061 .37495 .46115 Mtetra
.647 .746 .922 r
.37495 .46115 .38434 .47061 .39984 .46595 .39051 .45636 Mtetra
.648 .745 .92 r
.39051 .45636 .39984 .46595 .41544 .46087 .40615 .45153 Mtetra
.663 .756 .92 r
.40615 .45153 .41544 .46087 .43115 .4554 .42192 .44609 Mtetra
.662 .758 .921 r
.42192 .44609 .43115 .4554 .44694 .45022 .43777 .44065 Mtetra
.656 .751 .92 r
.43777 .44065 .44694 .45022 .46281 .44534 .4537 .43541 Mtetra
.653 .744 .916 r
.4537 .43541 .46281 .44534 .47877 .4405 .46973 .43028 Mtetra
.652 .738 .913 r
.46973 .43028 .47877 .4405 .49484 .43537 .48586 .42515 Mtetra
.656 .741 .912 r
.48586 .42515 .49484 .43537 .511 .43011 .50208 .41983 Mtetra
.66 .742 .911 r
.50208 .41983 .511 .43011 .52726 .4247 .5184 .4143 Mtetra
.659 .741 .91 r
.5184 .4143 .52726 .4247 .54362 .419 .53482 .40878 Mtetra
.656 .745 .915 r
.53482 .40878 .54362 .419 .56007 .41335 .55133 .40336 Mtetra
.65 .749 .922 r
.55133 .40336 .56007 .41335 .57661 .40798 .56795 .39815 Mtetra
.649 .754 .926 r
.56795 .39815 .57661 .40798 .59327 .40291 .58467 .39294 Mtetra
.663 .757 .92 r
.58467 .39294 .59327 .40291 .61002 .39745 .60148 .38711 Mtetra
.664 .75 .914 r
.60148 .38711 .61002 .39745 .62685 .39155 .61839 .38122 Mtetra
.658 .75 .918 r
.61839 .38122 .62685 .39155 .6438 .38583 .6354 .37556 Mtetra
.648 .749 .923 r
.6354 .37556 .6438 .38583 .66086 .3805 .65254 .37024 Mtetra
.66 .755 .92 r
.65254 .37024 .66086 .3805 .67802 .37493 .66976 .36439 Mtetra
.668 .753 .914 r
.66976 .36439 .67802 .37493 .69525 .36879 .68706 .35817 Mtetra
.667 .752 .914 r
.68706 .35817 .69525 .36879 .71259 .36263 .70448 .35199 Mtetra
.657 .75 .918 r
.70448 .35199 .71259 .36263 .73005 .35682 .72202 .34617 Mtetra
.681 .76 .911 r
.72202 .34617 .73005 .35682 .74757 .35031 .73959 .33929 Mtetra
.697 .759 .9 r
.73959 .33929 .74757 .35031 .76511 .34275 .75721 .33159 Mtetra
.678 .751 .906 r
.75721 .33159 .76511 .34275 .78278 .33554 .77499 .32475 Mtetra
.563 .71 .94 r
.77499 .32475 .78278 .33554 .80089 .33235 .79324 .32229 Mtetra
.453 .671 .957 r
.79324 .32229 .80089 .33235 .81947 .33258 .81192 .3228 Mtetra
.484 .697 .962 r
.81192 .3228 .81947 .33258 .83824 .33282 .83071 .32232 Mtetra
.748 .778 .877 r
.18377 .52186 .19396 .5302 .20904 .52022 .19881 .51277 Mtetra
.785 .798 .863 r
.19881 .51277 .20904 .52022 .22423 .50927 .21411 .50148 Mtetra
.747 .792 .889 r
.21411 .50148 .22423 .50927 .23921 .50114 .22921 .49261 Mtetra
.655 .761 .928 r
.22921 .49261 .23921 .50114 .2539 .4972 .24403 .48771 Mtetra
.604 .725 .931 r
.24403 .48771 .2539 .4972 .26861 .49411 .25878 .48456 Mtetra
.616 .729 .927 r
.25878 .48456 .26861 .49411 .28348 .49024 .27367 .481 Mtetra
.652 .748 .92 r
.27367 .481 .28348 .49024 .29851 .48535 .28875 .47615 Mtetra
.648 .749 .923 r
.28875 .47615 .29851 .48535 .3136 .48083 .3039 .47141 Mtetra
.642 .744 .922 r
.3039 .47141 .3136 .48083 .32878 .47634 .31913 .46686 Mtetra
.645 .744 .921 r
.31913 .46686 .32878 .47634 .34407 .47151 .33446 .46218 Mtetra
.661 .753 .919 r
.33446 .46218 .34407 .47151 .35948 .46616 .34992 .45689 Mtetra
.66 .756 .921 r
.34992 .45689 .35948 .46616 .37495 .46115 .36546 .45161 Mtetra
.651 .748 .921 r
.36546 .45161 .37495 .46115 .39051 .45636 .38107 .44662 Mtetra
.647 .744 .92 r
.38107 .44662 .39051 .45636 .40615 .45153 .39678 .44177 Mtetra
.652 .746 .919 r
.39678 .44177 .40615 .45153 .42192 .44609 .41258 .43671 Mtetra
.662 .759 .922 r
.41258 .43671 .42192 .44609 .43777 .44065 .42849 .4312 Mtetra
.661 .758 .922 r
.42849 .4312 .43777 .44065 .4537 .43541 .4445 .4257 Mtetra
.657 .752 .92 r
.4445 .4257 .4537 .43541 .46973 .43028 .46059 .42034 Mtetra
.656 .748 .918 r
.46059 .42034 .46973 .43028 .48586 .42515 .47677 .41498 Mtetra
.656 .744 .915 r
.47677 .41498 .48586 .42515 .50208 .41983 .49306 .4096 Mtetra
.49306 .4096 .50208 .41983 .5184 .4143 .50944 .40418 Mtetra
.655 .748 .918 r
.50944 .40418 .5184 .4143 .53482 .40878 .52592 .39878 Mtetra
.65 .75 .923 r
.52592 .39878 .53482 .40878 .55133 .40336 .5425 .39351 Mtetra
.649 .754 .926 r
.5425 .39351 .55133 .40336 .56795 .39815 .55918 .38824 Mtetra
.66 .758 .923 r
.55918 .38824 .56795 .39815 .58467 .39294 .57596 .38253 Mtetra
.664 .75 .914 r
.57596 .38253 .58467 .39294 .60148 .38711 .59284 .3766 Mtetra
.66 .748 .915 r
.59284 .3766 .60148 .38711 .61839 .38122 .60982 .37079 Mtetra
.652 .748 .92 r
.60982 .37079 .61839 .38122 .6354 .37556 .62692 .36529 Mtetra
.651 .753 .924 r
.62692 .36529 .6354 .37556 .65254 .37024 .64412 .3598 Mtetra
.666 .756 .917 r
.64412 .3598 .65254 .37024 .66976 .36439 .6614 .35366 Mtetra
.668 .752 .913 r
.6614 .35366 .66976 .36439 .68706 .35817 .67878 .3474 Mtetra
.663 .75 .915 r
.67878 .3474 .68706 .35817 .70448 .35199 .69628 .34132 Mtetra
.66 .753 .919 r
.69628 .34132 .70448 .35199 .72202 .34617 .71389 .33534 Mtetra
.689 .761 .907 r
.71389 .33534 .72202 .34617 .73959 .33929 .73152 .32801 Mtetra
.696 .757 .898 r
.73152 .32801 .73959 .33929 .75721 .33159 .74921 .32025 Mtetra
.657 .741 .912 r
.74921 .32025 .75721 .33159 .77499 .32475 .76714 .31429 Mtetra
.537 .708 .95 r
.76714 .31429 .77499 .32475 .79324 .32229 .78553 .31249 Mtetra
.434 .671 .962 r
.78553 .31249 .79324 .32229 .81192 .3228 .80431 .31323 Mtetra
.514 .721 .966 r
.80431 .31323 .81192 .3228 .83071 .32232 .82308 .3117 Mtetra
.725 .773 .891 r
.17347 .51333 .18377 .52186 .19881 .51277 .18845 .50545 Mtetra
.786 .803 .866 r
.18845 .50545 .19881 .51277 .21411 .50148 .20382 .49414 Mtetra
.763 .804 .886 r
.20382 .49414 .21411 .50148 .22921 .49261 .21907 .48443 Mtetra
.69 .779 .919 r
.21907 .48443 .22921 .49261 .24403 .48771 .23405 .47819 Mtetra
.609 .729 .93 r
.23405 .47819 .24403 .48771 .25878 .48456 .24887 .47479 Mtetra
.611 .725 .926 r
.24887 .47479 .25878 .48456 .27367 .481 .26378 .47135 Mtetra
.641 .738 .919 r
.26378 .47135 .27367 .481 .28875 .47615 .27888 .46686 Mtetra
.653 .75 .921 r
.27888 .46686 .28875 .47615 .3039 .47141 .2941 .46188 Mtetra
.644 .744 .922 r
.2941 .46188 .3039 .47141 .31913 .46686 .30938 .45722 Mtetra
.643 .742 .921 r
.30938 .45722 .31913 .46686 .33446 .46218 .32476 .45256 Mtetra
.652 .746 .919 r
.32476 .45256 .33446 .46218 .34992 .45689 .34025 .44754 Mtetra
.663 .757 .92 r
.34025 .44754 .34992 .45689 .36546 .45161 .35585 .44209 Mtetra
.656 .752 .921 r
.35585 .44209 .36546 .45161 .38107 .44662 .37154 .43686 Mtetra
.651 .746 .92 r
.37154 .43686 .38107 .44662 .39678 .44177 .3873 .4318 Mtetra
.648 .742 .918 r
.3873 .4318 .39678 .44177 .41258 .43671 .40316 .42682 Mtetra
.651 .746 .919 r
.40316 .42682 .41258 .43671 .42849 .4312 .41911 .42169 Mtetra
.659 .758 .923 r
.41911 .42169 .42849 .4312 .4445 .4257 .43518 .41621 Mtetra
.659 .76 .925 r
.43518 .41621 .4445 .4257 .46059 .42034 .45133 .41069 Mtetra
.658 .758 .924 r
.45133 .41069 .46059 .42034 .47677 .41498 .46758 .4052 Mtetra
.656 .755 .923 r
.46758 .4052 .47677 .41498 .49306 .4096 .48393 .39976 Mtetra
.654 .755 .924 r
.48393 .39976 .49306 .4096 .50944 .40418 .50038 .39436 Mtetra
.652 .756 .926 r
.50038 .39436 .50944 .40418 .52592 .39878 .51692 .38899 Mtetra
.652 .758 .927 r
.51692 .38899 .52592 .39878 .5425 .39351 .53357 .38358 Mtetra
.66 .759 .923 r
.53357 .38358 .5425 .39351 .55918 .38824 .55032 .37781 Mtetra
.663 .751 .915 r
.55032 .37781 .55918 .38824 .57596 .38253 .56716 .37189 Mtetra
.661 .746 .914 r
.56716 .37189 .57596 .38253 .59284 .3766 .58411 .36605 Mtetra
.656 .748 .918 r
.58411 .36605 .59284 .3766 .60982 .37079 .60116 .36038 Mtetra
.649 .75 .923 r
.60116 .36038 .60982 .37079 .62692 .36529 .61833 .35493 Mtetra
.659 .756 .922 r
.61833 .35493 .62692 .36529 .64412 .3598 .63559 .34903 Mtetra
.667 .752 .913 r
.63559 .34903 .64412 .3598 .6614 .35366 .65295 .34276 Mtetra
.667 .75 .913 r
.65295 .34276 .6614 .35366 .67878 .3474 .6704 .33649 Mtetra
.658 .748 .916 r
.6704 .33649 .67878 .3474 .69628 .34132 .68798 .33052 Mtetra
.669 .756 .916 r
.68798 .33052 .69628 .34132 .71389 .33534 .70564 .32405 Mtetra
.692 .756 .901 r
.70564 .32405 .71389 .33534 .73152 .32801 .72334 .31649 Mtetra
.692 .753 .898 r
.72334 .31649 .73152 .32801 .74921 .32025 .74113 .30885 Mtetra
.624 .729 .922 r
.74113 .30885 .74921 .32025 .76714 .31429 .75924 .30417 Mtetra
.504 .702 .959 r
.75924 .30417 .76714 .31429 .78553 .31249 .77777 .30312 Mtetra
.424 .68 .969 r
.77777 .30312 .78553 .31249 .80431 .31323 .79663 .30377 Mtetra
.558 .748 .966 r
.79663 .30377 .80431 .31323 .82308 .3117 .81535 .30083 Mtetra
.695 .763 .904 r
.1631 .50444 .17347 .51333 .18845 .50545 .17799 .49794 Mtetra
.776 .801 .873 r
.17799 .49794 .18845 .50545 .20382 .49414 .19336 .48727 Mtetra
.779 .816 .882 r
.19336 .48727 .20382 .49414 .21907 .48443 .20877 .47666 Mtetra
.725 .796 .907 r
.20877 .47666 .21907 .48443 .23405 .47819 .22395 .46883 Mtetra
.629 .741 .928 r
.22395 .46883 .23405 .47819 .24887 .47479 .23886 .46474 Mtetra
.608 .72 .924 r
.23886 .46474 .24887 .47479 .26378 .47135 .25381 .46136 Mtetra
.625 .728 .921 r
.25381 .46136 .26378 .47135 .27888 .46686 .26891 .45738 Mtetra
.654 .749 .92 r
.26891 .45738 .27888 .46686 .2941 .46188 .28418 .45234 Mtetra
.648 .747 .921 r
.28418 .45234 .2941 .46188 .30938 .45722 .29953 .44747 Mtetra
.644 .742 .92 r
.29953 .44747 .30938 .45722 .32476 .45256 .31496 .44273 Mtetra
.645 .742 .92 r
.31496 .44273 .32476 .45256 .34025 .44754 .33049 .4379 Mtetra
.657 .751 .919 r
.33049 .4379 .34025 .44754 .35585 .44209 .34614 .43263 Mtetra
.662 .758 .921 r
.34614 .43263 .35585 .44209 .37154 .43686 .36189 .42711 Mtetra
.655 .751 .92 r
.36189 .42711 .37154 .43686 .3873 .4318 .37772 .42182 Mtetra
.652 .746 .918 r
.37772 .42182 .3873 .4318 .40316 .42682 .39364 .41663 Mtetra
.65 .742 .917 r
.39364 .41663 .40316 .42682 .41911 .42169 .40965 .41148 Mtetra
.651 .743 .917 r
.40965 .41148 .41911 .42169 .43518 .41621 .42576 .40625 Mtetra
.653 .751 .921 r
.42576 .40625 .43518 .41621 .45133 .41069 .44198 .40091 Mtetra
.655 .756 .924 r
.44198 .40091 .45133 .41069 .46758 .4052 .45829 .39547 Mtetra
.656 .759 .926 r
.45829 .39547 .46758 .4052 .48393 .39976 .4747 .38997 Mtetra
.4747 .38997 .48393 .39976 .50038 .39436 .49121 .3844 Mtetra
.658 .757 .923 r
.49121 .3844 .50038 .39436 .51692 .38899 .50782 .37873 Mtetra
.66 .753 .919 r
.50782 .37873 .51692 .38899 .53357 .38358 .52454 .37294 Mtetra
.661 .747 .913 r
.52454 .37294 .53357 .38358 .55032 .37781 .54135 .36707 Mtetra
.66 .745 .913 r
.54135 .36707 .55032 .37781 .56716 .37189 .55826 .36124 Mtetra
.657 .747 .917 r
.55826 .36124 .56716 .37189 .58411 .36605 .57528 .35551 Mtetra
.65 .748 .922 r
.57528 .35551 .58411 .36605 .60116 .36038 .59241 .35001 Mtetra
.655 .756 .924 r
.59241 .35001 .60116 .36038 .61833 .35493 .60964 .34426 Mtetra
.666 .754 .916 r
.60964 .34426 .61833 .35493 .63559 .34903 .62697 .33803 Mtetra
.667 .749 .912 r
.62697 .33803 .63559 .34903 .65295 .34276 .6444 .33172 Mtetra
.663 .748 .914 r
.6444 .33172 .65295 .34276 .6704 .33649 .66193 .32554 Mtetra
.658 .75 .918 r
.66193 .32554 .6704 .33649 .68798 .33052 .67959 .31952 Mtetra
.683 .759 .91 r
.67959 .31952 .68798 .33052 .70564 .32405 .69729 .31239 Mtetra
.694 .751 .896 r
.69729 .31239 .70564 .32405 .72334 .31649 .71506 .30463 Mtetra
.678 .743 .9 r
.71506 .30463 .72334 .31649 .74113 .30885 .73297 .29759 Mtetra
.58 .714 .935 r
.73297 .29759 .74113 .30885 .75924 .30417 .75127 .29444 Mtetra
.463 .694 .967 r
.75127 .29444 .75924 .30417 .77777 .30312 .76995 .29421 Mtetra
.442 .704 .977 r
.76995 .29421 .77777 .30312 .79663 .30377 .78883 .29407 Mtetra
.606 .768 .957 r
.78883 .29407 .79663 .30377 .81535 .30083 .80751 .28956 Mtetra
.659 .744 .913 r
.15267 .49494 .1631 .50444 .17799 .49794 .16745 .48982 Mtetra
.749 .789 .885 r
.16745 .48982 .17799 .49794 .19336 .48727 .18275 .48061 Mtetra
.788 .822 .879 r
.18275 .48061 .19336 .48727 .20877 .47666 .19828 .46938 Mtetra
.75 .811 .9 r
.19828 .46938 .20877 .47666 .22395 .46883 .21365 .46031 Mtetra
.672 .773 .926 r
.21365 .46031 .22395 .46883 .23886 .46474 .22875 .45464 Mtetra
.611 .722 .924 r
.22875 .45464 .23886 .46474 .25381 .46136 .24375 .45111 Mtetra
.615 .721 .921 r
.24375 .45111 .25381 .46136 .26891 .45738 .25887 .44742 Mtetra
.641 .737 .918 r
.25887 .44742 .26891 .45738 .28418 .45234 .27415 .44279 Mtetra
.655 .751 .92 r
.27415 .44279 .28418 .45234 .29953 .44747 .28957 .43761 Mtetra
.646 .743 .92 r
.28957 .43761 .29953 .44747 .31496 .44273 .30506 .43274 Mtetra
.645 .741 .919 r
.30506 .43274 .31496 .44273 .33049 .4379 .32064 .42789 Mtetra
.647 .742 .919 r
.32064 .42789 .33049 .4379 .34614 .43263 .33632 .42291 Mtetra
.657 .753 .92 r
.33632 .42291 .34614 .43263 .36189 .42711 .35212 .41752 Mtetra
.661 .758 .922 r
.35212 .41752 .36189 .42711 .37772 .42182 .36802 .41194 Mtetra
.657 .752 .92 r
.36802 .41194 .37772 .42182 .39364 .41663 .38401 .4065 Mtetra
.654 .747 .918 r
.38401 .4065 .39364 .41663 .40965 .41148 .40008 .40114 Mtetra
.653 .743 .916 r
.40008 .40114 .40965 .41148 .42576 .40625 .41626 .39578 Mtetra
.653 .742 .915 r
.41626 .39578 .42576 .40625 .44198 .40091 .43253 .39038 Mtetra
.654 .742 .914 r
.43253 .39038 .44198 .40091 .45829 .39547 .4489 .38491 Mtetra
.656 .743 .914 r
.4489 .38491 .45829 .39547 .4747 .38997 .46538 .37934 Mtetra
.657 .744 .914 r
.46538 .37934 .4747 .38997 .49121 .3844 .48195 .37368 Mtetra
.658 .744 .913 r
.48195 .37368 .49121 .3844 .50782 .37873 .49863 .36794 Mtetra
.658 .743 .913 r
.49863 .36794 .50782 .37873 .52454 .37294 .5154 .36217 Mtetra
.658 .745 .914 r
.5154 .36217 .52454 .37294 .54135 .36707 .53228 .35638 Mtetra
.655 .747 .918 r
.53228 .35638 .54135 .36707 .55826 .36124 .54927 .35068 Mtetra
.65 .75 .922 r
.54927 .35068 .55826 .36124 .57528 .35551 .56636 .34512 Mtetra
.654 .756 .925 r
.56636 .34512 .57528 .35551 .59241 .35001 .58356 .33937 Mtetra
.664 .755 .918 r
.58356 .33937 .59241 .35001 .60964 .34426 .60085 .33319 Mtetra
.666 .749 .912 r
.60085 .33319 .60964 .34426 .62697 .33803 .61825 .32687 Mtetra
.665 .748 .912 r
.61825 .32687 .62697 .33803 .6444 .33172 .63575 .32056 Mtetra
.657 .746 .916 r
.63575 .32056 .6444 .33172 .66193 .32554 .65337 .31456 Mtetra
.669 .756 .915 r
.65337 .31456 .66193 .32554 .67959 .31952 .67108 .30799 Mtetra
.689 .754 .901 r
.67108 .30799 .67959 .31952 .69729 .31239 .68884 .30044 Mtetra
.691 .747 .895 r
.68884 .30044 .69729 .31239 .71506 .30463 .70669 .29271 Mtetra
.642 .73 .912 r
.70669 .29271 .71506 .30463 .73297 .29759 .72478 .28719 Mtetra
.534 .715 .956 r
.72478 .28719 .73297 .29759 .75127 .29444 .74325 .2852 Mtetra
.428 .69 .974 r
.74325 .2852 .75127 .29444 .76995 .29421 .76205 .2855 Mtetra
.5 .743 .982 r
.76205 .2855 .76995 .29421 .78883 .29407 .78089 .2837 Mtetra
.65 .774 .939 r
.78089 .2837 .78883 .29407 .80751 .28956 .79952 .27761 Mtetra
.608 .712 .918 r
.14222 .4845 .15267 .49494 .16745 .48982 .15685 .48113 Mtetra
.71 .775 .903 r
.15685 .48113 .16745 .48982 .18275 .48061 .172 .47385 Mtetra
.783 .822 .883 r
.172 .47385 .18275 .48061 .19828 .46938 .18759 .46291 Mtetra
.774 .831 .896 r
.18759 .46291 .19828 .46938 .21365 .46031 .20314 .45262 Mtetra
.721 .802 .915 r
.20314 .45262 .21365 .46031 .22875 .45464 .21849 .44489 Mtetra
.633 .739 .924 r
.21849 .44489 .22875 .45464 .24375 .45111 .23361 .44055 Mtetra
.612 .716 .919 r
.23361 .44055 .24375 .45111 .25887 .44742 .24875 .43693 Mtetra
.621 .722 .918 r
.24875 .43693 .25887 .44742 .27415 .44279 .26403 .43296 Mtetra
.651 .746 .919 r
.26403 .43296 .27415 .44279 .28957 .43761 .27949 .42788 Mtetra
.653 .75 .921 r
.27949 .42788 .28957 .43761 .30506 .43274 .29505 .42267 Mtetra
.647 .742 .919 r
.29505 .42267 .30506 .43274 .32064 .42789 .31069 .41769 Mtetra
.646 .74 .918 r
.31069 .41769 .32064 .42789 .33632 .42291 .32642 .41271 Mtetra
.648 .742 .918 r
.32642 .41271 .33632 .42291 .35212 .41752 .34226 .40761 Mtetra
.655 .752 .921 r
.34226 .40761 .35212 .41752 .36802 .41194 .3582 .40221 Mtetra
.66 .758 .923 r
.3582 .40221 .36802 .41194 .38401 .4065 .37426 .39659 Mtetra
.659 .756 .921 r
.37426 .39659 .38401 .4065 .40008 .40114 .3904 .39095 Mtetra
.656 .75 .919 r
.3904 .39095 .40008 .40114 .41626 .39578 .40664 .3854 Mtetra
.655 .747 .917 r
.40664 .3854 .41626 .39578 .43253 .39038 .42298 .37987 Mtetra
.655 .745 .916 r
.42298 .37987 .43253 .39038 .4489 .38491 .43941 .37429 Mtetra
.656 .745 .915 r
.43941 .37429 .4489 .38491 .46538 .37934 .45595 .36866 Mtetra
.45595 .36866 .46538 .37934 .48195 .37368 .47259 .36297 Mtetra
.656 .746 .916 r
.47259 .36297 .48195 .37368 .49863 .36794 .48933 .35725 Mtetra
.655 .747 .917 r
.48933 .35725 .49863 .36794 .5154 .36217 .50617 .35153 Mtetra
.652 .748 .92 r
.50617 .35153 .5154 .36217 .53228 .35638 .52312 .34591 Mtetra
.652 .753 .924 r
.52312 .34591 .53228 .35638 .54927 .35068 .54017 .34027 Mtetra
.657 .757 .924 r
.54017 .34027 .54927 .35068 .56636 .34512 .55733 .33439 Mtetra
.663 .754 .918 r
.55733 .33439 .56636 .34512 .58356 .33937 .57459 .32821 Mtetra
.665 .748 .912 r
.57459 .32821 .58356 .33937 .60085 .33319 .59196 .3219 Mtetra
.664 .746 .911 r
.59196 .3219 .60085 .33319 .61825 .32687 .60943 .31559 Mtetra
.658 .745 .914 r
.60943 .31559 .61825 .32687 .63575 .32056 .62701 .3095 Mtetra
.661 .752 .918 r
.62701 .3095 .63575 .32056 .65337 .31456 .6447 .30327 Mtetra
.685 .758 .907 r
.6447 .30327 .65337 .31456 .67108 .30799 .66245 .2959 Mtetra
.691 .746 .893 r
.66245 .2959 .67108 .30799 .68884 .30044 .68029 .28814 Mtetra
.675 .737 .897 r
.68029 .28814 .68884 .30044 .70669 .29271 .69826 .28112 Mtetra
.587 .716 .932 r
.69826 .28112 .70669 .29271 .72478 .28719 .71655 .27761 Mtetra
.477 .71 .972 r
.71655 .27761 .72478 .28719 .74325 .2852 .73518 .27677 Mtetra
.422 .711 .984 r
.73518 .27677 .74325 .2852 .76205 .2855 .75405 .27665 Mtetra
.576 .78 .976 r
.75405 .27665 .76205 .2855 .78089 .2837 .7728 .27269 Mtetra
.694 .78 .917 r
.7728 .27269 .78089 .2837 .79952 .27761 .79136 .26463 Mtetra
.555 .682 .924 r
.13174 .47342 .14222 .4845 .15685 .48113 .14622 .47164 Mtetra
.668 .752 .913 r
.14622 .47164 .15685 .48113 .172 .47385 .16123 .46603 Mtetra
.75 .801 .894 r
.16123 .46603 .172 .47385 .18759 .46291 .17671 .45677 Mtetra
.787 .839 .891 r
.17671 .45677 .18759 .46291 .20314 .45262 .19242 .44567 Mtetra
.751 .824 .908 r
.19242 .44567 .20314 .45262 .21849 .44489 .20798 .43651 Mtetra
.686 .785 .925 r
.20798 .43651 .21849 .44489 .23361 .44055 .22333 .43013 Mtetra
.621 .724 .92 r
.22333 .43013 .23361 .44055 .24875 .43693 .23855 .42615 Mtetra
.617 .716 .916 r
.23855 .42615 .24875 .43693 .26403 .43296 .25386 .42228 Mtetra
.629 .724 .915 r
.25386 .42228 .26403 .43296 .27949 .42788 .26931 .41794 Mtetra
.653 .748 .919 r
.26931 .41794 .27949 .42788 .29505 .42267 .28492 .4127 Mtetra
.653 .748 .92 r
.28492 .4127 .29505 .42267 .31069 .41769 .30063 .4074 Mtetra
.648 .741 .917 r
.30063 .4074 .31069 .41769 .32642 .41271 .31642 .40229 Mtetra
.647 .74 .917 r
.31642 .40229 .32642 .41271 .34226 .40761 .33231 .39716 Mtetra
.649 .741 .917 r
.33231 .39716 .34226 .40761 .3582 .40221 .3483 .39195 Mtetra
.651 .747 .92 r
.3483 .39195 .3582 .40221 .37426 .39659 .36439 .3866 Mtetra
.657 .756 .923 r
.36439 .3866 .37426 .39659 .3904 .39095 .3806 .38102 Mtetra
.658 .759 .924 r
.3806 .38102 .3904 .39095 .40664 .3854 .3969 .37534 Mtetra
.658 .757 .923 r
.3969 .37534 .40664 .3854 .42298 .37987 .4133 .36964 Mtetra
.657 .754 .922 r
.4133 .36964 .42298 .37987 .43941 .37429 .4298 .36395 Mtetra
.656 .753 .921 r
.4298 .36395 .43941 .37429 .45595 .36866 .44641 .35825 Mtetra
.655 .753 .922 r
.44641 .35825 .45595 .36866 .47259 .36297 .46311 .35256 Mtetra
.654 .754 .923 r
.46311 .35256 .47259 .36297 .48933 .35725 .47991 .34687 Mtetra
.653 .755 .925 r
.47991 .34687 .48933 .35725 .50617 .35153 .49682 .34116 Mtetra
.655 .758 .925 r
.49682 .34116 .50617 .35153 .52312 .34591 .51384 .33535 Mtetra
.66 .757 .922 r
.51384 .33535 .52312 .34591 .54017 .34027 .53096 .3293 Mtetra
.663 .751 .915 r
.53096 .3293 .54017 .34027 .55733 .33439 .54819 .3231 Mtetra
.664 .746 .911 r
.54819 .3231 .55733 .33439 .57459 .32821 .56552 .31682 Mtetra
.663 .745 .911 r
.56552 .31682 .57459 .32821 .59196 .3219 .58296 .31052 Mtetra
.658 .744 .914 r
.58296 .31052 .59196 .3219 .60943 .31559 .60051 .3044 Mtetra
.659 .75 .918 r
.60051 .3044 .60943 .31559 .62701 .3095 .61817 .29822 Mtetra
.679 .757 .91 r
.61817 .29822 .62701 .3095 .6447 .30327 .6359 .29109 Mtetra
.687 .744 .894 r
.6359 .29109 .6447 .30327 .66245 .2959 .65372 .28348 Mtetra
.684 .739 .893 r
.65372 .28348 .66245 .2959 .68029 .28814 .67165 .27597 Mtetra
.628 .723 .915 r
.67165 .27597 .68029 .28814 .69826 .28112 .6898 .27092 Mtetra
.531 .724 .962 r
.6898 .27092 .69826 .28112 .71655 .27761 .70827 .26878 Mtetra
.427 .705 .98 r
.70827 .26878 .71655 .27761 .73518 .27677 .72703 .26866 Mtetra
.491 .759 .99 r
.72703 .26866 .73518 .27677 .75405 .27665 .74586 .26664 Mtetra
.638 .782 .95 r
.74586 .26664 .75405 .27665 .7728 .27269 .76456 .26082 Mtetra
.726 .777 .893 r
.76456 .26082 .7728 .27269 .79136 .26463 .78307 .25095 Mtetra
.535 .668 .923 r
.12119 .46196 .13174 .47342 .14622 .47164 .13563 .4607 Mtetra
.608 .707 .914 r
.13563 .4607 .14622 .47164 .16123 .46603 .15044 .45722 Mtetra
.7 .777 .911 r
.15044 .45722 .16123 .46603 .17671 .45677 .16573 .45025 Mtetra
.775 .833 .897 r
.16573 .45025 .17671 .45677 .19242 .44567 .18145 .43979 Mtetra
.778 .849 .905 r
.18145 .43979 .19242 .44567 .20798 .43651 .19722 .42927 Mtetra
.735 .82 .917 r
.19722 .42927 .20798 .43651 .22333 .43013 .21284 .4208 Mtetra
.663 .762 .924 r
.21284 .4208 .22333 .43013 .23855 .42615 .22825 .41522 Mtetra
.619 .716 .915 r
.22825 .41522 .23855 .42615 .25386 .42228 .2436 .41125 Mtetra
.622 .716 .914 r
.2436 .41125 .25386 .42228 .26931 .41794 .25907 .40713 Mtetra
.633 .725 .915 r
.25907 .40713 .26931 .41794 .28492 .4127 .27468 .4026 Mtetra
.653 .748 .919 r
.27468 .4026 .28492 .4127 .30063 .4074 .29044 .39726 Mtetra
.655 .749 .919 r
.29044 .39726 .30063 .4074 .31642 .40229 .30631 .39181 Mtetra
.649 .741 .917 r
.30631 .39181 .31642 .40229 .33231 .39716 .32226 .38654 Mtetra
.649 .74 .915 r
.32226 .38654 .33231 .39716 .3483 .39195 .3383 .38125 Mtetra
.65 .739 .915 r
.3383 .38125 .3483 .39195 .36439 .3866 .35445 .37591 Mtetra
.651 .741 .916 r
.35445 .37591 .36439 .3866 .3806 .38102 .3707 .37048 Mtetra
.653 .746 .918 r
.3707 .37048 .3806 .38102 .3969 .37534 .38706 .36495 Mtetra
.654 .751 .921 r
.38706 .36495 .3969 .37534 .4133 .36964 .40352 .35933 Mtetra
.655 .755 .923 r
.40352 .35933 .4133 .36964 .4298 .36395 .42008 .35364 Mtetra
.656 .756 .924 r
.42008 .35364 .4298 .36395 .44641 .35825 .43675 .34788 Mtetra
.657 .756 .923 r
.43675 .34788 .44641 .35825 .46311 .35256 .45352 .34206 Mtetra
.658 .755 .922 r
.45352 .34206 .46311 .35256 .47991 .34687 .47039 .33616 Mtetra
.659 .753 .919 r
.47039 .33616 .47991 .34687 .49682 .34116 .48738 .33017 Mtetra
.661 .749 .916 r
.48738 .33017 .49682 .34116 .51384 .33535 .50446 .32407 Mtetra
.662 .745 .912 r
.50446 .32407 .51384 .33535 .53096 .3293 .52165 .31788 Mtetra
.662 .743 .911 r
.52165 .31788 .53096 .3293 .54819 .3231 .53895 .31163 Mtetra
.662 .744 .911 r
.53895 .31163 .54819 .3231 .56552 .31682 .55635 .30536 Mtetra
.657 .743 .914 r
.55635 .30536 .56552 .31682 .58296 .31052 .57386 .29927 Mtetra
.659 .75 .918 r
.57386 .29927 .58296 .31052 .60051 .3044 .59149 .29306 Mtetra
.677 .756 .911 r
.59149 .29306 .60051 .3044 .61817 .29822 .6092 .28602 Mtetra
.684 .743 .896 r
.6092 .28602 .61817 .29822 .6359 .29109 .627 .27853 Mtetra
.685 .739 .891 r
.627 .27853 .6359 .29109 .65372 .28348 .6449 .27089 Mtetra
.65 .725 .904 r
.6449 .27089 .65372 .28348 .67165 .27597 .66297 .26489 Mtetra
.565 .721 .946 r
.66297 .26489 .67165 .27597 .6898 .27092 .68131 .26189 Mtetra
.46 .72 .981 r
.68131 .26189 .6898 .27092 .70827 .26878 .69993 .26102 Mtetra
.431 .739 .991 r
.69993 .26102 .70827 .26878 .72703 .26866 .71874 .26011 Mtetra
.588 .797 .979 r
.71874 .26011 .72703 .26866 .74586 .26664 .73749 .25558 Mtetra
.695 .783 .919 r
.73749 .25558 .74586 .26664 .76456 .26082 .75612 .24737 Mtetra
.73 .752 .87 r
.75612 .24737 .76456 .26082 .78307 .25095 .77465 .23683 Mtetra
.549 .68 .925 r
.11051 .45069 .12119 .46196 .13563 .4607 .12502 .44893 Mtetra
.555 .673 .917 r
.12502 .44893 .13563 .4607 .15044 .45722 .13966 .44708 Mtetra
.648 .739 .916 r
.13966 .44708 .15044 .45722 .16573 .45025 .15478 .4421 Mtetra
.726 .798 .909 r
.15478 .4421 .16573 .45025 .18145 .43979 .17032 .43394 Mtetra
.781 .851 .904 r
.17032 .43394 .18145 .43979 .19722 .42927 .1862 .42322 Mtetra
.766 .849 .914 r
.1862 .42322 .19722 .42927 .21284 .4208 .20203 .4133 Mtetra
.723 .816 .923 r
.20203 .4133 .21284 .4208 .22825 .41522 .21774 .40526 Mtetra
.653 .749 .92 r
.21774 .40526 .22825 .41522 .2436 .41125 .23326 .39996 Mtetra
.621 .713 .912 r
.23326 .39996 .2436 .41125 .25907 .40713 .24877 .39582 Mtetra
.625 .715 .911 r
.24877 .39582 .25907 .40713 .27468 .4026 .2644 .3915 Mtetra
.631 .723 .913 r
.2644 .3915 .27468 .4026 .29044 .39726 .28015 .38692 Mtetra
.651 .746 .919 r
.28015 .38692 .29044 .39726 .30631 .39181 .29606 .38155 Mtetra
.656 .75 .919 r
.29606 .38155 .30631 .39181 .32226 .38654 .31208 .37598 Mtetra
.653 .744 .917 r
.31208 .37598 .32226 .38654 .3383 .38125 .3282 .37046 Mtetra
.651 .74 .915 r
.3282 .37046 .3383 .38125 .35445 .37591 .3444 .365 Mtetra
.651 .739 .914 r
.3444 .365 .35445 .37591 .3707 .37048 .36072 .35949 Mtetra
.652 .739 .913 r
.36072 .35949 .3707 .37048 .38706 .36495 .37713 .35391 Mtetra
.653 .74 .913 r
.37713 .35391 .38706 .36495 .40352 .35933 .39365 .34825 Mtetra
.654 .741 .913 r
.39365 .34825 .40352 .35933 .42008 .35364 .41027 .34251 Mtetra
.656 .742 .913 r
.41027 .34251 .42008 .35364 .43675 .34788 .427 .33669 Mtetra
.657 .742 .913 r
.427 .33669 .43675 .34788 .45352 .34206 .44384 .33077 Mtetra
.658 .742 .912 r
.44384 .33077 .45352 .34206 .47039 .33616 .46078 .32478 Mtetra
.659 .742 .911 r
.46078 .32478 .47039 .33616 .48738 .33017 .47782 .3187 Mtetra
.66 .742 .911 r
.47782 .3187 .48738 .33017 .50446 .32407 .49498 .31256 Mtetra
.49498 .31256 .50446 .32407 .52165 .31788 .51223 .30635 Mtetra
.658 .743 .912 r
.51223 .30635 .52165 .31788 .53895 .31163 .5296 .3002 Mtetra
.656 .745 .916 r
.5296 .3002 .53895 .31163 .55635 .30536 .54708 .29411 Mtetra
.66 .752 .918 r
.54708 .29411 .55635 .30536 .57386 .29927 .56466 .2878 Mtetra
.678 .755 .909 r
.56466 .2878 .57386 .29927 .59149 .29306 .58234 .28068 Mtetra
.681 .74 .895 r
.58234 .28068 .59149 .29306 .6092 .28602 .60012 .27327 Mtetra
.683 .736 .89 r
.60012 .27327 .6092 .28602 .627 .27853 .61799 .26568 Mtetra
.658 .725 .899 r
.61799 .26568 .627 .27853 .6449 .27089 .63601 .25927 Mtetra
.584 .72 .936 r
.63601 .25927 .6449 .27089 .66297 .26489 .65426 .25567 Mtetra
.491 .733 .979 r
.65426 .25567 .66297 .26489 .68131 .26189 .67276 .25405 Mtetra
.424 .735 .991 r
.67276 .25405 .68131 .26189 .69993 .26102 .69149 .25326 Mtetra
.535 .794 .993 r
.69149 .25326 .69993 .26102 .71874 .26011 .71024 .24983 Mtetra
.66 .788 .943 r
.71024 .24983 .71874 .26011 .73749 .25558 .72894 .24308 Mtetra
.725 .768 .887 r
.72894 .24308 .73749 .25558 .75612 .24737 .74752 .23304 Mtetra
.719 .735 .864 r
.74752 .23304 .75612 .24737 .77465 .23683 .76618 .22286 Mtetra
.576 .695 .922 r
.09969 .43952 .11051 .45069 .12502 .44893 .11433 .43694 Mtetra
.547 .668 .916 r
.11433 .43694 .12502 .44893 .13966 .44708 .12897 .43527 Mtetra
.581 .686 .913 r
.12897 .43527 .13966 .44708 .15478 .4421 .14385 .43256 Mtetra
.671 .761 .918 r
.14385 .43256 .15478 .4421 .17032 .43394 .1592 .42661 Mtetra
.74 .82 .914 r
.1592 .42661 .17032 .43394 .1862 .42322 .17495 .41776 Mtetra
.778 .864 .913 r
.17495 .41776 .1862 .42322 .20203 .4133 .19094 .40716 Mtetra
.756 .851 .921 r
.19094 .40716 .20203 .4133 .21774 .40526 .20687 .39762 Mtetra
.717 .816 .926 r
.20687 .39762 .21774 .40526 .23326 .39996 .22269 .38975 Mtetra
.655 .748 .918 r
.22269 .38975 .23326 .39996 .24877 .39582 .23836 .38427 Mtetra
.626 .713 .909 r
.23836 .38427 .24877 .39582 .2644 .3915 .25404 .37985 Mtetra
.627 .713 .908 r
.25404 .37985 .2644 .3915 .28015 .38692 .26983 .37536 Mtetra
.632 .717 .909 r
.26983 .37536 .28015 .38692 .29606 .38155 .28574 .37066 Mtetra
.643 .736 .916 r
.28574 .37066 .29606 .38155 .31208 .37598 .30178 .36549 Mtetra
.654 .749 .92 r
.30178 .36549 .31208 .37598 .3282 .37046 .31795 .3599 Mtetra
.656 .749 .919 r
.31795 .3599 .3282 .37046 .3444 .365 .33423 .35419 Mtetra
.656 .745 .916 r
.33423 .35419 .3444 .365 .36072 .35949 .35061 .34844 Mtetra
.653 .741 .914 r
.35061 .34844 .36072 .35949 .37713 .35391 .36709 .34276 Mtetra
.654 .74 .913 r
.36709 .34276 .37713 .35391 .39365 .34825 .38367 .33701 Mtetra
.655 .74 .912 r
.38367 .33701 .39365 .34825 .41027 .34251 .40036 .33119 Mtetra
.656 .74 .912 r
.40036 .33119 .41027 .34251 .427 .33669 .41715 .32529 Mtetra
.657 .74 .912 r
.41715 .32529 .427 .33669 .44384 .33077 .43405 .31933 Mtetra
.657 .741 .911 r
.43405 .31933 .44384 .33077 .46078 .32478 .45105 .31329 Mtetra
.658 .742 .912 r
.45105 .31329 .46078 .32478 .47782 .3187 .46816 .30718 Mtetra
.656 .742 .913 r
.46816 .30718 .47782 .3187 .49498 .31256 .48538 .30114 Mtetra
.656 .745 .916 r
.48538 .30114 .49498 .31256 .51223 .30635 .50271 .29505 Mtetra
.658 .75 .918 r
.50271 .29505 .51223 .30635 .5296 .3002 .52015 .28884 Mtetra
.668 .754 .915 r
.52015 .28884 .5296 .3002 .54708 .29411 .53769 .28219 Mtetra
.677 .747 .904 r
.53769 .28219 .54708 .29411 .56466 .2878 .55534 .27507 Mtetra
.679 .734 .892 r
.55534 .27507 .56466 .2878 .58234 .28068 .57309 .26771 Mtetra
.679 .731 .889 r
.57309 .26771 .58234 .28068 .60012 .27327 .59094 .26028 Mtetra
.656 .723 .898 r
.59094 .26028 .60012 .27327 .61799 .26568 .60892 .25391 Mtetra
.592 .722 .934 r
.60892 .25391 .61799 .26568 .63601 .25927 .6271 .25002 Mtetra
.511 .744 .979 r
.6271 .25002 .63601 .25927 .65426 .25567 .6455 .24784 Mtetra
.433 .741 .992 r
.6455 .24784 .65426 .25567 .67276 .25405 .66412 .24679 Mtetra
.499 .791 .997 r
.66412 .24679 .67276 .25405 .69149 .25326 .68284 .24393 Mtetra
.632 .8 .963 r
.68284 .24393 .69149 .25326 .71024 .24983 .70155 .23806 Mtetra
.713 .779 .904 r
.70155 .23806 .71024 .24983 .72894 .24308 .72018 .2288 Mtetra
.722 .738 .864 r
.72018 .2288 .72894 .24308 .74752 .23304 .73883 .21842 Mtetra
.705 .727 .868 r
.73883 .21842 .74752 .23304 .76618 .22286 .75762 .20898 Mtetra
.61 .72 .924 r
.08867 .42894 .09969 .43952 .11433 .43694 .10348 .42523 Mtetra
.573 .686 .917 r
.10348 .42523 .11433 .43694 .12897 .43527 .11825 .4227 Mtetra
.552 .662 .909 r
.11825 .4227 .12897 .43527 .14385 .43256 .13304 .42088 Mtetra
.602 .699 .912 r
.13304 .42088 .14385 .43256 .1592 .42661 .14815 .41738 Mtetra
.68 .773 .921 r
.14815 .41738 .1592 .42661 .17495 .41776 .16369 .41099 Mtetra
.744 .837 .922 r
.16369 .41099 .17495 .41776 .19094 .40716 .17959 .40196 Mtetra
.773 .874 .921 r
.17959 .40196 .19094 .40716 .20687 .39762 .19569 .39159 Mtetra
.751 .857 .928 r
.19569 .39159 .20687 .39762 .22269 .38975 .21173 .38221 Mtetra
.717 .822 .93 r
.21173 .38221 .22269 .38975 .23836 .38427 .2277 .37426 Mtetra
.667 .759 .919 r
.2277 .37426 .23836 .38427 .25404 .37985 .24357 .36822 Mtetra
.636 .718 .907 r
.24357 .36822 .25404 .37985 .26983 .37536 .25943 .36335 Mtetra
.629 .71 .904 r
.25943 .36335 .26983 .37536 .28574 .37066 .27537 .35871 Mtetra
.634 .714 .905 r
.27537 .35871 .28574 .37066 .30178 .36549 .29144 .35383 Mtetra
.638 .722 .909 r
.29144 .35383 .30178 .36549 .31795 .3599 .30763 .34875 Mtetra
.645 .736 .915 r
.30763 .34875 .31795 .3599 .33423 .35419 .32394 .3434 Mtetra
.653 .747 .919 r
.32394 .3434 .33423 .35419 .35061 .34844 .34037 .33769 Mtetra
.655 .75 .92 r
.34037 .33769 .35061 .34844 .36709 .34276 .35692 .33187 Mtetra
.656 .749 .919 r
.35692 .33187 .36709 .34276 .38367 .33701 .37356 .326 Mtetra
.656 .748 .917 r
.37356 .326 .38367 .33701 .40036 .33119 .39031 .32007 Mtetra
.656 .747 .917 r
.39031 .32007 .40036 .33119 .41715 .32529 .40717 .31411 Mtetra
.40717 .31411 .41715 .32529 .43405 .31933 .42413 .30811 Mtetra
.656 .748 .917 r
.42413 .30811 .43405 .31933 .45105 .31329 .4412 .30206 Mtetra
.657 .749 .918 r
.4412 .30206 .45105 .31329 .46816 .30718 .45838 .29595 Mtetra
.659 .751 .918 r
.45838 .29595 .46816 .30718 .48538 .30114 .47567 .28973 Mtetra
.666 .752 .914 r
.47567 .28973 .48538 .30114 .50271 .29505 .49307 .28314 Mtetra
.671 .745 .906 r
.49307 .28314 .50271 .29505 .52015 .28884 .51058 .27627 Mtetra
.674 .735 .896 r
.51058 .27627 .52015 .28884 .53769 .28219 .5282 .26919 Mtetra
.677 .729 .889 r
.5282 .26919 .53769 .28219 .55534 .27507 .54591 .26186 Mtetra
.672 .725 .89 r
.54591 .26186 .55534 .27507 .57309 .26771 .56374 .25474 Mtetra
.645 .72 .903 r
.56374 .25474 .57309 .26771 .59094 .26028 .58169 .24883 Mtetra
.591 .73 .94 r
.58169 .24883 .59094 .26028 .60892 .25391 .59981 .24487 Mtetra
.517 .754 .982 r
.59981 .24487 .60892 .25391 .6271 .25002 .61812 .2424 Mtetra
.442 .753 .994 r
.61812 .2424 .6271 .25002 .6455 .24784 .63665 .24096 Mtetra
.486 .795 .999 r
.63665 .24096 .6455 .24784 .66412 .24679 .65529 .23815 Mtetra
.616 .811 .975 r
.65529 .23815 .66412 .24679 .68284 .24393 .67398 .2326 Mtetra
.7 .784 .917 r
.67398 .2326 .68284 .24393 .70155 .23806 .69263 .22403 Mtetra
.722 .744 .869 r
.69263 .22403 .70155 .23806 .72018 .2288 .71128 .21369 Mtetra
.705 .721 .862 r
.71128 .21369 .72018 .2288 .73883 .21842 .73006 .20407 Mtetra
.686 .727 .881 r
.73006 .20407 .73883 .21842 .75762 .20898 .74903 .19566 Mtetra
.645 .745 .922 r
.07744 .41892 .08867 .42894 .10348 .42523 .09246 .41395 Mtetra
.6 .706 .918 r
.09246 .41395 .10348 .42523 .11825 .4227 .10737 .4105 Mtetra
.572 .679 .913 r
.10737 .4105 .11825 .4227 .13304 .42088 .12227 .40798 Mtetra
.561 .663 .905 r
.12227 .40798 .13304 .42088 .14815 .41738 .13724 .40582 Mtetra
.613 .709 .913 r
.13724 .40582 .14815 .41738 .16369 .41099 .15254 .40187 Mtetra
.681 .779 .925 r
.15254 .40187 .16369 .41099 .17959 .40196 .16822 .39538 Mtetra
.737 .844 .93 r
.16822 .39538 .17959 .40196 .19569 .39159 .18423 .38659 Mtetra
.764 .882 .93 r
.18423 .38659 .19569 .39159 .21173 .38221 .20043 .37652 Mtetra
.75 .868 .934 r
.20043 .37652 .21173 .38221 .2277 .37426 .21662 .3671 Mtetra
.72 .834 .935 r
.21662 .3671 .2277 .37426 .24357 .36822 .23276 .35893 Mtetra
.688 .783 .923 r
.23276 .35893 .24357 .36822 .25943 .36335 .24885 .35198 Mtetra
.649 .731 .909 r
.24885 .35198 .25943 .36335 .27537 .35871 .26491 .3465 Mtetra
.637 .712 .902 r
.26491 .3465 .27537 .35871 .29144 .35383 .28104 .34145 Mtetra
.635 .71 .901 r
.28104 .34145 .29144 .35383 .30763 .34875 .29727 .33643 Mtetra
.64 .714 .901 r
.29727 .33643 .30763 .34875 .32394 .3434 .31362 .33117 Mtetra
.643 .718 .902 r
.31362 .33117 .32394 .3434 .34037 .33769 .33008 .32577 Mtetra
.647 .726 .907 r
.33008 .32577 .34037 .33769 .35692 .33187 .34666 .32019 Mtetra
.65 .734 .91 r
.34666 .32019 .35692 .33187 .37356 .326 .36336 .31445 Mtetra
.653 .739 .912 r
.36336 .31445 .37356 .326 .39031 .32007 .38017 .30856 Mtetra
.656 .741 .913 r
.38017 .30856 .39031 .32007 .40717 .31411 .39709 .30252 Mtetra
.658 .742 .912 r
.39709 .30252 .40717 .31411 .42413 .30811 .41412 .29635 Mtetra
.661 .741 .91 r
.41412 .29635 .42413 .30811 .4412 .30206 .43126 .29002 Mtetra
.663 .738 .905 r
.43126 .29002 .4412 .30206 .45838 .29595 .44851 .28353 Mtetra
.666 .733 .9 r
.44851 .28353 .45838 .29595 .47567 .28973 .46588 .27686 Mtetra
.668 .727 .894 r
.46588 .27686 .47567 .28973 .49307 .28314 .48334 .27003 Mtetra
.672 .725 .89 r
.48334 .27003 .49307 .28314 .51058 .27627 .50092 .26296 Mtetra
.67 .722 .888 r
.50092 .26296 .51058 .27627 .5282 .26919 .5186 .2559 Mtetra
.66 .721 .893 r
.5186 .2559 .5282 .26919 .54591 .26186 .53639 .24929 Mtetra
.625 .721 .916 r
.53639 .24929 .54591 .26186 .56374 .25474 .5543 .24416 Mtetra
.582 .746 .955 r
.5543 .24416 .56374 .25474 .58169 .24883 .57237 .24029 Mtetra
.511 .765 .988 r
.57237 .24029 .58169 .24883 .59981 .24487 .59061 .23771 Mtetra
.449 .77 .997 r
.59061 .23771 .59981 .24487 .61812 .2424 .60904 .23581 Mtetra
.494 .807 1 r
.60904 .23581 .61812 .2424 .63665 .24096 .62761 .2326 Mtetra
.613 .818 .979 r
.62761 .2326 .63665 .24096 .65529 .23815 .64624 .22703 Mtetra
.692 .787 .923 r
.64624 .22703 .65529 .23815 .67398 .2326 .6649 .2188 Mtetra
.719 .747 .874 r
.6649 .2188 .67398 .2326 .69263 .22403 .68356 .2087 Mtetra
.706 .719 .859 r
.68356 .2087 .69263 .22403 .71128 .21369 .70232 .19894 Mtetra
.692 .724 .874 r
.70232 .19894 .71128 .21369 .73006 .20407 .72124 .19012 Mtetra
.663 .727 .897 r
.72124 .19012 .73006 .20407 .74903 .19566 .74038 .18289 Mtetra
.657 .753 .921 r
.06605 .40904 .07744 .41892 .09246 .41395 .08118 .40358 Mtetra
.64 .74 .921 r
.08118 .40358 .09246 .41395 .10737 .4105 .09631 .39868 Mtetra
.597 .698 .914 r
.09631 .39868 .10737 .4105 .12227 .40798 .11135 .39527 Mtetra
.575 .674 .906 r
.11135 .39527 .12227 .40798 .13724 .40582 .12641 .39258 Mtetra
.569 .663 .901 r
.12641 .39258 .13724 .40582 .15254 .40187 .14155 .39012 Mtetra
.613 .709 .913 r
.14155 .39012 .15254 .40187 .16822 .39538 .157 .38607 Mtetra
.674 .777 .928 r
.157 .38607 .16822 .39538 .18423 .38659 .17281 .37975 Mtetra
.72 .841 .939 r
.17281 .37975 .18423 .38659 .20043 .37652 .18889 .37158 Mtetra
.752 .886 .94 r
.18889 .37158 .20043 .37652 .21662 .3671 .20519 .36196 Mtetra
.749 .884 .94 r
.20519 .36196 .21662 .3671 .23276 .35893 .22154 .35241 Mtetra
.723 .853 .943 r
.22154 .35241 .23276 .35893 .24885 .35198 .23785 .344 Mtetra
.702 .818 .937 r
.23785 .344 .24885 .35198 .26491 .3465 .25415 .3364 Mtetra
.678 .769 .92 r
.25415 .3364 .26491 .3465 .28104 .34145 .27046 .3297 Mtetra
.652 .73 .906 r
.27046 .3297 .28104 .34145 .29727 .33643 .2868 .32394 Mtetra
.645 .715 .899 r
.2868 .32394 .29727 .33643 .31362 .33117 .30321 .31843 Mtetra
.643 .711 .896 r
.30321 .31843 .31362 .33117 .33008 .32577 .31973 .31294 Mtetra
.645 .711 .896 r
.31973 .31294 .33008 .32577 .34666 .32019 .33636 .30735 Mtetra
.648 .713 .896 r
.33636 .30735 .34666 .32019 .36336 .31445 .35311 .3016 Mtetra
.651 .716 .895 r
.35311 .3016 .36336 .31445 .38017 .30856 .36997 .29565 Mtetra
.654 .717 .894 r
.36997 .29565 .38017 .30856 .39709 .30252 .38695 .28954 Mtetra
.657 .718 .894 r
.38695 .28954 .39709 .30252 .41412 .29635 .40404 .28328 Mtetra
.66 .719 .892 r
.40404 .28328 .41412 .29635 .43126 .29002 .42124 .27682 Mtetra
.663 .719 .89 r
.42124 .27682 .43126 .29002 .44851 .28353 .43856 .27019 Mtetra
.664 .718 .889 r
.43856 .27019 .44851 .28353 .46588 .27686 .45598 .26346 Mtetra
.663 .718 .89 r
.45598 .26346 .46588 .27686 .48334 .27003 .47351 .25674 Mtetra
.657 .719 .894 r
.47351 .25674 .48334 .27003 .50092 .26296 .49114 .25027 Mtetra
.635 .723 .911 r
.49114 .25027 .50092 .26296 .5186 .2559 .50889 .24475 Mtetra
.607 .744 .942 r
.50889 .24475 .5186 .2559 .53639 .24929 .52675 .24015 Mtetra
.564 .774 .977 r
.52675 .24015 .53639 .24929 .5543 .24416 .54477 .23638 Mtetra
.495 .778 .995 r
.54477 .23638 .5543 .24416 .57237 .24029 .56295 .23379 Mtetra
.458 .792 .999 r
.56295 .23379 .57237 .24029 .59061 .23771 .58129 .2313 Mtetra
.524 .826 1 r
.58129 .2313 .59061 .23771 .60904 .23581 .59978 .22731 Mtetra
.623 .82 .976 r
.59978 .22731 .60904 .23581 .62761 .2326 .61835 .22141 Mtetra
.692 .786 .923 r
.61835 .22141 .62761 .2326 .64624 .22703 .63698 .21315 Mtetra
.715 .746 .876 r
.63698 .21315 .64624 .22703 .6649 .2188 .65564 .20323 Mtetra
.704 .715 .858 r
.65564 .20323 .6649 .2188 .68356 .2087 .6744 .19352 Mtetra
.693 .718 .869 r
.6744 .19352 .68356 .2087 .70232 .19894 .6933 .18454 Mtetra
.666 .721 .89 r
.6933 .18454 .70232 .19894 .72124 .19012 .71239 .1771 Mtetra
.655 .743 .915 r
.71239 .1771 .72124 .19012 .74038 .18289 .73165 .17023 Mtetra
.656 .752 .92 r
.05454 .39901 .06605 .40904 .08118 .40358 .06971 .39351 Mtetra
.656 .752 .921 r
.06971 .39351 .08118 .40358 .09631 .39868 .08498 .38797 Mtetra
.638 .736 .919 r
.08498 .38797 .09631 .39868 .11135 .39527 .10025 .38306 Mtetra
.6 .695 .91 r
.10025 .38306 .11135 .39527 .12641 .39258 .11545 .37946 Mtetra
.582 .673 .901 r
.11545 .37946 .12641 .39258 .14155 .39012 .13068 .37648 Mtetra
.574 .661 .896 r
.13068 .37648 .14155 .39012 .157 .38607 .14599 .37377 Mtetra
.605 .699 .91 r
.14599 .37377 .157 .38607 .17281 .37975 .16155 .36993 Mtetra
.661 .767 .928 r
.16155 .36993 .17281 .37975 .18889 .37158 .17745 .36399 Mtetra
.695 .824 .944 r
.17745 .36399 .18889 .37158 .20519 .36196 .19359 .35671 Mtetra
.732 .882 .95 r
.19359 .35671 .20519 .36196 .22154 .35241 .20997 .34781 Mtetra
.737 .898 .951 r
.20997 .34781 .22154 .35241 .23785 .344 .22644 .33857 Mtetra
.729 .881 .951 r
.22644 .33857 .23785 .344 .25415 .3364 .24295 .32971 Mtetra
.708 .852 .951 r
.24295 .32971 .25415 .3364 .27046 .3297 .25945 .32173 Mtetra
.694 .823 .944 r
.25945 .32173 .27046 .3297 .2868 .32394 .27598 .31432 Mtetra
.681 .785 .929 r
.27598 .31432 .2868 .32394 .30321 .31843 .29256 .30739 Mtetra
.668 .754 .915 r
.29256 .30739 .30321 .31843 .31973 .31294 .3092 .30087 Mtetra
.656 .732 .905 r
.3092 .30087 .31973 .31294 .33636 .30735 .32592 .29478 Mtetra
.654 .723 .899 r
.32592 .29478 .33636 .30735 .35311 .3016 .34274 .28872 Mtetra
.653 .718 .896 r
.34274 .28872 .35311 .3016 .36997 .29565 .35966 .28262 Mtetra
.654 .717 .895 r
.35966 .28262 .36997 .29565 .38695 .28954 .3767 .27644 Mtetra
.655 .718 .894 r
.3767 .27644 .38695 .28954 .40404 .28328 .39384 .27018 Mtetra
.655 .719 .895 r
.39384 .27018 .40404 .28328 .42124 .27682 .4111 .26388 Mtetra
.654 .723 .899 r
.4111 .26388 .42124 .27682 .43856 .27019 .42847 .25761 Mtetra
.644 .727 .909 r
.42847 .25761 .43856 .27019 .45598 .26346 .44593 .25177 Mtetra
.632 .742 .927 r
.44593 .25177 .45598 .26346 .47351 .25674 .46351 .24634 Mtetra
.614 .764 .951 r
.46351 .24634 .47351 .25674 .49114 .25027 .4812 .24141 Mtetra
.583 .789 .977 r
.4812 .24141 .49114 .25027 .50889 .24475 .49902 .23706 Mtetra
.53 .796 .994 r
.49902 .23706 .50889 .24475 .52675 .24015 .51698 .2336 Mtetra
.486 .805 1 r
.51698 .2336 .52675 .24015 .54477 .23638 .5351 .23056 Mtetra
.482 .82 .999 r
.5351 .23056 .54477 .23638 .56295 .23379 .55337 .22716 Mtetra
.571 .842 .996 r
.55337 .22716 .56295 .23379 .58129 .2313 .57178 .22212 Mtetra
.643 .813 .965 r
.57178 .22212 .58129 .2313 .59978 .22731 .59031 .21569 Mtetra
.698 .781 .915 r
.59031 .21569 .59978 .22731 .61835 .22141 .6089 .20709 Mtetra
.711 .738 .872 r
.6089 .20709 .61835 .22141 .63698 .21315 .62755 .19729 Mtetra
.699 .71 .857 r
.62755 .19729 .63698 .21315 .65564 .20323 .64631 .18776 Mtetra
.69 .714 .867 r
.64631 .18776 .65564 .20323 .6744 .19352 .66518 .17883 Mtetra
.667 .718 .887 r
.66518 .17883 .6744 .19352 .6933 .18454 .68424 .17127 Mtetra
.655 .74 .912 r
.68424 .17127 .6933 .18454 .71239 .1771 .70345 .16435 Mtetra
.655 .752 .921 r
.70345 .16435 .71239 .1771 .73165 .17023 .7228 .15737 Mtetra
.655 .751 .92 r
.04291 .38883 .05454 .39901 .06971 .39351 .05813 .38331 Mtetra
.656 .752 .92 r
.05813 .38331 .06971 .39351 .08498 .38797 .07344 .37772 Mtetra
.07344 .37772 .08498 .38797 .10025 .38306 .08885 .37208 Mtetra
.641 .735 .917 r
.08885 .37208 .10025 .38306 .11545 .37946 .10428 .36697 Mtetra
.606 .695 .906 r
.10428 .36697 .11545 .37946 .13068 .37648 .11965 .36309 Mtetra
.593 .675 .898 r
.11965 .36309 .13068 .37648 .14599 .37377 .13507 .35967 Mtetra
.579 .658 .891 r
.13507 .35967 .14599 .37377 .16155 .36993 .15055 .35672 Mtetra
.597 .682 .901 r
.15055 .35672 .16155 .36993 .17745 .36399 .16623 .35309 Mtetra
.64 .743 .923 r
.16623 .35309 .17745 .36399 .19359 .35671 .1822 .34784 Mtetra
.674 .796 .94 r
.1822 .34784 .19359 .35671 .20997 .34781 .19841 .34128 Mtetra
.694 .853 .958 r
.19841 .34128 .20997 .34781 .22644 .33857 .2148 .33377 Mtetra
.715 .895 .961 r
.2148 .33377 .22644 .33857 .24295 .32971 .23137 .32521 Mtetra
.713 .902 .963 r
.23137 .32521 .24295 .32971 .25945 .32173 .24802 .31659 Mtetra
.708 .89 .963 r
.24802 .31659 .25945 .32173 .27598 .31432 .26472 .30824 Mtetra
.696 .869 .964 r
.26472 .30824 .27598 .31432 .29256 .30739 .28146 .30042 Mtetra
.683 .849 .962 r
.28146 .30042 .29256 .30739 .3092 .30087 .29824 .29313 Mtetra
.675 .831 .958 r
.29824 .29313 .3092 .30087 .32592 .29478 .31509 .28617 Mtetra
.668 .811 .952 r
.31509 .28617 .32592 .29478 .34274 .28872 .33202 .27948 Mtetra
.661 .797 .947 r
.33202 .27948 .34274 .28872 .35966 .28262 .34904 .27303 Mtetra
.655 .789 .946 r
.34904 .27303 .35966 .28262 .3767 .27644 .36615 .26678 Mtetra
.648 .787 .948 r
.36615 .26678 .3767 .27644 .39384 .27018 .38337 .26073 Mtetra
.64 .791 .955 r
.38337 .26073 .39384 .27018 .4111 .26388 .40068 .25491 Mtetra
.627 .799 .965 r
.40068 .25491 .4111 .26388 .42847 .25761 .4181 .24938 Mtetra
.609 .811 .978 r
.4181 .24938 .42847 .25761 .44593 .25177 .43564 .24418 Mtetra
.581 .818 .989 r
.43564 .24418 .44593 .25177 .46351 .24634 .45329 .23952 Mtetra
.544 .822 .997 r
.45329 .23952 .46351 .24634 .4812 .24141 .47106 .2354 Mtetra
.512 .828 1 r
.47106 .2354 .4812 .24141 .49902 .23706 .48898 .23156 Mtetra
.498 .835 .998 r
.48898 .23156 .49902 .23706 .51698 .2336 .50705 .22768 Mtetra
.555 .851 .998 r
.50705 .22768 .51698 .2336 .5351 .23056 .52527 .22273 Mtetra
.618 .834 .983 r
.52527 .22273 .5351 .23056 .55337 .22716 .54362 .21679 Mtetra
.669 .796 .943 r
.54362 .21679 .55337 .22716 .57178 .22212 .56209 .20952 Mtetra
.702 .764 .9 r
.56209 .20952 .57178 .22212 .59031 .21569 .58065 .20055 Mtetra
.705 .723 .864 r
.58065 .20055 .59031 .21569 .6089 .20709 .59929 .19087 Mtetra
.692 .703 .856 r
.59929 .19087 .6089 .20709 .62755 .19729 .61804 .18166 Mtetra
.686 .711 .867 r
.61804 .18166 .62755 .19729 .64631 .18776 .6369 .1729 Mtetra
.664 .716 .887 r
.6369 .1729 .64631 .18776 .66518 .17883 .65592 .1654 Mtetra
.655 .738 .911 r
.65592 .1654 .66518 .17883 .68424 .17127 .6751 .15843 Mtetra
.656 .752 .921 r
.6751 .15843 .68424 .17127 .70345 .16435 .6944 .15141 Mtetra
.656 .752 .92 r
.6944 .15141 .70345 .16435 .7228 .15737 .71384 .1443 Mtetra
.651 .747 .92 r
.03117 .3784 .04291 .38883 .05813 .38331 .04641 .37296 Mtetra
.655 .751 .92 r
.04641 .37296 .05813 .38331 .07344 .37772 .06177 .36734 Mtetra
.656 .752 .92 r
.06177 .36734 .07344 .37772 .08885 .37208 .07723 .36165 Mtetra
.657 .752 .92 r
.07723 .36165 .08885 .37208 .10428 .36697 .09279 .35589 Mtetra
.645 .737 .916 r
.09279 .35589 .10428 .36697 .11965 .36309 .10839 .35053 Mtetra
.617 .701 .905 r
.10839 .35053 .11965 .36309 .13507 .35967 .12396 .34617 Mtetra
.602 .68 .896 r
.12396 .34617 .13507 .35967 .15055 .35672 .13957 .34233 Mtetra
.591 .662 .887 r
.13957 .34233 .15055 .35672 .16623 .35309 .15525 .33888 Mtetra
.594 .667 .89 r
.15525 .33888 .16623 .35309 .1822 .34784 .17106 .33528 Mtetra
.613 .705 .91 r
.17106 .33528 .1822 .34784 .19841 .34128 .18708 .33091 Mtetra
.651 .762 .931 r
.18708 .33091 .19841 .34128 .2148 .33377 .20336 .32511 Mtetra
.669 .804 .947 r
.20336 .32511 .2148 .33377 .23137 .32521 .21981 .31855 Mtetra
.677 .852 .966 r
.21981 .31855 .23137 .32521 .24802 .31659 .23641 .31146 Mtetra
.684 .888 .973 r
.23641 .31146 .24802 .31659 .26472 .30824 .25315 .30377 Mtetra
.681 .903 .975 r
.25315 .30377 .26472 .30824 .28146 .30042 .26998 .29593 Mtetra
.672 .902 .977 r
.26998 .29593 .28146 .30042 .29824 .29313 .28689 .28828 Mtetra
.664 .894 .98 r
.28689 .28828 .29824 .29313 .31509 .28617 .30387 .28092 Mtetra
.654 .885 .982 r
.30387 .28092 .31509 .28617 .33202 .27948 .32092 .27389 Mtetra
.643 .876 .984 r
.32092 .27389 .33202 .27948 .34904 .27303 .33805 .26722 Mtetra
.63 .869 .987 r
.33805 .26722 .34904 .27303 .36615 .26678 .35526 .2609 Mtetra
.615 .865 .99 r
.35526 .2609 .36615 .26678 .38337 .26073 .37256 .25494 Mtetra
.597 .862 .993 r
.37256 .25494 .38337 .26073 .40068 .25491 .38996 .24933 Mtetra
.575 .86 .996 r
.38996 .24933 .40068 .25491 .4181 .24938 .40748 .24406 Mtetra
.554 .859 .997 r
.40748 .24406 .4181 .24938 .43564 .24418 .42511 .2391 Mtetra
.536 .858 .997 r
.42511 .2391 .43564 .24418 .45329 .23952 .44286 .23432 Mtetra
.543 .86 .997 r
.44286 .23432 .45329 .23952 .47106 .2354 .46076 .22939 Mtetra
.583 .859 .995 r
.46076 .22939 .47106 .2354 .48898 .23156 .47881 .22387 Mtetra
.623 .838 .982 r
.47881 .22387 .48898 .23156 .50705 .22768 .49699 .21779 Mtetra
.657 .802 .952 r
.49699 .21779 .50705 .22768 .52527 .22273 .5153 .21094 Mtetra
.692 .776 .916 r
.5153 .21094 .52527 .22273 .54362 .21679 .53373 .20261 Mtetra
.699 .736 .88 r
.53373 .20261 .54362 .21679 .56209 .20952 .55226 .19348 Mtetra
.694 .706 .857 r
.55226 .19348 .56209 .20952 .58065 .20055 .57088 .18418 Mtetra
.686 .699 .857 r
.57088 .18418 .58065 .20055 .59929 .19087 .58961 .17525 Mtetra
.679 .709 .871 r
.58961 .17525 .59929 .19087 .61804 .18166 .60845 .16684 Mtetra
.661 .716 .889 r
.60845 .16684 .61804 .18166 .6369 .1729 .62744 .15947 Mtetra
.654 .74 .912 r
.62744 .15947 .6369 .1729 .65592 .1654 .64658 .15248 Mtetra
.656 .752 .921 r
.64658 .15248 .65592 .1654 .6751 .15843 .66584 .14541 Mtetra
.656 .752 .92 r
.66584 .14541 .6751 .15843 .6944 .15141 .68523 .13827 Mtetra
.66 .753 .919 r
.68523 .13827 .6944 .15141 .71384 .1443 .70475 .13092 Mtetra
.654 .75 .92 r
.01928 .36795 .03117 .3784 .04641 .37296 .03459 .36234 Mtetra
.651 .747 .92 r
.03459 .36234 .04641 .37296 .06177 .36734 .04998 .3568 Mtetra
.655 .751 .92 r
.04998 .3568 .06177 .36734 .07723 .36165 .06549 .35108 Mtetra
.656 .752 .92 r
.06549 .35108 .07723 .36165 .09279 .35589 .08109 .34529 Mtetra
.657 .752 .92 r
.08109 .34529 .09279 .35589 .10839 .35053 .0968 .33942 Mtetra
.65 .742 .917 r
.0968 .33942 .10839 .35053 .12396 .34617 .11258 .33377 Mtetra
.631 .713 .905 r
.11258 .33377 .12396 .34617 .13957 .34233 .12837 .32877 Mtetra
.612 .686 .895 r
.12837 .32877 .13957 .34233 .15525 .33888 .14418 .32445 Mtetra
.606 .67 .885 r
.14418 .32445 .15525 .33888 .17106 .33528 .16008 .32032 Mtetra
.598 .659 .881 r
.16008 .32032 .17106 .33528 .18708 .33091 .17606 .31648 Mtetra
.605 .672 .888 r
.17606 .31648 .18708 .33091 .20336 .32511 .1922 .3123 Mtetra
.62 .708 .908 r
.1922 .3123 .20336 .32511 .21981 .31855 .20851 .30755 Mtetra
.644 .752 .928 r
.20851 .30755 .21981 .31855 .23641 .31146 .22503 .30188 Mtetra
.657 .787 .944 r
.22503 .30188 .23641 .31146 .25315 .30377 .24171 .29563 Mtetra
.662 .821 .96 r
.24171 .29563 .25315 .30377 .26998 .29593 .25852 .28907 Mtetra
.659 .85 .973 r
.25852 .28907 .26998 .29593 .28689 .28828 .27544 .28235 Mtetra
.651 .87 .981 r
.27544 .28235 .28689 .28828 .30387 .28092 .29247 .27559 Mtetra
.639 .881 .986 r
.29247 .27559 .30387 .28092 .32092 .27389 .30959 .2689 Mtetra
.626 .886 .988 r
.30959 .2689 .32092 .27389 .33805 .26722 .32681 .26235 Mtetra
.615 .886 .99 r
.32681 .26235 .33805 .26722 .35526 .2609 .34413 .25596 Mtetra
.606 .883 .991 r
.34413 .25596 .35526 .2609 .37256 .25494 .36155 .24974 Mtetra
.602 .878 .992 r
.36155 .24974 .37256 .25494 .38996 .24933 .37907 .24366 Mtetra
.604 .871 .992 r
.37907 .24366 .38996 .24933 .40748 .24406 .39672 .23764 Mtetra
.614 .859 .99 r
.39672 .23764 .40748 .24406 .42511 .2391 .41448 .23159 Mtetra
.629 .842 .982 r
.41448 .23159 .42511 .2391 .44286 .23432 .43238 .22538 Mtetra
.647 .817 .965 r
.43238 .22538 .44286 .23432 .46076 .22939 .4504 .21885 Mtetra
.666 .79 .941 r
.4504 .21885 .46076 .22939 .47881 .22387 .46855 .21173 Mtetra
.686 .766 .913 r
.46855 .21173 .47881 .22387 .49699 .21779 .48684 .20365 Mtetra
.691 .734 .883 r
.48684 .20365 .49699 .21779 .5153 .21094 .50523 .19498 Mtetra
.69 .706 .859 r
.50523 .19498 .5153 .21094 .53373 .20261 .52373 .18595 Mtetra
.682 .693 .854 r
.52373 .18595 .53373 .20261 .55226 .19348 .54232 .1772 Mtetra
.68 .699 .861 r
.54232 .1772 .55226 .19348 .57088 .18418 .56102 .16863 Mtetra
.669 .708 .876 r
.56102 .16863 .57088 .18418 .58961 .17525 .57984 .16073 Mtetra
.658 .722 .896 r
.57984 .16073 .58961 .17525 .60845 .16684 .5988 .15351 Mtetra
.654 .743 .915 r
.5988 .15351 .60845 .16684 .62744 .15947 .61789 .14649 Mtetra
.655 .752 .921 r
.61789 .14649 .62744 .15947 .64658 .15248 .63711 .13939 Mtetra
.656 .752 .92 r
.63711 .13939 .64658 .15248 .66584 .14541 .65646 .13219 Mtetra
.66 .753 .919 r
.65646 .13219 .66584 .14541 .68523 .13827 .67594 .12481 Mtetra
.657 .749 .917 r
.67594 .12481 .68523 .13827 .70475 .13092 .69556 .11747 Mtetra
0 g
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.13514 .21677 m
.13978 .22141 L
s
[(-2)] .12586 .2075 1 .99877 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.56863 .04703 m
.57247 .05235 L
s
[(2)] .56094 .0364 .72324 1 Mshowa
.125 Mabswid
.18558 .19702 m
.18832 .19985 L
s
.23703 .17687 m
.23971 .17975 L
s
.28951 .15632 m
.29214 .15925 L
s
.39772 .11395 m
.40023 .11699 L
s
.4535 .09211 m
.45595 .0952 L
s
.51046 .06981 m
.51284 .07294 L
s
.08568 .23614 m
.08851 .23887 L
s
.62804 .02377 m
.63027 .02701 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  GeneratedCell->False,
  CellAutoOverwrite->False,
  ImageSize->{288, 233.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00o?ooool2o`0006[ooooo003iooooo`?o000000?oooooo`000?ooool0
JOooool00?Oooooo0_l00004ooooo`;o0000JOooool00?Cooooo0ol00006ooooo`03o`000?oooooo
000006Sooooo003;ooooo`Go00008_ooool2o`0000Wooooo00?o0000ooooool00000J?ooool00<_o
oooo00GoV9RHob4Q8Oo^k^koooooodA4A00Oooooo`?o00002oooool01?l0003oooooooooool0001W
ooooo`00c?ooool00onHV9So8B4Qonk^kP0Mooooo`?o00003_ooool01Ol0003ooooooooooooooooo
000006Kooooo003=ooooo`03oiRHV?lQ8B7ok^k^01[ooooo0_l0000Aooooo`05o`000?oooooooooo
ooooool00000I_ooool00<kooooo00?oMgMgofIVI_ooool05_ooool3o`0001?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1Sooooo`00coooool00ol0003oooooooooo`0Cooooo`;o
00000_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0H_ooool00<_ooooo00Go0000okZj^_ooooooV9RHoa0@400Booooo`?o00006Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo06;ooooo003;ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`04?ooool2o`0001cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Qooooo`00
gOooool3o`0001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Qooooo`00fooo
ool2o`00027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Pooooo`00f?ooool3
o`0002?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Oooooo`00eOooool3o`00
02Kooooo00?o0000ooooooooool01?ooool2o`00067ooooo003Cooooo`;o0000:Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo05kooooo003@ooooo`?o000000?oooooo`000?ooool0
:?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05gooooo003>ooooo`;o00001Ooo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0GOoo
ool00<_ooooo0ol0000`ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0G?ooool0
0<Wooooo0_l0000cooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Foooool00<Ko
oooo0ol0000eooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Foooool00<Cooooo
0_l0000hooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0F_ooool00<7ooooo0ol0
000jooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03_ooool5o`0004Kooooo002n
ooooo`?o0000?Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00kooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A016ooooo`00_?ooool2o`0000?ooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo1_l00003ooooo`03oiRHV?lQ8B7o
k^k^04Oooooo002iooooo`?o0000@oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00kooooo00?oV9RHob4Q8Oo^k^h0A_ooool00;Oooooo0_l00016ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03oooool00omgMgOoIVIVooooo`15ooooo`00]?ooool3o`0004Sooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo04Cooooo
002booooo`;o0000Boooool00ol0003oooooooooo`0=ooooo`;o00003?ooool01Ol0003o^[Zjoooo
oonHV9So410@04Kooooo002_ooooo`?o0000COooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooo000000cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c016ooooo`00[Oooool2o`00053ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`1Dooooo`00Z_ooool4o`00057ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1Dooooo`00Z?ooool2o`0000Cooooo00?o0000oooo
ooooool0C_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo05?ooooo001nooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h08_ooool3o`0005Oooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`1Booooo`00O_ooool01OmgMgOoV9RHoooooonHV9SoMgMg01oooooo0ol0001Joooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool0D_ooool007kooooo00Go410@oooooooo
oooooooooa0@400Mooooo`;o0000GOooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
057ooooo001nooooo`05o`000?ooooooooooooooool000006_ooool3o`0005oooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`1@ooooo`00O_ooool01Ol0003ooooooooooooooooo0000
01Sooooo0_l0001Rooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0D?ooool007ko
oooo00Go410@oooooooooooooooooa0@400Eooooo`?o0000I?ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo04oooooo001nooooo`05ogMgMonHV9SooooooiRHV?mgMgL04oooool2o`00
00?ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
04kooooo001nooooo`05onk^k_lb<S;o0000oc8b<_o^k^h04?ooool3o`0006Sooooo00?oZ;oZo`00
0?ooool05_ooool00ol0003oooooooooo`1>ooooo`00TOooool2o`0006Sooooo1?nX_nX00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo04gooooo002>ooooo`?o0000J?ooool7ojRojP03o`00
0?oooooooooo01Cooooo0ol0001>ooooo`00Roooool3o`0006Wooooo0_nX`>/7ojRojP03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool0C?ooool008Wooooo0_l0001Yooooo`KoZ<3[1_nX_nX0
0ol0003oZ;oZooooo`0Gooooo`03o`000?oooooooooo04_ooooo0026ooooo`?o0000J?ooool00onW
`>_oZ<3[ojS0j`07ojS0j`GoZ;oZ00?o0000ojS0joooool06?ooool00ol0003oooooooooo`1:oooo
o`00Q?ooool2o`0000;ooooo00?o0000ooooooooool0Hoooool5ojO0j`WoZ<3[0_nX_nX2ojS0j`03
o`000?nX`>_oZ<3[01Sooooo00?o0000ooooooooool0B_ooool0087ooooo0ol00005ooooo`03o`00
0?oooooooooo063ooooo2?nW`>/7ojS0j`03ojO0jonX`>_oZ<3[00;oZ<3[00Co0000ojS0jonX`>_o
Z<3[6?ooool00ol0003oooooooooo`19ooooo`00Ooooool2o`0006Wooooo2_nW`>/4ojS0j`GoYl3[
0onX`>/00ol0003oZ<3[ojS0j`02ojS0jaSooooo00?o0000ooooooooool0B?ooool007cooooo0ol0
001Xooooo`koYl3[00?oZ<3[ojO0jonW`>/01_nW`>/2ojS0j`05o`000?nX`>_oZ<3[ojS0jonW`>/0
6?ooool00ol0003oooooooooo`18ooooo`00N_ooool2o`0006Oooooo0_nW_^XIojO0j`;oZ<3[00?o
0000ojS0jonW`>/00onW`>/Hooooo`03o`000?oooooooooo04Oooooo001gooooo`?o0000I_ooool6
ojNnjQWoYl3[00?oZ<3[o`000?nW`>/01OnW`>/Hooooo`03o`000?oooooooooo04Kooooo001doooo
o`?o0000I_ooool00onX^>GoYkkZojNnjP07ojNnjPKoYl3[0_nW_NTAojO0j`03o`000?nW`>_oYl3[
00CoYl3[6?ooool00ol0003oooooooooo`16ooooo`00L_ooool2o`0000;ooooo00?o0000oooooooo
ool0H_ooool4ojRhi@WoYkkZ0_nW`>/6ojNmjA3oYl3[00?o0000ojO0jonW`>/01OnW`>/Hooooo`03
o`000?oooooooooo04Gooooo001_ooooo`?o0000Ioooool7ojRhi@OoYkkZ00?oZKOSojNmjOnW_NT0
1onW_NT6ojO0j`03ojNljOnW`>_oYl3[00KoYl3[00?o0000ojO0jonW`>/01OnW`>/Hooooo`03o`00
0?oooooooooo04Gooooo001]ooooo`;o0000J?ooool00on[]N3oZ;SUojRhi@06ojRhi@CoYkkZ1OnY
]n<9ojNmj@;oYl3[1OnW_>T7ojO0j`03o`000?nW`>_oYl3[00KoYl3[5oooool2o`0004Kooooo001Z
ooooo`?o0000Ioooool5oj^eh0SoZ;SU00?oYkkZojVghonY]n<01_nY]n<7ojNmj@03ojVghonW_>Wo
YkcY00KoYkcY1_nW`>/00ol0003oYkgYojO0j`07ojO0jaSooooo00?o0000ooooooooool0@oooool0
06Sooooo0_l0001Xooooo`SoZkGP1_nX^>D00on]]MkoZKOSojVgh`07ojVgh`CoYkgY1OnY]n<8ojNl
j@;oYl3[0onW_NT00ol0003oYkgYojNmj@08ojO0jaOooooo00?o0000ooooooooool0@oooool006Go
oooo0ol0001Xooooo`03ojjbg?n[]N3oZkGP00OoZkGP1?nX^>D4ojfegPWoZKOS00?oYkgYojVghonY
]n<01_nY]n<6ojNlj@03ojZghonW_NWoYkgY00?oYkgY00Co0000ojNmjOnW_NWoYkgY1_nW`>/00onW
_^[oooooooooo`0Fooooo`03o`000?oooooooooo04;ooooo001Sooooo`;o0000J?ooool5ojjbg0Wo
ZkGP00?oZ;SUojfeg_n]]Mh01On]]Mh7ojVgh`03ojnfgOnY]n?oZKOS00OoZKOS1?nW_>T4ojZgh`Go
YkgY00Co0000ojNmjOnW_NWoYkgY0_nW`>/5ojNnjQSooooo00?o0000ooooooooool0@Oooool0063o
oooo0ol000000ooooooo0000ooooo`1Tooooo`03ojjaf_n^/]co[[;L00Ko[[;L1on[]N000on_/]_o
[KGNojfegP07ojfegPCoZKOS1?n_]]d9ojVgh`03ojNljOnZ]n?oZ[OS00GoZ[OS1?nW_NT01?l0003o
YkgYojNmjOnZ^><8ojNnjQOooooo00?o0000ooooooooool0@Oooool003Kooooo1Ol0000Sooooo`;o
0000J?ooool4ojjafPSo[[;L1?n[]N04ojnbf`Wo[KGN00?oZKOSojnfgOn_]]d01On_]]d7ojVgh`03
ok2fgOnZ]n?oZ[OS00KoZ[OS1?nW_NT00ol0003oZ[SSojZhh`02ojZhh`SoYkkZ5oooool00ol0003o
ooooooooo`10ooooo`00=_ooool01OnHV9So8B4Qonk^k_ooooooA4A4023ooooo0ol0001Xooooo`Ko
[[7J2On^/]`00on[]N3o[k;Kojnbf`05ojnbf`Oo[KGN00?o/K?KojnfgOn_]]d01_n_]]d4ojVgh`Go
/;KM2?nZ]n<01?nW_NWoZ[SSojZhhol00005ojZhh`KoYkkZ00?oZK[Uooooooooool05_ooool00ol0
003oooooooooo`0oooooo`00;_ooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h07_ooool3o`0006Wo
oooo00?o/;CKojjaf_n^/MX01_n^/MX7ojjbg003ok6dfon_/]_o[k;K00Ko[k;K1?n]]Mh5ok6cf`So
[kKM00?oZKOSok2fgOn`]]d01_n`]]d6ojZgh`05ok6gg_nZ^>?oZ[SSojZhhol000001OnZ^><4ojNn
jPCoZK[U5oooool00ol0003oooooooooo`0oooooo`00>?ooool00onHV9So8B4Qonk^kP0Kooooo`;o
0000JOooool5ok2df`Oo[[7J1?n^/]`5ok6df`So[k;K00?o[KGNok6cfona/m/01_na/m/6ojnfg@03
ok:efon`]]go/;KM00Oo/;KM1?nZ]n<4ok6ggP;oZ[SS00?o0000ojZhhonZ^><01?nZ^><00onW_^[o
ZK[UojVji@05ojVjiAOooooo00?o0000ooooooooool0?_ooool003Wooooo00?oMgMgofIVI_ooool0
5oooool3o`0006Wooooo1on`]=/8ojjafP03ojjbg?na]=_o/KCK00Ko/KCK1_n_/]/00ond^Mgo/K?K
ok6cf`07ok6cf`Co[kKM1?nb]M/9ok2fg@03ojZghona]mko/KON00Go/KON00?oZ[SSo`000?nZ^><0
1?nZ^><00ona^MooZK[UojVji@06ojVjiASooooo00?o0000ooooooooool0?Oooool003[ooooo00?o
0000ooooooooool05?ooool2o`0006[ooooo00?o/;_Rok2dfon`]=/01on`]=/6ojjafP03ok:lhOna
]=_o/KCK00Oo/KCK1?n_/]/4okBig@Wo/K?K00?o[kKMok:efonb]M/01Onb]M/7ok2fg@03okBgfona
]mko/KON00Ko/KON00CoZ[SSo`000?nZ^>?oZ[SS1Ona^Ml8ojVjiAOooooo00?o0000ooooooooool0
?Oooool003Kooooo00Go0000okZj^_ooooooV9RHoa0@400Cooooo`?o00000_ooool00ol0003ooooo
ooooo`1Uooooo`Co/;_R2?n`]=/4ojjafPCo/[cQ2Ona]=/00on_/]_o];WMokBig@05okBig@Oo/K?K
00?o][cOok:efonb]M/01_nb]M/4ok2fg@Go];OK2?na]mh00ol0003o/KWOok6ig`06ok6ig`KoZK[U
00?o[k[Qooooooooool05_ooool00ol0003oooooooooo`0looooo`00=_ooool01OnHV9So410@o`00
0?lQ8B7oc<c<017ooooo0_l0001[ooooo`Oo/;_R2?n`]=/00on^/M[o/[cQok:lh@05ok:lh@Oo/KCK
00?o/l?VokBigOnd^Md01_nd^Md6ok6cf`?o][cO2?nb]M/00on`]]go];OKokBgf`06okBgf`Ko/KON
00?o];SKo`000?na^Ml01ona^Ml4ojVji@Co[k[Q5_ooool3o`0003gooooo0019ooooo`?o0000Jooo
ool00on_a>Wo/;_Rok2khP06ok2khPOo/;CK00?o/LKZok:lhOnb_>401onb_>44ok6df`Co/l?V2?nd
^Md3ok6cf`Go][cO1onb]M/00ong_^3o];OKokBgf`07okBgf`Co/KON0ond^=/00ol0003o/KWOok6i
g`07ok6ig`03ojVjiOn_^^7o[k[Q00Go[k[Q5oooool00ol0003oooooooooo`0kooooo`00Aoooool2
o`0006cooooo1?n_a>T8ok2khPCo/;CK1?naa^X9ok:lh@03ok6dfonc`nKo/l?V00Co/l?V2Ond^Md0
0ona/m_o][cOokJlg`05okJlg`Go/[GK0ong_^09okBgf`03ok6gg_nd^=_o];SK00?o];SK00?o0000
okBhfona^Ml01_na^Ml00ond^=co[k[Qojnjh@07ojnjhAOooooo00?o0000ooooooooool0>_ooool0
04Cooooo0ol0001/ooooo`Oo[lCY2?n`^n800on`]=_o/LKZok76jP05ok76jPOo/[cQ00?oZl_aok?3
i_nc`nH01_nc`nH7okBig@03ok;7j_nf_=oo][cO00Ko][cO0onb]M/6okNnh0Oo];OK00?o^;oOokBh
fond^=/01?nd^=/00ol0003o];SKok6ig`03ok6ig`Go];SL1on_^^400ond^]koooooooooo`0Foooo
o`03o`000?oooooooooo03Wooooo0011ooooo`?o0000KOooool00onZb_3o[lCYojo4j@07ojo4j@Ko
/;_R00?oZ<gcok76j_naa^X01_naa^X4ok:lh@GoZl_a1onc`nH4okBig@Go//OZ2?nf_=l00onb]M_o
]kkPokNnh005okNnh0Ko];OK0onh_ml5okBhf`04o`000?nd^=_o];SKok6ig`So];SL1?n_^^44okBj
gQOooooo00?o0000ooooooooool0>Oooool003oooooo0ol0001]ooooo`CoZ/[`2On_a>T2ok2khPGo
Z<gc2?naa^X00onb_>7oZl_aoj_;l@06oj_;l@Oo/l?V00?o];WMok;7j_nbanX01_nbanX6okJlg`03
ok79k?ng_^3o]kkP00Oo]kkP0ond]m/6okRog`Co];SK00?o0000okBhfonh_]h02_nd^=`00on_^^7o
];[NokBjgP05okBjgQOooooo00?o0000ooooooooool0>?ooool003cooooo0ol00003ooooo`03o`00
0?oooooooooo06Sooooo1onZb_06ojo4j@;oWmKk2?nXcO<6ok76jP?oW]Gk1on[bo46ok?3iP?oY=3g
2?nbanX2okJlg`Go/LW/2Ong_^000ond]m_o^;oOokRog`05okRog`Co];SK00Co0000okRng_nh_]ko
^;kN2?nd^=`00onh_=go];[NokBjgP06okBjgQOooooo00?o0000ooooooooool01oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^02cooooo000jooooo`;o0000Koooool2ojGAm`SoZ/[`0_n_a>T6oioFn`So
Z<gc0_naa^X7oikEn`OoZl_a0_nc`nH7ojC@m`Ko//OZ00?oWm7iok79k?nabN`01_nabN`6okNnh0;o
/LW/2Onh_ml01?nd^=_o^;kNokRng_l00004okRngPGo];SL1?nh_=d8okBjgQOooooo00?o0000oooo
ooooool01_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02cooooo000gooooo`?o0000K_ooool6ojGA
m`KoZ/[`0onEfoh7oioFn`KoZ<gc0on>fOl8oikEn`?oZl_a1?nBeoh9ojC@m`;o//OZ1OnOdOT8ok79
k0;o]kkP1_nabN`7okRog`03ok?8j_nh_]ko^;kN00;o^;kN00Co0000okRng_nh_]ko^;kN1?nd^=`6
okRlg@Ko];[N00?o^;cMooooooooool05_ooool00ol0003oooooooooo`05ooooo`05oa0@4?oooooo
ooooooooool@4100;?ooool003Gooooo0_l0001^ooooo`;oXMOk2?nUdOL2oj[:l0OoUM_n1onOe_/2
ojS=l`OoS]Wo1_nNeO/2og_Ao`OoT]On1_nTd?L3ohKCo`OoWm7i1_nabN`00onLdO[o/LW/ok79k007
ok79k0Co^;oO1?ncb>X3okRngP03o`000?nh_]ko^;kN00;o^;kN00?o];SLokRlgOnh_=d01_nh_=d4
okBjgPCo^;cM5oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool00000;?oo
ool003;ooooo0ol0001]ooooo`KoXMOk1_nUdOL3oh_Lo`SoUM_n0onOe_/5ogoEo`SoS]Wo0_nNeO/6
og_Ao`OoT]On0_nTd?L7ohKCo`OoWm7i0_nabN`5oicAnPWo/LW/00?o^;oOok?8j_ncb>X01Oncb>X2
okRngP05o`000?nh_]ko^;kNokRng_nfanL02_nh_=d00ond^]ko^;cMokRlg@05okRlgAOooooo00?o
0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000002cooooo000`ooooo`;o0000KOoo
ool3oigKo@OoXMOk0_nUdOL8oh_Lo`?oUM_n1On3dol7ogoEo`CoS]Wo1Omlc_l7og_Ao`?oT]On1Ome
b_l8ohKCo`?oWm7i1?mnc_l7oicAnPKo/LW/0_nMcoT8ok?8jP;o^;kN00?o0000okRng_nfanL00onf
anL8okRlg@03okW4honh_=go^;cM00Ko^;cM6?ooool00ol0003oooooooooo`03ooooo`05oa0@4?oo
ooooooooooooool@4100;?ooool002gooooo0ol000000ooooooo0000ooooo`1Yooooo`OoWM_m0onQ
eo/5ohWKo`OoRmco0on;d_l7oh?Co`?oOmGo1On7boh8ogc>o`?oNm7o1Omnaoh7ogG:o`CoQ]?o1?mb
aOl7ogk>o`OoW=7j0_nabN`6oig?n@So/lSZ00?o^;kNo`000?nfanL01OnfanL5okRlg@Co^LCS2?nh
_=dGooooo`;o00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg02cooooo000Zooooo`?o0000K?oo
ool3oi[No@KoWM_m0on=fol8ohWKo`;oRmco1on;d_l3oh?Co`GoULWj2?n7boh3ogc>o`GoT<Kj1omn
aoh3ogG:o`GoP/?l1ombaOl7ogk>o`?oW=7j1?mlbol8oig?n@Ko/lSZ00?oXLcfokK7iol000001_nf
anL4okRlg@Ko^LCS1_nh_=d00onj`=koooooooooo`0Cooooo`;o000000?oooooo`000?ooool00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^02cooooo000Xooooo`;o0000K?ooool7oi[No@;oWM_m2?n=
fol3ohWKo`GoU=7m1_n;d_l3oig3l`SoULWj0on7boh4oi^nl@SoT<Kj0omnaoh4oiBnm0WoP/?l1_mb
aOl3ogk>o`GoLL3n1_mlbol8oig?n@;o/lSZ1OnQc?H00ol0003o]/OWokK7i`05okK7i`03okRlgOni
a>?o^LCS00Ko^LCS1?nh_=d4ok[0gQSooooo00?o0000ooooooooool0<_ooool002Gooooo0ol0001[
ooooo`?oV^3m1_nJg_d3oi?LoPOoSM_o0_nKcoX8oiCAo@;oRm;o1onM`o<6oiG9nP03oj:ijOnK__7o
Vkka00KoVkka1_n@a_X00onO^>[oU;kdoiBnm006oiBnm0KoP/?l0onG^_07ohC1n`OoLL3n1_mlbol4
oig?n@CoOl[o1OnQc?H2o`0000Ko]/OW00?oZ<WaokW4honia><02?nia><00onh_=go^/3Nok[0gP05
ok[0gQOooooo00?o0000ooooooooool0<_ooool002?ooooo0_l0001[ooooo`OoV^3m0_nJg_d8oi?L
oP;oSM_o1_nKcoX6oiCAo@?oXKg]2?nM`o<2oiG9nPGoX[WY2?nK__42oi36nPGoWkSZ2?nD__@2oh;3
o0OoUk[`1on4`O/3og70oPCoP[kj1_m^_Od8ogo:o`07oj7<m_l0003o0000o`000?nQc?Ko0000oj7<
mP02okK7i`GoZ<Wa2?nia><00onab>_o^/3Nok[0gP07ok[0gQOooooo00?o0000ooooooooool0<Ooo
ool0023ooooo0ol0001Zooooo`?oVn;m1_nJh?d3oiSLoPOoTmcn0_nPc?L8oi_?nP;oU=7m1onQ_Nd6
oig3l`03ojRhi?nR^NWoX[WY00KoX[WY1_nK__400onX^>CoWkSZoinhjP06oinhjPKoU;kd0_nU^>L9
oiNjl0?oQ<7k1?nG^>l7oh:nnPKoK[gm1Omob_l3o`0000?oXLcf0_n8boh00ol0003oZ<WaojS9l@06
ojS9l@Co^LCS1Onab>/7ok[0gP03okW6i?oooooooooo01Kooooo00?o0000ooooooooool0<?ooool0
01oooooo0_l0001Yooooo`OoVn;m0_nJh?d8oiSLoP;oTmcn1_nPc?L6oi_?nP;oY;[X2OnQ_Nd2oig3
l`GoZ;ST2?nR^NT2oi^nl@GoZ;ST2?nO^>X2oiBnm0KoYKSW1onG^_000onW^NGoUkS_oiNhk`06oiNh
k`OoP[kj1_m^_Od01?mob_oo0000o`000?l00004ofblo@GoR<_n00?o0000ojS9lOnXbO401_nXbO40
0onia>?o/LS[ok78j`06ok78j`Go^/3N0onia^@Gooooo`03o`000?oooooooooo033ooooo000Ooooo
o`03o`000?oooooo000006Gooooo0onMh_d6oi_Ro@?oWMgm1onHg?h2oj?:m0SoX<cg0_nKcoX6ojBj
j0OoXKg]00?oZKOSojRhi?nX^>@01_nX^>@6oj:ij@03oj^hhonX^>CoZ;ST00KoZ;ST1_nO^>X00on/
^N?oYKSWojFhi`07ojFhi`CoUk[`1?nW^ND8oiNhk`?oP[kj1?nE^>l3ogfknP?o000000?oOK_jofbl
oOm/_?d01Om/_?d5ohS;oP03o`000?nXbO7oZ<Wa00CoZ<Wa00?oU/cjok78jonab>/01onab>/3ok[0
gPKo^LKT5oooool00ol0003oooooooooo`0_ooooo`003?ooool5o`0000?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP06ooooo`04o`000?ooooooooooo`00067ooooo1onMh_d2oi_Ro@SoWMgm0_nHg?h6
oj?:m0KoX<cg0_nW^NH8ojBjj0CoXKg]1?nY]n<7ojRhi0CoX[WY1?n[^><8ojRhi0;oWkSZ1On/^N<9
ojFhi`03oiNjl?nW^NGoYkWU00GoYkWU1_nG^>l00onX^NKoUKS_oiFhk`05oiFhk`?o00001Omm^oX7
ofblo@CoR<_n00Co0000ohS;o_nXbO7oZ<Wa1OnFc?X9ok78j`03ok[0g_nia^Co^LKT00Go^LKT6?oo
ool00ol0003oooooooooo`0^ooooo`003?ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`;o00000_ooool00ol0003oooooooooo`1Kooooo`?oX>;l
1_nMh_d3oj7No0OoWMgm0onUbO87oj?:m0;oX<cg1_nW^NH8ojBjj003oj6mkOnY]n?oZKOS00GoZKOS
1onX^>@00onR^NWoZkSSoj^hh`05oj^hh`KoZ;ST00?o[K[Sojbihon/^N<01_n/^N<6ojFhi`;o[K_S
2OnW^ND2oiNhk`GoZ;WV0onE^>l3o`0000;oUKS_0omm^oX4oi2hlPKoMKSk1Om^_Od00ol0003oK[gm
oiK<nP06oiK<nPKo/LS[0_nSb?<9okW6i1Oooooo00?o0000ooooooooool0;_ooool000Cooooo1_l0
0003ooooo`03oiRHV?lQ8B7ok^k^00Cooooo00Go410@oooooooooooooooooa0@4005ooooo`;o0000
1?ooool00ol0003oooooooooo`1Hooooo`OoX>;l00?oWN;moj7No?nQg_`01_nQg_`2oigMo@OoYLWb
1OnSb_@2ojNhi@SoYkWV1_nT^^P9ojVgh`KoZ;ST00?o[;WSoj^hhon[^><01_n[^><4ojRhi0Co[K[S
2?n/^N<2ojFhi`Ko[K_S1onW^ND00on^_>?oZ;WVojRiiP05ojRiiP?o00001?nE^>l00onV^NOoT;Sb
oi2hlP06oi2hlPKoMKSk1Om^_Od00ol0003oK[gmoiK<nP06oiK<nP;o/LS[1_nSb?<7okW6i003ok77
j_oooooooooo01Kooooo00?o0000ooooooooool0;Oooool000kooooo00?oV9RHob4Q8Oo^k^h00ooo
ool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`1Eooooo`SoX>;l0onTh?/6oj7No0?oYlWb2?nUbO800onSb_CoYkSUojNhi@04ojNhi@SoYkWV
0_nT^^P=ojVgh`;oZ;ST1On/^N<8oj^hh`03ojRhi?n]^^?o[K[S00Go[K[S1_n/^N<00on]^nCo[K_S
ojfkh`07ojfkh`CoYkWU1?n^_><4ojRiiP;o00000_nX^NH2oiFhk`GoY[WW2?n@^?86ogFhn`CoK[gm
00?o0000ofjmoOm^_Od00onFc?X4ogg2o@OoXlSc1?nia^@5ok77jQSooooo00?o0000ooooooooool0
;?ooool000oooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000000Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Booooo`CoXn7l0onPh_`7ojCPn`;oXMkl
1onWbO86ojG9lP03ojNgi?nW^>GoYkSU00KoYkSU1_nW^NH00onY^>?oZKOSojVgh`0<ojVgh`03oj^j
i?n/^N?o[;WS00Ko[;WS1_n[^><00on/_>Go[K[Sojfjh`06ojfjh`Co[;WS1?n]^n@9ojfkh`03ojNi
iOn^_>?o[[cS00Go[[cS0ol00003ojRiiP03ojnmi?nV^NOoY[WW00KoY[WW1_n@^?800onP^N[oQkWf
ohNimP05ohNimPCoKKCj00Co0000offdn_m]]?[oKKCj1_mm`_d7oj?8l`03okW6i?naan[o/LOZ00Go
/LOZ5oooool2o`0002kooooo000@ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413o
ooooooooo`03ooooo`;o00001oooool00ol0003oooooooooo`1>ooooo`OoXn7l0onWh_/6ojCPn`?o
ZLcb2?nWbO82ojG9lPGoYkOT2?nW^>D2ojNiiPGoZKSS2_nY]n<5oj^ji0So[;WS0_n[^><5ojbli@So
[K[S00?o[;WSojfki?n]^n@01On]^n@7ojfkh`03ojjmiOn^_>?o[[cS00?o[[cS0ol00004ojRiiPCo
[kgT2?nV^NL2oi2hlPGoX;WZ1on7^OH4offdnP04o`000?m]]?[oKKCjoffdnPKoOL;m0onSb?<3oi?7
n@So/LOZ6Oooool00ol0003oooooooooo`0[ooooo`003?ooool01Ol0003o^[ZjoooooonHV9So410@
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0B_ooool3ojKNn`GoXn7l1onWh_/00onTh?_oZLcbojW<lP05ojW<lPKoYlWb00?oYkOU
ojNgi?nW]n@01_nW]n@6ojNhi@03ojRhi?nY^>?oZKSS00KoZKSS1_nY]n<00onZ^nKoZk[Toj^ji006
oj^ji0Ko[;WS00?oZkkWojbliOn/_>D01_n/_>D6ojfjh`;o[KoW2?n]^n@4ojfkh`Co[[gU00Co[[cS
o`000?l0003o00001?n^_><00onX^NKo[kgTojnmi005ojnmi0KoY[WW00?o[kgToj2ij_nP^NX01_nP
^NX7ohNimPCoKKCj00?o0000ogZen?mj]OP01om/]_/6oi?7n@So/LOZ6?ooool00ol0003ooooooooo
o`0[ooooo`003?ooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0A_ooool8ojKNn`03oj?Q
o?nWh__oYn;k00KoYn;k0_n[co<8ojW<lP;oYlWb1OnW]nD8ojNgi0;oYkSU1OnX^>@7ojVhh`CoZKOS
1?nZ^nH8oj^ji0;o[;WS1On[_^L8ojbli@;o[K[S1_n]_nL8ojfki003ojfkhon^_NGo[[gU00;o[[gU
0ol00006ojjlh`03ojnniOn__NCo[kgT00Ko[kgT1?nV^NL4ojnmi0SoX;WZ0on7^OH4oiJgkP?oN[Gh
00Co0000ogZen?mj]OSoN[Gh1om/]_/6oi?7n@Ko/LOZ00?oY/K`ooooooooool05oooool00ol0003o
ooooooooo`0Zooooo`007_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo04;ooooo
0onXfOT7ojKNn`CoZNCj0onWh_/6oj_?l`KoZLcb2OnW]nD6ojNgi003ojRgi?nX^>CoZ;ST00KoZ;ST
1onY^><00onY]n?oZ[_VojZkiP05ojZkiPKoZk[T0_nZ`>T7oj^ni`Ko[;cU0_n[`NX8ojfoi`Ko[K_T
00?o[L7XojjmiOn^_ND00ol00004ojjmi@;o[[cS1On__^D8ojnmi003ojJiion__NCo[kgT00Go[kgT
1_nP^NX00on/_>GoU[O^oiJgkP06oiJgkP?oN[Gh00Co0000ogZen?mj]OSoN[Gh1om/]_/6oi?7n@;o
/LOZ1OnVa_0Iooooo`03o`000?oooooooooo02Wooooo000Mooooo`?o00002oooool00ol0003ooooo
ooooo`0nooooo`SoZ=Wi0_nVg_/7ojWTnP;o[=Ce2?n[co<2ojW<lPcoYkOU1?nW]n@4ojRgi0OoZ;ST
1_nY^><00onY_>OoZ[_VojZkiP06ojZkiPCoZk[T1OnZ`>T7oj^ni`;o[;cU1_n[`NX8ojfoi`;o[K_T
0on]`NP3o`0000Ko[[gU00?o[L7YojnniOn__^D01_n__^D6ojnmi003ojnni?n__NCo[kgT00Oo[kgT
0_nP^NX5ojbli@SoU[O^0omj]OP01?l0003oR;OdohRgm?n8]o@6off`n@OoOkkk1onVa_0Hooooo`03
o`000?oooooooooo02Wooooo000Mooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
>oooool2ojWBm@OoZ=Wi0on/i_X5ojWTnPGo[=Ce1_n[co<00onW^NKoYkOUojNgi@0=ojNgi@03ojNg
i?nX]nCoZ;OT00GoZ;OT1onX^>@2ojVhh`GoZKcW2?nZ^nH00on[^^CoZ/3Yoj[0j@06oj[0j@GoZkkW
0_nX_n/8oj_1jPKo[KoW00?oZ<3[ojg1j?n]`NP00ol00003ojg1j0Co[[gU1?n]`NT8ojnni@;o[kgT
1On__^@7ojnmi003ok2ni?n/_>Go[;cU00Ko[;cU1_nF]nh2ojBjj@?oR;Od00Co0000ohRgm?n8]oCo
R;Od1_m]/?T7ognnn`OoY/K`6?ooool00ol0003oooooooooo`0Xooooo`007Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo03Sooooo1OnYd_D4ojSIn@Oo[>Kj00?oZNCjojcDmOn/e?D0
1_n/e?D2oj_?l`GoYkWV3OnW]nD2ojNgi0OoZ;OT1_nX^>@2ojVmj0OoZKcW1_nZ^nH2ojS0j`WoZ/3Y
00?oZkkWojRojonX_n/01?nX_n/8oj_1jP;o[KoW0onX`>/3o`0000Oo[L7X00?o[[gUojg1jOn]`NT0
1On]`NT6ojnni@03ojg1j?n__^Co[kkT00Ko[kkT1?n__N@4ok2ni0So[;cU0_nF]nh6ojBjj@;oR;Od
00?o0000ohRgm?n8]o@00_n8]o@6off`n@OoOkkk0onVa_04oi_4m1Sooooo00?o0000ooooooooool0
9oooool001gooooo0_l0000?ooooo`03o`000?oooooooooo03Gooooo2?nYd_D00onXfOWo[>KjojcV
nP06ojcVnP?o[]Wf1_n/e?D00onW^nOoYkWVojNiiP06ojNiiPWoYkOU1_nW]n@7ojRgi0;oZ;ST1_nY
_NP7ojVli`;oZ[_V1_nX`>/7oj[0j@03ojNnj_nX_n_oZ;o[00KoZ;o[1_n[`NX01?nW_^[oZ<3[ojS0
jonX`>/2o`0000?oZ<3[1_n]`NP00onX_n_o[L7Yojg1j@06ojg1j@Co[kkU1?n]`NP8ojnni003ojnm
i?n`_^Co/;kT00Go/;kT1_n/_>D00on`_nGoY;[YojBjj@07ojBjj@;oR;Od00Co0000oiBfkonD]^oo
U;K_1omf/OL6og6dnPSoVlCd5oooool00ol0003oooooooooo`0Wooooo`007Oooool00ol0003ooooo
ooooo`0?ooooo`;o0000<oooool3ojS9l@KoZM;e1?n^ioT3ojcVnPSo[]Wf00?o[=CeojNkionW^nL0
0onW^nL8ojNiiPGoYkOU0_nV]nD8ojNgi0GoZ;OT0_nX_NT8ojVmj0GoZKcW0_nX_n/8ojS0j`CoZ/3Y
1?nW_^X8ojRoj`;oZl7Z1?nW_^X3o`0000KoZ<3[0_n]`NP5ojRoj`So[L7Y00?o[kkUojg1j?n]`NP0
1On]`NP6ojnni003ojo2j?n`_^Co/;kT00Oo/;kT0_n/_>D5ok2oi@OoY;[Y00Go[KkVoiBfkonD]^oo
U;K_o`000003oiBfk`OoM[7g1_ma]?X8oi_4m1Oooooo00?o0000ooooooooool09_ooool001gooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0]ooooo`SoZ<Wa00?oZM;eojkWnOn^ioT0
1On^ioT3ok;NmPOo[]Wf00?oZl7ZojNkionW^nL01OnW^nL8ojNiiP03ojNgiOnV]nGoY[OU00CoY[OU
2?nW]n@00onX]nCoZ;gYojRmj@04ojRmj@SoZKgX00?oZKcWojRojonX_n/01?nX_n/8ojS0j`03oj[0
jOnW_^[oYkkZ00GoYkkZ1_nX_n/01?nX_^WoYkkZojNnj_nW_^X3o`0000;oYkkZ1_nX`>/00onX_^Wo
Z;o[ojRoj`06ojRoj`Ko[L7Y0_nX_n/8ojg1j0;o[kkT1On_`^P7ok2ni003ok31i_n`_nGo/;oU00Ko
/;oU1?nT^^T4ojfniP?oU;K_00Co0000oiBfkonD]^ooU;K_1omf/OL6og6dnPCoVlCd0on>_oLHoooo
o`03o`000?oooooooooo02Gooooo000Mooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool0:Oooool3ojC0k@OoZ<Wa0on_hoT4ojkWn@Ko/]kf1?n^fOH4oj_1jPOoYk_W1_nW^NH00onU]^Go
Y[OUojJgi@06ojJgi@KoYkOT00?oYkgYojRmjOnX_NT01_nX_NT6ojVmj003ojNoj_nX_n_oZ;o[00Ko
Z;o[1_nX`>/2ojNmj@SoYkkZ0_nX_n/4ojRnj@?o00001_nW_^X2ojS0j`GoZ;kY2?nX_n/2ojg1j@Ko
Z;o[1_n]`NP00onY`>_o[l;Xojo2j006ojo2j0Co/;kT1?n``NH8ok2oi@03ojBjjOn]_^Ko[KkV00Go
[KkV0_nD]^l00ol0003oU;K_oiBfk`02oiBfk`?oM[7g1?n1/oD5ofb^n0SoS[og5oooool2o`0002Ko
oooo000Looooo`?o00005?ooool00ol0003oooooooooo`0Uooooo`OoY<3]1?nXbO47ojoSn@03ojkW
nOnbg_Ko/]kf00Ko/]kf00?o[]Wfoj_1j_n[`NX01On[`NX7ojNki`;oYkWV1OnU]^D8ojJgi@;oYkOT
1OnW_NT8ojRmj@;oZKgX1OnW_nX8ojRoj`;oZ<3[1_nW_NT6ojNnjP04ojRmjOnX_^WoZ;kYojRnj@?o
00000_nX_^T6ojNnjP03ojVnjOnX_^WoZ;kY00KoZ;kY1_nX_n/2ojRnj@SoZ;o[0_n]`NP5ojW0j`So
[l;X00?o/;kTok31i_n``NH01On``NH6ok2oi@03ok70iOn]_^Ko[KkV00Oo[KkV0_nD]^l01?l0003o
Wk[/oinjk?nO^^`8oh6cm@GoK:kh1on>_oLFooooo`03o`000?oooooo000002Kooooo000Looooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool08?ooool4oijej0SoY<3]00?oZ<WaojoSnOn_
hoT01_n_hoT3okGSmPKo/]kf0on^b>d6oj_1jPKoYk_W2OnU]^D6ojJgi@WoYkgY1_nX_NT9ojNojPKo
Z;o[00?oZ;gYojNmjOnW_NT01onW_NT2ojNnjPCoZ;gY0ol00006ojRnj@;oYkkZ1OnY_^T8ojRnj@;o
Z;o[1_nX_^T6ojRoj`03ojRnjOnY`>_oZL3[00KoZL3[1_n_`^P00on[`N[o/<7Vok31iP07ok31iP;o
/;oU1Ona`>D7ojfniP05ok70iOnO^^coWk[/oinjk?l000000onO^^`8oh6cm@GoK:kh1on>_oLHoooo
o`03o`000?oooooooooo02?ooooo000:ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o
<S8bonk^kPKooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Kooooo`03oiZ/honN
]NSoW[GX00KoW[GX1_nT`>d3ojgJm`Go[n?i1_nehoH2ok;NmPOo[/S]1_n[`NX2ojNki`goYKKU0_nV
]nD=ojNmj@;oZ;gY3OnW_nX2ojRoj`GoZ;gY1onW_NT4ojRmj@?o00000_nX_NT6ojRnj@WoZKkY1_nX
_^T00onY_^WoZ;kYojRnj@07ojRnj@;oZ;o[1OnX_^T8ojW0j`;o[l;X1On[`NX7ok31iP03ojk2j?na
`>Go/L3U00Go/L3U1?n]_^H5ok70i@;oWk[/00?o0000oinjk?nO^^`00_nO^^`4oh6cm@?oRKGc1?m_
ZoH2ofb^n0?oS[og0on3^?LHooooo`03o`000?oooooooooo02?ooooo000<ooooo`03o`000?oooooo
oooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool05oooool5oiZ/h`SoW[GX0_nT`>d8ojgJm`03ojoSnOnehoKo]N?f00Go]N?f0ona
d_48ojk8k@?oZl7Z0onT]^D=ojFfi@;oY[_X3OnW_NT?ojNojPWoZ;gY1?nW_NT3ojRmj@?o00001_nX
_NT2ojRnj@goZKkY0_nX_^T5ojVnj@OoZ;kY00?oZKkYojRnjOnX_^T01_nX_^T6ojW0j`03ojRnj_n[
`N[oZl7Z00KoZl7Z1?n``NH4ojk2j0Oo/L3U00?o[KkVok70iOna`>D01Ona`>D3oinjk004o`000?nO
^^coWk[/ojRmj@SoRKGc1_m_ZoH6oh>hmaSooooo00?o0000ooooooooool08_ooool00003ooooool0
003o000000Co00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100
1_ooool2o`0001Wooooo00?o0000ooooooooool04_ooool3oiVXh@OoVZcS1_nN]NP3oj_=lPOo[M[g
0onfi_H4okGSmPKo/M;a1_n^b>d00onU]nKoY;KUojBfi@05ojBfi@WoYKKU1_nV^nP9ojNmj@ooYkoZ
3OnX_NT01?nW_NWoZ;gYojRmjOnX_NT2o`0000SoZ;gY6?nY_^T4ojRnj@CoZKkY2?nX_^T2ojW0j`Go
Z;kZ2?n[`NX00on``NKo[/;Xojk2j004ojk2j0Ko/L3U00?o/L7Vok70iOna`>D01ona`>D2oinjk003
ojRmjOl0003oZ;gY00;oZ;gY1on9]O<7ofn[mPKoPkSg6?ooool00ol0003oooooooooo`0Qooooo`00
3?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo00cooooo0_nKZn87oiVXh@OoVZcS0onN]NP6oj_=lPCo
[M[g1onfi_H00onehoKo/M;aok7Bl@06ok7Bl@;o[/S]1OnU]nH7ojBfi@KoYKKU00?oYKWXojJkj?nV
^nP01_nV^nP5ojNmj@ooYkoZ4OnX_NT3o`0000OoZ;gY7?nY_^T00onX_^WoZKkYojVnj@05ojVnj@Ko
Z;kY00?oZ[oYojRnj_nX_^X01_nX_^X6oj_1jP03ojRojon^`^So[/;X00Ko[/;X0_na`>D5ok71iPOo
/L3U00?o//7UojRmjOnX_NT00_nX_NT01?l0003oZ;gYojRmjOnX_NT7ohVel`OoKj_f1_n3^?LGoooo
o`03o`000?oooooooooo027ooooo000<ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`000005ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool01oooool00onL
[nGoVj_Roi^[hP04oi^[hPOoVJSQ1onJ[><00onN]NSoZlgboj_=lP06oj_=lP03ojgJmonfi_Ko]^Kf
00Ko]^Kf0onef_<6ok7Bl@03ojJjionU]nKoYKOV00KoYKOV1onT]^D2ojFfi@GoYKWX2?nV^nP00onW
_NWoYkoZojNojP0=ojNojQ7oZ;gY0ol00007ojRmj@03ojVoj_nY_^WoZKkY00coZKkY00?oZL3ZojVn
jOnY_^T03?nY_^T2ojZoj@SoZKkY0_nX_^T5ojZoj@SoZ;kZ0_n[`NX5ojRoj`Ko[/;X00?oZl7Zok71
i_na`NH01_na`NH4ok70i@Co//7U0onX_NT00ol0003oZ;gYojRmj@02ojRmj@?oRKGc1?n@]O06og>[
m0OoNk;f5oooool00ol0003oooooooooo`0Pooooo`003?ooool00ol0003oooooooooo`02ooooo`05
oa0@4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
00?ooooo1OnL[nD6oi^[hPKoVJSQ1_nJ[><3ojK3kPKoZlgb1?ngiOH3okKVmPSo]M[c00?o/M;aojJj
ionV^^L00onV^^L7ojFgiPKoY;KU00?oY;OVojFij?nU^NP01_nU^NP6ojJkj003ojNojonW_n[oYkoZ
00_oYkoZ0_nW_NT?ojRmj@?o00001onX_NT5ojVojP[oZKkY1OnY`>X:ojVnj@KoZ[oY1_nY_^T9ojZo
j@KoZ;kZ00?oZKoYojRojonX_n/01OnX_n/4ojk2j0CoZl7Z2?na`NH00ona`>Go//7Uok;1i@05ok;1
i@?oZ;gY00?o0000ojRmjOnX_NT00_n]`>L7oi2el0KoLj_d1omk/_HGooooo`03o`000?oooooooooo
01oooooo000<ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o00007_ooool00ol0003ooooooj6fi`08oib_i@KoVj_R1_nIZ>42oiZ/h`OoY/?^0on[cO86okOU
mP?o^^7c1onef_<00on]a>_oY[[WojJji`05ojJji`OoYKOV0_nT]^D5ojBgiPSoYKWX0_nV^nP5ojNo
j`WoYkoZ1_nW_NT;ojRmj@?o00001onX_NT2ojS0j`OoZKoZ1_nY_^T00onX`NcoZL3ZojW0jP06ojW0
jPKoZKkY00?oZL7[ojZojOnZ_nT01onZ_nT2ojVnj@goZ[oY0_nX_^X5ojVoj@OoZ;o[00?o[/;Xoj_1
j_n[`NX01On[`NX6ok71iP03ok32j?nb`NGo//7U00Oo//7U0_nX_NT00on]`>Oo0000ojg0i`03ojg0
i`OoT;G`1_mcZo@7og^bmQKooooo00?o0000ooooooooool07oooool000[ooooo00?oEEEEofIVI_l0
00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool07?ooool5oj6f
i`OoW:oU1onKZn83oiVXh@CoW;CX2?nV`nh00on[cO;o]nGfokOUmP03okOUmPKo^^7c1?nef_<4ojg4
j`OoY[[W1OnU]nH2oj>fiPOoY;OV1_nU^NP9ojNoj`KoYkoZ2OnW_NT7ojRmj@?o00001onX_NT6ojS0
j`OoZKoZ0_nY_^T5ojS1k0SoZL3Z0_nY_^T5ojW1j`OoZ[oY00?oZL7[ojZojOnZ_nT03OnZ_nT8ojVo
j@GoZ;o[0_nX_nX8oj_1jP;o/L7V1On``^P7ok;1i@03ok;2i_n]`>Oo[L3W00;o[L3W00?o0000ojg0
ion]`>L00_n]`>L3oi2el0?oU[S_1_mh[?<7ogN]m1Oooooo00?o0000ooooooooool07_ooool001_o
oooo00?o0000ooooooooool06_ooool2ojJmjPKoXKKW1onL[nD3oi^[hPCoV:[S1onL]>P6ojK3kPCo
/M[e0_ngiOH8ok[Ql`03okGJlon]a>_o[LC[00Go[LC[1onV^^L00onU]nKoXkKVoj>fiP04oj>fiPOo
Y;OV0_nU^NP=ojNoj`;oYkoZ3OnW_NT3ojRmj@?o00002?nX_NT00onX`NcoZ<3[ojS0j`06ojS0j`Go
ZKoZ00?oYl;/ojS1k?nX`N`01_nX`N`6ojW0jP;oZ<7/1onY`N/4ojZoj@CoZL7[3onZ_nT8ojVoj@03
ojRojonX_n[oZ;oZ00CoZ;oZ1_n[`NX00onX`>_o/<;Xok32j006ok32j0Co//7U1?nb`^H3ojg0i`05
o`000?n]`>Oo[L3Wojg0ion_`NL01onF^>l6ogR/l`OoMjgd5oooool00ol0003oooooooooo`0Moooo
o`006oooool00ol0003oooooooooo`0Gooooo`KoY[gZ1_nQ]^L5oib_i@03oiNYhonHZ^?oV:[S00Ko
V:[S1onL]>P2ojK3kPOo/M[e0onliO<6ok[Ql`?o/m7_1on]a>/3ojJji`?oX[GV2?nS]^H5ojBgiPoo
Yko[4?nW_NT3o`0000SoZ;gY1OnX`N`8ojS0j`03ojVoj_nW`^coYl;/00?oYl;/2?nX`N`2ojW0jPKo
Z<7/1onY`N/00onZ_nWoZL7[ojW1j`05ojW1j`KoZ[oY00?oZ/7ZojZojOnZ_nT01_nZ_nT6ojVoj@03
ojZojOnX_n[oZ;oZ00KoZ;oZ0_n[`NX5ojS0j`So/<;X00?o//7Uok;2i_nb`^H01Onb`^H3ojg0i`03
o`000?n_`NOo[l7W00;o[l7W1_nF^>l7ogR/l`KoMjgd5_ooool2o`0001oooooo000Kooooo`;o0000
5_ooool3ojS0j`KoY[gZ1_nQ]^L00onL[nGoUjWSoiNYh`03oiNYh`SoV:[S1OnL]>P3ojc;l0Go/M[e
1onliO<00onjhO?o/m7_ok?Ak`05ok?Ak`Go[LC[0_nS]^H6oj:eiPSoXkKV00?oY;OVojNojonW_n/0
3OnW_n/AojNmj@;o00000_nW_NT6ojRmj@WoZ<7/1_nX`>/00onW`NcoYl;/ojO2k005ojO2k0KoZ<7/
0_nV`>`8ojS1k0?oZL7[1?nW`N`8ojW1j`;oZ[oY1OnZ`NX8ojZoj@;oZKoY1OnZ_nT6ojRojP03ojVo
j_nX`>_oZ<3[00KoZ<3[1_n``^P2ojk2j@So//;V00Co[L3Wojo1ion_`NOo00000on_`NL7oiJhk`Oo
N:cc1_mg[O@Gooooo`03o`000?oooooooooo01cooooo000Jooooo`03o`000?oooooooooo01?ooooo
1onX`>/6ojJmjP?oXKKW0onJ[^D6oiNYh`SoV:[S00?oW;CXojc;l?n/bo001_n/bo000onaf_Go_>Gc
okcUl`06okcUl`;o^M[a2?ncdNl00on]a>_oXkKVoj>fiP04oj>fiPKoX[GV1_nS]^H00onU_>[oYko[
ojNoj`0;ojNoja7oYkgY0ol00005ojNmj@;oZ;gY3OnX`N`2ojS0j`GoYl7/1onW`^`2ojS1k0KoY/3/
1_nX`N`00onV_ncoYl7/ojO1k006ojO1k0KoZL7[00?oYl7/oj[1j_nZ`NX01_nZ`NX6ojZoj@03oj[0
jOnZ_nWoZ[oY00KoZ[oY0_nX_nX5ojVojPSoZ<3[0_n``^P6ojk2j@Ko//;V00?o//?Wojo1ion_`NL0
0_n_`NL01?l0003o[l7Wojo1ion_`NL3oiJhk`CoV[[^1_mk[?87ogFYlaKooooo00?o0000oooooooo
ool07?ooool001[ooooo00?o0000ooooooooool04?ooool3ojO0j`SoZ<3[0onV_NX3oifci`KoVZkU
1_nGZN<6oiRZh`;oXkk/1on/bo03ok_Ql`Go_>Gc1Onif_46ok?Ak`03ojJkj?nS]^KoXkKV00KoXkKV
1_nR]NH2oj>fiPGoYKcZ2OnW_n/AojNmj@?o00001onW_NT00onW`NcoZ<7/ojS1k00<ojS1k0WoYl7/
1OnW`^`3ojJoj`OoY/3/0_nX`N`5ojJok0SoYl7/0_nY`N/5ojO1k0SoZ/7Z0_nZ_nT5oj[0j@KoZ[oY
00?oZl3YojVoj_nY_nX01_nY_nX6ojS0j`;oZ;o[2?n^`^T2ok;2iPGo//?W0on_`NL00ol0003o[l7W
ojo1i`02ok73i`OoV[[^1_mk[?87ogFYlaKooooo00?o0000ooooooooool06oooool001[ooooo00?o
0000ooooooooool03Oooool7ojO0j`KoZ<3[00?oYKcZoifcionM/nL01OnM/nL6oiZ^i@KoUjWS0_nH
Z^<6oj>nk0Co[<_`1onkhO<00onliO?o^M[aokWJl@06okWJl@;o/m7_1OnV^nP8oj>fiP?oX[GV0onS
^>P7ojFljPKoYko[0_nW_^X>ojNmj@?o00001onW_NT5ojO1k0[oZ<7/3OnW`N`00onW`^coY[o[ojJo
j`05ojJoj`GoY/3/00?oYko[ojJok?nV_n`01_nV_n`6ojO1k003ojJok?nW`NcoYl7/00KoYl7/1_nZ
`NX2ojS1k0OoZ/3Y0_nZ_nT5oj_0j@SoZKoZ0_nX`>/6ojRoj`Ko[/;Y00?o[<;Yok;3ionb`nL01_nb
`nL2ojo1i`03ok73iol0003o/L?W00?o/L?W1onJ^^h6og^/lPOoMJWc5_ooool00ol0003ooooooooo
o`06ooooo`Go00003oooool001[ooooo0_l0000;ooooo`_oYl3[0_nX`>/5ojFljPOoWK?W1_nJ[^D3
oiNYh`?oV:kV2?nS_^`00on/bo3o^n7cok_Ql`06ok_Ql`?o_n;`1_nif_42ok38k0OoY[_X1_nS]^H0
0onR]^OoXkSXoj>hj005oj>hj0OoYKcZ0_nW_n/6ojNnjPKoYkgY00CoY[gYojNmjOnW_NWoYkgY0ol0
0007ojNmj@WoYl7/1_nX`N`00onW`>coYl7/ojO1k00<ojO1k0;oYkoZ2?nV_n/00onV`>coYko[ojNo
j`03ojNoj`SoY[o/0_nW`N`5ojJok0SoYl7/0_nZ`NX6ojS1k0GoZ/3Y00?oZ/7Zoj_0jOn[`>T01_n[
`>T6ojVojP;oZ/3Y2?nX_n/2ojk2j@Go[<;Y1_nb`nL5ok73i`03o`000?na`nOo/L?W00;o/L?W0onJ
^^h3oibkkPKoOZca1omeYo4Fooooo`03o`000?oooooooooo00Kooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A00?ooooo`006_ooool00ol0003oooooooooo`06ooooo`;oY[o[3?nW`>/2ojS0j`OoYKcZ1onM
/nL3oiZ^i@;oU:ST1onH[^H6oj>nk0?o/M;a1OnkhO<7okoRl003okWJlOn`b>co/<S/00Co/<S/1onV
^nP2oj>fiPGoX[KW1onS^>P5ojFljP?oYko[1onW_^X2ojNmj@CoY[gY0ol00007ojNmj@goYl7/0_nX
`N`5ojO0k0[oYl7/1_nW_nX6ojJoj`03ojRnjOnW_n_oYko[00GoYko[1_nV_n`00onX_n[oY[o/ojJo
k006ojJok0KoYl7/0_nV_n`8ojS1k003oj[0jOnZ`N[oZ/7Z00?oZ/7Z2?n[`>T2ojVojPKoZ/3Y1_nX
_n/00onX`>_o[<;Yojc2j@05ojc2j@Co//?W1ona`nL01Ol0003o/L?Wok73iona`nOo/LCX00OoW;_^
1_mn[?47ogFWlAKooooo00?o0000ooooooooool01_ooool00onHV9So8B4Qonk^kP0@ooooo`006_oo
ool00ol0003oooooooooo`03ooooo`KoY[o[2?nW`>/6ojS0j`KoYKcZ1_nM/nL00onG[>GoU:SToiBX
i004oiBXi0OoV:kV0onS_^`7ok7Bl@03ok_Qlonoh_3o_n;`00Ko_n;`0_nheNl7ok38k0GoY[_X0_nQ
]NL7oj:fi`OoXkSX00?oYKcZojNojonW_n/01OnW_n/5ojNnjPCoY[gY0ol00002ojJmj@KoYkgY00?o
Yl3[ojO1k?nW`N`02onW`N`3ojO0j`KoYl3/1_nW`N`2ojNnjPSoYkoZ0_nV_n/5ojRnj@OoYko[0_nV
_n`5ojRojPSoY[o/0_nW`N`6ojJok0KoZ<7/00?oY/3/oj[1j_nZ`NX01OnZ`NX7oj_0j@WoZ/3Y0_nX
_n/5ojS0j`Oo[<;Y00?o//?Wok73iona`nL02?na`nL00ol0003o/LCXok74j002ok74j0OoW;_^1_mn
[?46ogFWlAOooooo00?o0000ooooooooool01_ooool00onHV9So8B4Qonk^kP0?ooooo`006_ooool0
0ol0003oooooooooo`02ojNoj`SoY[o[1onW`>/7ojS0j`KoYKcZ0_nM/nL5oiN/i@KoU:ST1onH[^H0
0onS_^co/M;aok7Bl@05ok7Bl@?o`>;`1Onoh_05okSEk`Oo/<S/00?oY[_Xoj6eionQ]NL01?nQ]NL7
oj:fi`?oXkSX3?nW_n/00onW_^[oY[gYojJmj@02ojJmj@?o00001_nV_NT2ojNmj@GoYl3[2OnW`N`7
ojO0j`KoYl3/0_nW`N`6ojNnjPKoYkoZ2OnX_^T5ojNoj`03ojRnjOnX_n[oZ;oZ00KoZ;oZ1_nV_n`2
ojNoj`SoY[o/0_nX`N`5ojK0k0OoZ/7Z1on[`>T7oj[0j@03oj_1j_nX`>_oZ<3[00GoZ<3[1_n/`^T2
oj_1jPWo/L?W0_naa>P01?l0003o/LCXok74j?naa>P8oibkkPKoOZca1_meYo4Fooooo`03o`000?oo
oooooooo00Oooooo00?oMgMgofIVI_ooool03_ooool001Wooooo00?o0000ojNojonW_n/01?nW_n/8
ojJoj`OoYl3[1onX`>/3ojFljP?oVk7W1onG[>D6oiBXi0GoV:kV0onYa>d4ok7Bl@Oo`>;`00?o_n;`
okSEkonheNl01_nheNl3ok38k0?oX[OX2?nQ]NL5oj:fi`;oY;cZ3OnW_n/00onV_N[oY[gYojJmj@03
o`0000SoY[gY0_nW_^/7ojO0j`KoYl7/0_nX`N`8ojO0j`?oYl3/2onW_^X2ojNojPgoZ;kY00?oYko[
ojRnjOnX_^T00onX_^T8ojRojP;oY[o/1_nW_n/6ojJok003ojJojonV`>coY/3/00GoY/3/1_nZ`NX0
0onX`N_oZl3Yoj_0j@06oj_0j@CoZ/3Y1?n[`NX7ojS0j`;o[<;Y1_n[`NX6ok73i`03ok74ionaa>So
/LCX00;o/LCX00Co0000ok74j?naa>So/LCX1onL^nh6ogj[l0KoMZG`5oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00gooooo000Iooooo`03o`000?nW_n_oYko[00GoYko[1_nV_n/9
ojO0j`GoZ<3[0_nT_>X6oi^ai`KoUjcU1onDZ>@00onH[^KoZLC]ojW4k@06ojW4k@03ok7BlOo0h_3o
`>;`00Go`>;`0onog^l6okSEk`;oZ/;[1_nR]nP8oj6ei`03oj:fionT_>[oY;cZ00CoY;cZ2OnW_n/4
ojJmjP;o00002?nV_NT6ojNnj`OoYl3[0_nW`N`6ojS1k0KoYl3[3_nW_^X?ojRnj@03ojVojOnX_^Wo
Z;kY00GoZ;kY1_nX_nX2ojVnj@SoYko[0_nV_n`5ojJoj`OoY/3/0_nZ`NX5ojS1j`SoZl3Y00?oZ/3Y
oj_1j_n[`NX01On[`NX6ojS0j`WoZl7Z0_na`nL5ok74i`?o/LCX00Co0000ok74j?naa>So/LCX2?nL
^nh6ogj[l0KoMZG`5Oooool3o`0000Cooooo00Go0000okZj^_ooooooV9RHoa0@400?ooooo`003_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooooonW_n/01_nW_n/2ojJoj`goYl3[
00?oZ<3[ojBlj_nT_>X01?nT_>X6oi^ai`KoUjcU0onDZ>@4oiZbj0OoZLC]0onheo04ol3Rl0Oo_mk_
00?o^=G_oj[2jonZ`^/01?nZ`^/6oj:gj0KoXKGW00?oXKOXojBlj_nT_>X01_nT_>X5ojNoj`;oYkkZ
0_nV_NX3o`0000;oY[gZ1_nV_NT00onV_N[oYkk[ojNnj`06ojNnj`GoYl3[2_nX`N`2ojO0j`koYkkZ
3onX_^T5ojVoj@OoZ;kY0_nX_nX6ojVnj@KoYko[00?oZ;oZojJojonV_n/01_nV_n/5ojK0k003ojFo
k?nX`N_oZ<7[00KoZ<7[1_n[`>T:oj_1jPKoZ<3[1on[`NX00onZ`N[o/LCWok74i`06ok74i`?o/LCX
00Co0000ok74j?naa>So/LCX2?nL^nh6ogj[l0KoMZG`5_ooool00ol0003oooooooooo`02ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`03oooool000kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06oooo
o`03o`000?oooooooooo00GoYko[0onV_n/?ojO0j`KoY;cZ1_nK/NL3oiN/i@?oTZWU1onJ/^P4ojW4
k@Oo^=O`00?o`>;`okoNkonog^l01Onog^l2okOBkPOoZ/;[1_nR]nP2oj6ei`GoXKOX2?nT_>X00onW
_n_oYkkZojNnjP02ojNnjP?o00001_nV_NX2ojJmj@GoY[gZ2?nW_^/00onW`>_oZ<7/ojS1k00:ojS1
k0koYkkZ3onX_^T00onX`>_oZKoYojVoj@06ojVoj@GoZ;kY0_nY`>X8ojVnj@;oYko[1OnX_nX8ojJo
j`03ojK0k?nU_ncoYKo/00?oYKo/2?nX`N/2oj_0j@goZl7Z1onX`>/4oj_1jPCoZ/7Z2?naa>L3ok74
j004o`000?naa>So/LCXok74j0KoW;_^00?oV[[_ogjYkomnZNl01?mnZNl5ogVUkP;oMZG`5_ooool0
0ol0003oooooooooo`0Eooooo`003_ooool01Ol@413ooooooooooooooooo410@00Kooooo0_l00002
ooooo`03ojNojonV_n_oY[o[00GoY[o[3onW`>/6ojBljP?oVk7W0_nD[>H7oi:Yi@OoV[;X00?oZLC]
okSGl?nheo001_nheo03ol?QkPCo_mk_1Ongd^h7oj[2j`?oX[OX0onP]^P7oj6gj0KoY;cZ00?oYko[
ojNnj_nW_^X00ol00003ojNnjPkoY[gZ1_nW_^/2ojS2k0WoZ<7/3_nW_^X?ojRnj@GoZ<3[2?nY_nT0
0onX_^WoZL3ZojW0jP04ojW0jPKoZKkY00?oZKoYojRoj_nX_nX01_nX_nX6ojJoj`03ojRojonU_nco
YKo/00GoYKo/1_nX`N/2ojO0k0ooZl7Z1onX`>/00on[`N[oZ/7Zoj[1jP05oj[1jPKo/LCW1Onaa>P0
1?l0003o/LCXok74j?naa>P2oibkkPGoV[[_1_mnZNl6ogVUkQOooooo00?o0000ooooooooool05?oo
ool000kooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00?ooooo1onV
_n/?ojO0j`?oY;cZ0_nI/NP6oiB/iPOoTZWU1OnJ/^P3ojc6k@Ko^=O`1_o3hNh00onog^oo]m;^okOB
kP05okOBkPGoZ/;[2?nP]^P7oj6gj0;oY;cZ0onW_n/3o`0000OoYkkZ3_nV_NX2ojNnj`KoZ<;/1OnX
`N`2ojNojPgoYkkZ00?oYkkYojRnjOnX_^T02onX_^T2ojS1k0OoZ<3[1_nY_nT2ojS2k0OoZL3Z0_nY
_^T5ojVoj@SoZ;oZ0_nV_n/5ojRoj`OoYKo/0_nX`N/6ojO0k0KoZl7Z00?oZ/7Zoj_1j_n[`NX01On[
`NX6ojS0j`;oZL3[2?nZ`NX2ok74i`So/LCX00Co0000ok74j?naa>So/LGY2?nJ^^l6ogjYk`KoNJG^
5_ooool00ol0003oooooooooo`0Dooooo`003_ooool01Ol0003ooooooooooooooooo000000Gooooo
00?o0000ooooooooool01Oooool5ojJoj`ooYl3[00?oXkc[oiVaj?nI/NP01?nI/NP6oiB/iPOoTZWU
00?oV[;Xojc6kOn/a^d01On/a^d3okSGl0Oo`n7^0_o0fnd8okOBkP03oj[2jonP]^SoX;KX00[oX;KX
1OnQ]nP3ojJnj`?o00000onW_n/6ojNnjPkoY[gZ0_nX`N`8ojS2k003ojS1k?nW_n[oYkoZ00CoYkoZ
2OnW_^X5ojNnj@WoZ;kY1_nX`N`7ojS0j`;oZKoY1_nX`^`5ojW0jP03ojS2k?nY_nWoZKoY00KoZKoY
1_nX_nX2ojVoj@OoZ;o[0onU_n`4ojJok0SoYl3/0_n[`NX5oj[1jPOoZl7Z0_nX`>/6ojW0j`OoZ/7Z
2_naa>P00onaaNWo0000ok75j@02ok75j@SoV[[_1_mnZNl6ogVUkQKooooo00?o0000ooooooooool0
4oooool000kooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo00Kooooo
00?oY[o[ojO0jonW`>/03OnW`>/5oj>lj`KoVK7X1_nD[>H5oi:Yi@;oW;GY2?n/a^d00onheo3o`n7^
ol?QkP04ol?QkPGo`=_]1_ngd^h00onW_n_oX;KXoj2fj00<oj2fj004oj6gj?nV_^_oY[k[ojJnj`?o
000000?oY[k[ojNojonW_n/01?nW_n/2ojNnjPkoY[gZ1_nX`N`6ojS2k003ojNojonW_n[oYkoZ00Ko
YkoZ1OnW_^X00onW_NWoYkkYojNnj@06ojNnj@KoZ;kY0_nW`^d7ojS1k0?oZ<3[1?nV`^d8ojS2k003
ojW0j_nX`^coZ<;/00?oZ<;/2?nY_nT2ojRojPKoZKoY1OnX_n/00onY`>[oY[o/ojJok006ojJok0Ko
Yl3/00?oY/3/oj[1j_nZ`NX01OnZ`NX8oj_1jPSoZL3[1onZ`NX6ok74j0;o//GX0onaaNT01?l0003o
/LGYok75jOnaaNT4oiZjk`?oU[S_1_mmYnh6ogjUkAOooooo00?o0000ooooooooool04_ooool000ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o00002?ooool>ojO0j`OoXkc[1_nI/NP6oiB/
iP03oi:YiOnL]NWoW;GY00CoW;GY1_n/a^d4okcHkP;o`n7^2?o0fnd2okOBkPGoYko[2onP]^P3oj6i
j@?o00001OnV_^/3ojNoj`koY[gZ1?nV_n/7ojS1k0;oZ<;/1OnW_n/8ojNojP03ojNnj_nW_NWoYkgY
00?oYkgY2?nW_^T2ojRnj@KoYl;]1OnX`N`00onV`NgoY/;]ojK2k@06ojK2k@KoZ<;/00?oY/7]ojS2
k?nX`^`01OnX`^`6ojVoj@;oZL7[2?nY_nT00onX_n_oZL3ZojW0jP03ojW0jPSoY[o/0_nW`>`5ojK0
k0OoZ/7Z2?n[`NX6ojW0j`03ojW1jonZ`N[oZ/7Z00KoZ/7Z0_naa>P6ok;5j0;o/LGY00?o0000ok75
jOnaaNT00_n`aNX7oiJhk`KoOJO^1_mnYNdFooooo`03o`000?oooooooooo01;ooooo000>ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`08ooooo`koYl3[1onS_>/6oiVa
j0?oU:cV0onAZNH7oibej@?o[<K]1_nlf>h3olGOj`Ko`=_]0ongd>d6ojNoj`KoX;KX00?oWkOYoj6i
jOnQ^NT00_nQ^NT2o`000003oj6ijOnV_^_oY[k[00CoY[k[00?oYko[ojJmj_nV_NX03?nV_NX8ojJo
j`GoZ<7/0_nX`N/7ojNoj`KoYkoZ0_nW_NX6ojNmj@KoYkkY2_nW`^d00onX`NcoY/7]ojK1k@03ojK1
k@SoY/;]0_nX`^`5ojK1k@OoZ<;/0_nY_nT6ojW1j`KoZKoY00?oZ/3ZojW0j_nY`>X01OnY`>X6ojJo
k0;oYko[1onV`>`7oj[1jPSoZl7Z0_nY`>/5ojW1j`KoZ/7Z00?oZl7Zok;5j?nbaNP01onbaNP00ona
aNWo/<GZo`000004ok35jPKoU[S_1_mmYnh6ogjUkAOooooo00?o0000ooooooooool04Oooool001So
oooo00?o0000ooooooooool02Oooool>ojO0j`OoXkc[0onI/NP2oi>/i`OoTJWV1onL]NT00on/a^go
_=S^okcHkP04okcHkPKoaMo[00?o`=_]okO@kOngd>d01Ongd>d6ojNoj`;oX;KX1OnO]nT3o`0000Co
XKWY0_nV_^/5ojNoj`koY[gZ2?nV_n/00onX`NcoZ<7[ojS1j`04ojS1j`OoYko[0_nW_nX6ojNmjPKo
YkgY0_nW_^T<ojO2k@03ojO1k?nV`NgoY/7]00GoY/7]1_nV`^d2ojJok0OoY/7]1OnX`^`2ojK1k@So
ZL7[0_nY_nT5oj[0jPOoZL3Z0_nV_n`6ojNoj`OoY/3/1onZ`NX8oj_1jPOoZL7[0_nZ`NX5oj_1jPOo
//GX00Go//KYok35j_n`aN[o/<GZo`000004ok35jPKoU[S_1_mmYnh6ogjUkAOooooo00?o0000oooo
ooooool04?ooool001Sooooo00?o0000ooooooooool02_ooool>ojO0j`?oXkc[0onH/^T6oi>/i`Oo
TJWV1OnL]NT3ojk7k0Co_=S^1_o5gn/3ol7Ij`Oo]m3]0onW_n/3oijfj@?oWkOY0ol000000onO]nWo
XKWYoj6ij@03oj6ij@WoYko[1_nV_NX00onU_N[oY[gZojJmjP05ojJmjPKoY[o[0_nX`^`7ojS1j`Go
Yko[0_nW_^X8ojNmjP?oYkgY1?nW`N`9ojO2k@GoYl7/1onV`Nd2ojK2k@KoY[o/1onV`Nd00onX`^co
Y/7]ojK1k@04ojK1k@KoZL7[00?oYl7/oj[0j_nZ`>X01_nZ`>X7ojW0jPSoYko[0onV`>`3ojJok0So
Z/7Z2?n[`NX5ojW1j`03ojS1jon[`N[oZl7Z00KoZl7Z1?nbaNP4ok;6j@?o/<GZ00Co0000ok35j_n`
aN[o[LG[1_nA/nh6ogbTk0KoQ:O[5oooool2o`00017ooooo000Gooooo`?o00003Oooool:ojO0j`?o
Xkg[1_nH/^T6oi>/i`OoTJWV00?oW;GYojk7k?n^an`01_n^an`00onlf>koaMo[olGOj`04olGOj`Go
`MW[1Ongd>d00onW_n_oW[KYoijfj@04oijfj@?o00001OnO]nT00onQ^NWoYko[ojNoj`0;ojNoj`;o
Y[gZ1OnU_NX7ojJmjP;oY[o[1_nX`^`7ojS1j`03ojNojonW_^[oYkkZ00CoYkkZ1_nW_NX00onW`>_o
Yl7/ojO1k006ojO1k0GoYl;]2OnW`N`5ojK1k@;oYko[2?nV_n`3ojK1k@CoY[o/1onV`Nd2ojW1j`Go
Yl7/2?nZ`>X7ojW0jPKoYko[00?oYl3[ojJok?nV_n`01OnV_n`8oj[1jPSoZl7Z00?oZL7[ojS1jonX
`N/00onX`N/8oj_1jP03ok;5j?nba^Wo//KY00Co//KY0on`aNX00ol0003o[LG[ojg5j`02ojg5j`Ko
TK?^1_mlY>`6ohBWjaGooooo00?o0000ooooool000004Oooool001Oooooo00?o0000ooooooooool0
3_ooool5ojO0j`;oZ<3[1_nS_N/6oiRbj@KoTjcW0onAZNH4oibej@Oo[/O/0onne^`4olGOj`Oo`MW[
00?o]m3]ojNojonW_n/00onW_n/2oijfj@?o00000_nN]^T5oingj@?oX[WZ2onW_n/9ojFmjPGoY[gZ
0onW`>/7ojS2k0?oZ<7[1?nW_n/7ojNnjP;oYkgZ1OnW`>/8ojO1k003ojO2kOnW`NcoYl7/00_oYl7/
00?oY/7]ojNojonW_n/01?nW_n/6ojJok003ojNnj_nV_ncoY[o/00KoY[o/1OnV`Nd2ojFok0OoYl7/
1_nZ`>X00onZ`N[oZL3ZojW0jP06ojW0jP;oYko[1OnW`>/7ojJok0SoZ/7Z1_n[`NX00on[`^_oZ<7[
ojS1j`05ojS1j`KoZl7Z00?o[<;Zok;6jOnba^T01_nba^T01?n`aN[o[LG[ojg5jol00003ojg5j`Ko
TK?^1omlY>`6ohBWjaKooooo00?o0000ooooooooool03oooool001Oooooo00?o0000ooooooooool0
3oooool00onW`>_oZ<3[ojS0j`04ojS0j`KoXkg[1_nH/^T3oi>/i`?oSjWW1onL]NT4ojk7k0Oo_]K/
00?oaMo[ol7Ijoo1fN/01Oo1fN/2okW@k0CoYko[0ol00006oijfj@03oingjOnR^N[oX[WZ00GoX[WZ
1onW_n/=ojFmjP03ojJmj_nW`>_oYl3[00GoYl3[1OnX`^`00onX`>_oYko[ojNoj`06ojNoj`GoYkkZ
0_nV_^X7ojO0j`KoYl7/0_nX`^`:ojO1k0CoYkkZ1onW_n/2ojJok0GoYkkZ2?nV_n`00onV`NgoYKo/
ojFok004ojFok0OoYl7/0_nZ`>X5oj[1jPKoZL3Z00?oZL7[ojO0jonW`>/01_nW`>/5ojJok0;oY[o[
2?nZ`NX2oj_1jPGoZl;[1onX`N/2oj_1jPGo[<;Z1_nba^T2ok;7j@?o[LG[00Co0000ojg5jon]aN_o
[LG[1_nA/nh7ogbTk0KoQ:O[5_ooool00ol0003oooooooooo`0>ooooo`005oooool00ol0003ooooo
ooooo`0@ooooo`OoZ<3[1_nS_N/3oiRbj@?oTZgY1_n?ZNL7oibej@03ojk7k?nne^co_]K/00Ko_]K/
0oo7gNT4ol7Ij`Go^M3/0ol00003ojNoj`?oW[KY1?nO]nT8oj:ijPKoYko[2onU_NX3ojFmj`SoYl3[
00?oZ<;/ojS0jonX`>/00onX`>/8ojNoj`03ojNnj_nV_^[oY[kZ00CoY[kZ1onW`>/2ojO1k0KoZ<;/
1OnW`N`9ojNnjPGoYko[00?oZ;gXojNnj_nW_^X01_nW_^X6ojJok0;oYko[1onU_n`3ojO1k0CoY/3/
1onZ`NX2ojW0jPGoZL7[2?nW`>/00onV_ncoY[o[ojJoj`04ojJoj`OoZ/7Z1on[`^/8ojS1j`Oo[<;Z
0_nba^T6ok;7j@?o[LG[00?o0000ojg5jonW`^d01_n=[^`7og^PjPKoS:WY5oooool00ol0003ooooo
ooooo`0=ooooo`005oooool2o`0001;ooooo1onX`>/3oj>mj`?oVKC[1_nB[NT6ohnYi`GoW;GY0on^
aN/5okkFk0KoamgY00?o`MW[okW@k?nid>`00_nid>`3o`000004okW@k?nW_n_oYko[ojNoj`?oW[OZ
1onO]nT6oj:ijPSoYko[1_nU_NX8ojFmj`KoYl3[00?oZL;/ojS0jonX`>/01OnX`>/6ojNoj`03ojJm
j_nV_^[oY[kZ00KoY[kZ1OnW`>/:ojS2k003ojO1k?nW_^[oYkkZ00_oYkkZ00?oYko[ojRmj?nX_NP0
0onX_NP8ojNnjP;oY[o/1_nW_n/5ojFok003ojJok?nV`>coY/3/00KoY/3/1_nZ`NX8ojW1j`OoYl3[
2?nV_n/7oj[1jPOoZl;[2?nX`N/5ojc2jP;o[/?Y2?nbanT00on]aN_oYl;]o`000003ojO2k@KoSJk/
1omkX>X6ohbYjAKooooo00?o0000ooooooooool03Oooool001Oooooo00?o0000ooooooooool04_oo
ool5ojS0j`;oYKk/1_nI]>/6oi:]j@KoSjWW00?oW;GYojk5jon^aN/01_n^aN/00onne^coamgYolOM
j@05olOMj@?oa=WY00?o^M3/o`000?l000000onid>`2ojW3k0KoW[OZ1onO]nT2oj:ijPcoYko[0_nU
_NX<ojFmj`;oYl3[1OnY`^`7ojS0j`;oYko[1OnV_NX8ojJnjP03ojO0jonX`^coZ<;/00[oZ<;/00?o
Yko[ojNnj_nW_^X02onW_^X00onX_NWoZ;gXojRmj005ojRmj0KoYkkZ0_nY_^T8ojNoj`03ojFok?nV
_ncoY[o/00?oY[o/2?nV`>`6oj[1jPSoZL7[1onW`>/7ojJoj`OoZ/7Z2?n[`^/8ojS1j`03ojc2j_n^
`nWo[/?Y00Co[/?Y1_nbanT01Onban[oYl;]ojO2kOnW`^go000000?oYl;]1_n=[^`6og^PjPOoS:WY
5_ooool00ol0003oooooooooo`0<ooooo`005oooool00ol0003oooooooooo`0Cooooo`03ojS0jonU
_^coYKk/00CoYKk/1_nI]>/6oi:]j@?oSjWW1?nJ/^T6ojk5j`?o_M7Y1?o7gNT3olCIj@?o000000?o
a=WYokW@k?nY`n`01OnY`n`6oijgjPGoWkOY0_nQ^NX<ojNoj`koYKg[0onX`>/6ojW2k0GoZ<3[0onV
_^/6ojJmjPKoY[kZ2onX`^`5ojNoj`WoYkkZ1OnX_NT7ojRmj0;oYkkZ1_nY_^T6ojNoj`03ojRoj_nV
_ncoY[o/00GoY[o/1_nV`>`2ojFok0KoZ/7Z2?nY`N/7ojO0j`OoY[o[1onZ`NX8oj_2j`KoZ<7[00?o
Z<3[ojk3jOn^`nT01_n^`nT2ok;7j@Go//OZ0onW`^d01?l0003oYl;]ojO2kOnW`^d6ohf^k0KoNj3Z
0on<ZNT3oiF_j1Oooooo00?o0000ooooooooool02oooool001Oooooo00?o0000ooooooooool05Ooo
ool6ojFnk0KoVKC[0onB[NT3ohfYj0OoV[;Y0on^aN/7okgAj@03olOMjOo4fNWo000000;o00000oo4
fNT3okcAjPKoZL?/1_nN]nX00onO]nWoXKWZoj6ijP04oj6ijPSoYko[3_nU_N/7ojS0j`KoZL;/00?o
Z<3[ojJnjonV_^/01OnV_^/6ojJmjP;oY[kZ2onX`^`2ojS0j`OoYko[1OnW_^X2ojNmj@OoZ;gY1OnX
_NP2oj[1j`SoZKkY0_nW_n/5ojRojPOoY[o/0_nV`>`6ojFok0KoZ/7Z2?nY`N/5ojO0j`03ojK0k?nV
_n_oY[o[00KoY[o[1OnZ`NX:oj_2j`;oZ<7[1OnX`>/6ojk3j@03ok36j_nban[o//OZ00Ko//OZ0onW
`^d00ol0003oWkg^oinmkP06ohRXj`KoOIkX1onE[nPFooooo`03o`000?oooooooooo00_ooooo000F
ooooo`?o00005oooool6ojFnk0?oVKC[0onB[nX6ohfYj0OoV[;Y00?o[/G[okgAjOnmdNT01OnmdNT3
o`0000Coa=WY1_nldNX6ojW3k0?oW[OZ0onM]nX7oj6ijPOoYko[3_nU_N/8ojS0j`?oZL;/0onW`>/8
ojJnj`?oY[gZ0onV_^/9ojS2k0KoZ<3[1onW_n/00onW_^[oYkgYojNmj@04ojNmj@OoZ;gY00?oZ;gX
oj[1jonZ`N/01?nZ`N/6ojVnj@;oZl3Y1_nX_nX8ojJok0SoYKo/0onZ`NX3oj[1j`SoZL7[00?oYl3[
ojK0k?nV`>`00onV`>`8ojJoj`03oj[1j_n[`^_oZl;[00[oZl;[00?oZ/;[ojS0jonX`>/01OnX`>/4
ojk3j@Co/<KZ1_nbanX01Onab>_oWkg^oinmk_nO_Nko000000?oWkg^1_n8Z>/6ogfNj0OoUJoX5_oo
ool00ol0003oooooooooo`0:ooooo`005_ooool00ol0003oooooooooo`0Hooooo`?oYKk/0onL^>`6
oi:_jPKoSJWX1OnJ/^T3oj_2j`?o_M7Y0ol00005olOIi`03olCIjOnldN[o_=7Z00Ko_=7Z0onY`n`2
oijij`OoWKOZ1onQ^NX7ojNoj`koYKg[1_nX`>/00onY`^_oYl3[ojO0j`05ojO0j`KoY[k[00?oYKg[
ojJnjonV_^/01OnV_^/6ojS2k0;oZL;/1onX`>/3ojNoj`CoY[cY1onW_NT3ojRmj@CoZ<?]1onZ`N/2
ojVnj@KoZl3Y1_nX_nX8ojJok0KoYKo/00?oYKk/oj[1jonZ`N/01OnZ`N/7ojW1j`OoY/3/1_nV_n/0
0onW_n_oZl;[oj_2j`08oj_2j`GoZ/;[1onX`>/00on^`nWo/<KZok36jP05ok36jP;o//OZ1Onab>/3
oinmkP04o`000?nO_NkoWkg^oinmkPGoR:S[1_mmW^P8oiF_j1Cooooo0ol0000;ooooo`001?ooool4
o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h6ooooo`03o`000?oooooooooo01Wo
oooo1_nL^>`6oi:_jPKoSJWX00?oV[;Yoj_2jon[`^/01?n[`^/3o`000003okgAjOo7fNOoamWW00Ko
amWW1onldNX00on_b>coW[W[oijij`04oijij`OoWKOZ0onQ^NX4ojJnj`OoYko[3_nU_N/2ojS0j`Go
ZL;[1onW`>/2ojJnj`GoYKg[1onV_^/2ojS2k0KoZL;/1OnX`>/00onW_^[oY[cYojJlj@06ojJlj@Go
YkgY0_nW`nd7ojS3k@GoZ/7[0_nW`^d8oj_0j@?oZ;oZ0onY`NX8ojJok0;oYKo/1OnU_^`7oj[1j`Oo
ZL7[1onV`>`2ojJoj`GoYko[2?n[`^/7oj[2j`OoZ<3[1_n`a^X2ok77j`Oo/LS[0onO_Nh00ol0003o
UK?/oiFck004oh>Sj0;oR:S[1_mmW^P4oiF_j0?oW[KY4Oooool3o`0000;ooooo00?o0000oooooooo
ool02Oooool000Kooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Ko
oooo00?o0000ooooooooool06_ooool6oibhk0KoTZoZ0on=ZNP3oiB_j@?oZl;[0ol00002oj_2j`03
okgAjOo7fNOoamWW00SoamWW1?nldNX4ojo8k0KoW[W[1OnM]nX2oijhj`OoY[k[1OnW_n/2ojFnj`co
YKg[0onX`>/6ojW2j`GoYl3[0onV_^/6ojFmj`GoY[k[2_nY`^`00onX`>_oYkkZojNnjP03ojNnjPSo
Y[cY00?oYkgYojO3kOnW`nd01?nW`nd7ojS3k@03oj[1jonW`^goYl;]00CoYl;]1_n[`>T00on[`N[o
ZL7ZojW1jP05ojW1jPSoY[o/1_nU_^`8oj[1j`OoZL7[0onV`>`4ojJok0OoYko[2?n[`^/5oj[2j`03
ojW2jonX`>_oZ<3[00KoZ<3[0on`a^X5ok77j`Go/LS[00Go[LK/oiFck?nE/ncoUK?/o`000003oiFc
k0GoPj?X1on4X>H7oijfj@gooooo0ol00005ooooo`03o`000?oooooooooo00Wooooo0006ooooo`03
o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`;o00007?ooool6oibh
k0?oTZoZ0_n<ZnX6oiB_j@?o00001?n[`^/3okW<j0[oamWW00?o_=7Zojo8k?n_b>`01On_b>`6oiji
j`03oifgj_nN^>_oW[S[00CoW[S[1onV_^/00onW_n_oYKk[ojFnj`04ojFnj`SoYKg[1onX`>/6ojW2
j`03ojO0jonV_^_oY[k[00GoY[k[1_nU_N/00onV_^_oZL;/ojW2k00:ojW2k003ojO0jonW_^[oYkkZ
00GoYkkZ1_nV_>T2ojO0k0OoYl?]0onX`nd4ojG3k`OoYl;]0_n[`>T5oj_1jPOoZL7Z2?nV_n`6ojFn
k0SoZ/7[1_nY`N/8ojJok0GoYko[0_nY`>/8oj_2j`03oj[2jonY`^_oZL;[00?oZL;[2?nX`>/00on`
a^[o/LO[ok77j`05ok77j`03ok78jon]a^co[LK/00?o[LK/0onE/n`01?l0003oUK?/oiFck?nE/n`5
oh>Sj0OoQ:3V1onN]^T8ooooo`Co00002?ooool00ol0003oooooooooo`09ooooo`001_ooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001Oooool2o`0001kooooo0onL^>`2
oi>ak0KoS:_Z0onD[nT2o`0000;oU:oY0_n[`^/7okW<j0SoamWW0oo0d^P7ojo8k0?oW[W[1?nL]n/6
oijhj`GoY[k[0_nW`>/7ojFnj`OoYKg[2?nX`>/3ojW2j`?oYl3[2?nV_^/3ojFmj`?oY[k[2OnY`^`5
ojO0j`OoYkkZ0_nV_>T6ojO0k0GoYl?]00?oYlC^ojG3konU`nl01_nU`nl5ojO2k@03ojBok?n[`N[o
Zl7Z00KoZl7Z1OnY`NX2ojW2j`SoY[o/0onU_^`3ojJnj`SoZ/7[1_nY`N/8ojJok003ojNojonY`>_o
ZL3[00CoZL3[1on[`^/7ojW2j`KoZ<3[00?oZl;Zok77jonaan/01Onaan/00onbbN_o[LK/ojg6k005
ojg6k0?oUK?/00Co0000oiFck?nE/ncoUK?/1On3XnP7ohBPiP?oW[KY0onV_>T5ooooo`?o00003Ooo
ool00ol0003oooooooooo`08ooooo`001_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000001Oooool00ol0003oooooooooo`0Nooooo`GoTk7/1On<ZnX3o`0000?oU:oY0onU
_NX6okW<j0?oa]GU1?o7fNL7ol3Bj0?o[lS/0onR_N`7oibgj`KoW[S[00?oY[k[ojO0jonW`>/01?nW
`>/7ojFnj`OoYKg[1_nX`>/00onY`N_oYl3[ojO0j`05ojO0j`KoY[k[00?oYKk[ojJnjonV_^/01OnV
_^/5ojW2k0?oZL;[1_nW`>/5ojNnjP;oYKgZ2?nW`>`00onW`ngoYlC^ojO4kP03ojO4kPSoYL?_00?o
Yl;]ojBok?nT_n`00onT_n`8oj_1jP03ojW1j_nY`^_oZL;[00CoZL;[1onV_n`7ojJnj`KoZ/7[00?o
Z/;[ojW1jonY`N/01OnY`N/6ojJok003ojFnjonY`>_oZL3[00KoZL3[1on[`^/7ojW2j`;oZ<3[1On[
`^X4ok77j`Co//W[1on]a^`3oiFck003o`000?n>Z^SoSZ[X00CoPIgU0_n3XnP3ohBPiP?oSZKU1onV
_>T01?oooooo0000o`000?l0000@ooooo`03o`000?oooooooooo00Sooooo0006ooooo`03o`000?oo
oooooooo00;ooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo01oooooo
1OnC/N`01?n<Zn[o0000o`000?l00002ohb[jP03oiB_jOnU_N[oYKgZ00GoYKgZ0onic>P7olKEi@03
olOIioo0d^So`=;X00Go`=;X00?o^<gZoj:mk?nR_N`01OnR_N`7oibgj`?oW[S[0onT_>/7ojO0j`?o
YKk[1?nT_N/7ojFmj`;oZ<3[1OnY`N/7ojO0j`;oY[k[1OnU_^/7ojJnj`03ojW2k?nY`^_oZL;[00Go
ZL;[1_nW`>/00onW_^[oYKgZojFmjP04ojFmjPKoYl3/0_nY`n`6ojO4kPKoYL?_0_nS_^d6ojBok0Ko
Zl7Z0_n[`^/7ojW2j`OoY[o/1onV_^/2oj[1j`GoZ/;[1onY`N/2ojJok0GoYKk[1_nY`>/00onZ`^_o
Zl;[oj_2j`06oj_2j`?oZL;[0onX`N/8oj_2jP03ok77jonbbN_o//W[00Go//W[0on]a^`3ojC0k@?o
SZ[X00Co0000ohjZj?n>Z^SoSZ[X1On1WND7ohjVi@OoY[cY4oooool00ol0003oooooooooo`08oooo
o`001_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2o`00
027ooooo0_nC/N`3o`0000?oS:_Z0on>[>X8ojFmjP03okW<j?o6eNGoa]GU00Goa]GU0oo9e^@4ol3B
j0Co^<gZ1onR_N`5oibgj`03oifhjonT_>_oY;c[00GoY;c[1OnW`>/2ojFoj`OoY;g[1OnU_N/3ojJn
j`KoZL7[1OnW`>/2ojJoj`OoYKk[1OnV_^/2ojW1j`SoZL;[0onW`>/3ojFnj`OoYKgZ0_nW`>`6ojW3
k0KoYlC^0_nU`nl6oj>nk@KoY;o/0_n[`NX6oj_2j`GoZL;[0_nX`N/6ojJok0KoY[k[0_nW_n/7oj[2
j`?oZL7[1?nX`N/7ojFnj`;oZL3[1OnZ`^/6oj_2j`03oj[2jonX`N_oZ<7[00GoZ<7[1_n[`^X00on^
aN_o//W[ok;9j`05ok;9j`03ok7:k?nT`>goY<3]00GoY<3]0on>Z^P00ol0003oSZ[XohjZj006oh6M
i@KoSZKU1_nV_>T2ok75jA;ooooo00?o0000ooooooooool02?ooool000Cooooo00?oEEEEofIVI_l0
00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool07oooool3o`00
00CoS:k/1_n>[>X6ojFmjP?o/lKY1?o6eND7olWFi003ol3Bj?nhcN[o^<gZ00Co^<gZ1onR_N`00onL
]n_oWKS[oifhj`03oifhj`OoY;c[00?oYl3[ojFojonU_n/01?nU_n/7ojBmj`03ojFmjonV_^_oY[k[
00GoY[k[1_nY`N/00onW`>_oY[o[ojJoj`04ojJoj`OoYKk[00?oY[k[ojW1jonY`N/01?nY`N/6ojW2
j`;oZ<3[1_nU_^/5ojFmjP;oZ;o[2?nY`n`3ojO4kP?oYl3[2?nS_^d3ojBok0?oY;g[2?n[`^/00onY
`^_oZ<7[ojS1j`04ojS1j`KoY[o/0_nV_^/6ojNoj`GoZ/;[0_nY`^/7ojS1j`GoYKk[0_nV_^/7oj[2
j`;oZl;[1OnZ`^/7ojS1j`;oZl;Z1On^aN/4ok;9j`Co/L[/1_nT`>d4ohjZj003o`000?n>Z^SoPIgU
00GoPIgU1on>Y^D2ojJlj@Ko/LGY4Oooool00ol0003oooooooooo`08ooooo`005Oooool00ol0003o
ooooooooo`0Looooo`?o00000oooool5ohb^k0KoSZcZ0onU_NX7ok?6j@03olKEiOo9e^CobMKT00Go
bMKT0_o6e>D7okS=jP?oX[g/1?nL^>`6oifhj`GoY;c[0onW_n/6ojFoj`OoY;g[2?nV_^/3ojW1j`?o
Z<7[1onV_n/7ojFnj`OoZL7[0_nY`^/6ojS0j`KoYKk[00?oYKgZojRojonX_n/01?nX_n/6ojW3k0;o
[<7Y1_nW`>/6oj>nk@03oj>jjOnT_N_oY;g[00GoY;g[1_n[`^/00on[`ncoZ<7[ojS1j`06ojS1j`?o
Y[o/0onU_^/8ojNoj`03oj[2jonY`^_oZL;[00CoZL;[1onX`N/00onU_^_oY[k[ojJnj`04ojJnj`Go
Z/;[0_nZ`n/7oj[2j`GoZ<7[0_nX`>/7ojk5j`03ok;9jonab^co/L[/00Co/L[/1onT`>d4ohjZj003
o`000?n>Z^SoPIgU00GoPIgU0on>Y^D3oiZai`Oo/LGY00?o^m7[ooooooooool03oooool00ol0003o
ooooooooo`08ooooo`005Oooool00ol0003oooooooooo`0Iooooo`?o00001oooool5ohb^k0KoSZcZ
00?oYKgZok?6jOnca^T01Onca^T2oko=i0KobMKT1?o6e>D5okS=jP?o[<G]1_nL^>`6oifhj`03ojBl
jonW_n_oYko[00GoYko[1_nU_n/7ojBmj`KoY[k[00?oZL3[ojS1jonX`N/01OnX`N/5ojJoj`;oYKk/
1onU_^/5ojW1j`;oZ/7[2?nX`>/3ojFnj`?oY;k/1onX_n/2ojW3k0Ko[<7Y1_nW`>/2oj>nk@GoXk[Y
1onT_N/2oj_2j`GoZl?/1_nX`N/00onW`>_oYKk[ojFnj`05ojFnj`KoYko[2OnY`^/3ojS1j`?oY[o[
2?nV_^/00onZ`^_oZ/?[oj[3j`04oj[3j`OoZ/;[00?oZ<7[ojS0jonX`>/01?nX`>/5ojk5j`;o/<W/
1onab^`3ojC0k@?oV;;Y1?n8X^H00ol0003oR:;VohFMh`05ohFMh`OoV[7W1?naaNT4ok_Aja3ooooo
00?o0000ooooooooool02?ooool001Gooooo00?o0000ooooooooool05_ooool3o`0000_ooooo1On<
[^`3ohj/jPCoVkCY1Onca^T4oko=i0?obMKT1oo6e>D00onhcN[o[<G]ojc5k@05ojc5k@KoW;S/0onM
^>/3oinjj`SoYko[0onU_n/3ojBnk0OoY;g[0_nV_^/5ojW0j`OoZ<7[00?oY[o[ojFnk?nU_^`01?nU
_^`7ojFnj`03ojW1jonZ`N_oZ/7[00CoZ/7[1_nX`>/00onV_ncoY;k/ojBnk005ojBnk0GoZ;o[0_n[
`NX8ojc1j@?oYl3[0onW_>P7oj>jj@GoY;g[0_nW_n/7oj_3k0;oZ<7[1OnW`>/7ojFnj`;oYko[2onY
`^/00onX`N_oY[o[ojJoj`05ojJoj`KoY[k[00?oZ<3[oj[3jonZ`n/01_nZ`n/3oj[2j`?oZL;/2?nX
`>/00on^aN_o/<W/ok39k004ok39k0Go/L[/0_n]a^d6oiRbj@CoR:;V00?o0000ohRRi_n5WN<01On5
WN<7oiZai`03ok75jOnkdN_o^m7[00Go^m7[4?ooool00ol0003oooooooooo`07ooooo`005?ooool2
o`0001Gooooo0ol0000>ooooo`KoR:_/1onK]>T3ok?6j@Ko_lgT00?obMKTolKDiOo6e>D01Oo6e>D3
oko?iPOo[<G]0onL^>`3oi^hk0KoWk[[2?nW_n/6ojBnk0GoY;g[0onU_^/6ojW0j`GoZ<7[0_nW`>/7
ojFnk0GoYKk[0_nW_n/7oj[1j`;oZ<3[1OnV_n`7ojBnk003ojRojon[`N[oZl7Z00CoZl7Z1_n/`NT0
0on/_nSoYkcXojNlj005ojNlj0OoXk[Y00?oY;g[ojNojonW_n/01?nW_n/5oj_3k0;oZL;/1onW`>/5
ojFnj`;oY[k[2OnY`^/5ojS1j`OoY[o[0_nV_^/5ojS0j`KoZ/?[00?oZ/?/ojW2k?nY`^`01OnY`^`6
ojS0j`03oj_2jon`bNco/<W/00Ko/<W/00?o/L[/ojg6kOn]a^d01?n]a^d6oiRbj@CoR:;V00?o0000
ohRRi_n5WN<01On5WN<5oiZai`;oY;_Y1_nkdN/2okkGk0oooooo00?o0000ooooooooool01oooool0
01Cooooo00?o0000ooooooooool04_ooool2o`0001;ooooo1_n8Zn`7oi^dj@03ok?6jOnocNCo_lgT
00Co_lgT0oo8d^84olKDi@Ko_loV1On/aNd00onQ_NgoVkS/oi^hk005oi^hk0KoWk[[2?nW_n/6ojBn
k003ojBmjonU_^_oYKk[00GoYKk[1_nY`>/00onX`N_oYl3[ojO0j`04ojO0j`OoYKk/00?oYKk[ojNo
jonW_n/01?nW_n/5oj[1j`;oZL7[1onV_n`5ojBnk0;oY;o/1on[`NX2ojc1j@Go[;oX1onW_>P3oj>j
j@?oYKcZ2?nW_n/00on[`ncoZL;/ojW2k004ojW2k0OoYl3[00?oYKk[ojJnjonV_^/01?nV_^/5ojW2
j`;oZL;/1onX`N/5ojJoj`;oY[k[1onX`>/2oj[3j`GoZ/?/1onY`^`2ojS0j`GoZl;[1_n`bN`2ok7:
k0Oo[LK]1_nH/^T4ohRRiP03o`000?n8X^KoQIgS00GoQIgS00?oV[7WojBkjOnT^nT01?nT^nT3ok_A
j`Go_]O/3_ooool00ol0003oooooooooo`07ooooo`005?ooool00ol0003oooooooooo`0?ooooo`?o
00005Oooool6ohR[k0?oVkCY1On[`>T3oko=i0Oob=;R00?oa]CUoko?i_nocnH01_nocnH00on/aNgo
XKg]oj6mk@03oj6mk@OoVkS/0onO^^/4ojBlj`OoYko[1_nT_^`8ojFnj`?oZL3[0onY`N/7ojO0j`Oo
YKk/1onW_n/00onZ`N_oZL7[ojW1j`04ojW1j`OoY[o/00?oY;k/ojBok?nT_n`01?nT_n`5oj_1jP03
oj_2j_n/_nSo[;oX00Ko[;oX1OnW_>P2ojNmj@KoYKcZ1_nW_n/2oj[4k@OoZL;/0onW`>/;ojJnj`03
ojW2jonY`^coZL;/00CoZL;/1onX`N/00onV_n_oY[k[ojJnj`04ojJnj`GoZ<3[2?nZ`n`6ojW2k0;o
Z<3[1on[`^/2ok39k0Ko/L[/0on]a^d3oj6jj`KoT:OU1?n5Vn400ol0003oQI_Qoi2Th`05oi2Th`So
Y;_Y00?o^m7[okkGk?nnen`00onnen`2okcGkPgooooo00?o0000ooooooooool01oooool001Cooooo
00?o0000ooooooooool03?ooool3o`0001Wooooo0on8Zn`3ohj^k0SoZl3Y00?o_lgTolSBh_o8d^80
1Oo8d^83olWBh@Ko_loV0_nibnP6oj6mk@GoVkS/0_nL^Nd7ojBlj`GoYko[00?oYKo/ojBnk?nT_^`0
1OnT_^`6ojFnj`03ojJojonY`N_oZL7[00GoZL7[1OnW`>/2ojJok0OoYKk/1OnW_n/2ojW0jPOoZL7[
0onV_n`4ojFok0OoY;o/00?oZl7Zoj_2j_n[`^X00on[`^X8ojboj003ojNlj?nW_NWoYkgY00CoYkgY
1_nU_>X2ojNoj`KoZ/C]1OnY`^`2ojO0j`coY[k[0_nX`N`7ojW2k0?oZ<7[0onW`>/8ojJnj`03ojS0
jonZ`ncoZ/?/00[oZ/?/0_nY`^`6ojS0j`GoZl;[0_n_b>d6ok7:k003ojo:kOnQ^^_oXK[[00GoXK[[
1_n@YnD4ohFKh@03o`000?n5Vn7oT:CS00GoT:CS1_nT^nT2ok77j`?o_]O/1Onlenh<ooooo`03o`00
0?oooooooooo00Oooooo000Cooooo`?o00002_ooool3o`0001gooooo1_n>[^`6oj_0j@?o]LKW1Oo8
d^86olWBh@03oko?i_nibnSo^L_X00Co^L_X1_nQ_Nd00onK^>coW;W]oibik@04oibik@OoY;c[00?o
Yko[ojFok?nU_n`00onU_n`7ojBnk0;oYKk[1OnV_n/7ojW1j`03ojO0jonV_ncoY[o/00CoY[o/1onU
_^`00onW_n_oZL3ZojW0jP04ojW0jPGoZL7[0_nY`>/7ojFok0GoY;o/0_nT`>d6oj_2jPKo[;oX0_nY
`>X7ojNmj@?oYKcZ0onX`nd8oj[4k@03ojW2k?nW`>_oYl3[00CoYl3[2?nV_^/6ojS1k0KoZL;/1onW
`>/6ojJnj`03ojNojonZ`ncoZ/?/00coZ/?/2?nX`>/00on[`^_o[lS]ojo8k@04ojo8k@?o/L[/1?n_
b^d6oj6jj`KoT:OU1On5Vn400ol0003oT:CSoi2Th`05oi2Th`;oY;_Y1_naan/00onnenco_=O^okcG
kP05okcGkP_ooooo00?o0000ooooooooool01oooool001Cooooo00?o0000ooooooooool01_ooool3
o`00027ooooo1_n>[^`3oj_0j@Ko]LKW0oo8d^86olWBh@;oam3Q1onibnP3oj6mk@CoVk[^1_nL^Nd5
ojBlj`;oY[o[1_nU_n`8ojBnk0KoY[o[1onY`N/7ojJok0?oYKk/1?nU_n`7ojW0jP03ojW1jonY`>_o
ZL3[00CoZL3[1onU_n`00onT_ncoY<3]ojC0k@04ojC0k@KoZl;Z0_n/_nP6ojW0jPGoYkgY0_nW`nd6
ojS3k@KoZ/C]00?oZ<7/ojO0jonW`>/01_nW`>/6ojJnj`SoZ<7/1_nY`^`7ojO0j`;oY[k[1OnW_n/>
oj[3k0KoZ<3[00?oZ<7[ojo8kOn_b>d01_n_b>d00onab^co[l[]ojo:k@04ojo:k@KoXK[[1_n@YnD4
ohFKh@03o`000?n5Vn7oT:CS00;oT:CS0onM/nL7ok77j`03ok_EkOnlenko_=O^00Go_=O^00?o]m?^
ooooooooool02Oooool00ol0003oooooooooo`07ooooo`005?ooool00ol0003oooooooooo`03oooo
o`?o00009Oooool6ohj^k003oj_0jOnea^Oo]LKW00Ko]LKW00?ob=;RolWBhOo9d^401?o9d^44olO@
h@Go^L_X0on`an/6oi^jkPKoW;W]00?oY;c[ojJojonV_n/01?nV_n/6ojFok0SoY;k/1_nV_n/7ojW1
j`SoY[o/1_nU_n`5ojW0jP;oZ/7Z1onY`>/7ojFok0OoY<3]0on[`^X3ojS2k@SoZL3Z00?oYkgYojO3
kOnW`nd01?nW`nd6ojS3k@;oZ/C]1OnX`N`6ojO0j`03ojJmj_nV_^_oY[k[00GoY[k[1_nX`N`00onY
`ncoZL;/ojW2k005ojW2k0GoYl3[0_nV_^/7ojNoj`koZ/?/0_nX`>/5ojS1j`Ko[lS]0_n`b^d7ojo:
k@?oXK[[0_nEZ^D6ohVNh@GoRYgP00?o0000oifcionM/nL01OnM/nL4ok77j`Co^mG]1?nlenh4okOC
kP_ooooo00?o0000ooooooooool01_ooool001?ooooo00Co0000oooooooooooooooo0ol0000Yoooo
o`?oSZk/1?nK]^/6okG6i`?o_lWR0oo9d^47olO@h@03okW;j?n`an_o/<O[00Go/<O[1_nK^^h3oibi
k@?oWK[]1onV_n/3ojFok0_oY;k/0onV_n/3ojRoj`OoZL7[2?nV_n`6ojFok003ojW0j_nZ`N[oZ/7Z
00CoZ/7Z1OnY`>/00onY`>[oYKo/ojFok006ojFok0GoY<3]0_nT_nd6ojS2k@KoZL3Z0_nV`nh7ojO3
k@?oZ<?]0onX`^`7ojS1k0;oYl3[1OnV_NX7ojJnj`;oZ<7/1OnY`n`7ojW2k003ojO0jonV_^_oY[k[
00CoY[k[1OnW_n/2ojW3k0[oZ/?/2onX`N/2ojo8k@Ko/<[]0on_b^d3ojJok0KoUJ[U1_n9W^45ohZM
h003o`000?nM/nOoWK?W00GoWK?W00?o/LO[ok_EkOnkeNd01OnkeNd00onlenko]m?^okOCkP05okOC
kP[ooooo00?o0000ooooooooool01_ooool001?ooooo1?l0000^ooooo`KoVkK[0onea^L6oko9hP03
olWBhOo7d>7oam3Q00Goam3Q0oo3cN87ok37j`?oVk[^0onJ^Nh6oifjk@GoY[o[0_nW_n/>ojBnk0Ko
Z;o[1OnY`N/2ojS0j`SoY[o/1_nU_n`7oj[1jP03ojW0jonY`>[oZL3Z00?oZL3Z2?nU_n`00onT`>go
Y;o]ojBok@04ojBok@KoZ<;]0_nY`>X6ojK3kPGoYl?]0_nW`^d6ojS2k0GoZ<7/0_nW_^X7ojJmjPGo
Y[k[0_nX`^`7ojW3k0?oZL;/0onX`>/8ojJnj`03ojNojonY`ncoZL?/00CoZL?/1OnZ`n`2ojW3k0co
Z<7[0_n]and6ok3:k@03ok3;k_nV_ncoY[o/00GoY[o/1_nEZ^D6ohVNh@GoRYgP00?o0000oifcionM
/nL00onM/nL00onY_n[o^mG]ok_Ek@05ok_Ek@;o_=[_1_ngdnh00onacNkoooooooooo`08ooooo`03
o`000?oooooooooo00Kooooo000Cooooo`;o0000<Oooool6oi^fj`03okG6ionobN;o_lWR00Co_lWR
0oo6cMl4olO@h@Ko`lgR1On`an/2ojO2k@KoV[W^1_nM^^d00onV_n_oYko[ojNoj`04ojNoj`koY;k/
1_nX_n/00onY`N_oZ<3[ojS0j`04ojS0j`KoY[o/2?nU_n`7oj[1jPKoZL3Z1_nU_n`2ojJoj`OoY;o]
0onX`^d3ojG1k@SoY/?^00?oYl?]ojO2kOnW`^d01?nW`^d6ojS2k003ojS1k?nW_^[oYkkZ00CoYkkZ
1onV_NX00onV_^_oZ<;/ojS2k004ojS2k0GoZL?/0_nX`N`6ojS0j`KoY[k[00?oYko[ojW3k?nY`n`0
1_nY`n`00onZ`ncoZL?/ojW3k004ojW3k0SoZ<7[1_n]and2ok3:k@Go/<_^1_nV_n`7oiFZi@GoRIkQ
1On:WN000ol0003oWK?Woifci`05ojVojPCo^mG]1Onlf^l2okOCkPGo/Lg^2Oooool00ol0003ooooo
ooooo`06ooooo`001Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02?ooool00ol0003ooooo
ooooo`0_ooooo`?oVkK[1?nX_^T3oko9hPOoa/gO00?oam3Qol?=h_o3cN801_o3cN800on`an_oYl;]
ojO2k@04ojO2k@KoV[W^0onM^^d3oj2lk0OoYko[3_nT_^`3ojRoj`[oZ<3[0_nV_n`<ojFok0OoZ/7Z
1_nY`>X2ojFok0KoY[o[1OnT_nd2ojFok0KoYL7]1_nV`nh00onV`>coYl;]ojO2k@06ojO2k@?oZ<;/
0onW_nX7ojNnjP?oY[gZ0onV_n/8ojS2k003ojW3k?nX`NcoZ<7/00CoZ<7/1_nX`>/2ojJnj`GoYko[
1_nY`n`00onZ`ncoZL?/ojW3k006ojW3k0KoZ<7[1_n]and2ojo;kPOo/<_^1_nV_n`3oiFZi@?oSZ3P
1?n:Vmh2ohVNh@?oRYgP0_nGZn@00ol0003oZKoZojVojP05ojVojP03ok_EkOnlf^oo_=[_00Co_=[_
00?o^=G_ok7=k_nacNh01_nacNh8ooooo`03o`000?oooooooooo00Kooooo00001OnHV9So8B4Qonk^
k_ooooooA4A400?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`09ooooo`03o`000?oooooooooo02ko
oooo2?nX_^T00onobN;oa/gOolK=g`05olK=g`;obLgM1oo3cN82oko:h`OoYl;]1_nJ^Nh6oj2lk0So
Yko[3OnT_^`>ojS0j`goYKo/1onZ`NX3ojW0jP?oZKoZ2?nV_n/00onT_ngoYKo/ojFok004ojFok0Ko
YL7]0_nV`nh5ojK0k0KoYl;]2?nW_nX7ojNnjPKoY[o[1_nX`^`00onY`^coZ<7/ojS1k006ojS1k0?o
Z<3[0onV_^X7ojNoj`;oZL?/1OnZ`n`6ojW3k0SoZ<7[0on]and5ojo;kPGo/<_^00?oZ<7[oiR/i?nH
[>@01?nH[>@7ohjPh0GoRY_N1_nGZn@00ol0003oZKoZojVojP03ojVojP;o]m;^1?nlf^l4okSEk`Ko
/Lg^00?oZL?/ooooooooool01_ooool00ol0003oooooooooo`06ooooo`0000CooooooiRHV?lQ8B7o
k^k^1?ooool01Ol@413ooooooooooooooooo410@00[ooooo00?o0000ooooooooool0;_ooool6ojRn
j@?o/L?W1Oo6cMl4olW=g@Co`lgR1Onob^<5ojO2k@;oXKk^1_nJ^Nh6oj2lk0SoYko[3OnT_^`>ojS0
j`goYKo/1OnZ`NX2ojW1j`KoZKoZ1_nV_n/2ojRojPOoYKo/0onU`Nd3ojNoj`OoY/3/0_nW`^d<ojNo
jPOoYkkZ1_nV_n/2ojS2k0GoZL;/1_nX`N`00onW_n_oY[kZojJnjP05ojJnjPGoYko[0_nY`n`7oj[3
k0;oZL?/3?nX`N/00on]ango[l_^ojo;kP05ojo;kP03ok3;k_nX`N_oZ<7[00?oZ<7[1_nH[>@6ohjP
h0KoRY_N1_nGZn@00ol0003oZKoZokOBkP05okOBkP03okcJkonheNoo^=G_00Go^=G_0_nacNh5ojW3
k0Oooooo00?o0000ooooooooool01_ooool000;ooooo00?oV9RHob4Q8Oo^k^h00oooool01Ol0003o
oooooooooooooooo000000_ooooo0_l0000_ooooo`?oZ;kY1_na`nL3olK=g`KobLgM00?o`lgRoko:
honob^<01_nob^<00onW`^goXKk^oj6nkP04oj6nkPKoV[W^0onP_>`4oj:mk0OoYko[3OnT_^`3ojS0
j`?oZL3[2?nX`>/=ojFok003oj[1j_nY`N_oZL7[00CoZL7[1_nY_nX2ojJoj`KoZ;oZ1OnU_n`2ojNn
jPKoYko[1OnV`>`2ojNnjPcoYkoZ2OnW_^X3ojJoj`?oZ<?]1onY`^`2ojS1k0GoYko[1onV_^X00onW
_n_oZL?/ojW3k004ojW3k0GoZ/?/0_nY`n`<ojS1j`;o[LS^1_n_bnh00on_c>koZ<7[ojS1j`05ojS1
j`GoV:cT1_n>X>06ohZKgPKoUj_T00?o0000okOBk_ngd^h01?ngd^h2okcKl0Ko^=G_00?o/m3_ojW3
k?nY`n`01_nY`n`7ooooo`03o`000?oooooooooo00Gooooo0003ooooo`03ogMgMomVIVKooooo00;o
oooo00Go0000ooooooooooooooooo`00000=ooooo`03o`000?oooooooooo02gooooo00?oZ;kYok73
iona`nL01_na`nL00oo6cMoobLgMolW=g@04olW=g@?ob<cL1_nob^<2ok_8i0OoXKk^0onJ^Nh4oiZj
kPKoX[g/1OnW_n/2ojJok0_oY;k/0_nT_n`6ojW0j`SoZ<3[2onU_n`2ojFok@OoZL7[0onY_nX3oj[0
j@SoZ;oZ00?oYKo/ojNnj_nW_^X01?nW_^X6ojNoj`03ojK0k?nW_^[oYkkZ00CoYkkZ2?nW_nX;ojNn
jP;oZ<;]1_nX`nd5ojW2k0;oZ<7[1onW_n/3ojJnjP?oYl7/2?nY`n`00onZ`ncoZL?/ojW3k004ojW3
k0SoZ<7[1_n]b>h2ojo;kPGo[lc^1onX`N/5oiR/i0KoSZ3P1_n:Vmh2oiN[i0CoY;[Y00Co0000okOB
k_ngd^ko]m;^1Onlfo02okSEk`Go/m3_1_nY`n`00onW_n_oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo0004ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`0<
ooooo`03o`000?oooooooooo02kooooo1_na`nL3okW5i0?obLgM1oo8c=`00onob^?o^lSTok_8i004
ok_8i0GoXKk^0onM_Nl6oiZjkPKoX[g/00?oYko[ojJok?nV_n`01?nV_n`7ojBnk0KoY;o/1_nY`>/8
ojS0j`OoYKo/1_nU_nd5ojW1j`;oYl7/1_nZ`>T6ojRojP03ojVojOnW_^[oYkkZ00KoYkkZ0onW_n/3
ojRnj@OoYkkZ0onW_nX3ojNnj@WoYkkZ1_nX`^d6ojS3k@03ojW2k?nX`N_oZ<7[00CoZ<7[1OnW_n/2
ojJnj`KoYl7/3onY`n`3ojS1j`CoZ<7/1On]b>h2ojk<k`Oo[lc^0onX`N/3oiZ[h`GoTJ7N1_n<V]`6
oiBVhPOoY;[Y00?o0000okOBk_nlfo001?nlfo03okSHl0Ko/m3_0_nY`n`5ojNoj`Kooooo00?o0000
ooooooooool01Oooool00005o`000?nj^[[ooooooiRHV?l@41000oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00oooooo00?o0000ooooooooool0;_ooool3ok73i`Ko^LGT00?obLgMolS<g?o8c=`01Oo8
c=`2olO:g0Oo^lST00?oXKk^oifmkonM_Nl01OnM_Nl6oiZjkP?oX[g/0onS_^`7ojJok0?oY;k/0onT
_nd7ojBok0?oZL3[0onY`N/8ojS0j`?oYKo/0onV_n`7ojFok@03ojW1jonW`NcoYl7/00CoYl7/1_nZ
`>T2ojRojPGoZKoY1_nW_^X00onY_nWoZ;kYojRnj@05ojRnj@GoYkkZ0_nX_nX6ojNnj@KoYkkZ00?o
Yl;]ojS2kOnX`^d01_nX`^d3ojS3k@?oZ<7/1onX`N/00onW_n_oY[k[ojJnj`04ojJnj`KoYl7/3OnY
`n`00onX`>_oZ<7/ojS1k006ojS1k003ojg8k_n^c>oo[/c_00Co[/c_1On_c>h00onX_^[oVZ_SoiZ[
h`05oiZ[h`GoTJ7N1_n<V]`6oiBVhPKoY;[Y00?o//k^o`000?nlfo000_nlfo06okSHl0?o/m3_0_n[
aNd8ojNoj`Gooooo00?o0000ooooooooool01Oooool00005oiRHV?l@413o0000ob4Q8Oo<c<`00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^013ooooo0_l0000_ooooo`03ok73ioniaNCo^LGT00Co^LGT
0onoan05olS<g0Coal[L1Onkb>@3okO6i@OoWKg_0onJ^^h3oiZkk`KoXkk/1onV_n`6ojBok@GoY;o/
0_nT_nd6ojW1j`SoZ<3[1_nV_n`7ojFok@OoYl7/0onZ`>T3ojW2j`OoZKoY0_nW_^X5ojVoj@OoZ;kY
00?oYkkZojRoj_nX_nX01?nX_nX6ojNnj@;oYkkZ1OnW`^d6ojS2k@03ojS2k?nX`NcoZ<7/00GoZ<7/
1OnX`N/2ojNnjPOoY[k[0onW`N`3ojW3k@WoZL?/1OnX`>/6ojS1k003ojg:kon^c>oo[/c_00Ko[/c_
00?o[lc^ojRnj_nX_^X00onX_^X6oiZ[h`KoTJ7N1_n<V]`6oiBVhP;oY;[Y1?nbc^h00ol0003o//k^
okcKl006okSHl003ok?Bl?n[aNgoZlG]00CoZlG]1_nW_n/00onW`>_oooooooooo`03ooooo`03o`00
0?oooooooooo00Gooooo000Oooooo`03o`000?oooooooooo02gooooo1OniaN@5oko7h0?ob<cL1_o7
b]`00onkb>Co]lKUokO6i@05okO6i@GoWKg_0_nK_>l6oiZkk`KoXkk/1onV_n`6ojBok@03ojBok?nT
_ngoY;o]00CoY;o]1_nY`N/8ojS0j`KoY[o/1onU_nd5ojO1k0;oYL7]1_nY`^/5ojVoj@;oZL7[1onY
_nT5ojRnj@;oZ<3[1onX_nX3ojNnj@[oYl;]0_nX`^d5ojS2k0OoZ<7/00?oZ<7[ojNnj_nW_^X01?nW
_^X5ojJnj`;oZ<?]1_nY`nd5ojW3k0;oZL;/1onX`>/2ojS1k0Go[L[_1_n^c>l00on^bnkoZ;kZojRn
jP04ojRnjPKoVZ_S1_nAXMh7ohbJg0?oU:KR0onR^>P6ok;>kP03o`000?njg?7o^=S`00?o^=S`1?nc
d_06oj_5k@;oYko[1OnW`>/4ooooo`03o`000?oooooooooo00Gooooo000Pooooo`03o`000?oooooo
oooo02gooooo0oniaN@7oko7h003olS<g?o7b]coal[L00Coal[L0oo5b=`7okO6i@03oifmkonK_>oo
Vkc_00CoVkc_1_nJ^nl3oj>nk0?oY;o/1onV_n`=ojBok@?oZL7[1?nX`N/7ojS0j`OoY[o/1_nU_nd0
0onW`NcoYL7]ojG1k@04ojG1k@KoZL;[00?oZKoYojW1jonY`N/01?nY`N/7ojVoj@03ojRnjOnX`>_o
Z<3[00CoZ<3[1OnX_nX=ojO2k@WoZ<;/0onX`N`;ojNnjP03ojJnjonX`ngoZ<?]00CoZ<?]1_nY`nd0
0onY`ncoZL;/ojW2k004ojW2k0GoZ<3[0_nXa>d7ojg:k`;o[/c_1On^bnh6ojRnjPKoVZ_S1_nAXMh3
ohbJg0?oU:CP1onR^>P2ok;>kPCo^]ca00?o0000ok[LlOnhf?001oncd_03oj_5k@[oYl3[0oooool0
0ol0003oooooooooo`05ooooo`008Oooool00ol0003oooooooooo`0]ooooo`03okW5i?noan3o_lOP
00Go_lOP0_o3amd5olO:g0GoaLSL1Onga^D3okC4iPKoVkc_0onJ^nl3oiZll0KoY;o/1onV_n`=ojBo
k@OoZ<7[1OnX`>/2ojW0jPOoY[o/0onU_nd3ojG0k0OoYL7]0onY`^/3ojK1k@OoZL7[0onY_nT3ojS2
k0SoZ<3[00?oZ;oZojO2kOnW`^d02onW`^d;ojS2k0;oZ;o[3?nW_^X00onW`NcoZ<?]ojS3k@06ojS3
k@KoZL?]1onY`^`00onX`>_oZ<C]ojS4k@04ojS4k@Go[L[_0_n^cO07ojk;kP?oZ;kZ0_nKZN06oi>O
g0KoSY[K1onDY>05oj:hj0;o/<k_1Onjg?400ol0003o]mWaokOIl@06ok?Bl003oj_5kOnW`>_oYl3[
00_oYl3[1?ooool00ol0003oooooooooo`04ooooo`008_ooool00ol0003oooooooooo`0^ooooo`Co
_lOP1Oo3amd3olO:g0OoaLSL00?o]lKUokC4i_nda>H01Onda>H6oi^lk`KoV[c`1_nT_n`7ojJok0go
Y;o]1onX`N/00onX`>_oZL3ZojW0jP04ojW0jPGoY[o/0_nW_n/6ojG0k0GoYL7]0_nU`>d6ojK1k@Go
ZL7[0_nV`^d6ojS2k0KoZ<3[4?nW`^d7ojS2k0KoZ;o[2?nW_^X5ojO1k0KoZ<?]2?nY`nd3ojW2k0?o
Yl3/2?nXa>d00on]b^oo[/g`ojk=l004ojk=l0?o[/_^0onU^>H6oi^Yh0KoTioL1_n>V]/7oiBTh003
oj:hj?n`c^oo/<k_00Co/<k_0_njg?43okOIl@03o`000?ngfO7o]mWa00;o/m;`1On[aNd=ojO0j`?o
oooo00?o0000ooooooooool01?ooool002?ooooo0_l0000`ooooo`03oko7h?o3amgo`lOM00Go`lOM
00?oal[LolG8g?o5b=`01Oo5b=`2olC6g0Ko]<CV0_nb`^H6oi^lk`KoV[c`0onT_n`3ojBok@OoY[o/
3OnT_nd3ojS1j`CoYl7/1onY`>X00onV_ncoYko[ojNoj`04ojNoj`KoYL3/00?oYL7]ojG0kOnU`>d0
1?nU`>d6ojK1k@03ojW1jonV`^goY/;]00CoY/;]1_nX`^`2ojS0j`_oYl;]00?oYl7]ojO2kOnW`^d0
1_nW`^d3ojS2k0?oYko[1onX_n/3ojNnjP?oYko[1onW`N`2ojS3k@[oZL?]0_nX`N/6ojO0k0KoZ<C]
0_n]bo05ojk=l003ojc7kOnU^>KoYKSV00GoYKSV1_nKZN06oi>Og0GoSY[K1_nDY>000onR^>So/<k_
ok3>k`04ok3>k`?o^Mgb1?ngfO400ol0003o/m;`oj_5k@07oj_5k@goYl3[0_ooool00ol0003ooooo
ooooo`04ooooo`009Oooool00ol0003oooooooooo`0^ooooo`Ko`lOM0oo5a]/4olG8g0Goa<KL0ond
a>H5ok;2iPKoVkc_0onJ_?03oiZml0KoY;o]1onV_n`=ojBok@OoYl7/1onY`>X7ojNoj`?oYL3/0onV
_n/7ojG0k@?oY/7]0onU`>d7ojK2k@?oZ<;/1?nV`Nd8ojO2k@GoYl7]1_nW`^d8ojNoj`GoZ;o[2?nW
_n/5ojO1k0;oZ<?]2?nY`nd6ojS1j`KoYl3/0_nXa>d6ojg;l003ojk=l?n/ango[<O]00?o[<O]1_nU
^>H7oi^Yh0KoTioL1On>V]/2oiBTh0GoX[SX0on`c^l6okWMlP06okOIlOncd_3o/m;`ok?Bl?l0003o
/m;`1_n[aNd=ojO0j`04ojS1k?ooooooooooo`0000Kooooo000Vooooo`03o`000?oooooooooo02ko
oooo0oo3amd7olG6f`03olG8g?o4a]coa<KL00Goa<KL00?o]<CVok;2i_nb`^H01Onb`^H3oi^lk`?o
Vkc`1_nJ_O06ojBok@OoY[o/3OnT_nd7ojO1k0OoZL3Z1OnW_n/2ojRojPKoY[o[1OnU`>d2ojJok0Ko
YL3]1OnV`^d9ojK1k@?oYl;]0onW`N`7ojO1k@;oYl;]3?nW_n/00onX_n_oYko[ojNoj`0:ojNoj`03
ojO1k?nX`ngoZ<?]00CoZ<?]1OnY`nd2ojS2k0OoZ<7[0onW`>`4oj[8k`Go[L_`00?o[Lc`ojc7kOn/
and01On/and6ojFhiP?oVjWP0onDWMT6oi6KfPGoUZKP2?nR^>P00on`c^oo^MgbokWMlP04okWMlP03
okKJl_ncd_3o/m;`00;o/m;`00?o0000ok?Bl?ncd_000_n[aNd=ojO0j`GoZ<7/00?oooooo`000?oo
ool01Oooool002Oooooo00?o0000ooooooooool0;_ooool00oo3amgoaLKKolG6f`05olG6f`;oa/GI
1_o4a]`2ol?4f`Ko//;V0_nb`ND6oi^ll0KoV[g`0onT_nd3oj?0kPOoY[o/3OnT_nd3ojO1k0CoY/7/
1onY`>X00onW_n_oZ;oZojRojP04ojRojPKoY[o[00?oYL3]ojJok?nV_n`01?nV_n`6ojG0k@03ojK2
kOnV`NgoY/7]00WoY/7]0_nW`>`6ojO1k0GoYl7]3?nW_n/3ojNnjP_oYko[2_nX`nd00onY`ngoZ<;/
ojS2k004ojS2k0GoZ<7[00?oZ<?^oj[8konZb>l01_nZb>l00on]bo3o[Lc`ojg<l003ojg<l0Oo[<O]
0onU^>H2oi^Ug@OoU9gI1_nAVmX5oiJVh0KoX[SX0_n`d?44okWMlPCo]][b1?ncd_000ol0003oZlG]
ojO0j`0>ojO0j`KoZ<7/00?o0000ooooooooool01?ooool002Sooooo0_l0000_ooooo`KoaLKK1?o6
aMT3olC6g0Go`lCK0onb`^H5ok;1i@KoVkc`0onJ_O03oiZml@KoXl3^1OnV_n`2ojO0k0_oY;o]0_nT
`>d7ojK1k0GoZL3Z0_nY`N/7ojRojP?oY[o[0onW_nX7ojJok0?oYL3]1?nV_n/7ojK1k@KoYl3/1_nW
`N`00onW`NgoYko[ojNoj`09ojNoj`SoYkkZ1_nW_n/>ojS3k@SoZ<;/00?oZ<7[ojS3k_nX`nh00onX
`nh6oj[8k`;o[<ga1_n]c?03ojc7k@?oXJoQ1_nKYMd6oiBMf@KoTI_J1_nFY^02oj:hj0Ko/=3a00?o
^MgbokKJl_nff_801Onff_801_ncd_3oZlG]oj_5kOn[aNgo0000oj_5k@ooYl3[0onX`N`2ooooo`03
o`000?oooooooooo00Cooooo000Zooooo`03o`000?oooooooooo02gooooo0oo5a]/7olK5f@03olC6
g?o3a=_o`lCK00Go`lCK00?o//;Vok;1iOnb`ND01Onb`ND3oi^ll0?oVkc_1_nJ_O46oj?0kP03ojJo
k?nW`>coYl3/00CoYl3/1onT_nd6ojC0k@OoY/7/00?oZL3ZojW1jonY`N/01?nY`N/5ojRojP;oZL7[
1_nW_nX5ojJok0;oYkkZ1onV_n/3ojK1k@?oYko[1onW`>`3ojO1k0?oYkkZ2?nW_n/<ojNnjP;oYko[
4_nX`nd6ojS2k003ojO1k?nX`nkoZ<?^00GoZ<?^0_nZb>l6ojc=l@?o[Lc`0onY_NP6oj6_h@KoVjGM
1OnDWMT7oi6KfP?oUZKP1?nS^nX5ok3@l@;o]mod1_nff_82ok7Al0CoZlG]00?o0000oj_5kOnW`>/0
3?nW`>/7ooooo`03o`000?oooooooooo00?ooooo000[ooooo`03o`000?oooooooooo02gooooo00?o
aLKKolK5fOo6aMT01Oo6aMT2olK5f0Ko`lCK0_o2`]X6ok;1i@?o/l3S1OnK_>l6oiZml@?oXl3^0onR
`>l7ojO0k0?oY;o]0onT_n`7ojC0k@?oY/7/1?nT`Nd7ojW1j`03ojRoj_nY`N_oZL7[00CoZL7[1_nW
_nX00onV_ncoYkkZojNnjP04ojNnjPGoY[o[0_nX_^X6ojNoj`GoYl3/0_nX_^X6ojNnjPGoYko[0_nX
_nX:ojNnjP?oYl?]5?nX`nd2ojS2k0GoYl7/1OnX`nh3oj_<l@Go[<ga00?o[<O^ojVmj?nY_NP01OnY
_NP5oj6_h@OoVjGM1OnDWMT3oi6KfP?oVZ[R2?nS^nX00on`d?7o]modokOOm004okOOm0;o]][b1_na
dO03oj_5k@03o`000?nW_n_oYl3[00WoYl3[2_ooool00ol0003oooooooooo`03ooooo`00;?ooool0
0ol0003oooooooooo`0^ooooo`Goa/GI1?o6aMP3ol?4f`Go`/;J0onb`ND6ok?0h`GoVkc_0onJ_O43
oiVnl@KoX/3_1onW`>`6ojBok0OoY<3]1onT`Nd5ojW1j`;oY/7]1onY`N/3ojNojP?oZL3Z1onW_^X0
0onV_n_oZ;kZojRnjP04ojRnjPKoYko[00?oYl3/ojRnj_nX_^X01?nX_^X6ojNnjP03ojNojonX_n[o
Z;oZ00CoZ;oZ1OnW_^X8ojO3kA7oZ<?]1?nW`>/6ojO1k003ojS3k_n[c?7oZlca00GoZlca00?o[<ga
ojc7k_n/anh00on/anh7ojVmj0GoXJoQ0onKYMd3oiFKe`GoU9gJ1onJZ^86oj>kjP;o/MKc1Onggo@2
okCHl`Ko/M7`00?oZL?/ojNojonW_n/00_nW_n/00ol0003oYko[ojO0j`05ojO0j`gooooo00?o0000
ooooooooool00oooool002gooooo0_l0000_ooooo`?oa/GI1_o6aMP00oo3a=_o`/;Jol;2fP05ol;2
fP03ok;1iOnc`>?o/l3S00Ko/l3S0_nK_>l4oifmk`GoVKka1_nR`>l7ojO0k0KoY;o/1onT`>d7ojC1
k@03ojW1jonV`NgoY/7]00CoY/7]1OnY`N/00onW`^coZL3ZojW0jP05ojW0jPGoYkkZ00?oZL3[ojRn
j_nX_^X01_nX_^X3ojNoj`;oZ;oZ2?nX_^X3ojNnjPCoZ<3[1_nX_nX00onW_^[oYl?]ojO3k@0:ojO3
k@coZ<?]00?oZ<7[ojO0jonW`>/01_nW`>/3ojO1k0?oZL[a1_n[c?400on/c?7o[<O^ojc7kP05ojc7
kP?oZKgX0onNYm`5oiZPf0OoUI_G1OnDWMX7oiZZhP;oXk_Z1_nae_<00onggoCo]=ScokCHl`04okCH
l`;o/M7`1OnY`n`4ojNoj`04o`000?nW_n_oYl3[ojO0ja3ooooo00?o0000ooooooooool00oooool0
02oooooo00?o0000ooooooooool0;Oooool00oo6aMWoa/GHolK5f004olK5f0;oa/CH1_o2`]X3ol;1
f0Ko/l3S0_nf_^06oifmk`GoVKka0onR`>l4oio0l0KoYl3/0onT_n`4ojFok0KoY<3]0onT`Nd4ojC0
kPOoY/7]00?oZL7[ojO2k?nW`^`00onW`^`7ojW0jP03ojNnj_nY`>_oZL3[00?oZL3[1_nX_^X00onX
`N_oZ;oZojRojP04ojRojPKoZ;kZ00?oZ<7/ojS0jonX`>/01_nX`>/3ojRojQ3oYl?]2?nX`nd5ojS1
j`KoYl3[00?oYlO`ojW:lOnYb_401OnYb_42oj_<l@Go[<ca1On/anh00onS[]ooWZOLoijWg005oijW
g0GoVZ3H1_nEVmL6oiBMfPGoVZ[R00?oY/7]ok7Flonae_<01Onae_<2okKOm0Go]=Sc00?o[lk`ojW3
k?nY`n`01_nY`n`3ojNoj`03o`000?oooooooooo017ooooo00?o0000ooooooooool00oooool0033o
oooo00?o0000ooooooooool0;Oooool5olK5f0Coa/CH0oo2`]X6ol;1f0?o/l3S1Onf_^06oifmk`;o
VKka1?nI__87oio0l0;oYl3/1?nV`^d6ojFok0?oY<3]0onT_nd7ojC0kP?oY/7]0onT`Nh7ojO2k0?o
ZL3Z1?nX`^`6ojW0j`;oZ;kZ1OnX`N/6ojRojP;oZ;kZ1OnX`N`6ojS0j`03ojO3k_nW`ngoYl?]00[o
Yl?]00?oYl?^ojO3kOnW`nd01OnW`nd3ojS3k@CoZ<7/1_nX`N/2ojO0j`GoYlO`1OnYb_43oj[=lPKo
[<ca00?o[<O^oj>^gonS[]l00onS[]l6oijWg0KoVZ3H1OnEVmL7oiBMfP03oiZZh_nV`NgoY/7]00?o
Y/7]1?nae_<5okKOm003okCHlon_c_3o[lk`00?o[lk`1_nY`n`5ooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool00oooool0037ooooo00?o0000ooooooooool0;Oooool3olK5f0Koa/CH
00?o`/;Jol;1f?o2`MP01_o2`MP00onc`>?o][kPokJnh005okJnh0?oWKg_1?nQ^n/5oiVnlPGoWl3`
0_nL`?46ojK2k@CoYKo/0_nW`>`6ojBok@GoY<3^0_nT`Nd6ojC1kPGoYl;/0_nU`^h7ojS2k0?oZL3[
0onW`^d7ojS1j`?oZ;oZ0onW`^d7ojS1k0;oZ<3[1OnW`nh8ojO3k@GoYl?^1OnW`nd2ojO1k0OoZ<7/
0onX`N/4ojO5k`KoYlO`00?oZL[aoj[=l_nZcO801OnZcO83ojc<l@?oZ;SU1_nS[]l5oijWg0KoVZ3H
1_nEVmL3oiBMfP?oWk;U1onV`Nd00onae_?o]]odokKOm004okKOm0;o/]Oc1_n_c_02ojW3k0Wooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`03ooooo`00<_ooool2o`0002kooooo00?o
a/GHolK4f?o6a=P01?o6a=P3olG3f0Ko`/7H0_o2_mL6okJnh0;o^KgM1onQ^n/5oiVnlP03oio0l?nL
`?7oW<3a00CoW<3a1_nV`^d00onU_ncoYl3/ojO0k003ojO0k0KoY;o]00?oY<3^ojC1kOnT`Nd01?nT
`Nd6ojC1kP03ojO2k?nU`^koYL;^00CoYL;^1OnX`^`2ojG2kPKoYl;]1OnX`N/2ojK2kPKoYl;]1OnX
`N`2ojK3kPOoYl?^0onW`nd:ojO3kP03ojO3kOnW`NcoYl7/00CoYl7/1OnX`N`2ojO3kPOoYlG_0onW
ao04ojW=lPGoZ/gb00?oZ/7ZojRhiOnX^>D01OnX^>D5oj>^g`KoWZOL1_nJX=P3oiFKe`?oUj?M1_nO
/^D5ojK1k@?o/]cf0_nfgo@6ok;Gl`?o[lk`3_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00;ooooo000dooooo`03o`000?oooooooooo02cooooo1Oo6a=P5olG3f0?o`/7H1Oo2_mL3
okJnh0Go^KgM1OnQ^n/2ojNji`KoVKkb1_nL`?43ojK2k@;oXl?`1onW`>`3ojBok@CoYKo/1_nT`Nd7
ojC1kPKoYL;^00?oZ<;/ojG2k_nU`^h01?nU`^h6ojO2k@03ojS1jonV`^koY/;^00CoY/;^1_nW`^d0
0onX`NcoY/?^ojK3kP04ojK3kPGoYl?^0_nV`nh:ojO3kP[oYl7/00?oZ<7/ojO3k_nW`nh01?nW`nh5
ojO5k`03ojS<lonYcO;oZLgb00KoZLgb00?oZ/gboj[1j_nZ`NX00onZ`NX7ojRhi@GoXjkO0onNYm`2
oiVLe@KoUicG1onGXmd6oinbi@03ojK1kOnbg?Ko/]cf00?o/]cf0oncgOD5ok;Gla;ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`02ooooo`00=Oooool00ol0003oooooooooo`0/oooo
o`?oa/CH1oo5`mP00oo2`MSo`[oGol:oe`05ol:oe`03okJnh?ni_Mgo^KgM00Go^KgM00?oXK_[ojNj
ionW^^L01?nW^^L6oiVnlP?oW<3a0onJ`O<5oj?3l0GoYl3/0_nW`nd7ojFok0?oY<7]0onU_n`7ojC1
kP?oYL;^0onU`Nh7ojG2kP?oYl;]1?nU`^h6ojK2kP?oYl;]2_nV`nh00onW`nkoY/?^ojK3kP04ojK3
kPGoYl?^3OnW`N`00onW`ngoYl?^ojO3kP06ojO3kP03ojO5konXc??oZ<cc00?oZ<cc1_nYcO800onZ
ankoZ/7Zoj[1jP04oj[1jPKoZ;SU00?oX:CHoifPe_nMX=H00onMX=H6oiVLe@KoUicG1onGXmd3oinb
i@?oZLgb0onbg?H6ok?Mm@03ok;Glooooooooooo01Cooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`02ooooo`00=_ooool00ol0003oooooooooo`0/ooooo`03olK4f?o5`mSoaL?H00Go
aL?H0_o4`]T6ol:oe`;o`kgE1_ni_Md2ok^kf@OoYk[W0onI__83oi^ml0KoV/7c1OnS`o000onW`>co
Yl?]ojO3k@04ojO3k@GoYKo/0_nW`N`6ojFok0GoY<7^0_nU`>`6ojG1kPkoYL;^0onV`^h3ojG2kP[o
Y/?^1?nV`^h6ojK3kP03ojO3k_nW`NcoYl7/00_oYl7/1OnW`nd6ojO3kP;oYl_c1_nXc?<2ojW=lPGo
Z/O^1_nZ`NX2ojRhi@GoX:CH1OnMX=H6oiVLe@GoUicG1_nGXmd00onS^n[oZLgbojW=lP05ojW=lP03
ok;Lm_ncgOGo/mge00Co/mge6Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;o
oooo000gooooo`;o0000;_ooool5olG3f0Coa<;I0oo2_mL5ol>me@?o^KgM1Onk^mT5ojNji`;o[k[Q
1_nK_O06oi[1l`;oXl?`1?nN`_86ojO3k@03ojFok?nW`NcoYl7/00CoYl7/1_nU_n`00onT`NkoYL3/
ojG0k004ojG0k0KoYL7^3?nU`^h2ojG1k@KoYL;^1OnV`nh2ojK1k@OoY/;^0onV`nh2ojO0k0_oYl7/
2OnW`nd2ojO3kPKoYl_c0onXc?<4ojW9l@KoZ/O^0onZ`NX2oj>Yf`OoX:CH1OnMX=H6oiVLe@KoUicG
0_nGXmd5oj>kjPGoZLgb0onah?L2ok?MmAgooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`02ooooo`00>Oooool00ol0003oooooooooo`0/ooooo`?oaL?H1_o4`]T00oo2_mOo`kgEol>m
e@05ol>me@03okVmgOnk^mWo^k_I00Go^k_I00?oYk[WojnjhOn_^^401?n_^^46oi^ml0?oV/7c1?nI
`?<5oik2lP?oYl?]0onSa?47ojO1k0?oYKo/1?nW`>`6ojG0k0?oYL7^1?nU`>`7ojG2kPKoYL7]1_nU
`^h00onV`nkoY/7]ojK1k@04ojK1k@GoY/;^1onW`>`6ojO1k003ojO3k_nW`ngoYl?]00SoYl?]1?nV
bo<5ojO;l`;oZ<_b1onYbO43oj[7kP;oYJgM1_nSZM/6oj2Tf0KoWJ3F1_nIW=D3oiNLe`;oWk3T2?nS
^nX00onYcO;o/N3gok7Pm`03ok7Pmb3ooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`02ooooo`00>_ooool00ol0003oooooooooo`0/ooooo`03olG3f?o4`]Woa<;I00Coa<;I0_o1`]X6
ol>me@;o`kgD1_nk^mT2okfiePOo[k[Q0onK_O04oj6ijPKoVL3c0_nN`_83oi[3m0KoXlCa1OnW`N`2
ojG5l0OoYl3/0onU`>`3ojO0k0OoYL3/0onU`^h3ojJok0OoYL7]0onU`^h3ojK0k0OoY/7]00?oY/;^
ojO0k?nW`>`02OnW`>`2ojO1k0GoYl?^1OnW`nd9ojK;l`03ojO;lonXbo;oZ<_b00CoZ<_b1OnYbO40
0onW/MooYJgMojF]g@04ojF]g@KoXjWK1_nPY=P3oifPeP;oVikF1_nJY=`6oin`i0KoXk_Z0on]f_L0
0onah?Ooooooooooo`0Rooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00_ooool0
03_ooooo00?o0000ooooooooool0;Oooool3olC2f@Go`L;J0oo3_MD5ol>me0?o^k_I1Onm^MH5ojnj
h@;o][WK1onQ^NX3oiW0l`?oVkk`1OnJ`o@6oj?4l@03ojO1k?nUaO3oYLG`00CoYLG`1OnW`>`2ojK5
k`KoYl3/1OnU`>`2ojO1k0KoY[o/1OnU`Nd00onW`>coY/3/ojK0k005ojK0k0?oY/7]0onW`N`:ojO0
k0CoYlG_1_nW`nh00onW`ngoY/_cojK;l`08ojK;l`?oYl_c1onXbo800onYbO7oYk7OojNag`03ojNa
g`GoYJgM1onSZM/3oj2Tf0;oW9cC1_nKW]H6oiZTg0KoWk3T0_nS^nX5ojgJmbOooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`01ooooo`00??ooool00ol0003oooooooooo`0]ooooo`03
olC2fOo1`][o`L;J00Go`L;J00?o`kgEol>me?o3_M@01Oo3_M@00onk^mWo_KWFokfieP05okfieP03
ojnjhOnf^M_o][WK00Co][WK1OnQ^NX2oj^ghPKoVkk`1OnJ`o@3oj?4l@CoW<Cc1_nUaO000onW`>co
Y/G_ojK5k`04ojK5k`KoYl3/00?oYL3/ojO1k?nW`N`01?nW`N`6ojJok003ojG1kOnW`>coYl3/00?o
Yl3/1OnV`>`2ojO3kPKoYl7/1OnW`>`2ojK6l0OoYlG_0onW`nh4ojG;l`KoY/_c1onWbo<3ojS;lP?o
Z;CQ1_nW/Ml6ojF]g@?oXjWK0onOWM<6oibLd`KoVikF1_nJY=`3oin`i0GoY/_c00?o[M[goooooooo
ool0:Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo007ooooo000mooooo`;o0000
;_ooool6ol72fP03okk2gOo3_MCo`kgD00Ko`kgD1onm^MH00ono^=?o][WKokJif`06okJif`03oj6i
j_n[]n;oZkOR00CoZkOR1_nK__02oi[3m0CoV/7c1_nLa?<3ojG5l0CoW/Gc1_nVaNl3ojO0k0CoY/K`
1_nW`N`3ojJok0?oYl?^1_nW`>`00onV`>coYl?^ojO3kP04ojO3kPKoYl7/00?oYl3/ojK6l?nVa_00
1?nVa_05ojO5k`?oY<_d1_nUbo<6ojK;l`GoYl_c0_nX]^<6ojRdh@KoYk7O0onU[Md2oj6Od`OoWigC
1OnLW=<6oi^NePGoVZCL00?oY;k/ojK;lonVbo<01OnVbo<]ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool00Oooool003oooooo00?o0000ooooooooool0;?ooool3ol72fPCo_/;M2?o3
_M@5okfieP?o_kSC1_nf^M/2okVfePOoZkOR0onK__03oj:gi`KoV/7c0onLa?<4oi_3m0KoW/Gc0onV
aNl3oio6l`OoY/K`0onW`N`2ojG7l@OoYl?^0onW`>`4ojK7l@KoYl?^0onW`N`4ojG9lPKoY/K`00?o
YlG_ojC;m?nTbo@01OnTbo@3ojG;l`?oYL[c1_nVbo<00onWbo?oZ;KSojRfh`04ojRfh`KoZ;CQ0onW
/Ml2oj>Re0KoXIoC1_nOWM<5oibLd`OoVikF00?oVZCLojBnk?nT_^`00onT_^`4ojK;lc3ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`01ooooo`00@?ooool00ol0003oooooooooo`0/
ooooo`03ol72f_nn`]go_/;M00Co_/;M2?o3_M@3okfiePGo_kSC0onf^M/5okVfePGoZkOR0_nd]]X6
oj:gi`?oV/7c1?nN^^`6oi_3m0?oW/Gc0onLaO@6oio6l`GoY/K`00?oW/OdojG7lOnUao401?nUao45
ojO3kP;oX/Sc1onVao43ojO3kPCoXlWd1_nUbO83ojK6l0?oXl_d1_nTbo@00onTb?;oYL[cojG:l`05
ojG:l`?oY/_c2_nX]^<3ojRdh@;oY:?D1_nSX]@6oj6Od`GoWigC1_nLW=<3oi^NePCoX[CV1_nT_^`0
0onVbo?oooooooooo`0aooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00Oooool0
047ooooo00?o0000ooooooooool0;?ooool7okk2g@So`kgD00?o_KWFoknhdono^=<01Ono^=<00onf
^M_o^KKFokVfeP05okVfeP03oj^gh_nd]][o];KJ00Co];KJ1?nR]nL2ojfdg@OoW[[/0onK`o@3oifm
k`KoW<Gd1_nOa_<00onVa_3oW/Odoik7m003oik7m0KoYLOa00?oYl?^oj;8lonRb?<01?nRb?<5ojK7
l@;oX<We1onSbO@3ojG9lP?oX/[e1_nSbo@2ojC;m0GoY<Sb1OnUb_<2ojRdhP_oZ;KS00?oYJCDojBS
e?nTXm@01?nTXm@6oj>Re0GoXIoC1_nOWM<3oibLd`?oWjcP1onR]>H3ojBnk3Kooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`01ooooo`00@_ooool2o`0002gooooo1Onn`]d2okW3hPKo
`kgD0_o2_mL6oknhd`;o`KWB1_ni]]H00onl]=;o];KJokBffP06okBffP03oj:gion]]=go[KCM00?o
[KCM1OnN^^`2ojVch0KoWKg_1_nLaO@3oio6l`CoW<Ke1OnNao@3ojG7l@CoW/Se1_nRb?<00onVao7o
X<Weoj39m@04oj39m@GoXlWd0_nQbO@6oj;:m@?oXl_d1?nTaO46ojC8lP03ojG:lonX]>;oZ;CR00Co
Z;CR1onX]^<5ojFTe0GoY:?D1_nSX]@6oj6Od`?oWigC0onOY]/6oin/h0GoX[CV>oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo007ooooo0014ooooo`03o`000?oooooooooo02_ooooo
00?o_/;MokW3h_ni`n801?ni`n83ol>me0Go`[oG0ono^=<5ol6idP?o^KKF1?nl]=86okBffP03okRb
don]]=go[KCM00Go[KCM00?oW[[/ojVch?nY/n001?nY/n06oifmk`?oW<Gd1?nN_Nl6oic6m@;oW/Od
1?nMaO@6oik8m@?oX/Sc1?nOb?D6oj39m@03oj?9m?nQbOCoXLWd00CoXLWd0onRb_D4ojBok0KoY<Ga
0onTb?83ojNag`OoZ;CR0onX]^<2ojJUe0KoYJCD1OnTXm@7oj>Re0?oXIoC0_nPXmL7oinVf`KoWjcP
00?oX[CVooooooooool0?Oooool00ol0003oooooooooo`07ooooo`7o00000Oooool1ooooo`00AOoo
ool00ol0003oooooooooo`0[ooooo`Oo^L?R00?o`kgDol:oeoo2_mL01Oo2_mL00ono^=?o`KWBol6i
dP05ol6idP03okVfe_nl]=;o_;CB00Co_;CB0ond]]X4okRbd`Go[KCM0_ne/MD7ojVch0?oWKg_1?nW
/^46oijmk`?oW<Ke0onP_>d6oig5m0?oW/Se1?nO`o86oio8m@?oX<We0onQa?85oj79m0;oYKOV1onT
_n`3ojC5l@?oZ:kL1_nW/Ml5ojRdhP03ojNTdonVYMCoYZGD00CoYZGD1OnUY=@6ojBSe0?oXj;D0onQ
XM@6oj2Se`OoWjKK0onO[>13ooooo`03o`000?oooooooooo00Kooooo0Ol00001ooooo`7ooooo0016
ooooo`03o`000?oooooooooo02_ooooo1Oni`n82ok75j0Ko`[oG00?o_L7Mol6id_o1^M801Oo1^M80
0oo1_MKo_;CBokbddP06okbddP03okBff_nh/]?o^;;C00Co^;;C00?o[KCMokFaeOne/MD01?ne/MD5
ojVch003ok>`e_nW/^7oYk;Q00KoYk;Q0onN_Nl2ojNag`OoX;c]0onMaO@4oj>hi`KoWl?b0onOb?D3
oj>kjPKoXLCb00?oXLWdojFgi_nU]nH01?nU]nH5ojBok003ojV/fOnX[]coZ:kL00GoZ:kL1_nW/Ml0
0onX]>;oYjCCojNTd`03ojNTd`GoYZGD1_nUY=@3ojBSe0;oXj3B1onQXM@5oj2Se`KoWjKKAoooool0
0ol0003oooooooooo`06ooooo`7o00000Oooool1ooooo`00Aoooool2o`0002cooooo00?o^L?Rok75
j?naaNP01?naaNP3ol:oe`Co_L7M1Oo1^M83ol6mePKo_;CB00?o_kKAokRbdonh/]<01Onh/]<8okFa
e@03ojVch?nc/=Ko/k3F00?o/k3F1_nW/^400ona[mGoYk7OojNag`04ojNag`GoX;c]0_nY[m`7oj>h
i`?oWl?b0_nV/N07oj>kjP?oXLCb0onW/=h7ojFgiP03ojBok?nY[=WoZJcI00?oZJcI1onX[]`3ojNa
g`;oZ:CB1_nWY=<6ojJUe0?oYJCD0_nTX=46oj>PdPKoXJ7D1_nPXmL2oinVfd_ooooo00?o0000oooo
ooooool01Oooool1o`00007ooooo0Oooool004Wooooo00?o0000ooooooooool0:_ooool7ok75j003
ol:oeonm`Mgo_L7M00Co_L7M0oo1^M85ol6meP?o_;CB1?no]]45okRbd`;o_;;@1_ne/MD00oni/=3o
/k3Fok>`eP05ok>`eP?oYk;Q1?na[mD6ojNag`03oj2lkOnY[mcoZJoL00CoZJoL1OnS^>L00on][MSo
Y[7PojJah004ojJah0GoXk_Z00?oZjcHojN`g_nW/=h01OnW/=h5ojFgiP03oj^YeOnY[=WoZJcI00Go
ZJcI1OnX[]`00onYXm7oZ:CBojRTdP04ojRTdPGoYjCC1OnVYM@00onVXM7oY:3AojBPd@04ojBPd@Ko
Xj3B1_nQXM@3oj2See3ooooo00?o0000ooooooooool01?ooool1o`00007ooooo0Oooool004[ooooo
00?o0000ooooooooool0:_ooool5ok75j0;oYlSa1onm`Md00oo1^M;o`KgFol6meP05ol6meP03okbd
d_no]]7o_kKA00Co_kKA0onh/]<4okbbd0?o]K7E1?ni/=07ok>`eP03ojNbhOna[mGo/JoE00?o/JoE
1OnW/Ml2ok6/e0OoZJoL00?oXkSWojf]f?n][MP00on][MP6ojJah003oj>kj_n[[=SoZjcH00?oZjcH
1onW/=h00onU]nKoZjWEoj^Ye@03oj^Ye@OoZJcI00?oZ:kLojVSdOnYXm400onYXm45ojRTdPKoYjCC
00?oYZGDojJQdOnVXM400onVXM46ojBPd@KoXj3B0onQXMAFooooo`03o`000?oooooooooo00?ooooo
0Ol00001ooooo`7ooooo001;ooooo`03o`000?oooooooooo02[ooooo00?o/LGXojO8lOnWb?401?nW
b?45okg1g@;o]LCU1_o1_MH00onm`Mgo_kKAoknfd@06oknfd@03okRbdonl/]3o_;;@00Co_;;@00?o
]K7EokV`d?ni/=001?ni/=05ok>`eP;o]jg@1_na[mD00onW/Moo/JcDok6/e004ok6/e0GoZJoL00?o
/:[Aojf]f?n][MP01On][MP4ojJah003ojjYd_n[[=SoZjcH00GoZjcH1OnW/=h00on/Y]7oZjWEoj^Y
e@05oj^Ye@GoZJcI00?oZj??ojVSdOnYXm401?nYXm46ojRTdP?oYjCC0_nXX]47ojJQd@GoY:3A1OnS
X=9Jooooo`03o`000?oooooooooo00?ooooo0Ol00001ooooo`7ooooo001<ooooo`;o0000;?ooool6
ojO8l@03okg1gOnea>Go]LCU00Co]LCU0oo1_MH4okg1g@Ko_kKA00?o_kgGokbbd?nl/]001?nl/]00
0onn^MCo^K3@okV`d006okV`d003ok>`e_ng[M3o]jg@00Co]jg@1?na[mD00one[<oo/JcDok6/e006
ok6/e003ojV_g?n`Z]7o/:[A00?o/:[A1on][MP00onV/N3o[ZWBojjYdP02ojjYdPOoZjcH00?oYk3N
ojbVdOn/Y]400on/Y]47oj^Ye@03ojV/fOn[XlooZj??00?oZj??1OnYXm45ojRTdP03ojVTd_nXX]7o
Z:;A00CoZ:;A1_nVXM46ojBPd@03oj>Pd_oooooooooo05cooooo00?o0000ooooooooool00oooool1
o`00007ooooo001>ooooo`03o`000?oooooooooo02[ooooo0onWb?44oiK7n0Ko]LCU00?o`KgFokg1
gOnm`Md01?nm`Md3oknfd@Co_kgG0onl/]04okjie0Ko^K3@00?o_;GBokN]d?ng[M001_ng[M000ona
[mGo]Jc?okF/c`02okF/c`Ko/JcD00?o]J_?ok2ZdOn`Z]401On`Z]45ojf]f003ok2Wcon^ZM;o[ZWB
00Co[ZWB1On[[=P00on^YLoo[:KAojbVd@05ojbVd@GoZjWE00?o[JC?oj^Scon[Xll01?n[Xll6ojVS
d@03ojRTd_nYY=;oZJCB00?oZJCB1_nXX]46ojJQd@?oY:3AH_ooool00ol0003oooooooooo`02oooo
o`7o00000Oooool004oooooo00?o0000ooooooooool0:oooool6oiK7n0?o]LCU0onZbo47okg1g@03
oknfdOno_MOo_kgG00Co_kgG00?o_;;@okjie?nn^M@01?nn^M@3okV`d0Co_;GB1_ng[M000onk/m;o
]Jc?okF/c`04okF/c`?o/JcD1?neZll7ok2Zd@03ojf]f?n`Yloo/:O?00?o/:O?1_n^ZM800on[[=So
[ZG?ojjUc`03ojjUc`Oo[:KA00?oZjWEojfTcon]Y<l00on]Y<l5oj^Sc`GoZJ?A00?oZjOCojVTd_nY
Y=801OnYY=85ojRRd@GoYZ7AIoooool01Ol0003ooooooooooooooooo0000007ooooo001@ooooo`03
o`000?oooooooooo02_ooooo0onFaoP3ogo2o@KoZ/_a1Onm`Md2ok;6j0Go_kgG00?o^<;Rokjie?nn
^M@01_nn^M@00oni/=3o_;GBokbedP04okbedP?o]jg@1?nk/m86okF/c`03ok6/e?neZloo]J_?00Co
]J_?1On`Z]400one[<oo/:O?ok2Wc`04ok2Wc`Go[ZWB00?o/JS?ojjUcon^YLl01On^YLl5ojbVd@03
ojnWd?n]Y<oo[JC?00Co[JC?1_n[Xll00onYXm7oZjOCoj^Wd`03oj^Wd`KoZJCB1_nXX]400onVXM7o
ooooooooo`1Xooooo`05o`000?ooooooooooooooool000000Oooool0057ooooo0_l0000]ooooo`Go
Ol;m1_nZbo400onm`Mgo//KXok;6j004ok;6j0?o_kgG0onh`^86okjie003ok[0gonl]M;o_;GB00Ko
_;GB00?o]jg@ok^cd_nk/m800onk/m85okF/c`03okZcdoneZloo]J_?00Go]J_?0on`Z]44okF/c`Ko
/:O?00?o[ZWBok6XconaZ<l00onaZ<l7ojjUc`03ojbVdOn_Ym3o[jO@00?o[jO@1On]Y<l5oj^Sc`03
ojf/e_n[Ym?oZjOC00GoZjOC1_nYY=83ojRRdFkooooo00Co0000oooooooooooo00000Oooool005?o
oooo00?o0000ooooooooool0:oooool5ogo2o@?oZ/_a1?nCb_X6ok;6j003oknmeonh`^;o^<;R00?o
^<;R0onn^M@4ok[0g`Ko_;GB00?o^[oNok^cd_nk/m801?nk/m83okF/c`Co^[?C1oneZll00on`Z]7o
]Jc?okF/c`03okF/c`Go/:O?00?o]JoCok6XconaZ<l01OnaZ<l5ojjUc`03ok:^e?n_Ym3o[jO@00Co
[jO@1_n]Y<l00on[Xloo[JcFojf/eP03ojf/ePKoZjOC1OnYY=9cooooo`03o`000?oooooo0000007o
oooo001Dooooo`03o`000?oooooooooo02cooooo1_mh_O`5oi?:nP?o//KX0onRcOH6okS2hP03okji
e?nj`=oo^/3O00Co^/3O0onl]M84okZogPKo^k?B00?o]Jc?okZcdonj/m<01?nj/m<5okF[c`03okVf
e_ne[<oo]Jc?00Go]Jc?00?o/:O?okF_done[m<00one[m<7ok6Xc`03ojjUconb[]Co/ZkD00?o/ZkD
1On_Ym05ojfTc`03ojnbf_n][=Ko[JcF00Go[JcF1_n[Ym<00onYY=;oooooooooo`1dooooo`03o`00
0?oooooo0000007ooooo001Eooooo`03o`000?oooooooooo02cooooo0omh_O`4oh6nn`GoO<?m1OnR
cOH3okS2hP?oZ/gb1onj`=l00onl]M;o^[oNokZogP04okZogPCo^k?B0_nh_]h7okZcd`03okF[coni
]]Ko^KKF00?o^KKF1One[<l00ong^]co]JoCokF_d`05okF_d`Go/JS?00?o];OKok:^e?nb[]@01?nb
[]@6ojnWd003ojfTcon_/][o[k;J00?o[k;J1on][=H3oj^Wdg[ooooo0Ol00001ooooo`7o0000001F
ooooo`;o0000;_ooool6oh6nn`GoO<?m0_nRcOH4ohG9oPGoZ/gb1Onj`=l2ojg;l0Oo^[oN00?o^k?B
okRng_nh_]h00onh_]h5okZcd`03okG0h_ni]]Ko^KKF00Co^KKF0one[<l4okNjg0Oo]JoC00?o/JS?
okBgfond]m/00ond]m/6ok:^e0?o[jO@0on`^N06ojnbfPGo[JcFOoooool2o`000000F?ooool00ol0
003oooooooooo`0/ooooo`?oPKkk1?n>__L5ogboo0GoQLWn1OnZcO800onj`=oo[L_`ojg;l004ojg;
l0Go^[oN00?o[Lc`okRng_nh_]h01Onh_]h00onj/m?o]L3RokG0hP03okG0hPKo^KKF00?o]Jc?okNj
g?ng^]`01?ng^]`5okF_d`03ok6oiOnd]m_o];OK00Co];OK1Onb[]@00on^`NSo/;WPok2ih005ok2i
h0Ko[k;J00?o[JcFooooooooool0Ooooool3o`000000FOooool00ol0003oooooooooo`0]ooooo`Ko
S[kg1Oml_o`2ohG9oPCoN/7m1On=cOd6ojg;l003okZog_n]c?3o[Lc`00?o[Lc`1Onh_]h2oj_>lPKo
]L3R1?ni]]H2ok74j0Oo]k[L00?o]JoCok6oiOna_nD00ona_nD6okBgf`03ok:^e?n^`NSo[/7X00?o
[/7X1on`^N03ojnbfX3ooooo1?l00003ooooo`00F_ooool00ol0003oooooooooo`0]ooooo`?oS[kg
1?nK__45oh[1n@GoN/7m1On=cOd3ojg;l0?oTLom1_n]c?000onh_]koZlkboj_>lP04oj_>lPKo]L3R
00?o^KKFok74j?naa>P00onaa>P5okNjg0;oZlcb1Ona_nD5okBgf`;oZLcb1_n^`NP5ok2ih87ooooo
0ol00007ooooo`00Foooool00ol0003oooooooooo`0]ooooo`OoVkka1On:`OT2og[1o@CoQl;k1_ml
a?h4oi7?o@?o[Lc`1?n?dOh6oj_>lP?o]L3R0onUd_L6ok74j003okNjg?n[c?;oZlcb00CoZlcb1Ona
_nD00ond]m_oZLcbojW<lP04ojW<lPKo[/7X00?o/;WPooooooooool0O_ooool4o`0000[ooooo001L
ooooo`;o0000;_ooool5oi^nl@;oYKo/1_nG__85ohO2n`?oO<Cn1?n7a?`5ogg6oPGoSm7n0on[c_83
ohWAo`KoYM;g0onaa>P4oi[Eo0KoZlcb0_na_nD4oikFn`KoZLcb0on^`NQoooooo`Co00003_ooool0
05kooooo00?o0000ooooooooool0;?ooool00onK__7oYKo/ojFok004ojFok0CoUkkb0_nS_nd6oiJn
l`KoQlCl0_mma_h4ohW5o0KoOlSn1?n9dOl3ojGBm`CoQ<oo1_nJeO`3oj_<lP?oR]Co1_nNe_/3ojW<
lX3ooooo1?l0000Booooo`00Goooool00ol0003oooooooooo`0]ooooo`KoYKo/00?oUkkboj>okOnS
_nd00onS_nd6oiJnl`?oQlCl0onF_o<6ohW5o0?oOlSn0on>a_X6oh;8oPGoQ<oo0onJeO`4ohC>o`Go
R]Co0onNe_^1ooooo`Co00005_ooool0063ooooo00?o0000ooooooooool0;Oooool3ojFok0CoZ<3[
1OnS_nd3oiJnl`CoXkk]1OnF_o<3ohW5o0CoV;oc1On>a_X3oh;8oPCoTlGh1_n8b_d2ohC>ohSooooo
0ol0000Jooooo`00HOooool2o`0002oooooo1_nX`>/2oj>ok@CoYl3[1_nS_^d2oiJol`CoY;o]1_nH
_o<2ohk6nPCoW;oa1_nCaOP3ohS:oHSooooo1?l0000Mooooo`00Hoooool00ol0003oooooooooo`0]
ooooo`?oZ<3[2OnW`>/3oj>nk@?oYl3[1_nT_nd3oiRol`?oYKo/1_nL_o43oi?5n8Wooooo1?l0000Q
ooooo`00I?ooool00ol0003oooooooooo`0]oooooa;oYl3[0onT_nd3ojS0j`KoYKo/0onL_o6:oooo
o`Co00009Oooool006Gooooo00?o0000ooooooooool0;OoooolBojO0j`KoZ<3[1?nU_nb:ooooo`Co
0000:Oooool006Kooooo0_l0000^ooooo`;oYl3[1?nW`N`<ojO0j`KoZ<3[00?oYKo/ooooooooool0
Qoooool3o`0002gooooo001Xooooo`03o`000?oooooooooo02cooooo1_nW`N`3ojO0j`?oYl7/1_nW
`>/3ojS0jhSooooo1?l0000`ooooo`00JOooool00ol0003oooooooooo`0/ooooo`?oYl7/1?nV`>`5
ojO1k0?oYl3[ROooool4o`0003Cooooo001Zooooo`03o`000?oooooooooo02cooooo1onV`>`2ojO1
k8[ooooo1?l0000hooooo`00Joooool2o`0002gooooo1OnV`>b9ooooo`Co0000??ooool006gooooo
00?o0000ooooooooool0:oooool00onV`>coooooooooo`27ooooo`?o0000@?ooool006kooooo00?o
0000ooooooooool0:_ooool00ol0003oooooooooo`23ooooo`Co0000@oooool006oooooo00?o0000
ooooooooool0:Oooool00ol0003oooooooooo`1oooooo`Co0000Aoooool0073ooooo0_l0000Yoooo
o`03o`000?oooooooooo07_ooooo1?l0001;ooooo`00L_ooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo07Oooooo1?l0001?ooooo`00Loooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo07Cooooo0ol0001Cooooo`00M?ooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo073ooooo1?l0001Fooooo`00MOooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo06cooooo1?l0001Jooooo`00M_ooool2o`0002?ooooo00?o0000ooooooooool0J?ooool4o`00
05kooooo001hooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0I?ooool4o`0006;o
oooo001iooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0HOooool3o`0006Kooooo
001jooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0GOooool4o`0006Wooooo001k
ooooo`;o00007_ooool00ol0003oooooooooo`1Iooooo`Co0000KOooool007gooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`1Eooooo`Co0000LOooool007kooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`1Aooooo`Co0000MOooool007oooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`1>ooooo`?o0000NOooool0083ooooo0_l0000Iooooo`03o`000?oo
oooooooo04[ooooo1?l0001looooo`00P_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo04Kooooo1?l00020ooooo`00Poooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
04;ooooo1?l00024ooooo`00Q?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo03ko
oooo1?l00028ooooo`00QOooool2o`0001?ooooo00?o0000ooooooooool0??ooool3o`0008cooooo
0027ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0>?ooool4o`0008oooooo0028
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0=?ooool4o`0009?ooooo0029oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool0<?ooool4o`0009Oooooo002:ooooo`;o
00003_ooool00ol0003oooooooooo`0/ooooo`Co0000Voooool008cooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0Yooooo`?o0000Woooool008gooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0Uooooo`Co0000X_ooool008kooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0Qooooo`Co0000Y_ooool008oooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0Mooooo`Co0000Z_ooool0093ooooo0_l00008ooooo`03o`000?oooooooooo01Wo
oooo1?l0002^ooooo`00T_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Kooooo
0ol0002booooo`00Toooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01;ooooo1?l0
002eooooo`00U?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00kooooo1?l0002i
ooooo`00UOooool2o`0000?ooooo00?o0000ooooooooool02_ooool4o`000;gooooo002Gooooo`04
o`000?ooooooooooo`0000Sooooo1?l00031ooooo`00V?ooool00ol0003oooooo`000005ooooo`?o
0000aOooool009Wooooo0_l000000ooooooo0000o`000002o`000<Sooooo002Jooooo`;o0000c?oo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.0538698, 0.0432538, \
0.0035044, 0.0035044}}]
}, Closed]],

Cell["Fig. 5.4(animation) Evolution of shallow water waves", "Caption",
  CellTags->"Fig. 5.4"],

Cell[TextData[{
  StyleBox["(18)",
    FontWeight->"Bold"],
  " A general spherically symmetric function ",
  Cell[BoxData[
      \(TraditionalForm\`z(r)\)]],
  " has a Fourier transform representation of the form"
}], "Text",
  CellTags->"i:61"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{\(z(r)\), "=", " ", 
          RowBox[{"\[Integral]", 
            RowBox[{\(\(z\&~\)(k)\), 
              SuperscriptBox["\[ExponentialE]", 
                RowBox[{"\[ImaginaryI]", " ", 
                  RowBox[{
                    StyleBox["k",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], "\[CenterDot]", 
                    StyleBox["r",
                      FontWeight->"Bold",
                      FontSlant->"Plain"]}]}]], \(\[DifferentialD]\^3 
                  k/\((2\ \[Pi])\)\^3\)}]}]}], TraditionalForm]]],
  ".\nBy comparing the result written in cylindrical coordinates ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Rho], \[Phi], \ z)\)\)]],
  " with that written in terms of the spherical radial coordinate ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  ", prove the following identity:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_0\%\[Pi]\(\( 
                  J\_o\)(\[Rho]\ sin\ \[Theta])\)\ \(\[ExponentialE]\^\(\
\[ImaginaryI]\ z\ cos\ \[Theta]\)\) sin\[Theta] \[DifferentialD]\[Theta] = 
        2 \( sin\ \@\(\[Rho]\^2 + z\^2\)\)\/\@\(\[Rho]\^2 + z\^2\)\)]],
  "."
}], "NumberedEquation",
  CellTags->"(5.1.103)"],

Cell[TextData[{
  StyleBox["(19)",
    FontWeight->"Bold"],
  "  A stationary point sound source emits waves of frequency ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_o\)]],
  ": ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"S", "(", 
            RowBox[{
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[",",
                FontWeight->"Plain"], 
              StyleBox["t",
                FontWeight->"Plain"]}], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{
            StyleBox["s",
              FontWeight->"Plain"], 
            StyleBox[" ",
              FontWeight->"Plain"], 
            RowBox[{
              StyleBox["\[Delta]",
                FontWeight->"Plain"], 
              StyleBox["(",
                FontWeight->"Plain"], 
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[")",
                FontWeight->"Plain"]}], 
            
            StyleBox[\(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \(\[Omega]\_o\) 
                    t\)\),
              FontWeight->"Plain"]}]}], TraditionalForm]]],
  " Using Eq. ",
  ButtonBox["(5.1.85)",
    ButtonData:>"(5.1.85)",
    ButtonStyle->"Hyperlink"],
  ",  show that the pressure response to this source is"
}], "Text"],

Cell[TextData[{
  "\t\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"p", "(", 
            RowBox[{
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[",",
                FontWeight->"Plain"], 
              StyleBox["t",
                FontWeight->"Plain"]}], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox["=",
            
            FontWeight->
              "Plain"], \(\(s\/\(4  \[Pi]\ \(c\^\(\(2\)\(\ \)\)\) 
                  r\)\) \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \
\(\(\[Omega]\_o\)(t - r/c)\)\)\)}], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(20)",
    FontWeight->"Bold"],
  " An explosion occurs at a height ",
  Cell[BoxData[
      \(TraditionalForm\`z = H\)]],
  " above a flat surface. The explosion can be modeled as a point pressure \
source in the three-dimensional wave equation , ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\^2 p\/\[PartialD]t\^2 = \(c\^2\) \
\[Del]\^2 p + 
          s\ \(\[Delta](x)\) \(\[Delta](y)\) \(\[Delta](z - H)\) \(h(t)\) 
            t\ \[ExponentialE]\^\(\(-\[Gamma]\)\ t\)\)]],
  ". At ground level, the boundary condition is that ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]p/\[PartialD]z = 0\)]],
  ". Using either Fourier methods or Eq. ",
  ButtonBox["(5.1.85)",
    ButtonData:>"(5.1.85)",
    ButtonStyle->"Hyperlink"],
  ", determine the evolution of the pressure ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  " in the resulting blast wave. (Hint: Show that the boundary condition can \
be met by adding an appropriate  image source below the plane. Then solve for \
the pressure from a source in free space, and add in the image to match the \
boundary condition.) For ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(H = 5\), ",", \(\[Gamma] = 3\), ",", " ", \(c = \(s = 1\)\),
           ",", Cell[""]}], TraditionalForm]]],
  "make an animation of  surface plots of the evolution of ",
  Cell[BoxData[
      \(TraditionalForm\`p(r, z, t)\)]],
  " in the ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, z)\)\)]],
  " plane for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 8\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(21)",
    FontWeight->"Bold"],
  " Fourier transforms can also be used to solve certain potential problems.  \
Solve the following problem in the domain ",
  Cell[BoxData[
      \(TraditionalForm\`z > 0\)]],
  ": ",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2\( \[Phi](x, y, z)\) = 0\)]],
  "  with boundary conditions in the ",
  Cell[BoxData[
      \(TraditionalForm\`\(\((x, y)\)\(\ \)\)\)]],
  "plane that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](x, y, 0)\  = \ V\_o\)]],
  " in a circular patch of radius ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](x, y, 0) = 0\)]],
  " otherwise. Another boundary condition is ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] \[Rule] 0\)]],
  " as ",
  Cell[BoxData[
      \(TraditionalForm\`z \[Rule] \ \[Infinity]\)]],
  ". Solve this problem by Fourier-transforming in ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(x\)\(\ \)\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " and solving the resulting ",
  Cell[BoxData[
      \(TraditionalForm\`ODE\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Phi]\&~\)(k\_x, k\_y, z)\)]],
  " with the appropriate boundary conditions. Show that  the result can be \
written as the following integral: "
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](r, z)\  = \ 
        V\_o\ a \(\[Integral]\_0\%\[Infinity]\(\( J\_o\)(\(k\_r\) 
                  r)\)\ \(\(J\_1\)(\(k\_r\) 
                  a)\) \(\[ExponentialE]\^\(\(-k\_r\) 
                    z\)\) \[DifferentialD]k\_r\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "Plot the solution for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]/V\_o\)]],
  " in the ",
  Cell[BoxData[
      \(TraditionalForm\`y = 0\)]],
  " plane as a ",
  StyleBox["Plot3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " graphics object taking ",
  Cell[BoxData[
      \(TraditionalForm\`a = 1\)]],
  ", for ",
  Cell[BoxData[
      \(TraditionalForm\`\(-3\) < x < 3, \ 0 < z < 6\)]],
  ", by numerically evaluating this integral."
}], "Text"],

Cell[TextData[{
  StyleBox["(22)",
    FontWeight->"Bold"],
  " A circular speaker sits in the ",
  Cell[BoxData[
      \(TraditionalForm\`x - y\)]],
  " plane, in air with with\tequilibrium presure ",
  Cell[BoxData[
      \(TraditionalForm\`p\_o\)]],
  ". The speaker is an elastic membrane that moves according to ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox[
              RowBox[{"\[Delta]", 
                StyleBox["z",
                  FontSlant->"Italic"]}]], "(", \(r, 0, t\), ")"}], 
          "=", \(z\_o\ sin\ \(\[Omega]\_o\) t\)}], TraditionalForm]]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`r < a\)]],
  ", and  ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox[
              RowBox[{"\[Delta]", 
                StyleBox["z",
                  FontSlant->"Italic"]}]], "(", \(r, 0, t\), ")"}], " ", "=", 
          " ", "0"}], TraditionalForm]]],
  " otherwise. The perturbed air pressure ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[Delta]", 
            StyleBox["p",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " around the speaker satisfies potential flow with fluid displacement ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["\[Eta]",
              FontWeight->"Bold"], 
            StyleBox["(",
              FontWeight->"Plain"], 
            StyleBox[\(r, z, t\),
              FontWeight->"Plain"], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox[\(\[Del]\[Phi]\),
            FontWeight->"Plain"]}], TraditionalForm]]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " satisfies Eq. ",
  ButtonBox["(4.4.39)",
    ButtonData:>{"Chapter4.nb", "(4.4.39)"},
    ButtonStyle->"Hyperlink"],
  " and the sound speed is ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  ". Also, the perturbed pressure is related to ",
  Cell[BoxData[
      FormBox[
        StyleBox["\[Eta]",
          FontWeight->"Bold"], TraditionalForm]]],
  " by Eq. ",
  ButtonBox["(4.4.40)",
    ButtonData:>{"Chapter4.nb", "(4.4.40)"},
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Using Fourier cosine transforms,  write the solution for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](r, z, t)\)]],
  " as \n\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Phi](r, z, t)\), " ", "=", " ", 
          RowBox[{\(u(r, z, t)\), " ", "+", " ", 
            RowBox[{"\[Integral]", 
              
              RowBox[{\(\[DifferentialD]\^2\( 
                          k\_ \[UpTee] \)\/\((2\ \[Pi])\)\^2\), 
                RowBox[{\(\[Integral]\_0\%\[Infinity]\), 
                  
                  RowBox[{\(\[DifferentialD]k\_z\), 
                    " ", \(A(\(k\_ \[UpTee] \), k\_z, t)\), 
                    SuperscriptBox["\[ExponentialE]", 
                      RowBox[{"\[ImaginaryI]", " ", 
                        RowBox[{
                          SubscriptBox[
                            StyleBox["k",
                              FontWeight->"Bold",
                              FontSlant->"Plain"], "\[UpTee]"], 
                          "\[CenterDot]", 
                          StyleBox["r",
                            FontWeight->"Bold",
                            FontSlant->"Plain"]}]}]], \(cos(\(k\_z\) z)\), 
                    Cell[""]}]}]}]}]}]}], TraditionalForm]]],
  ",\nwhere ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox[
            StyleBox["k",
              FontWeight->"Bold",
              FontSlant->"Plain"], "\[UpTee]"], 
          "=", \(k\_r\ \((cos\[Theta]\ x\&^\  + sin\[Theta]\ y\&^)\)\)}], 
        TraditionalForm]]],
  " is the perpendicular component of the wavenumber, and ",
  Cell[BoxData[
      \(TraditionalForm\`u\)]],
  "satisfies the boundary conditions. Solve for ",
  Cell[BoxData[
      \(TraditionalForm\`A(\(k\_ \[UpTee] \), k\_z, t)\)]],
  " to show that "
}], "Text",
  CellTags->"i:63"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FractionBox[
            RowBox[{
              StyleBox[
                RowBox[{"\[Delta]", 
                  StyleBox["p",
                    FontSlant->"Italic"]}]], "(", \(r, z, t\), 
              ")"}], \(p\_o\)], 
          "=", \(\(\(a\ z\_o\ \[Omega]\_o\^2\)\/\[Pi]\) \(\[Integral]\_0\%\
\[Infinity]\[DifferentialD]k\_r \(\( J\_o\)(\(k\_r\) r)\) \(\(J\_1\)(\(k\_r\) 
                    a)\) \(\[Integral]\_0\%\[Infinity]\[DifferentialD]k\_z \(\
\(\( \[Omega]\_o\) sin\ c\ k\ t\  - \ 
                          c\ k\ sin\ \(\[Omega]\_o\) 
                            t\)\/\(c\ k\ \((\[Omega]\_o\^2 - \(c\^2\) 
                                k\^2)\)\)\) cos\ \((k\_z\ z)\)\)\)\)}], 
        TraditionalForm]]],
  ",\t"
}], "Text"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`k = \@\(k\_r\^2 + k\_z\^2\)\)]],
  ". (Hint: to satisfy the von-Neumann boundary conditions in the ",
  Cell[BoxData[
      \(TraditionalForm\`\((x - y)\)\)]],
  " plane, put the wave equation for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " in standard form by employing a function ",
  Cell[BoxData[
      \(TraditionalForm\`u(r, z, t)\)]],
  " that matches the boundary conditions, but that also satisfies the Laplace \
equation ",
  Cell[BoxData[
      \(TraditionalForm\`\[Del]\^2 u = 0\)]],
  ".)"
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Although the integrals in the solution for ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Delta]", 
          StyleBox["\[AliasDelimiter]",
            FontSlant->"Italic"]}], TraditionalForm]]],
  " are well defined, they cannot be evaluated analytically, and are \
nontrivial to evaluate numerically. We will use the following method to \
evaluate ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[Delta]", 
            StyleBox["p",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " in the ",
  Cell[BoxData[
      \(TraditionalForm\`z = \(\(1/2\)\(\ \)\)\)]],
  "plane at ",
  Cell[BoxData[
      \(TraditionalForm\`t = 1\)]],
  ", taking ",
  Cell[BoxData[
      FormBox[
        RowBox[{"a", "=", 
          RowBox[{\(z\_o\), "=", 
            RowBox[{\(p\_o\), "=", 
              RowBox[{"c", "=", 
                RowBox[{"1", " ", "and", " ", Cell[TextData[Cell[BoxData[
                      \(TraditionalForm\`\[Omega]\_o = 10\)]]]]}]}]}]}]}], 
        TraditionalForm]]],
  ". \n First, define  a numerical function ",
  Cell[BoxData[
      \(TraditionalForm\`f(k\_r, z, 
          t) = \[Integral]\_0\%1000\[DifferentialD]k\_z \(\(\( \[Omega]\_o\) 
                    sin\ c\ k\ t\  - \ 
                  c\ k\ sin\ \(\[Omega]\_o\) 
                    t\)\/\(c\ k\ \((\[Omega]\_o\^2 - \(c\^2\) k\^2)\)\)\) 
            cos\ \((k\_z\ z)\)\)]],
  ", using ",
  StyleBox["NIntegrate",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ".\n  Next, make a table of values of ",
  Cell[BoxData[
      \(TraditionalForm\`{k\_r, f(k\_r, 1/2, 1)}\)]],
  "for ",
  Cell[BoxData[
      \(TraditionalForm\`k\_r = \ i\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`i = 0, 1, 2,  .. , 50. \)]],
  " \n  Next, create an interpolating function ",
  Cell[BoxData[
      \(TraditionalForm\`g(k\_r)\)]],
  "by interpolating this data.\n   Finally, define a numerical function ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox[
              RowBox[{"\[Delta]", 
                StyleBox["p",
                  FontSlant->"Italic"]}]], "(", "r", ")"}], "=", Cell[
          TextData[Cell[BoxData[
              \(TraditionalForm\`\(\(a\ \(z\_o\) 
                      p\_o\ \[Omega]\_o\^2\)\/\[Pi]\) \(\[Integral]\_0\%50\
\[DifferentialD]k\_r \(\( J\_o\)(\(k\_r\) r)\) \(\(J\_1\)(\(k\_r\) a)\)\ \(g(
                      k\_r)\)\)\)]]]]}], TraditionalForm]]],
  ", and plot the result for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < r < 2\)]],
  " to obtain the pressure field in the ",
  Cell[BoxData[
      \(TraditionalForm\`z = \(\(1/2\)\(\ \)\)\)]],
  "plane at ",
  Cell[BoxData[
      \(TraditionalForm\`t = 1\)]],
  ". [The solution for ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[Delta]", 
              StyleBox["p",
                FontSlant->"Italic"]}]], "(", \(r, t = 1\), ")"}], 
        TraditionalForm]]],
  " is shown in Fig. ",
  ButtonBox["5.5",
    ButtonData:>"Fig. 5.5",
    ButtonStyle->"Hyperlink"],
  " for the case of the ",
  Cell[BoxData[
      \(TraditionalForm\`z = 0\)]],
  " plane. Waves of wavelength ",
  Cell[BoxData[
      \(TraditionalForm\`2\ \[Pi]\ c/\[Omega]\_o = 0.63 ... \)]],
  " are being excited. Note the kink at the edge of the speaker, at ",
  Cell[BoxData[
      \(TraditionalForm\`r = 1\)]],
  ". Also note that the solution vanishes for ",
  Cell[BoxData[
      \(TraditionalForm\`r > 2\)]],
  ", as expected for ",
  Cell[BoxData[
      \(TraditionalForm\`t = 1\)]],
  "since  the signal has not yet propagated into this region.)"
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.47619 0.0147151 0.0637899 [
[.2619 .00222 -9 -9 ]
[.2619 .00222 9 0 ]
[.5 .00222 -3 -9 ]
[.5 .00222 3 0 ]
[.7381 .00222 -9 -9 ]
[.7381 .00222 9 0 ]
[.97619 .00222 -3 -9 ]
[.97619 .00222 3 0 ]
[1.025 .01472 0 -6 ]
[1.025 .01472 10 6 ]
[.01131 .14229 -6 -4.5 ]
[.01131 .14229 0 4.5 ]
[.01131 .26987 -6 -4.5 ]
[.01131 .26987 0 4.5 ]
[.01131 .39745 -6 -4.5 ]
[.01131 .39745 0 4.5 ]
[.01131 .52503 -6 -4.5 ]
[.01131 .52503 0 4.5 ]
[.5 .63053 -80.5 0 ]
[.5 .63053 80.5 14.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2619 .01472 m
.2619 .02097 L
s
[(0.5)] .2619 .00222 0 1 Mshowa
.5 .01472 m
.5 .02097 L
s
[(1)] .5 .00222 0 1 Mshowa
.7381 .01472 m
.7381 .02097 L
s
[(1.5)] .7381 .00222 0 1 Mshowa
.97619 .01472 m
.97619 .02097 L
s
[(2)] .97619 .00222 0 1 Mshowa
.125 Mabswid
.07143 .01472 m
.07143 .01847 L
s
.11905 .01472 m
.11905 .01847 L
s
.16667 .01472 m
.16667 .01847 L
s
.21429 .01472 m
.21429 .01847 L
s
.30952 .01472 m
.30952 .01847 L
s
.35714 .01472 m
.35714 .01847 L
s
.40476 .01472 m
.40476 .01847 L
s
.45238 .01472 m
.45238 .01847 L
s
.54762 .01472 m
.54762 .01847 L
s
.59524 .01472 m
.59524 .01847 L
s
.64286 .01472 m
.64286 .01847 L
s
.69048 .01472 m
.69048 .01847 L
s
.78571 .01472 m
.78571 .01847 L
s
.83333 .01472 m
.83333 .01847 L
s
.88095 .01472 m
.88095 .01847 L
s
.92857 .01472 m
.92857 .01847 L
s
.25 Mabswid
0 .01472 m
1 .01472 L
s
gsave
1.025 .01472 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .14229 m
.03006 .14229 L
s
[(2)] .01131 .14229 1 0 Mshowa
.02381 .26987 m
.03006 .26987 L
s
[(4)] .01131 .26987 1 0 Mshowa
.02381 .39745 m
.03006 .39745 L
s
[(6)] .01131 .39745 1 0 Mshowa
.02381 .52503 m
.03006 .52503 L
s
[(8)] .01131 .52503 1 0 Mshowa
.125 Mabswid
.02381 .04661 m
.02756 .04661 L
s
.02381 .07851 m
.02756 .07851 L
s
.02381 .1104 m
.02756 .1104 L
s
.02381 .17419 m
.02756 .17419 L
s
.02381 .20608 m
.02756 .20608 L
s
.02381 .23798 m
.02756 .23798 L
s
.02381 .30177 m
.02756 .30177 L
s
.02381 .33366 m
.02756 .33366 L
s
.02381 .36556 m
.02756 .36556 L
s
.02381 .42935 m
.02756 .42935 L
s
.02381 .46124 m
.02756 .46124 L
s
.02381 .49314 m
.02756 .49314 L
s
.02381 .55693 m
.02756 .55693 L
s
.02381 .58882 m
.02756 .58882 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -141.5 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 22.5 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 14.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 14.250 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(d) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(p) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 14.250 moveto
(@) show
81.000 14.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(r) show
87.000 14.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
93.000 14.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
99.000 14.250 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
105.000 14.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
111.000 14.250 moveto
(D) show
123.000 14.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(in) show
141.000 14.250 moveto
(the) show
165.000 14.250 moveto
(z) show
171.000 14.250 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
177.000 14.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
189.000 14.250 moveto
(plane) show
gsave
newpath
 219.000 17.500 moveto
 220.000 17.500 lineto
 220.000 5.000 lineto
 219.000 5.000 lineto
 219.000 17.500 lineto
closepath
clip newpath
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
grestore
220.000 14.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .60332 m
.04762 .59137 L
.07143 .56256 L
.09524 .51954 L
.11905 .467 L
.14286 .41686 L
.16667 .37414 L
.19048 .3483 L
.21429 .34201 L
.2381 .35435 L
.2619 .38378 L
.28571 .41953 L
.30952 .45594 L
.33333 .48177 L
.35714 .48931 L
.38095 .47752 L
.40476 .44076 L
.42857 .39041 L
.45238 .3292 L
.47619 .27212 L
.4881 .25817 L
.5 .25292 L
.50476 .25141 L
.5119 .24779 L
.51667 .24372 L
.52381 .2344 L
.54762 .1811 L
.57143 .12649 L
.59524 .08369 L
.61905 .05333 L
.64286 .04352 L
.66667 .04762 L
.69048 .06346 L
.71429 .08495 L
.7381 .1038 L
.7619 .11755 L
.78571 .12065 L
.80952 .11373 L
.83333 .09856 L
.85714 .07732 L
.88095 .05593 L
.90476 .03676 L
.92857 .02334 L
.95238 .0168 L
.97619 .01487 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Picture",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00Eoooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd0??ooool4o`000003oa0@4?oooooooooo03[ooooo1?l00000
0ol@413oooooooooo`02ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM03[ooooo1Ol0
000Zooooo`00Eoooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb
<S;ooooo03gooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`04ooooo`;o8B4Q2?oo
ool00omgMgOo<S8booooo`0iooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0:_ooool005Oooooo00Go
410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0
?_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03Wooooo00?oV9RHob4Q8Oo^k^h0
:oooool005Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo03gooooo
00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0>ooooo`03ogMgMolb<S;ooooo03_ooooo
00?oV9RHob4Q8Oo^k^h0:_ooool005Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`0?_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00_o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c00mooooo`03ogMgMomVIVKooooo02Wooooo001Gooooo`05
oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo
03kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo
02Sooooo001Gooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`10oooo
o`03o`000?oooooooooo03kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0loooo
o`05o`000?nj^[[ooooooiRHV?l@4100:_ooool005Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<
ooooo`Co0000?Oooool00omEEEGoIVIVo`00000nooooo`03oeEEEOmVIVKo000000gooooo1?l0000k
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0:_ooool00?ooooooJOooool001Wooooo00?o0000oooo
ooooool0oooooom=ooooo`006Oooool00ol0003oooooooooo`3ooooooc?ooooo00?o410@o`000?l0
00000ol0000Dooooo`006Oooool00ol0003oooooooooo`3oooooocGooooo00?o0000ooooooooool0
5Oooool001Wooooo00?o0000ooooooooool0ooooooleooooo`03o`000?oooooooooo01Gooooo000B
oooooooo0000=?l0000;ooooo`03o`000?oooooooooo01Gooooo000Iooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool00_ooool6o`0000?ooooo00?o0000ooooooooool04Oooool00ol0
003o<S8bomgMg@0Eooooo`006Oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo04Ko
oooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0iooooo`?o00002Oooool00ol0003o
ooooooooo`0@ooooo`;o000000CoZJVYob4Q8Ol0003o8B4Q4oooool001Wooooo00?o0000oooooooo
ool0oooooolBooooo`?o0000>?ooool001Wooooo00?o0000ooooooooool0ooooool@ooooo`;o0000
>oooool001Wooooo00?o0000ooooooooool0ooooool?ooooo`03o`000?oooooooooo03_ooooo000I
ooooo`03o`000?oooooooooo0?oooooo3Oooool2o`0003kooooo000Iooooo`03o`000?oooooooooo
0?oooooo2oooool2o`00043ooooo000Iooooo`03o`000?oooooooooo0?oooooo2_ooool00ol0003o
ooooooooo`10ooooo`006Oooool00ol0003oooooooooo`2jooooo`Ko0000B?ooool00ol0003ooooo
ooooo`11ooooo`006Oooool3o`000;Oooooo0ol00006ooooo`Co0000@_ooool2o`0004Cooooo000I
ooooo`03o`000?oooooooooo0;Cooooo0ol0000=ooooo`03o`000?oooooooooo03kooooo00?o0000
ooooooooool0A?ooool001Wooooo00?o0000ooooooooool0/oooool00ol0003oooooooooo`0?oooo
o`;o0000?Oooool00ol0003oooooooooo`15ooooo`006Oooool00ol0003oooooooooo`2cooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool0>?ooool2o`0004Sooooo000Iooooo`03o`00
0?oooooooooo0;;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0fooooo`03o`00
0?oooooooooo04Sooooo000Iooooo`03o`000?oooooooooo0;7ooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo04Wooooo000Iooooo`03o`000?oooooo
oooo0;3ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0booooo`03o`000?oooooo
oooo04[ooooo000Iooooo`03o`000?oooooooooo0:oooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0`ooooo`03o`000?oooooooooo04_ooooo000Iooooo`03o`000?oooooooooo0:oo
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo04co
oooo000Iooooo`03o`000?oooooooooo0:kooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0/ooooo`03o`000?oooooooooo04gooooo000Iooooo`?o0000[Oooool00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0C_ooool001Wooooo00?o0000
ooooooooool0[?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo02Sooooo00?o0000
ooooooooool0Coooool001Wooooo00?o0000ooooooooool0[?ooool00ol0003oooooooooo`0Qoooo
o`;o00009oooool00ol0003oooooooooo`1@ooooo`006Oooool00ol0003oooooooooo`2[ooooo`03
o`000?oooooooooo02Cooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Aooooo`00
6Oooool00ol0003oooooooooo`2[ooooo`03o`000?oooooooooo02Gooooo0_l0000Rooooo`03o`00
0?oooooooooo05;ooooo000Iooooo`03o`000?oooooooooo0:[ooooo00?o0000ooooooooool0:?oo
ool2o`0001oooooo00?o0000ooooooooool0Doooool001Wooooo00?o0000ooooooooool0Z_ooool0
0ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01[ooooo0_l0001Fooooo`006Oooool00ol0
003oooooooooo`2Yooooo`03o`000?oooooooooo02cooooo0_l0000Hooooo`;o0000F?ooool001Wo
oooo00?o0000ooooooooool0Z?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool0F?ooool001Wooooo0ol0002Xooooo`03o`000?oooooooooo033ooooo
0_l0000Booooo`;o0000Foooool001Wooooo00?o0000ooooooooool0Yoooool00ol0003ooooooooo
o`0cooooo`03o`000?oooooooooo00gooooo0_l0001Mooooo`006Oooool00ol0003oooooooooo`2W
ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool02Oooool3o`0005oooooo000Ioooo
o`03o`000?oooooooooo0:Kooooo00?o0000ooooooooool0=_ooool5o`0000?ooooo0ol0001Roooo
o`006Oooool00ol0003oooooooooo`2Vooooo`03o`000?oooooooooo03_ooooo0ol0001Uooooo`00
6Oooool00ol0003oooooooooo`2Uooooo`03o`000?oooooooooo0:Cooooo000Iooooo`03o`000?oo
oooooooo0:Gooooo00?o0000ooooooooool0Y?ooool001Wooooo00?o0000ooooooooool0Y?ooool0
0ol0003oooooooooo`2Uooooo`003oooool5o`0000Gooooo00?o0000ooooooooool0Y?ooool00ol0
003oooooooooo`2Uooooo`003oooool01OnHV9So8B4Qonk^k_ooooooA4A400Gooooo00?o0000oooo
ooooool0Y?ooool00ol0003oooooooooo`2Uooooo`004?ooool00onHV9So8B4Qonk^kP06ooooo`?o
0000Xoooool00ol0003oooooooooo`2Vooooo`004Oooool00onHV9So8B4Qonk^kP05ooooo`03o`00
0?oooooooooo0:?ooooo00?o0000ooooooooool0Y_ooool001;ooooo00?oMgMgofIVI_ooool01?oo
ool00ol0003oooooooooo`2Rooooo`03o`000?oooooooooo0:Oooooo000Cooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0X_ooool00ol0003oooooooooo`2Wooooo`003oooool01Ol0
003o^[ZjoooooonHV9So410@00Gooooo00?o0000ooooooooool0XOooool00ol0003oooooooooo`2X
ooooo`003oooool01OnHV9So410@o`000?lQ8B7oc<c<00Gooooo00?o0000ooooooooool0XOooool0
0ol0003oooooooooo`2Xooooo`006Oooool00ol0003oooooooooo`2Qooooo`03o`000?oooooooooo
0:Sooooo000Iooooo`03o`000?oooooooooo0:3ooooo00?o0000ooooooooool0ZOooool001Wooooo
00?o0000ooooooooool0X?ooool00ol0003oooooooooo`2Yooooo`006Oooool00ol0003ooooooooo
o`2Oooooo`03o`000?oooooooooo0:[ooooo000Iooooo`?o0000Woooool00ol0003oooooooooo`2Z
ooooo`006Oooool00ol0003oooooooooo`2Oooooo`03o`000?oooooooooo0:[ooooo000Iooooo`03
o`000?oooooooooo09kooooo00?o0000ooooooooool0Zoooool001Wooooo00?o0000ooooooooool0
W_ooool00ol0003oooooooooo`2[ooooo`006Oooool00ol0003oooooooooo`2Mooooo`03o`000?oo
oooooooo0:cooooo000Iooooo`03o`000?oooooooooo09gooooo00?o0000ooooooooool0[?ooool0
01Wooooo00?o0000ooooooooool0W?ooool00ol0003oooooooooo`2]ooooo`006Oooool00ol0003o
ooooooooo`2Looooo`03o`000?oooooooooo0:gooooo000Iooooo`03o`000?oooooooooo09_ooooo
00?o0000ooooooooool0[_ooool001Wooooo00?o0000ooooooooool0Voooool00ol0003ooooooooo
o`2^ooooo`006Oooool3o`0009[ooooo00?o0000ooooooooool0[oooool001Wooooo00?o0000oooo
ooooool0V_ooool00ol0003oooooooooo`2_ooooo`006Oooool00ol0003oooooooooo`2Iooooo`03
o`000?oooooooooo0;3ooooo000Iooooo`03o`000?oooooooooo09Wooooo00?o0000ooooooooool0
/?ooool001Wooooo00?o0000ooooooooool0V?ooool00ol0003oooooooooo`2aooooo`006Oooool0
0ol0003oooooooooo`2Hooooo`03o`000?oooooooooo0;7ooooo000Iooooo`03o`000?oooooooooo
09Oooooo00?o0000ooooooooool0/_ooool001Wooooo00?o0000ooooooooool0Uoooool00ol0003o
ooooooooo`2booooo`006Oooool00ol0003oooooooooo`2Fooooo`03o`000?oooooooooo0;?ooooo
000Iooooo`?o0000U_ooool00ol0003oooooooooo`2cooooo`006Oooool00ol0003oooooooooo`2E
ooooo`03o`000?oooooooooo0;Cooooo000Iooooo`03o`000?oooooooooo09Cooooo00?o0000oooo
ooooool0]Oooool001Wooooo00?o0000ooooooooool0T_ooool2o`000;Sooooo000Iooooo`03o`00
0?oooooooooo097ooooo00?o0000ooooooooool0^?ooool001Wooooo00?o0000ooooooooool0S_oo
ool3o`000;_ooooo000Iooooo`03o`000?oooooooooo08cooooo0_l0002nooooo`006Oooool00ol0
003oooooooooo`2;ooooo`03o`000?oooooooooo0;kooooo000Aooooo`;o000000?o410@oooooooo
ool00oooool00ol0003oooooooooo`2;ooooo`03o`000?oooooooooo0;kooooo000Booooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0R_ooool00ol0003oooooooooo`2oooooo`003ooo
ool5o`0000Gooooo0ol00029ooooo`03o`000?oooooooooo0<3ooooo000?ooooo`04odA4A?oMgMgo
ooooo`0000Kooooo00?o0000ooooooooool0R?ooool00ol0003oooooooooo`31ooooo`003oooool0
1?oMgMgoEEEEooooool00006ooooo`03o`000?oooooooooo08Sooooo00?o0000ooooooooool0`Ooo
ool0013ooooo00?oMgMgolc<c?l000001_ooool00ol0003oooooooooo`27ooooo`03o`000?oooooo
oooo0<;ooooo000@ooooo`03onk^k_m4A4Co000000Kooooo00?o0000ooooooooool0Qoooool00ol0
003oooooooooo`32ooooo`004Oooool00omgMgOo0000ooooo`05ooooo`03o`000?oooooooooo08Ko
oooo00?o0000ooooooooool0`oooool001Wooooo00?o0000ooooooooool0Q_ooool00ol0003ooooo
ooooo`33ooooo`006Oooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo0<Cooooo000I
ooooo`03o`000?oooooooooo08Gooooo00?o0000ooooooooool0a?ooool001Wooooo00?o0000oooo
ooooool0Q?ooool00ol0003oooooooooo`35ooooo`006Oooool3o`0008Cooooo00?o0000oooooooo
ool0aOooool001Wooooo00?o0000ooooooooool0Q?ooool00ol0003oooooooooo`35ooooo`006Ooo
ool00ol0003oooooooooo`23ooooo`03o`000?oooooooooo0<Kooooo000Iooooo`03o`000?oooooo
oooo08?ooooo00?o0000ooooooooool0a_ooool001Wooooo00?o0000ooooooooool0P_ooool00ol0
003oooooooooo`37ooooo`006Oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo0<Oo
oooo000Iooooo`03o`000?oooooooooo087ooooo00?o0000ooooooooool0b?ooool001Wooooo00?o
0000ooooooooool0POooool00ol0003oooooooooo`38ooooo`006Oooool00ol0003oooooooooo`20
ooooo`03o`000?oooooooooo0<Wooooo000Iooooo`03o`000?oooooooooo083ooooo00?o0000oooo
ooooool0bOooool001Wooooo0ol0001oooooo`03o`000?oooooooooo0<[ooooo000Iooooo`03o`00
0?oooooooooo07oooooo00?o0000ooooooooool0b_ooool001Wooooo00?o0000ooooooooool0=_oo
ool4o`0004Gooooo00?o0000ooooooooool0b_ooool001Wooooo00?o0000ooooooooool0<_ooool4
o`0000Cooooo0_l00012ooooo`03o`000?oooooooooo0<_ooooo000Iooooo`03o`000?oooooooooo
033ooooo0_l0000:ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0boooool001Wo
oooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0:ooooo`;o0000?oooool00ol0003o
ooooooooo`3;ooooo`006Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`3<ooooo`006Oooool00ol0003ooooooooo
o`0^ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`3<ooooo`006Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool0>Oooool00ol0003oooooooooo`3=ooooo`006Oooool3o`0002cooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo0<gooooo000Iooooo`03
o`000?oooooooooo02_ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo0<gooooo000Iooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo0<kooooo000Iooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0eooooo`03o`000?oo
oooooooo0<kooooo000Iooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`0dooooo`03o`000?oooooooooo0<kooooo000Iooooo`03o`000?oooooooooo
02Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo
0<oooooo000Iooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`0aooooo`03o`000?oooooooooo0<oooooo000Iooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo0<oooooo
000?ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01Oooool00ol0003oooooooooo`0Wooooo`03o`00
0?oooooooooo01gooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`3@ooooo`003ooo
ool01OmEEEGoMgMgoooooonHV9So8B4Q00Gooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0d?ooool000oooooo00Go
0000ooooooooooooooooo`000005ooooo`?o00009Oooool00ol0003oooooooooo`0Pooooo`03o`00
0?oooooooooo02gooooo00?o0000ooooooooool0dOooool000oooooo00Go0000oiRHV?ooooooV9RH
ob4Q8@05ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool08Oooool00ol0003ooooo
ooooo`0/ooooo`03o`000?oooooooooo0=7ooooo000?ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0
1Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0
:_ooool00ol0003oooooooooo`3Booooo`003oooool00omEEEGoQhN7ooooo`07ooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo0=;ooooo000?ooooo`03omgMgOl@413oV9RH00Oooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0doooool0
013ooooo00Coc<c<odA4A?l0003o410@1Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`3Cooooo`006Oooool00ol0
003oooooooooo`0Rooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`3Dooooo`006Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo02So
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`3Dooooo`006Oooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`3Dooooo`006Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo02[ooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`3Eooooo`006Oooool3o`00023ooooo00?o0000
ooooooooool0;?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo0=Gooooo000Ioooo
o`03o`000?oooooooooo023ooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Poooo
o`03o`000?oooooooooo0=Kooooo000Iooooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool0;_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo0=Kooooo000Iooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo0=Oooooo000Iooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0<Ooo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo0=Oooooo000Iooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo0=Sooooo000Iooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0<_ooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo0=Sooooo000Iooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo0=Wo
oooo000Iooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0=Oooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo0=[ooooo000Iooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool0=_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo0=[ooooo000I
ooooo`?o00007?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool0foooool001Wooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0ioooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0foooool001Wooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool0g?ooool001Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0looooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool0gOooool001Wooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0gOoo
ool001Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0oooooo`03o`000?oooooo
oooo00cooooo0_l0003Pooooo`006Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
043ooooo0ol00008ooooo`?o0000h_ooool001Wooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`14ooooo`?o00000_ooool3o`000>Gooooo000Iooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool0Aoooool2o`000>Sooooo000Iooooo`?o00005oooool00ol0003ooooooooo
o`3ooooooc?ooooo000Iooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0oooooolc
ooooo`006Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo0?oooooo=?ooool001Wo
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`3oooooocCooooo000Iooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool0ooooooleooooo`006Oooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo0?oooooo=Oooool001Wooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`3oooooocKooooo000Iooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool0oooooolfooooo`003oooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Gooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`3oooooocOooooo000?ooooo`05ob4Q8OnHV9SooooooiRH
V?lQ8B401Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo0?oooooo=oooool000oo
oooo00Go0000ooooooooooooooooo`000005ooooo`?o00004_ooool00ol0003oooooooooo`3ooooo
ocSooooo000?ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801Oooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo0?oooooo>?ooool000oooooo00Goc<c<o`000?l0003o0000olc<c005oooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool0ooooooliooooo`003oooool01Ol@413o
^[Zjoooooonj^[[o410@00Gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`3ooooo
ocWooooo000?ooooo`05o`000?nj^[[ooooookZj^_l000001Oooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo0?oooooo>_ooool000oooooo00GoZJVYoa0@4?l0003o410@ojVYZ@05oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0ooooooljooooo`006Oooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo0?oooooo>oooool001Wooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`3ooooooc_ooooo000Iooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool0oooooollooooo`006Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo0?oooooo??ooool001Wooooo0ol0000=ooooo`03o`000?oooooooooo0?oooooo?Oooool001Wo
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`3oooooocgooooo000Iooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool0oooooolnooooo`006Oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo0?oooooo?_ooool001Wooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`3oooooocoooooo000Iooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool0oooooom0ooooo`006Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0?oo
oooo@Oooool001Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`3ooooood;ooooo
000Iooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0oooooom3ooooo`006Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?ooooooA?ooool001Wooooo0ol00004oooo
o`;o0000oooooom7ooooo`006Oooool00ol0003oooooooooo`02ooooo`;o0000oooooom9ooooo`00
6Oooool00ol0003oooooooooo`02o`000?ooooooBoooool001Wooooo0ol0003oooooodgooooo000I
ooooo`03o`000?oooooooooo0?ooooooCOooool001Wooooo00?o0000ooooooooool0oooooom=oooo
o`006Oooool00ol0003oooooooooo`3oooooodgooooo000Iooooo`03o`000?oooooooooo0?oooooo
COooool001Wooooo00?o0000ooooooooool0oooooom=ooooo`006Oooool00ol0003oooooooooo`3o
ooooodgooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo001Booooo`04oa0@4?l0003o0000o`00097ooooo00Co410@o`00
0?l0003o0000OOooool005?ooooo00?o0000ooooooooool01_ooool2o`0000_ooooo00?o0000okZj
^_ooool06oooool2o`0005oooooo00?o0000ooooooooool0OOooool005?ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0:ooooo`;o<S8b7Oooool00ol0003oooooooooo`1Mooooo`03
o`000?oooooooooo07gooooo001:ooooo`05ojVYZOl@413o0000oa0@4?n7QhL01?ooool01_l0003o
MgMgo`000?l0003oEEEEonk^kP?ooooo00Co0000oooooooooooo410@1Ol00004ooooo`03ohN7Qol0
003o^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4okZj^P0:ooooo`Co000000?o410@ooooooooool0
0_ooool00ol0003oooooooooo`0;ooooo`Go00000_ooool01?l@413o0000o`000?ooool2o`000003
oa0@4?oooooooooo00Kooooo00GoV9RHo`000?l0003oA4A4okZj^P02ooooo`04oa0@4?l0003o0000
ooooo`;o000000Co410@ooooooo^k^koEEEE0_l000000om4A4Co^[Zjooooo`07ooooo`Go00002_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Oo0000ogMgMol0003o0000oeEEEOo^k^kooooo
00Go00000oooool01_nHV9So0000o`000?mgMgOo410@o`0000;ooooo00Co410@o`000?l0003ooooo
0_l000001?l@413oooooonk^k_mEEED2o`000003odA4A?nj^[[ooooo05[ooooo001:ooooo`06o`00
0?nHV9Soooooolc<c?lQ8B7oQhN70oooool01_l0003oEEEEonk^k_ooooooMgMgoeEEE@?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03olc<c?l0003o410@00Cooooo00Go
410@okZj^_o^k^koMgMgoa0@4002ooooo`Ko00001?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Wo
oooo00Go410@okZj^_o^k^koMgMgoa0@4003ooooo`05o`000?ooooooooooooooool000000_ooool0
1_mEEEGoMgMgooooooo^k^koMgMgoa0@40Sooooo0_mgMgL2ooooo`04o`000?ooooooooooooooo`Ko
000000KoooooogMgMonHV9SooooooiRHV?mgMgL;ooooo`06o`000?mEEEGok^k^oooooomgMgOoEEEE
0oooool00ol0003oooooooooo`03ooooo`05o`000?o<c<cok^k^ohN7Qol000001?ooool01Ol0003o
oooooooooooooooo000000;ooooo00KoEEEEogMgMoooooook^k^ogMgMol@411Kooooo`00B_ooool0
1_l0003ooooooooooooooooogMgMoa0@40?ooooo00?o0000onk^k_ooool00_ooool01Ol0003ooooo
oooooooooooo000000Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`03ooooo`05
o`000?ooooooooooooooool000002Oooool00ol0003oooooooooo`05ooooo`05o`000?oooooooooo
ooooool000000_ooool00ol0003oooooooooo`0<ooooo`03oeEEEOnHV9Sooooo00_ooooo00Go410@
oooooooooooooooooa0@400;ooooo`03o`000?o^k^kooooo00;ooooo00Go0000oooooooooooooooo
o`000005ooooo`05oa0@4?n7QhOoooooonk^k_l000001?ooool01Ol0003ooooooooooooooooo0000
00;ooooo00?o0000ooooooooool0G_ooool004[ooooo00?oEEEEokZj^_ooool00_ooool01_l0003o
oooooooooooooooo0000onk^kP?ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool01?ooool6o`0000Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooooooo
o`000009ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000002ooooo`Ko
00002_ooool00omEEEGoV9RHooooo`03ooooo`Ko000000?oooooo`000?ooool00_ooool00ol0003o
ooooooooo`09ooooo`03o`000?o^k^kooooo00;ooooo00Go0000ooooooooooooooooo`000005oooo
o`03okZj^_l@413o000000;o00001?ooool01Ol0003ooooooooooooooooo000000;ooooo1_l0001K
ooooo`00B_ooool01_o^k^koA4A4okZj^_ooooooQhN7oc8b<P?ooooo00Ko0000oeEEEOo^k^kooooo
ogMgMomVIVH3ooooo`03o`000?oooooooooo00;ooooo00?o0000oc8b<_oMgMd03?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`03ooooo`05o`000?n7QhOoooooojVYZOl000002Oooool00ol0003oooooooooo`05oooo
o`05o`000?mgMgOoooooojVYZOl000000_ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b<PSooooo
00Go0000oooooooooooo<S8bohN7Q`0:ooooo`05o`000?ooooooooooooooool000002oooool01_l0
003oEEEEonk^k_ooooooMgMgofIVIP?ooooo00?o0000ooooooooool01_ooool00oo<c<co0000oooo
o`03ooooo`05o`000?n7QhOoooooojVYZOl000000_ooool01_mEEEGoQhN7onk^k_ooooooQhN7oc8b
<U_ooooo001<ooooo`04oiRHV?lQ8B7oA4A4onk^kP;ooooo00?o410@o`000?mgMgL00_l000000omV
IVKok^k^ooooo`02ooooo`04o`000?ooooooooooooooo`;o000000CoZJVYob4Q8Ol0003o8B4Q2?oo
ool00ol@413o0000o`000003o`0000gooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0;ooooo`03oa0@4?l0003o000000Cooooo00?o410@o`000?mgMgL00_l000000onHV9Sooooooooo
o`05ooooo`03oa0@4?l0003o000000?o00001?ooool01Ol0003oMgMgo`000?l0003oV9RH00;ooooo
00Kok^k^oeEEEOl0003o0000odA4A?o^k^h8ooooo`Go00002_ooool01Ol@413ooooooooooooooooo
410@00[ooooo00?o410@o`000?mgMgL00_l000000omVIVKok^k^ooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00Co<S8bo`000?l0003oV9RH0oooool00ol@413o0000ogMgM`02o`000005oiRHV?oo
ooooooooonk^k_mEEED00_l000000om4A4Cok^k^ooooo`1Jooooo`00C?ooool00ol0003o^[Zjoooo
o`0=ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Qooooo`05ogMgMonHV9SooooooiRHV?mgMgL05?ooool00ol0003oooooooooo`1dooooo`00C?oo
ool01?nHV9So0000o`000?l@410<ooooo`;o00004_ooool00ol0003oooooooooo`0<ooooo`03oeEE
EOmVIVKo000000Gooooo0_l0000?ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Qooooo`05onk^k_lb<S;o0000oc8b<_o^k^h05?ooool00ol0003o
ooooooooo`1dooooo`00V?ooool00ol@413oooooooooo`0Hooooo`03oa0@4?l0003ooooo03Wooooo
00?o410@o`000?l00000M_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-0.178256, -0.773064, \
0.00859027, 0.0641261}}],

Cell["Fig. 5.5 Exercise (22).", "Caption",
  CellTags->"Fig. 5.5"],

Cell[TextData[{
  StyleBox["(23)",
    FontWeight->"Bold"],
  " A  jet aircraft  moves with constant speed ",
  Cell[BoxData[
      \(TraditionalForm\`v\)]],
  " in the ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  " direction. The jet acts as a point pressure source,  and the air pressure \
responds according to the three-dimensional wave equation, ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\^2 p\/\[PartialD]t\^2 = \(c\^2\) \
\[Del]\^2 p + s\ \(\[Delta](z - v\ t)\) \(\[Delta](x)\) \(\[Delta](y)\)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Using Fourier transforms, find the particular solution for the wake \
behind this moving source  of the form ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(p(z - v\ t\ , \ r)\)\)\)]],
  " in cylindrical coordinates ",
  Cell[BoxData[
      \(TraditionalForm\`\((r, \[Theta], z)\)\)]],
  ",",
  StyleBox[" assuming that ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`v < c\)],
    FontSlant->"Italic"],
  StyleBox[".",
    FontSlant->"Italic"],
  " (As seen in a frame moving with the source, this wake is stationary.)"
}], "Text",
  CellTags->"i:64"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " In the moving frame ",
  Cell[BoxData[
      \(TraditionalForm\`z\&_ = z - v\ t\)]],
  ", plot contours of constant ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  " in the ",
  Cell[BoxData[
      \(TraditionalForm\`x - z\&_\)]],
  " plane for ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\((i)\)\ v = 0\)\(\ \)\(,\)\)\)]],
  "(ii) ",
  Cell[BoxData[
      \(TraditionalForm\`v = c/2\)]],
  ", (iii) ",
  Cell[BoxData[
      \(TraditionalForm\`v = 9\ c/10\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Show that for ",
  Cell[BoxData[
      \(TraditionalForm\`v > c\)]],
  ", your solution breaks down along lines defined by ",
  Cell[BoxData[
      \(TraditionalForm\`\((z\&_/r)\)\^2 = \((v/c)\)\^2 - 1\)]],
  ".  What is the physical significance of these lines? (Actually, your \
answer is incorrect if ",
  Cell[BoxData[
      \(TraditionalForm\`v > c\)]],
  ". See the next exercise.)"
}], "Text"],

Cell[TextData[{
  StyleBox["(24)",
    FontWeight->"Bold"],
  " Redo the calculation in the previous problem, taking ",
  Cell[BoxData[
      \(TraditionalForm\`v > c\)]],
  ", and using Eq. ",
  ButtonBox["(5.1.85)",
    ButtonData:>"(5.1.85)",
    ButtonStyle->"Hyperlink"],
  " rather than Fourier methods. "
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Show that the retarded time ",
  Cell[BoxData[
      \(TraditionalForm\`t\_o\)]],
  " in Eq. ",
  ButtonBox["(5.1.85)",
    ButtonData:>"(5.1.85)",
    ButtonStyle->"Hyperlink"],
  " satisfies  ",
  Cell[BoxData[
      \(TraditionalForm\`t\_o = 
        t - \(\(\ \)\(v\ z\&_ \[PlusMinus] \@\(\(r\^2\)(c\^2 - v\^2) + \(z\&_\
\^2\) c\^2\)\)\)\/\(c\^2 - v\^2\)\)]],
  ",where  ",
  Cell[BoxData[
      \(TraditionalForm\`z\&_ - z - v\ t\)]],
  "  , with the added requirement ",
  Cell[BoxData[
      \(TraditionalForm\`t\_o < t\)]],
  " used to determine the choice of the ",
  Cell[BoxData[
      \(TraditionalForm\`\[PlusMinus]\)]],
  " sign, and with no solution if the argument of the square root is \
negative."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Show that for ",
  Cell[BoxData[
      \(TraditionalForm\`c > v\)]],
  " the requirement that ",
  Cell[BoxData[
      \(TraditionalForm\`t\_o < t\)]],
  " implies that  only the ",
  Cell[BoxData[
      \(TraditionalForm\`+\)]],
  " sign should be kept."
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Show that for ",
  Cell[BoxData[
      \(TraditionalForm\`c < v\)]],
  " the requirement that ",
  Cell[BoxData[
      \(TraditionalForm\`t\_o < t\)]],
  " implies that ",
  Cell[BoxData[
      \(TraditionalForm\`z\&_ < 0\)]],
  " and that both signs can be kept."
}], "Text"],

Cell[TextData[{
  StyleBox["(d)",
    FontWeight->"Bold"],
  " Using Eq. ",
  ButtonBox["(2.3.33)",
    ButtonData:>{"Chapter2.nb", "(2.3.33)"},
    ButtonStyle->"Hyperlink"],
  ", show that ",
  Cell[BoxData[
      FormBox[
        RowBox[{"p", "(", 
          RowBox[{
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[",",
              FontWeight->"Plain"], 
            StyleBox["t",
              FontWeight->"Plain"]}], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  "can be written as"
}], "Text"],

Cell[TextData[{
  "\t\t ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"p", "(", 
            RowBox[{
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[",",
                FontWeight->"Plain"], 
              StyleBox["t",
                FontWeight->"Plain"]}], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox[" ",
            FontWeight->"Plain"], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox[" ",
            
            FontWeight->
              "Plain"], \(\(s\/\(4  \[Pi]\ c\)\) \(\[Sum]\+\(t\_o\)1\/\(\(|\)\
\(\(t\_o\)(v\^2 - c\^2) + \(c\^2\) t - v\ z\)\(|\)\)\)\)}], 
        TraditionalForm]]],
  ", "
}], "Text"],

Cell["where the sum is over the solution(s) for the retarded time.", "Text"],

Cell[TextData[{
  StyleBox["(e)",
    FontWeight->"Bold"],
  " Using the previous results, show that, for ",
  Cell[BoxData[
      \(TraditionalForm\`v > c\)]],
  ", "
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"p", "(", 
            RowBox[{
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[",",
                FontWeight->"Plain"], 
              StyleBox["t",
                FontWeight->"Plain"]}], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox["=",
            
            FontWeight->
              "Plain"], \(\(s\/\(2  \[Pi]\ c\)\) \(1\/\@\(\(r\^2\)(c\^2 - \
v\^2) + \(z\&_\^2\) c\^2\)\) \(h(\(-r\) \@\(c\^2 - v\^2\) - \(z\&_\) c)\)\)}],
         TraditionalForm]]],
  ","
}], "Text"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`h\)]],
  " is a Heaviside function, and for ",
  Cell[BoxData[
      \(TraditionalForm\`v < c\)]],
  ","
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"p", "(", 
            RowBox[{
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[",",
                FontWeight->"Plain"], 
              StyleBox["t",
                FontWeight->"Plain"]}], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox["=",
            FontWeight->"Plain"], \(\(s\/\(4  \[Pi]\ c\)\) 
            1\/\@\(\(r\^2\)(c\^2 - v\^2) + \(z\&_\^2\) c\^2\)\)}], 
        TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  " (This is the solution to the previous problem.) Make a surface plot of ",
  Cell[BoxData[
      \(TraditionalForm\`p(r, \ z\&_)\)]],
  "  for (i) ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(v/c\  = \ 2\)\(,\)\)\)]],
  " (ii) ",
  Cell[BoxData[
      \(TraditionalForm\`v/c\  = \ 4\)]],
  "."
}], "Text"],

Cell[TextData[{
  "(The cone structure visible behind the source is called a ",
  StyleBox[ButtonBox["Mach",
    ButtonData:>{
      URL[ "http://scienceworld.wolfram.com/biography/Mach.html"], None},
    ButtonStyle->"Hyperlink"],
    FontSlant->"Italic"],
  StyleBox[" cone",
    FontSlant->"Italic"],
  ". The large amplitude just behind the cone implies that linear theory \
breaks down and a nonlinear ",
  StyleBox["shock wave",
    FontSlant->"Italic"],
  " forms. Shocks will be discussed in Chapter ",
  ButtonBox["7",
    ButtonData:>{"Chapter7.nb", None},
    ButtonStyle->"Hyperlink"],
  ".)"
}], "Text",
  CellTags->"i:53"],

Cell[TextData[{
  StyleBox["(25) ",
    FontWeight->"Bold"],
  "A long straight wire of radius ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " and resistivity ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\)]],
  " is initially at temperature ",
  Cell[BoxData[
      \(TraditionalForm\`T = 0  \[Degree]C\)]],
  ". The wire is clad with an infinitely thick shell of material, also at ",
  Cell[BoxData[
      \(TraditionalForm\`T = 0\)]],
  ". The cladding is not electrically conductive but has the same thermal \
diffusivity ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi]\)]],
  " as the conductor in the wire. At time ",
  Cell[BoxData[
      \(TraditionalForm\`t = 0\)]],
  ", the wire begins to carry  a uniform  current density ",
  Cell[BoxData[
      \(TraditionalForm\`j\)]],
  ", creating a heating power density ",
  Cell[BoxData[
      \(TraditionalForm\`S = \[Rho]\ j\ \(h(a - r)\)\)]],
  " , where ",
  Cell[BoxData[
      \(TraditionalForm\`h\)]],
  " is a Heaviside function.\n",
  StyleBox["(a)",
    FontWeight->"Bold"],
  "  Find the evolution of the temperature, and show that in cylindrical \
coordinates,"
}], "Text",
  CellTags->"i:65"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`T(r, t)\  = \ 
        a\ S \(\[Integral]\_0\%\[Infinity]\(\( J\_o\)(k\ r)\)\ \(\(J\_1\)(
                k\ a)\) \((\(1 - \[ExponentialE]\^\(\(-\[Chi]\)\ \(k\^2\) t\)\
\)\/\(\[Chi]\ k\^2\))\) \[DifferentialD]k\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Perform the integral to show that the temperature along axis of the wire \
satisfies "
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`T(0, t) = 
        S\ \((\ t(
                1 - \[ExponentialE]\^\(-\(a\^2\/\(4\ t\ \[Chi]\)\)\)\ ) + \(a\
\^2\ \(\[CapitalGamma](0, a\^2\/\(4\ t\ \[Chi]\))\)\)\/\(4\ \[Chi]\))\)\)]],
  ", "
}], "Text"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalGamma](n, x)\)]],
  "is a special function called an ",
  StyleBox["incomplete Gamma function",
    FontSlant->"Italic"],
  StyleBox[". ",
    FontWeight->"Bold",
    FontSlant->"Italic"],
  " Plot this result for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi] = \(a = \(S = 1\)\)\)]],
  ",and for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t \[LessEqual] \ 10\^3\)]],
  ". Show that at large times the temperature diverges, and find the form of \
this divergence. (The material cannot conduct heat away from the source \
rapidly enough to equilibrate its temperature.)"
}], "Text"],

Cell[TextData[{
  StyleBox["(26)",
    FontWeight->"Bold"],
  " A Gaussian wave packet of water waves propagates across a river, in the \
+",
  Cell[BoxData[
      \(TraditionalForm\`y\ direction\)]],
  ". The form of the packet is ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(z(x, y, t)\), " ", 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{"2", " ", "Re", 
            RowBox[{"\[Integral]", 
              
              RowBox[{\(\(\(\[DifferentialD]\^2 
                      k\)\(\ \)\)\/\((2  \[Pi])\)\^2\), 
                RowBox[{"A", "(", 
                  StyleBox["k",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], 
                  StyleBox[")",
                    FontWeight->"Plain"]}], 
                StyleBox[" ",
                  FontWeight->"Plain"], 
                StyleBox[
                  SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"\[ImaginaryI]", " ", 
                      RowBox[{"(", 
                        RowBox[{
                          RowBox[{
                            StyleBox["k",
                              FontWeight->"Bold",
                              FontSlant->"Plain"], "\[CenterDot]", 
                            StyleBox["r",
                              FontWeight->"Bold",
                              FontSlant->"Plain"]}], 
                          StyleBox["-",
                            FontWeight->"Plain"], 
                          RowBox[{
                            StyleBox[\(\[Omega](k)\),
                              FontWeight->"Plain"], 
                            StyleBox[" ",
                              FontWeight->"Bold"], "t"}]}], ")"}]}]],
                  FontWeight->"Plain"]}]}]}]}], TraditionalForm]]],
  ", where ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"A", "(", 
            StyleBox["k",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox[" ",
            FontWeight->"Plain"], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox[
            RowBox[{
              StyleBox[" ",
                FontWeight->"Plain"], 
              " "}]], \(25\ \[Pi]\ \[ExponentialE]\^\(-\(25\/4\)\ [k\_x\^2 + \
\ \((\(-1\) + k\_y)\)\^2]\)\)}], TraditionalForm]]],
  ", with distances measured in centimeters. Thus, the wave packet is peaked \
at ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox[
            StyleBox["k",
              FontWeight->"Bold",
              FontSlant->"Plain"], "o"], "=", \((0, 1)\)}], 
        TraditionalForm]]],
  ". In still water, the dispersion relation for the waves is ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega](k) = \@\(g\ k\)\)]],
  ". However, there is a current in the ",
  Cell[BoxData[
      \(TraditionalForm\`\(+x\)\)]],
  " direction, with speed ",
  Cell[BoxData[
      FormBox[
        RowBox[{"U", "=", " ", 
          RowBox[{"10", " ", 
            RowBox[{"cm", "/", 
              StyleBox["s",
                FontSlant->"Plain"]}]}]}], TraditionalForm]]],
  ". Keeping dispersion in both ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " directions, plot the contours of constant ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  " for ",
  Cell[BoxData[
      FormBox[
        RowBox[{"0", "<", "t", "<", 
          RowBox[{"2", " ", 
            StyleBox["s",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  ".  (Solution: See Fig. ",
  ButtonBox["5.3",
    ButtonData:>"Fig. 5.3",
    ButtonStyle->"Hyperlink"],
  ")"
}], "Text"],

Cell[TextData[{
  StyleBox["(27)",
    FontWeight->"Bold"],
  " Magnetized plasmas carry many different types of waves that have \
anisotropic dispersion due to the magnetic field. Assuming a uniform magnetic \
field in the ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  "-direction, magnetized electron plasma waves have the following dispersion \
relation:"
}], "Text",
  CellTags->"i:54"],

Cell[TextData[{
  "\t\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\  = \ \(\(\[Omega]\_\(\(p\)\(\ \)\)\) 
            k\_z/k\  = \ \[Omega]\_p\ cos\ \[Theta]\)\)]],
  ","
}], "Text"],

Cell[TextData[{
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\)]],
  " is the angle between ",
  Cell[BoxData[
      FormBox[
        StyleBox["k",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " and the magnetic field, ",
  Cell[BoxData[
      FormBox[Cell[TextData[{
          Cell[BoxData[
              \(TraditionalForm\`\[Omega]\_\(\(p\)\(\ \)\)\)]],
          "=",
          Cell[BoxData[
              \(TraditionalForm\`\@\(\(e\^\(\(2\)\(\ \)\)\) \
n/\[Epsilon]\_\(\(o\)\(\ \)\) m\)\)]]
        }]], TraditionalForm]]],
  "is the electron plasma frequency, ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " is the electron density in the plasma, ",
  Cell[BoxData[
      \(TraditionalForm\`e\)]],
  " is the electron charge and ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " is the electron mass. "
}], "Text",
  CellTags->"i:55"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Find the group and phase velocities. Show that ",
  Cell[BoxData[
      \(TraditionalForm\`v\_g = 0\)]],
  " if ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta] = 0\)]],
  ", and for fixed ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_p\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  " find the angle ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\)]],
  " that provides the maximum value of ",
  Cell[BoxData[
      \(TraditionalForm\`v\_g\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " A disturbance that is initially spherically-symmetric propagates in the \
",
  Cell[BoxData[
      \(TraditionalForm\`\(+z\)\)]],
  "-direction according to ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"E", "(", 
            RowBox[{
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], ",", "t"}], ")"}], " ", 
          StyleBox["=",
            FontWeight->"Plain"], " ", 
          RowBox[{"2", " ", "Re", 
            RowBox[{"\[Integral]", 
              
              RowBox[{\(\(\(\[DifferentialD]\^3 
                      k\)\(\ \)\)\/\((2  \[Pi])\)\^3\), 
                RowBox[{"A", "(", "k", 
                  StyleBox[")",
                    FontWeight->"Plain"]}], 
                StyleBox[" ",
                  FontWeight->"Plain"], 
                RowBox[{
                  StyleBox[
                    SuperscriptBox["\[ExponentialE]", 
                      RowBox[{"\[ImaginaryI]", " ", 
                        RowBox[{"(", 
                          RowBox[{
                            RowBox[{
                              StyleBox["k",
                                FontWeight->"Bold",
                                FontSlant->"Plain"], "\[CenterDot]", 
                              StyleBox["r",
                                FontWeight->"Bold",
                                FontSlant->"Plain"]}], 
                            StyleBox["-",
                              FontWeight->"Plain"], 
                            RowBox[{
                              RowBox[{
                                StyleBox["\[Omega]",
                                  FontWeight->"Plain"], 
                                StyleBox["(",
                                  FontWeight->"Plain"], 
                                StyleBox["k",
                                  FontWeight->"Bold",
                                  FontSlant->"Plain"], 
                                StyleBox[")",
                                  FontWeight->"Plain"]}], 
                              StyleBox["t",
                                FontWeight->"Plain"]}]}], ")"}]}]],
                    FontWeight->"Plain"], " ", "."}]}]}]}]}], 
        TraditionalForm]]],
  " Show that this disturbance can be written as a single integral over the \
magnitude of ",
  Cell[BoxData[
      FormBox[
        StyleBox["k",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  ", "
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"E", "(", 
            RowBox[{
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], ",", "t"}], ")"}], " ", 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{
            StyleBox["8",
              FontWeight->"Plain"], " ", "\[Pi]", " ", "Re", 
            RowBox[{"\[Integral]", 
              RowBox[{\(\(\(k\^2\) \[DifferentialD]k\)\/\((2  \[Pi])\)\^3\), 
                RowBox[{"A", "(", "k", 
                  StyleBox[")",
                    FontWeight->"Plain"]}], 
                StyleBox[" ",
                  
                  FontWeight->
                    "Plain"], \(\(sin(\@\(\(k\^2\) r\^2 + \((k\ z\  - \ \(\
\[Omega]\_p\) t)\)\^2\))\)\/\@\(\(k\^2\) r\^2 + \((k\ z\  - \ \(\[Omega]\_p\) \
t)\)\^2\)\), Cell[""]}]}]}]}], TraditionalForm]]],
  ","
}], "Text"],

Cell[TextData[{
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`\((r, z)\)\)]],
  " are cylindrical coordinates. (Hint: use Eq. ",
  ButtonBox["(5.1.103)",
    ButtonData:>"(5.1.103)",
    ButtonStyle->"Hyperlink"],
  " ). Evaluating this integral numerically over the range ",
  Cell[BoxData[
      \(TraditionalForm\`0 < k < 8\)]],
  ",  create an animation of  a pulse  with a spectrum of the form ",
  Cell[BoxData[
      \(TraditionalForm\`A(k)\  = \ \[ExponentialE]\^\(\(-k\^2\)/4\)\)]],
  ". Plot the pulse evolution in the ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(r\)\(-\)\(z\)\(\ \)\)\)]],
  "plane for ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(0\)\(<\)\(\(\[Omega]\_p\) 
          t\)\(<\)\(20\)\(\ \)\)\)]],
  ", via a series of ",
  StyleBox["Plot3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " graphics functions."
}], "Text"],

Cell[TextData[{
  StyleBox["(28)",
    FontWeight->"Bold"],
  " Whistler waves are low-frequency electromagnetic waves that propagate \
along the magnetic field in a magnetized plasma. They have the following \
dispersion relation:"
}], "Text",
  CellTags->"i:56"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\  = \ \[CapitalOmega]\_c\ \(c\^\(\(2\)\(\ \
\)\)\) k\^2/\[Omega]\_p\^2\)]],
  ", "
}], "NumberedEquation",
  CellTags->"(5.1.104)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[CapitalOmega]\_c = e\ B/m\)]],
  " is the electron cyclotron frequency, we have assumed that ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["k",
            FontWeight->"Bold",
            FontSlant->"Plain"], " "}], TraditionalForm]]],
  " is parallel to the magnetic field, and we have also assumed that  ",
  Cell[BoxData[
      \(TraditionalForm\`c\ k\ << \ \[Omega] << \(\[CapitalOmega]\_c\)\)]],
  ". [See  ",
  ButtonBox["Stix (1962, pg. 55)",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  ".]"
}], "Text",
  CellTags->"i:57"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " A group of whistler waves is created by a lightning flash in the upper \
atmosphere. The waves propagate  along the earth's magnetic field in the \
ionospheric plasma, according to ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(E(x, t)\), " ", 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{"2", " ", "Re", 
            RowBox[{"\[Integral]", 
              RowBox[{\(\(\(\[DifferentialD]k\)\(\ \)\)\/\(2  \[Pi]\)\), 
                RowBox[{"A", "(", "k", 
                  StyleBox[")",
                    FontWeight->"Plain"]}], 
                StyleBox[" ",
                  FontWeight->"Plain"], 
                StyleBox[
                  SuperscriptBox["\[ExponentialE]", 
                    RowBox[{"\[ImaginaryI]", " ", 
                      RowBox[{"(", 
                        RowBox[{\(k\ x\), 
                          StyleBox["-",
                            FontWeight->"Plain"], 
                          StyleBox[\(\(\[Omega](k)\)\ t\),
                            FontWeight->"Plain"]}], ")"}]}]],
                  FontWeight->"Plain"]}]}]}]}], TraditionalForm]]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " is the distance along the magnetic field. Taking ",
  Cell[BoxData[
      \(TraditionalForm\`A(
          k)\  = \ \[ExponentialE]\^\(\(-k\^2\)/k\_o\^2\)\)]],
  ", find the evolution of the wave packet analytically, without \
approximation. Animate the evolution for the following parameters: ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(k\_o\), " ", "=", " ", 
          RowBox[{"0.01", " ", 
            SuperscriptBox[
              StyleBox["m",
                FontSlant->"Plain"], \(-1\)]}]}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[CapitalOmega]\_c\), "=", " ", 
          RowBox[{\(10\^5\), " ", 
            SuperscriptBox[
              StyleBox["s",
                FontSlant->"Plain"], \(-1\)]}]}], TraditionalForm]]],
  ", and ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Omega]\_p\), "=", " ", 
          RowBox[{\(10\^7\), " ", 
            SuperscriptBox[
              StyleBox["s",
                FontSlant->"Plain"], \(-1\)]}]}], TraditionalForm]]],
  ", and for ",
  Cell[BoxData[
      FormBox[
        RowBox[{"0", "<", "t", "<", 
          RowBox[{"0.01", "  ", 
            StyleBox["s",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " A radio receiver is 3000 kilometers away from the initial location of the \
lightning flash, as measured along the magnetic field. Using the ",
  StyleBox["Play",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function, play the sound that the whistler waves make as they are picked \
up by the receiver. (A good time range is from zero to 5 seconds).  Explain \
qualitatively why you hear a descending tone (this is why they are called \
whistler waves!). (Hint: how does the phase velocity depend on frequency?) To \
hear the sound of real whistler waves, picked up by the University of Iowa's \
plasma wave instrument on NASA's ",
  ButtonBox["POLAR spacecraft",
    ButtonData:>{
      URL[ "http://istp.gsfc.nasa.gov/istp/polar/index.html"], None},
    ButtonStyle->"Hyperlink"],
  ", go to the following link: ",
  ButtonBox["http://www-pw.physics.uiowa.edu/plasma-wave/istp/polar/\
magnetosound.html",
    ButtonData:>{
      URL[ 
      "http://www-pw.physics.uiowa.edu/plasma-wave/istp/polar/magnetosound.\
html"], None},
    ButtonStyle->"Hyperlink"]
}], "Text",
  CellTags->"i:58"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " For propagation that is not aligned with the magnetic field, the whistler \
wave dispersion relation is \n",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Omega]\  = \ \[CapitalOmega]\_c\ \
\(c\^\(\(2\)\(\ \)\)\) k\^2\ cos\ \[Theta]/\[Omega]\_p\^2\)\(,\)\)\)]],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\)]],
  " is the angle between ",
  Cell[BoxData[
      FormBox[
        StyleBox["k",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " and the magnetic field. Show that this dispersion relation implies that \
the angle  between the group velocity and the magnetic field is always less \
than ",
  Cell[BoxData[
      \(TraditionalForm\`19.5\ \[Degree]\)]],
  ". Hence, the earth's magnetic field guides these waves.  "
}], "Text"],

Cell[TextData[{
  StyleBox["(29)",
    FontWeight->"Bold"],
  " Using Fourier transforms find the Green's function for the following heat \
equation with anisotropic diffusion, in 2 dimensions:"
}], "Text"],

Cell[TextData[{
  " \t",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]T\/\[PartialD]t = 
        A\ \[PartialD]\^2 T\/\[PartialD]x\^2 + \ 
          B\ \[PartialD]\^2 T\/\(\[PartialD]x \[PartialD]y\) + 
          C \[PartialD]\^2 T\/\[PartialD]y\^2\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "Show that a bounded solution only exists provided that the diffusion \
coefficients ",
  Cell[BoxData[
      \(TraditionalForm\`A, \ B\ and\ C\)]],
  " satisfy ",
  Cell[BoxData[
      \(TraditionalForm\`4  A\ C\  - \ B\^2 > 0\)]],
  ". Such anisotropic diffusion can occur in crystals and in magnetized \
plasmas, for example. "
}], "Text"],

Cell[TextData[{
  StyleBox["(30)(a)",
    FontWeight->"Bold"],
  " A semiinfinite slab of material, with thermal diffusivity ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi]\)]],
  ",  runs from ",
  Cell[BoxData[
      \(TraditionalForm\`0 < x < \[Infinity]\)]],
  " and is initially at uniform temperature ",
  Cell[BoxData[
      \(TraditionalForm\`T\_0\)]],
  ". At time ",
  Cell[BoxData[
      \(TraditionalForm\`t = 0\)]],
  ", it is put in contact with a heat reservoir, setting the temperature at \
",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  " to be ",
  Cell[BoxData[
      \(TraditionalForm\`T(0, t)\  = T\_1\)]],
  ".  Use a Fourier sine transform to  show that the subsequent evolution of \
the temperature is given by \t\t\n\t",
  Cell[BoxData[
      \(TraditionalForm\`T(x, 
          t)\  = \ \((T\_0 - T\_1)\) \(erf(
              x/2 \@\( \[Pi]\ \[Chi]\ t\))\)\  + \ T\_1\)]],
  ", \nwhere ",
  Cell[BoxData[
      \(TraditionalForm\`erf(x)\)]],
  " is an error function. Plot in the ranges ",
  Cell[BoxData[
      \(TraditionalForm\`0 < x < 2\)]],
  " and  ",
  Cell[BoxData[
      \(TraditionalForm\`0.0001 < t < 1\)]],
  ", taking ",
  Cell[BoxData[
      \(TraditionalForm\`\[Chi]\  = \ \(T\_0 = 1\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`T\_1 = 0\)]],
  ". \n",
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Show that the temperature gradient at ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  " is given by ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[PartialD]T/\[PartialD]x\)\( | \_\(x = 
                0\)\)\) = \((T\_0 - T\_1)\)/\@\(\[Pi]\ \[Chi]\ t\)\)]],
  ". For ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(T\_0\), "=", 
            RowBox[{"2000", " ", 
              StyleBox["K",
                FontSlant->"Plain"]}]}], ",", " ", 
          RowBox[{\(T\_1\), "=", 
            RowBox[{"300", 
              StyleBox["K",
                FontSlant->"Plain"]}]}]}], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Chi]", " ", "=", " ", 
          RowBox[{\(2\[Cross]10\^\(-6\)\), " ", 
            RowBox[{
              SuperscriptBox[
                StyleBox["m",
                  FontSlant->"Plain"], "2"], "/", 
              StyleBox["s",
                FontSlant->"Plain"]}]}]}], TraditionalForm]]],
  ", find the time in years required for the gradient to relax to 0.03 K/m. \
Compare to the result obtained for the cooling of the earth in Chapter 4, \
Cell ",
  ButtonBox["4.49",
    ButtonData:>{"Chapter4.nb", "Cell 4.49"},
    ButtonStyle->"Hyperlink"],
  ". Explain in a few words why the results are almost identical. "
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["5.2 The WKB Method", "Subtitle",
  CellTags->{"i:66", "c:19"}],

Cell["", "Text"],

Cell[CellGroupData[{

Cell["5.2.1 WKB Analysis without Dispersion", "Subsubtitle",
  CellTags->"c:20"],

Cell[CellGroupData[{

Cell["The Eikonal", "Section",
  CellTags->{"i:67", "c:21"}],

Cell[TextData[{
  "\tSo far in this chapter we have considered systems that are ",
  StyleBox["homogeneous in space and time:",
    FontSlant->"Italic"],
  " their intrinsic properties such as wave speed ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  " or conductivity ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Kappa]\)\(\ \)\)\)]],
  "do not vary from place to place, or from instant to instant. As a \
consequence, Fourier transform techniques work to determine the solution.  In \
this section we consider systems that  are inhomogeneous, but slowly varying, \
in space or time.  The inhomogeneity is assumed to be  slowly varying in \
space on the scale of the wavelength of the waves that make up the solution; \
and slowly varying in time compared to the frequency of these waves."
}], "Text"],

Cell[TextData[{
  "\t   For such systems, the technique of WKB analysis allows us to \
determine analytic approximations to the solution. (WKB stands for G. \
Wentzel, H. Kramers, and ",
  ButtonBox["L. Brillouin",
    ButtonData:>{
      URL[ "http://scienceworld.wolfram.com/biography/BrillouinLeon.html"], 
      None},
    ButtonStyle->"Hyperlink"],
  ", who more or less independently discovered the theory. Several other \
researchers also made important contributions to its development, including \
",
  ButtonBox["H. Jeffreys",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Jeffreys.\
html"], None},
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["Lord Rayleigh",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Rayleigh.\
html"], None},
    ButtonStyle->"Hyperlink"],
  ".)"
}], "Text",
  CellTags->"i:128"],

Cell[TextData[{
  "\tAs a simple example,  consider a string under uniform tension ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  ", but for which the mass per unit length varies, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho] = \[Rho](x)\)]],
  ". Then the wave equation for this system is given by Eq. ",
  ButtonBox["(3.1.7)",
    ButtonData:>{"Chapter3.nb", "(3.1.7)"},
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text",
  CellTags->"i:106"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\^2 y\/\[PartialD]t\^2 = \(\(c\^2\)(
            x)\) \[PartialD]\^2 y\/\[PartialD]x\^2\)]],
  ","
}], "NE2",
  CellTags->"(5.2.1)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`c(x) = \@\(T/\(\[Rho](x)\)\)\)]],
  " is the propagation speed. This speed now varies with position on the \
string, so the solution for the string motion can no longer be written as a \
superposition of traveling waves of the form ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(\[ImaginaryI]\ \((k\ x - \[Omega]\
\ t)\)\)\)]],
  ". Rather, we will look for ",
  "traveling",
  "-wave solutions  of the more general form "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`y(x, 
          t) = \(\[ExponentialE]\^\(\(-i\)\ \[Omega]\ t\)\) \(\[Psi](
            x)\)\)]],
  ","
}], "NE2",
  CellTags->"(5.2.2)"],

Cell[TextData[{
  "where the function ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi](x)\)]],
  " provides the spatial dependence in the ",
  "traveling",
  " wave. Substituting Eq. ",
  ButtonBox["(5.2.2)",
    ButtonData:>"(5.2.2)",
    ButtonStyle->"Hyperlink"],
  " into Eq. ",
  ButtonBox["(5.2.1)",
    ButtonData:>"(5.2.1)",
    ButtonStyle->"Hyperlink"],
  " provides an ODE for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi](x)\)]],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\^2 \[Psi]\/\[PartialD]x\^2 = \(-\(\(k\^2\
\)(x)\)\)\ \(\[Psi](x)\)\)]],
  ","
}], "NE2",
  CellTags->"(5.2.3)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`k(x)\  = \ \ \[Omega]/\(c(x)\)\)]],
  " ."
}], "Text"],

Cell[TextData[{
  "\t If ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(k(x)\)\(\ \)\)\)]],
  " were constant, then the independent solutions of Eq. ",
  ButtonBox["(5.2.3)",
    ButtonData:>{"Chapter5.nb", "(5.2.3)"},
    ButtonStyle->"Hyperlink"],
  " would be ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(\(\[PlusMinus]\[ImaginaryI]\)\ k\ \
x\)\)]],
  " and we would refer to ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  " as the wavenumber of the waves. We will continue with this nomenclature, \
and refer to the  function ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(k(x)\)\(\ \)\)\)]],
  "as  the wavenumber, but now the solution will no longer be of the form ",
  Cell[BoxData[
      \(TraditionalForm\`\[ExponentialE]\^\(\(\[PlusMinus]\[ImaginaryI]\)\ k\ \
x\)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tTo find the solution, we introduce the ",
  StyleBox["eikonal",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`S(x)\)]],
  ", writing "
}], "Text",
  CellTags->"i:68"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Psi](x) = \[ExponentialE]\^\(S(x)\)\)]],
  "."
}], "NE2",
  CellTags->"(5.2.4)"],

Cell["The eikonal has real and imaginary parts:", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`S(x)\  = \ 
        ln\ \(A(x)\) + \ \(\(\[ImaginaryI]\)\(\ \)\(\[Phi](x)\)\(\ \)\)\)]],
  ". "
}], "NE2",
  CellTags->"(5.2.5)"],

Cell[TextData[{
  "Here, ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(A(x)\)\(\ \)\)\)]],
  " is the amplitude of the wave, and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](x)\)]],
  "is the phase, as may be seen when this form is substituted into Eq. ",
  ButtonBox["(5.2.4)",
    ButtonData:>"(5.2.4)",
    ButtonStyle->"Hyperlink"],
  ": ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi](
          x)\  = \ \(A(
            x)\)\ \[ExponentialE]\^\(\[ImaginaryI]\ \(\[Phi](x)\)\)\)]],
  ". Substituting Eq. ",
  ButtonBox["(5.2.4)",
    ButtonData:>"(5.2.4)",
    ButtonStyle->"Hyperlink"],
  "  into Eq. ",
  ButtonBox["(5.2.3)",
    ButtonData:>"(5.2.3)",
    ButtonStyle->"Hyperlink"],
  " yields a nonlinear ODE for ",
  Cell[BoxData[
      \(TraditionalForm\`S(x)\)]],
  ","
}], "Text",
  CellTags->"i:142"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\^2 S\/\[PartialD]x\^2 + \
\((\[PartialD]S\/\[PartialD]x)\)\^2 = \(-\(\(k\^2\)(x)\)\)\)]],
  "."
}], "NE2",
  CellTags->"(5.2.6)"],

Cell[TextData[{
  "\tSo far no approximations have been made. However,  it doesn't appear \
that we have made much progress: we have replaced a linear equation, Eq ",
  ButtonBox["(5.2.3)",
    ButtonData:>"(5.2.3)",
    ButtonStyle->"Hyperlink"],
  ", by a ",
  StyleBox["nonlinear",
    FontSlant->"Italic"],
  " equation, Eq. ",
  ButtonBox["(5.2.6)",
    ButtonData:>"(5.2.6)",
    ButtonStyle->"Hyperlink"],
  ".  Usually, nonlinear ODEs are much harder to solve than linear ones. But \
it turns out to be relatively easy to find  an",
  StyleBox[" approximate",
    FontSlant->"Italic"],
  " solution to Eq. ",
  ButtonBox["(5.2.6)",
    ButtonData:>"(5.2.6)",
    ButtonStyle->"Hyperlink"],
  ", by dropping one of the terms in the equation because it is smaller than \
the others. To determine the size of the terms, let us define a length scale \
",
  Cell[BoxData[
      \(TraditionalForm\`L(x)\)]],
  " for the spatial variation of ",
  Cell[BoxData[
      \(TraditionalForm\`k(x)\)]],
  " :"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`L(
          x)\  = \(\(\(|\)\(\ \)\(\(k(
                x)\)/\((\[DifferentialD]k/\[DifferentialD]x)\)\)\(|\)\) = \
\(\(|\)\(\((\[DifferentialD]\ 
                      ln\ \(k(
                        x)\)/\[DifferentialD]x\ )\)\^\(-1\)\)\(|\)\)\)\)]],
  "."
}], "NE2",
  CellTags->"(5.2.7)"],

Cell[TextData[{
  "We will assume that the wavelength of the wave in question, ",
  Cell[BoxData[
      \(TraditionalForm\`2 \(\( \[Pi]/\(k(x)\)\)\(\ \)\)\)]],
  ", is ",
  StyleBox["small compared to ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`L(x)\)]],
  ": ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(1/\(k(x)\)\), " ", 
          RowBox[{"<<", 
            FormBox[\(L(x)\),
              "TraditionalForm"]}]}], TraditionalForm]]],
  ". Let us define a small dimensionless parameter ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\)]],
  ", "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Epsilon]\)\(=\)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`1\/\(\(k(x)\)\ \(L(x)\)\)\)]],
  "<<1. "
}], "NE2",
  CellTags->"(5.2.8)"],

Cell[TextData[{
  "We will refer to the limit where the ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\)]],
  " is small as the ",
  StyleBox["WKB limit",
    FontSlant->"Italic"],
  "."
}], "Text",
  CellTags->"i:69"],

Cell[TextData[{
  "\tWe now determine the relative size of the terms in Eq. ",
  ButtonBox["(5.2.6)",
    ButtonData:>"(5.2.6)",
    ButtonStyle->"Hyperlink"],
  ". To do so, divide the equation by ",
  Cell[BoxData[
      \(TraditionalForm\`\(k\^2\)(x)\)]],
  ", and replace ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\^n\(\(/\)\(\[PartialD]x\^n\)\)\)]],
  " by ",
  Cell[BoxData[
      \(TraditionalForm\`1/L\^n\)]],
  ". The result is "
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Epsilon]\^2\) 
            S + \(\[Epsilon]\^\(\(2\)\(\ \)\)\) S\^2 = \(-1\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "This  equation is no longer strictly correct, and must be regarded as only \
a qualitative indicator of the relative size of terms. The idea is that ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\(\(/\)\(\[PartialD]x\)\)\)]],
  " is ",
  StyleBox["on the order of ",
    FontSlant->"Italic"],
  Cell[BoxData[
      \(TraditionalForm\`1/L\)],
    FontSlant->"Italic"],
  ". After determining the small term(s), we can go back to using the correct \
equation and then drop the small term(s) to get an approximate solution. "
}], "Text"],

Cell[TextData[{
  "\tWhich term(s)  are small?  Sometimes that is obvious, but not in this \
case.  It appears that both terms on the ",
  "left-hand",
  " side are small because they are multiplied by ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\^2\)]],
  ", but it is best not to  make any assumptions about the size of ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  ". Instead, we will systematically assume that each term in the equation is \
small, drop that term, solve for ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(S\)\(,\)\)\)]],
  " and then see if our assumption is consistent with the solution for ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  ". This trial-and-error method is called ",
  StyleBox["finding the",
    FontSlant->"Italic"],
  " ",
  StyleBox["dominant balance ",
    FontSlant->"Italic"],
  "between terms in the equation. "
}], "Text",
  CellTags->"i:70"],

Cell[TextData[{
  "\tIf we assume that ",
  Cell[BoxData[
      \(TraditionalForm\`\(-1\)\)]],
  "  is the small term, and drop ",
  Cell[BoxData[
      \(TraditionalForm\`\(-1\)\)]],
  ", then we are left with the equation ",
  Cell[BoxData[
      \(TraditionalForm\`S\^2 = \(-S\)\)]],
  ", which has the \"solutions\" ",
  Cell[BoxData[
      \(TraditionalForm\`S = 0\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`S = \(-1\)\)]],
  ". [These are not the actual solutions for ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(S(x)\)\(,\)\)\)]],
  " which must follow from Eq. ",
  ButtonBox["(5.2.6)",
    ButtonData:>"(5.2.6)",
    ButtonStyle->"Hyperlink"],
  ". Rather, they only provide the order of magnitude of ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  ".] However, these solutions aren't consistent with dropping ",
  Cell[BoxData[
      \(TraditionalForm\`\(-1\)\)]],
  ", because ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Epsilon]\^2\) 
          S + \(\[Epsilon]\^\(\(2\)\(\ \)\)\) S\^2\)]],
  " is then small compared to ",
  Cell[BoxData[
      \(TraditionalForm\`\(-1\)\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tIf we instead assume ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Epsilon]\^2\) S\^2\)]],
  "is the small term, we obtain the equation ",
  Cell[BoxData[
      \(TraditionalForm\`S = \(-1\)/\[Epsilon]\^2\)]],
  ". However, this implies that ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Epsilon]\^\(\(2\)\(\ \)\)\) S\^2 = 
        1/\[Epsilon]\^2\)]],
  ", which is even larger than the terms we kept, so this also is not a \
consistent approximation. "
}], "Text"],

Cell[TextData[{
  "\tWe are therefore left with ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          FormBox[\(\(\[Epsilon]\^2\) S\),
            "TraditionalForm"]}], TraditionalForm]]],
  " as the small term. Dropping this term, we obtain ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Epsilon]\^\(\(2\)\(\ \)\)\) S\^2 = \(-1\)\)]],
  " which yields ",
  Cell[BoxData[
      FormBox[
        RowBox[{"S", "=", Cell["\[PlusMinus]\[ImaginaryI] / \[Epsilon]"]}], 
        TraditionalForm]]],
  ". Then the term we dropped, ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Epsilon]\^2\) S\)]],
  ", equals ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[PlusMinus]\[ImaginaryI]\)\ \[Epsilon]\)]],
  ", which ",
  StyleBox["is",
    FontSlant->"Italic"],
  " in fact  small compared to either of the other terms that we kept. \
Therefore, ",
  StyleBox["this",
    FontSlant->"Italic"],
  " is a consistent approximation.  We have found the dominant balance \
between the terms in the equation: ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Epsilon]\^\(\(2\)\(\ \)\)\) S\^2\)]],
  " balances ",
  Cell[BoxData[
      \(TraditionalForm\`\(-1\)\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Epsilon]\^2\) S\)]],
  " is a small correction to this dominant balance."
}], "Text"],

Cell[TextData[{
  "\t  We have found that the eikonal ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  " is large, scaling as ",
  Cell[BoxData[
      \(TraditionalForm\`1/\[Epsilon]\)]],
  ". This reflects the fact that in the WKB limit,  over a distance of order \
",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " there must be many wavelengths in ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\)]],
  " . The phase ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " must vary by a large amount over this distance."
}], "Text"],

Cell[TextData[{
  "\tReturning now to the exact equation, Eq. ",
  ButtonBox["(5.2.6)",
    ButtonData:>"(5.2.6)",
    ButtonStyle->"Hyperlink"],
  ", we drop the small term ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\^2 S/\[PartialD]x\^2\)]],
  "to obtain an approximate solution for ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  ". Let us call the result the zeroth approximation for ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  ",   ",
  Cell[BoxData[
      \(TraditionalForm\`S = S\_0\)]],
  ", where"
}], "Text"],

Cell[TextData[{
  "\t\t ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[PartialD]S\_0\/\[PartialD]x)\)\^2 = \(-\(\(k\^2\
\)(x)\)\)\)]],
  "."
}], "Text"],

Cell["This equation has the solution", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(S\_0\)(x) = 
        B \[PlusMinus] \[ImaginaryI] \(\[Integral]\^x\( k(
                  x)\) \[DifferentialD]x\)\)]],
  ","
}], "NE2",
  CellTags->"(5.2.9)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`B\)]],
  " is a constant of integration. Comparing with Eq. ",
  ButtonBox["(5.2.5)",
    ButtonData:>"(5.2.5)",
    ButtonStyle->"Hyperlink"],
  ",  we have found that  to lowest-order in ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\)]],
  " the amplitude is constant and the phase is ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](
          x)\  = \ \(\[PlusMinus]\(\[Integral]\^x\( k(
                x)\) \[DifferentialD]x\)\)\)]],
  ".  Since the wavenumber ",
  Cell[BoxData[
      \(TraditionalForm\`k(x)\)]],
  " now varies with position, phase accumulates according to Eq. ",
  ButtonBox["(5.2.9)",
    ButtonData:>"(5.2.9)",
    ButtonStyle->"Hyperlink"],
  " rather than merely as ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[PlusMinus]k\)\ x\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\tWe will now confirm that ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(|\)\(\[PartialD]\^2 
            S/\[PartialD]x\^2\)\(|\)\(<< \(\(|\)\(\[PartialD]S/\[PartialD]x\)\
\( | \^2\)\)\)\)\)]],
  " in the WKB limit. Comparing ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\^2 S\_0/\[PartialD]x\^2\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[PartialD]S\_0/\[PartialD]x)\)\^2\)]],
  " using Eq. ",
  ButtonBox["(5.2.9)",
    ButtonData:>"(5.2.9)",
    ButtonStyle->"Hyperlink"],
  ", we have ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(|\)\(\[PartialD]S\_0/\[PartialD]x\)\( | \^2\)\) \
= k\^2\)]],
  "and ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\(|\)\(\[PartialD]\^2 S\_0/\[PartialD]x\^2\)\(|\)\), " ", 
          "=", " ", 
          RowBox[{"|", \(\[PartialD]k/\[PartialD]x\), "|", 
            RowBox[{\(\(\(~\)\(k\)\)/L\), Cell[""]}]}]}], TraditionalForm]]],
  ", so "
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(\(|\)\(\(\[PartialD]\^2 \
S\_0\/\[PartialD]x\^2\)/\((\[PartialD]S\_0\/\[PartialD]x)\)\^2\)\(|\)\(\(~\)\(\
\(|\)\(\(1\/k\^2\) \(\(\ \)\(k\)\)\/\(\(L\)\(\ \)\)\)\(|\)\)\)\) = \[Epsilon] \
<< 1\)]],
  ","
}], "Text"],

Cell[TextData[{
  " where the inequality follows directly from Eq. ",
  ButtonBox["(5.2.8)",
    ButtonData:>"(5.2.8)",
    ButtonStyle->"Hyperlink"],
  ".  Therefore, Eq. ",
  ButtonBox["(5.2.9)",
    ButtonData:>"(5.2.9)",
    ButtonStyle->"Hyperlink"],
  " is a consistent approximate solution to Eq. ",
  ButtonBox["(5.2.3)",
    ButtonData:>"(5.2.3)",
    ButtonStyle->"Hyperlink"],
  " in the WKB limit."
}], "Text"],

Cell[TextData[{
  "\tEquation ",
  ButtonBox["(5.2.9)",
    ButtonData:>"(5.2.9)",
    ButtonStyle->"Hyperlink"],
  ", along with Eq. ",
  ButtonBox["(5.2.4)",
    ButtonData:>"(5.2.4)",
    ButtonStyle->"Hyperlink"],
  " , provides us with (approximations to) the two independent solutions to \
Eq. ",
  ButtonBox["(5.2.3)",
    ButtonData:>"(5.2.3)",
    ButtonStyle->"Hyperlink"],
  ", which when superimposed provide an approximate general solution for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi](x)\)]],
  " "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Psi](x)\  = \ 
        C\ \[ExponentialE]\^\(\(\ \)\(\[ImaginaryI]\ \(\[Integral]\^x\( \
k(x)\) \(\(\[DifferentialD]x\)\(\ \)\)\)\)\) + \ \(\(D\)\(\ \)\(\
\[ExponentialE]\^\(\(\ \)\(\(-\ \[ImaginaryI]\)\ \(\[Integral]\^x\( k(
                        x)\) \(\(\[DifferentialD]x\)\(\ \)\)\)\)\)\)\(\ \
\)\)\)]],
  "."
}], "NE2",
  CellTags->"(5.2.10)"],

Cell[TextData[{
  "Using Eq. ",
  ButtonBox["(5.2.10)",
    ButtonData:>"(5.2.10)",
    ButtonStyle->"Hyperlink"],
  "  in Eq. ",
  ButtonBox["(5.2.2)",
    ButtonData:>"(5.2.2)",
    ButtonStyle->"Hyperlink"],
  ", we have for ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(y(x, t)\)\(\ \)\)\)]],
  "a left and right propagating  wave,"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`y(x, t)\  \[TildeEqual] \ 
      C\ \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Omega]\ t\  + \ \
\[ImaginaryI]\ \(\[Integral]\^x\( k(x)\) \(\(\[DifferentialD]x\)\(\ \)\)\)\) \
+ \ D\ \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Omega]\ t\  - \ \[ImaginaryI]\
\ \(\[Integral]\^x\( k(x)\) \(\(\[DifferentialD]x\)\(\ \)\)\)\)\)]]], "NE2",
  CellTags->"(5.2.11)"],

Cell[TextData[{
  "These waves are generalizations of ",
  "traveling",
  " waves of the form ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\(\ \
\)\((\[Omega]\ t\  \[PlusMinus] k\ x)\)\(\ \)\)\)\)\)]],
  ", encountered previously in the description of waves in a homogeneous \
system. \n\tHowever, Eq. ",
  ButtonBox["(5.2.10)",
    ButtonData:>"(5.2.10)",
    ButtonStyle->"Hyperlink"],
  " is a rather crude approximation to the exact solution of Eq. ",
  ButtonBox["(5.2.3)",
    ButtonData:>"(5.2.3)",
    ButtonStyle->"Hyperlink"],
  ".  We will now improve on the solution by first rewriting the exact \
equation for ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  ", Eq. ",
  ButtonBox["(5.2.6)",
    ButtonData:>"(5.2.6)",
    ButtonStyle->"Hyperlink"],
  ", as "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\((\[PartialD]S\/\[PartialD]x)\)\^2 = \(-\(\(k\^2\)(
              x)\)\)\  - \[Lambda] \[PartialD]\^2 S\/\[PartialD]x\^2\)]],
  ","
}], "NE2",
  CellTags->"(5.2.12)"],

Cell[TextData[{
  "We have placed an ",
  StyleBox["ordering parameter",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\)]],
  " in front of the small term ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\^2 S\/\[PartialD]x\^2\)]],
  "  in order to remind us that this term is small, of order ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\)]],
  ",  compared to the other terms.  This allows us to keep track of small \
terms in the following calculation. We can even expand our solutions in \
powers of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\)]],
  ", since this is equivalent to expanding in powers of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\)]],
  ".  However, when we are finished,  we will set ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda] = 1\)]],
  ". This is a bookkeeping device that allows us to identify small terms at a \
glance, and easily perform Taylor expansions in powers of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tPreviously, we found  ",
  Cell[BoxData[
      \(TraditionalForm\`S\_0\)]],
  " by dropping the ",
  Cell[BoxData[
      FormBox[Cell[TextData[Cell[BoxData[
            \(TraditionalForm\`\[Lambda]\)]]]], TraditionalForm]]],
  "-term altogether. Let us call an improvement to this solution ",
  Cell[BoxData[
      \(TraditionalForm\`S = S\_1\)]],
  ".  To obtain an equation for ",
  Cell[BoxData[
      \(TraditionalForm\`S\_1\)]],
  " we rewrite ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda] \[PartialD]\^2 S\/\[PartialD]x\^2\)]],
  " as ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda] \[PartialD]\^2 S\/\[PartialD]x\^2 = \
\[Lambda] \[PartialD]\^2 S\_0\/\[PartialD]x\^2 + \[Lambda] \[PartialD]\^2\((S \
- S\_0)\)\/\[PartialD]x\^2\)]],
  " . However, in the WKB limit we expect that ",
  Cell[BoxData[
      \(TraditionalForm\`S - S\_0\)]],
  "  will be small, so that  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda] \[PartialD]\^2\((S - S\_0)\)\/\[PartialD]x\
\^2\)]],
  " is a small correction to the small correction, and so we drop this term. \
Then Eq. ",
  ButtonBox["(5.2.12)",
    ButtonData:>"(5.2.12)",
    ButtonStyle->"Hyperlink"],
  " becomes"
}], "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[PartialD]S\_1\/\[PartialD]x)\)\^2 = \(-\(\(k\^2\
\)(x)\)\)\  - \[Lambda] \[PartialD]\^2 S\_0\/\[PartialD]x\^2\)]],
  "."
}], "NE2",
  CellTags->"(5.2.13)"],

Cell[TextData[{
  "Furthermore, since we already know ",
  Cell[BoxData[
      \(TraditionalForm\`S\_0\)]],
  " from Eq. ",
  ButtonBox["(5.2.9)",
    ButtonData:>"(5.2.9)",
    ButtonStyle->"Hyperlink"],
  ", this equation can be solved for ",
  Cell[BoxData[
      \(TraditionalForm\`S\_1\)]],
  ". The result is "
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(S\_1\)(x)\  = \ 
        B \[PlusMinus] 
          i \(\[Integral]\^x\( k(
                  x)\) \(\@\(1\  + \ \(\[Lambda]\/\(\(k\^2\)(
                              x)\)\) \[PartialD]\^2 S\_0\/\[PartialD]x\^2\)\) \
\[DifferentialD]x\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "We can simplify the square root by noting that  the ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\)]],
  " term is small, of order ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\)]],
  ". A first-order Taylor expansion in ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\)]],
  " yields"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\(S\_1\)(x)\), " ", "=", " ", 
          
          RowBox[{\(\(B\  \[PlusMinus] 
                i \(\[Integral]\^x\( k(
                        x)\) \[DifferentialD]x\)\)\  \[PlusMinus] \
\[ImaginaryI]\ \(\[Lambda]\/2\) \(\[Integral]\^x\( 
                        1\/\(k(
                          x)\)\) \(\[PartialD]\^2 S\_0\/\[PartialD]x\^2\) \
\[DifferentialD]x\)\), "+", 
            RowBox[{"0", 
              RowBox[{"(", 
                FormBox[\(\[Lambda]\^2\),
                  "TraditionalForm"], ")"}]}]}]}], TraditionalForm]]],
  ". "
}], "Text"],

Cell[TextData[{
  "Also, we can perform the second integral analytically by substituting for \
",
  Cell[BoxData[
      \(TraditionalForm\`S\_0\)]],
  "using Eq. ",
  ButtonBox["(5.2.9)",
    ButtonData:>"(5.2.9)",
    ButtonStyle->"Hyperlink"],
  " , yielding"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\^x\( 
              1\/\(k(x)\)\) \(\[PartialD]\^2 S\_0\/\[PartialD]x\^2\) \
\[DifferentialD]x\)]],
  "=",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\^x\(\(\[PlusMinus]\[ImaginaryI]\)\/\(k(
                  x)\)\) \(\[PartialD]k\/\[PartialD]x\) \[DifferentialD]x = \
\(\[PlusMinus]\[ImaginaryI]\)\ \(log(k(x))\)\)]],
  ". \nTherefore, we obtain"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(S\_1\)(
          x) = \(B\  \[PlusMinus] 
            i \(\[Integral]\^x\( k(
                    x)\) \[DifferentialD]x\)\) - \(\[Lambda]\/2\) \(log(
              k(x))\) + 0 \((\[Lambda]\^2)\)\)]],
  ". "
}], "NE2",
  CellTags->"(5.2.14)"],

Cell[TextData[{
  "Setting ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda] = 1\)]],
  ", and using this improved approximation for ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  " in  ",
  ButtonBox["(5.2.4)",
    ButtonData:>"(5.2.4)",
    ButtonStyle->"Hyperlink"],
  ",  we find that the ",
  Cell[BoxData[
      \(TraditionalForm\`\(1\/2\) \(log(k(x))\)\)]],
  "  term has the effect of causing the amplitude of the wave to vary with \
position, according to"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Psi](
          x) = \(\[ExponentialE]\^\(\(\[PlusMinus]i\) \(\[Integral]\^x\( k(x)\
\) \[DifferentialD]x\)\  + \ B\  + \ log\ \(k(x)\)\^\(\(-1\)/2\)\) = \(\
\[ExponentialE]\^\(\(B\)\(\ \)\)\) \[ExponentialE]\^\(\(\[PlusMinus]i\) \(\
\[Integral]\^x\( k(x)\) \[DifferentialD]x\)\)/\(\(\@\(k(x)\)\)\(.\)\)\)\)]],
  " "
}], "NE2",
  CellTags->"(5.2.15)"],

Cell[TextData[{
  "Therefore, in the WKB limit we have the following traveling wave solution \
to Eq. ",
  ButtonBox["(5.2.1)",
    ButtonData:>"(5.2.1)",
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`y(x, t)\  \[TildeEqual] \ 
        C\/\@\(k(x)\)\ \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Omega]\ t\  + \
\ \[ImaginaryI]\ \(\[Integral]\^x\( k(x)\) \(\(\[DifferentialD]x\)\(\ \
\)\)\)\) + \ 
          D\/\@\(k(x)\)\ \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Omega]\ t\  \
- \ \[ImaginaryI]\ \(\[Integral]\^x\( k(x)\) \(\(\[DifferentialD]x\)\(\ \
\)\)\)\)\)]],
  " ."
}], "NE2",
  CellTags->"(5.2.16)"],

Cell[TextData[{
  "This is a much better approximation to the exact solution than Eq.  ",
  ButtonBox["(5.2.11)",
    ButtonData:>"(5.2.11)",
    ButtonStyle->"Hyperlink"],
  ", because it has amplitude variation that is missing in Eq. ",
  ButtonBox["(5.2.11)",
    ButtonData:>"(5.2.11)",
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text"],

Cell[TextData[{
  "\tHowever, Eq. ",
  ButtonBox["(5.2.16)",
    ButtonData:>"(5.2.16)",
    ButtonStyle->"Hyperlink"],
  " is  also only an approximate solution to Eq. ",
  ButtonBox["(5.2.1)",
    ButtonData:>"(5.2.1)",
    ButtonStyle->"Hyperlink"],
  ", valid only in the WKB limit ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon] << 1\)]],
  ".   One could, if one wished, further improve the solution. Defining the \
",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  "th approximation to the solution  as ",
  Cell[BoxData[
      \(TraditionalForm\`S\_n\)]],
  ", we  replace Eq. ",
  ButtonBox["(5.2.13)",
    ButtonData:>"(5.2.13)",
    ButtonStyle->"Hyperlink"],
  " by a ",
  StyleBox["recursion relation ",
    FontSlant->"Italic"],
  ","
}], "Text",
  CellTags->"i:96"],

Cell[TextData[{
  "\t\t ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[PartialD]S\_n\/\[PartialD]x)\)\^2 = \(-\(\(k\^2\
\)(x)\)\)\  - \[Lambda] \[PartialD]\^2 S\_\(n - 1\)\/\[PartialD]x\^2\)]],
  "."
}], "NE2",
  CellTags->"(5.2.17)"],

Cell[TextData[{
  " For instance, we could obtain ",
  Cell[BoxData[
      \(TraditionalForm\`S\_2\)]],
  "by using ",
  Cell[BoxData[
      \(TraditionalForm\`S\_1\)]],
  " in the right-hand side of Eq. ",
  ButtonBox["(5.2.15)",
    ButtonData:>"(5.2.15)",
    ButtonStyle->"Hyperlink"],
  ". We could then use that form on the ",
  "right-hand",
  " side to obtain ",
  Cell[BoxData[
      \(TraditionalForm\`S\_3\)]],
  ", and so on. The hope is that the resulting approximants converge so that \
for ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " large,",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[PartialD]\^2 S\_\(n - 1\)\/\[PartialD]x\^2\)\(\
\[Rule]\)\(\[PartialD]\^2 S\_n\/\[PartialD]x\^2\)\(\ \)\)\)]],
  " and Eq. ",
  ButtonBox["(5.2.17)",
    ButtonData:>"(5.2.17)",
    ButtonStyle->"Hyperlink"],
  "  becomes the same as Eq. ",
  ButtonBox["(5.2.12)",
    ButtonData:>"(5.2.12)",
    ButtonStyle->"Hyperlink"],
  ", so that we are obtaining the exact solution for ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  " in the limit."
}], "Text",
  CellTags->"i:71"],

Cell[TextData[{
  "\tAt each stage in the recursion, we can Taylor expand ",
  Cell[BoxData[
      \(TraditionalForm\`S\_n\)]],
  " in ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\)]],
  " to the appropriate order so as to obtain the simplest possible analytic \
result. In fact, one can automate this procedure quite easily, since \
evaluating recursion relations  and performing Taylor expansions are just the \
sort of things at which ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  " excels. We do so below, defining a function ",
  StyleBox["Sp[n,x]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", which is ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]S\_n/\[PartialD]x\)]],
  ". According to Eq. ",
  ButtonBox["(5.2.17)",
    ButtonData:>"(5.2.17)",
    ButtonStyle->"Hyperlink"],
  ","
}], "Text"],

Cell[BoxData[
    \(\(Sp[n_, x_]\  := 
        Sqrt[\(-k[x]^2\)\  - \ \[Lambda]\ D[Sp[n - 1, x], x]];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 5.12"],

Cell["\<\
(one could also choose a negative sign in front of the square root \
to obtain a second solution). For the initial condition in this recursion \
relation, we take \
\>", "Text"],

Cell[BoxData[
    \(\(Sp[0, x_]\  := \ Sqrt[\(-\ k[x]^2\)];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 5.13"],

Cell["\<\
Then we can ask for the result at any order. For instance, at \
second-order,\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Sp[2, x]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 5.14"],

Cell[BoxData[
    SqrtBox[
      RowBox[{\(-k[x]\^2\), "-", 
        FractionBox[
          RowBox[{"\[Lambda]", " ", 
            RowBox[{"(", 
              RowBox[{
                RowBox[{\(-2\), " ", \(k[x]\), " ", 
                  RowBox[{
                    SuperscriptBox["k", "\[Prime]",
                      MultilineFunction->None], "[", "x", "]"}]}], "+", 
                FractionBox[
                  RowBox[{"\[Lambda]", " ", \(k[x]\^2\), " ", 
                    SuperscriptBox[
                      RowBox[{
                        SuperscriptBox["k", "\[Prime]",
                          MultilineFunction->None], "[", "x", "]"}], 
                      "2"]}], \(\((\(-k[x]\^2\))\)\^\(3/2\)\)], "+", 
                FractionBox[
                  RowBox[{"\[Lambda]", " ", 
                    SuperscriptBox[
                      RowBox[{
                        SuperscriptBox["k", "\[Prime]",
                          MultilineFunction->None], "[", "x", "]"}], 
                      "2"]}], \(\@\(-k[x]\^2\)\)], "+", 
                FractionBox[
                  RowBox[{"\[Lambda]", " ", \(k[x]\), " ", 
                    RowBox[{
                      SuperscriptBox["k", "\[Prime]\[Prime]",
                        MultilineFunction->None], "[", "x", 
                      "]"}]}], \(\@\(-k[x]\^2\)\)]}], ")"}]}], 
          RowBox[{"2", " ", 
            SqrtBox[
              RowBox[{\(-k[x]\^2\), "+", 
                FractionBox[
                  RowBox[{"\[Lambda]", " ", \(k[x]\), " ", 
                    RowBox[{
                      SuperscriptBox["k", "\[Prime]",
                        MultilineFunction->None], "[", "x", 
                      "]"}]}], \(\@\(-k[x]\^2\)\)]}]]}]]}]]], "Output"]
}, Open  ]],

Cell[TextData[{
  "This is very messy, but can be simplified by noting that it is correct \
only to second-order in ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\)]],
  ". Therefore, we can Taylor-expand in ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\)]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(Expand[
      Simplify[Normal[Series[%, {\[Lambda], 0, 2}]], k[x] > 0]]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 5.15"],

Cell[BoxData[
    RowBox[{\(\[ImaginaryI]\ k[x]\), "-", 
      FractionBox[
        RowBox[{"\[Lambda]", " ", 
          RowBox[{
            SuperscriptBox["k", "\[Prime]",
              MultilineFunction->None], "[", "x", "]"}]}], \(2\ k[x]\)], "+", 
      
      FractionBox[
        RowBox[{"3", " ", "\[ImaginaryI]", " ", \(\[Lambda]\^2\), " ", 
          SuperscriptBox[
            RowBox[{
              SuperscriptBox["k", "\[Prime]",
                MultilineFunction->None], "[", "x", "]"}], 
            "2"]}], \(8\ k[x]\^3\)], "-", 
      FractionBox[
        RowBox[{"\[ImaginaryI]", " ", \(\[Lambda]\^2\), " ", 
          RowBox[{
            SuperscriptBox["k", "\[Prime]\[Prime]",
              MultilineFunction->None], "[", "x", 
            "]"}]}], \(4\ k[x]\^2\)]}]], "Output"]
}, Open  ]],

Cell[TextData[{
  " This is the derivative of the second-order approximant, ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]S\_2/\[PartialD]x\)]],
  ".  It contains the contributions from ",
  Cell[BoxData[
      \(TraditionalForm\`S\_1\)]],
  " given by Eq. ",
  ButtonBox["(5.2.14)",
    ButtonData:>"(5.2.14)",
    ButtonStyle->"Hyperlink"],
  " as well as two correction terms of order ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\^2\)]],
  ". It is easy to continue this process and obtain even higher",
  "-order",
  " corrections. "
}], "Text"],

Cell[TextData[{
  "\t More often than not, however, the approximants do ",
  StyleBox["not ",
    FontSlant->"Italic"],
  " converge as ",
  Cell[BoxData[
      \(TraditionalForm\`n \[Rule] \ \[Infinity]\)]],
  "; instead, they converge for a time, and then begin to diverge as ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(n\)\(\ \)\)\)]],
  "increases past some value that depends on the size of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\)]],
  ". This is typical behavior for ",
  StyleBox["asymptotic",
    FontSlant->"Italic"],
  StyleBox[" ",
    FontSlant->"Italic"],
  StyleBox["expansions",
    FontSlant->"Italic"],
  ", of which WKB solutions are an important case. [Some examples of this \
behavior are considered in the exercises. Readers interested in learning more \
about asymptotic expansions are referred to the book by ",
  ButtonBox["Bender and Orzag (1978)",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  ".] Nevertheless, if ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\)]],
  " is sufficiently small, the WKB solution ",
  Cell[BoxData[
      \(TraditionalForm\`S\_1\)]],
  " is usually a reasonably good approximation.  We will not bother with the \
higher-order approximants for ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  " here, because they become more and more complicated in form, and make \
only minor corrections to Eq. ",
  ButtonBox["(5.2.16)",
    ButtonData:>"(5.2.16)",
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text",
  CellTags->"i:140"]
}, Closed]],

Cell[CellGroupData[{

Cell["Example: Waves on a String with Varying Mass Density.", "Section",
  CellTags->{"i:72", "c:22"}],

Cell[TextData[{
  " \tAs a simple example of  traveling wave solutions in an inhomogeneous \
system, let us consider the case where the string mass varies as ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho](x) = \[Rho]\_o\ \[ExponentialE]\^\(x/L\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`\ \)]],
  "(i.e. the string gets exponentially heavier as one moves to the right).  \
Then the wave speed obeys ",
  Cell[BoxData[
      \(TraditionalForm\`c(
          x) = \(\@\(T/\(\[Rho](x)\)\) = \(c\_o\) \
\[ExponentialE]\^\(\(-x\)/\((2  L)\)\)\)\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`c\_o = \@\(T/\[Rho]\_o\)\)]],
  " is the wave speed at ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  ",  and the local wavenumber varies with position as ",
  Cell[BoxData[
      \(TraditionalForm\`k(
          x) = \[Omega]\ \[ExponentialE]\^\(x/\((2  L)\)\)/c\_o\)]],
  ". This implies that phase in the wave accumulates according to ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\^x\( k(x)\) \[DifferentialD]x\)]],
  "=",
  Cell[BoxData[
      \(TraditionalForm\`\(\(2 | \[Omega] | \ 
              L\)\/c\_o\) \[ExponentialE]\^\(x/\((2  L)\)\)\)]],
  " and so the ",
  "traveling",
  " wave solution is "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`y(x, t)\  \[TildeEqual] \ 
        C\/\(\(\[ExponentialE]\)\(\ \)\)\^\(x/\((4  L)\)\)\ \[ExponentialE]\^\
\(\(-\[ImaginaryI]\ [\ \[Omega]\ t\  - \ \(\(2 | \[Omega] | \ L\)\/c\_o\) \
\[ExponentialE]\^\(x/\((2  L)\)\)\ ]\)\(\ \)\) + \ 
          D\/\(\(\[ExponentialE]\)\(\ \)\)\^\(x/\((4  L)\)\)\ \[ExponentialE]\
\^\(\(-\[ImaginaryI]\ [\ \[Omega]\ t\  + \ \(\(2 | \[Omega] | \ L\)\/c\_o\) \
\[ExponentialE]\^\(x/\((2  L)\)\)\ ]\)\(\ \)\)\)]],
  " ."
}], "NE2",
  CellTags->"(5.2.18)"],

Cell[TextData[{
  "The real part of this solution is plotted in Cell ",
  ButtonBox["5.16",
    ButtonData:>"Cell 5.16",
    ButtonStyle->"Hyperlink"],
  ", taking ",
  Cell[BoxData[
      \(TraditionalForm\`D = 0\)]],
  " (i.e. the wave propagates to the right), and ",
  Cell[BoxData[
      \(TraditionalForm\`c\_o = \(\[Omega] = 1\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`L = 5\)]],
  Cell[BoxData[
      FormBox["", TraditionalForm]]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(y[x_, t_]\  = \ 
        1\/\(\(\[ExponentialE]\)\(\ \)\)\^\(x/\((4  L)\)\)\ \[ExponentialE]\^\
\(\(-\[ImaginaryI]\)\(\ \)\((\ \[Omega]\ t\  - \ \(\(2  \[Omega]\ L\)\/c\_o\) \
\[ExponentialE]\^\(x/\((2  L)\)\)\ )\)\(\ \)\) /. {c\_o \[Rule] 1, 
            L \[Rule] 5, \[Omega] \[Rule] 1};\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(Table[
        Plot[Re[y[x, t]], {x, \(-4\), 20}, PlotRange \[Rule] {\(-1\), 1}, 
          AxesLabel \[Rule] {"\<x\>", "\<y\>"}], {t, 0, 
          1.8  Pi,  .2  Pi}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 5.16"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.18254 0.0396825 0.309017 0.309017 [
[.38095 .29652 -3 -9 ]
[.38095 .29652 3 0 ]
[.57937 .29652 -6 -9 ]
[.57937 .29652 6 0 ]
[.77778 .29652 -6 -9 ]
[.77778 .29652 6 0 ]
[.97619 .29652 -6 -9 ]
[.97619 .29652 6 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.17004 0 -12 -4.5 ]
[.17004 0 0 4.5 ]
[.17004 .07725 -30 -4.5 ]
[.17004 .07725 0 4.5 ]
[.17004 .15451 -24 -4.5 ]
[.17004 .15451 0 4.5 ]
[.17004 .23176 -30 -4.5 ]
[.17004 .23176 0 4.5 ]
[.17004 .38627 -24 -4.5 ]
[.17004 .38627 0 4.5 ]
[.17004 .46353 -18 -4.5 ]
[.17004 .46353 0 4.5 ]
[.17004 .54078 -24 -4.5 ]
[.17004 .54078 0 4.5 ]
[.17004 .61803 -6 -4.5 ]
[.17004 .61803 0 4.5 ]
[.18254 .64303 -5 0 ]
[.18254 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.38095 .30902 m
.38095 .31527 L
s
[(5)] .38095 .29652 0 1 Mshowa
.57937 .30902 m
.57937 .31527 L
s
[(10)] .57937 .29652 0 1 Mshowa
.77778 .30902 m
.77778 .31527 L
s
[(15)] .77778 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(20)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.22222 .30902 m
.22222 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30159 .30902 m
.30159 .31277 L
s
.34127 .30902 m
.34127 .31277 L
s
.42063 .30902 m
.42063 .31277 L
s
.46032 .30902 m
.46032 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.53968 .30902 m
.53968 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.65873 .30902 m
.65873 .31277 L
s
.69841 .30902 m
.69841 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.81746 .30902 m
.81746 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.89683 .30902 m
.89683 .31277 L
s
.93651 .30902 m
.93651 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.10317 .30902 m
.10317 .31277 L
s
.06349 .30902 m
.06349 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.18254 0 m
.18879 0 L
s
[(-1)] .17004 0 1 0 Mshowa
.18254 .07725 m
.18879 .07725 L
s
[(-0.75)] .17004 .07725 1 0 Mshowa
.18254 .15451 m
.18879 .15451 L
s
[(-0.5)] .17004 .15451 1 0 Mshowa
.18254 .23176 m
.18879 .23176 L
s
[(-0.25)] .17004 .23176 1 0 Mshowa
.18254 .38627 m
.18879 .38627 L
s
[(0.25)] .17004 .38627 1 0 Mshowa
.18254 .46353 m
.18879 .46353 L
s
[(0.5)] .17004 .46353 1 0 Mshowa
.18254 .54078 m
.18879 .54078 L
s
[(0.75)] .17004 .54078 1 0 Mshowa
.18254 .61803 m
.18879 .61803 L
s
[(1)] .17004 .61803 1 0 Mshowa
.125 Mabswid
.18254 .01545 m
.18629 .01545 L
s
.18254 .0309 m
.18629 .0309 L
s
.18254 .04635 m
.18629 .04635 L
s
.18254 .0618 m
.18629 .0618 L
s
.18254 .09271 m
.18629 .09271 L
s
.18254 .10816 m
.18629 .10816 L
s
.18254 .12361 m
.18629 .12361 L
s
.18254 .13906 m
.18629 .13906 L
s
.18254 .16996 m
.18629 .16996 L
s
.18254 .18541 m
.18629 .18541 L
s
.18254 .20086 m
.18629 .20086 L
s
.18254 .21631 m
.18629 .21631 L
s
.18254 .24721 m
.18629 .24721 L
s
.18254 .26266 m
.18629 .26266 L
s
.18254 .27812 m
.18629 .27812 L
s
.18254 .29357 m
.18629 .29357 L
s
.18254 .32447 m
.18629 .32447 L
s
.18254 .33992 m
.18629 .33992 L
s
.18254 .35537 m
.18629 .35537 L
s
.18254 .37082 m
.18629 .37082 L
s
.18254 .40172 m
.18629 .40172 L
s
.18254 .41717 m
.18629 .41717 L
s
.18254 .43262 m
.18629 .43262 L
s
.18254 .44807 m
.18629 .44807 L
s
.18254 .47898 m
.18629 .47898 L
s
.18254 .49443 m
.18629 .49443 L
s
.18254 .50988 m
.18629 .50988 L
s
.18254 .52533 m
.18629 .52533 L
s
.18254 .55623 m
.18629 .55623 L
s
.18254 .57168 m
.18629 .57168 L
s
.18254 .58713 m
.18629 .58713 L
s
.18254 .60258 m
.18629 .60258 L
s
.25 Mabswid
.18254 0 m
.18254 .61803 L
s
gsave
.18254 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03131 .61803 m
.06244 .47033 L
.08255 .33747 L
.10458 .18817 L
.11448 .12736 L
.12507 .07123 L
.1302 .04833 L
.13506 .02975 L
.13975 .01491 L
.14415 .004 L
s
.14415 .004 m
.14621 0 L
s
.16714 0 m
.16867 .00296 L
.17292 .01368 L
.17796 .0306 L
.18257 .04985 L
.19248 .10281 L
.20165 .16381 L
.22241 .32705 L
.23216 .40482 L
.24266 .48018 L
.2475 .50985 L
.25258 .53663 L
.25735 .55691 L
.26168 .57084 L
.264 .57643 L
.26619 .58044 L
.2674 .58211 L
.26851 .5833 L
.26973 .58424 L
.27102 .58478 L
.27205 .5849 L
.27315 .58469 L
.2742 .58419 L
.27515 .58346 L
.27627 .58229 L
.27749 .58062 L
.27971 .57653 L
.28231 .56999 L
.28466 .56247 L
.28994 .54027 L
.29483 .51345 L
.29943 .48323 L
.31784 .32831 L
.32829 .23276 L
.33803 .1533 L
.34299 .12005 L
.34768 .09464 L
.35027 .0835 L
.35309 .07393 L
.35433 .07058 L
.35564 .06764 L
.35677 .06564 L
.35801 .06397 L
.35865 .06333 L
.35934 .06282 L
.36007 .06248 L
.36074 .06234 L
.36195 .06253 L
.36325 .06337 L
.36398 .06412 L
Mistroke
.36477 .06517 L
.3662 .0677 L
.3676 .07093 L
.36889 .07456 L
.37384 .09437 L
.37634 .10772 L
.37909 .12481 L
.38928 .20713 L
.39857 .2989 L
.40943 .40686 L
.4142 .44859 L
.41948 .48708 L
.42177 .50071 L
.42424 .51301 L
.42658 .52218 L
.42872 .52838 L
.4299 .53087 L
.431 .53256 L
.43221 .53373 L
.4335 .53417 L
.43415 .53408 L
.43486 .53373 L
.43614 .53244 L
.43739 .53039 L
.43854 .5278 L
.44102 .51996 L
.44334 .50988 L
.44862 .47764 L
.45376 .43531 L
.45929 .38067 L
.46941 .26969 L
.47475 .21351 L
.48044 .16203 L
.48326 .14127 L
.48591 .12522 L
.48829 .11402 L
.48963 .10914 L
.49086 .1056 L
.49202 .10311 L
.49311 .10155 L
.4943 .10068 L
.49557 .10075 L
.49621 .10117 L
.4969 .10193 L
.49817 .10411 L
.4994 .1072 L
.50054 .11092 L
.50296 .12149 L
.50517 .13426 L
.51017 .17285 L
Mistroke
.51921 .26838 L
.52989 .39303 L
.5351 .44432 L
.53736 .46268 L
.53982 .47919 L
.54101 .48579 L
.54227 .49173 L
.54344 .49622 L
.54453 .49951 L
.54556 .50178 L
.54665 .50334 L
.54787 .50398 L
.54898 .50355 L
.55023 .50192 L
.55138 .49933 L
.55265 .4953 L
.554 .48966 L
.5565 .47566 L
.55876 .45923 L
.56389 .41058 L
.56943 .34537 L
.57463 .27962 L
.57947 .22145 L
.58203 .19409 L
.58446 .17152 L
.58682 .15328 L
.58901 .14017 L
.59018 .13474 L
.59143 .13027 L
.59268 .12718 L
.59339 .12606 L
.59406 .12543 L
.59475 .12521 L
.59541 .12543 L
.59666 .12693 L
.59735 .1284 L
.598 .13016 L
.59946 .13557 L
.60078 .14213 L
.60221 .15094 L
.60481 .17119 L
.60966 .22162 L
.62054 .36328 L
.62513 .41752 L
.62765 .44208 L
.63004 .46069 L
.63139 .46893 L
.6321 .47257 L
.63286 .47587 L
.6335 .47819 L
Mistroke
.6342 .48027 L
.63543 .48265 L
.63668 .48338 L
.63739 .48304 L
.63803 .48226 L
.63922 .47962 L
.64047 .4752 L
.64179 .46874 L
.64299 .46132 L
.64568 .43963 L
.65053 .38582 L
.65587 .31306 L
.66153 .23555 L
.66628 .18255 L
.66758 .1713 L
.66898 .1611 L
.6703 .15343 L
.67151 .14817 L
.67268 .14474 L
.67377 .14307 L
.67496 .14293 L
.67623 .14475 L
.67744 .14838 L
.67858 .15345 L
.6796 .15933 L
.68071 .16705 L
.68322 .18954 L
.68598 .22098 L
.69154 .29844 L
.69632 .3677 L
.69883 .40052 L
.7015 .4299 L
.7028 .44159 L
.70423 .45222 L
.70553 .45966 L
.70676 .46457 L
.70801 .46747 L
.70915 .46817 L
.71041 .46678 L
.71173 .46288 L
.71284 .45768 L
.71403 .45025 L
.71618 .43228 L
.71873 .40413 L
.72104 .37348 L
.72633 .29379 L
.72923 .25058 L
.73193 .21453 L
.73443 .18735 L
.73552 .17781 L
Mistroke
.73671 .16927 L
.73801 .16227 L
.73925 .15802 L
.73993 .15669 L
.74066 .15611 L
.74197 .15721 L
.74315 .16058 L
.74423 .16562 L
.74542 .17323 L
.74667 .18349 L
.74878 .20554 L
.75109 .23543 L
.75638 .31686 L
.76118 .3894 L
.76386 .42164 L
.76508 .43339 L
.76639 .44339 L
.76705 .44743 L
.76777 .45104 L
.76906 .45516 L
.76978 .4562 L
.77055 .45627 L
.77128 .45534 L
.77195 .45364 L
.77323 .44819 L
.77441 .44061 L
.77571 .42963 L
.7771 .41512 L
.78199 .34608 L
.78699 .26409 L
.78973 .22387 L
.79228 .19398 L
.79361 .18227 L
.7943 .17745 L
.79504 .17318 L
.79586 .16971 L
.79663 .16762 L
.79738 .16671 L
.79807 .16688 L
.7993 .16954 L
.8 .1724 L
.80066 .17595 L
.80198 .18556 L
.80341 .19938 L
.81304 .34855 L
.81568 .38919 L
.81713 .40813 L
.8185 .42305 L
.81978 .43397 L
.8205 .43873 L
Mistroke
.82116 .44217 L
.82234 .44598 L
.82358 .44672 L
.82482 .44405 L
.82596 .43867 L
.82727 .4291 L
.82851 .4169 L
.83072 .38871 L
.83312 .35076 L
.83864 .25527 L
.84103 .21958 L
.84229 .20421 L
.84362 .19118 L
.8443 .18593 L
.84505 .18133 L
.84636 .17636 L
.847 .1754 L
.84769 .17548 L
.84893 .17852 L
.84966 .18202 L
.85045 .18721 L
.85188 .20017 L
.85328 .21679 L
.85457 .23513 L
.85946 .31989 L
.86216 .36706 L
.86349 .38771 L
.86473 .40446 L
.86599 .41861 L
.86714 .42846 L
.86841 .43572 L
.86911 .43796 L
.86977 .43891 L
.87092 .43781 L
.87198 .43372 L
.87315 .42591 L
.87438 .41411 L
.87661 .38467 L
.8787 .35003 L
.88343 .26288 L
.88471 .24145 L
.8861 .22088 L
.88733 .20583 L
.88864 .19361 L
.88981 .18635 L
.8911 .1827 L
.89228 .18352 L
.89338 .18787 L
.89468 .19732 L
.89534 .20375 L
Mistroke
.89606 .21198 L
.89851 .24819 L
.90405 .35138 L
.90658 .39283 L
.90801 .41085 L
.90933 .42298 L
.91048 .42961 L
.91175 .4323 L
.91239 .43178 L
.91307 .42982 L
.91431 .42267 L
.91551 .41159 L
.91681 .39526 L
.91919 .35648 L
.92364 .27038 L
.92495 .24704 L
.92635 .225 L
.92768 .20827 L
.9289 .19711 L
.92959 .19284 L
.93033 .18986 L
.93112 .18871 L
.93184 .18946 L
.93313 .19505 L
.93385 .2005 L
.93451 .20684 L
.9358 .22281 L
.93699 .24117 L
.93969 .29151 L
.94224 .34274 L
.94459 .38432 L
.94641 .40856 L
.94732 .41718 L
.94832 .4235 L
.94933 .42639 L
.9504 .42551 L
.95142 .42092 L
.95234 .4137 L
.95328 .40359 L
.95414 .39201 L
.95608 .3593 L
.95962 .28802 L
.96147 .25217 L
.96345 .22069 L
.96459 .20749 L
.96563 .19917 L
.96668 .19474 L
.96767 .19435 L
.9687 .19786 L
.96979 .20587 L
Mistroke
.97082 .21721 L
.97175 .2303 L
.97619 .31619 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00??ooool4o`000003oa0@4?oooooooooo0?oooooo
9_ooool003kooooo00?o0000ooooooooool0oooooolXooooo`00<oooool6o`0000Gooooo00?o0000
ooooooooool0oooooolXooooo`00>_ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000
ooooooooool00_ooool3o`000?oooooo8?ooool003[ooooo00Go0000ooooooooooooooooo`000002
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0oooooolPooooo`00>_ooool01Ol0
003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3o
ooooob3ooooo000iooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooooooo0?oooooo8?ooool003Sooooo00Oo0000oooooooooooooooooeEEEOmV
IVKo000000Cooooo00Co0000oooooooooooo0000oooooolRooooo`00>?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00;o0000oooooolQooooo`00>?ooool00ol0003oooooooooo`08
ooooo`04o`000?ooooooooooo`000?oooooo8_ooool003Oooooo00?o0000ooooooooool02_ooool0
0ol0003oooooo`00003oooooob;ooooo000gooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ool00000oooooolRooooo`00=oooool00ol0003oooooooooo`0:ooooo`04o`000?oooooo0000o`00
0?oooooo8Oooool003Oooooo00?o0000ooooooooool02_ooool00ol0003oooooo`00003oooooob;o
oooo000fooooo`03o`000?oooooooooo00cooooo0_l0003oooooob;ooooo000fooooo`03o`000?oo
oooooooo00cooooo0_l0003oooooob;ooooo000fooooo`03o`000?oooooooooo00cooooo0_l0003o
ooooob;ooooo000eooooo`03o`000?oooooooooo00kooooo0_l0003oooooob7ooooo000eooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool0oooooolPooooo`00=Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo0?oooooo8?ooool003Gooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`3oooooob3ooooo000eooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool0oooooolPooooo`00=?ooool00ol0003oooooooooo`0?ooooo`;o0000=Oooool2o`00
0>Wooooo000dooooo`03o`000?oooooooooo00oooooo0_l0000dooooo`Co0000j?ooool002?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool2o`000003onk^k_oooooooooo00?o
oooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`;o0000=?ooool01?l0003oooooooooool0003X
ooooo`008oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B45ooooo`03o`000?mEEEGo
ZJVY00Sooooo00?oMgMgoc8b<_ooool01?ooool2o`0003?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`3Uooooo`006oooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400<
ooooo`03o`000?nYZJWoEEEE00Wooooo00?o0000ooooooooool00oooool2o`0003?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`3Uooooo`008oooool01Ol0003ooooooooooooooooo
000000cooooo00?o0000oooooolQ8B402?ooool00omgMgOo<S8booooo`04ooooo`?o0000<_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo0>Gooooo000Sooooo`05o`000?oooooooooo
ooooool000002oooool01Ol0003ooooooooooomEEEGoc<c<00Cooooo00Go0000ob4Q8Ol0003o<S8b
olc<c005ooooo`03o`000?oooooo0000037ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`3Uooooo`008oooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000oooooooooooo
ZJVYogMgM`04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooool00000<Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo0>Gooooo000Sooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool01Ol0003ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0
003oooooo`00000aooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0i?ooool002?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo00?o0000oooo
ool00000<?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0>Cooooo000cooooo`03
o`000?oooooooooo013ooooo0ol0000`ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0i?ooool003;ooooo00?o0000ooooooooool04Oooool01?l0003oooooooooool0000_ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0i?ooool003;ooooo00?o0000ooooooooool0
4Oooool01?l0003oooooooooool0000_ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool08oooool2o`000;oooooo000booooo`03o`000?oooooooooo017ooooo00Co0000oooooooooooo
0000;oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo027ooooo00?o0000ooooool0
0000_oooool003;ooooo00?o0000ooooooooool04Oooool01?l0003oooooooooool0000_ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool08Oooool01?l0003oooooooooool0002noooo
o`00<Oooool00ol0003oooooooooo`0Booooo`;o000000?oooooo`000?ooool0;Oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo027ooooo00Co0000oooooooooooo0000__ooool0037o
oooo00?o0000ooooooooool04_ooool01?l0003oooooooooool0000^ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool08?ooool01Ol0003ooooooooooooooooo00000;kooooo000aoooo
o`03o`000?oooooooooo01;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool08?ooool01Ol0003ooooooooooooooooo00000;kooooo000a
ooooo`03o`000?oooooooooo01;ooooo00Go0000ooooooooooooooooo`00000]ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo0;_ooooo000aooooo`03o`000?oooooooooo01;ooooo0_l00002ooooo`03o`000?oooooo
oooo02_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0^oooool0033ooooo00?o0000ooooooooool04oooool01Ol0
003ooooooooooooooooo000002gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool06Oooool2o`000:3ooooo000`oooo
o`03o`000?oooooooooo01?ooooo00Go0000ooooooooooooooooo`00000]ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooool00000X?ooool0033ooooo00?o0000ooooooooool04oooool01Ol0
003ooooooooooooooooo000002cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool06?ooool00ol0003oooooo`00002P
ooooo`00<?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0:Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Hooooo`04o`000?ooooooooooo`0009oooooo000`oooo
o`03o`000?oooooooooo01?ooooo0_l00003ooooo`03o`000?oooooooooo02Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool06?ooool01?l0003oooooooooool0002Oooooo`00;oooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Hoooo
o`04o`000?ooooooooooo`0001Kooooo00?o0000ooooooooool0Q_ooool002_ooooo00Gok^k^oc8b
<_l0003o<S8bo`000005ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Sooooo00Co
0000oooooooooooo00005_ooool2o`0008Oooooo000[ooooo`05ogMgMonHV9SooooooiRHV?l00000
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo02Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool05oooool01Ol0003ooooooooooooooooo000001Co
oooo00?o0000ooooool00000Qoooool002?ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool0
00004?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool04_ooool00ol0003oooooo`000027ooooo`00:oooool01Ol0003ooooooooooooooooo000000oo
oooo00?oMgMgoc8b<_ooool01?ooool3o`0000;ooooo00?o0000ooooooooool0:?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04_ooool01?l0003o
ooooooooool0000Booooo`03o`000?oooooooooo077ooooo000[ooooo`05o`000?oooooooooooooo
ool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Booooo`04o`000?ooooooooooo`0001;ooooo00?o0000ooooooooool0LOoo
ool002_ooooo00Go410@oooooooooooo0000oa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0Booooo`04o`000?ooooooooooo`00017ooooo
00?o0000ooooool00000L_ooool002_ooooo00GoMgMgoiRHV?oooooo0000ogMgM`0<ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Wooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Aooooo`04o`00
0?ooooooooooo`00017ooooo00?o0000ooooool00000L_ooool002_ooooo00Gok^k^oc8b<_l0003o
0000onk^kP0<ooooo`Co00001_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo013o
oooo00Go0000ooooooooooooooooo`00000Aooooo`03o`000?oooooo000000oooooo0_l0001Qoooo
o`00;_ooool00ol0003oooooooooo`0Eooooo`;o00001?ooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0@ooooo`05
o`000?ooooooooooooooool000004Oooool00ol0003oooooo`00000?ooooo`;o0000HOooool002ko
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo013o
oooo00Go0000ooooooooooooooooo`00000Aooooo`03o`000?oooooo000000oooooo00?o0000oooo
ool00000H?ooool002kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo013ooooo00Go0000ooooooooooooooooo`00000@ooooo`04o`000?oooooooooo
o`0000oooooo00?o0000ooooool000003Oooool2o`00057ooooo000]ooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool03Oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000
ooooool000003Oooool2o`00057ooooo000]ooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool03Oooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooool000003Oooool2
o`0000cooooo00?o0000ooooooooool0@_ooool002gooooo00?o0000ooooooooool05_ooool2o`00
00Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00gooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooo000000cooooo00?o0000
ooooool000003?ooool2o`0004?ooooo000]ooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool03Oooool01Ol0003ooooooooooooooooo000000gooooo00Co0000oooooooooooo00003?oo
ool00ol0003oooooo`00000<ooooo`;o00002_ooool2o`0003Oooooo000]ooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool03Oooool01Ol0003ooooooooooooooooo000000gooooo00Co
0000oooooooooooo00003?ooool00ol0003oooooo`00000;ooooo`03o`000?oooooo000000[ooooo
0_l0000:ooooo`03o`000?oooooooooo02[ooooo000]ooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00Go
0000ooooooooooooooooo`00000;ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooool0
00002_ooool2o`0000[ooooo00?o0000ooooooooool0:_ooool002gooooo00?o0000ooooooooool0
5_ooool2o`0000Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`05o`00
0?ooooooooooooooool000002oooool01?l0003oooooooooool0000:ooooo`03o`000?oooooo0000
00[ooooo0_l00009ooooo`;o0000;?ooool002cooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool01Ol0003o
oooooooooooooooo000000_ooooo00Co0000oooooooooooo00002_ooool00ol0003oooooo`00000:
ooooo`;o00002Oooool2o`0002cooooo000/ooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00[ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooool000002Ooo
ool00ol0003oooooo`000009ooooo`03o`000?oooooo000002_ooooo000/ooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00[ooooo00Go0000ooooooooooooooooo`00000;ooooo`04o`000?ooooooooooo`0000[ooooo
00?o0000ooooool000002Oooool00ol0003oooooo`000009ooooo`03o`000?oooooo000002_ooooo
000/ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Sooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`09ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooool000002Oooool00ol0003ooooo
o`000009ooooo`03o`000?oooooo000002_ooooo000/ooooo`03o`000?oooooooooo01Oooooo0_l0
0006ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Sooooo00Go0000ooooooooooooooooo`000009ooooo`04o`00
0?ooooooooooo`0000Wooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00000[oooo
o`00;?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool02?ooool01Ol0003ooooooooooooooooo000000Wooooo00Co0000oooooooooooo00002Oooool0
1?l0003oooooooooool00008ooooo`03o`000?oooooo000002_ooooo000/ooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`05o`000?oooooo
ooooooooool000002Oooool01?l0003oooooooooool00009ooooo`04o`000?ooooooooooo`0000So
oooo00?o0000ooooool00000:oooool002?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`03
o`000?lQ8B7o8B4Q00Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00Go0000ooooooooooooooooo`000009
ooooo`04o`000?ooooooooooo`0000Wooooo00Co0000oooooooooooo00002?ooool00ol0003ooooo
o`00000[ooooo`008oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00Co0000oooooolQ8B7o
8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`06ooooo`04o`000?ooooooooooo`0000Wooooo00Co0000oooooooooooo00002?oo
ool00ol0003oooooo`00000[ooooo`006oooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
4003ooooo`03o`000?oooooooooo00Kooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003ooooooooo
o`03ooooo`?o00001Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01_ooool01Ol0003ooooooooooooooooo000000Sooooo00Co0000oooooooooooo
00002?ooool00ol0003oooooo`00000[ooooo`008oooool01Ol0003ooooooooooooooooo000000?o
oooo00?o0000ooooooooool01oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo000000Sooooo00Co0000oooo
oooooooo00002?ooool00ol0003oooooo`00000[ooooo`008oooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool02?ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo027ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool00000
2?ooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0002_ooooo000Sooooo`05
oa0@4?ooooooooooooooool@41000oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
027ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`05o`000?oooooooooo
ooooool000002?ooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0002_ooooo
000Sooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool00ol0003oooooooooo`05ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Ko
oooo00Go0000ooooooooooooooooo`000008ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000
oooooooooooo0000:oooool002?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`03o`000?oo
oooooooo00Gooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`0000Oooooo
00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo
00Go0000ooooooooooooooooo`000008ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooo
oooooooo0000:oooool002_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo023ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06oooo
o`05o`000?ooooooooooooooool000002?ooool01?l0003oooooooooool00007ooooo`04o`000?oo
ooooooooo`0002_ooooo000Zooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_oo
ool01Ol0003ooooooooooooooooo000000Sooooo00Co0000oooooooooooo00001oooool01Ol0003o
oooooooooooooooo000002[ooooo000Zooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01_ooool01Ol0003ooooooooooooooooo000000Sooooo00Co0000oooooooooooo00001oooool0
1Ol0003ooooooooooooooooo000002[ooooo000Zooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01_ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooooooooooooooo
o`000007ooooo`05o`000?ooooooooooooooool00000:_ooool002[ooooo00?o0000ooooooooool0
6Oooool2o`0000Sooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Kooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooooooooooo
ool000001oooool01Ol0003ooooooooooooooooo000002[ooooo000Zooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
00gooooo00OoA4A4o`000?l0003o<S8bomgMgOoooooo000001Kooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0:ooooo`Go00000_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool01Oooool00ol0003oooooo`000003o`000004oa0@4?ooooooooooooooo`?o
000000Go<S8bomgMgOooooooooooo`000009ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01_ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`00
0005ooooo`Go000000Soooooo`000?ooooook^k^oc8b<_l0003o<S8bonk^kRCooooo000Zooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Oooooo`03
o`000?oooooooooo013ooooo00CoMgMgoc8b<_oooooo00005_ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooool000000_ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000Gooooo00Go
0000ooooooooooooMgMgoc8b<P02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool000001oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00goV9RHob4Q8Ol0003oooooodA4A?oooooo
0000oooooomgMgOoV9RHoooooonHV9SoMgMg02Cooooo000Zooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo017ooooo
00?o0000ooooool000005_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooool000000_ooool01Ol@413ooooooooooooooooo410@00Cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool01Oooool01Ol0003ooooooooooooooooo000000Gooooo00Go0000ooooooooooooooooo`000002
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06
ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ob4Q8Oo^k^h00_ooool00ol0003ooooooa0@4003ooooo`03oa0@4?oo
oooooooo02;ooooo000Yooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo013ooooo00CoMgMgoc8b<_oooooo00005_oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooool000000_oo
ool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool01Ol0003ooooo
oooooooooooo000000Gooooo00Go0000ooooooooooooMgMgoc8b<P03ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00?ooooo00So0000oiRHV?lQ8B7ok^k^ooooool0003oooooo`0000?ooooo00?o0000ooooooooool0
8_ooool002Wooooo00?o0000ooooooooool06_ooool2o`0000Sooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`0=ooooo`07o`000?lQ8B7o0000oc8b<_o<c<coooooo`00000Fooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooo`000002ooooo`05
o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`05ooooo`05o`000?oooooooooo
ooooool000001Oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00?ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooo
ool02?l0003oooooogMgMomVIVKoooooo`000?oooooo00000oooool00ol0003oooooooooo`0Roooo
o`00:Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooool0
00000_ooool01Ol@413ooooooooooooooooo410@00Cooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool01Ol0
003ooooooooooooooooo000000Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`08o`000?ooooooooooo`000?oooooo0000ooooool@4103ooooo`03oa0@4?oooooooooo02;o
oooo000Yooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0Nooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003ooooo
o`000002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`05ooooo`05
o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00;ooooo0_l000002oooooooV9RHoa0@4?oooooo0000oooooomgMgOoV9RHoooooonHV9SoMgMg02Co
oooo000Yooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo00kooooo1?l00003ooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0:ooooo`05oeEEEOmVIVKo0000ooooool0
00000_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool01Ol0
003ooooooeEEEOmVIVKo000000Gooooo1?l00004ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00goV9RH
o`000?l0003o8B4Qolc<c?oooooo0000ooooooo^k^ko<S8bo`000?lb<S;ok^k^02Cooooo000Yoooo
o`03o`000?oooooooooo01[ooooo0_l00009ooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Xooooo`00:Oooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo02Oooooo000Yooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
3oooool2o`0000;ooooo0_l0000Booooo`00:?ooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00oooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMdBooooo`00:?ooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo013ooooo00CogMgMo`000?l@413oc<c<4oooool000gooooo
ool0000jo`0000_ooooo00Cok^k^ob4Q8Ol@413ok^k^4oooool001Cooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo0_l0000<ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooool000002_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool02?ooool00ol0003oooooo`00000:ooooo`;o0000
2oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo000000Sooooo00Co0000oooooooooooo
00001Oooool00ol0003oooooooooo`04ooooo`;o00002?ooool00ol0003oooooo`000005ooooo`03
o`000?oooooooooo00?ooooo0_l00006ooooo`03o`000?oooooooooo00;ooooo0_l00006ooooo`04
o`000?ooooooooooooooo`;o00001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
013ooooo00Co8B4QogMgMomgMgOo<S8b4oooool002Sooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0<ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`04ooooo`;o00002?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool03oooool2o`0000;ooooo0_l0000Booooo`00:?ooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0]ooooo`00:?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0]ooooo`00:?ooool00ol0003ooooo
ooooo`0Kooooo`;o00002_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02gooooo
000Wooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooo
oooooooo0000033ooooo000Wooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool01Ol0003ooooooooooooooooo0000033ooooo000Wooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000033ooooo000Wooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000033ooooo
000Wooooo`03o`000?oooooooooo01cooooo0_l0000:ooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000
<?ooool002Oooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oo
ooooooooooooool00000<?ooool002Oooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`04ooooo`05o`000?ooooooooooooooool00000<?ooool002Kooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000<?ooool002Kooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000
<?ooool002Kooooo00?o0000ooooooooool07Oooool2o`0000_ooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooooooo
o`00000`ooooo`009_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go
0000ooooooooooooooooo`00000`ooooo`009_ooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00Go0000ooooooooooooooooo`00000`ooooo`009_ooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo0000<?ooool002Gooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`00033ooooo000Uooooo`03o`00
0?oooooooooo01kooooo0_l0000<ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1oooool01Ol0003ooooooooooooooooo000000Wooooo00Go0000ooooooooooooooooo`000007oooo
o`04o`000?ooooooooooo`00033ooooo000Uooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00Go0000oooo
ooooooooooooo`000009ooooo`05o`000?ooooooooooooooool000001oooool01?l0003ooooooooo
ool0000`ooooo`008oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000
1?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`000009oooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000<?ooool002?ooooo00GoMgMg
oiRHV?l0003oV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo000000Wooooo00Co0000oooooooo
oooo00002?ooool01?l0003oooooooooool0000`ooooo`008oooool01Ol@413oooooo`000?oooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`?o00002oooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`00
0009ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000<?ooool002?ooooo
0_l00002ooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8b
ooooo`04ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`07ooooo`05o`000?ooooooooooooooool000002Oooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`00033ooooo000Sooooo`;o00000_ooool00ol0003oooooooooo`0<oooo
o`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`05o`000?oooooo
ooooooooool000002Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`00033o
oooo000Sooooo`05oa0@4?l0003oooooooooool@41003oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`000009ooooo`04o`000?oooooooooo
o`0000Sooooo00Co0000oooooooooooo0000<?ooool002?ooooo00GoMgMgo`000?ooooooV9RHogMg
M`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`04o`00
0?ooooooooooo`0000Wooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0000`
ooooo`008oooool01Oo^k^ko0000o`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c004ooooo`Co00001_ooool2o`0000gooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00[ooooo00Go0000ooooooooooooooooo`00000:ooooo`04o`00
0?ooooooooooo`0000Wooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00000aoooo
o`009?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooo
oooo00002oooool01?l0003oooooooooool00009ooooo`04o`000?ooooooooooo`0000Sooooo00?o
0000ooooool00000<Oooool002?ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`00000<ooooo`04o`000?oo
ooooooooo`0000_ooooo00Co0000oooooooooooo00002Oooool01?l0003oooooooooool00008oooo
o`03o`000?oooooo0000037ooooo000Sooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool000003?ooool01?l0
003oooooooooool0000;ooooo`04o`000?ooooooooooo`0000Wooooo00Co0000oooooooooooo0000
2?ooool00ol0003oooooo`00000aooooo`008oooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool02oooool01Ol0003ooooooooooooooooo000000cooooo
00Co0000oooooooooooo00002oooool01?l0003oooooooooool00009ooooo`04o`000?oooooooooo
o`0000Sooooo00?o0000ooooool00000<Oooool002?ooooo00?o0000ooooooooool08?ooool2o`00
00kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool02oooool01Ol0003ooooooooooooooooo000000cooooo00Co0000
oooooooooooo00002oooool01?l0003oooooooooool00009ooooo`04o`000?ooooooooooo`0000So
oooo00?o0000ooooool00000<Oooool002?ooooo00?o0000ooooooooool08?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03_ooool01Ol0003ooooo
oooooooooooo000000kooooo00Go0000ooooooooooooooooo`00000<ooooo`04o`000?oooooooooo
o`0000_ooooo00Co0000oooooooooooo00002_ooool2o`0000Wooooo00?o0000ooooool00000<Ooo
ool002?ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool03_ooool01Ol0003ooooooooooooooooo000000kooooo00Go
0000ooooooooooooooooo`00000<ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooool0
00002oooool2o`0000[ooooo0_l0000aooooo`008_ooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0>ooooo`05o`00
0?ooooooooooooooool000003_ooool01Ol0003ooooooooooooooooo000000cooooo00Co0000oooo
oooooooo00002oooool00ol0003oooooo`00000;ooooo`;o00002_ooool00ol0003oooooooooo`0`
ooooo`008_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0?ooooo`05o`000?ooooooooooooooool000003oooool0
1?l0003oooooooooool0000=ooooo`03o`000?oooooo000000_ooooo00?o0000ooooool000002ooo
ool2o`0003gooooo000Rooooo`03o`000?oooooooooo027ooooo0_l0000>ooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool03oooool01Ol0003ooooooooooooooooo000000oooooo00Co
0000oooooooooooo00003Oooool00ol0003oooooo`00000;ooooo`03o`000?oooooo000000_ooooo
0_l0000mooooo`008_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0?ooooo`05o`000?ooooooooooooooool00000
3oooool01?l0003oooooooooool0000=ooooo`03o`000?oooooo000000cooooo0_l0001:ooooo`00
8_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0?ooooo`05o`000?ooooooooooooooool000003oooool01?l0003o
ooooooooool0000=ooooo`03o`000?oooooo000000cooooo00?o0000ooooooooool0BOooool002;o
oooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool03oooool01Ol0003ooooooooooooooooo000000oooooo00Co0000oooo
oooooooo00003Oooool2o`0005Wooooo000Qooooo`03o`000?oooooooooo02;ooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00oooooo00Go0000oooo
ooooooooooooo`00000?ooooo`03o`000?oooooo000000kooooo0_l0001Iooooo`008Oooool00ol0
003oooooooooo`0Rooooo`;o00003oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
023ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
013ooooo00Co0000oooooooooooo00003oooool00ol0003oooooo`00001Yooooo`008Oooool00ol0
003oooooooooo`0Rooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo01?ooooo00Go0000ooooooooooooooooo`00000C
ooooo`04o`000?ooooooooooo`0000oooooo00?o0000ooooool00000JOooool0027ooooo00?o0000
ooooooooool01oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0
003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Cooooo`05o`000?ooooooooooooooool0
00004oooool00ol0003oooooo`00000Aooooo`;o0000JOooool0027ooooo00?o0000ooooooooool0
1oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo023o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool04oooool01Ol0003ooooooooooooooooo000001?ooooo00?o0000oooo
ool00000O?ooool0027ooooo00?o0000ooooooooool01oooool01Ol@413ooooooooooooooooo410@
013ooooo00?o0000ooooooooool00oooool3o`0000oooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0Qooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo01?ooooo00Go0000ooooooooooooooooo`00000C
ooooo`03o`000?oooooo000007cooooo000Pooooo`03o`000?oooooooooo00Sooooo00Go0000oooo
ooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool0
1Ol0003ooooooooooooooooo000001?ooooo00?o0000ooooool00000O?ooool0023ooooo00?o0000
ooooooooool02?ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8b
olc<c005ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo01Gooooo00Co0000oooooooooooo00005?ooool00ol0003o
ooooooooo`1kooooo`008?ooool00ol0003oooooooooo`08ooooo`05oa0@4?ooooooooooooooool@
41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Gooooo00Co0000oooooooo
oooo0000T_ooool0023ooooo00?o0000ooooooooool02?ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Eooooo`04o`000?oooooooooo
o`0009;ooooo000Pooooo`03o`000?oooooooooo00Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<
ooooo`Co00001_ooool2o`00017ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0R
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo01Kooooo0_l0002Cooooo`008?ooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo01Kooooo0_l0002Cooooo`007oooool00ol0003oooooooooo`0Tooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool06_ooool01Ol0003ooooooooooooooooo0000
01Wooooo00?o0000ooooooooool0TOooool001oooooo00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo01_ooooo00Go0000ooooooooooooooooo`00002]oooo
o`007oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool06oooool01Ol0003ooooooooooooooooo00000:gooooo000Oooooo`03o`000?oooooooooo02Co
oooo0_l0000Aooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo01_ooooo00Co0000oooooooooooo0000[_ooool001oo
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool08oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01_o
oooo00Co0000oooooooooooo0000[_ooool001kooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo01cooooo00?o0000ooooool00000[_ooool001kooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01gooooo
0_l0002_ooooo`007_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0c_ooool001kooooo00?o0000ooooooooool09Oooool2o`0001;ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0c_ooool001kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo0<kooooo000Mooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`3?ooooo`007Oooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Vooooo`05o`00
0?ooooooooooooooool00000dOooool001gooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool09oooool01Ol0003ooooo
oooooooooooo00000=7ooooo000Mooooo`03o`000?oooooooooo02Kooooo0_l0000Cooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool09oooool01Ol0003ooooooooooooooooo00000=7o
oooo000Mooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo02Sooooo00Co0000ooooool0003o0000dOooool001cooooo
00?o0000ooooooooool01?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03
o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Xooooo`?o0000d_ooool001co
oooo00?o0000ooooooooool01?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46oooo
o`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`3Aoooo
o`007?ooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@41003Oooool00onY
ZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo0?kooooo000Looooo`03o`000?oooooooooo00Co
oooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b
<_ooool01?ooool3o`0001?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`3noooo
o`007?ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000003_ooool00omE
EEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0o_ooool001_ooooo00?o0000oooo
ooooool01Oooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`3nooooo`006oooool00ol0003oooooooooo`05ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooo
ool001_ooooo00?o0000ooooooooool01Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol0
0004ooooo`Co00001_ooool2o`0001Gooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`3oooooo`006oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`3oooooo`006oooool00ol0003oooooooooo`0Xoooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3ooooo
o`006_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`3oooooo`006_ooool00ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooo`7ooooo
000Jooooo`03o`000?oooooooooo02Wooooo0_l0000Fooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0ooooool1ooooo`006_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3oooooo`7ooooo000Joooo
o`03o`000?oooooooooo02Wooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo0?oooooo0_ooool001Wooooo00?o0000ooooooooool0:_ooool00ol0003o
ooooooooo`0Gooooo`04o`000?ooooooooooo`000?oooooo1Oooool001Wooooo00?o0000oooooooo
ool0:_ooool00ol0003oooooooooo`0Hooooo`?o0000ooooool5ooooo`006Oooool00ol0003ooooo
ooooo`0Zooooo`;o0000oooooolQooooo`006Oooool00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo0?oooooo8?ooool001Wooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`3o
ooooob3ooooo000Hooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0oooooolPoooo
o`006?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo0?oooooo8?ooool001Sooooo
00?o0000ooooooooool0:oooool2o`000?oooooo8Oooool001Sooooo00?o0000ooooooooool0:ooo
ool00ol0003oooooooooo`3oooooob3ooooo000Hooooo`03o`000?oooooooooo027ooooo1?l00000
0ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo8?ooool001Oooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo8?ooool001Oo
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oo
oooo8?ooool001Oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`05ooooo`?o0000
oooooolPooooo`00?_ooool00ol0003oooooooooo`3oooooobSooooo000nooooo`03o`000?oooooo
oooo0?oooooo:?ooool003kooooo00?o0000ooooooooool0oooooolXooooo`00??ooool00omEEEGo
IVIVo`00003oooooob[ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo0012ooooo`?o000000?o410@ooooooooool0oooooolQooooo`00A?ooool00ol@413o^[Zj
ooooo`3oooooob;ooooo0014ooooo`03oiRHV?lb<S;ooooo0?oooooo8_ooool004Cooooo00?ogMgM
o`000?nj^[X0oooooolRooooo`00A?ooool00omEEEGoMgMgodA4A03oooooob;ooooo0013ooooo`05
omgMgOl@413oooooob4Q8OoMgMd0oooooolQooooo`00@oooool01OmVIVKoQhN7oooooonHV9SoEEEE
0?oooooo8Oooool004;ooooo00?ok^k^o`000?o^k^h00_ooool00ol0003ogMgMooooo`3ooooooaoo
oooo0012ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool0oooooolNooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-5.66973, -1.05832, 0.1009, \
0.0129571}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.18254 0.0396825 0.309017 0.309017 [
[.38095 .29652 -3 -9 ]
[.38095 .29652 3 0 ]
[.57937 .29652 -6 -9 ]
[.57937 .29652 6 0 ]
[.77778 .29652 -6 -9 ]
[.77778 .29652 6 0 ]
[.97619 .29652 -6 -9 ]
[.97619 .29652 6 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.17004 0 -12 -4.5 ]
[.17004 0 0 4.5 ]
[.17004 .07725 -30 -4.5 ]
[.17004 .07725 0 4.5 ]
[.17004 .15451 -24 -4.5 ]
[.17004 .15451 0 4.5 ]
[.17004 .23176 -30 -4.5 ]
[.17004 .23176 0 4.5 ]
[.17004 .38627 -24 -4.5 ]
[.17004 .38627 0 4.5 ]
[.17004 .46353 -18 -4.5 ]
[.17004 .46353 0 4.5 ]
[.17004 .54078 -24 -4.5 ]
[.17004 .54078 0 4.5 ]
[.17004 .61803 -6 -4.5 ]
[.17004 .61803 0 4.5 ]
[.18254 .64303 -5 0 ]
[.18254 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.38095 .30902 m
.38095 .31527 L
s
[(5)] .38095 .29652 0 1 Mshowa
.57937 .30902 m
.57937 .31527 L
s
[(10)] .57937 .29652 0 1 Mshowa
.77778 .30902 m
.77778 .31527 L
s
[(15)] .77778 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(20)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.22222 .30902 m
.22222 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30159 .30902 m
.30159 .31277 L
s
.34127 .30902 m
.34127 .31277 L
s
.42063 .30902 m
.42063 .31277 L
s
.46032 .30902 m
.46032 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.53968 .30902 m
.53968 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.65873 .30902 m
.65873 .31277 L
s
.69841 .30902 m
.69841 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.81746 .30902 m
.81746 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.89683 .30902 m
.89683 .31277 L
s
.93651 .30902 m
.93651 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.10317 .30902 m
.10317 .31277 L
s
.06349 .30902 m
.06349 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.18254 0 m
.18879 0 L
s
[(-1)] .17004 0 1 0 Mshowa
.18254 .07725 m
.18879 .07725 L
s
[(-0.75)] .17004 .07725 1 0 Mshowa
.18254 .15451 m
.18879 .15451 L
s
[(-0.5)] .17004 .15451 1 0 Mshowa
.18254 .23176 m
.18879 .23176 L
s
[(-0.25)] .17004 .23176 1 0 Mshowa
.18254 .38627 m
.18879 .38627 L
s
[(0.25)] .17004 .38627 1 0 Mshowa
.18254 .46353 m
.18879 .46353 L
s
[(0.5)] .17004 .46353 1 0 Mshowa
.18254 .54078 m
.18879 .54078 L
s
[(0.75)] .17004 .54078 1 0 Mshowa
.18254 .61803 m
.18879 .61803 L
s
[(1)] .17004 .61803 1 0 Mshowa
.125 Mabswid
.18254 .01545 m
.18629 .01545 L
s
.18254 .0309 m
.18629 .0309 L
s
.18254 .04635 m
.18629 .04635 L
s
.18254 .0618 m
.18629 .0618 L
s
.18254 .09271 m
.18629 .09271 L
s
.18254 .10816 m
.18629 .10816 L
s
.18254 .12361 m
.18629 .12361 L
s
.18254 .13906 m
.18629 .13906 L
s
.18254 .16996 m
.18629 .16996 L
s
.18254 .18541 m
.18629 .18541 L
s
.18254 .20086 m
.18629 .20086 L
s
.18254 .21631 m
.18629 .21631 L
s
.18254 .24721 m
.18629 .24721 L
s
.18254 .26266 m
.18629 .26266 L
s
.18254 .27812 m
.18629 .27812 L
s
.18254 .29357 m
.18629 .29357 L
s
.18254 .32447 m
.18629 .32447 L
s
.18254 .33992 m
.18629 .33992 L
s
.18254 .35537 m
.18629 .35537 L
s
.18254 .37082 m
.18629 .37082 L
s
.18254 .40172 m
.18629 .40172 L
s
.18254 .41717 m
.18629 .41717 L
s
.18254 .43262 m
.18629 .43262 L
s
.18254 .44807 m
.18629 .44807 L
s
.18254 .47898 m
.18629 .47898 L
s
.18254 .49443 m
.18629 .49443 L
s
.18254 .50988 m
.18629 .50988 L
s
.18254 .52533 m
.18629 .52533 L
s
.18254 .55623 m
.18629 .55623 L
s
.18254 .57168 m
.18629 .57168 L
s
.18254 .58713 m
.18629 .58713 L
s
.18254 .60258 m
.18629 .60258 L
s
.25 Mabswid
.18254 0 m
.18254 .61803 L
s
gsave
.18254 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.06499 .61803 m
.07314 .58503 L
.08284 .53581 L
.10458 .39862 L
.12545 .25033 L
.14465 .12414 L
.15434 .07236 L
.16339 .03495 L
.16795 .02087 L
.17029 .01499 L
.17283 .00969 L
.17428 .00719 L
.17562 .00522 L
.17687 .00368 L
.17825 .00232 L
.17949 .00141 L
.18065 .00083 L
.18188 .00049 L
.1832 .00046 L
.18445 .00075 L
.18559 .00128 L
.18691 .00221 L
.18816 .0034 L
.19037 .0063 L
.19277 .01053 L
.19541 .01653 L
.19822 .02439 L
.20324 .0423 L
.21328 .09201 L
.22434 .1651 L
.24542 .33554 L
.26468 .4833 L
.27421 .53684 L
.27682 .54811 L
.2796 .55827 L
.2822 .56599 L
.28459 .57148 L
.28577 .57358 L
.28705 .57545 L
.28834 .57685 L
.28905 .57741 L
.28971 .5778 L
.29092 .57819 L
.29203 .57817 L
.29331 .57769 L
.29452 .5768 L
.2956 .57562 L
.29675 .57398 L
.29882 .57005 L
.30105 .56439 L
Mistroke
.3035 .55648 L
.30843 .53535 L
.31362 .50606 L
.32289 .43826 L
.34376 .24747 L
.35333 .16566 L
.35858 .12836 L
.36354 .1002 L
.36579 .09001 L
.36816 .08117 L
.36941 .07737 L
.37077 .07386 L
.37203 .07128 L
.37317 .06945 L
.37429 .06817 L
.37535 .06743 L
.37647 .06713 L
.37769 .0674 L
.37876 .06812 L
.37989 .0694 L
.38085 .07091 L
.38192 .07302 L
.38426 .07929 L
.38682 .08868 L
.39199 .11532 L
.39678 .1484 L
.40124 .18539 L
.41196 .29054 L
.42209 .39397 L
.42685 .43756 L
.43189 .47681 L
.43452 .49368 L
.43742 .50889 L
.43869 .51437 L
.44005 .5194 L
.44133 .5233 L
.44252 .52617 L
.44367 .52828 L
.4449 .52976 L
.4456 .53025 L
.44626 .53048 L
.4475 .53028 L
.44868 .52933 L
.44977 .52779 L
.45096 .52537 L
.45223 .522 L
.45441 .51416 L
.45646 .50463 L
.4611 .47548 L
.46611 .43372 L
Mistroke
.47156 .37906 L
.48147 .2687 L
.48608 .21933 L
.49104 .17245 L
.49333 .15407 L
.49573 .13738 L
.49781 .12541 L
.50003 .11534 L
.50125 .11107 L
.50236 .108 L
.50347 .1057 L
.50452 .10427 L
.50575 .10353 L
.50688 .10373 L
.50812 .10494 L
.50944 .10733 L
.51067 .11062 L
.51199 .11527 L
.51438 .1265 L
.51722 .14442 L
.51982 .16477 L
.53072 .28057 L
.54083 .39936 L
.54558 .44577 L
.54791 .46432 L
.55005 .4784 L
.55253 .49076 L
.55383 .49545 L
.5545 .49734 L
.55521 .49898 L
.55636 .5008 L
.55743 .50154 L
.55871 .50121 L
.55987 .49976 L
.56116 .49687 L
.56181 .4949 L
.56253 .49234 L
.56498 .48054 L
.56785 .46109 L
.57053 .43786 L
.58061 .32089 L
.58557 .25773 L
.59099 .19596 L
.59346 .17266 L
.5961 .15247 L
.59738 .14461 L
.59859 .13848 L
.59968 .13408 L
.60085 .13051 L
.60201 .12826 L
Mistroke
.60308 .1273 L
.60427 .12753 L
.60554 .12928 L
.60618 .13075 L
.60687 .13279 L
.60813 .13765 L
.60936 .14381 L
.61049 .15073 L
.6148 .1866 L
.61937 .23843 L
.62874 .36286 L
.63365 .42105 L
.63634 .44631 L
.63764 .45646 L
.63883 .46431 L
.63989 .47012 L
.64103 .47513 L
.64224 .47891 L
.64339 .48101 L
.64464 .48165 L
.64528 .48129 L
.64598 .48037 L
.64721 .47742 L
.64837 .47311 L
.6495 .4675 L
.65057 .46092 L
.65258 .44545 L
.65711 .39772 L
.66672 .26569 L
.66925 .23204 L
.67199 .19981 L
.67435 .1768 L
.67569 .16617 L
.67695 .15803 L
.67813 .152 L
.67939 .14742 L
.68009 .14575 L
.68074 .14474 L
.68198 .14435 L
.68313 .14575 L
.68419 .14857 L
.68536 .15333 L
.6866 .16024 L
.68874 .17649 L
.69076 .19624 L
.69534 .25402 L
.70519 .39516 L
.70759 .42282 L
.71015 .44589 L
.71162 .45557 L
Mistroke
.71295 .46186 L
.71359 .46401 L
.71429 .46567 L
.71556 .46687 L
.71671 .46592 L
.71779 .46326 L
.71897 .45841 L
.72024 .45099 L
.72157 .4409 L
.72283 .42925 L
.72519 .4026 L
.73407 .27168 L
.73646 .23709 L
.73903 .20455 L
.74022 .1919 L
.74147 .18045 L
.74255 .17225 L
.7437 .16537 L
.7449 .16038 L
.74602 .15783 L
.74671 .15728 L
.74736 .15747 L
.74857 .15969 L
.74922 .16189 L
.74991 .16496 L
.75115 .17237 L
.75248 .18295 L
.75395 .19748 L
.76338 .33571 L
.76564 .37034 L
.76804 .40311 L
.7703 .42806 L
.77137 .43734 L
.77235 .44427 L
.77355 .45052 L
.77485 .45442 L
.776 .45531 L
.7772 .45363 L
.77851 .44881 L
.77973 .44157 L
.78106 .43071 L
.78249 .41596 L
.78735 .34759 L
.79177 .27439 L
.79426 .23598 L
.79691 .20208 L
.79829 .18837 L
.79902 .18238 L
.79981 .17701 L
.80053 .17312 L
Mistroke
.80119 .17044 L
.80249 .16774 L
.80372 .16834 L
.80486 .17165 L
.80611 .17827 L
.80681 .18329 L
.80744 .18865 L
.81012 .2187 L
.81265 .25598 L
.81767 .34122 L
.82013 .38038 L
.82238 .41034 L
.82351 .4225 L
.82474 .4331 L
.82604 .441 L
.82728 .44513 L
.82799 .44597 L
.82863 .44575 L
.82938 .44434 L
.83008 .44188 L
.83132 .43483 L
.83202 .42942 L
.83267 .42357 L
.83489 .39763 L
.83695 .36677 L
.84165 .28504 L
.844 .2456 L
.84623 .21394 L
.84745 .1999 L
.8481 .19368 L
.84879 .18804 L
.85 .18064 L
.85112 .17689 L
.85233 .17626 L
.85364 .17963 L
.85488 .18664 L
.85603 .19632 L
.8582 .22203 L
.86052 .25799 L
.86573 .35146 L
.86829 .39215 L
.86941 .40686 L
.87064 .42015 L
.8718 .42952 L
.87288 .43529 L
.87402 .43809 L
.87525 .43723 L
.87589 .43517 L
.87658 .43171 L
.87785 .42223 L
Mistroke
.87909 .40932 L
.88023 .39446 L
.88477 .31685 L
.88893 .24188 L
.89119 .21028 L
.89232 .19844 L
.89356 .18918 L
.89481 .1841 L
.89551 .1832 L
.89614 .18362 L
.89738 .18777 L
.89855 .19566 L
.89964 .20633 L
.9008 .22079 L
.90288 .25338 L
.90758 .34198 L
.91002 .38406 L
.91137 .40291 L
.91264 .4169 L
.91383 .42593 L
.91512 .43106 L
.9163 .43123 L
.91738 .42754 L
.91806 .4234 L
.9188 .41739 L
.92013 .40273 L
.92261 .36443 L
.9253 .31319 L
.92818 .25771 L
.9295 .23533 L
.93075 .21737 L
.93188 .2046 L
.9331 .19488 L
.93426 .19004 L
.93549 .18979 L
.93654 .19359 L
.93769 .20195 L
.93835 .20857 L
.93905 .21687 L
.94029 .23481 L
.94308 .28583 L
.94573 .3392 L
.94814 .38256 L
.94943 .40112 L
.95066 .41435 L
.95195 .42311 L
.95268 .42549 L
.95335 .426 L
.95447 .42323 L
.95571 .41504 L
Mistroke
.957 .40113 L
.9582 .38378 L
.96395 .2713 L
.96647 .22742 L
.96716 .218 L
.96789 .20955 L
.96921 .19891 L
.97018 .19511 L
.97109 .19482 L
.97191 .19729 L
.97279 .20279 L
.97365 .21089 L
.97456 .22212 L
.97619 .24813 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00??ooool4o`000003oa0@4?oooooooooo0?oooooo
9_ooool003kooooo00?o0000ooooooooool0oooooolXooooo`00<oooool6o`0000Gooooo00?o0000
ooooooooool0oooooolXooooo`00?_ooool00ol0003oooooooooo`03ooooo`Go0000oooooolPoooo
o`00?_ooool00ol0003oooooooooo`03ooooo`04o`000?oooooo0000o`000?oooooo8Oooool003ko
oooo00?o0000ooooooooool00_ooool01_l0003oooooooooool0003oooooo`000?oooooo8?ooool0
03kooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo
oooo0?oooooo7Oooool003cooooo00?oEEEEofIVI_l000000oooool01Ol0003ooooooooooooooooo
000000;ooooo00?o0000ooooooooool0oooooolMooooo`00@_ooool01?l0003oooooooooooooool2
o`0000;ooooo00?o0000ooooooooool0oooooolLooooo`00@Oooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool00000oooooolNooooo`00@Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0oooooolKooooo`00@Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0oooooolKooooo`00
@?ooool00ol0003oooooooooo`03ooooo`;o00000oooool00ol0003oooooooooo`3ooooooa_ooooo
0010ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`3ooooooa_ooooo0010ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`3ooooooa[ooooo0010ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`3ooooooa[ooooo0010ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3ooooooa[ooooo000oooooo`03o`00
0?oooooooooo00Cooooo0_l00004ooooo`03o`000?oooooooooo0?oooooo6_ooool003oooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo6_oo
ool003oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo0?oooooo6Oooool003kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo0?oooooo6Oooool003kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo0?oooooo6Oooool003kooooo00?o0000ooooooooool0
1Oooool2o`0000Gooooo00?o0000ooooooooool0oooooolIooooo`00?_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooolIooooo`008oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00Go
A4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
<?ooool3o`000>Cooooo000Sooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo
00?oEEEEojVYZOooool01Oooool01?l0003oooooogMgMolb<S85ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0<?ooool01?l0003oooooooooool0003Sooooo`006oooool6o`0000;o
oooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Gooooo00Co0000oooo
oooooooo00001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo033ooooo00Co0000
oooooooooooo0000hoooool002?ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ob4Q8Ooo
oooooooo00Cooooo00Co0000oooooomgMgOo<S8b1Oooool3o`0000Gooooo00?o0000ooooooooool0
;oooool01Ol0003ooooooooooooooooo00000>?ooooo000Sooooo`05o`000?ooooooooooooooool0
00003_ooool00omEEEGoc<c<ooooo`03ooooo`?o000000?o<S8bolc<c?ooool01?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`3Pooooo`008oooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMooo
ool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0;_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0>3ooooo000Sooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo<S8b00Cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`3Oooooo`008oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00_ooooo1Ol00004ooooo`Co00001_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
02gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3Oooooo`00??ooool00ol0003o
ooooooooo`07ooooo`;o00001oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0goooool003cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`3Oooooo`00>oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0;?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0=oooooo000k
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0[
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool08?ooool2o`000;cooooo000koooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0[oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool08?ooool3o`000;_ooooo000kooooo`03
o`000?oooooooooo00Sooooo0_l00008ooooo`03o`000?oooooooooo02_ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0Oooooo`04o`000?ooooooooooo`000;_ooooo000kooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool07oooool01?l0003oooooooooool0002koooo
o`00>oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0:_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01oooooo00Go0000oooooooo
ooooooooo`00002jooooo`00>_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01oo
oooo00Go0000ooooooooooooooooo`00002jooooo`00>_ooool00ol0003oooooooooo`09ooooo`;o
00002Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0;Sooooo000jooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Yooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool0W?ooool003[ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06?oo
ool3o`0009gooooo000jooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooool00000WOooool0
03[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool06?ooool00ol0003oooooo`00002Mooooo`00>Oooool00ol0003o
ooooooooo`0:ooooo`;o00002_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Oo
oooo00Co0000oooooooooooo0000W?ooool003Wooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05oooool01?l0003o
ooooooooool0002Looooo`00:oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B42oooo
o`04o`000?ooooooooooodA4A0;o000000?o<S8bomgMgOooool01?ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05_ooool01Ol0003ooooooooooooo
oooo000001Gooooo0_l00025ooooo`00:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B42ooooo`03o`000?oooooooooo00?ooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05_ooool01Ol0003ooooooooo
oooooooo000001Gooooo0_l00025ooooo`008oooool6o`0000;ooooo00Go410@oooooooooooooooo
oa0@4009ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05_ooool01Ol0003ooooo
oooooooooooo000001Cooooo00?o0000ooooool00000QOooool002_ooooo00Go0000oooooooooooo
ooooo`000009ooooo`03o`000?oooooooooo00?ooooo00?oMgMgoc8b<_ooool01?ooool3o`0000Wo
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Fooooo`05o`000?oooooooooooooo
ool000005?ooool01?l0003oooooooooool00024ooooo`00:oooool01Ol0003ooooooooooooooooo
000000Wooooo00So0000oooooooooooo0000ob4Q8Ol0003o<S8bolc<c0Gooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Gooooo00Go0000oooooooo
ooooooooo`00000Dooooo`04o`000?ooooooooooo`0001;ooooo00?o0000ooooooooool0Koooool0
02_ooooo00Go410@oooooooooooooooooa0@4008ooooo`05o`000?ooooooooooooooool000002Ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05Ooo
ool01Ol0003ooooooooooooooooo000001Cooooo00Co0000oooooooooooo00004Oooool3o`00073o
oooo000[ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02?ooool01Ol0003ooooooooooooooooo0000
00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Aooooo`04o`000?oooooooooo
o`00017ooooo00?o0000ooooool00000L?ooool002_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP08
ooooo`04o`000?ooooooooooooooo`Co00001_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo017ooooo00Co0000oooooooooooo00004Oooool00ol0003oooooo`00000?ooooo`;o0000
Goooool003Sooooo00?o0000ooooooooool02oooool2o`0000_ooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04Ooo
ool01Ol0003ooooooooooooooooo0000013ooooo00?o0000ooooool000003oooool2o`0005oooooo
000hooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03_ooool00ol0003oooooo`00
000?ooooo`;o0000Goooool003Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooo000000kooooo00?o0000ooooool000003Oooool2o`00053ooooo000goooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03Oooool01Ol0003ooooooooooooooooo
000000gooooo00?o0000ooooool000003Oooool2o`00053ooooo000gooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool03Oooool01Ol0003ooooooooooooooooo000000gooooo00Co0000
oooooooooooo00003?ooool2o`0000cooooo0_l00012ooooo`00=oooool00ol0003oooooooooo`0<
ooooo`;o00003?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool03Oooool01Ol0003ooooooooooooooooo000000gooooo00Co0000oooooooooooo0000
3?ooool00ol0003oooooo`00000;ooooo`;o0000@_ooool003Oooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0=ooooo`05o`000?ooooooooooooooool000003Oooool01?l0003ooooo
ooooool0000<ooooo`03o`000?oooooo000000_ooooo0_l0000:ooooo`;o0000=_ooool003Oooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02?ooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0=ooooo`05o`000?ooooooooooooooool0
00003Oooool01?l0003oooooooooool0000<ooooo`03o`000?oooooo000000_ooooo0_l0000:oooo
o`;o0000=_ooool003Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0=ooooo`05
o`000?ooooooooooooooool000003Oooool01?l0003oooooooooool0000<ooooo`03o`000?oooooo
000000[ooooo00?o0000ooooool000002_ooool2o`0000[ooooo00?o0000ooooooooool0:Oooool0
03Oooooo00?o0000ooooooooool03?ooool2o`0000cooooo00?o0000ooooooooool08oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00gooooo00Go0000ooooooooooooooooo`00000=
ooooo`04o`000?ooooooooooo`0000_ooooo00Co0000oooooooooooo00002_ooool00ol0003ooooo
o`00000:ooooo`;o00002Oooool2o`0002_ooooo000fooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00_ooooo00Co
0000oooooooooooo00002oooool01?l0003oooooooooool0000:ooooo`04o`000?ooooooooooo`00
00Wooooo0_l00009ooooo`;o0000:oooool003Kooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02oooool01Ol0003o
oooooooooooooooo000000[ooooo00Co0000oooooooooooo00002_ooool01?l0003oooooooooool0
0009ooooo`;o00002Oooool2o`0002_ooooo000fooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00_ooooo00Go0000
ooooooooooooooooo`00000:ooooo`04o`000?ooooooooooo`0000[ooooo00Co0000oooooooooooo
00002Oooool00ol0003oooooo`000008ooooo`03o`000?oooooo000002[ooooo000fooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00_ooooo00Go0000ooooooooooooooooo`00000:ooooo`05o`000?oooooooooooooo
ool000002Oooool01?l0003oooooooooool00009ooooo`03o`000?oooooo000000Sooooo00?o0000
ooooool00000:_ooool003Kooooo00?o0000ooooooooool03Oooool2o`0000gooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool000002_ooool0
1Ol0003ooooooooooooooooo000000Wooooo00Co0000oooooooooooo00002?ooool01?l0003ooooo
ooooool00008ooooo`03o`000?oooooo000002[ooooo000fooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00_ooooo
00Go0000ooooooooooooooooo`00000:ooooo`05o`000?ooooooooooooooool000002Oooool01?l0
003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000:_oo
ool003Gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Sooooo00Go0000ooooooooooooooooo`000009ooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo00002?ooool00ol0003oooooo`00000Zooooo`008oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM
00Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`05o`000?oooooooooo
ooooool000002Oooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0000Oooooo
00Co0000oooooooooooo0000:_ooool002?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1?ooool01OnHV9So8B4Qo`000?ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00Go0000ooooooooooooooooo`000008
ooooo`05o`000?ooooooooooooooool000002?ooool01?l0003oooooooooool00007ooooo`04o`00
0?ooooooooooo`0002[ooooo000Kooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00co
oooo00?oV9RHo`000?o^k^h02Oooool00ol0003oooooooooo`03ooooo`?o00003?ooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool01Ol0003o
oooooooooooooooo000000Sooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool0
000Zooooo`008oooool01Ol0003ooooooooooooooooo000000gooooo00?o0000ob4Q8Oo^k^h01ooo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00Go0000oooooooooooooooo
o`000008ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo0000:_ooool002?o
oooo00Go0000ooooooooooooooooo`00000=ooooo`03o`000?mgMgOoIVIV00Cooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00Go0000ooooooooooooooooo`00
0008ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000Yooooo`00
8oooool01Ol@413ooooooooooooooooo410@00gooooo00?o0000ooooool000001?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`05ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000Y
ooooo`008oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo0_l000000oooooooV9RHoa0@4004
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooo
oooooooo000002Wooooo000Sooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So0000
o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o00003_ooool00ol0003oooooooooo`0Oooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Gooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooooooo
000002Wooooo000dooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00001oooool0
0ol0003oooooooooo`0[ooooo`00=?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`04o`000?oooooooooo
o`0000Oooooo00?o0000ooooooooool0:oooool003Cooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool01?l0
003oooooooooool00007ooooo`03o`000?oooooooooo02_ooooo000dooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Gooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`0[ooooo`00<oooool00ol0
003oooooooooo`0@ooooo`;o00003_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo02_ooooo000coooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo00Sooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`07ooooo`Co000000Co410@
ooooooooooook^k^0_l000000olb<S;ok^k^ooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo1Ol0
00001Ol@413oooooooooooooooooA4A400;o000000?o<S8bomgMgOooool00_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000003ooooo`Go
00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Cooooo000cooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00_o
oooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02ooooo`05ogMgMol0003ooooooiRH
V?mgMgL01oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Oooooo00?o0000ogMg
Molb<S800oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00Go0000oooo
ooooooooooooo`000003ooooo`05oiRHV?lQ8B7ok^k^o`000?m4A4@00oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg02Cooooo000cooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`02ooooo`05oa0@4?l0003oooooooooool@41001oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooo000000Oooooo00?o0000ooooool000000oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000004ooooo`03
oiRHV?lQ8B7o000000Cooooo00Go410@oooooooooooooooooa0@400Tooooo`00<oooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`0;ooooo`03ogMgMolb<S;ooooo00Gooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000000Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool00ol0003oooooo`000007oooo
o`03o`000?mgMgOo<S8b00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05oooo
o`05o`000?ooooooooooooooool000001Oooool00onHV9So0000onk^kP03ooooo`05o`000?oooooo
ooooooooool000009?ooool003?ooooo00?o0000ooooooooool04?ooool2o`0000oooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`08ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01_oo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooo000000Gooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo0000
00Kooooo00?o0000ofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000002Cooooo000coooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool@41001oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
000000Gooooo00?o0000ooooool000001_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Gooooo00Go0000ooooooooooooooooo`000006ooooo`;o00000oooool01Ol@413ooooooooo
oooooooo410@02Cooooo000booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`02ooooo`05o`000?nHV9SooooooiRHV?mgMgL01oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooo000000Gooooo00?o0000ooooool000001_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?nj^[[oooooo`000?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg02Cooooo000boooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo00Sooooo1?l00007ooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`07ooooo`03oeEEEOmVIVKo000000Cooooo00Go0000oc8b
<_l0003o<S8bonk^kP07ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo00?o0000ofIVI_l000001Oooool4
o`0000Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00;ooooo00Ko0000oooooooooooooooooiRHV?l@4102o`000009olc<c?ooooooooooooooooo^
k^ko<S8bo`000?lb<S;ok^k^02Cooooo000booooo`03o`000?oooooooooo017ooooo0_l0000?oooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0:oooool003;ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0:oooool003;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool04oooool2o`0000;ooooo0_l0000Booooo`00<_oo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0Dooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM4_ooool0037ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool05Oooool01?oMgMgo0000oa0@4?o<c<`Cooooo`003Oooooooo`0003[o0000
2oooool01?o^k^ko8B4Qoa0@4?o^k^hCooooo`005?ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`;o00003?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooo000000_ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooool000003?ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooo000000Wooooo00?o0000ooooool000002_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooo000000Kooooo00?o0000ooooooooool00oooool01?l0003o
ooooooooool00007ooooo`;o00001_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo0000
00Kooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00?ooooo00Ko0000
oooooooooooo0000ooooool00005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
4?ooool01?lQ8B7oMgMgogMgMolb<S8Cooooo`00<Oooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00?ooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool03oooool2o`0000;ooooo0_l0000Booooo`00
<Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0/ooooo`00<Oooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0/ooooo`00<Oooool0
0ol0003oooooooooo`0Booooo`;o00004Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo02cooooo000`ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo02cooooo000`ooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02co
oooo000`ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo02cooooo000`ooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02cooooo000`
ooooo`03o`000?oooooooooo01?ooooo0_l0000Aooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0;?ooool0033ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0;?ooool0033ooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0;?ooool002oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0;?ooool002oooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0;?oo
ool002oooooo00?o0000ooooooooool05?ooool2o`0001;ooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0/ooooo`00;oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00Go0000ooooooooooooooooo`00000_ooooo`00;oooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo0000;oooool002oooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00Go0000oooo
ooooooooooooo`000007ooooo`04o`000?ooooooooooo`0002oooooo000^ooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`05o`000?oooooo
ooooooooool000001oooool01?l0003oooooooooool0000_ooooo`00;_ooool00ol0003ooooooooo
o`0Eooooo`;o00004_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00Go
0000ooooooooooooooooo`000008ooooo`05o`000?ooooooooooooooool000001oooool01?l0003o
ooooooooool0000_ooooo`00;_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`05o`000?oooooooooooooo
ool000002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000;ooo
ool002?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03ob4Q8Ol0003ooooo00?ooooo1Ol0
0004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo000000So
oooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0002oooooo000Soooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00olQ8B7o0000ooooo`03ooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool00000
2?ooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000;oooool002?o
oooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00?ooooo00?oV9RHob4Q
8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`?o00004_ooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooooooo
000000[ooooo00Go0000ooooooooooooooooo`000008ooooo`04o`000?ooooooooooo`0000Sooooo
00Co0000oooooooooooo0000;oooool002?ooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo00Cooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Sooooo00Go0000ooooooooooooooooo`00000:ooooo`05o`000?oooooooooo
ooooool000002?ooool01?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0002oooooo
000Sooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`06ooooo`03ogMg
MomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00So
oooo00Go0000ooooooooooooooooo`00000:ooooo`05o`000?ooooooooooooooool000002?ooool0
1?l0003oooooooooool00008ooooo`04o`000?ooooooooooo`0002oooooo000Sooooo`05oa0@4?oo
ooooooooooooool@41001Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool0
00002_ooool01Ol0003ooooooooooooooooo000000Sooooo00Co0000oooooooooooo00002?ooool0
1?l0003oooooooooool0000_ooooo`008oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o
0000ooooooooool00oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool000002_ooool01Ol0003o
oooooooooooooooo000000Sooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0
000_ooooo`008oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool00ooo
ool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o00005?ooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0;ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooooooooooo0000
00[ooooo00Go0000ooooooooooooooooo`000008ooooo`04o`000?ooooooooooo`0000Sooooo00Co
0000oooooooooooo0000;oooool002gooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`00
0?ooooooooooooooool000002_ooool01?l0003oooooooooool00009ooooo`04o`000?oooooooooo
o`0000Sooooo00Co0000oooooooooooo0000;oooool002gooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`00
000;ooooo`05o`000?ooooooooooooooool000002_ooool01?l0003oooooooooool00009ooooo`04
o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000;oooool002gooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00_ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05o`000?ooooooooooooooool000002_ooool01?l0003ooooooooo
ool00009ooooo`04o`000?ooooooooooo`0000Wooooo0_l0000`ooooo`00;?ooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02oooool01Ol0003ooooo
oooooooooooo000000_ooooo00Go0000ooooooooooooooooo`00000:ooooo`04o`000?oooooooooo
o`0000[ooooo00?o0000ooooool000002Oooool2o`00033ooooo000/ooooo`03o`000?oooooooooo
01Oooooo0_l0000Dooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03_ooool01Ol0
003ooooooooooooooooo000000kooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?oo
ooooooooooooool000002oooool00ol0003oooooo`00000:ooooo`03o`000?oooooo000000Wooooo
0_l0000`ooooo`00;?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0>ooooo`05o`000?ooooooooooooooool00000
3_ooool01Ol0003ooooooooooooooooo000000cooooo00Co0000oooooooooooo00002oooool00ol0
003oooooo`00000:ooooo`03o`000?oooooo000000Wooooo0_l0000`ooooo`00;?ooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0>ooooo`05o`000?ooooooooooooooool000003_ooool01Ol0003ooooooooooooooooo
000000cooooo00Co0000oooooooooooo00002oooool00ol0003oooooo`00000:ooooo`;o00002_oo
ool2o`00033ooooo000/ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00kooooo00Go0000ooooooooooooooooo`00
000>ooooo`05o`000?ooooooooooooooool000003?ooool01?l0003oooooooooool0000;ooooo`03
o`000?oooooo000000[ooooo0_l0000:ooooo`03o`000?oooooooooo02oooooo000/ooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo01gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00kooooo00Go0000ooooooooooooooooo`00000>ooooo`05o`000?oooooooooooooo
ool000003?ooool01?l0003oooooooooool0000;ooooo`;o00002oooool2o`0003cooooo000/oooo
o`03o`000?oooooooooo01Oooooo0_l0000Eooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool03_ooool01Ol0003ooooooooooooooooo000000oooooo00Co0000oooooooooooo00003?oo
ool00ol0003oooooo`00000<ooooo`;o0000BOooool002_ooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03oooool0
1Ol0003ooooooooooooooooo000000oooooo00Co0000oooooooooooo00003?ooool00ol0003ooooo
o`00000<ooooo`;o0000BOooool002_ooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03oooool01Ol0003ooooooooo
oooooooo000000oooooo00?o0000ooooool000003_ooool2o`0000gooooo00?o0000ooooooooool0
Aoooool002_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool03oooool01Ol0003ooooooooooooooooo000000oooooo
00?o0000ooooool000003_ooool2o`0005Oooooo000[ooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00oooooo00Go
0000ooooooooooooooooo`00000?ooooo`03o`000?oooooo000000kooooo00?o0000ooooooooool0
E_ooool002_ooooo00?o0000ooooooooool06?ooool2o`0001Kooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0?ooooo`05o`000?ooooooooooooooool000003oooool00ol0003ooooo
o`00001Wooooo`00:oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01?ooooo00Go
0000ooooooooooooooooo`00000Booooo`04o`000?ooooooooooo`0000oooooo0_l0001Xooooo`00
:oooool01Ol0003o<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b
<_oMgMd01Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Cooooo`05o`000?ooooooooooooooool000004_ooool0
1?l0003oooooooooool0000@ooooo`03o`000?oooooooooo06Kooooo000Zooooo`06o`000?mgMgOo
V9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Cooooo`05o`000?ooooooooooooooool000004_ooool00ol0003oooooo`00001jooooo`00
:_ooool00ol0003o410@ooooo`02ooooo`03oa0@4?oooooooooo00kooooo00?o0000ooooooooool0
0oooool3o`0001Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Oooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo01?ooooo00Go0000ooooooooooooooooo`00000Booooo`03o`000?oooooo000007[o
oooo000Zooooo`;o00000oooool00ol0003oooooooooo`0=ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool04oooool01Ol0003ooooooooooooooooo000001?ooooo0_l0001jooooo`00
:_ooool2o`0000?ooooo00?o0000ooooooooool02_ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Go
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool04oooool01Ol0003ooooooooooooooooo000001?ooooo00?o0000oooo
ooooool0NOooool002[ooooo00?o0000oa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool05?ooool00ol0003oooooo`00002@ooooo`00
:_ooool01_l0003oMgMgoiRHV?ooooooV9RHogMgM`cooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool08Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooo0000093ooooo000Zooooo`06o`000?o^k^ko<S8bo`00
0?lb<S;ok^k^3?ooool4o`0000Kooooo0_l0000Gooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo0000093ooooo000Yoooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`2?oooo
o`00:Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0:Sooooo000Yooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Jooooo`04o`00
0?ooooooooooo`000:_ooooo000Yooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Jooooo`04o`000?ooooooooooo`000:_ooooo000Yooooo`03o`00
0?oooooooooo01[ooooo0_l0000Gooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooool00000
Zoooool002Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooool00000Zoooool002Wooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool08_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo01cooooo0ol0002[ooooo`00:?ooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0Sooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0b_ooool002So
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool08oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0<[o
oooo000Xooooo`03o`000?oooooooooo01_ooooo0_l0000Hooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0<[ooooo
000Xooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`3:ooooo`00:?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0b_ooool002Sooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool09Oooool01Ol0003ooooooooooooooooo
00000<gooooo000Xooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo02Kooooo00Co0000oooooooooooo0000cOooool0
02Oooooo00?o0000ooooooooool07?ooool2o`0001Wooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0Vooooo`04o`000?ooooooooooo`000<gooooo000Wooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
02Kooooo0ol0003>ooooo`008oooool01Oo^k^ko<S8bo`000?lb<S;o000000Gooooo0_lQ8B46oooo
o`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`3hooooo`008oooool01Omg
MgOoV9RHoooooonHV9So000000Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool0n?ooool002?ooooo00Go410@ooooooooooooooooo`00000=ooooo`03ojVYZOmEEEGo
oooo00Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0n?ooool002?ooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool3o`0001Wooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`3hooooo`008oooool00ol0003oooooooooo`02o`00
00kooooo00?oEEEEolc<c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?Sooooo000Soooo
o`05oa0@4?ooooooooooo`000?l@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo0?Wooooo000Sooooo`05ogMgMonHV9Soooooo`000?mgMgL02oooool01Ol@413ooooooooooooo
oooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0nOooool002?ooooo00Gok^k^oc8b<_l0003o0000onk^
kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l0000Looooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0nOooool002Kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0nOooool002Gooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0n_ooool002Gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0n_ooool002Gooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
n_ooool002Gooooo00?o0000ooooooooool07_ooool2o`0001kooooo00Go0000oooooooooooooooo
o`00003mooooo`009Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01gooooo00Co
0000oooooooooooo0000o_ooool002Cooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`0Nooooo`?o0000o_ooool002Cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`3o
ooooob3ooooo000Tooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0oooooolPoooo
o`009?ooool00ol0003oooooooooo`0Oooooo`;o0000oooooolQooooo`009?ooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo0?oooooo8?ooool002?ooooo00?o0000ooooooooool08?oo
ool00ol0003oooooooooo`3oooooob3ooooo000Sooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool0oooooolPooooo`008oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
0?oooooo8?ooool002;ooooo00?o0000ooooooooool08Oooool2o`000?oooooo8Oooool002;ooooo
00?o0000ooooooooool08Oooool00ol0003oooooooooo`3oooooob3ooooo000Rooooo`03o`000?oo
oooooooo01Oooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo8?oo
ool002;ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo0?oooooo8?ooool0027ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo0?oooooo8?ooool0027ooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`05ooooo`?o0000oooooolPooooo`00?_ooool00ol0003oooooooooo`3oooooobSooooo
000nooooo`03o`000?oooooooooo0?oooooo:?ooool003kooooo00?o0000ooooooooool0oooooolX
ooooo`00??ooool00omEEEGoIVIVo`00003oooooob[ooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo0012ooooo`?o000000?o410@ooooooooool0oooooolQoooo
o`00A?ooool00ol@413o^[Zjooooo`3oooooob;ooooo0014ooooo`03oiRHV?lb<S;ooooo0?oooooo
8_ooool004Cooooo00?ogMgMo`000?nj^[X0oooooolRooooo`00A?ooool00omEEEGoMgMgodA4A03o
ooooob;ooooo0013ooooo`05omgMgOl@413oooooob4Q8OoMgMd0oooooolQooooo`00@oooool01OmV
IVKoQhN7oooooonHV9SoEEEE0?oooooo8Oooool004;ooooo00?ok^k^o`000?o^k^h00_ooool00ol0
003ogMgMooooo`3ooooooaoooooo0012ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@oooo
ooooool0oooooolNooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-5.66973, -1.05832, 0.1009, \
0.0129571}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.18254 0.0396825 0.309017 0.309017 [
[.38095 .29652 -3 -9 ]
[.38095 .29652 3 0 ]
[.57937 .29652 -6 -9 ]
[.57937 .29652 6 0 ]
[.77778 .29652 -6 -9 ]
[.77778 .29652 6 0 ]
[.97619 .29652 -6 -9 ]
[.97619 .29652 6 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.17004 0 -12 -4.5 ]
[.17004 0 0 4.5 ]
[.17004 .07725 -30 -4.5 ]
[.17004 .07725 0 4.5 ]
[.17004 .15451 -24 -4.5 ]
[.17004 .15451 0 4.5 ]
[.17004 .23176 -30 -4.5 ]
[.17004 .23176 0 4.5 ]
[.17004 .38627 -24 -4.5 ]
[.17004 .38627 0 4.5 ]
[.17004 .46353 -18 -4.5 ]
[.17004 .46353 0 4.5 ]
[.17004 .54078 -24 -4.5 ]
[.17004 .54078 0 4.5 ]
[.17004 .61803 -6 -4.5 ]
[.17004 .61803 0 4.5 ]
[.18254 .64303 -5 0 ]
[.18254 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.38095 .30902 m
.38095 .31527 L
s
[(5)] .38095 .29652 0 1 Mshowa
.57937 .30902 m
.57937 .31527 L
s
[(10)] .57937 .29652 0 1 Mshowa
.77778 .30902 m
.77778 .31527 L
s
[(15)] .77778 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(20)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.22222 .30902 m
.22222 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30159 .30902 m
.30159 .31277 L
s
.34127 .30902 m
.34127 .31277 L
s
.42063 .30902 m
.42063 .31277 L
s
.46032 .30902 m
.46032 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.53968 .30902 m
.53968 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.65873 .30902 m
.65873 .31277 L
s
.69841 .30902 m
.69841 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.81746 .30902 m
.81746 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.89683 .30902 m
.89683 .31277 L
s
.93651 .30902 m
.93651 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.10317 .30902 m
.10317 .31277 L
s
.06349 .30902 m
.06349 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.18254 0 m
.18879 0 L
s
[(-1)] .17004 0 1 0 Mshowa
.18254 .07725 m
.18879 .07725 L
s
[(-0.75)] .17004 .07725 1 0 Mshowa
.18254 .15451 m
.18879 .15451 L
s
[(-0.5)] .17004 .15451 1 0 Mshowa
.18254 .23176 m
.18879 .23176 L
s
[(-0.25)] .17004 .23176 1 0 Mshowa
.18254 .38627 m
.18879 .38627 L
s
[(0.25)] .17004 .38627 1 0 Mshowa
.18254 .46353 m
.18879 .46353 L
s
[(0.5)] .17004 .46353 1 0 Mshowa
.18254 .54078 m
.18879 .54078 L
s
[(0.75)] .17004 .54078 1 0 Mshowa
.18254 .61803 m
.18879 .61803 L
s
[(1)] .17004 .61803 1 0 Mshowa
.125 Mabswid
.18254 .01545 m
.18629 .01545 L
s
.18254 .0309 m
.18629 .0309 L
s
.18254 .04635 m
.18629 .04635 L
s
.18254 .0618 m
.18629 .0618 L
s
.18254 .09271 m
.18629 .09271 L
s
.18254 .10816 m
.18629 .10816 L
s
.18254 .12361 m
.18629 .12361 L
s
.18254 .13906 m
.18629 .13906 L
s
.18254 .16996 m
.18629 .16996 L
s
.18254 .18541 m
.18629 .18541 L
s
.18254 .20086 m
.18629 .20086 L
s
.18254 .21631 m
.18629 .21631 L
s
.18254 .24721 m
.18629 .24721 L
s
.18254 .26266 m
.18629 .26266 L
s
.18254 .27812 m
.18629 .27812 L
s
.18254 .29357 m
.18629 .29357 L
s
.18254 .32447 m
.18629 .32447 L
s
.18254 .33992 m
.18629 .33992 L
s
.18254 .35537 m
.18629 .35537 L
s
.18254 .37082 m
.18629 .37082 L
s
.18254 .40172 m
.18629 .40172 L
s
.18254 .41717 m
.18629 .41717 L
s
.18254 .43262 m
.18629 .43262 L
s
.18254 .44807 m
.18629 .44807 L
s
.18254 .47898 m
.18629 .47898 L
s
.18254 .49443 m
.18629 .49443 L
s
.18254 .50988 m
.18629 .50988 L
s
.18254 .52533 m
.18629 .52533 L
s
.18254 .55623 m
.18629 .55623 L
s
.18254 .57168 m
.18629 .57168 L
s
.18254 .58713 m
.18629 .58713 L
s
.18254 .60258 m
.18629 .60258 L
s
.25 Mabswid
.18254 0 m
.18254 .61803 L
s
gsave
.18254 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .56189 m
.03279 .59843 L
s
.03279 .59843 m
.0388 .61803 L
s
.09412 .61803 m
.10458 .57484 L
.12493 .45709 L
.14349 .32454 L
.16419 .17507 L
.17329 .1176 L
.18333 .0654 L
.18795 .04644 L
.19292 .03008 L
.19521 .02407 L
.19761 .01884 L
.19967 .01529 L
.20192 .01238 L
.20325 .01115 L
.20451 .01033 L
.20564 .00987 L
.20686 .00969 L
.2075 .00972 L
.2082 .00986 L
.20893 .01011 L
.20961 .01045 L
.21083 .01132 L
.21215 .01261 L
.21337 .01415 L
.2147 .01619 L
.21712 .0209 L
.22166 .03318 L
.22699 .05316 L
.23201 .07722 L
.24137 .13445 L
.26236 .30227 L
.28078 .45329 L
.28582 .48804 L
.29122 .51983 L
.29632 .54368 L
.29857 .55208 L
.30096 .55946 L
.30218 .56259 L
.30352 .56553 L
.30475 .56776 L
.30588 .5694 L
.30721 .57082 L
.30791 .57135 L
.30864 .57174 L
.30988 .57202 L
.31058 .57196 L
.31123 .57177 L
.3125 .57101 L
.31369 .56981 L
.31477 .56836 L
Mistroke
.31593 .56636 L
.31854 .5603 L
.32094 .55282 L
.32582 .53216 L
.33119 .5015 L
.34202 .41836 L
.36314 .22009 L
.36799 .17835 L
.37315 .13944 L
.37792 .11001 L
.38241 .08935 L
.38459 .08202 L
.38572 .07899 L
.38695 .07625 L
.38822 .07409 L
.38892 .07319 L
.38957 .07254 L
.39073 .07182 L
.39197 .07169 L
.39266 .07191 L
.39331 .0723 L
.39402 .07294 L
.39477 .07385 L
.39603 .07593 L
.39741 .07902 L
.39997 .08689 L
.40237 .09676 L
.40713 .12321 L
.41148 .15466 L
.42129 .24488 L
.43126 .34956 L
.43674 .40466 L
.44189 .45064 L
.44671 .48573 L
.44925 .50036 L
.45193 .51256 L
.45418 .52007 L
.45547 .52314 L
.45666 .52522 L
.45776 .52643 L
.45876 .52696 L
.45992 .52687 L
.46102 .5261 L
.46215 .5246 L
.46321 .52253 L
.46437 .51955 L
.46563 .51549 L
.46819 .50459 L
.47053 .49159 L
.47481 .46094 L
Mistroke
.47932 .42041 L
.48895 .31589 L
.49923 .20327 L
.50456 .15629 L
.50717 .13804 L
.50958 .1246 L
.51178 .11542 L
.51288 .11196 L
.5141 .10909 L
.51531 .10722 L
.51662 .10633 L
.51786 .10659 L
.51899 .10775 L
.52012 .10981 L
.52133 .11298 L
.52247 .11689 L
.5235 .12118 L
.52603 .1347 L
.52841 .15107 L
.53736 .23825 L
.54716 .35638 L
.55251 .41612 L
.55512 .44114 L
.55749 .4607 L
.55953 .47466 L
.56175 .4865 L
.56297 .49143 L
.5641 .49494 L
.56517 .49734 L
.56631 .49885 L
.56746 .49927 L
.56869 .49849 L
.56985 .49659 L
.57091 .49386 L
.57215 .48949 L
.57351 .48327 L
.57598 .46824 L
.58695 .35544 L
.59233 .28591 L
.59729 .22464 L
.60171 .17864 L
.60422 .15816 L
.60657 .14359 L
.6078 .13787 L
.60893 .13387 L
.61022 .13076 L
.61145 .12933 L
.61274 .12943 L
.61392 .13098 L
.61523 .1343 L
Mistroke
.61589 .13661 L
.61661 .13966 L
.61908 .15369 L
.62168 .1743 L
.62632 .22362 L
.63679 .36274 L
.64116 .41551 L
.64356 .43938 L
.64583 .45746 L
.64712 .46554 L
.6478 .46911 L
.64852 .47236 L
.64979 .47672 L
.65096 .47914 L
.65213 .47999 L
.65323 .47935 L
.65444 .47704 L
.65573 .47269 L
.65642 .46961 L
.65707 .46623 L
.65827 .4587 L
.66098 .43642 L
.66586 .38071 L
.67161 .30019 L
.6769 .22767 L
.67933 .19923 L
.6816 .17722 L
.68396 .15992 L
.68521 .1534 L
.68592 .15059 L
.68656 .14858 L
.6872 .14707 L
.68789 .14608 L
.68913 .14587 L
.68981 .14663 L
.69045 .14791 L
.69116 .14994 L
.69192 .15285 L
.69321 .15951 L
.69457 .16875 L
.69699 .19054 L
.70201 .25275 L
.70656 .32004 L
.71146 .38985 L
.71404 .42045 L
.71545 .43441 L
.71677 .44536 L
.71799 .45356 L
.71911 .45926 L
.72036 .4635 L
Mistroke
.72104 .46486 L
.72169 .46551 L
.72282 .46513 L
.72386 .46307 L
.72501 .45893 L
.72622 .45242 L
.72727 .44513 L
.72841 .4356 L
.73046 .41431 L
.73514 .35086 L
.73976 .27924 L
.74469 .21036 L
.74615 .19419 L
.74753 .18134 L
.74876 .17205 L
.7494 .16814 L
.75011 .16458 L
.75138 .16015 L
.75208 .15887 L
.75273 .1584 L
.7539 .15937 L
.75515 .16297 L
.75583 .16601 L
.75655 .17008 L
.75785 .17946 L
.7594 .19389 L
.7608 .20973 L
.76616 .28778 L
.77106 .36591 L
.77374 .40298 L
.77505 .41822 L
.77624 .43009 L
.77734 .43916 L
.77855 .44673 L
.77982 .45196 L
.78102 .45418 L
.78234 .45348 L
.78301 .45187 L
.78375 .44913 L
.78505 .44188 L
.78627 .43236 L
.78858 .40778 L
.79071 .37896 L
.79549 .30146 L
.79803 .25969 L
.80075 .2201 L
.80206 .20401 L
.80331 .19122 L
.80442 .18197 L
.80563 .17456 L
Mistroke
.80692 .16985 L
.80757 .16876 L
.80829 .16858 L
.80955 .17086 L
.81073 .17598 L
.81146 .18048 L
.81214 .18569 L
.81342 .1978 L
.81631 .23468 L
.82127 .31682 L
.82593 .39186 L
.82719 .40815 L
.82851 .42256 L
.8292 .42881 L
.82996 .43458 L
.83066 .43881 L
.8313 .44175 L
.83252 .44486 L
.83382 .44445 L
.83502 .44062 L
.83616 .434 L
.83722 .42537 L
.83839 .41327 L
.84075 .38164 L
.84498 .30971 L
.84956 .23252 L
.85082 .21529 L
.85216 .19991 L
.85342 .1887 L
.85457 .18162 L
.85585 .17742 L
.85657 .17684 L
.85724 .17747 L
.85846 .18151 L
.85975 .18975 L
.86097 .20099 L
.86211 .2143 L
.86469 .2528 L
.86945 .3385 L
.87179 .37822 L
.87396 .40819 L
.87518 .42103 L
.87648 .43085 L
.87778 .43638 L
.87852 .4375 L
.87922 .43719 L
.88043 .43353 L
.88153 .42678 L
.88275 .41581 L
.88403 .40058 L
Mistroke
.88918 .31327 L
.89189 .26297 L
.89332 .23902 L
.89483 .21721 L
.89613 .20218 L
.89683 .19589 L
.89757 .19053 L
.89888 .18487 L
.90011 .18407 L
.90074 .1854 L
.90144 .18822 L
.90271 .1969 L
.90394 .20949 L
.90509 .22445 L
.9099 .30959 L
.91225 .35439 L
.91442 .39019 L
.91566 .40663 L
.91698 .41981 L
.9183 .42812 L
.91904 .43047 L
.91974 .43108 L
.92096 .42843 L
.92207 .42198 L
.92335 .41 L
.92456 .39461 L
.9297 .30153 L
.93243 .2498 L
.93386 .22687 L
.93464 .21627 L
.93536 .20784 L
.93661 .19694 L
.93727 .19314 L
.93797 .19065 L
.93922 .19036 L
.94035 .19471 L
.94151 .2035 L
.94276 .21762 L
.94503 .25335 L
.95002 .3519 L
.95253 .3941 L
.95322 .40311 L
.95396 .41124 L
.95466 .41733 L
.9553 .42146 L
.95652 .42538 L
.95765 .42415 L
.95889 .41745 L
.96022 .40452 L
.96148 .38719 L
Mistroke
.96267 .36723 L
.96489 .32365 L
.96713 .27727 L
.96949 .23418 L
.97047 .22004 L
.97151 .20807 L
.97266 .19921 L
.97372 .19536 L
.97501 .1966 L
.97619 .20333 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCacheValid->False],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.18254 0.0396825 0.309017 0.309017 [
[.38095 .29652 -3 -9 ]
[.38095 .29652 3 0 ]
[.57937 .29652 -6 -9 ]
[.57937 .29652 6 0 ]
[.77778 .29652 -6 -9 ]
[.77778 .29652 6 0 ]
[.97619 .29652 -6 -9 ]
[.97619 .29652 6 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.17004 0 -12 -4.5 ]
[.17004 0 0 4.5 ]
[.17004 .07725 -30 -4.5 ]
[.17004 .07725 0 4.5 ]
[.17004 .15451 -24 -4.5 ]
[.17004 .15451 0 4.5 ]
[.17004 .23176 -30 -4.5 ]
[.17004 .23176 0 4.5 ]
[.17004 .38627 -24 -4.5 ]
[.17004 .38627 0 4.5 ]
[.17004 .46353 -18 -4.5 ]
[.17004 .46353 0 4.5 ]
[.17004 .54078 -24 -4.5 ]
[.17004 .54078 0 4.5 ]
[.17004 .61803 -6 -4.5 ]
[.17004 .61803 0 4.5 ]
[.18254 .64303 -5 0 ]
[.18254 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.38095 .30902 m
.38095 .31527 L
s
[(5)] .38095 .29652 0 1 Mshowa
.57937 .30902 m
.57937 .31527 L
s
[(10)] .57937 .29652 0 1 Mshowa
.77778 .30902 m
.77778 .31527 L
s
[(15)] .77778 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(20)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.22222 .30902 m
.22222 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30159 .30902 m
.30159 .31277 L
s
.34127 .30902 m
.34127 .31277 L
s
.42063 .30902 m
.42063 .31277 L
s
.46032 .30902 m
.46032 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.53968 .30902 m
.53968 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.65873 .30902 m
.65873 .31277 L
s
.69841 .30902 m
.69841 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.81746 .30902 m
.81746 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.89683 .30902 m
.89683 .31277 L
s
.93651 .30902 m
.93651 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.10317 .30902 m
.10317 .31277 L
s
.06349 .30902 m
.06349 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.18254 0 m
.18879 0 L
s
[(-1)] .17004 0 1 0 Mshowa
.18254 .07725 m
.18879 .07725 L
s
[(-0.75)] .17004 .07725 1 0 Mshowa
.18254 .15451 m
.18879 .15451 L
s
[(-0.5)] .17004 .15451 1 0 Mshowa
.18254 .23176 m
.18879 .23176 L
s
[(-0.25)] .17004 .23176 1 0 Mshowa
.18254 .38627 m
.18879 .38627 L
s
[(0.25)] .17004 .38627 1 0 Mshowa
.18254 .46353 m
.18879 .46353 L
s
[(0.5)] .17004 .46353 1 0 Mshowa
.18254 .54078 m
.18879 .54078 L
s
[(0.75)] .17004 .54078 1 0 Mshowa
.18254 .61803 m
.18879 .61803 L
s
[(1)] .17004 .61803 1 0 Mshowa
.125 Mabswid
.18254 .01545 m
.18629 .01545 L
s
.18254 .0309 m
.18629 .0309 L
s
.18254 .04635 m
.18629 .04635 L
s
.18254 .0618 m
.18629 .0618 L
s
.18254 .09271 m
.18629 .09271 L
s
.18254 .10816 m
.18629 .10816 L
s
.18254 .12361 m
.18629 .12361 L
s
.18254 .13906 m
.18629 .13906 L
s
.18254 .16996 m
.18629 .16996 L
s
.18254 .18541 m
.18629 .18541 L
s
.18254 .20086 m
.18629 .20086 L
s
.18254 .21631 m
.18629 .21631 L
s
.18254 .24721 m
.18629 .24721 L
s
.18254 .26266 m
.18629 .26266 L
s
.18254 .27812 m
.18629 .27812 L
s
.18254 .29357 m
.18629 .29357 L
s
.18254 .32447 m
.18629 .32447 L
s
.18254 .33992 m
.18629 .33992 L
s
.18254 .35537 m
.18629 .35537 L
s
.18254 .37082 m
.18629 .37082 L
s
.18254 .40172 m
.18629 .40172 L
s
.18254 .41717 m
.18629 .41717 L
s
.18254 .43262 m
.18629 .43262 L
s
.18254 .44807 m
.18629 .44807 L
s
.18254 .47898 m
.18629 .47898 L
s
.18254 .49443 m
.18629 .49443 L
s
.18254 .50988 m
.18629 .50988 L
s
.18254 .52533 m
.18629 .52533 L
s
.18254 .55623 m
.18629 .55623 L
s
.18254 .57168 m
.18629 .57168 L
s
.18254 .58713 m
.18629 .58713 L
s
.18254 .60258 m
.18629 .60258 L
s
.25 Mabswid
.18254 0 m
.18254 .61803 L
s
gsave
.18254 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .3489 m
.04262 .46308 L
.06244 .56472 L
.07286 .60521 L
s
.07286 .60521 m
.07701 .61803 L
s
.12063 .61803 m
.12452 .60518 L
.13461 .56133 L
.14558 .49928 L
.16497 .36312 L
.18637 .20128 L
.19611 .13525 L
.20123 .10476 L
.20662 .0767 L
.21136 .05599 L
.21654 .03812 L
.21881 .03196 L
.22125 .02659 L
.22354 .02271 L
.22455 .02137 L
.22563 .02019 L
.22682 .0192 L
.22794 .01857 L
.22862 .01833 L
.22927 .01819 L
.23048 .01821 L
.23175 .0186 L
.23294 .0193 L
.23423 .02045 L
.23561 .02211 L
.2381 .02625 L
.24044 .03149 L
.24482 .04472 L
.25003 .06618 L
.25481 .09107 L
.26561 .16312 L
.28608 .33625 L
.29606 .421 L
.30515 .48754 L
.30968 .5146 L
.31459 .53824 L
.31684 .54685 L
.31923 .55433 L
.32127 .55933 L
.32234 .56142 L
.32352 .56329 L
.32476 .56477 L
.32607 .56578 L
.32728 .5662 L
.3284 .56614 L
.32909 .5659 L
.32974 .56552 L
.33095 .56443 L
.33225 .56269 L
.33366 .56016 L
Mistroke
.33607 .55427 L
.33862 .54592 L
.34318 .52565 L
.34812 .49645 L
.35264 .46395 L
.36279 .37528 L
.38112 .19964 L
.38591 .16003 L
.39101 .12459 L
.39537 .10114 L
.39785 .09099 L
.40018 .08374 L
.40139 .08089 L
.40271 .0785 L
.40338 .07758 L
.4041 .07683 L
.40538 .07605 L
.40667 .07603 L
.40789 .0767 L
.40898 .07788 L
.41016 .07978 L
.41145 .08259 L
.41288 .08657 L
.41576 .09739 L
.41843 .11064 L
.42093 .12571 L
.43132 .21175 L
.44119 .31488 L
.45091 .41508 L
.45515 .45239 L
.45972 .48546 L
.4623 .50003 L
.46466 .51052 L
.46693 .51778 L
.46807 .52037 L
.46932 .52236 L
.47 .52307 L
.47065 .5235 L
.47187 .52363 L
.47318 .5228 L
.47392 .52189 L
.47461 .52076 L
.47574 .51827 L
.477 .51465 L
.47954 .50457 L
.48193 .49186 L
.48411 .4776 L
.48903 .43723 L
.49793 .34322 L
.50709 .23833 L
Mistroke
.51212 .18709 L
.51687 .14808 L
.51957 .13123 L
.52099 .12414 L
.5225 .11805 L
.52376 .11411 L
.52443 .11246 L
.52515 .11104 L
.52642 .10944 L
.5276 .10899 L
.52888 .10963 L
.52961 .11052 L
.53028 .11169 L
.53151 .11467 L
.53282 .11903 L
.53532 .13068 L
.53758 .14484 L
.54776 .24307 L
.5585 .37385 L
.56293 .42224 L
.56767 .46335 L
.56907 .47274 L
.57039 .48031 L
.57168 .48639 L
.57287 .49083 L
.574 .49396 L
.57519 .4961 L
.57639 .49702 L
.57772 .49658 L
.57895 .4948 L
.57964 .49322 L
.58029 .49137 L
.58147 .48705 L
.58273 .48116 L
.58514 .46632 L
.58732 .44906 L
.59264 .39427 L
.59766 .33157 L
.60656 .21861 L
.609 .1924 L
.61162 .1685 L
.61409 .15079 L
.61518 .14464 L
.61634 .13931 L
.61759 .13503 L
.61874 .13243 L
.61998 .13114 L
.62069 .1311 L
.62135 .13154 L
.62254 .13345 L
Mistroke
.62363 .13649 L
.62483 .14121 L
.6261 .14772 L
.62865 .16545 L
.63102 .18699 L
.63641 .25003 L
.64527 .37039 L
.64994 .42508 L
.65229 .44674 L
.65364 .45691 L
.65488 .46459 L
.65624 .47117 L
.65699 .47391 L
.6577 .47592 L
.65897 .47802 L
.65969 .47837 L
.66035 .47815 L
.66163 .47624 L
.66279 .47283 L
.66344 .47025 L
.66413 .46693 L
.66539 .45951 L
.66791 .43963 L
.67057 .41212 L
.67533 .35051 L
.68032 .27847 L
.68505 .21551 L
.68711 .19266 L
.6893 .17276 L
.69044 .16445 L
.6917 .15707 L
.69284 .15207 L
.69391 .14894 L
.69507 .14728 L
.6963 .14751 L
.69734 .14933 L
.69848 .15301 L
.69972 .15894 L
.70104 .16744 L
.70341 .18801 L
.70615 .21912 L
.70874 .25399 L
.71358 .32627 L
.71786 .38759 L
.7202 .41606 L
.72239 .43766 L
.72362 .44731 L
.72475 .45434 L
.726 .46002 L
.7267 .46216 L
Mistroke
.72735 .46353 L
.72849 .46434 L
.72954 .46331 L
.73069 .46022 L
.73192 .45471 L
.74149 .34741 L
.74672 .26591 L
.74927 .22931 L
.75158 .20088 L
.75261 .19027 L
.75372 .18034 L
.75468 .17321 L
.75574 .167 L
.75687 .16241 L
.75806 .15987 L
.75916 .15969 L
.7602 .16143 L
.76141 .16584 L
.76257 .17233 L
.76361 .18 L
.76474 .19024 L
.76963 .25288 L
.77444 .33026 L
.77898 .39794 L
.78149 .42648 L
.7829 .43847 L
.78421 .44652 L
.7853 .45094 L
.78651 .45318 L
.78777 .45255 L
.78894 .4492 L
.78961 .44612 L
.79034 .44181 L
.79167 .43155 L
.79416 .4046 L
.79975 .31884 L
.80224 .27688 L
.80493 .23497 L
.80725 .20484 L
.80856 .1913 L
.80979 .18141 L
.81094 .17468 L
.81218 .17048 L
.8135 .16953 L
.81469 .17187 L
.8158 .17673 L
.81701 .18483 L
.81814 .19505 L
.81919 .20651 L
.82423 .28208 L
Mistroke
.8268 .32691 L
.82957 .37279 L
.83095 .39312 L
.83227 .40995 L
.83355 .42353 L
.83474 .43329 L
.83586 .43978 L
.83705 .44361 L
.83773 .44433 L
.83837 .44401 L
.83957 .44085 L
.84021 .4378 L
.84091 .43341 L
.84233 .42133 L
.84364 .40659 L
.84486 .39016 L
.85058 .29307 L
.85302 .25105 L
.8556 .21352 L
.85695 .19843 L
.85767 .19195 L
.85844 .18624 L
.85915 .18224 L
.85979 .17965 L
.86106 .17759 L
.86232 .1796 L
.86349 .18505 L
.86477 .19485 L
.86614 .20938 L
.86868 .24557 L
.87098 .28557 L
.87557 .36837 L
.87682 .388 L
.87815 .4059 L
.8793 .41848 L
.88053 .42856 L
.8817 .43451 L
.88275 .43677 L
.88382 .43593 L
.88483 .43224 L
.886 .42452 L
.88709 .41425 L
.88955 .38141 L
.89417 .29785 L
.8966 .25347 L
.89793 .23208 L
.89916 .21498 L
.90034 .20179 L
.90141 .19283 L
.9026 .18659 L
Mistroke
.90387 .18449 L
.90494 .18646 L
.90609 .1924 L
.90718 .20148 L
.90819 .21265 L
.91332 .29892 L
.91614 .35319 L
.91754 .3773 L
.91883 .39665 L
.92003 .4113 L
.92132 .42264 L
.92205 .42694 L
.92274 .42947 L
.92403 .4301 L
.92522 .42593 L
.92632 .41818 L
.92752 .40564 L
.92879 .38831 L
.9331 .309 L
.93548 .26263 L
.93773 .22535 L
.939 .20927 L
.93972 .20218 L
.94038 .19704 L
.94155 .19149 L
.9428 .19073 L
.94396 .19486 L
.94505 .20284 L
.94625 .21586 L
.94753 .23429 L
.95278 .33551 L
.95416 .36211 L
.95564 .38701 L
.95636 .39729 L
.95703 .40568 L
.9583 .41756 L
.95948 .42369 L
.96056 .42488 L
.96175 .42117 L
.96301 .41169 L
.96428 .39683 L
.96547 .37876 L
.96817 .32725 L
.97619 .1989 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00??ooool4o`000003oa0@4?oooooooooo0?oooooo
9_ooool003kooooo00?o0000ooooooooool0oooooolXooooo`00<oooool6o`0000Gooooo00?o0000
ooooooooool0oooooolXooooo`00?_ooool00ol0003oooooooooo`05ooooo`?o0000oooooolPoooo
o`00?_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo8?ooool003kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooob3ooooo000nooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0oooooolPooooo`00??ooool00omEEEGoIVIVo`000007
ooooo`03o`000?oooooooooo0?oooooo8?ooool004Kooooo0_l0000<ooooo`;o0000oooooolCoooo
o`00A_ooool00ol0003oooooooooo`0:ooooo`Co0000oooooolBooooo`00A_ooool00ol0003ooooo
ooooo`0:ooooo`04o`000?ooooooooooo`000?oooooo4_ooool004Kooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo3oooool004Kooooo0_l0
000:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0ooooool?ooooo`00A_ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0ooooool>
ooooo`00A_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0ooooool>ooooo`00A_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0ooooool>ooooo`00A_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0ooooool=ooooo`00A_ooool2o`0000Sooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`3oooooo`gooooo0016ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooo`gooooo0016oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`3ooooo
o`cooooo0016ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`3oooooo`cooooo0016ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`3oooooo`cooooo0016ooooo`;o00001oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo0?oooooo2oooool004Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0?oooooo2oooool002?ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o
0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool0ooooool;ooooo`008oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0ooooool;ooooo`006oooool6
o`0000;ooooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0;Oooool2o`000=_ooooo000Sooooo`05o`000?ooooooooooooooool000003_oo
ool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo0ol00004ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool0;?ooool3o`000=_ooooo000Sooooo`05o`000?oooooo
ooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
:oooool01?l0003oooooooooool0003Jooooo`008oooool01Ol@413ooooooooooooooooo410@00ko
oooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0[ooooo`04o`000?ooooooooooo`00
0=[ooooo000Sooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooooooooooo
<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool0:oooool01Ol0003ooooooooooooooooo00000=Wooooo000S
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0eoooool004Kooooo0_l00004ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo0=Kooooo0016ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0e_ooool004Ko
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3Fooooo`00A_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0:?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo0=Kooooo0016ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0e_ooool004Kooooo0_l00004ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool0:?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01oooooo0_l0002e
ooooo`00A_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0:?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ool00000]Oooool004Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Nooooo`04
o`000?ooooooooooo`000;Cooooo0016ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool07Oooool01?l0003oooooooooool0002dooooo`00A_ooool2o`0000?ooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool07Oooool01?l0003oooooooooool0002dooooo`00A_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo01cooooo00Go0000ooooooooooooooooo`00002dooooo`00A_ooool01Ol0003o
oooooooooooooooo000001?ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2aoooo
o`00A_ooool01Ol0003ooooooooooooooooo000001?ooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0Gooooo`;o0000V?ooool004Kooooo00Go0000ooooooooooooooooo`00000Coooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05oooool2o`0009Sooooo0016ooooo`;o
00000_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool05_ooool00ol0003oooooo`00002Hooooo`00A_ooool01Ol0003ooooooooooooooooo000001Co
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Eooooo`04o`000?ooooooooooo`00
09Oooooo000[ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`05o`000?ooooooooooooooool000005?ooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo01Gooooo00Co0000oooooooooooo0000Uoooool002_ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`04o`00
0?ooooooooooo`0001Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Eooooo`04
o`000?ooooooooooo`0001Cooooo0_l00021ooooo`008oooool6o`0000;ooooo00Go410@oooooooo
oooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00005Oooool0
0ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Cooooo00Go0000ooooooooooooooooo`00
000Dooooo`;o0000POooool002_ooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb
<S;ooooo00Cooooo1?l0000Eooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05?oo
ool01Ol0003ooooooooooooooooo000001Cooooo00?o0000ooooool00000P?ooool002_ooooo00Go
0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool01?l0003o
ooooooooool0000Fooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo017ooooo00?o0000ooooool00000P?ooool002_o
oooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00Co0000oooo
oooooooo00005_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo0000017ooooo0_l0001]
ooooo`00:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
1?l0003oooooooooool0000Fooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo013ooooo00Go0000oooooooooooooooo
o`00000@ooooo`;o0000KOooool002_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co0000
1_ooool01?l0003oooooooooool0000Fooooo`03o`000?oooooooooo02;ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo013ooooo00Go0000oooooooo
ooooooooo`00000@ooooo`;o0000KOooool004Kooooo0ol0000Gooooo`03o`000?oooooooooo02;o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo013o
oooo00Go0000ooooooooooooooooo`00000@ooooo`;o00003oooool2o`0005cooooo0016ooooo`03
o`000?oooooo000001Oooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool04?ooool01Ol0003ooooooooooooooooo0000
00oooooo00Co0000oooooooooooo00003_ooool2o`0005cooooo0016ooooo`03o`000?oooooo0000
01Oooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool03oooool01Ol0003ooooooooooooooooo000000oooooo00Co0000
oooooooooooo00003_ooool2o`0000kooooo00?o0000ooooooooool0Boooool004Kooooo00?o0000
ooooool000006?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0?ooooo`05o`000?ooooooooooooooool000003ooo
ool01?l0003oooooooooool0000>ooooo`;o00003Oooool2o`0004gooooo0016ooooo`03o`000?oo
oooo000001Sooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool03oooool01Ol0003ooooooooooooooooo000000oooooo
00Co0000oooooooooooo00003_ooool00ol0003oooooo`00000<ooooo`;o00003?ooool00ol0003o
ooooooooo`0nooooo`00A_ooool3o`0001Sooooo00?o0000ooooooooool08?ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00gooooo00Co0000oooooooooooo00003Oooool01?l0003o
ooooooooool0000<ooooo`;o00003?ooool00ol0003oooooooooo`0nooooo`00A_ooool00ol0003o
ooooo`00000Hooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0=ooooo`04o`000?ooooooooooo`0000gooooo00Co0000oooooooooooo00003?ooool2
o`0000cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0booooo`00A_ooool2o`00
01Wooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00gooooo00Co0000oooooooooooo00003Oooool01?l0003oooooooooool0000<ooooo`03o`000?oo
oooo000000[ooooo00?o0000ooooool000002_ooool00ol0003oooooooooo`0booooo`00A_ooool2
o`0001Wooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00cooooo00Go0000ooooooooooooooooo`00000=ooooo`04o`000?ooooooooooo`0000cooooo
00?o0000ooooool000002_ooool00ol0003oooooo`000009ooooo`;o0000=?ooool004Kooooo0_l0
000Iooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0<ooooo`05o`000?ooooooooooooooool000003Oooool01?l0003oooooooooool0000;ooooo`04
o`000?ooooooooooo`0000[ooooo00?o0000ooooool000002Oooool2o`0000[ooooo00?o0000oooo
ooooool09oooool004Kooooo0_l0000Iooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0<ooooo`05o`000?ooooooooooooooool000003Oooool01?l0
003oooooooooool0000;ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooool000002Ooo
ool00ol0003oooooo`000009ooooo`03o`000?oooooooooo02Oooooo0016ooooo`;o00006Oooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02oooool0
1Ol0003ooooooooooooooooo000000gooooo00Co0000oooooooooooo00002oooool01?l0003ooooo
ooooool0000:ooooo`03o`000?oooooo000000Wooooo00?o0000ooooool000002Oooool00ol0003o
ooooooooo`0Wooooo`00A_ooool2o`0001[ooooo00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0:ooooo`04o`000?ooooooooooo`0000_ooooo00Co0000oooooooooooo00002_ooool00ol0
003oooooo`000009ooooo`03o`000?oooooo000000Wooooo00?o0000ooooooooool09oooool004Ko
oooo0_l0000Jooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool01?l0003o
ooooooooool0000;ooooo`04o`000?ooooooooooo`0000Wooooo00Co0000oooooooooooo00002Ooo
ool00ol0003oooooo`000009ooooo`03o`000?oooooooooo02Oooooo0016ooooo`;o00006_ooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooo00002ooo
ool01?l0003oooooooooool00009ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooool0
00002Oooool00ol0003oooooooooo`0Wooooo`00A_ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo01kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool02_ooool01?l0003oooooooooool0000;ooooo`04
o`000?ooooooooooo`0000Wooooo00Co0000oooooooooooo00002Oooool00ol0003oooooo`000009
ooooo`03o`000?oooooooooo02Oooooo0016ooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?ooooooooooooooool000002oooool0
1?l0003oooooooooool00009ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooool00000
2Oooool00ol0003oooooooooo`0Wooooo`008oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000oooooooo
ooooooooo`00000;ooooo`04o`000?ooooooooooo`0000Wooooo00Co0000oooooooooooo00002Ooo
ool00ol0003oooooo`000008ooooo`03o`000?oooooooooo02Sooooo000Sooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`05o`00
0?ooooooooooooooool000002?ooool01?l0003oooooooooool00009ooooo`04o`000?oooooooooo
o`0000Oooooo00?o0000ooooooooool0:?ooool001_ooooo1_l00002ooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP09ooooo`03o`000?oooooooooo00?ooooo0ol0000I
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Sooooo00Go0000ooooooooooooooooo`000008ooooo`04o`000?oo
ooooooooo`0000Wooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`0Xooooo`00
8oooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo
<S8booooo`04ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00Co0000oooooooooooo00002Oooool01?l0
003oooooooooool00007ooooo`03o`000?oooooooooo02Sooooo000Sooooo`05o`000?oooooooooo
ooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Ooo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool000002?ooool01?l0003ooooo
ooooool00007ooooo`03o`000?oooooooooo02Sooooo000Sooooo`05oa0@4?ooooooooooooooool@
41003oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo0_l0000Looooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`05
o`000?ooooooooooooooool000002?ooool01?l0003oooooooooool00007ooooo`03o`000?oooooo
oooo02Sooooo000Sooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonH
V9So410@00Cooooo00?o0000ooooooooool01_ooool2o`0001cooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00Go0000oooooooooooooooo
o`000008ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool0:?ooool002?ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`00
00Gooooo0ol0000Kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`06ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooo
oooo000000Oooooo00?o0000ooooooooool0:?ooool004Gooooo0_l0000Looooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`05o`000?oooooo
ooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool0
:?ooool004Gooooo0_l0000Looooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooo
oooooooooooo000000Oooooo00?o0000ooooooooool0:?ooool004Gooooo0_l0000Looooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`05o`00
0?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000oooo
ooooool0:?ooool004Gooooo0_l0000Looooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool000001oooool01Ol0
003ooooooooooooooooo000000Oooooo00?o0000ooooooooool0:?ooool004Cooooo00Co0000oooo
ool0003o00006oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01_ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooooooooooooooo
o`000007ooooo`03o`000?oooooooooo02Sooooo0014ooooo`03o`000?oooooo000001gooooo00?o
0000ooooooooool06oooool3o`000003oc8b<_oMgMgooooo00gooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0;ooooo`04o`000?ooooooooooooooo`Co000000[o410@oooooooooooo
k^k^oc8b<_l0003o<S8bonk^k_oooooo00002Oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool02Oooool01?l0003oooooooooooooool4o`000005oa0@
4?oooooooooooooooom4A4@00_l000000olb<S;ogMgMo`000006ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`05o`000?oooooooooooooo
ool000001oooool01_l0003ooooooooooooooooo0000ooooo`Ko00000_ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^02Cooooo0014ooooo`03o`000?oooooo000001gooooo00?o0000ooooooooool06ooo
ool01Ol0003ooooooooooomgMgOo<S8b00kooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01omgMgOoV9RH
oooooonHV9SoMgMgooooool000002Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`;o00001oooool00omg
MgOo<S8bo`000006ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`05ooooo`05o`000?ooooooooooooooool000001oooool03?l0003ooooooooooooo
oooo0000oooooonHV9So8B4Qonk^k_ooooooA4A4o`0000;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Tooooo`00A?ooool00ol0003oooooo`00000Mooooo`03o`000?oooooooooo01_ooooo00Go0000
ooooooooooooooooo`00000>ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Oo410@oooooooooooooooo
oa0@4?oooooo000000[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool2o`0000Sooooo0_l00006ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`05
o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000;ooooo00GoV9RH
ob4Q8Oo^k^koooooo`000002ooooo`05oa0@4?ooooooooooooooool@41009?ooool004Cooooo00?o
0000ooooool000007Oooool00ol0003oooooooooo`0Jooooo`06o`000?oooooooooooooooomgMgOo
<S8b3_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooooooo`;o00002oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooo000000Kooooo00?oMgMgoc8b<_l000001_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool01Ol0
003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000003ooooo`04oiRHV?lQ
8B7ok^k^o`0000;ooooo00Go0000ooooooooooooooooo`00000Tooooo`00A?ooool01?l0003ooooo
o`000?l0000Looooo`03o`000?oooooooooo01[ooooo0_l000001?lQ8B7o0000oc8b<_o<c<`>oooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooooooo0_l0000;ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooool000000oooool01_l0003o8B4Qo`000?lb<S;oc<c<o`0000Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool0
00001?ooool00omgMgOoIVIVo`000002ooooo`05o`000?ooooooooooooooool000009?ooool004Co
oooo00?o0000ooooool000007Oooool00ol0003oooooooooo`0Jooooo`;o00004_ooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`02ooooo`06oa0@4?ooooooooooooooool@413o00002oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooo
oooo000000Gooooo0_l00002ooooo`05oa0@4?ooooooooooooooool@41009?ooool004?ooooo00Co
0000oooooooooooo00007Oooool00ol0003oooooooooo`0Jooooo`;o00004_ooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`02ooooo`06ogMgMonHV9SooooooiRHV?mgMgOo00002oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooo000000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02oooo
o`;o000000Go^[ZjoooooonHV9So410@o`000002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL09?oo
ool004?ooooo00Co0000oooooooooooo00007Oooool00ol0003oooooooooo`0Jooooo`Go00003ooo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00cooooo00Ko0000ooooooooooooEEEE
ofIVI_l00004ooooo`06onk^k_lb<S;o0000oc8b<_o^k^ko00002oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02
ooooo`05oeEEEOmVIVKo0000ooooool000000oooool4o`000003ooooool0003ooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00Oo
0000oiRHV?l@413o0000ob4Q8Oo<c<co000000;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Toooo
o`00@oooool00ol0003oooooooooo`02o`0001cooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Yooooo`00@oooool01?l0003oooooooooool0000Nooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0:Oooool004?ooooo00Co0000oooooooooooo00007_ooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo017ooooo0_l00002ooooo`;o00004_ooool004?ooooo
00Co0000oooooooooooo00007_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo017o
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMdBooooo`00@oooool01?l0003oooooooooool0000N
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04_ooool01?oMgMgo0000oa0@4?o<
c<`Cooooo`003Oooooooo`0003[o00002oooool01?o^k^ko8B4Qoa0@4?o^k^hCooooo`005?ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool000002oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Kooooo00Go0000ooooooooooooooooo`00000;ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooo`000008ooooo`03o`00
0?oooooo000000Gooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00006ooooo`03
o`000?oooooo000000Cooooo00?o0000ooooooooool01?ooool2o`0000Cooooo00?o0000oooooooo
ool00oooool2o`0000Cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Boooo
o`04ob4Q8OmgMgOoMgMgoc8b<Q?ooooo0012ooooo`05o`000?ooooooooooooooool000007_ooool0
0ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool000004Oooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool2o`0000Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00017ooooo
0_l00002ooooo`;o00004_ooool004;ooooo00Go0000ooooooooooooooooo`00000Nooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0:_ooool004;ooooo00Go0000oooooooooooooooo
o`00000Nooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0:_ooool004;ooooo00Co
0000oooooooooooooooo0_l0000Nooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
:_ooool004;ooooo00Go0000ooooooooooooooooo`00000Oooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0:_ooool0047ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0:_ooool0047ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0:_ooool0047ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0:_ooool0047ooooo00?o0000oooooooo
ool00_ooool2o`0001kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Zooooo`00
@Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0Zooooo`00@Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Zooooo`005?ooool0
0ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooo
oooooooo000002cooooo000Dooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00Go0000oooooooooooooooo
o`000007ooooo`05o`000?ooooooooooooooool00000;?ooool001Cooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`03ooooo`;o00007oooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`05o`00
0?ooooooooooooooool000001oooool01?l0003oooooooooool0000]ooooo`005?ooool00ol0003o
ooooooooo`0Yooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`05ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool0000]
ooooo`005Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00Go0000oooo
ooooooooooooo`000008ooooo`05o`000?ooooooooooooooool000001oooool01?l0003ooooooooo
ool0000]ooooo`005Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00Go
0000ooooooooooooooooo`000008ooooo`05o`000?ooooooooooooooool000001oooool01?l0003o
ooooooooool0000]ooooo`005Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Ko
oooo00Go0000ooooooooooooooooo`000008ooooo`05o`000?ooooooooooooooool000001oooool0
1?l0003oooooooooool0000]ooooo`005Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo00?ooooo0_l0000Oooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool0
1Ol0003ooooooooooooooooo000000Sooooo00Go0000ooooooooooooooooo`000007ooooo`04o`00
0?ooooooooooo`0002gooooo000Eooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1_ooool01Ol0003ooooooooooooooooo000000Sooooo00Go0000ooooooooooooooooo`000007oooo
o`04o`000?ooooooooooo`0002gooooo000Eooooo`03o`000?oooooooooo00_ooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o0000omgM
g@05ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`06ooooo`05o`000?ooooooooooooooool000002?ooool01Ol0003ooooooooooooooooo000000Oo
oooo00Co0000oooooooooooo0000;Oooool001Kooooo00?o0000ooooooooool02_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool0
0ol0003o<S8booooo`04ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool000002?ooool01Ol0003ooooooooo
oooooooo000000Oooooo00Co0000oooooooooooo0000;Oooool001Kooooo00?o0000ooooooooool0
2_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02?ooool2o`0000Go
oooo0ol0000Oooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool01Ol0003o
oooooooooooooooo000000Sooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?oooooo
ooooo`0002gooooo000Fooooo`03o`000?oooooooooo00[ooooo00Go0000ooooooooooooooooo`00
000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000oc8b<_ooool01?ooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooo
oooooooo000000Sooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`00
02gooooo000Fooooo`03o`000?oooooooooo00[ooooo00Go0000ooooooooooooooooo`00000>oooo
o`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o0000olc<c005ooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`05o`000?oooooo
ooooooooool000002Oooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0002go
oooo000Fooooo`03o`000?oooooooooo00[ooooo00Go410@oooooooooooooooooa0@400?ooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo
000000Wooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool0000]ooooo`005_oo
ool00ol0003oooooooooo`0:ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zj
oooooonHV9So410@00Cooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool01?l0003oooooooooool00009
ooooo`03o`000?oooooo000000Sooooo00Co0000oooooooooooo0000;Oooool001Oooooo00?o0000
ooooooooool02Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c004ooooo`Co00001_ooool2o`00023ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Sooooo00Go0000ooooooooooooooooo`00000:ooooo`04
o`000?ooooooooooo`0000Wooooo00?o0000ooooool000002?ooool01?l0003oooooooooool0000]
ooooo`005oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00gooooo00Go0000oooo
ooooooooooooo`00000=ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool0
1?l0003oooooooooool0000:ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooool00000
2Oooool00ol0003oooooo`00000]ooooo`005oooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00gooooo00Go0000ooooooooooooooooo`00000=ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool02Oooool01?l0003oooooooooool0000:ooooo`04o`000?ooooooooooo`00
00Wooooo00?o0000ooooool000002Oooool2o`0002kooooo000Gooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool03Oooool01Ol0003ooooooooooooooooo000000gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`09ooooo`04o`000?ooooooooooo`0000[ooooo00Co0000
oooooooooooo00002Oooool00ol0003oooooo`000009ooooo`;o0000;_ooool001Oooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0=ooooo`05o`000?ooooooooooooooool000003_oo
ool01Ol0003ooooooooooooooooo000000_ooooo00Co0000oooooooooooo00002_ooool01?l0003o
ooooooooool00009ooooo`03o`000?oooooo000000Wooooo0_l0000^ooooo`006?ooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo00Gooooo0_l0000Qooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool03Oooool01Ol0003ooooooooooooooooo000000kooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04o`000?ooooooooooo`0000[ooooo00Co0000oooooooooooo0000
2Oooool00ol0003oooooo`000009ooooo`;o0000;_ooool001Sooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0=ooooo`05o`000?ooooooooooooooool000003_ooool01?l0003ooooo
ooooool0000<ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooool000002_ooool00ol0
003oooooo`000009ooooo`;o0000;_ooool001Sooooo00?o0000ooooooooool08_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0=ooooo`05o`000?ooooooooooooooool000003_ooool01?l0003oooooooooool0000<
ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooool000002_ooool00ol0003oooooo`00
0009ooooo`;o0000;_ooool001Sooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0>
ooooo`05o`000?ooooooooooooooool000003_ooool01?l0003oooooooooool0000<ooooo`04o`00
0?ooooooooooo`0000_ooooo0_l0000;ooooo`;o0000>Oooool001Sooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0>ooooo`05o`000?ooooooooooooooool000003_ooool01?l0003o
ooooooooool0000<ooooo`03o`000?oooooo000000cooooo0_l0000;ooooo`03o`000?oooooooooo
03Sooooo000Hooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool01_ooool2o`0002;o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0>ooooo`05o`000?oooooooooooooo
ool000003_ooool01?l0003oooooooooool0000<ooooo`03o`000?oooooo000000cooooo0_l00016
ooooo`006Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00kooooo00Go0000oooo
ooooooooooooo`00000>ooooo`04o`000?ooooooooooo`0000cooooo00?o0000ooooool000003?oo
ool2o`0004Kooooo000Iooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03_ooool0
1?l0003oooooooooool0000?ooooo`03o`000?oooooo000000kooooo0_l0001Dooooo`006Oooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool08Oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00oooooo00?o0000ooooool000003oooool0
0ol0003oooooo`00000>ooooo`03o`000?oooooooooo05?ooooo000Iooooo`03o`000?oooooooooo
023ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool03oooool00ol0003oooooo`00000@ooooo`;o0000I?ooool001Wo
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`07ooooo`;o00008_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00oooooo00?o0000ooooool000004?ooool2o`0006Co
oooo000Iooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0Booooo`04o`000?ooooooooooo`0001;ooooo00?o0000ooooool000004?ooool2o`0006Co
oooo000Jooooo`03o`000?oooooooooo00kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1Oooool3o`000003oc8b<_oMgMgooooo00Cooooo00?o0000ooooooooool08_ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04_ooool01?l0003o
ooooooooool0000Booooo`03o`000?oooooo000007Kooooo000Jooooo`03o`000?oooooooooo00ko
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1Oooool01Ol0003ooooooooooomgMgOo
<S8b00Gooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool04oooool01?l0003oooooooooool0000Booooo`03o`000?oo
oooo000007Kooooo000Jooooo`03o`000?oooooooooo00kooooo00Go410@oooooooooooooooooa0@
400<ooooo`05o`000?ooooooooooooooool000001Oooool3o`0002;ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01?ooooo00Co0000oooooooooooo
00004oooool2o`0007Kooooo000Jooooo`03o`000?oooooooooo00kooooo00Go0000oooooooooooo
ooooo`00000<ooooo`05o`000?ooooooooooogMgMolb<S801Oooool00ol0003oooooooooo`0Roooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Coooo
o`04o`000?ooooooooooo`0001?ooooo00?o0000ooooooooool0MOooool001[ooooo00?o0000oooo
ooooool03_ooool01Ol0003ooooooooooooooooo000000_ooooo0_l000001?lQ8B7o0000oc8b<_o<
c<`5ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo01?ooooo00Co0000oooooooooooo0000Roooool001[ooooo00?o
0000ooooooooool03_ooool01Ol@413ooooooooooooooooo410@00_ooooo0_l00009ooooo`03o`00
0?oooooooooo02;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooool00000Roooool001_ooooo00?o0000ooooooooool03Ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo0_l00009ooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Cooooo
0_l0002<ooooo`006oooool00ol0003oooooooooo`0=ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2oooool5o`0000Kooooo0_l0000Tooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
7oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Sooooo00Go0000oooooooooooo
ooooo`00000Fooooo`;o0000S?ooool001_ooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06?ooool01Ol0003ooooo
oooooooooooo00000:Cooooo000Kooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
7oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Sooooo00Go0000oooooooooooo
ooooo`00002Tooooo`006oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01oooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Iooooo`04o`000?ooooooooooo`000:Go
oooo000Looooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0Sooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool08?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooool00000YOooool001cooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`09ooooo`;o00009?ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0Jooooo`?o0000YOooool001cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool06_ooool2o`000:Kooooo000Loooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo0<?ooooo000Looooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0<?ooooo000Mooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool08_ooool01Ol0003ooooooooooooooooo00000<Go
oooo000Mooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02Oooool2o`0002Gooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Rooooo`05o`000?ooooooooooooooool0
0000aOooool001gooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Sooooo`05o`00
0?ooooooooooooooool00000aOooool001gooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0Tooooo`04o`000?ooooooooooo`000<Gooooo000Mooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool09?ooool00ol0003oooooo`000036ooooo`007Oooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo02Cooooo0ol00036ooooo`007_ooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo00[ooooo0_l0000Vooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0kOooool001kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3]oooo
o`007_ooool00ol0003oooooooooo`02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q
8@Kooooo00Co0000onk^k_oooooo00000oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0>kooooo000N
ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_oo
ool01?mEEEGoZJVYooooool00006ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0>kooooo000Nooooo`03o`000?oo
oooooooo00;ooooo00Go410@oooooooooooooooooa0@400=ooooo`04ojVYZOmEEEGoooooo`0000Oo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0k_ooool001oooooo00Go0000ooooooooooooooooo`000003ooooo`03
o`000?oooooooooo00cooooo00?o8B4Qooooool000001_ooool00omgMgOo<S8booooo`04ooooo`?o
00009_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0>oooooo000Oooooo`05o`00
0?ooooooooooooooool000000oooool00ol0003oooooooooo`0<ooooo`03oeEEEOo<c<co000000?o
oooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo02Oooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`3_ooooo`007oooool01Ol0003ooooooooooooooooo410@
00?ooooo00?o410@ooooooooool03?ooool00onYZJWoMgMgo`000003ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
0>oooooo000Oooooo`09o`000?oooooooooooooooomgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Ko
410@oooooooooooooooooc8b<_l00003ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0>oooooo000Oooooo`09o`00
0?ooooooooooooooooo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2
o`0002Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3_ooooo`008?ooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0:?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo0>oooooo000Pooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00;o
0000l_ooool0023ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo02Wooooo0ol0003cooooo`008?ooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`3booooo`008?ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00gooooo0_l0003oooooob7ooooo000Qoooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`3ooooo
ob3ooooo000Qooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`3oooooob3ooooo000Qooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`3oooooob3ooooo000Rooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`3oooooob3ooooo000Rooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool03_ooool2o`000?oooooo8Oooool002;ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo0?oooooo8?ooool002?o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo0?oo
oooo8?ooool002?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo0?oooooo8?ooool002?ooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo0?oooooo8?ooool002Cooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0?ooooo`;o0000oooooolQooooo`009?ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0oooooolPooooo`009?ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00Gooooo1?l000000ol@413oooooooooo`03ooooo`03
o`000?oooooooooo0?oooooo8?ooool002Cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooolPooooo`009Ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`3oooooob3ooooo000Uooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`05ooooo`?o0000oooooolPooooo`00?_ooool00ol0
003oooooooooo`3oooooobSooooo000nooooo`03o`000?oooooooooo0?oooooo:?ooool003kooooo
00?o0000ooooooooool0oooooolXooooo`00??ooool00omEEEGoIVIVo`00003oooooob[ooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0012ooooo`?o000000?o
410@ooooooooool0oooooolQooooo`00A?ooool00ol@413o^[Zjooooo`3oooooob;ooooo0014oooo
o`03oiRHV?lb<S;ooooo0?oooooo8_ooool004Cooooo00?ogMgMo`000?nj^[X0oooooolRooooo`00
A?ooool00omEEEGoMgMgodA4A03oooooob;ooooo0013ooooo`05omgMgOl@413oooooob4Q8OoMgMd0
oooooolQooooo`00@oooool01OmVIVKoQhN7oooooonHV9SoEEEE0?oooooo8Oooool004;ooooo00?o
k^k^o`000?o^k^h00_ooool00ol0003ogMgMooooo`3ooooooaoooooo0012ooooo`04oa0@4?l0003o
0000ooooo`;o000000?o410@ooooooooool0oooooolNooooo`00oooooomYooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-5.66973, -1.05832, 0.1009, \
0.0129571}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.18254 0.0396825 0.309017 0.309017 [
[.38095 .29652 -3 -9 ]
[.38095 .29652 3 0 ]
[.57937 .29652 -6 -9 ]
[.57937 .29652 6 0 ]
[.77778 .29652 -6 -9 ]
[.77778 .29652 6 0 ]
[.97619 .29652 -6 -9 ]
[.97619 .29652 6 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.17004 0 -12 -4.5 ]
[.17004 0 0 4.5 ]
[.17004 .07725 -30 -4.5 ]
[.17004 .07725 0 4.5 ]
[.17004 .15451 -24 -4.5 ]
[.17004 .15451 0 4.5 ]
[.17004 .23176 -30 -4.5 ]
[.17004 .23176 0 4.5 ]
[.17004 .38627 -24 -4.5 ]
[.17004 .38627 0 4.5 ]
[.17004 .46353 -18 -4.5 ]
[.17004 .46353 0 4.5 ]
[.17004 .54078 -24 -4.5 ]
[.17004 .54078 0 4.5 ]
[.17004 .61803 -6 -4.5 ]
[.17004 .61803 0 4.5 ]
[.18254 .64303 -5 0 ]
[.18254 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.38095 .30902 m
.38095 .31527 L
s
[(5)] .38095 .29652 0 1 Mshowa
.57937 .30902 m
.57937 .31527 L
s
[(10)] .57937 .29652 0 1 Mshowa
.77778 .30902 m
.77778 .31527 L
s
[(15)] .77778 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(20)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.22222 .30902 m
.22222 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30159 .30902 m
.30159 .31277 L
s
.34127 .30902 m
.34127 .31277 L
s
.42063 .30902 m
.42063 .31277 L
s
.46032 .30902 m
.46032 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.53968 .30902 m
.53968 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.65873 .30902 m
.65873 .31277 L
s
.69841 .30902 m
.69841 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.81746 .30902 m
.81746 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.89683 .30902 m
.89683 .31277 L
s
.93651 .30902 m
.93651 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.10317 .30902 m
.10317 .31277 L
s
.06349 .30902 m
.06349 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.18254 0 m
.18879 0 L
s
[(-1)] .17004 0 1 0 Mshowa
.18254 .07725 m
.18879 .07725 L
s
[(-0.75)] .17004 .07725 1 0 Mshowa
.18254 .15451 m
.18879 .15451 L
s
[(-0.5)] .17004 .15451 1 0 Mshowa
.18254 .23176 m
.18879 .23176 L
s
[(-0.25)] .17004 .23176 1 0 Mshowa
.18254 .38627 m
.18879 .38627 L
s
[(0.25)] .17004 .38627 1 0 Mshowa
.18254 .46353 m
.18879 .46353 L
s
[(0.5)] .17004 .46353 1 0 Mshowa
.18254 .54078 m
.18879 .54078 L
s
[(0.75)] .17004 .54078 1 0 Mshowa
.18254 .61803 m
.18879 .61803 L
s
[(1)] .17004 .61803 1 0 Mshowa
.125 Mabswid
.18254 .01545 m
.18629 .01545 L
s
.18254 .0309 m
.18629 .0309 L
s
.18254 .04635 m
.18629 .04635 L
s
.18254 .0618 m
.18629 .0618 L
s
.18254 .09271 m
.18629 .09271 L
s
.18254 .10816 m
.18629 .10816 L
s
.18254 .12361 m
.18629 .12361 L
s
.18254 .13906 m
.18629 .13906 L
s
.18254 .16996 m
.18629 .16996 L
s
.18254 .18541 m
.18629 .18541 L
s
.18254 .20086 m
.18629 .20086 L
s
.18254 .21631 m
.18629 .21631 L
s
.18254 .24721 m
.18629 .24721 L
s
.18254 .26266 m
.18629 .26266 L
s
.18254 .27812 m
.18629 .27812 L
s
.18254 .29357 m
.18629 .29357 L
s
.18254 .32447 m
.18629 .32447 L
s
.18254 .33992 m
.18629 .33992 L
s
.18254 .35537 m
.18629 .35537 L
s
.18254 .37082 m
.18629 .37082 L
s
.18254 .40172 m
.18629 .40172 L
s
.18254 .41717 m
.18629 .41717 L
s
.18254 .43262 m
.18629 .43262 L
s
.18254 .44807 m
.18629 .44807 L
s
.18254 .47898 m
.18629 .47898 L
s
.18254 .49443 m
.18629 .49443 L
s
.18254 .50988 m
.18629 .50988 L
s
.18254 .52533 m
.18629 .52533 L
s
.18254 .55623 m
.18629 .55623 L
s
.18254 .57168 m
.18629 .57168 L
s
.18254 .58713 m
.18629 .58713 L
s
.18254 .60258 m
.18629 .60258 L
s
.25 Mabswid
.18254 0 m
.18254 .61803 L
s
gsave
.18254 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .12067 m
.06244 .36735 L
.08255 .49134 L
.0932 .54685 L
.09905 .57294 L
.10458 .59416 L
.10972 .61055 L
.11243 .6178 L
s
.11243 .6178 m
.11254 .61803 L
s
.14504 .61803 m
.14916 .60628 L
.1546 .5862 L
.1645 .53832 L
.18306 .41611 L
.20245 .26483 L
.21274 .18675 L
.22384 .11347 L
.22899 .0854 L
.23441 .06099 L
.23903 .04486 L
.24166 .03781 L
.2441 .03268 L
.24528 .03069 L
.24657 .02892 L
.24779 .02762 L
.24891 .02675 L
.24992 .02623 L
.25104 .02596 L
.2522 .02602 L
.25329 .02638 L
.25456 .02719 L
.25576 .02833 L
.25684 .02968 L
.25802 .03149 L
.26066 .03685 L
.26311 .0434 L
.2682 .06186 L
.2737 .08881 L
.28367 .15403 L
.30229 .31265 L
.31175 .39656 L
.32188 .47561 L
.32769 .51183 L
.33299 .537 L
.33554 .54611 L
.33688 .55007 L
.33831 .55361 L
.33956 .55613 L
.34093 .55829 L
.34218 .55969 L
.34335 .56049 L
.34455 .5608 L
.34566 .56062 L
.34689 .55991 L
.34819 .55854 L
.34885 .55762 L
.34957 .55643 L
.35086 .55382 L
.35329 .54729 L
Mistroke
.35559 .53914 L
.35802 .52852 L
.36239 .50454 L
.37215 .43093 L
.38289 .32885 L
.39289 .22991 L
.40237 .14914 L
.40761 .11547 L
.41056 .10093 L
.41198 .09525 L
.4133 .09071 L
.4145 .08727 L
.4156 .08469 L
.41682 .08248 L
.41814 .08087 L
.41933 .08012 L
.42064 .08009 L
.4213 .08039 L
.42201 .08094 L
.42328 .08254 L
.42451 .08483 L
.42586 .08819 L
.4286 .09765 L
.43113 .1095 L
.4335 .12319 L
.43885 .16234 L
.4446 .21509 L
.45505 .3265 L
.46474 .42612 L
.46964 .46699 L
.47215 .48413 L
.47486 .49928 L
.47641 .50623 L
.47784 .51146 L
.4792 .51538 L
.4799 .51695 L
.48065 .51833 L
.48194 .51992 L
.48315 .52049 L
.48389 .5204 L
.48458 .52001 L
.48589 .51847 L
.48705 .51625 L
.48832 .51285 L
.48965 .50826 L
.49089 .50299 L
.49552 .47576 L
.50056 .43377 L
.50599 .37755 L
.51638 .25693 L
Mistroke
.52144 .20234 L
.52604 .16091 L
.52838 .14394 L
.53092 .12925 L
.53231 .12296 L
.5336 .11834 L
.53483 .11503 L
.53612 .11271 L
.53743 .11164 L
.53817 .1116 L
.53884 .11192 L
.54014 .11351 L
.54138 .11619 L
.54207 .1182 L
.54281 .12073 L
.54414 .12629 L
.54715 .1435 L
.54977 .16335 L
.55253 .18863 L
.55747 .24266 L
.56861 .37968 L
.57327 .4297 L
.57583 .45247 L
.57825 .47004 L
.57962 .47807 L
.58111 .48511 L
.58176 .48763 L
.58246 .4899 L
.58371 .49292 L
.58496 .49457 L
.58613 .49485 L
.58742 .49373 L
.58814 .49245 L
.5888 .49086 L
.59009 .48666 L
.5913 .48137 L
.59356 .46814 L
.596 .44932 L
.59864 .42418 L
.60778 .31197 L
.61254 .24967 L
.61765 .19131 L
.62059 .16515 L
.62326 .14747 L
.62455 .14132 L
.62523 .13873 L
.62595 .13649 L
.62658 .13497 L
.62727 .13377 L
.6285 .13288 L
Mistroke
.62975 .13362 L
.63039 .13463 L
.63108 .13621 L
.6323 .14025 L
.63344 .1454 L
.63602 .1618 L
.63878 .18603 L
.64383 .24482 L
.64843 .30762 L
.65362 .37835 L
.65636 .4113 L
.65926 .4404 L
.66179 .45958 L
.66323 .46748 L
.66392 .47044 L
.66458 .47274 L
.66582 .47569 L
.66695 .47677 L
.66816 .47619 L
.66885 .47506 L
.66949 .47349 L
.67078 .46881 L
.67143 .46571 L
.67214 .46174 L
.67458 .44386 L
.67742 .4154 L
.68008 .38288 L
.68529 .30908 L
.69004 .24149 L
.69226 .2135 L
.69466 .1875 L
.69576 .17748 L
.69693 .16832 L
.69803 .16121 L
.69903 .15603 L
.70017 .15176 L
.70139 .14912 L
.70247 .14852 L
.70361 .14965 L
.70486 .15297 L
.70602 .15799 L
.7073 .16558 L
.70866 .17598 L
.71125 .20178 L
.714 .23617 L
.71892 .30864 L
.72169 .35055 L
.72467 .39206 L
.72742 .42423 L
.72878 .43704 L
Mistroke
.73004 .44682 L
.7312 .45395 L
.73244 .45935 L
.73368 .46241 L
.73439 .46308 L
.73506 .46299 L
.73621 .46118 L
.73726 .45768 L
.73842 .45187 L
.73964 .44358 L
.74225 .41899 L
.74468 .38892 L
.7502 .30532 L
.75523 .22946 L
.75807 .19536 L
.75943 .18264 L
.7607 .17316 L
.7618 .16699 L
.76299 .16262 L
.76431 .16063 L
.76551 .1615 L
.76676 .16512 L
.76747 .16838 L
.76813 .17216 L
.76934 .18095 L
.77062 .19281 L
.77303 .22121 L
.77564 .25897 L
.78036 .33579 L
.78463 .39915 L
.78585 .41403 L
.78702 .4262 L
.78807 .43543 L
.7892 .44315 L
.79042 .44897 L
.79155 .45182 L
.79277 .4521 L
.79346 .45095 L
.79412 .44902 L
.79527 .44359 L
.79632 .43643 L
.79748 .42628 L
.79871 .4132 L
.80369 .34058 L
.80914 .24971 L
.81186 .21174 L
.81319 .1968 L
.81442 .18571 L
.81509 .18082 L
.81584 .17648 L
Mistroke
.81658 .17325 L
.81737 .17111 L
.81804 .17035 L
.81876 .17061 L
.82006 .1739 L
.82136 .18081 L
.82209 .18626 L
.82278 .19225 L
.82536 .2224 L
.83021 .30072 L
.8353 .3857 L
.8367 .4046 L
.83817 .42107 L
.83943 .43183 L
.84014 .43646 L
.84081 .43975 L
.8421 .44324 L
.84333 .4429 L
.84443 .43956 L
.84562 .43274 L
.84692 .42174 L
.8483 .40633 L
.85078 .37066 L
.85504 .29568 L
.8574 .2546 L
.85963 .22076 L
.86089 .20527 L
.86156 .19834 L
.86227 .192 L
.86351 .18365 L
.86467 .17933 L
.86595 .17854 L
.86715 .18166 L
.86823 .18758 L
.8694 .19719 L
.87437 .26793 L
.8771 .31829 L
.8797 .3648 L
.88211 .40104 L
.88347 .41672 L
.88473 .42739 L
.88578 .43319 L
.88695 .43605 L
.88817 .43497 L
.88932 .43016 L
.89054 .42108 L
.89184 .40744 L
.89415 .3742 L
.89935 .27799 L
.9019 .23428 L
Mistroke
.90329 .21473 L
.90462 .2003 L
.90537 .19411 L
.90618 .18916 L
.90692 .18634 L
.9076 .18518 L
.90824 .18539 L
.90895 .18706 L
.90969 .1904 L
.91038 .19499 L
.91162 .20666 L
.91295 .22347 L
.91535 .26267 L
.91814 .31641 L
.92077 .36584 L
.92198 .38568 L
.92326 .40339 L
.92393 .41108 L
.92466 .41811 L
.92595 .42661 L
.92712 .4298 L
.92838 .42825 L
.92956 .4221 L
.93064 .41271 L
.93531 .33953 L
.93787 .28844 L
.94027 .2438 L
.94231 .21406 L
.94346 .20218 L
.94451 .19488 L
.94559 .19124 L
.94678 .19198 L
.94802 .19799 L
.94918 .20819 L
.94999 .2178 L
.95086 .23026 L
.95246 .25736 L
.95544 .31692 L
.95862 .37774 L
.95949 .39134 L
.96043 .40372 L
.96131 .41297 L
.96212 .41915 L
.96299 .42322 L
.96395 .42445 L
.96484 .42248 L
.96568 .41798 L
.96664 .40975 L
.9675 .39967 L
.96944 .36937 L
Mistroke
.97619 .23653 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00??ooool4o`000003oa0@4?oooooooooo0?oooooo
9_ooool003kooooo00?o0000ooooooooool0oooooolXooooo`00<oooool6o`0000Gooooo00?o0000
ooooooooool0oooooolXooooo`00?_ooool00ol0003oooooooooo`05ooooo`?o0000oooooolPoooo
o`00?_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo8?ooool003kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooob3ooooo000nooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0oooooolPooooo`00??ooool00omEEEGoIVIVo`000007
ooooo`03o`000?oooooooooo0?oooooo8?ooool004Kooooo0_l0003oooooob7ooooo0016ooooo`03
o`000?oooooooooo0?oooooo8?ooool004Kooooo00?o0000ooooooooool0oooooolPooooo`00A_oo
ool00ol0003oooooooooo`0Aooooo`?o0000ooooool<ooooo`00A_ooool2o`00017ooooo0_l00002
ooooo`03o`000?oooooooooo0?oooooo2Oooool004Kooooo00?o0000ooooooooool04?ooool01Ol0
003ooooooooooooooooo00000?oooooo2oooool004Kooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo2?ooool004Kooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo2?ooool004Kooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo
1oooool004Kooooo0_l0000?ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooo
ool7ooooo`00A_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0ooooool7ooooo`00A_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0ooooool7ooooo`00A_ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0ooooool6ooooo`00A_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0ooooool6ooooo`00A_oo
ool2o`0000kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooo`Kooooo0016
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3o
ooooo`Kooooo000Sooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000
onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo1_ooool002?ooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo0?oooooo1Oooool001_ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41003Ooo
ool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0?oooooo1Oooool002?ooooo00Go0000
ooooooooooooooooo`00000>ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?oo
ool3o`0000cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`3oooooo`Gooooo000S
ooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0:oooool3o`000=Kooooo000Sooooo`05oa0@4?ooooooooooooooool@4100
3_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooool00000
e_ooool002?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb
<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0Yooooo`05o`000?ooooooooooooooool00000eOooool002?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Wooooo00Go0000oooo
ooooooooooooo`00003Eooooo`00A_ooool2o`0000cooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0Xooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0d_ooool004Ko
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02So
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3Booooo`00A_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo0=;ooooo0016ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0d_ooool004Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3B
ooooo`00A_ooool2o`0000_ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0d_ooool004Kooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0Nooooo`;o0000/_ooool004Kooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo00000;7ooooo000Dooooo`03o`000?oo
oooooooo02oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Looooo`04o`000?oo
ooooooooo`000;7ooooo000Dooooo`03o`000?oooooooooo02oooooo0_l0000;ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo01cooooo00Co0000oooooooooooo0000/Oooool001Cooooo00?o0000ooooooooool0;ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01cooooo00Go0000oooooooooooooooo
o`00002`ooooo`005?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool07?ooool01Ol0003ooooooooooooooooo00000;3ooooo000Eooooo`03o`000?oo
oooooooo02kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Looooo`05o`000?oo
ooooooooooooool000006Oooool00ol0003oooooooooo`2Dooooo`005Oooool00ol0003ooooooooo
o`0^ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06oooool01Ol0003ooooooooo
oooooooo000001Sooooo0ol0002Eooooo`005Oooool00ol0003oooooooooo`0^ooooo`;o00002_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooo`00002Eooooo`005Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooool00000UOooool001Gooooo00?o0000ooooooooool04oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool08_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0Eooooo`04o`000?ooooooooooo`0009Cooooo000Eooooo`03o`000?oo
oooooooo01?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8b
ooooo`04ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0Rooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo01Cooooo00Go0000ooooooooooooooooo`00000Dooooo`03
o`000?oooooooooo07gooooo000Eooooo`03o`000?oooooooooo00_ooooo1_l00002ooooo`05oa0@
4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Co
oooo00Go0000ooooooooooooooooo`00000Cooooo`;o0000Ooooool001Kooooo00?o0000oooooooo
ool04_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?ooool3o`00
00Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
01Cooooo00Go0000ooooooooooooooooo`00000Cooooo`03o`000?oooooo000007kooooo000Foooo
o`03o`000?oooooooooo01;ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool08_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool04Oooool00ol0003oooooo`00001nooooo`005_ooool00ol0003oooooooooo`0B
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Rooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooo0000017ooooo0_l0001[ooooo`005_ooool00ol0003oooooooooo`0Booooo`05ogMgMonHV9So
oooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0Aooooo`04o`000?ooooooooooo`00013ooooo
0_l0001[ooooo`005_ooool00ol0003oooooooooo`0Booooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
3?ooool4o`0000Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo013ooooo00Go0000ooooooooooooooooo`00000@ooooo`;o0000Joooool001Kooooo
00?o0000ooooooooool0;Oooool2o`0000Sooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0@ooooo`05o`000?ooooooooooooooool000004?ooool00ol0003oooooo`00000>ooooo`03
o`000?oooooooooo05Wooooo000Gooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo013ooooo00Go0000oooooooooooo
ooooo`00000?ooooo`04o`000?ooooooooooo`0000kooooo0_l0001Jooooo`005oooool00ol0003o
ooooooooo`0/ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0?ooooo`05o`000?ooooooooooooooool000003oooool01?l0003oooooooooool0000=
ooooo`03o`000?oooooo000000gooooo00?o0000ooooooooool0B_ooool001Oooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool08?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool03oooool01Ol0003ooooooooooooooooo000000oooooo00Co0000oooooooooooo00003Ooo
ool00ol0003oooooo`00000=ooooo`03o`000?oooooooooo04[ooooo000Gooooo`03o`000?oooooo
oooo02cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00oooooo00Go0000ooooooooooooooooo`00000?ooooo`04o`000?ooooooooooo`0000gooooo
00?o0000ooooool000003?ooool2o`0004cooooo000Gooooo`03o`000?oooooooooo02cooooo0_l0
0007ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool08?ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03oooool01Ol0003ooooooooo
oooooooo000000oooooo00Co0000oooooooooooo00003Oooool00ol0003oooooo`00000<ooooo`03
o`000?oooooo000000_ooooo0_l0000nooooo`005oooool00ol0003oooooooooo`0/ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Pooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0?ooooo`05o`00
0?ooooooooooooooool000003oooool01?l0003oooooooooool0000=ooooo`03o`000?oooooo0000
00cooooo00?o0000ooooool000002oooool2o`0000[ooooo00?o0000ooooooooool0<Oooool001So
oooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00_o
oooo00Go0000ooooooooooooooooo`00000=ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000
ooooool000002_ooool00ol0003oooooo`00000:ooooo`03o`000?oooooooooo037ooooo000Hoooo
o`03o`000?oooooooooo02_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0;oooo
o`05o`000?ooooooooooooooool000003Oooool01?l0003oooooooooool0000;ooooo`03o`000?oo
oooo000000[ooooo00?o0000ooooool000002_ooool00ol0003oooooooooo`0aooooo`006?ooool0
0ol0003oooooooooo`0[ooooo`;o00001oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0;ooooo`05o`000?oooooo
ooooooooool000003Oooool01?l0003oooooooooool0000;ooooo`03o`000?oooooo000000[ooooo
00?o0000ooooool000002_ooool2o`0003;ooooo000Hooooo`03o`000?oooooooooo02_ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01kooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool00000
3Oooool01?l0003oooooooooool0000;ooooo`03o`000?oooooo000000[ooooo00?o0000ooooool0
00002Oooool00ol0003oooooo`00000booooo`006?ooool00ol0003oooooooooo`0[ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool02oooool01Ol0003ooooooooooooooooo000000co
oooo00Go0000ooooooooooooooooo`00000;ooooo`03o`000?oooooo000000[ooooo00?o0000oooo
ool000002Oooool00ol0003oooooo`00000booooo`006?ooool00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Wooooo00Go0000ooooooooooooooooo`00000;ooooo`03o`000?oooooo0000
00[ooooo00?o0000ooooool000002Oooool00ol0003oooooo`00000booooo`006?ooool00ol0003o
ooooooooo`0[ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`0Nooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Wooooo00Go0000ooooooooooooooooo`00000;oooo
o`03o`000?oooooo000000[ooooo00?o0000ooooool000002Oooool00ol0003oooooo`00000boooo
o`006Oooool00ol0003oooooooooo`0Zooooo`;o00001_ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo01kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooooooooooo0000
00[ooooo00Go0000ooooooooooooooooo`000009ooooo`03o`000?oooooo000000Wooooo00?o0000
ooooool00000<_ooool001Wooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09oooo
o`05o`000?ooooooooooooooool000002_ooool01Ol0003ooooooooooooooooo000000Wooooo00Co
0000oooooooooooo00002?ooool00ol0003oooooo`00000booooo`006Oooool00ol0003ooooooooo
o`0Zooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Wooooo00Go0000ooooooooooooooooo`00000:ooooo`05o`00
0?ooooooooooooooool000002Oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo0000
03;ooooo000Iooooo`03o`000?oooooooooo00Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Wooooo00Go0000ooooooooooooooooo`00000:ooooo`05o`000?ooooooooooooooool00000
2Oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo000003;ooooo000Iooooo`03o`00
0?oooooooooo00Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09oooo
o`05o`000?ooooooooooooooool000002_ooool01Ol0003ooooooooooooooooo000000Sooooo00Go
0000ooooooooooooooooo`000008ooooo`04o`000?ooooooooooo`00037ooooo000Iooooo`03o`00
0?oooooo000000Go00000_ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^
k^h02Oooool00ol0003oooooooooo`03ooooo`?o00001?ooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooooooooooo0000
00[ooooo00Go0000ooooooooooooooooo`000008ooooo`05o`000?ooooooooooooooool000001ooo
ool01Ol0003ooooooooooooooooo0000037ooooo000Jooooo`03o`000?oooooooooo00Kooooo00Go
0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
2?ooool01Ol0003ooooooooooooooooo000000Sooooo00Go0000ooooooooooooooooo`000007oooo
o`05o`000?ooooooooooooooool00000<Oooool001[ooooo00?o0000ooooooooool01_ooool01Ol0
003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Sooooo00Go0000ooooooooooooooooo`000008ooooo`05o`000?ooooooooooooooool0
00001oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool09oooool001[o
oooo00?o0000ooooooooool01_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01_ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`00
0007ooooo`03o`000?oooooooooo02Oooooo000Jooooo`03o`000?oooooooooo00Kooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool01Ol0003ooooo
oooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo
02Oooooo000Jooooo`03o`000?oooooooooo00Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;oooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l00005ooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooo
ooooooooool000001oooool00ol0003oooooooooo`0Wooooo`006_ooool00ol0003oooooooooo`0Y
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oo
oooooooo02Oooooo000Jooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
1Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool09oooool001_ooooo00?o0000
ooooooooool0:?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001ooo
ool00ol0003oooooooooo`0Wooooo`006oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo02Oooooo000K
ooooo`03o`000?oooooooooo02Sooooo0_l00004ooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_oo
ool00ol0003oooooooooo`0Xooooo`006oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Fooooo`05odA4A?l0003o
0000oc8b<_l000004_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00[ooooo1Ol0
00002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^1?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooo000000?o000000Go410@o`000?ooooooooooodA4A002o`000005oc8b<_oMgMgo
ooooooooool000001Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Co
0000oooooooooooooooo1_l000002?oooooo0000ooooooo^k^ko<S8bo`000?lb<S;ok^k^9?ooool0
01_ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool06Oooool00omgMgOo0000ooooo`0Aooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool02oooool00ol0003oooooo`000004ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`09ooooo`05o`000?ooooooooooooooool000000_oo
ool00ol0003oooooooooo`03ooooo`05ogMgMolb<S;oooooooooool000001Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo01;o0000ooooooooooooooooo`000?nHV9So8B4Q
onk^k_ooooooA4A4ooooool0003oooooogMgMonHV9SooooooiRHV?mgMgLTooooo`006oooool00ol0
003oooooooooo`0Xooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooo000000Cooooo00Go410@oooooooooooooooooa0@4003
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Sooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oo
oooooooo00Cooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00Wo0000ooooooooooooooooo`000?ooooooV9RHob4Q8Oo^k^h00_ooool0
0ol0003ooooooa0@4003ooooo`03oa0@4?oooooooooo02;ooooo000Looooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
01Sooooo00?oMgMgo`000?ooool04_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooool000001?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool02?ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00ooo
ool01OmgMgOo<S8boooooooooooo000000Gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`04ooooo`05o`000?ooooooooooooooool000000_ooool01onHV9So8B4Qonk^k_oooooo0000
ooooool000000oooool00ol0003oooooooooo`0Rooooo`007?ooool00ol0003oooooooooo`0Woooo
o`;o00000oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Gooooo00Go0000ob4Q
8Ol0003o<S8bo`00000Cooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooo`000004ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`08ooooo`05o`000?ooooooooooooooool000000_ooool02?l0003oooooooooool0003o8B4Qo`00
0?lb<S;oc<c<0_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool01Ol0003ooooooooooooooooo000000?ooooo00KoMgMgofIVI_oooooo0000
ooooool00003ooooo`03o`000?oooooooooo02;ooooo000Looooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Gooooo
00Co0000oooooooooooo00005?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooool000001?ooool01Ol@413ooooooooooooooooo410@00?ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool02?ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00001_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?oo
ool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooool0003ooooooa0@4003ooooo`03
oa0@4?oooooooooo02;ooooo000Looooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Gooooo00Co0000oooooooooooo
00005?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00cooooo00?o0000ooooool0
00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool01Ol0
003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00001_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01?l0003ooooooooo
ooooool2o`00000<okZj^_ooooooV9RHoa0@4?oooooo0000oooooomgMgOoV9RHoooooonHV9SoMgMg
9?ooool001cooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool05Oooool4o`0001Cooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?mVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP03ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00Ko0000ooooooooooooEEEEofIVI_l00002oooo
o`03o`000?oooooooooo00Co00000oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`0=o`000?l@413o0000
ob4Q8Oo<c<coooooo`000?ooooook^k^oc8b<_l0003o<S8bonk^kP0Tooooo`007?ooool00ol0003o
ooooooooo`0Wooooo`;o00000oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0:?ooool001cooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Xooooo`007Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo013ooooo0_l0
0002ooooo`;o00004_ooool001gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0@
ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM4_ooool001gooooo00?o0000ooooooooool09_oo
ool01Ol0003ooooooooooooooooo0000023ooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0Booooo`04omgMgOl0003o410@olc<c1?ooooo000=oooooooo0000>_l0000;ooooo`04onk^
k_lQ8B7o410@onk^kQ?ooooo000Dooooo`03o`000?oooooooooo00Kooooo00Go0000oooooooooooo
ooooo`00000;ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool01Ol0003o
oooooooooooooooo000000Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool2o`0000[ooooo00?o0000oooo
ooooool02?ooool2o`0000cooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`05o`000?oooooo
ooooooooool000002?ooool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool0
00001Oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000002?ooool00ol0
003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooool000004_ooool01?lQ8B7oMgMgogMgMolb<S8Cooooo`007Oooool00ol0003oooooooooo`0V
ooooo`05o`000?ooooooooooooooool000008?ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooool000004Oooool2o`0000;ooooo0_l0000Booooo`007_ooool0
0ol0003oooooooooo`0Uooooo`05o`000?ooooooooooooooool000008?ooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo02Wooooo000Nooooo`03o`000?oooooooooo02Gooooo00Go0000
ooooooooooooooooo`00000Pooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0:Ooo
ool001kooooo00?o0000ooooooooool09Oooool2o`0000;ooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Wooooo000Nooooo`03o`000?oooooooooo
02Gooooo00Go0000ooooooooooooooooo`00000Qooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0:Oooool001kooooo00?o0000ooooooooool09Oooool01?l0003oooooooooool0000R
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0:Oooool001kooooo00?o0000oooo
ooooool09Oooool01?l0003oooooooooool0000Rooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0:Oooool001oooooo00?o0000ooooooooool09?ooool01?l0003oooooooooool0000R
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0:Oooool001oooooo00?o0000oooo
ooooool09?ooool2o`000003ooooool0003ooooo027ooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0Yooooo`007oooool00ol0003oooooooooo`0Tooooo`04o`000?ooooooooooo`00
02;ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Yooooo`007oooool00ol0003o
ooooooooo`0Tooooo`04o`000?ooooooooooo`0002;ooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0Yooooo`007oooool00ol0003oooooooooo`0Tooooo`04o`000?ooooooooooo`00
02;ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00Co0000oooooooooooo0000;?ooool001oooooo00?o0000ooooooooool09?ooool01?l0
003oooooooooool0000Rooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0002cooooo000Oooooo`03o`000?oooooo
oooo02Cooooo0ol0000Tooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0002cooooo000Pooooo`03o`000?oooooo
oooo02?ooooo00?o0000ooooool000009?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool0000/ooooo`008?ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooo000002Cooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool0
1Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000;?ooool0023ooooo00?o
0000ooooooooool08oooool00ol0003oooooo`00000Tooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool00000
2?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00Go0000oooooooooooo
ooooo`000007ooooo`04o`000?ooooooooooo`0002cooooo000Pooooo`03o`000?oooooooooo02?o
oooo00?o0000ooooool000009?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000001oooool0
1?l0003oooooooooool0000/ooooo`008?ooool00ol0003oooooooooo`0Sooooo`?o00009?ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool0
1Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`05ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool0000/ooooo`00
8?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo000002Cooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo00Go0000oooooooooooo
ooooo`000008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool01Ol0003o
oooooooooooooooo000000Oooooo00Co0000oooooooooooo0000;?ooool0027ooooo00Oo0000oooo
ooo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`00
0?lb<S;ogMgM00Gooooo00?o0000ooooool000009?ooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooooooo000000So
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`04o`000?ooooooooooo`00
00Oooooo00Co0000oooooooooooo0000;?ooool0027ooooo00Oo0000oooooomgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01oooool00omgMgOo<S8b
ooooo`04ooooo`;o00009Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02?ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`06ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooo
oooooooo0000;?ooool0027ooooo00?o0000ooooool@41000oooool00ol@413oooooooooo`0:oooo
o`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool3o`0002Gooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00Go0000oooo
ooooooooooooo`000009ooooo`05o`000?ooooooooooooooool000002?ooool01?l0003ooooooooo
ool00007ooooo`04o`000?ooooooooooo`0002cooooo000Qooooo`03o`000?oooooo000000?ooooo
00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo
0_l0000Vooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`08ooooo`05o`000?ooooooooooooooool000002Oooool01Ol0003ooooooooooooooooo0000
00Sooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool0000/ooooo`008Oooool0
0ol0003oooooo`000003ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool00oooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo0_l0000Vooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool00000
2Oooool01Ol0003ooooooooooooooooo000000Sooooo00Co0000oooooooooooo00001oooool01?l0
003oooooooooool0000/ooooo`008_ooool00ol0003o410@ooooo`02ooooo`03oa0@4?oooooooooo
00gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`;o00009_ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool01Ol0
003ooooooooooooooooo000000Wooooo00Co0000oooooooooooo00002Oooool01?l0003ooooooooo
ool00007ooooo`04o`000?ooooooooooo`0002cooooo000Rooooo`06o`000?mgMgOoV9RHoooooonH
V9SoMgMg2oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooooooool01oooool2
o`0002Kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go
0000ooooooooooooooooo`000009ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooool0
00002?ooool01?l0003oooooooooool0000/ooooo`008_ooool01_l0003ok^k^oc8b<_l0003o<S8b
onk^kP_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`0002Kooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool02_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oooooooooooo
ooooo`000009ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooool000002Oooool00ol0
003oooooo`00000/ooooo`008_ooool00ol0003oooooooooo`0Qooooo`;o00009_ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0:ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooooooooooo
000000Wooooo00Co0000oooooooooooo00002Oooool00ol0003oooooo`000009ooooo`03o`000?oo
oooo000002cooooo000Rooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooo
oooooooo000000Wooooo00Co0000oooooooooooo00002Oooool00ol0003oooooo`000009ooooo`03
o`000?oooooo000002cooooo000Rooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00gooooo00Go0000oooooooooooo
ooooo`00000=ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooooooooooo
000000[ooooo00?o0000ooooool000002Oooool00ol0003oooooo`000009ooooo`03o`000?oooooo
000002cooooo000Sooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00gooooo00Go0000ooooooooooooooooo`00000=
ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooooooooooo000000[ooooo
00?o0000ooooool000002Oooool00ol0003oooooo`000009ooooo`03o`000?oooooo000002cooooo
000Sooooo`03o`000?oooooooooo023ooooo0_l0000Wooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool03Oooool01Ol0003ooooooooooooooooo000000gooooo00Go0000oooooooooooo
ooooo`00000;ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooool000002Oooool00ol0
003oooooo`000009ooooo`;o0000;Oooool002?ooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03Oooool01Ol0003o
oooooooooooooooo000000gooooo00Go0000ooooooooooooooooo`00000;ooooo`04o`000?oooooo
ooooo`0000_ooooo00?o0000ooooool000002Oooool00ol0003oooooo`000009ooooo`;o0000;Ooo
ool002?ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool03Oooool01Ol0003ooooooooooooooooo000000gooooo00Go
0000ooooooooooooooooo`00000;ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooool0
00002_ooool2o`0000Wooooo0_l0000]ooooo`008oooool00ol0003oooooooooo`0Pooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0=ooooo`05o`00
0?ooooooooooooooool000003Oooool01Ol0003ooooooooooooooooo000000_ooooo00Co0000oooo
oooooooo00002oooool2o`0000_ooooo0_l0000hooooo`009?ooool00ol0003oooooooooo`0Noooo
o`;o0000:?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool04?ooool01Ol0003ooooooooooooooooo0000013ooooo00Go0000ooooooooooooooooo`00
000=ooooo`05o`000?ooooooooooooooool000003?ooool00ol0003oooooo`00000;ooooo`;o0000
2oooool00ol0003oooooooooo`0gooooo`009?ooool00ol0003oooooooooo`0Nooooo`?o00009ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04?oo
ool01Ol0003ooooooooooooooooo0000013ooooo00Go0000ooooooooooooooooo`00000>ooooo`03
o`000?oooooo000000gooooo00?o0000ooooool000002oooool2o`0004Gooooo000Tooooo`03o`00
0?oooooooooo01kooooo0_l0000Xooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0@ooooo`05o`000?ooooooooooooooool000004?ooool01Ol0003o
oooooooooooooooo000000kooooo00?o0000ooooool000003Oooool00ol0003oooooo`00000<oooo
o`03o`000?oooooooooo04?ooooo000Tooooo`03o`000?oooooooooo01kooooo0_l0000Yooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Aooooo`05
o`000?ooooooooooooooool000004?ooool01Ol0003ooooooooooooooooo000000kooooo00?o0000
ooooool000003Oooool2o`0005?ooooo000Tooooo`03o`000?oooooooooo01kooooo0_l0000Yoooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Aoooo
o`05o`000?ooooooooooooooool000004Oooool01?l0003oooooooooool0000>ooooo`03o`000?oo
oooo000000kooooo00?o0000ooooooooool0DOooool002Cooooo00?o0000ooooooooool07_ooool2
o`0002Wooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo017ooooo00Go0000ooooooooooooooooo`00000Aooooo`04o`000?ooooooooooo`0000kooooo
00?o0000ooooool00000H_ooool002Gooooo00?o0000ooooooooool07?ooool01?l0003oooooo`00
0?l0000Xooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Aooooo`05o`000?ooooooooooooooool000004Oooool00ol0003oooooo`00000@ooooo`;o
0000H_ooool002Gooooo00?o0000ooooooooool07?ooool00ol0003oooooo`00000Yooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Aooooo`05o`00
0?ooooooooooooooool000004Oooool00ol0003oooooo`00000@ooooo`03o`000?oooooooooo067o
oooo000Uooooo`03o`000?oooooooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00?ooooo00?o0000ooooool00000:Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04Oooool01Ol0
003ooooooooooooooooo0000017ooooo00?o0000ooooool00000M?ooool002Gooooo00?o0000oooo
ooooool00oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo00;ooooo00?o0000ooooool00000:Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool04Oooool01Ol0003ooooooooooooooooo0000017ooooo00?o
0000ooooool00000M?ooool002Gooooo00?o0000ooooooooool00oooool01Ol@413ooooooooooooo
oooo410@013ooooo00Ko0000ooooooooooooooooo`000?ooool3o`0002Oooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01;ooooo00Go0000oooooooo
ooooooooo`00000Booooo`;o0000M?ooool002Gooooo00?o0000ooooooooool00oooool01Ol0003o
oooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00_ooool00ol0003oooooo`00000Zoooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooo000008Wooooo000Vooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`00oooool00ol0003oooooo`00000Z
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooo000008Wooooo000Vooooo`03o`000?oooooooooo00;ooooo00Go410@oooo
oooooooooooooa0@400<ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo0000:_oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04ooo
ool00ol0003oooooo`000029ooooo`009_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03?ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0002[ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool06?ooool01Ol0003ooooooooooooooooo000001Kooooo0_l00029ooooo`00
9_ooool00ol0003oooooooooo`02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000?o
oooo00?o0000ooooooooool00_l0000Yooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Sooooo00Co0000oooooooo
oooo00005oooool00ol0003oooooooooo`28ooooo`009_ooool00ol0003oooooooooo`0Jooooo`04
o`000?ooooooooooo`0002[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06?ooool01?l0003oooooooooool0002R
ooooo`009oooool00ol0003oooooooooo`0Iooooo`04o`000?ooooooooooo`0002[ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool06?ooool01?l0003oooooooooool0002Rooooo`009oooool00ol0003oooooooooo`0I
ooooo`04o`000?ooooooooooo`0002_ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06?ooool01?l0003ooooooooo
ool0002Rooooo`009oooool00ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool00000
:oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Jooooo`?o0000X_ooool002Oooooo00?o0000ooooooooool06?oo
ool01?l0003oooooooooooooool2o`0002[ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06_ooool2o`000:?ooooo
000Wooooo`03o`000?oooooooooo01Sooooo00Go0000ooooooooooooooooo`00000[ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo0;oooooo000Wooooo`03o`000?oooooooooo01Sooooo00Go0000oooooooooooooooo
o`00000[ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo0;oooooo000Xooooo`03o`000?oooooooooo01Oooooo00Go
0000ooooooooooooooooo`00000[ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
8?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0;oooooo000Xooooo`03o`000?oo
oooooooo01Oooooo00Go0000ooooooooooooooooo`00000/ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0;oooooo
000Xooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool00_ooool2o`0002_ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Qooooo`05o`000?ooooooooooooooool00000
`Oooool002Sooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Qooooo`04o`000?oo
ooooooooo`000<;ooooo000Xooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool08Ooo
ool2o`000003ooooool0003ooooo0<7ooooo000Yooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool08oooool2o`000<?ooooo000Yooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0j?ooool002Wooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`02ooooo`;o
0000;?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0>Sooooo000Yooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0[ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0j?ooool002?ooooo00Ook^k^oc8b<_l0003o<S8b
onk^k_oooooo000000?ooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0
003o<S8bo`000005ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3Xooooo`008oooool01omgMgOoV9RHoooooonHV9SoMgMgooooool000000oooool2
ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo0000ooooo`04ooooo`03o`000?oooooo
oooo02cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3Yooooo`008oooool01Ol@
413ooooooooooooooooo410@00;ooooo00?o0000ooooooooool02?ooool00onYZJWoEEEEooooo`08
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0>Wooooo000Sooooo`05o`000?ooooooooooooooool000000_ooool0
0ol0003oooooooooo`09ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgo`000?ooool01?ooool3
o`0002gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3Yooooo`008oooool01Ol0
003ooooooooooooooooo000000;ooooo00?o0000ooooooooool02Oooool00omEEEGoc<c<ooooo`03
ooooo`05o`000?lQ8B7o0000oc8b<_l000001Oooool00ol0003oooooooooo`0]ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0j_ooool002?ooooo00Go410@oooooooooooooooooa0@
4002ooooo`03o`000?oooooooooo00Wooooo00?oZJVYogMgMoooool00oooool01?l0003ooooooooo
ool00006ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`3Zooooo`008oooool01OmgMgOoV9RHoooooonHV9SoMgMg00;ooooo00?o0000ooooooooool0
1_ooool01Ol@413ooooooooooooooooo<S8b00Cooooo00Co0000oooooooooooo00001_ooool00ol0
003oooooooooo`0]ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0j_ooool002?o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`03o`000?oooooooooo00Gooooo1Ol00004oooo
o`Co00001_ooool2o`0002kooooo0_l00002ooooo`03o`000?oooooooooo0>_ooooo000[ooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0^ooooo`Co
0000kOooool002_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo02oooooo0_l0003^ooooo`00:oooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0oooooolPooooo`00:oooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooolPooooo`00;?ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo00Gooooo0_l0003oooooob7ooooo000/ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooob3o
oooo000/ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`3oooooob3ooooo000/ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`3oooooob3ooooo000/ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`3oooooob3ooooo000]ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool01_ooool2o`000?oooooo8Oooool002gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo8?ooool002gooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo
8?ooool002gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo0?oooooo8?ooool002kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo0?oooooo8?ooool002kooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`08ooooo`;o0000oooooolQooooo`00;_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool0oooooolPooooo`00;oooool00ol0003ooooo
ooooo`09ooooo`Go000000?o410@ooooooooool00oooool00ol0003oooooooooo`3oooooob3ooooo
000_ooooo`03o`000?oooooooooo00Wooooo00Co0000oooooooooooo00001oooool00ol0003ooooo
ooooo`3oooooob3ooooo000`ooooo`03o`000?oooooooooo00Oooooo00Go0000oooooooooooooooo
o`000007ooooo`03o`000?oooooooooo0?oooooo8?ooool0033ooooo00?o0000ooooooooool01ooo
ool01Ol0003ooooooooooooooooo000000Oooooo0ol0003oooooob3ooooo000nooooo`03o`000?oo
oooooooo0?oooooo:?ooool003kooooo00?o0000ooooooooool0oooooolXooooo`00?_ooool00ol0
003oooooooooo`3oooooobSooooo000looooo`03oeEEEOmVIVKo00000?oooooo:_ooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool004;ooooo0ol000000ol@413o
ooooooooo`3oooooob7ooooo0014ooooo`03oa0@4?nj^[[ooooo0?oooooo8_ooool004Cooooo00?o
V9RHoc8b<_ooool0oooooolRooooo`00A?ooool00ooMgMgo0000okZj^P3oooooob;ooooo0014oooo
o`03oeEEEOmgMgOoA4A40?oooooo8_ooool004?ooooo00GogMgMoa0@4?oooooo8B4QomgMg@3ooooo
ob7ooooo0013ooooo`05ofIVI_n7QhOooooooiRHV?mEEED0oooooolQooooo`00@_ooool00oo^k^ko
0000onk^kP02ooooo`03o`000?oMgMgooooo0?oooooo7oooool004;ooooo00Co410@o`000?l0003o
oooo0_l000000ol@413oooooooooo`3ooooooakooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-5.66973, -1.05832, 0.1009, \
0.0129571}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.18254 0.0396825 0.309017 0.309017 [
[.38095 .29652 -3 -9 ]
[.38095 .29652 3 0 ]
[.57937 .29652 -6 -9 ]
[.57937 .29652 6 0 ]
[.77778 .29652 -6 -9 ]
[.77778 .29652 6 0 ]
[.97619 .29652 -6 -9 ]
[.97619 .29652 6 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.17004 0 -12 -4.5 ]
[.17004 0 0 4.5 ]
[.17004 .07725 -30 -4.5 ]
[.17004 .07725 0 4.5 ]
[.17004 .15451 -24 -4.5 ]
[.17004 .15451 0 4.5 ]
[.17004 .23176 -30 -4.5 ]
[.17004 .23176 0 4.5 ]
[.17004 .38627 -24 -4.5 ]
[.17004 .38627 0 4.5 ]
[.17004 .46353 -18 -4.5 ]
[.17004 .46353 0 4.5 ]
[.17004 .54078 -24 -4.5 ]
[.17004 .54078 0 4.5 ]
[.17004 .61803 -6 -4.5 ]
[.17004 .61803 0 4.5 ]
[.18254 .64303 -5 0 ]
[.18254 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.38095 .30902 m
.38095 .31527 L
s
[(5)] .38095 .29652 0 1 Mshowa
.57937 .30902 m
.57937 .31527 L
s
[(10)] .57937 .29652 0 1 Mshowa
.77778 .30902 m
.77778 .31527 L
s
[(15)] .77778 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(20)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.22222 .30902 m
.22222 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30159 .30902 m
.30159 .31277 L
s
.34127 .30902 m
.34127 .31277 L
s
.42063 .30902 m
.42063 .31277 L
s
.46032 .30902 m
.46032 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.53968 .30902 m
.53968 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.65873 .30902 m
.65873 .31277 L
s
.69841 .30902 m
.69841 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.81746 .30902 m
.81746 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.89683 .30902 m
.89683 .31277 L
s
.93651 .30902 m
.93651 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.10317 .30902 m
.10317 .31277 L
s
.06349 .30902 m
.06349 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.18254 0 m
.18879 0 L
s
[(-1)] .17004 0 1 0 Mshowa
.18254 .07725 m
.18879 .07725 L
s
[(-0.75)] .17004 .07725 1 0 Mshowa
.18254 .15451 m
.18879 .15451 L
s
[(-0.5)] .17004 .15451 1 0 Mshowa
.18254 .23176 m
.18879 .23176 L
s
[(-0.25)] .17004 .23176 1 0 Mshowa
.18254 .38627 m
.18879 .38627 L
s
[(0.25)] .17004 .38627 1 0 Mshowa
.18254 .46353 m
.18879 .46353 L
s
[(0.5)] .17004 .46353 1 0 Mshowa
.18254 .54078 m
.18879 .54078 L
s
[(0.75)] .17004 .54078 1 0 Mshowa
.18254 .61803 m
.18879 .61803 L
s
[(1)] .17004 .61803 1 0 Mshowa
.125 Mabswid
.18254 .01545 m
.18629 .01545 L
s
.18254 .0309 m
.18629 .0309 L
s
.18254 .04635 m
.18629 .04635 L
s
.18254 .0618 m
.18629 .0618 L
s
.18254 .09271 m
.18629 .09271 L
s
.18254 .10816 m
.18629 .10816 L
s
.18254 .12361 m
.18629 .12361 L
s
.18254 .13906 m
.18629 .13906 L
s
.18254 .16996 m
.18629 .16996 L
s
.18254 .18541 m
.18629 .18541 L
s
.18254 .20086 m
.18629 .20086 L
s
.18254 .21631 m
.18629 .21631 L
s
.18254 .24721 m
.18629 .24721 L
s
.18254 .26266 m
.18629 .26266 L
s
.18254 .27812 m
.18629 .27812 L
s
.18254 .29357 m
.18629 .29357 L
s
.18254 .32447 m
.18629 .32447 L
s
.18254 .33992 m
.18629 .33992 L
s
.18254 .35537 m
.18629 .35537 L
s
.18254 .37082 m
.18629 .37082 L
s
.18254 .40172 m
.18629 .40172 L
s
.18254 .41717 m
.18629 .41717 L
s
.18254 .43262 m
.18629 .43262 L
s
.18254 .44807 m
.18629 .44807 L
s
.18254 .47898 m
.18629 .47898 L
s
.18254 .49443 m
.18629 .49443 L
s
.18254 .50988 m
.18629 .50988 L
s
.18254 .52533 m
.18629 .52533 L
s
.18254 .55623 m
.18629 .55623 L
s
.18254 .57168 m
.18629 .57168 L
s
.18254 .58713 m
.18629 .58713 L
s
.18254 .60258 m
.18629 .60258 L
s
.25 Mabswid
.18254 0 m
.18254 .61803 L
s
gsave
.18254 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03131 0 m
.06244 .1477 L
.08255 .28057 L
.10458 .42987 L
.11448 .49067 L
.12507 .54681 L
.1302 .5697 L
.13506 .58828 L
.13975 .60312 L
.14415 .61404 L
s
.14415 .61404 m
.14621 .61803 L
s
.16714 .61803 m
.16867 .61507 L
.17292 .60435 L
.17796 .58743 L
.18257 .56819 L
.19248 .51523 L
.20165 .45422 L
.22241 .29099 L
.23216 .21322 L
.24266 .13785 L
.2475 .10818 L
.25258 .08141 L
.25735 .06113 L
.26168 .04719 L
.264 .0416 L
.26619 .03759 L
.2674 .03593 L
.26851 .03473 L
.26973 .0338 L
.27102 .03325 L
.27205 .03314 L
.27315 .03334 L
.2742 .03385 L
.27515 .03457 L
.27627 .03574 L
.27749 .03741 L
.27971 .04151 L
.28231 .04804 L
.28466 .05556 L
.28994 .07776 L
.29483 .10459 L
.29943 .1348 L
.31784 .28972 L
.32829 .38527 L
.33803 .46473 L
.34299 .49799 L
.34768 .52339 L
.35027 .53454 L
.35309 .54411 L
.35433 .54745 L
.35564 .55039 L
.35677 .5524 L
.35801 .55407 L
.35865 .5547 L
.35934 .55522 L
.36007 .55556 L
.36074 .5557 L
.36195 .5555 L
.36325 .55467 L
.36398 .55391 L
Mistroke
.36477 .55286 L
.3662 .55033 L
.3676 .54711 L
.36889 .54347 L
.37384 .52366 L
.37634 .51032 L
.37909 .49322 L
.38928 .41091 L
.39857 .31913 L
.40943 .21117 L
.4142 .16944 L
.41948 .13095 L
.42177 .11733 L
.42424 .10502 L
.42658 .09585 L
.42872 .08965 L
.4299 .08717 L
.431 .08547 L
.43221 .0843 L
.4335 .08386 L
.43415 .08396 L
.43486 .08431 L
.43614 .08559 L
.43739 .08764 L
.43854 .09024 L
.44102 .09808 L
.44334 .10815 L
.44862 .14039 L
.45376 .18272 L
.45929 .23737 L
.46941 .34835 L
.47475 .40452 L
.48044 .45601 L
.48326 .47677 L
.48591 .49281 L
.48829 .50401 L
.48963 .50889 L
.49086 .51244 L
.49202 .51492 L
.49311 .51649 L
.4943 .51735 L
.49557 .51729 L
.49621 .51686 L
.4969 .5161 L
.49817 .51393 L
.4994 .51083 L
.50054 .50712 L
.50296 .49654 L
.50517 .48377 L
.51017 .44519 L
Mistroke
.51921 .34966 L
.52989 .225 L
.5351 .17372 L
.53736 .15535 L
.53982 .13885 L
.54101 .13224 L
.54227 .12631 L
.54344 .12182 L
.54453 .11852 L
.54556 .11625 L
.54665 .1147 L
.54787 .11406 L
.54898 .11448 L
.55023 .11611 L
.55138 .1187 L
.55265 .12274 L
.554 .12838 L
.5565 .14238 L
.55876 .1588 L
.56389 .20745 L
.56943 .27267 L
.57463 .33842 L
.57947 .39659 L
.58203 .42394 L
.58446 .44651 L
.58682 .46476 L
.58901 .47786 L
.59018 .4833 L
.59143 .48776 L
.59268 .49085 L
.59339 .49197 L
.59406 .4926 L
.59475 .49282 L
.59541 .49261 L
.59666 .4911 L
.59735 .48964 L
.598 .48787 L
.59946 .48246 L
.60078 .47591 L
.60221 .4671 L
.60481 .44685 L
.60966 .39641 L
.62054 .25476 L
.62513 .20051 L
.62765 .17596 L
.63004 .15734 L
.63139 .1491 L
.6321 .14547 L
.63286 .14216 L
.6335 .13984 L
Mistroke
.6342 .13777 L
.63543 .13539 L
.63668 .13465 L
.63739 .13499 L
.63803 .13578 L
.63922 .13841 L
.64047 .14283 L
.64179 .14929 L
.64299 .15671 L
.64568 .1784 L
.65053 .23222 L
.65587 .30497 L
.66153 .38248 L
.66628 .43548 L
.66758 .44674 L
.66898 .45693 L
.6703 .4646 L
.67151 .46986 L
.67268 .47329 L
.67377 .47497 L
.67496 .4751 L
.67623 .47328 L
.67744 .46966 L
.67858 .46459 L
.6796 .45871 L
.68071 .45098 L
.68322 .4285 L
.68598 .39705 L
.69154 .3196 L
.69632 .25033 L
.69883 .21752 L
.7015 .18814 L
.7028 .17644 L
.70423 .16581 L
.70553 .15838 L
.70676 .15346 L
.70801 .15057 L
.70915 .14986 L
.71041 .15125 L
.71173 .15515 L
.71284 .16036 L
.71403 .16779 L
.71618 .18575 L
.71873 .2139 L
.72104 .24455 L
.72633 .32424 L
.72923 .36745 L
.73193 .4035 L
.73443 .43068 L
.73552 .44022 L
Mistroke
.73671 .44877 L
.73801 .45577 L
.73925 .46002 L
.73993 .46134 L
.74066 .46192 L
.74197 .46082 L
.74315 .45745 L
.74423 .45242 L
.74542 .44481 L
.74667 .43454 L
.74878 .4125 L
.75109 .3826 L
.75638 .30118 L
.76118 .22864 L
.76386 .1964 L
.76508 .18465 L
.76639 .17465 L
.76705 .1706 L
.76777 .167 L
.76906 .16287 L
.76978 .16183 L
.77055 .16176 L
.77128 .16269 L
.77195 .16439 L
.77323 .16984 L
.77441 .17742 L
.77571 .1884 L
.7771 .20292 L
.78199 .27195 L
.78699 .35394 L
.78973 .39416 L
.79228 .42405 L
.79361 .43576 L
.7943 .44058 L
.79504 .44485 L
.79586 .44832 L
.79663 .45042 L
.79738 .45132 L
.79807 .45116 L
.7993 .44849 L
.8 .44564 L
.80066 .44208 L
.80198 .43248 L
.80341 .41866 L
.81304 .26949 L
.81568 .22884 L
.81713 .2099 L
.8185 .19498 L
.81978 .18407 L
.8205 .17931 L
Mistroke
.82116 .17586 L
.82234 .17206 L
.82358 .17131 L
.82482 .17398 L
.82596 .17936 L
.82727 .18893 L
.82851 .20114 L
.83072 .22933 L
.83312 .26727 L
.83864 .36276 L
.84103 .39846 L
.84229 .41383 L
.84362 .42685 L
.8443 .43211 L
.84505 .4367 L
.84636 .44168 L
.847 .44263 L
.84769 .44255 L
.84893 .43951 L
.84966 .43602 L
.85045 .43082 L
.85188 .41786 L
.85328 .40125 L
.85457 .38291 L
.85946 .29814 L
.86216 .25097 L
.86349 .23033 L
.86473 .21358 L
.86599 .19942 L
.86714 .18957 L
.86841 .18232 L
.86911 .18007 L
.86977 .17913 L
.87092 .18022 L
.87198 .18431 L
.87315 .19212 L
.87438 .20392 L
.87661 .23336 L
.8787 .268 L
.88343 .35516 L
.88471 .37659 L
.8861 .39715 L
.88733 .4122 L
.88864 .42442 L
.88981 .43169 L
.8911 .43533 L
.89228 .43452 L
.89338 .43017 L
.89468 .42071 L
.89534 .41429 L
Mistroke
.89606 .40606 L
.89851 .36984 L
.90405 .26666 L
.90658 .22521 L
.90801 .20718 L
.90933 .19505 L
.91048 .18843 L
.91175 .18574 L
.91239 .18626 L
.91307 .18822 L
.91431 .19536 L
.91551 .20645 L
.91681 .22278 L
.91919 .26155 L
.92364 .34765 L
.92495 .37099 L
.92635 .39304 L
.92768 .40977 L
.9289 .42092 L
.92959 .42519 L
.93033 .42817 L
.93112 .42932 L
.93184 .42858 L
.93313 .42298 L
.93385 .41753 L
.93451 .41119 L
.9358 .39523 L
.93699 .37686 L
.93969 .32652 L
.94224 .27529 L
.94459 .23371 L
.94641 .20948 L
.94732 .20086 L
.94832 .19454 L
.94933 .19164 L
.9504 .19252 L
.95142 .19711 L
.95234 .20433 L
.95328 .21445 L
.95414 .22603 L
.95608 .25873 L
.95962 .33001 L
.96147 .36587 L
.96345 .39734 L
.96459 .41054 L
.96563 .41886 L
.96668 .42329 L
.96767 .42369 L
.9687 .42017 L
.96979 .41216 L
Mistroke
.97082 .40083 L
.97175 .38773 L
.97619 .30185 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00??ooool4o`000003oa0@4?oooooooooo0?oooooo
9_ooool003kooooo00?o0000ooooooooool0oooooolXooooo`00<oooool6o`0000Gooooo00?o0000
ooooooooool0oooooolXooooo`005oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
00Gooooo0ol0003oooooob3ooooo000Gooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooob3ooooo000Gooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooob3ooooo000Gooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooob3ooooo000H
ooooo`03o`000?oooooooooo027ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`3o
ooooob3ooooo000Hooooo`03o`000?oooooooooo02_ooooo0_l0003oooooob7ooooo000Hooooo`03
o`000?oooooooooo02_ooooo00?o0000ooooooooool0oooooolPooooo`006?ooool00ol0003ooooo
ooooo`0[ooooo`03o`000?oooooooooo0?oooooo8?ooool001Sooooo00?o0000ooooooooool0:ooo
ool00ol0003oooooooooo`3oooooob3ooooo000Iooooo`03o`000?oooooooooo02[ooooo0_l0003o
ooooob7ooooo000Iooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool06?ooool2o`00
0?oooooo1_ooool001Wooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Gooooo`;o
000000?oooooo`000?ooool0ooooool4ooooo`006Oooool00ol0003oooooooooo`0Zooooo`03o`00
0?oooooooooo01Oooooo00Co0000oooooooooooo0000ooooool5ooooo`006Oooool00ol0003ooooo
ooooo`0Zooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`3oooooo`;ooooo000Jooooo`03o`000?oooooooooo02Wooooo0_l0000Fooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0ooooool2ooooo`006_ooool00ol0003oooooooooo`0Y
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3o
ooooo`7ooooo000Jooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo0Oooool001[ooooo00?o0000oooooooo
ool0:Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0ooooool001[ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0ooooool001_ooooo00?o0000ooooooooool0:?oo
ool2o`0001Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooo`006oooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`3oooooo`006oooool00ol0003oooooooooo`05ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo0?kooooo000Kooooo`03o`000?oooooooooo00Gooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?kooooo000K
ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`3nooooo`007?ooool00ol0003oooooooooo`04ooooo`05o`000?oooooo
ooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo0ol0
000Cooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0o_ooool001cooooo00?o0000
ooooooooool01?ooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<c?ooool00ooo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo0?kooooo000Looooo`03o`000?oooooooooo00Cooooo00Go
410@oooooooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
:Oooool3o`000=;ooooo000Looooo`03o`000?oooooooooo00Cooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Xooooo`03
o`000?oooooo00000=;ooooo000Looooo`03o`000?oooooooooo00Cooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Kooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo02Sooooo00Co0000oooooooooooo0000dOooool001go
oooo00?o0000ooooooooool09_ooool2o`0001?ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0Xooooo`04o`000?ooooooooooo`000=7ooooo000Mooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Oo
oooo00Go0000ooooooooooooooooo`00003Aooooo`007Oooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Vooooo`05
o`000?ooooooooooooooool00000dOooool001gooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo0<oooooo000Mooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`3>ooooo`007_ooool00ol0003ooooooooo
o`0Uooooo`;o00004_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`3>ooooo`007_ooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`2]
ooooo`007_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool07Oooool00ol0003oooooo`00002^ooooo`007_ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Tooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool07?ooool00ol0003oooooo`00002^ooooo`00
7_ooool00ol0003oooooooooo`0Uooooo`;o00004_ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo02?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Kooooo`04o`00
0?ooooooooooo`000:kooooo000Oooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Kooooo`04o`000?ooooooooooo`000:kooooo000Oooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo02?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Kooooo`05o`00
0?ooooooooooooooool00000[Oooool001oooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool08oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo01_ooooo00Go0000ooooooooooooooooo`00002]ooooo`00
7oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
6_ooool01Ol0003ooooooooooooooooo000001Sooooo0_l0002Cooooo`007oooool00ol0003ooooo
ooooo`0Tooooo`;o00004Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02?ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool05_ooool2o`0009?ooooo000Pooooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool05Oooool01?l0003oooooooooool0002Booooo`008?ooool00ol0003ooooooooo
o`08ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o
<S8bomgMg@05ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo01Gooooo00Co0000oooooooooooo0000T_ooool0023o
oooo00?o0000ooooooooool02?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48oooo
o`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo02;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05Oooool01?l0003oooooooooool0002B
ooooo`008?ooool00ol0003oooooooooo`06o`0000;ooooo00Go410@oooooooooooooooooa0@400@
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05?ooool01?l0003oooooooooool0
000Dooooo`;o0000O?ooool0023ooooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooo
oooo000000oooooo00?oMgMgoc8b<_ooool01?ooool3o`0000oooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01?ooooo00Go0000oooooooooooooooo
o`00000Cooooo`03o`000?oooooo000007cooooo000Pooooo`03o`000?oooooooooo00Sooooo00Go
0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Cooooo`05o`000?ooooooooooooooool000004oooool00ol0003oooooo`00001loooo
o`008Oooool00ol0003oooooooooo`07ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0Qooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo01?ooooo00Go0000ooooooooooooooooo`00000C
ooooo`03o`000?oooooo0000017ooooo00?o0000ooooooooool0J?ooool0027ooooo00?o0000oooo
ooooool01oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Cooooo`05o`000?ooooooooooooooool000004oooool00ol0003oooooo`00
000Aooooo`;o0000JOooool0027ooooo00?o0000ooooooooool01oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00cooooo1?l00006ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01?ooooo00Go0000oooooooooooooooo
o`00000Cooooo`04o`000?ooooooooooo`0000oooooo00?o0000ooooool00000JOooool0027ooooo
00?o0000ooooooooool08_ooool2o`0000oooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0@ooooo`04o`000?ooooooooooo`0000oooooo00?o0000ooooool000003_ooool2o`0005Wo
oooo000Qooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00oooooo00Go0000ooooooooooooooooo`00000?ooooo`03
o`000?oooooo000000kooooo0_l0001Iooooo`008Oooool00ol0003oooooooooo`0Rooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Oooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0?ooooo`05o`00
0?ooooooooooooooool000003oooool01?l0003oooooooooool0000=ooooo`;o0000FOooool002;o
oooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool03oooool01Ol0003ooooooooooooooooo000000oooooo00Co0000oooo
oooooooo00003Oooool00ol0003oooooo`00000<ooooo`;o0000B_ooool002;ooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool03oooool01Ol0003ooooooooooooooooo000000oooooo00Co0000oooooooooooo00003Ooo
ool00ol0003oooooo`00000<ooooo`;o0000B_ooool002;ooooo00?o0000ooooooooool08Oooool2
o`0000kooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0?ooooo`05o`000?oooooo
ooooooooool000003oooool01?l0003oooooooooool0000=ooooo`03o`000?oooooo000000cooooo
0_l0000;ooooo`;o0000?Oooool002;ooooo00?o0000ooooooooool08Oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03oooool01Ol0003ooooooooo
oooooooo000000oooooo00Co0000oooooooooooo00003Oooool00ol0003oooooo`00000;ooooo`03
o`000?oooooo000000_ooooo0_l0000mooooo`008_ooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0>ooooo`05o`00
0?ooooooooooooooool000003_ooool01Ol0003ooooooooooooooooo000000cooooo00Co0000oooo
oooooooo00002oooool00ol0003oooooo`00000;ooooo`;o00002_ooool00ol0003oooooooooo`0`
ooooo`008_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0>ooooo`05o`000?ooooooooooooooool000003_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Co0000oooooooooooo00002oooool00ol0003ooooo
o`00000;ooooo`;o00002_ooool2o`00037ooooo000Sooooo`03o`000?oooooooooo023ooooo0_l0
000>ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03_ooool01Ol0003ooooooooo
oooooooo000000kooooo00Go0000ooooooooooooooooo`00000<ooooo`04o`000?ooooooooooo`00
00_ooooo00Co0000oooooooooooo00002_ooool2o`0000Wooooo00?o0000ooooool00000<Oooool0
02?ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00_ooooo00Go0000ooooooooooooooooo`00000<ooooo`04o`000?ooooooooooo`0000_ooooo00Co
0000oooooooooooo00002Oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo0000037o
oooo000Sooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0;ooooo`05o`000?ooooooooooooooool000003?ooool01?l0003oooooooooool0000;oooo
o`04o`000?ooooooooooo`0000Wooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00
000aooooo`008oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool02oooool01Ol0003ooooooooooooooooo000000cooooo00Co0000oooooooooooo0000
2oooool01?l0003oooooooooool00009ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000oooo
ool00000<Oooool002?ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`00000<ooooo`04o`000?oooooooooo
o`0000_ooooo00Co0000oooooooooooo00002Oooool01?l0003oooooooooool00008ooooo`03o`00
0?oooooo0000037ooooo000Tooooo`03o`000?oooooooooo01oooooo0_l0000=ooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`04o`000?oo
ooooooooo`0000_ooooo00Co0000oooooooooooo00002Oooool01?l0003oooooooooool00008oooo
o`03o`000?oooooo0000037ooooo000Tooooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool02_ooool01Ol0003ooooooooooooooooo000000[ooooo00Co0000oooooooooooo00002Oooool0
1?l0003oooooooooool00008ooooo`03o`000?oooooo0000037ooooo000Tooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Sooooo00Co0000oooooooooooo00002Oooool01?l0003oooooooooool00008ooooo`04o`00
0?ooooooooooo`00033ooooo000Sooooo`05onk^k_l0003o0000oc8b<_o^k^h01Oooool2ob4Q8@Co
oooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo
000000Wooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0000`ooooo`008ooo
ool01OmgMgOo0000oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool000002Oooool01?l0
003oooooooooool00008ooooo`04o`000?ooooooooooo`00033ooooo000Kooooo`Ko00000_ooool0
1Ol@413o0000oooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003ooooooooo
o`03ooooo`?o00002oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00Go
0000ooooooooooooooooo`000009ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooo
oooo0000<?ooool002?ooooo00Go0000ooooool0003oooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^
00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo000000Wooooo00Co0000
oooooooooooo00002?ooool01?l0003oooooooooool0000`ooooo`008oooool01Ol0003oooooo`00
0?oooooo000000kooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Go
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oo
oooo00Go0000ooooooooooooooooo`000009ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000
oooooooooooo0000<?ooool002?ooooo00Go410@ooooool0003ooooooa0@400?ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo000000Wooooo
00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0000`ooooo`008oooool01OmgMgOo
V9RHo`000?nHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Oooooo00Go0000ooooooooooooooooo`000009ooooo`05o`000?ooooooooooooooool00000
1oooool01?l0003oooooooooool0000`ooooo`008oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`0000cooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool000002?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo0000<?oo
ool002Gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`00033ooooo
000Vooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool01?l0003ooooooooo
ool0000`ooooo`009_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go
0000ooooooooooooooooo`00000`ooooo`009_ooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00Go0000ooooooooooooooooo`00000`ooooo`009_ooool00ol0003ooooooooo
o`0Mooooo`;o00002oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000033ooooo000Vooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo013ooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`08ooooo`Co000000So410@oooooooooooo
k^k^oc8b<_l0003o<S8bonk^kPKooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool5o`000005oa0@4?oooooo
ooooo`000?m4A4@00_l000000olb<S;ogMgMooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooooooo`Go0000
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Cooooo000Vooooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01?ooooo
00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool02_ooool2o`0000?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Oooooo00Co0000oooooooooooo00001?ooool01_l0003ooooooooooooooooo
MgMgoc8b<PCooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00Wo0000ooooooooooooooooo`000?lQ8B7ok^k^oooooom4A4@00oooool01Omg
MgOoV9RHoooooonHV9SoMgMg02Cooooo000Wooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool02_ooool2o`0000?ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Oooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00So0000ooooooooooooooooo`000?nHV9So8B4Qonk^kPCooooo00Go410@oooo
oooooooooooooa0@400Tooooo`009oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Cooooo`03ogMgMolb<S;ooooo
00?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
00[ooooo0_l00003ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07
ooooo`04o`000?ooooooooooo`0000Cooooo00Ko0000ooooooooooooooooogMgMolb<S84ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`09
o`000?ooooooooooooooool0003ooooooiRHV?lQ8B7ok^k^00?ooooo00Go0000oooooooooooooooo
o`00000Tooooo`009oooool00ol0003oooooooooo`0Looooo`;o00002oooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo00oooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0:ooooo`;o0000
0oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool01?l0003o
ooooooooool00004ooooo`;o000000Co8B4Qo`000?lb<S;oc<c<1?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooo
oooo000000;ooooo00?oMgMgofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000002Cooooo
000Wooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02_ooool2o`0000?ooooo00Go
410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo
00001?ooool2o`0000Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool@41000oooool00ol@413oooooooooo`0Rooooo`009oooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo00[ooooo0_l00003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`07ooooo`04o`000?ooooooooooo`0000Cooooo0_l00008ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`09o`000?oo
ooooooooooooool0003o^[ZjoooooonHV9So410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0T
ooooo`009oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`0?ooooo`Co00001?ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool02Oooool01?mEEEGoIVIVo`000?l00003
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`04o`000?mE
EEGoIVIVo`0000Cooooo1Ol00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`09o`000?ooooooooooooooool0003o410@o`000?lQ8B7o
c<c<00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Tooooo`009oooool00ol0003oooooooooo`0L
ooooo`;o00002_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool01Ol0003ooooooooooooooooo0000033ooooo000Xooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000033ooooo000X
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo01Gooooo0_l00002ooooo`;o00004_ooool002Sooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0?ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM4_oo
ool002Sooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0@ooooo`04omgMgOl0003o
410@olc<c1?ooooo000=oooooooo0000>_l0000;ooooo`04onk^k_lQ8B7o410@onk^kQ?ooooo000D
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`08
ooooo`;o00003?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo000000[ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooool000002_ooool2o`0000_ooooo00?o0000ooooooooool02?ooool00ol0003oooooo`000008
ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooooooool01?ooool2o`0000Sooooo00?o
0000ooooool000001Oooool00ol0003oooooooooo`03ooooo`;o00001_ooool00ol0003ooooooooo
o`02ooooo`;o00001_ooool01?l0003oooooooooooooool2o`0000Gooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0@ooooo`04ob4Q8OmgMgOoMgMgoc8b<Q?ooooo000Xooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool03Oooool00ol0003oooooo`00000:ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01?ooool00ol0003oooooo`000007ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0?ooooo`;o0000
0_ooool2o`0001;ooooo000Xooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09ooo
ool002Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Wooooo`00:Oooool00ol0
003oooooooooo`0Jooooo`;o00002Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool09oooool002Wooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0Xooooo`00:Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Sooooo
000Yooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0:?ooool002Wooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Xooooo`00:Oooool00ol0003oooooooooo`0Joooo
o`;o00002?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0:?ooool002Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Xooooo`00
:_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
7oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00Go0000oooooooooooo
ooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo02Sooooo000Zooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000:_ooool002[o
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`05o`000?oooooooooooooo
ool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`00
000Zooooo`00:_ooool00ol0003oooooooooo`0Iooooo`;o00002?ooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooo
oooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool0
0000:_ooool002[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`05o`00
0?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooo
ooooooooooooo`00000Zooooo`00:_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Kooooo00Go0000ooooooooooooooooo`000008ooooo`04o`000?ooooooooooo`0000Oooooo00Go
0000ooooooooooooooooo`00000Zooooo`00:_ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Kooooo00Go0000ooooooooooooooooo`000008ooooo`04o`000?ooooooooooo`0000Oo
oooo00Go0000ooooooooooooooooo`00000Zooooo`00:oooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Kooooo00Go0000ooooooooooooooooo`000008ooooo`04o`000?oooooooooo
o`0000Oooooo00Co0000oooooooooooo0000:oooool002_ooooo00?o0000ooooooooool06?ooool2
o`0000Oooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Kooooo00Go0000ooooooooooooooooo`000008ooooo`04o`000?ooooooooooo`0000Oooooo
00Co0000oooooooooooo0000:oooool002_ooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`06ooooo`05o`000?ooooooooooooooool000002?ooool01?l0003oooooooooool00007oooo
o`04o`000?ooooooooooo`0002_ooooo000Sooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool0
1?l0003oooooob4Q8OlQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo000000Sooooo00Co0000oooooooo
oooo00001oooool01?l0003oooooooooool0000[ooooo`008oooool01OmgMgOoV9RHoooooonHV9So
MgMg00?ooooo00Co0000oooooolQ8B7o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool0
00002?ooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0002_ooooo000Soooo
o`05oa0@4?ooooooooooooooool@41000oooool00ol0003oooooooooo`06ooooo`03oiRHV?lQ8B7o
k^k^00Wooooo00?o0000ooooooooool00oooool3o`0000Kooooo00?o0000ooooooooool08Oooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00Go0000ooooooooooooooooo`00
0008ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000:oooool002?ooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Oooooo00?oV9RHob4Q8Oo^k^h0
1oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00Go0000oooooooooooo
ooooo`000008ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000:oooool002?o
oooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Sooooo00?oMgMgofIV
I_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Rooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool0
1?l0003oooooooooool00009ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000
:oooool002?ooooo00Go410@oooooooooooooooooa0@4004ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool02?ooool01Ol0003ooooooooooooooooo000000Wooooo00Co0000oooooooo
oooo00002Oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo000002_ooooo000Soooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00ol0003oooooooooo`04ooooo`05o`000?nj^[[o
oooooiRHV?l@41001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool08_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool02?ooool01Ol0003ooooooooooooooooo000000Wooooo00Co0000oooooooooooo
00002Oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo000002_ooooo000Sooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01?ooool00ol0003oooooooooo`04ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l00006ooooo`03o`000?oooooooooo02?ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00Go0000
ooooooooooooooooo`000009ooooo`04o`000?ooooooooooo`0000Wooooo00Co0000oooooooooooo
00002?ooool00ol0003oooooo`00000[ooooo`00;?ooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooooooo000000Wo
oooo00Co0000oooooooooooo00002Oooool00ol0003oooooo`000009ooooo`03o`000?oooooo0000
02_ooooo000/ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`09ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000ooooool000002Oooool00ol0
003oooooo`000009ooooo`03o`000?oooooo000002_ooooo000/ooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00[o
oooo00Go0000ooooooooooooooooo`00000;ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000
ooooool000002Oooool00ol0003oooooo`000009ooooo`03o`000?oooooo000002_ooooo000/oooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00[ooooo00Go0000ooooooooooooooooo`00000;ooooo`04o`000?oooooo
ooooo`0000[ooooo00?o0000ooooool000002Oooool00ol0003oooooo`000009ooooo`03o`000?oo
oooo000002_ooooo000/ooooo`03o`000?oooooooooo01Oooooo0_l00005ooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo000000_ooooo00Co
0000oooooooooooo00002_ooool00ol0003oooooo`00000:ooooo`;o00002Oooool2o`0002cooooo
000]ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00[ooooo00Go0000ooooooooooooooooo`00000;ooooo`04o`00
0?ooooooooooo`0000[ooooo00?o0000ooooool000002_ooool2o`0000Wooooo0_l0000/ooooo`00
;Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0:ooooo`05o`000?ooooooooooooooool000002oooool01?l0003o
ooooooooool0000:ooooo`03o`000?oooooo000000[ooooo0_l0000:ooooo`03o`000?oooooooooo
02[ooooo000]ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03Oooool01Ol0003o
oooooooooooooooo000000gooooo00Co0000oooooooooooo00003?ooool00ol0003oooooo`00000;
ooooo`03o`000?oooooo000000[ooooo0_l0000gooooo`00;Oooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00gooooo00Go0000ooooooooooooooooo`00000=ooooo`04o`000?oooooo
ooooo`0000cooooo00?o0000ooooool000003?ooool2o`0000[ooooo0_l0000gooooo`00;Oooool0
0ol0003oooooooooo`0Fooooo`;o00001Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool03Oooool01Ol0003ooooooooooooooooo000000kooooo00?o
0000ooooool000003?ooool00ol0003oooooo`00000<ooooo`03o`000?oooooooooo04;ooooo000]
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03Oooool01Ol0003ooooooooooooo
oooo000000kooooo00?o0000ooooool000003Oooool2o`0000cooooo00?o0000ooooooooool0@_oo
ool002gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0=ooooo`05o`000?oooooo
ooooooooool000003_ooool00ol0003oooooo`00000=ooooo`;o0000DOooool002kooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo013ooooo00Go0000
ooooooooooooooooo`00000@ooooo`04o`000?ooooooooooo`0000oooooo00?o0000ooooool00000
3Oooool00ol0003oooooooooo`1@ooooo`00;_ooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool04?ooool01Ol0003ooooooooooooooooo0000017ooooo
00?o0000ooooool000003oooool00ol0003oooooo`00001Pooooo`00;_ooool00ol0003ooooooooo
o`0Eooooo`;o00001?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0@ooooo`05o`000?ooooooooooooooool00000
4Oooool00ol0003oooooo`00000?ooooo`;o0000HOooool002kooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo017ooooo00Co0000oooooooooooo0000
4Oooool00ol0003oooooo`00000@ooooo`03o`000?oooooooooo05oooooo000[ooooo`05onk^k_lb
<S;o0000o`000?o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool04Oooool01?l0003oooooooooool0000Aoooo
o`03o`000?oooooo000007;ooooo000[ooooo`05ogMgMonHV9Soooooo`000?mgMgL01Oooool2ob4Q
8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
01;ooooo00Co0000oooooooooooo00004_ooool2o`0007;ooooo000[ooooo`05oa0@4?oooooooooo
ooooool000004?ooool00ol0003oooooooooo`03ooooo`?o00000oooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0B
ooooo`04o`000?ooooooooooo`0001;ooooo00?o0000ooooooooool0LOooool002_ooooo00Go0000
ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0Booooo`04o`000?ooooooooooo`0008Kooooo000[ooooo`05o`000?oo
ooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo000008Oooooo000[ooooo`05oa0@
4?ooooooooooooooool000003?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool04_ooool00ol0003oooooo`000027ooooo`00:oooool01OmgMgOoV9RH
oooooonHV9So000000cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool05oooool01?l0003oooooooooool0000Foooo
o`;o0000Qoooool002_ooooo00Gok^k^oc8b<_l0003o<S8bo`00000<ooooo`Co00001_ooool2o`00
00?ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Hooooo`04o`000?oooooooooo
o`0009oooooo000_ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo01Sooooo00Co0000oooooooooooo0000Woooool0
033ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool06?ooool01?l0003oooooooooool0002Oooooo`00<?ooool00ol0
003oooooooooo`0Cooooo`05o`000?ooooooooooooooool00000;?ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooo00000:3ooooo000`ooooo`03o`000?oooooooooo01?ooooo00Go0000oooo
ooooooooooooo`00000]ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Wooooo0_l0002Pooooo`00<?ooool00ol0
003oooooooooo`0Cooooo`;o00000_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
01Wooooo0_l0002Pooooo`00<?ooool00ol0003oooooooooo`0Cooooo`05o`000?oooooooooooooo
ool00000;Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`2kooooo`00<Oooool00ol0003oooooooooo`0Booooo`05
o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2kooooo`00<Oooool00ol0003o
ooooooooo`0Booooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo023ooooo00Go0000ooooooooooooooooo`00002nooooo`00<Oooool00ol0
003oooooooooo`0Booooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo023ooooo00Go0000ooooooooooooooooo`00002nooooo`00<Oooool0
0ol0003oooooooooo`0Booooo`;o000000?oooooo`000?ooool0;Oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo027ooooo00Co0000oooooooooooo0000__ooool003;ooooo00?o0000
ooooooooool04Oooool01?l0003oooooooooool0000_ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool08Oooool00ol0003oooooo`00002oooooo`00<_ooool00ol0003oooooooooo`0A
ooooo`04o`000?ooooooooooo`0002oooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0Qooooo`?o0000_oooool003;ooooo00?o0000ooooooooool04Oooool01?l0003oooooooooool0
000_ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0i?ooool003;ooooo00?o0000
ooooooooool04Oooool01?l0003oooooooooool0000_ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0i?ooool003;ooooo00?o0000ooooooooool04Oooool2o`000003ooooool0003o
oooo02kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3Tooooo`00<oooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooo0000033ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3Tooooo`008oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`04o`000?oooooo0000onk^kPGooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oo
oooo0000037ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3Tooooo`008oooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`04o`000?ooooooEEEEojVYZ@Sooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooo`00000aooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0iOooool002?ooooo00Go410@oooooooooooooooooa0@400;ooooo`04o`00
0?ooooooZJVYoeEEE@Wooooo00?o0000ooooooooool00oooool00ol0003oooooo`00000aooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0iOooool002?ooooo00Go0000oooooooooooo
ooooo`00000<ooooo`03o`000?oooooo8B4Q00Sooooo00?oMgMgoc8b<_ooool01?ooool3o`0003;o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3Uooooo`008oooool01Ol0003ooooo
oooooooooooo000000cooooo00Co0000oooooomEEEGoc<c<1?ooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00Gooooo0_l0000cooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0iOooool0
02?ooooo00Go410@oooooooooooooooooa0@400<ooooo`04o`000?ooooooZJVYogMgM`Cooooo00?o
0000ooooooooool01oooool2o`0003?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`3Uooooo`008oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@o`000?oooooooooo
oc8b<P04ooooo`03o`000?oooooooooo00Oooooo0_l0000dooooo`04o`000?ooooooooooo`000>So
oooo000Sooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006ooooo`;o
0000=Oooool2o`000>Wooooo000dooooo`03o`000?oooooooooo00oooooo0_l0003oooooob7ooooo
000eooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0oooooolPooooo`00=Oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo0?oooooo8?ooool003Gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`3oooooob3ooooo000eooooo`03o`000?oooooooooo00ko
oooo0_l0003oooooob7ooooo000eooooo`03o`000?oooooooooo00gooooo0_l0003oooooob;ooooo
000fooooo`03o`000?oooooooooo00cooooo0_l0003oooooob;ooooo000fooooo`03o`000?oooooo
oooo00cooooo0_l0003oooooob;ooooo000fooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ool00000oooooolRooooo`00=oooool00ol0003oooooooooo`0:ooooo`04o`000?oooooo0000o`00
0?oooooo8Oooool003Oooooo00?o0000ooooooooool02_ooool00ol0003oooooo`00003oooooob;o
oooo000gooooo`03o`000?oooooooooo00[ooooo00?o0000ooooool00000oooooolRooooo`00>?oo
ool00ol0003oooooooooo`08ooooo`04o`000?ooooooooooo`000?oooooo8_ooool003Sooooo00?o
0000ooooooooool02?ooool01?l0003oooooooooool0003oooooob;ooooo000hooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool00_l0003oooooob7ooooo000hooooo`03o`000?oooooo
oooo00Sooooo00Co0000oooooooooooo0000oooooolRooooo`00>Oooool00ol0003oooooooooo`04
o`000003oa0@4?oooooo000000?ooooo00?o0000ooooooooool0oooooolPooooo`00>_ooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00003oooooob;ooooo000j
ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo0?oooooo8?ooool003[ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oo
oooooooo00;ooooo0ol0003oooooob3ooooo000nooooo`03o`000?oooooooooo0?oooooo:?ooool0
03kooooo00?o0000ooooooooool0oooooolXooooo`00?_ooool00ol0003oooooooooo`3oooooobSo
oooo000looooo`03oeEEEOmVIVKo00000?oooooo:_ooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool004;ooooo0ol000000ol@413oooooooooo`3oooooob7ooooo
0014ooooo`03oa0@4?nj^[[ooooo0?oooooo8_ooool004Cooooo00?oV9RHoc8b<_ooool0oooooolR
ooooo`00A?ooool00ooMgMgo0000okZj^P3oooooob;ooooo0014ooooo`03oeEEEOmgMgOoA4A40?oo
oooo8_ooool004?ooooo00GogMgMoa0@4?oooooo8B4QomgMg@3oooooob7ooooo0013ooooo`05ofIV
I_n7QhOooooooiRHV?mEEED0oooooolQooooo`00@_ooool00oo^k^ko0000onk^kP02ooooo`03o`00
0?oMgMgooooo0?oooooo7oooool004;ooooo00Co410@o`000?l0003ooooo0_l000000ol@413ooooo
ooooo`3ooooooakooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-5.66973, -1.05832, 0.1009, \
0.0129571}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.18254 0.0396825 0.309017 0.309017 [
[.38095 .29652 -3 -9 ]
[.38095 .29652 3 0 ]
[.57937 .29652 -6 -9 ]
[.57937 .29652 6 0 ]
[.77778 .29652 -6 -9 ]
[.77778 .29652 6 0 ]
[.97619 .29652 -6 -9 ]
[.97619 .29652 6 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.17004 0 -12 -4.5 ]
[.17004 0 0 4.5 ]
[.17004 .07725 -30 -4.5 ]
[.17004 .07725 0 4.5 ]
[.17004 .15451 -24 -4.5 ]
[.17004 .15451 0 4.5 ]
[.17004 .23176 -30 -4.5 ]
[.17004 .23176 0 4.5 ]
[.17004 .38627 -24 -4.5 ]
[.17004 .38627 0 4.5 ]
[.17004 .46353 -18 -4.5 ]
[.17004 .46353 0 4.5 ]
[.17004 .54078 -24 -4.5 ]
[.17004 .54078 0 4.5 ]
[.17004 .61803 -6 -4.5 ]
[.17004 .61803 0 4.5 ]
[.18254 .64303 -5 0 ]
[.18254 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.38095 .30902 m
.38095 .31527 L
s
[(5)] .38095 .29652 0 1 Mshowa
.57937 .30902 m
.57937 .31527 L
s
[(10)] .57937 .29652 0 1 Mshowa
.77778 .30902 m
.77778 .31527 L
s
[(15)] .77778 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(20)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.22222 .30902 m
.22222 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30159 .30902 m
.30159 .31277 L
s
.34127 .30902 m
.34127 .31277 L
s
.42063 .30902 m
.42063 .31277 L
s
.46032 .30902 m
.46032 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.53968 .30902 m
.53968 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.65873 .30902 m
.65873 .31277 L
s
.69841 .30902 m
.69841 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.81746 .30902 m
.81746 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.89683 .30902 m
.89683 .31277 L
s
.93651 .30902 m
.93651 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.10317 .30902 m
.10317 .31277 L
s
.06349 .30902 m
.06349 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.18254 0 m
.18879 0 L
s
[(-1)] .17004 0 1 0 Mshowa
.18254 .07725 m
.18879 .07725 L
s
[(-0.75)] .17004 .07725 1 0 Mshowa
.18254 .15451 m
.18879 .15451 L
s
[(-0.5)] .17004 .15451 1 0 Mshowa
.18254 .23176 m
.18879 .23176 L
s
[(-0.25)] .17004 .23176 1 0 Mshowa
.18254 .38627 m
.18879 .38627 L
s
[(0.25)] .17004 .38627 1 0 Mshowa
.18254 .46353 m
.18879 .46353 L
s
[(0.5)] .17004 .46353 1 0 Mshowa
.18254 .54078 m
.18879 .54078 L
s
[(0.75)] .17004 .54078 1 0 Mshowa
.18254 .61803 m
.18879 .61803 L
s
[(1)] .17004 .61803 1 0 Mshowa
.125 Mabswid
.18254 .01545 m
.18629 .01545 L
s
.18254 .0309 m
.18629 .0309 L
s
.18254 .04635 m
.18629 .04635 L
s
.18254 .0618 m
.18629 .0618 L
s
.18254 .09271 m
.18629 .09271 L
s
.18254 .10816 m
.18629 .10816 L
s
.18254 .12361 m
.18629 .12361 L
s
.18254 .13906 m
.18629 .13906 L
s
.18254 .16996 m
.18629 .16996 L
s
.18254 .18541 m
.18629 .18541 L
s
.18254 .20086 m
.18629 .20086 L
s
.18254 .21631 m
.18629 .21631 L
s
.18254 .24721 m
.18629 .24721 L
s
.18254 .26266 m
.18629 .26266 L
s
.18254 .27812 m
.18629 .27812 L
s
.18254 .29357 m
.18629 .29357 L
s
.18254 .32447 m
.18629 .32447 L
s
.18254 .33992 m
.18629 .33992 L
s
.18254 .35537 m
.18629 .35537 L
s
.18254 .37082 m
.18629 .37082 L
s
.18254 .40172 m
.18629 .40172 L
s
.18254 .41717 m
.18629 .41717 L
s
.18254 .43262 m
.18629 .43262 L
s
.18254 .44807 m
.18629 .44807 L
s
.18254 .47898 m
.18629 .47898 L
s
.18254 .49443 m
.18629 .49443 L
s
.18254 .50988 m
.18629 .50988 L
s
.18254 .52533 m
.18629 .52533 L
s
.18254 .55623 m
.18629 .55623 L
s
.18254 .57168 m
.18629 .57168 L
s
.18254 .58713 m
.18629 .58713 L
s
.18254 .60258 m
.18629 .60258 L
s
.25 Mabswid
.18254 0 m
.18254 .61803 L
s
gsave
.18254 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.06499 0 m
.07314 .033 L
.08284 .08223 L
.10458 .21942 L
.12545 .36771 L
.14465 .49389 L
.15434 .54568 L
.16339 .58308 L
.16795 .59716 L
.17029 .60304 L
.17283 .60835 L
.17428 .61084 L
.17562 .61281 L
.17687 .61435 L
.17825 .61571 L
.17949 .61662 L
.18065 .6172 L
.18188 .61754 L
.1832 .61757 L
.18445 .61729 L
.18559 .61676 L
.18691 .61583 L
.18816 .61463 L
.19037 .61174 L
.19277 .6075 L
.19541 .6015 L
.19822 .59364 L
.20324 .57573 L
.21328 .52603 L
.22434 .45293 L
.24542 .2825 L
.26468 .13473 L
.27421 .08119 L
.27682 .06993 L
.2796 .05976 L
.2822 .05204 L
.28459 .04656 L
.28577 .04445 L
.28705 .04258 L
.28834 .04118 L
.28905 .04062 L
.28971 .04023 L
.29092 .03984 L
.29203 .03986 L
.29331 .04034 L
.29452 .04124 L
.2956 .04242 L
.29675 .04406 L
.29882 .04799 L
.30105 .05364 L
Mistroke
.3035 .06156 L
.30843 .08269 L
.31362 .11198 L
.32289 .17978 L
.34376 .37057 L
.35333 .45238 L
.35858 .48967 L
.36354 .51784 L
.36579 .52802 L
.36816 .53687 L
.36941 .54067 L
.37077 .54417 L
.37203 .54676 L
.37317 .54858 L
.37429 .54986 L
.37535 .55061 L
.37647 .5509 L
.37769 .55064 L
.37876 .54991 L
.37989 .54863 L
.38085 .54712 L
.38192 .54501 L
.38426 .53875 L
.38682 .52936 L
.39199 .50272 L
.39678 .46963 L
.40124 .43264 L
.41196 .32749 L
.42209 .22406 L
.42685 .18047 L
.43189 .14122 L
.43452 .12436 L
.43742 .10914 L
.43869 .10366 L
.44005 .09863 L
.44133 .09474 L
.44252 .09186 L
.44367 .08976 L
.4449 .08827 L
.4456 .08778 L
.44626 .08755 L
.4475 .08775 L
.44868 .08871 L
.44977 .09025 L
.45096 .09266 L
.45223 .09604 L
.45441 .10387 L
.45646 .1134 L
.4611 .14255 L
.46611 .18431 L
Mistroke
.47156 .23897 L
.48147 .34933 L
.48608 .3987 L
.49104 .44558 L
.49333 .46396 L
.49573 .48065 L
.49781 .49263 L
.50003 .50269 L
.50125 .50697 L
.50236 .51004 L
.50347 .51233 L
.50452 .51376 L
.50575 .5145 L
.50688 .5143 L
.50812 .5131 L
.50944 .5107 L
.51067 .50741 L
.51199 .50277 L
.51438 .49153 L
.51722 .47361 L
.51982 .45326 L
.53072 .33747 L
.54083 .21867 L
.54558 .17226 L
.54791 .15371 L
.55005 .13964 L
.55253 .12727 L
.55383 .12258 L
.5545 .12069 L
.55521 .11905 L
.55636 .11723 L
.55743 .11649 L
.55871 .11682 L
.55987 .11828 L
.56116 .12117 L
.56181 .12314 L
.56253 .1257 L
.56498 .1375 L
.56785 .15694 L
.57053 .18017 L
.58061 .29714 L
.58557 .3603 L
.59099 .42208 L
.59346 .44537 L
.5961 .46557 L
.59738 .47342 L
.59859 .47955 L
.59968 .48396 L
.60085 .48752 L
.60201 .48978 L
Mistroke
.60308 .49074 L
.60427 .4905 L
.60554 .48875 L
.60618 .48728 L
.60687 .48525 L
.60813 .48038 L
.60936 .47422 L
.61049 .46731 L
.6148 .43143 L
.61937 .37961 L
.62874 .25518 L
.63365 .19699 L
.63634 .17172 L
.63764 .16157 L
.63883 .15372 L
.63989 .14791 L
.64103 .1429 L
.64224 .13912 L
.64339 .13702 L
.64464 .13639 L
.64528 .13674 L
.64598 .13766 L
.64721 .14062 L
.64837 .14492 L
.6495 .15053 L
.65057 .15711 L
.65258 .17258 L
.65711 .22031 L
.66672 .35234 L
.66925 .38599 L
.67199 .41823 L
.67435 .44123 L
.67569 .45186 L
.67695 .46001 L
.67813 .46604 L
.67939 .47062 L
.68009 .47228 L
.68074 .47329 L
.68198 .47369 L
.68313 .47228 L
.68419 .46946 L
.68536 .4647 L
.6866 .45779 L
.68874 .44155 L
.69076 .42179 L
.69534 .36401 L
.70519 .22287 L
.70759 .19521 L
.71015 .17215 L
.71162 .16246 L
Mistroke
.71295 .15617 L
.71359 .15402 L
.71429 .15236 L
.71556 .15116 L
.71671 .15211 L
.71779 .15477 L
.71897 .15963 L
.72024 .16704 L
.72157 .17714 L
.72283 .18878 L
.72519 .21543 L
.73407 .34635 L
.73646 .38095 L
.73903 .41348 L
.74022 .42613 L
.74147 .43759 L
.74255 .44578 L
.7437 .45266 L
.7449 .45765 L
.74602 .46021 L
.74671 .46076 L
.74736 .46057 L
.74857 .45834 L
.74922 .45615 L
.74991 .45307 L
.75115 .44566 L
.75248 .43509 L
.75395 .42055 L
.76338 .28232 L
.76564 .24769 L
.76804 .21492 L
.7703 .18997 L
.77137 .1807 L
.77235 .17376 L
.77355 .16752 L
.77485 .16362 L
.776 .16272 L
.7772 .1644 L
.77851 .16922 L
.77973 .17647 L
.78106 .18732 L
.78249 .20207 L
.78735 .27045 L
.79177 .34365 L
.79426 .38206 L
.79691 .41595 L
.79829 .42967 L
.79902 .43566 L
.79981 .44103 L
.80053 .44492 L
Mistroke
.80119 .44759 L
.80249 .45029 L
.80372 .44969 L
.80486 .44639 L
.80611 .43977 L
.80681 .43474 L
.80744 .42939 L
.81012 .39934 L
.81265 .36206 L
.81767 .27682 L
.82013 .23765 L
.82238 .20769 L
.82351 .19553 L
.82474 .18493 L
.82604 .17704 L
.82728 .17291 L
.82799 .17207 L
.82863 .17228 L
.82938 .1737 L
.83008 .17616 L
.83132 .1832 L
.83202 .18861 L
.83267 .19446 L
.83489 .22041 L
.83695 .25126 L
.84165 .33299 L
.844 .37243 L
.84623 .40409 L
.84745 .41813 L
.8481 .42436 L
.84879 .43 L
.85 .43739 L
.85112 .44114 L
.85233 .44177 L
.85364 .4384 L
.85488 .43139 L
.85603 .42171 L
.8582 .396 L
.86052 .36005 L
.86573 .26657 L
.86829 .22588 L
.86941 .21117 L
.87064 .19789 L
.8718 .18852 L
.87288 .18274 L
.87402 .17994 L
.87525 .18081 L
.87589 .18286 L
.87658 .18632 L
.87785 .1958 L
Mistroke
.87909 .20872 L
.88023 .22357 L
.88477 .30118 L
.88893 .37616 L
.89119 .40775 L
.89232 .41959 L
.89356 .42885 L
.89481 .43393 L
.89551 .43483 L
.89614 .43442 L
.89738 .43026 L
.89855 .42238 L
.89964 .4117 L
.9008 .39725 L
.90288 .36466 L
.90758 .27605 L
.91002 .23398 L
.91137 .21513 L
.91264 .20113 L
.91383 .1921 L
.91512 .18698 L
.9163 .1868 L
.91738 .1905 L
.91806 .19464 L
.9188 .20064 L
.92013 .2153 L
.92261 .2536 L
.9253 .30484 L
.92818 .36033 L
.9295 .38271 L
.93075 .40066 L
.93188 .41343 L
.9331 .42315 L
.93426 .42799 L
.93549 .42824 L
.93654 .42444 L
.93769 .41608 L
.93835 .40947 L
.93905 .40116 L
.94029 .38323 L
.94308 .3322 L
.94573 .27883 L
.94814 .23548 L
.94943 .21691 L
.95066 .20368 L
.95195 .19493 L
.95268 .19254 L
.95335 .19203 L
.95447 .19481 L
.95571 .20299 L
Mistroke
.957 .2169 L
.9582 .23426 L
.96395 .34673 L
.96647 .39061 L
.96716 .40003 L
.96789 .40848 L
.96921 .41913 L
.97018 .42292 L
.97109 .42321 L
.97191 .42075 L
.97279 .41524 L
.97365 .40714 L
.97456 .39591 L
.97619 .3699 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00??ooool4o`000003oa0@4?oooooooooo0?oooooo
9_ooool003kooooo00?o0000ooooooooool0oooooolXooooo`00<oooool6o`0000Gooooo00?o0000
ooooooooool0oooooolXooooo`008Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
00Gooooo0ol0003oooooob3ooooo000Qooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3oooooob3ooooo000Qooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooob3ooooo000Rooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooob3ooooo000R
ooooo`03o`000?oooooooooo01Oooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`3o
ooooob3ooooo000Rooooo`03o`000?oooooooooo027ooooo0_l0003oooooob7ooooo000Sooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0oooooolPooooo`008oooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo0?oooooo8?ooool002?ooooo00?o0000ooooooooool08?oo
ool00ol0003oooooooooo`3oooooob3ooooo000Tooooo`03o`000?oooooooooo01oooooo0_l0003o
ooooob7ooooo000Tooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0oooooolPoooo
o`009?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo0?oooooo8?ooool002Cooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`0Nooooo`;o0000ooooool002Gooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`0Mooooo`;o000000?oooooo`000?ooool0oOoo
ool002Gooooo00?o0000ooooooooool07_ooool2o`0001kooooo00Co0000oooooooooooo0000o_oo
ool002Gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Mooooo`05o`000?oooooo
ooooooooool00000oOooool002Gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0n_ooool002Gooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0n_ooool002Kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0nOooool002Kooooo00?o0000ooooooooool0
7Oooool2o`0001cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3iooooo`009_oo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`3iooooo`008oooool01Oo^k^ko<S8bo`000?l0003ok^k^00Gooooo0_lQ
8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3iooooo`008ooo
ool01OmgMgOoV9RHooooool0003oMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0nOooool001_ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool00000
3Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?Sooooo000Sooooo`05o`000?oo
ooooooooooooool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Cooooo
0ol0000Iooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0n?ooool002?ooooo00Go
0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o
<S8bolc<c005ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`3hooooo`008oooool01Ol@413ooooooooooooooooo000000kooooo00?oZJVYogMgMooo
ool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`3hooooo`008oooool01OmgMgOoV9RHoooooonHV9So000000_o
oooo00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02Sooooo0_l0003>oooo
o`008oooool01Oo^k^ko<S8bo`000?lb<S;o000000_ooooo1Ol00004ooooo`Co00001_ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool09oooool00ol0
003oooooo`00003>ooooo`009oooool00ol0003oooooooooo`0Looooo`;o00006Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo02Kooooo00Co0000oooooooooooo0000cOooool002So
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool09_ooool01?l0003oooooooooool0003=ooooo`00:?ooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0Uooooo`05o`000?ooooooooooooooool00000cOooool002Sooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0<[ooooo000Xooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3:ooooo`00:?oo
ool00ol0003oooooooooo`0Kooooo`;o00006?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo02?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3:ooooo`00:?ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0b_ooool0
02Sooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
01cooooo0_l0002/ooooo`00:Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool07?ooool00ol0003oooooo`00002[ooooo`00:Oooool00ol0003ooooo
ooooo`0Jooooo`;o00006?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo00000:_ooooo
000Yooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Jooooo`04o`000?ooooooooooo`000:_ooooo000Yooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo027ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Jooooo`04o`000?ooooooooooo`000:_ooooo
000Yooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Jooooo`04o`000?ooooooooooo`000:_ooooo000Yooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo027ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`2?ooooo`00:Oooool00ol0003oooooooooo`0J
ooooo`;o00005oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool05Oooool2o`00097ooooo000Zooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool05Oooool00ol0003oooooo`00002@ooooo`00:_ooool01_l0003ok^k^oc8b<_l0003o<S8b
onk^kPGooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool08Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooo0000093ooooo000Zooooo`06o`000?mgMgOoV9RHoooooonHV9SoMgMg
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooo0000093ooooo000Sooooo`Ko000000?oooooo`000?l@41000oooool00ol@413ooooooooo
o`0>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05?ooool01?l0003ooooooooo
ool0000Cooooo`;o0000N_ooool002[ooooo0_l00003ooooo`03o`000?oooooooooo00gooooo00?o
MgMgoc8b<_ooool01?ooool3o`0001Gooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo01?ooooo00Go0000ooooooooooooooooo`00000Cooooo`;o0000
N_ooool002[ooooo0_l00003ooooo`03o`000?oooooooooo00[ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c005ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo01?ooooo00Go0000ooooooooooooooooo`00000Booooo`03
o`000?oooooo000007[ooooo000Zooooo`03o`000?l@413ooooo00;ooooo00?o410@ooooooooool0
2_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01?ooooo00Go0000oooooooooooo
ooooo`00000Booooo`03o`000?oooooo000007[ooooo000[ooooo`05o`000?nHV9SooooooiRHV?mg
MgL03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01?ooooo00Go0000oooooooo
ooooooooo`00000Booooo`03o`000?oooooo0000017ooooo00?o0000ooooooooool0I_ooool002_o
oooo00Go0000oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03oooool01Ol0003ooooooooooooooooo
000000oooooo0_l0001Xooooo`00:oooool00ol0003oooooooooo`0Hooooo`;o00005_ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00oooooo00Go0000ooooooooooooooooo`00000?
ooooo`03o`000?oooooo000000kooooo00?o0000ooooooooool0E_ooool002_ooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool03oooool01Ol0003ooooooooooooooooo000000oooooo00?o0000ooooool000003_ooool2
o`0005Oooooo000[ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00oooooo00Go0000ooooooooooooooooo`00000?
ooooo`03o`000?oooooo000000kooooo0_l0001Gooooo`00:oooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0?oooo
o`05o`000?ooooooooooooooool000003oooool00ol0003oooooo`00000>ooooo`;o00003Oooool0
0ol0003oooooooooo`17ooooo`00:oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0?ooooo`05o`000?oooooooooo
ooooool000003oooool01?l0003oooooooooool0000<ooooo`03o`000?oooooo000000cooooo0_l0
0019ooooo`00;?ooool00ol0003oooooooooo`0Gooooo`;o00005Oooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00oooooo00Go0000ooooooooooooooooo`00000>ooooo`05o`000?oo
ooooooooooooool000003?ooool00ol0003oooooo`00000<ooooo`;o00002oooool2o`0003cooooo
000/ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00kooooo00Go0000ooooooooooooooooo`00000>ooooo`05o`00
0?ooooooooooooooool000003?ooool01?l0003oooooooooool0000;ooooo`;o00002oooool2o`00
03cooooo000/ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00kooooo00Go0000ooooooooooooooooo`00000>oooo
o`05o`000?ooooooooooooooool000003?ooool01?l0003oooooooooool0000;ooooo`03o`000?oo
oooo000000[ooooo0_l0000:ooooo`03o`000?oooooooooo02oooooo000/ooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00kooooo00Go0000ooooooooooooooooo`00000>ooooo`05o`000?ooooooooooooooool00000
3?ooool01?l0003oooooooooool0000;ooooo`03o`000?oooooo000000[ooooo0_l0000:ooooo`;o
0000<?ooool002cooooo00?o0000ooooooooool05oooool2o`0001Cooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0>ooooo`05o`000?ooooooooooooooool000003_ooool01Ol0003o
oooooooooooooooo000000cooooo00Co0000oooooooooooo00002oooool00ol0003oooooo`00000:
ooooo`03o`000?oooooo000000Wooooo0_l0000`ooooo`00;?ooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0>oooo
o`05o`000?ooooooooooooooool000003_ooool01Ol0003ooooooooooooooooo000000cooooo00Co
0000oooooooooooo00002oooool00ol0003oooooo`00000:ooooo`03o`000?oooooo000000Wooooo
0_l0000`ooooo`00;?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool02oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oooooooooooo
ooooo`00000;ooooo`03o`000?oooooo000000[ooooo00?o0000ooooool000002Oooool2o`00033o
oooo000]ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0;ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooooooooooo0000
00[ooooo00Co0000oooooooooooo00002_ooool00ol0003oooooo`000009ooooo`;o0000<?ooool0
02gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00_ooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?ooooooooooooooool000002_oo
ool01?l0003oooooooooool00009ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooo
oooo0000;oooool002gooooo00?o0000ooooooooool05_ooool2o`0001Cooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool02oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`00000:
ooooo`04o`000?ooooooooooo`0000Wooooo00Co0000oooooooooooo00002?ooool01?l0003ooooo
ooooool0000_ooooo`00;Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oooooooo
ooooooooo`00000:ooooo`05o`000?ooooooooooooooool000002?ooool01?l0003oooooooooool0
0008ooooo`04o`000?ooooooooooo`0002oooooo000]ooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool02?ooool01Ol0003ooooooooooooooooo000000[ooooo00Go0000oooooooooooo
ooooo`000008ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000;oooool0
02?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03o`000?lQ8B7ooooo00?ooooo1Ol00004
ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`05o`000?oo
ooooooooooooool000002_ooool01Ol0003ooooooooooooooooo000000Sooooo00Co0000oooooooo
oooo00002?ooool01?l0003oooooooooool0000_ooooo`008oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo00?o0000ob4Q8Oooool00oooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o
MgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool00000
2_ooool01Ol0003ooooooooooooooooo000000Sooooo00Co0000oooooooooooo00002?ooool01?l0
003oooooooooool0000_ooooo`006oooool6o`0000;ooooo00Go410@oooooooooooooooooa0@4006
ooooo`03o`000?oooooooooo00?ooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03
ooooo`?o00004_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool02?ooool01Ol0003ooooooooooooooooo000000[ooooo00Go0000oooooooooooooooo
o`000008ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000;oooool002?o
oooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00Cooooo00?oV9RHob4Q
8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo00Go0000oooo
ooooooooooooo`00000:ooooo`05o`000?ooooooooooooooool000002?ooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`0002oooooo000Sooooo`05o`000?ooooooooooooooool0
00001_ooool00ol0003oooooooooo`05ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0
003o<S8bolc<c005ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`07ooooo`05o`000?ooooooooooooooool000002?ooool01Ol0003ooooooooooooo
oooo000000Oooooo00Co0000oooooooooooo0000;oooool002?ooooo00Go410@oooooooooooooooo
oa0@4006ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`07ooooo`05o`000?ooooooooooooooool000002?ooool01Ol0003ooooooooooooooooo0000
00Oooooo00Co0000oooooooooooo0000;oooool002?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06
ooooo`03o`000?oooooooooo00;ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Oooooo00Go0000ooooooooooooooooo`000008ooooo`05o`000?ooooooooooooooool0
00001oooool01?l0003oooooooooool0000_ooooo`008oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Kooooo00?o0000ooooooooool00_ooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006
ooooo`;o00004_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool000001ooo
ool01?l0003oooooooooool0000_ooooo`00;_ooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo000000Oooooo
00Co0000oooooooooooo0000;oooool002oooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Kooooo00Go0000ooooooooooooooooo`000007ooooo`04
o`000?ooooooooooo`0002oooooo000_ooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01Oooool01?l0003oooooooooool0000_ooooo`00;oooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000_ooooo`00;oooool00ol0003o
ooooooooo`0Dooooo`;o00004_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000002oooooo000_ooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo00[ooooo00GoA4A4o`000?l0003o<S8bomgMg@08ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`05ooooo`Co000000So410@o`00
0?ooooook^k^oc8b<_l0003o<S8bonk^kPWooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool4o`000005oa0@
4?oooooooooooooooom4A4@00_l000000olb<S;ogMgMooooo`04ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Go
00000oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Cooooo000_ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00go
oooo00?oMgMgoc8b<_ooool01oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool01oooool02_l0003oooooooooool0003oooooogMgMonHV9SooooooiRH
V?mgMgL9ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Sooooo0_l00006ooooo`04o`000?ooooooMgMgoc8b<PGo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00So0000ooooooooooooV9RHob4Q8Ol0003oooooodA4A0?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0Tooooo`00;oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Oooooo00Ko
0000oooooooooooo0000ooooool@4103ooooo`03oa0@4?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool02?ooool2o`0000Kooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01ol0003ooooooooooooooooo
V9RHo`000?o^k^h01?ooool01Ol@413ooooooooooooooooo410@02Cooooo000`ooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo00gooooo00?oMgMgoc8b<_ooool01oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool01oooool01_l0003oooooooooool0003oooooo`0000?o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`08ooooo`;o00001_ooool01?l0003o
ooooogMgMolb<S85ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ob4Q8Oo^k^h00oooool01Ol0
003ooooooooooooooooo000002Cooooo000`ooooo`03o`000?oooooooooo01?ooooo0_l0000Aoooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02_ooool01Ol0003o8B4Qo`000?lb<S;o
c<c<00Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo00Oooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool02?ooool2o`0000Gooooo0ol000000olb<S;oc<c<ooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ogMgMomVIVH00oooool01Ol0003ooooooooooooooooo000002Co
oooo000`ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01oooool01_l0003ooooo
oooooooooooo0000oa0@40?ooooo00?o410@ooooooooool01_ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07oooo
o`;o00001Oooool2o`0000Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooo`000003oooo
o`05oa0@4?ooooooooooooooool@41009?ooool0033ooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`07ooooo`0:o`000?ooooooooooooooool0003oMgMgoiRHV?ooooooV9RHogMgM`So
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01oooool2o`0000Gooooo0_l00008ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`08o`000?ooooooooooo`00
0?nj^[[o0000oiRHV?l@4103ooooo`05ogMgMonHV9SooooooiRHV?mgMgL09?ooool0033ooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool02_ooool4o`0000Wooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo00Gooooo00?oEEEEofIVI_l000000oooool01_l0003ok^k^oc8b
<_l0003o<S8bonk^kPSooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00omEEEGo0000o`000005ooooo`Co
00001_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool02?l0003ooooooooooonHV9So410@o`000?lQ8B7oc<c<0oooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^02Cooooo000`ooooo`03o`000?oooooooooo01?ooooo0_l0000Aooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0;?ooool0037ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0;?ooool0
037ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool05?ooool2o`0000;ooooo0_l0000Booooo`00<Oooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0Dooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM4_ooool0037ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool05Oooool01?oMgMgo0000oa0@4?o<c<`Cooooo`003Oooooooo`0003[o00002oooool01?o^
k^ko8B4Qoa0@4?o^k^hCooooo`005?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00Wooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`08ooooo`;o00003?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooo000000_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooool000003?ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooo000000Wooooo00?o0000ooooool000002_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooo000000Kooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooo
oooo000000Kooooo0_l00006ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000001_oo
ool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00oooool01_l0003ooooo
ooooool0003oooooo`0000Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0@oooo
o`04ob4Q8OmgMgOoMgMgoc8b<Q?ooooo000aooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool00oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00oooooo0_l00002ooooo`;o00004_ooool0
03;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0;?ooool003;ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0:oooool003;ooooo
00?o0000ooooooooool04Oooool2o`00013ooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0[ooooo`00<_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0[ooooo`00<_ooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0[
ooooo`00<_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000001_ooool0
0ol0003oooooooooo`0[ooooo`00<_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`05o`000?oooooooooo
ooooool000001_ooool00ol0003oooooooooo`0[ooooo`00<oooool00ol0003oooooooooo`0@oooo
o`;o00003oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo02_ooooo000cooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo02_ooooo000coooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
oooo02_ooooo000cooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000006
ooooo`03o`000?oooooooooo02_ooooo000cooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo02_ooooo000cooooo`03o`000?oooooooooo
013ooooo0_l0000>ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0:oooool003?ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01Oooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo02_ooooo000doooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00001oooool00ol0003oooooooooo`0[
ooooo`00=?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000
ooooooooool0:oooool003Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00007
ooooo`05o`000?ooooooooooooooool00000:Oooool003Cooooo00?o0000ooooooooool03oooool2
o`0000kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`04o`000?oooooo
ooooo`0000Oooooo00Go0000ooooooooooooooooo`00000Yooooo`00=?ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`05ooooo`04o`000?ooooooooooo`0000Oooooo00Go0000ooooooooooooooooo`00000Yooooo`00
8oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00001oooool01Ol0003ooooooooooooo
oooo000002Wooooo000Sooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go
V9RHob4Q8Ol0003oooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo
00001oooool01Ol0003ooooooooooooooooo000002Wooooo000Sooooo`05oa0@4?oooooooooooooo
ool@41003?ooool00onHV9So0000onk^kP09ooooo`03o`000?oooooooooo00?ooooo0ol0000<oooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06oooo
o`05o`000?ooooooooooooooool000002?ooool01?l0003oooooooooool00007ooooo`04o`000?oo
ooooooooo`0002[ooooo000Sooooo`05o`000?ooooooooooooooool000003Oooool00ol0003o8B4Q
onk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool01Ol0003ooooo
oooooooooooo000000Sooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool0000Z
ooooo`008oooool01Ol0003ooooooooooooooooo000000gooooo00?o0000ogMgMomVIVH01?ooool0
1Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`08ooooo`05o`000?ooooooooooooooool000002?ooool01Ol0003ooooooooooooooooo000000So
oooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool0000Zooooo`008oooool01Ol@
413ooooooooooooooooo410@00gooooo00?o0000ooooool000001?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooo
oooo000000Wooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00007ooooo`04
o`000?ooooooooooo`0002[ooooo000Sooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[Zjo`000?nHV9So410@00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Sooooo00Go0000ooooooooooooooooo`000009ooooo`04o`000?oo
ooooooooo`0000Sooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00000Zooooo`00
8oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c004oooo
o`Co00001_ooool2o`0000gooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0;oooo
o`05o`000?ooooooooooooooool000002_ooool01Ol0003ooooooooooooooooo000000Wooooo00Co
0000oooooooooooo00002?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooo000002[o
oooo000fooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`00000:ooooo`05
o`000?ooooooooooooooool000002Oooool01?l0003oooooooooool00008ooooo`04o`000?oooooo
ooooo`0000Sooooo00?o0000ooooool00000:_ooool003Kooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02oooool0
1Ol0003ooooooooooooooooo000000[ooooo00Go0000ooooooooooooooooo`000009ooooo`04o`00
0?ooooooooooo`0000Sooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00000Zoooo
o`00=_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool000002_ooool01?l0
003oooooooooool0000:ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooool000002?oo
ool00ol0003oooooo`00000Zooooo`00=_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0;ooooo`05o`000?oooooo
ooooooooool000002_ooool01?l0003oooooooooool0000:ooooo`04o`000?ooooooooooo`0000Wo
oooo00?o0000ooooool000002?ooool2o`0002_ooooo000fooooo`03o`000?oooooooooo00gooooo
0_l0000<ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02oooool01?l0003ooooo
ooooool0000;ooooo`04o`000?ooooooooooo`0000[ooooo00Co0000oooooooooooo00002Oooool2
o`0000Wooooo0_l0000[ooooo`00=_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0;ooooo`04o`000?oooooooooo
o`0000_ooooo00Co0000oooooooooooo00002_ooool00ol0003oooooo`00000:ooooo`;o00002Ooo
ool2o`0002_ooooo000gooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03Oooool0
1Ol0003ooooooooooooooooo000000gooooo00Co0000oooooooooooo00003?ooool00ol0003ooooo
o`00000:ooooo`03o`000?oooooo000000[ooooo0_l0000:ooooo`03o`000?oooooooooo02Wooooo
000gooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0Sooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03Oooool01Ol0003ooooooooo
oooooooo000000gooooo00Co0000oooooooooooo00003?ooool00ol0003oooooo`00000;ooooo`;o
00002_ooool2o`0003Kooooo000gooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
3Oooool01Ol0003ooooooooooooooooo000000gooooo00Co0000oooooooooooo00003?ooool00ol0
003oooooo`00000;ooooo`;o0000@_ooool003Oooooo00?o0000ooooooooool03?ooool2o`0000co
oooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00go
oooo00Go0000ooooooooooooooooo`00000=ooooo`04o`000?ooooooooooo`0000cooooo00?o0000
ooooool000002oooool2o`0004;ooooo000gooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool03Oooool01Ol0003ooooooooooooooooo000000gooooo00Co0000oooooooooooo00003?oo
ool2o`00053ooooo000gooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03Oooool0
1Ol0003ooooooooooooooooo000000gooooo00?o0000ooooool000003Oooool2o`00053ooooo000g
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03_ooool00ol0003oooooo`00000>
ooooo`03o`000?oooooo000000kooooo00?o0000ooooooooool0C_ooool003Sooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo000000oooooo0_l0001Ooooo
o`00>?ooool00ol0003oooooooooo`0;ooooo`;o00002oooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Aooooo`05
o`000?ooooooooooooooool000004?ooool00ol0003oooooo`00000?ooooo`;o0000Goooool003So
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo017o
oooo00Co0000oooooooooooo00004Oooool00ol0003oooooo`00001`ooooo`00:oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B400ooooooo0000ooooo`02ooooo`05odA4A?l0003o0000
oc8b<_oMgMd01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo00Co0000
oooooooooooo00004Oooool00ol0003oooooo`00001`ooooo`00:oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B400ooooooo0000ooooo`05ooooo`03ogMgMolb<S;ooooo00Cooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0Aooooo`04o`000?ooooooooooo`00017ooooo
0_l0001aooooo`00:oooool01Ol@413ooooooooooooooooo410@00Sooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`03ooooo`?o00002_ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo01Gooooo00Go0000ooooooooooooooooo`00000Dooooo`04o`000?ooooooooooo`00
01;ooooo00?o0000ooooooooool0Koooool002_ooooo00Go0000ooooooooooooooooo`000009oooo
o`03o`000?oooooooooo00?ooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo02Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05_ooool01Ol0003ooooooooooooooooo
000001Cooooo00Co0000oooooooooooo0000Q?ooool002_ooooo00Go0000ooooooooooooooooo`00
0009ooooo`08o`000?ooooooooooo`000?lQ8B7o0000oc8b<_o<c<`5ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Fooooo`05o`000?oooooooooo
ooooool000005?ooool00ol0003oooooo`000025ooooo`00:oooool01Ol@413ooooooooooooooooo
410@00Wooooo00Co0000oooooooooooo00002Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo02Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool05_ooool01Ol0003ooooooooooooooooo000001Gooooo
0_l00025ooooo`00:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Wooooo00Co0000oooooooooooo
00002Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02Oooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool05_ooool01Ol0003ooooooooooooooooo000001Gooooo0_l00025ooooo`00:oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Wooooo00?o0000ooooooooool01?l00006ooooo`;o00002_ooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo01Oooooo00Co0000oooooooooooo0000W?ooool0
03Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool05oooool01?l0003oooooooooool0002Looooo`00>Oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooo000009gooooo000jooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01So
oooo00?o0000ooooool00000WOooool003[ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`2Looooo`00>_ooool00ol0003oooooooooo`09ooooo`;o00002Oooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo0;Sooooo000jooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0;Sooooo000joooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Zoooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07oooool01Ol0003ooooooooooooooooo
00000;[ooooo000jooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0Zooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07oooool01Ol0
003ooooooooooooooooo00000;[ooooo000kooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool07oooool01?l0003oooooooooool0002kooooo`00>oooool00ol0003oooooooooo`08oooo
o`;o00002?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool08?ooool00ol0003oooooo`00002kooooo`00>oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo023ooooo0_l0002looooo`00>oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo0=kooooo000kooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0gooo
ool003cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo02cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3Oooooo`00??ooool00ol0
003oooooooooo`07ooooo`;o00001oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0goooool003cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`3Oooooo`008oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03
o`000?o^k^kooooo00Cooooo0ol000000olb<S;ogMgMooooo`04ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0=oo
oooo000Sooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOoo
ool01?ooool01Ol0003ooooooooooomgMgOo<S8b00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0_ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0h?ooool002?o
oooo00Go410@oooooooooooooooooa0@400=ooooo`03ojVYZOmEEEGooooo00Gooooo00Co0000oooo
oooooooo00001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`3Pooooo`008oooool01Ol0003ooooooooooooooooo
000000kooooo00?o8B4Qooooooooool01?ooool01?l0003oooooogMgMolb<S85ooooo`?o00001Ooo
ool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0h?oo
ool002?ooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<cooooo00?ooooo0ol0
00000olb<S;oc<c<ooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0<?oo
ool01?l0003oooooooooool0003Sooooo`008oooool01Ol@413ooooooooooooooooo410@00kooooo
00?oZJVYogMgMoooool00oooool2o`0000Sooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0`ooooo`Co0000hoooool002?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@
4?oooooooooooooooolb<S801?ooool2o`0000Sooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0booooo`;o0000i?ooool002?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go
00001?ooool4o`0000Kooooo0_l00005ooooo`03o`000?oooooooooo0?oooooo6Oooool003kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo
6Oooool003kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo0?oooooo6Oooool003kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo0?oooooo6Oooool003oooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo6_ooool003oooooo00?o0000oooooooo
ool01?ooool2o`0000Cooooo00?o0000ooooooooool0oooooolJooooo`00?oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0oooooolJooooo`00?ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0oooo
oolJooooo`00@?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0oooooolJooooo`00@?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0oooooolJooooo`00@?ooool00ol0003oooooooooo`03ooooo`;o
00000oooool00ol0003oooooooooo`3ooooooa_ooooo0010ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`3ooooooa_ooooo0011ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3ooooooa_ooooo0011
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3o
oooooa_ooooo0011ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00003o
oooooakooooo0012ooooo`04o`000?ooooooooooooooo`;o00000_ooool00ol0003oooooooooo`3o
oooooacooooo0012ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`3o
oooooagooooo000looooo`Co000000Co410@oooooooooooo00000_ooool01?l0003oooooooooool0
003ooooooaoooooo000nooooo`03o`000?oooooooooo00?ooooo00Go0000ooooool0003oooooo`00
003oooooob3ooooo000nooooo`03o`000?oooooooooo00?ooooo1?l0003oooooob7ooooo000noooo
o`03o`000?oooooooooo00Gooooo0ol0003oooooob3ooooo000nooooo`03o`000?oooooooooo0?oo
oooo:?ooool003kooooo00?o0000ooooooooool0oooooolXooooo`00?_ooool00ol0003ooooooooo
o`3oooooobSooooo000looooo`03oeEEEOmVIVKo00000?oooooo:_ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool004;ooooo0ol000000ol@413oooooooooo`3o
ooooob7ooooo0014ooooo`03oa0@4?nj^[[ooooo0?oooooo8_ooool004Cooooo00?oV9RHoc8b<_oo
ool0oooooolRooooo`00A?ooool00ooMgMgo0000okZj^P3oooooob;ooooo0014ooooo`03oeEEEOmg
MgOoA4A40?oooooo8_ooool004?ooooo00GogMgMoa0@4?oooooo8B4QomgMg@3oooooob7ooooo0013
ooooo`05ofIVI_n7QhOooooooiRHV?mEEED0oooooolQooooo`00@_ooool00oo^k^ko0000onk^kP02
ooooo`03o`000?oMgMgooooo0?oooooo7oooool004;ooooo00Co410@o`000?l0003ooooo0_l00000
0ol@413oooooooooo`3ooooooakooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-5.66973, -1.05832, 0.1009, \
0.0129571}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.18254 0.0396825 0.309017 0.309017 [
[.38095 .29652 -3 -9 ]
[.38095 .29652 3 0 ]
[.57937 .29652 -6 -9 ]
[.57937 .29652 6 0 ]
[.77778 .29652 -6 -9 ]
[.77778 .29652 6 0 ]
[.97619 .29652 -6 -9 ]
[.97619 .29652 6 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.17004 0 -12 -4.5 ]
[.17004 0 0 4.5 ]
[.17004 .07725 -30 -4.5 ]
[.17004 .07725 0 4.5 ]
[.17004 .15451 -24 -4.5 ]
[.17004 .15451 0 4.5 ]
[.17004 .23176 -30 -4.5 ]
[.17004 .23176 0 4.5 ]
[.17004 .38627 -24 -4.5 ]
[.17004 .38627 0 4.5 ]
[.17004 .46353 -18 -4.5 ]
[.17004 .46353 0 4.5 ]
[.17004 .54078 -24 -4.5 ]
[.17004 .54078 0 4.5 ]
[.17004 .61803 -6 -4.5 ]
[.17004 .61803 0 4.5 ]
[.18254 .64303 -5 0 ]
[.18254 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.38095 .30902 m
.38095 .31527 L
s
[(5)] .38095 .29652 0 1 Mshowa
.57937 .30902 m
.57937 .31527 L
s
[(10)] .57937 .29652 0 1 Mshowa
.77778 .30902 m
.77778 .31527 L
s
[(15)] .77778 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(20)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.22222 .30902 m
.22222 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30159 .30902 m
.30159 .31277 L
s
.34127 .30902 m
.34127 .31277 L
s
.42063 .30902 m
.42063 .31277 L
s
.46032 .30902 m
.46032 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.53968 .30902 m
.53968 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.65873 .30902 m
.65873 .31277 L
s
.69841 .30902 m
.69841 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.81746 .30902 m
.81746 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.89683 .30902 m
.89683 .31277 L
s
.93651 .30902 m
.93651 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.10317 .30902 m
.10317 .31277 L
s
.06349 .30902 m
.06349 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.18254 0 m
.18879 0 L
s
[(-1)] .17004 0 1 0 Mshowa
.18254 .07725 m
.18879 .07725 L
s
[(-0.75)] .17004 .07725 1 0 Mshowa
.18254 .15451 m
.18879 .15451 L
s
[(-0.5)] .17004 .15451 1 0 Mshowa
.18254 .23176 m
.18879 .23176 L
s
[(-0.25)] .17004 .23176 1 0 Mshowa
.18254 .38627 m
.18879 .38627 L
s
[(0.25)] .17004 .38627 1 0 Mshowa
.18254 .46353 m
.18879 .46353 L
s
[(0.5)] .17004 .46353 1 0 Mshowa
.18254 .54078 m
.18879 .54078 L
s
[(0.75)] .17004 .54078 1 0 Mshowa
.18254 .61803 m
.18879 .61803 L
s
[(1)] .17004 .61803 1 0 Mshowa
.125 Mabswid
.18254 .01545 m
.18629 .01545 L
s
.18254 .0309 m
.18629 .0309 L
s
.18254 .04635 m
.18629 .04635 L
s
.18254 .0618 m
.18629 .0618 L
s
.18254 .09271 m
.18629 .09271 L
s
.18254 .10816 m
.18629 .10816 L
s
.18254 .12361 m
.18629 .12361 L
s
.18254 .13906 m
.18629 .13906 L
s
.18254 .16996 m
.18629 .16996 L
s
.18254 .18541 m
.18629 .18541 L
s
.18254 .20086 m
.18629 .20086 L
s
.18254 .21631 m
.18629 .21631 L
s
.18254 .24721 m
.18629 .24721 L
s
.18254 .26266 m
.18629 .26266 L
s
.18254 .27812 m
.18629 .27812 L
s
.18254 .29357 m
.18629 .29357 L
s
.18254 .32447 m
.18629 .32447 L
s
.18254 .33992 m
.18629 .33992 L
s
.18254 .35537 m
.18629 .35537 L
s
.18254 .37082 m
.18629 .37082 L
s
.18254 .40172 m
.18629 .40172 L
s
.18254 .41717 m
.18629 .41717 L
s
.18254 .43262 m
.18629 .43262 L
s
.18254 .44807 m
.18629 .44807 L
s
.18254 .47898 m
.18629 .47898 L
s
.18254 .49443 m
.18629 .49443 L
s
.18254 .50988 m
.18629 .50988 L
s
.18254 .52533 m
.18629 .52533 L
s
.18254 .55623 m
.18629 .55623 L
s
.18254 .57168 m
.18629 .57168 L
s
.18254 .58713 m
.18629 .58713 L
s
.18254 .60258 m
.18629 .60258 L
s
.25 Mabswid
.18254 0 m
.18254 .61803 L
s
gsave
.18254 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .05615 m
.03279 .0196 L
s
.03279 .0196 m
.0388 0 L
s
.09412 0 m
.10458 .04319 L
.12493 .16094 L
.14349 .29349 L
.16419 .44297 L
.17329 .50043 L
.18333 .55263 L
.18795 .57159 L
.19292 .58796 L
.19521 .59396 L
.19761 .59919 L
.19967 .60275 L
.20192 .60566 L
.20325 .60689 L
.20451 .60771 L
.20564 .60816 L
.20686 .60834 L
.2075 .60831 L
.2082 .60818 L
.20893 .60792 L
.20961 .60758 L
.21083 .60672 L
.21215 .60543 L
.21337 .60389 L
.2147 .60184 L
.21712 .59713 L
.22166 .58486 L
.22699 .56487 L
.23201 .54082 L
.24137 .48358 L
.26236 .31576 L
.28078 .16474 L
.28582 .13 L
.29122 .0982 L
.29632 .07435 L
.29857 .06595 L
.30096 .05857 L
.30218 .05545 L
.30352 .0525 L
.30475 .05027 L
.30588 .04863 L
.30721 .04721 L
.30791 .04668 L
.30864 .04629 L
.30988 .04601 L
.31058 .04607 L
.31123 .04626 L
.3125 .04703 L
.31369 .04822 L
.31477 .04968 L
Mistroke
.31593 .05168 L
.31854 .05773 L
.32094 .06521 L
.32582 .08588 L
.33119 .11654 L
.34202 .19968 L
.36314 .39794 L
.36799 .43969 L
.37315 .47859 L
.37792 .50802 L
.38241 .52869 L
.38459 .53601 L
.38572 .53905 L
.38695 .54178 L
.38822 .54395 L
.38892 .54484 L
.38957 .54549 L
.39073 .54621 L
.39197 .54634 L
.39266 .54612 L
.39331 .54573 L
.39402 .54509 L
.39477 .54418 L
.39603 .5421 L
.39741 .53901 L
.39997 .53114 L
.40237 .52128 L
.40713 .49482 L
.41148 .46337 L
.42129 .37316 L
.43126 .26848 L
.43674 .21337 L
.44189 .16739 L
.44671 .1323 L
.44925 .11767 L
.45193 .10547 L
.45418 .09796 L
.45547 .09489 L
.45666 .09282 L
.45776 .0916 L
.45876 .09107 L
.45992 .09116 L
.46102 .09193 L
.46215 .09344 L
.46321 .0955 L
.46437 .09849 L
.46563 .10254 L
.46819 .11345 L
.47053 .12644 L
.47481 .1571 L
Mistroke
.47932 .19762 L
.48895 .30214 L
.49923 .41477 L
.50456 .46175 L
.50717 .47999 L
.50958 .49344 L
.51178 .50261 L
.51288 .50607 L
.5141 .50894 L
.51531 .51082 L
.51662 .5117 L
.51786 .51144 L
.51899 .51028 L
.52012 .50823 L
.52133 .50505 L
.52247 .50115 L
.5235 .49685 L
.52603 .48333 L
.52841 .46696 L
.53736 .37979 L
.54716 .26165 L
.55251 .20192 L
.55512 .17689 L
.55749 .15734 L
.55953 .14337 L
.56175 .13153 L
.56297 .1266 L
.5641 .12309 L
.56517 .12069 L
.56631 .11919 L
.56746 .11877 L
.56869 .11954 L
.56985 .12144 L
.57091 .12417 L
.57215 .12855 L
.57351 .13476 L
.57598 .1498 L
.58695 .26259 L
.59233 .33213 L
.59729 .39339 L
.60171 .4394 L
.60422 .45987 L
.60657 .47444 L
.6078 .48017 L
.60893 .48416 L
.61022 .48727 L
.61145 .48871 L
.61274 .48861 L
.61392 .48705 L
.61523 .48373 L
Mistroke
.61589 .48142 L
.61661 .47838 L
.61908 .46434 L
.62168 .44374 L
.62632 .39441 L
.63679 .25529 L
.64116 .20252 L
.64356 .17866 L
.64583 .16057 L
.64712 .15249 L
.6478 .14892 L
.64852 .14568 L
.64979 .14131 L
.65096 .13889 L
.65213 .13804 L
.65323 .13868 L
.65444 .141 L
.65573 .14535 L
.65642 .14843 L
.65707 .15181 L
.65827 .15933 L
.66098 .18162 L
.66586 .23733 L
.67161 .31785 L
.6769 .39037 L
.67933 .4188 L
.6816 .44082 L
.68396 .45811 L
.68521 .46464 L
.68592 .46745 L
.68656 .46946 L
.6872 .47096 L
.68789 .47195 L
.68913 .47216 L
.68981 .47141 L
.69045 .47013 L
.69116 .4681 L
.69192 .46518 L
.69321 .45852 L
.69457 .44929 L
.69699 .42749 L
.70201 .36529 L
.70656 .298 L
.71146 .22818 L
.71404 .19758 L
.71545 .18363 L
.71677 .17268 L
.71799 .16448 L
.71911 .15878 L
.72036 .15454 L
Mistroke
.72104 .15317 L
.72169 .15252 L
.72282 .15291 L
.72386 .15497 L
.72501 .15911 L
.72622 .16561 L
.72727 .17291 L
.72841 .18244 L
.73046 .20372 L
.73514 .26718 L
.73976 .33879 L
.74469 .40767 L
.74615 .42384 L
.74753 .4367 L
.74876 .44599 L
.7494 .44989 L
.75011 .45346 L
.75138 .45788 L
.75208 .45917 L
.75273 .45963 L
.7539 .45866 L
.75515 .45506 L
.75583 .45202 L
.75655 .44796 L
.75785 .43857 L
.7594 .42415 L
.7608 .4083 L
.76616 .33026 L
.77106 .25212 L
.77374 .21506 L
.77505 .19981 L
.77624 .18794 L
.77734 .17887 L
.77855 .1713 L
.77982 .16608 L
.78102 .16386 L
.78234 .16456 L
.78301 .16616 L
.78375 .1689 L
.78505 .17616 L
.78627 .18567 L
.78858 .21026 L
.79071 .23907 L
.79549 .31657 L
.79803 .35835 L
.80075 .39793 L
.80206 .41403 L
.80331 .42682 L
.80442 .43606 L
.80563 .44347 L
Mistroke
.80692 .44818 L
.80757 .44927 L
.80829 .44946 L
.80955 .44718 L
.81073 .44205 L
.81146 .43755 L
.81214 .43234 L
.81342 .42024 L
.81631 .38335 L
.82127 .30121 L
.82593 .22617 L
.82719 .20988 L
.82851 .19547 L
.8292 .18922 L
.82996 .18346 L
.83066 .17922 L
.8313 .17628 L
.83252 .17317 L
.83382 .17358 L
.83502 .17741 L
.83616 .18403 L
.83722 .19266 L
.83839 .20476 L
.84075 .23639 L
.84498 .30832 L
.84956 .38552 L
.85082 .40275 L
.85216 .41813 L
.85342 .42933 L
.85457 .43641 L
.85585 .44062 L
.85657 .44119 L
.85724 .44056 L
.85846 .43652 L
.85975 .42829 L
.86097 .41704 L
.86211 .40374 L
.86469 .36524 L
.86945 .27953 L
.87179 .23982 L
.87396 .20984 L
.87518 .19701 L
.87648 .18718 L
.87778 .18165 L
.87852 .18053 L
.87922 .18084 L
.88043 .1845 L
.88153 .19126 L
.88275 .20223 L
.88403 .21745 L
Mistroke
.88918 .30477 L
.89189 .35506 L
.89332 .37901 L
.89483 .40082 L
.89613 .41585 L
.89683 .42214 L
.89757 .4275 L
.89888 .43317 L
.90011 .43397 L
.90074 .43263 L
.90144 .42981 L
.90271 .42113 L
.90394 .40854 L
.90509 .39359 L
.9099 .30844 L
.91225 .26364 L
.91442 .22785 L
.91566 .2114 L
.91698 .19822 L
.9183 .18992 L
.91904 .18756 L
.91974 .18696 L
.92096 .1896 L
.92207 .19606 L
.92335 .20803 L
.92456 .22342 L
.9297 .3165 L
.93243 .36823 L
.93386 .39116 L
.93464 .40176 L
.93536 .4102 L
.93661 .42109 L
.93727 .42489 L
.93797 .42738 L
.93922 .42767 L
.94035 .42333 L
.94151 .41454 L
.94276 .40042 L
.94503 .36469 L
.95002 .26613 L
.95253 .22393 L
.95322 .21493 L
.95396 .2068 L
.95466 .2007 L
.9553 .19657 L
.95652 .19266 L
.95765 .19389 L
.95889 .20058 L
.96022 .21352 L
.96148 .23085 L
Mistroke
.96267 .25081 L
.96489 .29438 L
.96713 .34076 L
.96949 .38386 L
.97047 .398 L
.97151 .40997 L
.97266 .41882 L
.97372 .42268 L
.97501 .42144 L
.97619 .4147 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00??ooool4o`000003oa0@4?oooooooooo0?oooooo
9_ooool003kooooo00?o0000ooooooooool0oooooolXooooo`00<oooool6o`0000Gooooo00?o0000
ooooooooool0oooooolXooooo`006Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool01Oooool3o`000?oooooo8?ooool001Wooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0oooooolPooooo`006?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooob3ooooo000Hooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo8?ooool001Sooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0>
ooooo`03oeEEEOmVIVKo000000Oooooo00?o0000ooooooooool0oooooolPooooo`005oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo01Sooooo0_l0003oooooob7ooooo000Gooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`3oooooob3o
oooo000Gooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`3oooooob3ooooo000Gooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`3oooooob3ooooo000Fooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool05oooool2o`000?oooooo8Oooool001Kooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo0?oooooo8?ooool001Kooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo0?oooooo8?ooool001Gooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo0?oooooo
8?ooool001Gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo0?oooooo8?ooool001Gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0F
ooooo`;o00009Oooool2o`000?Wooooo000Eooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`0Sooooo`04o`000?ooooooooooo`000?Sooooo000Doooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Soooo
o`04o`000?ooooooooooo`000?Sooooo000Dooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`0Rooooo`05o`000?ooooooooooooooool00000n?ooool0
02kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0mOooool002kooooo00?o0000ooooooooool05Oooool2o`0002?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3eooooo`00;_ooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`3dooooo`008oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o8B4Qo`000?ooool0
1Oooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0m?ooool002?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q00?o0000ooooooooool00oooool00omEEEGo
ZJVYooooo`07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo0?Cooooo000Kooooo`Ko00000_ooool01Ol@413ooooo
oooooooooooo410@00Oooooo00?o0000ooooooooool00oooool00onYZJWoEEEEooooo`08ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0?Cooooo000Sooooo`05o`000?ooooooooooooooool000001oooool00ol0003o
ooooooooo`04ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool3o`00023o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3cooooo`008oooool01Ol0003ooooo
oooooooooooo000000Oooooo00?o0000ooooooooool01?ooool00omEEEGoc<c<ooooo`03ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0loooool002?ooooo00Go410@oooooooooooooooooa0@4007oooo
o`03o`000?oooooooooo00Cooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo023ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3coooo
o`008oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Sooooo00Co0000oooooooooooo410@0oooool0
0olb<S;oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo0??ooooo000Sooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02?ooool00ol0003oooooooooo`05o`0000Cooooo1?l00006ooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Wooooo`;o0000b_ooool0
033ooooo00?o0000ooooooooool04oooool2o`00023ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooo00000<[ooooo000`ooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02Go
oooo00Co0000ooooool0003o0000bOooool0033ooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool09Oooool01?l0003o
ooooooooool00039ooooo`00<Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Tooooo`05o`000?oooooooooooooo
ool00000bOooool0037ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool09?ooool01Ol0003ooooooooooooooooo0000
0<Wooooo000aooooo`03o`000?oooooooooo01;ooooo0_l0000Oooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0<Ko
oooo000aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`36ooooo`00<Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01kooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0a_ooool0037ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo01_ooooo0_l0002Yooooo`00<_ooool00ol0003oooooooooo`0Aoooo
o`;o00007_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02;ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo00000:Sooooo000booooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooo00000:Sooooo000booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo00000:Sooooo000booooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo023ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Iooooo`04o`000?oo
ooooooooo`000:Sooooo000booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Iooooo`05o`000?ooooooooooooooool00000Yoooool003?ooooo00?o
0000ooooooooool04?ooool2o`0001kooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06Oooool01Ol0003ooooooooo
oooooooo000001Oooooo0_l0002>ooooo`00<oooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo01Gooooo0_l0002>ooooo`00:oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00?ooooo00Co
0000oooooolQ8B7o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool04oooool00ol0003oooooo`00002>ooooo`00:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00?o
oooo00Co0000oooooolQ8B7o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
01?ooooo00Co0000oooooooooooo0000SOooool002?ooooo1_l00002ooooo`05oa0@4?oooooooooo
ooooool@41000oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool04oooool01?l0003oooooooooool0000Cooooo`03o`000?oooooooooo07Oooooo000[
ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`08ooooo`03ogMgMolb
<S;ooooo00Cooooo0ol0000Looooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0Cooooo`04o`000?ooooooooooo`0001?ooooo0_l0001hooooo`00:ooo
ool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool01Oooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo01kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool04_ooool01Ol0003ooooooooooooooooo0000
01;ooooo00?o0000ooooool00000N?ooool002_ooooo00Go410@oooooooooooooooooa0@4004oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Boooo
o`05o`000?ooooooooooooooool000004_ooool00ol0003oooooo`00001hooooo`00:oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo01;ooooo00Go0000ooooooooooooooooo`00000Booooo`03o`000?oo
oooo0000017ooooo00?o0000ooooooooool0I?ooool002_ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP04ooooo`03o`000?oooooooooo00Gooooo1?l00006ooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01;ooooo00Go
0000ooooooooooooooooo`00000Booooo`03o`000?oooooo0000013ooooo0_l0001Vooooo`00=?oo
ool00ol0003oooooooooo`0?ooooo`;o00007?ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00oooooo00Co0000oooooooooooo00003oooool2o`0006Kooooo000eooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00oooooo00Co0000oooooooooooo00003oooool00ol0003oooooo`00000>ooooo`03o`00
0?oooooooooo05Cooooo000eooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00oooooo00Co0000oooooooooooo0000
3_ooool01?l0003oooooooooool0000=ooooo`;o0000E_ooool003Gooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
3_ooool01Ol0003ooooooooooooooooo000000kooooo00Co0000oooooooooooo00003Oooool2o`00
00gooooo00?o0000ooooooooool0A_ooool003Gooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03_ooool01Ol0003o
oooooooooooooooo000000kooooo00Co0000oooooooooooo00003Oooool00ol0003oooooo`00000<
ooooo`;o0000Aoooool003Gooooo00?o0000ooooooooool03_ooool2o`0001_ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0>ooooo`05o`000?ooooooooooooooool000003_ooool0
1?l0003oooooooooool0000=ooooo`03o`000?oooooo000000_ooooo00?o0000ooooool000002ooo
ool00ol0003oooooooooo`0iooooo`00=Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0>ooooo`05o`000?oooooo
ooooooooool000003_ooool01?l0003oooooooooool0000=ooooo`03o`000?oooooo000000_ooooo
00?o0000ooooool000002_ooool2o`0003_ooooo000eooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00kooooo00Go
0000ooooooooooooooooo`00000>ooooo`04o`000?ooooooooooo`0000gooooo00?o0000ooooool0
00002oooool00ol0003oooooo`00000:ooooo`;o00002_ooool2o`0002oooooo000fooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0;ooooo`04o`00
0?ooooooooooo`0000cooooo00Co0000oooooooooooo00002oooool00ol0003oooooo`00000:oooo
o`03o`000?oooooo000000Wooooo0_l0000_ooooo`00=_ooool00ol0003oooooooooo`0=ooooo`;o
00006oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool000002oooool01?l0
003oooooooooool0000;ooooo`03o`000?oooooo000000[ooooo00?o0000ooooool000002Oooool2
o`0002oooooo000fooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0;ooooo`05o`000?ooooooooooooooool000002oooool01?l0003oooooooooool0
000;ooooo`03o`000?oooooo000000[ooooo00?o0000ooooool000002Oooool2o`0002oooooo000f
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0;
ooooo`05o`000?ooooooooooooooool000002oooool01?l0003oooooooooool0000;ooooo`03o`00
0?oooooo000000[ooooo00?o0000ooooool000002Oooool2o`0002oooooo000fooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool02Oooool01?l0003oooooooooool0000;ooooo`03o`00
0?oooooo000000[ooooo00?o0000ooooool000002Oooool00ol0003oooooo`00000^ooooo`00=_oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo00Co0000oooooooooooo0000
2oooool01?l0003oooooooooool00009ooooo`03o`000?oooooo000000Sooooo00Co0000oooooooo
oooo0000;_ooool003Kooooo00?o0000ooooooooool03Oooool2o`0001[ooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo00Co0000oooooooo
oooo00002oooool01?l0003oooooooooool00009ooooo`03o`000?oooooo000000Sooooo00Co0000
oooooooooooo0000;_ooool003Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09
ooooo`04o`000?ooooooooooo`0000_ooooo00Co0000oooooooooooo00002Oooool00ol0003ooooo
o`000008ooooo`04o`000?ooooooooooo`0002kooooo000gooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool02Oooool01?l0003oooooooooool0000;ooooo`04o`000?ooooooooooo`00
00Sooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0000^ooooo`008oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`00
0?lb<S;ogMgM00Gooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooooooo000000[o
oooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool00008ooooo`04o`000?oooooo
ooooo`0002kooooo000Sooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go
V9RHob4Q8Oo^k^koooooo`000007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
2?ooool01Ol0003ooooooooooooooooo000000Wooooo00Go0000ooooooooooooooooo`000008oooo
o`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000;_ooool001_ooooo1_l00002
ooooo`05oa0@4?ooooooooooooooool@41003?ooool01?nHV9So8B4Qonk^k_l00008ooooo`03o`00
0?oooooooooo00?ooooo0ol0000Iooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool000002Oooool01Ol0003o
oooooooooooooooo000000Sooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0
000^ooooo`008oooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Ol000001ooo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo00Go0000oooooooooooooooo
o`000009ooooo`05o`000?ooooooooooooooool000002?ooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0002kooooo000Sooooo`05o`000?ooooooooooooooool000003_ooool0
0omgMgOo0000ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`08ooooo`05o`000?ooooooooooooooool000002Oooool01Ol0003ooooooooooooooooo000000So
oooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0000^ooooo`008oooool01Ol@
413ooooooooooooooooo410@00oooooo0_l00003ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool02?ooool01Ol0003ooooooooooooooooo000000Wooooo00Go0000oooooooooooooooo
o`000008ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000;_ooool002?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`06o`000?nj^[[ooooooiRHV?l@413o00000ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo00Go0000oooooooooooooooo
o`000009ooooo`05o`000?ooooooooooooooool000002?ooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`0002kooooo000Sooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool0
1_nHV9So410@o`000?lQ8B7oc<c<o`0000?ooooo1?l00006ooooo`;o00006Oooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`000008ooooo`05
o`000?ooooooooooooooool000001_ooool01Ol0003ooooooooooooooooo000002kooooo000hoooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`000008ooooo`05o`000?oooooo
ooooooooool000001_ooool01Ol0003ooooooooooooooooo000002kooooo000hooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Oooooo00Go0000ooooooooooooooooo`000008ooooo`05o`000?ooooooooooooooool0
00001_ooool01Ol0003ooooooooooooooooo000002kooooo000hooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Ko
oooo00Go0000ooooooooooooooooo`000008ooooo`05o`000?ooooooooooooooool000001_ooool0
1Ol0003ooooooooooooooooo000002kooooo000hooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00Go0000
ooooooooooooooooo`000008ooooo`05o`000?ooooooooooooooool000001_ooool01Ol0003ooooo
oooooooooooo000002kooooo000iooooo`03o`000?oooooooooo00[ooooo0_l0000Iooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?oooooooooooooo
ool00000;_ooool003Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool01Oooool01Om4A4Co0000o`000?lb<S;ogMgM
00cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Aooooo`04o`000?oooooooooo
ooooo`Co000000Co410@ooooooooooook^k^0_l000000olb<S;ok^k^ooooo`0;ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo1?l000001Ol@413oooooooooooooooooA4A400;o000000?o<S8bomgMgOooool0
1_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooo`000004o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Tooooo`00>Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`08ooooo`03ogMgMolb<S;ooooo00_ooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01OmgMgOo
0000oooooonHV9SoMgMg00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool2o`0000Kooooo00?o0000ogMg
Molb<S801oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000001_ooool0
1ol0003ooooooiRHV?lQ8B7o0000oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg02Co
oooo000iooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?l0003oooooooooool@41002oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`;o
00001_ooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00Go0000oooooooo
ooooooooo`000006ooooo`06o`000?oooooooooooiRHV?l0003ok^k^1?ooool01Ol@413ooooooooo
oooooooo410@02Cooooo000iooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Sooooo00?oMgMgoc8b<_ooool02ooo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`02ooooo`;o00000_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Oooooo0_l00006ooooo`03o`000?mgMgOo<S8b00Oooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Ooo
ool01Ol0003ooooooooooooooooo000000Kooooo00Oo0000oooooooooooooooooiRHV?l0003ok^k^
00?ooooo00Go0000ooooooooooooooooo`00000Tooooo`00>Oooool00ol0003oooooooooo`0:oooo
o`;o00006?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Gooooo00Go0000ob4Q
8Ol0003o<S8bolc<c00<ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01oooool2o`0000Cooooo00Go0000ob4Q8Ol0003o0000olc<
c007ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ofIVI_ooool00_ooool01Ol0003ooooooooooooooooo000002Co
oooo000iooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?oooooo0000ooooool@41002oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`;o
00001?ooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo0_l00003ooooo`05oa0@4?oooooo
ooooooooool@41009?ooool003[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?l0003oV9RHogMgM`0;ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Oooooo0_l00004ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1Oooool01Ol0003ooooooooooooooooo000000Kooooo00Oo0000ooooool0003o^[Zjooooool0003o
410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Tooooo`00>_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`04
ooooo`Co00003?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool00_ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`04ooooo`04oeEEEOmVIVKo0000o`0000Cooooo1?l00007ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`04o`00
0?ooooooV9RHoa0@40;o000000Woc<c<ooooooooooooooooonk^k_lb<S;o0000oc8b<_o^k^h09?oo
ool003[ooooo00?o0000ooooooooool02Oooool2o`0001Sooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0[ooooo`00>_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0[ooooo`00>_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0Cooooo`;o00000_ooool2o`0001;ooooo000jooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01?ooooo
00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMdBooooo`00>_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Dooooo`04
omgMgOl0003o410@olc<c1?ooooo000=oooooooo0000>_l0000;ooooo`04onk^k_lQ8B7o410@onk^
kQ?ooooo000Dooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooo000000[ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool01Ol0003o
oooooooooooooooo000000Sooooo00?o0000ooooooooool02Oooool00ol0003oooooo`000009oooo
o`03o`000?oooooooooo00Kooooo00Go0000ooooooooooooooooo`00000;ooooo`03o`000?oooooo
000000[ooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000Oooooo
00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooo000000Wooooo00?o0000oooooooo
ool01_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool01?ooool2o`00
00Oooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`04o`000?oooooo
ooooo`0000?ooooo00?o0000ooooooooool00oooool00ol0003oooooo`000003ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000Booooo`04ob4Q8OmgMgOoMgMgoc8b<Q?o
oooo000kooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02?ooool01?l0003ooooo
ooooool0000<ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00Go0000ooooooooooooooooo`000004oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo
0000017ooooo0_l00002ooooo`;o00004_ooool003_ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:oooool003_o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0:_ooool003_ooooo00?o0000ooooooooool02?ooool2o`0001Oooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Zooooo`00>oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0Zooooo`00>oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0Zooooo`00??ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Zoooo
o`00??ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0Zooooo`00??ooool00ol0003oooooooooo`07ooooo`;o0000
5_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02[ooooo000looooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo02[ooooo000looooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo02[ooooo000looooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooooooo02[ooooo000looooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo02[ooooo000l
ooooo`03o`000?oooooooooo00Oooooo0_l0000Eooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0:_oo
ool003gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o
0000ooooooooool0:_ooool003gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooo
oooo000000Kooooo00?o0000ooooooooool0:_ooool003gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool0
1Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0:_ooool003gooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool000001ooo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0:_ooool003gooooo00?o
0000ooooooooool01_ooool2o`0001Gooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Kooooo00Go0000ooooooooooooooooo`000007ooooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooooooo`0Zooooo`00?Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Kooooo00Co0000oooooooooooo00002?ooool01Ol0003o
oooooooooooooooo000000Kooooo00?o0000ooooooooool0:_ooool002?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Kooooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooooooool0:_ooool002?ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ogMgMolb
<S801Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`06ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo02[ooooo000Sooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooo000000Gooooo0ol0000C
ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06
ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001oooool00ol0003ooooo
ooooo`0Zooooo`008oooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1_ooool00ol0003oMgMgoc8b<P05ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
7oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1oooool01Ol0003ooooooooooooooooo000000Wooooo00Co0000oooooooooooo00002?ooool01?l0
003oooooooooool00007ooooo`03o`000?oooooooooo02[ooooo000Sooooo`05o`000?oooooooooo
ooooool000003_ooool00omgMgOoIVIVooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Ooo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00Go0000oooooooooooooooo
o`000009ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001oooool00ol0
003oooooooooo`0Zooooo`008oooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000oooo
ooooool00_ooool00ol0003oooooo`000007ooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01oooool01Ol0003ooooooooooooooooo000000Wooooo00Co0000oooooooooooo00002?oo
ool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo02Wooooo000Sooooo`05ogMgMonH
V9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000ooooool0
00001oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00Go0000oooooooo
ooooooooo`000009ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooool000002?ooool0
0ol0003oooooooooo`0Yooooo`008oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c004ooooo`Co00001_ooool2o`0001?ooooo00?o0000ooooooooool08?oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01ooo
ool01Ol0003ooooooooooooooooo000000Wooooo00Co0000oooooooooooo00002Oooool00ol0003o
ooooo`000008ooooo`03o`000?oooooooooo02Wooooo000nooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo
00Go0000ooooooooooooooooo`00000:ooooo`05o`000?ooooooooooooooool000002Oooool01?l0
003oooooooooool00009ooooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool0:Oooool0
03oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
023ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo000000[ooooo00Go0000
ooooooooooooooooo`000009ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooool00000
2?ooool00ol0003oooooooooo`0Yooooo`00?oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`05o`000?oo
ooooooooooooool000002oooool01?l0003oooooooooool0000:ooooo`03o`000?oooooo000000Wo
oooo00?o0000ooooool000002?ooool00ol0003oooooooooo`0Yooooo`00?oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool08Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0:ooooo`05o`000?ooooooooooooooool000002oooool01?l0003oooooooooool0000:oooo
o`03o`000?oooooo000000Wooooo00?o0000ooooool000002?ooool00ol0003oooooo`00000Yoooo
o`00?oooool00ol0003oooooooooo`04ooooo`;o00004oooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool03Oooool01Ol0003ooooooooooooooooo0000
00cooooo00Go0000ooooooooooooooooo`00000;ooooo`04o`000?ooooooooooo`0000[ooooo00?o
0000ooooool000002Oooool00ol0003oooooo`000008ooooo`03o`000?oooooo000002Wooooo000o
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03Oooool01Ol0003ooooooooooooo
oooo000000cooooo00Go0000ooooooooooooooooo`00000;ooooo`04o`000?ooooooooooo`0000[o
oooo00?o0000ooooool000002Oooool2o`0000Wooooo0_l0000Zooooo`00?oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool08Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00gooooo00Go0000ooooooooooooooooo`00000=ooooo`04
o`000?ooooooooooo`0000_ooooo00?o0000ooooool000002oooool00ol0003oooooo`000009oooo
o`;o00002_ooool00ol0003oooooooooo`0Xooooo`00?oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00gooooo00Go0000ooooooooooooooooo`00000=ooooo`04o`000?oooooooooo
o`0000_ooooo00?o0000ooooool000002oooool2o`0000_ooooo00?o0000ooooooooool0<oooool0
03oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
013ooooo00Go0000ooooooooooooooooo`00000?ooooo`05o`000?ooooooooooooooool000003Ooo
ool00ol0003oooooo`00000<ooooo`03o`000?oooooo000000_ooooo0_l00011ooooo`00@?ooool0
0ol0003oooooooooo`03ooooo`;o00004_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0@ooooo`05o`000?oooooo
ooooooooool000003oooool01?l0003oooooooooool0000>ooooo`03o`000?oooooo000000cooooo
00?o0000ooooool000002oooool2o`00047ooooo0010ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0@ooooo`05o`000?ooooooooooooooool00000
3oooool01?l0003oooooooooool0000>ooooo`03o`000?oooooo000000gooooo0_l0001>ooooo`00
@?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
4?ooool01Ol0003ooooooooooooooooo000000oooooo00Co0000oooooooooooo00003_ooool00ol0
003oooooo`00000=ooooo`03o`000?oooooooooo04gooooo0010ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0@ooooo`05o`000?oooooooooooooo
ool000004?ooool00ol0003oooooo`00000>ooooo`03o`000?oooooo000005gooooo0010ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0@ooooo`05
o`000?ooooooooooooooool000004?ooool00ol0003oooooo`00000>ooooo`;o0000G_ooool0043o
oooo00?o0000ooooooooool00oooool2o`0001;ooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04?ooool01Ol0003o
oooooooooooooooo0000013ooooo00?o0000ooooool000003oooool00ol0003oooooooooo`1Loooo
o`00@?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool04?ooool01Ol0003ooooooooooooooooo0000013ooooo00?o0000ooooool00000K_ooool002_o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01_m4A4Co0000o`000?lb<S;o
gMgMo`0000Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Aooooo`04o`000?oo
ooooooooo`00017ooooo00?o0000ooooool00000K_ooool002_ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8bo`000004ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool04Oooool01?l0003oooooooooool0000Aooooo`;o0000Koooool002_ooooo
00Go410@oooooooooooooooooa0@400@ooooo`;o00001?ooool3o`00013ooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool04Oooool01?l0003oooooooooool00022ooooo`00:oooool01Ol0003ooooooooooooooooo0000
00oooooo00?oMgMgoc8b<_l000001?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooool00000P_ooool002_ooooo00Go0000ooooooooooooooooo`00000<oooo
o`06o`000?lQ8B7o0000oc8b<_o<c<co00001?ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool05Oooool01Ol0003ooooooooooooooooo000001Cooooo
00?o0000ooooool00000P_ooool002_ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool05Oooool01Ol0003ooooooooooooooooo000001Co
oooo0_l00023ooooo`00:oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooooooo
ool00oooool01Ol0003ooooooooooooooooo0000017ooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0Eooooo`04o`000?ooooooooooo`0009[ooooo000[ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03?ooool4o`0000;ooooo00Co0000oooooooooooooooo0_l0000@ooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool05_ooool01?l0003oooooooooool0002Jooooo`00@_oo
ool01Ol0003ooooooooooooooooo0000017ooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooo000009[ooooo0012ooooo`05o`000?ooooooooooooooool00000
4Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooool00000
V_ooool004;ooooo00Go0000ooooooooooooooooo`00000Aooooo`03o`000?oooooooooo02Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool05oooool2o`0009_ooooo0012ooooo`05o`000?ooooooooooooooool00000
4Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0;Cooooo0013ooooo`03o`000?oo
oooooooo00;o00004?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool07Oooool01Ol0003ooooooooooooooooo00000;Oooooo0013ooooo`04o`000?oo
ooooooooo`00013ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo01gooooo00Go0000ooooooooooooooooo`00002gooooo`00@oooool01?l0003ooooo
ooooool0000@ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Nooooo`04o`000?ooooooooooo`000;Oooooo0013ooooo`04o`000?ooooooooooo`00
013ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
01oooooo00Co0000oooooooooooo0000]oooool004?ooooo00Co0000oooooooooooo00004?ooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool07oooool0
0ol0003oooooo`00002hooooo`00@oooool00ol0003oooooooooo`02o`0000oooooo00?o0000oooo
ooooool0:Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01oooooo0ol0002hoooo
o`00A?ooool00ol0003oooooo`00000@ooooo`03o`000?oooooooooo02Wooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3Jooooo`00A?ooool00ol0003oooooo`00000?ooooo`03o`00
0?oooooooooo02[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3Kooooo`00A?oo
ool00ol0003oooooo`00000?ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`3Kooooo`00A?ooool00ol0003oooooo`00000?ooooo`03o`000?oooooo
oooo02_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3Kooooo`00A?ooool01?l0
003oooooo`000?l0000>ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`3Kooooo`00AOooool2o`0000oooooo00?o0000ooooooooool0:oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo0=_ooooo000Sooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;o
gMgM00Cooooo0_l0000?ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`3Kooooo`008oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46
ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool00oooool2o`0000kooooo00?o0000
ooooooooool0;Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0=_ooooo000Soooo
o`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooo
oooo00;ooooo0_l0000>ooooo`03o`000?oooooooooo02gooooo00Go0000ooooooooooooooooo`00
003Nooooo`008oooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_oo
ool00omgMgOo<S8booooo`03ooooo`Co00003?ooool00ol0003oooooooooo`0^ooooo`03o`000?oo
oooo00000=oooooo000Sooooo`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<oooo
o`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo02kooooo0ol0003Oooooo`008oooool01Ol@413ooooooooooooooooo410@00kooooo
00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool0oooooolAooooo`008oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo
00Go410@oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`3ooooooa7ooooo000Sooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02oooool5o`0000Cooooo1?l00006ooooo`;o00003?ooool00ol0003oooooooooo`3ooooooa;o
oooo0016ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0oooooolBooooo`00A_oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0?oooooo4_ooool004Kooooo0_l0000<
ooooo`03o`000?oooooooooo0?oooooo4_ooool004Kooooo0_l0000<ooooo`03o`000?oooooooooo
0?oooooo4_ooool004Kooooo0_l0000;ooooo`03o`000?oooooooooo0?oooooo4oooool004Kooooo
0_l0000;ooooo`03o`000?oooooooooo0?oooooo4oooool004Kooooo00?o0000ooooool000002_oo
ool00ol0003oooooooooo`3ooooooa?ooooo0016ooooo`03o`000?oooooo000000Wooooo00?o0000
ooooooooool0oooooolDooooo`00A_ooool00ol0003oooooo`000009ooooo`03o`000?oooooooooo
0?oooooo5?ooool004Kooooo0_l000000ooooooo0000ooooo`07ooooo`03o`000?oooooooooo0?oo
oooo5?ooool004Kooooo00Co0000oooooooooooo00002?ooool00ol0003oooooooooo`3ooooooaCo
oooo0016ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooaGo
oooo0016ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooaGo
oooo0016ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooaGo
oooo0016ooooo`;o00000oooool01?l0003oooooooooooooool2o`000?oooooo6?ooool004Kooooo
00?o0000ooooooooool00oooool4o`000?oooooo6Oooool003cooooo1?l000000ol@413ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo0_l0003ooooooa[ooooo000nooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0oooooolPooooo`00?_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo0?oooooo8?ooool003kooooo00?o0000ooooooooool01Oooool3o`000?oo
oooo8?ooool003kooooo00?o0000ooooooooool0oooooolXooooo`00?_ooool00ol0003ooooooooo
o`3oooooobSooooo000nooooo`03o`000?oooooooooo0?oooooo:?ooool003cooooo00?oEEEEofIV
I_l00000oooooolZooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00@_ooool3o`000003oa0@4?oooooooooo0?oooooo8Oooool004Cooooo00?o410@okZj^_oo
ool0oooooolRooooo`00A?ooool00onHV9So<S8booooo`3oooooob;ooooo0014ooooo`03omgMgOl0
003o^[Zj0?oooooo8_ooool004Cooooo00?oEEEEogMgMom4A4@0oooooolRooooo`00@oooool01OoM
gMgo410@oooooolQ8B7ogMgM0?oooooo8Oooool004?ooooo00GoIVIVohN7QoooooooV9RHoeEEE@3o
ooooob7ooooo0012ooooo`03onk^k_l0003ok^k^00;ooooo00?o0000omgMgOooool0oooooolOoooo
o`00@_ooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo0?oooooo7_ooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-5.66973, -1.05832, 0.1009, \
0.0129571}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.18254 0.0396825 0.309017 0.309017 [
[.38095 .29652 -3 -9 ]
[.38095 .29652 3 0 ]
[.57937 .29652 -6 -9 ]
[.57937 .29652 6 0 ]
[.77778 .29652 -6 -9 ]
[.77778 .29652 6 0 ]
[.97619 .29652 -6 -9 ]
[.97619 .29652 6 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.17004 0 -12 -4.5 ]
[.17004 0 0 4.5 ]
[.17004 .07725 -30 -4.5 ]
[.17004 .07725 0 4.5 ]
[.17004 .15451 -24 -4.5 ]
[.17004 .15451 0 4.5 ]
[.17004 .23176 -30 -4.5 ]
[.17004 .23176 0 4.5 ]
[.17004 .38627 -24 -4.5 ]
[.17004 .38627 0 4.5 ]
[.17004 .46353 -18 -4.5 ]
[.17004 .46353 0 4.5 ]
[.17004 .54078 -24 -4.5 ]
[.17004 .54078 0 4.5 ]
[.17004 .61803 -6 -4.5 ]
[.17004 .61803 0 4.5 ]
[.18254 .64303 -5 0 ]
[.18254 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.38095 .30902 m
.38095 .31527 L
s
[(5)] .38095 .29652 0 1 Mshowa
.57937 .30902 m
.57937 .31527 L
s
[(10)] .57937 .29652 0 1 Mshowa
.77778 .30902 m
.77778 .31527 L
s
[(15)] .77778 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(20)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.22222 .30902 m
.22222 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30159 .30902 m
.30159 .31277 L
s
.34127 .30902 m
.34127 .31277 L
s
.42063 .30902 m
.42063 .31277 L
s
.46032 .30902 m
.46032 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.53968 .30902 m
.53968 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.65873 .30902 m
.65873 .31277 L
s
.69841 .30902 m
.69841 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.81746 .30902 m
.81746 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.89683 .30902 m
.89683 .31277 L
s
.93651 .30902 m
.93651 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.10317 .30902 m
.10317 .31277 L
s
.06349 .30902 m
.06349 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.18254 0 m
.18879 0 L
s
[(-1)] .17004 0 1 0 Mshowa
.18254 .07725 m
.18879 .07725 L
s
[(-0.75)] .17004 .07725 1 0 Mshowa
.18254 .15451 m
.18879 .15451 L
s
[(-0.5)] .17004 .15451 1 0 Mshowa
.18254 .23176 m
.18879 .23176 L
s
[(-0.25)] .17004 .23176 1 0 Mshowa
.18254 .38627 m
.18879 .38627 L
s
[(0.25)] .17004 .38627 1 0 Mshowa
.18254 .46353 m
.18879 .46353 L
s
[(0.5)] .17004 .46353 1 0 Mshowa
.18254 .54078 m
.18879 .54078 L
s
[(0.75)] .17004 .54078 1 0 Mshowa
.18254 .61803 m
.18879 .61803 L
s
[(1)] .17004 .61803 1 0 Mshowa
.125 Mabswid
.18254 .01545 m
.18629 .01545 L
s
.18254 .0309 m
.18629 .0309 L
s
.18254 .04635 m
.18629 .04635 L
s
.18254 .0618 m
.18629 .0618 L
s
.18254 .09271 m
.18629 .09271 L
s
.18254 .10816 m
.18629 .10816 L
s
.18254 .12361 m
.18629 .12361 L
s
.18254 .13906 m
.18629 .13906 L
s
.18254 .16996 m
.18629 .16996 L
s
.18254 .18541 m
.18629 .18541 L
s
.18254 .20086 m
.18629 .20086 L
s
.18254 .21631 m
.18629 .21631 L
s
.18254 .24721 m
.18629 .24721 L
s
.18254 .26266 m
.18629 .26266 L
s
.18254 .27812 m
.18629 .27812 L
s
.18254 .29357 m
.18629 .29357 L
s
.18254 .32447 m
.18629 .32447 L
s
.18254 .33992 m
.18629 .33992 L
s
.18254 .35537 m
.18629 .35537 L
s
.18254 .37082 m
.18629 .37082 L
s
.18254 .40172 m
.18629 .40172 L
s
.18254 .41717 m
.18629 .41717 L
s
.18254 .43262 m
.18629 .43262 L
s
.18254 .44807 m
.18629 .44807 L
s
.18254 .47898 m
.18629 .47898 L
s
.18254 .49443 m
.18629 .49443 L
s
.18254 .50988 m
.18629 .50988 L
s
.18254 .52533 m
.18629 .52533 L
s
.18254 .55623 m
.18629 .55623 L
s
.18254 .57168 m
.18629 .57168 L
s
.18254 .58713 m
.18629 .58713 L
s
.18254 .60258 m
.18629 .60258 L
s
.25 Mabswid
.18254 0 m
.18254 .61803 L
s
gsave
.18254 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .26914 m
.04262 .15496 L
.06244 .05331 L
.07286 .01283 L
s
.07286 .01283 m
.07701 0 L
s
.12063 0 m
.12452 .01285 L
.13461 .05671 L
.14558 .11876 L
.16497 .25492 L
.18637 .41676 L
.19611 .48279 L
.20123 .51327 L
.20662 .54133 L
.21136 .56204 L
.21654 .57992 L
.21881 .58607 L
.22125 .59144 L
.22354 .59533 L
.22455 .59666 L
.22563 .59784 L
.22682 .59883 L
.22794 .59946 L
.22862 .59971 L
.22927 .59984 L
.23048 .59982 L
.23175 .59944 L
.23294 .59874 L
.23423 .59759 L
.23561 .59592 L
.2381 .59178 L
.24044 .58654 L
.24482 .57332 L
.25003 .55186 L
.25481 .52697 L
.26561 .45491 L
.28608 .28178 L
.29606 .19703 L
.30515 .1305 L
.30968 .10344 L
.31459 .07979 L
.31684 .07118 L
.31923 .0637 L
.32127 .05871 L
.32234 .05661 L
.32352 .05474 L
.32476 .05326 L
.32607 .05226 L
.32728 .05184 L
.3284 .05189 L
.32909 .05214 L
.32974 .05251 L
.33095 .05361 L
.33225 .05534 L
.33366 .05788 L
Mistroke
.33607 .06377 L
.33862 .07212 L
.34318 .09238 L
.34812 .12158 L
.35264 .15409 L
.36279 .24275 L
.38112 .4184 L
.38591 .458 L
.39101 .49344 L
.39537 .5169 L
.39785 .52705 L
.40018 .53429 L
.40139 .53715 L
.40271 .53954 L
.40338 .54045 L
.4041 .5412 L
.40538 .54198 L
.40667 .54201 L
.40789 .54133 L
.40898 .54015 L
.41016 .53825 L
.41145 .53544 L
.41288 .53146 L
.41576 .52064 L
.41843 .50739 L
.42093 .49232 L
.43132 .40629 L
.44119 .30315 L
.45091 .20296 L
.45515 .16564 L
.45972 .13257 L
.4623 .11801 L
.46466 .10751 L
.46693 .10025 L
.46807 .09766 L
.46932 .09567 L
.47 .09496 L
.47065 .09454 L
.47187 .0944 L
.47318 .09523 L
.47392 .09614 L
.47461 .09728 L
.47574 .09976 L
.477 .10338 L
.47954 .11346 L
.48193 .12617 L
.48411 .14044 L
.48903 .1808 L
.49793 .27481 L
.50709 .3797 L
Mistroke
.51212 .43094 L
.51687 .46996 L
.51957 .4868 L
.52099 .49389 L
.5225 .49998 L
.52376 .50393 L
.52443 .50557 L
.52515 .50699 L
.52642 .50859 L
.5276 .50905 L
.52888 .5084 L
.52961 .50751 L
.53028 .50635 L
.53151 .50337 L
.53282 .49901 L
.53532 .48735 L
.53758 .47319 L
.54776 .37497 L
.5585 .24418 L
.56293 .19579 L
.56767 .15468 L
.56907 .14529 L
.57039 .13772 L
.57168 .13164 L
.57287 .12721 L
.574 .12408 L
.57519 .12194 L
.57639 .12102 L
.57772 .12146 L
.57895 .12323 L
.57964 .12482 L
.58029 .12667 L
.58147 .13098 L
.58273 .13688 L
.58514 .15171 L
.58732 .16898 L
.59264 .22377 L
.59766 .28646 L
.60656 .39942 L
.609 .42563 L
.61162 .44953 L
.61409 .46724 L
.61518 .47339 L
.61634 .47872 L
.61759 .48301 L
.61874 .4856 L
.61998 .4869 L
.62069 .48693 L
.62135 .4865 L
.62254 .48458 L
Mistroke
.62363 .48154 L
.62483 .47682 L
.6261 .47031 L
.62865 .45258 L
.63102 .43104 L
.63641 .368 L
.64527 .24764 L
.64994 .19296 L
.65229 .1713 L
.65364 .16113 L
.65488 .15344 L
.65624 .14686 L
.65699 .14412 L
.6577 .14212 L
.65897 .14001 L
.65969 .13966 L
.66035 .13988 L
.66163 .14179 L
.66279 .1452 L
.66344 .14778 L
.66413 .1511 L
.66539 .15852 L
.66791 .1784 L
.67057 .20592 L
.67533 .26752 L
.68032 .33956 L
.68505 .40252 L
.68711 .42538 L
.6893 .44527 L
.69044 .45359 L
.6917 .46097 L
.69284 .46596 L
.69391 .46909 L
.69507 .47076 L
.6963 .47052 L
.69734 .4687 L
.69848 .46502 L
.69972 .45909 L
.70104 .45059 L
.70341 .43003 L
.70615 .39891 L
.70874 .36404 L
.71358 .29176 L
.71786 .23044 L
.7202 .20197 L
.72239 .18037 L
.72362 .17072 L
.72475 .16369 L
.726 .15801 L
.7267 .15587 L
Mistroke
.72735 .15451 L
.72849 .15369 L
.72954 .15472 L
.73069 .15781 L
.73192 .16332 L
.74149 .27062 L
.74672 .35212 L
.74927 .38873 L
.75158 .41715 L
.75261 .42777 L
.75372 .43769 L
.75468 .44483 L
.75574 .45103 L
.75687 .45562 L
.75806 .45816 L
.75916 .45835 L
.7602 .4566 L
.76141 .4522 L
.76257 .44571 L
.76361 .43804 L
.76474 .42779 L
.76963 .36515 L
.77444 .28777 L
.77898 .22009 L
.78149 .19155 L
.7829 .17956 L
.78421 .17151 L
.7853 .16709 L
.78651 .16485 L
.78777 .16549 L
.78894 .16883 L
.78961 .17192 L
.79034 .17622 L
.79167 .18649 L
.79416 .21343 L
.79975 .29919 L
.80224 .34115 L
.80493 .38306 L
.80725 .41319 L
.80856 .42674 L
.80979 .43663 L
.81094 .44335 L
.81218 .44755 L
.8135 .4485 L
.81469 .44617 L
.8158 .44131 L
.81701 .4332 L
.81814 .42298 L
.81919 .41153 L
.82423 .33595 L
Mistroke
.8268 .29112 L
.82957 .24525 L
.83095 .22491 L
.83227 .20808 L
.83355 .19451 L
.83474 .18475 L
.83586 .17825 L
.83705 .17442 L
.83773 .17371 L
.83837 .17402 L
.83957 .17719 L
.84021 .18023 L
.84091 .18462 L
.84233 .19671 L
.84364 .21145 L
.84486 .22787 L
.85058 .32496 L
.85302 .36699 L
.8556 .40451 L
.85695 .4196 L
.85767 .42609 L
.85844 .43179 L
.85915 .43579 L
.85979 .43839 L
.86106 .44044 L
.86232 .43843 L
.86349 .43298 L
.86477 .42318 L
.86614 .40865 L
.86868 .37246 L
.87098 .33246 L
.87557 .24967 L
.87682 .23003 L
.87815 .21213 L
.8793 .19955 L
.88053 .18947 L
.8817 .18352 L
.88275 .18126 L
.88382 .18211 L
.88483 .1858 L
.886 .19352 L
.88709 .20378 L
.88955 .23662 L
.89417 .32019 L
.8966 .36456 L
.89793 .38595 L
.89916 .40305 L
.90034 .41625 L
.90141 .42521 L
.9026 .43145 L
Mistroke
.90387 .43354 L
.90494 .43157 L
.90609 .42564 L
.90718 .41655 L
.90819 .40538 L
.91332 .31912 L
.91614 .26484 L
.91754 .24073 L
.91883 .22138 L
.92003 .20673 L
.92132 .19539 L
.92205 .19109 L
.92274 .18857 L
.92403 .18793 L
.92522 .1921 L
.92632 .19985 L
.92752 .2124 L
.92879 .22972 L
.9331 .30904 L
.93548 .35541 L
.93773 .39268 L
.939 .40877 L
.93972 .41585 L
.94038 .42099 L
.94155 .42654 L
.9428 .4273 L
.94396 .42318 L
.94505 .4152 L
.94625 .40217 L
.94753 .38374 L
.95278 .28252 L
.95416 .25592 L
.95564 .23102 L
.95636 .22075 L
.95703 .21235 L
.9583 .20048 L
.95948 .19434 L
.96056 .19316 L
.96175 .19687 L
.96301 .20635 L
.96428 .22121 L
.96547 .23927 L
.96817 .29078 L
.97619 .41913 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00??ooool4o`000003oa0@4?oooooooooo0?oooooo
9_ooool003kooooo00?o0000ooooooooool0oooooolXooooo`00<oooool6o`0000Gooooo00?o0000
ooooooooool0oooooolXooooo`009Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool01Oooool3o`000?oooooo8?ooool002Gooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0oooooolPooooo`009Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooob3ooooo000Tooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo8?ooool002Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`05
ooooo`03oeEEEOmVIVKo000000Oooooo00?o0000ooooooooool0oooooolPooooo`009?ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00oooooo0_l0003oooooob7ooooo000Sooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`3oooooob3o
oooo000Sooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`3oooooob3ooooo000Sooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`3oooooob3ooooo000Rooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool03_ooool2o`000?oooooo8Oooool002;ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo0?oooooo8?ooool002;ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo0?oooooo8?ooool0027ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo0?oooooo
8?ooool0027ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo0?oooooo8?ooool0027ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0=
ooooo`;o0000oooooolQooooo`008?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool0oooooolPooooo`008?ooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool0:Oooool3o`000??ooooo000Pooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Xooooo`;o0000
00?oooooo`000?ooool0l_ooool0023ooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo02Sooooo00Go0000ooooooooooooooooo`00003booooo`008?oo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00cooooo0_l0000Yooooo`05o`000?oo
ooooooooooooool00000l_ooool001oooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`3_ooooo`007oooool02Ol0003oooooooooooooooook^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1_ooool01?l0003ok^k^ooooool00003ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0koooool0
01oooooo00Wo0000ooooooooooooooooogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo
00CoEEEEojVYZOoooooo00001_ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3_ooooo`006oooool6o`0000;ooooo
00Go410@oooooooooooooooooa0@400=ooooo`04ojVYZOmEEEGoooooo`0000Oooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0koooool001oooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo
00cooooo00?o8B4Qooooool000001_ooool00omgMgOo<S8booooo`04ooooo`?o00009_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo0>oooooo000Nooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEEEOo<c<co000000?ooooo00Go0000ob4Q
8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`3^ooooo`007_ooool00ol0003oooooooooo`02ooooo`05oa0@4?oooooooooo
ooooool@41003_ooool00onYZJWoMgMgo`000003ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0>kooooo000Noooo
o`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`06oa0@4?oooooo
oooooooooolb<S;o00000oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3^ooooo`007_ooool00ol0003ooooooooo
o`02ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`000004ooooool0003oooooooooo`Co
00001_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0kOooool001kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0:ooooo`;o0000
9_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Cooooo0_l00037ooooo`007Ooo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooool00000a_oo
ool001gooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo
00000<Kooooo000Mooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool09?ooool01?l0
003oooooooooool00035ooooo`007Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
02?ooooo00Go0000ooooooooooooooooo`000035ooooo`007Oooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo00[ooooo0_l0000Uooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool08_ooool01Ol0003ooooooooooooooooo00000<Gooooo000Mooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool08_ooool01Ol0003ooooooooooooooooo00000<Gooooo000Loooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo0<?ooooo000Looooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0<?ooooo000Looooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool02Oooool2o`0002Cooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
6_ooool2o`000:Kooooo000Looooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooool00000YOoo
ool001cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo02?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool06_ooool00ol0003oooooo`00002Uooooo`006oooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool08oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0Iooooo`04o`000?ooooooooooo`000:Gooooo000Kooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
01Sooooo00Go0000ooooooooooooooooo`00002Tooooo`006oooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo00Sooooo0_l0000Tooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Sooooo00Go0000oooo
ooooooooooooo`00000Fooooo`;o0000S?ooool001_ooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06?ooool01Ol0
003ooooooooooooooooo000001Kooooo0_l0002<ooooo`006oooool00ol0003oooooooooo`0=oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Ko0000odA4A?l0003o0000oc8b
<_oMgMd5ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooool00000Roooool001[ooooo00?o
0000ooooooooool03_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`06o`00
0?oooooooooooooooomgMgOo<S8b1Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo0000
08_ooooo000Jooooo`03o`000?oooooooooo00Kooooo1_l00002ooooo`05oa0@4?oooooooooooooo
ool@41002oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool08_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool05?ooool00ol0003oooooo`00002;ooooo`006_ooool00ol0003oooooooooo`0>ooooo`05
o`000?ooooooooooooooool000003?ooool01Ol0003ooooooooooomgMgOo<S8b00Gooooo0ol0000R
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0C
ooooo`04o`000?ooooooooooo`0001?ooooo0_l0001fooooo`006_ooool00ol0003oooooooooo`0>
ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo
00?o0000ooooooooool08_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool04oooool01?l0003oooooooooool0000Booooo`03o`000?oooooo000007Ko
oooo000Jooooo`03o`000?oooooooooo00kooooo00Go410@oooooooooooooooooa0@400<ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool04oooool01?l0003oooooooooool0000Boooo
o`03o`000?oooooo000007Kooooo000Jooooo`03o`000?oooooooooo00kooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04_ooool01?l0
003oooooooooool0000Booooo`03o`000?oooooo0000013ooooo0_l0001Tooooo`006Oooool00ol0
003oooooooooo`0?ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Kooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool04Oooool01Ol0003ooooooooooooooooo000001;ooooo00?o0000ooooool000004?oo
ool2o`0006Cooooo000Iooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01oooool2
o`0002;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
0000013ooooo0_l0001Tooooo`006Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooool000004?ooool2o`0000kooooo00?o0000ooooooooool0Doooool001Wo
oooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0>ooooo`04o`000?ooooooooooo`00
00oooooo00?o0000ooooool000003_ooool2o`0005Cooooo000Iooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool03_ooool01?l0003oooooooooool0000?ooooo`03o`000?oooooo0000
00kooooo0_l0000<ooooo`03o`000?oooooooooo04Gooooo000Iooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool03_ooool01Ol0003ooooooooooooooooo000000kooooo00Co0000oooo
oooooooo00003?ooool00ol0003oooooo`00000<ooooo`;o0000A_ooool001Sooooo00?o0000oooo
ooooool08_ooool00ol0003oooooooooo`06ooooo`;o00008Oooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00kooooo00Go0000ooooooooooooooooo`00000>ooooo`04o`000?oooooo
ooooo`0000cooooo00?o0000ooooool000003?ooool2o`0000_ooooo00?o0000ooooooooool0>?oo
ool001Sooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0>ooooo`05o`000?oooooo
ooooooooool000003_ooool01?l0003oooooooooool0000<ooooo`03o`000?oooooo000000cooooo
0_l0000;ooooo`03o`000?oooooooooo03Sooooo000Hooooo`03o`000?oooooooooo02;ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool03Oooool01Ol0003ooooooooooooooooo000000kooooo00Co0000oooooooooooo
00003?ooool01?l0003oooooooooool0000;ooooo`;o00002oooool2o`0000Wooooo0_l0000^oooo
o`006?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool08?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00gooooo00Go0000oooooooo
ooooooooo`00000>ooooo`04o`000?ooooooooooo`0000cooooo00Co0000oooooooooooo00002_oo
ool00ol0003oooooo`00000:ooooo`03o`000?oooooo000000Wooooo0_l0000^ooooo`006?ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Gooooo0_l0000Qooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool03Oooool01Ol0003ooooooooooooooooo000000kooooo00Co
0000oooooooooooo00003?ooool01?l0003oooooooooool0000:ooooo`04o`000?ooooooooooo`00
00Wooooo00?o0000ooooool000002Oooool2o`0002kooooo000Hooooo`03o`000?oooooooooo02?o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool03Oooool01Ol0003ooooooooooooooooo000000kooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04o`000?ooooooooooo`0000[ooooo00Co0000oooooooooooo0000
2Oooool00ol0003oooooo`000009ooooo`;o0000;_ooool001Oooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0=ooooo`05o`000?ooooooooooooooool000003_ooool01Ol0003ooooo
oooooooooooo000000_ooooo00Co0000oooooooooooo00002_ooool01?l0003oooooooooool00009
ooooo`03o`000?oooooo000000Wooooo0_l0000^ooooo`005oooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00gooooo00Go0000ooooooooooooooooo`00000=ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool02Oooool01?l0003oooooooooool0000:ooooo`04o`000?oo
ooooooooo`0000Wooooo00?o0000ooooool000002Oooool2o`0002kooooo000Gooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool03Oooool01Ol0003ooooooooooooooooo000000gooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`04o`000?ooooooooooo`0000[o
oooo00Co0000oooooooooooo00002Oooool00ol0003oooooo`000009ooooo`;o0000;_ooool001Oo
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`05ooooo`;o00008?ooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00gooooo00Go0000ooooooooooooooooo`00000=oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool01?l0003oooooooooool0000:
ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooool000002Oooool00ol0003oooooo`00
000]ooooo`005oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool02?ooool01Ol0003ooooooooooooooooo000000[ooooo00Co0000oooooooooooo0000
2Oooool00ol0003oooooo`000008ooooo`04o`000?ooooooooooo`0002gooooo000Gooooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Oooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01oooool01?l0003oooooooooool00009ooooo`04
o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo0000;Oooool001Kooooo00?o0000oooo
ooooool02_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool0
1Om4A4Co0000o`000?l0003ogMgM00Gooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Kooooo00Go0000ooooooooooooooooo`000009ooooo`04o`00
0?ooooooooooo`0000Oooooo00Co0000oooooooooooo0000;Oooool001Kooooo00?o0000oooooooo
ool02_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@01oooool00ol0003o<S8booooo`04ooooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool000002Ooo
ool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0002gooooo000Fooooo`03o`00
0?oooooooooo00;ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP08ooooo`;o00001Oooool3o`0001oooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`06ooooo`05o`000?ooooooooooooooool000002Oooool01?l0003oooooooooool00007
ooooo`04o`000?ooooooooooo`0002gooooo000Fooooo`03o`000?oooooooooo00[ooooo00Go0000
ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000oc8b<_ooool01?oo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_oo
ool01Ol0003ooooooooooooooooo000000Sooooo00Go0000ooooooooooooooooo`000007ooooo`04
o`000?ooooooooooo`0002gooooo000Fooooo`03o`000?oooooooooo00[ooooo00Go0000oooooooo
ooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0003o0000olc<c005
ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06
ooooo`05o`000?ooooooooooooooool000002?ooool01Ol0003ooooooooooooooooo000000Oooooo
00Co0000oooooooooooo0000;Oooool001Kooooo00?o0000ooooooooool02_ooool01Ol@413ooooo
oooooooooooo410@00oooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00006oooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06oooo
o`05o`000?ooooooooooooooool000002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Co
0000oooooooooooo0000;Oooool001Gooooo00?o0000ooooooooool02oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`05o`000?oooooooooooooo
ool000001Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01_ooool01Ol0003ooooooooooooooooo000000Sooooo00Go0000ooooooooooooooooo`00
0007ooooo`04o`000?ooooooooooo`0002gooooo000Eooooo`03o`000?oooooooooo00_ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool5o`0000Go
oooo0_l0000Oooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool01Ol0003o
oooooooooooooooo000000Sooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?oooooo
ooooo`0002gooooo000Eooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool0
1Ol0003ooooooooooooooooo000000Sooooo00Go0000ooooooooooooooooo`000007ooooo`04o`00
0?ooooooooooo`0002gooooo000Eooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1_ooool01Ol0003ooooooooooooooooo000000Sooooo00Go0000ooooooooooooooooo`000007oooo
o`04o`000?ooooooooooo`0002gooooo000Eooooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01_ooool01Ol0003ooooooooooooooooo000000Sooooo00Go0000ooooooooooooooooo`00
0007ooooo`04o`000?ooooooooooo`0002gooooo000Eooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00Go
0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0002gooooo000Dooooo`03o`00
0?oooooooooo02Wooooo00?o0000ooooooooool00oooool2o`0001oooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1Oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000;Oooool001Co
oooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool05Oooool01?l0003ooooooooooom4A4@2o`000003oc8b<_oMgMgooooo
00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0@ooooo`Go000000So410@oooo
ooooooook^k^oc8b<_l0003o<S8bo`0000kooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool4o`000005oa0@
4?l0003ooooooooooom4A4@00_l000000olb<S;o0000ooooo`08ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Go
oooo00Go0000ooooooooooooooooo`000007ooooo`Go00000oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^02Cooooo000Dooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool00oooool00omg
MgOo<S8booooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool01Ol0
003ooooooooooooooooo000000Cooooo00GoMgMgoiRHV?ooooooV9RHo`00000=ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00Co0000oooooooooooo00001Oooool00omgMgOo0000ooooo`07ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`00
0?lQ8B7ok^k^ooooool000000oooool01OmgMgOoV9RHoooooonHV9SoMgMg02Cooooo0011ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00oooooo00Go0000ooooooooooooooooo`000004ooooo`05oa0@4?oooooooooo
ooooool000003Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Kooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool01_l0003ooooooiRHV?lQ8B7ok^k^o`0000?ooooo00Go410@oooooooo
oooooooooa0@400Tooooo`00@Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`03ooooo`03ogMgMolb<S;ooooo00oo
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`05o`000?oooooooooooooo
ool000001?ooool01Ol0003ooooooooooooooooo000000gooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
1?l0003oooooooooool00005ooooo`03ogMgMol0003ooooo00Oooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Ko0000ooooooooooooV9RH
ob4Q8Ol00003ooooo`05o`000?ooooooooooooooool000009?ooool0047ooooo00?o0000oooooooo
ool00_ooool2o`0001kooooo00?o0000ooooooooool05_ooool02?l0003oooooooooool0003o8B4Q
o`000?lb<S;oc<c<4?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00Go
0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000003Oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000ob4Q8Ol0003o<S8bo`000008
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`06o`000?oooooooooooooooomgMgOo00000oooool01Ol0003ooooooooooooooooo000002Co
oooo0011ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`0Fooooo`04o`000?ooooooooooo`0001Cooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0?ooooo`05o`000?ooooooooooooooool000001?ooool01Ol@413ooooooooooooooooo
000000gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00002ooooo`05o`000?oo
ooooooooooooool000002?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool@
41000oooool00ol@413oooooooooo`0Rooooo`00@Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo01gooooo00?o0000ooooooooool05_ooool01?l0003oooooooooool0000Dooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool01Ol0003ooooooooooooooooo0000
00Cooooo00GoMgMgoiRHV?ooooooV9RHo`00000=ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00Co0000
oooooooooooo00000_ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo0_l000001?nj^[[ooooo
oiRHV?l00003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL09?ooool0047ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01Oooooo00?o0000ooooool0
00000ol0000Aooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool01Ol0003o
oooooeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bo`00000=ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00?ooooo00?oEEEEofIVI_l000000_ooool00ol0003oooooooooo`05o`0000Sooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Ko0000
oiRHV?l@413o0000ob4Q8Ol00003ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h09?ooool004;ooooo
00Co0000oooooooooooooooo0_l0000Nooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0:_ooool004;ooooo00Go0000ooooooooooooooooo`00000Oooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0:_ooool004;ooooo00Go0000ooooooooooooooooo`00000Nooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool04_ooool2o`0000;ooooo0_l0000Booooo`00
@_ooool01Ol0003ooooooooooooooooo000001kooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0Booooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM4_ooool004;ooooo00Go0000oooo
ooooooooooooo`00000Nooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04oooool0
1?oMgMgo0000oa0@4?o<c<`Cooooo`003Oooooooo`0003[o00002oooool01?o^k^ko8B4Qoa0@4?o^
k^hCooooo`005?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool000002ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Kooooo00Go0000oooooooooooooooo
o`00000;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000008ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`05
o`000?ooooooooooooooool000001oooool00ol0003oooooo`000008ooooo`03o`000?oooooo0000
00Gooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00006ooooo`03o`000?oooooo
000000Cooooo00?o0000ooooooooool01?ooool2o`0000Cooooo00?o0000ooooooooool00oooool2
o`0000Cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0000Booooo`04ob4Q8Omg
MgOoMgMgoc8b<Q?ooooo0013ooooo`04o`000?ooooooooooo`0001kooooo00?o0000ooooooooool0
6?ooool01Ol0003ooooooooooooooooo0000017ooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooool000001Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00004Oooool2o`00
00;ooooo0_l0000Booooo`00@oooool01?l0003oooooooooool0000Nooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0:Oooool004?ooooo00Co0000oooooooooooo00007_ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo02Wooooo0013ooooo`03o`000?oooooooooo00;o
00007Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Wooooo0013ooooo`04o`00
0?ooooooooooo`0001gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Yooooo`00
@oooool01?l0003oooooooooool0000Mooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0:Oooool004?ooooo00Co0000oooooooooooo00007Oooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo02Wooooo0014ooooo`03o`000?oooooo000001gooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`0Yooooo`00A?ooool01?l0003oooooo`000?l0000Looooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooo
ooooool0:Oooool004Cooooo00?o0000ooooool000007Oooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo
02Wooooo0014ooooo`03o`000?oooooo000001gooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000007oooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0Yooooo`00A?ooool00ol0
003oooooo`00000Mooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`05ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooo
oooo000000Kooooo00?o0000ooooooooool0:Oooool004Cooooo00?o0000ooooool000007Oooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool0
1Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo02Wooooo0014ooooo`04o`000?oooooo0000o`0001_ooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00Go0000oooooooooooo
ooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0Yoooo
o`00A?ooool00ol0003oooooo`00000Looooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool000001oooool01Ol0
003ooooooooooooooooo000000Oooooo00?o0000ooooooooool0:?ooool004Gooooo0_l0000Loooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06oooo
o`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00?o
0000ooooooooool0:?ooool004Gooooo0_l0000Looooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool000001ooo
ool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool0:?ooool004Gooooo0_l0
000Looooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`06ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oo
oooo00?o0000ooooooooool0:?ooool004Gooooo0ol0000Kooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool0
00001oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool0:?ooool004Go
oooo0_l0000Looooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`06ooooo`05o`000?ooooooooooooooool000002?ooool01?l0003oooooooooool00007
ooooo`03o`000?oooooooooo02Sooooo000Sooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool2o`0001cooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00Go
0000ooooooooooooooooo`000008ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000oooooooo
ool0:?ooool002?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool00oooool2o`0001cooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00Go0000oooo
ooooooooooooo`000008ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool0:?oo
ool002?ooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o
0000ooooooooool00oooool3o`0001Wooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Kooooo00Co0000oooooooooooo00002Oooool01?l0003ooooo
ooooool00007ooooo`03o`000?oooooooooo02Sooooo000Sooooo`05o`000?ooooooooooooooool0
00003Oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool000002?ooool01?l0
003oooooooooool00009ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool0:?oo
ool002?ooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go
0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
2?ooool01?l0003oooooooooool00009ooooo`04o`000?ooooooooooo`0000Wooooo00Co0000oooo
oooooooo00001oooool00ol0003oooooooooo`0Xooooo`008oooool01Ol@413ooooooooooooooooo
410@00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?oooooo
ooooooooool000002oooool01?l0003oooooooooool00009ooooo`04o`000?ooooooooooo`0000Wo
oooo00?o0000ooooool000002?ooool00ol0003oooooooooo`0Xooooo`008oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Wooooo00Go0000ooooooooooooooooo`00000;ooooo`04o`000?ooooooooooo`0000Wooooo00Co
0000oooooooooooo00002Oooool00ol0003oooooo`000008ooooo`03o`000?oooooooooo02Sooooo
000Sooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Co
oooo1?l00006ooooo`;o00006_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[o
oooo00Co0000oooooooooooo00002oooool01?l0003oooooooooool00009ooooo`04o`000?oooooo
ooooo`0000Wooooo00?o0000ooooool000002Oooool00ol0003oooooooooo`0Wooooo`00A_ooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool0
1?l0003oooooooooool0000;ooooo`04o`000?ooooooooooo`0000Wooooo00Co0000oooooooooooo
00002Oooool00ol0003oooooo`000009ooooo`03o`000?oooooooooo02Oooooo0016ooooo`;o0000
6_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooo
00002oooool01?l0003oooooooooool00009ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000
ooooool000002Oooool00ol0003oooooooooo`0Wooooo`00A_ooool2o`0001[ooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0:ooooo`04o`000?ooooooooooo`0000_ooooo00Co0000
oooooooooooo00002Oooool01?l0003oooooooooool00009ooooo`03o`000?oooooo000000Wooooo
00?o0000ooooooooool09oooool004Kooooo0_l0000Iooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool00000
3Oooool01?l0003oooooooooool0000;ooooo`04o`000?ooooooooooo`0000[ooooo00?o0000oooo
ool000002Oooool00ol0003oooooo`000009ooooo`03o`000?oooooooooo02Oooooo0016ooooo`;o
00006Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool03?ooool01Ol0003ooooooooooooooooo000000gooooo00Co0000oooooooooooo00002oooool0
1?l0003oooooooooool0000:ooooo`03o`000?oooooo000000Wooooo00?o0000ooooool000002Ooo
ool00ol0003oooooooooo`0Wooooo`00A_ooool2o`0001Wooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo00Go0000ooooooooooooooooo`00
000=ooooo`04o`000?ooooooooooo`0000_ooooo00Co0000oooooooooooo00002_ooool00ol0003o
ooooo`000009ooooo`;o00002_ooool00ol0003oooooooooo`0Wooooo`00A_ooool2o`0001Wooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00gooooo
00Co0000oooooooooooo00003Oooool01?l0003oooooooooool0000;ooooo`04o`000?oooooooooo
o`0000[ooooo00?o0000ooooool000002Oooool2o`0003Cooooo0016ooooo`;o00006Oooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03Oooool01?l0
003oooooooooool0000=ooooo`04o`000?ooooooooooo`0000cooooo00?o0000ooooool000002_oo
ool00ol0003oooooo`00000:ooooo`03o`000?oooooooooo03;ooooo0016ooooo`03o`000?oooooo
000001Sooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00gooooo00Co0000oooooooooooo00003Oooool01?l0003oooooooooool0000<ooooo`;o0000
3?ooool00ol0003oooooooooo`0nooooo`00A_ooool3o`0001Sooooo00?o0000ooooooooool08?oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00gooooo00Co0000oooooooooooo0000
3_ooool00ol0003oooooo`00000<ooooo`;o00003?ooool00ol0003oooooooooo`0nooooo`00A_oo
ool00ol0003oooooo`00000Hooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0=ooooo`04o`000?ooooooooooo`0000kooooo00?o0000ooooool00000
3?ooool2o`0004gooooo0016ooooo`03o`000?oooooo000001Sooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03ooo
ool01Ol0003ooooooooooooooooo000000oooooo00Co0000oooooooooooo00003_ooool2o`0000go
oooo0_l0001=ooooo`00A_ooool00ol0003oooooo`00000Gooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo013ooooo
00Go0000ooooooooooooooooo`00000?ooooo`04o`000?ooooooooooo`0000kooooo0_l0001Loooo
o`00A_ooool00ol0003oooooo`00000Gooooo`03o`000?oooooooooo02;ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo013ooooo00Go0000oooooooo
ooooooooo`00000?ooooo`04o`000?ooooooooooo`0000kooooo0_l0001Looooo`00A_ooool3o`00
01Oooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool04?ooool01Ol0003ooooooooooooooooo000000oooooo00Co0000
oooooooooooo00003oooool00ol0003oooooooooo`1Jooooo`00A_ooool01?l0003oooooooooool0
000Fooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo013ooooo00Go0000ooooooooooooooooo`00000@ooooo`;o0000
KOooool002_ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000
o`000?lb<S;ogMgM00Gooooo00Co0000oooooooooooo00005_ooool00ol0003oooooooooo`0Roooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0@oooo
o`04o`000?ooooooooooo`00017ooooo0_l0001]ooooo`00:oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00Co0000oooooooooooo00005_oo
ool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooo0000017ooooo0_l0001]ooooo`00:oooool0
1Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool4o`0001Kooooo00?o
0000ooooooooool08_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool04Oooool00ol0003oooooo`000020ooooo`00:oooool01Ol0003ooooooooooooo
oooo000000oooooo00?oMgMgoc8b<_ooool01?ooool01?l0003oooooooooool0000Fooooo`03o`00
0?oooooooooo02;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool05?ooool01Ol0003ooooooooooooooooo000001Co
oooo00?o0000ooooool00000P?ooool002_ooooo00Go0000ooooooooooooooooo`00000<ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`01Oooool01?l0003oooooooooool0000Eooooo`03o`000?oooooo
oooo02?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool05?ooool01Ol0003ooooooooooooooooo000001Cooooo0_l0
0021ooooo`00:oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01ooo
ool01?l0003oooooooooool0000Eooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
5?ooool01Ol0003ooooooooooooooooo000001Gooooo00?o0000ooooooooool0Ooooool002_ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00Go0000oooooooo
ooooooooo`00000Dooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05Oooool01?l0
003oooooooooool0002Gooooo`00:oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00006
ooooo`;o00000_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool05Oooool01?l0003oooooooooool0002Gooooo`00A_ooool01Ol0003ooooooooooooo
oooo000001Cooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooo000009Sooooo0016ooooo`05o`000?ooooooooooooooool000004oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo01Oooooo0_l0002Hooooo`00A_ooool01Ol0003ooooooooooooo
oooo000001?ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Gooooo`;o0000V?oo
ool004Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0/Oooool004Kooooo0_l00003ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2aooooo`00A_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo01cooooo00Go0000ooooooooooooooooo`00002doooo
o`00A_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01kooooo00Co0000oooooooo
oooo0000]?ooool004Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Nooooo`04
o`000?ooooooooooo`000;Cooooo0016ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool07_ooool3o`000;Gooooo0016ooooo`;o00001?ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo02Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Oooooo`03o`00
0?oooooooooo0;Cooooo0016ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0e_oo
ool004Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo02Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3Fooooo`00A_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo0=Kooooo0016ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0e_ooool004Kooooo0_l00004ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool0:_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0=Kooooo
0016ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0Zooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0eoooool002?ooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0
003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool0:oooool01Ol0003ooooooooooooooooo00000=Wooooo000Sooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo
<S8booooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0[ooooo`04o`000?ooooooooooo`000=[ooooo000Sooooo`05oa0@4?oooooooooooooo
ool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02_ooooo1?l0003Joooo
o`008oooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool01_ooool00omg
MgOo<S8booooo`04ooooo`?o00001?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
02gooooo0_l0003Kooooo`008oooool01Ol0003ooooooooooooooooo000000kooooo00?oEEEEolc<
c?ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0?oooooo2oooool002?ooooo00Go410@oooo
oooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0ooooool;
ooooo`008oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go410@oooooooooooooooooc8b
<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo0?oooooo2oooool002?ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`Go00001?ooool4o`0000Kooooo0_l00006ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool0ooooool;ooooo`00A_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool0ooooool;ooooo`00A_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0ooooool<ooooo`00A_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0ooooool<ooooo`00
A_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
ooooool<ooooo`00A_ooool2o`0000Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`3oooooo`gooooo0016ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`3oooooo`gooooo0016ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`3oooooo`gooooo0016ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooo`gooooo0016ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3oooooo`kooooo
0016ooooo`;o00002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo3_oo
ool004Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo0?oooooo3oooool004Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo0?oooooo3oooool004Kooooo00?o0000ooooooooool02_ooool01?l0003o
ooooooooool0003ooooooa;ooooo0016ooooo`03o`000?oooooooooo00_ooooo0_l0003ooooooa?o
oooo0016ooooo`;o0000oooooolQooooo`00A_ooool00ol0003oooooooooo`3oooooob3ooooo000l
ooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`3oooooob3ooooo000noooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooolPooooo`00?_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo0?oooooo8?ooool003kooooo00?o0000ooooooooool0
1Oooool3o`000?oooooo8?ooool003kooooo00?o0000ooooooooool0oooooolXooooo`00?_ooool0
0ol0003oooooooooo`3oooooobSooooo000nooooo`03o`000?oooooooooo0?oooooo:?ooool003co
oooo00?oEEEEofIVI_l00000oooooolZooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00@_ooool3o`000003oa0@4?oooooooooo0?oooooo8Oooool004Cooooo
00?o410@okZj^_ooool0oooooolRooooo`00A?ooool00onHV9So<S8booooo`3oooooob;ooooo0014
ooooo`03omgMgOl0003o^[Zj0?oooooo8_ooool004Cooooo00?oEEEEogMgMom4A4@0oooooolRoooo
o`00@oooool01OoMgMgo410@oooooolQ8B7ogMgM0?oooooo8Oooool004?ooooo00GoIVIVohN7Qooo
ooooV9RHoeEEE@3oooooob7ooooo0012ooooo`03onk^k_l0003ok^k^00;ooooo00?o0000omgMgOoo
ool0oooooolOooooo`00@_ooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo0?oo
oooo7_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-5.66973, -1.05832, 0.1009, \
0.0129571}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.18254 0.0396825 0.309017 0.309017 [
[.38095 .29652 -3 -9 ]
[.38095 .29652 3 0 ]
[.57937 .29652 -6 -9 ]
[.57937 .29652 6 0 ]
[.77778 .29652 -6 -9 ]
[.77778 .29652 6 0 ]
[.97619 .29652 -6 -9 ]
[.97619 .29652 6 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.17004 0 -12 -4.5 ]
[.17004 0 0 4.5 ]
[.17004 .07725 -30 -4.5 ]
[.17004 .07725 0 4.5 ]
[.17004 .15451 -24 -4.5 ]
[.17004 .15451 0 4.5 ]
[.17004 .23176 -30 -4.5 ]
[.17004 .23176 0 4.5 ]
[.17004 .38627 -24 -4.5 ]
[.17004 .38627 0 4.5 ]
[.17004 .46353 -18 -4.5 ]
[.17004 .46353 0 4.5 ]
[.17004 .54078 -24 -4.5 ]
[.17004 .54078 0 4.5 ]
[.17004 .61803 -6 -4.5 ]
[.17004 .61803 0 4.5 ]
[.18254 .64303 -5 0 ]
[.18254 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.38095 .30902 m
.38095 .31527 L
s
[(5)] .38095 .29652 0 1 Mshowa
.57937 .30902 m
.57937 .31527 L
s
[(10)] .57937 .29652 0 1 Mshowa
.77778 .30902 m
.77778 .31527 L
s
[(15)] .77778 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(20)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.22222 .30902 m
.22222 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30159 .30902 m
.30159 .31277 L
s
.34127 .30902 m
.34127 .31277 L
s
.42063 .30902 m
.42063 .31277 L
s
.46032 .30902 m
.46032 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.53968 .30902 m
.53968 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.65873 .30902 m
.65873 .31277 L
s
.69841 .30902 m
.69841 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.81746 .30902 m
.81746 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.89683 .30902 m
.89683 .31277 L
s
.93651 .30902 m
.93651 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.10317 .30902 m
.10317 .31277 L
s
.06349 .30902 m
.06349 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.18254 0 m
.18879 0 L
s
[(-1)] .17004 0 1 0 Mshowa
.18254 .07725 m
.18879 .07725 L
s
[(-0.75)] .17004 .07725 1 0 Mshowa
.18254 .15451 m
.18879 .15451 L
s
[(-0.5)] .17004 .15451 1 0 Mshowa
.18254 .23176 m
.18879 .23176 L
s
[(-0.25)] .17004 .23176 1 0 Mshowa
.18254 .38627 m
.18879 .38627 L
s
[(0.25)] .17004 .38627 1 0 Mshowa
.18254 .46353 m
.18879 .46353 L
s
[(0.5)] .17004 .46353 1 0 Mshowa
.18254 .54078 m
.18879 .54078 L
s
[(0.75)] .17004 .54078 1 0 Mshowa
.18254 .61803 m
.18879 .61803 L
s
[(1)] .17004 .61803 1 0 Mshowa
.125 Mabswid
.18254 .01545 m
.18629 .01545 L
s
.18254 .0309 m
.18629 .0309 L
s
.18254 .04635 m
.18629 .04635 L
s
.18254 .0618 m
.18629 .0618 L
s
.18254 .09271 m
.18629 .09271 L
s
.18254 .10816 m
.18629 .10816 L
s
.18254 .12361 m
.18629 .12361 L
s
.18254 .13906 m
.18629 .13906 L
s
.18254 .16996 m
.18629 .16996 L
s
.18254 .18541 m
.18629 .18541 L
s
.18254 .20086 m
.18629 .20086 L
s
.18254 .21631 m
.18629 .21631 L
s
.18254 .24721 m
.18629 .24721 L
s
.18254 .26266 m
.18629 .26266 L
s
.18254 .27812 m
.18629 .27812 L
s
.18254 .29357 m
.18629 .29357 L
s
.18254 .32447 m
.18629 .32447 L
s
.18254 .33992 m
.18629 .33992 L
s
.18254 .35537 m
.18629 .35537 L
s
.18254 .37082 m
.18629 .37082 L
s
.18254 .40172 m
.18629 .40172 L
s
.18254 .41717 m
.18629 .41717 L
s
.18254 .43262 m
.18629 .43262 L
s
.18254 .44807 m
.18629 .44807 L
s
.18254 .47898 m
.18629 .47898 L
s
.18254 .49443 m
.18629 .49443 L
s
.18254 .50988 m
.18629 .50988 L
s
.18254 .52533 m
.18629 .52533 L
s
.18254 .55623 m
.18629 .55623 L
s
.18254 .57168 m
.18629 .57168 L
s
.18254 .58713 m
.18629 .58713 L
s
.18254 .60258 m
.18629 .60258 L
s
.25 Mabswid
.18254 0 m
.18254 .61803 L
s
gsave
.18254 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .49736 m
.06244 .25068 L
.08255 .12669 L
.0932 .07118 L
.09905 .04509 L
.10458 .02388 L
.10972 .00748 L
.11243 .00023 L
s
.11243 .00023 m
.11254 0 L
s
.14504 0 m
.14916 .01176 L
.1546 .03184 L
.1645 .07971 L
.18306 .20193 L
.20245 .35321 L
.21274 .43128 L
.22384 .50457 L
.22899 .53263 L
.23441 .55704 L
.23903 .57317 L
.24166 .58022 L
.2441 .58536 L
.24528 .58735 L
.24657 .58912 L
.24779 .59041 L
.24891 .59128 L
.24992 .5918 L
.25104 .59207 L
.2522 .59202 L
.25329 .59165 L
.25456 .59085 L
.25576 .5897 L
.25684 .58835 L
.25802 .58654 L
.26066 .58119 L
.26311 .57463 L
.2682 .55617 L
.2737 .52922 L
.28367 .464 L
.30229 .30538 L
.31175 .22147 L
.32188 .14243 L
.32769 .10621 L
.33299 .08103 L
.33554 .07192 L
.33688 .06796 L
.33831 .06442 L
.33956 .0619 L
.34093 .05974 L
.34218 .05835 L
.34335 .05755 L
.34455 .05724 L
.34566 .05741 L
.34689 .05813 L
.34819 .05949 L
.34885 .06042 L
.34957 .0616 L
.35086 .06422 L
.35329 .07074 L
Mistroke
.35559 .07889 L
.35802 .08952 L
.36239 .11349 L
.37215 .18711 L
.38289 .28918 L
.39289 .38813 L
.40237 .46889 L
.40761 .50257 L
.41056 .51711 L
.41198 .52278 L
.4133 .52733 L
.4145 .53076 L
.4156 .53334 L
.41682 .53556 L
.41814 .53716 L
.41933 .53791 L
.42064 .53794 L
.4213 .53764 L
.42201 .53709 L
.42328 .53549 L
.42451 .5332 L
.42586 .52984 L
.4286 .52038 L
.43113 .50853 L
.4335 .49485 L
.43885 .45569 L
.4446 .40294 L
.45505 .29154 L
.46474 .19191 L
.46964 .15105 L
.47215 .1339 L
.47486 .11876 L
.47641 .1118 L
.47784 .10657 L
.4792 .10266 L
.4799 .10108 L
.48065 .09971 L
.48194 .09812 L
.48315 .09754 L
.48389 .09763 L
.48458 .09802 L
.48589 .09956 L
.48705 .10179 L
.48832 .10519 L
.48965 .10978 L
.49089 .11504 L
.49552 .14227 L
.50056 .18427 L
.50599 .24048 L
.51638 .36111 L
Mistroke
.52144 .41569 L
.52604 .45712 L
.52838 .4741 L
.53092 .48879 L
.53231 .49508 L
.5336 .49969 L
.53483 .50301 L
.53612 .50532 L
.53743 .50639 L
.53817 .50643 L
.53884 .50611 L
.54014 .50453 L
.54138 .50184 L
.54207 .49983 L
.54281 .4973 L
.54414 .49174 L
.54715 .47453 L
.54977 .45469 L
.55253 .42941 L
.55747 .37538 L
.56861 .23835 L
.57327 .18833 L
.57583 .16556 L
.57825 .148 L
.57962 .13996 L
.58111 .13293 L
.58176 .13041 L
.58246 .12814 L
.58371 .12511 L
.58496 .12346 L
.58613 .12318 L
.58742 .1243 L
.58814 .12559 L
.5888 .12717 L
.59009 .13137 L
.5913 .13666 L
.59356 .14989 L
.596 .16872 L
.59864 .19385 L
.60778 .30607 L
.61254 .36837 L
.61765 .42672 L
.62059 .45288 L
.62326 .47057 L
.62455 .47672 L
.62523 .4793 L
.62595 .48155 L
.62658 .48306 L
.62727 .48427 L
.6285 .48515 L
Mistroke
.62975 .48441 L
.63039 .48341 L
.63108 .48183 L
.6323 .47779 L
.63344 .47264 L
.63602 .45623 L
.63878 .432 L
.64383 .37321 L
.64843 .31041 L
.65362 .23968 L
.65636 .20673 L
.65926 .17763 L
.66179 .15845 L
.66323 .15056 L
.66392 .14759 L
.66458 .14529 L
.66582 .14235 L
.66695 .14127 L
.66816 .14185 L
.66885 .14298 L
.66949 .14455 L
.67078 .14922 L
.67143 .15233 L
.67214 .1563 L
.67458 .17418 L
.67742 .20264 L
.68008 .23515 L
.68529 .30895 L
.69004 .37655 L
.69226 .40454 L
.69466 .43054 L
.69576 .44056 L
.69693 .44972 L
.69803 .45682 L
.69903 .462 L
.70017 .46627 L
.70139 .46891 L
.70247 .46951 L
.70361 .46839 L
.70486 .46506 L
.70602 .46004 L
.7073 .45245 L
.70866 .44206 L
.71125 .41625 L
.714 .38186 L
.71892 .3094 L
.72169 .26748 L
.72467 .22598 L
.72742 .1938 L
.72878 .18099 L
Mistroke
.73004 .17121 L
.7312 .16409 L
.73244 .15869 L
.73368 .15562 L
.73439 .15495 L
.73506 .15505 L
.73621 .15686 L
.73726 .16035 L
.73842 .16616 L
.73964 .17445 L
.74225 .19904 L
.74468 .22911 L
.7502 .31272 L
.75523 .38858 L
.75807 .42267 L
.75943 .43539 L
.7607 .44487 L
.7618 .45105 L
.76299 .45542 L
.76431 .4574 L
.76551 .45653 L
.76676 .45292 L
.76747 .44966 L
.76813 .44587 L
.76934 .43708 L
.77062 .42523 L
.77303 .39682 L
.77564 .35907 L
.78036 .28224 L
.78463 .21888 L
.78585 .204 L
.78702 .19183 L
.78807 .18261 L
.7892 .17489 L
.79042 .16907 L
.79155 .16621 L
.79277 .16594 L
.79346 .16708 L
.79412 .16901 L
.79527 .17444 L
.79632 .1816 L
.79748 .19175 L
.79871 .20483 L
.80369 .27745 L
.80914 .36832 L
.81186 .4063 L
.81319 .42123 L
.81442 .43232 L
.81509 .43721 L
.81584 .44155 L
Mistroke
.81658 .44478 L
.81737 .44692 L
.81804 .44768 L
.81876 .44743 L
.82006 .44413 L
.82136 .43723 L
.82209 .43178 L
.82278 .42578 L
.82536 .39564 L
.83021 .31731 L
.8353 .23233 L
.8367 .21343 L
.83817 .19697 L
.83943 .1862 L
.84014 .18158 L
.84081 .17828 L
.8421 .17479 L
.84333 .17514 L
.84443 .17848 L
.84562 .18529 L
.84692 .19629 L
.8483 .21171 L
.85078 .24738 L
.85504 .32236 L
.8574 .36344 L
.85963 .39728 L
.86089 .41276 L
.86156 .41969 L
.86227 .42603 L
.86351 .43438 L
.86467 .43871 L
.86595 .43949 L
.86715 .43638 L
.86823 .43045 L
.8694 .42084 L
.87437 .3501 L
.8771 .29974 L
.8797 .25323 L
.88211 .21699 L
.88347 .20132 L
.88473 .19064 L
.88578 .18484 L
.88695 .18198 L
.88817 .18307 L
.88932 .18788 L
.89054 .19695 L
.89184 .2106 L
.89415 .24383 L
.89935 .34004 L
.9019 .38375 L
Mistroke
.90329 .4033 L
.90462 .41773 L
.90537 .42393 L
.90618 .42887 L
.90692 .43169 L
.9076 .43285 L
.90824 .43265 L
.90895 .43098 L
.90969 .42763 L
.91038 .42305 L
.91162 .41137 L
.91295 .39456 L
.91535 .35537 L
.91814 .30162 L
.92077 .25219 L
.92198 .23236 L
.92326 .21464 L
.92393 .20696 L
.92466 .19993 L
.92595 .19142 L
.92712 .18823 L
.92838 .18978 L
.92956 .19594 L
.93064 .20533 L
.93531 .27851 L
.93787 .3296 L
.94027 .37424 L
.94231 .40397 L
.94346 .41586 L
.94451 .42315 L
.94559 .42679 L
.94678 .42606 L
.94802 .42004 L
.94918 .40984 L
.94999 .40023 L
.95086 .38777 L
.95246 .36068 L
.95544 .30112 L
.95862 .24029 L
.95949 .22669 L
.96043 .21431 L
.96131 .20506 L
.96212 .19889 L
.96299 .19481 L
.96395 .19359 L
.96484 .19555 L
.96568 .20005 L
.96664 .20829 L
.9675 .21837 L
.96944 .24867 L
Mistroke
.97619 .38151 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00??ooool4o`000003oa0@4?oooooooooo0?oooooo
9_ooool003kooooo00?o0000ooooooooool0oooooolXooooo`00<oooool6o`0000Gooooo00?o0000
ooooooooool0oooooolXooooo`00<?ooool00ol0003oooooooooo`07ooooo`05o`000?oooooooooo
ooooool000001oooool3o`000?oooooo8?ooool0033ooooo00?o0000ooooooooool01oooool01Ol0
003ooooooooooooooooo000000Oooooo00?o0000ooooooooool0oooooolPooooo`00;oooool00ol0
003oooooooooo`09ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool0oooooolP
ooooo`00;oooool00ol0003oooooooooo`09ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000
ooooooooool0oooooolPooooo`00;_ooool00ol0003oooooooooo`0:ooooo`04o`000?mEEEGoIVIV
o`0000Oooooo00?o0000ooooooooool0oooooolPooooo`00;_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Sooooo0_l0003oooooob7ooooo000^ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooob3ooooo000]ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3oooooob3ooooo
000]ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`3oooooob3ooooo000]ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01_ooool2
o`000?oooooo8Oooool002gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo0?oooooo8?ooool002cooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo0?oooooo8?ooool002cooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo8?ooool002cooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo8?oo
ool002cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`05ooooo`;o0000oooooolQ
ooooo`00;?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0oooooolPooooo`00;?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0oooooolPooooo`00:oooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0oooooolPooooo`00:oooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0;_ooool3o`000>kooooo000[
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01?ooool2o`0002oooooo00Co0000
oooooooooooo0000kOooool002_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo02gooooo00Go0000ooooooooooooooooo`00003]ooooo`008oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo00?o0000ooooooooool00_lQ8B46ooooo`03o`000?o^
k^kooooo00Cooooo00GoA4A4o`000?l0003o0000omgMg@05ooooo`03o`000?oooooooooo02gooooo
00Go0000ooooooooooooooooo`00003]ooooo`008oooool01OmgMgOoV9RHoooooonHV9SoMgMg00;o
oooo00?o0000ooooooooool00_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?o0000oc8b<_oo
ool01?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0j_ooool001_ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41000_ooool00ol0003o
ooooooooo`08ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0]ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0j_ooool002?ooooo
00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00Wooooo00?o8B4Qoooooooo
ool01_ooool00omgMgOo0000ooooo`04ooooo`?o0000;?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo0>Wooooo000Sooooo`05o`000?ooooooooooooooool000000_ooool00ol0003o
ooooooooo`09ooooo`03oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bo`000005oooo
o`03o`000?oooooooooo02cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3Yoooo
o`008oooool01ol@413ooooooooooooooooo410@ooooool000003?ooool00onYZJWoMgMgooooo`03
ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0jOooool002?ooooo00OoMgMgoiRHV?ooooooV9RHogMg
Mooooooo000000Wooooo00Go410@oooooooooooooooooc8b<P04ooooo`05o`000?oooooooooooooo
ool000001Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0j?ooool002?ooooo00Ook^k^oc8b<_l0003o<S8bonk^k_oooooo000000Wooooo1Ol00004
ooooo`Go00001Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0j?ooool002Wooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`02oooo
o`;o0000;?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0>Sooooo000Yooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool08oooool2o`000<?ooooo000Xooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0[ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool08oooool2o`000<?ooooo000Xooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool08Oooool01?l0003oooooooooool00032ooooo`00:?oo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0:_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo027ooooo00Co0000oooooooooooo0000
`_ooool002Sooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`02ooooo`;o0000:ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo027ooooo00Go0000oooooooooooooooo
o`000031ooooo`00:?ooool00ol0003oooooooooo`0Gooooo`05o`000?ooooooooooooooool00000
;?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`2oooooo`00:?ooool00ol0003oooooooooo`0Gooooo`05o`000?oo
ooooooooooooool00000;?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo023ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`2oooooo`009oooool00ol0003ooooooooo
o`0Hooooo`05o`000?ooooooooooooooool00000:oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo023ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2oooooo`009ooo
ool00ol0003oooooooooo`0Hooooo`04o`000?ooooooooooooooo`;o0000:_ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0Jooooo`;o0000Xoooool002Oooooo00?o0000ooooooooool06?ooool01Ol0003ooooooooo
oooooooo000002_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Pooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool06_ooool3o`000:;ooooo000Wooooo`03o`000?oo
oooooooo01Sooooo00Go0000ooooooooooooooooo`00000[ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool07_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Wooooo
0_l000000ooooooo0000ooooo`2Qooooo`009oooool00ol0003oooooooooo`0Hooooo`05o`000?oo
ooooooooooooool00000:oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Hooooo`04o`000?ooooooooooo`000:;o
oooo000Wooooo`03o`000?oooooooooo01Wooooo00Co0000oooooooooooo0000:_ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0Hooooo`04o`000?ooooooooooo`000:;ooooo000Vooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool00_l0000Yooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Sooooo00Co0000oooooooo
oooo0000X_ooool002Kooooo00?o0000ooooooooool06_ooool01?l0003oooooooooool0000Zoooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo01Sooooo00Co0000oooooooooooo00005oooool2o`0008Wooooo000Voooo
o`03o`000?oooooooooo00;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool0
1Om4A4Co0000o`000?lb<S;ogMgM00;ooooo00Co0000oooooooooooo0000:_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04oooool00ol0003ooooo
o`000029ooooo`009_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Sooooo00GoMgMgoc8b<_ooooooooooo`000002ooooo`03o`000?oooooooooo02So
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooool00000ROooool002?ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@
41004?ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ool00000ROooool002Gooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo0000
00oooooo00?oMgMgoc8b<_ooool00_ooool00ol0003oooooo`000002o`0002Sooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ool000004oooool00ol0003oooooooooo`1cooooo`009Oooool00ol0003oooooooooo`03ooooo`05
o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00?ooooo00?o0000
ooooool00000:Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool04_ooool01Ol0003ooooooooooooooooo0000017ooooo00?o0000ooooool00000M?oo
ool002Gooooo00?o0000ooooooooool00oooool01Ol@413ooooooooooooooooo410@00cooooo00?o
0000ooooooooool01Oooool00ol0003oooooo`00000Yooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Aooooo`05o`000?ooooooooooooooool00000
4Oooool00ol0003oooooo`00001dooooo`009Oooool00ol0003oooooooooo`03ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000002Wooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo
00Go0000ooooooooooooooooo`00000Aooooo`03o`000?oooooo000007Cooooo000Uooooo`03o`00
0?oooooooooo00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001?ooool00ol0003o
ooooo`00000Yooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Aooooo`05o`000?ooooooooooooooool000004Oooool00ol0003oooooo`00000@oooo
o`03o`000?oooooooooo067ooooo000Uooooo`03o`000?oooooooooo01cooooo00Co0000ooooool0
003o0000:?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool04Oooool01Ol0003ooooooooooooooooo0000017ooooo00?o0000ooooool000004?ooool2
o`0006;ooooo000Tooooo`03o`000?oooooooooo01kooooo0_l0000Yooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Aooooo`05o`000?oooooooooo
ooooool000004Oooool01?l0003oooooooooool0000>ooooo`03o`000?oooooo000000kooooo00?o
0000ooooooooool0DOooool002Cooooo00?o0000ooooooooool07_ooool2o`0002Wooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo00Go0000
ooooooooooooooooo`00000@ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003ooooo
o`00000=ooooo`;o0000Doooool002Cooooo00?o0000ooooooooool07_ooool2o`0002Wooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo017ooooo00Go
0000ooooooooooooooooo`00000@ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003o
ooooo`00000=ooooo`;o0000Doooool002Cooooo00?o0000ooooooooool07_ooool2o`0002Sooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo013ooooo
00Go0000ooooooooooooooooo`00000@ooooo`05o`000?ooooooooooooooool000003_ooool00ol0
003oooooo`00000=ooooo`03o`000?oooooo000000_ooooo0_l00015ooooo`009?ooool00ol0003o
ooooooooo`0Nooooo`?o00009oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool04?ooool01Ol0003ooooooooooooooooo0000013ooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03o`000?oooooo000000gooooo00?o0000ooooool000002oooool2
o`0004Gooooo000Sooooo`03o`000?oooooooooo01oooooo0_l0000Xooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool03Oooool01Ol0003ooooooooooooooooo000000gooooo00Go0000
ooooooooooooooooo`00000<ooooo`03o`000?oooooo000000_ooooo0_l0000;ooooo`;o0000>?oo
ool002?ooooo00?o0000ooooooooool07oooool2o`0002Sooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0=ooooo`05o`000?ooooooooooooooool000003Oooool01Ol0003ooooooooo
oooooooo000000_ooooo00Co0000oooooooooooo00002oooool00ol0003oooooo`00000:ooooo`;o
00002_ooool00ol0003oooooooooo`0[ooooo`008oooool00ol0003oooooooooo`0Pooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0=ooooo`05o`00
0?ooooooooooooooool000003Oooool01Ol0003ooooooooooooooooo000000_ooooo00Co0000oooo
oooooooo00002oooool00ol0003oooooo`00000:ooooo`;o00002Oooool2o`0002gooooo000Soooo
o`03o`000?oooooooooo023ooooo0_l0000Wooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool03Oooool01Ol0003ooooooooooooooooo000000gooooo00Go0000ooooooooooooooooo`00
000;ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooool000002Oooool00ol0003ooooo
o`000009ooooo`;o0000;Oooool002?ooooo00?o0000ooooooooool08?ooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03Oooool01Ol0003ooooooooo
oooooooo000000gooooo00Go0000ooooooooooooooooo`00000;ooooo`04o`000?ooooooooooo`00
00_ooooo00?o0000ooooool000002Oooool00ol0003oooooo`000009ooooo`;o0000;Oooool002?o
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool03Oooool01Ol0003ooooooooooooooooo000000gooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05o`000?ooooooooooooooool000002_ooool00ol0003oooooo`00
0009ooooo`03o`000?oooooo000000Wooooo00?o0000ooooool00000;?ooool002;ooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool03Oooool01Ol0003ooooooooooooooooo000000gooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?ooooooooooooooool000002_ooool00ol0003oooooo`000009ooooo`03
o`000?oooooo000000Wooooo00?o0000ooooool00000;?ooool002;ooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00_ooooo00Go0000oooooooooooo
ooooo`00000;ooooo`05o`000?ooooooooooooooool000002Oooool01?l0003oooooooooool00009
ooooo`03o`000?oooooo000000Wooooo00?o0000ooooool00000;?ooool002;ooooo00?o0000oooo
ooooool08Oooool2o`0002Kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo
000000_ooooo00Go0000ooooooooooooooooo`000009ooooo`04o`000?ooooooooooo`0000Wooooo
00?o0000ooooool000002Oooool00ol0003oooooo`00000/ooooo`008_ooool00ol0003ooooooooo
o`0Qooooo`;o00009_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`05o`000?ooooooooooooooool00000
2oooool01Ol0003ooooooooooooooooo000000Wooooo00Co0000oooooooooooo00002Oooool00ol0
003oooooo`000009ooooo`03o`000?oooooo000002cooooo000Rooooo`03o`000?oooooooooo027o
oooo0_l0000Vooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00[ooooo00Go0000ooooooooooooooooo`00000;oooo
o`05o`000?ooooooooooooooool000002Oooool01?l0003oooooooooool00009ooooo`03o`000?oo
oooo000000Wooooo00?o0000ooooool00000;?ooool002;ooooo00Ko0000onk^k_lb<S;o0000oc8b
<_o^k^h5ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`;o
00009_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool02?ooool01Ol0003ooooooooooooooooo000000Wooooo00Co0000oooooooooooo00002Oooool0
0ol0003oooooo`000008ooooo`04o`000?ooooooooooo`0002cooooo000Qooooo`07o`000?oooooo
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oo
oooo00?oMgMgoc8b<_ooool01?ooool2o`0002Kooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00Go0000ooooooooooooooooo`000009oooo
o`05o`000?ooooooooooooooool000002?ooool01?l0003oooooooooool00007ooooo`04o`000?oo
ooooooooo`0002cooooo000Kooooo`Oo000000?ooooooa0@4?ooool00_ooool00ol@413ooooooooo
o`0:ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool00oooool3o`0002Gooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00Go
0000ooooooooooooooooo`000009ooooo`05o`000?ooooooooooooooool000002?ooool01?l0003o
ooooooooool00007ooooo`04o`000?ooooooooooo`0002cooooo000Qooooo`03o`000?oooooo0000
00?ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo
00Cooooo0_l0000Vooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`08ooooo`05o`000?ooooooooooooooool000002Oooool01Ol0003ooooooooooooo
oooo000000Sooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool0000/ooooo`00
8Oooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool0
0oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo0_l0000Uooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`05o`000?oooooooooooooo
ool000002?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00Co0000oooo
oooooooo00001oooool01?l0003oooooooooool0000/ooooo`008Oooool00ol0003ooooooa0@4003
ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07
ooooo`;o00009Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool02?ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`06ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo
0000;?ooool0023ooooo00So0000ooooooooooooMgMgoiRHV?ooooooV9RHogMgM`_ooooo00Go0000
okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooool000009?oo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?oo
ool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`05ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool0000/oooo
o`008?ooool02?l0003oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnHV9So410@o`00
0?lQ8B7oc<c<00Cooooo1?l00006ooooo`?o00009?ooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooooooo000000So
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`05o`000?oooooooooooooo
ool000001oooool01?l0003oooooooooool0000/ooooo`008?ooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooo000002Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Sooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000Oooooo00Co
0000oooooooooooo0000;?ooool0023ooooo00?o0000ooooooooool08oooool00ol0003oooooo`00
000Tooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`08ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`00
02cooooo000Pooooo`03o`000?oooooooooo02?ooooo00?o0000ooooool000009?ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`05ooooo`05o`000?ooooooooooooooool000001oooool01?l0003oooooooooool0000/
ooooo`008?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo000002Cooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01Oooool01Ol0003ooooooooooooooooo000000Oooooo00Co0000oooooooooooo0000;?oo
ool001oooooo00?o0000ooooooooool09?ooool3o`0002Cooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo0000;?oo
ool001oooooo00?o0000ooooooooool09?ooool00ol0003oooooo`00000Sooooo`03o`000?oooooo
oooo01?ooooo00GoA4A4o`000?l0003o<S8bomgMg@0Eooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03Oooool4o`00000:oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^kooooo
o`0000kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Gooooo00Co0000oooooooooooooooo1?l000001Ol@413oooooooooool0003oA4A400;o0000
00Co<S8bomgMgOoooooo00002?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool5o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Toooo
o`007oooool00ol0003oooooooooo`0Tooooo`04o`000?ooooooooooo`0002;ooooo00?o0000oooo
ooooool05?ooool01?l0003oooooogMgMolb<S8Eooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool03_ooool2o`0000Cooooo00OoMgMgoiRHV?ooooooV9RHogMgMooooooo000000kooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Cooooo00CoMgMgoc8b<_oo
oooo00002?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool01OnHV9So0000onk^k_oooooo000000?ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0Tooooo`007oooool00ol0003oooooooooo`0Tooooo`04o`000?ooooooooooo`0002;ooooo00?o
0000ooooooooool05?ooool01?l0003oooooooooool0000Eooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03_ooool2o`0000Cooooo00Oo410@oooooooooooooooooa0@4?oooooo0000
00kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000
ooooool000002?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool01_l0003oV9RHob4Q8Oo^k^koooooo`0000;ooooo00Go410@oooooooooooo
oooooa0@400Tooooo`007oooool00ol0003oooooooooo`0Tooooo`04o`000?ooooooooooo`0002;o
oooo00?o0000ooooooooool05Oooool00ol0003oMgMgoc8b<P0Eooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool2o`0000Cooooo00Oo0000ooooooooooooooooo`000?oooooo
000000kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Cooooo00Co
MgMgoc8b<_oooooo00002?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool01_l0003ooooooiRHV?lQ8B7ok^k^o`0000;ooooo00Go0000oooo
ooooooooooooo`00000Tooooo`007oooool00ol0003oooooooooo`0Tooooo`;o000000?oooooo`00
0?ooool08Oooool00ol0003oooooooooo`0Cooooo`05o`000?lQ8B7o0000oc8b<_o<c<`05?ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo0_l00004ooooo`05o`000?oooooo
ooooooooool000000_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00go
0000ooooooooooooooooo`000?oooooo0000ob4Q8Ol0003o<S8bolc<c?oooooo000000Sooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00Ko
0000ooooooooooooMgMgofIVI_l00002ooooo`05o`000?ooooooooooooooool000009?ooool001oo
oooo00?o0000ooooooooool09?ooool01?l0003oooooooooool0000Rooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooool000005_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00kooooo0_l00004ooooo`05oa0@4?ooooooooooooooool@41000_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00?ooooo00Oo0000ooooooooooooooooo`000?oooooo000000Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool01?l0003oooooooooooooool2o`0000;ooooo00Go410@oooooooo
oooooooooa0@400Tooooo`007_ooool00ol0003oooooooooo`0Uooooo`04o`000?ooooooooooo`00
02;ooooo00?o0000ooooooooool04oooool00ol0003oooooo`00000Fooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool03_ooool2o`0000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`02
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool01ol0003ooooooooooooo
oooo0000ooooool000001Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`06o`000?nj^[[ooooooiRHV?l@
413o00000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02Cooooo000Nooooo`03o`000?oooooooooo
02Gooooo00Co0000oooooooooooo00008_ooool00ol0003oooooooooo`0Cooooo`Co00005Oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?oEEEEo`000?l000001?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00;ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool01ol0003ooooooooo
ooooooooEEEEofIVI_l000000oooool00ol0003oooooo`000003o`0000;ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool01_l0003o410@o`000?lQ8B7oc<c<o`0000;ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0Tooooo`007_ooool00ol0003oooooooooo`0Uooooo`;o00000_ooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0:Oooool001kooooo00?o0000oooo
ooooool09Oooool01Ol0003ooooooooooooooooo0000023ooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Yooooo`007_ooool00ol0003oooooooooo`0Uooooo`05o`000?oooooooooo
ooooool000008?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo017ooooo0_l00002
ooooo`;o00004_ooool001kooooo00?o0000ooooooooool09Oooool01Ol0003ooooooooooooooooo
0000023ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Aooooo`06onk^k_lQ8B7o
QhN7okZj^_l0003ogMgM4_ooool001gooooo00?o0000ooooooooool09_ooool01Ol0003ooooooooo
oooooooo0000023ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Booooo`04omgM
gOl0003o410@olc<c1?ooooo000=oooooooo0000>_l0000;ooooo`04onk^k_lQ8B7o410@onk^kQ?o
oooo000Dooooo`03o`000?oooooooooo00Kooooo00Go0000ooooooooooooooooo`00000;ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo0000
00Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02_ooool2o`0000[ooooo00?o0000ooooooooool02?ooool2o`00
00cooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000002?oo
ool01?l0003oooooooooool00008ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003o
ooooooooo`03ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooooooo`05oooo
o`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000004_ooool0
1?lQ8B7oMgMgogMgMolb<S8Cooooo`007Oooool00ol0003oooooooooo`0Vooooo`05o`000?oooooo
ooooooooool000008?ooool00ol0003oooooooooo`0Fooooo`;o00005?ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooo`00
000Aooooo`;o00000_ooool2o`0001;ooooo000Mooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0:?ooool001gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Xoooo
o`007?ooool00ol0003oooooooooo`0Wooooo`;o00000oooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0:?ooool001cooooo00?o0000ooooooooool0
9oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Xooooo`007?ooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo02Sooooo000Looooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
1Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0:?ooool001cooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_oo
ool00ol0003oooooooooo`0Xooooo`007?ooool00ol0003oooooooooo`0Wooooo`;o00000oooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
1Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0:?ooool001cooooo00?o0000
ooooooooool09oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_oo
ool00ol0003oooooooooo`0Xooooo`006oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo02Sooooo000K
ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooo
oooo000000Kooooo00?o0000ooooooooool0:?ooool001_ooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooooooo
o`0Xooooo`006oooool00ol0003oooooooooo`0Xooooo`;o00001?ooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooo
oooo000000Kooooo00?o0000ooooooooool0:?ooool001_ooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooooooo
o`0Xooooo`006oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000
ooooooooooooooooo`000007ooooo`03o`000?oooooooooo02Oooooo000Jooooo`03o`000?oooooo
oooo02Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Oooooo00?o
0000ooooooooool09oooool001[ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`0Wooooo`006_ooool0
0ol0003oooooooooo`0Yooooo`;o00001Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Oooooo00?o
0000ooooooooool09oooool001[ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`0Wooooo`006_ooool0
0ol0003oooooooooo`06ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol0
0004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Kooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooooooooooo
ool000001oooool00ol0003oooooooooo`0Wooooo`006_ooool00ol0003oooooooooo`06ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Sooooo00Go0000ooooooooooooooooo`000008ooooo`05o`000?oo
ooooooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000oooooooo
ool09oooool001[ooooo00?o0000ooooooooool01_ooool01Ol@413ooooooooooooooooo410@00co
oooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`?o00001?ooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00Go0000ooooooooooooooooo`000008oooo
o`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo0000037ooooo000I
ooooo`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ
8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooooooo000000Sooooo
00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool00000<Oooool001Wo
oooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIV
I_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool0
1Ol0003ooooooooooooooooo000000[ooooo00Go0000ooooooooooooooooo`000008ooooo`05o`00
0?ooooooooooooooool000002?ooool01?l0003oooooooooool0000aooooo`006Oooool00ol0003o
ooooooooo`07ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003ooooooooooooooooo
000000[ooooo00Go0000ooooooooooooooooo`000008ooooo`05o`000?ooooooooooooooool00000
2?ooool01?l0003oooooooooool0000aooooo`006Oooool00ol0003oooooooooo`07ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?ooooooooooooooool000002_ooool0
1Ol0003ooooooooooooooooo000000Wooooo00Co0000oooooooooooo00002?ooool00ol0003ooooo
o`00000booooo`006Oooool00ol0003oooooooooo`07ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o00001_ooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool01Ol0003o
oooooooooooooooo000000[ooooo00Go0000ooooooooooooooooo`000009ooooo`04o`000?oooooo
ooooo`0000Sooooo00?o0000ooooool00000<_ooool001Wooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`09ooooo`05o`000?ooooooooooooooool000002_ooool01?l0003ooooooooo
ool0000:ooooo`03o`000?oooooo000000Wooooo00?o0000ooooool00000<_ooool001Sooooo00?o
0000ooooooooool0:oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?ooooooooooooooool00000
2oooool00ol0003oooooo`00000:ooooo`03o`000?oooooo000000Wooooo00?o0000ooooool00000
<_ooool001Sooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`05o`000?oo
ooooooooooooool000002oooool00ol0003oooooo`00000:ooooo`03o`000?oooooo000000Wooooo
00?o0000ooooool00000<_ooool001Sooooo00?o0000ooooooooool0:oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`00
0?ooooooooooooooool000002oooool00ol0003oooooo`00000:ooooo`03o`000?oooooo000000Wo
oooo00?o0000ooooool00000<_ooool001Sooooo00?o0000ooooooooool0:oooool2o`0000Kooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02oooool01Ol0003ooooooooooooooooo000000gooooo00Co0000oooooooo
oooo00002oooool00ol0003oooooo`00000:ooooo`03o`000?oooooo000000Wooooo00?o0000oooo
ool00000<_ooool001Sooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`00000=ooooo`04o`000?oooooooooo
o`0000_ooooo00?o0000ooooool000002_ooool00ol0003oooooo`000009ooooo`03o`000?oooooo
000003;ooooo000Hooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0;ooooo`05o`000?ooooooooooooooool000003Oooool01?l0003oooooooooool0
000;ooooo`03o`000?oooooo000000[ooooo00?o0000ooooool000002_ooool2o`0003;ooooo000H
ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0;
ooooo`05o`000?ooooooooooooooool000003Oooool01?l0003oooooooooool0000;ooooo`03o`00
0?oooooo000000[ooooo00?o0000ooooool000002_ooool00ol0003oooooooooo`0aooooo`005ooo
ool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02ooo
ool01Ol0003ooooooooooooooooo000000gooooo00Co0000oooooooooooo00002oooool00ol0003o
ooooo`00000;ooooo`;o0000?_ooool001Oooooo00?o0000ooooooooool0;?ooool2o`0000Oooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0?ooooo`05o`000?ooooooooooooooool0
00003oooool01?l0003oooooooooool0000=ooooo`03o`000?oooooo000000cooooo00?o0000oooo
ool000002oooool00ol0003oooooooooo`0mooooo`005oooool00ol0003oooooooooo`0/ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0?ooooo`05
o`000?ooooooooooooooool000003oooool01?l0003oooooooooool0000=ooooo`03o`000?oooooo
000000cooooo0_l0001<ooooo`005oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0?ooooo`05o`000?oooooooooo
ooooool000003oooool01?l0003oooooooooool0000=ooooo`03o`000?oooooo000000gooooo00?o
0000ooooooooool0B_ooool001Oooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03oooool01Ol0003ooooooooooooo
oooo000000oooooo00Co0000oooooooooooo00003Oooool00ol0003oooooo`00001Jooooo`005ooo
ool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0@ooooo`05o`000?ooooooooooooooool000003oooool01?l0003ooooo
ooooool0000>ooooo`03o`000?oooooooooo05Wooooo000Fooooo`03o`000?oooooooooo02gooooo
0_l00008ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool08?ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04?ooool01Ol0003ooooo
oooooooooooo000000oooooo00?o0000ooooool000003oooool00ol0003oooooooooo`1Iooooo`00
5_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0@ooooo`05o`000?ooooooooooooooool000004?ooool2o`0006_o
oooo000Fooooo`03o`000?oooooooooo01;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo017ooooo00Co0000oooooooooooo00004?ooool2
o`0006_ooooo000Fooooo`03o`000?oooooooooo01;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo0000017ooooo00?o0000
ooooooooool0J_ooool001Kooooo00?o0000ooooooooool04_ooool01Ol@413ooooooooooooooooo
410@013ooooo00?o0000ooooooooool00oooool3o`0000Sooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooo000007kooooo000Fooooo`03o`000?oooooooooo
01;ooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02;ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool05?ooool01Ol0003ooooooooooooooooo000001?ooooo00?o0000ooooool00000O_oo
ool001Gooooo00?o0000ooooooooool04oooool01Ol0003ooooooooooooooooo000000cooooo00Go
0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Cooooo00Go0000oooooooooooo
ooooo`00000Dooooo`03o`000?oooooooooo07gooooo000Eooooo`03o`000?oooooooooo01?ooooo
00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02;ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool05?ooool01Ol0003ooooooooooooooooo000009Cooooo000Eooooo`03o`000?oooooooooo01?o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02;ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool05?ooool01Ol0003ooooooooooooooooo000009Cooooo000Eooooo`03o`000?oooooooooo
01?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool2o`0000[ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooool00000UOooool001Gooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooo000009Gooooo000Eooooo`03o`000?oooooooooo02kooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Kooooo`05o`000?ooooooooooooooool000006?ooool3o`00
09Gooooo000Eooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0Looooo`05o`000?ooooooooooooooool00000/?ooool001Cooooo00?o0000oooooooo
ool0;oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01cooooo00Go0000oooooooo
ooooooooo`00002`ooooo`005?ooool00ol0003oooooooooo`0_ooooo`;o00002_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0Looooo`05o`000?ooooooooooooooool00000/?ooool001Cooooo00?o0000oooooooo
ool0;oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01cooooo00Co0000oooooooo
oooo0000/Oooool004Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Looooo`04
o`000?ooooooooooo`000;7ooooo0016ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool07_ooool2o`000;;ooooo0016ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
7_ooool2o`000;;ooooo0016ooooo`;o00002oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3Booooo`00A_ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool09oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo0=;ooooo0016ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0d_ooool004Kooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`3Booooo`00A_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0:?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0=;ooooo
0016ooooo`;o00003?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Wooooo00Go
0000ooooooooooooooooo`00003Eooooo`00A_ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool0:Oooool01Ol0003ooooooooooooooooo00000=Gooooo
000Sooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo00?o0000onk^k_ooool0
1?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooool00000e_ooool002?ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1_ooool00omEEEGoZJVYooooo`07ooooo`03
ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo02[ooooo00?o0000ooooool00000e_ooool002?ooooo00Go410@oooooooooooo
oooooa0@400=ooooo`03ojVYZOmEEEGooooo00Sooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0;?ooool00ol0003o
ooooooooo`3Eooooo`008oooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qoooooooo
ool01_ooool00omgMgOo<S8booooo`04ooooo`?o00003?ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo0?oooooo1Oooool002?ooooo00Go0000ooooooooooooooooo`00000>ooooo`03
oeEEEOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`3oooooo`Gooooo000Sooooo`05
oa0@4?ooooooooooooooool@41003_ooool00onYZJWoMgMgooooo`03ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
0?oooooo1Oooool002?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooo
oooooolb<S801?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`3oooooo`Kooooo000Sooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006ooooo`;o00003_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo0?oooooo1_ooool004Kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo1_ooool004Kooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo1_ooool004Kooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?oooooo
1_ooool004Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo1oooool004Kooooo0_l0000?ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0ooooool7ooooo`00A_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0ooooool7ooooo`00A_ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0ooooool7ooooo`00A_ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0ooooool8ooooo`00A_oo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0oooo
ool8ooooo`00A_ooool2o`00017ooooo00Go0000ooooooooooooooooo`00003oooooo`_ooooo0016
ooooo`03o`000?oooooooooo017ooooo00Co0000ooooool0003o0000ooooool;ooooo`00A_ooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo0?oooooo2oooool004Kooooo00?o0000oooo
ooooool0oooooolPooooo`00A_ooool00ol0003oooooooooo`3oooooob3ooooo0016ooooo`;o0000
oooooolQooooo`00A_ooool00ol0003oooooooooo`3oooooob3ooooo000looooo`Co000000?o410@
ooooooooool00oooool00ol0003oooooooooo`3oooooob3ooooo000nooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0oooooolPooooo`00?_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0?oooooo8?ooool003kooooo00?o0000ooooooooool01Oooool3o`000?oooooo
8?ooool003kooooo00?o0000ooooooooool0oooooolXooooo`00?_ooool00ol0003oooooooooo`3o
ooooobSooooo000nooooo`03o`000?oooooooooo0?oooooo:?ooool003cooooo00?oEEEEofIVI_l0
0000oooooolZooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00@_ooool3o`000003oa0@4?oooooooooo0?oooooo8Oooool004Cooooo00?o410@okZj^_ooool0
oooooolRooooo`00A?ooool00onHV9So<S8booooo`3oooooob;ooooo0014ooooo`03omgMgOl0003o
^[Zj0?oooooo8_ooool004Cooooo00?oEEEEogMgMom4A4@0oooooolRooooo`00@oooool01OoMgMgo
410@oooooolQ8B7ogMgM0?oooooo8Oooool004?ooooo00GoIVIVohN7QoooooooV9RHoeEEE@3ooooo
ob7ooooo0012ooooo`03onk^k_l0003ok^k^00;ooooo00?o0000omgMgOooool0oooooolOooooo`00
@_ooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo0?oooooo7_ooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-5.66973, -1.05832, 0.1009, \
0.0129571}}]
}, Closed]]
}, Open  ]],

Cell["\<\
This plot shows that the wave decreases in amplitude as it \
propagates to the right, because the string gets heavier as one moves in this \
direction. Also, since the wave slows down as it propagates, wavefronts pile \
up, making the wavelength smaller.\
\>", "Text"],

Cell[TextData[{
  "\tThis solution propagates to the right.  As an exercise, reevaluate this \
cell , modifying the definition of ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " so that it is a traveling wave moving to the left. What does the \
animation look like now? How does it relate to the one shown in Cell ",
  ButtonBox["5.16",
    ButtonData:>"Cell 5.16",
    ButtonStyle->"Hyperlink"],
  "?"
}], "Text"],

Cell[TextData[{
  "\t Another question is: how close is this WKB solution to the exact \
solution for this ",
  "traveling",
  " wave? One can answer this question by solving Eq. ",
  ButtonBox["(5.2.3)",
    ButtonData:>"(5.2.3)",
    ButtonStyle->"Hyperlink"],
  "  for \[Psi]  using ",
  StyleBox["DSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\[Psi][
        x_]\  = \ \[Psi][
          x] /. \(DSolve[\(\[Psi]''\)[
                x] \[Equal] \(-\(\[Omega]\^2\/c\_o\^2\)\)\ Exp[x/L]\ \[Psi][
                  x], \[Psi][x], x]\)[\([1]\)]\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 5.17"],

Cell[BoxData[
    \(BesselJ[0, \(2\ \@\[ExponentialE]\^\(x\/L\)\ L\ \[Omega]\)\/c\_o]\ C[
          1] + 2\ BesselY[
          0, \(2\ \@\[ExponentialE]\^\(x\/L\)\ L\ \[Omega]\)\/c\_o]\ C[
          2]\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "The result is a superposition of two Bessel functions. In order to compare \
this exact solution with our WKB approximation, we must determine the \
constants ",
  StyleBox["C[1]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " and ",
  StyleBox["C[2]",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ". To do so, we will match ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi](x)\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`y(x, 0)\)]],
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"at", 
            FormBox[\(x = 0\),
              "TraditionalForm"]}], ","}], TraditionalForm]]],
  " and  ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\[Psi]/\[PartialD]x\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[PartialD]y/\[PartialD]x\)\( | \_\(t = 
              0\)\)\)\)]],
  " at ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  ". Therefore, the solutions will match at ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  ", but not necessarily at any other ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ":  "
}], "Text"],

Cell[BoxData[{
    \(\(Solve[{\[Psi][0]\  \[Equal] 
            y[0, 0], \((D[\[Psi][x], x] /. 
                x \[Rule] 0)\) \[Equal] \((D[y[x, 0], x] /. 
                x \[Rule] 0)\)}, {C[1], C[2]}];\)\), "\n", 
    \(\(\[Psi][x_]\  = \ \[Psi][x] /. %[\([1]\)];\)\), "\n", 
    \(\(yexact[x_, 
          t_]\  = \[Psi][x]\ Exp[\(-I\)\ \[Omega]\ t] /. {\[Omega] \[Rule] 
              1. , L \[Rule] 5. , c\_o \[Rule] 1. };\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 5.18"],

Cell[TextData[{
  "We plot the exact solution in Cell ",
  ButtonBox["5.19",
    ButtonData:>"Cell 5.19",
    ButtonStyle->"Hyperlink"],
  ", at time ",
  Cell[BoxData[
      \(TraditionalForm\`t = 0\)]],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[Re[yexact[x, 0]], {x, \(-4\), 20}, 
        PlotRange \[Rule] {\(-1\), 1}, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 5.19"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.18254 0.0396825 0.309017 0.309017 [
[.38095 .29652 -3 -9 ]
[.38095 .29652 3 0 ]
[.57937 .29652 -6 -9 ]
[.57937 .29652 6 0 ]
[.77778 .29652 -6 -9 ]
[.77778 .29652 6 0 ]
[.97619 .29652 -6 -9 ]
[.97619 .29652 6 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.17004 0 -12 -4.5 ]
[.17004 0 0 4.5 ]
[.17004 .07725 -30 -4.5 ]
[.17004 .07725 0 4.5 ]
[.17004 .15451 -24 -4.5 ]
[.17004 .15451 0 4.5 ]
[.17004 .23176 -30 -4.5 ]
[.17004 .23176 0 4.5 ]
[.17004 .38627 -24 -4.5 ]
[.17004 .38627 0 4.5 ]
[.17004 .46353 -18 -4.5 ]
[.17004 .46353 0 4.5 ]
[.17004 .54078 -24 -4.5 ]
[.17004 .54078 0 4.5 ]
[.17004 .61803 -6 -4.5 ]
[.17004 .61803 0 4.5 ]
[.18254 .64303 -5 0 ]
[.18254 .64303 5 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.38095 .30902 m
.38095 .31527 L
s
[(5)] .38095 .29652 0 1 Mshowa
.57937 .30902 m
.57937 .31527 L
s
[(10)] .57937 .29652 0 1 Mshowa
.77778 .30902 m
.77778 .31527 L
s
[(15)] .77778 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(20)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.22222 .30902 m
.22222 .31277 L
s
.2619 .30902 m
.2619 .31277 L
s
.30159 .30902 m
.30159 .31277 L
s
.34127 .30902 m
.34127 .31277 L
s
.42063 .30902 m
.42063 .31277 L
s
.46032 .30902 m
.46032 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.53968 .30902 m
.53968 .31277 L
s
.61905 .30902 m
.61905 .31277 L
s
.65873 .30902 m
.65873 .31277 L
s
.69841 .30902 m
.69841 .31277 L
s
.7381 .30902 m
.7381 .31277 L
s
.81746 .30902 m
.81746 .31277 L
s
.85714 .30902 m
.85714 .31277 L
s
.89683 .30902 m
.89683 .31277 L
s
.93651 .30902 m
.93651 .31277 L
s
.14286 .30902 m
.14286 .31277 L
s
.10317 .30902 m
.10317 .31277 L
s
.06349 .30902 m
.06349 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.18254 0 m
.18879 0 L
s
[(-1)] .17004 0 1 0 Mshowa
.18254 .07725 m
.18879 .07725 L
s
[(-0.75)] .17004 .07725 1 0 Mshowa
.18254 .15451 m
.18879 .15451 L
s
[(-0.5)] .17004 .15451 1 0 Mshowa
.18254 .23176 m
.18879 .23176 L
s
[(-0.25)] .17004 .23176 1 0 Mshowa
.18254 .38627 m
.18879 .38627 L
s
[(0.25)] .17004 .38627 1 0 Mshowa
.18254 .46353 m
.18879 .46353 L
s
[(0.5)] .17004 .46353 1 0 Mshowa
.18254 .54078 m
.18879 .54078 L
s
[(0.75)] .17004 .54078 1 0 Mshowa
.18254 .61803 m
.18879 .61803 L
s
[(1)] .17004 .61803 1 0 Mshowa
.125 Mabswid
.18254 .01545 m
.18629 .01545 L
s
.18254 .0309 m
.18629 .0309 L
s
.18254 .04635 m
.18629 .04635 L
s
.18254 .0618 m
.18629 .0618 L
s
.18254 .09271 m
.18629 .09271 L
s
.18254 .10816 m
.18629 .10816 L
s
.18254 .12361 m
.18629 .12361 L
s
.18254 .13906 m
.18629 .13906 L
s
.18254 .16996 m
.18629 .16996 L
s
.18254 .18541 m
.18629 .18541 L
s
.18254 .20086 m
.18629 .20086 L
s
.18254 .21631 m
.18629 .21631 L
s
.18254 .24721 m
.18629 .24721 L
s
.18254 .26266 m
.18629 .26266 L
s
.18254 .27812 m
.18629 .27812 L
s
.18254 .29357 m
.18629 .29357 L
s
.18254 .32447 m
.18629 .32447 L
s
.18254 .33992 m
.18629 .33992 L
s
.18254 .35537 m
.18629 .35537 L
s
.18254 .37082 m
.18629 .37082 L
s
.18254 .40172 m
.18629 .40172 L
s
.18254 .41717 m
.18629 .41717 L
s
.18254 .43262 m
.18629 .43262 L
s
.18254 .44807 m
.18629 .44807 L
s
.18254 .47898 m
.18629 .47898 L
s
.18254 .49443 m
.18629 .49443 L
s
.18254 .50988 m
.18629 .50988 L
s
.18254 .52533 m
.18629 .52533 L
s
.18254 .55623 m
.18629 .55623 L
s
.18254 .57168 m
.18629 .57168 L
s
.18254 .58713 m
.18629 .58713 L
s
.18254 .60258 m
.18629 .60258 L
s
.25 Mabswid
.18254 0 m
.18254 .61803 L
s
gsave
.18254 .64303 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.03148 .61803 m
.06244 .47174 L
.08255 .33884 L
.10458 .18924 L
.11448 .12825 L
.12507 .07191 L
.1302 .04891 L
.13506 .03024 L
.13975 .01531 L
.14415 .00432 L
s
.14415 .00432 m
.14636 0 L
s
.16711 0 m
.16867 .003 L
.17292 .0137 L
.17796 .0306 L
.18257 .04985 L
.19248 .10283 L
.20165 .16388 L
.22241 .32725 L
.23216 .40507 L
.24266 .48044 L
.2475 .5101 L
.25258 .53685 L
.25735 .5571 L
.26168 .57099 L
.264 .57655 L
.26619 .58053 L
.2674 .58218 L
.26851 .58336 L
.26973 .58427 L
.27102 .5848 L
.27205 .58489 L
.27315 .58467 L
.2742 .58415 L
.27515 .5834 L
.27627 .58221 L
.27749 .58052 L
.27971 .57638 L
.28231 .56979 L
.28466 .56223 L
.28994 .53992 L
.29483 .51299 L
.29943 .48268 L
.31784 .32751 L
.32829 .23195 L
.33803 .15259 L
.34299 .11943 L
.34768 .09415 L
.35027 .08308 L
.35309 .0736 L
.35433 .0703 L
.35564 .0674 L
.35677 .06544 L
.35801 .06381 L
.35865 .0632 L
.35934 .06271 L
.36007 .0624 L
.36074 .06229 L
.36195 .06253 L
.36325 .06341 L
.36398 .0642 L
Mistroke
.36477 .06528 L
.3662 .06787 L
.3676 .07115 L
.36889 .07483 L
.37384 .09484 L
.37634 .10828 L
.37909 .12548 L
.38928 .2081 L
.39857 .30001 L
.40943 .40791 L
.4142 .44952 L
.41948 .48784 L
.42177 .50137 L
.42424 .51356 L
.42658 .52262 L
.42872 .52871 L
.4299 .53113 L
.431 .53276 L
.43221 .53387 L
.4335 .53423 L
.43415 .5341 L
.43486 .53371 L
.43614 .53235 L
.43739 .53023 L
.43854 .52757 L
.44102 .51959 L
.44334 .50938 L
.44862 .47687 L
.45376 .43431 L
.45929 .37949 L
.46941 .26843 L
.47475 .21235 L
.48044 .16108 L
.48326 .14045 L
.48591 .12456 L
.48829 .1135 L
.48963 .10871 L
.49086 .10525 L
.49202 .10285 L
.49311 .10136 L
.4943 .10058 L
.49557 .10074 L
.49621 .10121 L
.4969 .10202 L
.49817 .10429 L
.4994 .10747 L
.50054 .11127 L
.50296 .12201 L
.50517 .13493 L
.51017 .17381 L
Mistroke
.51921 .26968 L
.52989 .39427 L
.5351 .44533 L
.53736 .46356 L
.53982 .4799 L
.54101 .48642 L
.54227 .49226 L
.54344 .49665 L
.54453 .49986 L
.54556 .50205 L
.54665 .50351 L
.54787 .50405 L
.54898 .50352 L
.55023 .50179 L
.55138 .49909 L
.55265 .49495 L
.554 .4892 L
.5565 .475 L
.55876 .4584 L
.56389 .40944 L
.56943 .34402 L
.57463 .27825 L
.57947 .22021 L
.58203 .19298 L
.58446 .17056 L
.58682 .15249 L
.58901 .13957 L
.59018 .13424 L
.59143 .12989 L
.59268 .12692 L
.59339 .12587 L
.59406 .1253 L
.59475 .12515 L
.59541 .12543 L
.59666 .12706 L
.59735 .1286 L
.598 .13042 L
.59946 .13597 L
.60078 .14265 L
.60221 .15159 L
.60481 .17206 L
.60966 .22282 L
.62054 .36461 L
.62513 .41864 L
.62765 .44302 L
.63004 .46143 L
.63139 .46954 L
.6321 .4731 L
.63286 .47633 L
.6335 .47859 L
Mistroke
.6342 .48059 L
.63543 .48283 L
.63668 .48343 L
.63739 .48301 L
.63803 .48216 L
.63922 .47939 L
.64047 .47484 L
.64179 .46824 L
.64299 .46069 L
.64568 .43875 L
.65053 .38459 L
.65587 .31167 L
.66153 .23428 L
.66628 .18161 L
.66758 .17047 L
.66898 .16042 L
.6703 .15289 L
.67151 .14777 L
.67268 .14447 L
.67377 .14293 L
.67496 .14293 L
.67623 .14491 L
.67744 .14868 L
.67858 .15388 L
.6796 .15988 L
.68071 .16773 L
.68322 .19046 L
.68598 .22213 L
.69154 .29982 L
.69632 .369 L
.69883 .40167 L
.7015 .43083 L
.7028 .4424 L
.70423 .45287 L
.70553 .46015 L
.70676 .46492 L
.70801 .46765 L
.70915 .46821 L
.71041 .46665 L
.71173 .46258 L
.71284 .45723 L
.71403 .44966 L
.71618 .43146 L
.71873 .40306 L
.72104 .37225 L
.72633 .29242 L
.72923 .2493 L
.73193 .21343 L
.73443 .18648 L
.73552 .17707 L
Mistroke
.73671 .16867 L
.73801 .16183 L
.73925 .15775 L
.73993 .15652 L
.74066 .15604 L
.74197 .15733 L
.74315 .16086 L
.74423 .16604 L
.74542 .17381 L
.74667 .18423 L
.74878 .2065 L
.75109 .2366 L
.75638 .31821 L
.76118 .39055 L
.76386 .42254 L
.76508 .43415 L
.76639 .44399 L
.76705 .44794 L
.76777 .45144 L
.76906 .45538 L
.76978 .45632 L
.77055 .45627 L
.77128 .45523 L
.77195 .45343 L
.77323 .4478 L
.77441 .44005 L
.77571 .4289 L
.7771 .41422 L
.78199 .3448 L
.78699 .26281 L
.78973 .22278 L
.79228 .19316 L
.79361 .18163 L
.7943 .1769 L
.79504 .17274 L
.79586 .16939 L
.79663 .16742 L
.79738 .16663 L
.79807 .1669 L
.7993 .16976 L
.8 .17273 L
.80066 .17638 L
.80198 .18618 L
.80341 .20019 L
.81304 .34982 L
.81568 .39028 L
.81713 .40907 L
.8185 .42383 L
.81978 .43456 L
.8205 .43921 L
Mistroke
.82116 .44255 L
.82234 .44617 L
.82358 .44671 L
.82482 .44384 L
.82596 .43827 L
.82727 .4285 L
.82851 .41612 L
.83072 .38767 L
.83312 .34954 L
.83864 .25407 L
.84103 .21859 L
.84229 .20337 L
.84362 .19053 L
.8443 .18538 L
.84505 .18091 L
.84636 .17615 L
.847 .17531 L
.84769 .17551 L
.84893 .17876 L
.84966 .18238 L
.85045 .1877 L
.85188 .20089 L
.85328 .21769 L
.85457 .23617 L
.85946 .32116 L
.86216 .36822 L
.86349 .38874 L
.86473 .40535 L
.86599 .41933 L
.86714 .429 L
.86841 .43604 L
.86911 .43816 L
.86977 .43899 L
.87092 .43769 L
.87198 .4334 L
.87315 .4254 L
.87438 .4134 L
.87661 .38367 L
.8787 .34885 L
.88343 .2617 L
.88471 .24037 L
.8861 .21996 L
.88733 .20508 L
.88864 .19306 L
.88981 .186 L
.8911 .1826 L
.89228 .18363 L
.89338 .18819 L
.89468 .19787 L
.89534 .20441 L
Mistroke
.89606 .21274 L
.89851 .24927 L
.90405 .35255 L
.90658 .39376 L
.90801 .41158 L
.90933 .42349 L
.91048 .4299 L
.91175 .43235 L
.91239 .4317 L
.91307 .42961 L
.91431 .42223 L
.91551 .41094 L
.91681 .39441 L
.91919 .35537 L
.92364 .26922 L
.92495 .24598 L
.92635 .2241 L
.92768 .20757 L
.9289 .19663 L
.92959 .19249 L
.93033 .18966 L
.93112 .18866 L
.93184 .18956 L
.93313 .1954 L
.93385 .20099 L
.93451 .20745 L
.93699 .24215 L
.93969 .2927 L
.94205 .34005 L
.94459 .38526 L
.94554 .39896 L
.94655 .41073 L
.94741 .41836 L
.94835 .42393 L
.94923 .42639 L
.95018 .42597 L
.95107 .42266 L
.95188 .41727 L
.95291 .40725 L
.95386 .39515 L
.95601 .35956 L
.95992 .28075 L
.96173 .24639 L
.96368 .21694 L
.9648 .20496 L
.96582 .19771 L
.96685 .19428 L
.96782 .1947 L
.96883 .19892 L
.9699 .20749 L
Mistroke
.97091 .21916 L
.97183 .23239 L
.97619 .31736 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00??ooool4o`000003oa0@4?oooooooooo0?oooooo
9_ooool003kooooo00?o0000ooooooooool0oooooolXooooo`00<oooool6o`0000Gooooo00?o0000
ooooooooool0oooooolXooooo`00>_ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000
ooooooooool00_ooool3o`000?oooooo8?ooool003[ooooo00Go0000ooooooooooooooooo`000002
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0oooooolPooooo`00>_ooool01Ol0
003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3o
ooooob3ooooo000iooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooooooo0?oooooo8?ooool003Wooooo00Ko0000ooooooooooooEEEEofIVI_l0
0004ooooo`04o`000?ooooooooooo`000?oooooo8_ooool003Sooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`02o`000?oooooo8Oooool003Sooooo00?o0000ooooooooool02?ooool0
1?l0003oooooooooool0003oooooob;ooooo000hooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooool00000oooooolRooooo`00=oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo0000
0?oooooo8_ooool003Oooooo00?o0000ooooooooool02_ooool01?l0003oooooo`000?l0003ooooo
ob7ooooo000gooooo`03o`000?oooooooooo00[ooooo00?o0000ooooool00000oooooolRooooo`00
=_ooool00ol0003oooooooooo`0<ooooo`;o0000oooooolRooooo`00=_ooool00ol0003ooooooooo
o`0<ooooo`;o0000oooooolRooooo`00=_ooool00ol0003oooooooooo`0<ooooo`;o0000oooooolR
ooooo`00=Oooool00ol0003oooooooooo`0>ooooo`;o0000oooooolQooooo`00=Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo0?oooooo8?ooool003Gooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`3oooooob3ooooo000eooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool0oooooolPooooo`00=Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo0?oooooo8?ooool003Cooooo00?o0000ooooooooool03oooool2o`0003Gooooo0_l0003Yoooo
o`00=?ooool00ol0003oooooooooo`0?ooooo`;o0000=?ooool4o`000>Sooooo000Sooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo0_l000000oo^k^koooooooooo`03ooooo`05
odA4A?l0003o0000oc8b<_oMgMd01Oooool2o`0003Cooooo00Co0000oooooooooooo0000j?ooool0
02?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1Oooool00ol0003oEEEEojVYZ@08
ooooo`03ogMgMolb<S;ooooo00Cooooo0_l0000cooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0iOooool001_ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0ol0003oZJVYoeEEE@09ooooo`03o`000?oooooooooo00?ooooo0_l0000cooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0iOooool002?ooooo00Go0000ooooooooooooooooo`00000<
ooooo`03o`000?oooooo8B4Q00Sooooo00?oMgMgoc8b<_ooool01?ooool3o`0003;ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`3Uooooo`008oooool01Ol0003ooooooooooooooooo
000000_ooooo00Go0000ooooooooooooEEEEolc<c004ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
1Oooool00ol0003oooooo`00000aooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
iOooool002?ooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooojVYZOmg
MgL01?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo0000037ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`3Uooooo`008oooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000oooooooooooooooooc8b<P04ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ool00000<Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0>Cooooo000Sooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool5o`0000Cooooo1?l00006ooooo`03o`000?oooooo0000
033ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3Tooooo`00<oooool00ol0003o
ooooooooo`0@ooooo`?o0000<?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0>Co
oooo000booooo`03o`000?oooooooooo017ooooo00Co0000oooooooooooo0000;oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo0>Cooooo000booooo`03o`000?oooooooooo017ooooo
00Co0000oooooooooooo0000;oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02?o
oooo0_l0002oooooo`00<_ooool00ol0003oooooooooo`0Aooooo`04o`000?ooooooooooo`0002oo
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo00000;oo
oooo000booooo`03o`000?oooooooooo017ooooo00Co0000oooooooooooo0000;oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo027ooooo00Co0000oooooooooooo0000__ooool0037o
oooo00?o0000ooooooooool04_ooool2o`000003ooooool0003ooooo02gooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Qooooo`04o`000?ooooooooooo`000;kooooo000aooooo`03
o`000?oooooooooo01;ooooo00Co0000oooooooooooo0000;_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo023ooooo00Go0000ooooooooooooooooo`00002nooooo`00<Oooool00ol0
003oooooooooo`0Booooo`05o`000?ooooooooooooooool00000;Oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo023ooooo00Go0000ooooooooooooooooo`00002nooooo`00<Oooool0
0ol0003oooooooooo`0Booooo`05o`000?ooooooooooooooool00000;Oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`2kooooo`00<Oooool00ol0003oooooooooo`0Booooo`;o00000_ooool00ol0003oooooooooo`0[
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo0;_ooooo000`ooooo`03o`000?oooooooooo01?ooooo00Go0000oooo
ooooooooooooo`00000]ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Wooooo0_l0002Pooooo`00<?ooool00ol0
003oooooooooo`0Cooooo`05o`000?ooooooooooooooool00000;?ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooo00000:3ooooo000`ooooo`03o`000?oooooooooo01?ooooo00Go0000oooo
ooooooooooooo`00000/ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooool00000X?ooool0
033ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool06?ooool01?l0003oooooooooool0002Oooooo`00<?ooool00ol0
003oooooooooo`0Cooooo`;o00000oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
01Sooooo00Co0000oooooooooooo0000Woooool002oooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool06?ooool01?l0
003oooooooooool0000Fooooo`03o`000?oooooooooo08Kooooo000[ooooo`05onk^k_lb<S;o0000
oc8b<_l000001Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Hooooo`04o`000?oo
ooooooooo`0001Kooooo0_l00027ooooo`00:oooool01OmgMgOoV9RHoooooonHV9So000000Gooooo
0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooo000008Oooooo000Sooooo`Ko00000_ooool01Ol@413ooooooooo
oooooooo0000013ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo02Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooool00000Qoooool002_ooooo00Go0000oooooooooooooooo
o`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo0ol00002ooooo`03o`000?oooooooooo02Sooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01;ooooo
00Co0000oooooooooooo00004_ooool00ol0003oooooooooo`1aooooo`00:oooool01Ol0003ooooo
oooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool04_ooool01?l0003oooooooooool0000Booooo`03o`000?oooooo
oooo077ooooo000[ooooo`05oa0@4?ooooooooooo`000?l@41003?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04_ooool01?l0003oooooooooool0
000Aooooo`03o`000?oooooo000007;ooooo000[ooooo`05ogMgMonHV9Soooooo`000?mgMgL03?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04Ooo
ool01?l0003oooooooooool0000Aooooo`03o`000?oooooo000007;ooooo000[ooooo`05onk^k_lb
<S;o0000o`000?o^k^h03?ooool4o`0000Kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0@ooooo`05o`000?ooooooooooooooool000004Oooool00ol0003oooooo`00000?ooooo`;o
0000HOooool002kooooo00?o0000ooooooooool05Oooool2o`0000Cooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
4?ooool01Ol0003ooooooooooooooooo0000017ooooo00?o0000ooooool000003oooool2o`00067o
oooo000^ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0@ooooo`05o`000?ooooooooooooooool000004?ooool01?l0003oooooooooool0000?oooo
o`03o`000?oooooo000000gooooo00?o0000ooooooooool0D?ooool002kooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo013ooooo00Go0000oooooooo
ooooooooo`00000@ooooo`04o`000?ooooooooooo`0000oooooo00?o0000ooooool000003Oooool0
0ol0003oooooooooo`1@ooooo`00;_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00gooooo00Go0000ooooooooooooooooo`00000>ooooo`03o`000?oooooo000000gooooo0_l0001A
ooooo`00;Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00gooooo00Go0000oooo
ooooooooooooo`00000>ooooo`03o`000?oooooo000000gooooo0_l0000<ooooo`03o`000?oooooo
oooo04;ooooo000]ooooo`03o`000?oooooooooo01Kooooo0_l00005ooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0=ooooo`05o`000?oooooooooo
ooooool000003_ooool00ol0003oooooo`00000<ooooo`03o`000?oooooo000000cooooo00?o0000
ooooooooool0@_ooool002gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0=oooo
o`05o`000?ooooooooooooooool000003Oooool01?l0003oooooooooool0000<ooooo`03o`000?oo
oooo000000cooooo0_l0000:ooooo`;o0000=oooool002gooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0=ooooo`05o`000?ooooooooooooooool000003Oooool01?l0003ooooooooo
ool0000<ooooo`03o`000?oooooo000000_ooooo00?o0000ooooool000002_ooool2o`0000[ooooo
00?o0000ooooooooool0:_ooool002gooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool01Ol0003ooooooooo
oooooooo000000_ooooo00Co0000oooooooooooo00002_ooool00ol0003oooooo`00000:ooooo`;o
00002Oooool2o`0002cooooo000]ooooo`03o`000?oooooooooo01Kooooo0_l00005ooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool02_ooool01Ol0003ooooooooooooooooo000000_o
oooo00Co0000oooooooooooo00002_ooool00ol0003oooooo`00000:ooooo`;o00002Oooool2o`00
02cooooo000]ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0Tooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00[ooooo00Go0000ooooooooooooooooo`00000;oooo
o`04o`000?ooooooooooo`0000[ooooo00?o0000ooooool000002_ooool2o`0000Wooooo0_l0000/
ooooo`00;?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0:ooooo`05o`000?ooooooooooooooool000002oooool0
1?l0003oooooooooool0000:ooooo`03o`000?oooooo000000Wooooo00?o0000ooooool000002Ooo
ool00ol0003oooooo`00000[ooooo`00;?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool02Oooool01?l0003oooooooooool0000:ooooo`03o`000?oo
oooo000000Wooooo00?o0000ooooool000002Oooool00ol0003oooooo`00000[ooooo`00;?ooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool0
1Ol0003ooooooooooooooooo000000[ooooo00?o0000ooooool000002Oooool00ol0003oooooo`00
0009ooooo`03o`000?oooooo000002_ooooo000/ooooo`03o`000?oooooooooo01Oooooo0_l00006
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Sooooo00Go0000ooooooooooooooooo`000009ooooo`04o`000?oo
ooooooooo`0000Wooooo00?o0000ooooool000002Oooool00ol0003oooooo`00000[ooooo`00;?oo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?oo
ool01Ol0003ooooooooooooooooo000000Wooooo00Co0000oooooooooooo00002Oooool00ol0003o
ooooo`000009ooooo`03o`000?oooooo000002_ooooo000/ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool0
00002Oooool01?l0003oooooooooool00009ooooo`03o`000?oooooo000000Wooooo00?o0000oooo
ool00000:oooool002?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP04ooooo`03o`000?lQ8B7o8B4Q
00Cooooo1Ol00004ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Sooooo00Go0000ooooooooooooooooo`000009ooooo`04o`000?oo
ooooooooo`0000Wooooo00?o0000ooooool000002Oooool00ol0003oooooo`00000[ooooo`008ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo00?o0000ob4Q8OlQ8B401?ooool01OnHV9So8B4Q
onk^k_ooooooA4A400Oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`04
o`000?ooooooooooo`0000Wooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00000[
ooooo`006oooool6o`0000;ooooo00Go410@oooooooooooooooooa0@4003ooooo`03o`000?oooooo
oooo00Kooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`03ooooo`?o00001Oooool0
0ol0003oooooooooo`0Rooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool0
1?l0003oooooooooool00009ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000
:oooool002?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Oooooo
00?oV9RHob4Q8Oo^k^h01oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo
00Go0000ooooooooooooooooo`000008ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooo
oooooooo0000:oooool002?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo
oooo00Sooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01_ooool01Ol0003ooooooooooooooooo000000Sooooo00Co0000oooooooooooo
00001oooool01?l0003oooooooooool0000[ooooo`008oooool01Ol@413ooooooooooooooooo410@
00?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo000000Sooooo00Co0000
oooooooooooo00001oooool01?l0003oooooooooool0000[ooooo`008oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00?ooooo00?o0000ooooooooool01Oooool01Ol0003o^[ZjoooooonHV9So410@00Co
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`05o`000?oooooooooooooo
ool000002?ooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0002_ooooo000S
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00oooool00ol0003oooooooooo`05ooooo`05oiRHV?l@
413o0000ob4Q8Oo<c<`01?ooool4o`0000Kooooo0_l00007ooooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool0
00002?ooool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0002_ooooo000[oooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Poooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo
000000Sooooo00Co0000oooooooooooo00001oooool01?l0003oooooooooool0000[ooooo`00:ooo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool08?oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00Go0000oooooooooooooooo
o`000008ooooo`04o`000?ooooooooooo`0000Oooooo00Co0000oooooooooooo0000:oooool002[o
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo023o
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`05o`000?oooooooooooooo
ool000002?ooool01?l0003oooooooooool00007ooooo`05o`000?ooooooooooooooool00000:_oo
ool002[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`05o`000?oooooo
ooooooooool000001oooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooooooooooo
ooooo`00000Zooooo`00:_ooool00ol0003oooooooooo`0Iooooo`;o00002?ooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool01Ol0003ooooo
oooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooooooo
ooooool00000:_ooool002[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool03Oooool01om4A4Co0000o`000?lb<S;o
gMgMooooool000005_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo1Ol0
0002ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooo000000?o000000Co410@oooooooooooooooo0ol000001Olb<S;ogMgMoooooooooooo0000
00Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`05o`000?oooooooooo
ooooool000001oooool01Ol0003ooooooooooooooooo000000Gooooo1Ol000002?oooooo0000oooo
ooo^k^ko<S8bo`000?lb<S;ok^k^9?ooool002[ooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool04?ooool01?mgMgOo
<S8booooool0000Fooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0
003oooooo`000002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`05
ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0003ooooooooooomgMgOo<S8b00;ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo
00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00_ooool03OnHV9So0000onk^k_ooooooA4A4ooooool0003oooooogMgMonHV9SooooooiRHV?mg
MgL09?ooool002[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool04Oooool00ol0003oooooo`00000Fooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooo`000002ooooo`05oa0@
4?ooooooooooooooool@41001?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`05ooooo`05o`000?oooooooooooooo
ool000001Oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00Go0000ooooooooooooooooo`00
0007ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003o8B4Qonk^
kP02ooooo`03o`000?oooooo410@00?ooooo00?o410@ooooooooool08_ooool002[ooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool04?ooool01?mgMgOo<S8booooool0000Fooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03?ooool00ol0003oooooo`000002ooooo`05o`000?ooooooooooooooool00000
1?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0003o
oooooooooomgMgOo<S8b00?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Kooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool02?l0003oV9RHob4Q8Oo^k^koooooo`000?oooooo
00000oooool00ol0003oooooooooo`0Rooooo`00:Oooool00ol0003oooooooooo`0Jooooo`;o0000
2?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00gooooo00Oo0000ob4Q8Ol0003o
<S8bolc<c?oooooo000001Kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooo000000;ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Gooooo00Go0000ooooooooooooooooo`000005ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`0
0oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`08o`000?ooooooMgMgofIVI_oooooo0000ooooool00003
ooooo`03o`000?oooooooooo02;ooooo000Yooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03?ooool00ol0003oooooo`000002ooooo`05oa0@4?ooooooooooooooool@41001?ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo00So0000oooooooooooo0000ooooool0003ooooooa0@
40?ooooo00?o410@ooooooooool08_ooool002Wooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooo000000;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00_ooool2o`00000;oooooonHV9So410@ooooool0003ooooo
ogMgMonHV9SooooooiRHV?mgMgL09?ooool002Wooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool03_ooool4o`0000?o
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[o
oooo00GoEEEEofIVI_l0003oooooo`000002ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`05ooooo`05o`000?ooooooEEEEofIVI_l000001Oooool4o`0000Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00_ooool03OnHV9So0000o`000?lQ8B7oc<c<ooooool0003oooooonk^k_lb<S;o
0000oc8b<_o^k^h09?ooool002Wooooo00?o0000ooooooooool06_ooool2o`0000Wooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Sooooo000Yoooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0:?ooool002Wooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0?ooooo`;o00000_ooool2o`0001;ooooo000Yooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool03oooool01_o^k^ko8B4QohN7Qonj^[[o0000omgM
gA;ooooo000Xooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04?ooool01?oMgMgo
0000oa0@4?o<c<`Cooooo`003Oooooooo`0003[o00002oooool01?o^k^ko8B4Qoa0@4?o^k^hCoooo
o`005?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool02?ooool2o`0000cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool00ol0003oooooo`00000:ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooo000000[ooooo0_l0000;ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooool0
00002?ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo00Cooooo0_l00008oooo
o`03o`000?oooooo000000Gooooo00?o0000ooooooooool00oooool2o`0000Kooooo00?o0000oooo
ooooool00_ooool2o`0000Kooooo00Co0000oooooooooooooooo0_l00005ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool04?ooool01?lQ8B7oMgMgogMgMolb<S8Cooooo`00:?ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00cooooo00Co0000oooooooooooo00002_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo0_l00008ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0?ooooo`;o00000_oo
ool2o`0001;ooooo000Xooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09oooool0
02Sooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooo
ooooool00000<?ooool002Sooooo00?o0000ooooooooool06oooool2o`0000[ooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00Go0000oooo
ooooooooooooo`00000`ooooo`00:?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Cooooo00Go0000ooooooooooooooooo`00000`ooooo`009oooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000`ooooo`009oooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000`
ooooo`009oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooo
ooooooooooooo`00000`ooooo`009oooool00ol0003oooooooooo`0Looooo`;o00002_ooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0
003ooooooooooooooooo0000033ooooo000Wooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01?ooool01Ol0003ooooooooooooooooo0000033ooooo000Wooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000033ooooo000Woooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo
0000033ooooo000Vooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0
003ooooooooooooooooo0000033ooooo000Vooooo`03o`000?oooooooooo01gooooo0_l0000;oooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04oooo
o`05o`000?ooooooooooooooool00000<?ooool002Kooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000<?ooool002Kooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000<?ooool0
02Kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`04o`000?oooooooooo
o`00033ooooo000Vooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00Go0000ooooooooooooooooo`000008
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0
000`ooooo`009Oooool00ol0003oooooooooo`0Nooooo`;o00003?ooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`000008ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0000`ooooo`009Ooo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool000002Oooool01Ol0003ooooo
oooooooooooo000000Oooooo00Co0000oooooooooooo0000<?ooool002?ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@05
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07
ooooo`05o`000?ooooooooooooooool000002Oooool01?l0003oooooooooool00008ooooo`04o`00
0?ooooooooooo`00033ooooo000Sooooo`05ogMgMonHV9So0000oiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00Go0000oooo
ooooooooooooo`000009ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000
<?ooool002?ooooo00Go410@ooooool0003ooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo
00?o0000ooooooooool00oooool3o`0000_ooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`07ooooo`05o`000?ooooooooooooooool000002Oooool01?l0003oooooooooool00008oooo
o`04o`000?ooooooooooo`00033ooooo000Sooooo`05o`000?oooooo0000ooooool000003Oooool0
0onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`00
0009ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo0000<?ooool002?ooooo
0_l00002ooooo`03o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool00oooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`000009ooooo`04o`000?oooooooooo
o`0000Sooooo00Co0000oooooooooooo0000<?ooool002?ooooo00Go410@o`000?oooooooooooa0@
400?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool01Ol0003ooooooooo
oooooooo000000Wooooo00Co0000oooooooooooo00002?ooool01?l0003oooooooooool0000`oooo
o`008oooool01OmgMgOo0000oooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooo00002Oooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`00033ooooo000Sooooo`05onk^k_l0003o0000oc8b<_o^
k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo1?l00006ooooo`;o00003Oooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool01Ol0
003ooooooooooooooooo000000[ooooo00Co0000oooooooooooo00002Oooool01?l0003ooooooooo
ool00008ooooo`04o`000?ooooooooooo`00033ooooo000Tooooo`03o`000?oooooooooo01oooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool02_ooool01?l0003oooooooooool0000;ooooo`04o`000?ooooooooooo`00
00Wooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00000aooooo`008oooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooo00002oooool0
1?l0003oooooooooool00009ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000
<Oooool002?ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00_ooooo00Go0000ooooooooooooooooo`00000<ooooo`04o`000?ooooooooooo`0000_o
oooo00Co0000oooooooooooo00002Oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo
0000037ooooo000Sooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0;ooooo`05o`000?ooooooooooooooool000003?ooool01?l0003oooooooooool0
000;ooooo`04o`000?ooooooooooo`0000Wooooo00Co0000oooooooooooo00002?ooool00ol0003o
ooooo`00000aooooo`008oooool00ol0003oooooooooo`0Pooooo`;o00003_ooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0;ooooo`05o`000?ooooooooooooooool000003?ooool01?l0003oooooooooool0000;oooo
o`04o`000?ooooooooooo`0000Wooooo00Co0000oooooooooooo00002Oooool2o`00037ooooo000S
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00kooooo00Go0000ooooooooooooooooo`00000>ooooo`05o`000?oo
ooooooooooooool000003?ooool01?l0003oooooooooool0000;ooooo`04o`000?ooooooooooo`00
00[ooooo0_l0000:ooooo`;o0000<Oooool002?ooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03_ooool01Ol0003o
oooooooooooooooo000000kooooo00Go0000ooooooooooooooooo`00000<ooooo`04o`000?oooooo
ooooo`0000_ooooo00?o0000ooooool000002oooool2o`0000[ooooo0_l0000aooooo`008_ooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0>ooooo`05o`000?ooooooooooooooool000003_ooool01Ol0003ooooooooo
oooooooo000000cooooo00Co0000oooooooooooo00002oooool00ol0003oooooo`00000;ooooo`;o
00002_ooool00ol0003oooooooooo`0`ooooo`008_ooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Oooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0?ooooo`05o`00
0?ooooooooooooooool000003oooool01?l0003oooooooooool0000=ooooo`03o`000?oooooo0000
00_ooooo00?o0000ooooool000002oooool2o`0003gooooo000Rooooo`03o`000?oooooooooo027o
oooo0_l0000>ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03oooool01Ol0003o
oooooooooooooooo000000oooooo00Co0000oooooooooooo00003Oooool00ol0003oooooo`00000;
ooooo`03o`000?oooooo000000_ooooo0_l0000mooooo`008_ooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0?oooo
o`05o`000?ooooooooooooooool000003oooool01?l0003oooooooooool0000=ooooo`03o`000?oo
oooo000000cooooo0_l0001:ooooo`008_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0?ooooo`05o`000?oooooo
ooooooooool000003oooool01?l0003oooooooooool0000=ooooo`03o`000?oooooo000000cooooo
00?o0000ooooooooool0BOooool002;ooooo00?o0000ooooooooool08Oooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03oooool01Ol0003ooooooooo
oooooooo000000oooooo00Co0000oooooooooooo00003Oooool2o`0005Wooooo000Qooooo`03o`00
0?oooooooooo02;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo023ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00oooooo00Go0000ooooooooooooooooo`00000?ooooo`03o`000?oooooo000000ko
oooo0_l0001Iooooo`008Oooool00ol0003oooooooooo`0Rooooo`;o00003oooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo013ooooo00Co0000oooooooooooo00003oooool00ol0003o
ooooo`00001Yooooo`008Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01?ooooo
00Go0000ooooooooooooooooo`00000Cooooo`04o`000?ooooooooooo`0000oooooo00?o0000oooo
ool00000JOooool0027ooooo00?o0000ooooooooool01oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0C
ooooo`05o`000?ooooooooooooooool000004oooool00ol0003oooooo`00000Aooooo`;o0000JOoo
ool0027ooooo00?o0000ooooooooool01oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ
8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool01Ol0003ooooooooo
oooooooo000001?ooooo00?o0000ooooool00000O?ooool0027ooooo00?o0000ooooooooool01ooo
ool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool3o`0000oooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01?ooooo
00Go0000ooooooooooooooooo`00000Cooooo`03o`000?oooooo000007cooooo000Pooooo`03o`00
0?oooooooooo00Sooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool04oooool01Ol0003ooooooooooooooooo000001?ooooo00?o0000oooo
ool00000O?ooool0023ooooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooooooo0000
00cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Gooooo00Co0000
oooooooooooo00005?ooool00ol0003oooooooooo`1kooooo`008?ooool00ol0003oooooooooo`08
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Rooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo01Gooooo00Co0000oooooooooooo0000T_ooool0023ooooo00?o0000ooooooooool02?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool08_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0Eooooo`04o`000?ooooooooooo`0009;ooooo000Pooooo`03o`000?oooooooooo00Sooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001_ooool2o`00017ooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Kooooo0_l0002Cooooo`00
8?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Kooooo0_l0002Cooooo`007ooo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0TOoo
ool001oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo01_ooooo00Go0000ooooooooooooooooo`00002]ooooo`007oooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0S
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06oooool01Ol0003ooooooooooooo
oooo00000:gooooo000Oooooo`03o`000?oooooooooo02Cooooo0_l0000Aooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo01_ooooo00Co0000oooooooooooo0000[_ooool001oooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo01_ooooo00Co0000oooooooooooo0000[_oo
ool001kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooool00000[_ooool001kooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo01gooooo0_l0002_ooooo`007_ooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Tooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0c_ooool001kooooo
00?o0000ooooooooool09Oooool2o`0001;ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0c_ooool001kooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0<kooooo000M
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`3?
ooooo`007Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0Vooooo`05o`000?ooooooooooooooool00000dOooool0
01gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool09oooool01Ol0003ooooooooooooooooo00000=7ooooo000Moooo
o`03o`000?oooooooooo02Kooooo0_l0000Cooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool09oooool01Ol0003ooooooooooooooooo00000=7ooooo000Mooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
02Sooooo00?o0000ooooool00000d_ooool001cooooo00?o0000ooooooooool01?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`03o`000?o^k^kooooo00Cooooo00GoA4A4o`00
0?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0Xooooo`?o0000d_ooool001cooooo00?o0000ooooooooool01?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEEEOnYZJWooooo00Oooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool0:_ooool00ol0003oooooooooo`3Aooooo`007?ooool00ol0003oooooooooo`04oooo
o`05oa0@4?ooooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo0?kooooo000Looooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000>
ooooo`03ob4Q8Ooooooooooo00Kooooo00?oMgMgoc8b<_ooool01?ooool3o`0001?ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`3nooooo`007?ooool00ol0003oooooooooo`04oooo
o`05o`000?ooooooooooooooool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool0o_ooool001_ooooo00?o0000ooooooooool01Oooool01Ol@413ooooooooooooo
oooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3nooooo`006oooool0
0ol0003oooooooooo`05ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol@413ooooooooo
oooooooo<S8b00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0ooooool001_ooooo00?o0000ooooooooool01Ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001_ooool2o`0001Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooo`006oooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`3oooooo`006oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`3oooooo`006_ooool00ol0003oooooooooo`0Yoooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3ooooo
o`006_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`3oooooo`7ooooo000Jooooo`03o`000?oooooooooo02Wooooo
0_l0000Fooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0ooooool1ooooo`006_oo
ool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`3oooooo`7ooooo000Jooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo0_ooool0
01Wooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Gooooo`04o`000?oooooooooo
o`000?oooooo1Oooool001Wooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Goooo
o`Co0000ooooool5ooooo`006Oooool00ol0003oooooooooo`0Zooooo`;o0000oooooolQooooo`00
6Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo0?oooooo8?ooool001Wooooo00?o
0000ooooooooool0:_ooool00ol0003oooooooooo`3oooooob3ooooo000Hooooo`03o`000?oooooo
oooo02_ooooo00?o0000ooooooooool0oooooolPooooo`006?ooool00ol0003oooooooooo`0[oooo
o`03o`000?oooooooooo0?oooooo8?ooool001Sooooo00?o0000ooooooooool0:oooool2o`000?oo
oooo8Oooool001Sooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`3oooooob3ooooo
000Hooooo`03o`000?oooooooooo027ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oo
oooooooo0?oooooo8?ooool001Oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0?oooooo8?ooool001Oooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo8?ooool001Oooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`05ooooo`?o0000oooooolPooooo`00?_ooool00ol0003ooooo
ooooo`3oooooobSooooo000nooooo`03o`000?oooooooooo0?oooooo:?ooool003kooooo00?o0000
ooooooooool0oooooolXooooo`00??ooool00omEEEGoIVIVo`00003oooooob[ooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0012ooooo`?o000000?o410@oooo
ooooool0oooooolQooooo`00A?ooool00ol@413o^[Zjooooo`3oooooob;ooooo0014ooooo`03oiRH
V?lb<S;ooooo0?oooooo8_ooool004Cooooo00?ogMgMo`000?nj^[X0oooooolRooooo`00A?ooool0
0omEEEGoMgMgodA4A03oooooob;ooooo0013ooooo`05omgMgOl@413oooooob4Q8OoMgMd0oooooolQ
ooooo`00@oooool01OmVIVKoQhN7oooooonHV9SoEEEE0?oooooo8Oooool004;ooooo00?ok^k^o`00
0?o^k^h00_ooool00ol0003ogMgMooooo`3ooooooaoooooo0012ooooo`04oa0@4?l0003o0000oooo
o`;o000000?o410@ooooooooool0oooooolNooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-5.66973, -1.05832, 0.1009, \
0.0129571}}]
}, Open  ]],

Cell[TextData[{
  "This exact solution looks almost identical to the WKB solution. However, \
there is a small difference, plotted in Cell ",
  ButtonBox["5.20",
    ButtonData:>"Cell 5.20",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[Re[yexact[x, 0]\  - y[x, 0]], {x, \(-4\), 20}, 
        AxesLabel \[Rule] {"\<x\>", "\<\[CapitalDelta]y\>"}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 5.20"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.18254 0.0396825 0.305171 64.5104 [
[.38095 .29267 -3 -9 ]
[.38095 .29267 3 0 ]
[.57937 .29267 -6 -9 ]
[.57937 .29267 6 0 ]
[.77778 .29267 -6 -9 ]
[.77778 .29267 6 0 ]
[.97619 .29267 -6 -9 ]
[.97619 .29267 6 0 ]
[1.025 .30517 0 -6 ]
[1.025 .30517 10 6 ]
[.17004 .04713 -36 -4.5 ]
[.17004 .04713 0 4.5 ]
[.17004 .17615 -36 -4.5 ]
[.17004 .17615 0 4.5 ]
[.17004 .43419 -30 -4.5 ]
[.17004 .43419 0 4.5 ]
[.17004 .56321 -30 -4.5 ]
[.17004 .56321 0 4.5 ]
[.18254 .64303 -8 0 ]
[.18254 .64303 8 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.38095 .30517 m
.38095 .31142 L
s
[(5)] .38095 .29267 0 1 Mshowa
.57937 .30517 m
.57937 .31142 L
s
[(10)] .57937 .29267 0 1 Mshowa
.77778 .30517 m
.77778 .31142 L
s
[(15)] .77778 .29267 0 1 Mshowa
.97619 .30517 m
.97619 .31142 L
s
[(20)] .97619 .29267 0 1 Mshowa
.125 Mabswid
.22222 .30517 m
.22222 .30892 L
s
.2619 .30517 m
.2619 .30892 L
s
.30159 .30517 m
.30159 .30892 L
s
.34127 .30517 m
.34127 .30892 L
s
.42063 .30517 m
.42063 .30892 L
s
.46032 .30517 m
.46032 .30892 L
s
.5 .30517 m
.5 .30892 L
s
.53968 .30517 m
.53968 .30892 L
s
.61905 .30517 m
.61905 .30892 L
s
.65873 .30517 m
.65873 .30892 L
s
.69841 .30517 m
.69841 .30892 L
s
.7381 .30517 m
.7381 .30892 L
s
.81746 .30517 m
.81746 .30892 L
s
.85714 .30517 m
.85714 .30892 L
s
.89683 .30517 m
.89683 .30892 L
s
.93651 .30517 m
.93651 .30892 L
s
.14286 .30517 m
.14286 .30892 L
s
.10317 .30517 m
.10317 .30892 L
s
.06349 .30517 m
.06349 .30892 L
s
.02381 .30517 m
.02381 .30892 L
s
.25 Mabswid
0 .30517 m
1 .30517 L
s
gsave
1.025 .30517 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.18254 .04713 m
.18879 .04713 L
s
[(-0.004)] .17004 .04713 1 0 Mshowa
.18254 .17615 m
.18879 .17615 L
s
[(-0.002)] .17004 .17615 1 0 Mshowa
.18254 .43419 m
.18879 .43419 L
s
[(0.002)] .17004 .43419 1 0 Mshowa
.18254 .56321 m
.18879 .56321 L
s
[(0.004)] .17004 .56321 1 0 Mshowa
.125 Mabswid
.18254 .07938 m
.18629 .07938 L
s
.18254 .11164 m
.18629 .11164 L
s
.18254 .14389 m
.18629 .14389 L
s
.18254 .20841 m
.18629 .20841 L
s
.18254 .24066 m
.18629 .24066 L
s
.18254 .27292 m
.18629 .27292 L
s
.18254 .33743 m
.18629 .33743 L
s
.18254 .36968 m
.18629 .36968 L
s
.18254 .40194 m
.18629 .40194 L
s
.18254 .46645 m
.18629 .46645 L
s
.18254 .4987 m
.18629 .4987 L
s
.18254 .53096 m
.18629 .53096 L
s
.18254 .01487 m
.18629 .01487 L
s
.18254 .59547 m
.18629 .59547 L
s
.25 Mabswid
.18254 0 m
.18254 .61803 L
s
gsave
.18254 .64303 -69 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(D) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
75.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .43709 m
.03279 .49649 L
.04262 .54669 L
.04758 .56597 L
.05288 .58208 L
.05546 .58824 L
.05789 .59307 L
.06024 .59684 L
.06244 .59958 L
.06371 .60082 L
.06487 .60173 L
.06616 .6025 L
.06687 .60282 L
.06754 .60305 L
.06819 .60321 L
.06888 .60331 L
.07013 .60332 L
.07089 .60321 L
.07161 .60304 L
.07225 .60282 L
.07295 .60251 L
.07412 .60185 L
.07541 .6009 L
.078 .59831 L
.0804 .59514 L
.08265 .59153 L
.08819 .58011 L
.09323 .56688 L
.10458 .52927 L
.12528 .44556 L
.13438 .40868 L
.14443 .37189 L
.15337 .34466 L
.15807 .33295 L
.16301 .32276 L
.16555 .31843 L
.16832 .31439 L
.17088 .31133 L
.17319 .30909 L
.17559 .30732 L
.1769 .30658 L
.17815 .30602 L
.1793 .30563 L
.18036 .30538 L
.18152 .30522 L
.18275 .30517 L
.18396 .30526 L
.18528 .30549 L
.18653 .30584 L
.18769 .30627 L
Mistroke
.18987 .30737 L
.19219 .30891 L
.19751 .31373 L
.20233 .31938 L
.22064 .34513 L
.22553 .35117 L
.2282 .35399 L
.23069 .35623 L
.233 .35792 L
.2351 .35911 L
.2363 .35962 L
.23743 .36 L
.23863 .36026 L
.23993 .36039 L
.24122 .36036 L
.24243 .36018 L
.24312 .36001 L
.24375 .35981 L
.24518 .3592 L
.24648 .35846 L
.2479 .35743 L
.25076 .35466 L
.25326 .35144 L
.25594 .34718 L
.26076 .33738 L
.27103 .30774 L
.28215 .26485 L
.29176 .22324 L
.30231 .17965 L
.30728 .16226 L
.31001 .15401 L
.31261 .14725 L
.31501 .142 L
.31628 .13966 L
.31764 .13752 L
.31877 .13601 L
.32002 .13465 L
.32116 .13371 L
.32223 .1331 L
.32345 .13271 L
.32415 .13264 L
.3248 .13268 L
.32611 .13308 L
.32684 .13348 L
.32751 .13396 L
.3287 .1351 L
.33 .13675 L
.33235 .14083 L
.33511 .14744 L
.33804 .15661 L
Mistroke
.34328 .17855 L
.3527 .23422 L
.36283 .31169 L
.38114 .45914 L
.38603 .49073 L
.39125 .51684 L
.3928 .5228 L
.39425 .52759 L
.39567 .53144 L
.39698 .53427 L
.39822 .5363 L
.39953 .53772 L
.40084 .53839 L
.40159 .53842 L
.40229 .53823 L
.40354 .53732 L
.40424 .53649 L
.40489 .53551 L
.40609 .5332 L
.40736 .53002 L
.40956 .52272 L
.41199 .51205 L
.41735 .47906 L
.42238 .43729 L
.44087 .2295 L
.44594 .17158 L
.45135 .11712 L
.45397 .09477 L
.45645 .07673 L
.45866 .06345 L
.46109 .05219 L
.46235 .04782 L
.46352 .04466 L
.46476 .04234 L
.46546 .04151 L
.4661 .04104 L
.46723 .04091 L
.46847 .0418 L
.46963 .04365 L
.47071 .04624 L
.47208 .05071 L
.47337 .05614 L
.47577 .06942 L
.47835 .08817 L
.48114 .11331 L
.49214 .25182 L
.50225 .40353 L
.50697 .46874 L
.50956 .50039 L
.51202 .52663 L
Mistroke
.5143 .54728 L
.51679 .56504 L
.51788 .5712 L
.51904 .57657 L
.52003 .58016 L
.52113 .58305 L
.52178 .58423 L
.5225 .58504 L
.52381 .5852 L
.52508 .58372 L
.52627 .58088 L
.52699 .57846 L
.52767 .57569 L
.52895 .56928 L
.5318 .54915 L
.5343 .52524 L
.53661 .49844 L
.54181 .42361 L
.55089 .265 L
.55589 .17779 L
.56062 .10589 L
.5633 .07281 L
.56471 .05807 L
.56621 .04471 L
.56747 .03543 L
.56886 .02734 L
.57012 .02203 L
.57131 .01886 L
.57253 .0175 L
.57381 .01816 L
.57491 .02044 L
.57611 .02474 L
.5774 .03152 L
.57879 .04115 L
.58128 .06455 L
.60119 .42299 L
.60664 .51649 L
.60939 .55224 L
.61097 .56839 L
.61241 .58005 L
.61374 .58796 L
.61499 .59295 L
.61568 .59461 L
.61632 .59547 L
.61702 .59563 L
.61776 .59492 L
.61841 .59355 L
.61912 .59128 L
.62039 .58509 L
.62163 .57653 L
Mistroke
.62277 .56649 L
.62509 .53993 L
.62757 .50307 L
.63204 .41856 L
.64221 .19054 L
.64486 .13668 L
.64773 .08656 L
.64905 .06732 L
.65045 .04985 L
.65165 .03739 L
.65295 .0269 L
.65421 .01978 L
.65536 .01594 L
.65645 .01472 L
.65761 .01604 L
.65888 .0206 L
.66006 .02774 L
.66135 .03874 L
.66274 .05402 L
.67243 .24291 L
.67773 .37556 L
.68268 .48775 L
.68526 .53405 L
.68659 .55333 L
.68804 .57038 L
.68886 .57808 L
.68961 .5839 L
.69034 .58824 L
.69111 .59152 L
.6918 .59326 L
.69245 .59387 L
.69316 .59339 L
.69392 .59151 L
.69518 .58539 L
.69589 .58027 L
.69655 .57442 L
.69789 .55956 L
.69932 .53932 L
.70428 .43964 L
.70944 .3046 L
.71505 .15792 L
.71762 .102 L
.71903 .07642 L
.72035 .05629 L
.72156 .04134 L
.72267 .0309 L
.72391 .02313 L
.72459 .02062 L
.72523 .01942 L
.72643 .02029 L
Mistroke
.72752 .02459 L
.72878 .03364 L
.72996 .04609 L
.73207 .07723 L
.73435 .12253 L
.73949 .2567 L
.7443 .39565 L
.74889 .50915 L
.75021 .53431 L
.75146 .55411 L
.75258 .56822 L
.75381 .57934 L
.75506 .58596 L
.75577 .58751 L
.75644 .58748 L
.75714 .5859 L
.75778 .58305 L
.75848 .5784 L
.75923 .57179 L
.76047 .55695 L
.76162 .53904 L
.76424 .48519 L
.76944 .33948 L
.77508 .1696 L
.77766 .10525 L
.77908 .07681 L
.7804 .05544 L
.78153 .04164 L
.78274 .03164 L
.78343 .02827 L
.78408 .02666 L
.78531 .02788 L
.7866 .03513 L
.78777 .0469 L
.78842 .05549 L
.78912 .06638 L
.79039 .09011 L
.7951 .21466 L
.80029 .38265 L
.80313 .46647 L
.80451 .50127 L
.80577 .52827 L
.80684 .5472 L
.808 .56314 L
.80923 .57438 L
.81039 .57945 L
.81167 .57861 L
.81232 .57562 L
.81303 .57035 L
.81428 .55605 L
Mistroke
.81546 .53712 L
.8177 .48778 L
.81975 .42993 L
.82436 .2756 L
.82681 .194 L
.82912 .12663 L
.8304 .09564 L
.83178 .06846 L
.83304 .05027 L
.83419 .03948 L
.83529 .0348 L
.83631 .03541 L
.83743 .04162 L
.83863 .05463 L
.83989 .075 L
.84109 .10023 L
.84333 .16088 L
.84814 .32644 L
.85077 .41837 L
.85325 .49209 L
.85453 .52247 L
.85591 .54776 L
.85666 .55785 L
.85745 .5656 L
.85812 .56979 L
.85885 .57176 L
.86015 .56847 L
.86088 .56287 L
.86154 .55548 L
.86283 .53504 L
.86405 .50886 L
.87375 .17714 L
.87611 .10773 L
.87744 .07825 L
.87865 .05856 L
.87933 .0508 L
.88008 .04521 L
.88078 .04275 L
.88143 .04295 L
.8827 .05014 L
.8834 .058 L
.88404 .06744 L
.8852 .08987 L
.88642 .12041 L
.88861 .18959 L
.89354 .37794 L
.8956 .45096 L
.89781 .51345 L
.89907 .53915 L
.90023 .55495 L
Mistroke
.90139 .56293 L
.90249 .56291 L
.90363 .55503 L
.90486 .53778 L
.90602 .51368 L
.90708 .48554 L
.91215 .29926 L
.91475 .19719 L
.91716 .11809 L
.91837 .088 L
.91967 .06502 L
.92041 .05655 L
.92111 .05183 L
.92242 .05174 L
.92348 .06013 L
.92465 .07786 L
.92588 .10527 L
.92702 .1382 L
.93126 .30099 L
.93363 .39858 L
.93588 .47813 L
.93712 .51221 L
.93778 .52665 L
.93848 .53904 L
.93971 .55288 L
.94084 .55612 L
.9419 .55067 L
.94307 .53548 L
.94428 .50989 L
.94541 .47802 L
.9496 .31427 L
.95195 .21434 L
.95417 .1334 L
.9554 .09909 L
.95605 .08479 L
.95673 .07277 L
.95794 .06 L
.95906 .05826 L
.96012 .06563 L
.96109 .07989 L
.96221 .10475 L
.96327 .13591 L
.96721 .29467 L
.96929 .38614 L
.9715 .47076 L
.97278 .50796 L
.97393 .5321 L
.9751 .54596 L
.97619 .54882 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003o@oooool0
0ol0003oooooooooo`3oooooob?ooooo0013ooooo`03o`000?oooooooooo0?oooooo8oooool004?o
oooo00?o0000ooooooooool0oooooolSooooo`00@oooool00ol0003oooooooooo`3oooooob?ooooo
0013ooooo`03o`000?oooooooooo0?oooooo8oooool004?ooooo0_l0002Fooooo`03o`000?oooooo
oooo08[ooooo0013ooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool05oooool2o`00
01Gooooo00?o0000ooooooooool0M?ooool004?ooooo00?o0000ooooooooool0NOooool00ol0003o
ooooo`00000Hooooo`03o`000?oooooo000001Cooooo00?o0000ooooooooool0M?ooool004?ooooo
00?o0000ooooooooool0NOooool00ol0003oooooo`00000Hooooo`03o`000?oooooo000001Cooooo
0_l0001eooooo`00@oooool00ol0003oooooooooo`1iooooo`03o`000?oooooo000001Sooooo00?o
0000ooooool000005?ooool2o`00017ooooo00?o0000ooooooooool0HOooool004?ooooo00?o0000
ooooooooool0NOooool01?l0003oooooooooool0000Gooooo`03o`000?oooooo000001?ooooo00?o
0000ooooool000004?ooool2o`0006?ooooo0013ooooo`03o`000?oooooooooo07Sooooo00Go0000
ooooooooooooooooo`00000Fooooo`04o`000?ooooooooooo`0001?ooooo00?o0000ooooool00000
4?ooool00ol0003oooooo`00000>ooooo`;o0000D_ooool004?ooooo00?o0000ooooooooool0N?oo
ool01Ol0003ooooooooooooooooo000001Kooooo00Go0000ooooooooooooooooo`00000Booooo`03
o`000?oooooo0000013ooooo00?o0000ooooool000003_ooool2o`0005;ooooo000Hooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000
ooooooooool0F?ooool00ol0003oooooooooo`0Mooooo`05o`000?ooooooooooooooool000005_oo
ool01Ol0003ooooooooooooooooo000001;ooooo00?o0000ooooool000004?ooool00ol0003ooooo
o`00000>ooooo`;o0000D_ooool001Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Eoooool00ol0003oooooo`00000Noooo
o`05o`000?ooooooooooooooool000005_ooool01Ol0003ooooooooooooooooo000001;ooooo00Co
0000oooooooooooo00003oooool00ol0003oooooo`00000>ooooo`;o00003Oooool00ol0003ooooo
ooooo`12ooooo`004?ooool6o`0000;ooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@
4?ooooooooooooooool@41000oooool01Ol@413ooooooooooooooooo410@00?ooooo1Ol00006oooo
o`?o0000Eoooool00ol0003oooooo`00000Nooooo`05o`000?ooooooooooooooool000005_ooool0
1Ol0003ooooooooooooooooo000001;ooooo00Co0000oooooooooooo00003oooool00ol0003ooooo
o`00000>ooooo`;o00003Oooool00ol0003oooooooooo`12ooooo`006?ooool01Ol0003ooooooooo
oooooooo000000_ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool000000oooool01?m4A4CogMgMooooool00007ooooo`03o`000?oooooooooo05Oooooo00Co0000
oooooooooooo00007Oooool01Ol0003ooooooooooooooooo000001Kooooo00Go0000oooooooooooo
ooooo`00000Aooooo`05o`000?ooooooooooooooool000003oooool00ol0003oooooo`00000>oooo
o`;o00003?ooool00ol0003oooooo`000013ooooo`006?ooool01Ol0003ooooooooooooooooo0000
00_ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000ooo
ool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo05Kooooo00Go0000oooooooooooo
ooooo`00000Mooooo`05o`000?ooooooooooooooool000005_ooool01Ol0003ooooooooooooooooo
0000017ooooo00Go0000ooooooooooooooooo`00000?ooooo`03o`000?oooooo000000kooooo0_l0
000<ooooo`03o`000?oooooo000000_ooooo00?o0000ooooooooool0=Oooool001Sooooo00Go410@
oooooooooooooooooa0@400;ooooo`05oa0@4?ooooooooooooooool@41000oooool01Ol@413ooooo
oooooooooooo410@00Cooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`1Fooooo`05
o`000?ooooooooooooooool000007Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
01?ooooo00Go0000ooooooooooooooooo`00000Aooooo`05o`000?ooooooooooooooool000003ooo
ool00ol0003oooooo`00000>ooooo`;o00003?ooool00ol0003oooooo`00000;ooooo`03o`000?oo
oooooooo03Gooooo000Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`03onk^k_m4A4Co000000Oo
oooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Cooooo`05o`000?oooooooooooooo
ool000004Oooool01Ol0003ooooooooooooooooo000000oooooo00?o0000ooooool000003_ooool2
o`0000cooooo00?o0000ooooool000002oooool2o`0000[ooooo00?o0000ooooooooool0:Oooool0
01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00ooo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?oMgMgo`000?ooool01_ooool00ol0003ooooo
ooooo`1Eooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo01?ooooo00Go0000ooooooooooooooooo`00000Aooooo`05
o`000?ooooooooooooooool000003oooool01?l0003oooooooooool0000<ooooo`03o`000?oooooo
000000cooooo00?o0000ooooool000002_ooool00ol0003oooooo`00000:ooooo`03o`000?oooooo
oooo02Wooooo0013ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04oooool01Ol0
003ooooooooooooooooo0000017ooooo00Go0000ooooooooooooooooo`00000?ooooo`04o`000?oo
ooooooooo`0000cooooo00?o0000ooooool000003?ooool00ol0003oooooo`00000:ooooo`03o`00
0?oooooo000000[ooooo00?o0000ooooooooool0:Oooool004?ooooo00?o0000ooooooooool0EOoo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0Cooooo`05o`000?ooooooooooooooool000004Oooool01Ol0003ooooo
oooooooooooo000000kooooo00Go0000ooooooooooooooooo`00000<ooooo`04o`000?oooooooooo
o`0000_ooooo00?o0000ooooool000002_ooool00ol0003oooooo`000009ooooo`;o0000:oooool0
04?ooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Cooooo`05o`000?oooooooooo
ooooool000004Oooool01Ol0003ooooooooooooooooo000000kooooo00Go0000oooooooooooooooo
o`00000<ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooool000002_ooool00ol0003o
ooooo`000009ooooo`;o0000:oooool004?ooooo00?o0000ooooooooool0EOooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0Cooooo`05o`000?ooooooooooooooool000004Oooool01Ol0003ooooooooooooooooo0000
00kooooo00Go0000ooooooooooooooooo`00000<ooooo`04o`000?ooooooooooo`0000_ooooo00?o
0000ooooool000002_ooool00ol0003oooooo`000009ooooo`03o`000?oooooo000002[ooooo0013
ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool01Ol0003ooooooooooooo
oooo0000017ooooo00Go0000ooooooooooooooooo`00000>ooooo`05o`000?ooooooooooooooool0
00003?ooool01?l0003oooooooooool0000;ooooo`03o`000?oooooo000000[ooooo00?o0000oooo
ool000002Oooool00ol0003oooooo`00000Zooooo`00@oooool2o`0005Kooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00oooooo00Go0000oooooooo
ooooooooo`00000>ooooo`05o`000?ooooooooooooooool000003?ooool01?l0003oooooooooool0
000;ooooo`03o`000?oooooo000000[ooooo00?o0000ooooool000002Oooool00ol0003oooooo`00
000Zooooo`00@oooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0?ooooo`05o`000?ooooooooooooooool000003_oo
ool01Ol0003ooooooooooooooooo000000cooooo00Co0000oooooooooooo00002oooool00ol0003o
ooooo`00000:ooooo`03o`000?oooooo000000Wooooo00?o0000ooooool00000:_ooool004?ooooo
00?o0000ooooooooool0EOooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool03_ooool01Ol0003ooooooooooooooooo000000kooooo00Go0000oooooooo
ooooooooo`00000<ooooo`04o`000?ooooooooooo`0000_ooooo00?o0000ooooool000002_ooool0
0ol0003oooooo`000009ooooo`03o`000?oooooo000002[ooooo0013ooooo`03o`000?oooooooooo
05Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00kooooo00Go0000ooooooooooooooooo`00000>ooooo`05o`000?ooooooooooooooool000003?oo
ool01?l0003oooooooooool0000;ooooo`03o`000?oooooo000000[ooooo00?o0000ooooool00000
2Oooool00ol0003oooooo`00000Zooooo`00@oooool00ol0003oooooooooo`1Dooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0>ooooo`05o`000?oo
ooooooooooooool000003_ooool01Ol0003ooooooooooooooooo000000cooooo00Co0000oooooooo
oooo00002oooool00ol0003oooooo`00000:ooooo`03o`000?oooooo000000Wooooo00?o0000oooo
ool00000:_ooool004?ooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool03_ooool01Ol0003ooooooooooooooooo0000
00kooooo00Go0000ooooooooooooooooo`00000<ooooo`04o`000?ooooooooooo`0000[ooooo00Co
0000oooooooooooo00002_ooool00ol0003oooooo`000009ooooo`03o`000?oooooo000002[ooooo
0013ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00kooooo00Go0000ooooooooooooooooo`00000>ooooo`05o`00
0?ooooooooooooooool000003?ooool01?l0003oooooooooool0000:ooooo`04o`000?oooooooooo
o`0000[ooooo00?o0000ooooool000002Oooool00ol0003oooooo`00000Zooooo`00@oooool00ol0
003oooooooooo`1Dooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02oooool01Ol0
003ooooooooooooooooo000000cooooo00Co0000oooooooooooo00002_ooool01?l0003ooooooooo
ool0000:ooooo`03o`000?oooooo000000Wooooo00?o0000ooooool00000:_ooool004?ooooo00?o
0000ooooooooool0E?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00_ooooo00Go
0000ooooooooooooooooo`00000<ooooo`04o`000?ooooooooooo`0000[ooooo00Co0000oooooooo
oooo00002_ooool00ol0003oooooo`000009ooooo`03o`000?oooooo000002[ooooo0013ooooo`03
o`000?oooooooooo05?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0;ooooo`05
o`000?ooooooooooooooool000003?ooool01?l0003oooooooooool0000:ooooo`05o`000?oooooo
ooooooooool000002Oooool00ol0003oooooo`000009ooooo`03o`000?oooooo000002[ooooo0013
ooooo`;o0000E?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00_ooooo00Go0000
ooooooooooooooooo`00000<ooooo`04o`000?ooooooooooo`0000[ooooo00Go0000oooooooooooo
ooooo`000009ooooo`03o`000?oooooo000000Wooooo00?o0000ooooool00000:_ooool004?ooooo
00?o0000ooooooooool0Doooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00_ooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?ooooooooooooooool000002_ooool01Ol0
003ooooooooooooooooo000000Wooooo00?o0000ooooool000002Oooool00ol0003oooooo`00000Z
ooooo`00@oooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool02oooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`00
000:ooooo`05o`000?ooooooooooooooool000002Oooool00ol0003oooooo`000009ooooo`03o`00
0?oooooo000002[ooooo0013ooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003ooooo
oooooooooooo000000[ooooo00Go0000ooooooooooooooooo`000009ooooo`03o`000?oooooo0000
00Wooooo00?o0000ooooool00000:_ooool004?ooooo00?o0000ooooooooool0Doooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`00000;oooo
o`05o`000?ooooooooooooooool000002_ooool01Ol0003ooooooooooooooooo000000Wooooo00Co
0000oooooooooooo00002?ooool00ol0003oooooo`00000Zooooo`00@oooool00ol0003ooooooooo
o`1Cooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02oooool01Ol0003ooooooooo
oooooooo000000_ooooo00Go0000ooooooooooooooooo`00000:ooooo`05o`000?oooooooooooooo
ool000002Oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo000002[ooooo0013oooo
o`03o`000?oooooooooo05?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0;oooo
o`05o`000?ooooooooooooooool000002oooool01Ol0003ooooooooooooooooo000000[ooooo00Go
0000ooooooooooooooooo`000009ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool0
0000:_ooool004?ooooo00?o0000ooooooooool0:Oooool4o`0002Gooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool000002oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`000009oooo
o`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool00000:_ooool004?ooooo00?o0000oooo
ooooool0:?ooool2o`0000;ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`00000;ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo000000Wooooo00Co
0000oooooooooooo00002?ooool00ol0003oooooo`00000Zooooo`00@oooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool01Ol0003ooooooooo
oooooooo000000Wooooo00Co0000oooooooooooo00002?ooool00ol0003oooooo`00000Zooooo`00
@oooool2o`0002Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Rooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`05o`00
0?ooooooooooooooool000002Oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo0000
02[ooooo0013ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`07ooooo`05o`000?ooooooooooooooool000002Oooool01?l0003oooooooooool00008
ooooo`03o`000?oooooo000002[ooooo0013ooooo`03o`000?oooooooooo02Oooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool000002Oooool0
1?l0003oooooooooool00008ooooo`03o`000?oooooo000002[ooooo0013ooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`05o`000?oooooo
ooooooooool000002Oooool01?l0003oooooooooool00008ooooo`03o`000?oooooo000002[ooooo
0013ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`07ooooo`05o`000?ooooooooooooooool000002Oooool01?l0003oooooooooool00008ooooo`03
o`000?oooooo000002[ooooo0013ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool000002?ooool01Ol0003o
oooooooooooooooo000000Sooooo00?o0000ooooool00000:_ooool004?ooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00Go0000oooooooo
ooooooooo`000008ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003oooooo`00000Z
ooooo`00@oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool01oooool01Ol0003ooooooooooooooooo000000Sooooo00Go0000ooooooooooooooooo`00
0008ooooo`03o`000?oooooo000002[ooooo000Hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h00oooool5o`0000Kooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo01kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`000008ooooo`05o`000?oooooooooo
ooooool000002?ooool00ol0003oooooo`00000Zooooo`006?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B44ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`05o`000?oooooooooooooo
ool000002?ooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooool00000:_ooool0
013ooooo1_l00002ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413ooooooooooooo
oooo410@00?ooooo00Go410@oooooooooooooooooa0@4004ooooo`03oiRHV?lQ8B7ok^k^00Oooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo
00Go0000ooooooooooooooooo`000008ooooo`05o`000?ooooooooooooooool000002?ooool00ol0
003oooooo`00000Zooooo`006?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000001Oooool00onHV9So8B4Qonk^
kP06ooooo`?o00008oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01kooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00Go
0000ooooooooooooooooo`000008ooooo`05o`000?ooooooooooooooool000001oooool01?l0003o
ooooooooool0000Zooooo`006?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000001_ooool00omgMgOoIVIVoooo
o`05ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`07ooooo`05o`000?ooooooooooooooool000002?ooool01Ol0003ooooooooooooooooo000000Oo
oooo00Go0000ooooooooooooooooo`00000Yooooo`006?ooool01Ol@413ooooooooooooooooo410@
00_ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?ooooooooooooooool@41001ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool000002?ooool01Ol0003ooooo
oooooooooooo000000Oooooo00Go0000ooooooooooooooooo`00000Yooooo`006?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`03ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL00oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00Go0000oooooooooooo
ooooo`000008ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo
000002Wooooo000Hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`01_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01oooool01Ol0003ooooooooooooooooo000000Sooooo00Go0000ooooooooooooooooo`000007
ooooo`05o`000?ooooooooooooooool00000:Oooool004?ooooo00?o0000ooooooooool08_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`00
0008ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo000002Wo
oooo0013ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`07ooooo`05o`000?ooooooooooooooool000002?ooool01Ol0003ooooooooooooooooo0000
00Oooooo00Go0000ooooooooooooooooo`00000Yooooo`00@oooool00ol0003oooooooooo`0Roooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo
000000Sooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool00000
:Oooool004?ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Oooooo00Go0000ooooooooooooooooo`000008ooooo`05o`000?ooooooooooooooool0
00001oooool01Ol0003ooooooooooooooooo000002Wooooo0013ooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`05o`000?oooooooooooooo
ool000002?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`00
000Yooooo`00@oooool2o`0002;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07
ooooo`05o`000?ooooooooooooooool000002?ooool01Ol0003ooooooooooooooooo000000Oooooo
00Go0000ooooooooooooooooo`00000Yooooo`00@oooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooooooo000000So
oooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool00000:Oooool0
04?ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Oooooo00Go0000ooooooooooooooooo`000008ooooo`05o`000?ooooooooooooooool000001ooo
ool01Ol0003ooooooooooooooooo000002Wooooo0013ooooo`03o`000?oooooooooo027ooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool00000
2?ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000ooooooooooooooooo`00000Yoooo
o`00@oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000:Oooool004?ooooo00?o0000oooo
ooooool08?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00Go0000oooo
ooooooooooooo`000008ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool0
1Ol0003ooooooooooooooooo000002Wooooo0013ooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool000002?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooooooo
o`00000Yooooo`00@oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01oooool01Ol0003ooooooooooooooooo000000Sooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000:Oooool004?ooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo
00Go0000ooooooooooooooooo`000008ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool01Ol0003ooooooooooooooooo000002Wooooo0013ooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00Go0000ooooooooooooooooo`00000Yooooo`00@oooool2o`00023ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooo
ooooooooo`00000Yooooo`00@oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?oooooooooooooo
ool00000:Oooool004?ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000
02Wooooo0013ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00000Yoooo
o`00@oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool00000:Oooool004?o
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000002Wooooo0013ooooo`03
o`000?oooooooooo01kooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Vooooo`00
@oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
9_ooool004?ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo00?ooooo00GoA4A4o`000?l0003o<S8bomgMg@0?ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`04o`000005oa0@4?ooooooooooonk^k_lb
<S800_l000000oo^k^koooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo1Ol00003ooooo`05
odA4A?l0003o0000oc8b<_l000002?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01?ooool6o`0000?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0P
ooooo`00@oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool01_ooool00omgMgOo<S8booooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRH
V?oooooo0000ogMgM`0=ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000001_ooool0
0omgMgOo0000ooooo`07ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`07o`000?ooooooV9RHob4Q8Oo^k^koooooo`000003ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL08?ooool004?ooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooo`000?l@41003Oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooo000000Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool01ol0003ooooooooooonHV9So8B4Q
onk^k_l000000oooool01Ol@413ooooooooooooooooo410@023ooooo0013ooooo`;o00007Oooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Kooooo00?oMgMgoc8b<_ooool03_ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o00003Oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooo000000Kooooo00?oMgMgo`000?ooool01oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool01ol0003ooooooooooooo
ooooV9RHob4Q8Ol000000oooool01Ol0003ooooooooooooooooo0000023ooooo0013ooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`03ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000003Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000?ooooo00Go0000ob4Q
8Ol0003o<S8bo`000008ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?oMgMgo`000?ooool00_ooool0
1Ol0003ooooooooooooooooo0000023ooooo0013ooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00_ooool01Ol@413ooooooooooooooooo000000gooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooo`000003ooooo`05o`000?ooooooooooooooool000002?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`05o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`0Nooooo`00
@oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?oooooo
V9RHo`00000=ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool000000oooool01Ol0003o
oooooooooooooooo000000Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00Oo0000ooooool0003o^[ZjoooooonHV9So000000?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0Pooooo`00@oooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool00_ooool4o`0000oooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`0?ooooo`06o`000?oooooooooooeEEEOmVIVKo00001?ooool01Oo^k^ko
<S8bo`000?lb<S;o000000gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool01OmEEEGoIVIVo`000?oooooo
000000?ooooo1Ol00008ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`07o`000?ooooooV9RHoa0@4?l0003o8B4Qo`000003ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h08?ooool004?ooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo02Kooooo0013ooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Vooooo`00@oooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04oooool2o`0000;ooooo0_l0000=
ooooo`00@oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool04oooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@gooooo0013ooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Dooooo`04omgMgOl0003o
410@olc<c0kooooo0008oooooooo0000@ol0000<ooooo`04onk^k_lQ8B7o410@onk^kPkooooo000@
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00Oooooo0_l000000ooooooo0000ooooo`02o`0000Wooooo00?o0000
ooooooooool02Oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooool000002oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool0
00002?ooool2o`0000Sooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooo000000Kooooo00Co0000oooooooooooo00001?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooo000000Cooooo00?o0000ooooooooool00oooool00ol0003oooooo`000003
ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00004oooool01?lQ8B7oMgMgogMg
Molb<S8>ooooo`00?oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1_ooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool01?l0003oooooooooool0000Booooo`;o00000_ooool2o`0000gooooo000nooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool09_ooool003gooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Vooooo`00?Oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo02Kooooo000mooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09_ooool0
03gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Vooooo`00??ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0Nooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo02Kooooo000kooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01oooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool09_ooool003_ooooo00?o0000ooooooooool01Oooool2o`0000Oooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Kooooo000j
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09_ooool003[ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool08?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Vooooo`00>Oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo02Kooooo000iooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
9_ooool003Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Vooooo`00>?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Kooooo000hooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool03Oooool2o`0000;ooooo0_l0000Vooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
02Kooooo000hooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03_ooool3o`0002So
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool09_ooool003Sooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0iooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo02Kooooo000gooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool0>Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0Vooooo`00=oooool00ol0003oooooooooo`09
ooooo`;o0000>_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0Vooooo`00=oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo03Wooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09_ooool003Kooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Kooooo000fooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Vooooo`00=_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool09_oo
ool003Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0jooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo02Kooooo000eooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0>_ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Vooooo`00=Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03[o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool09_ooool003Cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0jooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo02Kooooo000dooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`0Vooooo`00=?ooool00ol0003oooooooooo`0<ooooo`;o0000??oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooo
ooooo`0Vooooo`00<oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0
9_ooool003?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Gooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo02Kooooo
000cooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0>oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`05ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0Vooooo`00<ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Ooo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool09_ooool003;ooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01_ooool01Ol0003ooooooooooooooooo000000Oooooo00Go0000oooooooooooo
ooooo`000006ooooo`03o`000?oooooooooo02Kooooo000booooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool0>oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo
00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool000001_ooool00ol0
003oooooooooo`0Vooooo`00<_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03co
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`05o`000?oooooooooooooo
ool000001oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool09_ooool0
01Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`Go00001_ooool00ol0003ooooo
ooooo`0looooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01_ooool01Ol0003ooooo
oooooooooooo000000Oooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo
02Kooooo000Hooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`03ooooo`05ogMgMol0003ooooooiRHV?mgMgL00oooool01OnHV9So8B4Qonk^
k_ooooooA4A400Kooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Kooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?oooooooooooooo
ool000001oooool00ol0003oooooooooo`0Uooooo`006?ooool01Ol@413ooooooooooooooooo410@
00_ooooo00Go410@oooooooooooooooooa0@4003ooooo`05oa0@4?l0003oooooooooool@41001?oo
ool00onHV9So8B4Qonk^kP07ooooo`?o0000??ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Kooooo00Go0000ooooooooooooooooo`000007ooooo`05o`000?ooooooooooooooool0
00001oooool00ol0003oooooooooo`0Uooooo`004?ooool00ol0003oooooooooo`05ooooo`05o`00
0?ooooooooooooooool000002oooool01Ol0003ooooooooooooooooo000000?ooooo0_l00002oooo
o`03o`000?oooooooooo00?ooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`0loooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo
000000Oooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo02Gooooo000@
ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?oo
ooooooooooooool000000oooool2o`0000;ooooo00?o0000ooooooooool01?ooool00omgMgOoIVIV
ooooo`05ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`06ooooo`05o`000?ooooooooooooooool000001oooool01Ol0003ooooooooooooooooo0000
00Oooooo00?o0000ooooooooool09Oooool0013ooooo00?o0000ooooooooool01Oooool01Ol@413o
oooooooooooooooo410@00_ooooo00Go410@oooooooooooooooooa0@4003ooooo`05o`000?oooooo
ooooooooool@41001oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03cooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`04o`000?ooooooooooo`0000Wooooo
00Co0000oooooooooooo00001oooool00ol0003oooooooooo`0Uooooo`004?ooool00ol0003ooooo
ooooo`05ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00?ooooo00Go0000oiRHV?ooooooV9RHogMgM`03ooooo`05o`000?nj^[[ooooooiRHV?l@41001_oo
ool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01_oo
ool01?l0003oooooooooool00009ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000oooooooo
ool09Oooool0017ooooo00?o0000ooooooooool01?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`05o`000?lb<S;o0000oc8b<_o^k^h00oooool0
1OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0?Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Kooooo00Co0000oooooooooooo00002Oooool01?l0003ooooo
ooooool00007ooooo`03o`000?oooooooooo02Gooooo000Aooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01_ooool01?l0003oooooooooool00009ooooo`04o`000?ooooooooooo`00
00Oooooo00?o0000ooooooooool09Oooool0017ooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`07ooooo`04o`000?ooooooooooo`0000Wooooo00Co0000oooooooooooo00001oooool0
0ol0003oooooooooo`0Uooooo`004Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooooooo000000Wooooo00Co0000
oooooooooooo00002Oooool01?l0003oooooooooool00007ooooo`03o`000?oooooooooo02Gooooo
000Aooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0mooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`08ooooo`05o`000?ooooooooooooooool000002Oooool01?l0003oooooooooool00009ooooo`04
o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool09Oooool0017ooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo03gooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00Go0000oooooooo
ooooooooo`000009ooooo`04o`000?ooooooooooo`0000Wooooo00Co0000oooooooooooo00001ooo
ool00ol0003oooooooooo`0Uooooo`004_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo017ooooo0_l0000nooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool000002Oooool01?l0003ooooooooo
ool00009ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool09Oooool001;ooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo03gooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Sooooo
00Go0000ooooooooooooooooo`000009ooooo`04o`000?ooooooooooo`0000Wooooo00Co0000oooo
oooooooo00001oooool00ol0003oooooooooo`0Uooooo`004_ooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooooooo
000000Wooooo00Co0000oooooooooooo00002Oooool01?l0003oooooooooool00007ooooo`03o`00
0?oooooooooo02Gooooo000Booooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool000002Oooool01?l0003ooooo
ooooool00009ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool09Oooool001;o
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo03ko
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00So
oooo00Go0000ooooooooooooooooo`000009ooooo`04o`000?ooooooooooo`0000Wooooo00Co0000
oooooooooooo00001oooool00ol0003oooooooooo`0Uooooo`004_ooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooo
oooo000000Wooooo00Co0000oooooooooooo00002Oooool01?l0003oooooooooool00007ooooo`03
o`000?oooooooooo02Gooooo000Booooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool000002Oooool01?l0003o
ooooooooool00009ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool09Oooool0
01?ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
03kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Sooooo00Go0000ooooooooooooooooo`000009ooooo`04o`000?ooooooooooo`0000Wooooo00Co
0000oooooooooooo00001oooool00ol0003oooooooooo`0Uooooo`004oooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0?_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool01Ol0003ooooooooo
oooooooo000000Wooooo00Co0000oooooooooooo00002Oooool01?l0003oooooooooool00007oooo
o`03o`000?oooooooooo02Gooooo000Cooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool000002Oooool01?l0
003oooooooooool00009ooooo`04o`000?ooooooooooo`0000Oooooo00?o0000ooooooooool09Ooo
ool001?ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Dooooo`;o0000?oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool0
1Ol0003ooooooooooooooooo000000Wooooo00Co0000oooooooooooo00002Oooool00ol0003ooooo
o`000008ooooo`03o`000?oooooooooo02Gooooo000Cooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool00000
2Oooool01?l0003oooooooooool00009ooooo`03o`000?oooooo000000Sooooo00?o0000oooooooo
ool09Oooool001?ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo03oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Sooooo00Go0000ooooooooooooooooo`000009ooooo`04o`000?ooooooooooo`00
00Wooooo00?o0000ooooool000002?ooool00ol0003oooooooooo`0Uooooo`005?ooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0?oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool01Ol0003o
oooooooooooooooo000000Wooooo00Co0000oooooooooooo00002Oooool00ol0003oooooo`000008
ooooo`03o`000?oooooooooo02Gooooo000Dooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`09ooooo`04o`000?ooooooooooo`0000Wooooo00Co0000
oooooooooooo00002Oooool00ol0003oooooo`000008ooooo`03o`000?oooooooooo02Gooooo000D
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`10
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03Oooool01Ol0003ooooooooooooo
oooo000000cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`04o`000?oo
ooooooooo`0000Wooooo00Co0000oooooooooooo00002Oooool00ol0003oooooo`000008ooooo`03
o`000?oooooooooo02Gooooo000Dooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
3Oooool01Ol0003ooooooooooooooooo000000gooooo00Co0000oooooooooooo00003?ooool01?l0
003oooooooooool00009ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooool000002?oo
ool00ol0003oooooooooo`0Uooooo`005?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00gooooo00Go0000ooooooooooooooooo`00000=ooooo`04o`000?ooooooooooo`0000cooooo
00Co0000oooooooooooo00002Oooool01?l0003oooooooooool00009ooooo`03o`000?oooooo0000
00Sooooo00?o0000ooooooooool09Oooool001Gooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Nooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0=ooooo`05o`000?ooooooooooooooool000003Oooool01?l0003oooooooooool0000<
ooooo`03o`000?oooooo000000[ooooo00Co0000oooooooooooo00002Oooool00ol0003oooooo`00
0009ooooo`03o`000?oooooooooo02Cooooo000Eooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool03Oooool01Ol0003ooooooooooooooooo000000gooooo00Co0000oooooooooooo0000
3?ooool00ol0003oooooo`00000:ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooool0
00002Oooool00ol0003oooooooooo`0Tooooo`005Oooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool0@Oooool01Ol0003ooooooooooooooooo0000027o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00go
oooo00Go0000ooooooooooooooooo`00000=ooooo`04o`000?ooooooooooo`0000cooooo00?o0000
ooooool000002oooool00ol0003oooooo`000009ooooo`03o`000?oooooo000000Wooooo00?o0000
ooooooooool09?ooool001Gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Foooo
o`;o0000@_ooool01Ol0003ooooooooooooooooo0000027ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00gooooo00Go0000ooooooooooooooooo`00
000=ooooo`04o`000?ooooooooooo`0000cooooo00?o0000ooooool000002oooool00ol0003ooooo
o`000009ooooo`03o`000?oooooo000000Wooooo00?o0000ooooooooool09?ooool001Gooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04;ooooo00?o
0000ooooool000008_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool03Oooool01Ol0003ooooooooooooooooo000000gooooo00Co0000oooooooooooo
00003?ooool00ol0003oooooo`00000;ooooo`03o`000?oooooo000000Wooooo00?o0000ooooool0
00002Oooool00ol0003oooooooooo`0Tooooo`005Oooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool0@_ooool3o`0002;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00gooooo00Go0000oooooooooooo
ooooo`00000=ooooo`04o`000?ooooooooooo`0000cooooo00?o0000ooooool000002oooool00ol0
003oooooo`000009ooooo`03o`000?oooooo000000Wooooo00?o0000ooooooooool09?ooool001Ko
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo06Oo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00go
oooo00Go0000ooooooooooooooooo`00000=ooooo`04o`000?ooooooooooo`0000cooooo00?o0000
ooooool000002oooool00ol0003oooooo`000009ooooo`03o`000?oooooo000000Wooooo00?o0000
ooooooooool09?ooool001Kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo06Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00gooooo00Go0000ooooooooooooooooo`00000=ooooo`04o`000?oooooo
ooooo`0000cooooo00?o0000ooooool000002oooool00ol0003oooooo`000009ooooo`03o`000?oo
oooo000000Wooooo00?o0000ooooooooool09?ooool001Kooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04Oooool0
1Ol0003ooooooooooooooooo000000oooooo00Go0000ooooooooooooooooo`00000=ooooo`04o`00
0?ooooooooooo`0000cooooo00?o0000ooooool000002oooool2o`0000_ooooo0_l0000:ooooo`03
o`000?oooooooooo02?ooooo000Fooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo017ooooo00Co0000oooooooooooo
00004?ooool01?l0003oooooooooool0000>ooooo`04o`000?ooooooooooo`0000cooooo00?o0000
ooooool000002oooool2o`0000_ooooo0_l0000`ooooo`005oooool01_l0003ok^k^oc8b<_l0003o
<S8bonk^kPGooooo0_lQ8B43ooooo`06o`000?o^k^ko<S8bo`000?lb<S;ok^k^0oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo
06Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Fooooo`05o`000?oooooooooo
ooooool000005?ooool01?l0003oooooooooool0000@ooooo`04o`000?ooooooooooo`0000kooooo
00Co0000oooooooooooo00003?ooool00ol0003oooooo`00000;ooooo`;o00002oooool2o`00033o
oooo000Gooooo`06o`000?mgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@?ooooo00Ko0000ogMg
MonHV9SooooooiRHV?mgMgL3ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0Fooooo`05o`000?ooooooooooooooool000005?ooool01?l0003oooooooooool0000@oooo
o`04o`000?ooooooooooo`0000oooooo00?o0000ooooool000003?ooool00ol0003oooooo`00000;
ooooo`;o00002oooool00ol0003oooooooooo`0_ooooo`005oooool00ol0003o410@ooooo`02oooo
o`03oa0@4?oooooooooo00Sooooo00?o0000oa0@4?ooool00_ooool01Ol@413ooooooooooooooooo
410@00?ooooo00Co410@oooooooooooooooo1Ol00006ooooo`03o`000?oooooooooo06Sooooo00Go
0000ooooooooooooooooo`00000Iooooo`05o`000?ooooooooooooooool000005?ooool01?l0003o
ooooooooool0000@ooooo`04o`000?ooooooooooo`0000oooooo00?o0000ooooool000003?ooool0
0ol0003oooooo`00000<ooooo`03o`000?oooooooooo03_ooooo000Hooooo`05o`000?oooooooooo
ooooool000002Oooool00ol0003oooooo`000003ooooo`05o`000?ooooooooooooooool000000ooo
ool02?l0003oooooooooooooooooA4A4omgMgOoooooo00001oooool3o`0006Sooooo00Go0000oooo
ooooooooooooo`00000Iooooo`05o`000?ooooooooooooooool000005?ooool01?l0003ooooooooo
ool0000Aooooo`03o`000?oooooo000000oooooo00?o0000ooooool000003?ooool00ol0003ooooo
o`00000<ooooo`03o`000?oooooooooo03_ooooo000Hooooo`05o`000?ooooooooooooooool00000
2Oooool00ol0003oooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool02?l0003o
oooooooooooooooogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`1Xooooo`05o`000?oo
ooooooooooooool000006Oooool01Ol0003ooooooooooooooooo000001Cooooo00Co0000oooooooo
oooo00004Oooool00ol0003oooooo`00000?ooooo`;o00003Oooool00ol0003oooooo`00001:oooo
o`006?ooool01Ol0003ooooooooooooooooo410@00Wooooo00?o0000ooooool@41000oooool01Ol@
413ooooooooooooooooo410@00?ooooo00?o410@ooooooooool00_ooool00omgMgOoc<c<o`000007
ooooo`03o`000?oooooooooo06Sooooo00Go0000ooooooooooooooooo`00000Iooooo`05o`000?oo
ooooooooooooool000005?ooool01?l0003oooooooooool0000Aooooo`03o`000?oooooo000000oo
oooo0_l0000>ooooo`03o`000?oooooooooo04Wooooo000Hooooo`05o`000?nHV9SooooooiRHV?mg
MgL02Oooool01ol0003oooooogMgMonHV9SooooooiRHV?mgMgL00oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`1Xooooo`05o`000?oo
ooooooooooooool000006Oooool01Ol0003ooooooooooooooooo000001Cooooo00Co0000oooooooo
oooo00004Oooool00ol0003oooooo`00000?ooooo`;o00003_ooool00ol0003oooooooooo`19oooo
o`006?ooool01Oo^k^ko0000o`000?lb<S;ok^k^00Sooooo00So0000ooooooooooook^k^oc8b<_l0
003o<S8bonk^kP?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03ogMgMol0003ooooo00Ko
oooo00?o0000ooooooooool0JOooool01?l0003oooooooooool0000Jooooo`04o`000?oooooooooo
o`0001Cooooo00Co0000oooooooooooo00004Oooool00ol0003oooooo`00000?ooooo`;o0000F_oo
ool001Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo06Wooooo00?o0000ooooool000006oooool01?l0003oooooooooool0000Dooooo`04o`000?oo
ooooooooo`00017ooooo00?o0000ooooool000003oooool2o`0005[ooooo000Iooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Zooooo`;o00006ooo
ool00ol0003oooooo`00000Eooooo`04o`000?ooooooooooo`00017ooooo0_l0001/ooooo`006Ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0J_oo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooo000001Kooooo0_l0000Cooooo`03o`000?oo
oooooooo06[ooooo000Jooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`27ooooo`03o`000?oooooo000001Kooooo0_l0000Cooooo`03o`000?oooooo
oooo06[ooooo000Kooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`28ooooo`;o00005_ooool2o`00083ooooo000Kooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool07_ooool2o`0008Wooooo0_l0000Fooooo`;o0000P?ooool001cooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo0?oooooo
8oooool001cooooo0ol000000ooooooo0000ooooo`0Qooooo`03o`000?oooooooooo0?oooooo8ooo
ool001kooooo0_l0000Sooooo`03o`000?oooooooooo0?oooooo8oooool004?ooooo00?o0000oooo
ooooool0oooooolSooooo`00@oooool00ol0003oooooooooo`3oooooob?ooooo0013ooooo`03o`00
0?oooooooooo0?oooooo8oooool004?ooooo00?o0000ooooooooool0oooooolSooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00@oooool3o`000003oa0@4?oo
oooooooo0?oooooo8?ooool004Gooooo00?o410@okZj^_ooool0oooooolQooooo`00AOooool00onH
V9So<S8booooo`3oooooob7ooooo000kooooo`03oc8b<_l0003o000000?o000000Oo<S8boooooooo
ooooooooomgMgOl0003o^[Zj0?oooooo8Oooool003_ooooo00?oV9RHodA4A?ooool00_ooool00om4
A4CoV9RHooooo`02ooooo`03oeEEEOmgMgOoA4A40?oooooo8Oooool003cooooo00Go410@omgMgOoo
oooogMgMoa0@4003ooooo`05omgMgOl@413oooooob4Q8OoMgMd0oooooolPooooo`00??ooool01On7
QhOoMgMgoooooomVIVKoQhN700?ooooo00GoIVIVohN7QoooooooV9RHoeEEE@3oooooob3ooooo000l
ooooo`05onk^k_l@413ok^k^oa0@4?o^k^h00_ooool00oo^k^ko0000onk^kP02ooooo`03o`000?oM
gMgooooo0?oooooo7_ooool003gooooo00?oMgMgob4Q8OmEEED00oooool01?l@413o0000o`000?oo
ool2o`000003oa0@4?oooooooooo0?oooooo7Oooool003gooooo00?ogMgMo`000?oMgMd0oooooolY
ooooo`00?_ooool00onYZJWoooooooooo`3oooooobSooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-5.28856, -0.00473062, \
0.0981498, 6.03752*^-5}}]
}, Open  ]],

Cell[TextData[{
  "This error in the WKB solution grows as the length scale ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " decreases, for fixed ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`c\_o\)]],
  ". This is because the WKB limit  depends on ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " being large. The reader is invited to reevaluate these plots for smaller \
",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  ", in order to investigate the error in the WKB approach."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["\<\
WKB Method for Systems that Vary Slowly in Time: Adiabatic \
Invariance\
\>", "Section",
  CellTags->{"i:73", "c:23"}],

Cell["\<\
\tConsider a quantum mechanical system, such as an atom, that is in \
a particular energy eigenstate described by some set of quantum numbers. When \
the system is put in an external electric of magnetic field that varies \
rapidly in time, it is well known that this can cause the system to jump to \
other energy eigenstates, with different quantum numbers.\
\>", "Text"],

Cell[TextData[{
  "\tOn the other hand, if the external fields vary slowly, it is observed \
that the system remains in the original quantum state. For example, hydrogen \
atoms remain in the ground state if they are slowly transported from a \
field-free region to a region where magnetic or electric fields exist. Thus, \
the quantum numbers are ",
  StyleBox["constants of the motion",
    FontSlant->"Italic"],
  " when the external fields vary slowly, but not when the fields vary \
quickly. "
}], "Text"],

Cell["\<\
\tIn 1911, at  the first Solvay conference,  the question was \
raised as to whether there is analogous behavior in classical systems. That \
is, when a classical system is placed in slowly varying external fields,  is \
there some quantity  that remains time-independent,  in analogy to the \
quantum numbers of the quantum system?  Albert Einstein, a conference \
attendee, showed that such a quantity does in fact exist. It is called an \
adiabatic invariant, because it is only invariant if the fields vary \
adiabatically (slowly).\
\>", "Text"],

Cell[TextData[{
  "\tTo illustrate the concept of an adiabatic invariant, Einstein chose the \
following model system: a pendulum whose length is varied slowly compared to \
its oscillation frequency. A slightly simpler version of this problem is a \
harmonic oscillator for which the oscillator frequency varies slowly in time \
in some prescribed manner, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_o = \(\[Omega]\_o\)(t)\)]],
  " (the pendulum problem is considered in the exercises).  The Hamiltonian \
of the oscillator is "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`H = \(1\/2\) m\ x\& . \^2 + \(1\/2\) 
            m\ \(\(\[Omega]\_o\%2\)(t)\) x\^2\)]],
  ". "
}], "NE2",
  CellTags->"(5.2.19)"],

Cell[TextData[{
  "Since ",
  Cell[BoxData[
      \(TraditionalForm\`H\)]],
  " depends explicitly on time, the energy of the system is not  a conserved \
quantity. To find the adiabatic invariant for this system, one can examine \
the equation of motion for the oscillator:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(x\&\[DoubleDot]\)(
          t) = \(-\(\(\[Omega]\_o\^2\)(t)\)\)\ \(x(t)\)\)]],
  "."
}], "NE2",
  CellTags->"(5.2.20)"],

Cell[TextData[{
  "This equation has the same form as Eq. ",
  ButtonBox["(5.2.3)",
    ButtonData:>"(5.2.3)",
    ButtonStyle->"Hyperlink"],
  ", so we can apply WKB theory to find an approximate solution. This \
solution will be valid only if the frequency ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Omega]\_o\)(t)\)]],
  " is slowly varying in time. Specifically, the requirement on ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_o\)]],
  " is ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          FormBox[\(\[Omega]\& . \_o/\[Omega]\_o\^2 << 1\),
            "TraditionalForm"]}], TraditionalForm]]],
  " [this is analogous to Eq. ",
  ButtonBox["(5.2.8)",
    ButtonData:>"(5.2.8)",
    ButtonStyle->"Hyperlink"],
  "].  Comparing with the WKB solution of Eq. ",
  ButtonBox["(5.2.3)",
    ButtonData:>"(5.2.3)",
    ButtonStyle->"Hyperlink"],
  ", we can write the  WKB solution to Eq. ",
  ButtonBox["(5.2.20)",
    ButtonData:>"(5.2.20)",
    ButtonStyle->"Hyperlink"],
  " as "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`x(
          t)\  = \(A\/\@\(\(\[Omega]\_o\)(t)\)\) \(cos(\[Integral]\^t\(\( \
\[Omega]\_o\)(t)\) \[DifferentialD]t\  + \[Phi])\)\)]],
  " ,"
}], "NE2",
  CellTags->"(5.2.21)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " is a constant phase factor and ",
  Cell[BoxData[
      \(TraditionalForm\`A\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " are determined by the initial conditions on Eq. ",
  ButtonBox["(5.2.10)",
    ButtonData:>"(5.2.10)",
    ButtonStyle->"Hyperlink"],
  ". Equation ",
  ButtonBox["(5.2.21)",
    ButtonData:>"(5.2.21)",
    ButtonStyle->"Hyperlink"],
  " shows that when the frequency of the oscillator increases with time, the \
amplitude of the oscillations decreases like ",
  Cell[BoxData[
      \(TraditionalForm\`1/\@\(\(\[Omega]\_o\)(t)\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "  We can see this behavior if we solve Eq. ",
  ButtonBox["(5.2.20)",
    ButtonData:>"(5.2.20)",
    ButtonStyle->"Hyperlink"],
  " numerically for a given initial condition and a given ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Omega]\_o\)(t)\)]],
  ". For example, take ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Omega]\_o\)(
          t)\  = \(-\[Alpha]\)\ t + \ \[ExponentialE]\^\(\(\ \
\)\(\[Alpha]t\)\)\)]],
  ", ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(x(0) = 1\), " ", ",", 
          RowBox[{\(x' \((0)\)\), "=", 
            RowBox[{"0", Cell[""]}]}]}], TraditionalForm]]],
  ". Then the WKB solution for these initial conditions is ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(x(t)\), " ", "=", Cell[TextData[Cell[BoxData[
              \(TraditionalForm\`cos \(\[Integral]\_0\%t\(\( \[Omega]\_o\)(
                      t)\) \[DifferentialD]t/\@\(\(\[Omega]\_o\)(t)\)\)\)]]]],
           " "}], TraditionalForm]]],
  ". This is compared with the numerical solution of Eq. ",
  ButtonBox["(5.2.20)",
    ButtonData:>"(5.2.20)",
    ButtonStyle->"Hyperlink"],
  " in Cell ",
  ButtonBox["5.21",
    ButtonData:>"Cell 5.21",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Clear["\<Global`*\>"];\)\), "\n", 
    \(\(<< Graphics`;\)\), "\n", 
    \(\(\[Alpha]\  = \ 1/3;\)\), "\n", 
    \(\(\[Omega]\_o[
          t_]\  = \ \ \(-\[Alpha]\)\ t\  + \ \[ExponentialE]\^\(\[Alpha]\ \
t\);\)\), "\n", 
    \(\(xWKB[t_]\  = \ 
        Cos[Integrate[\[Omega]\_o[t1], {t1, 0, t}]]/
          Sqrt[\[Omega]\_o[t]];\)\), "\n", 
    \(\(NDSolve[{\(x''\)[t]\  \[Equal] \ \(-\[Omega]\_o[t]^2\)\ x[t], 
          x[0] \[Equal] 1, \(x'\)[0] \[Equal] 0}, x[t], {t, 0, 15}, 
        MaxSteps \[Rule] 5000];\)\), "\n", 
    \(\(x1[t_]\  = \ x[t] /. %[\([1]\)];\)\), "\n", 
    \(\(Plot[{xWKB[t], x1[t]}, {t, 0, 15}, 
        PlotStyle \[Rule] {{Red, Dashing[{0.01, 0.02}], Thickness[0.006]}, 
            Blue}, AxesLabel \[Rule] {"\<t\>", "\<\>"}, 
        PlotLabel \[Rule] "\<Oscillator with varying frequency\>"];\)\)}], \
"Input",
  ShowCellTags->True,
  CellTags->"Cell 5.21"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0634921 0.277501 0.325818 [
[.15079 .265 -3 -9 ]
[.15079 .265 3 0 ]
[.27778 .265 -3 -9 ]
[.27778 .265 3 0 ]
[.40476 .265 -3 -9 ]
[.40476 .265 3 0 ]
[.53175 .265 -3 -9 ]
[.53175 .265 3 0 ]
[.65873 .265 -6 -9 ]
[.65873 .265 6 0 ]
[.78571 .265 -6 -9 ]
[.78571 .265 6 0 ]
[.9127 .265 -6 -9 ]
[.9127 .265 6 0 ]
[1.025 .2775 0 -6 ]
[1.025 .2775 10 6 ]
[.01131 .03314 -30 -4.5 ]
[.01131 .03314 0 4.5 ]
[.01131 .11459 -24 -4.5 ]
[.01131 .11459 0 4.5 ]
[.01131 .19605 -30 -4.5 ]
[.01131 .19605 0 4.5 ]
[.01131 .35896 -24 -4.5 ]
[.01131 .35896 0 4.5 ]
[.01131 .44041 -18 -4.5 ]
[.01131 .44041 0 4.5 ]
[.01131 .52186 -24 -4.5 ]
[.01131 .52186 0 4.5 ]
[.01131 .60332 -6 -4.5 ]
[.01131 .60332 0 4.5 ]
[.5 .63053 -101.062 0 ]
[.5 .63053 101.062 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15079 .2775 m
.15079 .28375 L
s
[(2)] .15079 .265 0 1 Mshowa
.27778 .2775 m
.27778 .28375 L
s
[(4)] .27778 .265 0 1 Mshowa
.40476 .2775 m
.40476 .28375 L
s
[(6)] .40476 .265 0 1 Mshowa
.53175 .2775 m
.53175 .28375 L
s
[(8)] .53175 .265 0 1 Mshowa
.65873 .2775 m
.65873 .28375 L
s
[(10)] .65873 .265 0 1 Mshowa
.78571 .2775 m
.78571 .28375 L
s
[(12)] .78571 .265 0 1 Mshowa
.9127 .2775 m
.9127 .28375 L
s
[(14)] .9127 .265 0 1 Mshowa
.125 Mabswid
.05556 .2775 m
.05556 .28125 L
s
.0873 .2775 m
.0873 .28125 L
s
.11905 .2775 m
.11905 .28125 L
s
.18254 .2775 m
.18254 .28125 L
s
.21429 .2775 m
.21429 .28125 L
s
.24603 .2775 m
.24603 .28125 L
s
.30952 .2775 m
.30952 .28125 L
s
.34127 .2775 m
.34127 .28125 L
s
.37302 .2775 m
.37302 .28125 L
s
.43651 .2775 m
.43651 .28125 L
s
.46825 .2775 m
.46825 .28125 L
s
.5 .2775 m
.5 .28125 L
s
.56349 .2775 m
.56349 .28125 L
s
.59524 .2775 m
.59524 .28125 L
s
.62698 .2775 m
.62698 .28125 L
s
.69048 .2775 m
.69048 .28125 L
s
.72222 .2775 m
.72222 .28125 L
s
.75397 .2775 m
.75397 .28125 L
s
.81746 .2775 m
.81746 .28125 L
s
.84921 .2775 m
.84921 .28125 L
s
.88095 .2775 m
.88095 .28125 L
s
.94444 .2775 m
.94444 .28125 L
s
.97619 .2775 m
.97619 .28125 L
s
.25 Mabswid
0 .2775 m
1 .2775 L
s
gsave
1.025 .2775 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .03314 m
.03006 .03314 L
s
[(-0.75)] .01131 .03314 1 0 Mshowa
.02381 .11459 m
.03006 .11459 L
s
[(-0.5)] .01131 .11459 1 0 Mshowa
.02381 .19605 m
.03006 .19605 L
s
[(-0.25)] .01131 .19605 1 0 Mshowa
.02381 .35896 m
.03006 .35896 L
s
[(0.25)] .01131 .35896 1 0 Mshowa
.02381 .44041 m
.03006 .44041 L
s
[(0.5)] .01131 .44041 1 0 Mshowa
.02381 .52186 m
.03006 .52186 L
s
[(0.75)] .01131 .52186 1 0 Mshowa
.02381 .60332 m
.03006 .60332 L
s
[(1)] .01131 .60332 1 0 Mshowa
.125 Mabswid
.02381 .04943 m
.02756 .04943 L
s
.02381 .06572 m
.02756 .06572 L
s
.02381 .08201 m
.02756 .08201 L
s
.02381 .0983 m
.02756 .0983 L
s
.02381 .13088 m
.02756 .13088 L
s
.02381 .14717 m
.02756 .14717 L
s
.02381 .16346 m
.02756 .16346 L
s
.02381 .17976 m
.02756 .17976 L
s
.02381 .21234 m
.02756 .21234 L
s
.02381 .22863 m
.02756 .22863 L
s
.02381 .24492 m
.02756 .24492 L
s
.02381 .26121 m
.02756 .26121 L
s
.02381 .29379 m
.02756 .29379 L
s
.02381 .31008 m
.02756 .31008 L
s
.02381 .32637 m
.02756 .32637 L
s
.02381 .34266 m
.02756 .34266 L
s
.02381 .37525 m
.02756 .37525 L
s
.02381 .39154 m
.02756 .39154 L
s
.02381 .40783 m
.02756 .40783 L
s
.02381 .42412 m
.02756 .42412 L
s
.02381 .4567 m
.02756 .4567 L
s
.02381 .47299 m
.02756 .47299 L
s
.02381 .48928 m
.02756 .48928 L
s
.02381 .50557 m
.02756 .50557 L
s
.02381 .53816 m
.02756 .53816 L
s
.02381 .55445 m
.02756 .55445 L
s
.02381 .57074 m
.02756 .57074 L
s
.02381 .58703 m
.02756 .58703 L
s
.02381 .01685 m
.02756 .01685 L
s
.02381 .00056 m
.02756 .00056 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -162.062 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Oscillator) show
129.125 13.000 moveto
(with) show
159.125 13.000 moveto
(varying) show
207.125 13.000 moveto
(frequency) show
261.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.006 w
[ .01 .02 ] 0 setdash
.02381 .60332 m
.02499 .60326 L
.02605 .6031 L
.02729 .6028 L
.02846 .6024 L
.03053 .60139 L
.03279 .59988 L
.03527 .59773 L
.0379 .59487 L
.04262 .5883 L
.05205 .56969 L
.06244 .54113 L
.0842 .45715 L
.10458 .35606 L
.14335 .14849 L
.15346 .10198 L
.16449 .05999 L
.16953 .04469 L
.1749 .03152 L
.17752 .02639 L
.17998 .02237 L
.1822 .01945 L
.18458 .01707 L
.18584 .01614 L
.18698 .01549 L
.18814 .01503 L
.18923 .01478 L
.1905 .01472 L
.19168 .01488 L
.19297 .0153 L
.19362 .01561 L
.19434 .01603 L
.19568 .01703 L
.1969 .01819 L
.19966 .02169 L
.20209 .0258 L
.20465 .03118 L
.20922 .04343 L
.21348 .05789 L
.22313 .10122 L
.23365 .16328 L
.24358 .23225 L
.26217 .36705 L
.27189 .42584 L
.27679 .44863 L
.27961 .45905 L
.28219 .46666 L
.28331 .46937 L
.28454 .47189 L
.28572 .47385 L
Mistroke
.28678 .47523 L
.28802 .47638 L
.28934 .47704 L
.29057 .47711 L
.29172 .4767 L
.29281 .47589 L
.29395 .47457 L
.29493 .47308 L
.29601 .47104 L
.2984 .46499 L
.30064 .4575 L
.30566 .43426 L
.31112 .39971 L
.32103 .31795 L
.33061 .22972 L
.3396 .15807 L
.34414 .13231 L
.34538 .12693 L
.34669 .12213 L
.34791 .11847 L
.34902 .11588 L
.35027 .11382 L
.35095 .11309 L
.3516 .11265 L
.35275 .11251 L
.35399 .11327 L
.35464 .11406 L
.35536 .11524 L
.35681 .1186 L
.35816 .1229 L
.35941 .12794 L
.36213 .14211 L
.36471 .15946 L
.36955 .2008 L
.38043 .31577 L
.3854 .36456 L
.38784 .38447 L
.39007 .39952 L
.39241 .41138 L
.39364 .41583 L
.39494 .4191 L
.39558 .42016 L
.39627 .42088 L
.39751 .42106 L
.39826 .42046 L
.39898 .4194 L
.39962 .41803 L
.40032 .4161 L
.40146 .41195 L
.40253 .40696 L
Mistroke
.40497 .3918 L
.40734 .37233 L
.40989 .34701 L
.41873 .24183 L
.42363 .18933 L
.42504 .17728 L
.42636 .1676 L
.42757 .16039 L
.42885 .15453 L
.42953 .15219 L
.43028 .15027 L
.4316 .14862 L
.43234 .14867 L
.43313 .14953 L
.43388 .1511 L
.43457 .15317 L
.43588 .15881 L
.4373 .16737 L
.43988 .18891 L
.44943 .30866 L
.45205 .3412 L
.45343 .35621 L
.45487 .36989 L
.45614 .3798 L
.45682 .38415 L
.45753 .38806 L
.4588 .39301 L
.45997 .39529 L
.46062 .39556 L
.46131 .39507 L
.46254 .3922 L
.46386 .38627 L
.46461 .38163 L
.46531 .37648 L
.46774 .35323 L
.47035 .32062 L
.47485 .25548 L
.47723 .22275 L
.47976 .19396 L
.48056 .1868 L
.4813 .18101 L
.48202 .17632 L
.48269 .17289 L
.48399 .16872 L
.48468 .16794 L
.4854 .16818 L
.48672 .17149 L
.48795 .17787 L
.48866 .18291 L
.4893 .18833 L
Mistroke
.49075 .20318 L
.49561 .27226 L
.49828 .31355 L
.50078 .34711 L
.50195 .35962 L
.50306 .36905 L
.50434 .37653 L
.50551 .3799 L
.5068 .37957 L
.508 .37542 L
.50932 .36673 L
.51006 .36009 L
.51073 .35305 L
.51546 .28351 L
.51758 .24835 L
.51991 .21426 L
.52122 .19925 L
.52244 .18883 L
.52373 .18218 L
.52445 .18058 L
.52511 .18049 L
.52629 .18362 L
.52757 .19172 L
.52878 .20353 L
.5299 .21764 L
.53509 .30425 L
.53651 .32711 L
.53801 .34725 L
.53929 .35997 L
.54002 .36499 L
.54069 .36812 L
.54195 .36973 L
.54313 .36616 L
.54419 .35883 L
.54535 .34681 L
.5466 .32955 L
.54793 .30767 L
.55032 .26411 L
.55239 .22849 L
.55353 .21235 L
.55462 .20048 L
.55589 .19174 L
.55706 .18927 L
.55816 .19198 L
.55935 .20034 L
.56002 .20738 L
.56075 .21669 L
.56207 .23729 L
.56453 .28331 L
.56721 .33095 L
Mistroke
.56856 .34848 L
.56932 .3555 L
.57004 .35985 L
.57134 .36193 L
.57253 .35702 L
.57319 .35162 L
.5739 .34372 L
.5752 .32469 L
.57768 .27773 L
.57995 .23429 L
.58109 .21669 L
.58229 .2034 L
.58349 .19669 L
.58481 .19774 L
.58595 .20579 L
.58717 .22102 L
.58832 .24045 L
.58937 .26095 L
.59193 .31314 L
.59264 .32558 L
.59338 .33692 L
.59401 .34478 L
.59471 .35119 L
.59597 .35612 L
.59667 .35496 L
.59732 .35143 L
.59857 .33825 L
.59975 .31918 L
.60228 .26679 L
.60367 .23863 L
.60498 .21749 L
.60608 .2059 L
.60727 .20141 L
.60792 .20271 L
.6086 .20689 L
.60981 .22107 L
.61276 .27962 L
.61421 .31076 L
.61485 .32279 L
.61555 .33409 L
.61677 .3474 L
.61805 .35111 L
.61873 .34848 L
.61946 .34222 L
.62077 .32291 L
.62332 .26788 L
.62458 .24075 L
.62574 .22072 L
.6268 .20936 L
.62792 .2059 L
Mistroke
.62916 .2131 L
.63029 .22885 L
.63161 .25534 L
.63281 .28351 L
.63411 .3126 L
.6348 .32563 L
.63554 .33668 L
.63678 .34665 L
.63794 .34481 L
.63862 .33869 L
.63927 .32975 L
.64048 .30637 L
.64269 .25398 L
.64391 .22931 L
.64505 .2142 L
.64601 .20953 L
.64705 .2137 L
.64821 .22886 L
.64927 .25039 L
.65044 .27866 L
.65168 .30847 L
.65286 .33064 L
.65393 .34198 L
.65514 .34226 L
.65627 .33018 L
.6575 .30615 L
.65883 .27317 L
.66004 .24399 L
.66119 .22306 L
.66183 .21603 L
.66252 .21275 L
.66373 .21866 L
.66488 .23688 L
.6661 .26556 L
.66725 .29518 L
.6683 .31917 L
.66896 .33048 L
.66966 .33819 L
.67035 .34091 L
.67112 .3378 L
.67178 .33016 L
.67249 .31753 L
.67377 .28677 L
.6751 .25209 L
.67636 .22651 L
.67749 .21585 L
.67872 .22069 L
.68873 .26611 L
.69003 .23476 L
.69077 .22321 L
Mistroke
.69145 .21817 L
.6927 .22465 L
.6934 .23652 L
.69404 .25121 L
.69558 .29354 L
.69633 .31259 L
.69703 .32611 L
.69834 .336 L
.69903 .33179 L
.69976 .32068 L
.70211 .2587 L
.70343 .22924 L
.70464 .22001 L
.70532 .224 L
.70606 .23549 L
.70676 .25181 L
.7074 .26987 L
.70805 .28858 L
.70874 .30737 L
.70999 .33037 L
.71114 .33241 L
.7122 .31708 L
.71339 .28593 L
.71464 .2499 L
.71586 .22616 L
.717 .22326 L
.71825 .24289 L
.71894 .26152 L
.71958 .28055 L
.72089 .31607 L
.72155 .32744 L
.72228 .3322 L
.72356 .31918 L
.72477 .28782 L
.72543 .26746 L
.72616 .24697 L
.72748 .22482 L
.72827 .22526 L
.729 .23525 L
.72967 .25115 L
.73039 .27242 L
.73104 .29239 L
.73172 .31113 L
.73246 .32545 L
.73315 .33052 L
.73439 .31798 L
.73509 .30049 L
.73575 .28046 L
.73695 .24483 L
.73809 .22627 L
Mistroke
.73941 .23447 L
.7406 .26556 L
.74174 .3013 L
.74297 .32643 L
.74414 .32474 L
.7452 .30162 L
.74648 .26108 L
.74767 .2323 L
.74891 .22938 L
.74957 .24045 L
.75027 .25956 L
.7516 .30207 L
.75235 .31991 L
.75304 .32738 L
.75431 .31456 L
.75495 .29723 L
.75565 .2742 L
.75687 .23894 L
.75817 .22911 L
.75941 .25317 L
.76053 .29019 L
.76167 .32004 L
.76288 .32371 L
.76402 .29816 L
.76506 .26345 L
.76628 .23308 L
.7676 .2362 L
.76885 .27129 L
.76999 .30843 L
.77107 .32507 L
.77207 .31502 L
.77318 .28184 L
.77436 .24398 L
.77559 .2309 L
.77677 .25344 L
.77782 .28962 L
.77896 .31982 L
.78019 .31813 L
.78131 .28639 L
.78251 .24603 L
.78383 .2325 L
.78505 .25977 L
.78617 .29946 L
.78725 .32213 L
.7884 .31173 L
.78965 .26997 L
.79083 .23676 L
.79205 .23938 L
.7927 .25697 L
.79339 .28206 L
Mistroke
.79415 .3074 L
.79486 .32088 L
.79551 .32009 L
.7962 .30552 L
.79743 .26181 L
.79814 .24128 L
.79879 .23338 L
.79948 .23972 L
.80022 .26077 L
.80096 .28839 L
.80174 .31257 L
.80242 .32118 L
.80317 .31347 L
.80447 .26965 L
.80516 .24661 L
.80581 .23504 L
.80656 .23895 L
.80724 .25718 L
.8085 .30312 L
.80913 .31767 L
.80982 .31878 L
.81111 .28264 L
.81232 .24193 L
.81343 .23926 L
.81462 .277 L
.81529 .30179 L
.81601 .31805 L
.8167 .31661 L
.81734 .3009 L
.81852 .25609 L
.81982 .23677 L
.82111 .27291 L
.82177 .29839 L
.82247 .31628 L
.82374 .30373 L
.82491 .25884 L
.82562 .23966 L
.82639 .23937 L
.82712 .25894 L
.82779 .28573 L
.82906 .31798 L
.82971 .31168 L
.83041 .28874 L
.83171 .24266 L
.83289 .24658 L
.83419 .29572 L
.83484 .31406 L
.83556 .31524 L
.83677 .27613 L
.83806 .23842 L
Mistroke
.83928 .26077 L
.84038 .30437 L
.84154 .31303 L
.84278 .26939 L
.84383 .23935 L
.84498 .25859 L
.84622 .30713 L
.84692 .31606 L
.84756 .30469 L
.84879 .2555 L
.84996 .24167 L
.85105 .27883 L
.85221 .3148 L
.8532 .30017 L
.85429 .25524 L
.85546 .24302 L
.85672 .28975 L
.85791 .3145 L
.859 .28131 L
.86027 .24062 L
.86148 .26774 L
.86256 .30956 L
.86373 .30025 L
.865 .24852 L
.86565 .24108 L
.86636 .25806 L
.86762 .30869 L
.86878 .29991 L
.86995 .25127 L
.87105 .2485 L
.87222 .29677 L
.87349 .30652 L
.8746 .26044 L
.87577 .24554 L
.87689 .28987 L
.8779 .31279 L
.87919 .26809 L
.87985 .24536 L
.88056 .24712 L
.88183 .29941 L
.88302 .30407 L
.88373 .27335 L
.88441 .24721 L
.88569 .26604 L
.8864 .29855 L
.88706 .31215 L
.88778 .296 L
.88855 .2606 L
.88974 .2493 L
.89101 .30323 L
Mistroke
.89222 .296 L
.89332 .24857 L
.89455 .26568 L
.89524 .29809 L
.89589 .31132 L
.89719 .2654 L
.89792 .24413 L
.89859 .25548 L
.8997 .30459 L
.9009 .29072 L
.90221 .24425 L
.90344 .28713 L
.9041 .30937 L
.90482 .2998 L
.90612 .24608 L
.9074 .28083 L
.90858 .30794 L
.90978 .25661 L
.91092 .25782 L
.91194 .30419 L
.91304 .29045 L
.91424 .24536 L
.91551 .29121 L
.91659 .30316 L
.91778 .25037 L
.91845 .25045 L
.91918 .28347 L
.91987 .30829 L
.9205 .29905 L
.92171 .24742 L
.92298 .28612 L
.92364 .30838 L
.92435 .29361 L
.92563 .24641 L
.92641 .27302 L
.92715 .30572 L
.92782 .30071 L
.92855 .26481 L
.92987 .2653 L
.93107 .30796 L
.93173 .28538 L
.93245 .25143 L
.93375 .28379 L
.93497 .2978 L
.93627 .24722 L
.93737 .29166 L
.93858 .28998 L
.93979 .24836 L
.94092 .29809 L
.94215 .27982 L
Mistroke
.94346 .25719 L
.94459 .30668 L
.94565 .26924 L
.94682 .26042 L
.94807 .306 L
.94912 .25833 L
.95027 .27232 L
.95147 .30128 L
.95259 .24993 L
.95364 .2834 L
.95459 .30216 L
.95569 .25077 L
.95673 .28203 L
.95785 .29577 L
.95909 .25006 L
.96038 .30531 L
.96159 .25843 L
.96271 .27636 L
.96374 .30133 L
.96494 .2495 L
.96607 .29716 L
.96728 .27064 L
.96858 .27491 L
.9698 .29256 L
.97091 .25097 L
.97222 .305 L
.97295 .27536 L
.97363 .25011 L
.97488 .3032 L
.97619 .25397 L
Mfstroke
0 0 1 r
.5 Mabswid
[ ] 0 setdash
.02381 .60332 m
.02499 .60326 L
.02605 .60311 L
.02729 .60283 L
.02846 .60245 L
.03053 .60149 L
.03279 .60007 L
.03527 .59802 L
.0379 .59532 L
.04262 .5891 L
.05205 .5715 L
.06244 .54444 L
.0842 .4646 L
.10458 .36769 L
.14335 .16431 L
.15346 .11731 L
.16449 .07386 L
.16953 .05756 L
.1749 .04312 L
.17752 .03729 L
.17998 .03257 L
.1822 .02898 L
.18458 .02585 L
.18584 .0245 L
.18698 .02347 L
.18815 .02261 L
.18923 .02199 L
.19049 .02148 L
.19115 .02131 L
.19185 .0212 L
.19304 .02117 L
.19434 .02139 L
.19499 .0216 L
.19568 .02189 L
.1969 .02258 L
.19822 .02359 L
.19966 .02501 L
.20225 .02839 L
.20465 .0325 L
.20933 .04319 L
.21359 .056 L
.22313 .09519 L
.23311 .1503 L
.24231 .21115 L
.26311 .36002 L
.27215 .4154 L
.27723 .44002 L
.28187 .45709 L
.28449 .46408 L
.28597 .46712 L
Mistroke
.28734 .46933 L
.28866 .47088 L
.28986 .47179 L
.29052 .47208 L
.29124 .47223 L
.29254 .47205 L
.29374 .47136 L
.29443 .47074 L
.29507 .47001 L
.29635 .4681 L
.29773 .46539 L
.30024 .45875 L
.30251 .45076 L
.30733 .4279 L
.31245 .39552 L
.32163 .32114 L
.33164 .23056 L
.33689 .18684 L
.33975 .16601 L
.34241 .14926 L
.34496 .13599 L
.34728 .12667 L
.3486 .1226 L
.34985 .11965 L
.35117 .11751 L
.35191 .11676 L
.35259 .11635 L
.35371 .1163 L
.35475 .11695 L
.3559 .11843 L
.35713 .12093 L
.35841 .12455 L
.35963 .12893 L
.36192 .13958 L
.36647 .16955 L
.37068 .20617 L
.38021 .30548 L
.38484 .35168 L
.38726 .37274 L
.38982 .39141 L
.39207 .40416 L
.39335 .40967 L
.39453 .41359 L
.39563 .41614 L
.39662 .41753 L
.39777 .41801 L
.39885 .41734 L
.40004 .41535 L
.40135 .41164 L
.40201 .40917 L
Mistroke
.40271 .40607 L
.40399 .39933 L
.40647 .38231 L
.40873 .36261 L
.41945 .24022 L
.42422 .19036 L
.42559 .17891 L
.42688 .16972 L
.42806 .16284 L
.4293 .15723 L
.43039 .15379 L
.43159 .1517 L
.43268 .15136 L
.4337 .15242 L
.4349 .15539 L
.43599 .1597 L
.43725 .16652 L
.43845 .17474 L
.44095 .19699 L
.44361 .22675 L
.44838 .28878 L
.45112 .32413 L
.45401 .35643 L
.4552 .36743 L
.45648 .37727 L
.45721 .38194 L
.45788 .38552 L
.45917 .39056 L
.46038 .39284 L
.46149 .39282 L
.46271 .39042 L
.464 .38519 L
.46512 .37846 L
.46617 .37042 L
.46855 .34653 L
.47384 .27543 L
.47615 .24267 L
.47866 .21074 L
.4798 .19857 L
.48101 .18766 L
.48215 .17959 L
.48319 .17433 L
.48425 .1711 L
.4854 .17021 L
.48648 .17189 L
.48748 .17559 L
.48862 .18228 L
.48968 .19077 L
.49209 .21711 L
.49695 .28836 L
Mistroke
.49939 .32436 L
.50197 .35545 L
.50332 .36706 L
.50409 .37194 L
.50481 .37527 L
.50608 .37808 L
.50679 .37791 L
.50743 .37664 L
.50869 .37115 L
.50986 .36261 L
.51115 .34976 L
.51252 .33259 L
.51735 .25664 L
.51976 .22079 L
.52103 .20543 L
.52172 .19845 L
.52237 .19297 L
.52354 .18582 L
.52483 .18244 L
.52592 .18344 L
.52709 .18847 L
.52823 .19709 L
.52946 .2103 L
.53171 .24245 L
.53593 .31361 L
.53706 .33073 L
.53826 .34606 L
.53957 .35871 L
.54077 .36575 L
.5419 .36797 L
.54294 .36609 L
.54409 .35969 L
.54532 .34815 L
.54666 .33072 L
.54811 .30749 L
.55075 .26022 L
.55198 .2391 L
.5533 .21923 L
.55455 .20455 L
.55569 .19553 L
.55699 .19115 L
.55822 .19313 L
.55891 .19687 L
.55955 .20195 L
.56025 .20921 L
.561 .2187 L
.56389 .26766 L
.56662 .31767 L
.56785 .33643 L
.56916 .3511 L
Mistroke
.56984 .35621 L
.57059 .35954 L
.57191 .35935 L
.5731 .35245 L
.57438 .33849 L
.57559 .32012 L
.5767 .30025 L
.57918 .25187 L
.5804 .23053 L
.58151 .21464 L
.58269 .20311 L
.58395 .1978 L
.58525 .20071 L
.58591 .20538 L
.58663 .21278 L
.58784 .22997 L
.58893 .24957 L
.59139 .29902 L
.59248 .31936 L
.59366 .33742 L
.59478 .34906 L
.59581 .35415 L
.59701 .35265 L
.5983 .34226 L
.59951 .32511 L
.60062 .30477 L
.60336 .24802 L
.60457 .22661 L
.60526 .21694 L
.6059 .20996 L
.60718 .20313 L
.60783 .20345 L
.60853 .20673 L
.60925 .21321 L
.61002 .22313 L
.61138 .24728 L
.61406 .30421 L
.61537 .32821 L
.61658 .34341 L
.61774 .34964 L
.61897 .34634 L
.62021 .33315 L
.62091 .32185 L
.62157 .30933 L
.62389 .25828 L
.62504 .23522 L
.6261 .2188 L
.62733 .20844 L
.62798 .20728 L
.62867 .20946 L
Mistroke
.6299 .22174 L
.63101 .24074 L
.63376 .30198 L
.63497 .32541 L
.63565 .33539 L
.63629 .34189 L
.63735 .34584 L
.6385 .34 L
.63972 .32315 L
.64083 .3006 L
.64318 .2463 L
.64383 .23365 L
.64451 .22276 L
.64574 .21176 L
.64686 .21283 L
.64792 .22349 L
.64907 .24416 L
.65031 .27294 L
.65141 .29938 L
.65257 .3232 L
.65356 .33693 L
.65464 .34252 L
.65597 .33469 L
.65718 .31471 L
.65852 .28375 L
.65993 .24939 L
.66116 .22607 L
.66231 .21491 L
.66357 .21741 L
.66428 .22555 L
.66492 .23664 L
.66722 .29156 L
.66843 .31881 L
.66971 .33667 L
.67095 .33834 L
.67207 .32608 L
.6732 .30312 L
.67426 .27622 L
.67558 .24367 L
.67682 .22271 L
.6781 .21702 L
.67878 .22156 L
.67951 .23184 L
.68081 .26061 L
.68204 .29294 L
.68314 .31839 L
.68433 .33485 L
.68564 .33421 L
.68638 .32493 L
.68708 .31133 L
Mistroke
.6886 .27216 L
.68926 .25467 L
.68999 .23808 L
.69128 .22054 L
.69251 .22256 L
.69318 .23166 L
.69391 .24652 L
.69521 .28099 L
.69586 .29849 L
.69656 .31496 L
.69781 .33311 L
.69912 .33058 L
.69988 .31916 L
.70056 .30377 L
.7018 .26982 L
.70312 .23715 L
.70424 .22233 L
.70549 .22609 L
.70616 .23691 L
.7069 .25391 L
.70822 .29107 L
.70898 .31058 L
.70977 .32568 L
.71045 .33218 L
.71119 .33146 L
.7119 .32321 L
.71255 .31018 L
.714 .27017 L
.71464 .25232 L
.71534 .23636 L
.71661 .22305 L
.71786 .23408 L
.71903 .26223 L
.71975 .28325 L
.72042 .30246 L
.7217 .32733 L
.72294 .32843 L
.72365 .31808 L
.7243 .30281 L
.72574 .26069 L
.72645 .24235 L
.72709 .23043 L
.72828 .2259 L
.72955 .24682 L
.73064 .27796 L
.73178 .31035 L
.73301 .32884 L
.73416 .32244 L
.73542 .29243 L
.73612 .27097 L
Mistroke
.73677 .25182 L
.73799 .22859 L
.73864 .22651 L
.73934 .23313 L
.74003 .24768 L
.74076 .26872 L
.74206 .30768 L
.74328 .32727 L
.7444 .32081 L
.74564 .28991 L
.74696 .2495 L
.7477 .23362 L
.74839 .22775 L
.74915 .23245 L
.74994 .2489 L
.7514 .29396 L
.75211 .31317 L
.75276 .32403 L
.75397 .32115 L
.75527 .28847 L
.75596 .26601 L
.75661 .24704 L
.75736 .23253 L
.75803 .22914 L
.75927 .24817 L
.75996 .26915 L
.7606 .2902 L
.76176 .31962 L
.76298 .32235 L
.76362 .31054 L
.76431 .29062 L
.76555 .25066 L
.7663 .23442 L
.76702 .23038 L
.76766 .23718 L
.76836 .25409 L
.76964 .29608 L
.77083 .32234 L
.77208 .3152 L
.77274 .29782 L
.77346 .27392 L
.77471 .23812 L
.77591 .23413 L
.77699 .25916 L
.77816 .2988 L
.77881 .31544 L
.77949 .32306 L
.78071 .30664 L
.78203 .26287 L
.78277 .2417 L
Mistroke
.78347 .23261 L
.78473 .24909 L
.78589 .28784 L
.78652 .30774 L
.78722 .32053 L
.78848 .31033 L
.78952 .27674 L
.79061 .24247 L
.79182 .23577 L
.79292 .26335 L
.79413 .30502 L
.79545 .32016 L
.79668 .291 L
.79783 .25096 L
.79852 .23646 L
.79917 .23542 L
.80038 .26511 L
.80107 .29043 L
.8018 .31216 L
.80311 .31474 L
.80439 .27442 L
.80513 .2493 L
.8058 .23634 L
.80653 .23852 L
.80731 .25841 L
.80799 .28366 L
.80872 .30782 L
.81 .31615 L
.81119 .28096 L
.81192 .25436 L
.81261 .23837 L
.81389 .24981 L
.81512 .29433 L
.81625 .31857 L
.81749 .29664 L
.8188 .24918 L
.82002 .23945 L
.82072 .25678 L
.82136 .28098 L
.82253 .31567 L
.82377 .3033 L
.82488 .26167 L
.82593 .23771 L
.82707 .25623 L
.8283 .3025 L
.82954 .31472 L
.83024 .29649 L
.83089 .27097 L
.83221 .2381 L
.83294 .24759 L
Mistroke
.83361 .27087 L
.83481 .3121 L
.83611 .30244 L
.83734 .25537 L
.83847 .23982 L
.83953 .26985 L
.84067 .31044 L
.84174 .30886 L
.84272 .27321 L
.84387 .24007 L
.84512 .26285 L
.84629 .30736 L
.84739 .30947 L
.84852 .26778 L
.84976 .24009 L
.85098 .27415 L
.85229 .31436 L
.85344 .29199 L
.85465 .2461 L
.85569 .24806 L
.85682 .29231 L
.85813 .31133 L
.85935 .26748 L
.85998 .24603 L
.86068 .24272 L
.86141 .26388 L
.86209 .29312 L
.86335 .31082 L
.86449 .26896 L
.86513 .24681 L
.86582 .24318 L
.86708 .28801 L
.8683 .31197 L
.86942 .27399 L
.8707 .24246 L
.87191 .28225 L
.87304 .31276 L
.87407 .28535 L
.8752 .24422 L
.8764 .26646 L
.87771 .3118 L
.8789 .28321 L
.87955 .25487 L
.88027 .2431 L
.88157 .28694 L
.88278 .30971 L
.88407 .25981 L
.88517 .24734 L
.88639 .29655 L
.88708 .31143 L
Mistroke
.88781 .29576 L
.88911 .24542 L
.88983 .25194 L
.89051 .28065 L
.89125 .30807 L
.89204 .303 L
.89326 .25172 L
.89457 .26556 L
.89532 .29945 L
.896 .31023 L
.89669 .29066 L
.89734 .26021 L
.89858 .25492 L
.89929 .28672 L
.89994 .30863 L
.90063 .30193 L
.90126 .27409 L
.90199 .2471 L
.90268 .25201 L
.90392 .30447 L
.90507 .2898 L
.90627 .24548 L
.90759 .28914 L
.9083 .30936 L
.90894 .29731 L
.90968 .26236 L
.91038 .24567 L
.9116 .2899 L
.9123 .3091 L
.91293 .29571 L
.91362 .26263 L
.91427 .24603 L
.91497 .26329 L
.91573 .29927 L
.91653 .3051 L
.91728 .27255 L
.91796 .24768 L
.9187 .2588 L
.91936 .29079 L
.92007 .30847 L
.92135 .25923 L
.92261 .26552 L
.92376 .30819 L
.92501 .26163 L
.92572 .24753 L
.92638 .27032 L
.92707 .30222 L
.92772 .30406 L
.92847 .27026 L
.92915 .24752 L
Mistroke
.93032 .28786 L
.93156 .29427 L
.93263 .24865 L
.9338 .28502 L
.93505 .29494 L
.93576 .25946 L
.93641 .24883 L
.9376 .30007 L
.93886 .27637 L
.94006 .25513 L
.94137 .30676 L
.94261 .25747 L
.94375 .27093 L
.94478 .30614 L
.94591 .25778 L
.9471 .27418 L
.9482 .30329 L
.94949 .2493 L
.95072 .29502 L
.95182 .28615 L
.95302 .25266 L
.95432 .30573 L
.95504 .28167 L
.9557 .25148 L
.95699 .29428 L
.95819 .27845 L
.95924 .25366 L
.96039 .30458 L
.96158 .25977 L
.9627 .2745 L
.96375 .30133 L
.9647 .2548 L
.9658 .28227 L
.96684 .29582 L
.96797 .2505 L
.96917 .30231 L
.97019 .27097 L
.97132 .26644 L
.97253 .29847 L
.97383 .25315 L
.97506 .30418 L
.97619 .25501 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{350, 216.312},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006e00013R000`400?l00000o`00003ooooooonf
ooooo`00oooooonfooooo`00oooooonfooooo`00oooooonfooooo`00oooooonfooooo`00oooooonf
ooooo`00oooooonfooooo`00:_ooool2o`000?ooooooR_ooool002[ooooo00?o0000ooooooooool0
oooooon9ooooo`00:_ooool00ol0003oooooooooo`3oooooohWooooo000Zooooo`03o`000?oooooo
oooo0?ooooooROooool002[ooooo00?o0000ooooooooool0oooooon9ooooo`00:_ooool00ol0003o
ooooooooo`3oooooohWooooo000Zooooo`03o`000?oooooooooo03[ooooo1?oo003ooooood_ooooo
000Zooooo`;o0000>Oooool6ool00?ooooooBoooool002[ooooo00?o0000ooooooooool0>?ooool3
ool00004ooooool00?oo003oo`00ooooooooB_ooool002[ooooo00?o0000ooooooooool0>oooool0
1Ol00?oooooooooooooooooo003o0?ooooooBOooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1_ooool00ol0003ok^k^ooooo`04ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
1_ooool00ol0003oooooooooo`0jooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool0
oooooom6ooooo`001_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B46ooooo`03oeEE
EOnYZJWooooo00Oooooo00?oMgMgoc8b<_ooool01Oooool00ol0003oooooooooo`0iooooo`03o`00
oooooooooooo00Cooooo00?oo`00o`00ooooool0oooooom6ooooo`001?l00002ooooo`05oa0@4?oo
ooooooooooooool@41003Oooool00onYZJWoEEEEooooo`08ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0>Oooool00ol00?ooooooooooo`04ooooo`;oo`0000?o003oooooooooool0
oooooom4ooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?o8B4Qooooooooool0
1_ooool00omgMgOo<S8booooo`05ooooo`?o0000>?ooool00ol00?ooooooooooo`06ooooo`03ool0
0?l00?oooooo0?ooooooAOooool000Kooooo00Go0000ooooooooooooooooo`00000>ooooo`03oeEE
EOo<c<cooooo00?ooooo00Go0000ob4Q8Ol0003o<S8bolc<c006ooooo`03o`000?oooooooooo03Go
oooo0_oo00000ol00?ooooooooooo`07ooooo`;oo`0000?o003oooooooooool0oooooom3ooooo`00
1_ooool01Ol@413ooooooooooooooooo410@00kooooo00?oZJVYogMgMoooool00oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo03Gooooo0_oo00000ol00?ooooooooooo`08ooooo`03
ool00?l00?oooooo0?ooooooA?ooool000Kooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
oa0@4?oooooooooooooooolb<S801?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
03Cooooo0_oo00000ol00?ooooooooooo`09ooooo`03ool00?l00?oooooo0?ooooooA?ooool000Ko
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`Go00001?ooool4o`0000Oooooo00?o0000oooo
ooooool0<oooool3ool00003o`00oooooooooooo00_ooooo00?o003oooooooooool0oooooom2oooo
o`00:_ooool00ol0003oooooooooo`0cooooo`;oo`0000?oooooo`00ooooool03?ooool00ol00?oo
ooooooooo`3ooooood;ooooo000Zooooo`;o0000=?ooool2ool00003o`00oooooooooooo00cooooo
00?o003oooooooooool0oooooom2ooooo`00:_ooool00ol0003oooooooooo`0eooooo`03o`00oooo
oooooooo00gooooo00?o003oooooooooool0oooooom1ooooo`00:_ooool00ol0003oooooooooo`0e
ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool0oooooom1ooooo`00:_ooool00ol0
003oooooooooo`0dooooo`03o`00oooooooooooo00gooooo00?oo`00o`00ooooool0oooooom2oooo
o`00:_ooool00ol0003oooooooooo`0dooooo`03o`00oooooooooooo00gooooo00?oo`00o`00oooo
ool0oooooom2ooooo`00:_ooool00ol0003oooooooooo`0cooooo`03o`00oooooooooooo00kooooo
0_oo00000ol00?ooooooooooo`3ooooood3ooooo000Zooooo`;o0000<_ooool2ool00003o`00oooo
oooooooo00kooooo0_oo00000ol00?ooooooooooo`3ooooood3ooooo000Zooooo`03o`000?oooooo
oooo037ooooo0_oo00000ol00?ooooooooooo`0?ooooo`03ool00?l00?oooooo0?oooooo@Oooool0
02[ooooo00?o0000ooooooooool0<?ooool2ool00003o`00oooooooooooo013ooooo00?oo`00o`00
ooooool0oooooom1ooooo`00:_ooool00ol0003oooooooooo`0`ooooo`;oo`0000?o003ooooooooo
ool04_ooool00ol00?ooooooooooo`3oooooocoooooo000Zooooo`03o`000?oooooooooo033ooooo
0_oo00000ol00?ooooooooooo`0Booooo`03o`00oooooooooooo0?oooooo?oooool002[ooooo00?o
0000ooooooooool0<_ooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo0?oooooo?ooo
ool002[ooooo0_l0000booooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool0ooooooln
ooooo`00:_ooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo01Cooooo00?o003ooooo
ooooool0oooooolnooooo`00:_ooool00ol0003oooooooooo`0aooooo`03o`00oooooooooooo01?o
oooo00?oo`00o`00ooooool0ooooooloooooo`00:_ooool00ol0003oooooooooo`0aooooo`03o`00
oooooooooooo01?ooooo00?oo`00o`00ooooool0ooooooloooooo`00:_ooool00ol0003ooooooooo
o`0`ooooo`03o`00oooooooooooo01Cooooo0_oo00000ol00?ooooooooooo`3oooooocgooooo000Z
ooooo`03o`000?oooooooooo02kooooo0_oo00000ol00?ooooooooooo`0Dooooo`;oo`0000?o003o
ooooooooool0oooooolmooooo`00:_ooool00ol0003oooooooooo`0^ooooo`;oo`0000?o003ooooo
ooooool05?ooool2ool00003o`00oooooooooooo0?oooooo?Oooool002[ooooo0_l0000^ooooo`?o
o`0000?o003oooooooooool05?ooool2ool00003o`00oooooooooooo0?oooooo?Oooool002[ooooo
00?o0000ooooooooool0;Oooool2ool00003ooooool00?oooooo01Oooooo00?o003oooooooooool0
oooooolmooooo`00:_ooool00ol0003oooooooooo`0]ooooo`;oo`0000?o003oooooooooool06?oo
ool00ol00?ooooooooooo`3ooooooccooooo000>ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@06ooooo`03o`000?oooooooooo02gooooo
0_oo00000ol00?ooooooooooo`0Hooooo`03o`00oooooooooooo0?oooooo??ooool000kooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`05ooooo`03o`00
0?oooooooooo02oooooo00?o003oooooooooool06?ooool00ol00?ooooooooooo`3ooooooccooooo
0006ooooo`Ko00000_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0_ooooo`03o`00oooooooooooo01Sooooo00?o003oooooooooool0
oooooollooooo`003_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool0
1Oooool3o`0002kooooo00?o003oooooooooool06Oooool00ol00?ooooooooooo`0]ooooo`;o003o
ooooool=ooooo`003_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o
<S8bolc<c006ooooo`03o`000?oooooooooo02kooooo00?o003oooooooooool06?ooool2ool00003
o`00oooooooooooo02cooooo0_l00?l00ooo003oooooooooo`3oooooo`[ooooo000>ooooo`05oa0@
4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02ko
oooo00?o003oooooooooool06?ooool2ool00003o`00oooooooooooo02_ooooo00Co003ooooooooo
003o003oooooool<ooooo`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0[ooooo`;oo`0000?oooooo`00ooooool06Oooool2ool0
0003o`00oooooooooooo02_ooooo00Co003ooooooooo003o003oooooool<ooooo`003_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00007ooooo`03o`000?oooooooooo02_ooooo0_oo0000
0ol00?ooooooooooo`0Iooooo`;oo`0000?o003oooooooooool0:Oooool01_oo003o003ooooooooo
ooooo`00o`00oooooooo3?ooool002[ooooo00?o0000ooooooooool0:oooool2ool00003o`00oooo
oooooooo01Wooooo0_oo00000ol00?ooooooooooo`0Xooooo`;oo`0000?o003oooooooooool00_oo
00000ol00?ooooooooooo`3oooooo`Wooooo000Zooooo`;o0000;?ooool2ool00003o`00oooooooo
oooo01cooooo00?o003oooooooooool09oooool2ool00003o`00oooooooooooo00;ooooo00?o003o
ooooooooool0ooooool9ooooo`00:_ooool00ol0003oooooooooo`0[ooooo`;oo`0000?o003ooooo
ooooool07?ooool00ol00?ooooooooooo`0Wooooo`03ool00?l00?oooooo00Cooooo00?o003ooooo
ooooool0ooooool9ooooo`00:_ooool00ol0003oooooooooo`0[ooooo`;oo`0000?o003ooooooooo
ool07?ooool00ol00?ooooooooooo`0Wooooo`03ool00?l00?oooooo00Gooooo00?o003ooooooooo
ool0ooooool8ooooo`00:_ooool00ol0003oooooooooo`0/ooooo`03o`00oooooooooooo01gooooo
00?o003oooooooooool09oooool00ooo003o003oooooo`05ooooo`03o`00oooooooooooo0?oooooo
2?ooool002[ooooo00?o0000ooooooooool0;?ooool00ol00?ooooooooooo`0Mooooo`03o`00oooo
oooooooo02Sooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`3oooooo`Sooooo000Z
ooooo`03o`000?oooooooooo02cooooo00?o003oooooooooool07_ooool00ol00?ooooooooooo`0V
ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool0ooooool8ooooo`00:_ooool2o`00
02gooooo00?o003oooooooooool07?ooool2ool00003o`00oooooooooooo02Kooooo00?o003ooooo
ooooool01?ooool00ooo003o003oooooo`3oooooo`Wooooo000Zooooo`03o`000?oooooooooo02_o
oooo00?o003oooooooooool07Oooool2ool00003o`00oooooooooooo02Kooooo00?o003ooooooooo
ool01?ooool00ooo003o003oooooo`0Gooooo`?oo`00k_ooool002[ooooo00?o0000ooooooooool0
:Oooool2ool00003o`00oooooooooooo01gooooo0_oo00000ol00?ooooooooooo`0Vooooo`03o`00
oooooooooooo00Cooooo00?oo`00o`00ooooool05_ooool2ool000;o003ok_ooool002[ooooo00?o
0000ooooooooool0:Oooool2ool00003o`00oooooooooooo01gooooo0_oo00000ol00?oooooooooo
o`0Tooooo`;oo`0000?o003oooooooooool01?ooool00ooo003o003oooooo`0Fooooo`;oo`0000?o
003oooooool00?l0kOooool002[ooooo00?o0000ooooooooool0:Oooool2ool00003o`00oooooooo
oooo01gooooo0_oo00000ol00?ooooooooooo`0Tooooo`;oo`0000?o003oooooooooool01?ooool2
ool00003o`00oooooooooooo01Cooooo00Goo`00o`00ooooooooooooo`00o`3]ooooo`00:_ooool0
0ol0003oooooooooo`0Xooooo`?oo`0000?o003oooooooooool07Oooool2ool00003o`00oooooooo
oooo02Cooooo00?oo`00o`00ooooool02?ooool00ol00?ooooooooooo`0Dooooo`05ool00?l00?oo
ooooooooool00?l0kOooool002[ooooo0_l0000Yooooo`;oo`0000?o003oooooooooool08Oooool0
0ol00?ooooooooooo`0Sooooo`03ool00?l00?oooooo00Sooooo00?o003oooooooooool05Oooool0
1?l00?ooooooooooool00?o]ooooo`00:_ooool00ol0003oooooooooo`0Xooooo`;oo`0000?o003o
ooooooooool08Oooool00ol00?ooooooooooo`0Sooooo`03ool00?l00?oooooo00Sooooo00?o003o
ooooooooool05Oooool01?l00?ooooooooooool00?o]ooooo`00:_ooool00ol0003oooooooooo`0Z
ooooo`03o`00oooooooooooo027ooooo00?o003oooooooooool08oooool00ooo003o003oooooo`08
ooooo`03o`00oooooooooooo01Cooooo00Go003oooooooooooooooooo`00o`0@ooooo`?oo`00f_oo
ool002[ooooo00?o0000ooooooooool0:_ooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooo
oooo02Cooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`0Dooooo`05o`00oooooooo
ooooool00?l00?l04?ooool00ooo003o003oo`00o`3Jooooo`00:_ooool00ol0003oooooooooo`0Z
ooooo`03o`00oooooooooooo027ooooo00?o003oooooooooool09?ooool00ol00?ooooooooooo`07
ooooo`03o`00oooooooooooo01Cooooo00?o003oooooooooool00_oo00000ol00?ooooooooooo`0=
ooooo`03ool00?l00?oo003o0=[ooooo000Zooooo`03o`000?oooooooooo02Wooooo00?o003ooooo
ooooool08?ooool2ool00003o`00oooooooooooo02Cooooo00?o003oooooooooool01_ooool00ooo
003o003oooooo`0Dooooo`04ool00?l00?ooooooooooo`;oo`0000?o003oooooooooool03?ooool2
ool00003o`00oooooooo003o0=Wooooo000Zooooo`03o`000?oooooooooo02Wooooo00?o003ooooo
ooooool08?ooool2ool00003o`00oooooooooooo02?ooooo00?o003oooooooooool01oooool00ooo
003o003oooooo`0Dooooo`03ool00?l00?oooooo00;ooooo00?oo`00o`00ooooool03Oooool2ool0
0003o`00oooooooo003o0=Wooooo000Zooooo`;o0000:?ooool2ool00003o`00oooooooooooo023o
oooo0_oo00000ol00?ooooooooooo`0Sooooo`03o`00oooooooooooo00Oooooo0_oo00000ol00?oo
ooooooooo`0Booooo`03ool00?l00?oooooo00;ooooo00?oo`00o`00ooooool03oooool00ol00?oo
ooooo`00o`0<ooooo`;oo`00boooool002[ooooo00?o0000ooooooooool09oooool2ool00003o`00
oooooooooooo023ooooo0ooo00000ol00?ooooooooooo`0Qooooo`03ool00?l00?oooooo00Sooooo
0_oo00000ol00?ooooooooooo`0Aooooo`;oo`0000?o003oooooooooool00_ooool00ol00?oooooo
ooooo`0>ooooo`03o`00oooooooo003o00cooooo00?oo`00o`00ooooool0b_ooool002[ooooo00?o
0000ooooooooool09oooool2ool00003o`00oooooooooooo027ooooo0_oo00000ol00?oooooooooo
o`0Qooooo`03ool00?l00?oooooo00Wooooo00?oo`00o`00ooooool04_ooool00ooo003o003ooooo
o`04ooooo`03o`00oooooooooooo00gooooo00Co003ooooooooooooo003o3?ooool2o`00ol_ooooo
0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00004ooooo`05odA4
A?l0003o0000oc8b<_oMgMd01_ooool00ol0003oooooooooo`0Vooooo`;oo`0000?o003ooooooooo
ool08_ooool2ool00003o`00oooooooooooo027ooooo00?oo`00o`00ooooool02Oooool00ooo003o
003oooooo`0Booooo`03ool00?l00?oooooo00Gooooo00?o003oooooooooool03?ooool01?l00?oo
ooooooooool00?l<ooooo`03o`00oooo003o003o0<[ooooo0006ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;o
oooo00Gooooo00?o0000ooooooooool09_ooool2ool00003o`00oooooooooooo02Cooooo00?o003o
ooooooooool08?ooool2ool00003o`00oooooooooooo00Wooooo00?o003oooooooooool04_ooool0
0ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00cooooo00Co003ooooooooo003o003o3?oo
ool00ol00?ooo`00o`00o`09ooooo`03ool00?l00?oooooo0;kooooo0004o`0000;ooooo00Go410@
oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0Vooooo`;oo`0000?o003oooooooooool09?ooool00ol00?oooooooooo
o`0Pooooo`;oo`0000?o003oooooooooool02Oooool00ol00?ooooooooooo`0Booooo`03o`00oooo
oooooooo00Cooooo00?o003oooooooooool03?ooool01?l00?ooooooool00?l00?l<ooooo`03o`00
oooooooo003o00Wooooo00?oo`00o`00ool00?l0__ooool000Kooooo00Go0000oooooooooooooooo
o`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?oMgMgoc8b<_ooool01Oooool3o`0002Sooooo
00?o003oooooooooool09?ooool00ol00?ooooooooooo`0Pooooo`;oo`0000?o003oooooooooool0
2Oooool00ol00?ooooooooooo`0Booooo`03o`00oooooooooooo00Cooooo00?o003oooooooooool0
2oooool01Ooo003o003ooooooooo003o003o00cooooo00?o003oooooool00?l02Oooool00ooo003o
003oo`00o`2nooooo`001_ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_oo
ool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Kooooo00?o0000ooooooooool0:?ooool00ol0
0?ooooooooooo`0Tooooo`03o`00oooooooooooo027ooooo00?o003oooooooooool02oooool00ol0
0?ooooooooooo`0Aooooo`03o`00oooooooooooo00?ooooo00?oo`00o`00ooooool03?ooool01_oo
003o003ooooooooo003o003oool000_ooooo00?o003oooooool00?l02?ooool2ool000;o003o1ooo
ool00ooo003o003oooooo`2dooooo`001_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02Sooooo00?o
003oooooooooool09?ooool00ol00?ooooooooooo`0Qooooo`03o`00oooooooooooo00_ooooo00?o
003oooooooooool04Oooool00ol00?ooooooooooo`03ooooo`03ool00?l00?oooooo00_ooooo0_oo
00001Ol00?ooooooooooool00?ooo`0000Wooooo0_oo00000ol00?ooooooo`00o`08ooooo`04ool0
0?l00?ooooooo`00o`Oooooo00?oo`00o`00ool00?l01_ooool2ool00:cooooo0006ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Cooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0Wooooo`03o`00oooooooooooo02Kooooo00?o003ooooo
ooooool08?ooool00ol00?ooooooooooo`0:ooooo`03ool00?l00?oooooo01;ooooo00?o003ooooo
ooooool00oooool00ooo003o003oooooo`0;ooooo`;oo`0000Go003ooooooooooooo003oool00009
ooooo`03ool00?l00?oooooo00;ooooo00?o003oooooooooool01Oooool01?oo003o003oooooool0
0?l7ooooo`03ool00?l00?oo003o00Kooooo00?oo`00o`00ooooool0Zoooool000Kooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Oooooo
00?o0000ooooooooool09oooool00ol00?ooooooooooo`0Tooooo`;oo`0000?o003oooooooooool0
8?ooool00ol00?ooooooooooo`0:ooooo`03ool00?l00?oooooo017ooooo00?oo`00o`00ooooool0
1?ooool00ooo003o003oooooo`0;ooooo`03ool00?l00?oooooo00?ooooo00?o003oooooooooool0
1oooool00ooo003o003oooooo`02ooooo`03o`00oooooooooooo00Kooooo00?o003oool00?l00?l0
1oooool00ooo003o003oo`00o`06ooooo`03ool00?l00?oo003o00Kooooo00?o003oooooooooool0
X_ooool002[ooooo00?o0000ooooooooool09oooool00ol00?ooooooooooo`0Tooooo`;oo`0000?o
003oooooooooool08?ooool00ol00?ooooooooooo`0:ooooo`03ool00?l00?oooooo017ooooo00?o
o`00o`00ooooool01?ooool00ooo003o003oooooo`0<ooooo`03o`00oooooooooooo00;ooooo00?o
003oooooooooool01oooool00ooo003o003oooooo`02ool00003o`00oooooooooooo00Kooooo00?o
003oool00?l00?l01_ooool2ool000;o003o1oooool2o`00o`Kooooo00?o003oooooooooool0X_oo
ool002[ooooo0_l0000Vooooo`;oo`0000?o003oooooooooool09?ooool2ool00003o`00oooooooo
oooo023ooooo00?o003oooooooooool02_ooool00ooo003o003oooooo`0@ooooo`;oo`0000?o003o
ooooooooool00oooool00ooo003o003oooooo`0<ooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool01oooool00ooo003o003oooooo`02ool00003o`00oooooooooooo00Kooooo00?o003o
ool00?l00?l01_ooool01?oo003o003oool00?l00?l7ooooo`;o003o1_ooool00ol00?oooooooooo
o`03ooooo`03ool00?l00?oooooo09cooooo000Zooooo`03o`000?oooooooooo02Gooooo0_oo0000
0ol00?ooooooooooo`0Uooooo`03ool00?l00?oooooo01oooooo0_oo00000ol00?ooooooooooo`0:
ooooo`03ool00?l00?oooooo013ooooo0_oo00000ol00?ooooooooooo`05ooooo`03o`00oooooooo
oooo00[ooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`08ooooo`05o`00oooooooo
o`00ool00?l00?l02?ooool01?l00?ooo`00ool00?l00?l6ooooo`03o`00oooo003o003o00Kooooo
00?o003oool00?l00?l01_ooool00ol00?ooooooooooo`03ooooo`03ool00?l00?oooooo00Cooooo
00?o003oooooooooool00_ooool2ool0097ooooo000Zooooo`03o`000?oooooooooo02Cooooo0_oo
00000ol00?ooooooooooo`0Vooooo`03ool00?l00?oooooo01oooooo0_oo00000ol00?oooooooooo
o`0:ooooo`03ool00?l00?oooooo013ooooo00?oo`00o`00ooooool01oooool00ol00?oooooooooo
o`0:ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool02?ooool01Ol00?oooooooooo
oooo003o003o00Sooooo00Co003oool00?oo003o003o1_ooool01?l00?ooo`00o`00oooo0005oooo
o`03o`00oooooooo003o00Gooooo00?o003oool00?l00?l01?ooool00ooo003o003oooooo`04oooo
o`;o003o0oooool00ooo003o003oooooo`2@ooooo`00:_ooool00ol0003oooooooooo`0Tooooo`;o
o`0000?o003oooooooooool09oooool00ol00?ooooooooooo`0Nooooo`;oo`0000?o003ooooooooo
ool02oooool00ol00?ooooooooooo`0@ooooo`03o`00oooooooooooo00Kooooo00?o003ooooooooo
ool02_ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00Sooooo00Go003ooooooooo
ooooo`00o`00o`08ooooo`04o`00ooooooooooooo`00o`Kooooo00Co003oooooool00?ooo`001?oo
ool01?oo003o003oooooool00?l4ooooo`04ool00?l00?ooo`00o`00o`Cooooo00?o003oool00?l0
0?l01?ooool2o`00o`?ooooo00?oo`00o`00ooooool00_ooool00ooo003o003oooooo`02ooooo`;o
o`00Qoooool002[ooooo00?o0000ooooooooool09?ooool2ool00003o`00oooooooooooo02Sooooo
00?o003oooooooooool07Oooool00ooo003o003oooooo`0>ooooo`03o`00oooooooooooo00oooooo
00?o003oooooooooool01_ooool00ol00?ooooooooooo`0:ooooo`06o`00oooooooooooooooooooo
003o003o2_ooool01Ol00?oooooooooooooo003o003o00Kooooo0_oo00001?l00?ooooooooooool0
0?l6ooooo`04o`00ooooooooo`00o`00o`Cooooo00Coo`00o`00oooooooo003o1?ooool01?oo003o
003oool00?l00?l4ooooo`03o`00oooo003o003o00?ooooo00?oo`00o`00ool00?l00oooool00ooo
003o003oool00002ooooo`03ool00?l00?oo003o00;ooooo00?oo`00o`00oooo00000oooool00ol0
0?ooooooooooo`20ooooo`00:_ooool00ol0003oooooooooo`0Vooooo`03o`00oooooooooooo02So
oooo00?o003oooooooooool07Oooool00ooo003o003oooooo`0>ooooo`03o`00oooooooooooo00oo
oooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`09ooooo`03ool00?l00?oooooo00;o
oooo00?oo`00o`00ooooool02Oooool01Ol00?oooooooooooooooooo003o00Kooooo0_oo00001?l0
0?ooooooooooool00?l6ooooo`04o`00ooooooooo`00o`00o`Cooooo00Coo`00o`00oooooooo003o
1?ooool01?oo003o003oool00?l00?l3ooooo`04ool00?l00?ooo`00o`00o`?ooooo00?oo`00o`00
ool00?l01?ooool01Ol00?ooo`00ooooooooooooo`0000;o003o0_ooool00ooo003o003oo`00o`03
ooooo`05o`00ooooooooooooooooool00?l00_ooool00ooo003o003oooooo`1iooooo`00:_ooool2
o`0002Oooooo00?o003oooooooooool0:?ooool00ol00?ooooooooooo`0Mooooo`03ool00?l00?oo
oooo00kooooo00?o003oooooooooool03oooool00ol00?ooooooooooo`05ooooo`03ool00?l00?oo
oooo00[ooooo00?o003oool00?ooool00_ooool00ooo003o003oooooo`09ooooo`05o`00oooooooo
ooooooooool00?l01_ooool2ool00004o`00ooooooooooooo`00o`Kooooo00Co003ooooooooooooo
003o1?ooool01?oo003o003oooooool00?l4ooooo`04ool00?l00?ooo`00o`00o`?ooooo00Coo`00
o`00oooooooo003o0oooool00ooo003o003oo`00o`04ooooo`05o`00oooooooooooooooooooo0000
0_l00?l2ooooo`03ool00?l00?oo003o00?ooooo00Go003oooooooooooooooooo`00o`02ooooo`03
ool00?l00?oooooo00;ooooo00Go003oooooooooooooo`00o`00o`1booooo`00:_ooool00ol0003o
ooooooooo`0Vooooo`03o`00oooooooooooo02Sooooo00?o003oooooooooool07_ooool00ol00?oo
ooooooooo`0=ooooo`03o`00oooooooooooo00oooooo00?o003oooooooooool01Oooool00ooo003o
003oooooo`0:ooooo`03o`00oooo003ooooo00;ooooo00?oo`00o`00oooo00001oooool2ool00005
o`00ooooooooooooooooool00?l01_ooool00ooo003o003oooooo`02ooooo`03o`00oooooooooooo
00?ooooo00Goo`00o`00ooooooooooooo`00o`04ooooo`04ool00?l00?ooooooo`00o`Cooooo00Co
o`00o`00oooo003o003o0oooool01?oo003o003oooooool00?l3ooooo`03ool00?l00?oo003o00Co
oooo0_l00?l2ooooo`03ool00?l00?oo003o00?ooooo0_l00?l2ooooo`;o003o0_ooool01Ooo003o
003oooooooooooooo`0000;o003o0_ooool01Ol00?oooooooooooooo003o003o00;ooooo00?o003o
ooooooooool0KOooool002[ooooo00?o0000ooooooooool09Oooool00ol00?ooooooooooo`0Yoooo
o`03o`00oooooooooooo01kooooo00?o003oooooooooool03Oooool00ol00?ooooooooooo`0?oooo
o`03o`00oooooooooooo00Gooooo00?oo`00o`00ooooool02Oooool00ooo003o003oool00004oooo
o`03o`00oooo003ooooo00Kooooo0_oo00001Ol00?oooooooooooooooooo003o00Kooooo00?oo`00
o`00ooooool00_ooool00ol00?ooooooooooo`03ooooo`05ool00?l00?ooooooooooool00?l01?oo
ool01?oo003o003oool00?l00?l4ooooo`04ool00?l00?ooooooo`00o`?ooooo00Coo`00o`00oooo
oooo003o0oooool00ooo003o003oo`00o`04ooooo`;o003o0_ooool00ooo003o003oo`00o`03oooo
o`;o003o0_ooool2o`00o`;ooooo00Goo`00o`00ooooooooooooool00002o`00o`;ooooo00?o003o
ooooooooool00_l00?l00oooooooo`00o`00o`03ooooo`03o`00oooooooo003o06Wooooo000Zoooo
o`03o`000?oooooooooo02Gooooo00?o003oooooooooool0:?ooool00ooo003o003oooooo`0Ooooo
o`03o`00oooooooooooo00cooooo00?oo`00o`00ooooool03oooool00ooo003o003oooooo`06oooo
o`03ool00?l00?oooooo00Wooooo00?oo`00o`00ooooool01?ooool00ol00?ooo`00ooooo`06oooo
o`;oo`0000Go003oooooooooooooooooo`00o`06ooooo`06ool00?l00?oooooooooooooo003o003o
1Oooool01Ooo003o003ooooooooooooo003o00Gooooo00Co003oool00?oo003o003o1?ooool00ol0
0?ooooooo`00o`03ooooo`04ool00?l00?ooooooo`00o`?ooooo00?oo`00o`00ool00?l00oooool0
0ol00?ooooooo`00o`03ooooo`;o003o0oooool2o`00o`;ooooo0_l00?l2ooooo`03ool00?l00?oo
o`0000;ooooo0_l00?l2ooooo`03o`00oooooooooooo00;o003o00?oooooool00?l00?l00oooool0
1?l00?ooo`00o`00ooooool2ool00006o`00oooo003o003ooooooooo003o003o0oooool2ool005_o
oooo000Zooooo`03o`000?oooooooooo02Gooooo00?o003oooooooooool0:?ooool00ooo003o003o
ooooo`0Oooooo`03o`00oooooooooooo00cooooo00?oo`00o`00ooooool03oooool00ooo003o003o
ooooo`06ooooo`03ool00?l00?oooooo00Wooooo00?oo`00o`00ooooool01Oooool00ol00?oooooo
ooooo`05ooooo`;oo`0000Go003oooooooooooooo`00o`00o`07ooooo`05o`00ooooooooooooool0
0?l00?l01Oooool01Ooo003o003ooooooooooooo003o00Gooooo00Co003oool00?oo003o003o1?oo
ool00ol00?ooooooo`00o`03ooooo`04ool00?l00?ooooooo`00o`?ooooo00?o003oooooool00?l0
0_ooool01?oo003o003oooooool00?l3ooooo`;o003o0oooool2o`00o`04oooooooo003o003oo`00
o`?ooooo0_l00?l2ooooo`;o003o00?oooooool00?l00?l00_ooool2o`00o`05oooooooo003o003o
oooooooo00000_l00?l00ooo003o003oooooo`02ool00006o`00oooo003o003ooooooooo003o003o
0_ooool00ol00?ooo`00o`00o`02ool00003o`00oooooooo003o00Coo`00D_ooool002[ooooo00?o
0000ooooooooool08oooool2ool00003o`00oooooooooooo00;ooooo1Ol0000Qooooo`;oo`0000?o
003oooooooooool02?ooool2o`000003oa0@4?oooooooooo013ooooo00?o003oooooooooool03?oo
ool00ooo003o003oooooo`07ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`00_ooool2ool00003o`00
oooooooooooo00Gooooo00?oo`00o`00ooooool02_ooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo00Gooooo00Soo`00o`00ooooooooc<c<ob4Q8Ooo003o003oolc<c0Kooooo00Go003o
ooooooooooooo`00o`00o`05ooooo`05ool00?l00?ooooooooooool00?l01Oooool01?l00?oooooo
ool00?l00?l4ooooo`03o`00oooooooo003o00Cooooo013o003oo`000?l00?oo0000oa0@4?oooooo
003oonk^k_l00?oo0000oc8b<_oo003o003oooooool00?ooo`000_ooool2o`00o`?ooooo0_l00?l0
1oooooooo`00o`00ool00?ooo`00oooooooo00000_l00?l01oooooooo`00o`00ool00?ooooooool0
0?l00?l00_ooool2o`00o`05oooooooo003o003oo`000?oo00000_l00?l01?oo003o003ooooooooo
0002o`00o`05ool00?l00?ooooooool00?l00?l00_ooool00ol00?ooo`00o`00o`02ool0000:o`00
oooooooo003oool00?l00?ooo`00o`00ooooooooo`00o`00o`Cooooo0_oo000;ooooo`Co000000?o
410@ooooooooool00_ooool2o`000003oa0@4?oooooooooo033ooooo000Zooooo`;o00009?ooool2
ool00003o`00oooooooooooo00;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Qooooo`;oo`0000?o
003oooooooooool02Oooool00ol0003oooooooooo`0?ooooo`03ool00?l00?oooooo00kooooo00?o
o`00o`00ooooool01oooool01OmEEEGoMgMgoooooonHV9So8B4Q00;ooooo0_oo00000ol00?oooooo
ooooo`06ooooo`03o`00oooooooooooo00Wooooo00?o003oooooooooool01?ooool00ol00?oooooo
ooooo`05ooooo`08ool00?l00?ooooooob4Q8OnHV9Soo`00o`00oolQ8B46ooooo`03o`00oooooooo
oooo00;oo`0000?o003oooooooooool00_ooool01Ooo003o003ooooooooo003o003o00Gooooo00Co
003ooooooooo003o003o1?ooool00ol00?ooooooo`00o`04ooooo`03o`00oooo003o003o00?ooooo
00[o003oogMgMol00?oooooooiRHV?oo003o003oooooool00?ooo`000_ooool2o`00o`?ooooo0_l0
0?l01oooooooo`00o`00ool00?ooo`00oooooooo00000_l00?l02Oooooooo`00o`00ool00?ooo`00
o`00oooo003o003oooooo`02o`00o`05oooooooo003o003ooooooooo00000_l00?l01?oo003o003o
o`00oooo0002o`00o`05ool00?l00?ooooooool00?l00?l00_ooool00ol00?ooo`00o`00o`02ool0
000:o`00oooo003o003oool00?l00?ooo`00o`00ooooooooo`00o`00o`?ooooo00Co003oool00?l0
0?oooooo0_l00?l00ooooooo003oooooo`06ooooo`;oo`001oooool00ol0003oooooooooo`0aoooo
o`00:_ooool00ol0003oooooooooo`0Sooooo`03ool00?l00?oooooo00Gooooo00?oV9RHob4Q8Oo^
k^h08_ooool2ool00003o`00oooooooooooo00Kooooo1Ol0000@ooooo`03ool00?l00?oooooo00ko
oooo0_oo00000ol00?ooooooooooo`05ooooo`05o`000?ooooooooooooooool000000_ooool2ool0
0003o`00oooooooooooo00Oooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`04oooo
o`03o`00oooooooooooo00Kooooo00Oo003oooooool0003oooooool00?l00?oo000000Kooooo00?o
003oooooooooool00_oo00000ol00?ooooooooooo`03ooooo`04o`00ooooooooo`00o`00o`Gooooo
00Co003ooooooooooooo003o1?ooool00ol00?ooooooo`00o`04ooooo`03o`00oooo003o003o00?o
oooo00?o003ooa0@4?l00?l00_ooool01Ooo003o003oooooool00?ooo`0000;ooooo0_l00?l2oooo
o`03ool00?l00?oo003o00;ooooo0_l00?l00ooo003oooooool00002o`00o`09oooooooo003o003o
o`00oooo003o003oool00?l00?oooooo00;o003o00Goooooool00?l00?ooooooool00002o`00o`04
ool00?l00?oo003oool000;o003o00Goo`00o`00ooooooooooooo`00o`02ooooo`03o`00oooo003o
003o00;oo`0000Oo003oool00?l00?ooo`00o`00oooo003o003o00;oo`0000So003oool00?l00?oo
o`00o`00oooo003o003oooooo`;o003o00Ooo`00o`00oooooooo003oooooool00?oooooo00?oo`00
0_l00?l01?oooooo003oo`00ool00002ool00004o`000?l00?oo003oooooo`;oo`00;_ooool002[o
oooo00?o0000ooooooooool08_ooool2ool00003o`00oooooooooooo00Gooooo00?oV9RHob4Q8Oo^
k^h08Oooool2ool00003o`00oooooooooooo00Kooooo00CoA4A4omgMgOoooooo00004Oooool00ooo
003o003oooooo`0@ooooo`03o`00oooooooooooo00Gooooo00Go0000oiRHV?ooooooV9RHob4Q8@02
ooooo`;oo`0000?o003oooooooooool01oooool00ol00?ooooooooooo`08ooooo`03o`00oooooooo
oooo00Cooooo00?o003oooooooooool01_ooool01ol00?oooooooc8b<_nHV9Soo`00o`00oolb<S80
1_ooool00ol00?ooooooooooo`02ool00003o`00oooooooooooo00?ooooo00Co003ooooooooo003o
003o1Oooool01?l00?ooooooooooool00?l4ooooo`03o`00oooo003o003o00Cooooo00?o003oool0
0?l00?l00oooool00ol00?oo0000o`00o`02ooooo`04ool00?l00?ooooooo`00o`;oo`0000?o003o
ool00?l00?l00_ooool00ooo003o003oo`00o`02ooooo`03o`00oooooooo003o00;oo`000_l00?l0
2Oooooooo`00o`00ool00?ooo`00o`00oooo003o003oooooo`02o`00o`;ooooo0_l00?l01?oo003o
003oo`00oooo0002o`00o`05ooooool00?oo003oool00?l00?l00_ooool01Ol00?ooo`00o`00ool0
0?ooo`0000;o003o00Soo`00o`00oooo003o003oool00?l00?ooooooo`00o`;oo`0000So003oool0
0?l00?ooo`00o`00oooo003o003oooooo`;o003o00Ooo`00o`00oooo003o003oool00?l00?oooooo
00?oo`000_l00?l01Ooooooo003oo`00oom4A4Co003o00;oo`000ol00?l00ooo003o003oool00003
ooooo`03o`00oooo003ooooo00;ooooo0_oo00000oooooooo`00ool0000Pooooo`00:_ooool00ol0
003oooooooooo`0Rooooo`;oo`0000?o003oooooooooool01_ooool00omgMgOoIVIVooooo`0Roooo
o`03o`00oooooooooooo00Kooooo00CogMgMoeEEEOoooooo00004Oooool00ooo003o003oooooo`0@
ooooo`03o`00oooooooooooo00Gooooo00Go0000oeEEEOl0003o410@olc<c004ooooo`03o`00oooo
oooooooo00Oooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`03ooooo`03ool00?l0
0?oooooo00Oooooo00Oo003oooooooo<c<co0000ool00?l00?ooc<c<00Gooooo00?oo`00o`00oooo
ool00oooool00ol00?ooooooooooo`03ooooo`04o`00ooooooooo`00o`00o`Cooooo00Goo`00o`00
ooooooooooooo`00o`03ooooo`04ool00?l00?ooo`00o`00o`Cooooo00?o003oool00?l00?l00_oo
ool01?oo003o003oool00?l00?l2ooooo`04ool00?l00?ooooooo`00o`;oo`0000?o003oooooool0
0?l00_ooool00ooo003o003oo`00o`02ooooo`03o`00oooooooo003o00;oo`000_l00?l02Ooooooo
o`00o`00ool00?ooooooo`00oooo003o003oooooo`02o`00o`;ooooo0_l00?l01?oooooo003oo`00
ooooool2o`00o`04ooooool00?oo003oogMgM`;o003o00?oooooo`00oooo00000_l00?l00ooooooo
003oo`00o`02o`00o`06ool00?l00?ooo`00o`00oooooooo003o0_oo00002?l00?ooo`00o`00oooo
003o003oool00?l00?oooooo0_l00?l01Ooo003o003oool00?l00?ooo`0000;o003o0ooo0002o`00
o`05ooooool00?oo003oool00?l00?l00_oo0003o`00o`03ool00?l00?ooo`0000?ooooo0ol00?l2
ooooo`;oo`0000?o003oool00?oo00008?ooool002[ooooo00?o0000ooooooooool08_ooool2ool0
0003o`00oooooooooooo00Oooooo00?o0000ooooooooool08Oooool00ol00?ooooooooooo`07oooo
o`03ogMgMoo<c<co0000017ooooo00?oo`00o`00ooooool04?ooool00ol00?ooooooooooo`05oooo
o`03oeEEEOn7QhOooooo00Kooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`07oooo
o`03ool00?l00?oooooo00Cooooo00?oo`00o`00ooooool01oooool01ol00?oooooooa0@4?nj^[[o
ooooo`00ool@41001Oooool00ooo003o003oooooo`03ooooo`03o`00oooooooooooo00?ooooo00Co
003ooooooooo003o003o1?ooool01Ooo003o003ooooooooooooo003o00?ooooo00Goo`00o`00oooo
003o003oool00003ooooo`03o`00oooo003o003o00;ooooo00Coo`00o`00oooo003o003o0_ooool0
1?l@413o003oooooool00?l2ool00004o`00oooooooo003oooooo`;oo`000_l00?l2ooooo`09o`00
oooooooo003oooooool00?ooooooo`00ooooooooo`0000;o003o00Goooooo`00oooo003o003oool0
0002o`00o`;ooooo0_l00?l01?oooooo003oo`00ooooool2o`00o`04ooooool00?oo003oooooo`;o
003o00?oooooo`00oooo00000_l00?l00ooooooo003oo`00o`02o`00o`05ool00?l00?ooo`00o`00
ooooool00_l00?l02Ooooooo003oool00?l00?ooo`00o`00oooo003o003oooooo`02o`00o`05ool0
0?l00?ooo`00o`00oooo00000_l00?l00ooo003o003oool00002o`00o`05ooooool00?oo003oool0
0?l00?l00_oo0003o`00o`03ool00?l00?oo003o00?ooooo1?l00?l01Oooooooo`00o`00ool00?oo
o`0000;o003o7oooool002[ooooo00?o0000ooooooooool09?ooool00ol00?ooooooooooo`03oooo
o`05o`000?nj^[[ooooooiRHV?l@41008oooool00ol00?ooooooooooo`07ooooo`03onk^k_m4A4Co
0000017ooooo00?oo`00o`00ooooool04?ooool00ol00?ooooooooooo`05ooooo`03omgMgOl@413o
V9RH00Kooooo00?o003oooooooooool01oooool00ol00?ooooooooooo`07ooooo`03ool00?l00?oo
oooo00Cooooo00?oo`00o`00ooooool01oooool01ol00?ooooooo`000?nj^[[oooooo`00ool00000
1Oooool00ooo003o003oooooo`03ooooo`03o`00oooooooooooo00?ooooo00Co003ooooooooooooo
003o0oooool2ool00004o`00ooooooooooooo`00o`?ooooo00Goo`00o`00oooooooo003oool00002
ooooo`04ool00?l00?ooo`00o`00o`;ooooo01Coo`00o`00oooo003o003ooooooonHV9SoMgMgo`00
oooooooo003ooooooooo003o003oooooool00?ooooooool00?l00?ooo`00o`00o`;ooooo00Oo003o
ooooool00?ooooooo`00oooooooo003o00;ooooo0_l00?l01Ooooooo003oooooool00?ooo`0000;o
003o0_ooool2o`00o`04ooooool00?oo003oooooo`;o003o00Co0000o`00ool00?ooV9RH0_l00?l0
0ooooooo003oool00002o`00o`03ool00?l00?oo003o00Co003o00?oooooo`00ool00?l01?l00?l0
1ooo003o003oool00?l00?ooooooo`00oooo00001?l00?l00ooo003o003oool00002o`00o`03ool0
0?l00?ooo`0000;o003o00?oo`00o`00ool00?l00_l00?l00ooo003o003oo`00o`07o`00o`03oooo
ool00?oo003o00;o003o00Goooooool00?l00?oo003oool00002o`00oaoooooo000Zooooo`03o`00
0?oooooooooo02Cooooo00?o003oooooooooool00oooool01OnHV9So410@o`000?lQ8B7oc<c<02Co
oooo00?o003oooooooooool01oooool00omgMgOo0000ooooo`0Aooooo`03o`00oooooooooooo00oo
oooo00?o003oooooooooool01_ooool01?o<c<coA4A4o`000?l@4103ooooo`03o`00oooooooooooo
00Kooooo0_oo00000ol00?ooooooooooo`07ooooo`03ool00?l00?oooooo00Cooooo00?oo`00o`00
ooooool01_ooool02?oo003o003ooooooonYZJWo410@o`000?l00?ooZJVY1Oooool00ooo003o003o
ooooo`03ooooo`04o`00ooooooooooooooooo`;oo`0000Co003ooooooooooooo003o0oooool2ool0
0004o`00ooooooooooooo`00o`;ooooo0_oo00001?l00?ooooooo`00oooo0002ooooo`0Jool00?l0
0?ooIVIVo`000?l00?ooooooool00?l00?ooo`00o`00oooo003o<S8bonk^k_l00?ooooooo`00oooo
ooooo`00o`00oooooooo003ooooooooo003o003oooooool00?l2ooooo`07o`00oooooooo003ooooo
ool00?ooo`00o`00o`02ooooo`;o003o00Goooooo`00oooooooo003oool00002o`00o`;ooooo0_l0
0?l01?mVIVKo003oo`00ooooool2o`00o`04oiRHV?l00?oo003oob4Q8@;o003o00?oo`00o`00oooo
00000_l00?l00ooo003o003oo`00o`04o`00o`03ooooool00?oo003o00Co003o00?oooooo`00ool0
0?l00ol00?l00ooo003o003oo`00o`02o`00o`03ool00?l00?ooo`0000Co003o00CoIVIVo`00ool0
0?ooo`003_l00?l00ooooooo003oo`00o`03o`00o`04ool00?l00?oo003oool000;o003o7oooool0
02[ooooo0_l0000Tooooo`03o`00oooooooooooo02gooooo00?o003oooooooooool06oooool00ol0
0?ooooooooooo`0?ooooo`03o`00oooooooooooo00gooooo00?o003oooooooooool01_ooool2ool0
0003o`00oooooooooooo00Kooooo00?oo`00o`00oooo00001Oooool00ooo003o003oooooo`06oooo
o`03ool00?l00?oooooo00?ooooo00?o003oooooooooool01?ooool00ooo003o003oooooo`03oooo
o`04o`00ooooooooooooooooo`;oo`0000Co003ooooooooooooo003o0oooool2ool00004o`00oooo
ooooo`00o`00o`;ooooo0_oo00001?l00?ooooooo`00oooo0002ooooo`0;ool00?l00?oooooooooo
ool00?ooooooool00?l00?ooooooo`00oooo00000_ooool02?l00?ooooooo`00ooooooooo`00o`00
oooooooo003o0_ooool05Ol00?ooooooo`00ooooooooo`00o`00oooooooo003oooooool00?ooo`00
o`00oooooooo003oool00?l00?ooooooo`00oooooooo003oool00002o`00o`;oo`000_l00?l01?oo
oooo003oo`00ooooool2o`00o`04ooooool00?oo003oooooo`;o003o00?oo`00o`00oooo00000_l0
0?l00ooo003o003oo`00o`03o`00o`03ool00?l00?oo003o00Go003o00?oo`00o`00ool00?l02?l0
0?l00ooo003o003oooooo`07o`00o`03ool00?l00?oo003o00co003o00?oo`00o`00ool00?l00ol0
0?l01?oooooo003oo`00oooo0002o`00oaoooooo000Zooooo`03o`000?oooooooooo02?ooooo00?o
003oooooooooool0:oooool2ool00003o`00oooooooooooo01_ooooo00?o003oooooooooool03_oo
ool00ooo003o003oooooo`0=ooooo`03ool00?l00?oooooo00Oooooo0_oo00000ol00?oooooooooo
o`06ooooo`03ool00?l00?oooooo00Gooooo00?oo`00o`00ooooool01_ooool00ooo003o003ooooo
o`04ooooo`03o`00oooooooooooo00?ooooo00?oo`00o`00ooooool00_ooool00ooo003o003ooooo
o`02ooooo`;oo`0000Co003ooooooooooooo003o1Oooool01?l00?ooooooool00?l00?l2ooooo`;o
o`0000?o003oooooool00?l00oooool02ooo003o003ooooooooooooo003ooooooooo003o003ooooo
oooo003o003o00;ooooo00Ko003oooooool00?ooooooool00?l00?l2ooooo`0Go`00oooooooo003o
ooooool00?ooooooool00?l00?ooo`00o`00oooooooo003oool00?l00?ooooooo`00oooo003o003o
ooooool00?ooooooo`00oooo00000_l00?l2ool000;o003o00Coooooo`00ool00?ooo`000_l00?l0
1?oo003o003oo`00ooooool4o`00o`04ool00?l00?oo003oool000Go003o00?oo`00o`00ool00?l0
1Ol00?l00ooo003o003oo`00o`08o`00o`03ooooool00?oooooo00Oo003o00?oo`00o`00ool00?l0
3?l00?l00ooo003o003oo`00o`03o`00o`04ooooool00?oo003oool000;o003o7oooool002[ooooo
00?o0000ooooooooool08oooool00ol00?ooooooooooo`0[ooooo`;oo`0000?o003oooooooooool0
6_ooool00ol00?ooooooooooo`0?ooooo`03ool00?l00?oooooo00gooooo00?oo`00o`00ooooool0
1oooool2ool00003o`00oooooooooooo00Kooooo00?oo`00o`00ooooool01_ooool00ol00?oooooo
ooooo`04ooooo`;oo`0000?o003oooooooooool00oooool00ol00?ooooooooooo`04ooooo`06o`00
oooooooooooooooooooo003o003o0oooool2ool00004o`00ooooooooooooo`00o`Gooooo00Co003o
oooooooo003o003o1?ooool00ol00?ooooooo`00o`03ooooo`05ool00?l00?ooooooooooool00?l0
0_ooool01?l00?ooooooooooool00?l2ooooo`03o`00oooooooo003o00;ooooo01[o003ooooooooo
003o003oooooool00?ooooooo`00ooooooooo`00o`00oooo003o003oooooool00?ooo`00o`00oooo
oooo003oool00?l00?ooo`00o`00oooooooo003oool000;o003o0_oo0002o`00o`04ool00?l00?oo
003oool000;o003o00Coo`00o`00ool00?ooo`001?l00?l01?oo003o003oo`00oooo0005o`00o`03
ool00?l00?oo003o00Go003o00?oo`00o`00ool00?l02_l00?l00ooooooo003oo`00o`05o`00o`03
ool00?l00?oo003o01;o003o00?oo`00o`00ool00?l00ol00?lOooooo`00:_ooool00ol0003ooooo
ooooo`0Qooooo`;oo`0000?o003oooooooooool0:oooool2ool00003o`00oooooooooooo01[ooooo
00?o003oooooooooool03oooool00ooo003o003oooooo`0=ooooo`03ool00?l00?oooooo00Sooooo
00?oo`00o`00ooooool02?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00Cooooo
0_oo00000ol00?ooooooooooo`02ooooo`03ool00?l00?oooooo00Gooooo00Ko003ooooooooooooo
ooooool00?l00?l3ooooo`;oo`0000Co003ooooooooooooo003o1Oooool01?l00?ooooooool00?l0
0?l4ooooo`03o`00oooooooo003o00Cooooo00Co003ooooooooooooo003o0_ooool02Ol00?oooooo
ooooool00?ooooooool00?l00?ooooooo`00o`02ooooo`0Jo`00ooooooooo`00o`00oooooooo003o
ooooool00?ooooooool00?l00?ooo`00o`00oooo003o003oool00?l00?ooooooo`00oooo003o003o
ool00?l00?ooooooo`00ooooool2o`00o`;oo`000_l00?l01?oo003o003oo`00oooo0002o`00o`04
ool00?l00?oo003oool000Co003o00Coo`00o`00ool00?ooo`001Ol00?l00ooo003o003oo`00o`0B
o`00o`03ooooool00?oo003o023o003o5_ooool01OnHV9So0000o`000?m4A4Co^[Zj00Cooooo000Z
ooooo`03o`000?oooooooooo027ooooo0_oo00000ol00?ooooooooooo`0[ooooo`;oo`0000?o003o
ooooooooool06Oooool00ooo003o003oooooo`0@ooooo`;oo`0000?o003oooooooooool02_ooool2
ool00003o`00oooooooooooo00Oooooo00?oo`00o`00ooooool02?ooool00ol00?ooooooooooo`06
ooooo`03o`00oooooooooooo00?ooooo0_oo00000ol00?ooooooooooo`02ooooo`03ool00?l00?oo
oooo00Gooooo00Ko003oooooooooooooooooool00?l00?l3ooooo`;oo`0000Go003ooooooooooooo
003oool00004ooooo`04o`00ooooooooo`00o`00o`Cooooo00Co003ooooooooooooo003o0oooool0
1?l00?ooooooool00?l00?l2ooooo`09o`00ooooooooooooo`00ooooooooo`00o`00oooooooo003o
00;ooooo01[o003ooooooooo003o003oooooool00?ooooooo`00ooooooooo`00o`00oooo003o003o
ool00?l00?ooo`00o`00oooo003o003oooooool00?ooo`00o`00oooo003o003oooooo`;o003o00Go
o`00o`00oooooooo003oool00002o`00o`04ool00?l00?oo003oool000?o003o00Coo`00o`00ool0
0?oooooo0ol00?l00ooooooo003oo`00o`03o`00o`03ool00?l00?oo003o03Go003o5_ooool01Ol@
413o^[Zjonk^k_mgMgOo410@00Cooooo000Zooooo`03o`000?oooooooooo027ooooo00?oo`00o`00
ooooool0;_ooool00ooo003o003oooooo`0Jooooo`03ool00?l00?oooooo013ooooo0_oo00000ol0
0?ooooooooooo`0:ooooo`;oo`0000?o003oooooooooool02Oooool00ol00?ooooooooooo`06oooo
o`03o`00oooooooooooo00Kooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`02oooo
o`03ool00?l00?oooooo00Gooooo00Ko003oooooooooooooooooool00?l00?l5ooooo`05o`00oooo
ooooooooool00?l00?l01?ooool01?l00?ooooooool00?l00?l4ooooo`04o`00ooooooooooooo`00
o`;ooooo00Go003oooooooooooooo`00o`00o`02ooooo`09o`00ooooooooooooo`00ooooooooo`00
o`00oooooooo003o00;ooooo00Ko003ooooooooo003o003oool00?l00?l2ool0000Bo`00oooo003o
003oool00?l00?ooo`00o`00oooooooo003oool00?l00?ooooooo`00oooo003o003oool00?l00?oo
oooo0_l00?l01Ooo003o003oooooool00?ooo`0000;o003o00Coo`00o`00ool00?ooo`000ol00?l0
1?oo003o003oo`00ooooool4o`00o`03ool00?l00?oo003o00;o003o00?oooooo`00ool00?l0=Ol0
0?lFooooo`03o`000?oooooooooo00Kooooo000Qooooobco00000_oo00000ol00?oo0000o`00000]
o`0000;oo`0000?o003oo`000?l000006?l000000ooo003o003oo`00000@o`0000;oo`0000?o003o
o`000?l000002_l00002ool00003o`00ool0003o000000Wo000000?o003oo`000?l000001_l00000
0ol00?oo0000o`000006o`000003o`00ool0003o000000Co000000?o003oo`000?l000000ol00000
0ooo003o003oo`000005o`000006o`00ool0003o0000o`000?oo003o003o1?l000001_l00?oo0000
o`000?l0003oo`00o`00o`?o000000?o003oo`000?l000000_l000002?l00?oo0000o`000?l0003o
003oo`000?oo003o003o0_l000001Ol00?oo0000o`000?oo003o003o00;o000000Oo003oo`000?l0
003o003oo`000?oo003o003o00;o000000So003oo`000?l00?oo0000ool00?l00?ooo`00o`00o`;o
o`0001;o003oo`000?l00?ooo`00o`00oooo003o003oo`000?l00?ooo`00o`00ool0003o003oool0
0?l00?ooo`00o`00ool00002o`00o`05o`000?l00?oo0000o`00oooo00000_l00?l01?oo003o003o
o`00oooo0003o`00o`04ool00?l00?oo003oo`0000Co003o00?oo`00o`00ool00?l00_l00?l00ol0
003o003oo`00o`0eo`00o`Wo00003Oooool00ol0003oooooooooo`06ooooo`00:_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool2ool00003
o`00oooooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Wooooo00Co0000oooooooooooo003o2Oooool00ol0003oooooooooo`09oooo
o`04o`000?ooooooooooooooo`;oo`0000?o003oooooooooool00oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooo003o00Wooooo00?o0000ooooooooool00_ooool00ol00?ooooooooooo`04
ooooo`03o`000?oooooooooo00;ooooo00?o003oooooooooool01?ooool00ol0003oooooo`00o`08
ooooo`03o`00ool0003ooooo00Cooooo00?o003oooooooooool00oooool00ooo003o003oooooo`05
ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool00_ooool02_l00?oooooooooooooo
ooooo`00o`00oooooooo0000ool00?l00?l4ooooo`08o`00ooooooooo`00ool00?l00?oo0000ool0
0?l00?l2ooooo`05o`00ooooooooooooool00?l00?l00_ooool01ol00?ooooooooooool00?oooooo
ool00?l00?l00_ooool02?l00?ooooooo`00ool0003oo`00o`00oooo003o003o0_oo00004_l00?oo
ooooo`00oooooooo003oool00?l00?ooooooo`00oooo003o003oooooool00?ooo`00o`00oooo003o
003oo`0000;o003o00Goooooo`00oooooooo003oool00002o`00o`04ooooool00?oo003oooooo`?o
003o00Coo`00o`00ool00?oooooo1?l00?l02?oooooo003oo`00oooo003o003oooooool00?ooo`00
=?l00?l00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Kooooo000Zooooo`03o`000?oo
oooooooo023ooooo0_oo00000ol00?ooooooooooo`08ooooo`03o`000?oooooooooo02Cooooo00?o
003oooooooooool01oooool00ol0003oooooooooo`0=ooooo`;oo`0000?o003oooooooooool04Ooo
ool00ol00?ooooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o003oooooooooool02Ooo
ool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00Gooooo00?oo`00o`00ooooool01Ooo
ool00ol00?ooooooooooo`03ooooo`03ool00?l00?oooooo00?ooooo0_oo00000ol00?oooooooooo
o`02ooooo`03o`00oooooooooooo00;ooooo00Ko003oooooooooooooooooool00?l00?l2ooooo`03
ool00?l00?oooooo00?ooooo00So003ooooooooo003oo`00o`00ooooooooo`00o`00o`;ooooo00ko
003oooooooooooooo`00o`00ooooooooo`00o`00ooooooooo`00o`00ooooooooo`00o`00o`;ooooo
00?o003oooooool00?l00_ooool06Ol00?ooo`00o`00ooooooooo`00o`00oooooooo003oooooool0
0?ooo`00o`00oooooooo003oool00?l00?ooooooo`00oooooooo003oool00?l00?ooo`00o`00oooo
ool00_l00?l00ooo003o003oooooo`02o`00o`04ooooool00?oo003oooooo`?o003o00Coo`00o`00
ool00?oooooo1?l00?l02?oooooo003oo`00oooo003o003oooooool00?ooo`00=?l00?lEooooo`03
oa0@4?l0003o000000?o00001Oooool002[ooooo00?o0000ooooooooool08_ooool00ol00?oooooo
ooooo`0_ooooo`03o`00oooooooooooo01Oooooo0_oo00000ol00?ooooooooooo`0Aooooo`03o`00
oooooooooooo00cooooo00?o003oooooooooool02Oooool00ol00?ooooooooooo`05ooooo`03ool0
0?l00?oooooo00Kooooo00?oo`00o`00ooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo00;ooooo00?oo`00o`00ooooool01?ooool00ol00?ooooooooooo`02ooooo`06o`00
oooooooooooooooooooo003o003o0_ooool00ooo003o003oooooo`03ooooo`04o`00ooooooooo`00
o`00o`;ooooo00Goo`00o`00ooooooooo`00o`00o`02ooooo`08ool00?l00?ooooooool00?l00?oo
ooooool00?l00?l2ooooo`06o`00ooooooooooooo`00oooooooo003o0_ooool06Ol00?ooo`00o`00
ooooooooo`00o`00oooooooo003oooooool00?ooooooo`00oooooooo003oool00?l00?ooo`00o`00
oooooooo003oooooool00?ooo`00o`00oooo00000_l00?l00ooo003o003oooooo`03o`00o`03ool0
0?l00?oooooo00?o003o00Coo`00o`00ool00?oooooo1?l00?l02?oooooo003oo`00oooo003o003o
ooooool00?oooooo4Ol00?l00ooo003o003oo`00o`0Po`00oaOooooo00?o0000ooooooooool01_oo
ool002[ooooo00?o0000ooooooooool08_ooool00ol00?ooooooooooo`0_ooooo`03o`00oooooooo
oooo01Wooooo00?o003oooooooooool04Oooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooo
oooo00Sooooo0_oo00000ol00?ooooooooooo`05ooooo`03ool00?l00?oooooo00Kooooo00?oo`00
o`00ooooool01Oooool00ol00?ooooooooooo`04ooooo`03o`00oooooooooooo00;ooooo00?oo`00
o`00ooooool01?ooool00ol00?ooooooooooo`02ooooo`03o`00oooooooooooo00;ooooo00Go003o
ooooooooooooo`00o`00o`04ooooo`04o`00ooooooooo`00o`00o`;ooooo00Goo`00o`00oooooooo
o`00o`00o`03ooooo`07o`00ooooooooo`00o`00ooooooooo`00o`00o`02ooooo`06o`00oooooooo
ooooo`00oooooooo003o0_ooool00ol00?ooo`00o`00o`02ooooo`0Do`00oooooooo003oooooool0
0?ooooooo`00oooo003o003oooooool00?ooo`00o`00oooooooo003oooooool00?ooo`00o`00oooo
0002o`00o`04ool00?l00?oo003oool000;o003o00?oo`00o`00ooooool00ol00?l01?oo003o003o
o`00oooo0004o`00o`08ooooool00?oo003oool00?l00?ooooooo`00oooooolAo`00o`03ool00?l0
0?oo003o00_o003o00?oo`00o`00ool00?l04_l00?lGooooo`03o`000?oooooooooo00Kooooo000Z
ooooo`03o`000?oooooooooo027ooooo00?o003oooooooooool0<?ooool00ol00?ooooooooooo`0H
ooooo`03o`00oooooooooooo01;ooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`08
ooooo`;oo`0000?o003oooooooooool01Oooool00ooo003o003oooooo`06ooooo`03ool00?l00?oo
oooo00Cooooo00?oo`00o`00ooooool01Oooool00ol00?ooooooooooo`02ooooo`03ool00?l00?oo
oooo00Cooooo00Ko003oooooooooooooooooool00?l00?l4ooooo`05o`00ooooooooooooool00?l0
0?l00oooool01Ooo003o003ooooooooo003o003o00;ooooo00Goo`00o`00ooooooooo`00o`00o`03
ooooo`09o`00ooooooooo`00o`00ooooooooo`00o`00oooooooo003o00?ooooo00?o003oooooool0
0?l00_ooool00ol00?ooooooo`00o`02ooooo`;o003o00Woo`00ooooool00?ooooooo`00oooo003o
003oooooool00?l00_oo0002o`00o`05ooooool00?ooo`00o`00oooo00000_l00?l01?oo003o003o
o`00ooooool2o`00o`03ool00?l00?oooooo00?o003o00Coo`00o`00ool00?ooo`001?l00?l02?oo
oooo003oo`00oooo003o003oool00?l00?oooooo4Ol00?l00ooo003o003oo`00o`0;o`00o`03ool0
0?l00?oo003o00Co003o00?oo`00o`00ool00?l02ol00?lPooooo`00:_ooool2o`0002;ooooo00?o
003oooooooooool0;oooool00ooo003o003oooooo`0Iooooo`03o`00oooooooooooo017ooooo00?o
o`00o`00ooooool03?ooool00ol00?ooooooooooo`08ooooo`;oo`0000?o003oooooooooool01Ooo
ool00ooo003o003oooooo`06ooooo`03ool00?l00?oooooo00Cooooo00?oo`00o`00ooooool01Ooo
ool00ol00?ooooooooooo`02ooooo`03ool00?l00?oooooo00Gooooo00Go003oooooooooooooo`00
o`00o`04ooooo`05o`00ooooooooooooool00?l00?l00oooool01Ooo003o003ooooooooo003o003o
00?ooooo00Co003ooooooooo003o003o0oooool02Ol00?ooooooool00?l00?ooooooool00?l00?oo
ooooo`00o`03ooooo`03o`00oooooooo003o00;ooooo00?o003oooooool00?l00_ooool2o`00o`;o
o`0000Oo003oooooool00?ooo`00o`00oooooooo003o00;oo`000_l00?l01Ooooooo003oool00?l0
0?ooo`0000;o003o00Coo`00o`00ool00?oooooo0_l00?l00ooo003o003oooooo`03o`00o`04ool0
0?l00?oo003oool000Co003o00Soooooo`00ool00?ooo`00o`00oooo003o003ooooooa7o003o00?o
ooooo`00ool00?l02ol00?l01?oooooo003oo`00ooooool3o`00o`03ool00?l00?oo003o00;o003o
00?oo`00o`00ool00?l01_l00?lPooooo`00:_ooool00ol0003oooooooooo`0Qooooo`03o`00oooo
oooooooo02oooooo0_oo00000ol00?ooooooooooo`0Gooooo`03o`00oooooooooooo017ooooo0_oo
00000ol00?ooooooooooo`09ooooo`03ool00?l00?oooooo00Wooooo0_oo00000ol00?oooooooooo
o`05ooooo`03o`00oooo003ooooo00Oooooo00?o003oooooooooool00oooool00ooo003o003ooooo
o`05ooooo`03o`00oooooooooooo00?ooooo00?o003oooooooooool00_ooool2ool00005o`00oooo
ooooooooool00?l00?l01?ooool01Ol00?oooooooooooooooooo003o00?ooooo00Goo`00o`00oooo
ooooooooo`00o`03ooooo`04o`00ooooooooo`00o`00o`?ooooo00Wo003ooooooooo003o003ooooo
oooo003o003oooooool00?l00oooool02?l00?ooooooo`00ooooooooo`00o`00oooooooo003o0_oo
ool2o`00o`;oo`0000?o003oooooool00?l00_oo0002o`00o`;oo`000_l00?l01Ooooooo003oool0
0?l00?ooo`0000;o003o00Coo`00o`00ool00?oooooo0_l00?l01?oooooo003oo`00ooooool2o`00
o`04ooooool00?oo003oool000Co003o00Soo`00o`00ool00?ooo`00o`00oooo003o003oool000Co
003o00?oo`00o`00ool00?l02_l00?l00ooooooo003oool0000;o`00o`03ooooool00?oo003o00;o
oooo0_l00?l00ooo003o003oo`00o`02o`00o`03ool00?l00?ooo`0000Ko003o8?ooool002[ooooo
00?o0000ooooooooool07oooool2ool00003o`00oooooooooooo02oooooo0_oo00000ol00?oooooo
ooooo`0Gooooo`03o`00oooooooooooo017ooooo0_oo00000ol00?ooooooooooo`09ooooo`03ool0
0?l00?oooooo00[ooooo00?oo`00o`00ooooool01_ooool00ol00?ooo`00ooooo`07ooooo`03o`00
oooooooooooo00?ooooo00?oo`00o`00ooooool01Oooool00ooo003o003oooooo`03ooooo`03o`00
oooooooooooo00;ooooo0_oo00001Ol00?oooooooooooooo003o003o00Cooooo00Go003ooooooooo
ooooooooo`00o`03ooooo`05ool00?l00?ooooooooooool00?l00oooool01?l00?ooooooool00?l0
0?l3ooooo`04o`00ooooooooooooo`00o`;ooooo00?o003oool00?l00?l00oooool02?l00?oooooo
o`00ooooooooo`00o`00oooooooo003o0_ooool2o`00o`;oo`0000?o003oooooool00?l00_oo0002
o`00o`;oo`000_l00?l01Ooooooo003oooooool00?ooo`0000;o003o00Coooooo`00ool00?oooooo
0_l00?l01?ooooooo`00o`00ooooool2o`00o`04ooooool00?oo003oool000Co003o00Soo`00o`00
ool00?ooo`00o`00oooo003o003oool000Co003o00?oo`00o`00ool00?l01Ol00?l02?oo003o003o
o`00oooo003o003oooooool00?ooo`001Ol00?l00ooo003o003oo`00o`03o`00o`03ool00?l00?oo
003o00?ooooo00?o003oool00?l00?l00_l00?l2ool00005o`00oooo003o003oo`00ooooool00ol0
0?lPooooo`00:_ooool00ol0003oooooooooo`0Oooooo`;oo`0000?o003oooooooooool0;oooool2
ool00003o`00oooooooooooo01Oooooo00?o003oooooooooool04Oooool2ool00003o`00oooooooo
oooo00Sooooo0_oo00000ol00?ooooooooooo`09ooooo`03ool00?l00?oooooo00Kooooo00?o003o
ooooooooool01oooool00ol00?ooooooooooo`03ooooo`03ool00?l00?oooooo00Gooooo00?oo`00
o`00ooooool00oooool00ol00?ooooooooooo`02ooooo`;oo`0000Go003oooooooooooooo`00o`00
o`04ooooo`05o`00ooooooooooooooooool00?l00oooool01Ooo003o003ooooooooooooo003o00?o
oooo00Co003ooooooooooooo003o0oooool00ol00?ooooooo`00o`03ooooo`03o`00oooo003o003o
00?ooooo00So003oooooool00?ooooooool00?l00?ooooooo`00o`;ooooo0_l00?l01Oooooooo`00
o`00oooo003o003o00;oo`000_l00?l2ooooo`;o003o00Goo`00o`00oooooooo003oooooo`02o`00
o`04ooooool00?oo003oooooo`;o003o00Coooooool00?l00?oooooo0_l00?l01?oooooo003oo`00
oooo0004o`00o`08ool00?l00?oo003oool00?l00?ooo`00o`00oooo0004o`00o`03ool00?l00?oo
003o00?o003o00?oo`00o`00oooo00000_l00?l01Ooo003o003oooooool00?ooo`0000;o003o00Ko
o`00o`00ool00?ooo`00o`00ooooool3o`00o`03ool00?l00?oo003o00;oo`0000?oooooo`00oooo
ool00ol00?l01?oo003oooooo`00oooo0002o`00o`04ooooool00?ooo`00o`00ob3ooooo000Zoooo
o`03o`000?oooooooooo01oooooo00?oo`00o`00ooooool0<Oooool2ool00003o`00oooooooooooo
01Kooooo00?oo`00o`00ooooool04_ooool2ool00003o`00oooooooooooo00Sooooo0_oo00000ol0
0?ooooooooooo`0:ooooo`03o`00oooooooooooo00Gooooo00?o003oooooooooool01oooool00ol0
0?ooooooooooo`03ooooo`03ool00?l00?oooooo00Gooooo00?oo`00o`00ooooool00oooool00ol0
0?ooooooooooo`02ooooo`;oo`0000Go003oooooooooooooooooo`00o`03ooooo`03ool00?l00?oo
oooo00;ooooo00Ko003oooooooooooooooooool00?l00?l2ooooo`05o`00ooooooooooooooooool0
0?l00_ooool01ol00?oooooooooooooo003o003oooooool00?l00oooool00ol00?ooo`00o`00o`03
ooooo`0:o`00oooooooo003ooooooooo003o003oooooool00?ooooooool000;o003o00Goooooool0
0?l00?ooo`00o`00o`02ooooo`;o003o0_ooool2o`00o`05ool00?l00?ooooooo`00ooooool00_l0
0?l01?oooooo003oo`00oooo0002o`00o`04oooooooo003o003oooooo`;o003o00Coooooo`00ool0
0?oooooo1?l00?l02?oo003o003oo`00oooo003o003oool00?l00?ooo`001?l00?l02Ooo003o003o
ool00?l00?ooo`00o`00oooo003o003oooooo`02o`00o`05ool00?l00?ooooooo`00oooo00000_l0
0?l01_oo003o003oo`00oooo003o003oooooo`?o003o00?oo`00o`00ool00?l00_oo0003ooooo`?o
003o00Ooo`00ooooool00?ooo`00o`00oooo003ooooo00;oo`0000?o003oooooooooool07_ooool0
02[ooooo00?o0000ooooooooool07_ooool2ool00003o`00oooooooooooo033ooooo0_oo00000ol0
0?ooooooooooo`0Fooooo`03ool00?l00?oooooo01;ooooo0_oo00000ol00?ooooooooooo`08oooo
o`;oo`0000?o003oooooooooool02_ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo
00Oooooo00?o003oooooooooool01?ooool00ol00?ooooooooooo`04ooooo`03ool00?l00?oooooo
00?ooooo00?o003oooooooooool00_ooool2ool00005o`00ooooooooooooooooool00?l00oooool0
0ooo003o003oooooo`02ooooo`03o`00oooooooooooo00;ooooo00Co003ooooooooooooo003o0ooo
ool01?l00?ooooooooooool00?l2ooooo`04ool00?l00?ooooooo`00o`Cooooo0_l00?l3ooooo`0:
o`00oooooooo003ooooooooo003o003oool00?l00?ooooooool000;o003o00Goooooool00?l00?oo
o`00o`00o`02ooooo`;o003o0_ooool2o`00o`03ool00?l00?oo003o00;ooooo0_l00?l01?oooooo
003oo`00oooo0002o`00o`04oooooooo003o003oool000;o003o00Coooooo`00ool00?oooooo1?l0
0?l02?oo003o003oo`00oooo003o003oool00?l00?ooo`001?l00?l02Ooo003o003oool00?l00?oo
o`00o`00oooooooo003oooooo`02o`00o`05ool00?l00?ooo`00o`00oooo00000_l00?l02ooo003o
003oool00?oo003o003oooooool00?ooo`00o`00oooo003o003o00?oo`000oooool2o`00o`04ool0
0?ooooooooooo`00o`;oo`000oooool2ool0023ooooo000Zooooo`;o00007oooool2ool00003o`00
oooooooooooo03;ooooo00?o003oooooooooool05_ooool00ooo003o003oooooo`0Dooooo`03o`00
oooooooooooo00[ooooo00?o003oooooooooool02oooool00ol00?ooooooooooo`04ooooo`03o`00
oooooooooooo00Sooooo00?o003oooooooooool00oooool00ol00?ooooooooooo`04ooooo`03ool0
0?l00?oooooo00?ooooo00?o003oooooooooool00_ooool2ool00005o`00ooooooooooooooooool0
0?l00oooool00ooo003o003oooooo`02ool00003o`00oooooooooooo00;ooooo00Co003ooooooooo
oooo003o0_ooool01Ooo003o003ooooooooooooo003o00;ooooo00Coo`00o`00oooooooo003o1?oo
ool2o`00o`?ooooo00[o003oooooool00?ooooooool00?l00?ooo`00o`00ooooooooo`000_l00?l2
ooooo`03o`00oooo003o003o00;ooooo0_l00?l2ooooo`;o003o00?oo`00o`00ool00?l00_ooool2
o`00o`03ooooool00?oo003o00;oo`0000Go003ooooooooo003o003oool00002o`00o`04ooooool0
0?oo003oooooo`;o003o00?oo`00o`00oooo00000_l00?l01Ooo003o003oool00?l00?ooo`0000;o
003o00_oo`00o`00oooo003o003oool00?l00?ooo`00o`00oooooooo003oooooo`02o`00o`05oooo
ool00?ooo`00o`00ooooool00_l00?l03?oooooo003oool00?oo003o003oooooool00?ooo`00o`00
oooo003o003oooooo`;oo`000oooool3ool002[ooooo000Zooooo`03o`000?oooooooooo01kooooo
0_oo00000ol00?ooooooooooo`0booooo`03o`00oooooooooooo01Gooooo0_oo00000ol00?oooooo
ooooo`0Cooooo`03o`00oooooooooooo00[ooooo00?o003oooooooooool02oooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00Oooooo00?oo`00o`00ooooool01?ooool00ol00?oooooo
ooooo`04ooooo`04ool00?l00?ooooooooooo`;oo`0000?o003oooooooooool01?ooool01?l00?oo
ooooooooool00?l4ooooo`;oo`0000Co003oool00?oo003o003o1?ooool01?l00?ooooooool00?l0
0?l2ooooo`05ool00?l00?ooooooooooool00?l00_ooool2ool000;o003o0_ooool2ool000;o003o
0oooool00ol00?ooooooo`00o`02ooooo`05o`00oooo003o003ooooooooo00000_l00?l2ooooo`03
o`00oooo003o003o00;ooooo0_l00?l2ooooo`;o003o00?oo`00o`00ool00?l00_ooool2o`00o`;o
o`0000So003oool00?oo003o003ooooooooo003o003oool000;o003o00Coo`00o`00ool00?oooooo
0_l00?l02Ooo003o003oooooool00?ooooooool00?l00?ooo`00o`00o`04ooooo`;oo`0000So003o
ool00?l00?ooo`00o`00oooooooo003oooooo`;o003o0_ooool00ooo003o003oooooo`03ooooo`;o
o`001?ooool4ool00003oooooooo003oo`00033ooooo000Zooooo`03o`000?oooooooooo023ooooo
00?o003oooooooooool0<oooool00ol00?ooooooooooo`0Dooooo`03ool00?l00?oooooo01Gooooo
00?o003oooooooooool02_ooool00ol00?ooooooooooo`0;ooooo`03o`00oooooooooooo00?ooooo
00?oo`00o`00ooooool02?ooool00ooo003o003oooooo`04ooooo`03o`00oooooooooooo00Gooooo
00?o003oooooooooool00_oo00000ol00?ooooooooooo`04ooooo`04o`00ooooooooooooo`00o`Co
oooo0_oo00001?l00?ooo`00ool00?l00?l4ooooo`04o`00ooooooooo`00o`00o`;ooooo0_oo0000
0ol00?ooo`00o`00o`02ooooo`;oo`000_l00?l2ooooo`;oo`000_l00?l3ooooo`03o`00oooooooo
003o00;ooooo00Go003oool00?l00?ooooooool00002o`00o`;ooooo00?o003oooooool00?l00_oo
ool2o`00o`;ooooo0_l00?l01Ooo003o003oo`00ooooooooo`0000;o003o0_oo00001ol00?oooooo
ool00?l00?ooooooool00?l00?l00_oo00003_l00?ooo`00ool00?l00?ooooooool00?l00?ooo`00
o`00oooooooo003ooooooooo003o003o2?ooool00ol00?ooo`00ool00009ooooo`;oo`00@Oooool0
02[ooooo00?o0000ooooooooool08?ooool00ol00?ooooooooooo`0cooooo`03o`00oooooooooooo
01Cooooo00?oo`00o`00ooooool05Oooool00ol00?ooooooooooo`0:ooooo`03o`00oooooooooooo
00_ooooo00?o003oooooooooool00oooool00ooo003o003oooooo`08ooooo`03ool00?l00?oooooo
00?ooooo00?o003oooooooooool01_ooool00ol00?ooooooooooo`02ool00003o`00oooooooooooo
00Cooooo00Co003ooooooooooooo003o1_ooool00ol00?ooo`00o`00o`05ooooo`04o`00oooo003o
003oool000;ooooo0_oo00000ol00?ooo`00o`00o`02ooooo`;oo`000_l00?l2ooooo`;oo`000_l0
0?l3ooooo`03o`00oooooooo003o00;ooooo00Go003oool00?l00?ooooooool00002o`00o`?ooooo
0_l00?l2ooooo`;o003o00Goooooool00?l00?oo003oooooo`02o`00o`04oooooooo003o003oo`00
o`;oo`0000[o003ooooooooo003o003ooooooooo003o003ooooooooo003o003o1Ooo00000ol00?oo
o`00o`00o`03ooooo`;oo`002Oooool2ool004cooooo000Zooooo`03o`000?oooooooooo01oooooo
00?o003oooooooooool0=?ooool00ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01Cooooo
00?o003oooooooooool02Oooool00ol00?ooooooooooo`0:ooooo`;oo`0000?o003oooooooooool0
0oooool00ooo003o003oooooo`08ooooo`03ool00?l00?oooooo00;ooooo00?oo`00o`00ooooool0
1oooool01Ol00?oooooooooooooo003o003o00Oooooo00Co003ooooooooo003o003o1_ooool00ol0
0?ooo`00o`00o`05ooooo`03o`00oooo003o003o00Cooooo00Coo`00o`00oooo003o003o1?ooool2
o`00o`;ooooo0_oo0002o`00o`?ooooo0_l00?l3ooooo`03o`00oooo003o003o00;ooooo0_l00?l3
ooooo`;o003o00Koooooool00?l00?oo003ooooooooo0002o`00o`05ooooool00?oo003ooooooooo
00000_l00?l2ool0000;o`00ooooooooooooo`00ooooooooo`00o`00ooooooooo`00o`00ooooool0
1?oo00000oooooooo`00o`00o`1Looooo`00:_ooool00ol0003oooooooooo`0Oooooo`03o`00oooo
oooooooo03Cooooo00?o003oooooooooool05Oooool00ol00?ooooooooooo`0Dooooo`03o`00oooo
oooooooo00Wooooo00?o003oooooooooool02_ooool2ool00003o`00oooooooooooo00?ooooo00?o
o`00o`00ooooool02?ooool00ooo003o003oooooo`02ooooo`03ool00?l00?oooooo00Oooooo00Go
003oooooooooooooo`00o`00o`07ooooo`04o`00ooooooooo`00o`00o`Kooooo00?o003oool00?l0
0?l01?ooool01?oo003o003oool00?l00?l4ooooo`04ool00?l00?ooo`00o`00o`Cooooo0_l00?l2
ooooo`;oo`000_l00?l3ooooo`;o003o0oooool00ol00?ooooooo`00o`02ooooo`;o003o0oooool2
o`00o`06oooooooo003o003oo`00ooooooooo`000_l00?l01?ooooooo`00o`00ooooool2ool00004
o`00ooooooooo`00o`00o`;ooooo00Co003ooooooooo003oo`001?ooool4ool005oooooo000Zoooo
o`03o`000?oooooooooo01oooooo00?o003oooooooooool0<_ooool2ool00003o`00oooooooooooo
01Gooooo00?o003oooooooooool04oooool00ooo003o003oooooo`09ooooo`03ool00?l00?oooooo
00_ooooo0_oo00000ol00?ooooooooooo`03ooooo`03ool00?l00?oooooo00Sooooo00?oo`00o`00
ooooool00_ooool00ooo003o003oooooo`07ooooo`05o`00ooooooooooooool00?l00?l01_ooool0
1Ooo003o003ooooooooo003o003o00Kooooo00?o003oooooool00?l01?ooool01?oo003o003ooooo
ool00?l5ooooo`03o`00oooo003o003o00Cooooo0_l00?l3ooooo`03ool00?l00?oo003o00?ooooo
0_l00?l4ooooo`;o003o0_ooool2o`00o`;ooooo00Goo`00o`00ooooooooooooool00002o`00o`03
oooooooo003o003o00;ooooo00?oo`00o`00ooooool00ooo00000oooooooo`00ool0001]ooooo`00
:_ooool2o`00023ooooo00?o003oooooooooool0<_ooool2ool00003o`00oooooooooooo01Gooooo
00?o003oooooooooool04oooool00ooo003o003oooooo`09ooooo`03ool00?l00?oooooo00cooooo
00?oo`00o`00ooooool01?ooool00ooo003o003oooooo`09ooooo`06o`00oooooooooooooooooooo
003o003o2?ooool01Ol00?oooooooooooooooooo003o00Kooooo00Goo`00o`00ooooooooo`00o`00
o`06ooooo`03o`00oooooooo003o00Cooooo00Coo`00o`00oooooooo003o1Oooool00ol00?ooo`00
o`00o`04ooooo`;o003o1?ooool2o`00o`?ooooo0_l00?l2ooooo`;oo`0000Co003ooooooooooooo
oooo0_l00?l2ooooo`06ool00?l00?oooooooooooooo003o003o0_ooool00ooo003o003oooooo`05
ooooo`;oo`00L?ooool002[ooooo00?o0000ooooooooool07?ooool2ool00003ooooool00?oooooo
03?ooooo0_oo00000ol00?ooooooooooo`0Eooooo`03o`00oooooooooooo01?ooooo0_oo00000ol0
0?ooooooooooo`07ooooo`03ool00?l00?oooooo00cooooo00?oo`00o`00ooooool01?ooool00ol0
0?ooooooooooo`09ooooo`06o`00oooooooooooooooooooo003o003o1oooool00ooo003o003ooooo
o`02ooooo`03o`00oooooooooooo00Cooooo00Goo`00o`00ooooooooo`00o`00o`06ooooo`03o`00
oooooooo003o00Cooooo00Coo`00o`00oooooooo003o1Oooool00ol00?ooooooo`00o`04ooooo`;o
003o1?ooool2o`00o`Cooooo00?o003oooooooooool00_oo00001_l00?ooooooooooooooooooo`00
o`00o`;ooooo0_oo0002ooooo`;oo`000_ooool2ool007Sooooo000Zooooo`03o`000?oooooooooo
01cooooo0_oo00000ol00?ooooooooooo`0cooooo`?oo`0000?o003oooooooooool04_ooool2ool0
0003o`00oooooooooooo01?ooooo0_oo00000ol00?ooooooooooo`06ooooo`;oo`0000?o003ooooo
ooooool03?ooool00ol00?ooooooooooo`03ooooo`03o`00oooooooooooo00Wooooo00Ko003ooooo
ooooooooooooool00?l00?l7ooooo`03ool00?l00?oooooo00;ooooo00?o003oooooooooool01?oo
ool01Ooo003o003ooooooooo003o003o00Gooooo00Coo`00o`00oooooooo003o1?ooool01?oo003o
003oooooool00?l5ooooo`;o003o1?ooool00ooo003o003oo`00o`04ooooo`;o003o1?ooool00ol0
0?ooooooooooo`02ool00006o`00oooooooooooooooooooo003o003o0_ooool2ool000;ooooo0_oo
001looooo`00:_ooool00ol0003oooooooooo`0Looooo`;oo`0000?o003oooooooooool0=?ooool2
ool00003o`00oooooooooooo01;ooooo0_oo00000ol00?ooooooooooo`0Cooooo`;oo`0000?o003o
ooooooooool01_ooool2ool00003o`00oooooooooooo00cooooo00?o003oooooooooool00oooool0
0ol00?ooooooooooo`09ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool01Oooool0
0ooo003o003oool00002ooooo`03o`00oooooooooooo00Cooooo00Goo`00o`00ooooooooooooo`00
o`05ooooo`04ool00?l00?ooooooo`00o`Cooooo00Coo`00o`00oooooooo003o1Oooool2o`00o`Co
oooo00?oo`00o`00ool00?l01?ooool2o`00o`Cooooo00Co003ooooooooooooooooo0_oo0007oooo
o`;oo`00P?ooool002[ooooo00?o0000ooooooooool07?ooool2ool00003o`00oooooooooooo03Co
oooo0_oo00000ol00?ooooooooooo`0Booooo`03ool00?l00?oooooo01Gooooo0_oo00000ol00?oo
ooooooooo`06ooooo`;oo`0000?o003oooooooooool03?ooool00ol00?ooooooooooo`03ooooo`03
o`00oooooooooooo00Wooooo00?o003oooooooooool00_ooool00ol00?ooooooooooo`06ooooo`05
o`00oooo003oooooooooool00?l01_ooool01Ooo003o003ooooooooooooo003o00Gooooo00Coo`00
o`00oooooooo003o1_ooool2o`00o`Cooooo00?oo`00o`00ool00?l01?ooool00ooo003o003oo`00
o`04ooooo`03ool00?l00?oooooo00Oooooo0_oo0029ooooo`00:_ooool00ol0003oooooooooo`0L
ooooo`;oo`0000?o003oooooooooool0=_ooool00ol00?ooooooooooo`0Booooo`03ool00?l00?oo
oooo01Oooooo00?o003oooooooooool02?ooool00ol00?ooooooooooo`0<ooooo`03o`00oooooooo
oooo00?ooooo00?o003oooooooooool02?ooool00ooo003o003oooooo`03ooooo`03o`00oooooooo
oooo00Kooooo00Goo`00o`00ooooooooo`00o`00o`06ooooo`05ool00?l00?ooooooooooool00?l0
1Oooool01?oo003o003oool00?l00?l6ooooo`;o003o1?ooool00ooo003o003oo`00o`04ooooo`03
ool00?l00?oooooo00?ooooo0ooo002Cooooo`00:_ooool2o`0001oooooo00?o003oooooooooool0
=_ooool00ol00?ooooooooooo`0Booooo`03ool00?l00?oooooo01Oooooo00?o003oooooooooool0
2?ooool00ol00?ooooooooooo`0=ooooo`03o`00oooooooooooo00;ooooo00?o003oooooooooool0
2?ooool2ool00005o`00ooooooooooooooooool00?l02Oooool01?l00?ooooooool00?l00?l6oooo
o`05ool00?l00?ooooooooooool00?l01Oooool01?oo003o003oool00?l00?l6ooooo`;o003o1?oo
ool00ooo003o003oo`00o`04ooooo`03ool00?l00?oooooo00?ooooo0_oo002Dooooo`00:_ooool0
0ol0003oooooooooo`0Nooooo`03o`00oooooooooooo03Kooooo00?o003oooooooooool04_ooool0
0ooo003o003oooooo`0Gooooo`03o`00oooooooooooo00Sooooo00?o003oooooooooool03Oooool0
1_l00?ooooooooooooooooooo`00o`00o`[ooooo0_oo00001Ol00?oooooooooooooooooo003o00Wo
oooo00Co003ooooooooo003o003o1_ooool2ool000;o003o1_ooool01?oo003o003oool00?l00?l6
ooooo`;o003o1?ooool2ool00003o`00oooooooooooo00;ooooo0_oo002Jooooo`00:_ooool00ol0
003oooooooooo`0Mooooo`03o`00oooooooooooo03Oooooo00?o003oooooooooool04oooool00ol0
0?ooooooooooo`0Fooooo`03o`00oooooooooooo00Oooooo00?o003oooooooooool03?ooool2ool0
0006o`00oooooooooooooooooooo003o003o2oooool00ooo003o003oooooo`02ooooo`03o`00oooo
oooooooo00Oooooo00Co003ooooooooo003o003o1_ooool2ool000;o003o1oooool00ol00?ooo`00
o`00o`06ooooo`03o`00oooo003ooooo00?ooooo0ooo002Pooooo`001_ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Ko
oooo00?o0000ooooooooool07Oooool00ol00?ooooooooooo`0hooooo`03o`00oooooooooooo01;o
oooo00?o003oooooooooool05_ooool00ol00?ooooooooooo`07ooooo`03o`00oooooooooooo00co
oooo0_oo00001_l00?ooooooooooooooooooo`00o`00o`_ooooo00?oo`00o`00ooooool00_oo0000
0ol00?ooooooooooo`07ooooo`04o`00oooo003oo`00o`00o`Sooooo0_l00?l7ooooo`;o003o1_oo
ool3ool00:Oooooo0006ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go
V9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo00Gooooo00?o0000ooooooooool0
7Oooool00ol00?ooooooooooo`0fooooo`;oo`0000?o003oooooooooool04_ooool00ol00?oooooo
ooooo`0Eooooo`03ool00?l00?oooooo00Oooooo00?oo`00o`00ooooool03Oooool2ool00006o`00
oooooooooooooooooooo003o003o2oooool00ooo003o003oooooo`02ool00003o`00oooooooooooo
00Oooooo00Co003oool00?oo003o003o2?ooool2o`00o`Oooooo00?oo`00o`00ooooool01Oooool2
ool00:Sooooo0006ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP09
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07Oooool00ol00?ooooooooooo`0f
ooooo`;oo`0000?o003oooooooooool04_ooool00ol00?ooooooooooo`0Eooooo`03ool00?l00?oo
oooo00Oooooo00?oo`00o`00ooooool03_ooool00ooo003o003oooooo`02ooooo`03ool00?l00?oo
oooo00_ooooo00Co003ooooooooo003o003o2_ooool00ol00?ooooooo`00o`09ooooo`;o003o^Ooo
ool000Kooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o
MgMgoc8b<_ooool01Oooool3o`0001[ooooo0_oo00000ooooooo003oooooo`0gooooo`;oo`0000?o
003oooooooooool04_ooool00ol00?ooooooooooo`0Eooooo`03ool00?l00?oooooo00Oooooo00?o
o`00o`00ooooool03_ooool00ooo003o003oooooo`02ooooo`03o`00oooooooooooo00_ooooo00Co
003ooooooooo003o003o2Oooool01?oo003o003oooooool00?l9ooooo`;o003o^Oooool000Kooooo
00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00?ooooo00Go0000ob4Q8Ol0
003o<S8bolc<c006ooooo`03o`000?oooooooooo01[ooooo0_oo00000ol00?ooooooooooo`0goooo
o`;oo`0000?o003oooooooooool04Oooool00ol00?ooooooooooo`0Fooooo`03ool00?l00?ooo`00
00Kooooo0_oo00000ol00?ooooooooooo`0=ooooo`03ool00?l00?oooooo00;ooooo00?o003ooooo
ooooool02oooool01?l00?ooooooool00?l00?l9ooooo`04ool00?l00?ooooooo`00o`Wooooo0_oo
002iooooo`001_ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01[ooooo0_oo00000ol00?oooooooooo
o`0gooooo`;oo`0000?o003oooooooooool04?ooool00ooo003o003oooooo`0Hooooo`03ool00?l0
0?oooooo00Gooooo0_oo00000ol00?ooooooooooo`0>ooooo`05o`00ooooooooooooooooool00?l0
3_ooool00ol00?ooooooo`00o`09ooooo`;oo`000_l00?o4ooooo`001_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool06_ooool2ool00003o`00oooooooooooo03Oooooo0_oo00000ol00?oo
ooooooooo`0@ooooo`03ool00?l00?oooooo01Sooooo00?oo`00o`00ooooool01Oooool2ool00003
o`00oooooooooooo00kooooo00Go003oooooooooooooooooo`00o`0>ooooo`03o`00oooooooo003o
00[ooooo00?oo`00o`00ool00?l0a?ooool000Kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;oooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0000Oooooo00?o0000ooooooooool06_ooool2
ool00003o`00oooooooooooo03[ooooo00?o003oooooooooool03oooool00ooo003o003oooooo`0I
ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03_ooool01Ol00?oooooooooooooo
oooo003o00kooooo00?o003oooooool00?l02_ooool2ool00<Gooooo000Zooooo`03o`000?oooooo
oooo01[ooooo0_oo00000ol00?ooooooooooo`0jooooo`03o`00oooooooooooo00oooooo00?oo`00
o`00ooooool06Oooool00ol00?ooooooooooo`06ooooo`03o`00oooooooooooo00kooooo00Go003o
ooooooooooooooooo`00o`0=ooooo`04ool00?l00?ooooooo`00o`[ooooo0_oo0035ooooo`00:_oo
ool2o`0001cooooo00?o003oooooooooool0>oooool00ol00?ooooooooooo`0?ooooo`03ool00?l0
0?oooooo01Wooooo00?o003oooooooooool01Oooool00ol00?ooooooooooo`0@ooooo`04o`00oooo
ooooo`00o`00o`gooooo00Coo`00o`00oooooooo003odOooool002[ooooo00?o0000ooooooooool0
6oooool00ol00?ooooooooooo`0kooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool0
6?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00kooooo0_oo00001?l00?oooooo
ool00?l00?l=ooooo`;oo`0000?o003oooooooooool0d?ooool002[ooooo00?o0000ooooooooool0
6oooool00ol00?ooooooooooo`0kooooo`03o`00oooooooooooo013ooooo00?o003oooooooooool0
6?ooool00ol00?ooooooooooo`05ooooo`03o`00oooooooooooo00kooooo0_oo00001?l00?oooooo
ool00?l00?l=ooooo`?oo`00d_ooool002[ooooo00?o0000ooooooooool06oooool00ol00?oooooo
ooooo`0jooooo`03ool00?l00?oooooo017ooooo00?o003oooooooooool06Oooool00ol00?oooooo
ooooo`04ooooo`03o`00oooooooooooo00oooooo00Goo`00o`00ooooooooo`00o`00o`0=ooooo`?o
o`00d_ooool002[ooooo00?o0000ooooooooool06oooool00ol00?ooooooooooo`0jooooo`03ool0
0?l00?oooooo013ooooo00?o003oooooooooool06Oooool00ooo003o003oooooo`03ooooo`;oo`00
00?o003oooooooooool03oooool01Ooo003o003ooooooooo003o003o0>;ooooo000Zooooo`03o`00
0?oooooooooo01Sooooo0_oo00000ol00?ooooooooooo`0kooooo`;oo`0000?o003oooooooooool0
3_ooool00ol00?ooooooooooo`0Iooooo`03ool00?l00?oooooo00?ooooo0_oo00000ol00?oooooo
ooooo`0?ooooo`05ool00?l00?ooooooool00?l00?l0h_ooool002[ooooo0_l0000Iooooo`;oo`00
00?o003oooooooooool0>oooool2ool00003o`00oooooooooooo00kooooo00?o003oooooooooool0
6Oooool00ooo003o003oooooo`03ooooo`;oo`0000?o003oooooooooool03oooool2ool000;o003o
hoooool002[ooooo00?o0000ooooooooool06?ooool2ool00003o`00oooooooooooo03_ooooo0_oo
00000ol00?ooooooooooo`0=ooooo`03ool00?l00?oooooo01[ooooo00?oo`00o`00ooooool00ooo
ool00ooo003o003oooooo`0Cooooo`;o003ohoooool002[ooooo00?o0000ooooooooool05oooool3
ool00003o`00oooooooooooo03_ooooo0_oo00000ol00?ooooooooooo`0=ooooo`03ool00?l00?oo
oooo01[ooooo00?oo`00o`00ooooool00oooool00ooo003o003oooooo`3hooooo`00:_ooool00ol0
003oooooooooo`0Gooooo`;oo`0000?oooooo`00ooooool0?_ooool00ol00?ooooooooooo`0<oooo
o`;oo`0000?o003oooooooooool06oooool01_l00?ooooooooooooooooooo`00o`00ooWooooo000Z
ooooo`03o`000?oooooooooo01Oooooo0_oo00000ol00?ooooooooooo`0nooooo`03o`00oooooooo
oooo00cooooo0_oo00000ol00?ooooooooooo`0Kooooo`03o`00oooooooooooo00;ooooo00?o003o
ooooooooool0moooool002[ooooo00?o0000ooooooooool06Oooool00ol00?ooooooooooo`0noooo
o`03o`00oooooooooooo00cooooo0_oo00000ol00?ooooooooooo`0Kooooo`05o`00oooooooooooo
ooooool00?l0n_ooool002[ooooo00?o0000ooooooooool06Oooool00ol00?ooooooooooo`0ooooo
o`03o`00oooooooooooo00_ooooo00?oo`00o`00ooooool07Oooool01Ol00?oooooooooooooooooo
003o0?[ooooo000Zooooo`;o00006_ooool00ol00?ooooooooooo`0oooooo`03o`00oooooooooooo
00cooooo00?o003oooooooooool07Oooool01?l00?ooooooooooool00?ojooooo`00:_ooool00ol0
003oooooooooo`0Hooooo`03o`00oooooooooooo043ooooo00?o003oooooooooool03?ooool00ol0
0?ooooooooooo`0Mooooo`04o`00ooooooooooooo`00oo[ooooo000Zooooo`03o`000?oooooooooo
01Sooooo00?o003oooooooooool0?oooool00ooo003o003oooooo`0=ooooo`03o`00oooooooooooo
01_ooooo0_oo00000ol00?ooooooo`00o`3kooooo`00:_ooool00ol0003oooooooooo`0Fooooo`;o
o`0000?o003oooooooooool0?oooool00ooo003o003oooooo`0=ooooo`03o`00oooooooooooo01_o
oooo0ooo0002o`00oo_ooooo000Zooooo`03o`000?oooooooooo01Kooooo0_oo00000ol00?oooooo
ooooo`0oooooo`03ool00?l00?oooooo00gooooo00?o003oooooooooool07?ooool3ool00?cooooo
000Zooooo`03o`000?oooooooooo01Kooooo0_oo00000ol00?ooooooooooo`0oooooo`;oo`0000?o
003oooooooooool02Oooool00ooo003o003oooooo`0Nooooo`?oo`00o?ooool002[ooooo0_l0000F
ooooo`;oo`0000?o003oooooooooool0@?ooool2ool00003o`00oooooooooooo00Wooooo00?oo`00
o`00ooooool07oooool2ool00?cooooo000Zooooo`03o`000?oooooooooo01Gooooo0_oo00000ol0
0?ooooooooooo`10ooooo`;oo`0000?o003oooooooooool02Oooool00ooo003o003oooooo`3ooooo
oakooooo000Zooooo`03o`000?oooooooooo01Gooooo0_oo00000ol00?ooooooooooo`12ooooo`03
o`00oooooooooooo00Sooooo0_oo00000ol00?ooooooooooo`3ooooooagooooo000Zooooo`03o`00
0?oooooooooo01Oooooo00?o003oooooooooool0@_ooool00ol00?ooooooooooo`08ooooo`;oo`00
00?o003oooooooooool0oooooolMooooo`003_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01_ooool00ol0003oooooooooo`0Fooooo`03
o`00oooooooooooo04Cooooo00?o003oooooooooool01oooool00ooo003o003oooooo`3ooooooaoo
oooo000>ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_oo
ool01Oooool00ol0003oooooooooo`0Fooooo`03o`00oooooooooooo04Cooooo00?o003ooooooooo
ool02?ooool00ol00?ooooooooooo`3ooooooakooooo000>ooooo`05oa0@4?ooooooooooooooool@
41004?ooool00ol0003oooooooooo`04ooooo`?o00005_ooool00ol00?ooooooooooo`14ooooo`03
o`00oooooooooooo00Sooooo00?o003oooooooooool0oooooolNooooo`003_ooool01Ol0003ooooo
oooooooooooo000000oooooo00?oMgMgoc8b<_ooool01Oooool00ol0003oooooooooo`0Fooooo`03
o`00oooooooooooo04?ooooo00?oo`00o`00ooooool02Oooool00ol00?ooooooooooo`3ooooooako
oooo000>ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00Kooooo00?o0000ooooooooool05_ooool00ol00?ooooooooooo`13ooooo`;oo`0000?o003ooooo
ooooool01oooool00ol00?ooooooooooo`3ooooooakooooo000>ooooo`05oa0@4?oooooooooooooo
ool@41003?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Cooooo00?oo`00o`00
ooooool0AOooool2ool00003o`00oooooooooooo00Kooooo00?o003oooooooooool0oooooolOoooo
o`003_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0Dooooo`03ool00?l00?oooooo04Gooooo0_oo00000ol00?ooooooooooo`05oooo
o`03ool00?l00?oooooo0?oooooo8?ooool000kooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<oooo
o`Co00001oooool00ol0003oooooooooo`0Cooooo`;oo`0000?o003oooooooooool0A?ooool3ool0
0003o`00oooooooooooo00Cooooo00?oo`00o`00ooooool0oooooolPooooo`00:_ooool2o`0001Co
oooo0_oo00000ol00?ooooooooooo`15ooooo`;oo`0000?o003oooooooooool00oooool00ooo003o
003oool0003oooooob7ooooo000Zooooo`03o`000?oooooooooo01?ooooo0_oo00000ol00?oooooo
ooooo`17ooooo`03o`00oooooooooooo00?ooooo00?oo`00o`00ooooool0oooooolQooooo`00:_oo
ool00ol0003oooooooooo`0Dooooo`03o`00oooooooooooo04Wooooo00?o003oooooooooool00_oo
ool00ooo003o003oooooo`3oooooob7ooooo000Zooooo`03o`000?oooooooooo01Cooooo00?o003o
ooooooooool0BOooool00ol00?ooooooooooo`02ooooo`03o`00oooo003ooooo0?oooooo8Oooool0
02[ooooo00?o0000ooooooooool05?ooool00ol00?ooooooooooo`1:ooooo`05o`00oooooooooooo
ooooool00?l0oooooolSooooo`00:_ooool00ol0003oooooooooo`0Dooooo`03o`00oooooooooooo
04[ooooo00?o003oooooooooool00_l00?ooooooob?ooooo000Zooooo`;o00005?ooool00ol00?oo
ooooooooo`19ooooo`;oo`0000Coooooo`00ool00?oo003ooooooolTooooo`00:_ooool00ol0003o
ooooooooo`0Cooooo`03o`00oooooooooooo04Wooooo0ooo003oooooobOooooo000Zooooo`03o`00
0?oooooooooo017ooooo0_oo00000ol00?ooooooooooo`1:ooooo`?oo`00oooooolVooooo`00:_oo
ool00ol0003oooooooooo`0Aooooo`03ool00?l00?oooooo04gooooo0_oo003oooooobKooooo000Z
ooooo`03o`000?oooooooooo013ooooo0_oo00000ol00?ooooooooooo`3oooooogCooooo000Zoooo
o`03o`000?oooooooooo013ooooo0_oo00000ol00?ooooooooooo`3oooooogCooooo000Zooooo`03
o`000?oooooooooo013ooooo0_oo00000ol00?ooooooooooo`3oooooogCooooo000Zooooo`;o0000
4_ooool00ol00?ooooooooooo`3oooooogGooooo000Zooooo`03o`000?oooooooooo017ooooo00?o
003oooooooooool0oooooomeooooo`00:_ooool00ol0003oooooooooo`0Aooooo`03o`00oooooooo
oooo0?ooooooMOooool002[ooooo00?o0000ooooooooool04?ooool00ol00?ooooooooooo`3ooooo
ogKooooo000Zooooo`03o`000?oooooooooo013ooooo00?o003oooooooooool0oooooomfooooo`00
:_ooool00ol0003oooooooooo`0@ooooo`03o`00oooooooooooo0?ooooooM_ooool002[ooooo0_l0
000?ooooo`03ool00?l00?oooooo0?ooooooN?ooool002[ooooo00?o0000ooooooooool03_ooool0
0ooo003o003oooooo`3oooooogSooooo000Zooooo`03o`000?oooooooooo00gooooo0_oo00000ol0
0?ooooooooooo`3oooooogOooooo000Zooooo`03o`000?oooooooooo00gooooo0_oo00000ol00?oo
ooooooooo`3oooooogOooooo0006ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Ko
oooo00?o0000onk^k_ooool01?ooool01Om4A4Co0000o`000?lb<S;ogMgM00Kooooo00?o0000oooo
ooooool03Oooool00ooo003o003oooooo`3oooooogWooooo0006ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Kooooo00?oEEEEojVYZOooool01oooool00omgMgOo<S8booooo`05oooo
o`03o`000?oooooooooo00kooooo00?o003oooooooooool0oooooomhooooo`001_ooool01Ol@413o
oooooooooooooooo410@00gooooo00?oZJVYoeEEEOooool02?ooool00ol0003oooooooooo`04oooo
o`?o00003_ooool00ol00?ooooooooooo`3oooooogSooooo0006ooooo`05o`000?oooooooooooooo
ool000003_ooool00olQ8B7oooooooooo`06ooooo`03ogMgMolb<S;ooooo00Gooooo00?o0000oooo
ooooool03Oooool00ol00?ooooooooooo`3oooooogWooooo0006ooooo`05o`000?oooooooooooooo
ool000003_ooool00omEEEGoc<c<ooooo`03ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01_ooool0
0ol0003oooooooooo`0=ooooo`03o`00oooooooooooo0?ooooooNOooool000Kooooo00Go410@oooo
oooooooooooooa0@400>ooooo`03ojVYZOmgMgOooooo00?ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0=ooooo`03o`00oooooooooooo0?ooooooNOooool000Kooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0;ooooo`05oa0@4?oooooooooooooooolb<S801?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00gooooo00?o003oooooooooool0oooooomiooooo`001_ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo1Ol00004ooooo`Co00001oooool00ol0003ooooooooo
o`0;ooooo`03ool00?l00?oooooo0?ooooooNoooool002[ooooo0_l0000<ooooo`03ool00?l00?oo
oooo0?ooooooNoooool002[ooooo00?o0000ooooooooool02_ooool2ool00003o`00oooooooooooo
0?ooooooN_ooool002[ooooo00?o0000ooooooooool02_ooool00ooo003o003oooooo`3oooooogco
oooo000Zooooo`03o`000?oooooooooo00[ooooo00?oo`00o`00ooooool0oooooomlooooo`00:_oo
ool00ol0003oooooooooo`0;ooooo`03o`00oooooooooooo0?ooooooNoooool002[ooooo00?o0000
ooooooooool02oooool00ol00?ooooooooooo`3oooooog_ooooo000Zooooo`03o`000?oooooooooo
00[ooooo00?o003oooooooooool0oooooomlooooo`00:_ooool2o`0000_ooooo00?o003ooooooooo
ool0oooooomlooooo`00:_ooool00ol0003oooooooooo`0:ooooo`03o`00oooooooooooo0?oooooo
O?ooool002[ooooo00?o0000ooooooooool02Oooool00ol00?ooooooooooo`3ooooooggooooo000Z
ooooo`03o`000?oooooooooo00Oooooo0_oo00000ol00?ooooooooooo`3ooooooggooooo000Zoooo
o`03o`000?oooooooooo00Oooooo0_oo00000ol00?ooooooooooo`3ooooooggooooo000Zooooo`03
o`000?oooooooooo00Oooooo00?oo`00o`00ooooool0oooooomoooooo`00:_ooool2o`0000Oooooo
0_oo00000ol00?ooooooooooo`3oooooogkooooo000Zooooo`03o`000?oooooooooo00Kooooo0_oo
00000ol00?ooooooooooo`3oooooogkooooo000Zooooo`03o`000?oooooooooo00Oooooo00?o003o
ooooooooool0oooooomoooooo`00:_ooool00ol0003oooooooooo`07ooooo`03o`00oooooooooooo
0?ooooooOoooool002[ooooo00?o0000ooooooooool01_ooool00ol00?ooooooooooo`3ooooooh3o
oooo000Zooooo`03o`000?oooooooooo00Gooooo00?o003oooooooooool0oooooon1ooooo`00:_oo
ool2o`0000Kooooo00?o003oooooooooool0oooooon1ooooo`00:_ooool00ol0003oooooooooo`03
ooooo`03ool00?l00?oooooo0?ooooooPoooool002[ooooo00?o0000ooooooooool00_ooool00ooo
003o003oool0003oooooohCooooo000Zooooo`07o`000?oooooooooooooooooo003o003oool0003o
ooooohGooooo000Oooooo`Co000000?o410@ooooooooool01?ooool01_l0003ooooooooooooo003o
003oool00?ooooooQ_ooool0027ooooo00?o0000ooooooooool01_ooool01Ol0003oooooo`00ool0
0?ooo`000?ooooooQoooool0027ooooo00?o0000ooooooooool01_ooool3o`00ooooooooROooool0
027ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooohWooooo000Qooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0oooooon9ooooo`008Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo0?ooooooROooool0027ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`3oooooohWooooo000Oooooo`03oeEEEOmVIVKo000000Sooooo00?o0000
ooooooooool0oooooon9ooooo`00:_ooool00ol0003oooooooooo`3oooooohWooooo003ooooookKo
oooo003ooooookKooooo003ooooookKooooo003ooooookKooooo003ooooookKooooo003dooooo`?o
000000?o410@ooooooooool05?ooool01OlQ8B7o0000o`000?m4A4CogMgM027ooooo0ol000000ol@
413oooooooooo`0Nooooo`?o000000?o410@ooooooooool0Eoooool00?Kooooo00?o410@okZj^_oo
ool06?ooool00omgMgOo<S8booooo`0Rooooo`03o`000?oooooooooo027ooooo00?o410@okZj^_oo
ool0F?ooool00?Kooooo00?oV9RHoc8b<_ooool06Oooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo027ooooo00?oV9RHoc8b<_ooool0F?ooool006Gooooo00GoZJVYoa0@4?l0003o410@
ojVYZ@03ooooo`06oa0@4?lb<S;o0000o`000?l@413oZJVY0oooool01OmVIVKo0000o`000?m4A4Co
c<c<00?ooooo1Ol00002ooooo`Go00000oooool5o`0000?ooooo00KoV9RHo`000?l0003oMgMgoa0@
4?l00003ooooo`05oiRHV?l0003o0000odA4A?nj^[X00_ooool02?o^k^koEEEEo`000?l0003oEEEE
onk^k_oooooo410@1Ol00006ooooo`05o`000?o<c<cogMgMo`000?o^k^h00oooool5o`0000?ooooo
00GoV9RHo`000?l0003oA4A4okZj^P02ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@oooo
ooooool01oooool00olQ8B7o<S8booooo`03ooooo`08oiRHV?l0003o0000ogMgMol@413o0000oooo
ool@4105o`0000Cooooo00?ogMgMo`000?nj^[X01Oooool5o`0000;ooooo00Co410@o`000?l0003o
oooo0_l000002?l@413oooooonk^k_mEEEGo0000oa0@4?o<c<co00001_ooool00ol@413o0000o`00
0002o`000003oa0@4?oooooo410@00Go00000oooool01_o^k^koEEEEo`000?l0003oA4A4okZj^P;o
oooo00Kok^k^oeEEEOl0003o0000ogMgMol00003ooooo`09oiRHV?l0003o0000ogMgMol0003o410@
ooooooo^k^koEEEE00;o000000GoA4A4okZj^_oooooooooooa0@4002o`000004ooooool0003o0000
oa0@40;ooooo00GoIVIVo`000?l0003oA4A4olc<c003ooooo`03omgMgOl0003o^[Zj05Sooooo001T
ooooo`07ojVYZOlQ8B7o^[Zjoooooonj^[[o8B4QojVYZ@02ooooo`06o`000?nYZJWooooooooooonj
^[[o00000_ooool01_mVIVKoMgMgooooooooooooQhN7oa0@40Gooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00Go0000olc<c?o^k^koQhN7
o`000004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000_ooool01_mEEEGoMgMgooooooooooooMgMg
oeEEE@?ooooo00?o0000ooooooooool01_ooool01_nYZJWo0000ohN7QonHV9So0000oiRHV0Gooooo
00?o0000ooooooooool00oooool01Ol@413o^[Zjonk^k_mgMgOo410@00?ooooo00Go0000oooooooo
ooooooooo`000009ooooo`04oiRHV?lb<S;o410@okZj^P?ooooo00Go0000olc<c?o^k^koQhN7o`00
0004ooooo`03o`000?oooooooooo00Gooooo00?oEEEEogMgMom4A4@01oooool00ol0003ooooooooo
o`03ooooo`05o`000?ooooooooooooooool000000_ooool01_mEEEGoMgMgooooooo^k^koEEEEo`00
00Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`06oeEEEOmgMgOooooo
onk^k_mgMgOo410@0_ooool01_mEEEGoMgMgooooooo^k^koEEEEo`0000?ooooo00Go0000ojVYZOoo
ooooQhN7o`000002ooooo`06oeEEEOmgMgOoooooonk^k_mgMgOo410@0oooool01Ol0003ooooooooo
oooooooo000000;ooooo00KoIVIVogMgMoooooooooooohN7Qol@4103ooooo`03oeEEEOmgMgOoA4A4
05Sooooo001Tooooo`03ob4Q8OnYZJWooooo00;ooooo00?oZJVYob4Q8Oooool00_ooool01Onj^[[o
QhN7ofIVI_mVIVKo410@00;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool01Ol@413oQhN7ooooooo^k^ko
000000Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000002?ooool01_mEEEGoQhN7odA4A?mEEEGoMgMgoeEEE@Gooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000002Oooool01?l@
413o^[ZjoiRHV?lb<S83ooooo`05oa0@4?n7QhOoooooonk^k_l000001?ooool00ol0003ooooooooo
o`04ooooo`05omgMgOl@413oooooob4Q8OoMgMd01_ooool00ol0003oooooooooo`03ooooo`05o`00
0?ooooooooooooooool000000_ooool01_l0003oooooooooooooooook^k^o`0000Sooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00Ko0000
ooooooooooooooooonk^k_l00003ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003o
ooooooooo`06ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`05oooo
o`05omgMgOl@413oooooob4Q8OoMgMd0Eoooool006Cooooo00?o0000ooooooooool00oooool01Ol0
003ooooooooooolb<S;o8B4Q00;oMgMg00GoQhN7onk^k_ooooooooooo`00000:ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03okZj^_l@
413o000000;o00001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000008ooooo`06o`000?oMgMgoA4A4ob4Q8Oo^k^ko00001Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000008
ooooo`06oiRHV?lb<S;oooooooooool@413o^[Zj0_ooool00onj^[[o410@o`000002o`0000Cooooo
00?o0000ooooooooool01?ooool01OmVIVKoQhN7oooooonHV9SoEEEE00Kooooo00?o0000oooooooo
ool00oooool01Ol0003ooooooooooooooooo000000;ooooo00Ko0000ooooooooooooooooonk^k_l0
0008ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool6o`0000;ooooo00Ko
0000ooooooooooooooooonk^k_l00003ooooo`05o`000?ooooooooooooooool000000_ooool6o`00
00?ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00Gooooo00GoIVIV
ohN7QoooooooV9RHoeEEE@1Gooooo`00I?ooool00ol0003oooooooooo`03ooooo`09o`000?oooooo
ooooo`000?nj^[[oooooonk^k_mgMgOo000000;ooooo00KoIVIVogMgMoooooooooooohN7Qol00005
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06
ooooo`03olc<c?l0003ooooo00?ooooo00?o0000ooooooooool01?ooool01_mEEEGoMgMgoooooooo
ooooMgMgoeEEE@?ooooo00?o0000oc8b<_oMgMd01Oooool02?nYZJWo8B4Qoooooon7QhOoEEEEoooo
oolb<S;oZJVY1?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00Go0000
ogMgMoooooooZJVYo`000007ooooo`03onk^k_l0003ogMgM00;ooooo00?oV9RHoc8b<_ooool01?oo
ool00oo<c<co0000ooooo`03ooooo`03o`000?lb<S;ogMgM00?ooooo00?ok^k^o`000?o^k^h00_oo
ool00ol0003ogMgMooooo`04ooooo`03o`000?oooooooooo00?ooooo00Go0000ohN7QoooooooZJVY
o`000002ooooo`06oeEEEOmgMgOoooooonk^k_mEEEGo00002?ooool00ol0003oooooooooo`04oooo
o`03o`000?lb<S;ogMgM00Cooooo00KoEEEEohN7Qoo^k^koooooohN7Qolb<S82ooooo`06ofIVI_mg
MgOoooooonk^k_mEEEGo00000oooool01Ol0003ooooooooooooooooo000000;ooooo00KoEEEEohN7
Qoo^k^koooooohN7Qolb<S83ooooo`05o`000?n7QhOoooooojVYZOl000000_ooool02_mVIVKoMgMg
ooooooooooooQhN7o`000?ooooook^k^o`000?o^k^h2ooooo`03o`000?oMgMgooooo05Gooooo001T
ooooo`03ob4Q8OnYZJWooooo00;ooooo00KoZJVYob4Q8OooooooooooojVYZOlQ8B42o`000006oc8b
<_l0003oooooooooooo^k^koIVIV0_l000000om4A4Co0000ooooo`02ooooo`03oa0@4?l0003o0000
00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`04oc8b<_l0003o0000
oiRHV0;ooooo00?o410@o`000?l000000ol00003ooooo`06onk^k_mEEEGo0000o`000?mEEEGok^k^
0_ooool2o`000004ojVYZOlQ8B7o0000ob4Q8@?ooooo0ol00002ooooo`?o00000_ooool00ol@413o
0000o`000003ooooo`03oa0@4?l0003o000000?o00001?ooool01Ol0003oMgMgo`000?l0003oV9RH
00Oooooo00?o410@o`000?l000000_ooool3o`0000;ooooo00Co<S8bo`000?l0003oV9RH0oooool2
o`000006ojVYZOlQ8B7o0000ob4Q8Ooooooo410@0_l000001?oooooo0000o`000?l@4103ooooo`03
oa0@4?l0003o000000Cooooo00?o410@o`000?mgMgL00_l000002_nHV9Soooooooooooo^k^koEEEE
o`000?lQ8B7oZJVYo`000?l@4105ooooo`03oa0@4?l0003o000000?o00000_ooool2o`000004ojVY
ZOlQ8B7o0000ob4Q8@;ooooo00Kok^k^oeEEEOl0003o0000odA4A?o^k^h2ooooo`0:onk^k_mEEEGo
0000o`000?mgMgOo0000oa0@4?oooooo410@o`0000;ooooo0_l00002ooooo`06onk^k_mEEEGo0000
o`000?m4A4Cok^k^0_ooool00ol@413o0000ogMgM`02o`000005oiRHV?ooooooooooonk^k_mVIVH0
0_l000001?m4A4Co0000ooooool@4102o`000004ooooool0003o0000oa0@45Kooooo001Tooooo`07
ojVYZOlQ8B7o^[Zjoooooonj^[[o8B4QojVYZ@0Looooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0B?ooool00ol0003oooooooooo`2Gooooo`00IOooool01OnYZJWo410@o`000?l@413o
ZJVY01Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Hooooo`03oa0@4?nj^[[o
oooo09Oooooo0020ooooo`03oa0@4?oooooooooo00;ooooo00?o410@o`000?l000001Oooool00ol@
413o0000o`00000booooo`03oa0@4?oooooooooo00[ooooo00?o410@o`000?ooool0;_ooool00ol@
413oooooooooo`0Hooooo`04okZj^_l@413o0000oa0@49Kooooo003ooooookKooooo003ooooookKo
oooo003ooooookKooooo003ooooookKooooo003ooooookKooooo003ooooookKooooo003ooooookKo
oooo003ooooookKooooo003ooooookKooooo0000\
\>"],
  ImageRangeCache->{{{0, 436.5}, {269.375, 0}} -> {-1.74602, -0.907928, \
0.0516357, 0.0100622}}]
}, Open  ]],

Cell[TextData[{
  "The WKB solution (dashed line) works reasonably well, considering that the \
time variation of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Omega]\_o\)(t)\)]],
  " is rather rapid. By changing the value of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Alpha]\)\(,\)\)\)]],
  " the reader can observe how the error in the WKB solution depends on  rate \
of change of  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Omega]\_o\)(t)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\tCan we find a constant of the motion for this problem in the WKB limit, \
where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\& . \_o/\[Omega]\_o\^2 << 1\)]],
  "? We know that energy is not conserved.  However, consider the following \
quantity: "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`J = \(E(t)\)/\(\(\[Omega]\_o\)(t)\)\)]],
  "."
}], "NE2",
  CellTags->"(5.2.22)"],

Cell[TextData[{
  " We will show that the quantity ",
  Cell[BoxData[
      \(TraditionalForm\`J\)]],
  " is  constant  in the WKB approximation, and is the adiabatic invariant we \
are looking for.  To show this, we will substitute Eq. ",
  ButtonBox["(5.2.21)",
    ButtonData:>"(5.2.21)",
    ButtonStyle->"Hyperlink"],
  " into Eq. ",
  ButtonBox["(5.2.19)",
    ButtonData:>"(5.2.19)",
    ButtonStyle->"Hyperlink"],
  ". This requires that we first evaluate ",
  Cell[BoxData[
      \(TraditionalForm\`\(x\& . \)(
          t) = \[DifferentialD]x/\[DifferentialD]t\)]],
  ":"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(x\& . \)(
          t)\  = \(A\/\@\(\(\[Omega]\_o\)(t)\)\)[\(-\(\[Omega]\& . \_o\/\(2  \
\[Omega]\_o\)\)\) \(cos(\[Integral]\^t\(\( \[Omega]\_o\)(
                        t)\) \[DifferentialD]t\  + \[Phi])\) + \
\(\[Omega]\_o\) \(sin(\[Integral]\^t\(\( \[Omega]\_o\)(
                        t)\) \[DifferentialD]t\  + \[Phi])\)]\)]],
  "."
}], "Text"],

Cell[TextData[{
  "However, the first term is negligible compared to the second term in the \
WKB limit where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\& . \_o/\[Omega]\_o\^2 << 1\)]],
  " , so we will drop it. Then we have \n\t\t",
  Cell[BoxData[
      \(TraditionalForm\`H = \(E \[TildeEqual] \ \(1\/2\) 
                m \( A\^2\/\(\(\[Omega]\_o\)(
                      t)\)\) \(\[Omega]\_o\^2\) \(\(sin\^2\)(\[Integral]\^t\(\
\( \[Omega]\_o\)(t)\) \[DifferentialD]t\  + \[Phi])\) + \(1\/2\) 
                m\ \(\[Omega]\_o\^2\) \(A\^2\/\(\(\[Omega]\_o\)(
                      t)\)\) \(\(cos\^2\)(\[Integral]\^t\(\( \[Omega]\_o\)(
                          t)\) \[DifferentialD]t\  + \[Phi])\) = \(1\/2\) 
            m\ A\^2\ \(\(\[Omega]\_o\)(t)\)\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "This proves that ",
  Cell[BoxData[
      \(TraditionalForm\`J = E/\(\(\[Omega]\_o\)(t)\)\)]],
  " is a constant of the motion in the WKB limit. However, it is only an \
approximate constant. For example, if we evaluate ",
  Cell[BoxData[
      \(TraditionalForm\`E/\(\(\[Omega]\_o\)(t)\)\)]],
  " using the previous numerical solution, we find (Cell ",
  ButtonBox["5.22",
    ButtonData:>"Cell 5.22",
    ButtonStyle->"Hyperlink"],
  ") that this quantity does vary slightly:"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(J[
          t_]\  = \ \((1/2\ \(x1'\)[t]^2\  + \ 
              1/2\ \[Omega]\_o[t]^2\ x1[t]^2)\)/\[Omega]\_o[t];\)\), "\n", 
    \(\(Plot[J[t], {t, 0, 15}, PlotPoints \[Rule] 2000, 
        PlotRange \[Rule] All, 
        PlotLabel \[Rule] "\<adiabatic invariant vs time\>"];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 5.22"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.0634921 -2.65097 6.1565 [
[.15079 .41478 -3 -9 ]
[.15079 .41478 3 0 ]
[.27778 .41478 -3 -9 ]
[.27778 .41478 3 0 ]
[.40476 .41478 -3 -9 ]
[.40476 .41478 3 0 ]
[.53175 .41478 -3 -9 ]
[.53175 .41478 3 0 ]
[.65873 .41478 -6 -9 ]
[.65873 .41478 6 0 ]
[.78571 .41478 -6 -9 ]
[.78571 .41478 6 0 ]
[.9127 .41478 -6 -9 ]
[.9127 .41478 6 0 ]
[.01131 .05789 -24 -4.5 ]
[.01131 .05789 0 4.5 ]
[.01131 .18102 -24 -4.5 ]
[.01131 .18102 0 4.5 ]
[.01131 .30415 -24 -4.5 ]
[.01131 .30415 0 4.5 ]
[.01131 .55041 -24 -4.5 ]
[.01131 .55041 0 4.5 ]
[.5 .63053 -83 0 ]
[.5 .63053 83 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.15079 .42728 m
.15079 .43353 L
s
[(2)] .15079 .41478 0 1 Mshowa
.27778 .42728 m
.27778 .43353 L
s
[(4)] .27778 .41478 0 1 Mshowa
.40476 .42728 m
.40476 .43353 L
s
[(6)] .40476 .41478 0 1 Mshowa
.53175 .42728 m
.53175 .43353 L
s
[(8)] .53175 .41478 0 1 Mshowa
.65873 .42728 m
.65873 .43353 L
s
[(10)] .65873 .41478 0 1 Mshowa
.78571 .42728 m
.78571 .43353 L
s
[(12)] .78571 .41478 0 1 Mshowa
.9127 .42728 m
.9127 .43353 L
s
[(14)] .9127 .41478 0 1 Mshowa
.125 Mabswid
.05556 .42728 m
.05556 .43103 L
s
.0873 .42728 m
.0873 .43103 L
s
.11905 .42728 m
.11905 .43103 L
s
.18254 .42728 m
.18254 .43103 L
s
.21429 .42728 m
.21429 .43103 L
s
.24603 .42728 m
.24603 .43103 L
s
.30952 .42728 m
.30952 .43103 L
s
.34127 .42728 m
.34127 .43103 L
s
.37302 .42728 m
.37302 .43103 L
s
.43651 .42728 m
.43651 .43103 L
s
.46825 .42728 m
.46825 .43103 L
s
.5 .42728 m
.5 .43103 L
s
.56349 .42728 m
.56349 .43103 L
s
.59524 .42728 m
.59524 .43103 L
s
.62698 .42728 m
.62698 .43103 L
s
.69048 .42728 m
.69048 .43103 L
s
.72222 .42728 m
.72222 .43103 L
s
.75397 .42728 m
.75397 .43103 L
s
.81746 .42728 m
.81746 .43103 L
s
.84921 .42728 m
.84921 .43103 L
s
.88095 .42728 m
.88095 .43103 L
s
.94444 .42728 m
.94444 .43103 L
s
.97619 .42728 m
.97619 .43103 L
s
.25 Mabswid
0 .42728 m
1 .42728 L
s
.02381 .05789 m
.03006 .05789 L
s
[(0.44)] .01131 .05789 1 0 Mshowa
.02381 .18102 m
.03006 .18102 L
s
[(0.46)] .01131 .18102 1 0 Mshowa
.02381 .30415 m
.03006 .30415 L
s
[(0.48)] .01131 .30415 1 0 Mshowa
.02381 .55041 m
.03006 .55041 L
s
[(0.52)] .01131 .55041 1 0 Mshowa
.125 Mabswid
.02381 .08868 m
.02756 .08868 L
s
.02381 .11946 m
.02756 .11946 L
s
.02381 .15024 m
.02756 .15024 L
s
.02381 .21181 m
.02756 .21181 L
s
.02381 .24259 m
.02756 .24259 L
s
.02381 .27337 m
.02756 .27337 L
s
.02381 .33494 m
.02756 .33494 L
s
.02381 .36572 m
.02756 .36572 L
s
.02381 .3965 m
.02756 .3965 L
s
.02381 .45807 m
.02756 .45807 L
s
.02381 .48885 m
.02756 .48885 L
s
.02381 .51963 m
.02756 .51963 L
s
.02381 .02711 m
.02756 .02711 L
s
.02381 .5812 m
.02756 .5812 L
s
.02381 .61198 m
.02756 .61198 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
gsave
.5 .63053 -144 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(adiabatic) show
123.000 13.000 moveto
(invariant) show
183.000 13.000 moveto
(vs) show
201.000 13.000 moveto
(time) show
225.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 Mabswid
.02381 .42728 m
.02382 .42729 L
.02384 .42729 L
.02385 .42728 L
.02387 .42728 L
.02388 .42728 L
.02389 .42729 L
.0239 .42729 L
.02392 .42728 L
.02393 .42728 L
.02395 .42728 L
.02396 .42728 L
.02397 .42728 L
.02404 .42728 L
.02409 .42728 L
.02416 .42728 L
.02427 .42729 L
.0244 .42729 L
.02454 .4273 L
.02478 .42732 L
.02504 .42734 L
.02528 .42737 L
.02574 .42744 L
.02623 .42753 L
.02671 .42763 L
.02716 .42776 L
.02765 .4279 L
.02812 .42807 L
.02861 .42826 L
.02909 .42846 L
.02955 .42868 L
.03004 .42893 L
.03051 .42919 L
.03097 .42945 L
.03145 .42975 L
.03191 .43005 L
.03241 .4304 L
.03288 .43075 L
.03334 .43111 L
.03383 .43151 L
.0343 .4319 L
.03479 .43234 L
.03527 .43277 L
.03574 .43321 L
.03623 .43371 L
.0367 .4342 L
.03715 .43468 L
.03764 .4352 L
.03811 .43572 L
.0386 .43628 L
Mistroke
.03908 .43685 L
.03954 .43741 L
.04003 .43802 L
.0405 .43862 L
.041 .43926 L
.04148 .4399 L
.04194 .44052 L
.04243 .4412 L
.04291 .44186 L
.04337 .44251 L
.04385 .4432 L
.04432 .44389 L
.04482 .44462 L
.0453 .44534 L
.04576 .44604 L
.04625 .44679 L
.04672 .44751 L
.04717 .44822 L
.04766 .44898 L
.04812 .44972 L
.04862 .45051 L
.04909 .45128 L
.04955 .45203 L
.05004 .45282 L
.05051 .45359 L
.05101 .45439 L
.05149 .45516 L
.05195 .4559 L
.05244 .4567 L
.05291 .45747 L
.05337 .45821 L
.05386 .45899 L
.05432 .45974 L
.05482 .46054 L
.0553 .46131 L
.05576 .46204 L
.05624 .46281 L
.05672 .46354 L
.05717 .46425 L
.05765 .46499 L
.05812 .46569 L
.05861 .46643 L
.05908 .46713 L
.05954 .4678 L
.06003 .46849 L
.0605 .46915 L
.06099 .46984 L
.06147 .47049 L
.06194 .4711 L
.06243 .47173 L
Mistroke
.0629 .47232 L
.06335 .47287 L
.06384 .47345 L
.0643 .47398 L
.0648 .47454 L
.06528 .47505 L
.06573 .47552 L
.06622 .476 L
.06669 .47644 L
.06719 .47688 L
.06767 .47728 L
.06814 .47765 L
.06863 .478 L
.0691 .47832 L
.06956 .47861 L
.07004 .47888 L
.07051 .47912 L
.07101 .47935 L
.07149 .47954 L
.07195 .47969 L
.07244 .47982 L
.07268 .47987 L
.07291 .47991 L
.07313 .47994 L
.07336 .47997 L
.07348 .47998 L
.07361 .47999 L
.07366 .47999 L
.07372 .48 L
.07377 .48 L
.07383 .48 L
.07386 .48 L
.07389 .48 L
.07392 .48 L
.07395 .48 L
.07397 .48 L
.07398 .48 L
.07398 .48 L
.074 .48 L
.07401 .48 L
.07401 .48 L
.07402 .48 L
.07403 .48 L
.07404 .48 L
.07405 .48 L
.07406 .48 L
.07407 .48 L
.07408 .48 L
.0741 .48 L
.07412 .48 L
Mistroke
.07414 .48 L
.07418 .48 L
.07421 .48 L
.07427 .48 L
.07433 .48 L
.07444 .47999 L
.07455 .47998 L
.0748 .47996 L
.07504 .47992 L
.07526 .47988 L
.07574 .47977 L
.0762 .47963 L
.07669 .47944 L
.07716 .47922 L
.07766 .47894 L
.07814 .47864 L
.0786 .47831 L
.07909 .47793 L
.07956 .47752 L
.08002 .47709 L
.08051 .47658 L
.08097 .47606 L
.08147 .47545 L
.08195 .47482 L
.08241 .47417 L
.0829 .47344 L
.08337 .47268 L
.08382 .47192 L
.0843 .47106 L
.08477 .47018 L
.08526 .4692 L
.08574 .46821 L
.08619 .46722 L
.08668 .46611 L
.08715 .465 L
.08765 .46376 L
.08813 .46252 L
.08859 .46128 L
.08908 .4599 L
.08955 .45852 L
.09001 .45715 L
.09049 .45564 L
.09096 .45414 L
.09145 .45249 L
.09193 .45085 L
.09239 .44923 L
.09288 .44744 L
.09335 .44568 L
.09385 .44374 L
.09433 .44182 L
Mistroke
.09479 .43993 L
.09529 .43786 L
.09576 .43581 L
.09622 .4338 L
.0967 .4316 L
.09717 .42944 L
.09767 .42708 L
.09815 .42476 L
.09861 .42248 L
.0991 .41999 L
.09957 .41755 L
.10002 .41515 L
.10051 .41255 L
.10097 .40999 L
.10147 .40722 L
.10194 .40451 L
.1024 .40184 L
.10289 .39896 L
.10336 .39614 L
.10386 .39309 L
.10434 .3901 L
.1048 .38718 L
.10529 .38402 L
.10576 .38093 L
.10622 .37792 L
.1067 .37467 L
.10717 .3715 L
.10767 .36808 L
.10814 .36474 L
.1086 .36149 L
.10909 .35798 L
.10956 .35456 L
.11002 .35123 L
.1105 .34764 L
.11096 .34415 L
.11146 .3404 L
.11193 .33676 L
.11239 .33321 L
.11287 .3294 L
.11334 .3257 L
.11384 .32174 L
.11432 .31788 L
.11478 .31413 L
.11527 .31012 L
.11574 .30622 L
.1162 .30245 L
.11668 .29841 L
.11715 .2945 L
.11764 .29032 L
.11812 .28626 L
Mistroke
.11858 .28233 L
.11907 .27812 L
.11954 .27404 L
.12004 .26968 L
.12052 .26547 L
.12098 .26139 L
.12147 .25704 L
.12195 .25284 L
.1224 .24879 L
.12289 .24447 L
.12336 .2403 L
.12385 .23586 L
.12433 .23157 L
.12479 .22744 L
.12528 .22304 L
.12575 .2188 L
.12621 .21474 L
.12669 .21041 L
.12715 .20625 L
.12765 .20183 L
.12812 .19757 L
.12858 .19348 L
.12907 .18913 L
.12954 .18495 L
.13003 .1805 L
.13051 .17623 L
.13098 .17214 L
.13147 .16781 L
.13194 .16366 L
.1324 .15969 L
.13288 .15549 L
.13335 .15147 L
.13384 .14722 L
.13432 .14316 L
.13478 .13928 L
.13527 .13519 L
.13574 .13128 L
.13624 .12716 L
.13672 .12324 L
.13718 .1195 L
.13768 .11557 L
.13815 .11182 L
.13861 .10825 L
.13909 .10449 L
.13956 .10091 L
.14006 .09717 L
.14054 .09362 L
.141 .09025 L
.14149 .08673 L
.14196 .0834 L
Mistroke
.14242 .08025 L
.1429 .07696 L
.14336 .07385 L
.14386 .07061 L
.14434 .06757 L
.14479 .06471 L
.14528 .06174 L
.14575 .05894 L
.14625 .05605 L
.14673 .05333 L
.14719 .05077 L
.14768 .04814 L
.14816 .04568 L
.14861 .0434 L
.1491 .04106 L
.14957 .03889 L
.15006 .03668 L
.15054 .03464 L
.151 .03276 L
.15149 .03085 L
.15196 .02911 L
.15241 .02753 L
.1529 .02595 L
.15336 .02453 L
.15385 .02311 L
.15433 .02185 L
.15479 .02072 L
.15527 .01961 L
.15574 .01864 L
.15624 .01772 L
.15672 .01695 L
.15718 .01632 L
.15767 .01576 L
.15814 .01534 L
.1586 .01503 L
.15883 .01491 L
.15908 .01482 L
.1592 .01478 L
.15934 .01475 L
.1594 .01474 L
.15946 .01473 L
.15952 .01472 L
.15958 .01472 L
.15961 .01472 L
.15964 .01472 L
.15965 .01472 L
.15967 .01472 L
.15968 .01472 L
.1597 .01472 L
.15971 .01472 L
Mistroke
.15973 .01472 L
.15974 .01472 L
.15976 .01472 L
.15977 .01472 L
.15978 .01472 L
.15981 .01472 L
.15984 .01472 L
.15987 .01472 L
.15993 .01473 L
.15999 .01473 L
.16006 .01475 L
.16018 .01477 L
.1603 .0148 L
.16055 .0149 L
.16078 .01501 L
.16103 .01517 L
.16152 .01557 L
.16199 .01608 L
.16245 .01668 L
.16293 .01742 L
.1634 .01825 L
.16389 .01924 L
.16437 .02032 L
.16483 .02148 L
.16532 .02284 L
.16579 .02428 L
.16629 .02593 L
.16677 .02766 L
.16724 .02944 L
.16773 .03146 L
.16821 .03353 L
.16866 .03563 L
.16915 .03801 L
.16962 .04042 L
.17011 .04311 L
.17059 .04582 L
.17106 .04854 L
.17155 .05155 L
.17202 .05456 L
.17247 .05757 L
.17296 .06089 L
.17342 .0642 L
.17392 .06786 L
.17439 .0715 L
.17485 .07511 L
.17534 .07907 L
.17581 .083 L
.17631 .08729 L
.17679 .09155 L
.17725 .09576 L
Mistroke
.17774 .10035 L
.17822 .10488 L
.17867 .10933 L
.17916 .11418 L
.17963 .11893 L
.18012 .12409 L
.1806 .12916 L
.18106 .13413 L
.18155 .13952 L
.18202 .14481 L
.18248 .14998 L
.18296 .15557 L
.18342 .16104 L
.18392 .16695 L
.18439 .17272 L
.18485 .17835 L
.18534 .18442 L
.18581 .19035 L
.1863 .19672 L
.18678 .20293 L
.18725 .20897 L
.18774 .21546 L
.18821 .22177 L
.18866 .22789 L
.18915 .23447 L
.18961 .24084 L
.19011 .24768 L
.19059 .25431 L
.19105 .26073 L
.19154 .26761 L
.19201 .27426 L
.19251 .28137 L
.19299 .28824 L
.19345 .29489 L
.19394 .30197 L
.19442 .30882 L
.19487 .31541 L
.19536 .32244 L
.19583 .32922 L
.19633 .33643 L
.1968 .34338 L
.19726 .35005 L
.19776 .35715 L
.19823 .36397 L
.19868 .37051 L
.19916 .37745 L
.19963 .38411 L
.20012 .39116 L
.2006 .39792 L
.20106 .40438 L
Mistroke
.20155 .41121 L
.20201 .41774 L
.20251 .42463 L
.20299 .4312 L
.20346 .43747 L
.20395 .44408 L
.20442 .45039 L
.20488 .45639 L
.20536 .46271 L
.20583 .46871 L
.20633 .475 L
.2068 .48096 L
.20726 .4866 L
.20775 .49251 L
.20822 .4981 L
.20868 .50337 L
.20916 .50888 L
.20962 .51407 L
.21012 .51947 L
.21059 .52455 L
.21105 .52931 L
.21153 .53424 L
.212 .53886 L
.2125 .54363 L
.21298 .54808 L
.21344 .55222 L
.21393 .55647 L
.21441 .56041 L
.21486 .56405 L
.21534 .56777 L
.21581 .5712 L
.2163 .57467 L
.21678 .57785 L
.21724 .58073 L
.21773 .58363 L
.2182 .58624 L
.2187 .58881 L
.21918 .59111 L
.21964 .59314 L
.22013 .5951 L
.22061 .5968 L
.22106 .59825 L
.22155 .5996 L
.22202 .6007 L
.22251 .60166 L
.22299 .60239 L
.22345 .60289 L
.22369 .60307 L
.22381 .60315 L
.22394 .60321 L
Mistroke
.22406 .60326 L
.22412 .60327 L
.22418 .60329 L
.22423 .6033 L
.22428 .60331 L
.22431 .60331 L
.22434 .60332 L
.22436 .60332 L
.22437 .60332 L
.22438 .60332 L
.2244 .60332 L
.22441 .60332 L
.22442 .60332 L
.22444 .60332 L
.22446 .60332 L
.22447 .60332 L
.22448 .60332 L
.2245 .60332 L
.22451 .60332 L
.22454 .60331 L
.22457 .60331 L
.22464 .6033 L
.2247 .60329 L
.22477 .60327 L
.22489 .60323 L
.225 .60317 L
.22512 .6031 L
.22534 .60294 L
.2256 .6027 L
.22584 .60241 L
.2263 .60172 L
.22679 .60076 L
.22727 .59963 L
.22772 .59835 L
.2282 .59678 L
.22867 .59506 L
.22916 .59301 L
.22964 .59083 L
.2301 .58854 L
.23059 .58589 L
.23106 .58313 L
.23155 .57997 L
.23204 .57671 L
.2325 .57338 L
.23299 .56964 L
.23346 .56584 L
.23392 .56199 L
.2344 .55771 L
.23487 .55341 L
.23537 .54863 L
Mistroke
.23585 .54384 L
.23631 .53904 L
.2368 .53374 L
.23727 .52847 L
.23772 .52326 L
.2382 .51753 L
.23867 .51186 L
.23916 .50566 L
.23964 .49955 L
.24009 .49353 L
.24058 .48697 L
.24105 .4805 L
.24155 .47347 L
.24203 .46656 L
.24249 .45979 L
.24298 .45248 L
.24345 .44533 L
.24391 .43835 L
.24439 .43082 L
.24486 .42349 L
.24535 .41562 L
.24583 .40793 L
.24629 .40044 L
.24678 .3924 L
.24725 .3846 L
.24775 .37626 L
.24823 .36819 L
.24869 .36038 L
.24918 .35204 L
.24966 .344 L
.25011 .33627 L
.2506 .32802 L
.25107 .32006 L
.25156 .31158 L
.25204 .30343 L
.2525 .29562 L
.25299 .28736 L
.25347 .27944 L
.25392 .27188 L
.2544 .26389 L
.25487 .25628 L
.25536 .24828 L
.25584 .24064 L
.2563 .23334 L
.25678 .22566 L
.25725 .21838 L
.25775 .21078 L
.25823 .2036 L
.25869 .19681 L
.25919 .18974 L
Mistroke
.25966 .1831 L
.26011 .17688 L
.2606 .17041 L
.26107 .16432 L
.26156 .15801 L
.26204 .15212 L
.2625 .14665 L
.26299 .14105 L
.26346 .13588 L
.26391 .1311 L
.26439 .12623 L
.26486 .1218 L
.26535 .11733 L
.26583 .11326 L
.26628 .10954 L
.26677 .10581 L
.26724 .10248 L
.26774 .09925 L
.26821 .09641 L
.26868 .09395 L
.26917 .09161 L
.26964 .08965 L
.27009 .08805 L
.27058 .08664 L
.27104 .08552 L
.27128 .08505 L
.27154 .08462 L
.27179 .08427 L
.27201 .08404 L
.27214 .08394 L
.27225 .08386 L
.27237 .08381 L
.27244 .08378 L
.27247 .08377 L
.2725 .08377 L
.27253 .08376 L
.27256 .08376 L
.27258 .08375 L
.27259 .08375 L
.27261 .08375 L
.27262 .08375 L
.27263 .08375 L
.27264 .08375 L
.27266 .08375 L
.27267 .08375 L
.27269 .08375 L
.2727 .08375 L
.27271 .08375 L
.27273 .08375 L
.27276 .08376 L
Mistroke
.27279 .08376 L
.27285 .08377 L
.27291 .08379 L
.27298 .08382 L
.27309 .08387 L
.27322 .08396 L
.27347 .08418 L
.2737 .08447 L
.27395 .08486 L
.27445 .08588 L
.27493 .08718 L
.27538 .08873 L
.27587 .09066 L
.27634 .09279 L
.27684 .09535 L
.27733 .09813 L
.27779 .1011 L
.27828 .10456 L
.27876 .10818 L
.27921 .11193 L
.2797 .11621 L
.28017 .1206 L
.28066 .12554 L
.28114 .13056 L
.2816 .1356 L
.28209 .14123 L
.28257 .1469 L
.28302 .15257 L
.2835 .15883 L
.28397 .16507 L
.28446 .17192 L
.28494 .17873 L
.2854 .18545 L
.28589 .19279 L
.28636 .20002 L
.28685 .20787 L
.28733 .2156 L
.2878 .22316 L
.28829 .23134 L
.28876 .23933 L
.28922 .24711 L
.2897 .25548 L
.29017 .26361 L
.29067 .27232 L
.29114 .28077 L
.2916 .28893 L
.29209 .29764 L
.29256 .30603 L
.29302 .3141 L
.2935 .32268 L
Mistroke
.29396 .3309 L
.29446 .33961 L
.29493 .34793 L
.29539 .35586 L
.29588 .36422 L
.29635 .37216 L
.29684 .38048 L
.29732 .38837 L
.29778 .39581 L
.29827 .40357 L
.29875 .41087 L
.2992 .41772 L
.29969 .42482 L
.30015 .43144 L
.30065 .43824 L
.30112 .44456 L
.30158 .4504 L
.30207 .45635 L
.30254 .4618 L
.30304 .46729 L
.30352 .47228 L
.30399 .47678 L
.30448 .48125 L
.30495 .48523 L
.30541 .48874 L
.30589 .49212 L
.30636 .49504 L
.30686 .49777 L
.30734 .50003 L
.3078 .50186 L
.30829 .50343 L
.30853 .50406 L
.30876 .50455 L
.30898 .50495 L
.30921 .50527 L
.30933 .5054 L
.30945 .50551 L
.30957 .50559 L
.30968 .50565 L
.30974 .50567 L
.30977 .50568 L
.3098 .50569 L
.30983 .50569 L
.30985 .5057 L
.30987 .5057 L
.30988 .5057 L
.3099 .5057 L
.30991 .5057 L
.30992 .5057 L
.30994 .5057 L
Mistroke
.30995 .5057 L
.30996 .5057 L
.30998 .5057 L
.30999 .5057 L
.31 .5057 L
.31003 .50569 L
.31006 .50569 L
.31009 .50568 L
.31015 .50566 L
.31021 .50564 L
.31027 .50561 L
.31038 .50553 L
.3105 .50543 L
.31063 .50528 L
.31087 .50495 L
.31112 .5045 L
.31158 .50341 L
.31206 .50186 L
.31253 .49997 L
.31302 .49757 L
.3135 .49487 L
.31396 .49193 L
.31444 .48843 L
.31491 .48472 L
.31541 .48037 L
.31589 .47579 L
.31636 .47106 L
.31685 .46571 L
.31732 .46022 L
.31778 .45467 L
.31826 .44848 L
.31873 .44223 L
.31923 .43524 L
.31971 .42826 L
.32017 .42133 L
.32065 .41372 L
.32113 .4062 L
.32158 .39881 L
.32206 .39072 L
.32253 .38274 L
.32302 .37412 L
.3235 .36572 L
.32395 .35754 L
.32444 .34875 L
.32491 .34025 L
.32541 .33118 L
.32589 .32237 L
.32635 .31386 L
.32684 .30484 L
.32731 .29623 L
Mistroke
.32777 .288 L
.32825 .27933 L
.32872 .27107 L
.32921 .26242 L
.32969 .25425 L
.33015 .24658 L
.33064 .2386 L
.33111 .23112 L
.33161 .22342 L
.33209 .21626 L
.33255 .20964 L
.33305 .20288 L
.33352 .19669 L
.33398 .19106 L
.33446 .18542 L
.33493 .18034 L
.33543 .17532 L
.33591 .1709 L
.33637 .16702 L
.33686 .16332 L
.33733 .16018 L
.33778 .15757 L
.33827 .15525 L
.33873 .15345 L
.33897 .1527 L
.33923 .15201 L
.33947 .15148 L
.3397 .15111 L
.33981 .15096 L
.33994 .15083 L
.34 .15077 L
.34007 .15073 L
.34013 .15069 L
.34019 .15066 L
.34022 .15065 L
.34025 .15064 L
.34028 .15064 L
.34031 .15063 L
.34033 .15063 L
.34034 .15063 L
.34036 .15063 L
.34037 .15062 L
.34039 .15062 L
.3404 .15062 L
.34041 .15063 L
.34043 .15063 L
.34044 .15063 L
.34047 .15063 L
.34051 .15064 L
.34054 .15065 L
Mistroke
.3406 .15067 L
.34066 .1507 L
.34078 .15079 L
.3409 .1509 L
.34112 .15119 L
.34136 .15161 L
.34158 .15211 L
.34204 .1535 L
.34254 .15547 L
.34302 .15785 L
.34347 .16056 L
.34396 .16391 L
.34443 .16758 L
.34493 .17193 L
.34541 .17656 L
.34588 .18142 L
.34637 .18701 L
.34684 .19276 L
.3473 .19863 L
.34778 .20522 L
.34825 .21189 L
.34875 .21928 L
.34923 .2267 L
.34969 .23408 L
.35018 .24218 L
.35065 .25018 L
.3511 .25804 L
.35158 .26657 L
.35205 .27489 L
.35254 .28385 L
.35302 .29255 L
.35348 .30095 L
.35396 .30991 L
.35443 .31851 L
.35493 .32759 L
.35541 .33626 L
.35587 .3445 L
.35636 .35311 L
.35684 .36122 L
.35729 .36884 L
.35778 .37671 L
.35824 .38404 L
.35874 .39152 L
.35922 .39841 L
.35968 .4047 L
.36016 .41102 L
.36063 .41672 L
.36113 .42233 L
.36162 .42728 L
.36208 .43161 L
Mistroke
.36257 .4357 L
.36305 .43914 L
.3635 .44197 L
.36399 .44447 L
.36446 .44635 L
.3647 .4471 L
.36496 .44778 L
.36508 .44804 L
.36521 .44827 L
.36533 .44845 L
.36544 .44859 L
.36555 .4487 L
.36561 .44874 L
.36567 .44878 L
.3657 .44879 L
.36572 .4488 L
.36575 .44881 L
.36577 .44881 L
.36579 .44882 L
.36581 .44882 L
.36582 .44882 L
.36583 .44882 L
.36585 .44882 L
.36586 .44882 L
.36587 .44882 L
.36589 .44882 L
.3659 .44882 L
.36591 .44882 L
.36592 .44882 L
.36594 .44882 L
.36595 .44881 L
.36598 .44881 L
.36601 .4488 L
.36608 .44877 L
.36614 .44873 L
.36626 .44864 L
.36639 .4485 L
.36662 .44814 L
.36687 .4476 L
.36713 .4469 L
.36737 .44609 L
.36783 .44415 L
.36832 .44154 L
.3688 .43847 L
.36925 .43501 L
.36973 .43083 L
.3702 .42633 L
.3707 .42105 L
.37117 .41549 L
.37163 .40975 L
Mistroke
.37212 .40319 L
.37259 .39649 L
.37309 .389 L
.37357 .38144 L
.37403 .37389 L
.37453 .36559 L
.375 .35737 L
.37546 .34929 L
.37594 .34054 L
.37641 .332 L
.37691 .32285 L
.37739 .314 L
.37785 .30549 L
.37834 .29649 L
.37881 .28792 L
.37926 .27979 L
.37975 .27131 L
.38021 .26336 L
.3807 .25519 L
.38118 .24759 L
.38164 .24056 L
.38213 .23347 L
.3826 .22704 L
.38309 .2207 L
.38357 .21507 L
.38404 .21006 L
.38453 .20529 L
.385 .20127 L
.38546 .19794 L
.38594 .19501 L
.38641 .19273 L
.38665 .19178 L
.3869 .19094 L
.38715 .19031 L
.38738 .18988 L
.38751 .18971 L
.38757 .18964 L
.38763 .18959 L
.38768 .18955 L
.38774 .18951 L
.38779 .18949 L
.38782 .18948 L
.38785 .18947 L
.38787 .18947 L
.38788 .18947 L
.38788 .18947 L
.3879 .18947 L
.38791 .18947 L
.38792 .18947 L
.38793 .18947 L
Mistroke
.38794 .18947 L
.38795 .18947 L
.38796 .18947 L
.38798 .18947 L
.38799 .18947 L
.38801 .18948 L
.38804 .18949 L
.38807 .1895 L
.3881 .18951 L
.38815 .18955 L
.38821 .18959 L
.38832 .1897 L
.38843 .18985 L
.38856 .19005 L
.38878 .19051 L
.38903 .19119 L
.38927 .19201 L
.38973 .19404 L
.39022 .19683 L
.39069 .20014 L
.39115 .20385 L
.39163 .20838 L
.39209 .21328 L
.39259 .21902 L
.39306 .22506 L
.39352 .2313 L
.39401 .23837 L
.39448 .24556 L
.39498 .25356 L
.39546 .26159 L
.39592 .26956 L
.39641 .27825 L
.39688 .28678 L
.39734 .29508 L
.39782 .30398 L
.39829 .31255 L
.39878 .32162 L
.39926 .33025 L
.39972 .33841 L
.40021 .34688 L
.40068 .35479 L
.40118 .36286 L
.40166 .37026 L
.40212 .377 L
.40262 .3837 L
.40309 .38965 L
.40355 .39487 L
.40403 .39986 L
.4045 .40409 L
.405 .40789 L
Mistroke
.40548 .41088 L
.40594 .41313 L
.40618 .41404 L
.40643 .4148 L
.40654 .41507 L
.40666 .41532 L
.40678 .41551 L
.40688 .41566 L
.407 .41578 L
.40706 .41582 L
.40712 .41586 L
.40716 .41587 L
.40717 .41588 L
.40719 .41588 L
.40721 .41588 L
.40722 .41589 L
.40722 .41589 L
.40723 .41589 L
.40724 .41589 L
.40726 .41589 L
.40727 .41589 L
.40728 .41589 L
.4073 .41589 L
.40731 .41589 L
.40732 .41589 L
.40733 .41588 L
.40735 .41588 L
.40738 .41587 L
.4074 .41586 L
.40744 .41585 L
.40749 .41581 L
.40756 .41576 L
.40762 .41571 L
.40775 .41554 L
.40787 .41533 L
.40811 .41477 L
.40833 .41409 L
.4088 .41214 L
.40926 .40962 L
.40974 .40629 L
.41021 .40238 L
.4107 .39756 L
.41118 .39231 L
.41164 .38671 L
.41213 .38021 L
.4126 .3735 L
.4131 .36587 L
.41358 .35812 L
.41404 .35033 L
.41453 .34178 L
Mistroke
.41501 .33333 L
.41546 .32505 L
.41595 .31614 L
.41642 .30753 L
.41691 .29845 L
.41739 .2898 L
.41785 .28164 L
.41834 .27321 L
.41881 .26539 L
.41927 .25821 L
.41975 .25099 L
.42021 .2445 L
.42071 .23815 L
.42118 .23264 L
.42164 .22793 L
.42213 .2236 L
.4226 .22011 L
.4231 .21719 L
.42335 .21605 L
.42358 .21518 L
.4238 .21451 L
.42392 .21424 L
.42404 .21399 L
.42416 .2138 L
.42427 .21367 L
.42433 .21362 L
.42439 .21358 L
.42441 .21357 L
.42444 .21356 L
.42447 .21355 L
.42449 .21354 L
.42451 .21354 L
.42452 .21354 L
.42454 .21354 L
.42455 .21354 L
.42455 .21354 L
.42457 .21354 L
.42458 .21354 L
.42459 .21354 L
.4246 .21354 L
.42462 .21354 L
.42464 .21355 L
.42467 .21356 L
.42473 .21359 L
.42476 .21361 L
.42479 .21363 L
.42485 .21368 L
.42498 .21385 L
.42509 .21405 L
.42521 .21431 L
Mistroke
.42543 .21492 L
.42569 .21584 L
.42593 .21691 L
.4264 .21952 L
.42689 .22306 L
.42736 .22721 L
.42782 .23186 L
.4283 .23746 L
.42877 .24345 L
.42927 .25039 L
.42974 .2576 L
.4302 .26494 L
.43069 .27313 L
.43117 .28131 L
.43162 .28938 L
.4321 .29813 L
.43257 .30661 L
.43306 .31563 L
.43353 .32422 L
.43399 .33231 L
.43448 .34068 L
.43495 .34842 L
.43545 .35622 L
.43593 .36323 L
.43639 .36945 L
.43688 .37545 L
.43735 .38056 L
.43781 .3848 L
.43829 .38854 L
.43876 .39136 L
.43899 .3925 L
.43925 .3935 L
.43937 .39388 L
.4395 .39422 L
.43962 .39449 L
.43973 .39469 L
.43985 .39485 L
.43992 .39491 L
.43995 .39494 L
.43999 .39496 L
.44002 .39497 L
.44005 .39498 L
.44006 .39499 L
.44007 .39499 L
.44009 .39499 L
.4401 .39499 L
.44012 .395 L
.44013 .395 L
.44015 .39499 L
.44016 .39499 L
Mistroke
.44016 .39499 L
.44018 .39499 L
.44019 .39499 L
.44023 .39497 L
.44026 .39496 L
.44029 .39494 L
.44035 .39489 L
.44041 .39484 L
.44046 .39477 L
.44059 .39459 L
.44072 .39433 L
.44095 .39369 L
.44117 .39291 L
.44164 .39065 L
.44213 .38735 L
.44261 .38333 L
.44307 .37875 L
.44356 .37315 L
.44403 .36709 L
.44448 .3607 L
.44497 .35337 L
.44543 .34587 L
.44592 .33751 L
.4464 .32916 L
.44686 .32094 L
.44734 .31208 L
.44781 .30355 L
.44831 .29456 L
.44879 .2861 L
.44925 .27823 L
.44974 .27022 L
.45021 .26298 L
.45067 .25653 L
.45115 .25028 L
.45162 .24492 L
.45211 .24004 L
.45259 .23618 L
.45305 .23326 L
.45328 .23209 L
.45353 .23109 L
.45366 .2307 L
.45379 .23034 L
.45391 .23009 L
.45397 .22999 L
.45403 .22989 L
.4541 .2298 L
.45416 .22974 L
.45419 .22972 L
.45422 .2297 L
.45425 .22968 L
Mistroke
.45427 .22967 L
.4543 .22966 L
.45432 .22966 L
.45433 .22965 L
.45434 .22965 L
.45435 .22965 L
.45435 .22965 L
.45436 .22965 L
.45437 .22965 L
.45438 .22965 L
.45439 .22965 L
.4544 .22965 L
.45442 .22966 L
.45443 .22966 L
.45446 .22967 L
.45449 .22968 L
.45453 .2297 L
.45459 .22975 L
.45465 .22982 L
.45476 .22998 L
.45488 .2302 L
.45501 .23052 L
.45525 .23128 L
.4555 .23234 L
.456 .23521 L
.45648 .2389 L
.45694 .24327 L
.45744 .24874 L
.45791 .25476 L
.45837 .26116 L
.45885 .26856 L
.45932 .27615 L
.45982 .28463 L
.4603 .29309 L
.46076 .3014 L
.46125 .31029 L
.46172 .31881 L
.46218 .32684 L
.46266 .33512 L
.46312 .34271 L
.46362 .35029 L
.4641 .35696 L
.46455 .36275 L
.46504 .36815 L
.46551 .37248 L
.46601 .37614 L
.46626 .3776 L
.46649 .3787 L
.46671 .37952 L
.46683 .37986 L
Mistroke
.46695 .38016 L
.46708 .38039 L
.46719 .38054 L
.46724 .3806 L
.46727 .38062 L
.4673 .38064 L
.46733 .38066 L
.46734 .38066 L
.46736 .38067 L
.46737 .38067 L
.46738 .38068 L
.4674 .38068 L
.46741 .38068 L
.46742 .38068 L
.46743 .38068 L
.46744 .38068 L
.46745 .38068 L
.46747 .38068 L
.46748 .38068 L
.46749 .38067 L
.46752 .38066 L
.46755 .38065 L
.46758 .38063 L
.46765 .38058 L
.4677 .38051 L
.46776 .38043 L
.46787 .38025 L
.4681 .37966 L
.46823 .37923 L
.46835 .37877 L
.46884 .37627 L
.4693 .37292 L
.46979 .36841 L
.47027 .36319 L
.47072 .35743 L
.47121 .35058 L
.47167 .3434 L
.47217 .33524 L
.47265 .32698 L
.47311 .31879 L
.4736 .30994 L
.47407 .30142 L
.47453 .29335 L
.47501 .28502 L
.47547 .27735 L
.47597 .26976 L
.47644 .26308 L
.4769 .25734 L
.47739 .25207 L
.47786 .2479 L
Mistroke
.4781 .24613 L
.47836 .24451 L
.47859 .24334 L
.47884 .24233 L
.47895 .24196 L
.47908 .24165 L
.47914 .2415 L
.47921 .24139 L
.47927 .2413 L
.47933 .24123 L
.47936 .24119 L
.47939 .24117 L
.47942 .24115 L
.47945 .24113 L
.47947 .24112 L
.47949 .24112 L
.4795 .24112 L
.47951 .24111 L
.47953 .24111 L
.47954 .24111 L
.47956 .24111 L
.47957 .24111 L
.47958 .24111 L
.47959 .24112 L
.4796 .24112 L
.47962 .24112 L
.47965 .24114 L
.47969 .24116 L
.47975 .24121 L
.47981 .24128 L
.47992 .24146 L
.48003 .24169 L
.48028 .24243 L
.48053 .24345 L
.48075 .24463 L
.48123 .24794 L
.4817 .25207 L
.48219 .25745 L
.48266 .26348 L
.48312 .26996 L
.4836 .2775 L
.48407 .28525 L
.48457 .29387 L
.48505 .30241 L
.48551 .3107 L
.486 .31943 L
.48647 .32762 L
.48692 .33514 L
.4874 .34263 L
.48787 .34923 L
Mistroke
.48836 .35542 L
.48884 .36049 L
.48929 .36446 L
.48955 .36625 L
.48978 .36759 L
.49002 .36873 L
.49025 .36951 L
.49036 .3698 L
.49048 .37005 L
.49054 .37014 L
.4906 .37022 L
.49063 .37025 L
.49067 .37028 L
.4907 .37031 L
.49073 .37032 L
.49074 .37033 L
.49076 .37033 L
.49077 .37034 L
.49079 .37034 L
.4908 .37034 L
.49082 .37034 L
.49082 .37034 L
.49083 .37034 L
.49085 .37034 L
.49086 .37034 L
.49088 .37033 L
.49091 .37032 L
.49093 .37031 L
.49096 .37029 L
.49101 .37024 L
.49108 .37016 L
.49121 .36994 L
.49133 .36965 L
.49144 .36932 L
.49169 .36835 L
.49192 .3672 L
.49217 .36564 L
.49265 .36173 L
.49312 .35695 L
.49362 .35089 L
.4941 .34419 L
.49456 .33709 L
.49506 .32897 L
.49553 .32074 L
.49599 .31263 L
.49647 .30393 L
.49694 .29564 L
.49743 .28714 L
.49791 .27942 L
.49837 .27257 L
Mistroke
.49886 .26602 L
.49933 .26065 L
.49978 .25639 L
.50003 .25444 L
.50027 .25293 L
.50051 .25165 L
.50073 .25074 L
.50084 .2504 L
.50096 .2501 L
.50102 .24996 L
.50109 .24986 L
.50114 .24978 L
.50117 .24975 L
.50121 .24972 L
.50124 .24969 L
.50127 .24967 L
.50128 .24967 L
.50129 .24966 L
.50131 .24965 L
.50132 .24965 L
.50133 .24965 L
.50134 .24965 L
.50135 .24965 L
.50136 .24965 L
.50137 .24965 L
.50139 .24965 L
.5014 .24965 L
.50141 .24965 L
.50143 .24966 L
.50144 .24966 L
.50147 .24968 L
.5015 .2497 L
.50156 .24975 L
.50162 .24982 L
.50167 .2499 L
.50178 .25012 L
.50189 .2504 L
.50214 .25128 L
.50238 .25246 L
.5026 .25382 L
.50308 .25758 L
.50354 .26221 L
.50402 .26813 L
.50449 .27469 L
.50499 .28242 L
.50547 .29043 L
.50593 .29849 L
.50642 .30726 L
.5069 .31568 L
.50735 .3236 L
Mistroke
.50784 .33163 L
.5083 .3388 L
.5088 .34564 L
.50928 .3513 L
.50974 .35576 L
.50999 .3578 L
.51022 .35934 L
.51047 .36064 L
.5107 .36154 L
.51081 .36188 L
.51093 .36216 L
.51098 .36227 L
.51105 .36236 L
.51108 .36241 L
.51111 .36244 L
.51114 .36247 L
.51118 .36249 L
.51119 .3625 L
.51121 .3625 L
.51122 .36251 L
.51124 .36251 L
.51124 .36252 L
.51125 .36252 L
.51127 .36252 L
.51128 .36252 L
.5113 .36252 L
.51131 .36252 L
.51133 .36251 L
.51134 .36251 L
.51135 .3625 L
.51138 .36249 L
.51141 .36247 L
.51147 .36242 L
.51153 .36235 L
.51159 .36224 L
.51166 .36211 L
.51178 .36179 L
.51191 .36135 L
.51215 .36029 L
.51239 .35893 L
.51264 .35715 L
.5131 .35312 L
.51358 .34773 L
.51404 .3416 L
.51454 .33421 L
.51501 .32647 L
.51547 .31859 L
.51595 .30993 L
.51642 .30162 L
.51692 .29296 L
Mistroke
.5174 .28499 L
.51786 .27799 L
.51835 .27134 L
.51883 .26585 L
.51928 .26172 L
.51953 .25988 L
.51977 .25852 L
.52 .25741 L
.52012 .25697 L
.52023 .25666 L
.52029 .25653 L
.52035 .25642 L
.52041 .25634 L
.52044 .2563 L
.52047 .25628 L
.5205 .25626 L
.52053 .25624 L
.52054 .25623 L
.52056 .25623 L
.52057 .25622 L
.52058 .25622 L
.5206 .25622 L
.52061 .25622 L
.52062 .25622 L
.52064 .25622 L
.52065 .25622 L
.52066 .25622 L
.52068 .25622 L
.52069 .25623 L
.52072 .25624 L
.52075 .25626 L
.52081 .25632 L
.52086 .25639 L
.52092 .25647 L
.52104 .25672 L
.52117 .2571 L
.52141 .25804 L
.52166 .25941 L
.52211 .26284 L
.5226 .26769 L
.52306 .27342 L
.52356 .28051 L
.52404 .28809 L
.5245 .29589 L
.52499 .30449 L
.52546 .31285 L
.52591 .32071 L
.52639 .32869 L
.52686 .33577 L
.52735 .3424 L
Mistroke
.52782 .34776 L
.52828 .35178 L
.52852 .35337 L
.52877 .35472 L
.52889 .35523 L
.52902 .35568 L
.52915 .35601 L
.52921 .35613 L
.52927 .35622 L
.52932 .35629 L
.52935 .35632 L
.52938 .35634 L
.52939 .35635 L
.52941 .35636 L
.52942 .35637 L
.52943 .35637 L
.52945 .35637 L
.52946 .35638 L
.52948 .35638 L
.52949 .35638 L
.5295 .35638 L
.52952 .35637 L
.52953 .35637 L
.52955 .35636 L
.52958 .35635 L
.52961 .35632 L
.52967 .35626 L
.52974 .35616 L
.52985 .35593 L
.52998 .35559 L
.53011 .35512 L
.53023 .35459 L
.53069 .35172 L
.53093 .34972 L
.53119 .34728 L
.53164 .34201 L
.53213 .33535 L
.5326 .32813 L
.5331 .31983 L
.53358 .31141 L
.53404 .3032 L
.53453 .29468 L
.535 .28698 L
.53546 .28009 L
.53594 .27372 L
.53641 .26871 L
.53665 .26661 L
.5369 .26473 L
.53715 .2633 L
.53738 .26233 L
Mistroke
.53751 .26195 L
.53757 .2618 L
.53763 .26169 L
.53768 .26161 L
.53774 .26154 L
.53777 .26151 L
.53779 .26149 L
.53782 .26147 L
.53784 .26146 L
.53785 .26146 L
.53787 .26146 L
.53788 .26145 L
.53789 .26145 L
.53791 .26145 L
.53793 .26146 L
.53793 .26146 L
.53794 .26146 L
.53796 .26147 L
.53797 .26147 L
.538 .26149 L
.53803 .26151 L
.53808 .26157 L
.53814 .26166 L
.53821 .26179 L
.53833 .2621 L
.53845 .26248 L
.53857 .263 L
.53882 .26435 L
.53906 .26597 L
.53931 .26809 L
.5398 .27332 L
.54028 .27955 L
.54074 .28643 L
.54123 .29446 L
.5417 .30263 L
.54216 .31062 L
.54264 .319 L
.5431 .32664 L
.5436 .33404 L
.54407 .34021 L
.54453 .345 L
.54478 .34715 L
.54501 .34876 L
.54526 .35002 L
.54536 .35046 L
.54548 .35086 L
.5456 .35116 L
.54566 .35128 L
.54569 .35134 L
.54572 .35138 L
Mistroke
.54575 .35142 L
.54578 .35145 L
.5458 .35146 L
.54581 .35147 L
.54583 .35148 L
.54584 .35148 L
.54585 .35149 L
.54587 .35149 L
.54588 .35149 L
.54589 .35149 L
.54591 .35149 L
.54592 .35148 L
.54593 .35148 L
.54594 .35147 L
.54598 .35145 L
.54601 .35143 L
.54607 .35136 L
.54613 .35127 L
.5462 .35114 L
.54632 .35082 L
.54644 .35043 L
.54668 .34931 L
.54691 .3479 L
.54738 .34389 L
.54784 .3387 L
.54833 .3321 L
.5488 .32478 L
.54929 .3164 L
.54978 .30799 L
.55024 .2999 L
.55073 .29164 L
.5512 .28437 L
.55166 .27811 L
.55214 .27282 L
.55261 .26898 L
.55286 .26747 L
.55298 .26688 L
.5531 .26643 L
.55317 .26624 L
.5532 .26617 L
.55323 .26611 L
.55328 .26604 L
.55331 .26601 L
.55334 .26599 L
.55346 .26588 L
.55351 .26582 L
.55354 .2658 L
.55355 .26579 L
.55356 .26578 L
.55358 .26577 L
Mistroke
.55359 .26577 L
.55359 .26577 L
.55361 .26577 L
.55362 .26577 L
.55364 .26578 L
.55365 .26579 L
.55366 .2658 L
.55368 .26581 L
.55374 .26588 L
.5538 .26599 L
.55386 .26612 L
.55392 .26628 L
.55402 .26668 L
.55424 .2676 L
.55448 .26901 L
.55472 .27084 L
.55498 .27317 L
.55546 .27873 L
.55593 .28521 L
.55642 .29305 L
.5569 .30119 L
.55736 .30926 L
.55785 .31773 L
.55832 .32544 L
.55878 .33214 L
.55926 .3382 L
.55972 .34274 L
.55996 .34454 L
.56009 .34529 L
.56022 .34598 L
.56034 .34651 L
.56045 .3469 L
.56051 .34705 L
.56057 .34719 L
.56062 .34729 L
.56067 .34738 L
.5607 .34741 L
.56073 .34744 L
.56076 .34746 L
.56079 .34748 L
.5608 .34748 L
.56081 .34748 L
.56082 .34749 L
.56083 .34749 L
.56085 .34749 L
.56086 .34749 L
.56086 .34749 L
.56088 .34748 L
.56089 .34748 L
.56089 .34748 L
Mistroke
.56091 .34747 L
.56093 .34746 L
.56095 .34745 L
.56098 .34742 L
.56103 .34735 L
.5611 .34723 L
.56117 .3471 L
.56128 .34676 L
.56139 .34635 L
.56164 .3451 L
.56188 .34342 L
.5621 .34153 L
.56258 .33642 L
.56304 .3303 L
.56352 .32279 L
.56399 .31483 L
.56449 .30617 L
.56497 .29786 L
.56543 .29032 L
.56593 .28314 L
.5664 .27738 L
.56686 .27316 L
.56709 .27157 L
.56734 .27031 L
.56746 .26987 L
.56753 .26969 L
.56759 .26953 L
.56765 .26943 L
.56769 .26938 L
.56772 .26934 L
.56775 .26932 L
.56776 .26931 L
.56778 .2693 L
.56779 .26929 L
.56781 .26928 L
.56782 .26928 L
.56784 .26928 L
.56785 .26928 L
.56786 .26928 L
.56787 .26928 L
.56788 .26928 L
.56789 .26929 L
.5679 .26929 L
.56791 .26929 L
.56793 .2693 L
.56796 .26933 L
.56799 .26936 L
.56803 .26941 L
.56809 .26951 L
.56816 .26965 L
Mistroke
.56822 .26982 L
.56833 .27021 L
.56857 .27137 L
.5688 .27282 L
.56927 .27712 L
.56973 .28259 L
.57021 .28963 L
.57068 .29723 L
.57118 .3058 L
.57165 .31413 L
.57212 .3218 L
.5726 .3292 L
.57308 .33522 L
.57353 .3397 L
.57376 .34144 L
.57388 .34217 L
.57401 .34284 L
.57413 .34332 L
.57425 .34371 L
.57432 .34387 L
.57438 .34399 L
.57441 .34403 L
.57445 .34407 L
.57448 .3441 L
.57451 .34412 L
.57452 .34412 L
.57454 .34413 L
.57455 .34413 L
.57456 .34413 L
.57458 .34413 L
.57459 .34413 L
.57459 .34413 L
.57461 .34413 L
.57462 .34412 L
.57464 .34412 L
.57465 .34411 L
.57468 .34409 L
.5747 .34407 L
.57473 .34404 L
.57476 .34399 L
.57479 .34394 L
.57486 .34379 L
.57498 .34345 L
.5751 .34299 L
.57521 .34246 L
.57546 .34092 L
.57568 .33911 L
.57593 .3367 L
.57641 .33088 L
.57688 .32407 L
Mistroke
.57737 .31596 L
.57785 .30771 L
.57831 .29974 L
.5788 .29179 L
.57927 .28497 L
.57977 .27904 L
.58002 .27669 L
.58025 .27494 L
.58047 .27365 L
.58058 .27315 L
.58065 .27291 L
.58071 .27272 L
.58077 .27257 L
.58083 .27244 L
.58086 .27239 L
.58089 .27235 L
.58092 .27232 L
.58094 .27229 L
.58097 .27227 L
.58099 .27226 L
.581 .27226 L
.581 .27226 L
.58102 .27225 L
.58103 .27225 L
.58105 .27225 L
.58106 .27225 L
.58107 .27226 L
.58108 .27226 L
.58109 .27226 L
.58111 .27227 L
.58113 .27229 L
.58116 .27231 L
.58119 .27235 L
.58125 .27244 L
.58132 .27258 L
.58144 .27292 L
.58155 .27337 L
.58166 .27389 L
.58191 .27543 L
.58213 .27724 L
.58261 .28237 L
.58307 .28867 L
.58357 .29643 L
.58404 .30452 L
.5845 .31244 L
.58498 .32054 L
.58545 .32758 L
.58595 .33379 L
.5862 .33628 L
.58643 .33816 L
Mistroke
.58665 .33959 L
.58676 .34015 L
.58689 .34064 L
.58695 .34083 L
.58701 .34099 L
.58706 .3411 L
.58712 .34119 L
.58715 .34123 L
.58718 .34126 L
.5872 .34127 L
.58722 .34128 L
.58722 .34128 L
.58723 .34129 L
.58725 .34129 L
.58726 .34129 L
.58728 .34129 L
.58729 .34129 L
.58731 .34129 L
.58732 .34128 L
.58734 .34127 L
.58735 .34126 L
.58737 .34125 L
.58743 .34118 L
.58747 .34112 L
.5875 .34106 L
.58755 .34094 L
.58762 .34076 L
.58773 .34037 L
.58784 .33985 L
.58808 .33844 L
.58833 .33642 L
.58882 .33105 L
.5893 .32441 L
.58976 .31707 L
.59026 .30864 L
.59073 .3005 L
.59118 .29301 L
.59167 .28608 L
.59213 .2807 L
.59238 .27842 L
.59263 .27675 L
.59274 .27612 L
.59286 .27559 L
.59292 .27538 L
.59298 .27521 L
.59303 .27507 L
.59308 .27497 L
.59314 .27488 L
.59317 .27485 L
.5932 .27482 L
Mistroke
.59322 .27481 L
.59323 .2748 L
.59324 .2748 L
.59325 .27479 L
.59327 .27479 L
.59328 .27479 L
.59329 .27479 L
.59331 .27479 L
.59332 .27479 L
.59333 .27479 L
.59334 .2748 L
.59335 .27481 L
.59338 .27482 L
.59341 .27485 L
.59343 .27489 L
.59349 .27499 L
.59355 .27511 L
.59366 .27546 L
.59379 .27597 L
.59401 .2772 L
.59424 .27898 L
.59446 .28104 L
.59493 .28658 L
.59543 .29386 L
.5959 .30176 L
.59636 .3097 L
.59685 .31795 L
.59732 .32517 L
.59782 .33155 L
.59807 .33409 L
.5983 .33598 L
.59853 .33739 L
.59864 .33792 L
.59871 .33817 L
.59877 .33837 L
.59882 .33853 L
.59889 .33867 L
.59892 .33872 L
.59895 .33877 L
.59897 .3388 L
.599 .33883 L
.59901 .33884 L
.59903 .33885 L
.59905 .33885 L
.59905 .33886 L
.59906 .33886 L
.59908 .33886 L
.59909 .33886 L
.59911 .33886 L
.59912 .33885 L
Mistroke
.59913 .33885 L
.59914 .33885 L
.59915 .33884 L
.59918 .33881 L
.59922 .33878 L
.59925 .33873 L
.59931 .33862 L
.59938 .33846 L
.5995 .33806 L
.59961 .33755 L
.59972 .33697 L
.59994 .33542 L
.60019 .33322 L
.60067 .32758 L
.60114 .32081 L
.60163 .31267 L
.6021 .30447 L
.60256 .29679 L
.60305 .28939 L
.60352 .28361 L
.60376 .28124 L
.60388 .28018 L
.60401 .27925 L
.60413 .27855 L
.60426 .27791 L
.60438 .27747 L
.60449 .27718 L
.60455 .27706 L
.60459 .27701 L
.6046 .27699 L
.60462 .27697 L
.60463 .27696 L
.60465 .27695 L
.60466 .27694 L
.60468 .27694 L
.60469 .27694 L
.60471 .27694 L
.60471 .27694 L
.60472 .27694 L
.60474 .27695 L
.60475 .27696 L
.60477 .27697 L
.6048 .277 L
.60485 .27708 L
.6049 .27718 L
.60496 .2773 L
.60507 .27765 L
.60519 .27816 L
.60541 .27942 L
.60565 .28133 L
Mistroke
.60591 .28387 L
.60636 .28962 L
.60685 .29708 L
.60732 .30499 L
.60782 .31354 L
.6083 .32128 L
.60876 .3277 L
.609 .33041 L
.60925 .33293 L
.6095 .3347 L
.60973 .33599 L
.60979 .33633 L
.60982 .33649 L
.60984 .33656 L
.60985 .33661 L
.60987 .33666 L
.60988 .33668 L
.60988 .33669 L
.6099 .33672 L
.60991 .33673 L
.60993 .33674 L
.60994 .33674 L
.60995 .33674 L
.60997 .33673 L
.61 .33672 L
.61001 .33671 L
.61002 .33671 L
.61003 .33671 L
.61004 .3367 L
.61006 .3367 L
.61007 .3367 L
.61009 .3367 L
.6101 .33671 L
.61012 .33671 L
.61013 .33671 L
.61014 .33671 L
.61015 .33671 L
.61017 .3367 L
.61018 .3367 L
.61019 .33669 L
.61022 .33667 L
.61025 .33664 L
.61028 .33661 L
.6103 .33659 L
.61031 .33658 L
.61032 .33657 L
.61033 .33657 L
.61034 .33657 L
.61035 .33656 L
.61037 .33656 L
Mistroke
.61038 .33656 L
.61039 .33656 L
.61039 .33656 L
.6104 .33655 L
.61042 .33654 L
.61043 .33653 L
.61043 .33651 L
.61045 .33648 L
.61046 .33643 L
.61049 .33631 L
.61054 .33601 L
.61066 .33533 L
.61089 .33393 L
.61102 .33291 L
.61115 .33165 L
.61162 .32618 L
.61209 .31938 L
.61258 .31118 L
.61306 .30298 L
.61352 .29543 L
.61401 .28841 L
.61448 .28318 L
.61473 .28112 L
.61485 .28037 L
.61498 .27975 L
.61509 .27931 L
.61516 .27912 L
.61522 .27897 L
.61525 .27892 L
.61527 .27887 L
.6153 .27884 L
.61532 .27881 L
.61534 .2788 L
.61535 .27879 L
.61537 .27878 L
.61538 .27878 L
.61539 .27878 L
.61541 .27878 L
.61542 .27879 L
.61543 .27879 L
.61544 .27879 L
.61547 .27881 L
.61549 .27882 L
.6155 .27884 L
.61553 .27887 L
.61556 .27892 L
.61562 .27902 L
.61567 .27916 L
.61574 .27934 L
.6158 .2796 L
Mistroke
.61593 .28019 L
.61618 .28184 L
.61642 .28402 L
.61688 .28943 L
.61737 .29671 L
.61784 .30457 L
.61829 .31233 L
.61878 .32012 L
.61924 .32652 L
.61948 .3292 L
.61973 .33158 L
.61985 .3325 L
.61998 .33325 L
.6201 .33385 L
.62021 .33433 L
.62024 .33445 L
.62027 .33455 L
.62028 .33459 L
.6203 .33462 L
.62031 .33464 L
.62033 .33466 L
.62035 .33468 L
.62036 .33469 L
.6204 .33471 L
.62043 .33474 L
.62045 .33475 L
.62046 .33476 L
.62048 .33477 L
.62049 .33477 L
.62051 .33477 L
.62052 .33477 L
.62053 .33477 L
.62054 .33477 L
.62055 .33477 L
.62058 .33476 L
.62064 .33474 L
.62066 .33473 L
.62067 .33473 L
.62068 .33472 L
.62069 .33472 L
.6207 .33471 L
.62071 .3347 L
.62072 .33467 L
.62074 .33464 L
.62076 .33455 L
.62083 .33429 L
.62094 .33383 L
.62106 .33319 L
.62112 .3329 L
.62118 .33252 L
Mistroke
.62124 .33204 L
.62131 .33148 L
.62144 .33029 L
.62168 .32784 L
.62217 .32139 L
.62263 .31398 L
.62313 .30549 L
.62361 .29751 L
.62407 .29068 L
.62432 .28745 L
.62455 .28498 L
.6248 .28294 L
.62491 .2822 L
.62502 .28153 L
.62514 .28103 L
.6252 .28083 L
.62527 .28065 L
.6253 .28058 L
.62533 .28052 L
.62535 .28048 L
.62538 .28045 L
.62541 .28043 L
.62542 .28042 L
.62543 .28041 L
.62545 .2804 L
.62546 .2804 L
.62548 .2804 L
.62549 .2804 L
.6255 .2804 L
.62552 .28041 L
.62553 .28041 L
.62555 .28042 L
.62558 .28045 L
.62561 .28048 L
.62566 .28056 L
.62569 .28062 L
.62572 .28069 L
.62584 .28113 L
.62596 .28168 L
.62621 .28327 L
.62643 .28522 L
.62691 .2909 L
.62737 .2978 L
.62786 .306 L
.62833 .314 L
.62878 .32107 L
.62903 .32448 L
.62926 .32721 L
.62951 .32955 L
.62973 .33126 L
Mistroke
.62984 .3319 L
.62996 .33239 L
.63009 .33281 L
.63014 .33296 L
.63017 .33304 L
.6302 .33312 L
.63022 .33315 L
.63023 .33317 L
.63025 .33318 L
.63026 .33319 L
.63028 .33318 L
.63029 .33317 L
.63031 .33316 L
.63032 .33313 L
.63043 .33298 L
.6305 .33285 L
.63057 .3327 L
.63062 .33258 L
.63065 .33252 L
.63067 .33248 L
.63068 .33243 L
.63072 .33229 L
.63074 .33212 L
.6308 .33173 L
.63093 .33091 L
.63103 .33015 L
.63109 .32975 L
.63115 .32932 L
.6312 .32875 L
.63126 .32805 L
.63139 .3267 L
.63161 .32417 L
.6321 .3168 L
.63258 .30885 L
.63304 .30107 L
.63352 .29346 L
.63399 .28748 L
.63425 .28501 L
.63437 .28411 L
.63449 .28331 L
.63461 .2827 L
.63467 .28245 L
.63473 .28223 L
.63479 .28207 L
.63485 .28195 L
.63487 .28191 L
.6349 .28187 L
.63493 .28184 L
.63495 .28182 L
.63497 .28181 L
Mistroke
.63498 .2818 L
.635 .2818 L
.63501 .2818 L
.63502 .2818 L
.63503 .2818 L
.63505 .28181 L
.63505 .28182 L
.63506 .28182 L
.63508 .28184 L
.63514 .28192 L
.63519 .28203 L
.63525 .28217 L
.63531 .28238 L
.63544 .28293 L
.63556 .28364 L
.63567 .28442 L
.63593 .28664 L
.6364 .29242 L
.63686 .29942 L
.63735 .30766 L
.63782 .3155 L
.63832 .32284 L
.63857 .32584 L
.6388 .32811 L
.63902 .32982 L
.63914 .33045 L
.6392 .33075 L
.63926 .33102 L
.63932 .33125 L
.63934 .33131 L
.63935 .33135 L
.63937 .33138 L
.63938 .33141 L
.63941 .33144 L
.63944 .33147 L
.63949 .33152 L
.63951 .33153 L
.63953 .33154 L
.63953 .33154 L
.63954 .33154 L
.63955 .33155 L
.63956 .33155 L
.63957 .33155 L
.63958 .33155 L
.63959 .33155 L
.6396 .33154 L
.63961 .33154 L
.63963 .33153 L
.63968 .33151 L
.63969 .33151 L
Mistroke
.6397 .33151 L
.63972 .33151 L
.63973 .3315 L
.63975 .33149 L
.63976 .33147 L
.63978 .33144 L
.63979 .3314 L
.63981 .33134 L
.63987 .33106 L
.64 .33044 L
.64013 .32978 L
.64016 .32964 L
.64019 .32947 L
.64024 .32906 L
.6403 .32848 L
.64036 .32787 L
.64048 .32678 L
.64073 .32401 L
.64118 .31756 L
.64166 .30965 L
.64213 .30179 L
.64262 .29401 L
.64287 .2907 L
.6431 .28806 L
.64332 .28599 L
.64344 .28507 L
.64356 .28435 L
.64368 .28377 L
.64375 .28353 L
.64381 .28333 L
.64384 .28325 L
.64387 .28319 L
.64389 .28316 L
.6439 .28313 L
.64392 .28312 L
.64393 .2831 L
.64395 .28309 L
.64395 .28308 L
.64396 .28308 L
.64398 .28307 L
.64399 .28307 L
.644 .28307 L
.64401 .28307 L
.64402 .28307 L
.64403 .28307 L
.64404 .28307 L
.64405 .28307 L
.64406 .28308 L
.64407 .28308 L
.64408 .28309 L
Mistroke
.64411 .28312 L
.64414 .28316 L
.64418 .28321 L
.64421 .28327 L
.64423 .28333 L
.64429 .28348 L
.64435 .28371 L
.64441 .28397 L
.64454 .28467 L
.64478 .28653 L
.64501 .28873 L
.64549 .29505 L
.64595 .30243 L
.64644 .31079 L
.64692 .31836 L
.64737 .32438 L
.64761 .32673 L
.64786 .32862 L
.64798 .32933 L
.64801 .3295 L
.64805 .32965 L
.64808 .32975 L
.64811 .32983 L
.64817 .32996 L
.64821 .33002 L
.64824 .33008 L
.64827 .33012 L
.6483 .33015 L
.64836 .3302 L
.64839 .33024 L
.6484 .33026 L
.64841 .33027 L
.64842 .33028 L
.64843 .33028 L
.64844 .33028 L
.64845 .33027 L
.64846 .33025 L
.64848 .33022 L
.64849 .33018 L
.64851 .33014 L
.64854 .33003 L
.64859 .32984 L
.64872 .32936 L
.64878 .32911 L
.64881 .32902 L
.64884 .3289 L
.64887 .32873 L
.6489 .32853 L
.64896 .32799 L
.64909 .32691 L
Mistroke
.64931 .32486 L
.64956 .32174 L
.64978 .31861 L
.65026 .31098 L
.65072 .30318 L
.65121 .29535 L
.65146 .29199 L
.65168 .28927 L
.6519 .28718 L
.65202 .28621 L
.65214 .2855 L
.65226 .2849 L
.65233 .28462 L
.65236 .28451 L
.65239 .28442 L
.65242 .28435 L
.65245 .2843 L
.65248 .28426 L
.65251 .28423 L
.65252 .28421 L
.65254 .2842 L
.65255 .28419 L
.65256 .28419 L
.65257 .28418 L
.65258 .28418 L
.65258 .28418 L
.6526 .28418 L
.65261 .28418 L
.65262 .28418 L
.65263 .28418 L
.65265 .28418 L
.65266 .28419 L
.65268 .2842 L
.65269 .28421 L
.6527 .28422 L
.65272 .28424 L
.65274 .28427 L
.65275 .2843 L
.65287 .28467 L
.65298 .28512 L
.6531 .28574 L
.65333 .28754 L
.65355 .28977 L
.65402 .29592 L
.65451 .3039 L
.65499 .31196 L
.65545 .31908 L
.6557 .32244 L
.65594 .32495 L
.65605 .32605 L
Mistroke
.65618 .32698 L
.6563 .32772 L
.65635 .32806 L
.65641 .32829 L
.65646 .32846 L
.65652 .32864 L
.65659 .32879 L
.65665 .3289 L
.65666 .32893 L
.65668 .32895 L
.65669 .32896 L
.6567 .32897 L
.65671 .32897 L
.65672 .32897 L
.65673 .32896 L
.65674 .32896 L
.65674 .32895 L
.65678 .32891 L
.65681 .32888 L
.65684 .32883 L
.65687 .32879 L
.6569 .32873 L
.65696 .32859 L
.65699 .32851 L
.65703 .32839 L
.65706 .32825 L
.65709 .32809 L
.65715 .32779 L
.65737 .32633 L
.65749 .32525 L
.6576 .32417 L
.65785 .32121 L
.65832 .31438 L
.65882 .30597 L
.6593 .29806 L
.65976 .29158 L
.66 .28897 L
.66013 .28788 L
.66026 .28691 L
.66038 .28618 L
.66049 .28568 L
.66055 .2855 L
.66058 .28542 L
.66061 .28536 L
.66066 .28527 L
.66068 .28524 L
.6607 .28522 L
.66071 .28521 L
.66073 .2852 L
.66074 .2852 L
Mistroke
.66075 .28519 L
.66076 .28519 L
.66078 .28519 L
.66079 .28519 L
.6608 .28519 L
.66082 .2852 L
.66084 .2852 L
.66085 .28521 L
.66086 .28523 L
.66089 .28527 L
.66095 .2854 L
.66101 .2856 L
.66108 .28583 L
.6612 .28639 L
.66131 .28716 L
.66144 .28811 L
.66166 .29028 L
.66211 .29618 L
.66259 .30392 L
.66306 .31175 L
.66355 .31927 L
.6638 .32236 L
.66403 .32472 L
.66425 .32635 L
.66431 .32676 L
.66434 .32695 L
.66437 .32709 L
.6644 .32719 L
.66443 .32727 L
.66448 .32745 L
.6646 .32772 L
.66463 .32779 L
.66465 .32782 L
.66466 .32785 L
.66468 .32787 L
.66469 .32789 L
.6647 .32789 L
.66471 .32789 L
.66472 .32788 L
.66473 .32786 L
.66475 .32784 L
.66478 .32779 L
.66483 .32771 L
.66494 .32745 L
.66497 .32738 L
.66499 .32734 L
.665 .3273 L
.66502 .32725 L
.66503 .32718 L
.66506 .32704 L
Mistroke
.66517 .32635 L
.66543 .32444 L
.66566 .32201 L
.66591 .31872 L
.6664 .31111 L
.66688 .30301 L
.66734 .29583 L
.66759 .2924 L
.66783 .28985 L
.66794 .28879 L
.66807 .28783 L
.66819 .28712 L
.66824 .28683 L
.6683 .2866 L
.66835 .28641 L
.66841 .28627 L
.66844 .28621 L
.66847 .28616 L
.6685 .28613 L
.66852 .2861 L
.66854 .28609 L
.66855 .28608 L
.66857 .28607 L
.66857 .28607 L
.66858 .28607 L
.66859 .28607 L
.6686 .28607 L
.66861 .28609 L
.66862 .28609 L
.66863 .2861 L
.66865 .28613 L
.66871 .28622 L
.66874 .28628 L
.66877 .28636 L
.66882 .28652 L
.66888 .28675 L
.66899 .28732 L
.66924 .28914 L
.6695 .29176 L
.66974 .29485 L
.6702 .30191 L
.67068 .31012 L
.67115 .31748 L
.67139 .32067 L
.67165 .32347 L
.67178 .32448 L
.6719 .32541 L
.67201 .32598 L
.67213 .32644 L
.67216 .32655 L
Mistroke
.6722 .32666 L
.67221 .3267 L
.67223 .32674 L
.67224 .32677 L
.67226 .32679 L
.67227 .3268 L
.67228 .3268 L
.6723 .32679 L
.67231 .32678 L
.67237 .32675 L
.6724 .32673 L
.67242 .32672 L
.67243 .3267 L
.67249 .32661 L
.67255 .32653 L
.67257 .32652 L
.67258 .32651 L
.67258 .32649 L
.67259 .32647 L
.6726 .32645 L
.67262 .32638 L
.67263 .32631 L
.67265 .32622 L
.67268 .32604 L
.67274 .32565 L
.67285 .32496 L
.6731 .32282 L
.67336 .3199 L
.6736 .31653 L
.67406 .3091 L
.67456 .30086 L
.67503 .29385 L
.67527 .29106 L
.67549 .28908 L
.67561 .28824 L
.67566 .2879 L
.67572 .28761 L
.67579 .28737 L
.67584 .28718 L
.67591 .28703 L
.67594 .28696 L
.67596 .28693 L
.67597 .28691 L
.67598 .2869 L
.67598 .28689 L
.67599 .28688 L
.67601 .28687 L
.67602 .28687 L
.67604 .28687 L
.67605 .28688 L
Mistroke
.67607 .28689 L
.6761 .28691 L
.67612 .28694 L
.67615 .28698 L
.67621 .28709 L
.67624 .28716 L
.67628 .28725 L
.67631 .28737 L
.67634 .2875 L
.67646 .28813 L
.67668 .28979 L
.67693 .29231 L
.67741 .29902 L
.67788 .30668 L
.67837 .31475 L
.67862 .31829 L
.67885 .32109 L
.67907 .32324 L
.67919 .32419 L
.6793 .32485 L
.67936 .32515 L
.67939 .32531 L
.67942 .32545 L
.67945 .32553 L
.67946 .32557 L
.67948 .3256 L
.67951 .32564 L
.67953 .32568 L
.67956 .32572 L
.67959 .32575 L
.67961 .32577 L
.67962 .32577 L
.67962 .32578 L
.67964 .32578 L
.67965 .32579 L
.67967 .32579 L
.67968 .32579 L
.67969 .32579 L
.67969 .3258 L
.6797 .3258 L
.67972 .32581 L
.67974 .32583 L
.67975 .32584 L
.67976 .32584 L
.67977 .32584 L
.67978 .32583 L
.6798 .3258 L
.67981 .32576 L
.67983 .3257 L
.67984 .32563 L
Mistroke
.6799 .32535 L
.68002 .32485 L
.68008 .32457 L
.6801 .32451 L
.68012 .32443 L
.68015 .32425 L
.68017 .32401 L
.6802 .32371 L
.68027 .32311 L
.68075 .31761 L
.68122 .3104 L
.68171 .30209 L
.68219 .29487 L
.68241 .29222 L
.68253 .29093 L
.68265 .28991 L
.68277 .28899 L
.68289 .28838 L
.68295 .28813 L
.68301 .2879 L
.68304 .2878 L
.68306 .28776 L
.68307 .28772 L
.68309 .2877 L
.68311 .28768 L
.68314 .28765 L
.68315 .28764 L
.68317 .28763 L
.68318 .28762 L
.6832 .28762 L
.68321 .28762 L
.68322 .28762 L
.68323 .28762 L
.68324 .28763 L
.68326 .28763 L
.68327 .28764 L
.68329 .28766 L
.68331 .28767 L
.68332 .28768 L
.68334 .28771 L
.68335 .28774 L
.68338 .28781 L
.68349 .28824 L
.6836 .28875 L
.68366 .28912 L
.68373 .28962 L
.68385 .29061 L
.68407 .29295 L
.68456 .29981 L
.68503 .30762 L
Mistroke
.68548 .31492 L
.68574 .31843 L
.68597 .3211 L
.68619 .32308 L
.68631 .32384 L
.68634 .32403 L
.68637 .32422 L
.6864 .32437 L
.68643 .32446 L
.68655 .32477 L
.68661 .32486 L
.68667 .32496 L
.68668 .32499 L
.68669 .32502 L
.68671 .32503 L
.68672 .32503 L
.68673 .32503 L
.68674 .32501 L
.68676 .32498 L
.68679 .32486 L
.68692 .32446 L
.68698 .32425 L
.68701 .32417 L
.68703 .32412 L
.68704 .32408 L
.68706 .324 L
.68707 .3239 L
.68711 .32359 L
.68718 .32303 L
.68742 .3209 L
.68765 .31816 L
.6879 .31463 L
.68839 .30663 L
.68886 .29891 L
.68931 .29279 L
.68955 .29055 L
.68968 .2896 L
.6898 .28895 L
.68985 .28869 L
.68989 .28857 L
.68991 .2885 L
.68997 .28839 L
.69 .28834 L
.69002 .28831 L
.69004 .2883 L
.69005 .28829 L
.69007 .28828 L
.69009 .28827 L
.6901 .28826 L
.69012 .28826 L
Mistroke
.69013 .28826 L
.69014 .28826 L
.69016 .28827 L
.69017 .28828 L
.69018 .2883 L
.69021 .28837 L
.69027 .28853 L
.69039 .28896 L
.69045 .28924 L
.69052 .28966 L
.69074 .29142 L
.69097 .29401 L
.69122 .29744 L
.69172 .30542 L
.6922 .3133 L
.69266 .31955 L
.6929 .32186 L
.69302 .32275 L
.69305 .32298 L
.69309 .3232 L
.69312 .32336 L
.69315 .32347 L
.69328 .32386 L
.69333 .324 L
.69336 .32408 L
.69339 .32416 L
.6934 .32419 L
.69342 .32421 L
.69343 .32421 L
.69344 .3242 L
.69345 .32418 L
.69348 .32411 L
.69351 .32402 L
.69364 .32372 L
.6937 .3236 L
.69371 .32358 L
.69373 .32354 L
.69374 .32351 L
.69374 .32348 L
.69376 .32339 L
.69379 .32313 L
.69383 .32283 L
.69389 .32237 L
.69414 .32024 L
.69437 .31744 L
.69459 .31434 L
.69506 .30673 L
.69556 .29861 L
.69581 .2951 L
.69604 .29243 L
Mistroke
.69627 .29048 L
.69638 .28978 L
.69644 .28945 L
.69647 .28931 L
.6965 .28921 L
.69656 .28906 L
.69659 .28899 L
.69663 .28894 L
.69668 .28887 L
.69669 .28886 L
.69671 .28884 L
.69672 .28883 L
.69674 .28884 L
.69675 .28884 L
.69677 .28886 L
.6968 .28891 L
.69686 .28904 L
.69689 .28913 L
.69693 .28923 L
.69696 .28933 L
.69699 .28943 L
.69701 .28955 L
.69704 .28971 L
.6971 .29008 L
.69723 .29094 L
.69745 .29307 L
.69794 .29977 L
.69842 .30762 L
.69888 .3149 L
.69913 .31828 L
.69937 .32069 L
.69948 .32164 L
.69954 .3221 L
.69958 .32231 L
.69961 .32247 L
.69967 .32269 L
.69973 .32293 L
.69984 .32328 L
.69985 .32333 L
.69987 .32338 L
.69988 .32341 L
.69989 .32342 L
.6999 .32342 L
.69991 .32341 L
.69991 .3234 L
.69992 .32339 L
.69993 .32337 L
.69996 .3233 L
.70008 .32309 L
.70014 .32299 L
Mistroke
.70015 .32298 L
.70016 .32298 L
.70017 .32297 L
.70018 .32294 L
.7002 .3229 L
.70021 .32284 L
.70022 .32276 L
.70025 .32254 L
.7003 .32215 L
.70041 .32141 L
.70053 .32049 L
.70065 .31916 L
.70077 .31781 L
.70102 .31435 L
.70127 .31062 L
.70176 .30227 L
.70202 .29832 L
.70225 .29515 L
.70247 .2926 L
.70259 .29154 L
.70271 .29067 L
.70277 .29028 L
.7028 .29011 L
.70283 .28997 L
.70289 .28978 L
.70295 .28961 L
.703 .2895 L
.70303 .28945 L
.70305 .28941 L
.70307 .28939 L
.70308 .28938 L
.7031 .28938 L
.70311 .28938 L
.70313 .2894 L
.70314 .28941 L
.70317 .28945 L
.7032 .2895 L
.70323 .28956 L
.70329 .28971 L
.70332 .28979 L
.70335 .28991 L
.70339 .2901 L
.70342 .29029 L
.70367 .29203 L
.70379 .29325 L
.70392 .29478 L
.70416 .29806 L
.70465 .30591 L
.70512 .31353 L
.70536 .31682 L
Mistroke
.70557 .3193 L
.70568 .3203 L
.70581 .32128 L
.70587 .32165 L
.70593 .3219 L
.70599 .32216 L
.70606 .32239 L
.70609 .32252 L
.70611 .32259 L
.70611 .32262 L
.70612 .32264 L
.70614 .32266 L
.70615 .32267 L
.70616 .32266 L
.70617 .32265 L
.70618 .32262 L
.7063 .32246 L
.70633 .32241 L
.70634 .32238 L
.70636 .32237 L
.70637 .32236 L
.70638 .32235 L
.70639 .32235 L
.7064 .32235 L
.70642 .32233 L
.70643 .3223 L
.70644 .32225 L
.70646 .32216 L
.70647 .32207 L
.70652 .32168 L
.70663 .321 L
.70674 .32017 L
.70687 .31889 L
.70699 .31759 L
.70722 .31443 L
.70747 .31057 L
.70797 .30234 L
.70822 .29846 L
.70844 .29531 L
.70867 .29286 L
.70879 .29178 L
.7089 .291 L
.70896 .29064 L
.70903 .29037 L
.70909 .29015 L
.70916 .28999 L
.70917 .28996 L
.70919 .28993 L
.7092 .2899 L
.70922 .28988 L
Mistroke
.70923 .28988 L
.70924 .28988 L
.70925 .28988 L
.70925 .28988 L
.70927 .28989 L
.70928 .28991 L
.70931 .28993 L
.70935 .28997 L
.70937 .29002 L
.7094 .29008 L
.70943 .29015 L
.70945 .29019 L
.70946 .29023 L
.7095 .29036 L
.70952 .2905 L
.70964 .29113 L
.70976 .29198 L
.70989 .29322 L
.71037 .29952 L
.71084 .30713 L
.71133 .31486 L
.71158 .31796 L
.7117 .31917 L
.71181 .32012 L
.71186 .32057 L
.71189 .32077 L
.71192 .32091 L
.71203 .3214 L
.71209 .32163 L
.71212 .32176 L
.71214 .32188 L
.71216 .32192 L
.71217 .32195 L
.71219 .32196 L
.7122 .32195 L
.71221 .32193 L
.71222 .32192 L
.71223 .32189 L
.71225 .32187 L
.71227 .32186 L
.7123 .32184 L
.71231 .32183 L
.71233 .32181 L
.71235 .32177 L
.71237 .32175 L
.71238 .32174 L
.7124 .32173 L
.71241 .32173 L
.71243 .32174 L
.71244 .32173 L
Mistroke
.71245 .32172 L
.71246 .3217 L
.71247 .32167 L
.71248 .32163 L
.71249 .32154 L
.71251 .32142 L
.71262 .32069 L
.71268 .32033 L
.7127 .32019 L
.71273 .32001 L
.71276 .31975 L
.71279 .31943 L
.71285 .3188 L
.71297 .31763 L
.71322 .31438 L
.7137 .30672 L
.71417 .29908 L
.71441 .29576 L
.71454 .29428 L
.71467 .29291 L
.71479 .29195 L
.71485 .29152 L
.71488 .2913 L
.71492 .2911 L
.71498 .29084 L
.71504 .29064 L
.71509 .29049 L
.71512 .29042 L
.71513 .29039 L
.71515 .29036 L
.71516 .29034 L
.71518 .29034 L
.71519 .29034 L
.71519 .29034 L
.7152 .29035 L
.71521 .29035 L
.71524 .29037 L
.71525 .29038 L
.71527 .29039 L
.71529 .29041 L
.7153 .29043 L
.71533 .29048 L
.71536 .29053 L
.71538 .29059 L
.7154 .29063 L
.71542 .29069 L
.71545 .29083 L
.71551 .29117 L
.71563 .2919 L
.7157 .29243 L
Mistroke
.71576 .29297 L
.71587 .29408 L
.71612 .29723 L
.71658 .30441 L
.71707 .3124 L
.71732 .31582 L
.71755 .31838 L
.71766 .31939 L
.71771 .31986 L
.71776 .32017 L
.71782 .32046 L
.71789 .32076 L
.71795 .321 L
.71797 .32113 L
.71799 .3212 L
.718 .32125 L
.71802 .32128 L
.71803 .32129 L
.71804 .32128 L
.71805 .32128 L
.71806 .32125 L
.71808 .32123 L
.71808 .32122 L
.71809 .32122 L
.7181 .32121 L
.71811 .32121 L
.71812 .32121 L
.71813 .3212 L
.71814 .3212 L
.71816 .32119 L
.71817 .32117 L
.71818 .32116 L
.7182 .32114 L
.71821 .32113 L
.71822 .32113 L
.71823 .32113 L
.71825 .32114 L
.71826 .32115 L
.71827 .32115 L
.71829 .32113 L
.7183 .32108 L
.71831 .32104 L
.71832 .32099 L
.71833 .32089 L
.71836 .32068 L
.71847 .32005 L
.71871 .31808 L
.71884 .31663 L
.71896 .31511 L
.71944 .30773 L
Mistroke
.7199 .30013 L
.72014 .29673 L
.72026 .29516 L
.7204 .29371 L
.72052 .29257 L
.72064 .29174 L
.7207 .29143 L
.72076 .29118 L
.72081 .291 L
.72087 .29084 L
.72089 .29081 L
.7209 .29078 L
.72091 .29077 L
.72093 .29076 L
.72094 .29076 L
.72096 .29077 L
.72097 .29077 L
.72098 .29078 L
.721 .29078 L
.72101 .29079 L
.72102 .2908 L
.72103 .29081 L
.72105 .29084 L
.72108 .29088 L
.72111 .29092 L
.72112 .29096 L
.72114 .29101 L
.72117 .29113 L
.72124 .29144 L
.7213 .29179 L
.72136 .29213 L
.72147 .29307 L
.7216 .29427 L
.72185 .29741 L
.72231 .30465 L
.72281 .31261 L
.72305 .31595 L
.72317 .31732 L
.72328 .31836 L
.72334 .31883 L
.72339 .31928 L
.72342 .31945 L
.72345 .31961 L
.7235 .3199 L
.72357 .32019 L
.7236 .32033 L
.72363 .32048 L
.72364 .32055 L
.72365 .32061 L
.72367 .32064 L
Mistroke
.72368 .32066 L
.7237 .32065 L
.72371 .32063 L
.72374 .3206 L
.72376 .32059 L
.72377 .32059 L
.72378 .32059 L
.7238 .32059 L
.72381 .32058 L
.72383 .32057 L
.72384 .32056 L
.72385 .32055 L
.72387 .32055 L
.72388 .32055 L
.72389 .32056 L
.72391 .32058 L
.72393 .32058 L
.72393 .32057 L
.72394 .32055 L
.72396 .32048 L
.72397 .3204 L
.7241 .31961 L
.72416 .31927 L
.72422 .31884 L
.72428 .31825 L
.72435 .31763 L
.72447 .31634 L
.72469 .31342 L
.72516 .30589 L
.72562 .29861 L
.72587 .29528 L
.7261 .29299 L
.72622 .29215 L
.72628 .2918 L
.72634 .29155 L
.7264 .29136 L
.72643 .29127 L
.72644 .29124 L
.72645 .2912 L
.72647 .29118 L
.72648 .29116 L
.72649 .29116 L
.7265 .29115 L
.72651 .29115 L
.72653 .29115 L
.72654 .29116 L
.72656 .29116 L
.72657 .29116 L
.72659 .29117 L
.7266 .29118 L
Mistroke
.72663 .29122 L
.72666 .29125 L
.72667 .29127 L
.72668 .29129 L
.7267 .29133 L
.72671 .29139 L
.72675 .29153 L
.72681 .2918 L
.72687 .29214 L
.72694 .29256 L
.72706 .29361 L
.7273 .29625 L
.72755 .2998 L
.72801 .30722 L
.72826 .3113 L
.72849 .3146 L
.72861 .31601 L
.72873 .31734 L
.72885 .31839 L
.72896 .31912 L
.72902 .31946 L
.72905 .31961 L
.72906 .31967 L
.72907 .31974 L
.72909 .31978 L
.7291 .31982 L
.72913 .31987 L
.7292 .31997 L
.72923 .32001 L
.72925 .32002 L
.72926 .32003 L
.72927 .32004 L
.72927 .32005 L
.72928 .32006 L
.7293 .3201 L
.72931 .32012 L
.72932 .32013 L
.72933 .32014 L
.72935 .32013 L
.72936 .32009 L
.72938 .32003 L
.72939 .31996 L
.72945 .3197 L
.72951 .31946 L
.72956 .31927 L
.72958 .31921 L
.72959 .31914 L
.72961 .31903 L
.72962 .31891 L
.72968 .31839 L
Mistroke
.72981 .31729 L
.72993 .31596 L
.73039 .30941 L
.73088 .30135 L
.73113 .29771 L
.73136 .29488 L
.73146 .29383 L
.73157 .29289 L
.7317 .29216 L
.73175 .2919 L
.73178 .29179 L
.73181 .29168 L
.73182 .29164 L
.73184 .29161 L
.73185 .29159 L
.73187 .29157 L
.7319 .29154 L
.73191 .29153 L
.73192 .29152 L
.73194 .29151 L
.73195 .29151 L
.73196 .29151 L
.73197 .29151 L
.73199 .29152 L
.732 .29152 L
.73202 .29152 L
.73202 .29153 L
.73203 .29153 L
.73205 .29155 L
.73206 .29158 L
.73207 .29161 L
.7321 .2917 L
.73215 .2919 L
.73221 .29214 L
.73227 .29241 L
.7323 .29262 L
.73233 .29287 L
.73239 .29333 L
.73252 .29457 L
.73276 .29749 L
.73325 .30501 L
.73371 .31244 L
.73395 .31556 L
.73408 .31688 L
.73414 .31756 L
.73421 .31806 L
.73434 .31883 L
.73437 .31899 L
.7344 .31919 L
.73441 .31927 L
Mistroke
.73443 .31935 L
.73444 .3194 L
.73446 .31942 L
.73447 .31942 L
.73449 .31942 L
.7345 .31941 L
.73451 .31942 L
.73453 .31943 L
.73454 .31944 L
.73457 .31946 L
.73459 .31947 L
.73461 .31947 L
.73462 .31948 L
.73463 .31949 L
.73464 .3195 L
.73466 .31954 L
.73467 .31957 L
.73469 .31958 L
.7347 .31957 L
.73472 .31951 L
.73473 .31943 L
.73474 .31934 L
.73481 .31902 L
.73486 .31875 L
.73492 .31851 L
.73495 .31833 L
.73497 .31818 L
.73498 .31803 L
.73504 .31754 L
.73517 .31632 L
.73542 .31327 L
.73564 .30994 L
.73612 .30202 L
.73634 .29863 L
.73658 .2955 L
.7367 .29428 L
.73682 .29323 L
.73689 .29276 L
.73696 .29244 L
.73701 .29218 L
.73705 .29205 L
.73706 .29199 L
.73708 .29195 L
.73709 .29191 L
.73711 .29189 L
.73712 .29188 L
.73713 .29187 L
.73715 .29185 L
.73716 .29184 L
.73717 .29184 L
Mistroke
.73718 .29183 L
.7372 .29183 L
.73721 .29183 L
.73723 .29184 L
.73724 .29184 L
.73725 .29184 L
.73727 .29185 L
.73728 .29185 L
.73729 .29187 L
.73731 .2919 L
.73732 .29195 L
.73734 .292 L
.73737 .29211 L
.73744 .29238 L
.73756 .29307 L
.73767 .29398 L
.73779 .29518 L
.73801 .29792 L
.7385 .30567 L
.73875 .30969 L
.73898 .3131 L
.7392 .3158 L
.73932 .31701 L
.73944 .31785 L
.73949 .31823 L
.73953 .31843 L
.73954 .31852 L
.73956 .31859 L
.73958 .31864 L
.73959 .31868 L
.73962 .31875 L
.73969 .3189 L
.73975 .319 L
.73976 .31904 L
.73977 .31907 L
.73978 .31909 L
.73979 .31911 L
.73981 .3191 L
.73982 .31909 L
.73982 .31906 L
.73984 .31899 L
.73987 .31885 L
.73993 .31866 L
.73999 .31846 L
.74001 .31842 L
.74003 .31837 L
.74003 .31833 L
.74004 .31829 L
.74006 .31816 L
.74012 .31767 L
Mistroke
.74018 .31724 L
.7404 .31502 L
.74064 .31184 L
.7409 .30789 L
.74135 .30037 L
.74161 .29677 L
.74184 .29425 L
.74196 .2933 L
.74202 .29291 L
.74208 .29261 L
.74211 .29249 L
.74214 .29237 L
.74215 .29232 L
.74217 .29228 L
.74218 .29225 L
.74219 .29223 L
.74222 .29219 L
.74224 .29217 L
.74225 .29216 L
.74226 .29215 L
.74227 .29214 L
.74228 .29213 L
.74231 .29212 L
.74232 .29212 L
.74234 .29211 L
.74235 .29211 L
.74235 .29212 L
.74237 .29214 L
.74238 .29217 L
.7424 .29221 L
.74242 .29229 L
.74249 .29251 L
.74252 .29263 L
.74255 .29275 L
.74258 .2929 L
.74261 .29309 L
.74267 .29354 L
.7428 .29468 L
.74304 .29746 L
.74326 .30066 L
.74373 .30833 L
.74397 .31202 L
.7441 .31372 L
.74423 .31529 L
.74435 .31653 L
.74442 .31705 L
.74448 .31746 L
.74454 .3178 L
.74459 .31816 L
.74461 .31825 L
Mistroke
.74462 .31831 L
.74463 .31833 L
.74464 .31835 L
.74466 .31835 L
.74467 .31835 L
.74468 .31835 L
.7447 .31836 L
.74471 .31838 L
.74477 .31844 L
.74478 .31845 L
.74479 .31845 L
.7448 .31847 L
.74482 .31851 L
.74483 .31855 L
.74484 .31858 L
.74485 .3186 L
.74487 .31859 L
.74488 .31855 L
.7449 .31848 L
.74491 .31839 L
.74494 .31823 L
.745 .31798 L
.74506 .31774 L
.74508 .31768 L
.74509 .3176 L
.7451 .31754 L
.74511 .31747 L
.74513 .31732 L
.74519 .31682 L
.74543 .31442 L
.74565 .31146 L
.74613 .30364 L
.74636 .30006 L
.7466 .29669 L
.74673 .29516 L
.74686 .29405 L
.74697 .29323 L
.74703 .29292 L
.74706 .29278 L
.7471 .29263 L
.74711 .29257 L
.74713 .29253 L
.74714 .2925 L
.74716 .29248 L
.74719 .29245 L
.7472 .29243 L
.74721 .29242 L
.74722 .29241 L
.74723 .2924 L
.74725 .2924 L
Mistroke
.74728 .29239 L
.74729 .29239 L
.7473 .29239 L
.74732 .2924 L
.74733 .29242 L
.74734 .29245 L
.74736 .2925 L
.74739 .2926 L
.74745 .29281 L
.74748 .29294 L
.7475 .29301 L
.74752 .29309 L
.74755 .2933 L
.74758 .29352 L
.74782 .29564 L
.74804 .29842 L
.74851 .30582 L
.74875 .30969 L
.749 .31338 L
.74913 .31482 L
.74925 .3161 L
.74936 .31692 L
.74942 .31732 L
.74944 .31742 L
.74945 .31752 L
.74947 .31758 L
.74948 .31762 L
.74955 .31779 L
.74961 .31792 L
.74962 .31795 L
.74963 .31799 L
.74965 .31803 L
.74966 .31809 L
.74968 .31813 L
.74969 .31815 L
.7497 .31814 L
.74972 .3181 L
.74978 .31786 L
.74985 .31767 L
.74987 .31759 L
.74989 .31756 L
.7499 .31753 L
.74992 .31746 L
.74993 .31741 L
.74994 .31734 L
.74997 .31709 L
.7502 .3151 L
.75034 .31357 L
.75046 .31189 L
.75094 .30435 L
Mistroke
.75141 .29723 L
.75153 .29575 L
.75166 .29446 L
.75179 .29354 L
.75185 .2932 L
.75188 .29307 L
.75189 .29299 L
.75191 .29293 L
.75192 .29288 L
.75193 .29284 L
.75196 .29279 L
.75199 .29273 L
.75201 .2927 L
.75202 .29269 L
.75204 .29267 L
.75205 .29266 L
.75206 .29265 L
.75208 .29263 L
.75209 .29262 L
.7521 .29262 L
.75212 .29263 L
.75213 .29265 L
.75215 .29268 L
.75216 .29273 L
.75219 .2928 L
.75226 .29301 L
.75229 .29311 L
.75232 .29323 L
.75233 .29333 L
.75235 .29344 L
.75238 .29365 L
.75261 .29562 L
.75274 .29714 L
.75286 .29875 L
.75332 .30621 L
.75356 .31004 L
.75382 .31363 L
.75395 .31497 L
.75407 .31612 L
.75418 .31684 L
.75421 .31706 L
.75423 .31718 L
.75425 .31728 L
.75426 .31734 L
.75428 .31737 L
.75429 .31738 L
.7543 .31738 L
.75432 .31739 L
.75433 .31741 L
.75436 .31745 L
Mistroke
.75439 .31749 L
.75441 .31751 L
.75442 .31753 L
.75443 .31756 L
.75445 .3176 L
.75446 .31765 L
.75448 .31769 L
.75449 .31769 L
.7545 .31767 L
.75451 .31762 L
.75453 .31753 L
.75459 .31722 L
.75466 .31698 L
.75469 .31689 L
.7547 .31683 L
.75471 .31675 L
.75475 .31648 L
.75478 .31624 L
.75501 .31403 L
.75526 .31074 L
.75574 .30293 L
.75596 .29948 L
.7562 .29628 L
.75632 .29507 L
.75638 .2945 L
.75644 .29402 L
.75651 .29361 L
.75658 .2933 L
.7566 .29316 L
.75662 .2931 L
.75663 .29305 L
.75665 .29302 L
.75667 .29299 L
.7567 .29294 L
.75671 .29292 L
.75673 .2929 L
.75674 .29289 L
.75675 .29288 L
.75677 .29287 L
.75678 .29287 L
.75679 .29286 L
.7568 .29286 L
.75682 .29286 L
.75683 .29289 L
.75685 .29292 L
.75688 .293 L
.75694 .29321 L
.75697 .29331 L
.75698 .29337 L
.757 .29343 L
Mistroke
.75703 .2936 L
.75706 .29379 L
.75716 .29456 L
.75727 .29564 L
.7574 .29702 L
.75762 .30007 L
.75811 .30805 L
.75835 .31175 L
.75847 .31331 L
.75858 .31451 L
.75869 .31549 L
.7588 .31635 L
.75884 .31655 L
.75885 .31662 L
.75887 .31668 L
.75893 .31685 L
.75898 .317 L
.759 .31703 L
.75901 .31707 L
.75903 .31713 L
.75904 .31719 L
.75906 .31724 L
.75906 .31725 L
.75907 .31726 L
.75909 .31723 L
.7591 .31717 L
.75916 .31698 L
.75922 .31683 L
.75925 .31677 L
.75926 .31675 L
.75927 .31671 L
.75929 .31664 L
.7593 .31658 L
.75931 .31651 L
.75934 .31628 L
.75939 .3159 L
.75952 .31479 L
.75976 .31206 L
.75998 .30884 L
.76044 .30127 L
.76068 .29783 L
.7608 .29628 L
.76094 .29495 L
.761 .29438 L
.76107 .29398 L
.76113 .29363 L
.76115 .29348 L
.76117 .29342 L
.76118 .29336 L
.7612 .29332 L
Mistroke
.76121 .29329 L
.76124 .29323 L
.76127 .29317 L
.76129 .29313 L
.76132 .29309 L
.76133 .29308 L
.76134 .29307 L
.76135 .29306 L
.76137 .29306 L
.76138 .29308 L
.7614 .29311 L
.76141 .29314 L
.76147 .29328 L
.7615 .29338 L
.76153 .29346 L
.76154 .29351 L
.76156 .29357 L
.76157 .29366 L
.76159 .29375 L
.76164 .29409 L
.76176 .29501 L
.76189 .29633 L
.76212 .29941 L
.76234 .30282 L
.76258 .30671 L
.76284 .31073 L
.76295 .31235 L
.76308 .31385 L
.76314 .31448 L
.7632 .31504 L
.76331 .31581 L
.76334 .31602 L
.76336 .31615 L
.76338 .31628 L
.76339 .31638 L
.7634 .31642 L
.76341 .31644 L
.76342 .31647 L
.76343 .31648 L
.76345 .31648 L
.76347 .3165 L
.76347 .31652 L
.76348 .31653 L
.7635 .31657 L
.76353 .31663 L
.76357 .3167 L
.76358 .31675 L
.7636 .31681 L
.76361 .31684 L
.76362 .31684 L
Mistroke
.76364 .3168 L
.76365 .31672 L
.76367 .31662 L
.76369 .31655 L
.7637 .3165 L
.76372 .31645 L
.76375 .31635 L
.76378 .31623 L
.76379 .31619 L
.7638 .31617 L
.76381 .31615 L
.76382 .31611 L
.76383 .31607 L
.76384 .31595 L
.76387 .3157 L
.76393 .31527 L
.76406 .31407 L
.76431 .3111 L
.76476 .30389 L
.76502 .29985 L
.76525 .29673 L
.76536 .2955 L
.76542 .29495 L
.76549 .29443 L
.76554 .29408 L
.76561 .29374 L
.76563 .2936 L
.76565 .29354 L
.76566 .2935 L
.76569 .29344 L
.76572 .29338 L
.76573 .29336 L
.76575 .29333 L
.76578 .2933 L
.7658 .29327 L
.76582 .29326 L
.76583 .29326 L
.76584 .29328 L
.76585 .29329 L
.76586 .29331 L
.76589 .29339 L
.76595 .29355 L
.76598 .29363 L
.76599 .29368 L
.76601 .29373 L
.76602 .29382 L
.76604 .29391 L
.76607 .29409 L
.76617 .29484 L
.76629 .29598 L
Mistroke
.76641 .29743 L
.76664 .30056 L
.76709 .30796 L
.76735 .31169 L
.76747 .31317 L
.76758 .31433 L
.7677 .31525 L
.76773 .3155 L
.76774 .31561 L
.76776 .31569 L
.76777 .31576 L
.76779 .31581 L
.76782 .31592 L
.76788 .3161 L
.76791 .31618 L
.76792 .31624 L
.76794 .31631 L
.76795 .31638 L
.76797 .31642 L
.76798 .31643 L
.76799 .3164 L
.76801 .31635 L
.76802 .3163 L
.76805 .31622 L
.76811 .31609 L
.76814 .31603 L
.76814 .31603 L
.76815 .31602 L
.76817 .31599 L
.76818 .31592 L
.7682 .31583 L
.76823 .31559 L
.76828 .31525 L
.76841 .31418 L
.76853 .31293 L
.76901 .30594 L
.76947 .29872 L
.7697 .29586 L
.76977 .29521 L
.76983 .29469 L
.76989 .29431 L
.76992 .29413 L
.76995 .29394 L
.76997 .29385 L
.76998 .29379 L
.77 .29374 L
.77001 .2937 L
.77007 .29357 L
.7701 .29351 L
.77012 .29348 L
Mistroke
.77013 .29345 L
.77015 .29343 L
.77016 .29343 L
.77017 .29343 L
.77018 .29345 L
.77019 .29348 L
.77024 .29357 L
.7703 .29371 L
.77032 .29375 L
.77033 .2938 L
.77034 .29386 L
.77036 .29394 L
.77041 .29428 L
.77065 .29633 L
.77077 .29778 L
.7709 .29962 L
.77139 .30736 L
.77161 .31071 L
.77174 .31235 L
.77185 .31367 L
.77197 .31465 L
.77203 .31507 L
.77206 .31533 L
.77208 .31546 L
.77209 .31551 L
.77209 .31555 L
.7721 .31558 L
.77211 .31559 L
.77212 .31561 L
.77213 .31561 L
.77215 .31563 L
.77215 .31565 L
.77216 .31567 L
.77219 .31575 L
.77221 .31579 L
.77223 .31582 L
.77224 .31586 L
.77226 .31591 L
.77227 .31598 L
.77229 .31603 L
.7723 .31605 L
.77232 .31602 L
.77233 .31595 L
.77235 .31587 L
.77241 .31569 L
.77246 .31554 L
.77248 .31551 L
.77249 .31546 L
.77251 .31536 L
.77252 .31525 L
Mistroke
.77259 .3148 L
.77272 .31366 L
.77285 .31232 L
.77332 .30514 L
.77378 .29805 L
.77391 .29655 L
.77402 .2954 L
.77408 .29487 L
.77415 .29442 L
.77418 .29424 L
.77421 .29405 L
.77423 .29398 L
.77424 .29393 L
.77427 .29385 L
.77433 .29371 L
.77436 .29366 L
.77437 .29364 L
.77439 .29361 L
.7744 .2936 L
.77442 .29361 L
.77442 .29362 L
.77443 .29364 L
.77445 .29366 L
.77451 .29379 L
.77454 .29386 L
.77455 .29388 L
.77456 .2939 L
.77457 .29396 L
.77459 .29404 L
.7746 .29412 L
.77463 .29428 L
.7747 .29468 L
.77476 .29518 L
.77488 .29633 L
.77499 .29762 L
.77524 .30118 L
.77573 .30914 L
.77598 .31245 L
.7761 .31369 L
.77621 .31461 L
.77624 .3148 L
.77625 .31488 L
.77627 .31494 L
.7763 .31505 L
.77633 .31517 L
.77638 .31537 L
.77641 .31548 L
.77642 .31555 L
.77643 .31561 L
.77645 .31565 L
Mistroke
.77646 .31564 L
.77648 .3156 L
.77649 .31555 L
.77651 .3155 L
.77652 .31548 L
.77653 .31547 L
.77656 .31543 L
.77657 .31541 L
.77658 .31538 L
.7766 .31536 L
.77661 .31536 L
.77663 .31535 L
.77664 .3153 L
.77666 .31523 L
.77667 .31513 L
.77678 .31444 L
.7769 .31339 L
.77704 .31193 L
.77716 .31034 L
.77764 .30278 L
.77787 .29911 L
.778 .29744 L
.77813 .29596 L
.77825 .29494 L
.77832 .29449 L
.77835 .2943 L
.77836 .29421 L
.77838 .29414 L
.77841 .29406 L
.77844 .29397 L
.77849 .29385 L
.77851 .29381 L
.77852 .29378 L
.77853 .29376 L
.77855 .29376 L
.77856 .29378 L
.77858 .2938 L
.77861 .29384 L
.77864 .2939 L
.77867 .29396 L
.77868 .29399 L
.7787 .29402 L
.77871 .29406 L
.77872 .29412 L
.77875 .29429 L
.77878 .29445 L
.77885 .29485 L
.77895 .29574 L
.77907 .29694 L
.77956 .30421 L
Mistroke
.7798 .30817 L
.78003 .31141 L
.78025 .31371 L
.78032 .31419 L
.78035 .31446 L
.78036 .31457 L
.78038 .31467 L
.78039 .31473 L
.7804 .31477 L
.78042 .31479 L
.78043 .31482 L
.78044 .31486 L
.78046 .31491 L
.78049 .315 L
.7805 .31504 L
.78052 .31508 L
.78053 .31515 L
.78055 .31522 L
.78056 .31527 L
.78058 .31529 L
.78059 .31527 L
.7806 .31522 L
.78066 .31506 L
.78073 .31494 L
.78074 .31493 L
.78075 .31493 L
.78076 .31491 L
.78077 .31488 L
.78079 .31478 L
.78084 .31433 L
.78089 .31399 L
.78092 .31381 L
.78095 .31362 L
.78096 .31346 L
.78098 .3133 L
.78101 .313 L
.78107 .31235 L
.78118 .31101 L
.78143 .30739 L
.78168 .30328 L
.78191 .29966 L
.78213 .29675 L
.78224 .2956 L
.78231 .2951 L
.78237 .29466 L
.78243 .29437 L
.78249 .29413 L
.78252 .29404 L
.78253 .29399 L
.78255 .29396 L
Mistroke
.78256 .29395 L
.78258 .29395 L
.78259 .29395 L
.7826 .29395 L
.78262 .29395 L
.78263 .29396 L
.78265 .29397 L
.78266 .29398 L
.78268 .29399 L
.78268 .294 L
.78269 .29401 L
.7827 .29402 L
.78271 .29404 L
.78272 .29409 L
.78279 .29435 L
.78282 .29452 L
.78285 .29467 L
.78288 .29485 L
.78291 .29509 L
.78297 .29561 L
.78309 .29673 L
.78334 .30002 L
.78383 .30801 L
.78408 .31148 L
.78419 .31269 L
.78425 .31324 L
.78428 .31354 L
.78431 .31378 L
.78434 .31395 L
.78437 .31412 L
.78443 .31441 L
.78446 .31456 L
.78447 .31466 L
.78449 .31474 L
.7845 .3148 L
.78451 .31483 L
.78452 .31483 L
.78454 .3148 L
.78455 .31478 L
.78456 .31477 L
.78457 .31477 L
.78458 .31478 L
.7846 .31478 L
.78461 .31478 L
.78461 .31478 L
.78462 .31478 L
.78463 .31477 L
.78465 .31478 L
.78466 .3148 L
.78468 .31482 L
Mistroke
.78469 .3148 L
.7847 .31475 L
.78472 .31467 L
.78478 .31439 L
.7849 .31366 L
.78501 .31272 L
.78514 .31123 L
.78526 .30958 L
.78573 .30223 L
.78596 .29869 L
.78608 .29711 L
.78622 .29573 L
.78628 .2952 L
.78632 .29496 L
.78635 .29476 L
.7864 .29449 L
.78646 .29426 L
.78649 .29417 L
.7865 .29413 L
.78652 .29411 L
.78653 .29409 L
.78655 .29409 L
.78656 .29409 L
.78657 .29409 L
.78659 .29409 L
.7866 .2941 L
.78661 .2941 L
.78662 .29411 L
.78663 .29413 L
.78665 .29414 L
.78666 .29416 L
.78668 .29418 L
.78669 .29423 L
.78675 .2945 L
.78681 .2948 L
.78687 .29517 L
.78692 .29564 L
.78718 .29846 L
.78766 .30609 L
.78789 .30954 L
.78813 .31249 L
.7882 .31308 L
.78823 .31341 L
.78825 .31356 L
.78827 .31366 L
.7883 .31378 L
.78833 .31393 L
.78836 .31409 L
.78839 .31425 L
.78841 .31434 L
Mistroke
.78842 .31441 L
.78843 .31445 L
.78844 .31445 L
.78845 .31445 L
.78846 .31444 L
.78847 .31443 L
.78848 .31443 L
.78848 .31443 L
.7885 .31444 L
.78852 .31445 L
.78853 .31445 L
.78854 .31445 L
.78855 .31445 L
.78856 .31446 L
.78858 .31448 L
.78859 .3145 L
.7886 .31448 L
.78862 .31443 L
.78863 .31435 L
.78869 .31408 L
.78872 .31394 L
.78875 .31383 L
.78876 .3138 L
.78877 .31376 L
.78878 .31369 L
.78879 .31362 L
.78882 .3133 L
.78889 .31276 L
.78913 .31007 L
.78937 .30641 L
.78959 .30281 L
.78981 .29934 L
.78993 .29775 L
.79005 .29633 L
.79012 .29574 L
.79019 .29518 L
.79025 .29479 L
.79031 .2945 L
.79032 .29444 L
.79034 .29439 L
.79037 .29432 L
.79039 .29429 L
.7904 .29427 L
.79043 .29423 L
.79044 .29422 L
.79046 .2942 L
.79046 .2942 L
.79047 .2942 L
.79048 .29421 L
.79049 .29422 L
Mistroke
.79052 .29428 L
.79055 .29434 L
.79058 .29442 L
.7906 .29447 L
.79061 .29453 L
.79063 .2946 L
.79064 .29467 L
.79067 .29484 L
.79079 .29562 L
.79091 .29679 L
.79104 .29839 L
.79153 .30609 L
.79178 .3098 L
.7919 .31131 L
.79201 .31244 L
.79206 .31292 L
.79212 .31334 L
.79217 .31366 L
.7922 .31382 L
.79221 .31388 L
.79223 .31392 L
.79226 .31399 L
.79229 .31406 L
.79232 .31412 L
.79235 .3142 L
.79236 .31424 L
.79238 .31426 L
.79239 .31424 L
.79241 .31419 L
.79246 .31402 L
.79249 .31393 L
.79251 .31389 L
.79252 .31386 L
.79254 .31385 L
.79255 .31383 L
.79256 .31379 L
.79257 .31373 L
.79258 .3136 L
.79269 .31274 L
.79282 .31141 L
.79294 .30992 L
.79342 .30254 L
.79365 .29893 L
.79387 .29633 L
.79398 .29536 L
.79404 .29498 L
.7941 .29468 L
.79414 .29456 L
.79417 .29447 L
.79418 .29442 L
Mistroke
.79419 .2944 L
.7942 .29437 L
.79421 .29436 L
.79422 .29435 L
.79423 .29435 L
.79425 .29435 L
.79426 .29436 L
.79427 .29436 L
.79428 .29436 L
.79429 .29438 L
.79433 .29441 L
.79434 .29442 L
.79435 .29445 L
.79437 .2945 L
.79438 .29456 L
.79441 .29467 L
.79447 .29496 L
.79452 .29531 L
.79458 .29573 L
.79482 .29845 L
.79529 .30574 L
.79553 .30936 L
.79566 .31097 L
.79579 .31235 L
.79585 .3128 L
.79591 .31323 L
.79593 .31335 L
.79594 .31345 L
.79596 .31351 L
.79598 .31356 L
.79604 .31375 L
.79607 .31382 L
.79608 .31388 L
.7961 .31392 L
.79611 .31395 L
.79612 .31394 L
.79613 .31393 L
.79614 .31388 L
.79616 .31384 L
.79617 .31382 L
.79619 .31379 L
.79622 .31373 L
.79623 .3137 L
.79624 .31368 L
.79626 .31368 L
.79627 .31367 L
.79628 .31363 L
.7963 .31354 L
.79633 .31332 L
.79639 .31292 L
Mistroke
.79649 .31204 L
.79661 .31083 L
.79674 .30903 L
.79723 .30132 L
.79745 .29807 L
.79757 .29669 L
.7977 .29555 L
.79776 .2951 L
.7978 .29492 L
.79783 .29478 L
.79786 .29467 L
.79789 .29457 L
.7979 .29454 L
.79791 .29452 L
.79791 .2945 L
.79792 .2945 L
.79793 .29449 L
.79794 .29449 L
.79795 .29448 L
.79797 .29448 L
.79798 .29448 L
.79799 .29448 L
.798 .29448 L
.79801 .29449 L
.79803 .2945 L
.79804 .29451 L
.79806 .29453 L
.79807 .29458 L
.79813 .29482 L
.79817 .29496 L
.7982 .2951 L
.79822 .2953 L
.79825 .2955 L
.79831 .29596 L
.79843 .29724 L
.79869 .30068 L
.79914 .30799 L
.79938 .31109 L
.79951 .31235 L
.79957 .31278 L
.79958 .3129 L
.7996 .31301 L
.79962 .3131 L
.79963 .31316 L
.79969 .31336 L
.79972 .31345 L
.79975 .31357 L
.79977 .31363 L
.79978 .31367 L
.79979 .31366 L
Mistroke
.79981 .31362 L
.79986 .31351 L
.79992 .31344 L
.79993 .31344 L
.79994 .31345 L
.79995 .31343 L
.79996 .3134 L
.79997 .31329 L
.79999 .31313 L
.80005 .3127 L
.80008 .31252 L
.8001 .31245 L
.80011 .31236 L
.80013 .31222 L
.80014 .31207 L
.80017 .31175 L
.80023 .31113 L
.80034 .30978 L
.80059 .3061 L
.80084 .30209 L
.80107 .29863 L
.80118 .29721 L
.80129 .29611 L
.80135 .29563 L
.80138 .2954 L
.80142 .29518 L
.80147 .29491 L
.8015 .29481 L
.80153 .29471 L
.80154 .29468 L
.80154 .29466 L
.80156 .29463 L
.80157 .29462 L
.80159 .29461 L
.8016 .2946 L
.80162 .29459 L
.80163 .29459 L
.80164 .2946 L
.80166 .2946 L
.80167 .29461 L
.80168 .29461 L
.80169 .29462 L
.8017 .29465 L
.80172 .2947 L
.80173 .29476 L
.80176 .29487 L
.80182 .29512 L
.80185 .29528 L
.80188 .29551 L
.80198 .29637 L
Mistroke
.80211 .29772 L
.80222 .29921 L
.80247 .30308 L
.80272 .30708 L
.80284 .30885 L
.80295 .31027 L
.80305 .31144 L
.80311 .31199 L
.80317 .31244 L
.80323 .31279 L
.80326 .31295 L
.80329 .31314 L
.80331 .31323 L
.80332 .31329 L
.80333 .31331 L
.80335 .31329 L
.80336 .31326 L
.80337 .31325 L
.80338 .31325 L
.80339 .31326 L
.80341 .31326 L
.80342 .31327 L
.80344 .31327 L
.80345 .31328 L
.80346 .3133 L
.80347 .31332 L
.80348 .31332 L
.8035 .31327 L
.80351 .31317 L
.80353 .3131 L
.80359 .31286 L
.80361 .31275 L
.80363 .31269 L
.80364 .31261 L
.80365 .3125 L
.80367 .31239 L
.8037 .31215 L
.80376 .31163 L
.80389 .31023 L
.80438 .30283 L
.80462 .29907 L
.80474 .29753 L
.80485 .29636 L
.80491 .29589 L
.80496 .29549 L
.80501 .29518 L
.80507 .29492 L
.80508 .29486 L
.8051 .2948 L
.80511 .29475 L
Mistroke
.80513 .29472 L
.80514 .29471 L
.80515 .2947 L
.80517 .29469 L
.80518 .29469 L
.8052 .29468 L
.80521 .29469 L
.80522 .29469 L
.80523 .2947 L
.80525 .2947 L
.80526 .29471 L
.80527 .29473 L
.80529 .29479 L
.8053 .29484 L
.80536 .29509 L
.80542 .2954 L
.80548 .29583 L
.80555 .29639 L
.80577 .29903 L
.80624 .30639 L
.80647 .3098 L
.80661 .31128 L
.80673 .31228 L
.80679 .31257 L
.80681 .31273 L
.80683 .31283 L
.80684 .3129 L
.80686 .31293 L
.80687 .31292 L
.80688 .31292 L
.80689 .31293 L
.80691 .31295 L
.80696 .31301 L
.80698 .31305 L
.80699 .31306 L
.807 .31306 L
.80701 .31302 L
.80703 .31295 L
.80709 .31271 L
.80712 .31261 L
.80714 .31258 L
.80715 .31253 L
.80716 .31243 L
.80718 .31228 L
.80721 .31203 L
.80743 .30984 L
.80756 .30807 L
.80768 .30624 L
.80815 .29894 L
.80827 .29737 L
Mistroke
.80839 .29619 L
.80845 .29568 L
.80851 .29532 L
.80854 .29515 L
.80855 .29507 L
.80857 .295 L
.80859 .29495 L
.80861 .2949 L
.80864 .29483 L
.80865 .2948 L
.80867 .29477 L
.80868 .29475 L
.8087 .29475 L
.80871 .29476 L
.80872 .29478 L
.80874 .2948 L
.80875 .29482 L
.80877 .29484 L
.80878 .29487 L
.8088 .29491 L
.80882 .29494 L
.80883 .295 L
.80884 .29507 L
.80887 .29522 L
.80899 .29599 L
.80909 .29697 L
.80932 .29993 L
.80957 .30389 L
.80981 .30757 L
.80993 .30929 L
.81006 .31082 L
.81012 .31142 L
.81019 .3119 L
.81022 .3121 L
.81023 .31223 L
.81025 .31233 L
.81026 .31239 L
.81028 .31243 L
.81031 .3125 L
.81036 .31265 L
.81039 .31276 L
.8104 .31281 L
.81041 .31283 L
.81043 .31281 L
.81044 .31275 L
.81045 .31272 L
.81046 .3127 L
.81048 .31267 L
.81051 .31261 L
.81052 .31258 L
Mistroke
.81053 .31256 L
.81055 .31257 L
.81056 .31256 L
.81057 .31253 L
.81058 .31248 L
.81059 .31241 L
.8106 .31234 L
.81066 .3119 L
.81077 .31098 L
.8109 .30954 L
.81102 .30787 L
.81148 .30056 L
.81172 .29734 L
.81184 .29615 L
.81191 .29562 L
.81197 .29526 L
.812 .29514 L
.81203 .29501 L
.81204 .29498 L
.81205 .29496 L
.81206 .29494 L
.81207 .29493 L
.81208 .29491 L
.8121 .29489 L
.81211 .29487 L
.81213 .29487 L
.81214 .29486 L
.81215 .29486 L
.81216 .29486 L
.81218 .29486 L
.81219 .29489 L
.8122 .29492 L
.81222 .29496 L
.81227 .29514 L
.8123 .29524 L
.81233 .29537 L
.81235 .29554 L
.81238 .29574 L
.81244 .29618 L
.81256 .29738 L
.81267 .29877 L
.81292 .30253 L
.81314 .30616 L
.81338 .30961 L
.81352 .31102 L
.81358 .31149 L
.81361 .31173 L
.81362 .31186 L
.81364 .31198 L
.81366 .31205 L
Mistroke
.81366 .31208 L
.81367 .31211 L
.8137 .31221 L
.81376 .31239 L
.81377 .31245 L
.81379 .31254 L
.8138 .31259 L
.81382 .31259 L
.81383 .31257 L
.81383 .31254 L
.81384 .3125 L
.81385 .31247 L
.81387 .31243 L
.81388 .31241 L
.8139 .31238 L
.81391 .31235 L
.81393 .31233 L
.81394 .31233 L
.81395 .31234 L
.81396 .31231 L
.81398 .31221 L
.814 .312 L
.81407 .31159 L
.81414 .31106 L
.81425 .30989 L
.81438 .3083 L
.81485 .30086 L
.81497 .29905 L
.8151 .29736 L
.81517 .29671 L
.81523 .29612 L
.81529 .29568 L
.81532 .29548 L
.81535 .29535 L
.81537 .29523 L
.8154 .29512 L
.81543 .29503 L
.81545 .29499 L
.81546 .29496 L
.81547 .29494 L
.81549 .29494 L
.8155 .29495 L
.81551 .29495 L
.81552 .29495 L
.81553 .29496 L
.81555 .29497 L
.81557 .29499 L
.81558 .295 L
.8156 .29503 L
.81561 .29507 L
Mistroke
.81564 .29521 L
.8157 .29547 L
.81572 .29559 L
.81575 .29576 L
.81578 .296 L
.8158 .29622 L
.81606 .29912 L
.8163 .30283 L
.81654 .30669 L
.81676 .30965 L
.81681 .3103 L
.81688 .3109 L
.81699 .31171 L
.81701 .31181 L
.81702 .31192 L
.81703 .31196 L
.81704 .31199 L
.81706 .31203 L
.81707 .31206 L
.81709 .3121 L
.81712 .31217 L
.81715 .31223 L
.81716 .31225 L
.81717 .31228 L
.81719 .3123 L
.8172 .31227 L
.81721 .31222 L
.81724 .31212 L
.81727 .31205 L
.81729 .31201 L
.8173 .31198 L
.81732 .31197 L
.81732 .31196 L
.81733 .31193 L
.81735 .31184 L
.81736 .3117 L
.81742 .31128 L
.81744 .3111 L
.81746 .31103 L
.81747 .31095 L
.81748 .31089 L
.81749 .31082 L
.8175 .31063 L
.81753 .31026 L
.8176 .30955 L
.81772 .30796 L
.81797 .30406 L
.8182 .30037 L
.81843 .29735 L
.81854 .29622 L
Mistroke
.8186 .29575 L
.81863 .29556 L
.81865 .29546 L
.81866 .29539 L
.81868 .29533 L
.8187 .29527 L
.81872 .29517 L
.81876 .29508 L
.81877 .29506 L
.81877 .29503 L
.81878 .29502 L
.81879 .29502 L
.81881 .29502 L
.81882 .29502 L
.81883 .29503 L
.81884 .29503 L
.81885 .29504 L
.81887 .29506 L
.81888 .29507 L
.8189 .29508 L
.81891 .29512 L
.81892 .29518 L
.81894 .29523 L
.81897 .29534 L
.819 .29549 L
.81901 .29555 L
.81902 .29563 L
.81905 .29581 L
.81908 .29602 L
.81913 .29647 L
.81925 .29776 L
.81936 .29922 L
.81961 .3031 L
.81986 .30701 L
.81998 .30868 L
.82009 .30996 L
.8202 .311 L
.82026 .31134 L
.82028 .31153 L
.82031 .31177 L
.82032 .31187 L
.82034 .31191 L
.82035 .3119 L
.82036 .31189 L
.82037 .31186 L
.82038 .31187 L
.8204 .31189 L
.82042 .31193 L
.82043 .31194 L
.82044 .31195 L
Mistroke
.82046 .312 L
.82047 .31205 L
.82048 .31205 L
.8205 .31199 L
.82051 .3119 L
.82052 .31187 L
.82053 .31184 L
.82055 .3118 L
.82058 .3117 L
.82059 .31165 L
.82061 .3116 L
.82062 .31153 L
.82064 .31143 L
.82067 .31121 L
.8208 .31009 L
.82093 .30863 L
.82104 .30705 L
.82129 .30309 L
.82152 .2995 L
.82163 .29797 L
.82174 .29676 L
.8218 .29623 L
.82183 .29596 L
.82187 .29572 L
.82192 .29542 L
.82195 .29531 L
.82196 .29524 L
.82198 .29517 L
.82199 .29512 L
.82201 .29511 L
.82204 .29509 L
.82205 .29507 L
.82207 .29507 L
.82209 .29506 L
.82211 .29506 L
.82212 .29508 L
.82214 .29512 L
.82215 .29516 L
.82218 .29526 L
.82221 .29536 L
.82224 .2955 L
.82227 .29566 L
.82233 .29606 L
.82243 .29703 L
.82267 .30015 L
.82289 .30367 L
.82314 .30748 L
.82326 .30905 L
.82337 .31022 L
.82342 .31066 L
Mistroke
.82345 .31088 L
.82348 .31112 L
.82349 .31123 L
.82351 .3113 L
.82352 .31134 L
.82353 .31138 L
.82359 .31156 L
.82362 .31168 L
.82363 .31175 L
.82364 .3118 L
.82366 .31179 L
.82367 .31174 L
.82368 .31171 L
.82369 .31169 L
.8237 .31168 L
.82371 .31167 L
.82372 .31166 L
.82374 .31163 L
.82375 .31161 L
.82376 .31161 L
.82378 .31163 L
.82379 .31163 L
.8238 .31156 L
.82381 .3115 L
.82382 .31143 L
.82388 .31105 L
.82389 .31096 L
.8239 .31088 L
.82392 .31083 L
.82393 .31078 L
.82394 .3107 L
.82396 .31058 L
.82398 .31022 L
.82405 .30959 L
.82417 .30804 L
.82429 .30635 L
.82455 .30224 L
.82479 .2986 L
.82491 .29707 L
.82498 .29647 L
.82503 .296 L
.82509 .29565 L
.82514 .29539 L
.82517 .29528 L
.82518 .29522 L
.8252 .29519 L
.8252 .29518 L
.82521 .29517 L
.82523 .29516 L
.82524 .29514 L
Mistroke
.82526 .29513 L
.82527 .29513 L
.82529 .29512 L
.8253 .29512 L
.82532 .29514 L
.82533 .29518 L
.82534 .29522 L
.82537 .2953 L
.8254 .29542 L
.82542 .29548 L
.82544 .29555 L
.82546 .29574 L
.8255 .29595 L
.82562 .29703 L
.82575 .29858 L
.8262 .30564 L
.82633 .30758 L
.82646 .30914 L
.82657 .31025 L
.82663 .31075 L
.82669 .31108 L
.82674 .31128 L
.82677 .31138 L
.82678 .31145 L
.8268 .31152 L
.82681 .31155 L
.82682 .31154 L
.82683 .31151 L
.82684 .31147 L
.82686 .31145 L
.82687 .31144 L
.82689 .31142 L
.8269 .3114 L
.82691 .31139 L
.82693 .31141 L
.82694 .31143 L
.82695 .31142 L
.82696 .31138 L
.82698 .31126 L
.82704 .31083 L
.82715 .30991 L
.82727 .30865 L
.82739 .30699 L
.82761 .30355 L
.82785 .29974 L
.82798 .29802 L
.82805 .29722 L
.82811 .29658 L
.82818 .29606 L
.82823 .29569 L
Mistroke
.8283 .29539 L
.82831 .29532 L
.82832 .29529 L
.82833 .29527 L
.82834 .29526 L
.82835 .29524 L
.82836 .29522 L
.82838 .29521 L
.82839 .2952 L
.82841 .29519 L
.82842 .29518 L
.82844 .29518 L
.82844 .29519 L
.82845 .2952 L
.82847 .29524 L
.82848 .29528 L
.82854 .29545 L
.82855 .29551 L
.82857 .29557 L
.82858 .29565 L
.82859 .29575 L
.82871 .29668 L
.82883 .29791 L
.82896 .29969 L
.82908 .30152 L
.82932 .30541 L
.82954 .30851 L
.82966 .30983 L
.82972 .31029 L
.82975 .31053 L
.82976 .31065 L
.82977 .31075 L
.82979 .31082 L
.8298 .31088 L
.82984 .311 L
.8299 .31121 L
.82991 .31129 L
.82992 .31133 L
.82993 .31135 L
.82994 .31135 L
.82995 .31132 L
.82995 .31128 L
.82996 .31125 L
.82997 .31123 L
.82998 .31121 L
.82999 .3112 L
.83001 .31117 L
.83003 .31114 L
.83004 .31114 L
.83006 .31114 L
Mistroke
.83007 .31109 L
.83008 .31103 L
.83009 .31096 L
.83015 .3106 L
.83026 .30971 L
.83038 .30836 L
.83051 .30657 L
.83075 .3028 L
.83101 .29884 L
.83113 .29735 L
.8312 .29667 L
.83126 .29615 L
.83129 .29595 L
.83132 .29575 L
.83134 .29563 L
.83137 .29551 L
.8314 .2954 L
.83141 .29535 L
.83143 .2953 L
.83143 .29528 L
.83144 .29526 L
.83146 .29526 L
.83147 .29525 L
.83149 .29525 L
.8315 .29525 L
.83152 .29526 L
.83153 .29526 L
.83154 .29527 L
.83156 .29529 L
.83157 .29533 L
.8316 .29545 L
.83166 .29568 L
.83167 .29574 L
.83169 .29583 L
.83171 .29603 L
.83178 .29658 L
.83184 .2972 L
.83196 .29862 L
.83242 .30571 L
.83254 .30747 L
.83265 .3089 L
.83272 .30953 L
.83278 .31013 L
.8328 .31028 L
.83281 .3104 L
.83283 .31047 L
.83284 .3105 L
.83285 .31053 L
.8329 .31079 L
.83293 .31095 L
Mistroke
.83294 .311 L
.83295 .31103 L
.83296 .31103 L
.83298 .311 L
.83299 .31099 L
.833 .31099 L
.83302 .31099 L
.83303 .31099 L
.83304 .31098 L
.83305 .31099 L
.83306 .31101 L
.83308 .31103 L
.83309 .31102 L
.83309 .31098 L
.83311 .31088 L
.83314 .31071 L
.83318 .31056 L
.83319 .31049 L
.8332 .31047 L
.83321 .31043 L
.83322 .31039 L
.83323 .31032 L
.83325 .31014 L
.83328 .30986 L
.8334 .30865 L
.83365 .30508 L
.8339 .30115 L
.83411 .29801 L
.83417 .29731 L
.83424 .29665 L
.8343 .29618 L
.83436 .29578 L
.83439 .29561 L
.83441 .29553 L
.83442 .29546 L
.83444 .29541 L
.83445 .29538 L
.83446 .29535 L
.83448 .29532 L
.83449 .29531 L
.83451 .29529 L
.83452 .29527 L
.83454 .29526 L
.83455 .29527 L
.83457 .2953 L
.83459 .29536 L
.83462 .29544 L
.83463 .29546 L
.83464 .29548 L
.83466 .29554 L
Mistroke
.83467 .29559 L
.83467 .29563 L
.83469 .29574 L
.83472 .29593 L
.83485 .29695 L
.83496 .29831 L
.83507 .29983 L
.83532 .30377 L
.83555 .3072 L
.83567 .30868 L
.83579 .30987 L
.83586 .3103 L
.83587 .31041 L
.83588 .31047 L
.83589 .31051 L
.8359 .31054 L
.83591 .31057 L
.83592 .31061 L
.83596 .3107 L
.83599 .31077 L
.836 .3108 L
.836 .31083 L
.83602 .31085 L
.83603 .31083 L
.83605 .31078 L
.83611 .31066 L
.83612 .31065 L
.83614 .31064 L
.83615 .3106 L
.83617 .3105 L
.83619 .31028 L
.83622 .31009 L
.83626 .30992 L
.83626 .30988 L
.83627 .30983 L
.83628 .30977 L
.83629 .30967 L
.83632 .30932 L
.83635 .30904 L
.8364 .30852 L
.83653 .30688 L
.83678 .3029 L
.83701 .29935 L
.83712 .29778 L
.83725 .29648 L
.83731 .29601 L
.83735 .29579 L
.83737 .29568 L
.83738 .29561 L
.83742 .29549 L
Mistroke
.83745 .29541 L
.83746 .29537 L
.83748 .29534 L
.83748 .29533 L
.83749 .29533 L
.83751 .29533 L
.83752 .29533 L
.83753 .29534 L
.83754 .29534 L
.83757 .29537 L
.83757 .29538 L
.83758 .29539 L
.83759 .29542 L
.8376 .29545 L
.83763 .29558 L
.83766 .2957 L
.83769 .29584 L
.8377 .29593 L
.83772 .29605 L
.83775 .29628 L
.83787 .29744 L
.83798 .29883 L
.83823 .30267 L
.83848 .30654 L
.8386 .30813 L
.83871 .30931 L
.83876 .30973 L
.83879 .30995 L
.83881 .3101 L
.83882 .31023 L
.83884 .3103 L
.83885 .31031 L
.83887 .31032 L
.83888 .31036 L
.83891 .31044 L
.83893 .31051 L
.83895 .31059 L
.83896 .31068 L
.83897 .31071 L
.83898 .3107 L
.83899 .31066 L
.83904 .31048 L
.83908 .31042 L
.83908 .31041 L
.83909 .31041 L
.8391 .31039 L
.83911 .31035 L
.83912 .31024 L
.83914 .31013 L
.83917 .30996 L
Mistroke
.83928 .30904 L
.83941 .30761 L
.83966 .30385 L
.8399 .30005 L
.84 .29857 L
.84012 .2972 L
.84018 .29658 L
.84024 .29613 L
.84027 .29592 L
.84028 .29582 L
.84029 .29575 L
.84031 .2957 L
.84032 .29563 L
.84035 .29553 L
.84038 .29543 L
.84039 .29537 L
.84041 .29535 L
.84042 .29535 L
.84043 .29535 L
.84044 .29536 L
.84045 .29536 L
.84046 .29536 L
.84047 .29537 L
.84049 .29538 L
.8405 .29538 L
.8405 .29538 L
.84052 .29541 L
.84053 .29546 L
.8406 .29576 L
.84066 .29613 L
.84072 .29658 L
.84084 .29788 L
.84106 .30102 L
.84131 .30503 L
.84142 .30666 L
.84154 .3082 L
.8416 .30883 L
.84166 .30933 L
.84171 .30979 L
.84172 .30991 L
.84174 .30998 L
.84175 .31 L
.84177 .31003 L
.84178 .31008 L
.8418 .31015 L
.84181 .3102 L
.84182 .31023 L
.84183 .31026 L
.84185 .31036 L
.84185 .31042 L
Mistroke
.84186 .31045 L
.84188 .31046 L
.84189 .31039 L
.8419 .31033 L
.84192 .3103 L
.84193 .31029 L
.84195 .31026 L
.84196 .31025 L
.84197 .31024 L
.84199 .31024 L
.842 .31019 L
.84201 .31013 L
.84202 .31007 L
.84203 .30998 L
.84206 .30983 L
.84209 .30968 L
.84212 .3095 L
.84215 .30923 L
.84218 .30898 L
.84224 .30836 L
.84246 .30544 L
.8427 .30156 L
.84291 .29834 L
.84304 .29693 L
.84309 .29644 L
.84315 .29598 L
.84318 .2958 L
.84321 .29566 L
.84324 .29554 L
.84326 .29549 L
.84327 .29543 L
.84329 .29539 L
.84329 .29538 L
.8433 .29538 L
.84331 .29538 L
.84332 .29538 L
.84333 .29538 L
.84334 .29538 L
.84335 .29538 L
.84336 .29538 L
.84337 .29539 L
.84338 .29538 L
.8434 .2954 L
.84342 .29546 L
.84343 .29552 L
.84346 .29565 L
.84349 .29578 L
.84351 .29584 L
.84352 .29589 L
.84352 .29594 L
Mistroke
.84355 .29616 L
.84358 .29637 L
.84363 .29685 L
.84376 .29826 L
.84389 .3001 L
.84412 .30392 L
.84434 .30715 L
.84446 .30857 L
.84452 .30905 L
.84455 .3093 L
.84456 .30945 L
.84458 .30958 L
.84459 .30967 L
.84461 .30971 L
.84464 .30982 L
.84467 .30994 L
.8447 .31009 L
.84471 .31019 L
.84472 .31021 L
.84473 .3102 L
.84474 .31017 L
.84475 .31013 L
.84476 .3101 L
.84476 .31009 L
.84478 .31008 L
.84479 .31008 L
.8448 .31007 L
.84481 .31005 L
.84482 .31006 L
.84483 .31007 L
.84484 .3101 L
.84486 .31008 L
.84487 .30999 L
.84489 .30985 L
.8449 .30974 L
.84492 .30966 L
.84495 .30949 L
.845 .30912 L
.84506 .30858 L
.84531 .30542 L
.84556 .3013 L
.84579 .29795 L
.84591 .29669 L
.84594 .29641 L
.84598 .29613 L
.846 .29595 L
.84604 .29578 L
.84606 .29564 L
.84608 .29556 L
.84609 .29551 L
Mistroke
.84611 .29547 L
.84612 .29546 L
.84612 .29545 L
.84614 .29543 L
.84615 .29541 L
.84617 .2954 L
.84618 .29538 L
.8462 .29536 L
.84621 .29538 L
.84622 .29541 L
.84624 .29544 L
.84626 .29551 L
.84629 .2956 L
.8463 .29562 L
.84631 .29565 L
.84632 .29572 L
.84634 .29583 L
.84636 .29594 L
.84639 .29615 L
.84651 .29723 L
.84662 .29865 L
.84673 .30019 L
.84698 .30414 L
.8471 .30597 L
.84721 .30743 L
.84732 .30866 L
.84737 .30908 L
.8474 .30931 L
.84742 .30942 L
.84743 .3095 L
.84744 .30955 L
.84746 .3096 L
.84749 .30971 L
.8475 .30976 L
.84752 .3098 L
.84753 .30986 L
.84754 .30993 L
.84756 .30999 L
.84757 .30998 L
.84759 .30992 L
.8476 .30989 L
.84761 .30987 L
.84763 .30984 L
.84765 .30981 L
.84766 .30981 L
.84767 .30982 L
.84768 .30985 L
.84769 .30986 L
.8477 .30983 L
.84771 .3097 L
Mistroke
.84773 .30955 L
.84774 .30943 L
.84776 .30934 L
.84779 .30914 L
.84781 .30908 L
.84782 .30897 L
.84783 .30887 L
.84784 .30878 L
.84785 .30861 L
.84791 .30805 L
.84813 .30509 L
.84838 .30104 L
.84849 .29936 L
.84862 .29775 L
.84867 .29712 L
.84873 .29654 L
.84878 .29612 L
.84884 .29579 L
.84887 .29564 L
.84889 .29557 L
.8489 .29554 L
.8489 .29551 L
.84892 .29547 L
.84893 .29546 L
.84895 .29544 L
.84896 .29543 L
.84897 .29543 L
.84898 .29542 L
.84899 .29542 L
.849 .29541 L
.84901 .29541 L
.84902 .29543 L
.84904 .29547 L
.84905 .2955 L
.84908 .29559 L
.84911 .29569 L
.84912 .29575 L
.84913 .29582 L
.84915 .29592 L
.84917 .29603 L
.8492 .29624 L
.8493 .29724 L
.84942 .29871 L
.84955 .30058 L
.84979 .30444 L
.84992 .30632 L
.85005 .30795 L
.85011 .30853 L
.85017 .30901 L
.85019 .30916 L
Mistroke
.8502 .30923 L
.85021 .30928 L
.85022 .30936 L
.85023 .30939 L
.85024 .30941 L
.85027 .30952 L
.85029 .30958 L
.8503 .3096 L
.8503 .30963 L
.85032 .3097 L
.85033 .30978 L
.85035 .30979 L
.85036 .30975 L
.85037 .30971 L
.85039 .30968 L
.8504 .30966 L
.85041 .30964 L
.85043 .30961 L
.85044 .30961 L
.85045 .30962 L
.85046 .30965 L
.85047 .30965 L
.85048 .30961 L
.85049 .30949 L
.85051 .30934 L
.85052 .30923 L
.85053 .30915 L
.85065 .30823 L
.85076 .307 L
.85101 .30337 L
.85123 .29981 L
.85135 .29806 L
.85141 .29734 L
.85147 .29676 L
.85153 .29629 L
.85159 .29588 L
.85162 .29572 L
.85163 .29566 L
.85165 .29559 L
.85167 .29553 L
.85168 .2955 L
.85169 .29548 L
.85171 .29547 L
.85172 .29546 L
.85173 .29545 L
.85174 .29545 L
.85175 .29544 L
.85176 .29544 L
.85177 .29544 L
.85178 .29545 L
Mistroke
.85179 .29547 L
.85179 .29549 L
.85181 .29554 L
.85184 .29564 L
.85186 .2957 L
.85187 .29575 L
.85188 .29579 L
.85189 .29584 L
.85191 .29594 L
.85196 .29635 L
.85208 .29744 L
.8522 .29903 L
.85245 .30298 L
.85258 .30493 L
.85271 .30675 L
.85282 .30802 L
.85288 .30858 L
.85291 .30881 L
.85294 .30903 L
.85295 .30912 L
.85297 .30918 L
.853 .30929 L
.85305 .3095 L
.85307 .30957 L
.85308 .30959 L
.8531 .30955 L
.85311 .3095 L
.85312 .30948 L
.85313 .30947 L
.85315 .30945 L
.85316 .30942 L
.85317 .30942 L
.85318 .30942 L
.85319 .30945 L
.85321 .30944 L
.85322 .30935 L
.85323 .30921 L
.85325 .30909 L
.85326 .30899 L
.85329 .30881 L
.8534 .30786 L
.85352 .3064 L
.85366 .30446 L
.8539 .30056 L
.85402 .29874 L
.85414 .29731 L
.8542 .29667 L
.85426 .29619 L
.85432 .29581 L
.85436 .29565 L
Mistroke
.85437 .29558 L
.85438 .29554 L
.85439 .29553 L
.85441 .29551 L
.85442 .29549 L
.85444 .29548 L
.85445 .29547 L
.85446 .29546 L
.85448 .29545 L
.85449 .29546 L
.85451 .2955 L
.85454 .29559 L
.85457 .2957 L
.85458 .29574 L
.85459 .29577 L
.8546 .29582 L
.85463 .29601 L
.85474 .29689 L
.85485 .29817 L
.85497 .29988 L
.85508 .30162 L
.85533 .30555 L
.85545 .30708 L
.85551 .30777 L
.85557 .30832 L
.85562 .30876 L
.85564 .30886 L
.85565 .30891 L
.85566 .30894 L
.85568 .30905 L
.85571 .30915 L
.85574 .30927 L
.85575 .30934 L
.85577 .30936 L
.85578 .30935 L
.85579 .30931 L
.85582 .30929 L
.85583 .30928 L
.85584 .30927 L
.85585 .30926 L
.85585 .30927 L
.85587 .30929 L
.85588 .30929 L
.85589 .30927 L
.8559 .30917 L
.85591 .30906 L
.85597 .30876 L
.85603 .30836 L
.85609 .30775 L
.85615 .30713 L
Mistroke
.85628 .30535 L
.85652 .3016 L
.85673 .29835 L
.85679 .29763 L
.85685 .29694 L
.85691 .29641 L
.85694 .2962 L
.85697 .296 L
.857 .29584 L
.85703 .29569 L
.85705 .29561 L
.85705 .29558 L
.85706 .29556 L
.85707 .29555 L
.85708 .29554 L
.8571 .29551 L
.85711 .2955 L
.85712 .29549 L
.85713 .29548 L
.85714 .29547 L
.85716 .29547 L
.85717 .2955 L
.85719 .29554 L
.85722 .29561 L
.85723 .29566 L
.85725 .2957 L
.85726 .29576 L
.85727 .29584 L
.85733 .29623 L
.8574 .29678 L
.85746 .29738 L
.85768 .30045 L
.8579 .30396 L
.85803 .30583 L
.85814 .30729 L
.8582 .30789 L
.85826 .30837 L
.85829 .30857 L
.85832 .30876 L
.85834 .30885 L
.85835 .30894 L
.85837 .30899 L
.85838 .30901 L
.85841 .30908 L
.85844 .30912 L
.85845 .30915 L
.85846 .30917 L
.85848 .30918 L
.85849 .30915 L
.85849 .30912 L
Mistroke
.85851 .30905 L
.85853 .30902 L
.85854 .30897 L
.85856 .30893 L
.85857 .30892 L
.85859 .3089 L
.8586 .30879 L
.85863 .30851 L
.85875 .30748 L
.85886 .30616 L
.85911 .30236 L
.85935 .29866 L
.85946 .29735 L
.85951 .29678 L
.85957 .29628 L
.8596 .29606 L
.85963 .29588 L
.85966 .29572 L
.85968 .29566 L
.85969 .29562 L
.85971 .29559 L
.85972 .29556 L
.85973 .29553 L
.85975 .29551 L
.85976 .29549 L
.85978 .29549 L
.85979 .2955 L
.85981 .29552 L
.85984 .29558 L
.85985 .29562 L
.85987 .29567 L
.85988 .29572 L
.8599 .2958 L
.85993 .29596 L
.86 .29644 L
.86006 .297 L
.86018 .29844 L
.86029 .30003 L
.86054 .30401 L
.86065 .30562 L
.86076 .30708 L
.86083 .30778 L
.86089 .30826 L
.8609 .30838 L
.86092 .30851 L
.86093 .30857 L
.86094 .3086 L
.86095 .30864 L
.86098 .30875 L
.86099 .30879 L
Mistroke
.86101 .30884 L
.86102 .30892 L
.86104 .309 L
.86105 .30904 L
.86107 .30898 L
.86108 .30893 L
.8611 .30891 L
.86111 .30889 L
.86113 .30887 L
.86114 .30887 L
.86116 .30891 L
.86117 .30891 L
.86118 .30883 L
.86124 .30839 L
.8613 .30796 L
.86137 .30731 L
.86149 .30585 L
.86172 .30234 L
.86197 .29853 L
.86209 .29704 L
.86216 .29641 L
.86219 .29615 L
.86222 .29596 L
.86225 .29581 L
.86228 .29569 L
.86229 .29563 L
.86231 .29559 L
.86232 .29558 L
.86232 .29556 L
.86234 .29554 L
.86235 .29553 L
.86236 .29553 L
.86237 .29552 L
.86239 .2955 L
.8624 .29551 L
.86241 .29554 L
.86243 .29559 L
.86246 .29568 L
.86248 .29573 L
.86249 .29578 L
.8625 .29582 L
.86251 .29587 L
.86253 .29598 L
.86259 .29638 L
.86264 .29692 L
.8627 .29748 L
.86295 .30107 L
.86317 .3046 L
.8633 .30634 L
.86336 .30706 L
Mistroke
.86342 .30762 L
.86348 .3081 L
.86349 .30822 L
.8635 .30832 L
.86352 .3084 L
.86353 .30845 L
.86356 .30857 L
.86358 .30862 L
.86359 .30867 L
.8636 .3087 L
.86361 .30875 L
.86362 .30883 L
.86363 .30885 L
.86364 .30883 L
.86365 .3088 L
.86366 .30877 L
.86366 .30875 L
.86367 .30874 L
.86368 .30873 L
.86369 .30872 L
.8637 .30871 L
.86371 .3087 L
.86372 .30869 L
.86374 .30873 L
.86374 .30874 L
.86375 .30872 L
.86376 .30865 L
.86377 .30856 L
.86379 .3084 L
.86382 .30823 L
.86383 .30814 L
.86384 .3081 L
.86385 .30807 L
.86387 .30797 L
.86388 .30779 L
.86391 .30751 L
.86403 .30616 L
.86414 .30461 L
.86439 .30062 L
.86451 .29885 L
.86463 .29729 L
.86468 .29675 L
.86474 .29629 L
.86476 .29616 L
.86477 .29605 L
.86478 .29597 L
.8648 .2959 L
.86483 .29576 L
.86486 .29564 L
.86487 .29559 L
Mistroke
.86488 .29556 L
.8649 .29555 L
.86491 .29554 L
.86493 .29553 L
.86494 .29553 L
.86496 .29551 L
.86497 .29551 L
.86498 .29552 L
.86498 .29554 L
.865 .2956 L
.86503 .29571 L
.86506 .29581 L
.86507 .29584 L
.86508 .29588 L
.86509 .29599 L
.86516 .29648 L
.86522 .29711 L
.86535 .29858 L
.86559 .30228 L
.8658 .30562 L
.86586 .30636 L
.86593 .30707 L
.86604 .30803 L
.86607 .30822 L
.86611 .30846 L
.86612 .30858 L
.86613 .3086 L
.86614 .3086 L
.86615 .30857 L
.86616 .30854 L
.86616 .30852 L
.86617 .30853 L
.86619 .30854 L
.8662 .30855 L
.86622 .30856 L
.86622 .30859 L
.86623 .30861 L
.86625 .30862 L
.86626 .30857 L
.86626 .30851 L
.86628 .30843 L
.86629 .30838 L
.86632 .30826 L
.86633 .30823 L
.86634 .3082 L
.86635 .30815 L
.86636 .3081 L
.86639 .30789 L
.86642 .30765 L
.86655 .30632 L
Mistroke
.86667 .3046 L
.86679 .30273 L
.86701 .29927 L
.86714 .2976 L
.8672 .29691 L
.86725 .29641 L
.86731 .296 L
.86734 .29585 L
.86737 .2957 L
.86738 .29561 L
.8674 .29557 L
.86741 .29556 L
.86741 .29556 L
.86743 .29554 L
.86745 .29552 L
.86746 .29551 L
.86748 .29549 L
.86749 .29548 L
.86751 .29551 L
.86752 .29556 L
.86755 .29567 L
.86757 .29572 L
.86759 .29577 L
.8676 .2958 L
.8676 .29585 L
.86762 .29598 L
.86768 .2964 L
.86774 .29699 L
.86786 .29844 L
.86797 .30006 L
.86822 .30404 L
.86834 .30567 L
.8684 .30646 L
.86846 .30708 L
.86852 .30756 L
.86854 .30777 L
.86856 .3079 L
.86858 .30801 L
.86859 .30808 L
.8686 .30812 L
.86863 .30821 L
.86864 .30825 L
.86866 .30829 L
.86867 .30833 L
.86868 .3084 L
.8687 .30845 L
.86871 .30842 L
.86872 .30837 L
.86873 .30835 L
.86874 .30834 L
Mistroke
.86875 .30833 L
.86877 .3083 L
.86878 .3083 L
.8688 .30832 L
.8688 .30832 L
.86881 .30828 L
.86883 .30816 L
.86886 .30793 L
.86889 .30775 L
.86891 .3077 L
.86892 .30762 L
.86894 .30745 L
.86895 .30726 L
.86898 .30694 L
.86901 .30667 L
.86904 .30637 L
.86907 .30588 L
.86911 .30542 L
.86917 .30451 L
.86942 .30054 L
.86953 .29889 L
.86965 .29733 L
.86971 .29673 L
.86977 .29624 L
.86978 .29613 L
.8698 .29601 L
.86981 .29593 L
.86983 .29587 L
.86985 .29575 L
.86988 .29564 L
.86989 .29561 L
.86989 .29557 L
.86991 .29555 L
.86992 .29554 L
.86994 .29552 L
.86995 .29551 L
.86997 .29551 L
.86998 .2955 L
.86999 .29551 L
.87001 .29555 L
.87002 .29559 L
.87006 .2957 L
.87007 .29575 L
.87008 .2958 L
.8701 .2959 L
.87012 .296 L
.87023 .29699 L
.87029 .29765 L
.87036 .29848 L
.87058 .3019 L
Mistroke
.87071 .30398 L
.87084 .30574 L
.87089 .30638 L
.87092 .30674 L
.87095 .30702 L
.87098 .30724 L
.87101 .3075 L
.87102 .30762 L
.87104 .30779 L
.87105 .3079 L
.87107 .30793 L
.87108 .30794 L
.8711 .30798 L
.87113 .30808 L
.87114 .30815 L
.87116 .30826 L
.87117 .30832 L
.87119 .30827 L
.8712 .3082 L
.87121 .30816 L
.87122 .30814 L
.87124 .30812 L
.87125 .3081 L
.87127 .3081 L
.87128 .30809 L
.87129 .308 L
.87135 .30764 L
.87142 .30713 L
.87154 .30587 L
.87176 .30261 L
.87201 .29871 L
.87213 .29718 L
.87219 .29654 L
.87223 .29625 L
.87225 .29612 L
.87226 .296 L
.87229 .29583 L
.87233 .29568 L
.87234 .29562 L
.87236 .29556 L
.87237 .29553 L
.87238 .29553 L
.87239 .29552 L
.8724 .29551 L
.87241 .2955 L
.87242 .2955 L
.87243 .2955 L
.87245 .2955 L
.87246 .29551 L
.87247 .29555 L
Mistroke
.8725 .29564 L
.87253 .29575 L
.87254 .2958 L
.87256 .29587 L
.87257 .29592 L
.87258 .29599 L
.87259 .2961 L
.87262 .29632 L
.87274 .29755 L
.87286 .2991 L
.87297 .30075 L
.87321 .30458 L
.87333 .30615 L
.87339 .30674 L
.87341 .30702 L
.87343 .30714 L
.87344 .30727 L
.87345 .30736 L
.87347 .30742 L
.87349 .30757 L
.87352 .30772 L
.87354 .30782 L
.87355 .30793 L
.87356 .30798 L
.87358 .30796 L
.87359 .30795 L
.87361 .30797 L
.87362 .30798 L
.87363 .308 L
.87365 .30803 L
.87366 .30807 L
.87367 .30804 L
.87369 .30796 L
.8737 .3079 L
.87371 .30786 L
.87374 .30777 L
.87376 .30774 L
.87377 .30772 L
.87377 .30768 L
.87379 .30754 L
.8738 .30741 L
.87383 .3072 L
.87389 .30668 L
.87395 .30604 L
.87401 .30527 L
.87413 .30346 L
.87436 .29991 L
.87448 .29817 L
.87459 .29682 L
.87465 .29627 L
Mistroke
.87469 .29602 L
.87472 .29582 L
.87474 .29574 L
.87475 .29566 L
.87477 .29561 L
.87478 .29557 L
.87481 .29552 L
.87483 .2955 L
.87484 .29548 L
.87486 .29548 L
.87487 .2955 L
.8749 .29555 L
.87491 .29558 L
.87493 .29561 L
.87494 .29566 L
.87496 .29573 L
.87499 .29591 L
.87501 .29601 L
.87502 .29609 L
.87504 .2962 L
.87505 .29633 L
.87508 .29661 L
.87514 .29725 L
.87521 .29807 L
.87533 .29985 L
.87557 .30365 L
.8757 .30543 L
.87577 .30624 L
.8758 .3066 L
.87582 .30678 L
.87583 .30687 L
.87583 .30695 L
.87585 .30705 L
.87586 .30712 L
.87589 .3073 L
.87591 .30739 L
.87592 .30748 L
.87593 .30755 L
.87594 .30764 L
.87595 .3078 L
.87596 .30785 L
.87597 .30786 L
.87599 .3078 L
.876 .30776 L
.87602 .30778 L
.87605 .30783 L
.87607 .3079 L
.87608 .30791 L
.87608 .30787 L
.8761 .30776 L
Mistroke
.87611 .30771 L
.87613 .30767 L
.87614 .30761 L
.87616 .30757 L
.87616 .30754 L
.87617 .30751 L
.87619 .3074 L
.8762 .3073 L
.87631 .30635 L
.87638 .30567 L
.87644 .30484 L
.87657 .30288 L
.87681 .299 L
.87692 .29753 L
.87698 .29685 L
.87704 .29633 L
.87711 .29586 L
.87714 .2957 L
.87715 .29562 L
.87717 .29556 L
.87718 .29553 L
.8772 .29551 L
.87723 .29548 L
.87724 .29547 L
.87726 .29545 L
.87726 .29544 L
.87727 .29545 L
.87729 .2955 L
.87732 .29559 L
.87734 .29565 L
.87735 .2957 L
.87737 .29575 L
.87738 .29581 L
.87738 .29586 L
.87741 .29607 L
.87752 .29707 L
.87765 .29861 L
.87778 .30059 L
.87801 .30431 L
.87808 .3052 L
.87815 .30603 L
.87818 .30633 L
.87821 .30668 L
.87822 .30676 L
.87822 .30684 L
.87823 .30689 L
.87824 .30694 L
.87827 .30711 L
.87829 .30721 L
.8783 .3073 L
Mistroke
.87832 .30743 L
.87833 .30758 L
.87835 .30767 L
.87836 .30766 L
.87838 .3076 L
.87839 .30758 L
.8784 .3076 L
.87842 .30761 L
.87843 .30762 L
.87844 .30767 L
.87846 .30771 L
.87847 .30764 L
.8785 .3075 L
.87853 .30738 L
.87855 .30732 L
.87856 .30727 L
.87857 .30721 L
.8786 .30698 L
.87863 .30674 L
.87875 .30556 L
.87887 .30384 L
.87899 .30207 L
.87912 .29997 L
.87924 .29818 L
.87935 .29683 L
.8794 .29633 L
.87942 .29619 L
.87944 .29604 L
.87945 .29594 L
.87947 .29587 L
.8795 .29571 L
.87953 .29555 L
.87954 .2955 L
.87955 .29548 L
.87955 .29547 L
.87956 .29547 L
.87957 .29547 L
.87958 .29546 L
.87959 .29544 L
.87961 .29544 L
.87962 .29541 L
.87964 .2954 L
.87965 .29544 L
.87968 .29556 L
.87971 .29567 L
.87973 .2957 L
.87974 .29579 L
.87976 .2959 L
.87977 .296 L
.87983 .29647 L
Mistroke
.87989 .29703 L
.87994 .2977 L
.88019 .30141 L
.88032 .30337 L
.88043 .30501 L
.88054 .30621 L
.88056 .30653 L
.88058 .30669 L
.88059 .30678 L
.88062 .3069 L
.88065 .30707 L
.88068 .30729 L
.88069 .30745 L
.88071 .30752 L
.88072 .30748 L
.88073 .30742 L
.88075 .3074 L
.88076 .30741 L
.88078 .30742 L
.88079 .30744 L
.8808 .30747 L
.88081 .3075 L
.88082 .30746 L
.88084 .30735 L
.88086 .30728 L
.88088 .30717 L
.8809 .30711 L
.88092 .30702 L
.88093 .30689 L
.88095 .30677 L
.88102 .30624 L
.88114 .30484 L
.88137 .30124 L
.88159 .29794 L
.8817 .29663 L
.88176 .29613 L
.88182 .29573 L
.88185 .29558 L
.88187 .29549 L
.88188 .29544 L
.88189 .29544 L
.8819 .29544 L
.88191 .29543 L
.88192 .29542 L
.88193 .29541 L
.88193 .29541 L
.88195 .2954 L
.88197 .29537 L
.88197 .29537 L
.88198 .2954 L
Mistroke
.88201 .29551 L
.88204 .29561 L
.88206 .29565 L
.88207 .29571 L
.88209 .29582 L
.8821 .29595 L
.88213 .29616 L
.8822 .29676 L
.88232 .2982 L
.88254 .30165 L
.88277 .30498 L
.88283 .3057 L
.88286 .30605 L
.88288 .30623 L
.88289 .3064 L
.8829 .30653 L
.88292 .30661 L
.88295 .30675 L
.88298 .30692 L
.88298 .30697 L
.88299 .30703 L
.88301 .30719 L
.88302 .30727 L
.88303 .30732 L
.88304 .30729 L
.88305 .30725 L
.88306 .30722 L
.88307 .30721 L
.88308 .30722 L
.88309 .30723 L
.8831 .30723 L
.88311 .30724 L
.88312 .30727 L
.88313 .30731 L
.88313 .30732 L
.88314 .30728 L
.88321 .30697 L
.88326 .30663 L
.88332 .30615 L
.88339 .30546 L
.88351 .30397 L
.88375 .30005 L
.88387 .29825 L
.88398 .29687 L
.88404 .29635 L
.88406 .2961 L
.88408 .29596 L
.88409 .29586 L
.88411 .2958 L
.88412 .29573 L
Mistroke
.88415 .29558 L
.88416 .29552 L
.88418 .29544 L
.88419 .2954 L
.8842 .2954 L
.88422 .29539 L
.88423 .29538 L
.88424 .29537 L
.88425 .29537 L
.88426 .29534 L
.88428 .29534 L
.88429 .29539 L
.88432 .2955 L
.88435 .29559 L
.88437 .29564 L
.88438 .29573 L
.88441 .29595 L
.88444 .29614 L
.88455 .29731 L
.88468 .29898 L
.8849 .30247 L
.88501 .30417 L
.88507 .30494 L
.88513 .30565 L
.88516 .30592 L
.88519 .30624 L
.88519 .30632 L
.8852 .30638 L
.88522 .30645 L
.88525 .30661 L
.88527 .30676 L
.88529 .30686 L
.8853 .30701 L
.88531 .30712 L
.88533 .30713 L
.88534 .30707 L
.88535 .30703 L
.88537 .30703 L
.88538 .30704 L
.88539 .30704 L
.88541 .30708 L
.88542 .30713 L
.88544 .30707 L
.88547 .3069 L
.8855 .30678 L
.88551 .30672 L
.88553 .30663 L
.88554 .30651 L
.88556 .30639 L
.88559 .30615 L
Mistroke
.8857 .30506 L
.88581 .3035 L
.88603 .29998 L
.88616 .29811 L
.88622 .29732 L
.88627 .29667 L
.88633 .29617 L
.88639 .29574 L
.88642 .2956 L
.88645 .29544 L
.88646 .29539 L
.88647 .29537 L
.88648 .29537 L
.8865 .29535 L
.88651 .29534 L
.88653 .29533 L
.88654 .2953 L
.88655 .2953 L
.88656 .29531 L
.88657 .29535 L
.88658 .29538 L
.88661 .2955 L
.88663 .29555 L
.88663 .29557 L
.88664 .29559 L
.88666 .29568 L
.88667 .2958 L
.8867 .29601 L
.88676 .29655 L
.88688 .29791 L
.887 .29976 L
.88726 .30373 L
.88732 .30452 L
.88738 .30529 L
.88743 .30586 L
.88749 .30632 L
.88751 .30643 L
.88753 .30657 L
.88754 .30662 L
.88754 .30666 L
.88755 .30667 L
.88756 .3067 L
.88759 .30679 L
.8876 .30682 L
.88761 .30685 L
.88762 .30694 L
.88764 .30696 L
.88765 .3069 L
.88766 .30687 L
.88767 .30686 L
Mistroke
.88769 .30684 L
.8877 .30682 L
.88771 .30683 L
.88773 .30685 L
.88774 .30676 L
.88778 .30652 L
.8878 .30636 L
.88786 .30594 L
.88792 .3054 L
.88798 .30458 L
.8882 .30129 L
.88832 .29933 L
.88845 .2975 L
.88856 .29629 L
.88859 .29604 L
.88863 .2958 L
.88866 .29563 L
.88868 .2955 L
.8887 .29545 L
.88871 .29539 L
.88873 .29535 L
.88874 .29535 L
.88874 .29534 L
.88876 .29533 L
.88877 .29532 L
.88879 .29532 L
.8888 .29532 L
.88881 .29534 L
.88882 .29537 L
.88883 .29539 L
.88886 .29548 L
.88887 .29553 L
.88888 .29556 L
.88889 .2956 L
.8889 .29565 L
.88891 .29571 L
.88892 .29582 L
.88903 .29676 L
.88909 .29748 L
.88915 .29821 L
.8894 .3021 L
.88951 .30375 L
.88957 .30453 L
.88963 .30529 L
.88969 .30585 L
.8897 .30598 L
.88972 .30614 L
.88973 .30625 L
.88974 .3063 L
.88977 .30641 L
Mistroke
.8898 .30654 L
.88982 .30673 L
.88984 .30682 L
.88985 .30679 L
.88987 .30672 L
.88988 .3067 L
.8899 .3067 L
.88991 .30669 L
.88992 .3067 L
.88993 .30673 L
.88994 .30674 L
.88994 .30672 L
.88996 .30661 L
.88997 .30653 L
.89 .30639 L
.89002 .30632 L
.89003 .30624 L
.89006 .30602 L
.89009 .30579 L
.8902 .30462 L
.89032 .30288 L
.89054 .29939 L
.89067 .29756 L
.89073 .29682 L
.89079 .29626 L
.89081 .29602 L
.89083 .2959 L
.89084 .29581 L
.89085 .29574 L
.89087 .29567 L
.89089 .29553 L
.89091 .29545 L
.89092 .29537 L
.89093 .29535 L
.89094 .29534 L
.89095 .29533 L
.89097 .29531 L
.89098 .2953 L
.891 .29528 L
.89101 .29526 L
.89103 .29528 L
.89104 .29533 L
.89107 .29541 L
.89108 .29546 L
.8911 .2955 L
.8911 .29552 L
.89111 .29557 L
.89113 .29568 L
.89124 .29658 L
.8913 .29725 L
Mistroke
.89137 .29813 L
.89149 .29996 L
.89172 .30364 L
.89179 .3045 L
.89186 .30528 L
.89189 .3056 L
.89191 .30577 L
.89192 .30593 L
.89193 .30603 L
.89195 .30608 L
.89196 .30615 L
.89198 .30624 L
.892 .30632 L
.892 .30638 L
.89201 .30645 L
.89203 .30654 L
.89204 .30653 L
.89205 .30651 L
.89207 .30652 L
.89208 .30653 L
.8921 .30655 L
.89211 .3066 L
.89212 .30663 L
.89213 .30661 L
.89214 .30656 L
.89215 .3065 L
.89216 .30645 L
.89217 .30641 L
.89218 .30636 L
.89219 .30631 L
.89221 .30628 L
.89222 .30627 L
.89223 .30624 L
.89224 .30609 L
.89226 .30594 L
.89228 .30572 L
.89231 .30555 L
.89232 .30546 L
.89234 .3053 L
.89235 .30507 L
.89237 .3049 L
.89239 .30458 L
.89246 .30376 L
.89268 .30035 L
.8928 .29841 L
.89286 .29756 L
.89292 .29687 L
.89297 .29631 L
.89303 .29582 L
.89307 .2956 L
Mistroke
.89308 .29551 L
.89309 .29548 L
.8931 .29545 L
.89313 .29536 L
.89314 .29532 L
.89315 .29529 L
.89316 .29527 L
.89317 .29525 L
.89317 .29525 L
.89319 .29526 L
.89321 .29527 L
.89321 .29528 L
.89322 .29529 L
.89324 .2953 L
.89325 .29533 L
.89327 .29539 L
.89328 .29545 L
.89331 .29561 L
.89335 .29583 L
.89341 .29634 L
.89347 .29704 L
.89353 .29778 L
.89367 .29974 L
.89391 .3035 L
.89397 .30432 L
.89403 .30508 L
.89409 .30562 L
.89412 .30586 L
.89414 .30598 L
.89415 .30608 L
.89417 .30615 L
.89418 .30618 L
.89421 .30628 L
.89423 .30633 L
.89423 .30636 L
.89424 .30641 L
.89426 .30647 L
.89427 .30643 L
.89428 .30639 L
.8943 .30637 L
.89431 .30636 L
.89432 .30634 L
.89433 .30635 L
.89435 .30638 L
.89436 .3063 L
.89438 .30616 L
.89488 .29987 L
.895 .29803 L
.89507 .29716 L
.89513 .29646 L
Mistroke
.89518 .29598 L
.89521 .29577 L
.89524 .29559 L
.89527 .29544 L
.89528 .29538 L
.8953 .29531 L
.89531 .29529 L
.89533 .29527 L
.89534 .29526 L
.89536 .29525 L
.89537 .29524 L
.89538 .29525 L
.8954 .29529 L
.89541 .29532 L
.89543 .29537 L
.89545 .29542 L
.89546 .29547 L
.89547 .29555 L
.89558 .29636 L
.89564 .29701 L
.89571 .29782 L
.89582 .29954 L
.89606 .30325 L
.89616 .3046 L
.89622 .30518 L
.89627 .30568 L
.89631 .30588 L
.89634 .30605 L
.89635 .30612 L
.89637 .30615 L
.89639 .30621 L
.89642 .30627 L
.89644 .30631 L
.89645 .3063 L
.89645 .30627 L
.89648 .30618 L
.89649 .30615 L
.89651 .30612 L
.89652 .30612 L
.89653 .3061 L
.89654 .30604 L
.89657 .3058 L
.8966 .30559 L
.89664 .30533 L
.8967 .30467 L
.89676 .3039 L
.897 .30033 L
.89712 .29836 L
.89719 .29741 L
.89725 .29664 L
Mistroke
.89732 .29604 L
.89735 .29577 L
.89736 .29567 L
.89738 .29557 L
.8974 .29549 L
.89741 .29541 L
.89743 .29534 L
.89744 .29531 L
.89747 .29526 L
.89749 .29524 L
.8975 .29521 L
.89752 .29523 L
.89753 .29525 L
.89756 .2953 L
.89757 .29533 L
.89759 .29538 L
.89759 .29542 L
.8976 .29547 L
.89762 .29555 L
.89768 .29593 L
.89773 .2964 L
.89786 .29794 L
.89797 .29972 L
.8982 .30321 L
.89831 .30467 L
.89837 .30528 L
.89841 .30551 L
.89842 .30561 L
.89844 .30575 L
.89845 .30586 L
.89847 .30589 L
.89849 .30596 L
.89851 .30601 L
.89852 .30608 L
.89854 .30613 L
.89855 .30612 L
.89856 .30609 L
.89858 .30607 L
.89859 .30606 L
.8986 .30605 L
.89862 .30606 L
.89863 .30604 L
.89864 .30595 L
.89866 .30586 L
.89869 .30571 L
.8987 .30566 L
.89872 .3056 L
.89873 .30547 L
.89875 .30531 L
.89878 .30502 L
Mistroke
.89889 .3038 L
.89914 .29993 L
.89925 .29825 L
.89936 .29672 L
.8994 .29635 L
.89943 .29603 L
.89946 .29579 L
.89949 .29559 L
.89951 .29549 L
.89952 .29542 L
.89953 .29537 L
.89955 .29533 L
.89958 .29524 L
.8996 .29519 L
.89961 .29518 L
.89963 .2952 L
.89964 .29521 L
.89967 .29526 L
.89968 .29527 L
.89969 .29529 L
.8997 .29536 L
.89974 .29553 L
.89979 .29591 L
.89986 .29648 L
.89997 .29789 L
.90008 .2995 L
.9003 .303 L
.90036 .30385 L
.90043 .30462 L
.90049 .30513 L
.90055 .30557 L
.90058 .30574 L
.9006 .30584 L
.90061 .30588 L
.90062 .30588 L
.90063 .30588 L
.90064 .3059 L
.90064 .30591 L
.90065 .30592 L
.90066 .30594 L
.90067 .30595 L
.90068 .30597 L
.90069 .30594 L
.90071 .30589 L
.90074 .30581 L
.90076 .30579 L
.90077 .30572 L
.90078 .30566 L
.90079 .3056 L
.9008 .30551 L
Mistroke
.90086 .30507 L
.90093 .30445 L
.90104 .30289 L
.90128 .29918 L
.90138 .29766 L
.90144 .29691 L
.9015 .29631 L
.90155 .29584 L
.90158 .29563 L
.90161 .29547 L
.90163 .29539 L
.90164 .29533 L
.90166 .29526 L
.90167 .29523 L
.90169 .29522 L
.9017 .29521 L
.90171 .2952 L
.90173 .29519 L
.90174 .29519 L
.90175 .2952 L
.90176 .29524 L
.9018 .29535 L
.9018 .29538 L
.90181 .29541 L
.90182 .29544 L
.90183 .29548 L
.90186 .29569 L
.90192 .29614 L
.90198 .29677 L
.9021 .29834 L
.90221 .30002 L
.90233 .30207 L
.90245 .30376 L
.90251 .30444 L
.90258 .30505 L
.90261 .3053 L
.90262 .30543 L
.90263 .30549 L
.90264 .30552 L
.90266 .30558 L
.90268 .30565 L
.90268 .30568 L
.90269 .30571 L
.9027 .30575 L
.90271 .3058 L
.90272 .30588 L
.90273 .30587 L
.90274 .30584 L
.90276 .30579 L
.90277 .30578 L
Mistroke
.90278 .30578 L
.90279 .30577 L
.9028 .30579 L
.90281 .30582 L
.90282 .30583 L
.90282 .30579 L
.90283 .30571 L
.90295 .30486 L
.90301 .30422 L
.90307 .30347 L
.90321 .30148 L
.90333 .29947 L
.90345 .29772 L
.90356 .29638 L
.90362 .29583 L
.90368 .29547 L
.90369 .29539 L
.9037 .29535 L
.90371 .29531 L
.90372 .29526 L
.90374 .29524 L
.90377 .29518 L
.90378 .29517 L
.90379 .29516 L
.9038 .29516 L
.9038 .29517 L
.90383 .29524 L
.90385 .29528 L
.90387 .29531 L
.90388 .29538 L
.9039 .29548 L
.90393 .29564 L
.90398 .29611 L
.90404 .29665 L
.90416 .29831 L
.90442 .30226 L
.90454 .30397 L
.9046 .30463 L
.90466 .30511 L
.90469 .30528 L
.90471 .30544 L
.90473 .30551 L
.90474 .30555 L
.90477 .30561 L
.9048 .30568 L
.90481 .30573 L
.90482 .30572 L
.90483 .30569 L
.90486 .30561 L
.90487 .30557 L
Mistroke
.90488 .30556 L
.9049 .30556 L
.90491 .30548 L
.90494 .30524 L
.90497 .30505 L
.905 .30482 L
.90506 .30425 L
.90511 .30354 L
.90536 .29975 L
.90547 .29805 L
.90559 .29653 L
.90566 .29588 L
.90572 .29546 L
.90574 .29538 L
.90575 .2953 L
.90576 .29528 L
.90577 .29526 L
.90578 .29522 L
.9058 .29519 L
.90581 .29515 L
.90583 .29514 L
.90584 .29515 L
.90586 .29516 L
.90587 .29519 L
.90588 .2952 L
.9059 .29524 L
.90591 .29531 L
.90593 .29537 L
.90594 .29545 L
.90596 .29553 L
.90597 .29562 L
.90599 .29572 L
.90601 .29593 L
.90607 .29648 L
.9062 .29811 L
.90632 .29999 L
.90654 .30333 L
.9066 .30406 L
.90667 .3047 L
.9067 .30498 L
.90671 .30512 L
.90673 .30519 L
.90674 .30523 L
.90675 .30528 L
.90677 .30535 L
.90678 .30541 L
.9068 .3055 L
.90681 .3056 L
.90683 .30558 L
.90684 .30551 L
Mistroke
.90685 .3055 L
.90687 .30549 L
.90688 .30549 L
.9069 .30552 L
.9069 .30551 L
.90691 .30545 L
.90693 .30535 L
.90694 .30531 L
.90694 .30528 L
.90696 .30519 L
.90698 .30513 L
.90699 .30503 L
.90701 .30489 L
.90702 .30477 L
.90714 .30353 L
.90721 .30257 L
.90727 .30159 L
.9075 .29804 L
.90756 .29719 L
.90763 .2964 L
.90768 .29589 L
.90774 .29545 L
.90776 .29536 L
.90778 .29527 L
.90779 .2952 L
.9078 .29518 L
.90781 .29518 L
.90782 .29515 L
.90784 .29513 L
.90785 .29512 L
.90786 .2951 L
.90787 .29509 L
.90788 .29509 L
.90788 .29512 L
.90789 .29514 L
.90791 .29518 L
.90793 .29523 L
.90793 .29525 L
.90794 .29526 L
.90796 .29532 L
.90796 .29537 L
.90797 .29543 L
.908 .29562 L
.90806 .29606 L
.90812 .29666 L
.90818 .2975 L
.90824 .29839 L
.90848 .30211 L
.90861 .3038 L
.90864 .30418 L
Mistroke
.90866 .30437 L
.90868 .30456 L
.90869 .30469 L
.90871 .30478 L
.90874 .30497 L
.90877 .30518 L
.90878 .30527 L
.90878 .30536 L
.9088 .30541 L
.90882 .30534 L
.90883 .30532 L
.90884 .30533 L
.90886 .30534 L
.90887 .30539 L
.90888 .30543 L
.90889 .30543 L
.9089 .30532 L
.90892 .30526 L
.90895 .30515 L
.90896 .30511 L
.90897 .30507 L
.90898 .30502 L
.90899 .30496 L
.90904 .30454 L
.9091 .30401 L
.90922 .30254 L
.90945 .2988 L
.90958 .29703 L
.90964 .29623 L
.90968 .29592 L
.90969 .29578 L
.9097 .2957 L
.90971 .29563 L
.90972 .29554 L
.90974 .29546 L
.90977 .29528 L
.90978 .29522 L
.90979 .29517 L
.9098 .29514 L
.9098 .29513 L
.90982 .29512 L
.90983 .2951 L
.90984 .29509 L
.90985 .29507 L
.90987 .29503 L
.90987 .29502 L
.90988 .29504 L
.9099 .29509 L
.90993 .29517 L
.90994 .2952 L
Mistroke
.90995 .29523 L
.90997 .29532 L
.90998 .29543 L
.91001 .29561 L
.91006 .29605 L
.91018 .29743 L
.91041 .30091 L
.91053 .30271 L
.91059 .30355 L
.91065 .3042 L
.91072 .30473 L
.91072 .3048 L
.91073 .30488 L
.91074 .30492 L
.91075 .30494 L
.91077 .30501 L
.91079 .30507 L
.9108 .30513 L
.91081 .30522 L
.91082 .30526 L
.91083 .30526 L
.91085 .30521 L
.91086 .30519 L
.91087 .30518 L
.91088 .30518 L
.91089 .30518 L
.9109 .3052 L
.91091 .30522 L
.91092 .30514 L
.91093 .30507 L
.91094 .305 L
.91096 .30493 L
.91097 .30485 L
.91103 .30438 L
.91106 .30412 L
.91108 .30402 L
.91109 .30391 L
.91111 .30369 L
.91112 .30345 L
.91115 .30309 L
.91138 .29965 L
.9115 .29782 L
.91162 .29623 L
.91169 .29565 L
.91172 .2954 L
.91176 .29523 L
.91176 .29519 L
.91177 .29514 L
.91179 .2951 L
.9118 .29508 L
Mistroke
.91182 .29506 L
.91183 .29504 L
.91185 .29501 L
.91186 .29503 L
.91187 .29505 L
.91188 .29507 L
.91191 .29514 L
.91192 .29516 L
.91193 .2952 L
.91194 .29525 L
.91195 .29529 L
.91198 .29547 L
.91201 .29568 L
.91207 .29623 L
.91212 .2969 L
.91236 .3004 L
.91248 .30231 L
.91255 .30323 L
.91262 .30396 L
.91268 .3045 L
.91271 .30471 L
.91272 .30477 L
.91273 .30483 L
.91274 .30488 L
.91274 .30491 L
.91277 .30498 L
.91279 .30502 L
.9128 .30504 L
.9128 .30508 L
.91282 .30513 L
.91283 .3051 L
.91286 .30502 L
.91287 .30499 L
.91289 .305 L
.9129 .30501 L
.91291 .30498 L
.91292 .30484 L
.91294 .30474 L
.91295 .30464 L
.91297 .30456 L
.91298 .30453 L
.91299 .30442 L
.91301 .30422 L
.91304 .30394 L
.91309 .30339 L
.91332 .30007 L
.91343 .29817 L
.91356 .29648 L
.91362 .29583 L
.91366 .29555 L
Mistroke
.91369 .29532 L
.9137 .29527 L
.91371 .29522 L
.91372 .29518 L
.91373 .29516 L
.91376 .29507 L
.91377 .29503 L
.91379 .295 L
.9138 .29501 L
.91381 .29501 L
.91382 .29501 L
.91383 .29503 L
.91385 .29504 L
.91386 .29508 L
.91387 .29512 L
.91388 .29515 L
.91391 .29528 L
.91393 .29542 L
.91396 .29566 L
.914 .29593 L
.91406 .29658 L
.9143 .30018 L
.91442 .30204 L
.91453 .30346 L
.91459 .30402 L
.91462 .30427 L
.91463 .30443 L
.91465 .30454 L
.91466 .30458 L
.91467 .30464 L
.91469 .30471 L
.9147 .30477 L
.91471 .30486 L
.91473 .30497 L
.91474 .30498 L
.91475 .30493 L
.91477 .30491 L
.91478 .30491 L
.91479 .3049 L
.91481 .30494 L
.91482 .305 L
.91484 .30493 L
.91487 .30469 L
.9149 .30456 L
.9149 .30454 L
.91491 .30448 L
.91492 .30438 L
.91493 .3043 L
.91499 .30378 L
.91511 .3022 L
Mistroke
.91523 .30037 L
.91546 .29699 L
.91552 .29627 L
.91558 .29567 L
.91563 .29532 L
.91564 .29523 L
.91566 .29513 L
.91567 .29509 L
.91569 .29506 L
.91572 .29499 L
.91573 .29495 L
.91574 .29494 L
.91575 .29496 L
.91578 .29502 L
.9158 .29504 L
.91581 .29505 L
.91582 .29508 L
.91583 .29517 L
.91585 .29525 L
.91587 .2954 L
.91588 .29544 L
.91589 .29549 L
.91591 .29563 L
.91594 .29592 L
.91605 .29727 L
.91618 .29912 L
.9164 .30252 L
.91651 .30384 L
.91655 .30413 L
.91655 .30421 L
.91656 .30429 L
.91658 .30438 L
.9166 .30451 L
.91664 .30467 L
.91665 .30478 L
.91666 .3048 L
.91667 .30478 L
.91668 .30476 L
.91669 .30476 L
.91671 .30477 L
.91672 .3048 L
.91674 .30486 L
.91675 .30483 L
.91676 .3047 L
.91678 .30463 L
.91679 .30457 L
.9168 .30451 L
.91682 .30451 L
.91683 .3045 L
.91684 .30439 L
Mistroke
.91686 .3042 L
.91709 .30133 L
.91722 .29936 L
.91735 .29732 L
.91742 .29647 L
.91748 .29582 L
.91754 .29537 L
.91755 .29528 L
.91757 .29517 L
.91758 .29511 L
.9176 .29506 L
.91761 .29502 L
.91763 .29498 L
.91764 .29494 L
.91765 .29493 L
.91766 .29494 L
.91767 .29494 L
.91769 .29496 L
.9177 .29498 L
.91772 .29499 L
.91773 .29504 L
.91774 .29511 L
.91777 .29525 L
.91779 .29531 L
.9178 .29539 L
.91781 .29551 L
.91783 .29562 L
.91795 .29692 L
.91808 .29887 L
.9182 .30071 L
.91832 .30257 L
.91838 .3033 L
.91845 .30393 L
.91848 .30415 L
.91849 .30426 L
.91851 .30437 L
.91852 .30444 L
.91853 .30448 L
.91856 .30457 L
.91857 .30459 L
.91858 .30462 L
.91859 .30467 L
.9186 .30471 L
.9186 .30471 L
.91861 .30467 L
.91862 .30464 L
.91863 .30463 L
.91865 .30461 L
.91866 .3046 L
.91867 .30462 L
Mistroke
.91868 .30463 L
.91869 .3046 L
.9187 .30452 L
.91873 .30431 L
.91873 .30427 L
.91874 .30422 L
.91876 .30419 L
.91877 .30409 L
.91878 .30391 L
.91882 .3036 L
.91904 .30056 L
.91916 .29866 L
.91928 .29684 L
.91935 .2961 L
.91938 .29575 L
.91942 .29547 L
.91944 .29534 L
.91944 .29528 L
.91945 .29523 L
.91947 .29516 L
.91948 .29509 L
.91951 .29498 L
.91953 .29493 L
.91953 .29492 L
.91954 .29492 L
.91956 .29491 L
.91957 .29491 L
.91958 .29491 L
.91959 .2949 L
.9196 .29493 L
.91962 .29499 L
.91963 .29503 L
.91964 .29508 L
.91966 .29512 L
.91967 .29521 L
.91969 .29532 L
.91972 .29552 L
.91978 .29614 L
.9199 .2977 L
.92002 .29941 L
.92015 .30146 L
.92021 .30236 L
.92027 .30307 L
.92032 .30361 L
.92038 .30407 L
.92041 .30426 L
.92042 .30436 L
.92044 .30443 L
.92045 .30443 L
.92047 .30446 L
Mistroke
.92048 .30449 L
.92049 .30452 L
.92051 .30458 L
.92052 .30456 L
.92053 .30452 L
.92054 .30446 L
.92055 .30444 L
.92056 .30442 L
.92057 .30439 L
.92059 .3044 L
.9206 .30433 L
.92062 .30418 L
.92065 .30395 L
.92066 .30391 L
.92067 .30388 L
.92068 .30373 L
.92071 .30339 L
.92074 .30309 L
.92077 .30272 L
.9208 .30236 L
.92086 .30151 L
.92098 .2996 L
.92109 .29794 L
.9212 .29637 L
.92127 .29569 L
.9213 .29543 L
.92133 .29523 L
.92135 .29509 L
.92137 .29501 L
.92138 .29495 L
.92139 .29493 L
.9214 .29492 L
.92142 .29489 L
.92143 .29487 L
.92144 .29485 L
.92146 .29487 L
.92147 .29489 L
.9215 .29495 L
.92152 .29499 L
.92152 .29503 L
.92153 .29507 L
.92156 .29523 L
.92162 .29564 L
.92167 .29615 L
.92179 .29768 L
.92191 .29962 L
.92203 .30144 L
.92213 .30288 L
.92216 .30317 L
.92219 .3035 L
Mistroke
.92221 .30367 L
.92222 .30376 L
.92225 .30392 L
.92228 .30416 L
.92229 .30424 L
.9223 .30427 L
.92231 .30426 L
.92233 .30428 L
.92234 .30432 L
.92235 .30436 L
.92236 .30441 L
.92237 .30445 L
.92238 .30442 L
.9224 .30435 L
.92241 .30431 L
.92242 .30428 L
.92244 .30427 L
.92245 .30428 L
.92246 .30424 L
.92248 .3041 L
.92249 .304 L
.9225 .3039 L
.92252 .30382 L
.92253 .30378 L
.92255 .30367 L
.92256 .30347 L
.92259 .30314 L
.92265 .30238 L
.92271 .30165 L
.92285 .29949 L
.92296 .29766 L
.92309 .29605 L
.92312 .29573 L
.92315 .29544 L
.92318 .29523 L
.92321 .29505 L
.92324 .29494 L
.92326 .29488 L
.92326 .29485 L
.92327 .29484 L
.92329 .29484 L
.9233 .29483 L
.92331 .29483 L
.92333 .29483 L
.92334 .29484 L
.92335 .29489 L
.92338 .29499 L
.9234 .29504 L
.92341 .29511 L
.92343 .29522 L
Mistroke
.92344 .29532 L
.92355 .29632 L
.92361 .29709 L
.92366 .29789 L
.92378 .29981 L
.92389 .30148 L
.92401 .30294 L
.92406 .30351 L
.92409 .30372 L
.9241 .30379 L
.92411 .30385 L
.92413 .30405 L
.92414 .30421 L
.92415 .30419 L
.92417 .30412 L
.92418 .30414 L
.9242 .30417 L
.92421 .30421 L
.92422 .3043 L
.92424 .30428 L
.92425 .30419 L
.92426 .30416 L
.92427 .30415 L
.92428 .30411 L
.9243 .30407 L
.92431 .30401 L
.92433 .30391 L
.92436 .30375 L
.92442 .30318 L
.92449 .30248 L
.92473 .29881 L
.92485 .297 L
.92496 .29572 L
.92501 .29524 L
.92504 .29508 L
.92506 .29498 L
.92507 .29488 L
.92508 .29483 L
.9251 .29482 L
.92511 .29479 L
.92513 .29477 L
.92514 .29474 L
.92515 .2947 L
.92516 .29473 L
.92518 .29478 L
.9252 .29484 L
.92522 .29486 L
.92524 .29492 L
.92525 .29502 L
.92526 .29512 L
Mistroke
.92529 .29528 L
.92531 .2954 L
.92532 .29557 L
.92535 .29586 L
.92541 .29654 L
.92565 .30009 L
.92577 .30194 L
.92584 .30278 L
.92587 .30318 L
.92591 .30344 L
.92597 .30388 L
.92598 .30399 L
.92598 .30409 L
.926 .30407 L
.92601 .30402 L
.92602 .30399 L
.92603 .304 L
.92603 .30401 L
.92605 .30403 L
.92606 .3041 L
.92608 .30413 L
.92609 .30404 L
.92611 .30397 L
.92611 .30394 L
.92612 .30392 L
.92614 .30387 L
.92615 .30381 L
.92617 .30372 L
.92618 .30364 L
.92621 .30346 L
.92626 .30293 L
.92638 .30152 L
.9265 .2996 L
.92663 .29758 L
.92674 .29611 L
.9268 .29548 L
.92682 .29535 L
.92683 .2952 L
.92685 .29511 L
.92686 .29503 L
.92689 .29487 L
.9269 .29477 L
.92692 .29474 L
.92693 .29473 L
.92694 .29472 L
.92695 .29471 L
.92696 .29469 L
.92698 .29464 L
.92699 .29466 L
.927 .29471 L
Mistroke
.92702 .29474 L
.92703 .29478 L
.92704 .29481 L
.92706 .29483 L
.92707 .29491 L
.92708 .29501 L
.92711 .29519 L
.92712 .29527 L
.92714 .29537 L
.92715 .29554 L
.92717 .2957 L
.9272 .29598 L
.92726 .29679 L
.92732 .29766 L
.92755 .30116 L
.92761 .30201 L
.92767 .30278 L
.92773 .30329 L
.92774 .3034 L
.92776 .30355 L
.92777 .30365 L
.92779 .30369 L
.9278 .30372 L
.92781 .30375 L
.92782 .30381 L
.92784 .30391 L
.92785 .30396 L
.92786 .30393 L
.92787 .3039 L
.92788 .30388 L
.92789 .30388 L
.9279 .30387 L
.92791 .30387 L
.92791 .30389 L
.92792 .30392 L
.92794 .30387 L
.92795 .30373 L
.92796 .30369 L
.92797 .30365 L
.92799 .30356 L
.928 .30354 L
.92801 .30352 L
.92802 .30344 L
.92805 .3031 L
.92829 .29991 L
.92841 .29802 L
.92847 .29704 L
.92853 .29623 L
.92859 .2956 L
.92862 .29532 L
Mistroke
.92865 .29507 L
.92868 .29492 L
.9287 .29484 L
.92871 .29477 L
.92872 .29471 L
.92874 .29469 L
.92876 .29466 L
.92878 .29464 L
.92879 .29463 L
.92881 .29467 L
.92882 .2947 L
.92883 .29473 L
.92885 .29477 L
.92886 .29483 L
.92888 .29491 L
.92894 .29534 L
.929 .29592 L
.9291 .2973 L
.92922 .29911 L
.92935 .30107 L
.92941 .30193 L
.92947 .3026 L
.92952 .3031 L
.92954 .3033 L
.92956 .3034 L
.92957 .3035 L
.92959 .30359 L
.9296 .30362 L
.92963 .3037 L
.92964 .30375 L
.92966 .30383 L
.92967 .30383 L
.92967 .3038 L
.92969 .30376 L
.92972 .30372 L
.92973 .30375 L
.92975 .30369 L
.92976 .30356 L
.92978 .30347 L
.92978 .30342 L
.92979 .30338 L
.92981 .30334 L
.92982 .30324 L
.92984 .30305 L
.92987 .30276 L
.92992 .30216 L
.93017 .29842 L
.93028 .29673 L
.93034 .29595 L
.9304 .29537 L
Mistroke
.93046 .29491 L
.93048 .29481 L
.93049 .29476 L
.9305 .29474 L
.93051 .29472 L
.93052 .29469 L
.93053 .29465 L
.93055 .29461 L
.93056 .2946 L
.93058 .29461 L
.93059 .29463 L
.9306 .29464 L
.93061 .29464 L
.93062 .29468 L
.93064 .29475 L
.93065 .29481 L
.93067 .29488 L
.93068 .29492 L
.93068 .29496 L
.9307 .29508 L
.93071 .29519 L
.93078 .29581 L
.9309 .29736 L
.93112 .30085 L
.93118 .3017 L
.93125 .30248 L
.93128 .30279 L
.93131 .30305 L
.93132 .30317 L
.93134 .30329 L
.93135 .30335 L
.93137 .30341 L
.93139 .30354 L
.93141 .30362 L
.93142 .30361 L
.93143 .30361 L
.93145 .30362 L
.93146 .30364 L
.93147 .30367 L
.93149 .30363 L
.9315 .30356 L
.93151 .30352 L
.93153 .30348 L
.93154 .30345 L
.93155 .30341 L
.93156 .30334 L
.93159 .30312 L
.93171 .30192 L
.93182 .30037 L
.93195 .29832 L
Mistroke
.93207 .29654 L
.93212 .29582 L
.93219 .29522 L
.93222 .29499 L
.93223 .29489 L
.93224 .29483 L
.93225 .29477 L
.93226 .29473 L
.93227 .2947 L
.93228 .29466 L
.9323 .29462 L
.93231 .29458 L
.93233 .29455 L
.93234 .29456 L
.93236 .29458 L
.93237 .2946 L
.93239 .29462 L
.93239 .29463 L
.9324 .29465 L
.93242 .29473 L
.93243 .29481 L
.93249 .29517 L
.93254 .29562 L
.9326 .29632 L
.93266 .29717 L
.93277 .29888 L
.93289 .30076 L
.93296 .30168 L
.93302 .30242 L
.93308 .30295 L
.93311 .30317 L
.93312 .30325 L
.93313 .30335 L
.93313 .3034 L
.93314 .3034 L
.93316 .30339 L
.93317 .30343 L
.93318 .30347 L
.93319 .3035 L
.9332 .30355 L
.93321 .30358 L
.93323 .30351 L
.93324 .30347 L
.93325 .30345 L
.93327 .30343 L
.93328 .30344 L
.9333 .30337 L
.93331 .30325 L
.93332 .30317 L
.93333 .3031 L
Mistroke
.93335 .30303 L
.93336 .30298 L
.93337 .30284 L
.93339 .30268 L
.93342 .30237 L
.93347 .30171 L
.93371 .29806 L
.93384 .29624 L
.9339 .29551 L
.93394 .29517 L
.93397 .29492 L
.93399 .29481 L
.934 .29477 L
.93401 .29473 L
.93404 .29461 L
.93405 .29455 L
.93406 .29453 L
.93407 .29453 L
.93408 .29453 L
.93409 .29452 L
.9341 .29452 L
.9341 .29452 L
.93412 .29452 L
.93413 .29456 L
.93416 .29465 L
.93417 .29468 L
.93418 .29471 L
.93419 .29475 L
.9342 .2948 L
.93423 .29501 L
.93428 .29546 L
.93434 .29612 L
.93446 .29778 L
.93459 .29984 L
.93471 .30163 L
.93476 .30227 L
.93482 .3028 L
.93483 .30295 L
.93485 .30303 L
.93486 .30305 L
.93487 .30309 L
.93488 .30317 L
.9349 .30324 L
.93491 .30337 L
.93493 .30343 L
.93494 .30336 L
.93496 .30335 L
.93497 .30335 L
.93498 .30337 L
.935 .30341 L
Mistroke
.93501 .30331 L
.93503 .30323 L
.93506 .30313 L
.93507 .30306 L
.93509 .30293 L
.93511 .30272 L
.93517 .30221 L
.93529 .30057 L
.93541 .29877 L
.93553 .29689 L
.93559 .29609 L
.93564 .29547 L
.93571 .29492 L
.93574 .29471 L
.93575 .29465 L
.93576 .2946 L
.93577 .29458 L
.93578 .29456 L
.93579 .29452 L
.93581 .29448 L
.93582 .29444 L
.93584 .29446 L
.93587 .29451 L
.93588 .29453 L
.9359 .29455 L
.93591 .29463 L
.93592 .29471 L
.93595 .29486 L
.93597 .29495 L
.93598 .29509 L
.93601 .29537 L
.93612 .29666 L
.93637 .30047 L
.93648 .30195 L
.93651 .30226 L
.93652 .30245 L
.93654 .30257 L
.93654 .30261 L
.93655 .30266 L
.93657 .30277 L
.9366 .30301 L
.93661 .3031 L
.93662 .30314 L
.93663 .30312 L
.93664 .30313 L
.93665 .30315 L
.93667 .3032 L
.93668 .3033 L
.9367 .30329 L
.93671 .30321 L
Mistroke
.93672 .3032 L
.93673 .30318 L
.93674 .30316 L
.93675 .30316 L
.93676 .30317 L
.93678 .30307 L
.93679 .30294 L
.93682 .30278 L
.93683 .30272 L
.93685 .3026 L
.93686 .3024 L
.93688 .30226 L
.93689 .30211 L
.93691 .302 L
.93692 .30187 L
.93694 .30163 L
.93696 .30129 L
.93708 .29951 L
.9372 .29767 L
.9373 .29616 L
.93736 .29546 L
.93742 .29497 L
.93743 .29486 L
.93745 .29474 L
.93748 .29459 L
.93749 .29453 L
.9375 .29449 L
.93751 .29446 L
.93752 .29442 L
.93753 .29442 L
.93754 .29442 L
.93755 .29441 L
.93756 .29441 L
.93757 .29441 L
.93758 .29441 L
.93759 .29443 L
.9376 .29446 L
.93761 .29449 L
.93762 .29455 L
.93763 .29458 L
.93764 .29461 L
.93766 .2947 L
.93767 .29482 L
.93779 .29599 L
.93785 .29678 L
.93792 .29775 L
.93804 .29963 L
.93815 .30131 L
.93821 .30198 L
.93826 .30246 L
Mistroke
.93832 .30285 L
.93835 .30303 L
.93837 .30316 L
.93838 .30315 L
.93838 .3031 L
.9384 .30308 L
.93841 .30308 L
.93842 .30309 L
.93844 .30316 L
.93845 .30316 L
.93847 .30299 L
.93848 .30291 L
.9385 .30285 L
.93851 .30281 L
.93852 .30278 L
.93853 .30271 L
.93856 .30242 L
.93863 .30174 L
.93875 .30008 L
.93888 .298 L
.939 .29617 L
.93906 .29551 L
.93912 .29497 L
.93915 .29475 L
.93916 .29466 L
.93918 .29456 L
.93919 .29447 L
.93921 .29444 L
.93924 .29438 L
.93925 .29434 L
.93926 .29433 L
.93928 .29437 L
.93929 .29438 L
.9393 .2944 L
.93931 .29443 L
.93932 .29445 L
.93934 .29451 L
.93935 .2946 L
.93941 .29501 L
.93945 .29533 L
.93948 .29566 L
.9396 .29724 L
.93971 .29899 L
.93982 .3007 L
.93988 .3015 L
.93994 .30211 L
.93997 .30239 L
.93998 .30252 L
.94 .30263 L
.94001 .30267 L
Mistroke
.94001 .3027 L
.94003 .30278 L
.94005 .30287 L
.94006 .30294 L
.94006 .30298 L
.94008 .30296 L
.9401 .30295 L
.94011 .30295 L
.94012 .30297 L
.94014 .30302 L
.94015 .30294 L
.94018 .30277 L
.94024 .30239 L
.94026 .30225 L
.94028 .30214 L
.94029 .30203 L
.9403 .3019 L
.94031 .30178 L
.94043 .30024 L
.94065 .29673 L
.94071 .2959 L
.94077 .29526 L
.9408 .29497 L
.94083 .29474 L
.94086 .29456 L
.94088 .29446 L
.94089 .29442 L
.94089 .2944 L
.94092 .29434 L
.94094 .29431 L
.94095 .29429 L
.94096 .29432 L
.94098 .29434 L
.94099 .29436 L
.94101 .29439 L
.94102 .29446 L
.94103 .29452 L
.94105 .2946 L
.94106 .29467 L
.94108 .29476 L
.94109 .29489 L
.94112 .2951 L
.94123 .29644 L
.94136 .29834 L
.94149 .30039 L
.94155 .30124 L
.94161 .30189 L
.94167 .30239 L
.9417 .30256 L
.94171 .30269 L
Mistroke
.94172 .30278 L
.94173 .30282 L
.94174 .30277 L
.94176 .30278 L
.94177 .3028 L
.94179 .30284 L
.9418 .3029 L
.94182 .30282 L
.94183 .30276 L
.94184 .30272 L
.94186 .30269 L
.94187 .30268 L
.94188 .30265 L
.94189 .30252 L
.94191 .3024 L
.94197 .30183 L
.9421 .30036 L
.94232 .2968 L
.94238 .29596 L
.94245 .29521 L
.9425 .29472 L
.94253 .29451 L
.94255 .29442 L
.94256 .29438 L
.94258 .29433 L
.94259 .29428 L
.94261 .29424 L
.94262 .29425 L
.94263 .29425 L
.94264 .29426 L
.94266 .29427 L
.94267 .29429 L
.94268 .29435 L
.9427 .29442 L
.94272 .29449 L
.94273 .29453 L
.94273 .29458 L
.94275 .2947 L
.94278 .29494 L
.94282 .2953 L
.94293 .29677 L
.94306 .29873 L
.94318 .30057 L
.94324 .30134 L
.94329 .30192 L
.94333 .30217 L
.94334 .30233 L
.94335 .3024 L
.94336 .30243 L
.94337 .30245 L
Mistroke
.94338 .30248 L
.94339 .30255 L
.94341 .30265 L
.94342 .30273 L
.94343 .30276 L
.94344 .3027 L
.94346 .30268 L
.94347 .30267 L
.94348 .3027 L
.9435 .30275 L
.94351 .3027 L
.94352 .3026 L
.94353 .3025 L
.94355 .30244 L
.94356 .30239 L
.94357 .30239 L
.94358 .30235 L
.94359 .30217 L
.94361 .302 L
.94367 .30133 L
.94379 .2997 L
.94402 .29624 L
.94408 .29548 L
.94411 .29515 L
.94414 .29482 L
.94417 .29459 L
.9442 .29441 L
.94422 .29434 L
.94423 .2943 L
.94425 .29426 L
.94426 .29422 L
.94427 .29418 L
.94429 .2942 L
.9443 .29421 L
.94432 .29423 L
.94432 .29424 L
.94433 .29424 L
.94435 .2943 L
.94438 .29445 L
.94443 .29479 L
.94448 .29531 L
.9446 .29677 L
.94472 .29867 L
.94483 .3004 L
.94489 .30113 L
.94494 .30168 L
.945 .30217 L
.94501 .30229 L
.94502 .30235 L
.94503 .30238 L
Mistroke
.94504 .30243 L
.94506 .30248 L
.94507 .30254 L
.94508 .30259 L
.94509 .30262 L
.9451 .3026 L
.94511 .30257 L
.94512 .30256 L
.94513 .30255 L
.94514 .30255 L
.94515 .30257 L
.94516 .30258 L
.94517 .30253 L
.94517 .30247 L
.94518 .30241 L
.94519 .30237 L
.94525 .30198 L
.94531 .30149 L
.94537 .30077 L
.94543 .29983 L
.94555 .29795 L
.94567 .2961 L
.94573 .29531 L
.94577 .29495 L
.94581 .29465 L
.94582 .29453 L
.94584 .29441 L
.94585 .29432 L
.94586 .2943 L
.94587 .29428 L
.94588 .29423 L
.9459 .29419 L
.94591 .29414 L
.94593 .29414 L
.94595 .29416 L
.94596 .29418 L
.94598 .2942 L
.94598 .29422 L
.94599 .29426 L
.94602 .29439 L
.94605 .29458 L
.94608 .29482 L
.94611 .29507 L
.94616 .29566 L
.94641 .29939 L
.94652 .30091 L
.94657 .30156 L
.94661 .30183 L
.94662 .30197 L
.94663 .30208 L
Mistroke
.94665 .30214 L
.94667 .30223 L
.94668 .30233 L
.94669 .30239 L
.9467 .3024 L
.94673 .30243 L
.94675 .30247 L
.94676 .30247 L
.94677 .30242 L
.94679 .30238 L
.9468 .30235 L
.94681 .30235 L
.94682 .30233 L
.94683 .30227 L
.94684 .3022 L
.94685 .30211 L
.94687 .30203 L
.94688 .30195 L
.9469 .30179 L
.94691 .30166 L
.94693 .30151 L
.94694 .3014 L
.94695 .30124 L
.94697 .30106 L
.94699 .30072 L
.94711 .29894 L
.94722 .29728 L
.94733 .29565 L
.94739 .29497 L
.94742 .29472 L
.94745 .2945 L
.94747 .29441 L
.94748 .29433 L
.9475 .29426 L
.94751 .2942 L
.94752 .29417 L
.94753 .29416 L
.94754 .29414 L
.94756 .29413 L
.94757 .29412 L
.94757 .29411 L
.94759 .29413 L
.9476 .29417 L
.94762 .29421 L
.94763 .29425 L
.94764 .29429 L
.94766 .29439 L
.94768 .29454 L
.94774 .29506 L
.9478 .29568 L
Mistroke
.94804 .29935 L
.9481 .30021 L
.94816 .301 L
.94821 .30159 L
.94824 .30182 L
.94826 .30193 L
.94827 .30204 L
.94828 .3021 L
.94829 .30214 L
.94831 .3022 L
.94832 .30224 L
.94833 .30232 L
.94834 .3024 L
.94836 .30235 L
.94837 .30233 L
.94838 .30232 L
.9484 .30233 L
.94841 .3024 L
.94843 .30231 L
.94844 .30218 L
.94845 .30214 L
.94846 .3021 L
.94847 .30205 L
.94849 .30205 L
.9485 .30187 L
.94852 .30169 L
.94853 .30155 L
.94855 .30143 L
.94856 .3014 L
.94856 .30132 L
.94858 .30106 L
.94861 .3007 L
.94872 .29908 L
.94884 .29713 L
.94896 .29551 L
.94902 .29488 L
.94908 .2944 L
.9491 .2943 L
.9491 .29425 L
.94911 .2942 L
.94912 .29417 L
.94913 .29415 L
.94915 .29411 L
.94916 .29408 L
.94917 .29406 L
.94918 .29406 L
.9492 .29409 L
.94921 .29411 L
.94923 .29414 L
.94923 .29415 L
Mistroke
.94924 .29418 L
.94927 .29434 L
.94932 .29472 L
.94938 .29531 L
.94945 .29611 L
.94967 .29949 L
.94978 .301 L
.94984 .30164 L
.94987 .30185 L
.94989 .30196 L
.9499 .30205 L
.94991 .30208 L
.94992 .30212 L
.94994 .30216 L
.94995 .30221 L
.94997 .30228 L
.94998 .30225 L
.94999 .30221 L
.95001 .30219 L
.95002 .3022 L
.95003 .30222 L
.95005 .30211 L
.95006 .30202 L
.95007 .30194 L
.95009 .30188 L
.9501 .30187 L
.9501 .30183 L
.95012 .30165 L
.95015 .30134 L
.95016 .30125 L
.95018 .30109 L
.95021 .30069 L
.95023 .3004 L
.95036 .29851 L
.95047 .2967 L
.95058 .29526 L
.95061 .29494 L
.95064 .29465 L
.95067 .29444 L
.95068 .29433 L
.95069 .29427 L
.9507 .29422 L
.95071 .29419 L
.95072 .29416 L
.95073 .29411 L
.95074 .29408 L
.95075 .29405 L
.95076 .29403 L
.95077 .29403 L
.95078 .29403 L
Mistroke
.9508 .29404 L
.95081 .29404 L
.95082 .29405 L
.95082 .29408 L
.95083 .29412 L
.95085 .29417 L
.95086 .29423 L
.95087 .29427 L
.95088 .29434 L
.9509 .29445 L
.95096 .29499 L
.95102 .29568 L
.95108 .29645 L
.9513 .29986 L
.95136 .30067 L
.95139 .30107 L
.95142 .30136 L
.95148 .30182 L
.9515 .30189 L
.95151 .30196 L
.95153 .30211 L
.95154 .30218 L
.95155 .30209 L
.95157 .30208 L
.95158 .30208 L
.9516 .30213 L
.95161 .30211 L
.95163 .30201 L
.95164 .30195 L
.95165 .30189 L
.95166 .30187 L
.95167 .30183 L
.95168 .30176 L
.95169 .30169 L
.95172 .30145 L
.95178 .30085 L
.9519 .29919 L
.95203 .2971 L
.95209 .29623 L
.95215 .29539 L
.95221 .29479 L
.95227 .29431 L
.95228 .29422 L
.9523 .29411 L
.95231 .29406 L
.95232 .29405 L
.95233 .29404 L
.95234 .29402 L
.95235 .29399 L
.95237 .29394 L
Mistroke
.95237 .29394 L
.95238 .29397 L
.95239 .29399 L
.9524 .294 L
.95241 .29403 L
.95243 .29404 L
.95244 .2941 L
.95246 .2942 L
.95252 .29464 L
.95255 .29491 L
.95258 .29529 L
.95264 .29605 L
.95275 .29775 L
.95288 .29978 L
.95295 .30061 L
.95297 .30091 L
.95299 .30108 L
.953 .30126 L
.95302 .30139 L
.95303 .30146 L
.95306 .30166 L
.95307 .30171 L
.95308 .30181 L
.95309 .30189 L
.95309 .30191 L
.95311 .30188 L
.95312 .30191 L
.95314 .30195 L
.95315 .30203 L
.95317 .30201 L
.95318 .30194 L
.95319 .30191 L
.95321 .30188 L
.95322 .30188 L
.95322 .30188 L
.95324 .30178 L
.95327 .30154 L
.95329 .30147 L
.9533 .30142 L
.95331 .3013 L
.95334 .30093 L
.95336 .3008 L
.95337 .30065 L
.9534 .3002 L
.95343 .29982 L
.95349 .29891 L
.9536 .29713 L
.95372 .29544 L
.95378 .29475 L
.95381 .29445 L
Mistroke
.95383 .29432 L
.95385 .2942 L
.95386 .29411 L
.95387 .29408 L
.95388 .29404 L
.9539 .29399 L
.95391 .29393 L
.95393 .29392 L
.95394 .29391 L
.95395 .29391 L
.95397 .29391 L
.95398 .29395 L
.954 .29399 L
.95401 .29405 L
.95403 .2941 L
.95404 .2942 L
.95406 .29429 L
.95408 .29448 L
.95414 .29507 L
.95421 .29589 L
.95446 .29975 L
.95452 .30053 L
.95458 .30118 L
.9546 .30134 L
.95461 .30144 L
.95462 .30151 L
.95463 .30154 L
.95464 .30156 L
.95464 .3016 L
.95465 .30165 L
.95466 .30169 L
.95467 .30174 L
.95468 .30182 L
.95469 .30189 L
.9547 .30185 L
.95472 .30182 L
.95473 .30182 L
.95474 .30183 L
.95475 .30188 L
.95476 .30191 L
.95478 .30176 L
.95479 .30167 L
.95481 .3016 L
.95482 .30159 L
.95483 .3016 L
.95483 .30158 L
.95484 .30147 L
.95487 .30115 L
.95489 .30102 L
.9549 .30089 L
Mistroke
.95492 .3007 L
.95493 .30052 L
.95496 .3002 L
.95509 .29825 L
.95522 .2963 L
.95527 .29554 L
.95533 .29485 L
.95536 .29456 L
.95539 .29429 L
.9554 .29419 L
.95542 .29409 L
.95543 .294 L
.95545 .29397 L
.95548 .29388 L
.95549 .29383 L
.9555 .29384 L
.95551 .29385 L
.95552 .29386 L
.95554 .29388 L
.95555 .29388 L
.95556 .29395 L
.9556 .2941 L
.95562 .29428 L
.95569 .29488 L
.9558 .29631 L
.95592 .29815 L
.95604 .29999 L
.95611 .3008 L
.95614 .30112 L
.95618 .30135 L
.95619 .30146 L
.9562 .30153 L
.95622 .30157 L
.95623 .30163 L
.95625 .30169 L
.95626 .30176 L
.95627 .30174 L
.95628 .30171 L
.95629 .3017 L
.9563 .3017 L
.95631 .3017 L
.95632 .30173 L
.95633 .30168 L
.95634 .30161 L
.95635 .30156 L
.95636 .30152 L
.95637 .30148 L
.95637 .30145 L
.95639 .30142 L
.9564 .30125 L
Mistroke
.95642 .30112 L
.95664 .29821 L
.95677 .29616 L
.95683 .29531 L
.95689 .29467 L
.95695 .29418 L
.95696 .29407 L
.95698 .29398 L
.95699 .29395 L
.957 .29392 L
.95701 .29387 L
.95703 .29382 L
.95704 .29378 L
.95705 .29379 L
.95707 .29381 L
.95708 .29382 L
.9571 .29383 L
.95711 .29389 L
.95712 .29395 L
.95714 .29402 L
.95715 .29409 L
.95717 .29421 L
.95719 .29434 L
.95724 .29489 L
.95738 .29666 L
.95748 .29836 L
.9576 .30002 L
.95766 .30077 L
.95772 .30126 L
.95774 .30135 L
.95775 .30146 L
.95776 .30148 L
.95777 .30149 L
.95778 .30153 L
.9578 .30157 L
.95781 .30165 L
.95783 .30163 L
.95784 .30158 L
.95785 .30156 L
.95787 .30155 L
.95788 .30156 L
.95789 .30149 L
.9579 .30141 L
.95791 .30136 L
.95792 .30131 L
.95793 .30124 L
.95795 .30118 L
.95796 .30108 L
.95796 .30098 L
.95808 .29968 L
Mistroke
.95821 .29767 L
.95833 .29576 L
.95839 .29501 L
.95845 .29438 L
.95848 .29414 L
.9585 .29403 L
.95852 .29392 L
.95853 .29387 L
.95853 .29385 L
.95855 .29381 L
.95857 .29378 L
.95858 .29374 L
.95859 .29372 L
.95861 .29375 L
.95862 .29378 L
.95863 .29381 L
.95865 .29383 L
.95866 .29389 L
.95869 .29403 L
.95874 .29446 L
.9588 .2951 L
.95893 .29697 L
.95906 .29891 L
.95917 .30038 L
.95918 .30055 L
.9592 .30074 L
.95921 .30085 L
.95923 .30097 L
.95924 .30107 L
.95926 .30121 L
.95927 .30129 L
.95929 .30132 L
.9593 .30138 L
.95932 .30146 L
.95933 .3015 L
.95935 .30147 L
.95936 .30146 L
.95937 .30146 L
.95938 .30146 L
.95939 .30148 L
.95941 .30139 L
.95943 .30127 L
.95945 .30123 L
.95946 .30115 L
.95947 .30099 L
.95949 .30089 L
.9595 .30078 L
.95951 .30072 L
.95953 .30054 L
.95954 .30033 L
Mistroke
.95957 .30002 L
.95963 .29923 L
.95976 .29726 L
.95986 .2956 L
.95992 .29484 L
.95998 .29427 L
.96001 .29402 L
.96002 .29395 L
.96003 .2939 L
.96005 .29384 L
.96006 .29379 L
.96008 .29372 L
.96009 .29369 L
.96009 .29368 L
.96011 .29369 L
.96013 .2937 L
.96014 .2937 L
.96016 .29371 L
.96016 .29375 L
.96017 .29379 L
.96023 .29411 L
.96026 .29433 L
.96029 .29464 L
.96035 .29537 L
.96046 .297 L
.96059 .29904 L
.96071 .30055 L
.96074 .30077 L
.96075 .30089 L
.96077 .30112 L
.96078 .30121 L
.96079 .30122 L
.9608 .30117 L
.96082 .30123 L
.96083 .30129 L
.96084 .30141 L
.96086 .30138 L
.96087 .30132 L
.96089 .30132 L
.9609 .30132 L
.96092 .30129 L
.96093 .30121 L
.96094 .30114 L
.96096 .30108 L
.96098 .30101 L
.96098 .30093 L
.96099 .30085 L
.96101 .30072 L
.96108 .30002 L
.9612 .29832 L
Mistroke
.96131 .29657 L
.96142 .29491 L
.96146 .29452 L
.96149 .2942 L
.96152 .29397 L
.96154 .29386 L
.96155 .29378 L
.96157 .29373 L
.96158 .29369 L
.9616 .29363 L
.96161 .29359 L
.96163 .29361 L
.96164 .29362 L
.96166 .29364 L
.96166 .29363 L
.96167 .29365 L
.96169 .29373 L
.9617 .2938 L
.96171 .29387 L
.96173 .29393 L
.96174 .29406 L
.96176 .29417 L
.96179 .29445 L
.96185 .29521 L
.96191 .29603 L
.96213 .29941 L
.96219 .30014 L
.96225 .30071 L
.96228 .30095 L
.96229 .30117 L
.96231 .30118 L
.96232 .3011 L
.96234 .30113 L
.96235 .30116 L
.96236 .30128 L
.96237 .3013 L
.96238 .30123 L
.96239 .30117 L
.9624 .30116 L
.96241 .30113 L
.96243 .30111 L
.96244 .30104 L
.96246 .30094 L
.96249 .30073 L
.96255 .30023 L
.96261 .29948 L
.96285 .29577 L
.96292 .29489 L
.96295 .29448 L
.96299 .29414 L
Mistroke
.96302 .29392 L
.96305 .29373 L
.96305 .29365 L
.96306 .29361 L
.96307 .2936 L
.96308 .29359 L
.9631 .29356 L
.96311 .29351 L
.96313 .29348 L
.96314 .29351 L
.96314 .29354 L
.96316 .29357 L
.96317 .29359 L
.96318 .2936 L
.96319 .29366 L
.96321 .29374 L
.96324 .29396 L
.96327 .29422 L
.9633 .2945 L
.96336 .29527 L
.96348 .29703 L
.96359 .29875 L
.96364 .29948 L
.9637 .30013 L
.96373 .30042 L
.96376 .30066 L
.96377 .3008 L
.96379 .30086 L
.96381 .30095 L
.96383 .30104 L
.96384 .30108 L
.96385 .30107 L
.96386 .30105 L
.96386 .30105 L
.96387 .30105 L
.96388 .30105 L
.96389 .30107 L
.9639 .30108 L
.96391 .30104 L
.96391 .30099 L
.96393 .30093 L
.96394 .30087 L
.96396 .30084 L
.96397 .30076 L
.96398 .30067 L
.96399 .30055 L
.96401 .30044 L
.96403 .3002 L
.96406 .29985 L
.96432 .29608 L
Mistroke
.96437 .29522 L
.96444 .29446 L
.96449 .29397 L
.9645 .29384 L
.96452 .29375 L
.96455 .29361 L
.96456 .29353 L
.96458 .2935 L
.96459 .29349 L
.9646 .29348 L
.96461 .29348 L
.96462 .29345 L
.96463 .29347 L
.96465 .29352 L
.96466 .29356 L
.96468 .29361 L
.9647 .29367 L
.9647 .29374 L
.96471 .2938 L
.96473 .29392 L
.96479 .29448 L
.96485 .29522 L
.96491 .29605 L
.96502 .29776 L
.96513 .29945 L
.96519 .30011 L
.96522 .30042 L
.96524 .30053 L
.96525 .30066 L
.96527 .30075 L
.96528 .30079 L
.96531 .30089 L
.96532 .30098 L
.96534 .30098 L
.96535 .30095 L
.96535 .30094 L
.96537 .30093 L
.96538 .30095 L
.9654 .30095 L
.96541 .30082 L
.96542 .30075 L
.96548 .30041 L
.96551 .30016 L
.96554 .29982 L
.9656 .29899 L
.96572 .29718 L
.96583 .29552 L
.96588 .29476 L
.96594 .29411 L
.96597 .29384 L
Mistroke
.96599 .29373 L
.96601 .29362 L
.96602 .29356 L
.96602 .29353 L
.96604 .29349 L
.96605 .29346 L
.96607 .29341 L
.96608 .29341 L
.9661 .29342 L
.96611 .29343 L
.96613 .29345 L
.96614 .29352 L
.96616 .29358 L
.96619 .29376 L
.96621 .29396 L
.96624 .29419 L
.9663 .29483 L
.96641 .29647 L
.96654 .29846 L
.9666 .29932 L
.96663 .29964 L
.96664 .29983 L
.96666 .30005 L
.96667 .30014 L
.96668 .30022 L
.9667 .30033 L
.96671 .30042 L
.96672 .30059 L
.96674 .30079 L
.96675 .30075 L
.96676 .3007 L
.96678 .30075 L
.96679 .30077 L
.9668 .30083 L
.96681 .30091 L
.96683 .3008 L
.96684 .30078 L
.96685 .30076 L
.96687 .30074 L
.96688 .30067 L
.96691 .3005 L
.96694 .30026 L
.967 .2997 L
.96707 .29889 L
.96714 .29783 L
.96726 .29584 L
.96738 .29431 L
.96743 .29377 L
.96745 .29367 L
.96747 .29355 L
Mistroke
.96748 .29344 L
.9675 .29342 L
.96751 .29338 L
.96753 .29334 L
.96754 .29328 L
.96756 .29332 L
.96757 .29334 L
.96758 .29337 L
.9676 .29336 L
.96761 .29343 L
.96763 .29353 L
.96764 .29362 L
.96767 .29385 L
.96773 .29441 L
.96786 .29619 L
.96797 .29789 L
.96809 .2995 L
.96812 .2999 L
.96813 .3 L
.96813 .30007 L
.96814 .30011 L
.96815 .30016 L
.96818 .30037 L
.9682 .30056 L
.9682 .30061 L
.96821 .30058 L
.96822 .30057 L
.96823 .30059 L
.96824 .30063 L
.96825 .30068 L
.96826 .30074 L
.96828 .30074 L
.96829 .30065 L
.9683 .30063 L
.96832 .30061 L
.96833 .30064 L
.96835 .3005 L
.96836 .30038 L
.96838 .30029 L
.96839 .30023 L
.9684 .30014 L
.96841 .30004 L
.96843 .29988 L
.96846 .29955 L
.96858 .2979 L
.96869 .29618 L
.9688 .29455 L
.96886 .29395 L
.96887 .29381 L
.96889 .29367 L
Mistroke
.96892 .29349 L
.96894 .2934 L
.96895 .29335 L
.96896 .29332 L
.96898 .29329 L
.96899 .29325 L
.969 .29326 L
.96902 .29328 L
.96903 .2933 L
.96905 .29332 L
.96906 .29339 L
.96908 .29347 L
.96909 .29356 L
.96911 .29365 L
.96912 .29378 L
.96915 .29402 L
.96922 .29477 L
.96928 .29567 L
.96939 .29731 L
.9695 .29899 L
.96956 .29974 L
.96959 .30001 L
.96962 .30024 L
.96964 .30035 L
.96965 .30042 L
.96967 .30046 L
.96968 .3005 L
.9697 .30057 L
.9697 .30062 L
.96971 .30062 L
.96973 .30056 L
.96974 .30054 L
.96976 .30054 L
.96977 .30057 L
.96978 .30043 L
.9698 .30034 L
.96985 .29996 L
.96987 .29982 L
.96988 .2997 L
.9699 .29956 L
.96991 .29934 L
.96998 .29848 L
.97011 .29643 L
.97017 .29554 L
.97023 .29466 L
.97028 .29404 L
.97034 .29355 L
.97036 .29344 L
.97037 .29336 L
.97039 .29331 L
Mistroke
.9704 .29326 L
.97042 .29321 L
.97043 .29322 L
.97045 .29322 L
.97046 .29322 L
.97048 .29325 L
.97048 .29328 L
.97049 .29331 L
.97051 .29337 L
.97052 .29342 L
.97053 .29349 L
.97054 .29355 L
.97056 .29368 L
.97059 .29396 L
.97065 .29461 L
.97071 .29547 L
.97082 .29723 L
.97095 .299 L
.97098 .29944 L
.97101 .29976 L
.97103 .29992 L
.97104 .30002 L
.97105 .3001 L
.97106 .30013 L
.97106 .30015 L
.97108 .30023 L
.97109 .30031 L
.9711 .30038 L
.97111 .30047 L
.97112 .30046 L
.97114 .30042 L
.97115 .30043 L
.97115 .30043 L
.97117 .30049 L
.97118 .30055 L
.97119 .30053 L
.97119 .30043 L
.9712 .30035 L
.97122 .3003 L
.97123 .30025 L
.97125 .3002 L
.97126 .30005 L
.97129 .29983 L
.97132 .29952 L
.97139 .29872 L
.97145 .29784 L
.97157 .29596 L
.97168 .2944 L
.97173 .29382 L
.97176 .29359 L
Mistroke
.97177 .29348 L
.97179 .29337 L
.9718 .2933 L
.97182 .29325 L
.97183 .29321 L
.97185 .29315 L
.97186 .29315 L
.97188 .29316 L
.97188 .29316 L
.97189 .29316 L
.97191 .29318 L
.97192 .29324 L
.97194 .2933 L
.97195 .29336 L
.97196 .29342 L
.97198 .29354 L
.97199 .29364 L
.972 .29374 L
.97201 .29382 L
.97203 .29399 L
.97204 .29414 L
.97207 .29448 L
.97213 .29525 L
.97225 .29715 L
.97231 .29807 L
.97237 .29885 L
.97242 .29948 L
.97247 .29991 L
.97248 .30001 L
.9725 .30013 L
.97251 .30019 L
.97253 .30022 L
.97254 .30027 L
.97255 .30033 L
.97257 .30039 L
.97258 .30032 L
.9726 .30031 L
.97261 .30031 L
.97263 .30034 L
.97264 .3002 L
.97266 .30012 L
.97267 .30005 L
.97268 .30003 L
.9727 .2999 L
.97271 .29971 L
.97273 .29958 L
.97276 .29926 L
.97282 .29855 L
.97294 .29668 L
.97301 .2956 L
Mistroke
.97307 .29469 L
.97313 .29397 L
.97316 .29366 L
.97319 .29342 L
.97321 .29333 L
.97322 .29325 L
.97323 .29322 L
.97324 .29319 L
.97325 .29314 L
.97326 .2931 L
.97328 .2931 L
.97329 .2931 L
.97331 .2931 L
.97332 .29312 L
.97333 .29317 L
.97335 .29322 L
.97336 .29327 L
.97337 .29334 L
.97339 .29344 L
.97341 .29361 L
.97344 .29388 L
.97347 .2942 L
.97353 .2949 L
.97364 .29667 L
.97376 .29853 L
.97383 .29932 L
.97386 .29966 L
.9739 .29992 L
.97393 .30008 L
.97394 .30024 L
.97396 .30025 L
.97397 .3002 L
.97397 .30019 L
.97398 .3002 L
.97399 .3002 L
.97401 .30029 L
.97402 .30029 L
.97404 .30013 L
.97405 .30007 L
.97407 .30002 L
.97408 .29998 L
.9741 .29981 L
.97411 .2997 L
.97414 .29942 L
.97425 .29804 L
.97437 .29614 L
.97444 .29513 L
.9745 .29429 L
.97456 .2937 L
.97459 .29347 L
Mistroke
.9746 .29336 L
.97462 .29324 L
.97462 .29319 L
.97463 .29317 L
.97465 .29312 L
.97466 .29307 L
.97467 .29303 L
.97468 .29302 L
.97469 .29303 L
.9747 .29304 L
.97471 .29305 L
.97473 .29304 L
.97474 .2931 L
.97477 .29323 L
.9748 .29338 L
.97482 .29358 L
.97485 .29381 L
.97491 .29451 L
.97496 .29527 L
.97507 .29699 L
.97519 .29869 L
.97525 .29937 L
.97527 .29953 L
.97528 .29963 L
.97528 .29971 L
.97529 .29974 L
.9753 .29978 L
.97532 .29987 L
.97533 .29998 L
.97535 .30011 L
.97536 .30007 L
.97537 .30006 L
.97538 .30008 L
.97539 .3001 L
.97541 .30021 L
.97542 .30015 L
.97543 .30003 L
.9755 .29971 L
.97551 .29964 L
.97552 .29956 L
.97553 .29951 L
.97553 .29947 L
.97554 .29937 L
.97555 .29925 L
.97557 .29907 L
.97569 .2974 L
.97582 .29538 L
.97587 .29459 L
.97593 .29386 L
.97597 .29354 L
Mistroke
.976 .29331 L
.97601 .2932 L
.97603 .29314 L
.97604 .29308 L
.97605 .29305 L
.97606 .29302 L
.97607 .29298 L
.97607 .29298 L
.97608 .29298 L
.97609 .29298 L
.9761 .29298 L
.97611 .29298 L
.97612 .29298 L
.97613 .29302 L
.97614 .29305 L
.97615 .29311 L
.97616 .29314 L
.97617 .29319 L
.97618 .29326 L
.97619 .29332 L
Mfstroke
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.875},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003o9?ooool0
0ol0003oooooooooo`3ooooood;ooooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Co
oooo00?o0000ooooooooool0oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;ooooo
000Tooooo`03o`000?oooooooooo0?oooooo@_ooool002Cooooo00?o0000ooooooooool0:Oooool3
o`000?oooooo5_ooool002Cooooo00?o0000ooooooooool0:Oooool00ol0003oooooo`00003ooooo
oaKooooo000Tooooo`03o`000?oooooooooo02Sooooo00Co0000oooooooooooo0000oooooolFoooo
o`009?ooool00ol0003oooooooooo`0Xooooo`05o`000?ooooooooooooooool00000oooooolEoooo
o`009?ooool3o`0002Oooooo0_l00003ooooo`03o`000?oooooooooo0?oooooo4oooool002Cooooo
00?o0000ooooooooool09oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?oooooo
4oooool002Cooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo0?oooooo4_ooool002Cooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo0?oooooo4_ooool002Cooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo4_ooool002Cooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo4_ooool002Cooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo
4_ooool002Cooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0?oooooo4Oooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Kooooo
0_l000000ol@413oooooooooo`03ooooo`;o000000?o410@ooooooooool01?ooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooolAooooo`0000Ko
ooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo0?oooooo4Oooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool0
2Oooool5o`0000?ooooo1Ol00006ooooo`?o00009Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo0?oooooo4Oooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02Ooo
ool01?m4A4CogMgMooooool00004ooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo4Oooool00003oooo
ool0003ooooo00;ooooo00?o0000ooooooooool02Oooool01?oMgMgoEEEEooooool00004ooooo`04
omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo0?oooooo4Oooool00003ooooool@413ooooo00;ooooo00?o410@oooooooo
ool02_ooool00omgMgOoc<c<o`000005ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?oooooo4Oooool00006oooo
oomgMgOoV9RHoooooonHV9SoMgMg3?ooool00oo^k^koA4A4o`000005ooooo`03onk^k_m4A4Co0000
00Oooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
0?oooooo4Oooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`05
ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo0?oooooo4?ooool002Cooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo0?oooooo4?ooool002Cooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0?oooooo4?ooool002Cooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool0koooool002Cooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo01cooooo0_l0003aooooo`009?ooool3o`0002Cooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooo00000?3ooooo000Toooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooo00000?3ooooo000Tooooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0Kooooo`04o`000?ooooooooooo`000?3ooooo000Tooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Jooooo`04
o`000?ooooooooooo`000?3ooooo000Tooooo`03o`000?oooooooooo02?ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0Jooooo`04o`000?ooooooooooo`000?3ooooo000Tooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Jooooo`05
o`000?ooooooooooooooool00000koooool002Cooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo01[ooooo00Go0000ooooooooooooooooo`00003_oooo
o`009?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool06_ooool01Ol0003ooooooooooooooooo00000>oooooo000Tooooo`03o`000?oooooooooo02?o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Jooooo`05o`000?oooooooooooooo
ool00000koooool002Cooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo01[ooooo00Go0000ooooooooooooooooo`00003_ooooo`009?ooool3o`0002;o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0kOooool002Cooooo00?o0000ooooooooool08_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`3]ooooo`009?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0>gooooo000T
ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0kOooool002Cooooo00?o0000oooo
ooooool08_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`3/ooooo`009?ooool00ol0003oooooooooo`0Rooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo0>cooooo000Tooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
k?ooool002Cooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3/ooooo`009?ooool0
0ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo0>cooooo000Tooooo`03o`000?oooooooooo
027ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0k?ooool002Cooooo0ol0000Qooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool0fOooool002Cooooo00?o0000ooooooooool08Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0?ooooo`;o0000foooool002Cooooo00?o0000ooooooooool08Oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooo00000=[ooooo000Tooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool03oooool00ol0003oooooo`00003Jooooo`009?ooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00oooooo00?o0000ooooool00000f_ooool002Cooooo00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo00000=[ooooo000Tooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool03oooool00ol0003oooooo`00003Jooooo`009?oo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00gooooo00Co0000oooooooooooo0000
f_ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Kooooo0_l000002Ol@413o
ooooooooooooooook^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool03Oooool01?l0003oooooooooool0003Jooooo`0000KoooooogMgMonHV9Sooooo
oiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`02ooooo`05oeEEEOmgMgOooooooiRH
V?lQ8B401_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00gooooo00Go0000oooo
ooooooooooooo`00003Iooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`09oooo
o`Go00000oooool01Ol0003ooooooooooooooooo000000Kooooo0ol0000Pooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00gooooo00Go0000ooooooooooooooooo`00003Iooooo`0000?oooooo`000?ooool00_ooool0
0ol0003oooooooooo`09ooooo`04odA4A?oMgMgoooooo`0000Cooooo00Go0000oiRHV?ooooooV9RH
ob4Q8@06ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03Oooool01Ol0003ooooo
oooooooooooo00000=Wooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo
00CogMgMoeEEEOoooooo00001?ooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000oooo
ooooool08?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0=ooooo`05o`000?ooooooooooooooool00000fOooool0
0003ooooool@413ooooo00;ooooo00?o410@ooooooooool02_ooool00omgMgOoc<c<o`000004oooo
o`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0=oooo
o`05o`000?ooooooooooooooool000003?ooool2o`000<_ooooo00001_ooooooMgMgoiRHV?oooooo
V9RHogMgM`cooooo00?ok^k^odA4A?l000001?ooool00ooMgMgo410@oiRHV008ooooo`03o`000?oo
oooooooo023ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool03Oooool01Ol0003ooooooooooooooooo000000cooooo
0_l0003;ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h=ooooo`03ogMgMol0003ooooo00Co
oooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00gooooo00Go0000ooooooooooooooooo`00000<ooooo`;o0000boooool002Cooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0=ooooo`05o`000?ooooooooooooooool000003?ooool2
o`000<_ooooo000Tooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03Oooool01Ol0
003ooooooooooooooooo000000cooooo0_l0003;ooooo`009?ooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00gooooo00Go0000ooooooooooooooooo`00000;ooooo`04o`000?oooooo
ooooo`000<[ooooo000Tooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03Oooool0
1Ol0003ooooooooooooooooo000000_ooooo00Co0000oooooooooooo0000b_ooool002Cooooo0ol0
000Oooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`09ooooo`04o`000?ooooooooooo`000<[ooooo000Tooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo00Co
0000oooooooooooo00002Oooool2o`000;oooooo000Tooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo00Co
0000oooooooooooo00002Oooool2o`000;oooooo000Tooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo00Co
0000oooooooooooo00002Oooool2o`000;oooooo000Tooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo00Co
0000oooooooooooo00002Oooool2o`000;oooooo000Tooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo00Co
0000oooooooooooo00002Oooool2o`000;oooooo000Tooooo`03o`000?oooooooooo01kooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo00Co
0000oooooooooooo00002Oooool2o`0000Sooooo0_l0002eooooo`009?ooool00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`08ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooooooo00001oooool2o`000;Go
oooo000Tooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Sooooo00Co0000oooooooooooo00002?ooool01?l0003o
ooooooooool00007ooooo`;o0000]Oooool002Cooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool01?l0003o
ooooooooool00008ooooo`04o`000?ooooooooooo`0000Oooooo0_l0002eooooo`009?ooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`07ooooo`05o`000?ooooooooooooooool000002?ooool01?l0003oooooooooool0
0006ooooo`03o`000?oooooo000000Kooooo0_l0002]ooooo`009?ooool3o`0001kooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Kooooo00?o
0000ooooool000001_ooool2o`000:gooooo000Tooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Kooooo00?o
0000ooooool000001_ooool2o`000:gooooo000Tooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Kooooo00?o
0000ooooool000001_ooool2o`0000Gooooo0_l0002Vooooo`009?ooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0
0006ooooo`03o`000?oooooo000000Kooooo0_l00005ooooo`;o0000Y_ooool002Cooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00Co0000
oooooooooooo00001_ooool00ol0003oooooo`000006ooooo`;o00001Oooool2o`0000Gooooo00?o
0000ooooooooool0W_ooool002Cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00001_ooool00ol0003oooooo`00
0006ooooo`;o00001Oooool2o`0000Gooooo00?o0000ooooooooool0W_ooool002Cooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00Co0000
oooooooooooo00001_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooo000000Gooooo
0_l00004ooooo`;o00001?ooool2o`0009[ooooo000Tooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Kooooo
00Co0000oooooooooooo00001?ooool00ol0003oooooo`000005ooooo`;o00001?ooool2o`0000Co
oooo0_l00004ooooo`03o`000?oooooooooo09?ooooo000Tooooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Ko
oooo00Co0000oooooooooooo00001?ooool01?l0003oooooooooool00004ooooo`;o00001?ooool0
0ol0003oooooo`000003ooooo`;o00000oooool2o`0000?ooooo0_l0002@ooooo`009?ooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0
003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo00001?ooool01?l0003ooooooooo
ool00004ooooo`;o00001?ooool00ol0003oooooo`000003ooooo`;o00000oooool2o`0000?ooooo
0_l00003ooooo`03o`000?oooooooooo08[ooooo000Tooooo`?o00007Oooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000006ooooo`04o`00
0?ooooooooooo`0000Cooooo00Co0000oooooooooooo00001?ooool00ol0003oooooo`000003oooo
o`03o`000?oooooo000000?ooooo0_l00003ooooo`;o00000oooool2o`0000;ooooo0_l00003oooo
o`03o`000?oooooooooo08Kooooo000Tooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool01?l0
003oooooooooool00004ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo0000
0oooool00ol0003oooooo`000003ooooo`;o00000oooool2o`0000?ooooo0_l00002ooooo`;o0000
0_ooool2o`0000;ooooo0_l00002ooooo`03o`000?oooooooooo07oooooo000Tooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00004ooooo`04o`00
0?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000oooool00ol0003oooooo`000003oooo
o`;o00000oooool2o`0000?ooooo0_l00002ooooo`;o00000_ooool2o`0000;ooooo0_l00002oooo
o`04o`000?ooooooooooo`0000;ooooo0_l0001jooooo`009?ooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000004ooooo`04o`000?oooooo
ooooo`0000?ooooo00Co0000oooooooooooo00000oooool00ol0003oooooo`000003ooooo`;o0000
0oooool2o`0000?ooooo0_l00002ooooo`;o00000_ooool2o`0000;ooooo0_l00002ooooo`04o`00
0?ooooooooooo`0000;ooooo0_l000001Ooooooo0000o`000?oooooo000000;ooooo00?o0000oooo
ooooool0L?ooool002Cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000001?ooool01?l0003oooooooooool00003ooooo`04o`000?oooooo
ooooo`0000?ooooo00?o0000ooooool000000oooool2o`0000?ooooo0_l00003ooooo`;o00000_oo
ool2o`0000;ooooo0_l00002ooooo`;o00000_ooool00ol0003oooooooooo`02o`000004ooooool0
003o0000ooooo`;o000000Koooooo`000?ooooooooooo`000?ooool2o`000005ooooool0003ooooo
o`000?ooool00_l0001Xooooo`009?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`000004ooooo`04o`000?ooooooooooo`0000?ooooo00Co
0000oooooooooooo00000oooool00ol0003oooooo`000003ooooo`;o00000oooool2o`0000?ooooo
0_l00002ooooo`;o00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`;o0000
00Coooooo`000?l0003ooooo0_l000001_oooooo0000oooooooooooo0000ooooo`;o000000Oooooo
o`000?oooooo0000ooooool0003ooooo00Co000000?oooooo`000?l000001_l000000ooooooo0000
ooooo`1Hooooo`009?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000004ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooo
oooo00000oooool00ol0003oooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000
ooooool000000_ooool2o`0000;ooooo0_l00002ooooo`;o00000_ooool2o`000003ooooool0003o
000000;ooooo0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003ooooo00;o000000?o
ooooo`000?l000000_l000000ooooooo0000ooooo`0=o`000003ooooool0003ooooo00Co000000Co
ooooo`000?l0003ooooo4Ol0000Soooooa?o00002oooool00006ooooooo^k^ko<S8bo`000?lb<S;o
k^k^1Oooool2ob4Q8@Kooooo0_l000002Ol@413oooooooooooooooooc<c<ob4Q8Ol0003o8B4Qolc<
c006ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000Cooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool00003oooo
o`03o`000?oooooo000000;ooooo00Co0000oooooooooooo00000_ooool01ol0003oooooo`000?oo
oooo0000ooooool000000_ooool2o`0000;ooooo0_l00002ooooo`;o000000Goooooo`000?oooooo
0000ooooo`02o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?l000000_l000000ooo
oooo0000o`000002o`000003ooooool0003ooooo00oo000000?oooooo`000?l00000COl0000;oooo
o`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q1oooool00ol0003oooooooooo`02
ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`000004ooooo`04o`000?ooooooooooo`0000?o
oooo00Co0000oooooooooooo00000oooool00ol0003oooooo`000002ooooo`04o`000?oooooooooo
o`0000;ooooo00Oo0000ooooool0003oooooo`000?oooooo000000;ooooo0_l00002ooooo`04o`00
0?oooooo0000ooooo`;o000000Goooooo`000?oooooo0000ooooo`02o`000004ooooool0003o0000
ooooo`;o000000?oooooo`000?l000000_l000000ooooooo0000o`000002o`000003ooooool0003o
000005oo00002oooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02Oooool5o`00
00?ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo00Co0000oooooooooooo0000
0oooool01?l0003oooooooooool00003ooooo`03o`000?oooooo000000;ooooo00Co0000oooooooo
oooo00000_ooool01ol0003oooooo`000?oooooo0000ooooool000000_ooool02?l0003oooooo`00
0?oooooo0000ooooool0003ooooo0_l000001Ooooooo0000ooooool0003ooooo00;o000000Cooooo
o`000?l0003ooooo0ol000001Ooooooo0000o`000?l0003ooooo00Co000000?oooooo`000?l00000
GOl0000=ooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`09ooooo`04odA4A?oM
gMgoooooo`0000Cooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o00006oooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000001?ooool01?l0003oooooooooool00003
ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooool000000_ooool01_l0003ooooooooo
ool0003oooooo`0000;ooooo00Go0000ooooool0003oooooo`000002ooooo`08o`000?oooooo0000
ooooool0003oooooo`000?ooool2o`000003ooooool0003ooooo00;o000000?oooooo`000?ooool0
0_l000001Ooooooo0000o`000?l0003ooooo00?o000000?oooooo`000?l000000_l000000ooooooo
0000o`00001Ao`0001Wooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00Wooooo
00CogMgMoeEEEOoooooo00001?ooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001?ooool0
1?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo
00000_ooool01_l0003oooooooooool0003oooooo`0000;ooooo00Go0000ooooool0003oooooo`00
0002ooooo`08o`000?oooooo0000ooooool0003oooooo`000?ooool2o`000003ooooool0003ooooo
00;o000000?oooooo`000?ooool00_l000001Ooooooo0000o`000?l0003ooooo00?o000000?ooooo
o`000?l000000ol000000ooooooo0000o`000012o`0002Oooooo00000ooooooo410@ooooo`02oooo
o`03oa0@4?oooooooooo00[ooooo00?oMgMgolc<c?l000001?ooool01Ol@413o^[Zjoooooonj^[[o
410@00Kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000001?ooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00000_ooool01_l0003oooooooooool0003oooooo`0000;ooooo00?o
0000ooooool000000_ooool02?l0003oooooo`000?oooooo0000ooooool0003ooooo0_l000001Ooo
oooo0000ooooool0003ooooo00;o000000?oooooo`000?ooool00_l000001Ooooooo0000o`000?l0
003ooooo00;o000000?oooooo`000?l000001?l000000ooooooo0000o`00000eo`0003Cooooo0000
1_ooooooMgMgoiRHV?ooooooV9RHogMgM`cooooo00?ok^k^odA4A?l000001?ooool01Ol0003o^[Zj
oooooonj^[[o000000Kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000001?ooool01?l0003oooooooooool00003ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01_l0003oooooooooool0003oooooo`00
00;ooooo00?o0000ooooool000000_ooool2o`0000;ooooo00Co0000ooooool0003ooooo0_l00000
1Ooooooo0000ooooool0003ooooo00;o000000Koooooo`000?l0003oooooo`000?ooool3o`000004
ooooool0003o0000ooooo`Co000000?oooooo`000?ooool03ol000000ooooooo0000o`000002o`00
0003ooooool0003o000001?o0000@Oooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3Oooool0
0omgMgOo0000ooooo`03ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool00004ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00002ooooo`03o`000?oooooo000000;ooooo00?o0000ooooool000000_ooool2
o`0000;ooooo00Co0000ooooool0003ooooo0_l000001Ooooooo0000ooooool0003ooooo00;o0000
00Coooooo`000?l0003ooooo0_l000001?oooooo0000o`000?ooool2o`000003ooooool0003ooooo
00;o000000?oooooo`000?ooool03ol000000ooooooo0000o`00000;o`0004kooooo000Tooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0000Cooooo00Co0000oooooooooooo00000oooool00ol0003oooooo`000003
ooooo`03o`000?oooooo000000;ooooo00?o0000ooooool000000_ooool00ol0003oooooo`000002
ooooo`;o00000_ooool01?l0003oooooo`000?ooool2o`0000;ooooo0_l000001?oooooo0000o`00
0?ooool2o`000004ooooool0003o0000ooooo`;o000000Koooooo`000?l0003oooooo`000?ooool2
o`000005ooooool0003oooooo`000?ooool03Ol000001?oooooo0000ooooool0001Hooooo`009?oo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool00004ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooool0
00000oooool00ol0003oooooo`000002ooooo`03o`000?oooooo000000;ooooo00?o0000ooooool0
00000_ooool2o`0000;ooooo0_l00002ooooo`;o00000_ooool2o`000004ooooool0003o0000oooo
o`;o000000Coooooo`000?l0003ooooo0_l000001_oooooo0000o`000?oooooo0000ooooo`;o0000
00?oooooo`000?ooool01_l000001?oooooo0000ooooool0001Qooooo`009?ooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01?l0003ooooo
ooooool00004ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooool000000oooool00ol0
003oooooo`000002ooooo`03o`000?oooooo000000;ooooo00?o0000ooooool000000_ooool2o`00
00;ooooo0_l00002ooooo`;o00000_ooool2o`000004ooooool0003o0000ooooo`;o000000Cooooo
o`000?l0003ooooo0_l000001_oooooo0000o`000?oooooo0000ooooo`;o000000Coooooo`000?oo
oooo0000J_ooool002Cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo0000
00Cooooo00Co0000oooooooooooo00001?ooool01?l0003oooooooooool00003ooooo`03o`000?oo
oooo000000?ooooo00?o0000ooooool000000_ooool00ol0003oooooo`000002ooooo`03o`000?oo
oooo000000;ooooo0_l00002ooooo`;o00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`00
0002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000ooooool0003o0000Loooool002Cooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000Cooooo00Co0000oooooooo
oooo00001?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooo000000?ooooo00?o0000
ooooool000000_ooool00ol0003oooooo`000002ooooo`03o`000?oooooo000000;ooooo0_l00002
ooooo`;o00000_ooool2o`0000;ooooo0_l000000ooooooo0000o`000002ooooo`04o`000?oooooo
ooooo`0007Wooooo000Tooooo`?o00006_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00005ooooo`04o`000?oo
ooooooooo`0000Cooooo00?o0000ooooool000001?ooool00ol0003oooooo`000003ooooo`03o`00
0?oooooo000000;ooooo00?o0000ooooool000000_ooool00ol0003oooooo`000002ooooo`;o0000
0_ooool2o`0000;ooooo0_l00002ooooo`03o`000?oooooooooo00;o0000Ooooool002Cooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01?ooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Co
oooo00?o0000ooooool000001?ooool00ol0003oooooo`000003ooooo`03o`000?oooooo000000?o
oooo0_l00003ooooo`;o00000_ooool2o`0000;ooooo0_l00002ooooo`;o0000Q_ooool002Cooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`00
00Cooooo00?o0000ooooool000001?ooool00ol0003oooooo`000003ooooo`03o`000?oooooo0000
00?ooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00000oooool00ol0003oooooooooo`28
ooooo`009?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00Go0000oooo
ooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooo`000004ooooo`03o`000?oooooo000000?ooooo00?o0000ooooool00000
0oooool2o`0000?ooooo00Co0000oooooooooooooooo0_l0002>ooooo`009?ooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Kooooo00Go0000ooooooooooooooooo`000006ooooo`04
o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00001?ooool00ol0003oooooo`000004
ooooo`03o`000?oooooo000000?ooooo0_l00004ooooo`;o00000oooool00ol0003oooooooooo`2A
ooooo`009?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo00Go0000oooo
ooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo0000
1?ooool00ol0003oooooo`000004ooooo`03o`000?oooooo000000?ooooo0_l00004ooooo`03o`00
0?oooooooooo09Kooooo000Tooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01_oo
ool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo00001Oooool01?l0003o
ooooooooool00004ooooo`03o`000?oooooo000000Cooooo0_l00004ooooo`;o0000WOooool002Co
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`05o`000?oooooooooooooo
ool000001_ooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Cooooo00?o
0000ooooool000001?ooool2o`0000Gooooo00?o0000ooooooooool0Voooool002Cooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool000001_oo
ool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000Gooooo0_l00004ooooo`;o
0000Xoooool002Cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`05o`00
0?ooooooooooooooool000001_ooool01?l0003oooooooooool00006ooooo`;o00001_ooool2o`00
00Gooooo00?o0000ooooooooool0XOooool002Cooooo0ol0000Iooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Ko
oooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Kooooo0_l00006
ooooo`;o0000ZOooool002Cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06oooo
o`05o`000?ooooooooooooooool000001_ooool01?l0003oooooooooool00006ooooo`;o00001_oo
ool00ol0003oooooooooo`2Xooooo`009?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Kooooo00Go0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Kooooo
0_l0002aooooo`009?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00Go
0000ooooooooooooooooo`000006ooooo`04o`000?ooooooooooo`0000Kooooo0_l0002aooooo`00
9?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00Co0000oooooooooooo
00001oooool01?l0003oooooooooool00006ooooo`;o0000/Oooool002Cooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`06ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000oooo
ool000001_ooool2o`000;7ooooo000Tooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01_ooool01?l0003oooooooooool00008ooooo`;o0000^_ooool002Cooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`09ooooo`Go00003_ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00Kooooo0_l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00Kok^k^oc8b<_l0003o410@olc<c?l00008ooooo`;o00006_ooool01Oo<c<co8B4Qo`000?lQ
8B7oc<c<027ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^7_ooool4o`00
0003oa0@4?oooooooooo00Go00007Oooool4o`000003oa0@4?oooooooooo00;ooooo0_l000000ol@
413oooooooooo`0Iooooo`009?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Wo
oooo00GoV9RHob4Q8Oo^k^koooooodA4A00>ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00KoEEEEogMg
Mol0003oV9RHob4Q8Ol00008ooooo`;o00006_ooool01OlQ8B7oV9RHoooooonHV9So8B4Q02?ooooo
00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg023ooooo00?o0000oooooooo
ool00_ooool01OnHV9So8B4Qonk^k_ooooooA4A401oooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0Jooooo`009?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00[o
oooo00?oV9RHob4Q8Oo^k^h03oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Co
oooo1Ol00005ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool01Ol0003o
oooooooooooooooo000000Oooooo00?o0000ooooooooool00ol00008ooooo`;o00006_ooool01Ol0
003ooooooooooooooooo000002?ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooo
oooo410@023ooooo00?o0000ooooooooool00oooool00onHV9So8B4Qonk^kP0Pooooo`03o`000?oo
oooooooo00;ooooo1Ol0000Kooooo`009?ooool3o`0001Oooooo00?o0000ooooooooool03?ooool0
0onHV9So8B4Qonk^kP0>ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01?ooool0
1?m4A4CogMgMooooool00006ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Ooo
ool01Ol0003ooooooooooooooooo000000Oooooo00Ko0000oiRHV?oooooo0000ob4Q8Ol0000Toooo
o`05oc8b<_nHV9SooooooiRHV?lb<S808oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000008?ooool00ol0003oooooooooo`04ooooo`03oiRHV?lQ8B7ok^k^01oooooo00?o
0000ooooooooool00_ooool01?m4A4CogMgMooooool0000Looooo`009?ooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo00gooooo00?oMgMgofIVI_ooool03Oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00Cooooo00CogMgMoeEEEOoooooo00001_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000007ooooo`06
o`000?mEEEGo0000o`000?o<c<co00009?ooool01Oo<c<co0000o`000?l0003oc<c<02?ooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000023ooooo00?o0000ooooooooool0
1Oooool00omgMgOoIVIVooooo`0Nooooo`03o`000?oooooooooo00;ooooo00CogMgMoeEEEOoooooo
00007?ooool002Cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`05ooooo`03ogMg
Moo<c<co000000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`05o`00
0?ooooooooooooooool000001oooool01_mEEEGoQhN7ooooool0003oooooo`0002Cooooo00Go410@
okZj^_oooooo^[Zjoa0@400Sooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooo
oa0@400Pooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`03ooooo`03ogMgMoo<c<co000001cooooo000Tooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool02_ooool01Ol0003o^[ZjoooooonHV9So410@00kooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`05ooooo`03onk^k_m4A4Co000000Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`09ooooo`05o`000?ooooooooooooooool000001oooool01_oMgMgo
410@oiRHV?l0003oooooo`0002Cooooo00Go0000okZj^_oooooo^[Zjo`00000Sooooo`03o`000?oo
oooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Pooooo`03o`000?oooooooooo00;ooooo
00Go0000okZj^_ooooooV9RHoa0@400Oooooo`03o`000?oooooooooo00?ooooo00?ok^k^odA4A?l0
00007?ooool002Cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0:ooooo`05oiRH
V?l@413o0000ob4Q8Oo<c<`03_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Ko
oooo00?oMgMgo`000?ooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wo
oooo00Go0000ooooooooooooooooo`000008ooooo`04olc<c?m4A4Co0000o`0002Gooooo00GoZJVY
oa0@4?l0003o410@ojVYZ@0Qooooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0Nooooo`03oeEEEOmVIVKo000000Cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Mooooo`03
oeEEEOmVIVKo000000Kooooo00?oMgMgo`000?ooool06oooool002Cooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo00Go0000oooooooooooo
ooooo`00000:ooooo`;o0000aOooool002Cooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`0Nooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00[ooooo00Go0000ooooooooooooooooo`00000:ooooo`;o
0000aOooool002Cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Oooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00_ooooo00Co0000oooooooooooo0000dOooool002Cooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo00Co0000oooooooooooo
0000dOooool002Cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Oooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00_ooooo00Co0000oooooooooooo0000dOooool001goooooool00019o`0000?ooooo
000Tooooo`03o`000?oooooo000000;o00001_ooool00ol0003oooooooooo`07ooooo`04o`000?oo
ooooooooo`0000Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000009ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02o`0000Wooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool02Oooool002Cooooo00Co0000oooooooooooooooo0_l0000Booooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00_ooooo00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo01kooooo000Tooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooool00000d_ooool002Co
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo023o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool02oooool00ol0003oooooo`00003Booooo`009?ooool00ol0003ooooo
ooooo`03ooooo`;o00003oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooool00000d_ooool002Cooooo00?o0000ooooooooool01?ooool2o`0000kooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0<ooooo`;o0000d_ooool002Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool03?ooool2o`000=;ooooo000Tooooo`03o`000?oooooooooo00Gooooo0_l0000<oooo
o`;o00008oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`3Pooooo`009?ooool00ol0003oooooooooo`06ooooo`;o
00002oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0>3ooooo000Tooooo`?o0000
1oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
h?ooool002Cooooo00?o0000ooooooooool01oooool2o`0000[ooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo017ooooo00Go0000oooooooooooooooo
o`00003Sooooo`009?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo017ooooo00Go
0000ooooooooooooooooo`00003Sooooo`009?ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo017ooooo00Go0000ooooooooooooooooo`00003Sooooo`009?ooool00ol0003ooooooooo
o`09ooooo`;o00001_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool04Oooool01Ol0003ooooooooooooooooo00000>?ooooo000Tooooo`03o`000?oo
oooooooo00[ooooo0_l00005ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0Aooooo`05o`000?ooooooooooooooool00000hoooool002Cooooo00?o
0000ooooooooool02oooool2o`0000?ooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo017ooooo00Go0000ooooooooooooooooo`00003Sooooo`009?oo
ool00ol0003oooooooooo`0<ooooo`Co0000:Oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo01;ooooo00Go0000ooooooooooooooooo`00003Sooooo`009?ooool00ol0003ooooooooo
o`0iooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04_ooool01Ol0003ooooooooo
oooooooo00000>?ooooo000Tooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0Booooo`05o`000?ooooooooooooooool00000hoooool002Cooooo0ol0
000iooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04_ooool01?l0003ooooooooo
ool0003Tooooo`009?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool04oooool00ol0003oooooo`00003Tooooo`009?ooool00ol0003oooooooooo`0j
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04oooool00ol0003oooooo`00003T
ooooo`009?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool04oooool00ol0003oooooo`00003Tooooo`009?ooool00ol0003oooooooooo`0jooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool04oooool00ol0003oooooo`00003Tooooo`00
9?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
4oooool3o`000>Cooooo000Tooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo0>?ooooo000Tooooo`03o`000?oooooo
oooo03[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3jooooo`009?ooool00ol0
003oooooooooo`0jooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0n_ooool002Co
oooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0?[o
oooo000Tooooo`?o0000>_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0?_ooooo
000Tooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`3kooooo`009?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0noooool002Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo0?_ooooo000Tooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3kooooo`009?ooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0noooool002Cooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?_ooooo000Tooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3kooooo`0000Koooooonk^
k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00;ooooo
1Ol00006ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`3kooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q2?ooool02OmgMgOo
<S8booooooooooooV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`3kooooo`0000?ooooooa0@4?ooool00_ooool0
0ol@413oooooooooo`0>ooooo`07o`000?oooooooooooooooonHV9So8B4Qonk^kP07ooooo`?o0000
>oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?_ooooo00000ooooooo0000oooo
o`02ooooo`03o`000?oooooooooo00gooooo00?oMgMgoc8b<_ooool00oooool00onHV9So8B4Qonk^
kP06ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`3looooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0:ooooo`05o`000?lQ8B7o
0000oc8b<_o<c<`01Oooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo03cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`3looooo`0000?ooooooa0@4?ooool00_ooool0
0ol@413oooooooooo`0:ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0looooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0o?ooool0
0006oooooomgMgOoV9RHoooooonHV9SoMgMg3?ooool00ol0003oooooooooo`04ooooo`05o`000?nj
^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0o?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3?ooool4o`0000?o
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo03cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`3looooo`009?ooool00ol0003oooooooooo`0looooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0o?ooool002Cooooo00?o0000ooooooooool0
??ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?cooooo000Tooooo`03o`000?oo
oooooooo03cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3looooo`009?ooool0
0ol0003oooooooooo`0looooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0oOooool0
02Cooooo0ol0000mooooo`05o`000?ooooooooooooooool00000ooooool002Cooooo00?o0000oooo
ooooool0?Oooool01Ol0003ooooooooooooooooo00000?oooooo000Tooooo`03o`000?oooooooooo
03gooooo00Go0000ooooooooooooooooo`00003oooooo`009?ooool00ol0003oooooooooo`0moooo
o`05o`000?ooooooooooooooool00000ooooool002Cooooo00?o0000ooooooooool0?Oooool01Ol0
003ooooooooooooooooo00000?oooooo000Tooooo`03o`000?oooooooooo03kooooo00?o0000oooo
ool00000ooooool1ooooo`009?ooool00ol0003oooooooooo`0nooooo`03o`000?oooooo00000?oo
oooo0Oooool002Cooooo00?o0000ooooooooool0?_ooool3o`000?oooooo0Oooool002Cooooo00?o
0000ooooooooool0?oooool00ol0003oooooooooo`3oooooo`009?ooool00ol0003oooooooooo`3o
oooood;ooooo000Tooooo`?o0000oooooom2ooooo`009?ooool00ol0003oooooooooo`3ooooood;o
oooo000Tooooo`03o`000?oooooooooo0?oooooo@_ooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool005cooooo00KoV9RHo`000?l0003oMgMgoa0@4?l00002ooooo`07onk^k_mEEEGo
0000o`000?nHV9So0000oa0@4002ooooo`Go00000_ooool01_nHV9So0000o`000?mgMgOo410@o`00
00;ooooo00?o410@o`000?n7QhL00_l000001?mVIVKok^k^oooooonHV9P2o`000003ogMgMol@413o
000000?ooooo00GoV9RHo`000?l0003oA4A4okZj^P03ooooo`Go00000oooool01OmVIVKo0000o`00
0?m4A4Coc<c<00Kooooo1Ol00002ooooo`04oa0@4?l0003o0000ooooo`;o000000Ko410@oooooooo
ooooooooob4Q8Olb<S84ooooo`08oiRHV?l0003o0000ogMgMol@413o0000ooooool@4105o`0000Co
oooo1Ol00002ooooo`06oiRHV?l0003o0000ogMgMol@413o00000_ooool01?l@413o0000o`000?oo
ool2o`000004oa0@4?oooooooooooiRHV0;o000000?oA4A4okZj^_ooool01_ooool00olQ8B7o<S8b
ooooo`03ooooo`06oa0@4?lb<S;o0000o`000?l@413oZJVY2Oooool01OnHV9So0000o`000?m4A4Co
^[Zj00?ooooo1Ol000000ooooooo0000o`000002ooooo`07o`000?ooooooooooo`000?l@413ok^k^
oeEEE@02o`000003odA4A?nj^[[ooooo047ooooo001Looooo`05o`000?o<c<cok^k^ohN7Qol00000
0oooool01_mEEEGoMgMgooooooo^k^koEEEEo`0000Gooooo00?o0000ooooooooool00_ooool01Ol0
003oc<c<onk^k_n7QhOo000000Cooooo00co0000oeEEEOo^k^koooooogMgMomVIVKoooooo`000?o<
c<cok^k^ohN7Qol00004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001Oooool00ol0003ooooooooo
o`02ooooo`06ofIVI_mgMgOooooooooooon7QhOo410@2?ooool00ol0003oooooooooo`03ooooo`05
o`000?ooooooooooooooool000000oooool01?nHV9So<S8boa0@4?nj^[X3ooooo`05o`000?o<c<co
k^k^ohN7Qol000001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00Go
0000olc<c?o^k^koQhN7o`000004ooooo`05o`000?ooooooooooooooool000000oooool01Ol@413o
^[Zjonk^k_mgMgOo410@00Kooooo00CoV9RHoc8b<_l@413o^[Zj0oooool01_l0003oZJVYoooooooo
oooo^[Zjo`0000Wooooo00Go410@okZj^_o^k^koMgMgoa0@4005ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00000_ooool02?l0003ooooooeEEEOmgMgOoooooonk^k_mgMgOo410@
@_ooool005cooooo00Go410@ohN7Qoooooook^k^o`000003ooooo`06o`000?ooooooooooooooooo^
k^ko00001Oooool00ol0003oooooooooo`02ooooo`05oa0@4?n7QhOoooooonk^k_l000001?ooool0
0ol0003ok^k^ooooo`02ooooo`07o`000?oooooo410@ohN7Qoooooook^k^o`000004ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000003ooooo`04oa0@4?nj^[[oV9RHoc8b
<P?ooooo00Go410@ohN7Qoooooook^k^o`000004ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool00_ooool01Ol@413oQhN7ooooooo^k^ko000000Cooooo00Go0000oooooooooooooooo
o`000003ooooo`03o`000?oooooooooo00Sooooo00Co410@okZj^_nHV9So<S8b1?ooool01Onj^[[o
QhN7ofIVI_mVIVKo410@00Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0000;ooooo00?o0000ooooool00000Aoooool005cooooo00?o^[Zjoa0@
4?l000000_l00003ooooo`06o`000?ooooooooooooooooo^k^ko00001Oooool00ol0003ooooooooo
o`02ooooo`03okZj^_l@413o000000;o00001?ooool00ol0003ok^k^ooooo`02ooooo`04o`000?oo
oooo^[Zjoa0@40?o00001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool0
00000_ooool01_nHV9So<S8boooooooooooo410@okZj^P;ooooo00?o^[Zjoa0@4?l000000_l00004
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool00onj^[[o410@o`000002
o`0000Cooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Oooooo00Ko
V9RHoc8b<_oooooooooooa0@4?nj^[X2ooooo`06oc8b<_lQ8B7oMgMgogMgMon7QhOok^k^2Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool00ol0003oooooo`000005o`0004;ooooo001Oooooo`03olc<c?l0003ooooo00;ooooo00KoIVIV
ogMgMoooooook^k^oeEEEOl00005ooooo`03o`000?oooooooooo00Gooooo00?oc<c<o`000?ooool0
0oooool01_l0003oEEEEonk^k_ooooooMgMgoeEEE@Cooooo00?oc<c<o`000?ooool00oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00KoIVIVogMgMoooooooooooohN7Qol0
0008ooooo`03o`000?oooooooooo00?ooooo00Wo0000ohN7QoooooooZJVYo`000?ooooook^k^o`00
0?oMgMd00_ooool00onHV9So<S8booooo`04ooooo`03olc<c?l0003ooooo00?ooooo00?o0000oc8b
<_oMgMd01oooool00ol0003oooooooooo`05ooooo`03olc<c?l0003ooooo00?ooooo00Go0000ohN7
QoooooooZJVYo`000003ooooo`03o`000?oooooooooo00Kooooo00?ok^k^o`000?oMgMd00_ooool0
2_nHV9So<S8boooooooooooo0000okZj^_ooooook^k^ogMgMol00009ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool00_ooool03_l0003oc<c<olc<c?l0003oZJVYomgMgOlQ8B7ooooo
oeEEEOn7QhOok^k^oooooon7QhOo<S8b@_ooool005gooooo00Co<S8bo`000?l0003oV9RH0oooool0
1_o^k^koEEEEo`000?l@413oc<c<o`0000?ooooo00?o410@o`000?l000001Oooool01?lb<S;o0000
o`000?nHV9P4ooooo`06o`000?o<c<co410@o`000?mEEEGok^k^0_ooool01?lb<S;o0000o`000?nH
V9P2ooooo`03oa0@4?l0003o000000?o00001?ooool00ol@413o0000o`000004ooooo`06onk^k_mV
IVKo0000o`000?m4A4Co00001_ooool00ol@413o0000o`000004ooooo`03oa0@4?l0003oMgMg00;o
000000?oV9RHooooool@41000_l00002ooooo`?o00000_ooool01?lb<S;o0000o`000?nHV9P3oooo
o`;o000000CoZJVYob4Q8Ol0003o8B4Q0oooool00ol@413o0000o`000005ooooo`04oc8b<_l0003o
0000oiRHV0?ooooo00?o410@o`000?mgMgL00_l000000onHV9Sooooooa0@4005o`0000Gooooo00?o
410@o`000?l000000_ooool3o`000003oooooonYZJWo8B4Q00;o000000?o<S8bo`000?ooool01_oo
ool00ol@413o0000o`000003o`0000Cooooo00?o410@o`000?l000000oooool02ol@413o0000ob4Q
8Ol0003oMgMgoa0@4?l0003oZJVYooooooo^k^koEEEE00;o000000?oA4A4onk^k_ooool0@Oooool0
06Wooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
05Sooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1Looooo`00JOooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`1Booooo`00J?ooool2o`0000Gooooo00?o410@ooooooooool02_ooool00ol@413o0000
ooooo`0Hooooo`03oa0@4?oooooooooo013ooooo00?o410@ooooooooool09Oooool00ol@413ooooo
ooooo`0nooooo`03oa0@4?oooooooooo05;ooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.312, 0}} -> {-1.77328, 0.430596, \
0.0601693, 0.000620527}}]
}, Open  ]],

Cell[TextData[{
  "Initially, ",
  Cell[BoxData[
      \(TraditionalForm\`J\)]],
  " is not very well conserved. But as time goes by,  ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(\[Omega]\& . \_o/\[Omega]\_o\^2\),
            "TraditionalForm"], " ", "~", 
          " ", \(\[ExponentialE]\^\(\(-\[Alpha]\)\ t\)\)}], 
        TraditionalForm]]],
  " becomes smaller, we approach the WKB limit, and the adiabatic invariant \
is almost a constant of the motion. "
}], "Text"],

Cell[TextData[{
  "\tAdiabatic invariants can also be defined for other systems where a \
degree of freedom exhibits high-frequency oscillations. These approximate \
invariants can be related to action integrals. For in-depth discussions of \
this important subject, see  ",
  ButtonBox["Goldstein (1980, p531)",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  ", and",
  " ",
  ButtonBox["Landau and Lifshitz (1976,pg. 154)",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  StyleBox[".",
    FontSlant->"Italic"]
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["WKB Wave Packets", "Section",
  CellTags->{"i:74", "c:24"}],

Cell[TextData[{
  "Let us return now to the problem of waves on an inhomogeneous string. \
General solutions to the wave equation can be constructed out of \
superpositions of these traveling waves. In order to see how this is \
accomplished, perform a temporal Fourier transform of the wave equation ",
  ButtonBox["(5.2.1)",
    ButtonData:>"(5.2.1)",
    ButtonStyle->"Hyperlink"],
  ":  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(-\[Omega]\^2\) \(\(y\&~\)(
            x, \[Omega])\) = \(\(c\^2\)(
            x)\) \[PartialD]\^2 y\&~\/\[PartialD]x\^2\)\(,\)\)\)]],
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\(y\&~\)(x, \[Omega])\)]],
  " is the Fourier transform in time of ",
  Cell[BoxData[
      \(TraditionalForm\`y(x, t)\)]],
  ". Dividing through by ",
  Cell[BoxData[
      \(TraditionalForm\`c\^2\)]],
  ", we obtain"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\^2 y\&~\/\[PartialD]x\^2 = \(\(k\^2\)(
            x, \[Omega])\)\ \(\(y\&~\)(x, \[Omega])\)\)]],
  ","
}], "NE2",
  CellTags->"(5.2.23)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`k(x, \[Omega]) = \[Omega]/\(c(x)\)\)]],
  ". The general solution to this ODE is of the form "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(y\&~\)(
          x, \[Omega]) = \(A(\[Omega])\) \(\(\[Psi]\_1\)(
              x, \[Omega])\) + \(\(B(\[Omega])\) \(\(\[Psi]\_2\)(
              x, \[Omega])\)\(\ \)\)\)]],
  ","
}], "NE2",
  CellTags->"(5.2.24)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\_1\)(x, \[Omega])\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\_2\)(x, \[Omega])\)]],
  " are two independent solutions to this second",
  "-order",
  " ODE. Taking the inverse transform, we find that the general solution to \
Eq. ",
  ButtonBox["(5.2.23)",
    ButtonData:>"(5.2.23)",
    ButtonStyle->"Hyperlink"],
  " may be expressed as"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`y(x, 
        t) = \[Integral]\_\(-\[Infinity]\)\%\[Infinity]\(\[DifferentialD]\
\[Omega]\/\(2  \[Pi]\)\)[\(A(\[Omega])\) \
\(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\(\ \)\(\[Omega]\)\(\ \)\(t\)\(\ \ \
\)\)\) \(\(\[Psi]\_1\)(
                x, \[Omega])\)\  + \(B(\[Omega])\) \(\[ExponentialE]\^\(\(-\
\[ImaginaryI]\)\(\ \)\(\[Omega]\)\(\ \)\(t\)\(\ \ \)\)\) \(\(\[Psi]\_2\)(
                x, \[Omega])\)\ ]\)]]], "NE2",
  CellTags->"(5.2.25)"],

Cell[TextData[{
  "The functions ",
  Cell[BoxData[
      \(TraditionalForm\`A(\[Omega])\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`B(\[Omega])\)]],
  " can be used to help match to given initial conditions and/or boundary \
conditions (if any). "
}], "Text"],

Cell[TextData[{
  "\tWe  found WKB approximations for ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\_1\)(x, \[Omega])\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\_2\)(x, \[Omega])\)]],
  " previously; see Eq. ",
  ButtonBox["(5.2.15)",
    ButtonData:>"(5.2.15)",
    ButtonStyle->"Hyperlink"],
  ". Assuming that the WKB limit holds, we can use these solutions in Eq. ",
  ButtonBox["(5.2.25)",
    ButtonData:>"(5.2.25)",
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`y(x, 
          t) = \[Integral]\_\(-\[Infinity]\)\%\[Infinity]\(\[DifferentialD]\
\[Omega]\/\(2  \[Pi]\)\) \(\(A(\[Omega])\) \
\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Omega]\ t\  + \ \[ImaginaryI]\ \(\
\[Integral]\^x\( k(x, \[Omega])\) \(\(\[DifferentialD]x\)\(\ \)\)\)\)\  + \ \ \
\(B(\[Omega])\) \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Omega]\ t\  - \ \
\[ImaginaryI]\ \(\[Integral]\^x\( k(x, \[Omega])\) \(\(\[DifferentialD]x\)\(\ \
\)\)\)\)\)\/\@\(k(x, \[Omega])\)\)]],
  "."
}], "NE2",
  CellTags->"(5.2.26)"],

Cell[TextData[{
  "For the case of a nonuniform string, where ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(k(x, \[Omega]) = \[Omega]/\(c(x)\)\)\(,\)\)\)]],
  " Eq. ",
  ButtonBox["(5.2.26)",
    ButtonData:>"(5.2.26)",
    ButtonStyle->"Hyperlink"],
  " can be further simplified:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`y(x, 
          t) = \(\@\(c(
                x)\)\) \(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\(\
\[DifferentialD]\[Omega]\/\(2  \[Pi]\)\)[\(\(A\&_\)(\[Omega])\) \
\[ExponentialE]\^\(\(\ \)\(\(-\[ImaginaryI]\)\ \(\[Omega](t\  - \
\[Integral]\^x\[DifferentialD]x\/\(c(x)\)\ )\)\)\)\  + \(\(B\&_\)(\[Omega])\) \
\[ExponentialE]\^\(\(\ \)\(\(-\[ImaginaryI]\)\ \(\[Omega](\ t\ \  + \
\[Integral]\^x\[DifferentialD]x\/\(c(x)\)\ )\)\)\)]\)\)]],
  ","
}], "NE2",
  CellTags->"(5.2.27)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`A\&_ = \(\(A/\@\[Omega]\)\(\ \)\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`B\&_ = B/\@\[Omega]\)]],
  ". Let us now define a function ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Tau](x)\), "=", Cell[TextData[Cell[BoxData[
              \(TraditionalForm\`\[Integral]\^x\[DifferentialD]x\/\(c(x)\)\)]]\
]]}], TraditionalForm]]],
  "; this is the time required to propagate to point ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ". [It is convenient to leave the integral in ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau](x)\)]],
  " with an indeterminate lower bound, so we have not specified an initial \
position. To be precise, we should say that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau](x\_2) - \[Tau](
            x\_1) = \[Integral]\_\(x\_1\)\%\(x\_2\)\[DifferentialD]x\/\(c(x)\)\
\)]],
  " is the time required to propagate from ",
  Cell[BoxData[
      \(TraditionalForm\`x\_1\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`x\_2\)]],
  ".] "
}], "Text"],

Cell[TextData[{
  "\tUsing this definition for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau](x)\)]],
  " in Eq. ",
  ButtonBox["(5.2.26)",
    ButtonData:>"(5.2.26)",
    ButtonStyle->"Hyperlink"],
  ",  we can write the solution as"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(\(y(x, t)\  = \ \(\@\(c(x)\)\)[
        f(t - \[Tau](x))\  + \ g(t + \[Tau](x))]\)\(,\)\)\)]]], "NE2",
  CellTags->"(5.2.28)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(f(t)\)\(\ \)\(=\)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\(\
\[DifferentialD]\[Omega]\/\(2  \[Pi]\)\) \(\(A\&_\)(\[Omega])\) \
\[ExponentialE]\^\(\(\ \)\(\(\[ImaginaryI]\)\(\ \)\(\[Omega]\)\(\ \)\(t\)\(\ \
\)\)\)\)]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(g(t)\), " ", "=", 
          
          FormBox[\(\[Integral]\_\(-\[Infinity]\)\%\[Infinity]\(\
\[DifferentialD]\[Omega]\/\(2  \[Pi]\)\) \(\(B\&_\)(\[Omega])\) \
\[ExponentialE]\^\(\(\ \)\(\(-\[ImaginaryI]\)\(\ \)\(\[Omega]\)\(\ \)\(t\)\(\ \
\)\)\)\),
            "TraditionalForm"], " "}], TraditionalForm]]],
  " are Fourier transforms of  ",
  Cell[BoxData[
      \(TraditionalForm\`A\&_\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`B\&_\)]],
  ". This WKB form of the general solution to the  wave equation for an \
inhomogeneous medium has much in common with the expression for the \
d'Alembert solution for a homogeneous medium, Eq. ",
  ButtonBox["(5.1.11)",
    ButtonData:>"(5.1.11)",
    ButtonStyle->"Hyperlink"],
  ". Like Eq. ",
  ButtonBox["(5.1.11)",
    ButtonData:>"(5.1.11)",
    ButtonStyle->"Hyperlink"],
  ", Eq. ",
  ButtonBox["(5.2.28)",
    ButtonData:>"(5.2.28)",
    ButtonStyle->"Hyperlink"],
  " describes two counter-propagating wave packets. But now the time required \
to propagate to position ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " is  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau](x)\)]],
  " rather than ",
  Cell[BoxData[
      \(TraditionalForm\`x/c\)]],
  ",  and the shape and amplitude of the packets vary."
}], "Text"],

Cell[TextData[{
  "\tFor example, let us consider an initially Gaussian packet, ",
  Cell[BoxData[
      \(TraditionalForm\`y(x, 
          0) = \(\(y\_o\)(x)\  = \ \[ExponentialE]\^\(-x\^2\)\)\)]],
  ",  moving to the right. Then we can take ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(g = 0\)\(,\)\)\)]],
  " since this part of the solution describes a packet moving to the left. \
Also, ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  " is determined by the initial condition,"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`y(x, 
          0)\  = \(\(\(\@\(c(x)\)\) \(f(\(-\(\[Tau](
                  x)\)\))\)\)\(\ \)\(=\)\(\ \)\(\(y\_o\)(x)\)\(\ \)\)\)]],
  ". "
}], "NE2",
  CellTags->"(5.2.29)"],

Cell[TextData[{
  "We can solve this equation for ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  " by inverting the function ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau](x)\)]],
  ", given that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau]\)]],
  " increases monotonically with ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ". Let ",
  Cell[BoxData[
      \(TraditionalForm\`X(t)\)]],
  " be the solution for ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " to the equation ",
  Cell[BoxData[
      \(TraditionalForm\`t = \[Tau](x)\)]],
  ", for given ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  ". If we let ",
  Cell[BoxData[
      \(TraditionalForm\`t = \[Tau](x)\)]],
  " in Eq. ",
  ButtonBox["(5.2.29)",
    ButtonData:>"(5.2.29)",
    ButtonStyle->"Hyperlink"],
  ", then ",
  Cell[BoxData[
      \(TraditionalForm\`x\  = \ X(t)\)]],
  " , and the equation becomes"
}], "Text"],

Cell[TextData[{
  "  ",
  Cell[BoxData[
      \(TraditionalForm\`f(\(-t\))\  = \(\(\(\(y\_o\)(
            X(t))\)/\@\(c(X(t))\)\)\(\ \)\)\)]],
  ","
}], "NE2",
  CellTags->"(5.2.30)"],

Cell[TextData[{
  " This equation determines ",
  Cell[BoxData[
      \(TraditionalForm\`f(t)\)]],
  ", and when used in Eq. ",
  ButtonBox["(5.2.28)",
    ButtonData:>"(5.2.28)",
    ButtonStyle->"Hyperlink"],
  " it provides us with the solution for the motion of the ",
  "wave packet",
  ". "
}], "Text"],

Cell[TextData[{
  "\tWe will work out the WKB solution for the case ",
  Cell[BoxData[
      \(TraditionalForm\`c(
          x)\  = \ \(c\_o\) \[ExponentialE]\^\(\(-x\)/2  L\)\)]],
  " discussed previously. Then ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau](
          x)\  = \(\[Integral]\^x\[DifferentialD]x\/\(c(x)\) = \(\(\(2  
                  L\)\/c\_o\) \(\[ExponentialE]\^\(x/2  L\)\)\(\ \)\)\)\)]],
  ". This shows that it takes exponentially longer to travel to larger ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ", because the wave is slowing down as ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(x\)\(\ \)\)\)]],
  "increases. The solution for ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " to the equation ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau](x) = t\)]],
  " is  ",
  Cell[BoxData[
      \(TraditionalForm\`X(t)\  = \ 
        2  L\ ln[\(c\_\(\(o\)\(\ \)\)\) t/\((2  L)\)]\)]],
  ".  Then Eq. ",
  ButtonBox["(5.2.30)",
    ButtonData:>"(5.2.30)",
    ButtonStyle->"Hyperlink"],
  " implies ",
  Cell[BoxData[
      \(TraditionalForm\`f(\(-t\))\  = \ \[ExponentialE]\^\(-\ \
\(\(X\^2\)(t)\)\)\ \@\(t/\((2  L)\)\)\)]],
  ". Using this expression in Eq. ",
  ButtonBox["(5.2.28)",
    ButtonData:>"(5.2.28)",
    ButtonStyle->"Hyperlink"],
  ", together with our expression for ",
  Cell[BoxData[
      \(TraditionalForm\`T(x)\)]],
  ", provides us with the required solution for the propagation of the packet \
in the WKB approximation. This is shown in Cell ",
  ButtonBox["5.23",
    ButtonData:>"Cell 5.23",
    ButtonStyle->"Hyperlink"],
  ", taking ",
  Cell[BoxData[
      \(TraditionalForm\`L = 2, c\_o = 1\)]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(c[x_]\  = \ c\_o\ \[ExponentialE]\^\(\(-x\)/\((2  L)\)\);\)\), "\n", 
    \(\(\[Tau][
          x_]\  = \ \(\(2  
                L\)\/c\_o\) \[ExponentialE]\^\(x/\((2  L)\)\);\)\), "\n", 
    \(\(X[t_]\  = \ 
        2  L\ \ Log[\(c\_\(\(o\)\(\ \)\)\) t/\((2  L)\)];\)\), "\n", 
    \(\(\(f[
          t_]\  = \ \ \[ExponentialE]\^\(-X[\(-t\)]^2\)\ \@\(\(-t\)/\((2  \
L)\)\);\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(y[x_, 
          t_]\  = \ \(\@c[x]\) f[t - \[Tau][x]]\  /. {c\_o \[Rule] 1, \ 
            L \[Rule] 2};\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(Table[
        Plot[y[x, t], {x, \(-3\), 15}, 
          PlotRange \[Rule] {{\(-3\), 10}, {\(-0.2\), 1}}, 
          AxesLabel \[Rule] {"\<x\>", "\<\>"}, 
          PlotLabel \[Rule] "\<y[x,t], t =\>" <> ToString[t]], {t, 0, 30, 
          1}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 5.23"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.230769 0.0769231 0.103006 0.515028 [
[.07692 .09051 -6 -9 ]
[.07692 .09051 6 0 ]
[.38462 .09051 -3 -9 ]
[.38462 .09051 3 0 ]
[.53846 .09051 -3 -9 ]
[.53846 .09051 3 0 ]
[.69231 .09051 -3 -9 ]
[.69231 .09051 3 0 ]
[.84615 .09051 -3 -9 ]
[.84615 .09051 3 0 ]
[1 .09051 -6 -9 ]
[1 .09051 6 0 ]
[1.025 .10301 0 -6 ]
[1.025 .10301 10 6 ]
[.21827 0 -24 -4.5 ]
[.21827 0 0 4.5 ]
[.21827 .20601 -18 -4.5 ]
[.21827 .20601 0 4.5 ]
[.21827 .30902 -18 -4.5 ]
[.21827 .30902 0 4.5 ]
[.21827 .41202 -18 -4.5 ]
[.21827 .41202 0 4.5 ]
[.21827 .51503 -18 -4.5 ]
[.21827 .51503 0 4.5 ]
[.21827 .61803 -6 -4.5 ]
[.21827 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07692 .10301 m
.07692 .10926 L
s
[(-2)] .07692 .09051 0 1 Mshowa
.38462 .10301 m
.38462 .10926 L
s
[(2)] .38462 .09051 0 1 Mshowa
.53846 .10301 m
.53846 .10926 L
s
[(4)] .53846 .09051 0 1 Mshowa
.69231 .10301 m
.69231 .10926 L
s
[(6)] .69231 .09051 0 1 Mshowa
.84615 .10301 m
.84615 .10926 L
s
[(8)] .84615 .09051 0 1 Mshowa
1 .10301 m
1 .10926 L
s
[(10)] 1 .09051 0 1 Mshowa
.125 Mabswid
.11538 .10301 m
.11538 .10676 L
s
.15385 .10301 m
.15385 .10676 L
s
.19231 .10301 m
.19231 .10676 L
s
.26923 .10301 m
.26923 .10676 L
s
.30769 .10301 m
.30769 .10676 L
s
.34615 .10301 m
.34615 .10676 L
s
.42308 .10301 m
.42308 .10676 L
s
.46154 .10301 m
.46154 .10676 L
s
.5 .10301 m
.5 .10676 L
s
.57692 .10301 m
.57692 .10676 L
s
.61538 .10301 m
.61538 .10676 L
s
.65385 .10301 m
.65385 .10676 L
s
.73077 .10301 m
.73077 .10676 L
s
.76923 .10301 m
.76923 .10676 L
s
.80769 .10301 m
.80769 .10676 L
s
.88462 .10301 m
.88462 .10676 L
s
.92308 .10301 m
.92308 .10676 L
s
.96154 .10301 m
.96154 .10676 L
s
.03846 .10301 m
.03846 .10676 L
s
.25 Mabswid
0 .10301 m
1 .10301 L
s
gsave
1.025 .10301 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.23077 0 m
.23702 0 L
s
[(-0.2)] .21827 0 1 0 Mshowa
.23077 .20601 m
.23702 .20601 L
s
[(0.2)] .21827 .20601 1 0 Mshowa
.23077 .30902 m
.23702 .30902 L
s
[(0.4)] .21827 .30902 1 0 Mshowa
.23077 .41202 m
.23702 .41202 L
s
[(0.6)] .21827 .41202 1 0 Mshowa
.23077 .51503 m
.23702 .51503 L
s
[(0.8)] .21827 .51503 1 0 Mshowa
.23077 .61803 m
.23702 .61803 L
s
[(1)] .21827 .61803 1 0 Mshowa
.125 Mabswid
.23077 .02575 m
.23452 .02575 L
s
.23077 .0515 m
.23452 .0515 L
s
.23077 .07725 m
.23452 .07725 L
s
.23077 .12876 m
.23452 .12876 L
s
.23077 .15451 m
.23452 .15451 L
s
.23077 .18026 m
.23452 .18026 L
s
.23077 .23176 m
.23452 .23176 L
s
.23077 .25751 m
.23452 .25751 L
s
.23077 .28327 m
.23452 .28327 L
s
.23077 .33477 m
.23452 .33477 L
s
.23077 .36052 m
.23452 .36052 L
s
.23077 .38627 m
.23452 .38627 L
s
.23077 .43777 m
.23452 .43777 L
s
.23077 .46353 m
.23452 .46353 L
s
.23077 .48928 m
.23452 .48928 L
s
.23077 .54078 m
.23452 .54078 L
s
.23077 .56653 m
.23452 .56653 L
s
.23077 .59228 m
.23452 .59228 L
s
.25 Mabswid
.23077 0 m
.23077 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
123.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .10307 m
.00326 .10309 L
.00676 .10311 L
.01005 .10314 L
.01305 .10318 L
.01657 .10323 L
.0204 .1033 L
.02401 .10338 L
.02734 .10348 L
.034 .10375 L
.03779 .10396 L
.04134 .1042 L
.04848 .10488 L
.0525 .1054 L
.05617 .10599 L
.05994 .10672 L
.06396 .10768 L
.07118 .10997 L
.07561 .11181 L
.07978 .11393 L
.08757 .11911 L
.09504 .1259 L
.10191 .13414 L
.10946 .14583 L
.11743 .16175 L
.13121 .19945 L
.14598 .25582 L
.17263 .39392 L
.1866 .47337 L
.20143 .54833 L
.20917 .57899 L
.21328 .59208 L
.21771 .6034 L
.21968 .60745 L
.22176 .61102 L
.22368 .61368 L
.22547 .6156 L
.22716 .6169 L
.22896 .61775 L
.22998 .61798 L
.23095 .61803 L
.23277 .61769 L
.23449 .61683 L
.23611 .61556 L
.23788 .61365 L
.23979 .611 L
.24368 .60374 L
.24723 .59499 L
.25407 .57289 L
.26056 .54629 L
Mistroke
.29069 .38372 L
.30573 .30227 L
.31987 .23762 L
.33258 .19236 L
.3463 .15699 L
.35356 .14329 L
.36123 .13202 L
.36778 .12459 L
.37495 .11835 L
.38258 .11348 L
.38685 .1114 L
.39074 .10982 L
.39437 .1086 L
.39831 .10749 L
.40175 .10669 L
.40546 .10597 L
.40916 .10538 L
.41254 .10494 L
.41917 .10428 L
.42268 .10403 L
.42653 .1038 L
.43059 .10361 L
.43427 .10348 L
.43822 .10336 L
.44193 .10328 L
.44586 .10321 L
.45011 .10316 L
.45384 .10312 L
.45778 .10309 L
.46114 .10307 L
.46483 .10305 L
.46847 .10304 L
.47244 .10303 L
.47618 .10303 L
.47964 .10302 L
.48276 .10302 L
.4862 .10301 L
.48979 .10301 L
.49316 .10301 L
.49687 .10301 L
.50079 .10301 L
.50413 .10301 L
.50778 .10301 L
.51173 .10301 L
.51394 .10301 L
.51595 .10301 L
.51783 .10301 L
.51986 .10301 L
.52356 .10301 L
.52697 .10301 L
Mistroke
.53065 .10301 L
.53412 .10301 L
.53729 .10301 L
.541 .10301 L
.5431 .10301 L
.54505 .10301 L
.54862 .10301 L
.55061 .10301 L
.55242 .10301 L
.55433 .10301 L
.55636 .10301 L
.55999 .10301 L
.562 .10301 L
.56389 .10301 L
.56609 .10301 L
.56817 .10301 L
.56996 .10301 L
.57191 .10301 L
.57533 .10301 L
.57726 .10301 L
.57931 .10301 L
.58107 .10301 L
.583 .10301 L
.58647 .10301 L
.58836 .10301 L
.59011 .10301 L
.59327 .10301 L
.59503 .10301 L
.59663 .10301 L
.5984 .10301 L
.60026 .10301 L
.60231 .10301 L
.60419 .10301 L
.60759 .10301 L
.60952 .10301 L
.61133 .10301 L
.61297 .10301 L
.61477 .10301 L
.61635 .10301 L
.61803 .10301 L
.61969 .10301 L
.6212 .10301 L
.62415 .10301 L
.62592 .10301 L
.62756 .10301 L
.62931 .10301 L
.63124 .10301 L
.63449 .10301 L
.63626 .10301 L
.63791 .10301 L
Mistroke
.63976 .10301 L
.64171 .10301 L
.64338 .10301 L
.64522 .10301 L
.6472 .10301 L
.64932 .10301 L
.65132 .10301 L
.65316 .10301 L
.65499 .10301 L
.65669 .10301 L
.65856 .10301 L
.66055 .10301 L
.66245 .10301 L
.66424 .10301 L
.66584 .10301 L
.66758 .10301 L
.66927 .10301 L
.67084 .10301 L
.67257 .10301 L
.67442 .10301 L
.67636 .10301 L
.6782 .10301 L
.67985 .10301 L
.68164 .10301 L
.68319 .10301 L
.6849 .10301 L
.68669 .10301 L
.68836 .10301 L
.68982 .10301 L
.69136 .10301 L
.69304 .10301 L
.69458 .10301 L
.69638 .10301 L
.69832 .10301 L
.70015 .10301 L
.70185 .10301 L
.70337 .10301 L
.70505 .10301 L
.70681 .10301 L
.70845 .10301 L
.71036 .10301 L
.71218 .10301 L
.71381 .10301 L
.71559 .10301 L
.71752 .10301 L
.71958 .10301 L
.72151 .10301 L
.72327 .10301 L
.72495 .10301 L
.72671 .10301 L
Mistroke
.72822 .10301 L
.72988 .10301 L
.73167 .10301 L
.73358 .10301 L
.73538 .10301 L
.73702 .10301 L
.73868 .10301 L
.74021 .10301 L
.74189 .10301 L
.74367 .10301 L
.74522 .10301 L
.74667 .10301 L
.74826 .10301 L
.74997 .10301 L
.7518 .10301 L
.75346 .10301 L
.75538 .10301 L
.75719 .10301 L
.75887 .10301 L
.76042 .10301 L
.76212 .10301 L
.76391 .10301 L
.76572 .10301 L
.76766 .10301 L
.7695 .10301 L
.77117 .10301 L
.77313 .10301 L
.77424 .10301 L
.77526 .10301 L
.77715 .10301 L
.7781 .10301 L
.77915 .10301 L
.78108 .10301 L
.78205 .10301 L
.78311 .10301 L
.785 .10301 L
.78676 .10301 L
.78782 .10301 L
.78883 .10301 L
.79072 .10301 L
.79178 .10301 L
.79276 .10301 L
.79382 .10301 L
.79497 .10301 L
.79674 .10301 L
.7984 .10301 L
.79942 .10301 L
.80038 .10301 L
.80219 .10301 L
.80408 .10301 L
Mistroke
.80585 .10301 L
.80686 .10301 L
.80778 .10301 L
.80877 .10301 L
.80984 .10301 L
.81159 .10301 L
.81322 .10301 L
.81421 .10301 L
.81516 .10301 L
.81693 .10301 L
.81879 .10301 L
.82051 .10301 L
.82241 .10301 L
.82336 .10301 L
.82442 .10301 L
.82615 .10301 L
.82775 .10301 L
.82949 .10301 L
.83133 .10301 L
.83294 .10301 L
.83444 .10301 L
.83608 .10301 L
.83783 .10301 L
.83882 .10301 L
.83986 .10301 L
.84174 .10301 L
.84279 .10301 L
.84376 .10301 L
.8449 .10301 L
.84599 .10301 L
.84692 .10301 L
.84793 .10301 L
.8497 .10301 L
.8507 .10301 L
.85177 .10301 L
.85369 .10301 L
.85556 .10301 L
.85662 .10301 L
.85759 .10301 L
.85937 .10301 L
.86125 .10301 L
.86294 .10301 L
.86452 .10301 L
.86625 .10301 L
.8681 .10301 L
.86988 .10301 L
.87089 .10301 L
.87184 .10301 L
.87375 .10301 L
.87483 .10301 L
Mistroke
.87581 .10301 L
.87756 .10301 L
.87946 .10301 L
.88126 .10301 L
.88293 .10301 L
.88394 .10301 L
.88504 .10301 L
.886 .10301 L
.88702 .10301 L
.88794 .10301 L
.88895 .10301 L
.89073 .10301 L
.89181 .10301 L
.8928 .10301 L
.89387 .10301 L
.89503 .10301 L
.8961 .10301 L
.89709 .10301 L
.89811 .10301 L
.89905 .10301 L
.90072 .10301 L
.90252 .10301 L
.90411 .10301 L
.90579 .10301 L
.90763 .10301 L
.90934 .10301 L
.91122 .10301 L
.91228 .10301 L
.91324 .10301 L
.91417 .10301 L
.91517 .10301 L
.91696 .10301 L
.91888 .10301 L
.91997 .10301 L
.92099 .10301 L
.92284 .10301 L
.92452 .10301 L
.92545 .10301 L
.92647 .10301 L
.92832 .10301 L
.92926 .10301 L
.93026 .10301 L
.93204 .10301 L
.93395 .10301 L
.93504 .10301 L
.93606 .10301 L
.9379 .10301 L
.93957 .10301 L
.9405 .10301 L
.94151 .10301 L
Mistroke
.94334 .10301 L
.94497 .10301 L
.94677 .10301 L
.94865 .10301 L
.95041 .10301 L
.95205 .10301 L
.95356 .10301 L
.95521 .10301 L
.95695 .10301 L
.95886 .10301 L
.9606 .10301 L
.96157 .10301 L
.96261 .10301 L
.9645 .10301 L
.96628 .10301 L
.96816 .10301 L
.96976 .10301 L
.97152 .10301 L
.97259 .10301 L
.9736 .10301 L
.97549 .10301 L
.97655 .10301 L
.97753 .10301 L
.97861 .10301 L
.97975 .10301 L
.98076 .10301 L
.98184 .10301 L
.98286 .10301 L
.98379 .10301 L
.98557 .10301 L
.98745 .10301 L
.98924 .10301 L
.99024 .10301 L
.99117 .10301 L
.99288 .10301 L
.9947 .10301 L
.99631 .10301 L
.99783 .10301 L
.9995 .10301 L
Mfstroke
.9995 .10301 m
1 .10301 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000oooooolLooooo`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0oooooolLooooo`00<?ooool6o`0000;o
oooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^0?oooooo7Oooool003So
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003ooooo
oa?ooooo000hooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05oooo
o`03o`000?oooooooooo0?oooooo4oooool003Sooooo00Go410@oooooooooooooooooa0@400?oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooo
oooo0?oooooo4oooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooo
oooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003ooooooooo
o`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000oooo
ooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`00
0?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool0
0ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o
0000ooooooooool0oooooolCooooo`008oooool5o`0002_ooooo00?o0000ooooooooool0:oooool5
o`0002kooooo0_l000000ol@413oooooooooo`0Zooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?oo
ool01Oo<c<co8B4Qo`000?lQ8B7oc<c<02Wooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`00
0?lb<S;ok^k^6_ooool002?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00[ooooo`03o`000?oooooo
oooo02_ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00_ooooo`03o`000?oooooooooo02_ooooo00Go
EEEEogMgMoooooooV9RHob4Q8@0/ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40:oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool001_ooooo1_l00003ooooo`03
oiRHV?lQ8B7ok^k^02cooooo00?o0000ooooooooool0;?ooool00onHV9So8B4Qonk^kP0]ooooo`Go
0000;?ooool01Ol0003ooooooooooooooooo000002cooooo00Go0000ooooooooooooooooo`00000[
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Jooooo`009Oooool0
0onHV9So8B4Qonk^kP0[ooooo`03o`000?oooooooooo02gooooo00?oV9RHob4Q8Oo^k^h0;?ooool0
1?m4A4CogMgMooooool0000]ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;?ooool01Olb<S;oV9RH
oooooonHV9So<S8b02_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
01[ooooo000Vooooo`03ogMgMomVIVKooooo02[ooooo0_l0000_ooooo`03ogMgMomVIVKooooo02_o
oooo00CogMgMoeEEEOoooooo0000;Oooool01Ol0003oEEEEo`000?l@413oc<c<02cooooo00Goc<c<
o`000?l0003o0000olc<c00[ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Jooooo`009oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool0:oooool00omgMgOoc<c<o`00000]ooooo`03oeEEEOn7QhOooooo02kooooo00Go
410@okZj^_oooooo^[Zjoa0@400[ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@400Jooooo`008oooool01Ol0003o^[ZjoooooonHV9So410@02_ooooo00?o0000oooooooo
ool0:oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo00?ok^k^odA4A?l00000;Oooool00ooM
gMgo410@oiRHV00^ooooo`05o`000?nj^[[ooooookZj^_l00000:oooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool002?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00[ooooo`03o`000?oooooooooo02_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00^ooooo`03ogMg
Mol0003ooooo02gooooo00Coc<c<odA4A?l0003o410@;?ooool01OnYZJWo410@o`000?l@413oZJVY
02Wooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo001Coooo
o`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00
Doooool00ol0003oooooooooo`3mooooo`;o00000_ooool2o`0000oooooo001Cooooo`03o`000?oo
oooooooo0?gooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd?ooooo`00Doooool00ol0003ooooo
ooooo`3nooooo`04omgMgOl0003o410@olc<c13ooooo000:oooooooo0000@?l0000;ooooo`04onk^
k_lQ8B7o410@onk^kQ3ooooo000Fooooo`03o`000?oooooooooo00Cooooo0ol00002ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03o`0000Kooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02Oooool01?lQ8B7oMgMgogMgMolb<S8@ooooo`008?ooool3o`00033ooooo
00?o0000ooooooooool0;_ooool3o`0002kooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`0^ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool02?ooool2o`0000;ooooo
0_l0000?ooooo`008oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo02cooooo0_l0
003Tooooo`009?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo02_ooooo00?o0000
ooooooooool0i?ooool002Gooooo0_l0000/ooooo`03o`000?oooooooooo02[ooooo00?o0000oooo
ooooool0iOooool002Oooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Yooooo`03
o`000?oooooooooo0>Kooooo000Xooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`3Vooooo`00:Oooool00ol0003oooooooooo`0Wooooo`;o0000:Ooo
ool00ol0003oooooooooo`3Wooooo`00:_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo02Oooooo00?o0000ooooooooool0j?ooool002[ooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo0>Wooooo000[ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`3Zooooo`00:oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0joooool002cooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo0>_ooooo000/
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`3/
ooooo`00;Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02?ooooo00?o0000oooo
ooooool0k?ooool002kooooo00?o0000ooooooooool08_ooool2o`0002Cooooo00?o0000oooooooo
ool0k?ooool002kooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Rooooo`03o`00
0?oooooooooo0>gooooo000_ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool08_oo
ool00ol0003oooooooooo`3]ooooo`00;oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool0k_ooool0033ooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`0Qooooo`03o`000?oooooooooo0>kooooo000`ooooo`03o`000?oooooooooo023o
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`3_ooooo`00<?ooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0koooool0037ooooo00?o
0000ooooooooool07oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo0?3ooooo000a
ooooo`03o`000?oooooooooo01oooooo0_l0000Pooooo`03o`000?oooooooooo0?3ooooo000aoooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`3`oooo
o`00<_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool0lOooool003;ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo0?7ooooo000booooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`3booooo`00<oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool0l_ooool003?ooooo00?o0000ooooooooool00_ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo0?;ooooo000cooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`3cooooo`00<oooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP07ooooo`?o00007?oo
ool00ol0003oooooooooo`3cooooo`00=?ooool01Ol0003ooooooooooooooooo000000?ooooo00?o
0000ooooooooool02oooool00onHV9So8B4Qonk^kP06ooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool0loooool003Cooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oo
oooooooo00cooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo0?Cooooo000dooooo`05o`000?ooooooooooooooool@41000oooool00ol@413ooooooooo
o`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`3dooooo`00=Oooool02?l0003ooooooooooomgMgOoV9RHoooooonHV9SoMgMg2oooool01Ol0003o
^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`3doooo
o`00=Oooool02?l0003oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^2oooool01OnHV9So410@o`00
0?lQ8B7oc<c<00Kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`3dooooo`00=Ooo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0mOoo
ool003Gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo0?Gooooo000fooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`3eooooo`00=_ooool00ol0003oooooooooo`0Jooooo`;o00006_ooool00ol0003o
ooooooooo`3fooooo`00=_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool0m_ooool003Kooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo0?Kooooo000gooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`3fooooo`00=oooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0m_ooool003Oooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo0?Oooooo000hooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`3gooooo`00>?oo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0mooo
ool003Sooooo00?o0000ooooooooool06?ooool2o`0001Wooooo00?o0000ooooooooool0moooool0
03Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
0?Oooooo000iooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`3hooooo`00>Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool0n?ooool003Wooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo0?Sooooo000iooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`3hooooo`00>Oooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0n?ooool003[ooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo0?Wooooo000jooooo`03o`00
0?oooooooooo01Kooooo0_l0000Gooooo`03o`000?oooooooooo0?Wooooo000jooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`3iooooo`00>_ooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0nOooool0
03[ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
0?Wooooo000kooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`3jooooo`00>oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool0n_ooool003Sooooo00Gok^k^oc8b<_l0003o0000onk^kP05ooooo`;o8B4Q
1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`3jooooo`00>?ooool01OmgMgOoV9RHooooool0003oMgMg00Gooooo0_lQ8B47ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`3jooooo`00>?oo
ool01Ol@413oooooooooool0003o410@00_ooooo1Ol00006ooooo`?o00005Oooool00ol0003ooooo
ooooo`3jooooo`00>?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo
00001oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0?[ooooo000hooooo`05o`00
0?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0noooool003Sooooo00Go410@ooooooooooooooooo`00000<oooo
o`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`3koooo
o`00>?ooool01OmgMgOoV9RHoooooonHV9So000000cooooo00?ok^k^odA4A?l000001oooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo0?_ooooo000hooooo`05onk^k_lb<S;o0000oc8b
<_l000003Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool0noooool003gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo0?_ooooo000mooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`3looooo`00?Oooool00ol0003oooooooooo`0Cooooo`;o00005?oo
ool00ol0003oooooooooo`3looooo`00?Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool0o?ooool003gooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo0?cooooo000nooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`3looooo`00?_ooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0oOooool003kooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo0?gooooo000n
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`3m
ooooo`00?_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool0oOooool003oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo0?gooooo000oooooo`03o`000?oooooooooo017ooooo0_l0000Booooo`03o`00
0?oooooooooo0?kooooo000oooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`3nooooo`00?oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool0o_ooool003oooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo0?kooooo0010ooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`3nooooo`00@?ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0ooooool0043ooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo0?oooooo0010
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`3o
ooooo`00@?ooool00ol0003oooooooooo`0@ooooo`;o00004Oooool00ol0003oooooooooo`3ooooo
o`00@Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool0ooooool0047ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo0?oooooo0011ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`3oooooo`7ooooo0011ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`3oooooo`7ooooo000hooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01?ooool00ol0003o8B4Qob4Q8@04ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0?oooooo0Oooool003Sooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`03o`000?lQ8B7ooooo00?ooooo00GoEEEEogMgMoooooooV9RH
ob4Q8@06ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0ooooool1ooooo`00>?oo
ool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000ooooooooool00oooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`3oooooo`7o
oooo000hooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`03ooooo`05
o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`0000oooooo00?o0000ooooooooool0ooooool1oooo
o`00>?ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool00oooool01Ol0
003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`3o
ooooo`;ooooo000hooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`03
ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`3o
ooooo`;ooooo000hooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`03
ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`3o
ooooo`;ooooo000hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`03
ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`3oooooo`;ooooo0013ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`3oooooo`;ooooo0013ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`3oooooo`?ooooo0013ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`3oooooo`?ooooo0013ooooo`03o`00
0?oooooooooo00gooooo0_l0000>ooooo`03o`000?oooooooooo0?oooooo0oooool004?ooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo0?oooooo0ooo
ool004?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo0?oooooo0oooool004Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo0?oooooo0oooool004Cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo0?oooooo1?ooool004Cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo0?oooooo1?ooool004Cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo0?oooooo1?oo
ool004Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo0?oooooo1?ooool004Cooooo00?o0000ooooooooool03?ooool2o`0000gooooo00?o0000oooo
ooooool0ooooool4ooooo`00AOooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool0ooooool4ooooo`00AOooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool0ooooool5ooooo`00AOooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0ooooool5ooooo`00AOooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0ooooool5
ooooo`00AOooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool0ooooool5ooooo`00A_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool0ooooool5ooooo`00A_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool0ooooool5ooooo`00A_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0ooooool6ooooo`00A_ooool0
0ol0003oooooooooo`0:ooooo`;o00002oooool00ol0003oooooooooo`3oooooo`Kooooo0016oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`3ooooo
o`Kooooo0017ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`3oooooo`Kooooo0017ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`3oooooo`Kooooo0017ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`3oooooo`Kooooo000hooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@?ooooo00Ko0000olc<c?lQ8B7o0000ob4Q8Oo<c<`6ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool0ooooool7ooooo`00>?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B43ooooo`06o`000?lQ8B7oV9RHoooooonHV9So8B4Q1_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo0?oooooo1oooool003Sooooo00Go410@oooo
oooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo0?oooooo1oooool003Sooooo00Go0000ooooooooooooooooo`00
000;ooooo`05o`000?nHV9SooooooiRHV?lb<S801_ooool3o`0000Wooooo00?o0000ooooooooool0
ooooool7ooooo`00>?ooool01Ol0003ooooooooooooooooo000000_ooooo1?l000000oo<c<cooooo
ooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0ooooool7ooooo`00>?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000okZj^_oooooo^[Zjoa0@4006ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool0ooooool8ooooo`00>?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0ooooool8ooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00_ooooo00GoZJVYo`000?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool0ooooool8ooooo`00BOooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0ooooool8ooooo`00BOooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool0ooooool8ooooo`00BOooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0ooooool8ooooo`00BOoo
ool00ol0003oooooooooo`07ooooo`;o00002?ooool00ol0003oooooooooo`3oooooo`Wooooo001:
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3o
ooooo`Wooooo001:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`3oooooo`Wooooo001:ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`3oooooo`Wooooo001:ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooo`[ooooo001;ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3oooooo`[ooooo001;
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3o
ooooo`[ooooo001;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3oooooo`_ooooo001;ooooo`03o`000?oooooooooo00Gooooo0_l00006ooooo`03
o`000?oooooooooo0?oooooo2oooool004_ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo0?oooooo2oooool004cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo3?ooool004cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo3?ooool0
04cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
0?oooooo3?ooool004cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo0?oooooo3Oooool004cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo0?oooooo3Oooool004gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo3Oooool004gooooo00?o0000
ooooooooool00oooool2o`0000?ooooo00?o0000ooooooooool0ooooool>ooooo`00COooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0ooooool>oooo
o`00C_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0ooooool>ooooo`00C_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
0000oooooolAooooo`00Coooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooooooo
ool0ooooool?ooooo`00D?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo0?oo
oooo3oooool004Wooooo1?l000001?l@413oooooooooool00002ooooo`04o`000?ooooooooooo`00
0?oooooo4_ooool004_ooooo00?o0000ooooooooool00oooool01Ol0003oooooo`000?oooooo0000
0?oooooo4oooool004_ooooo00?o0000ooooooooool00oooool5o`000?oooooo4oooool004_ooooo
00?o0000ooooooooool01Oooool3o`000?oooooo4oooool004_ooooo00?o0000ooooooooool0oooo
oolKooooo`00Boooool00ol0003oooooooooo`3ooooooa_ooooo001;ooooo`03o`000?oooooooooo
0?oooooo6oooool004Wooooo00?oEEEEofIVI_l00000oooooolMooooo`00O?ooool3o`000003oa0@
4?oooooooooo0>Kooooo001nooooo`03oa0@4?nj^[[ooooo00Kooooo0_l0000;ooooo`03o`000?nj
^[[ooooo00cooooo0_l00006ooooo`03o`000?nj^[[ooooo0;[ooooo001nooooo`03oiRHV?lb<S;o
oooo00Kooooo00?o0000ooooooooool02_ooool2oc8b<Pkooooo00?o0000ooooooooool01?ooool2
oc8b<[_ooooo001nooooo`03omgMgOl0003o^[Zj00Kooooo00?o0000ooooooooool00_ooool2o`00
00;ooooo0_l00002ooooo`03ohN7Qol0003o^[Zj00Gooooo00GoV9RHo`000?l0003oA4A4okZj^P03
ooooo`03o`000?oooooooooo00Cooooo00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4
A4Co^[Zj013ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP2Dooooo`00O_ooool00omEEEGoMgMgodA4
A006ooooo`03o`000?oooooooooo00;ooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd2ooooo`03
olc<c?l0003o410@00Gooooo00Go410@okZj^_o^k^koMgMgoa0@4003ooooo`03o`000?oooooooooo
00Cooooo00?oc<c<o`000?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l00000
1_ooooooMgMgoiRHV?ooooooV9RHogMgMiCooooo001mooooo`05omgMgOl@413oooooob4Q8OoMgMd0
1Oooool00ol0003oooooooooo`03ooooo`04omgMgOl0003o410@olc<c0_ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00Go410@oooooooo
oooooooooa0@402Dooooo`00OOooool01OmVIVKoQhN7oooooonHV9SoEEEE00Gooooo00?o0000oooo
ooooool00oooool01?o^k^ko8B4Qoa0@4?o^k^h;ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`0;ooooo`Ko000000?oooooo`000?ooool00_ooool0
0ol0003oooooooooo`2Booooo`00O?ooool00oo^k^ko0000onk^kP02ooooo`03o`000?oMgMgooooo
00?ooooo00?o0000ooooooooool00oooool01?lQ8B7oMgMgogMgMolb<S8;ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`05o`000?oooooo
ooooooooool00000U?ooool007cooooo00Co410@o`000?l0003ooooo0_l000000ol@413ooooooooo
o`02ooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`;o00002?ooool00ol@413o0000o`00
0003o`0000Cooooo00?o0000ooooooooool04Oooool00ol@413o0000o`000003o`00017ooooo00Go
410@oooooooooooooooooa0@402Dooooo`00Qoooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`05ogMgMonH
V9SooooooiRHV?mgMgL0U?ooool008Oooooo0_l0000Cooooo`03o`000?oooooooooo00Cooooo0_l0
000Eooooo`03o`000?oooooooooo01;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP2Dooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-3.4116, -0.234311, \
0.0510397, 0.00762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.230769 0.0769231 0.103006 0.515028 [
[.07692 .09051 -6 -9 ]
[.07692 .09051 6 0 ]
[.38462 .09051 -3 -9 ]
[.38462 .09051 3 0 ]
[.53846 .09051 -3 -9 ]
[.53846 .09051 3 0 ]
[.69231 .09051 -3 -9 ]
[.69231 .09051 3 0 ]
[.84615 .09051 -3 -9 ]
[.84615 .09051 3 0 ]
[1 .09051 -6 -9 ]
[1 .09051 6 0 ]
[1.025 .10301 0 -6 ]
[1.025 .10301 10 6 ]
[.21827 0 -24 -4.5 ]
[.21827 0 0 4.5 ]
[.21827 .20601 -18 -4.5 ]
[.21827 .20601 0 4.5 ]
[.21827 .30902 -18 -4.5 ]
[.21827 .30902 0 4.5 ]
[.21827 .41202 -18 -4.5 ]
[.21827 .41202 0 4.5 ]
[.21827 .51503 -18 -4.5 ]
[.21827 .51503 0 4.5 ]
[.21827 .61803 -6 -4.5 ]
[.21827 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07692 .10301 m
.07692 .10926 L
s
[(-2)] .07692 .09051 0 1 Mshowa
.38462 .10301 m
.38462 .10926 L
s
[(2)] .38462 .09051 0 1 Mshowa
.53846 .10301 m
.53846 .10926 L
s
[(4)] .53846 .09051 0 1 Mshowa
.69231 .10301 m
.69231 .10926 L
s
[(6)] .69231 .09051 0 1 Mshowa
.84615 .10301 m
.84615 .10926 L
s
[(8)] .84615 .09051 0 1 Mshowa
1 .10301 m
1 .10926 L
s
[(10)] 1 .09051 0 1 Mshowa
.125 Mabswid
.11538 .10301 m
.11538 .10676 L
s
.15385 .10301 m
.15385 .10676 L
s
.19231 .10301 m
.19231 .10676 L
s
.26923 .10301 m
.26923 .10676 L
s
.30769 .10301 m
.30769 .10676 L
s
.34615 .10301 m
.34615 .10676 L
s
.42308 .10301 m
.42308 .10676 L
s
.46154 .10301 m
.46154 .10676 L
s
.5 .10301 m
.5 .10676 L
s
.57692 .10301 m
.57692 .10676 L
s
.61538 .10301 m
.61538 .10676 L
s
.65385 .10301 m
.65385 .10676 L
s
.73077 .10301 m
.73077 .10676 L
s
.76923 .10301 m
.76923 .10676 L
s
.80769 .10301 m
.80769 .10676 L
s
.88462 .10301 m
.88462 .10676 L
s
.92308 .10301 m
.92308 .10676 L
s
.96154 .10301 m
.96154 .10676 L
s
.03846 .10301 m
.03846 .10676 L
s
.25 Mabswid
0 .10301 m
1 .10301 L
s
gsave
1.025 .10301 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.23077 0 m
.23702 0 L
s
[(-0.2)] .21827 0 1 0 Mshowa
.23077 .20601 m
.23702 .20601 L
s
[(0.2)] .21827 .20601 1 0 Mshowa
.23077 .30902 m
.23702 .30902 L
s
[(0.4)] .21827 .30902 1 0 Mshowa
.23077 .41202 m
.23702 .41202 L
s
[(0.6)] .21827 .41202 1 0 Mshowa
.23077 .51503 m
.23702 .51503 L
s
[(0.8)] .21827 .51503 1 0 Mshowa
.23077 .61803 m
.23702 .61803 L
s
[(1)] .21827 .61803 1 0 Mshowa
.125 Mabswid
.23077 .02575 m
.23452 .02575 L
s
.23077 .0515 m
.23452 .0515 L
s
.23077 .07725 m
.23452 .07725 L
s
.23077 .12876 m
.23452 .12876 L
s
.23077 .15451 m
.23452 .15451 L
s
.23077 .18026 m
.23452 .18026 L
s
.23077 .23176 m
.23452 .23176 L
s
.23077 .25751 m
.23452 .25751 L
s
.23077 .28327 m
.23452 .28327 L
s
.23077 .33477 m
.23452 .33477 L
s
.23077 .36052 m
.23452 .36052 L
s
.23077 .38627 m
.23452 .38627 L
s
.23077 .43777 m
.23452 .43777 L
s
.23077 .46353 m
.23452 .46353 L
s
.23077 .48928 m
.23452 .48928 L
s
.23077 .54078 m
.23452 .54078 L
s
.23077 .56653 m
.23452 .56653 L
s
.23077 .59228 m
.23452 .59228 L
s
.25 Mabswid
.23077 0 m
.23077 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
123.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
0 .10301 m
.00171 .10301 L
.00326 .10301 L
.00506 .10301 L
.00676 .10301 L
.00833 .10301 L
.00977 .10301 L
.01136 .10301 L
.01305 .10301 L
.01474 .10301 L
.01656 .10301 L
.01828 .10301 L
.01985 .10301 L
.02169 .10301 L
.02273 .10301 L
.02369 .10301 L
.02546 .10301 L
.02734 .10301 L
.02829 .10301 L
.02929 .10301 L
.03108 .10301 L
.03208 .10301 L
.03301 .10301 L
.03403 .10301 L
.03513 .10301 L
.03607 .10301 L
.0371 .10301 L
.03896 .10301 L
.04078 .10301 L
.04246 .10301 L
.04409 .10301 L
.04562 .10301 L
.0473 .10301 L
.04911 .10301 L
.0509 .10301 L
.05279 .10301 L
.05441 .10301 L
.05617 .10301 L
.0572 .10301 L
.05815 .10301 L
.05918 .10301 L
.0603 .10301 L
.0622 .10301 L
.06324 .10301 L
.06421 .10301 L
.06605 .10301 L
.06773 .10301 L
.06866 .10301 L
.06967 .10301 L
.07151 .10301 L
Mistroke
.07263 .10301 L
.07367 .10301 L
.07563 .10301 L
.07673 .10301 L
.07774 .10301 L
.08002 .10301 L
.08185 .10301 L
.08385 .10301 L
.08595 .10301 L
.0879 .10301 L
.08974 .10301 L
.09174 .10301 L
.09362 .10301 L
.09537 .10301 L
.09693 .10301 L
.09866 .10301 L
.10047 .10301 L
.10216 .10301 L
.10403 .10301 L
.106 .10301 L
.10768 .10301 L
.10951 .10301 L
.1115 .10301 L
.11362 .10301 L
.11561 .10301 L
.11743 .10302 L
.1208 .10302 L
.12271 .10302 L
.1245 .10303 L
.12811 .10304 L
.13013 .10305 L
.13198 .10307 L
.13527 .10309 L
.13713 .10311 L
.13885 .10314 L
.14201 .10319 L
.14537 .10328 L
.14894 .1034 L
.15279 .10358 L
.15642 .10383 L
.15975 .10413 L
.16344 .10459 L
.16748 .10527 L
.1717 .10624 L
.17563 .10746 L
.17944 .10902 L
.18296 .11085 L
.18682 .11339 L
.19091 .11682 L
.19777 .12468 L
Mistroke
.20168 .13058 L
.20534 .13721 L
.21214 .15281 L
.21835 .17129 L
.23235 .22939 L
.26231 .4143 L
.26982 .4617 L
.27689 .50098 L
.28324 .52956 L
.28652 .54125 L
.29011 .5514 L
.29181 .55519 L
.29363 .55849 L
.29536 .56088 L
.29692 .56243 L
.2987 .56346 L
.2997 .5637 L
.30062 .56371 L
.30232 .56319 L
.30412 .56187 L
.30564 .56015 L
.30728 .55769 L
.31025 .55169 L
.31377 .54204 L
.31701 .53099 L
.33097 .46381 L
.34566 .37474 L
.35956 .292 L
.37439 .21913 L
.38159 .19141 L
.38839 .16991 L
.39495 .15312 L
.4011 .14061 L
.40784 .12993 L
.41525 .12123 L
.42246 .11519 L
.42652 .11264 L
.43022 .11073 L
.43681 .10814 L
.44053 .10705 L
.44399 .10623 L
.45032 .10511 L
.45385 .10465 L
.45705 .10432 L
.46074 .10401 L
.46417 .10378 L
.46775 .1036 L
.47168 .10345 L
.47507 .10334 L
.47817 .10327 L
Mistroke
.48173 .1032 L
.48511 .10316 L
.48877 .10312 L
.49266 .10309 L
.49598 .10307 L
.49963 .10305 L
.50356 .10304 L
.50572 .10303 L
.50778 .10303 L
.51176 .10302 L
.51541 .10302 L
.51917 .10301 L
.52271 .10301 L
.52589 .10301 L
.52933 .10301 L
.53309 .10301 L
.53499 .10301 L
.53707 .10301 L
.53884 .10301 L
.54075 .10301 L
.54419 .10301 L
.54762 .10301 L
.54957 .10301 L
.55136 .10301 L
.55466 .10301 L
.55633 .10301 L
.55817 .10301 L
.56133 .10301 L
.56311 .10301 L
.56474 .10301 L
.56775 .10301 L
.57091 .10301 L
.57271 .10301 L
.57465 .10301 L
.57636 .10301 L
.57818 .10301 L
.57981 .10301 L
.58161 .10301 L
.58478 .10301 L
.58671 .10301 L
.58847 .10301 L
.59037 .10301 L
.59244 .10301 L
.59434 .10301 L
.59611 .10301 L
.5996 .10301 L
.60128 .10301 L
.6031 .10301 L
.6047 .10301 L
.60639 .10301 L
Mistroke
.60791 .10301 L
.60959 .10301 L
.61253 .10301 L
.61433 .10301 L
.61597 .10301 L
.61774 .10301 L
.61966 .10301 L
.62143 .10301 L
.62307 .10301 L
.6263 .10301 L
.62802 .10301 L
.62982 .10301 L
.63305 .10301 L
.63485 .10301 L
.63653 .10301 L
.63836 .10301 L
.64032 .10301 L
.64203 .10301 L
.64387 .10301 L
.64561 .10301 L
.64722 .10301 L
.65026 .10301 L
.65179 .10301 L
.65348 .10301 L
.65548 .10301 L
.65738 .10301 L
.65909 .10301 L
.66095 .10301 L
.66297 .10301 L
.66511 .10301 L
.66694 .10301 L
.66897 .10301 L
.67084 .10301 L
.67256 .10301 L
.67444 .10301 L
.67643 .10301 L
.67816 .10301 L
.67978 .10301 L
.68155 .10301 L
.68345 .10301 L
.68523 .10301 L
.6872 .10301 L
.68925 .10301 L
.69117 .10301 L
.69297 .10301 L
.69461 .10301 L
.6965 .10301 L
.6983 .10301 L
.70024 .10301 L
.7023 .10301 L
Mistroke
.70425 .10301 L
.70601 .10301 L
.7081 .10301 L
.70919 .10301 L
.71035 .10301 L
.71247 .10301 L
.71443 .10301 L
.71625 .10301 L
.71791 .10301 L
.71983 .10301 L
.72165 .10301 L
.72333 .10301 L
.72488 .10301 L
.72658 .10301 L
.72839 .10301 L
.7302 .10301 L
.73215 .10301 L
.73399 .10301 L
.73567 .10301 L
.73754 .10301 L
.73959 .10301 L
.74062 .10301 L
.74173 .10301 L
.74371 .10301 L
.74551 .10301 L
.74748 .10301 L
.74847 .10301 L
.74954 .10301 L
.75146 .10301 L
.75338 .10301 L
.7552 .10301 L
.75683 .10301 L
.75861 .10301 L
.75971 .10301 L
.76074 .10301 L
.76267 .10301 L
.76375 .10301 L
.76474 .10301 L
.76591 .10301 L
.76699 .10301 L
.76879 .10301 L
.76983 .10301 L
.77077 .10301 L
.77269 .10301 L
.77375 .10301 L
.77475 .10301 L
.77644 .10301 L
.7783 .10301 L
.77923 .10301 L
.78024 .10301 L
Mistroke
.78206 .10301 L
.78386 .10301 L
.78558 .10301 L
.78712 .10301 L
.7888 .10301 L
.78983 .10301 L
.79081 .10301 L
.79263 .10301 L
.79365 .10301 L
.79459 .10301 L
.79568 .10301 L
.79671 .10301 L
.79841 .10301 L
.80028 .10301 L
.8021 .10301 L
.80312 .10301 L
.80405 .10301 L
.80576 .10301 L
.80737 .10301 L
.80913 .10301 L
.81103 .10301 L
.81292 .10301 L
.81386 .10301 L
.8149 .10301 L
.81674 .10301 L
.81845 .10301 L
.82018 .10301 L
.82182 .10301 L
.82329 .10301 L
.82489 .10301 L
.82663 .10301 L
.82847 .10301 L
.83004 .10301 L
.83178 .10301 L
.83274 .10301 L
.83379 .10301 L
.8357 .10301 L
.83756 .10301 L
.83929 .10301 L
.84034 .10301 L
.84134 .10301 L
.84319 .10301 L
.84424 .10301 L
.8452 .10301 L
.84624 .10301 L
.84736 .10301 L
.84911 .10301 L
.85074 .10301 L
.85174 .10301 L
.85269 .10301 L
Mistroke
.85446 .10301 L
.85632 .10301 L
.85805 .10301 L
.85994 .10301 L
.86089 .10301 L
.86195 .10301 L
.86372 .10301 L
.86537 .10301 L
.86718 .10301 L
.86819 .10301 L
.86911 .10301 L
.87097 .10301 L
.87202 .10301 L
.87298 .10301 L
.87476 .10301 L
.87664 .10301 L
.87824 .10301 L
.87996 .10301 L
.88158 .10301 L
.88305 .10301 L
.88479 .10301 L
.88667 .10301 L
.88845 .10301 L
.8901 .10301 L
.89202 .10301 L
.89309 .10301 L
.89408 .10301 L
.8959 .10301 L
.89782 .10301 L
.89954 .10301 L
.90115 .10301 L
.90291 .10301 L
.9048 .10301 L
.90585 .10301 L
.90682 .10301 L
.90788 .10301 L
.90901 .10301 L
.9109 .10301 L
.91198 .10301 L
.91299 .10301 L
.91486 .10301 L
.91658 .10301 L
.91752 .10301 L
.91856 .10301 L
.92044 .10301 L
.92138 .10301 L
.92237 .10301 L
.92415 .10301 L
.92606 .10301 L
.92714 .10301 L
Mistroke
.92816 .10301 L
.93 .10301 L
.93167 .10301 L
.9326 .10301 L
.9336 .10301 L
.93543 .10301 L
.93706 .10301 L
.93886 .10301 L
.94074 .10301 L
.9425 .10301 L
.94414 .10301 L
.94564 .10301 L
.94729 .10301 L
.94903 .10301 L
.95094 .10301 L
.95268 .10301 L
.95364 .10301 L
.95468 .10301 L
.95658 .10301 L
.95835 .10301 L
.96023 .10301 L
.96183 .10301 L
.96359 .10301 L
.96466 .10301 L
.96567 .10301 L
.96756 .10301 L
.96862 .10301 L
.9696 .10301 L
.97068 .10301 L
.97182 .10301 L
.97282 .10301 L
.9739 .10301 L
.97493 .10301 L
.97586 .10301 L
.97764 .10301 L
.97952 .10301 L
.9813 .10301 L
.98231 .10301 L
.98324 .10301 L
.98494 .10301 L
.98675 .10301 L
.98837 .10301 L
.98988 .10301 L
.99155 .10301 L
.99334 .10301 L
.99513 .10301 L
.99615 .10301 L
.9971 .10301 L
.99901 .10301 L
Mfstroke
.99901 .10301 m
1 .10301 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000oooooolLooooo`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0oooooolLooooo`00<?ooool6o`0000;o
oooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^0?oooooo7Oooool003So
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003ooooo
oa?ooooo000hooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05oooo
o`03o`000?oooooooooo0?oooooo4oooool003Sooooo00Go410@oooooooooooooooooa0@400?oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooo
oooo0?oooooo4oooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooo
oooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003ooooooooo
o`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000oooo
ooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`00
0?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool0
0ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o
0000ooooooooool0oooooolCooooo`008oooool5o`0002_ooooo00?o0000ooooooooool0:oooool5
o`0002kooooo0_l000000ol@413oooooooooo`0Zooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?oo
ool01Oo<c<co8B4Qo`000?lQ8B7oc<c<02Wooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`00
0?lb<S;ok^k^6_ooool002?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00[ooooo`03o`000?oooooo
oooo02_ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00_ooooo`03o`000?oooooooooo02_ooooo00Go
EEEEogMgMoooooooV9RHob4Q8@0/ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40:oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool001_ooooo1_l00003ooooo`03
oiRHV?lQ8B7ok^k^02cooooo00?o0000ooooooooool0;?ooool00onHV9So8B4Qonk^kP0]ooooo`Go
0000;?ooool01Ol0003ooooooooooooooooo000002cooooo00Go0000ooooooooooooooooo`00000[
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Jooooo`009Oooool0
0onHV9So8B4Qonk^kP0[ooooo`03o`000?oooooooooo02gooooo00?oV9RHob4Q8Oo^k^h0;?ooool0
1?m4A4CogMgMooooool0000]ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;?ooool01Olb<S;oV9RH
oooooonHV9So<S8b02_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
01[ooooo000Vooooo`03ogMgMomVIVKooooo02[ooooo0_l0000_ooooo`03ogMgMomVIVKooooo02_o
oooo00CogMgMoeEEEOoooooo0000;Oooool01Ol0003oEEEEo`000?l@413oc<c<02cooooo00Goc<c<
o`000?l0003o0000olc<c00[ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Jooooo`009oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool0:oooool00omgMgOoc<c<o`00000]ooooo`03oeEEEOn7QhOooooo02kooooo00Go
410@okZj^_oooooo^[Zjoa0@400[ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@400Jooooo`008oooool01Ol0003o^[ZjoooooonHV9So410@02_ooooo00?o0000oooooooo
ool0:oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo00?ok^k^odA4A?l00000;Oooool00ooM
gMgo410@oiRHV00^ooooo`05o`000?nj^[[ooooookZj^_l00000:oooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool002?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00[ooooo`03o`000?oooooooooo02_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00^ooooo`03ogMg
Mol0003ooooo02gooooo00Coc<c<odA4A?l0003o410@;?ooool01OnYZJWo410@o`000?l@413oZJVY
02Wooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo001Coooo
o`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00
Doooool00ol0003oooooooooo`3mooooo`;o00000_ooool2o`0000oooooo001Cooooo`03o`000?oo
oooooooo0?gooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd?ooooo`00Doooool00ol0003ooooo
ooooo`3nooooo`04omgMgOl0003o410@olc<c13ooooo000:oooooooo0000@?l0000;ooooo`04onk^
k_lQ8B7o410@onk^kQ3ooooo000Fooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;ooooo1?l00003ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`04o`00
0?ooooooooooooooo`Co00001Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool01?lQ8B7oMgMgogMgMolb<S8@ooooo`008_ooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0;_ooool00ol0003o
ooooooooo`0;ooooo`;o00008Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02ko
oooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`08ooooo`;o00000_ooool2o`0000oo
oooo0015ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0>_ooool2o`000=Kooooo
0016ooooo`;o00002oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo0=Kooooo0018
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`3G
ooooo`00BOooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Oooooo00?o0000oooo
ooooool0f?ooool004Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0fooooo`03
o`000?oooooooooo0=Wooooo001:ooooo`03o`000?oooooooooo00Kooooo0_l0000fooooo`03o`00
0?oooooooooo0=[ooooo001:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0=Ooo
ool00ol0003oooooooooo`3Jooooo`00Boooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo03Cooooo00?o0000ooooooooool0foooool004_ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0dooooo`03o`000?oooooooooo0=_ooooo001<ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`3Looooo`00C?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0g?ooool004cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo0=gooooo001=
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`3N
ooooo`00COooool00ol0003oooooooooo`03ooooo`;o0000<_ooool00ol0003oooooooooo`3Noooo
o`00C_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo033ooooo00?o0000oooooooo
ool0goooool004kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0`ooooo`03o`00
0?oooooooooo0=oooooo001>ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0<?oo
ool00ol0003oooooooooo`3Oooooo`00Coooool01Ol0003ooooooooooooooooo0000037ooooo00?o
0000ooooooooool0h?ooool004oooooo00Go0000ooooooooooooooooo`00000aooooo`03o`000?oo
oooooooo0>3ooooo001?ooooo`05o`000?ooooooooooooooool00000<Oooool00ol0003ooooooooo
o`3Pooooo`00Coooool01Ol0003ooooooooooooooooo0000037ooooo00?o0000ooooooooool0h?oo
ool0053ooooo00?o0000ooooooooool00_l0000_ooooo`03o`000?oooooooooo0>7ooooo001@oooo
o`04o`000?ooooooooooo`00033ooooo00?o0000ooooooooool0hOooool0053ooooo00Co0000oooo
oooooooo0000<?ooool00ol0003oooooooooo`3Qooooo`00D?ooool01?l0003oooooooooool0000_
ooooo`03o`000?oooooooooo0>;ooooo001Aooooo`03o`000?oooooo000002oooooo00?o0000oooo
ooooool0h_ooool0057ooooo00?o0000ooooool00000;oooool00ol0003oooooooooo`3Rooooo`00
>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001?ooool00ol0003o
ooooo`00000_ooooo`03o`000?oooooooooo0>;ooooo000hooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`;o0000;_ooool00ol0
003oooooooooo`3Sooooo`00>?ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q
8Oo^k^h01_ooool4o`0002cooooo00?o0000ooooooooool0hoooool003Sooooo00Go0000oooooooo
ooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Gooooo0_l0000^ooooo`03o`000?oooooooooo
0>?ooooo000hooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`04oooo
o`;o0000;_ooool00ol0003oooooooooo`3Sooooo`00>?ooool01Ol@413ooooooooooooooooo410@
00oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo
0>?ooooo000hooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So
410@00Kooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`3Tooooo`00>?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oo
oooooooo02_ooooo00?o0000ooooooooool0i?ooool005?ooooo00?o0000ooooooooool0:oooool0
0ol0003oooooooooo`3Tooooo`00Doooool2o`0002cooooo00?o0000ooooooooool0i?ooool005?o
oooo0_l0000[ooooo`03o`000?oooooooooo0>Gooooo001Cooooo`;o0000:oooool00ol0003ooooo
ooooo`3Uooooo`00Doooool2o`0002_ooooo00?o0000ooooooooool0iOooool005?ooooo0_l0000[
ooooo`03o`000?oooooooooo0>Gooooo001Cooooo`03o`000?oooooo000002[ooooo00?o0000oooo
ooooool0iOooool005?ooooo00?o0000ooooool00000:Oooool00ol0003oooooooooo`3Vooooo`00
Doooool00ol0003oooooo`00000Yooooo`03o`000?oooooooooo0>Kooooo001Cooooo`03o`000?oo
oooo000002Wooooo00?o0000ooooooooool0i_ooool005?ooooo00?o0000ooooool00000:Oooool0
0ol0003oooooooooo`3Vooooo`00Doooool3o`0002Sooooo00?o0000ooooooooool0ioooool005?o
oooo00?o0000ooooool00000:?ooool00ol0003oooooooooo`3Wooooo`00Doooool01?l0003ooooo
ooooool0000Wooooo`03o`000?oooooooooo0>Oooooo001Cooooo`04o`000?ooooooooooo`0002Oo
oooo00?o0000ooooooooool0ioooool005?ooooo00Co0000oooooooooooo00009oooool00ol0003o
ooooooooo`3Wooooo`00Doooool01?l0003oooooooooool0000Vooooo`03o`000?oooooooooo0>So
oooo001Cooooo`04o`000?ooooooooooo`0002Kooooo00?o0000ooooooooool0j?ooool005?ooooo
00Co0000oooooooooooo00009_ooool00ol0003oooooooooo`3Xooooo`00Doooool2o`0000;ooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`3Xooooo`00Doooool01Ol0003ooooooooo
oooooooo000002Gooooo00?o0000ooooooooool0j?ooool005?ooooo00Go0000oooooooooooooooo
o`00000Tooooo`03o`000?oooooooooo0>Wooooo001Cooooo`05o`000?ooooooooooooooool00000
9?ooool00ol0003oooooooooo`3Yooooo`00Doooool01Ol0003ooooooooooooooooo000002Cooooo
00?o0000ooooooooool0jOooool005?ooooo00Go0000ooooooooooooooooo`00000Tooooo`03o`00
0?oooooooooo0>Wooooo000hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo
0_l000000ol@413oooooooooo`04ooooo`05o`000?ooooooooooooooool000009?ooool00ol0003o
ooooooooo`3Yooooo`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo0>[ooooo000hooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Ko
oooo0ol00002ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0j_ooool003Sooooo
00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo0>[ooooo000hooooo`05
o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`3Zooooo`00>?ooool01Ol@
413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0j_ooool003Sooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo0>[ooooo000hooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`3Zooooo`00Doooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool0joooool005?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo0>_ooooo001Cooooo`;o0000
1?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo0>_ooooo001Cooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`3[ooooo`00Doooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0joooool0
05?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
0>_ooooo001Cooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`3/ooooo`00Doooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool0k?ooool005?ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo0>cooooo001Cooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`3/ooooo`00Doooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool0k?ooool005?ooooo0_l00005ooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool0k?ooool005?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo0>cooooo001Cooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`3]ooooo`00Doooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0kOooool0
05?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
0>gooooo001Cooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`3]ooooo`00Doooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool0kOooool005?ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo0>gooooo001Cooooo`;o00001oooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo0>kooooo001Cooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`3^ooooo`00Doooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool0k_ooool005?ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo0>kooooo001Cooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`3^ooooo`00>?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0
1_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
koooool003Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMg
oooooonHV9So8B4Q00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo0>oooooo000hooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003o
oooooooooooooooo000000Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo0>oooooo000hooooo`05o`000?ooooooooooooooool000002oooool01Ol0
003oV9RHoooooonHV9So8B4Q00Kooooo0ol00007ooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool0koooool003Sooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo
0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool0koooool003Sooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7
QhOooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo0>oooooo000hooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRH
V008ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`3`ooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@
1_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
l?ooool005?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo0?3ooooo001Cooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`3`ooooo`00Doooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0l?ooool005?ooooo0_l00009ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool0l?ooool005?ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo0?7ooooo001Cooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`3aooooo`00Doooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0lOooool005?ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo0?7ooooo001Cooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`3aooooo`00
Doooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
l_ooool005?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo0?;ooooo001Cooooo`;o00002_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo0?;ooooo001Cooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`3booooo`00Doooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool0l_ooool005?ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo0?;ooooo001Cooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`3cooooo`00Doooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0loooool005?ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0??ooooo001Cooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`3cooooo`00
Doooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
loooool005?ooooo0_l0000<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0m?oo
ool005?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo0?Cooooo001Cooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`3dooooo`00Doooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool0m?ooool005?ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo0?Cooooo000hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`3dooooo`00>?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0mOooool003So
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0mOooool0
03Sooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_oo
ool3o`0000gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`3eooooo`00>?ooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`3eooooo`00>?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`3eooooo`00
>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000006oooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`3foooo
o`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`3f
ooooo`00Doooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool0m_ooool005?ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo0?Kooooo001Cooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`3gooooo`00Doooool2o`00013ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`3hooooo`00Doooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0n?ooool005?ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo0?Wooooo001Cooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`3iooooo`00Doooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0nOooool005?ooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0?[ooooo001C
ooooo`03o`000?oooooooooo017ooooo0_l00002ooooo`03o`000?oooooooooo0?[ooooo001Coooo
o`03o`000?oooooooooo01;ooooo0ol0003mooooo`00Doooool2o`000?oooooo5?ooool005?ooooo
00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001C
ooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCoooo
o`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo
4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool2o`000?oooooo5?ooool0
05?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?o
oooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooo
oolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo0019ooooo`Co000000?o410@oooo
ooooool00oooool00ol0003oooooooooo`3ooooooa?ooooo001;ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0oooooolCooooo`00Boooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0?oooooo4oooool004_ooooo00?o0000ooooooooool01Oooool3o`000?oooooo4ooo
ool004_ooooo00?o0000ooooooooool0oooooolKooooo`00Boooool00ol0003oooooooooo`3ooooo
oa_ooooo001;ooooo`03o`000?oooooooooo0?oooooo6oooool004Wooooo00?oEEEEofIVI_l00000
oooooolMooooo`00O?ooool3o`000003oa0@4?oooooooooo0>Kooooo001nooooo`03oa0@4?nj^[[o
oooo00Kooooo0_l0000;ooooo`03o`000?nj^[[ooooo00cooooo0_l00006ooooo`03o`000?nj^[[o
oooo0;[ooooo001nooooo`03oiRHV?lb<S;ooooo00Kooooo00?o0000ooooooooool02_ooool2oc8b
<Pkooooo00?o0000ooooooooool01?ooool2oc8b<[_ooooo001nooooo`03omgMgOl0003o^[Zj00Ko
oooo00?o0000ooooooooool00_ooool2o`0000;ooooo0_l00002ooooo`03ohN7Qol0003o^[Zj00Go
oooo00GoV9RHo`000?l0003oA4A4okZj^P03ooooo`03o`000?oooooooooo00Cooooo00?oQhN7o`00
0?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj017ooooo1?l000000ol@413oooooooooo`2A
ooooo`00O_ooool00omEEEGoMgMgodA4A006ooooo`03o`000?oooooooooo00;ooooo00Kok^k^ob4Q
8On7QhOo^[Zjo`000?oMgMd2ooooo`03olc<c?l0003o410@00Gooooo00Go410@okZj^_o^k^koMgMg
oa0@4003ooooo`03o`000?oooooooooo00Cooooo00?oc<c<o`000?l@41003?ooool01Ol@413o^[Zj
onk^k_mgMgOo410@00Wooooo1_l00004ooooo`03o`000?oooooooooo09?ooooo001mooooo`05omgM
gOl@413oooooob4Q8OoMgMd01Oooool00ol0003oooooooooo`03ooooo`04omgMgOl0003o410@olc<
c0_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool0Toooool007gooooo00GoIVIVohN7QoooooooV9RHoeEEE@05oooo
o`03o`000?oooooooooo00?ooooo00Cok^k^ob4Q8Ol@413ok^k^2oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02oooool6o`0000Cooooo00?o0000
ooooooooool0Toooool007cooooo00?ok^k^o`000?o^k^h00_ooool00ol0003ogMgMooooo`03oooo
o`03o`000?oooooooooo00?ooooo00Co8B4QogMgMomgMgOo<S8b2oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`2C
ooooo`00O?ooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00;ooooo00?o0000
ooooooooool00_ooool2o`0000;ooooo0_l00008ooooo`03oa0@4?l0003o000000?o00001?ooool0
0ol0003oooooooooo`0Aooooo`03oa0@4?l0003o000000?o00005?ooool00ol0003oooooooooo`2C
ooooo`00Qoooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo09?ooooo0027ooooo`;o
00004oooool00ol0003oooooooooo`04ooooo`;o00005Oooool00ol0003oooooooooo`0Cooooo`03
oeEEEOmVIVKo000009Gooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-3.4116, -0.234311, \
0.0510397, 0.00762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.230769 0.0769231 0.103006 0.515028 [
[.07692 .09051 -6 -9 ]
[.07692 .09051 6 0 ]
[.38462 .09051 -3 -9 ]
[.38462 .09051 3 0 ]
[.53846 .09051 -3 -9 ]
[.53846 .09051 3 0 ]
[.69231 .09051 -3 -9 ]
[.69231 .09051 3 0 ]
[.84615 .09051 -3 -9 ]
[.84615 .09051 3 0 ]
[1 .09051 -6 -9 ]
[1 .09051 6 0 ]
[1.025 .10301 0 -6 ]
[1.025 .10301 10 6 ]
[.21827 0 -24 -4.5 ]
[.21827 0 0 4.5 ]
[.21827 .20601 -18 -4.5 ]
[.21827 .20601 0 4.5 ]
[.21827 .30902 -18 -4.5 ]
[.21827 .30902 0 4.5 ]
[.21827 .41202 -18 -4.5 ]
[.21827 .41202 0 4.5 ]
[.21827 .51503 -18 -4.5 ]
[.21827 .51503 0 4.5 ]
[.21827 .61803 -6 -4.5 ]
[.21827 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07692 .10301 m
.07692 .10926 L
s
[(-2)] .07692 .09051 0 1 Mshowa
.38462 .10301 m
.38462 .10926 L
s
[(2)] .38462 .09051 0 1 Mshowa
.53846 .10301 m
.53846 .10926 L
s
[(4)] .53846 .09051 0 1 Mshowa
.69231 .10301 m
.69231 .10926 L
s
[(6)] .69231 .09051 0 1 Mshowa
.84615 .10301 m
.84615 .10926 L
s
[(8)] .84615 .09051 0 1 Mshowa
1 .10301 m
1 .10926 L
s
[(10)] 1 .09051 0 1 Mshowa
.125 Mabswid
.11538 .10301 m
.11538 .10676 L
s
.15385 .10301 m
.15385 .10676 L
s
.19231 .10301 m
.19231 .10676 L
s
.26923 .10301 m
.26923 .10676 L
s
.30769 .10301 m
.30769 .10676 L
s
.34615 .10301 m
.34615 .10676 L
s
.42308 .10301 m
.42308 .10676 L
s
.46154 .10301 m
.46154 .10676 L
s
.5 .10301 m
.5 .10676 L
s
.57692 .10301 m
.57692 .10676 L
s
.61538 .10301 m
.61538 .10676 L
s
.65385 .10301 m
.65385 .10676 L
s
.73077 .10301 m
.73077 .10676 L
s
.76923 .10301 m
.76923 .10676 L
s
.80769 .10301 m
.80769 .10676 L
s
.88462 .10301 m
.88462 .10676 L
s
.92308 .10301 m
.92308 .10676 L
s
.96154 .10301 m
.96154 .10676 L
s
.03846 .10301 m
.03846 .10676 L
s
.25 Mabswid
0 .10301 m
1 .10301 L
s
gsave
1.025 .10301 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.23077 0 m
.23702 0 L
s
[(-0.2)] .21827 0 1 0 Mshowa
.23077 .20601 m
.23702 .20601 L
s
[(0.2)] .21827 .20601 1 0 Mshowa
.23077 .30902 m
.23702 .30902 L
s
[(0.4)] .21827 .30902 1 0 Mshowa
.23077 .41202 m
.23702 .41202 L
s
[(0.6)] .21827 .41202 1 0 Mshowa
.23077 .51503 m
.23702 .51503 L
s
[(0.8)] .21827 .51503 1 0 Mshowa
.23077 .61803 m
.23702 .61803 L
s
[(1)] .21827 .61803 1 0 Mshowa
.125 Mabswid
.23077 .02575 m
.23452 .02575 L
s
.23077 .0515 m
.23452 .0515 L
s
.23077 .07725 m
.23452 .07725 L
s
.23077 .12876 m
.23452 .12876 L
s
.23077 .15451 m
.23452 .15451 L
s
.23077 .18026 m
.23452 .18026 L
s
.23077 .23176 m
.23452 .23176 L
s
.23077 .25751 m
.23452 .25751 L
s
.23077 .28327 m
.23452 .28327 L
s
.23077 .33477 m
.23452 .33477 L
s
.23077 .36052 m
.23452 .36052 L
s
.23077 .38627 m
.23452 .38627 L
s
.23077 .43777 m
.23452 .43777 L
s
.23077 .46353 m
.23452 .46353 L
s
.23077 .48928 m
.23452 .48928 L
s
.23077 .54078 m
.23452 .54078 L
s
.23077 .56653 m
.23452 .56653 L
s
.23077 .59228 m
.23452 .59228 L
s
.25 Mabswid
.23077 0 m
.23077 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
123.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.01765 .10301 m
.01863 .10301 L
.02045 .10301 L
.02217 .10301 L
.02376 .10301 L
.0255 .10301 L
.02734 .10301 L
.02913 .10301 L
.03076 .10301 L
.03264 .10301 L
.03443 .10301 L
.03607 .10301 L
.0376 .10301 L
.03927 .10301 L
.04106 .10301 L
.04208 .10301 L
.04302 .10301 L
.04405 .10301 L
.04514 .10301 L
.04697 .10301 L
.04801 .10301 L
.04898 .10301 L
.0508 .10301 L
.05245 .10301 L
.05436 .10301 L
.05617 .10301 L
.05798 .10301 L
.05968 .10301 L
.06155 .10301 L
.0626 .10301 L
.06356 .10301 L
.06539 .10301 L
.06642 .10301 L
.06738 .10301 L
.0684 .10301 L
.06933 .10301 L
.0704 .10301 L
.07141 .10301 L
.07312 .10301 L
.07493 .10301 L
.07648 .10301 L
.07818 .10301 L
.08 .10301 L
.08103 .10301 L
.08197 .10301 L
.08378 .10301 L
.08551 .10301 L
.08655 .10301 L
.08752 .10301 L
.08935 .10301 L
Mistroke
.09037 .10301 L
.09131 .10301 L
.09235 .10301 L
.09343 .10301 L
.09525 .10301 L
.09694 .10301 L
.09879 .10301 L
.09983 .10301 L
.10078 .10301 L
.10182 .10301 L
.10291 .10301 L
.10385 .10301 L
.10488 .10301 L
.10599 .10301 L
.10718 .10301 L
.1083 .10301 L
.10933 .10301 L
.11122 .10301 L
.11229 .10301 L
.11328 .10301 L
.11433 .10301 L
.11529 .10301 L
.11639 .10301 L
.11743 .10301 L
.11911 .10301 L
.12092 .10301 L
.12262 .10301 L
.12418 .10301 L
.126 .10301 L
.12703 .10301 L
.12799 .10301 L
.12974 .10301 L
.1316 .10301 L
.13336 .10301 L
.13527 .10301 L
.13707 .10301 L
.13872 .10301 L
.14055 .10301 L
.14158 .10301 L
.14255 .10301 L
.14357 .10301 L
.1445 .10301 L
.14557 .10301 L
.14658 .10301 L
.14813 .10301 L
.14983 .10301 L
.15161 .10301 L
.15328 .10301 L
.15483 .10301 L
.15626 .10301 L
Mistroke
.1579 .10301 L
.15946 .10301 L
.16114 .10301 L
.16292 .10301 L
.16461 .10301 L
.16614 .10301 L
.16794 .10301 L
.16896 .10301 L
.16989 .10301 L
.17161 .10301 L
.17343 .10301 L
.1752 .10301 L
.17621 .10301 L
.17713 .10301 L
.17884 .10301 L
.18064 .10301 L
.18226 .10301 L
.18377 .10301 L
.18543 .10301 L
.18722 .10301 L
.18902 .10301 L
.19003 .10301 L
.19098 .10301 L
.19289 .10301 L
.19396 .10301 L
.19493 .10301 L
.19668 .10301 L
.19857 .10301 L
.20035 .10301 L
.202 .10301 L
.20354 .10301 L
.20519 .10301 L
.20675 .10301 L
.20817 .10301 L
.20984 .10301 L
.21165 .10301 L
.21337 .10302 L
.21495 .10302 L
.21675 .10302 L
.21844 .10303 L
.21996 .10304 L
.22159 .10305 L
.22339 .10306 L
.22528 .10308 L
.22689 .1031 L
.22866 .10313 L
.23057 .10317 L
.23233 .10321 L
.23426 .10328 L
.23631 .10337 L
Mistroke
.23976 .10358 L
.24172 .10375 L
.24355 .10394 L
.24696 .10441 L
.25008 .10503 L
.25368 .10602 L
.2571 .10733 L
.26075 .10924 L
.26465 .11204 L
.26832 .11558 L
.27165 .11972 L
.27558 .12595 L
.27983 .13465 L
.28754 .15665 L
.29468 .18533 L
.30135 .21981 L
.31651 .32152 L
.32404 .37774 L
.33223 .43556 L
.33598 .45893 L
.33997 .48063 L
.34371 .49742 L
.34713 .50941 L
.34883 .51405 L
.35062 .51798 L
.35242 .5209 L
.35343 .5221 L
.35438 .52292 L
.3561 .52367 L
.35767 .52352 L
.35948 .52238 L
.36119 .52037 L
.36307 .51712 L
.36506 .51254 L
.36863 .50156 L
.37248 .48613 L
.37671 .46544 L
.40368 .29475 L
.41061 .25403 L
.41818 .21562 L
.42484 .18755 L
.43194 .16357 L
.44017 .14271 L
.44411 .13503 L
.44781 .12897 L
.45147 .12395 L
.45542 .11948 L
.46231 .11364 L
.46577 .11146 L
.46948 .10958 L
Mistroke
.47268 .10826 L
.47616 .1071 L
.48024 .10604 L
.4841 .10528 L
.48787 .1047 L
.49134 .1043 L
.49499 .10397 L
.49841 .10373 L
.50216 .10354 L
.50621 .10338 L
.51022 .10327 L
.51444 .10319 L
.51804 .10314 L
.52198 .1031 L
.52568 .10307 L
.52763 .10306 L
.52968 .10305 L
.53347 .10304 L
.53695 .10303 L
.54029 .10302 L
.54342 .10302 L
.54685 .10301 L
.54878 .10301 L
.55053 .10301 L
.55242 .10301 L
.55442 .10301 L
.55802 .10301 L
.56002 .10301 L
.5619 .10301 L
.56398 .10301 L
.56618 .10301 L
.56795 .10301 L
.56989 .10301 L
.57331 .10301 L
.57524 .10301 L
.5773 .10301 L
.58101 .10301 L
.58279 .10301 L
.58476 .10301 L
.58667 .10301 L
.58873 .10301 L
.59066 .10301 L
.59242 .10301 L
.59587 .10301 L
.59792 .10301 L
.59982 .10301 L
.60191 .10301 L
.60413 .10301 L
.60626 .10301 L
.60826 .10301 L
Mistroke
.61005 .10301 L
.61199 .10301 L
.6137 .10301 L
.61553 .10301 L
.61754 .10301 L
.61941 .10301 L
.62151 .10301 L
.62351 .10301 L
.6253 .10301 L
.62724 .10301 L
.62892 .10301 L
.63078 .10301 L
.63272 .10301 L
.63453 .10301 L
.63611 .10301 L
.63778 .10301 L
.6396 .10301 L
.64127 .10301 L
.64307 .10301 L
.64502 .10301 L
.64685 .10301 L
.64855 .10301 L
.65021 .10301 L
.65176 .10301 L
.65338 .10301 L
.65516 .10301 L
.65707 .10301 L
.65889 .10301 L
.66053 .10301 L
.66231 .10301 L
.66424 .10301 L
.66629 .10301 L
.66823 .10301 L
.66998 .10301 L
.67166 .10301 L
.67343 .10301 L
.67494 .10301 L
.6766 .10301 L
.67839 .10301 L
.6803 .10301 L
.6821 .10301 L
.68375 .10301 L
.6854 .10301 L
.68693 .10301 L
.68861 .10301 L
.6904 .10301 L
.69194 .10301 L
.69339 .10301 L
.69498 .10301 L
.69669 .10301 L
Mistroke
.69862 .10301 L
.70037 .10301 L
.70239 .10301 L
.7043 .10301 L
.70606 .10301 L
.70769 .10301 L
.70947 .10301 L
.71136 .10301 L
.71327 .10301 L
.71531 .10301 L
.71724 .10301 L
.719 .10301 L
.72106 .10301 L
.72223 .10301 L
.72331 .10301 L
.72528 .10301 L
.72739 .10301 L
.72918 .10301 L
.73083 .10301 L
.73264 .10301 L
.73454 .10301 L
.7362 .10301 L
.73775 .10301 L
.73945 .10301 L
.74126 .10301 L
.74324 .10301 L
.74436 .10301 L
.74539 .10301 L
.74728 .10301 L
.74929 .10301 L
.75108 .10301 L
.75276 .10301 L
.75461 .10301 L
.75563 .10301 L
.75659 .10301 L
.75853 .10301 L
.76028 .10301 L
.76217 .10301 L
.76324 .10301 L
.76422 .10301 L
.76586 .10301 L
.76766 .10301 L
.76954 .10301 L
.7713 .10301 L
.7723 .10301 L
.77338 .10301 L
.77434 .10301 L
.77535 .10301 L
.77727 .10301 L
.77905 .10301 L
Mistroke
.78003 .10301 L
.78108 .10301 L
.78299 .10301 L
.7841 .10301 L
.78526 .10301 L
.78633 .10301 L
.78734 .10301 L
.78918 .10301 L
.79084 .10301 L
.79264 .10301 L
.79365 .10301 L
.79458 .10301 L
.79613 .10301 L
.79785 .10301 L
.79963 .10301 L
.8013 .10301 L
.80225 .10301 L
.80328 .10301 L
.80515 .10301 L
.80697 .10301 L
.80866 .10301 L
.8097 .10301 L
.81067 .10301 L
.81249 .10301 L
.81351 .10301 L
.81445 .10301 L
.81546 .10301 L
.81656 .10301 L
.81841 .10301 L
.82016 .10301 L
.82186 .10301 L
.82343 .10301 L
.82512 .10301 L
.82699 .10301 L
.82793 .10301 L
.82894 .10301 L
.83077 .10301 L
.83247 .10301 L
.83432 .10301 L
.83606 .10301 L
.83769 .10301 L
.83929 .10301 L
.84075 .10301 L
.84243 .10301 L
.84401 .10301 L
.84576 .10301 L
.84767 .10301 L
.84864 .10301 L
.84967 .10301 L
.85154 .10301 L
Mistroke
.8534 .10301 L
.85516 .10301 L
.85674 .10301 L
.85846 .10301 L
.86033 .10301 L
.86139 .10301 L
.86239 .10301 L
.86441 .10301 L
.86554 .10301 L
.86658 .10301 L
.86832 .10301 L
.87023 .10301 L
.8712 .10301 L
.87223 .10301 L
.87409 .10301 L
.87588 .10301 L
.8769 .10301 L
.87785 .10301 L
.87977 .10301 L
.88085 .10301 L
.88183 .10301 L
.88358 .10301 L
.8855 .10301 L
.8873 .10301 L
.88897 .10301 L
.88999 .10301 L
.89109 .10301 L
.89206 .10301 L
.89308 .10301 L
.894 .10301 L
.89501 .10301 L
.89679 .10301 L
.89788 .10301 L
.89887 .10301 L
.90002 .10301 L
.9011 .10301 L
.90203 .10301 L
.90302 .10301 L
.90411 .10301 L
.90511 .10301 L
.90692 .10301 L
.90858 .10301 L
.91039 .10301 L
.91231 .10301 L
.91398 .10301 L
.91553 .10301 L
.91723 .10301 L
.91905 .10301 L
.92008 .10301 L
.92104 .10301 L
Mistroke
.92209 .10301 L
.92319 .10301 L
.92506 .10301 L
.92611 .10301 L
.9271 .10301 L
.92895 .10301 L
.93063 .10301 L
.93156 .10301 L
.93257 .10301 L
.93441 .10301 L
.93617 .10301 L
.93779 .10301 L
.93957 .10301 L
.94144 .10301 L
.94308 .10301 L
.9446 .10301 L
.94627 .10301 L
.94805 .10301 L
.94906 .10301 L
.95 .10301 L
.95102 .10301 L
.95211 .10301 L
.95393 .10301 L
.95497 .10301 L
.95594 .10301 L
.95775 .10301 L
.9594 .10301 L
.96131 .10301 L
.96312 .10301 L
.96504 .10301 L
.96679 .10301 L
.96775 .10301 L
.9688 .10301 L
.97069 .10301 L
.97247 .10301 L
.97435 .10301 L
.97596 .10301 L
.97772 .10301 L
.97879 .10301 L
.9798 .10301 L
.9817 .10301 L
.98276 .10301 L
.98374 .10301 L
.98482 .10301 L
.98596 .10301 L
.98784 .10301 L
.98961 .10301 L
.99063 .10301 L
.99156 .10301 L
.99258 .10301 L
Mistroke
.99365 .10301 L
.99545 .10301 L
.99646 .10301 L
.99739 .10301 L
.99911 .10301 L
Mfstroke
.99911 .10301 m
1 .10301 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000oooooolLooooo`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0oooooolLooooo`00<?ooool6o`0000;o
oooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^0?oooooo7Oooool003So
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003ooooo
oa?ooooo000hooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05oooo
o`03o`000?oooooooooo0?oooooo4oooool003Sooooo00Go410@oooooooooooooooooa0@400?oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooo
oooo0?oooooo4oooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooo
oooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003ooooooooo
o`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000oooo
ooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`00
0?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool0
0ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o
0000ooooooooool0oooooolCooooo`008oooool5o`0002_ooooo00?o0000ooooooooool0:oooool5
o`0002kooooo0_l000000ol@413oooooooooo`0Zooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?oo
ool01Oo<c<co8B4Qo`000?lQ8B7oc<c<02Wooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`00
0?lb<S;ok^k^6_ooool002?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00[ooooo`03o`000?oooooo
oooo02_ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00_ooooo`03o`000?oooooooooo02_ooooo00Go
EEEEogMgMoooooooV9RHob4Q8@0/ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40:oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool001_ooooo1_l00003ooooo`03
oiRHV?lQ8B7ok^k^02cooooo00?o0000ooooooooool0;?ooool00onHV9So8B4Qonk^kP0]ooooo`Go
0000;?ooool01Ol0003ooooooooooooooooo000002cooooo00Go0000ooooooooooooooooo`00000[
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Jooooo`009Oooool0
0onHV9So8B4Qonk^kP0[ooooo`03o`000?oooooooooo02gooooo00?oV9RHob4Q8Oo^k^h0;?ooool0
1?m4A4CogMgMooooool0000]ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;?ooool01Olb<S;oV9RH
oooooonHV9So<S8b02_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
01[ooooo000Vooooo`03ogMgMomVIVKooooo02[ooooo0_l0000_ooooo`03ogMgMomVIVKooooo02_o
oooo00CogMgMoeEEEOoooooo0000;Oooool01Ol0003oEEEEo`000?l@413oc<c<02cooooo00Goc<c<
o`000?l0003o0000olc<c00[ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Jooooo`009oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool0:oooool00omgMgOoc<c<o`00000]ooooo`03oeEEEOn7QhOooooo02kooooo00Go
410@okZj^_oooooo^[Zjoa0@400[ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@400Jooooo`008oooool01Ol0003o^[ZjoooooonHV9So410@02_ooooo00?o0000oooooooo
ool0:oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo00?ok^k^odA4A?l00000;Oooool00ooM
gMgo410@oiRHV00^ooooo`05o`000?nj^[[ooooookZj^_l00000:oooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool002?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00[ooooo`03o`000?oooooooooo02_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00^ooooo`03ogMg
Mol0003ooooo02gooooo00Coc<c<odA4A?l0003o410@;?ooool01OnYZJWo410@o`000?l@413oZJVY
02Wooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo001Coooo
o`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00
Doooool00ol0003oooooooooo`3mooooo`;o00000_ooool2o`0000oooooo001Cooooo`03o`000?oo
oooooooo0?gooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd?ooooo`00Doooool00ol0003ooooo
ooooo`3nooooo`04omgMgOl0003o410@olc<c13ooooo000:oooooooo0000@?l0000;ooooo`04onk^
k_lQ8B7o410@onk^kQ3ooooo000Fooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`04ooooo`?o00000_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool00ol00006ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02Oooool01?lQ8B7oMgMgogMgMolb<S8@ooooo`008_ooool00ol0003ooooo
ooooo`0^ooooo`03o`000?oooooooooo00Oooooo0_l0000Uooooo`03o`000?oooooooooo01Oooooo
0_l0000Eooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`0^ooooo`03o`000?oooooooooo00Sooooo0_l00002ooooo`;o00003oooool005?ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo0<Sooooo001C
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`39
ooooo`00Doooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03Oooooo0_l0003<oooo
o`00Doooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03Kooooo00?o0000oooooooo
ool0c?ooool005?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0eooooo`03o`00
0?oooooooooo0<cooooo001Cooooo`;o00003?ooool00ol0003oooooooooo`0dooooo`03o`000?oo
oooooooo0<gooooo001Cooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0<oooool0
0ol0003oooooooooo`3=ooooo`00Doooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
037ooooo00?o0000ooooooooool0c_ooool005?ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0aooooo`03o`000?oooooooooo0<kooooo001Cooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool0<?ooool00ol0003oooooooooo`3?ooooo`00Doooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0coooool005?ooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo0=3ooooo001Coooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`3@oooo
o`00Doooool2o`00013ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`3Aooooo`00
Doooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0
dOooool005?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo0=7ooooo001Cooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0:oooool0
0ol0003oooooooooo`3Booooo`00Doooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
02[ooooo00?o0000ooooooooool0d_ooool005?ooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0Zooooo`03o`000?oooooooooo0=;ooooo001Cooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool0:Oooool00ol0003oooooooooo`3Cooooo`00Doooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0doooool005?ooooo0_l0000A
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0doooool005?ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo0=Cooooo001Cooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`3Dooooo`00
Doooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
e?ooool005?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo0=Cooooo001Cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`3Eooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44
ooooo`Go00001_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool0eOooool003Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool0
1OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo0=Gooooo000hooooo`05oa0@4?ooooooooooooooool@41003?oo
ool00onHV9So8B4Qonk^kP07ooooo`?o00004oooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo0=Gooooo000hooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^
kP06ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`3Eooooo`00>?ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01Ooo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0e_oo
ool003Sooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo0=Kooooo000h
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo0=Kooooo
000hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Ko
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo0=Ko
oooo001Cooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool08Oooool00ol0003ooooo
ooooo`3Gooooo`00Doooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo027ooooo00?o
0000ooooooooool0eoooool005?ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo0=Oooooo001Cooooo`;o00005Oooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo0=Oooooo001Cooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`3Hooooo`00Doooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool0f?ooool005?ooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo0=Sooooo001Cooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`3Hooooo`00Doooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0f?ooool005?o
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo0=Wo
oooo001Cooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`3Iooooo`00Doooool2o`0001Kooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`3Iooooo`00Doooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool0fOooool005?ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo0=Wooooo001Cooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`3Jooooo`00Doooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool0f_ooool005?ooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo0=[ooooo001Cooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`3Jooooo`00Doooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0f_ooool005?o
oooo0_l0000Gooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0f_ooool005?ooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo0=[ooooo
001Cooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`3Kooooo`00Doooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool0foooool005?ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo0=_ooooo001Cooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`3Kooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool0foooool003Sooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`3Kooooo`00>?ooool01Ol@413ooooo
oooooooooooo410@00_ooooo1Ol00006ooooo`?o00005oooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo0=cooooo000hooooo`05o`000?ooooooooooooooool000002oooool01?m4A4Co
gMgMooooool00007ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`3Looooo`00>?ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEE
EOoooooo00001oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool0g?ooool003Sooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co
000000Oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo0=cooooo000hooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`000007
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`3L
ooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_ooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0g?ooool0
05?ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
0=cooooo001Cooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`3Mooooo`00Doooool2o`0001[ooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`3Mooooo`00Doooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool0gOooool005?ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo0=gooooo001Cooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`3Mooooo`00Doooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool0gOooool005?ooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo0=gooooo001Cooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`3Nooooo`00Doooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0g_ooool0
05?ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
0=kooooo001Cooooo`;o00006oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo0=ko
oooo001Cooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`3Nooooo`00Doooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0g_ooool005?ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo0=kooooo001Cooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`3Oooooo`00Doooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool0goooool005?ooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo0=oooooo001Cooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`3Oooooo`00Doooool2
o`0001cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`3Oooooo`00Doooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0goooool005?o
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo0>3o
oooo001Cooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`3Pooooo`00Doooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool0h?ooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?oo
ool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo0>3ooooo000hooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`3Pooooo`00>?ooool01Ol@413ooooo
oooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`3Pooooo`00>?ooool01Ol0003o
oooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o00007?ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo0>3ooooo000hooooo`05o`000?oooooooooo
ooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0>7ooooo000hooooo`05oa0@4?oooooo
ooooooooool@41002oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`3Qooooo`00>?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool0hOooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo0>7ooooo001Cooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`3Qooooo`00Doooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0hOooool005?ooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo0>7ooooo001Cooooo`;o
00007_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo0>;ooooo001Cooooo`03o`00
0?oooooooooo01gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`3Rooooo`00Dooo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0h_oo
ool005?ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo0>;ooooo001Cooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`3Rooooo`00Doooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool0h_ooool005?ooooo00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo0>;ooooo001Cooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`3Sooooo`00Doooool2o`00023ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`3Sooooo`00Doooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0hoooool005?ooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0>?ooooo001Cooooo`03o`00
0?oooooooooo023ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`3Sooooo`00Dooo
ool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0i?oo
ool005?ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo0>Cooooo001Cooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`3Tooooo`00Doooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0iOooool005?ooooo00?o0000ooooooooool08?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo0>Gooooo001Cooooo`;o00008_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0>Gooooo001Cooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`3Uooooo`00Doooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0i_ooool005?ooooo00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0>Kooooo001Cooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3Vooooo`00>?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<
c<`01_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0i_ooool003Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7o
V9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo0>Oooooo000hooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo0>Oooooo000hooooo`05o`000?ooooooooooooooool000002oooool0
1Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0000Sooooo`05o`000?ooooooooooooooool00000
j_ooool003Sooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<
c<`01_ooool00ol0003oooooooooo`0Sooooo`05o`000?ooooooooooooooool00000j_ooool003So
oooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool0
0ol0003oooooooooo`0Tooooo`?o0000joooool003Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;
ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`3ooooooa?ooooo000h
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo
00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001C
ooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCoooo
o`00Doooool2o`000?oooooo5?ooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Dooo
ool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool0
05?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?o
oooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooo
oolCooooo`00Doooool2o`000?oooooo5?ooool005?ooooo00?o0000ooooooooool0oooooolCoooo
o`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo
4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3o
oooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000oooooooo
ool0oooooolCooooo`00Doooool2o`000?oooooo5?ooool005?ooooo00?o0000ooooooooool0oooo
oolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo
0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003ooooo
ooooo`3ooooooa?ooooo0019ooooo`Co000000?o410@ooooooooool00oooool00ol0003ooooooooo
o`3ooooooa?ooooo001;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooolC
ooooo`00Boooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo4oooool004_o
oooo00?o0000ooooooooool01Oooool3o`000?oooooo4oooool004_ooooo00?o0000ooooooooool0
oooooolKooooo`00Boooool00ol0003oooooooooo`3ooooooa_ooooo001;ooooo`03o`000?oooooo
oooo0?oooooo6oooool004Wooooo00?oEEEEofIVI_l00000oooooolMooooo`00O?ooool3o`000003
oa0@4?oooooooooo0>Kooooo001nooooo`03oa0@4?nj^[[ooooo00Kooooo0_l0000;ooooo`03o`00
0?nj^[[ooooo00cooooo0_l00006ooooo`03o`000?nj^[[ooooo0;[ooooo001nooooo`03oiRHV?lb
<S;ooooo00Kooooo00?o0000ooooooooool02_ooool2oc8b<Pkooooo00?o0000ooooooooool01?oo
ool2oc8b<[_ooooo001nooooo`03omgMgOl0003o^[Zj00Kooooo00?o0000ooooooooool00_ooool2
o`0000;ooooo0_l00002ooooo`03ohN7Qol0003o^[Zj00Gooooo00GoV9RHo`000?l0003oA4A4okZj
^P03ooooo`03o`000?oooooooooo00Cooooo00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000o`00
0?m4A4Co^[Zj013ooooo1Ol0002Dooooo`00O_ooool00omEEEGoMgMgodA4A006ooooo`03o`000?oo
oooooooo00;ooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd2ooooo`03olc<c?l0003o410@00Go
oooo00Go410@okZj^_o^k^koMgMgoa0@4003ooooo`03o`000?oooooooooo00Cooooo00?oc<c<o`00
0?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l000001_ooooooV9RHob4Q8Oo^
k^koooooodA4A9Cooooo001mooooo`05omgMgOl@413oooooob4Q8OoMgMd01Oooool00ol0003ooooo
ooooo`03ooooo`04omgMgOl0003o410@olc<c0_ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?oV9RHob4Q8Oo^k^h0UOooool007gooooo
00GoIVIVohN7QoooooooV9RHoeEEE@05ooooo`03o`000?oooooooooo00?ooooo00Cok^k^ob4Q8Ol@
413ok^k^2oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool02oooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h0U?ooool007cooooo00?ok^k^o`000?o^
k^h00_ooool00ol0003ogMgMooooo`03ooooo`03o`000?oooooooooo00?ooooo00Co8B4QogMgMomg
MgOo<S8b2oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool05Oooool00omgMgOoIVIVooooo`2Cooooo`00O?ooool01?l@413o0000o`000?ooool2o`00
0003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool00_ooool2o`0000;ooooo0_l00008oooo
o`03oa0@4?l0003o000000?o00001?ooool00ol0003oooooooooo`0Aooooo`03oa0@4?l0003o0000
00?o00005Oooool00ol0003oooooooooo`2Booooo`00Qoooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`05
o`000?nj^[[ooooooiRHV?l@4100U?ooool008Oooooo0_l0000Cooooo`03o`000?oooooooooo00Co
oooo0_l0000Eooooo`03o`000?oooooooooo01;ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c02Doooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-3.4116, -0.234311, \
0.0510397, 0.00762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.230769 0.0769231 0.103006 0.515028 [
[.07692 .09051 -6 -9 ]
[.07692 .09051 6 0 ]
[.38462 .09051 -3 -9 ]
[.38462 .09051 3 0 ]
[.53846 .09051 -3 -9 ]
[.53846 .09051 3 0 ]
[.69231 .09051 -3 -9 ]
[.69231 .09051 3 0 ]
[.84615 .09051 -3 -9 ]
[.84615 .09051 3 0 ]
[1 .09051 -6 -9 ]
[1 .09051 6 0 ]
[1.025 .10301 0 -6 ]
[1.025 .10301 10 6 ]
[.21827 0 -24 -4.5 ]
[.21827 0 0 4.5 ]
[.21827 .20601 -18 -4.5 ]
[.21827 .20601 0 4.5 ]
[.21827 .30902 -18 -4.5 ]
[.21827 .30902 0 4.5 ]
[.21827 .41202 -18 -4.5 ]
[.21827 .41202 0 4.5 ]
[.21827 .51503 -18 -4.5 ]
[.21827 .51503 0 4.5 ]
[.21827 .61803 -6 -4.5 ]
[.21827 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07692 .10301 m
.07692 .10926 L
s
[(-2)] .07692 .09051 0 1 Mshowa
.38462 .10301 m
.38462 .10926 L
s
[(2)] .38462 .09051 0 1 Mshowa
.53846 .10301 m
.53846 .10926 L
s
[(4)] .53846 .09051 0 1 Mshowa
.69231 .10301 m
.69231 .10926 L
s
[(6)] .69231 .09051 0 1 Mshowa
.84615 .10301 m
.84615 .10926 L
s
[(8)] .84615 .09051 0 1 Mshowa
1 .10301 m
1 .10926 L
s
[(10)] 1 .09051 0 1 Mshowa
.125 Mabswid
.11538 .10301 m
.11538 .10676 L
s
.15385 .10301 m
.15385 .10676 L
s
.19231 .10301 m
.19231 .10676 L
s
.26923 .10301 m
.26923 .10676 L
s
.30769 .10301 m
.30769 .10676 L
s
.34615 .10301 m
.34615 .10676 L
s
.42308 .10301 m
.42308 .10676 L
s
.46154 .10301 m
.46154 .10676 L
s
.5 .10301 m
.5 .10676 L
s
.57692 .10301 m
.57692 .10676 L
s
.61538 .10301 m
.61538 .10676 L
s
.65385 .10301 m
.65385 .10676 L
s
.73077 .10301 m
.73077 .10676 L
s
.76923 .10301 m
.76923 .10676 L
s
.80769 .10301 m
.80769 .10676 L
s
.88462 .10301 m
.88462 .10676 L
s
.92308 .10301 m
.92308 .10676 L
s
.96154 .10301 m
.96154 .10676 L
s
.03846 .10301 m
.03846 .10676 L
s
.25 Mabswid
0 .10301 m
1 .10301 L
s
gsave
1.025 .10301 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.23077 0 m
.23702 0 L
s
[(-0.2)] .21827 0 1 0 Mshowa
.23077 .20601 m
.23702 .20601 L
s
[(0.2)] .21827 .20601 1 0 Mshowa
.23077 .30902 m
.23702 .30902 L
s
[(0.4)] .21827 .30902 1 0 Mshowa
.23077 .41202 m
.23702 .41202 L
s
[(0.6)] .21827 .41202 1 0 Mshowa
.23077 .51503 m
.23702 .51503 L
s
[(0.8)] .21827 .51503 1 0 Mshowa
.23077 .61803 m
.23702 .61803 L
s
[(1)] .21827 .61803 1 0 Mshowa
.125 Mabswid
.23077 .02575 m
.23452 .02575 L
s
.23077 .0515 m
.23452 .0515 L
s
.23077 .07725 m
.23452 .07725 L
s
.23077 .12876 m
.23452 .12876 L
s
.23077 .15451 m
.23452 .15451 L
s
.23077 .18026 m
.23452 .18026 L
s
.23077 .23176 m
.23452 .23176 L
s
.23077 .25751 m
.23452 .25751 L
s
.23077 .28327 m
.23452 .28327 L
s
.23077 .33477 m
.23452 .33477 L
s
.23077 .36052 m
.23452 .36052 L
s
.23077 .38627 m
.23452 .38627 L
s
.23077 .43777 m
.23452 .43777 L
s
.23077 .46353 m
.23452 .46353 L
s
.23077 .48928 m
.23452 .48928 L
s
.23077 .54078 m
.23452 .54078 L
s
.23077 .56653 m
.23452 .56653 L
s
.23077 .59228 m
.23452 .59228 L
s
.25 Mabswid
.23077 0 m
.23077 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
123.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.14271 .10301 m
.14365 .10301 L
.14538 .10301 L
.14721 .10301 L
.14893 .10301 L
.1505 .10301 L
.15231 .10301 L
.15403 .10301 L
.15561 .10301 L
.15708 .10301 L
.1587 .10301 L
.16042 .10301 L
.1623 .10301 L
.16337 .10301 L
.16434 .10301 L
.16614 .10301 L
.16804 .10301 L
.16975 .10301 L
.17134 .10301 L
.17309 .10301 L
.17496 .10301 L
.17675 .10301 L
.17866 .10301 L
.18028 .10301 L
.18208 .10301 L
.184 .10301 L
.18508 .10301 L
.18607 .10301 L
.1879 .10301 L
.18982 .10301 L
.1915 .10301 L
.1933 .10301 L
.195 .10301 L
.19654 .10301 L
.19836 .10301 L
.19938 .10301 L
.20033 .10301 L
.20206 .10301 L
.2039 .10301 L
.20554 .10301 L
.20703 .10301 L
.20875 .10301 L
.21039 .10301 L
.2119 .10301 L
.2133 .10301 L
.21483 .10301 L
.21647 .10301 L
.21826 .10301 L
.21927 .10301 L
.2202 .10301 L
Mistroke
.22191 .10301 L
.22372 .10301 L
.22534 .10301 L
.22685 .10301 L
.22851 .10301 L
.23029 .10301 L
.23207 .10301 L
.23308 .10301 L
.23403 .10301 L
.23594 .10301 L
.23701 .10301 L
.23799 .10301 L
.23965 .10301 L
.24147 .10301 L
.24336 .10301 L
.24512 .10301 L
.24613 .10301 L
.24722 .10301 L
.24825 .10301 L
.2492 .10301 L
.251 .10301 L
.25291 .10301 L
.2539 .10301 L
.25496 .10301 L
.25687 .10301 L
.25804 .10301 L
.25915 .10301 L
.26014 .10301 L
.26123 .10301 L
.26303 .10301 L
.26473 .10301 L
.26658 .10301 L
.26763 .10301 L
.26859 .10301 L
.27041 .10301 L
.27144 .10301 L
.2724 .10301 L
.27342 .10301 L
.27435 .10301 L
.27541 .10301 L
.27642 .10301 L
.27813 .10301 L
.27993 .10301 L
.28148 .10301 L
.28317 .10301 L
.285 .10301 L
.28602 .10302 L
.28695 .10302 L
.28877 .10302 L
.2905 .10303 L
Mistroke
.29231 .10304 L
.29333 .10305 L
.29426 .10306 L
.29599 .10308 L
.29781 .10312 L
.29945 .10316 L
.30098 .1032 L
.30265 .10327 L
.30445 .10337 L
.30636 .1035 L
.30844 .10369 L
.31041 .10394 L
.31222 .10423 L
.31566 .10501 L
.3174 .10555 L
.31931 .10628 L
.32278 .10807 L
.32595 .1104 L
.32944 .11392 L
.33311 .11901 L
.33631 .12488 L
.33929 .13176 L
.34605 .15335 L
.34988 .16974 L
.3534 .18772 L
.36137 .23813 L
.37582 .35252 L
.3826 .40554 L
.38895 .44727 L
.39214 .4639 L
.39557 .47782 L
.39752 .48376 L
.39937 .48802 L
.40103 .49067 L
.40285 .49227 L
.40379 .49259 L
.40479 .49252 L
.40658 .49142 L
.4085 .48883 L
.40959 .48674 L
.4106 .4844 L
.41413 .47346 L
.4179 .45738 L
.42503 .41725 L
.43153 .37373 L
.44739 .26493 L
.45436 .22426 L
.46204 .18751 L
.46901 .16169 L
.47555 .14343 L
Mistroke
.48244 .12944 L
.48632 .12355 L
.48987 .11917 L
.49345 .1156 L
.49727 .11257 L
.50146 .11 L
.50535 .10819 L
.50933 .10679 L
.51307 .10579 L
.51644 .10511 L
.52008 .10455 L
.52352 .10414 L
.52722 .10382 L
.53071 .1036 L
.53389 .10345 L
.53762 .10332 L
.53972 .10326 L
.54167 .10321 L
.54525 .10315 L
.54723 .10313 L
.54905 .10311 L
.55266 .10307 L
.55456 .10306 L
.55656 .10305 L
.55992 .10304 L
.56183 .10303 L
.5636 .10303 L
.5657 .10302 L
.56767 .10302 L
.57137 .10301 L
.57344 .10301 L
.57535 .10301 L
.57757 .10301 L
.57967 .10301 L
.58137 .10301 L
.58322 .10301 L
.58646 .10301 L
.58829 .10301 L
.59025 .10301 L
.59376 .10301 L
.59547 .10301 L
.59732 .10301 L
.59895 .10301 L
.60067 .10301 L
.60223 .10301 L
.60394 .10301 L
.60694 .10301 L
.60895 .10301 L
.61086 .10301 L
.61259 .10301 L
Mistroke
.61443 .10301 L
.61643 .10301 L
.61828 .10301 L
.62027 .10301 L
.62246 .10301 L
.62434 .10301 L
.62606 .10301 L
.62795 .10301 L
.62993 .10301 L
.63167 .10301 L
.63328 .10301 L
.63505 .10301 L
.63694 .10301 L
.63874 .10301 L
.64071 .10301 L
.64278 .10301 L
.64471 .10301 L
.64651 .10301 L
.64816 .10301 L
.65006 .10301 L
.65186 .10301 L
.65381 .10301 L
.65588 .10301 L
.65764 .10301 L
.65959 .10301 L
.66168 .10301 L
.66394 .10301 L
.66606 .10301 L
.66802 .10301 L
.66972 .10301 L
.67154 .10301 L
.67326 .10301 L
.67483 .10301 L
.67667 .10301 L
.67866 .10301 L
.68055 .10301 L
.68229 .10301 L
.68408 .10301 L
.68576 .10301 L
.68761 .10301 L
.68959 .10301 L
.69166 .10301 L
.69363 .10301 L
.6954 .10301 L
.69733 .10301 L
.69926 .10301 L
.70104 .10301 L
.70299 .10301 L
.70506 .10301 L
.70685 .10301 L
Mistroke
.70853 .10301 L
.71036 .10301 L
.71233 .10301 L
.71409 .10301 L
.71599 .10301 L
.71779 .10301 L
.71945 .10301 L
.72095 .10301 L
.7226 .10301 L
.72432 .10301 L
.72594 .10301 L
.72772 .10301 L
.72967 .10301 L
.7317 .10301 L
.7336 .10301 L
.73537 .10301 L
.73699 .10301 L
.73885 .10301 L
.74061 .10301 L
.74253 .10301 L
.7435 .10301 L
.74456 .10301 L
.74645 .10301 L
.7482 .10301 L
.74927 .10301 L
.75028 .10301 L
.75217 .10301 L
.75323 .10301 L
.75421 .10301 L
.75527 .10301 L
.75643 .10301 L
.75831 .10301 L
.75934 .10301 L
.76029 .10301 L
.76201 .10301 L
.76384 .10301 L
.76487 .10301 L
.76599 .10301 L
.76698 .10301 L
.76803 .10301 L
.76897 .10301 L
.77001 .10301 L
.77184 .10301 L
.77372 .10301 L
.77544 .10301 L
.77639 .10301 L
.77743 .10301 L
.77932 .10301 L
.78108 .10301 L
.78296 .10301 L
Mistroke
.78473 .10301 L
.78634 .10301 L
.78803 .10301 L
.78982 .10301 L
.79135 .10301 L
.79303 .10301 L
.79483 .10301 L
.79585 .10301 L
.79677 .10301 L
.79857 .10301 L
.80027 .10301 L
.80185 .10301 L
.80354 .10301 L
.80497 .10301 L
.80656 .10301 L
.80826 .10301 L
.81009 .10301 L
.81182 .10301 L
.81341 .10301 L
.81526 .10301 L
.81701 .10301 L
.81858 .10301 L
.82029 .10301 L
.82214 .10301 L
.82308 .10301 L
.82411 .10301 L
.82594 .10301 L
.82764 .10301 L
.82935 .10301 L
.83098 .10301 L
.83244 .10301 L
.83403 .10301 L
.83575 .10301 L
.83759 .10301 L
.83932 .10301 L
.84089 .10301 L
.84278 .10301 L
.84373 .10301 L
.84477 .10301 L
.84662 .10301 L
.84834 .10301 L
.84939 .10301 L
.85037 .10301 L
.85223 .10301 L
.85326 .10301 L
.85422 .10301 L
.85527 .10301 L
.85639 .10301 L
.85813 .10301 L
.85976 .10301 L
Mistroke
.8607 .10301 L
.86169 .10301 L
.86347 .10301 L
.86533 .10301 L
.86706 .10301 L
.86895 .10301 L
.87001 .10301 L
.87098 .10301 L
.87272 .10301 L
.87434 .10301 L
.87613 .10301 L
.87804 .10301 L
.879 .10301 L
.88004 .10301 L
.88195 .10301 L
.8838 .10301 L
.88551 .10301 L
.88727 .10301 L
.88892 .10301 L
.8904 .10301 L
.892 .10301 L
.89375 .10301 L
.8956 .10301 L
.89717 .10301 L
.8989 .10301 L
.89988 .10301 L
.90094 .10301 L
.90187 .10301 L
.90286 .10301 L
.90473 .10301 L
.90646 .10301 L
.90742 .10301 L
.90845 .10301 L
.91032 .10301 L
.91145 .10301 L
.91253 .10301 L
.9135 .10301 L
.91456 .10301 L
.91648 .10301 L
.91822 .10301 L
.91918 .10301 L
.92023 .10301 L
.92212 .10301 L
.9239 .10301 L
.92578 .10301 L
.92739 .10301 L
.92915 .10301 L
.93104 .10301 L
.93279 .10301 L
.93371 .10301 L
Mistroke
.93472 .10301 L
.93577 .10301 L
.93676 .10301 L
.93857 .10301 L
.94024 .10301 L
.94206 .10301 L
.94398 .10301 L
.9456 .10301 L
.94733 .10301 L
.94896 .10301 L
.95044 .10301 L
.95218 .10301 L
.95407 .10301 L
.95586 .10301 L
.95751 .10301 L
.95926 .10301 L
.96114 .10301 L
.96291 .10301 L
.96454 .10301 L
.96644 .10301 L
.96751 .10301 L
.96851 .10301 L
.97033 .10301 L
.97135 .10301 L
.97227 .10301 L
.97326 .10301 L
.97429 .10301 L
.97615 .10301 L
.97718 .10301 L
.97814 .10301 L
.9792 .10301 L
.98033 .10301 L
.98131 .10301 L
.98237 .10301 L
.98337 .10301 L
.9843 .10301 L
.98605 .10301 L
.98791 .10301 L
.98957 .10301 L
.99139 .10301 L
.99328 .10301 L
.99504 .10301 L
.99669 .10301 L
.9982 .10301 L
.99993 .10301 L
Mfstroke
.99993 .10301 m
1 .10301 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000oooooolLooooo`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0oooooolLooooo`00<?ooool6o`0000;o
oooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^0?oooooo7Oooool003So
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003ooooo
oa?ooooo000hooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05oooo
o`03o`000?oooooooooo0?oooooo4oooool003Sooooo00Go410@oooooooooooooooooa0@400?oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooo
oooo0?oooooo4oooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooo
oooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003ooooooooo
o`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000oooo
ooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`00
0?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool0
0ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o
0000ooooooooool0oooooolCooooo`008oooool5o`0002_ooooo00?o0000ooooooooool0:oooool5
o`0002kooooo0_l000000ol@413oooooooooo`0Zooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?oo
ool01Oo<c<co8B4Qo`000?lQ8B7oc<c<02Wooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`00
0?lb<S;ok^k^6_ooool002?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00[ooooo`03o`000?oooooo
oooo02_ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00_ooooo`03o`000?oooooooooo02_ooooo00Go
EEEEogMgMoooooooV9RHob4Q8@0/ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40:oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool001_ooooo1_l00003ooooo`03
oiRHV?lQ8B7ok^k^02cooooo00?o0000ooooooooool0;?ooool00onHV9So8B4Qonk^kP0]ooooo`Go
0000;?ooool01Ol0003ooooooooooooooooo000002cooooo00Go0000ooooooooooooooooo`00000[
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Jooooo`009Oooool0
0onHV9So8B4Qonk^kP0[ooooo`03o`000?oooooooooo02gooooo00?oV9RHob4Q8Oo^k^h0;?ooool0
1?m4A4CogMgMooooool0000]ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;?ooool01Olb<S;oV9RH
oooooonHV9So<S8b02_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
01[ooooo000Vooooo`03ogMgMomVIVKooooo02[ooooo0_l0000_ooooo`03ogMgMomVIVKooooo02_o
oooo00CogMgMoeEEEOoooooo0000;Oooool01Ol0003oEEEEo`000?l@413oc<c<02cooooo00Goc<c<
o`000?l0003o0000olc<c00[ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Jooooo`009oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool0:oooool00omgMgOoc<c<o`00000]ooooo`03oeEEEOn7QhOooooo02kooooo00Go
410@okZj^_oooooo^[Zjoa0@400[ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@400Jooooo`008oooool01Ol0003o^[ZjoooooonHV9So410@02_ooooo00?o0000oooooooo
ool0:oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo00?ok^k^odA4A?l00000;Oooool00ooM
gMgo410@oiRHV00^ooooo`05o`000?nj^[[ooooookZj^_l00000:oooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool002?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00[ooooo`03o`000?oooooooooo02_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00^ooooo`03ogMg
Mol0003ooooo02gooooo00Coc<c<odA4A?l0003o410@;?ooool01OnYZJWo410@o`000?l@413oZJVY
02Wooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo001Coooo
o`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00
Doooool00ol0003oooooooooo`3mooooo`;o00000_ooool2o`0000oooooo001Cooooo`03o`000?oo
oooooooo0?gooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd?ooooo`00Doooool00ol0003ooooo
ooooo`3booooo`03o`000?oooooooooo00Wooooo00CogMgMo`000?l@413oc<c<4?ooool000[ooooo
ool00010o`0000_ooooo00Cok^k^ob4Q8Ol@413ok^k^4?ooool001Kooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`02o`0000Oooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool4o`0000Sooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02Oooool01?lQ8B7oMgMgogMgMolb<S8@ooooo`008_ooool00ol0003ooooo
ooooo`0^ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0Rooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`0^ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool02?ooool2o`0000;ooooo
0_l0000?ooooo`00Doooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo03?ooooo00?o
0000ooooooooool0_Oooool005?ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0a
ooooo`03o`000?oooooooooo0;kooooo001Cooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool0;_ooool2o`000<7ooooo001Cooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool0;Oooool00ol0003oooooooooo`31ooooo`00Doooool00ol0003oooooooooo`0Oooooo`03o`00
0?oooooooooo02cooooo00?o0000ooooooooool0`Oooool005?ooooo0_l0000Pooooo`03o`000?oo
oooooooo02_ooooo00?o0000ooooooooool0`_ooool005?ooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`0Zooooo`03o`000?oooooooooo0<;ooooo001Cooooo`03o`000?oooooooooo
023ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`33ooooo`00Doooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0`oooool005?ooooo
00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo0<Cooooo
001Cooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool09oooool00ol0003ooooooooo
o`34ooooo`00Doooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool0aOooool005?ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Uoooo
o`03o`000?oooooooooo0<Gooooo001Cooooo`;o00008oooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo0<Gooooo001Cooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`36ooooo`00Doooool00ol0003oooooooooo`0Rooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool0a_ooool005?ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo0<Kooooo001Cooooo`03o`000?oooooooooo
02?ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`36ooooo`00Doooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0aoooool005?ooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo0<Oooooo
001Cooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`37ooooo`00Doooool2o`0002Cooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`37
ooooo`00Doooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool0b?ooool005?ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo0<Sooooo001Cooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
8?ooool00ol0003oooooooooo`38ooooo`00Doooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo023ooooo00?o0000ooooooooool0b?ooool005?ooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo0<Wooooo000hooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`39ooooo`00>?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0bOooool003Sooooo00Go410@
oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0000Uooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool0bOooool003Sooooo00Go0000ooooooooooooooooo`00
000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo0<[ooooo000hooooo`05o`000?ooooooooooooooool000003_oo
ool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`3:ooooo`00>?ooool01Ol@413ooooooooooooooooo410@00oooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool0b_ooool003Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj
^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool0b_ooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRH
V?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool0boooool005?ooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo0<_ooooo001Cooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`3;ooooo`00Doooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0boooool005?ooooo0_l0000Xoooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0boooool005?ooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo0<cooooo001Cooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`3<ooooo`00Dooo
ool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0c?oo
ool005?ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo0<cooooo001Cooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`3<ooooo`00Doooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool0c?ooool005?ooooo00?o0000ooooooooool0:?ooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo0<cooooo001Cooooo`;o0000:Oooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo0<gooooo001Cooooo`03o`000?oooooooooo02Sooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`3=ooooo`00Doooool00ol0003oooooooooo`0Xoooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0cOooool005?ooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo0<gooooo001Cooooo`03o`00
0?oooooooooo02Sooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`3=ooooo`00Dooo
ool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0cOoo
ool005?ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo0<kooooo001Cooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`3>ooooo`00Doooool2o`0002[ooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`3>ooooo`00Doooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool0c_ooool005?ooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo0<kooooo001Cooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`3>ooooo`00Doooool00ol0003oooooooooo`0Yoooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0c_ooool005?ooooo00?o0000oooooooo
ool0:Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo0<oooooo000hooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`3?ooooo`00
>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo0<oo
oooo000hooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Kooooo0ol0000Yooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool0coooool003Sooooo00Go0000oooooooooooo
ooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool0:_ooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo0<oooooo000hooooo`05o`000?oooooooooooooo
ool000002oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo02[ooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`3?ooooo`00>?ooool01Ol@413ooooooooooooooooo
410@00cooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool0coooool003Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<
ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo0=3ooooo000hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Oooool0
0omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`3@ooooo`00Doooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool0d?ooool005?ooooo00?o0000ooooooooool0:_ooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo0=3ooooo001Cooooo`;o0000:oooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo0=3ooooo001Cooooo`03o`000?oooooooooo02[ooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`3@ooooo`00Doooool00ol0003oooooooooo`0[
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0d?ooool005?ooooo00?o0000oooo
ooooool0:oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo0=7ooooo001Cooooo`03
o`000?oooooooooo02_ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`3Aooooo`00
Doooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
dOooool005?ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo0=7ooooo001Cooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`3Aooooo`00Doooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool0dOooool005?ooooo0_l0000/ooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool0dOooool005?ooooo00?o0000ooooooooool0:oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo0=;ooooo001Cooooo`03o`000?oooooooooo02cooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`3Booooo`00Doooool00ol0003oooooooooo`0/
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0d_ooool005?ooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo0=;ooooo001Cooooo`03
o`000?oooooooooo02cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`3Booooo`00
Doooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
d_ooool005?ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo0=;ooooo001Cooooo`;o0000;Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo0=?ooooo001Cooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`3Cooooo`00Doooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0doooool005?ooooo00?o0000ooooooooool0;Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo0=?ooooo001Cooooo`03o`000?oooooooooo02gooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`3Cooooo`00>?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003ooooo
ooooo`0]ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0doooool003Sooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Ko
oooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo0=?o
oooo000hooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo0000
00Kooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
0=Cooooo000hooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So
8B4Q00Kooooo0ol0000]ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0e?ooool0
03Sooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_oo
ool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0e?oo
ool003Sooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo00Sooooo00?o
0000ooooooooool0;_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0=Cooooo000h
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oo
oooooooo02kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`3Dooooo`00>?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003ooooo
ooooo`0^ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0e?ooool005?ooooo00?o
0000ooooooooool0;_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0=Cooooo001C
ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`3E
ooooo`00Doooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool0eOooool005?ooooo0_l0000_ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool0eOooool005?ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo0=Gooooo001Cooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`3Eooooo`00Doooool00ol0003oooooooooo`0_ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0eOooool005?ooooo00?o0000ooooooooool0;oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo0=Kooooo001Cooooo`03o`000?oooooooooo02oo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`3Fooooo`00Doooool00ol0003ooooo
ooooo`0`ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0e_ooool005?ooooo00?o
0000ooooooooool0<?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0=Kooooo001C
ooooo`;o0000<Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0=Oooooo001Coooo
o`03o`000?oooooooooo033ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3Goooo
o`00Doooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0eoooool005?ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo0=Sooooo001Cooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`3Hooooo`00Doooool00ol0003oooooooooo`0booooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0f?ooool005?ooooo00?o0000ooooooooool0<_ooool01Ol0
003ooooooooooooooooo00000=_ooooo001Cooooo`03o`000?oooooooooo03;ooooo00Go0000oooo
ooooooooooooo`00003Kooooo`00Doooool00ol0003oooooooooo`0cooooo`04o`000?oooooooooo
o`000=_ooooo001Cooooo`;o0000=?ooool3o`000=cooooo001Cooooo`03o`000?oooooooooo03Co
oooo00?o0000ooooooooool0foooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Dooo
ool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool0
03Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ
8B7oc<c<00Kooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003ooooo
ooooo`3ooooooa?ooooo000hooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooo
oooooooooooo000000Kooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01Ol0003ooooo
oooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000oooooolCoooo
o`00>?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c006
ooooo`03o`000?oooooooooo0?oooooo4oooool003Sooooo00Go410@oooooooooooooooooa0@400;
ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`3ooooooa?ooooo000h
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo
00?o0000ooooooooool0oooooolCooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo
00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo
00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001C
ooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo0_l0003ooooooaCooooo001Cooooo`03
o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Dooo
ool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool0
05?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?o
oooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo0_l0003ooooooaCooooo001C
ooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCoooo
o`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo
4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3o
oooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo0_l0003ooooooaCo
oooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooo
oolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo
0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00BOooool4o`000003oa0@
4?oooooooooo00?ooooo00?o0000ooooooooool0oooooolCooooo`00Boooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo0?oooooo4oooool004_ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`3ooooooa?ooooo001;ooooo`03o`000?oooooooooo00Gooooo0ol0003ooooo
oa?ooooo001;ooooo`03o`000?oooooooooo0?oooooo6oooool004_ooooo00?o0000ooooooooool0
oooooolKooooo`00Boooool00ol0003oooooooooo`3ooooooa_ooooo0019ooooo`03oeEEEOmVIVKo
00000?oooooo7Oooool007cooooo0ol000000ol@413oooooooooo`3Vooooo`00O_ooool00ol@413o
^[Zjooooo`06ooooo`;o00002oooool00ol0003o^[Zjooooo`0<ooooo`;o00001_ooool00ol0003o
^[Zjooooo`2jooooo`00O_ooool00onHV9So<S8booooo`06ooooo`03o`000?oooooooooo00[ooooo
0_lb<S8>ooooo`03o`000?oooooooooo00Cooooo0_lb<S:kooooo`00O_ooool00ooMgMgo0000okZj
^P06ooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`;o00000_ooool00on7QhOo0000okZj
^P05ooooo`05oiRHV?l0003o0000odA4A?nj^[X00oooool00ol0003oooooooooo`04ooooo`03ohN7
Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0@ooooo`05oiRHV?l@413o0000oc8b
<_o<c<`0U?ooool007kooooo00?oEEEEogMgMom4A4@01_ooool00ol0003oooooooooo`02ooooo`06
onk^k_lQ8B7oQhN7okZj^_l0003ogMgM0_ooool00oo<c<co0000oa0@4005ooooo`05oa0@4?nj^[[o
k^k^ogMgMol@41000oooool00ol0003oooooooooo`04ooooo`03olc<c?l0003o410@00cooooo00Go
410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko000000Kooooooa0@4?nj^[[oooooogMgMolb<S:Doooo
o`00OOooool01OoMgMgo410@oooooolQ8B7ogMgM00Gooooo00?o0000ooooooooool00oooool01?oM
gMgo0000oa0@4?o<c<`;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo09;ooooo001mooooo`05ofIVI_n7QhOooooo
oiRHV?mEEED01Oooool00ol0003oooooooooo`03ooooo`04onk^k_lQ8B7o410@onk^kP_ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00_ooooo1_l0
0004ooooo`03ojVYZOl@413ooooo09?ooooo001looooo`03onk^k_l0003ok^k^00;ooooo00?o0000
omgMgOooool00oooool00ol0003oooooooooo`03ooooo`04ob4Q8OmgMgOoMgMgoc8b<P_ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Cooooo00?o
410@o`000?nj^[X0U?ooool007cooooo00Co410@o`000?l0003ooooo0_l000000ol@413ooooooooo
o`02ooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`;o00002?ooool00ol@413o0000o`00
0003o`0000Cooooo00?o0000ooooooooool04Oooool00ol@413o0000o`000003o`0001Cooooo00?o
^[Zjob4Q8Oooool0Toooool008Oooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool01Ol@413oV9RHoooooonj
^[[o000009Cooooo0027ooooo`;o00004oooool00ol0003oooooooooo`04ooooo`;o00005Oooool0
0ol0003oooooooooo`0Booooo`05ojVYZOl@413o0000oa0@4?nYZJT0U?ooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-3.4116, -0.234311, \
0.0510397, 0.00762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.230769 0.0769231 0.103006 0.515028 [
[.07692 .09051 -6 -9 ]
[.07692 .09051 6 0 ]
[.38462 .09051 -3 -9 ]
[.38462 .09051 3 0 ]
[.53846 .09051 -3 -9 ]
[.53846 .09051 3 0 ]
[.69231 .09051 -3 -9 ]
[.69231 .09051 3 0 ]
[.84615 .09051 -3 -9 ]
[.84615 .09051 3 0 ]
[1 .09051 -6 -9 ]
[1 .09051 6 0 ]
[1.025 .10301 0 -6 ]
[1.025 .10301 10 6 ]
[.21827 0 -24 -4.5 ]
[.21827 0 0 4.5 ]
[.21827 .20601 -18 -4.5 ]
[.21827 .20601 0 4.5 ]
[.21827 .30902 -18 -4.5 ]
[.21827 .30902 0 4.5 ]
[.21827 .41202 -18 -4.5 ]
[.21827 .41202 0 4.5 ]
[.21827 .51503 -18 -4.5 ]
[.21827 .51503 0 4.5 ]
[.21827 .61803 -6 -4.5 ]
[.21827 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07692 .10301 m
.07692 .10926 L
s
[(-2)] .07692 .09051 0 1 Mshowa
.38462 .10301 m
.38462 .10926 L
s
[(2)] .38462 .09051 0 1 Mshowa
.53846 .10301 m
.53846 .10926 L
s
[(4)] .53846 .09051 0 1 Mshowa
.69231 .10301 m
.69231 .10926 L
s
[(6)] .69231 .09051 0 1 Mshowa
.84615 .10301 m
.84615 .10926 L
s
[(8)] .84615 .09051 0 1 Mshowa
1 .10301 m
1 .10926 L
s
[(10)] 1 .09051 0 1 Mshowa
.125 Mabswid
.11538 .10301 m
.11538 .10676 L
s
.15385 .10301 m
.15385 .10676 L
s
.19231 .10301 m
.19231 .10676 L
s
.26923 .10301 m
.26923 .10676 L
s
.30769 .10301 m
.30769 .10676 L
s
.34615 .10301 m
.34615 .10676 L
s
.42308 .10301 m
.42308 .10676 L
s
.46154 .10301 m
.46154 .10676 L
s
.5 .10301 m
.5 .10676 L
s
.57692 .10301 m
.57692 .10676 L
s
.61538 .10301 m
.61538 .10676 L
s
.65385 .10301 m
.65385 .10676 L
s
.73077 .10301 m
.73077 .10676 L
s
.76923 .10301 m
.76923 .10676 L
s
.80769 .10301 m
.80769 .10676 L
s
.88462 .10301 m
.88462 .10676 L
s
.92308 .10301 m
.92308 .10676 L
s
.96154 .10301 m
.96154 .10676 L
s
.03846 .10301 m
.03846 .10676 L
s
.25 Mabswid
0 .10301 m
1 .10301 L
s
gsave
1.025 .10301 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.23077 0 m
.23702 0 L
s
[(-0.2)] .21827 0 1 0 Mshowa
.23077 .20601 m
.23702 .20601 L
s
[(0.2)] .21827 .20601 1 0 Mshowa
.23077 .30902 m
.23702 .30902 L
s
[(0.4)] .21827 .30902 1 0 Mshowa
.23077 .41202 m
.23702 .41202 L
s
[(0.6)] .21827 .41202 1 0 Mshowa
.23077 .51503 m
.23702 .51503 L
s
[(0.8)] .21827 .51503 1 0 Mshowa
.23077 .61803 m
.23702 .61803 L
s
[(1)] .21827 .61803 1 0 Mshowa
.125 Mabswid
.23077 .02575 m
.23452 .02575 L
s
.23077 .0515 m
.23452 .0515 L
s
.23077 .07725 m
.23452 .07725 L
s
.23077 .12876 m
.23452 .12876 L
s
.23077 .15451 m
.23452 .15451 L
s
.23077 .18026 m
.23452 .18026 L
s
.23077 .23176 m
.23452 .23176 L
s
.23077 .25751 m
.23452 .25751 L
s
.23077 .28327 m
.23452 .28327 L
s
.23077 .33477 m
.23452 .33477 L
s
.23077 .36052 m
.23452 .36052 L
s
.23077 .38627 m
.23452 .38627 L
s
.23077 .43777 m
.23452 .43777 L
s
.23077 .46353 m
.23452 .46353 L
s
.23077 .48928 m
.23452 .48928 L
s
.23077 .54078 m
.23452 .54078 L
s
.23077 .56653 m
.23452 .56653 L
s
.23077 .59228 m
.23452 .59228 L
s
.25 Mabswid
.23077 0 m
.23077 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
123.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(4) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.2312 .10301 m
.23221 .10301 L
.23326 .10301 L
.23424 .10301 L
.236 .10301 L
.23789 .10301 L
.23894 .10301 L
.2401 .10301 L
.24119 .10301 L
.2422 .10301 L
.2441 .10301 L
.24517 .10301 L
.24614 .10301 L
.24708 .10301 L
.24807 .10301 L
.24985 .10301 L
.25176 .10301 L
.25284 .10301 L
.25386 .10301 L
.25569 .10301 L
.25736 .10301 L
.25829 .10301 L
.25929 .10301 L
.26112 .10301 L
.26286 .10301 L
.26448 .10301 L
.26627 .10301 L
.26727 .10301 L
.26819 .10301 L
.26994 .10301 L
.27185 .10301 L
.27281 .10301 L
.27384 .10301 L
.2757 .10301 L
.27744 .10301 L
.27933 .10301 L
.28112 .10301 L
.28276 .10301 L
.28425 .10301 L
.28588 .10301 L
.28758 .10301 L
.28918 .10301 L
.291 .10301 L
.29269 .10301 L
.29454 .10301 L
.29557 .10301 L
.29651 .10301 L
.29823 .10301 L
.30009 .10301 L
.30185 .10301 L
Mistroke
.30346 .10301 L
.30503 .10301 L
.30649 .10301 L
.30809 .10301 L
.30981 .10301 L
.31161 .10301 L
.31332 .10301 L
.31485 .10301 L
.31651 .10301 L
.31833 .10301 L
.32003 .10301 L
.3219 .10301 L
.32295 .10301 L
.32391 .10301 L
.32574 .10301 L
.32678 .10301 L
.32774 .10301 L
.32877 .10301 L
.32969 .10301 L
.33076 .10301 L
.33177 .10301 L
.33348 .10301 L
.3353 .10301 L
.33684 .10301 L
.33854 .10301 L
.34037 .10301 L
.34139 .10301 L
.34233 .10301 L
.34415 .10301 L
.34587 .10302 L
.34752 .10303 L
.3493 .10304 L
.35098 .10305 L
.35253 .10307 L
.35424 .10311 L
.35611 .10316 L
.35705 .1032 L
.35806 .10324 L
.35988 .10335 L
.36181 .1035 L
.36389 .10374 L
.36587 .10406 L
.36768 .10445 L
.36932 .10491 L
.37113 .10555 L
.37301 .10642 L
.37478 .10745 L
.37643 .10864 L
.37824 .11023 L
.38152 .11409 L
Mistroke
.38471 .11933 L
.38768 .12581 L
.3912 .13589 L
.39439 .14761 L
.40155 .18387 L
.41632 .2985 L
.42438 .36914 L
.42832 .40021 L
.43191 .42464 L
.43499 .44178 L
.43834 .45575 L
.44017 .46118 L
.44187 .46473 L
.4435 .46679 L
.44522 .46754 L
.44695 .46683 L
.4488 .46448 L
.45056 .46079 L
.45217 .45621 L
.4559 .44156 L
.45983 .42092 L
.47388 .32268 L
.4816 .26696 L
.48888 .22089 L
.49568 .18587 L
.50304 .15701 L
.50974 .13818 L
.5159 .12595 L
.5191 .12118 L
.52253 .11703 L
.5255 .11414 L
.52873 .1116 L
.53252 .10929 L
.5361 .10763 L
.5396 .10641 L
.54284 .10555 L
.54657 .10481 L
.55008 .1043 L
.55324 .10396 L
.55664 .10369 L
.56037 .10347 L
.56225 .10339 L
.5643 .10332 L
.56606 .10326 L
.56794 .10322 L
.57134 .10315 L
.57312 .10313 L
.57508 .1031 L
.577 .10308 L
.57905 .10307 L
Mistroke
.58097 .10306 L
.58273 .10305 L
.58618 .10303 L
.58823 .10303 L
.59013 .10302 L
.59239 .10302 L
.59444 .10302 L
.59627 .10301 L
.59824 .10301 L
.60033 .10301 L
.6023 .10301 L
.60583 .10301 L
.60784 .10301 L
.60971 .10301 L
.61165 .10301 L
.61349 .10301 L
.61561 .10301 L
.61754 .10301 L
.61924 .10301 L
.62103 .10301 L
.62426 .10301 L
.62605 .10301 L
.62774 .10301 L
.62958 .10301 L
.63157 .10301 L
.6334 .10301 L
.63506 .10301 L
.63697 .10301 L
.63878 .10301 L
.64034 .10301 L
.64199 .10301 L
.64381 .10301 L
.64548 .10301 L
.64728 .10301 L
.64922 .10301 L
.65105 .10301 L
.65273 .10301 L
.65468 .10301 L
.65681 .10301 L
.65883 .10301 L
.6607 .10301 L
.66263 .10301 L
.66471 .10301 L
.66668 .10301 L
.66849 .10301 L
.67013 .10301 L
.67192 .10301 L
.6738 .10301 L
.67555 .10301 L
.6776 .10301 L
Mistroke
.67955 .10301 L
.68129 .10301 L
.68319 .10301 L
.68525 .10301 L
.68744 .10301 L
.68931 .10301 L
.69137 .10301 L
.69314 .10301 L
.69479 .10301 L
.6966 .10301 L
.69853 .10301 L
.70057 .10301 L
.70248 .10301 L
.70421 .10301 L
.70607 .10301 L
.70769 .10301 L
.70948 .10301 L
.71134 .10301 L
.71308 .10301 L
.71471 .10301 L
.7162 .10301 L
.71791 .10301 L
.71954 .10301 L
.72127 .10301 L
.72319 .10301 L
.72519 .10301 L
.72708 .10301 L
.72883 .10301 L
.73044 .10301 L
.7322 .10301 L
.73406 .10301 L
.73595 .10301 L
.73701 .10301 L
.73797 .10301 L
.73984 .10301 L
.74161 .10301 L
.74261 .10301 L
.74367 .10301 L
.74557 .10301 L
.74663 .10301 L
.74762 .10301 L
.7488 .10301 L
.74987 .10301 L
.75169 .10301 L
.75261 .10301 L
.75362 .10301 L
.75541 .10301 L
.75709 .10301 L
.75909 .10301 L
.76009 .10301 L
Mistroke
.7612 .10301 L
.76214 .10301 L
.76315 .10301 L
.76497 .10301 L
.76682 .10301 L
.76786 .10301 L
.76883 .10301 L
.7706 .10301 L
.77248 .10301 L
.77415 .10301 L
.77573 .10301 L
.77746 .10301 L
.77932 .10301 L
.78101 .10301 L
.78259 .10301 L
.78432 .10301 L
.78617 .10301 L
.7871 .10301 L
.78811 .10301 L
.78994 .10301 L
.79173 .10301 L
.79337 .10301 L
.79491 .10301 L
.79635 .10301 L
.79793 .10301 L
.79963 .10301 L
.80141 .10301 L
.80309 .10301 L
.8046 .10301 L
.80625 .10301 L
.8072 .10301 L
.8082 .10301 L
.80998 .10301 L
.8119 .10301 L
.81299 .10301 L
.81401 .10301 L
.81585 .10301 L
.81753 .10301 L
.81846 .10301 L
.81947 .10301 L
.8213 .10301 L
.82293 .10301 L
.82473 .10301 L
.82662 .10301 L
.82838 .10301 L
.83002 .10301 L
.83153 .10301 L
.83327 .10301 L
.83492 .10301 L
.83684 .10301 L
Mistroke
.83858 .10301 L
.83954 .10301 L
.84059 .10301 L
.84248 .10301 L
.84426 .10301 L
.84614 .10301 L
.84774 .10301 L
.8495 .10301 L
.85057 .10301 L
.85158 .10301 L
.85348 .10301 L
.85454 .10301 L
.85552 .10301 L
.85666 .10301 L
.85774 .10301 L
.85951 .10301 L
.86045 .10301 L
.86147 .10301 L
.86248 .10301 L
.86354 .10301 L
.86543 .10301 L
.86722 .10301 L
.86823 .10301 L
.86917 .10301 L
.87088 .10301 L
.87269 .10301 L
.87431 .10301 L
.87583 .10301 L
.8775 .10301 L
.87929 .10301 L
.88119 .10301 L
.88226 .10301 L
.88326 .10301 L
.88509 .10301 L
.88611 .10301 L
.88703 .10301 L
.88878 .10301 L
.89068 .10301 L
.89246 .10301 L
.89411 .10301 L
.89565 .10301 L
.89731 .10301 L
.89887 .10301 L
.9003 .10301 L
.90197 .10301 L
.90379 .10301 L
.90551 .10301 L
.90709 .10301 L
.90872 .10301 L
.91025 .10301 L
Mistroke
.91193 .10301 L
.91374 .10301 L
.91554 .10301 L
.91743 .10301 L
.91904 .10301 L
.9208 .10301 L
.92272 .10301 L
.9245 .10301 L
.92542 .10301 L
.92644 .10301 L
.9275 .10301 L
.9285 .10301 L
.93033 .10301 L
.932 .10301 L
.93292 .10301 L
.93393 .10301 L
.93576 .10301 L
.93755 .10301 L
.93918 .10301 L
.94105 .10301 L
.94281 .10301 L
.94445 .10301 L
.94595 .10301 L
.9476 .10301 L
.94934 .10301 L
.95125 .10301 L
.95298 .10301 L
.95394 .10301 L
.95498 .10301 L
.95687 .10301 L
.95864 .10301 L
.96052 .10301 L
.96212 .10301 L
.96388 .10301 L
.96494 .10301 L
.96595 .10301 L
.96784 .10301 L
.9689 .10301 L
.96988 .10301 L
.97096 .10301 L
.97211 .10301 L
.97311 .10301 L
.97419 .10301 L
.97521 .10301 L
.97615 .10301 L
.97793 .10301 L
.97981 .10301 L
.98158 .10301 L
.98258 .10301 L
.98351 .10301 L
Mistroke
.98521 .10301 L
.98702 .10301 L
.98863 .10301 L
.99014 .10301 L
.9918 .10301 L
.99359 .10301 L
.99538 .10301 L
.99639 .10301 L
.99734 .10301 L
.99925 .10301 L
Mfstroke
.99925 .10301 m
1 .10301 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000oooooolLooooo`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0oooooolLooooo`00<?ooool6o`0000;o
oooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^0?oooooo7Oooool003So
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003ooooo
oa?ooooo000hooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05oooo
o`03o`000?oooooooooo0?oooooo4oooool003Sooooo00Go410@oooooooooooooooooa0@400?oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooo
oooo0?oooooo4oooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooo
oooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003ooooooooo
o`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000oooo
ooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`00
0?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool0
0ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o
0000ooooooooool0oooooolCooooo`008oooool5o`0002_ooooo00?o0000ooooooooool0:oooool5
o`0002kooooo0_l000000ol@413oooooooooo`0Zooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?oo
ool01Oo<c<co8B4Qo`000?lQ8B7oc<c<02Wooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`00
0?lb<S;ok^k^6_ooool002?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00[ooooo`03o`000?oooooo
oooo02_ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00_ooooo`03o`000?oooooooooo02_ooooo00Go
EEEEogMgMoooooooV9RHob4Q8@0/ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40:oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool001_ooooo1_l00003ooooo`03
oiRHV?lQ8B7ok^k^02cooooo00?o0000ooooooooool0;?ooool00onHV9So8B4Qonk^kP0]ooooo`Go
0000;?ooool01Ol0003ooooooooooooooooo000002cooooo00Go0000ooooooooooooooooo`00000[
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Jooooo`009Oooool0
0onHV9So8B4Qonk^kP0[ooooo`03o`000?oooooooooo02gooooo00?oV9RHob4Q8Oo^k^h0;?ooool0
1?m4A4CogMgMooooool0000]ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;?ooool01Olb<S;oV9RH
oooooonHV9So<S8b02_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
01[ooooo000Vooooo`03ogMgMomVIVKooooo02[ooooo0_l0000_ooooo`03ogMgMomVIVKooooo02_o
oooo00CogMgMoeEEEOoooooo0000;Oooool01Ol0003oEEEEo`000?l@413oc<c<02cooooo00Goc<c<
o`000?l0003o0000olc<c00[ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Jooooo`009oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool0:oooool00omgMgOoc<c<o`00000]ooooo`03oeEEEOn7QhOooooo02kooooo00Go
410@okZj^_oooooo^[Zjoa0@400[ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@400Jooooo`008oooool01Ol0003o^[ZjoooooonHV9So410@02_ooooo00?o0000oooooooo
ool0:oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo00?ok^k^odA4A?l00000;Oooool00ooM
gMgo410@oiRHV00^ooooo`05o`000?nj^[[ooooookZj^_l00000:oooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool002?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00[ooooo`03o`000?oooooooooo02_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00^ooooo`03ogMg
Mol0003ooooo02gooooo00Coc<c<odA4A?l0003o410@;?ooool01OnYZJWo410@o`000?l@413oZJVY
02Wooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo001Coooo
o`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00
Doooool00ol0003oooooooooo`3mooooo`;o00000_ooool2o`0000oooooo001Cooooo`03o`000?oo
oooooooo0?gooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd?ooooo`00Doooool00ol0003ooooo
ooooo`3nooooo`04omgMgOl0003o410@olc<c13ooooo000:oooooooo0000@?l0000;ooooo`04onk^
k_lQ8B7o410@onk^kQ3ooooo000Fooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`05ooooo`;o00000_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`;o0000
2oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool01?lQ8B7oMgMgogMgMolb<S8@ooooo`008_ooool00ol0003oooooooooo`0^ooooo`03o`00
0?oooooooooo02cooooo00?o0000ooooool00000;Oooool2o`000003ooooool0003ooooo02oooooo
00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00Sooooo
0_l00002ooooo`;o00003oooool005?ooooo00?o0000ooooooooool0;Oooool00ol0003ooooooooo
o`0[ooooo`03o`000?oooooooooo0;Cooooo001Cooooo`03o`000?oooooooooo02gooooo00?o0000
ooooooooool0:_ooool00ol0003oooooooooo`2eooooo`00Doooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0]_ooool005?ooooo00?o0000oooooooo
ool0;_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo0;Kooooo001Cooooo`03o`00
0?oooooooooo02oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`2gooooo`00Dooo
ool2o`00033ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`2gooooo`00Doooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0^?ooool0
05?ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
0;Sooooo001Cooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`2iooooo`00Doooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo02?ooooo
00?o0000ooooooooool0^Oooool005?ooooo00?o0000ooooooooool0<Oooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo0;[ooooo001Cooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`2jooooo`00Doooool00ol0003oooooooooo`0aoooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool0^_ooool005?ooooo0_l0000booooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0^oooool005?ooooo00?o0000ooooooooool0
<Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo0;_ooooo001Cooooo`03o`000?oo
oooooooo03;ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`2kooooo`00Doooool0
0ol0003oooooooooo`0booooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0_?ooool0
05?ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
0;cooooo001Cooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`2looooo`00Doooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool0_Oooool005?ooooo00?o0000ooooooooool0<oooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo0;gooooo001Cooooo`;o0000=?ooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo0;gooooo001Cooooo`03o`000?oooooooooo03?ooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`2nooooo`00Doooool00ol0003oooooooooo`0cooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool0__ooool005?ooooo00?o0000ooooooooool0
<oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo0;kooooo001Cooooo`03o`000?oo
oooooooo03?ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`2nooooo`00Doooool0
0ol0003oooooooooo`0cooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0__ooool0
03Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000
ooooooooool0=?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo0;oooooo000hoooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4
A006ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`2oooooo`00>?ooool01Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01ooo
ool3o`0003Cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`2oooooo`00>?ooool0
1Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0_oooool003Sooooo00Go0000
ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0=?oo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo0;oooooo000hooooo`05oa0@4?oooooo
ooooooooool@41003oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03Cooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`30ooooo`00>?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo03Cooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`30ooooo`00>?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo03Go
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`30ooooo`00Doooool00ol0003ooooo
ooooo`0eooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0`?ooool005?ooooo00?o
0000ooooooooool0=Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo0<3ooooo001C
ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`30
ooooo`00Doooool2o`0003Kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`30oooo
o`00Doooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool0`Oooool005?ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo0<7ooooo001Cooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`31ooooo`00Doooool00ol0003oooooooooo`0fooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool0`Oooool005?ooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo0<7ooooo001Cooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`31ooooo`00Doooool00ol0003ooooo
ooooo`0fooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0`Oooool005?ooooo0_l0
000gooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0`_ooool005?ooooo00?o0000
ooooooooool0=_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo0<;ooooo001Coooo
o`03o`000?oooooooooo03Kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`32oooo
o`00Doooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool0`_ooool005?ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo0<;ooooo001Cooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`32ooooo`00Doooool00ol0003oooooooooo`0gooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool0`_ooool005?ooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo0<?ooooo001Cooooo`;o0000>?ooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo0<?ooooo001Cooooo`03o`000?oooooooooo03Oooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`33ooooo`00Doooool00ol0003ooooooooo
o`0hooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0`oooool005?ooooo00?o0000
ooooooooool0>?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo0<?ooooo001Coooo
o`03o`000?oooooooooo03Sooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`34oooo
o`00Doooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool0a?ooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003
oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo0<Cooooo000hooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool0a?ooool003Sooooo00Go410@oooooooooooooooooa0@400;ooooo`Go
00001_ooool3o`0003Sooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`34ooooo`00
>?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00001oooool00ol0
003oooooooooo`0hooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0a?ooool003So
oooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000
ooooooooool0>Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo0<Gooooo000hoooo
o`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooo
oooo03Wooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`35ooooo`00>?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`0i
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0aOooool003Sooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0>Oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo0<Gooooo001Cooooo`03o`000?oooooooooo
03Wooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`35ooooo`00Doooool00ol0003o
ooooooooo`0iooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0aOooool005?ooooo
0_l0000jooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0aOooool005?ooooo00?o
0000ooooooooool0>_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo0<Kooooo001C
ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`36
ooooo`00Doooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool0a_ooool005?ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo0<Kooooo001Cooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`36ooooo`00Doooool00ol0003oooooooooo`0jooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool0a_ooool005?ooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo0<Kooooo001Cooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`36ooooo`00Doooool2o`0003co
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`37ooooo`00Doooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0aoooool005?ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo0<Oooooo001C
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`37
ooooo`00Doooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool0aoooool005?ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo0<Oooooo001Cooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`37ooooo`00Doooool00ol0003oooooooooo`0kooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool0aoooool005?ooooo0_l0000mooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0b?ooool005?ooooo00?o0000ooooooooool0??ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo0<Sooooo001Cooooo`03o`000?oooooooooo03co
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`38ooooo`00Doooool00ol0003ooooo
ooooo`0looooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0b?ooool005?ooooo00?o
0000ooooooooool0??ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo0<Sooooo000h
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@
olc<c006ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`38ooooo`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEE
EOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool0b?ooool003Sooooo00Go410@oooooooooooooooooa0@400;ooooo`05
o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0b?ooool003Sooooo00Go0000ooooooooooooooooo`00000;oooo
o`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`0003cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`39ooooo`00>?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000
oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`39ooooo`00>?ooool01Ol@413ooooooooooooooooo410@00_ooooo00?o
EEEEohN7Qoooool02?ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0bOooool003Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@
413oV9RH00Sooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0<Wooooo000hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`00
0?l@4106ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`39ooooo`00Doooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0bOooool005?ooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo0<Wooooo001Cooooo`03o`000?oooooooooo03kooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`3:ooooo`00Doooool2o`0003oooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`3:ooooo`00Doooool00ol0003oooooooooo`0nooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0b_ooool005?ooooo00?o0000ooooooooool0?_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0<[ooooo001Cooooo`03o`000?oooooo
oooo03kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3:ooooo`00Doooool00ol0
003oooooooooo`0oooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0boooool005?o
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0<_o
oooo001Cooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`3;ooooo`00Doooool00ol0003oooooooooo`0oooooo`05o`000?ooooooooooooooool00000
c_ooool005?ooooo0_l00011ooooo`04o`000?ooooooooooo`000<kooooo001Cooooo`03o`000?oo
oooooooo043ooooo0ol0003?ooooo`00Doooool00ol0003oooooooooo`11ooooo`03o`000?oooooo
oooo0<kooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000oooooooo
ool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oo
oooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0
003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003ooooo
ooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000
ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo000hooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006
ooooo`03o`000?oooooooooo0?oooooo4oooool003Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0oooo
oolCooooo`00>?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo0?oooooo4oooool003Sooooo00Go0000oooooooooooooooo
o`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3o`000?oooooo4oooool003Sooooo
00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0
003oooooooooo`3ooooooa?ooooo000hooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@
413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oo
oooooooo0?oooooo4oooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@
413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oo
oooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0
003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003ooooo
ooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000
ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03
o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Dooo
ool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0
003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo
00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001C
ooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCoooo
o`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Dooo
ool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool0
05?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?o
oooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool004Wooooo1?l000000ol@413ooooooooo
o`03ooooo`03o`000?oooooooooo0?oooooo4oooool004_ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`3ooooooa?ooooo001;ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0oooooolCooooo`00Boooool00ol0003oooooooooo`05ooooo`?o0000oooooolCooooo`00
Boooool00ol0003oooooooooo`3ooooooa_ooooo001;ooooo`03o`000?oooooooooo0?oooooo6ooo
ool004_ooooo00?o0000ooooooooool0oooooolKooooo`00BOooool00omEEEGoIVIVo`00003ooooo
oagooooo001looooo`?o000000?o410@ooooooooool0i_ooool007kooooo00?o410@okZj^_ooool0
1_ooool2o`0000_ooooo00?o0000okZj^_ooool03?ooool2o`0000Kooooo00?o0000okZj^_ooool0
^_ooool007kooooo00?oV9RHoc8b<_ooool01_ooool00ol0003oooooooooo`0:ooooo`;o<S8b3_oo
ool00ol0003oooooooooo`04ooooo`;o<S8b^oooool007kooooo00?ogMgMo`000?nj^[X01_ooool0
0ol0003oooooooooo`02ooooo`;o00000_ooool2o`0000;ooooo00?oQhN7o`000?nj^[X01Oooool0
1OnHV9So0000o`000?m4A4Co^[Zj00?ooooo00?o0000ooooooooool01?ooool00on7QhOo0000okZj
^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X04_ooool2o`000003oa0@4?oooooooooo09;ooooo
001nooooo`03oeEEEOmgMgOoA4A400Kooooo00?o0000ooooooooool00_ooool01_o^k^ko8B4QohN7
Qonj^[[o0000omgMg@;ooooo00?oc<c<o`000?l@41001Oooool01Ol@413o^[Zjonk^k_mgMgOo410@
00?ooooo00?o0000ooooooooool01?ooool00oo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^
ogMgMol@41002Oooool6o`0000Cooooo00?o0000ooooooooool0Toooool007gooooo00GogMgMoa0@
4?oooooo8B4QomgMg@05ooooo`03o`000?oooooooooo00?ooooo00CogMgMo`000?l@413oc<c<2ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_oo
ool5o`0009Cooooo001mooooo`05ofIVI_n7QhOooooooiRHV?mEEED01Oooool00ol0003ooooooooo
o`03ooooo`04onk^k_lQ8B7o410@onk^kP_ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo00_ooooo1_l000001OooooooA4A4omgMgOoooooo000009Go
oooo001looooo`03onk^k_l0003ok^k^00;ooooo00?o0000omgMgOooool00oooool00ol0003ooooo
ooooo`03ooooo`04ob4Q8OmgMgOoMgMgoc8b<P_ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00CogMgMoeEEEOoooooo0000UOooool007co
oooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`02ooooo`03o`000?oooooooooo
00;ooooo0_l00002ooooo`;o00002?ooool00ol@413o0000o`000003o`0000Cooooo00?o0000oooo
ooooool04Oooool00ol@413o0000o`000003o`0001;ooooo00?oMgMgolc<c?l00000UOooool008Oo
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool04oooool00oo^k^koA4A4o`00002Eooooo`00Qoooool2o`0001?ooooo
00?o0000ooooooooool01?ooool2o`0001Gooooo00?o0000ooooooooool05?ooool00omgMgOo0000
ooooo`2Dooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-3.4116, -0.234311, \
0.0510397, 0.00762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.230769 0.0769231 0.103006 0.515028 [
[.07692 .09051 -6 -9 ]
[.07692 .09051 6 0 ]
[.38462 .09051 -3 -9 ]
[.38462 .09051 3 0 ]
[.53846 .09051 -3 -9 ]
[.53846 .09051 3 0 ]
[.69231 .09051 -3 -9 ]
[.69231 .09051 3 0 ]
[.84615 .09051 -3 -9 ]
[.84615 .09051 3 0 ]
[1 .09051 -6 -9 ]
[1 .09051 6 0 ]
[1.025 .10301 0 -6 ]
[1.025 .10301 10 6 ]
[.21827 0 -24 -4.5 ]
[.21827 0 0 4.5 ]
[.21827 .20601 -18 -4.5 ]
[.21827 .20601 0 4.5 ]
[.21827 .30902 -18 -4.5 ]
[.21827 .30902 0 4.5 ]
[.21827 .41202 -18 -4.5 ]
[.21827 .41202 0 4.5 ]
[.21827 .51503 -18 -4.5 ]
[.21827 .51503 0 4.5 ]
[.21827 .61803 -6 -4.5 ]
[.21827 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07692 .10301 m
.07692 .10926 L
s
[(-2)] .07692 .09051 0 1 Mshowa
.38462 .10301 m
.38462 .10926 L
s
[(2)] .38462 .09051 0 1 Mshowa
.53846 .10301 m
.53846 .10926 L
s
[(4)] .53846 .09051 0 1 Mshowa
.69231 .10301 m
.69231 .10926 L
s
[(6)] .69231 .09051 0 1 Mshowa
.84615 .10301 m
.84615 .10926 L
s
[(8)] .84615 .09051 0 1 Mshowa
1 .10301 m
1 .10926 L
s
[(10)] 1 .09051 0 1 Mshowa
.125 Mabswid
.11538 .10301 m
.11538 .10676 L
s
.15385 .10301 m
.15385 .10676 L
s
.19231 .10301 m
.19231 .10676 L
s
.26923 .10301 m
.26923 .10676 L
s
.30769 .10301 m
.30769 .10676 L
s
.34615 .10301 m
.34615 .10676 L
s
.42308 .10301 m
.42308 .10676 L
s
.46154 .10301 m
.46154 .10676 L
s
.5 .10301 m
.5 .10676 L
s
.57692 .10301 m
.57692 .10676 L
s
.61538 .10301 m
.61538 .10676 L
s
.65385 .10301 m
.65385 .10676 L
s
.73077 .10301 m
.73077 .10676 L
s
.76923 .10301 m
.76923 .10676 L
s
.80769 .10301 m
.80769 .10676 L
s
.88462 .10301 m
.88462 .10676 L
s
.92308 .10301 m
.92308 .10676 L
s
.96154 .10301 m
.96154 .10676 L
s
.03846 .10301 m
.03846 .10676 L
s
.25 Mabswid
0 .10301 m
1 .10301 L
s
gsave
1.025 .10301 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.23077 0 m
.23702 0 L
s
[(-0.2)] .21827 0 1 0 Mshowa
.23077 .20601 m
.23702 .20601 L
s
[(0.2)] .21827 .20601 1 0 Mshowa
.23077 .30902 m
.23702 .30902 L
s
[(0.4)] .21827 .30902 1 0 Mshowa
.23077 .41202 m
.23702 .41202 L
s
[(0.6)] .21827 .41202 1 0 Mshowa
.23077 .51503 m
.23702 .51503 L
s
[(0.8)] .21827 .51503 1 0 Mshowa
.23077 .61803 m
.23702 .61803 L
s
[(1)] .21827 .61803 1 0 Mshowa
.125 Mabswid
.23077 .02575 m
.23452 .02575 L
s
.23077 .0515 m
.23452 .0515 L
s
.23077 .07725 m
.23452 .07725 L
s
.23077 .12876 m
.23452 .12876 L
s
.23077 .15451 m
.23452 .15451 L
s
.23077 .18026 m
.23452 .18026 L
s
.23077 .23176 m
.23452 .23176 L
s
.23077 .25751 m
.23452 .25751 L
s
.23077 .28327 m
.23452 .28327 L
s
.23077 .33477 m
.23452 .33477 L
s
.23077 .36052 m
.23452 .36052 L
s
.23077 .38627 m
.23452 .38627 L
s
.23077 .43777 m
.23452 .43777 L
s
.23077 .46353 m
.23452 .46353 L
s
.23077 .48928 m
.23452 .48928 L
s
.23077 .54078 m
.23452 .54078 L
s
.23077 .56653 m
.23452 .56653 L
s
.23077 .59228 m
.23452 .59228 L
s
.25 Mabswid
.23077 0 m
.23077 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
123.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(5) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.2995 .10301 m
.2997 .10301 L
.30147 .10301 L
.30315 .10301 L
.30497 .10301 L
.30599 .10301 L
.30691 .10301 L
.30871 .10301 L
.31041 .10301 L
.31137 .10301 L
.31239 .10301 L
.31421 .10301 L
.31522 .10301 L
.31617 .10301 L
.31721 .10301 L
.31832 .10301 L
.32016 .10301 L
.32187 .10301 L
.32374 .10301 L
.32468 .10301 L
.32572 .10301 L
.32746 .10301 L
.32934 .10301 L
.33111 .10301 L
.33273 .10301 L
.33432 .10301 L
.33579 .10301 L
.33741 .10301 L
.33913 .10301 L
.34095 .10301 L
.34266 .10301 L
.3442 .10301 L
.34587 .10301 L
.34768 .10301 L
.34869 .10301 L
.34962 .10301 L
.35141 .10301 L
.35312 .10301 L
.35408 .10301 L
.3551 .10301 L
.35694 .10301 L
.35806 .10301 L
.35912 .10301 L
.36007 .10301 L
.3611 .10301 L
.36211 .10301 L
.36305 .10301 L
.36408 .10301 L
.36519 .10301 L
.36635 .10301 L
Mistroke
.36744 .10301 L
.36843 .10301 L
.3695 .10301 L
.37043 .10301 L
.37145 .10301 L
.37251 .10301 L
.37351 .10301 L
.3753 .10301 L
.37722 .10301 L
.37904 .10301 L
.38074 .10301 L
.38259 .10301 L
.38363 .10301 L
.38458 .10301 L
.38649 .10301 L
.38756 .10301 L
.38856 .10301 L
.39038 .10301 L
.3913 .10301 L
.39231 .10301 L
.39411 .10302 L
.39576 .10302 L
.39765 .10304 L
.39945 .10306 L
.40111 .10308 L
.40265 .10312 L
.40433 .10318 L
.40613 .10328 L
.40777 .10341 L
.40958 .10361 L
.41146 .10391 L
.41322 .1043 L
.41486 .10479 L
.41636 .10536 L
.41809 .10622 L
.41973 .10727 L
.4215 .10872 L
.42339 .11069 L
.42676 .1156 L
.42864 .11927 L
.4304 .12343 L
.4344 .13591 L
.43783 .15045 L
.44108 .16789 L
.4472 .21033 L
.46096 .33562 L
.46442 .36648 L
.46815 .39604 L
.47144 .41742 L
.47324 .42685 L
Mistroke
.47491 .43409 L
.47685 .44047 L
.47788 .44296 L
.47898 .44494 L
.47998 .44612 L
.48093 .44668 L
.48271 .44632 L
.48447 .44418 L
.4861 .44068 L
.48788 .43525 L
.48978 .42778 L
.49294 .41192 L
.49634 .39086 L
.50249 .34599 L
.51652 .24021 L
.52325 .1989 L
.53045 .16493 L
.53458 .15 L
.53834 .13905 L
.5419 .13068 L
.54568 .12366 L
.54962 .11801 L
.55325 .11404 L
.55716 .11084 L
.56146 .1083 L
.56517 .10674 L
.56722 .10607 L
.56916 .10554 L
.57292 .10474 L
.57636 .10422 L
.57818 .10401 L
.58014 .10382 L
.58187 .10368 L
.5837 .10356 L
.58535 .10347 L
.58717 .10338 L
.59035 .10327 L
.5923 .10322 L
.59407 .10318 L
.59598 .10314 L
.59805 .10311 L
.59997 .10309 L
.60174 .10307 L
.60342 .10306 L
.60523 .10305 L
.6069 .10304 L
.60842 .10304 L
.61141 .10303 L
.61308 .10302 L
.6149 .10302 L
Mistroke
.61822 .10301 L
.62003 .10301 L
.62167 .10301 L
.62344 .10301 L
.62536 .10301 L
.62714 .10301 L
.62877 .10301 L
.63199 .10301 L
.63382 .10301 L
.63556 .10301 L
.63714 .10301 L
.63882 .10301 L
.64064 .10301 L
.64232 .10301 L
.64413 .10301 L
.64613 .10301 L
.64784 .10301 L
.64941 .10301 L
.65113 .10301 L
.65295 .10301 L
.65453 .10301 L
.656 .10301 L
.65774 .10301 L
.65934 .10301 L
.66122 .10301 L
.66326 .10301 L
.66505 .10301 L
.66695 .10301 L
.66865 .10301 L
.67024 .10301 L
.67199 .10301 L
.67386 .10301 L
.67585 .10301 L
.67802 .10301 L
.68007 .10301 L
.68197 .10301 L
.68385 .10301 L
.68556 .10301 L
.68753 .10301 L
.68938 .10301 L
.69108 .10301 L
.69289 .10301 L
.6946 .10301 L
.69616 .10301 L
.698 .10301 L
.69999 .10301 L
.70187 .10301 L
.7036 .10301 L
.70539 .10301 L
.70707 .10301 L
Mistroke
.70891 .10301 L
.71089 .10301 L
.71285 .10301 L
.71384 .10301 L
.71492 .10301 L
.71684 .10301 L
.71862 .10301 L
.7203 .10301 L
.72212 .10301 L
.72384 .10301 L
.72543 .10301 L
.72686 .10301 L
.72843 .10301 L
.73008 .10301 L
.73161 .10301 L
.73341 .10301 L
.73511 .10301 L
.73664 .10301 L
.7383 .10301 L
.74011 .10301 L
.74203 .10301 L
.74367 .10301 L
.74549 .10301 L
.74725 .10301 L
.74889 .10301 L
.75069 .10301 L
.7517 .10301 L
.75261 .10301 L
.75447 .10301 L
.75551 .10301 L
.75648 .10301 L
.75825 .10301 L
.76013 .10301 L
.76172 .10301 L
.76343 .10301 L
.76504 .10301 L
.76652 .10301 L
.76825 .10301 L
.77013 .10301 L
.77191 .10301 L
.77357 .10301 L
.77547 .10301 L
.77654 .10301 L
.77753 .10301 L
.77934 .10301 L
.78126 .10301 L
.78298 .10301 L
.78458 .10301 L
.78635 .10301 L
.78823 .10301 L
Mistroke
.78928 .10301 L
.79025 .10301 L
.79129 .10301 L
.79244 .10301 L
.79436 .10301 L
.79542 .10301 L
.79641 .10301 L
.79829 .10301 L
.8 .10301 L
.80189 .10301 L
.80283 .10301 L
.80387 .10301 L
.80579 .10301 L
.80756 .10301 L
.80848 .10301 L
.8095 .10301 L
.81058 .10301 L
.81156 .10301 L
.81336 .10301 L
.81436 .10301 L
.81531 .10301 L
.81698 .10301 L
.81881 .10301 L
.8206 .10301 L
.82223 .10301 L
.8241 .10301 L
.82586 .10301 L
.82749 .10301 L
.829 .10301 L
.83065 .10301 L
.83239 .10301 L
.83429 .10301 L
.83602 .10301 L
.83698 .10301 L
.83802 .10301 L
.83991 .10301 L
.84168 .10301 L
.84355 .10301 L
.84516 .10301 L
.84692 .10301 L
.84798 .10301 L
.84899 .10301 L
.85088 .10301 L
.85194 .10301 L
.85292 .10301 L
.85399 .10301 L
.85514 .10301 L
.85614 .10301 L
.85722 .10301 L
.85818 .10301 L
Mistroke
.85918 .10301 L
.86109 .10301 L
.86285 .10301 L
.86462 .10301 L
.86562 .10301 L
.86654 .10301 L
.86824 .10301 L
.87005 .10301 L
.87165 .10301 L
.87317 .10301 L
.87482 .10301 L
.87661 .10301 L
.8784 .10301 L
.87942 .10301 L
.88036 .10301 L
.88227 .10301 L
.88334 .10301 L
.88431 .10301 L
.88605 .10301 L
.88794 .10301 L
.88973 .10301 L
.89137 .10301 L
.89291 .10301 L
.89455 .10301 L
.89611 .10301 L
.89753 .10301 L
.8992 .10301 L
.90101 .10301 L
.90272 .10301 L
.90431 .10301 L
.90611 .10301 L
.90779 .10301 L
.90931 .10301 L
.91095 .10301 L
.91274 .10301 L
.91463 .10301 L
.91625 .10301 L
.91802 .10301 L
.91992 .10301 L
.92168 .10301 L
.92259 .10301 L
.9236 .10301 L
.92466 .10301 L
.92565 .10301 L
.92747 .10301 L
.92913 .10301 L
.93096 .10301 L
.93288 .10301 L
.9345 .10301 L
.93623 .10301 L
Mistroke
.93786 .10301 L
.93934 .10301 L
.94109 .10301 L
.94298 .10301 L
.94477 .10301 L
.94641 .10301 L
.94817 .10301 L
.95005 .10301 L
.95183 .10301 L
.95345 .10301 L
.95535 .10301 L
.95643 .10301 L
.95743 .10301 L
.95925 .10301 L
.96027 .10301 L
.96119 .10301 L
.96218 .10301 L
.96321 .10301 L
.96507 .10301 L
.9661 .10301 L
.96707 .10301 L
.96812 .10301 L
.96925 .10301 L
.97023 .10301 L
.97129 .10301 L
.97229 .10301 L
.97322 .10301 L
.97497 .10301 L
.97683 .10301 L
.97858 .10301 L
.98049 .10301 L
.9823 .10301 L
.98397 .10301 L
.98563 .10301 L
.98714 .10301 L
.98887 .10301 L
.99051 .10301 L
.9923 .10301 L
.99419 .10301 L
.99581 .10301 L
.99758 .10301 L
.99949 .10301 L
Mfstroke
.99949 .10301 m
1 .10301 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000oooooolLooooo`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0oooooolLooooo`00<?ooool6o`0000;o
oooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^0?oooooo7Oooool003So
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003ooooo
oa?ooooo000hooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05oooo
o`03o`000?oooooooooo0?oooooo4oooool003Sooooo00Go410@oooooooooooooooooa0@400?oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooo
oooo0?oooooo4oooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooo
oooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003ooooooooo
o`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000oooo
ooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`00
0?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool0
0ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o
0000ooooooooool0oooooolCooooo`008oooool5o`0002_ooooo00?o0000ooooooooool0:oooool5
o`0002kooooo0_l000000ol@413oooooooooo`0Zooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?oo
ool01Oo<c<co8B4Qo`000?lQ8B7oc<c<02Wooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`00
0?lb<S;ok^k^6_ooool002?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00[ooooo`03o`000?oooooo
oooo02_ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00_ooooo`03o`000?oooooooooo02_ooooo00Go
EEEEogMgMoooooooV9RHob4Q8@0/ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40:oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool001_ooooo1_l00003ooooo`03
oiRHV?lQ8B7ok^k^02cooooo00?o0000ooooooooool0;?ooool00onHV9So8B4Qonk^kP0]ooooo`Go
0000;?ooool01Ol0003ooooooooooooooooo000002cooooo00Go0000ooooooooooooooooo`00000[
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Jooooo`009Oooool0
0onHV9So8B4Qonk^kP0[ooooo`03o`000?oooooooooo02gooooo00?oV9RHob4Q8Oo^k^h0;?ooool0
1?m4A4CogMgMooooool0000]ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;?ooool01Olb<S;oV9RH
oooooonHV9So<S8b02_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
01[ooooo000Vooooo`03ogMgMomVIVKooooo02[ooooo0_l0000_ooooo`03ogMgMomVIVKooooo02_o
oooo00CogMgMoeEEEOoooooo0000;Oooool01Ol0003oEEEEo`000?l@413oc<c<02cooooo00Goc<c<
o`000?l0003o0000olc<c00[ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Jooooo`009oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool0:oooool00omgMgOoc<c<o`00000]ooooo`03oeEEEOn7QhOooooo02kooooo00Go
410@okZj^_oooooo^[Zjoa0@400[ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@400Jooooo`008oooool01Ol0003o^[ZjoooooonHV9So410@02_ooooo00?o0000oooooooo
ool0:oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo00?ok^k^odA4A?l00000;Oooool00ooM
gMgo410@oiRHV00^ooooo`05o`000?nj^[[ooooookZj^_l00000:oooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool002?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00[ooooo`03o`000?oooooooooo02_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00^ooooo`03ogMg
Mol0003ooooo02gooooo00Coc<c<odA4A?l0003o410@;?ooool01OnYZJWo410@o`000?l@413oZJVY
02Wooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo001Coooo
o`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00
Doooool00ol0003oooooooooo`3mooooo`;o00000_ooool2o`0000oooooo001Cooooo`03o`000?oo
oooooooo0?gooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd?ooooo`00Doooool00ol0003ooooo
ooooo`3nooooo`04omgMgOl0003o410@olc<c13ooooo000:oooooooo0000@?l0000;ooooo`04onk^
k_lQ8B7o410@onk^kQ3ooooo000Fooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo0_l0000<ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`04ooooo`?o0000
0_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool01?lQ8B7oMgMgogMgMolb<S8@ooooo`008_ooool00ol0003oooooooooo`0^ooooo`03o`00
0?oooooooooo02kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Rooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0^ooooo`03o`00
0?oooooooooo02kooooo00?o0000ooooooooool02?ooool2o`0000;ooooo0_l0000?ooooo`00Dooo
ool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0Zooo
ool005?ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo0:cooooo001Cooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool08oooool00ol0
003oooooooooo`2]ooooo`00Doooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool0[_ooool005?ooooo00?o0000ooooooooool0?Oooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo0:kooooo001Cooooo`;o0000?_ooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo0:oooooo001Cooooo`03o`000?oooooooooo03kooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`2_ooooo`00Doooool00ol0003oooooooooo`0noooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool0/?ooool005?ooooo00?o0000oooooooo
ool0?_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo0;3ooooo001Cooooo`03o`00
0?oooooooooo03kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`2`ooooo`00Dooo
ool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0/?oo
ool005?ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo0;7ooooo001Cooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`2aooooo`00Doooool2o`00043ooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`2aooooo`00Doooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool0/_ooool005?ooooo00?o0000ooooooooool0@?ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo0;;ooooo001Cooooo`03o`000?oooooooooo043ooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`2cooooo`00Doooool00ol0003oooooooooo`10oooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0/oooool005?ooooo00?o0000oooooooo
ool0@?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo0;?ooooo001Cooooo`03o`00
0?oooooooooo043ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`2cooooo`00Dooo
ool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0]?oo
ool005?ooooo0_l00012ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0]?ooool0
05?ooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
0;Cooooo001Cooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`2dooooo`00Doooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool0]?ooool005?ooooo00?o0000ooooooooool0@Oooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo0;Gooooo001Cooooo`03o`000?oooooooooo047ooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`2eooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`11ooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool0]Oooool003Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0@_oo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo0;Gooooo000hooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00onHV9So8B4Qonk^kP07ooooo`?o0000@_ooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo0;Gooooo000hooooo`05o`000?ooooooooooooooool000003Ooo
ool00onHV9So8B4Qonk^kP06ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`2eooooo`00>?ooool01Ol0003ooooooooooooooooo000000kooooo00?o
MgMgofIVI_ooool01Oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0]_ooool003Sooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo0;Kooooo000hooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooo
oonHV9So410@00Kooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo0;Kooooo000hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@
o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo0;Kooooo001Cooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`2fooooo`00Doooool00ol0003oooooooooo`12ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool0]_ooool005?ooooo00?o0000ooooooooool0@oooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo0;Kooooo001Cooooo`;o0000A?ooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo0;Oooooo001Cooooo`03o`000?oooooooooo04?o
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`2gooooo`00Doooool00ol0003ooooo
ooooo`13ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0]oooool005?ooooo00?o
0000ooooooooool0@oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo0;Oooooo001C
ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`2g
ooooo`00Doooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool0]oooool005?ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo0;Oooooo001Cooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`2hooooo`00Doooool2o`0004Cooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`2hooooo`00Doooool00ol0003oooooooooo`14ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool0^?ooool005?ooooo00?o0000ooooooooool0A?ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo0;Sooooo001Cooooo`03o`000?oooooooooo04Co
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`2hooooo`00Doooool00ol0003ooooo
ooooo`14ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0^?ooool005?ooooo00?o
0000ooooooooool0A?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo0;Sooooo001C
ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`2h
ooooo`00Doooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool0^?ooool005?ooooo0_l00015ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0^Oooool005?ooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo0;Wooooo001Cooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`2iooooo`00Doooool00ol0003oooooooooo`15ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool0^Oooool005?ooooo00?o0000ooooooooool0AOooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo0;Wooooo001Cooooo`03o`000?oooooooooo04Go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`2iooooo`00>?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003o
ooooooooo`15ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0^Oooool003Sooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo04Gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`2iooooo`00
>?ooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00006ooooo`?o0000AOooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo0;[ooooo000hooooo`05o`000?ooooooooooooooool0
00002oooool01?m4A4CogMgMooooool00007ooooo`03o`000?oooooooooo04Gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`2jooooo`00>?ooool01Ol0003ooooooooooooooooo0000
00_ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`15ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool0^_ooool003Sooooo00Go410@oooooooooooooooooa0@400<
ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo0;[ooooo000hooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool0
0oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`2jooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMg
o`000?ooool01_ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool0^_ooool005?ooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo0;[ooooo001Cooooo`03o`000?oooooooooo04Kooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`2jooooo`00Doooool2o`0004Oooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`2jooooo`00Doooool00ol0003oooooooooo`16ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool0^oooool005?ooooo00?o0000ooooooooool0A_ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0;_ooooo001Cooooo`03o`000?oooooooooo
04Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`2kooooo`00Doooool00ol0003o
ooooooooo`16ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0^oooool005?ooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0;_ooooo
001Cooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`2kooooo`00Doooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool0^oooool005?ooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo0;cooooo001Cooooo`;o0000B?ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo0;cooooo001Cooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`2looooo`00Doooool00ol0003oooooooooo`17ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool0_?ooool005?ooooo00?o0000ooooooooool0Aoooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo0;cooooo001Cooooo`03o`000?oooooooooo
04Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2looooo`00Doooool00ol0003o
ooooooooo`18ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0_?ooool005?ooooo
00?o0000ooooooooool0B?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;gooooo
001Cooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`2mooooo`00Doooool2o`0004Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2m
ooooo`00Doooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0_Oooool005?ooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo0;gooooo001Cooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`2mooooo`00Doooool00ol0003oooooooooo`19ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0_Oooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0
BOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0;kooooo000hooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03
o`000?oooooooooo04Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2nooooo`00
>?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000006oooo
o`03o`000?oooooooooo04[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2noooo
o`00>?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@06
ooooo`?o0000B_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0;kooooo000hoooo
o`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o
0000ooooooooool0B_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0;kooooo000h
ooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oo
oooooooo04[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2nooooo`00>?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003ooooooooo
o`1:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0_oooool003Sooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0
B_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0;oooooo001Cooooo`03o`000?oo
oooooooo04[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2oooooo`00Doooool0
0ol0003oooooooooo`1:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0_oooool0
05?ooooo00?o0000ooooooooool0Boooool01Ol0003ooooooooooooooooo00000<;ooooo001Coooo
o`;o0000C?ooool01Ol0003ooooooooooooooooo00000<;ooooo001Cooooo`03o`000?oooooooooo
04_ooooo00Co0000oooooooooooo0000`oooool005?ooooo00?o0000ooooooooool0C?ooool00ol0
003oooooo`000033ooooo`00Doooool00ol0003oooooooooo`1<ooooo`;o0000a?ooool005?ooooo
00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001C
ooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCoooo
o`00Doooool2o`000?oooooo5?ooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Dooo
ool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool0
05?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?o
oooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooo
oolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDoooo
o`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo
4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3o
oooooa?ooooo000hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<
ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0?oooooo4oooool003Sooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo
00?o0000ooooooooool0oooooolCooooo`00>?ooool01Ol@413ooooooooooooooooo410@00_ooooo
00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo4oooool003Sooooo
00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3o`00
0?oooooo4oooool003Sooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000
o`000?o<c<`01_ooool00ol0003oooooooooo`3ooooooa?ooooo000hooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0oooo
oolCooooo`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zj
o`000006ooooo`03o`000?oooooooooo0?oooooo4oooool003Sooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3ooooooa?o
oooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooo
oolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDoooo
o`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo
4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3o
oooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000oooooooo
ool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooo
oolDooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo
0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003ooooo
ooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000
ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o
0000oooooolDooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oo
oooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0
003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool004Wooooo
1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo4oooool004_ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`3ooooooa?ooooo001;ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0oooooolCooooo`00Boooool00ol0003oooooooooo`05oooo
o`?o0000oooooolCooooo`00Boooool00ol0003oooooooooo`3ooooooa_ooooo001;ooooo`03o`00
0?oooooooooo0?oooooo6oooool004_ooooo00?o0000ooooooooool0oooooolKooooo`00BOooool0
0omEEEGoIVIVo`00003ooooooagooooo001looooo`?o000000?o410@ooooooooool0i_ooool007ko
oooo00?o410@okZj^_ooool01_ooool2o`0000_ooooo00?o0000okZj^_ooool03?ooool2o`0000Ko
oooo00?o0000okZj^_ooool0^_ooool007kooooo00?oV9RHoc8b<_ooool01_ooool00ol0003ooooo
ooooo`0:ooooo`;o<S8b3_ooool00ol0003oooooooooo`04ooooo`;o<S8b^oooool007kooooo00?o
gMgMo`000?nj^[X01_ooool00ol0003oooooooooo`02ooooo`;o00000_ooool2o`0000;ooooo00?o
QhN7o`000?nj^[X01Oooool01OnHV9So0000o`000?m4A4Co^[Zj00?ooooo00?o0000ooooooooool0
1?ooool00on7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X04Oooool01Om4A4Co
0000o`000?lb<S;ogMgM09?ooooo001nooooo`03oeEEEOmgMgOoA4A400Kooooo00?o0000oooooooo
ool00_ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@;ooooo00?oc<c<o`000?l@41001Oooool0
1Ol@413o^[Zjonk^k_mgMgOo410@00?ooooo00?o0000ooooooooool01?ooool00oo<c<co0000oa0@
400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000Gooooo00?oMgMgoc8b<_ooool0
T_ooool007gooooo00GogMgMoa0@4?oooooo8B4QomgMg@05ooooo`03o`000?oooooooooo00?ooooo
00CogMgMo`000?l@413oc<c<2oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`2Aooooo`00OOooool01OmVIVKoQhN7
oooooonHV9SoEEEE00Gooooo00?o0000ooooooooool00oooool01?o^k^ko8B4Qoa0@4?o^k^h;oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0;oooo
o`Ko00001Oooool00omgMgOo<S8booooo`2Booooo`00O?ooool00oo^k^ko0000onk^kP02ooooo`03
o`000?oMgMgooooo00?ooooo00?o0000ooooooooool00oooool01?lQ8B7oMgMgogMgMolb<S8;oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Coooo
o`05o`000?lQ8B7o0000oc8b<_o<c<`0Toooool007cooooo00Co410@o`000?l0003ooooo0_l00000
0ol@413oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`;o00002?ooool0
0ol@413o0000o`000003o`0000Cooooo00?o0000ooooooooool04Oooool00ol@413o0000o`000003
o`0001;ooooo00?o0000ooooooooool0UOooool008Oooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`2Eooooo`00Qoooool2o`0001?ooooo00?o0000ooooooooool01?ooool2o`0001Go
oooo00?o0000ooooooooool04oooool4o`0009Cooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-3.4116, -0.234311, \
0.0510397, 0.00762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.230769 0.0769231 0.103006 0.515028 [
[.07692 .09051 -6 -9 ]
[.07692 .09051 6 0 ]
[.38462 .09051 -3 -9 ]
[.38462 .09051 3 0 ]
[.53846 .09051 -3 -9 ]
[.53846 .09051 3 0 ]
[.69231 .09051 -3 -9 ]
[.69231 .09051 3 0 ]
[.84615 .09051 -3 -9 ]
[.84615 .09051 3 0 ]
[1 .09051 -6 -9 ]
[1 .09051 6 0 ]
[1.025 .10301 0 -6 ]
[1.025 .10301 10 6 ]
[.21827 0 -24 -4.5 ]
[.21827 0 0 4.5 ]
[.21827 .20601 -18 -4.5 ]
[.21827 .20601 0 4.5 ]
[.21827 .30902 -18 -4.5 ]
[.21827 .30902 0 4.5 ]
[.21827 .41202 -18 -4.5 ]
[.21827 .41202 0 4.5 ]
[.21827 .51503 -18 -4.5 ]
[.21827 .51503 0 4.5 ]
[.21827 .61803 -6 -4.5 ]
[.21827 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07692 .10301 m
.07692 .10926 L
s
[(-2)] .07692 .09051 0 1 Mshowa
.38462 .10301 m
.38462 .10926 L
s
[(2)] .38462 .09051 0 1 Mshowa
.53846 .10301 m
.53846 .10926 L
s
[(4)] .53846 .09051 0 1 Mshowa
.69231 .10301 m
.69231 .10926 L
s
[(6)] .69231 .09051 0 1 Mshowa
.84615 .10301 m
.84615 .10926 L
s
[(8)] .84615 .09051 0 1 Mshowa
1 .10301 m
1 .10926 L
s
[(10)] 1 .09051 0 1 Mshowa
.125 Mabswid
.11538 .10301 m
.11538 .10676 L
s
.15385 .10301 m
.15385 .10676 L
s
.19231 .10301 m
.19231 .10676 L
s
.26923 .10301 m
.26923 .10676 L
s
.30769 .10301 m
.30769 .10676 L
s
.34615 .10301 m
.34615 .10676 L
s
.42308 .10301 m
.42308 .10676 L
s
.46154 .10301 m
.46154 .10676 L
s
.5 .10301 m
.5 .10676 L
s
.57692 .10301 m
.57692 .10676 L
s
.61538 .10301 m
.61538 .10676 L
s
.65385 .10301 m
.65385 .10676 L
s
.73077 .10301 m
.73077 .10676 L
s
.76923 .10301 m
.76923 .10676 L
s
.80769 .10301 m
.80769 .10676 L
s
.88462 .10301 m
.88462 .10676 L
s
.92308 .10301 m
.92308 .10676 L
s
.96154 .10301 m
.96154 .10676 L
s
.03846 .10301 m
.03846 .10676 L
s
.25 Mabswid
0 .10301 m
1 .10301 L
s
gsave
1.025 .10301 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.23077 0 m
.23702 0 L
s
[(-0.2)] .21827 0 1 0 Mshowa
.23077 .20601 m
.23702 .20601 L
s
[(0.2)] .21827 .20601 1 0 Mshowa
.23077 .30902 m
.23702 .30902 L
s
[(0.4)] .21827 .30902 1 0 Mshowa
.23077 .41202 m
.23702 .41202 L
s
[(0.6)] .21827 .41202 1 0 Mshowa
.23077 .51503 m
.23702 .51503 L
s
[(0.8)] .21827 .51503 1 0 Mshowa
.23077 .61803 m
.23702 .61803 L
s
[(1)] .21827 .61803 1 0 Mshowa
.125 Mabswid
.23077 .02575 m
.23452 .02575 L
s
.23077 .0515 m
.23452 .0515 L
s
.23077 .07725 m
.23452 .07725 L
s
.23077 .12876 m
.23452 .12876 L
s
.23077 .15451 m
.23452 .15451 L
s
.23077 .18026 m
.23452 .18026 L
s
.23077 .23176 m
.23452 .23176 L
s
.23077 .25751 m
.23452 .25751 L
s
.23077 .28327 m
.23452 .28327 L
s
.23077 .33477 m
.23452 .33477 L
s
.23077 .36052 m
.23452 .36052 L
s
.23077 .38627 m
.23452 .38627 L
s
.23077 .43777 m
.23452 .43777 L
s
.23077 .46353 m
.23452 .46353 L
s
.23077 .48928 m
.23452 .48928 L
s
.23077 .54078 m
.23452 .54078 L
s
.23077 .56653 m
.23452 .56653 L
s
.23077 .59228 m
.23452 .59228 L
s
.25 Mabswid
.23077 0 m
.23077 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
123.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(6) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.35592 .10301 m
.35684 .10301 L
.35793 .10301 L
.35896 .10301 L
.35988 .10301 L
.36089 .10301 L
.36272 .10301 L
.36437 .10301 L
.36629 .10301 L
.36809 .10301 L
.36976 .10301 L
.37129 .10301 L
.37298 .10301 L
.37476 .10301 L
.37577 .10301 L
.37672 .10301 L
.3785 .10301 L
.38041 .10301 L
.38149 .10301 L
.3825 .10301 L
.38416 .10301 L
.386 .10301 L
.38791 .10301 L
.38971 .10301 L
.39067 .10301 L
.39172 .10301 L
.39282 .10301 L
.39383 .10301 L
.39566 .10301 L
.39668 .10301 L
.39761 .10301 L
.39871 .10301 L
.39971 .10301 L
.40082 .10301 L
.40199 .10301 L
.40301 .10301 L
.40396 .10301 L
.405 .10301 L
.40613 .10301 L
.408 .10301 L
.40904 .10301 L
.40999 .10301 L
.41183 .10301 L
.41357 .10301 L
.41456 .10301 L
.4156 .10301 L
.41747 .10301 L
.41851 .10301 L
.41948 .10301 L
.42055 .10301 L
Mistroke
.42169 .10301 L
.42359 .10301 L
.42467 .10301 L
.42566 .10301 L
.42748 .10301 L
.4284 .10301 L
.42942 .10301 L
.43117 .10301 L
.43305 .10301 L
.43483 .10301 L
.43646 .10302 L
.43808 .10302 L
.43981 .10304 L
.44144 .10306 L
.44292 .10309 L
.44466 .10315 L
.44655 .10325 L
.44833 .10339 L
.44997 .10359 L
.45167 .10389 L
.45326 .10428 L
.45501 .10487 L
.45688 .10576 L
.45884 .10706 L
.46069 .10874 L
.46236 .1107 L
.46418 .11343 L
.46756 .12055 L
.46946 .12598 L
.47121 .13199 L
.47443 .14599 L
.47782 .16519 L
.48502 .22102 L
.49289 .29818 L
.50053 .37031 L
.50273 .38738 L
.50481 .40119 L
.5067 .41154 L
.50773 .41624 L
.5087 .42 L
.51045 .42518 L
.51138 .42707 L
.51237 .42844 L
.51414 .42917 L
.51576 .42797 L
.51764 .42443 L
.5187 .42144 L
.51969 .41808 L
.52342 .40062 L
.53672 .30196 L
Mistroke
.54399 .2448 L
.55077 .19961 L
.55812 .16256 L
.56201 .14788 L
.56617 .1355 L
.56998 .12679 L
.57359 .12046 L
.57682 .11607 L
.58034 .11243 L
.58407 .10958 L
.58819 .10736 L
.59026 .10652 L
.59249 .10579 L
.59442 .10527 L
.59652 .10481 L
.60033 .10419 L
.6024 .10394 L
.60433 .10375 L
.60779 .1035 L
.60973 .1034 L
.61149 .10333 L
.61332 .10326 L
.61526 .10321 L
.61873 .10314 L
.62067 .10311 L
.62247 .10309 L
.62445 .10307 L
.62658 .10305 L
.62841 .10304 L
.6304 .10303 L
.63228 .10303 L
.63402 .10302 L
.63732 .10302 L
.63916 .10301 L
.64082 .10301 L
.64246 .10301 L
.64422 .10301 L
.64615 .10301 L
.64794 .10301 L
.64996 .10301 L
.65187 .10301 L
.65359 .10301 L
.65545 .10301 L
.65706 .10301 L
.65884 .10301 L
.66069 .10301 L
.66243 .10301 L
.66405 .10301 L
.66554 .10301 L
.66725 .10301 L
Mistroke
.66888 .10301 L
.67079 .10301 L
.67251 .10301 L
.67451 .10301 L
.67639 .10301 L
.67813 .10301 L
.67974 .10301 L
.6815 .10301 L
.68336 .10301 L
.68524 .10301 L
.68726 .10301 L
.68917 .10301 L
.6909 .10301 L
.69294 .10301 L
.69409 .10301 L
.69515 .10301 L
.6971 .10301 L
.69918 .10301 L
.70083 .10301 L
.70264 .10301 L
.70452 .10301 L
.70628 .10301 L
.70793 .10301 L
.70943 .10301 L
.71116 .10301 L
.71279 .10301 L
.71457 .10301 L
.71646 .10301 L
.71806 .10301 L
.71983 .10301 L
.72174 .10301 L
.7228 .10301 L
.72378 .10301 L
.72567 .10301 L
.72747 .10301 L
.72915 .10301 L
.73067 .10301 L
.73242 .10301 L
.73407 .10301 L
.7356 .10301 L
.73701 .10301 L
.73855 .10301 L
.74018 .10301 L
.74183 .10301 L
.7436 .10301 L
.74527 .10301 L
.74679 .10301 L
.74858 .10301 L
.74959 .10301 L
.75052 .10301 L
Mistroke
.75223 .10301 L
.75404 .10301 L
.7557 .10301 L
.75752 .10301 L
.75941 .10301 L
.76117 .10301 L
.76282 .10301 L
.76432 .10301 L
.76606 .10301 L
.76769 .10301 L
.76948 .10301 L
.77137 .10301 L
.77298 .10301 L
.77475 .10301 L
.77666 .10301 L
.77773 .10301 L
.7787 .10301 L
.7806 .10301 L
.78239 .10301 L
.78392 .10301 L
.7856 .10301 L
.78735 .10301 L
.789 .10301 L
.79054 .10301 L
.79195 .10301 L
.79349 .10301 L
.79512 .10301 L
.79678 .10301 L
.79855 .10301 L
.80022 .10301 L
.80174 .10301 L
.80353 .10301 L
.80453 .10301 L
.80546 .10301 L
.80717 .10301 L
.80898 .10301 L
.81074 .10301 L
.81265 .10301 L
.81446 .10301 L
.81613 .10301 L
.81779 .10301 L
.8193 .10301 L
.82104 .10301 L
.82267 .10301 L
.82446 .10301 L
.82636 .10301 L
.82797 .10301 L
.82974 .10301 L
.83165 .10301 L
.83272 .10301 L
Mistroke
.8337 .10301 L
.8356 .10301 L
.83739 .10301 L
.83892 .10301 L
.8406 .10301 L
.84236 .10301 L
.84401 .10301 L
.84555 .10301 L
.84696 .10301 L
.84851 .10301 L
.85014 .10301 L
.8518 .10301 L
.85357 .10301 L
.85524 .10301 L
.85676 .10301 L
.85855 .10301 L
.85956 .10301 L
.86049 .10301 L
.86219 .10301 L
.864 .10301 L
.86576 .10301 L
.86768 .10301 L
.86949 .10301 L
.87117 .10301 L
.87284 .10301 L
.87435 .10301 L
.87609 .10301 L
.87773 .10301 L
.87952 .10301 L
.88142 .10301 L
.88304 .10301 L
.88481 .10301 L
.88673 .10301 L
.8878 .10301 L
.88878 .10301 L
.89067 .10301 L
.89247 .10301 L
.894 .10301 L
.89569 .10301 L
.89745 .10301 L
.8991 .10301 L
.90064 .10301 L
.90205 .10301 L
.90368 .10301 L
.90523 .10301 L
.90689 .10301 L
.90867 .10301 L
.91034 .10301 L
.91186 .10301 L
.91365 .10301 L
Mistroke
.91466 .10301 L
.91558 .10301 L
.91729 .10301 L
.9191 .10301 L
.92086 .10301 L
.92186 .10301 L
.92279 .10301 L
.92449 .10301 L
.92629 .10301 L
.9279 .10301 L
.92941 .10301 L
.93107 .10301 L
.93286 .10301 L
.93465 .10301 L
.93566 .10301 L
.93661 .10301 L
.93852 .10301 L
.93958 .10301 L
.94056 .10301 L
.9423 .10301 L
.94419 .10301 L
.94597 .10301 L
.94762 .10301 L
.94915 .10301 L
.9508 .10301 L
.95236 .10301 L
.95378 .10301 L
.95544 .10301 L
.95726 .10301 L
.95897 .10301 L
.96056 .10301 L
.96235 .10301 L
.96404 .10301 L
.96556 .10301 L
.96719 .10301 L
.96899 .10301 L
.97088 .10301 L
.97249 .10301 L
.97426 .10301 L
.97616 .10301 L
.97792 .10301 L
.97884 .10301 L
.97985 .10301 L
.98091 .10301 L
.9819 .10301 L
.98371 .10301 L
.98537 .10301 L
.9872 .10301 L
.98912 .10301 L
.99074 .10301 L
Mistroke
.99247 .10301 L
.99411 .10301 L
.99559 .10301 L
.99734 .10301 L
.99923 .10301 L
Mfstroke
.99923 .10301 m
1 .10301 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000oooooolLooooo`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0oooooolLooooo`00<?ooool6o`0000;o
oooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^0?oooooo7Oooool003So
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003ooooo
oa?ooooo000hooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05oooo
o`03o`000?oooooooooo0?oooooo4oooool003Sooooo00Go410@oooooooooooooooooa0@400?oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooo
oooo0?oooooo4oooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooo
oooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003ooooooooo
o`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000oooo
ooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`00
0?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool0
0ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o
0000ooooooooool0oooooolCooooo`008oooool5o`0002_ooooo00?o0000ooooooooool0:oooool5
o`0002kooooo0_l000000ol@413oooooooooo`0Zooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?oo
ool01Oo<c<co8B4Qo`000?lQ8B7oc<c<02Wooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`00
0?lb<S;ok^k^6_ooool002?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00[ooooo`03o`000?oooooo
oooo02_ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00_ooooo`03o`000?oooooooooo02_ooooo00Go
EEEEogMgMoooooooV9RHob4Q8@0/ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40:oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool001_ooooo1_l00003ooooo`03
oiRHV?lQ8B7ok^k^02cooooo00?o0000ooooooooool0;?ooool00onHV9So8B4Qonk^kP0]ooooo`Go
0000;?ooool01Ol0003ooooooooooooooooo000002cooooo00Go0000ooooooooooooooooo`00000[
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Jooooo`009Oooool0
0onHV9So8B4Qonk^kP0[ooooo`03o`000?oooooooooo02gooooo00?oV9RHob4Q8Oo^k^h0;?ooool0
1?m4A4CogMgMooooool0000]ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;?ooool01Olb<S;oV9RH
oooooonHV9So<S8b02_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
01[ooooo000Vooooo`03ogMgMomVIVKooooo02[ooooo0_l0000_ooooo`03ogMgMomVIVKooooo02_o
oooo00CogMgMoeEEEOoooooo0000;Oooool01Ol0003oEEEEo`000?l@413oc<c<02cooooo00Goc<c<
o`000?l0003o0000olc<c00[ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Jooooo`009oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool0:oooool00omgMgOoc<c<o`00000]ooooo`03oeEEEOn7QhOooooo02kooooo00Go
410@okZj^_oooooo^[Zjoa0@400[ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@400Jooooo`008oooool01Ol0003o^[ZjoooooonHV9So410@02_ooooo00?o0000oooooooo
ool0:oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo00?ok^k^odA4A?l00000;Oooool00ooM
gMgo410@oiRHV00^ooooo`05o`000?nj^[[ooooookZj^_l00000:oooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool002?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00[ooooo`03o`000?oooooooooo02_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00^ooooo`03ogMg
Mol0003ooooo02gooooo00Coc<c<odA4A?l0003o410@;?ooool01OnYZJWo410@o`000?l@413oZJVY
02Wooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo001Coooo
o`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00
Doooool00ol0003oooooooooo`3mooooo`;o00000_ooool2o`0000oooooo001Cooooo`03o`000?oo
oooooooo0?gooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd?ooooo`00Doooool00ol0003ooooo
ooooo`3nooooo`04omgMgOl0003o410@olc<c13ooooo000:oooooooo0000@?l0000;ooooo`04onk^
k_lQ8B7o410@onk^kQ3ooooo000Fooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool2o`0000_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`04o`00
0?ooooooooooooooo`;o00001oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00Co8B4QogMgMomgMgOo<S8b4?ooool002;ooooo00?o0000ooooooooool0;_ooool00ol0003o
ooooooooo`0^ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`0;ooooo`;o00008Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02ko
oooo00?o0000ooooooooool02?ooool2o`0000;ooooo0_l0000?ooooo`00Doooool00ol0003ooooo
ooooo`17ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0Xoooool005?ooooo00?o
0000ooooooooool0Aoooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo0:Cooooo001C
ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`2U
ooooo`00Doooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool0YOooool005?ooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo0:Kooooo001Cooooo`;o0000B_ooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo0:Kooooo001Cooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`2Wooooo`00Doooool00ol0003oooooooooo`1:ooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool0Yoooool005?ooooo00?o0000ooooooooool0B_ooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo0:Oooooo001Cooooo`03o`000?oooooooooo04_o
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`2Wooooo`00Doooool00ol0003ooooo
ooooo`1;ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0Z?ooool005?ooooo00?o
0000ooooooooool0Boooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo0:Sooooo001C
ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`2X
ooooo`00Doooool2o`0004cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`2Yoooo
o`00Doooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool0ZOooool005?ooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo0:Wooooo001Cooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`2Zooooo`00Doooool00ol0003oooooooooo`1<ooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool0Z_ooool005?ooooo00?o0000ooooooooool0C?ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo0:[ooooo001Cooooo`03o`000?oooooooooo04co
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`2Zooooo`00Doooool00ol0003ooooo
ooooo`1<ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0Zoooool005?ooooo0_l0
001>ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0Zoooool005?ooooo00?o0000
ooooooooool0COooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo0:_ooooo001Coooo
o`03o`000?oooooooooo04gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`2[oooo
o`00Doooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool0Zoooool005?ooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo0:cooooo001Cooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`2/ooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B44ooooo`Go00001_ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool0[?ooool003Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?oo
ool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0COooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo0:cooooo000hooooo`05oa0@4?ooooooooooooooool@4100
3?ooool00onHV9So8B4Qonk^kP07ooooo`?o0000COooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo0:cooooo000hooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Q
onk^kP06ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`2/ooooo`00>?ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool0
1Oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
[?ooool003Sooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo0:gooooo
000hooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Ko
oooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo0:go
oooo000hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<
00Kooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
0:gooooo001Cooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`2]ooooo`00Doooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool0[Oooool005?ooooo00?o0000ooooooooool0C_ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo0:gooooo001Cooooo`;o0000Coooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo0:gooooo001Cooooo`03o`000?oooooooooo04oooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`2^ooooo`00Doooool00ol0003oooooooooo`1?ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0[_ooool005?ooooo00?o0000ooooooooool0
Coooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0:kooooo001Cooooo`03o`000?oo
oooooooo04oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2^ooooo`00Doooool0
0ol0003oooooooooo`1?ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0[_ooool0
05?ooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
0:kooooo001Cooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`2^ooooo`00Doooool2o`00053ooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`2_ooooo`00Doooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool0[oooool005?ooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo0:oooooo001Cooooo`03o`000?oooooooooo053ooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`2_ooooo`00Doooool00ol0003oooooooooo`1@ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool0[oooool005?ooooo00?o0000ooooooooool0
D?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo0:oooooo001Cooooo`03o`000?oo
oooooooo053ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`2`ooooo`00Doooool0
0ol0003oooooooooo`1@ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0/?ooool0
05?ooooo0_l0001Aooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0/?ooool005?o
oooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo0;3o
oooo001Cooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`2`ooooo`00Doooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0/?ooool005?ooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo0;7ooooo001Cooooo`03o`000?oooooooooo057ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`2aooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`1Aoooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0/Oooool003Sooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
057ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`2aooooo`00>?ooool01Ol@413o
oooooooooooooooo410@00_ooooo1Ol00006ooooo`?o0000DOooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo0;7ooooo000hooooo`05o`000?ooooooooooooooool000002oooool01?m4
A4CogMgMooooool00007ooooo`03o`000?oooooooooo057ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`2aooooo`00>?ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgM
oeEEEOoooooo00001oooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool0/Oooool003Sooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<
c<co000000Oooooo00?o0000ooooooooool0DOooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo0;;ooooo000hooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`00
0007ooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`2booooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_oo
ool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0/_oo
ool005?ooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo0;;ooooo001Cooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`2booooo`00Doooool2o`0005?ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`2booooo`00Doooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0/_ooool005?ooooo00?o0000ooooooooool0D_ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo0;;ooooo001Cooooo`03o`000?oooooooooo05;ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`2cooooo`00Doooool00ol0003oooooooooo`1Boooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0/oooool005?ooooo00?o0000oooooooo
ool0D_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;?ooooo001Cooooo`03o`00
0?oooooooooo05;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2cooooo`00Dooo
ool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0/ooo
ool005?ooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo0;?ooooo001Cooooo`;o0000E?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
0;?ooooo001Cooooo`03o`000?oooooooooo05?ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2dooooo`00Doooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0]?ooool005?ooooo00?o0000ooooooooool0Doooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo0;Cooooo001Cooooo`03o`000?oooooooooo05?ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2dooooo`00Doooool00ol0003oooooooooo`1Coooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0]?ooool005?ooooo00?o0000oooooooo
ool0E?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0;Cooooo001Cooooo`03o`00
0?oooooooooo05Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2dooooo`00Dooo
ool2o`0005Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2dooooo`00Doooool0
0ol0003oooooooooo`1Dooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0]Oooool0
05?ooooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
0;Gooooo001Cooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`2eooooo`00Doooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0]Oooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0E?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo0;Gooooo000hooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo
05Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2eooooo`00>?ooool01Ol@413o
oooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
oooo05Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2eooooo`00>?ooool01Ol0
003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000EOoo
ool01Ol0003ooooooooooooooooo00000;Sooooo000hooooo`05o`000?ooooooooooooooool00000
2oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0EOooool01Ol0003o
oooooooooooooooo00000;Sooooo000hooooo`05oa0@4?ooooooooooooooool@41002oooool00omE
EEGoQhN7ooooo`08ooooo`03o`000?oooooooooo05Kooooo00Co0000oooooooooooo0000^?ooool0
03Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000
ooooooooool0E_ooool01?l0003oooooooooool0002hooooo`00>?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`1Fooooo`03o`00
0?oooooo00000;Wooooo001Cooooo`03o`000?oooooooooo05Kooooo0ol0002iooooo`00Doooool0
0ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?o
oooo0_l0003ooooooaCooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o
0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Coooo
o`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00
Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4ooo
ool005?ooooo0_l0003ooooooaCooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?o
oooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo
001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolC
ooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oo
oooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool2o`000?oooooo5?oo
ool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooo
oa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0
oooooolCooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<
c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3ooooooa?ooooo000hooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06oooo
o`03o`000?oooooooooo0?oooooo4oooool003Sooooo00Go410@oooooooooooooooooa0@400;oooo
o`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooa?ooooo000hoooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0
003ooooooa?ooooo000hooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`00
0?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01Ol@413ooooooooo
oooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo0?oo
oooo4oooool003Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj
^_l000001_ooool00ol0003oooooooooo`3ooooooa?ooooo000hooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0oooooolC
ooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oo
oooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool2o`000?oooooo5?oo
ool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooo
oa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0
oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooo
oooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool2o`000?oo
oooo5?ooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003ooooooooo
o`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000oooo
ooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`00
0?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool2
o`000?oooooo5?ooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o
0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo0019oooo
o`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`3ooooooa?ooooo001;ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooolCooooo`00Boooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo0?oooooo4oooool004_ooooo00?o0000ooooooooool01Ooo
ool3o`000?oooooo4oooool004_ooooo00?o0000ooooooooool0oooooolKooooo`00Boooool00ol0
003oooooooooo`3ooooooa_ooooo001;ooooo`03o`000?oooooooooo0?oooooo6oooool004Wooooo
00?oEEEEofIVI_l00000oooooolMooooo`00O?ooool3o`000003oa0@4?oooooooooo0>Kooooo001n
ooooo`03oa0@4?nj^[[ooooo00Kooooo0_l0000;ooooo`03o`000?nj^[[ooooo00cooooo0_l00006
ooooo`03o`000?nj^[[ooooo0;[ooooo001nooooo`03oiRHV?lb<S;ooooo00Kooooo00?o0000oooo
ooooool02_ooool2oc8b<Pkooooo00?o0000ooooooooool01?ooool2oc8b<[_ooooo001nooooo`03
omgMgOl0003o^[Zj00Kooooo00?o0000ooooooooool00_ooool2o`0000;ooooo0_l00002ooooo`03
ohN7Qol0003o^[Zj00Gooooo00GoV9RHo`000?l0003oA4A4okZj^P03ooooo`03o`000?oooooooooo
00Cooooo00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj013ooooo00Gok^k^
oc8b<_l0003o410@olc<c02Dooooo`00O_ooool00omEEEGoMgMgodA4A006ooooo`03o`000?oooooo
oooo00;ooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd2ooooo`03olc<c?l0003o410@00Gooooo
00Go410@okZj^_o^k^koMgMgoa0@4003ooooo`03o`000?oooooooooo00Cooooo00?oc<c<o`000?l@
41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l000001_ooooooEEEEogMgMooooooo
V9RHob4Q8ICooooo001mooooo`05omgMgOl@413oooooob4Q8OoMgMd01Oooool00ol0003ooooooooo
o`03ooooo`04omgMgOl0003o410@olc<c0_ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo01;ooooo00Go0000ooooooooooooooooo`00002Dooooo`00
OOooool01OmVIVKoQhN7oooooonHV9SoEEEE00Gooooo00?o0000ooooooooool00oooool01?o^k^ko
8B4Qoa0@4?o^k^h;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`0;ooooo`Ko000000Koooooo`000?nHV9SooooooiRHV?lQ8B6Dooooo`00O?ooool0
0oo^k^ko0000onk^kP02ooooo`03o`000?oMgMgooooo00?ooooo00?o0000ooooooooool00oooool0
1?lQ8B7oMgMgogMgMolb<S8;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0Booooo`05o`000?mEEEGo0000oa0@4?o<c<`0U?ooool007cooooo00Co
410@o`000?l0003ooooo0_l000000ol@413oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo
0_l00002ooooo`;o00002?ooool00ol@413o0000o`000003o`0000Cooooo00?o0000ooooooooool0
4Oooool00ol@413o0000o`000003o`00017ooooo00?oEEEEohN7Qoooool0U_ooool008Oooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool04_ooool00ooMgMgo410@oiRHV02Fooooo`00Qoooool2o`0001?ooooo00?o0000
ooooooooool01?ooool2o`0001Gooooo00?o0000ooooooooool04oooool01?o<c<coA4A4o`000?l@
412Dooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-3.4116, -0.234311, \
0.0510397, 0.00762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.230769 0.0769231 0.103006 0.515028 [
[.07692 .09051 -6 -9 ]
[.07692 .09051 6 0 ]
[.38462 .09051 -3 -9 ]
[.38462 .09051 3 0 ]
[.53846 .09051 -3 -9 ]
[.53846 .09051 3 0 ]
[.69231 .09051 -3 -9 ]
[.69231 .09051 3 0 ]
[.84615 .09051 -3 -9 ]
[.84615 .09051 3 0 ]
[1 .09051 -6 -9 ]
[1 .09051 6 0 ]
[1.025 .10301 0 -6 ]
[1.025 .10301 10 6 ]
[.21827 0 -24 -4.5 ]
[.21827 0 0 4.5 ]
[.21827 .20601 -18 -4.5 ]
[.21827 .20601 0 4.5 ]
[.21827 .30902 -18 -4.5 ]
[.21827 .30902 0 4.5 ]
[.21827 .41202 -18 -4.5 ]
[.21827 .41202 0 4.5 ]
[.21827 .51503 -18 -4.5 ]
[.21827 .51503 0 4.5 ]
[.21827 .61803 -6 -4.5 ]
[.21827 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07692 .10301 m
.07692 .10926 L
s
[(-2)] .07692 .09051 0 1 Mshowa
.38462 .10301 m
.38462 .10926 L
s
[(2)] .38462 .09051 0 1 Mshowa
.53846 .10301 m
.53846 .10926 L
s
[(4)] .53846 .09051 0 1 Mshowa
.69231 .10301 m
.69231 .10926 L
s
[(6)] .69231 .09051 0 1 Mshowa
.84615 .10301 m
.84615 .10926 L
s
[(8)] .84615 .09051 0 1 Mshowa
1 .10301 m
1 .10926 L
s
[(10)] 1 .09051 0 1 Mshowa
.125 Mabswid
.11538 .10301 m
.11538 .10676 L
s
.15385 .10301 m
.15385 .10676 L
s
.19231 .10301 m
.19231 .10676 L
s
.26923 .10301 m
.26923 .10676 L
s
.30769 .10301 m
.30769 .10676 L
s
.34615 .10301 m
.34615 .10676 L
s
.42308 .10301 m
.42308 .10676 L
s
.46154 .10301 m
.46154 .10676 L
s
.5 .10301 m
.5 .10676 L
s
.57692 .10301 m
.57692 .10676 L
s
.61538 .10301 m
.61538 .10676 L
s
.65385 .10301 m
.65385 .10676 L
s
.73077 .10301 m
.73077 .10676 L
s
.76923 .10301 m
.76923 .10676 L
s
.80769 .10301 m
.80769 .10676 L
s
.88462 .10301 m
.88462 .10676 L
s
.92308 .10301 m
.92308 .10676 L
s
.96154 .10301 m
.96154 .10676 L
s
.03846 .10301 m
.03846 .10676 L
s
.25 Mabswid
0 .10301 m
1 .10301 L
s
gsave
1.025 .10301 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.23077 0 m
.23702 0 L
s
[(-0.2)] .21827 0 1 0 Mshowa
.23077 .20601 m
.23702 .20601 L
s
[(0.2)] .21827 .20601 1 0 Mshowa
.23077 .30902 m
.23702 .30902 L
s
[(0.4)] .21827 .30902 1 0 Mshowa
.23077 .41202 m
.23702 .41202 L
s
[(0.6)] .21827 .41202 1 0 Mshowa
.23077 .51503 m
.23702 .51503 L
s
[(0.8)] .21827 .51503 1 0 Mshowa
.23077 .61803 m
.23702 .61803 L
s
[(1)] .21827 .61803 1 0 Mshowa
.125 Mabswid
.23077 .02575 m
.23452 .02575 L
s
.23077 .0515 m
.23452 .0515 L
s
.23077 .07725 m
.23452 .07725 L
s
.23077 .12876 m
.23452 .12876 L
s
.23077 .15451 m
.23452 .15451 L
s
.23077 .18026 m
.23452 .18026 L
s
.23077 .23176 m
.23452 .23176 L
s
.23077 .25751 m
.23452 .25751 L
s
.23077 .28327 m
.23452 .28327 L
s
.23077 .33477 m
.23452 .33477 L
s
.23077 .36052 m
.23452 .36052 L
s
.23077 .38627 m
.23452 .38627 L
s
.23077 .43777 m
.23452 .43777 L
s
.23077 .46353 m
.23452 .46353 L
s
.23077 .48928 m
.23452 .48928 L
s
.23077 .54078 m
.23452 .54078 L
s
.23077 .56653 m
.23452 .56653 L
s
.23077 .59228 m
.23452 .59228 L
s
.25 Mabswid
.23077 0 m
.23077 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
123.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(7) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.40308 .10301 m
.40416 .10301 L
.40519 .10301 L
.40613 .10301 L
.408 .10301 L
.4097 .10301 L
.41064 .10301 L
.41166 .10301 L
.4135 .10301 L
.41524 .10301 L
.41707 .10301 L
.41864 .10301 L
.42035 .10301 L
.4214 .10301 L
.42238 .10301 L
.42423 .10301 L
.42527 .10301 L
.42622 .10301 L
.42727 .10301 L
.42839 .10301 L
.43023 .10301 L
.43195 .10301 L
.43385 .10301 L
.43491 .10301 L
.43589 .10301 L
.43754 .10301 L
.4393 .10301 L
.44096 .10301 L
.44247 .10301 L
.44425 .10301 L
.44525 .10301 L
.44617 .10301 L
.44787 .10301 L
.44967 .10301 L
.45139 .10301 L
.45324 .10301 L
.45498 .10301 L
.45658 .10301 L
.45844 .10301 L
.4595 .10301 L
.46048 .10301 L
.46227 .10301 L
.46418 .10301 L
.46599 .10301 L
.46702 .10301 L
.46798 .10301 L
.46899 .10301 L
.46992 .10301 L
.47098 .10301 L
.47199 .10301 L
Mistroke
.47378 .10302 L
.47543 .10303 L
.47725 .10304 L
.47816 .10306 L
.47917 .10308 L
.48019 .10311 L
.48127 .10316 L
.48219 .10321 L
.48319 .10328 L
.48428 .10339 L
.48544 .10354 L
.48654 .10373 L
.48753 .10394 L
.48947 .10454 L
.49056 .105 L
.49156 .10552 L
.49341 .10679 L
.49537 .10869 L
.49719 .11111 L
.49885 .114 L
.50077 .1183 L
.50259 .12349 L
.50583 .13588 L
.50935 .15464 L
.51321 .18206 L
.51732 .21849 L
.52471 .2953 L
.53133 .36038 L
.53466 .38567 L
.53655 .39677 L
.53831 .40474 L
.5393 .40819 L
.54024 .41072 L
.54201 .41356 L
.5439 .41384 L
.54497 .41277 L
.54596 .41101 L
.54758 .40659 L
.54937 .39966 L
.55298 .37995 L
.5666 .27088 L
.57331 .21879 L
.57954 .17986 L
.5866 .14809 L
.59032 .13609 L
.59429 .12633 L
.59794 .11964 L
.60137 .11493 L
.60445 .11175 L
.60778 .10918 L
Mistroke
.61145 .10716 L
.61353 .1063 L
.61548 .10565 L
.6194 .10469 L
.6216 .1043 L
.6236 .10402 L
.62718 .10366 L
.6292 .10351 L
.63107 .1034 L
.6345 .10326 L
.63623 .10321 L
.63815 .10316 L
.6398 .10313 L
.64156 .1031 L
.6435 .10308 L
.6453 .10306 L
.64733 .10305 L
.64925 .10304 L
.65097 .10303 L
.65283 .10303 L
.65445 .10302 L
.65624 .10302 L
.6581 .10301 L
.65984 .10301 L
.66144 .10301 L
.66295 .10301 L
.6647 .10301 L
.66629 .10301 L
.66821 .10301 L
.66994 .10301 L
.67195 .10301 L
.67383 .10301 L
.67558 .10301 L
.67718 .10301 L
.67895 .10301 L
.68081 .10301 L
.6827 .10301 L
.68471 .10301 L
.68662 .10301 L
.68836 .10301 L
.69039 .10301 L
.69154 .10301 L
.6926 .10301 L
.69456 .10301 L
.69662 .10301 L
.69837 .10301 L
.70028 .10301 L
.70209 .10301 L
.70376 .10301 L
.70542 .10301 L
Mistroke
.70692 .10301 L
.70866 .10301 L
.7103 .10301 L
.71209 .10301 L
.71398 .10301 L
.71559 .10301 L
.71736 .10301 L
.71927 .10301 L
.72034 .10301 L
.72132 .10301 L
.72321 .10301 L
.72501 .10301 L
.72653 .10301 L
.72822 .10301 L
.72998 .10301 L
.73163 .10301 L
.73316 .10301 L
.73457 .10301 L
.73612 .10301 L
.73775 .10301 L
.73941 .10301 L
.74118 .10301 L
.74285 .10301 L
.74437 .10301 L
.74616 .10301 L
.74716 .10301 L
.74809 .10301 L
.7498 .10301 L
.75161 .10301 L
.75337 .10301 L
.75529 .10301 L
.7571 .10301 L
.75878 .10301 L
.76044 .10301 L
.76195 .10301 L
.76369 .10301 L
.76532 .10301 L
.76712 .10301 L
.76901 .10301 L
.77063 .10301 L
.7724 .10301 L
.77432 .10301 L
.77539 .10301 L
.77636 .10301 L
.77826 .10301 L
.78006 .10301 L
.78159 .10301 L
.78327 .10301 L
.78503 .10301 L
.78669 .10301 L
Mistroke
.78823 .10301 L
.78964 .10301 L
.79118 .10301 L
.79281 .10301 L
.79447 .10301 L
.79625 .10301 L
.79792 .10301 L
.79944 .10301 L
.80123 .10301 L
.80223 .10301 L
.80316 .10301 L
.80487 .10301 L
.80668 .10301 L
.80844 .10301 L
.81036 .10301 L
.81218 .10301 L
.81386 .10301 L
.81537 .10301 L
.81704 .10301 L
.81879 .10301 L
.82042 .10301 L
.82223 .10301 L
.82412 .10301 L
.82574 .10301 L
.82752 .10301 L
.82944 .10301 L
.83051 .10301 L
.83148 .10301 L
.83338 .10301 L
.83518 .10301 L
.83671 .10301 L
.8384 .10301 L
.84017 .10301 L
.84182 .10301 L
.84336 .10301 L
.84478 .10301 L
.8464 .10301 L
.84795 .10301 L
.84962 .10301 L
.85139 .10301 L
.85306 .10301 L
.85458 .10301 L
.85637 .10301 L
.85738 .10301 L
.85831 .10301 L
.86001 .10301 L
.86182 .10301 L
.86359 .10301 L
.86459 .10301 L
.86552 .10301 L
Mistroke
.86722 .10301 L
.86903 .10301 L
.87064 .10301 L
.87215 .10301 L
.87381 .10301 L
.8756 .10301 L
.87739 .10301 L
.87841 .10301 L
.87936 .10301 L
.88127 .10301 L
.88234 .10301 L
.88331 .10301 L
.88505 .10301 L
.88694 .10301 L
.88873 .10301 L
.89038 .10301 L
.89191 .10301 L
.89356 .10301 L
.89512 .10301 L
.89654 .10301 L
.89821 .10301 L
.90002 .10301 L
.90174 .10301 L
.90333 .10301 L
.90512 .10301 L
.90681 .10301 L
.90833 .10301 L
.90996 .10301 L
.91176 .10301 L
.91365 .10301 L
.91526 .10301 L
.91703 .10301 L
.91894 .10301 L
.9207 .10301 L
.92162 .10301 L
.92263 .10301 L
.92369 .10301 L
.92468 .10301 L
.9265 .10301 L
.92816 .10301 L
.93009 .10301 L
.93191 .10301 L
.93354 .10301 L
.93527 .10301 L
.93691 .10301 L
.93839 .10301 L
.94014 .10301 L
.94203 .10301 L
.94382 .10301 L
.94546 .10301 L
Mistroke
.94722 .10301 L
.94911 .10301 L
.95089 .10301 L
.95251 .10301 L
.95441 .10301 L
.95549 .10301 L
.95649 .10301 L
.95831 .10301 L
.95923 .10301 L
.96025 .10301 L
.96124 .10301 L
.96228 .10301 L
.96413 .10301 L
.96517 .10301 L
.96613 .10301 L
.96719 .10301 L
.96832 .10301 L
.96929 .10301 L
.97036 .10301 L
.97136 .10301 L
.97228 .10301 L
.97403 .10301 L
.97589 .10301 L
.97765 .10301 L
.97956 .10301 L
.98137 .10301 L
.98305 .10301 L
.98471 .10301 L
.98622 .10301 L
.98796 .10301 L
.98959 .10301 L
.99139 .10301 L
.99328 .10301 L
.9949 .10301 L
.99667 .10301 L
.99858 .10301 L
.99965 .10301 L
Mfstroke
.99965 .10301 m
1 .10301 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000oooooolLooooo`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0oooooolLooooo`00<?ooool6o`0000;o
oooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^0?oooooo7Oooool003So
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003ooooo
oa?ooooo000hooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05oooo
o`03o`000?oooooooooo0?oooooo4oooool003Sooooo00Go410@oooooooooooooooooa0@400?oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooo
oooo0?oooooo4oooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooo
oooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003ooooooooo
o`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000oooo
ooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`00
0?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool0
0ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o
0000ooooooooool0oooooolCooooo`008oooool5o`0002_ooooo00?o0000ooooooooool0:oooool5
o`0002kooooo0_l000000ol@413oooooooooo`0Zooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?oo
ool01Oo<c<co8B4Qo`000?lQ8B7oc<c<02Wooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`00
0?lb<S;ok^k^6_ooool002?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00[ooooo`03o`000?oooooo
oooo02_ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00_ooooo`03o`000?oooooooooo02_ooooo00Go
EEEEogMgMoooooooV9RHob4Q8@0/ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40:oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool001_ooooo1_l00003ooooo`03
oiRHV?lQ8B7ok^k^02cooooo00?o0000ooooooooool0;?ooool00onHV9So8B4Qonk^kP0]ooooo`Go
0000;?ooool01Ol0003ooooooooooooooooo000002cooooo00Go0000ooooooooooooooooo`00000[
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Jooooo`009Oooool0
0onHV9So8B4Qonk^kP0[ooooo`03o`000?oooooooooo02gooooo00?oV9RHob4Q8Oo^k^h0;?ooool0
1?m4A4CogMgMooooool0000]ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;?ooool01Olb<S;oV9RH
oooooonHV9So<S8b02_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
01[ooooo000Vooooo`03ogMgMomVIVKooooo02[ooooo0_l0000_ooooo`03ogMgMomVIVKooooo02_o
oooo00CogMgMoeEEEOoooooo0000;Oooool01Ol0003oEEEEo`000?l@413oc<c<02cooooo00Goc<c<
o`000?l0003o0000olc<c00[ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Jooooo`009oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool0:oooool00omgMgOoc<c<o`00000]ooooo`03oeEEEOn7QhOooooo02kooooo00Go
410@okZj^_oooooo^[Zjoa0@400[ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@400Jooooo`008oooool01Ol0003o^[ZjoooooonHV9So410@02_ooooo00?o0000oooooooo
ool0:oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo00?ok^k^odA4A?l00000;Oooool00ooM
gMgo410@oiRHV00^ooooo`05o`000?nj^[[ooooookZj^_l00000:oooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool002?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00[ooooo`03o`000?oooooooooo02_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00^ooooo`03ogMg
Mol0003ooooo02gooooo00Coc<c<odA4A?l0003o410@;?ooool01OnYZJWo410@o`000?l@413oZJVY
02Wooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo001Coooo
o`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00
Doooool00ol0003oooooooooo`3mooooo`;o00000_ooool2o`0000oooooo001Cooooo`03o`000?oo
oooooooo0?gooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd?ooooo`00Doooool00ol0003ooooo
ooooo`3nooooo`04omgMgOl0003o410@olc<c13ooooo000:oooooooo0000@?l0000;ooooo`04onk^
k_lQ8B7o410@onk^kQ3ooooo000Fooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo000000_ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`08ooooo`?o00002oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`04ob4Q
8OmgMgOoMgMgoc8b<Q3ooooo000Rooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0
;_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
4_ooool2o`0001[ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0^ooooo`03o`00
0?oooooooooo00Sooooo0_l00002ooooo`;o00003oooool005?ooooo00?o0000ooooooooool0D_oo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo09cooooo001Cooooo`03o`000?oooooo
oooo05?ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`2Looooo`00Doooool00ol0
003oooooooooo`1Cooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0WOooool005?o
oooo00?o0000ooooooooool0E?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo09go
oooo001Cooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`2Nooooo`00Doooool2o`0005Gooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`2Nooooo`00Doooool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool0Woooool005?ooooo00?o0000ooooooooool0EOooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo09oooooo001Cooooo`03o`000?oooooooooo05Gooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`2Oooooo`00Doooool00ol0003oooooooooo`1Eooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool0X?ooool005?ooooo00?o0000ooooooooool0EOoo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo0:3ooooo001Cooooo`03o`000?oooooo
oooo05Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`2Qooooo`00Doooool00ol0
003oooooooooo`1Fooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0XOooool005?o
oooo0_l0001Gooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0XOooool005?ooooo
00?o0000ooooooooool0E_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo0:;ooooo
001Cooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`2Rooooo`00Doooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool0X_ooool005?ooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo0:;ooooo001Cooooo`03o`000?oooooooooo05Oooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`2Rooooo`00Doooool00ol0003oooooooooo`1Gooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool0Xoooool005?ooooo00?o0000ooooooooool0Eooo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo0:?ooooo001Cooooo`;o0000F?ooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo0:?ooooo001Cooooo`03o`000?oooooooooo
05Oooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`2Sooooo`00Doooool00ol0003o
ooooooooo`1Gooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0Xoooool005?ooooo
00?o0000ooooooooool0Eoooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo0:?ooooo
001Cooooo`03o`000?oooooooooo05Oooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`2Tooooo`00Doooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool0Y?ooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0000Kooooo00?o0000ooooooooool0Eoooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo0:Cooooo000hooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`2Tooooo`00>?ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
V9RHob4Q8Oo^k^h01oooool3o`0005Sooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`2Tooooo`00>?ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01_oo
ool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0Y?oo
ool003Sooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Gooooo00?o
0000ooooooooool0F?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo0:Gooooo000h
ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo05Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2Uooooo`00>?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`00
0?oooooooooo05Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2Uooooo`00>?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03
o`000?oooooooooo05Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2Uooooo`00
Doooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
YOooool005?ooooo00?o0000ooooooooool0F?ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo0:Gooooo001Cooooo`03o`000?oooooooooo05Sooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`2Uooooo`00Doooool2o`0005[ooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`2Vooooo`00Doooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0Y_ooool005?ooooo00?o0000ooooooooool0FOooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo0:Kooooo001Cooooo`03o`000?oooooooooo05Wooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`2Vooooo`00Doooool00ol0003oooooooooo`1I
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0Y_ooool005?ooooo00?o0000oooo
ooooool0FOooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo0:Kooooo001Cooooo`03
o`000?oooooooooo05Wooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`2Vooooo`00
Doooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
Y_ooool005?ooooo0_l0001Kooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0Y_oo
ool005?ooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo0:Oooooo001Cooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`2Wooooo`00Doooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool0Yoooool005?ooooo00?o0000ooooooooool0F_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo0:Oooooo001Cooooo`03o`000?oooooooooo05[ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`2Wooooo`00Doooool00ol0003oooooooooo`1J
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0Yoooool005?ooooo00?o0000oooo
ooooool0F_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0:Oooooo001Cooooo`;o
0000Foooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo0:Oooooo001Cooooo`03o`00
0?oooooooooo05_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2Xooooo`00Dooo
ool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0Z?oo
ool005?ooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo0:Sooooo001Cooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`2Xooooo`00Doooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0Z?ooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0Foooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo0:Sooooo000hooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Kooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool0Z?ooool003Sooooo00Go410@oooooooooooo
oooooa0@400;ooooo`Go00001_ooool3o`0005_ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`2Xooooo`00>?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoo
oooo00001oooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool0Z?ooool003Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGooooo
o`0000Oooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo0:Wooooo000hooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000007
ooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2Y
ooooo`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001oooool0
0ol0003oooooooooo`1Looooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0ZOooool0
03Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000
ooooooooool0G?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0:Wooooo001Coooo
o`03o`000?oooooooooo05cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2Yoooo
o`00Doooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0ZOooool005?ooooo0_l0001Mooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
ZOooool005?ooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo0:Wooooo001Cooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`2Yooooo`00Doooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0Z_ooool005?ooooo00?o0000ooooooooool0GOooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo0:[ooooo001Cooooo`03o`000?oooooooooo05gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`2Zooooo`00Doooool00ol0003ooooooooo
o`1Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Z_ooool005?ooooo00?o0000
ooooooooool0GOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0:[ooooo001Coooo
o`03o`000?oooooooooo05gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2Zoooo
o`00Doooool2o`0005kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2Zooooo`00
Doooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
Z_ooool005?ooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo0:[ooooo001Cooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`2[ooooo`00Doooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0Zoooool005?ooooo00?o0000ooooooooool0G_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo0:_ooooo001Cooooo`03o`000?oooooooooo05kooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`2[ooooo`00Doooool00ol0003ooooooooo
o`1Nooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Zoooool005?ooooo0_l0001O
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0[?ooool005?ooooo00?o0000oooo
ooooool0G_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0:cooooo001Cooooo`03
o`000?oooooooooo05kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2/ooooo`00
Doooool00ol0003oooooooooo`1Nooooo`05o`000?ooooooooooooooool00000[oooool005?ooooo
00?o0000ooooooooool0G_ooool01Ol0003ooooooooooooooooo00000:oooooo000hooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006oooo
o`03o`000?oooooooooo05oooooo00Co0000oooooooooooo0000[oooool003Sooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o
0000ooooooooool0Goooool01?l0003oooooooooool0002_ooooo`00>?ooool01Ol@413ooooooooo
oooooooo410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo05oo
oooo00Co0000oooooooooooo0000[oooool003Sooooo00Go0000ooooooooooooooooo`00000;oooo
o`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`00063ooooo0_l0002`ooooo`00>?ooool01Ol0
003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oo
oooooooo067ooooo00?o0000ooooooooool0[_ooool003Sooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003ooooooooo
o`3ooooooa?ooooo000hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`00
0?l@4106ooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooo
oolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo
0?oooooo4oooool005?ooooo0_l0003ooooooaCooooo001Cooooo`03o`000?oooooooooo0?oooooo
4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3o
oooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000oooooooo
ool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oo
oooooooo0?oooooo4oooool005?ooooo0_l0003ooooooaCooooo001Cooooo`03o`000?oooooooooo
0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003ooooo
ooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000
ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03
o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Dooo
ool2o`000?oooooo5?ooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0
003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo
00?o0000ooooooooool0oooooolCooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3ooooooa?o
oooo000hooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?oo
ooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?oooooo4oooool003Sooooo00Go410@oooooooo
oooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3o
oooooa?ooooo000hooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonH
V9So<S8b00Kooooo0ol0003ooooooa?ooooo000hooooo`05o`000?ooooooooooooooool000002ooo
ool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooolCooooo`00>?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03
o`000?oooooooooo0?oooooo4oooool003Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`3ooooooa?ooooo000hooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000
ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03
o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Dooo
ool2o`000?oooooo5?ooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0
003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo
00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001C
ooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCoooo
o`00Doooool2o`000?oooooo5?ooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Dooo
ool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool0
05?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?o
oooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooo
oolCooooo`00Doooool2o`000?oooooo5?ooool005?ooooo00?o0000ooooooooool0oooooolCoooo
o`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo
4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3o
oooooa?ooooo0019ooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`3ooooo
oa?ooooo001;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooolCooooo`00
Boooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo4oooool004_ooooo00?o
0000ooooooooool01Oooool3o`000?oooooo4oooool004_ooooo00?o0000ooooooooool0oooooolK
ooooo`00Boooool00ol0003oooooooooo`3ooooooa_ooooo001;ooooo`03o`000?oooooooooo0?oo
oooo6oooool004Wooooo00?oEEEEofIVI_l00000oooooolMooooo`00O?ooool3o`000003oa0@4?oo
oooooooo0>Kooooo001nooooo`03oa0@4?nj^[[ooooo00Kooooo0_l0000;ooooo`03o`000?nj^[[o
oooo00cooooo0_l00006ooooo`03o`000?nj^[[ooooo0;[ooooo001nooooo`03oiRHV?lb<S;ooooo
00Kooooo00?o0000ooooooooool02_ooool2oc8b<Pkooooo00?o0000ooooooooool01?ooool2oc8b
<[_ooooo001nooooo`03omgMgOl0003o^[Zj00Kooooo00?o0000ooooooooool00_ooool2o`0000;o
oooo0_l00002ooooo`03ohN7Qol0003o^[Zj00Gooooo00GoV9RHo`000?l0003oA4A4okZj^P03oooo
o`03o`000?oooooooooo00Cooooo00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co
^[Zj01;ooooo00?o0000onk^k_ooool0U?ooool007kooooo00?oEEEEogMgMom4A4@01_ooool00ol0
003oooooooooo`02ooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM0_ooool00oo<c<co0000oa0@
4005ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000oooool00ol0003oooooooooo`04ooooo`03olc<
c?l0003o410@00cooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00000oooool00omEEEGo
ZJVYooooo`2Dooooo`00OOooool01OoMgMgo410@oooooolQ8B7ogMgM00Gooooo00?o0000oooooooo
ool00oooool01?oMgMgo0000oa0@4?o<c<`;ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0Dooooo`03ojVYZOmEEEGooooo09Cooooo001mooooo`05
ofIVI_n7QhOooooooiRHV?mEEED01Oooool00ol0003oooooooooo`03ooooo`04onk^k_lQ8B7o410@
onk^kP_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo00_ooooo1_l00004ooooo`03ob4Q8Ooooooooooo09?ooooo001looooo`03onk^k_l0003ok^k^
00;ooooo00?o0000omgMgOooool00oooool00ol0003oooooooooo`03ooooo`04ob4Q8OmgMgOoMgMg
oc8b<P_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo01Gooooo00?oEEEEolc<c?ooool0Toooool007cooooo00Co410@o`000?l0003ooooo0_l00000
0ol@413oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo0_l00002ooooo`;o00002?ooool0
0ol@413o0000o`000003o`0000Cooooo00?o0000ooooooooool04Oooool00ol@413o0000o`000003
o`0001Cooooo00?oZJVYogMgMoooool0Toooool008Oooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool01Ol@
413ooooooooooooooooo<S8b09Cooooo0027ooooo`;o00004oooool00ol0003oooooooooo`04oooo
o`;o00005Oooool00ol0003oooooooooo`0Booooo`Go0000U?ooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-3.4116, -0.234311, \
0.0510397, 0.00762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.230769 0.0769231 0.103006 0.515028 [
[.07692 .09051 -6 -9 ]
[.07692 .09051 6 0 ]
[.38462 .09051 -3 -9 ]
[.38462 .09051 3 0 ]
[.53846 .09051 -3 -9 ]
[.53846 .09051 3 0 ]
[.69231 .09051 -3 -9 ]
[.69231 .09051 3 0 ]
[.84615 .09051 -3 -9 ]
[.84615 .09051 3 0 ]
[1 .09051 -6 -9 ]
[1 .09051 6 0 ]
[1.025 .10301 0 -6 ]
[1.025 .10301 10 6 ]
[.21827 0 -24 -4.5 ]
[.21827 0 0 4.5 ]
[.21827 .20601 -18 -4.5 ]
[.21827 .20601 0 4.5 ]
[.21827 .30902 -18 -4.5 ]
[.21827 .30902 0 4.5 ]
[.21827 .41202 -18 -4.5 ]
[.21827 .41202 0 4.5 ]
[.21827 .51503 -18 -4.5 ]
[.21827 .51503 0 4.5 ]
[.21827 .61803 -6 -4.5 ]
[.21827 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07692 .10301 m
.07692 .10926 L
s
[(-2)] .07692 .09051 0 1 Mshowa
.38462 .10301 m
.38462 .10926 L
s
[(2)] .38462 .09051 0 1 Mshowa
.53846 .10301 m
.53846 .10926 L
s
[(4)] .53846 .09051 0 1 Mshowa
.69231 .10301 m
.69231 .10926 L
s
[(6)] .69231 .09051 0 1 Mshowa
.84615 .10301 m
.84615 .10926 L
s
[(8)] .84615 .09051 0 1 Mshowa
1 .10301 m
1 .10926 L
s
[(10)] 1 .09051 0 1 Mshowa
.125 Mabswid
.11538 .10301 m
.11538 .10676 L
s
.15385 .10301 m
.15385 .10676 L
s
.19231 .10301 m
.19231 .10676 L
s
.26923 .10301 m
.26923 .10676 L
s
.30769 .10301 m
.30769 .10676 L
s
.34615 .10301 m
.34615 .10676 L
s
.42308 .10301 m
.42308 .10676 L
s
.46154 .10301 m
.46154 .10676 L
s
.5 .10301 m
.5 .10676 L
s
.57692 .10301 m
.57692 .10676 L
s
.61538 .10301 m
.61538 .10676 L
s
.65385 .10301 m
.65385 .10676 L
s
.73077 .10301 m
.73077 .10676 L
s
.76923 .10301 m
.76923 .10676 L
s
.80769 .10301 m
.80769 .10676 L
s
.88462 .10301 m
.88462 .10676 L
s
.92308 .10301 m
.92308 .10676 L
s
.96154 .10301 m
.96154 .10676 L
s
.03846 .10301 m
.03846 .10676 L
s
.25 Mabswid
0 .10301 m
1 .10301 L
s
gsave
1.025 .10301 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.23077 0 m
.23702 0 L
s
[(-0.2)] .21827 0 1 0 Mshowa
.23077 .20601 m
.23702 .20601 L
s
[(0.2)] .21827 .20601 1 0 Mshowa
.23077 .30902 m
.23702 .30902 L
s
[(0.4)] .21827 .30902 1 0 Mshowa
.23077 .41202 m
.23702 .41202 L
s
[(0.6)] .21827 .41202 1 0 Mshowa
.23077 .51503 m
.23702 .51503 L
s
[(0.8)] .21827 .51503 1 0 Mshowa
.23077 .61803 m
.23702 .61803 L
s
[(1)] .21827 .61803 1 0 Mshowa
.125 Mabswid
.23077 .02575 m
.23452 .02575 L
s
.23077 .0515 m
.23452 .0515 L
s
.23077 .07725 m
.23452 .07725 L
s
.23077 .12876 m
.23452 .12876 L
s
.23077 .15451 m
.23452 .15451 L
s
.23077 .18026 m
.23452 .18026 L
s
.23077 .23176 m
.23452 .23176 L
s
.23077 .25751 m
.23452 .25751 L
s
.23077 .28327 m
.23452 .28327 L
s
.23077 .33477 m
.23452 .33477 L
s
.23077 .36052 m
.23452 .36052 L
s
.23077 .38627 m
.23452 .38627 L
s
.23077 .43777 m
.23452 .43777 L
s
.23077 .46353 m
.23452 .46353 L
s
.23077 .48928 m
.23452 .48928 L
s
.23077 .54078 m
.23452 .54078 L
s
.23077 .56653 m
.23452 .56653 L
s
.23077 .59228 m
.23452 .59228 L
s
.25 Mabswid
.23077 0 m
.23077 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
123.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(8) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.44451 .10301 m
.44641 .10301 L
.4482 .10301 L
.44984 .10301 L
.45166 .10301 L
.45335 .10301 L
.45521 .10301 L
.45625 .10301 L
.45719 .10301 L
.45892 .10301 L
.46079 .10301 L
.46255 .10301 L
.46418 .10301 L
.46587 .10301 L
.46741 .10301 L
.46919 .10301 L
.47087 .10301 L
.47243 .10301 L
.47387 .10301 L
.47545 .10301 L
.47712 .10301 L
.4788 .10301 L
.48061 .10301 L
.48231 .10301 L
.48388 .10301 L
.48561 .10301 L
.48751 .10301 L
.48847 .10301 L
.48949 .10301 L
.49133 .10301 L
.49227 .10301 L
.49327 .10301 L
.49505 .10301 L
.49696 .10301 L
.49805 .10301 L
.49907 .10301 L
.50091 .10301 L
.50259 .10301 L
.50351 .10301 L
.50453 .10301 L
.50637 .10301 L
.50817 .10302 L
.5098 .10304 L
.51168 .10308 L
.51345 .10314 L
.5151 .10325 L
.51661 .10341 L
.51827 .10368 L
.52003 .10412 L
.52181 .10482 L
Mistroke
.52281 .10536 L
.52374 .10597 L
.52545 .10746 L
.52726 .10966 L
.52887 .11231 L
.53039 .11551 L
.53205 .11997 L
.53384 .12604 L
.53761 .14383 L
.5395 .15563 L
.54156 .1708 L
.54863 .23847 L
.55532 .31253 L
.559 .34895 L
.5608 .36414 L
.56246 .37609 L
.564 .38523 L
.56569 .39294 L
.5674 .39809 L
.5692 .40067 L
.57072 .40055 L
.57235 .39816 L
.5739 .39387 L
.57531 .38835 L
.58987 .27759 L
.59786 .21242 L
.60177 .18627 L
.60536 .16629 L
.61172 .13996 L
.61506 .13017 L
.61858 .12231 L
.62219 .11636 L
.62556 .11234 L
.62924 .1092 L
.63131 .10789 L
.63319 .10693 L
.63666 .10559 L
.6384 .10509 L
.64033 .10465 L
.64197 .10434 L
.64373 .10407 L
.64692 .10371 L
.64883 .10355 L
.65091 .10341 L
.65288 .10332 L
.6547 .10325 L
.65648 .10319 L
.65815 .10315 L
.66007 .10312 L
.66182 .10309 L
Mistroke
.66352 .10307 L
.66511 .10306 L
.66677 .10305 L
.66859 .10304 L
.67013 .10303 L
.67159 .10303 L
.67328 .10302 L
.67481 .10302 L
.67651 .10301 L
.67831 .10301 L
.67985 .10301 L
.68155 .10301 L
.68337 .10301 L
.68532 .10301 L
.68717 .10301 L
.68887 .10301 L
.69073 .10301 L
.69248 .10301 L
.69406 .10301 L
.69577 .10301 L
.69763 .10301 L
.6996 .10301 L
.70128 .10301 L
.70313 .10301 L
.70486 .10301 L
.70644 .10301 L
.70826 .10301 L
.70999 .10301 L
.71158 .10301 L
.71306 .10301 L
.71468 .10301 L
.7164 .10301 L
.71739 .10301 L
.71844 .10301 L
.72032 .10301 L
.72136 .10301 L
.72233 .10301 L
.72347 .10301 L
.72454 .10301 L
.72648 .10301 L
.72824 .10301 L
.73014 .10301 L
.73121 .10301 L
.7322 .10301 L
.73391 .10301 L
.7355 .10301 L
.73726 .10301 L
.73914 .10301 L
.74008 .10301 L
.74111 .10301 L
Mistroke
.74299 .10301 L
.74481 .10301 L
.7465 .10301 L
.74837 .10301 L
.74931 .10301 L
.75034 .10301 L
.75217 .10301 L
.75388 .10301 L
.75491 .10301 L
.75589 .10301 L
.75773 .10301 L
.75876 .10301 L
.75971 .10301 L
.76074 .10301 L
.76186 .10301 L
.76358 .10301 L
.76519 .10301 L
.76711 .10301 L
.76887 .10301 L
.77061 .10301 L
.7725 .10301 L
.77346 .10301 L
.77448 .10301 L
.77633 .10301 L
.77814 .10301 L
.77982 .10301 L
.78166 .10301 L
.78259 .10301 L
.78361 .10301 L
.78533 .10301 L
.78717 .10301 L
.78891 .10301 L
.7905 .10301 L
.79213 .10301 L
.79366 .10301 L
.79532 .10301 L
.7971 .10301 L
.7988 .10301 L
.80039 .10301 L
.80183 .10301 L
.80337 .10301 L
.80518 .10301 L
.80683 .10301 L
.80874 .10301 L
.81054 .10301 L
.8122 .10301 L
.81374 .10301 L
.81543 .10301 L
.81722 .10301 L
.81902 .10301 L
Mistroke
.82002 .10301 L
.82095 .10301 L
.82265 .10301 L
.82444 .10301 L
.8254 .10301 L
.82641 .10301 L
.82825 .10301 L
.82937 .10301 L
.83043 .10301 L
.83145 .10301 L
.83241 .10301 L
.83418 .10301 L
.83512 .10301 L
.83613 .10301 L
.83718 .10301 L
.83818 .10301 L
.84006 .10301 L
.84181 .10301 L
.84344 .10301 L
.84522 .10301 L
.84711 .10301 L
.84899 .10301 L
.85005 .10301 L
.85102 .10301 L
.8528 .10301 L
.85468 .10301 L
.85568 .10301 L
.85675 .10301 L
.85776 .10301 L
.85867 .10301 L
.85975 .10301 L
.86092 .10301 L
.86203 .10301 L
.86304 .10301 L
.86486 .10301 L
.86658 .10301 L
.86813 .10301 L
.86982 .10301 L
.87165 .10301 L
.87267 .10301 L
.8736 .10301 L
.8754 .10301 L
.87711 .10301 L
.87871 .10301 L
.8804 .10301 L
.88185 .10301 L
.88343 .10301 L
.88514 .10301 L
.88697 .10301 L
.8887 .10301 L
Mistroke
.89028 .10301 L
.89214 .10301 L
.89307 .10301 L
.89411 .10301 L
.89594 .10301 L
.89765 .10301 L
.89864 .10301 L
.89967 .10301 L
.90152 .10301 L
.90255 .10301 L
.9035 .10301 L
.90456 .10301 L
.90568 .10301 L
.90757 .10301 L
.90863 .10301 L
.90961 .10301 L
.91141 .10301 L
.91332 .10301 L
.91503 .10301 L
.91663 .10301 L
.91838 .10301 L
.92027 .10301 L
.92127 .10301 L
.92221 .10301 L
.92397 .10301 L
.92586 .10301 L
.92693 .10301 L
.92791 .10301 L
.92956 .10301 L
.93136 .10301 L
.93324 .10301 L
.935 .10301 L
.936 .10301 L
.93709 .10301 L
.93811 .10301 L
.93906 .10301 L
.94085 .10301 L
.94276 .10301 L
.94374 .10301 L
.94479 .10301 L
.94671 .10301 L
.94787 .10301 L
.94898 .10301 L
.94997 .10301 L
.95106 .10301 L
.95201 .10301 L
.95304 .10301 L
.9549 .10301 L
.95672 .10301 L
.95839 .10301 L
Mistroke
.9602 .10301 L
.96123 .10301 L
.96219 .10301 L
.96321 .10301 L
.96413 .10301 L
.9652 .10301 L
.96621 .10301 L
.96791 .10301 L
.96971 .10301 L
.97125 .10301 L
.97295 .10301 L
.97477 .10301 L
.97579 .10301 L
.97673 .10301 L
.97846 .10301 L
.98029 .10301 L
.98208 .10301 L
.98309 .10301 L
.98402 .10301 L
.98573 .10301 L
.98755 .10301 L
.98917 .10301 L
.99069 .10301 L
.99235 .10301 L
.99415 .10301 L
.99604 .10301 L
.99712 .10301 L
.99811 .10301 L
.99994 .10301 L
Mfstroke
.99994 .10301 m
1 .10301 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000oooooolLooooo`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0oooooolLooooo`00<?ooool6o`0000;o
oooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^0?oooooo7Oooool003So
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003ooooo
oa?ooooo000hooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05oooo
o`03o`000?oooooooooo0?oooooo4oooool003Sooooo00Go410@oooooooooooooooooa0@400?oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooo
oooo0?oooooo4oooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooo
oooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003ooooooooo
o`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000oooo
ooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`00
0?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool0
0ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o
0000ooooooooool0oooooolCooooo`008oooool5o`0002_ooooo00?o0000ooooooooool0:oooool5
o`0002kooooo0_l000000ol@413oooooooooo`0Zooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?oo
ool01Oo<c<co8B4Qo`000?lQ8B7oc<c<02Wooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`00
0?lb<S;ok^k^6_ooool002?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00[ooooo`03o`000?oooooo
oooo02_ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00_ooooo`03o`000?oooooooooo02_ooooo00Go
EEEEogMgMoooooooV9RHob4Q8@0/ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40:oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool001_ooooo1_l00003ooooo`03
oiRHV?lQ8B7ok^k^02cooooo00?o0000ooooooooool0;?ooool00onHV9So8B4Qonk^kP0]ooooo`Go
0000;?ooool01Ol0003ooooooooooooooooo000002cooooo00Go0000ooooooooooooooooo`00000[
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Jooooo`009Oooool0
0onHV9So8B4Qonk^kP0[ooooo`03o`000?oooooooooo02gooooo00?oV9RHob4Q8Oo^k^h0;?ooool0
1?m4A4CogMgMooooool0000]ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;?ooool01Olb<S;oV9RH
oooooonHV9So<S8b02_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
01[ooooo000Vooooo`03ogMgMomVIVKooooo02[ooooo0_l0000_ooooo`03ogMgMomVIVKooooo02_o
oooo00CogMgMoeEEEOoooooo0000;Oooool01Ol0003oEEEEo`000?l@413oc<c<02cooooo00Goc<c<
o`000?l0003o0000olc<c00[ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Jooooo`009oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool0:oooool00omgMgOoc<c<o`00000]ooooo`03oeEEEOn7QhOooooo02kooooo00Go
410@okZj^_oooooo^[Zjoa0@400[ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@400Jooooo`008oooool01Ol0003o^[ZjoooooonHV9So410@02_ooooo00?o0000oooooooo
ool0:oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo00?ok^k^odA4A?l00000;Oooool00ooM
gMgo410@oiRHV00^ooooo`05o`000?nj^[[ooooookZj^_l00000:oooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool002?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00[ooooo`03o`000?oooooooooo02_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00^ooooo`03ogMg
Mol0003ooooo02gooooo00Coc<c<odA4A?l0003o410@;?ooool01OnYZJWo410@o`000?l@413oZJVY
02Wooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo001Coooo
o`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00
Doooool00ol0003oooooooooo`3mooooo`;o00000_ooool2o`0000oooooo001Cooooo`03o`000?oo
oooooooo0?gooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd?ooooo`00Doooool00ol0003ooooo
ooooo`3booooo`03o`000?oooooooooo00Wooooo00CogMgMo`000?l@413oc<c<4?ooool000[ooooo
ool00010o`0000_ooooo00Cok^k^ob4Q8Ol@413ok^k^4?ooool001Kooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
1Oooool01Ol0003ooooooooooooooooo000000_ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool01?lQ8B7o
MgMgogMgMolb<S8@ooooo`008_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02ko
oooo00?o0000ooooooooool0:_ooool01Ol0003ooooooooooooooooo000001cooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02kooooo00?o0000oooo
ooooool02?ooool2o`0000;ooooo0_l0000?ooooo`00Doooool00ol0003oooooooooo`1Looooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool0U?ooool005?ooooo00?o0000ooooooooool0
G?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo09Gooooo001Cooooo`03o`000?oo
oooooooo05gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`2Eooooo`00Doooool0
0ol0003oooooooooo`1Mooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0U_ooool0
05?ooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
09Oooooo001Cooooo`;o0000Goooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo09So
oooo001Cooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`2Hooooo`00Doooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool0VOooool005?ooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo09Wooooo001Cooooo`03o`000?oooooooooo05oooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`2Iooooo`00Doooool00ol0003oooooooooo`1Oooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool0VOooool005?ooooo00?o0000ooooooooool0
Goooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo09[ooooo001Cooooo`03o`000?oo
oooooooo05oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`2Jooooo`00Doooool2
o`00063ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`2Jooooo`00Doooool00ol0
003oooooooooo`1Oooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0V_ooool005?o
oooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo09[o
oooo001Cooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`2Kooooo`00Doooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool0Voooool005?ooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo09_ooooo001Cooooo`03o`000?oooooooooo063ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`2Kooooo`00Doooool00ol0003oooooooooo`1Pooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool0Voooool005?ooooo0_l0001Qooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool0W?ooool005?ooooo00?o0000ooooooooool0H?oo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo09cooooo001Cooooo`03o`000?oooooo
oooo063ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`2Looooo`00Doooool00ol0
003oooooooooo`1Qooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0W?ooool005?o
oooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo09co
oooo001Cooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`2Looooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000
1_ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
W?ooool003Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Q
onk^k_ooooooA4A400Kooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo09gooooo000hooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP07ooooo`?o0000HOooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo09go
oooo000hooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP06ooooo`03
o`000?oooooooooo067ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`2Mooooo`00
>?ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003o
ooooooooo`1Qooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0WOooool003Sooooo
00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0HOooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo09gooooo000hooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000oooo
ooooool0HOooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo09gooooo000hooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000
ooooooooool0HOooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo09gooooo001Coooo
o`03o`000?oooooooooo06;ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`2Noooo
o`00Doooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool0W_ooool005?ooooo00?o0000ooooooooool0H_ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo09kooooo001Cooooo`;o0000Hoooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo09kooooo001Cooooo`03o`000?oooooooooo06;ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`2Nooooo`00Doooool00ol0003oooooooooo`1Rooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool0W_ooool005?ooooo00?o0000ooooooooool0H_ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo09kooooo001Cooooo`03o`000?oooooooooo06;ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`2Oooooo`00Doooool00ol0003ooooooooo
o`1Rooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0Woooool005?ooooo00?o0000
ooooooooool0H_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo09oooooo001Coooo
o`03o`000?oooooooooo06;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`2Ooooo
o`00Doooool2o`0006?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`2Oooooo`00
Doooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
Woooool005?ooooo00?o0000ooooooooool0Hoooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo09oooooo001Cooooo`03o`000?oooooooooo06?ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`2Pooooo`00Doooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0X?ooool005?ooooo00?o0000ooooooooool0Hoooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo0:3ooooo001Cooooo`03o`000?oooooooooo06?ooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`2Pooooo`00Doooool00ol0003ooooooooo
o`1Sooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0X?ooool005?ooooo0_l0001T
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0X?ooool005?ooooo00?o0000oooo
ooooool0Hoooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo0:3ooooo001Cooooo`03
o`000?oooooooooo06?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2Pooooo`00
Doooool00ol0003oooooooooo`1Sooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
XOooool005?ooooo00?o0000ooooooooool0I?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo0:7ooooo001Cooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`2Qooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46
ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`1Tooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool0XOooool003Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo06Cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`2Qooooo`00>?ooool01Ol@413ooooooooooooooooo
410@00_ooooo1Ol00006ooooo`?o0000I?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo0:7ooooo000hooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool0
0007ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`2Qooooo`00>?ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo0000
1oooool00ol0003oooooooooo`1Tooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
XOooool003Sooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo
00?o0000ooooooooool0I?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0:7ooooo
000hooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`000007ooooo`03o`00
0?oooooooooo06Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2Rooooo`00>?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_ooool00ol0003ooooo
ooooo`1Uooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0X_ooool005?ooooo00?o
0000ooooooooool0IOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0:;ooooo001C
ooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2R
ooooo`00Doooool2o`0006Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2Roooo
o`00Doooool00ol0003oooooooooo`1Uooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0X_ooool005?ooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo0:;ooooo001Cooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`2Rooooo`00Doooool00ol0003oooooooooo`1Vooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0X_ooool005?ooooo00?o0000ooooooooool0I_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo0:?ooooo001Cooooo`03o`000?oooooooooo06Ko
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2Sooooo`00Doooool00ol0003ooooo
ooooo`1Vooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Xoooool005?ooooo00?o
0000ooooooooool0I_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0:?ooooo001C
ooooo`;o0000Ioooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo0:?ooooo001Coooo
o`03o`000?oooooooooo06Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2Soooo
o`00Doooool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0Xoooool005?ooooo00?o0000ooooooooool0Ioooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo0:?ooooo001Cooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`2Sooooo`00Doooool00ol0003oooooooooo`1Wooooo`05o`000?oooooo
ooooooooool00000Y_ooool005?ooooo00?o0000ooooooooool0Ioooool01Ol0003ooooooooooooo
oooo00000:Kooooo001Cooooo`03o`000?oooooooooo06Oooooo00Go0000ooooooooooooooooo`00
002Vooooo`00Doooool2o`0006Sooooo00Go0000ooooooooooooooooo`00002Vooooo`00Doooool0
0ol0003oooooooooo`1Xooooo`04o`000?ooooooooooo`000:Kooooo001Cooooo`03o`000?oooooo
oooo06Sooooo00?o0000ooooool00000Yoooool005?ooooo00?o0000ooooooooool0J?ooool00ol0
003oooooo`00002Wooooo`00Doooool00ol0003oooooooooo`1Yooooo`;o0000Yoooool003Sooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<
00Kooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`3o
oooooa?ooooo000hooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooo
oooo000000Kooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01Ol0003ooooooooooooo
oooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000oooooolCooooo`00>?oo
ool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03
o`000?oooooooooo0?oooooo4oooool003Sooooo00Go410@oooooooooooooooooa0@400;ooooo`03
oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`3ooooooa?o
oooo000hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4106oooo
o`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00
Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4ooo
ool005?ooooo0_l0003ooooooaCooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?o
oooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo
001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolC
ooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oo
oooo4oooool005?ooooo0_l0003ooooooaCooooo001Cooooo`03o`000?oooooooooo0?oooooo4ooo
ool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooo
oa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0
oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooo
oooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool2o`000?oo
oooo5?ooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003ooooooooo
o`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000oooo
ooooool0oooooolCooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3ooooooa?ooooo000hoooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q
8@06ooooo`03o`000?oooooooooo0?oooooo4oooool003Sooooo00Go410@oooooooooooooooooa0@
400;ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooa?ooooo
000hooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Ko
oooo0ol0003ooooooa?ooooo000hooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co
0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01Ol@413o
oooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooo
oooo0?oooooo4oooool003Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[o
oooookZj^_l000001_ooool00ol0003oooooooooo`3ooooooa?ooooo000hooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0
oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooo
oooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool2o`000?oo
oooo5?ooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003ooooooooo
o`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000oooo
ooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`00
0?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool2
o`000?oooooo5?ooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o
0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Coooo
o`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00
Doooool2o`000?oooooo5?ooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool0
0ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?o
oooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo
0019ooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`3ooooooa?ooooo001;
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooolCooooo`00Boooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo4oooool004_ooooo00?o0000oooooooo
ool01Oooool3o`000?oooooo4oooool004_ooooo00?o0000ooooooooool0oooooolKooooo`00Booo
ool00ol0003oooooooooo`3ooooooa_ooooo001;ooooo`03o`000?oooooooooo0?oooooo6oooool0
04Wooooo00?oEEEEofIVI_l00000oooooolMooooo`00O?ooool3o`000003oa0@4?oooooooooo0>Ko
oooo001nooooo`03oa0@4?nj^[[ooooo00Kooooo0_l0000;ooooo`03o`000?nj^[[ooooo00cooooo
0_l00006ooooo`03o`000?nj^[[ooooo0;[ooooo001nooooo`03oiRHV?lb<S;ooooo00Kooooo00?o
0000ooooooooool02_ooool2oc8b<Pkooooo00?o0000ooooooooool01?ooool2oc8b<[_ooooo001n
ooooo`03omgMgOl0003o^[Zj00Kooooo00?o0000ooooooooool00_ooool2o`0000;ooooo0_l00002
ooooo`03ohN7Qol0003o^[Zj00Gooooo00GoV9RHo`000?l0003oA4A4okZj^P03ooooo`03o`000?oo
oooooooo00Cooooo00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj013ooooo
00Goc<c<ob4Q8Ol0003o8B4Qolc<c02Dooooo`00O_ooool00omEEEGoMgMgodA4A006ooooo`03o`00
0?oooooooooo00;ooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd2ooooo`03olc<c?l0003o410@
00Gooooo00Go410@okZj^_o^k^koMgMgoa0@4003ooooo`03o`000?oooooooooo00Cooooo00?oc<c<
o`000?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l000001_oooooo8B4QoiRH
V?ooooooV9RHob4Q8ICooooo001mooooo`05omgMgOl@413oooooob4Q8OoMgMd01Oooool00ol0003o
ooooooooo`03ooooo`04omgMgOl0003o410@olc<c0_ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00Go0000ooooooooooooooooo`00002D
ooooo`00OOooool01OmVIVKoQhN7oooooonHV9SoEEEE00Gooooo00?o0000ooooooooool00oooool0
1?o^k^ko8B4Qoa0@4?o^k^h;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0;ooooo`Ko000000Kooooooc8b<_nHV9SooooooiRHV?lb<S:Dooooo`00
O?ooool00oo^k^ko0000onk^kP02ooooo`03o`000?oMgMgooooo00?ooooo00?o0000ooooooooool0
0oooool01?lQ8B7oMgMgogMgMolb<S8;ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0Booooo`05olc<c?l0003o0000o`000?o<c<`0U?ooool007co
oooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`02ooooo`03o`000?oooooooooo
00;ooooo0_l00002ooooo`;o00002?ooool00ol@413o0000o`000003o`0000Cooooo00?o0000oooo
ooooool04Oooool00ol@413o0000o`000003o`00017ooooo00Go410@okZj^_oooooo^[Zjoa0@402D
ooooo`00Qoooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0Booooo`05o`000?nj^[[ooooookZj^_l00000U?ooool0
08Oooooo0_l0000Cooooo`03o`000?oooooooooo00Cooooo0_l0000Eooooo`03o`000?oooooooooo
01;ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@2Dooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-3.4116, -0.234311, \
0.0510397, 0.00762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.230769 0.0769231 0.103006 0.515028 [
[.07692 .09051 -6 -9 ]
[.07692 .09051 6 0 ]
[.38462 .09051 -3 -9 ]
[.38462 .09051 3 0 ]
[.53846 .09051 -3 -9 ]
[.53846 .09051 3 0 ]
[.69231 .09051 -3 -9 ]
[.69231 .09051 3 0 ]
[.84615 .09051 -3 -9 ]
[.84615 .09051 3 0 ]
[1 .09051 -6 -9 ]
[1 .09051 6 0 ]
[1.025 .10301 0 -6 ]
[1.025 .10301 10 6 ]
[.21827 0 -24 -4.5 ]
[.21827 0 0 4.5 ]
[.21827 .20601 -18 -4.5 ]
[.21827 .20601 0 4.5 ]
[.21827 .30902 -18 -4.5 ]
[.21827 .30902 0 4.5 ]
[.21827 .41202 -18 -4.5 ]
[.21827 .41202 0 4.5 ]
[.21827 .51503 -18 -4.5 ]
[.21827 .51503 0 4.5 ]
[.21827 .61803 -6 -4.5 ]
[.21827 .61803 0 4.5 ]
[.5 .63053 -38 0 ]
[.5 .63053 38 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07692 .10301 m
.07692 .10926 L
s
[(-2)] .07692 .09051 0 1 Mshowa
.38462 .10301 m
.38462 .10926 L
s
[(2)] .38462 .09051 0 1 Mshowa
.53846 .10301 m
.53846 .10926 L
s
[(4)] .53846 .09051 0 1 Mshowa
.69231 .10301 m
.69231 .10926 L
s
[(6)] .69231 .09051 0 1 Mshowa
.84615 .10301 m
.84615 .10926 L
s
[(8)] .84615 .09051 0 1 Mshowa
1 .10301 m
1 .10926 L
s
[(10)] 1 .09051 0 1 Mshowa
.125 Mabswid
.11538 .10301 m
.11538 .10676 L
s
.15385 .10301 m
.15385 .10676 L
s
.19231 .10301 m
.19231 .10676 L
s
.26923 .10301 m
.26923 .10676 L
s
.30769 .10301 m
.30769 .10676 L
s
.34615 .10301 m
.34615 .10676 L
s
.42308 .10301 m
.42308 .10676 L
s
.46154 .10301 m
.46154 .10676 L
s
.5 .10301 m
.5 .10676 L
s
.57692 .10301 m
.57692 .10676 L
s
.61538 .10301 m
.61538 .10676 L
s
.65385 .10301 m
.65385 .10676 L
s
.73077 .10301 m
.73077 .10676 L
s
.76923 .10301 m
.76923 .10676 L
s
.80769 .10301 m
.80769 .10676 L
s
.88462 .10301 m
.88462 .10676 L
s
.92308 .10301 m
.92308 .10676 L
s
.96154 .10301 m
.96154 .10676 L
s
.03846 .10301 m
.03846 .10676 L
s
.25 Mabswid
0 .10301 m
1 .10301 L
s
gsave
1.025 .10301 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.23077 0 m
.23702 0 L
s
[(-0.2)] .21827 0 1 0 Mshowa
.23077 .20601 m
.23702 .20601 L
s
[(0.2)] .21827 .20601 1 0 Mshowa
.23077 .30902 m
.23702 .30902 L
s
[(0.4)] .21827 .30902 1 0 Mshowa
.23077 .41202 m
.23702 .41202 L
s
[(0.6)] .21827 .41202 1 0 Mshowa
.23077 .51503 m
.23702 .51503 L
s
[(0.8)] .21827 .51503 1 0 Mshowa
.23077 .61803 m
.23702 .61803 L
s
[(1)] .21827 .61803 1 0 Mshowa
.125 Mabswid
.23077 .02575 m
.23452 .02575 L
s
.23077 .0515 m
.23452 .0515 L
s
.23077 .07725 m
.23452 .07725 L
s
.23077 .12876 m
.23452 .12876 L
s
.23077 .15451 m
.23452 .15451 L
s
.23077 .18026 m
.23452 .18026 L
s
.23077 .23176 m
.23452 .23176 L
s
.23077 .25751 m
.23452 .25751 L
s
.23077 .28327 m
.23452 .28327 L
s
.23077 .33477 m
.23452 .33477 L
s
.23077 .36052 m
.23452 .36052 L
s
.23077 .38627 m
.23452 .38627 L
s
.23077 .43777 m
.23452 .43777 L
s
.23077 .46353 m
.23452 .46353 L
s
.23077 .48928 m
.23452 .48928 L
s
.23077 .54078 m
.23452 .54078 L
s
.23077 .56653 m
.23452 .56653 L
s
.23077 .59228 m
.23452 .59228 L
s
.25 Mabswid
.23077 0 m
.23077 .61803 L
s
gsave
.5 .63053 -99 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
123.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(9) show
135.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.48041 .10301 m
.48061 .10301 L
.48245 .10301 L
.48348 .10301 L
.48441 .10301 L
.48611 .10301 L
.48795 .10301 L
.48969 .10301 L
.49129 .10301 L
.49295 .10301 L
.49473 .10301 L
.49641 .10301 L
.49795 .10301 L
.49975 .10301 L
.50076 .10301 L
.5017 .10301 L
.50343 .10301 L
.50526 .10301 L
.507 .10301 L
.50888 .10301 L
.51065 .10301 L
.51228 .10301 L
.51408 .10301 L
.5151 .10301 L
.51605 .10301 L
.51797 .10301 L
.51905 .10301 L
.52003 .10301 L
.52179 .10301 L
.52279 .10301 L
.52373 .10301 L
.52562 .10301 L
.52669 .10301 L
.52766 .10301 L
.52938 .10301 L
.53126 .10301 L
.53304 .10301 L
.53469 .10301 L
.53569 .10301 L
.53677 .10302 L
.53779 .10302 L
.53873 .10303 L
.54051 .10306 L
.54239 .10312 L
.54337 .10318 L
.54441 .10326 L
.5463 .1035 L
.54745 .10373 L
.54854 .10402 L
.54952 .10438 L
Mistroke
.55059 .10488 L
.55237 .10607 L
.55405 .10772 L
.55589 .1103 L
.55692 .1122 L
.55786 .11427 L
.55966 .1192 L
.56163 .12633 L
.56368 .13602 L
.56558 .14727 L
.5691 .17405 L
.57229 .20468 L
.57944 .28609 L
.5831 .3263 L
.58651 .35732 L
.58823 .36944 L
.59007 .37938 L
.59113 .38354 L
.59212 .38644 L
.59399 .38911 L
.5956 .38857 L
.59732 .3852 L
.59878 .3802 L
.6004 .3726 L
.604 .34924 L
.60739 .32152 L
.61502 .25241 L
.62212 .19569 L
.626 .17126 L
.62953 .15339 L
.63345 .13801 L
.63764 .12604 L
.6414 .11846 L
.64487 .11349 L
.64668 .11151 L
.64868 .10972 L
.65078 .10821 L
.65271 .1071 L
.65625 .10562 L
.65821 .10503 L
.66006 .10458 L
.66336 .10401 L
.66522 .10378 L
.66695 .10362 L
.66864 .10348 L
.67047 .10337 L
.67219 .10329 L
.67378 .10323 L
.67679 .10315 L
.67831 .10312 L
Mistroke
.67997 .10309 L
.68178 .10307 L
.68343 .10306 L
.68534 .10304 L
.68715 .10303 L
.68881 .10303 L
.69035 .10302 L
.69205 .10302 L
.69384 .10302 L
.6955 .10301 L
.69731 .10301 L
.6992 .10301 L
.70096 .10301 L
.70261 .10301 L
.70411 .10301 L
.70584 .10301 L
.70748 .10301 L
.70926 .10301 L
.71115 .10301 L
.71276 .10301 L
.71453 .10301 L
.71643 .10301 L
.7175 .10301 L
.71848 .10301 L
.72037 .10301 L
.72217 .10301 L
.72385 .10301 L
.72537 .10301 L
.72712 .10301 L
.72877 .10301 L
.73031 .10301 L
.73172 .10301 L
.73326 .10301 L
.73489 .10301 L
.73655 .10301 L
.73832 .10301 L
.73999 .10301 L
.74151 .10301 L
.74329 .10301 L
.7443 .10301 L
.74523 .10301 L
.74694 .10301 L
.74875 .10301 L
.7505 .10301 L
.75241 .10301 L
.75422 .10301 L
.75589 .10301 L
.75755 .10301 L
.75906 .10301 L
.76079 .10301 L
Mistroke
.76243 .10301 L
.76422 .10301 L
.76611 .10301 L
.76772 .10301 L
.76949 .10301 L
.7714 .10301 L
.77247 .10301 L
.77345 .10301 L
.77534 .10301 L
.77714 .10301 L
.77867 .10301 L
.78035 .10301 L
.78211 .10301 L
.78376 .10301 L
.78529 .10301 L
.7867 .10301 L
.78825 .10301 L
.78988 .10301 L
.79154 .10301 L
.79331 .10301 L
.79498 .10301 L
.7965 .10301 L
.79829 .10301 L
.79929 .10301 L
.80022 .10301 L
.80193 .10301 L
.80374 .10301 L
.8055 .10301 L
.80742 .10301 L
.80923 .10301 L
.81091 .10301 L
.81257 .10301 L
.81408 .10301 L
.81582 .10301 L
.81745 .10301 L
.81925 .10301 L
.82114 .10301 L
.82276 .10301 L
.82453 .10301 L
.82645 .10301 L
.82752 .10301 L
.82849 .10301 L
.83039 .10301 L
.83219 .10301 L
.83372 .10301 L
.8354 .10301 L
.83716 .10301 L
.83882 .10301 L
.84036 .10301 L
.84177 .10301 L
Mistroke
.84332 .10301 L
.84494 .10301 L
.8466 .10301 L
.84838 .10301 L
.85005 .10301 L
.85157 .10301 L
.85336 .10301 L
.85436 .10301 L
.85529 .10301 L
.857 .10301 L
.85881 .10301 L
.86057 .10301 L
.8625 .10301 L
.86431 .10301 L
.86599 .10301 L
.8675 .10301 L
.86917 .10301 L
.87092 .10301 L
.87255 .10301 L
.87436 .10301 L
.87625 .10301 L
.87788 .10301 L
.87965 .10301 L
.88157 .10301 L
.88264 .10301 L
.88362 .10301 L
.88551 .10301 L
.88731 .10301 L
.88884 .10301 L
.89053 .10301 L
.8923 .10301 L
.89395 .10301 L
.89549 .10301 L
.89691 .10301 L
.89853 .10301 L
.90008 .10301 L
.90175 .10301 L
.90352 .10301 L
.9052 .10301 L
.90671 .10301 L
.9085 .10301 L
.90951 .10301 L
.91044 .10301 L
.91214 .10301 L
.91395 .10301 L
.91572 .10301 L
.91672 .10301 L
.91765 .10301 L
.91935 .10301 L
.92116 .10301 L
Mistroke
.92277 .10301 L
.92428 .10301 L
.92594 .10301 L
.92773 .10301 L
.92953 .10301 L
.93054 .10301 L
.93149 .10301 L
.9334 .10301 L
.93447 .10301 L
.93544 .10301 L
.93718 .10301 L
.93908 .10301 L
.94086 .10301 L
.94251 .10301 L
.94404 .10301 L
.94569 .10301 L
.94725 .10301 L
.94867 .10301 L
.95034 .10301 L
.95215 .10301 L
.95387 .10301 L
.95546 .10301 L
.95725 .10301 L
.95894 .10301 L
.96046 .10301 L
.9621 .10301 L
.96389 .10301 L
.96578 .10301 L
.96739 .10301 L
.96916 .10301 L
.97107 .10301 L
.97283 .10301 L
.97375 .10301 L
.97476 .10301 L
.97582 .10301 L
.97681 .10301 L
.97863 .10301 L
.98029 .10301 L
.98222 .10301 L
.98404 .10301 L
.98567 .10301 L
.9874 .10301 L
.98904 .10301 L
.99052 .10301 L
.99227 .10301 L
.99416 .10301 L
.99595 .10301 L
.99759 .10301 L
.99935 .10301 L
Mfstroke
.99935 .10301 m
1 .10301 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000oooooolLooooo`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0oooooolLooooo`00<?ooool6o`0000;o
oooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^0?oooooo7Oooool003So
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003ooooo
oa?ooooo000hooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05oooo
o`03o`000?oooooooooo0?oooooo4oooool003Sooooo00Go410@oooooooooooooooooa0@400?oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooo
oooo0?oooooo4oooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooo
oooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003ooooooooo
o`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000oooo
ooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`00
0?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool0
0ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o
0000ooooooooool0oooooolCooooo`008oooool5o`0002_ooooo00?o0000ooooooooool0:oooool5
o`0002kooooo0_l000000ol@413oooooooooo`0Zooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?oo
ool01Oo<c<co8B4Qo`000?lQ8B7oc<c<02Wooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`00
0?lb<S;ok^k^6_ooool002?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00[ooooo`03o`000?oooooo
oooo02_ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00_ooooo`03o`000?oooooooooo02_ooooo00Go
EEEEogMgMoooooooV9RHob4Q8@0/ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40:oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool001_ooooo1_l00003ooooo`03
oiRHV?lQ8B7ok^k^02cooooo00?o0000ooooooooool0;?ooool00onHV9So8B4Qonk^kP0]ooooo`Go
0000;?ooool01Ol0003ooooooooooooooooo000002cooooo00Go0000ooooooooooooooooo`00000[
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Jooooo`009Oooool0
0onHV9So8B4Qonk^kP0[ooooo`03o`000?oooooooooo02gooooo00?oV9RHob4Q8Oo^k^h0;?ooool0
1?m4A4CogMgMooooool0000]ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;?ooool01Olb<S;oV9RH
oooooonHV9So<S8b02_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
01[ooooo000Vooooo`03ogMgMomVIVKooooo02[ooooo0_l0000_ooooo`03ogMgMomVIVKooooo02_o
oooo00CogMgMoeEEEOoooooo0000;Oooool01Ol0003oEEEEo`000?l@413oc<c<02cooooo00Goc<c<
o`000?l0003o0000olc<c00[ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Jooooo`009oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool0:oooool00omgMgOoc<c<o`00000]ooooo`03oeEEEOn7QhOooooo02kooooo00Go
410@okZj^_oooooo^[Zjoa0@400[ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@400Jooooo`008oooool01Ol0003o^[ZjoooooonHV9So410@02_ooooo00?o0000oooooooo
ool0:oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo00?ok^k^odA4A?l00000;Oooool00ooM
gMgo410@oiRHV00^ooooo`05o`000?nj^[[ooooookZj^_l00000:oooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool002?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00[ooooo`03o`000?oooooooooo02_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00^ooooo`03ogMg
Mol0003ooooo02gooooo00Coc<c<odA4A?l0003o410@;?ooool01OnYZJWo410@o`000?l@413oZJVY
02Wooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo001Coooo
o`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00
Doooool00ol0003oooooooooo`3mooooo`;o00000_ooool2o`0000oooooo001Cooooo`03o`000?oo
oooooooo0?gooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd?ooooo`00Doooool00ol0003ooooo
ooooo`3nooooo`04omgMgOl0003o410@olc<c13ooooo000:oooooooo0000@?l0000;ooooo`04onk^
k_lQ8B7o410@onk^kQ3ooooo000Fooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00Co0000oooooooooooo
oooo0_l00006ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool2o`0000_o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00Co8B4QogMgMomgMgOo<S8b4?ooool002;ooooo00?o0000ooooooooool0;_ooool00ol0003o
ooooooooo`0^ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Iooooo`;o00003Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02ko
oooo00?o0000ooooooooool02?ooool2o`0000;ooooo0_l0000?ooooo`00Doooool00ol0003ooooo
ooooo`1Uooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0S_ooool005?ooooo00?o
0000ooooooooool0IOooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo08oooooo001C
ooooo`03o`000?oooooooooo06Kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`2?
ooooo`00Doooool00ol0003oooooooooo`1Vooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool0T?ooool005?ooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo093ooooo001Cooooo`;o0000Ioooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo093ooooo001Cooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`2Aooooo`00Doooool00ol0003oooooooooo`1Wooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool0TOooool005?ooooo00?o0000ooooooooool0Ioooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo09;ooooo001Cooooo`03o`000?oooooooooo06Oo
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`2Booooo`00Doooool00ol0003ooooo
ooooo`1Xooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0T_ooool005?ooooo00?o
0000ooooooooool0J?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo09?ooooo001C
ooooo`03o`000?oooooooooo06Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`2C
ooooo`00Doooool2o`0006Wooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`2Coooo
o`00Doooool00ol0003oooooooooo`1Xooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool0Toooool005?ooooo00?o0000ooooooooool0J?ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo09?ooooo001Cooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`2Dooooo`00Doooool00ol0003oooooooooo`1Yooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0U?ooool005?ooooo00?o0000ooooooooool0JOooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo09Cooooo001Cooooo`03o`000?oooooooooo06Wo
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2Dooooo`00Doooool00ol0003ooooo
ooooo`1Yooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0U?ooool005?ooooo0_l0
001Zooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0U?ooool005?ooooo00?o0000
ooooooooool0JOooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo09Cooooo001Coooo
o`03o`000?oooooooooo06Wooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`2Eoooo
o`00Doooool00ol0003oooooooooo`1Yooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool0UOooool005?ooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo09Gooooo001Cooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`2Eooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B44ooooo`Go00001_ooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool0UOooool003Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?oo
ool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0J_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo09Gooooo000hooooo`05oa0@4?ooooooooooooooool@4100
3?ooool00onHV9So8B4Qonk^kP07ooooo`?o0000J_ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo09Gooooo000hooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Q
onk^kP06ooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`2Fooooo`00>?ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool0
1Oooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
U_ooool003Sooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0J_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo09Kooooo
000hooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Ko
oooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo09Ko
oooo000hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<
00Kooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
09Kooooo001Cooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`2Fooooo`00Doooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0Uoooool005?ooooo00?o0000ooooooooool0Joooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo09Oooooo001Cooooo`;o0000K?ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo09Oooooo001Cooooo`03o`000?oooooooooo06_ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`2Gooooo`00Doooool00ol0003oooooooooo`1[ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool0Uoooool005?ooooo00?o0000ooooooooool0
Joooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo09Oooooo001Cooooo`03o`000?oo
oooooooo06_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2Hooooo`00Doooool0
0ol0003oooooooooo`1[ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0V?ooool0
05?ooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
09Sooooo001Cooooo`03o`000?oooooooooo06_ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`2Hooooo`00Doooool2o`0006cooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`2Hooooo`00Doooool00ol0003oooooooooo`1[ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool0V?ooool005?ooooo00?o0000ooooooooool0Joooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo09Sooooo001Cooooo`03o`000?oooooooooo06cooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`2Hooooo`00Doooool00ol0003oooooooooo`1/ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0VOooool005?ooooo00?o0000ooooooooool0
K?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo09Wooooo001Cooooo`03o`000?oo
oooooooo06cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2Iooooo`00Doooool0
0ol0003oooooooooo`1/ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0VOooool0
05?ooooo0_l0001]ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0VOooool005?o
oooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo09Wo
oooo001Cooooo`03o`000?oooooooooo06cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`2Iooooo`00Doooool00ol0003oooooooooo`1/ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0VOooool005?ooooo00?o0000ooooooooool0K?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo09Wooooo001Cooooo`03o`000?oooooooooo06cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`2Iooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`1/oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0VOooool003Sooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
06cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2Jooooo`00>?ooool01Ol@413o
oooooooooooooooo410@00_ooooo1Ol00006ooooo`?o0000KOooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo09[ooooo000hooooo`05o`000?ooooooooooooooool000002oooool01?m4
A4CogMgMooooool00007ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`2Jooooo`00>?ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgM
oeEEEOoooooo00001oooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0V_ooool003Sooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<
c<co000000Oooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo09[ooooo000hooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`00
0007ooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`2Jooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_oo
ool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0V_oo
ool005?ooooo00?o0000ooooooooool0KOooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo09[ooooo001Cooooo`03o`000?oooooooooo06gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`2Jooooo`00Doooool2o`0006kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`2Jooooo`00Doooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0Voooool005?ooooo00?o0000ooooooooool0KOooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo09_ooooo001Cooooo`03o`000?oooooooooo06gooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`2Kooooo`00Doooool00ol0003oooooooooo`1^oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Voooool005?ooooo00?o0000oooooooo
ool0K_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo09_ooooo001Cooooo`03o`00
0?oooooooooo06kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2Kooooo`00Dooo
ool00ol0003oooooooooo`1^ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Vooo
ool005?ooooo00?o0000ooooooooool0K_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo09_ooooo001Cooooo`;o0000Koooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
09cooooo001Cooooo`03o`000?oooooooooo06oooooo00Go0000ooooooooooooooooo`00002Noooo
o`00Doooool00ol0003oooooooooo`1_ooooo`05o`000?ooooooooooooooool00000W_ooool005?o
oooo00?o0000ooooooooool0Koooool01Ol0003ooooooooooooooooo000009kooooo001Cooooo`03
o`000?oooooooooo06oooooo00Go0000ooooooooooooooooo`00002Nooooo`00Doooool00ol0003o
ooooooooo`1_ooooo`04o`000?ooooooooooo`0009oooooo001Cooooo`03o`000?oooooooooo06oo
oooo00Co0000oooooooooooo0000Woooool005?ooooo00?o0000ooooooooool0L?ooool00ol0003o
ooooo`00002Oooooo`00Doooool2o`00077ooooo0_l0002Pooooo`00Doooool00ol0003ooooooooo
o`1aooooo`03o`000?oooooooooo09kooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool0
05?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?o
oooo000hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0
003o410@olc<c006ooooo`03o`000?oooooooooo0?oooooo4oooool003Sooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000
ooooooooool0oooooolCooooo`00>?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo4oooool003Sooooo00Go0000
ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`000?oooooo
4oooool003Sooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`01_ooool00ol0003oooooooooo`3ooooooa?ooooo000hooooo`05oa0@4?ooooooooooooooool@
41002oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo0?oooooo4oooool003Sooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000oooooooo
ool0oooooolCooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0
003o410@1_ooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oo
oooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003ooooooooo
o`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003oooooooooo`3ooooo
oa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0
oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooo
oooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003ooooooooo
o`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000oooo
ooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`00
0?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool0
0ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?o
oooo0_l0003ooooooaCooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o
0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Coooo
o`03o`000?oooooooooo0?oooooo4oooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooooolC
ooooo`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9So
oooooiRHV?lQ8B401_ooool00ol0003oooooooooo`3ooooooa?ooooo000hooooo`05oa0@4?oooooo
ooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0
oooooolCooooo`00>?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?oooooo
V9RHoc8b<P06ooooo`?o0000oooooolCooooo`00>?ooool01Ol0003ooooooooooooooooo000000_o
oooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo0?oooooo4oooool003So
oooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool0
0ol0003oooooooooo`3ooooooa?ooooo000hooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool0
1Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`00
0?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool0
0ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?o
oooo0_l0003ooooooaCooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o
0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Coooo
o`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00
Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4ooo
ool005?ooooo0_l0003ooooooaCooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?o
oooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo
001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolC
ooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oo
oooo4oooool005?ooooo0_l0003ooooooaCooooo001Cooooo`03o`000?oooooooooo0?oooooo4ooo
ool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooo
oa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0
oooooolCooooo`00BOooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooo
oolCooooo`00Boooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo4oooool0
04_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooooa?ooooo001;ooooo`03
o`000?oooooooooo00Gooooo0ol0003ooooooa?ooooo001;ooooo`03o`000?oooooooooo0?oooooo
6oooool004_ooooo00?o0000ooooooooool0oooooolKooooo`00Boooool00ol0003oooooooooo`3o
oooooa_ooooo0019ooooo`03oeEEEOmVIVKo00000?oooooo7Oooool007cooooo0ol000000ol@413o
ooooooooo`3Vooooo`00O_ooool00ol@413o^[Zjooooo`06ooooo`;o00002oooool00ol0003o^[Zj
ooooo`0<ooooo`;o00001_ooool00ol0003o^[Zjooooo`2jooooo`00O_ooool00onHV9So<S8boooo
o`06ooooo`03o`000?oooooooooo00[ooooo0_lb<S8>ooooo`03o`000?oooooooooo00Cooooo0_lb
<S:kooooo`00O_ooool00ooMgMgo0000okZj^P06ooooo`03o`000?oooooooooo00;ooooo0_l00002
ooooo`;o00000_ooool00on7QhOo0000okZj^P05ooooo`05oiRHV?l0003o0000odA4A?nj^[X00ooo
ool00ol0003oooooooooo`04ooooo`03ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4
okZj^P0@ooooo`04oa0@4?l0003oA4A4olc<c9Gooooo001nooooo`03oeEEEOmgMgOoA4A400Kooooo
00?o0000ooooooooool00_ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMg@;ooooo00?oc<c<o`00
0?l@41001Oooool01Ol@413o^[Zjonk^k_mgMgOo410@00?ooooo00?o0000ooooooooool01?ooool0
0oo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000?ooooo00?o
V9RHoa0@4?oMgMd0U?ooool007gooooo00GogMgMoa0@4?oooooo8B4QomgMg@05ooooo`03o`000?oo
oooooooo00?ooooo00CogMgMo`000?l@413oc<c<2oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool05Oooool00on7QhOoEEEEooooo`2Cooooo`00OOoo
ool01OmVIVKoQhN7oooooonHV9SoEEEE00Gooooo00?o0000ooooooooool00oooool01?o^k^ko8B4Q
oa0@4?o^k^h;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0;ooooo`Ko000000Koooooolc<c?lQ8B7o0000oeEEEOl0002Dooooo`00O?ooool00oo^
k^ko0000onk^kP02ooooo`03o`000?oMgMgooooo00?ooooo00?o0000ooooooooool00oooool01?lQ
8B7oMgMgogMgMolb<S8;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`0Booooo`05ob4Q8On7QhOooooooiRHV?l00000U?ooool007cooooo00Co410@
o`000?l0003ooooo0_l000000ol@413oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo0_l0
0002ooooo`;o00002?ooool00ol@413o0000o`000003o`0000Cooooo00?o0000ooooooooool04Ooo
ool00ol@413o0000o`000003o`00017ooooo00Go0000ooooooooooooooooo`00002Dooooo`00Qooo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0Booooo`05ob4Q8OnHV9SoooooogMgMomEEED0U?ooool008Oooooo0_l0
000Cooooo`03o`000?oooooooooo00Cooooo0_l0000Eooooo`03o`000?oooooooooo01;ooooo00Go
c<c<oa0@4?l0003o<S8bonk^kP2Dooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-3.4116, -0.234311, \
0.0510397, 0.00762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.230769 0.0769231 0.103006 0.515028 [
[.07692 .09051 -6 -9 ]
[.07692 .09051 6 0 ]
[.38462 .09051 -3 -9 ]
[.38462 .09051 3 0 ]
[.53846 .09051 -3 -9 ]
[.53846 .09051 3 0 ]
[.69231 .09051 -3 -9 ]
[.69231 .09051 3 0 ]
[.84615 .09051 -3 -9 ]
[.84615 .09051 3 0 ]
[1 .09051 -6 -9 ]
[1 .09051 6 0 ]
[1.025 .10301 0 -6 ]
[1.025 .10301 10 6 ]
[.21827 0 -24 -4.5 ]
[.21827 0 0 4.5 ]
[.21827 .20601 -18 -4.5 ]
[.21827 .20601 0 4.5 ]
[.21827 .30902 -18 -4.5 ]
[.21827 .30902 0 4.5 ]
[.21827 .41202 -18 -4.5 ]
[.21827 .41202 0 4.5 ]
[.21827 .51503 -18 -4.5 ]
[.21827 .51503 0 4.5 ]
[.21827 .61803 -6 -4.5 ]
[.21827 .61803 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07692 .10301 m
.07692 .10926 L
s
[(-2)] .07692 .09051 0 1 Mshowa
.38462 .10301 m
.38462 .10926 L
s
[(2)] .38462 .09051 0 1 Mshowa
.53846 .10301 m
.53846 .10926 L
s
[(4)] .53846 .09051 0 1 Mshowa
.69231 .10301 m
.69231 .10926 L
s
[(6)] .69231 .09051 0 1 Mshowa
.84615 .10301 m
.84615 .10926 L
s
[(8)] .84615 .09051 0 1 Mshowa
1 .10301 m
1 .10926 L
s
[(10)] 1 .09051 0 1 Mshowa
.125 Mabswid
.11538 .10301 m
.11538 .10676 L
s
.15385 .10301 m
.15385 .10676 L
s
.19231 .10301 m
.19231 .10676 L
s
.26923 .10301 m
.26923 .10676 L
s
.30769 .10301 m
.30769 .10676 L
s
.34615 .10301 m
.34615 .10676 L
s
.42308 .10301 m
.42308 .10676 L
s
.46154 .10301 m
.46154 .10676 L
s
.5 .10301 m
.5 .10676 L
s
.57692 .10301 m
.57692 .10676 L
s
.61538 .10301 m
.61538 .10676 L
s
.65385 .10301 m
.65385 .10676 L
s
.73077 .10301 m
.73077 .10676 L
s
.76923 .10301 m
.76923 .10676 L
s
.80769 .10301 m
.80769 .10676 L
s
.88462 .10301 m
.88462 .10676 L
s
.92308 .10301 m
.92308 .10676 L
s
.96154 .10301 m
.96154 .10676 L
s
.03846 .10301 m
.03846 .10676 L
s
.25 Mabswid
0 .10301 m
1 .10301 L
s
gsave
1.025 .10301 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.23077 0 m
.23702 0 L
s
[(-0.2)] .21827 0 1 0 Mshowa
.23077 .20601 m
.23702 .20601 L
s
[(0.2)] .21827 .20601 1 0 Mshowa
.23077 .30902 m
.23702 .30902 L
s
[(0.4)] .21827 .30902 1 0 Mshowa
.23077 .41202 m
.23702 .41202 L
s
[(0.6)] .21827 .41202 1 0 Mshowa
.23077 .51503 m
.23702 .51503 L
s
[(0.8)] .21827 .51503 1 0 Mshowa
.23077 .61803 m
.23702 .61803 L
s
[(1)] .21827 .61803 1 0 Mshowa
.125 Mabswid
.23077 .02575 m
.23452 .02575 L
s
.23077 .0515 m
.23452 .0515 L
s
.23077 .07725 m
.23452 .07725 L
s
.23077 .12876 m
.23452 .12876 L
s
.23077 .15451 m
.23452 .15451 L
s
.23077 .18026 m
.23452 .18026 L
s
.23077 .23176 m
.23452 .23176 L
s
.23077 .25751 m
.23452 .25751 L
s
.23077 .28327 m
.23452 .28327 L
s
.23077 .33477 m
.23452 .33477 L
s
.23077 .36052 m
.23452 .36052 L
s
.23077 .38627 m
.23452 .38627 L
s
.23077 .43777 m
.23452 .43777 L
s
.23077 .46353 m
.23452 .46353 L
s
.23077 .48928 m
.23452 .48928 L
s
.23077 .54078 m
.23452 .54078 L
s
.23077 .56653 m
.23452 .56653 L
s
.23077 .59228 m
.23452 .59228 L
s
.25 Mabswid
.23077 0 m
.23077 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
123.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(10) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.51271 .10301 m
.51274 .10301 L
.51456 .10301 L
.51624 .10301 L
.51808 .10301 L
.51901 .10301 L
.52003 .10301 L
.52193 .10301 L
.52301 .10301 L
.52401 .10301 L
.52584 .10301 L
.52676 .10301 L
.52778 .10301 L
.52954 .10301 L
.53143 .10301 L
.53322 .10301 L
.53486 .10301 L
.53677 .10301 L
.53855 .10301 L
.53958 .10301 L
.54051 .10301 L
.54158 .10301 L
.5426 .10301 L
.54359 .10301 L
.54463 .10301 L
.54651 .10301 L
.54756 .10301 L
.54853 .10301 L
.5496 .10301 L
.55075 .10301 L
.55266 .10301 L
.55443 .10301 L
.55545 .10301 L
.55637 .10301 L
.55744 .10301 L
.55844 .10301 L
.56027 .10301 L
.56195 .10301 L
.5638 .10301 L
.56472 .10302 L
.56574 .10303 L
.56753 .10306 L
.56917 .10312 L
.57105 .10325 L
.57283 .1035 L
.57448 .10389 L
.576 .10447 L
.57767 .10545 L
.57944 .10706 L
.5811 .10929 L
Mistroke
.58292 .11279 L
.58481 .11792 L
.58657 .12437 L
.58973 .14075 L
.5915 .15292 L
.5931 .1659 L
.60016 .24137 L
.60388 .28648 L
.6078 .32976 L
.60944 .34479 L
.6112 .35821 L
.61221 .3645 L
.61313 .36927 L
.61493 .37586 L
.61654 .37859 L
.6183 .37819 L
.61996 .37473 L
.62149 .36906 L
.62303 .36125 L
.62446 .35222 L
.62775 .3268 L
.6344 .26524 L
.64179 .20124 L
.64867 .15768 L
.65214 .14214 L
.65585 .12967 L
.65796 .12418 L
.65996 .11991 L
.66174 .11675 L
.66371 .11389 L
.66696 .11029 L
.66874 .10881 L
.67041 .10768 L
.6734 .10614 L
.67507 .1055 L
.6766 .10502 L
.67827 .1046 L
.68004 .10424 L
.68198 .10394 L
.68378 .10372 L
.68562 .10355 L
.68736 .10342 L
.68891 .10333 L
.6906 .10326 L
.6924 .1032 L
.69405 .10315 L
.69595 .10311 L
.69775 .10309 L
.69942 .10307 L
.70095 .10305 L
Mistroke
.70264 .10304 L
.70443 .10303 L
.70622 .10302 L
.70815 .10302 L
.70998 .10302 L
.71165 .10301 L
.7135 .10301 L
.71553 .10301 L
.71655 .10301 L
.71764 .10301 L
.71961 .10301 L
.72061 .10301 L
.72167 .10301 L
.72357 .10301 L
.72463 .10301 L
.72562 .10301 L
.72677 .10301 L
.72787 .10301 L
.72881 .10301 L
.72983 .10301 L
.73162 .10301 L
.73264 .10301 L
.73372 .10301 L
.73473 .10301 L
.73566 .10301 L
.73756 .10301 L
.73855 .10301 L
.7396 .10301 L
.74137 .10301 L
.74238 .10301 L
.74331 .10301 L
.74506 .10301 L
.74666 .10301 L
.7485 .10301 L
.75024 .10301 L
.75191 .10301 L
.7537 .10301 L
.75539 .10301 L
.75694 .10301 L
.75875 .10301 L
.75977 .10301 L
.76073 .10301 L
.76247 .10301 L
.76433 .10301 L
.76533 .10301 L
.76626 .10301 L
.76726 .10301 L
.76836 .10301 L
.77021 .10301 L
.77122 .10301 L
Mistroke
.77216 .10301 L
.77395 .10301 L
.77559 .10301 L
.77748 .10301 L
.77926 .10301 L
.7808 .10301 L
.7825 .10301 L
.78427 .10301 L
.78593 .10301 L
.78748 .10301 L
.7889 .10301 L
.79046 .10301 L
.7921 .10301 L
.79377 .10301 L
.79556 .10301 L
.79724 .10301 L
.79877 .10301 L
.80057 .10301 L
.80159 .10301 L
.80252 .10301 L
.80425 .10301 L
.80607 .10301 L
.80783 .10301 L
.80974 .10301 L
.81155 .10301 L
.81323 .10301 L
.8149 .10301 L
.8164 .10301 L
.81814 .10301 L
.81978 .10301 L
.82157 .10301 L
.82347 .10301 L
.82509 .10301 L
.82686 .10301 L
.82877 .10301 L
.82984 .10301 L
.83082 .10301 L
.83272 .10301 L
.83451 .10301 L
.83604 .10301 L
.83773 .10301 L
.83949 .10301 L
.84114 .10301 L
.84268 .10301 L
.84409 .10301 L
.84564 .10301 L
.84727 .10301 L
.84893 .10301 L
.8507 .10301 L
.85238 .10301 L
Mistroke
.85389 .10301 L
.85568 .10301 L
.85669 .10301 L
.85762 .10301 L
.85933 .10301 L
.86113 .10301 L
.8629 .10301 L
.86482 .10301 L
.86664 .10301 L
.86832 .10301 L
.86983 .10301 L
.8715 .10301 L
.87324 .10301 L
.87488 .10301 L
.87668 .10301 L
.87858 .10301 L
.8802 .10301 L
.88198 .10301 L
.88389 .10301 L
.88497 .10301 L
.88594 .10301 L
.88784 .10301 L
.88963 .10301 L
.89117 .10301 L
.89286 .10301 L
.89462 .10301 L
.89628 .10301 L
.89782 .10301 L
.89923 .10301 L
.90086 .10301 L
.90241 .10301 L
.90407 .10301 L
.90585 .10301 L
.90752 .10301 L
.90904 .10301 L
.91083 .10301 L
.91184 .10301 L
.91276 .10301 L
.91447 .10301 L
.91627 .10301 L
.91805 .10301 L
.91905 .10301 L
.91998 .10301 L
.92168 .10301 L
.92348 .10301 L
.9251 .10301 L
.92661 .10301 L
.92827 .10301 L
.93006 .10301 L
.93185 .10301 L
Mistroke
.93287 .10301 L
.93381 .10301 L
.93572 .10301 L
.93679 .10301 L
.93777 .10301 L
.93951 .10301 L
.9414 .10301 L
.94319 .10301 L
.94483 .10301 L
.94637 .10301 L
.94802 .10301 L
.94958 .10301 L
.951 .10301 L
.95266 .10301 L
.95448 .10301 L
.95619 .10301 L
.95778 .10301 L
.95958 .10301 L
.96127 .10301 L
.96278 .10301 L
.96442 .10301 L
.96621 .10301 L
.96811 .10301 L
.96972 .10301 L
.97149 .10301 L
.9734 .10301 L
.97516 .10301 L
.97607 .10301 L
.97709 .10301 L
.97815 .10301 L
.97914 .10301 L
.98096 .10301 L
.98262 .10301 L
.98454 .10301 L
.98637 .10301 L
.98799 .10301 L
.98973 .10301 L
.99136 .10301 L
.99285 .10301 L
.99459 .10301 L
.99649 .10301 L
.99827 .10301 L
.99992 .10301 L
Mfstroke
.99992 .10301 m
1 .10301 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000oooooolLooooo`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0oooooolLooooo`00<?ooool6o`0000;o
oooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^0?oooooo7Oooool003So
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003ooooo
oa?ooooo000hooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05oooo
o`03o`000?oooooooooo0?oooooo4oooool003Sooooo00Go410@oooooooooooooooooa0@400?oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooo
oooo0?oooooo4oooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooo
oooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003ooooooooo
o`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000oooo
ooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`00
0?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool0
0ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o
0000ooooooooool0oooooolCooooo`008oooool5o`0002_ooooo00?o0000ooooooooool0:oooool5
o`0002kooooo0_l000000ol@413oooooooooo`0Zooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?oo
ool01Oo<c<co8B4Qo`000?lQ8B7oc<c<02Wooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`00
0?lb<S;ok^k^6_ooool002?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00[ooooo`03o`000?oooooo
oooo02_ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00_ooooo`03o`000?oooooooooo02_ooooo00Go
EEEEogMgMoooooooV9RHob4Q8@0/ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40:oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool001_ooooo1_l00003ooooo`03
oiRHV?lQ8B7ok^k^02cooooo00?o0000ooooooooool0;?ooool00onHV9So8B4Qonk^kP0]ooooo`Go
0000;?ooool01Ol0003ooooooooooooooooo000002cooooo00Go0000ooooooooooooooooo`00000[
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Jooooo`009Oooool0
0onHV9So8B4Qonk^kP0[ooooo`03o`000?oooooooooo02gooooo00?oV9RHob4Q8Oo^k^h0;?ooool0
1?m4A4CogMgMooooool0000]ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;?ooool01Olb<S;oV9RH
oooooonHV9So<S8b02_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
01[ooooo000Vooooo`03ogMgMomVIVKooooo02[ooooo0_l0000_ooooo`03ogMgMomVIVKooooo02_o
oooo00CogMgMoeEEEOoooooo0000;Oooool01Ol0003oEEEEo`000?l@413oc<c<02cooooo00Goc<c<
o`000?l0003o0000olc<c00[ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Jooooo`009oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool0:oooool00omgMgOoc<c<o`00000]ooooo`03oeEEEOn7QhOooooo02kooooo00Go
410@okZj^_oooooo^[Zjoa0@400[ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@400Jooooo`008oooool01Ol0003o^[ZjoooooonHV9So410@02_ooooo00?o0000oooooooo
ool0:oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo00?ok^k^odA4A?l00000;Oooool00ooM
gMgo410@oiRHV00^ooooo`05o`000?nj^[[ooooookZj^_l00000:oooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool002?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00[ooooo`03o`000?oooooooooo02_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00^ooooo`03ogMg
Mol0003ooooo02gooooo00Coc<c<odA4A?l0003o410@;?ooool01OnYZJWo410@o`000?l@413oZJVY
02Wooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo001Coooo
o`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00
Doooool00ol0003oooooooooo`3mooooo`;o00000_ooool2o`0000oooooo001Cooooo`03o`000?oo
oooooooo0?gooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd?ooooo`00Doooool00ol0003ooooo
ooooo`1Gooooo`03o`000?oooooooooo0:Cooooo00CogMgMo`000?l@413oc<c<4?ooool000[ooooo
ool00010o`0000_ooooo00Cok^k^ob4Q8Ol@413ok^k^4?ooool001Kooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`;o00002oooool00ol0003oooooooooo`09ooooo`04o`00
0?ooooooooooooooo`?o00001Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02Oooool01?lQ8B7oMgMgogMgMolb<S8@ooooo`008_ooool00ol0003o
ooooooooo`0^ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0;_ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0^ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool02?ooool2o`0000;o
oooo0_l0000?ooooo`00Doooool00ol0003oooooooooo`1]ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool0R?ooool005?ooooo00?o0000ooooooooool0K_ooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo08Wooooo001Cooooo`03o`000?oooooooooo06kooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`29ooooo`00Doooool00ol0003oooooooooo`1^oooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0R_ooool005?ooooo00?o0000oooooooo
ool0K_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo08[ooooo001Cooooo`;o0000
Koooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo08_ooooo001Cooooo`03o`000?oo
oooooooo06kooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`2;ooooo`00Doooool0
0ol0003oooooooooo`1_ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0Roooool0
05?ooooo00?o0000ooooooooool0Koooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
08cooooo001Cooooo`03o`000?oooooooooo06oooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`2<ooooo`00Doooool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool0S?ooool005?ooooo00?o0000ooooooooool0L?ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo08cooooo001Cooooo`03o`000?oooooooooo073ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`2=ooooo`00Doooool2o`00077ooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`2=ooooo`00Doooool00ol0003oooooooooo`1`ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0SOooool005?ooooo00?o0000ooooooooool0
L?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo08gooooo001Cooooo`03o`000?oo
oooooooo073ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`2=ooooo`00Doooool0
0ol0003oooooooooo`1`ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0SOooool0
05?ooooo00?o0000ooooooooool0L?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
08kooooo001Cooooo`03o`000?oooooooooo073ooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`2>ooooo`00Doooool00ol0003oooooooooo`1`ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool0S_ooool005?ooooo0_l0001aooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool0S_ooool005?ooooo00?o0000ooooooooool0LOooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo08kooooo001Cooooo`03o`000?oooooooooo077ooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`2>ooooo`00Doooool00ol0003oooooooooo`1aooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool0S_ooool005?ooooo00?o0000ooooooooool0
LOooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo08oooooo001Cooooo`03o`000?oo
oooooooo077ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`2?ooooo`00>?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001_ooool00ol0003ooooooooo
o`1aooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0Soooool003Sooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo
00?o0000ooooooooool0LOooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo08oooooo
000hooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP07ooooo`?o0000
LOooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo08oooooo000hooooo`05o`000?oo
ooooooooooooool000003Oooool00onHV9So8B4Qonk^kP06ooooo`03o`000?oooooooooo07;ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`2?ooooo`00>?ooool01Ol0003ooooooooo
oooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`1booooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool0Soooool003Sooooo00Go410@oooooooooooooooo
oa0@400?ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0L_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo08oooooo000hooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0L_ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo08oooooo000hooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0L_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo093ooooo001Cooooo`03o`000?oooooooooo07;o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`2@ooooo`00Doooool00ol0003ooooo
ooooo`1booooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0T?ooool005?ooooo00?o
0000ooooooooool0L_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo093ooooo001C
ooooo`;o0000M?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo093ooooo001Coooo
o`03o`000?oooooooooo07?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2@oooo
o`00Doooool00ol0003oooooooooo`1cooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool0T?ooool005?ooooo00?o0000ooooooooool0Loooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo093ooooo001Cooooo`03o`000?oooooooooo07?ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`2@ooooo`00Doooool00ol0003oooooooooo`1cooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool0T?ooool005?ooooo00?o0000ooooooooool0Loooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo097ooooo001Cooooo`03o`000?oooooooooo07?o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2Aooooo`00Doooool2o`0007Cooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`2Aooooo`00Doooool00ol0003ooooooooo
o`1cooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0TOooool005?ooooo00?o0000
ooooooooool0Loooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo097ooooo001Coooo
o`03o`000?oooooooooo07Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2Aoooo
o`00Doooool00ol0003oooooooooo`1dooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0TOooool005?ooooo00?o0000ooooooooool0M?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo097ooooo001Cooooo`03o`000?oooooooooo07Cooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`2Booooo`00Doooool00ol0003oooooooooo`1dooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0T_ooool005?ooooo0_l0001eooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0T_ooool005?ooooo00?o0000ooooooooool0M?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo09;ooooo001Cooooo`03o`000?oooooooooo07Cooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`2Booooo`00Doooool00ol0003ooooooooo
o`1dooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0T_ooool005?ooooo00?o0000
ooooooooool0M?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo09;ooooo001Coooo
o`03o`000?oooooooooo07Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2Coooo
o`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@oooo
ooooool01?ooool00ol0003oooooooooo`1dooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0Toooool003Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo07Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`2Cooooo`00>?ooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00006oooo
o`?o0000M?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo09?ooooo000hooooo`05
o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool00007ooooo`03o`000?oooooo
oooo07Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2Cooooo`00>?ooool01Ol0
003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003ooooooooo
o`1eooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Toooool003Sooooo00Go410@
oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0MOoo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo09?ooooo000hooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo07Gooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`2Dooooo`00>?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00gooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`1eooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0U?ooool005?ooooo00?o0000ooooooooool0MOooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo09Cooooo001Cooooo`03o`000?oooooooooo
07Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2Dooooo`00Doooool2o`0007Ko
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2Dooooo`00Doooool00ol0003ooooo
ooooo`1eooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0U?ooool005?ooooo00?o
0000ooooooooool0M_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo09Cooooo001C
ooooo`03o`000?oooooooooo07Kooooo00Go0000ooooooooooooooooo`00002Gooooo`00Doooool0
0ol0003oooooooooo`1fooooo`05o`000?ooooooooooooooool00000Uoooool005?ooooo00?o0000
ooooooooool0M_ooool01Ol0003ooooooooooooooooo000009Oooooo001Cooooo`03o`000?oooooo
oooo07Kooooo00Go0000ooooooooooooooooo`00002Gooooo`00Doooool00ol0003oooooooooo`1f
ooooo`05o`000?ooooooooooooooool00000Uoooool005?ooooo00?o0000ooooooooool0M_ooool0
1Ol0003ooooooooooooooooo000009Oooooo001Cooooo`;o0000Moooool01Ol0003ooooooooooooo
oooo000009Oooooo001Cooooo`03o`000?oooooooooo07Kooooo00Go0000ooooooooooooooooo`00
002Gooooo`00Doooool00ol0003oooooooooo`1gooooo`03o`000?oooooo000009Sooooo001Coooo
o`03o`000?oooooooooo07Oooooo00?o0000ooooool00000V?ooool005?ooooo00?o0000oooooooo
ool0Moooool00ol0003oooooo`00002Hooooo`00Doooool00ol0003oooooooooo`1hooooo`03o`00
0?oooooooooo09Oooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000
ooooooooool0oooooolCooooo`00Doooool2o`000?oooooo5?ooool005?ooooo00?o0000oooooooo
ool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oo
oooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_oo
ool00ol0003oooooooooo`3ooooooa?ooooo000hooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Ooo
ool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?oooooo
4oooool003Sooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool0
00001_ooool00ol0003oooooooooo`3ooooooa?ooooo000hooooo`05o`000?ooooooooooooooool0
00002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0003ooooooa?ooooo000hooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000
ooooooooool0oooooolCooooo`00>?ooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEE
ohN7Qoooool02?ooool00ol0003oooooooooo`3ooooooa?ooooo000hooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo0?oooooo4oooool0
03Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o
0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Coooo
o`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00
Doooool2o`000?oooooo5?ooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool0
0ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?o
oooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo
001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolC
ooooo`00Doooool2o`000?oooooo5?ooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00
Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4ooo
ool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooo
oa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0
oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolD
ooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oo
oooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003ooooooooo
o`3ooooooa?ooooo000hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Go
c<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0?oooooo4oooool003Sooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Ko
oooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01Ol@413ooooooooooooooooo410@00_o
oooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo4oooool003So
oooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3
o`000?oooooo4oooool003Sooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o
0000o`000?o<c<`01_ooool00ol0003oooooooooo`3ooooooa?ooooo000hooooo`05oa0@4?oooooo
ooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0
oooooolCooooo`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo
^[Zjo`000006ooooo`03o`000?oooooooooo0?oooooo4oooool003Sooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3ooooo
oa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0
oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolD
ooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oo
oooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003ooooooooo
o`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000oooo
ooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000
oooooolDooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooo
oooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o
0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Coooo
o`;o0000oooooolDooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`00
0?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool0
0ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool004Wo
oooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo4oooool004_ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooooa?ooooo001;ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0oooooolCooooo`00Boooool00ol0003oooooooooo`05
ooooo`?o0000oooooolCooooo`00Boooool00ol0003oooooooooo`3ooooooa_ooooo001;ooooo`03
o`000?oooooooooo0?oooooo6oooool004_ooooo00?o0000ooooooooool0oooooolKooooo`00BOoo
ool00omEEEGoIVIVo`00003ooooooagooooo001hooooo`?o000000?o410@ooooooooool0j_ooool0
07[ooooo00?o410@okZj^_ooool01oooool2o`0000_ooooo00?o0000okZj^_ooool03?ooool2o`00
00Gooooo00?o0000okZj^_ooool0__ooool007[ooooo00?oV9RHoc8b<_ooool01oooool00ol0003o
ooooooooo`0:ooooo`;o<S8b3_ooool00ol0003oooooooooo`03ooooo`;o<S8b_oooool007[ooooo
00?ogMgMo`000?nj^[X01oooool01?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`03
ohN7Qol0003o^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4okZj^P04ooooo`03o`000?oooooooooo
00?ooooo00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj01;ooooo1?l00000
2?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^Soooool007[ooooo00?oEEEEogMgMom4A4@0
1oooool02_l0003oooooooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oMgMd3ooooo`03olc<c?l0
003o410@00Cooooo00Go410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oooooooooo00?ooooo
00?oc<c<o`000?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l00005ooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`2?ooooo`00NOooool01OoMgMgo
410@oooooolQ8B7ogMgM00Kooooo00?o0000ooooooooool00_ooool01?oMgMgo0000oa0@4?o<c<`;
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@402?ooooo`00NOooool0
1OmVIVKoQhN7oooooonHV9SoEEEE00Kooooo00?o0000ooooooooool00_ooool01?o^k^ko8B4Qoa0@
4?o^k^h;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0;ooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
0000Soooool007Sooooo00?ok^k^o`000?o^k^h00_ooool00ol0003ogMgMooooo`04ooooo`03o`00
0?oooooooooo00;ooooo00Co8B4QogMgMomgMgOo<S8b2oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool00000Soooool007Sooooo00Co410@o`000?l0003ooooo0_l000000ol@
413oooooooooo`03ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000Sooooo00?o410@
o`000?l000000ol00005ooooo`03o`000?oooooooooo013ooooo00?o410@o`000?l000000ol0000E
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@402?ooooo`00Q?ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`2?ooooo`00Q?ooool2o`0001;ooooo00?o0000ooooooooool01Oooool2o`0001Cooooo00?o0000
ooooooooool05?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0Sooo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-3.4116, -0.234311, \
0.0510397, 0.00762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.230769 0.0769231 0.103006 0.515028 [
[.07692 .09051 -6 -9 ]
[.07692 .09051 6 0 ]
[.38462 .09051 -3 -9 ]
[.38462 .09051 3 0 ]
[.53846 .09051 -3 -9 ]
[.53846 .09051 3 0 ]
[.69231 .09051 -3 -9 ]
[.69231 .09051 3 0 ]
[.84615 .09051 -3 -9 ]
[.84615 .09051 3 0 ]
[1 .09051 -6 -9 ]
[1 .09051 6 0 ]
[1.025 .10301 0 -6 ]
[1.025 .10301 10 6 ]
[.21827 0 -24 -4.5 ]
[.21827 0 0 4.5 ]
[.21827 .20601 -18 -4.5 ]
[.21827 .20601 0 4.5 ]
[.21827 .30902 -18 -4.5 ]
[.21827 .30902 0 4.5 ]
[.21827 .41202 -18 -4.5 ]
[.21827 .41202 0 4.5 ]
[.21827 .51503 -18 -4.5 ]
[.21827 .51503 0 4.5 ]
[.21827 .61803 -6 -4.5 ]
[.21827 .61803 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07692 .10301 m
.07692 .10926 L
s
[(-2)] .07692 .09051 0 1 Mshowa
.38462 .10301 m
.38462 .10926 L
s
[(2)] .38462 .09051 0 1 Mshowa
.53846 .10301 m
.53846 .10926 L
s
[(4)] .53846 .09051 0 1 Mshowa
.69231 .10301 m
.69231 .10926 L
s
[(6)] .69231 .09051 0 1 Mshowa
.84615 .10301 m
.84615 .10926 L
s
[(8)] .84615 .09051 0 1 Mshowa
1 .10301 m
1 .10926 L
s
[(10)] 1 .09051 0 1 Mshowa
.125 Mabswid
.11538 .10301 m
.11538 .10676 L
s
.15385 .10301 m
.15385 .10676 L
s
.19231 .10301 m
.19231 .10676 L
s
.26923 .10301 m
.26923 .10676 L
s
.30769 .10301 m
.30769 .10676 L
s
.34615 .10301 m
.34615 .10676 L
s
.42308 .10301 m
.42308 .10676 L
s
.46154 .10301 m
.46154 .10676 L
s
.5 .10301 m
.5 .10676 L
s
.57692 .10301 m
.57692 .10676 L
s
.61538 .10301 m
.61538 .10676 L
s
.65385 .10301 m
.65385 .10676 L
s
.73077 .10301 m
.73077 .10676 L
s
.76923 .10301 m
.76923 .10676 L
s
.80769 .10301 m
.80769 .10676 L
s
.88462 .10301 m
.88462 .10676 L
s
.92308 .10301 m
.92308 .10676 L
s
.96154 .10301 m
.96154 .10676 L
s
.03846 .10301 m
.03846 .10676 L
s
.25 Mabswid
0 .10301 m
1 .10301 L
s
gsave
1.025 .10301 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.23077 0 m
.23702 0 L
s
[(-0.2)] .21827 0 1 0 Mshowa
.23077 .20601 m
.23702 .20601 L
s
[(0.2)] .21827 .20601 1 0 Mshowa
.23077 .30902 m
.23702 .30902 L
s
[(0.4)] .21827 .30902 1 0 Mshowa
.23077 .41202 m
.23702 .41202 L
s
[(0.6)] .21827 .41202 1 0 Mshowa
.23077 .51503 m
.23702 .51503 L
s
[(0.8)] .21827 .51503 1 0 Mshowa
.23077 .61803 m
.23702 .61803 L
s
[(1)] .21827 .61803 1 0 Mshowa
.125 Mabswid
.23077 .02575 m
.23452 .02575 L
s
.23077 .0515 m
.23452 .0515 L
s
.23077 .07725 m
.23452 .07725 L
s
.23077 .12876 m
.23452 .12876 L
s
.23077 .15451 m
.23452 .15451 L
s
.23077 .18026 m
.23452 .18026 L
s
.23077 .23176 m
.23452 .23176 L
s
.23077 .25751 m
.23452 .25751 L
s
.23077 .28327 m
.23452 .28327 L
s
.23077 .33477 m
.23452 .33477 L
s
.23077 .36052 m
.23452 .36052 L
s
.23077 .38627 m
.23452 .38627 L
s
.23077 .43777 m
.23452 .43777 L
s
.23077 .46353 m
.23452 .46353 L
s
.23077 .48928 m
.23452 .48928 L
s
.23077 .54078 m
.23452 .54078 L
s
.23077 .56653 m
.23452 .56653 L
s
.23077 .59228 m
.23452 .59228 L
s
.25 Mabswid
.23077 0 m
.23077 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
123.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(11) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.54311 .10301 m
.54491 .10301 L
.54653 .10301 L
.5483 .10301 L
.54931 .10301 L
.55041 .10301 L
.55144 .10301 L
.5524 .10301 L
.55421 .10301 L
.55611 .10301 L
.55711 .10301 L
.55817 .10301 L
.56009 .10301 L
.56126 .10301 L
.56237 .10301 L
.56336 .10301 L
.56445 .10301 L
.56624 .10301 L
.56726 .10301 L
.56822 .10301 L
.56923 .10301 L
.57015 .10301 L
.57117 .10301 L
.57223 .10301 L
.57402 .10301 L
.57568 .10301 L
.5775 .10301 L
.57851 .10301 L
.57944 .10301 L
.58114 .10301 L
.58301 .10301 L
.58395 .10301 L
.58496 .10301 L
.58679 .10301 L
.5886 .10301 L
.59033 .10302 L
.59187 .10305 L
.59356 .1031 L
.5946 .10317 L
.59558 .10325 L
.59741 .10353 L
.59843 .10378 L
.59938 .1041 L
.60041 .10458 L
.6015 .10527 L
.60332 .10697 L
.60502 .10942 L
.60688 .11339 L
.60792 .11635 L
.60887 .11957 L
Mistroke
.61059 .1269 L
.61242 .13699 L
.61571 .16169 L
.61925 .19747 L
.62314 .24472 L
.6296 .32182 L
.63137 .33848 L
.63325 .3527 L
.63503 .3623 L
.63665 .36757 L
.63842 .36952 L
.64034 .36723 L
.64215 .36116 L
.64382 .35259 L
.64749 .32584 L
.65136 .2902 L
.65786 .2279 L
.66483 .17351 L
.66874 .15144 L
.67231 .13633 L
.67589 .12526 L
.67929 .11782 L
.6812 .11467 L
.68324 .11199 L
.685 .11013 L
.6869 .10852 L
.68892 .10717 L
.69083 .10619 L
.6931 .1053 L
.69517 .10469 L
.69703 .10428 L
.69878 .10398 L
.70035 .10377 L
.70205 .10359 L
.70391 .10344 L
.70587 .10332 L
.70755 .10324 L
.7094 .10318 L
.71113 .10314 L
.7127 .10311 L
.71452 .10308 L
.71625 .10306 L
.71784 .10305 L
.71931 .10304 L
.72093 .10303 L
.72265 .10302 L
.72469 .10302 L
.72656 .10301 L
.72754 .10301 L
.72861 .10301 L
Mistroke
.72975 .10301 L
.73078 .10301 L
.73269 .10301 L
.73374 .10301 L
.73474 .10301 L
.73651 .10301 L
.73751 .10301 L
.73843 .10301 L
.74014 .10301 L
.74173 .10301 L
.74348 .10301 L
.74537 .10301 L
.74724 .10301 L
.74818 .10301 L
.74921 .10301 L
.75104 .10301 L
.75273 .10301 L
.75459 .10301 L
.75553 .10301 L
.75656 .10301 L
.75838 .10301 L
.76009 .10301 L
.76112 .10301 L
.76209 .10301 L
.76393 .10301 L
.76495 .10301 L
.7659 .10301 L
.76693 .10301 L
.76805 .10301 L
.76994 .10301 L
.77172 .10301 L
.77346 .10301 L
.77505 .10301 L
.77678 .10301 L
.77868 .10301 L
.77963 .10301 L
.78065 .10301 L
.7825 .10301 L
.78431 .10301 L
.78599 .10301 L
.78782 .10301 L
.78875 .10301 L
.78977 .10301 L
.79148 .10301 L
.79332 .10301 L
.79506 .10301 L
.79665 .10301 L
.79829 .10301 L
.79981 .10301 L
.80147 .10301 L
Mistroke
.80325 .10301 L
.80495 .10301 L
.80654 .10301 L
.80798 .10301 L
.80953 .10301 L
.81133 .10301 L
.81298 .10301 L
.81487 .10301 L
.81667 .10301 L
.81833 .10301 L
.81986 .10301 L
.82155 .10301 L
.82334 .10301 L
.82513 .10301 L
.82613 .10301 L
.82706 .10301 L
.82876 .10301 L
.83055 .10301 L
.8315 .10301 L
.83251 .10301 L
.83435 .10301 L
.83547 .10301 L
.83652 .10301 L
.83747 .10301 L
.8385 .10301 L
.84041 .10301 L
.84219 .10301 L
.84321 .10301 L
.84414 .10301 L
.84522 .10301 L
.84624 .10301 L
.84722 .10301 L
.84827 .10301 L
.85016 .10301 L
.85131 .10301 L
.8524 .10301 L
.85338 .10301 L
.85443 .10301 L
.85621 .10301 L
.85722 .10301 L
.85816 .10301 L
.86006 .10301 L
.86112 .10301 L
.86209 .10301 L
.86382 .10301 L
.8657 .10301 L
.86748 .10301 L
.86912 .10301 L
.87084 .10301 L
.87265 .10301 L
Mistroke
.87419 .10301 L
.87588 .10301 L
.8777 .10301 L
.87872 .10301 L
.87965 .10301 L
.88145 .10301 L
.88315 .10301 L
.88475 .10301 L
.88644 .10301 L
.88788 .10301 L
.88946 .10301 L
.89117 .10301 L
.893 .10301 L
.89472 .10301 L
.8963 .10301 L
.89815 .10301 L
.89909 .10301 L
.90012 .10301 L
.90195 .10301 L
.90366 .10301 L
.90464 .10301 L
.90567 .10301 L
.90752 .10301 L
.90855 .10301 L
.90951 .10301 L
.91056 .10301 L
.91168 .10301 L
.91357 .10301 L
.91463 .10301 L
.91561 .10301 L
.91741 .10301 L
.91932 .10301 L
.92103 .10301 L
.92263 .10301 L
.92438 .10301 L
.92627 .10301 L
.92727 .10301 L
.9282 .10301 L
.92996 .10301 L
.93185 .10301 L
.93291 .10301 L
.93389 .10301 L
.93553 .10301 L
.93733 .10301 L
.93921 .10301 L
.94097 .10301 L
.94196 .10301 L
.94305 .10301 L
.94407 .10301 L
.94502 .10301 L
Mistroke
.94681 .10301 L
.94871 .10301 L
.94969 .10301 L
.95074 .10301 L
.95265 .10301 L
.95376 .10301 L
.95492 .10301 L
.95592 .10301 L
.957 .10301 L
.95795 .10301 L
.95898 .10301 L
.96084 .10301 L
.96265 .10301 L
.96432 .10301 L
.96613 .10301 L
.96716 .10301 L
.96812 .10301 L
.96913 .10301 L
.97006 .10301 L
.97112 .10301 L
.97214 .10301 L
.97383 .10301 L
.97563 .10301 L
.97733 .10301 L
.97887 .10301 L
.98069 .10301 L
.98172 .10301 L
.98266 .10301 L
.98439 .10301 L
.98621 .10301 L
.988 .10301 L
.989 .10301 L
.98993 .10301 L
.99164 .10301 L
.99345 .10301 L
.99507 .10301 L
.99658 .10301 L
.99825 .10301 L
Mfstroke
.99825 .10301 m
1 .10301 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000oooooolLooooo`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0oooooolLooooo`00<?ooool6o`0000;o
oooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^0?oooooo7Oooool003So
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003ooooo
oa?ooooo000hooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05oooo
o`03o`000?oooooooooo0?oooooo4oooool003Sooooo00Go410@oooooooooooooooooa0@400?oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooo
oooo0?oooooo4oooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooo
oooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003ooooooooo
o`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000oooo
ooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`00
0?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool0
0ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o
0000ooooooooool0oooooolCooooo`008oooool5o`0002_ooooo00?o0000ooooooooool0:oooool5
o`0002kooooo0_l000000ol@413oooooooooo`0Zooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?oo
ool01Oo<c<co8B4Qo`000?lQ8B7oc<c<02Wooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`00
0?lb<S;ok^k^6_ooool002?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00[ooooo`03o`000?oooooo
oooo02_ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00_ooooo`03o`000?oooooooooo02_ooooo00Go
EEEEogMgMoooooooV9RHob4Q8@0/ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40:oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool001_ooooo1_l00003ooooo`03
oiRHV?lQ8B7ok^k^02cooooo00?o0000ooooooooool0;?ooool00onHV9So8B4Qonk^kP0]ooooo`Go
0000;?ooool01Ol0003ooooooooooooooooo000002cooooo00Go0000ooooooooooooooooo`00000[
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Jooooo`009Oooool0
0onHV9So8B4Qonk^kP0[ooooo`03o`000?oooooooooo02gooooo00?oV9RHob4Q8Oo^k^h0;?ooool0
1?m4A4CogMgMooooool0000]ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;?ooool01Olb<S;oV9RH
oooooonHV9So<S8b02_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
01[ooooo000Vooooo`03ogMgMomVIVKooooo02[ooooo0_l0000_ooooo`03ogMgMomVIVKooooo02_o
oooo00CogMgMoeEEEOoooooo0000;Oooool01Ol0003oEEEEo`000?l@413oc<c<02cooooo00Goc<c<
o`000?l0003o0000olc<c00[ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Jooooo`009oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool0:oooool00omgMgOoc<c<o`00000]ooooo`03oeEEEOn7QhOooooo02kooooo00Go
410@okZj^_oooooo^[Zjoa0@400[ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@400Jooooo`008oooool01Ol0003o^[ZjoooooonHV9So410@02_ooooo00?o0000oooooooo
ool0:oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo00?ok^k^odA4A?l00000;Oooool00ooM
gMgo410@oiRHV00^ooooo`05o`000?nj^[[ooooookZj^_l00000:oooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool002?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00[ooooo`03o`000?oooooooooo02_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00^ooooo`03ogMg
Mol0003ooooo02gooooo00Coc<c<odA4A?l0003o410@;?ooool01OnYZJWo410@o`000?l@413oZJVY
02Wooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo001Coooo
o`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00
Doooool00ol0003oooooooooo`3mooooo`;o00000_ooool2o`0000oooooo001Cooooo`03o`000?oo
oooooooo0?gooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd?ooooo`00Doooool00ol0003ooooo
ooooo`3nooooo`04omgMgOl0003o410@olc<c13ooooo000:oooooooo0000@?l0000;ooooo`04onk^
k_lQ8B7o410@onk^kQ3ooooo000Fooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool000002oooool00ol0003o
ooooooooo`07ooooo`?o00002oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wo
oooo00Co8B4QogMgMomgMgOo<S8b4?ooool002;ooooo00?o0000ooooooooool0;_ooool00ol0003o
ooooooooo`0^ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0Fooooo`;o000000?oooooo`000?ooool0;oooool00ol0003oooooooooo`0^ooooo`03
o`000?oooooooooo00Sooooo0_l00002ooooo`;o00003oooool005?ooooo00?o0000ooooooooool0
MOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo08?ooooo001Cooooo`03o`000?oo
oooooooo07Gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`23ooooo`00Doooool0
0ol0003oooooooooo`1eooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0Poooool0
05?ooooo00?o0000ooooooooool0MOooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
08Cooooo001Cooooo`03o`000?oooooooooo07Kooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`24ooooo`00Doooool2o`0007Oooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`24ooooo`00Doooool00ol0003oooooooooo`1gooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool0QOooool005?ooooo00?o0000ooooooooool0Moooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo08Gooooo001Cooooo`03o`000?oooooooooo07Oooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`25ooooo`00Doooool00ol0003oooooooooo`1gooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0Q_ooool005?ooooo00?o0000ooooooooool0
Moooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo08Kooooo001Cooooo`03o`000?oo
oooooooo07Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`26ooooo`00Doooool0
0ol0003oooooooooo`1hooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0Qoooool0
05?ooooo0_l0001iooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0Qoooool005?o
oooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo08Oo
oooo001Cooooo`03o`000?oooooooooo07Sooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`27ooooo`00Doooool00ol0003oooooooooo`1hooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool0R?ooool005?ooooo00?o0000ooooooooool0N?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo08Sooooo001Cooooo`03o`000?oooooooooo07Sooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`28ooooo`00Doooool00ol0003oooooooooo`1hooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool0R?ooool005?ooooo00?o0000ooooooooool0
N?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo08Sooooo001Cooooo`;o0000NOoo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo08Sooooo001Cooooo`03o`000?oooooo
oooo07Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`28ooooo`00Doooool00ol0
003oooooooooo`1iooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0R?ooool005?o
oooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo08Wo
oooo001Cooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`29ooooo`00Doooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool0ROooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?oo
ool5o`0000Kooooo00?o0000ooooooooool0NOooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo08Wooooo000hooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go
V9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo07Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`29ooooo`00>?ooool01Ol@413ooooooooooooooooo410@00cooooo
00?oV9RHob4Q8Oo^k^h01oooool3o`0007Wooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`29ooooo`00>?ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1_ooool00ol0003oooooooooo`1iooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
ROooool003Sooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Gooooo
00?o0000ooooooooool0NOooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo08Wooooo
000hooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo07Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`29ooooo`00>?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03
o`000?oooooooooo07Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2:ooooo`00
>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006oooo
o`03o`000?oooooooooo07Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2:oooo
o`00Doooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool0R_ooool005?ooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo08[ooooo001Cooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`2:ooooo`00Doooool2o`0007_ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`2:ooooo`00Doooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0R_ooool005?ooooo00?o0000ooooooooool0N_ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo08[ooooo001Cooooo`03o`000?oooooooooo07[ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`2:ooooo`00Doooool00ol0003ooooooooo
o`1jooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Roooool005?ooooo00?o0000
ooooooooool0N_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo08_ooooo001Coooo
o`03o`000?oooooooooo07[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2;oooo
o`00Doooool00ol0003oooooooooo`1jooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0Roooool005?ooooo0_l0001kooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
Roooool005?ooooo00?o0000ooooooooool0N_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo08_ooooo001Cooooo`03o`000?oooooooooo07[ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`2;ooooo`00Doooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0Roooool005?ooooo00?o0000ooooooooool0Noooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo08_ooooo001Cooooo`03o`000?oooooooooo07_ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`2;ooooo`00Doooool00ol0003ooooooooo
o`1kooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0S?ooool005?ooooo00?o0000
ooooooooool0Noooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo08cooooo001Coooo
o`;o0000O?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo08cooooo001Cooooo`03
o`000?oooooooooo07_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2<ooooo`00
Doooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
S?ooool005?ooooo00?o0000ooooooooool0Noooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo08cooooo001Cooooo`03o`000?oooooooooo07_ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`2<ooooo`00Doooool00ol0003oooooooooo`1kooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0S?ooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0Noooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo08cooooo000hooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1loooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0S?ooool003Sooooo00Go410@oooooooo
oooooooooa0@400;ooooo`Go00001_ooool3o`0007cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`2=ooooo`00>?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgM
gOoooooo00001oooool00ol0003oooooooooo`1looooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0SOooool003Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGo
ooooo`0000Oooooo00?o0000ooooooooool0O?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo08gooooo000hooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00
0007ooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`2=ooooo`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001ooo
ool00ol0003oooooooooo`1looooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0SOoo
ool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o
0000ooooooooool0O?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo08gooooo001C
ooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`2=
ooooo`00Doooool00ol0003oooooooooo`1looooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0SOooool005?ooooo0_l0001nooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0SOooool005?ooooo00?o0000ooooooooool0OOooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo08gooooo001Cooooo`03o`000?oooooooooo07gooooo00Go0000oooooooooooooooo
o`00002@ooooo`00Doooool00ol0003oooooooooo`1mooooo`05o`000?ooooooooooooooool00000
T?ooool005?ooooo00?o0000ooooooooool0OOooool01Ol0003ooooooooooooooooo0000093ooooo
001Cooooo`03o`000?oooooooooo07gooooo00Go0000ooooooooooooooooo`00002@ooooo`00Dooo
ool00ol0003oooooooooo`1mooooo`05o`000?ooooooooooooooool00000T?ooool005?ooooo00?o
0000ooooooooool0OOooool01Ol0003ooooooooooooooooo0000093ooooo001Cooooo`03o`000?oo
oooooooo07kooooo00?o0000ooooool00000TOooool005?ooooo0_l0001oooooo`03o`000?oooooo
0000097ooooo001Cooooo`03o`000?oooooooooo07kooooo00?o0000ooooool00000TOooool005?o
oooo00?o0000ooooooooool0O_ooool2o`0009;ooooo001Cooooo`03o`000?oooooooooo0?oooooo
4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3o
oooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000oooooooo
ool0oooooolCooooo`00Doooool2o`000?oooooo5?ooool005?ooooo00?o0000ooooooooool0oooo
oolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo
0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0
003oooooooooo`3ooooooa?ooooo000hooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?oooooo4oooool0
03Sooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_oo
ool00ol0003oooooooooo`3ooooooa?ooooo000hooooo`05o`000?ooooooooooooooool000002ooo
ool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0003ooooooa?ooooo000hooooo`05o`000?oo
ooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000oooooooo
ool0oooooolCooooo`00>?ooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qooo
ool02?ooool00ol0003oooooooooo`3ooooooa?ooooo000hooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo0?oooooo4oooool003Sooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000oooo
ooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`00
0?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool2
o`000?oooooo5?ooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o
0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Coooo
o`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00
Doooool2o`000?oooooo5?ooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool0
0ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?o
oooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo
001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolC
ooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00
Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4ooo
ool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooo
oa?ooooo000hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q
8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0?oooooo4oooool003Sooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o
0000ooooooooool0oooooolCooooo`00>?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo4oooool003Sooooo00Go
0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3o`000?oo
oooo4oooool003Sooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`00
0?o<c<`01_ooool00ol0003oooooooooo`3ooooooa?ooooo000hooooo`05oa0@4?oooooooooooooo
ool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0oooooolC
ooooo`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00
0006ooooo`03o`000?oooooooooo0?oooooo4oooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3ooooooa?ooooo
001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolC
ooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00
Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4ooo
ool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooo
oa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0
oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolD
ooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oo
oooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003ooooooooo
o`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000oooo
ooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000
oooooolDooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooo
oooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool004Wooooo1?l0
00000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo4oooool004_ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`3ooooooa?ooooo001;ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0oooooolCooooo`00Boooool00ol0003oooooooooo`05ooooo`?o
0000oooooolCooooo`00Boooool00ol0003oooooooooo`3ooooooa_ooooo001;ooooo`03o`000?oo
oooooooo0?oooooo6oooool004_ooooo00?o0000ooooooooool0oooooolKooooo`00BOooool00omE
EEGoIVIVo`00003ooooooagooooo001hooooo`?o000000?o410@ooooooooool0j_ooool007[ooooo
00?o410@okZj^_ooool01oooool2o`0000_ooooo00?o0000okZj^_ooool03?ooool2o`0000Gooooo
00?o0000okZj^_ooool0__ooool007[ooooo00?oV9RHoc8b<_ooool01oooool00ol0003ooooooooo
o`0:ooooo`;o<S8b3_ooool00ol0003oooooooooo`03ooooo`;o<S8b_oooool007[ooooo00?ogMgM
o`000?nj^[X01oooool01?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`03ohN7Qol0
003o^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4okZj^P04ooooo`03o`000?oooooooooo00?ooooo
00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj01;ooooo1?l000001?l@413o
ooooooooooooool4o`000003oa0@4?oooooooooo08cooooo001jooooo`03oeEEEOmgMgOoA4A400Oo
oooo00[o0000ooooooooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0oooool00oo<c<co0000
oa0@4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003oooooooooo`03ooooo`03
olc<c?l0003o410@00cooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00001Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo08kooooo001iooooo`05omgMgOl@413oooooob4Q
8OoMgMd01_ooool00ol0003oooooooooo`02ooooo`04omgMgOl0003o410@olc<c0_ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`2>ooooo`00NOooool01OmVIVKoQhN7oooooonHV9So
EEEE00Kooooo00?o0000ooooooooool00_ooool01?o^k^ko8B4Qoa0@4?o^k^h;ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0;ooooo`Ko00001Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo08kooooo001hooooo`03onk^k_l0003o
k^k^00;ooooo00?o0000omgMgOooool01?ooool00ol0003oooooooooo`02ooooo`04ob4Q8OmgMgOo
MgMgoc8b<P_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2>ooooo`00N?ooool0
1?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo00Co0000oooooooooooooooo
0_l00002ooooo`;o00002?ooool00ol@413o0000o`000003o`0000Gooooo00?o0000ooooooooool0
4?ooool00ol@413o0000o`000003o`0001Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`2>ooooo`00Q?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0S_ooool008Cooooo0_l0000Booooo`03o`000?oooooooooo00Gooooo0_l0000D
ooooo`03o`000?oooooooooo01Cooooo00?oEEEEofIVI_l000001Oooool00omEEEGoIVIVo`00002@
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-3.4116, -0.234311, \
0.0510397, 0.00762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.230769 0.0769231 0.103006 0.515028 [
[.07692 .09051 -6 -9 ]
[.07692 .09051 6 0 ]
[.38462 .09051 -3 -9 ]
[.38462 .09051 3 0 ]
[.53846 .09051 -3 -9 ]
[.53846 .09051 3 0 ]
[.69231 .09051 -3 -9 ]
[.69231 .09051 3 0 ]
[.84615 .09051 -3 -9 ]
[.84615 .09051 3 0 ]
[1 .09051 -6 -9 ]
[1 .09051 6 0 ]
[1.025 .10301 0 -6 ]
[1.025 .10301 10 6 ]
[.21827 0 -24 -4.5 ]
[.21827 0 0 4.5 ]
[.21827 .20601 -18 -4.5 ]
[.21827 .20601 0 4.5 ]
[.21827 .30902 -18 -4.5 ]
[.21827 .30902 0 4.5 ]
[.21827 .41202 -18 -4.5 ]
[.21827 .41202 0 4.5 ]
[.21827 .51503 -18 -4.5 ]
[.21827 .51503 0 4.5 ]
[.21827 .61803 -6 -4.5 ]
[.21827 .61803 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07692 .10301 m
.07692 .10926 L
s
[(-2)] .07692 .09051 0 1 Mshowa
.38462 .10301 m
.38462 .10926 L
s
[(2)] .38462 .09051 0 1 Mshowa
.53846 .10301 m
.53846 .10926 L
s
[(4)] .53846 .09051 0 1 Mshowa
.69231 .10301 m
.69231 .10926 L
s
[(6)] .69231 .09051 0 1 Mshowa
.84615 .10301 m
.84615 .10926 L
s
[(8)] .84615 .09051 0 1 Mshowa
1 .10301 m
1 .10926 L
s
[(10)] 1 .09051 0 1 Mshowa
.125 Mabswid
.11538 .10301 m
.11538 .10676 L
s
.15385 .10301 m
.15385 .10676 L
s
.19231 .10301 m
.19231 .10676 L
s
.26923 .10301 m
.26923 .10676 L
s
.30769 .10301 m
.30769 .10676 L
s
.34615 .10301 m
.34615 .10676 L
s
.42308 .10301 m
.42308 .10676 L
s
.46154 .10301 m
.46154 .10676 L
s
.5 .10301 m
.5 .10676 L
s
.57692 .10301 m
.57692 .10676 L
s
.61538 .10301 m
.61538 .10676 L
s
.65385 .10301 m
.65385 .10676 L
s
.73077 .10301 m
.73077 .10676 L
s
.76923 .10301 m
.76923 .10676 L
s
.80769 .10301 m
.80769 .10676 L
s
.88462 .10301 m
.88462 .10676 L
s
.92308 .10301 m
.92308 .10676 L
s
.96154 .10301 m
.96154 .10676 L
s
.03846 .10301 m
.03846 .10676 L
s
.25 Mabswid
0 .10301 m
1 .10301 L
s
gsave
1.025 .10301 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.23077 0 m
.23702 0 L
s
[(-0.2)] .21827 0 1 0 Mshowa
.23077 .20601 m
.23702 .20601 L
s
[(0.2)] .21827 .20601 1 0 Mshowa
.23077 .30902 m
.23702 .30902 L
s
[(0.4)] .21827 .30902 1 0 Mshowa
.23077 .41202 m
.23702 .41202 L
s
[(0.6)] .21827 .41202 1 0 Mshowa
.23077 .51503 m
.23702 .51503 L
s
[(0.8)] .21827 .51503 1 0 Mshowa
.23077 .61803 m
.23702 .61803 L
s
[(1)] .21827 .61803 1 0 Mshowa
.125 Mabswid
.23077 .02575 m
.23452 .02575 L
s
.23077 .0515 m
.23452 .0515 L
s
.23077 .07725 m
.23452 .07725 L
s
.23077 .12876 m
.23452 .12876 L
s
.23077 .15451 m
.23452 .15451 L
s
.23077 .18026 m
.23452 .18026 L
s
.23077 .23176 m
.23452 .23176 L
s
.23077 .25751 m
.23452 .25751 L
s
.23077 .28327 m
.23452 .28327 L
s
.23077 .33477 m
.23452 .33477 L
s
.23077 .36052 m
.23452 .36052 L
s
.23077 .38627 m
.23452 .38627 L
s
.23077 .43777 m
.23452 .43777 L
s
.23077 .46353 m
.23452 .46353 L
s
.23077 .48928 m
.23452 .48928 L
s
.23077 .54078 m
.23452 .54078 L
s
.23077 .56653 m
.23452 .56653 L
s
.23077 .59228 m
.23452 .59228 L
s
.25 Mabswid
.23077 0 m
.23077 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
123.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(12) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.56994 .10301 m
.57163 .10301 L
.57257 .10301 L
.57357 .10301 L
.57537 .10301 L
.57647 .10301 L
.5775 .10301 L
.57843 .10301 L
.57944 .10301 L
.58116 .10301 L
.58301 .10301 L
.58476 .10301 L
.58635 .10301 L
.58821 .10301 L
.58927 .10301 L
.59024 .10301 L
.59203 .10301 L
.59393 .10301 L
.59573 .10301 L
.59675 .10301 L
.59768 .10301 L
.5994 .10301 L
.6012 .10301 L
.60216 .10301 L
.60319 .10301 L
.60504 .10301 L
.60617 .10301 L
.60724 .10301 L
.6082 .10301 L
.60924 .10301 L
.61094 .10301 L
.61253 .10302 L
.61428 .10304 L
.61616 .10309 L
.6171 .10314 L
.61813 .10323 L
.62 .10352 L
.62181 .10408 L
.6235 .10501 L
.62522 .10659 L
.62684 .10891 L
.6283 .11191 L
.62987 .11641 L
.63159 .12315 L
.6334 .13268 L
.63665 .15678 L
.64375 .23783 L
.64724 .28312 L
.65047 .32 L
.65227 .33644 L
Mistroke
.65418 .34962 L
.65609 .35792 L
.65718 .36034 L
.65821 .36108 L
.65998 .35901 L
.6616 .35359 L
.66338 .34421 L
.66526 .33111 L
.67246 .26352 L
.67924 .19987 L
.68533 .15749 L
.68877 .14067 L
.69193 .12912 L
.69515 .12057 L
.69698 .11688 L
.69869 .11407 L
.70214 .10989 L
.70408 .10822 L
.70584 .10704 L
.70774 .10604 L
.70949 .10533 L
.71142 .10473 L
.71346 .10425 L
.71523 .10394 L
.7169 .10372 L
.71872 .10353 L
.72069 .10338 L
.72237 .10329 L
.72393 .10322 L
.72564 .10316 L
.72747 .10312 L
.7294 .10309 L
.73122 .10306 L
.73285 .10305 L
.73462 .10304 L
.73616 .10303 L
.73785 .10302 L
.73962 .10302 L
.74127 .10301 L
.74282 .10301 L
.74423 .10301 L
.74586 .10301 L
.74741 .10301 L
.74922 .10301 L
.75024 .10301 L
.75118 .10301 L
.75291 .10301 L
.75473 .10301 L
.75636 .10301 L
.75789 .10301 L
Mistroke
.75957 .10301 L
.76136 .10301 L
.76328 .10301 L
.76436 .10301 L
.76536 .10301 L
.76719 .10301 L
.76812 .10301 L
.76914 .10301 L
.7709 .10301 L
.7728 .10301 L
.77459 .10301 L
.77623 .10301 L
.77779 .10301 L
.77945 .10301 L
.78102 .10301 L
.78245 .10301 L
.78413 .10301 L
.78595 .10301 L
.78767 .10301 L
.78926 .10301 L
.79089 .10301 L
.79243 .10301 L
.79411 .10301 L
.79592 .10301 L
.79781 .10301 L
.7996 .10301 L
.80121 .10301 L
.80297 .10301 L
.80391 .10301 L
.80491 .10301 L
.8067 .10301 L
.80862 .10301 L
.80971 .10301 L
.81072 .10301 L
.81257 .10301 L
.81425 .10301 L
.81518 .10301 L
.81619 .10301 L
.81802 .10301 L
.81966 .10301 L
.82146 .10301 L
.82334 .10301 L
.8251 .10301 L
.82675 .10301 L
.82825 .10301 L
.82999 .10301 L
.83164 .10301 L
.83356 .10301 L
.83531 .10301 L
.83627 .10301 L
Mistroke
.83732 .10301 L
.83921 .10301 L
.84099 .10301 L
.84287 .10301 L
.84447 .10301 L
.84623 .10301 L
.8473 .10301 L
.84831 .10301 L
.85021 .10301 L
.85127 .10301 L
.85225 .10301 L
.85333 .10301 L
.85447 .10301 L
.85636 .10301 L
.85813 .10301 L
.85914 .10301 L
.86007 .10301 L
.86109 .10301 L
.86216 .10301 L
.86396 .10301 L
.86497 .10301 L
.8659 .10301 L
.86761 .10301 L
.86943 .10301 L
.87105 .10301 L
.87257 .10301 L
.87424 .10301 L
.87603 .10301 L
.87793 .10301 L
.87901 .10301 L
.88 .10301 L
.88183 .10301 L
.88285 .10301 L
.88377 .10301 L
.88553 .10301 L
.88742 .10301 L
.88921 .10301 L
.89085 .10301 L
.8924 .10301 L
.89406 .10301 L
.89562 .10301 L
.89705 .10301 L
.89872 .10301 L
.90054 .10301 L
.90225 .10301 L
.90384 .10301 L
.90547 .10301 L
.907 .10301 L
.90868 .10301 L
.91049 .10301 L
Mistroke
.91229 .10301 L
.91417 .10301 L
.91579 .10301 L
.91755 .10301 L
.91848 .10301 L
.91947 .10301 L
.92125 .10301 L
.92315 .10301 L
.92424 .10301 L
.92525 .10301 L
.92708 .10301 L
.92876 .10301 L
.92968 .10301 L
.93069 .10301 L
.93252 .10301 L
.93414 .10301 L
.93593 .10301 L
.93781 .10301 L
.93957 .10301 L
.94121 .10301 L
.94271 .10301 L
.94436 .10301 L
.9461 .10301 L
.94801 .10301 L
.94974 .10301 L
.9507 .10301 L
.95174 .10301 L
.95363 .10301 L
.9554 .10301 L
.95728 .10301 L
.95888 .10301 L
.96065 .10301 L
.96171 .10301 L
.96272 .10301 L
.96461 .10301 L
.96567 .10301 L
.96665 .10301 L
.96772 .10301 L
.96887 .10301 L
.96987 .10301 L
.97095 .10301 L
.97197 .10301 L
.97291 .10301 L
.97469 .10301 L
.97658 .10301 L
.97835 .10301 L
.97935 .10301 L
.98028 .10301 L
.98198 .10301 L
.98379 .10301 L
Mistroke
.9854 .10301 L
.98691 .10301 L
.98857 .10301 L
.99036 .10301 L
.99215 .10301 L
.99317 .10301 L
.99412 .10301 L
.99603 .10301 L
.9971 .10301 L
.99807 .10301 L
.99981 .10301 L
Mfstroke
.99981 .10301 m
1 .10301 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000oooooolLooooo`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0oooooolLooooo`00<?ooool6o`0000;o
oooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^0?oooooo7Oooool003So
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003ooooo
oa?ooooo000hooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05oooo
o`03o`000?oooooooooo0?oooooo4oooool003Sooooo00Go410@oooooooooooooooooa0@400?oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooo
oooo0?oooooo4oooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooo
oooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003ooooooooo
o`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000oooo
ooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`00
0?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool0
0ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o
0000ooooooooool0oooooolCooooo`008oooool5o`0002_ooooo00?o0000ooooooooool0:oooool5
o`0002kooooo0_l000000ol@413oooooooooo`0Zooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?oo
ool01Oo<c<co8B4Qo`000?lQ8B7oc<c<02Wooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`00
0?lb<S;ok^k^6_ooool002?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00[ooooo`03o`000?oooooo
oooo02_ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00_ooooo`03o`000?oooooooooo02_ooooo00Go
EEEEogMgMoooooooV9RHob4Q8@0/ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40:oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool001_ooooo1_l00003ooooo`03
oiRHV?lQ8B7ok^k^02cooooo00?o0000ooooooooool0;?ooool00onHV9So8B4Qonk^kP0]ooooo`Go
0000;?ooool01Ol0003ooooooooooooooooo000002cooooo00Go0000ooooooooooooooooo`00000[
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Jooooo`009Oooool0
0onHV9So8B4Qonk^kP0[ooooo`03o`000?oooooooooo02gooooo00?oV9RHob4Q8Oo^k^h0;?ooool0
1?m4A4CogMgMooooool0000]ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;?ooool01Olb<S;oV9RH
oooooonHV9So<S8b02_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
01[ooooo000Vooooo`03ogMgMomVIVKooooo02[ooooo0_l0000_ooooo`03ogMgMomVIVKooooo02_o
oooo00CogMgMoeEEEOoooooo0000;Oooool01Ol0003oEEEEo`000?l@413oc<c<02cooooo00Goc<c<
o`000?l0003o0000olc<c00[ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Jooooo`009oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool0:oooool00omgMgOoc<c<o`00000]ooooo`03oeEEEOn7QhOooooo02kooooo00Go
410@okZj^_oooooo^[Zjoa0@400[ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@400Jooooo`008oooool01Ol0003o^[ZjoooooonHV9So410@02_ooooo00?o0000oooooooo
ool0:oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo00?ok^k^odA4A?l00000;Oooool00ooM
gMgo410@oiRHV00^ooooo`05o`000?nj^[[ooooookZj^_l00000:oooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool002?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00[ooooo`03o`000?oooooooooo02_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00^ooooo`03ogMg
Mol0003ooooo02gooooo00Coc<c<odA4A?l0003o410@;?ooool01OnYZJWo410@o`000?l@413oZJVY
02Wooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo001Coooo
o`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00
Doooool00ol0003oooooooooo`3mooooo`;o00000_ooool2o`0000oooooo001Cooooo`03o`000?oo
oooooooo0?gooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd?ooooo`00Doooool00ol0003ooooo
ooooo`3nooooo`04omgMgOl0003o410@olc<c13ooooo000:oooooooo0000@?l0000;ooooo`04onk^
k_lQ8B7o410@onk^kQ3ooooo000Fooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000oooooooo
ool02Oooool01?l0003oooooooooooooool2o`0000Kooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`04ob4Q8OmgMgOoMgMgoc8b<Q3ooooo000Rooooo`03o`000?oooooooooo
02kooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool04Oooool01?l0003oooooooooool0000]ooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool02?ooool2o`0000;ooooo0_l0000?ooooo`00Doooool00ol0
003oooooooooo`1looooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0OOooool005?o
oooo00?o0000ooooooooool0O?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo07ko
oooo001Cooooo`03o`000?oooooooooo07cooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`1nooooo`00Doooool00ol0003oooooooooo`1mooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool0O_ooool005?ooooo00?o0000ooooooooool0OOooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo07oooooo001Cooooo`;o0000O_ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo07oooooo001Cooooo`03o`000?oooooooooo07gooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`1oooooo`00Doooool00ol0003oooooooooo`1mooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool0Ooooool005?ooooo00?o0000ooooooooool0OOoo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo083ooooo001Cooooo`03o`000?oooooo
oooo07gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`20ooooo`00Doooool00ol0
003oooooooooo`1mooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0P?ooool005?o
oooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo083o
oooo001Cooooo`03o`000?oooooooooo07kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`21ooooo`00Doooool2o`0007oooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`21ooooo`00Doooool00ol0003oooooooooo`1nooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0POooool005?ooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo087ooooo001Cooooo`03o`000?oooooooooo07kooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`21ooooo`00Doooool00ol0003oooooooooo`1nooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool0POooool005?ooooo00?o0000ooooooooool0O_oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo08;ooooo001Cooooo`03o`000?oooooo
oooo07oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`22ooooo`00Doooool00ol0
003oooooooooo`1oooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0P_ooool005?o
oooo0_l00020ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0P_ooool005?ooooo
00?o0000ooooooooool0Ooooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo08;ooooo
001Cooooo`03o`000?oooooooooo07oooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`22ooooo`00Doooool00ol0003oooooooooo`1oooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool0P_ooool005?ooooo00?o0000ooooooooool0Ooooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo08?ooooo001Cooooo`03o`000?oooooooooo07oooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`23ooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`20ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0Poooool003Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0P?ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo08?ooooo000hooooo`05oa0@4?oooooooooooooo
ool@41003?ooool00onHV9So8B4Qonk^kP07ooooo`?o0000P?ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo08?ooooo000hooooo`05o`000?ooooooooooooooool000003Oooool00onH
V9So8B4Qonk^kP06ooooo`03o`000?oooooooooo083ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`23ooooo`00>?ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIV
I_ooool01Oooool00ol0003oooooooooo`20ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool0Poooool003Sooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0P?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
08?ooooo000hooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So
410@00Kooooo00?o0000ooooooooool0P?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo08Cooooo000hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ
8B7oc<c<00Kooooo00?o0000ooooooooool0P?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo08Cooooo001Cooooo`03o`000?oooooooooo083ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`24ooooo`00Doooool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0Q?ooool005?ooooo00?o0000ooooooooool0POooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo08Cooooo001Cooooo`;o0000P_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo08Cooooo001Cooooo`03o`000?oooooooooo087ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`24ooooo`00Doooool00ol0003oooooooooo`21
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0Q?ooool005?ooooo00?o0000oooo
ooooool0POooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo08Cooooo001Cooooo`03
o`000?oooooooooo087ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`24ooooo`00
Doooool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
Q?ooool005?ooooo00?o0000ooooooooool0POooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo08Gooooo001Cooooo`03o`000?oooooooooo087ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`25ooooo`00Doooool2o`0008;ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`25ooooo`00Doooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0QOooool005?ooooo00?o0000ooooooooool0P_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo08Gooooo001Cooooo`03o`000?oooooooooo08;ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`25ooooo`00Doooool00ol0003oooooooooo`22
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0QOooool005?ooooo00?o0000oooo
ooooool0P_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo08Gooooo001Cooooo`03
o`000?oooooooooo08;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`26ooooo`00
Doooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
Q_ooool005?ooooo0_l00023ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Q_oo
ool005?ooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo08Kooooo001Cooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`26ooooo`00Doooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0Q_ooool005?ooooo00?o0000ooooooooool0P_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo08Kooooo001Cooooo`03o`000?oooooooooo08;ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`27ooooo`00>?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003ooooooooo
o`22ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Qoooool003Sooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo08?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`27ooooo`00>?ooool0
1Ol@413ooooooooooooooooo410@00_ooooo1Ol00006ooooo`?o0000Poooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo08Oooooo000hooooo`05o`000?ooooooooooooooool000002ooo
ool01?m4A4CogMgMooooool00007ooooo`03o`000?oooooooooo08?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`27ooooo`00>?ooool01Ol0003ooooooooooooooooo000000_ooooo
00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`23ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0Qoooool003Sooooo00Go410@oooooooooooooooooa0@400<ooooo`03
ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0Poooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo08Oooooo000hooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^ko
A4A4o`000007ooooo`03o`000?oooooooooo08?ooooo00Go0000ooooooooooooooooo`00002:oooo
o`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_ooool00ol0
003oooooooooo`23ooooo`05o`000?ooooooooooooooool00000R_ooool005?ooooo00?o0000oooo
ooooool0Poooool01Ol0003ooooooooooooooooo000008[ooooo001Cooooo`03o`000?oooooooooo
08?ooooo00Go0000ooooooooooooooooo`00002:ooooo`00Doooool2o`0008Cooooo00Go0000oooo
ooooooooooooo`00002:ooooo`00Doooool00ol0003oooooooooo`23ooooo`05o`000?oooooooooo
ooooool00000R_ooool005?ooooo00?o0000ooooooooool0Poooool01Ol0003ooooooooooooooooo
000008[ooooo001Cooooo`03o`000?oooooooooo08?ooooo00Go0000ooooooooooooooooo`00002:
ooooo`00Doooool00ol0003oooooooooo`24ooooo`04o`000?ooooooooooo`0008[ooooo001Coooo
o`03o`000?oooooooooo08Cooooo00?o0000ooooool00000Roooool005?ooooo00?o0000oooooooo
ool0Q?ooool00ol0003oooooo`00002;ooooo`00Doooool00ol0003oooooooooo`24ooooo`03o`00
0?oooooo000008_ooooo001Cooooo`03o`000?oooooooooo08Cooooo0ol0002;ooooo`00Doooool2
o`0008Kooooo00?o0000ooooooooool0R_ooool005?ooooo00?o0000ooooooooool0oooooolCoooo
o`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo
4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3o
oooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000oooooooo
ool0oooooolCooooo`00Doooool2o`000?oooooo5?ooool005?ooooo00?o0000ooooooooool0oooo
oolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo
0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0
003oooooooooo`3ooooooa?ooooo000hooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?oooooo4oooool0
03Sooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_oo
ool00ol0003oooooooooo`3ooooooa?ooooo000hooooo`05o`000?ooooooooooooooool000002ooo
ool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0003ooooooa?ooooo000hooooo`05o`000?oo
ooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000oooooooo
ool0oooooolCooooo`00>?ooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qooo
ool02?ooool00ol0003oooooooooo`3ooooooa?ooooo000hooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo0?oooooo4oooool003Sooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000oooo
ooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`00
0?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool2
o`000?oooooo5?ooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o
0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Coooo
o`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00
Doooool2o`000?oooooo5?ooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool0
0ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?o
oooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo
001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolC
ooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00
Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4ooo
ool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooo
oa?ooooo000hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q
8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0?oooooo4oooool003Sooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o
0000ooooooooool0oooooolCooooo`00>?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo4oooool003Sooooo00Go
0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3o`000?oo
oooo4oooool003Sooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`00
0?o<c<`01_ooool00ol0003oooooooooo`3ooooooa?ooooo000hooooo`05oa0@4?oooooooooooooo
ool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0oooooolC
ooooo`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00
0006ooooo`03o`000?oooooooooo0?oooooo4oooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3ooooooa?ooooo
001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolC
ooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00
Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4ooo
ool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooo
oa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0
oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolD
ooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oo
oooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003ooooooooo
o`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000oooo
ooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000
oooooolDooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooo
oooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool004Wooooo1?l0
00000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo4oooool004_ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`3ooooooa?ooooo001;ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0oooooolCooooo`00Boooool00ol0003oooooooooo`05ooooo`?o
0000oooooolCooooo`00Boooool00ol0003oooooooooo`3ooooooa_ooooo001;ooooo`03o`000?oo
oooooooo0?oooooo6oooool004_ooooo00?o0000ooooooooool0oooooolKooooo`00BOooool00omE
EEGoIVIVo`00003ooooooagooooo001hooooo`?o000000?o410@ooooooooool0j_ooool007[ooooo
00?o410@okZj^_ooool01oooool2o`0000_ooooo00?o0000okZj^_ooool03?ooool2o`0000Gooooo
00?o0000okZj^_ooool0__ooool007[ooooo00?oV9RHoc8b<_ooool01oooool00ol0003ooooooooo
o`0:ooooo`;o<S8b3_ooool00ol0003oooooooooo`03ooooo`;o<S8b_oooool007[ooooo00?ogMgM
o`000?nj^[X01oooool01?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`03ohN7Qol0
003o^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4okZj^P04ooooo`03o`000?oooooooooo00?ooooo
00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj01;ooooo1?l000000ol@413o
ooooooooo`05o`0008oooooo001jooooo`03oeEEEOmgMgOoA4A400Oooooo00[o0000oooooooooooo
ooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0oooool00oo<c<co0000oa0@4004ooooo`05oa0@4?nj
^[[ok^k^ogMgMol@41001?ooool00ol0003oooooooooo`03ooooo`03olc<c?l0003o410@00cooooo
00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@0Soooool007Wooooo00GogMgMoa0@4?oooooo8B4QomgMg@06oooo
o`03o`000?oooooooooo00;ooooo00CogMgMo`000?l@413oc<c<2oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`03
ooooo`03oiRHV?lQ8B7ok^k^093ooooo001iooooo`05ofIVI_n7QhOooooooiRHV?mEEED01_ooool0
0ol0003oooooooooo`02ooooo`04onk^k_lQ8B7o410@onk^kP_ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00_ooooo1_l00005ooooo`03o`000?oo
oooooooo00Cooooo00?oV9RHob4Q8Oo^k^h0Soooool007Sooooo00?ok^k^o`000?o^k^h00_ooool0
0ol0003ogMgMooooo`04ooooo`03o`000?oooooooooo00;ooooo00Co8B4QogMgMomgMgOo<S8b2ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`05ooooo`03ogMgMomVIVKooooo08kooooo001hooooo`04oa0@4?l0003o
0000ooooo`;o000000?o410@ooooooooool00oooool01?l0003oooooooooooooool2o`0000;ooooo
0_l00008ooooo`03oa0@4?l0003o000000?o00001Oooool00ol0003oooooooooo`0@ooooo`03oa0@
4?l0003o000000?o00005Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo08gooooo
0024ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool00_ooool01Ol0003o^[Zjoooo
oonHV9So410@08oooooo0024ooooo`;o00004_ooool00ol0003oooooooooo`05ooooo`;o00005?oo
ool00ol0003oooooooooo`0Dooooo`03oeEEEOmVIVKo000000Cooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c02?ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-3.4116, -0.234311, \
0.0510397, 0.00762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.230769 0.0769231 0.103006 0.515028 [
[.07692 .09051 -6 -9 ]
[.07692 .09051 6 0 ]
[.38462 .09051 -3 -9 ]
[.38462 .09051 3 0 ]
[.53846 .09051 -3 -9 ]
[.53846 .09051 3 0 ]
[.69231 .09051 -3 -9 ]
[.69231 .09051 3 0 ]
[.84615 .09051 -3 -9 ]
[.84615 .09051 3 0 ]
[1 .09051 -6 -9 ]
[1 .09051 6 0 ]
[1.025 .10301 0 -6 ]
[1.025 .10301 10 6 ]
[.21827 0 -24 -4.5 ]
[.21827 0 0 4.5 ]
[.21827 .20601 -18 -4.5 ]
[.21827 .20601 0 4.5 ]
[.21827 .30902 -18 -4.5 ]
[.21827 .30902 0 4.5 ]
[.21827 .41202 -18 -4.5 ]
[.21827 .41202 0 4.5 ]
[.21827 .51503 -18 -4.5 ]
[.21827 .51503 0 4.5 ]
[.21827 .61803 -6 -4.5 ]
[.21827 .61803 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07692 .10301 m
.07692 .10926 L
s
[(-2)] .07692 .09051 0 1 Mshowa
.38462 .10301 m
.38462 .10926 L
s
[(2)] .38462 .09051 0 1 Mshowa
.53846 .10301 m
.53846 .10926 L
s
[(4)] .53846 .09051 0 1 Mshowa
.69231 .10301 m
.69231 .10926 L
s
[(6)] .69231 .09051 0 1 Mshowa
.84615 .10301 m
.84615 .10926 L
s
[(8)] .84615 .09051 0 1 Mshowa
1 .10301 m
1 .10926 L
s
[(10)] 1 .09051 0 1 Mshowa
.125 Mabswid
.11538 .10301 m
.11538 .10676 L
s
.15385 .10301 m
.15385 .10676 L
s
.19231 .10301 m
.19231 .10676 L
s
.26923 .10301 m
.26923 .10676 L
s
.30769 .10301 m
.30769 .10676 L
s
.34615 .10301 m
.34615 .10676 L
s
.42308 .10301 m
.42308 .10676 L
s
.46154 .10301 m
.46154 .10676 L
s
.5 .10301 m
.5 .10676 L
s
.57692 .10301 m
.57692 .10676 L
s
.61538 .10301 m
.61538 .10676 L
s
.65385 .10301 m
.65385 .10676 L
s
.73077 .10301 m
.73077 .10676 L
s
.76923 .10301 m
.76923 .10676 L
s
.80769 .10301 m
.80769 .10676 L
s
.88462 .10301 m
.88462 .10676 L
s
.92308 .10301 m
.92308 .10676 L
s
.96154 .10301 m
.96154 .10676 L
s
.03846 .10301 m
.03846 .10676 L
s
.25 Mabswid
0 .10301 m
1 .10301 L
s
gsave
1.025 .10301 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.23077 0 m
.23702 0 L
s
[(-0.2)] .21827 0 1 0 Mshowa
.23077 .20601 m
.23702 .20601 L
s
[(0.2)] .21827 .20601 1 0 Mshowa
.23077 .30902 m
.23702 .30902 L
s
[(0.4)] .21827 .30902 1 0 Mshowa
.23077 .41202 m
.23702 .41202 L
s
[(0.6)] .21827 .41202 1 0 Mshowa
.23077 .51503 m
.23702 .51503 L
s
[(0.8)] .21827 .51503 1 0 Mshowa
.23077 .61803 m
.23702 .61803 L
s
[(1)] .21827 .61803 1 0 Mshowa
.125 Mabswid
.23077 .02575 m
.23452 .02575 L
s
.23077 .0515 m
.23452 .0515 L
s
.23077 .07725 m
.23452 .07725 L
s
.23077 .12876 m
.23452 .12876 L
s
.23077 .15451 m
.23452 .15451 L
s
.23077 .18026 m
.23452 .18026 L
s
.23077 .23176 m
.23452 .23176 L
s
.23077 .25751 m
.23452 .25751 L
s
.23077 .28327 m
.23452 .28327 L
s
.23077 .33477 m
.23452 .33477 L
s
.23077 .36052 m
.23452 .36052 L
s
.23077 .38627 m
.23452 .38627 L
s
.23077 .43777 m
.23452 .43777 L
s
.23077 .46353 m
.23452 .46353 L
s
.23077 .48928 m
.23452 .48928 L
s
.23077 .54078 m
.23452 .54078 L
s
.23077 .56653 m
.23452 .56653 L
s
.23077 .59228 m
.23452 .59228 L
s
.25 Mabswid
.23077 0 m
.23077 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
123.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(13) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.59347 .10301 m
.59367 .10301 L
.59463 .10301 L
.59564 .10301 L
.59746 .10301 L
.59847 .10301 L
.59941 .10301 L
.60044 .10301 L
.60155 .10301 L
.60251 .10301 L
.60355 .10301 L
.60544 .10301 L
.60728 .10301 L
.60898 .10301 L
.61056 .10301 L
.61227 .10301 L
.61388 .10301 L
.61536 .10301 L
.61699 .10301 L
.61878 .10301 L
.62065 .10301 L
.6224 .10301 L
.62425 .10301 L
.62601 .10301 L
.62758 .10301 L
.62929 .10301 L
.63115 .10301 L
.63209 .10301 L
.63312 .10301 L
.63494 .10303 L
.63665 .10306 L
.63841 .10315 L
.64005 .10333 L
.64185 .10374 L
.64376 .10461 L
.64558 .10616 L
.6473 .10858 L
.64884 .11189 L
.65051 .11704 L
.65204 .12355 L
.65372 .13299 L
.65547 .14568 L
.6571 .16021 L
.66317 .23295 L
.66656 .27834 L
.66834 .30031 L
.67024 .32051 L
.67189 .33468 L
.67371 .3459 L
.67537 .35175 L
Mistroke
.67693 .3534 L
.67787 .35261 L
.67886 .3504 L
.68064 .34318 L
.68255 .3313 L
.68464 .31449 L
.69166 .24438 L
.69536 .20851 L
.69936 .17577 L
.70315 .15186 L
.70663 .13562 L
.70978 .12502 L
.71157 .12042 L
.71324 .11689 L
.71661 .11164 L
.7185 .10954 L
.72022 .10805 L
.72211 .10678 L
.72411 .10575 L
.72582 .10509 L
.72771 .10453 L
.72974 .10409 L
.73192 .10375 L
.73398 .10353 L
.73587 .10338 L
.73765 .10328 L
.73932 .1032 L
.74114 .10315 L
.74309 .1031 L
.74407 .10309 L
.74514 .10307 L
.74608 .10306 L
.74708 .10305 L
.74896 .10304 L
.7507 .10303 L
.75246 .10302 L
.75437 .10302 L
.75618 .10301 L
.75786 .10301 L
.75952 .10301 L
.76102 .10301 L
.76276 .10301 L
.7644 .10301 L
.76619 .10301 L
.76808 .10301 L
.7697 .10301 L
.77147 .10301 L
.77338 .10301 L
.77445 .10301 L
.77543 .10301 L
Mistroke
.77733 .10301 L
.77912 .10301 L
.78065 .10301 L
.78234 .10301 L
.7841 .10301 L
.78575 .10301 L
.78729 .10301 L
.7887 .10301 L
.79024 .10301 L
.79187 .10301 L
.79353 .10301 L
.79531 .10301 L
.79698 .10301 L
.7985 .10301 L
.80028 .10301 L
.80129 .10301 L
.80222 .10301 L
.80393 .10301 L
.80574 .10301 L
.8075 .10301 L
.80942 .10301 L
.81123 .10301 L
.81291 .10301 L
.81458 .10301 L
.81609 .10301 L
.81783 .10301 L
.81947 .10301 L
.82127 .10301 L
.82317 .10301 L
.82479 .10301 L
.82656 .10301 L
.82847 .10301 L
.82955 .10301 L
.83052 .10301 L
.83242 .10301 L
.83422 .10301 L
.83575 .10301 L
.83744 .10301 L
.8392 .10301 L
.84085 .10301 L
.8424 .10301 L
.84381 .10301 L
.84544 .10301 L
.84698 .10301 L
.84865 .10301 L
.85042 .10301 L
.85209 .10301 L
.85361 .10301 L
.8554 .10301 L
.85641 .10301 L
Mistroke
.85734 .10301 L
.85904 .10301 L
.86085 .10301 L
.86262 .10301 L
.86362 .10301 L
.86455 .10301 L
.86624 .10301 L
.86805 .10301 L
.86966 .10301 L
.87117 .10301 L
.87283 .10301 L
.87462 .10301 L
.87641 .10301 L
.87742 .10301 L
.87837 .10301 L
.88028 .10301 L
.88135 .10301 L
.88232 .10301 L
.88406 .10301 L
.88595 .10301 L
.88774 .10301 L
.88938 .10301 L
.89092 .10301 L
.89257 .10301 L
.89412 .10301 L
.89555 .10301 L
.89721 .10301 L
.89902 .10301 L
.90074 .10301 L
.90233 .10301 L
.90412 .10301 L
.90581 .10301 L
.90733 .10301 L
.90897 .10301 L
.91076 .10301 L
.91265 .10301 L
.91426 .10301 L
.91603 .10301 L
.91794 .10301 L
.9197 .10301 L
.92061 .10301 L
.92162 .10301 L
.92268 .10301 L
.92367 .10301 L
.92549 .10301 L
.92715 .10301 L
.92898 .10301 L
.9309 .10301 L
.93252 .10301 L
.93425 .10301 L
Mistroke
.93589 .10301 L
.93737 .10301 L
.93912 .10301 L
.94101 .10301 L
.9428 .10301 L
.94444 .10301 L
.9462 .10301 L
.94808 .10301 L
.94986 .10301 L
.95149 .10301 L
.95339 .10301 L
.95446 .10301 L
.95546 .10301 L
.95728 .10301 L
.95821 .10301 L
.95923 .10301 L
.96021 .10301 L
.96125 .10301 L
.9631 .10301 L
.96414 .10301 L
.9651 .10301 L
.96616 .10301 L
.96729 .10301 L
.96827 .10301 L
.96933 .10301 L
.97033 .10301 L
.97125 .10301 L
.97301 .10301 L
.97486 .10301 L
.97662 .10301 L
.97853 .10301 L
.98034 .10301 L
.98201 .10301 L
.98367 .10301 L
.98518 .10301 L
.98691 .10301 L
.98855 .10301 L
.99034 .10301 L
.99223 .10301 L
.99385 .10301 L
.99562 .10301 L
.99753 .10301 L
.9986 .10301 L
.99958 .10301 L
Mfstroke
.99958 .10301 m
1 .10301 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000oooooolLooooo`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0oooooolLooooo`00<?ooool6o`0000;o
oooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^0?oooooo7Oooool003So
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003ooooo
oa?ooooo000hooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05oooo
o`03o`000?oooooooooo0?oooooo4oooool003Sooooo00Go410@oooooooooooooooooa0@400?oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooo
oooo0?oooooo4oooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooo
oooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003ooooooooo
o`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000oooo
ooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`00
0?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool0
0ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o
0000ooooooooool0oooooolCooooo`008oooool5o`0002_ooooo00?o0000ooooooooool0:oooool5
o`0002kooooo0_l000000ol@413oooooooooo`0Zooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?oo
ool01Oo<c<co8B4Qo`000?lQ8B7oc<c<02Wooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`00
0?lb<S;ok^k^6_ooool002?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00[ooooo`03o`000?oooooo
oooo02_ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00_ooooo`03o`000?oooooooooo02_ooooo00Go
EEEEogMgMoooooooV9RHob4Q8@0/ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40:oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool001_ooooo1_l00003ooooo`03
oiRHV?lQ8B7ok^k^02cooooo00?o0000ooooooooool0;?ooool00onHV9So8B4Qonk^kP0]ooooo`Go
0000;?ooool01Ol0003ooooooooooooooooo000002cooooo00Go0000ooooooooooooooooo`00000[
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Jooooo`009Oooool0
0onHV9So8B4Qonk^kP0[ooooo`03o`000?oooooooooo02gooooo00?oV9RHob4Q8Oo^k^h0;?ooool0
1?m4A4CogMgMooooool0000]ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;?ooool01Olb<S;oV9RH
oooooonHV9So<S8b02_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
01[ooooo000Vooooo`03ogMgMomVIVKooooo02[ooooo0_l0000_ooooo`03ogMgMomVIVKooooo02_o
oooo00CogMgMoeEEEOoooooo0000;Oooool01Ol0003oEEEEo`000?l@413oc<c<02cooooo00Goc<c<
o`000?l0003o0000olc<c00[ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Jooooo`009oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool0:oooool00omgMgOoc<c<o`00000]ooooo`03oeEEEOn7QhOooooo02kooooo00Go
410@okZj^_oooooo^[Zjoa0@400[ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@400Jooooo`008oooool01Ol0003o^[ZjoooooonHV9So410@02_ooooo00?o0000oooooooo
ool0:oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo00?ok^k^odA4A?l00000;Oooool00ooM
gMgo410@oiRHV00^ooooo`05o`000?nj^[[ooooookZj^_l00000:oooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool002?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00[ooooo`03o`000?oooooooooo02_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00^ooooo`03ogMg
Mol0003ooooo02gooooo00Coc<c<odA4A?l0003o410@;?ooool01OnYZJWo410@o`000?l@413oZJVY
02Wooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo001Coooo
o`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00
Doooool00ol0003oooooooooo`3mooooo`;o00000_ooool2o`0000oooooo001Cooooo`03o`000?oo
oooooooo0?gooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd?ooooo`00Doooool00ol0003ooooo
ooooo`3nooooo`04omgMgOl0003o410@olc<c13ooooo000:oooooooo0000@?l0000;ooooo`04onk^
k_lQ8B7o410@onk^kQ3ooooo000Fooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo0_l000000ooooooo0000
ooooo`0:ooooo`03o`000?oooooooooo00Kooooo00Co0000oooooooooooo00002oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`04ob4Q8OmgMgOoMgMgoc8b<Q3ooooo000Rooooo`03o`000?oooooooooo02ko
oooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo023o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`08ooooo`;o00000_ooool2o`0000oo
oooo001Cooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`1gooooo`00Doooool00ol0003oooooooooo`23ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool0N?ooool005?ooooo00?o0000ooooooooool0Poooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo07Wooooo001Cooooo`03o`000?oooooooooo08?ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`1iooooo`00Doooool00ol0003oooooooooo`23ooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool0NOooool005?ooooo0_l00025ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool0NOooool005?ooooo00?o0000ooooooooool0Q?oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo07[ooooo001Cooooo`03o`000?oooooo
oooo08Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1jooooo`00Doooool00ol0
003oooooooooo`24ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0N_ooool005?o
oooo00?o0000ooooooooool0Q?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo07_o
oooo001Cooooo`03o`000?oooooooooo08Cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`1kooooo`00Doooool00ol0003oooooooooo`24ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool0Noooool005?ooooo00?o0000ooooooooool0Q?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo07cooooo001Cooooo`;o0000Q_ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo07cooooo001Cooooo`03o`000?oooooooooo08Gooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`1looooo`00Doooool00ol0003oooooooooo`25ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool0O?ooool005?ooooo00?o0000ooooooooool0QOoo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo07cooooo001Cooooo`03o`000?oooooo
oooo08Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1mooooo`00Doooool00ol0
003oooooooooo`25ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0OOooool005?o
oooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo07go
oooo001Cooooo`03o`000?oooooooooo08Gooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`1mooooo`00Doooool2o`0008Kooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`1mooooo`00Doooool00ol0003oooooooooo`26ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0OOooool005?ooooo00?o0000ooooooooool0Q_ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo07gooooo001Cooooo`03o`000?oooooooooo08Kooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`1mooooo`00Doooool00ol0003oooooooooo`26ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool0OOooool005?ooooo00?o0000ooooooooool0Q_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo07kooooo000hooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo08Kooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`1nooooo`00>?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003ooooo
ooooo`26ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0O_ooool003Sooooo00Go
410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol00026ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool0O_ooool003Sooooo00Go0000oooooooooooooooo
o`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0Q_ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo07kooooo000hooooo`05o`000?ooooooooooooooool00000
3_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo08Kooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`1nooooo`00>?ooool01Ol@413ooooooooooooooooo410@00oooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`26ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0O_ooool003Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`27ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0O_ooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`27ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool0O_ooool005?ooooo00?o0000ooooooooool0Qoooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo07kooooo001Cooooo`03o`000?oooooooooo08Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`1nooooo`00Doooool00ol0003ooooooooo
o`27ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Ooooool005?ooooo0_l00028
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Ooooool005?ooooo00?o0000oooo
ooooool0Qoooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo07oooooo001Cooooo`03
o`000?oooooooooo08Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1oooooo`00
Doooool00ol0003oooooooooo`27ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
Ooooool005?ooooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo07oooooo001Cooooo`03o`000?oooooooooo08Oooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`1oooooo`00Doooool00ol0003oooooooooo`27ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0Ooooool005?ooooo00?o0000ooooooooool0Qoooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo07oooooo001Cooooo`;o0000ROooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo07oooooo001Cooooo`03o`000?oooooooooo08Sooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`1oooooo`00Doooool00ol0003oooooooooo`28
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0P?ooool005?ooooo00?o0000oooo
ooooool0R?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo083ooooo001Cooooo`03
o`000?oooooooooo08Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`20ooooo`00
Doooool00ol0003oooooooooo`28ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
P?ooool005?ooooo00?o0000ooooooooool0R?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo083ooooo001Cooooo`03o`000?oooooooooo08Sooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`20ooooo`00Doooool2o`0008Wooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`20ooooo`00Doooool00ol0003oooooooooo`28ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0P?ooool005?ooooo00?o0000ooooooooool0R?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo083ooooo001Cooooo`03o`000?oooooooooo08Sooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`20ooooo`00Doooool00ol0003oooooooooo`28
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0P?ooool005?ooooo00?o0000oooo
ooooool0R?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo087ooooo000hooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04oooo
o`03o`000?oooooooooo08Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`21oooo
o`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0R?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
087ooooo000hooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Kooooo0ol00028oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0POooool003Sooooo00Go0000oooooooo
ooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool0ROooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo087ooooo000hooooo`05o`000?oooooooooo
ooooool000002oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo08Wooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`21ooooo`00>?ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`29ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0POooool003Sooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0ROooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo087ooooo000hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Ooo
ool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo08Wooooo00Go0000oooooooooooooooo
o`000024ooooo`00Doooool00ol0003oooooooooo`29ooooo`05o`000?ooooooooooooooool00000
Q?ooool005?ooooo00?o0000ooooooooool0ROooool01Ol0003ooooooooooooooooo000008Cooooo
001Cooooo`;o0000R_ooool01Ol0003ooooooooooooooooo000008Cooooo001Cooooo`03o`000?oo
oooooooo08Wooooo00Go0000ooooooooooooooooo`000024ooooo`00Doooool00ol0003ooooooooo
o`29ooooo`04o`000?ooooooooooo`0008Gooooo001Cooooo`03o`000?oooooooooo08[ooooo00?o
0000ooooool00000QOooool005?ooooo00?o0000ooooooooool0R_ooool00ol0003oooooo`000025
ooooo`00Doooool00ol0003oooooooooo`2:ooooo`03o`000?oooooo000008Gooooo001Cooooo`03
o`000?oooooooooo08_ooooo00?o0000ooooooooool0Q?ooool005?ooooo00?o0000ooooooooool0
oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolD
ooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oo
oooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003ooooooooo
o`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000oooo
ooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000
oooooolDooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooo
oooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo000hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Co
oooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0?oooooo4oooool003So
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So
8B4Q00Kooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo4ooo
ool003Sooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B40
1_ooool3o`000?oooooo4oooool003Sooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`00
0?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`3ooooooa?ooooo000hooooo`05oa0@
4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo0?oo
oooo4oooool003Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00So
oooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00co
oooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03
o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Dooo
ool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0
003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo
00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001C
ooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCoooo
o`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Dooo
ool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool0
05?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?o
oooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooo
oolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo
0?oooooo4oooool005?ooooo0_l0003ooooooaCooooo001Cooooo`03o`000?oooooooooo0?oooooo
4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3o
oooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool003Sooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000
ooooooooool0oooooolCooooo`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`3ooooooa?ooooo000h
ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool0oooooolCooooo`00>?ooool01Ol0003ooooooooooooooooo000000_ooooo
00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000oooooolCooooo`00>?ooool01Ol0003ooooo
oooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo
0?oooooo4oooool003Sooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooo
okZj^_l@41001_ooool00ol0003oooooooooo`3ooooooa?ooooo000hooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool0oooo
oolCooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@
ojVYZ@06ooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooo
oolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo
0?oooooo4oooool005?ooooo0_l0003ooooooaCooooo001Cooooo`03o`000?oooooooooo0?oooooo
4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3o
oooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000oooooooo
ool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oo
oooooooo0?oooooo4oooool005?ooooo0_l0003ooooooaCooooo001Cooooo`03o`000?oooooooooo
0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003ooooo
ooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000
ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03
o`000?oooooooooo0?oooooo4oooool005?ooooo0_l0003ooooooaCooooo001Cooooo`03o`000?oo
oooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0
003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo
00?o0000ooooooooool0oooooolCooooo`00BOooool4o`000003oa0@4?oooooooooo00?ooooo00?o
0000ooooooooool0oooooolCooooo`00Boooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo0?oooooo4oooool004_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooo
oa?ooooo001;ooooo`03o`000?oooooooooo00Gooooo0ol0003ooooooa?ooooo001;ooooo`03o`00
0?oooooooooo0?oooooo6oooool004_ooooo00?o0000ooooooooool0oooooolKooooo`00Boooool0
0ol0003oooooooooo`3ooooooa_ooooo0019ooooo`03oeEEEOmVIVKo00000?oooooo7Oooool007So
oooo0ol000000ol@413oooooooooo`3Zooooo`00N_ooool00ol@413o^[Zjooooo`07ooooo`;o0000
2oooool00ol0003o^[Zjooooo`0<ooooo`;o00001Oooool00ol0003o^[Zjooooo`2nooooo`00N_oo
ool00onHV9So<S8booooo`07ooooo`03o`000?oooooooooo00[ooooo0_lb<S8>ooooo`03o`000?oo
oooooooo00?ooooo0_lb<S:oooooo`00N_ooool00ooMgMgo0000okZj^P07ooooo`04o`000?oooooo
ooooooooo`;o00000_ooool2o`0000?ooooo00?oQhN7o`000?nj^[X01?ooool01OnHV9So0000o`00
0?m4A4Co^[Zj00Cooooo00?o0000ooooooooool00oooool00on7QhOo0000okZj^P0<ooooo`05oiRH
V?l0003o0000odA4A?nj^[X04_ooool4o`000008oa0@4?oooooooooooiRHV?l@413o0000oc8b<_o<
c<b?ooooo`00N_ooool00omEEEGoMgMgodA4A007ooooo`0:o`000?ooooooooooooooooo^k^ko8B4Q
ohN7Qonj^[[o0000omgMg@?ooooo00?oc<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo
410@00Cooooo00?o0000ooooooooool00oooool00oo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[o
k^k^ogMgMol@41002Oooool6o`0000Gooooo00?o0000ooooooooool00_ooool01Ol@413o^[Zjoooo
oomgMgOo<S8b08oooooo001iooooo`05omgMgOl@413oooooob4Q8OoMgMd01_ooool00ol0003ooooo
ooooo`02ooooo`04omgMgOl0003o410@olc<c0_ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`2=ooooo`00NOooool01OmVIVKoQhN7oooooonHV9SoEEEE00Kooooo00?o0000oooooooo
ool00_ooool01?o^k^ko8B4Qoa0@4?o^k^h;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0;ooooo`Ko00001Oooool00ol0003oooooooooo`05oooo
o`03ojVYZOl@413ooooo08kooooo001hooooo`03onk^k_l0003ok^k^00;ooooo00?o0000omgMgOoo
ool01?ooool00ol0003oooooooooo`02ooooo`04ob4Q8OmgMgOoMgMgoc8b<P_ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool01?ooool00ol@413o0000okZj^P2?ooooo`00N?ooool01?l@413o0000o`000?ooool2o`00
0003oa0@4?oooooooooo00?ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00002?ooool0
0ol@413o0000o`000003o`0000Gooooo00?o0000ooooooooool04?ooool00ol@413o0000o`000003
o`0001Gooooo00?o0000ooooooooool01Oooool00onj^[[o8B4Qooooo`2>ooooo`00Q?ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo00;ooooo00Go410@oiRHV?oooooo^[Zjo`00002?
ooooo`00Q?ooool2o`0001;ooooo00?o0000ooooooooool01Oooool2o`0001Cooooo00?o0000oooo
ooooool05?ooool00omEEEGoIVIVo`000004ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0Soooool0
0?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-3.4116, -0.234311, \
0.0510397, 0.00762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.230769 0.0769231 0.103006 0.515028 [
[.07692 .09051 -6 -9 ]
[.07692 .09051 6 0 ]
[.38462 .09051 -3 -9 ]
[.38462 .09051 3 0 ]
[.53846 .09051 -3 -9 ]
[.53846 .09051 3 0 ]
[.69231 .09051 -3 -9 ]
[.69231 .09051 3 0 ]
[.84615 .09051 -3 -9 ]
[.84615 .09051 3 0 ]
[1 .09051 -6 -9 ]
[1 .09051 6 0 ]
[1.025 .10301 0 -6 ]
[1.025 .10301 10 6 ]
[.21827 0 -24 -4.5 ]
[.21827 0 0 4.5 ]
[.21827 .20601 -18 -4.5 ]
[.21827 .20601 0 4.5 ]
[.21827 .30902 -18 -4.5 ]
[.21827 .30902 0 4.5 ]
[.21827 .41202 -18 -4.5 ]
[.21827 .41202 0 4.5 ]
[.21827 .51503 -18 -4.5 ]
[.21827 .51503 0 4.5 ]
[.21827 .61803 -6 -4.5 ]
[.21827 .61803 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07692 .10301 m
.07692 .10926 L
s
[(-2)] .07692 .09051 0 1 Mshowa
.38462 .10301 m
.38462 .10926 L
s
[(2)] .38462 .09051 0 1 Mshowa
.53846 .10301 m
.53846 .10926 L
s
[(4)] .53846 .09051 0 1 Mshowa
.69231 .10301 m
.69231 .10926 L
s
[(6)] .69231 .09051 0 1 Mshowa
.84615 .10301 m
.84615 .10926 L
s
[(8)] .84615 .09051 0 1 Mshowa
1 .10301 m
1 .10926 L
s
[(10)] 1 .09051 0 1 Mshowa
.125 Mabswid
.11538 .10301 m
.11538 .10676 L
s
.15385 .10301 m
.15385 .10676 L
s
.19231 .10301 m
.19231 .10676 L
s
.26923 .10301 m
.26923 .10676 L
s
.30769 .10301 m
.30769 .10676 L
s
.34615 .10301 m
.34615 .10676 L
s
.42308 .10301 m
.42308 .10676 L
s
.46154 .10301 m
.46154 .10676 L
s
.5 .10301 m
.5 .10676 L
s
.57692 .10301 m
.57692 .10676 L
s
.61538 .10301 m
.61538 .10676 L
s
.65385 .10301 m
.65385 .10676 L
s
.73077 .10301 m
.73077 .10676 L
s
.76923 .10301 m
.76923 .10676 L
s
.80769 .10301 m
.80769 .10676 L
s
.88462 .10301 m
.88462 .10676 L
s
.92308 .10301 m
.92308 .10676 L
s
.96154 .10301 m
.96154 .10676 L
s
.03846 .10301 m
.03846 .10676 L
s
.25 Mabswid
0 .10301 m
1 .10301 L
s
gsave
1.025 .10301 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.23077 0 m
.23702 0 L
s
[(-0.2)] .21827 0 1 0 Mshowa
.23077 .20601 m
.23702 .20601 L
s
[(0.2)] .21827 .20601 1 0 Mshowa
.23077 .30902 m
.23702 .30902 L
s
[(0.4)] .21827 .30902 1 0 Mshowa
.23077 .41202 m
.23702 .41202 L
s
[(0.6)] .21827 .41202 1 0 Mshowa
.23077 .51503 m
.23702 .51503 L
s
[(0.8)] .21827 .51503 1 0 Mshowa
.23077 .61803 m
.23702 .61803 L
s
[(1)] .21827 .61803 1 0 Mshowa
.125 Mabswid
.23077 .02575 m
.23452 .02575 L
s
.23077 .0515 m
.23452 .0515 L
s
.23077 .07725 m
.23452 .07725 L
s
.23077 .12876 m
.23452 .12876 L
s
.23077 .15451 m
.23452 .15451 L
s
.23077 .18026 m
.23452 .18026 L
s
.23077 .23176 m
.23452 .23176 L
s
.23077 .25751 m
.23452 .25751 L
s
.23077 .28327 m
.23452 .28327 L
s
.23077 .33477 m
.23452 .33477 L
s
.23077 .36052 m
.23452 .36052 L
s
.23077 .38627 m
.23452 .38627 L
s
.23077 .43777 m
.23452 .43777 L
s
.23077 .46353 m
.23452 .46353 L
s
.23077 .48928 m
.23452 .48928 L
s
.23077 .54078 m
.23452 .54078 L
s
.23077 .56653 m
.23452 .56653 L
s
.23077 .59228 m
.23452 .59228 L
s
.25 Mabswid
.23077 0 m
.23077 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
123.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(14) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.6175 .10301 m
.6192 .10301 L
.62081 .10301 L
.62231 .10301 L
.62418 .10301 L
.62595 .10301 L
.62753 .10301 L
.62925 .10301 L
.63112 .10301 L
.63207 .10301 L
.6331 .10301 L
.63494 .10301 L
.63665 .10301 L
.63842 .10301 L
.64006 .10301 L
.64187 .10301 L
.64378 .10301 L
.64544 .10301 L
.64699 .10301 L
.6487 .10301 L
.65054 .10301 L
.65207 .10301 L
.65375 .10301 L
.65551 .10303 L
.65714 .10308 L
.65867 .10319 L
.66007 .10338 L
.66168 .1038 L
.6632 .10455 L
.66484 .10595 L
.66665 .10858 L
.66854 .11313 L
.6703 .11962 L
.67195 .12812 L
.67346 .13826 L
.67685 .16989 L
.68402 .26448 L
.68591 .28919 L
.68796 .31235 L
.68889 .32132 L
.68988 .32942 L
.69166 .3401 L
.69352 .34573 L
.69525 .34577 L
.69715 .3404 L
.69822 .33515 L
.69919 .32914 L
.70269 .29986 L
.70601 .26585 L
.71246 .20054 L
Mistroke
.716 .17166 L
.71931 .15045 L
.72289 .13363 L
.72478 .1269 L
.72682 .1211 L
.72859 .1171 L
.73045 .11375 L
.73219 .11128 L
.73376 .10949 L
.73564 .10782 L
.73765 .10648 L
.73951 .10555 L
.74127 .1049 L
.74331 .10433 L
.7452 .10395 L
.74727 .10366 L
.74832 .10354 L
.74946 .10344 L
.75135 .10331 L
.7531 .10322 L
.75502 .10316 L
.75599 .10313 L
.75707 .10311 L
.75885 .10308 L
.75986 .10306 L
.76078 .10305 L
.76248 .10304 L
.76427 .10303 L
.76589 .10302 L
.76762 .10302 L
.76925 .10301 L
.77073 .10301 L
.77247 .10301 L
.77436 .10301 L
.77614 .10301 L
.77779 .10301 L
.77954 .10301 L
.78142 .10301 L
.78319 .10301 L
.78482 .10301 L
.78671 .10301 L
.78779 .10301 L
.78878 .10301 L
.79061 .10301 L
.79162 .10301 L
.79255 .10301 L
.79353 .10301 L
.79456 .10301 L
.79642 .10301 L
.79745 .10301 L
Mistroke
.79841 .10301 L
.79947 .10301 L
.8006 .10301 L
.80158 .10301 L
.80264 .10301 L
.80364 .10301 L
.80457 .10301 L
.80632 .10301 L
.80819 .10301 L
.80984 .10301 L
.81165 .10301 L
.81354 .10301 L
.8153 .10301 L
.81695 .10301 L
.81846 .10301 L
.82019 .10301 L
.82182 .10301 L
.82361 .10301 L
.82549 .10301 L
.8271 .10301 L
.82887 .10301 L
.83078 .10301 L
.83185 .10301 L
.83282 .10301 L
.83472 .10301 L
.83652 .10301 L
.83819 .10301 L
.83971 .10301 L
.84147 .10301 L
.84312 .10301 L
.84465 .10301 L
.84606 .10301 L
.84761 .10301 L
.84924 .10301 L
.85089 .10301 L
.85266 .10301 L
.85433 .10301 L
.85585 .10301 L
.85764 .10301 L
.85865 .10301 L
.85958 .10301 L
.86129 .10301 L
.8631 .10301 L
.86485 .10301 L
.86676 .10301 L
.86856 .10301 L
.87024 .10301 L
.8719 .10301 L
.8734 .10301 L
.87514 .10301 L
Mistroke
.87677 .10301 L
.87856 .10301 L
.88045 .10301 L
.88207 .10301 L
.88384 .10301 L
.88575 .10301 L
.88682 .10301 L
.88779 .10301 L
.88969 .10301 L
.89149 .10301 L
.89301 .10301 L
.89469 .10301 L
.89645 .10301 L
.8981 .10301 L
.89964 .10301 L
.90105 .10301 L
.9026 .10301 L
.90422 .10301 L
.90588 .10301 L
.90765 .10301 L
.90932 .10301 L
.91084 .10301 L
.91263 .10301 L
.91364 .10301 L
.91457 .10301 L
.91628 .10301 L
.91809 .10301 L
.91984 .10301 L
.92176 .10301 L
.92357 .10301 L
.92525 .10301 L
.92691 .10301 L
.92842 .10301 L
.93016 .10301 L
.9318 .10301 L
.93359 .10301 L
.93549 .10301 L
.9371 .10301 L
.93888 .10301 L
.94079 .10301 L
.94186 .10301 L
.94284 .10301 L
.94474 .10301 L
.94653 .10301 L
.94806 .10301 L
.94975 .10301 L
.95151 .10301 L
.95316 .10301 L
.9547 .10301 L
.95611 .10301 L
Mistroke
.95766 .10301 L
.95929 .10301 L
.96095 .10301 L
.96272 .10301 L
.96439 .10301 L
.96591 .10301 L
.9677 .10301 L
.96871 .10301 L
.96964 .10301 L
.97135 .10301 L
.97315 .10301 L
.97492 .10301 L
.97684 .10301 L
.97866 .10301 L
.98034 .10301 L
.98185 .10301 L
.98352 .10301 L
.98526 .10301 L
.9869 .10301 L
.9887 .10301 L
.9906 .10301 L
.99222 .10301 L
.99399 .10301 L
.99591 .10301 L
.99698 .10301 L
.99796 .10301 L
.99986 .10301 L
Mfstroke
.99986 .10301 m
1 .10301 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000oooooolLooooo`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0oooooolLooooo`00<?ooool6o`0000;o
oooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^0?oooooo7Oooool003So
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003ooooo
oa?ooooo000hooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05oooo
o`03o`000?oooooooooo0?oooooo4oooool003Sooooo00Go410@oooooooooooooooooa0@400?oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooo
oooo0?oooooo4oooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooo
oooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003ooooooooo
o`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000oooo
ooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`00
0?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool0
0ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o
0000ooooooooool0oooooolCooooo`008oooool5o`0002_ooooo00?o0000ooooooooool0:oooool5
o`0002kooooo0_l000000ol@413oooooooooo`0Zooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?oo
ool01Oo<c<co8B4Qo`000?lQ8B7oc<c<02Wooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`00
0?lb<S;ok^k^6_ooool002?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00[ooooo`03o`000?oooooo
oooo02_ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00_ooooo`03o`000?oooooooooo02_ooooo00Go
EEEEogMgMoooooooV9RHob4Q8@0/ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40:oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool001_ooooo1_l00003ooooo`03
oiRHV?lQ8B7ok^k^02cooooo00?o0000ooooooooool0;?ooool00onHV9So8B4Qonk^kP0]ooooo`Go
0000;?ooool01Ol0003ooooooooooooooooo000002cooooo00Go0000ooooooooooooooooo`00000[
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Jooooo`009Oooool0
0onHV9So8B4Qonk^kP0[ooooo`03o`000?oooooooooo02gooooo00?oV9RHob4Q8Oo^k^h0;?ooool0
1?m4A4CogMgMooooool0000]ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;?ooool01Olb<S;oV9RH
oooooonHV9So<S8b02_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
01[ooooo000Vooooo`03ogMgMomVIVKooooo02[ooooo0_l0000_ooooo`03ogMgMomVIVKooooo02_o
oooo00CogMgMoeEEEOoooooo0000;Oooool01Ol0003oEEEEo`000?l@413oc<c<02cooooo00Goc<c<
o`000?l0003o0000olc<c00[ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Jooooo`009oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool0:oooool00omgMgOoc<c<o`00000]ooooo`03oeEEEOn7QhOooooo02kooooo00Go
410@okZj^_oooooo^[Zjoa0@400[ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@400Jooooo`008oooool01Ol0003o^[ZjoooooonHV9So410@02_ooooo00?o0000oooooooo
ool0:oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo00?ok^k^odA4A?l00000;Oooool00ooM
gMgo410@oiRHV00^ooooo`05o`000?nj^[[ooooookZj^_l00000:oooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool002?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00[ooooo`03o`000?oooooooooo02_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00^ooooo`03ogMg
Mol0003ooooo02gooooo00Coc<c<odA4A?l0003o410@;?ooool01OnYZJWo410@o`000?l@413oZJVY
02Wooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo001Coooo
o`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00
Doooool00ol0003oooooooooo`3mooooo`;o00000_ooool2o`0000oooooo001Cooooo`03o`000?oo
oooooooo0?gooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd?ooooo`00Doooool00ol0003ooooo
ooooo`3nooooo`04omgMgOl0003o410@olc<c13ooooo000:oooooooo0000@?l0000;ooooo`04onk^
k_lQ8B7o410@onk^kQ3ooooo000Fooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00Go0000oooooooooooo
ooooo`000007ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooool000002Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`04ob4Q8OmgMgOoMgMgoc8b<Q3ooooo000Rooooo`03o`000?oooooooooo02ko
oooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`08ooooo`;o00000_ooool2o`0000oo
oooo001Cooooo`03o`000?oooooooooo08Sooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`1cooooo`00Doooool00ol0003oooooooooo`28ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool0Loooool005?ooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo07Cooooo001Cooooo`03o`000?oooooooooo08Wooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`1dooooo`00Doooool00ol0003oooooooooo`2:ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool0MOooool005?ooooo0_l0002;ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool0MOooool005?ooooo00?o0000ooooooooool0R_oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo07Gooooo001Cooooo`03o`000?oooooo
oooo08[ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1eooooo`00Doooool00ol0
003oooooooooo`2:ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0MOooool005?o
oooo00?o0000ooooooooool0R_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo07Go
oooo001Cooooo`03o`000?oooooooooo08[ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`1fooooo`00Doooool00ol0003oooooooooo`2:ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool0M_ooool005?ooooo00?o0000ooooooooool0R_ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo07Kooooo001Cooooo`;o0000Roooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo07Kooooo001Cooooo`03o`000?oooooooooo08_ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`1fooooo`00Doooool00ol0003oooooooooo`2;ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool0M_ooool005?ooooo00?o0000ooooooooool0Rooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo07Oooooo001Cooooo`03o`000?oooooo
oooo08_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1gooooo`00Doooool00ol0
003oooooooooo`2;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0Moooool005?o
oooo00?o0000ooooooooool0Roooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo07Oo
oooo001Cooooo`03o`000?oooooooooo08_ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`1gooooo`00Doooool2o`0008cooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`1hooooo`00Doooool00ol0003oooooooooo`2;ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0N?ooool005?ooooo00?o0000ooooooooool0Roooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo07Sooooo001Cooooo`03o`000?oooooooooo08_ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`1hooooo`00Doooool00ol0003oooooooooo`2;ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool0N?ooool005?ooooo00?o0000ooooooooool0S?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo07Wooooo000hooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo08cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`1iooooo`00>?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003ooooo
ooooo`2<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0NOooool003Sooooo00Go
410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0002<ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool0NOooool003Sooooo00Go0000oooooooooooooooo
o`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0S?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo07Wooooo000hooooo`05o`000?ooooooooooooooool00000
3_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo08cooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`1iooooo`00>?ooool01Ol@413ooooooooooooooooo410@00oooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`2<ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0NOooool003Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`00
0?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`2<ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0NOooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`2<ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0N_ooool005?ooooo00?o0000ooooooooool0S?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo07[ooooo001Cooooo`03o`000?oooooooooo08cooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`1jooooo`00Doooool00ol0003ooooooooo
o`2<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0N_ooool005?ooooo0_l0002=
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0N_ooool005?ooooo00?o0000oooo
ooooool0S?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo07[ooooo001Cooooo`03
o`000?oooooooooo08cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1jooooo`00
Doooool00ol0003oooooooooo`2=ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
N_ooool005?ooooo00?o0000ooooooooool0SOooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo07[ooooo001Cooooo`03o`000?oooooooooo08gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`1jooooo`00Doooool00ol0003oooooooooo`2=ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0Noooool005?ooooo00?o0000ooooooooool0SOooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo07_ooooo001Cooooo`;o0000S_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo07_ooooo001Cooooo`03o`000?oooooooooo08gooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`1kooooo`00Doooool00ol0003oooooooooo`2=
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Noooool005?ooooo00?o0000oooo
ooooool0SOooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo07_ooooo001Cooooo`03
o`000?oooooooooo08gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1kooooo`00
Doooool00ol0003oooooooooo`2=ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
Noooool005?ooooo00?o0000ooooooooool0SOooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo07_ooooo001Cooooo`03o`000?oooooooooo08kooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`1kooooo`00Doooool2o`0008oooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`1looooo`00Doooool00ol0003oooooooooo`2>ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0O?ooool005?ooooo00?o0000ooooooooool0S_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo07cooooo001Cooooo`03o`000?oooooooooo08kooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`1looooo`00Doooool00ol0003oooooooooo`2>
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0O?ooool005?ooooo00?o0000oooo
ooooool0S_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo07cooooo000hooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04oooo
o`03o`000?oooooooooo08oooooo00Go0000ooooooooooooooooo`00001nooooo`00>?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0Soooool01Ol0003ooooooooooooooooo000007kooooo000hooooo`05oa0@4?oooooo
ooooooooool@41002oooool5o`0000Kooooo0ol0002?ooooo`05o`000?ooooooooooooooool00000
O_ooool003Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Oo
oooo00?o0000ooooooooool0Soooool01Ol0003ooooooooooooooooo000007kooooo000hooooo`05
o`000?ooooooooooooooool000002oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooo
oooo08oooooo00Go0000ooooooooooooooooo`00001nooooo`00>?ooool01Ol@413ooooooooooooo
oooo410@00cooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`2?ooooo`04o`000?oo
ooooooooo`0007oooooo000hooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4
o`000007ooooo`03o`000?oooooooooo08oooooo00Co0000oooooooooooo0000Ooooool003Sooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000oooooooo
ool0Soooool01?l0003oooooooooool0001oooooo`00Doooool00ol0003oooooooooo`2?ooooo`04
o`000?ooooooooooo`0007oooooo001Cooooo`03o`000?oooooooooo08oooooo00Co0000oooooooo
oooo0000Ooooool005?ooooo0_l0002@ooooo`04o`000?ooooooooooo`0007oooooo001Cooooo`03
o`000?oooooooooo093ooooo00?o0000ooooool00000Ooooool005?ooooo00?o0000ooooooooool0
T?ooool00ol0003oooooo`00001oooooo`00Doooool00ol0003oooooooooo`2@ooooo`03o`000?oo
oooo000007oooooo001Cooooo`03o`000?oooooooooo093ooooo0_l00020ooooo`00Doooool00ol0
003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo
00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001C
ooooo`;o0000oooooolDooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03
o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Dooo
ool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool0
05?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?o
oooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001C
ooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCoooo
o`00Doooool00ol0003oooooooooo`3ooooooa?ooooo000hooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo
0?oooooo4oooool003Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmE
EEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01Ol@
413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oo
oooooooo0?oooooo4oooool003Sooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nH
V9SooooooiRHV?lQ8B401_ooool3o`000?oooooo4oooool003Sooooo00Go0000oooooooooooooooo
o`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`3ooooooa?o
oooo000hooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`08ooooo`03
o`000?oooooooooo0?oooooo4oooool003Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03
omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`3ooooo
oa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0
oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolD
ooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oo
oooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003ooooooooo
o`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000oooo
ooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000
oooooolDooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooo
oooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o
0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Coooo
o`03o`000?oooooooooo0?oooooo4oooool005?ooooo0_l0003ooooooaCooooo001Cooooo`03o`00
0?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool0
0ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool003So
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003ooooooooo
o`3ooooooa?ooooo000hooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooo
oooooooo000000Kooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01Ol0003ooooooooo
oooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000oooooolCooooo`00
>?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c006oooo
o`03o`000?oooooooooo0?oooooo4oooool003Sooooo00Go410@oooooooooooooooooa0@400;oooo
o`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`3ooooooa?ooooo000hoooo
o`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o
0000ooooooooool0oooooolCooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00Go
ZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o
0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Coooo
o`03o`000?oooooooooo0?oooooo4oooool005?ooooo0_l0003ooooooaCooooo001Cooooo`03o`00
0?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool0
0ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?o
oooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo
001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo0_l0003ooooooaCooooo001Coooo
o`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00
Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4ooo
ool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooo
oa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo0_l0003ooooooaCooooo
001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolC
ooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oo
oooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00BOooool4o`000003oa0@4?oo
oooooooo00?ooooo00?o0000ooooooooool0oooooolCooooo`00Boooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0?oooooo4oooool004_ooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`3ooooooa?ooooo001;ooooo`03o`000?oooooooooo00Gooooo0ol0003ooooooa?o
oooo001;ooooo`03o`000?oooooooooo0?oooooo6oooool004_ooooo00?o0000ooooooooool0oooo
oolKooooo`00Boooool00ol0003oooooooooo`3ooooooa_ooooo0019ooooo`03oeEEEOmVIVKo0000
0?oooooo7Oooool007Sooooo0ol000000ol@413oooooooooo`3Zooooo`00N_ooool00ol@413o^[Zj
ooooo`07ooooo`;o00002oooool00ol0003o^[Zjooooo`0<ooooo`;o00001Oooool00ol0003o^[Zj
ooooo`2nooooo`00N_ooool00onHV9So<S8booooo`07ooooo`03o`000?oooooooooo00[ooooo0_lb
<S8>ooooo`03o`000?oooooooooo00?ooooo0_lb<S:oooooo`00N_ooool00ooMgMgo0000okZj^P07
ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000?ooooo00?oQhN7o`000?nj^[X01?oo
ool01OnHV9So0000o`000?m4A4Co^[Zj00Cooooo00?o0000ooooooooool00oooool00on7QhOo0000
okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X04_ooool4o`000003oa0@4?oooooooooo00;o
oooo0_l000000ol@413oooooooooo`2=ooooo`00N_ooool00omEEEGoMgMgodA4A007ooooo`0:o`00
0?ooooooooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgMg@?ooooo00?oc<c<o`000?l@41001?oo
ool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo00?o0000ooooooooool00oooool00oo<c<co0000
oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`2>ooooo`00NOooool01OoMgMgo410@oooooolQ8B7ogMgM00Ko
oooo00?o0000ooooooooool00_ooool01?oMgMgo0000oa0@4?o<c<`;ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
00;ooooo1Ol0002?ooooo`00NOooool01OmVIVKoQhN7oooooonHV9SoEEEE00Kooooo00?o0000oooo
ooooool00_ooool01?o^k^ko8B4Qoa0@4?o^k^h;ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0;ooooo`Ko00001Oooool00ol0003oooooooooo`02
ooooo`04odA4A?oMgMgoooooo`00093ooooo001hooooo`03onk^k_l0003ok^k^00;ooooo00?o0000
omgMgOooool01?ooool00ol0003oooooooooo`02ooooo`04ob4Q8OmgMgOoMgMgoc8b<P_ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool00_ooool01?oMgMgoEEEEooooool0002@ooooo`00N?ooool01?l@413o0000o`00
0?ooool2o`000003oa0@4?oooooooooo00?ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o
00002?ooool00ol@413o0000o`000003o`0000Gooooo00?o0000ooooooooool04?ooool00ol@413o
0000o`000003o`0001Gooooo00?o0000ooooooooool00oooool00omgMgOoc<c<o`00002@ooooo`00
Q?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00?ooooo00?ok^k^odA4A?l00000
T?ooool008Cooooo0_l0000Booooo`03o`000?oooooooooo00Gooooo0_l0000Dooooo`03o`000?oo
oooooooo01Cooooo00?oEEEEofIVI_l000001_ooool00omgMgOo0000ooooo`2?ooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-3.4116, -0.234311, \
0.0510397, 0.00762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.230769 0.0769231 0.103006 0.515028 [
[.07692 .09051 -6 -9 ]
[.07692 .09051 6 0 ]
[.38462 .09051 -3 -9 ]
[.38462 .09051 3 0 ]
[.53846 .09051 -3 -9 ]
[.53846 .09051 3 0 ]
[.69231 .09051 -3 -9 ]
[.69231 .09051 3 0 ]
[.84615 .09051 -3 -9 ]
[.84615 .09051 3 0 ]
[1 .09051 -6 -9 ]
[1 .09051 6 0 ]
[1.025 .10301 0 -6 ]
[1.025 .10301 10 6 ]
[.21827 0 -24 -4.5 ]
[.21827 0 0 4.5 ]
[.21827 .20601 -18 -4.5 ]
[.21827 .20601 0 4.5 ]
[.21827 .30902 -18 -4.5 ]
[.21827 .30902 0 4.5 ]
[.21827 .41202 -18 -4.5 ]
[.21827 .41202 0 4.5 ]
[.21827 .51503 -18 -4.5 ]
[.21827 .51503 0 4.5 ]
[.21827 .61803 -6 -4.5 ]
[.21827 .61803 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07692 .10301 m
.07692 .10926 L
s
[(-2)] .07692 .09051 0 1 Mshowa
.38462 .10301 m
.38462 .10926 L
s
[(2)] .38462 .09051 0 1 Mshowa
.53846 .10301 m
.53846 .10926 L
s
[(4)] .53846 .09051 0 1 Mshowa
.69231 .10301 m
.69231 .10926 L
s
[(6)] .69231 .09051 0 1 Mshowa
.84615 .10301 m
.84615 .10926 L
s
[(8)] .84615 .09051 0 1 Mshowa
1 .10301 m
1 .10926 L
s
[(10)] 1 .09051 0 1 Mshowa
.125 Mabswid
.11538 .10301 m
.11538 .10676 L
s
.15385 .10301 m
.15385 .10676 L
s
.19231 .10301 m
.19231 .10676 L
s
.26923 .10301 m
.26923 .10676 L
s
.30769 .10301 m
.30769 .10676 L
s
.34615 .10301 m
.34615 .10676 L
s
.42308 .10301 m
.42308 .10676 L
s
.46154 .10301 m
.46154 .10676 L
s
.5 .10301 m
.5 .10676 L
s
.57692 .10301 m
.57692 .10676 L
s
.61538 .10301 m
.61538 .10676 L
s
.65385 .10301 m
.65385 .10676 L
s
.73077 .10301 m
.73077 .10676 L
s
.76923 .10301 m
.76923 .10676 L
s
.80769 .10301 m
.80769 .10676 L
s
.88462 .10301 m
.88462 .10676 L
s
.92308 .10301 m
.92308 .10676 L
s
.96154 .10301 m
.96154 .10676 L
s
.03846 .10301 m
.03846 .10676 L
s
.25 Mabswid
0 .10301 m
1 .10301 L
s
gsave
1.025 .10301 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.23077 0 m
.23702 0 L
s
[(-0.2)] .21827 0 1 0 Mshowa
.23077 .20601 m
.23702 .20601 L
s
[(0.2)] .21827 .20601 1 0 Mshowa
.23077 .30902 m
.23702 .30902 L
s
[(0.4)] .21827 .30902 1 0 Mshowa
.23077 .41202 m
.23702 .41202 L
s
[(0.6)] .21827 .41202 1 0 Mshowa
.23077 .51503 m
.23702 .51503 L
s
[(0.8)] .21827 .51503 1 0 Mshowa
.23077 .61803 m
.23702 .61803 L
s
[(1)] .21827 .61803 1 0 Mshowa
.125 Mabswid
.23077 .02575 m
.23452 .02575 L
s
.23077 .0515 m
.23452 .0515 L
s
.23077 .07725 m
.23452 .07725 L
s
.23077 .12876 m
.23452 .12876 L
s
.23077 .15451 m
.23452 .15451 L
s
.23077 .18026 m
.23452 .18026 L
s
.23077 .23176 m
.23452 .23176 L
s
.23077 .25751 m
.23452 .25751 L
s
.23077 .28327 m
.23452 .28327 L
s
.23077 .33477 m
.23452 .33477 L
s
.23077 .36052 m
.23452 .36052 L
s
.23077 .38627 m
.23452 .38627 L
s
.23077 .43777 m
.23452 .43777 L
s
.23077 .46353 m
.23452 .46353 L
s
.23077 .48928 m
.23452 .48928 L
s
.23077 .54078 m
.23452 .54078 L
s
.23077 .56653 m
.23452 .56653 L
s
.23077 .59228 m
.23452 .59228 L
s
.25 Mabswid
.23077 0 m
.23077 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
123.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(15) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.63841 .10301 m
.64004 .10301 L
.64183 .10301 L
.64374 .10301 L
.64557 .10301 L
.64728 .10301 L
.64882 .10301 L
.65049 .10301 L
.65202 .10301 L
.65369 .10301 L
.65545 .10301 L
.65708 .10301 L
.65861 .10301 L
.66001 .10301 L
.66162 .10301 L
.66315 .10301 L
.66478 .10301 L
.66659 .10301 L
.66847 .10301 L
.67024 .10301 L
.67189 .10301 L
.6734 .10302 L
.67506 .10305 L
.6768 .10314 L
.67858 .10337 L
.68048 .10394 L
.68227 .10508 L
.6839 .10696 L
.68581 .11077 L
.68689 .11397 L
.68789 .11774 L
.68972 .12713 L
.69166 .14102 L
.69855 .22263 L
.70195 .27086 L
.7051 .30887 L
.70685 .32434 L
.70871 .33517 L
.70978 .33855 L
.71078 .33985 L
.71265 .33753 L
.71438 .33034 L
.71597 .32009 L
.71955 .28778 L
.72726 .20636 L
.73147 .17011 L
.73353 .15599 L
.7354 .14516 L
.73881 .12993 L
.74069 .12371 L
Mistroke
.74247 .11899 L
.74428 .1152 L
.74619 .11206 L
.74829 .10947 L
.75023 .10769 L
.75189 .10654 L
.7537 .10558 L
.7556 .10484 L
.75736 .10434 L
.75901 .10399 L
.76052 .10375 L
.76225 .10354 L
.76389 .10339 L
.76567 .10328 L
.76756 .10319 L
.76918 .10314 L
.77095 .1031 L
.77285 .10307 L
.77392 .10306 L
.7749 .10305 L
.7768 .10303 L
.77859 .10302 L
.78012 .10302 L
.7818 .10301 L
.78355 .10301 L
.7852 .10301 L
.78674 .10301 L
.78815 .10301 L
.7897 .10301 L
.79133 .10301 L
.79298 .10301 L
.79475 .10301 L
.79642 .10301 L
.79794 .10301 L
.79973 .10301 L
.80074 .10301 L
.80167 .10301 L
.80338 .10301 L
.80519 .10301 L
.80694 .10301 L
.80886 .10301 L
.81066 .10301 L
.81234 .10301 L
.814 .10301 L
.81551 .10301 L
.81725 .10301 L
.81888 .10301 L
.82068 .10301 L
.82257 .10301 L
.82419 .10301 L
Mistroke
.82596 .10301 L
.82787 .10301 L
.82894 .10301 L
.82992 .10301 L
.83181 .10301 L
.83361 .10301 L
.83514 .10301 L
.83682 .10301 L
.83858 .10301 L
.84023 .10301 L
.84177 .10301 L
.84318 .10301 L
.84473 .10301 L
.84636 .10301 L
.84802 .10301 L
.84979 .10301 L
.85146 .10301 L
.85298 .10301 L
.85477 .10301 L
.85578 .10301 L
.85671 .10301 L
.85842 .10301 L
.86022 .10301 L
.86199 .10301 L
.86391 .10301 L
.86572 .10301 L
.8674 .10301 L
.86907 .10301 L
.87058 .10301 L
.87232 .10301 L
.87396 .10301 L
.87575 .10301 L
.87765 .10301 L
.87927 .10301 L
.88105 .10301 L
.88296 .10301 L
.88403 .10301 L
.88501 .10301 L
.88691 .10301 L
.8887 .10301 L
.89024 .10301 L
.89192 .10301 L
.89369 .10301 L
.89534 .10301 L
.89688 .10301 L
.89829 .10301 L
.89992 .10301 L
.90147 .10301 L
.90313 .10301 L
.90491 .10301 L
Mistroke
.90658 .10301 L
.9081 .10301 L
.90989 .10301 L
.9109 .10301 L
.91182 .10301 L
.91353 .10301 L
.91533 .10301 L
.9171 .10301 L
.91811 .10301 L
.91903 .10301 L
.92073 .10301 L
.92254 .10301 L
.92415 .10301 L
.92566 .10301 L
.92732 .10301 L
.9291 .10301 L
.9309 .10301 L
.93191 .10301 L
.93286 .10301 L
.93477 .10301 L
.93583 .10301 L
.93681 .10301 L
.93855 .10301 L
.94044 .10301 L
.94222 .10301 L
.94387 .10301 L
.94541 .10301 L
.94705 .10301 L
.94861 .10301 L
.95003 .10301 L
.9517 .10301 L
.95351 .10301 L
.95522 .10301 L
.95681 .10301 L
.95861 .10301 L
.9603 .10301 L
.96181 .10301 L
.96345 .10301 L
.96524 .10301 L
.96714 .10301 L
.96875 .10301 L
.97052 .10301 L
.97242 .10301 L
.97418 .10301 L
.9751 .10301 L
.97611 .10301 L
.97717 .10301 L
.97816 .10301 L
.97998 .10301 L
.98164 .10301 L
Mistroke
.98347 .10301 L
.98539 .10301 L
.98701 .10301 L
.98874 .10301 L
.99037 .10301 L
.99186 .10301 L
.9936 .10301 L
.9955 .10301 L
.99728 .10301 L
.99893 .10301 L
Mfstroke
.99893 .10301 m
1 .10301 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000oooooolLooooo`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0oooooolLooooo`00<?ooool6o`0000;o
oooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^0?oooooo7Oooool003So
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003ooooo
oa?ooooo000hooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05oooo
o`03o`000?oooooooooo0?oooooo4oooool003Sooooo00Go410@oooooooooooooooooa0@400?oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooo
oooo0?oooooo4oooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooo
oooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003ooooooooo
o`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000oooo
ooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`00
0?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool0
0ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o
0000ooooooooool0oooooolCooooo`008oooool5o`0002_ooooo00?o0000ooooooooool0:oooool5
o`0002kooooo0_l000000ol@413oooooooooo`0Zooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?oo
ool01Oo<c<co8B4Qo`000?lQ8B7oc<c<02Wooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`00
0?lb<S;ok^k^6_ooool002?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00[ooooo`03o`000?oooooo
oooo02_ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00_ooooo`03o`000?oooooooooo02_ooooo00Go
EEEEogMgMoooooooV9RHob4Q8@0/ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40:oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool001_ooooo1_l00003ooooo`03
oiRHV?lQ8B7ok^k^02cooooo00?o0000ooooooooool0;?ooool00onHV9So8B4Qonk^kP0]ooooo`Go
0000;?ooool01Ol0003ooooooooooooooooo000002cooooo00Go0000ooooooooooooooooo`00000[
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Jooooo`009Oooool0
0onHV9So8B4Qonk^kP0[ooooo`03o`000?oooooooooo02gooooo00?oV9RHob4Q8Oo^k^h0;?ooool0
1?m4A4CogMgMooooool0000]ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;?ooool01Olb<S;oV9RH
oooooonHV9So<S8b02_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
01[ooooo000Vooooo`03ogMgMomVIVKooooo02[ooooo0_l0000_ooooo`03ogMgMomVIVKooooo02_o
oooo00CogMgMoeEEEOoooooo0000;Oooool01Ol0003oEEEEo`000?l@413oc<c<02cooooo00Goc<c<
o`000?l0003o0000olc<c00[ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Jooooo`009oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool0:oooool00omgMgOoc<c<o`00000]ooooo`03oeEEEOn7QhOooooo02kooooo00Go
410@okZj^_oooooo^[Zjoa0@400[ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@400Jooooo`008oooool01Ol0003o^[ZjoooooonHV9So410@02_ooooo00?o0000oooooooo
ool0:oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo00?ok^k^odA4A?l00000;Oooool00ooM
gMgo410@oiRHV00^ooooo`05o`000?nj^[[ooooookZj^_l00000:oooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool002?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00[ooooo`03o`000?oooooooooo02_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00^ooooo`03ogMg
Mol0003ooooo02gooooo00Coc<c<odA4A?l0003o410@;?ooool01OnYZJWo410@o`000?l@413oZJVY
02Wooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo001Coooo
o`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00
Doooool00ol0003oooooooooo`3mooooo`;o00000_ooool2o`0000oooooo001Cooooo`03o`000?oo
oooooooo0?gooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd?ooooo`00Doooool00ol0003ooooo
ooooo`3nooooo`04omgMgOl0003o410@olc<c13ooooo000:oooooooo0000@?l0000;ooooo`04onk^
k_lQ8B7o410@onk^kQ3ooooo000Fooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
1_ooool01?l0003oooooooooool0000;ooooo`03o`000?oooooooooo00?ooooo0_l00004ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Wooooo00Co8B4QogMgMomgMgOo<S8b4?ooool002;ooooo00?o0000oooooooo
ool0;_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02kooooo00?o0000oooooooo
ool0;?ooool00ol0003oooooo`00000@ooooo`;o00007_ooool00ol0003oooooooooo`0^ooooo`03
o`000?oooooooooo00Sooooo0_l00002ooooo`;o00003oooool005?ooooo00?o0000ooooooooool0
S_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo06kooooo001Cooooo`03o`000?oo
oooooooo08oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1^ooooo`00Doooool0
0ol0003oooooooooo`2?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0Koooool0
05?ooooo00?o0000ooooooooool0Soooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
073ooooo001Cooooo`03o`000?oooooooooo08oooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`1`ooooo`00Doooool2o`00093ooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`1`ooooo`00Doooool00ol0003oooooooooo`2?ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool0L?ooool005?ooooo00?o0000ooooooooool0T?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo073ooooo001Cooooo`03o`000?oooooooooo093ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`1aooooo`00Doooool00ol0003oooooooooo`2@ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0LOooool005?ooooo00?o0000ooooooooool0
T?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo077ooooo001Cooooo`03o`000?oo
oooooooo093ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1aooooo`00Doooool0
0ol0003oooooooooo`2@ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0L_ooool0
05?ooooo0_l0002Aooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0L_ooool005?o
oooo00?o0000ooooooooool0T?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo07;o
oooo001Cooooo`03o`000?oooooooooo093ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`1booooo`00Doooool00ol0003oooooooooo`2Aooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool0Loooool005?ooooo00?o0000ooooooooool0TOooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo07?ooooo001Cooooo`03o`000?oooooooooo097ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`1cooooo`00Doooool00ol0003oooooooooo`2Aooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool0Loooool005?ooooo00?o0000ooooooooool0
TOooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo07?ooooo001Cooooo`;o0000T_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo07?ooooo001Cooooo`03o`000?oooooo
oooo097ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1cooooo`00Doooool00ol0
003oooooooooo`2Aooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0Loooool005?o
oooo00?o0000ooooooooool0TOooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo07Co
oooo001Cooooo`03o`000?oooooooooo097ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`1dooooo`00Doooool00ol0003oooooooooo`2Aooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0M?ooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?oo
ool5o`0000Kooooo00?o0000ooooooooool0TOooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo07Cooooo000hooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go
V9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo097ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`1dooooo`00>?ooool01Ol@413ooooooooooooooooo410@00cooooo
00?oV9RHob4Q8Oo^k^h01oooool3o`0009;ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`1dooooo`00>?ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h0
1_ooool00ol0003oooooooooo`2Booooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
M?ooool003Sooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Gooooo
00?o0000ooooooooool0T_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo07Cooooo
000hooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo09;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1dooooo`00>?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03
o`000?oooooooooo09;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1dooooo`00
>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006oooo
o`03o`000?oooooooooo09;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1doooo
o`00Doooool00ol0003oooooooooo`2Booooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0M?ooool005?ooooo00?o0000ooooooooool0T_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo07Gooooo001Cooooo`03o`000?oooooooooo09;ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`1eooooo`00Doooool2o`0009?ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`1eooooo`00Doooool00ol0003oooooooooo`2Booooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0MOooool005?ooooo00?o0000ooooooooool0T_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo07Gooooo001Cooooo`03o`000?oooooooooo09;ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`1eooooo`00Doooool00ol0003ooooooooo
o`2Booooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0MOooool005?ooooo00?o0000
ooooooooool0Toooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo07Gooooo001Coooo
o`03o`000?oooooooooo09?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1eoooo
o`00Doooool00ol0003oooooooooo`2Cooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0MOooool005?ooooo0_l0002Dooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
MOooool005?ooooo00?o0000ooooooooool0Toooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo07Gooooo001Cooooo`03o`000?oooooooooo09?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`1eooooo`00Doooool00ol0003oooooooooo`2Cooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0M_ooool005?ooooo00?o0000ooooooooool0Toooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo07Kooooo001Cooooo`03o`000?oooooooooo09?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`1fooooo`00Doooool00ol0003ooooooooo
o`2Cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0M_ooool005?ooooo00?o0000
ooooooooool0Toooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07Kooooo001Coooo
o`;o0000U?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07Kooooo001Cooooo`03
o`000?oooooooooo09?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1fooooo`00
Doooool00ol0003oooooooooo`2Cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
M_ooool005?ooooo00?o0000ooooooooool0U?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo07Kooooo001Cooooo`03o`000?oooooooooo09Cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`1fooooo`00Doooool00ol0003oooooooooo`2Dooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0M_ooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0U?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo07Kooooo000hooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2Doooo
o`05o`000?ooooooooooooooool00000NOooool003Sooooo00Go410@oooooooooooooooooa0@400;
ooooo`Go00001_ooool3o`0009Cooooo00Go0000ooooooooooooooooo`00001iooooo`00>?ooool0
1Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00001oooool00ol0003ooooo
ooooo`2Dooooo`05o`000?ooooooooooooooool00000NOooool003Sooooo00Go0000oooooooooooo
ooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0U?ooool01Ol0
003ooooooooooooooooo000007Wooooo000hooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo09Gooooo00Co0000oooooooooooo0000NOoo
ool003Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo00?o
0000ooooooooool0UOooool01?l0003oooooooooool0001iooooo`00>?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`2Eooooo`04o`00
0?ooooooooooo`0007Wooooo001Cooooo`03o`000?oooooooooo09Gooooo00?o0000ooooool00000
N_ooool005?ooooo00?o0000ooooooooool0UOooool00ol0003oooooo`00001jooooo`00Doooool2
o`0009Kooooo00?o0000ooooool00000N_ooool005?ooooo00?o0000ooooooooool0UOooool2o`00
07_ooooo001Cooooo`03o`000?oooooooooo09Kooooo00?o0000ooooooooool0NOooool005?ooooo
00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001C
ooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCoooo
o`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo
4oooool005?ooooo0_l0003ooooooaCooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool0
05?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?o
oooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooo
oolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo
0?oooooo4oooool005?ooooo0_l0003ooooooaCooooo001Cooooo`03o`000?oooooooooo0?oooooo
4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3o
oooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool003Sooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000
ooooooooool0oooooolCooooo`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`3ooooooa?ooooo000h
ooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool0oooooolCooooo`00>?ooool01Ol0003ooooooooooooooooo000000_ooooo
00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000oooooolCooooo`00>?ooool01Ol0003ooooo
oooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo
0?oooooo4oooool003Sooooo00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo
00Sooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003oooooooooo`3ooooooa?ooooo000hooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooo
oooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo0_l0
003ooooooaCooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000oooo
ooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`00
0?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool0
0ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?o
oooo0_l0003ooooooaCooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o
0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Coooo
o`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00
Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4ooo
ool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool2o`000?oooooo5?ooool005?o
oooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo
001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolC
ooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o
0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3ooooooa?ooooo000hooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`00
0?oooooooooo0?oooooo4oooool003Sooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooa?ooooo000hooooo`05o`00
0?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0003ooooo
oa?ooooo000hooooo`05o`000?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003o
c<c<00Kooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01Ol@413ooooooooooooooooo
410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo0?oooooo4ooo
ool003Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l00000
1_ooool00ol0003oooooooooo`3ooooooa?ooooo000hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
2oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool0oooooolCooooo`00
Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4ooo
ool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool2o`000?oooooo5?ooool005?o
oooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo
001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolC
ooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oo
oooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool2o`000?oooooo5?oo
ool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooo
oa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0
oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooo
oooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool2o`000?oo
oooo5?ooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003ooooooooo
o`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000oooo
ooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo0019ooooo`Co0000
00?o410@ooooooooool00oooool00ol0003oooooooooo`3ooooooa?ooooo001;ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0oooooolCooooo`00Boooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo0?oooooo4oooool004_ooooo00?o0000ooooooooool01Oooool3o`00
0?oooooo4oooool004_ooooo00?o0000ooooooooool0oooooolKooooo`00Boooool00ol0003ooooo
ooooo`3ooooooa_ooooo001;ooooo`03o`000?oooooooooo0?oooooo6oooool004Wooooo00?oEEEE
ofIVI_l00000oooooolMooooo`00N?ooool3o`000003oa0@4?oooooooooo0>[ooooo001jooooo`03
oa0@4?nj^[[ooooo00Oooooo0_l0000;ooooo`03o`000?nj^[[ooooo00cooooo0_l00005ooooo`03
o`000?nj^[[ooooo0;kooooo001jooooo`03oiRHV?lb<S;ooooo00Oooooo00?o0000ooooooooool0
2_ooool2oc8b<Pkooooo00?o0000ooooooooool00oooool2oc8b<[oooooo001jooooo`03omgMgOl0
003o^[Zj00Oooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00000oooool00on7QhOo0000
okZj^P04ooooo`05oiRHV?l0003o0000odA4A?nj^[X01?ooool00ol0003oooooooooo`03ooooo`03
ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj^P0Booooo`Co000000Go410@oooo
ooooooooooooodA4A002o`000003oc8b<_oMgMgooooo08gooooo001jooooo`03oeEEEOmgMgOoA4A4
00Oooooo00[o0000ooooooooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0oooool00oo<c<co
0000oa0@4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003oooooooooo`03oooo
o`03olc<c?l0003o410@00cooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00001Oooool0
0ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo08gooooo001iooooo`05omgMgOl@413ooooo
ob4Q8OoMgMd01_ooool00ol0003oooooooooo`02ooooo`04omgMgOl0003o410@olc<c0_ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`2<ooooo`00NOooool01OmVIVKoQhN7oooooonH
V9SoEEEE00Kooooo00?o0000ooooooooool00_ooool01?o^k^ko8B4Qoa0@4?o^k^h;ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0;ooooo`Ko0000
1Oooool00ol0003oooooooooo`06ooooo`03ogMgMolb<S;ooooo08gooooo001hooooo`03onk^k_l0
003ok^k^00;ooooo00?o0000omgMgOooool01?ooool00ol0003oooooooooo`02ooooo`04ob4Q8Omg
MgOoMgMgoc8b<P_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool00oooool01Ol0003o8B4Qo`000?lb<S;oc<c<08ko
oooo001hooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool00oooool01?l0003o
ooooooooooooool2o`0000;ooooo0_l00008ooooo`03oa0@4?l0003o000000?o00001Oooool00ol0
003oooooooooo`0@ooooo`03oa0@4?l0003o000000?o00005Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo093ooooo0024ooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`2@ooooo`00Q?ooool2o`0001;ooooo00?o0000ooooooooool0
1Oooool2o`0001Cooooo00?o0000ooooooooool05?ooool00omEEEGoIVIVo`000005ooooo`Co0000
Soooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-3.4116, -0.234311, \
0.0510397, 0.00762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.230769 0.0769231 0.103006 0.515028 [
[.07692 .09051 -6 -9 ]
[.07692 .09051 6 0 ]
[.38462 .09051 -3 -9 ]
[.38462 .09051 3 0 ]
[.53846 .09051 -3 -9 ]
[.53846 .09051 3 0 ]
[.69231 .09051 -3 -9 ]
[.69231 .09051 3 0 ]
[.84615 .09051 -3 -9 ]
[.84615 .09051 3 0 ]
[1 .09051 -6 -9 ]
[1 .09051 6 0 ]
[1.025 .10301 0 -6 ]
[1.025 .10301 10 6 ]
[.21827 0 -24 -4.5 ]
[.21827 0 0 4.5 ]
[.21827 .20601 -18 -4.5 ]
[.21827 .20601 0 4.5 ]
[.21827 .30902 -18 -4.5 ]
[.21827 .30902 0 4.5 ]
[.21827 .41202 -18 -4.5 ]
[.21827 .41202 0 4.5 ]
[.21827 .51503 -18 -4.5 ]
[.21827 .51503 0 4.5 ]
[.21827 .61803 -6 -4.5 ]
[.21827 .61803 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07692 .10301 m
.07692 .10926 L
s
[(-2)] .07692 .09051 0 1 Mshowa
.38462 .10301 m
.38462 .10926 L
s
[(2)] .38462 .09051 0 1 Mshowa
.53846 .10301 m
.53846 .10926 L
s
[(4)] .53846 .09051 0 1 Mshowa
.69231 .10301 m
.69231 .10926 L
s
[(6)] .69231 .09051 0 1 Mshowa
.84615 .10301 m
.84615 .10926 L
s
[(8)] .84615 .09051 0 1 Mshowa
1 .10301 m
1 .10926 L
s
[(10)] 1 .09051 0 1 Mshowa
.125 Mabswid
.11538 .10301 m
.11538 .10676 L
s
.15385 .10301 m
.15385 .10676 L
s
.19231 .10301 m
.19231 .10676 L
s
.26923 .10301 m
.26923 .10676 L
s
.30769 .10301 m
.30769 .10676 L
s
.34615 .10301 m
.34615 .10676 L
s
.42308 .10301 m
.42308 .10676 L
s
.46154 .10301 m
.46154 .10676 L
s
.5 .10301 m
.5 .10676 L
s
.57692 .10301 m
.57692 .10676 L
s
.61538 .10301 m
.61538 .10676 L
s
.65385 .10301 m
.65385 .10676 L
s
.73077 .10301 m
.73077 .10676 L
s
.76923 .10301 m
.76923 .10676 L
s
.80769 .10301 m
.80769 .10676 L
s
.88462 .10301 m
.88462 .10676 L
s
.92308 .10301 m
.92308 .10676 L
s
.96154 .10301 m
.96154 .10676 L
s
.03846 .10301 m
.03846 .10676 L
s
.25 Mabswid
0 .10301 m
1 .10301 L
s
gsave
1.025 .10301 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.23077 0 m
.23702 0 L
s
[(-0.2)] .21827 0 1 0 Mshowa
.23077 .20601 m
.23702 .20601 L
s
[(0.2)] .21827 .20601 1 0 Mshowa
.23077 .30902 m
.23702 .30902 L
s
[(0.4)] .21827 .30902 1 0 Mshowa
.23077 .41202 m
.23702 .41202 L
s
[(0.6)] .21827 .41202 1 0 Mshowa
.23077 .51503 m
.23702 .51503 L
s
[(0.8)] .21827 .51503 1 0 Mshowa
.23077 .61803 m
.23702 .61803 L
s
[(1)] .21827 .61803 1 0 Mshowa
.125 Mabswid
.23077 .02575 m
.23452 .02575 L
s
.23077 .0515 m
.23452 .0515 L
s
.23077 .07725 m
.23452 .07725 L
s
.23077 .12876 m
.23452 .12876 L
s
.23077 .15451 m
.23452 .15451 L
s
.23077 .18026 m
.23452 .18026 L
s
.23077 .23176 m
.23452 .23176 L
s
.23077 .25751 m
.23452 .25751 L
s
.23077 .28327 m
.23452 .28327 L
s
.23077 .33477 m
.23452 .33477 L
s
.23077 .36052 m
.23452 .36052 L
s
.23077 .38627 m
.23452 .38627 L
s
.23077 .43777 m
.23452 .43777 L
s
.23077 .46353 m
.23452 .46353 L
s
.23077 .48928 m
.23452 .48928 L
s
.23077 .54078 m
.23452 .54078 L
s
.23077 .56653 m
.23452 .56653 L
s
.23077 .59228 m
.23452 .59228 L
s
.25 Mabswid
.23077 0 m
.23077 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
123.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(16) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.65851 .10301 m
.65993 .10301 L
.66149 .10301 L
.66315 .10301 L
.66409 .10301 L
.66508 .10301 L
.66685 .10301 L
.66875 .10301 L
.66984 .10301 L
.67085 .10301 L
.67268 .10301 L
.67435 .10301 L
.67527 .10301 L
.67627 .10301 L
.6781 .10301 L
.67972 .10301 L
.68151 .10301 L
.68338 .10301 L
.68514 .10301 L
.68678 .10301 L
.68828 .10301 L
.68992 .10301 L
.69166 .10303 L
.69354 .10308 L
.69533 .10324 L
.69693 .10358 L
.69866 .10437 L
.70055 .10615 L
.70151 .1076 L
.70256 .10979 L
.70441 .11563 L
.70615 .12401 L
.70789 .13587 L
.70954 .15064 L
.71265 .1872 L
.71631 .23991 L
.71963 .28612 L
.7214 .3062 L
.72331 .32231 L
.72436 .32832 L
.72533 .33193 L
.72723 .3337 L
.72886 .3298 L
.73065 .32043 L
.73252 .30601 L
.73427 .28943 L
.74192 .20681 L
.74595 .17064 L
.74816 .15491 L
.75023 .14279 L
Mistroke
.75399 .12654 L
.75599 .12047 L
.75815 .11549 L
.76001 .11224 L
.76196 .10966 L
.76364 .108 L
.76546 .10662 L
.76736 .10557 L
.76908 .10487 L
.77106 .10428 L
.77293 .10389 L
.77467 .10364 L
.77627 .10346 L
.77802 .10332 L
.77987 .10322 L
.78155 .10316 L
.78308 .10312 L
.78485 .10308 L
.78653 .10306 L
.78807 .10304 L
.7895 .10303 L
.79107 .10302 L
.79274 .10302 L
.7944 .10301 L
.7962 .10301 L
.7979 .10301 L
.79945 .10301 L
.80118 .10301 L
.80307 .10301 L
.80402 .10301 L
.80504 .10301 L
.80687 .10301 L
.80866 .10301 L
.80967 .10301 L
.81062 .10301 L
.81254 .10301 L
.81362 .10301 L
.8146 .10301 L
.81635 .10301 L
.81826 .10301 L
.82006 .10301 L
.82174 .10301 L
.82275 .10301 L
.82385 .10301 L
.82488 .10301 L
.82583 .10301 L
.82764 .10301 L
.82955 .10301 L
.83054 .10301 L
.8316 .10301 L
Mistroke
.83351 .10301 L
.83468 .10301 L
.83579 .10301 L
.83679 .10301 L
.83787 .10301 L
.83968 .10301 L
.84138 .10301 L
.84324 .10301 L
.84429 .10301 L
.84525 .10301 L
.84707 .10301 L
.84811 .10301 L
.84907 .10301 L
.85008 .10301 L
.85101 .10301 L
.85208 .10301 L
.85308 .10301 L
.85479 .10301 L
.8566 .10301 L
.85814 .10301 L
.85984 .10301 L
.86166 .10301 L
.86268 .10301 L
.86362 .10301 L
.86543 .10301 L
.86716 .10301 L
.86897 .10301 L
.87 .10301 L
.87094 .10301 L
.87267 .10301 L
.8745 .10301 L
.87614 .10301 L
.87767 .10301 L
.87935 .10301 L
.88114 .10301 L
.88306 .10301 L
.88415 .10301 L
.88515 .10301 L
.88699 .10301 L
.88791 .10301 L
.88894 .10301 L
.8907 .10301 L
.8926 .10301 L
.89439 .10301 L
.89603 .10301 L
.89767 .10301 L
.89943 .10301 L
.90108 .10301 L
.90259 .10301 L
.90436 .10301 L
Mistroke
.90627 .10301 L
.90808 .10301 L
.90974 .10301 L
.91131 .10301 L
.91277 .10301 L
.91437 .10301 L
.91609 .10301 L
.91788 .10301 L
.91959 .10301 L
.92112 .10301 L
.92279 .10301 L
.92455 .10301 L
.92618 .10301 L
.92795 .10301 L
.92983 .10301 L
.93147 .10301 L
.93299 .10301 L
.93466 .10301 L
.93644 .10301 L
.93746 .10301 L
.93839 .10301 L
.93942 .10301 L
.94051 .10301 L
.94233 .10301 L
.94337 .10301 L
.94434 .10301 L
.94615 .10301 L
.9478 .10301 L
.94971 .10301 L
.95152 .10301 L
.95251 .10301 L
.95345 .10301 L
.95519 .10301 L
.95707 .10301 L
.95813 .10301 L
.9591 .10301 L
.96073 .10301 L
.96252 .10301 L
.96439 .10301 L
.96613 .10301 L
.96712 .10301 L
.9682 .10301 L
.96922 .10301 L
.97016 .10301 L
.97193 .10301 L
.97382 .10301 L
.9748 .10301 L
.97584 .10301 L
.97774 .10301 L
.97884 .10301 L
Mistroke
.97999 .10301 L
.98098 .10301 L
.98206 .10301 L
.983 .10301 L
.98398 .10301 L
.98576 .10301 L
.98767 .10301 L
.98875 .10301 L
.98976 .10301 L
.99159 .10301 L
.99327 .10301 L
.99419 .10301 L
.9952 .10301 L
.99703 .10301 L
.99865 .10301 L
Mfstroke
.99865 .10301 m
1 .10301 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000oooooolLooooo`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0oooooolLooooo`00<?ooool6o`0000;o
oooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^0?oooooo7Oooool003So
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003ooooo
oa?ooooo000hooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05oooo
o`03o`000?oooooooooo0?oooooo4oooool003Sooooo00Go410@oooooooooooooooooa0@400?oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooo
oooo0?oooooo4oooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooo
oooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003ooooooooo
o`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000oooo
ooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`00
0?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool0
0ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o
0000ooooooooool0oooooolCooooo`008oooool5o`0002_ooooo00?o0000ooooooooool0:oooool5
o`0002kooooo0_l000000ol@413oooooooooo`0Zooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?oo
ool01Oo<c<co8B4Qo`000?lQ8B7oc<c<02Wooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`00
0?lb<S;ok^k^6_ooool002?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00[ooooo`03o`000?oooooo
oooo02_ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00_ooooo`03o`000?oooooooooo02_ooooo00Go
EEEEogMgMoooooooV9RHob4Q8@0/ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40:oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool001_ooooo1_l00003ooooo`03
oiRHV?lQ8B7ok^k^02cooooo00?o0000ooooooooool0;?ooool00onHV9So8B4Qonk^kP0]ooooo`Go
0000;?ooool01Ol0003ooooooooooooooooo000002cooooo00Go0000ooooooooooooooooo`00000[
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Jooooo`009Oooool0
0onHV9So8B4Qonk^kP0[ooooo`03o`000?oooooooooo02gooooo00?oV9RHob4Q8Oo^k^h0;?ooool0
1?m4A4CogMgMooooool0000]ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;?ooool01Olb<S;oV9RH
oooooonHV9So<S8b02_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
01[ooooo000Vooooo`03ogMgMomVIVKooooo02[ooooo0_l0000_ooooo`03ogMgMomVIVKooooo02_o
oooo00CogMgMoeEEEOoooooo0000;Oooool01Ol0003oEEEEo`000?l@413oc<c<02cooooo00Goc<c<
o`000?l0003o0000olc<c00[ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Jooooo`009oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool0:oooool00omgMgOoc<c<o`00000]ooooo`03oeEEEOn7QhOooooo02kooooo00Go
410@okZj^_oooooo^[Zjoa0@400[ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@400Jooooo`008oooool01Ol0003o^[ZjoooooonHV9So410@02_ooooo00?o0000oooooooo
ool0:oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo00?ok^k^odA4A?l00000;Oooool00ooM
gMgo410@oiRHV00^ooooo`05o`000?nj^[[ooooookZj^_l00000:oooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool002?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00[ooooo`03o`000?oooooooooo02_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00^ooooo`03ogMg
Mol0003ooooo02gooooo00Coc<c<odA4A?l0003o410@;?ooool01OnYZJWo410@o`000?l@413oZJVY
02Wooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo001Coooo
o`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00
Doooool00ol0003oooooooooo`3mooooo`;o00000_ooool2o`0000oooooo001Cooooo`03o`000?oo
oooooooo0?gooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd?ooooo`00Doooool00ol0003ooooo
ooooo`3nooooo`04omgMgOl0003o410@olc<c13ooooo000:oooooooo0000@?l0000;ooooo`04onk^
k_lQ8B7o410@onk^kQ3ooooo000Fooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo00Sooooo0_l0000<ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`04
ob4Q8OmgMgOoMgMgoc8b<Q3ooooo000Rooooo`03o`000?oooooooooo02kooooo00?o0000oooooooo
ool0;_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02kooooo00Co0000oooooooo
oooo00004_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02kooooo00?o0000oooo
ooooool02?ooool2o`0000;ooooo0_l0000?ooooo`00Doooool00ol0003oooooooooo`2Cooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool0JOooool005?ooooo00?o0000ooooooooool0
U?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo06[ooooo001Cooooo`03o`000?oo
oooooooo09Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1[ooooo`00Doooool0
0ol0003oooooooooo`2Dooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0Joooool0
05?ooooo00?o0000ooooooooool0U?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
06_ooooo001Cooooo`;o0000UOooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo06_o
oooo001Cooooo`03o`000?oooooooooo09Gooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`1/ooooo`00Doooool00ol0003oooooooooo`2Eooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0K?ooool005?ooooo00?o0000ooooooooool0UOooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo06cooooo001Cooooo`03o`000?oooooooooo09Gooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`1]ooooo`00Doooool00ol0003oooooooooo`2Eooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool0KOooool005?ooooo00?o0000ooooooooool0
UOooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo06gooooo001Cooooo`03o`000?oo
oooooooo09Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1]ooooo`00Doooool2
o`0009Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1]ooooo`00Doooool00ol0
003oooooooooo`2Eooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0KOooool005?o
oooo00?o0000ooooooooool0UOooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo06go
oooo001Cooooo`03o`000?oooooooooo09Gooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`1^ooooo`00Doooool00ol0003oooooooooo`2Eooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool0K_ooool005?ooooo00?o0000ooooooooool0U_ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo06kooooo001Cooooo`03o`000?oooooooooo09Kooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`1^ooooo`00Doooool00ol0003oooooooooo`2Fooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool0K_ooool005?ooooo0_l0002Gooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool0K_ooool005?ooooo00?o0000ooooooooool0U_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo06kooooo001Cooooo`03o`000?oooooo
oooo09Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1^ooooo`00Doooool00ol0
003oooooooooo`2Fooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0K_ooool005?o
oooo00?o0000ooooooooool0U_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo06oo
oooo001Cooooo`03o`000?oooooooooo09Kooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`1_ooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go0000
1_ooool00ol0003oooooooooo`2Fooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
Koooool003Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Q
onk^k_ooooooA4A400Kooooo00?o0000ooooooooool0Uoooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo06oooooo000hooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So
8B4Qonk^kP07ooooo`?o0000Uoooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06oo
oooo000hooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP06ooooo`03
o`000?oooooooooo09Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1_ooooo`00
>?ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003o
ooooooooo`2Gooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Koooool003Sooooo
00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0Uoooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06oooooo000hooooo`05ogMg
MonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000oooo
ooooool0Uoooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06oooooo000hooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000
ooooooooool0Uoooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06oooooo001Coooo
o`03o`000?oooooooooo09Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1`oooo
o`00Doooool00ol0003oooooooooo`2Gooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0L?ooool005?ooooo00?o0000ooooooooool0V?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo073ooooo001Cooooo`;o0000VOooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo073ooooo001Cooooo`03o`000?oooooooooo09Sooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`1`ooooo`00Doooool00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0L?ooool005?ooooo00?o0000ooooooooool0V?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo073ooooo001Cooooo`03o`000?oooooooooo09Sooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`1`ooooo`00Doooool00ol0003ooooooooo
o`2Hooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0L?ooool005?ooooo00?o0000
ooooooooool0V?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo077ooooo001Coooo
o`03o`000?oooooooooo09Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1aoooo
o`00Doooool2o`0009Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1aooooo`00
Doooool00ol0003oooooooooo`2Hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
LOooool005?ooooo00?o0000ooooooooool0VOooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo077ooooo001Cooooo`03o`000?oooooooooo09Wooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`1aooooo`00Doooool00ol0003oooooooooo`2Iooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0LOooool005?ooooo00?o0000ooooooooool0VOooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo077ooooo001Cooooo`03o`000?oooooooooo09Wooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`1aooooo`00Doooool00ol0003ooooooooo
o`2Iooooo`05o`000?ooooooooooooooool00000M?ooool005?ooooo0_l0002Jooooo`05o`000?oo
ooooooooooooool00000M?ooool005?ooooo00?o0000ooooooooool0VOooool01Ol0003ooooooooo
oooooooo000007Cooooo001Cooooo`03o`000?oooooooooo09Wooooo00Go0000oooooooooooooooo
o`00001dooooo`00Doooool00ol0003oooooooooo`2Iooooo`05o`000?ooooooooooooooool00000
M?ooool005?ooooo00?o0000ooooooooool0VOooool01Ol0003ooooooooooooooooo000007Cooooo
001Cooooo`03o`000?oooooooooo09Wooooo00Go0000ooooooooooooooooo`00001dooooo`00>?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool0
1?ooool00ol0003oooooooooo`2Iooooo`05o`000?ooooooooooooooool00000M?ooool003Sooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo09Wooooo00Go0000ooooooooooooooooo`00001dooooo`00>?ooool01Ol@413o
oooooooooooooooo410@00_ooooo1Ol00006ooooo`?o0000VOooool01Ol0003ooooooooooooooooo
000007Cooooo000hooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool0
0007ooooo`03o`000?oooooooooo09Wooooo00Go0000ooooooooooooooooo`00001dooooo`00>?oo
ool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003o
ooooooooo`2Jooooo`03o`000?oooooo000007Gooooo000hooooo`05oa0@4?ooooooooooooooool@
41003?ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo09[ooooo00?o0000ooooool0
0000MOooool003Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oo
oooo00?o0000ooooooooool0V_ooool00ol0003oooooo`00001eooooo`00>?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`2Jooooo`03
o`000?oooooo000007Gooooo001Cooooo`03o`000?oooooooooo09[ooooo00?o0000ooooool00000
MOooool005?ooooo00?o0000ooooooooool0Voooool2o`0007Gooooo001Cooooo`;o0000W?ooool0
0ol0003oooooooooo`1dooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03
o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Dooo
ool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool0
05?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?o
oooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo0_l0003ooooooaCooooo001C
ooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCoooo
o`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo
4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3o
oooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo0_l0003ooooooaCo
oooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooo
oolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo
0?oooooo4oooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^
k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_oo
ool00ol0003oooooooooo`3ooooooa?ooooo000hooooo`05oa0@4?ooooooooooooooool@41002ooo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0oooooolCooooo`00>?oo
ool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o
0000oooooolCooooo`00>?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0
003o410@olc<c006ooooo`03o`000?oooooooooo0?oooooo4oooool003Sooooo00Go410@oooooooo
oooooooooa0@400;ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0oooooolCoooo
o`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0
003oooooooooo`3ooooooa?ooooo000hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<
c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000oooo
ooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`00
0?oooooooooo0?oooooo4oooool005?ooooo0_l0003ooooooaCooooo001Cooooo`03o`000?oooooo
oooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o
0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Coooo
o`03o`000?oooooooooo0?oooooo4oooool005?ooooo0_l0003ooooooaCooooo001Cooooo`03o`00
0?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool0
0ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?o
oooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo
001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolC
ooooo`00Doooool2o`000?oooooo5?ooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00
Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4ooo
ool005?ooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003ooooooooo
o`3ooooooa?ooooo000hooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go
8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?oooooo4oooool003Sooooo00Go
410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`3ooooooa?ooooo000hooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;o
V9RHoooooonHV9So<S8b00Kooooo0ol0003ooooooa?ooooo000hooooo`05o`000?oooooooooooooo
ool000002oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooolC
ooooo`00>?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@
4006ooooo`03o`000?oooooooooo0?oooooo4oooool003Sooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`3ooooooa?ooooo
000hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Ko
oooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo
001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolC
ooooo`00Doooool2o`000?oooooo5?ooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00
Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4ooo
ool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooo
oa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0
oooooolCooooo`00Doooool2o`000?oooooo5?ooool005?ooooo00?o0000ooooooooool0oooooolC
ooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oo
oooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003ooooooooo
o`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000oooo
ooooool0oooooolCooooo`00Doooool2o`000?oooooo5?ooool005?ooooo00?o0000ooooooooool0
oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooo
oooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo0019ooooo`Co000000?o410@ooooooooool00oooool00ol0003ooooo
ooooo`3ooooooa?ooooo001;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooo
oolCooooo`00Boooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo4oooool0
04_ooooo00?o0000ooooooooool01Oooool3o`000?oooooo4oooool004_ooooo00?o0000oooooooo
ool0oooooolKooooo`00Boooool00ol0003oooooooooo`3ooooooa_ooooo001;ooooo`03o`000?oo
oooooooo0?oooooo6oooool004Wooooo00?oEEEEofIVI_l00000oooooolMooooo`00N?ooool3o`00
0003oa0@4?oooooooooo0>[ooooo001jooooo`03oa0@4?nj^[[ooooo00Oooooo0_l0000;ooooo`03
o`000?nj^[[ooooo00cooooo0_l00005ooooo`03o`000?nj^[[ooooo0;kooooo001jooooo`03oiRH
V?lb<S;ooooo00Oooooo00?o0000ooooooooool02_ooool2oc8b<Pkooooo00?o0000ooooooooool0
0oooool2oc8b<[oooooo001jooooo`03omgMgOl0003o^[Zj00Oooooo00Co0000oooooooooooooooo
0_l00002ooooo`;o00000oooool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0003o0000odA4A?nj
^[X01?ooool00ol0003oooooooooo`03ooooo`03ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0
003oA4A4okZj^P0Booooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o410@olc<c8oooooo
001jooooo`03oeEEEOmgMgOoA4A400Oooooo00[o0000ooooooooooooooooonk^k_lQ8B7oQhN7okZj
^_l0003ogMgM0oooool00oo<c<co0000oa0@4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?oo
ool00ol0003oooooooooo`03ooooo`03olc<c?l0003o410@00cooooo00Go410@okZj^_o^k^koMgMg
oa0@4009ooooo`Ko00001Oooool00ol0003oooooooooo`02ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B40Soooool007Wooooo00GogMgMoa0@4?oooooo8B4QomgMg@06ooooo`03o`000?oooooooooo00;o
oooo00CogMgMo`000?l@413oc<c<2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
01;ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool00000Soooool007Wooooo00GoIVIVohN7QoooooooV9RHoeEEE@06ooooo`03o`000?oooooo
oooo00;ooooo00Cok^k^ob4Q8Ol@413ok^k^2oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool02oooool6o`0000Gooooo00?o0000ooooooooool00_oo
ool01Ol0003oV9RHoooooonHV9So8B4Q08oooooo001hooooo`03onk^k_l0003ok^k^00;ooooo00?o
0000omgMgOooool01?ooool00ol0003oooooooooo`02ooooo`04ob4Q8OmgMgOoMgMgoc8b<P_ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool00_ooool01Ol0003oEEEEo`000?l@413oc<c<08oooooo001hooooo`04oa0@
4?l0003o0000ooooo`;o000000?o410@ooooooooool00oooool01?l0003oooooooooooooool2o`00
00;ooooo0_l00008ooooo`03oa0@4?l0003o000000?o00001Oooool00ol0003oooooooooo`0@oooo
o`03oa0@4?l0003o000000?o00005Oooool00ol0003oooooooooo`02ooooo`03oeEEEOn7QhOooooo
097ooooo0024ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool00_ooool00ooMgMgo
410@oiRHV02Aooooo`00Q?ooool2o`0001;ooooo00?o0000ooooooooool01Oooool2o`0001Cooooo
00?o0000ooooooooool05?ooool00omEEEGoIVIVo`000005ooooo`04olc<c?m4A4Co0000oa0@48oo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-3.4116, -0.234311, \
0.0510397, 0.00762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.230769 0.0769231 0.103006 0.515028 [
[.07692 .09051 -6 -9 ]
[.07692 .09051 6 0 ]
[.38462 .09051 -3 -9 ]
[.38462 .09051 3 0 ]
[.53846 .09051 -3 -9 ]
[.53846 .09051 3 0 ]
[.69231 .09051 -3 -9 ]
[.69231 .09051 3 0 ]
[.84615 .09051 -3 -9 ]
[.84615 .09051 3 0 ]
[1 .09051 -6 -9 ]
[1 .09051 6 0 ]
[1.025 .10301 0 -6 ]
[1.025 .10301 10 6 ]
[.21827 0 -24 -4.5 ]
[.21827 0 0 4.5 ]
[.21827 .20601 -18 -4.5 ]
[.21827 .20601 0 4.5 ]
[.21827 .30902 -18 -4.5 ]
[.21827 .30902 0 4.5 ]
[.21827 .41202 -18 -4.5 ]
[.21827 .41202 0 4.5 ]
[.21827 .51503 -18 -4.5 ]
[.21827 .51503 0 4.5 ]
[.21827 .61803 -6 -4.5 ]
[.21827 .61803 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07692 .10301 m
.07692 .10926 L
s
[(-2)] .07692 .09051 0 1 Mshowa
.38462 .10301 m
.38462 .10926 L
s
[(2)] .38462 .09051 0 1 Mshowa
.53846 .10301 m
.53846 .10926 L
s
[(4)] .53846 .09051 0 1 Mshowa
.69231 .10301 m
.69231 .10926 L
s
[(6)] .69231 .09051 0 1 Mshowa
.84615 .10301 m
.84615 .10926 L
s
[(8)] .84615 .09051 0 1 Mshowa
1 .10301 m
1 .10926 L
s
[(10)] 1 .09051 0 1 Mshowa
.125 Mabswid
.11538 .10301 m
.11538 .10676 L
s
.15385 .10301 m
.15385 .10676 L
s
.19231 .10301 m
.19231 .10676 L
s
.26923 .10301 m
.26923 .10676 L
s
.30769 .10301 m
.30769 .10676 L
s
.34615 .10301 m
.34615 .10676 L
s
.42308 .10301 m
.42308 .10676 L
s
.46154 .10301 m
.46154 .10676 L
s
.5 .10301 m
.5 .10676 L
s
.57692 .10301 m
.57692 .10676 L
s
.61538 .10301 m
.61538 .10676 L
s
.65385 .10301 m
.65385 .10676 L
s
.73077 .10301 m
.73077 .10676 L
s
.76923 .10301 m
.76923 .10676 L
s
.80769 .10301 m
.80769 .10676 L
s
.88462 .10301 m
.88462 .10676 L
s
.92308 .10301 m
.92308 .10676 L
s
.96154 .10301 m
.96154 .10676 L
s
.03846 .10301 m
.03846 .10676 L
s
.25 Mabswid
0 .10301 m
1 .10301 L
s
gsave
1.025 .10301 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.23077 0 m
.23702 0 L
s
[(-0.2)] .21827 0 1 0 Mshowa
.23077 .20601 m
.23702 .20601 L
s
[(0.2)] .21827 .20601 1 0 Mshowa
.23077 .30902 m
.23702 .30902 L
s
[(0.4)] .21827 .30902 1 0 Mshowa
.23077 .41202 m
.23702 .41202 L
s
[(0.6)] .21827 .41202 1 0 Mshowa
.23077 .51503 m
.23702 .51503 L
s
[(0.8)] .21827 .51503 1 0 Mshowa
.23077 .61803 m
.23702 .61803 L
s
[(1)] .21827 .61803 1 0 Mshowa
.125 Mabswid
.23077 .02575 m
.23452 .02575 L
s
.23077 .0515 m
.23452 .0515 L
s
.23077 .07725 m
.23452 .07725 L
s
.23077 .12876 m
.23452 .12876 L
s
.23077 .15451 m
.23452 .15451 L
s
.23077 .18026 m
.23452 .18026 L
s
.23077 .23176 m
.23452 .23176 L
s
.23077 .25751 m
.23452 .25751 L
s
.23077 .28327 m
.23452 .28327 L
s
.23077 .33477 m
.23452 .33477 L
s
.23077 .36052 m
.23452 .36052 L
s
.23077 .38627 m
.23452 .38627 L
s
.23077 .43777 m
.23452 .43777 L
s
.23077 .46353 m
.23452 .46353 L
s
.23077 .48928 m
.23452 .48928 L
s
.23077 .54078 m
.23452 .54078 L
s
.23077 .56653 m
.23452 .56653 L
s
.23077 .59228 m
.23452 .59228 L
s
.25 Mabswid
.23077 0 m
.23077 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
123.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(17) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.67621 .10301 m
.67804 .10301 L
.6798 .10301 L
.68171 .10301 L
.68352 .10301 L
.68518 .10301 L
.68668 .10301 L
.68833 .10301 L
.69005 .10301 L
.69166 .10301 L
.69354 .10301 L
.69529 .10301 L
.69721 .10301 L
.69818 .10301 L
.69925 .10301 L
.70103 .10301 L
.70204 .10301 L
.70296 .10301 L
.70466 .10301 L
.70644 .10301 L
.70805 .10302 L
.70978 .10306 L
.7114 .10318 L
.71288 .10343 L
.71462 .10409 L
.7165 .10566 L
.71828 .10858 L
.71992 .11318 L
.72167 .12086 L
.72355 .13311 L
.72532 .149 L
.72693 .16719 L
.73464 .27767 L
.7365 .29984 L
.73751 .30966 L
.73847 .31712 L
.7396 .32358 L
.74063 .32708 L
.7416 .32834 L
.74264 .32753 L
.74356 .32505 L
.74456 .32057 L
.74561 .31411 L
.74659 .30666 L
.75023 .27068 L
.75753 .19114 L
.75953 .17326 L
.76165 .1571 L
.76349 .14547 L
.76546 .13522 L
Mistroke
.76731 .12754 L
.769 .12191 L
.77072 .11736 L
.77232 .11402 L
.77408 .11116 L
.776 .10881 L
.77788 .10713 L
.77987 .10584 L
.7817 .105 L
.78337 .10444 L
.78521 .104 L
.78614 .10383 L
.78716 .10367 L
.78887 .10347 L
.79071 .10332 L
.79244 .10322 L
.79403 .10316 L
.79567 .10311 L
.79718 .10308 L
.79885 .10306 L
.80062 .10304 L
.80215 .10303 L
.80359 .10302 L
.80517 .10302 L
.80687 .10301 L
.80869 .10301 L
.81035 .10301 L
.81226 .10301 L
.81406 .10301 L
.81574 .10301 L
.81728 .10301 L
.81897 .10301 L
.82076 .10301 L
.82256 .10301 L
.82358 .10301 L
.8245 .10301 L
.8263 .10301 L
.828 .10301 L
.82896 .10301 L
.82998 .10301 L
.83181 .10301 L
.83294 .10301 L
.83399 .10301 L
.83494 .10301 L
.83597 .10301 L
.83789 .10301 L
.83968 .10301 L
.8407 .10301 L
.84164 .10301 L
.84272 .10301 L
Mistroke
.84374 .10301 L
.84473 .10301 L
.84578 .10301 L
.84767 .10301 L
.84872 .10301 L
.8497 .10301 L
.85078 .10301 L
.85195 .10301 L
.85373 .10301 L
.85474 .10301 L
.85568 .10301 L
.85758 .10301 L
.85864 .10301 L
.85961 .10301 L
.86135 .10301 L
.86322 .10301 L
.865 .10301 L
.86663 .10301 L
.86846 .10301 L
.87019 .10301 L
.87174 .10301 L
.87344 .10301 L
.87527 .10301 L
.8763 .10301 L
.87723 .10301 L
.87904 .10301 L
.88074 .10301 L
.88235 .10301 L
.88405 .10301 L
.8855 .10301 L
.88709 .10301 L
.8888 .10301 L
.89063 .10301 L
.89236 .10301 L
.89393 .10301 L
.8958 .10301 L
.89674 .10301 L
.89778 .10301 L
.89961 .10301 L
.90133 .10301 L
.90237 .10301 L
.90335 .10301 L
.9052 .10301 L
.90623 .10301 L
.90719 .10301 L
.90824 .10301 L
.90936 .10301 L
.91125 .10301 L
.91232 .10301 L
.9133 .10301 L
Mistroke
.9151 .10301 L
.91701 .10301 L
.91872 .10301 L
.92032 .10301 L
.92207 .10301 L
.92395 .10301 L
.92572 .10301 L
.92673 .10301 L
.92767 .10301 L
.92957 .10301 L
.93064 .10301 L
.93163 .10301 L
.93328 .10301 L
.93509 .10301 L
.93697 .10301 L
.93873 .10301 L
.93974 .10301 L
.94083 .10301 L
.94186 .10301 L
.9428 .10301 L
.9446 .10301 L
.94651 .10301 L
.94749 .10301 L
.94855 .10301 L
.95046 .10301 L
.95163 .10301 L
.95274 .10301 L
.95373 .10301 L
.95482 .10301 L
.95577 .10301 L
.9568 .10301 L
.95867 .10301 L
.96049 .10301 L
.96216 .10301 L
.96398 .10301 L
.96501 .10301 L
.96597 .10301 L
.96699 .10301 L
.96791 .10301 L
.96898 .10301 L
.96999 .10301 L
.97169 .10301 L
.9735 .10301 L
.97504 .10301 L
.97674 .10301 L
.97856 .10301 L
.97958 .10301 L
.98052 .10301 L
.98225 .10301 L
.98406 .10301 L
Mistroke
.98587 .10301 L
.98688 .10301 L
.98782 .10301 L
.98953 .10301 L
.99135 .10301 L
.99298 .10301 L
.99451 .10301 L
.99618 .10301 L
.99797 .10301 L
.99988 .10301 L
Mfstroke
.99988 .10301 m
1 .10301 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000oooooolLooooo`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0oooooolLooooo`00<?ooool6o`0000;o
oooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^0?oooooo7Oooool003So
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003ooooo
oa?ooooo000hooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05oooo
o`03o`000?oooooooooo0?oooooo4oooool003Sooooo00Go410@oooooooooooooooooa0@400?oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooo
oooo0?oooooo4oooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooo
oooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003ooooooooo
o`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000oooo
ooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`00
0?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool0
0ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o
0000ooooooooool0oooooolCooooo`008oooool5o`0002_ooooo00?o0000ooooooooool0:oooool5
o`0002kooooo0_l000000ol@413oooooooooo`0Zooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?oo
ool01Oo<c<co8B4Qo`000?lQ8B7oc<c<02Wooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`00
0?lb<S;ok^k^6_ooool002?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00[ooooo`03o`000?oooooo
oooo02_ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00_ooooo`03o`000?oooooooooo02_ooooo00Go
EEEEogMgMoooooooV9RHob4Q8@0/ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40:oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool001_ooooo1_l00003ooooo`03
oiRHV?lQ8B7ok^k^02cooooo00?o0000ooooooooool0;?ooool00onHV9So8B4Qonk^kP0]ooooo`Go
0000;?ooool01Ol0003ooooooooooooooooo000002cooooo00Go0000ooooooooooooooooo`00000[
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Jooooo`009Oooool0
0onHV9So8B4Qonk^kP0[ooooo`03o`000?oooooooooo02gooooo00?oV9RHob4Q8Oo^k^h0;?ooool0
1?m4A4CogMgMooooool0000]ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;?ooool01Olb<S;oV9RH
oooooonHV9So<S8b02_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
01[ooooo000Vooooo`03ogMgMomVIVKooooo02[ooooo0_l0000_ooooo`03ogMgMomVIVKooooo02_o
oooo00CogMgMoeEEEOoooooo0000;Oooool01Ol0003oEEEEo`000?l@413oc<c<02cooooo00Goc<c<
o`000?l0003o0000olc<c00[ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Jooooo`009oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool0:oooool00omgMgOoc<c<o`00000]ooooo`03oeEEEOn7QhOooooo02kooooo00Go
410@okZj^_oooooo^[Zjoa0@400[ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@400Jooooo`008oooool01Ol0003o^[ZjoooooonHV9So410@02_ooooo00?o0000oooooooo
ool0:oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo00?ok^k^odA4A?l00000;Oooool00ooM
gMgo410@oiRHV00^ooooo`05o`000?nj^[[ooooookZj^_l00000:oooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool002?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00[ooooo`03o`000?oooooooooo02_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00^ooooo`03ogMg
Mol0003ooooo02gooooo00Coc<c<odA4A?l0003o410@;?ooool01OnYZJWo410@o`000?l@413oZJVY
02Wooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo001Coooo
o`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00
Doooool00ol0003oooooooooo`3mooooo`;o00000_ooool2o`0000oooooo001Cooooo`03o`000?oo
oooooooo0?gooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd?ooooo`00Doooool00ol0003ooooo
ooooo`3nooooo`04omgMgOl0003o410@olc<c13ooooo000:oooooooo0000@?l0000;ooooo`04onk^
k_lQ8B7o410@onk^kQ3ooooo000Fooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000002oooool01?l0003o
ooooooooool00009ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`04ob4Q8OmgMgOoMgMgoc8b<Q3ooooo000Rooooo`03o`000?oooooooooo
02kooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo
02kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`08ooooo`;o00000_ooool2o`00
00oooooo001Cooooo`03o`000?oooooooooo09Wooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`1Vooooo`00Doooool00ol0003oooooooooo`2Iooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool0I_ooool005?ooooo00?o0000ooooooooool0VOooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo06Kooooo001Cooooo`03o`000?oooooooooo09Wooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`1Wooooo`00Doooool00ol0003oooooooooo`2Ioooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool0Ioooool005?ooooo0_l0002Kooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0Ioooool005?ooooo00?o0000ooooooooool0
V_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo06Sooooo001Cooooo`03o`000?oo
oooooooo09[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Xooooo`00Doooool0
0ol0003oooooooooo`2Jooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0J?ooool0
05?ooooo00?o0000ooooooooool0Voooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
06Sooooo001Cooooo`03o`000?oooooooooo09_ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`1Xooooo`00Doooool00ol0003oooooooooo`2Kooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool0J?ooool005?ooooo00?o0000ooooooooool0Voooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo06Sooooo001Cooooo`;o0000W?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo06Wooooo001Cooooo`03o`000?oooooooooo09_ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`1Yooooo`00Doooool00ol0003oooooooooo`2Kooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool0JOooool005?ooooo00?o0000ooooooooool0
Voooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo06Wooooo001Cooooo`03o`000?oo
oooooooo09_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Zooooo`00Doooool0
0ol0003oooooooooo`2Kooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0J_ooool0
05?ooooo00?o0000ooooooooool0Voooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
06[ooooo001Cooooo`03o`000?oooooooooo09_ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`1Zooooo`00Doooool2o`0009cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`1Zooooo`00Doooool00ol0003oooooooooo`2Kooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0J_ooool005?ooooo00?o0000ooooooooool0Voooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo06[ooooo001Cooooo`03o`000?oooooooooo09_ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`1Zooooo`00Doooool00ol0003oooooooooo`2Kooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool0J_ooool005?ooooo00?o0000ooooooooool0
Voooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo06[ooooo000hooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo09cooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Zooooo`00>?ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`2Looooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0J_ooool003Sooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0002Looooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0J_ooool003Sooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0W?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo06_ooooo000hooooo`05o`000?ooooooooooooooool0
00003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo09cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`1[ooooo`00>?ooool01Ol@413ooooooooooooooooo410@00oo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2Looooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0Joooool003Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`2Looooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0Joooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;oooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`2Looooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0Joooool005?ooooo00?o0000ooooooooool0W?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo06_ooooo001Cooooo`03o`000?oooooooooo09co
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1[ooooo`00Doooool00ol0003ooooo
ooooo`2Looooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Joooool005?ooooo0_l0
002Mooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0K?ooool005?ooooo00?o0000
ooooooooool0W?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06cooooo001Coooo
o`03o`000?oooooooooo09cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1/oooo
o`00Doooool00ol0003oooooooooo`2Looooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0K?ooool005?ooooo00?o0000ooooooooool0W?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo06cooooo001Cooooo`03o`000?oooooooooo09cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`1/ooooo`00Doooool00ol0003oooooooooo`2Mooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0K?ooool005?ooooo00?o0000ooooooooool0WOooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo06cooooo001Cooooo`;o0000W_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo06cooooo001Cooooo`03o`000?oooooooooo09gooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`1]ooooo`00Doooool00ol0003ooooooooo
o`2Mooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0KOooool005?ooooo00?o0000
ooooooooool0WOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo06gooooo001Coooo
o`03o`000?oooooooooo09gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1]oooo
o`00Doooool00ol0003oooooooooo`2Mooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0KOooool005?ooooo00?o0000ooooooooool0WOooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo06gooooo001Cooooo`03o`000?oooooooooo09gooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`1]ooooo`00Doooool2o`0009kooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`1]ooooo`00Doooool00ol0003oooooooooo`2Mooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0KOooool005?ooooo00?o0000ooooooooool0W_ooool01?l0003o
ooooooooool0001`ooooo`00Doooool00ol0003oooooooooo`2Nooooo`04o`000?ooooooooooo`00
073ooooo001Cooooo`03o`000?oooooooooo09kooooo00Co0000oooooooooooo0000L?ooool005?o
oooo00?o0000ooooooooool0W_ooool01?l0003oooooooooool0001`ooooo`00>?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0
003oooooooooo`2Nooooo`04o`000?ooooooooooo`00073ooooo000hooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2N
ooooo`04o`000?ooooooooooo`00073ooooo000hooooo`05oa0@4?ooooooooooooooool@41002ooo
ool5o`0000Kooooo0ol0002Nooooo`04o`000?ooooooooooo`00073ooooo000hooooo`05o`000?oo
ooooooooooooool000002oooool01?m4A4CogMgMooooool00007ooooo`03o`000?oooooooooo09ko
oooo00Co0000oooooooooooo0000L?ooool003Sooooo00Go0000ooooooooooooooooo`00000;oooo
o`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0Woooool00ol0003oooooo`00001`
ooooo`00>?ooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001oooool0
0ol0003oooooooooo`2Oooooo`03o`000?oooooo0000073ooooo000hooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo09oooooo00?o0000
ooooool00000L?ooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003o
oooo00Kooooo00?o0000ooooooooool0Woooool2o`00077ooooo001Cooooo`03o`000?oooooooooo
09oooooo0_l0001aooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000
oooooolDooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooo
oooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o
0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Coooo
o`03o`000?oooooooooo0?oooooo4oooool005?ooooo0_l0003ooooooaCooooo001Cooooo`03o`00
0?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool0
0ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?o
oooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo
001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo0_l0003ooooooaCooooo001Coooo
o`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00
Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4ooo
ool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8bo`00
0?l@413oc<c<00Kooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003o
ooooooooo`3ooooooa?ooooo000hooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003o
oooooooooooooooo000000Kooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01Ol0003o
oooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000oooooolC
ooooo`00>?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@olc<
c006ooooo`03o`000?oooooooooo0?oooooo4oooool003Sooooo00Go410@oooooooooooooooooa0@
400;ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003ooooooooo
o`3ooooooa?ooooo000hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4o`00
0?l@4106ooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooo
oolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo
0?oooooo4oooool005?ooooo0_l0003ooooooaCooooo001Cooooo`03o`000?oooooooooo0?oooooo
4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3o
oooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000oooooooo
ool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oo
oooooooo0?oooooo4oooool005?ooooo0_l0003ooooooaCooooo001Cooooo`03o`000?oooooooooo
0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003ooooo
ooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000
ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03
o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Dooo
ool2o`000?oooooo5?ooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0
003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo
00?o0000ooooooooool0oooooolCooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3ooooooa?o
oooo000hooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRHV?oo
ooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?oooooo4oooool003Sooooo00Go410@oooooooo
oooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3o
oooooa?ooooo000hooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonH
V9So<S8b00Kooooo0ol0003ooooooa?ooooo000hooooo`05o`000?ooooooooooooooool000002ooo
ool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooolCooooo`00>?oo
ool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03
o`000?oooooooooo0?oooooo4oooool003Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`3ooooooa?ooooo000hooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000
ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03
o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Dooo
ool2o`000?oooooo5?ooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0
003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo
00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001C
ooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCoooo
o`00Doooool2o`000?oooooo5?ooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Dooo
ool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool0
05?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?o
oooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooo
oolCooooo`00Doooool2o`000?oooooo5?ooool005?ooooo00?o0000ooooooooool0oooooolCoooo
o`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo
4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3o
oooooa?ooooo0019ooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`3ooooo
oa?ooooo001;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooolCooooo`00
Boooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo4oooool004_ooooo00?o
0000ooooooooool01Oooool3o`000?oooooo4oooool004_ooooo00?o0000ooooooooool0oooooolK
ooooo`00Boooool00ol0003oooooooooo`3ooooooa_ooooo001;ooooo`03o`000?oooooooooo0?oo
oooo6oooool004Wooooo00?oEEEEofIVI_l00000oooooolMooooo`00N?ooool3o`000003oa0@4?oo
oooooooo0>[ooooo001jooooo`03oa0@4?nj^[[ooooo00Oooooo0_l0000;ooooo`03o`000?nj^[[o
oooo00cooooo0_l00005ooooo`03o`000?nj^[[ooooo0;kooooo001jooooo`03oiRHV?lb<S;ooooo
00Oooooo00?o0000ooooooooool02_ooool2oc8b<Pkooooo00?o0000ooooooooool00oooool2oc8b
<[oooooo001jooooo`03omgMgOl0003o^[Zj00Oooooo00Co0000oooooooooooooooo0_l00002oooo
o`;o00000oooool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0003o0000odA4A?nj^[X01?ooool0
0ol0003oooooooooo`03ooooo`03ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4okZj
^P0Booooo`Co000000?o410@ooooooooool00_ooool00ol0003ok^k^ooooo`2?ooooo`00N_ooool0
0omEEEGoMgMgodA4A007ooooo`0:o`000?ooooooooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgM
g@?ooooo00?oc<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo00?o0000
ooooooooool00oooool00oo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Ooo
ool6o`0000Gooooo00?o0000ooooooooool01?ooool00omEEEGoZJVYooooo`2?ooooo`00NOooool0
1OoMgMgo410@oooooolQ8B7ogMgM00Kooooo00?o0000ooooooooool00_ooool01?oMgMgo0000oa0@
4?o<c<`;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo00Cooooo00?oZJVYoeEEEOooool0Soooool007Wooooo00Go
IVIVohN7QoooooooV9RHoeEEE@06ooooo`03o`000?oooooooooo00;ooooo00Cok^k^ob4Q8Ol@413o
k^k^2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool02oooool6o`0000Gooooo00?o0000ooooooooool01Oooool00olQ8B7oooooooooo`2>ooooo`00
N?ooool00oo^k^ko0000onk^kP02ooooo`03o`000?oMgMgooooo00Cooooo00?o0000ooooooooool0
0_ooool01?lQ8B7oMgMgogMgMolb<S8;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Gooooo00?oEEEEolc<c?oo
ool0S_ooool007Sooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`03ooooo`04
o`000?ooooooooooooooo`;o00000_ooool2o`0000Sooooo00?o410@o`000?l000000ol00005oooo
o`03o`000?oooooooooo013ooooo00?o410@o`000?l000000ol0000Eooooo`03o`000?oooooooooo
00Gooooo00?oZJVYogMgMoooool0S_ooool008Cooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`02ooooo`05oa0@4?oooooooooooooooolb<S80Soooool008Cooooo0_l0000Booooo`03
o`000?oooooooooo00Gooooo0_l0000Dooooo`03o`000?oooooooooo01Cooooo00?oEEEEofIVI_l0
00001?ooool5o`0008oooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-3.4116, -0.234311, \
0.0510397, 0.00762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.230769 0.0769231 0.103006 0.515028 [
[.07692 .09051 -6 -9 ]
[.07692 .09051 6 0 ]
[.38462 .09051 -3 -9 ]
[.38462 .09051 3 0 ]
[.53846 .09051 -3 -9 ]
[.53846 .09051 3 0 ]
[.69231 .09051 -3 -9 ]
[.69231 .09051 3 0 ]
[.84615 .09051 -3 -9 ]
[.84615 .09051 3 0 ]
[1 .09051 -6 -9 ]
[1 .09051 6 0 ]
[1.025 .10301 0 -6 ]
[1.025 .10301 10 6 ]
[.21827 0 -24 -4.5 ]
[.21827 0 0 4.5 ]
[.21827 .20601 -18 -4.5 ]
[.21827 .20601 0 4.5 ]
[.21827 .30902 -18 -4.5 ]
[.21827 .30902 0 4.5 ]
[.21827 .41202 -18 -4.5 ]
[.21827 .41202 0 4.5 ]
[.21827 .51503 -18 -4.5 ]
[.21827 .51503 0 4.5 ]
[.21827 .61803 -6 -4.5 ]
[.21827 .61803 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07692 .10301 m
.07692 .10926 L
s
[(-2)] .07692 .09051 0 1 Mshowa
.38462 .10301 m
.38462 .10926 L
s
[(2)] .38462 .09051 0 1 Mshowa
.53846 .10301 m
.53846 .10926 L
s
[(4)] .53846 .09051 0 1 Mshowa
.69231 .10301 m
.69231 .10926 L
s
[(6)] .69231 .09051 0 1 Mshowa
.84615 .10301 m
.84615 .10926 L
s
[(8)] .84615 .09051 0 1 Mshowa
1 .10301 m
1 .10926 L
s
[(10)] 1 .09051 0 1 Mshowa
.125 Mabswid
.11538 .10301 m
.11538 .10676 L
s
.15385 .10301 m
.15385 .10676 L
s
.19231 .10301 m
.19231 .10676 L
s
.26923 .10301 m
.26923 .10676 L
s
.30769 .10301 m
.30769 .10676 L
s
.34615 .10301 m
.34615 .10676 L
s
.42308 .10301 m
.42308 .10676 L
s
.46154 .10301 m
.46154 .10676 L
s
.5 .10301 m
.5 .10676 L
s
.57692 .10301 m
.57692 .10676 L
s
.61538 .10301 m
.61538 .10676 L
s
.65385 .10301 m
.65385 .10676 L
s
.73077 .10301 m
.73077 .10676 L
s
.76923 .10301 m
.76923 .10676 L
s
.80769 .10301 m
.80769 .10676 L
s
.88462 .10301 m
.88462 .10676 L
s
.92308 .10301 m
.92308 .10676 L
s
.96154 .10301 m
.96154 .10676 L
s
.03846 .10301 m
.03846 .10676 L
s
.25 Mabswid
0 .10301 m
1 .10301 L
s
gsave
1.025 .10301 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.23077 0 m
.23702 0 L
s
[(-0.2)] .21827 0 1 0 Mshowa
.23077 .20601 m
.23702 .20601 L
s
[(0.2)] .21827 .20601 1 0 Mshowa
.23077 .30902 m
.23702 .30902 L
s
[(0.4)] .21827 .30902 1 0 Mshowa
.23077 .41202 m
.23702 .41202 L
s
[(0.6)] .21827 .41202 1 0 Mshowa
.23077 .51503 m
.23702 .51503 L
s
[(0.8)] .21827 .51503 1 0 Mshowa
.23077 .61803 m
.23702 .61803 L
s
[(1)] .21827 .61803 1 0 Mshowa
.125 Mabswid
.23077 .02575 m
.23452 .02575 L
s
.23077 .0515 m
.23452 .0515 L
s
.23077 .07725 m
.23452 .07725 L
s
.23077 .12876 m
.23452 .12876 L
s
.23077 .15451 m
.23452 .15451 L
s
.23077 .18026 m
.23452 .18026 L
s
.23077 .23176 m
.23452 .23176 L
s
.23077 .25751 m
.23452 .25751 L
s
.23077 .28327 m
.23452 .28327 L
s
.23077 .33477 m
.23452 .33477 L
s
.23077 .36052 m
.23452 .36052 L
s
.23077 .38627 m
.23452 .38627 L
s
.23077 .43777 m
.23452 .43777 L
s
.23077 .46353 m
.23452 .46353 L
s
.23077 .48928 m
.23452 .48928 L
s
.23077 .54078 m
.23452 .54078 L
s
.23077 .56653 m
.23452 .56653 L
s
.23077 .59228 m
.23452 .59228 L
s
.25 Mabswid
.23077 0 m
.23077 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
123.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(18) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.69459 .10301 m
.69554 .10301 L
.6974 .10301 L
.69915 .10301 L
.70015 .10301 L
.7012 .10301 L
.70308 .10301 L
.70413 .10301 L
.70511 .10301 L
.70619 .10301 L
.70734 .10301 L
.70925 .10301 L
.71034 .10301 L
.71134 .10301 L
.71318 .10301 L
.71411 .10301 L
.71513 .10301 L
.7169 .10301 L
.7188 .10301 L
.7206 .10301 L
.72224 .10301 L
.72387 .10302 L
.72562 .10306 L
.72726 .10319 L
.72875 .10348 L
.73051 .10426 L
.73242 .10618 L
.73422 .10979 L
.73588 .11548 L
.73759 .1246 L
.7392 .13672 L
.74096 .15436 L
.74285 .1781 L
.74668 .23565 L
.74854 .26368 L
.75023 .28618 L
.75203 .30527 L
.75373 .31725 L
.75552 .32291 L
.75653 .32291 L
.75746 .32098 L
.75929 .31224 L
.76032 .30477 L
.76129 .29646 L
.76534 .25303 L
.7692 .20896 L
.77285 .17327 L
.77612 .14879 L
.77797 .13815 L
.77968 .13017 L
Mistroke
.78268 .1198 L
.78439 .11559 L
.78599 .11251 L
.78767 .11002 L
.78921 .10828 L
.7909 .10682 L
.79268 .1057 L
.79435 .10493 L
.79613 .10434 L
.79781 .10395 L
.79933 .10369 L
.80113 .10347 L
.80214 .10337 L
.80307 .1033 L
.80478 .10321 L
.8066 .10314 L
.80836 .10309 L
.80936 .10308 L
.81029 .10306 L
.81198 .10304 L
.81379 .10303 L
.8154 .10302 L
.81691 .10302 L
.81856 .10301 L
.82035 .10301 L
.82214 .10301 L
.82316 .10301 L
.8241 .10301 L
.82601 .10301 L
.82708 .10301 L
.82805 .10301 L
.82979 .10301 L
.83168 .10301 L
.83346 .10301 L
.83511 .10301 L
.83664 .10301 L
.83829 .10301 L
.83985 .10301 L
.84127 .10301 L
.84293 .10301 L
.84474 .10301 L
.84646 .10301 L
.84805 .10301 L
.84984 .10301 L
.85153 .10301 L
.85304 .10301 L
.85468 .10301 L
.85648 .10301 L
.85837 .10301 L
.85998 .10301 L
Mistroke
.86175 .10301 L
.86365 .10301 L
.86541 .10301 L
.86633 .10301 L
.86734 .10301 L
.86839 .10301 L
.86938 .10301 L
.8712 .10301 L
.87286 .10301 L
.87468 .10301 L
.87661 .10301 L
.87823 .10301 L
.87996 .10301 L
.88159 .10301 L
.88307 .10301 L
.88482 .10301 L
.88671 .10301 L
.88849 .10301 L
.89014 .10301 L
.89189 .10301 L
.89378 .10301 L
.89555 .10301 L
.89718 .10301 L
.89908 .10301 L
.90015 .10301 L
.90115 .10301 L
.90297 .10301 L
.90399 .10301 L
.90492 .10301 L
.9059 .10301 L
.90694 .10301 L
.90879 .10301 L
.90983 .10301 L
.91079 .10301 L
.91185 .10301 L
.91298 .10301 L
.91395 .10301 L
.91501 .10301 L
.91602 .10301 L
.91694 .10301 L
.9187 .10301 L
.92055 .10301 L
.9223 .10301 L
.92421 .10301 L
.92602 .10301 L
.92769 .10301 L
.92935 .10301 L
.93086 .10301 L
.93259 .10301 L
.93423 .10301 L
Mistroke
.93602 .10301 L
.93791 .10301 L
.93952 .10301 L
.94129 .10301 L
.9432 .10301 L
.94427 .10301 L
.94525 .10301 L
.94714 .10301 L
.94894 .10301 L
.95047 .10301 L
.95215 .10301 L
.95391 .10301 L
.95556 .10301 L
.95709 .10301 L
.9585 .10301 L
.96005 .10301 L
.96168 .10301 L
.96334 .10301 L
.96511 .10301 L
.96678 .10301 L
.9683 .10301 L
.97009 .10301 L
.97109 .10301 L
.97202 .10301 L
.97373 .10301 L
.97554 .10301 L
.9773 .10301 L
.97922 .10301 L
.98103 .10301 L
.98271 .10301 L
.98437 .10301 L
.98588 .10301 L
.98762 .10301 L
.98925 .10301 L
.99105 .10301 L
.99294 .10301 L
.99456 .10301 L
.99633 .10301 L
.99825 .10301 L
.99932 .10301 L
Mfstroke
.99932 .10301 m
1 .10301 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000oooooolLooooo`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0oooooolLooooo`00<?ooool6o`0000;o
oooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^0?oooooo7Oooool003So
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003ooooo
oa?ooooo000hooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05oooo
o`03o`000?oooooooooo0?oooooo4oooool003Sooooo00Go410@oooooooooooooooooa0@400?oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooo
oooo0?oooooo4oooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooo
oooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003ooooooooo
o`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000oooo
ooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`00
0?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool0
0ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o
0000ooooooooool0oooooolCooooo`008oooool5o`0002_ooooo00?o0000ooooooooool0:oooool5
o`0002kooooo0_l000000ol@413oooooooooo`0Zooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?oo
ool01Oo<c<co8B4Qo`000?lQ8B7oc<c<02Wooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`00
0?lb<S;ok^k^6_ooool002?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00[ooooo`03o`000?oooooo
oooo02_ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00_ooooo`03o`000?oooooooooo02_ooooo00Go
EEEEogMgMoooooooV9RHob4Q8@0/ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40:oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool001_ooooo1_l00003ooooo`03
oiRHV?lQ8B7ok^k^02cooooo00?o0000ooooooooool0;?ooool00onHV9So8B4Qonk^kP0]ooooo`Go
0000;?ooool01Ol0003ooooooooooooooooo000002cooooo00Go0000ooooooooooooooooo`00000[
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Jooooo`009Oooool0
0onHV9So8B4Qonk^kP0[ooooo`03o`000?oooooooooo02gooooo00?oV9RHob4Q8Oo^k^h0;?ooool0
1?m4A4CogMgMooooool0000]ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;?ooool01Olb<S;oV9RH
oooooonHV9So<S8b02_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
01[ooooo000Vooooo`03ogMgMomVIVKooooo02[ooooo0_l0000_ooooo`03ogMgMomVIVKooooo02_o
oooo00CogMgMoeEEEOoooooo0000;Oooool01Ol0003oEEEEo`000?l@413oc<c<02cooooo00Goc<c<
o`000?l0003o0000olc<c00[ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Jooooo`009oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool0:oooool00omgMgOoc<c<o`00000]ooooo`03oeEEEOn7QhOooooo02kooooo00Go
410@okZj^_oooooo^[Zjoa0@400[ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@400Jooooo`008oooool01Ol0003o^[ZjoooooonHV9So410@02_ooooo00?o0000oooooooo
ool0:oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo00?ok^k^odA4A?l00000;Oooool00ooM
gMgo410@oiRHV00^ooooo`05o`000?nj^[[ooooookZj^_l00000:oooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool002?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00[ooooo`03o`000?oooooooooo02_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00^ooooo`03ogMg
Mol0003ooooo02gooooo00Coc<c<odA4A?l0003o410@;?ooool01OnYZJWo410@o`000?l@413oZJVY
02Wooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo001Coooo
o`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00
Doooool00ol0003oooooooooo`3mooooo`;o00000_ooool2o`0000oooooo001Cooooo`03o`000?oo
oooooooo0?gooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd?ooooo`00Doooool00ol0003ooooo
ooooo`3nooooo`04omgMgOl0003o410@olc<c13ooooo000:oooooooo0000@?l0000;ooooo`04onk^
k_lQ8B7o410@onk^kQ3ooooo000Fooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`;o00002_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Wooooo00Co8B4QogMgMomgMgOo<S8b4?ooool002;ooooo00?o0000ooooooooool0
;_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0
;_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00Sooooo0_l00002ooooo`;o0000
3oooool005?ooooo00?o0000ooooooooool0WOooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo067ooooo001Cooooo`03o`000?oooooooooo09kooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`1Rooooo`00Doooool00ol0003oooooooooo`2Nooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool0H_ooool005?ooooo00?o0000ooooooooool0W_ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo06;ooooo001Cooooo`03o`000?oooooooooo09kooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`1Sooooo`00Doooool2o`0009oooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`1Sooooo`00Doooool00ol0003oooooooooo`2O
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0Hoooool005?ooooo00?o0000oooo
ooooool0Woooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo06Cooooo001Cooooo`03
o`000?oooooooooo09oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Tooooo`00
Doooool00ol0003oooooooooo`2Oooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
I?ooool005?ooooo00?o0000ooooooooool0Woooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo06Cooooo001Cooooo`03o`000?oooooooooo09oooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`1Tooooo`00Doooool00ol0003oooooooooo`2Oooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool0I?ooool005?ooooo0_l0002Pooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0I?ooool005?ooooo00?o0000ooooooooool0Woooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo06Cooooo001Cooooo`03o`000?oooooooooo09oooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`1Tooooo`00Doooool00ol0003oooooooooo`2O
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0IOooool005?ooooo00?o0000oooo
ooooool0X?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo06Gooooo001Cooooo`03
o`000?oooooooooo0:3ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1Uooooo`00
Doooool00ol0003oooooooooo`2Pooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
IOooool005?ooooo00?o0000ooooooooool0X?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo06Gooooo001Cooooo`;o0000XOooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo06Gooooo001Cooooo`03o`000?oooooooooo0:3ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`1Uooooo`00Doooool00ol0003oooooooooo`2Pooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0I_ooool005?ooooo00?o0000ooooooooool0X?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo06Kooooo001Cooooo`03o`000?oooooooooo0:3ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`1Vooooo`00Doooool00ol0003oooooooooo`2P
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0I_ooool003Sooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0X?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo06Kooooo000hooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oo
oooooooo0:3ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Wooooo`00>?ooool0
1Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01oooool3o`000:3ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`1Wooooo`00>?ooool01Ol0003ooooooooooooo
oooo000000gooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`2Qooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0Ioooool003Sooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0XOooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo06Oooooo000hooooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0:7ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`1Wooooo`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go
0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0:7ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`1Wooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0:7ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`1Wooooo`00Doooool00ol0003oooooooooo`2Qooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0Ioooool005?ooooo00?o0000ooooooooool0XOoo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo06Oooooo001Cooooo`03o`000?oooooo
oooo0:7ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Wooooo`00Doooool2o`00
0:;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Xooooo`00Doooool00ol0003o
ooooooooo`2Qooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0J?ooool005?ooooo
00?o0000ooooooooool0XOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo06Sooooo
001Cooooo`03o`000?oooooooooo0:7ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`1Xooooo`00Doooool00ol0003oooooooooo`2Qooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0J?ooool005?ooooo00?o0000ooooooooool0XOooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo06Sooooo001Cooooo`03o`000?oooooooooo0:;ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`1Xooooo`00Doooool00ol0003oooooooooo`2Rooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0J?ooool005?ooooo0_l0002Sooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0J?ooool005?ooooo00?o0000ooooooooool0X_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo06Sooooo001Cooooo`03o`000?oooooooooo
0:;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Xooooo`00Doooool00ol0003o
ooooooooo`2Rooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0J?ooool005?ooooo
00?o0000ooooooooool0X_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo06Sooooo
001Cooooo`03o`000?oooooooooo0:;ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`1Xooooo`00Doooool00ol0003oooooooooo`2Rooooo`05o`000?ooooooooooooooool00000Jooo
ool005?ooooo00?o0000ooooooooool0X_ooool01Ol0003ooooooooooooooooo000006_ooooo001C
ooooo`;o0000Xoooool01Ol0003ooooooooooooooooo000006_ooooo001Cooooo`03o`000?oooooo
oooo0:;ooooo00Go0000ooooooooooooooooo`00001[ooooo`00Doooool00ol0003oooooooooo`2R
ooooo`05o`000?ooooooooooooooool00000Joooool005?ooooo00?o0000ooooooooool0X_ooool0
1Ol0003ooooooooooooooooo000006_ooooo001Cooooo`03o`000?oooooooooo0:;ooooo00Go0000
ooooooooooooooooo`00001[ooooo`00Doooool00ol0003oooooooooo`2Sooooo`04o`000?oooooo
ooooo`0006_ooooo000hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l0
00000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0:?ooooo00Co0000oooooooooooo0000
Joooool003Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo0:?ooooo00Co0000oooooooooooo0000Joooool003Sooooo
00Go410@oooooooooooooooooa0@400;ooooo`Go00001_ooool3o`000:?ooooo00Co0000oooooooo
oooo0000Joooool003Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgooooo
o`0000Oooooo00?o0000ooooooooool0Xoooool00ol0003oooooo`00001/ooooo`00>?ooool01Ol0
003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003ooooooooo
o`2Tooooo`;o0000K?ooool003Sooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<
c<co000000Oooooo00?o0000ooooooooool0Y?ooool2o`0006cooooo000hooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo0:Cooooo0_l0
001/ooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool01_oo
ool00ol0003oooooooooo`2Tooooo`03o`000?oooooooooo06_ooooo001Cooooo`03o`000?oooooo
oooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool2o`000?oo
oooo5?ooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003ooooooooo
o`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000oooo
ooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`00
0?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool0
0ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o
0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Coooo
o`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00
Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool0
0ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?o
oooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo
000hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o
410@olc<c006ooooo`03o`000?oooooooooo0?oooooo4oooool003Sooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000oooo
ooooool0oooooolCooooo`00>?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo4oooool003Sooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`000?oooooo4ooo
ool003Sooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0
1_ooool00ol0003oooooooooo`3ooooooa?ooooo000hooooo`05oa0@4?ooooooooooooooool@4100
2oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo0?oooooo4oooool003Sooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0
oooooolCooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o
410@1_ooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo
4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3o
oooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003oooooooooo`3ooooooa?o
oooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooo
oolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo
0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003ooooo
ooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003oooooooooo`3o
oooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000oooooooo
ool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oo
oooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0
003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo
0_l0003ooooooaCooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000
ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03
o`000?oooooooooo0?oooooo4oooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooooolCoooo
o`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B401_ooool00ol0003oooooooooo`3ooooooa?ooooo000hooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0oooo
oolCooooo`00>?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RH
oc8b<P06ooooo`?o0000oooooolCooooo`00>?ooool01Ol0003ooooooooooooooooo000000_ooooo
00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo0?oooooo4oooool003Sooooo
00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0
003oooooooooo`3ooooooa?ooooo000hooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0
003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oo
oooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0
003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo
0_l0003ooooooaCooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000
ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03
o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Dooo
ool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool0
05?ooooo0_l0003ooooooaCooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo
00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001C
ooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCoooo
o`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo
4oooool005?ooooo0_l0003ooooooaCooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool0
05?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?o
oooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooo
oolCooooo`00BOooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooolC
ooooo`00Boooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo4oooool004_o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooooa?ooooo001;ooooo`03o`00
0?oooooooooo00Gooooo0ol0003ooooooa?ooooo001;ooooo`03o`000?oooooooooo0?oooooo6ooo
ool004_ooooo00?o0000ooooooooool0oooooolKooooo`00Boooool00ol0003oooooooooo`3ooooo
oa_ooooo0019ooooo`03oeEEEOmVIVKo00000?oooooo7Oooool007Sooooo0ol000000ol@413ooooo
ooooo`3Zooooo`00N_ooool00ol@413o^[Zjooooo`07ooooo`;o00002oooool00ol0003o^[Zjoooo
o`0<ooooo`;o00001Oooool00ol0003o^[Zjooooo`2nooooo`00N_ooool00onHV9So<S8booooo`07
ooooo`03o`000?oooooooooo00[ooooo0_lb<S8>ooooo`03o`000?oooooooooo00?ooooo0_lb<S:o
ooooo`00N_ooool00ooMgMgo0000okZj^P07ooooo`04o`000?ooooooooooooooo`;o00000_ooool2
o`0000?ooooo00?oQhN7o`000?nj^[X01?ooool01OnHV9So0000o`000?m4A4Co^[Zj00Cooooo00?o
0000ooooooooool00oooool00on7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X0
4_ooool4o`000008oa0@4?ooooooooooolc<c?lQ8B7o0000ob4Q8Oo<c<b?ooooo`00N_ooool00omE
EEGoMgMgodA4A007ooooo`0:o`000?ooooooooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgMg@?o
oooo00?oc<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo00?o0000oooo
ooooool00oooool00oo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6
o`0000Gooooo00?o0000ooooooooool00_ooool01OlQ8B7oV9RHoooooonHV9So8B4Q08oooooo001i
ooooo`05omgMgOl@413oooooob4Q8OoMgMd01_ooool00ol0003oooooooooo`02ooooo`04omgMgOl0
003o410@olc<c0_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000008oo
oooo001iooooo`05ofIVI_n7QhOooooooiRHV?mEEED01_ooool00ol0003oooooooooo`02ooooo`04
onk^k_lQ8B7o410@onk^kP_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo00_ooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo00Go<S8boiRH
V?ooooooV9RHoc8b<P2?ooooo`00N?ooool00oo^k^ko0000onk^kP02ooooo`03o`000?oMgMgooooo
00Cooooo00?o0000ooooooooool00_ooool01?lQ8B7oMgMgogMgMolb<S8;ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo00;ooooo00Goc<c<o`000?l0003o0000olc<c02?ooooo`00N?ooool01?l@413o0000o`000?oo
ool2o`000003oa0@4?oooooooooo00?ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o0000
2?ooool00ol@413o0000o`000003o`0000Gooooo00?o0000ooooooooool04?ooool00ol@413o0000
o`000003o`0001Gooooo00?o0000ooooooooool00_ooool01Ol@413o^[Zjoooooonj^[[o410@08oo
oooo0024ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool00_ooool01Ol0003o^[Zj
oooooonj^[[o000008oooooo0024ooooo`;o00004_ooool00ol0003oooooooooo`05ooooo`;o0000
5?ooool00ol0003oooooooooo`0Dooooo`03oeEEEOmVIVKo000000Cooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@2?ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-3.4116, -0.234311, \
0.0510397, 0.00762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.230769 0.0769231 0.103006 0.515028 [
[.07692 .09051 -6 -9 ]
[.07692 .09051 6 0 ]
[.38462 .09051 -3 -9 ]
[.38462 .09051 3 0 ]
[.53846 .09051 -3 -9 ]
[.53846 .09051 3 0 ]
[.69231 .09051 -3 -9 ]
[.69231 .09051 3 0 ]
[.84615 .09051 -3 -9 ]
[.84615 .09051 3 0 ]
[1 .09051 -6 -9 ]
[1 .09051 6 0 ]
[1.025 .10301 0 -6 ]
[1.025 .10301 10 6 ]
[.21827 0 -24 -4.5 ]
[.21827 0 0 4.5 ]
[.21827 .20601 -18 -4.5 ]
[.21827 .20601 0 4.5 ]
[.21827 .30902 -18 -4.5 ]
[.21827 .30902 0 4.5 ]
[.21827 .41202 -18 -4.5 ]
[.21827 .41202 0 4.5 ]
[.21827 .51503 -18 -4.5 ]
[.21827 .51503 0 4.5 ]
[.21827 .61803 -6 -4.5 ]
[.21827 .61803 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07692 .10301 m
.07692 .10926 L
s
[(-2)] .07692 .09051 0 1 Mshowa
.38462 .10301 m
.38462 .10926 L
s
[(2)] .38462 .09051 0 1 Mshowa
.53846 .10301 m
.53846 .10926 L
s
[(4)] .53846 .09051 0 1 Mshowa
.69231 .10301 m
.69231 .10926 L
s
[(6)] .69231 .09051 0 1 Mshowa
.84615 .10301 m
.84615 .10926 L
s
[(8)] .84615 .09051 0 1 Mshowa
1 .10301 m
1 .10926 L
s
[(10)] 1 .09051 0 1 Mshowa
.125 Mabswid
.11538 .10301 m
.11538 .10676 L
s
.15385 .10301 m
.15385 .10676 L
s
.19231 .10301 m
.19231 .10676 L
s
.26923 .10301 m
.26923 .10676 L
s
.30769 .10301 m
.30769 .10676 L
s
.34615 .10301 m
.34615 .10676 L
s
.42308 .10301 m
.42308 .10676 L
s
.46154 .10301 m
.46154 .10676 L
s
.5 .10301 m
.5 .10676 L
s
.57692 .10301 m
.57692 .10676 L
s
.61538 .10301 m
.61538 .10676 L
s
.65385 .10301 m
.65385 .10676 L
s
.73077 .10301 m
.73077 .10676 L
s
.76923 .10301 m
.76923 .10676 L
s
.80769 .10301 m
.80769 .10676 L
s
.88462 .10301 m
.88462 .10676 L
s
.92308 .10301 m
.92308 .10676 L
s
.96154 .10301 m
.96154 .10676 L
s
.03846 .10301 m
.03846 .10676 L
s
.25 Mabswid
0 .10301 m
1 .10301 L
s
gsave
1.025 .10301 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.23077 0 m
.23702 0 L
s
[(-0.2)] .21827 0 1 0 Mshowa
.23077 .20601 m
.23702 .20601 L
s
[(0.2)] .21827 .20601 1 0 Mshowa
.23077 .30902 m
.23702 .30902 L
s
[(0.4)] .21827 .30902 1 0 Mshowa
.23077 .41202 m
.23702 .41202 L
s
[(0.6)] .21827 .41202 1 0 Mshowa
.23077 .51503 m
.23702 .51503 L
s
[(0.8)] .21827 .51503 1 0 Mshowa
.23077 .61803 m
.23702 .61803 L
s
[(1)] .21827 .61803 1 0 Mshowa
.125 Mabswid
.23077 .02575 m
.23452 .02575 L
s
.23077 .0515 m
.23452 .0515 L
s
.23077 .07725 m
.23452 .07725 L
s
.23077 .12876 m
.23452 .12876 L
s
.23077 .15451 m
.23452 .15451 L
s
.23077 .18026 m
.23452 .18026 L
s
.23077 .23176 m
.23452 .23176 L
s
.23077 .25751 m
.23452 .25751 L
s
.23077 .28327 m
.23452 .28327 L
s
.23077 .33477 m
.23452 .33477 L
s
.23077 .36052 m
.23452 .36052 L
s
.23077 .38627 m
.23452 .38627 L
s
.23077 .43777 m
.23452 .43777 L
s
.23077 .46353 m
.23452 .46353 L
s
.23077 .48928 m
.23452 .48928 L
s
.23077 .54078 m
.23452 .54078 L
s
.23077 .56653 m
.23452 .56653 L
s
.23077 .59228 m
.23452 .59228 L
s
.25 Mabswid
.23077 0 m
.23077 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
123.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(19) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.71059 .10301 m
.71103 .10301 L
.71268 .10301 L
.71446 .10301 L
.7154 .10301 L
.71643 .10301 L
.71751 .10301 L
.71852 .10301 L
.72031 .10301 L
.72132 .10301 L
.72224 .10301 L
.72398 .10301 L
.72582 .10301 L
.72739 .10301 L
.72913 .10301 L
.73098 .10301 L
.73203 .10301 L
.73299 .10301 L
.73475 .10301 L
.73661 .10301 L
.73824 .10301 L
.73998 .10304 L
.74162 .10312 L
.74312 .10334 L
.74487 .10397 L
.74677 .10563 L
.74857 .10892 L
.75023 .11435 L
.75192 .12322 L
.75348 .13492 L
.75526 .15311 L
.75696 .17481 L
.76002 .22121 L
.76327 .27077 L
.76513 .29371 L
.76683 .30856 L
.76853 .31678 L
.77013 .31812 L
.772 .31229 L
.77372 .3009 L
.77561 .28339 L
.77761 .26133 L
.78429 .18574 L
.78621 .16811 L
.78803 .15393 L
.79144 .13372 L
.79339 .12543 L
.7952 .11953 L
.79718 .11464 L
.79928 .1109 L
Mistroke
.80108 .1086 L
.80276 .10702 L
.80461 .10577 L
.80565 .10523 L
.8066 .10483 L
.80846 .10423 L
.81022 .10384 L
.8118 .10359 L
.81351 .1034 L
.81538 .10326 L
.81632 .10321 L
.81735 .10317 L
.81918 .10311 L
.82089 .10307 L
.82261 .10305 L
.82424 .10304 L
.8257 .10303 L
.82729 .10302 L
.82902 .10301 L
.83086 .10301 L
.83243 .10301 L
.83416 .10301 L
.83606 .10301 L
.83701 .10301 L
.83806 .10301 L
.83991 .10301 L
.84163 .10301 L
.84268 .10301 L
.84367 .10301 L
.84553 .10301 L
.84657 .10301 L
.84752 .10301 L
.84858 .10301 L
.84969 .10301 L
.85142 .10301 L
.85328 .10301 L
.85503 .10301 L
.85663 .10301 L
.85851 .10301 L
.85957 .10301 L
.86055 .10301 L
.86236 .10301 L
.86428 .10301 L
.86609 .10301 L
.86711 .10301 L
.86807 .10301 L
.86908 .10301 L
.87001 .10301 L
.87107 .10301 L
.87208 .10301 L
Mistroke
.87386 .10301 L
.87551 .10301 L
.87732 .10301 L
.87824 .10301 L
.87925 .10301 L
.88027 .10301 L
.88134 .10301 L
.88327 .10301 L
.88434 .10301 L
.88534 .10301 L
.88643 .10301 L
.8876 .10301 L
.88861 .10301 L
.88971 .10301 L
.89075 .10301 L
.8917 .10301 L
.89351 .10301 L
.89543 .10301 L
.89725 .10301 L
.89891 .10301 L
.90083 .10301 L
.90265 .10301 L
.90433 .10301 L
.90588 .10301 L
.90759 .10301 L
.9094 .10301 L
.91044 .10301 L
.9114 .10301 L
.91245 .10301 L
.91356 .10301 L
.91542 .10301 L
.91648 .10301 L
.91747 .10301 L
.91931 .10301 L
.92099 .10301 L
.92192 .10301 L
.92293 .10301 L
.92476 .10301 L
.92654 .10301 L
.92817 .10301 L
.93005 .10301 L
.93184 .10301 L
.93349 .10301 L
.93501 .10301 L
.93669 .10301 L
.93848 .10301 L
.9395 .10301 L
.94044 .10301 L
.94147 .10301 L
.94256 .10301 L
Mistroke
.94439 .10301 L
.94543 .10301 L
.9464 .10301 L
.94822 .10301 L
.94987 .10301 L
.95178 .10301 L
.95359 .10301 L
.95534 .10301 L
.95634 .10301 L
.95728 .10301 L
.95916 .10301 L
.96022 .10301 L
.96119 .10301 L
.96283 .10301 L
.96462 .10301 L
.96649 .10301 L
.96823 .10301 L
.96922 .10301 L
.9703 .10301 L
.97132 .10301 L
.97226 .10301 L
.97404 .10301 L
.97593 .10301 L
.9769 .10301 L
.97795 .10301 L
.97985 .10301 L
.981 .10301 L
.9821 .10301 L
.98308 .10301 L
.98416 .10301 L
.9851 .10301 L
.9861 .10301 L
.98788 .10301 L
.9898 .10301 L
.99089 .10301 L
.9919 .10301 L
.99374 .10301 L
.99542 .10301 L
.99635 .10301 L
.99736 .10301 L
.99919 .10301 L
Mfstroke
.99919 .10301 m
1 .10301 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000oooooolLooooo`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0oooooolLooooo`00<?ooool6o`0000;o
oooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^0?oooooo7Oooool003So
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003ooooo
oa?ooooo000hooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05oooo
o`03o`000?oooooooooo0?oooooo4oooool003Sooooo00Go410@oooooooooooooooooa0@400?oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooo
oooo0?oooooo4oooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooo
oooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003ooooooooo
o`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000oooo
ooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`00
0?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool0
0ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o
0000ooooooooool0oooooolCooooo`008oooool5o`0002_ooooo00?o0000ooooooooool0:oooool5
o`0002kooooo0_l000000ol@413oooooooooo`0Zooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?oo
ool01Oo<c<co8B4Qo`000?lQ8B7oc<c<02Wooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`00
0?lb<S;ok^k^6_ooool002?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00[ooooo`03o`000?oooooo
oooo02_ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00_ooooo`03o`000?oooooooooo02_ooooo00Go
EEEEogMgMoooooooV9RHob4Q8@0/ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40:oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool001_ooooo1_l00003ooooo`03
oiRHV?lQ8B7ok^k^02cooooo00?o0000ooooooooool0;?ooool00onHV9So8B4Qonk^kP0]ooooo`Go
0000;?ooool01Ol0003ooooooooooooooooo000002cooooo00Go0000ooooooooooooooooo`00000[
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Jooooo`009Oooool0
0onHV9So8B4Qonk^kP0[ooooo`03o`000?oooooooooo02gooooo00?oV9RHob4Q8Oo^k^h0;?ooool0
1?m4A4CogMgMooooool0000]ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;?ooool01Olb<S;oV9RH
oooooonHV9So<S8b02_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
01[ooooo000Vooooo`03ogMgMomVIVKooooo02[ooooo0_l0000_ooooo`03ogMgMomVIVKooooo02_o
oooo00CogMgMoeEEEOoooooo0000;Oooool01Ol0003oEEEEo`000?l@413oc<c<02cooooo00Goc<c<
o`000?l0003o0000olc<c00[ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Jooooo`009oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool0:oooool00omgMgOoc<c<o`00000]ooooo`03oeEEEOn7QhOooooo02kooooo00Go
410@okZj^_oooooo^[Zjoa0@400[ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@400Jooooo`008oooool01Ol0003o^[ZjoooooonHV9So410@02_ooooo00?o0000oooooooo
ool0:oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo00?ok^k^odA4A?l00000;Oooool00ooM
gMgo410@oiRHV00^ooooo`05o`000?nj^[[ooooookZj^_l00000:oooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool002?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00[ooooo`03o`000?oooooooooo02_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00^ooooo`03ogMg
Mol0003ooooo02gooooo00Coc<c<odA4A?l0003o410@;?ooool01OnYZJWo410@o`000?l@413oZJVY
02Wooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo001Coooo
o`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00
Doooool00ol0003oooooooooo`3mooooo`;o00000_ooool2o`0000oooooo001Cooooo`03o`000?oo
oooooooo0?gooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd?ooooo`00Doooool00ol0003ooooo
ooooo`3nooooo`04omgMgOl0003o410@olc<c13ooooo000:oooooooo0000@?l0000;ooooo`04onk^
k_lQ8B7o410@onk^kQ3ooooo000Fooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo000000_ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`04ob4Q8OmgMgOoMgMgoc8b<Q3ooooo000Rooooo`03o`00
0?oooooooooo02kooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0^ooooo`03o`00
0?oooooooooo02kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`08ooooo`;o0000
0_ooool2o`0000oooooo001Cooooo`03o`000?oooooooooo0:;ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`1Nooooo`00Doooool00ol0003oooooooooo`2Rooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool0G_ooool005?ooooo00?o0000ooooooooool0Xoooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo05kooooo001Cooooo`03o`000?oooooooooo0:?o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Nooooo`00Doooool00ol0003ooooo
ooooo`2Sooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0Goooool005?ooooo0_l0
002Tooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0Goooool005?ooooo00?o0000
ooooooooool0Xoooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05oooooo001Coooo
o`03o`000?oooooooooo0:?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Ooooo
o`00Doooool00ol0003oooooooooo`2Sooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool0Goooool005?ooooo00?o0000ooooooooool0Xoooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo063ooooo001Cooooo`03o`000?oooooooooo0:Cooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`1Pooooo`00Doooool00ol0003oooooooooo`2Tooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0H?ooool005?ooooo00?o0000ooooooooool0Y?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo067ooooo001Cooooo`;o0000YOooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo067ooooo001Cooooo`03o`000?oooooooooo0:Cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`1Qooooo`00Doooool00ol0003ooooooooo
o`2Tooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0HOooool005?ooooo00?o0000
ooooooooool0YOooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo067ooooo001Coooo
o`03o`000?oooooooooo0:Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Qoooo
o`00Doooool00ol0003oooooooooo`2Uooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0HOooool005?ooooo00?o0000ooooooooool0YOooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo067ooooo001Cooooo`03o`000?oooooooooo0:Gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`1Qooooo`00Doooool2o`000:Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`1Rooooo`00Doooool00ol0003oooooooooo`2Uooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0H_ooool005?ooooo00?o0000ooooooooool0YOooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo06;ooooo001Cooooo`03o`000?oooooooooo0:Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Rooooo`00Doooool00ol0003ooooooooo
o`2Uooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0H_ooool005?ooooo00?o0000
ooooooooool0YOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo06;ooooo000hoooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooo
oooo0:Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Rooooo`00>?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_oo
ool00ol0003oooooooooo`2Vooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0H_oo
ool003Sooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0
002Vooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0H_ooool003Sooooo00Go0000
ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0Y_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo06?ooooo000hooooo`05o`000?oooooo
ooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0:Kooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`1Sooooo`00>?ooool01Ol@413ooooooooooooo
oooo410@00oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2Vooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0Hoooool003Sooooo00GoMgMgoiRHV?ooooooV9RHogMg
M`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`2Vooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0Hoooool003Sooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`2Vooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0Hoooool005?ooooo00?o0000ooooooooool0
Y_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo06?ooooo001Cooooo`03o`000?oo
oooooooo0:Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Sooooo`00Doooool0
0ol0003oooooooooo`2Vooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Hoooool0
05?ooooo0_l0002Wooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Hoooool005?o
oooo00?o0000ooooooooool0Y_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo06?o
oooo001Cooooo`03o`000?oooooooooo0:Kooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`1Sooooo`00Doooool00ol0003oooooooooo`2Vooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0Hoooool005?ooooo00?o0000ooooooooool0Y_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo06Cooooo001Cooooo`03o`000?oooooooooo0:Oooooo00Go0000oooo
ooooooooooooo`00001Vooooo`00Doooool00ol0003oooooooooo`2Wooooo`05o`000?oooooooooo
ooooool00000I_ooool005?ooooo00?o0000ooooooooool0Yoooool01Ol0003ooooooooooooooooo
000006Kooooo001Cooooo`;o0000Z?ooool01Ol0003ooooooooooooooooo000006Kooooo001Coooo
o`03o`000?oooooooooo0:Oooooo00Go0000ooooooooooooooooo`00001Vooooo`00Doooool00ol0
003oooooooooo`2Wooooo`05o`000?ooooooooooooooool00000I_ooool005?ooooo00?o0000oooo
ooooool0Yoooool01Ol0003ooooooooooooooooo000006Kooooo001Cooooo`03o`000?oooooooooo
0:Oooooo00Go0000ooooooooooooooooo`00001Vooooo`00Doooool00ol0003oooooooooo`2Woooo
o`05o`000?ooooooooooooooool00000I_ooool005?ooooo00?o0000ooooooooool0Yoooool01Ol0
003ooooooooooooooooo000006Kooooo001Cooooo`03o`000?oooooooooo0:Oooooo00Go0000oooo
ooooooooooooo`00001Vooooo`00Doooool2o`000:Sooooo00Go0000ooooooooooooooooo`00001V
ooooo`00Doooool00ol0003oooooooooo`2Wooooo`05o`000?ooooooooooooooool00000I_ooool0
05?ooooo00?o0000ooooooooool0Yoooool01Ol0003ooooooooooooooooo000006Kooooo001Coooo
o`03o`000?oooooooooo0:Oooooo00Go0000ooooooooooooooooo`00001Vooooo`00Doooool00ol0
003oooooooooo`2Wooooo`04o`000?ooooooooooo`0006Oooooo001Cooooo`03o`000?oooooooooo
0:Oooooo00Co0000oooooooooooo0000Ioooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05
ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0Z?ooool0
0ol0003oooooo`00001Wooooo`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Z?ooool00ol0003oooooo`00001W
ooooo`00>?ooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00006ooooo`?o0000Z?ooool2
o`0006Sooooo000hooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool0
0007ooooo`03o`000?oooooooooo0:Sooooo0_l0001Xooooo`00>?ooool01Ol0003ooooooooooooo
oooo000000_ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`2Xooooo`;o0000
J?ooool003Sooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo
00?o0000ooooooooool0Z?ooool2o`0006Sooooo000hooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo0?oooooo4oooool003Sooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0
oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooo
oooo0?oooooo4oooool005?ooooo0_l0003ooooooaCooooo001Cooooo`03o`000?oooooooooo0?oo
oooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003ooooooooo
o`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000oooo
ooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`00
0?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool2
o`000?oooooo5?ooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o
0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Coooo
o`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00
Doooool2o`000?oooooo5?ooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool0
0ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?o
oooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`3ooooo
oa?ooooo000hooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMg
MoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?oooooo4oooool003Sooooo00Go410@oooo
oooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooooooo
o`3ooooooa?ooooo000hooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooo
oonHV9So8B4Q00Kooooo0ol0003ooooooa?ooooo000hooooo`05o`000?ooooooooooooooool00000
2oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0oooooolCooooo`00
>?ooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool02?ooool00ol0003o
ooooooooo`3ooooooa?ooooo000hooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo
410@oiRHV008ooooo`03o`000?oooooooooo0?oooooo4oooool003Sooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0oooooolCoooo
o`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo
4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool2o`000?oooooo5?ooool0
05?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?o
oooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooo
oolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo
0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool2o`000?oooooo
5?ooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3o
oooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000oooooooo
ool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oo
oooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0
003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003ooooo
ooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000
ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo000hooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006
ooooo`03o`000?oooooooooo0?oooooo4oooool003Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0oooo
oolCooooo`00>?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo0?oooooo4oooool003Sooooo00Go0000oooooooooooooooo
o`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3o`000?oooooo4oooool003Sooooo
00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0
003oooooooooo`3ooooooa?ooooo000hooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@
413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oo
oooooooo0?oooooo4oooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@
413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oo
oooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0
003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003ooooo
ooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000
ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03
o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Dooo
ool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0
003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo
00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001C
ooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCoooo
o`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Dooo
ool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool0
05?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?o
oooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool004Wooooo1?l000000ol@413ooooooooo
o`03ooooo`03o`000?oooooooooo0?oooooo4oooool004_ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`3ooooooa?ooooo001;ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0oooooolCooooo`00Boooool00ol0003oooooooooo`05ooooo`?o0000oooooolCooooo`00
Boooool00ol0003oooooooooo`3ooooooa_ooooo001;ooooo`03o`000?oooooooooo0?oooooo6ooo
ool004_ooooo00?o0000ooooooooool0oooooolKooooo`00BOooool00omEEEGoIVIVo`00003ooooo
oagooooo001hooooo`?o000000?o410@ooooooooool0j_ooool007[ooooo00?o410@okZj^_ooool0
1oooool2o`0000_ooooo00?o0000okZj^_ooool03?ooool2o`0000Gooooo00?o0000okZj^_ooool0
__ooool007[ooooo00?oV9RHoc8b<_ooool01oooool00ol0003oooooooooo`0:ooooo`;o<S8b3_oo
ool00ol0003oooooooooo`03ooooo`;o<S8b_oooool007[ooooo00?ogMgMo`000?nj^[X01oooool0
1?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`03ohN7Qol0003o^[Zj00Cooooo00Go
V9RHo`000?l0003oA4A4okZj^P04ooooo`03o`000?oooooooooo00?ooooo00?oQhN7o`000?nj^[X0
3?ooool01OnHV9So0000o`000?m4A4Co^[Zj01;ooooo1?l000001ol@413oooooooooool@413o0000
odA4A?o<c<`0T?ooool007[ooooo00?oEEEEogMgMom4A4@01oooool02_l0003ooooooooooooooooo
k^k^ob4Q8On7QhOo^[Zjo`000?oMgMd3ooooo`03olc<c?l0003o410@00Cooooo00Go410@okZj^_o^
k^koMgMgoa0@4004ooooo`03o`000?oooooooooo00?ooooo00?oc<c<o`000?l@41003?ooool01Ol@
413o^[Zjonk^k_mgMgOo410@00Wooooo1_l00005ooooo`03o`000?oooooooooo00Cooooo00?oV9RH
oa0@4?oMgMd0Soooool007Wooooo00GogMgMoa0@4?oooooo8B4QomgMg@06ooooo`03o`000?oooooo
oooo00;ooooo00CogMgMo`000?l@413oc<c<2oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`05ooooo`03ohN7QomE
EEGooooo08kooooo001iooooo`05ofIVI_n7QhOooooooiRHV?mEEED01_ooool00ol0003ooooooooo
o`02ooooo`04onk^k_lQ8B7o410@onk^kP_ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo00_ooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo
00Goc<c<ob4Q8Ol0003oEEEEo`00002?ooooo`00N?ooool00oo^k^ko0000onk^kP02ooooo`03o`00
0?oMgMgooooo00Cooooo00?o0000ooooooooool00_ooool01?lQ8B7oMgMgogMgMolb<S8;ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo00;ooooo00Go8B4QohN7QoooooooV9RHo`00002?ooooo`00N?ooool01?l@413o
0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo00Co0000oooooooooooooooo0_l00002
ooooo`;o00002?ooool00ol@413o0000o`000003o`0000Gooooo00?o0000ooooooooool04?ooool0
0ol@413o0000o`000003o`0001Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000008oooooo0024ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool00_ooool0
1OlQ8B7oV9RHoooooomgMgOoEEEE08oooooo0024ooooo`;o00004_ooool00ol0003oooooooooo`05
ooooo`;o00005?ooool00ol0003oooooooooo`0Dooooo`03oeEEEOmVIVKo000000Cooooo00Goc<c<
oa0@4?l0003o<S8bonk^kP2?ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-3.4116, -0.234311, \
0.0510397, 0.00762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.230769 0.0769231 0.103006 0.515028 [
[.07692 .09051 -6 -9 ]
[.07692 .09051 6 0 ]
[.38462 .09051 -3 -9 ]
[.38462 .09051 3 0 ]
[.53846 .09051 -3 -9 ]
[.53846 .09051 3 0 ]
[.69231 .09051 -3 -9 ]
[.69231 .09051 3 0 ]
[.84615 .09051 -3 -9 ]
[.84615 .09051 3 0 ]
[1 .09051 -6 -9 ]
[1 .09051 6 0 ]
[1.025 .10301 0 -6 ]
[1.025 .10301 10 6 ]
[.21827 0 -24 -4.5 ]
[.21827 0 0 4.5 ]
[.21827 .20601 -18 -4.5 ]
[.21827 .20601 0 4.5 ]
[.21827 .30902 -18 -4.5 ]
[.21827 .30902 0 4.5 ]
[.21827 .41202 -18 -4.5 ]
[.21827 .41202 0 4.5 ]
[.21827 .51503 -18 -4.5 ]
[.21827 .51503 0 4.5 ]
[.21827 .61803 -6 -4.5 ]
[.21827 .61803 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07692 .10301 m
.07692 .10926 L
s
[(-2)] .07692 .09051 0 1 Mshowa
.38462 .10301 m
.38462 .10926 L
s
[(2)] .38462 .09051 0 1 Mshowa
.53846 .10301 m
.53846 .10926 L
s
[(4)] .53846 .09051 0 1 Mshowa
.69231 .10301 m
.69231 .10926 L
s
[(6)] .69231 .09051 0 1 Mshowa
.84615 .10301 m
.84615 .10926 L
s
[(8)] .84615 .09051 0 1 Mshowa
1 .10301 m
1 .10926 L
s
[(10)] 1 .09051 0 1 Mshowa
.125 Mabswid
.11538 .10301 m
.11538 .10676 L
s
.15385 .10301 m
.15385 .10676 L
s
.19231 .10301 m
.19231 .10676 L
s
.26923 .10301 m
.26923 .10676 L
s
.30769 .10301 m
.30769 .10676 L
s
.34615 .10301 m
.34615 .10676 L
s
.42308 .10301 m
.42308 .10676 L
s
.46154 .10301 m
.46154 .10676 L
s
.5 .10301 m
.5 .10676 L
s
.57692 .10301 m
.57692 .10676 L
s
.61538 .10301 m
.61538 .10676 L
s
.65385 .10301 m
.65385 .10676 L
s
.73077 .10301 m
.73077 .10676 L
s
.76923 .10301 m
.76923 .10676 L
s
.80769 .10301 m
.80769 .10676 L
s
.88462 .10301 m
.88462 .10676 L
s
.92308 .10301 m
.92308 .10676 L
s
.96154 .10301 m
.96154 .10676 L
s
.03846 .10301 m
.03846 .10676 L
s
.25 Mabswid
0 .10301 m
1 .10301 L
s
gsave
1.025 .10301 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.23077 0 m
.23702 0 L
s
[(-0.2)] .21827 0 1 0 Mshowa
.23077 .20601 m
.23702 .20601 L
s
[(0.2)] .21827 .20601 1 0 Mshowa
.23077 .30902 m
.23702 .30902 L
s
[(0.4)] .21827 .30902 1 0 Mshowa
.23077 .41202 m
.23702 .41202 L
s
[(0.6)] .21827 .41202 1 0 Mshowa
.23077 .51503 m
.23702 .51503 L
s
[(0.8)] .21827 .51503 1 0 Mshowa
.23077 .61803 m
.23702 .61803 L
s
[(1)] .21827 .61803 1 0 Mshowa
.125 Mabswid
.23077 .02575 m
.23452 .02575 L
s
.23077 .0515 m
.23452 .0515 L
s
.23077 .07725 m
.23452 .07725 L
s
.23077 .12876 m
.23452 .12876 L
s
.23077 .15451 m
.23452 .15451 L
s
.23077 .18026 m
.23452 .18026 L
s
.23077 .23176 m
.23452 .23176 L
s
.23077 .25751 m
.23452 .25751 L
s
.23077 .28327 m
.23452 .28327 L
s
.23077 .33477 m
.23452 .33477 L
s
.23077 .36052 m
.23452 .36052 L
s
.23077 .38627 m
.23452 .38627 L
s
.23077 .43777 m
.23452 .43777 L
s
.23077 .46353 m
.23452 .46353 L
s
.23077 .48928 m
.23452 .48928 L
s
.23077 .54078 m
.23452 .54078 L
s
.23077 .56653 m
.23452 .56653 L
s
.23077 .59228 m
.23452 .59228 L
s
.25 Mabswid
.23077 0 m
.23077 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
123.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(20) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.7274 .10301 m
.7291 .10301 L
.73007 .10301 L
.73112 .10301 L
.73303 .10301 L
.73488 .10301 L
.73659 .10301 L
.73822 .10301 L
.73975 .10301 L
.74143 .10301 L
.74322 .10301 L
.7451 .10301 L
.74689 .10301 L
.74849 .10301 L
.75023 .10301 L
.7519 .10301 L
.75371 .10302 L
.75541 .10308 L
.75698 .10326 L
.75871 .10379 L
.7606 .10529 L
.76156 .10669 L
.76258 .10889 L
.76442 .11542 L
.76544 .12082 L
.76638 .12716 L
.76849 .1468 L
.77035 .1702 L
.77233 .19986 L
.77579 .25527 L
.7777 .28162 L
.77951 .30033 L
.78117 .31065 L
.78299 .31376 L
.78464 .30951 L
.78617 .30033 L
.78776 .28658 L
.78919 .27146 L
.79241 .23324 L
.79592 .19274 L
.79777 .17432 L
.79972 .1577 L
.80143 .14556 L
.8033 .13475 L
.8049 .12739 L
.8066 .12119 L
.8085 .11589 L
.81026 .11225 L
.81215 .10939 L
.81323 .10814 L
Mistroke
.81424 .10718 L
.81606 .10586 L
.81772 .105 L
.81955 .10434 L
.82147 .10387 L
.82309 .1036 L
.82483 .1034 L
.82646 .10327 L
.82794 .10319 L
.82969 .10313 L
.83158 .10308 L
.83337 .10305 L
.83502 .10304 L
.83677 .10303 L
.83866 .10302 L
.84044 .10301 L
.84206 .10301 L
.84397 .10301 L
.84504 .10301 L
.84604 .10301 L
.84786 .10301 L
.84879 .10301 L
.84981 .10301 L
.85079 .10301 L
.85183 .10301 L
.85368 .10301 L
.85472 .10301 L
.85568 .10301 L
.85674 .10301 L
.85787 .10301 L
.85885 .10301 L
.85991 .10301 L
.86091 .10301 L
.86183 .10301 L
.86359 .10301 L
.86544 .10301 L
.8672 .10301 L
.86911 .10301 L
.87092 .10301 L
.8726 .10301 L
.87426 .10301 L
.87576 .10301 L
.8775 .10301 L
.87914 .10301 L
.88093 .10301 L
.88283 .10301 L
.88444 .10301 L
.88621 .10301 L
.88813 .10301 L
.8892 .10301 L
Mistroke
.89017 .10301 L
.89207 .10301 L
.89386 .10301 L
.89539 .10301 L
.89708 .10301 L
.89884 .10301 L
.90049 .10301 L
.90203 .10301 L
.90344 .10301 L
.90499 .10301 L
.90662 .10301 L
.90827 .10301 L
.91005 .10301 L
.91172 .10301 L
.91324 .10301 L
.91503 .10301 L
.91603 .10301 L
.91696 .10301 L
.91867 .10301 L
.92048 .10301 L
.92224 .10301 L
.92416 .10301 L
.92598 .10301 L
.92766 .10301 L
.92932 .10301 L
.93083 .10301 L
.93257 .10301 L
.93421 .10301 L
.93601 .10301 L
.93791 .10301 L
.93953 .10301 L
.9413 .10301 L
.94322 .10301 L
.94429 .10301 L
.94526 .10301 L
.94716 .10301 L
.94896 .10301 L
.95049 .10301 L
.95218 .10301 L
.95394 .10301 L
.9556 .10301 L
.95714 .10301 L
.95855 .10301 L
.96018 .10301 L
.96173 .10301 L
.96339 .10301 L
.96516 .10301 L
.96684 .10301 L
.96835 .10301 L
.97014 .10301 L
Mistroke
.97115 .10301 L
.97208 .10301 L
.97379 .10301 L
.97559 .10301 L
.97736 .10301 L
.97836 .10301 L
.97929 .10301 L
.98099 .10301 L
.98279 .10301 L
.9844 .10301 L
.98591 .10301 L
.98757 .10301 L
.98936 .10301 L
.99115 .10301 L
.99217 .10301 L
.99311 .10301 L
.99502 .10301 L
.99609 .10301 L
.99706 .10301 L
.99881 .10301 L
Mfstroke
.99881 .10301 m
1 .10301 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000oooooolLooooo`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0oooooolLooooo`00<?ooool6o`0000;o
oooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^0?oooooo7Oooool003So
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003ooooo
oa?ooooo000hooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05oooo
o`03o`000?oooooooooo0?oooooo4oooool003Sooooo00Go410@oooooooooooooooooa0@400?oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooo
oooo0?oooooo4oooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooo
oooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003ooooooooo
o`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000oooo
ooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`00
0?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool0
0ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o
0000ooooooooool0oooooolCooooo`008oooool5o`0002_ooooo00?o0000ooooooooool0:oooool5
o`0002kooooo0_l000000ol@413oooooooooo`0Zooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?oo
ool01Oo<c<co8B4Qo`000?lQ8B7oc<c<02Wooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`00
0?lb<S;ok^k^6_ooool002?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00[ooooo`03o`000?oooooo
oooo02_ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00_ooooo`03o`000?oooooooooo02_ooooo00Go
EEEEogMgMoooooooV9RHob4Q8@0/ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40:oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool001_ooooo1_l00003ooooo`03
oiRHV?lQ8B7ok^k^02cooooo00?o0000ooooooooool0;?ooool00onHV9So8B4Qonk^kP0]ooooo`Go
0000;?ooool01Ol0003ooooooooooooooooo000002cooooo00Go0000ooooooooooooooooo`00000[
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Jooooo`009Oooool0
0onHV9So8B4Qonk^kP0[ooooo`03o`000?oooooooooo02gooooo00?oV9RHob4Q8Oo^k^h0;?ooool0
1?m4A4CogMgMooooool0000]ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;?ooool01Olb<S;oV9RH
oooooonHV9So<S8b02_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
01[ooooo000Vooooo`03ogMgMomVIVKooooo02[ooooo0_l0000_ooooo`03ogMgMomVIVKooooo02_o
oooo00CogMgMoeEEEOoooooo0000;Oooool01Ol0003oEEEEo`000?l@413oc<c<02cooooo00Goc<c<
o`000?l0003o0000olc<c00[ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Jooooo`009oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool0:oooool00omgMgOoc<c<o`00000]ooooo`03oeEEEOn7QhOooooo02kooooo00Go
410@okZj^_oooooo^[Zjoa0@400[ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@400Jooooo`008oooool01Ol0003o^[ZjoooooonHV9So410@02_ooooo00?o0000oooooooo
ool0:oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo00?ok^k^odA4A?l00000;Oooool00ooM
gMgo410@oiRHV00^ooooo`05o`000?nj^[[ooooookZj^_l00000:oooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool002?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00[ooooo`03o`000?oooooooooo02_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00^ooooo`03ogMg
Mol0003ooooo02gooooo00Coc<c<odA4A?l0003o410@;?ooool01OnYZJWo410@o`000?l@413oZJVY
02Wooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo001Coooo
o`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00
Doooool00ol0003oooooooooo`3mooooo`;o00000_ooool2o`0000oooooo001Cooooo`03o`000?oo
oooooooo0?gooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd?ooooo`00Doooool00ol0003ooooo
ooooo`3nooooo`04omgMgOl0003o410@olc<c13ooooo000:oooooooo0000@?l0000;ooooo`04onk^
k_lQ8B7o410@onk^kQ3ooooo000Fooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooool00000
3?ooool3o`0000Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`04ob4Q
8OmgMgOoMgMgoc8b<Q3ooooo000Rooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0
;_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
;_ooool00ol0003oooooooooo`08ooooo`;o00000_ooool2o`0000oooooo001Cooooo`03o`000?oo
oooooooo0:Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1Iooooo`00Doooool0
0ol0003oooooooooo`2Wooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0F_ooool0
05?ooooo00?o0000ooooooooool0Yoooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
05_ooooo001Cooooo`03o`000?oooooooooo0:Oooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`1Kooooo`00Doooool00ol0003oooooooooo`2Xooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool0Foooool005?ooooo0_l0002Yooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool0Foooool005?ooooo00?o0000ooooooooool0Z?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo05cooooo001Cooooo`03o`000?oooooooooo0:Sooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`1Looooo`00Doooool00ol0003oooooooooo`2Xooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool0G?ooool005?ooooo00?o0000ooooooooool0
Z?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo05cooooo001Cooooo`03o`000?oo
oooooooo0:Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Looooo`00Doooool0
0ol0003oooooooooo`2Xooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0G?ooool0
05?ooooo00?o0000ooooooooool0Z?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
05cooooo001Cooooo`;o0000ZOooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo05go
oooo001Cooooo`03o`000?oooooooooo0:Sooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`1Mooooo`00Doooool00ol0003oooooooooo`2Yooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0GOooool005?ooooo00?o0000ooooooooool0ZOooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo05gooooo001Cooooo`03o`000?oooooooooo0:Wooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`1Mooooo`00Doooool00ol0003oooooooooo`2Yooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0GOooool005?ooooo00?o0000ooooooooool0
ZOooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05gooooo001Cooooo`03o`000?oo
oooooooo0:Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Mooooo`00Doooool2
o`000:[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Mooooo`00Doooool00ol0
003oooooooooo`2Yooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0GOooool005?o
oooo00?o0000ooooooooool0ZOooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05ko
oooo001Cooooo`03o`000?oooooooooo0:Wooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`1Nooooo`00Doooool00ol0003oooooooooo`2Yooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0G_ooool005?ooooo00?o0000ooooooooool0ZOooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo05kooooo000hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2
ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo0:Wooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`1Nooooo`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`2Yooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0G_ooool003Sooooo00Go410@oooooooooooooooooa0@
400<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0002Yooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0G_ooool003Sooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ
8B7ok^k^00Kooooo00?o0000ooooooooool0ZOooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo05kooooo000hooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVoooo
o`05ooooo`03o`000?oooooooooo0:Wooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`1Nooooo`00>?ooool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`2Zooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Gooo
ool003Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
1_ooool00ol0003oooooooooo`2Zooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
Goooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`01_ooool00ol0003oooooooooo`2Zooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0Goooool005?ooooo00?o0000ooooooooool0Z_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo05oooooo001Cooooo`03o`000?oooooooooo0:[ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`1Oooooo`00Doooool00ol0003oooooooooo`2Zooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0Goooool005?ooooo0_l0002[ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0Goooool005?ooooo00?o0000ooooooooool0Z_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo05oooooo001Cooooo`03o`000?oooooooooo0:[ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`1Oooooo`00Doooool00ol0003ooooooooo
o`2[ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0Goooool005?ooooo00?o0000
ooooooooool0Zoooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05oooooo001Coooo
o`03o`000?oooooooooo0:_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Ooooo
o`00Doooool00ol0003oooooooooo`2[ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0Goooool005?ooooo00?o0000ooooooooool0Zoooool01Ol0003ooooooooooooooooo000006;o
oooo001Cooooo`;o0000[?ooool01Ol0003ooooooooooooooooo000006;ooooo001Cooooo`03o`00
0?oooooooooo0:_ooooo00Go0000ooooooooooooooooo`00001Rooooo`00Doooool00ol0003ooooo
ooooo`2[ooooo`05o`000?ooooooooooooooool00000H_ooool005?ooooo00?o0000ooooooooool0
Zoooool01Ol0003ooooooooooooooooo000006;ooooo001Cooooo`03o`000?oooooooooo0:_ooooo
00Go0000ooooooooooooooooo`00001Rooooo`00Doooool00ol0003oooooooooo`2[ooooo`05o`00
0?ooooooooooooooool00000H_ooool005?ooooo00?o0000ooooooooool0Zoooool01Ol0003ooooo
oooooooooooo000006;ooooo001Cooooo`03o`000?oooooooooo0:_ooooo00Co0000oooooooooooo
0000Hoooool005?ooooo0_l0002/ooooo`04o`000?ooooooooooo`0006?ooooo001Cooooo`03o`00
0?oooooooooo0:_ooooo00Co0000oooooooooooo0000Hoooool005?ooooo00?o0000ooooooooool0
Zoooool01?l0003oooooooooool0001Sooooo`00Doooool00ol0003oooooooooo`2/ooooo`03o`00
0?oooooo000006?ooooo001Cooooo`03o`000?oooooooooo0:cooooo00?o0000ooooool00000Hooo
ool005?ooooo00?o0000ooooooooool0[?ooool00ol0003oooooo`00001Sooooo`00>?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool0
0ol0003oooooooooo`2/ooooo`03o`000?oooooo000006?ooooo000hooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2/
ooooo`;o0000I?ooool003Sooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00001_ooool3
o`000:cooooo0_l0001Tooooo`00>?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo00001oooool00ol0003oooooooooo`2/ooooo`;o0000I?ooool003Sooooo00Go0000
ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0
[Oooool00ol0003oooooooooo`1Rooooo`00>?ooool01Ol@413ooooooooooooooooo410@00cooooo
00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`3ooooooa?ooooo000hooooo`05ogMgMonH
V9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo0?oooooo
4oooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Kooooo
00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001C
ooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo0_l0003ooooooaCooooo001Cooooo`03
o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Dooo
ool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool0
05?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?o
oooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooo
oolCooooo`00Doooool2o`000?oooooo5?ooool005?ooooo00?o0000ooooooooool0oooooolCoooo
o`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo
4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3o
oooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000oooooooo
ool0oooooolCooooo`00Doooool2o`000?oooooo5?ooool005?ooooo00?o0000ooooooooool0oooo
oolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo
0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0
003oooooooooo`3ooooooa?ooooo000hooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?oooooo4oooool0
03Sooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_oo
ool00ol0003oooooooooo`3ooooooa?ooooo000hooooo`05o`000?ooooooooooooooool000002ooo
ool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0003ooooooa?ooooo000hooooo`05o`000?oo
ooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000oooooooo
ool0oooooolCooooo`00>?ooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qooo
ool02?ooool00ol0003oooooooooo`3ooooooa?ooooo000hooooo`05ogMgMonHV9SooooooiRHV?mg
MgL02oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo0?oooooo4oooool003Sooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000oooo
ooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`00
0?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool2
o`000?oooooo5?ooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o
0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Coooo
o`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00
Doooool2o`000?oooooo5?ooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool0
0ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?o
oooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo
001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolC
ooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00
Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4ooo
ool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooo
oa?ooooo000hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q
8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0?oooooo4oooool003Sooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o
0000ooooooooool0oooooolCooooo`00>?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo4oooool003Sooooo00Go
0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3o`000?oo
oooo4oooool003Sooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`00
0?o<c<`01_ooool00ol0003oooooooooo`3ooooooa?ooooo000hooooo`05oa0@4?oooooooooooooo
ool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0oooooolC
ooooo`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00
0006ooooo`03o`000?oooooooooo0?oooooo4oooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3ooooooa?ooooo
001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolC
ooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00
Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4ooo
ool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooo
oa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0
oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolD
ooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oo
oooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003ooooooooo
o`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000oooo
ooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000
oooooolDooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooo
oooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool004Wooooo1?l0
00000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo4oooool004_ooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`3ooooooa?ooooo001;ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0oooooolCooooo`00Boooool00ol0003oooooooooo`05ooooo`?o
0000oooooolCooooo`00Boooool00ol0003oooooooooo`3ooooooa_ooooo001;ooooo`03o`000?oo
oooooooo0?oooooo6oooool004_ooooo00?o0000ooooooooool0oooooolKooooo`00BOooool00omE
EEGoIVIVo`00003ooooooagooooo001hooooo`?o000000?o410@ooooooooool0j_ooool007[ooooo
00?o410@okZj^_ooool01oooool2o`0000_ooooo00?o0000okZj^_ooool03?ooool2o`0000Gooooo
00?o0000okZj^_ooool0__ooool007[ooooo00?oV9RHoc8b<_ooool01oooool00ol0003ooooooooo
o`0:ooooo`;o<S8b3_ooool00ol0003oooooooooo`03ooooo`;o<S8b_oooool007[ooooo00?ogMgM
o`000?nj^[X01oooool01?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`03ohN7Qol0
003o^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4okZj^P04ooooo`03o`000?oooooooooo00?ooooo
00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj017ooooo1Ol00003ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h0Soooool007[ooooo00?oEEEEogMgMom4A4@01oooool02_l0003o
ooooooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oMgMd3ooooo`03olc<c?l0003o410@00Cooooo
00Go410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oooooooooo00?ooooo00?oc<c<o`000?l@
41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l00002ooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@00oooool01OmgMgOoV9RHoooooonHV9SoMgMg08oooooo001iooooo`05omgMgOl@413o
ooooob4Q8OoMgMd01_ooool00ol0003oooooooooo`02ooooo`04omgMgOl0003o410@olc<c0_ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01Cooooo
00?oV9RHob4Q8Oo^k^h01?ooool01Ol@413ooooooooooooooooo410@08oooooo001iooooo`05ofIV
I_n7QhOooooooiRHV?mEEED01_ooool00ol0003oooooooooo`02ooooo`04onk^k_lQ8B7o410@onk^
kP_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
00_ooooo1_l00004ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000ooooooooooooooooo`00002?
ooooo`00N?ooool00oo^k^ko0000onk^kP02ooooo`03o`000?oMgMgooooo00Cooooo00?o0000oooo
ooooool00_ooool01?lQ8B7oMgMgogMgMolb<S8;ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0Fooooo`03ogMgMomVIVKooooo00;ooooo00Go0000
ooooooooooooooooo`00002?ooooo`00N?ooool01?l@413o0000o`000?ooool2o`000003oa0@4?oo
oooooooo00?ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00002?ooool00ol@413o0000
o`000003o`0000Gooooo00?o0000ooooooooool04?ooool00ol@413o0000o`000003o`0001Kooooo
00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo08gooooo0024ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo01?ooooo00Go0000okZj^_ooooooV9RHoa0@4003ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL0Soooool008Cooooo0_l0000Booooo`03o`000?oooooooooo00Gooooo0_l0000Dooooo`03
o`000?oooooooooo01?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c003ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h0Soooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-3.4116, -0.234311, \
0.0510397, 0.00762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.230769 0.0769231 0.103006 0.515028 [
[.07692 .09051 -6 -9 ]
[.07692 .09051 6 0 ]
[.38462 .09051 -3 -9 ]
[.38462 .09051 3 0 ]
[.53846 .09051 -3 -9 ]
[.53846 .09051 3 0 ]
[.69231 .09051 -3 -9 ]
[.69231 .09051 3 0 ]
[.84615 .09051 -3 -9 ]
[.84615 .09051 3 0 ]
[1 .09051 -6 -9 ]
[1 .09051 6 0 ]
[1.025 .10301 0 -6 ]
[1.025 .10301 10 6 ]
[.21827 0 -24 -4.5 ]
[.21827 0 0 4.5 ]
[.21827 .20601 -18 -4.5 ]
[.21827 .20601 0 4.5 ]
[.21827 .30902 -18 -4.5 ]
[.21827 .30902 0 4.5 ]
[.21827 .41202 -18 -4.5 ]
[.21827 .41202 0 4.5 ]
[.21827 .51503 -18 -4.5 ]
[.21827 .51503 0 4.5 ]
[.21827 .61803 -6 -4.5 ]
[.21827 .61803 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07692 .10301 m
.07692 .10926 L
s
[(-2)] .07692 .09051 0 1 Mshowa
.38462 .10301 m
.38462 .10926 L
s
[(2)] .38462 .09051 0 1 Mshowa
.53846 .10301 m
.53846 .10926 L
s
[(4)] .53846 .09051 0 1 Mshowa
.69231 .10301 m
.69231 .10926 L
s
[(6)] .69231 .09051 0 1 Mshowa
.84615 .10301 m
.84615 .10926 L
s
[(8)] .84615 .09051 0 1 Mshowa
1 .10301 m
1 .10926 L
s
[(10)] 1 .09051 0 1 Mshowa
.125 Mabswid
.11538 .10301 m
.11538 .10676 L
s
.15385 .10301 m
.15385 .10676 L
s
.19231 .10301 m
.19231 .10676 L
s
.26923 .10301 m
.26923 .10676 L
s
.30769 .10301 m
.30769 .10676 L
s
.34615 .10301 m
.34615 .10676 L
s
.42308 .10301 m
.42308 .10676 L
s
.46154 .10301 m
.46154 .10676 L
s
.5 .10301 m
.5 .10676 L
s
.57692 .10301 m
.57692 .10676 L
s
.61538 .10301 m
.61538 .10676 L
s
.65385 .10301 m
.65385 .10676 L
s
.73077 .10301 m
.73077 .10676 L
s
.76923 .10301 m
.76923 .10676 L
s
.80769 .10301 m
.80769 .10676 L
s
.88462 .10301 m
.88462 .10676 L
s
.92308 .10301 m
.92308 .10676 L
s
.96154 .10301 m
.96154 .10676 L
s
.03846 .10301 m
.03846 .10676 L
s
.25 Mabswid
0 .10301 m
1 .10301 L
s
gsave
1.025 .10301 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.23077 0 m
.23702 0 L
s
[(-0.2)] .21827 0 1 0 Mshowa
.23077 .20601 m
.23702 .20601 L
s
[(0.2)] .21827 .20601 1 0 Mshowa
.23077 .30902 m
.23702 .30902 L
s
[(0.4)] .21827 .30902 1 0 Mshowa
.23077 .41202 m
.23702 .41202 L
s
[(0.6)] .21827 .41202 1 0 Mshowa
.23077 .51503 m
.23702 .51503 L
s
[(0.8)] .21827 .51503 1 0 Mshowa
.23077 .61803 m
.23702 .61803 L
s
[(1)] .21827 .61803 1 0 Mshowa
.125 Mabswid
.23077 .02575 m
.23452 .02575 L
s
.23077 .0515 m
.23452 .0515 L
s
.23077 .07725 m
.23452 .07725 L
s
.23077 .12876 m
.23452 .12876 L
s
.23077 .15451 m
.23452 .15451 L
s
.23077 .18026 m
.23452 .18026 L
s
.23077 .23176 m
.23452 .23176 L
s
.23077 .25751 m
.23452 .25751 L
s
.23077 .28327 m
.23452 .28327 L
s
.23077 .33477 m
.23452 .33477 L
s
.23077 .36052 m
.23452 .36052 L
s
.23077 .38627 m
.23452 .38627 L
s
.23077 .43777 m
.23452 .43777 L
s
.23077 .46353 m
.23452 .46353 L
s
.23077 .48928 m
.23452 .48928 L
s
.23077 .54078 m
.23452 .54078 L
s
.23077 .56653 m
.23452 .56653 L
s
.23077 .59228 m
.23452 .59228 L
s
.25 Mabswid
.23077 0 m
.23077 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
123.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(21) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.74149 .10301 m
.74311 .10301 L
.74503 .10301 L
.74684 .10301 L
.74847 .10301 L
.75023 .10301 L
.75193 .10301 L
.75375 .10301 L
.75547 .10301 L
.75703 .10301 L
.75887 .10301 L
.75991 .10301 L
.76087 .10301 L
.76263 .10301 L
.7645 .10301 L
.76628 .10301 L
.7682 .10304 L
.77001 .10317 L
.77167 .10353 L
.77351 .10466 L
.77456 .10592 L
.77553 .10774 L
.77656 .11055 L
.77749 .11413 L
.77857 .11973 L
.77959 .12669 L
.78115 .14086 L
.78286 .16144 L
.78633 .21508 L
.788 .24255 L
.78958 .26657 L
.79112 .28603 L
.79255 .29931 L
.79422 .30804 L
.79605 .30883 L
.79787 .30124 L
.79888 .29392 L
.7998 .28574 L
.8066 .20613 L
.81028 .16779 L
.81371 .14176 L
.81543 .13215 L
.81728 .12412 L
.81934 .11748 L
.82121 .11309 L
.82293 .11015 L
.82451 .10814 L
.82626 .10655 L
.82811 .10536 L
.82971 .10465 L
Mistroke
.83121 .10417 L
.83286 .10379 L
.83463 .10352 L
.83654 .10333 L
.83832 .10321 L
.83934 .10316 L
.84026 .10313 L
.84133 .1031 L
.84234 .10308 L
.84333 .10306 L
.84437 .10305 L
.84623 .10303 L
.84727 .10303 L
.84824 .10302 L
.8493 .10302 L
.85044 .10301 L
.85231 .10301 L
.85336 .10301 L
.85433 .10301 L
.85612 .10301 L
.85801 .10301 L
.85971 .10301 L
.8613 .10301 L
.86304 .10301 L
.86492 .10301 L
.86674 .10301 L
.8684 .10301 L
.87031 .10301 L
.87212 .10301 L
.87379 .10301 L
.87533 .10301 L
.87702 .10301 L
.87881 .10301 L
.88062 .10301 L
.88163 .10301 L
.88255 .10301 L
.88435 .10301 L
.88605 .10301 L
.88701 .10301 L
.88803 .10301 L
.88987 .10301 L
.89099 .10301 L
.89205 .10301 L
.893 .10301 L
.89402 .10301 L
.89594 .10301 L
.89773 .10301 L
.89875 .10301 L
.89969 .10301 L
.90077 .10301 L
Mistroke
.90179 .10301 L
.90278 .10301 L
.90384 .10301 L
.90572 .10301 L
.90677 .10301 L
.90776 .10301 L
.90883 .10301 L
.91 .10301 L
.91178 .10301 L
.91279 .10301 L
.91373 .10301 L
.91563 .10301 L
.9167 .10301 L
.91766 .10301 L
.9194 .10301 L
.92128 .10301 L
.92305 .10301 L
.92469 .10301 L
.92651 .10301 L
.92824 .10301 L
.9298 .10301 L
.93149 .10301 L
.93333 .10301 L
.93435 .10301 L
.93528 .10301 L
.93709 .10301 L
.93879 .10301 L
.9404 .10301 L
.9421 .10301 L
.94355 .10301 L
.94514 .10301 L
.94685 .10301 L
.94868 .10301 L
.95041 .10301 L
.95199 .10301 L
.95385 .10301 L
.95479 .10301 L
.95583 .10301 L
.95766 .10301 L
.95938 .10301 L
.96042 .10301 L
.9614 .10301 L
.96325 .10301 L
.96428 .10301 L
.96524 .10301 L
.96629 .10301 L
.96741 .10301 L
.96931 .10301 L
.97037 .10301 L
.97135 .10301 L
Mistroke
.97316 .10301 L
.97506 .10301 L
.97677 .10301 L
.97837 .10301 L
.98012 .10301 L
.982 .10301 L
.98377 .10301 L
.98478 .10301 L
.98572 .10301 L
.98763 .10301 L
.9887 .10301 L
.98968 .10301 L
.99133 .10301 L
.99314 .10301 L
.99503 .10301 L
.99678 .10301 L
.99779 .10301 L
.99888 .10301 L
.99991 .10301 L
Mfstroke
.99991 .10301 m
1 .10301 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000oooooolLooooo`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0oooooolLooooo`00<?ooool6o`0000;o
oooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^0?oooooo7Oooool003So
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003ooooo
oa?ooooo000hooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05oooo
o`03o`000?oooooooooo0?oooooo4oooool003Sooooo00Go410@oooooooooooooooooa0@400?oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooo
oooo0?oooooo4oooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooo
oooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003ooooooooo
o`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000oooo
ooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`00
0?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool0
0ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o
0000ooooooooool0oooooolCooooo`008oooool5o`0002_ooooo00?o0000ooooooooool0:oooool5
o`0002kooooo0_l000000ol@413oooooooooo`0Zooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?oo
ool01Oo<c<co8B4Qo`000?lQ8B7oc<c<02Wooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`00
0?lb<S;ok^k^6_ooool002?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00[ooooo`03o`000?oooooo
oooo02_ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00_ooooo`03o`000?oooooooooo02_ooooo00Go
EEEEogMgMoooooooV9RHob4Q8@0/ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40:oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool001_ooooo1_l00003ooooo`03
oiRHV?lQ8B7ok^k^02cooooo00?o0000ooooooooool0;?ooool00onHV9So8B4Qonk^kP0]ooooo`Go
0000;?ooool01Ol0003ooooooooooooooooo000002cooooo00Go0000ooooooooooooooooo`00000[
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Jooooo`009Oooool0
0onHV9So8B4Qonk^kP0[ooooo`03o`000?oooooooooo02gooooo00?oV9RHob4Q8Oo^k^h0;?ooool0
1?m4A4CogMgMooooool0000]ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;?ooool01Olb<S;oV9RH
oooooonHV9So<S8b02_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
01[ooooo000Vooooo`03ogMgMomVIVKooooo02[ooooo0_l0000_ooooo`03ogMgMomVIVKooooo02_o
oooo00CogMgMoeEEEOoooooo0000;Oooool01Ol0003oEEEEo`000?l@413oc<c<02cooooo00Goc<c<
o`000?l0003o0000olc<c00[ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Jooooo`009oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool0:oooool00omgMgOoc<c<o`00000]ooooo`03oeEEEOn7QhOooooo02kooooo00Go
410@okZj^_oooooo^[Zjoa0@400[ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@400Jooooo`008oooool01Ol0003o^[ZjoooooonHV9So410@02_ooooo00?o0000oooooooo
ool0:oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo00?ok^k^odA4A?l00000;Oooool00ooM
gMgo410@oiRHV00^ooooo`05o`000?nj^[[ooooookZj^_l00000:oooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool002?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00[ooooo`03o`000?oooooooooo02_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00^ooooo`03ogMg
Mol0003ooooo02gooooo00Coc<c<odA4A?l0003o410@;?ooool01OnYZJWo410@o`000?l@413oZJVY
02Wooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo001Coooo
o`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00
Doooool00ol0003oooooooooo`3mooooo`;o00000_ooool2o`0000oooooo001Cooooo`03o`000?oo
oooooooo0?gooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd?ooooo`00Doooool00ol0003ooooo
ooooo`3nooooo`04omgMgOl0003o410@olc<c13ooooo000:oooooooo0000@?l0000;ooooo`04onk^
k_lQ8B7o410@onk^kQ3ooooo000Fooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooool00000
2_ooool00ol0003oooooooooo`02ooooo`;o00001Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Wooooo00Co8B4QogMgMomgMgOo<S8b4?ooool002;ooooo00?o0000ooooooooool0
;_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0
;_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00Sooooo0_l00002ooooo`;o0000
3oooool005?ooooo00?o0000ooooooooool0Zoooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo05Kooooo001Cooooo`03o`000?oooooooooo0:_ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`1Gooooo`00Doooool00ol0003oooooooooo`2[ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool0Eoooool005?ooooo00?o0000ooooooooool0Zoooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo05Oooooo001Cooooo`03o`000?oooooooooo0:cooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Gooooo`00Doooool2o`000:gooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`1Hooooo`00Doooool00ol0003oooooooooo`2/
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0F?ooool005?ooooo00?o0000oooo
ooooool0[?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo05Sooooo001Cooooo`03
o`000?oooooooooo0:cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Hooooo`00
Doooool00ol0003oooooooooo`2/ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
F?ooool005?ooooo00?o0000ooooooooool0[?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo05Sooooo001Cooooo`03o`000?oooooooooo0:cooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`1Hooooo`00Doooool00ol0003oooooooooo`2/ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0F?ooool005?ooooo0_l0002^ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0F?ooool005?ooooo00?o0000ooooooooool0[Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo05Wooooo001Cooooo`03o`000?oooooooooo0:gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`1Iooooo`00Doooool00ol0003oooooooooo`2]
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0FOooool005?ooooo00?o0000oooo
ooooool0[Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo05Wooooo001Cooooo`03
o`000?oooooooooo0:gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Iooooo`00
Doooool00ol0003oooooooooo`2]ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
FOooool005?ooooo00?o0000ooooooooool0[Oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo05Wooooo001Cooooo`;o0000[_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo05[ooooo001Cooooo`03o`000?oooooooooo0:gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`1Jooooo`00Doooool00ol0003oooooooooo`2]ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0F_ooool005?ooooo00?o0000ooooooooool0[_ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo05[ooooo001Cooooo`03o`000?oooooooooo0:kooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`1Jooooo`00Doooool00ol0003oooooooooo`2^
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0F_ooool003Sooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0[_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo05_ooooo000hooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oo
oooooooo0:kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Kooooo`00>?ooool0
1Ol@413ooooooooooooooooo410@00cooooo00?oV9RHob4Q8Oo^k^h01oooool3o`000:kooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`1Kooooo`00>?ooool01Ol0003ooooooooooooo
oooo000000gooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`2^ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0Foooool003Sooooo00Go0000ooooooooooooooooo`00
000>ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0[_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo05_ooooo000hooooo`05oa0@4?ooooooooooooooool@41003ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0:kooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`1Kooooo`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go
0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0:kooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`1Kooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo
00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0:kooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`1Kooooo`00Doooool00ol0003oooooooooo`2^ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0Foooool005?ooooo00?o0000ooooooooool0[_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05cooooo001Cooooo`03o`000?oooooo
oooo0:kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Looooo`00Doooool2o`00
0:oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Looooo`00Doooool00ol0003o
ooooooooo`2^ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0G?ooool005?ooooo
00?o0000ooooooooool0[_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05cooooo
001Cooooo`03o`000?oooooooooo0:kooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`1Looooo`00Doooool00ol0003oooooooooo`2^ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0G?ooool005?ooooo00?o0000ooooooooool0[_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo05cooooo001Cooooo`03o`000?oooooooooo0:kooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`1Looooo`00Doooool00ol0003oooooooooo`2^ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0G?ooool005?ooooo0_l0002`ooooo`05o`000?oo
ooooooooooooool00000G_ooool005?ooooo00?o0000ooooooooool0[oooool01Ol0003ooooooooo
oooooooo000005kooooo001Cooooo`03o`000?oooooooooo0:oooooo00Go0000oooooooooooooooo
o`00001Nooooo`00Doooool00ol0003oooooooooo`2_ooooo`04o`000?ooooooooooo`0005oooooo
001Cooooo`03o`000?oooooooooo0:oooooo00Co0000oooooooooooo0000Goooool005?ooooo00?o
0000ooooooooool0[oooool01?l0003oooooooooool0001Oooooo`00Doooool00ol0003ooooooooo
o`2_ooooo`04o`000?ooooooooooo`0005oooooo001Cooooo`03o`000?oooooooooo0:oooooo00Co
0000oooooooooooo0000Goooool005?ooooo0_l0002`ooooo`04o`000?ooooooooooo`0005oooooo
001Cooooo`03o`000?oooooooooo0:oooooo00Co0000oooooooooooo0000Goooool005?ooooo00?o
0000ooooooooool0[oooool01?l0003oooooooooool0001Oooooo`00Doooool00ol0003ooooooooo
o`2_ooooo`04o`000?ooooooooooo`0005oooooo001Cooooo`03o`000?oooooooooo0;3ooooo00?o
0000ooooool00000Goooool005?ooooo00?o0000ooooooooool0/?ooool00ol0003oooooo`00001O
ooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool01?ooool00ol0003oooooooooo`2`ooooo`03o`000?oooooo000005oooooo000hoooo
o`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`2`ooooo`03o`000?oooooo000005oooooo000hooooo`05oa0@4?oooooooooo
ooooool@41002oooool5o`0000Kooooo0ol0002`ooooo`;o0000H?ooool003Sooooo00Go0000oooo
ooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool0oooo
oolCooooo`00>?ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEEEOoooooo0000
1oooool00ol0003oooooooooo`3ooooooa?ooooo000hooooo`05oa0@4?ooooooooooooooool@4100
3?ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo0?oooooo4oooool003Sooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool0
oooooolCooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMgo`000?ooool0
1_ooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4ooo
ool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool2o`000?oooooo5?ooool005?o
oooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo
001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolC
ooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oo
oooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003ooooooooo
o`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003oooooooooo`3ooooo
oa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0
oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooo
oooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003ooooooooo
o`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000oooo
ooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo000hooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@olc<c006oooo
o`03o`000?oooooooooo0?oooooo4oooool003Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0oooooolC
ooooo`00>?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`00
0006ooooo`03o`000?oooooooooo0?oooooo4oooool003Sooooo00Go0000ooooooooooooooooo`00
000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`000?oooooo4oooool003Sooooo00Go
0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003o
ooooooooo`3ooooooa?ooooo000hooooo`05oa0@4?ooooooooooooooool@41002oooool00omEEEGo
QhN7ooooo`08ooooo`03o`000?oooooooooo0?oooooo4oooool003Sooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0oooooolCooooo`00
>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@1_ooool00ol0
003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo
00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001C
ooooo`;o0000oooooolDooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03
o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Dooo
ool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool0
05?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?o
oooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001C
ooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCoooo
o`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo
4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3o
oooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo0_l0003ooooooaCo
oooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooo
oolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo
0?oooooo4oooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<
c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_oo
ool00ol0003oooooooooo`3ooooooa?ooooo000hooooo`05oa0@4?ooooooooooooooool@41002ooo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0oooooolCooooo`00>?oo
ool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o
0000oooooolCooooo`00>?ooool01Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0
003o0000olc<c006ooooo`03o`000?oooooooooo0?oooooo4oooool003Sooooo00Go410@oooooooo
oooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003oooooooooo`3o
oooooa?ooooo000hooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[Zjoooooonj
^[[o000000Kooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooooooo0?oooooo
4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3o
oooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo0_l0003ooooooaCo
oooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooo
oolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo
0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003ooooo
ooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo0_l0003o
oooooaCooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000oooooooo
ool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oo
oooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0
003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo
0_l0003ooooooaCooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000
ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03
o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00BOoo
ool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooolCooooo`00Boooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo4oooool004_ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`3ooooooa?ooooo001;ooooo`03o`000?oooooooooo00Go
oooo0ol0003ooooooa?ooooo001;ooooo`03o`000?oooooooooo0?oooooo6oooool004_ooooo00?o
0000ooooooooool0oooooolKooooo`00Boooool00ol0003oooooooooo`3ooooooa_ooooo0019oooo
o`03oeEEEOmVIVKo00000?oooooo7Oooool007Sooooo0ol000000ol@413oooooooooo`3Zooooo`00
N_ooool00ol@413o^[Zjooooo`07ooooo`;o00002oooool00ol0003o^[Zjooooo`0<ooooo`;o0000
1Oooool00ol0003o^[Zjooooo`2nooooo`00N_ooool00onHV9So<S8booooo`07ooooo`03o`000?oo
oooooooo00[ooooo0_lb<S8>ooooo`03o`000?oooooooooo00?ooooo0_lb<S:oooooo`00N_ooool0
0ooMgMgo0000okZj^P07ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000?ooooo00?o
QhN7o`000?nj^[X01?ooool01OnHV9So0000o`000?m4A4Co^[Zj00Cooooo00?o0000ooooooooool0
0oooool00on7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X04Oooool5o`0000Co
oooo1?l000000ol@413oooooooooo`2<ooooo`00N_ooool00omEEEGoMgMgodA4A007ooooo`0:o`00
0?ooooooooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgMg@?ooooo00?oc<c<o`000?l@41001?oo
ool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo00?o0000ooooooooool00oooool00oo<c<co0000
oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Oooool6o`0000;ooooo00GoV9RHob4Q8Oo^
k^koooooodA4A006ooooo`03o`000?oooooooooo08kooooo001iooooo`05omgMgOl@413oooooob4Q
8OoMgMd01_ooool00ol0003oooooooooo`02ooooo`04omgMgOl0003o410@olc<c0_ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01Cooooo00?oV9RH
ob4Q8Oo^k^h01oooool00ol0003oooooooooo`2>ooooo`00NOooool01OmVIVKoQhN7oooooonHV9So
EEEE00Kooooo00?o0000ooooooooool00_ooool01?o^k^ko8B4Qoa0@4?o^k^h;ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0;ooooo`Ko00001?oo
ool00onHV9So8B4Qonk^kP06ooooo`03o`000?oooooooooo08kooooo001hooooo`03onk^k_l0003o
k^k^00;ooooo00?o0000omgMgOooool01?ooool00ol0003oooooooooo`02ooooo`04ob4Q8OmgMgOo
MgMgoc8b<P_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo01Kooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`2>ooooo`00N?ooool0
1?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo00Co0000oooooooooooooooo
0_l00002ooooo`;o00002?ooool00ol@413o0000o`000003o`0000Gooooo00?o0000ooooooooool0
4?ooool00ol@413o0000o`000003o`0001Kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2>ooooo`00Q?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0Cooooo`05o`000?nj^[[ooooooiRHV?l@4100
1_ooool00ol0003oooooooooo`2>ooooo`00Q?ooool2o`0001;ooooo00?o0000ooooooooool01Ooo
ool2o`0001Cooooo00?o0000ooooooooool04oooool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo
00?oEEEEofIVI_l00000T?ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-3.4116, -0.234311, \
0.0510397, 0.00762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.230769 0.0769231 0.103006 0.515028 [
[.07692 .09051 -6 -9 ]
[.07692 .09051 6 0 ]
[.38462 .09051 -3 -9 ]
[.38462 .09051 3 0 ]
[.53846 .09051 -3 -9 ]
[.53846 .09051 3 0 ]
[.69231 .09051 -3 -9 ]
[.69231 .09051 3 0 ]
[.84615 .09051 -3 -9 ]
[.84615 .09051 3 0 ]
[1 .09051 -6 -9 ]
[1 .09051 6 0 ]
[1.025 .10301 0 -6 ]
[1.025 .10301 10 6 ]
[.21827 0 -24 -4.5 ]
[.21827 0 0 4.5 ]
[.21827 .20601 -18 -4.5 ]
[.21827 .20601 0 4.5 ]
[.21827 .30902 -18 -4.5 ]
[.21827 .30902 0 4.5 ]
[.21827 .41202 -18 -4.5 ]
[.21827 .41202 0 4.5 ]
[.21827 .51503 -18 -4.5 ]
[.21827 .51503 0 4.5 ]
[.21827 .61803 -6 -4.5 ]
[.21827 .61803 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07692 .10301 m
.07692 .10926 L
s
[(-2)] .07692 .09051 0 1 Mshowa
.38462 .10301 m
.38462 .10926 L
s
[(2)] .38462 .09051 0 1 Mshowa
.53846 .10301 m
.53846 .10926 L
s
[(4)] .53846 .09051 0 1 Mshowa
.69231 .10301 m
.69231 .10926 L
s
[(6)] .69231 .09051 0 1 Mshowa
.84615 .10301 m
.84615 .10926 L
s
[(8)] .84615 .09051 0 1 Mshowa
1 .10301 m
1 .10926 L
s
[(10)] 1 .09051 0 1 Mshowa
.125 Mabswid
.11538 .10301 m
.11538 .10676 L
s
.15385 .10301 m
.15385 .10676 L
s
.19231 .10301 m
.19231 .10676 L
s
.26923 .10301 m
.26923 .10676 L
s
.30769 .10301 m
.30769 .10676 L
s
.34615 .10301 m
.34615 .10676 L
s
.42308 .10301 m
.42308 .10676 L
s
.46154 .10301 m
.46154 .10676 L
s
.5 .10301 m
.5 .10676 L
s
.57692 .10301 m
.57692 .10676 L
s
.61538 .10301 m
.61538 .10676 L
s
.65385 .10301 m
.65385 .10676 L
s
.73077 .10301 m
.73077 .10676 L
s
.76923 .10301 m
.76923 .10676 L
s
.80769 .10301 m
.80769 .10676 L
s
.88462 .10301 m
.88462 .10676 L
s
.92308 .10301 m
.92308 .10676 L
s
.96154 .10301 m
.96154 .10676 L
s
.03846 .10301 m
.03846 .10676 L
s
.25 Mabswid
0 .10301 m
1 .10301 L
s
gsave
1.025 .10301 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.23077 0 m
.23702 0 L
s
[(-0.2)] .21827 0 1 0 Mshowa
.23077 .20601 m
.23702 .20601 L
s
[(0.2)] .21827 .20601 1 0 Mshowa
.23077 .30902 m
.23702 .30902 L
s
[(0.4)] .21827 .30902 1 0 Mshowa
.23077 .41202 m
.23702 .41202 L
s
[(0.6)] .21827 .41202 1 0 Mshowa
.23077 .51503 m
.23702 .51503 L
s
[(0.8)] .21827 .51503 1 0 Mshowa
.23077 .61803 m
.23702 .61803 L
s
[(1)] .21827 .61803 1 0 Mshowa
.125 Mabswid
.23077 .02575 m
.23452 .02575 L
s
.23077 .0515 m
.23452 .0515 L
s
.23077 .07725 m
.23452 .07725 L
s
.23077 .12876 m
.23452 .12876 L
s
.23077 .15451 m
.23452 .15451 L
s
.23077 .18026 m
.23452 .18026 L
s
.23077 .23176 m
.23452 .23176 L
s
.23077 .25751 m
.23452 .25751 L
s
.23077 .28327 m
.23452 .28327 L
s
.23077 .33477 m
.23452 .33477 L
s
.23077 .36052 m
.23452 .36052 L
s
.23077 .38627 m
.23452 .38627 L
s
.23077 .43777 m
.23452 .43777 L
s
.23077 .46353 m
.23452 .46353 L
s
.23077 .48928 m
.23452 .48928 L
s
.23077 .54078 m
.23452 .54078 L
s
.23077 .56653 m
.23452 .56653 L
s
.23077 .59228 m
.23452 .59228 L
s
.25 Mabswid
.23077 0 m
.23077 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
123.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(22) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.75563 .10301 m
.75739 .10301 L
.75906 .10301 L
.76059 .10301 L
.76227 .10301 L
.76404 .10301 L
.76584 .10301 L
.76685 .10301 L
.76776 .10301 L
.76955 .10301 L
.77123 .10301 L
.77219 .10301 L
.7732 .10301 L
.77501 .10301 L
.77602 .10301 L
.77697 .10301 L
.77801 .10301 L
.77913 .10301 L
.78085 .10303 L
.78246 .1031 L
.78422 .10339 L
.78611 .10434 L
.78706 .10534 L
.78809 .10706 L
.78996 .11271 L
.79178 .12273 L
.79346 .1371 L
.79503 .15539 L
.7965 .17637 L
.79984 .23178 L
.80151 .25848 L
.8031 .27983 L
.80493 .29715 L
.8066 .3048 L
.80753 .30553 L
.80854 .30356 L
.81038 .29351 L
.81216 .27733 L
.8138 .2588 L
.81746 .21324 L
.82148 .1692 L
.82315 .15464 L
.82495 .14177 L
.8265 .13278 L
.82819 .12501 L
.83009 .11836 L
.8319 .11375 L
.83365 .11049 L
.83527 .10829 L
.83706 .10657 L
Mistroke
.83807 .10584 L
.83899 .1053 L
.8407 .10454 L
.84249 .10401 L
.84344 .1038 L
.84446 .10362 L
.84629 .10339 L
.84741 .1033 L
.84846 .10323 L
.84941 .10318 L
.85044 .10314 L
.85144 .10311 L
.85238 .10308 L
.85341 .10307 L
.85451 .10305 L
.85567 .10304 L
.85676 .10303 L
.85775 .10302 L
.85882 .10302 L
.85974 .10302 L
.86076 .10301 L
.86182 .10301 L
.86282 .10301 L
.86461 .10301 L
.86561 .10301 L
.86653 .10301 L
.86838 .10301 L
.87013 .10301 L
.8717 .10301 L
.87341 .10301 L
.87526 .10301 L
.8762 .10301 L
.87723 .10301 L
.87905 .10301 L
.88076 .10301 L
.88247 .10301 L
.88409 .10301 L
.88555 .10301 L
.88714 .10301 L
.88887 .10301 L
.8907 .10301 L
.89244 .10301 L
.89401 .10301 L
.89589 .10301 L
.89684 .10301 L
.89789 .10301 L
.89973 .10301 L
.90145 .10301 L
.9025 .10301 L
.90349 .10301 L
Mistroke
.90534 .10301 L
.90637 .10301 L
.90733 .10301 L
.90839 .10301 L
.9095 .10301 L
.91122 .10301 L
.91308 .10301 L
.91483 .10301 L
.91644 .10301 L
.91822 .10301 L
.91923 .10301 L
.92017 .10301 L
.92206 .10301 L
.92313 .10301 L
.92409 .10301 L
.92583 .10301 L
.92745 .10301 L
.92923 .10301 L
.93115 .10301 L
.93211 .10301 L
.93315 .10301 L
.93505 .10301 L
.9369 .10301 L
.93862 .10301 L
.94037 .10301 L
.94202 .10301 L
.9435 .10301 L
.9451 .10301 L
.94685 .10301 L
.9487 .10301 L
.95028 .10301 L
.952 .10301 L
.95298 .10301 L
.95404 .10301 L
.95504 .10301 L
.95596 .10301 L
.95771 .10301 L
.95957 .10301 L
.96052 .10301 L
.96155 .10301 L
.96342 .10301 L
.96455 .10301 L
.96563 .10301 L
.9666 .10301 L
.96766 .10301 L
.96958 .10301 L
.97132 .10301 L
.97228 .10301 L
.97333 .10301 L
.97522 .10301 L
Mistroke
.977 .10301 L
.97888 .10301 L
.98049 .10301 L
.98225 .10301 L
.98414 .10301 L
.98589 .10301 L
.98681 .10301 L
.98782 .10301 L
.98887 .10301 L
.98986 .10301 L
.99167 .10301 L
.99333 .10301 L
.99515 .10301 L
.99707 .10301 L
.99869 .10301 L
Mfstroke
.99869 .10301 m
1 .10301 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000oooooolLooooo`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0oooooolLooooo`00<?ooool6o`0000;o
oooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^0?oooooo7Oooool003So
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003ooooo
oa?ooooo000hooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05oooo
o`03o`000?oooooooooo0?oooooo4oooool003Sooooo00Go410@oooooooooooooooooa0@400?oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooo
oooo0?oooooo4oooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooo
oooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003ooooooooo
o`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000oooo
ooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`00
0?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool0
0ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o
0000ooooooooool0oooooolCooooo`008oooool5o`0002_ooooo00?o0000ooooooooool0:oooool5
o`0002kooooo0_l000000ol@413oooooooooo`0Zooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?oo
ool01Oo<c<co8B4Qo`000?lQ8B7oc<c<02Wooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`00
0?lb<S;ok^k^6_ooool002?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00[ooooo`03o`000?oooooo
oooo02_ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00_ooooo`03o`000?oooooooooo02_ooooo00Go
EEEEogMgMoooooooV9RHob4Q8@0/ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40:oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool001_ooooo1_l00003ooooo`03
oiRHV?lQ8B7ok^k^02cooooo00?o0000ooooooooool0;?ooool00onHV9So8B4Qonk^kP0]ooooo`Go
0000;?ooool01Ol0003ooooooooooooooooo000002cooooo00Go0000ooooooooooooooooo`00000[
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Jooooo`009Oooool0
0onHV9So8B4Qonk^kP0[ooooo`03o`000?oooooooooo02gooooo00?oV9RHob4Q8Oo^k^h0;?ooool0
1?m4A4CogMgMooooool0000]ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;?ooool01Olb<S;oV9RH
oooooonHV9So<S8b02_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
01[ooooo000Vooooo`03ogMgMomVIVKooooo02[ooooo0_l0000_ooooo`03ogMgMomVIVKooooo02_o
oooo00CogMgMoeEEEOoooooo0000;Oooool01Ol0003oEEEEo`000?l@413oc<c<02cooooo00Goc<c<
o`000?l0003o0000olc<c00[ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Jooooo`009oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool0:oooool00omgMgOoc<c<o`00000]ooooo`03oeEEEOn7QhOooooo02kooooo00Go
410@okZj^_oooooo^[Zjoa0@400[ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@400Jooooo`008oooool01Ol0003o^[ZjoooooonHV9So410@02_ooooo00?o0000oooooooo
ool0:oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo00?ok^k^odA4A?l00000;Oooool00ooM
gMgo410@oiRHV00^ooooo`05o`000?nj^[[ooooookZj^_l00000:oooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool002?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00[ooooo`03o`000?oooooooooo02_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00^ooooo`03ogMg
Mol0003ooooo02gooooo00Coc<c<odA4A?l0003o410@;?ooool01OnYZJWo410@o`000?l@413oZJVY
02Wooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo001Coooo
o`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00
Doooool00ol0003oooooooooo`3mooooo`;o00000_ooool2o`0000oooooo001Cooooo`03o`000?oo
oooooooo0?gooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd?ooooo`00Doooool00ol0003ooooo
ooooo`3nooooo`04omgMgOl0003o410@olc<c13ooooo000:oooooooo0000@?l0000;ooooo`04onk^
k_lQ8B7o410@onk^kQ3ooooo000Fooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00Co0000oooooooooooo
00002oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`09ooooo`04ob4Q8OmgMgOoMgMgoc8b<Q3ooooo000Rooooo`03
o`000?oooooooooo02kooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0^ooooo`03
o`000?oooooooooo02kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0<ooooo`05
o`000?ooooooooooooooool00000<?ooool00ol0003oooooooooo`08ooooo`;o00000_ooool2o`00
00oooooo001Cooooo`03o`000?oooooooooo0:oooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`1Cooooo`00Doooool00ol0003oooooooooo`2_ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0Doooool005?ooooo00?o0000ooooooooool0/?ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo05?ooooo001Cooooo`03o`000?oooooooooo0;3ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`1Dooooo`00Doooool00ol0003oooooooooo`2`oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0E?ooool005?ooooo0_l0002aooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool0E?ooool005?ooooo00?o0000ooooooooool0
/?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo05Cooooo001Cooooo`03o`000?oo
oooooooo0;3ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Dooooo`00Doooool0
0ol0003oooooooooo`2`ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0EOooool0
05?ooooo00?o0000ooooooooool0/?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
05Gooooo001Cooooo`03o`000?oooooooooo0;3ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`1Eooooo`00Doooool00ol0003oooooooooo`2aooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0EOooool005?ooooo00?o0000ooooooooool0/Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo05Gooooo001Cooooo`;o0000/_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo05Gooooo001Cooooo`03o`000?oooooooooo0;7ooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`1Eooooo`00Doooool00ol0003oooooooooo`2aooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0EOooool005?ooooo00?o0000ooooooooool0
/Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05Kooooo001Cooooo`03o`000?oo
oooooooo0;7ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Fooooo`00Doooool0
0ol0003oooooooooo`2aooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0E_ooool0
05?ooooo00?o0000ooooooooool0/Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
05Kooooo001Cooooo`03o`000?oooooooooo0;7ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`1Fooooo`00Doooool2o`000;;ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`1Fooooo`00Doooool00ol0003oooooooooo`2aooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0E_ooool005?ooooo00?o0000ooooooooool0/Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo05Kooooo001Cooooo`03o`000?oooooooooo0;7ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`1Fooooo`00Doooool00ol0003oooooooooo`2aooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0E_ooool005?ooooo00?o0000ooooooooool0
/Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo05Oooooo000hooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oooooooooo0;7ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Gooooo`00>?ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003o
ooooooooo`2aooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Eoooool003Sooooo
00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0002aooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0Eoooool003Sooooo00Go0000oooooooooooo
ooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0/_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo05Oooooo000hooooo`05o`000?ooooooooooooooool0
00003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0;;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`1Gooooo`00>?ooool01Ol@413ooooooooooooooooo410@00oo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0Eoooool003Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05
o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0Eoooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;oooo
o`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`2booooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0Eoooool005?ooooo00?o0000ooooooooool0/_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo05Oooooo001Cooooo`03o`000?oooooooooo0;;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Gooooo`00Doooool00ol0003ooooo
ooooo`2booooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Eoooool005?ooooo0_l0
002cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Eoooool005?ooooo00?o0000
ooooooooool0/_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05Oooooo001Coooo
o`03o`000?oooooooooo0;;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Hoooo
o`00Doooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0F?ooool005?ooooo00?o0000ooooooooool0/_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo05Sooooo001Cooooo`03o`000?oooooooooo0;?ooooo00Go0000oooooooooooooooo
o`00001Jooooo`00Doooool00ol0003oooooooooo`2cooooo`05o`000?ooooooooooooooool00000
F_ooool005?ooooo00?o0000ooooooooool0/oooool01Ol0003ooooooooooooooooo000005[ooooo
001Cooooo`;o0000]?ooool01Ol0003ooooooooooooooooo000005[ooooo001Cooooo`03o`000?oo
oooooooo0;?ooooo00Go0000ooooooooooooooooo`00001Jooooo`00Doooool00ol0003ooooooooo
o`2cooooo`05o`000?ooooooooooooooool00000F_ooool005?ooooo00?o0000ooooooooool0/ooo
ool01Ol0003ooooooooooooooooo000005[ooooo001Cooooo`03o`000?oooooooooo0;?ooooo00Co
0000oooooooooooo0000Foooool005?ooooo00?o0000ooooooooool0/oooool01?l0003ooooooooo
ool0001Kooooo`00Doooool00ol0003oooooooooo`2cooooo`04o`000?ooooooooooo`0005_ooooo
001Cooooo`03o`000?oooooooooo0;?ooooo00Co0000oooooooooooo0000Foooool005?ooooo0_l0
002dooooo`04o`000?ooooooooooo`0005_ooooo001Cooooo`03o`000?oooooooooo0;?ooooo00Co
0000oooooooooooo0000Foooool005?ooooo00?o0000ooooooooool0]?ooool00ol0003oooooo`00
001Kooooo`00Doooool00ol0003oooooooooo`2dooooo`03o`000?oooooo000005_ooooo001Coooo
o`03o`000?oooooooooo0;Cooooo00?o0000ooooool00000Foooool005?ooooo00?o0000oooooooo
ool0]?ooool2o`0005cooooo000hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Ko
oooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oooooooooo0;Cooooo0_l0001Looooo`00
>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0]?ooool2o`0005cooooo000hooooo`05oa0@4?ooooooooooooooool@
41002oooool5o`0000Kooooo0ol0003ooooooa?ooooo000hooooo`05o`000?ooooooooooooooool0
00002oooool01?m4A4CogMgMooooool00007ooooo`03o`000?oooooooooo0?oooooo4oooool003So
oooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000
ooooooooool0oooooolCooooo`00>?ooool01Ol@413ooooooooooooooooo410@00cooooo00?oMgMg
olc<c?l000001oooool00ol0003oooooooooo`3ooooooa?ooooo000hooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo0?oooooo4oooool0
03Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo00Kooooo00?o0000
ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03
o`000?oooooooooo0?oooooo4oooool005?ooooo0_l0003ooooooaCooooo001Cooooo`03o`000?oo
oooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0
003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo
00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001C
ooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCoooo
o`00Doooool2o`000?oooooo5?ooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Dooo
ool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool0
05?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?o
oooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooo
oolCooooo`00Doooool2o`000?oooooo5?ooool005?ooooo00?o0000ooooooooool0oooooolCoooo
o`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo
4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01_ooool00ol0003ooooo
ooooo`3ooooooa?ooooo000hooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo
00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?oooooo4oooool003Sooooo
00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool00ol0
003oooooooooo`3ooooooa?ooooo000hooooo`05o`000?ooooooooooooooool000002oooool01Ol0
003oV9RHoooooonHV9So8B4Q00Kooooo0ol0003ooooooa?ooooo000hooooo`05o`000?oooooooooo
ooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0oooo
oolCooooo`00>?ooool01Ol@413ooooooooooooooooo410@00_ooooo00?oEEEEohN7Qoooool02?oo
ool00ol0003oooooooooo`3ooooooa?ooooo000hooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo0?oooooo4oooool003Sooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0
oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooo
oooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool2o`000?oo
oooo5?ooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003ooooooooo
o`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000oooo
ooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`00
0?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool2
o`000?oooooo5?ooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o
0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Coooo
o`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00
Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool0
0ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?o
oooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo
000hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o
8B4Qolc<c006ooooo`03o`000?oooooooooo0?oooooo4oooool003Sooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000oooo
ooooool0oooooolCooooo`00>?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo4oooool003Sooooo00Go0000oooo
ooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3o`000?oooooo4ooo
ool003Sooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0003o0000o`000?o<c<`0
1_ooool00ol0003oooooooooo`3ooooooa?ooooo000hooooo`05oa0@4?ooooooooooooooool@4100
2oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool0oooooolCooooo`00
>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`000006oooo
o`03o`000?oooooooooo0?oooooo4oooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;oooo
o`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3ooooooa?ooooo001Coooo
o`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00
Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool0
0ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?o
oooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo
001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolC
ooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00
Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4ooo
ool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooo
oa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0
oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolD
ooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oo
oooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003ooooooooo
o`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool004Wooooo1?l000000ol@
413oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo4oooool004_ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`3ooooooa?ooooo001;ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0oooooolCooooo`00Boooool00ol0003oooooooooo`05ooooo`?o0000oooo
oolCooooo`00Boooool00ol0003oooooooooo`3ooooooa_ooooo001;ooooo`03o`000?oooooooooo
0?oooooo6oooool004_ooooo00?o0000ooooooooool0oooooolKooooo`00BOooool00omEEEGoIVIV
o`00003ooooooagooooo001hooooo`?o000000?o410@ooooooooool0j_ooool007[ooooo00?o410@
okZj^_ooool01oooool2o`0000_ooooo00?o0000okZj^_ooool03?ooool2o`0000Gooooo00?o0000
okZj^_ooool0__ooool007[ooooo00?oV9RHoc8b<_ooool01oooool00ol0003oooooooooo`0:oooo
o`;o<S8b3_ooool00ol0003oooooooooo`03ooooo`;o<S8b_oooool007[ooooo00?ogMgMo`000?nj
^[X01oooool01?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`03ohN7Qol0003o^[Zj
00Cooooo00GoV9RHo`000?l0003oA4A4okZj^P04ooooo`03o`000?oooooooooo00?ooooo00?oQhN7
o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj017ooooo1Ol00003ooooo`Go0000Sooo
ool007[ooooo00?oEEEEogMgMom4A4@01oooool02_l0003oooooooooooooooook^k^ob4Q8On7QhOo
^[Zjo`000?oMgMd3ooooo`03olc<c?l0003o410@00Cooooo00Go410@okZj^_o^k^koMgMgoa0@4004
ooooo`03o`000?oooooooooo00?ooooo00?oc<c<o`000?l@41003?ooool01Ol@413o^[Zjonk^k_mg
MgOo410@00Wooooo1_l00002ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OnHV9So8B4Q
onk^k_ooooooA4A408oooooo001iooooo`05omgMgOl@413oooooob4Q8OoMgMd01_ooool00ol0003o
ooooooooo`02ooooo`04omgMgOl0003o410@olc<c0_ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo01Cooooo00?oV9RHob4Q8Oo^k^h01Oooool00onH
V9So8B4Qonk^kP2@ooooo`00NOooool01OmVIVKoQhN7oooooonHV9SoEEEE00Kooooo00?o0000oooo
ooooool00_ooool01?o^k^ko8B4Qoa0@4?o^k^h;ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0;ooooo`Ko00001?ooool00onHV9So8B4Qonk^kP05
ooooo`03oiRHV?lQ8B7ok^k^08oooooo001hooooo`03onk^k_l0003ok^k^00;ooooo00?o0000omgM
gOooool01?ooool00ol0003oooooooooo`02ooooo`04ob4Q8OmgMgOoMgMgoc8b<P_ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01Kooooo00?oMgMg
ofIVI_ooool01Oooool00omgMgOoIVIVooooo`2>ooooo`00N?ooool01?l@413o0000o`000?ooool2
o`000003oa0@4?oooooooooo00?ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00002?oo
ool00ol@413o0000o`000003o`0000Gooooo00?o0000ooooooooool04?ooool00ol@413o0000o`00
0003o`0001Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2=ooooo`00Q?ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0Cooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01Ol0003o^[Zjoooo
oonHV9So410@08oooooo0024ooooo`;o00004_ooool00ol0003oooooooooo`05ooooo`;o00005?oo
ool00ol0003oooooooooo`0Cooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01OnHV9So410@
o`000?lQ8B7oc<c<08oooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-3.4116, -0.234311, \
0.0510397, 0.00762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.230769 0.0769231 0.103006 0.515028 [
[.07692 .09051 -6 -9 ]
[.07692 .09051 6 0 ]
[.38462 .09051 -3 -9 ]
[.38462 .09051 3 0 ]
[.53846 .09051 -3 -9 ]
[.53846 .09051 3 0 ]
[.69231 .09051 -3 -9 ]
[.69231 .09051 3 0 ]
[.84615 .09051 -3 -9 ]
[.84615 .09051 3 0 ]
[1 .09051 -6 -9 ]
[1 .09051 6 0 ]
[1.025 .10301 0 -6 ]
[1.025 .10301 10 6 ]
[.21827 0 -24 -4.5 ]
[.21827 0 0 4.5 ]
[.21827 .20601 -18 -4.5 ]
[.21827 .20601 0 4.5 ]
[.21827 .30902 -18 -4.5 ]
[.21827 .30902 0 4.5 ]
[.21827 .41202 -18 -4.5 ]
[.21827 .41202 0 4.5 ]
[.21827 .51503 -18 -4.5 ]
[.21827 .51503 0 4.5 ]
[.21827 .61803 -6 -4.5 ]
[.21827 .61803 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07692 .10301 m
.07692 .10926 L
s
[(-2)] .07692 .09051 0 1 Mshowa
.38462 .10301 m
.38462 .10926 L
s
[(2)] .38462 .09051 0 1 Mshowa
.53846 .10301 m
.53846 .10926 L
s
[(4)] .53846 .09051 0 1 Mshowa
.69231 .10301 m
.69231 .10926 L
s
[(6)] .69231 .09051 0 1 Mshowa
.84615 .10301 m
.84615 .10926 L
s
[(8)] .84615 .09051 0 1 Mshowa
1 .10301 m
1 .10926 L
s
[(10)] 1 .09051 0 1 Mshowa
.125 Mabswid
.11538 .10301 m
.11538 .10676 L
s
.15385 .10301 m
.15385 .10676 L
s
.19231 .10301 m
.19231 .10676 L
s
.26923 .10301 m
.26923 .10676 L
s
.30769 .10301 m
.30769 .10676 L
s
.34615 .10301 m
.34615 .10676 L
s
.42308 .10301 m
.42308 .10676 L
s
.46154 .10301 m
.46154 .10676 L
s
.5 .10301 m
.5 .10676 L
s
.57692 .10301 m
.57692 .10676 L
s
.61538 .10301 m
.61538 .10676 L
s
.65385 .10301 m
.65385 .10676 L
s
.73077 .10301 m
.73077 .10676 L
s
.76923 .10301 m
.76923 .10676 L
s
.80769 .10301 m
.80769 .10676 L
s
.88462 .10301 m
.88462 .10676 L
s
.92308 .10301 m
.92308 .10676 L
s
.96154 .10301 m
.96154 .10676 L
s
.03846 .10301 m
.03846 .10676 L
s
.25 Mabswid
0 .10301 m
1 .10301 L
s
gsave
1.025 .10301 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.23077 0 m
.23702 0 L
s
[(-0.2)] .21827 0 1 0 Mshowa
.23077 .20601 m
.23702 .20601 L
s
[(0.2)] .21827 .20601 1 0 Mshowa
.23077 .30902 m
.23702 .30902 L
s
[(0.4)] .21827 .30902 1 0 Mshowa
.23077 .41202 m
.23702 .41202 L
s
[(0.6)] .21827 .41202 1 0 Mshowa
.23077 .51503 m
.23702 .51503 L
s
[(0.8)] .21827 .51503 1 0 Mshowa
.23077 .61803 m
.23702 .61803 L
s
[(1)] .21827 .61803 1 0 Mshowa
.125 Mabswid
.23077 .02575 m
.23452 .02575 L
s
.23077 .0515 m
.23452 .0515 L
s
.23077 .07725 m
.23452 .07725 L
s
.23077 .12876 m
.23452 .12876 L
s
.23077 .15451 m
.23452 .15451 L
s
.23077 .18026 m
.23452 .18026 L
s
.23077 .23176 m
.23452 .23176 L
s
.23077 .25751 m
.23452 .25751 L
s
.23077 .28327 m
.23452 .28327 L
s
.23077 .33477 m
.23452 .33477 L
s
.23077 .36052 m
.23452 .36052 L
s
.23077 .38627 m
.23452 .38627 L
s
.23077 .43777 m
.23452 .43777 L
s
.23077 .46353 m
.23452 .46353 L
s
.23077 .48928 m
.23452 .48928 L
s
.23077 .54078 m
.23452 .54078 L
s
.23077 .56653 m
.23452 .56653 L
s
.23077 .59228 m
.23452 .59228 L
s
.25 Mabswid
.23077 0 m
.23077 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
123.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(23) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.76995 .10301 m
.77187 .10301 L
.77368 .10301 L
.77535 .10301 L
.77719 .10301 L
.77811 .10301 L
.77913 .10301 L
.78097 .10301 L
.78271 .10301 L
.78428 .10301 L
.78598 .10301 L
.78783 .10301 L
.78877 .10301 L
.7898 .10301 L
.79162 .10301 L
.79333 .10302 L
.79495 .10309 L
.79666 .10337 L
.79812 .10403 L
.79972 .10572 L
.80144 .10968 L
.80328 .11793 L
.80502 .13102 L
.8066 .14814 L
.81031 .20513 L
.81378 .26241 L
.81553 .28413 L
.8174 .29824 L
.81847 .30149 L
.81949 .30134 L
.82139 .29331 L
.82239 .2856 L
.82346 .27533 L
.82538 .25318 L
.82973 .19847 L
.83181 .17537 L
.83377 .15705 L
.83551 .14371 L
.83743 .13214 L
.83926 .1237 L
.84097 .11779 L
.84278 .11319 L
.84371 .11137 L
.84472 .10973 L
.84652 .1075 L
.84822 .10603 L
.84988 .10505 L
.85142 .10441 L
.85322 .1039 L
.8549 .10359 L
Mistroke
.85676 .10336 L
.8578 .10328 L
.85875 .10322 L
.86056 .10313 L
.86159 .1031 L
.86254 .10308 L
.86355 .10306 L
.86447 .10305 L
.86553 .10304 L
.86653 .10303 L
.86821 .10302 L
.87002 .10301 L
.87173 .10301 L
.87328 .10301 L
.87511 .10301 L
.87614 .10301 L
.87709 .10301 L
.87884 .10301 L
.8807 .10301 L
.88247 .10301 L
.88437 .10301 L
.88617 .10301 L
.88782 .10301 L
.88965 .10301 L
.89068 .10301 L
.89165 .10301 L
.89267 .10301 L
.8936 .10301 L
.89467 .10301 L
.89568 .10301 L
.89723 .10301 L
.89894 .10301 L
.90072 .10301 L
.90238 .10301 L
.90394 .10301 L
.90536 .10301 L
.907 .10301 L
.90856 .10301 L
.91024 .10301 L
.91203 .10301 L
.91371 .10301 L
.91524 .10301 L
.91704 .10301 L
.91806 .10301 L
.919 .10301 L
.92071 .10301 L
.92253 .10301 L
.92431 .10301 L
.92531 .10301 L
.92624 .10301 L
Mistroke
.92794 .10301 L
.92975 .10301 L
.93136 .10301 L
.93287 .10301 L
.93453 .10301 L
.93632 .10301 L
.93812 .10301 L
.93914 .10301 L
.94008 .10301 L
.94199 .10301 L
.94306 .10301 L
.94404 .10301 L
.94578 .10301 L
.94767 .10301 L
.94946 .10301 L
.9511 .10301 L
.95264 .10301 L
.95429 .10301 L
.95585 .10301 L
.95727 .10301 L
.95894 .10301 L
.96075 .10301 L
.96247 .10301 L
.96406 .10301 L
.96585 .10301 L
.96754 .10301 L
.96906 .10301 L
.9707 .10301 L
.97249 .10301 L
.97438 .10301 L
.976 .10301 L
.97776 .10301 L
.97967 .10301 L
.98143 .10301 L
.98235 .10301 L
.98337 .10301 L
.98443 .10301 L
.98542 .10301 L
.98724 .10301 L
.9889 .10301 L
.99083 .10301 L
.99265 .10301 L
.99428 .10301 L
.99601 .10301 L
.99765 .10301 L
.99913 .10301 L
Mfstroke
.99913 .10301 m
1 .10301 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000oooooolLooooo`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0oooooolLooooo`00<?ooool6o`0000;o
oooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^0?oooooo7Oooool003So
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003ooooo
oa?ooooo000hooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05oooo
o`03o`000?oooooooooo0?oooooo4oooool003Sooooo00Go410@oooooooooooooooooa0@400?oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooo
oooo0?oooooo4oooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooo
oooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003ooooooooo
o`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000oooo
ooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`00
0?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool0
0ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o
0000ooooooooool0oooooolCooooo`008oooool5o`0002_ooooo00?o0000ooooooooool0:oooool5
o`0002kooooo0_l000000ol@413oooooooooo`0Zooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?oo
ool01Oo<c<co8B4Qo`000?lQ8B7oc<c<02Wooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`00
0?lb<S;ok^k^6_ooool002?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00[ooooo`03o`000?oooooo
oooo02_ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00_ooooo`03o`000?oooooooooo02_ooooo00Go
EEEEogMgMoooooooV9RHob4Q8@0/ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40:oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool001_ooooo1_l00003ooooo`03
oiRHV?lQ8B7ok^k^02cooooo00?o0000ooooooooool0;?ooool00onHV9So8B4Qonk^kP0]ooooo`Go
0000;?ooool01Ol0003ooooooooooooooooo000002cooooo00Go0000ooooooooooooooooo`00000[
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Jooooo`009Oooool0
0onHV9So8B4Qonk^kP0[ooooo`03o`000?oooooooooo02gooooo00?oV9RHob4Q8Oo^k^h0;?ooool0
1?m4A4CogMgMooooool0000]ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;?ooool01Olb<S;oV9RH
oooooonHV9So<S8b02_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
01[ooooo000Vooooo`03ogMgMomVIVKooooo02[ooooo0_l0000_ooooo`03ogMgMomVIVKooooo02_o
oooo00CogMgMoeEEEOoooooo0000;Oooool01Ol0003oEEEEo`000?l@413oc<c<02cooooo00Goc<c<
o`000?l0003o0000olc<c00[ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Jooooo`009oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool0:oooool00omgMgOoc<c<o`00000]ooooo`03oeEEEOn7QhOooooo02kooooo00Go
410@okZj^_oooooo^[Zjoa0@400[ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@400Jooooo`008oooool01Ol0003o^[ZjoooooonHV9So410@02_ooooo00?o0000oooooooo
ool0:oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo00?ok^k^odA4A?l00000;Oooool00ooM
gMgo410@oiRHV00^ooooo`05o`000?nj^[[ooooookZj^_l00000:oooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool002?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00[ooooo`03o`000?oooooooooo02_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00^ooooo`03ogMg
Mol0003ooooo02gooooo00Coc<c<odA4A?l0003o410@;?ooool01OnYZJWo410@o`000?l@413oZJVY
02Wooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo001Coooo
o`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00
Doooool00ol0003oooooooooo`3mooooo`;o00000_ooool2o`0000oooooo001Cooooo`03o`000?oo
oooooooo0?gooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd?ooooo`00Doooool00ol0003ooooo
ooooo`3nooooo`04omgMgOl0003o410@olc<c13ooooo000:oooooooo0000@?l0000;ooooo`04onk^
k_lQ8B7o410@onk^kQ3ooooo000Fooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
1oooool01?l0003oooooooooool0000;ooooo`;o00002_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`04
ob4Q8OmgMgOoMgMgoc8b<Q3ooooo000Rooooo`03o`000?oooooooooo02kooooo00?o0000oooooooo
ool0;_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02kooooo00?o0000oooooooo
ool08?ooool00ol0003oooooooooo`0:ooooo`;o0000<?ooool00ol0003oooooooooo`08ooooo`;o
00000_ooool2o`0000oooooo001Cooooo`03o`000?oooooooooo0;?ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`1?ooooo`00Doooool00ol0003oooooooooo`2cooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool0D?ooool005?ooooo00?o0000ooooooooool0/oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo053ooooo001Cooooo`03o`000?oooooooooo
0;?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1@ooooo`00Doooool00ol0003o
ooooooooo`2dooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0D?ooool005?ooooo
0_l0002eooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0DOooool005?ooooo00?o
0000ooooooooool0]?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo057ooooo001C
ooooo`03o`000?oooooooooo0;Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1A
ooooo`00Doooool00ol0003oooooooooo`2dooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0DOooool005?ooooo00?o0000ooooooooool0]?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo057ooooo001Cooooo`03o`000?oooooooooo0;Cooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`1Aooooo`00Doooool00ol0003oooooooooo`2dooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0DOooool005?ooooo00?o0000ooooooooool0]?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo057ooooo001Cooooo`;o0000]Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo05;ooooo001Cooooo`03o`000?oooooooooo0;Co
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Booooo`00Doooool00ol0003ooooo
ooooo`2dooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0D_ooool005?ooooo00?o
0000ooooooooool0]Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05;ooooo001C
ooooo`03o`000?oooooooooo0;Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1B
ooooo`00Doooool00ol0003oooooooooo`2eooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0Doooool005?ooooo00?o0000ooooooooool0]Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo05?ooooo001Cooooo`03o`000?oooooooooo0;Gooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`1Cooooo`00Doooool2o`000;Kooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`1Cooooo`00Doooool00ol0003oooooooooo`2eooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0Doooool005?ooooo00?o0000ooooooooool0]Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo05?ooooo001Cooooo`03o`000?oooooooooo0;Go
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1Cooooo`00Doooool00ol0003ooooo
ooooo`2fooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Doooool005?ooooo00?o
0000ooooooooool0]_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05?ooooo000h
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol00006ooooo`03o`000?oo
oooooooo0;Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1Cooooo`00>?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0
1_ooool00ol0003oooooooooo`2fooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
Doooool003Sooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^00Oooooo
0ol0002fooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0Doooool003Sooooo00Go
0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0
]_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo05?ooooo000hooooo`05o`000?oo
ooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0;Kooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`1Cooooo`00>?ooool01Ol@413ooooooooo
oooooooo410@00oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2fooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0E?ooool003Sooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`2fooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0E?ooool003Sooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`2foooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0E?ooool005?ooooo00?o0000oooooooo
ool0]_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05Cooooo001Cooooo`03o`00
0?oooooooooo0;Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1Dooooo`00Dooo
ool00ol0003oooooooooo`2fooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0E?oo
ool005?ooooo0_l0002gooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0E?ooool0
05?ooooo00?o0000ooooooooool0]oooool01Ol0003ooooooooooooooooo000005Kooooo001Coooo
o`03o`000?oooooooooo0;Oooooo00Go0000ooooooooooooooooo`00001Fooooo`00Doooool00ol0
003oooooooooo`2gooooo`04o`000?ooooooooooo`0005Oooooo001Cooooo`03o`000?oooooooooo
0;Oooooo00Co0000oooooooooooo0000Eoooool005?ooooo00?o0000ooooooooool0]oooool01?l0
003oooooooooool0001Gooooo`00Doooool00ol0003oooooooooo`2gooooo`04o`000?oooooooooo
o`0005Oooooo001Cooooo`03o`000?oooooooooo0;Oooooo00Co0000oooooooooooo0000Eoooool0
05?ooooo0_l0002hooooo`04o`000?ooooooooooo`0005Oooooo001Cooooo`03o`000?oooooooooo
0;Oooooo00Co0000oooooooooooo0000Eoooool005?ooooo00?o0000ooooooooool0]oooool01?l0
003oooooooooool0001Gooooo`00Doooool00ol0003oooooooooo`2gooooo`04o`000?oooooooooo
o`0005Oooooo001Cooooo`03o`000?oooooooooo0;Oooooo00Co0000oooooooooooo0000Eoooool0
05?ooooo00?o0000ooooooooool0]oooool01?l0003oooooooooool0001Gooooo`00Doooool00ol0
003oooooooooo`2gooooo`04o`000?ooooooooooo`0005Oooooo001Cooooo`03o`000?oooooooooo
0;Oooooo00Co0000oooooooooooo0000Eoooool005?ooooo0_l0002hooooo`03o`000?oooooo0000
05Sooooo001Cooooo`03o`000?oooooooooo0;Oooooo00?o0000ooooool00000F?ooool005?ooooo
00?o0000ooooooooool0]oooool00ol0003oooooo`00001Hooooo`00Doooool00ol0003ooooooooo
o`2hooooo`;o0000F?ooool005?ooooo00?o0000ooooooooool0^?ooool2o`0005Sooooo001Coooo
o`03o`000?oooooooooo0;Sooooo00?o0000ooooooooool0Eoooool003Sooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000oooo
ooooool0^?ooool00ol0003oooooooooo`1Gooooo`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooolCoooo
o`00>?ooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00006ooooo`?o0000oooooolCoooo
o`00>?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo00001oooool0
0ol0003oooooooooo`3ooooooa?ooooo000hooooo`05o`000?ooooooooooooooool000002oooool0
1?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo0?oooooo4oooool003Sooooo00Go410@
oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0oooo
oolCooooo`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l000001ooo
ool00ol0003oooooooooo`3ooooooa?ooooo000hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03Ooo
ool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000
ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o
0000oooooolDooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oo
oooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0
003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo
00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001C
ooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo0_l0003ooooooaCooooo001Cooooo`03
o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Dooo
ool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool0
05?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?o
oooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo0_l0003ooooooaCooooo001C
ooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCoooo
o`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo
4oooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo^k^ko<S8b
o`000?l@413oc<c<00Kooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0
003oooooooooo`3ooooooa?ooooo000hooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01Ol0
003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`?o0000oooo
oolCooooo`00>?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEEEOl0003o410@
olc<c006ooooo`03o`000?oooooooooo0?oooooo4oooool003Sooooo00Go410@oooooooooooooooo
oa0@400;ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0oooooolCooooo`00>?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003ooooo
ooooo`3ooooooa?ooooo000hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool01?o<c<coA4A4
o`000?l@4106ooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0
oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooo
oooo0?oooooo4oooool005?ooooo0_l0003ooooooaCooooo001Cooooo`03o`000?oooooooooo0?oo
oooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003ooooooooo
o`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000oooo
ooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`00
0?oooooooooo0?oooooo4oooool005?ooooo0_l0003ooooooaCooooo001Cooooo`03o`000?oooooo
oooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o
0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Coooo
o`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00
Doooool2o`000?oooooo5?ooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool0
0ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?o
oooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3ooooo
oa?ooooo000hooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00Go8B4QoiRH
V?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?oooooo4oooool003Sooooo00Go410@oooo
oooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooooooo
o`3ooooooa?ooooo000hooooo`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooo
oonHV9So<S8b00Kooooo0ol0003ooooooa?ooooo000hooooo`05o`000?ooooooooooooooool00000
2oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooooolCooooo`00
>?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zjoa0@4006oooo
o`03o`000?oooooooooo0?oooooo4oooool003Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;oooo
o`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`3ooooooa?ooooo000hoooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o
0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Coooo
o`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00
Doooool2o`000?oooooo5?ooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool0
0ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?o
oooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo
001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolC
ooooo`00Doooool2o`000?oooooo5?ooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00
Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4ooo
ool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooo
oa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0
oooooolCooooo`00Doooool2o`000?oooooo5?ooool005?ooooo00?o0000ooooooooool0oooooolC
ooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oo
oooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003ooooooooo
o`3ooooooa?ooooo0019ooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`3o
oooooa?ooooo001;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooolCoooo
o`00Boooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo4oooool004_ooooo
00?o0000ooooooooool01Oooool3o`000?oooooo4oooool004_ooooo00?o0000ooooooooool0oooo
oolKooooo`00Boooool00ol0003oooooooooo`3ooooooa_ooooo001;ooooo`03o`000?oooooooooo
0?oooooo6oooool004Wooooo00?oEEEEofIVI_l00000oooooolMooooo`00N?ooool3o`000003oa0@
4?oooooooooo0>[ooooo001jooooo`03oa0@4?nj^[[ooooo00Oooooo0_l0000;ooooo`03o`000?nj
^[[ooooo00cooooo0_l00005ooooo`03o`000?nj^[[ooooo0;kooooo001jooooo`03oiRHV?lb<S;o
oooo00Oooooo00?o0000ooooooooool02_ooool2oc8b<Pkooooo00?o0000ooooooooool00oooool2
oc8b<[oooooo001jooooo`03omgMgOl0003o^[Zj00Oooooo00Co0000oooooooooooooooo0_l00002
ooooo`;o00000oooool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0003o0000odA4A?nj^[X01?oo
ool00ol0003oooooooooo`03ooooo`03ohN7Qol0003o^[Zj00cooooo00GoV9RHo`000?l0003oA4A4
okZj^P0Aooooo`Go00000oooool01OnHV9So410@o`000?lb<S;oc<c<08oooooo001jooooo`03oeEE
EOmgMgOoA4A400Oooooo00[o0000ooooooooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0ooo
ool00oo<c<co0000oa0@4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003ooooo
ooooo`03ooooo`03olc<c?l0003o410@00cooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko
00000_ooool01OnHV9So8B4Qonk^k_ooooooA4A400?ooooo00Go410@okZj^_ooooooMgMgoc8b<P2?
ooooo`00NOooool01OoMgMgo410@oooooolQ8B7ogMgM00Kooooo00?o0000ooooooooool00_ooool0
1?oMgMgo0000oa0@4?o<c<`;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0Dooooo`03oiRHV?lQ8B7ok^k^00Sooooo00?o0000ooooooooool0SOoo
ool007Wooooo00GoIVIVohN7QoooooooV9RHoeEEE@06ooooo`03o`000?oooooooooo00;ooooo00Co
k^k^ob4Q8Ol@413ok^k^2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool02oooool6o`0000Cooooo00?oV9RHob4Q8Oo^k^h01_ooool00onYZJWo410@
ooooo`2>ooooo`00N?ooool00oo^k^ko0000onk^kP02ooooo`03o`000?oMgMgooooo00Cooooo00?o
0000ooooooooool00_ooool01?lQ8B7oMgMgogMgMolb<S8;ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Fooooo`03ogMgMomVIVKooooo00Cooooo
00?o410@o`000?nj^[X0Soooool007Sooooo00Co410@o`000?l0003ooooo0_l000000ol@413ooooo
ooooo`03ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000Sooooo00?o410@o`000?l0
00000ol00005ooooo`03o`000?oooooooooo013ooooo00?o410@o`000?l000000ol0000Fooooo`03
o`000?oooooooooo00Cooooo00?o^[Zjob4Q8Oooool0S_ooool008Cooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
4oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00Go410@oiRHV?oooooo^[Zjo`00002?oooo
o`00Q?ooool2o`0001;ooooo00?o0000ooooooooool01Oooool2o`0001Cooooo00?o0000oooooooo
ool04oooool01OnHV9So410@o`000?lQ8B7oc<c<00?ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@2?
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-3.4116, -0.234311, \
0.0510397, 0.00762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.230769 0.0769231 0.103006 0.515028 [
[.07692 .09051 -6 -9 ]
[.07692 .09051 6 0 ]
[.38462 .09051 -3 -9 ]
[.38462 .09051 3 0 ]
[.53846 .09051 -3 -9 ]
[.53846 .09051 3 0 ]
[.69231 .09051 -3 -9 ]
[.69231 .09051 3 0 ]
[.84615 .09051 -3 -9 ]
[.84615 .09051 3 0 ]
[1 .09051 -6 -9 ]
[1 .09051 6 0 ]
[1.025 .10301 0 -6 ]
[1.025 .10301 10 6 ]
[.21827 0 -24 -4.5 ]
[.21827 0 0 4.5 ]
[.21827 .20601 -18 -4.5 ]
[.21827 .20601 0 4.5 ]
[.21827 .30902 -18 -4.5 ]
[.21827 .30902 0 4.5 ]
[.21827 .41202 -18 -4.5 ]
[.21827 .41202 0 4.5 ]
[.21827 .51503 -18 -4.5 ]
[.21827 .51503 0 4.5 ]
[.21827 .61803 -6 -4.5 ]
[.21827 .61803 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07692 .10301 m
.07692 .10926 L
s
[(-2)] .07692 .09051 0 1 Mshowa
.38462 .10301 m
.38462 .10926 L
s
[(2)] .38462 .09051 0 1 Mshowa
.53846 .10301 m
.53846 .10926 L
s
[(4)] .53846 .09051 0 1 Mshowa
.69231 .10301 m
.69231 .10926 L
s
[(6)] .69231 .09051 0 1 Mshowa
.84615 .10301 m
.84615 .10926 L
s
[(8)] .84615 .09051 0 1 Mshowa
1 .10301 m
1 .10926 L
s
[(10)] 1 .09051 0 1 Mshowa
.125 Mabswid
.11538 .10301 m
.11538 .10676 L
s
.15385 .10301 m
.15385 .10676 L
s
.19231 .10301 m
.19231 .10676 L
s
.26923 .10301 m
.26923 .10676 L
s
.30769 .10301 m
.30769 .10676 L
s
.34615 .10301 m
.34615 .10676 L
s
.42308 .10301 m
.42308 .10676 L
s
.46154 .10301 m
.46154 .10676 L
s
.5 .10301 m
.5 .10676 L
s
.57692 .10301 m
.57692 .10676 L
s
.61538 .10301 m
.61538 .10676 L
s
.65385 .10301 m
.65385 .10676 L
s
.73077 .10301 m
.73077 .10676 L
s
.76923 .10301 m
.76923 .10676 L
s
.80769 .10301 m
.80769 .10676 L
s
.88462 .10301 m
.88462 .10676 L
s
.92308 .10301 m
.92308 .10676 L
s
.96154 .10301 m
.96154 .10676 L
s
.03846 .10301 m
.03846 .10676 L
s
.25 Mabswid
0 .10301 m
1 .10301 L
s
gsave
1.025 .10301 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.23077 0 m
.23702 0 L
s
[(-0.2)] .21827 0 1 0 Mshowa
.23077 .20601 m
.23702 .20601 L
s
[(0.2)] .21827 .20601 1 0 Mshowa
.23077 .30902 m
.23702 .30902 L
s
[(0.4)] .21827 .30902 1 0 Mshowa
.23077 .41202 m
.23702 .41202 L
s
[(0.6)] .21827 .41202 1 0 Mshowa
.23077 .51503 m
.23702 .51503 L
s
[(0.8)] .21827 .51503 1 0 Mshowa
.23077 .61803 m
.23702 .61803 L
s
[(1)] .21827 .61803 1 0 Mshowa
.125 Mabswid
.23077 .02575 m
.23452 .02575 L
s
.23077 .0515 m
.23452 .0515 L
s
.23077 .07725 m
.23452 .07725 L
s
.23077 .12876 m
.23452 .12876 L
s
.23077 .15451 m
.23452 .15451 L
s
.23077 .18026 m
.23452 .18026 L
s
.23077 .23176 m
.23452 .23176 L
s
.23077 .25751 m
.23452 .25751 L
s
.23077 .28327 m
.23452 .28327 L
s
.23077 .33477 m
.23452 .33477 L
s
.23077 .36052 m
.23452 .36052 L
s
.23077 .38627 m
.23452 .38627 L
s
.23077 .43777 m
.23452 .43777 L
s
.23077 .46353 m
.23452 .46353 L
s
.23077 .48928 m
.23452 .48928 L
s
.23077 .54078 m
.23452 .54078 L
s
.23077 .56653 m
.23452 .56653 L
s
.23077 .59228 m
.23452 .59228 L
s
.25 Mabswid
.23077 0 m
.23077 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
123.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(24) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.78223 .10301 m
.78242 .10301 L
.78413 .10301 L
.78594 .10301 L
.7875 .10301 L
.78895 .10301 L
.79055 .10301 L
.79226 .10301 L
.7941 .10301 L
.79515 .10301 L
.79611 .10301 L
.79788 .10301 L
.79976 .10301 L
.80144 .10301 L
.80301 .10301 L
.80474 .10301 L
.8066 .10306 L
.80842 .1033 L
.80944 .10365 L
.81036 .10424 L
.81217 .10671 L
.81387 .11184 L
.81483 .11656 L
.81586 .12337 L
.81769 .14094 L
.81966 .16766 L
.82183 .20392 L
.82388 .23962 L
.82582 .26904 L
.82689 .28161 L
.82806 .2915 L
.82913 .2967 L
.83011 .29823 L
.83113 .2966 L
.83208 .29234 L
.83387 .2784 L
.83579 .25716 L
.83786 .23067 L
.84162 .18394 L
.84513 .15025 L
.8469 .13776 L
.84879 .12743 L
.84987 .12278 L
.85089 .11909 L
.8528 .11376 L
.85446 .11047 L
.85622 .108 L
.85773 .10651 L
.85938 .10535 L
.86116 .10451 L
Mistroke
.86307 .10392 L
.86488 .10358 L
.86653 .10337 L
.8684 .10322 L
.87015 .10314 L
.87173 .10309 L
.87344 .10306 L
.87531 .10304 L
.87625 .10303 L
.87728 .10302 L
.87911 .10302 L
.88082 .10301 L
.88254 .10301 L
.88417 .10301 L
.88563 .10301 L
.88723 .10301 L
.88895 .10301 L
.89079 .10301 L
.89236 .10301 L
.8941 .10301 L
.89599 .10301 L
.89695 .10301 L
.89799 .10301 L
.89984 .10301 L
.90157 .10301 L
.90262 .10301 L
.90361 .10301 L
.90546 .10301 L
.9065 .10301 L
.90746 .10301 L
.90851 .10301 L
.90962 .10301 L
.91135 .10301 L
.91321 .10301 L
.91496 .10301 L
.91657 .10301 L
.91844 .10301 L
.9195 .10301 L
.92049 .10301 L
.92229 .10301 L
.92421 .10301 L
.92602 .10301 L
.92705 .10301 L
.92801 .10301 L
.92902 .10301 L
.92994 .10301 L
.931 .10301 L
.93201 .10301 L
.9338 .10301 L
.93545 .10301 L
Mistroke
.93726 .10301 L
.93817 .10301 L
.93918 .10301 L
.9402 .10301 L
.94128 .10301 L
.9432 .10301 L
.94427 .10301 L
.94527 .10301 L
.94636 .10301 L
.94753 .10301 L
.94854 .10301 L
.94964 .10301 L
.95068 .10301 L
.95164 .10301 L
.95345 .10301 L
.95536 .10301 L
.95718 .10301 L
.95885 .10301 L
.96076 .10301 L
.96258 .10301 L
.96426 .10301 L
.96582 .10301 L
.96752 .10301 L
.96934 .10301 L
.97038 .10301 L
.97133 .10301 L
.97238 .10301 L
.97349 .10301 L
.97536 .10301 L
.97641 .10301 L
.9774 .10301 L
.97924 .10301 L
.98092 .10301 L
.98185 .10301 L
.98286 .10301 L
.9847 .10301 L
.98648 .10301 L
.98811 .10301 L
.98999 .10301 L
.99178 .10301 L
.99342 .10301 L
.99495 .10301 L
.99662 .10301 L
.99841 .10301 L
.99943 .10301 L
Mfstroke
.99943 .10301 m
1 .10301 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000oooooolLooooo`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0oooooolLooooo`00<?ooool6o`0000;o
oooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^0?oooooo7Oooool003So
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003ooooo
oa?ooooo000hooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05oooo
o`03o`000?oooooooooo0?oooooo4oooool003Sooooo00Go410@oooooooooooooooooa0@400?oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooo
oooo0?oooooo4oooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooo
oooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003ooooooooo
o`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000oooo
ooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`00
0?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool0
0ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o
0000ooooooooool0oooooolCooooo`008oooool5o`0002_ooooo00?o0000ooooooooool0:oooool5
o`0002kooooo0_l000000ol@413oooooooooo`0Zooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?oo
ool01Oo<c<co8B4Qo`000?lQ8B7oc<c<02Wooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`00
0?lb<S;ok^k^6_ooool002?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00[ooooo`03o`000?oooooo
oooo02_ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00_ooooo`03o`000?oooooooooo02_ooooo00Go
EEEEogMgMoooooooV9RHob4Q8@0/ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40:oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool001_ooooo1_l00003ooooo`03
oiRHV?lQ8B7ok^k^02cooooo00?o0000ooooooooool0;?ooool00onHV9So8B4Qonk^kP0]ooooo`Go
0000;?ooool01Ol0003ooooooooooooooooo000002cooooo00Go0000ooooooooooooooooo`00000[
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Jooooo`009Oooool0
0onHV9So8B4Qonk^kP0[ooooo`03o`000?oooooooooo02gooooo00?oV9RHob4Q8Oo^k^h0;?ooool0
1?m4A4CogMgMooooool0000]ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;?ooool01Olb<S;oV9RH
oooooonHV9So<S8b02_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
01[ooooo000Vooooo`03ogMgMomVIVKooooo02[ooooo0_l0000_ooooo`03ogMgMomVIVKooooo02_o
oooo00CogMgMoeEEEOoooooo0000;Oooool01Ol0003oEEEEo`000?l@413oc<c<02cooooo00Goc<c<
o`000?l0003o0000olc<c00[ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Jooooo`009oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool0:oooool00omgMgOoc<c<o`00000]ooooo`03oeEEEOn7QhOooooo02kooooo00Go
410@okZj^_oooooo^[Zjoa0@400[ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@400Jooooo`008oooool01Ol0003o^[ZjoooooonHV9So410@02_ooooo00?o0000oooooooo
ool0:oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo00?ok^k^odA4A?l00000;Oooool00ooM
gMgo410@oiRHV00^ooooo`05o`000?nj^[[ooooookZj^_l00000:oooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool002?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00[ooooo`03o`000?oooooooooo02_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00^ooooo`03ogMg
Mol0003ooooo02gooooo00Coc<c<odA4A?l0003o410@;?ooool01OnYZJWo410@o`000?l@413oZJVY
02Wooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo001Coooo
o`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00
Doooool00ol0003oooooooooo`3mooooo`;o00000_ooool2o`0000oooooo001Cooooo`03o`000?oo
oooooooo0?gooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd?ooooo`00Doooool00ol0003ooooo
ooooo`3nooooo`04omgMgOl0003o410@olc<c13ooooo000:oooooooo0000@?l0000;ooooo`04onk^
k_lQ8B7o410@onk^kQ3ooooo000Fooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool2o`0000[ooooo00?o0000ooooooooool00_l00007ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo
00Co8B4QogMgMomgMgOo<S8b4?ooool002;ooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`0^ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo0000;Oooool00ol0003o
ooooooooo`08ooooo`;o00000_ooool2o`0000oooooo001Cooooo`03o`000?oooooooooo0;Oooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`1<ooooo`00Doooool00ol0003ooooooooo
o`2gooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0C?ooool005?ooooo00?o0000
ooooooooool0]oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo04gooooo001Coooo
o`03o`000?oooooooooo0;Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1=oooo
o`00Doooool00ol0003oooooooooo`2gooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool0COooool005?ooooo0_l0002hooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
COooool005?ooooo00?o0000ooooooooool0]oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo04gooooo001Cooooo`03o`000?oooooooooo0;Sooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`1>ooooo`00Doooool00ol0003oooooooooo`2hooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0C_ooool005?ooooo00?o0000ooooooooool0^?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo04kooooo001Cooooo`03o`000?oooooooooo0;Sooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`1>ooooo`00Doooool00ol0003ooooooooo
o`2hooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0C_ooool005?ooooo00?o0000
ooooooooool0^?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04kooooo001Coooo
o`;o0000^Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04kooooo001Cooooo`03
o`000?oooooooooo0;Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1>ooooo`00
Doooool00ol0003oooooooooo`2iooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
C_ooool005?ooooo00?o0000ooooooooool0^Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo04kooooo001Cooooo`03o`000?oooooooooo0;Wooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`1>ooooo`00Doooool00ol0003oooooooooo`2iooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0Coooool005?ooooo00?o0000ooooooooool0^Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo04oooooo001Cooooo`03o`000?oooooooooo0;Wooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`1?ooooo`00Doooool2o`000;[ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`1?ooooo`00Doooool00ol0003oooooooooo`2i
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Coooool005?ooooo00?o0000oooo
ooooool0^Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04oooooo001Cooooo`03
o`000?oooooooooo0;Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1?ooooo`00
Doooool00ol0003oooooooooo`2iooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
Coooool005?ooooo00?o0000ooooooooool0^Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo04oooooo000hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo1Ol0
0006ooooo`03o`000?oooooooooo0;Wooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`1@ooooo`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`2iooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0D?ooool003Sooooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo0ol0002iooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
D?ooool003Sooooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo
00?o0000ooooooooool0^Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo053ooooo
000hooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05ooooo`03o`00
0?oooooooooo0;Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1@ooooo`00>?oo
ool01Ol@413ooooooooooooooooo410@00oooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`2iooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0D?ooool003Sooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003o
ooooooooo`2iooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0D?ooool003Sooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0
003oooooooooo`2iooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0DOooool005?o
oooo00?o0000ooooooooool0^_ooool01Ol0003ooooooooooooooooo000005?ooooo001Cooooo`03
o`000?oooooooooo0;[ooooo00Go0000ooooooooooooooooo`00001Cooooo`00Doooool00ol0003o
ooooooooo`2jooooo`05o`000?ooooooooooooooool00000Doooool005?ooooo0_l0002kooooo`05
o`000?ooooooooooooooool00000Doooool005?ooooo00?o0000ooooooooool0^_ooool01Ol0003o
oooooooooooooooo000005?ooooo001Cooooo`03o`000?oooooooooo0;[ooooo00Go0000oooooooo
ooooooooo`00001Cooooo`00Doooool00ol0003oooooooooo`2jooooo`05o`000?oooooooooooooo
ool00000Doooool005?ooooo00?o0000ooooooooool0^_ooool01Ol0003ooooooooooooooooo0000
05?ooooo001Cooooo`03o`000?oooooooooo0;[ooooo00Go0000ooooooooooooooooo`00001Coooo
o`00Doooool00ol0003oooooooooo`2jooooo`05o`000?ooooooooooooooool00000Doooool005?o
oooo00?o0000ooooooooool0^oooool01?l0003oooooooooool0001Cooooo`00Doooool2o`000;co
oooo00Co0000oooooooooooo0000Doooool005?ooooo00?o0000ooooooooool0^oooool01?l0003o
ooooooooool0001Cooooo`00Doooool00ol0003oooooooooo`2kooooo`04o`000?ooooooooooo`00
05?ooooo001Cooooo`03o`000?oooooooooo0;_ooooo00Co0000oooooooooooo0000Doooool005?o
oooo00?o0000ooooooooool0^oooool00ol0003oooooo`00001Dooooo`00Doooool00ol0003ooooo
ooooo`2kooooo`03o`000?oooooo000005Cooooo001Cooooo`03o`000?oooooooooo0;_ooooo00?o
0000ooooool00000E?ooool005?ooooo00?o0000ooooooooool0^oooool00ol0003oooooo`00001D
ooooo`00Doooool2o`000;cooooo00?o0000ooooool00000E?ooool005?ooooo00?o0000oooooooo
ool0^oooool2o`0005Gooooo001Cooooo`03o`000?oooooooooo0;_ooooo0_l0001Eooooo`00Dooo
ool00ol0003oooooooooo`2kooooo`;o0000EOooool005?ooooo00?o0000ooooooooool0_?ooool0
0ol0003oooooooooo`1Cooooo`00Doooool00ol0003oooooooooo`2looooo`03o`000?oooooooooo
05?ooooo000hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@
413oooooooooo`04ooooo`03o`000?oooooooooo0?oooooo4oooool003Sooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?oooooo4oooool003Sooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00001_ooool3o`00
0?oooooo4oooool003Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgooooo
o`0000Oooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01Ol0003ooooooooooooooooo
000000_ooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`3ooooooa?ooooo000h
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000007ooooo`03o`000?oo
oooooooo0?oooooo4oooool003Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4
A4Co000000Oooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00gooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`3ooooooa?ooooo001C
ooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCoooo
o`00Doooool2o`000?oooooo5?ooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Dooo
ool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool0
05?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?o
oooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooo
oolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDoooo
o`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo
4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3o
oooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000oooooooo
ool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooo
oolDooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo
0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003ooooo
ooooo`3ooooooa?ooooo000hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0?oooooo4oooool003Sooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q
00Kooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01Ol@413ooooooooooooooooo410@
00_ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo4oooool0
03Sooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_oo
ool3o`000?oooooo4oooool003Sooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mE
EEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`3ooooooa?ooooo000hooooo`05oa0@4?oo
ooooooooooooool@41002oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo0?oooooo
4oooool003Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Sooooo
00?o0000ooooooooool0oooooolCooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo
00Coc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`00
0?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool0
0ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o
0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Coooo
o`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00
Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool0
0ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?o
oooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo
001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolC
ooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oo
oooo4oooool005?ooooo0_l0003ooooooaCooooo001Cooooo`03o`000?oooooooooo0?oooooo4ooo
ool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooo
oa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool003Sooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000oooo
ooooool0oooooolCooooo`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44oooo
o`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`3ooooooa?ooooo000hoooo
o`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo00?o
0000ooooooooool0oooooolCooooo`00>?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go
<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000oooooolCooooo`00>?ooool01Ol0003ooooooooo
oooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo0?oo
oooo4oooool003Sooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj
^_l@41001_ooool00ol0003oooooooooo`3ooooooa?ooooo000hooooo`05ogMgMonHV9SooooooiRH
V?mgMgL02oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool0oooooolC
ooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVY
Z@06ooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolC
ooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oo
oooo4oooool005?ooooo0_l0003ooooooaCooooo001Cooooo`03o`000?oooooooooo0?oooooo4ooo
ool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooo
oa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0
oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooo
oooo0?oooooo4oooool005?ooooo0_l0003ooooooaCooooo001Cooooo`03o`000?oooooooooo0?oo
oooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003ooooooooo
o`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000oooo
ooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`00
0?oooooooooo0?oooooo4oooool005?ooooo0_l0003ooooooaCooooo001Cooooo`03o`000?oooooo
oooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o
0000ooooooooool0oooooolCooooo`00BOooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000
ooooooooool0oooooolCooooo`00Boooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?oooooo4oooool004_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooooa?o
oooo001;ooooo`03o`000?oooooooooo00Gooooo0ol0003ooooooa?ooooo001;ooooo`03o`000?oo
oooooooo0?oooooo6oooool004_ooooo00?o0000ooooooooool0oooooolKooooo`00Boooool00ol0
003oooooooooo`3ooooooa_ooooo0019ooooo`03oeEEEOmVIVKo00000?oooooo7Oooool007Sooooo
0ol000000ol@413oooooooooo`3Zooooo`00N_ooool00ol@413o^[Zjooooo`07ooooo`;o00002ooo
ool00ol0003o^[Zjooooo`0<ooooo`;o00001Oooool00ol0003o^[Zjooooo`2nooooo`00N_ooool0
0onHV9So<S8booooo`07ooooo`03o`000?oooooooooo00[ooooo0_lb<S8>ooooo`03o`000?oooooo
oooo00?ooooo0_lb<S:oooooo`00N_ooool00ooMgMgo0000okZj^P07ooooo`04o`000?oooooooooo
ooooo`;o00000_ooool2o`0000?ooooo00?oQhN7o`000?nj^[X01?ooool01OnHV9So0000o`000?m4
A4Co^[Zj00Cooooo00?o0000ooooooooool00oooool00on7QhOo0000okZj^P0<ooooo`05oiRHV?l0
003o0000odA4A?nj^[X04Oooool5o`0000Gooooo0_l000000ol@413oooooooooo`2=ooooo`00N_oo
ool00omEEEGoMgMgodA4A007ooooo`0:o`000?ooooooooooooooooo^k^ko8B4QohN7Qonj^[[o0000
omgMg@?ooooo00?oc<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo00?o
0000ooooooooool00oooool00oo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@4100
2Oooool6o`0000;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo08ko
oooo001iooooo`05omgMgOl@413oooooob4Q8OoMgMd01_ooool00ol0003oooooooooo`02ooooo`04
omgMgOl0003o410@olc<c0_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo01Cooooo00?oV9RHob4Q8Oo^k^h01?ooool5o`0008oooooo001iooooo`05
ofIVI_n7QhOooooooiRHV?mEEED01_ooool00ol0003oooooooooo`02ooooo`04onk^k_lQ8B7o410@
onk^kP_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo00_ooooo1_l00004ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00CoA4A4omgMgOoooooo0000T?oo
ool007Sooooo00?ok^k^o`000?o^k^h00_ooool00ol0003ogMgMooooo`04ooooo`03o`000?oooooo
oooo00;ooooo00Co8B4QogMgMomgMgOo<S8b2oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool05_ooool00omgMgOoIVIVooooo`02ooooo`04omgMgOmE
EEGoooooo`00093ooooo001hooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool0
0oooool01?l0003oooooooooooooool2o`0000;ooooo0_l00008ooooo`03oa0@4?l0003o000000?o
00001Oooool00ol0003oooooooooo`0@ooooo`03oa0@4?l0003o000000?o00005_ooool00ol0003o
ooooooooo`02ooooo`03ogMgMoo<c<co0000093ooooo0024ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01?ooooo
00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03onk^k_m4A4Co0000093ooooo0024ooooo`;o0000
4_ooool00ol0003oooooooooo`05ooooo`;o00005?ooool00ol0003oooooooooo`0Cooooo`05oiRH
V?l@413o0000ob4Q8Oo<c<`01Oooool00omgMgOo0000ooooo`2?ooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-3.4116, -0.234311, \
0.0510397, 0.00762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.230769 0.0769231 0.103006 0.515028 [
[.07692 .09051 -6 -9 ]
[.07692 .09051 6 0 ]
[.38462 .09051 -3 -9 ]
[.38462 .09051 3 0 ]
[.53846 .09051 -3 -9 ]
[.53846 .09051 3 0 ]
[.69231 .09051 -3 -9 ]
[.69231 .09051 3 0 ]
[.84615 .09051 -3 -9 ]
[.84615 .09051 3 0 ]
[1 .09051 -6 -9 ]
[1 .09051 6 0 ]
[1.025 .10301 0 -6 ]
[1.025 .10301 10 6 ]
[.21827 0 -24 -4.5 ]
[.21827 0 0 4.5 ]
[.21827 .20601 -18 -4.5 ]
[.21827 .20601 0 4.5 ]
[.21827 .30902 -18 -4.5 ]
[.21827 .30902 0 4.5 ]
[.21827 .41202 -18 -4.5 ]
[.21827 .41202 0 4.5 ]
[.21827 .51503 -18 -4.5 ]
[.21827 .51503 0 4.5 ]
[.21827 .61803 -6 -4.5 ]
[.21827 .61803 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07692 .10301 m
.07692 .10926 L
s
[(-2)] .07692 .09051 0 1 Mshowa
.38462 .10301 m
.38462 .10926 L
s
[(2)] .38462 .09051 0 1 Mshowa
.53846 .10301 m
.53846 .10926 L
s
[(4)] .53846 .09051 0 1 Mshowa
.69231 .10301 m
.69231 .10926 L
s
[(6)] .69231 .09051 0 1 Mshowa
.84615 .10301 m
.84615 .10926 L
s
[(8)] .84615 .09051 0 1 Mshowa
1 .10301 m
1 .10926 L
s
[(10)] 1 .09051 0 1 Mshowa
.125 Mabswid
.11538 .10301 m
.11538 .10676 L
s
.15385 .10301 m
.15385 .10676 L
s
.19231 .10301 m
.19231 .10676 L
s
.26923 .10301 m
.26923 .10676 L
s
.30769 .10301 m
.30769 .10676 L
s
.34615 .10301 m
.34615 .10676 L
s
.42308 .10301 m
.42308 .10676 L
s
.46154 .10301 m
.46154 .10676 L
s
.5 .10301 m
.5 .10676 L
s
.57692 .10301 m
.57692 .10676 L
s
.61538 .10301 m
.61538 .10676 L
s
.65385 .10301 m
.65385 .10676 L
s
.73077 .10301 m
.73077 .10676 L
s
.76923 .10301 m
.76923 .10676 L
s
.80769 .10301 m
.80769 .10676 L
s
.88462 .10301 m
.88462 .10676 L
s
.92308 .10301 m
.92308 .10676 L
s
.96154 .10301 m
.96154 .10676 L
s
.03846 .10301 m
.03846 .10676 L
s
.25 Mabswid
0 .10301 m
1 .10301 L
s
gsave
1.025 .10301 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.23077 0 m
.23702 0 L
s
[(-0.2)] .21827 0 1 0 Mshowa
.23077 .20601 m
.23702 .20601 L
s
[(0.2)] .21827 .20601 1 0 Mshowa
.23077 .30902 m
.23702 .30902 L
s
[(0.4)] .21827 .30902 1 0 Mshowa
.23077 .41202 m
.23702 .41202 L
s
[(0.6)] .21827 .41202 1 0 Mshowa
.23077 .51503 m
.23702 .51503 L
s
[(0.8)] .21827 .51503 1 0 Mshowa
.23077 .61803 m
.23702 .61803 L
s
[(1)] .21827 .61803 1 0 Mshowa
.125 Mabswid
.23077 .02575 m
.23452 .02575 L
s
.23077 .0515 m
.23452 .0515 L
s
.23077 .07725 m
.23452 .07725 L
s
.23077 .12876 m
.23452 .12876 L
s
.23077 .15451 m
.23452 .15451 L
s
.23077 .18026 m
.23452 .18026 L
s
.23077 .23176 m
.23452 .23176 L
s
.23077 .25751 m
.23452 .25751 L
s
.23077 .28327 m
.23452 .28327 L
s
.23077 .33477 m
.23452 .33477 L
s
.23077 .36052 m
.23452 .36052 L
s
.23077 .38627 m
.23452 .38627 L
s
.23077 .43777 m
.23452 .43777 L
s
.23077 .46353 m
.23452 .46353 L
s
.23077 .48928 m
.23452 .48928 L
s
.23077 .54078 m
.23452 .54078 L
s
.23077 .56653 m
.23452 .56653 L
s
.23077 .59228 m
.23452 .59228 L
s
.25 Mabswid
.23077 0 m
.23077 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
123.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(25) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.79503 .10301 m
.79586 .10301 L
.7977 .10301 L
.79874 .10301 L
.79969 .10301 L
.80129 .10301 L
.80305 .10301 L
.80488 .10301 L
.8066 .10301 L
.80753 .10301 L
.80853 .10301 L
.81032 .10301 L
.81131 .10301 L
.81224 .10301 L
.81326 .10301 L
.81437 .10301 L
.81624 .10301 L
.81718 .10302 L
.81821 .10306 L
.82003 .10331 L
.82173 .10412 L
.82352 .10653 L
.82522 .11168 L
.82674 .12011 L
.8284 .1346 L
.8302 .15736 L
.8321 .18815 L
.83552 .24801 L
.83744 .27478 L
.8392 .29001 L
.84017 .29398 L
.84123 .29464 L
.84222 .29193 L
.84315 .2868 L
.84496 .27079 L
.84661 .25157 L
.85029 .20348 L
.85431 .15887 L
.85658 .14075 L
.85866 .12844 L
.86048 .12056 L
.86249 .11441 L
.8635 .1121 L
.86458 .1101 L
.86559 .10861 L
.86653 .10747 L
.86831 .10589 L
.86925 .10528 L
.87027 .10475 L
.87128 .10435 L
Mistroke
.87234 .10402 L
.87424 .10361 L
.876 .10338 L
.87764 .10324 L
.87944 .10315 L
.88136 .10309 L
.88245 .10306 L
.88345 .10305 L
.88454 .10304 L
.88571 .10303 L
.88672 .10302 L
.88766 .10302 L
.88869 .10301 L
.8898 .10301 L
.89079 .10301 L
.89186 .10301 L
.89287 .10301 L
.89381 .10301 L
.89558 .10301 L
.89747 .10301 L
.89927 .10301 L
.90092 .10301 L
.90273 .10301 L
.90464 .10301 L
.9063 .10301 L
.90785 .10301 L
.90956 .10301 L
.91138 .10301 L
.91241 .10301 L
.91336 .10301 L
.9144 .10301 L
.91551 .10301 L
.91737 .10301 L
.91843 .10301 L
.91942 .10301 L
.92126 .10301 L
.92295 .10301 L
.92388 .10301 L
.92489 .10301 L
.92674 .10301 L
.92768 .10301 L
.92867 .10301 L
.93045 .10301 L
.93237 .10301 L
.93346 .10301 L
.93447 .10301 L
.93631 .10301 L
.93799 .10301 L
.93891 .10301 L
.93992 .10301 L
Mistroke
.94175 .10301 L
.94338 .10301 L
.94518 .10301 L
.94706 .10301 L
.94882 .10301 L
.95047 .10301 L
.95197 .10301 L
.95362 .10301 L
.95536 .10301 L
.95727 .10301 L
.95901 .10301 L
.95998 .10301 L
.96102 .10301 L
.96291 .10301 L
.96469 .10301 L
.96656 .10301 L
.96817 .10301 L
.96993 .10301 L
.971 .10301 L
.97201 .10301 L
.9739 .10301 L
.97496 .10301 L
.97594 .10301 L
.97702 .10301 L
.97816 .10301 L
.97916 .10301 L
.98024 .10301 L
.98127 .10301 L
.9822 .10301 L
.98398 .10301 L
.98586 .10301 L
.98764 .10301 L
.98865 .10301 L
.98958 .10301 L
.99129 .10301 L
.9931 .10301 L
.99472 .10301 L
.99624 .10301 L
.9979 .10301 L
.99969 .10301 L
Mfstroke
.99969 .10301 m
1 .10301 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000oooooolLooooo`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0oooooolLooooo`00<?ooool6o`0000;o
oooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^0?oooooo7Oooool003So
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003ooooo
oa?ooooo000hooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05oooo
o`03o`000?oooooooooo0?oooooo4oooool003Sooooo00Go410@oooooooooooooooooa0@400?oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooo
oooo0?oooooo4oooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooo
oooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003ooooooooo
o`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000oooo
ooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`00
0?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool0
0ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o
0000ooooooooool0oooooolCooooo`008oooool5o`0002_ooooo00?o0000ooooooooool0:oooool5
o`0002kooooo0_l000000ol@413oooooooooo`0Zooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?oo
ool01Oo<c<co8B4Qo`000?lQ8B7oc<c<02Wooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`00
0?lb<S;ok^k^6_ooool002?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00[ooooo`03o`000?oooooo
oooo02_ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00_ooooo`03o`000?oooooooooo02_ooooo00Go
EEEEogMgMoooooooV9RHob4Q8@0/ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40:oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool001_ooooo1_l00003ooooo`03
oiRHV?lQ8B7ok^k^02cooooo00?o0000ooooooooool0;?ooool00onHV9So8B4Qonk^kP0]ooooo`Go
0000;?ooool01Ol0003ooooooooooooooooo000002cooooo00Go0000ooooooooooooooooo`00000[
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Jooooo`009Oooool0
0onHV9So8B4Qonk^kP0[ooooo`03o`000?oooooooooo02gooooo00?oV9RHob4Q8Oo^k^h0;?ooool0
1?m4A4CogMgMooooool0000]ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;?ooool01Olb<S;oV9RH
oooooonHV9So<S8b02_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
01[ooooo000Vooooo`03ogMgMomVIVKooooo02[ooooo0_l0000_ooooo`03ogMgMomVIVKooooo02_o
oooo00CogMgMoeEEEOoooooo0000;Oooool01Ol0003oEEEEo`000?l@413oc<c<02cooooo00Goc<c<
o`000?l0003o0000olc<c00[ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Jooooo`009oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool0:oooool00omgMgOoc<c<o`00000]ooooo`03oeEEEOn7QhOooooo02kooooo00Go
410@okZj^_oooooo^[Zjoa0@400[ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@400Jooooo`008oooool01Ol0003o^[ZjoooooonHV9So410@02_ooooo00?o0000oooooooo
ool0:oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo00?ok^k^odA4A?l00000;Oooool00ooM
gMgo410@oiRHV00^ooooo`05o`000?nj^[[ooooookZj^_l00000:oooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool002?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00[ooooo`03o`000?oooooooooo02_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00^ooooo`03ogMg
Mol0003ooooo02gooooo00Coc<c<odA4A?l0003o410@;?ooool01OnYZJWo410@o`000?l@413oZJVY
02Wooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo001Coooo
o`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00
Doooool00ol0003oooooooooo`3mooooo`;o00000_ooool2o`0000oooooo001Cooooo`03o`000?oo
oooooooo0?gooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd?ooooo`00Doooool00ol0003ooooo
ooooo`3nooooo`04omgMgOl0003o410@olc<c13ooooo000:oooooooo0000@?l0000;ooooo`04onk^
k_lQ8B7o410@onk^kQ3ooooo000Fooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00Co8B4QogMgMomgMgOo
<S8b4?ooool002;ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0^ooooo`03o`00
0?oooooooooo02kooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Wooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Xooooo`03o`00
0?oooooooooo00Sooooo0_l00002ooooo`;o00003oooool005?ooooo00?o0000ooooooooool0^_oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo04Wooooo001Cooooo`03o`000?oooooo
oooo0;_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`19ooooo`00Doooool00ol0
003oooooooooo`2kooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0BOooool005?o
oooo00?o0000ooooooooool0^oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo04Wo
oooo001Cooooo`03o`000?oooooooooo0;_ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`1:ooooo`00Doooool2o`000;cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`1:ooooo`00Doooool00ol0003oooooooooo`2kooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0B_ooool005?ooooo00?o0000ooooooooool0^oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo04[ooooo001Cooooo`03o`000?oooooooooo0;_ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`1;ooooo`00Doooool00ol0003oooooooooo`2kooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool0Boooool005?ooooo00?o0000ooooooooool0^ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04_ooooo001Cooooo`03o`000?oooooo
oooo0;cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1;ooooo`00Doooool00ol0
003oooooooooo`2looooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Boooool005?o
oooo0_l0002mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Boooool005?ooooo
00?o0000ooooooooool0_?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04_ooooo
001Cooooo`03o`000?oooooooooo0;cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`1;ooooo`00Doooool00ol0003oooooooooo`2looooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0Boooool005?ooooo00?o0000ooooooooool0_?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo04_ooooo001Cooooo`03o`000?oooooooooo0;cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`1;ooooo`00Doooool00ol0003oooooooooo`2looooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0C?ooool005?ooooo00?o0000ooooooooool0_Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04cooooo001Cooooo`;o0000__ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo04cooooo001Cooooo`03o`000?oooooooooo
0;gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1<ooooo`00Doooool00ol0003o
ooooooooo`2mooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0C?ooool005?ooooo
00?o0000ooooooooool0_Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04cooooo
001Cooooo`03o`000?oooooooooo0;gooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`1<ooooo`00Doooool00ol0003oooooooooo`2mooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool0COooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5
o`0000Kooooo00?o0000ooooooooool0_Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo04gooooo000hooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo0;gooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`1=ooooo`00>?ooool01Ol@413ooooooooooooooooo410@00cooooo00?o
V9RHob4Q8Oo^k^h01oooool3o`000;gooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`1=ooooo`00>?ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01_oo
ool00ol0003oooooooooo`2mooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0COoo
ool003Sooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Gooooo00?o
0000ooooooooool0_Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04gooooo000h
ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo0;gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1=ooooo`00>?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`00
0?oooooooooo0;gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`1=ooooo`00>?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03
o`000?oooooooooo0;kooooo00Go0000ooooooooooooooooo`00001?ooooo`00Doooool00ol0003o
ooooooooo`2nooooo`05o`000?ooooooooooooooool00000Coooool005?ooooo00?o0000oooooooo
ool0__ooool01Ol0003ooooooooooooooooo000004oooooo001Cooooo`03o`000?oooooooooo0;ko
oooo00Co0000oooooooooooo0000D?ooool005?ooooo0_l0002oooooo`04o`000?ooooooooooo`00
053ooooo001Cooooo`03o`000?oooooooooo0;kooooo00Co0000oooooooooooo0000D?ooool005?o
oooo00?o0000ooooooooool0__ooool01?l0003oooooooooool0001@ooooo`00Doooool00ol0003o
ooooooooo`2nooooo`04o`000?ooooooooooo`00053ooooo001Cooooo`03o`000?oooooooooo0;ko
oooo00Co0000oooooooooooo0000D?ooool005?ooooo00?o0000ooooooooool0__ooool01?l0003o
ooooooooool0001@ooooo`00Doooool00ol0003oooooooooo`2nooooo`04o`000?ooooooooooo`00
053ooooo001Cooooo`03o`000?oooooooooo0;kooooo00Co0000oooooooooooo0000D?ooool005?o
oooo0_l0002oooooo`04o`000?ooooooooooo`00053ooooo001Cooooo`03o`000?oooooooooo0;ko
oooo00Co0000oooooooooooo0000D?ooool005?ooooo00?o0000ooooooooool0__ooool01?l0003o
ooooooooool0001@ooooo`00Doooool00ol0003oooooooooo`2nooooo`04o`000?ooooooooooo`00
053ooooo001Cooooo`03o`000?oooooooooo0;kooooo00Co0000oooooooooooo0000D?ooool005?o
oooo00?o0000ooooooooool0__ooool01?l0003oooooooooool0001@ooooo`00Doooool00ol0003o
ooooooooo`2nooooo`04o`000?ooooooooooo`00053ooooo001Cooooo`03o`000?oooooooooo0;ko
oooo00?o0000ooooool00000DOooool005?ooooo0_l00030ooooo`;o0000DOooool005?ooooo00?o
0000ooooooooool0_oooool2o`00057ooooo001Cooooo`03o`000?oooooooooo0;oooooo0_l0001A
ooooo`00Doooool00ol0003oooooooooo`2oooooo`;o0000DOooool005?ooooo00?o0000oooooooo
ool0_oooool00ol0003oooooooooo`1@ooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo
000hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413ooooo
ooooo`04ooooo`03o`000?oooooooooo0?oooooo4oooool003Sooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo
4oooool003Sooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00001_ooool3o`000?oooooo
4oooool003Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Oo
oooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01Ol0003ooooooooooooooooo000000_o
oooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`3ooooooa?ooooo000hooooo`05
oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo
0?oooooo4oooool003Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co0000
00Oooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00gooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03
o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Dooo
ool2o`000?oooooo5?ooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0
003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo
00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001C
ooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCoooo
o`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Dooo
ool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool0
05?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?o
oooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooo
oolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDoooo
o`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo
4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3o
oooooa?ooooo000hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^
oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo0?oooooo4oooool003Sooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo
00?o0000ooooooooool0oooooolCooooo`00>?ooool01Ol@413ooooooooooooooooo410@00_ooooo
00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo4oooool003Sooooo
00Go0000ooooooooooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`00
0?oooooo4oooool003Sooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000
oa0@4?o<c<`01_ooool00ol0003oooooooooo`3ooooooa?ooooo000hooooo`05oa0@4?oooooooooo
ooooool@41002oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo0?oooooo4oooool0
03Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000
ooooooooool0oooooolCooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<
odA4A?l0003o410@1_ooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooo
oooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003ooooooooo
o`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000oooo
ooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`00
0?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool0
0ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o
0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Coooo
o`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00
Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4ooo
ool005?ooooo0_l0003ooooooaCooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?o
oooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo
001Cooooo`03o`000?oooooooooo0?oooooo4oooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0
oooooolCooooo`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q
8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`3ooooooa?ooooo000hooooo`05oa0@
4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooo
ooooool0oooooolCooooo`00>?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRH
V?ooooooV9RHoc8b<P06ooooo`?o0000oooooolCooooo`00>?ooool01Ol0003ooooooooooooooooo
000000_ooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo0?oooooo4ooo
ool003Sooooo00Go410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@4100
1_ooool00ol0003oooooooooo`3ooooooa?ooooo000hooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
2oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool0oooooolCooooo`00
>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06oooo
o`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00
Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4ooo
ool005?ooooo0_l0003ooooooaCooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?o
oooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo
001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolC
ooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oo
oooo4oooool005?ooooo0_l0003ooooooaCooooo001Cooooo`03o`000?oooooooooo0?oooooo4ooo
ool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooo
oa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0
oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooo
oooo0?oooooo4oooool005?ooooo0_l0003ooooooaCooooo001Cooooo`03o`000?oooooooooo0?oo
oooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003ooooooooo
o`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000oooo
ooooool0oooooolCooooo`00BOooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000oooooooo
ool0oooooolCooooo`00Boooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo
4oooool004_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooooa?ooooo001;
ooooo`03o`000?oooooooooo00Gooooo0ol0003ooooooa?ooooo001;ooooo`03o`000?oooooooooo
0?oooooo6oooool004_ooooo00?o0000ooooooooool0oooooolKooooo`00Boooool00ol0003ooooo
ooooo`3ooooooa_ooooo0019ooooo`03oeEEEOmVIVKo00000?oooooo7Oooool007Sooooo0ol00000
0ol@413oooooooooo`3Zooooo`00N_ooool00ol@413o^[Zjooooo`07ooooo`;o00002oooool00ol0
003o^[Zjooooo`0<ooooo`;o00001Oooool00ol0003o^[Zjooooo`2nooooo`00N_ooool00onHV9So
<S8booooo`07ooooo`03o`000?oooooooooo00[ooooo0_lb<S8>ooooo`03o`000?oooooooooo00?o
oooo0_lb<S:oooooo`00N_ooool00ooMgMgo0000okZj^P07ooooo`04o`000?ooooooooooooooo`;o
00000_ooool2o`0000?ooooo00?oQhN7o`000?nj^[X01?ooool01OnHV9So0000o`000?m4A4Co^[Zj
00Cooooo00?o0000ooooooooool00oooool00on7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000
odA4A?nj^[X04Oooool5o`0000Cooooo00GoA4A4o`000?l0003o<S8bomgMg@2>ooooo`00N_ooool0
0omEEEGoMgMgodA4A007ooooo`0:o`000?ooooooooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgM
g@?ooooo00?oc<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo00?o0000
ooooooooool00oooool00oo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Ooo
ool6o`0000;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A007ooooo`03ogMgMolb<S;ooooo08gooooo
001iooooo`05omgMgOl@413oooooob4Q8OoMgMd01_ooool00ol0003oooooooooo`02ooooo`04omgM
gOl0003o410@olc<c0_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo01Cooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`2<ooooo`00
NOooool01OmVIVKoQhN7oooooonHV9SoEEEE00Kooooo00?o0000ooooooooool00_ooool01?o^k^ko
8B4Qoa0@4?o^k^h;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0;ooooo`Ko00001?ooool00onHV9So8B4Qonk^kP07ooooo`03ogMgMolb<S;ooooo
08gooooo001hooooo`03onk^k_l0003ok^k^00;ooooo00?o0000omgMgOooool01?ooool00ol0003o
ooooooooo`02ooooo`04ob4Q8OmgMgOoMgMgoc8b<P_ooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo01Kooooo00?oMgMgofIVI_ooool00oooool01Ol0
003o8B4Qo`000?lb<S;oc<c<08kooooo001hooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@
ooooooooool00oooool01?l0003oooooooooooooool2o`0000;ooooo0_l00008ooooo`03oa0@4?l0
003o000000?o00001Oooool00ol0003oooooooooo`0@ooooo`03oa0@4?l0003o000000?o00005_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo093ooooo0024ooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo01?ooooo00Go0000okZj^_ooooooV9RHoa0@4004ooooo`03o`000?oooooooooo093ooooo0024
ooooo`;o00004_ooool00ol0003oooooooooo`05ooooo`;o00005?ooool00ol0003oooooooooo`0C
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01?ooool4o`0008oooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-3.4116, -0.234311, \
0.0510397, 0.00762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.230769 0.0769231 0.103006 0.515028 [
[.07692 .09051 -6 -9 ]
[.07692 .09051 6 0 ]
[.38462 .09051 -3 -9 ]
[.38462 .09051 3 0 ]
[.53846 .09051 -3 -9 ]
[.53846 .09051 3 0 ]
[.69231 .09051 -3 -9 ]
[.69231 .09051 3 0 ]
[.84615 .09051 -3 -9 ]
[.84615 .09051 3 0 ]
[1 .09051 -6 -9 ]
[1 .09051 6 0 ]
[1.025 .10301 0 -6 ]
[1.025 .10301 10 6 ]
[.21827 0 -24 -4.5 ]
[.21827 0 0 4.5 ]
[.21827 .20601 -18 -4.5 ]
[.21827 .20601 0 4.5 ]
[.21827 .30902 -18 -4.5 ]
[.21827 .30902 0 4.5 ]
[.21827 .41202 -18 -4.5 ]
[.21827 .41202 0 4.5 ]
[.21827 .51503 -18 -4.5 ]
[.21827 .51503 0 4.5 ]
[.21827 .61803 -6 -4.5 ]
[.21827 .61803 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07692 .10301 m
.07692 .10926 L
s
[(-2)] .07692 .09051 0 1 Mshowa
.38462 .10301 m
.38462 .10926 L
s
[(2)] .38462 .09051 0 1 Mshowa
.53846 .10301 m
.53846 .10926 L
s
[(4)] .53846 .09051 0 1 Mshowa
.69231 .10301 m
.69231 .10926 L
s
[(6)] .69231 .09051 0 1 Mshowa
.84615 .10301 m
.84615 .10926 L
s
[(8)] .84615 .09051 0 1 Mshowa
1 .10301 m
1 .10926 L
s
[(10)] 1 .09051 0 1 Mshowa
.125 Mabswid
.11538 .10301 m
.11538 .10676 L
s
.15385 .10301 m
.15385 .10676 L
s
.19231 .10301 m
.19231 .10676 L
s
.26923 .10301 m
.26923 .10676 L
s
.30769 .10301 m
.30769 .10676 L
s
.34615 .10301 m
.34615 .10676 L
s
.42308 .10301 m
.42308 .10676 L
s
.46154 .10301 m
.46154 .10676 L
s
.5 .10301 m
.5 .10676 L
s
.57692 .10301 m
.57692 .10676 L
s
.61538 .10301 m
.61538 .10676 L
s
.65385 .10301 m
.65385 .10676 L
s
.73077 .10301 m
.73077 .10676 L
s
.76923 .10301 m
.76923 .10676 L
s
.80769 .10301 m
.80769 .10676 L
s
.88462 .10301 m
.88462 .10676 L
s
.92308 .10301 m
.92308 .10676 L
s
.96154 .10301 m
.96154 .10676 L
s
.03846 .10301 m
.03846 .10676 L
s
.25 Mabswid
0 .10301 m
1 .10301 L
s
gsave
1.025 .10301 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.23077 0 m
.23702 0 L
s
[(-0.2)] .21827 0 1 0 Mshowa
.23077 .20601 m
.23702 .20601 L
s
[(0.2)] .21827 .20601 1 0 Mshowa
.23077 .30902 m
.23702 .30902 L
s
[(0.4)] .21827 .30902 1 0 Mshowa
.23077 .41202 m
.23702 .41202 L
s
[(0.6)] .21827 .41202 1 0 Mshowa
.23077 .51503 m
.23702 .51503 L
s
[(0.8)] .21827 .51503 1 0 Mshowa
.23077 .61803 m
.23702 .61803 L
s
[(1)] .21827 .61803 1 0 Mshowa
.125 Mabswid
.23077 .02575 m
.23452 .02575 L
s
.23077 .0515 m
.23452 .0515 L
s
.23077 .07725 m
.23452 .07725 L
s
.23077 .12876 m
.23452 .12876 L
s
.23077 .15451 m
.23452 .15451 L
s
.23077 .18026 m
.23452 .18026 L
s
.23077 .23176 m
.23452 .23176 L
s
.23077 .25751 m
.23452 .25751 L
s
.23077 .28327 m
.23452 .28327 L
s
.23077 .33477 m
.23452 .33477 L
s
.23077 .36052 m
.23452 .36052 L
s
.23077 .38627 m
.23452 .38627 L
s
.23077 .43777 m
.23452 .43777 L
s
.23077 .46353 m
.23452 .46353 L
s
.23077 .48928 m
.23452 .48928 L
s
.23077 .54078 m
.23452 .54078 L
s
.23077 .56653 m
.23452 .56653 L
s
.23077 .59228 m
.23452 .59228 L
s
.25 Mabswid
.23077 0 m
.23077 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
123.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(26) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.80753 .10301 m
.80854 .10301 L
.81037 .10301 L
.81215 .10301 L
.81379 .10301 L
.81557 .10301 L
.81657 .10301 L
.81752 .10301 L
.81942 .10301 L
.82048 .10301 L
.82146 .10301 L
.82322 .10301 L
.82485 .10301 L
.82664 .10301 L
.82854 .10303 L
.83019 .10313 L
.83173 .10349 L
.83342 .10471 L
.83525 .10826 L
.8362 .11168 L
.83722 .11701 L
.83905 .13209 L
.84017 .14521 L
.84122 .16022 L
.8432 .19363 L
.84515 .22908 L
.84722 .26224 L
.84829 .27548 L
.84948 .2857 L
.85056 .29065 L
.85157 .29149 L
.85249 .28918 L
.8535 .28364 L
.85534 .26697 L
.85878 .22321 L
.86277 .17326 L
.86473 .15393 L
.86653 .13978 L
.86831 .12898 L
.87019 .12055 L
.87208 .11457 L
.87315 .11204 L
.87414 .11014 L
.87589 .10767 L
.87747 .10613 L
.87931 .10494 L
.88104 .10422 L
.88291 .10373 L
.88385 .10356 L
.88489 .10342 L
Mistroke
.88672 .10325 L
.88844 .10315 L
.88943 .10311 L
.89046 .10309 L
.89232 .10305 L
.89335 .10304 L
.89431 .10303 L
.89536 .10302 L
.89649 .10302 L
.89836 .10301 L
.90008 .10301 L
.90198 .10301 L
.90293 .10301 L
.90398 .10301 L
.90574 .10301 L
.90763 .10301 L
.90942 .10301 L
.91105 .10301 L
.91273 .10301 L
.91429 .10301 L
.91601 .10301 L
.91783 .10301 L
.9194 .10301 L
.92088 .10301 L
.92251 .10301 L
.92426 .10301 L
.92608 .10301 L
.92774 .10301 L
.92965 .10301 L
.93145 .10301 L
.93312 .10301 L
.93467 .10301 L
.93636 .10301 L
.93815 .10301 L
.93995 .10301 L
.94097 .10301 L
.94189 .10301 L
.94369 .10301 L
.94539 .10301 L
.94635 .10301 L
.94737 .10301 L
.9492 .10301 L
.95033 .10301 L
.95138 .10301 L
.95233 .10301 L
.95336 .10301 L
.95528 .10301 L
.95707 .10301 L
.95809 .10301 L
.95903 .10301 L
Mistroke
.96011 .10301 L
.96113 .10301 L
.96212 .10301 L
.96317 .10301 L
.96506 .10301 L
.96611 .10301 L
.96709 .10301 L
.96817 .10301 L
.96934 .10301 L
.97112 .10301 L
.97213 .10301 L
.97307 .10301 L
.97497 .10301 L
.97603 .10301 L
.977 .10301 L
.97873 .10301 L
.98061 .10301 L
.98239 .10301 L
.98402 .10301 L
.98585 .10301 L
.98758 .10301 L
.98913 .10301 L
.99083 .10301 L
.99266 .10301 L
.99369 .10301 L
.99462 .10301 L
.99643 .10301 L
.99813 .10301 L
.99974 .10301 L
Mfstroke
.99974 .10301 m
1 .10301 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000oooooolLooooo`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0oooooolLooooo`00<?ooool6o`0000;o
oooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^0?oooooo7Oooool003So
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003ooooo
oa?ooooo000hooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05oooo
o`03o`000?oooooooooo0?oooooo4oooool003Sooooo00Go410@oooooooooooooooooa0@400?oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooo
oooo0?oooooo4oooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooo
oooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003ooooooooo
o`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000oooo
ooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`00
0?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool0
0ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o
0000ooooooooool0oooooolCooooo`008oooool5o`0002_ooooo00?o0000ooooooooool0:oooool5
o`0002kooooo0_l000000ol@413oooooooooo`0Zooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?oo
ool01Oo<c<co8B4Qo`000?lQ8B7oc<c<02Wooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`00
0?lb<S;ok^k^6_ooool002?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00[ooooo`03o`000?oooooo
oooo02_ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00_ooooo`03o`000?oooooooooo02_ooooo00Go
EEEEogMgMoooooooV9RHob4Q8@0/ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40:oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool001_ooooo1_l00003ooooo`03
oiRHV?lQ8B7ok^k^02cooooo00?o0000ooooooooool0;?ooool00onHV9So8B4Qonk^kP0]ooooo`Go
0000;?ooool01Ol0003ooooooooooooooooo000002cooooo00Go0000ooooooooooooooooo`00000[
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Jooooo`009Oooool0
0onHV9So8B4Qonk^kP0[ooooo`03o`000?oooooooooo02gooooo00?oV9RHob4Q8Oo^k^h0;?ooool0
1?m4A4CogMgMooooool0000]ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;?ooool01Olb<S;oV9RH
oooooonHV9So<S8b02_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
01[ooooo000Vooooo`03ogMgMomVIVKooooo02[ooooo0_l0000_ooooo`03ogMgMomVIVKooooo02_o
oooo00CogMgMoeEEEOoooooo0000;Oooool01Ol0003oEEEEo`000?l@413oc<c<02cooooo00Goc<c<
o`000?l0003o0000olc<c00[ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Jooooo`009oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool0:oooool00omgMgOoc<c<o`00000]ooooo`03oeEEEOn7QhOooooo02kooooo00Go
410@okZj^_oooooo^[Zjoa0@400[ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@400Jooooo`008oooool01Ol0003o^[ZjoooooonHV9So410@02_ooooo00?o0000oooooooo
ool0:oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo00?ok^k^odA4A?l00000;Oooool00ooM
gMgo410@oiRHV00^ooooo`05o`000?nj^[[ooooookZj^_l00000:oooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool002?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00[ooooo`03o`000?oooooooooo02_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00^ooooo`03ogMg
Mol0003ooooo02gooooo00Coc<c<odA4A?l0003o410@;?ooool01OnYZJWo410@o`000?l@413oZJVY
02Wooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo001Coooo
o`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00
Doooool00ol0003oooooooooo`3mooooo`;o00000_ooool2o`0000oooooo001Cooooo`03o`000?oo
oooooooo0?gooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd?ooooo`00Doooool00ol0003ooooo
ooooo`3nooooo`04omgMgOl0003o410@olc<c13ooooo000:oooooooo0000@?l0000;ooooo`04onk^
k_lQ8B7o410@onk^kQ3ooooo000Fooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`06ooooo`04o`000?ooooooooooo`0000Sooooo0_l000000ooooooo
0000ooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`09ooooo`04ob4Q8OmgMgOoMgMgoc8b<Q3ooooo000Rooooo`03o`000?oooooooooo02ko
oooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02ko
oooo00?o0000ooooooooool0:oooool01?l0003oooooooooool00008ooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool02?ooool2o`0000;ooooo0_l0000?ooooo`00Doooool00ol0003o
ooooooooo`2nooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0A_ooool005?ooooo
00?o0000ooooooooool0__ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo04Kooooo
001Cooooo`03o`000?oooooooooo0;kooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`16ooooo`00Doooool00ol0003oooooooooo`2nooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool0A_ooool005?ooooo00?o0000ooooooooool0_oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo04Oooooo001Cooooo`;o0000`?ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo04Oooooo001Cooooo`03o`000?oooooooooo0;oooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`17ooooo`00Doooool00ol0003oooooooooo`2oooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0B?ooool005?ooooo00?o0000ooooooooool0_oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo04Sooooo001Cooooo`03o`000?oooooooooo
0;oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`18ooooo`00Doooool00ol0003o
ooooooooo`2oooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0B?ooool005?ooooo
00?o0000ooooooooool0_oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo04Sooooo
001Cooooo`03o`000?oooooooooo0;oooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`18ooooo`00Doooool2o`000<3ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`18
ooooo`00Doooool00ol0003oooooooooo`2oooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0B?ooool005?ooooo00?o0000ooooooooool0_oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo04Sooooo001Cooooo`03o`000?oooooooooo0;oooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`18ooooo`00Doooool00ol0003oooooooooo`2oooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0BOooool005?ooooo00?o0000ooooooooool0_oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo04Wooooo001Cooooo`03o`000?oooooooooo
0;oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`19ooooo`00Doooool00ol0003o
ooooooooo`2oooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0BOooool005?ooooo
0_l00031ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0BOooool005?ooooo00?o
0000ooooooooool0`?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04Wooooo001C
ooooo`03o`000?oooooooooo0<3ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`19
ooooo`00Doooool00ol0003oooooooooo`30ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0BOooool005?ooooo00?o0000ooooooooool0`?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo04Wooooo001Cooooo`03o`000?oooooooooo0<3ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`19ooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`30ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0BOooool003Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0`?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo04[ooooo000hooooo`05oa0@4?ooooooooooooooool@
41003?ooool00onHV9So8B4Qonk^kP07ooooo`?o0000`?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo04[ooooo000hooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So
8B4Qonk^kP06ooooo`03o`000?oooooooooo0<3ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`1:ooooo`00>?ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_oo
ool01Oooool00ol0003oooooooooo`30ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0B_ooool003Sooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0`Oooool01Ol0003ooooooooooooooooo000004cooooo000hooooo`05
ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000
ooooooooool0`Oooool01Ol0003ooooooooooooooooo000004cooooo000hooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0
`Oooool01Ol0003ooooooooooooooooo000004cooooo001Cooooo`03o`000?oooooooooo0<7ooooo
00Go0000ooooooooooooooooo`00001<ooooo`00Doooool00ol0003oooooooooo`31ooooo`05o`00
0?ooooooooooooooool00000C?ooool005?ooooo00?o0000ooooooooool0`Oooool01Ol0003ooooo
oooooooooooo000004cooooo001Cooooo`;o0000`_ooool01Ol0003ooooooooooooooooo000004co
oooo001Cooooo`03o`000?oooooooooo0<7ooooo00Go0000ooooooooooooooooo`00001<ooooo`00
Doooool00ol0003oooooooooo`31ooooo`05o`000?ooooooooooooooool00000C?ooool005?ooooo
00?o0000ooooooooool0`Oooool01Ol0003ooooooooooooooooo000004cooooo001Cooooo`03o`00
0?oooooooooo0<7ooooo00Go0000ooooooooooooooooo`00001<ooooo`00Doooool00ol0003ooooo
ooooo`31ooooo`04o`000?ooooooooooo`0004gooooo001Cooooo`03o`000?oooooooooo0<7ooooo
00Co0000oooooooooooo0000COooool005?ooooo00?o0000ooooooooool0`Oooool01?l0003ooooo
ooooool0001=ooooo`00Doooool2o`000<;ooooo00Co0000oooooooooooo0000COooool005?ooooo
00?o0000ooooooooool0`Oooool01?l0003oooooooooool0001=ooooo`00Doooool00ol0003ooooo
ooooo`31ooooo`04o`000?ooooooooooo`0004gooooo001Cooooo`03o`000?oooooooooo0<7ooooo
00Co0000oooooooooooo0000COooool005?ooooo00?o0000ooooooooool0`_ooool00ol0003ooooo
o`00001=ooooo`00Doooool00ol0003oooooooooo`32ooooo`03o`000?oooooo000004gooooo001C
ooooo`03o`000?oooooooooo0<;ooooo0_l0001>ooooo`00Doooool00ol0003oooooooooo`32oooo
o`;o0000C_ooool005?ooooo0_l00033ooooo`;o0000C_ooool005?ooooo00?o0000ooooooooool0
`_ooool2o`0004kooooo001Cooooo`03o`000?oooooooooo0<;ooooo0_l0001>ooooo`00Doooool0
0ol0003oooooooooo`33ooooo`03o`000?oooooooooo04cooooo001Cooooo`03o`000?oooooooooo
0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@ooooooooool01?ooool00ol0003o
ooooooooo`3ooooooa?ooooo000hooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooooa?ooooo000hooooo`05oa0@
4?ooooooooooooooool@41002oooool5o`0000Kooooo0ol0003ooooooa?ooooo000hooooo`05o`00
0?ooooooooooooooool000002oooool01?m4A4CogMgMooooool00007ooooo`03o`000?oooooooooo
0?oooooo4oooool003Sooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGooooo
o`0000Oooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01Ol@413ooooooooooooooooo
410@00cooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`3ooooooa?ooooo000hoooo
o`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooo
oooo0?oooooo4oooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003o
oooo00Kooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooo
oa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo0_l0003ooooooaCooooo
001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolC
ooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oo
oooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003ooooooooo
o`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000oooo
ooooool0oooooolCooooo`00Doooool2o`000?oooooo5?ooool005?ooooo00?o0000ooooooooool0
oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooo
oooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o
0000ooooooooool0oooooolCooooo`00Doooool2o`000?oooooo5?ooool005?ooooo00?o0000oooo
ooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`00
0?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0
1_ooool00ol0003oooooooooo`3ooooooa?ooooo000hooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?oo
oooo4oooool003Sooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?oooooooooooooo
ool000001_ooool00ol0003oooooooooo`3ooooooa?ooooo000hooooo`05o`000?oooooooooooooo
ool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0003ooooooa?ooooo000hoooo
o`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o
0000ooooooooool0oooooolCooooo`00>?ooool01Ol@413ooooooooooooooooo410@00_ooooo00?o
EEEEohN7Qoooool02?ooool00ol0003oooooooooo`3ooooooa?ooooo000hooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo0?oooooo4ooo
ool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo
00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001C
ooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCoooo
o`00Doooool2o`000?oooooo5?ooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Dooo
ool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool0
05?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?o
oooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooo
oolCooooo`00Doooool2o`000?oooooo5?ooool005?ooooo00?o0000ooooooooool0oooooolCoooo
o`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo
4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3o
oooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000oooooooo
ool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooo
oolDooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo
0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003ooooo
ooooo`3ooooooa?ooooo000hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo
00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0?oooooo4oooool003Sooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q
00Kooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01Ol@413ooooooooooooooooo410@
00_ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo4oooool0
03Sooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_oo
ool3o`000?oooooo4oooool003Sooooo00Go0000ooooooooooooooooo`00000;ooooo`05olc<c?l0
003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`3ooooooa?ooooo000hooooo`05oa0@4?oo
ooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000oooooooo
ool0oooooolCooooo`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_oo
oooo^[Zjo`000006ooooo`03o`000?oooooooooo0?oooooo4oooool003Sooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`3o
oooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000oooooooo
ool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooo
oolDooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo
0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003ooooo
ooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000
ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o
0000oooooolDooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oo
oooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0
003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo
00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001C
ooooo`;o0000oooooolDooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03
o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Dooo
ool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool0
04Wooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo0?oooooo4oooool004_o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooooa?ooooo001;ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0oooooolCooooo`00Boooool00ol0003ooooooooo
o`05ooooo`?o0000oooooolCooooo`00Boooool00ol0003oooooooooo`3ooooooa_ooooo001;oooo
o`03o`000?oooooooooo0?oooooo6oooool004_ooooo00?o0000ooooooooool0oooooolKooooo`00
BOooool00omEEEGoIVIVo`00003ooooooagooooo001hooooo`?o000000?o410@ooooooooool0j_oo
ool007[ooooo00?o410@okZj^_ooool01oooool2o`0000_ooooo00?o0000okZj^_ooool03?ooool2
o`0000Gooooo00?o0000okZj^_ooool0__ooool007[ooooo00?oV9RHoc8b<_ooool01oooool00ol0
003oooooooooo`0:ooooo`;o<S8b3_ooool00ol0003oooooooooo`03ooooo`;o<S8b_oooool007[o
oooo00?ogMgMo`000?nj^[X01oooool01?l0003oooooooooooooool2o`0000;ooooo0_l00003oooo
o`03ohN7Qol0003o^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4okZj^P04ooooo`03o`000?oooooo
oooo00?ooooo00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4A4Co^[Zj017ooooo1Ol0
0003ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0Soooool007[ooooo00?oEEEEogMgMom4A4@01ooo
ool02_l0003oooooooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oMgMd3ooooo`03olc<c?l0003o
410@00Cooooo00Go410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oooooooooo00?ooooo00?o
c<c<o`000?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l00002ooooo`05oiRH
V?lQ8B7ok^k^oooooom4A4@00oooool01OmEEEGoMgMgoooooonHV9So8B4Q08oooooo001iooooo`05
omgMgOl@413oooooob4Q8OoMgMd01_ooool00ol0003oooooooooo`02ooooo`04omgMgOl0003o410@
olc<c0_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo01Cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol0003ooooooooooooooooo000008oooooo001i
ooooo`05ofIVI_n7QhOooooooiRHV?mEEED01_ooool00ol0003oooooooooo`02ooooo`04onk^k_lQ
8B7o410@onk^kP_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo00_ooooo1_l00004ooooo`03oiRHV?lQ8B7ok^k^00?ooooo00Go0000oiRHV?oooooo
V9RHob4Q8@2?ooooo`00N?ooool00oo^k^ko0000onk^kP02ooooo`03o`000?oMgMgooooo00Cooooo
00?o0000ooooooooool00_ooool01?lQ8B7oMgMgogMgMolb<S8;ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Fooooo`03ogMgMomVIVKooooo00;o
oooo00Go0000oeEEEOl0003o410@olc<c02?ooooo`00N?ooool01?l@413o0000o`000?ooool2o`00
0003oa0@4?oooooooooo00?ooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00002?ooool0
0ol@413o0000o`000003o`0000Gooooo00?o0000ooooooooool04?ooool00ol@413o0000o`000003
o`0001Kooooo00Ko0000oooooooooooooooooeEEEOn7QhNBooooo`00Q?ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0Cooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool00ooMgMgo410@oiRHV02Aooooo`00Q?oo
ool2o`0001;ooooo00?o0000ooooooooool01Oooool2o`0001Cooooo00?o0000ooooooooool04ooo
ool01OnHV9So410@o`000?lQ8B7oc<c<00Cooooo00Coc<c<odA4A?l0003o410@Soooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-3.4116, -0.234311, \
0.0510397, 0.00762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.230769 0.0769231 0.103006 0.515028 [
[.07692 .09051 -6 -9 ]
[.07692 .09051 6 0 ]
[.38462 .09051 -3 -9 ]
[.38462 .09051 3 0 ]
[.53846 .09051 -3 -9 ]
[.53846 .09051 3 0 ]
[.69231 .09051 -3 -9 ]
[.69231 .09051 3 0 ]
[.84615 .09051 -3 -9 ]
[.84615 .09051 3 0 ]
[1 .09051 -6 -9 ]
[1 .09051 6 0 ]
[1.025 .10301 0 -6 ]
[1.025 .10301 10 6 ]
[.21827 0 -24 -4.5 ]
[.21827 0 0 4.5 ]
[.21827 .20601 -18 -4.5 ]
[.21827 .20601 0 4.5 ]
[.21827 .30902 -18 -4.5 ]
[.21827 .30902 0 4.5 ]
[.21827 .41202 -18 -4.5 ]
[.21827 .41202 0 4.5 ]
[.21827 .51503 -18 -4.5 ]
[.21827 .51503 0 4.5 ]
[.21827 .61803 -6 -4.5 ]
[.21827 .61803 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07692 .10301 m
.07692 .10926 L
s
[(-2)] .07692 .09051 0 1 Mshowa
.38462 .10301 m
.38462 .10926 L
s
[(2)] .38462 .09051 0 1 Mshowa
.53846 .10301 m
.53846 .10926 L
s
[(4)] .53846 .09051 0 1 Mshowa
.69231 .10301 m
.69231 .10926 L
s
[(6)] .69231 .09051 0 1 Mshowa
.84615 .10301 m
.84615 .10926 L
s
[(8)] .84615 .09051 0 1 Mshowa
1 .10301 m
1 .10926 L
s
[(10)] 1 .09051 0 1 Mshowa
.125 Mabswid
.11538 .10301 m
.11538 .10676 L
s
.15385 .10301 m
.15385 .10676 L
s
.19231 .10301 m
.19231 .10676 L
s
.26923 .10301 m
.26923 .10676 L
s
.30769 .10301 m
.30769 .10676 L
s
.34615 .10301 m
.34615 .10676 L
s
.42308 .10301 m
.42308 .10676 L
s
.46154 .10301 m
.46154 .10676 L
s
.5 .10301 m
.5 .10676 L
s
.57692 .10301 m
.57692 .10676 L
s
.61538 .10301 m
.61538 .10676 L
s
.65385 .10301 m
.65385 .10676 L
s
.73077 .10301 m
.73077 .10676 L
s
.76923 .10301 m
.76923 .10676 L
s
.80769 .10301 m
.80769 .10676 L
s
.88462 .10301 m
.88462 .10676 L
s
.92308 .10301 m
.92308 .10676 L
s
.96154 .10301 m
.96154 .10676 L
s
.03846 .10301 m
.03846 .10676 L
s
.25 Mabswid
0 .10301 m
1 .10301 L
s
gsave
1.025 .10301 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.23077 0 m
.23702 0 L
s
[(-0.2)] .21827 0 1 0 Mshowa
.23077 .20601 m
.23702 .20601 L
s
[(0.2)] .21827 .20601 1 0 Mshowa
.23077 .30902 m
.23702 .30902 L
s
[(0.4)] .21827 .30902 1 0 Mshowa
.23077 .41202 m
.23702 .41202 L
s
[(0.6)] .21827 .41202 1 0 Mshowa
.23077 .51503 m
.23702 .51503 L
s
[(0.8)] .21827 .51503 1 0 Mshowa
.23077 .61803 m
.23702 .61803 L
s
[(1)] .21827 .61803 1 0 Mshowa
.125 Mabswid
.23077 .02575 m
.23452 .02575 L
s
.23077 .0515 m
.23452 .0515 L
s
.23077 .07725 m
.23452 .07725 L
s
.23077 .12876 m
.23452 .12876 L
s
.23077 .15451 m
.23452 .15451 L
s
.23077 .18026 m
.23452 .18026 L
s
.23077 .23176 m
.23452 .23176 L
s
.23077 .25751 m
.23452 .25751 L
s
.23077 .28327 m
.23452 .28327 L
s
.23077 .33477 m
.23452 .33477 L
s
.23077 .36052 m
.23452 .36052 L
s
.23077 .38627 m
.23452 .38627 L
s
.23077 .43777 m
.23452 .43777 L
s
.23077 .46353 m
.23452 .46353 L
s
.23077 .48928 m
.23452 .48928 L
s
.23077 .54078 m
.23452 .54078 L
s
.23077 .56653 m
.23452 .56653 L
s
.23077 .59228 m
.23452 .59228 L
s
.25 Mabswid
.23077 0 m
.23077 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
123.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(27) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.81969 .10301 m
.82146 .10301 L
.82313 .10301 L
.82491 .10301 L
.82642 .10301 L
.82808 .10301 L
.82987 .10301 L
.83179 .10301 L
.8336 .10301 L
.83525 .10301 L
.83617 .10301 L
.83719 .10301 L
.83825 .10301 L
.83925 .10302 L
.84103 .10314 L
.84294 .10372 L
.84396 .10454 L
.84507 .10623 L
.84623 .1094 L
.84731 .11418 L
.84832 .12076 L
.84925 .1288 L
.85031 .14071 L
.85131 .15453 L
.85486 .21672 L
.8568 .25041 L
.85862 .27426 L
.85956 .28238 L
.86058 .28738 L
.8617 .28836 L
.86273 .28527 L
.86367 .27955 L
.86468 .27065 L
.86653 .2493 L
.87012 .20094 L
.87201 .17748 L
.87401 .15656 L
.87575 .14187 L
.87767 .12954 L
.87941 .12129 L
.88104 .11568 L
.88209 .1129 L
.88309 .11079 L
.88495 .10789 L
.886 .10674 L
.88696 .1059 L
.88802 .10519 L
.88915 .10461 L
.89095 .10397 L
.89264 .1036 L
Mistroke
.89449 .10335 L
.89553 .10326 L
.89649 .1032 L
.89811 .10312 L
.89984 .10307 L
.90147 .10305 L
.90296 .10303 L
.9047 .10302 L
.90659 .10301 L
.90838 .10301 L
.91002 .10301 L
.91173 .10301 L
.91332 .10301 L
.91507 .10301 L
.91694 .10301 L
.91788 .10301 L
.91891 .10301 L
.92077 .10301 L
.92258 .10301 L
.92426 .10301 L
.92597 .10301 L
.92777 .10301 L
.9293 .10301 L
.93098 .10301 L
.9328 .10301 L
.93381 .10301 L
.93474 .10301 L
.93653 .10301 L
.93823 .10301 L
.93982 .10301 L
.94151 .10301 L
.94295 .10301 L
.94453 .10301 L
.94623 .10301 L
.94806 .10301 L
.94978 .10301 L
.95136 .10301 L
.95321 .10301 L
.95424 .10301 L
.95517 .10301 L
.95699 .10301 L
.9587 .10301 L
.95968 .10301 L
.96071 .10301 L
.96255 .10301 L
.96358 .10301 L
.96454 .10301 L
.96559 .10301 L
.96671 .10301 L
.96859 .10301 L
Mistroke
.96965 .10301 L
.97063 .10301 L
.97243 .10301 L
.97435 .10301 L
.97605 .10301 L
.97765 .10301 L
.97941 .10301 L
.9813 .10301 L
.98313 .10301 L
.98479 .10301 L
.98671 .10301 L
.98852 .10301 L
.99019 .10301 L
.99174 .10301 L
.99343 .10301 L
.99523 .10301 L
.99704 .10301 L
.99805 .10301 L
.99898 .10301 L
Mfstroke
.99898 .10301 m
1 .10301 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000oooooolLooooo`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0oooooolLooooo`00<?ooool6o`0000;o
oooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^0?oooooo7Oooool003So
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003ooooo
oa?ooooo000hooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05oooo
o`03o`000?oooooooooo0?oooooo4oooool003Sooooo00Go410@oooooooooooooooooa0@400?oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooo
oooo0?oooooo4oooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooo
oooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003ooooooooo
o`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000oooo
ooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`00
0?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool0
0ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o
0000ooooooooool0oooooolCooooo`008oooool5o`0002_ooooo00?o0000ooooooooool0:oooool5
o`0002kooooo0_l000000ol@413oooooooooo`0Zooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?oo
ool01Oo<c<co8B4Qo`000?lQ8B7oc<c<02Wooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`00
0?lb<S;ok^k^6_ooool002?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00[ooooo`03o`000?oooooo
oooo02_ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00_ooooo`03o`000?oooooooooo02_ooooo00Go
EEEEogMgMoooooooV9RHob4Q8@0/ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40:oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool001_ooooo1_l00003ooooo`03
oiRHV?lQ8B7ok^k^02cooooo00?o0000ooooooooool0;?ooool00onHV9So8B4Qonk^kP0]ooooo`Go
0000;?ooool01Ol0003ooooooooooooooooo000002cooooo00Go0000ooooooooooooooooo`00000[
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Jooooo`009Oooool0
0onHV9So8B4Qonk^kP0[ooooo`03o`000?oooooooooo02gooooo00?oV9RHob4Q8Oo^k^h0;?ooool0
1?m4A4CogMgMooooool0000]ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;?ooool01Olb<S;oV9RH
oooooonHV9So<S8b02_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
01[ooooo000Vooooo`03ogMgMomVIVKooooo02[ooooo0_l0000_ooooo`03ogMgMomVIVKooooo02_o
oooo00CogMgMoeEEEOoooooo0000;Oooool01Ol0003oEEEEo`000?l@413oc<c<02cooooo00Goc<c<
o`000?l0003o0000olc<c00[ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Jooooo`009oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool0:oooool00omgMgOoc<c<o`00000]ooooo`03oeEEEOn7QhOooooo02kooooo00Go
410@okZj^_oooooo^[Zjoa0@400[ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@400Jooooo`008oooool01Ol0003o^[ZjoooooonHV9So410@02_ooooo00?o0000oooooooo
ool0:oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo00?ok^k^odA4A?l00000;Oooool00ooM
gMgo410@oiRHV00^ooooo`05o`000?nj^[[ooooookZj^_l00000:oooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool002?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00[ooooo`03o`000?oooooooooo02_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00^ooooo`03ogMg
Mol0003ooooo02gooooo00Coc<c<odA4A?l0003o410@;?ooool01OnYZJWo410@o`000?l@413oZJVY
02Wooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo001Coooo
o`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00
Doooool00ol0003oooooooooo`3mooooo`;o00000_ooool2o`0000oooooo001Cooooo`03o`000?oo
oooooooo0?gooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd?ooooo`00Doooool00ol0003ooooo
ooooo`3nooooo`04omgMgOl0003o410@olc<c13ooooo000:oooooooo0000@?l0000;ooooo`04onk^
k_lQ8B7o410@onk^kQ3ooooo000Fooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo0_l0000:ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`04ob4Q
8OmgMgOoMgMgoc8b<Q3ooooo000Rooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0
;_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0
;_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0
2?ooool2o`0000;ooooo0_l0000?ooooo`00Doooool00ol0003oooooooooo`31ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool0@oooool005?ooooo00?o0000ooooooooool0`Oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo04?ooooo001Cooooo`03o`000?oooooooooo
0<;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`13ooooo`00Doooool00ol0003o
ooooooooo`32ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0@oooool005?ooooo
00?o0000ooooooooool0`_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04Cooooo
001Cooooo`;o0000`oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo04Cooooo001C
ooooo`03o`000?oooooooooo0<;ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`14
ooooo`00Doooool00ol0003oooooooooo`32ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0A?ooool005?ooooo00?o0000ooooooooool0`_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo04Gooooo001Cooooo`03o`000?oooooooooo0<;ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`15ooooo`00Doooool00ol0003oooooooooo`32ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool0AOooool005?ooooo00?o0000ooooooooool0`_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo04Gooooo001Cooooo`03o`000?oooooooooo
0<?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`15ooooo`00Doooool2o`000<Co
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`15ooooo`00Doooool00ol0003ooooo
ooooo`33ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0AOooool005?ooooo00?o
0000ooooooooool0`oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04Gooooo001C
ooooo`03o`000?oooooooooo0<?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`15
ooooo`00Doooool00ol0003oooooooooo`33ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0AOooool005?ooooo00?o0000ooooooooool0`oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo04Kooooo001Cooooo`03o`000?oooooooooo0<?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`16ooooo`00Doooool00ol0003oooooooooo`33ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0A_ooool005?ooooo0_l00034ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0A_ooool005?ooooo00?o0000ooooooooool0`oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo04Kooooo001Cooooo`03o`000?oooooooooo0<?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`16ooooo`00Doooool00ol0003ooooo
ooooo`34ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0A_ooool005?ooooo00?o
0000ooooooooool0a?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04Kooooo001C
ooooo`03o`000?oooooooooo0<Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`16
ooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001_ooool0
0ol0003oooooooooo`34ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0A_ooool0
03Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_oo
ooooA4A400Kooooo00?o0000ooooooooool0a?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo04Kooooo000hooooo`05oa0@4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^
kP07ooooo`?o0000a?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04Kooooo000h
ooooo`05o`000?ooooooooooooooool000003Oooool00onHV9So8B4Qonk^kP06ooooo`03o`000?oo
oooooooo0<Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`16ooooo`00>?ooool0
1Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooooooo
o`34ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0A_ooool003Sooooo00Go410@
oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0a?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04Kooooo000hooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
a?ooool01Ol0003ooooooooooooooooo000004Wooooo000hooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0a?ooool01Ol0
003ooooooooooooooooo000004Wooooo001Cooooo`03o`000?oooooooooo0<Cooooo00Go0000oooo
ooooooooooooo`000019ooooo`00Doooool00ol0003oooooooooo`34ooooo`05o`000?oooooooooo
ooooool00000BOooool005?ooooo00?o0000ooooooooool0a?ooool01Ol0003ooooooooooooooooo
000004Wooooo001Cooooo`;o0000aOooool01Ol0003ooooooooooooooooo000004Wooooo001Coooo
o`03o`000?oooooooooo0<Cooooo00Go0000ooooooooooooooooo`000019ooooo`00Doooool00ol0
003oooooooooo`34ooooo`04o`000?ooooooooooo`0004[ooooo001Cooooo`03o`000?oooooooooo
0<Cooooo00Co0000oooooooooooo0000B_ooool005?ooooo00?o0000ooooooooool0a?ooool01?l0
003oooooooooool0001:ooooo`00Doooool00ol0003oooooooooo`34ooooo`04o`000?oooooooooo
o`0004[ooooo001Cooooo`03o`000?oooooooooo0<Cooooo00Co0000oooooooooooo0000B_ooool0
05?ooooo00?o0000ooooooooool0a?ooool01?l0003oooooooooool0001:ooooo`00Doooool2o`00
0<Gooooo00Co0000oooooooooooo0000B_ooool005?ooooo00?o0000ooooooooool0a?ooool01?l0
003oooooooooool0001:ooooo`00Doooool00ol0003oooooooooo`35ooooo`03o`000?oooooo0000
04[ooooo001Cooooo`03o`000?oooooooooo0<Gooooo00?o0000ooooool00000B_ooool005?ooooo
00?o0000ooooooooool0aOooool00ol0003oooooo`00001:ooooo`00Doooool00ol0003ooooooooo
o`35ooooo`03o`000?oooooo000004[ooooo001Cooooo`03o`000?oooooooooo0<Gooooo00?o0000
ooooool00000B_ooool005?ooooo00?o0000ooooooooool0aOooool00ol0003oooooo`00001:oooo
o`00Doooool2o`000<Kooooo00?o0000ooooool00000B_ooool005?ooooo00?o0000ooooooooool0
a_ooool00ol0003oooooooooo`19ooooo`00Doooool00ol0003oooooooooo`36ooooo`03o`000?oo
oooooooo04Wooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000oooo
ooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo000hooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Kooooo0_l000000ol@413oooooooooo`04ooooo`03
o`000?oooooooooo0?oooooo4oooool003Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o
8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo4oooool003Sooooo
00Go410@oooooooooooooooooa0@400;ooooo`Go00001_ooool3o`000?oooooo4oooool003Sooooo
00Go0000ooooooooooooooooo`00000;ooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o0000oooo
ooooool0oooooolCooooo`00>?ooool01Ol0003ooooooooooooooooo000000_ooooo00CogMgMoeEE
EOoooooo00001oooool00ol0003oooooooooo`3ooooooa?ooooo000hooooo`05oa0@4?oooooooooo
ooooool@41003?ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo0?oooooo4oooool0
03Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03onk^k_m4A4Co000000Oooooo00?o0000
ooooooooool0oooooolCooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00gooooo00?oMgMg
o`000?ooool01_ooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo
0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool2o`000?oooooo
5?ooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3o
oooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000oooooooo
ool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oo
oooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0
003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003ooooo
ooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000
ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03
o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Dooo
ool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0
003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo
00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo000h
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Cooooo00Gok^k^oc8b<_l0003o410@
olc<c006ooooo`03o`000?oooooooooo0?oooooo4oooool003Sooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000oooooooo
ool0oooooolCooooo`00>?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go0000oooooooo
ooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo4oooool003Sooooo00Go0000oooooooo
ooooooooo`00000;ooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool3o`000?oooooo4oooool0
03Sooooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_oo
ool00ol0003oooooooooo`3ooooooa?ooooo000hooooo`05oa0@4?ooooooooooooooool@41002ooo
ool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo0?oooooo4oooool003Sooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0;ooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool0oooo
oolCooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo00Coc<c<odA4A?l0003o410@
1_ooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4ooo
ool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooo
oa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo
001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolC
ooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oo
oooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003ooooooooo
o`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003oooooooooo`3ooooo
oa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0
oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooo
oooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo0_l0
003ooooooaCooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000oooo
ooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`00
0?oooooooooo0?oooooo4oooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1?ooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0oooooolCooooo`00
>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9SooooooiRH
V?lQ8B401_ooool00ol0003oooooooooo`3ooooooa?ooooo000hooooo`05oa0@4?oooooooooooooo
ool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0oooooolC
ooooo`00>?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go<S8boiRHV?ooooooV9RHoc8b
<P06ooooo`?o0000oooooolCooooo`00>?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go
c<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo0?oooooo4oooool003Sooooo00Go
410@oooooooooooooooooa0@400;ooooo`05oa0@4?nj^[[ooooookZj^_l@41001_ooool00ol0003o
ooooooooo`3ooooooa?ooooo000hooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o
^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00_ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`03o`000?oooooo
oooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo0_l0
003ooooooaCooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000oooo
ooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`00
0?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool0
0ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?o
oooo0_l0003ooooooaCooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o
0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Coooo
o`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00
Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4ooo
ool005?ooooo0_l0003ooooooaCooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?o
oooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo
001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolC
ooooo`00BOooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0oooooolCoooo
o`00Boooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo4oooool004_ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooooa?ooooo001;ooooo`03o`000?oo
oooooooo00Gooooo0ol0003ooooooa?ooooo001;ooooo`03o`000?oooooooooo0?oooooo6oooool0
04_ooooo00?o0000ooooooooool0oooooolKooooo`00Boooool00ol0003oooooooooo`3ooooooa_o
oooo0019ooooo`03oeEEEOmVIVKo00000?oooooo7Oooool007Sooooo0ol000000ol@413ooooooooo
o`3Zooooo`00N_ooool00ol@413o^[Zjooooo`07ooooo`;o00002oooool00ol0003o^[Zjooooo`0<
ooooo`;o00001Oooool00ol0003o^[Zjooooo`2nooooo`00N_ooool00onHV9So<S8booooo`07oooo
o`03o`000?oooooooooo00[ooooo0_lb<S8>ooooo`03o`000?oooooooooo00?ooooo0_lb<S:ooooo
o`00N_ooool00ooMgMgo0000okZj^P07ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`00
00?ooooo00?oQhN7o`000?nj^[X01?ooool01OnHV9So0000o`000?m4A4Co^[Zj00Cooooo00?o0000
ooooooooool00oooool00on7QhOo0000okZj^P0<ooooo`05oiRHV?l0003o0000odA4A?nj^[X04Ooo
ool5o`0000Gooooo00?o0000onk^k_ooool0Soooool007[ooooo00?oEEEEogMgMom4A4@01oooool0
2_l0003oooooooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oMgMd3ooooo`03olc<c?l0003o410@
00Cooooo00Go410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oooooooooo00?ooooo00?oc<c<
o`000?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo1_l00002ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@01Oooool00omEEEGoZJVYooooo`2?ooooo`00NOooool01OoMgMgo410@oooo
oolQ8B7ogMgM00Kooooo00?o0000ooooooooool00_ooool01?oMgMgo0000oa0@4?o<c<`;ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Dooooo`03
oiRHV?lQ8B7ok^k^00Kooooo00?oZJVYoeEEEOooool0Soooool007Wooooo00GoIVIVohN7Qooooooo
V9RHoeEEE@06ooooo`03o`000?oooooooooo00;ooooo00Cok^k^ob4Q8Ol@413ok^k^2oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02oooool6o`00
00Cooooo00?oV9RHob4Q8Oo^k^h01_ooool00olQ8B7oooooooooo`2>ooooo`00N?ooool00oo^k^ko
0000onk^kP02ooooo`03o`000?oMgMgooooo00Cooooo00?o0000ooooooooool00_ooool01?lQ8B7o
MgMgogMgMolb<S8;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0Fooooo`03ogMgMomVIVKooooo00Gooooo00?oEEEEolc<c?ooool0S_ooool007So
oooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`03ooooo`04o`000?oooooooooo
ooooo`;o00000_ooool2o`0000Sooooo00?o410@o`000?l000000ol00005ooooo`03o`000?oooooo
oooo013ooooo00?o410@o`000?l000000ol0000Fooooo`03o`000?oooooooooo00Cooooo00?oZJVY
ogMgMoooool0S_ooool008Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04oooool01Ol0003o^[ZjoooooonHV9So
410@00?ooooo00Go410@oooooooooooooooooc8b<P2?ooooo`00Q?ooool2o`0001;ooooo00?o0000
ooooooooool01Oooool2o`0001Cooooo00?o0000ooooooooool04oooool01OnHV9So410@o`000?lQ
8B7oc<c<00?ooooo1Ol0002?ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-3.4116, -0.234311, \
0.0510397, 0.00762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.230769 0.0769231 0.103006 0.515028 [
[.07692 .09051 -6 -9 ]
[.07692 .09051 6 0 ]
[.38462 .09051 -3 -9 ]
[.38462 .09051 3 0 ]
[.53846 .09051 -3 -9 ]
[.53846 .09051 3 0 ]
[.69231 .09051 -3 -9 ]
[.69231 .09051 3 0 ]
[.84615 .09051 -3 -9 ]
[.84615 .09051 3 0 ]
[1 .09051 -6 -9 ]
[1 .09051 6 0 ]
[1.025 .10301 0 -6 ]
[1.025 .10301 10 6 ]
[.21827 0 -24 -4.5 ]
[.21827 0 0 4.5 ]
[.21827 .20601 -18 -4.5 ]
[.21827 .20601 0 4.5 ]
[.21827 .30902 -18 -4.5 ]
[.21827 .30902 0 4.5 ]
[.21827 .41202 -18 -4.5 ]
[.21827 .41202 0 4.5 ]
[.21827 .51503 -18 -4.5 ]
[.21827 .51503 0 4.5 ]
[.21827 .61803 -6 -4.5 ]
[.21827 .61803 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07692 .10301 m
.07692 .10926 L
s
[(-2)] .07692 .09051 0 1 Mshowa
.38462 .10301 m
.38462 .10926 L
s
[(2)] .38462 .09051 0 1 Mshowa
.53846 .10301 m
.53846 .10926 L
s
[(4)] .53846 .09051 0 1 Mshowa
.69231 .10301 m
.69231 .10926 L
s
[(6)] .69231 .09051 0 1 Mshowa
.84615 .10301 m
.84615 .10926 L
s
[(8)] .84615 .09051 0 1 Mshowa
1 .10301 m
1 .10926 L
s
[(10)] 1 .09051 0 1 Mshowa
.125 Mabswid
.11538 .10301 m
.11538 .10676 L
s
.15385 .10301 m
.15385 .10676 L
s
.19231 .10301 m
.19231 .10676 L
s
.26923 .10301 m
.26923 .10676 L
s
.30769 .10301 m
.30769 .10676 L
s
.34615 .10301 m
.34615 .10676 L
s
.42308 .10301 m
.42308 .10676 L
s
.46154 .10301 m
.46154 .10676 L
s
.5 .10301 m
.5 .10676 L
s
.57692 .10301 m
.57692 .10676 L
s
.61538 .10301 m
.61538 .10676 L
s
.65385 .10301 m
.65385 .10676 L
s
.73077 .10301 m
.73077 .10676 L
s
.76923 .10301 m
.76923 .10676 L
s
.80769 .10301 m
.80769 .10676 L
s
.88462 .10301 m
.88462 .10676 L
s
.92308 .10301 m
.92308 .10676 L
s
.96154 .10301 m
.96154 .10676 L
s
.03846 .10301 m
.03846 .10676 L
s
.25 Mabswid
0 .10301 m
1 .10301 L
s
gsave
1.025 .10301 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.23077 0 m
.23702 0 L
s
[(-0.2)] .21827 0 1 0 Mshowa
.23077 .20601 m
.23702 .20601 L
s
[(0.2)] .21827 .20601 1 0 Mshowa
.23077 .30902 m
.23702 .30902 L
s
[(0.4)] .21827 .30902 1 0 Mshowa
.23077 .41202 m
.23702 .41202 L
s
[(0.6)] .21827 .41202 1 0 Mshowa
.23077 .51503 m
.23702 .51503 L
s
[(0.8)] .21827 .51503 1 0 Mshowa
.23077 .61803 m
.23702 .61803 L
s
[(1)] .21827 .61803 1 0 Mshowa
.125 Mabswid
.23077 .02575 m
.23452 .02575 L
s
.23077 .0515 m
.23452 .0515 L
s
.23077 .07725 m
.23452 .07725 L
s
.23077 .12876 m
.23452 .12876 L
s
.23077 .15451 m
.23452 .15451 L
s
.23077 .18026 m
.23452 .18026 L
s
.23077 .23176 m
.23452 .23176 L
s
.23077 .25751 m
.23452 .25751 L
s
.23077 .28327 m
.23452 .28327 L
s
.23077 .33477 m
.23452 .33477 L
s
.23077 .36052 m
.23452 .36052 L
s
.23077 .38627 m
.23452 .38627 L
s
.23077 .43777 m
.23452 .43777 L
s
.23077 .46353 m
.23452 .46353 L
s
.23077 .48928 m
.23452 .48928 L
s
.23077 .54078 m
.23452 .54078 L
s
.23077 .56653 m
.23452 .56653 L
s
.23077 .59228 m
.23452 .59228 L
s
.25 Mabswid
.23077 0 m
.23077 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
123.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(28) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.83006 .10301 m
.83187 .10301 L
.83349 .10301 L
.83525 .10301 L
.83619 .10301 L
.8372 .10301 L
.83903 .10301 L
.84014 .10301 L
.8412 .10301 L
.84214 .10301 L
.84317 .10301 L
.84417 .10301 L
.84528 .10301 L
.84644 .10301 L
.84752 .10301 L
.84853 .10301 L
.84946 .10302 L
.85047 .10305 L
.85154 .10315 L
.85333 .10373 L
.85525 .10599 L
.85706 .11171 L
.8587 .12213 L
.85971 .13174 L
.86063 .14297 L
.86273 .17594 L
.86471 .21296 L
.86653 .24538 L
.86824 .26918 L
.86986 .28246 L
.87157 .28527 L
.87343 .27615 L
.87505 .26023 L
.87678 .23833 L
.87988 .19577 L
.88179 .17225 L
.88386 .15128 L
.8858 .13605 L
.88759 .12565 L
.88921 .11873 L
.89099 .11332 L
.89284 .1095 L
.89457 .10714 L
.89642 .10551 L
.89746 .10488 L
.89843 .10443 L
.9002 .10386 L
.90208 .10349 L
.90375 .1033 L
.90533 .10319 L
Mistroke
.90705 .10311 L
.90891 .10306 L
.91078 .10304 L
.91183 .10303 L
.91282 .10302 L
.91386 .10302 L
.9148 .10301 L
.91589 .10301 L
.91692 .10301 L
.91876 .10301 L
.92045 .10301 L
.9223 .10301 L
.92323 .10301 L
.92426 .10301 L
.92615 .10301 L
.9279 .10301 L
.92982 .10301 L
.93079 .10301 L
.93186 .10301 L
.93365 .10301 L
.93466 .10301 L
.93558 .10301 L
.93728 .10301 L
.93907 .10301 L
.94069 .10301 L
.94241 .10301 L
.94404 .10301 L
.94553 .10301 L
.94727 .10301 L
.94916 .10301 L
.95094 .10301 L
.95259 .10301 L
.95434 .10301 L
.95622 .10301 L
.95799 .10301 L
.95961 .10301 L
.96151 .10301 L
.96258 .10301 L
.96358 .10301 L
.9654 .10301 L
.96642 .10301 L
.96735 .10301 L
.96833 .10301 L
.96936 .10301 L
.97122 .10301 L
.97225 .10301 L
.97321 .10301 L
.97427 .10301 L
.9754 .10301 L
.97638 .10301 L
Mistroke
.97744 .10301 L
.97844 .10301 L
.97937 .10301 L
.98112 .10301 L
.98298 .10301 L
.98464 .10301 L
.98645 .10301 L
.98834 .10301 L
.9901 .10301 L
.99175 .10301 L
.99325 .10301 L
.99499 .10301 L
.99662 .10301 L
.9984 .10301 L
Mfstroke
.9984 .10301 m
1 .10301 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000oooooolLooooo`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0oooooolLooooo`00<?ooool6o`0000;o
oooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^0?oooooo7Oooool003So
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003ooooo
oa?ooooo000hooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05oooo
o`03o`000?oooooooooo0?oooooo4oooool003Sooooo00Go410@oooooooooooooooooa0@400?oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooo
oooo0?oooooo4oooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooo
oooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003ooooooooo
o`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000oooo
ooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`00
0?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool0
0ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o
0000ooooooooool0oooooolCooooo`008oooool5o`0002_ooooo00?o0000ooooooooool0:oooool5
o`0002kooooo0_l000000ol@413oooooooooo`0Zooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?oo
ool01Oo<c<co8B4Qo`000?lQ8B7oc<c<02Wooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`00
0?lb<S;ok^k^6_ooool002?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00[ooooo`03o`000?oooooo
oooo02_ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00_ooooo`03o`000?oooooooooo02_ooooo00Go
EEEEogMgMoooooooV9RHob4Q8@0/ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40:oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool001_ooooo1_l00003ooooo`03
oiRHV?lQ8B7ok^k^02cooooo00?o0000ooooooooool0;?ooool00onHV9So8B4Qonk^kP0]ooooo`Go
0000;?ooool01Ol0003ooooooooooooooooo000002cooooo00Go0000ooooooooooooooooo`00000[
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Jooooo`009Oooool0
0onHV9So8B4Qonk^kP0[ooooo`03o`000?oooooooooo02gooooo00?oV9RHob4Q8Oo^k^h0;?ooool0
1?m4A4CogMgMooooool0000]ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;?ooool01Olb<S;oV9RH
oooooonHV9So<S8b02_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
01[ooooo000Vooooo`03ogMgMomVIVKooooo02[ooooo0_l0000_ooooo`03ogMgMomVIVKooooo02_o
oooo00CogMgMoeEEEOoooooo0000;Oooool01Ol0003oEEEEo`000?l@413oc<c<02cooooo00Goc<c<
o`000?l0003o0000olc<c00[ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Jooooo`009oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool0:oooool00omgMgOoc<c<o`00000]ooooo`03oeEEEOn7QhOooooo02kooooo00Go
410@okZj^_oooooo^[Zjoa0@400[ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@400Jooooo`008oooool01Ol0003o^[ZjoooooonHV9So410@02_ooooo00?o0000oooooooo
ool0:oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo00?ok^k^odA4A?l00000;Oooool00ooM
gMgo410@oiRHV00^ooooo`05o`000?nj^[[ooooookZj^_l00000:oooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool002?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00[ooooo`03o`000?oooooooooo02_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00^ooooo`03ogMg
Mol0003ooooo02gooooo00Coc<c<odA4A?l0003o410@;?ooool01OnYZJWo410@o`000?l@413oZJVY
02Wooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo001Coooo
o`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00
Doooool00ol0003oooooooooo`3mooooo`;o00000_ooool2o`0000oooooo001Cooooo`03o`000?oo
oooooooo0?gooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd?ooooo`00Doooool00ol0003ooooo
ooooo`3nooooo`04omgMgOl0003o410@olc<c13ooooo000:oooooooo0000@?l0000;ooooo`04onk^
k_lQ8B7o410@onk^kQ3ooooo000Fooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`09ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000oooooooo
oooo00002?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool01?lQ8B7oMgMgogMgMolb<S8@ooooo`008_ooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooooooo02kooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooooooo02kooooo00Co0000oooooooooooo00002oooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo00Sooooo0_l00002ooooo`;o00003oooool005?ooooo00?o0000oooo
ooooool0a?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo043ooooo001Cooooo`03
o`000?oooooooooo0<Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`10ooooo`00
Doooool00ol0003oooooooooo`35ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
@?ooool005?ooooo00?o0000ooooooooool0aOooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo043ooooo001Cooooo`03o`000?oooooooooo0<Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`11ooooo`00Doooool2o`000<Kooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`11ooooo`00Doooool00ol0003oooooooooo`35ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0@Oooool005?ooooo00?o0000ooooooooool0aOooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo047ooooo001Cooooo`03o`000?oooooooooo0<Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`11ooooo`00Doooool00ol0003oooooooooo`36
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0@Oooool005?ooooo00?o0000oooo
ooooool0a_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo04;ooooo001Cooooo`03
o`000?oooooooooo0<Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`12ooooo`00
Doooool00ol0003oooooooooo`36ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
@_ooool005?ooooo0_l00037ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0@_oo
ool005?ooooo00?o0000ooooooooool0a_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo04;ooooo001Cooooo`03o`000?oooooooooo0<Kooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`12ooooo`00Doooool00ol0003oooooooooo`36ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0@oooool005?ooooo00?o0000ooooooooool0a_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo04?ooooo001Cooooo`03o`000?oooooooooo0<Kooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`13ooooo`00Doooool00ol0003oooooooooo`36
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0@oooool005?ooooo00?o0000oooo
ooooool0a_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04?ooooo001Cooooo`;o
0000aoooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04?ooooo001Cooooo`03o`00
0?oooooooooo0<Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`13ooooo`00Dooo
ool00ol0003oooooooooo`36ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0@ooo
ool005?ooooo00?o0000ooooooooool0a_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo04?ooooo001Cooooo`03o`000?oooooooooo0<Kooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`13ooooo`00Doooool00ol0003oooooooooo`36ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool0@oooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0aoooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo04?ooooo000hooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Co
oooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo0<Oooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`13ooooo`00>?ooool01Ol@413ooooooooooooooooo410@
00cooooo00?oV9RHob4Q8Oo^k^h01oooool3o`000<Oooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`13ooooo`00>?ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q
8Oo^k^h01_ooool00ol0003oooooooooo`37ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0@oooool003Sooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo
00Gooooo00?o0000ooooooooool0aoooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
04?ooooo000hooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo0<Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`13oooo
o`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006
ooooo`03o`000?oooooooooo0<Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`13
ooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c006ooooo`03o`000?oooooooooo0<Oooooo00Go0000ooooooooooooooooo`000016ooooo`00Dooo
ool00ol0003oooooooooo`37ooooo`05o`000?ooooooooooooooool00000A_ooool005?ooooo00?o
0000ooooooooool0aoooool01Ol0003ooooooooooooooooo000004Kooooo001Cooooo`03o`000?oo
oooooooo0<Oooooo00Go0000ooooooooooooooooo`000016ooooo`00Doooool2o`000<Sooooo00Go
0000ooooooooooooooooo`000016ooooo`00Doooool00ol0003oooooooooo`37ooooo`05o`000?oo
ooooooooooooool00000A_ooool005?ooooo00?o0000ooooooooool0aoooool01Ol0003ooooooooo
oooooooo000004Kooooo001Cooooo`03o`000?oooooooooo0<Oooooo00Go0000oooooooooooooooo
o`000016ooooo`00Doooool00ol0003oooooooooo`37ooooo`05o`000?ooooooooooooooool00000
A_ooool005?ooooo00?o0000ooooooooool0aoooool01Ol0003ooooooooooooooooo000004Kooooo
001Cooooo`03o`000?oooooooooo0<Oooooo00Co0000oooooooooooo0000Aoooool005?ooooo00?o
0000ooooooooool0aoooool01?l0003oooooooooool00017ooooo`00Doooool2o`000<Wooooo00?o
0000ooooool00000Aoooool005?ooooo00?o0000ooooooooool0b?ooool00ol0003oooooo`000017
ooooo`00Doooool00ol0003oooooooooo`38ooooo`03o`000?oooooo000004Oooooo001Cooooo`03
o`000?oooooooooo0<Sooooo00?o0000ooooool00000Aoooool005?ooooo00?o0000ooooooooool0
b?ooool00ol0003oooooo`000017ooooo`00Doooool00ol0003oooooooooo`38ooooo`03o`000?oo
oooo000004Oooooo001Cooooo`03o`000?oooooooooo0<Wooooo0_l00017ooooo`00Doooool00ol0
003oooooooooo`39ooooo`;o0000Aoooool005?ooooo0_l0003:ooooo`03o`000?oooooooooo04Ko
oooo001Cooooo`03o`000?oooooooooo0<Wooooo00?o0000ooooooooool0A_ooool005?ooooo00?o
0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Coooo
o`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00
>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@oooooooo
ool01?ooool00ol0003oooooooooo`3ooooooa?ooooo000hooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooooa?o
oooo000hooooo`05oa0@4?ooooooooooooooool@41002oooool5o`0000Kooooo0ol0003ooooooa?o
oooo000hooooo`05o`000?ooooooooooooooool000002oooool01?m4A4CogMgMooooool00007oooo
o`03o`000?oooooooooo0?oooooo4oooool003Sooooo00Go0000ooooooooooooooooo`00000;oooo
o`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01Ol@
413ooooooooooooooooo410@00cooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`3o
oooooa?ooooo000hooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00oo^k^koA4A4o`000007
ooooo`03o`000?oooooooooo0?oooooo4oooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=
ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0
003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo
0_l0003ooooooaCooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000
ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03
o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Dooo
ool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool0
05?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool2o`000?oooooo5?ooool005?ooooo
00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001C
ooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCoooo
o`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo
4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool2o`000?oooooo5?ooool0
05?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?o
oooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooo
oolCooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`3ooooooa?ooooo000hooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`03
o`000?oooooooooo0?oooooo4oooool003Sooooo00Go410@oooooooooooooooooa0@400;ooooo`05
o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`3ooooooa?ooooo000hooooo`05
o`000?ooooooooooooooool000002oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo0ol0003o
oooooa?ooooo000hooooo`05o`000?ooooooooooooooool000002oooool01Ol0003oEEEEo`000?l@
413oc<c<00Kooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01Ol@413ooooooooooooo
oooo410@00_ooooo00?oEEEEohN7Qoooool02?ooool00ol0003oooooooooo`3ooooooa?ooooo000h
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oo
oooooooo0?oooooo4oooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`04olc<c?m4
A4Co0000oa0@40Kooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003ooooooooo
o`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000oooo
ooooool0oooooolCooooo`00Doooool2o`000?oooooo5?ooool005?ooooo00?o0000ooooooooool0
oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooo
oooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o
0000ooooooooool0oooooolCooooo`00Doooool2o`000?oooooo5?ooool005?ooooo00?o0000oooo
ooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`00
0?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool0
0ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?o
oooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo
001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Coooo
o`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00
Doooool00ol0003oooooooooo`3ooooooa?ooooo000hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Cooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0?oo
oooo4oooool003Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q1?ooool01OlQ8B7o
V9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01Ol@413o
oooooooooooooooo410@00_ooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooo
oooo0?oooooo4oooool003Sooooo00Go0000ooooooooooooooooo`00000;ooooo`05oc8b<_nHV9So
oooooiRHV?lb<S801_ooool3o`000?oooooo4oooool003Sooooo00Go0000ooooooooooooooooo`00
000;ooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`3ooooooa?ooooo
000hooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@00Ko
oooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_o
oooo00Go0000okZj^_oooooo^[Zjo`000006ooooo`03o`000?oooooooooo0?oooooo4oooool003So
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool0
0ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?o
oooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo
001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Coooo
o`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00
Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4ooo
ool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooo
oa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo
001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolC
ooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oo
oooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003ooooooooo
o`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003oooooooooo`3ooooo
oa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0
oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooo
oooo0?oooooo4oooool004Wooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo
0?oooooo4oooool004_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3ooooooa?o
oooo001;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0oooooolCooooo`00Booo
ool00ol0003oooooooooo`05ooooo`?o0000oooooolCooooo`00Boooool00ol0003oooooooooo`3o
oooooa_ooooo001;ooooo`03o`000?oooooooooo0?oooooo6oooool004_ooooo00?o0000oooooooo
ool0oooooolKooooo`00BOooool00omEEEGoIVIVo`00003ooooooagooooo001hooooo`?o000000?o
410@ooooooooool0j_ooool007[ooooo00?o410@okZj^_ooool01oooool2o`0000_ooooo00?o0000
okZj^_ooool03?ooool2o`0000Gooooo00?o0000okZj^_ooool0__ooool007[ooooo00?oV9RHoc8b
<_ooool01oooool00ol0003oooooooooo`0:ooooo`;o<S8b3_ooool00ol0003oooooooooo`03oooo
o`;o<S8b_oooool007[ooooo00?ogMgMo`000?nj^[X01oooool01?l0003oooooooooooooool2o`00
00;ooooo0_l00003ooooo`03ohN7Qol0003o^[Zj00Cooooo00GoV9RHo`000?l0003oA4A4okZj^P04
ooooo`03o`000?oooooooooo00?ooooo00?oQhN7o`000?nj^[X03?ooool01OnHV9So0000o`000?m4
A4Co^[Zj017ooooo1Ol00003ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0Soooool007[ooooo00?o
EEEEogMgMom4A4@01oooool02_l0003oooooooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oMgMd3
ooooo`03olc<c?l0003o410@00Cooooo00Go410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oo
oooooooo00?ooooo00?oc<c<o`000?l@41003?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Wooooo
1_l00002ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@00oooool01OlQ8B7oV9RHoooooonHV9So8B4Q
08oooooo001iooooo`05omgMgOl@413oooooob4Q8OoMgMd01_ooool00ol0003oooooooooo`02oooo
o`04omgMgOl0003o410@olc<c0_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo01Cooooo00?oV9RHob4Q8Oo^k^h01?ooool01Ol0003ooooooooooooo
oooo000008oooooo001iooooo`05ofIVI_n7QhOooooooiRHV?mEEED01_ooool00ol0003ooooooooo
o`02ooooo`04onk^k_lQ8B7o410@onk^kP_ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo00_ooooo1_l00004ooooo`03oiRHV?lQ8B7ok^k^00?ooooo
00Go<S8boiRHV?ooooooV9RHoc8b<P2?ooooo`00N?ooool00oo^k^ko0000onk^kP02ooooo`03o`00
0?oMgMgooooo00Cooooo00?o0000ooooooooool00_ooool01?lQ8B7oMgMgogMgMolb<S8;ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Fooooo`03
ogMgMomVIVKooooo00;ooooo00Goc<c<o`000?l0003o0000olc<c02?ooooo`00N?ooool01?l@413o
0000o`000?ooool2o`000003oa0@4?oooooooooo00?ooooo00Co0000oooooooooooooooo0_l00002
ooooo`;o00002?ooool00ol@413o0000o`000003o`0000Gooooo00?o0000ooooooooool04?ooool0
0ol@413o0000o`000003o`0001Kooooo00Wo0000oooooooooooooooooa0@4?nj^[[ooooookZj^_l@
4100Soooool008Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool04oooool01Ol0003o^[ZjoooooonHV9So410@00?o
oooo00Go0000okZj^_oooooo^[Zjo`00002?ooooo`00Q?ooool2o`0001;ooooo00?o0000oooooooo
ool01Oooool2o`0001Cooooo00?o0000ooooooooool04oooool01OnHV9So410@o`000?lQ8B7oc<c<
00?ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@2?ooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-3.4116, -0.234311, \
0.0510397, 0.00762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.230769 0.0769231 0.103006 0.515028 [
[.07692 .09051 -6 -9 ]
[.07692 .09051 6 0 ]
[.38462 .09051 -3 -9 ]
[.38462 .09051 3 0 ]
[.53846 .09051 -3 -9 ]
[.53846 .09051 3 0 ]
[.69231 .09051 -3 -9 ]
[.69231 .09051 3 0 ]
[.84615 .09051 -3 -9 ]
[.84615 .09051 3 0 ]
[1 .09051 -6 -9 ]
[1 .09051 6 0 ]
[1.025 .10301 0 -6 ]
[1.025 .10301 10 6 ]
[.21827 0 -24 -4.5 ]
[.21827 0 0 4.5 ]
[.21827 .20601 -18 -4.5 ]
[.21827 .20601 0 4.5 ]
[.21827 .30902 -18 -4.5 ]
[.21827 .30902 0 4.5 ]
[.21827 .41202 -18 -4.5 ]
[.21827 .41202 0 4.5 ]
[.21827 .51503 -18 -4.5 ]
[.21827 .51503 0 4.5 ]
[.21827 .61803 -6 -4.5 ]
[.21827 .61803 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07692 .10301 m
.07692 .10926 L
s
[(-2)] .07692 .09051 0 1 Mshowa
.38462 .10301 m
.38462 .10926 L
s
[(2)] .38462 .09051 0 1 Mshowa
.53846 .10301 m
.53846 .10926 L
s
[(4)] .53846 .09051 0 1 Mshowa
.69231 .10301 m
.69231 .10926 L
s
[(6)] .69231 .09051 0 1 Mshowa
.84615 .10301 m
.84615 .10926 L
s
[(8)] .84615 .09051 0 1 Mshowa
1 .10301 m
1 .10926 L
s
[(10)] 1 .09051 0 1 Mshowa
.125 Mabswid
.11538 .10301 m
.11538 .10676 L
s
.15385 .10301 m
.15385 .10676 L
s
.19231 .10301 m
.19231 .10676 L
s
.26923 .10301 m
.26923 .10676 L
s
.30769 .10301 m
.30769 .10676 L
s
.34615 .10301 m
.34615 .10676 L
s
.42308 .10301 m
.42308 .10676 L
s
.46154 .10301 m
.46154 .10676 L
s
.5 .10301 m
.5 .10676 L
s
.57692 .10301 m
.57692 .10676 L
s
.61538 .10301 m
.61538 .10676 L
s
.65385 .10301 m
.65385 .10676 L
s
.73077 .10301 m
.73077 .10676 L
s
.76923 .10301 m
.76923 .10676 L
s
.80769 .10301 m
.80769 .10676 L
s
.88462 .10301 m
.88462 .10676 L
s
.92308 .10301 m
.92308 .10676 L
s
.96154 .10301 m
.96154 .10676 L
s
.03846 .10301 m
.03846 .10676 L
s
.25 Mabswid
0 .10301 m
1 .10301 L
s
gsave
1.025 .10301 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.23077 0 m
.23702 0 L
s
[(-0.2)] .21827 0 1 0 Mshowa
.23077 .20601 m
.23702 .20601 L
s
[(0.2)] .21827 .20601 1 0 Mshowa
.23077 .30902 m
.23702 .30902 L
s
[(0.4)] .21827 .30902 1 0 Mshowa
.23077 .41202 m
.23702 .41202 L
s
[(0.6)] .21827 .41202 1 0 Mshowa
.23077 .51503 m
.23702 .51503 L
s
[(0.8)] .21827 .51503 1 0 Mshowa
.23077 .61803 m
.23702 .61803 L
s
[(1)] .21827 .61803 1 0 Mshowa
.125 Mabswid
.23077 .02575 m
.23452 .02575 L
s
.23077 .0515 m
.23452 .0515 L
s
.23077 .07725 m
.23452 .07725 L
s
.23077 .12876 m
.23452 .12876 L
s
.23077 .15451 m
.23452 .15451 L
s
.23077 .18026 m
.23452 .18026 L
s
.23077 .23176 m
.23452 .23176 L
s
.23077 .25751 m
.23452 .25751 L
s
.23077 .28327 m
.23452 .28327 L
s
.23077 .33477 m
.23452 .33477 L
s
.23077 .36052 m
.23452 .36052 L
s
.23077 .38627 m
.23452 .38627 L
s
.23077 .43777 m
.23452 .43777 L
s
.23077 .46353 m
.23452 .46353 L
s
.23077 .48928 m
.23452 .48928 L
s
.23077 .54078 m
.23452 .54078 L
s
.23077 .56653 m
.23452 .56653 L
s
.23077 .59228 m
.23452 .59228 L
s
.25 Mabswid
.23077 0 m
.23077 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
123.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(29) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.84129 .10301 m
.8431 .10301 L
.84412 .10301 L
.8452 .10301 L
.84611 .10301 L
.84712 .10301 L
.84821 .10301 L
.84937 .10301 L
.85047 .10301 L
.85147 .10301 L
.8524 .10301 L
.8534 .10301 L
.85518 .10301 L
.85709 .10301 L
.85818 .10301 L
.8592 .10301 L
.86104 .10308 L
.86273 .10342 L
.86458 .10491 L
.86551 .10663 L
.86653 .10979 L
.8684 .12071 L
.86945 .13068 L
.87043 .1426 L
.87411 .20632 L
.87583 .23829 L
.87745 .2627 L
.87913 .27854 L
.88099 .28252 L
.88194 .27924 L
.88299 .27211 L
.88488 .25187 L
.88844 .20306 L
.89045 .1769 L
.89259 .15376 L
.89461 .13705 L
.89644 .12595 L
.89818 .11832 L
.90003 .11275 L
.9016 .1095 L
.90333 .1071 L
.90519 .10544 L
.90623 .10481 L
.90718 .10438 L
.90903 .10379 L
.91077 .10347 L
.9124 .10328 L
.91413 .10316 L
.91561 .1031 L
.91724 .10306 L
Mistroke
.91898 .10304 L
.92086 .10302 L
.92264 .10301 L
.92426 .10301 L
.92613 .10301 L
.92788 .10301 L
.92946 .10301 L
.93117 .10301 L
.93304 .10301 L
.93398 .10301 L
.93501 .10301 L
.93684 .10301 L
.93855 .10301 L
.94027 .10301 L
.9419 .10301 L
.94336 .10301 L
.94496 .10301 L
.94669 .10301 L
.94852 .10301 L
.95009 .10301 L
.95183 .10301 L
.95372 .10301 L
.95468 .10301 L
.95572 .10301 L
.95757 .10301 L
.9593 .10301 L
.96035 .10301 L
.96134 .10301 L
.96319 .10301 L
.96423 .10301 L
.96519 .10301 L
.96624 .10301 L
.96735 .10301 L
.96908 .10301 L
.97094 .10301 L
.97269 .10301 L
.9743 .10301 L
.97617 .10301 L
.97723 .10301 L
.97822 .10301 L
.98002 .10301 L
.98194 .10301 L
.98375 .10301 L
.98478 .10301 L
.98574 .10301 L
.98675 .10301 L
.98767 .10301 L
.98873 .10301 L
.98974 .10301 L
.99153 .10301 L
Mistroke
.99318 .10301 L
.99499 .10301 L
.9959 .10301 L
.99691 .10301 L
.99793 .10301 L
.99901 .10301 L
Mfstroke
.99901 .10301 m
1 .10301 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000oooooolLooooo`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0oooooolLooooo`00<?ooool6o`0000;o
oooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^0?oooooo7Oooool003So
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003ooooo
oa?ooooo000hooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05oooo
o`03o`000?oooooooooo0?oooooo4oooool003Sooooo00Go410@oooooooooooooooooa0@400?oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooo
oooo0?oooooo4oooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooo
oooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003ooooooooo
o`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000oooo
ooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`00
0?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool0
0ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o
0000ooooooooool0oooooolCooooo`008oooool5o`0002_ooooo00?o0000ooooooooool0:oooool5
o`0002kooooo0_l000000ol@413oooooooooo`0Zooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?oo
ool01Oo<c<co8B4Qo`000?lQ8B7oc<c<02Wooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`00
0?lb<S;ok^k^6_ooool002?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00[ooooo`03o`000?oooooo
oooo02_ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00_ooooo`03o`000?oooooooooo02_ooooo00Go
EEEEogMgMoooooooV9RHob4Q8@0/ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40:oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool001_ooooo1_l00003ooooo`03
oiRHV?lQ8B7ok^k^02cooooo00?o0000ooooooooool0;?ooool00onHV9So8B4Qonk^kP0]ooooo`Go
0000;?ooool01Ol0003ooooooooooooooooo000002cooooo00Go0000ooooooooooooooooo`00000[
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Jooooo`009Oooool0
0onHV9So8B4Qonk^kP0[ooooo`03o`000?oooooooooo02gooooo00?oV9RHob4Q8Oo^k^h0;?ooool0
1?m4A4CogMgMooooool0000]ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;?ooool01Olb<S;oV9RH
oooooonHV9So<S8b02_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
01[ooooo000Vooooo`03ogMgMomVIVKooooo02[ooooo0_l0000_ooooo`03ogMgMomVIVKooooo02_o
oooo00CogMgMoeEEEOoooooo0000;Oooool01Ol0003oEEEEo`000?l@413oc<c<02cooooo00Goc<c<
o`000?l0003o0000olc<c00[ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Jooooo`009oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool0:oooool00omgMgOoc<c<o`00000]ooooo`03oeEEEOn7QhOooooo02kooooo00Go
410@okZj^_oooooo^[Zjoa0@400[ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@400Jooooo`008oooool01Ol0003o^[ZjoooooonHV9So410@02_ooooo00?o0000oooooooo
ool0:oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo00?ok^k^odA4A?l00000;Oooool00ooM
gMgo410@oiRHV00^ooooo`05o`000?nj^[[ooooookZj^_l00000:oooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool002?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00[ooooo`03o`000?oooooooooo02_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00^ooooo`03ogMg
Mol0003ooooo02gooooo00Coc<c<odA4A?l0003o410@;?ooool01OnYZJWo410@o`000?l@413oZJVY
02Wooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo001Coooo
o`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00
Doooool00ol0003oooooooooo`3mooooo`;o00000_ooool2o`0000oooooo001Cooooo`03o`000?oo
oooooooo0?gooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd?ooooo`00Doooool00ol0003ooooo
ooooo`3nooooo`04omgMgOl0003o410@olc<c13ooooo000:oooooooo0000@?l0000;ooooo`04onk^
k_lQ8B7o410@onk^kQ3ooooo000Fooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00Co8B4QogMgMomgMgOo
<S8b4?ooool002;ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0^ooooo`03o`00
0?oooooooooo02kooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0^ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo00Sooooo0_l00002ooooo`;o00003oooool005?ooooo00?o0000ooooooooool0aooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03gooooo001Cooooo`03o`000?oooooo
oooo0<Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0mooooo`00Doooool00ol0
003oooooooooo`38ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0?Oooool005?o
oooo00?o0000ooooooooool0b?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03ko
oooo001Cooooo`03o`000?oooooooooo0<Sooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0nooooo`00Doooool2o`000<Wooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0nooooo`00Doooool00ol0003oooooooooo`38ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0?oooool005?ooooo00?o0000ooooooooool0b?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo03oooooo001Cooooo`03o`000?oooooooooo0<Wooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0oooooo`00Doooool00ol0003oooooooooo`39ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0?oooool005?ooooo00?o0000ooooooooool0bOoo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03oooooo001Cooooo`03o`000?oooooo
oooo0<Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0oooooo`00Doooool00ol0
003oooooooooo`39ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0?oooool005?o
oooo0_l0003:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0?oooool005?ooooo
00?o0000ooooooooool0bOooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03oooooo
001Cooooo`03o`000?oooooooooo0<Wooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0oooooo`00Doooool00ol0003oooooooooo`39ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0?oooool005?ooooo00?o0000ooooooooool0bOooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo043ooooo001Cooooo`03o`000?oooooooooo0<Wooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`10ooooo`00Doooool00ol0003oooooooooo`39ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0@?ooool005?ooooo00?o0000ooooooooool0b_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo043ooooo001Cooooo`;o0000boooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo043ooooo001Cooooo`03o`000?oooooooooo
0<[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`10ooooo`00Doooool00ol0003o
ooooooooo`3:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0@?ooool005?ooooo
00?o0000ooooooooool0b_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo043ooooo
001Cooooo`03o`000?oooooooooo0<[ooooo00Go0000ooooooooooooooooo`000013ooooo`00Dooo
ool00ol0003oooooooooo`3:ooooo`05o`000?ooooooooooooooool00000@oooool003Sooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool5o`0000Kooooo00?o0000ooooooooool0
b_ooool01Ol0003ooooooooooooooooo000004?ooooo000hooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo
0<[ooooo00Go0000ooooooooooooooooo`000013ooooo`00>?ooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h01oooool3o`000<[ooooo00Go0000ooooooooooooooooo`00
0013ooooo`00>?ooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RHob4Q8Oo^k^h01_oo
ool00ol0003oooooooooo`3:ooooo`05o`000?ooooooooooooooool00000@oooool003Sooooo00Go
0000ooooooooooooooooo`00000>ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0
b_ooool01Ol0003ooooooooooooooooo000004?ooooo000hooooo`05oa0@4?ooooooooooooooool@
41003oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0<[ooooo00Go0000oooooooo
ooooooooo`000013ooooo`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj
^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0<[ooooo00Go0000ooooooooooooooooo`00
0013ooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c006ooooo`03o`000?oooooooooo0<[ooooo00Go0000ooooooooooooooooo`000013ooooo`00
Doooool00ol0003oooooooooo`3:ooooo`05o`000?ooooooooooooooool00000@oooool005?ooooo
00?o0000ooooooooool0b_ooool01Ol0003ooooooooooooooooo000004?ooooo001Cooooo`03o`00
0?oooooooooo0<[ooooo00Co0000oooooooooooo0000A?ooool005?ooooo0_l0003;ooooo`04o`00
0?ooooooooooo`0004Cooooo001Cooooo`03o`000?oooooooooo0<[ooooo00Co0000oooooooooooo
0000A?ooool005?ooooo00?o0000ooooooooool0b_ooool01?l0003oooooooooool00014ooooo`00
Doooool00ol0003oooooooooo`3:ooooo`04o`000?ooooooooooo`0004Cooooo001Cooooo`03o`00
0?oooooooooo0<[ooooo00Co0000oooooooooooo0000A?ooool005?ooooo00?o0000ooooooooool0
b_ooool01?l0003oooooooooool00014ooooo`00Doooool00ol0003oooooooooo`3;ooooo`03o`00
0?oooooo000004Cooooo001Cooooo`03o`000?oooooooooo0<_ooooo00?o0000ooooool00000A?oo
ool005?ooooo0_l0003<ooooo`03o`000?oooooo000004Cooooo001Cooooo`03o`000?oooooooooo
0<_ooooo00?o0000ooooool00000A?ooool005?ooooo00?o0000ooooooooool0boooool00ol0003o
ooooo`000014ooooo`00Doooool00ol0003oooooooooo`3;ooooo`03o`000?oooooo000004Cooooo
001Cooooo`03o`000?oooooooooo0<_ooooo00?o0000ooooool00000A?ooool005?ooooo00?o0000
ooooooooool0boooool00ol0003oooooo`000014ooooo`00Doooool00ol0003oooooooooo`3;oooo
o`;o0000AOooool005?ooooo00?o0000ooooooooool0boooool2o`0004Gooooo001Cooooo`;o0000
cOooool00ol0003oooooooooo`13ooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001C
ooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCoooo
o`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo
4oooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2o`000003oa0@
4?oooooooooo00Cooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
oooooolCooooo`00>?ooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00006ooooo`?o0000
oooooolCooooo`00>?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo
00001oooool00ol0003oooooooooo`3ooooooa?ooooo000hooooo`05o`000?ooooooooooooooool0
00002oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo0?oooooo4oooool003So
oooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo00?o0000oooo
ooooool0oooooolCooooo`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4
A?l000001oooool00ol0003oooooooooo`3ooooooa?ooooo000hooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0?oooooo4oooool005?o
oooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo
001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Coooo
o`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00
Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4ooo
ool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooo
oa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo0_l0003ooooooaCooooo
001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolC
ooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oo
oooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003ooooooooo
o`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo0_l0003ooooo
oaCooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0
oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooo
oooo0?oooooo4oooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1?ooool0
1Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40
1_ooool00ol0003oooooooooo`3ooooooa?ooooo000hooooo`05oa0@4?ooooooooooooooool@4100
2oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0oooooolCooooo`00
>?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@06oooo
o`?o0000oooooolCooooo`00>?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oeEE
EOl0003o410@olc<c006ooooo`03o`000?oooooooooo0?oooooo4oooool003Sooooo00Go410@oooo
oooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000ooooooooool0oooooolC
ooooo`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P02?ooool0
0ol0003oooooooooo`3ooooooa?ooooo000hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool0
1?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000
ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03
o`000?oooooooooo0?oooooo4oooool005?ooooo0_l0003ooooooaCooooo001Cooooo`03o`000?oo
oooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0
003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo
00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001C
ooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo0_l0003ooooooaCooooo001Cooooo`03
o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Dooo
ool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool0
05?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?o
oooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooo
oolCooooo`00Doooool2o`000?oooooo5?ooool005?ooooo00?o0000ooooooooool0oooooolCoooo
o`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo
4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool00ol0003ooooo
ooooo`3ooooooa?ooooo000hooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo
00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?oooooo4oooool003Sooooo
00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool000001_ooool00ol0
003oooooooooo`3ooooooa?ooooo000hooooo`05o`000?ooooooooooooooool000002oooool01Olb
<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0003ooooooa?ooooo000hooooo`05o`000?oooooooooo
ooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0oooo
oolCooooo`00>?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj^_oooooo^[Zj
oa0@4006ooooo`03o`000?oooooooooo0?oooooo4oooool003Sooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`3ooooooa?o
oooo000hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`000?l@413oZJVY
00Kooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?o
oooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooo
oolCooooo`00Doooool2o`000?oooooo5?ooool005?ooooo00?o0000ooooooooool0oooooolCoooo
o`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo
4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3o
oooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000oooooooo
ool0oooooolCooooo`00Doooool2o`000?oooooo5?ooool005?ooooo00?o0000ooooooooool0oooo
oolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo
0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003ooooo
ooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000
ooooooooool0oooooolCooooo`00Doooool2o`000?oooooo5?ooool005?ooooo00?o0000oooooooo
ool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oo
oooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0
003oooooooooo`3ooooooa?ooooo0019ooooo`Co000000?o410@ooooooooool00oooool00ol0003o
ooooooooo`3ooooooa?ooooo001;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
oooooolCooooo`00Boooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0?oooooo4ooo
ool004_ooooo00?o0000ooooooooool01Oooool3o`000?oooooo4oooool004_ooooo00?o0000oooo
ooooool0oooooolKooooo`00Boooool00ol0003oooooooooo`3ooooooa_ooooo001;ooooo`03o`00
0?oooooooooo0?oooooo6oooool004Wooooo00?oEEEEofIVI_l00000oooooolMooooo`00N?ooool3
o`000003oa0@4?oooooooooo0>[ooooo001jooooo`03oa0@4?nj^[[ooooo00Oooooo0_l0000;oooo
o`03o`000?nj^[[ooooo00cooooo0_l00005ooooo`03o`000?nj^[[ooooo0;kooooo001jooooo`03
oiRHV?lb<S;ooooo00Oooooo00?o0000ooooooooool02_ooool2oc8b<Pkooooo00?o0000oooooooo
ool00oooool2oc8b<[oooooo001jooooo`03omgMgOl0003o^[Zj00Oooooo00Co0000oooooooooooo
oooo0_l00002ooooo`;o00000oooool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0003o0000odA4
A?nj^[X01?ooool00ol0003oooooooooo`03ooooo`03ohN7Qol0003o^[Zj00cooooo00GoV9RHo`00
0?l0003oA4A4okZj^P0Aooooo`Go00000oooool01?l@413o0000odA4A?o<c<b@ooooo`00N_ooool0
0omEEEGoMgMgodA4A007ooooo`0:o`000?ooooooooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgM
g@?ooooo00?oc<c<o`000?l@41001?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo00?o0000
ooooooooool00oooool00oo<c<co0000oa0@400<ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41002Ooo
ool6o`0000;ooooo00GoV9RHob4Q8Oo^k^koooooodA4A005ooooo`03oiRHV?l@413ogMgM08oooooo
001iooooo`05omgMgOl@413oooooob4Q8OoMgMd01_ooool00ol0003oooooooooo`02ooooo`04omgM
gOl0003o410@olc<c0_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo01Cooooo00?oV9RHob4Q8Oo^k^h01oooool00on7QhOoEEEEooooo`2>ooooo`00
NOooool01OmVIVKoQhN7oooooonHV9SoEEEE00Kooooo00?o0000ooooooooool00_ooool01?o^k^ko
8B4Qoa0@4?o^k^h;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0;ooooo`Ko00001?ooool00onHV9So8B4Qonk^kP03ooooo`05olc<c?lQ8B7o0000
oeEEEOl00000Soooool007Sooooo00?ok^k^o`000?o^k^h00_ooool00ol0003ogMgMooooo`04oooo
o`03o`000?oooooooooo00;ooooo00Co8B4QogMgMomgMgOo<S8b2oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool05_ooool00omgMgOoIVIVooooo`02
ooooo`05ob4Q8On7QhOooooooiRHV?l00000Soooool007Sooooo00Co410@o`000?l0003ooooo0_l0
00000ol@413oooooooooo`03ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000Sooooo
00?o410@o`000?l000000ol00005ooooo`03o`000?oooooooooo013ooooo00?o410@o`000?l00000
0ol0000Fooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`2=ooooo`00
Q?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0Cooooo`05o`000?nj^[[ooooooiRHV?l@41000oooool01OlQ8B7o
V9RHoooooomgMgOoEEEE08oooooo0024ooooo`;o00004_ooool00ol0003oooooooooo`05ooooo`;o
00005?ooool00ol0003oooooooooo`0Cooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`00oooool01Oo<
c<co410@o`000?lb<S;ok^k^08oooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-3.4116, -0.234311, \
0.0510397, 0.00762314}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.230769 0.0769231 0.103006 0.515028 [
[.07692 .09051 -6 -9 ]
[.07692 .09051 6 0 ]
[.38462 .09051 -3 -9 ]
[.38462 .09051 3 0 ]
[.53846 .09051 -3 -9 ]
[.53846 .09051 3 0 ]
[.69231 .09051 -3 -9 ]
[.69231 .09051 3 0 ]
[.84615 .09051 -3 -9 ]
[.84615 .09051 3 0 ]
[1 .09051 -6 -9 ]
[1 .09051 6 0 ]
[1.025 .10301 0 -6 ]
[1.025 .10301 10 6 ]
[.21827 0 -24 -4.5 ]
[.21827 0 0 4.5 ]
[.21827 .20601 -18 -4.5 ]
[.21827 .20601 0 4.5 ]
[.21827 .30902 -18 -4.5 ]
[.21827 .30902 0 4.5 ]
[.21827 .41202 -18 -4.5 ]
[.21827 .41202 0 4.5 ]
[.21827 .51503 -18 -4.5 ]
[.21827 .51503 0 4.5 ]
[.21827 .61803 -6 -4.5 ]
[.21827 .61803 0 4.5 ]
[.5 .63053 -41 0 ]
[.5 .63053 41 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.07692 .10301 m
.07692 .10926 L
s
[(-2)] .07692 .09051 0 1 Mshowa
.38462 .10301 m
.38462 .10926 L
s
[(2)] .38462 .09051 0 1 Mshowa
.53846 .10301 m
.53846 .10926 L
s
[(4)] .53846 .09051 0 1 Mshowa
.69231 .10301 m
.69231 .10926 L
s
[(6)] .69231 .09051 0 1 Mshowa
.84615 .10301 m
.84615 .10926 L
s
[(8)] .84615 .09051 0 1 Mshowa
1 .10301 m
1 .10926 L
s
[(10)] 1 .09051 0 1 Mshowa
.125 Mabswid
.11538 .10301 m
.11538 .10676 L
s
.15385 .10301 m
.15385 .10676 L
s
.19231 .10301 m
.19231 .10676 L
s
.26923 .10301 m
.26923 .10676 L
s
.30769 .10301 m
.30769 .10676 L
s
.34615 .10301 m
.34615 .10676 L
s
.42308 .10301 m
.42308 .10676 L
s
.46154 .10301 m
.46154 .10676 L
s
.5 .10301 m
.5 .10676 L
s
.57692 .10301 m
.57692 .10676 L
s
.61538 .10301 m
.61538 .10676 L
s
.65385 .10301 m
.65385 .10676 L
s
.73077 .10301 m
.73077 .10676 L
s
.76923 .10301 m
.76923 .10676 L
s
.80769 .10301 m
.80769 .10676 L
s
.88462 .10301 m
.88462 .10676 L
s
.92308 .10301 m
.92308 .10676 L
s
.96154 .10301 m
.96154 .10676 L
s
.03846 .10301 m
.03846 .10676 L
s
.25 Mabswid
0 .10301 m
1 .10301 L
s
gsave
1.025 .10301 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.23077 0 m
.23702 0 L
s
[(-0.2)] .21827 0 1 0 Mshowa
.23077 .20601 m
.23702 .20601 L
s
[(0.2)] .21827 .20601 1 0 Mshowa
.23077 .30902 m
.23702 .30902 L
s
[(0.4)] .21827 .30902 1 0 Mshowa
.23077 .41202 m
.23702 .41202 L
s
[(0.6)] .21827 .41202 1 0 Mshowa
.23077 .51503 m
.23702 .51503 L
s
[(0.8)] .21827 .51503 1 0 Mshowa
.23077 .61803 m
.23702 .61803 L
s
[(1)] .21827 .61803 1 0 Mshowa
.125 Mabswid
.23077 .02575 m
.23452 .02575 L
s
.23077 .0515 m
.23452 .0515 L
s
.23077 .07725 m
.23452 .07725 L
s
.23077 .12876 m
.23452 .12876 L
s
.23077 .15451 m
.23452 .15451 L
s
.23077 .18026 m
.23452 .18026 L
s
.23077 .23176 m
.23452 .23176 L
s
.23077 .25751 m
.23452 .25751 L
s
.23077 .28327 m
.23452 .28327 L
s
.23077 .33477 m
.23452 .33477 L
s
.23077 .36052 m
.23452 .36052 L
s
.23077 .38627 m
.23452 .38627 L
s
.23077 .43777 m
.23452 .43777 L
s
.23077 .46353 m
.23452 .46353 L
s
.23077 .48928 m
.23452 .48928 L
s
.23077 .54078 m
.23452 .54078 L
s
.23077 .56653 m
.23452 .56653 L
s
.23077 .59228 m
.23452 .59228 L
s
.25 Mabswid
.23077 0 m
.23077 .61803 L
s
gsave
.5 .63053 -102 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
93.000 13.000 moveto
(D) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
123.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(=) show
129.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(30) show
141.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.85099 .10301 m
.85147 .10301 L
.85328 .10301 L
.85496 .10301 L
.85681 .10301 L
.85785 .10301 L
.85879 .10301 L
.8607 .10301 L
.86177 .10301 L
.86277 .10301 L
.86459 .10301 L
.86551 .10301 L
.86653 .10301 L
.86827 .10301 L
.87017 .10304 L
.87113 .10311 L
.87216 .10332 L
.87401 .10458 L
.87585 .10867 L
.8776 .11783 L
.87916 .13259 L
.88086 .15648 L
.88476 .22945 L
.88571 .24581 L
.88673 .26056 L
.88785 .27235 L
.8889 .27862 L
.88985 .28018 L
.89088 .27759 L
.89277 .26314 L
.8946 .24079 L
.89631 .21683 L
.89807 .19217 L
.89997 .16831 L
.90164 .15084 L
.90341 .13631 L
.90501 .12637 L
.90676 .11843 L
.90836 .11335 L
.90985 .11001 L
.91172 .1072 L
.91349 .10553 L
.91508 .10459 L
.91681 .10394 L
.91869 .10352 L
.91964 .10339 L
.92068 .10328 L
.92253 .10315 L
.92426 .10309 L
.92598 .10305 L
Mistroke
.92781 .10303 L
.92954 .10302 L
.93111 .10301 L
.93296 .10301 L
.934 .10301 L
.93496 .10301 L
.93673 .10301 L
.93859 .10301 L
.94038 .10301 L
.9423 .10301 L
.94412 .10301 L
.94577 .10301 L
.94678 .10301 L
.94771 .10301 L
.94873 .10301 L
.94982 .10301 L
.95165 .10301 L
.95268 .10301 L
.95366 .10301 L
.95523 .10301 L
.95695 .10301 L
.95874 .10301 L
.96041 .10301 L
.96198 .10301 L
.96341 .10301 L
.96505 .10301 L
.96661 .10301 L
.9683 .10301 L
.9701 .10301 L
.97163 .10301 L
.97331 .10301 L
.97512 .10301 L
.97614 .10301 L
.97707 .10301 L
.97887 .10301 L
.98058 .10301 L
.98239 .10301 L
.98341 .10301 L
.98435 .10301 L
.98608 .10301 L
.9879 .10301 L
.98954 .10301 L
.99106 .10301 L
.99274 .10301 L
.99453 .10301 L
.99645 .10301 L
.99753 .10301 L
.99853 .10301 L
Mfstroke
.99853 .10301 m
1 .10301 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00>?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Go
oooo0_lQ8B44ooooo`Go0000oooooolLooooo`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B44ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0oooooolLooooo`00<?ooool6o`0000;o
oooo00Go410@oooooooooooooooooa0@400<ooooo`03oiRHV?lQ8B7ok^k^0?oooooo7Oooool003So
oooo00Go0000ooooooooooooooooo`00000=ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003ooooo
oa?ooooo000hooooo`05o`000?ooooooooooooooool000003_ooool00omgMgOoIVIVooooo`05oooo
o`03o`000?oooooooooo0?oooooo4oooool003Sooooo00Go410@oooooooooooooooooa0@400?oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooo
oooo0?oooooo4oooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooo
oooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003ooooooooo
o`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000oooo
ooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`00
0?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool0
0ol0003oooooooooo`3ooooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o
0000ooooooooool0oooooolCooooo`008oooool5o`0002_ooooo00?o0000ooooooooool0:oooool5
o`0002kooooo0_l000000ol@413oooooooooo`0Zooooo`05onk^k_lb<S;o0000oa0@4?o<c<`0;?oo
ool01Oo<c<co8B4Qo`000?lQ8B7oc<c<02Wooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`00
0?lb<S;ok^k^6_ooool002?ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00[ooooo`03o`000?oooooo
oooo02_ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00_ooooo`03o`000?oooooooooo02_ooooo00Go
EEEEogMgMoooooooV9RHob4Q8@0/ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B40:oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool001_ooooo1_l00003ooooo`03
oiRHV?lQ8B7ok^k^02cooooo00?o0000ooooooooool0;?ooool00onHV9So8B4Qonk^kP0]ooooo`Go
0000;?ooool01Ol0003ooooooooooooooooo000002cooooo00Go0000ooooooooooooooooo`00000[
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Jooooo`009Oooool0
0onHV9So8B4Qonk^kP0[ooooo`03o`000?oooooooooo02gooooo00?oV9RHob4Q8Oo^k^h0;?ooool0
1?m4A4CogMgMooooool0000]ooooo`05o`000?nHV9SooooooiRHV?lQ8B40;?ooool01Olb<S;oV9RH
oooooonHV9So<S8b02_ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
01[ooooo000Vooooo`03ogMgMomVIVKooooo02[ooooo0_l0000_ooooo`03ogMgMomVIVKooooo02_o
oooo00CogMgMoeEEEOoooooo0000;Oooool01Ol0003oEEEEo`000?l@413oc<c<02cooooo00Goc<c<
o`000?l0003o0000olc<c00[ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Jooooo`009oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool0:oooool00omgMgOoc<c<o`00000]ooooo`03oeEEEOn7QhOooooo02kooooo00Go
410@okZj^_oooooo^[Zjoa0@400[ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooo
oooooa0@400Jooooo`008oooool01Ol0003o^[ZjoooooonHV9So410@02_ooooo00?o0000oooooooo
ool0:oooool01Ol0003o^[ZjoooooonHV9So410@02gooooo00?ok^k^odA4A?l00000;Oooool00ooM
gMgo410@oiRHV00^ooooo`05o`000?nj^[[ooooookZj^_l00000:oooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL06_ooool002?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00[ooooo`03o`000?oooooooooo02_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00^ooooo`03ogMg
Mol0003ooooo02gooooo00Coc<c<odA4A?l0003o410@;?ooool01OnYZJWo410@o`000?l@413oZJVY
02Wooooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^01[ooooo001Coooo
o`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00
Doooool00ol0003oooooooooo`3mooooo`;o00000_ooool2o`0000oooooo001Cooooo`03o`000?oo
oooooooo0?gooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd?ooooo`00Doooool00ol0003ooooo
ooooo`3nooooo`04omgMgOl0003o410@olc<c13ooooo000:oooooooo0000@?l0000;ooooo`04onk^
k_lQ8B7o410@onk^kQ3ooooo000Fooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Kooooo00Co0000oooooooooooo
00002?ooool01?l0003oooooooooool0000<ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool02Oooool01?lQ8B7oMgMgogMgMolb<S8@ooooo`008_ooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooooooo02kooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooooooo02kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02?ooool2o`0000;ooooo0_l0000?oooo
o`00Doooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0>_ooool005?ooooo00?o0000ooooooooool0boooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo03_ooooo001Cooooo`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0kooooo`00Doooool00ol0003oooooooooo`3;ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0>oooool005?ooooo00?o0000ooooooooool0boooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo03_ooooo001Cooooo`;o0000c?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo03_ooooo001Cooooo`03o`000?oooooooooo0<_ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0looooo`00Doooool00ol0003ooooooooo
o`3;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0??ooool005?ooooo00?o0000
ooooooooool0boooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03cooooo001Coooo
o`03o`000?oooooooooo0<_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0loooo
o`00Doooool00ol0003oooooooooo`3;ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0??ooool005?ooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo03cooooo001Cooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0looooo`00Doooool2o`000<gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0looooo`00Doooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0??ooool005?ooooo00?o0000ooooooooool0c?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo03gooooo001Cooooo`03o`000?oooooooooo0<cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0mooooo`00Doooool00ol0003ooooooooo
o`3<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0?Oooool005?ooooo00?o0000
ooooooooool0c?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03gooooo001Coooo
o`03o`000?oooooooooo0<cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0moooo
o`00Doooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0?Oooool005?ooooo0_l0003=ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
?Oooool005?ooooo00?o0000ooooooooool0c?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo03gooooo001Cooooo`03o`000?oooooooooo0<cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0mooooo`00Doooool00ol0003oooooooooo`3<ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool0?Oooool005?ooooo00?o0000ooooooooool0c?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo03gooooo001Cooooo`03o`000?oooooooooo0<gooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0mooooo`00>?ooool01Oo^k^ko<S8bo`00
0?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001_ooool00ol0003oooooooooo`3=ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0?Oooool003Sooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`;o8B4Q1?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000oooooooo
ool0cOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo03gooooo000hooooo`05oa0@
4?ooooooooooooooool@41003?ooool00onHV9So8B4Qonk^kP07ooooo`?o0000cOooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo03gooooo000hooooo`05o`000?ooooooooooooooool0
00003Oooool00onHV9So8B4Qonk^kP06ooooo`03o`000?oooooooooo0<gooooo00Go0000oooooooo
ooooooooo`000010ooooo`00>?ooool01Ol0003ooooooooooooooooo000000kooooo00?oMgMgofIV
I_ooool01Oooool00ol0003oooooooooo`3=ooooo`05o`000?ooooooooooooooool00000@?ooool0
03Sooooo00Go410@oooooooooooooooooa0@400?ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0cOooool01Ol0003ooooooooooooooooo0000043ooooo000hooooo`05ogMgMonHV9So
oooooiRHV?mgMgL02oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0
cOooool01Ol0003ooooooooooooooooo0000043ooooo000hooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0cOooool01Ol0
003ooooooooooooooooo0000043ooooo001Cooooo`03o`000?oooooooooo0<gooooo00Go0000oooo
ooooooooooooo`000010ooooo`00Doooool00ol0003oooooooooo`3=ooooo`05o`000?oooooooooo
ooooool00000@?ooool005?ooooo00?o0000ooooooooool0cOooool01?l0003oooooooooool00011
ooooo`00Doooool2o`000<kooooo00Co0000oooooooooooo0000@Oooool005?ooooo00?o0000oooo
ooooool0cOooool01?l0003oooooooooool00011ooooo`00Doooool00ol0003oooooooooo`3>oooo
o`03o`000?oooooo0000047ooooo001Cooooo`03o`000?oooooooooo0<kooooo00?o0000ooooool0
0000@Oooool005?ooooo00?o0000ooooooooool0c_ooool00ol0003oooooo`000011ooooo`00Dooo
ool00ol0003oooooooooo`3>ooooo`03o`000?oooooo0000047ooooo001Cooooo`03o`000?oooooo
oooo0<kooooo00?o0000ooooool00000@Oooool005?ooooo00?o0000ooooooooool0c_ooool00ol0
003oooooo`000011ooooo`00Doooool2o`000<oooooo00?o0000ooooool00000@Oooool005?ooooo
00?o0000ooooooooool0c_ooool00ol0003oooooo`000011ooooo`00Doooool00ol0003ooooooooo
o`3>ooooo`03o`000?oooooo0000047ooooo001Cooooo`03o`000?oooooooooo0<kooooo00?o0000
ooooool00000@Oooool005?ooooo00?o0000ooooooooool0c_ooool00ol0003oooooo`000011oooo
o`00Doooool00ol0003oooooooooo`3>ooooo`;o0000@_ooool005?ooooo00?o0000ooooooooool0
coooool00ol0003oooooooooo`10ooooo`00Doooool00ol0003oooooooooo`3?ooooo`03o`000?oo
oooooooo043ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003oooooooooo`3ooooo
oa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0
oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooo
oooo0?oooooo4oooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2
o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0oooooolCooooo`00>?ooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol00006
ooooo`?o0000oooooolCooooo`00>?ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4
omgMgOoooooo00001oooool00ol0003oooooooooo`3ooooooa?ooooo000hooooo`05o`000?oooooo
ooooooooool000002oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo0?oooooo
4oooool003Sooooo00Go410@oooooooooooooooooa0@400<ooooo`03ogMgMoo<c<co000000Oooooo
00?o0000ooooooooool0oooooolCooooo`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo
00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`3ooooooa?ooooo000hooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo0?oooooo
4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3o
oooooa?ooooo001Cooooo`;o0000oooooolDooooo`00Doooool00ol0003oooooooooo`3ooooooa?o
oooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooo
oolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo
0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003ooooo
ooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo0_l0003o
oooooaCooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000oooooooo
ool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oo
oooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0
003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo
0_l0003ooooooaCooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000
ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03
o`000?oooooooooo0?oooooo4oooool003Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1?ooool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0oooooolCoooo
o`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooo
oiRHV?lQ8B401_ooool00ol0003oooooooooo`3ooooooa?ooooo000hooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0oooo
oolCooooo`00>?ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RH
ob4Q8@06ooooo`?o0000oooooolCooooo`00>?ooool01Ol0003ooooooooooooooooo000000_ooooo
00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo0?oooooo4oooool003Sooooo
00Go410@oooooooooooooooooa0@400;ooooo`03oeEEEOn7QhOooooo00Sooooo00?o0000oooooooo
ool0oooooolCooooo`00>?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nH
V9P02?ooool00ol0003oooooooooo`3ooooooa?ooooo000hooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h03?ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo0?oooooo4oooool005?o
oooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo
001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo0_l0003ooooooaCooooo001Coooo
o`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00
Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4ooo
ool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooo
oa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo0_l0003ooooooaCooooo
001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolC
ooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oo
oooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003ooooooooo
o`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000oooo
ooooool0oooooolCooooo`00Doooool2o`000?oooooo5?ooool005?ooooo00?o0000ooooooooool0
oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooo
oooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00>?ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`01_ooool0
0ol0003oooooooooo`3ooooooa?ooooo000hooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2
ob4Q8@Cooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo0?oooooo4ooo
ool003Sooooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000
1_ooool00ol0003oooooooooo`3ooooooa?ooooo000hooooo`05o`000?ooooooooooooooool00000
2oooool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol0003ooooooa?ooooo000hooooo`05o`00
0?ooooooooooooooool000002oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000oooo
ooooool0oooooolCooooo`00>?ooool01Ol@413ooooooooooooooooo410@00_ooooo00Go410@okZj
^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo0?oooooo4oooool003Sooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003ooooooooo
o`3ooooooa?ooooo000hooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnYZJWo410@o`00
0?l@413oZJVY00Kooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003ooooooooo
o`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000oooo
ooooool0oooooolCooooo`00Doooool2o`000?oooooo5?ooool005?ooooo00?o0000ooooooooool0
oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooo
oooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool00ol0003o
ooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o
0000ooooooooool0oooooolCooooo`00Doooool2o`000?oooooo5?ooool005?ooooo00?o0000oooo
ooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`00
0?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00Doooool0
0ol0003oooooooooo`3ooooooa?ooooo001Cooooo`03o`000?oooooooooo0?oooooo4oooool005?o
oooo00?o0000ooooooooool0oooooolCooooo`00Doooool2o`000?oooooo5?ooool005?ooooo00?o
0000ooooooooool0oooooolCooooo`00Doooool00ol0003oooooooooo`3ooooooa?ooooo001Coooo
o`03o`000?oooooooooo0?oooooo4oooool005?ooooo00?o0000ooooooooool0oooooolCooooo`00
Doooool00ol0003oooooooooo`3ooooooa?ooooo0019ooooo`Co000000?o410@ooooooooool00ooo
ool00ol0003oooooooooo`3ooooooa?ooooo001;ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0oooooolCooooo`00Boooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
0?oooooo4oooool004_ooooo00?o0000ooooooooool01Oooool3o`000?oooooo4oooool004_ooooo
00?o0000ooooooooool0oooooolKooooo`00Boooool00ol0003oooooooooo`3ooooooa_ooooo001;
ooooo`03o`000?oooooooooo0?oooooo6oooool004Wooooo00?oEEEEofIVI_l00000oooooolMoooo
o`00N?ooool3o`000003oa0@4?oooooooooo0>[ooooo001jooooo`03oa0@4?nj^[[ooooo00Oooooo
0_l0000;ooooo`03o`000?nj^[[ooooo00cooooo0_l00005ooooo`03o`000?nj^[[ooooo0;kooooo
001jooooo`03oiRHV?lb<S;ooooo00Oooooo00?o0000ooooooooool02_ooool2oc8b<Pkooooo00?o
0000ooooooooool00oooool2oc8b<[oooooo001jooooo`03omgMgOl0003o^[Zj00Oooooo00Co0000
oooooooooooooooo0_l00002ooooo`;o00000oooool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0
003o0000odA4A?nj^[X01?ooool00ol0003oooooooooo`03ooooo`03ohN7Qol0003o^[Zj00cooooo
00GoV9RHo`000?l0003oA4A4okZj^P0Aooooo`05oiRHV?l@413o0000oc8b<_o<c<`00oooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^08oooooo001jooooo`03oeEEEOmgMgOoA4A400Oooooo00[o0000oooo
ooooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0oooool00oo<c<co0000oa0@4004ooooo`05
oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003oooooooooo`03ooooo`03olc<c?l0003o410@
00cooooo00Go410@okZj^_o^k^koMgMgoa0@4009ooooo`Ko00000_ooool01Ol@413o^[Zjoooooomg
MgOo<S8b00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`2?ooooo`00NOooool01OoMgMgo410@oooo
oolQ8B7ogMgM00Kooooo00?o0000ooooooooool00_ooool01?oMgMgo0000oa0@4?o<c<`;ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Gooooo`05
o`000?ooooooooooooooool@41000oooool00ol@413oooooooooo`2=ooooo`00NOooool01OmVIVKo
QhN7oooooonHV9SoEEEE00Kooooo00?o0000ooooooooool00_ooool01?o^k^ko8B4Qoa0@4?o^k^h;
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0;
ooooo`Ko00001Oooool00onYZJWo410@ooooo`02ooooo`05o`000?ooooooooooooooool00000Sooo
ool007Sooooo00?ok^k^o`000?o^k^h00_ooool00ol0003ogMgMooooo`04ooooo`03o`000?oooooo
oooo00;ooooo00Co8B4QogMgMomgMgOo<S8b2oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool05Oooool00ol@413o0000okZj^P03ooooo`05o`000?oo
ooooooooooooool00000Soooool007Sooooo00Co410@o`000?l0003ooooo0_l000000ol@413ooooo
ooooo`03ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000Sooooo00?o410@o`000?l0
00000ol00005ooooo`03o`000?oooooooooo013ooooo00?o410@o`000?l000000ol0000Eooooo`03
okZj^_lQ8B7ooooo00;ooooo00Go410@oooooooooooooooooa0@402?ooooo`00Q?ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0Cooooo`05oa0@4?nHV9SooooookZj^_l000000oooool01OmgMgOoV9RHoooooonHV9So
MgMg08oooooo0024ooooo`;o00004_ooool00ol0003oooooooooo`05ooooo`;o00005?ooool00ol0
003oooooooooo`0Cooooo`05ojVYZOl@413o0000oa0@4?nYZJT00oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^08oooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-3.4116, -0.234311, \
0.0510397, 0.00762314}}]
}, Closed]]
}, Open  ]],

Cell[TextData[{
  "As the ",
  "wave packet",
  " propagates into the heavier region of the string where ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(c(x)\), Cell[""]}], TraditionalForm]]],
  "decreases, the packet  slows and becomes smaller. It also narrows, because \
the back of the packet catches up with the front as the packet slows down."
}], "Text"],

Cell[TextData[{
  "\t We also observed this narrowing of the packet when we analyzed the \
motion of a hanging string in Chapter 4, Sec. ",
  ButtonBox["4.2",
    ButtonData:>{"Chapter4.nb", "c:21"},
    ButtonStyle->"Hyperlink"],
  ". There however, it was the tension that varied with position, not the \
mass. As a result, the amplitude of the packet ",
  StyleBox["increased",
    FontSlant->"Italic"],
  " as the packet slowed and narrowed, rather than decreasing as it does \
here. The reason for this difference in behavior between strings with \
nonuniform tension and nonuniform mass density will be taken up in the \
exercises. "
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["WKB Waves in Two Dimensions: Water Waves Near the Shore", "Section",
  CellTags->{"i:75", "c:25"}],

Cell[TextData[{
  "Waves in shallow water of varying depth ",
  Cell[BoxData[
      FormBox[
        RowBox[{"h", "(", 
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  ", with amplitude ",
  Cell[BoxData[
      FormBox[
        RowBox[{"z", "(", 
          RowBox[{
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[",",
              FontWeight->"Plain"], 
            StyleBox["t",
              FontWeight->"Plain"]}], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  ", are described by the following wave equation:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[PartialD]\^2 z\/\[PartialD]t\^2\), "=", 
          RowBox[{"\[Del]", 
            RowBox[{"\[CenterDot]", 
              RowBox[{"(", 
                RowBox[{
                  RowBox[{\(c\^2\), "(", 
                    StyleBox["r",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], ")"}], \(\[Del]z\)}], ")"}]}]}]}], 
        TraditionalForm]]],
  ","
}], "NE2",
  CellTags->"(5.2.31)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(c\^2\), "(", 
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{
            StyleBox["g",
              FontWeight->"Plain"], 
            StyleBox[" ",
              FontWeight->"Plain"], 
            RowBox[{
              StyleBox["h",
                FontWeight->"Plain"], 
              StyleBox["(",
                FontWeight->"Plain"], 
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], ")"}]}]}], TraditionalForm]]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`g\)]],
  " is the acceleration of gravity. Equation ",
  ButtonBox["(5.2.31)",
    ButtonData:>"(5.2.31)",
    ButtonStyle->"Hyperlink"],
  " is a generalization of Eqs. ",
  ButtonBox["(3.1.78)",
    ButtonData:>{"Chapter3.nb", "(3.1.78)"},
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(3.1.79)",
    ButtonData:>{"Chapter3.nb", "(3.1.79)"},
    ButtonStyle->"Hyperlink"],
  " for varying depth and propagation in two dimensions, with  ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox[\((x, y)\),
            FontWeight->"Plain"]}], TraditionalForm]]],
  ". This equation follows from the same arguments that led to Eq. ",
  ButtonBox["(3.1.78)",
    ButtonData:>{"Chapter3.nb", "(3.1.78)"},
    ButtonStyle->"Hyperlink"],
  ". It provides a useful model for a discussion of wave propagation in \
inhomogeneous 2D systems. "
}], "Text"],

Cell[TextData[{
  "\tFor simplicity, we will assume that ",
  Cell[BoxData[
      \(TraditionalForm\`h = h(x)\)]],
  " only, so that there is no ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " -dependence to the water depth.  In this case, traveling-wave solutions \
to Eq. ",
  ButtonBox["(5.2.31)",
    ButtonData:>"(5.2.31)",
    ButtonStyle->"Hyperlink"],
  " are of the form ",
  Cell[BoxData[
      \(TraditionalForm\`z\  = \ \(\[ExponentialE]\^\(\[ImaginaryI](\(k\_y\) 
                    y - \[Omega]\ t)\)\) \(\[Psi](x)\)\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`k\_y\)]],
  " is the ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  "-component of the wavenumber, a constant. The function ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\)]],
  " satisfies the ODE"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\[PartialD]\/\[PartialD]x\)[\(1\/\(\(k\_x\^2\)(
                  x, \[Omega], 
                  k\_y)\)\) \(\[PartialD]\/\[PartialD]x\) \(\[Psi](
              x)\)] = \(-\ \(\[Psi](x)\)\)\)]],
  ","
}], "NE2",
  CellTags->"(5.2.32)"],

Cell["where", "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(k\_x\%2\)(x, \[Omega], 
        k\_y) = \[Omega]\^2/\(\(c\^2\)(x)\)\  - \ k\_y\^2\)]]], "NE2",
  CellTags->"(5.2.33)"],

Cell[TextData[{
  " is the square of the ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  "-component of the wave vector.  Equation ",
  ButtonBox["(5.2.33)",
    ButtonData:>"(5.2.33)",
    ButtonStyle->"Hyperlink"],
  " can be rearranged to read"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\^\(\(2\)\(\ \)\) = \(\(c\^2\)(
            x)\)\ \((k\_x\^2 + k\_y\^2)\)\)]],
  ","
}], "NE2",
  CellTags->"(5.2.34)"],

Cell[TextData[{
  "which is simply the dispersion relation for these waves. Since ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`k\_y\)]],
  " are constants, as ",
  Cell[BoxData[
      \(TraditionalForm\`c(x)\)]],
  " varies ",
  Cell[BoxData[
      \(TraditionalForm\`k\_x\)]],
  " must also vary in order to satisfy Eq. ",
  ButtonBox["(5.2.34)",
    ButtonData:>"(5.2.34)",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[TextData[{
  "\tEquation. ",
  ButtonBox["(5.2.3)",
    ButtonData:>"(5.2.3)",
    ButtonStyle->"Hyperlink"],
  " is a linear ODE that is similar in form to Eq. ",
  ButtonBox["(5.2.3)",
    ButtonData:>"(5.2.3)",
    ButtonStyle->"Hyperlink"],
  ", so WKB analysis can be used to follow the behavior of these \
shallow-water waves, provided that the depth varies little over a wavelength. \
 That is, we require that  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(k\_x\ L\  >> 1\)\(,\)\)\)]],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`L = \(\(|\)\(1/\[PartialD]\ 
                ln\ k\_x/\[PartialD]x\)\(|\)\)\)]],
  " is the scale length due to the depth variation. If this is so, then we \
can use the eikonal method discussed in the previous section, first writing \
",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi] = \[ExponentialE]\^\(S(x)\)\)]],
  ", and then approximating ",
  Cell[BoxData[
      \(TraditionalForm\`S(x)\)]],
  " in the WKB limit.  The result is"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`z(x, y, t) = 
        A\ \(\@\(\(k\_x\)(x, \[Omega], 
                k\_y)\)\) \[ExponentialE]\^\[ImaginaryI]\ [\(k\_y\ y\  \
\[PlusMinus] \ \[Integral]\^x\(\( k\_x\)(x, \[Omega], \ k\_y)\) \
\[DifferentialD]x\) - \[Omega]\ t]\)]],
  ","
}], "NE2",
  CellTags->"(5.2.35)"],

Cell[TextData[{
  "(see the exercises). Equation ",
  ButtonBox["(5.2.35)",
    ButtonData:>"(5.2.35)",
    ButtonStyle->"Hyperlink"],
  " describes a wave propagating in either the ",
  Cell[BoxData[
      \(TraditionalForm\`\(+x\)\)]],
  " or the ",
  Cell[BoxData[
      \(TraditionalForm\`\(-x\)\)]],
  " directions, and at the same time propagating in the ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " direction with wavenumber ",
  Cell[BoxData[
      \(TraditionalForm\`k\_y\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tFor example, let's assume that the water depth ",
  Cell[BoxData[
      \(TraditionalForm\`h(x)\)]],
  " decreases as ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " increases, according to"
}], "Text"],

Cell[TextData[{
  "  ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(h(x)\), "=", 
          TagBox[
            RowBox[{
              StyleBox["{",
                ShowAutoStyles->False,
                FontSize->16], 
              StyleBox[GridBox[{
                    {\(\(\(h\_o\) a/\((a + x)\)\)\(,\)\), \(x > 0\)},
                    {\(\(h\_o\)\(,\)\), \(x < 0\)}
                    }],
                ShowAutoStyles->False]}],
            (#&)]}], TraditionalForm]]]
}], "NE2",
  CellTags->"(5.2.36)"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000=P0002_1000`40O003h00OogooogooogooHgoo
003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mo
oomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogoo
ogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomS
Ool00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00
ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOooo
OoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomo
of=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo
003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mo
oomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogoo
ogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoo?Ool01D8@
00000000@Q0037oo0P00ogooP7oo003oOoo?Ool5000;Ool5003oOomnOol00?moolmoo`H00003@Q1o
ogoo00Ioo`03@Q00000000@00003HaQoogoo0?moogYoo`00ogoocgoo100000A24000001240Moo`@0
009oo`800?moogaoo`00ogoocgoo00=24000000017oo00<007ooOol01Goo0`0000E247ooOomoo`00
0?moogaoo`00ogooeWoo00<007ooOol01Goo0`0000I247ooOomood8@003oOomkOol00?moomIoo`03
HaP0048@00Aoo`05@Q000000001S6004Ool2@Q3oOomjOol00?moomQoo`8000=oo`@00?mooh5oo`00
ogoof7oo0P000goo1000ogooPGoo003oOooIOol01000@Q1oogoo1000ogooPGoo003oOooJOol00`00
@Q12400300000d8@Oomoo`3oOomoOol00?moomYoo`03@Q00000000<00?mooh9oo`00ogoofgoo1@00
ogooPWoo003oOooKOol400000d8@Oomoo`3oOon0Ool00?moom]oo`@00?mooh=oo`00ogoofgoo1000
ogooPgoo003oOooKOol4003oOon3Ool00?moomYoo`03HaP0000000800003@Q1oogoo0?mooh1oo`00
ogoofWoo00=2400000000`00ogooPWoo003oOooJOol01D8@00000000@Q000P00ogooPGoo003oOooJ
Ool0248@00000000@Q1oo`00@Q3oOon0Ool00?moomYoo`@00005HaQoogoo0012403oOomoOol00?mo
omYoo`@000=oo`03@Q000000009oo`<00?moogUoo`00ogoofWoo100017oo1`0000=247ooOol0ogoo
MWoo003oOooDOol5@Q0400000d8@Oomoo`03Ool00d8@0000000300000d8@Oomoo`3oOomfOol00?mo
omQoo`@000Uoo`04@Q000000003oOomiOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOooo
OoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomo
of=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo
003oOoooOoooOomSOol00?moomQoo`H00003@Q1oogoo0?mooh5oo`00PWoo5P00VWoo0d8@2@000d8@
00=S67ooOol0T7oo00=2424800000P00148@0P0000=246<HOol0Vgoo0d8@00<Q200000001P00148@
UWoo00=2400000004`0000=247ooOol097oo0023OolF002MOol00d8@00000004002FOol40007Ool3
002QOol6002LOolF000VOol008AooaD009ioo`D009Ioo`04@Q0000000008Ool4002QOol400000d8@
Oomoo`2KOolE000VOol008Aoo`03@Q00000001<009eoo`D009Ioo`<00003@Q1oogoo00Moo`@00:1o
o`@00003@Q1oogoo09aooaD002Eoo`00QGoo00A24000000Q20i240038@P0000009eoo`D009Eoo`05
@Q000000001S600:Ool300000d8@Oomoo`2MOol400000d8@Oomoo`2LOol016<H000000003d8@0P00
9Goo0027Ool2000@Ool2002LOol5002DOol5000;Ool4002OOol400000d8@Oomoo`2NOol200000d8@
Oomoo`0=Ool2000TOol008Qoo`80011oo`03001oogoo09Yoo`D009Aoo`D000]oo`05@Q0000000012
402NOol400000d8@Oomoo`2OOol2000@Ool00`00Oomoo`0ROol008Qoo`03@Q00000000moo`030012
47oo09Yoo`D009Aoo`@000aoo`05@Q0000000012402NOol400000d8@Oomoo`2POol2000?Ool2000S
Ool008Qoo`04HaP00000@Q2[Ool5002COol5000<Ool00d8@00000002002NOol400000d8@Oomoo`2P
Ool00b480012400cOol008Yoo`800003@Q1oogoo0:Qoo`D0099oo`03@Q00000000<000aoo`03@Q00
0000008009ioo`@00003@Q1oogoo0:5oo`<0039oo`00Rgoo0P00ZWoo1@00TWoo00=2400000000`00
37oo00=2400000000`00WGoo100000=247ooOol0XWoo0P0000=247ooOol0;goo001`Ool>000>Ool0
0b480012402<Ool>000>Ool5002BOol00d8@00000002000>Ool5002MOol400000d8@Oomoo`2SOol0
0d8@0012400`Ool0071oo`h000ioo`04@Q000000002;Ool>000>Ool5002BOol00d8@00000002000>
Ool5002MOol400000d8@Oomoo`2TOol3000_Ool0071oo`h000moo`<00003@Q1oogoo08Qoo`h000io
o`D0099oo`D000ioo`D009eoo`@00003@Q1oogoo0:Aoo`04@Q000000@Q0^Ool008ioo`<00:Ioo`D0
099oo`D000ioo`H009aoo`@00003@Q1oogoo0:Eoo`<002ioo`00Sgoo00=240000000YGoo1@00TWoo
1@003Woo1P00W7oo100000=247ooOol0YWoo00=240000000;Goo002@Ool3002TOol5002BOol5000>
Ool6002LOol400000d8@Oomoo`2WOol3000/Ool0091oo`04@Q000000@Q2SOol5002BOol5000>Ool6
002LOol400000d8@Oomoo`2WOol0148@00000000:goo002@Ool0148@00000000Xgoo1@00TWoo1@00
3Woo1P00W7oo100000=247ooOol0Ygoo00E240000000048@02Yoo`00TGoo1000XWoo1@00TWoo1@00
3Woo1P00W7oo100000=247ooOol0Z7oo1000:Woo002BOol4002QOol5002BOol5000>Ool6002LOol4
00000d8@Oomoo`2YOol4000YOol0099oo`D00:1oo`D0099oo`D000ioo`H009aoo`@00003@Q1oogoo
0:Uoo`D002Qoo`00TWoo00=2400000000P0000=S67ooOol0WGoo1@00TWoo1@003Woo1P00W7oo1000
00=247ooOol0ZGoo00=2400000000P0000=247ooOol09Goo002COol400000d8@Oomoo`2MOol5002B
Ool5000>Ool6002LOol400000d8@Oomoo`2ZOol5000WOol009=oo`@00003@Q1oogoo09eoo`D0099o
o`03@Q000000008000ioo`D009eoo`@00003@Q1oogoo0:Yoo`D002Moo`00Tgoo1@00Wgoo1@00TWoo
00=2400000000P003Woo1@00WGoo100000=247ooOol0ZWoo1@0000=247ooOol097oo0022Ool2@Q0?
Ool5002OOol5002BOol00d8@00000003000<Ool00d8@00000003002MOol400000d8@Oomoo`2IOol0
0f<H@Q1oo`0>Ool500000d8@Oomoo`0TOol0089oo`8000moo`D009moo`D0099oo`03@Q00000000<0
00aoo`03@Q000000008009ioo`@00003@Q1oogoo09Uoo`03@Q0007oo00ioo`D00003@Q1oogoo02Ao
o`00Pgoo00<0048@Ool037oo1P00Wgoo1@00Tgoo1@0037oo00=2400000000P00WWoo100000=247oo
Ool0VWoo0P003Goo1P0000=247ooOol097oo0023Ool00`00@Q1oo`0<Ool6002OOol5002COol5000<
Ool00d8@00000002002NOol400000d8@Oomoo`2JOol2000=Ool600000d8@Oomoo`0TOol008=oo`03
@Q00048@00]oo`03@Q00000000@009moo`D009Aoo`@00003@Q1oogoo00Uoo`058@P000000012402N
Ool400000d8@Oomoo`2JOol00d8@000Q200;Ool00d8@0000000400000d8@Oomoo`0TOol008Aoo`80
00Yoo`03@Q00000000@00003@Q1oogoo09eoo`D009Aoo`D000]oo`@009moo`@00003@Q1oogoo09]o
o`8000Yoo`03@Q00000000D002Moo`00Q7oo00A24000000000Qoo`L00003@Q1oogoo09eoo`D009Eo
o`@000]oo`@009moo`@00003@Q1oogoo09aoo`<000Qoo`P002Moo`00Q7oo00=2400000000P001Goo
2@00Vgoo00=247ooOol00Woo1@00UWoo0`0000=247ooOol01goo1000VWoo00<007ooOol00goo1000
00=247ooOol0W7oo100000=247ooOol00Woo2@00:7oo0025Ool00d8@0000000>00000d8@Oomoo`2I
Ool01F<H@Q00048@8@P01@00UWoo00@Q2000000Q20Qoo`05@Q0000000012402KOol2@Q000b48@Q00
000400000d8@Oomoo`2LOol00f<H0000000>00000d8@Oomoo`0VOol008Moo`h00:5oo`H009Moo`@0
00Ioo`04@Q000000002POol600000d8@Oomoo`2NOol>000ZOol008Qoo``00:=oo`D009Qoo`D000=o
o`@00003@Q1oogoo0:1oo`@00003@Q1oogoo09moo``00003@Q1oogoo02Qoo`00RGoo0T8@1P000T8@
YWoo00=242480000VGoo00=S648@00001@0000<Q248@Ool0Y7oo0T8@00<0048@Ool0XGoo00=S648@
00001@000T8@;7oo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOooo
OoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomo
of=oo`00QGooo`00o`00[P00;goo0025Ool00`00Oomoo`1BOol00d8@Oomoo`1COol00`00Oomoo`1B
Ool00`00Oomoo`1BOol00`00Oomoo`1COol00`00Oomoo`1BOol00`00Oomoo`1COol00`00Oomoo`1B
Ool00`00Oomoo`0]Ool008Eoo`03001oogoo059oo`03@Q1oogoo05=oo`03001oogoo059oo`03001o
ogoo059oo`03001oogoo05=oo`03001oogoo059oo`03001oogoo05=oo`03001oogoo059oo`03001o
ogoo02eoo`00QGoo00<007ooOol0DWoo00=247ooOol0Dgoo00<007ooOol0DWoo00<007ooOol0DWoo
00<007ooOol0Dgoo00<007ooOol0DWoo00<007ooOol0Dgoo00<007ooOol0DWoo00<007ooOol0;Goo
0025Ool00`00Oomoo`1BOol00d8@Oomoo`1COol00`00Oomoo`1BOol00`00Oomoo`1BOol00`00Oomo
o`1COol00`00Oomoo`1BOol00`00Oomoo`1COol00`00Oomoo`1BOol00`00Oomoo`0]Ool008Eoo`03
001oogoo059oo`03@Q1oogoo05=oo`03001oogoo059oo`03001oogoo059oo`03001oogoo05=oo`03
001oogoo059oo`03001oogoo05=oo`03001oogoo059oo`03001oogoo02eoo`00QGoo00<007ooOol0
Z7oo00<007ooOol0Ygoo00<007ooOol0Z7oo00<007ooOol0Z7oo00<007ooOol0;Goo0025Ool00`00
Oomoo`2XOol00`00Oomoo`2WOol00`00Oomoo`2XOol00`00Oomoo`2XOol00`00Oomoo`0]Ool008Eo
o`03001oogoo0:Qoo`03001oogoo0:Moo`03001oogoo0:Qoo`03001oogoo0:Qoo`03001oogoo02eo
o`00QGoo00<007ooOol0Z7oo00<007ooOol0Ygoo00<007ooOol0Z7oo00<007ooOol0Z7oo00<007oo
Ool0;Goo0025Ool00`00Oomoo`2XOol00d8@Oomoo`2WOol00d8@Oomoo`2XOol00d8@Oomoo`2XOol0
0`00Oomoo`0]Ool008Eoo`03001oogoo0?mooomoojYoo`03001oogoo02eoo`00QGoo00<007ooOol0
ogooogooZWoo00<007ooOol0;Goo0025Ool00`00Oomoo`3oOoooOonZOol00`00Oomoo`0]Ool008Eo
o`03001oogoo0?mooomoojYoo`03001oogoo02eoo`00QGoo00<007ooOol0ogooogooZWoo00<007oo
Ool0;Goo0025Ool00`00Oomoo`3oOoooOonZOol00`00Oomoo`0]Ool008Eoo`03001oogoo0?mooomo
ojYoo`03001oogoo02eoo`00QGoo00<007ooOol0ogooogooZWoo00<007ooOol0;Goo0025Ool00`00
Oomoo`3oOoooOonZOol00`00Oomoo`0]Ool008Eoo`03001oogoo0?mooomoojYoo`03001oogoo02eo
o`00QGoo00<007ooOol0ogooogooZWoo00<007ooOol0;Goo0025Ool00`00Oomoo`3oOoooOonZOol0
0`00Oomoo`0]Ool008Eoo`03001oogoo0?mooomoojYoo`03001oogoo02eoo`00QGoo00<007ooOol0
ogooogooZWoo00<007ooOol0;Goo0025Ool00`00Oomoo`3oOoooOonZOol00`00Oomoo`0]Ool008Eo
o`03001oogoo0?mooomoojYoo`03001oogoo02eoo`00QGoo00<007ooOol0ogooogooZWoo00<007oo
Ool0;Goo0025Ool00`00Oomoo`3oOoooOonZOol00`00Oomoo`0]Ool008Eoo`03001oogoo0?mooomo
ojYoo`03001oogoo02eoo`00QGoo00<007ooOol0ogooogooZWoo00<007ooOol0;Goo0025Ool00`00
Oomoo`3oOoooOonZOol00`00Oomoo`0]Ool008Eoo`03001oogoo0?mooomoojYoo`03001oogoo02eo
o`00QGoo00<007ooOol0ogooogooZWoo00<007ooOol0;Goo0025Ool00`00Oomoo`3oOoooOonZOol0
0`00Oomoo`0]Ool008Eoo`03001oogoo0?mooomoojYoo`03001oogoo02eoo`00QGoo00<007ooOol0
ogooogooZWoo00<007ooOol0;Goo0025Ool00`00Oomoo`3oOoooOonZOol00`00Oomoo`0]Ool008Eo
o`03001oogoo0?mooomoojYoo`03001oogoo02eoo`00QGoo00<007ooOol0ogooogooZWoo00<007oo
Ool0;Goo0025Ool00`00Oomoo`3oOoooOonZOol00`00Oomoo`0]Ool008Eoo`03001oogoo0?mooomo
ojYoo`03001oogoo02eoo`00QGoo00<007ooOol0ogooogooZWoo00<007ooOol0;Goo0025Ool00`00
Oomoo`3oOoooOonZOol00`00Oomoo`0]Ool008Eoo`03001oogoo0?mooomoojYoo`03001oogoo02eo
o`00QGoo00<007ooOol0ogooogooZWoo00<007ooOol0;Goo0025Ool00`00Oomoo`3oOoooOonZOol0
0`00Oomoo`0]Ool008Eoo`03001oogoo0?mooomoojYoo`03001oogoo02eoo`00QGoo00<007ooOol0
ogooogooZWoo00<007ooOol0;Goo0025Ool00`00Oomoo`3oOoooOonZOol00`00Oomoo`0]Ool008Eo
o`03001oogoo0?mooomoojYoo`03001oogoo02eoo`00QGoo00<007ooOol0ogooogooZWoo00<007oo
Ool0;Goo0025Ool00`00Oomoo`3oOoooOonZOol00`00Oomoo`0]Ool008Eoo`03001oogoo0?mooomo
ojYoo`03001oogoo02eoo`00QGoo00<007ooOol0ogooogooZWoo00<007ooOol0;Goo0025Ool00`00
Oomoo`3oOoooOonZOol00`00Oomoo`0]Ool008Eoo`03001oogoo0?mooomoojYoo`03001oogoo02eo
o`00QGoo00<007ooOol0ogooogooZWoo00<007ooOol0;Goo0025Ool00`00Oomoo`3oOoooOonZOol0
0`00Oomoo`0]Ool008Eoo`03001oogoo0?mooomoojYoo`03001oogoo02eoo`00QGoo00<007ooOol0
ogooogooZWoo00<007ooOol0;Goo0025Ool00`00Oomoo`3oOoooOonZOol00`00Oomoo`0]Ool008Eo
o`03001oogoo0?mooomoojYoo`03001oogoo02eoo`00QGoo00<007ooOol0ogooogooZWoo00<007oo
Ool0;Goo0025Ool00`00Oomoo`3oOoooOonZOol00`00Oomoo`0]Ool008Eoo`03001oogoo0?mooomo
ojYoo`03001oogoo02eoo`00QGoo00<007ooOol0ogooogooZWoo00<007ooOol0;Goo0025Ool00`00
Oomoo`3oOoooOonZOol00`00Oomoo`0]Ool008Eoo`03001oogoo0?mooomoojYoo`03001oogoo02eo
o`00QGoo00<007ooOol0ogooogooZWoo00<007ooOol0;Goo0025Ool00`00Oomoo`3oOoooOonZOol0
0`00Oomoo`0]Ool008Eoo`03001oogoo0?mooomoojYoo`03001oogoo02eoo`00QGoo00<007ooOol0
ogooogooZWoo00<007ooOol0;Goo0025Ool00`00Oomoo`3oOoooOonZOol00`00Oomoo`0]Ool008Eo
o`03001oogoo0?mooomoojYoo`03001oogoo02eoo`00QGoo00<007ooOol0ogooogooZWoo00<007oo
Ool0;Goo0025Ool00`00Oomoo`3oOoooOonZOol00`00Oomoo`0]Ool008Eoo`03001oogoo0?mooomo
ojYoo`03001oogoo02eoo`00FGoo5P005Woo00<007ooOol0ogooogooZWoo00<007ooOol0;Goo001I
OolF000FOol00`00Oomoo`3oOoooOonZOol00`00Oomoo`0]Ool005Yoo`03@Q00000001<001Eoo`03
001oogoo0?mooomoojYoo`03001oogoo02eoo`00G7oo5@0057oo00<007ooOol0ogooogooZWoo00<0
07ooOol0;Goo001LOol00d8@0000000B000DOol00`00Oomoo`3oOoooOonZOol00`00Oomoo`0]Ool0
05eoo`800003@Q1oogoo00aoo`03@Q00000001Aoo`03001oogoo0?mooomoojYoo`03001oogoo02eo
o`00GWoo00=24000@Q003goo00=24000Ool04Goo00=SV000@a40od<AEd<AogooE7oo00<007ooOol0
;Goo001OOol00d8@0000000?Ool00`00@Q1oo`0@Ool00d<A00000009003o0P9>0P800d<AOomoo`3o
Oom7Ool00d8@00000008000_Ool005moo`03@Q000000029oo`03@a4000820?l20UP20_mooe=oo`03
001oogoo02eoo`00H7oo00A24000001S625oo`03001oogoo0?mooeAoo`05@a420P820P934@3oOomA
Ool00`00Oomoo`0]Ool0069oo`80025oo`03001oogoo0?mooeIoo`<20P03@a5oogoo0?moodioo`03
001oogoo02eoo`00Agoo3P003Woo0P0087oo00<007ooOol0ogooEWoo00A34@820P820_mooe1oo`03
001oogoo02eoo`00Agoo3P003Woo00=2400000007goo00<007ooOol0ogooEgoo1082ogooCgoo00<0
07ooOol0;Goo0017Ool>000>Ool01F<H00000000HaP07Goo00<007ooOol0ogooF7oo00E34@820P82
0T<A0?moodeoo`03001oogoo02eoo`00IGoo0`007Goo00<007ooOol0ogooFGoo00=34@820P800P82
ogooC7oo00<007ooOol0;Goo001VOol3000LOol00`00Oomoo`3oOomJOol50P;oOom;Ool00`00Oomo
o`0]Ool006Moo`8001aoo`03001oogoo0?mooe]oo`D20_moodYoo`03001oogoo02eoo`00Igoo00@Q
2000001241Yoo`03001oogoo0?mooeeoo`058XT20P820P9SV03oOom8Ool00`00Oomoo`0]Ool006Mo
o`05@Q0000000012400IOol00`00Oomoo`3oOomNOol40P;oOom8Ool00`00Oomoo`0]Ool006Qoo`@0
01Uoo`03001oogoo0?mooemoo`@20_moodMoo`03001oogoo02eoo`00J7oo10006Goo00<007ooOol0
ogooH7oo1082ogooAWoo00<007ooOol0;Goo001YOol400000d8@Oomoo`0EOol00`00Oomoo`3oOomQ
Ool01B:90P820P82HiP0ogooA7oo00<007ooOol0;Goo001YOol5000GOol00`00Oomoo`3oOomROol5
0P;oOom3Ool00`00Oomoo`0]Ool006Yoo`@00003@Q1oogoo01Aoo`03001oogoo0?moof=oo`D20_mo
od9oo`03001oogoo02eoo`00JWoo100000=247ooOol057oo00<007ooOol0ogooI7oo00E34B:90P82
0R:90?mood5oo`03001oogoo02eoo`00JWoo1@005Woo00<007ooOol0ogooIWoo1082ogoo@7oo00<0
07ooOol0;Goo001ZOol5000FOol00`00Oomoo`3oOomWOol40P;oOoloOol00`00Oomoo`0]Ool005Uo
o`8000moo`D001Ioo`03001oogoo0?moofQoo`@20P03@a5oogoo0?mooc]oo`03001oogoo02eoo`00
FGoo00=24000@Q003Goo00=2400000000`005Woo00<007ooOol0ogooJ7oo00=SV0820P800P8200=3
4GooOol0ogoo>Woo00<007ooOol0;Goo001JOol2000=Ool6000FOol00`00Oomoo`3oOom[Ool40P;o
OolkOol00`00Oomoo`0]Ool005Yoo`800003@Q1oogoo00Yoo`H001Ioo`03001oogoo0?moofaoo`@2
0_moocYoo`03001oogoo02eoo`00Fgoo0P002goo1`005Woo00<007ooOol0ogooK7oo00E34@820P82
0T<A0?moocUoo`03001oogoo02eoo`00Fgoo00A24000@Q1240Qoo`038@P0000000@00003@Q1oogoo
01Aoo`03001oogoo0?moofeoo`04@a420P820P82@a7oOolgOol00`00Oomoo`0]Ool005aoo`@000Eo
o`T001Moo`03001oogoo0?moofmoo`@20P03@a5oogoo0?moocAoo`03001oogoo02eoo`00G7oo00=2
400000003`005goo00<007ooOol0ogooL7oo1082ogoo=Woo00<007ooOol0;Goo001MOol00d8@0000
000<00000d8@Oomoo`0FOol00`00Oomoo`3oOomaOol01D<A0P820P82@a40ogoo=7oo00<007ooOol0
;Goo001OOol<00000d8@Oomoo`0GOol00`00Oomoo`3oOomcOol40P;oOolcOol00`00Oomoo`0]Ool0
061oo`X001]oo`03001oogoo0?moog=oo`03@a420P8200820_mooc9oo`03001oogoo02eoo`00HWoo
1P007Goo00<007ooOol0ogooM7oo1@82ogoo<Goo00<007ooOol0;Goo0025Ool00`00Oomoo`3oOome
Ool2@a430P800d<AOomoo`3oOol]Ool00`00Oomoo`0]Ool008Eoo`03001oogoo0?moogMoo`03@a42
0P8200820_moobioo`03001oogoo02eoo`00QGoo00<007ooOol0ogooN7oo1@82ogoo;Goo00<007oo
Ool0;Goo0025Ool00`00Oomoo`3oOomiOol50P;oOol/Ool00`00Oomoo`0]Ool008Eoo`03001oogoo
0?moog]oo`058XT20P820P934@3oOolZOol00`00Oomoo`0]Ool008Eoo`03001oogoo0?moogaoo`D2
0_moobUoo`03001oogoo02eoo`00QGoo00<007ooOol0ogooOGoo1@82ogoo:7oo00<007ooOol0;Goo
0025Ool00`00Oomoo`3oOomoOol012:90P820R:9ogoo9goo00<007ooOol0;Goo0025Ool00`00Oomo
o`3oOon0Ool50P;oOolUOol00`00Oomoo`0]Ool008Eoo`03001oogoo0?mooh5oo`D20_moobAoo`03
001oogoo02eoo`00QGoo00<007ooOol0ogooPWoo108200=34GooOol0ogoo8Goo00<007ooOol0;Goo
0025Ool00`00Oomoo`3oOon3Ool014<A0P820P820T<Aogoo8Goo00<007ooOol0;Goo0025Ool00`00
Oomoo`3oOon5Ool50P;oOolPOol00`00Oomoo`0]Ool008Eoo`03001oogoo0?moohIoo`@20P03@a5o
ogoo0?mooaeoo`03001oogoo02eoo`00QGoo00<007ooOol0ogooQgoo1@82ogoo7Woo00<007ooOol0
;Goo0025Ool00`00Oomoo`3oOon8Ool00d<A0P820P020P800d<AOomoo`3oOolJOol00`00Oomoo`0]
Ool008Eoo`03001oogoo0?moohYoo`03@a420P8200820_mooa]oo`03001oogoo02eoo`00QGoo00<0
07ooOol0ogooRgoo1@82ogoo6Woo00<007ooOol0;Goo0025Ool00`00Oomoo`3oOon=Ool40P800d<A
Oomoo`3oOolFOol00`00Oomoo`0]Ool008Eoo`03001oogoo0?mooheoo`03HiP20P8200820P03@a5o
ogoo0?mooaEoo`03001oogoo02eoo`00QGoo00<007ooOol0ogooT7oo1@82ogoo5Goo00<007ooOol0
;Goo0025Ool00`00Oomoo`3oOonAOol40P800d<AOomoo`3oOolBOol00`00Oomoo`0]Ool008Eoo`03
001oogoo0?mooi5oo`03HiQ34@8200<20P03@a5oogoo0?mooa1oo`03001oogoo02eoo`00QGoo00<0
07ooOol0ogooU7oo108200=34GooOol0ogoo3goo00<007ooOol0;Goo0025Ool00`00Oomoo`3oOonE
Ool00d<A0P820P020P;oOol@Ool00`00Oomoo`0]Ool008Eoo`03001oogoo0?mooiIoo`D20_moo`mo
o`03001oogoo02eoo`00QGoo00<007ooOol0ogooUgoo00=34B:90P800P8200<RRD<AOol0ogoo2goo
00<007ooOol0;Goo0025Ool00`00Oomoo`3oOonIOol60P;oOol;Ool00`00Oomoo`0]Ool008Eoo`03
001oogoo0?mooi]oo`D20P03@a5oogoo0?moo`Moo`03001oogoo02eoo`00QGoo00<007ooOol0ogoo
W7oo00=34@820P800P82ogoo2Goo00<007ooOol0;Goo0025Ool00`00Oomoo`3oOonMOol2@a440P80
0d<AOomoo`3oOol4Ool00`00Oomoo`0]Ool008Eoo`03001oogoo0?mooj1oo`D20_moo`Eoo`03001o
ogoo02eoo`00QGoo00<007ooOol0ogooXGoo1P82ogoo0goo00<007ooOol0;Goo0025Ool00`00Oomo
o`3oOonROol2@a430P800b:9@a5oo`3oOol00`00Oomoo`0]Ool008Eoo`03001oogoo0?moojEoo`D2
0_moo`03001oogoo02eoo`00QGoo00<007ooOol0ogooYWoo1@8200=34GooOol0ngoo00<007ooOol0
;Goo0025Ool00`00Oomoo`3oOonWOol00d<A0P820P020P;mOol00`00Oomoo`0]Ool008Eoo`03001o
ogoo0?moojQoo`934@@20P03@a5oogoo0?Qoo`03001oogoo02eoo`00QGoo00<007ooOol0ogooZgoo
1@82nGoo00<007ooOol0;Goo0025Ool00`00Oomoo`3oOon/Ool50P;hOol00`00Oomoo`0]Ool008Eo
o`03001oogoo0?moojeoo`D20P03@a5oogoo0?Aoo`03001oogoo02eoo`00QGoo00<007ooOol0ogoo
[goo00@RR@820P820P934OAoo`03001oogoo02eoo`00QGoo00<007ooOol0ogoo/Goo1@82lgoo00<0
07ooOol0;Goo0025Ool00`00Oomoo`3oOonbOol50P;bOol00`00Oomoo`0]Ool008Eoo`03001oogoo
0?mook=oo`03@a420P8200820P934Nmoo`03001oogoo02eoo`00QGoo00<007ooOol0ogoo]Woo1082
00=34GooOol0k7oo00<007ooOol0;Goo0025Ool00`00Oomoo`3oOonfOol00d<A0P820P030P;]Ool0
0`00Oomoo`0]Ool008Eoo`03001oogoo0?mookQoo`D20P03@a5oogoo0>Uoo`03001oogoo02eoo`00
QGoo00<007ooOol0ogoo^Goo00=34B:90P800`8200=34GooOol0igoo00<007ooOol0;Goo0025Ool0
0`00Oomoo`3oOonlOol50P800d<AOomoo`3UOol00`00Oomoo`0]Ool008Eoo`03001oogoo0?mookeo
o`03@a420P8200<20^Ioo`03001oogoo02eoo`00QGoo00<007ooOol0ogoo_Woo1`82i7oo00<007oo
Ool0;Goo0025Ool00`00Oomoo`3oOoo0Ool00d<A8XT20P030P82@a7QOol00`00Oomoo`0]Ool008Eo
o`H00?mool1oo`H20]]oo`H002moo`00QGoo00<007ooOol0ogooaGoo1@82ggoo00<007ooOol0;Goo
0025Ool00`00Oomoo`3oOoo6Ool60P;MOol00`00Oomoo`0]Ool008Eoo`03001oogoo0?moolMoo`93
4@@20P934MYoo`03001oogoo02eoo`00QGoo00<007ooOol0ogoobWoo1P8200=34GooOol0eWoo00<0
07ooOol0;Goo0025Ool00`00Oomoo`3oOoo<Ool60P;GOol00`00Oomoo`0]Ool008Eoo`03001oogoo
0?mooleoo`934@D20P03@a5oogoo0=9oo`03001oogoo02eoo`00QGoo00<007ooOol0ogood7oo00=3
4@820P801082dWoo00<007ooOol0;Goo0025Ool00`00Oomoo`3oOooBOol60P;AOol00`00Oomoo`0]
Ool008Eoo`03001oogoo0?moomAoo`H20/moo`03001oogoo02eoo`00QGoo00<007ooOol0ogooeGoo
0T<A108200<RRD<AOol0bgoo00<007ooOol0;Goo0025Ool00`00Oomoo`3oOooHOol70P;:Ool00`00
Oomoo`0]Ool008Eoo`03001oogoo0?moomYoo`H20/Uoo`03001oogoo02eoo`00QGoo00<007ooOol0
ogoofgoo00=34@820P801082agoo00<007ooOol0;Goo0025Ool00`00Oomoo`3oOooMOol2@a440P82
@a74Ool00`00Oomoo`0]Ool008Eoo`03001oogoo0?moon1oo`H20P03@a5oogoo0<1oo`03001oogoo
02eoo`00QGoo00<007ooOol0ogooeGoo00<007ooOol02Woo1@82`Woo00<007ooOol0;Goo0025Ool0
0`00Oomoo`3oOooDOol00d8@001oo`0<Ool2@a440P800d<AHiQoo`2mOol00`00Oomoo`0]Ool008Eo
o`03001oogoo0?moomAoo`03@Q00000000moo`H20[eoo`03001oogoo02eoo`00QGoo00<007ooOol0
ogooe7oo0`0047oo1`82^goo00<007ooOol0;Goo0025Ool00`00Oomoo`3oOooDOol3000BOol60P:j
Ool00`00Oomoo`0]Ool008Eoo`03001oogoo0?moom=oo`05@Q0000000012400BOol00f>H@a420P04
0P82@a6fOol00`00Oomoo`0]Ool008Eoo`03001oogoo0?moom=oo`@00003@Q1oogoo01Aoo`L20[Ao
o`03001oogoo02eoo`00QGoo00<007ooOol0ogoodgoo1@005goo1`82/goo00<007ooOol0;Goo0025
Ool00`00Oomoo`3oOooBOol6000IOol00d<A0P820P040P:aOol00`00Oomoo`0]Ool008Eoo`03001o
ogoo0?moom5oo`03@Q00000000D001Yoo`934@@20P038XU34D<A0:eoo`03001oogoo02eoo`00QGoo
00<007ooOol0ogoodGoo20007Goo1`82[7oo00<007ooOol0;Goo0025Ool00`00Oomoo`3oOooAOol9
000NOol70P:ZOol00`00Oomoo`0]Ool008Eoo`03001oogoo0?moom1oo`03@Q00000000L0021oo`93
4@@20P038XU34D<A0:Ioo`03001oogoo02eoo`00QGoo00<007ooOol0ogood7oo00=2400000002000
8Woo1`8200=34GooOol0XWoo00<007ooOol0;Goo0025Ool00`00Oomoo`3oOoo@Ool;000TOol80P:R
Ool00`00Oomoo`0]Ool008Eoo`03001oogoo0?moom1oo`/002Ioo`L20P03@a5oogoo09ioo`03001o
ogoo02eoo`00QGoo00<007ooOol0ogoocgoo00=2400000000P0000<Q2000@Q00100000=247ooOol0
9Goo0T<A1@820T<AWGoo00<007ooOol0;Goo0025Ool00`00Oomoo`3oOoo?Ool5000017oo001ood8@
1000:goo1`82Vgoo00<007ooOol0;Goo0025Ool00`00Oomoo`3oOoo>Ool50002Ool00`00Oomoo`04
000/Ool00d<A0P820P050P:IOol00`00Oomoo`0]Ool008Eoo`03001oogoo0?moolioo`@000=oo`04
001oogooOol3000_Ool70P:GOol00`00Oomoo`0]Ool008Eoo`03001oogoo0?mooleoo`04@Q000000
8@P4Ool00`00Oomoo`02Ool00d8@0000000_Ool3@a450P82@a6COol00`00Oomoo`0]Ool008Eoo`03
001oogoo0?mooleoo`<000Eoo`03001oogoo00=oo`03@Q0007oo039oo`P20Y5oo`03001oogoo02eo
o`00QGoo00<007ooOol0ogoocGoo0P001Woo00<007ooOol017oo0P00=Goo1`82Sgoo00<007ooOol0
;Goo0025Ool00`00Oomoo`3oOoo<Ool00d8@001oo`06Ool00`00Oomoo`05Ool00`00Oomoo`0dOol7
0P:>Ool00`00Oomoo`0]Ool008Eoo`03001oogoo0?moolaoo`03HaQoogoo00Ioo`03001oogoo03io
o`03HiQ34@8200D20P03@a5oogoo08Qoo`03001oogoo02eoo`00QGoo00<007ooOol0ogooeGoo00<0
07ooOol0@Woo1`8200=34GooOol0QGoo00<007ooOol0;Goo0025Ool00`00Oomoo`3oOooEOol00`00
Oomoo`14Ool70P:6Ool00`00Oomoo`0]Ool008Eoo`03001oogoo0?moomEoo`03001oogoo04Ioo`93
4@D20P038XU34D<A085oo`03001oogoo02eoo`00QGoo00<007ooOol0ogooeGoo00<007ooOol0BGoo
00=34@820P801@8200=34GooOol0OGoo00<007ooOol0;Goo0025Ool00`00Oomoo`3oOooEOol00`00
Oomoo`1<Ool80P9mOol00`00Oomoo`0]Ool008Eoo`03001oogoo0?moomEoo`03001oogoo04ioo`L2
0P03@a5oogoo07Uoo`03001oogoo02eoo`00QGoo00<007ooOol0ogooeGoo00<007ooOol0D7oo0T<A
1P820T<AMgoo00<007ooOol0;Goo0025Ool00`00Oomoo`3oOooEOol00`00Oomoo`1DOol80P9eOol0
0`00Oomoo`0]Ool008Eoo`03001oogoo0?moomEoo`03001oogoo05Ioo`P20W=oo`03001oogoo02eo
o`00QGoo00<007ooOol0ogooeGoo00<007ooOol0F7oo00=34@820P801@8200=34GooOol0KWoo00<0
07ooOol0;Goo0025Ool00`00Oomoo`3oOooEOol00`00Oomoo`1JOol2@a400b:90P820P040P800d<A
Oomoo`1[Ool00`00Oomoo`0]Ool008Eoo`03001oogoo0?moomEoo`03001oogoo05moo`P20VYoo`03
001oogoo02eoo`00QGoo00<007ooOol0ogooeGoo00<007ooOol0HGoo2082J7oo00<007ooOol0;Goo
0025Ool00`00Oomoo`3oOooEOol00`00Oomoo`1SOol2@a460P800b:9@a534@1SOol00`00Oomoo`0]
Ool008Eoo`03001oogoo0?moomEoo`03001oogoo06Moo`03@a420P8200H20V5oo`03001oogoo02eo
o`00QGoo00<007ooOol0ogooeGoo00<007ooOol0JWoo208200=34GooOol0G7oo00<007ooOol0;Goo
0025Ool00`00Oomoo`3oOooEOol00`00Oomoo`1/Ool90P9LOol00`00Oomoo`0]Ool008Eoo`03001o
ogoo0?moomEoo`03001oogoo06ioo`03HiQ34D<A00H20P=34EMoo`03001oogoo02eoo`00QGoo00<0
07ooOol0ogooeGoo00<007ooOol0Lgoo2@82EGoo00<007ooOol0;Goo000]Ool5001COol00`00Oomo
o`3oOooEOol00`00Oomoo`1fOol90P9BOol00`00Oomoo`0]Ool002]oo`@0009oo`800003@Q1oogoo
04moo`03001oogoo0?moomEoo`03001oogoo07Qoo`T20P03@a5oogoo04eoo`03001oogoo02eoo`00
:7oo00=S648@00000P0000=247ooOol00Woo0P0000=247ooOol0CWoo00<007ooOol0ogooeGoo00<0
07ooOol0NWoo00ASV4<A@a4RR@H20P934D]oo`03001oogoo02eoo`009goo1@0000=247ooOol00Woo
1000D7oo00<007ooOol0ogooeGoo00<007ooOol0P7oo208200=34GooOol0AWoo00<007ooOol0;Goo
000POol00d8@001oo`02Ool70005Ool4001@Ool00`00Oomoo`3oOooEOol00`00Oomoo`22Ool90P96
Ool00`00Oomoo`0]Ool0025oo`03@Q00000000L00003@Q1oogoo00=oo`04@Q000000@Q1@Ool00`00
Oomoo`3oOooEOol00`00Oomoo`25Ool2@a460P83@a51Ool00`00Oomoo`0]Ool0029oo`P005]oo`03
001oogoo0?moomEoo`03001oogoo08Uoo`X20Sioo`03001oogoo02eoo`008goo1@0000=247ooOol0
FWoo00<007ooOol0ogooeGoo00<007ooOol0S7oo2@82?7oo00<007ooOol0;Goo000TOol4001MOol0
0`00Oomoo`3oOooEOol00`00Oomoo`2>Ool:0P8iOol00`00Oomoo`0]Ool002Aoo`03HaQ247oo05io
o`03001oogoo0?moomEoo`03001oogoo095oo`934@038XT20P8200D20P038XU34D<A03=oo`03001o
ogoo02eoo`009Goo00<007ooOol0GGoo00<007ooOol0ogooeGoo00<007ooOol0Ugoo2P82<7oo00<0
07ooOol0;Goo000VOol00`00Oomoo`1LOol00`00Oomoo`3oOooEOol00`00Oomoo`2JOol90P8^Ool0
0`00Oomoo`0]Ool002Moo`03001oogoo05]oo`03001oogoo0?moomEoo`03001oogoo09aoo`X20R]o
o`03001oogoo02eoo`00:7oo00=247ooOol0FWoo00<007ooOol0ogooeGoo00<007ooOol0Wgoo00=S
V4<A@a401P820T<A00=SV7ooOol097oo00<007ooOol0;Goo000YOol00`00Oomoo`1IOol00`00Oomo
o`3oOooEOol00`00Oomoo`2TOol90P8TOol00`00Oomoo`0]Ool002Uoo`03001oogoo05Uoo`03001o
ogoo0?moomEoo`03001oogoo0:Ioo`03@a420P8200H20R9oo`03001oogoo02eoo`00:Woo00<007oo
Ool0F7oo00<007ooOol0ogooeGoo00<007ooOol0ZGoo2@827goo00<007ooOol0;Goo000[Ool00d8@
HaQoo`1GOol00`00Oomoo`3oOooEOol00`00Oomoo`2[Ool2@a400b:90P820P050P801B:9@a534D<A
HiP05goo00<007ooOol0;Goo000/Ool00d8@Oomoo`0_Ool@000GOol00`00Oomoo`3oOooEOol00`00
Oomoo`2aOol;0P800d<AOomoo`0BOol00`00Oomoo`0]Ool002eoo`03001oogoo035oo`T001]oo`03
001oogoo0?moomEoo`03001oogoo0;Aoo``20Q5oo`03001oogoo02eoo`00;Goo0T8@=7oo00<Q2000
00000P0000=247ooOol06Woo00<007ooOol0ogooeGoo00<007ooOol0^7oo0d<A20820d<A2goo00<0
07ooOol0;Goo000_Ool00d8@Oomoo`0aOol00d8@00000002000MOol00`00Oomoo`3oOooEOol00`00
Oomoo`2nOol<0P87Ool00`00Oomoo`0]Ool002moo`03@Q1oogoo035oo`03@Q000000008001eoo`03
001oogoo0?moomEoo`03001oogoo0<5oo``20PAoo`03001oogoo02eoo`0097oo00=247ooOol02Goo
00<007ooOol0<7oo00=2400000000P007Goo00<007ooOol0ogooeGoo00<007ooOol0a7oo00=34@82
0P802@8200=oo`00Ool0;Woo000TOol00d8@0012400:Ool00`00Oomoo`0_Ool00d8@00000002000M
Ool00`00Oomoo`3oOooEOol00`00Oomoo`38Ool3@a400b:90P820P030P800`00Oomoo`0]Ool002Ao
o`03@Q00000000`0031oo`03@Q000000008001eoo`/00?mooleoo`03001oogoo0<Moo`03@Q000000
00P002moo`009Goo3P0000=247ooOol0;Goo00=2400000000P007Goo00<007ooOol0ogooeGoo00<0
07ooOol0dGoo00<007ooOol0;Goo000UOol?000_Ool00d8@00000002000MOol00`00Oomoo`3oOooE
Ool00`00Oomoo`3AOol00`00Oomoo`0]Ool002Eooa000003@Q1oogoo02]oo`03@Q000000008001eo
o`03001oogoo0?moomEoo`03001oogoo0=5oo`03001oogoo02eoo`00Agoo3P003Woo00=240000000
0P007Goo00<007ooOol0ogooeGoo00<007ooOol0dGoo00<007ooOol0;Goo0017Ool>000>Ool00d8@
00000002000MOol00`00Oomoo`3oOooEOol00`00Oomoo`3AOol00`00Oomoo`0]Ool004Moo`h000io
o`03@Q000000008001eoo`03001oogoo0?moomEoo`03001oogoo0=5oo`03001oogoo02eoo`00Hgoo
00=2400000000P007Goo00<007ooOol0ogooeGoo00<007ooOol0dGoo00<007ooOol0;Goo001SOol0
0d8@00000002000MOol00`00Oomoo`3oOooEOol00`00Oomoo`3AOol00`00Oomoo`0]Ool006=oo`03
@Q000000008001eoo`03001oogoo0?moomEoo`03001oogoo0=5oo`03001oogoo02eoo`00Hgoo00=2
400000000P007Goo00<007ooOol0ogooeGoo00<007ooOol0dGoo00<007ooOol0;Goo001SOol00d8@
00000002000MOol00`00Oomoo`3oOooEOol00`00Oomoo`3AOol00`00Oomoo`0]Ool006=oo`03@Q00
0000008001eoo`03001oogoo0?moomEoo`03001oogoo0=5oo`03001oogoo02eoo`00Hgoo00=24000
00000P007Goo00<007ooOol0ogooeGoo00<007ooOol0dGoo00<007ooOol0;Goo001SOol00d8@0000
0002000MOol00`00Oomoo`3oOooEOol00`00Oomoo`3AOol00`00Oomoo`0]Ool006=oo`03@Q000000
008001eoo`03001oogoo0?moomEoo`03001oogoo0=5oo`03001oogoo02eoo`00Hgoo00=240000000
0P007Goo00<007ooOol0ogooeGoo00<007ooOol0dGoo00<007ooOol0;Goo001SOol00d8@00000002
000MOol00`00Oomoo`3oOooEOol00`00Oomoo`3AOol00`00Oomoo`0]Ool006=oo`03@Q0000000080
01eoo`03001oogoo0?moomEoo`03001oogoo0=5oo`03001oogoo02eoo`00Hgoo00=2400000000P00
7Goo00<007ooOol0ogooeGoo00<007ooOol0dGoo00<007ooOol0;Goo001SOol00d8@00000002000M
Ool00`00Oomoo`3oOooEOol00`00Oomoo`3AOol00`00Oomoo`0]Ool006=oo`03@Q000000008001eo
o`03001oogoo0?moomEoo`03001oogoo0=5oo`03001oogoo02eoo`00Hgoo00=2400000000P007Goo
00<007ooOol0ogooeGoo00<007ooOol0dGoo00<007ooOol0;Goo001SOol00d8@00000002000MOol0
0`00Oomoo`3oOooEOol00`00Oomoo`3AOol00`00Oomoo`0]Ool006=oo`03@Q000000008001eoo`03
001oogoo0?moomEoo`03001oogoo0=5oo`03001oogoo02eoo`00Hgoo00=2400000000P007Goo00<0
07ooOol0ogooeGoo00<007ooOol0dGoo00<007ooOol0;Goo001NOol00`00Oomoo`02Ool00d8@0000
0002000MOol00`00Oomoo`3oOooEOol00`00Oomoo`3AOol00`00Oomoo`0]Ool005moo`80009oo`D0
01eoo`03001oogoo0?moomEoo`03001oogoo0=5oo`03001oogoo02eoo`00H7oo20007Goo00<007oo
Ool0ogooeGoo00<007ooOol0dGoo00<007ooOol0;Goo001ROol00d8@8@P00003000MOol00`00Oomo
o`3oOooEOol00`00Oomoo`3AOol00`00Oomoo`0]Ool006Eoo`<001eoo`03001oogoo0?moomEoo`03
001oogoo0=5oo`03001oogoo02eoo`00Igoo00<007ooOol06goo00<007ooOol0ogooeGoo00<007oo
Ool0dGoo00<007ooOol0;Goo0025Ool00`00Oomoo`3oOooEOol00`00Oomoo`3AOol00`00Oomoo`0]
Ool008Eoo`03001oogoo0?moomEoo`03001oogoo0=5oo`03001oogoo02eoo`00QGoo00<007ooOol0
ogooeGoo00<007ooOol0dGoo00<007ooOol0;Goo0025Ool00`00Oomoo`3oOooEOol00`00Oomoo`3A
Ool00`00Oomoo`0]Ool008Eoo`03001oogoo0?moomEoo`03001oogoo0=5oo`03001oogoo02eoo`00
QGoo00<007ooOol0ogooeGoo00<007ooOol0dGoo00<007ooOol0;Goo0025Ool00`00Oomoo`3oOooE
Ool00`00Oomoo`0/Ool00d8@Oomoo`0SOol00`00Oomoo`1lOol00`00Oomoo`0]Ool008Eoo`03001o
ogoo0?moomEoo`03001oogoo02aoo`03001oogoo029oo`03@Q00000007eoo`03001oogoo02eoo`00
QGoo00<007ooOol0ogooeGoo00<007ooOol0:goo0T8@9Goo00A24000001S67]oo`03001oogoo02eo
o`00QGoo00<007ooOol0ogooeGoo00<007ooOol0:goo00<0048@Ool09Woo0P00Ngoo00<007ooOol0
;Goo0025Ool00`00Oomoo`3oOooEOol00`00Oomoo`0ZOol200000d8@Oomoo`0VOol2001jOol00`00
Oomoo`0]Ool008Eoo`03001oogoo0?moomEoo`03001oogoo02Uoo`03@Q00000002Uoo`04@Q000000
HaQhOol00`00Oomoo`0]Ool008Eoo`03001oogoo0?moomEoo`03001oogoo02Uoo`<002Yoo`<007Qo
o`03001oogoo02eoo`00QGoo00<007ooOol0ogooeGoo00<007ooOol0:Goo0`00:goo0P00N7oo00<0
07ooOol0;Goo0025Ool00`00Oomoo`3oOooEOol00`00Oomoo`0XOol0148@00000000:goo0`00Mgoo
00<007ooOol0;Goo0025Ool00`00Oomoo`3oOooEOol00`00Oomoo`0IOol016<H@Q12448@2goo00=2
4000000037oo148@37oo0T8@00=S67ooOol037oo0`0000=247ooOol0Lgoo00<007ooOol0;Goo0025
Ool00`00Oomoo`3oOooEOol00`00Oomoo`09Ool4000<Ool5000:Ool3000;Ool500000d8@Oomoo`08
Ool00d8@00000002000=Ool0148@00000000MGoo00<007ooOol0;Goo0025Ool00`00Oomoo`3oOooE
Ool00`00Oomoo`09Ool5000;Ool60009Ool3000;Ool6000:Ool6000<Ool01D8@00000000@Q00M7oo
00<007ooOol0;Goo0025Ool00`00Oomoo`3oOooEOol00`00Oomoo`0:Ool4000;Ool70008Ool3000;
Ool70009Ool7000<Ool4001dOol00`00Oomoo`0]Ool008Eoo`03001oogoo0?moomEoo`03001oogoo
00Yoo`@000]oo`@00005HaQood8@001S6006Ool3000;Ool00d8@00000002@Q0016<H@Q0006<H1Woo
100000ES67oo@Q00048@00]oo`@00003@Q1oogoo075oo`03001oogoo02eoo`00QGoo00<007ooOol0
ogooeGoo00<007ooOol02Woo00E240000000048@00Yoo`@00005@Q1oogooOom24006Ool3000BOol0
0`00@Q1oo`05Ool40004Ool00`00Oomoo`0:Ool4001cOol00`00Oomoo`0]Ool008Eoo`03001oogoo
0?moomEoo`03001oogoo00Yoo`05@Q0000000012400:Ool01D8@00000000@Q000goo00<007ooOol0
0goo10004goo00<007ooOol017oo100017oo00=24000Ool02Woo1@00LWoo00<007ooOol0;Goo0025
Ool00`00Oomoo`3oOooEOol00`00Oomoo`0:Ool01D8@000000008@P02Woo00E240000000048@00=o
o`03HaP007oo00=oo`@001=oo`03HaP0048@00=oo`@001=oo`@00003@Q1oogoo06moo`03001oogoo
02eoo`00QGoo00<007ooOol0ogooeGoo00<007ooOol02goo10002goo10002Goo100057oo0P000goo
10004goo1@00LGoo00<007ooOol0;Goo0025Ool00`00Oomoo`3oOooEOol00`00Oomoo`0;Ool4000;
Ool40009Ool4000EOol20002Ool4000COol5001aOol00`00Oomoo`0]Ool008Eoo`03001oogoo0?mo
omEoo`03001oogoo00]oo`D000Yoo`@000Uoo`@001Ioo`03001247oo00@001Aoo`@00003@Q1oogoo
06ioo`03001oogoo02eoo`00QGoo00<007ooOol0ogooeGoo00<007ooOol02goo00=2400000000P00
00=247ooOol01goo00E240000000048@00Qoo`@001Ioo`03@Q00000000<001Eoo`@00003@Q1oogoo
06ioo`03001oogoo02eoo`00QGoo00<007ooOol0ogooeGoo00<007ooOol037oo1@002Woo100027oo
1@005Woo00=2400000000P005Goo100000=247ooOol0KWoo00<007ooOol0;Goo0025Ool00`00Oomo
o`3oOooEOol00`00Oomoo`0<Ool60009Ool40008Ool5000FOol00d8@00000002000EOol01D8@0000
0000@Q00L7oo00<007ooOol0;Goo0025Ool00`00Oomoo`3oOooEOol00`00Oomoo`0=Ool50009Ool5
0007Ool5000FOol01D8@00000000@Q005Goo00=2400000000P00L7oo00<007ooOol0;Goo0025Ool0
0`00Oomoo`3oOooEOol00`00Oomoo`0=Ool400000d8@8@Qoo`08Ool40007Ool5000FOol01D8@0000
0000@Q005Goo00=2400000000P00L7oo00<007ooOol0;Goo0025Ool00`00Oomoo`3oOooEOol00`00
Oomoo`0=Ool500000d8@Oomoo`07Ool40008Ool4000FOol01D8@00000000@Q005Goo00=240000000
0P00L7oo00<007ooOol0;Goo0025Ool00`00Oomoo`3oOooEOol00`00Oomoo`0>Ool400000d8@001o
o`08Ool40007Ool400000d8@Oomoo`0COol01D8@00000000@Q005Goo00=2400000000P00L7oo00<0
07ooOol0;Goo0025Ool00`00Oomoo`3oOooEOol00`00Oomoo`0>Ool400000goo00000008Ool40007
Ool400000d8@Oomoo`0COol5000FOol4001`Ool00`00Oomoo`0]Ool008Eoo`03001oogoo0?moomEo
o`03001oogoo00ioo`068@P00000001S67oo0P0000=S67ooOol017oo100000=S67ooOol017oo1000
00=247ooOol04goo100000<Q248@Ool057oo1000L7oo00<007ooOol0;Goo0025Ool00`00Oomoo`3o
OooEOol00`00Oomoo`0>Ool01D8@00000000@Q000Woo0P001Woo00E240000000048@00Ioo`03@Q00
0000008001Eoo`@00003Ool0000001Aoo`@0071oo`03001oogoo02eoo`00QGoo00<007ooOol0ogoo
eGoo00<007ooOol03Woo00E240000000048@00=oo`8000Eoo`05@Q00000000124006Ool00d8@0000
0002000DOol50002Ool00`00@Q1oo`0BOol4001`Ool00`00Oomoo`0]Ool008Eoo`03001oogoo0?mo
omEoo`03001oogoo00ioo`05HaP00000000Q2003Ool016<H0000048@0goo00DQ20000000048@00Io
o`03HaP00000008001Aoo`@000=oo`03@Q00048@009oo`03HaQ2448@00eoo`@0071oo`03001oogoo
02eoo`00QGoo00<007ooOol0ogooeGoo00<007ooOol03goo10001Goo2@0000=247ooOol01Goo1@00
4goo100017oo00=2400000001@0037oo1000L7oo00<007ooOol0;Goo0025Ool00`00Oomoo`3oOooE
Ool00`00Oomoo`0?Ool40006Ool800000d8@Oomoo`06Ool4000=Ool00d8@001oo`02Ool50005Ool7
000<Ool300000d8@Oomoo`1^Ool00`00Oomoo`0]Ool008Eoo`03001oogoo0?moomEoo`03001oogoo
00moo`D000Ioo`L000Uoo`D000ioo`L000Moo`H000aoo`<00003@Q1oogoo06ioo`03001oogoo02eo
o`00QGoo00<007ooOol0ogooeGoo00<007ooOol047oo100027oo0d8@37oo100047oo148@2Woo0d8@
3Goo0`0000=247ooOol0KWoo00<007ooOol0;Goo0025Ool00`00Oomoo`3oOooEOol00`00Oomoo`0@
Ool4000HOol4000]Ool300000d8@Oomoo`1^Ool00`00Oomoo`0]Ool008Eoo`03001oogoo0?moomEo
o`03001oogoo015oo`@001Moo`04@Q000000000]Ool300000d8@Oomoo`1^Ool00`00Oomoo`0]Ool0
08Eoo`03001oogoo0?moomEoo`03001oogoo015oo`@001Moo`05@Q0000000012400/Ool3001aOol0
0`00Oomoo`0]Ool008Eoo`03001oogoo0?moomEoo`03001oogoo015oo`@00003@Q1oogoo01Eoo`04
@Q0000008@P[Ool016<H00000000LGoo00<007ooOol0;Goo0025Ool00`00Oomoo`3oOooEOol00`00
Oomoo`0BOol4000IOol2000[Ool00d8@0000001bOol00`00Oomoo`0]Ool008Eoo`03001oogoo0?mo
omEoo`03001oogoo019oo`@001Yoo`8002Yoo`03@Q000000079oo`03001oogoo02eoo`00QGoo00<0
07ooOol0ogooeGoo00<007ooOol04Woo00DQ2000000006<H01Uoo`038@P0000002Uoo`03@Q00048@
079oo`03001oogoo02eoo`00QGoo00<007ooOol0ogooeGoo00<007ooOol04Woo00E240000000048@
01Yoo`800003@Q1oogoo02Ioo`03@Q0007oo079oo`03001oogoo02eoo`00QGoo00<007ooOol0ogoo
eGoo00<007ooOol04Woo00E240000000048@01]oo`8002Qoo`8007=oo`03001oogoo02eoo`00QGoo
00<007ooOol0ogooeGoo00<007ooOol04Woo00E240000000048@01aoo`8002Moo`03001oogoo079o
o`03001oogoo02eoo`00QGoo00<007ooOol0ogooeGoo00<007ooOol03Woo00AS648@@Q1240D001ao
o`04HaP00000@Q0TOol00d8@8@Qoo`1cOol00`00Oomoo`0]Ool008Eoo`H00?moom9oo`03001oogoo
015oo`H004Aoo`03001247oo06ioo`H002moo`00QGoo00<007ooOol0ogooeGoo00<007ooOol05Goo
0`00^Goo00<007ooOol0;Goo0025Ool00`00Oomoo`3oOooEOol00`00Oomoo`3AOol00`00Oomoo`0]
Ool008Eoo`03001oogoo0?moomEoo`03001oogoo0=5oo`03001oogoo02eoo`00QGoo00<007ooOol0
ogooeGoo00<007ooOol0dGoo00<007ooOol0;Goo0025Ool00`00Oomoo`3oOooEOol00`00Oomoo`3A
Ool00`00Oomoo`0]Ool008Eoo`03001oogoo0?moomEoo`03001oogoo0=5oo`03001oogoo02eoo`00
QGoo00<007ooOol0ogooeGoo00<007ooOol0dGoo00<007ooOol0;Goo0025Ool00`00Oomoo`3oOooE
Ool00`00Oomoo`3AOol00`00Oomoo`0]Ool008Eoo`03001oogoo0?moomEoo`03001oogoo0=5oo`03
001oogoo02eoo`00QGoo00<007ooOol0ogooeGoo00<007ooOol0dGoo00<007ooOol0;Goo0025Ool0
0`00Oomoo`3oOooEOol00`00Oomoo`3AOol00`00Oomoo`0]Ool008Eoo`03001oogoo0?moomEoo`03
001oogoo0=5oo`03001oogoo02eoo`00QGoo00<007ooOol0ogooeGoo00<007ooOol0dGoo00<007oo
Ool0;Goo0025Ool00`00Oomoo`3oOooEOol00`00Oomoo`3AOol00`00Oomoo`0]Ool008Eoo`03001o
ogoo0?moomEoo`03001oogoo0=5oo`03001oogoo02eoo`00QGoo00<007ooOol0ogooeGoo00<007oo
Ool0dGoo00<007ooOol0;Goo0025Ool00`00Oomoo`3oOooEOol00`00Oomoo`3AOol00`00Oomoo`0]
Ool008Eoo`03001oogoo0?moomEoo`03001oogoo0=5oo`03001oogoo02eoo`00QGoo00<007ooOol0
ogooeGoo00<007ooOol0dGoo00<007ooOol0;Goo0025Ool00`00Oomoo`3oOooEOol00`00Oomoo`3A
Ool00`00Oomoo`0]Ool008Eoo`03001oogoo0?moomEoo`03001oogoo0=5oo`03001oogoo02eoo`00
QGoo00<007ooOol0ogooeGoo00<007ooOol0dGoo00<007ooOol0;Goo0025Ool00`00Oomoo`3oOooE
Ool00`00Oomoo`3AOol00`00Oomoo`0]Ool008Eoo`03001oogoo0?moomEoo`03001oogoo0=5oo`03
001oogoo02eoo`00QGoo00<007ooOol0ogooeGoo00<007ooOol0dGoo00<007ooOol0;Goo0025Ool0
0`00Oomoo`3oOooEOol00`00Oomoo`3AOol00`00Oomoo`0]Ool008Eoo`03001oogoo0?moomEoo`03
001oogoo0=5oo`03001oogoo02eoo`00QGoo00<007ooOol0ogooeGoo00<007ooOol0dGoo00<007oo
Ool0;Goo0025Ool00`00Oomoo`3oOooEOol00`00Oomoo`3AOol00`00Oomoo`0]Ool008Eoo`03001o
ogoo0?moomEoo`03001oogoo0=5oo`03001oogoo02eoo`00QGoo00<007ooOol0ogooeGoo00<007oo
Ool0dGoo00<007ooOol0;Goo0025Ool00`00Oomoo`3oOooEOol00`00Oomoo`3AOol00`00Oomoo`0]
Ool008Eoo`03001oogoo0?moomEoo`03001oogoo0=5oo`03001oogoo02eoo`00QGoo00<007ooOol0
ogooeGoo00<007ooOol0dGoo00<007ooOol0;Goo0025Ool00`00Oomoo`3oOooEOol00`00Oomoo`3A
Ool00`00Oomoo`0]Ool008Eoo`03001oogoo0?moomEoo`03001oogoo0=5oo`03001oogoo02eoo`00
QGoo00<007ooOol0ogooeGoo00<007ooOol0dGoo00<007ooOol0;Goo0025Ool00`00Oomoo`3oOooE
Ool00`00Oomoo`3AOol00`00Oomoo`0]Ool008Eoo`03001oogoo0?moomEoo`03001oogoo0=5oo`03
001oogoo02eoo`00QGoo00<007ooOol0ogooeGoo00<007ooOol0dGoo00<007ooOol0;Goo0025Ool0
0`00Oomoo`3oOooEOol00`00Oomoo`3AOol00`00Oomoo`0]Ool008Eoo`03001oogoo0?moomEoo`03
001oogoo0=5oo`03001oogoo02eoo`00QGoo00<007ooOol0ogooeGoo00<007ooOol0dGoo00<007oo
Ool0;Goo0025Ool00`00Oomoo`3oOooEOol00`00Oomoo`3AOol00`00Oomoo`0]Ool008Eoo`03001o
ogoo0?moomEoo`03001oogoo0=5oo`03001oogoo02eoo`00QGoo00<007ooOol0ogooeGoo00<007oo
Ool0dGoo00<007ooOol0;Goo0025Ool00`00Oomoo`3oOooEOol00`00Oomoo`3AOol00`00Oomoo`0]
Ool008Eoo`03001oogoo0?moomEoo`03001oogoo0=5oo`03001oogoo02eoo`00QGoo00<007ooOol0
ogooeGoo00<007ooOol0dGoo00<007ooOol0;Goo0025Ool00`00Oomoo`3oOooEOol00`00Oomoo`3A
Ool00`00Oomoo`0]Ool008Eoo`03001oogoo0?moomEoo`03001oogoo0=5oo`03001oogoo02eoo`00
QGoo00<007ooOol0ogooeGoo00<007ooOol0dGoo00<007ooOol0;Goo0025Ool00`00Oomoo`3oOooE
Ool00`00Oomoo`3AOol00`00Oomoo`0]Ool008Eoo`03001oogoo0?moomEoo`03001oogoo0=5oo`03
001oogoo02eoo`00QGoo00<007ooOol0ogooc7oo00=S67ooOol01Woo00<007ooOol0dGoo00<007oo
Ool0;Goo0025Ool00`00Oomoo`3oOoo<Ool00d8@Oomoo`06Ool00`00Oomoo`06Ool00`00Oomoo`38
Ool00`00Oomoo`0]Ool008Eoo`03001oogoo0?moolaoo`03@Q0007oo00Ioo`03001oogoo00Eoo`03
001oogoo0<Uoo`03001oogoo02eoo`00QGoo00<007ooOol0ogooc7oo00AS6000001240Eoo`03001o
ogoo00=oo`03HaP000000<]oo`03001oogoo02eoo`00QGoo00<007ooOol0ogoocGoo0`0000=247oo
Ool00Woo00<007ooOol00goo0P00c7oo00<007ooOol0;Goo0025Ool00`00Oomoo`3oOoo=Ool40004
Ool00`00Oomoo`02Ool3003<Ool00`00Oomoo`0]Ool008Eoo`03001oogoo0?moolioo`@000=oo`04
001oogooOol4003<Ool00`00Oomoo`0]Ool008Eoo`03001oogoo0?moolioo`D00005@Q1oo`00OomS
6004003=Ool00`00Oomoo`0]Ool008Eoo`03001oogoo0?moolmoo`D00003@Q0007oo00D00<eoo`03
001oogoo02eoo`00QGoo00<007ooOol0ogoocgoo300000=247ooOol0bgoo00<007ooOol0;Goo0025
Ool00`00Oomoo`3oOoo@Ool;00000d8@Oomoo`3;Ool00`00Oomoo`0]Ool008Eoo`03001oogoo0?mo
om1oo`/00<ioo`03001oogoo02eoo`00QGoo00<007ooOol0ogood7oo00=2400000002000cWoo00<0
07ooOol0;Goo0025Ool00`00Oomoo`3oOoo@Ool00d8@00000007003?Ool00`00Oomoo`0]Ool008Eo
o`03001oogoo0?moom1oo`03HaP0000000L00<moo`03001oogoo02eoo`00QGoo00<007ooOol0ogoo
dGoo2000d7oo00<007ooOol0;Goo0025Ool00`00Oomoo`3oOooAOol8003@Ool00`00Oomoo`0]Ool0
08Eoo`03001oogoo0?moom9oo`L00=1oo`03001oogoo02eoo`00QGoo00<007ooOol0ogoodWoo00=2
400000000`00dGoo00<007ooOol0;Goo0025Ool00`00Oomoo`3oOooCOol400000d8@Oomoo`3?Ool0
0`00Oomoo`0]Ool008Eoo`03001oogoo0?moom=oo`@00003@Q1oogoo0<moo`03001oogoo02eoo`00
QGoo00<007ooOol0ogooe7oo0`0000=247ooOol0cgoo00<007ooOol0;Goo001SOol6@Q0LOol00`00
Oomoo`3oOooDOol3003BOol00`00Oomoo`0]Ool0065oo`X001Yoo`03001oogoo0?moomAoo`03@Q00
00000=9oo`03001oogoo02eoo`00Ggoo00=2400000000P0017oo10006Goo00<007ooOol0ogooe7oo
00=24000Ool0dWoo00<007ooOol0;Goo001NOol01D8@00000000@Q001goo0`0000=247ooOol05Goo
00<007ooOol0ogooe7oo00=S6000Ool0dWoo00<007ooOol0;Goo001MOol4000:Ool300000d8@Oomo
o`0DOol00`00Oomoo`3oOoooOonZOol00`00Oomoo`0]Ool005eoo`@000Yoo`04@Q000000@Q0FOol0
0`00Oomoo`3oOoooOonZOol00`00Oomoo`0]Ool005aoo`04@Q000000000;Ool0148@000000005Woo
00<007ooOol0ogooogooZWoo00<007ooOol0;Goo001LOol4000;Ool01F<H00000000@Q0057oo00=o
6`00OQH0oghFoghFZghF00<007ooOol0;Goo001LOol300000d8@Oomoo`0:Ool4000DOol00ghF0000
0009003oO2goO2fHO2d00d0600000008000_Ool005]oo`@00003@Q1oogoo00Yoo`D001=oo`03OQH0
07`]0?ml;Oml;J]l;@03001oogoo02eoo`00Fgoo100000=247ooOol02Woo1@0057oo00<007ooOol0
ogooogooZWoo00<007ooOol0;Goo001JOol500000d8@Oomoo`0:Ool500000d8@Oomoo`0AOol00`00
Oomoo`3oOoooOonZOol00`00Oomoo`0]Ool005Yoo`D000ioo`D001=oo`03001oogoo0?mooomoojYo
o`03001oogoo02eoo`00FWoo1@003Woo1@004goo00<007ooOol0ogooogooZWoo00<007ooOol0;Goo
001JOol5000>Ool5000COol00`00Oomoo`3oOoooOonZOol00`00Oomoo`0]Ool005Uoo`H000ioo`D0
0003HaQoogoo011oo`03001oogoo0?mooomoojYoo`03001oogoo02eoo`00FGoo1P003Woo1@0000=2
47ooOol047oo00<007ooOol0ogooogooZWoo00<007ooOol0;Goo001IOol6000>Ool500000d8@Oomo
o`0@Ool00`00Oomoo`3oOoooOonZOol00`00Oomoo`0]Ool005Uoo`H000ioo`D00003@Q1oogoo011o
o`03001oogoo0?mooomoojYoo`03001oogoo02eoo`00FGoo1P003Woo1@0000=247ooOol047oo00<0
07ooOol0ogooogooZWoo00<007ooOol0;Goo001IOol6000>Ool500000d8@Oomoo`0@Ool00`00Oomo
o`3oOoooOonZOol00`00Oomoo`0]Ool005Uoo`H000ioo`D00003@Q1oogoo011oo`03001oogoo0?mo
oomoojYoo`03001oogoo02eoo`00FGoo1P003Woo1@0000=247ooOol047oo00<007ooOol0ogooogoo
ZWoo00<007ooOol0;Goo001IOol6000>Ool500000d8@Oomoo`0@Ool00`00Oomoo`3oOoooOonZOol0
0`00Oomoo`0]Ool005Uoo`H000ioo`D00003@Q1oogoo011oo`03001oogoo0?mooomoojYoo`03001o
ogoo02eoo`00FGoo1P003Woo1@0000=247ooOol047oo00<007ooOol0ogooogooZWoo00<007ooOol0
;Goo001JOol5000>Ool5000COol00`00Oomoo`3oOoooOonZOol00`00Oomoo`0]Ool005Yoo`D00003
@Q1oogoo00Yoo`H001=oo`03001oogoo0?mooomoojYoo`03001oogoo02eoo`00FWoo1@0000=247oo
Ool02Woo1P004goo00<007ooOol0ogooogooZWoo00<007ooOol0;Goo001JOol00d8@000000020000
0d8@Oomoo`0:Ool5000DOol00`00Oomoo`3oOoooOonZOol00`00Oomoo`0]Ool005]oo`@00003@Q1o
ogoo00Yoo`D001Aoo`03001oogoo0?mooomoojYoo`03001oogoo02eoo`00G7oo0`0000=247ooOol0
2Woo10005Goo00<007ooOol0ogooogooZWoo00<007ooOol0;Goo001LOol4000;Ool00d8@00000002
000EOol00`00Oomoo`3oOoooOonZOol00`00Oomoo`0]Ool005aoo`048@P00000000;Ool0148@0000
00005Woo00<007ooOol0ogooogooZWoo00<007ooOol0;Goo001MOol4000:Ool300000d8@Oomoo`0D
Ool00`00Oomoo`3oOoooOonZOol00`00Oomoo`0]Ool005eoo`@000Yoo`<00003@Q1oogoo01Aoo`03
001oogoo0?mooomoojYoo`03001oogoo02eoo`00GWoo100027oo10005goo00<007ooOol0ogooogoo
ZWoo00<007ooOol0;Goo001OOol01B4800000000@Q000goo00=S648@00000P0000=247ooOol05Woo
00<007ooOol0ogooogooZWoo00<007ooOol0;Goo001QOol:000JOol00`00Oomoo`3oOoooOonZOol0
0`00Oomoo`0]Ool006=oo`H001aoo`03001oogoo0?mooomoojYoo`03001oogoo02eoo`00QGoo00<0
07ooOol0ogooogooZWoo00<007ooOol0;Goo0025Ool00`00Oomoo`3oOoooOonZOol00`00Oomoo`0]
Ool008Eoo`03001oogoo0?mooomoojYoo`03001oogoo02eoo`00QGoo00<007ooOol0ogooogooZWoo
00<007ooOol0;Goo0025Ool00`00Oomoo`3oOoooOonZOol00`00Oomoo`0]Ool008Eoo`03001oogoo
0?mooomoojYoo`03001oogoo02eoo`00QGoo00<007ooOol0ogooogooZWoo00<007ooOol0;Goo0025
Ool00`00Oomoo`3oOoooOonZOol00`00Oomoo`0]Ool008Eoo`03001oogoo0?mooomoojYoo`03001o
ogoo02eoo`00QGoo00<007ooOol0ogooogooZWoo00<007ooOol0;Goo0025Ool00`00Oomoo`3oOooo
OonZOol00`00Oomoo`0]Ool008Eoo`03001oogoo0?mooomoojYoo`03001oogoo02eoo`00QGoo00<0
07ooOol0ogooogooZWoo00<007ooOol0;Goo0025Ool00`00Oomoo`3oOoooOonZOol00`00Oomoo`0]
Ool008Eoo`03001oogoo0?mooomoojYoo`03001oogoo02eoo`00QGoo00<007ooOol0ogooogooZWoo
00<007ooOol0;Goo0025Ool00`00Oomoo`3oOoooOonZOol00`00Oomoo`0]Ool008Eoo`03001oogoo
0?mooomoojYoo`03001oogoo02eoo`00QGoo00<007ooOol0ogooogooZWoo00<007ooOol0;Goo0025
Ool00`00Oomoo`3oOoooOonZOol00`00Oomoo`0]Ool008Eoo`03001oogoo0?mooomoojYoo`03001o
ogoo02eoo`00QGoo00<007ooOol0ogooogooZWoo00<007ooOol0;Goo0025Ool00`00Oomoo`3oOooo
OonZOol00`00Oomoo`0]Ool008Eoo`03001oogoo0?mooomoojYoo`03001oogoo02eoo`00QGoo00<0
07ooOol0ogooogooZWoo00<007ooOol0;Goo0025Ool00`00Oomoo`3oOoooOonZOol00`00Oomoo`0]
Ool008Eoo`03001oogoo0?mooomoojYoo`03001oogoo02eoo`00QGoo00<007ooOol0ogooogooZWoo
00<007ooOol0;Goo0025Ool00`00Oomoo`3oOoooOonZOol00`00Oomoo`0]Ool008Eoo`03001oogoo
0?mooomoojYoo`03001oogoo02eoo`00QGoo00<007ooOol0ogooogooZWoo00<007ooOol0;Goo0025
Ool00`00Oomoo`3oOoooOonZOol00`00Oomoo`0]Ool008Eoo`03001oogoo0?mooomoojYoo`03001o
ogoo02eoo`00QGoo00<007ooOol0ogooogooZWoo00<007ooOol0;Goo0025Ool00`00Oomoo`3oOooo
OonZOol00`00Oomoo`0]Ool008Eoo`03001oogoo0?mooomoojYoo`03001oogoo02eoo`00QGoo00<0
07ooOol0ogooogooZWoo00<007ooOol0;Goo0025Ool00`00Oomoo`3oOoooOonZOol00`00Oomoo`0]
Ool008Eoo`03001oogoo0?mooomoojYoo`03001oogoo02eoo`00QGoo00<007ooOol0ogooogooZWoo
00<007ooOol0;Goo0025Ool00`00Oomoo`3oOoooOonZOol00`00Oomoo`0]Ool008Eoo`03001oogoo
0?mooomoojYoo`03001oogoo02eoo`00QGoo00<007ooOol0ogooogooZWoo00<007ooOol0;Goo0025
Ool00`00Oomoo`3oOoooOonZOol00`00Oomoo`0]Ool008Eoo`03001oogoo0:Qoo`03001oogoo0:Mo
o`03001oogoo0:Qoo`03001oogoo0:Qoo`03001oogoo02eoo`00QGoo00<007ooOol0Z7oo00<007oo
Ool0Ygoo00<007ooOol0Z7oo00<007ooOol0Z7oo00<007ooOol0;Goo0025Ool00`00Oomoo`2XOol0
0`00Oomoo`2WOol00`00Oomoo`2XOol00`00Oomoo`2XOol00`00Oomoo`0]Ool008Eoo`03001oogoo
0:Qoo`03001oogoo0:Moo`03001oogoo0:Qoo`03001oogoo0:Qoo`03001oogoo02eoo`00QGoo00<0
07ooOol0Z7oo00<007ooOol0Ygoo00<007ooOol0Z7oo00<007ooOol0Z7oo00<007ooOol0;Goo0025
Ool00`00Oomoo`1BOol00d8@Oomoo`1COol00`00Oomoo`1BOol00`00Oomoo`1BOol00`00Oomoo`1C
Ool00`00Oomoo`1BOol00`00Oomoo`1COol00`00Oomoo`1BOol00`00Oomoo`0]Ool008Eoo`03001o
ogoo059oo`03@Q1oogoo05=oo`03001oogoo059oo`03001oogoo059oo`03001oogoo05=oo`03001o
ogoo059oo`03001oogoo05=oo`03001oogoo059oo`03001oogoo02eoo`00QGoo00<007ooOol0DWoo
00=247ooOol0Dgoo00<007ooOol0DWoo00<007ooOol0DWoo00<007ooOol0Dgoo00<007ooOol0DWoo
00<007ooOol0Dgoo00<007ooOol0DWoo00<007ooOol0;Goo0025Ool00`00Oomoo`1BOol00d8@Oomo
o`1COol00`00Oomoo`1BOol00`00Oomoo`1BOol00`00Oomoo`1COol00`00Oomoo`1BOol00`00Oomo
o`1COol00`00Oomoo`1BOol00`00Oomoo`0]Ool008Eoool00?l00:h002moo`00ogooogooogooHgoo
003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mo
oomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogoo
ogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomS
Ool00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00
ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOooo
OoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomo
of=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo
003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mo
oomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogoo
ogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomS
Ool00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00
ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOooo
OoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomo
of=oo`00ogooogooogooHgoo003oOoooOoooOomSOol00?mooomooomoof=oo`00ogooogooogooHgoo
0000\
\>"], "Picture",
  Evaluatable->False,
  ImageSize->{219.938, 178.25},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["Fig. 5.6 Equilibrium water depth as a function of position.", "Caption",
  CellTags->"Fig. 5.6"],

Cell[TextData[{
  "In other words, as ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(x\)\(\ \)\)\)]],
  " increases we approach the shore. (See Fig. ",
  ButtonBox["5.6",
    ButtonData:>"Fig. 5.6",
    ButtonStyle->"Hyperlink"],
  ".) In Cell ",
  ButtonBox["5.24",
    ButtonData:>"Cell 5.24",
    ButtonStyle->"Hyperlink"],
  " we display ",
  Cell[BoxData[
      \(TraditionalForm\`z(x, 0, t)\)]],
  "  for a wave propagating in the positive ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(x\)\(\ \)\)\)]],
  "and ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " directions. In this example  we choose ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\)]],
  " so that ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(k\_x\), " ", "=", " ", 
          RowBox[{\(k\_y\), "=", 
            RowBox[{"1", " ", 
              SuperscriptBox[
                StyleBox["m",
                  FontSlant->"Plain"], \(-1\)], "for", 
              FormBox[\(x < 0\),
                "TraditionalForm"]}]}]}], TraditionalForm]]],
  ". According to Eq. ",
  ButtonBox["(5.2.34)",
    ButtonData:>"(5.2.34)",
    ButtonStyle->"Hyperlink"],
  " this requires ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Omega]", " ", "=", " ", 
          RowBox[{\(\@\(2\ g\ h\_o\)\), "\[Times]", "1", 
            SuperscriptBox[
              StyleBox["m",
                FontSlant->"Plain"], \(-1\)]}]}], TraditionalForm]]],
  ". Also, for ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(x > 0\)\(,\)\)\)]],
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(k\_x\), "=", 
          RowBox[{\(\@\(1 + 2  x/a\)\), 
            SuperscriptBox[
              StyleBox["m",
                FontSlant->"Plain"], \(-1\)]}]}], TraditionalForm]]],
  " according to Eqs. ",
  ButtonBox["(5.2.33)",
    ButtonData:>"(5.2.33)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(3.1.79)",
    ButtonData:>{"Chapter3.nb", "(3.1.79)"},
    ButtonStyle->"Hyperlink"],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(h[x_]\  := \ h0\ a/\((a + x)\)\  /; \ x > 0;\)\), "\n", 
    \(\(h[x_]\  := \ h0\  /; \ x \[LessEqual] \ 0;\)\), "\n", 
    \(\(\(c[x_]\  = \ \@\(g\ h[x]\);\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(kx[
          x_]\  := \ \@\(\[Omega]\^2/c[x]\^2 - \
ky\^2\);\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(\(\(\[Omega]\  = \ \@\(2\ g\ h0\);\)\(\[IndentingNewLine]\)
    \)\), "\n", 
    \(ky\  = \ 1; g = 9.8; a = 2; h0 = 2;\n\), "\[IndentingNewLine]", 
    \(\(\(z[x_, y_, t_]\  := \ \(\@kx[x]\) 
          Exp[I \((ky\ y\  + \ 
                  NIntegrate[
                    kx[x1], {x1, 0, x}]\  - \ \[Omega]\ t)\)];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(Table[
        Plot[Re[z[x, 0, t]], {x, \(-5\), 10}, PlotRange \[Rule] {\(-3\), 3}, 
          AxesLabel \[Rule] {"\<x\>", "\<z[x,0,t]\>"}], {t, 0, 
          1.8  Pi/\[Omega],  .2  Pi/\[Omega]}];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 5.24"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.0634921 0.309017 0.103006 [
[.0873 .29652 -6 -9 ]
[.0873 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.46825 .29652 -3 -9 ]
[.46825 .29652 3 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.72222 .29652 -3 -9 ]
[.72222 .29652 3 0 ]
[.84921 .29652 -3 -9 ]
[.84921 .29652 3 0 ]
[.97619 .29652 -6 -9 ]
[.97619 .29652 6 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .10301 -12 -4.5 ]
[.32877 .10301 0 4.5 ]
[.32877 .20601 -12 -4.5 ]
[.32877 .20601 0 4.5 ]
[.32877 .41202 -6 -4.5 ]
[.32877 .41202 0 4.5 ]
[.32877 .51503 -6 -4.5 ]
[.32877 .51503 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.34127 .64303 -26 0 ]
[.34127 .64303 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.0873 .30902 m
.0873 .31527 L
s
[(-4)] .0873 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-2)] .21429 .29652 0 1 Mshowa
.46825 .30902 m
.46825 .31527 L
s
[(2)] .46825 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(4)] .59524 .29652 0 1 Mshowa
.72222 .30902 m
.72222 .31527 L
s
[(6)] .72222 .29652 0 1 Mshowa
.84921 .30902 m
.84921 .31527 L
s
[(8)] .84921 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(10)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.18254 .30902 m
.18254 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.65873 .30902 m
.65873 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.81746 .30902 m
.81746 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.05556 .30902 m
.05556 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.34127 0 m
.34752 0 L
s
[(-3)] .32877 0 1 0 Mshowa
.34127 .10301 m
.34752 .10301 L
s
[(-2)] .32877 .10301 1 0 Mshowa
.34127 .20601 m
.34752 .20601 L
s
[(-1)] .32877 .20601 1 0 Mshowa
.34127 .41202 m
.34752 .41202 L
s
[(1)] .32877 .41202 1 0 Mshowa
.34127 .51503 m
.34752 .51503 L
s
[(2)] .32877 .51503 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(3)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .0206 m
.34502 .0206 L
s
.34127 .0412 m
.34502 .0412 L
s
.34127 .0618 m
.34502 .0618 L
s
.34127 .0824 m
.34502 .0824 L
s
.34127 .12361 m
.34502 .12361 L
s
.34127 .14421 m
.34502 .14421 L
s
.34127 .16481 m
.34502 .16481 L
s
.34127 .18541 m
.34502 .18541 L
s
.34127 .22661 m
.34502 .22661 L
s
.34127 .24721 m
.34502 .24721 L
s
.34127 .26781 m
.34502 .26781 L
s
.34127 .28842 m
.34502 .28842 L
s
.34127 .32962 m
.34502 .32962 L
s
.34127 .35022 m
.34502 .35022 L
s
.34127 .37082 m
.34502 .37082 L
s
.34127 .39142 m
.34502 .39142 L
s
.34127 .43262 m
.34502 .43262 L
s
.34127 .45322 m
.34502 .45322 L
s
.34127 .47383 m
.34502 .47383 L
s
.34127 .49443 m
.34502 .49443 L
s
.34127 .53563 m
.34502 .53563 L
s
.34127 .55623 m
.34502 .55623 L
s
.34127 .57683 m
.34502 .57683 L
s
.34127 .59743 m
.34502 .59743 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.34127 .64303 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.000 moveto
(D) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .33824 m
.06244 .27653 L
.08255 .2477 L
.0932 .23475 L
.10458 .22321 L
.11009 .21859 L
.11531 .21485 L
.12038 .21182 L
.12507 .20957 L
.12951 .20794 L
.13175 .2073 L
.13422 .20675 L
.13548 .20652 L
.13669 .20635 L
.13735 .20626 L
.13808 .20619 L
.13935 .20609 L
.14055 .20603 L
.14184 .20601 L
.14305 .20603 L
.14415 .20608 L
.14535 .20617 L
.14648 .20629 L
.14771 .20646 L
.14903 .20668 L
.15172 .20727 L
.15418 .20796 L
.15891 .20973 L
.1634 .21191 L
.17337 .21848 L
.18422 .22815 L
.20399 .2516 L
.225 .28249 L
.26275 .3428 L
.28372 .37253 L
.29291 .38356 L
.30295 .39383 L
.31272 .40178 L
.3218 .40722 L
.32683 .40937 L
.33139 .41078 L
.33392 .41133 L
.33535 .41158 L
.33666 .41175 L
.33782 .41187 L
.33908 .41196 L
.33973 .41199 L
.34041 .41201 L
.34164 .41217 L
.34295 .41266 L
Mistroke
.34414 .41306 L
.34544 .41344 L
.34685 .41379 L
.34818 .41406 L
.3494 .41425 L
.35057 .41438 L
.3518 .41446 L
.35291 .41449 L
.3541 .41446 L
.35521 .41438 L
.35623 .41427 L
.35743 .41408 L
.35873 .4138 L
.36109 .41312 L
.3636 .41212 L
.36636 .41068 L
.37195 .40666 L
.37713 .40155 L
.38198 .3955 L
.39184 .37949 L
.4022 .35743 L
.42072 .30718 L
.44073 .24611 L
.44944 .22129 L
.45888 .19828 L
.46415 .18794 L
.469 .18038 L
.47139 .17741 L
.47363 .17513 L
.47597 .17329 L
.4772 .17254 L
.47853 .17191 L
.47921 .17166 L
.47993 .17145 L
.48122 .17122 L
.48194 .17117 L
.48262 .17118 L
.48336 .17124 L
.48416 .17138 L
.4848 .17155 L
.48551 .17178 L
.48694 .17243 L
.48826 .17325 L
.48949 .17419 L
.49202 .17668 L
.49433 .17959 L
.49949 .1884 L
.50433 .19941 L
.50946 .21386 L
.51866 .24614 L
Mistroke
.53944 .33797 L
.54958 .3834 L
.55922 .42057 L
.5634 .43377 L
.56787 .44532 L
.57043 .45066 L
.57276 .45461 L
.5751 .45769 L
.57624 .45886 L
.5773 .45975 L
.57843 .46047 L
.57966 .46101 L
.58087 .46127 L
.58216 .46126 L
.58336 .46098 L
.5845 .46046 L
.58552 .4598 L
.58663 .45886 L
.58918 .45585 L
.59188 .45136 L
.59672 .43999 L
.60185 .4236 L
.60665 .40448 L
.61761 .35014 L
.6361 .24468 L
.64116 .21808 L
.64657 .19297 L
.65125 .1749 L
.65631 .15994 L
.65913 .15396 L
.66036 .1519 L
.66172 .15004 L
.663 .14868 L
.6642 .14777 L
.66547 .14718 L
.66618 .14702 L
.66682 .14699 L
.66804 .1472 L
.66917 .14773 L
.67041 .14867 L
.67172 .15009 L
.67298 .15184 L
.67416 .15385 L
.67637 .15852 L
.68166 .1744 L
.68652 .19445 L
.69747 .25516 L
.70737 .32076 L
.71795 .39018 L
.72309 .41963 L
Mistroke
.72794 .44312 L
.7323 .4597 L
.73476 .46692 L
.73703 .4721 L
.73815 .4741 L
.73922 .47567 L
.74045 .47706 L
.74157 .47793 L
.74262 .47839 L
.7436 .47852 L
.74467 .47832 L
.74582 .47772 L
.74707 .47659 L
.74778 .47573 L
.74843 .47481 L
.75089 .47015 L
.75313 .46432 L
.7555 .45655 L
.76032 .43588 L
.76483 .41133 L
.77508 .3416 L
.78411 .273 L
.79371 .20537 L
.79871 .17649 L
.80137 .16369 L
.80423 .15219 L
.80685 .14393 L
.808 .14103 L
.80926 .13838 L
.81045 .13638 L
.81155 .13497 L
.81272 .13396 L
.81397 .13344 L
.81467 .13339 L
.8154 .13354 L
.81672 .13431 L
.81745 .13501 L
.81813 .13584 L
.81969 .13839 L
.82105 .14133 L
.8223 .14461 L
.8251 .15398 L
.83028 .1782 L
.8352 .20847 L
.85532 .3694 L
.86493 .43819 L
.86769 .45373 L
.8703 .46609 L
.87266 .47524 L
.87395 .47934 L
Mistroke
.87516 .48258 L
.87631 .48513 L
.87736 .48699 L
.87852 .48851 L
.87977 .48951 L
.88081 .48984 L
.88194 .48968 L
.88301 .48902 L
.884 .48798 L
.88514 .48627 L
.8862 .48416 L
.88864 .47758 L
.891 .46886 L
.89356 .45702 L
.89853 .42734 L
.90315 .39315 L
.91363 .3015 L
.92449 .20743 L
.92982 .17006 L
.93216 .1566 L
.93474 .14422 L
.93721 .13491 L
.93839 .1314 L
.93952 .12866 L
.94079 .12626 L
.94195 .12474 L
.94321 .12382 L
.94392 .12363 L
.94457 .12368 L
.94584 .12435 L
.94702 .12569 L
.94833 .12793 L
.94973 .13127 L
.9526 .14091 L
.95522 .153 L
.95954 .17908 L
.96428 .21518 L
.97382 .30332 L
.97619 .32649 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.875},
  ImageMargins->{{0.75, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00K?ooool01OnHV9So410@o`000?lb<S;oc<c<0?Oo
oooo001/ooooo`05oa0@4?nj^[[oooooogMgMolb<S80moooool006Cooooo1_l00006ooooo`03o`00
0?oooooooooo0?Gooooo001_ooooo`03ojVYZOl@413ooooo00Gooooo0ol0003^ooooo`00K_ooool0
0ol@413o0000okZj^P06ooooo`03o`000?oooooooooo0>kooooo001_ooooo`03okZj^_lQ8B7ooooo
00Gooooo00?o0000ooooooooool0k_ooool006cooooo00Go410@oiRHV?oooooo^[Zjo`000006oooo
o`03o`000?oooooooooo0>kooooo001/ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0
003oooooooooo`3^ooooo`00Moooool00ol0003oooooooooo`3^ooooo`00Moooool2o`000>oooooo
001gooooo`03o`000?oooooooooo0>kooooo001gooooo`03o`000?oooooooooo0>kooooo001goooo
o`03o`000?oooooooooo0>kooooo001gooooo`03o`000?oooooooooo0>kooooo001gooooo`03o`00
0?oooooooooo0>kooooo001gooooo`03o`000?oooooooooo0>kooooo001gooooo`;o0000koooool0
07Oooooo00?o0000ooooooooool0k_ooool007Oooooo00?o0000ooooooooool0k_ooool007Oooooo
00?o0000ooooooooool0k_ooool007Oooooo00?o0000ooooooooool0k_ooool007Oooooo00?o0000
ooooooooool0k_ooool007Oooooo0_l0003_ooooo`00Moooool00ol0003oooooooooo`3^ooooo`00
Moooool00ol0003oooooooooo`3^ooooo`00Moooool00ol0003oooooooooo`3^ooooo`00Moooool0
0ol0003oooooooooo`3^ooooo`00Moooool00ol0003oooooooooo`3^ooooo`00Moooool00ol0003o
ooooooooo`3^ooooo`00Moooool2o`000>oooooo001gooooo`03o`000?oooooooooo0>kooooo001g
ooooo`03o`000?oooooooooo0>kooooo001/ooooo`Go00001_ooool00ol0003oooooooooo`3^oooo
o`00K?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0k_ooool006Co
oooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0k_ooool006kooooo
00?oV9RHob4Q8Oo^k^h01_ooool3o`000>kooooo001_ooooo`03ogMgMomVIVKooooo00Gooooo00?o
0000ooooooooool0k_ooool0073ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3^
ooooo`00K?ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0k_ooool0
06cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0>kooooo001goooo
o`03o`000?oooooooooo0>kooooo001gooooo`;o0000^_ooool2o`0003?ooooo001gooooo`03o`00
0?oooooooooo0;Sooooo0ol0000cooooo`00Moooool00ol0003oooooooooo`2hooooo`04o`000?oo
ooooooooo`0003;ooooo001gooooo`03o`000?oooooooooo097ooooo00?o0000ooooooooool09?oo
ool01?l0003oooooooooool0000booooo`00Moooool00ol0003oooooooooo`2@ooooo`03o`000?oo
oooo000002Cooooo00Go0000ooooooooooooooooo`00000booooo`00Moooool00ol0003ooooooooo
o`2?ooooo`05o`000?ooooooooooooooool000008oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo02oooooo001gooooo`03o`000?oooooooooo08oooooo00Go0000oooooooooooooooo
o`00000Sooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0;oooool007Oooooo0_l0
002@ooooo`05o`000?ooooooooooooooool000008oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo02oooooo001gooooo`03o`000?oooooooooo06;ooooo0ol0000Zooooo`05o`000?oo
ooooooooooooool000008oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02oooooo
001gooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool00_l0000Xooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo02kooooo001gooooo`03o`000?oooooooooo067ooooo00Go0000ooooooooooooooooo`00
000Xooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo02kooooo001gooooo`03o`000?oooooooooo067ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02kooooo001goooo
o`03o`000?oooooooooo063ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo02kooooo001gooooo`;o0000HOooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0;_ooool007Oooooo00?o0000ooooooooool0
Goooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
;_ooool007Oooooo00?o0000ooooooooool0:?ooool3o`0003Cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02gooooo001gooooo`03o`000?oooooo
oooo02Oooooo0_l00002ooooo`;o0000<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0;Oooool007Oooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0Qooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo02gooooo001gooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0]ooooo`00Moooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0;Oooool007Oooooo0_l0
000Uooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0;?ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0;Oooool007Oooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02_ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02gooooo001goooo
o`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0[oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0/oooo
o`00Moooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool0:_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool0;?ooool006gooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0/ooooo`00Koooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0/ooooo`00=oooool6o`0002Oooooo1_l00005ooooo`03o`000?oooooooooo00Gooooo0ol0000Q
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0;?ooool003?ooooo1?l00006oooo
o`?o0000;oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0[ooooo`00<_ooool00ol0003oooooooooo`0;ooooo`;o
0000;Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0[ooooo`00<?ooool2o`00013ooooo00?o0000ooooooooool0
:_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0[ooooo`00;_ooool2o`0001?ooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0[ooooo`00;Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo02Kooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool0:oooool002gooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`0_ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0[ooooo`00;?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02ko
oooo0_l0000Oooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0:oooool002_ooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Zooooo`00:_ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo02[ooooo000Zooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool0;?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool08oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool0:_ooool002Wooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0[oooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Roooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Zoooo
o`00:?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02[ooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02[ooooo000Wooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool0:Oooool2o`0001gooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0Zooooo`009oooool00ol0003oooooooooo`0Rooooo`03o`000?oo
oooooooo02Sooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo02[ooooo000Vooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool08Oooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0:_ooool0
02Gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Zooooo`009?ooool00ol0003o
ooooooooo`0Wooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo02Wooooo000Sooooo`03o`000?oooooooooo02Sooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool0:Oooool002?ooooo00?o0000ooooooooool01Oooool2o`000003oa0@4?oo
oooooooo01oooooo00?o0000ooooool000001?l0000Qooooo`;o00006oooool00ol0003ooooooooo
o`05ooooo`Go00003oooool00ol0003oooooooooo`0Cooooo`;o000000?o410@ooooooooool01ooo
ool00ol0003oooooooooo`0Booooo`09o`000?ooooooooooooooooo^k^ko<S8bo`000?l@413oc<c<
01;ooooo00?o0000ooooooooool03_ooool01Ol0003o8B4Qo`000?lQ8B7oc<c<01?ooooo00?o0000
ooooooooool02Oooool4o`000008oa0@4?l0003oooooonk^k_lb<S;o0000oc8b<_o^k^hUooooo`00
8_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo027ooooo00Ko0000oiRHV?lQ8B7o
k^k^oooooom4A4@Qooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01Oooool01OnH
V9So8B4Qonk^k_ooooooA4A400oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo01;ooooo00Wo0000oooooooooooooooooeEEEOmgMgOooooooiRHV?lQ
8B404_ooool00ol0003oooooooooo`0>ooooo`05ob4Q8Ol0003ooooooiRHV?lQ8B404oooool00ol0
003oooooooooo`0;ooooo`0:o`000?ooooooooooo`000?ooooooMgMgoiRHV?ooooooV9RHogMgMbGo
oooo000Qooooo`Ko00000_ooool5o`0001_ooooo1_l00002ooooo`04o`000?nHV9So8B4Qonk^kR;o
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`06ooooo`03oiRHV?lQ8B7ok^k^017o
oooo00?o0000ooooooooool04?ooool5o`0000Wooooo00?o0000ooooooooool04_ooool01Ol0003o
oooooooooooooooo000000?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0>oooo
o`;o00000_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00_ooooo00Ko0000oooo
oooooooo0000ooooool@4103ooooo`03oa0@4?oooooooooo02?ooooo000Pooooo`03o`000?oooooo
oooo00Kooooo00CoA4A4omgMgOoooooo00009?ooool01Ol0003ooooooiRHV?lQ8B7ok^k^027ooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`08ooooo`03oiRHV?lQ8B7ok^k^013ooooo
00?o0000ooooooooool04?ooool01?m4A4CogMgMooooool0000:ooooo`03o`000?oooooooooo01;o
oooo00Wo0000ooooooooooooooooo`000?nHV9SooooooiRHV?lQ8B404_ooool00ol0003ooooooooo
o`0>ooooo`05oc8b<_l0003ooooooiRHV?lb<S804oooool00ol0003oooooooooo`0;ooooo`06o`00
0?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`0Sooooo`008?ooool00ol0003o
ooooooooo`06ooooo`04omgMgOmEEEGoooooo`0002Gooooo00Co0000oooooomgMgOoIVIV8Oooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Wooooo00?oMgMgofIVI_ooool03oooool0
0ol0003oooooooooo`0@ooooo`04omgMgOmEEEGoooooo`0000Wooooo00?o0000ooooooooool04ooo
ool02Ol0003ooooooooooooooooo0000oeEEEOl0003o410@olc<c00Booooo`03o`000?oooooooooo
00kooooo00Goc<c<o`000?l0003o0000olc<c00Cooooo`03o`000?oooooooooo00_ooooo00Ko0000
oooooooooooo0000ooooool00003ooooo`03o`000?oooooooooo02?ooooo000Oooooo`03o`000?oo
oooooooo00Sooooo00?oMgMgolc<c?l000009_ooool00ol0003oooooo`00000Qooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo017ooooo00?oMgMgolc<c?l000002Oooool00ol0003oooooooooo`0Dooooo`05o`000?oo
oooooooooeEEEOn7QhL05Oooool00ol0003oooooooooo`0>ooooo`05oa0@4?l0003ooooookZj^_l@
41004oooool00ol0003oooooooooo`0;ooooo`06o`000?ooooooooooo`000?oooooo410@0oooool0
0ol@413oooooooooo`0Sooooo`007_ooool00ol0003oooooooooo`09ooooo`03onk^k_m4A4Co0000
02Cooooo00Go0000okZj^_l0003oV9RHoa0@400Qooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool01oooool01Ol0003o^[ZjoooooonHV9So410@013ooooo00?o0000ooooooooool04Ooo
ool00oo^k^koA4A4o`000009ooooo`03o`000?oooooooooo01Cooooo00Ko0000oooooooooooogMgM
oa0@4?nHV9PCooooo`03o`000?oooooooooo00oooooo0_l000000ooooooo^[Zjo`00000Cooooo`03
o`000?oooooooooo00_ooooo00[o0000oooooooooooo0000oooooomgMgOoV9RHoooooonHV9SoMgMg
9Oooool001kooooo00?o0000ooooooooool02_ooool00omgMgOo0000ooooo`0Sooooo`05oiRHV?l@
413o0000o`000?o<c<`08Oooool2o`0001Wooooo00?o0000ooooooooool01oooool01OnHV9So410@
o`000?lQ8B7oc<c<017ooooo00?o0000ooooooooool04Oooool00omgMgOo0000ooooo`08ooooo`03
o`000?oooooooooo01Cooooo00So0000ooooooooooooooooolc<c?m4A4Co0000oa0@417ooooo00?o
0000ooooooooool03oooool01OnYZJWo0000o`000?l@413oZJVY01;ooooo00?o0000ooooooooool0
2_ooool00omEEEGoIVIVo`000003ooooo`06o`000?o^k^ko<S8bo`000?lb<S;ok^k^9Oooool001go
oooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Xooooo`007Oooool00ol0003ooooo
ooooo`0eooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`0Nooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo02Sooooo000Looooo`03o`000?oooooooooo03Oooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01kooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool0:?ooool001_ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0@
ooooo`;o00000_ooool2o`0001;ooooo000Kooooo`03o`000?oooooooooo03Wooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool04?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgA;ooooo000=oooooooo0000>_l0000;
ooooo`04omgMgOl0003o410@olc<c1?ooooo000Dooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01Oooool00ol0003oooooo`000008ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Wooooo00?o0000
ooooooooool01_ooool2o`0000Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool04Oooool01?o^k^ko8B4Qoa0@4?o^
k^hCooooo`006Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Gooooo`05o`000?ooooooooooooooool000004Ooo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`0Aooooo`04ob4Q8OmgMgOoMgMgoc8b<Q?ooooo000Hooooo`03o`000?oo
oooooooo03oooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo02;ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool04?ooool2o`0000;ooooo0_l0000Booooo`005oooool0
0ol0003oooooooooo`10ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02Sooooo000Gooooo`03o`000?oooooooooo
047ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
02?ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool0:?ooool001Kooooo00?o0000ooooooooool0@oooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Xooooo`005_ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo01Sooooo
0_l0000Dooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo03cooooo000Eooooo`03o`000?oooooooooo04Gooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03cooooo000D
ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo03cooooo001Nooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0looooo`00Goooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0??ooool005oooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03cooooo001Pooooo`03o`000?oo
oooooooo01Cooooo0_l0000Booooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03gooooo001Qooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0mooooo`00HOooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0?Oooool006;o
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02Wo
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03go
oooo001Sooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0[ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0mooooo`00Hoooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool0:oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool0?Oooool006Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo03gooooo001Uooooo`03o`000?oooooooooo00oooooo0_l0000?oooo
o`03o`000?oooooooooo02cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo03gooooo001Uooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0mooooo`00I_ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo01gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool0?Oooool006Oooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03kooooo001Xooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0nooooo`00JOooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0<?ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0?_ooool006[o
oooo00?o0000ooooooooool02_ooool2o`0000cooooo00?o0000ooooooooool0<Oooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0?_ooool006_ooooo
0_l0000:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0<_ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0?_ooool006gooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03;ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03kooooo001^
ooooo`;o00001oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03?ooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03kooooo001]oooo
o`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
03Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
03oooooo001_ooooo`04o`000?oooooo0000o`0000Cooooo00?o0000ooooooooool01_ooool2o`00
03Sooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
03oooooo001_ooooo`04o`000?ooooooooooooooo`Oo00001?ooool2o`0003[ooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03oooooo001_ooooo`03
o`000?oooooooooo00Gooooo1ol0000looooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0oooooo`00Koooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo047ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Rooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo03oooooo001_ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0@Ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0@?oo
ool006oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`11ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`10ooooo`00KOooool00omE
EEGoIVIVo`000007ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0Rooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo043ooooo001gooooo`03o`000?oooooooooo04;o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo043o
oooo001gooooo`;o0000A?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0@?ooool007Oooooo00?o0000ooooooooool0@oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0@?ooool007Oooooo00?o0000
ooooooooool0@oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0@?ooool007Oooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0@Oooool007Oooooo00?o0000oooooooo
ool0A?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool0@Oooool007Oooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Pooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0@Oooool007Oooooo0_l00016ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo023ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`11ooooo`00Moooool0
0ol0003oooooooooo`16ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0:Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`11ooooo`00Moooool00ol0003oooooooooo`16ooooo`;o00000_ooool00ol0
003oooooooooo`0Zooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo047ooooo001gooooo`03o`000?oooooooooo04Oo
oooo0ol0000]ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo047ooooo001gooooo`03o`000?oooooooooo07Sooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0@_ooool007Oooooo00?o0000ooooooooool0N?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`12ooooo`00Moooool00ol0003oooooooooo`1iooooo`05o`000?ooooooooooooooool000009Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04;ooooo001gooooo`;o0000N_ooool2
o`000003ooooool0003ooooo02Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`13
ooooo`00Moooool00ol0003oooooooooo`1jooooo`?o00009oooool01Ol0003ooooooooooooooooo
000004Gooooo001gooooo`03o`000?oooooooooo0:Cooooo00Go0000ooooooooooooooooo`000015
ooooo`00Moooool00ol0003oooooooooo`2Tooooo`04o`000?ooooooooooo`0004Kooooo001goooo
o`03o`000?oooooooooo0:Gooooo0ol00016ooooo`00Moooool00ol0003oooooooooo`2Uooooo`;o
0000Aoooool007Oooooo0_l0003_ooooo`00Moooool00ol0003oooooooooo`3^ooooo`00Moooool0
0ol0003oooooooooo`3^ooooo`00Moooool00ol0003oooooooooo`3^ooooo`00K?ooool5o`0000Ko
oooo00?o0000ooooooooool0k_ooool006cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03
o`000?oooooooooo0>kooooo001]ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0
k_ooool006kooooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000>kooooo001_ooooo`03ogMgMomVIVKo
oooo00Gooooo00?o0000ooooooooool0k_ooool0073ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`3^ooooo`00K?ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000oooo
ooooool0k_ooool006cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo
0>kooooo001gooooo`03o`000?oooooooooo0>kooooo001gooooo`;o0000koooool007Oooooo00?o
0000ooooooooool0k_ooool007Oooooo00?o0000ooooooooool0k_ooool007Oooooo00?o0000oooo
ooooool0k_ooool007Oooooo00?o0000ooooooooool0k_ooool007Oooooo00?o0000ooooooooool0
k_ooool007Oooooo0_l0003_ooooo`00Moooool00ol0003oooooooooo`3^ooooo`00Moooool00ol0
003oooooooooo`3^ooooo`00Moooool00ol0003oooooooooo`3^ooooo`00Moooool00ol0003ooooo
ooooo`3^ooooo`00Moooool00ol0003oooooooooo`3^ooooo`00Moooool00ol0003oooooooooo`3^
ooooo`00Moooool2o`000>oooooo001gooooo`03o`000?oooooooooo0>kooooo001gooooo`03o`00
0?oooooooooo0>kooooo001gooooo`03o`000?oooooooooo0>kooooo001gooooo`03o`000?oooooo
oooo0>kooooo001gooooo`03o`000?oooooooooo0>kooooo001gooooo`;o0000koooool007Oooooo
00?o0000ooooooooool0k_ooool007Oooooo00?o0000ooooooooool0k_ooool007Oooooo00?o0000
ooooooooool0k_ooool006cooooo00GoV9RHoa0@4?l0003o<S8bolc<c006ooooo`03o`000?oooooo
oooo0>kooooo001/ooooo`05oa0@4?nj^[[oooooogMgMolb<S801_ooool00ol0003oooooooooo`3^
ooooo`00L?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0>kooooo001_ooooo`03
ojVYZOl@413ooooo00Gooooo0ol0003^ooooo`00K_ooool00ol@413o0000okZj^P3gooooo`00Kooo
ool00onj^[[o8B4Qooooo`3fooooo`00K?ooool01Ol@413oV9RHoooooonj^[[o00000?Oooooo001/
ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0moooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool006Gooooo0_l0000;ooooo`03o`000?nj^[[o
oooo00cooooo00?o0000okZj^_ooool03?ooool2o`000=Kooooo001Uooooo`03o`000?oooooooooo
00[ooooo0_lb<S8=ooooo`;o<S8b3_ooool00ol0003oooooooooo`3Dooooo`00F_ooool5o`0000Ko
oooo00Co0000oooooooooooooooo0_l00002ooooo`;o00000oooool00on7QhOo0000okZj^P03oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0003o
0000odA4A?nj^[X01?ooool00ol0003oooooooooo`3Dooooo`00F_ooool2ogMgM`;ooooo00?o0000
ooooooooool01?ooool02_l0003oooooooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oMgMd3oooo
o`03olc<c?l0003o410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`03olc<c?l0003o
410@00Cooooo00Go410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oooooooooo0=Cooooo001K
ooooo`03oeEEEOnHV9Sooooo00Oooooo00?o0000ooooooooool00_ooool01?oMgMgo0000oa0@4?o<
c<`:ooooo`05oa0@4?ooooooooooooooool@41002oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo0=Cooooo001Looooo`03oeEEEOnHV9Sooooo00Kooooo00?o0000ooooooooool00_oo
ool01?o^k^ko8B4Qoa0@4?o^k^h:ooooo`05o`000?ooooooooooooooool000002oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo0=Cooooo001Jooooo`05o`000?oooooooooooc8b<_n7
QhL01_ooool00ol0003oooooooooo`02ooooo`04ob4Q8OmgMgOoMgMgoc8b<P[ooooo00Go0000oooo
ooooooooooooo`00000;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0e?ooool0
05[ooooo1Ol00006ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000Wooooo00Go410@
oooooooooooooooooa0@4009ooooo`03oa0@4?l0003o000000?o00001Oooool00ol0003ooooooooo
o`3Dooooo`00IOooool00ol0003oooooooooo`0@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0=Cooooo001Uooooo`;o00004Oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00?o0000ooooooooool01Oooool2o`000=Kooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.312, 0}} -> {-6.0463, -3.175, 0.063082, \
0.0388833}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.0634921 0.309017 0.103006 [
[.0873 .29652 -6 -9 ]
[.0873 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.46825 .29652 -3 -9 ]
[.46825 .29652 3 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.72222 .29652 -3 -9 ]
[.72222 .29652 3 0 ]
[.84921 .29652 -3 -9 ]
[.84921 .29652 3 0 ]
[.97619 .29652 -6 -9 ]
[.97619 .29652 6 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .10301 -12 -4.5 ]
[.32877 .10301 0 4.5 ]
[.32877 .20601 -12 -4.5 ]
[.32877 .20601 0 4.5 ]
[.32877 .41202 -6 -4.5 ]
[.32877 .41202 0 4.5 ]
[.32877 .51503 -6 -4.5 ]
[.32877 .51503 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.34127 .64303 -26 0 ]
[.34127 .64303 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.0873 .30902 m
.0873 .31527 L
s
[(-4)] .0873 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-2)] .21429 .29652 0 1 Mshowa
.46825 .30902 m
.46825 .31527 L
s
[(2)] .46825 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(4)] .59524 .29652 0 1 Mshowa
.72222 .30902 m
.72222 .31527 L
s
[(6)] .72222 .29652 0 1 Mshowa
.84921 .30902 m
.84921 .31527 L
s
[(8)] .84921 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(10)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.18254 .30902 m
.18254 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.65873 .30902 m
.65873 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.81746 .30902 m
.81746 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.05556 .30902 m
.05556 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.34127 0 m
.34752 0 L
s
[(-3)] .32877 0 1 0 Mshowa
.34127 .10301 m
.34752 .10301 L
s
[(-2)] .32877 .10301 1 0 Mshowa
.34127 .20601 m
.34752 .20601 L
s
[(-1)] .32877 .20601 1 0 Mshowa
.34127 .41202 m
.34752 .41202 L
s
[(1)] .32877 .41202 1 0 Mshowa
.34127 .51503 m
.34752 .51503 L
s
[(2)] .32877 .51503 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(3)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .0206 m
.34502 .0206 L
s
.34127 .0412 m
.34502 .0412 L
s
.34127 .0618 m
.34502 .0618 L
s
.34127 .0824 m
.34502 .0824 L
s
.34127 .12361 m
.34502 .12361 L
s
.34127 .14421 m
.34502 .14421 L
s
.34127 .16481 m
.34502 .16481 L
s
.34127 .18541 m
.34502 .18541 L
s
.34127 .22661 m
.34502 .22661 L
s
.34127 .24721 m
.34502 .24721 L
s
.34127 .26781 m
.34502 .26781 L
s
.34127 .28842 m
.34502 .28842 L
s
.34127 .32962 m
.34502 .32962 L
s
.34127 .35022 m
.34502 .35022 L
s
.34127 .37082 m
.34502 .37082 L
s
.34127 .39142 m
.34502 .39142 L
s
.34127 .43262 m
.34502 .43262 L
s
.34127 .45322 m
.34502 .45322 L
s
.34127 .47383 m
.34502 .47383 L
s
.34127 .49443 m
.34502 .49443 L
s
.34127 .53563 m
.34502 .53563 L
s
.34127 .55623 m
.34502 .55623 L
s
.34127 .57683 m
.34502 .57683 L
s
.34127 .59743 m
.34502 .59743 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.34127 .64303 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.000 moveto
(D) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .39071 m
.06244 .34019 L
.10458 .2731 L
.12507 .24434 L
.13506 .23257 L
.14415 .2235 L
.1536 .21593 L
.16254 .21066 L
.16744 .2086 L
.17197 .20722 L
.17434 .2067 L
.1757 .20647 L
.17694 .2063 L
.17825 .20616 L
.17897 .20611 L
.17966 .20606 L
.18088 .20602 L
.18157 .20601 L
.18221 .20601 L
.18349 .20605 L
.18414 .20609 L
.18485 .20614 L
.18611 .20626 L
.18728 .20641 L
.18993 .20688 L
.19278 .20758 L
.19798 .20938 L
.20273 .21161 L
.21229 .21774 L
.22134 .22544 L
.24125 .24809 L
.25967 .2744 L
.29893 .33706 L
.33668 .38776 L
.35603 .40969 L
.36133 .41478 L
.36691 .4192 L
.37168 .42209 L
.37438 .42331 L
.37689 .42415 L
.37816 .42447 L
.37886 .42461 L
.37951 .42472 L
.38067 .42486 L
.38194 .42494 L
.38264 .42495 L
.38332 .42493 L
.38458 .42484 L
.38528 .42475 L
.38593 .42464 L
Mistroke
.38741 .42431 L
.38871 .42392 L
.38994 .42346 L
.39222 .42237 L
.39468 .42086 L
.39734 .41881 L
.40206 .41409 L
.40703 .4076 L
.41593 .39207 L
.42544 .37016 L
.43561 .34138 L
.45396 .28056 L
.47381 .21586 L
.47924 .20112 L
.48501 .18787 L
.48994 .17889 L
.49259 .17507 L
.49537 .17186 L
.49784 .16974 L
.49924 .16886 L
.50055 .16826 L
.50175 .16788 L
.50284 .16769 L
.5041 .16766 L
.50529 .16781 L
.50658 .16819 L
.50724 .16846 L
.50795 .16882 L
.51041 .17056 L
.5118 .17189 L
.51328 .17359 L
.51596 .17739 L
.52114 .18739 L
.52606 .19998 L
.53527 .23103 L
.55346 .31266 L
.56383 .36297 L
.57356 .40605 L
.57819 .42354 L
.58307 .43912 L
.58562 .44592 L
.58841 .45219 L
.59093 .45672 L
.59332 .45998 L
.59464 .46134 L
.59533 .46192 L
.59607 .46245 L
.59737 .46312 L
.59857 .46345 L
.59924 .46351 L
Mistroke
.59995 .46348 L
.60124 .46317 L
.60203 .46282 L
.60278 .46238 L
.60419 .46125 L
.60541 .45995 L
.6067 .45825 L
.60903 .45436 L
.6118 .44836 L
.61431 .44167 L
.62435 .40393 L
.63358 .35665 L
.6544 .23444 L
.6635 .18931 L
.66859 .16976 L
.67324 .15654 L
.67587 .15122 L
.67736 .14894 L
.67873 .14733 L
.67993 .14631 L
.68061 .14589 L
.68125 .1456 L
.68254 .14535 L
.68327 .1454 L
.68393 .14556 L
.68513 .14615 L
.68625 .14704 L
.68748 .14839 L
.68879 .15026 L
.69147 .15548 L
.69391 .16179 L
.69876 .1787 L
.7039 .2023 L
.71311 .25634 L
.72314 .32484 L
.73391 .39666 L
.73916 .42662 L
.74415 .44996 L
.74862 .4657 L
.75115 .47214 L
.7535 .47642 L
.75465 .4779 L
.7559 .47904 L
.75708 .47966 L
.75816 .47984 L
.75914 .47968 L
.76021 .47915 L
.76133 .4782 L
.76237 .47695 L
.7636 .47504 L
Mistroke
.76476 .47278 L
.76694 .46742 L
.76928 .46002 L
.77182 .45015 L
.78125 .39871 L
.79165 .32329 L
.80262 .23903 L
.80743 .20584 L
.81267 .17495 L
.81517 .16275 L
.81783 .15179 L
.82034 .14355 L
.82262 .13797 L
.82383 .13574 L
.82495 .13417 L
.82618 .13299 L
.82748 .13236 L
.82861 .13233 L
.82967 .13274 L
.83083 .13369 L
.83207 .13526 L
.83347 .13773 L
.83476 .14067 L
.83768 .14958 L
.84025 .15995 L
.84299 .1734 L
.85295 .23997 L
.86253 .31972 L
.87263 .40234 L
.8768 .43149 L
.88125 .45733 L
.88381 .4692 L
.88614 .47787 L
.88726 .4813 L
.88848 .48444 L
.88954 .48668 L
.89069 .48856 L
.89189 .48992 L
.89301 .49064 L
.8937 .4908 L
.89435 .49077 L
.89557 .4902 L
.89686 .48891 L
.89805 .48706 L
.89935 .48432 L
.90075 .48059 L
.90325 .47183 L
.90561 .46126 L
.91002 .43595 L
.92005 .3574 L
Mistroke
.93088 .25834 L
.9404 .18131 L
.94301 .16453 L
.9458 .14934 L
.94844 .13792 L
.95084 .13019 L
.95215 .12711 L
.95287 .12576 L
.95354 .12473 L
.95473 .12343 L
.95603 .1228 L
.95672 .12281 L
.95745 .12307 L
.95875 .12419 L
.95947 .12518 L
.96015 .12632 L
.96167 .12975 L
.96301 .13367 L
.96427 .13815 L
.96663 .14848 L
.97192 .18028 L
.97619 .21337 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0.75, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00K?ooool01OnHV9So410@o`000?lb<S;oc<c<0?Oo
oooo001/ooooo`05oa0@4?nj^[[oooooogMgMolb<S80moooool006Cooooo1_l00006ooooo`03o`00
0?oooooooooo0?Gooooo001_ooooo`03ojVYZOl@413ooooo00Gooooo0ol0003^ooooo`00K_ooool0
0ol@413o0000okZj^P06ooooo`03o`000?oooooooooo0>kooooo001_ooooo`03okZj^_lQ8B7ooooo
00Gooooo00?o0000ooooooooool0k_ooool006cooooo00Go410@oiRHV?oooooo^[Zjo`000006oooo
o`03o`000?oooooooooo0>kooooo001/ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0
003oooooooooo`3^ooooo`00Moooool00ol0003oooooooooo`3^ooooo`00Moooool2o`000>oooooo
001gooooo`03o`000?oooooooooo0>kooooo001gooooo`03o`000?oooooooooo0>kooooo001goooo
o`03o`000?oooooooooo0>kooooo001gooooo`03o`000?oooooooooo0>kooooo001gooooo`03o`00
0?oooooooooo0>kooooo001gooooo`03o`000?oooooooooo0>kooooo001gooooo`;o0000koooool0
07Oooooo00?o0000ooooooooool0k_ooool007Oooooo00?o0000ooooooooool0k_ooool007Oooooo
00?o0000ooooooooool0k_ooool007Oooooo00?o0000ooooooooool0k_ooool007Oooooo00?o0000
ooooooooool0k_ooool007Oooooo0_l0003_ooooo`00Moooool00ol0003oooooooooo`3^ooooo`00
Moooool00ol0003oooooooooo`3^ooooo`00Moooool00ol0003oooooooooo`3^ooooo`00Moooool0
0ol0003oooooooooo`3^ooooo`00Moooool00ol0003oooooooooo`3^ooooo`00Moooool2o`000>oo
oooo001gooooo`03o`000?oooooooooo0>kooooo001gooooo`03o`000?oooooooooo0>kooooo001g
ooooo`03o`000?oooooooooo0>kooooo001/ooooo`Go00001_ooool00ol0003oooooooooo`3^oooo
o`00K?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0k_ooool006Co
oooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0k_ooool006kooooo
00?oV9RHob4Q8Oo^k^h01_ooool3o`000>kooooo001_ooooo`03ogMgMomVIVKooooo00Gooooo00?o
0000ooooooooool0k_ooool0073ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3^
ooooo`00K?ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0k_ooool0
06cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0>kooooo001goooo
o`03o`000?oooooooooo0>kooooo001gooooo`;o0000__ooool2o`0002oooooo001gooooo`03o`00
0?oooooooooo0;cooooo00Co0000ooooool0003o0000;_ooool007Oooooo00?o0000ooooooooool0
_?ooool01?l0003oooooooooool0000^ooooo`00Moooool00ol0003oooooooooo`2Eooooo`;o0000
9Oooool01?l0003oooooooooool0000^ooooo`00Moooool00ol0003oooooooooo`2Dooooo`04o`00
0?ooooooooooo`0002?ooooo00Go0000ooooooooooooooooo`00000^ooooo`00Moooool00ol0003o
ooooooooo`2Dooooo`04o`000?ooooooooooo`0002?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0[ooooo`00Moooool00ol0003oooooooooo`2Dooooo`04o`000?ooooooooooo`00
02?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0[ooooo`00Moooool2o`0006So
oooo0ol0000Yooooo`05o`000?ooooooooooooooool000008_ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo02[ooooo001gooooo`03o`000?oooooooooo06Kooooo0_l000000ooooooo
0000ooooo`0Xooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo02[ooooo001gooooo`03o`000?oooooooooo06Kooooo
00Go0000ooooooooooooooooo`00000Wooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02[ooooo001gooooo`03o`00
0?oooooooooo06Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo02[ooooo001gooooo`03o`000?oooooooooo06Gooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02[ooooo001gooooo`03o`000?oooooo
oooo06Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo02[ooooo001gooooo`;o0000IOooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
02?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0:_ooool007Oooooo00?o0000ooooooooool0;oooool3o`0003;o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Wo
oooo001gooooo`03o`000?oooooooooo02gooooo0_l00003ooooo`;o0000;oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0:Oooool007Oooooo00?o
0000ooooooooool0;Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Wooooo001g
ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0/
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Y
ooooo`00Moooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0:Oooool007Oooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo02[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo02Wooooo001gooooo`;o0000:oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo02[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Pooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo02Wooooo001gooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0Xooooo`00Moooool00ol0003oooooooooo`0Yooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0:?ooool007Oooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo02Sooooo001]ooooo`Co000000?o410@oooooooo
ool00oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool0:?ooool006oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Xooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo01gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool0:?ooool004;ooooo1ol0000Kooooo`Ko00001Ooo
ool00ol0003oooooooooo`05ooooo`?o0000:?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo02Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo02Oooooo0010ooooo`;o00001oooool3o`0002?ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool09oooool0
03kooooo0_l0000<ooooo`;o00008Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Wooooo`00?Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Wooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo03Cooooo000looooo`03o`000?oooooooooo013ooooo
0_l0000Nooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`0dooooo`00>oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Wooooo00?o
EEEEofIVI_l000001oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo03Gooooo000i
ooooo`;o00005oooool00ol0003oooooooooo`0Rooooo`;o00009oooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0e
ooooo`00>?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02;ooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02?ooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`0eooooo`00=oooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0eooooo`00
=oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`0eooooo`00=_ooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo01oooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo02;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0eooooo`00=Oooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool09?ooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`0eooooo`00=?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
027ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0eooooo`00=?ooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo01cooooo0_l0000Uooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo03Ko
oooo000cooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0Sooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool08?ooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo03Kooooo000booooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool07oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo03Kooooo000a
ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0S
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo03Kooooo000`ooooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo03Kooooo000`ooooo`03
o`000?oooooooooo02Sooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Rooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo03Kooooo000[ooooo`;o000000?o410@ooooool000008Oooool5o`0000Kooooo
00?o0000ooooooooool06?ooool2o`0002?ooooo1Ol0000Fooooo`03o`000?oooooooooo00cooooo
0_l000000ol@413oooooooooo`0<ooooo`03o`000?oooooooooo017ooooo00Go0000oc8b<_l0003o
410@olc<c00Fooooo`03o`000?oooooooooo00[ooooo00Koc<c<ob4Q8Ol0003o8B4Qolc<c?l0000F
ooooo`03o`000?oooooooooo00Kooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;o
k^k^9?ooool002cooooo00?o0000ooooool000008_ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oo
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Qooooo`06o`000?nHV9So8B4Qonk^
k_ooooooA4A45_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool04Oooool01OmEEEGo0000oooooonHV9So8B4Q01Kooooo00?o0000ooooooooool02_oo
ool01_lQ8B7oV9RHoooooonHV9So8B4Qo`0001Kooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL09?ooool0027ooooo1_l00002ooooo`Go
00006oooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h02Oooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo027ooooo00Go0000oooooonHV9So8B4Qonk^kP0Gooooo`03o`000?oooooooooo
00[ooooo1Ol0000>ooooo`03o`000?oooooooooo017ooooo0_l00002ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool02_ooool01?l0003oooooooooooooool2o`0001Kooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41009?oo
ool002Wooooo00?oA4A4omgMgOooool00_l0000Uooooo`03oiRHV?lQ8B7ok^k^00Sooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`0Qooooo`06o`000?oooooooooooiRHV?lQ8B7ok^k^
5_ooool00ol0003oooooooooo`0:ooooo`04odA4A?oMgMgoooooo`0000oooooo00?o0000oooooooo
ool04Oooool2o`000003oooooonHV9So8B4Q01Kooooo00?o0000ooooooooool02_ooool01_lb<S;o
V9RHoooooonHV9So<S8bo`0001Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000009?ooool002Wooooo00CogMgMoeEEEOoooooo00009ooo
ool00omgMgOoIVIVooooo`08ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool08?oo
ool00ol0003oooooooooo`02ooooo`03ogMgMomVIVKooooo01Gooooo00?o0000ooooooooool02_oo
ool01?oMgMgoEEEEooooool0000?ooooo`03o`000?oooooooooo017ooooo0ol000000ol@413oc<c<
ooooo`0Eooooo`03o`000?oooooooooo00[ooooo00Koc<c<o`000?l0003o0000olc<c?l0000Eoooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo
000002Cooooo000Zooooo`03ogMgMol0003o000002Sooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo00[ooooo00?oMgMgolc<c?l000003oooool00ol0
003oooooooooo`0Aooooo`03oeEEEOl0003ooooo01Oooooo00?o0000ooooooooool02oooool01ol@
413o^[Zjoooooonj^[[o410@ooooool000005?ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00;ooooo00Go410@oooooooooooooooooa0@400Tooooo`00:_ooool00oo^k^ko0000o`00
000Tooooo`05o`000?nj^[[ooooooiRHV?l@41002_ooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo023ooooo00Oo0000ooooool0003o^[ZjoooooonHV9So410@01Oooooo00?o0000oooo
ooooool02_ooool00oo^k^koA4A4o`00000?ooooo`03o`000?oooooooooo017ooooo00?ogMgMoa0@
4?l000005oooool00ol0003oooooooooo`0;ooooo`07o`000?nj^[[ooooookZj^_l0003oooooo`00
000Dooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg02Cooooo000Zooooo`03o`000?mgMgOo000002Cooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c00;ooooo`03o`000?oooooooooo01?ooooo0_l0000Pooooo`08o`000?oooooooooooiRHV?l@
413o0000ob4Q8Oo<c<`Gooooo`03o`000?oooooooooo00_ooooo00?oMgMgo`000?ooool03Oooool0
0ol0003oooooooooo`0Cooooo`04olc<c?l0003o0000oa0@41Gooooo00?o0000ooooooooool02ooo
ool01onYZJWo410@o`000?l@413oZJVYooooool000005?ooool00ol0003oooooooooo`07ooooo`03
oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0Tooooo`00:_ooool00ol0003o
ooooooooo`0dooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0gooooo`00:Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0gooooo`00:?ooool00ol0003ooooooooo
o`0hooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0Oooooo`;o00000_ooool2o`0001;ooooo000Xooooo`03o`000?oooooooooo03Sooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01oooooo00Kok^k^
ob4Q8On7QhOo^[Zjo`000?oMgMdBooooo`009oooool00ol0003oooooooooo`0jooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Pooooo`04omgMgOl0
003o410@olc<c1?ooooo000=oooooooo0000>_l0000;ooooo`04onk^k_lQ8B7o410@onk^kQ?ooooo
000Dooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool00ol0003oooooo`00
0009ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooo`00
0007ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooool000001oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool01?l0003ooooooooo
ool00009ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooool000001oooool00ol0003ooooo
ooooo`07ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`07ooooo`04
o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0@oooo
o`04ob4Q8OmgMgOoMgMgoc8b<Q?ooooo000Uooooo`04o`000?ooooooooooo`0002Oooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool03oooool01Ol0003ooooooooooooooooo000001;ooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0?ooooo`;o00000_ooool2o`0001;ooooo000Uooooo`03o`000?oooooo
oooo03kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo03Sooooo000Tooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo03Sooooo000Sooooo`03o`000?oooooooooo047o
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02;o
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03So
oooo000Sooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo03Sooooo000Rooooo`03o`000?oooooooooo04Cooooo00?o
0000ooooooooool02oooool2o`0001gooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0>?ooool002;ooooo00?o0000
ooooooooool0A?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool08_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool0>?ooool0027ooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo01_ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0>?ooool0023ooooo00?o0000oooooooo
ool0Aoooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0>?ooool0023ooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool0>Oooool001oooooo00?o0000ooooooooool0B_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0>Ooo
ool001kooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`07ooooo`;o00006oooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0iooooo`007Oooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0iooooo`007Oooool00ol0003o
ooooooooo`1>ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`0Wooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0iooooo`007?ooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0iooooo`006oooool00ol0003ooooooooo
o`1Booooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`0Wooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0iooooo`006_ooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0iooooo`006_ooool00ol0003oooooooooo`1Doooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Xoooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0ioooo
o`006Oooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo00;ooooo0_l0000Iooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo03[ooooo000Hooooo`03o`000?oooooooooo05Sooooo00Go0000oooooooooooo
ooooo`00000Iooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo03[ooooo000Gooooo`03o`000?oooooooooo05Wooooo
00Go0000ooooooooooooooooo`00000Iooooo`03o`000?oooooooooo02[ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03[ooooo000Gooooo`03o`00
0?oooooooooo05[ooooo00Co0000oooooooooooo00006?ooool00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0jooooo`00
5_ooool00ol0003oooooooooo`1Looooo`03o`000?oooooo000001Sooooo00?o0000ooooooooool0
:oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
>_ooool001Gooooo00?o0000ooooooooool0G_ooool2o`0001Sooooo00?o0000ooooooooool0;?oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0>_oo
ool001Cooooo00?o0000ooooooooool0Goooool3o`0001Kooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0>_ooool0
07Oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0jooooo`00Moooool2o`0001Go
oooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool0>oooool007Oooooo00?o0000ooooool000004oooool00ol0003ooooo
ooooo`0_ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0kooooo`00KOooool4o`000003oa0@4?oooooooooo00?ooooo00Co0000oooooooooooo0000
4_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
7oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0kooooo`00Koooool00ol0003oooooooooo`05ooooo`05o`000?oo
ooooooooooooool000004?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0kooooo`00Koooool00ol0003ooooooooo
o`05ooooo`?o00000_ooool2o`0000gooooo00?o0000ooooooooool0<_ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0>oooool006oooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0<oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool0>oooool006oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0>oooool006oooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`;o00001oooool00ol0003oooooooooo`0fooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0kooooo`00
Koooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Oooooo1ol0000iooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0kooooo`00KOoo
ool00omEEEGoIVIVo`000007ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03cooooo001gooooo`03o`000?oooooo
oooo04Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo03cooooo001gooooo`;o0000BOooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
02?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0??ooool007Oooooo00?o0000ooooooooool0B?ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0??ooool007Oooooo
00?o0000ooooooooool0BOooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool0??ooool007Oooooo00?o0000ooooooooool0BOooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0??ooool007Oooooo00?o0000
ooooooooool0B_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0?Oooool007Oooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0?Oooool007Oooooo0_l0001;ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo01kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0mooooo`00
Moooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
9oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0mooooo`00Moooool00ol0003oooooooooo`1<ooooo`05o`000?oo
ooooooooooooool00000:oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo023ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0nooooo`00Moooool00ol0003ooooooooo
o`1<ooooo`Co0000;?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0nooooo`00Moooool00ol0003oooooooooo`1l
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo03kooooo001gooooo`03o`000?oooooooooo07cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool0?_ooool007Oooooo00?o0000ooooooooool0OOooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo02;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0nooooo`00
Moooool2o`0007oooooo00Co0000oooooooooooo00009Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo03kooooo001gooooo`03o`000?oooooooooo07kooooo1?l0000Uooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0?oooool007Oooooo00?o0000ooooooooool0Oooo
ool2o`0002Oooooo00Go0000ooooooooooooooooo`000011ooooo`00Moooool00ol0003ooooooooo
o`2Xooooo`05o`000?ooooooooooooooool00000@Oooool007Oooooo00?o0000ooooooooool0Z?oo
ool2o`000003ooooool0003ooooo047ooooo001gooooo`03o`000?oooooooooo0:Wooooo0_l00013
ooooo`00Moooool2o`000>oooooo001gooooo`03o`000?oooooooooo0>kooooo001gooooo`03o`00
0?oooooooooo0>kooooo001gooooo`03o`000?oooooooooo0>kooooo001/ooooo`Go00001_ooool0
0ol0003oooooooooo`3^ooooo`00K?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000
ooooooooool0k_ooool006gooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`3^oooo
o`00K_ooool00onHV9So8B4Qonk^kP06ooooo`?o0000k_ooool006oooooo00?oMgMgofIVI_ooool0
1Oooool00ol0003oooooooooo`3^ooooo`00L?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo0>kooooo001/ooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003ooooooooo
o`3^ooooo`00K?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0k_oo
ool007Oooooo00?o0000ooooooooool0k_ooool007Oooooo0_l0003_ooooo`00Moooool00ol0003o
ooooooooo`3^ooooo`00Moooool00ol0003oooooooooo`3^ooooo`00Moooool00ol0003ooooooooo
o`3^ooooo`00Moooool00ol0003oooooooooo`3^ooooo`00Moooool00ol0003oooooooooo`3^oooo
o`00Moooool2o`000>oooooo001gooooo`03o`000?oooooooooo0>kooooo001gooooo`03o`000?oo
oooooooo0>kooooo001gooooo`03o`000?oooooooooo0>kooooo001gooooo`03o`000?oooooooooo
0>kooooo001gooooo`03o`000?oooooooooo0>kooooo001gooooo`03o`000?oooooooooo0>kooooo
001gooooo`;o0000koooool007Oooooo00?o0000ooooooooool0k_ooool007Oooooo00?o0000oooo
ooooool0k_ooool007Oooooo00?o0000ooooooooool0k_ooool007Oooooo00?o0000ooooooooool0
k_ooool007Oooooo00?o0000ooooooooool0k_ooool007Oooooo0_l0003_ooooo`00Moooool00ol0
003oooooooooo`3^ooooo`00Moooool00ol0003oooooooooo`3^ooooo`00Moooool00ol0003ooooo
ooooo`3^ooooo`00K?ooool01OnHV9So410@o`000?lb<S;oc<c<00Kooooo00?o0000ooooooooool0
k_ooool006cooooo00Go410@okZj^_ooooooMgMgoc8b<P06ooooo`03o`000?oooooooooo0>kooooo
001`ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0k_ooool006oooooo00?oZJVY
oa0@4?ooool01Oooool3o`000>kooooo001^ooooo`03oa0@4?l0003o^[Zj0?Oooooo001_ooooo`03
okZj^_lQ8B7ooooo0?Kooooo001/ooooo`05oa0@4?nHV9SooooookZj^_l00000moooool006cooooo
00GoZJVYoa0@4?l0003o410@ojVYZ@3gooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00IOooool2o`0000_ooooo00?o0000okZj^_ooool0
3?ooool00ol0003o^[Zjooooo`0<ooooo`;o0000e_ooool006Gooooo00?o0000ooooooooool02_oo
ool2oc8b<Pgooooo0_lb<S8>ooooo`03o`000?oooooooooo0=Cooooo001Jooooo`Go00001_ooool0
1?l0003oooooooooooooool2o`0000;ooooo0_l00003ooooo`03ohN7Qol0003o^[Zj00?ooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP04ooooo`03ohN7Qol0003o^[Zj00Cooooo00GoV9RHo`000?l0003o
A4A4okZj^P04ooooo`03o`000?oooooooooo0=Cooooo001Jooooo`;oMgMg0_ooool00ol0003ooooo
ooooo`04ooooo`0:o`000?ooooooooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgMg@?ooooo00?o
c<c<o`000?l@41000oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Cooooo00?oc<c<o`000?l@4100
1?ooool01Ol@413o^[Zjonk^k_mgMgOo410@00Cooooo00?o0000ooooooooool0e?ooool005_ooooo
00?oEEEEoiRHV?ooool01oooool00ol0003oooooooooo`02ooooo`04omgMgOl0003o410@olc<c0[o
oooo00Go410@oooooooooooooooooa0@400;ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0e?ooool005cooooo00?oEEEEoiRHV?ooool01_ooool00ol0003oooooooooo`02ooooo`04
onk^k_lQ8B7o410@onk^kP[ooooo00Go0000ooooooooooooooooo`00000;ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0e?ooool005[ooooo00Go0000oooooooooooo<S8bohN7Q`06
ooooo`03o`000?oooooooooo00;ooooo00Co8B4QogMgMomgMgOo<S8b2_ooool01Ol0003ooooooooo
oooooooo000000_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3Dooooo`00F_oo
ool5o`0000Kooooo00Co0000oooooooooooooooo0_l00002ooooo`;o00002Oooool01Ol@413ooooo
oooooooooooo410@00Wooooo00?o410@o`000?l000000ol00005ooooo`03o`000?oooooooooo0=Co
oooo001Uooooo`03o`000?oooooooooo013ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0e?ooool006Gooooo0_l0000Aooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h02oooool00ol0003oooooooooo`05ooooo`;o0000e_ooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-6.04357, -3.17494, \
0.0630624, 0.0388712}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.0634921 0.309017 0.103006 [
[.0873 .29652 -6 -9 ]
[.0873 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.46825 .29652 -3 -9 ]
[.46825 .29652 3 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.72222 .29652 -3 -9 ]
[.72222 .29652 3 0 ]
[.84921 .29652 -3 -9 ]
[.84921 .29652 3 0 ]
[.97619 .29652 -6 -9 ]
[.97619 .29652 6 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .10301 -12 -4.5 ]
[.32877 .10301 0 4.5 ]
[.32877 .20601 -12 -4.5 ]
[.32877 .20601 0 4.5 ]
[.32877 .41202 -6 -4.5 ]
[.32877 .41202 0 4.5 ]
[.32877 .51503 -6 -4.5 ]
[.32877 .51503 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.34127 .64303 -26 0 ]
[.34127 .64303 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.0873 .30902 m
.0873 .31527 L
s
[(-4)] .0873 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-2)] .21429 .29652 0 1 Mshowa
.46825 .30902 m
.46825 .31527 L
s
[(2)] .46825 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(4)] .59524 .29652 0 1 Mshowa
.72222 .30902 m
.72222 .31527 L
s
[(6)] .72222 .29652 0 1 Mshowa
.84921 .30902 m
.84921 .31527 L
s
[(8)] .84921 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(10)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.18254 .30902 m
.18254 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.65873 .30902 m
.65873 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.81746 .30902 m
.81746 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.05556 .30902 m
.05556 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.34127 0 m
.34752 0 L
s
[(-3)] .32877 0 1 0 Mshowa
.34127 .10301 m
.34752 .10301 L
s
[(-2)] .32877 .10301 1 0 Mshowa
.34127 .20601 m
.34752 .20601 L
s
[(-1)] .32877 .20601 1 0 Mshowa
.34127 .41202 m
.34752 .41202 L
s
[(1)] .32877 .41202 1 0 Mshowa
.34127 .51503 m
.34752 .51503 L
s
[(2)] .32877 .51503 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(3)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .0206 m
.34502 .0206 L
s
.34127 .0412 m
.34502 .0412 L
s
.34127 .0618 m
.34502 .0618 L
s
.34127 .0824 m
.34502 .0824 L
s
.34127 .12361 m
.34502 .12361 L
s
.34127 .14421 m
.34502 .14421 L
s
.34127 .16481 m
.34502 .16481 L
s
.34127 .18541 m
.34502 .18541 L
s
.34127 .22661 m
.34502 .22661 L
s
.34127 .24721 m
.34502 .24721 L
s
.34127 .26781 m
.34502 .26781 L
s
.34127 .28842 m
.34502 .28842 L
s
.34127 .32962 m
.34502 .32962 L
s
.34127 .35022 m
.34502 .35022 L
s
.34127 .37082 m
.34502 .37082 L
s
.34127 .39142 m
.34502 .39142 L
s
.34127 .43262 m
.34502 .43262 L
s
.34127 .45322 m
.34502 .45322 L
s
.34127 .47383 m
.34502 .47383 L
s
.34127 .49443 m
.34502 .49443 L
s
.34127 .53563 m
.34502 .53563 L
s
.34127 .55623 m
.34502 .55623 L
s
.34127 .57683 m
.34502 .57683 L
s
.34127 .59743 m
.34502 .59743 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.34127 .64303 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.000 moveto
(D) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .41199 m
.02499 .41192 L
.02605 .41183 L
.02729 .41168 L
.02846 .41151 L
.03053 .41112 L
.03279 .41057 L
.0379 .40886 L
.04262 .4067 L
.05224 .40065 L
.06244 .39194 L
.0825 .36886 L
.10458 .3367 L
.14487 .2725 L
.1634 .24632 L
.18364 .22387 L
.18894 .21933 L
.1946 .21518 L
.19949 .21219 L
.20477 .2096 L
.2076 .2085 L
.2102 .20766 L
.21268 .20702 L
.21395 .20676 L
.21531 .20651 L
.21654 .20634 L
.21767 .20621 L
.21879 .20611 L
.21986 .20605 L
.22111 .20601 L
.22226 .20602 L
.22352 .20606 L
.22416 .2061 L
.22486 .20615 L
.22608 .20627 L
.22721 .20641 L
.22978 .20687 L
.23228 .20747 L
.23496 .20829 L
.23981 .21022 L
.24421 .21248 L
.25494 .2199 L
.26507 .22923 L
.28508 .25336 L
.30353 .28053 L
.34294 .34365 L
.36273 .37862 L
.38082 .40844 L
.3856 .415 L
.3908 .42119 L
Mistroke
.39577 .426 L
.40027 .42928 L
.40298 .43071 L
.40421 .43123 L
.40552 .43167 L
.40619 .43185 L
.40692 .43202 L
.40821 .43224 L
.40893 .43231 L
.40971 .43235 L
.41044 .43236 L
.41111 .43233 L
.4124 .43218 L
.41359 .43195 L
.41489 .43158 L
.41628 .43106 L
.4186 .42987 L
.42116 .42809 L
.4261 .4233 L
.43128 .41625 L
.44055 .39858 L
.45052 .3727 L
.46142 .33765 L
.48271 .25886 L
.49277 .22336 L
.50203 .19572 L
.50664 .18464 L
.51169 .17499 L
.51432 .17113 L
.51678 .16829 L
.51811 .16707 L
.51937 .16613 L
.52007 .1657 L
.52083 .16531 L
.52147 .16504 L
.52216 .16481 L
.52333 .16457 L
.52442 .16452 L
.52573 .16468 L
.52693 .16504 L
.52811 .16559 L
.5294 .16643 L
.53075 .16756 L
.53201 .16885 L
.53642 .17517 L
.53888 .17993 L
.54113 .185 L
.55109 .21556 L
.56029 .25375 L
.58108 .35761 L
Mistroke
.59011 .40038 L
.59982 .43738 L
.60267 .44574 L
.60538 .45244 L
.60802 .45771 L
.60931 .45981 L
.61047 .46144 L
.61158 .46275 L
.61278 .46388 L
.61405 .46477 L
.61524 .46531 L
.61656 .46556 L
.61723 .46555 L
.61796 .46544 L
.61925 .46496 L
.62045 .4642 L
.62171 .46307 L
.62305 .46151 L
.62546 .45775 L
.62805 .45237 L
.63091 .44485 L
.63602 .42747 L
.64082 .40696 L
.65938 .30165 L
.66832 .2469 L
.67787 .19561 L
.68336 .17247 L
.68834 .15683 L
.69075 .15135 L
.69202 .14905 L
.69336 .14705 L
.69453 .14569 L
.69582 .14461 L
.69699 .14402 L
.69809 .1438 L
.69933 .14394 L
.70003 .14421 L
.70068 .14458 L
.70187 .14555 L
.70314 .14702 L
.70439 .14889 L
.70556 .15103 L
.70776 .15603 L
.71275 .17206 L
.71814 .19609 L
.72914 .26212 L
.73925 .3333 L
.74836 .3954 L
.75338 .42503 L
.75812 .44835 L
Mistroke
.76081 .45911 L
.76373 .46853 L
.76501 .47189 L
.76638 .47491 L
.76766 .4772 L
.76883 .47885 L
.77001 .48006 L
.77128 .48085 L
.77246 .4811 L
.77357 .48092 L
.77487 .48018 L
.77608 .479 L
.7774 .47714 L
.7788 .47452 L
.78141 .46798 L
.78416 .45872 L
.78908 .4365 L
.79439 .40546 L
.80021 .36478 L
.81075 .28219 L
.82037 .21037 L
.82517 .18047 L
.8277 .16705 L
.83039 .15488 L
.83273 .14618 L
.83397 .14232 L
.83531 .13878 L
.83654 .13613 L
.83767 .13419 L
.83874 .13278 L
.83988 .13178 L
.84119 .13124 L
.84238 .13134 L
.84303 .13163 L
.84375 .13214 L
.84505 .13358 L
.84626 .13552 L
.84755 .13821 L
.84986 .14462 L
.85255 .15457 L
.85506 .16621 L
.86079 .2002 L
.87935 .35215 L
.88916 .42842 L
.89198 .44625 L
.89464 .46071 L
.89705 .47168 L
.8996 .4808 L
.90091 .48446 L
.90235 .48764 L
Mistroke
.90366 .48975 L
.90488 .49105 L
.90562 .49151 L
.90632 .49172 L
.90763 .49153 L
.90836 .49108 L
.90904 .49045 L
.90979 .48952 L
.91058 .48826 L
.91178 .48581 L
.91308 .48245 L
.91542 .47454 L
.91821 .46215 L
.92076 .44813 L
.93056 .37503 L
.94086 .28018 L
.94972 .20278 L
.95458 .16816 L
.95697 .15417 L
.95917 .14331 L
.96121 .13511 L
.96346 .12831 L
.96462 .12573 L
.96571 .12391 L
.96686 .12263 L
.96809 .12199 L
.96913 .12205 L
.97027 .12274 L
.97134 .12398 L
.97233 .12564 L
.97322 .12756 L
.9742 .13013 L
.97619 .13679 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0.75, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00K?ooool01OnHV9So410@o`000?lb<S;oc<c<0?Oo
oooo001/ooooo`05oa0@4?nj^[[oooooogMgMolb<S80moooool006Cooooo1_l00006ooooo`03o`00
0?oooooooooo0?Gooooo001_ooooo`03ojVYZOl@413ooooo00Gooooo0ol0003^ooooo`00K_ooool0
0ol@413o0000okZj^P06ooooo`03o`000?oooooooooo0>kooooo001_ooooo`03okZj^_lQ8B7ooooo
00Gooooo00?o0000ooooooooool0k_ooool006cooooo00Go410@oiRHV?oooooo^[Zjo`000006oooo
o`03o`000?oooooooooo0>kooooo001/ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0
003oooooooooo`3^ooooo`00Moooool00ol0003oooooooooo`3^ooooo`00Moooool2o`000>oooooo
001gooooo`03o`000?oooooooooo0>kooooo001gooooo`03o`000?oooooooooo0>kooooo001goooo
o`03o`000?oooooooooo0>kooooo001gooooo`03o`000?oooooooooo0>kooooo001gooooo`03o`00
0?oooooooooo0>kooooo001gooooo`03o`000?oooooooooo0>kooooo001gooooo`;o0000koooool0
07Oooooo00?o0000ooooooooool0k_ooool007Oooooo00?o0000ooooooooool0k_ooool007Oooooo
00?o0000ooooooooool0k_ooool007Oooooo00?o0000ooooooooool0k_ooool007Oooooo00?o0000
ooooooooool0k_ooool007Oooooo0_l0003_ooooo`00Moooool00ol0003oooooooooo`3^ooooo`00
Moooool00ol0003oooooooooo`3^ooooo`00Moooool00ol0003oooooooooo`3^ooooo`00Moooool0
0ol0003oooooooooo`3^ooooo`00Moooool00ol0003oooooooooo`3^ooooo`00Moooool2o`000>oo
oooo001gooooo`03o`000?oooooooooo0>kooooo001gooooo`03o`000?oooooooooo0>kooooo001g
ooooo`03o`000?oooooooooo0>kooooo001/ooooo`Go00001_ooool00ol0003oooooooooo`3^oooo
o`00K?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0k_ooool006Co
oooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0k_ooool006kooooo
00?oV9RHob4Q8Oo^k^h01_ooool3o`000>kooooo001_ooooo`03ogMgMomVIVKooooo00Gooooo00?o
0000ooooooooool0k_ooool0073ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3^
ooooo`00K?ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0k_ooool0
06cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0>kooooo001goooo
o`03o`000?oooooooooo0>kooooo001gooooo`;o0000`Oooool3o`0002_ooooo001gooooo`03o`00
0?oooooooooo0<3ooooo00?o0000ooooool00000:oooool007Oooooo00?o0000ooooooooool0`?oo
ool01?l0003oooooooooool0000Zooooo`00Moooool00ol0003oooooooooo`2Iooooo`?o00009?oo
ool01?l0003oooooooooool0000Zooooo`00Moooool00ol0003oooooooooo`2Hooooo`04o`000?oo
ooooooooo`0002?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Wooooo`00Mooo
ool00ol0003oooooooooo`2Hooooo`04o`000?ooooooooooo`0002?ooooo00?o0000ooooooooool0
;?ooool007Oooooo00?o0000ooooooooool0Uoooool01Ol0003ooooooooooooooooo000002;ooooo
00?o0000ooooooooool0;Oooool007Oooooo0_l0001]ooooo`?o0000:?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0;Oooool007Oooooo00?o0000
ooooooooool0Joooool00ol0003oooooooooo`02o`0002Oooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02gooooo001gooooo`03o`000?oooooooooo
06[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0]ooooo`00Moooool00ol0003o
ooooooooo`1Zooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0;Oooool007Oooooo
00?o0000ooooooooool0J_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02?ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02gooooo
001gooooo`03o`000?oooooooooo06[ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0Sooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`0]ooooo`00Moooool2o`0003Kooooo1?l0000`ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool0;_ooool007Oooooo00?o0000ooooooooool0=?ooool2o`0000;ooooo0_l0000_oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool0;_ooool007Oooooo00?o0000oooooooo
ool0<oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`0^ooooo`00Moooool00ol0003oooooooooo`0booooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo027ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo02kooooo001gooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool08?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0;_oo
ool007Oooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo02[ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0_ooooo`00Moooool00ol0
003oooooooooo`0aooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0:Oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo02oooooo001gooooo`;o0000<_ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0_ooooo`00Moooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool0:?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01oooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02oooooo
001gooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0;oooool007Oooooo00?o0000
ooooooooool0;oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`0`ooooo`00KOooool4o`000003oa0@4?oooooooooo
00?ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0`ooooo`00Koooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0<?ooool004oooooo
1_l0000?ooooo`Ko00001Oooool00ol0003oooooooooo`05ooooo`?o0000;_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0`ooooo`00C?ooool3o`0000Kooooo1?l0000Fooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0;_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`0`ooooo`00Boooool00ol0003oooooooooo`0;
ooooo`;o00005?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02kooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool0<?ooool004Wooooo0_l0000@ooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo033ooooo0018ooooo`03
o`000?oooooooooo017ooooo0_l0000Aooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0;Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02?ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0aooooo`00Aoooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo00cooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`0]ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo037ooooo0016ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool05Ooo
ool2o`0002kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool0<Oooool004Kooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0<Oooool0
04Gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
02cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool0<Oooool004Cooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0<Oooool004?ooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02_ooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool0<Oooool004;ooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0<Oooool0047ooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02_ooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool0<_ooool0043ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0@oooo
o`;o0000:oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`0booooo`00@?ooool00ol0003oooooooooo`0Rooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo01kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0booooo`00
?oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
:_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0booooo`00?_ooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0booooo`00?Oooool0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0:Oooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`0booooo`00?Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0booooo`00:oooool2o`000003
oa0@4?oooooooooo00cooooo00?o0000ooooooooool04_ooool5o`0001?ooooo00?o0000oooooooo
ool02oooool2o`0002?ooooo1Ol00002ooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool01_ooool2o`000003oa0@4?oooooooooo017ooooo00?o0000ooooooooool03?ooool01_o^k^ko
<S8bo`000?l@413oc<c<o`0001[ooooo00?o0000ooooooooool01Oooool01Oo<c<co8B4Qo`000?lQ
8B7oc<c<00Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`02ooooo`Co000000So
410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kRCooooo000/ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool04oooool01OnHV9So8B4Qonk^k_ooooooA4A401?ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0Rooooo`07oiRHV?lQ8B7ok^k^oooooom4A4Coooooo`00
000Jooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0<ooooo`06oeEEEOmgMgOooooooiRHV?lQ8B7o00006_ooool00ol0003oooooooooo`05ooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B401?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02Cooooo000Qoooo
o`Ko00000_ooool5o`0000cooooo00?o0000ooooooooool03?ooool6o`0000?ooooo00?oV9RHob4Q
8Oo^k^h05Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02?ooooo00?oV9RHob4Q
8Oo^k^h00_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Cooooo1Ol0000Coooo
o`03o`000?oooooooooo00cooooo00Co0000oooooooooooooooo0_l0000Iooooo`03o`000?oooooo
oooo00Kooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100
9?ooool002Wooooo00CoA4A4omgMgOoooooo00003Oooool00ol0003oooooooooo`0Fooooo`03oiRH
V?lQ8B7ok^k^01Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Tooooo`05oiRH
V?lQ8B7ok^k^ooooool000006_ooool00ol0003oooooooooo`04ooooo`04odA4A?oMgMgoooooo`00
01Cooooo00?o0000ooooooooool03?ooool01ol0003oV9RHoooooonHV9So8B4Qooooool000006?oo
ool00ol0003oooooooooo`06ooooo`05oc8b<_nHV9SooooooiRHV?lb<S801?ooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000002Cooooo000Yooooo`04omgMgOmEEEGoooooo`0000cooooo00?o0000oooooooo
ool06?ooool00omgMgOoIVIVooooo`0Eooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool09Oooool01?mgMgOoIVIVooooool0000Jooooo`03o`000?oooooooooo00Cooooo00CogMgMoeEE
EOoooooo00005?ooool00ol0003oooooooooo`0<ooooo`07o`000?mEEEGo0000oa0@4?o<c<cooooo
o`00000Hooooo`03o`000?oooooooooo00Kooooo00Goc<c<o`000?l0003o0000olc<c004ooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000009?ooool002[ooooo00?oMgMgolc<c?l000002oooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0Vooooo`;o00007?ooool00ol0003oooooooooo`04ooooo`03ogMgMoo<c<co000001Co
oooo00?o0000ooooooooool03?ooool00omEEEGoQhN7ooooo`03ooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool01_ooool01Ol@413o^[Zjoooooonj^[[o410@00Cooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00Go410@oooo
oooooooooooooa0@400Tooooo`00:_ooool00oo^k^koA4A4o`00000;ooooo`03o`000?oooooooooo
01Kooooo00Go0000okZj^_ooooooV9RHoa0@400Gooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool08_ooool01_l0003o^[ZjoooooonHV9So410@o`0001cooooo00?o0000ooooooooool0
1?ooool00oo^k^koA4A4o`00000Dooooo`03o`000?oooooooooo00cooooo00?ogMgMoa0@4?nHV9P0
0oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Kooooo00Go0000okZj^_oooooo
^[Zjo`000004ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL09?ooool002_ooooo00?oMgMgo`000?oo
ool02Oooool00ol0003oooooooooo`0Gooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`06?ooool00ol0
003oooooooooo`06ooooo`;o00008oooool01_nHV9So410@o`000?lQ8B7oc<c<o`0001cooooo00?o
0000ooooooooool01Oooool00omgMgOo0000ooooo`0Cooooo`03o`000?oooooooooo00gooooo00Ko
c<c<odA4A?l0003o410@ooooool0000Hooooo`03o`000?oooooooooo00Kooooo00GoZJVYoa0@4?l0
003o410@ojVYZ@04ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00oooool00omE
EEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h09?ooool003Kooooo00?o0000oooo
ooooool0=Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Oooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool0<oooool003Kooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool0<oooool003Gooooo00?o0000ooooooooool0
=oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
7?ooool2o`0000;ooooo0_l0000Booooo`00=?ooool00ol0003oooooooooo`0iooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Looooo`06onk^k_lQ
8B7oQhN7okZj^_l0003ogMgM4_ooool003Cooooo00?o0000ooooooooool0>_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool07Oooool01?oMgMgo0000
oa0@4?o<c<`Cooooo`003Oooooooo`0003[o00002oooool01?o^k^ko8B4Qoa0@4?o^k^hCooooo`00
5?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool2o`0000Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooo000000Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`;o0000
2?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo
00002Oooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000oooo
ooooool01?ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo013ooooo00Co8B4Q
ogMgMomgMgOo<S8b4oooool002Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool03oooool2o`0000;ooooo0_l0000B
ooooo`00<Oooool00ol0003oooooooooo`0oooooo`05o`000?ooooooooooooooool000009oooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0dooooo`00<Oooool00ol0003oooooooooo`10ooooo`04o`000?oooooooooo
o`0002Kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool0=?ooool0033ooooo00?o0000ooooooooool0@Oooool01?l0
003oooooooooool0000Vooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03Cooooo000_ooooo`03o`000?oooooooooo
04?ooooo00?o0000ooooool000009_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0dooooo`00;oooool00ol0003o
ooooooooo`13ooooo`04o`000?oooooo0000o`0002Gooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0=Oooool002ko
oooo00?o0000ooooooooool0AOooool2o`0002Gooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0=Oooool002gooooo
00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03Gooooo
000]ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool08oooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`0eooooo`00;?ooool00ol0003oooooooooo`18ooooo`;o00008oooool00ol0003oooooooooo`0R
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0e
ooooo`00:oooool00ol0003oooooooooo`19ooooo`;o00008oooool00ol0003oooooooooo`0Roooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0eoooo
o`00:oooool00ol0003oooooooooo`19ooooo`?o00008_ooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0eooooo`00
:_ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooo0000027ooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
=Oooool002[ooooo00?o0000ooooooooool0B_ooool01?l0003oooooooooool0000Pooooo`03o`00
0?oooooooooo02Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo03Gooooo000Yooooo`03o`000?oooooooooo04_ooooo00Co0000oooooooooooo0000
8?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0eooooo`00:?ooool00ol0003oooooooooo`1<ooooo`05o`000?oo
ooooooooooooool000007_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0fooooo`00:?ooool00ol0003ooooooooo
o`1<ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0fooooo`009oooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0fooooo`009_ooool00ol0003oooooooooo`1>oooo
o`;o00001?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02Oooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03Kooooo000Uooooo`03
o`000?oooooooooo04oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo03Kooooo000Tooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03Kooooo000Sooooo`03o`000?oo
oooooooo057ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo03Kooooo000Rooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03Kooooo000Qooooo`03o`000?oooooooooo
05?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
02[ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
03Kooooo000Pooooo`03o`000?oooooooooo05Cooooo0_l00007ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool0=oooool001oooooo00?o0000ooooooooool0EOooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0:_ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0=oooool001kooooo00?o
0000ooooooooool0E_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool0;?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool0=oooool001cooooo0_l0001Iooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0gooooo`006oooool00ol0003oooooooooo`1?oooo
o`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool0=oooool001Sooooo0ol0001Dooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03Oo
oooo000Dooooo`Co0000Eoooool00ol0003oooooooooo`05ooooo`?o00002_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo03Oooooo001_ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03Sooooo001_
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo03Sooooo001_ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo037ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03Sooooo001_ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`07ooooo`;o
0000=?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02;ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool0>?ooool006gooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`0>ooooo`;o0000
1_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0hooooo`00Moooool00ol0003oooooooooo`0@ooooo`;o00000_oo
ool2o`0003Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Rooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo03Sooooo001gooooo`;o00004_ooool4o`0003Wooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo03Sooooo001gooooo`03o`000?oooooooooo
04kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
03Sooooo001gooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Tooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo03Wooooo001gooooo`03o`000?oooooooooo04oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03Wooooo
001gooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo03Wooooo001gooooo`03o`000?oooooooooo04oooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03Wooooo001goooo
o`;o0000DOooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0>Oooool007Oooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Oooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool0>Oooool007Oooooo00?o0000ooooooooool0
DOooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
>_ooool007Oooooo00?o0000ooooooooool0DOooool2o`0000;ooooo00?o0000ooooooooool0:?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0jooooo`00Moooool00ol0003oooooooooo`1Booooo`?o0000;?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0jooooo`00Moooool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
03[ooooo001gooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0>_ooool007Oooooo
0_l00023ooooo`05o`000?ooooooooooooooool000009?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo03[ooooo001gooooo`03o`000?oooooooooo08;ooooo0_l000000ooooooo0000
ooooo`0Uooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0>_ooool007Oooooo00?o
0000ooooooooool0Poooool3o`0002Kooooo00Go0000ooooooooooooooooo`00000mooooo`00Mooo
ool00ol0003oooooooooo`2/ooooo`04o`000?ooooooooooo`0003kooooo001gooooo`03o`000?oo
oooooooo0:cooooo00Co0000oooooooooooo0000?_ooool007Oooooo00?o0000ooooooooool0[Ooo
ool3o`0003kooooo001gooooo`;o0000koooool007Oooooo00?o0000ooooooooool0k_ooool007Oo
oooo00?o0000ooooooooool0k_ooool007Oooooo00?o0000ooooooooool0k_ooool006cooooo1Ol0
0006ooooo`03o`000?oooooooooo0>kooooo001/ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_oo
ool00ol0003oooooooooo`3^ooooo`00KOooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooo
oooo0>kooooo001^ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003^ooooo`00Koooool00omgMgOo
IVIVooooo`05ooooo`03o`000?oooooooooo0>kooooo001`ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0k_ooool006cooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`00
0?oooooooooo0>kooooo001/ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003ooooo
ooooo`3^ooooo`00Moooool00ol0003oooooooooo`3^ooooo`00Moooool2o`000>oooooo001goooo
o`03o`000?oooooooooo0>kooooo001gooooo`03o`000?oooooooooo0>kooooo001gooooo`03o`00
0?oooooooooo0>kooooo001gooooo`03o`000?oooooooooo0>kooooo001gooooo`03o`000?oooooo
oooo0>kooooo001gooooo`;o0000koooool007Oooooo00?o0000ooooooooool0k_ooool007Oooooo
00?o0000ooooooooool0k_ooool007Oooooo00?o0000ooooooooool0k_ooool007Oooooo00?o0000
ooooooooool0k_ooool007Oooooo00?o0000ooooooooool0k_ooool007Oooooo00?o0000oooooooo
ool0k_ooool007Oooooo0_l0003_ooooo`00Moooool00ol0003oooooooooo`3^ooooo`00Moooool0
0ol0003oooooooooo`3^ooooo`00Moooool00ol0003oooooooooo`3^ooooo`00Moooool00ol0003o
ooooooooo`3^ooooo`00Moooool00ol0003oooooooooo`3^ooooo`00Moooool2o`000>oooooo001g
ooooo`03o`000?oooooooooo0>kooooo001gooooo`03o`000?oooooooooo0>kooooo001gooooo`03
o`000?oooooooooo0>kooooo001/ooooo`05oiRHV?l@413o0000oc8b<_o<c<`01_ooool00ol0003o
ooooooooo`3^ooooo`00K?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Kooooo00?o0000oooooooo
ool0k_ooool0073ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3^ooooo`00Kooo
ool00onYZJWo410@ooooo`05ooooo`?o0000k_ooool006kooooo00?o410@o`000?nj^[X0moooool0
06oooooo00?o^[Zjob4Q8Oooool0m_ooool006cooooo00Go410@oiRHV?oooooo^[Zjo`00003goooo
o`00K?ooool01OnYZJWo410@o`000?l@413oZJVY0?Oooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo001Uooooo`;o00002oooool00ol0003o
^[Zjooooo`0<ooooo`03o`000?nj^[[ooooo00cooooo0_l0003Fooooo`00IOooool00ol0003ooooo
ooooo`0:ooooo`;o<S8b3Oooool2oc8b<Pkooooo00?o0000ooooooooool0e?ooool005[ooooo1Ol0
0006ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000?ooooo00?oQhN7o`000?nj^[X0
0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo00?oQhN7o`000?nj^[X01?ooool01OnHV9So
0000o`000?m4A4Co^[Zj00Cooooo00?o0000ooooooooool0e?ooool005[ooooo0_mgMgL2ooooo`03
o`000?oooooooooo00Cooooo00[o0000ooooooooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM
0oooool00oo<c<co0000oa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?ooool00oo<c<co
0000oa0@4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003oooooooooo`3Doooo
o`00Foooool00omEEEGoV9RHooooo`07ooooo`03o`000?oooooooooo00;ooooo00CogMgMo`000?l@
413oc<c<2_ooool01Ol@413ooooooooooooooooo410@00_ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`3Dooooo`00G?ooool00omEEEGoV9RHooooo`06ooooo`03o`000?oooooooooo
00;ooooo00Cok^k^ob4Q8Ol@413ok^k^2_ooool01Ol0003ooooooooooooooooo000000_ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`3Dooooo`00F_ooool01Ol0003ooooooooooolb
<S;oQhN700Kooooo00?o0000ooooooooool00_ooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`05o`00
0?ooooooooooooooool000002oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0=Co
oooo001Jooooo`Go00001_ooool01?l0003oooooooooooooool2o`0000;ooooo0_l00009ooooo`05
oa0@4?ooooooooooooooool@41002Oooool00ol@413o0000o`000003o`0000Gooooo00?o0000oooo
ooooool0e?ooool006Gooooo00?o0000ooooooooool04?ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3Dooooo`00IOooool2o`00017o
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`03o`000?oooooooooo00Gooooo0_l0003Foooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-6.04357, -3.17494, \
0.0630624, 0.0388712}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.0634921 0.309017 0.103006 [
[.0873 .29652 -6 -9 ]
[.0873 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.46825 .29652 -3 -9 ]
[.46825 .29652 3 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.72222 .29652 -3 -9 ]
[.72222 .29652 3 0 ]
[.84921 .29652 -3 -9 ]
[.84921 .29652 3 0 ]
[.97619 .29652 -6 -9 ]
[.97619 .29652 6 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .10301 -12 -4.5 ]
[.32877 .10301 0 4.5 ]
[.32877 .20601 -12 -4.5 ]
[.32877 .20601 0 4.5 ]
[.32877 .41202 -6 -4.5 ]
[.32877 .41202 0 4.5 ]
[.32877 .51503 -6 -4.5 ]
[.32877 .51503 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.34127 .64303 -26 0 ]
[.34127 .64303 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.0873 .30902 m
.0873 .31527 L
s
[(-4)] .0873 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-2)] .21429 .29652 0 1 Mshowa
.46825 .30902 m
.46825 .31527 L
s
[(2)] .46825 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(4)] .59524 .29652 0 1 Mshowa
.72222 .30902 m
.72222 .31527 L
s
[(6)] .72222 .29652 0 1 Mshowa
.84921 .30902 m
.84921 .31527 L
s
[(8)] .84921 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(10)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.18254 .30902 m
.18254 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.65873 .30902 m
.65873 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.81746 .30902 m
.81746 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.05556 .30902 m
.05556 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.34127 0 m
.34752 0 L
s
[(-3)] .32877 0 1 0 Mshowa
.34127 .10301 m
.34752 .10301 L
s
[(-2)] .32877 .10301 1 0 Mshowa
.34127 .20601 m
.34752 .20601 L
s
[(-1)] .32877 .20601 1 0 Mshowa
.34127 .41202 m
.34752 .41202 L
s
[(1)] .32877 .41202 1 0 Mshowa
.34127 .51503 m
.34752 .51503 L
s
[(2)] .32877 .51503 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(3)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .0206 m
.34502 .0206 L
s
.34127 .0412 m
.34502 .0412 L
s
.34127 .0618 m
.34502 .0618 L
s
.34127 .0824 m
.34502 .0824 L
s
.34127 .12361 m
.34502 .12361 L
s
.34127 .14421 m
.34502 .14421 L
s
.34127 .16481 m
.34502 .16481 L
s
.34127 .18541 m
.34502 .18541 L
s
.34127 .22661 m
.34502 .22661 L
s
.34127 .24721 m
.34502 .24721 L
s
.34127 .26781 m
.34502 .26781 L
s
.34127 .28842 m
.34502 .28842 L
s
.34127 .32962 m
.34502 .32962 L
s
.34127 .35022 m
.34502 .35022 L
s
.34127 .37082 m
.34502 .37082 L
s
.34127 .39142 m
.34502 .39142 L
s
.34127 .43262 m
.34502 .43262 L
s
.34127 .45322 m
.34502 .45322 L
s
.34127 .47383 m
.34502 .47383 L
s
.34127 .49443 m
.34502 .49443 L
s
.34127 .53563 m
.34502 .53563 L
s
.34127 .55623 m
.34502 .55623 L
s
.34127 .57683 m
.34502 .57683 L
s
.34127 .59743 m
.34502 .59743 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.34127 .64303 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.000 moveto
(D) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .39393 m
.03279 .4013 L
.04262 .40725 L
.04758 .40937 L
.05035 .41029 L
.05288 .41096 L
.05524 .41144 L
.05657 .41164 L
.0578 .4118 L
.05887 .4119 L
.06005 .41197 L
.06129 .41202 L
.06244 .41202 L
.0631 .41201 L
.06379 .41198 L
.06504 .41191 L
.06581 .41184 L
.06653 .41176 L
.06788 .41158 L
.07036 .41113 L
.07305 .41047 L
.0781 .40874 L
.08274 .40658 L
.09336 .39972 L
.10458 .38973 L
.12422 .36642 L
.14255 .33969 L
.18146 .27755 L
.20127 .24896 L
.21172 .23606 L
.22282 .22453 L
.23266 .21645 L
.23788 .21304 L
.24352 .21011 L
.24603 .20905 L
.24867 .2081 L
.25112 .20738 L
.25339 .20685 L
.25554 .20646 L
.25673 .2063 L
.25782 .20618 L
.25902 .20609 L
.26031 .20603 L
.26154 .20601 L
.26267 .20603 L
.26392 .20609 L
.26511 .20618 L
.26618 .20629 L
.26734 .20645 L
.26994 .20692 L
Mistroke
.27236 .20752 L
.27675 .20898 L
.28143 .21105 L
.29226 .21788 L
.30207 .22635 L
.32135 .24851 L
.34219 .2785 L
.38324 .3595 L
.39313 .38155 L
.40371 .40333 L
.41285 .41919 L
.41767 .42596 L
.42278 .43169 L
.42531 .4339 L
.4281 .43582 L
.42932 .43649 L
.43063 .43708 L
.43187 .43752 L
.43301 .43782 L
.43418 .43802 L
.43526 .43811 L
.43646 .43809 L
.43773 .43795 L
.43837 .43782 L
.43906 .43765 L
.44033 .43722 L
.44155 .43668 L
.44269 .43607 L
.44486 .43457 L
.44688 .4328 L
.45149 .4274 L
.45599 .4203 L
.46081 .41069 L
.47096 .38404 L
.48202 .34661 L
.50214 .26648 L
.51232 .22711 L
.52189 .19573 L
.52709 .18218 L
.53186 .17247 L
.53445 .16843 L
.53717 .16516 L
.53858 .16388 L
.5399 .16294 L
.54064 .16252 L
.54134 .16221 L
.54215 .16194 L
.54289 .16178 L
.54404 .16169 L
.54527 .16182 L
Mistroke
.54644 .16217 L
.54751 .16267 L
.54875 .16348 L
.55011 .16465 L
.55259 .16753 L
.55517 .17156 L
.55793 .17699 L
.56287 .18966 L
.57255 .22427 L
.58132 .2647 L
.6022 .37444 L
.61136 .41696 L
.61621 .43543 L
.61888 .44406 L
.62141 .4511 L
.62384 .45677 L
.62648 .46164 L
.62765 .46333 L
.62889 .46482 L
.62995 .46584 L
.63111 .46668 L
.63228 .46723 L
.63336 .46748 L
.63454 .46745 L
.63578 .46708 L
.63687 .46648 L
.63788 .46569 L
.63898 .46456 L
.64017 .46305 L
.64273 .45871 L
.64551 .45238 L
.65055 .43674 L
.65546 .41674 L
.65998 .39465 L
.68035 .27046 L
.69031 .21141 L
.69503 .18782 L
.6994 .16965 L
.70389 .1554 L
.70626 .14987 L
.70747 .14761 L
.70878 .1456 L
.71003 .14412 L
.71119 .14314 L
.71229 .14256 L
.71345 .14231 L
.7145 .14241 L
.71547 .14279 L
.71654 .14351 L
.71768 .14465 L
Mistroke
.719 .14642 L
.72021 .14849 L
.72296 .15471 L
.72538 .16192 L
.72796 .17126 L
.73731 .21835 L
.75706 .35608 L
.7657 .41346 L
.77026 .43869 L
.77513 .46007 L
.77783 .46909 L
.78029 .47533 L
.78147 .47766 L
.78275 .47965 L
.78396 .48103 L
.78507 .48187 L
.78621 .48228 L
.78727 .48227 L
.78843 .48181 L
.78967 .4808 L
.79098 .47917 L
.79221 .47708 L
.79453 .47176 L
.79705 .46396 L
.79972 .45344 L
.80453 .42921 L
.81541 .35454 L
.82499 .27754 L
.83509 .20195 L
.83926 .17637 L
.84371 .15444 L
.84627 .14477 L
.8486 .13802 L
.84972 .13549 L
.85094 .13329 L
.85208 .13174 L
.85314 .13078 L
.85426 .13025 L
.85545 .13024 L
.85658 .13076 L
.85762 .13168 L
.85882 .13331 L
.86014 .13576 L
.86254 .14197 L
.86503 .15081 L
.8677 .16276 L
.87248 .19026 L
.88342 .27489 L
.89333 .36176 L
.90271 .43419 L
Mistroke
.90743 .46181 L
.91011 .47394 L
.91261 .48267 L
.91402 .48643 L
.91535 .48919 L
.91655 .49099 L
.91785 .49221 L
.91852 .49253 L
.91927 .49265 L
.92004 .49251 L
.92077 .49212 L
.92207 .49083 L
.9228 .48976 L
.92346 .48856 L
.92579 .48283 L
.9271 .47852 L
.92833 .47384 L
.93344 .44758 L
.9385 .41225 L
.94398 .36607 L
.95393 .27271 L
.96297 .19419 L
.96752 .16271 L
.97011 .14827 L
.97253 .13735 L
.97429 .13106 L
.97619 .12598 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0.75, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00K?ooool01OnHV9So410@o`000?lb<S;oc<c<0?Oo
oooo001/ooooo`05oa0@4?nj^[[oooooogMgMolb<S80moooool006Cooooo1_l00006ooooo`03o`00
0?oooooooooo0?Gooooo001_ooooo`03ojVYZOl@413ooooo00Gooooo0ol0003^ooooo`00K_ooool0
0ol@413o0000okZj^P06ooooo`03o`000?oooooooooo0>kooooo001_ooooo`03okZj^_lQ8B7ooooo
00Gooooo00?o0000ooooooooool0k_ooool006cooooo00Go410@oiRHV?oooooo^[Zjo`000006oooo
o`03o`000?oooooooooo0>kooooo001/ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0
003oooooooooo`3^ooooo`00Moooool00ol0003oooooooooo`3^ooooo`00Moooool2o`000>oooooo
001gooooo`03o`000?oooooooooo0>kooooo001gooooo`03o`000?oooooooooo0>kooooo001goooo
o`03o`000?oooooooooo0>kooooo001gooooo`03o`000?oooooooooo0>kooooo001gooooo`03o`00
0?oooooooooo0>kooooo001gooooo`03o`000?oooooooooo0>kooooo001gooooo`;o0000koooool0
07Oooooo00?o0000ooooooooool0k_ooool007Oooooo00?o0000ooooooooool0k_ooool007Oooooo
00?o0000ooooooooool0k_ooool007Oooooo00?o0000ooooooooool0k_ooool007Oooooo00?o0000
ooooooooool0k_ooool007Oooooo0_l0003_ooooo`00Moooool00ol0003oooooooooo`3^ooooo`00
Moooool00ol0003oooooooooo`3^ooooo`00Moooool00ol0003oooooooooo`3^ooooo`00Moooool0
0ol0003oooooooooo`3^ooooo`00Moooool00ol0003oooooooooo`3^ooooo`00Moooool2o`000>oo
oooo001gooooo`03o`000?oooooooooo0>kooooo001gooooo`03o`000?oooooooooo0>kooooo001g
ooooo`03o`000?oooooooooo0>kooooo001/ooooo`Go00001_ooool00ol0003oooooooooo`3^oooo
o`00K?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0k_ooool006Co
oooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0k_ooool006kooooo
00?oV9RHob4Q8Oo^k^h01_ooool3o`000>kooooo001_ooooo`03ogMgMomVIVKooooo00Gooooo00?o
0000ooooooooool0k_ooool0073ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3^
ooooo`00K?ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0k_ooool0
06cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0>kooooo001goooo
o`03o`000?oooooooooo0>kooooo001gooooo`;o0000koooool007Oooooo00?o0000ooooooooool0
a?ooool00ol0003oooooooooo`0Wooooo`00Moooool00ol0003oooooooooo`2Mooooo`;o00009Ooo
ool00ol0003oooooooooo`0Wooooo`00Moooool00ol0003oooooooooo`2Looooo`Co00008oooool0
0ol0003oooooooooo`0Xooooo`00Moooool00ol0003oooooooooo`2Looooo`04o`000?oooooooooo
o`0002?ooooo00?o0000ooooooooool0:?ooool007Oooooo00?o0000ooooooooool0W?ooool01?l0
003oooooooooool0000Rooooo`03o`000?oooooooooo02Wooooo001gooooo`03o`000?oooooooooo
077ooooo0_l0000Yooooo`05o`000?ooooooooooooooool000008Oooool00ol0003oooooooooo`0Y
ooooo`00Moooool2o`00077ooooo00Co0000ooooool0003o00009oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0:Oooool007Oooooo00?o0000oooo
ooooool0L?ooool01Ol0003ooooooooooooooooo000002Kooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02Wooooo001gooooo`03o`000?oooooooooo
06oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Yooooo`00Moooool00ol0003o
ooooooooo`1_ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool08oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0:Oooool007Oooooo
00?o0000ooooooooool0Koooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02?ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02[ooooo
001gooooo`03o`000?oooooooooo03cooooo0_l0000`ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool08_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool0:_ooool007Oooooo0_l0000kooooo`;o00000_ooool00ol0003oooooooooo`0]
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0:_ooool007Oooooo00?o0000oooo
ooooool0>_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02cooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`0Zooooo`00Moooool00ol0003oooooooooo`0jooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo02[ooooo001gooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
8?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
:oooool007Oooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0[ooooo`00Moooool0
0ol0003oooooooooo`0hooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02_ooooo001gooooo`03o`000?oooooooooo
03Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool0:oooool007Oooooo0_l0000hooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02_o
oooo001gooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0;?ooool007Oooooo00?o
0000ooooooooool0=_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02Oooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`0/ooooo`00Moooool00ol0003oooooooooo`0f
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo02cooooo001]ooooo`Co000000?o410@ooooooooool00oooool00ol0
003oooooooooo`0fooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo02cooooo001_ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0/ooooo`00Foooool7o`0000;ooooo
1_l00005ooooo`03o`000?oooooooooo00Gooooo0ol0000eooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02cooooo
001Hooooo`?o00001oooool3o`0000[ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool08oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo02cooooo001Fooooo`;o00003Oooool2o`0000Sooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool08oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02cooooo001Eoooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo03Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0;Oooool005Cooooo00?o0000oooooooo
ool04Oooool2o`0000Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0dooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo02gooooo001Cooooo`03o`000?oooooooooo01Cooooo00Ko0000oooooooooooo
EEEEofIVI_l00007ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Rooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0;Oooool005;o
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`09ooooo`;o0000=?ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`0]ooooo`00DOooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool0<oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`0]ooooo`00D?ooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0<oooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`0]ooooo`00Coooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0<oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`0]ooooo`00Coooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo023ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Ioooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0]oooo
o`00C_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0<_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`0]ooooo`00COooool00ol0003oooooooooo`0Pooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0]ooooo`00C?oo
ool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00?ooooo0_l0000cooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo02gooooo001<ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0aooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02gooooo001;ooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
02gooooo001:ooooo`03o`000?oooooooooo02Kooooo00Go0000ooooooooooooooooo`00000coooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo02kooooo0019ooooo`03o`000?oooooooooo02Oooooo00Go0000oooooooo
ooooooooo`00000cooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo02kooooo0018ooooo`03o`000?oooooooooo02Wo
oooo00Co0000oooooooooooo0000<_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0^ooooo`00:oooool2o`000003
oa0@4?oooooooooo01Sooooo00?o0000ooooooooool01_ooool5o`0001oooooo00Co0000ooooool0
003o00008oooool5o`0000Wooooo00?o0000ooooooooool05Oooool01?l0003oooooooooooooool2
o`000003oa0@4?oooooooooo01Kooooo00?o0000ooooooooool01oooool01Oo^k^ko<S8bo`000?l@
413oc<c<00Gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`02ooooo`05olc<c?lQ
8B7o0000ob4Q8Oo<c<`02?ooool00ol0003oooooooooo`0Dooooo`Go000000So410@oooooooooooo
k^k^oc8b<_l0003o<S8bonk^kRCooooo000/ooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool01oooool01OnHV9So8B4Qonk^k_ooooooA4A4023ooooo0_l0000Tooooo`05oiRHV?lQ8B7o
k^k^oooooom4A4@02Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`07ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B40
1Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00;ooooo00Go8B4QoiRHV?oooooo
V9RHob4Q8@09ooooo`03o`000?oooooooooo01?ooooo00Co0000oooooooooooo00001?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg02Cooooo000Qooooo`Ko00000_ooool5o`0001Sooooo00?o0000oooo
ooooool01_l00003ooooo`03oiRHV?lQ8B7ok^k^027ooooo0_l0000Uooooo`03oiRHV?lQ8B7ok^k^
00[ooooo00?o0000ooooooooool05_ooool6o`0001Sooooo00?o0000ooooooooool01oooool01Ol0
003ooooooooooooooooo000000Gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000002Oooool00ol0003oooooooooo`0Cooooo`04o`000?oo
ooooooooo`0000Cooooo00Go410@oooooooooooooooooa0@400Tooooo`00:Oooool01?m4A4CogMgM
ooooool0000Hooooo`03o`000?oooooooooo00_ooooo00?oV9RHob4Q8Oo^k^h08Oooool00ol0003o
ooooooooo`0Tooooo`03oiRHV?lQ8B7ok^k^00Sooooo00?o0000ooooooooool05oooool01Ol0003o
A4A4omgMgOoooooo000001Wooooo00?o0000ooooooooool01oooool01Ol0003oV9RHoooooonHV9So
8B4Q00Gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`02ooooo`05oc8b<_nHV9So
oooooiRHV?lb<S802Oooool00ol0003oooooooooo`0Cooooo`04o`000?ooooooooooo`0000Cooooo
00Go0000ooooooooooooooooo`00000Tooooo`00:Oooool01?oMgMgoEEEEooooool0000Hooooo`03
o`000?oooooooooo00cooooo00?oMgMgofIVI_ooool08?ooool2o`0002Kooooo00?oMgMgofIVI_oo
ool01oooool00ol0003oooooooooo`0Gooooo`05o`000?oMgMgoEEEEooooool000006Oooool00ol0
003oooooooooo`07ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo00;ooooo00Goc<c<o`000?l0003o0000olc<c009ooooo`03o`000?oo
oooooooo01?ooooo00Co0000oooooooooooo00001?ooool01Ol0003ooooooooooooooooo000002Co
oooo000Zooooo`03ogMgMoo<c<co000001Oooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0Oooooo`;o00009oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Oooooo
00Go0000oooooomgMgOoc<c<o`00000Hooooo`03o`000?oooooooooo00Sooooo00?oEEEEohN7Qooo
ool02?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00;ooooo00Go410@okZj^_oo
oooo^[Zjoa0@4009ooooo`03o`000?oooooooooo01?ooooo00Co0000oooooooooooo00001?ooool0
1Ol@413ooooooooooooooooo410@02Cooooo000Zooooo`03onk^k_m4A4Co000001Kooooo00?o0000
ooooooooool02oooool01Ol0003o^[ZjoooooonHV9So410@027ooooo00?o0000ooooool000008_oo
ool01Ol0003o^[ZjoooooonHV9So410@00Oooooo00?o0000ooooooooool06?ooool01Ol0003ooooo
onk^k_m4A4Co000001Sooooo00?o0000ooooooooool02?ooool00ooMgMgo410@oiRHV008ooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool00_ooool01Ol0003o^[Zjoooooonj^[[o0000
00Wooooo00?o0000ooooooooool04oooool01?l0003oooooooooool00004ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL09?ooool002_ooooo00?oMgMgo`000?ooool05Oooool00ol0003oooooooooo`0;
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`08Oooool3o`0002;ooooo00GoV9RHoa0@4?l0003o8B4Q
olc<c007ooooo`03o`000?oooooooooo01Wooooo00Co0000oooooomgMgOo00006?ooool00ol0003o
ooooooooo`09ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`02ooooo`05ojVYZOl@413o0000oa0@4?nYZJT02Oooool00ol0003oooooooooo`0B
ooooo`05o`000?ooooooEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Cooooo
0012ooooo`03o`000?oooooooooo03;ooooo00Co0000oooooooooooo0000;Oooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0_ooooo`00@_ooool00ol0003oooooooooo`0booooo`04o`000?ooooooooooo`0002gooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool0;oooool0047ooooo00?o0000ooooooooool0<oooool01Ol0003ooooooooo
oooooooo000002_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool05oooool2o`0000;ooooo0_l0000Booooo`00@?oo
ool00ol0003oooooooooo`0dooooo`05o`000?ooooooooooooooool00000:oooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0Gooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM4_ooool0043ooooo00?o0000oooooooo
ool0=?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Sooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool06?ooool01?oMgMgo0000oa0@4?o<c<`Cooooo`003Oooooooo`0003[o00002oooool01?o^k^ko
8B4Qoa0@4?o^k^hCooooo`005?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`04o`000?ooooooooooo`00
00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00?ooooo00Go0000ooooooooooooooooo`000009ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000Wooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Sooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`;o00002Oooool00ol0003ooooooooo
o`07ooooo`;o00002?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo000000Oooooo00?o
0000ooooooooool01oooool2o`0000Sooooo00?o0000ooooooooool04?ooool01?lQ8B7oMgMgogMg
Molb<S8Cooooo`00:?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooo000001Oooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0?ooooo`;o00000_ooool2o`0001;ooooo000m
ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo033ooooo000mooooo`03o`000?oooooooooo03Oooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo033ooooo000looooo`03
o`000?oooooooooo03Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Tooooo`03
o`000?oooooooooo01kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo033ooooo000looooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo033ooooo000kooooo`03o`000?oo
oooooooo03Wooooo0_l00006ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0<?oo
ool003[ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool0<Oooool003[ooooo00?o0000ooooooooool0>_ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0<Oooool003Wo
oooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo023o
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool0<Oooool003Wooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool08Oooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0<Oooool003Sooooo00?o
0000ooooooooool0??ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01kooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool0<Oooool003Oooooo00?o0000ooooooooool0?Oooool2o`0000Wooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0aooooo`00=oooool00ol0003oooooooooo`0moooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Roooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0aoooo
o`00=_ooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0booooo`00=_ooool00ol0003oooooooooo`0nooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Sooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0booooo`00=Ooo
ool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0booooo`00=?ooool00ol0003oooooooooo`10ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0booooo`00<oooool00ol0
003oooooooooo`11ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0booooo`00<_ooool00ol0003oooooooooo`12ooooo`;o00003Oooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo03;ooooo000aooooo`03o`000?oooooooooo04?ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03;ooooo
000`ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo03;ooooo000_ooooo`03o`000?oooooooooo04Gooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03;ooooo000^oooo
o`03o`000?oooooooooo04Kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo02Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo03;ooooo000]ooooo`03o`000?oooooooooo04Oooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02Oooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03;ooooo000]ooooo`03o`00
0?oooooooooo04Oooooo0_l0000?ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
:?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
<oooool001Cooooo0_l0000Fooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03?ooooo000Fooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool0<oooool001Oooooo0_l0000@ooooo`;o0000C?ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0:_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0<oooool001Wo
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`12ooooo`Co000000?o410@oooooooo
ool00oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool0:_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool0<oooool001[ooooo0_l00009ooooo`?o0000Aoooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Zooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0cooooo`007?oo
ool9o`0004[ooooo00?o0000ooooooooool01Oooool3o`0001;ooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0cooooo`00Koooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0cooooo`00Koooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0]ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0cooooo`00Koooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0cooooo`00Koooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0^ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool08?ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0dooooo`00KOooool00omEEEGoIVIVo`000007ooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0dooooo`00Moooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0=?ooool007Oooooo0_l0000Hoooo
o`;o00001Oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool08_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0dooooo`00Moooool00ol0003oooooooooo`0Hooooo`Ko
0000=Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02;ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool0=?ooool007Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0eooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo01gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0eooooo`00Mooo
ool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0eooooo`00Moooool00ol0003oooooooooo`1Dooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0eooooo`00Moooool00ol0
003oooooooooo`1Eooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0eooooo`00Moooool2o`0005Kooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo03Gooooo001gooooo`03o`000?oooooooooo05Kooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Gooooo
001gooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0Wooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo03Gooooo001gooooo`03o`000?oooooooooo05Kooooo0_l00003
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0=_ooool007Oooooo00?o0000oooo
ooooool0Eoooool2o`000003ooooool0003ooooo02[ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0=_ooool007Oo
oooo00?o0000ooooooooool0F?ooool2o`0002cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0=_ooool007Oooooo
00?o0000ooooooooool0Q_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0fooooo`00Moooool2o`0008Oooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0=_ooool007Oooooo00?o0000ooooooooool0Qoooool01?l0003oooooooooool0
000Tooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0=oooool007Oooooo00?o0000
ooooooooool0Qoooool3o`0002Kooooo00Go0000ooooooooooooooooo`00000iooooo`00Moooool0
0ol0003oooooooooo`2`ooooo`05o`000?ooooooooooooooool00000>Oooool007Oooooo00?o0000
ooooooooool0/?ooool2o`000003ooooool0003ooooo03Wooooo001gooooo`03o`000?oooooooooo
0;7ooooo0ol0000jooooo`00Moooool2o`000;?ooooo00?o0000ooooooooool0>Oooool007Oooooo
00?o0000ooooooooool0k_ooool007Oooooo00?o0000ooooooooool0k_ooool007Oooooo00?o0000
ooooooooool0k_ooool006cooooo1Ol00006ooooo`03o`000?oooooooooo0>kooooo001/ooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`3^ooooo`00KOooool00onHV9So
8B4Qonk^kP07ooooo`03o`000?oooooooooo0>kooooo001^ooooo`03oiRHV?lQ8B7ok^k^00Kooooo
0ol0003^ooooo`00Koooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0>kooooo001`
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0k_ooool006cooooo00Go0000okZj
^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0>kooooo001/ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3^ooooo`00Moooool00ol0003oooooooooo`3^oooo
o`00Moooool2o`000>oooooo001gooooo`03o`000?oooooooooo0>kooooo001gooooo`03o`000?oo
oooooooo0>kooooo001gooooo`03o`000?oooooooooo0>kooooo001gooooo`03o`000?oooooooooo
0>kooooo001gooooo`03o`000?oooooooooo0>kooooo001gooooo`;o0000koooool007Oooooo00?o
0000ooooooooool0k_ooool007Oooooo00?o0000ooooooooool0k_ooool007Oooooo00?o0000oooo
ooooool0k_ooool007Oooooo00?o0000ooooooooool0k_ooool007Oooooo00?o0000ooooooooool0
k_ooool007Oooooo00?o0000ooooooooool0k_ooool007Oooooo0_l0003_ooooo`00Moooool00ol0
003oooooooooo`3^ooooo`00Moooool00ol0003oooooooooo`3^ooooo`00Moooool00ol0003ooooo
ooooo`3^ooooo`00Moooool00ol0003oooooooooo`3^ooooo`00Moooool00ol0003oooooooooo`3^
ooooo`00Moooool2o`000>oooooo001gooooo`03o`000?oooooooooo0>kooooo001gooooo`03o`00
0?oooooooooo0>kooooo001gooooo`03o`000?oooooooooo0>kooooo001/ooooo`05oiRHV?l@413o
0000oc8b<_o<c<`01_ooool00ol0003oooooooooo`3^ooooo`00K?ooool01Ol@413o^[Zjoooooomg
MgOo<S8b00Kooooo00?o0000ooooooooool0k_ooool0073ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`3^ooooo`00Koooool00onYZJWo410@ooooo`05ooooo`?o0000k_ooool006ko
oooo00?o410@o`000?nj^[X0moooool006oooooo00?o^[Zjob4Q8Oooool0m_ooool006cooooo00Go
410@oiRHV?oooooo^[Zjo`00003gooooo`00K?ooool01OnYZJWo410@o`000?l@413oZJVY0?Oooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
001Uooooo`;o00002oooool00ol0003o^[Zjooooo`0<ooooo`03o`000?nj^[[ooooo00cooooo0_l0
003Fooooo`00IOooool00ol0003oooooooooo`0:ooooo`;o<S8b3Oooool2oc8b<Pkooooo00?o0000
ooooooooool0e?ooool005[ooooo1Ol00006ooooo`04o`000?ooooooooooooooo`;o00000_ooool2
o`0000?ooooo00?oQhN7o`000?nj^[X00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo00?o
QhN7o`000?nj^[X01?ooool01OnHV9So0000o`000?m4A4Co^[Zj00Cooooo00?o0000ooooooooool0
e?ooool005[ooooo0_mgMgL2ooooo`03o`000?oooooooooo00Cooooo00[o0000oooooooooooooooo
onk^k_lQ8B7oQhN7okZj^_l0003ogMgM0oooool00oo<c<co0000oa0@4003ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01?ooool00oo<c<co0000oa0@4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@4100
1?ooool00ol0003oooooooooo`3Dooooo`00Foooool00omEEEGoV9RHooooo`07ooooo`03o`000?oo
oooooooo00;ooooo00CogMgMo`000?l@413oc<c<2_ooool01Ol@413ooooooooooooooooo410@00_o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3Dooooo`00G?ooool00omEEEGoV9RH
ooooo`06ooooo`03o`000?oooooooooo00;ooooo00Cok^k^ob4Q8Ol@413ok^k^2_ooool01Ol0003o
oooooooooooooooo000000_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3Doooo
o`00F_ooool01Ol0003ooooooooooolb<S;oQhN700Kooooo00?o0000ooooooooool00_ooool01?lQ
8B7oMgMgogMgMolb<S8:ooooo`05o`000?ooooooooooooooool000002oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0=Cooooo001Jooooo`Go00001_ooool01?l0003ooooooooooooo
ool2o`0000;ooooo0_l00009ooooo`05oa0@4?ooooooooooooooool@41002Oooool00ol@413o0000
o`000003o`0000Gooooo00?o0000ooooooooool0e?ooool006Gooooo00?o0000ooooooooool04?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`3Dooooo`00IOooool2o`00017ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`03o`00
0?oooooooooo00Gooooo0_l0003Fooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-6.04357, -3.17494, \
0.0630624, 0.0388712}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.0634921 0.309017 0.103006 [
[.0873 .29652 -6 -9 ]
[.0873 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.46825 .29652 -3 -9 ]
[.46825 .29652 3 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.72222 .29652 -3 -9 ]
[.72222 .29652 3 0 ]
[.84921 .29652 -3 -9 ]
[.84921 .29652 3 0 ]
[.97619 .29652 -6 -9 ]
[.97619 .29652 6 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .10301 -12 -4.5 ]
[.32877 .10301 0 4.5 ]
[.32877 .20601 -12 -4.5 ]
[.32877 .20601 0 4.5 ]
[.32877 .41202 -6 -4.5 ]
[.32877 .41202 0 4.5 ]
[.32877 .51503 -6 -4.5 ]
[.32877 .51503 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.34127 .64303 -26 0 ]
[.34127 .64303 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.0873 .30902 m
.0873 .31527 L
s
[(-4)] .0873 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-2)] .21429 .29652 0 1 Mshowa
.46825 .30902 m
.46825 .31527 L
s
[(2)] .46825 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(4)] .59524 .29652 0 1 Mshowa
.72222 .30902 m
.72222 .31527 L
s
[(6)] .72222 .29652 0 1 Mshowa
.84921 .30902 m
.84921 .31527 L
s
[(8)] .84921 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(10)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.18254 .30902 m
.18254 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.65873 .30902 m
.65873 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.81746 .30902 m
.81746 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.05556 .30902 m
.05556 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.34127 0 m
.34752 0 L
s
[(-3)] .32877 0 1 0 Mshowa
.34127 .10301 m
.34752 .10301 L
s
[(-2)] .32877 .10301 1 0 Mshowa
.34127 .20601 m
.34752 .20601 L
s
[(-1)] .32877 .20601 1 0 Mshowa
.34127 .41202 m
.34752 .41202 L
s
[(1)] .32877 .41202 1 0 Mshowa
.34127 .51503 m
.34752 .51503 L
s
[(2)] .32877 .51503 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(3)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .0206 m
.34502 .0206 L
s
.34127 .0412 m
.34502 .0412 L
s
.34127 .0618 m
.34502 .0618 L
s
.34127 .0824 m
.34502 .0824 L
s
.34127 .12361 m
.34502 .12361 L
s
.34127 .14421 m
.34502 .14421 L
s
.34127 .16481 m
.34502 .16481 L
s
.34127 .18541 m
.34502 .18541 L
s
.34127 .22661 m
.34502 .22661 L
s
.34127 .24721 m
.34502 .24721 L
s
.34127 .26781 m
.34502 .26781 L
s
.34127 .28842 m
.34502 .28842 L
s
.34127 .32962 m
.34502 .32962 L
s
.34127 .35022 m
.34502 .35022 L
s
.34127 .37082 m
.34502 .37082 L
s
.34127 .39142 m
.34502 .39142 L
s
.34127 .43262 m
.34502 .43262 L
s
.34127 .45322 m
.34502 .45322 L
s
.34127 .47383 m
.34502 .47383 L
s
.34127 .49443 m
.34502 .49443 L
s
.34127 .53563 m
.34502 .53563 L
s
.34127 .55623 m
.34502 .55623 L
s
.34127 .57683 m
.34502 .57683 L
s
.34127 .59743 m
.34502 .59743 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.34127 .64303 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.000 moveto
(D) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .34344 m
.04262 .37028 L
.06244 .39276 L
.07286 .40142 L
.07784 .40471 L
.08255 .40727 L
.08523 .40849 L
.08813 .4096 L
.09054 .41037 L
.0932 .41105 L
.09458 .41134 L
.09607 .41159 L
.09689 .4117 L
.09764 .41179 L
.09841 .41187 L
.09912 .41192 L
.09976 .41196 L
.10045 .412 L
.10122 .41202 L
.10192 .41202 L
.10258 .41202 L
.10329 .412 L
.10458 .41193 L
.10582 .41183 L
.10695 .4117 L
.1095 .41129 L
.11185 .41076 L
.11408 .41013 L
.11908 .40828 L
.12452 .40556 L
.13546 .39797 L
.14558 .3886 L
.16425 .36624 L
.18485 .33595 L
.22505 .27189 L
.24353 .24589 L
.254 .23338 L
.26374 .22358 L
.27343 .21583 L
.2784 .21268 L
.28378 .20994 L
.28674 .20874 L
.28947 .20782 L
.29207 .20711 L
.29341 .20682 L
.29484 .20656 L
.29613 .20636 L
.29731 .20622 L
.29849 .20612 L
.29962 .20605 L
Mistroke
.30092 .20601 L
.30214 .20602 L
.30283 .20604 L
.30346 .20607 L
.30419 .20611 L
.30488 .20617 L
.30605 .20629 L
.3073 .20646 L
.30955 .20686 L
.31223 .20751 L
.31467 .20826 L
.31998 .2104 L
.325 .21306 L
.33386 .2192 L
.34348 .22717 L
.34841 .23117 L
.35371 .2366 L
.3633 .24941 L
.37329 .26681 L
.38432 .29033 L
.404 .34041 L
.42551 .39638 L
.43546 .41783 L
.44092 .42734 L
.44608 .43447 L
.44841 .43704 L
.45089 .43927 L
.45218 .44023 L
.4536 .44112 L
.4549 .44178 L
.45609 .44224 L
.45726 .44257 L
.45836 .44276 L
.45953 .44284 L
.46079 .44277 L
.4619 .44259 L
.46307 .44226 L
.46408 .44187 L
.46519 .44132 L
.46753 .43975 L
.47009 .43738 L
.47277 .43418 L
.47526 .43053 L
.48451 .41148 L
.48979 .39689 L
.49458 .3815 L
.50536 .34087 L
.52613 .2517 L
.53526 .21556 L
.5401 .19889 L
Mistroke
.54531 .18362 L
.55034 .17199 L
.55273 .16768 L
.55494 .16443 L
.55716 .16193 L
.55833 .16092 L
.55957 .16009 L
.56076 .15953 L
.56188 .15921 L
.56288 .15911 L
.56397 .15918 L
.5652 .15951 L
.56636 .16005 L
.56762 .16091 L
.56898 .16213 L
.57175 .1656 L
.57427 .1699 L
.57913 .18119 L
.58374 .19537 L
.5934 .23484 L
.60366 .28738 L
.62209 .38802 L
.63147 .43027 L
.63674 .44833 L
.63925 .45512 L
.64158 .46032 L
.64363 .46397 L
.64583 .46684 L
.64709 .468 L
.64827 .46876 L
.64933 .46917 L
.65048 .46932 L
.65161 .46917 L
.65286 .46865 L
.65415 .46772 L
.65536 .4665 L
.65753 .46344 L
.65986 .45893 L
.66241 .45257 L
.66512 .4442 L
.67 .42528 L
.68105 .36699 L
.70116 .23768 L
.71148 .18196 L
.71431 .17007 L
.71729 .15952 L
.71983 .15226 L
.72127 .14892 L
.72262 .14628 L
.72389 .14428 L
Mistroke
.72456 .1434 L
.72527 .14262 L
.72652 .14158 L
.72767 .14104 L
.72831 .1409 L
.729 .14089 L
.73024 .14123 L
.731 .14166 L
.73172 .14223 L
.73307 .14372 L
.73424 .14544 L
.73549 .14772 L
.73773 .15297 L
.74039 .16107 L
.74281 .17012 L
.75283 .22266 L
.76205 .28641 L
.77281 .36615 L
.77807 .40217 L
.78287 .43101 L
.78721 .45263 L
.78951 .46198 L
.79194 .47019 L
.79318 .47364 L
.79454 .47686 L
.79579 .47928 L
.79694 .48102 L
.79812 .48233 L
.79939 .4832 L
.8005 .4835 L
.80168 .48333 L
.80297 .48257 L
.80415 .48136 L
.8048 .48048 L
.80551 .47935 L
.80679 .47685 L
.80926 .47041 L
.81155 .46261 L
.81679 .4384 L
.82234 .40436 L
.84213 .24811 L
.85078 .18637 L
.85568 .1595 L
.85801 .14935 L
.86022 .14158 L
.86143 .13805 L
.86275 .13488 L
.86394 .1326 L
.86504 .131 L
.86624 .12983 L
Mistroke
.86755 .12921 L
.86821 .12917 L
.86891 .12932 L
.87019 .13013 L
.87141 .13153 L
.87209 .13259 L
.87273 .13375 L
.87514 .13963 L
.87733 .14699 L
.87965 .15682 L
.88478 .1853 L
.88959 .21926 L
.90054 .31278 L
.91039 .39812 L
.91576 .43748 L
.91838 .45359 L
.92076 .46614 L
.92281 .47524 L
.92504 .48313 L
.92626 .48655 L
.92739 .48912 L
.92846 .49103 L
.9296 .49247 L
.93075 .49331 L
.93198 .49353 L
.93315 .49307 L
.93421 .4921 L
.93545 .49028 L
.93681 .48748 L
.93809 .48405 L
.93927 .48021 L
.94362 .46085 L
.94831 .43147 L
.95681 .36117 L
.97619 .18509 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0.75, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00K?ooool01OnHV9So410@o`000?lb<S;oc<c<0?Oo
oooo001/ooooo`05oa0@4?nj^[[oooooogMgMolb<S80moooool006Cooooo1_l00006ooooo`03o`00
0?oooooooooo0?Gooooo001_ooooo`03ojVYZOl@413ooooo00Gooooo0ol0003^ooooo`00K_ooool0
0ol@413o0000okZj^P06ooooo`03o`000?oooooooooo0>kooooo001_ooooo`03okZj^_lQ8B7ooooo
00Gooooo00?o0000ooooooooool0k_ooool006cooooo00Go410@oiRHV?oooooo^[Zjo`000006oooo
o`03o`000?oooooooooo0>kooooo001/ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0
003oooooooooo`3^ooooo`00Moooool00ol0003oooooooooo`3^ooooo`00Moooool2o`000>oooooo
001gooooo`03o`000?oooooooooo0>kooooo001gooooo`03o`000?oooooooooo0>kooooo001goooo
o`03o`000?oooooooooo0>kooooo001gooooo`03o`000?oooooooooo0>kooooo001gooooo`03o`00
0?oooooooooo0>kooooo001gooooo`03o`000?oooooooooo0>kooooo001gooooo`;o0000koooool0
07Oooooo00?o0000ooooooooool0k_ooool007Oooooo00?o0000ooooooooool0k_ooool007Oooooo
00?o0000ooooooooool0k_ooool007Oooooo00?o0000ooooooooool0k_ooool007Oooooo00?o0000
ooooooooool0k_ooool007Oooooo0_l0003_ooooo`00Moooool00ol0003oooooooooo`3^ooooo`00
Moooool00ol0003oooooooooo`3^ooooo`00Moooool00ol0003oooooooooo`3^ooooo`00Moooool0
0ol0003oooooooooo`3^ooooo`00Moooool00ol0003oooooooooo`3^ooooo`00Moooool2o`000>oo
oooo001gooooo`03o`000?oooooooooo0>kooooo001gooooo`03o`000?oooooooooo0>kooooo001g
ooooo`03o`000?oooooooooo0>kooooo001/ooooo`Go00001_ooool00ol0003oooooooooo`3^oooo
o`00K?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0k_ooool006Co
oooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0k_ooool006kooooo
00?oV9RHob4Q8Oo^k^h01_ooool3o`000>kooooo001_ooooo`03ogMgMomVIVKooooo00Gooooo00?o
0000ooooooooool0k_ooool0073ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3^
ooooo`00K?ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0k_ooool0
06cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0>kooooo001goooo
o`03o`000?oooooooooo0>kooooo001gooooo`;o0000koooool007Oooooo00?o0000ooooooooool0
k_ooool007Oooooo00?o0000ooooooooool0XOooool2o`0004_ooooo001gooooo`03o`000?oooooo
oooo0:3ooooo0_l000000ooooooo0000ooooo`19ooooo`00Moooool00ol0003oooooooooo`2Poooo
o`04o`000?ooooooooooo`0004[ooooo001gooooo`03o`000?oooooooooo0:3ooooo00Go0000oooo
ooooooooooooo`000019ooooo`00Moooool00ol0003oooooooooo`1eooooo`?o00009oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo04Oooooo001gooooo`;o0000MOooool2o`0000;o
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo04Ko
oooo001gooooo`03o`000?oooooooooo07Cooooo00Go0000ooooooooooooooooo`00000Vooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0A_ooool007Oooooo00?o0000ooooooooool0
Loooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`16ooooo`00Moooool00ol0003oooooooooo`1cooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo04Kooooo001gooooo`03o`000?oooooooooo04;ooooo0_l0000_ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo04Kooooo001gooooo`03o`000?oooooooooo047ooooo1?l0000^ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
04Kooooo001gooooo`;o0000@Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02_o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0A_ooool007Oooooo00?o0000ooooooooool0?oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0AOooool007Oooooo00?o
0000ooooooooool0?oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Wooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool0AOooool007Oooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0AOooool007Oooooo00?o0000oooo
ooooool0?_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0AOooool007Oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Oooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0AOooool007Oooooo00?o0000ooooooooool0
?Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
A?ooool007Oooooo0_l0000nooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02Oooooo001gooooo`03o`000?oooooo
oooo03cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool09oooool007Oooooo00?o0000ooooooooool0??ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`0Wooooo`00Moooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02Oo
oooo001]ooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo02Oooooo001_ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0Xooooo`00I?ooool:o`000003ooooool0003ooooo00Kooooo0ol0000k
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo02Sooooo001Uooooo`?o00001_ooool4o`0000Gooooo00?o0000oooo
ooooool0>_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02?ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`0Xooooo`00Hoooool2o`0000[ooooo00?o0000oooooooo
ool00_l00003ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0:?ooool006;ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0003co
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool0:?ooool0067ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooo000003cooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0Qooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0:?ooool0063ooooo00?o
0000ooooooooool02_ooool00omEEEGoIVIVo`000006ooooo`;o0000??ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`0Xooooo`00Goooool00ol0003oooooooooo`0Eooooo`;o0000>_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0X
ooooo`00G_ooool00ol0003oooooooooo`0Fooooo`?o0000>Oooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Yoooo
o`00GOooool00ol0003oooooooooo`0Gooooo`04o`000?ooooooooooo`0003Sooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool0:Oooool005cooooo00?o0000ooooooooool06?ooool01?l0003oooooooooool0000goooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo02Wooooo001Looooo`03o`000?oooooooooo01Sooooo00Go0000oooooooo
ooooooooo`00000fooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo02Wooooo001Kooooo`03o`000?oooooooooo01Wo
oooo00Go0000ooooooooooooooooo`00000fooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02Wooooo001Jooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0cooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo02Wooooo001Iooooo`03o`000?oooooooooo01_ooooo0_l00004ooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool0:Oooool005Wooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0:Ooo
ool005Sooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo033ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool0:_ooool005Oooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0:_ooool005Ko
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02go
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool0:_ooool005Kooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0:_ooool002_ooooo0_l0
00000ol@413oooooooooo`0Qooooo`Go00008Oooool2o`0000Sooooo00?o0000ooooooooool06?oo
ool5o`0000oooooo00?o0000ooooooooool04oooool3o`0001kooooo00Wo0000oooooooooooooooo
onk^k_lb<S;o0000oa0@4?o<c<`02_ooool00ol0003oooooooooo`0Fooooo`05o`000?lQ8B7o0000
ob4Q8Oo<c<`03?ooool00ol0003oooooooooo`0Aooooo`Co000000So410@ooooooooooook^k^oc8b
<_l0003o<S8bonk^kRCooooo000/ooooo`03o`000?oooooooooo02;ooooo00GoV9RHob4Q8Oo^k^ko
0000odA4A00Qooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool06?ooool01OnHV9So
8B4Qonk^k_ooooooA4A400oooooo00?o0000ooooooooool05?ooool2o`0001gooooo00?o0000oooo
ooooool00_ooool01OmEEEGoMgMgoooooonHV9So8B4Q00[ooooo00?o0000ooooooooool05_ooool0
1Ol0003oV9RHoooooonHV9So8B4Q00cooooo00?o0000ooooooooool04oooool2o`0000?ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`0Tooooo`008Oooool6o`0000;ooooo1Ol0000Kooooo`Ko00000ooo
ool00onHV9So0000onk^kP0Rooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06?oo
ool00onHV9So8B4Qonk^kP0@ooooo`03o`000?oooooooooo017ooooo1Ol0000Mooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`00000:ooooo`03o`000?oooooooooo01Kooooo
00Go0000ooooooooooooooooo`00000<ooooo`03o`000?oooooooooo01?ooooo0_l00003ooooo`05
oa0@4?ooooooooooooooool@41009?ooool002Wooooo00CoA4A4omgMgOoooooo00009_ooool00ol0
003o8B4Qonk^kP0Qooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06Oooool00onH
V9So8B4Qonk^kP0>ooooo`03o`000?oooooooooo01;ooooo00?oA4A4omgMgOooool00_l0000Moooo
o`03o`000?oooooooooo00;ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0:ooooo`03o`000?oooooo
oooo01Kooooo00Go0000oiRHV?ooooooV9RHoc8b<P0<ooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000002Cooooo000Yooooo`04omgMgOmE
EEGoooooo`0002Gooooo00Co0000oooooomgMgOoIVIV8Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo01Wooooo00?oMgMgofIVI_ooool03Oooool00ol0003oooooooooo`0Booooo`06
omgMgOmEEEGoooooo`000?oooooo00007?ooool00ol0003oooooooooo`02ooooo`05o`000?mEEEGo
0000oa0@4?o<c<`02oooool00ol0003oooooooooo`0Eooooo`Co000000?oc<c<ooooooooool02ooo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`00000Tooooo`00:_ooool00omgMgOoc<c<o`00000Tooooo`05o`000?ooooooooooooooool00000
8Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0Cooooo`05ogMgMoo<c<co0000ooooool000007?ooool00ol0003o
ooooooooo`02ooooo`03oeEEEOn7QhOooooo00gooooo00?o0000ooooooooool05?ooool01_l0003o
410@okZj^_oooooo^[Zjoa0@40gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`02
ooooo`05oa0@4?ooooooooooooooool@41009?ooool002[ooooo00?ok^k^odA4A?l000009?ooool0
1Ol0003o^[ZjoooooonHV9So410@027ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0Eooooo`05o`000?nj^[[ooooooiRHV?l@41003_ooool00ol0003oooooooooo`0Cooooo`05onk^
k_m4A4Co0000ooooool000006oooool00ol0003oooooooooo`03ooooo`03omgMgOl@413oV9RH00go
oooo00?o0000ooooooooool05?ooool2o`000004okZj^_oooooo^[Zjo`0000gooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL09?ooool0
02_ooooo00?oMgMgo`000?ooool08_ooool01_l0003oV9RHoa0@4?l0003o8B4Qolc<c27ooooo0_l0
000<ooooo`03o`000?oooooooooo01Cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00>ooooo`03o`00
0?oooooooooo01Cooooo00CoMgMgo`000?oooooo00006oooool00ol0003oooooooooo`04ooooo`04
olc<c?m4A4Co0000oa0@40_ooooo00?o0000ooooooooool05?ooool01_l0003oZJVYoa0@4?l0003o
410@ojVYZ@gooooo00?o0000ooooooooool04?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h09?ooool004oooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0:oooool004oooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool0:oooool004kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04oooool2o`0000;ooooo0_l0000Boooo
o`00COooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0Dooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM4_ooool0
04gooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
02?ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool05Oooool01?oMgMgo0000oa0@4?o<c<`Cooooo`003Oooooooo`00
03[o00002oooool01?o^k^ko8B4Qoa0@4?o^k^hCooooo`005?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo
000000Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`05o`000?oooooo
ooooooooool000002Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00Go
0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00Go0000oooooooo
ooooooooo`000005ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool01Ol0
003ooooooooooooooooo000000Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo013ooooo00Co8B4QogMgMomgMgOo<S8b4oooool002Sooooo00?o0000
ooooooooool08?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool05oooool01Ol0003ooooooooooooooooo000001Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0?ooooo`;o00000_ooool2o`0001;ooooo001:ooooo`03o`000?oooooo
oooo02[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo02cooooo001:ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo02cooooo0019ooooo`03o`000?oooooooooo02_o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02co
oooo0018ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo02gooooo0018ooooo`03o`000?oooooooooo02cooooo0_l0
000Aooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0;Oooool004Oooooo00?o0000
ooooooooool0;Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool0;Oooool004Kooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool0;Oooool004Kooooo00?o0000oooooooo
ool0;_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool0;Oooool001Cooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0_ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0]ooooo`005?oo
ool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02gooooo000Eooooo`03o`000?oooooo
oooo02cooooo00?o0000ooooooooool0<?ooool2o`0001?ooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0]ooooo`005_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo
037ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
023ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
02kooooo000Gooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0<_ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0;_ooool001Oooooo
00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0^ooooo`006?ooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo02kooooo000Iooooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool0=?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool08_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool0;_ooool001[ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0doooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Soooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0^oooo
o`006_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo03Gooooo0_l0000Fooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool0;_ooool001_ooooo00?o0000ooooooooool0
8?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0^ooooo`007?ooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo03Oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo02kooooo000Mooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0>?ooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0;oooool0
01kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0_ooooo`007oooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo02oooooo000Pooooo`;o00005oooool00ol0003ooooo
ooooo`0kooooo`;o00006?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02oooooo
000Rooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0??ooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0;oooool002?ooooo00?o0000
ooooooooool04?ooool2o`0003oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo02oooooo000Tooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool0?oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool0;oooool002Gooooo0_l0000<ooooo`;o0000>?ooool4o`000003oa0@4?oooooooooo00?o
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02So
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02oo
oooo000Wooooo`03o`000?oooooooooo00Oooooo0_l0000looooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02Sooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02oooooo
000Xooooo`Wo0000?_ooool00ol0003oooooooooo`05ooooo`?o00006_ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo02oooooo001_ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02[ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02oooooo001_oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo02_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo033ooooo001_ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02_ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo033ooooo001_ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo02cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Pooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo033ooooo001]ooooo`03oeEEEOmVIVKo000000Oooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo033ooooo001gooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0`ooooo`00Moooool2o`00
01oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0`ooooo`00Moooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0<?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0<?ooool007Oooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo037ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo037ooooo
001gooooo`03o`000?oooooooooo027ooooo1?l0000dooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0aooooo`00Moooool00ol0003oooooooooo`1J
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0a
ooooo`00Moooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0aooooo`00Moooool2o`0005_ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo037ooooo001gooooo`03o`00
0?oooooooooo05[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo03;ooooo001gooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03;ooooo001gooooo`03o`000?oooooo
oooo05_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo03;ooooo001gooooo`03o`000?oooooooooo05cooooo00Co0000oooooooooooo0000:Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0booooo`00Moooool00ol0003oooooooooo`1Mooooo`?o0000:_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0booooo`00Moooool00ol0003oooooooooo`2:ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03;o
oooo001gooooo`;o0000Roooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo027ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0cooooo`00Moooool00ol0003ooooooooo
o`2;ooooo`03o`000?oooooooooo00;o00008oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo03?ooooo001gooooo`03o`000?oooooooooo08cooooo0ol0000Uooooo`05o`000?oooooo
ooooooooool00000=Oooool007Oooooo00?o0000ooooooooool0S?ooool2o`0002Kooooo00Go0000
ooooooooooooooooo`00000eooooo`00Moooool00ol0003oooooooooo`2dooooo`04o`000?oooooo
ooooo`0003Kooooo001gooooo`03o`000?oooooooooo0;Gooooo0ol0000fooooo`00Moooool2o`00
0;Kooooo0_l0000gooooo`00Moooool00ol0003oooooooooo`3^ooooo`00Moooool00ol0003ooooo
ooooo`3^ooooo`00Moooool00ol0003oooooooooo`3^ooooo`00K?ooool5o`0000Kooooo00?o0000
ooooooooool0k_ooool006cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooo
oooo0>kooooo001]ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0k_ooool006ko
oooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000>kooooo001_ooooo`03ogMgMomVIVKooooo00Gooooo
00?o0000ooooooooool0k_ooool0073ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`3^ooooo`00K?ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0k_oo
ool006cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0>kooooo001g
ooooo`03o`000?oooooooooo0>kooooo001gooooo`;o0000koooool007Oooooo00?o0000oooooooo
ool0k_ooool007Oooooo00?o0000ooooooooool0k_ooool007Oooooo00?o0000ooooooooool0k_oo
ool007Oooooo00?o0000ooooooooool0k_ooool007Oooooo00?o0000ooooooooool0k_ooool007Oo
oooo0_l0003_ooooo`00Moooool00ol0003oooooooooo`3^ooooo`00Moooool00ol0003ooooooooo
o`3^ooooo`00Moooool00ol0003oooooooooo`3^ooooo`00Moooool00ol0003oooooooooo`3^oooo
o`00Moooool00ol0003oooooooooo`3^ooooo`00Moooool00ol0003oooooooooo`3^ooooo`00Mooo
ool2o`000>oooooo001gooooo`03o`000?oooooooooo0>kooooo001gooooo`03o`000?oooooooooo
0>kooooo001gooooo`03o`000?oooooooooo0>kooooo001gooooo`03o`000?oooooooooo0>kooooo
001gooooo`03o`000?oooooooooo0>kooooo001gooooo`;o0000koooool007Oooooo00?o0000oooo
ooooool0k_ooool007Oooooo00?o0000ooooooooool0k_ooool007Oooooo00?o0000ooooooooool0
k_ooool006cooooo00GoV9RHoa0@4?l0003o<S8bolc<c006ooooo`03o`000?oooooooooo0>kooooo
001/ooooo`05oa0@4?nj^[[oooooogMgMolb<S801_ooool00ol0003oooooooooo`3^ooooo`00L?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0>kooooo001_ooooo`03ojVYZOl@413o
oooo00Gooooo0ol0003^ooooo`00K_ooool00ol@413o0000okZj^P3gooooo`00Koooool00onj^[[o
8B4Qooooo`3fooooo`00K?ooool01Ol@413oV9RHoooooonj^[[o00000?Oooooo001/ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT0moooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool006Gooooo0_l0000;ooooo`03o`000?nj^[[ooooo00cooooo
00?o0000okZj^_ooool03?ooool2o`000=Kooooo001Uooooo`03o`000?oooooooooo00[ooooo0_lb
<S8=ooooo`;o<S8b3_ooool00ol0003oooooooooo`3Dooooo`00F_ooool5o`0000Kooooo00Co0000
oooooooooooooooo0_l00002ooooo`;o00000oooool00on7QhOo0000okZj^P03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01?ooool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0003o0000odA4A?nj
^[X01?ooool00ol0003oooooooooo`3Dooooo`00F_ooool2ogMgM`;ooooo00?o0000ooooooooool0
1?ooool02_l0003oooooooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oMgMd3ooooo`03olc<c?l0
003o410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`03olc<c?l0003o410@00Cooooo
00Go410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oooooooooo0=Cooooo001Kooooo`03oeEE
EOnHV9Sooooo00Oooooo00?o0000ooooooooool00_ooool01?oMgMgo0000oa0@4?o<c<`:ooooo`05
oa0@4?ooooooooooooooool@41002oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
0=Cooooo001Looooo`03oeEEEOnHV9Sooooo00Kooooo00?o0000ooooooooool00_ooool01?o^k^ko
8B4Qoa0@4?o^k^h:ooooo`05o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo0=Cooooo001Jooooo`05o`000?oooooooooooc8b<_n7QhL01_ooool0
0ol0003oooooooooo`02ooooo`04ob4Q8OmgMgOoMgMgoc8b<P[ooooo00Go0000oooooooooooooooo
o`00000;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0e?ooool005[ooooo1Ol0
0006ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000Wooooo00Go410@oooooooooooo
oooooa0@4009ooooo`03oa0@4?l0003o000000?o00001Oooool00ol0003oooooooooo`3Dooooo`00
IOooool00ol0003oooooooooo`0@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo0=Cooooo001Uooooo`;o00004Oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00?o0000ooooooooool01Oooool2o`000=Kooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-6.04357, -3.17494, \
0.0630624, 0.0388712}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.0634921 0.309017 0.103006 [
[.0873 .29652 -6 -9 ]
[.0873 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.46825 .29652 -3 -9 ]
[.46825 .29652 3 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.72222 .29652 -3 -9 ]
[.72222 .29652 3 0 ]
[.84921 .29652 -3 -9 ]
[.84921 .29652 3 0 ]
[.97619 .29652 -6 -9 ]
[.97619 .29652 6 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .10301 -12 -4.5 ]
[.32877 .10301 0 4.5 ]
[.32877 .20601 -12 -4.5 ]
[.32877 .20601 0 4.5 ]
[.32877 .41202 -6 -4.5 ]
[.32877 .41202 0 4.5 ]
[.32877 .51503 -6 -4.5 ]
[.32877 .51503 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.34127 .64303 -26 0 ]
[.34127 .64303 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.0873 .30902 m
.0873 .31527 L
s
[(-4)] .0873 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-2)] .21429 .29652 0 1 Mshowa
.46825 .30902 m
.46825 .31527 L
s
[(2)] .46825 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(4)] .59524 .29652 0 1 Mshowa
.72222 .30902 m
.72222 .31527 L
s
[(6)] .72222 .29652 0 1 Mshowa
.84921 .30902 m
.84921 .31527 L
s
[(8)] .84921 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(10)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.18254 .30902 m
.18254 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.65873 .30902 m
.65873 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.81746 .30902 m
.81746 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.05556 .30902 m
.05556 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.34127 0 m
.34752 0 L
s
[(-3)] .32877 0 1 0 Mshowa
.34127 .10301 m
.34752 .10301 L
s
[(-2)] .32877 .10301 1 0 Mshowa
.34127 .20601 m
.34752 .20601 L
s
[(-1)] .32877 .20601 1 0 Mshowa
.34127 .41202 m
.34752 .41202 L
s
[(1)] .32877 .41202 1 0 Mshowa
.34127 .51503 m
.34752 .51503 L
s
[(2)] .32877 .51503 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(3)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .0206 m
.34502 .0206 L
s
.34127 .0412 m
.34502 .0412 L
s
.34127 .0618 m
.34502 .0618 L
s
.34127 .0824 m
.34502 .0824 L
s
.34127 .12361 m
.34502 .12361 L
s
.34127 .14421 m
.34502 .14421 L
s
.34127 .16481 m
.34502 .16481 L
s
.34127 .18541 m
.34502 .18541 L
s
.34127 .22661 m
.34502 .22661 L
s
.34127 .24721 m
.34502 .24721 L
s
.34127 .26781 m
.34502 .26781 L
s
.34127 .28842 m
.34502 .28842 L
s
.34127 .32962 m
.34502 .32962 L
s
.34127 .35022 m
.34502 .35022 L
s
.34127 .37082 m
.34502 .37082 L
s
.34127 .39142 m
.34502 .39142 L
s
.34127 .43262 m
.34502 .43262 L
s
.34127 .45322 m
.34502 .45322 L
s
.34127 .47383 m
.34502 .47383 L
s
.34127 .49443 m
.34502 .49443 L
s
.34127 .53563 m
.34502 .53563 L
s
.34127 .55623 m
.34502 .55623 L
s
.34127 .57683 m
.34502 .57683 L
s
.34127 .59743 m
.34502 .59743 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.34127 .64303 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.000 moveto
(D) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .2798 m
.06244 .34151 L
.08255 .37033 L
.0932 .38328 L
.10458 .39482 L
.11009 .39944 L
.11531 .40318 L
.12038 .40622 L
.12507 .40846 L
.12951 .4101 L
.13175 .41073 L
.13422 .41129 L
.13548 .41151 L
.13669 .41169 L
.13735 .41177 L
.13808 .41185 L
.13935 .41195 L
.14055 .412 L
.14184 .41202 L
.14305 .412 L
.14415 .41195 L
.14535 .41186 L
.14648 .41174 L
.14771 .41158 L
.14903 .41136 L
.15172 .41077 L
.15418 .41007 L
.15891 .40831 L
.1634 .40612 L
.17337 .39955 L
.18422 .38988 L
.20399 .36644 L
.225 .33554 L
.26275 .27524 L
.28372 .2455 L
.29291 .23448 L
.30295 .22421 L
.31272 .21625 L
.3218 .21082 L
.32683 .20867 L
.33139 .20726 L
.33392 .2067 L
.33535 .20646 L
.33666 .20628 L
.33782 .20616 L
.33908 .20607 L
.33973 .20604 L
.34041 .20602 L
.34164 .20586 L
.34295 .20537 L
Mistroke
.34414 .20498 L
.34544 .20459 L
.34685 .20424 L
.34818 .20397 L
.3494 .20379 L
.35057 .20365 L
.3518 .20357 L
.35291 .20355 L
.3541 .20357 L
.35521 .20365 L
.35623 .20377 L
.35743 .20396 L
.35873 .20423 L
.36109 .20491 L
.3636 .20591 L
.36636 .20735 L
.37195 .21137 L
.37713 .21649 L
.38198 .22253 L
.39184 .23854 L
.4022 .2606 L
.42072 .31086 L
.44073 .37193 L
.44944 .39675 L
.45888 .41975 L
.46415 .43009 L
.469 .43766 L
.47139 .44062 L
.47363 .4429 L
.47597 .44475 L
.4772 .4455 L
.47853 .44613 L
.47921 .44637 L
.47993 .44658 L
.48122 .44681 L
.48194 .44686 L
.48262 .44686 L
.48336 .44679 L
.48416 .44665 L
.4848 .44649 L
.48551 .44625 L
.48694 .4456 L
.48826 .44479 L
.48949 .44385 L
.49202 .44136 L
.49433 .43844 L
.49949 .42964 L
.50433 .41862 L
.50946 .40418 L
.51866 .3719 L
Mistroke
.53944 .28006 L
.54958 .23464 L
.55922 .19746 L
.5634 .18427 L
.56787 .17272 L
.57043 .16738 L
.57276 .16342 L
.5751 .16034 L
.57624 .15917 L
.5773 .15829 L
.57843 .15756 L
.57966 .15702 L
.58087 .15676 L
.58216 .15677 L
.58336 .15706 L
.5845 .15757 L
.58552 .15823 L
.58663 .15917 L
.58918 .16218 L
.59188 .16668 L
.59672 .17804 L
.60185 .19444 L
.60665 .21356 L
.61761 .26789 L
.6361 .37336 L
.64116 .39996 L
.64657 .42507 L
.65125 .44314 L
.65631 .4581 L
.65913 .46408 L
.66036 .46614 L
.66172 .468 L
.663 .46935 L
.6642 .47027 L
.66547 .47085 L
.66618 .47101 L
.66682 .47105 L
.66804 .47083 L
.66917 .47031 L
.67041 .46937 L
.67172 .46795 L
.67298 .46619 L
.67416 .46418 L
.67637 .45952 L
.68166 .44363 L
.68652 .42358 L
.69747 .36288 L
.70737 .29727 L
.71795 .22785 L
.72309 .19841 L
Mistroke
.72794 .17491 L
.7323 .15833 L
.73476 .15112 L
.73703 .14594 L
.73815 .14393 L
.73922 .14236 L
.74045 .14098 L
.74157 .14011 L
.74262 .13964 L
.7436 .13951 L
.74467 .13971 L
.74582 .14032 L
.74707 .14145 L
.74778 .1423 L
.74843 .14322 L
.75089 .14788 L
.75313 .15372 L
.7555 .16148 L
.76032 .18215 L
.76483 .2067 L
.77508 .27643 L
.78411 .34504 L
.79371 .41266 L
.79871 .44155 L
.80137 .45434 L
.80423 .46585 L
.80685 .47411 L
.808 .477 L
.80926 .47965 L
.81045 .48166 L
.81155 .48307 L
.81272 .48407 L
.81397 .4846 L
.81467 .48464 L
.8154 .48449 L
.81672 .48373 L
.81745 .48303 L
.81813 .48219 L
.81969 .47965 L
.82105 .4767 L
.8223 .47342 L
.8251 .46406 L
.83028 .43983 L
.8352 .40956 L
.85532 .24863 L
.86493 .17984 L
.86769 .16431 L
.8703 .15194 L
.87266 .14279 L
.87395 .13869 L
Mistroke
.87516 .13545 L
.87631 .1329 L
.87736 .13105 L
.87852 .12952 L
.87977 .12852 L
.88081 .12819 L
.88194 .12835 L
.88301 .12901 L
.884 .13005 L
.88514 .13177 L
.8862 .13387 L
.88864 .14045 L
.891 .14918 L
.89356 .16101 L
.89853 .19069 L
.90315 .22489 L
.91363 .31653 L
.92449 .4106 L
.92982 .44797 L
.93216 .46143 L
.93474 .47382 L
.93721 .48312 L
.93839 .48663 L
.93952 .48937 L
.94079 .49177 L
.94195 .4933 L
.94321 .49422 L
.94392 .4944 L
.94457 .49436 L
.94584 .49368 L
.94702 .49235 L
.94833 .4901 L
.94973 .48677 L
.9526 .47712 L
.95522 .46503 L
.95954 .43896 L
.96428 .40285 L
.97382 .31471 L
.97619 .29154 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0.75, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00K?ooool01OnHV9So410@o`000?lb<S;oc<c<0?Oo
oooo001/ooooo`05oa0@4?nj^[[oooooogMgMolb<S80moooool006Cooooo1_l00006ooooo`03o`00
0?oooooooooo0?Gooooo001_ooooo`03ojVYZOl@413ooooo00Gooooo0ol0003^ooooo`00K_ooool0
0ol@413o0000okZj^P06ooooo`03o`000?oooooooooo0>kooooo001_ooooo`03okZj^_lQ8B7ooooo
00Gooooo00?o0000ooooooooool0k_ooool006cooooo00Go410@oiRHV?oooooo^[Zjo`000006oooo
o`03o`000?oooooooooo0>kooooo001/ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0
003oooooooooo`3^ooooo`00Moooool00ol0003oooooooooo`3^ooooo`00Moooool2o`000>oooooo
001gooooo`03o`000?oooooooooo0>kooooo001gooooo`03o`000?oooooooooo0>kooooo001goooo
o`03o`000?oooooooooo0>kooooo001gooooo`03o`000?oooooooooo0>kooooo001gooooo`03o`00
0?oooooooooo0>kooooo001gooooo`03o`000?oooooooooo0>kooooo001gooooo`;o0000koooool0
07Oooooo00?o0000ooooooooool0k_ooool007Oooooo00?o0000ooooooooool0k_ooool007Oooooo
00?o0000ooooooooool0k_ooool007Oooooo00?o0000ooooooooool0k_ooool007Oooooo00?o0000
ooooooooool0k_ooool007Oooooo0_l0003_ooooo`00Moooool00ol0003oooooooooo`3^ooooo`00
Moooool00ol0003oooooooooo`3^ooooo`00Moooool00ol0003oooooooooo`3^ooooo`00Moooool0
0ol0003oooooooooo`3^ooooo`00Moooool00ol0003oooooooooo`3^ooooo`00Moooool2o`000>oo
oooo001gooooo`03o`000?oooooooooo0>kooooo001gooooo`03o`000?oooooooooo0>kooooo001g
ooooo`03o`000?oooooooooo0>kooooo001/ooooo`Go00001_ooool00ol0003oooooooooo`3^oooo
o`00K?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0k_ooool006Co
oooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0k_ooool006kooooo
00?oV9RHob4Q8Oo^k^h01_ooool3o`000>kooooo001_ooooo`03ogMgMomVIVKooooo00Gooooo00?o
0000ooooooooool0k_ooool0073ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3^
ooooo`00K?ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0k_ooool0
06cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0>kooooo001goooo
o`03o`000?oooooooooo0>kooooo001gooooo`;o0000koooool007Oooooo00?o0000ooooooooool0
k_ooool007Oooooo00?o0000ooooooooool0YOooool3o`0004Kooooo001gooooo`03o`000?oooooo
oooo0:Cooooo0_l000000ooooooo0000ooooo`15ooooo`00Moooool00ol0003oooooooooo`2Toooo
o`04o`000?ooooooooooo`0004Kooooo001gooooo`03o`000?oooooooooo07[ooooo0_l0000Xoooo
o`04o`000?ooooooooooo`0004Kooooo001gooooo`03o`000?oooooooooo07[ooooo00?o0000oooo
ool000009_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo04?ooooo001gooooo`;o
0000N_ooool01?l0003oooooooooool0000Vooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool0@oooool007Oooooo00?o0000ooooooooool0NOooool01Ol0003ooooooooooooooooo0000
02Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`12ooooo`00Moooool00ol0003o
ooooooooo`1hooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool08_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo04;ooooo001gooooo`03o`000?oooooooooo07Sooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0@_ooool007Oooooo00?o0000ooooooooool0Aoooool4o`0002cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0@Oooool007Oooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0@Oooool007Oooooo0_l00017oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo023ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`11oooo
o`00Moooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`11ooooo`00Moooool00ol0003oooooooooo`15ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo023ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`11ooooo`00Mooo
ool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`11ooooo`00Moooool00ol0003oooooooooo`14ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`10ooooo`00Moooool00ol0
003oooooooooo`13ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`10ooooo`00Moooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`10ooooo`00Moooool2o`0004Cooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool07_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo043ooooo
001gooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo043ooooo001gooooo`03o`000?oooooooooo04;ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo043ooooo001goooo
o`03o`000?oooooooooo047ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Roooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo043ooooo001]ooooo`Co000000?o410@ooooooooool00oooool00ol0003o
ooooooooo`11ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool08_ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`10ooooo`00Koooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000?o0000
?_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
?oooool006Cooooo1_l00005ooooo`03o`000?oooooooooo00;ooooo1_l00003ooooo`?o0000>_oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0?ooo
ool006oooooo00?o0000ooooooooool00_l00003ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool0=oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0?oooool006oooooo0ol00005ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0=_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool0?oooool006kooooo0_l00007ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool0=Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool0?oooool006gooooo00?o0000ooooool000001oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo03?ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Pooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo03kooooo001/ooooo`04o`000?mEEEGoIVIVo`0000Oooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
7oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0nooooo`00Joooool00ol0003oooooooooo`09ooooo`;o00002ooo
ool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0nooooo`00J_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool0?_ooool006Wooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo03kooooo001Xooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0nooooo`00Ioooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0;_ooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0?_ooool006Kooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02kooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03kooooo001U
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0/
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0m
ooooo`00IOooool00ol0003oooooooooo`0?ooooo`;o00003oooool00ol0003oooooooooo`0/oooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0moooo
o`00I?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0:oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool0?Oooool006?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo02_ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo03gooooo001Sooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0mooooo`00H_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool0?Oooool006;ooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo03gooooo000[ooooo`;o000000?o410@oooooooo
ool08Oooool5o`0000_ooooo00?o0000ooooooooool04oooool2o`0001;ooooo00?o0000oooooooo
ool03_ooool5o`0001Gooooo00?o0000ooooooooool03Oooool2o`000003oa0@4?oooooooooo00?o
oooo00?o0000ooooooooool06_ooool01Ol0003o<S8bo`000?l@413oc<c<00oooooo00?o0000oooo
ooooool04Oooool01Oo<c<co8B4Qo`000?lQ8B7o0000013ooooo00?o0000ooooooooool03Oooool4
o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hTooooo`00;?ooool00ol0003ooooo
ooooo`0Rooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@02_ooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool03_ooool01OnHV9So8B4Qonk^k_ooooooA4A4
01Gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
01[ooooo00Go0000ogMgMoooooooV9RHob4Q8@0?ooooo`03o`000?oooooooooo017ooooo00Go8B4Q
oiRHV?ooooooV9RHo`00000@ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg02Cooooo000Qooooo`Ko00000_ooool5o`0001_ooooo1_l0
0003ooooo`03oiRHV?lQ8B7ok^k^00_ooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo00oooooo00?oV9RHob4Q8Oo^k^h05_ooool00ol0003ooooooooo
o`0;ooooo`Go00001Oooool00ol0003oooooooooo`0Jooooo`05o`000?ooooooooooooooool00000
3oooool00ol0003oooooooooo`0Aooooo`05o`000?ooooooooooooooool000004Oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@400Toooo
o`00:Oooool01?m4A4CogMgMooooool0000Vooooo`03oiRHV?lQ8B7ok^k^00Wooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00oooooo00?oV9RHob4Q
8Oo^k^h05?ooool00ol0003oooooooooo`0<ooooo`04odA4A?oMgMgoooooo`0000Kooooo00?o0000
ooooooooool06_ooool01Ol0003oV9RHoooooonHV9So8B4Q00oooooo00?o0000ooooooooool04Ooo
ool01Olb<S;oV9RHoooooonHV9So0000017ooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000009?ooool001Cooooo00?o0000ooooooooool0
4_ooool01?oMgMgoEEEEooooool0000Wooooo`03ogMgMomVIVKooooo00Sooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo013ooooo00?oMgMgofIVI_oo
ool04oooool00ol0003oooooooooo`0<ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000oooo
ooooool06Oooool01Ol0003oEEEEo`000?l@413oc<c<00oooooo00?o0000ooooooooool04Oooool0
0oo<c<co0000o`000002o`00017ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000009?ooool001Cooooo00?o0000ooooooooool04oooool0
0omgMgOoc<c<o`00000Xooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`0=ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool06Oooool0
0ol0003oQhN7ooooo`0Aooooo`03o`000?oooooooooo017ooooo00Go410@okZj^_oooooo^[Zjo`00
000Aooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooo
oooooooo410@02Cooooo000Eooooo`03o`000?oooooooooo01;ooooo00?ok^k^odA4A?l000009?oo
ool01Ol0003o^[ZjoooooonHV9So410@00Oooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo00cooooo00Go0000okZj^_ooooooV9RHoa0@400Dooooo`03
o`000?oooooooooo00gooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`0Iooooo`03
o`000?l@413oV9RH017ooooo00?o0000ooooooooool04Oooool00ol0003o^[Zjooooo`02o`00017o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL09?ooool001Kooooo00?o0000ooooooooool04_ooool00omgMgOo0000ooooo`0Sooooo`05
oiRHV?l@413o0000ob4Q8Oo<c<`01oooool00ol0003oooooooooo`0Gooooo`;o00005?ooool00ol0
003oooooooooo`0<ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`04oooool00ol0003oooooooooo`0?
ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool06?ooool01_l0003oooooolc<c?m4
A4Co0000oa0@413ooooo00?o0000ooooooooool04?ooool01OnYZJWo410@o`000?l0003oZJVY017o
oooo00?o0000ooooooooool03?ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h09?ooool001Kooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Wooooo`00
5oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
5?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02Oooooo000Gooooo`03o`000?oo
oooooooo047ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo02?ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool03oooool2o`0000;ooooo0_l0000Booooo`006?ooool0
0ol0003oooooooooo`0oooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo00oooooo00Kok^k^ob4Q8On7QhOo^[Zjo`00
0?oMgMdBooooo`006Oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00Co
gMgMo`000?l@413oc<c<4oooool000goooooool0000jo`0000_ooooo00Cok^k^ob4Q8Ol@413ok^k^
4oooool001Cooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Wooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo000000Sooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo
0_l00009ooooo`03o`000?oooooooooo00Kooooo0_l00009ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`;o00004_ooool01?lQ8B7oMgMg
ogMgMolb<S8Cooooo`006oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`;o00004oooool00ol0003ooooo
ooooo`0@ooooo`;o00004Oooool2o`0000;ooooo0_l0000Booooo`006oooool00ol0003ooooooooo
o`0iooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo02Sooooo000Looooo`03o`000?oooooooooo03Oooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool0:?ooool001gooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Xoooo
o`007Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo02Sooooo000Nooooo`03o`00
0?oooooooooo03Cooooo00?o0000ooooooooool07oooool2o`0001Wooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
4?ooool00ol0003oooooooooo`0Xooooo`007_ooool00ol0003oooooooooo`0cooooo`03o`000?oo
oooooooo023ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo02Wooooo000Oooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool08Oooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0:Oooool0
023ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Yooooo`008?ooool00ol0003o
ooooooooo`0_ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo02Wooooo000Qooooo`03o`000?oooooooooo02gooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool0:Oooool002;ooooo00?o0000ooooooooool0:oooool00ol0003ooooooooo
o`0Tooooo`;o00006oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01kooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02Wooooo000S
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0:Oooool002Cooooo00?o0000oooo
ooooool0:?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0Yooooo`009?ooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo02Wooooo000Uooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
9oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
7oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
:_ooool002Kooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Zooooo`009oooool0
0ol0003oooooooooo`0Rooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02[ooooo000Wooooo`03o`000?oooooooooo
027ooooo00?o0000ooooooooool0:Oooool2o`0001gooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`0Qooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0Zooooo`00:?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02[o
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02[o
oooo000Yooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0:oooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool08Oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0:_ooool002[ooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0Zooooo`00:_ooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo02[ooooo000[ooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool0;_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool0:_ooool002cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0_ooooo`;o
00007oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02Cooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02_ooooo000]ooooo`;o0000
5Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0[ooooo`00;oooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo037ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo02_ooooo000`ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0<_ooool0
0ol0003oooooooooo`0Oooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0:oooool0
037ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Yooooo`Co000000?o410@oooo
ooooool00oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool09_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool0:oooool003;ooooo0ol00009ooooo`?o0000;_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0[ooooo`00
=Oooool9o`00037ooooo00?o0000ooooooooool01Oooool3o`00027ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0[ooooo`00Koooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0[ooooo`00Koooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0/ooooo`00Koooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0/ooooo`00Koooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0Zooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0/ooooo`00KOooool00omEEEGoIVIVo`000007ooooo`03o`000?oooooooooo02?ooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0/ooooo`00Moooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0:oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0;?ooool007Oooooo0_l0000U
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0;Oooool007Oooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02gooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02gooooo001gooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0^ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0]ooooo`00
Moooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
;oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
;Oooool007Oooooo00?o0000ooooooooool09oooool5o`0003;ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02gooooo001gooooo`03o`000?oooooo
oooo05oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo02gooooo001gooooo`;o0000H?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
02?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0;Oooool007Oooooo00?o0000ooooooooool0Goooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0;_ooool007Oooooo
00?o0000ooooooooool0H?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0;_ooool007Oooooo00?o0000ooooooooool0H?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0;_ooool007Oooooo00?o0000
ooooooooool0HOooool01Ol0003ooooooooooooooooo000002Sooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0;_oo
ool007Oooooo00?o0000ooooooooool0HOooool2o`000003ooooool0003ooooo02Sooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool0;_ooool007Oooooo00?o0000ooooooooool0H_ooool3o`0002[ooooo00Go0000oooo
ooooooooooooo`00000Sooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0;_ooool0
07Oooooo0_l0002@ooooo`05o`000?ooooooooooooooool000008oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo02oooooo001gooooo`03o`000?oooooooooo08oooooo00Go0000oooo
ooooooooooooo`00000Sooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0;oooool0
07Oooooo00?o0000ooooooooool0T?ooool00ol0003oooooo`00000Tooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0;oooool007Oooooo00?o0000ooooooooool0T?ooool3o`0002Co
oooo00Go0000ooooooooooooooooo`00000booooo`00Moooool00ol0003oooooooooo`2hooooo`04
o`000?ooooooooooo`0003;ooooo001gooooo`03o`000?oooooooooo0;Sooooo00Co0000ooooool0
003o0000<_ooool007Oooooo0_l0002jooooo`;o0000<oooool007Oooooo00?o0000ooooooooool0
k_ooool007Oooooo00?o0000ooooooooool0k_ooool007Oooooo00?o0000ooooooooool0k_ooool0
06cooooo1Ol00006ooooo`03o`000?oooooooooo0>kooooo001/ooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@01_ooool00ol0003oooooooooo`3^ooooo`00KOooool00onHV9So8B4Qonk^kP07ooooo`03
o`000?oooooooooo0>kooooo001^ooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol0003^ooooo`00Kooo
ool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo0>kooooo001`ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool0k_ooool006cooooo00Go0000okZj^_ooooooV9RHoa0@4006
ooooo`03o`000?oooooooooo0>kooooo001/ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool0
0ol0003oooooooooo`3^ooooo`00Moooool00ol0003oooooooooo`3^ooooo`00Moooool2o`000>oo
oooo001gooooo`03o`000?oooooooooo0>kooooo001gooooo`03o`000?oooooooooo0>kooooo001g
ooooo`03o`000?oooooooooo0>kooooo001gooooo`03o`000?oooooooooo0>kooooo001gooooo`03
o`000?oooooooooo0>kooooo001gooooo`;o0000koooool007Oooooo00?o0000ooooooooool0k_oo
ool007Oooooo00?o0000ooooooooool0k_ooool007Oooooo00?o0000ooooooooool0k_ooool007Oo
oooo00?o0000ooooooooool0k_ooool007Oooooo00?o0000ooooooooool0k_ooool007Oooooo00?o
0000ooooooooool0k_ooool007Oooooo0_l0003_ooooo`00Moooool00ol0003oooooooooo`3^oooo
o`00Moooool00ol0003oooooooooo`3^ooooo`00Moooool00ol0003oooooooooo`3^ooooo`00Mooo
ool00ol0003oooooooooo`3^ooooo`00Moooool00ol0003oooooooooo`3^ooooo`00Moooool2o`00
0>oooooo001gooooo`03o`000?oooooooooo0>kooooo001gooooo`03o`000?oooooooooo0>kooooo
001gooooo`03o`000?oooooooooo0>kooooo001/ooooo`05oiRHV?l@413o0000oc8b<_o<c<`01_oo
ool00ol0003oooooooooo`3^ooooo`00K?ooool01Ol@413o^[ZjoooooomgMgOo<S8b00Kooooo00?o
0000ooooooooool0k_ooool0073ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3^
ooooo`00Koooool00onYZJWo410@ooooo`05ooooo`?o0000k_ooool006kooooo00?o410@o`000?nj
^[X0moooool006oooooo00?o^[Zjob4Q8Oooool0m_ooool006cooooo00Go410@oiRHV?oooooo^[Zj
o`00003gooooo`00K?ooool01OnYZJWo410@o`000?l@413oZJVY0?Oooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo001Uooooo`;o00002ooo
ool00ol0003o^[Zjooooo`0<ooooo`03o`000?nj^[[ooooo00cooooo0_l0003Fooooo`00IOooool0
0ol0003oooooooooo`0:ooooo`;o<S8b3Oooool2oc8b<Pkooooo00?o0000ooooooooool0e?ooool0
05[ooooo1Ol00006ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000?ooooo00?oQhN7
o`000?nj^[X00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Cooooo00?oQhN7o`000?nj^[X01?oo
ool01OnHV9So0000o`000?m4A4Co^[Zj00Cooooo00?o0000ooooooooool0e?ooool005[ooooo0_mg
MgL2ooooo`03o`000?oooooooooo00Cooooo00[o0000ooooooooooooooooonk^k_lQ8B7oQhN7okZj
^_l0003ogMgM0oooool00oo<c<co0000oa0@4003ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01?oo
ool00oo<c<co0000oa0@4004ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41001?ooool00ol0003ooooo
ooooo`3Dooooo`00Foooool00omEEEGoV9RHooooo`07ooooo`03o`000?oooooooooo00;ooooo00Co
gMgMo`000?l@413oc<c<2_ooool01Ol@413ooooooooooooooooo410@00_ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`3Dooooo`00G?ooool00omEEEGoV9RHooooo`06ooooo`03o`00
0?oooooooooo00;ooooo00Cok^k^ob4Q8Ol@413ok^k^2_ooool01Ol0003ooooooooooooooooo0000
00_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3Dooooo`00F_ooool01Ol0003o
oooooooooolb<S;oQhN700Kooooo00?o0000ooooooooool00_ooool01?lQ8B7oMgMgogMgMolb<S8:
ooooo`05o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0=Cooooo001Jooooo`Go00001_ooool01?l0003oooooooooooooool2o`0000;ooooo0_l0
0009ooooo`05oa0@4?ooooooooooooooool@41002Oooool00ol@413o0000o`000003o`0000Gooooo
00?o0000ooooooooool0e?ooool006Gooooo00?o0000ooooooooool04?ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3Dooooo`00IOoo
ool2o`00017ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;ooooo`03o`000?oooooooooo00Gooooo
0_l0003Fooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-6.04357, -3.17494, \
0.0630624, 0.0388712}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.0634921 0.309017 0.103006 [
[.0873 .29652 -6 -9 ]
[.0873 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.46825 .29652 -3 -9 ]
[.46825 .29652 3 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.72222 .29652 -3 -9 ]
[.72222 .29652 3 0 ]
[.84921 .29652 -3 -9 ]
[.84921 .29652 3 0 ]
[.97619 .29652 -6 -9 ]
[.97619 .29652 6 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .10301 -12 -4.5 ]
[.32877 .10301 0 4.5 ]
[.32877 .20601 -12 -4.5 ]
[.32877 .20601 0 4.5 ]
[.32877 .41202 -6 -4.5 ]
[.32877 .41202 0 4.5 ]
[.32877 .51503 -6 -4.5 ]
[.32877 .51503 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.34127 .64303 -26 0 ]
[.34127 .64303 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.0873 .30902 m
.0873 .31527 L
s
[(-4)] .0873 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-2)] .21429 .29652 0 1 Mshowa
.46825 .30902 m
.46825 .31527 L
s
[(2)] .46825 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(4)] .59524 .29652 0 1 Mshowa
.72222 .30902 m
.72222 .31527 L
s
[(6)] .72222 .29652 0 1 Mshowa
.84921 .30902 m
.84921 .31527 L
s
[(8)] .84921 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(10)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.18254 .30902 m
.18254 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.65873 .30902 m
.65873 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.81746 .30902 m
.81746 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.05556 .30902 m
.05556 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.34127 0 m
.34752 0 L
s
[(-3)] .32877 0 1 0 Mshowa
.34127 .10301 m
.34752 .10301 L
s
[(-2)] .32877 .10301 1 0 Mshowa
.34127 .20601 m
.34752 .20601 L
s
[(-1)] .32877 .20601 1 0 Mshowa
.34127 .41202 m
.34752 .41202 L
s
[(1)] .32877 .41202 1 0 Mshowa
.34127 .51503 m
.34752 .51503 L
s
[(2)] .32877 .51503 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(3)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .0206 m
.34502 .0206 L
s
.34127 .0412 m
.34502 .0412 L
s
.34127 .0618 m
.34502 .0618 L
s
.34127 .0824 m
.34502 .0824 L
s
.34127 .12361 m
.34502 .12361 L
s
.34127 .14421 m
.34502 .14421 L
s
.34127 .16481 m
.34502 .16481 L
s
.34127 .18541 m
.34502 .18541 L
s
.34127 .22661 m
.34502 .22661 L
s
.34127 .24721 m
.34502 .24721 L
s
.34127 .26781 m
.34502 .26781 L
s
.34127 .28842 m
.34502 .28842 L
s
.34127 .32962 m
.34502 .32962 L
s
.34127 .35022 m
.34502 .35022 L
s
.34127 .37082 m
.34502 .37082 L
s
.34127 .39142 m
.34502 .39142 L
s
.34127 .43262 m
.34502 .43262 L
s
.34127 .45322 m
.34502 .45322 L
s
.34127 .47383 m
.34502 .47383 L
s
.34127 .49443 m
.34502 .49443 L
s
.34127 .53563 m
.34502 .53563 L
s
.34127 .55623 m
.34502 .55623 L
s
.34127 .57683 m
.34502 .57683 L
s
.34127 .59743 m
.34502 .59743 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.34127 .64303 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.000 moveto
(D) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .22732 m
.06244 .27785 L
.10458 .34494 L
.12507 .3737 L
.13506 .38546 L
.14415 .39453 L
.1536 .4021 L
.16254 .40737 L
.16744 .40944 L
.17197 .41082 L
.17434 .41133 L
.1757 .41156 L
.17694 .41173 L
.17825 .41187 L
.17897 .41193 L
.17966 .41197 L
.18088 .41201 L
.18157 .41202 L
.18221 .41202 L
.18349 .41198 L
.18414 .41195 L
.18485 .4119 L
.18611 .41177 L
.18728 .41162 L
.18993 .41116 L
.19278 .41046 L
.19798 .40865 L
.20273 .40642 L
.21229 .4003 L
.22134 .39259 L
.24125 .36994 L
.25967 .34364 L
.29893 .28098 L
.33668 .23027 L
.35603 .20834 L
.36133 .20325 L
.36691 .19883 L
.37168 .19595 L
.37438 .19473 L
.37689 .19388 L
.37816 .19357 L
.37886 .19343 L
.37951 .19332 L
.38067 .19317 L
.38194 .19309 L
.38264 .19309 L
.38332 .1931 L
.38458 .1932 L
.38528 .19329 L
.38593 .1934 L
Mistroke
.38741 .19373 L
.38871 .19412 L
.38994 .19458 L
.39222 .19566 L
.39468 .19718 L
.39734 .19923 L
.40206 .20394 L
.40703 .21043 L
.41593 .22597 L
.42544 .24788 L
.43561 .27666 L
.45396 .33747 L
.47381 .40218 L
.47924 .41691 L
.48501 .43016 L
.48994 .43914 L
.49259 .44297 L
.49537 .44617 L
.49784 .44829 L
.49924 .44917 L
.50055 .44978 L
.50175 .45016 L
.50284 .45034 L
.5041 .45037 L
.50529 .45022 L
.50658 .44985 L
.50724 .44958 L
.50795 .44922 L
.51041 .44748 L
.5118 .44615 L
.51328 .44445 L
.51596 .44064 L
.52114 .43065 L
.52606 .41806 L
.53527 .387 L
.55346 .30538 L
.56383 .25506 L
.57356 .21198 L
.57819 .19449 L
.58307 .17892 L
.58562 .17212 L
.58841 .16585 L
.59093 .16131 L
.59332 .15805 L
.59464 .1567 L
.59533 .15611 L
.59607 .15559 L
.59737 .15492 L
.59857 .15459 L
.59924 .15453 L
Mistroke
.59995 .15456 L
.60124 .15486 L
.60203 .15521 L
.60278 .15565 L
.60419 .15679 L
.60541 .15808 L
.6067 .15978 L
.60903 .16367 L
.6118 .16967 L
.61431 .17637 L
.62435 .21411 L
.63358 .26139 L
.6544 .3836 L
.6635 .42872 L
.66859 .44828 L
.67324 .4615 L
.67587 .46682 L
.67736 .46909 L
.67873 .47071 L
.67993 .47173 L
.68061 .47215 L
.68125 .47243 L
.68254 .47268 L
.68327 .47263 L
.68393 .47247 L
.68513 .47188 L
.68625 .471 L
.68748 .46965 L
.68879 .46777 L
.69147 .46256 L
.69391 .45624 L
.69876 .43934 L
.7039 .41573 L
.71311 .3617 L
.72314 .2932 L
.73391 .22137 L
.73916 .19142 L
.74415 .16808 L
.74862 .15233 L
.75115 .14589 L
.7535 .14162 L
.75465 .14013 L
.7559 .139 L
.75708 .13838 L
.75816 .1382 L
.75914 .13836 L
.76021 .13889 L
.76133 .13983 L
.76237 .14108 L
.7636 .143 L
Mistroke
.76476 .14525 L
.76694 .15061 L
.76928 .15801 L
.77182 .16789 L
.78125 .21932 L
.79165 .29475 L
.80262 .37901 L
.80743 .4122 L
.81267 .44309 L
.81517 .45529 L
.81783 .46625 L
.82034 .47448 L
.82262 .48007 L
.82383 .48229 L
.82495 .48386 L
.82618 .48504 L
.82748 .48567 L
.82861 .4857 L
.82967 .48529 L
.83083 .48435 L
.83207 .48277 L
.83347 .4803 L
.83476 .47737 L
.83768 .46846 L
.84025 .45809 L
.84299 .44463 L
.85295 .37807 L
.86253 .29832 L
.87263 .21569 L
.8768 .18654 L
.88125 .16071 L
.88381 .14884 L
.88614 .14016 L
.88726 .13673 L
.88848 .1336 L
.88954 .13135 L
.89069 .12948 L
.89189 .12811 L
.89301 .1274 L
.8937 .12723 L
.89435 .12726 L
.89557 .12783 L
.89686 .12913 L
.89805 .13098 L
.89935 .13372 L
.90075 .13744 L
.90325 .1462 L
.90561 .15677 L
.91002 .18209 L
.92005 .26064 L
Mistroke
.93088 .3597 L
.9404 .43672 L
.94301 .4535 L
.9458 .4687 L
.94844 .48011 L
.95084 .48784 L
.95215 .49092 L
.95287 .49227 L
.95354 .49331 L
.95473 .4946 L
.95603 .49523 L
.95672 .49522 L
.95745 .49496 L
.95875 .49384 L
.95947 .49286 L
.96015 .49171 L
.96167 .48829 L
.96301 .48436 L
.96427 .47989 L
.96663 .46955 L
.97192 .43775 L
.97619 .40466 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0.75, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00K?ooool01OnHV9So410@o`000?lb<S;oc<c<0?Oo
oooo001/ooooo`05oa0@4?nj^[[oooooogMgMolb<S80moooool006Cooooo1_l00006ooooo`03o`00
0?oooooooooo0?Gooooo001_ooooo`03ojVYZOl@413ooooo00Gooooo0ol0003^ooooo`00K_ooool0
0ol@413o0000okZj^P06ooooo`03o`000?oooooooooo0>kooooo001_ooooo`03okZj^_lQ8B7ooooo
00Gooooo00?o0000ooooooooool0k_ooool006cooooo00Go410@oiRHV?oooooo^[Zjo`000006oooo
o`03o`000?oooooooooo0>kooooo001/ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0
003oooooooooo`3^ooooo`00Moooool00ol0003oooooooooo`3^ooooo`00Moooool2o`000>oooooo
001gooooo`03o`000?oooooooooo0>kooooo001gooooo`03o`000?oooooooooo0>kooooo001goooo
o`03o`000?oooooooooo0>kooooo001gooooo`03o`000?oooooooooo0>kooooo001gooooo`03o`00
0?oooooooooo0>kooooo001gooooo`03o`000?oooooooooo0>kooooo001gooooo`;o0000koooool0
07Oooooo00?o0000ooooooooool0k_ooool007Oooooo00?o0000ooooooooool0k_ooool007Oooooo
00?o0000ooooooooool0k_ooool007Oooooo00?o0000ooooooooool0k_ooool007Oooooo00?o0000
ooooooooool0k_ooool007Oooooo0_l0003_ooooo`00Moooool00ol0003oooooooooo`3^ooooo`00
Moooool00ol0003oooooooooo`3^ooooo`00Moooool00ol0003oooooooooo`3^ooooo`00Moooool0
0ol0003oooooooooo`3^ooooo`00Moooool00ol0003oooooooooo`3^ooooo`00Moooool2o`000>oo
oooo001gooooo`03o`000?oooooooooo0>kooooo001gooooo`03o`000?oooooooooo0>kooooo001g
ooooo`03o`000?oooooooooo0>kooooo001/ooooo`Go00001_ooool00ol0003oooooooooo`3^oooo
o`00K?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0k_ooool006Co
oooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0k_ooool006kooooo
00?oV9RHob4Q8Oo^k^h01_ooool3o`000>kooooo001_ooooo`03ogMgMomVIVKooooo00Gooooo00?o
0000ooooooooool0k_ooool0073ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3^
ooooo`00K?ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0k_ooool0
06cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0>kooooo001goooo
o`03o`000?oooooooooo0>kooooo001gooooo`;o0000koooool007Oooooo00?o0000ooooooooool0
Z_ooool00ol0003oooooooooo`11ooooo`00Moooool00ol0003oooooooooo`2Yooooo`?o0000@_oo
ool007Oooooo00?o0000ooooooooool0Z?ooool00ol0003oooooooooo`02o`00047ooooo001goooo
o`03o`000?oooooooooo0:Sooooo00Go0000ooooooooooooooooo`000011ooooo`00Moooool00ol0
003oooooooooo`1nooooo`?o00009oooool01Ol0003ooooooooooooooooo0000047ooooo001goooo
o`03o`000?oooooooooo07kooooo00Co0000oooooooooooo00009Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo03oooooo001gooooo`;o0000O_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo02;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0noooo
o`00Moooool00ol0003oooooooooo`1mooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool08_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03kooooo001gooooo`03o`00
0?oooooooooo07cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Rooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0?_ooool007Oooooo00?o0000ooooooooool0COoo
ool3o`0002cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Rooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool0?_ooool007Oooooo00?o0000ooooooooool0C?ooool0
0ol0003oooooooooo`02o`0002_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0?_ooool007Oooooo00?o0000oooo
ooooool0Boooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0?_ooool007Oooooo0_l0001<ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0nooooo`00Moooool00ol0003oooooooooo`1:ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0mooooo`00Mooo
ool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0mooooo`00Moooool00ol0003oooooooooo`1:ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0mooooo`00Moooool00ol0
003oooooooooo`19ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0mooooo`00Moooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0looooo`00Moooool00ol0003ooooo
ooooo`19ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0looooo`00Moooool2o`0004Wooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0Sooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo03cooooo001gooooo`03o`000?oooooooooo04Sooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03cooooo001goooo
o`03o`000?oooooooooo00Sooooo1Ol0000jooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0looooo`00Moooool00ol0003oooooooooo`06ooooo`?o
00001?ooool2o`0003Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo03cooooo001]ooooo`Co000000?o410@ooooooooool00oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0=Oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0>oooool006oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool0=?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo027ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool0>oooool006Cooooo1_l00005ooooo`03o`000?oooooooooo00Gooooo0ol00003
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0>oooool006oooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool0<Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool0>oooool006oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool0>oooool006oooooo00?o0000ooooooooool0
1Oooool01Ol0003ooooooooooooooooo0000017ooooo00?o0000ooooooooool0<?ooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0>oooool006oooooo
00?o0000ooooooooool01Oooool01?l0003oooooooooool0000Cooooo`03o`000?oooooooooo02oo
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03_o
oooo001]ooooo`03oeEEEOmVIVKo000000Oooooo00?o0000ooooool000005?ooool00ol0003ooooo
ooooo`0^ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0kooooo`00Moooool2o`0001Kooooo00?o0000ooooooooool0;Oooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0>_ooool001Cooooo00?o0000
ooooooooool0H?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo02gooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03[ooooo000Doooo
o`03o`000?oooooooooo05oooooo0_l0000Hooooo`03o`000?oooooooooo02cooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03[ooooo000Eooooo`03
o`000?oooooooooo05kooooo0_l0000Hooooo`03o`000?oooooooooo02_ooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03[ooooo000Fooooo`03o`00
0?oooooooooo05cooooo00?o0000ooooool000006Oooool00ol0003oooooooooo`0Zooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0jooooo`005ooo
ool00ol0003oooooooooo`1Jooooo`04o`000?ooooooooooo`0001Wooooo00?o0000ooooooooool0
:_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
>_ooool001Sooooo00?o0000ooooooooool0F?ooool01Ol0003ooooooooooooooooo000001Wooooo
00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool0>_ooool001Sooooo00?o0000ooooooooool0Eoooool00ol0003ooooooooo
o`02ooooo`;o00006Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0jooooo`006Oooool00ol0003oooooooooo`1F
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0i
ooooo`006_ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0iooooo`006oooool00ol0003oooooooooo`1Booooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0iooooo`00
7?ooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0iooooo`007?ooool00ol0003oooooooooo`1?ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0iooooo`007Oooool0
0ol0003oooooooooo`0;ooooo`;o000000?o410@ooooooooool08Oooool5o`0001Sooooo00?o0000
ooooooooool01_ooool2o`0001_ooooo00?o0000ooooooooool01Oooool5o`0001_ooooo00?o0000
ooooooooool01oooool2o`000003oa0@4?oooooooooo00Sooooo00?o0000ooooooooool05Oooool0
1_o^k^ko<S8bo`000?l@413oc<c<o`0001;ooooo00?o0000ooooooooool03Oooool01Oo<c<co8B4Q
o`000?lQ8B7oc<c<00?ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`09ooooo`Co
000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kRCooooo000Nooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool08_ooool01OnHV9So8B4Qonk^k_ooooooA4A401Oooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Gooooo00Go
V9RHob4Q8Oo^k^koooooodA4A00Kooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0Eooooo`06oeEEEOmgMgOooooooiRHV?lQ8B7o00004_ooool00ol0
003oooooooooo`0=ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B400oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonH
V9SoMgMg02Cooooo000Oooooo`03o`000?oooooo000000Go00000_ooool5o`0001_ooooo1_l00003
ooooo`03oiRHV?lQ8B7ok^k^01Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo00Gooooo00?oV9RHob4Q8Oo^k^h07?ooool00ol0003oooooooooo`05
ooooo`Go00002oooool00ol0003oooooooooo`0Dooooo`04o`000?ooooooooooooooo`;o00004_oo
ool00ol0003oooooooooo`0=ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00_ooool01Ol@413ooooo
oooooooooooo410@02Cooooo000Pooooo`03o`000?oooooooooo00Kooooo00CoA4A4omgMgOoooooo
00009_ooool00onHV9So8B4Qonk^kP0Eooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`06ooooo`03oiRHV?lQ8B7ok^k^01_ooooo00?o0000oooooooo
ool01Oooool01?m4A4CogMgMooooool0000<ooooo`03o`000?oooooooooo01Cooooo00Ko0000oiRH
V?ooooooV9RHob4Q8Ol0000Booooo`03o`000?oooooooooo00gooooo00Go<S8boiRHV?ooooooV9RH
oc8b<P03ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000009?ooool0023ooooo00?o0000ooooooooool0
1_ooool01?oMgMgoEEEEooooool0000Wooooo`03ogMgMomVIVKooooo01?ooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Oooooo00?oMgMgofIVI_oo
ool06_ooool00ol0003oooooooooo`05ooooo`04omgMgOmEEEGoooooo`0000cooooo00?o0000oooo
ooooool05?ooool01_l0003oEEEEo`000?l@413oc<c<o`0001;ooooo00?o0000ooooooooool03Ooo
ool01Oo<c<co0000o`000?l0003oc<c<00?ooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Tooooo`00
8Oooool00ol0003oooooooooo`06ooooo`03ogMgMoo<c<co000002Sooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00Oooooo00?oMgMgolc<c?l00000
3?ooool00ol0003oooooooooo`0Dooooo`05oeEEEOn7QhOoooooooooool000004oooool00ol0003o
ooooooooo`0=ooooo`05oa0@4?nj^[[ooooookZj^_l@41000oooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo
410@02Cooooo000Rooooo`03o`000?oooooooooo00Gooooo00?ok^k^odA4A?l000009?ooool01Ol0
003o^[ZjoooooonHV9So410@01?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo00?ooooo00Go0000okZj^_ooooooV9RHoa0@400Jooooo`03o`000?oo
oooooooo00Oooooo00?ok^k^odA4A?l000003?ooool00ol0003oooooooooo`0Dooooo`05omgMgOl@
413oV9RHooooool000005?ooool00ol0003oooooooooo`0<ooooo`05o`000?nj^[[ooooookZj^_l0
00000oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02Cooooo000Rooooo`03o`000?oooooooooo00Ko
oooo00?oMgMgo`000?ooool08oooool01OnHV9So410@o`000?lQ8B7oc<c<01;ooooo00?o0000oooo
ooooool03?ooool2o`0001gooooo00?o0000ooooooooool00oooool01OnHV9So410@o`000?lQ8B7o
c<c<01[ooooo00?o0000ooooooooool02?ooool00omgMgOo0000ooooo`0;ooooo`03o`000?oooooo
oooo01Gooooo00Coc<c<odA4A?l0003o00005?ooool00ol0003oooooooooo`0<ooooo`05ojVYZOl@
413o0000oa0@4?nYZJT00_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Sooooo
00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Cooooo000Sooooo`03o`00
0?oooooooooo04;ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Looooo`03o`00
0?oooooooooo02;ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo03Sooooo000Sooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03Sooooo000Tooooo`03o`000?oooooo
oooo043ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo023ooooo0_l00002ooooo`;o00004_ooool002Gooooo00?o0000ooooooooool0?_ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool08?ooool01_o^
k^ko8B4QohN7Qonj^[[o0000omgMgA;ooooo000Uooooo`03o`000?oooooooooo03gooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo027ooooo00CogMgM
o`000?l@413oc<c<4oooool000goooooool0000jo`0000_ooooo00Cok^k^ob4Q8Ol@413ok^k^4ooo
ool001Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`;o00002Oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo0_l00008ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool01?ooool01?l0003oooooooooool00009ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Oooooo00Co0000oooooooooooo00001_ooool00ol0003oooooooooo`07ooooo`05
o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`07ooooo`05o`000?oooooooooo
ooooool000001Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo013ooooo00Co8B4Q
ogMgMomgMgOo<S8b4oooool002Oooooo0_l0000Wooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00kooooo00Co0000
oooooooooooo00005?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00oooooo0_l0
0002ooooo`;o00004_ooool002Sooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0J
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0=oooool002Sooooo00?o0000oooo
ooooool0=oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool0=oooool002Wooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool0=oooool002[ooooo00?o0000ooooooooool0
=?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
=oooool002[ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Cooooo`;o00008?oo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0gooooo`00:oooool00ol0003oooooooooo`0booooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0gooooo`00:oooool00ol0
003oooooooooo`0aooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0gooooo`00;?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0gooooo`00;Oooool00ol0003ooooo
ooooo`0^ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool08Oooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0gooooo`00;Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`0fooooo`00;_ooool00ol0003oooooooooo`0/
ooooo`03o`000?oooooooooo01Oooooo0_l0000Rooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo03Kooooo000_oooo
o`03o`000?oooooooooo02[ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Roooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo03Kooooo000`ooooo`03o`000?oooooooooo02Sooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo03Kooooo000aooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Rooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo03Kooooo000aooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo03Kooooo000booooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo03Kooooo000cooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`0Sooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo03Kooooo000dooooo`03o`000?oooooooooo027o
oooo00?o0000ooooooooool07?ooool2o`0002Gooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`0=ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0=_ooool003Cooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool0=Oooool003Gooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0=Oooool003Kooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool0=Oooool003Oooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Poooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Roooo
o`03o`000?oooooooooo00kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0=Oooool003Sooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool0=Oooool003Wooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Rooooo`;o0000
9oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0eooooo`00>_ooool2o`0001Gooooo00?o0000ooooooooool08ooo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo03Gooooo000looooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo03Gooooo000mooooo`03o`000?oooooooooo00kooooo0_l0000Wooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool0=?ooool003kooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Mooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool09oooool003oooooo0_l00009ooooo`?o0000
8_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0Wooooo`00@Oooool9o`0002Gooooo00?o0000ooooooooool01Ooo
ool3o`0002Sooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Wooooo`00Koooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0Xooooo`00Koooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
02Sooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Xooooo`00Koooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Wooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0Xooooo`00Koooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Wooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Xooooo`00KOooool00omEEEGoIVIVo`00
0007ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool07_ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0Xooooo`00Moooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool0:_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0:Oooool007Oooooo0_l0000[ooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool0:_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0:Oooool007Oooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo02_ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo02Wooooo001gooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
8?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Yooooo`00Moooool00ol0003oooooooooo`0]ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo023ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool0:Oooool007Oooooo00?o0000ooooooooool0;Oooool0
0ol0003oooooooooo`02ooooo`;o0000;oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0:Oooool007Oooooo00?o0000ooooooooool0;_ooool4o`00
037ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
02Wooooo001gooooo`;o0000I?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02;o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0:Oooool007Oooooo00?o0000ooooooooool0I?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0:_ooool007Oooooo00?o
0000ooooooooool0I?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0:_ooool007Oooooo00?o0000ooooooooool0IOooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0:_ooool007Oooooo00?o0000oooo
ooooool0I_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool0:_ooool007Oooooo00?o0000ooooooooool0I_ooool00ol0003oooooooooo`02o`0002Oo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0:_ooool007Oooooo00?o0000ooooooooool0Ioooool3o`0002Wooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool0:_ooool007Oooooo0_l0002Dooooo`05o`000?ooooooooooooooool00000
8_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02[ooooo001gooooo`03o`000?oo
oooooooo09?ooooo00Go0000ooooooooooooooooo`00000Sooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool0:oooool007Oooooo00?o0000ooooooooool0U?ooool01?l0003ooooooooo
ool0000Sooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0:oooool007Oooooo00?o
0000ooooooooool0U?ooool3o`0002Cooooo00Go0000ooooooooooooooooo`00000^ooooo`00Mooo
ool00ol0003oooooooooo`2looooo`04o`000?ooooooooooo`0002kooooo001gooooo`03o`000?oo
oooooooo0;cooooo00Co0000oooooooooooo0000;_ooool007Oooooo0_l0002mooooo`?o0000;ooo
ool007Oooooo00?o0000ooooooooool0k_ooool007Oooooo00?o0000ooooooooool0k_ooool007Oo
oooo00?o0000ooooooooool0k_ooool006cooooo1Ol00006ooooo`03o`000?oooooooooo0>kooooo
001/ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`3^ooooo`00KOoo
ool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo0>kooooo001^ooooo`03oiRHV?lQ8B7o
k^k^00Kooooo0ol0003^ooooo`00Koooool00omgMgOoIVIVooooo`05ooooo`03o`000?oooooooooo
0>kooooo001`ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0k_ooool006cooooo
00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo0>kooooo001/ooooo`05oiRH
V?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`3^ooooo`00Moooool00ol0003ooooo
ooooo`3^ooooo`00Moooool2o`000>oooooo001gooooo`03o`000?oooooooooo0>kooooo001goooo
o`03o`000?oooooooooo0>kooooo001gooooo`03o`000?oooooooooo0>kooooo001gooooo`03o`00
0?oooooooooo0>kooooo001gooooo`03o`000?oooooooooo0>kooooo001gooooo`;o0000koooool0
07Oooooo00?o0000ooooooooool0k_ooool007Oooooo00?o0000ooooooooool0k_ooool007Oooooo
00?o0000ooooooooool0k_ooool007Oooooo00?o0000ooooooooool0k_ooool007Oooooo00?o0000
ooooooooool0k_ooool007Oooooo00?o0000ooooooooool0k_ooool007Oooooo0_l0003_ooooo`00
Moooool00ol0003oooooooooo`3^ooooo`00Moooool00ol0003oooooooooo`3^ooooo`00Moooool0
0ol0003oooooooooo`3^ooooo`00Moooool00ol0003oooooooooo`3^ooooo`00Moooool00ol0003o
ooooooooo`3^ooooo`00Moooool2o`000>oooooo001gooooo`03o`000?oooooooooo0>kooooo001g
ooooo`03o`000?oooooooooo0>kooooo001gooooo`03o`000?oooooooooo0>kooooo001/ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`01_ooool00ol0003oooooooooo`3^ooooo`00K?ooool01Ol@413o
^[ZjoooooomgMgOo<S8b00Kooooo00?o0000ooooooooool0k_ooool0073ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`3^ooooo`00Koooool00onYZJWo410@ooooo`05ooooo`?o0000
k_ooool006kooooo00?o410@o`000?nj^[X0moooool006oooooo00?o^[Zjob4Q8Oooool0m_ooool0
06cooooo00Go410@oiRHV?oooooo^[Zjo`00003gooooo`00K?ooool01OnYZJWo410@o`000?l@413o
ZJVY0?Oooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo001Uooooo`;o00002oooool00ol0003o^[Zjooooo`0<ooooo`03o`000?nj^[[ooooo
00cooooo0_l0003Fooooo`00IOooool00ol0003oooooooooo`0:ooooo`;o<S8b3Oooool2oc8b<Pko
oooo00?o0000ooooooooool0e?ooool005[ooooo1Ol00006ooooo`04o`000?ooooooooooooooo`;o
00000_ooool2o`0000?ooooo00?oQhN7o`000?nj^[X00oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Cooooo00?oQhN7o`000?nj^[X01?ooool01OnHV9So0000o`000?m4A4Co^[Zj00Cooooo00?o0000
ooooooooool0e?ooool005[ooooo0_mgMgL2ooooo`03o`000?oooooooooo00Cooooo00[o0000oooo
ooooooooooooonk^k_lQ8B7oQhN7okZj^_l0003ogMgM0oooool00oo<c<co0000oa0@4003ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01?ooool00oo<c<co0000oa0@4004ooooo`05oa0@4?nj^[[ok^k^
ogMgMol@41001?ooool00ol0003oooooooooo`3Dooooo`00Foooool00omEEEGoV9RHooooo`07oooo
o`03o`000?oooooooooo00;ooooo00CogMgMo`000?l@413oc<c<2_ooool01Ol@413ooooooooooooo
oooo410@00_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`3Dooooo`00G?ooool0
0omEEEGoV9RHooooo`06ooooo`03o`000?oooooooooo00;ooooo00Cok^k^ob4Q8Ol@413ok^k^2_oo
ool01Ol0003ooooooooooooooooo000000_ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`3Dooooo`00F_ooool01Ol0003ooooooooooolb<S;oQhN700Kooooo00?o0000ooooooooool0
0_ooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`05o`000?ooooooooooooooool000002oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo0=Cooooo001Jooooo`Go00001_ooool01?l0003o
ooooooooooooool2o`0000;ooooo0_l00009ooooo`05oa0@4?ooooooooooooooool@41002Oooool0
0ol@413o0000o`000003o`0000Gooooo00?o0000ooooooooool0e?ooool006Gooooo00?o0000oooo
ooooool04?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00_ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`3Dooooo`00IOooool2o`00017ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0;
ooooo`03o`000?oooooooooo00Gooooo0_l0003Fooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-6.04357, -3.17494, \
0.0630624, 0.0388712}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.0634921 0.309017 0.103006 [
[.0873 .29652 -6 -9 ]
[.0873 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.46825 .29652 -3 -9 ]
[.46825 .29652 3 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.72222 .29652 -3 -9 ]
[.72222 .29652 3 0 ]
[.84921 .29652 -3 -9 ]
[.84921 .29652 3 0 ]
[.97619 .29652 -6 -9 ]
[.97619 .29652 6 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .10301 -12 -4.5 ]
[.32877 .10301 0 4.5 ]
[.32877 .20601 -12 -4.5 ]
[.32877 .20601 0 4.5 ]
[.32877 .41202 -6 -4.5 ]
[.32877 .41202 0 4.5 ]
[.32877 .51503 -6 -4.5 ]
[.32877 .51503 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.34127 .64303 -26 0 ]
[.34127 .64303 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.0873 .30902 m
.0873 .31527 L
s
[(-4)] .0873 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-2)] .21429 .29652 0 1 Mshowa
.46825 .30902 m
.46825 .31527 L
s
[(2)] .46825 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(4)] .59524 .29652 0 1 Mshowa
.72222 .30902 m
.72222 .31527 L
s
[(6)] .72222 .29652 0 1 Mshowa
.84921 .30902 m
.84921 .31527 L
s
[(8)] .84921 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(10)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.18254 .30902 m
.18254 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.65873 .30902 m
.65873 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.81746 .30902 m
.81746 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.05556 .30902 m
.05556 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.34127 0 m
.34752 0 L
s
[(-3)] .32877 0 1 0 Mshowa
.34127 .10301 m
.34752 .10301 L
s
[(-2)] .32877 .10301 1 0 Mshowa
.34127 .20601 m
.34752 .20601 L
s
[(-1)] .32877 .20601 1 0 Mshowa
.34127 .41202 m
.34752 .41202 L
s
[(1)] .32877 .41202 1 0 Mshowa
.34127 .51503 m
.34752 .51503 L
s
[(2)] .32877 .51503 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(3)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .0206 m
.34502 .0206 L
s
.34127 .0412 m
.34502 .0412 L
s
.34127 .0618 m
.34502 .0618 L
s
.34127 .0824 m
.34502 .0824 L
s
.34127 .12361 m
.34502 .12361 L
s
.34127 .14421 m
.34502 .14421 L
s
.34127 .16481 m
.34502 .16481 L
s
.34127 .18541 m
.34502 .18541 L
s
.34127 .22661 m
.34502 .22661 L
s
.34127 .24721 m
.34502 .24721 L
s
.34127 .26781 m
.34502 .26781 L
s
.34127 .28842 m
.34502 .28842 L
s
.34127 .32962 m
.34502 .32962 L
s
.34127 .35022 m
.34502 .35022 L
s
.34127 .37082 m
.34502 .37082 L
s
.34127 .39142 m
.34502 .39142 L
s
.34127 .43262 m
.34502 .43262 L
s
.34127 .45322 m
.34502 .45322 L
s
.34127 .47383 m
.34502 .47383 L
s
.34127 .49443 m
.34502 .49443 L
s
.34127 .53563 m
.34502 .53563 L
s
.34127 .55623 m
.34502 .55623 L
s
.34127 .57683 m
.34502 .57683 L
s
.34127 .59743 m
.34502 .59743 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.34127 .64303 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.000 moveto
(D) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .20605 m
.02499 .20612 L
.02605 .20621 L
.02729 .20635 L
.02846 .20652 L
.03053 .20691 L
.03279 .20746 L
.0379 .20917 L
.04262 .21133 L
.05224 .21738 L
.06244 .22609 L
.0825 .24917 L
.10458 .28133 L
.14487 .34554 L
.1634 .37171 L
.18364 .39416 L
.18894 .3987 L
.1946 .40285 L
.19949 .40584 L
.20477 .40843 L
.2076 .40953 L
.2102 .41037 L
.21268 .41101 L
.21395 .41128 L
.21531 .41152 L
.21654 .4117 L
.21767 .41183 L
.21879 .41192 L
.21986 .41198 L
.22111 .41202 L
.22226 .41202 L
.22352 .41197 L
.22416 .41194 L
.22486 .41189 L
.22608 .41177 L
.22721 .41162 L
.22978 .41117 L
.23228 .41057 L
.23496 .40975 L
.23981 .40781 L
.24421 .40555 L
.25494 .39814 L
.26507 .3888 L
.28508 .36467 L
.30353 .3375 L
.34294 .27439 L
.36273 .23941 L
.38082 .20959 L
.3856 .20304 L
.3908 .19685 L
Mistroke
.39577 .19204 L
.40027 .18875 L
.40298 .18732 L
.40421 .18681 L
.40552 .18637 L
.40619 .18618 L
.40692 .18601 L
.40821 .1858 L
.40893 .18572 L
.40971 .18568 L
.41044 .18568 L
.41111 .18571 L
.4124 .18585 L
.41359 .18608 L
.41489 .18645 L
.41628 .18698 L
.4186 .18817 L
.42116 .18994 L
.4261 .19474 L
.43128 .20178 L
.44055 .21945 L
.45052 .24533 L
.46142 .28039 L
.48271 .35917 L
.49277 .39467 L
.50203 .42231 L
.50664 .43339 L
.51169 .44305 L
.51432 .44691 L
.51678 .44975 L
.51811 .45096 L
.51937 .45191 L
.52007 .45233 L
.52083 .45273 L
.52147 .453 L
.52216 .45323 L
.52333 .45346 L
.52442 .45351 L
.52573 .45335 L
.52693 .45299 L
.52811 .45244 L
.5294 .4516 L
.53075 .45047 L
.53201 .44919 L
.53642 .44286 L
.53888 .4381 L
.54113 .43304 L
.55109 .40247 L
.56029 .36429 L
.58108 .26042 L
Mistroke
.59011 .21765 L
.59982 .18066 L
.60267 .17229 L
.60538 .16559 L
.60802 .16032 L
.60931 .15822 L
.61047 .1566 L
.61158 .15529 L
.61278 .15415 L
.61405 .15326 L
.61524 .15273 L
.61656 .15247 L
.61723 .15248 L
.61796 .1526 L
.61925 .15307 L
.62045 .15384 L
.62171 .15496 L
.62305 .15653 L
.62546 .16028 L
.62805 .16566 L
.63091 .17318 L
.63602 .19057 L
.64082 .21108 L
.65938 .31638 L
.66832 .37114 L
.67787 .42242 L
.68336 .44556 L
.68834 .46121 L
.69075 .46668 L
.69202 .46899 L
.69336 .47098 L
.69453 .47234 L
.69582 .47342 L
.69699 .47402 L
.69809 .47424 L
.69933 .47409 L
.70003 .47383 L
.70068 .47346 L
.70187 .47248 L
.70314 .47102 L
.70439 .46915 L
.70556 .467 L
.70776 .46201 L
.71275 .44598 L
.71814 .42194 L
.72914 .35591 L
.73925 .28473 L
.74836 .22263 L
.75338 .19301 L
.75812 .16969 L
Mistroke
.76081 .15893 L
.76373 .1495 L
.76501 .14614 L
.76638 .14313 L
.76766 .14083 L
.76883 .13919 L
.77001 .13798 L
.77128 .13719 L
.77246 .13693 L
.77357 .13711 L
.77487 .13785 L
.77608 .13904 L
.7774 .14089 L
.7788 .14351 L
.78141 .15006 L
.78416 .15931 L
.78908 .18154 L
.79439 .21258 L
.80021 .25326 L
.81075 .33584 L
.82037 .40767 L
.82517 .43756 L
.8277 .45098 L
.83039 .46316 L
.83273 .47186 L
.83397 .47571 L
.83531 .47925 L
.83654 .48191 L
.83767 .48385 L
.83874 .48525 L
.83988 .48626 L
.84119 .48679 L
.84238 .4867 L
.84303 .4864 L
.84375 .48589 L
.84505 .48446 L
.84626 .48251 L
.84755 .47982 L
.84986 .47342 L
.85255 .46346 L
.85506 .45183 L
.86079 .41784 L
.87935 .26589 L
.88916 .18961 L
.89198 .17178 L
.89464 .15732 L
.89705 .14636 L
.8996 .13723 L
.90091 .13357 L
.90235 .13039 L
Mistroke
.90366 .12828 L
.90488 .12699 L
.90562 .12652 L
.90632 .12631 L
.90763 .12651 L
.90836 .12696 L
.90904 .12759 L
.90979 .12852 L
.91058 .12977 L
.91178 .13223 L
.91308 .13558 L
.91542 .14349 L
.91821 .15588 L
.92076 .1699 L
.93056 .24301 L
.94086 .33786 L
.94972 .41525 L
.95458 .44987 L
.95697 .46386 L
.95917 .47472 L
.96121 .48292 L
.96346 .48972 L
.96462 .49231 L
.96571 .49412 L
.96686 .4954 L
.96809 .49604 L
.96913 .49598 L
.97027 .4953 L
.97134 .49406 L
.97233 .49239 L
.97322 .49048 L
.9742 .48791 L
.97619 .48125 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0.75, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00K?ooool01OnHV9So410@o`000?lb<S;oc<c<0?Oo
oooo001/ooooo`05oa0@4?nj^[[oooooogMgMolb<S80moooool006Cooooo1_l00006ooooo`03o`00
0?oooooooooo0?Gooooo001_ooooo`03ojVYZOl@413ooooo00Gooooo0ol0003^ooooo`00K_ooool0
0ol@413o0000okZj^P06ooooo`03o`000?oooooooooo0>kooooo001_ooooo`03okZj^_lQ8B7ooooo
00Gooooo00?o0000ooooooooool0k_ooool006cooooo00Go410@oiRHV?oooooo^[Zjo`000006oooo
o`03o`000?oooooooooo0>kooooo001/ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0
003oooooooooo`3^ooooo`00Moooool00ol0003oooooooooo`3^ooooo`00Moooool2o`000>oooooo
001gooooo`03o`000?oooooooooo0>kooooo001gooooo`03o`000?oooooooooo0>kooooo001goooo
o`03o`000?oooooooooo0>kooooo001gooooo`03o`000?oooooooooo0>kooooo001gooooo`03o`00
0?oooooooooo0>kooooo001gooooo`03o`000?oooooooooo0>kooooo001gooooo`;o0000koooool0
07Oooooo00?o0000ooooooooool0k_ooool007Oooooo00?o0000ooooooooool0k_ooool007Oooooo
00?o0000ooooooooool0k_ooool007Oooooo00?o0000ooooooooool0k_ooool007Oooooo00?o0000
ooooooooool0k_ooool007Oooooo0_l0003_ooooo`00Moooool00ol0003oooooooooo`3^ooooo`00
Moooool00ol0003oooooooooo`3^ooooo`00Moooool00ol0003oooooooooo`3^ooooo`00Moooool0
0ol0003oooooooooo`3^ooooo`00Moooool00ol0003oooooooooo`3^ooooo`00Moooool2o`000>oo
oooo001gooooo`03o`000?oooooooooo0>kooooo001gooooo`03o`000?oooooooooo0>kooooo001g
ooooo`03o`000?oooooooooo0>kooooo001/ooooo`Go00001_ooool00ol0003oooooooooo`3^oooo
o`00K?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0k_ooool006Co
oooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0k_ooool006kooooo
00?oV9RHob4Q8Oo^k^h01_ooool3o`000>kooooo001_ooooo`03ogMgMomVIVKooooo00Gooooo00?o
0000ooooooooool0k_ooool0073ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3^
ooooo`00K?ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0k_ooool0
06cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0>kooooo001goooo
o`03o`000?oooooooooo0>kooooo001gooooo`;o0000koooool007Oooooo00?o0000ooooooooool0
[Oooool2o`0003oooooo001gooooo`03o`000?oooooooooo0:cooooo0_l000000ooooooo0000oooo
o`0mooooo`00Moooool00ol0003oooooooooo`2/ooooo`04o`000?ooooooooooo`0003kooooo001g
ooooo`03o`000?oooooooooo08Cooooo00?o0000ooooooooool09Oooool01Ol0003ooooooooooooo
oooo000003gooooo001gooooo`03o`000?oooooooooo08?ooooo0ol0000Vooooo`05o`000?oooooo
ooooooooool00000?Oooool007Oooooo00?o0000ooooooooool0P_ooool01?l0003oooooooooool0
000Vooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0>_ooool007Oooooo0_l00023
ooooo`05o`000?ooooooooooooooool000009?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo03[ooooo001gooooo`03o`000?oooooooooo087ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0>_ooool0
07Oooooo00?o0000ooooooooool0Doooool2o`0002cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Qooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0>_ooool007Oo
oooo00?o0000ooooooooool0D_ooool01?l0003oooooo`000?l0000Zooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
03[ooooo001gooooo`03o`000?oooooooooo057ooooo00Go0000ooooooooooooooooo`00000Zoooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo03[ooooo001gooooo`03o`000?oooooooooo057ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03[ooooo001gooooo`;o0000
DOooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
>Oooool007Oooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0>Oooool007Oooooo00?o0000ooooooooool0Coooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0>Oooool0
07Oooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0>Oooool007Oooooo00?o0000ooooooooool0Coooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0>Oooool007Oooooo
00?o0000ooooooooool0C_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0>Oooool007Oooooo00?o0000ooooooooool0C_ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0>Oooool007Oooooo0_l0000B
ooooo`Go0000>?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02;ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool0>?ooool007Oooooo00?o0000ooooooooool03oooool2o`0000Gooooo00?o0000oooo
ooooool0=?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02;ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool0>?ooool007Oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo03?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Rooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo03Sooooo001gooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
8_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0hooooo`00KOooool4o`000003oa0@4?oooooooooo00?ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03;ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo03Sooooo001_
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo03Sooooo000Dooooo`?o0000COooool6o`0000Gooooo00?o0000oooo
ooooool01Oooool3o`0000_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0`oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0hoooo
o`005oooool3o`0005Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool0=oooool001[ooooo0_l0001Cooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo02kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Oooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo03Oooooo000Looooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0;Ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0=ooo
ool001gooooo0_l0001@ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03Oooooo000Oooooo`03o`000?oooooooooo
04_ooooo00?oEEEEofIVI_l000001oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool0=oooool0023ooooo00?o0000ooooooooool0E?ooool2o`0000So
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0gooooo`008?ooool00ol0003ooooo
ooooo`1Dooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0Zooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0gooooo`008Oooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0gooooo`008_ooool00ol0003oooooooooo`1B
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Y
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0f
ooooo`008oooool00ol0003oooooooooo`1Aooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0fooooo`009?ooool00ol0003oooooooooo`1@ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Xooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0fooooo`00
9Oooool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0fooooo`009_ooool00ol0003oooooooooo`1>ooooo`;o00001?oo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03Kooooo000Wooooo`03o`000?oooooo
oooo04gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo03Kooooo000Wooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo03Kooooo000Xooooo`03o`000?oooooooooo04co
oooo00Go0000ooooooooooooooooo`00000Nooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03Kooooo000Yooooo`03
o`000?oooooooooo04_ooooo00Co0000oooooooooooo00008?ooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0foooo
o`00:Oooool00ol0003oooooooooo`1;ooooo`04o`000?ooooooooooo`00023ooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool0=Oooool002[ooooo0ol000000ol@413oooooooooo`0Qooooo`Go00008Oooool3o`00027o
oooo1_l0000Qooooo`04o`000?ooooooooooooooo`;o000000?o410@ooooooooool03Oooool00ol0
003oooooooooo`0@ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`01Oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00Wooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c007ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool01Oooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o
0000oc8b<_o^k^hTooooo`00:_ooool00ol0003oooooo`00000Tooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@08Oooool00ol0003oooooo`00000Rooooo`05o`000?lQ8B7ok^k^oooooom4A4@08Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool04?ooool0
1OmEEEGoMgMgoooooonHV9So8B4Q00Gooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`08ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02Co
oooo000Qooooo`Ko00000_ooool5o`0001_ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^02;ooooo
0_l0000Sooooo`04o`000?nHV9So8B4Qonk^kR7ooooo00?o0000ooooooooool01Ol0000?ooooo`03
o`000?oooooooooo013ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool02?ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00Go410@
oooooooooooooooooa0@400Tooooo`00:Oooool01?m4A4CogMgMooooool0000Vooooo`03oiRHV?lQ
8B7ok^k^027ooooo0_l0000Sooooo`05o`000?ooooooV9RHob4Q8Oo^k^h08?ooool01ol0003ooooo
oooooom4A4CogMgMooooool000004Oooool00ol0003oooooooooo`0?ooooo`05o`000?nHV9Sooooo
oiRHV?lQ8B401?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Sooooo00Go<S8b
oiRHV?ooooooV9RHoc8b<P07ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000009?ooool002Wooooo00Co
gMgMoeEEEOoooooo00009oooool00omgMgOoIVIVooooo`0Pooooo`03o`000?oooooooooo02?ooooo
00Co0000oooooomgMgOoIVIV8?ooool01ol0003ooooooooooooMgMgoEEEEooooool000004Oooool0
0ol0003oooooooooo`0?ooooo`05o`000?mEEEGo0000oa0@4?o<c<`01?ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo00Sooooo00Goc<c<o`000?l0003o0000olc<c007ooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000009?ooool002[ooooo00CoMgMgolc<c?l0003o00009oooool00ol0003o
ooooooooo`0Nooooo`;o00009Oooool01?l0003oooooooooool0000Pooooo`07o`000?oooooooooo
oooooomgMgOoc<c<o`00000Aooooo`03o`000?oooooooooo00oooooo00?oEEEEohN7Qoooool01_oo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Sooooo00Go410@okZj^_oooooo^[Zj
oa0@4006ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`02ooooo`05oa0@4?ooooooooooooooool@41009?ooool002[ooooo00Cok^k^odA4A?l0003o
00008oooool01Ol0003o^[ZjoooooonHV9So410@023ooooo0_l0000Tooooo`;o000000?ooooooiRH
V?l@41008?ooool01ol0003oooooooooooooooook^k^odA4A?l000004Oooool00ol0003ooooooooo
o`0?ooooo`03omgMgOl@413oV9RH00Kooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`08ooooo`05o`000?nj^[[ooooookZj^_l000001_ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg02Co
oooo000[ooooo`04ogMgMol0003oooooo`0002;ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Ooooo
o`04o`000?oooooo0000o`0002?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00Oooooo`03o`000?oo
oooooooo00?ooooo00?oMgMgo`000?ooool04?ooool00ol0003oooooooooo`0@ooooo`04olc<c?m4
A4Co0000oa0@40Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`08ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT01_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Go
oooo00?oEEEEofIVI_l000001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Cooooo000_ooooo`03
o`000?oooooooooo04?ooooo00?o0000ooooool000009_ooool00ol0003oooooooooo`0Oooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Aooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0dooooo`00
;oooool00ol0003oooooooooo`12ooooo`04o`000?ooooooooooo`0002Kooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool0=?ooool0033ooooo00?o0000ooooooooool0@?ooool01Ol0003ooooooooooooooooo000002Ko
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool07?ooool2o`0000;ooooo0_l0000Booooo`00<Oooool00ol0003ooooo
ooooo`0oooooo`05o`000?ooooooooooooooool000009oooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Looooo`06
onk^k_lQ8B7oQhN7okZj^_l0003ogMgM4_ooool0037ooooo00?o0000ooooooooool0?_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool07Oooool01?oM
gMgo0000oa0@4?o<c<`Cooooo`003Oooooooo`0003[o00002oooool01?o^k^ko8B4Qoa0@4?o^k^hC
ooooo`005?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01oooool2o`0000Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07oooo
o`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
000000Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`;o00002?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00002Ooo
ool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000Wooooo00?o0000ooooooooool0
1?ooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo013ooooo00Co8B4QogMgMomg
MgOo<S8b4oooool002Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Uooooo`;o
00007_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool04?ooool01Ol0003ooooooooooooooooo000001Kooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0?ooooo`;o00000_ooool2o`0001;ooooo000dooooo`03o`000?oooooooooo03Wo
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo03Co
oooo000dooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Vooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo03Cooooo000eooooo`03o`000?oooooooooo03Oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo03?ooooo000f
ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo03?ooooo000fooooo`03o`000?oooooooooo03Cooooo00?o0000oooo
ooooool01oooool2o`0002Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0<oooool003Oooooo00?o0000oooooooo
ool0<oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Oooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool0<oooool003Sooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool0<oooool003Sooooo00?o0000ooooooooool0<Ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0<ooo
ool003Wooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo02Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool0<oooool003[ooooo00?o0000ooooooooool0;Oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0<oooool003[o
oooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0:ooooo`;o0000:Oooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0cooooo`00>oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`0booooo`00??ooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`0booooo`00?Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool0:Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`0booooo`00?Oooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0boooo
o`00?_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool0:_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`0booooo`00?oooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo01kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0booooo`00@?oo
ool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00oooooo0_l0000[ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo03;ooooo0010ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo03;ooooo0011ooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
037ooooo0012ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0[ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo037ooooo0013ooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool08Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo037ooooo
0014ooooo`03o`000?oooooooooo01Sooooo0_l0000Fooooo`03o`000?oooooooooo02cooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool0<Oooool004Gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0F
ooooo`;o0000;Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`0aooooo`00A_ooool2o`0001Gooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo037ooooo0018ooooo`03
o`000?oooooooooo013ooooo0_l0000Jooooo`03o`000?oooooooooo02gooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool0<Oooool004Wooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo02gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Sooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool0<Oooool004[ooooo0ol0000<ooooo`03o`000?oo
oooooooo017ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooooooo02kooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool0<?ooool004gooooo00?o0000ooooooooool01oooool2o`0001Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool08oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo033ooooo001>oooo
o`Wo00006?ooool00ol0003oooooooooo`05ooooo`?o0000;_ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0`oooo
o`00Koooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02kooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool0<?ooool006oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0^ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo01gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo033ooooo001_ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0;ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0`ooooo`00Koooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo02oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool0<?ooool006gooooo00?oEEEEofIVI_l000001oooool00ol0
003oooooooooo`0_ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo02oooooo001gooooo`03o`000?oooooooooo033o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool0;oooool007Oooooo0_l0000booooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0:?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01oooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02oooooo
001gooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0;oooool007Oooooo00?o0000
ooooooooool0<_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`0_ooooo`00Moooool00ol0003oooooooooo`0boooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo023ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo02kooooo001gooooo`03o`000?oooooooooo03?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool0;_ooool007Oooooo00?o0000ooooooooool0=?ooool01?l0003oooooooooooooool2o`0002ko
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0^ooooo`00Moooool2o`0003Kooooo
1?l0000`ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool08Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0;_ooool007Oooooo00?o
0000ooooooooool0JOooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02;ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02kooooo001g
ooooo`03o`000?oooooooooo06Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0S
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0]
ooooo`00Moooool00ol0003oooooooooo`1Zooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool0;Oooool007Oooooo00?o0000ooooooooool0J_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo02gooooo001gooooo`03o`000?oooooooooo06_ooooo00Go0000oooooooooooo
ooooo`00000Wooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`0]ooooo`00Moooool00ol0003oooooooooo`1[ooooo`;o000000?oooooo`000?ooool0
9oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0
;Oooool007Oooooo0_l0001]ooooo`?o0000:?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo01oooooo00?o0000ooooooooool0;Oooool007Oooooo00?o0000ooooooooool0V?ooool0
1Ol0003ooooooooooooooooo0000027ooooo00?o0000ooooooooool0;Oooool007Oooooo00?o0000
ooooooooool0V?ooool01?l0003oooooooooool0000Sooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool09oooool007Oooooo00?o0000ooooooooool0V?ooool4o`0002?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Wooooo`00Moooool00ol0003oooooooooo`2Ioooo
o`;o00009?ooool01Ol0003ooooooooooooooooo000002[ooooo001gooooo`03o`000?oooooooooo
0<3ooooo00Co0000ooooool0003o0000:_ooool007Oooooo0_l00031ooooo`?o0000:oooool007Oo
oooo00?o0000ooooooooool0`Oooool00ol0003oooooooooo`0Zooooo`00Moooool00ol0003ooooo
ooooo`3^ooooo`00Moooool00ol0003oooooooooo`3^ooooo`00K?ooool5o`0000Kooooo00?o0000
ooooooooool0k_ooool006cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooo
oooo0>kooooo001]ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0k_ooool006ko
oooo00?oV9RHob4Q8Oo^k^h01_ooool3o`000>kooooo001_ooooo`03ogMgMomVIVKooooo00Gooooo
00?o0000ooooooooool0k_ooool0073ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`3^ooooo`00K?ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0k_oo
ool006cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0>kooooo001g
ooooo`03o`000?oooooooooo0>kooooo001gooooo`;o0000koooool007Oooooo00?o0000oooooooo
ool0k_ooool007Oooooo00?o0000ooooooooool0k_ooool007Oooooo00?o0000ooooooooool0k_oo
ool007Oooooo00?o0000ooooooooool0k_ooool007Oooooo00?o0000ooooooooool0k_ooool007Oo
oooo0_l0003_ooooo`00Moooool00ol0003oooooooooo`3^ooooo`00Moooool00ol0003ooooooooo
o`3^ooooo`00Moooool00ol0003oooooooooo`3^ooooo`00Moooool00ol0003oooooooooo`3^oooo
o`00Moooool00ol0003oooooooooo`3^ooooo`00Moooool00ol0003oooooooooo`3^ooooo`00Mooo
ool2o`000>oooooo001gooooo`03o`000?oooooooooo0>kooooo001gooooo`03o`000?oooooooooo
0>kooooo001gooooo`03o`000?oooooooooo0>kooooo001gooooo`03o`000?oooooooooo0>kooooo
001gooooo`03o`000?oooooooooo0>kooooo001gooooo`;o0000koooool007Oooooo00?o0000oooo
ooooool0k_ooool007Oooooo00?o0000ooooooooool0k_ooool007Oooooo00?o0000ooooooooool0
k_ooool006cooooo00GoV9RHoa0@4?l0003o<S8bolc<c006ooooo`03o`000?oooooooooo0>kooooo
001/ooooo`05oa0@4?nj^[[oooooogMgMolb<S801_ooool00ol0003oooooooooo`3^ooooo`00L?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo0>kooooo001_ooooo`03ojVYZOl@413o
oooo00Gooooo0ol0003^ooooo`00K_ooool00ol@413o0000okZj^P3gooooo`00Koooool00onj^[[o
8B4Qooooo`3fooooo`00K?ooool01Ol@413oV9RHoooooonj^[[o00000?Oooooo001/ooooo`05ojVY
ZOl@413o0000oa0@4?nYZJT0moooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool006Gooooo0_l0000;ooooo`03o`000?nj^[[ooooo00cooooo
00?o0000okZj^_ooool03?ooool2o`000=Kooooo001Uooooo`03o`000?oooooooooo00[ooooo0_lb
<S8=ooooo`;o<S8b3_ooool00ol0003oooooooooo`3Dooooo`00F_ooool5o`0000Kooooo00Co0000
oooooooooooooooo0_l00002ooooo`;o00000oooool00on7QhOo0000okZj^P03ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01?ooool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0003o0000odA4A?nj
^[X01?ooool00ol0003oooooooooo`3Dooooo`00F_ooool2ogMgM`;ooooo00?o0000ooooooooool0
1?ooool02_l0003oooooooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oMgMd3ooooo`03olc<c?l0
003o410@00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`03olc<c?l0003o410@00Cooooo
00Go410@okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oooooooooo0=Cooooo001Kooooo`03oeEE
EOnHV9Sooooo00Oooooo00?o0000ooooooooool00_ooool01?oMgMgo0000oa0@4?o<c<`:ooooo`05
oa0@4?ooooooooooooooool@41002oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
0=Cooooo001Looooo`03oeEEEOnHV9Sooooo00Kooooo00?o0000ooooooooool00_ooool01?o^k^ko
8B4Qoa0@4?o^k^h:ooooo`05o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo0=Cooooo001Jooooo`05o`000?oooooooooooc8b<_n7QhL01_ooool0
0ol0003oooooooooo`02ooooo`04ob4Q8OmgMgOoMgMgoc8b<P[ooooo00Go0000oooooooooooooooo
o`00000;ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0e?ooool005[ooooo1Ol0
0006ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000Wooooo00Go410@oooooooooooo
oooooa0@4009ooooo`03oa0@4?l0003o000000?o00001Oooool00ol0003oooooooooo`3Dooooo`00
IOooool00ol0003oooooooooo`0@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo0=Cooooo001Uooooo`;o00004Oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00_ooooo00?o0000ooooooooool01Oooool2o`000=Kooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-6.04357, -3.17494, \
0.0630624, 0.0388712}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.0634921 0.309017 0.103006 [
[.0873 .29652 -6 -9 ]
[.0873 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.46825 .29652 -3 -9 ]
[.46825 .29652 3 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.72222 .29652 -3 -9 ]
[.72222 .29652 3 0 ]
[.84921 .29652 -3 -9 ]
[.84921 .29652 3 0 ]
[.97619 .29652 -6 -9 ]
[.97619 .29652 6 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .10301 -12 -4.5 ]
[.32877 .10301 0 4.5 ]
[.32877 .20601 -12 -4.5 ]
[.32877 .20601 0 4.5 ]
[.32877 .41202 -6 -4.5 ]
[.32877 .41202 0 4.5 ]
[.32877 .51503 -6 -4.5 ]
[.32877 .51503 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.34127 .64303 -26 0 ]
[.34127 .64303 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.0873 .30902 m
.0873 .31527 L
s
[(-4)] .0873 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-2)] .21429 .29652 0 1 Mshowa
.46825 .30902 m
.46825 .31527 L
s
[(2)] .46825 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(4)] .59524 .29652 0 1 Mshowa
.72222 .30902 m
.72222 .31527 L
s
[(6)] .72222 .29652 0 1 Mshowa
.84921 .30902 m
.84921 .31527 L
s
[(8)] .84921 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(10)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.18254 .30902 m
.18254 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.65873 .30902 m
.65873 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.81746 .30902 m
.81746 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.05556 .30902 m
.05556 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.34127 0 m
.34752 0 L
s
[(-3)] .32877 0 1 0 Mshowa
.34127 .10301 m
.34752 .10301 L
s
[(-2)] .32877 .10301 1 0 Mshowa
.34127 .20601 m
.34752 .20601 L
s
[(-1)] .32877 .20601 1 0 Mshowa
.34127 .41202 m
.34752 .41202 L
s
[(1)] .32877 .41202 1 0 Mshowa
.34127 .51503 m
.34752 .51503 L
s
[(2)] .32877 .51503 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(3)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .0206 m
.34502 .0206 L
s
.34127 .0412 m
.34502 .0412 L
s
.34127 .0618 m
.34502 .0618 L
s
.34127 .0824 m
.34502 .0824 L
s
.34127 .12361 m
.34502 .12361 L
s
.34127 .14421 m
.34502 .14421 L
s
.34127 .16481 m
.34502 .16481 L
s
.34127 .18541 m
.34502 .18541 L
s
.34127 .22661 m
.34502 .22661 L
s
.34127 .24721 m
.34502 .24721 L
s
.34127 .26781 m
.34502 .26781 L
s
.34127 .28842 m
.34502 .28842 L
s
.34127 .32962 m
.34502 .32962 L
s
.34127 .35022 m
.34502 .35022 L
s
.34127 .37082 m
.34502 .37082 L
s
.34127 .39142 m
.34502 .39142 L
s
.34127 .43262 m
.34502 .43262 L
s
.34127 .45322 m
.34502 .45322 L
s
.34127 .47383 m
.34502 .47383 L
s
.34127 .49443 m
.34502 .49443 L
s
.34127 .53563 m
.34502 .53563 L
s
.34127 .55623 m
.34502 .55623 L
s
.34127 .57683 m
.34502 .57683 L
s
.34127 .59743 m
.34502 .59743 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.34127 .64303 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.000 moveto
(D) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .22411 m
.03279 .21674 L
.04262 .21078 L
.04758 .20866 L
.05035 .20774 L
.05288 .20708 L
.05524 .2066 L
.05657 .20639 L
.0578 .20624 L
.05887 .20614 L
.06005 .20606 L
.06129 .20602 L
.06244 .20601 L
.0631 .20603 L
.06379 .20605 L
.06504 .20613 L
.06581 .20619 L
.06653 .20627 L
.06788 .20645 L
.07036 .2069 L
.07305 .20756 L
.0781 .2093 L
.08274 .21145 L
.09336 .21831 L
.10458 .2283 L
.12422 .25161 L
.14255 .27834 L
.18146 .34048 L
.20127 .36907 L
.21172 .38197 L
.22282 .39351 L
.23266 .40159 L
.23788 .40499 L
.24352 .40793 L
.24603 .40899 L
.24867 .40993 L
.25112 .41065 L
.25339 .41119 L
.25554 .41157 L
.25673 .41173 L
.25782 .41185 L
.25902 .41195 L
.26031 .41201 L
.26154 .41202 L
.26267 .412 L
.26392 .41195 L
.26511 .41185 L
.26618 .41174 L
.26734 .41158 L
.26994 .41111 L
Mistroke
.27236 .41051 L
.27675 .40906 L
.28143 .40698 L
.29226 .40016 L
.30207 .39168 L
.32135 .36952 L
.34219 .33953 L
.38324 .25853 L
.39313 .23649 L
.40371 .2147 L
.41285 .19885 L
.41767 .19207 L
.42278 .18635 L
.42531 .18414 L
.4281 .18221 L
.42932 .18154 L
.43063 .18095 L
.43187 .18051 L
.43301 .18021 L
.43418 .18002 L
.43526 .17993 L
.43646 .17994 L
.43773 .18009 L
.43837 .18021 L
.43906 .18039 L
.44033 .18081 L
.44155 .18135 L
.44269 .18197 L
.44486 .18346 L
.44688 .18523 L
.45149 .19063 L
.45599 .19774 L
.46081 .20735 L
.47096 .23399 L
.48202 .27142 L
.50214 .35155 L
.51232 .39092 L
.52189 .4223 L
.52709 .43585 L
.53186 .44556 L
.53445 .4496 L
.53717 .45287 L
.53858 .45416 L
.5399 .45509 L
.54064 .45551 L
.54134 .45583 L
.54215 .4561 L
.54289 .45626 L
.54404 .45635 L
.54527 .45621 L
Mistroke
.54644 .45587 L
.54751 .45536 L
.54875 .45455 L
.55011 .45338 L
.55259 .45051 L
.55517 .44648 L
.55793 .44104 L
.56287 .42837 L
.57255 .39377 L
.58132 .35333 L
.6022 .24359 L
.61136 .20108 L
.61621 .18261 L
.61888 .17398 L
.62141 .16693 L
.62384 .16126 L
.62648 .1564 L
.62765 .1547 L
.62889 .15321 L
.62995 .1522 L
.63111 .15135 L
.63228 .1508 L
.63336 .15056 L
.63454 .15059 L
.63578 .15095 L
.63687 .15155 L
.63788 .15234 L
.63898 .15347 L
.64017 .15499 L
.64273 .15933 L
.64551 .16566 L
.65055 .1813 L
.65546 .2013 L
.65998 .22338 L
.68035 .34757 L
.69031 .40663 L
.69503 .43021 L
.6994 .44838 L
.70389 .46264 L
.70626 .46816 L
.70747 .47043 L
.70878 .47243 L
.71003 .47391 L
.71119 .47489 L
.71229 .47548 L
.71345 .47573 L
.7145 .47562 L
.71547 .47525 L
.71654 .47452 L
.71768 .47339 L
Mistroke
.719 .47161 L
.72021 .46954 L
.72296 .46332 L
.72538 .45612 L
.72796 .44678 L
.73731 .39968 L
.75706 .26195 L
.7657 .20457 L
.77026 .17935 L
.77513 .15796 L
.77783 .14894 L
.78029 .1427 L
.78147 .14038 L
.78275 .13838 L
.78396 .137 L
.78507 .13617 L
.78621 .13575 L
.78727 .13576 L
.78843 .13622 L
.78967 .13723 L
.79098 .13887 L
.79221 .14095 L
.79453 .14627 L
.79705 .15408 L
.79972 .1646 L
.80453 .18883 L
.81541 .2635 L
.82499 .3405 L
.83509 .41608 L
.83926 .44166 L
.84371 .46359 L
.84627 .47326 L
.8486 .48001 L
.84972 .48255 L
.85094 .48475 L
.85208 .48629 L
.85314 .48726 L
.85426 .48778 L
.85545 .4878 L
.85658 .48728 L
.85762 .48635 L
.85882 .48472 L
.86014 .48228 L
.86254 .47606 L
.86503 .46722 L
.8677 .45527 L
.87248 .42777 L
.88342 .34315 L
.89333 .25627 L
.90271 .18384 L
Mistroke
.90743 .15622 L
.91011 .14409 L
.91261 .13536 L
.91402 .13161 L
.91535 .12885 L
.91655 .12705 L
.91785 .12583 L
.91852 .1255 L
.91927 .12538 L
.92004 .12552 L
.92077 .12591 L
.92207 .12721 L
.9228 .12828 L
.92346 .12947 L
.92579 .1352 L
.9271 .13951 L
.92833 .1442 L
.93344 .17046 L
.9385 .20579 L
.94398 .25196 L
.95393 .34532 L
.96297 .42384 L
.96752 .45533 L
.97011 .46976 L
.97253 .48068 L
.97429 .48697 L
.97619 .49205 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0.75, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00K?ooool01OnHV9So410@o`000?lb<S;oc<c<0?Oo
oooo001/ooooo`05oa0@4?nj^[[oooooogMgMolb<S80moooool006Cooooo1_l00006ooooo`03o`00
0?oooooooooo0?Gooooo001_ooooo`03ojVYZOl@413ooooo00Gooooo0ol0003^ooooo`00K_ooool0
0ol@413o0000okZj^P06ooooo`03o`000?oooooooooo0>kooooo001_ooooo`03okZj^_lQ8B7ooooo
00Gooooo00?o0000ooooooooool0k_ooool006cooooo00Go410@oiRHV?oooooo^[Zjo`000006oooo
o`03o`000?oooooooooo0>kooooo001/ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0
003oooooooooo`3^ooooo`00Moooool00ol0003oooooooooo`3^ooooo`00Moooool2o`000>oooooo
001gooooo`03o`000?oooooooooo0>kooooo001gooooo`03o`000?oooooooooo0>kooooo001goooo
o`03o`000?oooooooooo0>kooooo001gooooo`03o`000?oooooooooo0>kooooo001gooooo`03o`00
0?oooooooooo0>kooooo001gooooo`03o`000?oooooooooo0>kooooo001gooooo`;o0000koooool0
07Oooooo00?o0000ooooooooool0k_ooool007Oooooo00?o0000ooooooooool0k_ooool007Oooooo
00?o0000ooooooooool0k_ooool007Oooooo00?o0000ooooooooool0k_ooool007Oooooo00?o0000
ooooooooool0k_ooool007Oooooo0_l0003_ooooo`00Moooool00ol0003oooooooooo`3^ooooo`00
Moooool00ol0003oooooooooo`3^ooooo`00Moooool00ol0003oooooooooo`3^ooooo`00Moooool0
0ol0003oooooooooo`3^ooooo`00Moooool00ol0003oooooooooo`3^ooooo`00Moooool2o`000>oo
oooo001gooooo`03o`000?oooooooooo0>kooooo001gooooo`03o`000?oooooooooo0>kooooo001g
ooooo`03o`000?oooooooooo0>kooooo001/ooooo`Go00001_ooool00ol0003oooooooooo`3^oooo
o`00K?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0k_ooool006Co
oooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0k_ooool006kooooo
00?oV9RHob4Q8Oo^k^h01_ooool3o`000>kooooo001_ooooo`03ogMgMomVIVKooooo00Gooooo00?o
0000ooooooooool0k_ooool0073ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3^
ooooo`00K?ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0k_ooool0
06cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0>kooooo001goooo
o`03o`000?oooooooooo0>kooooo001gooooo`;o0000koooool007Oooooo00?o0000ooooooooool0
/Oooool3o`0003[ooooo001gooooo`03o`000?oooooooooo0;7ooooo00?o0000ooooool00000>_oo
ool007Oooooo00?o0000ooooooooool0/?ooool01?l0003oooooooooool0000jooooo`00Moooool0
0ol0003oooooooooo`28ooooo`;o00009_ooool01Ol0003ooooooooooooooooo000003Wooooo001g
ooooo`03o`000?oooooooooo08Oooooo00Co0000ooooool0003o00009Oooool01Ol0003ooooooooo
oooooooo000003Wooooo001gooooo`03o`000?oooooooooo08Kooooo0_l00002ooooo`03o`000?oo
oooooooo02;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0gooooo`00Moooool2
o`0008Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0=_ooool007Oooooo00?o0000ooooooooool0Q_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0fooooo`00Moooool00ol0003oooooooooo`1Gooooo`Co0000:oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0fooooo`00Moooool00ol0003oooooooooo`1Gooooo`03o`000?oooooooooo00;o0000
:Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0fooooo`00Moooool00ol0003oooooooooo`1Fooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo01oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0fooooo`00Moooool0
0ol0003oooooooooo`1Fooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool09oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0eooooo`00Moooool2o`0005Oooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo03Gooooo001gooooo`03o`000?oooooooooo05Go
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Go
oooo001gooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo03Gooooo001gooooo`03o`000?oooooooooo05Cooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03Gooooo001g
ooooo`03o`000?oooooooooo05Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0S
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo03Gooooo001gooooo`03o`000?oooooooooo01Wooooo1Ol0000eoooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0eoooo
o`00Moooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00;ooooo0_l0000dooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0dooooo`00
Moooool2o`0001Sooooo00?o0000ooooooooool01?ooool2o`0003?ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo03Cooooo001gooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0`ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0dooooo`00Moooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0<?ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0=?ooool0
07Oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
02kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
03Cooooo001]ooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool0<oooool006oooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
;Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
<oooool001gooooo1ol00010ooooo`Ko00001Oooool00ol0003oooooooooo`05ooooo`?o00004ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo03?ooooo000Kooooo`;o00001oooool3
o`0004Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool0<oooool001Wooooo0_l0000<ooooo`;o0000A_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0Zooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0cooooo`005oooool2o`00013ooooo00?o0000ooooooooool0@oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0Zooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0cooooo`005_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04;ooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool0<oooool001Gooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0oooooo`03oeEEEOmVIVKo000000Oooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo03?ooooo000Dooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool0B?ooool2o`00017ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0c
ooooo`00;Oooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0cooooo`00;_ooool00ol0003oooooooooo`16ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0booooo`00
;oooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0booooo`00<?ooool00ol0003oooooooooo`14ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Wooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0booooo`00<Oooool0
0ol0003oooooooooo`13ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0booooo`00<_ooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0booooo`00<oooool00ol0003o
ooooooooo`11ooooo`;o00003Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03;o
oooo000dooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo03;ooooo000dooooo`03o`000?oooooooooo043ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03;ooooo000e
ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo03;ooooo000eooooo`03o`000?oooooooooo03oooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo02?ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo03;ooooo000fooooo`03
o`000?oooooooooo03kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo03;ooooo000[ooooo`;o000000?o410@ooooooooool01oooool00ol0003ooooo
ooooo`0Gooooo`Go00008Oooool2o`0000[ooooo00?o0000ooooooooool05_ooool5o`0000;ooooo
00?o0000ooooooooool08?ooool3o`0001Cooooo00?o0000ooooooooool02oooool01Oo^k^ko<S8b
o`000?l@413oc<c<00Wooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`05ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`03?ooool00ol0003oooooooooo`0=ooooo`04o`000?oooooooooo
ooooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kRCooooo000/ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool05oooool01OnHV9So8B4Qonk^k_ooooooA4A4027o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Gooooo`05oiRHV?lQ8B7ok^k^oooo
oom4A4@00_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool02oooool01OmEEEGoMgMgoooooonHV9So8B4Q00Wooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`05ooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B403?ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg02Cooooo000Qooooo`Ko00000_ooool5o`0000[ooooo00?o0000ooooooooool03_oo
ool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h08_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo01Sooooo00?oV9RHob4Q8Oo^k^h00oooool00ol0003oooooooooo`0Nooooo`Go00005?oo
ool00ol0003oooooooooo`0;ooooo`05o`000?ooooooooooooooool000002Oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`00000;ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`05
oa0@4?ooooooooooooooool@41009?ooool002Wooooo00CoA4A4omgMgOoooooo00002oooool00ol0
003oooooooooo`0Hooooo`03oiRHV?lQ8B7ok^k^027ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0Jooooo`03oiRHV?lQ8B7ok^k^00;ooooo00?o0000ooooooooool07_ooool01?m4
A4CogMgMooooool0000Fooooo`03o`000?oooooooooo00[ooooo00Go0000oiRHV?ooooooV9RHob4Q
8@09ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01Oooool01Olb<S;oV9RHoooo
oonHV9So<S8b00_ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Tooooo`00:Oooool01?oMgMgoEEEE
ooooool0000<ooooo`03o`000?oooooooooo01Sooooo00?oMgMgofIVI_ooool08?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo01_ooooo00?oMgMgofIVI_ooool00_ooool00ol0003o
ooooooooo`0Mooooo`04omgMgOmEEEGoooooo`0001Kooooo00?o0000ooooooooool02_ooool01Ol0
003oEEEEo`000?l@413oc<c<00Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`04
ooooo`05olc<c?l0003o0000o`000?o<c<`02oooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000002Cooooo
000Zooooo`03ogMgMoo<c<co000000cooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07?ooool01Ol0003ooooooooo
oooooooo0000023ooooo00?oMgMgolc<c?l000005_ooool00ol0003oooooooooo`0:ooooo`03oeEE
EOn7QhOooooo00[ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`04ooooo`05oa0@
4?nj^[[ooooookZj^_l@41002oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@02Cooooo000Zooooo`03
onk^k_m4A4Co000000gooooo00?o0000ooooooooool05?ooool01Ol0003o^[ZjoooooonHV9So410@
027ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Iooooo`05o`000?nj^[[ooooo
oiRHV?l@41000oooool00ol0003oooooooooo`0Nooooo`03onk^k_l0003o000001Kooooo00?o0000
ooooooooool02_ooool00ooMgMgo410@oiRHV00:ooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool01?ooool01Ol0003o^[Zjoooooonj^[[o000000_ooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`0Tooooo`00:oooool00omgMgOo0000ooooo`0=ooooo`03o`000?oooooooooo01?ooooo00Go
V9RHoa0@4?l0003o8B4Qolc<c00Qooooo`;o00001oooool00ol0003oooooooooo`0Iooooo`05oiRH
V?l@413o0000ob4Q8Oo<c<`01?ooool00ol0003oooooooooo`0Nooooo`;o00005_ooool00ol0003o
ooooooooo`0;ooooo`04olc<c?m4A4Co0000oa0@40Sooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`04ooooo`05ojVYZOl@413o0000oa0@4?nYZJT02oooool00ol0003oooooooooo`0?
ooooo`06o`000?oooooooooooeEEEOmVIVKo00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Co
oooo000kooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`0Sooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo033ooooo000looooo`03o`000?oooooooooo03Sooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo01kooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo033ooooo000l
ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo01Sooooo0_l00002ooooo`;o00004_ooool003gooooo00?o0000oooo
ooooool0=oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Gooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool06?ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgA;ooooo000nooooo`03o`000?oooooo
oooo03Kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo01Wooooo00CogMgMo`000?l@413oc<c<4oooool000goooooool0000jo`0000_ooooo00Cok^k^
ob4Q8Ol@413ok^k^4oooool001Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool01?l0003oooooooooool0
0006ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool00ol0003oooooo`00
0009ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool00ol0003oooooo`00
0008ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool2o`0000Wooooo00?o
0000ooooooooool01oooool2o`0000Sooooo00?o0000ooooooooool01oooool00ol0003oooooo`00
0007ooooo`03o`000?oooooooooo00Oooooo0_l00008ooooo`03o`000?oooooooooo013ooooo00Co
8B4QogMgMomgMgOo<S8b4oooool002Sooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06oooool00ol0003oooooo`00
000Gooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03oooool2o`0000;ooooo0_l0
000Booooo`00@?ooool00ol0003oooooooooo`0dooooo`05o`000?ooooooooooooooool00000:ooo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0_ooooo`00@Oooool00ol0003oooooooooo`0cooooo`05o`000?oooooo
ooooooooool00000:oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0_ooooo`00@_ooool00ol0003oooooooooo`0b
ooooo`05o`000?ooooooooooooooool00000;?ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Dooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0_ooooo`00@_ooool0
0ol0003oooooooooo`0booooo`04o`000?ooooooooooo`0002gooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0;ooo
ool004?ooooo00?o0000ooooooooool0<Oooool2o`000003ooooool0003ooooo02cooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool0;oooool004?ooooo00?o0000ooooooooool0<Oooool00ol0003oooooo`00000^oooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo02oooooo0014ooooo`03o`000?oooooooooo033ooooo00?o0000ooooool0
0000;oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0^ooooo`00AOooool00ol0003oooooooooo`0_ooooo`;o0000
<?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`0^ooooo`00AOooool00ol0003oooooooooo`0_ooooo`;o0000<?oo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0^ooooo`00A_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooo
oooo033ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool0;_ooool004Oooooo00?o0000ooooooooool0;?ooool3o`00
037ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool0;_ooool004Sooooo00?o0000ooooooooool0:_ooool00ol0003o
ooooo`00000booooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo02kooooo0019ooooo`03o`000?oooooooooo02Sooooo
00Co0000oooooooooooo0000<_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0^ooooo`00BOooool00ol0003ooooo
ooooo`0Xooooo`04o`000?ooooooooooo`0003?ooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0;_ooool004[ooooo
00?o0000ooooooooool09_ooool01Ol0003ooooooooooooooooo000003?ooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool0;_ooool004_ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Nooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool0;_ooool004cooooo00?o0000ooooooooool08_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0;Ooo
ool004cooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`03ooooo`;o0000<oooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`0]ooooo`00COooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0]ooooo`00C_ooool00ol0003o
ooooooooo`0Nooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0<_ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`0]ooooo`00Coooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo023ooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`0]ooooo`00Coooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0<_ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`0]ooooo`00D?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool0<oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`0]ooooo`00DOooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo00Wooooo0_l0000dooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02gooooo001Booooo`;o
00005_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo03?ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool0;Oooool005Cooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo03?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool0;Oooool005Gooooo0_l0000@ooooo`;o00003_oo
ool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool08_oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02gooooo001Gooooo`;o00003Oooool0
0ol0003oooooooooo`04ooooo`Co000000?o410@ooooooooool00oooool00ol0003oooooooooo`0d
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo02gooooo001Iooooo`;o00002?ooool3o`0000Wooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo02cooooo001Jooooo`Wo
00003?ooool00ol0003oooooooooo`05ooooo`?o0000=Oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0/ooooo`00
Koooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
;?ooool006oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0eooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo02cooooo001_ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0=_ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0/ooooo`00Koooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
03Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool0;?ooool006gooooo00?oEEEEofIVI_l000001oooool00ol0003o
ooooooooo`0fooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool09oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo02cooooo001gooooo`03o`000?oooooooooo03Kooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool07_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool0;?ooool007Oooooo0_l0000hooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool09oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01kooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo02_ooooo001g
ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0:oooool007Oooooo00?o0000oooo
ooooool0=oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0[ooooo`00Moooool00ol0003oooooooooo`0hooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo02_ooooo001gooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
8?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
:oooool007Oooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo02_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Zooooo`00Moooool2
o`0003_ooooo00Go0000ooooooooooooooooo`00000^ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool0:_ooool007Oooooo00?o0000ooooooooool0>oooool4o`0002oooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`0Zooooo`00Moooool00ol0003oooooooooo`1^oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool0:_ooool007Oooooo00?o0000oooooooo
ool0Koooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02?ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo02[ooooo001gooooo`03o`00
0?oooooooooo06oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Sooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Yooooo`00Mooo
ool00ol0003oooooooooo`1_ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0:Ooo
ool007Oooooo00?o0000ooooooooool0L?ooool01?l0003oooooooooool0000Wooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Yooooo`00Moooool2
o`00077ooooo1?l0000Wooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`0Yooooo`00Moooool00ol0003oooooooooo`2Looooo`05o`000?oooooooooo
ooooool000008Oooool00ol0003oooooooooo`0Yooooo`00Moooool00ol0003oooooooooo`2Loooo
o`04o`000?ooooooooooo`0002;ooooo00?o0000ooooooooool0:Oooool007Oooooo00?o0000oooo
ooooool0W?ooool01?l0003oooooooooool0000Rooooo`03o`000?oooooooooo02Wooooo001goooo
o`03o`000?oooooooooo09gooooo0_l0000Tooooo`03o`000?oooooooooo02Sooooo001gooooo`03
o`000?oooooooooo0<Cooooo00?o0000ooooooooool09oooool007Oooooo0_l0003_ooooo`00Mooo
ool00ol0003oooooooooo`3^ooooo`00Moooool00ol0003oooooooooo`3^ooooo`00Moooool00ol0
003oooooooooo`3^ooooo`00K?ooool5o`0000Kooooo00?o0000ooooooooool0k_ooool006cooooo
00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo0>kooooo001]ooooo`03oiRH
V?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0k_ooool006kooooo00?oV9RHob4Q8Oo^k^h01_oo
ool3o`000>kooooo001_ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0k_ooool0
073ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3^ooooo`00K?ooool01Ol0003o
^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0k_ooool006cooooo00GoV9RHoa0@4?l0
003o8B4Qolc<c006ooooo`03o`000?oooooooooo0>kooooo001gooooo`03o`000?oooooooooo0>ko
oooo001gooooo`;o0000koooool007Oooooo00?o0000ooooooooool0k_ooool007Oooooo00?o0000
ooooooooool0k_ooool007Oooooo00?o0000ooooooooool0k_ooool007Oooooo00?o0000oooooooo
ool0k_ooool007Oooooo00?o0000ooooooooool0k_ooool007Oooooo0_l0003_ooooo`00Moooool0
0ol0003oooooooooo`3^ooooo`00Moooool00ol0003oooooooooo`3^ooooo`00Moooool00ol0003o
ooooooooo`3^ooooo`00Moooool00ol0003oooooooooo`3^ooooo`00Moooool00ol0003ooooooooo
o`3^ooooo`00Moooool00ol0003oooooooooo`3^ooooo`00Moooool2o`000>oooooo001gooooo`03
o`000?oooooooooo0>kooooo001gooooo`03o`000?oooooooooo0>kooooo001gooooo`03o`000?oo
oooooooo0>kooooo001gooooo`03o`000?oooooooooo0>kooooo001gooooo`03o`000?oooooooooo
0>kooooo001gooooo`;o0000koooool007Oooooo00?o0000ooooooooool0k_ooool007Oooooo00?o
0000ooooooooool0k_ooool007Oooooo00?o0000ooooooooool0k_ooool006cooooo00GoV9RHoa0@
4?l0003o<S8bolc<c006ooooo`03o`000?oooooooooo0>kooooo001/ooooo`05oa0@4?nj^[[ooooo
ogMgMolb<S801_ooool00ol0003oooooooooo`3^ooooo`00L?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo0>kooooo001_ooooo`03ojVYZOl@413ooooo00Gooooo0ol0003^ooooo`00
K_ooool00ol@413o0000okZj^P3gooooo`00Koooool00onj^[[o8B4Qooooo`3fooooo`00K?ooool0
1Ol@413oV9RHoooooonj^[[o00000?Oooooo001/ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0mooo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool006Gooooo0_l0000;ooooo`03o`000?nj^[[ooooo00cooooo00?o0000okZj^_ooool03?ooool2
o`000=Kooooo001Uooooo`03o`000?oooooooooo00[ooooo0_lb<S8=ooooo`;o<S8b3_ooool00ol0
003oooooooooo`3Dooooo`00F_ooool5o`0000Kooooo00Co0000oooooooooooooooo0_l00002oooo
o`;o00000oooool00on7QhOo0000okZj^P03ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01?ooool0
0on7QhOo0000okZj^P04ooooo`05oiRHV?l0003o0000odA4A?nj^[X01?ooool00ol0003ooooooooo
o`3Dooooo`00F_ooool2ogMgM`;ooooo00?o0000ooooooooool01?ooool02_l0003ooooooooooooo
ooook^k^ob4Q8On7QhOo^[Zjo`000?oMgMd3ooooo`03olc<c?l0003o410@00?ooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`04ooooo`03olc<c?l0003o410@00Cooooo00Go410@okZj^_o^k^koMgMgoa0@
4004ooooo`03o`000?oooooooooo0=Cooooo001Kooooo`03oeEEEOnHV9Sooooo00Oooooo00?o0000
ooooooooool00_ooool01?oMgMgo0000oa0@4?o<c<`:ooooo`05oa0@4?ooooooooooooooool@4100
2oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0=Cooooo001Looooo`03oeEEEOnH
V9Sooooo00Kooooo00?o0000ooooooooool00_ooool01?o^k^ko8B4Qoa0@4?o^k^h:ooooo`05o`00
0?ooooooooooooooool000002oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0=Co
oooo001Jooooo`05o`000?oooooooooooc8b<_n7QhL01_ooool00ol0003oooooooooo`02ooooo`04
ob4Q8OmgMgOoMgMgoc8b<P[ooooo00Go0000ooooooooooooooooo`00000;ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool0e?ooool005[ooooo1Ol00006ooooo`04o`000?oooooooooo
ooooo`;o00000_ooool2o`0000Wooooo00Go410@oooooooooooooooooa0@4009ooooo`03oa0@4?l0
003o000000?o00001Oooool00ol0003oooooooooo`3Dooooo`00IOooool00ol0003oooooooooo`0@
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo0=Cooooo001Uooooo`;o00004Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00_ooooo00?o
0000ooooooooool01Oooool2o`000=Kooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-6.04357, -3.17494, \
0.0630624, 0.0388712}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.34127 0.0634921 0.309017 0.103006 [
[.0873 .29652 -6 -9 ]
[.0873 .29652 6 0 ]
[.21429 .29652 -6 -9 ]
[.21429 .29652 6 0 ]
[.46825 .29652 -3 -9 ]
[.46825 .29652 3 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.72222 .29652 -3 -9 ]
[.72222 .29652 3 0 ]
[.84921 .29652 -3 -9 ]
[.84921 .29652 3 0 ]
[.97619 .29652 -6 -9 ]
[.97619 .29652 6 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.32877 0 -12 -4.5 ]
[.32877 0 0 4.5 ]
[.32877 .10301 -12 -4.5 ]
[.32877 .10301 0 4.5 ]
[.32877 .20601 -12 -4.5 ]
[.32877 .20601 0 4.5 ]
[.32877 .41202 -6 -4.5 ]
[.32877 .41202 0 4.5 ]
[.32877 .51503 -6 -4.5 ]
[.32877 .51503 0 4.5 ]
[.32877 .61803 -6 -4.5 ]
[.32877 .61803 0 4.5 ]
[.34127 .64303 -26 0 ]
[.34127 .64303 26 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.0873 .30902 m
.0873 .31527 L
s
[(-4)] .0873 .29652 0 1 Mshowa
.21429 .30902 m
.21429 .31527 L
s
[(-2)] .21429 .29652 0 1 Mshowa
.46825 .30902 m
.46825 .31527 L
s
[(2)] .46825 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(4)] .59524 .29652 0 1 Mshowa
.72222 .30902 m
.72222 .31527 L
s
[(6)] .72222 .29652 0 1 Mshowa
.84921 .30902 m
.84921 .31527 L
s
[(8)] .84921 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(10)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.11905 .30902 m
.11905 .31277 L
s
.15079 .30902 m
.15079 .31277 L
s
.18254 .30902 m
.18254 .31277 L
s
.24603 .30902 m
.24603 .31277 L
s
.27778 .30902 m
.27778 .31277 L
s
.30952 .30902 m
.30952 .31277 L
s
.37302 .30902 m
.37302 .31277 L
s
.40476 .30902 m
.40476 .31277 L
s
.43651 .30902 m
.43651 .31277 L
s
.5 .30902 m
.5 .31277 L
s
.53175 .30902 m
.53175 .31277 L
s
.56349 .30902 m
.56349 .31277 L
s
.62698 .30902 m
.62698 .31277 L
s
.65873 .30902 m
.65873 .31277 L
s
.69048 .30902 m
.69048 .31277 L
s
.75397 .30902 m
.75397 .31277 L
s
.78571 .30902 m
.78571 .31277 L
s
.81746 .30902 m
.81746 .31277 L
s
.88095 .30902 m
.88095 .31277 L
s
.9127 .30902 m
.9127 .31277 L
s
.94444 .30902 m
.94444 .31277 L
s
.05556 .30902 m
.05556 .31277 L
s
.02381 .30902 m
.02381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.34127 0 m
.34752 0 L
s
[(-3)] .32877 0 1 0 Mshowa
.34127 .10301 m
.34752 .10301 L
s
[(-2)] .32877 .10301 1 0 Mshowa
.34127 .20601 m
.34752 .20601 L
s
[(-1)] .32877 .20601 1 0 Mshowa
.34127 .41202 m
.34752 .41202 L
s
[(1)] .32877 .41202 1 0 Mshowa
.34127 .51503 m
.34752 .51503 L
s
[(2)] .32877 .51503 1 0 Mshowa
.34127 .61803 m
.34752 .61803 L
s
[(3)] .32877 .61803 1 0 Mshowa
.125 Mabswid
.34127 .0206 m
.34502 .0206 L
s
.34127 .0412 m
.34502 .0412 L
s
.34127 .0618 m
.34502 .0618 L
s
.34127 .0824 m
.34502 .0824 L
s
.34127 .12361 m
.34502 .12361 L
s
.34127 .14421 m
.34502 .14421 L
s
.34127 .16481 m
.34502 .16481 L
s
.34127 .18541 m
.34502 .18541 L
s
.34127 .22661 m
.34502 .22661 L
s
.34127 .24721 m
.34502 .24721 L
s
.34127 .26781 m
.34502 .26781 L
s
.34127 .28842 m
.34502 .28842 L
s
.34127 .32962 m
.34502 .32962 L
s
.34127 .35022 m
.34502 .35022 L
s
.34127 .37082 m
.34502 .37082 L
s
.34127 .39142 m
.34502 .39142 L
s
.34127 .43262 m
.34502 .43262 L
s
.34127 .45322 m
.34502 .45322 L
s
.34127 .47383 m
.34502 .47383 L
s
.34127 .49443 m
.34502 .49443 L
s
.34127 .53563 m
.34502 .53563 L
s
.34127 .55623 m
.34502 .55623 L
s
.34127 .57683 m
.34502 .57683 L
s
.34127 .59743 m
.34502 .59743 L
s
.25 Mabswid
.34127 0 m
.34127 .61803 L
s
gsave
.34127 .64303 -87 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(z) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 13.000 moveto
(@) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
87.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
93.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(,) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
105.000 13.000 moveto
(D) show
111.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .2746 m
.04262 .24776 L
.06244 .22528 L
.07286 .21661 L
.07784 .21332 L
.08255 .21076 L
.08523 .20955 L
.08813 .20843 L
.09054 .20766 L
.0932 .20698 L
.09458 .2067 L
.09607 .20645 L
.09689 .20633 L
.09764 .20624 L
.09841 .20617 L
.09912 .20611 L
.09976 .20607 L
.10045 .20604 L
.10122 .20602 L
.10192 .20601 L
.10258 .20602 L
.10329 .20604 L
.10458 .2061 L
.10582 .20621 L
.10695 .20634 L
.1095 .20675 L
.11185 .20727 L
.11408 .2079 L
.11908 .20976 L
.12452 .21247 L
.13546 .22006 L
.14558 .22943 L
.16425 .2518 L
.18485 .28209 L
.22505 .34614 L
.24353 .37215 L
.254 .38465 L
.26374 .39445 L
.27343 .4022 L
.2784 .40535 L
.28378 .40809 L
.28674 .4093 L
.28947 .41022 L
.29207 .41092 L
.29341 .41121 L
.29484 .41148 L
.29613 .41167 L
.29731 .41181 L
.29849 .41192 L
.29962 .41198 L
Mistroke
.30092 .41202 L
.30214 .41202 L
.30283 .412 L
.30346 .41197 L
.30419 .41192 L
.30488 .41187 L
.30605 .41174 L
.3073 .41158 L
.30955 .41117 L
.31223 .41052 L
.31467 .40977 L
.31998 .40763 L
.325 .40498 L
.33386 .39884 L
.34348 .39087 L
.34841 .38686 L
.35371 .38143 L
.3633 .36862 L
.37329 .35123 L
.38432 .3277 L
.404 .27762 L
.42551 .22165 L
.43546 .20021 L
.44092 .19069 L
.44608 .18357 L
.44841 .181 L
.45089 .17876 L
.45218 .1778 L
.4536 .17691 L
.4549 .17625 L
.45609 .17579 L
.45726 .17546 L
.45836 .17527 L
.45953 .17519 L
.46079 .17526 L
.4619 .17545 L
.46307 .17578 L
.46408 .17617 L
.46519 .17672 L
.46753 .17829 L
.47009 .18066 L
.47277 .18385 L
.47526 .1875 L
.48451 .20655 L
.48979 .22114 L
.49458 .23654 L
.50536 .27716 L
.52613 .36633 L
.53526 .40247 L
.5401 .41915 L
Mistroke
.54531 .43441 L
.55034 .44604 L
.55273 .45035 L
.55494 .4536 L
.55716 .4561 L
.55833 .45711 L
.55957 .45794 L
.56076 .4585 L
.56188 .45882 L
.56288 .45893 L
.56397 .45885 L
.5652 .45852 L
.56636 .45798 L
.56762 .45712 L
.56898 .4559 L
.57175 .45244 L
.57427 .44814 L
.57913 .43684 L
.58374 .42266 L
.5934 .3832 L
.60366 .33066 L
.62209 .23001 L
.63147 .18776 L
.63674 .16971 L
.63925 .16291 L
.64158 .15771 L
.64363 .15407 L
.64583 .15119 L
.64709 .15003 L
.64827 .14927 L
.64933 .14886 L
.65048 .14871 L
.65161 .14887 L
.65286 .14938 L
.65415 .15031 L
.65536 .15154 L
.65753 .1546 L
.65986 .1591 L
.66241 .16547 L
.66512 .17383 L
.67 .19276 L
.68105 .25105 L
.70116 .38036 L
.71148 .43608 L
.71431 .44796 L
.71729 .45851 L
.71983 .46577 L
.72127 .46911 L
.72262 .47175 L
.72389 .47376 L
Mistroke
.72456 .47463 L
.72527 .47542 L
.72652 .47645 L
.72767 .477 L
.72831 .47713 L
.729 .47714 L
.73024 .47681 L
.731 .47637 L
.73172 .4758 L
.73307 .47432 L
.73424 .47259 L
.73549 .47031 L
.73773 .46507 L
.74039 .45696 L
.74281 .44792 L
.75283 .39537 L
.76205 .33162 L
.77281 .25188 L
.77807 .21586 L
.78287 .18703 L
.78721 .1654 L
.78951 .15605 L
.79194 .14784 L
.79318 .1444 L
.79454 .14117 L
.79579 .13876 L
.79694 .13701 L
.79812 .1357 L
.79939 .13483 L
.8005 .13454 L
.80168 .13471 L
.80297 .13546 L
.80415 .13667 L
.8048 .13756 L
.80551 .13868 L
.80679 .14118 L
.80926 .14763 L
.81155 .15542 L
.81679 .17964 L
.82234 .21367 L
.84213 .36992 L
.85078 .43167 L
.85568 .45854 L
.85801 .46868 L
.86022 .47646 L
.86143 .47998 L
.86275 .48315 L
.86394 .48544 L
.86504 .48703 L
.86624 .48821 L
Mistroke
.86755 .48882 L
.86821 .48887 L
.86891 .48871 L
.87019 .48791 L
.87141 .48651 L
.87209 .48544 L
.87273 .48428 L
.87514 .4784 L
.87733 .47104 L
.87965 .46121 L
.88478 .43274 L
.88959 .39877 L
.90054 .30525 L
.91039 .21992 L
.91576 .18056 L
.91838 .16444 L
.92076 .15189 L
.92281 .14279 L
.92504 .1349 L
.92626 .13148 L
.92739 .12891 L
.92846 .127 L
.9296 .12556 L
.93075 .12472 L
.93198 .12451 L
.93315 .12496 L
.93421 .12594 L
.93545 .12775 L
.93681 .13055 L
.93809 .13398 L
.93927 .13782 L
.94362 .15719 L
.94831 .18657 L
.95681 .25687 L
.97619 .43294 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{0.75, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00K?ooool01OnHV9So410@o`000?lb<S;oc<c<0?Oo
oooo001/ooooo`05oa0@4?nj^[[oooooogMgMolb<S80moooool006Cooooo1_l00006ooooo`03o`00
0?oooooooooo0?Gooooo001_ooooo`03ojVYZOl@413ooooo00Gooooo0ol0003^ooooo`00K_ooool0
0ol@413o0000okZj^P06ooooo`03o`000?oooooooooo0>kooooo001_ooooo`03okZj^_lQ8B7ooooo
00Gooooo00?o0000ooooooooool0k_ooool006cooooo00Go410@oiRHV?oooooo^[Zjo`000006oooo
o`03o`000?oooooooooo0>kooooo001/ooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0
003oooooooooo`3^ooooo`00Moooool00ol0003oooooooooo`3^ooooo`00Moooool2o`000>oooooo
001gooooo`03o`000?oooooooooo0>kooooo001gooooo`03o`000?oooooooooo0>kooooo001goooo
o`03o`000?oooooooooo0>kooooo001gooooo`03o`000?oooooooooo0>kooooo001gooooo`03o`00
0?oooooooooo0>kooooo001gooooo`03o`000?oooooooooo0>kooooo001gooooo`;o0000koooool0
07Oooooo00?o0000ooooooooool0k_ooool007Oooooo00?o0000ooooooooool0k_ooool007Oooooo
00?o0000ooooooooool0k_ooool007Oooooo00?o0000ooooooooool0k_ooool007Oooooo00?o0000
ooooooooool0k_ooool007Oooooo0_l0003_ooooo`00Moooool00ol0003oooooooooo`3^ooooo`00
Moooool00ol0003oooooooooo`3^ooooo`00Moooool00ol0003oooooooooo`3^ooooo`00Moooool0
0ol0003oooooooooo`3^ooooo`00Moooool00ol0003oooooooooo`3^ooooo`00Moooool2o`000>oo
oooo001gooooo`03o`000?oooooooooo0>kooooo001gooooo`03o`000?oooooooooo0>kooooo001g
ooooo`03o`000?oooooooooo0>kooooo001/ooooo`Go00001_ooool00ol0003oooooooooo`3^oooo
o`00K?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0k_ooool006Co
oooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0k_ooool006kooooo
00?oV9RHob4Q8Oo^k^h01_ooool3o`000>kooooo001_ooooo`03ogMgMomVIVKooooo00Gooooo00?o
0000ooooooooool0k_ooool0073ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3^
ooooo`00K?ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0k_ooool0
06cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0>kooooo001goooo
o`03o`000?oooooooooo0>kooooo001gooooo`;o0000koooool007Oooooo00?o0000ooooooooool0
]Oooool2o`0003Oooooo001gooooo`03o`000?oooooooooo0;Cooooo00Co0000oooooooooooo0000
=_ooool007Oooooo00?o0000ooooooooool0]?ooool01?l0003oooooooooool0000fooooo`00Mooo
ool00ol0003oooooooooo`2<ooooo`?o00009Oooool01Ol0003ooooooooooooooooo000003Gooooo
001gooooo`03o`000?oooooooooo08_ooooo0_l000000ooooooo0000ooooo`0Tooooo`05o`000?oo
ooooooooooooool00000=Oooool007Oooooo00?o0000ooooooooool0Roooool01Ol0003ooooooooo
oooooooo000002?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0cooooo`00Mooo
ool2o`0008_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool0<oooool007Oooooo00?o0000ooooooooool0GOooool3
o`0002[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool0<oooool007Oooooo00?o0000ooooooooool0G?ooool2o`00
0003ooooool0003ooooo02Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Poooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0<_ooool007Oooooo00?o0000oooooooo
ool0G?ooool01Ol0003ooooooooooooooooo000002Sooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0<_ooool007Oo
oooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0<_ooool007Oooooo00?o0000ooooooooool0Foooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0Nooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0<_ooool007Oooooo0_l0
001Kooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0booooo`00Moooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0aooooo`00Moooool00ol0003oooooooooo`1Joooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0aoooo
o`00Moooool00ol0003oooooooooo`0Rooooo`;o0000=_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0<Oooool007Oooooo00?o0000ooooooooool0
8?ooool6o`0003?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Sooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo037ooooo001gooooo`03o`000?oooooooooo01oooooo0_l00005ooooo`03o`000?oo
oooooooo033ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Rooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo037ooooo001gooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08Oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0`ooooo`00Moooool2o`0001kooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0^ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool08Oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0`ooooo`00Moooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo023o
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0<?ooool007Oooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo033ooooo001gooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0`ooooo`00KOooool4o`000003oa0@4?oooooo
oooo00?ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo02_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo033ooooo001_ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo033ooooo000Zooooo`Oo0000<oooool6o`0000Go
oooo00?o0000ooooooooool01Oooool3o`0001[ooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0Zooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool07_ooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0_ooooo`009oooool3o`0000Kooooo1?l0000kooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02[ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02oooooo
000Uooooo`?o00003?ooool2o`0003Wooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0;oooool002?ooooo0_l0000A
ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0;oooool002;ooooo00?o0000oooo
ooooool04_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo02Sooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02oooooo000Qooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool0<_ooool00omEEEGoIVIVo`000007ooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0_ooooo`00
8?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo03_ooooo0_l0000Iooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo01gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool0;oooool0023ooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0_ooooo`007oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo03[ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo02oooooo000Nooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0>Oooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool09Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0;oooool001go
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0_ooooo`007?ooool00ol0003ooooo
ooooo`0Nooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo02kooooo000Kooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool0=_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool0;_ooool001[ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`0e
ooooo`;o00005_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo02?ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02kooooo000Joooo
o`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool0;_ooool001Wooooo00?o0000oooooooo
ool09?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo01Cooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0^ooooo`006?ooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo03?ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo02;ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo02kooooo000Gooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0<_oo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool08Ooo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0;_oo
ool001Oooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0booooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0^ooooo`005_ooool00ol0
003oooooooooo`0Booooo`;o000000?o410@ooooooooool04oooool00ol0003oooooooooo`0;oooo
o`Go00008Oooool2o`0001?ooooo00?o0000ooooooooool03Oooool5o`0000Wooooo00?o0000oooo
ooooool06Oooool2o`000003oa0@4?oooooooooo00;ooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`06ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`03Oooool00ol0003oooooooooo`0?
ooooo`09o`000?ooooooooooooooooo<c<co8B4Qo`000?lQ8B7oc<c<00oooooo00?o0000oooooooo
ool03Oooool5o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^hTooooo`005Oooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool02oooool0
1OnHV9So8B4Qonk^k_ooooooA4A4027ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0=ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@02Oooool00ol0003oooooooooo`0Jooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`06ooooo`05oeEE
EOmgMgOooooooiRHV?lQ8B403Oooool00ol0003oooooooooo`0@ooooo`08o`000?ooooooooooob4Q
8OnHV9SooooooiRHV?lQ8B4?ooooo`03o`000?oooooooooo00gooooo00Co0000oooooooooooo0000
1?ooool01OmgMgOoV9RHoooooonHV9SoMgMg02Cooooo000Dooooo`03o`000?oooooooooo00[ooooo
1_l00002ooooo`Go00005_ooool00ol0003oooooooooo`02ooooo`Ko00000oooool00onHV9So8B4Q
onk^kP0Rooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03_ooool00onHV9So8B4Q
onk^kP0;ooooo`03o`000?oooooooooo01Kooooo1Ol00004ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo000000gooooo00?o0000oooooooo
ool04?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooo`000004ooooo`05oa0@4?ooooooooooooooool@41009?ooool0
02Wooooo00CoA4A4omgMgOoooooo00006?ooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7o
k^k^027ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@ooooo`03oiRHV?lQ8B7o
k^k^00[ooooo00?o0000ooooooooool05_ooool01?m4A4CogMgMooooool00004ooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool01_ooool01Ol0003oV9RHoooooonHV9So8B4Q00gooooo
00?o0000ooooooooool04?ooool02?l0003ooooooooooolb<S;oV9RHoooooonHV9So<S8b3oooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooo000000Cooooo00Go0000ooooooooooooooooo`00
000Tooooo`00:Oooool01?oMgMgoEEEEooooool0000Hooooo`03o`000?oooooooooo00cooooo00?o
MgMgofIVI_ooool08?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o
MgMgofIVI_ooool02Oooool00ol0003oooooooooo`0Fooooo`04omgMgOmEEEGoooooo`0000Cooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`06ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`03Oooool00ol0003oooooooooo`0@ooooo`04o`000?ooooooooooolc<c0?o000000?oc<c<oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo000000Cooooo00Go0000oooo
ooooooooooooo`00000Tooooo`00:_ooool00omgMgOoc<c<o`00000Iooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Gooooo`03ogMgMoo<c<co0000
00Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`05ooooo`03oeEEEOn7QhOooooo
00oooooo00?o0000ooooooooool04?ooool02?l0003oooooooooool@413o^[Zjoooooonj^[[o410@
3oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo000000Cooooo00Go410@oooooooooooo
oooooa0@400Tooooo`00:_ooool00oo^k^koA4A4o`00000Iooooo`03o`000?oooooooooo00Sooooo
00Go0000okZj^_ooooooV9RHoa0@400Qooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool03oooool01Ol0003o^[ZjoooooonHV9So410@00_ooooo00?o0000ooooooooool05_ooool00oo^
k^koA4A4o`000004ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01Oooool00ooM
gMgo410@oiRHV00?ooooo`03o`000?oooooooooo013ooooo00So0000oooooooooooo0000okZj^_oo
oooo^[Zjo`0000oooooo00?o0000ooooooooool03_ooool00ol0003oooooo`000004ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL09?ooool002_ooooo00?oMgMgo`000?ooool06Oooool00ol0003ooooo
ooooo`07ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`08Oooool2o`00017ooooo00?o0000oooooooo
ool03oooool01OnHV9So410@o`000?lQ8B7oc<c<00_ooooo00?o0000ooooooooool05oooool00omg
MgOo0000ooooo`03ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool01_ooool01?o<
c<coA4A4o`000?l@410=ooooo`03o`000?oooooooooo013ooooo00So0000ooooooooooooZJVYoa0@
4?l0003o410@ojVYZ@oooooo00?o0000ooooooooool03_ooool00ol0003oIVIVo`000004ooooo`05
onk^k_lb<S;o0000oc8b<_o^k^h09?ooool004Sooooo00?o0000ooooooooool0;?ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0;Oooool004Sooooo
00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo023ooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0;Oooool004Wooooo00?o0000ooooooooool0:oooool00ol0003ooooooooo
o`0?ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool05?ooool2o`0000;ooooo0_l0
000Booooo`00B_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00kooooo00?o0000
ooooooooool08_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0Dooooo`06onk^k_lQ8B7oQhN7okZj^_l0003ogMgM
4_ooool004[ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo02;ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool05Oooool01?oMgMgo0000oa0@4?o<c<`Cooooo`003Ooo
ooooo`0003[o00002oooool01?o^k^ko8B4Qoa0@4?o^k^hCooooo`005?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool01Ol0003ooooooooo
oooooooo000000Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`05o`00
0?ooooooooooooooool000002Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oo
oooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01oooool01?l0003oooooooooool00005ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00Go0000
ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00ooo
ool01Ol0003ooooooooooooooooo000000Wooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo013ooooo00Co8B4QogMgMomgMgOo<S8b4oooool002Sooooo
00?o0000ooooooooool08Oooool01Ol0003ooooooooooooooooo000002Kooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool05oooool01?l0003oooooooooool0000Iooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0Cooooo`05o`000?ooooooooooooooool000003oooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03oooool2
o`0000;ooooo0_l0000Booooo`00COooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0/ooooo`00COooool00ol0003o
ooooooooo`0Wooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0/ooooo`00C_ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0[ooooo`00Coooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0[ooooo`00Coooool00ol0003oooooooooo`0Uooooo`;o00003?ooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo02_ooooo001@ooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02_ooooo001Aooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Xooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Booooo`03
o`000?oooooooooo02_ooooo001Aooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo02_ooooo001Booooo`03o`000?oo
oooooooo02;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo02_ooooo001Cooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo02[ooooo001Cooooo`03o`000?oooooooooo
027ooooo0_l00008ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0:_ooool005Co
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo02co
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool0:_ooool005Gooooo00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0:_ooool005Kooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02gooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool0:_ooool005Kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0:_ooool005Oooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02oooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool0:_ooool005Sooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo033ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool0:_ooool005Wooooo00?o0000ooooooooool0
6oooool2o`0000Gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo01kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Yooooo`00FOoo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0<_oo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool05_oo
ool00ol0003oooooooooo`0Yooooo`00F_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Yooooo`00Foooool00ol0
003oooooooooo`0Iooooo`05o`000?ooooooooooooooool00000=_ooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Y
ooooo`00G?ooool00ol0003oooooooooo`0Hooooo`05o`000?ooooooooooooooool00000=oooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`0Yooooo`00GOooool00ol0003oooooooooo`0Gooooo`04o`000?oooooo0000
o`0003Sooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool0:Oooool005kooooo00?o0000ooooooooool05_ooool2o`00
03[ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool0:Oooool005oooooo0_l0000Eooooo`;o0000>oooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`0Yooooo`00HOooool00ol0003oooooooooo`0@ooooo`;o000000?oooooo`000?ooool0
>oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`0Xooooo`00H_ooool2o`0000oooooo00Go0000oooooooooooooooo
o`00000looooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool08Oooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo02Sooooo001Tooooo`03o`000?oooooooooo00Kooooo1?l0
00000ol@413o0000ooooo`03ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0:?oo
ool006Gooooo00?o0000ooooooooool01oooool3o`0000Gooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`0Xooooo`00I_ooool:o`0000Oooooo0ol0000jooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
02Sooooo001_ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0>oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`0Xooooo`00Koooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03_ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool0:?ooool006oooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0kooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo02Sooooo001_ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`0Wooooo`00KOooool00omEEEGoIVIVo`000007oooo
o`03o`000?oooooooooo03cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool09oooool007Oooooo00?o0000oooooooo
ool0??ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`0Wooooo`00Moooool2o`0003kooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
9oooool007Oooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool0A?ooool007Oooooo00?o0000ooooooooool0?_ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0A?ooool0
07Oooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0AOooool007Oooooo00?o0000ooooooooool0?oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0AOooool007Oooooo
00?o0000ooooooooool0?oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo02Wooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool0AOooool007Oooooo0_l00011ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool0:_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`15ooooo`00Moooool00ol0003oooooooooo`11
ooooo`04o`000?ooooooooooo`0002kooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0AOooool007Oooooo00?o0000
ooooooooool0@Oooool4o`0002kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0A_ooool007Oooooo00?o0000oooo
ooooool0Loooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02;ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`16ooooo`00Moooool00ol0003oooooooooo`1cooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo04Kooooo001gooooo`03o`000?oooooooooo07Cooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
A_ooool007Oooooo00?o0000ooooooooool0M?ooool01Ol0003ooooooooooooooooo000002Kooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`16ooooo`00Moooool2o`0007Kooooo1?l0
000Vooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0A_ooool007Oooooo00?o0000
ooooooooool0M_ooool2o`0002Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`17
ooooo`00Moooool00ol0003oooooooooo`2Pooooo`05o`000?ooooooooooooooool00000BOooool0
07Oooooo00?o0000ooooooooool0X?ooool01?l0003oooooooooool0001:ooooo`00Moooool00ol0
003oooooooooo`2Qooooo`?o0000B_ooool007Oooooo00?o0000ooooooooool0k_ooool007Oooooo
0_l0003_ooooo`00Moooool00ol0003oooooooooo`3^ooooo`00Moooool00ol0003oooooooooo`3^
ooooo`00Moooool00ol0003oooooooooo`3^ooooo`00K?ooool5o`0000Kooooo00?o0000oooooooo
ool0k_ooool006cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo0>ko
oooo001]ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool0k_ooool006kooooo00?o
V9RHob4Q8Oo^k^h01_ooool3o`000>kooooo001_ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000
ooooooooool0k_ooool0073ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`3^oooo
o`00K?ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool0k_ooool006co
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo0>kooooo001gooooo`03
o`000?oooooooooo0>kooooo001gooooo`;o0000koooool007Oooooo00?o0000ooooooooool0k_oo
ool007Oooooo00?o0000ooooooooool0k_ooool007Oooooo00?o0000ooooooooool0k_ooool007Oo
oooo00?o0000ooooooooool0k_ooool007Oooooo00?o0000ooooooooool0k_ooool007Oooooo0_l0
003_ooooo`00Moooool00ol0003oooooooooo`3^ooooo`00Moooool00ol0003oooooooooo`3^oooo
o`00Moooool00ol0003oooooooooo`3^ooooo`00Moooool00ol0003oooooooooo`3^ooooo`00Mooo
ool00ol0003oooooooooo`3^ooooo`00Moooool00ol0003oooooooooo`3^ooooo`00Moooool2o`00
0>oooooo001gooooo`03o`000?oooooooooo0>kooooo001gooooo`03o`000?oooooooooo0>kooooo
001gooooo`03o`000?oooooooooo0>kooooo001gooooo`03o`000?oooooooooo0>kooooo001goooo
o`03o`000?oooooooooo0>kooooo001gooooo`;o0000koooool007Oooooo00?o0000ooooooooool0
k_ooool007Oooooo00?o0000ooooooooool0k_ooool007Oooooo00?o0000ooooooooool0k_ooool0
06cooooo00GoV9RHoa0@4?l0003o<S8bolc<c006ooooo`03o`000?oooooooooo0>kooooo001/oooo
o`05oa0@4?nj^[[oooooogMgMolb<S801_ooool00ol0003oooooooooo`3^ooooo`00L?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo0>kooooo001_ooooo`03ojVYZOl@413ooooo00Go
oooo0ol0003^ooooo`00K_ooool00ol@413o0000okZj^P3gooooo`00Koooool00onj^[[o8B4Qoooo
o`3fooooo`00K?ooool01Ol@413oV9RHoooooonj^[[o00000?Oooooo001/ooooo`05ojVYZOl@413o
0000oa0@4?nYZJT0moooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool006Gooooo0_l0000;ooooo`03o`000?nj^[[ooooo00cooooo00?o0000
okZj^_ooool03?ooool2o`000=Kooooo001Uooooo`03o`000?oooooooooo00[ooooo0_lb<S8=oooo
o`;o<S8b3_ooool00ol0003oooooooooo`3Dooooo`00F_ooool5o`0000Kooooo00Co0000oooooooo
oooooooo0_l00002ooooo`;o00000oooool00on7QhOo0000okZj^P03ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h01?ooool00on7QhOo0000okZj^P04ooooo`05oiRHV?l0003o0000odA4A?nj^[X01?oo
ool00ol0003oooooooooo`3Dooooo`00F_ooool2ogMgM`;ooooo00?o0000ooooooooool01?ooool0
2_l0003oooooooooooooooook^k^ob4Q8On7QhOo^[Zjo`000?oMgMd3ooooo`03olc<c?l0003o410@
00?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`04ooooo`03olc<c?l0003o410@00Cooooo00Go410@
okZj^_o^k^koMgMgoa0@4004ooooo`03o`000?oooooooooo0=Cooooo001Kooooo`03oeEEEOnHV9So
oooo00Oooooo00?o0000ooooooooool00_ooool01?oMgMgo0000oa0@4?o<c<`:ooooo`05oa0@4?oo
ooooooooooooool@41002oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo0=Cooooo
001Looooo`03oeEEEOnHV9Sooooo00Kooooo00?o0000ooooooooool00_ooool01?o^k^ko8B4Qoa0@
4?o^k^h:ooooo`05o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo0=Cooooo001Jooooo`05o`000?oooooooooooc8b<_n7QhL01_ooool00ol0003o
ooooooooo`02ooooo`04ob4Q8OmgMgOoMgMgoc8b<P[ooooo00Go0000ooooooooooooooooo`00000;
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0e?ooool005[ooooo1Ol00006oooo
o`04o`000?ooooooooooooooo`;o00000_ooool2o`0000Wooooo00Go410@oooooooooooooooooa0@
4009ooooo`03oa0@4?l0003o000000?o00001Oooool00ol0003oooooooooo`3Dooooo`00IOooool0
0ol0003oooooooooo`0@ooooo`05ogMgMonHV9SooooooiRHV?mgMgL02oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo0=Cooooo001Uooooo`;o00004Oooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00_ooooo00?o0000ooooooooool01Oooool2o`000=Kooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-6.04357, -3.17494, \
0.0630624, 0.0388712}}]
}, Closed]]
}, Open  ]],

Cell[TextData[{
  "As the waves move toward the beach, they slow down [",
  Cell[BoxData[
      \(TraditionalForm\`c(x)\)]],
  " decreases as the depth decreases]. As the waves slow, the wavefronts pile \
up, and this results in a shortening of the ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  "-wavelength, ",
  Cell[BoxData[
      \(TraditionalForm\`2\ \[Pi]/k\_x\)]],
  "  (that is,  ",
  Cell[BoxData[
      \(TraditionalForm\`k\_x\)]],
  " increases). However, unlike the waves on a nonuniform string, the \
amplitude of these water waves ",
  StyleBox["increases",
    FontSlant->"Italic"],
  " as the waves slow. Eventually, if the amplitude becomes sufficiently \
large, nonlinear effects become important : the waves break. This will be \
discussed in Chapter ",
  ButtonBox["7",
    ButtonData:>{"Chapter7.nb", None},
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text"],

Cell[TextData[{
  "\tWhile ",
  Cell[BoxData[
      \(TraditionalForm\`k\_x\)]],
  " increases as ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(x\)\(\ \)\)\)]],
  " increases, ",
  Cell[BoxData[
      \(TraditionalForm\`k\_y\)]],
  " remains constant, and this implies that the wave vector ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["k",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox[\((k\_x, \ k\_y)\),
            FontWeight->"Plain"]}], TraditionalForm]]],
  " changes direction as the waves propagate, increasingly pointing in the ",
  Cell[BoxData[
      FormBox[Cell[TextData[Cell[BoxData[
            \(TraditionalForm\`x\)]]]], TraditionalForm]]],
  " direction as ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  "  increases. This is shown in Cell ",
  ButtonBox["5.25",
    ButtonData:>"Cell 5.25",
    ButtonStyle->"Hyperlink"],
  " using a contour plot."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(waves\  = \ 
        Table[ContourPlot[Re[z[x, y, t]], {x, \(-5\), 10}, {y, \(-5\), 10}, 
            PlotRange \[Rule] {\(-3\), 3}, 
            FrameLabel \[Rule] {"\<x\>", "\<y\>"}, 
            PlotPoints \[Rule] 100], {t, 0, 
            1.8  Pi/\[Omega],  .2  Pi/\[Omega]}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 5.25"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.339744 0.0641026 0.339744 0.0641026 [
[.08333 -0.0125 -6 -9 ]
[.08333 -0.0125 6 0 ]
[.21154 -0.0125 -6 -9 ]
[.21154 -0.0125 6 0 ]
[.33974 -0.0125 -3 -9 ]
[.33974 -0.0125 3 0 ]
[.46795 -0.0125 -3 -9 ]
[.46795 -0.0125 3 0 ]
[.59615 -0.0125 -3 -9 ]
[.59615 -0.0125 3 0 ]
[.72436 -0.0125 -3 -9 ]
[.72436 -0.0125 3 0 ]
[.85256 -0.0125 -3 -9 ]
[.85256 -0.0125 3 0 ]
[.98077 -0.0125 -6 -9 ]
[.98077 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5 -21 ]
[.5 -0.0125 5 -9 ]
[-0.0125 .08333 -12 -4.5 ]
[-0.0125 .08333 0 4.5 ]
[-0.0125 .21154 -12 -4.5 ]
[-0.0125 .21154 0 4.5 ]
[-0.0125 .33974 -6 -4.5 ]
[-0.0125 .33974 0 4.5 ]
[-0.0125 .46795 -6 -4.5 ]
[-0.0125 .46795 0 4.5 ]
[-0.0125 .59615 -6 -4.5 ]
[-0.0125 .59615 0 4.5 ]
[-0.0125 .72436 -6 -4.5 ]
[-0.0125 .72436 0 4.5 ]
[-0.0125 .85256 -6 -4.5 ]
[-0.0125 .85256 0 4.5 ]
[-0.0125 .98077 -12 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -24 -5 ]
[-0.01875 .5 -12 5 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08333 0 m
.08333 .00625 L
s
[(-4)] .08333 -0.0125 0 1 Mshowa
.21154 0 m
.21154 .00625 L
s
[(-2)] .21154 -0.0125 0 1 Mshowa
.33974 0 m
.33974 .00625 L
s
[(0)] .33974 -0.0125 0 1 Mshowa
.46795 0 m
.46795 .00625 L
s
[(2)] .46795 -0.0125 0 1 Mshowa
.59615 0 m
.59615 .00625 L
s
[(4)] .59615 -0.0125 0 1 Mshowa
.72436 0 m
.72436 .00625 L
s
[(6)] .72436 -0.0125 0 1 Mshowa
.85256 0 m
.85256 .00625 L
s
[(8)] .85256 -0.0125 0 1 Mshowa
.98077 0 m
.98077 .00625 L
s
[(10)] .98077 -0.0125 0 1 Mshowa
.125 Mabswid
.11538 0 m
.11538 .00375 L
s
.14744 0 m
.14744 .00375 L
s
.17949 0 m
.17949 .00375 L
s
.24359 0 m
.24359 .00375 L
s
.27564 0 m
.27564 .00375 L
s
.30769 0 m
.30769 .00375 L
s
.37179 0 m
.37179 .00375 L
s
.40385 0 m
.40385 .00375 L
s
.4359 0 m
.4359 .00375 L
s
.5 0 m
.5 .00375 L
s
.53205 0 m
.53205 .00375 L
s
.5641 0 m
.5641 .00375 L
s
.62821 0 m
.62821 .00375 L
s
.66026 0 m
.66026 .00375 L
s
.69231 0 m
.69231 .00375 L
s
.75641 0 m
.75641 .00375 L
s
.78846 0 m
.78846 .00375 L
s
.82051 0 m
.82051 .00375 L
s
.88462 0 m
.88462 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.94872 0 m
.94872 .00375 L
s
.05128 0 m
.05128 .00375 L
s
.01923 0 m
.01923 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66 -25 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .08333 m
.00625 .08333 L
s
[(-4)] -0.0125 .08333 1 0 Mshowa
0 .21154 m
.00625 .21154 L
s
[(-2)] -0.0125 .21154 1 0 Mshowa
0 .33974 m
.00625 .33974 L
s
[(0)] -0.0125 .33974 1 0 Mshowa
0 .46795 m
.00625 .46795 L
s
[(2)] -0.0125 .46795 1 0 Mshowa
0 .59615 m
.00625 .59615 L
s
[(4)] -0.0125 .59615 1 0 Mshowa
0 .72436 m
.00625 .72436 L
s
[(6)] -0.0125 .72436 1 0 Mshowa
0 .85256 m
.00625 .85256 L
s
[(8)] -0.0125 .85256 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(10)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .11538 m
.00375 .11538 L
s
0 .14744 m
.00375 .14744 L
s
0 .17949 m
.00375 .17949 L
s
0 .24359 m
.00375 .24359 L
s
0 .27564 m
.00375 .27564 L
s
0 .30769 m
.00375 .30769 L
s
0 .37179 m
.00375 .37179 L
s
0 .40385 m
.00375 .40385 L
s
0 .4359 m
.00375 .4359 L
s
0 .5 m
.00375 .5 L
s
0 .53205 m
.00375 .53205 L
s
0 .5641 m
.00375 .5641 L
s
0 .62821 m
.00375 .62821 L
s
0 .66026 m
.00375 .66026 L
s
0 .69231 m
.00375 .69231 L
s
0 .75641 m
.00375 .75641 L
s
0 .78846 m
.00375 .78846 L
s
0 .82051 m
.00375 .82051 L
s
0 .88462 m
.00375 .88462 L
s
0 .91667 m
.00375 .91667 L
s
0 .94872 m
.00375 .94872 L
s
0 .05128 m
.00375 .05128 L
s
0 .01923 m
.00375 .01923 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
-0.01875 .5 -84 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
66 10 translate
90 rotate
-66 -10 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.08333 .99375 m
.08333 1 L
s
.21154 .99375 m
.21154 1 L
s
.33974 .99375 m
.33974 1 L
s
.46795 .99375 m
.46795 1 L
s
.59615 .99375 m
.59615 1 L
s
.72436 .99375 m
.72436 1 L
s
.85256 .99375 m
.85256 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.11538 .99625 m
.11538 1 L
s
.14744 .99625 m
.14744 1 L
s
.17949 .99625 m
.17949 1 L
s
.24359 .99625 m
.24359 1 L
s
.27564 .99625 m
.27564 1 L
s
.30769 .99625 m
.30769 1 L
s
.37179 .99625 m
.37179 1 L
s
.40385 .99625 m
.40385 1 L
s
.4359 .99625 m
.4359 1 L
s
.5 .99625 m
.5 1 L
s
.53205 .99625 m
.53205 1 L
s
.5641 .99625 m
.5641 1 L
s
.62821 .99625 m
.62821 1 L
s
.66026 .99625 m
.66026 1 L
s
.69231 .99625 m
.69231 1 L
s
.75641 .99625 m
.75641 1 L
s
.78846 .99625 m
.78846 1 L
s
.82051 .99625 m
.82051 1 L
s
.88462 .99625 m
.88462 1 L
s
.91667 .99625 m
.91667 1 L
s
.94872 .99625 m
.94872 1 L
s
.05128 .99625 m
.05128 1 L
s
.01923 .99625 m
.01923 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .08333 m
1 .08333 L
s
.99375 .21154 m
1 .21154 L
s
.99375 .33974 m
1 .33974 L
s
.99375 .46795 m
1 .46795 L
s
.99375 .59615 m
1 .59615 L
s
.99375 .72436 m
1 .72436 L
s
.99375 .85256 m
1 .85256 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .11538 m
1 .11538 L
s
.99625 .14744 m
1 .14744 L
s
.99625 .17949 m
1 .17949 L
s
.99625 .24359 m
1 .24359 L
s
.99625 .27564 m
1 .27564 L
s
.99625 .30769 m
1 .30769 L
s
.99625 .37179 m
1 .37179 L
s
.99625 .40385 m
1 .40385 L
s
.99625 .4359 m
1 .4359 L
s
.99625 .5 m
1 .5 L
s
.99625 .53205 m
1 .53205 L
s
.99625 .5641 m
1 .5641 L
s
.99625 .62821 m
1 .62821 L
s
.99625 .66026 m
1 .66026 L
s
.99625 .69231 m
1 .69231 L
s
.99625 .75641 m
1 .75641 L
s
.99625 .78846 m
1 .78846 L
s
.99625 .82051 m
1 .82051 L
s
.99625 .88462 m
1 .88462 L
s
.99625 .91667 m
1 .91667 L
s
.99625 .94872 m
1 .94872 L
s
.99625 .05128 m
1 .05128 L
s
.99625 .01923 m
1 .01923 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.6 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.5 g
.01923 .98004 m
.02821 .97106 L
.02894 .97033 L
.03793 .96134 L
.03866 .96061 L
.04764 .95163 L
.04837 .9509 L
.05735 .94192 L
.05808 .94119 L
.06706 .93221 L
.06779 .93148 L
.07678 .92249 L
.07751 .92176 L
.08649 .91278 L
.08722 .91205 L
.0962 .90307 L
.09693 .90234 L
.10591 .89336 L
.10664 .89263 L
.11563 .88364 L
.11636 .88291 L
.12534 .87393 L
.12607 .8732 L
.13505 .86422 L
.13578 .86349 L
.14476 .85451 L
.14549 .85378 L
.15448 .84479 L
.15521 .84406 L
.16419 .83508 L
.16492 .83435 L
.1739 .82537 L
.17463 .82464 L
.18361 .81566 L
.18434 .81493 L
.19333 .80594 L
.19406 .80521 L
.20304 .79623 L
.20377 .7955 L
.21275 .78652 L
.21348 .78579 L
.22246 .77681 L
.22319 .77608 L
.23218 .76709 L
.23291 .76636 L
.24189 .75738 L
.24262 .75665 L
.2516 .74767 L
.25233 .74694 L
.26131 .73796 L
.26204 .73723 L
.27103 .72824 L
.27176 .72751 L
.28074 .71853 L
.28147 .7178 L
.29045 .70882 L
.29118 .70809 L
.30016 .69911 L
.30089 .69838 L
.30988 .68939 L
.31061 .68866 L
.31959 .67968 L
.32032 .67895 L
.3293 .66997 L
.33003 .66924 L
.33904 .66026 L
.33974 .65953 L
.34792 .65054 L
.34946 .64883 L
.35639 .64083 L
.35917 .63753 L
.36448 .63112 L
.36888 .62567 L
.37227 .62141 L
.37859 .61326 L
.37979 .61169 L
.38707 .60198 L
.38831 .60031 L
.39415 .59227 L
.39802 .58684 L
.40103 .58256 L
.40773 .57287 L
.40775 .57284 L
.41431 .56313 L
.41744 .55841 L
.42072 .55342 L
.42701 .54371 L
.42716 .54348 L
.43317 .53399 L
.43687 .52808 L
.43922 .52428 L
.44517 .51457 L
.44658 .51224 L
.45102 .50486 L
.45629 .49597 L
.45678 .49514 L
.46245 .48543 L
.46601 .47927 L
.46804 .47572 L
.47355 .46601 L
.47572 .46215 L
.47898 .45629 L
.48436 .44658 L
.48543 .44463 L
.48966 .43687 L
.4949 .42716 L
.49514 .42671 L
.50008 .41744 L
.50486 .40839 L
.5052 .40773 L
.51027 .39802 L
.51457 .3897 L
.51528 .38831 L
.52024 .37859 L
.52428 .37063 L
.52516 .36888 L
.53003 .35917 L
.53399 .3512 L
.53485 .34946 L
.53963 .33974 L
.54371 .3314 L
.54437 .33003 L
.54906 .32032 L
.55342 .31125 L
.55372 .31061 L
.55834 .30089 L
.56293 .29118 L
.56313 .29075 L
.56747 .28147 L
.57199 .27176 L
.57284 .26991 L
.57646 .26204 L
.58091 .25233 L
.58256 .24873 L
.58532 .24262 L
.58971 .23291 L
.59227 .22722 L
.59406 .22319 L
.59839 .21348 L
.60198 .20538 L
.60268 .20377 L
.60695 .19406 L
.6112 .18434 L
.61169 .18321 L
.6154 .17463 L
.61961 .16492 L
.62141 .16073 L
.62376 .15521 L
.62791 .14549 L
.63112 .13794 L
.63202 .13578 L
.63611 .12607 L
.64019 .11636 L
.64083 .11483 L
.64422 .10664 L
.64827 .09693 L
.65054 .09142 L
.65226 .08722 L
.65625 .07751 L
.66022 .06779 L
.66026 .06771 L
.66414 .05808 L
.66809 .04837 L
.66997 .0437 L
.67197 .03866 L
.67587 .02894 L
.67968 .01939 L
.67974 .01923 L
.01923 .01923 L
F
0 g
.01923 .98004 m
.02821 .97106 L
.02894 .97033 L
.03793 .96134 L
.03866 .96061 L
.04764 .95163 L
.04837 .9509 L
.05735 .94192 L
.05808 .94119 L
.06706 .93221 L
.06779 .93148 L
.07678 .92249 L
.07751 .92176 L
.08649 .91278 L
.08722 .91205 L
.0962 .90307 L
.09693 .90234 L
.10591 .89336 L
.10664 .89263 L
.11563 .88364 L
.11636 .88291 L
.12534 .87393 L
.12607 .8732 L
.13505 .86422 L
.13578 .86349 L
.14476 .85451 L
.14549 .85378 L
.15448 .84479 L
.15521 .84406 L
.16419 .83508 L
.16492 .83435 L
.1739 .82537 L
.17463 .82464 L
.18361 .81566 L
.18434 .81493 L
.19333 .80594 L
.19406 .80521 L
.20304 .79623 L
.20377 .7955 L
.21275 .78652 L
.21348 .78579 L
.22246 .77681 L
.22319 .77608 L
.23218 .76709 L
.23291 .76636 L
.24189 .75738 L
.24262 .75665 L
.2516 .74767 L
.25233 .74694 L
.26131 .73796 L
Mistroke
.26204 .73723 L
.27103 .72824 L
.27176 .72751 L
.28074 .71853 L
.28147 .7178 L
.29045 .70882 L
.29118 .70809 L
.30016 .69911 L
.30089 .69838 L
.30988 .68939 L
.31061 .68866 L
.31959 .67968 L
.32032 .67895 L
.3293 .66997 L
.33003 .66924 L
.33904 .66026 L
.33974 .65953 L
.34792 .65054 L
.34946 .64883 L
.35639 .64083 L
.35917 .63753 L
.36448 .63112 L
.36888 .62567 L
.37227 .62141 L
.37859 .61326 L
.37979 .61169 L
.38707 .60198 L
.38831 .60031 L
.39415 .59227 L
.39802 .58684 L
.40103 .58256 L
.40773 .57287 L
.40775 .57284 L
.41431 .56313 L
.41744 .55841 L
.42072 .55342 L
.42701 .54371 L
.42716 .54348 L
.43317 .53399 L
.43687 .52808 L
.43922 .52428 L
.44517 .51457 L
.44658 .51224 L
.45102 .50486 L
.45629 .49597 L
.45678 .49514 L
.46245 .48543 L
.46601 .47927 L
.46804 .47572 L
.47355 .46601 L
Mistroke
.47572 .46215 L
.47898 .45629 L
.48436 .44658 L
.48543 .44463 L
.48966 .43687 L
.4949 .42716 L
.49514 .42671 L
.50008 .41744 L
.50486 .40839 L
.5052 .40773 L
.51027 .39802 L
.51457 .3897 L
.51528 .38831 L
.52024 .37859 L
.52428 .37063 L
.52516 .36888 L
.53003 .35917 L
.53399 .3512 L
.53485 .34946 L
.53963 .33974 L
.54371 .3314 L
.54437 .33003 L
.54906 .32032 L
.55342 .31125 L
.55372 .31061 L
.55834 .30089 L
.56293 .29118 L
.56313 .29075 L
.56747 .28147 L
.57199 .27176 L
.57284 .26991 L
.57646 .26204 L
.58091 .25233 L
.58256 .24873 L
.58532 .24262 L
.58971 .23291 L
.59227 .22722 L
.59406 .22319 L
.59839 .21348 L
.60198 .20538 L
.60268 .20377 L
.60695 .19406 L
.6112 .18434 L
.61169 .18321 L
.6154 .17463 L
.61961 .16492 L
.62141 .16073 L
.62376 .15521 L
.62791 .14549 L
.63112 .13794 L
Mistroke
.63202 .13578 L
.63611 .12607 L
.64019 .11636 L
.64083 .11483 L
.64422 .10664 L
.64827 .09693 L
.65054 .09142 L
.65226 .08722 L
.65625 .07751 L
.66022 .06779 L
.66026 .06771 L
.66414 .05808 L
.66809 .04837 L
.66997 .0437 L
.67197 .03866 L
.67587 .02894 L
.67968 .01939 L
.67974 .01923 L
Mfstroke
.4 g
.01923 .94463 m
.02194 .94192 L
.02894 .93491 L
.03165 .93221 L
.03866 .9252 L
.04136 .92249 L
.04837 .91549 L
.05108 .91278 L
.05808 .90578 L
.06079 .90307 L
.06779 .89606 L
.0705 .89336 L
.07751 .88635 L
.08021 .88364 L
.08722 .87664 L
.08993 .87393 L
.09693 .86693 L
.09964 .86422 L
.10664 .85721 L
.10935 .85451 L
.11636 .8475 L
.11906 .84479 L
.12607 .83779 L
.12878 .83508 L
.13578 .82808 L
.13849 .82537 L
.14549 .81836 L
.1482 .81566 L
.15521 .80865 L
.15791 .80594 L
.16492 .79894 L
.16763 .79623 L
.17463 .78923 L
.17734 .78652 L
.18434 .77951 L
.18705 .77681 L
.19406 .7698 L
.19676 .76709 L
.20377 .76009 L
.20648 .75738 L
.21348 .75038 L
.21619 .74767 L
.22319 .74066 L
.2259 .73796 L
.23291 .73095 L
.23561 .72824 L
.24262 .72124 L
.24533 .71853 L
.25233 .71153 L
.25504 .70882 L
.26204 .70181 L
.26475 .69911 L
.27176 .6921 L
.27446 .68939 L
.28147 .68239 L
.28418 .67968 L
.29118 .67268 L
.29389 .66997 L
.30089 .66296 L
.3036 .66026 L
.31061 .65325 L
.31331 .65054 L
.32032 .64354 L
.32303 .64083 L
.33003 .63383 L
.33275 .63112 L
.33974 .62411 L
.3425 .62141 L
.34946 .61467 L
.35238 .61169 L
.35917 .60445 L
.36142 .60198 L
.36888 .5935 L
.36994 .59227 L
.37805 .58256 L
.37859 .58189 L
.38583 .57284 L
.38831 .56965 L
.39331 .56313 L
.39802 .55682 L
.40053 .55342 L
.40753 .54371 L
.40773 .54343 L
.41436 .53399 L
.41744 .5295 L
.421 .52428 L
.42716 .51504 L
.42747 .51457 L
.43383 .50486 L
.43687 .5001 L
.44003 .49514 L
.44611 .48543 L
.44658 .48467 L
.4521 .47572 L
.45629 .46878 L
.45797 .46601 L
.46375 .45629 L
.46601 .45244 L
.46944 .44658 L
.47503 .43687 L
.47572 .43566 L
.48056 .42716 L
.48543 .41845 L
.48599 .41744 L
.49138 .40773 L
.49514 .40083 L
.49668 .39802 L
.50193 .38831 L
.50486 .3828 L
.5071 .37859 L
.51223 .36888 L
.51457 .36437 L
.51729 .35917 L
.5223 .34946 L
.52428 .34556 L
.52726 .33974 L
.53217 .33003 L
.53399 .32637 L
.53703 .32032 L
.54185 .31061 L
.54371 .3068 L
.54662 .30089 L
.55135 .29118 L
.55342 .28687 L
.55603 .28147 L
.56069 .27176 L
.56313 .26658 L
.56529 .26204 L
.56988 .25233 L
.57284 .24594 L
.5744 .24262 L
.57892 .23291 L
.58256 .22496 L
.58337 .22319 L
.58783 .21348 L
.59221 .20377 L
.59227 .20363 L
.5966 .19406 L
.60094 .18434 L
.60198 .18197 L
.60525 .17463 L
.60955 .16492 L
.61169 .15998 L
.61379 .15521 L
.61804 .14549 L
.62141 .13766 L
.62222 .13578 L
.62643 .12607 L
.63056 .11636 L
.63112 .11503 L
.6347 .10664 L
.63882 .09693 L
.64083 .09208 L
.64288 .08722 L
.64696 .07751 L
.65054 .06882 L
.65097 .06779 L
.65501 .05808 L
.659 .04837 L
.66026 .04525 L
.66297 .03866 L
.66694 .02894 L
.66997 .02138 L
.67084 .01923 L
.01923 .01923 L
F
0 g
.01923 .94463 m
.02194 .94192 L
.02894 .93491 L
.03165 .93221 L
.03866 .9252 L
.04136 .92249 L
.04837 .91549 L
.05108 .91278 L
.05808 .90578 L
.06079 .90307 L
.06779 .89606 L
.0705 .89336 L
.07751 .88635 L
.08021 .88364 L
.08722 .87664 L
.08993 .87393 L
.09693 .86693 L
.09964 .86422 L
.10664 .85721 L
.10935 .85451 L
.11636 .8475 L
.11906 .84479 L
.12607 .83779 L
.12878 .83508 L
.13578 .82808 L
.13849 .82537 L
.14549 .81836 L
.1482 .81566 L
.15521 .80865 L
.15791 .80594 L
.16492 .79894 L
.16763 .79623 L
.17463 .78923 L
.17734 .78652 L
.18434 .77951 L
.18705 .77681 L
.19406 .7698 L
.19676 .76709 L
.20377 .76009 L
.20648 .75738 L
.21348 .75038 L
.21619 .74767 L
.22319 .74066 L
.2259 .73796 L
.23291 .73095 L
.23561 .72824 L
.24262 .72124 L
.24533 .71853 L
.25233 .71153 L
.25504 .70882 L
Mistroke
.26204 .70181 L
.26475 .69911 L
.27176 .6921 L
.27446 .68939 L
.28147 .68239 L
.28418 .67968 L
.29118 .67268 L
.29389 .66997 L
.30089 .66296 L
.3036 .66026 L
.31061 .65325 L
.31331 .65054 L
.32032 .64354 L
.32303 .64083 L
.33003 .63383 L
.33275 .63112 L
.33974 .62411 L
.3425 .62141 L
.34946 .61467 L
.35238 .61169 L
.35917 .60445 L
.36142 .60198 L
.36888 .5935 L
.36994 .59227 L
.37805 .58256 L
.37859 .58189 L
.38583 .57284 L
.38831 .56965 L
.39331 .56313 L
.39802 .55682 L
.40053 .55342 L
.40753 .54371 L
.40773 .54343 L
.41436 .53399 L
.41744 .5295 L
.421 .52428 L
.42716 .51504 L
.42747 .51457 L
.43383 .50486 L
.43687 .5001 L
.44003 .49514 L
.44611 .48543 L
.44658 .48467 L
.4521 .47572 L
.45629 .46878 L
.45797 .46601 L
.46375 .45629 L
.46601 .45244 L
.46944 .44658 L
.47503 .43687 L
Mistroke
.47572 .43566 L
.48056 .42716 L
.48543 .41845 L
.48599 .41744 L
.49138 .40773 L
.49514 .40083 L
.49668 .39802 L
.50193 .38831 L
.50486 .3828 L
.5071 .37859 L
.51223 .36888 L
.51457 .36437 L
.51729 .35917 L
.5223 .34946 L
.52428 .34556 L
.52726 .33974 L
.53217 .33003 L
.53399 .32637 L
.53703 .32032 L
.54185 .31061 L
.54371 .3068 L
.54662 .30089 L
.55135 .29118 L
.55342 .28687 L
.55603 .28147 L
.56069 .27176 L
.56313 .26658 L
.56529 .26204 L
.56988 .25233 L
.57284 .24594 L
.5744 .24262 L
.57892 .23291 L
.58256 .22496 L
.58337 .22319 L
.58783 .21348 L
.59221 .20377 L
.59227 .20363 L
.5966 .19406 L
.60094 .18434 L
.60198 .18197 L
.60525 .17463 L
.60955 .16492 L
.61169 .15998 L
.61379 .15521 L
.61804 .14549 L
.62141 .13766 L
.62222 .13578 L
.62643 .12607 L
.63056 .11636 L
.63112 .11503 L
Mistroke
.6347 .10664 L
.63882 .09693 L
.64083 .09208 L
.64288 .08722 L
.64696 .07751 L
.65054 .06882 L
.65097 .06779 L
.65501 .05808 L
.659 .04837 L
.66026 .04525 L
.66297 .03866 L
.66694 .02894 L
.66997 .02138 L
.67084 .01923 L
Mfstroke
.3 g
.01923 .90095 m
.02676 .89336 L
.02894 .89124 L
.03654 .88364 L
.03866 .88152 L
.04625 .87393 L
.04837 .87181 L
.05596 .86422 L
.05808 .8621 L
.06567 .85451 L
.06779 .85239 L
.07539 .84479 L
.07751 .84267 L
.0851 .83508 L
.08722 .83296 L
.09481 .82537 L
.09693 .82325 L
.10452 .81566 L
.10664 .81354 L
.11424 .80594 L
.11636 .80382 L
.12395 .79623 L
.12607 .79411 L
.13366 .78652 L
.13578 .7844 L
.14337 .77681 L
.14549 .77469 L
.15309 .76709 L
.15521 .76497 L
.1628 .75738 L
.16492 .75526 L
.17251 .74767 L
.17463 .74555 L
.18222 .73796 L
.18434 .73584 L
.19194 .72824 L
.19406 .72612 L
.20165 .71853 L
.20377 .71641 L
.21136 .70882 L
.21348 .7067 L
.22107 .69911 L
.22319 .69699 L
.23079 .68939 L
.23291 .68727 L
.2405 .67968 L
.24262 .67756 L
.25021 .66997 L
.25233 .66785 L
.25992 .66026 L
.26204 .65814 L
.26964 .65054 L
.27176 .64842 L
.27935 .64083 L
.28147 .63871 L
.28906 .63112 L
.29118 .629 L
.29877 .62141 L
.30089 .61929 L
.30849 .61169 L
.31061 .60957 L
.3182 .60198 L
.32032 .59986 L
.32791 .59227 L
.33003 .59015 L
.33752 .58256 L
.33974 .58044 L
.34946 .57339 L
.35018 .57284 L
.35917 .56509 L
.36138 .56313 L
.36888 .55572 L
.3712 .55342 L
.37859 .54543 L
.38019 .54371 L
.38831 .53432 L
.38859 .53399 L
.39667 .52428 L
.39802 .52249 L
.40434 .51457 L
.40773 .50998 L
.41165 .50486 L
.41744 .49682 L
.41867 .49514 L
.4256 .48543 L
.42716 .48308 L
.4323 .47572 L
.43687 .46877 L
.43874 .46601 L
.44513 .45629 L
.44658 .45393 L
.45136 .44658 L
.45629 .43857 L
.45737 .43687 L
.46342 .42716 L
.46601 .42273 L
.46925 .41744 L
.47498 .40773 L
.47572 .4064 L
.4807 .39802 L
.48543 .38962 L
.4862 .38831 L
.49179 .37859 L
.49514 .37241 L
.49714 .36888 L
.50255 .35917 L
.50486 .35476 L
.50779 .34946 L
.51302 .33974 L
.51457 .33669 L
.51817 .33003 L
.52325 .32032 L
.52428 .3182 L
.5283 .31061 L
.53325 .30089 L
.53399 .29933 L
.53822 .29118 L
.54305 .28147 L
.54371 .28006 L
.54793 .27176 L
.55268 .26204 L
.55342 .26042 L
.55746 .25233 L
.56214 .24262 L
.56313 .2404 L
.56681 .23291 L
.57144 .22319 L
.57284 .22002 L
.576 .21348 L
.58058 .20377 L
.58256 .19928 L
.58504 .19406 L
.58958 .18434 L
.59227 .17819 L
.59393 .17463 L
.59844 .16492 L
.60198 .15675 L
.60269 .15521 L
.60715 .14549 L
.61137 .13578 L
.61169 .13498 L
.61573 .12607 L
.62 .11636 L
.62141 .11288 L
.62419 .10664 L
.62847 .09693 L
.63112 .09044 L
.63254 .08722 L
.6368 .07751 L
.64079 .06779 L
.64083 .06768 L
.64501 .05808 L
.6491 .04837 L
.65054 .04461 L
.6531 .03866 L
.65723 .02894 L
.66026 .02121 L
.6611 .01923 L
.01923 .01923 L
F
0 g
.01923 .90095 m
.02676 .89336 L
.02894 .89124 L
.03654 .88364 L
.03866 .88152 L
.04625 .87393 L
.04837 .87181 L
.05596 .86422 L
.05808 .8621 L
.06567 .85451 L
.06779 .85239 L
.07539 .84479 L
.07751 .84267 L
.0851 .83508 L
.08722 .83296 L
.09481 .82537 L
.09693 .82325 L
.10452 .81566 L
.10664 .81354 L
.11424 .80594 L
.11636 .80382 L
.12395 .79623 L
.12607 .79411 L
.13366 .78652 L
.13578 .7844 L
.14337 .77681 L
.14549 .77469 L
.15309 .76709 L
.15521 .76497 L
.1628 .75738 L
.16492 .75526 L
.17251 .74767 L
.17463 .74555 L
.18222 .73796 L
.18434 .73584 L
.19194 .72824 L
.19406 .72612 L
.20165 .71853 L
.20377 .71641 L
.21136 .70882 L
.21348 .7067 L
.22107 .69911 L
.22319 .69699 L
.23079 .68939 L
.23291 .68727 L
.2405 .67968 L
.24262 .67756 L
.25021 .66997 L
.25233 .66785 L
.25992 .66026 L
Mistroke
.26204 .65814 L
.26964 .65054 L
.27176 .64842 L
.27935 .64083 L
.28147 .63871 L
.28906 .63112 L
.29118 .629 L
.29877 .62141 L
.30089 .61929 L
.30849 .61169 L
.31061 .60957 L
.3182 .60198 L
.32032 .59986 L
.32791 .59227 L
.33003 .59015 L
.33752 .58256 L
.33974 .58044 L
.34946 .57339 L
.35018 .57284 L
.35917 .56509 L
.36138 .56313 L
.36888 .55572 L
.3712 .55342 L
.37859 .54543 L
.38019 .54371 L
.38831 .53432 L
.38859 .53399 L
.39667 .52428 L
.39802 .52249 L
.40434 .51457 L
.40773 .50998 L
.41165 .50486 L
.41744 .49682 L
.41867 .49514 L
.4256 .48543 L
.42716 .48308 L
.4323 .47572 L
.43687 .46877 L
.43874 .46601 L
.44513 .45629 L
.44658 .45393 L
.45136 .44658 L
.45629 .43857 L
.45737 .43687 L
.46342 .42716 L
.46601 .42273 L
.46925 .41744 L
.47498 .40773 L
.47572 .4064 L
.4807 .39802 L
Mistroke
.48543 .38962 L
.4862 .38831 L
.49179 .37859 L
.49514 .37241 L
.49714 .36888 L
.50255 .35917 L
.50486 .35476 L
.50779 .34946 L
.51302 .33974 L
.51457 .33669 L
.51817 .33003 L
.52325 .32032 L
.52428 .3182 L
.5283 .31061 L
.53325 .30089 L
.53399 .29933 L
.53822 .29118 L
.54305 .28147 L
.54371 .28006 L
.54793 .27176 L
.55268 .26204 L
.55342 .26042 L
.55746 .25233 L
.56214 .24262 L
.56313 .2404 L
.56681 .23291 L
.57144 .22319 L
.57284 .22002 L
.576 .21348 L
.58058 .20377 L
.58256 .19928 L
.58504 .19406 L
.58958 .18434 L
.59227 .17819 L
.59393 .17463 L
.59844 .16492 L
.60198 .15675 L
.60269 .15521 L
.60715 .14549 L
.61137 .13578 L
.61169 .13498 L
.61573 .12607 L
.62 .11636 L
.62141 .11288 L
.62419 .10664 L
.62847 .09693 L
.63112 .09044 L
.63254 .08722 L
.6368 .07751 L
.64079 .06779 L
Mistroke
.64083 .06768 L
.64501 .05808 L
.6491 .04837 L
.65054 .04461 L
.6531 .03866 L
.65723 .02894 L
.66026 .02121 L
.6611 .01923 L
Mfstroke
.4 g
.01923 .82234 m
.02608 .81566 L
.02894 .81263 L
.03563 .80594 L
.03866 .80292 L
.04534 .79623 L
.04837 .7932 L
.05505 .78652 L
.05808 .78349 L
.06476 .77681 L
.06779 .77378 L
.07448 .76709 L
.07751 .76407 L
.08419 .75738 L
.08722 .75435 L
.0939 .74767 L
.09693 .74464 L
.10361 .73796 L
.10664 .73493 L
.11333 .72824 L
.11636 .72522 L
.12304 .71853 L
.12607 .7155 L
.13275 .70882 L
.13578 .70579 L
.14246 .69911 L
.14549 .69608 L
.15218 .68939 L
.15521 .68637 L
.16189 .67968 L
.16492 .67665 L
.1716 .66997 L
.17463 .66694 L
.18131 .66026 L
.18434 .65723 L
.19103 .65054 L
.19406 .64752 L
.20074 .64083 L
.20377 .6378 L
.21045 .63112 L
.21348 .62809 L
.22017 .62141 L
.22319 .61838 L
.22988 .61169 L
.23291 .60867 L
.23959 .60198 L
.24262 .59895 L
.2493 .59227 L
.25233 .58924 L
.25902 .58256 L
.26204 .57953 L
.26873 .57284 L
.27176 .56982 L
.27844 .56313 L
.28147 .5601 L
.28815 .55342 L
.29118 .55039 L
.29787 .54371 L
.30089 .54068 L
.30758 .53399 L
.31061 .53097 L
.31729 .52428 L
.32032 .52125 L
.327 .51457 L
.33003 .51154 L
.33697 .50486 L
.33974 .50183 L
.34482 .49514 L
.34946 .48869 L
.35188 .48543 L
.35902 .47572 L
.35917 .47552 L
.36605 .46601 L
.36888 .46206 L
.37298 .45629 L
.37859 .44833 L
.37981 .44658 L
.38651 .43687 L
.38831 .43424 L
.39308 .42716 L
.39802 .41978 L
.39955 .41744 L
.40592 .40773 L
.40773 .40494 L
.41214 .39802 L
.41744 .3897 L
.41831 .38831 L
.42435 .37859 L
.42716 .37406 L
.43029 .36888 L
.43619 .35917 L
.43687 .35804 L
.44193 .34946 L
.44658 .34161 L
.44765 .33974 L
.45327 .33003 L
.45629 .32479 L
.4588 .32032 L
.46431 .31061 L
.46601 .3076 L
.46968 .30089 L
.47508 .29118 L
.47572 .29002 L
.48032 .28147 L
.48543 .27207 L
.48559 .27176 L
.49072 .26204 L
.49514 .25374 L
.49586 .25233 L
.5009 .24262 L
.50486 .23505 L
.50593 .23291 L
.51088 .22319 L
.51457 .216 L
.5158 .21348 L
.52067 .20377 L
.52428 .1966 L
.5255 .19406 L
.53028 .18434 L
.53399 .17685 L
.53503 .17463 L
.53972 .16492 L
.54371 .15676 L
.54442 .15521 L
.54901 .14549 L
.55342 .13633 L
.55366 .13578 L
.55816 .12607 L
.56276 .11636 L
.56313 .11556 L
.56717 .10664 L
.57169 .09693 L
.57284 .09445 L
.57605 .08722 L
.5805 .07751 L
.58256 .07302 L
.58482 .06779 L
.58919 .05808 L
.59227 .05127 L
.59349 .04837 L
.59776 .03866 L
.60198 .02921 L
.60209 .02894 L
.60623 .01923 L
.01923 .01923 L
F
0 g
.01923 .82234 m
.02608 .81566 L
.02894 .81263 L
.03563 .80594 L
.03866 .80292 L
.04534 .79623 L
.04837 .7932 L
.05505 .78652 L
.05808 .78349 L
.06476 .77681 L
.06779 .77378 L
.07448 .76709 L
.07751 .76407 L
.08419 .75738 L
.08722 .75435 L
.0939 .74767 L
.09693 .74464 L
.10361 .73796 L
.10664 .73493 L
.11333 .72824 L
.11636 .72522 L
.12304 .71853 L
.12607 .7155 L
.13275 .70882 L
.13578 .70579 L
.14246 .69911 L
.14549 .69608 L
.15218 .68939 L
.15521 .68637 L
.16189 .67968 L
.16492 .67665 L
.1716 .66997 L
.17463 .66694 L
.18131 .66026 L
.18434 .65723 L
.19103 .65054 L
.19406 .64752 L
.20074 .64083 L
.20377 .6378 L
.21045 .63112 L
.21348 .62809 L
.22017 .62141 L
.22319 .61838 L
.22988 .61169 L
.23291 .60867 L
.23959 .60198 L
.24262 .59895 L
.2493 .59227 L
.25233 .58924 L
.25902 .58256 L
Mistroke
.26204 .57953 L
.26873 .57284 L
.27176 .56982 L
.27844 .56313 L
.28147 .5601 L
.28815 .55342 L
.29118 .55039 L
.29787 .54371 L
.30089 .54068 L
.30758 .53399 L
.31061 .53097 L
.31729 .52428 L
.32032 .52125 L
.327 .51457 L
.33003 .51154 L
.33697 .50486 L
.33974 .50183 L
.34482 .49514 L
.34946 .48869 L
.35188 .48543 L
.35902 .47572 L
.35917 .47552 L
.36605 .46601 L
.36888 .46206 L
.37298 .45629 L
.37859 .44833 L
.37981 .44658 L
.38651 .43687 L
.38831 .43424 L
.39308 .42716 L
.39802 .41978 L
.39955 .41744 L
.40592 .40773 L
.40773 .40494 L
.41214 .39802 L
.41744 .3897 L
.41831 .38831 L
.42435 .37859 L
.42716 .37406 L
.43029 .36888 L
.43619 .35917 L
.43687 .35804 L
.44193 .34946 L
.44658 .34161 L
.44765 .33974 L
.45327 .33003 L
.45629 .32479 L
.4588 .32032 L
.46431 .31061 L
.46601 .3076 L
Mistroke
.46968 .30089 L
.47508 .29118 L
.47572 .29002 L
.48032 .28147 L
.48543 .27207 L
.48559 .27176 L
.49072 .26204 L
.49514 .25374 L
.49586 .25233 L
.5009 .24262 L
.50486 .23505 L
.50593 .23291 L
.51088 .22319 L
.51457 .216 L
.5158 .21348 L
.52067 .20377 L
.52428 .1966 L
.5255 .19406 L
.53028 .18434 L
.53399 .17685 L
.53503 .17463 L
.53972 .16492 L
.54371 .15676 L
.54442 .15521 L
.54901 .14549 L
.55342 .13633 L
.55366 .13578 L
.55816 .12607 L
.56276 .11636 L
.56313 .11556 L
.56717 .10664 L
.57169 .09693 L
.57284 .09445 L
.57605 .08722 L
.5805 .07751 L
.58256 .07302 L
.58482 .06779 L
.58919 .05808 L
.59227 .05127 L
.59349 .04837 L
.59776 .03866 L
.60198 .02921 L
.60209 .02894 L
.60623 .01923 L
Mfstroke
.5 g
.01923 .77865 m
.02109 .77681 L
.02894 .76894 L
.03079 .76709 L
.03866 .75923 L
.0405 .75738 L
.04837 .74952 L
.05022 .74767 L
.05808 .7398 L
.05993 .73796 L
.06779 .73009 L
.06964 .72824 L
.07751 .72038 L
.07935 .71853 L
.08722 .71067 L
.08907 .70882 L
.09693 .70095 L
.09878 .69911 L
.10664 .69124 L
.10849 .68939 L
.11636 .68153 L
.1182 .67968 L
.12607 .67182 L
.12792 .66997 L
.13578 .6621 L
.13763 .66026 L
.14549 .65239 L
.14734 .65054 L
.15521 .64268 L
.15705 .64083 L
.16492 .63297 L
.16677 .63112 L
.17463 .62325 L
.17648 .62141 L
.18434 .61354 L
.18619 .61169 L
.19406 .60383 L
.1959 .60198 L
.20377 .59412 L
.20562 .59227 L
.21348 .5844 L
.21533 .58256 L
.22319 .57469 L
.22504 .57284 L
.23291 .56498 L
.23475 .56313 L
.24262 .55527 L
.24447 .55342 L
.25233 .54555 L
.25418 .54371 L
.26204 .53584 L
.26389 .53399 L
.27176 .52613 L
.2736 .52428 L
.28147 .51642 L
.28332 .51457 L
.29118 .5067 L
.29303 .50486 L
.30089 .49699 L
.30274 .49514 L
.31061 .48728 L
.31245 .48543 L
.32032 .47757 L
.32217 .47572 L
.33003 .46785 L
.33193 .46601 L
.33974 .45814 L
.34146 .45629 L
.34946 .44744 L
.35022 .44658 L
.35857 .43687 L
.35917 .43615 L
.36658 .42716 L
.36888 .42429 L
.37429 .41744 L
.37859 .41187 L
.38175 .40773 L
.38831 .39892 L
.38897 .39802 L
.39599 .38831 L
.39802 .38545 L
.40283 .37859 L
.40773 .37148 L
.4095 .36888 L
.41602 .35917 L
.41744 .35702 L
.4224 .34946 L
.42716 .34209 L
.42866 .33974 L
.43479 .33003 L
.43687 .3267 L
.44081 .32032 L
.44658 .31086 L
.44674 .31061 L
.45256 .30089 L
.45629 .29458 L
.45829 .29118 L
.46394 .28147 L
.46601 .27788 L
.46951 .27176 L
.475 .26204 L
.47572 .26077 L
.48042 .25233 L
.48543 .24324 L
.48577 .24262 L
.49106 .23291 L
.49514 .22532 L
.49628 .22319 L
.50144 .21348 L
.50486 .20701 L
.50655 .20377 L
.5116 .19406 L
.51457 .18832 L
.5166 .18434 L
.52156 .17463 L
.52428 .16925 L
.52645 .16492 L
.53131 .15521 L
.53399 .14981 L
.53612 .14549 L
.54089 .13578 L
.54371 .13002 L
.54561 .12607 L
.55031 .11636 L
.55342 .10987 L
.55495 .10664 L
.55956 .09693 L
.56313 .08937 L
.56413 .08722 L
.56867 .07751 L
.57284 .06852 L
.57318 .06779 L
.57764 .05808 L
.58209 .04837 L
.58256 .04734 L
.58648 .03866 L
.59087 .02894 L
.59227 .02584 L
.59521 .01923 L
.01923 .01923 L
F
0 g
.01923 .77865 m
.02109 .77681 L
.02894 .76894 L
.03079 .76709 L
.03866 .75923 L
.0405 .75738 L
.04837 .74952 L
.05022 .74767 L
.05808 .7398 L
.05993 .73796 L
.06779 .73009 L
.06964 .72824 L
.07751 .72038 L
.07935 .71853 L
.08722 .71067 L
.08907 .70882 L
.09693 .70095 L
.09878 .69911 L
.10664 .69124 L
.10849 .68939 L
.11636 .68153 L
.1182 .67968 L
.12607 .67182 L
.12792 .66997 L
.13578 .6621 L
.13763 .66026 L
.14549 .65239 L
.14734 .65054 L
.15521 .64268 L
.15705 .64083 L
.16492 .63297 L
.16677 .63112 L
.17463 .62325 L
.17648 .62141 L
.18434 .61354 L
.18619 .61169 L
.19406 .60383 L
.1959 .60198 L
.20377 .59412 L
.20562 .59227 L
.21348 .5844 L
.21533 .58256 L
.22319 .57469 L
.22504 .57284 L
.23291 .56498 L
.23475 .56313 L
.24262 .55527 L
.24447 .55342 L
.25233 .54555 L
.25418 .54371 L
Mistroke
.26204 .53584 L
.26389 .53399 L
.27176 .52613 L
.2736 .52428 L
.28147 .51642 L
.28332 .51457 L
.29118 .5067 L
.29303 .50486 L
.30089 .49699 L
.30274 .49514 L
.31061 .48728 L
.31245 .48543 L
.32032 .47757 L
.32217 .47572 L
.33003 .46785 L
.33193 .46601 L
.33974 .45814 L
.34146 .45629 L
.34946 .44744 L
.35022 .44658 L
.35857 .43687 L
.35917 .43615 L
.36658 .42716 L
.36888 .42429 L
.37429 .41744 L
.37859 .41187 L
.38175 .40773 L
.38831 .39892 L
.38897 .39802 L
.39599 .38831 L
.39802 .38545 L
.40283 .37859 L
.40773 .37148 L
.4095 .36888 L
.41602 .35917 L
.41744 .35702 L
.4224 .34946 L
.42716 .34209 L
.42866 .33974 L
.43479 .33003 L
.43687 .3267 L
.44081 .32032 L
.44658 .31086 L
.44674 .31061 L
.45256 .30089 L
.45629 .29458 L
.45829 .29118 L
.46394 .28147 L
.46601 .27788 L
.46951 .27176 L
Mistroke
.475 .26204 L
.47572 .26077 L
.48042 .25233 L
.48543 .24324 L
.48577 .24262 L
.49106 .23291 L
.49514 .22532 L
.49628 .22319 L
.50144 .21348 L
.50486 .20701 L
.50655 .20377 L
.5116 .19406 L
.51457 .18832 L
.5166 .18434 L
.52156 .17463 L
.52428 .16925 L
.52645 .16492 L
.53131 .15521 L
.53399 .14981 L
.53612 .14549 L
.54089 .13578 L
.54371 .13002 L
.54561 .12607 L
.55031 .11636 L
.55342 .10987 L
.55495 .10664 L
.55956 .09693 L
.56313 .08937 L
.56413 .08722 L
.56867 .07751 L
.57284 .06852 L
.57318 .06779 L
.57764 .05808 L
.58209 .04837 L
.58256 .04734 L
.58648 .03866 L
.59087 .02894 L
.59227 .02584 L
.59521 .01923 L
Mfstroke
.6 g
.01923 .74324 m
.02451 .73796 L
.02894 .73353 L
.03423 .72824 L
.03866 .72382 L
.04394 .71853 L
.04837 .71411 L
.05366 .70882 L
.05808 .70439 L
.06337 .69911 L
.06779 .69468 L
.07308 .68939 L
.07751 .68497 L
.08279 .67968 L
.08722 .67526 L
.09251 .66997 L
.09693 .66554 L
.10222 .66026 L
.10664 .65583 L
.11193 .65054 L
.11636 .64612 L
.12164 .64083 L
.12607 .63641 L
.13136 .63112 L
.13578 .62669 L
.14107 .62141 L
.14549 .61698 L
.15078 .61169 L
.15521 .60727 L
.16049 .60198 L
.16492 .59756 L
.17021 .59227 L
.17463 .58784 L
.17992 .58256 L
.18434 .57813 L
.18963 .57284 L
.19406 .56842 L
.19934 .56313 L
.20377 .55871 L
.20906 .55342 L
.21348 .54899 L
.21877 .54371 L
.22319 .53928 L
.22848 .53399 L
.23291 .52957 L
.23819 .52428 L
.24262 .51986 L
.24791 .51457 L
.25233 .51014 L
.25762 .50486 L
.26204 .50043 L
.26733 .49514 L
.27176 .49072 L
.27704 .48543 L
.28147 .48101 L
.28676 .47572 L
.29118 .47129 L
.29647 .46601 L
.30089 .46158 L
.30618 .45629 L
.31061 .45187 L
.31589 .44658 L
.32032 .44216 L
.32561 .43687 L
.33003 .43244 L
.33533 .42716 L
.33974 .42273 L
.34515 .41744 L
.34946 .41329 L
.35485 .40773 L
.35917 .40306 L
.36374 .39802 L
.36888 .39212 L
.37214 .38831 L
.37859 .3805 L
.38015 .37859 L
.38783 .36888 L
.38831 .36827 L
.39525 .35917 L
.39802 .35544 L
.40242 .34946 L
.40773 .34204 L
.40937 .33974 L
.41613 .33003 L
.41744 .32811 L
.42274 .32032 L
.42716 .31366 L
.42918 .31061 L
.43548 .30089 L
.43687 .29872 L
.44166 .29118 L
.44658 .28329 L
.44771 .28147 L
.45367 .27176 L
.45629 .2674 L
.45952 .26204 L
.46526 .25233 L
.46601 .25105 L
.47094 .24262 L
.47572 .23427 L
.4765 .23291 L
.48202 .22319 L
.48543 .21707 L
.48743 .21348 L
.4928 .20377 L
.49514 .19944 L
.49808 .19406 L
.50331 .18434 L
.50486 .18141 L
.50847 .17463 L
.51357 .16492 L
.51457 .16299 L
.51863 .15521 L
.52361 .14549 L
.52428 .14418 L
.52857 .13578 L
.53346 .12607 L
.53399 .12498 L
.53832 .11636 L
.54311 .10664 L
.54371 .10542 L
.54788 .09693 L
.55259 .08722 L
.55342 .08549 L
.55728 .07751 L
.56191 .06779 L
.56313 .0652 L
.56651 .05808 L
.57108 .04837 L
.57284 .04456 L
.5756 .03866 L
.58011 .02894 L
.58256 .02357 L
.58455 .01923 L
.01923 .01923 L
F
0 g
.01923 .74324 m
.02451 .73796 L
.02894 .73353 L
.03423 .72824 L
.03866 .72382 L
.04394 .71853 L
.04837 .71411 L
.05366 .70882 L
.05808 .70439 L
.06337 .69911 L
.06779 .69468 L
.07308 .68939 L
.07751 .68497 L
.08279 .67968 L
.08722 .67526 L
.09251 .66997 L
.09693 .66554 L
.10222 .66026 L
.10664 .65583 L
.11193 .65054 L
.11636 .64612 L
.12164 .64083 L
.12607 .63641 L
.13136 .63112 L
.13578 .62669 L
.14107 .62141 L
.14549 .61698 L
.15078 .61169 L
.15521 .60727 L
.16049 .60198 L
.16492 .59756 L
.17021 .59227 L
.17463 .58784 L
.17992 .58256 L
.18434 .57813 L
.18963 .57284 L
.19406 .56842 L
.19934 .56313 L
.20377 .55871 L
.20906 .55342 L
.21348 .54899 L
.21877 .54371 L
.22319 .53928 L
.22848 .53399 L
.23291 .52957 L
.23819 .52428 L
.24262 .51986 L
.24791 .51457 L
.25233 .51014 L
.25762 .50486 L
Mistroke
.26204 .50043 L
.26733 .49514 L
.27176 .49072 L
.27704 .48543 L
.28147 .48101 L
.28676 .47572 L
.29118 .47129 L
.29647 .46601 L
.30089 .46158 L
.30618 .45629 L
.31061 .45187 L
.31589 .44658 L
.32032 .44216 L
.32561 .43687 L
.33003 .43244 L
.33533 .42716 L
.33974 .42273 L
.34515 .41744 L
.34946 .41329 L
.35485 .40773 L
.35917 .40306 L
.36374 .39802 L
.36888 .39212 L
.37214 .38831 L
.37859 .3805 L
.38015 .37859 L
.38783 .36888 L
.38831 .36827 L
.39525 .35917 L
.39802 .35544 L
.40242 .34946 L
.40773 .34204 L
.40937 .33974 L
.41613 .33003 L
.41744 .32811 L
.42274 .32032 L
.42716 .31366 L
.42918 .31061 L
.43548 .30089 L
.43687 .29872 L
.44166 .29118 L
.44658 .28329 L
.44771 .28147 L
.45367 .27176 L
.45629 .2674 L
.45952 .26204 L
.46526 .25233 L
.46601 .25105 L
.47094 .24262 L
.47572 .23427 L
Mistroke
.4765 .23291 L
.48202 .22319 L
.48543 .21707 L
.48743 .21348 L
.4928 .20377 L
.49514 .19944 L
.49808 .19406 L
.50331 .18434 L
.50486 .18141 L
.50847 .17463 L
.51357 .16492 L
.51457 .16299 L
.51863 .15521 L
.52361 .14549 L
.52428 .14418 L
.52857 .13578 L
.53346 .12607 L
.53399 .12498 L
.53832 .11636 L
.54311 .10664 L
.54371 .10542 L
.54788 .09693 L
.55259 .08722 L
.55342 .08549 L
.55728 .07751 L
.56191 .06779 L
.56313 .0652 L
.56651 .05808 L
.57108 .04837 L
.57284 .04456 L
.5756 .03866 L
.58011 .02894 L
.58256 .02357 L
.58455 .01923 L
Mfstroke
.7 g
.01923 .69953 m
.01964 .69911 L
.02894 .68981 L
.02936 .68939 L
.03866 .6801 L
.03908 .67968 L
.04837 .67039 L
.04879 .66997 L
.05808 .66068 L
.0585 .66026 L
.06779 .65096 L
.06821 .65054 L
.07751 .64125 L
.07793 .64083 L
.08722 .63154 L
.08764 .63112 L
.09693 .62183 L
.09735 .62141 L
.10664 .61211 L
.10706 .61169 L
.11636 .6024 L
.11678 .60198 L
.12607 .59269 L
.12649 .59227 L
.13578 .58298 L
.1362 .58256 L
.14549 .57326 L
.14591 .57284 L
.15521 .56355 L
.15563 .56313 L
.16492 .55384 L
.16534 .55342 L
.17463 .54413 L
.17505 .54371 L
.18434 .53441 L
.18476 .53399 L
.19406 .5247 L
.19448 .52428 L
.20377 .51499 L
.20419 .51457 L
.21348 .50528 L
.2139 .50486 L
.22319 .49556 L
.22361 .49514 L
.23291 .48585 L
.23333 .48543 L
.24262 .47614 L
.24304 .47572 L
.25233 .46643 L
.25275 .46601 L
.26204 .45671 L
.26246 .45629 L
.27176 .447 L
.27218 .44658 L
.28147 .43729 L
.28189 .43687 L
.29118 .42758 L
.2916 .42716 L
.30089 .41786 L
.30131 .41744 L
.31061 .40815 L
.31103 .40773 L
.32032 .39844 L
.32074 .39802 L
.33003 .38873 L
.33044 .38831 L
.33974 .37901 L
.34025 .37859 L
.34946 .37202 L
.35356 .36888 L
.35917 .36372 L
.36421 .35917 L
.36888 .35435 L
.37375 .34946 L
.37859 .34405 L
.38255 .33974 L
.38831 .33295 L
.39081 .33003 L
.39802 .3211 L
.39865 .32032 L
.40628 .31061 L
.40773 .30859 L
.41358 .30089 L
.41744 .29544 L
.42056 .29118 L
.42716 .28168 L
.42731 .28147 L
.43404 .27176 L
.43687 .26739 L
.44048 .26204 L
.44658 .25253 L
.44671 .25233 L
.453 .24262 L
.45629 .23719 L
.459 .23291 L
.46494 .22319 L
.46601 .22134 L
.47081 .21348 L
.47572 .20502 L
.47646 .20377 L
.4822 .19406 L
.48543 .18825 L
.4877 .18434 L
.49322 .17463 L
.49514 .17103 L
.4986 .16492 L
.50391 .15521 L
.50486 .15337 L
.50921 .14549 L
.51433 .13578 L
.51457 .13529 L
.51955 .12607 L
.52428 .11681 L
.52452 .11636 L
.52965 .10664 L
.53399 .09794 L
.53452 .09693 L
.53954 .08722 L
.54371 .07867 L
.5443 .07751 L
.54923 .06779 L
.55342 .05903 L
.55389 .05808 L
.55873 .04837 L
.56313 .03901 L
.5633 .03866 L
.56807 .02894 L
.57258 .01923 L
.01923 .01923 L
F
0 g
.01923 .69953 m
.01964 .69911 L
.02894 .68981 L
.02936 .68939 L
.03866 .6801 L
.03908 .67968 L
.04837 .67039 L
.04879 .66997 L
.05808 .66068 L
.0585 .66026 L
.06779 .65096 L
.06821 .65054 L
.07751 .64125 L
.07793 .64083 L
.08722 .63154 L
.08764 .63112 L
.09693 .62183 L
.09735 .62141 L
.10664 .61211 L
.10706 .61169 L
.11636 .6024 L
.11678 .60198 L
.12607 .59269 L
.12649 .59227 L
.13578 .58298 L
.1362 .58256 L
.14549 .57326 L
.14591 .57284 L
.15521 .56355 L
.15563 .56313 L
.16492 .55384 L
.16534 .55342 L
.17463 .54413 L
.17505 .54371 L
.18434 .53441 L
.18476 .53399 L
.19406 .5247 L
.19448 .52428 L
.20377 .51499 L
.20419 .51457 L
.21348 .50528 L
.2139 .50486 L
.22319 .49556 L
.22361 .49514 L
.23291 .48585 L
.23333 .48543 L
.24262 .47614 L
.24304 .47572 L
.25233 .46643 L
.25275 .46601 L
Mistroke
.26204 .45671 L
.26246 .45629 L
.27176 .447 L
.27218 .44658 L
.28147 .43729 L
.28189 .43687 L
.29118 .42758 L
.2916 .42716 L
.30089 .41786 L
.30131 .41744 L
.31061 .40815 L
.31103 .40773 L
.32032 .39844 L
.32074 .39802 L
.33003 .38873 L
.33044 .38831 L
.33974 .37901 L
.34025 .37859 L
.34946 .37202 L
.35356 .36888 L
.35917 .36372 L
.36421 .35917 L
.36888 .35435 L
.37375 .34946 L
.37859 .34405 L
.38255 .33974 L
.38831 .33295 L
.39081 .33003 L
.39802 .3211 L
.39865 .32032 L
.40628 .31061 L
.40773 .30859 L
.41358 .30089 L
.41744 .29544 L
.42056 .29118 L
.42716 .28168 L
.42731 .28147 L
.43404 .27176 L
.43687 .26739 L
.44048 .26204 L
.44658 .25253 L
.44671 .25233 L
.453 .24262 L
.45629 .23719 L
.459 .23291 L
.46494 .22319 L
.46601 .22134 L
.47081 .21348 L
.47572 .20502 L
.47646 .20377 L
Mistroke
.4822 .19406 L
.48543 .18825 L
.4877 .18434 L
.49322 .17463 L
.49514 .17103 L
.4986 .16492 L
.50391 .15521 L
.50486 .15337 L
.50921 .14549 L
.51433 .13578 L
.51457 .13529 L
.51955 .12607 L
.52428 .11681 L
.52452 .11636 L
.52965 .10664 L
.53399 .09794 L
.53452 .09693 L
.53954 .08722 L
.54371 .07867 L
.5443 .07751 L
.54923 .06779 L
.55342 .05903 L
.55389 .05808 L
.55873 .04837 L
.56313 .03901 L
.5633 .03866 L
.56807 .02894 L
.57258 .01923 L
Mfstroke
.6 g
.01923 .62099 m
.02854 .61169 L
.02894 .61127 L
.03823 .60198 L
.03866 .60156 L
.04795 .59227 L
.04837 .59185 L
.05766 .58256 L
.05808 .58214 L
.06737 .57284 L
.06779 .57242 L
.07708 .56313 L
.07751 .56271 L
.0868 .55342 L
.08722 .553 L
.09651 .54371 L
.09693 .54329 L
.10622 .53399 L
.10664 .53357 L
.11593 .52428 L
.11636 .52386 L
.12565 .51457 L
.12607 .51415 L
.13536 .50486 L
.13578 .50444 L
.14507 .49514 L
.14549 .49472 L
.15478 .48543 L
.15521 .48501 L
.1645 .47572 L
.16492 .4753 L
.17421 .46601 L
.17463 .46559 L
.18392 .45629 L
.18434 .45587 L
.19363 .44658 L
.19406 .44616 L
.20335 .43687 L
.20377 .43645 L
.21306 .42716 L
.21348 .42674 L
.22277 .41744 L
.22319 .41702 L
.23248 .40773 L
.23291 .40731 L
.2422 .39802 L
.24262 .3976 L
.25191 .38831 L
.25233 .38789 L
.26162 .37859 L
.26204 .37817 L
.27134 .36888 L
.27176 .36846 L
.28105 .35917 L
.28147 .35875 L
.29076 .34946 L
.29118 .34904 L
.30047 .33974 L
.30089 .33932 L
.31019 .33003 L
.31061 .32961 L
.3199 .32032 L
.32032 .3199 L
.32961 .31061 L
.33003 .31019 L
.33937 .30089 L
.33974 .30047 L
.34669 .29118 L
.34946 .28732 L
.35377 .28147 L
.35917 .27411 L
.36089 .27176 L
.36791 .26204 L
.36888 .26069 L
.37481 .25233 L
.37859 .24694 L
.38159 .24262 L
.38828 .23291 L
.38831 .23287 L
.39481 .22319 L
.39802 .21839 L
.40124 .21348 L
.4076 .20377 L
.40773 .20356 L
.41379 .19406 L
.41744 .18831 L
.4199 .18434 L
.42595 .17463 L
.42716 .17268 L
.43185 .16492 L
.43687 .15665 L
.43772 .15521 L
.44347 .14549 L
.44658 .14022 L
.44913 .13578 L
.45476 .12607 L
.45629 .12341 L
.46026 .11636 L
.46577 .10664 L
.46601 .10622 L
.47112 .09693 L
.47572 .08863 L
.47647 .08722 L
.48172 .07751 L
.48543 .07068 L
.48693 .06779 L
.4921 .05808 L
.49514 .05235 L
.49718 .04837 L
.50225 .03866 L
.50486 .03367 L
.50722 .02894 L
.51221 .01923 L
.01923 .01923 L
F
0 g
.01923 .62099 m
.02854 .61169 L
.02894 .61127 L
.03823 .60198 L
.03866 .60156 L
.04795 .59227 L
.04837 .59185 L
.05766 .58256 L
.05808 .58214 L
.06737 .57284 L
.06779 .57242 L
.07708 .56313 L
.07751 .56271 L
.0868 .55342 L
.08722 .553 L
.09651 .54371 L
.09693 .54329 L
.10622 .53399 L
.10664 .53357 L
.11593 .52428 L
.11636 .52386 L
.12565 .51457 L
.12607 .51415 L
.13536 .50486 L
.13578 .50444 L
.14507 .49514 L
.14549 .49472 L
.15478 .48543 L
.15521 .48501 L
.1645 .47572 L
.16492 .4753 L
.17421 .46601 L
.17463 .46559 L
.18392 .45629 L
.18434 .45587 L
.19363 .44658 L
.19406 .44616 L
.20335 .43687 L
.20377 .43645 L
.21306 .42716 L
.21348 .42674 L
.22277 .41744 L
.22319 .41702 L
.23248 .40773 L
.23291 .40731 L
.2422 .39802 L
.24262 .3976 L
.25191 .38831 L
.25233 .38789 L
.26162 .37859 L
Mistroke
.26204 .37817 L
.27134 .36888 L
.27176 .36846 L
.28105 .35917 L
.28147 .35875 L
.29076 .34946 L
.29118 .34904 L
.30047 .33974 L
.30089 .33932 L
.31019 .33003 L
.31061 .32961 L
.3199 .32032 L
.32032 .3199 L
.32961 .31061 L
.33003 .31019 L
.33937 .30089 L
.33974 .30047 L
.34669 .29118 L
.34946 .28732 L
.35377 .28147 L
.35917 .27411 L
.36089 .27176 L
.36791 .26204 L
.36888 .26069 L
.37481 .25233 L
.37859 .24694 L
.38159 .24262 L
.38828 .23291 L
.38831 .23287 L
.39481 .22319 L
.39802 .21839 L
.40124 .21348 L
.4076 .20377 L
.40773 .20356 L
.41379 .19406 L
.41744 .18831 L
.4199 .18434 L
.42595 .17463 L
.42716 .17268 L
.43185 .16492 L
.43687 .15665 L
.43772 .15521 L
.44347 .14549 L
.44658 .14022 L
.44913 .13578 L
.45476 .12607 L
.45629 .12341 L
.46026 .11636 L
.46577 .10664 L
.46601 .10622 L
Mistroke
.47112 .09693 L
.47572 .08863 L
.47647 .08722 L
.48172 .07751 L
.48543 .07068 L
.48693 .06779 L
.4921 .05808 L
.49514 .05235 L
.49718 .04837 L
.50225 .03866 L
.50486 .03367 L
.50722 .02894 L
.51221 .01923 L
Mfstroke
.5 g
.01923 .57727 m
.02367 .57284 L
.02894 .56756 L
.03337 .56313 L
.03866 .55784 L
.04308 .55342 L
.04837 .54813 L
.05279 .54371 L
.05808 .53842 L
.06251 .53399 L
.06779 .52871 L
.07222 .52428 L
.07751 .51899 L
.08193 .51457 L
.08722 .50928 L
.09164 .50486 L
.09693 .49957 L
.10136 .49514 L
.10664 .48986 L
.11107 .48543 L
.11636 .48014 L
.12078 .47572 L
.12607 .47043 L
.13049 .46601 L
.13578 .46072 L
.14021 .45629 L
.14549 .45101 L
.14992 .44658 L
.15521 .44129 L
.15963 .43687 L
.16492 .43158 L
.16934 .42716 L
.17463 .42187 L
.17906 .41744 L
.18434 .41216 L
.18877 .40773 L
.19406 .40244 L
.19848 .39802 L
.20377 .39273 L
.20819 .38831 L
.21348 .38302 L
.21791 .37859 L
.22319 .37331 L
.22762 .36888 L
.23291 .36359 L
.23733 .35917 L
.24262 .35388 L
.24704 .34946 L
.25233 .34417 L
.25676 .33974 L
.26204 .33446 L
.26647 .33003 L
.27176 .32474 L
.27618 .32032 L
.28147 .31503 L
.28589 .31061 L
.29118 .30532 L
.29561 .30089 L
.30089 .29561 L
.30532 .29118 L
.31061 .28589 L
.31503 .28147 L
.32032 .27618 L
.32474 .27176 L
.33003 .26647 L
.33454 .26204 L
.33974 .25676 L
.34382 .25233 L
.34946 .24606 L
.35247 .24262 L
.35917 .23477 L
.36073 .23291 L
.36865 .22319 L
.36888 .22291 L
.3763 .21348 L
.37859 .21049 L
.38369 .20377 L
.38831 .19754 L
.39085 .19406 L
.39783 .18434 L
.39802 .18407 L
.40462 .17463 L
.40773 .1701 L
.41125 .16492 L
.41744 .15564 L
.41773 .15521 L
.42408 .14549 L
.42716 .14071 L
.43029 .13578 L
.4364 .12607 L
.43687 .12532 L
.4424 .11636 L
.44658 .10948 L
.44829 .10664 L
.45409 .09693 L
.45629 .0932 L
.4598 .08722 L
.46543 .07751 L
.46601 .0765 L
.47097 .06779 L
.47572 .05938 L
.47645 .05808 L
.48185 .04837 L
.48543 .04186 L
.48718 .03866 L
.49245 .02894 L
.49514 .02394 L
.49765 .01923 L
.01923 .01923 L
F
0 g
.01923 .57727 m
.02367 .57284 L
.02894 .56756 L
.03337 .56313 L
.03866 .55784 L
.04308 .55342 L
.04837 .54813 L
.05279 .54371 L
.05808 .53842 L
.06251 .53399 L
.06779 .52871 L
.07222 .52428 L
.07751 .51899 L
.08193 .51457 L
.08722 .50928 L
.09164 .50486 L
.09693 .49957 L
.10136 .49514 L
.10664 .48986 L
.11107 .48543 L
.11636 .48014 L
.12078 .47572 L
.12607 .47043 L
.13049 .46601 L
.13578 .46072 L
.14021 .45629 L
.14549 .45101 L
.14992 .44658 L
.15521 .44129 L
.15963 .43687 L
.16492 .43158 L
.16934 .42716 L
.17463 .42187 L
.17906 .41744 L
.18434 .41216 L
.18877 .40773 L
.19406 .40244 L
.19848 .39802 L
.20377 .39273 L
.20819 .38831 L
.21348 .38302 L
.21791 .37859 L
.22319 .37331 L
.22762 .36888 L
.23291 .36359 L
.23733 .35917 L
.24262 .35388 L
.24704 .34946 L
.25233 .34417 L
.25676 .33974 L
Mistroke
.26204 .33446 L
.26647 .33003 L
.27176 .32474 L
.27618 .32032 L
.28147 .31503 L
.28589 .31061 L
.29118 .30532 L
.29561 .30089 L
.30089 .29561 L
.30532 .29118 L
.31061 .28589 L
.31503 .28147 L
.32032 .27618 L
.32474 .27176 L
.33003 .26647 L
.33454 .26204 L
.33974 .25676 L
.34382 .25233 L
.34946 .24606 L
.35247 .24262 L
.35917 .23477 L
.36073 .23291 L
.36865 .22319 L
.36888 .22291 L
.3763 .21348 L
.37859 .21049 L
.38369 .20377 L
.38831 .19754 L
.39085 .19406 L
.39783 .18434 L
.39802 .18407 L
.40462 .17463 L
.40773 .1701 L
.41125 .16492 L
.41744 .15564 L
.41773 .15521 L
.42408 .14549 L
.42716 .14071 L
.43029 .13578 L
.4364 .12607 L
.43687 .12532 L
.4424 .11636 L
.44658 .10948 L
.44829 .10664 L
.45409 .09693 L
.45629 .0932 L
.4598 .08722 L
.46543 .07751 L
.46601 .0765 L
.47097 .06779 L
Mistroke
.47572 .05938 L
.47645 .05808 L
.48185 .04837 L
.48543 .04186 L
.48718 .03866 L
.49245 .02894 L
.49514 .02394 L
.49765 .01923 L
Mfstroke
.4 g
.01923 .54186 m
.02709 .53399 L
.02894 .53215 L
.03681 .52428 L
.03866 .52243 L
.04652 .51457 L
.04837 .51272 L
.05623 .50486 L
.05808 .50301 L
.06595 .49514 L
.06779 .4933 L
.07566 .48543 L
.07751 .48358 L
.08537 .47572 L
.08722 .47387 L
.09508 .46601 L
.09693 .46416 L
.1048 .45629 L
.10664 .45445 L
.11451 .44658 L
.11636 .44473 L
.12422 .43687 L
.12607 .43502 L
.13393 .42716 L
.13578 .42531 L
.14365 .41744 L
.14549 .4156 L
.15336 .40773 L
.15521 .40588 L
.16307 .39802 L
.16492 .39617 L
.17278 .38831 L
.17463 .38646 L
.1825 .37859 L
.18434 .37675 L
.19221 .36888 L
.19406 .36703 L
.20192 .35917 L
.20377 .35732 L
.21163 .34946 L
.21348 .34761 L
.22135 .33974 L
.22319 .3379 L
.23106 .33003 L
.23291 .32818 L
.24077 .32032 L
.24262 .31847 L
.25048 .31061 L
.25233 .30876 L
.2602 .30089 L
.26204 .29905 L
.26991 .29118 L
.27176 .28933 L
.27962 .28147 L
.28147 .27962 L
.28933 .27176 L
.29118 .26991 L
.29905 .26204 L
.30089 .2602 L
.30876 .25233 L
.31061 .25048 L
.31847 .24262 L
.32032 .24077 L
.32818 .23291 L
.33003 .23106 L
.3379 .22319 L
.33974 .22135 L
.34782 .21348 L
.34946 .2119 L
.35726 .20377 L
.35917 .20168 L
.36602 .19406 L
.36888 .19073 L
.37431 .18434 L
.37859 .17912 L
.38223 .17463 L
.38831 .16688 L
.38983 .16492 L
.39717 .15521 L
.39802 .15405 L
.40429 .14549 L
.40773 .14066 L
.41119 .13578 L
.41744 .12673 L
.41789 .12607 L
.42446 .11636 L
.42716 .11228 L
.43087 .10664 L
.43687 .09733 L
.43712 .09693 L
.44328 .08722 L
.44658 .08191 L
.44931 .07751 L
.45523 .06779 L
.45629 .06601 L
.46106 .05808 L
.46601 .04967 L
.46677 .04837 L
.47243 .03866 L
.47572 .03289 L
.47798 .02894 L
.48346 .01923 L
.01923 .01923 L
F
0 g
.01923 .54186 m
.02709 .53399 L
.02894 .53215 L
.03681 .52428 L
.03866 .52243 L
.04652 .51457 L
.04837 .51272 L
.05623 .50486 L
.05808 .50301 L
.06595 .49514 L
.06779 .4933 L
.07566 .48543 L
.07751 .48358 L
.08537 .47572 L
.08722 .47387 L
.09508 .46601 L
.09693 .46416 L
.1048 .45629 L
.10664 .45445 L
.11451 .44658 L
.11636 .44473 L
.12422 .43687 L
.12607 .43502 L
.13393 .42716 L
.13578 .42531 L
.14365 .41744 L
.14549 .4156 L
.15336 .40773 L
.15521 .40588 L
.16307 .39802 L
.16492 .39617 L
.17278 .38831 L
.17463 .38646 L
.1825 .37859 L
.18434 .37675 L
.19221 .36888 L
.19406 .36703 L
.20192 .35917 L
.20377 .35732 L
.21163 .34946 L
.21348 .34761 L
.22135 .33974 L
.22319 .3379 L
.23106 .33003 L
.23291 .32818 L
.24077 .32032 L
.24262 .31847 L
.25048 .31061 L
.25233 .30876 L
.2602 .30089 L
Mistroke
.26204 .29905 L
.26991 .29118 L
.27176 .28933 L
.27962 .28147 L
.28147 .27962 L
.28933 .27176 L
.29118 .26991 L
.29905 .26204 L
.30089 .2602 L
.30876 .25233 L
.31061 .25048 L
.31847 .24262 L
.32032 .24077 L
.32818 .23291 L
.33003 .23106 L
.3379 .22319 L
.33974 .22135 L
.34782 .21348 L
.34946 .2119 L
.35726 .20377 L
.35917 .20168 L
.36602 .19406 L
.36888 .19073 L
.37431 .18434 L
.37859 .17912 L
.38223 .17463 L
.38831 .16688 L
.38983 .16492 L
.39717 .15521 L
.39802 .15405 L
.40429 .14549 L
.40773 .14066 L
.41119 .13578 L
.41744 .12673 L
.41789 .12607 L
.42446 .11636 L
.42716 .11228 L
.43087 .10664 L
.43687 .09733 L
.43712 .09693 L
.44328 .08722 L
.44658 .08191 L
.44931 .07751 L
.45523 .06779 L
.45629 .06601 L
.46106 .05808 L
.46601 .04967 L
.46677 .04837 L
.47243 .03866 L
.47572 .03289 L
Mistroke
.47798 .02894 L
.48346 .01923 L
Mfstroke
.3 g
.01923 .49817 m
.02219 .49514 L
.02894 .48846 L
.03197 .48543 L
.03866 .47875 L
.04168 .47572 L
.04837 .46903 L
.0514 .46601 L
.05808 .45932 L
.06111 .45629 L
.06779 .44961 L
.07082 .44658 L
.07751 .4399 L
.08053 .43687 L
.08722 .43018 L
.09025 .42716 L
.09693 .42047 L
.09996 .41744 L
.10664 .41076 L
.10967 .40773 L
.11636 .40105 L
.11938 .39802 L
.12607 .39133 L
.1291 .38831 L
.13578 .38162 L
.13881 .37859 L
.14549 .37191 L
.14852 .36888 L
.15521 .3622 L
.15823 .35917 L
.16492 .35248 L
.16795 .34946 L
.17463 .34277 L
.17766 .33974 L
.18434 .33306 L
.18737 .33003 L
.19406 .32335 L
.19708 .32032 L
.20377 .31363 L
.2068 .31061 L
.21348 .30392 L
.21651 .30089 L
.22319 .29421 L
.22622 .29118 L
.23291 .2845 L
.23593 .28147 L
.24262 .27478 L
.24565 .27176 L
.25233 .26507 L
.25536 .26204 L
.26204 .25536 L
.26507 .25233 L
.27176 .24565 L
.27478 .24262 L
.28147 .23593 L
.2845 .23291 L
.29118 .22622 L
.29421 .22319 L
.30089 .21651 L
.30392 .21348 L
.31061 .2068 L
.31363 .20377 L
.32032 .19708 L
.32335 .19406 L
.33003 .18737 L
.33299 .18434 L
.33974 .17766 L
.34358 .17463 L
.34946 .17065 L
.35663 .16492 L
.35917 .16234 L
.36684 .15521 L
.36888 .15296 L
.37616 .14549 L
.37859 .14267 L
.38484 .13578 L
.38831 .13157 L
.393 .12607 L
.39802 .11972 L
.40074 .11636 L
.40773 .10719 L
.40816 .10664 L
.41545 .09693 L
.41744 .09406 L
.42242 .08722 L
.42716 .08031 L
.42913 .07751 L
.43573 .06779 L
.43687 .066 L
.44219 .05808 L
.44658 .05116 L
.44841 .04837 L
.45459 .03866 L
.45629 .03581 L
.46062 .02894 L
.46601 .01995 L
.46645 .01923 L
.01923 .01923 L
F
0 g
.01923 .49817 m
.02219 .49514 L
.02894 .48846 L
.03197 .48543 L
.03866 .47875 L
.04168 .47572 L
.04837 .46903 L
.0514 .46601 L
.05808 .45932 L
.06111 .45629 L
.06779 .44961 L
.07082 .44658 L
.07751 .4399 L
.08053 .43687 L
.08722 .43018 L
.09025 .42716 L
.09693 .42047 L
.09996 .41744 L
.10664 .41076 L
.10967 .40773 L
.11636 .40105 L
.11938 .39802 L
.12607 .39133 L
.1291 .38831 L
.13578 .38162 L
.13881 .37859 L
.14549 .37191 L
.14852 .36888 L
.15521 .3622 L
.15823 .35917 L
.16492 .35248 L
.16795 .34946 L
.17463 .34277 L
.17766 .33974 L
.18434 .33306 L
.18737 .33003 L
.19406 .32335 L
.19708 .32032 L
.20377 .31363 L
.2068 .31061 L
.21348 .30392 L
.21651 .30089 L
.22319 .29421 L
.22622 .29118 L
.23291 .2845 L
.23593 .28147 L
.24262 .27478 L
.24565 .27176 L
.25233 .26507 L
.25536 .26204 L
Mistroke
.26204 .25536 L
.26507 .25233 L
.27176 .24565 L
.27478 .24262 L
.28147 .23593 L
.2845 .23291 L
.29118 .22622 L
.29421 .22319 L
.30089 .21651 L
.30392 .21348 L
.31061 .2068 L
.31363 .20377 L
.32032 .19708 L
.32335 .19406 L
.33003 .18737 L
.33299 .18434 L
.33974 .17766 L
.34358 .17463 L
.34946 .17065 L
.35663 .16492 L
.35917 .16234 L
.36684 .15521 L
.36888 .15296 L
.37616 .14549 L
.37859 .14267 L
.38484 .13578 L
.38831 .13157 L
.393 .12607 L
.39802 .11972 L
.40074 .11636 L
.40773 .10719 L
.40816 .10664 L
.41545 .09693 L
.41744 .09406 L
.42242 .08722 L
.42716 .08031 L
.42913 .07751 L
.43573 .06779 L
.43687 .066 L
.44219 .05808 L
.44658 .05116 L
.44841 .04837 L
.45459 .03866 L
.45629 .03581 L
.46062 .02894 L
.46601 .01995 L
.46645 .01923 L
Mfstroke
.4 g
.01923 .41956 m
.02172 .41744 L
.02894 .40985 L
.03106 .40773 L
.03866 .40014 L
.04078 .39802 L
.04837 .39043 L
.05049 .38831 L
.05808 .38071 L
.0602 .37859 L
.06779 .371 L
.06991 .36888 L
.07751 .36129 L
.07963 .35917 L
.08722 .35158 L
.08934 .34946 L
.09693 .34186 L
.09905 .33974 L
.10664 .33215 L
.10876 .33003 L
.11636 .32244 L
.11848 .32032 L
.12607 .31273 L
.12819 .31061 L
.13578 .30301 L
.1379 .30089 L
.14549 .2933 L
.14761 .29118 L
.15521 .28359 L
.15733 .28147 L
.16492 .27388 L
.16704 .27176 L
.17463 .26416 L
.17675 .26204 L
.18434 .25445 L
.18646 .25233 L
.19406 .24474 L
.19618 .24262 L
.20377 .23503 L
.20589 .23291 L
.21348 .22531 L
.2156 .22319 L
.22319 .2156 L
.22531 .21348 L
.23291 .20589 L
.23503 .20377 L
.24262 .19618 L
.24474 .19406 L
.25233 .18646 L
.25445 .18434 L
.26204 .17675 L
.26416 .17463 L
.27176 .16704 L
.27388 .16492 L
.28147 .15733 L
.28359 .15521 L
.29118 .14761 L
.2933 .14549 L
.30089 .1379 L
.30301 .13578 L
.31061 .12819 L
.31273 .12607 L
.32032 .11848 L
.32244 .11636 L
.33003 .10876 L
.33236 .10664 L
.33974 .09905 L
.34143 .09693 L
.34855 .08722 L
.34946 .08595 L
.35567 .07751 L
.35917 .07272 L
.36275 .06779 L
.36888 .0593 L
.36975 .05808 L
.37663 .04837 L
.37859 .04556 L
.38337 .03866 L
.38831 .03147 L
.39001 .02894 L
.39655 .01923 L
.01923 .01923 L
F
0 g
.01923 .41956 m
.02172 .41744 L
.02894 .40985 L
.03106 .40773 L
.03866 .40014 L
.04078 .39802 L
.04837 .39043 L
.05049 .38831 L
.05808 .38071 L
.0602 .37859 L
.06779 .371 L
.06991 .36888 L
.07751 .36129 L
.07963 .35917 L
.08722 .35158 L
.08934 .34946 L
.09693 .34186 L
.09905 .33974 L
.10664 .33215 L
.10876 .33003 L
.11636 .32244 L
.11848 .32032 L
.12607 .31273 L
.12819 .31061 L
.13578 .30301 L
.1379 .30089 L
.14549 .2933 L
.14761 .29118 L
.15521 .28359 L
.15733 .28147 L
.16492 .27388 L
.16704 .27176 L
.17463 .26416 L
.17675 .26204 L
.18434 .25445 L
.18646 .25233 L
.19406 .24474 L
.19618 .24262 L
.20377 .23503 L
.20589 .23291 L
.21348 .22531 L
.2156 .22319 L
.22319 .2156 L
.22531 .21348 L
.23291 .20589 L
.23503 .20377 L
.24262 .19618 L
.24474 .19406 L
.25233 .18646 L
.25445 .18434 L
Mistroke
.26204 .17675 L
.26416 .17463 L
.27176 .16704 L
.27388 .16492 L
.28147 .15733 L
.28359 .15521 L
.29118 .14761 L
.2933 .14549 L
.30089 .1379 L
.30301 .13578 L
.31061 .12819 L
.31273 .12607 L
.32032 .11848 L
.32244 .11636 L
.33003 .10876 L
.33236 .10664 L
.33974 .09905 L
.34143 .09693 L
.34855 .08722 L
.34946 .08595 L
.35567 .07751 L
.35917 .07272 L
.36275 .06779 L
.36888 .0593 L
.36975 .05808 L
.37663 .04837 L
.37859 .04556 L
.38337 .03866 L
.38831 .03147 L
.39001 .02894 L
.39655 .01923 L
Mfstroke
.5 g
.01923 .37589 m
.02624 .36888 L
.02894 .36617 L
.03595 .35917 L
.03866 .35646 L
.04566 .34946 L
.04837 .34675 L
.05537 .33974 L
.05808 .33704 L
.06509 .33003 L
.06779 .32732 L
.0748 .32032 L
.07751 .31761 L
.08451 .31061 L
.08722 .3079 L
.09422 .30089 L
.09693 .29819 L
.10394 .29118 L
.10664 .28847 L
.11365 .28147 L
.11636 .27876 L
.12336 .27176 L
.12607 .26905 L
.13307 .26204 L
.13578 .25934 L
.14279 .25233 L
.14549 .24962 L
.1525 .24262 L
.15521 .23991 L
.16221 .23291 L
.16492 .2302 L
.17192 .22319 L
.17463 .22049 L
.18164 .21348 L
.18434 .21077 L
.19135 .20377 L
.19406 .20106 L
.20106 .19406 L
.20377 .19135 L
.21077 .18434 L
.21348 .18164 L
.22049 .17463 L
.22319 .17192 L
.2302 .16492 L
.23291 .16221 L
.23991 .15521 L
.24262 .1525 L
.24962 .14549 L
.25233 .14279 L
.25934 .13578 L
.26204 .13307 L
.26905 .12607 L
.27176 .12336 L
.27876 .11636 L
.28147 .11365 L
.28847 .10664 L
.29118 .10394 L
.29819 .09693 L
.30089 .09422 L
.3079 .08722 L
.31061 .08451 L
.31761 .07751 L
.32032 .0748 L
.32732 .06779 L
.33003 .06509 L
.33711 .05808 L
.33974 .05537 L
.34615 .04837 L
.34946 .04467 L
.3547 .03866 L
.35917 .03338 L
.36286 .02894 L
.36888 .02153 L
.37071 .01923 L
.01923 .01923 L
F
0 g
.01923 .37589 m
.02624 .36888 L
.02894 .36617 L
.03595 .35917 L
.03866 .35646 L
.04566 .34946 L
.04837 .34675 L
.05537 .33974 L
.05808 .33704 L
.06509 .33003 L
.06779 .32732 L
.0748 .32032 L
.07751 .31761 L
.08451 .31061 L
.08722 .3079 L
.09422 .30089 L
.09693 .29819 L
.10394 .29118 L
.10664 .28847 L
.11365 .28147 L
.11636 .27876 L
.12336 .27176 L
.12607 .26905 L
.13307 .26204 L
.13578 .25934 L
.14279 .25233 L
.14549 .24962 L
.1525 .24262 L
.15521 .23991 L
.16221 .23291 L
.16492 .2302 L
.17192 .22319 L
.17463 .22049 L
.18164 .21348 L
.18434 .21077 L
.19135 .20377 L
.19406 .20106 L
.20106 .19406 L
.20377 .19135 L
.21077 .18434 L
.21348 .18164 L
.22049 .17463 L
.22319 .17192 L
.2302 .16492 L
.23291 .16221 L
.23991 .15521 L
.24262 .1525 L
.24962 .14549 L
.25233 .14279 L
.25934 .13578 L
Mistroke
.26204 .13307 L
.26905 .12607 L
.27176 .12336 L
.27876 .11636 L
.28147 .11365 L
.28847 .10664 L
.29118 .10394 L
.29819 .09693 L
.30089 .09422 L
.3079 .08722 L
.31061 .08451 L
.31761 .07751 L
.32032 .0748 L
.32732 .06779 L
.33003 .06509 L
.33711 .05808 L
.33974 .05537 L
.34615 .04837 L
.34946 .04467 L
.3547 .03866 L
.35917 .03338 L
.36286 .02894 L
.36888 .02153 L
.37071 .01923 L
Mfstroke
.6 g
.01923 .34047 m
.01996 .33974 L
.02894 .33076 L
.02967 .33003 L
.03866 .32105 L
.03939 .32032 L
.04837 .31134 L
.0491 .31061 L
.05808 .30162 L
.05881 .30089 L
.06779 .29191 L
.06852 .29118 L
.07751 .2822 L
.07824 .28147 L
.08722 .27249 L
.08795 .27176 L
.09693 .26277 L
.09766 .26204 L
.10664 .25306 L
.10737 .25233 L
.11636 .24335 L
.11709 .24262 L
.12607 .23364 L
.1268 .23291 L
.13578 .22392 L
.13651 .22319 L
.14549 .21421 L
.14622 .21348 L
.15521 .2045 L
.15594 .20377 L
.16492 .19479 L
.16565 .19406 L
.17463 .18507 L
.17536 .18434 L
.18434 .17536 L
.18507 .17463 L
.19406 .16565 L
.19479 .16492 L
.20377 .15594 L
.2045 .15521 L
.21348 .14622 L
.21421 .14549 L
.22319 .13651 L
.22392 .13578 L
.23291 .1268 L
.23364 .12607 L
.24262 .11709 L
.24335 .11636 L
.25233 .10737 L
.25306 .10664 L
.26204 .09766 L
.26277 .09693 L
.27176 .08795 L
.27249 .08722 L
.28147 .07824 L
.2822 .07751 L
.29118 .06852 L
.29191 .06779 L
.30089 .05881 L
.30162 .05808 L
.31061 .0491 L
.31134 .04837 L
.32032 .03939 L
.32105 .03866 L
.33003 .02967 L
.33077 .02894 L
.33974 .01996 L
.34048 .01923 L
.01923 .01923 L
F
0 g
.01923 .34047 m
.01996 .33974 L
.02894 .33076 L
.02967 .33003 L
.03866 .32105 L
.03939 .32032 L
.04837 .31134 L
.0491 .31061 L
.05808 .30162 L
.05881 .30089 L
.06779 .29191 L
.06852 .29118 L
.07751 .2822 L
.07824 .28147 L
.08722 .27249 L
.08795 .27176 L
.09693 .26277 L
.09766 .26204 L
.10664 .25306 L
.10737 .25233 L
.11636 .24335 L
.11709 .24262 L
.12607 .23364 L
.1268 .23291 L
.13578 .22392 L
.13651 .22319 L
.14549 .21421 L
.14622 .21348 L
.15521 .2045 L
.15594 .20377 L
.16492 .19479 L
.16565 .19406 L
.17463 .18507 L
.17536 .18434 L
.18434 .17536 L
.18507 .17463 L
.19406 .16565 L
.19479 .16492 L
.20377 .15594 L
.2045 .15521 L
.21348 .14622 L
.21421 .14549 L
.22319 .13651 L
.22392 .13578 L
.23291 .1268 L
.23364 .12607 L
.24262 .11709 L
.24335 .11636 L
.25233 .10737 L
.25306 .10664 L
Mistroke
.26204 .09766 L
.26277 .09693 L
.27176 .08795 L
.27249 .08722 L
.28147 .07824 L
.2822 .07751 L
.29118 .06852 L
.29191 .06779 L
.30089 .05881 L
.30162 .05808 L
.31061 .0491 L
.31134 .04837 L
.32032 .03939 L
.32105 .03866 L
.33003 .02967 L
.33077 .02894 L
.33974 .01996 L
.34048 .01923 L
Mfstroke
.7 g
.01923 .2968 m
.02477 .29118 L
.02894 .28709 L
.03457 .28147 L
.03866 .27738 L
.04428 .27176 L
.04837 .26767 L
.05399 .26204 L
.05808 .25795 L
.0637 .25233 L
.06779 .24824 L
.07342 .24262 L
.07751 .23853 L
.08313 .23291 L
.08722 .22882 L
.09284 .22319 L
.09693 .2191 L
.10255 .21348 L
.10664 .20939 L
.11227 .20377 L
.11636 .19968 L
.12198 .19406 L
.12607 .18997 L
.13169 .18434 L
.13578 .18025 L
.1414 .17463 L
.14549 .17054 L
.15112 .16492 L
.15521 .16083 L
.16083 .15521 L
.16492 .15112 L
.17054 .14549 L
.17463 .1414 L
.18025 .13578 L
.18434 .13169 L
.18997 .12607 L
.19406 .12198 L
.19968 .11636 L
.20377 .11227 L
.20939 .10664 L
.21348 .10255 L
.2191 .09693 L
.22319 .09284 L
.22882 .08722 L
.23291 .08313 L
.23853 .07751 L
.24262 .07342 L
.24824 .06779 L
.25233 .0637 L
.25795 .05808 L
.26204 .05399 L
.26767 .04837 L
.27176 .04428 L
.27738 .03866 L
.28147 .03457 L
.28709 .02894 L
.29118 .02477 L
.2968 .01923 L
.01923 .01923 L
F
0 g
.01923 .2968 m
.02477 .29118 L
.02894 .28709 L
.03457 .28147 L
.03866 .27738 L
.04428 .27176 L
.04837 .26767 L
.05399 .26204 L
.05808 .25795 L
.0637 .25233 L
.06779 .24824 L
.07342 .24262 L
.07751 .23853 L
.08313 .23291 L
.08722 .22882 L
.09284 .22319 L
.09693 .2191 L
.10255 .21348 L
.10664 .20939 L
.11227 .20377 L
.11636 .19968 L
.12198 .19406 L
.12607 .18997 L
.13169 .18434 L
.13578 .18025 L
.1414 .17463 L
.14549 .17054 L
.15112 .16492 L
.15521 .16083 L
.16083 .15521 L
.16492 .15112 L
.17054 .14549 L
.17463 .1414 L
.18025 .13578 L
.18434 .13169 L
.18997 .12607 L
.19406 .12198 L
.19968 .11636 L
.20377 .11227 L
.20939 .10664 L
.21348 .10255 L
.2191 .09693 L
.22319 .09284 L
.22882 .08722 L
.23291 .08313 L
.23853 .07751 L
.24262 .07342 L
.24824 .06779 L
.25233 .0637 L
.25795 .05808 L
Mistroke
.26204 .05399 L
.26767 .04837 L
.27176 .04428 L
.27738 .03866 L
.28147 .03457 L
.28709 .02894 L
.29118 .02477 L
.2968 .01923 L
Mfstroke
.6 g
.01923 .21817 m
.02422 .21348 L
.02894 .20846 L
.03364 .20377 L
.03866 .19875 L
.04335 .19406 L
.04837 .18904 L
.05306 .18434 L
.05808 .17932 L
.06277 .17463 L
.06779 .16961 L
.07249 .16492 L
.07751 .1599 L
.0822 .15521 L
.08722 .15019 L
.09191 .14549 L
.09693 .14047 L
.10162 .13578 L
.10664 .13076 L
.11134 .12607 L
.11636 .12105 L
.12105 .11636 L
.12607 .11134 L
.13076 .10664 L
.13578 .10162 L
.14047 .09693 L
.14549 .09191 L
.15019 .08722 L
.15521 .0822 L
.1599 .07751 L
.16492 .07249 L
.16961 .06779 L
.17463 .06277 L
.17932 .05808 L
.18434 .05306 L
.18904 .04837 L
.19406 .04335 L
.19875 .03866 L
.20377 .03364 L
.20846 .02894 L
.21348 .02422 L
.21817 .01923 L
.01923 .01923 L
F
0 g
.01923 .21817 m
.02422 .21348 L
.02894 .20846 L
.03364 .20377 L
.03866 .19875 L
.04335 .19406 L
.04837 .18904 L
.05306 .18434 L
.05808 .17932 L
.06277 .17463 L
.06779 .16961 L
.07249 .16492 L
.07751 .1599 L
.0822 .15521 L
.08722 .15019 L
.09191 .14549 L
.09693 .14047 L
.10162 .13578 L
.10664 .13076 L
.11134 .12607 L
.11636 .12105 L
.12105 .11636 L
.12607 .11134 L
.13076 .10664 L
.13578 .10162 L
.14047 .09693 L
.14549 .09191 L
.15019 .08722 L
.15521 .0822 L
.1599 .07751 L
.16492 .07249 L
.16961 .06779 L
.17463 .06277 L
.17932 .05808 L
.18434 .05306 L
.18904 .04837 L
.19406 .04335 L
.19875 .03866 L
.20377 .03364 L
.20846 .02894 L
.21348 .02422 L
.21817 .01923 L
s
.5 g
.01923 .1745 m
.02882 .16492 L
.02894 .16479 L
.03853 .15521 L
.03866 .15508 L
.04824 .14549 L
.04837 .14537 L
.05795 .13578 L
.05808 .13565 L
.06767 .12607 L
.06779 .12594 L
.07738 .11636 L
.07751 .11623 L
.08709 .10664 L
.08722 .10652 L
.0968 .09693 L
.09693 .0968 L
.10652 .08722 L
.10664 .08709 L
.11623 .07751 L
.11636 .07738 L
.12594 .06779 L
.12607 .06767 L
.13565 .05808 L
.13578 .05795 L
.14537 .04837 L
.14549 .04824 L
.15508 .03866 L
.15521 .03853 L
.16479 .02894 L
.16492 .02882 L
.1745 .01923 L
.01923 .01923 L
F
0 g
.01923 .1745 m
.02882 .16492 L
.02894 .16479 L
.03853 .15521 L
.03866 .15508 L
.04824 .14549 L
.04837 .14537 L
.05795 .13578 L
.05808 .13565 L
.06767 .12607 L
.06779 .12594 L
.07738 .11636 L
.07751 .11623 L
.08709 .10664 L
.08722 .10652 L
.0968 .09693 L
.09693 .0968 L
.10652 .08722 L
.10664 .08709 L
.11623 .07751 L
.11636 .07738 L
.12594 .06779 L
.12607 .06767 L
.13565 .05808 L
.13578 .05795 L
.14537 .04837 L
.14549 .04824 L
.15508 .03866 L
.15521 .03853 L
.16479 .02894 L
.16492 .02882 L
.1745 .01923 L
s
.4 g
.01923 .13909 m
.02254 .13578 L
.02894 .12938 L
.03225 .12607 L
.03866 .11967 L
.04197 .11636 L
.04837 .10995 L
.05168 .10664 L
.05808 .10024 L
.06139 .09693 L
.06779 .09053 L
.0711 .08722 L
.07751 .08082 L
.08082 .07751 L
.08722 .0711 L
.09053 .06779 L
.09693 .06139 L
.10024 .05808 L
.10664 .05168 L
.10995 .04837 L
.11636 .04197 L
.11967 .03866 L
.12607 .03225 L
.12938 .02894 L
.13578 .02254 L
.13909 .01923 L
.01923 .01923 L
F
0 g
.01923 .13909 m
.02254 .13578 L
.02894 .12938 L
.03225 .12607 L
.03866 .11967 L
.04197 .11636 L
.04837 .10995 L
.05168 .10664 L
.05808 .10024 L
.06139 .09693 L
.06779 .09053 L
.0711 .08722 L
.07751 .08082 L
.08082 .07751 L
.08722 .0711 L
.09053 .06779 L
.09693 .06139 L
.10024 .05808 L
.10664 .05168 L
.10995 .04837 L
.11636 .04197 L
.11967 .03866 L
.12607 .03225 L
.12938 .02894 L
.13578 .02254 L
.13909 .01923 L
s
.3 g
.01923 .0954 m
.02737 .08722 L
.02894 .08569 L
.03713 .07751 L
.03866 .07598 L
.04684 .06779 L
.04837 .06627 L
.05655 .05808 L
.05808 .05655 L
.06627 .04837 L
.06779 .04684 L
.07598 .03866 L
.07751 .03713 L
.08569 .02894 L
.08722 .02737 L
.0954 .01923 L
.01923 .01923 L
F
0 g
.01923 .0954 m
.02737 .08722 L
.02894 .08569 L
.03713 .07751 L
.03866 .07598 L
.04684 .06779 L
.04837 .06627 L
.05655 .05808 L
.05808 .05655 L
.06627 .04837 L
.06779 .04684 L
.07598 .03866 L
.07751 .03713 L
.08569 .02894 L
.08722 .02737 L
.0954 .01923 L
s
.7 g
.06217 .98077 m
.06779 .97523 L
.07188 .97106 L
.07751 .96543 L
.08159 .96134 L
.08722 .95572 L
.09131 .95163 L
.09693 .94601 L
.10102 .94192 L
.10664 .9363 L
.11073 .93221 L
.11636 .92658 L
.12044 .92249 L
.12607 .91687 L
.13016 .91278 L
.13578 .90716 L
.13987 .90307 L
.14549 .89745 L
.14958 .89336 L
.15521 .88773 L
.15929 .88364 L
.16492 .87802 L
.16901 .87393 L
.17463 .86831 L
.17872 .86422 L
.18434 .8586 L
.18843 .85451 L
.19406 .84888 L
.19814 .84479 L
.20377 .83917 L
.20786 .83508 L
.21348 .82946 L
.21757 .82537 L
.22319 .81975 L
.22728 .81566 L
.23291 .81003 L
.23699 .80594 L
.24262 .80032 L
.24671 .79623 L
.25233 .79061 L
.25642 .78652 L
.26204 .7809 L
.26613 .77681 L
.27176 .77118 L
.27585 .76709 L
.28147 .76147 L
.28556 .75738 L
.29118 .75176 L
.29527 .74767 L
.30089 .74205 L
.30498 .73796 L
.31061 .73233 L
.3147 .72824 L
.32032 .72262 L
.32441 .71853 L
.33003 .71291 L
.33442 .70882 L
.33974 .7032 L
.34292 .69911 L
.34946 .6901 L
.34998 .68939 L
.35713 .67968 L
.35917 .67688 L
.36419 .66997 L
.36888 .66344 L
.37115 .66026 L
.37802 .65054 L
.37859 .64972 L
.38474 .64083 L
.38831 .63562 L
.39134 .63112 L
.39787 .62141 L
.39802 .62118 L
.40423 .61169 L
.40773 .60632 L
.4105 .60198 L
.4167 .59227 L
.41744 .59109 L
.42274 .58256 L
.42716 .57544 L
.42872 .57284 L
.43462 .56313 L
.43687 .55941 L
.4404 .55342 L
.44616 .54371 L
.44658 .543 L
.45177 .53399 L
.45629 .52618 L
.45735 .52428 L
.46284 .51457 L
.46601 .50898 L
.46826 .50486 L
.47365 .49514 L
.47572 .4914 L
.47892 .48543 L
.4842 .47572 L
.48543 .47345 L
.48934 .46601 L
.49453 .45629 L
.49514 .45513 L
.49955 .44658 L
.50464 .43687 L
.50486 .43644 L
.50955 .42716 L
.51455 .41744 L
.51457 .4174 L
.51936 .40773 L
.52427 .39802 L
.52428 .398 L
.529 .38831 L
.53382 .37859 L
.53399 .37824 L
.53847 .36888 L
.54321 .35917 L
.54371 .35815 L
.54778 .34946 L
.55245 .33974 L
.55342 .33771 L
.55694 .33003 L
.56154 .32032 L
.56313 .31693 L
.56597 .31061 L
.57049 .30089 L
.57284 .29583 L
.57488 .29118 L
.57932 .28147 L
.58256 .27441 L
.58369 .27176 L
.58802 .26204 L
.59227 .25266 L
.59241 .25233 L
.59661 .24262 L
.60095 .23291 L
.60198 .23059 L
.6051 .22319 L
.60938 .21348 L
.61169 .20821 L
.61351 .20377 L
.6177 .19406 L
.62141 .18552 L
.62187 .18434 L
.62592 .17463 L
.6301 .16492 L
.63112 .16253 L
.63407 .15521 L
.63818 .14549 L
.64083 .13923 L
.64217 .13578 L
.64617 .12607 L
.65024 .11636 L
.65054 .11563 L
.65409 .10664 L
.65811 .09693 L
.66026 .09174 L
.66197 .08722 L
.66589 .07751 L
.66987 .06779 L
.66997 .06756 L
.67361 .05808 L
.67755 .04837 L
.67968 .04308 L
.68131 .03866 L
.68514 .02894 L
.68903 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.06217 .98077 m
.06779 .97523 L
.07188 .97106 L
.07751 .96543 L
.08159 .96134 L
.08722 .95572 L
.09131 .95163 L
.09693 .94601 L
.10102 .94192 L
.10664 .9363 L
.11073 .93221 L
.11636 .92658 L
.12044 .92249 L
.12607 .91687 L
.13016 .91278 L
.13578 .90716 L
.13987 .90307 L
.14549 .89745 L
.14958 .89336 L
.15521 .88773 L
.15929 .88364 L
.16492 .87802 L
.16901 .87393 L
.17463 .86831 L
.17872 .86422 L
.18434 .8586 L
.18843 .85451 L
.19406 .84888 L
.19814 .84479 L
.20377 .83917 L
.20786 .83508 L
.21348 .82946 L
.21757 .82537 L
.22319 .81975 L
.22728 .81566 L
.23291 .81003 L
.23699 .80594 L
.24262 .80032 L
.24671 .79623 L
.25233 .79061 L
.25642 .78652 L
.26204 .7809 L
.26613 .77681 L
.27176 .77118 L
.27585 .76709 L
.28147 .76147 L
.28556 .75738 L
.29118 .75176 L
.29527 .74767 L
.30089 .74205 L
Mistroke
.30498 .73796 L
.31061 .73233 L
.3147 .72824 L
.32032 .72262 L
.32441 .71853 L
.33003 .71291 L
.33442 .70882 L
.33974 .7032 L
.34292 .69911 L
.34946 .6901 L
.34998 .68939 L
.35713 .67968 L
.35917 .67688 L
.36419 .66997 L
.36888 .66344 L
.37115 .66026 L
.37802 .65054 L
.37859 .64972 L
.38474 .64083 L
.38831 .63562 L
.39134 .63112 L
.39787 .62141 L
.39802 .62118 L
.40423 .61169 L
.40773 .60632 L
.4105 .60198 L
.4167 .59227 L
.41744 .59109 L
.42274 .58256 L
.42716 .57544 L
.42872 .57284 L
.43462 .56313 L
.43687 .55941 L
.4404 .55342 L
.44616 .54371 L
.44658 .543 L
.45177 .53399 L
.45629 .52618 L
.45735 .52428 L
.46284 .51457 L
.46601 .50898 L
.46826 .50486 L
.47365 .49514 L
.47572 .4914 L
.47892 .48543 L
.4842 .47572 L
.48543 .47345 L
.48934 .46601 L
.49453 .45629 L
.49514 .45513 L
Mistroke
.49955 .44658 L
.50464 .43687 L
.50486 .43644 L
.50955 .42716 L
.51455 .41744 L
.51457 .4174 L
.51936 .40773 L
.52427 .39802 L
.52428 .398 L
.529 .38831 L
.53382 .37859 L
.53399 .37824 L
.53847 .36888 L
.54321 .35917 L
.54371 .35815 L
.54778 .34946 L
.55245 .33974 L
.55342 .33771 L
.55694 .33003 L
.56154 .32032 L
.56313 .31693 L
.56597 .31061 L
.57049 .30089 L
.57284 .29583 L
.57488 .29118 L
.57932 .28147 L
.58256 .27441 L
.58369 .27176 L
.58802 .26204 L
.59227 .25266 L
.59241 .25233 L
.59661 .24262 L
.60095 .23291 L
.60198 .23059 L
.6051 .22319 L
.60938 .21348 L
.61169 .20821 L
.61351 .20377 L
.6177 .19406 L
.62141 .18552 L
.62187 .18434 L
.62592 .17463 L
.6301 .16492 L
.63112 .16253 L
.63407 .15521 L
.63818 .14549 L
.64083 .13923 L
.64217 .13578 L
.64617 .12607 L
.65024 .11636 L
Mistroke
.65054 .11563 L
.65409 .10664 L
.65811 .09693 L
.66026 .09174 L
.66197 .08722 L
.66589 .07751 L
.66987 .06779 L
.66997 .06756 L
.67361 .05808 L
.67755 .04837 L
.67968 .04308 L
.68131 .03866 L
.68514 .02894 L
.68903 .01923 L
Mfstroke
.6 g
.1408 .98077 m
.14549 .97578 L
.15051 .97106 L
.15521 .96636 L
.16023 .96134 L
.16492 .95665 L
.16994 .95163 L
.17463 .94694 L
.17965 .94192 L
.18434 .93723 L
.18936 .93221 L
.19406 .92751 L
.19908 .92249 L
.20377 .9178 L
.20879 .91278 L
.21348 .90809 L
.2185 .90307 L
.22319 .89838 L
.22821 .89336 L
.23291 .88866 L
.23793 .88364 L
.24262 .87895 L
.24764 .87393 L
.25233 .86924 L
.25735 .86422 L
.26204 .85953 L
.26706 .85451 L
.27176 .84981 L
.27678 .84479 L
.28147 .8401 L
.28649 .83508 L
.29118 .83039 L
.2962 .82537 L
.30089 .82068 L
.30591 .81566 L
.31061 .81096 L
.31563 .80594 L
.32032 .80125 L
.32534 .79623 L
.33003 .79154 L
.33495 .78652 L
.33974 .78183 L
.34637 .77681 L
.34946 .7748 L
.35862 .76709 L
.35917 .76647 L
.36864 .75738 L
.36888 .75709 L
.37788 .74767 L
.37859 .74681 L
.38651 .73796 L
.38831 .73572 L
.39463 .72824 L
.39802 .72388 L
.40232 .71853 L
.40773 .71135 L
.40968 .70882 L
.41683 .69911 L
.41744 .6982 L
.42382 .68939 L
.42716 .68446 L
.43051 .67968 L
.43687 .67014 L
.43699 .66997 L
.44349 .66026 L
.44658 .65532 L
.44969 .65054 L
.45578 .64083 L
.45629 .63995 L
.46185 .63112 L
.46601 .62411 L
.46767 .62141 L
.47351 .61169 L
.47572 .60779 L
.47918 .60198 L
.48475 .59227 L
.48543 .59101 L
.49033 .58256 L
.49514 .57379 L
.49568 .57284 L
.50115 .56313 L
.50486 .55614 L
.50636 .55342 L
.51167 .54371 L
.51457 .53807 L
.51677 .53399 L
.52194 .52428 L
.52428 .51959 L
.52694 .51457 L
.53198 .50486 L
.53399 .50071 L
.53689 .49514 L
.54182 .48543 L
.54371 .48145 L
.54662 .47572 L
.55146 .46601 L
.55342 .4618 L
.55617 .45629 L
.56094 .44658 L
.56313 .44179 L
.56555 .43687 L
.57024 .42716 L
.57284 .4214 L
.57475 .41744 L
.5794 .40773 L
.58256 .40066 L
.58381 .39802 L
.5884 .38831 L
.59227 .37957 L
.59272 .37859 L
.59726 .36888 L
.60156 .35917 L
.60198 .35814 L
.60598 .34946 L
.6103 .33974 L
.61169 .33637 L
.61457 .33003 L
.6189 .32032 L
.62141 .31426 L
.62304 .31061 L
.62736 .30089 L
.63112 .29182 L
.6314 .29118 L
.63568 .28147 L
.63979 .27176 L
.64083 .26907 L
.64389 .26204 L
.64804 .25233 L
.65054 .246 L
.65199 .24262 L
.65615 .23291 L
.66004 .22319 L
.66026 .2226 L
.66412 .21348 L
.66814 .20377 L
.66997 .19891 L
.672 .19406 L
.67604 .18434 L
.67968 .17491 L
.67979 .17463 L
.68381 .16492 L
.68772 .15521 L
.68939 .15061 L
.69148 .14549 L
.69544 .13578 L
.69909 .12607 L
.69911 .12601 L
.70301 .11636 L
.70684 .10664 L
.70882 .10112 L
.71049 .09693 L
.71437 .08722 L
.71801 .07751 L
.71853 .07594 L
.72175 .06779 L
.72554 .05808 L
.72824 .05047 L
.72906 .04837 L
.73287 .03866 L
.73653 .02894 L
.73796 .02471 L
.74008 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.1408 .98077 m
.14549 .97578 L
.15051 .97106 L
.15521 .96636 L
.16023 .96134 L
.16492 .95665 L
.16994 .95163 L
.17463 .94694 L
.17965 .94192 L
.18434 .93723 L
.18936 .93221 L
.19406 .92751 L
.19908 .92249 L
.20377 .9178 L
.20879 .91278 L
.21348 .90809 L
.2185 .90307 L
.22319 .89838 L
.22821 .89336 L
.23291 .88866 L
.23793 .88364 L
.24262 .87895 L
.24764 .87393 L
.25233 .86924 L
.25735 .86422 L
.26204 .85953 L
.26706 .85451 L
.27176 .84981 L
.27678 .84479 L
.28147 .8401 L
.28649 .83508 L
.29118 .83039 L
.2962 .82537 L
.30089 .82068 L
.30591 .81566 L
.31061 .81096 L
.31563 .80594 L
.32032 .80125 L
.32534 .79623 L
.33003 .79154 L
.33495 .78652 L
.33974 .78183 L
.34637 .77681 L
.34946 .7748 L
.35862 .76709 L
.35917 .76647 L
.36864 .75738 L
.36888 .75709 L
.37788 .74767 L
.37859 .74681 L
Mistroke
.38651 .73796 L
.38831 .73572 L
.39463 .72824 L
.39802 .72388 L
.40232 .71853 L
.40773 .71135 L
.40968 .70882 L
.41683 .69911 L
.41744 .6982 L
.42382 .68939 L
.42716 .68446 L
.43051 .67968 L
.43687 .67014 L
.43699 .66997 L
.44349 .66026 L
.44658 .65532 L
.44969 .65054 L
.45578 .64083 L
.45629 .63995 L
.46185 .63112 L
.46601 .62411 L
.46767 .62141 L
.47351 .61169 L
.47572 .60779 L
.47918 .60198 L
.48475 .59227 L
.48543 .59101 L
.49033 .58256 L
.49514 .57379 L
.49568 .57284 L
.50115 .56313 L
.50486 .55614 L
.50636 .55342 L
.51167 .54371 L
.51457 .53807 L
.51677 .53399 L
.52194 .52428 L
.52428 .51959 L
.52694 .51457 L
.53198 .50486 L
.53399 .50071 L
.53689 .49514 L
.54182 .48543 L
.54371 .48145 L
.54662 .47572 L
.55146 .46601 L
.55342 .4618 L
.55617 .45629 L
.56094 .44658 L
.56313 .44179 L
Mistroke
.56555 .43687 L
.57024 .42716 L
.57284 .4214 L
.57475 .41744 L
.5794 .40773 L
.58256 .40066 L
.58381 .39802 L
.5884 .38831 L
.59227 .37957 L
.59272 .37859 L
.59726 .36888 L
.60156 .35917 L
.60198 .35814 L
.60598 .34946 L
.6103 .33974 L
.61169 .33637 L
.61457 .33003 L
.6189 .32032 L
.62141 .31426 L
.62304 .31061 L
.62736 .30089 L
.63112 .29182 L
.6314 .29118 L
.63568 .28147 L
.63979 .27176 L
.64083 .26907 L
.64389 .26204 L
.64804 .25233 L
.65054 .246 L
.65199 .24262 L
.65615 .23291 L
.66004 .22319 L
.66026 .2226 L
.66412 .21348 L
.66814 .20377 L
.66997 .19891 L
.672 .19406 L
.67604 .18434 L
.67968 .17491 L
.67979 .17463 L
.68381 .16492 L
.68772 .15521 L
.68939 .15061 L
.69148 .14549 L
.69544 .13578 L
.69909 .12607 L
.69911 .12601 L
.70301 .11636 L
.70684 .10664 L
.70882 .10112 L
Mistroke
.71049 .09693 L
.71437 .08722 L
.71801 .07751 L
.71853 .07594 L
.72175 .06779 L
.72554 .05808 L
.72824 .05047 L
.72906 .04837 L
.73287 .03866 L
.73653 .02894 L
.73796 .02471 L
.74008 .01923 L
Mfstroke
.5 g
.18447 .98077 m
.19406 .97118 L
.19418 .97106 L
.20377 .96147 L
.2039 .96134 L
.21348 .95176 L
.21361 .95163 L
.22319 .94205 L
.22332 .94192 L
.23291 .93233 L
.23303 .93221 L
.24262 .92262 L
.24275 .92249 L
.25233 .91291 L
.25246 .91278 L
.26204 .9032 L
.26217 .90307 L
.27176 .89348 L
.27188 .89336 L
.28147 .88377 L
.2816 .88364 L
.29118 .87406 L
.29131 .87393 L
.30089 .86435 L
.30102 .86422 L
.31061 .85463 L
.31073 .85451 L
.32032 .84492 L
.32045 .84479 L
.33003 .83521 L
.33016 .83508 L
.33974 .8255 L
.33987 .82537 L
.34946 .81605 L
.34985 .81566 L
.35906 .80594 L
.35917 .80583 L
.36773 .79623 L
.36888 .79488 L
.37595 .78652 L
.37859 .78327 L
.3838 .77681 L
.38831 .77104 L
.39135 .76709 L
.39802 .7582 L
.39863 .75738 L
.4057 .74767 L
.40773 .74481 L
.41257 .73796 L
.41744 .73088 L
.41925 .72824 L
.42577 .71853 L
.42716 .71643 L
.43216 .70882 L
.43687 .70148 L
.43839 .69911 L
.44452 .68939 L
.44658 .68606 L
.45053 .67968 L
.45629 .67016 L
.45641 .66997 L
.46223 .66026 L
.46601 .65382 L
.46793 .65054 L
.47356 .64083 L
.47572 .63704 L
.4791 .63112 L
.48456 .62141 L
.48543 .61983 L
.48996 .61169 L
.49514 .60221 L
.49527 .60198 L
.50055 .59227 L
.50486 .58418 L
.50572 .58256 L
.51088 .57284 L
.51457 .56576 L
.51594 .56313 L
.52098 .55342 L
.52428 .54694 L
.52594 .54371 L
.53088 .53399 L
.53399 .52775 L
.53574 .52428 L
.54058 .51457 L
.54371 .50819 L
.54535 .50486 L
.5501 .49514 L
.55342 .48826 L
.55479 .48543 L
.55946 .47572 L
.56313 .46797 L
.56406 .46601 L
.56867 .45629 L
.57284 .44733 L
.57319 .44658 L
.57773 .43687 L
.58219 .42716 L
.58256 .42634 L
.58665 .41744 L
.59106 .40773 L
.59227 .40502 L
.59544 .39802 L
.5998 .38831 L
.60198 .38335 L
.60411 .37859 L
.60842 .36888 L
.61169 .36136 L
.61266 .35917 L
.61692 .34946 L
.62111 .33974 L
.62141 .33905 L
.62531 .33003 L
.62948 .32032 L
.63112 .31642 L
.6336 .31061 L
.63773 .30089 L
.64083 .29347 L
.64179 .29118 L
.64588 .28147 L
.64991 .27176 L
.65054 .27021 L
.65394 .26204 L
.65795 .25233 L
.66026 .24664 L
.66191 .24262 L
.66589 .23291 L
.6698 .22319 L
.66997 .22277 L
.67374 .21348 L
.67764 .20377 L
.67968 .1986 L
.6815 .19406 L
.68539 .18434 L
.6892 .17463 L
.68939 .17414 L
.69305 .16492 L
.69686 .15521 L
.69911 .14938 L
.70063 .14549 L
.70443 .13578 L
.70817 .12607 L
.70882 .12434 L
.71191 .11636 L
.71565 .10664 L
.71853 .09901 L
.71933 .09693 L
.72305 .08722 L
.72672 .07751 L
.72824 .0734 L
.73037 .06779 L
.73404 .05808 L
.73765 .04837 L
.73796 .04751 L
.74128 .03866 L
.7449 .02894 L
.74767 .02135 L
.74845 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.18447 .98077 m
.19406 .97118 L
.19418 .97106 L
.20377 .96147 L
.2039 .96134 L
.21348 .95176 L
.21361 .95163 L
.22319 .94205 L
.22332 .94192 L
.23291 .93233 L
.23303 .93221 L
.24262 .92262 L
.24275 .92249 L
.25233 .91291 L
.25246 .91278 L
.26204 .9032 L
.26217 .90307 L
.27176 .89348 L
.27188 .89336 L
.28147 .88377 L
.2816 .88364 L
.29118 .87406 L
.29131 .87393 L
.30089 .86435 L
.30102 .86422 L
.31061 .85463 L
.31073 .85451 L
.32032 .84492 L
.32045 .84479 L
.33003 .83521 L
.33016 .83508 L
.33974 .8255 L
.33987 .82537 L
.34946 .81605 L
.34985 .81566 L
.35906 .80594 L
.35917 .80583 L
.36773 .79623 L
.36888 .79488 L
.37595 .78652 L
.37859 .78327 L
.3838 .77681 L
.38831 .77104 L
.39135 .76709 L
.39802 .7582 L
.39863 .75738 L
.4057 .74767 L
.40773 .74481 L
.41257 .73796 L
.41744 .73088 L
Mistroke
.41925 .72824 L
.42577 .71853 L
.42716 .71643 L
.43216 .70882 L
.43687 .70148 L
.43839 .69911 L
.44452 .68939 L
.44658 .68606 L
.45053 .67968 L
.45629 .67016 L
.45641 .66997 L
.46223 .66026 L
.46601 .65382 L
.46793 .65054 L
.47356 .64083 L
.47572 .63704 L
.4791 .63112 L
.48456 .62141 L
.48543 .61983 L
.48996 .61169 L
.49514 .60221 L
.49527 .60198 L
.50055 .59227 L
.50486 .58418 L
.50572 .58256 L
.51088 .57284 L
.51457 .56576 L
.51594 .56313 L
.52098 .55342 L
.52428 .54694 L
.52594 .54371 L
.53088 .53399 L
.53399 .52775 L
.53574 .52428 L
.54058 .51457 L
.54371 .50819 L
.54535 .50486 L
.5501 .49514 L
.55342 .48826 L
.55479 .48543 L
.55946 .47572 L
.56313 .46797 L
.56406 .46601 L
.56867 .45629 L
.57284 .44733 L
.57319 .44658 L
.57773 .43687 L
.58219 .42716 L
.58256 .42634 L
.58665 .41744 L
Mistroke
.59106 .40773 L
.59227 .40502 L
.59544 .39802 L
.5998 .38831 L
.60198 .38335 L
.60411 .37859 L
.60842 .36888 L
.61169 .36136 L
.61266 .35917 L
.61692 .34946 L
.62111 .33974 L
.62141 .33905 L
.62531 .33003 L
.62948 .32032 L
.63112 .31642 L
.6336 .31061 L
.63773 .30089 L
.64083 .29347 L
.64179 .29118 L
.64588 .28147 L
.64991 .27176 L
.65054 .27021 L
.65394 .26204 L
.65795 .25233 L
.66026 .24664 L
.66191 .24262 L
.66589 .23291 L
.6698 .22319 L
.66997 .22277 L
.67374 .21348 L
.67764 .20377 L
.67968 .1986 L
.6815 .19406 L
.68539 .18434 L
.6892 .17463 L
.68939 .17414 L
.69305 .16492 L
.69686 .15521 L
.69911 .14938 L
.70063 .14549 L
.70443 .13578 L
.70817 .12607 L
.70882 .12434 L
.71191 .11636 L
.71565 .10664 L
.71853 .09901 L
.71933 .09693 L
.72305 .08722 L
.72672 .07751 L
.72824 .0734 L
Mistroke
.73037 .06779 L
.73404 .05808 L
.73765 .04837 L
.73796 .04751 L
.74128 .03866 L
.7449 .02894 L
.74767 .02135 L
.74845 .01923 L
Mfstroke
.4 g
.21988 .98077 m
.22319 .97746 L
.2296 .97106 L
.23291 .96775 L
.23931 .96134 L
.24262 .95803 L
.24902 .95163 L
.25233 .94832 L
.25873 .94192 L
.26204 .93861 L
.26845 .93221 L
.27176 .9289 L
.27816 .92249 L
.28147 .91918 L
.28787 .91278 L
.29118 .90947 L
.29758 .90307 L
.30089 .89976 L
.3073 .89336 L
.31061 .89005 L
.31701 .88364 L
.32032 .88033 L
.32672 .87393 L
.33003 .87062 L
.33652 .86422 L
.33974 .86091 L
.34561 .85451 L
.34946 .85021 L
.35418 .84479 L
.35917 .83892 L
.36237 .83508 L
.36888 .82706 L
.37023 .82537 L
.37782 .81566 L
.37859 .81464 L
.38516 .80594 L
.38831 .80169 L
.39229 .79623 L
.39802 .78822 L
.39922 .78652 L
.40598 .77681 L
.40773 .77425 L
.41258 .76709 L
.41744 .75979 L
.41903 .75738 L
.42535 .74767 L
.42716 .74486 L
.43155 .73796 L
.43687 .72947 L
.43763 .72824 L
.4436 .71853 L
.44658 .71363 L
.44948 .70882 L
.45526 .69911 L
.45629 .69735 L
.46095 .68939 L
.46601 .68065 L
.46656 .67968 L
.47209 .66997 L
.47572 .66353 L
.47755 .66026 L
.48294 .65054 L
.48543 .64601 L
.48825 .64083 L
.49352 .63112 L
.49514 .62809 L
.49871 .62141 L
.50385 .61169 L
.50486 .60978 L
.50892 .60198 L
.51396 .59227 L
.51457 .59108 L
.51893 .58256 L
.52386 .57284 L
.52428 .57202 L
.52874 .56313 L
.53358 .55342 L
.53399 .55258 L
.53836 .54371 L
.54312 .53399 L
.54371 .53279 L
.54782 .52428 L
.55249 .51457 L
.55342 .51264 L
.55711 .50486 L
.56172 .49514 L
.56313 .49214 L
.56626 .48543 L
.57079 .47572 L
.57284 .47129 L
.57527 .46601 L
.57973 .45629 L
.58256 .45011 L
.58415 .44658 L
.58855 .43687 L
.59227 .4286 L
.59291 .42716 L
.59724 .41744 L
.60155 .40773 L
.60198 .40676 L
.60581 .39802 L
.61008 .38831 L
.61169 .3846 L
.61428 .37859 L
.61849 .36888 L
.62141 .36211 L
.62266 .35917 L
.6268 .34946 L
.63094 .33974 L
.63112 .33932 L
.63502 .33003 L
.63911 .32032 L
.64083 .31621 L
.64315 .31061 L
.64719 .30089 L
.65054 .2928 L
.6512 .29118 L
.65519 .28147 L
.65917 .27176 L
.66026 .26909 L
.6631 .26204 L
.66704 .25233 L
.66997 .24508 L
.67095 .24262 L
.67483 .23291 L
.67872 .22319 L
.67968 .22078 L
.68255 .21348 L
.6864 .20377 L
.68939 .19618 L
.69021 .19406 L
.69401 .18434 L
.69781 .17463 L
.69911 .17129 L
.70155 .16492 L
.70532 .15521 L
.70882 .14613 L
.70906 .14549 L
.71276 .13578 L
.71648 .12607 L
.71853 .12068 L
.72015 .11636 L
.72382 .10664 L
.7275 .09693 L
.72824 .09495 L
.73111 .08722 L
.73476 .07751 L
.73796 .06895 L
.73838 .06779 L
.74196 .05808 L
.74557 .04837 L
.74767 .04267 L
.74912 .03866 L
.75268 .02894 L
.75625 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.21988 .98077 m
.22319 .97746 L
.2296 .97106 L
.23291 .96775 L
.23931 .96134 L
.24262 .95803 L
.24902 .95163 L
.25233 .94832 L
.25873 .94192 L
.26204 .93861 L
.26845 .93221 L
.27176 .9289 L
.27816 .92249 L
.28147 .91918 L
.28787 .91278 L
.29118 .90947 L
.29758 .90307 L
.30089 .89976 L
.3073 .89336 L
.31061 .89005 L
.31701 .88364 L
.32032 .88033 L
.32672 .87393 L
.33003 .87062 L
.33652 .86422 L
.33974 .86091 L
.34561 .85451 L
.34946 .85021 L
.35418 .84479 L
.35917 .83892 L
.36237 .83508 L
.36888 .82706 L
.37023 .82537 L
.37782 .81566 L
.37859 .81464 L
.38516 .80594 L
.38831 .80169 L
.39229 .79623 L
.39802 .78822 L
.39922 .78652 L
.40598 .77681 L
.40773 .77425 L
.41258 .76709 L
.41744 .75979 L
.41903 .75738 L
.42535 .74767 L
.42716 .74486 L
.43155 .73796 L
.43687 .72947 L
.43763 .72824 L
Mistroke
.4436 .71853 L
.44658 .71363 L
.44948 .70882 L
.45526 .69911 L
.45629 .69735 L
.46095 .68939 L
.46601 .68065 L
.46656 .67968 L
.47209 .66997 L
.47572 .66353 L
.47755 .66026 L
.48294 .65054 L
.48543 .64601 L
.48825 .64083 L
.49352 .63112 L
.49514 .62809 L
.49871 .62141 L
.50385 .61169 L
.50486 .60978 L
.50892 .60198 L
.51396 .59227 L
.51457 .59108 L
.51893 .58256 L
.52386 .57284 L
.52428 .57202 L
.52874 .56313 L
.53358 .55342 L
.53399 .55258 L
.53836 .54371 L
.54312 .53399 L
.54371 .53279 L
.54782 .52428 L
.55249 .51457 L
.55342 .51264 L
.55711 .50486 L
.56172 .49514 L
.56313 .49214 L
.56626 .48543 L
.57079 .47572 L
.57284 .47129 L
.57527 .46601 L
.57973 .45629 L
.58256 .45011 L
.58415 .44658 L
.58855 .43687 L
.59227 .4286 L
.59291 .42716 L
.59724 .41744 L
.60155 .40773 L
.60198 .40676 L
Mistroke
.60581 .39802 L
.61008 .38831 L
.61169 .3846 L
.61428 .37859 L
.61849 .36888 L
.62141 .36211 L
.62266 .35917 L
.6268 .34946 L
.63094 .33974 L
.63112 .33932 L
.63502 .33003 L
.63911 .32032 L
.64083 .31621 L
.64315 .31061 L
.64719 .30089 L
.65054 .2928 L
.6512 .29118 L
.65519 .28147 L
.65917 .27176 L
.66026 .26909 L
.6631 .26204 L
.66704 .25233 L
.66997 .24508 L
.67095 .24262 L
.67483 .23291 L
.67872 .22319 L
.67968 .22078 L
.68255 .21348 L
.6864 .20377 L
.68939 .19618 L
.69021 .19406 L
.69401 .18434 L
.69781 .17463 L
.69911 .17129 L
.70155 .16492 L
.70532 .15521 L
.70882 .14613 L
.70906 .14549 L
.71276 .13578 L
.71648 .12607 L
.71853 .12068 L
.72015 .11636 L
.72382 .10664 L
.7275 .09693 L
.72824 .09495 L
.73111 .08722 L
.73476 .07751 L
.73796 .06895 L
.73838 .06779 L
.74196 .05808 L
Mistroke
.74557 .04837 L
.74767 .04267 L
.74912 .03866 L
.75268 .02894 L
.75625 .01923 L
Mfstroke
.3 g
.26357 .98077 m
.27176 .97263 L
.27328 .97106 L
.28147 .96287 L
.28299 .96134 L
.29118 .95316 L
.29271 .95163 L
.30089 .94345 L
.30242 .94192 L
.31061 .93373 L
.31213 .93221 L
.32032 .92402 L
.32184 .92249 L
.33003 .91431 L
.33172 .91278 L
.33974 .9046 L
.34097 .90307 L
.34811 .89336 L
.34946 .89148 L
.35523 .88364 L
.35917 .87826 L
.36232 .87393 L
.36888 .86485 L
.36933 .86422 L
.3762 .85451 L
.37859 .8511 L
.38295 .84479 L
.38831 .83701 L
.38961 .83508 L
.39614 .82537 L
.39802 .82255 L
.40254 .81566 L
.40773 .8077 L
.40885 .80594 L
.41506 .79623 L
.41744 .79246 L
.42113 .78652 L
.42716 .77684 L
.42718 .77681 L
.43306 .76709 L
.43687 .76079 L
.43888 .75738 L
.44464 .74767 L
.44658 .74437 L
.45027 .73796 L
.45591 .72824 L
.45629 .72757 L
.46138 .71853 L
.46601 .71036 L
.46685 .70882 L
.47222 .69911 L
.47572 .69278 L
.47753 .68939 L
.4828 .67968 L
.48543 .67483 L
.48798 .66997 L
.49315 .66026 L
.49514 .65651 L
.49821 .65054 L
.50329 .64083 L
.50486 .63782 L
.50823 .63112 L
.51322 .62141 L
.51457 .61877 L
.51807 .61169 L
.52297 .60198 L
.52428 .59937 L
.52772 .59227 L
.53254 .58256 L
.53399 .57962 L
.53721 .57284 L
.54195 .56313 L
.54371 .55952 L
.54655 .55342 L
.55121 .54371 L
.55342 .53909 L
.55574 .53399 L
.56032 .52428 L
.56313 .51832 L
.5648 .51457 L
.56929 .50486 L
.57284 .49722 L
.57374 .49514 L
.57813 .48543 L
.58256 .4758 L
.58259 .47572 L
.58685 .46601 L
.59126 .45629 L
.59227 .45404 L
.59547 .44658 L
.5998 .43687 L
.60198 .43197 L
.60399 .42716 L
.60824 .41744 L
.61169 .4096 L
.61245 .40773 L
.61657 .39802 L
.6208 .38831 L
.62141 .38691 L
.62482 .37859 L
.62899 .36888 L
.63112 .36391 L
.633 .35917 L
.63708 .34946 L
.64083 .34061 L
.64116 .33974 L
.64509 .33003 L
.64917 .32032 L
.65054 .31701 L
.65304 .31061 L
.65704 .30089 L
.66026 .29312 L
.66098 .29118 L
.66484 .28147 L
.66882 .27176 L
.66997 .26894 L
.67259 .26204 L
.6765 .25233 L
.67968 .24447 L
.68035 .24262 L
.68411 .23291 L
.688 .22319 L
.68939 .21971 L
.69168 .21348 L
.6955 .20377 L
.69911 .19467 L
.69932 .19406 L
.70294 .18434 L
.70675 .17463 L
.70882 .16934 L
.71038 .16492 L
.71408 .15521 L
.71786 .14549 L
.71853 .14375 L
.72138 .13578 L
.7251 .12607 L
.72824 .11788 L
.72875 .11636 L
.73228 .10664 L
.73598 .09693 L
.73796 .09173 L
.73948 .08722 L
.74307 .07751 L
.74674 .06779 L
.74767 .06532 L
.75015 .05808 L
.75375 .04837 L
.75738 .03866 L
.75738 .03865 L
.76072 .02894 L
.76431 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.26357 .98077 m
.27176 .97263 L
.27328 .97106 L
.28147 .96287 L
.28299 .96134 L
.29118 .95316 L
.29271 .95163 L
.30089 .94345 L
.30242 .94192 L
.31061 .93373 L
.31213 .93221 L
.32032 .92402 L
.32184 .92249 L
.33003 .91431 L
.33172 .91278 L
.33974 .9046 L
.34097 .90307 L
.34811 .89336 L
.34946 .89148 L
.35523 .88364 L
.35917 .87826 L
.36232 .87393 L
.36888 .86485 L
.36933 .86422 L
.3762 .85451 L
.37859 .8511 L
.38295 .84479 L
.38831 .83701 L
.38961 .83508 L
.39614 .82537 L
.39802 .82255 L
.40254 .81566 L
.40773 .8077 L
.40885 .80594 L
.41506 .79623 L
.41744 .79246 L
.42113 .78652 L
.42716 .77684 L
.42718 .77681 L
.43306 .76709 L
.43687 .76079 L
.43888 .75738 L
.44464 .74767 L
.44658 .74437 L
.45027 .73796 L
.45591 .72824 L
.45629 .72757 L
.46138 .71853 L
.46601 .71036 L
.46685 .70882 L
Mistroke
.47222 .69911 L
.47572 .69278 L
.47753 .68939 L
.4828 .67968 L
.48543 .67483 L
.48798 .66997 L
.49315 .66026 L
.49514 .65651 L
.49821 .65054 L
.50329 .64083 L
.50486 .63782 L
.50823 .63112 L
.51322 .62141 L
.51457 .61877 L
.51807 .61169 L
.52297 .60198 L
.52428 .59937 L
.52772 .59227 L
.53254 .58256 L
.53399 .57962 L
.53721 .57284 L
.54195 .56313 L
.54371 .55952 L
.54655 .55342 L
.55121 .54371 L
.55342 .53909 L
.55574 .53399 L
.56032 .52428 L
.56313 .51832 L
.5648 .51457 L
.56929 .50486 L
.57284 .49722 L
.57374 .49514 L
.57813 .48543 L
.58256 .4758 L
.58259 .47572 L
.58685 .46601 L
.59126 .45629 L
.59227 .45404 L
.59547 .44658 L
.5998 .43687 L
.60198 .43197 L
.60399 .42716 L
.60824 .41744 L
.61169 .4096 L
.61245 .40773 L
.61657 .39802 L
.6208 .38831 L
.62141 .38691 L
.62482 .37859 L
Mistroke
.62899 .36888 L
.63112 .36391 L
.633 .35917 L
.63708 .34946 L
.64083 .34061 L
.64116 .33974 L
.64509 .33003 L
.64917 .32032 L
.65054 .31701 L
.65304 .31061 L
.65704 .30089 L
.66026 .29312 L
.66098 .29118 L
.66484 .28147 L
.66882 .27176 L
.66997 .26894 L
.67259 .26204 L
.6765 .25233 L
.67968 .24447 L
.68035 .24262 L
.68411 .23291 L
.688 .22319 L
.68939 .21971 L
.69168 .21348 L
.6955 .20377 L
.69911 .19467 L
.69932 .19406 L
.70294 .18434 L
.70675 .17463 L
.70882 .16934 L
.71038 .16492 L
.71408 .15521 L
.71786 .14549 L
.71853 .14375 L
.72138 .13578 L
.7251 .12607 L
.72824 .11788 L
.72875 .11636 L
.73228 .10664 L
.73598 .09693 L
.73796 .09173 L
.73948 .08722 L
.74307 .07751 L
.74674 .06779 L
.74767 .06532 L
.75015 .05808 L
.75375 .04837 L
.75738 .03866 L
.75738 .03865 L
.76072 .02894 L
Mistroke
.76431 .01923 L
Mfstroke
.4 g
.34277 .98077 m
.34946 .97597 L
.35595 .97106 L
.35917 .96787 L
.36625 .96134 L
.36888 .9585 L
.37562 .95163 L
.37859 .94821 L
.38431 .94192 L
.38831 .9371 L
.39249 .93221 L
.39802 .92526 L
.40026 .92249 L
.40769 .91278 L
.40773 .91273 L
.41502 .90307 L
.41744 .89959 L
.42199 .89336 L
.42716 .88584 L
.4287 .88364 L
.43534 .87393 L
.43687 .87154 L
.4418 .86422 L
.44658 .85669 L
.44801 .85451 L
.45423 .84479 L
.45629 .84134 L
.46025 .83508 L
.46601 .82549 L
.46608 .82537 L
.472 .81566 L
.47572 .80918 L
.47765 .80594 L
.48333 .79623 L
.48543 .7924 L
.48884 .78652 L
.49429 .77681 L
.49514 .77517 L
.49971 .76709 L
.50486 .75752 L
.50493 .75738 L
.51029 .74767 L
.51457 .73945 L
.51538 .73796 L
.5206 .72824 L
.52428 .72097 L
.52557 .71853 L
.53067 .70882 L
.53399 .7021 L
.53555 .69911 L
.54054 .68939 L
.54371 .68283 L
.54531 .67968 L
.55021 .66997 L
.55342 .66319 L
.55488 .66026 L
.5597 .65054 L
.56313 .64317 L
.56428 .64083 L
.56902 .63112 L
.57284 .62278 L
.57351 .62141 L
.57818 .61169 L
.58256 .60204 L
.58258 .60198 L
.58719 .59227 L
.5916 .58256 L
.59227 .58096 L
.59606 .57284 L
.60047 .56313 L
.60198 .55952 L
.60479 .55342 L
.60919 .54371 L
.61169 .53775 L
.6134 .53399 L
.61777 .52428 L
.62141 .51564 L
.62188 .51457 L
.62622 .50486 L
.63036 .49514 L
.63112 .49321 L
.63455 .48543 L
.63874 .47572 L
.64083 .47045 L
.64276 .46601 L
.64696 .45629 L
.65054 .44738 L
.65088 .44658 L
.65505 .43687 L
.65906 .42716 L
.66026 .42399 L
.66303 .41744 L
.6671 .40773 L
.66997 .40029 L
.67092 .39802 L
.67498 .38831 L
.67885 .37859 L
.67968 .37629 L
.68275 .36888 L
.68671 .35917 L
.68939 .35199 L
.69043 .34946 L
.6944 .33974 L
.69818 .33003 L
.69911 .3274 L
.70197 .32032 L
.70585 .31061 L
.70882 .3025 L
.70946 .30089 L
.71334 .29118 L
.71709 .28147 L
.71853 .27732 L
.72073 .27176 L
.72456 .26204 L
.72809 .25233 L
.72824 .25185 L
.73186 .24262 L
.73559 .23291 L
.73796 .22611 L
.73908 .22319 L
.74285 .21348 L
.74645 .20377 L
.74767 .20008 L
.74998 .19406 L
.75369 .18434 L
.75711 .17463 L
.75738 .17377 L
.76074 .16492 L
.76439 .15521 L
.76709 .14719 L
.76773 .14549 L
.77139 .13578 L
.77495 .12607 L
.77681 .12035 L
.77829 .11636 L
.78191 .10664 L
.78537 .09693 L
.78652 .09323 L
.78873 .08722 L
.79232 .07751 L
.79565 .06779 L
.79623 .06585 L
.79907 .05808 L
.80261 .04837 L
.80582 .03866 L
.80594 .0382 L
.8093 .02894 L
.81279 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.34277 .98077 m
.34946 .97597 L
.35595 .97106 L
.35917 .96787 L
.36625 .96134 L
.36888 .9585 L
.37562 .95163 L
.37859 .94821 L
.38431 .94192 L
.38831 .9371 L
.39249 .93221 L
.39802 .92526 L
.40026 .92249 L
.40769 .91278 L
.40773 .91273 L
.41502 .90307 L
.41744 .89959 L
.42199 .89336 L
.42716 .88584 L
.4287 .88364 L
.43534 .87393 L
.43687 .87154 L
.4418 .86422 L
.44658 .85669 L
.44801 .85451 L
.45423 .84479 L
.45629 .84134 L
.46025 .83508 L
.46601 .82549 L
.46608 .82537 L
.472 .81566 L
.47572 .80918 L
.47765 .80594 L
.48333 .79623 L
.48543 .7924 L
.48884 .78652 L
.49429 .77681 L
.49514 .77517 L
.49971 .76709 L
.50486 .75752 L
.50493 .75738 L
.51029 .74767 L
.51457 .73945 L
.51538 .73796 L
.5206 .72824 L
.52428 .72097 L
.52557 .71853 L
.53067 .70882 L
.53399 .7021 L
.53555 .69911 L
Mistroke
.54054 .68939 L
.54371 .68283 L
.54531 .67968 L
.55021 .66997 L
.55342 .66319 L
.55488 .66026 L
.5597 .65054 L
.56313 .64317 L
.56428 .64083 L
.56902 .63112 L
.57284 .62278 L
.57351 .62141 L
.57818 .61169 L
.58256 .60204 L
.58258 .60198 L
.58719 .59227 L
.5916 .58256 L
.59227 .58096 L
.59606 .57284 L
.60047 .56313 L
.60198 .55952 L
.60479 .55342 L
.60919 .54371 L
.61169 .53775 L
.6134 .53399 L
.61777 .52428 L
.62141 .51564 L
.62188 .51457 L
.62622 .50486 L
.63036 .49514 L
.63112 .49321 L
.63455 .48543 L
.63874 .47572 L
.64083 .47045 L
.64276 .46601 L
.64696 .45629 L
.65054 .44738 L
.65088 .44658 L
.65505 .43687 L
.65906 .42716 L
.66026 .42399 L
.66303 .41744 L
.6671 .40773 L
.66997 .40029 L
.67092 .39802 L
.67498 .38831 L
.67885 .37859 L
.67968 .37629 L
.68275 .36888 L
.68671 .35917 L
Mistroke
.68939 .35199 L
.69043 .34946 L
.6944 .33974 L
.69818 .33003 L
.69911 .3274 L
.70197 .32032 L
.70585 .31061 L
.70882 .3025 L
.70946 .30089 L
.71334 .29118 L
.71709 .28147 L
.71853 .27732 L
.72073 .27176 L
.72456 .26204 L
.72809 .25233 L
.72824 .25185 L
.73186 .24262 L
.73559 .23291 L
.73796 .22611 L
.73908 .22319 L
.74285 .21348 L
.74645 .20377 L
.74767 .20008 L
.74998 .19406 L
.75369 .18434 L
.75711 .17463 L
.75738 .17377 L
.76074 .16492 L
.76439 .15521 L
.76709 .14719 L
.76773 .14549 L
.77139 .13578 L
.77495 .12607 L
.77681 .12035 L
.77829 .11636 L
.78191 .10664 L
.78537 .09693 L
.78652 .09323 L
.78873 .08722 L
.79232 .07751 L
.79565 .06779 L
.79623 .06585 L
.79907 .05808 L
.80261 .04837 L
.80582 .03866 L
.80594 .0382 L
.8093 .02894 L
.81279 .01923 L
Mfstroke
.5 g
.38175 .98077 m
.38831 .97242 L
.38936 .97106 L
.39672 .96134 L
.39802 .95959 L
.40385 .95163 L
.40773 .9462 L
.41076 .94192 L
.41744 .93226 L
.41748 .93221 L
.42406 .92249 L
.42716 .91781 L
.43047 .91278 L
.43674 .90307 L
.43687 .90287 L
.44291 .89336 L
.44658 .88744 L
.44894 .88364 L
.45487 .87393 L
.45629 .87155 L
.4607 .86422 L
.46601 .85521 L
.46642 .85451 L
.47208 .84479 L
.47572 .83843 L
.47763 .83508 L
.48313 .82537 L
.48543 .82122 L
.48853 .81566 L
.49387 .80594 L
.49514 .8036 L
.49915 .79623 L
.50435 .78652 L
.50486 .78557 L
.50952 .77681 L
.51457 .76714 L
.51459 .76709 L
.51965 .75738 L
.52428 .74833 L
.52462 .74767 L
.52957 .73796 L
.53399 .72913 L
.53444 .72824 L
.5393 .71853 L
.54371 .70957 L
.54408 .70882 L
.54885 .69911 L
.55342 .68964 L
.55354 .68939 L
.55823 .67968 L
.56284 .66997 L
.56313 .66935 L
.56745 .66026 L
.572 .65054 L
.57284 .64871 L
.57653 .64083 L
.58101 .63112 L
.58256 .62773 L
.58546 .62141 L
.58989 .61169 L
.59227 .6064 L
.59427 .60198 L
.59865 .59227 L
.60198 .58474 L
.60296 .58256 L
.60728 .57284 L
.61153 .56313 L
.61169 .56275 L
.61579 .55342 L
.62001 .54371 L
.62141 .54043 L
.6242 .53399 L
.62838 .52428 L
.63112 .5178 L
.6325 .51457 L
.63664 .50486 L
.64071 .49514 L
.64083 .49485 L
.6448 .48543 L
.64885 .47572 L
.65054 .47159 L
.65287 .46601 L
.65689 .45629 L
.66026 .44802 L
.66085 .44658 L
.66484 .43687 L
.66877 .42716 L
.66997 .42415 L
.67269 .41744 L
.67661 .40773 L
.67968 .39998 L
.68047 .39802 L
.68436 .38831 L
.6882 .37859 L
.68939 .37552 L
.69202 .36888 L
.69586 .35917 L
.69911 .35076 L
.69962 .34946 L
.70342 .33974 L
.70718 .33003 L
.70882 .32572 L
.71091 .32032 L
.71466 .31061 L
.71835 .30089 L
.71853 .30039 L
.72206 .29118 L
.72576 .28147 L
.72824 .27478 L
.72939 .27176 L
.73307 .26204 L
.7367 .25233 L
.73796 .2489 L
.74031 .24262 L
.74394 .23291 L
.7475 .22319 L
.74767 .22273 L
.7511 .21348 L
.75469 .20377 L
.75738 .19629 L
.7582 .19406 L
.76177 .18434 L
.76531 .17463 L
.76709 .16959 L
.76879 .16492 L
.77232 .15521 L
.7758 .14549 L
.77681 .14262 L
.77927 .13578 L
.78276 .12607 L
.78618 .11636 L
.78652 .11538 L
.78963 .10664 L
.79309 .09693 L
.79623 .08788 L
.79646 .08722 L
.7999 .07751 L
.80332 .06779 L
.80594 .06012 L
.80666 .05808 L
.81006 .04837 L
.81344 .03866 L
.81566 .0321 L
.81675 .02894 L
.82013 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.38175 .98077 m
.38831 .97242 L
.38936 .97106 L
.39672 .96134 L
.39802 .95959 L
.40385 .95163 L
.40773 .9462 L
.41076 .94192 L
.41744 .93226 L
.41748 .93221 L
.42406 .92249 L
.42716 .91781 L
.43047 .91278 L
.43674 .90307 L
.43687 .90287 L
.44291 .89336 L
.44658 .88744 L
.44894 .88364 L
.45487 .87393 L
.45629 .87155 L
.4607 .86422 L
.46601 .85521 L
.46642 .85451 L
.47208 .84479 L
.47572 .83843 L
.47763 .83508 L
.48313 .82537 L
.48543 .82122 L
.48853 .81566 L
.49387 .80594 L
.49514 .8036 L
.49915 .79623 L
.50435 .78652 L
.50486 .78557 L
.50952 .77681 L
.51457 .76714 L
.51459 .76709 L
.51965 .75738 L
.52428 .74833 L
.52462 .74767 L
.52957 .73796 L
.53399 .72913 L
.53444 .72824 L
.5393 .71853 L
.54371 .70957 L
.54408 .70882 L
.54885 .69911 L
.55342 .68964 L
.55354 .68939 L
.55823 .67968 L
Mistroke
.56284 .66997 L
.56313 .66935 L
.56745 .66026 L
.572 .65054 L
.57284 .64871 L
.57653 .64083 L
.58101 .63112 L
.58256 .62773 L
.58546 .62141 L
.58989 .61169 L
.59227 .6064 L
.59427 .60198 L
.59865 .59227 L
.60198 .58474 L
.60296 .58256 L
.60728 .57284 L
.61153 .56313 L
.61169 .56275 L
.61579 .55342 L
.62001 .54371 L
.62141 .54043 L
.6242 .53399 L
.62838 .52428 L
.63112 .5178 L
.6325 .51457 L
.63664 .50486 L
.64071 .49514 L
.64083 .49485 L
.6448 .48543 L
.64885 .47572 L
.65054 .47159 L
.65287 .46601 L
.65689 .45629 L
.66026 .44802 L
.66085 .44658 L
.66484 .43687 L
.66877 .42716 L
.66997 .42415 L
.67269 .41744 L
.67661 .40773 L
.67968 .39998 L
.68047 .39802 L
.68436 .38831 L
.6882 .37859 L
.68939 .37552 L
.69202 .36888 L
.69586 .35917 L
.69911 .35076 L
.69962 .34946 L
.70342 .33974 L
Mistroke
.70718 .33003 L
.70882 .32572 L
.71091 .32032 L
.71466 .31061 L
.71835 .30089 L
.71853 .30039 L
.72206 .29118 L
.72576 .28147 L
.72824 .27478 L
.72939 .27176 L
.73307 .26204 L
.7367 .25233 L
.73796 .2489 L
.74031 .24262 L
.74394 .23291 L
.7475 .22319 L
.74767 .22273 L
.7511 .21348 L
.75469 .20377 L
.75738 .19629 L
.7582 .19406 L
.76177 .18434 L
.76531 .17463 L
.76709 .16959 L
.76879 .16492 L
.77232 .15521 L
.7758 .14549 L
.77681 .14262 L
.77927 .13578 L
.78276 .12607 L
.78618 .11636 L
.78652 .11538 L
.78963 .10664 L
.79309 .09693 L
.79623 .08788 L
.79646 .08722 L
.7999 .07751 L
.80332 .06779 L
.80594 .06012 L
.80666 .05808 L
.81006 .04837 L
.81344 .03866 L
.81566 .0321 L
.81675 .02894 L
.82013 .01923 L
Mfstroke
.6 g
.4042 .98077 m
.40773 .97564 L
.41084 .97106 L
.41733 .96134 L
.41744 .96118 L
.42369 .95163 L
.42716 .94624 L
.42991 .94192 L
.43603 .93221 L
.43687 .93085 L
.44203 .92249 L
.44658 .91501 L
.44793 .91278 L
.45373 .90307 L
.45629 .89874 L
.45945 .89336 L
.46508 .88364 L
.46601 .88204 L
.47063 .87393 L
.47572 .86492 L
.47611 .86422 L
.48151 .85451 L
.48543 .84739 L
.48685 .84479 L
.49213 .83508 L
.49514 .82947 L
.49733 .82537 L
.50249 .81566 L
.50486 .81116 L
.50758 .80594 L
.51263 .79623 L
.51457 .79247 L
.51761 .78652 L
.52256 .77681 L
.52428 .7734 L
.52744 .76709 L
.5323 .75738 L
.53399 .75397 L
.53709 .74767 L
.54186 .73796 L
.54371 .73417 L
.54657 .72824 L
.55126 .71853 L
.55342 .71402 L
.55589 .70882 L
.5605 .69911 L
.56313 .69352 L
.56506 .68939 L
.56959 .67968 L
.57284 .67268 L
.57409 .66997 L
.57855 .66026 L
.58256 .6515 L
.58299 .65054 L
.58738 .64083 L
.59176 .63112 L
.59227 .62998 L
.59609 .62141 L
.60041 .61169 L
.60198 .60814 L
.60468 .60198 L
.60895 .59227 L
.61169 .58598 L
.61317 .58256 L
.61738 .57284 L
.62141 .5635 L
.62156 .56313 L
.6257 .55342 L
.62985 .54371 L
.63112 .5407 L
.63393 .53399 L
.63803 .52428 L
.64083 .5176 L
.64208 .51457 L
.64612 .50486 L
.65015 .49514 L
.65054 .49419 L
.65413 .48543 L
.65812 .47572 L
.66026 .47048 L
.66206 .46601 L
.666 .45629 L
.66992 .44658 L
.66997 .44647 L
.6738 .43687 L
.67769 .42716 L
.67968 .42216 L
.68153 .41744 L
.68538 .40773 L
.68922 .39802 L
.68939 .39756 L
.693 .38831 L
.6968 .37859 L
.69911 .37268 L
.70056 .36888 L
.70432 .35917 L
.70807 .34946 L
.70882 .34751 L
.71177 .33974 L
.71549 .33003 L
.71853 .32206 L
.71918 .32032 L
.72284 .31061 L
.72653 .30089 L
.72824 .29633 L
.73015 .29118 L
.73379 .28147 L
.73743 .27176 L
.73796 .27033 L
.741 .26204 L
.74461 .25233 L
.74767 .24405 L
.74819 .24262 L
.75173 .23291 L
.75531 .22319 L
.75738 .21751 L
.75882 .21348 L
.76235 .20377 L
.76588 .19406 L
.76709 .19069 L
.76935 .18434 L
.77285 .17463 L
.77634 .16492 L
.77681 .16362 L
.77977 .15521 L
.78324 .14549 L
.78652 .13628 L
.78669 .13578 L
.79009 .12607 L
.79353 .11636 L
.79623 .10868 L
.79693 .10664 L
.80031 .09693 L
.80372 .08722 L
.80594 .08082 L
.80707 .07751 L
.81043 .06779 L
.81381 .05808 L
.81566 .05271 L
.81712 .04837 L
.82045 .03866 L
.8238 .02894 L
.82537 .02436 L
.82708 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.4042 .98077 m
.40773 .97564 L
.41084 .97106 L
.41733 .96134 L
.41744 .96118 L
.42369 .95163 L
.42716 .94624 L
.42991 .94192 L
.43603 .93221 L
.43687 .93085 L
.44203 .92249 L
.44658 .91501 L
.44793 .91278 L
.45373 .90307 L
.45629 .89874 L
.45945 .89336 L
.46508 .88364 L
.46601 .88204 L
.47063 .87393 L
.47572 .86492 L
.47611 .86422 L
.48151 .85451 L
.48543 .84739 L
.48685 .84479 L
.49213 .83508 L
.49514 .82947 L
.49733 .82537 L
.50249 .81566 L
.50486 .81116 L
.50758 .80594 L
.51263 .79623 L
.51457 .79247 L
.51761 .78652 L
.52256 .77681 L
.52428 .7734 L
.52744 .76709 L
.5323 .75738 L
.53399 .75397 L
.53709 .74767 L
.54186 .73796 L
.54371 .73417 L
.54657 .72824 L
.55126 .71853 L
.55342 .71402 L
.55589 .70882 L
.5605 .69911 L
.56313 .69352 L
.56506 .68939 L
.56959 .67968 L
.57284 .67268 L
Mistroke
.57409 .66997 L
.57855 .66026 L
.58256 .6515 L
.58299 .65054 L
.58738 .64083 L
.59176 .63112 L
.59227 .62998 L
.59609 .62141 L
.60041 .61169 L
.60198 .60814 L
.60468 .60198 L
.60895 .59227 L
.61169 .58598 L
.61317 .58256 L
.61738 .57284 L
.62141 .5635 L
.62156 .56313 L
.6257 .55342 L
.62985 .54371 L
.63112 .5407 L
.63393 .53399 L
.63803 .52428 L
.64083 .5176 L
.64208 .51457 L
.64612 .50486 L
.65015 .49514 L
.65054 .49419 L
.65413 .48543 L
.65812 .47572 L
.66026 .47048 L
.66206 .46601 L
.666 .45629 L
.66992 .44658 L
.66997 .44647 L
.6738 .43687 L
.67769 .42716 L
.67968 .42216 L
.68153 .41744 L
.68538 .40773 L
.68922 .39802 L
.68939 .39756 L
.693 .38831 L
.6968 .37859 L
.69911 .37268 L
.70056 .36888 L
.70432 .35917 L
.70807 .34946 L
.70882 .34751 L
.71177 .33974 L
.71549 .33003 L
Mistroke
.71853 .32206 L
.71918 .32032 L
.72284 .31061 L
.72653 .30089 L
.72824 .29633 L
.73015 .29118 L
.73379 .28147 L
.73743 .27176 L
.73796 .27033 L
.741 .26204 L
.74461 .25233 L
.74767 .24405 L
.74819 .24262 L
.75173 .23291 L
.75531 .22319 L
.75738 .21751 L
.75882 .21348 L
.76235 .20377 L
.76588 .19406 L
.76709 .19069 L
.76935 .18434 L
.77285 .17463 L
.77634 .16492 L
.77681 .16362 L
.77977 .15521 L
.78324 .14549 L
.78652 .13628 L
.78669 .13578 L
.79009 .12607 L
.79353 .11636 L
.79623 .10868 L
.79693 .10664 L
.80031 .09693 L
.80372 .08722 L
.80594 .08082 L
.80707 .07751 L
.81043 .06779 L
.81381 .05808 L
.81566 .05271 L
.81712 .04837 L
.82045 .03866 L
.8238 .02894 L
.82537 .02436 L
.82708 .01923 L
Mfstroke
.7 g
.42558 .98077 m
.42716 .97823 L
.43149 .97106 L
.43687 .96219 L
.43736 .96134 L
.44311 .95163 L
.44658 .94575 L
.44878 .94192 L
.45441 .93221 L
.45629 .92894 L
.45992 .92249 L
.46543 .91278 L
.46601 .91175 L
.47078 .90307 L
.47572 .89417 L
.47615 .89336 L
.4814 .88364 L
.48543 .87622 L
.48662 .87393 L
.49178 .86422 L
.49514 .85789 L
.49687 .85451 L
.50194 .84479 L
.50486 .8392 L
.50692 .83508 L
.5119 .82537 L
.51457 .82016 L
.51678 .81566 L
.52167 .80594 L
.52428 .80075 L
.52646 .79623 L
.53126 .78652 L
.53399 .781 L
.53597 .77681 L
.54069 .76709 L
.54371 .76091 L
.54533 .75738 L
.54997 .74767 L
.55342 .74047 L
.55455 .73796 L
.55909 .72824 L
.56313 .71971 L
.56365 .71853 L
.56808 .70882 L
.57261 .69911 L
.57284 .69861 L
.57695 .68939 L
.58141 .67968 L
.58256 .67718 L
.5857 .66997 L
.59009 .66026 L
.59227 .65542 L
.59434 .65054 L
.59865 .64083 L
.60198 .63336 L
.6029 .63112 L
.6071 .62141 L
.61138 .61169 L
.61169 .61098 L
.61546 .60198 L
.61968 .59227 L
.62141 .58829 L
.62373 .58256 L
.62788 .57284 L
.63112 .56529 L
.63196 .56313 L
.63599 .55342 L
.64011 .54371 L
.64083 .542 L
.64402 .53399 L
.64808 .52428 L
.65054 .5184 L
.65201 .51457 L
.65597 .50486 L
.66 .49514 L
.66026 .49451 L
.66379 .48543 L
.66776 .47572 L
.66997 .47032 L
.67158 .46601 L
.67545 .45629 L
.67939 .44658 L
.67968 .44585 L
.68308 .43687 L
.68697 .42716 L
.68939 .42109 L
.69071 .41744 L
.69448 .40773 L
.69833 .39802 L
.69911 .39605 L
.70194 .38831 L
.70574 .37859 L
.70882 .37073 L
.70945 .36888 L
.71308 .35917 L
.71686 .34946 L
.71853 .34513 L
.72042 .33974 L
.7241 .33003 L
.72784 .32032 L
.72824 .31926 L
.73131 .31061 L
.735 .30089 L
.73796 .29312 L
.73859 .29118 L
.7421 .28147 L
.74577 .27176 L
.74767 .2667 L
.74923 .26204 L
.75278 .25233 L
.75642 .24262 L
.75738 .24003 L
.75979 .23291 L
.76335 .22319 L
.76695 .21348 L
.76709 .21309 L
.77025 .20377 L
.77381 .19406 L
.77681 .18589 L
.77728 .18434 L
.78062 .17463 L
.78416 .16492 L
.78652 .15843 L
.78752 .15521 L
.7909 .14549 L
.79441 .13578 L
.79623 .13071 L
.79768 .12607 L
.80107 .11636 L
.80456 .10664 L
.80594 .10274 L
.80776 .09693 L
.81115 .08722 L
.8146 .07751 L
.81566 .07452 L
.81776 .06779 L
.82113 .05808 L
.82456 .04837 L
.82537 .04604 L
.82767 .03866 L
.83102 .02894 L
.83442 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.42558 .98077 m
.42716 .97823 L
.43149 .97106 L
.43687 .96219 L
.43736 .96134 L
.44311 .95163 L
.44658 .94575 L
.44878 .94192 L
.45441 .93221 L
.45629 .92894 L
.45992 .92249 L
.46543 .91278 L
.46601 .91175 L
.47078 .90307 L
.47572 .89417 L
.47615 .89336 L
.4814 .88364 L
.48543 .87622 L
.48662 .87393 L
.49178 .86422 L
.49514 .85789 L
.49687 .85451 L
.50194 .84479 L
.50486 .8392 L
.50692 .83508 L
.5119 .82537 L
.51457 .82016 L
.51678 .81566 L
.52167 .80594 L
.52428 .80075 L
.52646 .79623 L
.53126 .78652 L
.53399 .781 L
.53597 .77681 L
.54069 .76709 L
.54371 .76091 L
.54533 .75738 L
.54997 .74767 L
.55342 .74047 L
.55455 .73796 L
.55909 .72824 L
.56313 .71971 L
.56365 .71853 L
.56808 .70882 L
.57261 .69911 L
.57284 .69861 L
.57695 .68939 L
.58141 .67968 L
.58256 .67718 L
.5857 .66997 L
Mistroke
.59009 .66026 L
.59227 .65542 L
.59434 .65054 L
.59865 .64083 L
.60198 .63336 L
.6029 .63112 L
.6071 .62141 L
.61138 .61169 L
.61169 .61098 L
.61546 .60198 L
.61968 .59227 L
.62141 .58829 L
.62373 .58256 L
.62788 .57284 L
.63112 .56529 L
.63196 .56313 L
.63599 .55342 L
.64011 .54371 L
.64083 .542 L
.64402 .53399 L
.64808 .52428 L
.65054 .5184 L
.65201 .51457 L
.65597 .50486 L
.66 .49514 L
.66026 .49451 L
.66379 .48543 L
.66776 .47572 L
.66997 .47032 L
.67158 .46601 L
.67545 .45629 L
.67939 .44658 L
.67968 .44585 L
.68308 .43687 L
.68697 .42716 L
.68939 .42109 L
.69071 .41744 L
.69448 .40773 L
.69833 .39802 L
.69911 .39605 L
.70194 .38831 L
.70574 .37859 L
.70882 .37073 L
.70945 .36888 L
.71308 .35917 L
.71686 .34946 L
.71853 .34513 L
.72042 .33974 L
.7241 .33003 L
.72784 .32032 L
Mistroke
.72824 .31926 L
.73131 .31061 L
.735 .30089 L
.73796 .29312 L
.73859 .29118 L
.7421 .28147 L
.74577 .27176 L
.74767 .2667 L
.74923 .26204 L
.75278 .25233 L
.75642 .24262 L
.75738 .24003 L
.75979 .23291 L
.76335 .22319 L
.76695 .21348 L
.76709 .21309 L
.77025 .20377 L
.77381 .19406 L
.77681 .18589 L
.77728 .18434 L
.78062 .17463 L
.78416 .16492 L
.78652 .15843 L
.78752 .15521 L
.7909 .14549 L
.79441 .13578 L
.79623 .13071 L
.79768 .12607 L
.80107 .11636 L
.80456 .10664 L
.80594 .10274 L
.80776 .09693 L
.81115 .08722 L
.8146 .07751 L
.81566 .07452 L
.81776 .06779 L
.82113 .05808 L
.82456 .04837 L
.82537 .04604 L
.82767 .03866 L
.83102 .02894 L
.83442 .01923 L
Mfstroke
.6 g
.49289 .98077 m
.49514 .97651 L
.49826 .97106 L
.5036 .96134 L
.50486 .95891 L
.50888 .95163 L
.51403 .94192 L
.51457 .94083 L
.51923 .93221 L
.52421 .92249 L
.52428 .92235 L
.52934 .91278 L
.53399 .90347 L
.5342 .90307 L
.53923 .89336 L
.54371 .88421 L
.54399 .88364 L
.54893 .87393 L
.55342 .86456 L
.55359 .86422 L
.55844 .85451 L
.56302 .84479 L
.56313 .84455 L
.56777 .83508 L
.57232 .82537 L
.57284 .82417 L
.57695 .81566 L
.58147 .80594 L
.58256 .80343 L
.58597 .79623 L
.59047 .78652 L
.59227 .78234 L
.59486 .77681 L
.59933 .76709 L
.60198 .76091 L
.6036 .75738 L
.60804 .74767 L
.61169 .73913 L
.61223 .73796 L
.61662 .72824 L
.62081 .71853 L
.62141 .71703 L
.62507 .70882 L
.62931 .69911 L
.63112 .6946 L
.63341 .68939 L
.63765 .67968 L
.64083 .67184 L
.64164 .66997 L
.64586 .66026 L
.64987 .65054 L
.65054 .64876 L
.65395 .64083 L
.65804 .63112 L
.66026 .62538 L
.66194 .62141 L
.66604 .61169 L
.66986 .60198 L
.66997 .60168 L
.67391 .59227 L
.67787 .58256 L
.67968 .57768 L
.68168 .57284 L
.68568 .56313 L
.68938 .55342 L
.68939 .55337 L
.69335 .54371 L
.69722 .53399 L
.69911 .52878 L
.70092 .52428 L
.70484 .51457 L
.70849 .50486 L
.70882 .50389 L
.71231 .49514 L
.71613 .48543 L
.71853 .47871 L
.71971 .47572 L
.72355 .46601 L
.72721 .45629 L
.72824 .45324 L
.73085 .44658 L
.73463 .43687 L
.73796 .42749 L
.73808 .42716 L
.74185 .41744 L
.74553 .40773 L
.74767 .40146 L
.74899 .39802 L
.75271 .38831 L
.75627 .37859 L
.75738 .37516 L
.75976 .36888 L
.76344 .35917 L
.76683 .34946 L
.76709 .34858 L
.77042 .33974 L
.77403 .33003 L
.77681 .32173 L
.77733 .32032 L
.78095 .31061 L
.78449 .30089 L
.78652 .29462 L
.78778 .29118 L
.79137 .28147 L
.79482 .27176 L
.79623 .26724 L
.79813 .26204 L
.80168 .25233 L
.80504 .24262 L
.80594 .23959 L
.80836 .23291 L
.81188 .22319 L
.81514 .21348 L
.81566 .21169 L
.8185 .20377 L
.82198 .19406 L
.82514 .18434 L
.82537 .18352 L
.82854 .17463 L
.83198 .16492 L
.83506 .15521 L
.83508 .15511 L
.83848 .14549 L
.84189 .13578 L
.84479 .12644 L
.84492 .12607 L
.84833 .11636 L
.85171 .10664 L
.85451 .09752 L
.85471 .09693 L
.85809 .08722 L
.86145 .07751 L
.86422 .06835 L
.86441 .06779 L
.86777 .05808 L
.8711 .04837 L
.87393 .03894 L
.87403 .03866 L
.87736 .02894 L
.88067 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.49289 .98077 m
.49514 .97651 L
.49826 .97106 L
.5036 .96134 L
.50486 .95891 L
.50888 .95163 L
.51403 .94192 L
.51457 .94083 L
.51923 .93221 L
.52421 .92249 L
.52428 .92235 L
.52934 .91278 L
.53399 .90347 L
.5342 .90307 L
.53923 .89336 L
.54371 .88421 L
.54399 .88364 L
.54893 .87393 L
.55342 .86456 L
.55359 .86422 L
.55844 .85451 L
.56302 .84479 L
.56313 .84455 L
.56777 .83508 L
.57232 .82537 L
.57284 .82417 L
.57695 .81566 L
.58147 .80594 L
.58256 .80343 L
.58597 .79623 L
.59047 .78652 L
.59227 .78234 L
.59486 .77681 L
.59933 .76709 L
.60198 .76091 L
.6036 .75738 L
.60804 .74767 L
.61169 .73913 L
.61223 .73796 L
.61662 .72824 L
.62081 .71853 L
.62141 .71703 L
.62507 .70882 L
.62931 .69911 L
.63112 .6946 L
.63341 .68939 L
.63765 .67968 L
.64083 .67184 L
.64164 .66997 L
.64586 .66026 L
Mistroke
.64987 .65054 L
.65054 .64876 L
.65395 .64083 L
.65804 .63112 L
.66026 .62538 L
.66194 .62141 L
.66604 .61169 L
.66986 .60198 L
.66997 .60168 L
.67391 .59227 L
.67787 .58256 L
.67968 .57768 L
.68168 .57284 L
.68568 .56313 L
.68938 .55342 L
.68939 .55337 L
.69335 .54371 L
.69722 .53399 L
.69911 .52878 L
.70092 .52428 L
.70484 .51457 L
.70849 .50486 L
.70882 .50389 L
.71231 .49514 L
.71613 .48543 L
.71853 .47871 L
.71971 .47572 L
.72355 .46601 L
.72721 .45629 L
.72824 .45324 L
.73085 .44658 L
.73463 .43687 L
.73796 .42749 L
.73808 .42716 L
.74185 .41744 L
.74553 .40773 L
.74767 .40146 L
.74899 .39802 L
.75271 .38831 L
.75627 .37859 L
.75738 .37516 L
.75976 .36888 L
.76344 .35917 L
.76683 .34946 L
.76709 .34858 L
.77042 .33974 L
.77403 .33003 L
.77681 .32173 L
.77733 .32032 L
.78095 .31061 L
Mistroke
.78449 .30089 L
.78652 .29462 L
.78778 .29118 L
.79137 .28147 L
.79482 .27176 L
.79623 .26724 L
.79813 .26204 L
.80168 .25233 L
.80504 .24262 L
.80594 .23959 L
.80836 .23291 L
.81188 .22319 L
.81514 .21348 L
.81566 .21169 L
.8185 .20377 L
.82198 .19406 L
.82514 .18434 L
.82537 .18352 L
.82854 .17463 L
.83198 .16492 L
.83506 .15521 L
.83508 .15511 L
.83848 .14549 L
.84189 .13578 L
.84479 .12644 L
.84492 .12607 L
.84833 .11636 L
.85171 .10664 L
.85451 .09752 L
.85471 .09693 L
.85809 .08722 L
.86145 .07751 L
.86422 .06835 L
.86441 .06779 L
.86777 .05808 L
.8711 .04837 L
.87393 .03894 L
.87403 .03866 L
.87736 .02894 L
.88067 .01923 L
Mfstroke
.2 g
.50486 .28662 m
.51299 .29118 L
.50649 .30089 L
.50486 .30319 L
.4994 .30089 L
.50302 .29118 L
F
0 g
.50486 .28662 m
.51299 .29118 L
.50649 .30089 L
.50486 .30319 L
.4994 .30089 L
.50302 .29118 L
.50486 .28662 L
s
.8 g
.50486 .89077 m
.51426 .89336 L
.50785 .90307 L
.50486 .90734 L
.50009 .90307 L
.50381 .89336 L
F
0 g
.50486 .89077 m
.51426 .89336 L
.50785 .90307 L
.50486 .90734 L
.50009 .90307 L
.50381 .89336 L
.50486 .89077 L
s
.8 g
.55294 .01923 m
.5478 .02894 L
.54371 .03735 L
.5426 .03866 L
.53728 .04837 L
.53399 .0554 L
.53187 .05808 L
.52631 .06779 L
.52428 .07223 L
.52057 .07751 L
.51464 .08722 L
.51457 .08737 L
.50826 .09693 L
.50486 .10181 L
.5003 .09693 L
.50405 .08722 L
.50486 .08523 L
.50812 .07751 L
.5123 .06779 L
.51457 .06259 L
.51657 .05808 L
.52089 .04837 L
.52428 .04073 L
.52522 .03866 L
.52958 .02894 L
.53389 .01923 L
F
0 g
.55294 .01923 m
.5478 .02894 L
.54371 .03735 L
.5426 .03866 L
.53728 .04837 L
.53399 .0554 L
.53187 .05808 L
.52631 .06779 L
.52428 .07223 L
.52057 .07751 L
.51464 .08722 L
.51457 .08737 L
.50826 .09693 L
.50486 .10181 L
.5003 .09693 L
.50405 .08722 L
.50486 .08523 L
.50812 .07751 L
.5123 .06779 L
.51457 .06259 L
.51657 .05808 L
.52089 .04837 L
.52428 .04073 L
.52522 .03866 L
.52958 .02894 L
.53389 .01923 L
s
.2 g
.80287 .01923 m
.80048 .02894 L
.79623 .03801 L
.796 .03866 L
.7925 .04837 L
.78978 .05808 L
.78652 .06517 L
.78555 .06779 L
.78203 .07751 L
.77897 .08722 L
.77681 .09204 L
.77499 .09693 L
.77326 .10664 L
.76808 .11636 L
.76709 .1186 L
.76431 .12607 L
.76191 .13578 L
.75738 .14489 L
.75715 .14549 L
.75351 .15521 L
.75054 .16492 L
.74767 .17094 L
.74625 .17463 L
.74257 .18434 L
.73915 .19406 L
.73796 .19664 L
.73521 .20377 L
.7327 .21348 L
.72824 .22207 L
.72779 .22319 L
.72403 .23291 L
.72078 .24262 L
.71853 .24723 L
.71651 .25233 L
.71439 .26204 L
.70894 .27176 L
.70882 .272 L
.70506 .28147 L
.70189 .29118 L
.69911 .2966 L
.69735 .30089 L
.69345 .31061 L
.6896 .32032 L
.68939 .32074 L
.68561 .33003 L
.68232 .33974 L
.67968 .34471 L
.67769 .34946 L
.67547 .35917 L
.66997 .36823 L
.66968 .36888 L
.66562 .37859 L
.66197 .38831 L
.66026 .3915 L
.65746 .39802 L
.65457 .40773 L
.65054 .41444 L
.64921 .41744 L
.64502 .42716 L
.64085 .43687 L
.64083 .4369 L
.63659 .44658 L
.63278 .45629 L
.63112 .45917 L
.62805 .46601 L
.62483 .47572 L
.62141 .48107 L
.61937 .48543 L
.61498 .49514 L
.61169 .50255 L
.61057 .50486 L
.60609 .51457 L
.60198 .52357 L
.60161 .52428 L
.59705 .53399 L
.59257 .54371 L
.59227 .54418 L
.58784 .55342 L
.58347 .56313 L
.58256 .56448 L
.57844 .57284 L
.57414 .58256 L
.57284 .58434 L
.56883 .59227 L
.56395 .60198 L
.56313 .60371 L
.55898 .61169 L
.55397 .62141 L
.55342 .62255 L
.54884 .63112 L
.54371 .64082 L
.54368 .64083 L
.53837 .65054 L
.53399 .65849 L
.53299 .66026 L
.52745 .66997 L
.52428 .67546 L
.52176 .67968 L
.51587 .68939 L
.51457 .69242 L
.5096 .69911 L
.50486 .70596 L
.50103 .69911 L
.50485 .68939 L
.50486 .68938 L
.50896 .67968 L
.51316 .66997 L
.51457 .66674 L
.51745 .66026 L
.52176 .65054 L
.52428 .64488 L
.52611 .64083 L
.53047 .63112 L
.53399 .62323 L
.53482 .62141 L
.53919 .61169 L
.54344 .60198 L
.54371 .60154 L
.54788 .59227 L
.55156 .58256 L
.55342 .57959 L
.55653 .57284 L
.56082 .56313 L
.56313 .55754 L
.56511 .55342 L
.56938 .54371 L
.57284 .5355 L
.57362 .53399 L
.57786 .52428 L
.58191 .51457 L
.58256 .51336 L
.58626 .50486 L
.58974 .49514 L
.59227 .49067 L
.59459 .48543 L
.59714 .47572 L
.60198 .46786 L
.60283 .46601 L
.60694 .45629 L
.61083 .44658 L
.61169 .44489 L
.61508 .43687 L
.61834 .42716 L
.62141 .42147 L
.62314 .41744 L
.6253 .40773 L
.63112 .39802 L
.63112 .39802 L
.6351 .38831 L
.63854 .37859 L
.64083 .37407 L
.64298 .36888 L
.64547 .35917 L
.65054 .35002 L
.65078 .34946 L
.65468 .33974 L
.65809 .33003 L
.66026 .32559 L
.66239 .32032 L
.66483 .31061 L
.66997 .30103 L
.67002 .30089 L
.67384 .29118 L
.67708 .28147 L
.67968 .27605 L
.68139 .27176 L
.68351 .26204 L
.68877 .25233 L
.68939 .25094 L
.69261 .24262 L
.69551 .23291 L
.69911 .22547 L
.7 .22319 L
.70369 .21348 L
.70702 .20377 L
.70882 .19979 L
.71101 .19406 L
.71334 .18434 L
.71821 .17463 L
.71853 .17389 L
.72189 .16492 L
.72473 .15521 L
.72824 .14764 L
.72906 .14549 L
.73265 .13578 L
.7358 .12607 L
.73796 .12118 L
.73975 .11636 L
.74173 .10664 L
.74663 .09693 L
.74767 .09449 L
.75032 .08722 L
.75274 .07751 L
.75728 .06779 L
.75738 .06755 L
.76079 .05808 L
.76349 .04837 L
.76709 .04029 L
.76769 .03866 L
.77115 .02894 L
.77404 .01923 L
F
0 g
.80287 .01923 m
.80048 .02894 L
.79623 .03801 L
.796 .03866 L
.7925 .04837 L
.78978 .05808 L
.78652 .06517 L
.78555 .06779 L
.78203 .07751 L
.77897 .08722 L
.77681 .09204 L
.77499 .09693 L
.77326 .10664 L
.76808 .11636 L
.76709 .1186 L
.76431 .12607 L
.76191 .13578 L
.75738 .14489 L
.75715 .14549 L
.75351 .15521 L
.75054 .16492 L
.74767 .17094 L
.74625 .17463 L
.74257 .18434 L
.73915 .19406 L
.73796 .19664 L
.73521 .20377 L
.7327 .21348 L
.72824 .22207 L
.72779 .22319 L
.72403 .23291 L
.72078 .24262 L
.71853 .24723 L
.71651 .25233 L
.71439 .26204 L
.70894 .27176 L
.70882 .272 L
.70506 .28147 L
.70189 .29118 L
.69911 .2966 L
.69735 .30089 L
.69345 .31061 L
.6896 .32032 L
.68939 .32074 L
.68561 .33003 L
.68232 .33974 L
.67968 .34471 L
.67769 .34946 L
.67547 .35917 L
.66997 .36823 L
Mistroke
.66968 .36888 L
.66562 .37859 L
.66197 .38831 L
.66026 .3915 L
.65746 .39802 L
.65457 .40773 L
.65054 .41444 L
.64921 .41744 L
.64502 .42716 L
.64085 .43687 L
.64083 .4369 L
.63659 .44658 L
.63278 .45629 L
.63112 .45917 L
.62805 .46601 L
.62483 .47572 L
.62141 .48107 L
.61937 .48543 L
.61498 .49514 L
.61169 .50255 L
.61057 .50486 L
.60609 .51457 L
.60198 .52357 L
.60161 .52428 L
.59705 .53399 L
.59257 .54371 L
.59227 .54418 L
.58784 .55342 L
.58347 .56313 L
.58256 .56448 L
.57844 .57284 L
.57414 .58256 L
.57284 .58434 L
.56883 .59227 L
.56395 .60198 L
.56313 .60371 L
.55898 .61169 L
.55397 .62141 L
.55342 .62255 L
.54884 .63112 L
.54371 .64082 L
.54368 .64083 L
.53837 .65054 L
.53399 .65849 L
.53299 .66026 L
.52745 .66997 L
.52428 .67546 L
.52176 .67968 L
.51587 .68939 L
.51457 .69242 L
Mistroke
.5096 .69911 L
.50486 .70596 L
.50103 .69911 L
.50485 .68939 L
.50486 .68938 L
.50896 .67968 L
.51316 .66997 L
.51457 .66674 L
.51745 .66026 L
.52176 .65054 L
.52428 .64488 L
.52611 .64083 L
.53047 .63112 L
.53399 .62323 L
.53482 .62141 L
.53919 .61169 L
.54344 .60198 L
.54371 .60154 L
.54788 .59227 L
.55156 .58256 L
.55342 .57959 L
.55653 .57284 L
.56082 .56313 L
.56313 .55754 L
.56511 .55342 L
.56938 .54371 L
.57284 .5355 L
.57362 .53399 L
.57786 .52428 L
.58191 .51457 L
.58256 .51336 L
.58626 .50486 L
.58974 .49514 L
.59227 .49067 L
.59459 .48543 L
.59714 .47572 L
.60198 .46786 L
.60283 .46601 L
.60694 .45629 L
.61083 .44658 L
.61169 .44489 L
.61508 .43687 L
.61834 .42716 L
.62141 .42147 L
.62314 .41744 L
.6253 .40773 L
.63112 .39802 L
.63112 .39802 L
.6351 .38831 L
.63854 .37859 L
Mistroke
.64083 .37407 L
.64298 .36888 L
.64547 .35917 L
.65054 .35002 L
.65078 .34946 L
.65468 .33974 L
.65809 .33003 L
.66026 .32559 L
.66239 .32032 L
.66483 .31061 L
.66997 .30103 L
.67002 .30089 L
.67384 .29118 L
.67708 .28147 L
.67968 .27605 L
.68139 .27176 L
.68351 .26204 L
.68877 .25233 L
.68939 .25094 L
.69261 .24262 L
.69551 .23291 L
.69911 .22547 L
.7 .22319 L
.70369 .21348 L
.70702 .20377 L
.70882 .19979 L
.71101 .19406 L
.71334 .18434 L
.71821 .17463 L
.71853 .17389 L
.72189 .16492 L
.72473 .15521 L
.72824 .14764 L
.72906 .14549 L
.73265 .13578 L
.7358 .12607 L
.73796 .12118 L
.73975 .11636 L
.74173 .10664 L
.74663 .09693 L
.74767 .09449 L
.75032 .08722 L
.75274 .07751 L
.75728 .06779 L
.75738 .06755 L
.76079 .05808 L
.76349 .04837 L
.76709 .04029 L
.76769 .03866 L
.77115 .02894 L
Mistroke
.77404 .01923 L
Mfstroke
.8 g
.50486 .488 m
.51131 .49514 L
.50486 .50458 L
.50201 .49514 L
F
0 g
.50486 .488 m
.51131 .49514 L
.50486 .50458 L
.50201 .49514 L
.50486 .488 L
s
.8 g
.72891 .01923 m
.72824 .02063 L
.72503 .02894 L
.72222 .03866 L
.71853 .04584 L
.71752 .04837 L
.71371 .05808 L
.71021 .06779 L
.70882 .07066 L
.70608 .07751 L
.70344 .08722 L
.69911 .0952 L
.69839 .09693 L
.69448 .10664 L
.69093 .11636 L
.68939 .1194 L
.68666 .12607 L
.68393 .13578 L
.67968 .14332 L
.67875 .14549 L
.67475 .15521 L
.67096 .16492 L
.66997 .16685 L
.6667 .17463 L
.66355 .18434 L
.66026 .19015 L
.65856 .19406 L
.65444 .20377 L
.65054 .21299 L
.65032 .21348 L
.64613 .22319 L
.64232 .23291 L
.64083 .23558 L
.63772 .24262 L
.63453 .25233 L
.63112 .25784 L
.62919 .26204 L
.62487 .27176 L
.62141 .27967 L
.62054 .28147 L
.61615 .29118 L
.61177 .30089 L
.61169 .30103 L
.60728 .31061 L
.60313 .32032 L
.60198 .32216 L
.59826 .33003 L
.59442 .33974 L
.59227 .3429 L
.58907 .34946 L
.58442 .35917 L
.58256 .36322 L
.5797 .36888 L
.57494 .37859 L
.57284 .38309 L
.57012 .38831 L
.56525 .39802 L
.56313 .4025 L
.5603 .40773 L
.5553 .41744 L
.55342 .42138 L
.55021 .42716 L
.54506 .43687 L
.54371 .43966 L
.53978 .44658 L
.53444 .45629 L
.53399 .4572 L
.52893 .46601 L
.52428 .47408 L
.52331 .47572 L
.51745 .48543 L
.51457 .4901 L
.50593 .48543 L
.51007 .47572 L
.51428 .46601 L
.51457 .46514 L
.51859 .45629 L
.52291 .44658 L
.52428 .44273 L
.52727 .43687 L
.53162 .42716 L
.53399 .42091 L
.53598 .41744 L
.54034 .40773 L
.54371 .39946 L
.54468 .39802 L
.54903 .38831 L
.55331 .37859 L
.55342 .37841 L
.55767 .36888 L
.56144 .35917 L
.56313 .35632 L
.56624 .34946 L
.56926 .33974 L
.57284 .3341 L
.57475 .33003 L
.57898 .32032 L
.58256 .31184 L
.58317 .31061 L
.58737 .30089 L
.59131 .29118 L
.59227 .28938 L
.59569 .28147 L
.599 .27176 L
.60198 .26646 L
.60393 .26204 L
.6062 .25233 L
.61169 .24347 L
.61209 .24262 L
.61616 .23291 L
.61985 .22319 L
.62141 .22014 L
.62421 .21348 L
.62713 .20377 L
.63112 .19651 L
.63218 .19406 L
.63615 .18434 L
.63991 .17463 L
.64083 .17274 L
.64402 .16492 L
.6471 .15521 L
.65054 .14856 L
.65182 .14549 L
.65364 .13578 L
.6594 .12607 L
.66026 .12425 L
.66341 .11636 L
.6664 .10664 L
.66997 .09957 L
.67104 .09693 L
.67485 .08722 L
.67838 .07751 L
.67968 .0747 L
.68239 .06779 L
.6851 .05808 L
.68939 .04953 L
.68986 .04837 L
.6936 .03866 L
.69686 .02894 L
.69911 .02455 L
.70099 .01923 L
F
0 g
.72891 .01923 m
.72824 .02063 L
.72503 .02894 L
.72222 .03866 L
.71853 .04584 L
.71752 .04837 L
.71371 .05808 L
.71021 .06779 L
.70882 .07066 L
.70608 .07751 L
.70344 .08722 L
.69911 .0952 L
.69839 .09693 L
.69448 .10664 L
.69093 .11636 L
.68939 .1194 L
.68666 .12607 L
.68393 .13578 L
.67968 .14332 L
.67875 .14549 L
.67475 .15521 L
.67096 .16492 L
.66997 .16685 L
.6667 .17463 L
.66355 .18434 L
.66026 .19015 L
.65856 .19406 L
.65444 .20377 L
.65054 .21299 L
.65032 .21348 L
.64613 .22319 L
.64232 .23291 L
.64083 .23558 L
.63772 .24262 L
.63453 .25233 L
.63112 .25784 L
.62919 .26204 L
.62487 .27176 L
.62141 .27967 L
.62054 .28147 L
.61615 .29118 L
.61177 .30089 L
.61169 .30103 L
.60728 .31061 L
.60313 .32032 L
.60198 .32216 L
.59826 .33003 L
.59442 .33974 L
.59227 .3429 L
.58907 .34946 L
Mistroke
.58442 .35917 L
.58256 .36322 L
.5797 .36888 L
.57494 .37859 L
.57284 .38309 L
.57012 .38831 L
.56525 .39802 L
.56313 .4025 L
.5603 .40773 L
.5553 .41744 L
.55342 .42138 L
.55021 .42716 L
.54506 .43687 L
.54371 .43966 L
.53978 .44658 L
.53444 .45629 L
.53399 .4572 L
.52893 .46601 L
.52428 .47408 L
.52331 .47572 L
.51745 .48543 L
.51457 .4901 L
.50593 .48543 L
.51007 .47572 L
.51428 .46601 L
.51457 .46514 L
.51859 .45629 L
.52291 .44658 L
.52428 .44273 L
.52727 .43687 L
.53162 .42716 L
.53399 .42091 L
.53598 .41744 L
.54034 .40773 L
.54371 .39946 L
.54468 .39802 L
.54903 .38831 L
.55331 .37859 L
.55342 .37841 L
.55767 .36888 L
.56144 .35917 L
.56313 .35632 L
.56624 .34946 L
.56926 .33974 L
.57284 .3341 L
.57475 .33003 L
.57898 .32032 L
.58256 .31184 L
.58317 .31061 L
.58737 .30089 L
Mistroke
.59131 .29118 L
.59227 .28938 L
.59569 .28147 L
.599 .27176 L
.60198 .26646 L
.60393 .26204 L
.6062 .25233 L
.61169 .24347 L
.61209 .24262 L
.61616 .23291 L
.61985 .22319 L
.62141 .22014 L
.62421 .21348 L
.62713 .20377 L
.63112 .19651 L
.63218 .19406 L
.63615 .18434 L
.63991 .17463 L
.64083 .17274 L
.64402 .16492 L
.6471 .15521 L
.65054 .14856 L
.65182 .14549 L
.65364 .13578 L
.6594 .12607 L
.66026 .12425 L
.66341 .11636 L
.6664 .10664 L
.66997 .09957 L
.67104 .09693 L
.67485 .08722 L
.67838 .07751 L
.67968 .0747 L
.68239 .06779 L
.6851 .05808 L
.68939 .04953 L
.68986 .04837 L
.6936 .03866 L
.69686 .02894 L
.69911 .02455 L
.70099 .01923 L
Mfstroke
.2 g
.64724 .01923 m
.64398 .02894 L
.64083 .03424 L
.63885 .03866 L
.6346 .04837 L
.63112 .05643 L
.63034 .05808 L
.62602 .06779 L
.6218 .07751 L
.62141 .07819 L
.61731 .08722 L
.61341 .09693 L
.61169 .09972 L
.60847 .10664 L
.60505 .11636 L
.60198 .12087 L
.59947 .12607 L
.59491 .13578 L
.59227 .1416 L
.59031 .14549 L
.58565 .15521 L
.58256 .1619 L
.58096 .16492 L
.5762 .17463 L
.57284 .18178 L
.57141 .18434 L
.56654 .19406 L
.56313 .20122 L
.56163 .20377 L
.55663 .21348 L
.55342 .22019 L
.55158 .22319 L
.54643 .23291 L
.54371 .2386 L
.5412 .24262 L
.53586 .25233 L
.53399 .25624 L
.5304 .26204 L
.52483 .27176 L
.52428 .27287 L
.51902 .28147 L
.51457 .28872 L
.50702 .28147 L
.51118 .27176 L
.51457 .26397 L
.51542 .26204 L
.51974 .25233 L
.52406 .24262 L
.52428 .24203 L
.52843 .23291 L
.53277 .22319 L
.53399 .22006 L
.53714 .21348 L
.54149 .20377 L
.54371 .19824 L
.54584 .19406 L
.55018 .18434 L
.55342 .17654 L
.55449 .17463 L
.55881 .16492 L
.56307 .15521 L
.56313 .1551 L
.56738 .14549 L
.57115 .13578 L
.57284 .13284 L
.57587 .12607 L
.5789 .11636 L
.58256 .11041 L
.58429 .10664 L
.58848 .09693 L
.59227 .08796 L
.59263 .08722 L
.59679 .07751 L
.60059 .06779 L
.60198 .06515 L
.60502 .05808 L
.60811 .04837 L
.61169 .04201 L
.61317 .03866 L
.61723 .02894 L
.62121 .01923 L
F
0 g
.64724 .01923 m
.64398 .02894 L
.64083 .03424 L
.63885 .03866 L
.6346 .04837 L
.63112 .05643 L
.63034 .05808 L
.62602 .06779 L
.6218 .07751 L
.62141 .07819 L
.61731 .08722 L
.61341 .09693 L
.61169 .09972 L
.60847 .10664 L
.60505 .11636 L
.60198 .12087 L
.59947 .12607 L
.59491 .13578 L
.59227 .1416 L
.59031 .14549 L
.58565 .15521 L
.58256 .1619 L
.58096 .16492 L
.5762 .17463 L
.57284 .18178 L
.57141 .18434 L
.56654 .19406 L
.56313 .20122 L
.56163 .20377 L
.55663 .21348 L
.55342 .22019 L
.55158 .22319 L
.54643 .23291 L
.54371 .2386 L
.5412 .24262 L
.53586 .25233 L
.53399 .25624 L
.5304 .26204 L
.52483 .27176 L
.52428 .27287 L
.51902 .28147 L
.51457 .28872 L
.50702 .28147 L
.51118 .27176 L
.51457 .26397 L
.51542 .26204 L
.51974 .25233 L
.52406 .24262 L
.52428 .24203 L
.52843 .23291 L
Mistroke
.53277 .22319 L
.53399 .22006 L
.53714 .21348 L
.54149 .20377 L
.54371 .19824 L
.54584 .19406 L
.55018 .18434 L
.55342 .17654 L
.55449 .17463 L
.55881 .16492 L
.56307 .15521 L
.56313 .1551 L
.56738 .14549 L
.57115 .13578 L
.57284 .13284 L
.57587 .12607 L
.5789 .11636 L
.58256 .11041 L
.58429 .10664 L
.58848 .09693 L
.59227 .08796 L
.59263 .08722 L
.59679 .07751 L
.60059 .06779 L
.60198 .06515 L
.60502 .05808 L
.60811 .04837 L
.61169 .04201 L
.61317 .03866 L
.61723 .02894 L
.62121 .01923 L
Mfstroke
.8 g
.87178 .01923 m
.87024 .02894 L
.86558 .03866 L
.86422 .04205 L
.86208 .04837 L
.8605 .05808 L
.85581 .06779 L
.85451 .07102 L
.85229 .07751 L
.85062 .08722 L
.84593 .09693 L
.84479 .09974 L
.84241 .10664 L
.84059 .11636 L
.83595 .12607 L
.83508 .12819 L
.83245 .13578 L
.83043 .14549 L
.82585 .15521 L
.82537 .15638 L
.82238 .16492 L
.82013 .17463 L
.81566 .18431 L
.81564 .18434 L
.81222 .19406 L
.8097 .20377 L
.80594 .21201 L
.80541 .21348 L
.80195 .22319 L
.79916 .23291 L
.79623 .23943 L
.79507 .24262 L
.79158 .25233 L
.78852 .26204 L
.78652 .26656 L
.78461 .27176 L
.78286 .28147 L
.77777 .29118 L
.77681 .2934 L
.77405 .30089 L
.7717 .31061 L
.76709 .31996 L
.76696 .32032 L
.76336 .33003 L
.76049 .33974 L
.75738 .3463 L
.75618 .34946 L
.75255 .35917 L
.74924 .36888 L
.74767 .37231 L
.74527 .37859 L
.74301 .38831 L
.73796 .39799 L
.73795 .39802 L
.73422 .40773 L
.73122 .41744 L
.72824 .42348 L
.72679 .42716 L
.72304 .43687 L
.71947 .44658 L
.71853 .44858 L
.71549 .45629 L
.71273 .46601 L
.70882 .47344 L
.70789 .47572 L
.70404 .48543 L
.70049 .49514 L
.69911 .49795 L
.69631 .50486 L
.69359 .51457 L
.68939 .52219 L
.68851 .52428 L
.68456 .53399 L
.68087 .54371 L
.67968 .54606 L
.67662 .55342 L
.67365 .56313 L
.66997 .56967 L
.6686 .57284 L
.66454 .58256 L
.66055 .59227 L
.66026 .59284 L
.65637 .60198 L
.65285 .61169 L
.65054 .61581 L
.64809 .62141 L
.64543 .63112 L
.64083 .63839 L
.63972 .64083 L
.63546 .65054 L
.63125 .66026 L
.63112 .66049 L
.6269 .66997 L
.62302 .67968 L
.62141 .6824 L
.61821 .68939 L
.61486 .69911 L
.61169 .70393 L
.60938 .70882 L
.6049 .71853 L
.60198 .72505 L
.6004 .72824 L
.59584 .73796 L
.59227 .74574 L
.59126 .74767 L
.5866 .75738 L
.58256 .76598 L
.58193 .76709 L
.57717 .77681 L
.57284 .7858 L
.5724 .78652 L
.56753 .79623 L
.56313 .80522 L
.56264 .80594 L
.55765 .81566 L
.55342 .82428 L
.55262 .82537 L
.54748 .83508 L
.54371 .8429 L
.54228 .84479 L
.53695 .85451 L
.53399 .86081 L
.53153 .86422 L
.52597 .87393 L
.52428 .87755 L
.52021 .88364 L
.51457 .89288 L
.50786 .88364 L
.51204 .87393 L
.51457 .86812 L
.5163 .86422 L
.52062 .85451 L
.52428 .84627 L
.52494 .84479 L
.52931 .83508 L
.53345 .82537 L
.53399 .82452 L
.53803 .81566 L
.54237 .80594 L
.54371 .80264 L
.54673 .79623 L
.55106 .78652 L
.55342 .78075 L
.55538 .77681 L
.55968 .76709 L
.56313 .75892 L
.56397 .75738 L
.56825 .74767 L
.57237 .73796 L
.57284 .7371 L
.57674 .72824 L
.58032 .71853 L
.58256 .71463 L
.58515 .70882 L
.58787 .69911 L
.59227 .69201 L
.59348 .68939 L
.59763 .67968 L
.60168 .66997 L
.60198 .66937 L
.60586 .66026 L
.60937 .65054 L
.61169 .64619 L
.614 .64083 L
.6166 .63112 L
.62141 .62289 L
.62207 .62141 L
.62609 .61169 L
.6298 .60198 L
.63112 .59933 L
.63405 .59227 L
.63703 .58256 L
.64083 .57544 L
.64193 .57284 L
.64586 .56313 L
.64958 .55342 L
.65054 .55139 L
.65365 .54371 L
.65665 .53399 L
.66026 .52697 L
.66136 .52428 L
.66521 .51457 L
.66881 .50486 L
.66997 .50237 L
.67283 .49514 L
.67565 .48543 L
.67968 .47745 L
.68038 .47572 L
.68415 .46601 L
.68753 .45629 L
.68939 .45228 L
.69162 .44658 L
.69404 .43687 L
.699 .42716 L
.69911 .42692 L
.70272 .41744 L
.70574 .40773 L
.70882 .40116 L
.71004 .39802 L
.71172 .38831 L
.71705 .37859 L
.71853 .37524 L
.72093 .36888 L
.72333 .35917 L
.72808 .34946 L
.72824 .34907 L
.7317 .33974 L
.73454 .33003 L
.73796 .32257 L
.7388 .32032 L
.74235 .31061 L
.74546 .30089 L
.74767 .29585 L
.74939 .29118 L
.75128 .28147 L
.75618 .27176 L
.75738 .2689 L
.75987 .26204 L
.76216 .25233 L
.76672 .24262 L
.76709 .2417 L
.77024 .23291 L
.77279 .22319 L
.77681 .21423 L
.77708 .21348 L
.78051 .20377 L
.78324 .19406 L
.78652 .18649 L
.78729 .18434 L
.79068 .17463 L
.79353 .16492 L
.79623 .15852 L
.7974 .15521 L
.7987 .14549 L
.80368 .13578 L
.80594 .13031 L
.80742 .12607 L
.8089 .11636 L
.81371 .10664 L
.81566 .10186 L
.81736 .09693 L
.81894 .08722 L
.82363 .07751 L
.82537 .07316 L
.8272 .06779 L
.82883 .05808 L
.83344 .04837 L
.83508 .04423 L
.83697 .03866 L
.83859 .02894 L
.84315 .01923 L
F
0 g
.87178 .01923 m
.87024 .02894 L
.86558 .03866 L
.86422 .04205 L
.86208 .04837 L
.8605 .05808 L
.85581 .06779 L
.85451 .07102 L
.85229 .07751 L
.85062 .08722 L
.84593 .09693 L
.84479 .09974 L
.84241 .10664 L
.84059 .11636 L
.83595 .12607 L
.83508 .12819 L
.83245 .13578 L
.83043 .14549 L
.82585 .15521 L
.82537 .15638 L
.82238 .16492 L
.82013 .17463 L
.81566 .18431 L
.81564 .18434 L
.81222 .19406 L
.8097 .20377 L
.80594 .21201 L
.80541 .21348 L
.80195 .22319 L
.79916 .23291 L
.79623 .23943 L
.79507 .24262 L
.79158 .25233 L
.78852 .26204 L
.78652 .26656 L
.78461 .27176 L
.78286 .28147 L
.77777 .29118 L
.77681 .2934 L
.77405 .30089 L
.7717 .31061 L
.76709 .31996 L
.76696 .32032 L
.76336 .33003 L
.76049 .33974 L
.75738 .3463 L
.75618 .34946 L
.75255 .35917 L
.74924 .36888 L
.74767 .37231 L
Mistroke
.74527 .37859 L
.74301 .38831 L
.73796 .39799 L
.73795 .39802 L
.73422 .40773 L
.73122 .41744 L
.72824 .42348 L
.72679 .42716 L
.72304 .43687 L
.71947 .44658 L
.71853 .44858 L
.71549 .45629 L
.71273 .46601 L
.70882 .47344 L
.70789 .47572 L
.70404 .48543 L
.70049 .49514 L
.69911 .49795 L
.69631 .50486 L
.69359 .51457 L
.68939 .52219 L
.68851 .52428 L
.68456 .53399 L
.68087 .54371 L
.67968 .54606 L
.67662 .55342 L
.67365 .56313 L
.66997 .56967 L
.6686 .57284 L
.66454 .58256 L
.66055 .59227 L
.66026 .59284 L
.65637 .60198 L
.65285 .61169 L
.65054 .61581 L
.64809 .62141 L
.64543 .63112 L
.64083 .63839 L
.63972 .64083 L
.63546 .65054 L
.63125 .66026 L
.63112 .66049 L
.6269 .66997 L
.62302 .67968 L
.62141 .6824 L
.61821 .68939 L
.61486 .69911 L
.61169 .70393 L
.60938 .70882 L
.6049 .71853 L
Mistroke
.60198 .72505 L
.6004 .72824 L
.59584 .73796 L
.59227 .74574 L
.59126 .74767 L
.5866 .75738 L
.58256 .76598 L
.58193 .76709 L
.57717 .77681 L
.57284 .7858 L
.5724 .78652 L
.56753 .79623 L
.56313 .80522 L
.56264 .80594 L
.55765 .81566 L
.55342 .82428 L
.55262 .82537 L
.54748 .83508 L
.54371 .8429 L
.54228 .84479 L
.53695 .85451 L
.53399 .86081 L
.53153 .86422 L
.52597 .87393 L
.52428 .87755 L
.52021 .88364 L
.51457 .89288 L
.50786 .88364 L
.51204 .87393 L
.51457 .86812 L
.5163 .86422 L
.52062 .85451 L
.52428 .84627 L
.52494 .84479 L
.52931 .83508 L
.53345 .82537 L
.53399 .82452 L
.53803 .81566 L
.54237 .80594 L
.54371 .80264 L
.54673 .79623 L
.55106 .78652 L
.55342 .78075 L
.55538 .77681 L
.55968 .76709 L
.56313 .75892 L
.56397 .75738 L
.56825 .74767 L
.57237 .73796 L
.57284 .7371 L
Mistroke
.57674 .72824 L
.58032 .71853 L
.58256 .71463 L
.58515 .70882 L
.58787 .69911 L
.59227 .69201 L
.59348 .68939 L
.59763 .67968 L
.60168 .66997 L
.60198 .66937 L
.60586 .66026 L
.60937 .65054 L
.61169 .64619 L
.614 .64083 L
.6166 .63112 L
.62141 .62289 L
.62207 .62141 L
.62609 .61169 L
.6298 .60198 L
.63112 .59933 L
.63405 .59227 L
.63703 .58256 L
.64083 .57544 L
.64193 .57284 L
.64586 .56313 L
.64958 .55342 L
.65054 .55139 L
.65365 .54371 L
.65665 .53399 L
.66026 .52697 L
.66136 .52428 L
.66521 .51457 L
.66881 .50486 L
.66997 .50237 L
.67283 .49514 L
.67565 .48543 L
.67968 .47745 L
.68038 .47572 L
.68415 .46601 L
.68753 .45629 L
.68939 .45228 L
.69162 .44658 L
.69404 .43687 L
.699 .42716 L
.69911 .42692 L
.70272 .41744 L
.70574 .40773 L
.70882 .40116 L
.71004 .39802 L
.71172 .38831 L
Mistroke
.71705 .37859 L
.71853 .37524 L
.72093 .36888 L
.72333 .35917 L
.72808 .34946 L
.72824 .34907 L
.7317 .33974 L
.73454 .33003 L
.73796 .32257 L
.7388 .32032 L
.74235 .31061 L
.74546 .30089 L
.74767 .29585 L
.74939 .29118 L
.75128 .28147 L
.75618 .27176 L
.75738 .2689 L
.75987 .26204 L
.76216 .25233 L
.76672 .24262 L
.76709 .2417 L
.77024 .23291 L
.77279 .22319 L
.77681 .21423 L
.77708 .21348 L
.78051 .20377 L
.78324 .19406 L
.78652 .18649 L
.78729 .18434 L
.79068 .17463 L
.79353 .16492 L
.79623 .15852 L
.7974 .15521 L
.7987 .14549 L
.80368 .13578 L
.80594 .13031 L
.80742 .12607 L
.8089 .11636 L
.81371 .10664 L
.81566 .10186 L
.81736 .09693 L
.81894 .08722 L
.82363 .07751 L
.82537 .07316 L
.8272 .06779 L
.82883 .05808 L
.83344 .04837 L
.83508 .04423 L
.83697 .03866 L
.83859 .02894 L
Mistroke
.84315 .01923 L
Mfstroke
.5 g
.50815 .98077 m
.51326 .97106 L
.51457 .96853 L
.51831 .96134 L
.52331 .95163 L
.52428 .94971 L
.52826 .94192 L
.53316 .93221 L
.53399 .93052 L
.53802 .92249 L
.54282 .91278 L
.54371 .91095 L
.54759 .90307 L
.5523 .89336 L
.55342 .89102 L
.55699 .88364 L
.56163 .87393 L
.56313 .87074 L
.56623 .86422 L
.5708 .85451 L
.57284 .8501 L
.57532 .84479 L
.57983 .83508 L
.58256 .82911 L
.58428 .82537 L
.58873 .81566 L
.59227 .80778 L
.5931 .80594 L
.59749 .79623 L
.60181 .78652 L
.60198 .78612 L
.60613 .77681 L
.61041 .76709 L
.61169 .76413 L
.61466 .75738 L
.6189 .74767 L
.62141 .74182 L
.62308 .73796 L
.62728 .72824 L
.63112 .71918 L
.6314 .71853 L
.63555 .70882 L
.63964 .69911 L
.64083 .69623 L
.64372 .68939 L
.64779 .67968 L
.65054 .67297 L
.65179 .66997 L
.65583 .66026 L
.6598 .65054 L
.66026 .64941 L
.66378 .64083 L
.66774 .63112 L
.66997 .62554 L
.67164 .62141 L
.67558 .61169 L
.67944 .60198 L
.67968 .60137 L
.68333 .59227 L
.68719 .58256 L
.68939 .5769 L
.691 .57284 L
.69484 .56313 L
.69862 .55342 L
.69911 .55215 L
.70241 .54371 L
.70619 .53399 L
.70882 .52711 L
.70991 .52428 L
.71367 .51457 L
.71738 .50486 L
.71853 .50178 L
.72107 .49514 L
.72478 .48543 L
.72824 .47617 L
.72841 .47572 L
.73209 .46601 L
.73575 .45629 L
.73796 .45028 L
.73934 .44658 L
.74298 .43687 L
.74657 .42716 L
.74767 .42412 L
.75014 .41744 L
.75374 .40773 L
.75726 .39802 L
.75738 .39768 L
.76082 .38831 L
.76438 .37859 L
.76709 .37097 L
.76785 .36888 L
.77139 .35917 L
.77489 .34946 L
.77681 .344 L
.77834 .33974 L
.78184 .33003 L
.78529 .32032 L
.78652 .31676 L
.78871 .31061 L
.79218 .30089 L
.79558 .29118 L
.79623 .28926 L
.79898 .28147 L
.80241 .27176 L
.80576 .26204 L
.80594 .2615 L
.80916 .25233 L
.81255 .24262 L
.81566 .23349 L
.81586 .23291 L
.81923 .22319 L
.82259 .21348 L
.82537 .20522 L
.82587 .20377 L
.82921 .19406 L
.83254 .18434 L
.83508 .1767 L
.83578 .17463 L
.8391 .16492 L
.8424 .15521 L
.84479 .14792 L
.84561 .14549 L
.8489 .13578 L
.85217 .12607 L
.85451 .1189 L
.85536 .11636 L
.85862 .10664 L
.86186 .09693 L
.86422 .08964 L
.86502 .08722 L
.86826 .07751 L
.87147 .06779 L
.87393 .06013 L
.8746 .05808 L
.87781 .04837 L
.88101 .03866 L
.88364 .03037 L
.88411 .02894 L
.88729 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.50815 .98077 m
.51326 .97106 L
.51457 .96853 L
.51831 .96134 L
.52331 .95163 L
.52428 .94971 L
.52826 .94192 L
.53316 .93221 L
.53399 .93052 L
.53802 .92249 L
.54282 .91278 L
.54371 .91095 L
.54759 .90307 L
.5523 .89336 L
.55342 .89102 L
.55699 .88364 L
.56163 .87393 L
.56313 .87074 L
.56623 .86422 L
.5708 .85451 L
.57284 .8501 L
.57532 .84479 L
.57983 .83508 L
.58256 .82911 L
.58428 .82537 L
.58873 .81566 L
.59227 .80778 L
.5931 .80594 L
.59749 .79623 L
.60181 .78652 L
.60198 .78612 L
.60613 .77681 L
.61041 .76709 L
.61169 .76413 L
.61466 .75738 L
.6189 .74767 L
.62141 .74182 L
.62308 .73796 L
.62728 .72824 L
.63112 .71918 L
.6314 .71853 L
.63555 .70882 L
.63964 .69911 L
.64083 .69623 L
.64372 .68939 L
.64779 .67968 L
.65054 .67297 L
.65179 .66997 L
.65583 .66026 L
.6598 .65054 L
Mistroke
.66026 .64941 L
.66378 .64083 L
.66774 .63112 L
.66997 .62554 L
.67164 .62141 L
.67558 .61169 L
.67944 .60198 L
.67968 .60137 L
.68333 .59227 L
.68719 .58256 L
.68939 .5769 L
.691 .57284 L
.69484 .56313 L
.69862 .55342 L
.69911 .55215 L
.70241 .54371 L
.70619 .53399 L
.70882 .52711 L
.70991 .52428 L
.71367 .51457 L
.71738 .50486 L
.71853 .50178 L
.72107 .49514 L
.72478 .48543 L
.72824 .47617 L
.72841 .47572 L
.73209 .46601 L
.73575 .45629 L
.73796 .45028 L
.73934 .44658 L
.74298 .43687 L
.74657 .42716 L
.74767 .42412 L
.75014 .41744 L
.75374 .40773 L
.75726 .39802 L
.75738 .39768 L
.76082 .38831 L
.76438 .37859 L
.76709 .37097 L
.76785 .36888 L
.77139 .35917 L
.77489 .34946 L
.77681 .344 L
.77834 .33974 L
.78184 .33003 L
.78529 .32032 L
.78652 .31676 L
.78871 .31061 L
.79218 .30089 L
Mistroke
.79558 .29118 L
.79623 .28926 L
.79898 .28147 L
.80241 .27176 L
.80576 .26204 L
.80594 .2615 L
.80916 .25233 L
.81255 .24262 L
.81566 .23349 L
.81586 .23291 L
.81923 .22319 L
.82259 .21348 L
.82537 .20522 L
.82587 .20377 L
.82921 .19406 L
.83254 .18434 L
.83508 .1767 L
.83578 .17463 L
.8391 .16492 L
.8424 .15521 L
.84479 .14792 L
.84561 .14549 L
.8489 .13578 L
.85217 .12607 L
.85451 .1189 L
.85536 .11636 L
.85862 .10664 L
.86186 .09693 L
.86422 .08964 L
.86502 .08722 L
.86826 .07751 L
.87147 .06779 L
.87393 .06013 L
.8746 .05808 L
.87781 .04837 L
.88101 .03866 L
.88364 .03037 L
.88411 .02894 L
.88729 .01923 L
Mfstroke
.4 g
.52125 .98077 m
.52428 .97479 L
.52615 .97106 L
.53101 .96134 L
.53399 .95535 L
.53582 .95163 L
.5406 .94192 L
.54371 .93555 L
.54532 .93221 L
.55002 .92249 L
.55342 .9154 L
.55466 .91278 L
.55928 .90307 L
.56313 .8949 L
.56385 .89336 L
.56839 .88364 L
.57284 .87406 L
.5729 .87393 L
.57737 .86422 L
.58182 .85451 L
.58256 .85288 L
.58621 .84479 L
.5906 .83508 L
.59227 .83137 L
.59494 .82537 L
.59927 .81566 L
.60198 .80953 L
.60355 .80594 L
.60782 .79623 L
.61169 .78737 L
.61206 .78652 L
.61626 .77681 L
.62046 .76709 L
.62141 .76488 L
.6246 .75738 L
.62875 .74767 L
.63112 .74209 L
.63285 .73796 L
.63694 .72824 L
.64083 .71898 L
.64102 .71853 L
.64505 .70882 L
.64908 .69911 L
.65054 .69557 L
.65307 .68939 L
.65706 .67968 L
.66026 .67186 L
.66102 .66997 L
.66495 .66026 L
.66888 .65054 L
.66997 .64785 L
.67276 .64083 L
.67666 .63112 L
.67968 .62354 L
.68052 .62141 L
.68436 .61169 L
.6882 .60198 L
.68939 .59895 L
.69199 .59227 L
.69579 .58256 L
.69911 .57406 L
.69957 .57284 L
.70332 .56313 L
.70708 .55342 L
.70882 .54889 L
.71078 .54371 L
.7145 .53399 L
.71821 .52428 L
.71853 .52345 L
.72187 .51457 L
.72555 .50486 L
.72824 .49772 L
.72919 .49514 L
.73282 .48543 L
.73647 .47572 L
.73796 .47171 L
.74005 .46601 L
.74365 .45629 L
.74725 .44658 L
.74767 .44544 L
.75078 .43687 L
.75436 .42716 L
.75738 .41889 L
.7579 .41744 L
.76141 .40773 L
.76495 .39802 L
.76709 .39208 L
.76843 .38831 L
.77192 .37859 L
.77542 .36888 L
.77681 .365 L
.77885 .35917 L
.78232 .34946 L
.78578 .33974 L
.78652 .33766 L
.78918 .33003 L
.79262 .32032 L
.79604 .31061 L
.79623 .31007 L
.7994 .30089 L
.80281 .29118 L
.80594 .28221 L
.80619 .28147 L
.80953 .27176 L
.81291 .26204 L
.81566 .2541 L
.81625 .25233 L
.81956 .24262 L
.82291 .23291 L
.82537 .22574 L
.82621 .22319 L
.8295 .21348 L
.83283 .20377 L
.83508 .19712 L
.83609 .19406 L
.83936 .18434 L
.84265 .17463 L
.84479 .16826 L
.84588 .16492 L
.84912 .15521 L
.85239 .14549 L
.85451 .13915 L
.8556 .13578 L
.85881 .12607 L
.86205 .11636 L
.86422 .1098 L
.86523 .10664 L
.86841 .09693 L
.87163 .08722 L
.87393 .08021 L
.87479 .07751 L
.87794 .06779 L
.88114 .05808 L
.88364 .05038 L
.88427 .04837 L
.88739 .03866 L
.89056 .02894 L
.89336 .02031 L
.89369 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.52125 .98077 m
.52428 .97479 L
.52615 .97106 L
.53101 .96134 L
.53399 .95535 L
.53582 .95163 L
.5406 .94192 L
.54371 .93555 L
.54532 .93221 L
.55002 .92249 L
.55342 .9154 L
.55466 .91278 L
.55928 .90307 L
.56313 .8949 L
.56385 .89336 L
.56839 .88364 L
.57284 .87406 L
.5729 .87393 L
.57737 .86422 L
.58182 .85451 L
.58256 .85288 L
.58621 .84479 L
.5906 .83508 L
.59227 .83137 L
.59494 .82537 L
.59927 .81566 L
.60198 .80953 L
.60355 .80594 L
.60782 .79623 L
.61169 .78737 L
.61206 .78652 L
.61626 .77681 L
.62046 .76709 L
.62141 .76488 L
.6246 .75738 L
.62875 .74767 L
.63112 .74209 L
.63285 .73796 L
.63694 .72824 L
.64083 .71898 L
.64102 .71853 L
.64505 .70882 L
.64908 .69911 L
.65054 .69557 L
.65307 .68939 L
.65706 .67968 L
.66026 .67186 L
.66102 .66997 L
.66495 .66026 L
.66888 .65054 L
Mistroke
.66997 .64785 L
.67276 .64083 L
.67666 .63112 L
.67968 .62354 L
.68052 .62141 L
.68436 .61169 L
.6882 .60198 L
.68939 .59895 L
.69199 .59227 L
.69579 .58256 L
.69911 .57406 L
.69957 .57284 L
.70332 .56313 L
.70708 .55342 L
.70882 .54889 L
.71078 .54371 L
.7145 .53399 L
.71821 .52428 L
.71853 .52345 L
.72187 .51457 L
.72555 .50486 L
.72824 .49772 L
.72919 .49514 L
.73282 .48543 L
.73647 .47572 L
.73796 .47171 L
.74005 .46601 L
.74365 .45629 L
.74725 .44658 L
.74767 .44544 L
.75078 .43687 L
.75436 .42716 L
.75738 .41889 L
.7579 .41744 L
.76141 .40773 L
.76495 .39802 L
.76709 .39208 L
.76843 .38831 L
.77192 .37859 L
.77542 .36888 L
.77681 .365 L
.77885 .35917 L
.78232 .34946 L
.78578 .33974 L
.78652 .33766 L
.78918 .33003 L
.79262 .32032 L
.79604 .31061 L
.79623 .31007 L
.7994 .30089 L
Mistroke
.80281 .29118 L
.80594 .28221 L
.80619 .28147 L
.80953 .27176 L
.81291 .26204 L
.81566 .2541 L
.81625 .25233 L
.81956 .24262 L
.82291 .23291 L
.82537 .22574 L
.82621 .22319 L
.8295 .21348 L
.83283 .20377 L
.83508 .19712 L
.83609 .19406 L
.83936 .18434 L
.84265 .17463 L
.84479 .16826 L
.84588 .16492 L
.84912 .15521 L
.85239 .14549 L
.85451 .13915 L
.8556 .13578 L
.85881 .12607 L
.86205 .11636 L
.86422 .1098 L
.86523 .10664 L
.86841 .09693 L
.87163 .08722 L
.87393 .08021 L
.87479 .07751 L
.87794 .06779 L
.88114 .05808 L
.88364 .05038 L
.88427 .04837 L
.88739 .03866 L
.89056 .02894 L
.89336 .02031 L
.89369 .01923 L
Mfstroke
.3 g
.53475 .98077 m
.53943 .97106 L
.54371 .9623 L
.54414 .96134 L
.54873 .95163 L
.55339 .94192 L
.55342 .94186 L
.55787 .93221 L
.56247 .92249 L
.56313 .92109 L
.56689 .91278 L
.57141 .90307 L
.57284 .89999 L
.57577 .89336 L
.58023 .88364 L
.58256 .87856 L
.58455 .87393 L
.58892 .86422 L
.59227 .85681 L
.59323 .85451 L
.59749 .84479 L
.60183 .83508 L
.60198 .83475 L
.60597 .82537 L
.61025 .81566 L
.61169 .81236 L
.61435 .80594 L
.61856 .79623 L
.62141 .78967 L
.62267 .78652 L
.62677 .77681 L
.63094 .76709 L
.63112 .76668 L
.6349 .75738 L
.63902 .74767 L
.64083 .74338 L
.64296 .73796 L
.647 .72824 L
.65054 .71978 L
.65101 .71853 L
.6549 .70882 L
.65893 .69911 L
.66026 .69589 L
.66275 .68939 L
.66671 .67968 L
.66997 .67171 L
.6706 .66997 L
.67441 .66026 L
.67835 .65054 L
.67968 .64723 L
.68207 .64083 L
.68593 .63112 L
.68939 .62248 L
.68977 .62141 L
.69346 .61169 L
.69731 .60198 L
.69911 .59743 L
.70096 .59227 L
.70472 .58256 L
.70854 .57284 L
.70882 .57212 L
.71209 .56313 L
.71586 .55342 L
.71853 .54651 L
.71949 .54371 L
.72311 .53399 L
.72685 .52428 L
.72824 .52064 L
.73036 .51457 L
.73401 .50486 L
.73772 .49514 L
.73796 .49451 L
.74114 .48543 L
.7448 .47572 L
.74767 .46809 L
.74835 .46601 L
.75182 .45629 L
.75546 .44658 L
.75738 .44141 L
.75888 .43687 L
.76239 .42716 L
.766 .41744 L
.76709 .41447 L
.76933 .40773 L
.77286 .39802 L
.77643 .38831 L
.77681 .38727 L
.7797 .37859 L
.78322 .36888 L
.78652 .35981 L
.78671 .35917 L
.78997 .34946 L
.79348 .33974 L
.79623 .33209 L
.79685 .33003 L
.80015 .32032 L
.80363 .31061 L
.80594 .30412 L
.80692 .30089 L
.81023 .29118 L
.81369 .28147 L
.81566 .2759 L
.81691 .27176 L
.82022 .26204 L
.82365 .25233 L
.82537 .24743 L
.82682 .24262 L
.83012 .23291 L
.83353 .22319 L
.83508 .21871 L
.83665 .21348 L
.83993 .20377 L
.84331 .19406 L
.84479 .18974 L
.84639 .18434 L
.84965 .17463 L
.85301 .16492 L
.85451 .16053 L
.85606 .15521 L
.8593 .14549 L
.86263 .13578 L
.86422 .13108 L
.86566 .12607 L
.86886 .11636 L
.87216 .10664 L
.87393 .10139 L
.87519 .09693 L
.87834 .08722 L
.88162 .07751 L
.88364 .07146 L
.88465 .06779 L
.88774 .05808 L
.89101 .04837 L
.89336 .0413 L
.89405 .03866 L
.89708 .02894 L
.90031 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.53475 .98077 m
.53943 .97106 L
.54371 .9623 L
.54414 .96134 L
.54873 .95163 L
.55339 .94192 L
.55342 .94186 L
.55787 .93221 L
.56247 .92249 L
.56313 .92109 L
.56689 .91278 L
.57141 .90307 L
.57284 .89999 L
.57577 .89336 L
.58023 .88364 L
.58256 .87856 L
.58455 .87393 L
.58892 .86422 L
.59227 .85681 L
.59323 .85451 L
.59749 .84479 L
.60183 .83508 L
.60198 .83475 L
.60597 .82537 L
.61025 .81566 L
.61169 .81236 L
.61435 .80594 L
.61856 .79623 L
.62141 .78967 L
.62267 .78652 L
.62677 .77681 L
.63094 .76709 L
.63112 .76668 L
.6349 .75738 L
.63902 .74767 L
.64083 .74338 L
.64296 .73796 L
.647 .72824 L
.65054 .71978 L
.65101 .71853 L
.6549 .70882 L
.65893 .69911 L
.66026 .69589 L
.66275 .68939 L
.66671 .67968 L
.66997 .67171 L
.6706 .66997 L
.67441 .66026 L
.67835 .65054 L
.67968 .64723 L
Mistroke
.68207 .64083 L
.68593 .63112 L
.68939 .62248 L
.68977 .62141 L
.69346 .61169 L
.69731 .60198 L
.69911 .59743 L
.70096 .59227 L
.70472 .58256 L
.70854 .57284 L
.70882 .57212 L
.71209 .56313 L
.71586 .55342 L
.71853 .54651 L
.71949 .54371 L
.72311 .53399 L
.72685 .52428 L
.72824 .52064 L
.73036 .51457 L
.73401 .50486 L
.73772 .49514 L
.73796 .49451 L
.74114 .48543 L
.7448 .47572 L
.74767 .46809 L
.74835 .46601 L
.75182 .45629 L
.75546 .44658 L
.75738 .44141 L
.75888 .43687 L
.76239 .42716 L
.766 .41744 L
.76709 .41447 L
.76933 .40773 L
.77286 .39802 L
.77643 .38831 L
.77681 .38727 L
.7797 .37859 L
.78322 .36888 L
.78652 .35981 L
.78671 .35917 L
.78997 .34946 L
.79348 .33974 L
.79623 .33209 L
.79685 .33003 L
.80015 .32032 L
.80363 .31061 L
.80594 .30412 L
.80692 .30089 L
.81023 .29118 L
Mistroke
.81369 .28147 L
.81566 .2759 L
.81691 .27176 L
.82022 .26204 L
.82365 .25233 L
.82537 .24743 L
.82682 .24262 L
.83012 .23291 L
.83353 .22319 L
.83508 .21871 L
.83665 .21348 L
.83993 .20377 L
.84331 .19406 L
.84479 .18974 L
.84639 .18434 L
.84965 .17463 L
.85301 .16492 L
.85451 .16053 L
.85606 .15521 L
.8593 .14549 L
.86263 .13578 L
.86422 .13108 L
.86566 .12607 L
.86886 .11636 L
.87216 .10664 L
.87393 .10139 L
.87519 .09693 L
.87834 .08722 L
.88162 .07751 L
.88364 .07146 L
.88465 .06779 L
.88774 .05808 L
.89101 .04837 L
.89336 .0413 L
.89405 .03866 L
.89708 .02894 L
.90031 .01923 L
Mfstroke
.2 g
.55423 .98077 m
.55855 .97106 L
.56272 .96134 L
.56313 .96061 L
.56711 .95163 L
.57074 .94192 L
.57284 .93834 L
.57561 .93221 L
.57841 .92249 L
.58256 .91594 L
.58403 .91278 L
.58822 .90307 L
.59227 .89356 L
.59237 .89336 L
.59653 .88364 L
.60024 .87393 L
.60198 .87067 L
.60477 .86422 L
.6077 .85451 L
.61169 .84755 L
.61292 .84479 L
.61698 .83508 L
.6209 .82537 L
.62141 .82435 L
.62502 .81566 L
.62836 .80594 L
.63112 .80067 L
.63299 .79623 L
.63529 .78652 L
.64083 .77692 L
.64088 .77681 L
.64482 .76709 L
.64823 .75738 L
.65054 .75273 L
.65262 .74767 L
.65504 .73796 L
.66026 .72843 L
.66034 .72824 L
.66419 .71853 L
.66749 .70882 L
.66997 .70372 L
.67182 .69911 L
.67406 .68939 L
.67932 .67968 L
.67968 .67888 L
.68316 .66997 L
.6862 .66026 L
.68939 .65366 L
.69063 .65054 L
.69237 .64083 L
.69782 .63112 L
.69911 .62826 L
.70174 .62141 L
.70434 .61169 L
.70882 .60259 L
.70906 .60198 L
.71272 .59227 L
.7158 .58256 L
.71853 .5766 L
.71997 .57284 L
.72178 .56313 L
.72694 .55342 L
.72824 .55042 L
.73075 .54371 L
.73317 .53399 L
.73784 .52428 L
.73796 .524 L
.74142 .51457 L
.74421 .50486 L
.74767 .49724 L
.74845 .49514 L
.75197 .48543 L
.75501 .47572 L
.75738 .47027 L
.75894 .46601 L
.76069 .45629 L
.76561 .44658 L
.76709 .44306 L
.76932 .43687 L
.77143 .42716 L
.77606 .41744 L
.77681 .41561 L
.7796 .40773 L
.78196 .39802 L
.78636 .38831 L
.78652 .38791 L
.78978 .37859 L
.79231 .36888 L
.79623 .35993 L
.7965 .35917 L
.79987 .34946 L
.8025 .33974 L
.80594 .3317 L
.80653 .33003 L
.80987 .32032 L
.81257 .31061 L
.81566 .30324 L
.81647 .30089 L
.81978 .29118 L
.82251 .28147 L
.82537 .27455 L
.82633 .27176 L
.82961 .26204 L
.83234 .25233 L
.83508 .24561 L
.8361 .24262 L
.83936 .23291 L
.84206 .22319 L
.84479 .21644 L
.8458 .21348 L
.84902 .20377 L
.85167 .19406 L
.85451 .18703 L
.85541 .18434 L
.85861 .17463 L
.86119 .16492 L
.86422 .15739 L
.86495 .15521 L
.86813 .14549 L
.8706 .13578 L
.87393 .12751 L
.87441 .12607 L
.87757 .11636 L
.87991 .10664 L
.88364 .09742 L
.8838 .09693 L
.88694 .08722 L
.8891 .07751 L
.89309 .06779 L
.89336 .06708 L
.89625 .05808 L
.89818 .04837 L
.90227 .03866 L
.90307 .03649 L
.90548 .02894 L
.90711 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.55423 .98077 m
.55855 .97106 L
.56272 .96134 L
.56313 .96061 L
.56711 .95163 L
.57074 .94192 L
.57284 .93834 L
.57561 .93221 L
.57841 .92249 L
.58256 .91594 L
.58403 .91278 L
.58822 .90307 L
.59227 .89356 L
.59237 .89336 L
.59653 .88364 L
.60024 .87393 L
.60198 .87067 L
.60477 .86422 L
.6077 .85451 L
.61169 .84755 L
.61292 .84479 L
.61698 .83508 L
.6209 .82537 L
.62141 .82435 L
.62502 .81566 L
.62836 .80594 L
.63112 .80067 L
.63299 .79623 L
.63529 .78652 L
.64083 .77692 L
.64088 .77681 L
.64482 .76709 L
.64823 .75738 L
.65054 .75273 L
.65262 .74767 L
.65504 .73796 L
.66026 .72843 L
.66034 .72824 L
.66419 .71853 L
.66749 .70882 L
.66997 .70372 L
.67182 .69911 L
.67406 .68939 L
.67932 .67968 L
.67968 .67888 L
.68316 .66997 L
.6862 .66026 L
.68939 .65366 L
.69063 .65054 L
.69237 .64083 L
Mistroke
.69782 .63112 L
.69911 .62826 L
.70174 .62141 L
.70434 .61169 L
.70882 .60259 L
.70906 .60198 L
.71272 .59227 L
.7158 .58256 L
.71853 .5766 L
.71997 .57284 L
.72178 .56313 L
.72694 .55342 L
.72824 .55042 L
.73075 .54371 L
.73317 .53399 L
.73784 .52428 L
.73796 .524 L
.74142 .51457 L
.74421 .50486 L
.74767 .49724 L
.74845 .49514 L
.75197 .48543 L
.75501 .47572 L
.75738 .47027 L
.75894 .46601 L
.76069 .45629 L
.76561 .44658 L
.76709 .44306 L
.76932 .43687 L
.77143 .42716 L
.77606 .41744 L
.77681 .41561 L
.7796 .40773 L
.78196 .39802 L
.78636 .38831 L
.78652 .38791 L
.78978 .37859 L
.79231 .36888 L
.79623 .35993 L
.7965 .35917 L
.79987 .34946 L
.8025 .33974 L
.80594 .3317 L
.80653 .33003 L
.80987 .32032 L
.81257 .31061 L
.81566 .30324 L
.81647 .30089 L
.81978 .29118 L
.82251 .28147 L
Mistroke
.82537 .27455 L
.82633 .27176 L
.82961 .26204 L
.83234 .25233 L
.83508 .24561 L
.8361 .24262 L
.83936 .23291 L
.84206 .22319 L
.84479 .21644 L
.8458 .21348 L
.84902 .20377 L
.85167 .19406 L
.85451 .18703 L
.85541 .18434 L
.85861 .17463 L
.86119 .16492 L
.86422 .15739 L
.86495 .15521 L
.86813 .14549 L
.8706 .13578 L
.87393 .12751 L
.87441 .12607 L
.87757 .11636 L
.87991 .10664 L
.88364 .09742 L
.8838 .09693 L
.88694 .08722 L
.8891 .07751 L
.89309 .06779 L
.89336 .06708 L
.89625 .05808 L
.89818 .04837 L
.90227 .03866 L
.90307 .03649 L
.90548 .02894 L
.90711 .01923 L
Mfstroke
.3 g
.57591 .98077 m
.58067 .97106 L
.58256 .96743 L
.58536 .96134 L
.59002 .95163 L
.59227 .94712 L
.59463 .94192 L
.59919 .93221 L
.60198 .92639 L
.60457 .92249 L
.60819 .91278 L
.61169 .90524 L
.61301 .90307 L
.61704 .89336 L
.62141 .88371 L
.62145 .88364 L
.62575 .87393 L
.63007 .86422 L
.63112 .86198 L
.63434 .85451 L
.63859 .84479 L
.64083 .83977 L
.64357 .83508 L
.64698 .82537 L
.65054 .81714 L
.65133 .81566 L
.65527 .80594 L
.6594 .79623 L
.66026 .79429 L
.66492 .78652 L
.66752 .77681 L
.66997 .77104 L
.67207 .76709 L
.67556 .75738 L
.67957 .74767 L
.67968 .74741 L
.68533 .73796 L
.68746 .72824 L
.68939 .72358 L
.69202 .71853 L
.69528 .70882 L
.69911 .6993 L
.6992 .69911 L
.70477 .68939 L
.70687 .67968 L
.70882 .67483 L
.71125 .66997 L
.71448 .66026 L
.71829 .65054 L
.71853 .64996 L
.72342 .64083 L
.7258 .63112 L
.72824 .62485 L
.72987 .62141 L
.73324 .61169 L
.73696 .60198 L
.73796 .59943 L
.7415 .59227 L
.74429 .58256 L
.74767 .57366 L
.74803 .57284 L
.75315 .56313 L
.75521 .55342 L
.75738 .54768 L
.75919 .54371 L
.76241 .53399 L
.766 .52428 L
.76709 .52139 L
.7703 .51457 L
.7731 .50486 L
.77666 .49514 L
.77681 .49477 L
.78133 .48543 L
.78368 .47572 L
.78652 .46792 L
.78734 .46601 L
.79229 .45629 L
.79414 .44658 L
.79623 .44081 L
.79794 .43687 L
.80104 .42716 L
.80449 .41744 L
.80594 .41341 L
.80843 .40773 L
.81131 .39802 L
.81473 .38831 L
.81566 .38573 L
.81882 .37859 L
.82148 .36888 L
.82487 .35917 L
.82537 .35778 L
.82908 .34946 L
.83155 .33974 L
.83492 .33003 L
.83508 .32956 L
.83922 .32032 L
.84153 .31061 L
.84479 .3011 L
.84487 .30089 L
.84923 .29118 L
.85141 .28147 L
.85451 .27238 L
.85475 .27176 L
.85911 .26204 L
.86121 .25233 L
.86422 .24341 L
.86453 .24262 L
.86886 .23291 L
.87092 .22319 L
.87393 .21419 L
.87421 .21348 L
.87848 .20377 L
.88055 .19406 L
.88364 .18472 L
.88379 .18434 L
.88798 .17463 L
.89009 .16492 L
.89329 .15521 L
.89336 .155 L
.89737 .14549 L
.89956 .13578 L
.90273 .12607 L
.90307 .12505 L
.90666 .11636 L
.90896 .10664 L
.9121 .09693 L
.91278 .09485 L
.91586 .08722 L
.91828 .07751 L
.92139 .06779 L
.92249 .06441 L
.92498 .05808 L
.92754 .04837 L
.93062 .03866 L
.93221 .03372 L
.93404 .02894 L
.93857 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.57591 .98077 m
.58067 .97106 L
.58256 .96743 L
.58536 .96134 L
.59002 .95163 L
.59227 .94712 L
.59463 .94192 L
.59919 .93221 L
.60198 .92639 L
.60457 .92249 L
.60819 .91278 L
.61169 .90524 L
.61301 .90307 L
.61704 .89336 L
.62141 .88371 L
.62145 .88364 L
.62575 .87393 L
.63007 .86422 L
.63112 .86198 L
.63434 .85451 L
.63859 .84479 L
.64083 .83977 L
.64357 .83508 L
.64698 .82537 L
.65054 .81714 L
.65133 .81566 L
.65527 .80594 L
.6594 .79623 L
.66026 .79429 L
.66492 .78652 L
.66752 .77681 L
.66997 .77104 L
.67207 .76709 L
.67556 .75738 L
.67957 .74767 L
.67968 .74741 L
.68533 .73796 L
.68746 .72824 L
.68939 .72358 L
.69202 .71853 L
.69528 .70882 L
.69911 .6993 L
.6992 .69911 L
.70477 .68939 L
.70687 .67968 L
.70882 .67483 L
.71125 .66997 L
.71448 .66026 L
.71829 .65054 L
.71853 .64996 L
Mistroke
.72342 .64083 L
.7258 .63112 L
.72824 .62485 L
.72987 .62141 L
.73324 .61169 L
.73696 .60198 L
.73796 .59943 L
.7415 .59227 L
.74429 .58256 L
.74767 .57366 L
.74803 .57284 L
.75315 .56313 L
.75521 .55342 L
.75738 .54768 L
.75919 .54371 L
.76241 .53399 L
.766 .52428 L
.76709 .52139 L
.7703 .51457 L
.7731 .50486 L
.77666 .49514 L
.77681 .49477 L
.78133 .48543 L
.78368 .47572 L
.78652 .46792 L
.78734 .46601 L
.79229 .45629 L
.79414 .44658 L
.79623 .44081 L
.79794 .43687 L
.80104 .42716 L
.80449 .41744 L
.80594 .41341 L
.80843 .40773 L
.81131 .39802 L
.81473 .38831 L
.81566 .38573 L
.81882 .37859 L
.82148 .36888 L
.82487 .35917 L
.82537 .35778 L
.82908 .34946 L
.83155 .33974 L
.83492 .33003 L
.83508 .32956 L
.83922 .32032 L
.84153 .31061 L
.84479 .3011 L
.84487 .30089 L
.84923 .29118 L
Mistroke
.85141 .28147 L
.85451 .27238 L
.85475 .27176 L
.85911 .26204 L
.86121 .25233 L
.86422 .24341 L
.86453 .24262 L
.86886 .23291 L
.87092 .22319 L
.87393 .21419 L
.87421 .21348 L
.87848 .20377 L
.88055 .19406 L
.88364 .18472 L
.88379 .18434 L
.88798 .17463 L
.89009 .16492 L
.89329 .15521 L
.89336 .155 L
.89737 .14549 L
.89956 .13578 L
.90273 .12607 L
.90307 .12505 L
.90666 .11636 L
.90896 .10664 L
.9121 .09693 L
.91278 .09485 L
.91586 .08722 L
.91828 .07751 L
.92139 .06779 L
.92249 .06441 L
.92498 .05808 L
.92754 .04837 L
.93062 .03866 L
.93221 .03372 L
.93404 .02894 L
.93857 .01923 L
Mfstroke
.4 g
.59365 .98077 m
.59816 .97106 L
.60198 .96229 L
.60241 .96134 L
.60688 .95163 L
.61113 .94192 L
.61169 .94052 L
.61546 .93221 L
.61975 .92249 L
.62141 .91841 L
.62392 .91278 L
.62821 .90307 L
.63112 .89598 L
.63227 .89336 L
.63654 .88364 L
.64056 .87393 L
.64083 .87322 L
.64475 .86422 L
.64885 .85451 L
.65054 .85015 L
.65284 .84479 L
.65698 .83508 L
.66026 .82676 L
.66084 .82537 L
.66496 .81566 L
.6689 .80594 L
.66997 .80306 L
.67283 .79623 L
.67685 .78652 L
.67968 .77906 L
.68061 .77681 L
.68463 .76709 L
.68846 .75738 L
.68939 .75476 L
.69229 .74767 L
.69622 .73796 L
.69911 .73016 L
.69988 .72824 L
.70381 .71853 L
.70758 .70882 L
.70882 .70527 L
.71128 .69911 L
.71514 .68939 L
.71853 .68009 L
.71869 .67968 L
.72253 .66997 L
.72628 .66026 L
.72824 .65463 L
.72984 .65054 L
.73364 .64083 L
.73722 .63112 L
.73796 .62888 L
.74085 .62141 L
.74458 .61169 L
.74767 .60284 L
.748 .60198 L
.75173 .59227 L
.75536 .58256 L
.75738 .57654 L
.75878 .57284 L
.76247 .56313 L
.76599 .55342 L
.76709 .54997 L
.76944 .54371 L
.77309 .53399 L
.77645 .52428 L
.77681 .52311 L
.77999 .51457 L
.78358 .50486 L
.78652 .496 L
.78683 .49514 L
.79042 .48543 L
.79394 .47572 L
.79623 .46862 L
.79718 .46601 L
.80074 .45629 L
.80419 .44658 L
.80594 .44098 L
.80743 .43687 L
.81096 .42716 L
.81433 .41744 L
.81566 .41307 L
.81757 .40773 L
.82107 .39802 L
.82437 .38831 L
.82537 .38491 L
.82762 .37859 L
.83108 .36888 L
.83432 .35917 L
.83508 .3565 L
.83757 .34946 L
.841 .33974 L
.84418 .33003 L
.84479 .32783 L
.84742 .32032 L
.85083 .31061 L
.85397 .30089 L
.85451 .29891 L
.85719 .29118 L
.86057 .28147 L
.86368 .27176 L
.86422 .26974 L
.86687 .26204 L
.87023 .25233 L
.87332 .24262 L
.87393 .24033 L
.87647 .23291 L
.8798 .22319 L
.8829 .21348 L
.88364 .21067 L
.88599 .20377 L
.8893 .19406 L
.89241 .18434 L
.89336 .18078 L
.89542 .17463 L
.89872 .16492 L
.90184 .15521 L
.90307 .15064 L
.90478 .14549 L
.90806 .13578 L
.9112 .12607 L
.91278 .12026 L
.91407 .11636 L
.91732 .10664 L
.92049 .09693 L
.92249 .08965 L
.92329 .08722 L
.92651 .07751 L
.92969 .06779 L
.93221 .0588 L
.93244 .05808 L
.93563 .04837 L
.93882 .03866 L
.94164 .02894 L
.94192 .02772 L
.94468 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.59365 .98077 m
.59816 .97106 L
.60198 .96229 L
.60241 .96134 L
.60688 .95163 L
.61113 .94192 L
.61169 .94052 L
.61546 .93221 L
.61975 .92249 L
.62141 .91841 L
.62392 .91278 L
.62821 .90307 L
.63112 .89598 L
.63227 .89336 L
.63654 .88364 L
.64056 .87393 L
.64083 .87322 L
.64475 .86422 L
.64885 .85451 L
.65054 .85015 L
.65284 .84479 L
.65698 .83508 L
.66026 .82676 L
.66084 .82537 L
.66496 .81566 L
.6689 .80594 L
.66997 .80306 L
.67283 .79623 L
.67685 .78652 L
.67968 .77906 L
.68061 .77681 L
.68463 .76709 L
.68846 .75738 L
.68939 .75476 L
.69229 .74767 L
.69622 .73796 L
.69911 .73016 L
.69988 .72824 L
.70381 .71853 L
.70758 .70882 L
.70882 .70527 L
.71128 .69911 L
.71514 .68939 L
.71853 .68009 L
.71869 .67968 L
.72253 .66997 L
.72628 .66026 L
.72824 .65463 L
.72984 .65054 L
.73364 .64083 L
Mistroke
.73722 .63112 L
.73796 .62888 L
.74085 .62141 L
.74458 .61169 L
.74767 .60284 L
.748 .60198 L
.75173 .59227 L
.75536 .58256 L
.75738 .57654 L
.75878 .57284 L
.76247 .56313 L
.76599 .55342 L
.76709 .54997 L
.76944 .54371 L
.77309 .53399 L
.77645 .52428 L
.77681 .52311 L
.77999 .51457 L
.78358 .50486 L
.78652 .496 L
.78683 .49514 L
.79042 .48543 L
.79394 .47572 L
.79623 .46862 L
.79718 .46601 L
.80074 .45629 L
.80419 .44658 L
.80594 .44098 L
.80743 .43687 L
.81096 .42716 L
.81433 .41744 L
.81566 .41307 L
.81757 .40773 L
.82107 .39802 L
.82437 .38831 L
.82537 .38491 L
.82762 .37859 L
.83108 .36888 L
.83432 .35917 L
.83508 .3565 L
.83757 .34946 L
.841 .33974 L
.84418 .33003 L
.84479 .32783 L
.84742 .32032 L
.85083 .31061 L
.85397 .30089 L
.85451 .29891 L
.85719 .29118 L
.86057 .28147 L
Mistroke
.86368 .27176 L
.86422 .26974 L
.86687 .26204 L
.87023 .25233 L
.87332 .24262 L
.87393 .24033 L
.87647 .23291 L
.8798 .22319 L
.8829 .21348 L
.88364 .21067 L
.88599 .20377 L
.8893 .19406 L
.89241 .18434 L
.89336 .18078 L
.89542 .17463 L
.89872 .16492 L
.90184 .15521 L
.90307 .15064 L
.90478 .14549 L
.90806 .13578 L
.9112 .12607 L
.91278 .12026 L
.91407 .11636 L
.91732 .10664 L
.92049 .09693 L
.92249 .08965 L
.92329 .08722 L
.92651 .07751 L
.92969 .06779 L
.93221 .0588 L
.93244 .05808 L
.93563 .04837 L
.93882 .03866 L
.94164 .02894 L
.94192 .02772 L
.94468 .01923 L
Mfstroke
.5 g
.60499 .98077 m
.60929 .97106 L
.61169 .96552 L
.61353 .96134 L
.61778 .95163 L
.62141 .9432 L
.62196 .94192 L
.62617 .93221 L
.63031 .92249 L
.63112 .92057 L
.63445 .91278 L
.63856 .90307 L
.64083 .89762 L
.64263 .89336 L
.64671 .88364 L
.65054 .87436 L
.65072 .87393 L
.65476 .86422 L
.65876 .85451 L
.66026 .85079 L
.66272 .84479 L
.66669 .83508 L
.66997 .82692 L
.6706 .82537 L
.67454 .81566 L
.67843 .80594 L
.67968 .80275 L
.6823 .79623 L
.68617 .78652 L
.68939 .77829 L
.68998 .77681 L
.69383 .76709 L
.69763 .75738 L
.69911 .75353 L
.7014 .74767 L
.7052 .73796 L
.70882 .72849 L
.70891 .72824 L
.71267 .71853 L
.71641 .70882 L
.71853 .70316 L
.72008 .69911 L
.7238 .68939 L
.72746 .67968 L
.72824 .67755 L
.73112 .66997 L
.73478 .66026 L
.73796 .65166 L
.73837 .65054 L
.74202 .64083 L
.74563 .63112 L
.74767 .6255 L
.74919 .62141 L
.75279 .61169 L
.75634 .60198 L
.75738 .59906 L
.75988 .59227 L
.76344 .58256 L
.76692 .57284 L
.76709 .57236 L
.77045 .56313 L
.77397 .55342 L
.77681 .54538 L
.77741 .54371 L
.78091 .53399 L
.78438 .52428 L
.78652 .51815 L
.78779 .51457 L
.79126 .50486 L
.79469 .49514 L
.79623 .49065 L
.79807 .48543 L
.80151 .47572 L
.80489 .46601 L
.80594 .46289 L
.80825 .45629 L
.81165 .44658 L
.81499 .43687 L
.81566 .43487 L
.81833 .42716 L
.8217 .41744 L
.825 .40773 L
.82537 .4066 L
.82832 .39802 L
.83166 .38831 L
.83491 .37859 L
.83508 .37808 L
.83822 .36888 L
.84153 .35917 L
.84475 .34946 L
.84479 .34931 L
.84803 .33974 L
.85131 .33003 L
.8545 .32032 L
.85451 .32029 L
.85775 .31061 L
.86101 .30089 L
.86417 .29118 L
.86422 .29102 L
.86739 .28147 L
.87063 .27176 L
.87376 .26204 L
.87393 .26151 L
.87696 .25233 L
.88017 .24262 L
.88329 .23291 L
.88364 .23176 L
.88644 .22319 L
.88963 .21348 L
.89274 .20377 L
.89336 .20177 L
.89586 .19406 L
.89902 .18434 L
.90212 .17463 L
.90307 .17154 L
.9052 .16492 L
.90834 .15521 L
.91143 .14549 L
.91278 .14107 L
.91447 .13578 L
.91759 .12607 L
.92067 .11636 L
.92249 .11037 L
.92367 .10664 L
.92677 .09693 L
.92984 .08722 L
.93221 .07944 L
.93281 .07751 L
.93588 .06779 L
.93894 .05808 L
.94189 .04837 L
.94192 .04828 L
.94493 .03866 L
.94798 .02894 L
.95095 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.60499 .98077 m
.60929 .97106 L
.61169 .96552 L
.61353 .96134 L
.61778 .95163 L
.62141 .9432 L
.62196 .94192 L
.62617 .93221 L
.63031 .92249 L
.63112 .92057 L
.63445 .91278 L
.63856 .90307 L
.64083 .89762 L
.64263 .89336 L
.64671 .88364 L
.65054 .87436 L
.65072 .87393 L
.65476 .86422 L
.65876 .85451 L
.66026 .85079 L
.66272 .84479 L
.66669 .83508 L
.66997 .82692 L
.6706 .82537 L
.67454 .81566 L
.67843 .80594 L
.67968 .80275 L
.6823 .79623 L
.68617 .78652 L
.68939 .77829 L
.68998 .77681 L
.69383 .76709 L
.69763 .75738 L
.69911 .75353 L
.7014 .74767 L
.7052 .73796 L
.70882 .72849 L
.70891 .72824 L
.71267 .71853 L
.71641 .70882 L
.71853 .70316 L
.72008 .69911 L
.7238 .68939 L
.72746 .67968 L
.72824 .67755 L
.73112 .66997 L
.73478 .66026 L
.73796 .65166 L
.73837 .65054 L
.74202 .64083 L
Mistroke
.74563 .63112 L
.74767 .6255 L
.74919 .62141 L
.75279 .61169 L
.75634 .60198 L
.75738 .59906 L
.75988 .59227 L
.76344 .58256 L
.76692 .57284 L
.76709 .57236 L
.77045 .56313 L
.77397 .55342 L
.77681 .54538 L
.77741 .54371 L
.78091 .53399 L
.78438 .52428 L
.78652 .51815 L
.78779 .51457 L
.79126 .50486 L
.79469 .49514 L
.79623 .49065 L
.79807 .48543 L
.80151 .47572 L
.80489 .46601 L
.80594 .46289 L
.80825 .45629 L
.81165 .44658 L
.81499 .43687 L
.81566 .43487 L
.81833 .42716 L
.8217 .41744 L
.825 .40773 L
.82537 .4066 L
.82832 .39802 L
.83166 .38831 L
.83491 .37859 L
.83508 .37808 L
.83822 .36888 L
.84153 .35917 L
.84475 .34946 L
.84479 .34931 L
.84803 .33974 L
.85131 .33003 L
.8545 .32032 L
.85451 .32029 L
.85775 .31061 L
.86101 .30089 L
.86417 .29118 L
.86422 .29102 L
.86739 .28147 L
Mistroke
.87063 .27176 L
.87376 .26204 L
.87393 .26151 L
.87696 .25233 L
.88017 .24262 L
.88329 .23291 L
.88364 .23176 L
.88644 .22319 L
.88963 .21348 L
.89274 .20377 L
.89336 .20177 L
.89586 .19406 L
.89902 .18434 L
.90212 .17463 L
.90307 .17154 L
.9052 .16492 L
.90834 .15521 L
.91143 .14549 L
.91278 .14107 L
.91447 .13578 L
.91759 .12607 L
.92067 .11636 L
.92249 .11037 L
.92367 .10664 L
.92677 .09693 L
.92984 .08722 L
.93221 .07944 L
.93281 .07751 L
.93588 .06779 L
.93894 .05808 L
.94189 .04837 L
.94192 .04828 L
.94493 .03866 L
.94798 .02894 L
.95095 .01923 L
Mfstroke
.6 g
.61514 .98077 m
.61935 .97106 L
.62141 .96627 L
.6235 .96134 L
.62765 .95163 L
.63112 .94347 L
.63177 .94192 L
.63586 .93221 L
.63994 .92249 L
.64083 .92037 L
.64397 .91278 L
.64802 .90307 L
.65054 .89696 L
.65201 .89336 L
.656 .88364 L
.65998 .87393 L
.66026 .87324 L
.6639 .86422 L
.66784 .85451 L
.66997 .84923 L
.67173 .84479 L
.67562 .83508 L
.67951 .82537 L
.67968 .82493 L
.68333 .81566 L
.68718 .80594 L
.68939 .80033 L
.69098 .79623 L
.69478 .78652 L
.69858 .77681 L
.69911 .77545 L
.70232 .76709 L
.70608 .75738 L
.70882 .75028 L
.7098 .74767 L
.71351 .73796 L
.71723 .72824 L
.71853 .72483 L
.72089 .71853 L
.72457 .70882 L
.72824 .69911 L
.72824 .6991 L
.73185 .68939 L
.7355 .67968 L
.73796 .6731 L
.7391 .66997 L
.74269 .66026 L
.7463 .65054 L
.74767 .64682 L
.74984 .64083 L
.75341 .63112 L
.75697 .62141 L
.75738 .62028 L
.76047 .61169 L
.76401 .60198 L
.76709 .59346 L
.76751 .59227 L
.77099 .58256 L
.77449 .57284 L
.77681 .56639 L
.77794 .56313 L
.7814 .55342 L
.78487 .54371 L
.78652 .53905 L
.78827 .53399 L
.7917 .52428 L
.79514 .51457 L
.79623 .51145 L
.7985 .50486 L
.80191 .49514 L
.80531 .48543 L
.80594 .48359 L
.80864 .47572 L
.81201 .46601 L
.81538 .45629 L
.81566 .45548 L
.81867 .44658 L
.82203 .43687 L
.82536 .42716 L
.82537 .42712 L
.82862 .41744 L
.83195 .40773 L
.83508 .39851 L
.83524 .39802 L
.83848 .38831 L
.84178 .37859 L
.84479 .36965 L
.84504 .36888 L
.84826 .35917 L
.85153 .34946 L
.85451 .34054 L
.85476 .33974 L
.85795 .33003 L
.86119 .32032 L
.86422 .31119 L
.8644 .31061 L
.86756 .30089 L
.87078 .29118 L
.87393 .2816 L
.87397 .28147 L
.8771 .27176 L
.88029 .26204 L
.88346 .25233 L
.88364 .25176 L
.88656 .24262 L
.88972 .23291 L
.89287 .22319 L
.89336 .22169 L
.89594 .21348 L
.89908 .20377 L
.90222 .19406 L
.90307 .19138 L
.90526 .18434 L
.90837 .17463 L
.91149 .16492 L
.91278 .16084 L
.91452 .15521 L
.9176 .14549 L
.92069 .13578 L
.92249 .13007 L
.92371 .12607 L
.92675 .11636 L
.92983 .10664 L
.93221 .09906 L
.93284 .09693 L
.93584 .08722 L
.9389 .07751 L
.94192 .06783 L
.94193 .06779 L
.94488 .05808 L
.94791 .04837 L
.95093 .03866 L
.95163 .03637 L
.95385 .02894 L
.95686 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.61514 .98077 m
.61935 .97106 L
.62141 .96627 L
.6235 .96134 L
.62765 .95163 L
.63112 .94347 L
.63177 .94192 L
.63586 .93221 L
.63994 .92249 L
.64083 .92037 L
.64397 .91278 L
.64802 .90307 L
.65054 .89696 L
.65201 .89336 L
.656 .88364 L
.65998 .87393 L
.66026 .87324 L
.6639 .86422 L
.66784 .85451 L
.66997 .84923 L
.67173 .84479 L
.67562 .83508 L
.67951 .82537 L
.67968 .82493 L
.68333 .81566 L
.68718 .80594 L
.68939 .80033 L
.69098 .79623 L
.69478 .78652 L
.69858 .77681 L
.69911 .77545 L
.70232 .76709 L
.70608 .75738 L
.70882 .75028 L
.7098 .74767 L
.71351 .73796 L
.71723 .72824 L
.71853 .72483 L
.72089 .71853 L
.72457 .70882 L
.72824 .69911 L
.72824 .6991 L
.73185 .68939 L
.7355 .67968 L
.73796 .6731 L
.7391 .66997 L
.74269 .66026 L
.7463 .65054 L
.74767 .64682 L
.74984 .64083 L
Mistroke
.75341 .63112 L
.75697 .62141 L
.75738 .62028 L
.76047 .61169 L
.76401 .60198 L
.76709 .59346 L
.76751 .59227 L
.77099 .58256 L
.77449 .57284 L
.77681 .56639 L
.77794 .56313 L
.7814 .55342 L
.78487 .54371 L
.78652 .53905 L
.78827 .53399 L
.7917 .52428 L
.79514 .51457 L
.79623 .51145 L
.7985 .50486 L
.80191 .49514 L
.80531 .48543 L
.80594 .48359 L
.80864 .47572 L
.81201 .46601 L
.81538 .45629 L
.81566 .45548 L
.81867 .44658 L
.82203 .43687 L
.82536 .42716 L
.82537 .42712 L
.82862 .41744 L
.83195 .40773 L
.83508 .39851 L
.83524 .39802 L
.83848 .38831 L
.84178 .37859 L
.84479 .36965 L
.84504 .36888 L
.84826 .35917 L
.85153 .34946 L
.85451 .34054 L
.85476 .33974 L
.85795 .33003 L
.86119 .32032 L
.86422 .31119 L
.8644 .31061 L
.86756 .30089 L
.87078 .29118 L
.87393 .2816 L
.87397 .28147 L
Mistroke
.8771 .27176 L
.88029 .26204 L
.88346 .25233 L
.88364 .25176 L
.88656 .24262 L
.88972 .23291 L
.89287 .22319 L
.89336 .22169 L
.89594 .21348 L
.89908 .20377 L
.90222 .19406 L
.90307 .19138 L
.90526 .18434 L
.90837 .17463 L
.91149 .16492 L
.91278 .16084 L
.91452 .15521 L
.9176 .14549 L
.92069 .13578 L
.92249 .13007 L
.92371 .12607 L
.92675 .11636 L
.92983 .10664 L
.93221 .09906 L
.93284 .09693 L
.93584 .08722 L
.9389 .07751 L
.94192 .06783 L
.94193 .06779 L
.94488 .05808 L
.94791 .04837 L
.95093 .03866 L
.95163 .03637 L
.95385 .02894 L
.95686 .01923 L
Mfstroke
.7 g
.62566 .98077 m
.62984 .97106 L
.63112 .96806 L
.63382 .96134 L
.63792 .95163 L
.64083 .94476 L
.64193 .94192 L
.64592 .93221 L
.64999 .92249 L
.65054 .92117 L
.65384 .91278 L
.65786 .90307 L
.66026 .89727 L
.66174 .89336 L
.66565 .88364 L
.66963 .87393 L
.66997 .87309 L
.67337 .86422 L
.6773 .85451 L
.67968 .84862 L
.68108 .84479 L
.6849 .83508 L
.68879 .82537 L
.68939 .82386 L
.69245 .81566 L
.69629 .80594 L
.69911 .79882 L
.70002 .79623 L
.70371 .78652 L
.70753 .77681 L
.70882 .7735 L
.71111 .76709 L
.71485 .75738 L
.71853 .7479 L
.71861 .74767 L
.72212 .73796 L
.72586 .72824 L
.72824 .72203 L
.72943 .71853 L
.73303 .70882 L
.73674 .69911 L
.73796 .69589 L
.74019 .68939 L
.74382 .67968 L
.74749 .66997 L
.74767 .66948 L
.75087 .66026 L
.75449 .65054 L
.75738 .6428 L
.75801 .64083 L
.76144 .63112 L
.76505 .62141 L
.76709 .61586 L
.76844 .61169 L
.77191 .60198 L
.77549 .59227 L
.77681 .58865 L
.7788 .58256 L
.78228 .57284 L
.78582 .56313 L
.78652 .5612 L
.78906 .55342 L
.79254 .54371 L
.79605 .53399 L
.79623 .53348 L
.79924 .52428 L
.80271 .51457 L
.80594 .50551 L
.80613 .50486 L
.80932 .49514 L
.81277 .48543 L
.81566 .47729 L
.81611 .47572 L
.81932 .46601 L
.82274 .45629 L
.82537 .44881 L
.82602 .44658 L
.82922 .43687 L
.83262 .42716 L
.83508 .42009 L
.83584 .41744 L
.83904 .40773 L
.84241 .39802 L
.84479 .39113 L
.8456 .38831 L
.84877 .37859 L
.85212 .36888 L
.85451 .36192 L
.85528 .35917 L
.85842 .34946 L
.86174 .33974 L
.86422 .33247 L
.86489 .33003 L
.86798 .32032 L
.87129 .31061 L
.87393 .30278 L
.87443 .30089 L
.87747 .29118 L
.88075 .28147 L
.88364 .27285 L
.88393 .27176 L
.88689 .26204 L
.89014 .25233 L
.89336 .24269 L
.89337 .24262 L
.89624 .23291 L
.89945 .22319 L
.90268 .21348 L
.90307 .21229 L
.90552 .20377 L
.90869 .19406 L
.91191 .18434 L
.91278 .18165 L
.91474 .17463 L
.91787 .16492 L
.92106 .15521 L
.92249 .15079 L
.92391 .14549 L
.92697 .13578 L
.93015 .12607 L
.93221 .1197 L
.93305 .11636 L
.93601 .10664 L
.93917 .09693 L
.94192 .08838 L
.94219 .08722 L
.94499 .07751 L
.94812 .06779 L
.95124 .05808 L
.95163 .05684 L
.95393 .04837 L
.95701 .03866 L
.96012 .02894 L
.96134 .02508 L
.96284 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.62566 .98077 m
.62984 .97106 L
.63112 .96806 L
.63382 .96134 L
.63792 .95163 L
.64083 .94476 L
.64193 .94192 L
.64592 .93221 L
.64999 .92249 L
.65054 .92117 L
.65384 .91278 L
.65786 .90307 L
.66026 .89727 L
.66174 .89336 L
.66565 .88364 L
.66963 .87393 L
.66997 .87309 L
.67337 .86422 L
.6773 .85451 L
.67968 .84862 L
.68108 .84479 L
.6849 .83508 L
.68879 .82537 L
.68939 .82386 L
.69245 .81566 L
.69629 .80594 L
.69911 .79882 L
.70002 .79623 L
.70371 .78652 L
.70753 .77681 L
.70882 .7735 L
.71111 .76709 L
.71485 .75738 L
.71853 .7479 L
.71861 .74767 L
.72212 .73796 L
.72586 .72824 L
.72824 .72203 L
.72943 .71853 L
.73303 .70882 L
.73674 .69911 L
.73796 .69589 L
.74019 .68939 L
.74382 .67968 L
.74749 .66997 L
.74767 .66948 L
.75087 .66026 L
.75449 .65054 L
.75738 .6428 L
.75801 .64083 L
Mistroke
.76144 .63112 L
.76505 .62141 L
.76709 .61586 L
.76844 .61169 L
.77191 .60198 L
.77549 .59227 L
.77681 .58865 L
.7788 .58256 L
.78228 .57284 L
.78582 .56313 L
.78652 .5612 L
.78906 .55342 L
.79254 .54371 L
.79605 .53399 L
.79623 .53348 L
.79924 .52428 L
.80271 .51457 L
.80594 .50551 L
.80613 .50486 L
.80932 .49514 L
.81277 .48543 L
.81566 .47729 L
.81611 .47572 L
.81932 .46601 L
.82274 .45629 L
.82537 .44881 L
.82602 .44658 L
.82922 .43687 L
.83262 .42716 L
.83508 .42009 L
.83584 .41744 L
.83904 .40773 L
.84241 .39802 L
.84479 .39113 L
.8456 .38831 L
.84877 .37859 L
.85212 .36888 L
.85451 .36192 L
.85528 .35917 L
.85842 .34946 L
.86174 .33974 L
.86422 .33247 L
.86489 .33003 L
.86798 .32032 L
.87129 .31061 L
.87393 .30278 L
.87443 .30089 L
.87747 .29118 L
.88075 .28147 L
.88364 .27285 L
Mistroke
.88393 .27176 L
.88689 .26204 L
.89014 .25233 L
.89336 .24269 L
.89337 .24262 L
.89624 .23291 L
.89945 .22319 L
.90268 .21348 L
.90307 .21229 L
.90552 .20377 L
.90869 .19406 L
.91191 .18434 L
.91278 .18165 L
.91474 .17463 L
.91787 .16492 L
.92106 .15521 L
.92249 .15079 L
.92391 .14549 L
.92697 .13578 L
.93015 .12607 L
.93221 .1197 L
.93305 .11636 L
.93601 .10664 L
.93917 .09693 L
.94192 .08838 L
.94219 .08722 L
.94499 .07751 L
.94812 .06779 L
.95124 .05808 L
.95163 .05684 L
.95393 .04837 L
.95701 .03866 L
.96012 .02894 L
.96134 .02508 L
.96284 .01923 L
Mfstroke
.8 g
.63961 .98077 m
.64083 .97837 L
.64378 .97106 L
.64674 .96134 L
.65054 .95411 L
.65158 .95163 L
.65547 .94192 L
.65911 .93221 L
.66026 .92978 L
.66317 .92249 L
.66605 .91278 L
.66997 .90511 L
.6708 .90307 L
.67461 .89336 L
.67809 .88364 L
.67968 .88022 L
.68216 .87393 L
.68474 .86422 L
.68939 .85509 L
.68963 .85451 L
.69337 .84479 L
.69655 .83508 L
.69911 .82962 L
.70076 .82537 L
.70278 .81566 L
.70795 .80594 L
.70882 .80397 L
.71175 .79623 L
.71446 .78652 L
.71853 .77801 L
.719 .77681 L
.72262 .76709 L
.72572 .75738 L
.72824 .75179 L
.7298 .74767 L
.73166 .73796 L
.73671 .72824 L
.73796 .72535 L
.74047 .71853 L
.74286 .70882 L
.74749 .69911 L
.74767 .69867 L
.75104 .68939 L
.75376 .67968 L
.75738 .67166 L
.75801 .66997 L
.7615 .66026 L
.76444 .65054 L
.76709 .64443 L
.7684 .64083 L
.76993 .63112 L
.77494 .62141 L
.77681 .61697 L
.77869 .61169 L
.78057 .60198 L
.78529 .59227 L
.78652 .58926 L
.78888 .58256 L
.79099 .57284 L
.7955 .56313 L
.79623 .56131 L
.79898 .55342 L
.80124 .54371 L
.80559 .53399 L
.80594 .53311 L
.80899 .52428 L
.81134 .51457 L
.81558 .50486 L
.81566 .50466 L
.81891 .49514 L
.82131 .48543 L
.82537 .47596 L
.82545 .47572 L
.82874 .46601 L
.83116 .45629 L
.83508 .44702 L
.83523 .44658 L
.8385 .43687 L
.84089 .42716 L
.84479 .41785 L
.84493 .41744 L
.84817 .40773 L
.85051 .39802 L
.85451 .38844 L
.85455 .38831 L
.85777 .37859 L
.86002 .36888 L
.86408 .35917 L
.86422 .3588 L
.86729 .34946 L
.86942 .33974 L
.87351 .33003 L
.87393 .32891 L
.87674 .32032 L
.8787 .31061 L
.88286 .30089 L
.88364 .29879 L
.88611 .29118 L
.88786 .28147 L
.89211 .27176 L
.89336 .26844 L
.89542 .26204 L
.89688 .25233 L
.90127 .24262 L
.90307 .23786 L
.90466 .23291 L
.90575 .22319 L
.91033 .21348 L
.91278 .20706 L
.91384 .20377 L
.9169 .19406 L
.91928 .18434 L
.92249 .17605 L
.92295 .17463 L
.92599 .16492 L
.9281 .15521 L
.93196 .14549 L
.93221 .14481 L
.93503 .13578 L
.93676 .12607 L
.94082 .11636 L
.94192 .11332 L
.944 .10664 L
.94524 .09693 L
.94957 .08722 L
.95163 .08162 L
.95291 .07751 L
.95588 .06779 L
.95818 .05808 L
.96134 .04971 L
.96176 .04837 L
.96473 .03866 L
.96664 .02894 L
.97048 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.63961 .98077 m
.64083 .97837 L
.64378 .97106 L
.64674 .96134 L
.65054 .95411 L
.65158 .95163 L
.65547 .94192 L
.65911 .93221 L
.66026 .92978 L
.66317 .92249 L
.66605 .91278 L
.66997 .90511 L
.6708 .90307 L
.67461 .89336 L
.67809 .88364 L
.67968 .88022 L
.68216 .87393 L
.68474 .86422 L
.68939 .85509 L
.68963 .85451 L
.69337 .84479 L
.69655 .83508 L
.69911 .82962 L
.70076 .82537 L
.70278 .81566 L
.70795 .80594 L
.70882 .80397 L
.71175 .79623 L
.71446 .78652 L
.71853 .77801 L
.719 .77681 L
.72262 .76709 L
.72572 .75738 L
.72824 .75179 L
.7298 .74767 L
.73166 .73796 L
.73671 .72824 L
.73796 .72535 L
.74047 .71853 L
.74286 .70882 L
.74749 .69911 L
.74767 .69867 L
.75104 .68939 L
.75376 .67968 L
.75738 .67166 L
.75801 .66997 L
.7615 .66026 L
.76444 .65054 L
.76709 .64443 L
.7684 .64083 L
Mistroke
.76993 .63112 L
.77494 .62141 L
.77681 .61697 L
.77869 .61169 L
.78057 .60198 L
.78529 .59227 L
.78652 .58926 L
.78888 .58256 L
.79099 .57284 L
.7955 .56313 L
.79623 .56131 L
.79898 .55342 L
.80124 .54371 L
.80559 .53399 L
.80594 .53311 L
.80899 .52428 L
.81134 .51457 L
.81558 .50486 L
.81566 .50466 L
.81891 .49514 L
.82131 .48543 L
.82537 .47596 L
.82545 .47572 L
.82874 .46601 L
.83116 .45629 L
.83508 .44702 L
.83523 .44658 L
.8385 .43687 L
.84089 .42716 L
.84479 .41785 L
.84493 .41744 L
.84817 .40773 L
.85051 .39802 L
.85451 .38844 L
.85455 .38831 L
.85777 .37859 L
.86002 .36888 L
.86408 .35917 L
.86422 .3588 L
.86729 .34946 L
.86942 .33974 L
.87351 .33003 L
.87393 .32891 L
.87674 .32032 L
.8787 .31061 L
.88286 .30089 L
.88364 .29879 L
.88611 .29118 L
.88786 .28147 L
.89211 .27176 L
Mistroke
.89336 .26844 L
.89542 .26204 L
.89688 .25233 L
.90127 .24262 L
.90307 .23786 L
.90466 .23291 L
.90575 .22319 L
.91033 .21348 L
.91278 .20706 L
.91384 .20377 L
.9169 .19406 L
.91928 .18434 L
.92249 .17605 L
.92295 .17463 L
.92599 .16492 L
.9281 .15521 L
.93196 .14549 L
.93221 .14481 L
.93503 .13578 L
.93676 .12607 L
.94082 .11636 L
.94192 .11332 L
.944 .10664 L
.94524 .09693 L
.94957 .08722 L
.95163 .08162 L
.95291 .07751 L
.95588 .06779 L
.95818 .05808 L
.96134 .04971 L
.96176 .04837 L
.96473 .03866 L
.96664 .02894 L
.97048 .01923 L
Mfstroke
.7 g
.98077 .07814 m
.97807 .08722 L
.97511 .09693 L
.97209 .10664 L
.97106 .11001 L
.96908 .11636 L
.96814 .12607 L
.96356 .13578 L
.96134 .14163 L
.96013 .14549 L
.95711 .15521 L
.95481 .16492 L
.95163 .17301 L
.95112 .17463 L
.94807 .18434 L
.94603 .19406 L
.94206 .20377 L
.94192 .20415 L
.93897 .21348 L
.93722 .22319 L
.93302 .23291 L
.93221 .23509 L
.9298 .24262 L
.92835 .25233 L
.92392 .26204 L
.92249 .26578 L
.92057 .27176 L
.91942 .28147 L
.91476 .29118 L
.91278 .29624 L
.91126 .30089 L
.90813 .31061 L
.90552 .32032 L
.90307 .32645 L
.90189 .33003 L
.89873 .33974 L
.89619 .34946 L
.89336 .35641 L
.89244 .35917 L
.88925 .36888 L
.88676 .37859 L
.88364 .38613 L
.88291 .38831 L
.87969 .39802 L
.87723 .40773 L
.87393 .4156 L
.8733 .41744 L
.87006 .42716 L
.8676 .43687 L
.86422 .44482 L
.86361 .44658 L
.86034 .45629 L
.85784 .46601 L
.85451 .47379 L
.85384 .47572 L
.85054 .48543 L
.84796 .49514 L
.84479 .50251 L
.84398 .50486 L
.84065 .51457 L
.83796 .52428 L
.83508 .53098 L
.83402 .53399 L
.83067 .54371 L
.82784 .55342 L
.82537 .55918 L
.82397 .56313 L
.82059 .57284 L
.8176 .58256 L
.81566 .58711 L
.81382 .59227 L
.81225 .60198 L
.80725 .61169 L
.80594 .61478 L
.80357 .62141 L
.80158 .63112 L
.79679 .64083 L
.79623 .64217 L
.79321 .65054 L
.79081 .66026 L
.78652 .6693 L
.78627 .66997 L
.78274 .67968 L
.77995 .68939 L
.77681 .69619 L
.77572 .69911 L
.77216 .70882 L
.76901 .71853 L
.76709 .72277 L
.76505 .72824 L
.7631 .73796 L
.75799 .74767 L
.75738 .74904 L
.75425 .75738 L
.75161 .76709 L
.74767 .77508 L
.747 .77681 L
.74332 .78652 L
.74012 .79623 L
.73796 .80081 L
.73597 .80594 L
.73395 .81566 L
.72862 .82537 L
.72824 .8262 L
.7248 .83508 L
.72187 .84479 L
.71853 .85139 L
.71728 .85451 L
.71348 .86422 L
.7099 .87393 L
.70882 .87619 L
.70584 .88364 L
.70306 .89336 L
.69911 .90074 L
.69814 .90307 L
.69424 .91278 L
.69061 .92249 L
.68939 .92493 L
.68641 .93221 L
.68353 .94192 L
.67968 .94886 L
.6785 .95163 L
.6745 .96134 L
.67064 .97106 L
.66997 .97226 L
.66645 .98077 L
.98077 .98077 L
F
0 g
.98077 .07814 m
.97807 .08722 L
.97511 .09693 L
.97209 .10664 L
.97106 .11001 L
.96908 .11636 L
.96814 .12607 L
.96356 .13578 L
.96134 .14163 L
.96013 .14549 L
.95711 .15521 L
.95481 .16492 L
.95163 .17301 L
.95112 .17463 L
.94807 .18434 L
.94603 .19406 L
.94206 .20377 L
.94192 .20415 L
.93897 .21348 L
.93722 .22319 L
.93302 .23291 L
.93221 .23509 L
.9298 .24262 L
.92835 .25233 L
.92392 .26204 L
.92249 .26578 L
.92057 .27176 L
.91942 .28147 L
.91476 .29118 L
.91278 .29624 L
.91126 .30089 L
.90813 .31061 L
.90552 .32032 L
.90307 .32645 L
.90189 .33003 L
.89873 .33974 L
.89619 .34946 L
.89336 .35641 L
.89244 .35917 L
.88925 .36888 L
.88676 .37859 L
.88364 .38613 L
.88291 .38831 L
.87969 .39802 L
.87723 .40773 L
.87393 .4156 L
.8733 .41744 L
.87006 .42716 L
.8676 .43687 L
.86422 .44482 L
Mistroke
.86361 .44658 L
.86034 .45629 L
.85784 .46601 L
.85451 .47379 L
.85384 .47572 L
.85054 .48543 L
.84796 .49514 L
.84479 .50251 L
.84398 .50486 L
.84065 .51457 L
.83796 .52428 L
.83508 .53098 L
.83402 .53399 L
.83067 .54371 L
.82784 .55342 L
.82537 .55918 L
.82397 .56313 L
.82059 .57284 L
.8176 .58256 L
.81566 .58711 L
.81382 .59227 L
.81225 .60198 L
.80725 .61169 L
.80594 .61478 L
.80357 .62141 L
.80158 .63112 L
.79679 .64083 L
.79623 .64217 L
.79321 .65054 L
.79081 .66026 L
.78652 .6693 L
.78627 .66997 L
.78274 .67968 L
.77995 .68939 L
.77681 .69619 L
.77572 .69911 L
.77216 .70882 L
.76901 .71853 L
.76709 .72277 L
.76505 .72824 L
.7631 .73796 L
.75799 .74767 L
.75738 .74904 L
.75425 .75738 L
.75161 .76709 L
.74767 .77508 L
.747 .77681 L
.74332 .78652 L
.74012 .79623 L
.73796 .80081 L
Mistroke
.73597 .80594 L
.73395 .81566 L
.72862 .82537 L
.72824 .8262 L
.7248 .83508 L
.72187 .84479 L
.71853 .85139 L
.71728 .85451 L
.71348 .86422 L
.7099 .87393 L
.70882 .87619 L
.70584 .88364 L
.70306 .89336 L
.69911 .90074 L
.69814 .90307 L
.69424 .91278 L
.69061 .92249 L
.68939 .92493 L
.68641 .93221 L
.68353 .94192 L
.67968 .94886 L
.6785 .95163 L
.6745 .96134 L
.67064 .97106 L
.66997 .97226 L
.66645 .98077 L
Mfstroke
.6 g
.98077 .10252 m
.97955 .10664 L
.97662 .11636 L
.97134 .12607 L
.97106 .1345 L
.97078 .13578 L
.96803 .14549 L
.9649 .15521 L
.96177 .16492 L
.96134 .16627 L
.9591 .17463 L
.956 .18434 L
.95284 .19406 L
.95163 .19781 L
.95009 .20377 L
.94703 .21348 L
.94384 .22319 L
.94192 .22911 L
.94097 .23291 L
.93798 .24262 L
.93478 .25233 L
.93221 .26019 L
.93176 .26204 L
.92887 .27176 L
.92565 .28147 L
.92249 .29103 L
.92246 .29118 L
.91967 .30089 L
.91646 .31061 L
.91322 .32032 L
.91278 .32165 L
.9104 .33003 L
.90719 .33974 L
.90392 .34946 L
.90307 .35202 L
.90106 .35917 L
.89785 .36888 L
.89455 .37859 L
.89336 .38216 L
.89163 .38831 L
.88843 .39802 L
.88511 .40773 L
.88364 .41206 L
.88213 .41744 L
.87893 .42716 L
.87558 .43687 L
.87393 .44172 L
.87256 .44658 L
.86935 .45629 L
.86598 .46601 L
.86422 .47113 L
.86292 .47572 L
.85968 .48543 L
.85629 .49514 L
.85451 .50029 L
.8532 .50486 L
.84993 .51457 L
.84652 .52428 L
.84479 .52921 L
.8434 .53399 L
.8401 .54371 L
.83665 .55342 L
.83508 .55788 L
.83351 .56313 L
.83017 .57284 L
.8267 .58256 L
.82537 .5863 L
.82354 .59227 L
.82014 .60198 L
.81664 .61169 L
.81566 .61445 L
.81348 .62141 L
.81002 .63112 L
.80649 .64083 L
.80594 .64236 L
.80331 .65054 L
.7998 .66026 L
.79624 .66997 L
.79623 .67 L
.79303 .67968 L
.78947 .68939 L
.78652 .69738 L
.786 .69911 L
.78264 .70882 L
.77903 .71853 L
.77681 .7245 L
.77562 .72824 L
.77213 .73796 L
.76847 .74767 L
.76709 .75135 L
.7651 .75738 L
.7615 .76709 L
.7578 .77681 L
.75738 .77792 L
.75443 .78652 L
.75074 .79623 L
.74767 .80423 L
.74712 .80594 L
.7436 .81566 L
.73985 .82537 L
.73796 .83026 L
.73632 .83508 L
.73263 .84479 L
.72883 .85451 L
.72824 .85601 L
.72532 .86422 L
.72151 .87393 L
.71853 .88148 L
.7178 .88364 L
.71413 .89336 L
.71025 .90307 L
.70882 .90666 L
.70661 .91278 L
.70277 .92249 L
.69911 .93154 L
.69888 .93221 L
.69519 .94192 L
.69124 .95163 L
.68939 .95615 L
.68748 .96134 L
.68357 .97106 L
.67968 .98044 L
.67957 .98077 L
.98077 .98077 L
F
0 g
.98077 .10252 m
.97955 .10664 L
.97662 .11636 L
.97134 .12607 L
.97106 .1345 L
.97078 .13578 L
.96803 .14549 L
.9649 .15521 L
.96177 .16492 L
.96134 .16627 L
.9591 .17463 L
.956 .18434 L
.95284 .19406 L
.95163 .19781 L
.95009 .20377 L
.94703 .21348 L
.94384 .22319 L
.94192 .22911 L
.94097 .23291 L
.93798 .24262 L
.93478 .25233 L
.93221 .26019 L
.93176 .26204 L
.92887 .27176 L
.92565 .28147 L
.92249 .29103 L
.92246 .29118 L
.91967 .30089 L
.91646 .31061 L
.91322 .32032 L
.91278 .32165 L
.9104 .33003 L
.90719 .33974 L
.90392 .34946 L
.90307 .35202 L
.90106 .35917 L
.89785 .36888 L
.89455 .37859 L
.89336 .38216 L
.89163 .38831 L
.88843 .39802 L
.88511 .40773 L
.88364 .41206 L
.88213 .41744 L
.87893 .42716 L
.87558 .43687 L
.87393 .44172 L
.87256 .44658 L
.86935 .45629 L
.86598 .46601 L
Mistroke
.86422 .47113 L
.86292 .47572 L
.85968 .48543 L
.85629 .49514 L
.85451 .50029 L
.8532 .50486 L
.84993 .51457 L
.84652 .52428 L
.84479 .52921 L
.8434 .53399 L
.8401 .54371 L
.83665 .55342 L
.83508 .55788 L
.83351 .56313 L
.83017 .57284 L
.8267 .58256 L
.82537 .5863 L
.82354 .59227 L
.82014 .60198 L
.81664 .61169 L
.81566 .61445 L
.81348 .62141 L
.81002 .63112 L
.80649 .64083 L
.80594 .64236 L
.80331 .65054 L
.7998 .66026 L
.79624 .66997 L
.79623 .67 L
.79303 .67968 L
.78947 .68939 L
.78652 .69738 L
.786 .69911 L
.78264 .70882 L
.77903 .71853 L
.77681 .7245 L
.77562 .72824 L
.77213 .73796 L
.76847 .74767 L
.76709 .75135 L
.7651 .75738 L
.7615 .76709 L
.7578 .77681 L
.75738 .77792 L
.75443 .78652 L
.75074 .79623 L
.74767 .80423 L
.74712 .80594 L
.7436 .81566 L
.73985 .82537 L
Mistroke
.73796 .83026 L
.73632 .83508 L
.73263 .84479 L
.72883 .85451 L
.72824 .85601 L
.72532 .86422 L
.72151 .87393 L
.71853 .88148 L
.7178 .88364 L
.71413 .89336 L
.71025 .90307 L
.70882 .90666 L
.70661 .91278 L
.70277 .92249 L
.69911 .93154 L
.69888 .93221 L
.69519 .94192 L
.69124 .95163 L
.68939 .95615 L
.68748 .96134 L
.68357 .97106 L
.67968 .98044 L
.67957 .98077 L
Mfstroke
.5 g
.98077 .12274 m
.97763 .12607 L
.97543 .13578 L
.97351 .14549 L
.97106 .15481 L
.97094 .15521 L
.96806 .16492 L
.96505 .17463 L
.96205 .18434 L
.96134 .18665 L
.95915 .19406 L
.95614 .20377 L
.95311 .21348 L
.95163 .21827 L
.95017 .22319 L
.94717 .23291 L
.94412 .24262 L
.94192 .24966 L
.94113 .25233 L
.93813 .26204 L
.93506 .27176 L
.93221 .28083 L
.93202 .28147 L
.92903 .29118 L
.92594 .30089 L
.92286 .31061 L
.92249 .31176 L
.91986 .32032 L
.91676 .33003 L
.91364 .33974 L
.91278 .34246 L
.91062 .34946 L
.90751 .35917 L
.90437 .36888 L
.90307 .37292 L
.90131 .37859 L
.89818 .38831 L
.89502 .39802 L
.89336 .40315 L
.89193 .40773 L
.88879 .41744 L
.8856 .42716 L
.88364 .43314 L
.88247 .43687 L
.87932 .44658 L
.8761 .45629 L
.87393 .46289 L
.87295 .46601 L
.86977 .47572 L
.86653 .48543 L
.86422 .4924 L
.86335 .49514 L
.86015 .50486 L
.85688 .51457 L
.85451 .52167 L
.85367 .52428 L
.85044 .53399 L
.84715 .54371 L
.84479 .55069 L
.84391 .55342 L
.84065 .56313 L
.83734 .57284 L
.83508 .57946 L
.83407 .58256 L
.83078 .59227 L
.82743 .60198 L
.82537 .60799 L
.82414 .61169 L
.82081 .62141 L
.81744 .63112 L
.81566 .63626 L
.81412 .64083 L
.81075 .65054 L
.80735 .66026 L
.80594 .66427 L
.804 .66997 L
.8006 .67968 L
.79716 .68939 L
.79623 .69203 L
.79379 .69911 L
.79034 .70882 L
.78687 .71853 L
.78652 .71953 L
.78347 .72824 L
.77998 .73796 L
.77681 .74677 L
.77649 .74767 L
.77304 .75738 L
.76951 .76709 L
.76709 .77374 L
.76601 .77681 L
.7625 .78652 L
.75893 .79623 L
.75738 .80045 L
.75541 .80594 L
.75183 .81566 L
.74823 .82537 L
.74767 .82688 L
.74468 .83508 L
.74105 .84479 L
.73796 .85305 L
.73743 .85451 L
.73382 .86422 L
.73014 .87393 L
.72824 .87894 L
.7265 .88364 L
.72282 .89336 L
.7191 .90307 L
.71853 .90455 L
.71542 .91278 L
.71168 .92249 L
.70882 .92987 L
.70794 .93221 L
.70419 .94192 L
.70039 .95163 L
.69911 .95492 L
.69663 .96134 L
.69281 .97106 L
.68939 .97967 L
.68897 .98077 L
.98077 .98077 L
F
0 g
.98077 .12274 m
.97763 .12607 L
.97543 .13578 L
.97351 .14549 L
.97106 .15481 L
.97094 .15521 L
.96806 .16492 L
.96505 .17463 L
.96205 .18434 L
.96134 .18665 L
.95915 .19406 L
.95614 .20377 L
.95311 .21348 L
.95163 .21827 L
.95017 .22319 L
.94717 .23291 L
.94412 .24262 L
.94192 .24966 L
.94113 .25233 L
.93813 .26204 L
.93506 .27176 L
.93221 .28083 L
.93202 .28147 L
.92903 .29118 L
.92594 .30089 L
.92286 .31061 L
.92249 .31176 L
.91986 .32032 L
.91676 .33003 L
.91364 .33974 L
.91278 .34246 L
.91062 .34946 L
.90751 .35917 L
.90437 .36888 L
.90307 .37292 L
.90131 .37859 L
.89818 .38831 L
.89502 .39802 L
.89336 .40315 L
.89193 .40773 L
.88879 .41744 L
.8856 .42716 L
.88364 .43314 L
.88247 .43687 L
.87932 .44658 L
.8761 .45629 L
.87393 .46289 L
.87295 .46601 L
.86977 .47572 L
.86653 .48543 L
Mistroke
.86422 .4924 L
.86335 .49514 L
.86015 .50486 L
.85688 .51457 L
.85451 .52167 L
.85367 .52428 L
.85044 .53399 L
.84715 .54371 L
.84479 .55069 L
.84391 .55342 L
.84065 .56313 L
.83734 .57284 L
.83508 .57946 L
.83407 .58256 L
.83078 .59227 L
.82743 .60198 L
.82537 .60799 L
.82414 .61169 L
.82081 .62141 L
.81744 .63112 L
.81566 .63626 L
.81412 .64083 L
.81075 .65054 L
.80735 .66026 L
.80594 .66427 L
.804 .66997 L
.8006 .67968 L
.79716 .68939 L
.79623 .69203 L
.79379 .69911 L
.79034 .70882 L
.78687 .71853 L
.78652 .71953 L
.78347 .72824 L
.77998 .73796 L
.77681 .74677 L
.77649 .74767 L
.77304 .75738 L
.76951 .76709 L
.76709 .77374 L
.76601 .77681 L
.7625 .78652 L
.75893 .79623 L
.75738 .80045 L
.75541 .80594 L
.75183 .81566 L
.74823 .82537 L
.74767 .82688 L
.74468 .83508 L
.74105 .84479 L
Mistroke
.73796 .85305 L
.73743 .85451 L
.73382 .86422 L
.73014 .87393 L
.72824 .87894 L
.7265 .88364 L
.72282 .89336 L
.7191 .90307 L
.71853 .90455 L
.71542 .91278 L
.71168 .92249 L
.70882 .92987 L
.70794 .93221 L
.70419 .94192 L
.70039 .95163 L
.69911 .95492 L
.69663 .96134 L
.69281 .97106 L
.68939 .97967 L
.68897 .98077 L
Mfstroke
.4 g
.98077 .14201 m
.97944 .14549 L
.97654 .15521 L
.97378 .16492 L
.97106 .17415 L
.97091 .17463 L
.96795 .18434 L
.96495 .19406 L
.96201 .20377 L
.96134 .20606 L
.95907 .21348 L
.95605 .22319 L
.95307 .23291 L
.95163 .23775 L
.95013 .24262 L
.9471 .25233 L
.94408 .26204 L
.94192 .26921 L
.94113 .27176 L
.93809 .28147 L
.93504 .29118 L
.93221 .30045 L
.93207 .30089 L
.92902 .31061 L
.92594 .32032 L
.92292 .33003 L
.92249 .33145 L
.91988 .33974 L
.91677 .34946 L
.91372 .35917 L
.91278 .36223 L
.91067 .36888 L
.90754 .37859 L
.90445 .38831 L
.90307 .39277 L
.90139 .39802 L
.89825 .40773 L
.89512 .41744 L
.89336 .42307 L
.89204 .42716 L
.88888 .43687 L
.88572 .44658 L
.88364 .45315 L
.88262 .45629 L
.87944 .46601 L
.87625 .47572 L
.87393 .48298 L
.87313 .48543 L
.86992 .49514 L
.86671 .50486 L
.86422 .51257 L
.86356 .51457 L
.86033 .52428 L
.85709 .53399 L
.85451 .54192 L
.85392 .54371 L
.85066 .55342 L
.84739 .56313 L
.84479 .57103 L
.84419 .57284 L
.8409 .58256 L
.83761 .59227 L
.83508 .59989 L
.83438 .60198 L
.83106 .61169 L
.82775 .62141 L
.82537 .6285 L
.82448 .63112 L
.82114 .64083 L
.81779 .65054 L
.81566 .65687 L
.81449 .66026 L
.81112 .66997 L
.80775 .67968 L
.80594 .68498 L
.80441 .68939 L
.801 .69911 L
.79761 .70882 L
.79623 .71283 L
.79423 .71853 L
.79079 .72824 L
.78737 .73796 L
.78652 .74043 L
.78395 .74767 L
.78048 .75738 L
.77704 .76709 L
.77681 .76777 L
.77356 .77681 L
.77006 .78652 L
.76709 .79485 L
.7666 .79623 L
.76307 .80594 L
.75953 .81566 L
.75738 .82166 L
.75603 .82537 L
.75246 .83508 L
.7489 .84479 L
.74767 .84821 L
.74534 .85451 L
.74173 .86422 L
.73816 .87393 L
.73796 .87448 L
.73453 .88364 L
.73089 .89336 L
.72824 .90049 L
.72727 .90307 L
.7236 .91278 L
.71992 .92249 L
.71853 .92621 L
.71625 .93221 L
.71252 .94192 L
.70883 .95163 L
.70882 .95166 L
.70508 .96134 L
.70132 .97106 L
.69911 .97683 L
.69758 .98077 L
.98077 .98077 L
F
0 g
.98077 .14201 m
.97944 .14549 L
.97654 .15521 L
.97378 .16492 L
.97106 .17415 L
.97091 .17463 L
.96795 .18434 L
.96495 .19406 L
.96201 .20377 L
.96134 .20606 L
.95907 .21348 L
.95605 .22319 L
.95307 .23291 L
.95163 .23775 L
.95013 .24262 L
.9471 .25233 L
.94408 .26204 L
.94192 .26921 L
.94113 .27176 L
.93809 .28147 L
.93504 .29118 L
.93221 .30045 L
.93207 .30089 L
.92902 .31061 L
.92594 .32032 L
.92292 .33003 L
.92249 .33145 L
.91988 .33974 L
.91677 .34946 L
.91372 .35917 L
.91278 .36223 L
.91067 .36888 L
.90754 .37859 L
.90445 .38831 L
.90307 .39277 L
.90139 .39802 L
.89825 .40773 L
.89512 .41744 L
.89336 .42307 L
.89204 .42716 L
.88888 .43687 L
.88572 .44658 L
.88364 .45315 L
.88262 .45629 L
.87944 .46601 L
.87625 .47572 L
.87393 .48298 L
.87313 .48543 L
.86992 .49514 L
.86671 .50486 L
Mistroke
.86422 .51257 L
.86356 .51457 L
.86033 .52428 L
.85709 .53399 L
.85451 .54192 L
.85392 .54371 L
.85066 .55342 L
.84739 .56313 L
.84479 .57103 L
.84419 .57284 L
.8409 .58256 L
.83761 .59227 L
.83508 .59989 L
.83438 .60198 L
.83106 .61169 L
.82775 .62141 L
.82537 .6285 L
.82448 .63112 L
.82114 .64083 L
.81779 .65054 L
.81566 .65687 L
.81449 .66026 L
.81112 .66997 L
.80775 .67968 L
.80594 .68498 L
.80441 .68939 L
.801 .69911 L
.79761 .70882 L
.79623 .71283 L
.79423 .71853 L
.79079 .72824 L
.78737 .73796 L
.78652 .74043 L
.78395 .74767 L
.78048 .75738 L
.77704 .76709 L
.77681 .76777 L
.77356 .77681 L
.77006 .78652 L
.76709 .79485 L
.7666 .79623 L
.76307 .80594 L
.75953 .81566 L
.75738 .82166 L
.75603 .82537 L
.75246 .83508 L
.7489 .84479 L
.74767 .84821 L
.74534 .85451 L
.74173 .86422 L
Mistroke
.73816 .87393 L
.73796 .87448 L
.73453 .88364 L
.73089 .89336 L
.72824 .90049 L
.72727 .90307 L
.7236 .91278 L
.71992 .92249 L
.71853 .92621 L
.71625 .93221 L
.71252 .94192 L
.70883 .95163 L
.70882 .95166 L
.70508 .96134 L
.70132 .97106 L
.69911 .97683 L
.69758 .98077 L
Mfstroke
.3 g
.98077 .16224 m
.97994 .16492 L
.97704 .17463 L
.97416 .18434 L
.97118 .19406 L
.97106 .19446 L
.96812 .20377 L
.96502 .21348 L
.96213 .22319 L
.96134 .22645 L
.9593 .23291 L
.95618 .24262 L
.95316 .25233 L
.95163 .25822 L
.95042 .26204 L
.94728 .27176 L
.94419 .28147 L
.94192 .28976 L
.94147 .29118 L
.93833 .30089 L
.93519 .31061 L
.93239 .32032 L
.93221 .32108 L
.92931 .33003 L
.92613 .33974 L
.92318 .34946 L
.92249 .35217 L
.92022 .35917 L
.91702 .36888 L
.91397 .37859 L
.91278 .38303 L
.91106 .38831 L
.90784 .39802 L
.90471 .40773 L
.90307 .41367 L
.90183 .41744 L
.89859 .42716 L
.89541 .43687 L
.89336 .44407 L
.89253 .44658 L
.88927 .45629 L
.88605 .46601 L
.88364 .47423 L
.88315 .47572 L
.87988 .48543 L
.87662 .49514 L
.87393 .50416 L
.8737 .50486 L
.87041 .51457 L
.86712 .52428 L
.86422 .53385 L
.86417 .53399 L
.86086 .54371 L
.85755 .55342 L
.85455 .56313 L
.85451 .56331 L
.85123 .57284 L
.84789 .58256 L
.84486 .59227 L
.84479 .59251 L
.84152 .60198 L
.83815 .61169 L
.8351 .62141 L
.83508 .62148 L
.83172 .63112 L
.82833 .64083 L
.82537 .6502 L
.82525 .65054 L
.82183 .66026 L
.81843 .66997 L
.81566 .67867 L
.8153 .67968 L
.81185 .68939 L
.80843 .69911 L
.80594 .70689 L
.80526 .70882 L
.80178 .71853 L
.79835 .72824 L
.79623 .73486 L
.79512 .73796 L
.79161 .74767 L
.78818 .75738 L
.78652 .76258 L
.78488 .76709 L
.78134 .77681 L
.77792 .78652 L
.77681 .79004 L
.77454 .79623 L
.77097 .80594 L
.76759 .81566 L
.76709 .81724 L
.76409 .82537 L
.7605 .83508 L
.75738 .84419 L
.75716 .84479 L
.75352 .85451 L
.74993 .86422 L
.74767 .87086 L
.74652 .87393 L
.74284 .88364 L
.73927 .89336 L
.73796 .89727 L
.73575 .90307 L
.73205 .91278 L
.72855 .92249 L
.72824 .92341 L
.72487 .93221 L
.72115 .94192 L
.71853 .94928 L
.71763 .95163 L
.71385 .96134 L
.71016 .97106 L
.70882 .97489 L
.70652 .98077 L
.98077 .98077 L
F
0 g
.98077 .16224 m
.97994 .16492 L
.97704 .17463 L
.97416 .18434 L
.97118 .19406 L
.97106 .19446 L
.96812 .20377 L
.96502 .21348 L
.96213 .22319 L
.96134 .22645 L
.9593 .23291 L
.95618 .24262 L
.95316 .25233 L
.95163 .25822 L
.95042 .26204 L
.94728 .27176 L
.94419 .28147 L
.94192 .28976 L
.94147 .29118 L
.93833 .30089 L
.93519 .31061 L
.93239 .32032 L
.93221 .32108 L
.92931 .33003 L
.92613 .33974 L
.92318 .34946 L
.92249 .35217 L
.92022 .35917 L
.91702 .36888 L
.91397 .37859 L
.91278 .38303 L
.91106 .38831 L
.90784 .39802 L
.90471 .40773 L
.90307 .41367 L
.90183 .41744 L
.89859 .42716 L
.89541 .43687 L
.89336 .44407 L
.89253 .44658 L
.88927 .45629 L
.88605 .46601 L
.88364 .47423 L
.88315 .47572 L
.87988 .48543 L
.87662 .49514 L
.87393 .50416 L
.8737 .50486 L
.87041 .51457 L
.86712 .52428 L
Mistroke
.86422 .53385 L
.86417 .53399 L
.86086 .54371 L
.85755 .55342 L
.85455 .56313 L
.85451 .56331 L
.85123 .57284 L
.84789 .58256 L
.84486 .59227 L
.84479 .59251 L
.84152 .60198 L
.83815 .61169 L
.8351 .62141 L
.83508 .62148 L
.83172 .63112 L
.82833 .64083 L
.82537 .6502 L
.82525 .65054 L
.82183 .66026 L
.81843 .66997 L
.81566 .67867 L
.8153 .67968 L
.81185 .68939 L
.80843 .69911 L
.80594 .70689 L
.80526 .70882 L
.80178 .71853 L
.79835 .72824 L
.79623 .73486 L
.79512 .73796 L
.79161 .74767 L
.78818 .75738 L
.78652 .76258 L
.78488 .76709 L
.78134 .77681 L
.77792 .78652 L
.77681 .79004 L
.77454 .79623 L
.77097 .80594 L
.76759 .81566 L
.76709 .81724 L
.76409 .82537 L
.7605 .83508 L
.75738 .84419 L
.75716 .84479 L
.75352 .85451 L
.74993 .86422 L
.74767 .87086 L
.74652 .87393 L
.74284 .88364 L
Mistroke
.73927 .89336 L
.73796 .89727 L
.73575 .90307 L
.73205 .91278 L
.72855 .92249 L
.72824 .92341 L
.72487 .93221 L
.72115 .94192 L
.71853 .94928 L
.71763 .95163 L
.71385 .96134 L
.71016 .97106 L
.70882 .97489 L
.70652 .98077 L
Mfstroke
.2 g
.98077 .1866 m
.97869 .19406 L
.97589 .20377 L
.9729 .21348 L
.97106 .21895 L
.96954 .22319 L
.96543 .23291 L
.96394 .24262 L
.96134 .2511 L
.96091 .25233 L
.95708 .26204 L
.9551 .27176 L
.95211 .28147 L
.95163 .28301 L
.94853 .29118 L
.94619 .30089 L
.9432 .31061 L
.94192 .3147 L
.93984 .32032 L
.93547 .33003 L
.93422 .33974 L
.93221 .34618 L
.93101 .34946 L
.9269 .35917 L
.92519 .36888 L
.92249 .37744 L
.92208 .37859 L
.91814 .38831 L
.91609 .39802 L
.91302 .40773 L
.91278 .40846 L
.90924 .41744 L
.90693 .42716 L
.90384 .43687 L
.90307 .43925 L
.90022 .44658 L
.8977 .45629 L
.89459 .46601 L
.89336 .46982 L
.89108 .47572 L
.8865 .48543 L
.88528 .49514 L
.88364 .50016 L
.88184 .50486 L
.87739 .51457 L
.8759 .52428 L
.87393 .53028 L
.87251 .53399 L
.86814 .54371 L
.86644 .55342 L
.86422 .56016 L
.86308 .56313 L
.85876 .57284 L
.85692 .58256 L
.85451 .58981 L
.85356 .59227 L
.84925 .60198 L
.84731 .61169 L
.84479 .61922 L
.84395 .62141 L
.83963 .63112 L
.83763 .64083 L
.83508 .6484 L
.83425 .65054 L
.82989 .66026 L
.82787 .66997 L
.82537 .67733 L
.82445 .67968 L
.82002 .68939 L
.81803 .69911 L
.81566 .70602 L
.81454 .70882 L
.81001 .71853 L
.8081 .72824 L
.80594 .73447 L
.80453 .73796 L
.79986 .74767 L
.79809 .75738 L
.79623 .76267 L
.79441 .76709 L
.78954 .77681 L
.78798 .78652 L
.78652 .79063 L
.78415 .79623 L
.7812 .80594 L
.77778 .81566 L
.77681 .81835 L
.77376 .82537 L
.77094 .83508 L
.76748 .84479 L
.76709 .84584 L
.76319 .85451 L
.76057 .86422 L
.75738 .87308 L
.75703 .87393 L
.75241 .88364 L
.75011 .89336 L
.74767 .90002 L
.74637 .90307 L
.74137 .91278 L
.73953 .92249 L
.73796 .92671 L
.73551 .93221 L
.73243 .94192 L
.72884 .95163 L
.72824 .95319 L
.72441 .96134 L
.72167 .97106 L
.71853 .97946 L
.71795 .98077 L
.98077 .98077 L
F
0 g
.98077 .1866 m
.97869 .19406 L
.97589 .20377 L
.9729 .21348 L
.97106 .21895 L
.96954 .22319 L
.96543 .23291 L
.96394 .24262 L
.96134 .2511 L
.96091 .25233 L
.95708 .26204 L
.9551 .27176 L
.95211 .28147 L
.95163 .28301 L
.94853 .29118 L
.94619 .30089 L
.9432 .31061 L
.94192 .3147 L
.93984 .32032 L
.93547 .33003 L
.93422 .33974 L
.93221 .34618 L
.93101 .34946 L
.9269 .35917 L
.92519 .36888 L
.92249 .37744 L
.92208 .37859 L
.91814 .38831 L
.91609 .39802 L
.91302 .40773 L
.91278 .40846 L
.90924 .41744 L
.90693 .42716 L
.90384 .43687 L
.90307 .43925 L
.90022 .44658 L
.8977 .45629 L
.89459 .46601 L
.89336 .46982 L
.89108 .47572 L
.8865 .48543 L
.88528 .49514 L
.88364 .50016 L
.88184 .50486 L
.87739 .51457 L
.8759 .52428 L
.87393 .53028 L
.87251 .53399 L
.86814 .54371 L
.86644 .55342 L
Mistroke
.86422 .56016 L
.86308 .56313 L
.85876 .57284 L
.85692 .58256 L
.85451 .58981 L
.85356 .59227 L
.84925 .60198 L
.84731 .61169 L
.84479 .61922 L
.84395 .62141 L
.83963 .63112 L
.83763 .64083 L
.83508 .6484 L
.83425 .65054 L
.82989 .66026 L
.82787 .66997 L
.82537 .67733 L
.82445 .67968 L
.82002 .68939 L
.81803 .69911 L
.81566 .70602 L
.81454 .70882 L
.81001 .71853 L
.8081 .72824 L
.80594 .73447 L
.80453 .73796 L
.79986 .74767 L
.79809 .75738 L
.79623 .76267 L
.79441 .76709 L
.78954 .77681 L
.78798 .78652 L
.78652 .79063 L
.78415 .79623 L
.7812 .80594 L
.77778 .81566 L
.77681 .81835 L
.77376 .82537 L
.77094 .83508 L
.76748 .84479 L
.76709 .84584 L
.76319 .85451 L
.76057 .86422 L
.75738 .87308 L
.75703 .87393 L
.75241 .88364 L
.75011 .89336 L
.74767 .90002 L
.74637 .90307 L
.74137 .91278 L
Mistroke
.73953 .92249 L
.73796 .92671 L
.73551 .93221 L
.73243 .94192 L
.72884 .95163 L
.72824 .95319 L
.72441 .96134 L
.72167 .97106 L
.71853 .97946 L
.71795 .98077 L
Mfstroke
.3 g
.98077 .27954 m
.9802 .28147 L
.97729 .29118 L
.97431 .30089 L
.97129 .31061 L
.97106 .31137 L
.96829 .32032 L
.96676 .33003 L
.96255 .33974 L
.96134 .34301 L
.95933 .34946 L
.9583 .35917 L
.95374 .36888 L
.95163 .37441 L
.95031 .37859 L
.94726 .38831 L
.94488 .39802 L
.94192 .40556 L
.94122 .40773 L
.93815 .41744 L
.93599 .42716 L
.93221 .43646 L
.93208 .43687 L
.92898 .44658 L
.92704 .45629 L
.92292 .46601 L
.92249 .46715 L
.91974 .47572 L
.91802 .48543 L
.91372 .49514 L
.91278 .49761 L
.91043 .50486 L
.90893 .51457 L
.90444 .52428 L
.90307 .52782 L
.90105 .53399 L
.89973 .54371 L
.89508 .55342 L
.89336 .55779 L
.89159 .56313 L
.89043 .57284 L
.88563 .58256 L
.88364 .58751 L
.88205 .59227 L
.88099 .60198 L
.87608 .61169 L
.87393 .61699 L
.87244 .62141 L
.8692 .63112 L
.86643 .64083 L
.86422 .64621 L
.86274 .65054 L
.85948 .66026 L
.85666 .66997 L
.85451 .67518 L
.85296 .67968 L
.8518 .68939 L
.84678 .69911 L
.84479 .7039 L
.84309 .70882 L
.84175 .71853 L
.83679 .72824 L
.83508 .73236 L
.83313 .73796 L
.83156 .74767 L
.82669 .75738 L
.82537 .76055 L
.82307 .76709 L
.82122 .77681 L
.81647 .78652 L
.81566 .78848 L
.81291 .79623 L
.81075 .80594 L
.80614 .81566 L
.80594 .81614 L
.80266 .82537 L
.80016 .83508 L
.79623 .84356 L
.79578 .84479 L
.79229 .85451 L
.78947 .86422 L
.78652 .87071 L
.78533 .87393 L
.78181 .88364 L
.77868 .89336 L
.77681 .89757 L
.77477 .90307 L
.77288 .91278 L
.76781 .92249 L
.76709 .92412 L
.76409 .93221 L
.76157 .94192 L
.75738 .95044 L
.75692 .95163 L
.75328 .96134 L
.75023 .97106 L
.74767 .9761 L
.74602 .98077 L
.98077 .98077 L
F
0 g
.98077 .27954 m
.9802 .28147 L
.97729 .29118 L
.97431 .30089 L
.97129 .31061 L
.97106 .31137 L
.96829 .32032 L
.96676 .33003 L
.96255 .33974 L
.96134 .34301 L
.95933 .34946 L
.9583 .35917 L
.95374 .36888 L
.95163 .37441 L
.95031 .37859 L
.94726 .38831 L
.94488 .39802 L
.94192 .40556 L
.94122 .40773 L
.93815 .41744 L
.93599 .42716 L
.93221 .43646 L
.93208 .43687 L
.92898 .44658 L
.92704 .45629 L
.92292 .46601 L
.92249 .46715 L
.91974 .47572 L
.91802 .48543 L
.91372 .49514 L
.91278 .49761 L
.91043 .50486 L
.90893 .51457 L
.90444 .52428 L
.90307 .52782 L
.90105 .53399 L
.89973 .54371 L
.89508 .55342 L
.89336 .55779 L
.89159 .56313 L
.89043 .57284 L
.88563 .58256 L
.88364 .58751 L
.88205 .59227 L
.88099 .60198 L
.87608 .61169 L
.87393 .61699 L
.87244 .62141 L
.8692 .63112 L
.86643 .64083 L
Mistroke
.86422 .64621 L
.86274 .65054 L
.85948 .66026 L
.85666 .66997 L
.85451 .67518 L
.85296 .67968 L
.8518 .68939 L
.84678 .69911 L
.84479 .7039 L
.84309 .70882 L
.84175 .71853 L
.83679 .72824 L
.83508 .73236 L
.83313 .73796 L
.83156 .74767 L
.82669 .75738 L
.82537 .76055 L
.82307 .76709 L
.82122 .77681 L
.81647 .78652 L
.81566 .78848 L
.81291 .79623 L
.81075 .80594 L
.80614 .81566 L
.80594 .81614 L
.80266 .82537 L
.80016 .83508 L
.79623 .84356 L
.79578 .84479 L
.79229 .85451 L
.78947 .86422 L
.78652 .87071 L
.78533 .87393 L
.78181 .88364 L
.77868 .89336 L
.77681 .89757 L
.77477 .90307 L
.77288 .91278 L
.76781 .92249 L
.76709 .92412 L
.76409 .93221 L
.76157 .94192 L
.75738 .95044 L
.75692 .95163 L
.75328 .96134 L
.75023 .97106 L
.74767 .9761 L
.74602 .98077 L
Mfstroke
.4 g
.98077 .3039 m
.97878 .31061 L
.97583 .32032 L
.97169 .33003 L
.97106 .33589 L
.97014 .33974 L
.96721 .34946 L
.96407 .35917 L
.96134 .36765 L
.96107 .36888 L
.9583 .37859 L
.95516 .38831 L
.95201 .39802 L
.95163 .39919 L
.94931 .40773 L
.94618 .41744 L
.943 .42716 L
.94192 .4305 L
.94023 .43687 L
.93714 .44658 L
.93393 .45629 L
.93221 .46158 L
.93107 .46601 L
.92802 .47572 L
.9248 .48543 L
.92249 .49242 L
.92182 .49514 L
.91883 .50486 L
.91559 .51457 L
.91278 .52303 L
.91248 .52428 L
.90957 .53399 L
.90632 .54371 L
.90307 .5534 L
.90307 .55342 L
.90023 .56313 L
.89697 .57284 L
.89369 .58256 L
.89336 .58354 L
.89081 .59227 L
.88754 .60198 L
.88423 .61169 L
.88364 .61344 L
.88132 .62141 L
.87804 .63112 L
.8747 .64083 L
.87393 .6431 L
.87175 .65054 L
.86845 .66026 L
.86509 .66997 L
.86422 .67251 L
.8621 .67968 L
.85878 .68939 L
.85539 .69911 L
.85451 .70168 L
.85237 .70882 L
.84903 .71853 L
.84561 .72824 L
.84479 .73059 L
.84256 .73796 L
.83918 .74767 L
.83574 .75738 L
.83508 .75926 L
.83266 .76709 L
.82925 .77681 L
.82578 .78652 L
.82537 .78768 L
.82267 .79623 L
.81921 .80594 L
.81572 .81566 L
.81566 .81583 L
.81258 .82537 L
.80908 .83508 L
.80594 .84374 L
.80564 .84479 L
.80239 .85451 L
.79885 .86422 L
.79623 .87139 L
.79546 .87393 L
.7921 .88364 L
.78851 .89336 L
.78652 .89877 L
.78517 .90307 L
.78169 .91278 L
.77806 .92249 L
.77681 .92588 L
.77473 .93221 L
.77116 .94192 L
.7675 .95163 L
.76709 .95273 L
.76417 .96134 L
.76051 .97106 L
.75738 .97929 L
.75692 .98077 L
.98077 .98077 L
F
0 g
.98077 .3039 m
.97878 .31061 L
.97583 .32032 L
.97169 .33003 L
.97106 .33589 L
.97014 .33974 L
.96721 .34946 L
.96407 .35917 L
.96134 .36765 L
.96107 .36888 L
.9583 .37859 L
.95516 .38831 L
.95201 .39802 L
.95163 .39919 L
.94931 .40773 L
.94618 .41744 L
.943 .42716 L
.94192 .4305 L
.94023 .43687 L
.93714 .44658 L
.93393 .45629 L
.93221 .46158 L
.93107 .46601 L
.92802 .47572 L
.9248 .48543 L
.92249 .49242 L
.92182 .49514 L
.91883 .50486 L
.91559 .51457 L
.91278 .52303 L
.91248 .52428 L
.90957 .53399 L
.90632 .54371 L
.90307 .5534 L
.90307 .55342 L
.90023 .56313 L
.89697 .57284 L
.89369 .58256 L
.89336 .58354 L
.89081 .59227 L
.88754 .60198 L
.88423 .61169 L
.88364 .61344 L
.88132 .62141 L
.87804 .63112 L
.8747 .64083 L
.87393 .6431 L
.87175 .65054 L
.86845 .66026 L
.86509 .66997 L
Mistroke
.86422 .67251 L
.8621 .67968 L
.85878 .68939 L
.85539 .69911 L
.85451 .70168 L
.85237 .70882 L
.84903 .71853 L
.84561 .72824 L
.84479 .73059 L
.84256 .73796 L
.83918 .74767 L
.83574 .75738 L
.83508 .75926 L
.83266 .76709 L
.82925 .77681 L
.82578 .78652 L
.82537 .78768 L
.82267 .79623 L
.81921 .80594 L
.81572 .81566 L
.81566 .81583 L
.81258 .82537 L
.80908 .83508 L
.80594 .84374 L
.80564 .84479 L
.80239 .85451 L
.79885 .86422 L
.79623 .87139 L
.79546 .87393 L
.7921 .88364 L
.78851 .89336 L
.78652 .89877 L
.78517 .90307 L
.78169 .91278 L
.77806 .92249 L
.77681 .92588 L
.77473 .93221 L
.77116 .94192 L
.7675 .95163 L
.76709 .95273 L
.76417 .96134 L
.76051 .97106 L
.75738 .97929 L
.75692 .98077 L
Mfstroke
.5 g
.98077 .32413 m
.97668 .33003 L
.975 .33974 L
.97288 .34946 L
.97106 .3562 L
.9702 .35917 L
.96726 .36888 L
.96425 .37859 L
.96134 .38804 L
.96127 .38831 L
.95836 .39802 L
.95534 .40773 L
.95231 .41744 L
.95163 .41966 L
.94939 .42716 L
.94636 .43687 L
.94331 .44658 L
.94192 .45105 L
.94035 .45629 L
.93732 .46601 L
.93425 .47572 L
.93221 .48221 L
.93124 .48543 L
.92822 .49514 L
.92512 .50486 L
.92249 .51314 L
.92207 .51457 L
.91904 .52428 L
.91593 .53399 L
.91282 .54371 L
.91278 .54384 L
.9098 .55342 L
.90667 .56313 L
.90354 .57284 L
.90307 .57431 L
.90049 .58256 L
.89734 .59227 L
.89418 .60198 L
.89336 .60454 L
.89111 .61169 L
.88794 .62141 L
.88475 .63112 L
.88364 .63453 L
.88165 .64083 L
.87847 .65054 L
.87525 .66026 L
.87393 .66428 L
.87212 .66997 L
.86891 .67968 L
.86568 .68939 L
.86422 .69379 L
.86251 .69911 L
.85928 .70882 L
.85602 .71853 L
.85451 .72306 L
.85282 .72824 L
.84957 .73796 L
.84628 .74767 L
.84479 .75208 L
.84306 .75738 L
.83977 .76709 L
.83646 .77681 L
.83508 .78085 L
.8332 .78652 L
.82989 .79623 L
.82654 .80594 L
.82537 .80937 L
.82327 .81566 L
.81992 .82537 L
.81654 .83508 L
.81566 .83764 L
.81323 .84479 L
.80985 .85451 L
.80645 .86422 L
.80594 .86566 L
.80311 .87393 L
.79968 .88364 L
.79625 .89336 L
.79623 .89341 L
.79288 .90307 L
.78942 .91278 L
.78652 .92091 L
.78598 .92249 L
.78255 .93221 L
.77905 .94192 L
.77681 .94815 L
.77559 .95163 L
.77211 .96134 L
.76857 .97106 L
.76709 .97512 L
.76509 .98077 L
.98077 .98077 L
F
0 g
.98077 .32413 m
.97668 .33003 L
.975 .33974 L
.97288 .34946 L
.97106 .3562 L
.9702 .35917 L
.96726 .36888 L
.96425 .37859 L
.96134 .38804 L
.96127 .38831 L
.95836 .39802 L
.95534 .40773 L
.95231 .41744 L
.95163 .41966 L
.94939 .42716 L
.94636 .43687 L
.94331 .44658 L
.94192 .45105 L
.94035 .45629 L
.93732 .46601 L
.93425 .47572 L
.93221 .48221 L
.93124 .48543 L
.92822 .49514 L
.92512 .50486 L
.92249 .51314 L
.92207 .51457 L
.91904 .52428 L
.91593 .53399 L
.91282 .54371 L
.91278 .54384 L
.9098 .55342 L
.90667 .56313 L
.90354 .57284 L
.90307 .57431 L
.90049 .58256 L
.89734 .59227 L
.89418 .60198 L
.89336 .60454 L
.89111 .61169 L
.88794 .62141 L
.88475 .63112 L
.88364 .63453 L
.88165 .64083 L
.87847 .65054 L
.87525 .66026 L
.87393 .66428 L
.87212 .66997 L
.86891 .67968 L
.86568 .68939 L
Mistroke
.86422 .69379 L
.86251 .69911 L
.85928 .70882 L
.85602 .71853 L
.85451 .72306 L
.85282 .72824 L
.84957 .73796 L
.84628 .74767 L
.84479 .75208 L
.84306 .75738 L
.83977 .76709 L
.83646 .77681 L
.83508 .78085 L
.8332 .78652 L
.82989 .79623 L
.82654 .80594 L
.82537 .80937 L
.82327 .81566 L
.81992 .82537 L
.81654 .83508 L
.81566 .83764 L
.81323 .84479 L
.80985 .85451 L
.80645 .86422 L
.80594 .86566 L
.80311 .87393 L
.79968 .88364 L
.79625 .89336 L
.79623 .89341 L
.79288 .90307 L
.78942 .91278 L
.78652 .92091 L
.78598 .92249 L
.78255 .93221 L
.77905 .94192 L
.77681 .94815 L
.77559 .95163 L
.77211 .96134 L
.76857 .97106 L
.76709 .97512 L
.76509 .98077 L
Mfstroke
.6 g
.98077 .3434 m
.9786 .34946 L
.97581 .35917 L
.97303 .36888 L
.97106 .37553 L
.97013 .37859 L
.96715 .38831 L
.96416 .39802 L
.96134 .40745 L
.96126 .40773 L
.95827 .41744 L
.95525 .42716 L
.9523 .43687 L
.95163 .43913 L
.94933 .44658 L
.9463 .45629 L
.94329 .46601 L
.94192 .4706 L
.94033 .47572 L
.93728 .48543 L
.93424 .49514 L
.93221 .50183 L
.93126 .50486 L
.9282 .51457 L
.92512 .52428 L
.92249 .53284 L
.92213 .53399 L
.91905 .54371 L
.91595 .55342 L
.91293 .56313 L
.91278 .56361 L
.90984 .57284 L
.90672 .58256 L
.90365 .59227 L
.90307 .59415 L
.90056 .60198 L
.89741 .61169 L
.89431 .62141 L
.89336 .62446 L
.89121 .63112 L
.88804 .64083 L
.8849 .65054 L
.88364 .65453 L
.88178 .66026 L
.87859 .66997 L
.87542 .67968 L
.87393 .68436 L
.87228 .68939 L
.86907 .69911 L
.86587 .70882 L
.86422 .71396 L
.86271 .71853 L
.85947 .72824 L
.85624 .73796 L
.85451 .74331 L
.85306 .74767 L
.84979 .75738 L
.84654 .76709 L
.84479 .77241 L
.84332 .77681 L
.84003 .78652 L
.83675 .79623 L
.83508 .80128 L
.8335 .80594 L
.83018 .81566 L
.82687 .82537 L
.82537 .82989 L
.82359 .83508 L
.82024 .84479 L
.81691 .85451 L
.81566 .85825 L
.8136 .86422 L
.81022 .87393 L
.80686 .88364 L
.80594 .88636 L
.80351 .89336 L
.80009 .90307 L
.79672 .91278 L
.79623 .91422 L
.79332 .92249 L
.78988 .93221 L
.78652 .94182 L
.78648 .94192 L
.78303 .95163 L
.77956 .96134 L
.77681 .96915 L
.77613 .97106 L
.77263 .98077 L
.98077 .98077 L
F
0 g
.98077 .3434 m
.9786 .34946 L
.97581 .35917 L
.97303 .36888 L
.97106 .37553 L
.97013 .37859 L
.96715 .38831 L
.96416 .39802 L
.96134 .40745 L
.96126 .40773 L
.95827 .41744 L
.95525 .42716 L
.9523 .43687 L
.95163 .43913 L
.94933 .44658 L
.9463 .45629 L
.94329 .46601 L
.94192 .4706 L
.94033 .47572 L
.93728 .48543 L
.93424 .49514 L
.93221 .50183 L
.93126 .50486 L
.9282 .51457 L
.92512 .52428 L
.92249 .53284 L
.92213 .53399 L
.91905 .54371 L
.91595 .55342 L
.91293 .56313 L
.91278 .56361 L
.90984 .57284 L
.90672 .58256 L
.90365 .59227 L
.90307 .59415 L
.90056 .60198 L
.89741 .61169 L
.89431 .62141 L
.89336 .62446 L
.89121 .63112 L
.88804 .64083 L
.8849 .65054 L
.88364 .65453 L
.88178 .66026 L
.87859 .66997 L
.87542 .67968 L
.87393 .68436 L
.87228 .68939 L
.86907 .69911 L
.86587 .70882 L
Mistroke
.86422 .71396 L
.86271 .71853 L
.85947 .72824 L
.85624 .73796 L
.85451 .74331 L
.85306 .74767 L
.84979 .75738 L
.84654 .76709 L
.84479 .77241 L
.84332 .77681 L
.84003 .78652 L
.83675 .79623 L
.83508 .80128 L
.8335 .80594 L
.83018 .81566 L
.82687 .82537 L
.82537 .82989 L
.82359 .83508 L
.82024 .84479 L
.81691 .85451 L
.81566 .85825 L
.8136 .86422 L
.81022 .87393 L
.80686 .88364 L
.80594 .88636 L
.80351 .89336 L
.80009 .90307 L
.79672 .91278 L
.79623 .91422 L
.79332 .92249 L
.78988 .93221 L
.78652 .94182 L
.78648 .94192 L
.78303 .95163 L
.77956 .96134 L
.77681 .96915 L
.77613 .97106 L
.77263 .98077 L
Mfstroke
.7 g
.98077 .36363 m
.97915 .36888 L
.97628 .37859 L
.97338 .38831 L
.97106 .39584 L
.97038 .39802 L
.96729 .40773 L
.96421 .41744 L
.96149 .42716 L
.96134 .42783 L
.95847 .43687 L
.95535 .44658 L
.95244 .45629 L
.95163 .4596 L
.94959 .46601 L
.94645 .47572 L
.94342 .48543 L
.94192 .49115 L
.94064 .49514 L
.93749 .50486 L
.93438 .51457 L
.93221 .52247 L
.93162 .52428 L
.92846 .53399 L
.92531 .54371 L
.92253 .55342 L
.92249 .55356 L
.91937 .56313 L
.91618 .57284 L
.91325 .58256 L
.91278 .58442 L
.91021 .59227 L
.90699 .60198 L
.90396 .61169 L
.90307 .61505 L
.90097 .62141 L
.89773 .63112 L
.89462 .64083 L
.89336 .64545 L
.89167 .65054 L
.88841 .66026 L
.88524 .66997 L
.88364 .67561 L
.88229 .67968 L
.87901 .68939 L
.8758 .69911 L
.87393 .70554 L
.87283 .70882 L
.86953 .71853 L
.86628 .72824 L
.86422 .73523 L
.8633 .73796 L
.85997 .74767 L
.8567 .75738 L
.85451 .76469 L
.85369 .76709 L
.85034 .77681 L
.84703 .78652 L
.84479 .7939 L
.84399 .79623 L
.84062 .80594 L
.83729 .81566 L
.83508 .82286 L
.83421 .82537 L
.83081 .83508 L
.82746 .84479 L
.82537 .85158 L
.82435 .85451 L
.82092 .86422 L
.81756 .87393 L
.81566 .88005 L
.81439 .88364 L
.81093 .89336 L
.80756 .90307 L
.80594 .90827 L
.80434 .91278 L
.80085 .92249 L
.79749 .93221 L
.79623 .93624 L
.79419 .94192 L
.79068 .95163 L
.78733 .96134 L
.78652 .96396 L
.78394 .97106 L
.78041 .98077 L
.98077 .98077 L
F
0 g
.98077 .36363 m
.97915 .36888 L
.97628 .37859 L
.97338 .38831 L
.97106 .39584 L
.97038 .39802 L
.96729 .40773 L
.96421 .41744 L
.96149 .42716 L
.96134 .42783 L
.95847 .43687 L
.95535 .44658 L
.95244 .45629 L
.95163 .4596 L
.94959 .46601 L
.94645 .47572 L
.94342 .48543 L
.94192 .49115 L
.94064 .49514 L
.93749 .50486 L
.93438 .51457 L
.93221 .52247 L
.93162 .52428 L
.92846 .53399 L
.92531 .54371 L
.92253 .55342 L
.92249 .55356 L
.91937 .56313 L
.91618 .57284 L
.91325 .58256 L
.91278 .58442 L
.91021 .59227 L
.90699 .60198 L
.90396 .61169 L
.90307 .61505 L
.90097 .62141 L
.89773 .63112 L
.89462 .64083 L
.89336 .64545 L
.89167 .65054 L
.88841 .66026 L
.88524 .66997 L
.88364 .67561 L
.88229 .67968 L
.87901 .68939 L
.8758 .69911 L
.87393 .70554 L
.87283 .70882 L
.86953 .71853 L
.86628 .72824 L
Mistroke
.86422 .73523 L
.8633 .73796 L
.85997 .74767 L
.8567 .75738 L
.85451 .76469 L
.85369 .76709 L
.85034 .77681 L
.84703 .78652 L
.84479 .7939 L
.84399 .79623 L
.84062 .80594 L
.83729 .81566 L
.83508 .82286 L
.83421 .82537 L
.83081 .83508 L
.82746 .84479 L
.82537 .85158 L
.82435 .85451 L
.82092 .86422 L
.81756 .87393 L
.81566 .88005 L
.81439 .88364 L
.81093 .89336 L
.80756 .90307 L
.80594 .90827 L
.80434 .91278 L
.80085 .92249 L
.79749 .93221 L
.79623 .93624 L
.79419 .94192 L
.79068 .95163 L
.78733 .96134 L
.78652 .96396 L
.78394 .97106 L
.78041 .98077 L
Mfstroke
.8 g
.98077 .388 m
.98069 .38831 L
.97796 .39802 L
.97512 .40773 L
.97205 .41744 L
.97106 .42033 L
.96855 .42716 L
.96411 .43687 L
.96316 .44658 L
.96134 .45247 L
.95997 .45629 L
.95589 .46601 L
.95431 .47572 L
.95163 .48441 L
.95127 .48543 L
.94743 .49514 L
.9454 .50486 L
.9424 .51457 L
.94192 .51609 L
.93879 .52428 L
.93644 .53399 L
.93342 .54371 L
.93221 .54755 L
.93001 .55342 L
.92558 .56313 L
.92438 .57284 L
.92249 .57881 L
.92111 .58256 L
.91691 .59227 L
.91528 .60198 L
.91278 .60985 L
.91211 .61169 L
.90808 .62141 L
.90611 .63112 L
.90307 .64066 L
.90301 .64083 L
.89909 .65054 L
.89688 .66026 L
.89376 .66997 L
.89336 .67121 L
.88999 .67968 L
.88758 .68939 L
.88445 .69911 L
.88364 .70155 L
.88077 .70882 L
.87821 .71853 L
.87506 .72824 L
.87393 .73165 L
.87145 .73796 L
.86672 .74767 L
.8656 .75738 L
.86422 .76153 L
.86203 .76709 L
.85737 .77681 L
.85606 .78652 L
.85451 .79118 L
.85252 .79623 L
.84788 .80594 L
.84646 .81566 L
.84479 .82059 L
.8429 .82537 L
.83826 .83508 L
.83677 .84479 L
.83508 .84976 L
.83319 .85451 L
.8285 .86422 L
.827 .87393 L
.82537 .8787 L
.82337 .88364 L
.8186 .89336 L
.81715 .90307 L
.81566 .90739 L
.81345 .91278 L
.80855 .92249 L
.80722 .93221 L
.80594 .93584 L
.80341 .94192 L
.80056 .95163 L
.79719 .96134 L
.79623 .96405 L
.79325 .97106 L
.79047 .98077 L
.98077 .98077 L
F
0 g
.98077 .388 m
.98069 .38831 L
.97796 .39802 L
.97512 .40773 L
.97205 .41744 L
.97106 .42033 L
.96855 .42716 L
.96411 .43687 L
.96316 .44658 L
.96134 .45247 L
.95997 .45629 L
.95589 .46601 L
.95431 .47572 L
.95163 .48441 L
.95127 .48543 L
.94743 .49514 L
.9454 .50486 L
.9424 .51457 L
.94192 .51609 L
.93879 .52428 L
.93644 .53399 L
.93342 .54371 L
.93221 .54755 L
.93001 .55342 L
.92558 .56313 L
.92438 .57284 L
.92249 .57881 L
.92111 .58256 L
.91691 .59227 L
.91528 .60198 L
.91278 .60985 L
.91211 .61169 L
.90808 .62141 L
.90611 .63112 L
.90307 .64066 L
.90301 .64083 L
.89909 .65054 L
.89688 .66026 L
.89376 .66997 L
.89336 .67121 L
.88999 .67968 L
.88758 .68939 L
.88445 .69911 L
.88364 .70155 L
.88077 .70882 L
.87821 .71853 L
.87506 .72824 L
.87393 .73165 L
.87145 .73796 L
.86672 .74767 L
Mistroke
.8656 .75738 L
.86422 .76153 L
.86203 .76709 L
.85737 .77681 L
.85606 .78652 L
.85451 .79118 L
.85252 .79623 L
.84788 .80594 L
.84646 .81566 L
.84479 .82059 L
.8429 .82537 L
.83826 .83508 L
.83677 .84479 L
.83508 .84976 L
.83319 .85451 L
.8285 .86422 L
.827 .87393 L
.82537 .8787 L
.82337 .88364 L
.8186 .89336 L
.81715 .90307 L
.81566 .90739 L
.81345 .91278 L
.80855 .92249 L
.80722 .93221 L
.80594 .93584 L
.80341 .94192 L
.80056 .95163 L
.79719 .96134 L
.79623 .96405 L
.79325 .97106 L
.79047 .98077 L
Mfstroke
.7 g
.98077 .48093 m
.97944 .48543 L
.97651 .49514 L
.97351 .50486 L
.97106 .51277 L
.97049 .51457 L
.96749 .52428 L
.96552 .53399 L
.96159 .54371 L
.96134 .54438 L
.95852 .55342 L
.95693 .56313 L
.95272 .57284 L
.95163 .57578 L
.9495 .58256 L
.94833 .59227 L
.94381 .60198 L
.94192 .60695 L
.94041 .61169 L
.93734 .62141 L
.93486 .63112 L
.93221 .63787 L
.93125 .64083 L
.92816 .65054 L
.92584 .66026 L
.92249 .66855 L
.92203 .66997 L
.91891 .67968 L
.91676 .68939 L
.91278 .69898 L
.91274 .69911 L
.9096 .70882 L
.9076 .71853 L
.90343 .72824 L
.90307 .72919 L
.90021 .73796 L
.89835 .74767 L
.89404 .75738 L
.89336 .75916 L
.89074 .76709 L
.88899 .77681 L
.88457 .78652 L
.88364 .78888 L
.8812 .79623 L
.87951 .80594 L
.875 .81566 L
.87393 .81836 L
.87158 .82537 L
.86991 .83508 L
.86533 .84479 L
.86422 .84758 L
.86188 .85451 L
.86016 .86422 L
.85556 .87393 L
.85451 .87655 L
.85209 .88364 L
.85028 .89336 L
.84568 .90307 L
.84479 .90527 L
.84221 .91278 L
.84026 .92249 L
.83569 .93221 L
.83508 .93372 L
.83224 .94192 L
.8301 .95163 L
.8256 .96134 L
.82537 .96191 L
.82217 .97106 L
.81981 .98077 L
.98077 .98077 L
F
0 g
.98077 .48093 m
.97944 .48543 L
.97651 .49514 L
.97351 .50486 L
.97106 .51277 L
.97049 .51457 L
.96749 .52428 L
.96552 .53399 L
.96159 .54371 L
.96134 .54438 L
.95852 .55342 L
.95693 .56313 L
.95272 .57284 L
.95163 .57578 L
.9495 .58256 L
.94833 .59227 L
.94381 .60198 L
.94192 .60695 L
.94041 .61169 L
.93734 .62141 L
.93486 .63112 L
.93221 .63787 L
.93125 .64083 L
.92816 .65054 L
.92584 .66026 L
.92249 .66855 L
.92203 .66997 L
.91891 .67968 L
.91676 .68939 L
.91278 .69898 L
.91274 .69911 L
.9096 .70882 L
.9076 .71853 L
.90343 .72824 L
.90307 .72919 L
.90021 .73796 L
.89835 .74767 L
.89404 .75738 L
.89336 .75916 L
.89074 .76709 L
.88899 .77681 L
.88457 .78652 L
.88364 .78888 L
.8812 .79623 L
.87951 .80594 L
.875 .81566 L
.87393 .81836 L
.87158 .82537 L
.86991 .83508 L
.86533 .84479 L
Mistroke
.86422 .84758 L
.86188 .85451 L
.86016 .86422 L
.85556 .87393 L
.85451 .87655 L
.85209 .88364 L
.85028 .89336 L
.84568 .90307 L
.84479 .90527 L
.84221 .91278 L
.84026 .92249 L
.83569 .93221 L
.83508 .93372 L
.83224 .94192 L
.8301 .95163 L
.8256 .96134 L
.82537 .96191 L
.82217 .97106 L
.81981 .98077 L
Mfstroke
.6 g
.98077 .50528 m
.978 .51457 L
.97504 .52428 L
.97158 .53399 L
.97106 .53727 L
.96941 .54371 L
.96638 .55342 L
.96323 .56313 L
.96134 .56904 L
.96042 .57284 L
.95748 .58256 L
.95431 .59227 L
.95163 .60057 L
.95131 .60198 L
.9485 .61169 L
.94533 .62141 L
.94216 .63112 L
.94192 .63188 L
.93944 .64083 L
.93629 .65054 L
.93309 .66026 L
.93221 .66296 L
.93031 .66997 L
.92717 .67968 L
.92394 .68939 L
.92249 .69381 L
.92109 .69911 L
.91798 .70882 L
.91473 .71853 L
.91278 .72442 L
.91178 .72824 L
.90872 .73796 L
.90545 .74767 L
.90307 .75479 L
.90241 .75738 L
.89938 .76709 L
.89609 .77681 L
.89336 .78493 L
.89295 .78652 L
.88996 .79623 L
.88666 .80594 L
.88364 .81482 L
.88344 .81566 L
.88047 .82537 L
.87715 .83508 L
.87393 .84448 L
.87385 .84479 L
.8709 .85451 L
.86756 .86422 L
.86422 .87389 L
.86421 .87393 L
.86124 .88364 L
.85788 .89336 L
.85451 .90306 L
.8545 .90307 L
.85151 .91278 L
.84812 .92249 L
.84479 .93198 L
.84473 .93221 L
.84169 .94192 L
.83827 .95163 L
.83508 .96064 L
.83489 .96134 L
.83177 .97106 L
.82832 .98077 L
.98077 .98077 L
F
0 g
.98077 .50528 m
.978 .51457 L
.97504 .52428 L
.97158 .53399 L
.97106 .53727 L
.96941 .54371 L
.96638 .55342 L
.96323 .56313 L
.96134 .56904 L
.96042 .57284 L
.95748 .58256 L
.95431 .59227 L
.95163 .60057 L
.95131 .60198 L
.9485 .61169 L
.94533 .62141 L
.94216 .63112 L
.94192 .63188 L
.93944 .64083 L
.93629 .65054 L
.93309 .66026 L
.93221 .66296 L
.93031 .66997 L
.92717 .67968 L
.92394 .68939 L
.92249 .69381 L
.92109 .69911 L
.91798 .70882 L
.91473 .71853 L
.91278 .72442 L
.91178 .72824 L
.90872 .73796 L
.90545 .74767 L
.90307 .75479 L
.90241 .75738 L
.89938 .76709 L
.89609 .77681 L
.89336 .78493 L
.89295 .78652 L
.88996 .79623 L
.88666 .80594 L
.88364 .81482 L
.88344 .81566 L
.88047 .82537 L
.87715 .83508 L
.87393 .84448 L
.87385 .84479 L
.8709 .85451 L
.86756 .86422 L
.86422 .87389 L
Mistroke
.86421 .87393 L
.86124 .88364 L
.85788 .89336 L
.85451 .90306 L
.8545 .90307 L
.85151 .91278 L
.84812 .92249 L
.84479 .93198 L
.84473 .93221 L
.84169 .94192 L
.83827 .95163 L
.83508 .96064 L
.83489 .96134 L
.83177 .97106 L
.82832 .98077 L
Mfstroke
.5 g
.98077 .52551 m
.97615 .53399 L
.97451 .54371 L
.97221 .55342 L
.97106 .55758 L
.96943 .56313 L
.96647 .57284 L
.96345 .58256 L
.96134 .58942 L
.96052 .59227 L
.95756 .60198 L
.95453 .61169 L
.95163 .62104 L
.95153 .62141 L
.94859 .63112 L
.94555 .64083 L
.94251 .65054 L
.94192 .65243 L
.93956 .66026 L
.9365 .66997 L
.93343 .67968 L
.93221 .68359 L
.93045 .68939 L
.9274 .69911 L
.9243 .70882 L
.92249 .71453 L
.92128 .71853 L
.91822 .72824 L
.9151 .73796 L
.91278 .74523 L
.91204 .74767 L
.90897 .75738 L
.90584 .76709 L
.90307 .77569 L
.90273 .77681 L
.89966 .78652 L
.8965 .79623 L
.89336 .80592 L
.89335 .80594 L
.89027 .81566 L
.88709 .82537 L
.88391 .83508 L
.88364 .83591 L
.88081 .84479 L
.87761 .85451 L
.8744 .86422 L
.87393 .86566 L
.87128 .87393 L
.86805 .88364 L
.86482 .89336 L
.86422 .89517 L
.86166 .90307 L
.85842 .91278 L
.85516 .92249 L
.85451 .92444 L
.85197 .93221 L
.8487 .94192 L
.84541 .95163 L
.84479 .95346 L
.84219 .96134 L
.83889 .97106 L
.83558 .98077 L
.98077 .98077 L
F
0 g
.98077 .52551 m
.97615 .53399 L
.97451 .54371 L
.97221 .55342 L
.97106 .55758 L
.96943 .56313 L
.96647 .57284 L
.96345 .58256 L
.96134 .58942 L
.96052 .59227 L
.95756 .60198 L
.95453 .61169 L
.95163 .62104 L
.95153 .62141 L
.94859 .63112 L
.94555 .64083 L
.94251 .65054 L
.94192 .65243 L
.93956 .66026 L
.9365 .66997 L
.93343 .67968 L
.93221 .68359 L
.93045 .68939 L
.9274 .69911 L
.9243 .70882 L
.92249 .71453 L
.92128 .71853 L
.91822 .72824 L
.9151 .73796 L
.91278 .74523 L
.91204 .74767 L
.90897 .75738 L
.90584 .76709 L
.90307 .77569 L
.90273 .77681 L
.89966 .78652 L
.8965 .79623 L
.89336 .80592 L
.89335 .80594 L
.89027 .81566 L
.88709 .82537 L
.88391 .83508 L
.88364 .83591 L
.88081 .84479 L
.87761 .85451 L
.8744 .86422 L
.87393 .86566 L
.87128 .87393 L
.86805 .88364 L
.86482 .89336 L
Mistroke
.86422 .89517 L
.86166 .90307 L
.85842 .91278 L
.85516 .92249 L
.85451 .92444 L
.85197 .93221 L
.8487 .94192 L
.84541 .95163 L
.84479 .95346 L
.84219 .96134 L
.83889 .97106 L
.83558 .98077 L
Mfstroke
.4 g
.98077 .54478 m
.97783 .55342 L
.97509 .56313 L
.97227 .57284 L
.97106 .57692 L
.96934 .58256 L
.96635 .59227 L
.96337 .60198 L
.96134 .60883 L
.96047 .61169 L
.95747 .62141 L
.95446 .63112 L
.95163 .64052 L
.95154 .64083 L
.94853 .65054 L
.94549 .66026 L
.94252 .66997 L
.94192 .67198 L
.93952 .67968 L
.93647 .68939 L
.93344 .69911 L
.93221 .70321 L
.93045 .70882 L
.92738 .71853 L
.92432 .72824 L
.92249 .73422 L
.92132 .73796 L
.91823 .74767 L
.91514 .75738 L
.91278 .76499 L
.91212 .76709 L
.90901 .77681 L
.90589 .78652 L
.90307 .79554 L
.90285 .79623 L
.89972 .80594 L
.89658 .81566 L
.8935 .82537 L
.89336 .82584 L
.89037 .83508 L
.8872 .84479 L
.88408 .85451 L
.88364 .85591 L
.88094 .86422 L
.87774 .87393 L
.8746 .88364 L
.87393 .88575 L
.87143 .89336 L
.86821 .90307 L
.86504 .91278 L
.86422 .91534 L
.86185 .92249 L
.85861 .93221 L
.8554 .94192 L
.85451 .94469 L
.85219 .95163 L
.84892 .96134 L
.84569 .97106 L
.84479 .9738 L
.84245 .98077 L
.98077 .98077 L
F
0 g
.98077 .54478 m
.97783 .55342 L
.97509 .56313 L
.97227 .57284 L
.97106 .57692 L
.96934 .58256 L
.96635 .59227 L
.96337 .60198 L
.96134 .60883 L
.96047 .61169 L
.95747 .62141 L
.95446 .63112 L
.95163 .64052 L
.95154 .64083 L
.94853 .65054 L
.94549 .66026 L
.94252 .66997 L
.94192 .67198 L
.93952 .67968 L
.93647 .68939 L
.93344 .69911 L
.93221 .70321 L
.93045 .70882 L
.92738 .71853 L
.92432 .72824 L
.92249 .73422 L
.92132 .73796 L
.91823 .74767 L
.91514 .75738 L
.91278 .76499 L
.91212 .76709 L
.90901 .77681 L
.90589 .78652 L
.90307 .79554 L
.90285 .79623 L
.89972 .80594 L
.89658 .81566 L
.8935 .82537 L
.89336 .82584 L
.89037 .83508 L
.8872 .84479 L
.88408 .85451 L
.88364 .85591 L
.88094 .86422 L
.87774 .87393 L
.8746 .88364 L
.87393 .88575 L
.87143 .89336 L
.86821 .90307 L
.86504 .91278 L
Mistroke
.86422 .91534 L
.86185 .92249 L
.85861 .93221 L
.8554 .94192 L
.85451 .94469 L
.85219 .95163 L
.84892 .96134 L
.84569 .97106 L
.84479 .9738 L
.84245 .98077 L
Mfstroke
.3 g
.98077 .56501 m
.97839 .57284 L
.97552 .58256 L
.97259 .59227 L
.97106 .59722 L
.96956 .60198 L
.96647 .61169 L
.96342 .62141 L
.96134 .62922 L
.96075 .63112 L
.95764 .64083 L
.95454 .65054 L
.9518 .66026 L
.95163 .66099 L
.94876 .66997 L
.94562 .67968 L
.9427 .68939 L
.94192 .69253 L
.93981 .69911 L
.93665 .70882 L
.93361 .71853 L
.93221 .72385 L
.93079 .72824 L
.92762 .73796 L
.9245 .74767 L
.92249 .75494 L
.92171 .75738 L
.91852 .76709 L
.91535 .77681 L
.91278 .78581 L
.91255 .78652 L
.90935 .79623 L
.90615 .80594 L
.90326 .81566 L
.90307 .81644 L
.90011 .82537 L
.89688 .83508 L
.89389 .84479 L
.89336 .84683 L
.8908 .85451 L
.88754 .86422 L
.88447 .87393 L
.88364 .877 L
.88142 .88364 L
.87814 .89336 L
.875 .90307 L
.87393 .90693 L
.87196 .91278 L
.86865 .92249 L
.86547 .93221 L
.86422 .93662 L
.86242 .94192 L
.85909 .95163 L
.85588 .96134 L
.85451 .96607 L
.8528 .97106 L
.84945 .98077 L
.98077 .98077 L
F
0 g
.98077 .56501 m
.97839 .57284 L
.97552 .58256 L
.97259 .59227 L
.97106 .59722 L
.96956 .60198 L
.96647 .61169 L
.96342 .62141 L
.96134 .62922 L
.96075 .63112 L
.95764 .64083 L
.95454 .65054 L
.9518 .66026 L
.95163 .66099 L
.94876 .66997 L
.94562 .67968 L
.9427 .68939 L
.94192 .69253 L
.93981 .69911 L
.93665 .70882 L
.93361 .71853 L
.93221 .72385 L
.93079 .72824 L
.92762 .73796 L
.9245 .74767 L
.92249 .75494 L
.92171 .75738 L
.91852 .76709 L
.91535 .77681 L
.91278 .78581 L
.91255 .78652 L
.90935 .79623 L
.90615 .80594 L
.90326 .81566 L
.90307 .81644 L
.90011 .82537 L
.89688 .83508 L
.89389 .84479 L
.89336 .84683 L
.8908 .85451 L
.88754 .86422 L
.88447 .87393 L
.88364 .877 L
.88142 .88364 L
.87814 .89336 L
.875 .90307 L
.87393 .90693 L
.87196 .91278 L
.86865 .92249 L
.86547 .93221 L
Mistroke
.86422 .93662 L
.86242 .94192 L
.85909 .95163 L
.85588 .96134 L
.85451 .96607 L
.8528 .97106 L
.84945 .98077 L
Mfstroke
.2 g
.98077 .58937 m
.97997 .59227 L
.97722 .60198 L
.97433 .61169 L
.97117 .62141 L
.97106 .62174 L
.96749 .63112 L
.96532 .64083 L
.96237 .65054 L
.96134 .65385 L
.95898 .66026 L
.95457 .66997 L
.95352 .67968 L
.95163 .68577 L
.95033 .68939 L
.94623 .69911 L
.94461 .70882 L
.94192 .71749 L
.94155 .71853 L
.93768 .72824 L
.93564 .73796 L
.93261 .74767 L
.93221 .74895 L
.92895 .75738 L
.92661 .76709 L
.92357 .77681 L
.92249 .78019 L
.9201 .78652 L
.91556 .79623 L
.91446 .80594 L
.91278 .81122 L
.91112 .81566 L
.90681 .82537 L
.90529 .83508 L
.90307 .84202 L
.90204 .84479 L
.89788 .85451 L
.89605 .86422 L
.89336 .87261 L
.89287 .87393 L
.88882 .88364 L
.88675 .89336 L
.88364 .90296 L
.8836 .90307 L
.87963 .91278 L
.87738 .92249 L
.87422 .93221 L
.87393 .93306 L
.87033 .94192 L
.86793 .95163 L
.86475 .96134 L
.86422 .96293 L
.86092 .97106 L
.85842 .98077 L
.98077 .98077 L
F
0 g
.98077 .58937 m
.97997 .59227 L
.97722 .60198 L
.97433 .61169 L
.97117 .62141 L
.97106 .62174 L
.96749 .63112 L
.96532 .64083 L
.96237 .65054 L
.96134 .65385 L
.95898 .66026 L
.95457 .66997 L
.95352 .67968 L
.95163 .68577 L
.95033 .68939 L
.94623 .69911 L
.94461 .70882 L
.94192 .71749 L
.94155 .71853 L
.93768 .72824 L
.93564 .73796 L
.93261 .74767 L
.93221 .74895 L
.92895 .75738 L
.92661 .76709 L
.92357 .77681 L
.92249 .78019 L
.9201 .78652 L
.91556 .79623 L
.91446 .80594 L
.91278 .81122 L
.91112 .81566 L
.90681 .82537 L
.90529 .83508 L
.90307 .84202 L
.90204 .84479 L
.89788 .85451 L
.89605 .86422 L
.89336 .87261 L
.89287 .87393 L
.88882 .88364 L
.88675 .89336 L
.88364 .90296 L
.8836 .90307 L
.87963 .91278 L
.87738 .92249 L
.87422 .93221 L
.87393 .93306 L
.87033 .94192 L
.86793 .95163 L
Mistroke
.86475 .96134 L
.86422 .96293 L
.86092 .97106 L
.85842 .98077 L
Mfstroke
.3 g
.98077 .6823 m
.97867 .68939 L
.97571 .69911 L
.97271 .70882 L
.97106 .71416 L
.96969 .71853 L
.9667 .72824 L
.96438 .73796 L
.96134 .74578 L
.96075 .74767 L
.95772 .75738 L
.95569 .76709 L
.95176 .77681 L
.95163 .77715 L
.94869 .78652 L
.94698 .79623 L
.9428 .80594 L
.94192 .80832 L
.93959 .81566 L
.93824 .82537 L
.9338 .83508 L
.93221 .83925 L
.93043 .84479 L
.92945 .85451 L
.92473 .86422 L
.92249 .86994 L
.9212 .87393 L
.91809 .88364 L
.9156 .89336 L
.91278 .90039 L
.9119 .90307 L
.90876 .91278 L
.90639 .92249 L
.90307 .93059 L
.90253 .93221 L
.89937 .94192 L
.89709 .95163 L
.89336 .96054 L
.89309 .96134 L
.8899 .97106 L
.88769 .98077 L
.98077 .98077 L
F
0 g
.98077 .6823 m
.97867 .68939 L
.97571 .69911 L
.97271 .70882 L
.97106 .71416 L
.96969 .71853 L
.9667 .72824 L
.96438 .73796 L
.96134 .74578 L
.96075 .74767 L
.95772 .75738 L
.95569 .76709 L
.95176 .77681 L
.95163 .77715 L
.94869 .78652 L
.94698 .79623 L
.9428 .80594 L
.94192 .80832 L
.93959 .81566 L
.93824 .82537 L
.9338 .83508 L
.93221 .83925 L
.93043 .84479 L
.92945 .85451 L
.92473 .86422 L
.92249 .86994 L
.9212 .87393 L
.91809 .88364 L
.9156 .89336 L
.91278 .90039 L
.9119 .90307 L
.90876 .91278 L
.90639 .92249 L
.90307 .93059 L
.90253 .93221 L
.89937 .94192 L
.89709 .95163 L
.89336 .96054 L
.89309 .96134 L
.8899 .97106 L
.88769 .98077 L
s
.4 g
.98077 .70667 m
.98013 .70882 L
.97722 .71853 L
.97425 .72824 L
.97119 .73796 L
.97106 .73865 L
.96864 .74767 L
.96555 .75738 L
.9624 .76709 L
.96134 .77042 L
.95969 .77681 L
.95664 .78652 L
.95348 .79623 L
.95163 .80196 L
.95065 .80594 L
.94767 .81566 L
.94449 .82537 L
.94192 .83327 L
.94149 .83508 L
.93862 .84479 L
.93543 .85451 L
.93225 .86422 L
.93221 .86434 L
.9295 .87393 L
.92631 .88364 L
.92309 .89336 L
.92249 .89519 L
.9203 .90307 L
.91712 .91278 L
.91387 .92249 L
.91278 .9258 L
.91102 .93221 L
.90785 .94192 L
.90458 .95163 L
.90307 .95618 L
.90166 .96134 L
.89851 .97106 L
.89522 .98077 L
.98077 .98077 L
F
0 g
.98077 .70667 m
.98013 .70882 L
.97722 .71853 L
.97425 .72824 L
.97119 .73796 L
.97106 .73865 L
.96864 .74767 L
.96555 .75738 L
.9624 .76709 L
.96134 .77042 L
.95969 .77681 L
.95664 .78652 L
.95348 .79623 L
.95163 .80196 L
.95065 .80594 L
.94767 .81566 L
.94449 .82537 L
.94192 .83327 L
.94149 .83508 L
.93862 .84479 L
.93543 .85451 L
.93225 .86422 L
.93221 .86434 L
.9295 .87393 L
.92631 .88364 L
.92309 .89336 L
.92249 .89519 L
.9203 .90307 L
.91712 .91278 L
.91387 .92249 L
.91278 .9258 L
.91102 .93221 L
.90785 .94192 L
.90458 .95163 L
.90307 .95618 L
.90166 .96134 L
.89851 .97106 L
.89522 .98077 L
s
.5 g
.98077 .7269 m
.98037 .72824 L
.97574 .73796 L
.97396 .74767 L
.9715 .75738 L
.97106 .75896 L
.96866 .76709 L
.96567 .77681 L
.96266 .78652 L
.96134 .79081 L
.95975 .79623 L
.95676 .80594 L
.95373 .81566 L
.95163 .82243 L
.95077 .82537 L
.94779 .83508 L
.94474 .84479 L
.94192 .85382 L
.94172 .85451 L
.93875 .86422 L
.93569 .87393 L
.93262 .88364 L
.93221 .88498 L
.92965 .89336 L
.92657 .90307 L
.92348 .91278 L
.92249 .91591 L
.92048 .92249 L
.91739 .93221 L
.91428 .94192 L
.91278 .94661 L
.91124 .95163 L
.90814 .96134 L
.905 .97106 L
.90307 .97707 L
.90193 .98077 L
.98077 .98077 L
F
0 g
.98077 .7269 m
.98037 .72824 L
.97574 .73796 L
.97396 .74767 L
.9715 .75738 L
.97106 .75896 L
.96866 .76709 L
.96567 .77681 L
.96266 .78652 L
.96134 .79081 L
.95975 .79623 L
.95676 .80594 L
.95373 .81566 L
.95163 .82243 L
.95077 .82537 L
.94779 .83508 L
.94474 .84479 L
.94192 .85382 L
.94172 .85451 L
.93875 .86422 L
.93569 .87393 L
.93262 .88364 L
.93221 .88498 L
.92965 .89336 L
.92657 .90307 L
.92348 .91278 L
.92249 .91591 L
.92048 .92249 L
.91739 .93221 L
.91428 .94192 L
.91278 .94661 L
.91124 .95163 L
.90814 .96134 L
.905 .97106 L
.90307 .97707 L
.90193 .98077 L
s
.6 g
.98077 .74617 m
.98015 .74767 L
.97709 .75738 L
.97435 .76709 L
.97151 .77681 L
.97106 .7783 L
.96855 .78652 L
.96556 .79623 L
.9626 .80594 L
.96134 .81021 L
.95968 .81566 L
.95667 .82537 L
.95367 .83508 L
.95163 .8419 L
.95074 .84479 L
.94772 .85451 L
.94469 .86422 L
.94192 .87336 L
.94174 .87393 L
.93871 .88364 L
.93566 .89336 L
.93266 .90307 L
.93221 .9046 L
.92964 .91278 L
.92656 .92249 L
.92352 .93221 L
.92249 .9356 L
.9205 .94192 L
.9174 .95163 L
.91433 .96134 L
.91278 .96638 L
.9113 .97106 L
.90818 .98077 L
.98077 .98077 L
F
0 g
.98077 .74617 m
.98015 .74767 L
.97709 .75738 L
.97435 .76709 L
.97151 .77681 L
.97106 .7783 L
.96855 .78652 L
.96556 .79623 L
.9626 .80594 L
.96134 .81021 L
.95968 .81566 L
.95667 .82537 L
.95367 .83508 L
.95163 .8419 L
.95074 .84479 L
.94772 .85451 L
.94469 .86422 L
.94192 .87336 L
.94174 .87393 L
.93871 .88364 L
.93566 .89336 L
.93266 .90307 L
.93221 .9046 L
.92964 .91278 L
.92656 .92249 L
.92352 .93221 L
.92249 .9356 L
.9205 .94192 L
.9174 .95163 L
.91433 .96134 L
.91278 .96638 L
.9113 .97106 L
.90818 .98077 L
s
.7 g
.98077 .7664 m
.98055 .76709 L
.97763 .77681 L
.97475 .78652 L
.9718 .79623 L
.97106 .79861 L
.96875 .80594 L
.96564 .81566 L
.96267 .82537 L
.96134 .8306 L
.95993 .83508 L
.95681 .84479 L
.95375 .85451 L
.95163 .86237 L
.95105 .86422 L
.94792 .87393 L
.94481 .88364 L
.94205 .89336 L
.94192 .89392 L
.93897 .90307 L
.93582 .91278 L
.93289 .92249 L
.93221 .92523 L
.92995 .93221 L
.92677 .94192 L
.92373 .95163 L
.92249 .95632 L
.92087 .96134 L
.91767 .97106 L
.91455 .98077 L
.98077 .98077 L
F
0 g
.98077 .7664 m
.98055 .76709 L
.97763 .77681 L
.97475 .78652 L
.9718 .79623 L
.97106 .79861 L
.96875 .80594 L
.96564 .81566 L
.96267 .82537 L
.96134 .8306 L
.95993 .83508 L
.95681 .84479 L
.95375 .85451 L
.95163 .86237 L
.95105 .86422 L
.94792 .87393 L
.94481 .88364 L
.94205 .89336 L
.94192 .89392 L
.93897 .90307 L
.93582 .91278 L
.93289 .92249 L
.93221 .92523 L
.92995 .93221 L
.92677 .94192 L
.92373 .95163 L
.92249 .95632 L
.92087 .96134 L
.91767 .97106 L
.91455 .98077 L
s
.8 g
.98077 .79075 m
.97924 .79623 L
.97647 .80594 L
.97353 .81566 L
.97106 .82311 L
.97026 .82537 L
.96636 .83508 L
.96454 .84479 L
.96158 .85451 L
.96134 .85525 L
.95793 .86422 L
.9557 .87393 L
.95272 .88364 L
.95163 .88715 L
.94933 .89336 L
.94492 .90307 L
.94381 .91278 L
.94192 .91885 L
.9406 .92249 L
.93647 .93221 L
.93484 .94192 L
.93221 .95034 L
.93174 .95163 L
.92782 .96134 L
.9258 .97106 L
.92276 .98077 L
.98077 .98077 L
F
0 g
.98077 .79075 m
.97924 .79623 L
.97647 .80594 L
.97353 .81566 L
.97106 .82311 L
.97026 .82537 L
.96636 .83508 L
.96454 .84479 L
.96158 .85451 L
.96134 .85525 L
.95793 .86422 L
.9557 .87393 L
.95272 .88364 L
.95163 .88715 L
.94933 .89336 L
.94492 .90307 L
.94381 .91278 L
.94192 .91885 L
.9406 .92249 L
.93647 .93221 L
.93484 .94192 L
.93221 .95034 L
.93174 .95163 L
.92782 .96134 L
.9258 .97106 L
.92276 .98077 L
s
.7 g
.98077 .88367 m
.97789 .89336 L
.97492 .90307 L
.97191 .91278 L
.97106 .91554 L
.9689 .92249 L
.9678 .93221 L
.96332 .94192 L
.96134 .94717 L
.95994 .95163 L
.95692 .96134 L
.95456 .97106 L
.95163 .97838 L
.95093 .98077 L
.98077 .98077 L
F
0 g
.98077 .88367 m
.97789 .89336 L
.97492 .90307 L
.97191 .91278 L
.97106 .91554 L
.9689 .92249 L
.9678 .93221 L
.96332 .94192 L
.96134 .94717 L
.95994 .95163 L
.95692 .96134 L
.95456 .97106 L
.95163 .97838 L
.95093 .98077 L
s
.6 g
.98077 .90805 m
.97937 .91278 L
.97644 .92249 L
.97147 .93221 L
.97106 .94004 L
.97064 .94192 L
.96784 .95163 L
.96471 .96134 L
.96158 .97106 L
.96134 .9718 L
.95892 .98077 L
.98077 .98077 L
F
0 g
.98077 .90805 m
.97937 .91278 L
.97644 .92249 L
.97147 .93221 L
.97106 .94004 L
.97064 .94192 L
.96784 .95163 L
.96471 .96134 L
.96158 .97106 L
.96134 .9718 L
.95892 .98077 L
s
.5 g
.98077 .92828 m
.97735 .93221 L
.97533 .94192 L
.97337 .95163 L
.97106 .96035 L
.97077 .96134 L
.96787 .97106 L
.96487 .98077 L
.98077 .98077 L
F
0 g
.98077 .92828 m
.97735 .93221 L
.97533 .94192 L
.97337 .95163 L
.97106 .96035 L
.97077 .96134 L
.96787 .97106 L
.96487 .98077 L
s
.4 g
.98077 .94755 m
.97923 .95163 L
.97637 .96134 L
.97361 .97106 L
.97106 .97969 L
.97073 .98077 L
.98077 .98077 L
F
0 g
.98077 .94755 m
.97923 .95163 L
.97637 .96134 L
.97361 .97106 L
.97106 .97969 L
.97073 .98077 L
s
.3 g
.98077 .96778 m
.97975 .97106 L
.97687 .98077 L
.98077 .98077 L
F
0 g
.98077 .96778 m
.97975 .97106 L
.97687 .98077 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00`_ooool2o`0000;ooooo0_l0
002Pooooo`00`_ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgJ3ooooo0033ooooo`04omgMgOl0
003o410@olc<c:7ooooo0033ooooo`04onk^k_lQ8B7o410@onk^kZ7ooooo0033ooooo`04ob4Q8Omg
MgOoMgMgoc8b<Z7ooooo0032ooooo`;o00000_ooool2o`000:3ooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0011oooo
o`;o000000?o410@ooooooooool08oooool5o`00023ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0T
ooooo`Go00009_ooool2o`000003oa0@4?oooooooooo02?ooooo00Gok^k^oc8b<_l0003o410@olc<
c00Tooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`08Oooool4o`000008oa0@4?ooooooooooonk^k_lb
<S;o0000oc8b<_o^k^h3ooooo`00@_ooool00ol0003oooooooooo`0Tooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@08?ooool01OmgMgOoV9RHoooooonHV9SoMgMg02Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A00Wooooo`03o`000?oooooooooo02Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@0Tooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B408oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00oooool003Oooooo1_l00002ooooo`Go00007Oooool6o`0000?ooooo00?oV9RHob4Q
8Oo^k^h08Oooool01Ol@413ooooooooooooooooo410@02Gooooo00?oV9RHob4Q8Oo^k^h09Oooool5
o`0002Gooooo00Go0000ooooooooooooooooo`00000Tooooo`05o`000?ooooooooooooooool00000
8oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool003oooooo
00CoA4A4omgMgOoooooo0000:?ooool00onHV9So8B4Qonk^kP0Pooooo`05o`000?oooooooooooooo
ool000009_ooool00onHV9So8B4Qonk^kP0Tooooo`04odA4A?oMgMgoooooo`0002Kooooo00Go0000
oiRHV?ooooooV9RHob4Q8@0Tooooo`05oc8b<_nHV9SooooooiRHV?lb<S808oooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool003oooooo00CogMgMoeEEEOoooooo
0000:Oooool00omgMgOoIVIVooooo`0Oooooo`05o`000?ooooooooooooooool000009oooool00omg
MgOoIVIVooooo`0Sooooo`04omgMgOmEEEGoooooo`0002Kooooo00Go0000oeEEEOl0003o410@olc<
c00Tooooo`05olc<c?l0003o0000o`000?o<c<`08oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000000oooool0043ooooo00?oMgMgolc<c?l00000:_ooool00ol0003ooooo
ooooo`0Nooooo`05oa0@4?ooooooooooooooool@4100:?ooool00ol0003oooooooooo`0Sooooo`03
ogMgMoo<c<co000002Kooooo00?oEEEEohN7Qoooool09_ooool01Ol@413o^[Zjoooooonj^[[o410@
02?ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo0010oooo
o`03onk^k_m4A4Co000002Kooooo00Go0000okZj^_ooooooV9RHoa0@400Pooooo`05ogMgMonHV9So
oooooiRHV?mgMgL09?ooool01Ol0003o^[ZjoooooonHV9So410@02Gooooo00?ok^k^odA4A?l00000
9_ooool00ooMgMgo410@oiRHV00Vooooo`05o`000?nj^[[ooooookZj^_l000008oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool0047ooooo00?oMgMgo`000?oo
ool09Oooool01OnHV9So410@o`000?lQ8B7oc<c<023ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0T
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`09_ooool00omgMgOo0000ooooo`0Vooooo`04olc<c?m4
A4Co0000oa0@42Cooooo00GoZJVYoa0@4?l0003o410@ojVYZ@0Qooooo`03oeEEEOmVIVKo000000Co
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`009?ooooooo`0004?o00000_ooool002Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`7o00000Oooool1ooooo`009?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo0Ol00001ooooo`7ooooo000T
ooooo`03o`000?oooooooooo0?oooooo?oooool1o`00007ooooo0Oooool002Cooooo00?o0000oooo
ooooool0ooooooloooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`3oooooocoo
oooo0Ol00001ooooo`7ooooo000Tooooo`;o00007?ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Co
oooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool0
0ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooooooo
ool00002ooooo`05o`000?ooooooooooooooool000002?ooool01ol0003ooooooooooooooooo0000
ooooool000000_ooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00Kooooo00Ko0000
oooooooooooo0000ooooool00002ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool0
1_ooool03?l0003oooooooooool0003oooooo`000?oooooo0000ooooool0003oooooo`0000Wooooo
00Wo0000ooooool0003oooooo`000?oooooo0000ooooool000000_ooool00ol0003oooooooooo`05
ooooo`;o00000_ooool002Cooooo00?o0000ooooooooool00ooooolHoda<C003o`000?mVIVKoIVIV
00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0:oiVIV@03o`000?nc/k?o/k>c
01Ko/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`06ogmoO`03o`000?mVIVKoIVIV
00KoIVIV00?o0000oda<C?m<C4`04om<C4`00ol0003oIVIVofIVIP03ofIVIP03o`000?moOgooOgmo
00;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000006ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000
ok>c/onc/k<01?nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Go0000ofIVI_mVIVKoIVIV
o`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04
o`000?moOgooOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c007o`000?nc/k?o
/k>cok>c/ol0003oVIVIo`000002ogmoO`03o`000?mVIVKo000000?oC4a<00?o0000oc<c<olc<c<0
1_lc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0
003oc<c<olc<c006olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<
C4co00002Olc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c/`03o`00
0?o<c<coc<c<00Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo5om<
C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02_nI
VIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl01omo
Ogl00ol0003oIVIVofIVIP05ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH00_mV
IVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01?nc
/k<00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c00?o/k>c00Go0000oiVIVOnIVIWoVIVI
o`000002ogmoO`05o`000?mVIVKoIVIVofIVI_l000001?m<C4`00ol0003o<c<coc<c<`06oc<c<`05
o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@04o`000?nc/k?o
/k>co`0000Woc<c<00Co0000ok>c/onc/k?o00000_nIVIT01_l0003oOgmoogmoOol0003oIVIVo`00
00?oC4a<00?o0000oc<c<olc<c<01_lc<c<02?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000
0_nIVIT00ol0003o/k>co`000009olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003o
IVIVo`000?m<C4co00002Olc<c<02ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc
/k?o000000?oc<c<1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00ooooolF
oda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0;
oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`07
ogmoO`03o`000?mVIVKoIVIV00KoIVIV00?o0000oda<C?m<C4`04om<C4`00ol0003oIVIVofIVIP03
ofIVIP03o`000?moOgooOgmo00;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000006ok>c/`03o`000?o<
c<coc<c<00?oc<c<00?o0000ok>c/onc/k<01?nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo
00Go0000ofIVI_mVIVKoIVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<
C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`00
0008olc<c007o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000002ogmoO`03o`000?mVIVKo000000?o
C4a<00?o0000oc<c<olc<c<01_lc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00?o0000
oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000
ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<00ol0003oC4a<oda<C002o`00
0007ogmoOol0003oVIVIoiVIVOl0003o/k>co`000003olc<c0Kooooo0Ol00001ooooo`7ooooo000T
ooooo`03o`000?oooooooooo00?ooooo5?m<C4`2o`0000goIVIV00?o0000ogmoOomoOgl02?moOgl2
o`0000coVIVI0_l0000Gok>c/`;o00003OnIVIT00ol0003oOgmoogmoO`07ogmoO`03o`000?mVIVKo
IVIV00GoIVIV0_l0000Foda<C003o`000?mVIVKoIVIV00;oIVIV00?o0000ogmoOomoOgl00_moOgl0
0ol0003oVIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`00oo<c<`0
0ol0003o/k>cok>c/`03ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01?l0003oIVIVofIV
I_l00004oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04
o`000?moOgooOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c004o`000?nc/k?o
/k>co`0000;oVIVI00Ko0000ogmoOomoOgoo0000ofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko
<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`05o`000?nIVIWo0000ok>c/ol000002Oo<
c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o
<c<c00Ko<c<c00_o0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`000004olc<
c0Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo4om<C4`00ol0003o
IVIVofIVIP0<ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o
/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl01omoOgl00ol0003o
IVIVofIVIP06ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003o
OgmoogmoO`02ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001onc/k<00ol0003oc<c<olc<c002olc<
c003o`000?nc/k?o/k>c00Co/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`04o`000?mVIVKo
IVIVo`0000CoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mV
IVKoIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c004
o`000?nc/k?o/k>co`0000;oVIVI00Ko0000ogmoOomoOgoo0000ofIVI_l00003oda<C003o`000?lc
<c?o<c<c00Ko<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`05o`000?nIVIWo0000ok>c
/ol000002Oo<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003
o`000?lc<c?o<c<c00Go<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000
ok>c/ol00004olc<c0Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo
4_m<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT0
2onIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl0
2?moOgl00ol0003oIVIVofIVIP05ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH0
0omVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<0
1?nc/k<00ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c00Co/k>c00Go0000oiVIVOnIVIWo
VIVIo`000003ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0
003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01Ol0003o/k>cok>c
/onc/k?o000000Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT01_l0003oOgmoogmoOol0003oIVIV
o`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP05o`000?mo
Ogoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c00:o`000?nc/k?o/k>co`000?nI
VIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<00ol0003oC4a<oda<
C002o`0000;oOgmo0_l00002ok>c/`03o`000?o<c<coc<c<00;oc<c<1_ooool1o`00007ooooo0Ooo
ool002Cooooo00?o0000ooooooooool00ooooolAoda<C0;o00003OmVIVH00ol0003oOgmoogmoO`08
ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0;
oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH01_mVIVH00ol0003oC4a<oda<C00D
oda<C003o`000?mVIVKoIVIV00;oIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@02
oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`04
ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000CoC4a<
00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;o
Ogmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>c
o`0000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`08o`000?m<
C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00[o0000
ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c
<`03o`000?m<C4coC4a<00;o000000CoOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c002
olc<c0Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo4?m<C4`00ol0
003oIVIVofIVIP0<ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0
003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0
003oIVIVofIVIP06ofIVIP03o`000?m<C4coC4a<01GoC4a<00?o0000ofIVI_mVIVH00_mVIVH00ol0
003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0
003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c00Co/k>c00Go0000oiVIVOnIVIWoVIVIo`000002
ogmoO`05o`000?mVIVKoIVIVofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`03o`000?m<
C4coC4a<00;oC4a<00Ko0000ofIVI_mVIVKo0000ogmoOol00002oiVIV@03o`000?nc/k?o/k>c00;o
/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo0000
00;oIVIV00Co0000oda<C?m<C4co00002Olc<c<02?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo
00000_nIVIT01?l0003o/k>cok>c/ol00008olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmo
Ool0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<00ol0003oC4a<oda<C002o`000004
ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`00_o<c<`6ooooo`7o00000Oooool1oooo
o`009?ooool00ol0003oooooooooo`03ooooo`ooC4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003o
OgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003o
VIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH01_mVIVH00ol0003o
C4a<oda<C00Eoda<C003o`000?mVIVKoIVIV00;oIVIV00?o0000ogmoOomoOgl00omoOgl01Ol0003o
VIVIoiVIVOnIVIWo000000Ko/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`04ok>c
/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000CoC4a<00?o
0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo
00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`00
00;oVIVI00Ko0000ogmoOomoOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c00So
0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`0
1ol0003o/k>co`000?nIVIWo0000ogmoOol000000_mVIVH00ol0003oC4a<o`000008oc<c<`05o`00
0?m<C4coC4a<o`000?mVIVH00_l000001OnIVIWo0000ok>c/onc/k?o000000Goc<c<1_ooool1o`00
007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool>oda<C0;o00003OmVIVH00ol0003o
OgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003o
VIVIoiVIV@0:oiVIV@;o00002_moOgl00ol0003oIVIVofIVIP07ofIVIP03o`000?m<C4coC4a<01Co
C4a<00?o0000ofIVI_mVIVH00_mVIVH2o`0000CoOgmo00Go0000oiVIVOnIVIWoVIVIo`000007ok>c
/`03o`000?o<c<coc<c<00;oc<c<00?o0000ok>c/onc/k<01?nc/k<01Ol0003oVIVIoiVIVOnIVIWo
000000?oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<
C4coC4a<oda<C?l000000omVIVH00ol0003oOgmoo`000002oiVIV@05o`000?nc/k?o/k>cok>c/ol0
00002?o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0
003oC4a<oda<C?l00008oc<c<`09o`000?m<C4coC4a<oda<C?l0003oIVIVo`000?moOgoo000000;o
VIVI00Co0000ok>c/onc/k?o00002?o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000
ofIVI_l0003oC4a<o`0000Wo<c<c00Co0000oda<C?l0003oIVIV0ol000001OnIVIWo0000ok>c/onc
/k?o000000Goc<c<1_ooool1o`00007ooooo0Oooool002Cooooo0_l00004ooooo`goC4a<00?o0000
ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000
ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000
ofIVI_mVIVH01omVIVH00ol0003oC4a<oda<C00Doda<C003o`000?mVIVKoIVIV00?oIVIV00?o0000
ogmoOomoOgl00omoOgl01Ol0003oVIVIoiVIVOnIVIWo000000Oo/k>c00?o0000olc<c?o<c<`00_o<
c<`00ol0003o/k>cok>c/`04ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01?l0003oIVIV
ofIVI_l00004oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000003ofIV
IP03o`000?moOgoo000000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c005o`000?nc/k?o
/k>cok>c/ol000000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c
00Wo0000oda<C?m<C4coC4a<o`000?mVIVKo0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol0
0008olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co00002Olc
<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<
00?oc<c<1Oooool2o`0000;ooooo000Tooooo`03o`000?oooooooooo00?ooooo3?m<C4`00ol0003o
IVIVofIVIP0<ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o
/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003o
IVIVofIVIP07ofIVIP03o`000?m<C4coC4a<01GoC4a<00?o0000ofIVI_mVIVH00_mVIVH00ol0003o
OgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003o
c<c<olc<c002olc<c003o`000?nc/k?o/k>c00Co/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmo
O`05o`000?mVIVKoIVIVofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4co
C4a<oda<C?l000000omVIVH00ol0003oOgmoo`000002oiVIV@05o`000?nc/k?o/k>cok>c/ol00000
2?o<c<`00ol0003o/k>cok>c/`02ok>c/`05o`000?nIVIWo0000ogmoOol000000_mVIVH01?l0003o
C4a<oda<C?l00009oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl00ol0003oVIVIo`00
0002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`;o
00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`03o`000?m<C4co000000;oIVIV0_l00002oiVIV@03
o`000?nc/k?o000000Koc<c<1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool0
0oooool<oda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVI
oiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02_nIVIT2o`0000[oOgmo
00?o0000ofIVI_mVIVH01omVIVH00ol0003oC4a<oda<C00Eoda<C003o`000?mVIVKoIVIV00?oIVIV
00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c00Go/k>c
00?o0000olc<c?o<c<`00_o<c<`00ol0003o/k>cok>c/`04ok>c/`05o`000?nIVIWoVIVIoiVIVOl0
00000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000CoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0
003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo00000onc
/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT00ol0003oOgmo
o`000002ofIVIP04o`000?m<C4coC4a<o`0000Wo<c<c00So0000oda<C?m<C4co0000ofIVI_l0003o
Ogmoo`0000;oVIVI00?o0000ok>c/ol000002Oo<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?mo
Ogoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00?o0000oda<C?l000000_mVIVH2
o`0000;oVIVI00?o0000ok>c/ol000001_o<c<`6ooooo`7o00000Oooool1ooooo`009?ooool00ol0
003oooooooooo`03ooooo`_oC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmo
O`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0:oiVI
V@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02?mVIVH00ol0003oC4a<oda<C00Eoda<
C003o`000?mVIVKoIVIV00?oIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@02oiVI
V@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`04ok>c
/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000CoC4a<00?o
0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo
00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c
/ol000000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000Wo<c<c00So0000
oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000;oVIVI00?o0000ok>c/ol000002Oo<c<`02_l0003o
/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c
00?o0000oda<C?l000000_mVIVH2o`0000;oVIVI00?o0000ok>c/ol000001_o<c<`6ooooo`7o0000
0Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`[oC4a<00?o0000ofIVI_mVIVH02omV
IVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc
/k<2o`0000coVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP08ofIVIP03o`000?m<
C4coC4a<01GoC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nI
VIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c002olc<c003o`000?nc
/k?o/k>c00Co/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`05o`000?mVIVKoIVIVofIVI_l0
00001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mV
IVKo00000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000
ok>c/onc/k?o/k>co`000002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co0000
2Olc<c<01?l0003oC4a<oda<C?l00002ofIVIP;o00000_nIVIT01?l0003o/k>cok>c/ol00008olc<
c004o`000?nc/k?o/k>co`0000;oVIVI0_l000001OmVIVKo0000oda<C?m<C4co000000So<c<c00co
0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00007olc<c0Kooooo0Ol0
0001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo2Om<C4`00ol0003oIVIVofIVIP0;
ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0F
ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP08
ofIVIP03o`000?m<C4coC4a<01GoC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`02
ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c002
olc<c003o`000?nc/k?o/k>c00Co/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`05o`000?mV
IVKoIVIVofIVI_l000001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<
00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<
00Koc<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo0000
0_m<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol0
00000_nIVIT01?l0003o/k>cok>c/ol00008olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmo
Ool0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01ol0003oC4a<oda<C?l0003oIVIV
o`000?moOgl00_l00002ok>c/`03o`000?o<c<coc<c<00Goc<c<1_ooool1o`00007ooooo0Oooool0
02Cooooo00?o0000ooooooooool00oooool8oda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmo
OomoOgl02?moOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVI
VOnIVIT02_nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00WoIVIV00?o0000oda<
C?m<C4`05Om<C4`00ol0003oIVIVofIVIP03ofIVIP03o`000?moOgooOgmo00;oOgmo00?o0000oiVI
VOnIVIT00_nIVIT00ol0003o/k>cok>c/`05ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o0000ok>c
/onc/k<01?nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Go0000ofIVI_mVIVKoIVIVo`00
0004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIV
I_l00002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01ol0003o
/k>cok>c/onc/k?o0000oiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00002oda<C003o`000?lc
<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`00
0?nc/k?o/k>co`0000Ooc<c<00_o0000ok>c/onc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIV
o`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Oo0000oda<C?m<C4co0000ofIVI_l0003oOgmo
00;o00000_nc/k<00ol0003oc<c<olc<c005olc<c0Kooooo0Ol00001ooooo`7ooooo000Tooooo`03
o`000?oooooooooo00?ooooo1om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00So
Ogmo00?o0000oiVIVOnIVIT02onIVIT2o`0001Oo/k>c0_l0000<oiVIV@03o`000?moOgooOgmo00Wo
Ogmo00?o0000ofIVI_mVIVH02OmVIVH00ol0003oC4a<oda<C00Eoda<C003o`000?mVIVKoIVIV00?o
IVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c00Go
/k>c00?o0000olc<c?o<c<`00_o<c<`00ol0003o/k>cok>c/`04ok>c/`05o`000?nIVIWoVIVIoiVI
VOl000000omoOgl01Ol0003oIVIVofIVI_mVIVKo000000CoC4a<00?o0000oc<c<olc<c<01Olc<c<0
0ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo0000
0onc/k<00ol0003oc<c<olc<c007olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol0
00000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000
ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00008olc<c008o`000?nc/k?o/k>co`000?nIVIWo
0000ogmoOol00002ofIVIP03o`000?m<C4co000000So<c<c00Oo0000oda<C?m<C4co0000ofIVI_l0
003oOgmo00;o00000_nc/k<00ol0003oc<c<olc<c006olc<c0Kooooo0Ol00001ooooo`7ooooo000K
ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`03ooooo`GoC4a<0_l0000<
ofIVIP;o00002_moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000
oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`;o00002omVIVH00ol0003oC4a<oda<C00E
oda<C003o`000?mVIVKoIVIV00?oIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@02
oiVIV@03o`000?nc/k?o/k>c00Ko/k>c00Go0000olc<c?o<c<coc<c<o`000007ok>c/`05o`000?nI
VIWoVIVIoiVIVOl000000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000CoC4a<00?o0000oc<c<olc
<c<01Olc<c<2o`0000?oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`04o`000?nIVIWoVIVI
o`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003o/k>cok>c/`02o`000005oiVIVOl0003o
OgmoogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`04o`000?m<C4coC4a<o`0000;o
IVIV00?o0000ogmoOol000000_nIVIT00ol0003o/k>co`000009olc<c00:o`000?nc/k?o/k>co`00
0?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01ol0003oC4a<
oda<C?l0003oIVIVo`000?moOgl00_l00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o0000oooo
ooooool00oooool1o`00007ooooo0Oooool001cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`03ooooo`GoC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`09ogmoO`03
o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03
o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Doda<C003
o`000?mVIVKoIVIV00CoIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@02oiVIV@03
o`000?nc/k?o/k>c00Ko/k>c00Go0000olc<c?o<c<coc<c<o`000006ok>c/`03o`000?nIVIWoVIVI
00;oVIVI00Co0000ogmoOomoOgoo00000omVIVH00ol0003oC4a<oda<C002oda<C003o`000?lc<c?o
<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Co
0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`0000;o
VIVI00Co0000ogmoOomoOgoo00000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`04o`000?m<C4co
C4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT00ol0003o/k>co`000009olc<c00:o`000?nc
/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<0
0ol0003oC4a<oda<C002o`0000;oOgmo0_l00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o0000
ooooooooool00oooool1o`00007ooooo0Oooool0017ooooo1_l00002ooooo`Go00001_ooool3o`00
00?ooooo1?m<C4`00ol0003oIVIVofIVIP0:ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVI
VOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmo
OomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIV
I_mVIVH01?mVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c
/onc/k<01_nc/k<01Ol0003oc<c<olc<c?o<c<co000000Oo/k>c00Go0000oiVIVOnIVIWoVIVIo`00
0002ogmoO`05o`000?mVIVKoIVIVofIVI_l000001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`00
0?m<C4coC4a<00;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`00
00?o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@04o`000?moOgoo
Ogmoo`0000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP08
o`000?moOgooOgmoo`000?nIVIWo0000ok>c/ol00009olc<c006o`000?nc/k?o/k>co`000?nIVIWo
00000_moOgl2o`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02_l0003oC4a<oda<C?l0003oIVIV
o`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ooooooooool0
0_ooool3o`0000;ooooo000Iooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool0
0oooool2oda<C0;o00003?mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI
00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo
00?o0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<oda<C00Doda<C003o`000?mVIVKoIVIV00CoIVIV
00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c00Ko/k>c
00Co0000olc<c?o<c<co00001onc/k<01?l0003oVIVIoiVIVOnIVIT2o`0000;oOgmo00Go0000ofIV
I_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`0
1?l0003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`0
1_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@06o`000?moOgooOgmoo`000?mVIVKo00000om<C4`0
0ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Go0000ogmoOol0003oVIVI
o`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmo
o`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo
0000ogmoOol0003oVIVIo`000?nc/k?o00002?o<c<`00ol0003oooooooooo`04ooooo`7o00000Ooo
ool1ooooo`006Oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo00?ooooo0_m<
C4`00ol0003oIVIVofIVIP0:ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onI
VIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI0_l0000:ogmoO`03o`000?mV
IVKoIVIV00[oIVIV00?o0000oda<C?m<C4`05Om<C4`00ol0003oIVIVofIVIP04ofIVIP03o`000?mo
OgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`06ok>c/`04o`000?o<
c<coc<c<o`0000Oo/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`05o`000?mVIVKoIVIVofIV
I_l000001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIV
I_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co
0000ok>c/onc/k?o00000_nIVIT01_l0003oOgmoogmoOol0003oIVIVo`0000?oC4a<00?o0000oc<c
<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc
/k<00ol0003oc<c<olc<c007olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIV
o`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<00ol0003oC4a<o`000002ofIVIP07o`000?moOgoo
0000oiVIVOl0003o/k>co`000008olc<c003o`000?oooooooooo00Cooooo0Ol00001ooooo`7ooooo
000Jooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool00oooool00om<C4co0000ofIV
IP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c
/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIV
IP0:ofIVIP03o`000?m<C4coC4a<01GoC4a<00?o0000ofIVI_mVIVH01?mVIVH00ol0003oOgmoogmo
O`02ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<01_nc/k<01?l0003oc<c<olc<
c?l00007ok>c/`05o`000?nIVIWoVIVIoiVIVOl000001?moOgl01?l0003oIVIVofIVI_l00005oda<
C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00om<C4`01?l0003oIVIVofIVI_l00002
ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c
/ol00002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<01Ol0
003oC4a<oda<C?m<C4co000000;oIVIV0_l000001OnIVIWo0000ok>c/onc/k?o000000Woc<c<00Co
0000ok>c/onc/k?o00000_nIVIT2o`000005ofIVI_l0003oC4a<oda<C?l000002?lc<c<02?l0003o
C4a<oda<C?l0003oIVIVo`000?moOgoo00000_nIVIT2o`0000Soc<c<00?o0000ok>c/oooool01Ooo
ool1o`00007ooooo0Oooool001[ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`03
ooooo`03o`000?mVIVKoIVIV00[oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0;
oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08
ogmoO`;o00003?mVIVH00ol0003oC4a<oda<C00Eoda<C0;o00001OmVIVH00ol0003oOgmoogmoO`03
ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01_nc/k<01?l0003oc<c<olc<c?l0
0007ok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`000002ofIVIP;o0000
1?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo
00000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c
/onc/k?o/k>co`000002oiVIV@06o`000?moOgooOgmoo`000?mVIVKo00000om<C4`00ol0003o<c<c
oc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c
/`03o`000?o<c<coc<c<00Ooc<c<00?o0000ok>c/ol000000_nIVIT01Ol0003oOgmoo`000?mVIVKo
000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo
0000oiVIVOl0003o/k>co`0000Soc<c<00?o0000ok>c/oooool01Oooool1o`00007ooooo0Oooool0
01_ooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`03ooooo`goIVIV00?o0000ogmo
OomoOgl02OmoOgl00ol0003oVIVIoiVIV@0:oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVI
VOnIVIT03?nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<
C?m<C4`05Om<C4`00ol0003oIVIVofIVIP04ofIVIP03o`000?moOgooOgmo00?oOgmo00?o0000oiVI
VOnIVIT00_nIVIT00ol0003o/k>cok>c/`07ok>c/`03o`000?o<c<co000000Oo/k>c00?o0000oiVI
VOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000;oIVIV00?o0000oda<C?m<C4`00om<C4`0
0ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Co0000ofIVI_mVIVKo00000_mo
Ogl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o
/k>co`000002oiVIV@06o`000?moOgooOgmoo`000?mVIVKo00000om<C4`00ol0003o<c<coc<c<`06
oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`00
0?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mVIVKo0000
00;oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?l0003oIVIV00;o00000_nIVIT0
0ol0003o/k>co`000008olc<c003o`000?nc/k?ooooo00Gooooo0Ol00001ooooo`7ooooo000Toooo
o`03o`000?oooooooooo00?ooooo3?mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI
00[oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo
00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Eoda<C003o`000?mVIVKoIVIV
00GoIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c
00Wo/k>c00?o0000ok>c/onc/k<01_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Go0000
ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<
C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003o
c<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT00ol0003oOgmoo`000002ofIV
IP04o`000?m<C4coC4a<o`0000Wo<c<c00Co0000oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`00
0?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@05
o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<
o`000?mVIVH00_l00002oiVIV@03o`000?nc/k?o000000Soc<c<00?o0000ok>c/ol000001Oooool1
o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool;ofIVIP03o`000?moOgooOgmo
00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI
00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<
01KoC4a<00?o0000ofIVI_mVIVH01?mVIVH00ol0003oOgmoogmoO`03ogmoO`05o`000?nIVIWoVIVI
oiVIVOl000005?nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000CoOgmo00Co0000ofIVI_mVIVKo0000
1Om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Co0000ofIVI_mVIVKo
00000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o0000ok>c
/onc/k<00_nc/k<00ol0003oVIVIo`000002ogmoO`03o`000?mVIVKo000000?oC4a<00?o0000oc<c
<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000
ok>c/onc/k?o00001oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV
00?o0000oda<C?l000002?lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0
003o/k>co`0000Soc<c<00Co0000ok>c/onc/k?o00001Oooool1o`00007ooooo0Oooool002Cooooo
00?o0000ooooooooool00oooool:ofIVIP03o`000?moOgooOgmo00SoOgmo0_l0000<oiVIV@;o0000
5onc/k<2o`0000goVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`00
0?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH01?mVIVH00ol0003oOgmoogmoO`03ogmoO`03o`00
0?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<04_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?o
Ogmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<
C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo00000onc
/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT00ol0003oOgmo
o`000002ofIVIP04o`000?m<C4coC4a<o`0000Wo<c<c00Co0000oda<C?m<C4co00000_mVIVH01Ol0
003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol0
0002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0<o`00
0?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00002?o<c<`01?l0003o/k>c
ok>c/ol00005ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`WoIVIV
00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c
00?o0000oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV
00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP04ofIVIP03o`000?moOgooOgmo00?oOgmo
00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0Bok>c/`05o`000?nIVIWoVIVIoiVIVOl0
00000omoOgl01Ol0003oIVIVofIVI_mVIVKo000000CoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0
003oC4a<oda<C002oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl0
0003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@03o`00
0?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<01?l0003oC4a<oda<C?l00002ofIV
IP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o
/k>co`0000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c
00?o0000oda<C?m<C4`00_l00002ogmoO`05o`000?nIVIWo0000ok>c/ol000002?o<c<`01?l0003o
/k>cok>c/ol00005ooooo`7o00000Oooool1ooooo`009?ooool2o`0000Cooooo2?mVIVH00ol0003o
OgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003o
VIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003o
C4a<oda<C00Foda<C003o`000?mVIVKoIVIV00GoIVIV00?o0000ogmoOomoOgl00omoOgl00ol0003o
VIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c01;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000004ogmo
O`04o`000?mVIVKoIVIVo`0000GoC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C002
oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`00
0?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@03o`000?moOgoo000000;o
IVIV00Co0000oda<C?m<C4co00002Olc<c<01?l0003oC4a<oda<C?l00002ofIVIP05o`000?moOgoo
0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c003o`000?nc/k?o000000;oVIVI00?o
0000ogmoOomoOgl00_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00[o0000oda<C?m<C4co0000
ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c003o`000?nc/k?o
000000Gooooo0_l00002ooooo`009?ooool00ol0003oooooooooo`03ooooo`OoIVIV00?o0000ogmo
OomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVI
VOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<
C?m<C4`05_m<C4`00ol0003oIVIVofIVIP05ofIVIP03o`000?moOgooOgmo00?oOgmo00?o0000oiVI
VOnIVIT00onIVIT00ol0003o/k>cok>c/`0Aok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000ogmo
OomoOgooOgmoo`000003ofIVIP03o`000?m<C4coC4a<00;oC4a<00?o0000oc<c<olc<c<01Olc<c<0
0ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Go0000oiVIVOnIVIWoVIVI
o`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@03
o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<2o`0000;oC4a<00?o0000ofIV
I_l000000_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00?o0000ok>c
/ol000000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<0
3?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Soc<c<00Co0000
ok>c/onc/k?o00001_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool6
ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0G
ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;
ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH01OmVIVH00ol0003oOgmoogmoO`03
ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<04_nc/k<00ol0003oVIVIoiVIV@02
oiVIV@05o`000?moOgooOgmoogmoOol000000omVIVH00ol0003oC4a<oda<C002oda<C003o`000?lc
<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00om<C4`01?l0003oIVIVofIVI_l00002ogmoO`05o`00
0?nIVIWoVIVIoiVIVOl000000onc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o
/k>c00Ko0000oiVIVOnIVIWo0000ogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Co
0000oda<C?m<C4co00000_mVIVH01_l0003oOgmoogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<
c?o<c<`01oo<c<`01Ol0003o/k>co`000?nIVIWo000000;oOgmo00?o0000ofIVI_l000000_m<C4`0
0ol0003o<c<coc<c<`06oc<c<`03o`000?m<C4co000000;oIVIV00Co0000ogmoOol0003o00000_nc
/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`0000Kooooo0Ol00001ooooo`7ooooo
000Tooooo`03o`000?oooooooooo00?ooooo1OmVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nI
VIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?mo
OgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mV
IVKoIVIV00GoIVIV00?o0000ogmoOomoOgl00omoOgl00ol0003oVIVIoiVIV@02oiVIV@03o`000?nc
/k?o/k>c01;o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000?oIVIV
00?o0000oda<C?m<C4`00_m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<
00Co0000ofIVI_mVIVKo00000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000?o/k>c00?o0000olc<
c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Ko0000ogmoOomoOgoo0000ofIV
I_l00003oda<C003o`000?lc<c?o<c<c00Go<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo0000
00;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c003o`000?nc/k?o0000
00;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00co0000
oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00009olc<c005o`000?nc/k?o
0000oiVIVOl000001Oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool4
ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0G
ok>c/`03o`000?nIVIWoVIVI00[oVIVI0_l0000:ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000
oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP05ofIVIP03o`000?moOgooOgmo00?oOgmo00?o0000
oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0Bok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omo
Ogl01Ol0003oIVIVofIVI_mVIVKo000000GoC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<
oda<C003oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0
003oc<c<olc<c005olc<c004o`000?nc/k?o/k>cok>c/`;o000000GoVIVIo`000?moOgooOgmoo`00
0002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo0000
00;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>c
o`0000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00co
0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00009olc<c0;o000000?o
VIVIo`000?ooool01Oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool3
ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0G
ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;
ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0003oOgmoogmoO`03
ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<04_nc/k<01Ol0003oVIVIoiVIVOnI
VIWo000000;oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C003oda<C003o`000?lc
<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00om<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`00
0?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`01Ol0003o/k>cok>c/onc/k?o0000
00;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`07o`000?m<
C4coC4a<oda<C?l0003oIVIVo`000002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<
c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`0
0ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<o`000?mVIVH00_l00002oiVIV@03o`000?nc
/k?o000000Woc<c<0_l000000onIVIWo0000ooooo`05ooooo`7o00000Oooool1ooooo`009?ooool0
0ol0003oooooooooo`03ooooo`;oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;
oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08
ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP06
ofIVIP03o`000?moOgooOgmo00?oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0B
ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01Ol0003oIVIVofIVI_mVIVKo000000GoC4a<
00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C003oda<C004o`000?mVIVKoIVIVo`0000;o
Ogmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>c
o`0000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`06o`00
0?m<C4coC4a<o`000?mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00002ok>c/`03o`000?o<c<co
c<c<00Koc<c<00?o0000ok>c/ol000000_nIVIT00ol0003oOgmoo`000002ofIVIP03o`000?m<C4co
000000So<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00009
olc<c005o`000?nc/k?o0000o`000?moOgl01_ooool1o`00007ooooo0Oooool002Cooooo00?o0000
ooooooooool00oooool00omVIVKo0000ogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000
ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0:oiVIV@;o00002_moOgl00ol0003oIVIVofIVIP0;
ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0003oOgmoogmoO`03
ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<04_nc/k<00ol0003oVIVIoiVIV@02
oiVIV@05o`000?moOgooOgmoogmoOol000000omVIVH00ol0003oC4a<oda<C002oda<C003o`000?lc
<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo
00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c007olc<c004o`000?nc/k?o/k>co`00
00;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`06o`000?m<
C4coC4a<o`000?mVIVKo00000_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ko
c<c<00Co0000ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000
oc<c<olc<c<01_lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>c
o`0000Soc<c<00?o0000ok>c/onc/k<00_l000000omoOgooooooooooo`04ooooo`7o00000Oooool1
ooooo`009?ooool00ol0003oooooooooo`03ooooo`03o`000?moOgooOgmo00SoOgmo00?o0000oiVI
VOnIVIT02onIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00[oVIVI00?o0000ogmo
OomoOgl02OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIV
I_mVIVH01omVIVH00ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c
/onc/k<04onc/k<00ol0003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol000000omVIVH0
0ol0003oC4a<oda<C002oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`0
1?l0003oIVIVofIVI_l00003ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`0
1_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01?l0
003oC4a<oda<C?l00009oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl00ol0003oVIVI
o`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT2o`0000;o
IVIV00Co0000oda<C?m<C4co00002?lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000
oiVIVOl0003o/k>co`0000Soc<c<00?o0000ok>c/onc/k<00_l000000omoOgooooooooooo`04oooo
o`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`[oOgmo00?o0000oiVIVOnI
VIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`;o00003?nIVIT00ol0003oOgmoogmoO`09ogmoO`03
o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP07ofIVIP03
o`000?moOgooOgmo00?oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0Bok>c/`03
o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`000003ofIVIP03o`000?m<C4coC4a<
00;oC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C005o`000?mVIVKoIVIV
ofIVI_l000000omoOgl01?l0003oVIVIoiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go
0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Co0000oda<C?m<
C4co00002Olc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00?o0000oiVIVOl000000_nc
/k<00ol0003oc<c<olc<c007olc<c003o`000?nc/k?o000000;oVIVI00Go0000ogmoOol0003oIVIV
o`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmo
o`000?nIVIWo0000ok>c/ol00009olc<c007o`000?nc/k?o0000oiVIVOl0003oOgmoo`000005oooo
o`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`WoOgmo00?o0000oiVIVOnI
VIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomo
Ogl02OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01SoC4a<00?o0000ofIVI_mV
IVH01_mVIVH00ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc
/k<04_nc/k<00ol0003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol000000omVIVH00ol0
003oC4a<oda<C003oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00om<C4`01?l0
003oIVIVofIVI_l00003ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<
c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Go0000ogmoOomoOgoo0000ofIVIP02o`0000;o
C4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo0000
00;oVIVI00?o0000ok>c/ol000002_o<c<`00ol0003o/k>co`000002oiVIV@05o`000?moOgoo0000
ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000
ogmoOol0003oVIVIo`000?nc/k?o00002?o<c<`02?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo
00001Oooool1o`00007ooooo0Oooool002Cooooo0_l00004ooooo`SoOgmo00?o0000oiVIVOnIVIT0
3?nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00[oVIVI00?o0000ogmoOomoOgl0
2OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01SoC4a<00?o0000ofIVI_mVIVH0
1omVIVH00ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<0
4_nc/k<00ol0003oVIVIoiVIV@02oiVIV@04o`000?moOgooOgmoo`0000CoIVIV00?o0000oda<C?m<
C4`00om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Co0000ofIVI_mV
IVKo00000omoOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Oo0000
ok>c/onc/k?o/k>co`000?nIVIWo000000?oOgmo00?o0000ofIVI_l000000om<C4`00ol0003o<c<c
oc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT00ol0003o
/k>co`00000:olc<c005o`000?nc/k?o0000oiVIVOl000000_moOgl00ol0003oIVIVo`000002oda<
C003o`000?lc<c?o<c<c00Ko<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo
0000ok>c/ol00008olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00004ooooo`;o0000
0_ooool002Cooooo00?o0000ooooooooool00oooool7ogmoO`03o`000?nIVIWoVIVI00_oVIVI0_l0
000Gok>c/`;o00003?nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o
0000oda<C?m<C4`06?m<C4`00ol0003oIVIVofIVIP07ofIVIP03o`000?moOgooOgmo00?oOgmo00?o
0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0Bok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go
0000ogmoOomoOgooOgmoo`000003ofIVIP03o`000?m<C4coC4a<00?oC4a<00?o0000oc<c<olc<c<0
1?lc<c<00ol0003oC4a<oda<C003oda<C004o`000?mVIVKoIVIVo`0000?oOgmo00Co0000oiVIVOnI
VIWo00001?nc/k<00ol0003oc<c<olc<c005olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT0
1_l0003oOgmoogmoOol0003oIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01Olc<c<02Ol0003oC4a<
oda<C?m<C4co0000ofIVI_l0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Woc<c<00?o
0000ok>c/ol000000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<0
1_lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Soc<c<
00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`0000Kooooo0Ol00001ooooo`7ooooo000Toooo
o`03o`000?oooooooooo00?ooooo1_moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c
01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`;o00003OmVIVH00ol0
003oC4a<oda<C00Hoda<C003o`000?mVIVKoIVIV00KoIVIV0_l00005ogmoO`03o`000?nIVIWoVIVI
00?oVIVI00?o0000ok>c/onc/k<04onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00?o0000
ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C003oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000
oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo0000
1?nc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT00ol0003o
Ogmoo`000002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01?l0003oC4a<oda<C?l00002
ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01_l0003o/k>cok>c
/ol0003oVIVIo`0000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0<
o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00002?o<c<`02?l0003o
/k>cok>c/ol0003oVIVIo`000?moOgoo00001_ooool1o`00007ooooo0Oooool002Cooooo00?o0000
ooooooooool00oooool5ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<0
0ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH03?mVIVH0
0ol0003oC4a<oda<C00Hoda<C003o`000?mVIVKoIVIV00OoIVIV00?o0000ogmoOomoOgl01?moOgl0
0ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c01?o/k>c00Go0000oiVIVOnIVIWoVIVIo`00
0003ogmoO`05o`000?mVIVKoIVIVofIVI_l000001_m<C4`00ol0003o<c<coc<c<`04oc<c<`03o`00
0?m<C4coC4a<00;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`00
00Co/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000
ogmoOol000000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Co0000oda<C?m<C4co0000
0_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Ko0000ok>c/onc
/k?o0000oiVIVOl00002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<0
3?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Soc<c<00So0000
ok>c/onc/k?o0000oiVIVOl0003oOgmoo`0000Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`00
0?oooooooooo00?ooooo1?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c
00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00coIVIV
00?o0000oda<C?m<C4`06?m<C4`00ol0003oIVIVofIVIP07ofIVIP03o`000?moOgooOgmo00CoOgmo
00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0Cok>c/`05o`000?nIVIWoVIVIoiVIVOl0
00000omoOgl00ol0003oIVIVofIVIP02ofIVIP03o`000?m<C4coC4a<00?oC4a<00?o0000oc<c<olc
<c<01?lc<c<00ol0003oC4a<oda<C003oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Go0000oiVI
VOnIVIWoVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`00
0002oiVIV@03o`000?moOgoo000000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`04o`00
0?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000onIVIT01?l0003o/k>cok>c/ol00008olc<
c005o`000?nc/k?o0000oiVIVOl000000_moOgl00ol0003oIVIVo`000003oda<C003o`000?lc<c?o
<c<c00Go<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00009
olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000Gooooo0Ol00001ooooo`7o
oooo000Tooooo`03o`000?oooooooooo00?ooooo0omoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`00
0?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`00
0?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`2o`0000WoIVIV00?o0000ogmoOomoOgl0
1?moOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT0
0_nIVIT01Ol0003oOgmoogmoOomoOgoo000000?oIVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o
<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmo
O`03o`000?nIVIWoVIVI00;o00000onc/k<00ol0003oc<c<olc<c005olc<c005o`000?nc/k?o/k>c
ok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<C?l00000
2?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc
/k?o00002?o<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00?o0000ofIVI_l000000_m<
C4`00ol0003o<c<coc<c<`06oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVI
o`000?nc/k?o00002Oo<c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000005oooo
o`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`;oOgmo00?o0000oiVIVOnI
VIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI0_l0000:ogmoO`03
o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP08ofIVIP03
o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0Cok>c/`03
o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`000003ofIVIP03o`000?m<C4coC4a<
00?oC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C003oda<C005o`000?mVIVKoIVIV
ofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Goc<c<00Go
0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Go0000oda<C?m<
C4coC4a<o`000008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT0
1?l0003o/k>cok>c/ol00008olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIV
IP04o`000?m<C4coC4a<o`0000So<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nI
VIWo0000ok>c/ol00009olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000Go
oooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo00?oOgmoo`000?nIVIT0
3?nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl0
2OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<0_l0000:ofIVIP03o`00
0?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0Cok>c/`03o`00
0?nIVIWoVIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`000003ofIVIP03o`000?m<C4coC4a<00?o
C4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C003oda<C005o`000?mVIVKoIVIVofIV
I_l000000_moOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000
ok>c/onc/k?o00000_nIVIT01?l0003oOgmoogmoOol00003ofIVIP04o`000?m<C4coC4a<o`0000So
<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>c
o`0000Soc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`03o`000?mVIVKo000000;oC4a<
00?o0000oc<c<olc<c<01_lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0
003o/k>co`0000Woc<c<00?o0000ok>c/onc/k<00_l000001?moOgoo0000ofIVI_l00006ooooo`7o
00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`03o`000?nIVIWoVIVI00_oVIVI
00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo
0_l0000=ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02OmVIVH00ol0003oOgmo
ogmoO`05ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<04_nc/k<00ol0003oVIVI
oiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol000001?mVIVH00ol0003oC4a<oda<C003oda<C003
o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00om<C4`01?l0003oIVIVofIVI_l00002ogmo
O`05o`000?nIVIWoVIVIoiVIVOl000000onc/k<2o`0000Ooc<c<00Go0000ok>c/onc/k?o/k>co`00
0002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`04
o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00008
olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl00ol0003oIVIVo`000002oda<C003o`00
0?lc<c?o<c<c00Ko<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c
/ol00008olc<c0;o000000So/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000Kooooo0Ol00001
ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo3OnIVIT00ol0003o/k>cok>c/`0Fok>c
/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIV
IP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`05ogmo
O`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<04_nc/k<00ol0003oVIVIoiVIV@02oiVI
V@05o`000?moOgooOgmoogmoOol000000omVIVH00ol0003oC4a<oda<C004oda<C003o`000?lc<c?o
<c<c00Co<c<c00?o0000oda<C?m<C4`00om<C4`01?l0003oIVIVofIVI_l00002ogmoO`05o`000?nI
VIWoVIVIoiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol0
00000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<0
1?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o0000
2?o<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0
003o<c<coc<c<`06oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc
/k?o00002?o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00006ooooo`7o
00000Oooool1ooooo`009?ooool2o`0000Cooooo3?nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`00
0?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`00
0?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02OmVIVH00ol0003oOgmoogmoO`05ogmoO`03o`00
0?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<04_nc/k<00ol0003oVIVIoiVIV@02oiVIV@03o`00
0?moOgooOgmo00;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000006oda<C003o`000?lc<c?o<c<c00?o
<c<c00?o0000oda<C?m<C4`00om<C4`01?l0003oIVIVofIVI_l00002ogmoO`03o`000?nIVIWoVIVI
00;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c005o`000?nc/k?o/k>cok>c/ol000000_nI
VIT01?l0003oOgmoogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Go0000oda<C?m<
C4coC4a<o`000002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`0
0ol0003o/k>co`000002oiVIV@06o`000?moOgooOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<c
oc<c<`06oc<c<`03o`000?m<C4co000000;oIVIV00Co0000ogmoOol0003o00000_nc/k<00ol0003o
c<c<olc<c006olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000Gooooo
0_l00002ooooo`009?ooool00ol0003oooooooooo`03ooooo`coVIVI00?o0000ok>c/onc/k<05_nc
/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omV
IVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00[oIVIV00?o0000ogmoOomoOgl01Omo
Ogl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c01;o/k>c00?o0000oiVIVOnIVIT00_nI
VIT01Ol0003oOgmoogmoOomoOgoo000000?oIVIV00?o0000oda<C?m<C4`01?m<C4`00ol0003o<c<c
oc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01Ol0003o
VIVIoiVIVOnIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o
000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c
00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`00
00Soc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`03o`000?mVIVKo000000;oC4a<00?o
0000oc<c<olc<c<01_lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o
/k>co`0000Soc<c<00_o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C006
ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`[oVIVI0_l0000Gok>c
/`;o00003OnIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<
C?m<C4`05om<C4`00ol0003oIVIVofIVIP0:ofIVIP03o`000?moOgooOgmo00CoOgmo0_l00006oiVI
V@03o`000?nc/k?o/k>c01;o/k>c00?o0000oiVIVOnIVIT00_nIVIT00ol0003oOgmoogmoO`02ogmo
O`05o`000?mVIVKoIVIVofIVI_l000001_m<C4`00ol0003o<c<coc<c<`03oc<c<`03o`000?m<C4co
C4a<00?oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`03o`000?nIVIWoVIVI00;o00000onc
/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmo
ogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Go0000oda<C?m<C4coC4a<o`000002
ofIVIP04o`000?moOgoo0000oiVIV@;o00000_nc/k<00ol0003oc<c<olc<c006olc<c006o`000?nc
/k?o/k>co`000?nIVIWo00000_moOgl01?l0003oIVIVo`000?m<C4`2o`0000So<c<c00co0000oda<
C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00008olc<c00<o`000?nc/k?o/k>c
o`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co00001Oooool1o`00007ooooo0Oooool002Co
oooo00?o0000ooooooooool00oooool9oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnI
VIT03?nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<
C4`05om<C4`00ol0003oIVIVofIVIP0:ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnI
VIT01?nIVIT00ol0003o/k>cok>c/`0Cok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomo
OgooOgmoo`000004ofIVIP03o`000?m<C4coC4a<00CoC4a<00?o0000oc<c<olc<c<00olc<c<00ol0
003oC4a<oda<C003oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl0
0004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVI
VOl00002ogmoO`04o`000?mVIVKoIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003o
C4a<oda<C?m<C4co000000;oIVIV00Go0000ogmoOol0003oVIVIo`000003ok>c/`03o`000?o<c<co
c<c<00Koc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`;o00000_m<C4`00ol0003o<c<c
oc<c<`07oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o0000
2?o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000Gooooo
0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo2?nIVIT00ol0003o/k>cok>c
/`0Gok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIV
IP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmo
O`05ogmoO`03o`000?nIVIWoVIVI00GoVIVI00?o0000ok>c/onc/k<04onc/k<01Ol0003oVIVIoiVI
VOnIVIWo000000CoOgmo00Go0000ofIVI_mVIVKoIVIVo`000006oda<C003o`000?lc<c?o<c<c00?o
<c<c00?o0000oda<C?m<C4`00om<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Co0000oiVI
VOnIVIWo00001?nc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nI
VIT01?l0003oOgmoogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Go0000oda<C?m<
C4coC4a<o`000002ofIVIP05o`000?moOgoo0000oiVIVOl000000onc/k<00ol0003oc<c<olc<c006
olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl01Ol0003oIVIVo`000?m<C4co000000Wo
<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00009olc<c00;
o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l000001_ooool1o`00007ooooo
0Oooool002Cooooo00?o0000ooooooooool00oooool7oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o
0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o
0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0:ofIVIP03o`000?moOgooOgmo00GoOgmo00?o
0000oiVIVOnIVIT01OnIVIT00ol0003o/k>cok>c/`0Cok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go
0000ogmoOomoOgooOgmoo`000004ofIVIP03o`000?m<C4coC4a<00?oC4a<00?o0000oc<c<olc<c<0
1?lc<c<00ol0003oC4a<oda<C003oda<C004o`000?mVIVKoIVIVo`0000?oOgmo00Co0000oiVIVOnI
VIWo00001?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Go0000oiVI
VOnIVIWo0000ogmoO`02o`000003ofIVI_l0003oC4a<00;oC4a<00?o0000oc<c<olc<c<01_lc<c<0
1ol0003oC4a<oda<C?m<C4co0000ofIVI_l000000_moOgl00ol0003oVIVIo`000002ok>c/`03o`00
0?o<c<coc<c<00Ooc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV00?o0000
oda<C?l000002Olc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>c
o`0000Woc<c<00_o0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`000006oooo
o`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`KoVIVI00?o0000ok>c/onc
/k<05onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mV
IVH02omVIVH00ol0003oC4a<oda<C00Foda<C0;o00003?mVIVH00ol0003oOgmoogmoO`05ogmoO`03
o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc/k<04onc/k<01Ol0003oVIVIoiVIVOnIVIWo0000
00CoOgmo00Go0000ofIVI_mVIVKoIVIVo`000005oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000
oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Co0000oiVIVOnIVIWo0000
1?nc/k<00ol0003oc<c<olc<c005olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003o
OgmoogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01ol0003oC4a<oda<C?m<
C4co0000ofIVI_l000000_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<
00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV00?o0000oda<C?l000002Olc<c<0
3?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Woc<c<00_o0000
ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`000006ooooo`7o00000Oooool1oooo
o`009?ooool00ol0003oooooooooo`03ooooo`GoVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003o
VIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003o
C4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl01_moOgl00ol0003o
VIVIoiVIV@05oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003o
OgmoogmoOomoOgoo000000CoIVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`04oc<c
<`03o`000?m<C4coC4a<00?oC4a<00Co0000ofIVI_mVIVKo00000omoOgl01?l0003oVIVIoiVIVOl0
0004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01_l0003oVIVIoiVI
VOl0003oOgmoo`0000;oIVIV00?o0000oda<C?m<C4`00_m<C4`00ol0003o<c<coc<c<`06oc<c<`06
o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl00ol0003oVIVIo`000003ok>c/`03o`000?o<c<co
c<c<00Koc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`03o`000?mVIVKo000000;oC4a<
00?o0000oc<c<olc<c<01_lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0
003o/k>co`0000Woc<c<00?o0000ok>c/onc/k<00_l000001omoOgoo0000ofIVI_l0003oC4a<o`00
0?lc<c<01_ooool1o`00007ooooo0Oooool001Wooooo1Ol00006ooooo`03o`000?oooooooooo00?o
oooo1?nIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00[oVIVI0_l0000:ogmoO`03
o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03
o`000?moOgooOgmo00KoOgmo00?o0000oiVIVOnIVIT01OnIVIT00ol0003o/k>cok>c/`0Cok>c/`03
o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`000004ofIVIP03o`000?m<C4coC4a<
00CoC4a<00?o0000oc<c<olc<c<00olc<c<00ol0003oC4a<oda<C003oda<C005o`000?mVIVKoIVIV
ofIVI_l000000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<
c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01Ol0003o
C4a<oda<C?m<C4co000000So<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00?o
0000oiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c008o`000?nc/k?o/k>co`000?nIVIWo
0000ogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00co0000oda<C?m<C4co0000ofIV
I_l0003oOgmoo`000?nIVIWo0000ok>c/ol00009olc<c00<o`000?nc/k?o0000oiVIVOl0003oOgmo
o`000?mVIVKo0000oda<C?l0003o<c<c1_ooool1o`00007ooooo0Oooool001Wooooo00GoV9RHob4Q
8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo00?ooooo0onIVIT00ol0003o/k>cok>c/`0G
ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;
ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`06
ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc/k<04onc/k<00ol0003oVIVIoiVIV@02
oiVIV@05o`000?moOgooOgmoogmoOol000001?mVIVH00ol0003oC4a<oda<C004oda<C003o`000?lc
<c?o<c<c00?o<c<c00?o0000oda<C?m<C4`00om<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo
00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c
/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc
<c<01ol0003oC4a<oda<C?m<C4co0000ofIVI_l000000_moOgl00ol0003oVIVIo`000003ok>c/`03
o`000?o<c<coc<c<00Koc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV00Co
0000oda<C?m<C4co00002?lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0
003o/k>co`0000Woc<c<00co0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`00
0?lc<c<6ooooo`7o00000Oooool1ooooo`004Oooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h01ooo
ool3o`0000?ooooo0_nIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o
0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o
0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`06ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o
0000ok>c/onc/k<04onc/k<00ol0003oVIVIoiVIV@02oiVIV@03o`000?moOgooOgmo00;oOgmo00Go
0000ofIVI_mVIVKoIVIVo`000006oda<C003o`000?lc<c?o<c<c00?o<c<c00?o0000oda<C?m<C4`0
0om<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000003ok>c
/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgoo
Ogmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`07o`000?m<C4coC4a<oda<C?l0
003oIVIVo`000002ogmoO`03o`000?nIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`02?l0
003o/k>cok>c/ol0003oVIVIo`000?moOgoo00000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`0:
o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`0
1_o<c<`01Ol0003o/k>co`000?nIVIWo000000;oOgmo0_l000001?m<C4co0000oc<c<olc<c<4oooo
o`?o00000_ooool001_ooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`03ooooo`03
oiVIVOl0003o/k>c01So/k>c00?o0000oiVIVOnIVIT02_nIVIT2o`0000[oOgmo00?o0000ofIVI_mV
IVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomo
Ogl01omoOgl00ol0003oVIVIoiVIV@05oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnI
VIT00_nIVIT00ol0003oOgmoogmoO`02ogmoO`05o`000?mVIVKoIVIVofIVI_l000001_m<C4`00ol0
003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002
ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc
/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<
C?l000002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP06o`000?moOgooOgmoo`000?nIVIWo0000
0_nc/k<00ol0003oc<c<olc<c007olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002
ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`00
0?nIVIWo0000ok>c/ol00009olc<c00;o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000
oda<C?l000000_lc<c<6ooooo`7o00000Oooool1ooooo`007?ooool00omgMgOoIVIVooooo`05oooo
o`03o`000?oooooooooo00?ooooo00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0:oiVI
V@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<
C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl01_moOgl00ol0003oVIVIoiVIV@06oiVI
V@03o`000?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT00_nIVIT00ol0003oOgmoogmoO`02ogmo
O`05o`000?mVIVKoIVIVofIVI_l000001_m<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4co
C4a<00?oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVIVOl00000
0onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003o
OgmoogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01?l0003oC4a<oda<C?l0
0002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`02?l0003o/k>c
ok>c/ol0003oVIVIo`000?moOgoo00000_mVIVH00ol0003oC4a<o`000009oc<c<`0<o`000?m<C4co
C4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00002Oo<c<`02ol0003o/k>co`000?nI
VIWo0000ogmoOol0003oIVIVo`000?m<C4co000000;o<c<c1_ooool1o`00007ooooo0Oooool001go
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooooaSo/k>c0_l0000<oiVIV@03
o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003
o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl01_moOgl00ol0003oVIVIoiVIV@06oiVIV@03
o`000?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT00onIVIT01Ol0003oOgmoogmoOomoOgoo0000
00CoIVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<
00?oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000onc
/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmo
ogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01?l0003oC4a<oda<C?l00002
ofIVIP06o`000?moOgooOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c007olc<c008o`00
0?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00co
0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00009olc<c003o`000?nc
/k?o000000;oVIVI0_l000001OmVIVKo0000oda<C?m<C4co000000;o<c<c1_ooool1o`00007ooooo
0Oooool001Wooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo00?ooooo
5onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH0
2omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV0_l00008ogmoO`03o`00
0?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc/k<04onc/k<00ol0003oVIVIoiVIV@03oiVIV@05o`00
0?moOgooOgmoogmoOol000001?mVIVH00ol0003oC4a<oda<C004oda<C003o`000?lc<c?o<c<c00?o
<c<c00?o0000oda<C?m<C4`00om<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Co0000oiVI
VOnIVIWo00001?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000
oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c
00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`00
00Soc<c<00Wo0000ok>c/onc/k?o/k>co`000?nIVIWo0000ogmoOol000000_mVIVH00ol0003oC4a<
o`000009oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o0000
2Oo<c<`02ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co000000?o<c<c1_oo
ool1o`00007ooooo0Oooool001Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oo
oooooooo00?ooooo5onc/k<00ol0003oVIVIoiVIV@0:oiVIV@03o`000?moOgooOgmo00WoOgmo00?o
0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00coIVIV00?o
0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@05oiVIV@03o`000?nc/k?o/k>c01Co/k>c00?o
0000oiVIVOnIVIT00onIVIT01Ol0003oOgmoogmoOomoOgoo000000CoIVIV00?o0000oda<C?m<C4`0
1?m<C4`00ol0003o<c<coc<c<`03oc<c<`03o`000?m<C4coC4a<00?oC4a<00Go0000ofIVI_mVIVKo
IVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0003oc<c<olc<c005olc<
c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l0
0002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmo
o`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Wo0000ok>c/onc/k?o/k>co`000?nIVIWo
0000ogmoOol000000_mVIVH00ol0003oC4a<o`000009oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo
0000ogmoOol0003oVIVIo`000?nc/k?o00002Oo<c<`02ol0003o/k>co`000?nIVIWo0000ogmoOol0
003oIVIVo`000?m<C4co000000?o<c<c1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000oooo
ooooool00ooooolEok>c/`;o00003?nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV
00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?moOgooOgmo
00OoOgmo00?o0000oiVIVOnIVIT01OnIVIT00ol0003o/k>cok>c/`0Dok>c/`03o`000?nIVIWoVIVI
00?oVIVI00Go0000ogmoOomoOgooOgmoo`000004ofIVIP03o`000?m<C4coC4a<00CoC4a<00?o0000
oc<c<olc<c<00olc<c<00ol0003oC4a<oda<C003oda<C003o`000?mVIVKoIVIV00;oIVIV00Co0000
ogmoOomoOgoo00000_nIVIT00ol0003o/k>cok>c/`02ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o
0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000?o
C4a<00?o0000oc<c<olc<c<01_lc<c<02Ol0003oC4a<oda<C?m<C4co0000ofIVI_l0003oOgmoo`00
0002oiVIV@04o`000?nc/k?o/k>co`0000Woc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmo
O`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02_l0003oC4a<oda<C?l0003o
IVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o0000ok>c/onc
/k<00_l000001?moOgoo0000ofIVI_mVIVH2o`0000Co<c<c1_ooool1o`00007ooooo0Oooool002Co
oooo00?o0000ooooooooool00ooooolDok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomo
Ogl02?moOgl2o`0000goIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP;o
00002OmoOgl00ol0003oVIVIoiVIV@05oiVIV@;o00005Onc/k<00ol0003oVIVIoiVIV@03oiVIV@05
o`000?moOgooOgmoogmoOol000001?mVIVH00ol0003oC4a<oda<C005oda<C003o`000?lc<c?o<c<c
00;o<c<c00?o0000oda<C?m<C4`01?m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Go0000
oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc
/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000;oC4a<00?o0000oc<c<olc
<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0
003o/k>cok>c/ol00009olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP04
o`000?m<C4coC4a<o`0000So<c<c00?o0000oda<C?l000000_mVIVH01Ol0003oOgmoo`000?nIVIWo
000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02ol0003o/k>co`000?nIVIWo0000ogmoOol0003o
IVIVo`000?m<C4co000000Co<c<c1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000oooooooo
ool00ooooolCok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003o
IVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003o
OgmoogmoO`07ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc/k<05?nc/k<00ol0003o
VIVIoiVIV@03oiVIV@05o`000?moOgooOgmoogmoOol000001?mVIVH00ol0003oC4a<oda<C005oda<
C003o`000?lc<c?o<c<c00;o<c<c00?o0000oda<C?m<C4`01?m<C4`01Ol0003oIVIVofIVI_mVIVKo
000000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o
0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000;o
C4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o0000ogmo
Ool000000_nIVIT01?l0003o/k>cok>c/ol00009olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000
ogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00?o0000oda<C?l000000_mVIVH01Ol0
003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01Oo<c<`03?l0003o/k>cok>c/ol0
003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000Co<c<c1_ooool1o`00007ooooo0Oooool0
02Cooooo00?o0000ooooooooool00ooooolBok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmo
OomoOgl02?moOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIV
I_mVIVH03?mVIVH00ol0003oOgmoogmoO`07ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c
/onc/k<05?nc/k<00ol0003oVIVIoiVIV@03oiVIV@05o`000?moOgooOgmoogmoOol000001OmVIVH0
0ol0003oC4a<oda<C004oda<C003o`000?lc<c?o<c<c00;o<c<c00?o0000oda<C?m<C4`01?m<C4`0
1Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`00
0?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`00
00;oIVIV00Co0000oda<C?m<C4co00002?lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o
0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00009olc<c008o`000?nc/k?o/k>co`000?nI
VIWo0000ogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00[o0000oda<C?m<C4co0000
ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o
0000oiVIVOl000000_moOgl2o`0000;oC4a<00?o0000oc<c<olc<c<00_lc<c<6ooooo`7o00000Ooo
ool1ooooo`009?ooool00ol0003oooooooooo`03oooooa7o/k>c00?o0000oiVIVOnIVIT02onIVIT0
0ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`0
0ol0003oIVIVofIVIP0;ofIVIP;o00002OmoOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o
/k>c01Co/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKo
IVIV00;oIVIV00?o0000oda<C?m<C4`01?m<C4`00ol0003o<c<coc<c<`03oc<c<`03o`000?m<C4co
C4a<00?oC4a<0_l00002ofIVIP05o`000?moOgooOgmoogmoOol000000_nIVIT00ol0003o/k>cok>c
/`02ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`00
0?moOgooOgmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`05o`000?m<C4coC4a<
oda<C?l000000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Co
0000ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc
<c<01olc<c<03?l0003oC4a<o`000?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Wo
c<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c
<`02oc<c<`Kooooo0Ol00001ooooo`7ooooo000Tooooo`;o00001?ooool@ok>c/`03o`000?nIVIWo
VIVI00_oVIVI0_l0000:ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`0
0ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT01onIVIT0
0ol0003o/k>cok>c/`0Dok>c/`03o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl00_moOgl0
0ol0003oIVIVofIVIP02ofIVIP03o`000?m<C4coC4a<00CoC4a<00?o0000oc<c<olc<c<00olc<c<0
0ol0003oC4a<oda<C003oda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01?l0003oVIVIoiVI
VOl00004ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04
o`000?moOgooOgmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`05o`000?m<C4co
C4a<oda<C?l000000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<
00Co0000ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c
<olc<c<01olc<c<00ol0003oC4a<o`000002ofIVIP07o`000?moOgoo0000oiVIVOl0003o/k>co`00
0009olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c
<olc<c<00_lc<c<5ooooo`;o00000_ooool002Cooooo00?o0000ooooooooool00oooool?ok>c/`03
o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03
o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03
o`000?nIVIWoVIVI00OoVIVI00?o0000ok>c/onc/k<05?nc/k<00ol0003oVIVIoiVIV@03oiVIV@03
o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C004oda<C003
o`000?lc<c?o<c<c00?o<c<c00?o0000oda<C?m<C4`00om<C4`00ol0003oIVIVofIVIP02ofIVIP04
o`000?moOgooOgmoo`0000;oVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c005olc<
c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l0
0002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Co0000oda<C?m<C4co00000_mVIVH01_l0003oOgmo
ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002
oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<2o`0000;oIVIV00Oo
0000ogmoOol0003oVIVIo`000?nc/k?o000000Woc<c<00?o0000ok>c/ol000000_nIVIT2o`000005
ofIVI_l0003oC4a<oda<C?l000001Olc<c<6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003o
ooooooooo`03ooooo`ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`;o
00003OmVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomo
Ogl02?moOgl00ol0003oVIVIoiVIV@07oiVIV@03o`000?nc/k?o/k>c01Co/k>c00?o0000oiVIVOnI
VIT00onIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<
C4`01Om<C4`00ol0003o<c<coc<c<`02oc<c<`03o`000?m<C4coC4a<00CoC4a<00Go0000ofIVI_mV
IVKoIVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0003oc<c<olc<c006
olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP05o`00
0?m<C4coC4a<oda<C?l000002?lc<c<01ol0003oC4a<oda<C?m<C4co0000ofIVI_l000000_moOgl0
1?l0003oVIVIoiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o0000
0_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01olc<c<00ol0003o
C4a<o`000002ofIVIP07o`000?moOgoo0000oiVIVOl0003o/k>co`000009olc<c004o`000?nc/k?o
0000oiVIV@?o000000GoIVIVo`000?m<C4coC4a<o`000005oc<c<`Kooooo0Ol00001ooooo`7ooooo
000Tooooo`03o`000?oooooooooo00?ooooo3Onc/k<00ol0003oVIVIoiVIV@0<oiVIV@03o`000?mo
OgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mV
IVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@07oiVIV@03o`000?nc
/k?o/k>c01Co/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mV
IVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01Om<C4`00ol0003o<c<coc<c<`02oc<c<`03o`000?m<
C4coC4a<00CoC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVIVOl0
00001?nc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0
003oOgmoogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01ol0003oC4a<oda<
C?m<C4co0000ofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00002ok>c/`03o`000?o<c<coc<c<
00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o
0000oc<c<olc<c<01olc<c<00ol0003oC4a<o`000002ofIVIP07o`000?moOgoo0000oiVIVOl0003o
/k>co`000009olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o
0000oc<c<olc<c<00olc<c<6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03
ooooo`co/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKo
IVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0:ofIVIP03o`000?moOgoo
Ogmo00WoOgmo00?o0000oiVIVOnIVIT01onIVIT00ol0003o/k>cok>c/`0Eok>c/`03o`000?nIVIWo
VIVI00;oVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4co
C4a<00CoC4a<00?o0000oc<c<olc<c<00_lc<c<00ol0003oC4a<oda<C004oda<C005o`000?mVIVKo
IVIVofIVI_l000000omoOgl01Ol0003oVIVIoiVIVOnIVIWo000000Co/k>c00?o0000olc<c?o<c<`0
1Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co0000ofIVI_mV
IVKo00000_m<C4`00ol0003o<c<coc<c<`07oc<c<`07o`000?m<C4coC4a<oda<C?l0003oIVIVo`00
0002ogmoO`04o`000?nIVIWoVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01_l0003o/k>c
ok>c/ol0003oVIVIo`0000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c
<`05o`000?m<C4co0000ofIVI_l000000_moOgl01Ol0003oVIVIo`000?nc/k?o000000Woc<c<0_l0
0002oiVIV@07o`000?moOgoo0000ofIVI_l0003oC4a<o`000006oc<c<`Kooooo0Ol00001ooooo`7o
oooo000Tooooo`03o`000?oooooooooo00?ooooo3?nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`00
0?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Goda<C003o`00
0?mVIVKoIVIV00[oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@07oiVIV@03o`00
0?nc/k?o/k>c01Go/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`02ogmoO`03o`00
0?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01Om<C4`00ol0003o<c<coc<c<`02oc<c<`03o`00
0?m<C4coC4a<00CoC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVI
VOl000001?nc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT0
1?l0003oOgmoogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01ol0003oC4a<
oda<C?m<C4co0000ofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00002ok>c/`03o`000?o<c<co
c<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<
00?o0000oc<c<olc<c<01olc<c<00ol0003oC4a<o`000002ofIVIP05o`000?moOgoo0000oiVIVOl0
00000_nc/k<00ol0003oc<c<olc<c006olc<c007o`000?nc/k?o0000oiVIVOl0003oOgmoo`000002
ofIVIP03o`000?m<C4co000000Ko<c<c1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000oooo
ooooool00oooool:ok>c/`;o00003OnIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV
00_oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0:ofIVIP;o00002_moOgl00ol0
003oVIVIoiVIV@08oiVIV@03o`000?nc/k?o/k>c01Co/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0
003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01Om<C4`00ol0
003o<c<coc<c<`02oc<c<`03o`000?m<C4coC4a<00CoC4a<00Go0000ofIVI_mVIVKoIVIVo`000003
ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc
/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00002oda<C003
o`000?lc<c?o<c<c00Oo<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00Co0000
oiVIVOnIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`0000;oVIVI
00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00?o0000oda<C?l0
00000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02ol0
003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co000000Oo<c<c1_ooool1o`00007o
oooo0Oooool002Cooooo00?o0000ooooooooool00oooool9ok>c/`03o`000?nIVIWoVIVI00coVIVI
00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<
00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00WoVIVI
00?o0000ok>c/onc/k<04onc/k<00ol0003oVIVIoiVIV@03oiVIV@03o`000?moOgooOgmo00?oOgmo
00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C005oda<C003o`000?lc<c?o<c<c00;o<c<c
00?o0000oda<C?m<C4`01?m<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Go0000oiVIVOnI
VIWoVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0
003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01olc
<c<01ol0003oC4a<oda<C?m<C4co0000ofIVI_l000000_moOgl00ol0003oVIVIo`000003ok>c/`03
o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mVIVKo
000000;oC4a<00?o0000oc<c<olc<c<01olc<c<00ol0003oC4a<o`000002ofIVIP05o`000?moOgoo
0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c005olc<c00<o`000?nc/k?o/k>co`000?nIVIWo
0000ogmoOol0003oIVIVo`000?m<C4co00001olc<c<6ooooo`7o00000Oooool1ooooo`009?ooool0
0ol0003oooooooooo`03ooooo`Wo/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08
ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0:
ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02OnIVIT00ol0003o/k>cok>c/`0D
ok>c/`03o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP02
ofIVIP03o`000?m<C4coC4a<00GoC4a<00?o0000oc<c<olc<c<00_lc<c<00ol0003oC4a<oda<C004
oda<C003o`000?mVIVKoIVIV00;oIVIV00Co0000ogmoOomoOgoo00000onIVIT00ol0003o/k>cok>c
/`02ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVI
VOl00002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01ol0003o
C4a<oda<C?m<C4co0000ofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00002ok>c/`03o`000?o<
c<coc<c<00Ooc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`0
0ol0003o<c<coc<c<`07oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`00
00;o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>co`000?nIVIWo000000;oOgmo0_l00002
oda<C003o`000?lc<c?o<c<c00Go<c<c1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000oooo
ooooool00oooool8ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0
003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02_mVIVH2o`00
00[oOgmo00?o0000oiVIVOnIVIT02?nIVIT2o`0001Ko/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0
003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01Om<C4`01Ol0
003o<c<coc<c<olc<c?o000000OoC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`04o`000?nI
VIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000?o
VIVI00Co0000ogmoOomoOgoo00000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Co0000
oda<C?m<C4co00000_mVIVH01_l0003oOgmoogmoOol0003oVIVIo`0000?o/k>c00?o0000olc<c?o<
c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`0
0ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Oo0000ogmoOol0003oVIVI
o`000?nc/k?o000000Woc<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<
C4`00ol0003o<c<coc<c<`05oc<c<`Kooooo0Ol00001ooooo`7ooooo000Tooooo`;o00001?ooool7
ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;
ofIVIP03o`000?m<C4coC4a<01KoC4a<0_l0000<ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000
oiVIVOnIVIT02OnIVIT00ol0003o/k>cok>c/`0Eok>c/`03o`000?nIVIWoVIVI00?oVIVI00?o0000
ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<00GoC4a<00Go0000
oc<c<olc<c?o<c<co`000006oda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgooOgmo
o`000002oiVIV@03o`000?nc/k?o/k>c00;o/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>c
ok>c/`02ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00002oda<
C003o`000?lc<c?o<c<c00Oo<c<c00Co0000oda<C?m<C4co00000_mVIVH01_l0003oOgmoogmoOol0
003oVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@05
o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<
o`0000;oIVIV00Oo0000ogmoOol0003oVIVIo`000?nc/k?o000000Woc<c<00Wo0000ok>c/ol0003o
VIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`05oc<c<`Gooooo0_l00002
ooooo`009?ooool00ol0003oooooooooo`03ooooo`Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0
003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0
003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02OnIVIT00ol0
003o/k>cok>c/`0Eok>c/`03o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl00_moOgl00ol0
003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<00GoC4a<00Go0000oc<c<olc<c?o<c<co`000006
oda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgooOgmoo`000003oiVIV@05o`000?nc
/k?o/k>cok>c/ol000001oo<c<`00ol0003o/k>cok>c/`02ok>c/`05o`000?nIVIWoVIVIoiVIVOl0
00000_moOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<
C?m<C4coC4a<o`000002ofIVIP05o`000?moOgoo0000oiVIVOl000000onc/k<00ol0003oc<c<olc<
c006olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<
oda<C?l00007oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Oo0000ogmoOol0003oVIVIo`000?nc
/k?o000000Woc<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0
003o<c<coc<c<`06oc<c<`03o`000?oooooooooo00?ooooo0Ol00001ooooo`7ooooo000Tooooo`03
o`000?oooooooooo00?ooooo1Onc/k<00ol0003oVIVIoiVIV@0:oiVIV@;o00002_moOgl00ol0003o
IVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003o
OgmoogmoO`08ogmoO`;o00002onIVIT00ol0003o/k>cok>c/`0Eok>c/`03o`000?nIVIWoVIVI00?o
VIVI0_l00004ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01_m<C4`01?l0003o
<c<coc<c<ol00007oda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01Ol0003oVIVIoiVIVOnI
VIWo000000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nI
VIWoVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`05
o`000?m<C4coC4a<oda<C?l000000_mVIVH01_l0003oOgmoogmoOol0003oVIVIo`0000;o/k>c00?o
0000olc<c?o<c<`01oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l0
00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Oo0000ogmo
Ool0003oVIVIo`000?nc/k?o000000Woc<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIV
I_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`03o`000?oooooooooo00?ooooo0Ol00001oooo
o`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo1?nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03
o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003
o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03
o`000?nc/k?o/k>c01Go/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`03ogmoO`03
o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01Om<C4`3o`000003oc<c<ol0003oC4a<00Ko
C4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc/k<0
0ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_mo
Ogl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4co
C4a<o`000002ofIVIP06o`000?moOgooOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c007
olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`00
0?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH01ol0003oOgmoo`000?nIVIWo0000
ok>c/ol000002Oo<c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003
o`000?lc<c?o<c<c00Ko<c<c00?o0000ooooooooool00oooool1o`00007ooooo0Oooool002Cooooo
00?o0000ooooooooool00oooool3ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl0
2?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH0
2omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00[oVIVI00?o0000ok>c/onc/k<0
5Onc/k<00ol0003oVIVIoiVIV@03oiVIV@03o`000?moOgooOgmo00?oOgmo00?o0000ofIVI_mVIVH0
0_mVIVH00ol0003oC4a<oda<C006oda<C004o`000?lc<c?o0000o`0000OoC4a<00?o0000ofIVI_mV
IVH00_mVIVH01?l0003oOgmoogmoOol00003oiVIV@03o`000?nc/k?o/k>c00;o/k>c00?o0000olc<
c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co0000
ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l00000
0_mVIVH01_l0003oOgmoogmoOol0003oVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0
003o/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c
<`07oc<c<`03o`000?m<C4co000000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`00
0?o<c<coc<c<00Koc<c<00Oo0000ok>c/ol0003oVIVIo`000?moOgoo000000;oIVIV00?o0000oda<
C?l000002?lc<c<00ol0003oooooooooo`04ooooo`7o00000Oooool1ooooo`009?ooool00ol0003o
ooooooooo`03ooooo`;o/k>c00?o0000oiVIVOnIVIT02_nIVIT2o`0000[oOgmo00?o0000ofIVI_mV
IVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomo
Ogl02?moOgl2o`0000coVIVI00?o0000ok>c/onc/k<05Onc/k<00ol0003oVIVIoiVIV@04oiVIV@03
o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH00_mVIVH2o`0000OoC4a<00Go0000oc<c<olc
<c?o<c<co`000007oda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01?l0003oVIVIoiVIVOl0
0005ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVI
VOl00002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003o
C4a<oda<C?m<C4co000000;oIVIV00?o0000ogmoOol000000_nIVIT01Ol0003o/k>cok>c/onc/k?o
000000Soc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`03o`000?mVIVKo000000;oC4a<
00?o0000oc<c<olc<c<01olc<c<01?l0003oC4a<o`000?mVIVH2o`000004ogmoOol0003oVIVIo`00
00;o/k>c00?o0000olc<c?o<c<`01_o<c<`02?l0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIV
0_l000000om<C4co0000oc<c<`07oc<c<`03o`000?oooooooooo00Cooooo0Ol00001ooooo`7ooooo
000Tooooo`03o`000?oooooooooo00?ooooo00?o/k>co`000?nIVIT02onIVIT00ol0003oOgmoogmo
O`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIV
IP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c
/`0Dok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIV
IP03ofIVIP03o`000?m<C4coC4a<00KoC4a<00Co0000oc<c<olc<c?o00002?m<C4`01Ol0003oIVIV
ofIVI_mVIVKo000000?oOgmo00Co0000oiVIVOnIVIWo00001Onc/k<00ol0003oc<c<olc<c005olc<
c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l0
0003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP03o`00
0?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01ol0003o/k>cok>c/onc/k?o0000
oiVIVOl000000_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Go0000
oda<C?l0003oIVIVo`000002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<
c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c
00Ko<c<c00?o0000ooooooooool01?ooool1o`00007ooooo0Oooool002Cooooo00?o0000oooooooo
ool00oooool00ol0003oVIVIoiVIV@0:oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mV
IVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomo
Ogl02OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Go/k>c00?o0000oiVIVOnI
VIT00onIVIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<
C4`01_m<C4`01?l0003o<c<coc<c<ol00008oda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl0
1Ol0003oVIVIoiVIVOnIVIWo000000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c
/`02ok>c/`07o`000?nIVIWoVIVIoiVIVOl0003oOgmoo`000003ofIVIP04o`000?m<C4coC4a<o`00
00So<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Co
0000ok>c/onc/k?o00002?o<c<`01?l0003o/k>cok>c/onc/k<2o`0000;oOgmo00?o0000ofIVI_l0
00000_m<C4`00ol0003o<c<coc<c<`07oc<c<`05o`000?m<C4co0000ofIVI_l000000_moOgl00ol0
003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Wo0000ok>c/ol0003oVIVIo`000?mo
Ogoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`03o`000?m<C4cooooo00Gooooo
0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo3?nIVIT00ol0003oOgmoogmo
O`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIV
IP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c
/`0Eok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIV
IP03ofIVIP03o`000?m<C4coC4a<00KoC4a<0ol00008oda<C005o`000?mVIVKoIVIVofIVI_l00000
0omoOgl01Ol0003oVIVIoiVIVOnIVIWo000000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o
/k>cok>c/`02ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00003
oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP03o`000?mo
Ogoo000000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`01_l0003o/k>cok>c/ol0003oVIVIo`00
00;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`06o`000?m<C4coC4a<
o`000?mVIVKo00000_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Wo
0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c
<`03o`000?m<C4cooooo00Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?o
oooo2onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<
C4`05_m<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnI
VIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomo
Ogl00_moOgl00ol0003oIVIVofIVIP02ofIVIP03o`000?m<C4coC4a<00WoC4a<00?o0000oda<C?m<
C4`01_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Go0000oiVIVOnIVIWoVIVIo`000004
ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnI
VIWo000000;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`00
0?m<C4coC4a<oda<C?l000000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`00
00Woc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`03o`000?mVIVKo000000;oC4a<00?o
0000oc<c<olc<c<01_lc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00?o0000oiVIVOl0
00000_nc/k<00ol0003oc<c<olc<c006olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mV
IVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<00ol0003oC4a<o`000005ooooo`7o00000Ooo
ool1ooooo`009?ooool2o`0000Cooooo2_nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKo
IVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?moOgoo
Ogmo00OoOgmo0_l0000=oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT01?nIVIT0
0ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`04_m<C4`0
1Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`00
0?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;o
Ogmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`03o`000?m<C4coC4a<
00;oC4a<00Go0000ofIVI_l0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Woc<c<00Ko
0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000;oC4a<00?o0000oc<c
<olc<c<01Olc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00Ko0000oiVIVOnIVIWo0000
ok>c/ol00008olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o
0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00004ooooo`;o00000_ooool002Cooooo00?o
0000ooooooooool00oooool9oiVIV@03o`000?moOgooOgmo00SoOgmo0_l0000=ofIVIP03o`000?m<
C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH2o`0000WoOgmo00?o0000oiVIVOnIVIT03?nI
VIT00ol0003o/k>cok>c/`0Eok>c/`;o00001_nIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mV
IVKoIVIV00?oIVIV00?o0000oda<C?m<C4`04Om<C4`00ol0003oIVIVofIVIP02ofIVIP05o`000?mo
OgooOgmoogmoOol000000onIVIT00ol0003o/k>cok>c/`02ok>c/`03o`000?o<c<coc<c<00Goc<c<
00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`05o`000?mVIVKoIVIVofIV
I_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`07o`000?m<C4coC4a<oda<C?l0003oIVIVo`00
0002ogmoO`04o`000?nIVIWoVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01oo<c<`01_l0003o/k>c
ok>c/ol0003oVIVIo`0000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c
<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl01Ol0003oVIVIo`000?nc/k?o000000Woc<c<
00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06
oc<c<`03o`000?m<C4co000000Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo
00?ooooo2?nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00coIVIV00?o0000oda<
C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVI
VOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmo
OomoOgl00omoOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<017oC4a<00?o0000ofIV
I_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000?oVIVI00?o0000ok>c/onc/k<00_nc/k<0
0ol0003oc<c<olc<c005olc<c005o`000?nc/k?o/k>cok>c/ol000000onIVIT01?l0003oOgmoogmo
Ool00003ofIVIP04o`000?m<C4coC4a<o`0000Wo<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo
000000;oOgmo00Co0000oiVIVOnIVIWo00000_nc/k<00ol0003oc<c<olc<c007olc<c006o`000?nc
/k?o/k>co`000?nIVIWo00000_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko
<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`05o`000?nIVIWo0000ok>c/ol000002Oo<
c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c
00Ko<c<c00?o0000oda<C?l000001_ooool1o`00007ooooo0Oooool002Cooooo00?o0000oooooooo
ool00oooool7oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH03?mVIVH00ol0003o
C4a<oda<C00Foda<C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl01omoOgl2o`0000go
VIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@05oiVIV@03o`000?moOgooOgmo00;o
Ogmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00Aoda<C003o`000?mVIVKoIVIV00;o
IVIV00Go0000ogmoOomoOgooOgmoo`000003oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<
c?o<c<`01?o<c<`00ol0003o/k>cok>c/`02ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl0
1?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Oo0000oda<C?m<C4coC4a<
o`000?mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo00000_nc/k<00ol0003oc<c<olc<c007olc<
c004o`000?nc/k?o/k>co`0000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc
<c?o<c<c00Ko<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`03o`000?nIVIWo000000;o
/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003o/k>co`000002oiVIV@;o000000?oIVIVo`000?m<
C4`00_m<C4`00ol0003o<c<coc<c<`05oc<c<`04o`000?m<C4co0000ofIVIPKooooo0Ol00001oooo
o`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo1_nIVIT00ol0003oOgmoogmoO`09ogmoO`03
o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP;o
00002OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@;o00006?nc/k<00ol0003oVIVIoiVIV@05oiVIV@03
o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00Boda<C005
o`000?mVIVKoIVIVofIVI_l000000omoOgl01Ol0003oVIVIoiVIVOnIVIWo000000Go/k>c00?o0000
olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co
0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`05oc<c<`05o`000?m<C4coC4a<oda<C?l0
00000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Wo0000
ok>c/onc/k?o/k>co`000?nIVIWo0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00008oc<c
<`05o`000?m<C4coC4a<o`000?mVIVH00_l000001?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<
c<coc<c<00Koc<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0
003o<c<coc<c<`06oc<c<`04o`000?m<C4co0000ofIVIPKooooo0Ol00001ooooo`7ooooo000Toooo
o`03o`000?oooooooooo00?ooooo1OnIVIT2o`0000[oOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0
003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0
003oVIVIoiVIV@0:oiVIV@03o`000?nc/k?o/k>c01Oo/k>c0_l00007oiVIV@03o`000?moOgooOgmo
00;oOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00Boda<C005o`000?mVIVKoIVIV
ofIVI_l000000omoOgl01Ol0003oVIVIoiVIVOnIVIWo000000Go/k>c00?o0000olc<c?o<c<`01?o<
c<`00ol0003o/k>cok>c/`03ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo
00001?m<C4`00ol0003o<c<coc<c<`05oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0
003oOgmoogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Co0000ok>c/onc/k?o0000
0_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Ko0000oda<C?m<
C4co0000ofIVI_l00002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`0
2Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko
<c<c00Co0000oda<C?l0003oIVIV1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000oooooooo
ool00oooool4oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003o
C4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl2o`0000co
VIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@06oiVIV@03o`000?moOgooOgmo00;o
Ogmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00Boda<C005o`000?mVIVKoIVIVofIV
I_l000000omoOgl01Ol0003oVIVIoiVIVOnIVIWo000000Go/k>c00?o0000olc<c?o<c<`01Oo<c<`0
0ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo0000
1?m<C4`00ol0003o<c<coc<c<`05oc<c<`05o`000?m<C4coC4a<oda<C?l000000omVIVH01_l0003o
OgmoogmoOol0003oVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01Oo<c<`02Ol0003o/k>cok>c/onc
/k?o0000oiVIVOl0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Ko0000oda<
C?m<C4co0000ofIVI_l00002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<
c<`00ol0003o/k>cok>c/`02o`000007ogmoOol0003oIVIVofIVI_l0003oC4a<o`000008oc<c<`03
o`000?m<C4co000000;oIVIV00?o0000ooooooooool00oooool1o`00007ooooo0Oooool002Cooooo
00?o0000ooooooooool00oooool3oiVIV@03o`000?moOgooOgmo00SoOgmo0_l0000=ofIVIP03o`00
0?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`00
0?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@05oiVIV@;o0000
1?moOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<01;oC4a<00?o0000ofIVI_mVIVH0
0_mVIVH01Ol0003oOgmoogmoOomoOgoo000000?oVIVI00?o0000ok>c/onc/k<00_nc/k<00ol0003o
c<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmo
O`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<
C4co000000;oIVIV00Ko0000ogmoOomoOgoo0000oiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Ko
c<c<00Wo0000ok>c/onc/k?o/k>co`000?nIVIWo0000ogmoOol000000_mVIVH01?l0003oC4a<oda<
C?l00008oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVIV@04o`000?nc/k?o
/k>co`0000Soc<c<00_o0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`000009
oc<c<`05o`000?m<C4co0000ofIVI_l000001_ooool1o`00007ooooo0Oooool001Wooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo00?ooooo0onIVIT00ol0003oOgmoogmo
O`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIV
IP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02_nIVIT00ol0003o/k>cok>c
/`0Gok>c/`03o`000?nIVIWoVIVI00KoVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIV
IP03ofIVIP03o`000?m<C4coC4a<01;oC4a<00?o0000ofIVI_mVIVH00_mVIVH01?l0003oOgmoogmo
Ool00004oiVIV@03o`000?nc/k?o/k>c00;o/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>c
ok>c/`02ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00003oda<
C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP06o`000?moOgoo
Ogmoo`000?nIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c009o`000?nc/k?o/k>cok>c/ol0
003oVIVIo`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<02?l0003oC4a<oda<
C?l0003oIVIVo`000?moOgoo00000_nIVIT01?l0003o/k>cok>c/ol00008olc<c00;o`000?nc/k?o
0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l000002Olc<c<01Ol0003oC4a<o`000?mVIVKo
000000Kooooo0Ol00001ooooo`7ooooo000Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool0
0ol0003oooooooooo`03ooooo`;oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;
ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`09
ogmoO`03o`000?nIVIWoVIVI00[oVIVI00?o0000ok>c/onc/k<06?nc/k<00ol0003oVIVIoiVIV@05
oiVIV@03o`000?moOgooOgmo00?oOgmo00?o0000ofIVI_mVIVH01?mVIVH00ol0003oC4a<oda<C00A
oda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgooOgmoo`000003oiVIV@03o`000?nc
/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`01Oo<c<`01Ol0003o/k>cok>c/onc/k?o000000?oVIVI
00Co0000ogmoOomoOgoo00000omVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Go0000oda<
C?m<C4coC4a<o`000002ofIVIP03o`000?moOgoo000000;oVIVI00Go0000ok>c/onc/k?o/k>co`00
0008olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<
oda<C?l00008oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVIV@03o`000?nc
/k?o000000Woc<c<00_o0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`000009
oc<c<`05o`000?m<C4co0000ofIVI_l000001_ooool1o`00007ooooo0Oooool001Wooooo00Go410@
oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00?ooooo00?oVIVIo`000?moOgl02Omo
Ogl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02_mV
IVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00[oVIVI00?o0000ok>c/onc/k<06?nc
/k<00ol0003oVIVIoiVIV@06oiVIV@03o`000?moOgooOgmo00?oOgmo00?o0000ofIVI_mVIVH00omV
IVH00ol0003oC4a<oda<C00Boda<C003o`000?mVIVKoIVIV00;oIVIV00Co0000ogmoOomoOgoo0000
1?nIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<0
0_nc/k<01?l0003oVIVIoiVIVOl00003ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c
<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Ko0000ogmoOomoOgoo0000oiVI
VOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo0000
00;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`08o`000?m<C4coC4a<
o`000?mVIVKo0000ogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Wo0000ok>c/ol0
003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`03o`000?m<
C4coC4a<00;o000000?oOgmoooooooooool01?ooool1o`00007ooooo0Oooool001Wooooo00Go0000
ooooooooooooooooo`000006ooooo`?o00000oooool00ol0003oOgmoogmoO`08ogmoO`03o`000?mV
IVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0:ofIVIP;o00002_mo
Ogl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c0_l00007oiVIV@03o`000?mo
OgooOgmo00?oOgmo00?o0000ofIVI_mVIVH00omVIVH2o`0001CoC4a<00Go0000ofIVI_mVIVKoIVIV
o`000003ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001Onc/k<00ol0003oc<c<olc<c005olc<c003
o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01Ol0003oIVIVofIVI_mVIVKo
000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o
0000ogmoOol000000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Co0000ok>c/onc/k?o
00000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00So0000oda<
C?m<C4co0000ofIVI_l0003oOgmoo`0000;oVIVI00?o0000ok>c/ol000002Oo<c<`02Ol0003o/k>c
o`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00?o0000
oda<C?m<C4`00_l000000omoOgooooooooooo`02ooooo`?o00000_ooool001Wooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo00?ooooo2_moOgl00ol0003oIVIVofIVIP0;
ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`09
ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@07
oiVIV@03o`000?moOgooOgmo00?oOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00C
oda<C004o`000?mVIVKoIVIVo`0000CoOgmo00Go0000oiVIVOnIVIWoVIVIo`000005ok>c/`03o`00
0?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00onc/k<01?l0003oVIVIoiVIVOl00002ogmoO`05
o`000?mVIVKoIVIVofIVI_l000000om<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<
00;oC4a<00Ko0000ofIVI_mVIVKo0000ogmoOol00002oiVIV@05o`000?nc/k?o/k>cok>c/ol00000
2?o<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo00000_m<C4`0
0ol0003o<c<coc<c<`06oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVIV@03
o`000?nc/k?o000000Woc<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<
C4`00ol0003o<c<coc<c<`06oc<c<`03o`000?m<C4coC4a<00;o000000?oOgmoo`000?ooool01?oo
ool1o`00007ooooo0Oooool001Wooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oo
oooooooo00?ooooo2OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o
0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o
0000ok>c/onc/k<06?nc/k<00ol0003oVIVIoiVIV@06oiVIV@03o`000?moOgooOgmo00?oOgmo00?o
0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00Coda<C005o`000?mVIVKoIVIVofIVI_l00000
0omoOgl01Ol0003oVIVIoiVIVOnIVIWo000000Go/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o
/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000003
oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?mo
OgooOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01?l0003o/k>cok>c/ol00002oiVI
V@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<02?l0003oC4a<oda<C?l0
003oIVIVo`000?moOgoo00000_nIVIT00ol0003o/k>co`000009olc<c009o`000?nc/k?o0000oiVI
VOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01olc<c<01?l0003oC4a<o`00
0?l00002ogmoO`03o`000?oooooooooo00?ooooo0Ol00001ooooo`7ooooo000Iooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`03ooooo`SoOgmo00?o0000ofIVI_mVIVH0
2omVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00[oIVIV0_l0000:ogmoO`03o`00
0?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<2o`0000SoVIVI00?o0000ogmoOomoOgl0
0omoOgl00ol0003oIVIVofIVIP04ofIVIP03o`000?m<C4coC4a<01;oC4a<00?o0000ofIVI_mVIVH0
0_mVIVH00ol0003oOgmoogmoO`02o`0000?oVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<
olc<c004olc<c003o`000?nc/k?o/k>c00;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`04
o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01_lc<c<01_l0003oC4a<oda<C?m<C4co
0000ofIVIP;o000000GoOgmoo`000?nIVIWoVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<
00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`00
00So<c<c00So0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000;oVIVI00?o0000ok>c/ol00000
2Oo<c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o
<c<c00Ko<c<c00?o0000oda<C?m<C4`00_l000000omoOgoo0000ooooo`05ooooo`7o00000Oooool1
ooooo`006Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool00oooool7
ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`2o`0000coIVIV00?o0000
ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000
oiVIVOnIVIT02?nIVIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000
oda<C?m<C4`04_m<C4`00ol0003oIVIVofIVIP03ofIVIP04o`000?moOgooOgmoo`0000CoVIVI00?o
0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00;o/k>c00Go
0000oiVIVOnIVIWoVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc
<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Go0000
ok>c/onc/k?o/k>co`000008olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol00000
0_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0
0002oiVIV@03o`000?nc/k?o000000Woc<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIV
I_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`03o`000?m<C4coC4a<00;o000000?oOgmoo`00
0?ooool01Oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool6ogmoO`03
o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03
o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Hok>c/`03
o`000?nIVIWoVIVI00OoVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIVIP03ofIVIP03
o`000?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH00_mVIVH01?l0003oOgmoogmoOol00004oiVI
V@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`02ok>c
/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00004oda<C003o`000?lc
<c?o<c<c00Ko<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00Co0000oiVIVOnI
VIWo00000onc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000
ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo
0000ogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00?o0000ok>c/onc/k<00_l00000
1omoOgoo0000ofIVI_mVIVKo0000oda<C?l000002Olc<c<01?l0003oC4a<o`000?mVIVH2o`000003
oiVIVOoooooooooo00Cooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo
1OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH0
2omVIVH00ol0003oOgmoogmoO`08ogmoO`;o00003OnIVIT00ol0003o/k>cok>c/`0Gok>c/`;o0000
2OnIVIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00CoIVIV00?o0000oda<C?m<C4`0
4_m<C4`00ol0003oIVIVofIVIP02ofIVIP05o`000?moOgooOgmoogmoOol000000onIVIT00ol0003o
/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01Ol0003o
VIVIoiVIVOnIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`07
oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01?l0003o/k>c
ok>c/ol00009olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0
003oC4a<oda<C?l00008oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVIV@04
o`000?nc/k?o0000o`0000Soc<c<00Oo0000ok>c/ol0003oVIVIo`000?moOgoo000000;oIVIV00?o
0000oda<C?l000002Olc<c<01?l0003oC4a<o`000?mVIVH2o`000003oiVIVOoooooooooo00Cooooo
0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo1?moOgl00ol0003oIVIVofIV
IP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmo
O`08ogmoO`03o`000?nIVIWoVIVI00coVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVI
V@08oiVIV@03o`000?moOgooOgmo00CoOgmo00?o0000ofIVI_mVIVH01?mVIVH00ol0003oC4a<oda<
C00Boda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgooOgmoo`000003oiVIV@03o`00
0?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`04o`00
0?nIVIWoVIVIo`0000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000003oda<C003o`000?lc<c?o<c<c
00Oo<c<c00Co0000oda<C?m<C4co00000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@04o`000?nc
/k?o/k>co`0000Woc<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIVIP04
o`000?m<C4coC4a<o`0000So<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo
00000_nc/k<00ol0003oc<c<olc<c007olc<c007o`000?nc/k?o0000oiVIVOl0003oOgmoo`000002
ofIVIP03o`000?m<C4co000000Wo<c<c00Co0000oda<C?l0003oIVIV0_l000000onIVIWo0000oooo
o`04ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`?oOgmo00?o0000
ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000
ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000
oiVIVOnIVIT02?nIVIT00ol0003oOgmoogmoO`04ogmoO`03o`000?mVIVKoIVIV00CoIVIV00?o0000
oda<C?m<C4`04_m<C4`00ol0003oIVIVofIVIP02ofIVIP05o`000?moOgooOgmoogmoOol000000onI
VIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc
/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000002oda<C003
o`000?lc<c?o<c<c00Oo<c<c00Co0000oda<C?m<C4co00000_mVIVH01?l0003oOgmoogmoOol00002
oiVIV@04o`000?nc/k?o/k>co`0000Woc<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmo
o`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00So0000oda<C?m<C4co0000ofIVI_l0003o
Ogmoo`0000;oVIVI00?o0000ok>c/ol000002Oo<c<`01Ol0003o/k>co`000?nIVIWo000000;oOgmo
00Go0000ofIVI_l0003oC4a<o`000009oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nI
VIWo000000Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo0_moOgl0
0ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH0
0ol0003oOgmoogmoO`08ogmoO`;o00003OnIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWo
VIVI00SoVIVI00?o0000ogmoOomoOgl01?moOgl00ol0003oIVIVofIVIP04ofIVIP03o`000?m<C4co
C4a<01;oC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000CoVIVI00?o
0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Co
0000oiVIVOnIVIWo00000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000?oC4a<00?o0000oc<c<olc
<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT0
1?l0003o/k>cok>c/ol00009olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Go0000ogmoOol0003o
IVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00So0000oda<C?m<C4co0000ofIVI_l0003o
Ogmoo`0000;oVIVI00?o0000ok>c/ol000002Oo<c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0
003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Oo0000oda<C?m<C4co0000ofIVI_l0
003oOgmo00;o00001_ooool1o`00007ooooo0Oooool002Cooooo0_l00004ooooo`03ogmoOol0003o
IVIV00coIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgoo
Ogmo00SoOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`0Fok>c/`;o00002onIVIT0
0ol0003oOgmoogmoO`04ogmoO`03o`000?mVIVKoIVIV00CoIVIV00?o0000oda<C?m<C4`04_m<C4`0
0ol0003oIVIVofIVIP02ofIVIP05o`000?moOgooOgmoogmoOol000001?nIVIT00ol0003o/k>cok>c
/`03ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00onc/k<01?l0003oVIVIoiVI
VOl00002ogmoO`05o`000?mVIVKoIVIVofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`05
o`000?m<C4coC4a<oda<C?l000000_mVIVH00ol0003oOgmoo`000003oiVIV@04o`000?nc/k?o/k>c
o`0000Soc<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo00?o0000ofIVI_l00000
0_m<C4`00ol0003o<c<coc<c<`07oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002
oiVIV@03o`000?nc/k?o000000Woc<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0
00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`07o`000?m<C4coC4a<o`000?mVIVKo0000ogmoO`02
o`0000Gooooo0_l00002ooooo`009?ooool00ol0003oooooooooo`03ooooo`03o`000?mVIVKoIVIV
00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo
00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI
00[oVIVI00?o0000ogmoOomoOgl01?moOgl00ol0003oIVIVofIVIP04ofIVIP03o`000?m<C4coC4a<
01?oC4a<00Go0000ofIVI_mVIVKoIVIVo`000004ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001Onc
/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Co0000oiVIVOnIVIWo0000
0_moOgl01Ol0003oIVIVofIVI_mVIVKo000000CoC4a<00?o0000oc<c<olc<c<01Olc<c<01Ol0003o
C4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000onIVIT01?l0003o/k>cok>c/ol0
0008olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Go0000ogmoOol0003oIVIVo`000003oda<C003
o`000?lc<c?o<c<c00Ko<c<c00So0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000;oVIVI00?o
0000ok>c/ol000002Oo<c<`00ol0003o/k>co`000002oiVIV@;o00000_mVIVH00ol0003oC4a<o`00
0009oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000Kooooo0Ol00001oooo
o`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo3OmVIVH00ol0003oC4a<oda<C00Foda<C003
o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03
o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`04ogmoO`03
o`000?mVIVKoIVIV00CoIVIV00?o0000oda<C?m<C4`04om<C4`00ol0003oIVIVofIVIP02ofIVIP05
o`000?moOgooOgmoogmoOol000000onIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<
00?oc<c<00?o0000ok>c/onc/k<00onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Go0000
ofIVI_mVIVKoIVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<
o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01ol0
003o/k>cok>c/onc/k?o0000oiVIVOl000000_moOgl00ol0003oIVIVo`000003oda<C003o`000?lc
<c?o<c<c00Ko<c<c00So0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000;oVIVI00?o0000ok>c
/ol000002Oo<c<`01ol0003o/k>co`000?nIVIWo0000ogmoOol000000_mVIVH00ol0003oC4a<o`00
0008oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000Kooooo0Ol00001
ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo3?mVIVH00ol0003oC4a<oda<C00Foda<
C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVI
V@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`05ogmo
O`03o`000?mVIVKoIVIV00CoIVIV00?o0000oda<C?m<C4`04om<C4`01Ol0003oIVIVofIVI_mVIVKo
000000CoOgmo00Go0000oiVIVOnIVIWoVIVIo`000006ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o
0000ok>c/onc/k<00onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Go0000ofIVI_mVIVKo
IVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIV
IP04o`000?moOgooOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01ol0003o/k>cok>c
/onc/k?o0000oiVIVOl000000_moOgl00ol0003oIVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko
<c<c00So0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000;oVIVI00?o0000ok>c/ol000002Oo<
c<`01ol0003o/k>co`000?nIVIWo0000ogmoOol000000_mVIVH00ol0003oC4a<o`000008oc<c<`0:
o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000Kooooo0Ol00001ooooo`7ooooo
000Tooooo`03o`000?oooooooooo00?ooooo2omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mV
IVKoIVIV00coIVIV00?o0000ogmoOomoOgl01omoOgl2o`0000goVIVI00?o0000ok>c/onc/k<05_nc
/k<00ol0003oVIVIoiVIV@0:oiVIV@03o`000?moOgooOgmo00GoOgmo00?o0000ofIVI_mVIVH01?mV
IVH00ol0003oC4a<oda<C00Coda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgooOgmo
o`000003oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>c
ok>c/`02ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01Ol0003oIVIVofIVI_mVIVKo0000
00?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000
ogmoOomoOgoo00000_nIVIT01?l0003o/k>cok>c/ol00009olc<c006o`000?nc/k?o/k>co`000?nI
VIWo00000_moOgl00ol0003oIVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c00So0000oda<
C?m<C4co0000ofIVI_l0003oOgmoo`0000;oVIVI00?o0000ok>c/ol000002Oo<c<`00ol0003o/k>c
ok>c/`02o`000007ogmoOol0003oIVIVofIVI_l0003oC4a<o`000008oc<c<`0;o`000?m<C4coC4a<
o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k<01_ooool1o`00007ooooo0Oooool002Cooooo
00?o0000ooooooooool00oooool:ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH0
2omVIVH2o`0000WoOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`00
0?nIVIWoVIVI00[oVIVI00?o0000ogmoOomoOgl01OmoOgl00ol0003oIVIVofIVIP04ofIVIP03o`00
0?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000Co
VIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o
/k>c00Co0000oiVIVOnIVIWo00000omoOgl01?l0003oIVIVofIVI_l00004oda<C003o`000?lc<c?o
<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01_l0003oIVIVofIVI_l0003oOgmoo`0000;oVIVI
00Co0000ok>c/onc/k?o00002_o<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00?o0000
ofIVI_l000000_m<C4`2o`0000So<c<c00So0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000;o
VIVI00Co0000ok>c/ol0003o00002?o<c<`01ol0003o/k>co`000?nIVIWo0000ogmoOol000000_mV
IVH00ol0003oC4a<o`000008oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVI
o`000?nc/k?o00001Oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool9
ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmoO`08
ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0:
oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH01?mVIVH00ol0003oC4a<oda<C00C
oda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgooOgmoo`000004oiVIV@03o`000?nc
/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`04o`000?nI
VIWoVIVIo`0000?oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03
o`000?m<C4coC4a<00;oC4a<00Ko0000ofIVI_mVIVKo0000ogmoOol00002oiVIV@04o`000?nc/k?o
/k>co`0000[oc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV00Co0000oda<
C?m<C4co00002Olc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c
/`03o`000?o<c<coc<c<00Ooc<c<00Oo0000ok>c/ol0003oVIVIo`000?moOgoo000000;oIVIV00?o
0000oda<C?l000002?lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o
/k>co`0000Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo2?mVIVH0
0ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl01omoOgl2
o`0000goVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgoo
Ogmo00GoOgmo00?o0000ofIVI_mVIVH01?mVIVH00ol0003oC4a<oda<C00Coda<C003o`000?mVIVKo
IVIV00;oIVIV00?o0000ogmoOomoOgl00_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Go/k>c00?o
0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`04o`000?nIVIWoVIVIo`0000?oOgmo
00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<
C?l000000_mVIVH00ol0003oOgmoo`000002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002Oo<c<`0
1_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<c
oc<c<`07oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVIV@03o`000?nc/k?o
000000Woc<c<00Go0000ok>c/ol0003oVIVIo`000002ogmoO`05o`000?mVIVKo0000oda<C?l00000
2?lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Kooooo
0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo1omVIVH00ol0003oC4a<oda<
C00Foda<C003o`000?mVIVKoIVIV00_oIVIV0_l00009ogmoO`03o`000?nIVIWoVIVI00_oVIVI0_l0
000Hok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl01OmoOgl00ol0003oIVIVofIV
IP04ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH00_mVIVH00ol0003oOgmoogmo
O`02ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001_nc/k<00ol0003oc<c<olc<c003olc<c003o`00
0?nc/k?o/k>c00?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`05o`000?mVIVKoIVIVofIV
I_l000001?m<C4`00ol0003o<c<coc<c<`05oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH0
1?l0003oOgmoogmoOol00002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01?l0003o/k>c
ok>c/ol00002oiVIV@06o`000?moOgooOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06
oc<c<`0;o`000?m<C4coC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl000000_nc/k<00ol0
003oc<c<olc<c006olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP03o`00
0?m<C4co000000So<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c
/ol00006ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`KoIVIV00?o
0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o
0000oiVIVOnIVIT02_nIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o
0000ogmoOomoOgl01OmoOgl00ol0003oIVIVofIVIP05ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o
0000ofIVI_mVIVH00_mVIVH00ol0003oOgmoogmoO`02ogmoO`05o`000?nIVIWoVIVIoiVIVOl00000
1Onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Go0000oiVIVOnIVIWo
VIVIo`000002ogmoO`05o`000?mVIVKoIVIVofIVI_l000001?m<C4`00ol0003o<c<coc<c<`05oc<c
<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@05o`000?nc
/k?o/k>cok>c/ol000002?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@06o`000?moOgooOgmoo`00
0?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0;o`000?m<C4coC4a<oda<C?l0003oIVIV
o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c008o`000?nc/k?o/k>c
o`000?nIVIWo0000ogmoOol00002ofIVIP03o`000?m<C4co000000So<c<c00co0000oda<C?m<C4co
0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00006ooooo`7o00000Oooool1ooooo`009?oo
ool2o`0000Cooooo1OmVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o
0000ogmoOomoOgl02?moOgl2o`0000coVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVI
V@0;oiVIV@03o`000?moOgooOgmo00GoOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<
C00Coda<C003o`000?mVIVKoIVIV00?oIVIV00Go0000ogmoOomoOgooOgmoo`000003oiVIV@03o`00
0?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`04o`00
0?nIVIWoVIVIo`0000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c
00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01_l0003oIVIVofIVI_l0003oOgmoo`0000;oVIVI00?o
0000ok>c/onc/k<00_nc/k<00ol0003oc<c<olc<c005olc<c007o`000?nc/k?o/k>cok>c/ol0003o
VIVIo`000002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01olc<c<02_l0003o
C4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<
00?o0000ok>c/ol000000_nIVIT2o`0000;oIVIV00?o0000oda<C?l000002Olc<c<00ol0003oC4a<
oda<C002o`000007ogmoOol0003oVIVIo`000?nc/k?o0000olc<c005ooooo`;o00000_ooool002Co
oooo00?o0000ooooooooool00oooool4ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mV
IVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc
/k<05onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00GoOgmo00?o0000ofIVI_mV
IVH01OmVIVH2o`0001CoC4a<0_l00004ofIVIP05o`000?moOgooOgmoogmoOol000001?nIVIT00ol0
003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00onc/k<01Ol0
003oVIVIoiVIVOnIVIWo000000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000003oda<C003o`000?lc
<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;o
VIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000
ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo
0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01oo<c<`01ol0003o/k>co`000?nI
VIWo0000ogmoOol000000_mVIVH00ol0003oC4a<o`000008oc<c<`;o000000_oC4a<o`000?mVIVKo
0000ogmoOol0003oVIVIo`000?nc/k?o0000olc<c006ooooo`7o00000Oooool1ooooo`009?ooool0
0ol0003oooooooooo`03ooooo`?oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;
ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02_nIVIT00ol0003o/k>cok>c/`0G
ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl01_moOgl00ol0003oIVIVofIVIP05
ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH00omVIVH01Ol0003oOgmoogmoOomo
Ogoo000000CoVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc
/k?o/k>c00?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000Co
C4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmo
OomoOgoo00000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Co0000ok>c/onc/k?o0000
0_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000Wo<c<c00[o0000oda<C?m<
C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c007olc<c007o`00
0?nc/k?o0000oiVIVOl0003oOgmoo`000002ofIVIP03o`000?m<C4co000000So<c<c00go0000oda<
C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol0003oc<c<00Kooooo0Ol00001oooo
o`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo0omVIVH00ol0003oC4a<oda<C00Foda<C003
o`000?mVIVKoIVIV00[oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0:oiVIV@03
o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`06ogmoO`03
o`000?mVIVKoIVIV00GoIVIV00?o0000oda<C?m<C4`04om<C4`00ol0003oIVIVofIVIP03ofIVIP03
o`000?moOgooOgmo00;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000006ok>c/`03o`000?o<c<coc<c<
00?oc<c<00?o0000ok>c/onc/k<00onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Co0000
ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co
0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Ko
c<c<00Co0000ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000
oc<c<olc<c<01olc<c<01?l0003oC4a<oda<C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl00000
0_nc/k<00ol0003oc<c<olc<c006olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003o
IVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<03Ol0003oC4a<oda<C?l0003oIVIVo`000?mo
Ogoo0000oiVIVOl0003o/k>co`000?o<c<`01_ooool1o`00007ooooo0Oooool002Cooooo00?o0000
ooooooooool00oooool2ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02_mVIVH0
0ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00[oVIVI00?o0000ok>c/onc/k<05onc/k<0
0ol0003oVIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH01OmVIVH0
0ol0003oC4a<oda<C00Coda<C003o`000?mVIVKoIVIV00?oIVIV00Go0000ogmoOomoOgooOgmoo`00
0003oiVIV@;o00001Onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Go
0000oiVIVOnIVIWoVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc
<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT0
1Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmo
o`000002ofIVIP04o`000?m<C4coC4a<o`0000Wo<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003o
Ogmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c007olc<c003o`000?nc/k?o/k>c00;o0000
00OoOgmoo`000?mVIVKoIVIVo`000?m<C4co000000So<c<c00co0000oda<C?m<C4co0000ofIVI_l0
003oOgmoo`000?nIVIWo0000ok>c/ol00002olc<c0Kooooo0Ol00001ooooo`7ooooo000Tooooo`03
o`000?oooooooooo00?ooooo0_l0000Hoda<C003o`000?mVIVKoIVIV00[oIVIV0_l0000:ogmoO`03
o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@;o
00002?moOgl00ol0003oIVIVofIVIP05ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000ofIVI_mV
IVH00omVIVH01Ol0003oOgmoogmoOomoOgoo000000CoVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0
003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c00?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000003
ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<
C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003o
c<c<olc<c006olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0
003oC4a<oda<C?l00008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Go0000ogmoOol0003oVIVI
o`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmo
o`0000;oIVIV00?o0000oda<C?l000002?lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo
0000oiVIVOl0003o/k>co`0000;oc<c<1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000oooo
ooooool00ooooolIoda<C003o`000?mVIVKoIVIV00[oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0
003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0
003oOgmoogmoO`07ogmoO`03o`000?mVIVKoIVIV00KoIVIV00?o0000oda<C?m<C4`04_m<C4`00ol0
003oIVIVofIVIP04ofIVIP05o`000?moOgooOgmoogmoOol000001?nIVIT00ol0003o/k>cok>c/`03
ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00onc/k<01Ol0003oVIVIoiVIVOnI
VIWo000000?oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`03o`00
0?m<C4coC4a<00;oC4a<00Ko0000ofIVI_mVIVKo0000ogmoOol00002oiVIV@03o`000?nc/k?o/k>c
00;o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo
000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP05o`00
0?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c008o`000?nc/k?o/k>co`00
0?nIVIWo0000ogmoOol00002ofIVIP03o`000?m<C4co000000So<c<c00co0000oda<C?m<C4co0000
ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00002olc<c0Kooooo0Ol00001ooooo`7ooooo000T
ooooo`03o`000?oooooooooo00?ooooo6?m<C4`00ol0003oIVIVofIVIP0:ofIVIP03o`000?moOgoo
Ogmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWo
VIVI00_oVIVI00?o0000ogmoOomoOgl01omoOgl00ol0003oIVIVofIVIP06ofIVIP03o`000?m<C4co
C4a<01?oC4a<00?o0000ofIVI_mVIVH00omVIVH01Ol0003oOgmoogmoOomoOgoo000000CoVIVI00?o
0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Co
0000oiVIVOnIVIWo00000omoOgl01?l0003oIVIVofIVI_l00004oda<C003o`000?lc<c?o<c<c00Go
<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVI
o`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?mo
Ogoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP05
o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c006o`000?nc/k?o/k>c
o`000?nIVIWo00000_moOgl01Ol0003oIVIVo`000?m<C4co000000Wo<c<c00Wo0000oda<C?l0003o
IVIVo`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006ooooo`7o00000Oooool1
ooooo`009?ooool00ol0003oooooooooo`03oooooaOoC4a<00?o0000ofIVI_mVIVH02_mVIVH2o`00
00[oOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI
00_oVIVI00?o0000ogmoOomoOgl01omoOgl00ol0003oIVIVofIVIP06ofIVIP03o`000?m<C4coC4a<
01CoC4a<00?o0000ofIVI_mVIVH00_mVIVH00ol0003oOgmoogmoO`02ogmoO`05o`000?nIVIWoVIVI
oiVIVOl000001onc/k<00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c00?o/k>c00Go0000
oiVIVOnIVIWoVIVIo`000002ogmoO`05o`000?mVIVKoIVIVofIVI_l000000om<C4`00ol0003o<c<c
oc<c<`06oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl00ol0003o
VIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVI
V@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<01?l0003oC4a<oda<C?l0
0002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c008o`00
0?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP03o`000?m<C4co000000Wo<c<c00_o0000
oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`000003olc<c0Kooooo0Ol00001oooo
o`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo5Om<C4`2o`0000coIVIV00?o0000ogmoOomo
Ogl02OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnI
VIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00GoIVIV00?o0000oda<C?m<
C4`05Om<C4`00ol0003oIVIVofIVIP02ofIVIP03o`000?moOgooOgmo00;oOgmo00Go0000oiVIVOnI
VIWoVIVIo`000007ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00onc/k<01Ol0
003oVIVIoiVIVOnIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c
<`06oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl00ol0003oVIVI
o`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@03
o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<01?l0003oC4a<oda<C?l00002
ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c008o`000?nc
/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP03o`000?m<C4co000000Wo<c<c00_o0000oda<
C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`000003olc<c0Kooooo0Ol00001ooooo`7o
oooo000Tooooo`03o`000?oooooooooo00?ooooo5?m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`00
0?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`00
0?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP05ofIVIP03o`00
0?m<C4coC4a<01GoC4a<00?o0000ofIVI_mVIVH00_mVIVH00ol0003oOgmoogmoO`02ogmoO`05o`00
0?nIVIWoVIVIoiVIVOl000001onc/k<00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c00?o
/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`05o`000?mVIVKoIVIVofIVI_l000000om<C4`0
0ol0003o<c<coc<c<`06oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_mo
Ogl00ol0003oVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>c
o`000002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<01?l0003o
C4a<oda<C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007
olc<c003o`000?nc/k?o000000;oVIVI0_l00002ofIVIP03o`000?m<C4co000000Wo<c<c00?o0000
oda<C?m<C4`00_l000001_moOgoo0000oiVIVOl0003o/k>co`0000Coc<c<1_ooool1o`00007ooooo
0Oooool002Cooooo0_l00004oooooa?oC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmo
O`08ogmoO`;o00003OnIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o
0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP06ofIVIP03o`000?m<C4coC4a<01?oC4a<0_l0
0004ofIVIP03o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c
/`04ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00onc/k<01Ol0003oVIVIoiVI
VOnIVIWo000000?oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`06oc<c<`05
o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@05o`000?nc/k?o
/k>cok>c/ol000002?o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmoOol00000
0_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Go0000ogmo
Ool0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Oo0000ok>c/ol0003oVIVIo`00
0?moOgoo000000;oIVIV00?o0000oda<C?l000002?lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`00
0?moOgoo0000oiVIVOl0003o/k>co`0000Coc<c<1Oooool2o`0000;ooooo000Tooooo`03o`000?oo
oooooooo00?ooooo4_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o
0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00coVIVI00?o
0000ogmoOomoOgl01omoOgl00ol0003oIVIVofIVIP07ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o
0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o
0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c00Co/k>c00Go
0000oiVIVOnIVIWoVIVIo`000003ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc
<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT0
1Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@05o`00
0?moOgoo0000ofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`00
00;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Oo0000
ok>c/ol0003oVIVIo`000?moOgoo000000;oIVIV00?o0000oda<C?l000002?lc<c<03?l0003oC4a<
oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Coc<c<1_ooool1o`00007ooooo
0Oooool002Cooooo00?o0000ooooooooool00ooooolAoda<C003o`000?mVIVKoIVIV00_oIVIV00?o
0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o
0000oiVIVOnIVIT02onIVIT2o`0000WoOgmo00?o0000ofIVI_mVIVH01omVIVH00ol0003oC4a<oda<
C00Coda<C003o`000?mVIVKoIVIV00?oIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVI
V@02oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c
/`04ok>c/`04o`000?nIVIWoVIVIo`0000?oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o
<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002
oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI
00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`0:o`000?m<C4coC4a<o`00
0?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01oo<c<`00ol0003o/k>c
ok>c/`02o`000005ogmoOol0003oIVIVofIVI_l000000_m<C4`00ol0003o<c<coc<c<`05oc<c<`06
o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl2o`000003ok>c/ol0003oc<c<00Coc<c<1_ooool1
o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool@oda<C003o`000?mVIVKoIVIV
00_oIVIV00?o0000ogmoOomoOgl02?moOgl2o`0000goVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0
003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH01omVIVH00ol0
003oC4a<oda<C00Doda<C003o`000?mVIVKoIVIV00?oIVIV00Go0000ogmoOomoOgooOgmoo`000004
oiVIV@03o`000?nc/k?o/k>c00Go/k>c00?o0000olc<c?o<c<`00_o<c<`00ol0003o/k>cok>c/`04
ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000CoC4a<
00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;o
Ogmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c007o`000?nc/k?o/k>c
ok>c/ol0003oVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000;oC4a<00?o0000oc<c<olc<c<0
1_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0
003oc<c<olc<c006olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP03o`00
0?m<C4co000000So<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c
/ol00005olc<c0Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo3om<
C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT03?nI
VIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?mo
Ogl00ol0003oIVIVofIVIP07ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH00omV
IVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01Onc
/k<00ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c00Co/k>c00Go0000oiVIVOnIVIWoVIVI
o`000002ogmoO`05o`000?mVIVKoIVIVofIVI_l000001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03
o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00003
ok>c/`03o`000?o<c<coc<c<00Koc<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo
00Co0000ofIVI_mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`00
00;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00So0000
ok>c/onc/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV00?o0000oda<C?l000002?lc<c<03?l0003o
C4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Goc<c<1_ooool1o`00007o
oooo0Oooool002Cooooo00?o0000ooooooooool00oooool>oda<C003o`000?mVIVKoIVIV00_oIVIV
00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c
00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00SoIVIV
00?o0000oda<C?m<C4`04om<C4`00ol0003oIVIVofIVIP03ofIVIP03o`000?moOgooOgmo00;oOgmo
00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`05ok>c/`03o`000?o<c<coc<c<00;oc<c<
00?o0000ok>c/onc/k<01?nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Co0000ofIVI_mV
IVKo00001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIV
I_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Co
0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So
<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVIV@03o`000?nc/k?o0000
00Soc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`05o`000?mVIVKo0000oda<C?l00000
2Olc<c<00ol0003oC4a<o`000002ofIVIP;o000000GoVIVIo`000?nc/k?o/k>co`000005olc<c0Ko
oooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo3Om<C4`00ol0003oIVIV
ofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo0_l0000=oiVIV@03o`000?nc/k?o/k>c01Ko/k>c
00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00SoIVIV
00?o0000oda<C?m<C4`05?m<C4`00ol0003oIVIVofIVIP03ofIVIP03o`000?moOgooOgmo00;oOgmo
00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00;oc<c<
00?o0000ok>c/onc/k<01?nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Go0000ofIVI_mV
IVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0
003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<
c<`01?l0003o/k>cok>c/ol00002oiVIV@06o`000?moOgooOgmoo`000?mVIVKo00000_m<C4`00ol0
003o<c<coc<c<`07oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Go0000ogmoOol0003oVIVIo`00
0002ok>c/`03o`000?o<c<coc<c<00Koc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`00
00;oIVIV00?o0000oda<C?l000002Olc<c<02ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVI
o`000?nc/k?o000000Koc<c<1_ooool1o`00007ooooo0Oooool001Wooooo1Ol00006ooooo`03o`00
0?oooooooooo00?ooooo3?m<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?moOgooOgmo00OoOgmo
00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI
00?o0000ogmoOomoOgl02?moOgl2o`0000WoIVIV00?o0000oda<C?m<C4`05Om<C4`00ol0003oIVIV
ofIVIP03ofIVIP03o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>c
ok>c/`04ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o0000ok>c/onc/k<01?nc/k<01Ol0003oVIVI
oiVIVOnIVIWo000000?oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c
00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWo
VIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@06o`00
0?moOgooOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`07oc<c<`04o`000?m<C4coC4a<
o`0000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00So
0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV00?o0000oda<C?l000002Olc<c<02ol0
003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o000000Koc<c<1_ooool1o`00007o
oooo0Oooool001Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo00?o
oooo2om<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnI
VIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomo
Ogl02?moOgl00ol0003oIVIVofIVIP08ofIVIP03o`000?m<C4coC4a<01GoC4a<00?o0000ofIVI_mV
IVH00omVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc
/k<01?nc/k<00ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c00Go/k>c00Co0000oiVIVOnI
VIWo00000omoOgl01Ol0003oIVIVofIVI_mVIVKo000000CoC4a<00?o0000oc<c<olc<c<01_lc<c<0
1Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01Ol0003o/k>c
ok>c/onc/k?o000000Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT01_l0003oOgmoogmoOol0003o
IVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP05o`00
0?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`00
00;oVIVI0_l00002ofIVIP03o`000?m<C4co000000Wo<c<c00Oo0000oda<C?l0003oIVIVo`000?mo
Ogoo000000;oVIVI0_l00007olc<c0Kooooo0Ol00001ooooo`7ooooo000Jooooo`03oiRHV?lQ8B7o
k^k^00Oooooo00?o0000ooooooooool00oooool:oda<C003o`000?mVIVKoIVIV00_oIVIV0_l0000:
ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;
oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02?mVIVH00ol0003oC4a<oda<C00E
oda<C003o`000?mVIVKoIVIV00?oIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@02
oiVIV@03o`000?nc/k?o/k>c00Go/k>c00?o0000olc<c?o<c<`00_o<c<`00ol0003o/k>cok>c/`04
ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01?l0003oIVIVofIVI_l00004oda<C003o`00
0?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000003ofIVIP03o`000?moOgoo000000?o
VIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Ko0000
ogmoOomoOgoo0000ofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Ko0000oda<C?m<C4co
0000ofIVI_l00002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02?l0
003o/k>cok>c/ol0003oVIVIo`000?moOgoo00000_mVIVH00ol0003oC4a<o`000008oc<c<`0<o`00
0?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00001oo<c<`6ooooo`7o0000
0Oooool1ooooo`006oooool00onHV9So8B4Qonk^kP06ooooo`?o00000oooool9oda<C003o`000?mV
IVKoIVIV00coIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc
/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`;o00002_mV
IVH00ol0003oC4a<oda<C00Doda<C003o`000?mVIVKoIVIV00?oIVIV00?o0000ogmoOomoOgl00omo
Ogl00ol0003oVIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c00Go/k>c00?o0000olc<c?o<c<`00_o<
c<`00ol0003o/k>cok>c/`04ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01?l0003oIVIV
ofIVI_l00004oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000003ofIV
IP03o`000?moOgoo000000?oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c004o`000?nc/k?o
/k>co`0000;oVIVI00Ko0000ogmoOomoOgoo0000ofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko
<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000
olc<c?o<c<`01_o<c<`02?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo00000_mVIVH00ol0003o
C4a<o`000008oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o
00001oo<c<`4ooooo`?o00000_ooool001cooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooo
ooooo`03ooooo`SoC4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmoO`07ogmoO`;o0000
3OnIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl0
2?moOgl00ol0003oIVIVofIVIP09ofIVIP03o`000?m<C4coC4a<01GoC4a<00?o0000ofIVI_mVIVH0
0omVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<0
1Onc/k<00ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c00Co/k>c00Go0000oiVIVOnIVIWo
VIVIo`000003ogmoO`04o`000?mVIVKoIVIVo`0000GoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0
003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo00000onc
/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Co0000ogmoOomoOgoo
00000_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`03o`000?m<C4coC4a<00;o00000_moOgl00ol0
003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o/k>c0_l00000
1OmoOgoo0000ofIVI_mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<o`00
0?mVIVKo000000;oOgmo0_l000000onc/k?o0000olc<c007olc<c0Kooooo0Ol00001ooooo`7ooooo
000Mooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool7oda<C003o`000?mV
IVKoIVIV00_oIVIV0_l00009ogmoO`03o`000?nIVIWoVIVI00_oVIVI0_l0000Hok>c/`03o`000?nI
VIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP09ofIVIP03o`000?m<
C4coC4a<01GoC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nI
VIWoVIVI00;oVIVI0_l00007ok>c/`05o`000?o<c<coc<c<olc<c?l000001_nc/k<01Ol0003oVIVI
oiVIVOnIVIWo000000?oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c
00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Go
0000ok>c/onc/k?o/k>co`000008olc<c0;o00000_nc/k<01_l0003oVIVIoiVIVOl0003oOgmoo`00
00;oIVIV00Co0000oda<C?m<C4co00002Olc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo
00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c008o`000?nc/k?o/k>co`000?nI
VIWo0000ogmoOol00002ofIVIP03o`000?m<C4co000000So<c<c00co0000oda<C?m<C4co0000ofIV
I_l0003oOgmoo`000?nIVIWo0000ok>c/ol00008olc<c0Kooooo0Ol00001ooooo`7ooooo000Ioooo
o`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`03ooooo`KoC4a<00?o0000
ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00[oVIVI00?o0000
ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo0_l0000;
ofIVIP03o`000?m<C4coC4a<01GoC4a<00?o0000ofIVI_mVIVH00omVIVH01Ol0003oOgmoogmoOomo
Ogoo000000GoVIVI00?o0000ok>c/onc/k<01_nc/k<01Ol0003oc<c<olc<c?o<c<co000000Ko/k>c
00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`05o`000?mVIVKoIVIVofIVI_l000001?m<C4`00ol0
003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl0
1?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>c
o`000002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<01_l0003o
C4a<oda<C?l0003oIVIVo`0000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006
olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP03o`000?m<C4co000000So
<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00008olc<c0Ko
oooo0Ol00001ooooo`7ooooo000;ooooo`?o000000?o410@ooooooooool02?ooool01OnHV9So410@
o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool00oooool5oda<C003o`000?mVIVKoIVIV00_o
IVIV00?o0000ogmoOomoOgl02?moOgl2o`0000coVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003o
VIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02_mVIVH00ol0003o
C4a<oda<C00Eoda<C003o`000?mVIVKoIVIV00?oIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003o
VIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c00Ko/k>c00Go0000olc<c?o<c<coc<c<o`000006ok>c
/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01Ol0003oIVIVofIVI_mVIVKo000000CoC4a<00?o
0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo
00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o
/k>c00Go0000oiVIVOl0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000Wo<c<c00Ko0000
oda<C?m<C4co0000ofIVI_l00002ogmoO`06o`000?nIVIWoVIVIo`000?nc/k?o00002?o<c<`01_l0
003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00Go0000ofIVI_l0003oC4a<o`000009oc<c<`09o`00
0?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`0
0ol0003oooooooooo`03ooooo`7o00000Oooool1ooooo`003Oooool00ol@413o^[Zjooooo`0Doooo
o`03o`000?oooooooooo00?ooooo1?m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo
00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI
00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<
01CoC4a<0_l00005ofIVIP03o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0
003o/k>cok>c/`05ok>c/`;o00000_o<c<`00ol0003o/k>cok>c/`05ok>c/`05o`000?nIVIWoVIVI
oiVIVOl000000omoOgl01?l0003oIVIVofIVI_l00005oda<C003o`000?lc<c?o<c<c00Go<c<c00?o
0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000?o
/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmo
Ool000000_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo0000
0_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Oo0000ok>c/onc/k?o
0000oiVIVOl0003oOgmo00;o000000CoIVIVo`000?m<C4co00002Olc<c<02Ol0003oC4a<o`000?mV
IVKo0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o0000oooooooo
ool00oooool1o`00007ooooo0Oooool000gooooo00?oV9RHoc8b<_ooool05?ooool00ol0003ooooo
ooooo`03ooooo`?oC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`00
0?nIVIWoVIVI00[oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`00
0?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<oda<C00Eoda<C003o`00
0?mVIVKoIVIV00CoIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@03oiVIV@03o`00
0?nc/k?o/k>c00Go/k>c00Go0000ok>c/ol0003oc<c<o`000007ok>c/`05o`000?nIVIWoVIVIoiVI
VOl000000omoOgl01?l0003oIVIVofIVI_l00005oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000
oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c
00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmoOol0
00000_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_mo
Ogl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00So0000ok>c/onc/k?o0000
oiVIVOl0003oOgmoo`0000;oIVIV00?o0000oda<C?l000002Olc<c<02Ol0003oC4a<o`000?mVIVKo
0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o0000ooooooooool0
0oooool1o`00007ooooo0Oooool000gooooo00?ogMgMo`000?nj^[X05?ooool00ol0003ooooooooo
o`03ooooo`?oC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nI
VIWoVIVI00[oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?mo
OgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<oda<C00Doda<C003o`000?mV
IVKoIVIV00CoIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc
/k?o/k>c00Ko/k>c00Co0000ok>c/onc/k?o00001onc/k<00ol0003oVIVIoiVIV@02oiVIV@04o`00
0?moOgooOgmoo`0000?oIVIV00?o0000oda<C?m<C4`00_m<C4`00ol0003o<c<coc<c<`05oc<c<`03
o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00004
ok>c/`03o`000?o<c<coc<c<00Koc<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo
00?o0000ofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`09o`000?m<C4coC4a<oda<C?l0
003oIVIVo`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`02?l0003o/k>cok>c
/ol0003oVIVIo`000?moOgoo00000_mVIVH00ol0003oC4a<o`000008oc<c<`03o`000?m<C4co0000
00;oIVIV00Oo0000ogmoOol0003oVIVIo`000?nc/k?o000000Woc<c<00?o0000ooooooooool00ooo
ool1o`00007ooooo0Oooool000gooooo00?oEEEEogMgMom4A4@05?ooool00ol0003oooooooooo`03
ooooo`;oC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWo
VIVI00[oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0<oiVIV@03o`000?moOgoo
Ogmo00SoOgmo00?o0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<oda<C00Eoda<C003o`000?mVIVKo
IVIV00CoIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o
/k>c00Go/k>c00?o0000olc<c?l000002Onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Co
0000ofIVI_mVIVKo00001Om<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<
00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<
00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000
oda<C?m<C4co00002?lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Go0000ogmoOol0003o
VIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT2o`00
00;oIVIV00?o0000oda<C?l000002Olc<c<01ol0003oC4a<o`000?mVIVKo0000ogmoOol000000_nI
VIT00ol0003o/k>co`000008olc<c003o`000?oooooooooo00Cooooo0Ol00001ooooo`7ooooo000<
ooooo`05omgMgOl@413oooooob4Q8OoMgMd04oooool00ol0003oooooooooo`03ooooo`03oda<C?l0
003oIVIV00_oIVIV0_l0000:ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc
/k<00ol0003oVIVIoiVIV@0;oiVIV@;o00002OmoOgl2o`0000coIVIV00?o0000oda<C?m<C4`05Om<
C4`00ol0003oIVIVofIVIP04ofIVIP03o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00onI
VIT00ol0003o/k>cok>c/`06ok>c/`04o`000?o<c<coc<c<o`0000Oo/k>c00Go0000oiVIVOnIVIWo
VIVIo`000003ogmoO`05o`000?mVIVKoIVIVofIVI_l000001?m<C4`00ol0003o<c<coc<c<`05oc<c
<`03o`000?m<C4coC4a<00;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`04o`000?nIVIWo
VIVIo`0000?o/k>c00?o0000olc<c?o<c<`01Oo<c<`2o`0000?o/k>c00?o0000oiVIVOl000000_mo
Ogl01?l0003oIVIVofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Wo0000oda<C?m<C4co
C4a<o`000?mVIVKo0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00008olc<c008o`000?nc
/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP03o`000?m<C4co000000So<c<c00co0000oda<
C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00009olc<c003o`000?oooooooooo
00Cooooo0Ol00001ooooo`7ooooo000<ooooo`05ofIVI_n7QhOooooooiRHV?mEEED04oooool2o`00
00Cooooo00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI
00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo
00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Eoda<C003o`000?mVIVKoIVIV
00?oIVIV00?o0000ogmoOomoOgl00omoOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c
00Ko/k>c00Co0000olc<c?o<c<co00001_nc/k<00ol0003oVIVIoiVIV@02oiVIV@05o`000?moOgoo
OgmoogmoOol000000omVIVH00ol0003oC4a<oda<C002oda<C003o`000?lc<c?o<c<c00Go<c<c00?o
0000oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo
00000onc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00?o0000oiVIVOl0
00000_moOgl01?l0003oIVIVofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Wo0000oda<
C?m<C4coC4a<o`000?mVIVKo0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00008olc<c003
o`000?nc/k?o000000;oVIVI00?o0000ogmoOol000000_mVIVH00ol0003oC4a<o`000008oc<c<`0<
o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00002Oo<c<`00ol0003o
ooooooooo`03ooooo`;o00000_ooool000_ooooo00?ok^k^o`000?o^k^h00_ooool00ol0003ogMgM
ooooo`0Aooooo`03o`000?oooooooooo00?ooooo3?mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`00
0?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`00
0?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Eoda<C003o`00
0?mVIVKoIVIV00CoIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@03oiVIV@03o`00
0?nc/k?o/k>c00So/k>c0_l00007ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01Ol0003o
IVIVofIVI_mVIVKo000000CoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<
C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<
c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@03o`000?moOgoo000000;oIVIV
00Co0000oda<C?m<C4co00002?lc<c<02Ol0003oC4a<oda<C?m<C4co0000ofIVI_l0003oOgmoo`00
0002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmo
o`0000;oIVIV00Co0000oda<C?m<C4co00001olc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?mo
Ogoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o0000ok>c/oooool01Oooool1
o`00007ooooo0Oooool000_ooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`0@
ooooo`03o`000?oooooooooo00?ooooo2omVIVH2o`0000[oOgmo00?o0000oiVIVOnIVIT02onIVIT0
0ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl2
o`0000goIVIV00?o0000oda<C?m<C4`05Om<C4`00ol0003oIVIVofIVIP04ofIVIP03o`000?moOgoo
Ogmo00?oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`09ok>c/`03o`000?nc/k?o
/k>c00Ko/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`05o`000?mVIVKoIVIVofIVI_l00000
1?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo
00000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0
003o/k>cok>c/ol00002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Co0000oda<C?m<C4co0000
2?lc<c<02Ol0003oC4a<oda<C?m<C4co0000ofIVI_l0003oOgmoo`000002oiVIV@04o`000?nc/k?o
/k>co`0000Soc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV00?o0000oda<
C?l000002?lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03
o`000?o<c<coc<c<00Koc<c<00?o0000ok>c/ol000001Oooool1o`00007ooooo0Oooool002Cooooo
00?o0000ooooooooool00oooool:ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT0
2onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl0
2OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01GoC4a<00?o0000ofIVI_mVIVH0
1OmVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<0
4onc/k<01?l0003oVIVIoiVIVOl00004ogmoO`05o`000?mVIVKoIVIVofIVI_l000001?m<C4`00ol0
003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl0
1Ol0003oVIVIoiVIVOnIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c
/ol00002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<02Ol0
003oC4a<oda<C?m<C4co0000ofIVI_l0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000So
c<c<00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV00?o0000oda<C?l000002?lc
<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<co
c<c<00Koc<c<00?o0000ok>c/ol000001Oooool1o`00007ooooo0Oooool002Cooooo00?o0000oooo
ooooool00oooool9ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0
003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0
003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH01?mVIVH00ol0
003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<04_nc/k<01Ol0
003oVIVIoiVIVOnIVIWo000000?oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc
<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`05o`00
0?nIVIWoVIVIoiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`00
00;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`07o`000?m<
C4coC4a<oda<C?l0003oIVIVo`000002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<
c<`01_o<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00Go0000ofIVI_l0003oC4a<o`00
0009oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<
c?o<c<`01_o<c<`00ol0003o/k>co`000006ooooo`7o00000Oooool1ooooo`009?ooool00ol0003o
ooooooooo`03ooooo`SoIVIV00?o0000ogmoOomoOgl02?moOgl2o`0000goVIVI00?o0000ok>c/onc
/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo0_l0000=ofIVIP03
o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH01?mVIVH00ol0003oOgmoogmoO`03ogmoO`03
o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<04_nc/k<01Ol0003oVIVIoiVIVOnIVIWo0000
00?oOgmo00Go0000ofIVI_mVIVKoIVIVo`000005oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000
oda<C?m<C4`00_m<C4`2o`0000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT00ol0003o/k>cok>c
/`02ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT01_l0003oOgmo
ogmoOol0003oIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002
ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`02?l0003o/k>cok>c
/ol0003oVIVIo`000?moOgoo00000_mVIVH00ol0003oC4a<o`000009oc<c<`09o`000?m<C4co0000
ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003o/k>c
o`000006ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`OoIVIV00?o
0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o
0000oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o
0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP05ofIVIP03o`000?moOgooOgmo00?oOgmo00?o
0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`0Aok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go
0000ogmoOomoOgooOgmoo`000003ofIVIP03o`000?m<C4coC4a<00?oC4a<00?o0000oc<c<olc<c<0
1?lc<c<00ol0003oC4a<oda<C002oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01?l0003o
VIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Goc<c<00Go0000ok>c/onc/k?o/k>co`000002
oiVIV@06o`000?moOgooOgmoo`000?mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`04o`00
0?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00008olc<
c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP03o`000?m<C4co000000Wo<c<c
00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006
olc<c003o`000?nc/k?o000000Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo
00?ooooo1_mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c
/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@;o00002_moOgl00ol0003oIVIVofIVIP0;ofIV
IP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH01OmVIVH00ol0003oOgmoogmoO`03ogmo
O`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<04_nc/k<01Ol0003oVIVIoiVIVOnIVIWo
000000?oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C002oda<C003o`000?lc<c?o
<c<c00Co<c<c00?o0000oda<C?m<C4`00_m<C4`00ol0003oIVIVofIVIP02ofIVIP04o`000?moOgoo
Ogmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`000007olc<c005o`000?nc/k?o/k>cok>c/ol0
00000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Co0000
oda<C?m<C4co00000omVIVH2o`0000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`02?l0003o/k>c
ok>c/ol0003oVIVIo`000?moOgoo00000_mVIVH00ol0003oC4a<o`000009oc<c<`09o`000?m<C4co
0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o
/k>co`000?nIVIT6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`Go
IVIV00?o0000ogmoOomoOgl02?moOgl2o`0000goVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003o
VIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02_mVIVH2o`0001So
C4a<00?o0000ofIVI_mVIVH01OmVIVH00ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00?o
VIVI00?o0000ok>c/onc/k<04Onc/k<00ol0003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmo
Ool000000omVIVH00ol0003oC4a<oda<C002oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<
C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo00000onc
/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01_l0003oOgmo
ogmoOol0003oIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002
ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`02_l0003o/k>cok>c
/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00co0000
oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00009olc<c005o`000?nc/k?o
0000oiVIVOl000001Oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool4
ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`0F
ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl2o`0000coIVIV00?o0000
oda<C?m<C4`06?m<C4`00ol0003oIVIVofIVIP05ofIVIP03o`000?moOgooOgmo00;oOgmo00?o0000
oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0Bok>c/`05o`000?nIVIWoVIVIoiVIVOl000001?mo
Ogl01Ol0003oIVIVofIVI_mVIVKo000000CoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<
oda<C002oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00003ok>c
/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000onIVIT01_l0003oOgmoogmoOol0
003oIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP03
o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`02_l0003o/k>cok>c/ol0003o
VIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00co0000oda<C?m<
C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00009olc<c005o`000?nc/k?o0000oiVI
VOl000001Oooool1o`00007ooooo0Oooool002Cooooo0_l00004ooooo`?oIVIV00?o0000ogmoOomo
Ogl02OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnI
VIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<
C4`06?m<C4`00ol0003oIVIVofIVIP05ofIVIP03o`000?moOgooOgmo00?oOgmo00?o0000oiVIVOnI
VIT00onIVIT00ol0003o/k>cok>c/`0Aok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomo
OgooOgmoo`000003ofIVIP03o`000?m<C4coC4a<00;oC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0
003oC4a<oda<C002oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl0
0004ok>c/`03o`000?o<c<coc<c<00Goc<c<00Go0000ok>c/onc/k?o/k>co`000003oiVIV@05o`00
0?moOgoo0000ofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`00
00;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00008olc<c008o`000?nc/k?o
/k>co`000?nIVIWo0000ogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Wo0000oda<
C?l0003oIVIVo`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c005o`00
0?nc/k?o0000oiVIVOl000001Oooool2o`0000;ooooo000Tooooo`03o`000?oooooooooo00?ooooo
0_mVIVH00ol0003oOgmoogmoO`08ogmoO`;o00003OnIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`00
0?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`00
0?m<C4coC4a<01OoC4a<0_l00007ofIVIP03o`000?moOgooOgmo00?oOgmo00?o0000oiVIVOnIVIT0
0onIVIT00ol0003o/k>cok>c/`0Bok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01Ol0003o
IVIVofIVI_mVIVKo000000GoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<
C004o`000?mVIVKoIVIVo`0000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000003ok>c/`03o`000?o<
c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@03o`000?moOgoo000000;oIVIV
00Co0000oda<C?m<C4co00002Olc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo0000
00;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`02Ol0003o/k>cok>c/ol0003oVIVIo`000?moOgoo
0000ofIVIP02o`000003oda<C?l0003o<c<c00Oo<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003o
Ogmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o0000oiVIVOl0
00001_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool2ofIVIP03o`00
0?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`00
0?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl2o`0000coIVIV00?o0000oda<C?m<C4`0
6?m<C4`00ol0003oIVIVofIVIP06ofIVIP03o`000?moOgooOgmo00?oOgmo00?o0000oiVIVOnIVIT0
0onIVIT00ol0003o/k>cok>c/`0Aok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomoOgoo
Ogmoo`000003ofIVIP03o`000?m<C4coC4a<00?oC4a<00?o0000oc<c<olc<c<01Olc<c<01Ol0003o
C4a<oda<C?m<C4co000000?oIVIV00Co0000ogmoOomoOgoo00000onIVIT01Ol0003o/k>cok>c/onc
/k?o000000Soc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@03o`000?moOgoo000000;oIVIV
00Co0000oda<C?m<C4co00002Olc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo0000
00;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo
0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00[o0000oda<C?m<C4co0000ofIVI_l0
003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o0000oiVI
VOl000001_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool00omVIVKo
0000ogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003o
VIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003o
C4a<oda<C00Hoda<C003o`000?mVIVKoIVIV00KoIVIV00?o0000ogmoOomoOgl00omoOgl00ol0003o
VIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c01;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmo
O`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`04oc<c
<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000omoOgl01?l0003oVIVIoiVIVOl0
0003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@03o`00
0?moOgoo000000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`04o`000?m<C4coC4a<o`00
00;oIVIV00Ko0000ogmoOomoOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00[o
0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`07
oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<
c<`01_o<c<`00ol0003o/k>cok>c/`02o`000003ogmoOooooooooooo00Cooooo0Ol00001ooooo`7o
oooo000Tooooo`03o`000?oooooooooo00?ooooo00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVI
oiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmo
ogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`06?m<C4`00ol0003oIVIV
ofIVIP06ofIVIP03o`000?moOgooOgmo00?oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>c
ok>c/`0Bok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`000003ofIVIP03
o`000?m<C4coC4a<00?oC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C002oda<C005
o`000?mVIVKoIVIVofIVI_l000000_moOgl00ol0003oVIVIoiVIV@02o`0000?o/k>c00?o0000olc<
c?o<c<`01_o<c<`01ol0003o/k>cok>c/onc/k?o0000oiVIVOl000000_moOgl01?l0003oIVIVofIV
I_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH01Ol0003o
Ogmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`02_l0003o/k>cok>c/ol0003o
VIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Wo0000oda<C?l0
003oIVIVo`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c006o`000?nc
/k?o0000oiVIVOl0003oOgmo1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool0
0oooool:ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVI
oiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo0_l0000<ofIVIP03o`000?m<C4coC4a<01SoC4a<
00?o0000ofIVI_mVIVH01_mVIVH00ol0003oOgmoogmoO`04ogmoO`03o`000?nIVIWoVIVI00?oVIVI
00?o0000ok>c/onc/k<04_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000CoOgmo00Go0000ofIVI_mV
IVKoIVIVo`000005oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0
003oIVIVofIVI_mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<
c005olc<c003o`000?nc/k?o/k>c00;o/k>c00?o0000oiVIVOl000000_moOgl01?l0003oIVIVofIV
I_l00003oda<C003o`000?lc<c?o<c<c00Go<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo0000
00;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c00:o`000?nc/k?o/k>c
o`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01olc<c<02ol0003o
C4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o000000Woc<c<00Oo0000ok>c/ol0003o
VIVIo`000?moOgoo000000Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?o
oooo2?moOgl2o`0000goVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03
o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Hoda<C003
o`000?mVIVKoIVIV00KoIVIV00?o0000ogmoOomoOgl01?moOgl00ol0003oVIVIoiVIV@03oiVIV@03
o`000?nc/k?o/k>c01;o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo0000
00?oIVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<
00;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o
0000olc<c?o<c<`01_o<c<`01ol0003o/k>cok>c/onc/k?o0000oiVIVOl000000omoOgl01?l0003o
IVIVofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH0
1Ol0003oOgmoo`000?nIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`02_l0003o/k>cok>c
/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Wo0000
oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c005
o`000?nc/k?o0000oiVIVOl000000_moOgl00ol0003oooooooooo`03ooooo`7o00000Oooool1oooo
o`009?ooool00ol0003oooooooooo`03ooooo`OoOgmo00?o0000oiVIVOnIVIT02onIVIT2o`0001So
/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_o
IVIV00?o0000oda<C?m<C4`06?m<C4`00ol0003oIVIVofIVIP06ofIVIP03o`000?moOgooOgmo00Co
Ogmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0Bok>c/`03o`000?nIVIWoVIVI00;o
VIVI00Go0000ogmoOomoOgooOgmoo`000003ofIVIP03o`000?m<C4coC4a<00?oC4a<00?o0000oc<c
<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl0
1?l0003oVIVIoiVIVOl00003ok>c/`;o00001oo<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI
00Co0000ogmoOomoOgoo00000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`07o`000?m<C4coC4a<
oda<C?l0003oIVIVo`000002ogmoO`03o`000?nIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<
c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o
<c<c00Ko<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0
003oc<c<olc<c006olc<c007o`000?nc/k?o0000oiVIVOl0003oOgmoo`000006ooooo`7o00000Ooo
ool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`OoOgmo00?o0000oiVIVOnIVIT02_nIVIT0
0ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl2
o`0000coIVIV00?o0000oda<C?m<C4`06?m<C4`00ol0003oIVIVofIVIP07ofIVIP03o`000?moOgoo
Ogmo00CoOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0Bok>c/`03o`000?nIVIWo
VIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`000003ofIVIP03o`000?m<C4coC4a<00?oC4a<00?o
0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C005o`000?mVIVKoIVIVofIVI_l00000
0_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc
/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Co0000oda<C?m<C4co00002?lc
<c<01ol0003oC4a<oda<C?m<C4co0000ofIVI_l000000_moOgl00ol0003oVIVIo`000003ok>c/`03
o`000?o<c<coc<c<00Koc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000
0_m<C4`00ol0003o<c<coc<c<`06oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003o
VIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01ol0003o/k>co`000?nIVIWo0000ogmoOol0
00001_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool5ogmoO`;o0000
3?nIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl0
2?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01SoC4a<00?o0000ofIVI_mVIVH0
1omVIVH00ol0003oOgmoogmoO`04ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<0
4onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Go0000ofIVI_mVIVKoIVIVo`000006oda<
C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo
000000;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc
/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP04o`000?m<C4coC4a<o`00
00Wo<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000;o/k>c
00?o0000olc<c?o<c<`01_o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0
0003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000oiVI
VOl000000_nc/k<00ol0003oc<c<olc<c006olc<c003o`000?nc/k?o000000;oVIVI0_l000000omV
IVKoooooooooo`04ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`Co
Ogmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00_o
VIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01So
C4a<00?o0000ofIVI_mVIVH01omVIVH00ol0003oOgmoogmoO`04ogmoO`03o`000?nIVIWoVIVI00?o
VIVI00?o0000ok>c/onc/k<04onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000CoOgmo00Go0000ofIV
I_mVIVKoIVIVo`000005oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00om<C4`0
1?l0003oIVIVofIVI_l00002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000onc/k<00ol0003oc<c<
olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIV
IP04o`000?m<C4coC4a<o`0000Wo<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`05o`00
0?nIVIWo0000o`000?nc/k<00_l00008olc<c009o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0
003oIVIV00;o000000?oC4a<o`000?lc<c<01olc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?mo
Ogoo0000oiVIVOl0003o/k>co`0000Woc<c<00So0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIV
IPKooooo0Ol00001ooooo`7ooooo000Tooooo`;o00001?ooool4ogmoO`03o`000?nIVIWoVIVI00[o
VIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00So
Ogmo00?o0000ofIVI_mVIVH03?mVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00So
IVIV00?o0000ogmoOomoOgl01?moOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c01?o
/k>c00Go0000oiVIVOnIVIWoVIVIo`000004ogmoO`05o`000?mVIVKoIVIVofIVI_l000001Om<C4`0
0ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Co0000ofIVI_mVIVKo00000_mo
Ogl01Ol0003oVIVIoiVIVOnIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>c
ok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01?l0003oC4a<oda<C?l00009
oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVIV@04o`000?nc/k?o/k>co`00
00Woc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o
<c<coc<c<`06oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o
00002Oo<c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000004ooooo`;o00000_oo
ool002Cooooo00?o0000ooooooooool00oooool3ogmoO`03o`000?nIVIWoVIVI00[oVIVI00?o0000
ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000
ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00SoIVIV00?o0000
ogmoOomoOgl01?moOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o0000
oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000?oIVIV00?o0000oda<C?m<C4`01?m<
C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00;oC4a<00Go0000ofIVI_mVIVKoIVIV
o`000002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000onc/k<00ol0003oc<c<olc<c005olc<c003
o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl00ol0003oIVIVo`000003oda<
C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4coC4a<0_l00002ogmoO`04o`000?nIVIWo
VIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01_l0003o/k>cok>c/onc/k?o0000oiVIV@;o
00000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmo
Ool0003oVIVIo`000?nc/k?o00002Oo<c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIV
o`000005ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`;oOgmo00?o
0000oiVIVOnIVIT02_nIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00coVIVI00?o
0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o
0000ofIVI_mVIVH02?mVIVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o
0000ok>c/onc/k<04onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00?o0000ofIVI_mVIVH0
0_mVIVH00ol0003oC4a<oda<C003oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`0
0om<C4`01?l0003oIVIVofIVI_l00002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000onc/k<00ol0
003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol0
0002ofIVIP04o`000?m<C4coC4a<o`0000Wo<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmo
O`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`02_l0003o/k>cok>c/ol0003o
VIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Wo0000oda<C?l0
003oIVIVo`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c003o`000?nc
/k?o/k>c00;o000000CoOgmoo`000?mVIVKo00001_ooool1o`00007ooooo0Oooool002Cooooo00?o
0000ooooooooool00oooool00omoOgoo0000oiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o
0000oiVIVOnIVIT02onIVIT2o`0000WoOgmo0_l0000=ofIVIP03o`000?m<C4coC4a<01KoC4a<0_l0
000:ofIVIP;o00001_moOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o
0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000?oIVIV00?o0000oda<C?m<C4`0
1?m<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00;oC4a<00Go0000ofIVI_mVIVKo
IVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0
003o/k>cok>c/onc/k?o000000;oVIVI00Ko0000ogmoOol0003o0000ofIVI_l00003oda<C003o`00
0?lc<c?o<c<c00Ko<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00?o0000oiVI
VOl000000_nc/k<00ol0003oc<c<olc<c006olc<c00;o`000?nc/k?o/k>cok>c/ol0003oVIVIo`00
0?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`09o`000?m<C4co0000ofIV
I_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02Ol0003o/k>co`00
0?nIVIWo0000ogmoOol0003oIVIVo`000006ooooo`7o00000Oooool1ooooo`009?ooool00ol0003o
ooooooooo`03ooooo`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003o
VIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003o
C4a<oda<C00Foda<C003o`000?mVIVKoIVIV00WoIVIV00?o0000ogmoOomoOgl01_moOgl00ol0003o
VIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003o
OgmoogmoOomoOgoo000000?oIVIV00?o0000oda<C?m<C4`01?m<C4`00ol0003o<c<coc<c<`04oc<c
<`03o`000?m<C4coC4a<00;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`04o`000?nIVIWo
VIVIo`0000Co/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@04o`00
0?moOgooOgmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`04o`000?m<C4coC4a<
o`0000;oIVIV00Ko0000ogmoOomoOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<
00_o0000ok>c/onc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc
<c?o<c<c00Oo<c<c00_o0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`000009
olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000Kooooo0Ol00001ooooo`7o
oooo000Tooooo`03o`000?oooooooooo00?ooooo3OnIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`00
0?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`00
0?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02OmVIVH00ol0003oOgmoogmoO`06ogmoO`03o`00
0?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<04onc/k<00ol0003oVIVIoiVIV@02oiVIV@05o`00
0?moOgooOgmoogmoOol000000omVIVH00ol0003oC4a<oda<C004oda<C003o`000?lc<c?o<c<c00Co
<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Co0000oiVI
VOnIVIWo00001?nc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nI
VIT00ol0003oOgmoo`000002ofIVIP03o`000?m<C4coC4a<00;oC4a<00?o0000oc<c<olc<c<01Olc
<c<01ol0003oC4a<oda<C?m<C4co0000ofIVI_l000000_moOgl00ol0003oVIVIo`000002ok>c/`03
o`000?o<c<coc<c<00Ooc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000
0_m<C4`00ol0003o<c<coc<c<`07oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo
000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`01?l0003o/k>co`000?l00002ogmoO`;o000000?o
C4a<ooooooooool01?ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool<
oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08
ogmoO`;o00003OmVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00[oIVIV00?o0000
ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c01;o/k>c00?o0000
oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000CoIVIV00?o0000oda<C?m<C4`00om<
C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Co0000ofIVI_mVIVKo0000
0omoOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o0000ok>c/onc
/k<00_nc/k<01_l0003oVIVIoiVIVOl0003oOgmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`00
0008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Ko0000ogmoOomoOgoo0000oiVIVOl00002ok>c
/`03o`000?o<c<coc<c<00Ooc<c<00?o0000ok>c/ol000000_nIVIT01Ol0003oOgmoo`000?mVIVKo
000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo
0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o0000ok>c/onc/k<00_l000001Omo
Ogoo0000ofIVI_l0003oC4a<00Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo
00?ooooo2onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmo
OomoOgl02OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIV
I_mVIVH02omVIVH00ol0003oOgmoogmoO`04ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c
/onc/k<04onc/k<00ol0003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol000001?mVIVH0
0ol0003oC4a<oda<C003oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00om<C4`0
1?l0003oIVIVofIVI_l00002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000onc/k<00ol0003oc<c<
olc<c006olc<c003o`000?nc/k?o/k>c00;o/k>c00Ko0000oiVIVOnIVIWo0000ogmoOol00002ofIV
IP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP06o`000?mo
OgooOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`00
00;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00[o0000
oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<
c003o`000?nc/k?o/k>c00;o000000GoOgmoo`000?mVIVKo0000oda<C006ooooo`7o00000Oooool1
ooooo`006oooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool00oooool:oiVI
V@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmo
O`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIV
IP03o`000?moOgooOgmo00CoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`0Cok>c
/`03o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`000004ofIVIP03o`000?m<C4co
C4a<00?oC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C003oda<C004o`000?mVIVKo
IVIVo`0000?oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c003o`00
0?nc/k?o/k>c00;o/k>c00Ko0000oiVIVOnIVIWo0000ogmoOol00002ofIVIP05o`000?m<C4coC4a<
oda<C?l000002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP06o`000?moOgooOgmoo`000?nIVIWo
00000onc/k<00ol0003oc<c<olc<c006olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0
003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01olc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmo
Ool0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Co0000ok>c/ol0003oVIVI0_l0
00001OmVIVKo0000oda<C?m<C4co000000Gooooo0Ol00001ooooo`7ooooo000Looooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool00oooool9oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o
0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`;o00003OmVIVH00ol0003oC4a<oda<
C00Foda<C003o`000?mVIVKoIVIV00[oIVIV0_l00006ogmoO`03o`000?nIVIWoVIVI00GoVIVI00?o
0000ok>c/onc/k<04_nc/k<00ol0003oVIVIoiVIV@03oiVIV@05o`000?moOgooOgmoogmoOol00000
0omVIVH00ol0003oC4a<oda<C004oda<C003o`000?lc<c?o<c<c00?o<c<c00?o0000oda<C?m<C4`0
0om<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000003ok>c
/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgoo
Ogmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`04o`000?m<C4coC4a<o`0000;o
IVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00008olc<c004o`000?nc/k?o/k>c
o`0000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00co
0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol0000:olc<c0;o000000Ko
VIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?oooooooooo00?ooooo0Ol00001ooooo`7o
oooo000Iooooo`Go00001_ooool3o`0000?ooooo2?nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`00
0?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`00
0?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`04ogmoO`03o`00
0?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc/k<04_nc/k<00ol0003oVIVIoiVIV@03oiVIV@05o`00
0?moOgooOgmoogmoOol000000omVIVH00ol0003oC4a<oda<C004oda<C003o`000?lc<c?o<c<c00?o
<c<c00?o0000oda<C?m<C4`00om<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Go0000oiVI
VOnIVIWoVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`00
0002oiVIV@06o`000?moOgooOgmoo`000?mVIVKo00001?m<C4`00ol0003o<c<coc<c<`06oc<c<`04
o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00008
olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`00
0?lc<c?o<c<c00Ko<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c
/ol0000:olc<c0;o000000KoVIVIo`000?moOgoo0000ofIVI_l00002oda<C004o`000?oooooooooo
ooooo`?o00000_ooool001Wooooo00CoA4A4omgMgOoooooo00001oooool00ol0003oooooooooo`03
ooooo`OoVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@;o00002_moOgl0
0ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH0
0ol0003oOgmoogmoO`04ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc/k<04_nc/k<0
0ol0003oVIVIoiVIV@03oiVIV@05o`000?moOgooOgmoogmoOol000000omVIVH00ol0003oC4a<oda<
C004oda<C003o`000?lc<c?o<c<c00?o<c<c00?o0000oda<C?m<C4`00om<C4`01Ol0003oIVIVofIV
I_mVIVKo000000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Go
c<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Go0000
oda<C?m<C4coC4a<o`000008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol00000
0_nIVIT01?l0003o/k>cok>c/ol00009olc<c003o`000?nc/k?o000000;oVIVI00Go0000ogmoOol0
003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Wo0000oda<C?l0003oIVIVo`000?mo
Ogoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c004o`000?nc/k?o0000oiVIV@;o
00000_mVIVH00ol0003oC4a<o`000006ooooo`7o00000Oooool1ooooo`006Oooool01?oMgMgoEEEE
ooooool00007ooooo`03o`000?oooooooooo00?ooooo1_nIVIT00ol0003o/k>cok>c/`0Fok>c/`03
o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0:ofIVIP;o
00005om<C4`2o`0000goIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@05oiVIV@03
o`000?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo0000
00CoIVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<
00?oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o
0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo
00000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Co0000oda<C?m<C4co00000_mVIVH0
0ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Woc<c<00?o0000ok>c/ol000000_nI
VIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01olc<c<02Ol0003oC4a<
o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000
ok>c/onc/k?o0000oiVIV@02o`000005ofIVI_l0003oC4a<oda<C?l000001_ooool1o`00007ooooo
0Oooool001[ooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`03ooooo`GoVIVI00?o
0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo0_l0
000<ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmo
O`06ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<05?nc/k<00ol0003oVIVIoiVI
V@02oiVIV@05o`000?moOgooOgmoogmoOol000001?mVIVH00ol0003oC4a<oda<C003oda<C003o`00
0?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00om<C4`01?l0003oIVIVofIVI_l00003ogmoO`04
o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o
000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c
00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`00
00Woc<c<00?o0000ok>c/ol000000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000
oc<c<olc<c<01olc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c/`03
o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o0000oiVIV@02o`000005ofIVI_l0003oC4a<
oda<C?l000001_ooool1o`00007ooooo0Oooool001[ooooo00?ok^k^odA4A?l000001oooool00ol0
003oooooooooo`03ooooo`CoVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVI
V@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<
C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl01_moOgl00ol0003oVIVIoiVIV@05oiVI
V@03o`000?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo
000000CoIVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4co
C4a<00?oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c
00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomo
Ogoo00000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Co0000oda<C?m<C4co00000_mV
IVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Woc<c<00?o0000ok>c/ol00000
0_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01olc<c<00ol0003o
C4a<o`000002ofIVIP;o000000GoVIVIo`000?nc/k?o/k>co`000009olc<c006o`000?nc/k?o0000
oiVIVOl0003oOgmo0_l00002oda<C003o`000?lc<c?ooooo00Gooooo0Ol00001ooooo`7ooooo000K
ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool00oooool3oiVIV@03o`000?nc/k?o
/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKo
IVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgoo
Ogmo00KoOgmo00?o0000oiVIVOnIVIT01OnIVIT00ol0003o/k>cok>c/`0Cok>c/`03o`000?nIVIWo
VIVI00;oVIVI00?o0000ogmoOomoOgl00_moOgl01Ol0003oIVIVofIVI_mVIVKo000000KoC4a<00?o
0000oc<c<olc<c<00olc<c<00ol0003oC4a<oda<C004oda<C004o`000?mVIVKoIVIVo`0000?oOgmo
00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c
/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Go
0000oda<C?m<C4coC4a<o`000002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o
00002?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`0
0ol0003o<c<coc<c<`06oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`00
00;o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/ol0003oVIVI00;o000000KoIVIV
o`000?m<C4coC4a<o`000?lc<c<6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003ooooooooo
o`03ooooo`;oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?mo
OgooOgmo00SoOgmo0_l0000<ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02omV
IVH00ol0003oOgmoogmoO`06ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc/k<04onc
/k<00ol0003oVIVIoiVIV@02oiVIV@03o`000?moOgooOgmo00;oOgmo00Go0000ofIVI_mVIVKoIVIV
o`000006oda<C003o`000?lc<c?o<c<c00?o<c<c00?o0000oda<C?m<C4`01?m<C4`01?l0003oIVIV
ofIVI_l00003ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0
003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo00000_m<
C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01Ol0003oOgmo
o`000?nIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVI
V@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0:o`000?m<C4co
C4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0
003o/k>cok>c/ol0003oVIVI00;o000000KoIVIVo`000?m<C4coC4a<o`000?lc<c<6ooooo`7o0000
0Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`03oiVIVOl0003o/k>c01Oo/k>c00?o
0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o
0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00KoOgmo00?o
0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`0Cok>c/`03o`000?nIVIWoVIVI00;oVIVI00?o
0000ogmoOomoOgl00_moOgl01Ol0003oIVIVofIVI_mVIVKo000000KoC4a<00?o0000oc<c<olc<c<0
0olc<c<00ol0003oC4a<oda<C004oda<C004o`000?mVIVKoIVIVo`0000?oOgmo00Co0000oiVIVOnI
VIWo00001?nc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT0
1?l0003oOgmoogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Go0000oda<C?m<C4co
C4a<o`000002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`02_l0
003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo
<c<c00?o0000oda<C?m<C4`00_l000001omoOgoo0000oiVIVOnIVIWo0000ok>c/ol000002?o<c<`0
1ol0003o/k>cok>c/ol0003oVIVIo`000?moOgl00_l00002oda<C003o`000?lc<c?o<c<c00Kooooo
0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo00?o0000ok>c/onc/k<05_nc
/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omV
IVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl01_mo
Ogl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT00_nI
VIT2o`0000?oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C004oda<C003o`000?lc
<c?o<c<c00?o<c<c00?o0000oda<C?m<C4`00om<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo
00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Goc<c<00Go0000ok>c/onc
/k?o/k>co`000003oiVIV@03o`000?moOgoo000000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008
oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc
/k?o/k>co`0000Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mVIVKo0000
00;oC4a<00?o0000oc<c<olc<c<01_lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000
oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Oo0000ok>c/onc/k?o0000oiVIVOl0003o
Ogmo00;o00000_m<C4`00ol0003o<c<coc<c<`06ooooo`7o00000Oooool1ooooo`009?ooool00ol0
003oooooooooo`03oooooaSo/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmo
O`;o00003?mVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmo
OomoOgl01omoOgl00ol0003oVIVIoiVIV@05oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o0000oiVI
VOnIVIT00onIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<
C?m<C4`00om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Go0000ofIV
I_mVIVKoIVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000onc/k<00ol0003oc<c<olc<
c006olc<c005o`000?nc/k?o/k>cok>c/ol000000onIVIT00ol0003oOgmoo`000002ofIVIP05o`00
0?m<C4coC4a<oda<C?l000002?lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o0000ogmo
Ool000000_nIVIT01?l0003o/k>cok>c/ol00008olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Go
0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00[o0000oda<C?m<C4co
0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c007o`000?nc
/k?o/k>co`000?nIVIWo0000ogmoO`02o`0000;oC4a<00?o0000oc<c<olc<c<01_ooool1o`00007o
oooo0Oooool002Cooooo0_l00004oooooaOo/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmo
ogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIV
ofIVIP0;ofIVIP03o`000?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT01OnIVIT00ol0003o/k>c
ok>c/`0Dok>c/`03o`000?nIVIWoVIVI00;oVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIV
ofIVIP02ofIVIP03o`000?m<C4coC4a<00CoC4a<00?o0000oc<c<olc<c<00olc<c<00ol0003oC4a<
oda<C004oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000004ok>c
/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002
ogmoO`04o`000?mVIVKoIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01olc<c<01?l0003oC4a<oda<
C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01?l0003o
/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06
oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl2o`0000;o/k>c00?o0000olc<c?o<c<`0
1_o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000?o<c<c
1Oooool2o`0000;ooooo000Tooooo`03o`000?oooooooooo00?ooooo5_nc/k<00ol0003oVIVIoiVI
V@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<
C00Goda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVI
V@05oiVIV@03o`000?nc/k?o/k>c01Co/k>c00?o0000oiVIVOnIVIT00onIVIT01Ol0003oOgmoogmo
OomoOgoo000000CoIVIV00?o0000oda<C?m<C4`01?m<C4`00ol0003o<c<coc<c<`03oc<c<`03o`00
0?m<C4coC4a<00CoC4a<00Co0000ofIVI_mVIVKo00000omoOgl01?l0003oVIVIoiVIVOl00004ok>c
/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgoo
Ogmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`07o`000?m<C4coC4a<oda<C?l0
003oIVIVo`000002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`01_l0
003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c
<`06oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000
olc<c?o<c<`01_o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<
o`0000?o<c<c1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00ooooolEok>c
/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl2o`0000coIVIV00?o0000oda<
C?m<C4`05om<C4`00ol0003oIVIVofIVIP0:ofIVIP;o00002OmoOgl00ol0003oVIVIoiVIV@06oiVI
V@03o`000?nc/k?o/k>c01Co/k>c00?o0000oiVIVOnIVIT00onIVIT01Ol0003oOgmoogmoOomoOgoo
000000CoIVIV00?o0000oda<C?m<C4`01?m<C4`00ol0003o<c<coc<c<`03oc<c<`03o`000?m<C4co
C4a<00CoC4a<00Co0000ofIVI_mVIVKo00000omoOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`00
0?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`00
00;oIVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`07o`000?m<C4coC4a<oda<C?l0003oIVIV
o`000002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`01_l0003o/k>c
ok>c/ol0003oVIVIo`0000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c
<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<
c<`01_o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000?o
<c<c1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00ooooolDok>c/`03o`00
0?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`00
0?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`00
0?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc/k<05?nc/k<00ol0003oVIVIoiVIV@03oiVIV@05o`00
0?moOgooOgmoogmoOol000001?mVIVH00ol0003oC4a<oda<C004oda<C003o`000?lc<c?o<c<c00?o
<c<c00?o0000oda<C?m<C4`01?m<C4`01?l0003oIVIVofIVI_l00003ogmoO`05o`000?nIVIWoVIVI
oiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nI
VIT01?l0003oOgmoogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01ol0003o
C4a<oda<C?m<C4co0000ofIVI_l000000_moOgl00ol0003oVIVIo`000003ok>c/`03o`000?o<c<co
c<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<
00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP;o000000GoVIVIo`000?nc
/k?o/k>co`000008olc<c004o`000?nc/k?o/k>cok>c/`;o000000KoOgmoo`000?mVIVKo0000oda<
C?l00004oc<c<`Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo4onc
/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omV
IVH00ol0003oC4a<oda<C00Foda<C0;o00003?mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nI
VIWoVIVI00KoVIVI00?o0000ok>c/onc/k<05?nc/k<00ol0003oVIVIoiVIV@03oiVIV@03o`000?mo
OgooOgmo00;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000007oda<C003o`000?lc<c?o<c<c00;o<c<c
0_l00005oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01Ol0003oVIVIoiVIVOnIVIWo0000
00Co/k>c00?o0000olc<c?o<c<`01Oo<c<`2o`0000?o/k>c00Co0000oiVIVOnIVIWo00000_moOgl0
1?l0003oIVIVofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Oo0000oda<C?m<C4coC4a<
o`000?mVIVKo000000;oOgmo00?o0000oiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c006
o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o
<c<c00Ko<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0
003oc<c<olc<c006olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<
C4co00001?lc<c<6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03oooooa;o
/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00co
IVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00So
Ogmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`0Dok>c/`03o`000?nIVIWoVIVI00?o
VIVI00?o0000ogmoOomoOgl00_moOgl01Ol0003oIVIVofIVI_mVIVKo000000OoC4a<00?o0000oc<c
<olc<c<00_lc<c<00ol0003oC4a<oda<C004oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl0
1Ol0003oVIVIoiVIVOnIVIWo000000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c
/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo00000_m<C4`00ol0003o
<c<coc<c<`07oc<c<`07o`000?m<C4coC4a<oda<C?l0003oIVIVo`000002ogmoO`03o`000?nIVIWo
000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo
00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0:o`000?m<C4coC4a<o`000?mV
IVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`03?l0003o/k>cok>c
/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000Co<c<c1_ooool1o`00007ooooo0Ooo
ool002Cooooo00?o0000ooooooooool00ooooolAok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000
ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000
ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o0000
ok>c/onc/k<05?nc/k<00ol0003oVIVIoiVIV@03oiVIV@03o`000?moOgooOgmo00;oOgmo00?o0000
ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C004oda<C003o`000?lc<c?o<c<c00?o<c<c00?o0000
oda<C?m<C4`01?m<C4`01?l0003oIVIVofIVI_l00003ogmoO`05o`000?nIVIWoVIVIoiVIVOl00000
0onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003o
OgmoogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01Ol0003oC4a<oda<C?m<
C4co000000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00009olc<c006o`00
0?nc/k?o/k>co`000?nIVIWo00000_moOgl2o`0000;oC4a<00?o0000oc<c<olc<c<01olc<c<02_l0
003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ko
c<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00004oc<c<`Ko
oooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo4?nc/k<00ol0003oVIVI
oiVIV@0<oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<
oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVI
oiVIV@06oiVIV@03o`000?nc/k?o/k>c01Go/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmo
ogmoO`02ogmoO`05o`000?mVIVKoIVIVofIVI_l000001om<C4`00ol0003o<c<coc<c<`02oc<c<`03
o`000?m<C4coC4a<00CoC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`05o`000?nIVIWoVIVI
oiVIVOl000001?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000
oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c
00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00?o0000oiVIVOl000000onc/k<00ol0
003oc<c<olc<c006olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl00ol0003oIVIVo`00
0002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Oo0000oda<C?l0003oIVIVo`000?moOgoo000000;o
VIVI00?o0000ok>c/ol000002?o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIV
I_l0003oC4a<o`0000Go<c<c1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool0
0oooool?ok>c/`03o`000?nIVIWoVIVI00_oVIVI0_l00009ogmoO`;o00003OmVIVH00ol0003oC4a<
oda<C00Foda<C003o`000?mVIVKoIVIV00[oIVIV0_l0000:ogmoO`03o`000?nIVIWoVIVI00OoVIVI
00?o0000ok>c/onc/k<05?nc/k<00ol0003oVIVIoiVIV@03oiVIV@03o`000?moOgooOgmo00;oOgmo
00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C004oda<C003o`000?lc<c?o<c<c00?o<c<c
00?o0000oda<C?m<C4`01?m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Go0000oiVIVOnI
VIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0
003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc
<c<01?l0003oC4a<oda<C?l00002ofIVIP06o`000?moOgooOgmoo`000?nIVIWo00000_nc/k<00ol0
003oc<c<olc<c007olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl00ol0003oIVIVo`00
0002oda<C003o`000?lc<c?o<c<c00Ko<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`00
0?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000
ogmoOol0003oIVIVo`000?m<C4co00001Olc<c<6ooooo`7o00000Oooool1ooooo`009?ooool00ol0
003oooooooooo`03ooooo`ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmo
O`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIV
IP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02?nIVIT00ol0003o/k>cok>c/`0Cok>c
/`03o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl00omoOgl01Ol0003oIVIVofIVI_mVIVKo
000000OoC4a<00?o0000oc<c<olc<c<00_lc<c<00ol0003oC4a<oda<C005oda<C005o`000?mVIVKo
IVIVofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00005ok>c/`03o`000?o<c<coc<c<00Goc<c<
00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`00
00;oC4a<00?o0000oc<c<olc<c<01olc<c<01?l0003oC4a<oda<C?l00002ofIVIP06o`000?moOgoo
Ogmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c007olc<c006o`000?nc/k?o/k>co`000?nI
VIWo00000_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00[o0000oda<
C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c00<
o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co00001Olc<c<6ooooo`7o
00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`go/k>c00?o0000oiVIVOnIVIT0
2onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`0
5_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT0
2?nIVIT00ol0003o/k>cok>c/`0Dok>c/`03o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl0
0_moOgl00ol0003oIVIVofIVIP02ofIVIP03o`000?m<C4coC4a<00CoC4a<00?o0000oc<c<olc<c<0
0_lc<c<00ol0003oC4a<oda<C005oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01Ol0003o
VIVIoiVIVOnIVIWo000000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c
/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c
<`06oc<c<`07o`000?m<C4coC4a<oda<C?l0003oIVIVo`000002ogmoO`03o`000?nIVIWo000000;o
/k>c00?o0000olc<c?o<c<`01oo<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00?o0000
ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo0000
0_moOgl2o`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`00
0?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00?o<c<c1_ooool1o`00007ooooo0Ooo
ool002Cooooo0_l00004ooooo`co/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08
ogmoO`;o00003OmVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000
ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@07oiVIV@03o`000?nc/k?o/k>c01Co/k>c00?o0000
oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000
oda<C?m<C4`01Om<C4`00ol0003o<c<coc<c<`02oc<c<`03o`000?m<C4coC4a<00CoC4a<00Go0000
ofIVI_mVIVKoIVIVo`000003ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`0
1_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01Ol0
003oC4a<oda<C?m<C4co000000So<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP03o`000?mo
Ogoo000000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`01_l0003o/k>cok>c/ol0003oVIVIo`00
00;oOgmo00Go0000ofIVI_l0003oC4a<o`000009oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000
ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`03?l0003o/k>cok>c/ol0003o
VIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000Ko<c<c1Oooool2o`0000;ooooo000Tooooo`03
o`000?oooooooooo00?ooooo2onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00Wo
Ogmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_o
IVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@07oiVIV@03o`000?nc/k?o/k>c01Go
/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00;o
IVIV00?o0000oda<C?m<C4`01Om<C4`00ol0003o<c<coc<c<`02oc<c<`03o`000?m<C4coC4a<00Co
C4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000
olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo0000
0_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIV
IP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`01_l0003o/k>cok>c/ol0
003oVIVIo`0000;oOgmo00Go0000ofIVI_l0003oC4a<o`000009oc<c<`0:o`000?m<C4coC4a<o`00
0?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003o/k>c
o`000002oiVIV@07o`000?moOgoo0000ofIVI_l0003oC4a<o`000006oc<c<`Kooooo0Ol00001oooo
o`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo2_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03
o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003
o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@08oiVIV@03
o`000?nc/k?o/k>c01Co/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`02ogmoO`03
o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01Om<C4`00ol0003o<c<coc<c<`02oc<c<`03
o`000?m<C4coC4a<00GoC4a<00Co0000ofIVI_mVIVKo00000omoOgl01?l0003oVIVIoiVIVOl00004
ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?mo
OgooOgmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`05o`000?m<C4coC4a<oda<
C?l000000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Woc<c<00Co0000
ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<0
1_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP;o000000GoVIVIo`000?nc/k?o/k>co`000008olc<
c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co00001olc<c<6oooo
o`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`Wo/k>c00?o0000oiVIVOnI
VIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`;o00003OmVIVH00ol0003oC4a<oda<C00Foda<C003
o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl2o`0000[oVIVI00?o0000ok>c/onc
/k<05?nc/k<00ol0003oVIVIoiVIV@03oiVIV@03o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mV
IVH00_mVIVH00ol0003oC4a<oda<C006oda<C005o`000?lc<c?o<c<coc<c<ol000001om<C4`01Ol0
003oIVIVofIVI_mVIVKo000000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<
c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`00
0?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co0000
00;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00008olc<c0;o00000_nc/k<0
1Ol0003oVIVIo`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<02_l0003oC4a<
oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00co
0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00007oc<c<`Kooooo0Ol0
0001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo2?nc/k<00ol0003oVIVIoiVIV@0<
oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00F
oda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@08
oiVIV@03o`000?nc/k?o/k>c01Go/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`02
ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01_m<C4`01Ol0003o<c<coc<c<olc
<c?o000000OoC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVIVOl0
00001?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnI
VIWo00000_moOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000
oda<C?m<C4coC4a<o`000002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o0000
2?o<c<`02Ol0003o/k>cok>c/onc/k?o0000oiVIVOl0003oOgmoo`000002ofIVIP04o`000?m<C4co
C4a<o`0000Oo<c<c00_o0000oda<C?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002
ok>c/`03o`000?o<c<coc<c<00Koc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mV
IVKo0000oda<C?l00007oc<c<`Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo
00?ooooo1onc/k<00ol0003oVIVIoiVIV@0;oiVIV@;o00002_moOgl00ol0003oIVIVofIVIP0;ofIV
IP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`09ogmo
O`03o`000?nIVIWoVIVI00SoVIVI00?o0000ok>c/onc/k<05Onc/k<00ol0003oVIVIoiVIV@03oiVI
V@03o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C005oda<
C005o`000?lc<c?o<c<coc<c<ol000001om<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Co
0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c
00Oo0000oiVIVOnIVIWoVIVIo`000?moOgoo000000;oIVIV00Go0000oda<C?m<C4coC4a<o`000009
oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Ko0000ogmoOomoOgoo0000oiVIVOl00002ok>c/`03
o`000?o<c<coc<c<00Koc<c<00Wo0000ok>c/onc/k?o/k>co`000?nIVIWo0000ogmoOol000000_mV
IVH01?l0003oC4a<oda<C?l00008oc<c<`04o`000?m<C4coC4a<oda<C0;o000000OoOgmoo`000?nI
VIWoVIVIo`000?nc/k?o000000Soc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mV
IVKo0000oda<C?l00008oc<c<`Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo
00?ooooo1_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIV
I_mVIVH02_mVIVH2o`0001OoC4a<0_l0000=ofIVIP03o`000?moOgooOgmo00SoOgmo0_l0000:oiVI
V@03o`000?nc/k?o/k>c01Go/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`02ogmo
O`;o00001?mVIVH00ol0003oC4a<oda<C005oda<C005o`000?lc<c?o<c<coc<c<ol000001om<C4`0
1Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`00
0?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04
o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co
000000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00008olc<c009o`000?nc
/k?o/k>cok>c/ol0003oVIVIo`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<0
2_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<
00Koc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00008oc<c
<`Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo1Onc/k<00ol0003o
VIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo0_l0000<ofIVIP03o`000?m<C4coC4a<01Ko
C4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00[o
VIVI00?o0000ok>c/onc/k<05?nc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00;o
Ogmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C005oda<C005o`000?lc<c?o<c<coc<c
<ol000001_m<C4`00ol0003oIVIVofIVIP02ofIVIP05o`000?moOgooOgmoogmoOol000000onIVIT0
0ol0003o/k>cok>c/`02ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00onc/k<0
1?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<0
1_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o
/k>cok>c/ol00008olc<c009o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000?moOgoo000000;oIVIV
00Co0000oda<C?m<C4co00002?lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVI
VOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o0000ok>c/onc/k<00_l00002ogmoO`05o`00
0?mVIVKo0000oda<C?l000002?lc<c<00ol0003oooooooooo`03ooooo`7o00000Oooool1ooooo`00
9?ooool00ol0003oooooooooo`03ooooo`Co/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmo
ogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIV
ofIVIP0<ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02_nIVIT00ol0003o/k>c
ok>c/`0Eok>c/`03o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIV
ofIVIP03ofIVIP03o`000?m<C4coC4a<00GoC4a<00Go0000oc<c<olc<c?o<c<co`000007oda<C005
o`000?mVIVKoIVIVofIVI_l000000omoOgl01Ol0003oVIVIoiVIVOnIVIWo000000Co/k>c00?o0000
olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co
0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l0
00000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Oo0000ok>c
/onc/k?o/k>co`000?nIVIWo000000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c
<`07oc<c<`05o`000?m<C4co0000ofIVI_l000000_moOgl2o`0000;o/k>c00?o0000olc<c?o<c<`0
1_o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc
<c?o<c<c00Ko<c<c00?o0000ooooooooool00oooool1o`00007ooooo0Oooool002Cooooo00?o0000
ooooooooool00oooool3ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl0
0ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<0_l0000=ofIVIP03o`000?moOgoo
Ogmo00SoOgmo00?o0000oiVIVOnIVIT02_nIVIT00ol0003o/k>cok>c/`0Eok>c/`03o`000?nIVIWo
VIVI00CoVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP02ofIVIP03o`000?m<C4co
C4a<00KoC4a<00Co0000oc<c<olc<c?o00001om<C4`00ol0003oIVIVofIVIP02ofIVIP04o`000?mo
OgooOgmoo`0000?oVIVI00?o0000ok>c/onc/k<00_nc/k<00ol0003oc<c<olc<c005olc<c003o`00
0?nc/k?o/k>c00;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`00
00;oC4a<00?o0000oc<c<olc<c<01olc<c<01ol0003oC4a<oda<C?m<C4co0000ofIVI_l000000_mo
Ogl01?l0003oVIVIoiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o
00000_nIVIT00ol0003oOgmoo`000002ofIVIP03o`000?m<C4co000000[o<c<c00Wo0000oda<C?l0
003oIVIVo`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c00<o`000?nc
/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co00002?lc<c<00ol0003ooooooooo
o`04ooooo`7o00000Oooool1ooooo`009?ooool2o`0000Cooooo0_nc/k<00ol0003oVIVIoiVIV@0;
oiVIV@03o`000?moOgooOgmo00SoOgmo0_l0000<ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000
ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000
ok>c/onc/k<05Onc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00;oOgmo00?o0000
ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C006oda<C004o`000?lc<c?o<c<co`0000OoC4a<00?o
0000ofIVI_mVIVH00_mVIVH01?l0003oOgmoogmoOol00003oiVIV@03o`000?nc/k?o/k>c00;o/k>c
00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`05o`000?nIVIWoVIVIoiVIVOl0
00000_moOgl01?l0003oIVIVofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Oo0000oda<
C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo00000_nc/k<00ol0003oc<c<
olc<c006olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH00ol0003o
C4a<o`00000:oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o
0000olc<c?o<c<`01_o<c<`00ol0003o/k>co`000002oiVIV@07o`000?moOgoo0000ofIVI_l0003o
C4a<o`000008oc<c<`03o`000?oooooooooo00?ooooo0_l00002ooooo`009?ooool00ol0003ooooo
ooooo`03ooooo`03ok>c/ol0003oVIVI00coVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIV
ofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003oOgmo
ogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05Onc/k<00ol0003oVIVI
oiVIV@04oiVIV@03o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<
oda<C006oda<C004o`000?lc<c?o<c<co`0000OoC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003o
OgmoogmoOomoOgoo000000;oVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c004olc<
c003o`000?nc/k?o/k>c00?o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l0
0003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo000000;o
Ogmo00Co0000oiVIVOnIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>c
ok>c/ol000000_nIVIT2o`0000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<00ol0003oC4a<o`00
0002ofIVIP;o000000GoVIVIo`000?nc/k?o/k>co`000008olc<c008o`000?nc/k?o/k>co`000?nI
VIWo0000ogmoOol00002ofIVIP;o00002?lc<c<00ol0003oC4a<ooooo`05ooooo`7o00000Oooool1
ooooo`009?ooool00ol0003oooooooooo`03ooooo`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmo
OomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIV
I_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c
/onc/k<05Onc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00;oOgmo00?o0000ofIV
I_mVIVH00_mVIVH00ol0003oC4a<oda<C007oda<C003o`000?lc<c?o000000SoC4a<00Go0000ofIV
I_mVIVKoIVIVo`000003ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0003oc<c<olc<
c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIV
ofIVI_l00004oda<C003o`000?lc<c?o<c<c00Go<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIV
IP04o`000?moOgooOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`00ol0003o/k>cok>c
/`02o`000004oiVIVOl0003oOgmoo`0000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<02_l0003o
C4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<
00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00008oc<c<`03o`00
0?m<C4cooooo00Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo3OnI
VIT00ol0003oOgmoogmoO`08ogmoO`;o00003?mVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mV
IVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc
/k?o/k>c01Go/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mV
IVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01om<C4`00ol0003o<c<co`000007oda<C003o`000?mV
IVKoIVIV00;oIVIV00Go0000ogmoOomoOgooOgmoo`000003oiVIV@03o`000?nc/k?o/k>c00;o/k>c
00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;o
Ogmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`05oc<c<`05o`000?m<C4coC4a<
oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<
00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`00
00So<c<c00?o0000oda<C?l000000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000
olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/ol0003oVIVI00;o00000_mVIVH00ol0003oC4a<o`00
0008oc<c<`03o`000?m<C4cooooo00Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooo
oooo00?ooooo3?nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000
oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000
oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Eok>c/`03o`000?nIVIWoVIVI00GoVIVI00?o0000
ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP02ofIVIP03o`000?m<C4coC4a<00WoC4a<00?o0000
oda<C?m<C4`01_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Go0000oiVIVOnIVIWoVIVI
o`000004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVI
oiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0
003oC4a<oda<C002oda<C006o`000?mVIVKoIVIVo`000?moOgoo00000_nIVIT01?l0003o/k>cok>c
/ol00008olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003o
C4a<oda<C?l00008oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVIV@04o`00
0?nc/k?o/k>co`0000Ooc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000
oda<C?l00008oc<c<`03o`000?m<C4coC4a<00Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`00
0?oooooooooo00?ooooo2onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV
00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo
00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Eok>c/`03o`000?nIVIWoVIVI00GoVIVI
00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<017oC4a<
00?o0000ofIVI_mVIVH00_mVIVH01?l0003oOgmoogmoOol00003oiVIV@03o`000?nc/k?o/k>c00?o
/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`00
00;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4co
C4a<oda<C?l000000_mVIVH01_l0003oOgmoogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<
c<`01oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<
C?m<C4co00002?lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c
/`03o`000?o<c<coc<c<00Koc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo
0000oda<C?l00008oc<c<`04o`000?m<C4coC4a<o`0000Gooooo0Ol00001ooooo`7ooooo000Toooo
o`03o`000?oooooooooo00?ooooo2_nIVIT00ol0003oOgmoogmoO`08ogmoO`;o00003?mVIVH00ol0
003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00[oIVIV0_l0000:ogmoO`03o`000?nIVIWoVIVI
00coVIVI00?o0000ok>c/onc/k<05Onc/k<00ol0003oVIVIoiVIV@05oiVIV@03o`000?moOgooOgmo
00;oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C00Boda<C005o`000?mVIVKoIVIV
ofIVI_l000000omoOgl01Ol0003oVIVIoiVIVOnIVIWo000000Go/k>c00?o0000olc<c?o<c<`01Oo<
c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo
00000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01_l0
003oOgmoogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01oo<c<`01?l0003o/k>cok>c
/ol00002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<02_l0003o
C4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<
00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00008oc<c<`04o`00
0?m<C4coC4a<o`0000Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo
2OnIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`0
5om<C4`00ol0003oIVIVofIVIP0:ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT0
2onIVIT2o`0001Oo/k>c00?o0000oiVIVOnIVIT01OnIVIT00ol0003oOgmoogmoO`02ogmoO`03o`00
0?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<C4`04Om<C4`00ol0003oIVIVofIVIP02ofIVIP05o`00
0?moOgooOgmoogmoOol000000_nIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00Go
c<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIV
o`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Ko
0000ogmoOomoOgoo0000oiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc
/k?o00000_nIVIT01_l0003oOgmoogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc
<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo0_l00002ok>c/`03o`000?o<c<coc<c<00Ko
c<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<c
oc<c<`06oc<c<`03o`000?m<C4co000000Kooooo0Ol00001ooooo`7ooooo000Iooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`03ooooo`SoVIVI00?o0000ogmoOomoOgl0
2?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<0_l0000<ofIVIP03o`00
0?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`00
0?nIVIWoVIVI00CoVIVI0_l00004ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<C4`0
4_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Go0000oiVIVOnIVIWoVIVIo`000004ok>c
/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo
000000;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<
C4coC4a<oda<C?l000000_mVIVH00ol0003oOgmoo`000002oiVIV@05o`000?nc/k?o/k>cok>c/ol0
00002?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`0
0ol0003o<c<coc<c<`07oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`00
00;o/k>c00?o0000olc<c?o<c<`01_o<c<`02ol0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000
ofIVI_l0003oC4a<00;o00001olc<c<01?l0003oC4a<oda<C?l00006ooooo`7o00000Oooool1oooo
o`006Oooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool00oooool7oiVI
V@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH03?mVIVH00ol0003oC4a<oda<C00Foda<
C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0<oiVI
V@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`03ogmo
O`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<C4`04Om<C4`00ol0003oIVIVofIVIP02ofIV
IP05o`000?moOgooOgmoogmoOol000000onIVIT00ol0003o/k>cok>c/`02ok>c/`03o`000?o<c<co
c<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Co
0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l0
00000_mVIVH00ol0003oOgmoo`000002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01?l0
003o/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c
<`07oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000
olc<c?o<c<`01_o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<
o`0000So<c<c00Co0000oda<C?m<C4co00001_ooool1o`00007ooooo0Oooool001Wooooo00Go0000
ooooooooooooooooo`000006ooooo`?o00000oooool6oiVIV@03o`000?moOgooOgmo00WoOgmo00?o
0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o
0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o
0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o
0000oda<C?m<C4`04_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00?o0000oiVIVOnIVIT0
0_nIVIT00ol0003o/k>cok>c/`02ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<0
0onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0
003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Ko0000ofIVI_mVIVKo0000ogmoOol0
0002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Co0000ok>c/onc/k?o00000onIVIT01Ol0003o
Ogmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01olc<c<00ol0003oC4a<oda<C002o`00
00;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c003o`000?nc/k?o0000
00;oVIVI00Co0000ogmoOol0003o00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4co
C4a<o`0000Cooooo0ol00002ooooo`006Oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo00?o
0000ooooooooool00oooool6oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omV
IVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?mo
Ogl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT01OnI
VIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`04_m<
C4`00ol0003oIVIVofIVIP02ofIVIP05o`000?moOgooOgmoogmoOol000000onIVIT00ol0003o/k>c
ok>c/`02ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01Ol0003oVIVI
oiVIVOnIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c
<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@04o`000?nc
/k?o/k>co`0000Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mVIVKo0000
00;oC4a<00?o0000oc<c<olc<c<01olc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000
oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003o
Ogmoo`000?mVIVKo0000oda<C?l00008oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00001Oooool1
o`00007ooooo0Oooool001Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooo
oooo00?ooooo1?nIVIT2o`0000WoOgmo0_l0000=ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000
ofIVI_mVIVH02_mVIVH2o`0000[oOgmo0_l0000<oiVIV@;o00006?nc/k<00ol0003oVIVIoiVIV@05
oiVIV@03o`000?moOgooOgmo00?oOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00B
oda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01Ol0003oVIVIoiVIVOnIVIWo000000Go/k>c
00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;o
Ogmo00Go0000ofIVI_mVIVKoIVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c00?o0000oda<
C?m<C4`00_l00002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`0
1?l0003o/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<c
oc<c<`07oc<c<`0:o`000?m<C4co0000o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o
0000olc<c?o<c<`01_o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003o
C4a<o`0000So<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00005ooooo`7o00000Oooool1ooooo`00
6Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo00?ooooo0onIVIT00ol0003oOgmo
ogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIV
ofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>c
ok>c/`0Gok>c/`03o`000?nIVIWoVIVI00KoVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIV
ofIVIP03ofIVIP03o`000?m<C4coC4a<01;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`03
o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c005olc<c003
o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01Ol0003oIVIVofIVI_mVIVKo
000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00003ofIVIP03o`000?mo
Ogoo000000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@05
o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<
o`0000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go
0000ok>c/onc/k?o0000oiVIV@02o`0000;oIVIV00?o0000oda<C?l000002?lc<c<01_l0003oC4a<
oda<C?l0003oIVIVo`0000Gooooo0Ol00001ooooo`7ooooo000Iooooo`03omgMgOl@413oV9RH00So
oooo00?o0000ooooooooool00oooool2oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mV
IVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomo
Ogl02?moOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnI
VIT01_nIVIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<
C4`04_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Go0000oiVIVOnIVIWoVIVIo`000005
ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl0
0002ogmoO`05o`000?mVIVKoIVIVofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`04o`00
0?m<C4coC4a<o`0000?oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00009olc<
c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l0
0008oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVIV@04o`000?nc/k?o/k>c
o`0000Ooc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00009
oc<c<`05o`000?m<C4co0000ofIVI_l000001_ooool1o`00007ooooo0Oooool001[ooooo00Coc<c<
odA4A?l0003o410@1_ooool00ol0003oooooooooo`03ooooo`03oiVIVOl0003oOgmo00WoOgmo0_l0
000=ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmo
O`09ogmoO`03o`000?nIVIWoVIVI00[oVIVI0_l0000Iok>c/`03o`000?nIVIWoVIVI00GoVIVI00?o
0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<01;oC4a<00?o
0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000?oVIVI00?o0000ok>c/onc/k<0
0onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00;o/k>c00Go0000oiVIVOnIVIWo
VIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01olc<c<01?l0
003oC4a<oda<C?l00002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o0000
2Oo<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0
003o<c<coc<c<`07oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o
/k>c00?o0000olc<c?o<c<`01_o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIV
I_l0003oC4a<o`0000Wo<c<c00Go0000oda<C?l0003o0000ogmoO`06ooooo`7o00000Oooool1oooo
o`009?ooool00ol0003oooooooooo`03ooooo`03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mV
IVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomo
Ogl02OmoOgl00ol0003oVIVIoiVIV@0:oiVIV@03o`000?nc/k?o/k>c01So/k>c00?o0000oiVIVOnI
VIT01_nIVIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<
C4`04_m<C4`00ol0003oIVIVofIVIP02ofIVIP05o`000?moOgooOgmoogmoOol000000onIVIT00ol0
003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0
003oVIVIoiVIVOl00003ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01olc
<c<01?l0003oC4a<oda<C?l00002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Co0000ok>c/onc
/k?o00002Oo<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00?o0000ofIVI_l000000_m<
C4`00ol0003o<c<coc<c<`07oc<c<`05o`000?m<C4coC4a<o`000?mVIVH00_l00002oiVIV@04o`00
0?nc/k?o/k>co`0000Soc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000
oda<C?l00009oc<c<`05o`000?m<C4co0000o`000?moOgl01_ooool1o`00007ooooo0Oooool002Co
oooo00?o0000ooooooooool00oooool;ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<
C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnI
VIT02onIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00KoVIVI00?o0000ogmoOomo
Ogl00omoOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<01;oC4a<00?o0000ofIVI_mV
IVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000?oVIVI00?o0000ok>c/onc/k<00onc/k<00ol0
003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000003
ogmoO`04o`000?mVIVKoIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01olc<c<01?l0003oC4a<oda<
C?l00002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`01_l0
003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c
<`07oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000
olc<c?o<c<`01_o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<
C003o`000?lc<c?o<c<c00Ko<c<c00Oo0000oda<C?l0003oIVIVo`000?moOgoo000000Gooooo0Ol0
0001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo2OmoOgl2o`0000goIVIV00?o0000
oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo0_l0000<
oiVIV@;o00006Onc/k<00ol0003oVIVIoiVIV@06oiVIV@03o`000?moOgooOgmo00?oOgmo00?o0000
ofIVI_mVIVH01?mVIVH00ol0003oC4a<oda<C00Boda<C005o`000?mVIVKoIVIVofIVI_l000000omo
Ogl01Ol0003oVIVIoiVIVOnIVIWo000000Go/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>c
ok>c/`02ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00003oda<
C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgoo
Ogmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01ol0003o/k>cok>c/onc/k?o0000oiVI
VOl000000_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00?o0000oda<
C?l000000_mVIVH01ol0003oOgmoo`000?nIVIWo0000ok>c/ol000002Oo<c<`02ol0003o/k>cok>c
/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<00;o00002?lc<c<01ol0003oC4a<o`000?mV
IVKo0000ogmoOol000001Oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00ooo
ool9ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIV
IP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02_nIVIT00ol0003o/k>cok>c
/`0Hok>c/`03o`000?nIVIWoVIVI00OoVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIV
IP04ofIVIP03o`000?m<C4coC4a<01;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`05o`00
0?nIVIWoVIVIoiVIVOl000001Onc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o
/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000
oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo0000
0_nIVIT01?l0003o/k>cok>c/ol00008olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Ko0000ogmo
OomoOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Go0000oda<C?l0003oIVIV
o`000002ogmoO`05o`000?nIVIWo0000ok>c/ol000002Oo<c<`03?l0003o/k>cok>c/ol0003oVIVI
o`000?moOgoo0000ofIVI_l0003oC4a<o`0000Wo<c<c00Oo0000oda<C?l0003oIVIVo`000?moOgoo
000000Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo2?moOgl00ol0
003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0
003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00[oVIVI00?o0000ok>c/onc/k<06?nc/k<00ol0
003oVIVIoiVIV@07oiVIV@03o`000?moOgooOgmo00?oOgmo00?o0000ofIVI_mVIVH01?mVIVH00ol0
003oC4a<oda<C00Boda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01Ol0003oVIVIoiVIVOnI
VIWo000000Go/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`05o`000?nI
VIWoVIVIoiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00004oda<C003o`000?lc<c?o<c<c00Go
<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP07o`000?moOgooOgmoogmoOol0003oVIVIo`00
0003ok>c/`03o`000?o<c<coc<c<00Goc<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo000000;o
Ogmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`03o`000?m<C4co000000;o
IVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00co0000ok>c
/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00009oc<c<`07o`000?m<C4co0000
ofIVI_l0003oOgmoo`000006ooooo`7o00000Oooool1ooooo`009?ooool2o`0000Cooooo1omoOgl0
0ol0003oIVIVofIVIP0:ofIVIP;o00005om<C4`2o`0000goIVIV00?o0000ogmoOomoOgl02?moOgl2
o`0000coVIVI00?o0000ok>c/onc/k<06?nc/k<00ol0003oVIVIoiVIV@07oiVIV@03o`000?moOgoo
Ogmo00?oOgmo00?o0000ofIVI_mVIVH01?mVIVH00ol0003oC4a<oda<C00Boda<C003o`000?mVIVKo
IVIV00;oIVIV00Go0000ogmoOomoOgooOgmoo`000003oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o
0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo
00Go0000ofIVI_mVIVKoIVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<
C4coC4a<o`000002ofIVIP06o`000?moOgooOgmoo`000?nIVIWo00000onc/k<00ol0003oc<c<olc<
c006olc<c007o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000002ogmoO`03o`000?mVIVKo000000;o
C4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP05o`000?moOgoo0000
oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000
ogmoOol0003oIVIVo`000?m<C4co00002Olc<c<01ol0003oC4a<o`000?mVIVKo0000ogmoOol00000
1Oooool2o`0000;ooooo000Tooooo`03o`000?oooooooooo00?ooooo1OmoOgl2o`0000coIVIV00?o
0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?moOgooOgmo00SoOgmo00?o
0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Hok>c/`03o`000?nIVIWoVIVI00OoVIVI00?o
0000ogmoOomoOgl01?moOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o
0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000;oVIVI00?o0000ok>c/onc/k<0
1?nc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00;o/k>c00Go0000oiVIVOnIVIWo
VIVIo`000002ogmoO`05o`000?mVIVKoIVIVofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c
<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01_l0003oOgmoogmoOol0003oVIVIo`0000?o/k>c
00?o0000olc<c?o<c<`01_o<c<`01ol0003o/k>cok>c/onc/k?o0000oiVIVOl000000_moOgl00ol0
003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH0
1Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`03?l0003o/k>cok>c
/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000Wo<c<c00Oo0000oda<C?l0003oIVIV
o`000?moOgoo000000Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo
1?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH0
3?mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<0
6?nc/k<00ol0003oVIVIoiVIV@07oiVIV@03o`000?moOgooOgmo00CoOgmo00?o0000ofIVI_mVIVH0
1?mVIVH00ol0003oC4a<oda<C00Boda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgoo
Ogmoo`000003oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o
/k>cok>c/`03ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000003
oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP06o`000?mo
OgooOgmoo`000?nIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c007o`000?nc/k?o/k>cok>c
/ol0003oVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc
<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00003ok>c/`03o`000?o<c<co
c<c<00Goc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0
003o<c<coc<c<`06oc<c<`08o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIT6ooooo`7o0000
0Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`?oOgmo00?o0000ofIVI_mVIVH02omV
IVH00ol0003oC4a<oda<C00Foda<C0;o00003OmVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nI
VIWoVIVI00_oVIVI00?o0000ok>c/onc/k<06?nc/k<00ol0003oVIVIoiVIV@07oiVIV@03o`000?mo
OgooOgmo00CoOgmo00?o0000ofIVI_mVIVH01?mVIVH00ol0003oC4a<oda<C00Boda<C003o`000?mV
IVKoIVIV00;oIVIV00Go0000ogmoOomoOgooOgmoo`000003oiVIV@03o`000?nc/k?o/k>c00Co/k>c
00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`02ok>c/`05o`000?nIVIWoVIVIoiVIVOl0
00000_moOgl00ol0003oIVIVofIVIP02o`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003o
C4a<oda<C?m<C4co000000;oIVIV00?o0000ogmoOol000000_nIVIT01Ol0003o/k>cok>c/onc/k?o
000000Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<
C4coC4a<o`0000So<c<c00Co0000oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nIVIWo0000
00;o/k>c00?o0000olc<c?o<c<`01_o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000
ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo
0000oiVIVOl000001Oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool2
ogmoO`;o00003?mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00coIVIV00?o0000
ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01So/k>c00?o0000
oiVIVOnIVIT01onIVIT00ol0003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV00CoIVIV00?o0000
oda<C?m<C4`04_m<C4`00ol0003oIVIVofIVIP02ofIVIP05o`000?moOgooOgmoogmoOol000000onI
VIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00_nc
/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o
<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Ko0000ofIVI_mVIVKo0000ogmoOol00002
oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`00
0?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<01?l0003oC4a<oda<C?l00002ofIV
IP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c00:o`000?nc/k?o
/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02Ol0
003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000005ooooo`7o00000Oooool1ooooo`009?oo
ool00ol0003oooooooooo`03ooooo`03ogmoOol0003oIVIV00coIVIV00?o0000oda<C?m<C4`05_m<
C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onI
VIT00ol0003o/k>cok>c/`0Hok>c/`03o`000?nIVIWoVIVI00SoVIVI00?o0000ogmoOomoOgl01?mo
Ogl00ol0003oIVIVofIVIP04ofIVIP03o`000?m<C4coC4a<01;oC4a<00?o0000ofIVI_mVIVH00_mV
IVH01Ol0003oOgmoogmoOomoOgoo000000?oVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<
olc<c004olc<c003o`000?nc/k?o/k>c00;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`04
o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co
000000;oIVIV00?o0000ogmoOol000000onIVIT01?l0003o/k>cok>c/ol00008olc<c004o`000?nc
/k?o/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`03
o`000?m<C4co000000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<
00Koc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o
<c<coc<c<`06oc<c<`03o`000?m<C4coC4a<00;o000000CoOgmoo`000?nIVIWo00001_ooool1o`00
007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool00ol0003oIVIVofIVIP0;ofIVIP03
o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03
o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<2o`0000[oVIVI00?o0000ogmoOomo
Ogl01?moOgl00ol0003oIVIVofIVIP04ofIVIP03o`000?m<C4coC4a<01?oC4a<00Go0000ofIVI_mV
IVKoIVIVo`000004ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001Onc/k<00ol0003oc<c<olc<c004
olc<c003o`000?nc/k?o/k>c00?o/k>c00Co0000oiVIVOnIVIWo00000omoOgl01?l0003oIVIVofIV
I_l00004oda<C003o`000?lc<c?o<c<c00Go<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04
o`000?moOgooOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c004o`000?nc/k?o
/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH00ol0003oC4a<o`00000:oc<c<`03o`000?m<
C4co000000;oIVIV00Oo0000ogmoOol0003oVIVIo`000?nc/k?o000000Woc<c<00[o0000ok>c/onc
/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`09o`00
0?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000Kooooo0Ol00001ooooo`7ooooo000Toooo
o`03o`000?oooooooooo00?ooooo00?o0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<oda<C00Goda<
C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVI
V@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02OnIVIT00ol0003oOgmoogmoO`05ogmo
O`03o`000?mVIVKoIVIV00CoIVIV00?o0000oda<C?m<C4`04om<C4`01Ol0003oIVIVofIVI_mVIVKo
000000CoOgmo00Go0000oiVIVOnIVIWoVIVIo`000005ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o
0000ok>c/onc/k<00onc/k<01?l0003oVIVIoiVIVOl00003ogmoO`04o`000?mVIVKoIVIVo`0000Co
C4a<00?o0000oc<c<olc<c<01Olc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmo
OomoOgoo00000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Co0000ok>c/onc/k?o0000
0_nIVIT00ol0003oOgmoo`000002ofIVIP03o`000?m<C4co000000[o<c<c00Go0000oda<C?l0003o
IVIVo`000002ogmoO`05o`000?nIVIWo0000ok>c/ol000002Oo<c<`03?l0003o/k>cok>c/ol0003o
VIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000Wo<c<c00Wo0000oda<C?l0003oIVIVo`000?mo
Ogoo0000oiVIVOl000001_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00ooo
ool<ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmo
O`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<2o`0000_oVIVI00?o
0000ogmoOomoOgl01OmoOgl00ol0003oIVIVofIVIP04ofIVIP03o`000?m<C4coC4a<01?oC4a<00Go
0000ofIVI_mVIVKoIVIVo`000004ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001_nc/k<00ol0003o
c<c<olc<c003olc<c003o`000?nc/k?o/k>c00?o/k>c00Co0000oiVIVOnIVIWo00000omoOgl01?l0
003oIVIVofIVI_l00004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`0
1_l0003oIVIVofIVI_l0003oOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c009
o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co0000
2Olc<c<00ol0003oC4a<o`000002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003o
c<c<olc<c006olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<
00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<o`000?mVIVKo000000;oOgmo0_l000000onc/k?o
ooooooooo`04ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`_oIVIV
00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo
00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00[oVIVI
00?o0000ogmoOomoOgl01OmoOgl00ol0003oIVIVofIVIP04ofIVIP03o`000?m<C4coC4a<01?oC4a<
00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000?oVIVI00?o0000ok>c/onc
/k<01?nc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00;o/k>c00Go0000oiVIVOnI
VIWoVIVIo`000002ogmoO`05o`000?mVIVKoIVIVofIVI_l000000om<C4`00ol0003o<c<coc<c<`06
oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@04o`00
0?nc/k?o/k>co`0000Woc<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIV
IP04o`000?m<C4coC4a<o`0000So<c<c00Co0000oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`00
0?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`00
0?moOgoo0000ofIVI_l0003oC4a<o`0000Wo<c<c00[o0000oda<C?l0003oIVIVo`000?moOgoo0000
oiVIVOl0003o/k>c1_ooool1o`00007ooooo0Oooool002Cooooo0_l00004ooooo`[oIVIV00?o0000
oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0:ofIVIP;o00002_moOgl00ol0003oVIVIoiVIV@0<
oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`05
ogmoO`03o`000?mVIVKoIVIV00CoIVIV00?o0000oda<C?m<C4`04om<C4`00ol0003oIVIVofIVIP02
ofIVIP05o`000?moOgooOgmoogmoOol000000onIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<
c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo
00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<
C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Woc<c<00Co
0000ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000?oC4a<00?o0000oc<c<olc
<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<0
0ol0003oc<c<olc<c006olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`00
0?m<C4co00002Olc<c<02_l0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k<5oooo
o`;o00000_ooool002Cooooo00?o0000ooooooooool00oooool9ofIVIP03o`000?m<C4coC4a<01Oo
C4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00_o
VIVI0_l0000Gok>c/`;o00003?nIVIT00ol0003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV00Co
IVIV00?o0000oda<C?m<C4`04om<C4`00ol0003oIVIVofIVIP02ofIVIP05o`000?moOgooOgmoogmo
Ool000000onIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c
/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Co0000ofIVI_mVIVKo00000om<
C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmo
ogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Woc<c<00Co0000ok>c/onc/k?o00000_nIVIT0
0ol0003oOgmoo`000002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<02_l0003oC4a<oda<
C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00_o0000
ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`000009oc<c<`03o`000?m<C4co0000
00;oIVIV0_l000001OnIVIWo0000ok>c/onc/k?o000000Gooooo0Ol00001ooooo`7ooooo000Toooo
o`03o`000?oooooooooo00?ooooo2?mVIVH00ol0003oC4a<oda<C00Foda<C0;o00003?mVIVH00ol0
003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0
003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00GoOgmo00?o0000ofIVI_mVIVH01?mVIVH00ol0
003oC4a<oda<C00Coda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgooOgmoo`000004
oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03
ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00004oda<C003o`00
0?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`00
00;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?mo
Ogoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<01_l0003oC4a<oda<C?l0003oIVIVo`00
00;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c00<o`000?nc/k?o/k>c
o`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co00002Olc<c<02Ol0003oC4a<o`000?mVIVKo
0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?oooooooooo00?ooooo0Ol00001ooooo`7ooooo
000Tooooo`03o`000?oooooooooo00?ooooo2?mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mV
IVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc
/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`04ogmoO`03o`000?mV
IVKoIVIV00GoIVIV00?o0000oda<C?m<C4`04om<C4`00ol0003oIVIVofIVIP02ofIVIP05o`000?mo
OgooOgmoogmoOol000001?nIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00Coc<c<
00?o0000ok>c/onc/k<00onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Co0000ofIVI_mV
IVKo00001?m<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH0
1_l0003oOgmoogmoOol0003oVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01oo<c<`01?l0003o/k>c
ok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<01_l0
003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<
c006olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co00002Olc
<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?oooooooooo
00?ooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo1omVIVH00ol0003o
C4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003o
VIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003o
OgmoogmoO`04ogmoO`03o`000?mVIVKoIVIV00GoIVIV00?o0000oda<C?m<C4`04om<C4`00ol0003o
IVIVofIVIP02ofIVIP03o`000?moOgooOgmo00;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000005ok>c
/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00onc/k<01Ol0003oVIVIoiVIVOnIVIWo
000000?oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`05oc<c<`05o`000?m<
C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@05o`000?nc/k?o/k>cok>c
/ol000002?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Co
0000oda<C?m<C4co00002?lc<c<02?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo00000_nIVIT0
0ol0003o/k>co`000009olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`00
0?m<C4co00002Olc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c/`03
o`000?oooooooooo00?ooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo
1_mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl0
2?moOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT0
2_nIVIT2o`0000OoOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<C00Coda<C003o`00
0?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgooOgmoo`000004oiVIV@03o`000?nc/k?o/k>c00?o
/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`05o`000?nIVIWoVIVIoiVI
VOl000000_moOgl01?l0003oIVIVofIVI_l00005oda<C003o`000?lc<c?o<c<c00Go<c<c00Go0000
oda<C?m<C4coC4a<o`000002ofIVIP06o`000?moOgooOgmoo`000?nIVIWo00001?nc/k<00ol0003o
c<c<olc<c006olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0
003oC4a<oda<C?l00008oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl00ol0003oVIVI
o`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmo
o`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`03o`000?m<C4coC4a<00;o000000Co
Ogmoo`000?nIVIWo00000_nc/k<00ol0003oooooooooo`04ooooo`7o00000Oooool1ooooo`009?oo
ool00ol0003oooooooooo`03ooooo`GoIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIV
IP0:ofIVIP;o00002_moOgl2o`0000coVIVI0_l0000Gok>c/`;o00003OnIVIT00ol0003oOgmoogmo
O`05ogmoO`03o`000?mVIVKoIVIV00GoIVIV00?o0000oda<C?m<C4`04om<C4`00ol0003oIVIVofIV
IP02ofIVIP03o`000?moOgooOgmo00;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000006ok>c/`03o`00
0?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00onc/k<01?l0003oVIVIoiVIVOl00003ogmoO`04
o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<
C004o`000?mVIVKoIVIVo`0000;oOgmo00?o0000oiVIVOl000000onc/k<00ol0003oc<c<olc<c006
olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<
C4coC4a<o`0000So<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`05o`000?nIVIWo0000
ok>c/ol000002Oo<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<
C003o`000?lc<c?o<c<c00Ko<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00000
0_nc/k<00ol0003oooooooooo`04ooooo`7o00000Oooool1ooooo`009?ooool00ol0003ooooooooo
o`03ooooo`CoIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?mo
OgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nI
VIWoVIVI00coVIVI00?o0000ogmoOomoOgl01OmoOgl00ol0003oIVIVofIVIP06ofIVIP03o`000?m<
C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000CoVIVI
00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c
00Co0000oiVIVOnIVIWo00000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000CoC4a<00?o0000oc<c
<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00?o0000
oiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nI
VIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Ko0000oda<C?m<C4co
0000ofIVI_l00002ogmoO`05o`000?nIVIWo0000ok>c/ol000002Oo<c<`03?l0003o/k>cok>c/ol0
003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000Wo<c<c00Wo0000oda<C?l0003oIVIVo`00
0?moOgoo0000oiVIVOl000000_nc/k<00ol0003oooooooooo`04ooooo`7o00000Oooool1ooooo`00
9?ooool00ol0003oooooooooo`03ooooo`?oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIV
ofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>c
ok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl01OmoOgl00ol0003oIVIV
ofIVIP06ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH00_mVIVH00ol0003oOgmo
ogmoO`02ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001_nc/k<00ol0003oc<c<olc<c004olc<c003
o`000?nc/k?o/k>c00?o/k>c00Co0000oiVIVOnIVIWo00000omoOgl01?l0003oIVIVofIVI_l00004
oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l0
0002ogmoO`03o`000?nIVIWo000000?o/k>c00?o0000olc<c?o<c<`01oo<c<`01?l0003o/k>cok>c
/ol00002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<01?l0003o
C4a<oda<C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006
olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c
<olc<c<01_lc<c<01Ol0003oC4a<o`000?mVIVKo000000;oOgmo0_l00002ok>c/`03o`000?o<c<co
oooo00Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo0_mVIVH00ol0
003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0
003oVIVIoiVIV@0:oiVIV@;o00005onc/k<2o`0000goVIVI00?o0000ogmoOomoOgl01_moOgl00ol0
003oIVIVofIVIP05ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH00omVIVH01Ol0
003oOgmoogmoOomoOgoo000000CoVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c003
olc<c003o`000?nc/k?o/k>c00?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`05o`000?mV
IVKoIVIVofIVI_l000001?m<C4`00ol0003o<c<coc<c<`05oc<c<`05o`000?m<C4coC4a<oda<C?l0
00000omVIVH00ol0003oOgmoo`000002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002Oo<c<`01_l0
003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00?o0000ofIVI_l000000om<C4`00ol0003o<c<coc<c
<`06oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl00ol0003oVIVIo`000002ok>c/`03
o`000?o<c<coc<c<00Koc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000
0_m<C4`00ol0003o<c<coc<c<`06oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo
000000;o/k>c00?o0000olc<c?ooool01Oooool1o`00007ooooo0Oooool002Cooooo0_l00004oooo
o`03ofIVI_l0003oC4a<01OoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`09ogmo
O`03o`000?nIVIWoVIVI00[oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0<oiVI
V@03o`000?moOgooOgmo00OoOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<C00Coda<
C003o`000?mVIVKoIVIV00;oIVIV00?o0000ogmoOomoOgl00_moOgl01Ol0003oVIVIoiVIVOnIVIWo
000000Oo/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`03ok>c/`05o`000?nIVIWo
VIVIoiVIVOl000000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000?oC4a<00?o0000oc<c<olc<c<0
1_lc<c<01Ol0003oC4a<oda<C?m<C4co000000?oIVIV00?o0000ogmoOol000000_nIVIT01Ol0003o
/k>cok>c/onc/k?o000000Woc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`03o`000?mV
IVKo000000;oC4a<00?o0000oc<c<olc<c<01olc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;o
Ogmo00Go0000oiVIVOl0003o/k>co`000009olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmo
Ool0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02Ol0003oC4a<o`000?mVIVKo0000
ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<cooooo00Cooooo0_l00002ooooo`009?ooool0
0ol0003oooooooooo`03ooooo`03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH0
0ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<0
0ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00OoOgmo00?o0000ofIVI_mVIVH01OmVIVH0
0ol0003oC4a<oda<C00Coda<C003o`000?mVIVKoIVIV00?oIVIV00Go0000ogmoOomoOgooOgmoo`00
0004oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c
/`03ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000?o
C4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000?oIVIV00?o0000ogmo
Ool000000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Woc<c<00Ko0000ok>c/onc/k?o0000oiVI
VOl00002ogmoO`03o`000?mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01_l0003oC4a<
oda<C?l0003oIVIVo`0000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<
c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<0
1_lc<c<00ol0003oC4a<o`000002ofIVIP;o000000GoVIVIo`000?nc/k?o/k>co`000002olc<c0Ko
oooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo6?m<C4`00ol0003oIVIV
ofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo0_l0000<oiVIV@;o00005onc/k<2o`0000goVIVI
00?o0000ogmoOomoOgl01_moOgl2o`0000OoIVIV00?o0000oda<C?m<C4`04om<C4`00ol0003oIVIV
ofIVIP03ofIVIP03o`000?moOgooOgmo00;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000006ok>c/`03
o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<01?nc/k<01?l0003oVIVIoiVIVOl00003ogmo
O`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<
C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000So
c<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo00?o0000ofIVI_l000000_m<C4`0
0ol0003o<c<coc<c<`07oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVIV@04
o`000?nc/k?o/k>co`0000Soc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo
0000oda<C?l00009oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c
00?o0000olc<c?o<c<`01_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00ooo
oolGoda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVI
V@0:oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmo
O`07ogmoO`03o`000?mVIVKoIVIV00KoIVIV00?o0000oda<C?m<C4`04om<C4`00ol0003oIVIVofIV
IP03ofIVIP05o`000?moOgooOgmoogmoOol000001?nIVIT00ol0003o/k>cok>c/`04ok>c/`03o`00
0?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<01?nc/k<01?l0003oVIVIoiVIVOl00003ogmoO`04
o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co
000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01?l0003o/k>cok>c/ol00009olc<c004o`00
0?nc/k?o/k>co`0000;oVIVI00Ko0000ogmoOomoOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o
<c<c00Oo<c<c00So0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000;oVIVI00Co0000ok>c/onc
/k?o00002?o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`00
00Wo<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<
olc<c006ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03oooooaKoC4a<00?o
0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00[oVIVI00?o
0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00OoOgmo00?o
0000ofIVI_mVIVH01_mVIVH00ol0003oC4a<oda<C00Coda<C003o`000?mVIVKoIVIV00?oIVIV00?o
0000ogmoOomoOgl00_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Ko/k>c00?o0000olc<c?o<c<`0
0oo<c<`00ol0003o/k>cok>c/`04ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01?l0003o
IVIVofIVI_l00004oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002
ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c007o`00
0?nc/k?o/k>cok>c/ol0003oVIVIo`000002ogmoO`03o`000?mVIVKo000000?oC4a<00?o0000oc<c
<olc<c<01_lc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00?o0000oiVIVOl000000_nc
/k<00ol0003oc<c<olc<c006olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIV
o`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<00ol0003oC4a<oda<C002o`000007ogmoOol0003o
VIVIoiVIVOl0003o/k>co`000003olc<c0Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oo
oooooooo00?ooooo5?m<C4`2o`0000goIVIV00?o0000ogmoOomoOgl02?moOgl2o`0000coVIVI00?o
0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00OoOgmo00?o
0000ofIVI_mVIVH01_mVIVH00ol0003oC4a<oda<C00Doda<C003o`000?mVIVKoIVIV00;oIVIV00?o
0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o
0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`03ok>c/`05o`000?nIVIWoVIVIoiVIVOl00000
0omoOgl01?l0003oIVIVofIVI_l00004oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<
C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`00
0008olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Ko0000ogmoOomoOgoo0000ofIVI_l00003oda<
C003o`000?lc<c?o<c<c00Ko<c<c00So0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000;oVIVI
00?o0000ok>c/ol000002Oo<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0
0002oda<C003o`000?lc<c?o<c<c00Ko<c<c00_o0000oda<C?l0003oIVIVo`000?moOgoo0000oiVI
VOl0003o/k>co`000004olc<c0Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo
00?ooooo4om<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVI
VOnIVIT02onIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmo
OomoOgl01omoOgl00ol0003oIVIVofIVIP06ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIV
I_mVIVH00omVIVH00ol0003oOgmoogmoO`02ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001onc/k<0
0ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c00Co/k>c00Go0000oiVIVOnIVIWoVIVIo`00
0003ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<
oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0
003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Ko0000ogmoOomoOgoo0000ofIV
I_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00So0000oda<C?m<C4co0000ofIVI_l0003oOgmo
o`0000;oVIVI00?o0000ok>c/ol000002Oo<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo
0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Go<c<c00co0000oda<C?m<C4co0000ofIVI_l0
003oOgmoo`000?nIVIWo0000ok>c/ol00004olc<c0Kooooo0Ol00001ooooo`7ooooo000Tooooo`03
o`000?oooooooooo00?ooooo4_m<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?moOgooOgmo00So
Ogmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00_o
VIVI00?o0000ogmoOomoOgl01omoOgl00ol0003oIVIVofIVIP07ofIVIP03o`000?m<C4coC4a<01?o
C4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00;o
VIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c00Co
/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000
oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo0000
0_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT01_l0
003oOgmoogmoOol0003oIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<
C?l00002ofIVIP;o00000_nIVIT01?l0003o/k>cok>c/ol00008olc<c00:o`000?nc/k?o/k>co`00
0?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<
o`000?mVIVKo000000;oOgmo0_l00002ok>c/`03o`000?o<c<coc<c<00;oc<c<1_ooool1o`00007o
oooo0Oooool001Wooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo00?o
oooo4Om<C4`2o`0000goIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03
o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02_nIVIT2o`0000WoOgmo00?o0000ofIVI_mV
IVH01omVIVH00ol0003oC4a<oda<C00Doda<C003o`000?mVIVKoIVIV00;oIVIV00?o0000ogmoOomo
Ogl00_moOgl00ol0003oVIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<
c<`00oo<c<`00ol0003o/k>cok>c/`04ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01Ol0
003oIVIVofIVI_mVIVKo000000CoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002
oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<
olc<c006olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003o
C4a<oda<C?l00008oc<c<`;o00000_m<C4`01Ol0003oIVIVo`000?moOgoo000000;oVIVI00Co0000
ok>c/onc/k?o00002?o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002
oda<C003o`000?lc<c?o<c<c00Ko<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0
00000_nc/k<00ol0003oc<c<olc<c002olc<c0Kooooo0Ol00001ooooo`7ooooo000Iooooo`05ob4Q
8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`03oooooa3oC4a<00?o0000ofIVI_mV
IVH03?mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc
/k<05onc/k<00ol0003oVIVIoiVIV@0:oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mV
IVH01_mVIVH00ol0003oC4a<oda<C00Eoda<C003o`000?mVIVKoIVIV00;oIVIV00?o0000ogmoOomo
Ogl00_moOgl00ol0003oVIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<
c<`00oo<c<`00ol0003o/k>cok>c/`04ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01Ol0
003oIVIVofIVI_mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<00ol0003oC4a<oda<C002
oda<C006o`000?mVIVKoIVIVo`000?moOgoo00000_nIVIT00ol0003o/k>cok>c/`02ok>c/`03o`00
0?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIVIP04
o`000?m<C4coC4a<o`0000So<c<c00Wo0000oda<C?m<C4coC4a<o`000?mVIVKo0000ogmoOol00000
0_nIVIT01?l0003o/k>cok>c/ol00008olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0
003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmo
Ool0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00;oc<c<1_ooool1o`00007ooooo0Oooool0
01Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00?ooooo3om<C4`0
0ol0003oIVIVofIVIP0<ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT0
0ol0003o/k>cok>c/`0Fok>c/`;o00003?nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKo
IVIV00KoIVIV00?o0000oda<C?m<C4`05Om<C4`00ol0003oIVIVofIVIP02ofIVIP03o`000?moOgoo
Ogmo00;oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`05ok>c/`03o`000?o<c<co
c<c<00;oc<c<00?o0000ok>c/onc/k<01?nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Go
0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`0
0_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<
c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@06o`000?moOgooOgmoo`000?mVIVKo0000
0_m<C4`00ol0003o<c<coc<c<`06oc<c<`09o`000?m<C4coC4a<oda<C?l0003oIVIVo`000?moOgoo
000000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`01ol0003o/k>co`000?nIVIWo0000ogmoOol0
00000_mVIVH00ol0003oC4a<o`000008oc<c<`03o`000?m<C4co000000;oIVIV0_l000001OnIVIWo
0000ok>c/onc/k?o000000Goc<c<1_ooool1o`00007ooooo0Oooool001Wooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P06ooooo`?o00000oooool?oda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmo
OomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVI
VOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00OoIVIV00?o0000oda<
C?m<C4`05?m<C4`00ol0003oIVIVofIVIP02ofIVIP;o00000omoOgl00ol0003oVIVIoiVIV@02oiVI
V@03o`000?nc/k?o/k>c00Go/k>c00?o0000olc<c?o<c<`00_o<c<`00ol0003o/k>cok>c/`04ok>c
/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01?l0003oIVIVofIVI_l00004oda<C003o`000?lc
<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;o
VIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT0
0ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Wo0000oda<C?m<C4coC4a<
o`000?mVIVKo0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00008olc<c00<o`000?nc/k?o
/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co00002Olc<c<01?l0003oC4a<o`000?mV
IVH3o`000005oiVIVOl0003o/k>cok>c/ol000001Oo<c<`4ooooo`?o00000_ooool001Wooooo00Go
c<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo00?ooooo3_m<C4`00ol0003oIVIV
ofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>c
ok>c/`0Gok>c/`03o`000?nIVIWoVIVI00[oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIV
ofIVIP07ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmo
ogmoO`02ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01Onc/k<00ol0003oc<c<
olc<c002olc<c003o`000?nc/k?o/k>c00Co/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`04
o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co
000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<
00Go0000ok>c/onc/k?o/k>co`000002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<
C4co00002?lc<c<02Ol0003oC4a<oda<C?m<C4co0000ofIVI_l0003oOgmoo`000002oiVIV@04o`00
0?nc/k?o/k>co`0000Soc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000
oda<C?l00009oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o
0000olc<c?o<c<`00oo<c<`6ooooo`7o00000Oooool1ooooo`006Oooool01Ol@413o^[Zjoooooonj
^[[o410@00Kooooo00?o0000ooooooooool00oooool=oda<C003o`000?mVIVKoIVIV00_oIVIV00?o
0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c0_l0
000<oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH01omVIVH00ol0003oC4a<oda<
C00Eoda<C003o`000?mVIVKoIVIV00;oIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVI
V@03oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`00_o<c<`00ol0003o/k>cok>c
/`04ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01Ol0003oIVIVofIVI_mVIVKo000000?o
C4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmo
OomoOgoo00000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00?o0000ok>c/onc/k<00_nc
/k<01Ol0003oVIVIo`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<01ol0003o
C4a<oda<C?m<C4co0000ofIVI_l000000_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<co
c<c<00Koc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`;o00000_m<C4`00ol0003o<c<c
oc<c<`06oc<c<`07o`000?m<C4co0000ofIVI_l0003oOgmoo`000002oiVIV@03o`000?nc/k?o0000
00Koc<c<1_ooool1o`00007ooooo0Oooool001Wooooo00Go0000okZj^_oooooo^[Zjo`000006oooo
o`03o`000?oooooooooo00?ooooo3?m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo
00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI
00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP07ofIVIP03o`000?m<C4coC4a<
01GoC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI
00;oVIVI00?o0000ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c
00Co/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`05o`000?mVIVKoIVIVofIVI_l000001?m<
C4`00ol0003o<c<coc<c<`05oc<c<`;o00000om<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`00
0?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o0000
00;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`04o`000?m<C4co
C4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT00ol0003o/k>co`000009olc<c00:o`000?nc
/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<0
2?l0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVI0_l000000onc/k?o0000olc<c005olc<c0Ko
oooo0Ol00001ooooo`7ooooo000Iooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003o
ooooooooo`03ooooo`_oC4a<00?o0000ofIVI_mVIVH02_mVIVH2o`0000[oOgmo00?o0000oiVIVOnI
VIT03?nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00[oVIVI00?o0000ogmoOomo
Ogl02OmoOgl00ol0003oIVIVofIVIP08ofIVIP03o`000?m<C4coC4a<01GoC4a<00?o0000ofIVI_mV
IVH00omVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc
/k<01Onc/k<00ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c00Co/k>c00Go0000oiVIVOnI
VIWoVIVIo`000002ogmoO`05o`000?mVIVKoIVIVofIVI_l000001?m<C4`00ol0003o<c<coc<c<`05
oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVI
VOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@03
o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<01?l0003oC4a<oda<C?l00002
ofIVIP03o`000?moOgoo000000;oVIVI00?o0000ok>c/ol000002Oo<c<`02_l0003o/k>cok>c/ol0
003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Wo0000oda<
C?l0003oIVIVo`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c004olc<c0Kooooo
0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo2_m<C4`00ol0003oIVIVofIV
IP0:ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT2o`0001Oo/k>c0_l0
000<oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02?mVIVH00ol0003oC4a<oda<
C00Eoda<C003o`000?mVIVKoIVIV00?oIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVI
V@02oiVIV@03o`000?nc/k?o/k>c00Go/k>c00?o0000olc<c?o<c<`00_o<c<`00ol0003o/k>cok>c
/`04ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000Co
C4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`00
00;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o
/k>cok>c/ol000000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000Wo<c<c
00Co0000oda<C?m<C4co00000_mVIVH2o`0000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01?l0
003o/k>cok>c/ol00002oiVIV@;o000000GoIVIVo`000?m<C4coC4a<o`000008oc<c<`07o`000?m<
C4coC4a<o`000?mVIVKo0000ogmoO`02o`0000;o/k>c00?o0000olc<c?o<c<`01Oo<c<`6ooooo`7o
00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`SoC4a<0_l0000<ofIVIP03o`00
0?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`00
0?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP08ofIVIP03o`00
0?m<C4coC4a<01GoC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`02ogmoO`03o`00
0?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c002olc<c003o`00
0?nc/k?o/k>c00Co/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`05o`000?mVIVKoIVIVofIV
I_l000001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIV
I_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Oo
0000ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo00000_m<C4`00ol0
003o<c<coc<c<`06oc<c<`03o`000?m<C4coC4a<00;o000000CoIVIVo`000?moOgoo00000_nIVIT0
1?l0003o/k>cok>c/ol00008olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIV
o`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?l0003oIVIV00Co00000_nc
/k<00ol0003oc<c<olc<c005olc<c0Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooo
oooo00?ooooo2?m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000
oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000
ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP09ofIVIP03o`000?m<C4coC4a<01GoC4a<00?o0000
ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000
ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c00Co/k>c00Go0000
oiVIVOnIVIWoVIVIo`000003ogmoO`05o`000?mVIVKoIVIVofIVI_l000001?m<C4`00ol0003o<c<c
oc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003o
VIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Oo0000ok>c/onc/k?o/k>co`000?nI
VIWo000000;oOgmo00Co0000ofIVI_mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`04o`00
0?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00007olc<
c00;o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o
<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<o`000?mVIVH00_l000001OnIVIWo0000ok>c/onc/k?o
000000Ooc<c<1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool7oda<
C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0<oiVI
V@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmo
O`03o`000?mVIVKoIVIV00WoIVIV00?o0000oda<C?m<C4`05Om<C4`00ol0003oIVIVofIVIP03ofIV
IP03o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`05ok>c
/`05o`000?o<c<coc<c<olc<c?l000001onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Go
0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`0
0_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo00000_nc/k<00ol0
003oc<c<olc<c007olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Ko0000ogmoOomoOgoo0000ofIV
I_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH01Ol0003o
Ogmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`03Ol0003o/k>cok>c/onc/k?o
0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l000002Olc<c<00ol0003oC4a<o`000002ofIV
IP;o000000GoVIVIo`000?nc/k?o/k>co`000007olc<c0Kooooo0Ol00001ooooo`7ooooo000Toooo
o`03o`000?oooooooooo00?ooooo1_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo
00SoOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI
00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP09ofIVIP03o`000?m<C4coC4a<
01CoC4a<00?o0000ofIVI_mVIVH01?mVIVH01Ol0003oOgmoogmoOomoOgoo000000GoVIVI00?o0000
ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c00Co/k>c00Go0000
oiVIVOnIVIWoVIVIo`000003ogmoO`05o`000?mVIVKoIVIVofIVI_l000001?m<C4`00ol0003o<c<c
oc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003o
VIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002
oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<01?l0003oC4a<oda<
C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`02_l0003o
/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c
00Go0000oda<C?m<C4co0000ofIVIP02o`000005oiVIVOl0003o/k>cok>c/ol000002?o<c<`6oooo
o`7o00000Oooool1ooooo`009?ooool2o`0000Cooooo1Om<C4`00ol0003oIVIVofIVIP0:ofIVIP;o
00002_moOgl2o`0000coVIVI0_l0000Gok>c/`;o00003OnIVIT00ol0003oOgmoogmoO`08ogmoO`;o
00002omVIVH00ol0003oC4a<oda<C00Doda<C003o`000?mVIVKoIVIV00CoIVIV00?o0000ogmoOomo
Ogl00_moOgl00ol0003oVIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c00Ko/k>c00Go0000olc<c?o<
c<coc<c<o`000006ok>c/`;o00000onIVIT01?l0003oOgmoogmoOol00003ofIVIP03o`000?m<C4co
C4a<00;oC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C005o`000?mVIVKo
IVIVofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<
00Co0000ok>c/onc/k?o00000_nIVIT01_l0003oOgmoogmoOol0003oIVIVo`0000?oC4a<00?o0000
oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl00000
0_nc/k<00ol0003oc<c<olc<c007olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003o
IVIVo`000?m<C4co00002Olc<c<01?l0003oC4a<o`000?mVIVH3o`000005oiVIVOl0003o/k>cok>c
/ol000002?o<c<`00ol0003oooooooooo`02ooooo`;o00000_ooool002Cooooo00?o0000oooooooo
ool00oooool4oda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003o
VIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003o
OgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00[oIVIV00?o0000oda<C?m<C4`05Om<C4`00ol0003o
IVIVofIVIP03ofIVIP03o`000?moOgooOgmo00?oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o
/k>cok>c/`06ok>c/`05o`000?o<c<coc<c<olc<c?l000001_nc/k<00ol0003oVIVIoiVIV@02oiVI
V@04o`000?moOgooOgmoo`0000?oIVIV00?o0000oda<C?m<C4`00_m<C4`00ol0003o<c<coc<c<`05
oc<c<`03o`000?m<C4coC4a<00;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`04o`000?nI
VIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@06
o`000?moOgooOgmoo`000?mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4co
C4a<o`0000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<
00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00009oc<c<`09o`00
0?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`0
0ol0003oooooooooo`03ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03oooo
o`?oC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI
00coVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo
00SoOgmo00?o0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<oda<C00Eoda<C003o`000?mVIVKoIVIV
00CoIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c
00Ko/k>c0ol000000oo<c<co0000ok>c/`05ok>c/`03o`000?nIVIWoVIVI00;oVIVI00Co0000ogmo
OomoOgoo00000omVIVH00ol0003oC4a<oda<C002oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000
oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo0000
0onc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Ko0000ogmoOomo
Ogoo0000ofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mV
IVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`02_l0003o/k>c
ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00?o
0000oda<C?l000000_mVIVH2o`0000;oVIVI00Co0000ok>c/onc/k?o00001oo<c<`00ol0003ooooo
ooooo`04ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`;oC4a<00?o
0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00[oVIVI0_l0
000Gok>c/`;o00003OnIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o
0000oda<C?m<C4`05?m<C4`00ol0003oIVIVofIVIP04ofIVIP03o`000?moOgooOgmo00;oOgmo00?o
0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`06ok>c/`04o`000?o<c<coc<c<o`0000Oo/k>c
00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`05o`000?mVIVKoIVIVofIVI_l000001?m<C4`00ol0
003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl0
1?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o0000
0_nIVIT01_l0003oOgmoogmoOol0003oIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0
003oC4a<oda<C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<
c007olc<c003o`000?nc/k?o000000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`00
0?lc<c?o<c<c00Ko<c<c00?o0000oda<C?l000000_mVIVH2o`0000;oVIVI00?o0000ok>c/ol00000
2?o<c<`00ol0003oooooooooo`04ooooo`7o00000Oooool1ooooo`009?ooool00ol0003ooooooooo
o`03ooooo`03oda<C?l0003oIVIV00coIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVI
V@0:oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmo
O`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05Om<C4`00ol0003oIVIVofIV
IP04ofIVIP05o`000?moOgooOgmoogmoOol000001_nIVIT00ol0003o/k>cok>c/`06ok>c/`04o`00
0?o<c<coc<c<o`0000Oo/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`05o`000?mVIVKoIVIV
ofIVI_l000001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000
ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Goc<c<
00Go0000ok>c/onc/k?o/k>co`000002oiVIV@06o`000?moOgooOgmoo`000?mVIVKo00000om<C4`0
0ol0003o<c<coc<c<`05oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01Ol0003oOgmoo`00
0?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`00ol0003o/k>co`000002oiVIV@05o`00
0?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`03o`000?m<C4co000000;o
IVIV0_l00002oiVIV@03o`000?nc/k?o000000Soc<c<00?o0000ooooooooool01?ooool1o`00007o
oooo0Oooool002Cooooo00?o0000ooooooooool00oooool00ol0003oIVIVofIVIP0;ofIVIP03o`00
0?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`00
0?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`00
0?m<C4coC4a<01GoC4a<00?o0000ofIVI_mVIVH01?mVIVH00ol0003oOgmoogmoO`02ogmoO`03o`00
0?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<01_nc/k<01?l0003oc<c<olc<c?l00007ok>c/`05
o`000?nIVIWoVIVIoiVIVOl000000omoOgl01Ol0003oIVIVofIVI_mVIVKo000000CoC4a<00?o0000
oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C003oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co
0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c005olc<c005o`000?nc/k?o/k>cok>c/ol0
00000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00_o0000
oda<C?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<
00Ooc<c<00?o0000ok>c/ol000000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000
oc<c<olc<c<01_lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>c
o`0000Soc<c<00?o0000ok>c/oooool01Oooool1o`00007ooooo0Oooool002Cooooo00?o0000oooo
ooooool00oooool=ofIVIP03o`000?moOgooOgmo00SoOgmo0_l0000<oiVIV@;o00005onc/k<2o`00
00goVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<
01GoC4a<00?o0000ofIVI_mVIVH01?mVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI
00?oVIVI00?o0000ok>c/onc/k<01_nc/k<2o`000003olc<c?l0003o/k>c00Ko/k>c00?o0000oiVI
VOnIVIT00_nIVIT01?l0003oOgmoogmoOol00003ofIVIP03o`000?m<C4coC4a<00?oC4a<00?o0000
oc<c<olc<c<01?lc<c<2o`0000CoC4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVI
VOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@03
o`000?moOgoo000000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`04o`000?m<C4coC4a<
o`0000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<0_l0
00002Onc/k?o0000o`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c
00Ko<c<c00Go0000oda<C?m<C4co0000ofIVIP03o`000003oiVIVOl0003o000000Woc<c<00?o0000
ok>c/oooool01Oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool<ofIV
IP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02_nIVIT00ol0003o/k>cok>c/`0Fok>c
/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIV
IP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH01?mVIVH00ol0003oOgmoogmoO`02ogmo
O`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<02?nc/k<00ol0003o/k>cok>c/`06ok>c
/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01Ol0003oIVIVofIVI_mVIVKo000000GoC4a<00?o
0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C003oda<C004o`000?mVIVKoIVIVo`0000;oOgmo
00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c
/ol000000_nIVIT00ol0003oOgmoo`000002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<0
1?l0003oC4a<oda<C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<
olc<c006olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<
C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4co0000ofIVIP02o`0000;oVIVI0_l00009
olc<c003o`000?nc/k?o000000Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo
00?ooooo2omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00[oVIVI00?o0000ok>c
/onc/k<05onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIV
I_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00CoIVIV00?o0000ogmo
OomoOgl00_moOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c017o/k>c00Go0000oiVI
VOnIVIWoVIVIo`000003ogmoO`05o`000?mVIVKoIVIVofIVI_l000001Om<C4`00ol0003o<c<coc<c
<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVI
oiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o0000ok>c/onc/k<00_nc/k<01Ol0003o
VIVIo`000?moOgoo000000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`04o`000?m<C4co
C4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00007olc<c004o`00
0?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH00ol0003oC4a<o`000008oc<c<`0<
o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00002?o<c<`01?l0003o
/k>cok>c/ol00005ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`[o
IVIV00?o0000ogmoOomoOgl02?moOgl2o`0000coVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003o
VIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003o
C4a<oda<C00Foda<C003o`000?mVIVKoIVIV00CoIVIV00?o0000ogmoOomoOgl00omoOgl00ol0003o
VIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c01;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmo
O`05o`000?mVIVKoIVIVofIVI_l000001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4co
C4a<00;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c
00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmoOol0
00000_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_mo
Ogl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o0000
0_nIVIT01ol0003oOgmoo`000?mVIVKo0000oda<C?l000002Olc<c<03?l0003oC4a<oda<C?l0003o
IVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Soc<c<00Co0000ok>c/onc/k?o00001Oooool1
o`00007ooooo0Oooool002Cooooo0_l00004ooooo`WoIVIV00?o0000ogmoOomoOgl02?moOgl00ol0
003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0
003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0
003oIVIVofIVIP05ofIVIP03o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0
003o/k>cok>c/`0Bok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01Ol0003oIVIVofIVI_mV
IVKo000000CoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C005o`000?mV
IVKoIVIVofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Ko
c<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<
C?m<C4co00002Olc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00?o0000oiVIVOl00000
0_nc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Oo0000ogmoOol0
003oIVIVo`000?m<C4co000000Wo<c<c00?o0000oda<C?m<C4`00_l00002ogmoO`05o`000?nIVIWo
0000ok>c/ol000002?o<c<`01?l0003o/k>cok>c/ol00004ooooo`;o00000_ooool002Cooooo00?o
0000ooooooooool00oooool8ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onI
VIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?mo
Ogl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH01OmV
IVH00ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<04_nc
/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Go0000ofIVI_mVIVKoIVIVo`000005oda<C003
o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo0000
00;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o
/k>cok>c/ol000000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000Wo<c<c
00Co0000oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<
c?o<c<`01oo<c<`00ol0003o/k>co`000002oiVIV@03o`000?moOgooOgmo00;o00000_m<C4`00ol0
003o<c<coc<c<`06oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o
/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003o/k>co`000006ooooo`7o00000Oooool1ooooo`00
9?ooool00ol0003oooooooooo`03ooooo`OoIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVI
oiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02_nIVIT2o`0000[oOgmo
00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00GoIVIV
00?o0000ogmoOomoOgl00omoOgl00ol0003oVIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c01;o/k>c
00?o0000oiVIVOnIVIT00_nIVIT01?l0003oOgmoogmoOol00003ofIVIP;o00001?m<C4`00ol0003o
<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01Ol0
003oVIVIoiVIVOnIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01ol0003o/k>cok>c/onc
/k?o0000oiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo
<c<c00Go0000oda<C?m<C4co0000ofIVIP02o`000004ogmoOol0003oVIVIo`0000;o/k>c00?o0000
olc<c?o<c<`01oo<c<`00ol0003o/k>co`000002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<
C4`00ol0003o<c<coc<c<`06oc<c<`03o`000?m<C4co000000;oIVIV00Oo0000ogmoOol0003oVIVI
o`000?nc/k?o000000Soc<c<00Co0000ok>c/onc/k?o00001_ooool1o`00007ooooo0Oooool002Co
oooo00?o0000ooooooooool00oooool6ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnI
VIT02onIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00[oVIVI00?o0000ogmoOomo
Ogl02OmoOgl00ol0003oIVIVofIVIP0;ofIVIP;o00006?m<C4`00ol0003oIVIVofIVIP05ofIVIP03
o`000?moOgooOgmo00?oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`0Bok>c/`03
o`000?nIVIWoVIVI00;oVIVI00Co0000ogmoOomoOgoo00000omVIVH00ol0003oC4a<oda<C003oda<
C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00om<C4`01?l0003oIVIVofIVI_l00002
ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000onc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc
/k?o/k>c00;o/k>c00?o0000oiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00002oda<C003o`00
0?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH01_l0003oOgmoogmoOol0003oVIVI
o`0000;o/k>c00?o0000olc<c?o<c<`01oo<c<`01Ol0003o/k>co`000?nIVIWo000000;oOgmo00?o
0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`03o`000?m<C4co000000;oIVIV00Co
0000ogmoOol0003o00000_nc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`0000Ko
oooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo1OmVIVH00ol0003oOgmo
ogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<2o`0000coVIVI
00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<
00?o0000ofIVI_mVIVH01OmVIVH00ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00;oVIVI
00?o0000ok>c/onc/k<04_nc/k<00ol0003oVIVIoiVIV@02oiVIV@04o`000?moOgooOgmoo`0000?o
IVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;o
C4a<00Co0000ofIVI_mVIVKo00000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000?o/k>c00?o0000
olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Ko0000ogmoOomoOgoo0000
ofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002
ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`00ol0003o/k>co`000002
oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0<o`000?m<
C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00002Oo<c<`01Ol0003o/k>co`00
0?nIVIWo000000Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo1?mV
IVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc
/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omV
IVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00GoIVIV00?o0000ogmoOomoOgl00omo
Ogl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c01;o/k>c00Go0000oiVIVOnIVIWoVIVI
o`000003ogmoO`05o`000?mVIVKoIVIVofIVI_l000001Om<C4`00ol0003o<c<coc<c<`04oc<c<`03
o`000?m<C4coC4a<00;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`04o`000?nIVIWoVIVI
o`0000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co
0000ogmoOomoOgoo00000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`07o`000?m<C4coC4a<oda<
C?l0003oIVIVo`000002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`0
1?l0003o/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<c
oc<c<`06oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o0000
2Oo<c<`2o`000003oiVIVOl0003ooooo00Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oo
oooooooo00?ooooo0omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o
0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0:oiVIV@03o`000?moOgooOgmo00WoOgmo00?o
0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00KoIVIV00?o
0000ogmoOomoOgl00omoOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c01;o/k>c00Go
0000oiVIVOnIVIWoVIVIo`000002ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`0
0om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00;oC4a<00Go0000ofIVI_mVIVKo
IVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`01Ol0
003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01?l0003oC4a<oda<
C?l00008oc<c<`07o`000?m<C4coC4a<oda<C?l0003oIVIVo`000002ogmoO`03o`000?nIVIWo0000
00;o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@05o`000?moOgoo
0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<o`000?mVIVH0
0_l00002oiVIV@03o`000?nc/k?o000000Woc<c<0_l000000onIVIWo0000ooooo`05ooooo`7o0000
0Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`;oIVIV00?o0000ogmoOomoOgl02?mo
Ogl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c0_l0000<oiVIV@03o`000?mo
OgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mV
IVKoIVIV00KoIVIV00?o0000ogmoOomoOgl00omoOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc
/k?o/k>c01;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`05o`000?mVIVKoIVIVofIVI_l0
00001Om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00;oC4a<00Go0000ofIVI_mV
IVKoIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`0
1Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01?l0003oC4a<
oda<C?l00008oc<c<`07o`000?m<C4coC4a<oda<C?l0003oIVIVo`000002ogmoO`04o`000?nIVIWo
VIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003o/k>co`000002oiVIV@03o`000?mo
Ogoo000000;oIVIV00?o0000oda<C?l000002?lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?mo
Ogoo0000oiVIVOl0003o/k>co`0000Woc<c<00Go0000ok>c/ol0003o0000ogmoO`06ooooo`7o0000
0Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`03ofIVI_l0003oOgmo00WoOgmo00?o
0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o
0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o
0000ofIVI_mVIVH01_mVIVH00ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o
0000ok>c/onc/k<04_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00?o0000ofIVI_mVIVH0
0_mVIVH00ol0003oC4a<oda<C002oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`0
0_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0
003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01_l0003oOgmoogmoOol0
003oIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01ol0003oC4a<oda<C?m<C4co0000ofIV
I_l000000_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c
/onc/k?o00000_nIVIT01ol0003oOgmoo`000?mVIVKo0000oda<C?l000002Olc<c<03?l0003oC4a<
oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Soc<c<00?o0000ok>c/onc/k<0
0_l000000omoOgooooooooooo`04ooooo`7o00000Oooool1ooooo`009?ooool00ol0003ooooooooo
o`03ooooo`03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c
/`0Fok>c/`03o`000?nIVIWoVIVI00[oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIV
IP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH01omVIVH00ol0003oOgmoogmo
O`03ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<04_nc/k<01Ol0003oVIVIoiVI
VOnIVIWo000000?oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C002oda<C003o`00
0?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00003ogmoO`04
o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o
000000;oVIVI00Ko0000ogmoOomoOgoo0000ofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c
00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0
003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`0000;oVIVI0_l00002ofIVIP03o`000?m<C4co
000000Wo<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00008
olc<c003o`000?nc/k?o/k>c00;o000000?oOgmoooooooooool01?ooool1o`00007ooooo0Oooool0
02Cooooo0_l00004ooooo`[oOgmo00?o0000oiVIVOnIVIT02onIVIT2o`0001Oo/k>c0_l0000<oiVI
V@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Goda<
C003o`000?mVIVKoIVIV00KoIVIV0_l00005ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c
/onc/k<04_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00?o0000ofIVI_mVIVH00_mVIVH0
0ol0003oC4a<oda<C002oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`0
1Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000002ok>c/`03o`00
0?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`00
00;oIVIV00Co0000oda<C?m<C4co00002?lc<c<01ol0003oC4a<oda<C?m<C4co0000ofIVI_l00000
0_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00?o0000ok>c/ol00000
0_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<03?l0003o
C4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Woc<c<00Oo0000ok>c/ol0
003oVIVIo`000?moOgoo000000Cooooo0_l00002ooooo`009?ooool00ol0003oooooooooo`03oooo
o`WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI
00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<
01OoC4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0003oOgmoogmoO`04ogmoO`03o`000?nIVIWoVIVI
00?oVIVI00?o0000ok>c/onc/k<04_nc/k<00ol0003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmo
ogmoOol000000omVIVH00ol0003oC4a<oda<C003oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000
oda<C?m<C4`00om<C4`01?l0003oIVIVofIVI_l00002ogmoO`05o`000?nIVIWoVIVIoiVIVOl00000
0onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01Ol0003o
OgmoogmoOol0003oIVIV00;o00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<
o`0000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00009olc<c005o`000?nc
/k?o0000oiVIVOl000000_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c
00?o0000oda<C?l000000_mVIVH01ol0003oOgmoo`000?nIVIWo0000ok>c/ol000002?o<c<`02?l0
003o/k>cok>c/ol0003oVIVIo`000?moOgoo00001Oooool1o`00007ooooo0Oooool002Cooooo00?o
0000ooooooooool00oooool8ogmoO`03o`000?nIVIWoVIVI00coVIVI00?o0000ok>c/onc/k<05_nc
/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omV
IVH00ol0003oC4a<oda<C00Hoda<C003o`000?mVIVKoIVIV00KoIVIV00?o0000ogmoOomoOgl01?mo
Ogl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c01;o/k>c00?o0000oiVIVOnIVIT00_nI
VIT01Ol0003oOgmoogmoOomoOgoo000000?oIVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o<c<c
oc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01Ol0003o
VIVIoiVIVOnIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01ol0003o/k>cok>c/onc/k?o
0000oiVIVOl000000omoOgl00ol0003oIVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co
0000oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Wo
c<c<00Go0000ok>c/ol0003oVIVIo`000002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c
<olc<c<01_lc<c<00ol0003oC4a<o`000002ofIVIP07o`000?moOgoo0000oiVIVOl0003o/k>co`00
0008olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00005ooooo`7o00000Oooool1oooo
o`009?ooool00ol0003oooooooooo`03ooooo`OoOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o
/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003o
IVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0003o
OgmoogmoO`04ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<04_nc/k<00ol0003o
VIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol000001?mVIVH00ol0003oC4a<oda<C002oda<
C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo
000000;oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c005olc<c005o`000?nc
/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<
C?l000002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000
ok>c/onc/k?o00002?o<c<`00ol0003o/k>co`000002oiVIV@06o`000?moOgooOgmoo`000?mVIVKo
00000_m<C4`00ol0003o<c<coc<c<`05oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Co0000ogmo
Ool0003o00000_nc/k<00ol0003oc<c<olc<c006olc<c003o`000?nc/k?o/k>c00;o00000_moOgl0
0ol0003oooooooooo`03ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03oooo
o`KoOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI
00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<
01OoC4a<00?o0000ofIVI_mVIVH01omVIVH00ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI
00CoVIVI00?o0000ok>c/onc/k<04_nc/k<00ol0003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmo
ogmoOol000000omVIVH00ol0003oC4a<oda<C003oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000
oda<C?m<C4`00om<C4`01?l0003oIVIVofIVI_l00002ogmoO`05o`000?nIVIWoVIVIoiVIVOl00000
0onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01_l0003o
OgmoogmoOol0003oIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l0
0002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`01Ol0003o/k>c
o`000?nIVIWo000000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0<
o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00002?o<c<`02?l0003o
/k>cok>c/ol0003oVIVIo`000?moOgoo00001_ooool1o`00007ooooo0Oooool002Cooooo00?o0000
ooooooooool00oooool5ogmoO`;o00003?nIVIT2o`0001Oo/k>c0_l0000=oiVIV@03o`000?moOgoo
Ogmo00SoOgmo0_l0000<ofIVIP;o00006Om<C4`00ol0003oIVIVofIVIP07ofIVIP03o`000?moOgoo
Ogmo00CoOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0Cok>c/`05o`000?nIVIWo
VIVIoiVIVOl000000omoOgl01?l0003oIVIVofIVI_mVIVH2o`0000GoC4a<00?o0000oc<c<olc<c<0
1?lc<c<00ol0003oC4a<oda<C002oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01?l0003o
VIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01_l0
003oVIVIoiVIVOl0003oOgmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`04o`00
0?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00008olc<
c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc
<c?o<c<c00Ko<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol0
0008olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00006ooooo`7o00000Oooool1oooo
o`009?ooool00ol0003oooooooooo`03ooooo`CoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o
/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003o
IVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01SoC4a<00?o0000ofIVI_mVIVH02?mVIVH00ol0003o
OgmoogmoO`04ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<04onc/k<01Ol0003o
VIVIoiVIVOnIVIWo000000?oOgmo00Go0000ofIVI_mVIVKoIVIVo`000006oda<C003o`000?lc<c?o
<c<c00?o<c<c00?o0000oda<C?m<C4`00om<C4`01?l0003oIVIVofIVI_l00002ogmoO`05o`000?nI
VIWoVIVIoiVIVOl000001?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c
00Ko0000oiVIVOnIVIWo0000ogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<0
1?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o0000
2?o<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo0_l00003oda<C003o`000?lc<c?o<c<c
00Ko<c<c00Go0000oda<C?m<C4co0000ofIVIP02o`0000;oVIVI00?o0000ok>c/ol000002?o<c<`0
2?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo00001_ooool1o`00007ooooo0Oooool002Cooooo
00?o0000ooooooooool00oooool3ogmoO`03o`000?nIVIWoVIVI00coVIVI00?o0000ok>c/onc/k<0
5_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH0
2omVIVH00ol0003oC4a<oda<C00Hoda<C003o`000?mVIVKoIVIV00SoIVIV00?o0000ogmoOomoOgl0
1?moOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c01?o/k>c00Go0000oiVIVOnIVIWo
VIVIo`000003ogmoO`05o`000?mVIVKoIVIVofIVI_l000001_m<C4`00ol0003o<c<coc<c<`04oc<c
<`03o`000?m<C4coC4a<00;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`05o`000?nIVIWo
VIVIoiVIVOl000000onc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Ko
0000oiVIVOnIVIWo0000ogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01?l0
003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<
c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o
<c<coc<c<`06oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o
00002Oo<c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000005ooooo`7o00000Ooo
ool1ooooo`004_ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h6ooooo`03
o`000?oooooooooo00?ooooo0omoOgl00ol0003oVIVIoiVIV@0:oiVIV@;o00005onc/k<2o`0000go
VIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01Oo
C4a<0_l00009ofIVIP;o00001_moOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c01?o
/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000?oIVIV00?o0000oda<
C?m<C4`00om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Go0000ofIV
I_mVIVKoIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01Oo<
c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01Ol0003o
C4a<oda<C?m<C4co000000So<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002
oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`05
o`000?mVIVKo0000oda<C?l000002Olc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000
oiVIVOl0003o/k>co`0000Woc<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00000
1Oooool1o`00007ooooo0Oooool001Cooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Kooooo00?o0000ooooooooool00oooool2ogmoO`03o`000?nIVIWoVIVI00[oVIVI
00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo00SoOgmo
00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00WoIVIV
00?o0000ogmoOomoOgl01?moOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c01;o/k>c
00?o0000oiVIVOnIVIT00onIVIT01?l0003oOgmoogmoOol00004ofIVIP03o`000?m<C4coC4a<00?o
C4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C003oda<C005o`000?mVIVKoIVIVofIV
I_l000000_moOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Goc<c<00Go0000
ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Go0000oda<C?m<C4co
C4a<o`000007oc<c<`07o`000?m<C4coC4a<oda<C?l0003oIVIVo`000002ogmoO`04o`000?nIVIWo
VIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02?l0003o/k>cok>c/ol0003oVIVIo`000?mo
Ogoo00000_mVIVH00ol0003oC4a<o`000009oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmo
Ool0003oVIVIo`000?nc/k?o00002Oo<c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIV
o`000005ooooo`7o00000Oooool1ooooo`005?ooool00ol0003oooooooooo`02ooooo`05oa0@4?oo
ooooooooooooool@41001_ooool00ol0003oooooooooo`03ooooo`03ogmoOol0003oVIVI00coVIVI
00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo
00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00WoIVIV
00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c01?o/k>c
00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000?oIVIV00?o0000oda<C?m<
C4`00om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Go0000ofIVI_mV
IVKoIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`0
1Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000omVIVH01?l0003oC4a<
oda<C?l00008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0
003o/k>cok>c/ol00008olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl00ol0003oIVIV
o`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmo
o`000?nIVIWo0000ok>c/ol00009olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo
000000Kooooo0Ol00001ooooo`7ooooo000Dooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`000006ooooo`?o00000oooool00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o
/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKo
IVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP09ofIVIP03o`000?moOgoo
Ogmo00GoOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0Cok>c/`03o`000?nIVIWo
VIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`000004ofIVIP03o`000?m<C4coC4a<00?oC4a<00?o
0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C002oda<C005o`000?mVIVKoIVIVofIVI_l00000
0_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o
/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01?l0003oC4a<oda<C?l0
0008oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`00
0?nc/k?o/k>co`0000Soc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`03o`000?mVIVKo
000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<00ol0003oC4a<o`000002ofIVIP07o`000?moOgoo
0000oiVIVOl0003o/k>co`000008olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003o
IVIVo`0000Cooooo0ol00002ooooo`005?ooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`3oooooocoooooo0Ol00001ooooo`7ooooo000D
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oo
oooooooo0?oooooo?oooool1o`00007ooooo0Oooool001Cooooo00?o0000ooooooooool00_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0ooooooloooooo`7o00000Ooo
ool1ooooo`004_ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_oo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool00ooo
ool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03
ooooo`7o00000Oooool1ooooo`009?ooooooo`0004?o00000_ooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-7.04757, -6.93977, 0.0606246, \
0.0606246}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.339744 0.0641026 0.339744 0.0641026 [
[.08333 -0.0125 -6 -9 ]
[.08333 -0.0125 6 0 ]
[.21154 -0.0125 -6 -9 ]
[.21154 -0.0125 6 0 ]
[.33974 -0.0125 -3 -9 ]
[.33974 -0.0125 3 0 ]
[.46795 -0.0125 -3 -9 ]
[.46795 -0.0125 3 0 ]
[.59615 -0.0125 -3 -9 ]
[.59615 -0.0125 3 0 ]
[.72436 -0.0125 -3 -9 ]
[.72436 -0.0125 3 0 ]
[.85256 -0.0125 -3 -9 ]
[.85256 -0.0125 3 0 ]
[.98077 -0.0125 -6 -9 ]
[.98077 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5 -21 ]
[.5 -0.0125 5 -9 ]
[-0.0125 .08333 -12 -4.5 ]
[-0.0125 .08333 0 4.5 ]
[-0.0125 .21154 -12 -4.5 ]
[-0.0125 .21154 0 4.5 ]
[-0.0125 .33974 -6 -4.5 ]
[-0.0125 .33974 0 4.5 ]
[-0.0125 .46795 -6 -4.5 ]
[-0.0125 .46795 0 4.5 ]
[-0.0125 .59615 -6 -4.5 ]
[-0.0125 .59615 0 4.5 ]
[-0.0125 .72436 -6 -4.5 ]
[-0.0125 .72436 0 4.5 ]
[-0.0125 .85256 -6 -4.5 ]
[-0.0125 .85256 0 4.5 ]
[-0.0125 .98077 -12 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -24 -5 ]
[-0.01875 .5 -12 5 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08333 0 m
.08333 .00625 L
s
[(-4)] .08333 -0.0125 0 1 Mshowa
.21154 0 m
.21154 .00625 L
s
[(-2)] .21154 -0.0125 0 1 Mshowa
.33974 0 m
.33974 .00625 L
s
[(0)] .33974 -0.0125 0 1 Mshowa
.46795 0 m
.46795 .00625 L
s
[(2)] .46795 -0.0125 0 1 Mshowa
.59615 0 m
.59615 .00625 L
s
[(4)] .59615 -0.0125 0 1 Mshowa
.72436 0 m
.72436 .00625 L
s
[(6)] .72436 -0.0125 0 1 Mshowa
.85256 0 m
.85256 .00625 L
s
[(8)] .85256 -0.0125 0 1 Mshowa
.98077 0 m
.98077 .00625 L
s
[(10)] .98077 -0.0125 0 1 Mshowa
.125 Mabswid
.11538 0 m
.11538 .00375 L
s
.14744 0 m
.14744 .00375 L
s
.17949 0 m
.17949 .00375 L
s
.24359 0 m
.24359 .00375 L
s
.27564 0 m
.27564 .00375 L
s
.30769 0 m
.30769 .00375 L
s
.37179 0 m
.37179 .00375 L
s
.40385 0 m
.40385 .00375 L
s
.4359 0 m
.4359 .00375 L
s
.5 0 m
.5 .00375 L
s
.53205 0 m
.53205 .00375 L
s
.5641 0 m
.5641 .00375 L
s
.62821 0 m
.62821 .00375 L
s
.66026 0 m
.66026 .00375 L
s
.69231 0 m
.69231 .00375 L
s
.75641 0 m
.75641 .00375 L
s
.78846 0 m
.78846 .00375 L
s
.82051 0 m
.82051 .00375 L
s
.88462 0 m
.88462 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.94872 0 m
.94872 .00375 L
s
.05128 0 m
.05128 .00375 L
s
.01923 0 m
.01923 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66 -25 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .08333 m
.00625 .08333 L
s
[(-4)] -0.0125 .08333 1 0 Mshowa
0 .21154 m
.00625 .21154 L
s
[(-2)] -0.0125 .21154 1 0 Mshowa
0 .33974 m
.00625 .33974 L
s
[(0)] -0.0125 .33974 1 0 Mshowa
0 .46795 m
.00625 .46795 L
s
[(2)] -0.0125 .46795 1 0 Mshowa
0 .59615 m
.00625 .59615 L
s
[(4)] -0.0125 .59615 1 0 Mshowa
0 .72436 m
.00625 .72436 L
s
[(6)] -0.0125 .72436 1 0 Mshowa
0 .85256 m
.00625 .85256 L
s
[(8)] -0.0125 .85256 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(10)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .11538 m
.00375 .11538 L
s
0 .14744 m
.00375 .14744 L
s
0 .17949 m
.00375 .17949 L
s
0 .24359 m
.00375 .24359 L
s
0 .27564 m
.00375 .27564 L
s
0 .30769 m
.00375 .30769 L
s
0 .37179 m
.00375 .37179 L
s
0 .40385 m
.00375 .40385 L
s
0 .4359 m
.00375 .4359 L
s
0 .5 m
.00375 .5 L
s
0 .53205 m
.00375 .53205 L
s
0 .5641 m
.00375 .5641 L
s
0 .62821 m
.00375 .62821 L
s
0 .66026 m
.00375 .66026 L
s
0 .69231 m
.00375 .69231 L
s
0 .75641 m
.00375 .75641 L
s
0 .78846 m
.00375 .78846 L
s
0 .82051 m
.00375 .82051 L
s
0 .88462 m
.00375 .88462 L
s
0 .91667 m
.00375 .91667 L
s
0 .94872 m
.00375 .94872 L
s
0 .05128 m
.00375 .05128 L
s
0 .01923 m
.00375 .01923 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
-0.01875 .5 -84 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
66 10 translate
90 rotate
-66 -10 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.08333 .99375 m
.08333 1 L
s
.21154 .99375 m
.21154 1 L
s
.33974 .99375 m
.33974 1 L
s
.46795 .99375 m
.46795 1 L
s
.59615 .99375 m
.59615 1 L
s
.72436 .99375 m
.72436 1 L
s
.85256 .99375 m
.85256 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.11538 .99625 m
.11538 1 L
s
.14744 .99625 m
.14744 1 L
s
.17949 .99625 m
.17949 1 L
s
.24359 .99625 m
.24359 1 L
s
.27564 .99625 m
.27564 1 L
s
.30769 .99625 m
.30769 1 L
s
.37179 .99625 m
.37179 1 L
s
.40385 .99625 m
.40385 1 L
s
.4359 .99625 m
.4359 1 L
s
.5 .99625 m
.5 1 L
s
.53205 .99625 m
.53205 1 L
s
.5641 .99625 m
.5641 1 L
s
.62821 .99625 m
.62821 1 L
s
.66026 .99625 m
.66026 1 L
s
.69231 .99625 m
.69231 1 L
s
.75641 .99625 m
.75641 1 L
s
.78846 .99625 m
.78846 1 L
s
.82051 .99625 m
.82051 1 L
s
.88462 .99625 m
.88462 1 L
s
.91667 .99625 m
.91667 1 L
s
.94872 .99625 m
.94872 1 L
s
.05128 .99625 m
.05128 1 L
s
.01923 .99625 m
.01923 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .08333 m
1 .08333 L
s
.99375 .21154 m
1 .21154 L
s
.99375 .33974 m
1 .33974 L
s
.99375 .46795 m
1 .46795 L
s
.99375 .59615 m
1 .59615 L
s
.99375 .72436 m
1 .72436 L
s
.99375 .85256 m
1 .85256 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .11538 m
1 .11538 L
s
.99625 .14744 m
1 .14744 L
s
.99625 .17949 m
1 .17949 L
s
.99625 .24359 m
1 .24359 L
s
.99625 .27564 m
1 .27564 L
s
.99625 .30769 m
1 .30769 L
s
.99625 .37179 m
1 .37179 L
s
.99625 .40385 m
1 .40385 L
s
.99625 .4359 m
1 .4359 L
s
.99625 .5 m
1 .5 L
s
.99625 .53205 m
1 .53205 L
s
.99625 .5641 m
1 .5641 L
s
.99625 .62821 m
1 .62821 L
s
.99625 .66026 m
1 .66026 L
s
.99625 .69231 m
1 .69231 L
s
.99625 .75641 m
1 .75641 L
s
.99625 .78846 m
1 .78846 L
s
.99625 .82051 m
1 .82051 L
s
.99625 .88462 m
1 .88462 L
s
.99625 .91667 m
1 .91667 L
s
.99625 .94872 m
1 .94872 L
s
.99625 .05128 m
1 .05128 L
s
.99625 .01923 m
1 .01923 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.4 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.3 g
.01923 .9412 m
.0282 .93221 L
.02894 .93149 L
.03794 .92249 L
.03866 .92178 L
.04765 .91278 L
.04837 .91207 L
.05736 .90307 L
.05808 .90235 L
.06708 .89336 L
.06779 .89264 L
.07679 .88364 L
.07751 .88293 L
.0865 .87393 L
.08722 .87322 L
.09621 .86422 L
.09693 .8635 L
.10593 .85451 L
.10664 .85379 L
.11564 .84479 L
.11636 .84408 L
.12535 .83508 L
.12607 .83437 L
.13506 .82537 L
.13578 .82465 L
.14478 .81566 L
.14549 .81494 L
.15449 .80594 L
.15521 .80523 L
.1642 .79623 L
.16492 .79552 L
.17391 .78652 L
.17463 .7858 L
.18363 .77681 L
.18434 .77609 L
.19334 .76709 L
.19406 .76638 L
.20305 .75738 L
.20377 .75666 L
.21276 .74767 L
.21348 .74695 L
.22248 .73796 L
.22319 .73724 L
.23219 .72824 L
.23291 .72753 L
.2419 .71853 L
.24262 .71781 L
.25161 .70882 L
.25233 .7081 L
.26133 .69911 L
.26204 .69839 L
.27104 .68939 L
.27176 .68868 L
.28075 .67968 L
.28147 .67896 L
.29046 .66997 L
.29118 .66925 L
.30018 .66026 L
.30089 .65954 L
.30989 .65054 L
.31061 .64983 L
.3196 .64083 L
.32032 .64011 L
.32931 .63112 L
.33003 .6304 L
.33897 .62141 L
.33974 .62069 L
.34946 .61368 L
.35208 .61169 L
.35917 .60538 L
.36297 .60198 L
.36888 .596 L
.37262 .59227 L
.37859 .58571 L
.3815 .58256 L
.38831 .5746 L
.38982 .57284 L
.39774 .56313 L
.39802 .56276 L
.40542 .55342 L
.40773 .55025 L
.41272 .54371 L
.41744 .5371 L
.41972 .53399 L
.42655 .52428 L
.42716 .52335 L
.43327 .51457 L
.43687 .50905 L
.4397 .50486 L
.44601 .49514 L
.44658 .4942 L
.45227 .48543 L
.45629 .47885 L
.45827 .47572 L
.46427 .46601 L
.46601 .46301 L
.47012 .45629 L
.47572 .44668 L
.47577 .44658 L
.48154 .43687 L
.48543 .4299 L
.48703 .42716 L
.49259 .41744 L
.49514 .41269 L
.49795 .40773 L
.50331 .39802 L
.50486 .39503 L
.50858 .38831 L
.51375 .37859 L
.51457 .37696 L
.51893 .36888 L
.52395 .35917 L
.52428 .35848 L
.52905 .34946 L
.53393 .33974 L
.53399 .3396 L
.53895 .33003 L
.54371 .32033 L
.54371 .32032 L
.54865 .31061 L
.55333 .30089 L
.55342 .30069 L
.55816 .29118 L
.56278 .28147 L
.56313 .28067 L
.56751 .27176 L
.57208 .26204 L
.57284 .26029 L
.57669 .25233 L
.58123 .24262 L
.58256 .23956 L
.58571 .23291 L
.59023 .22319 L
.59227 .21847 L
.5946 .21348 L
.59908 .20377 L
.60198 .19703 L
.60335 .19406 L
.6078 .18434 L
.61169 .17525 L
.61198 .17463 L
.61638 .16492 L
.62059 .15521 L
.62141 .15315 L
.62483 .14549 L
.62908 .13578 L
.63112 .13072 L
.63317 .12607 L
.63742 .11636 L
.64083 .10796 L
.6414 .10664 L
.64562 .09693 L
.64966 .08722 L
.65054 .08489 L
.65371 .07751 L
.65781 .06779 L
.66026 .0615 L
.6617 .05808 L
.66581 .04837 L
.66966 .03866 L
.66997 .0378 L
.67368 .02894 L
.67765 .01923 L
.01923 .01923 L
F
0 g
.01923 .9412 m
.0282 .93221 L
.02894 .93149 L
.03794 .92249 L
.03866 .92178 L
.04765 .91278 L
.04837 .91207 L
.05736 .90307 L
.05808 .90235 L
.06708 .89336 L
.06779 .89264 L
.07679 .88364 L
.07751 .88293 L
.0865 .87393 L
.08722 .87322 L
.09621 .86422 L
.09693 .8635 L
.10593 .85451 L
.10664 .85379 L
.11564 .84479 L
.11636 .84408 L
.12535 .83508 L
.12607 .83437 L
.13506 .82537 L
.13578 .82465 L
.14478 .81566 L
.14549 .81494 L
.15449 .80594 L
.15521 .80523 L
.1642 .79623 L
.16492 .79552 L
.17391 .78652 L
.17463 .7858 L
.18363 .77681 L
.18434 .77609 L
.19334 .76709 L
.19406 .76638 L
.20305 .75738 L
.20377 .75666 L
.21276 .74767 L
.21348 .74695 L
.22248 .73796 L
.22319 .73724 L
.23219 .72824 L
.23291 .72753 L
.2419 .71853 L
.24262 .71781 L
.25161 .70882 L
.25233 .7081 L
.26133 .69911 L
Mistroke
.26204 .69839 L
.27104 .68939 L
.27176 .68868 L
.28075 .67968 L
.28147 .67896 L
.29046 .66997 L
.29118 .66925 L
.30018 .66026 L
.30089 .65954 L
.30989 .65054 L
.31061 .64983 L
.3196 .64083 L
.32032 .64011 L
.32931 .63112 L
.33003 .6304 L
.33897 .62141 L
.33974 .62069 L
.34946 .61368 L
.35208 .61169 L
.35917 .60538 L
.36297 .60198 L
.36888 .596 L
.37262 .59227 L
.37859 .58571 L
.3815 .58256 L
.38831 .5746 L
.38982 .57284 L
.39774 .56313 L
.39802 .56276 L
.40542 .55342 L
.40773 .55025 L
.41272 .54371 L
.41744 .5371 L
.41972 .53399 L
.42655 .52428 L
.42716 .52335 L
.43327 .51457 L
.43687 .50905 L
.4397 .50486 L
.44601 .49514 L
.44658 .4942 L
.45227 .48543 L
.45629 .47885 L
.45827 .47572 L
.46427 .46601 L
.46601 .46301 L
.47012 .45629 L
.47572 .44668 L
.47577 .44658 L
.48154 .43687 L
Mistroke
.48543 .4299 L
.48703 .42716 L
.49259 .41744 L
.49514 .41269 L
.49795 .40773 L
.50331 .39802 L
.50486 .39503 L
.50858 .38831 L
.51375 .37859 L
.51457 .37696 L
.51893 .36888 L
.52395 .35917 L
.52428 .35848 L
.52905 .34946 L
.53393 .33974 L
.53399 .3396 L
.53895 .33003 L
.54371 .32033 L
.54371 .32032 L
.54865 .31061 L
.55333 .30089 L
.55342 .30069 L
.55816 .29118 L
.56278 .28147 L
.56313 .28067 L
.56751 .27176 L
.57208 .26204 L
.57284 .26029 L
.57669 .25233 L
.58123 .24262 L
.58256 .23956 L
.58571 .23291 L
.59023 .22319 L
.59227 .21847 L
.5946 .21348 L
.59908 .20377 L
.60198 .19703 L
.60335 .19406 L
.6078 .18434 L
.61169 .17525 L
.61198 .17463 L
.61638 .16492 L
.62059 .15521 L
.62141 .15315 L
.62483 .14549 L
.62908 .13578 L
.63112 .13072 L
.63317 .12607 L
.63742 .11636 L
.64083 .10796 L
Mistroke
.6414 .10664 L
.64562 .09693 L
.64966 .08722 L
.65054 .08489 L
.65371 .07751 L
.65781 .06779 L
.66026 .0615 L
.6617 .05808 L
.66581 .04837 L
.66966 .03866 L
.66997 .0378 L
.67368 .02894 L
.67765 .01923 L
Mfstroke
.4 g
.01923 .86263 m
.02743 .85451 L
.02894 .85292 L
.03707 .84479 L
.03866 .84321 L
.04678 .83508 L
.04837 .8335 L
.05649 .82537 L
.05808 .82378 L
.06621 .81566 L
.06779 .81407 L
.07592 .80594 L
.07751 .80436 L
.08563 .79623 L
.08722 .79465 L
.09534 .78652 L
.09693 .78493 L
.10506 .77681 L
.10664 .77522 L
.11477 .76709 L
.11636 .76551 L
.12448 .75738 L
.12607 .7558 L
.13419 .74767 L
.13578 .74608 L
.14391 .73796 L
.14549 .73637 L
.15362 .72824 L
.15521 .72666 L
.16333 .71853 L
.16492 .71695 L
.17304 .70882 L
.17463 .70723 L
.18276 .69911 L
.18434 .69752 L
.19247 .68939 L
.19406 .68781 L
.20218 .67968 L
.20377 .6781 L
.21189 .66997 L
.21348 .66838 L
.22161 .66026 L
.22319 .65867 L
.23132 .65054 L
.23291 .64896 L
.24103 .64083 L
.24262 .63925 L
.25074 .63112 L
.25233 .62953 L
.26046 .62141 L
.26204 .61982 L
.27017 .61169 L
.27176 .61011 L
.27988 .60198 L
.28147 .6004 L
.28959 .59227 L
.29118 .59068 L
.29931 .58256 L
.30089 .58097 L
.30902 .57284 L
.31061 .57126 L
.31873 .56313 L
.32032 .56155 L
.32844 .55342 L
.33003 .55183 L
.33832 .54371 L
.33974 .54212 L
.34585 .53399 L
.34946 .52897 L
.35292 .52428 L
.35917 .51578 L
.36005 .51457 L
.36708 .50486 L
.36888 .50235 L
.37399 .49514 L
.37859 .4886 L
.38079 .48543 L
.38749 .47572 L
.38831 .47453 L
.39404 .46601 L
.39802 .46005 L
.40049 .45629 L
.40685 .44658 L
.40773 .44522 L
.41306 .43687 L
.41744 .42997 L
.41919 .42716 L
.42524 .41744 L
.42716 .41434 L
.43115 .40773 L
.43687 .39831 L
.43704 .39802 L
.44278 .38831 L
.44658 .38188 L
.44847 .37859 L
.45409 .36888 L
.45629 .36507 L
.45961 .35917 L
.46512 .34946 L
.46601 .34788 L
.47048 .33974 L
.47572 .3303 L
.47586 .33003 L
.4811 .32032 L
.48543 .31234 L
.48633 .31061 L
.49148 .30089 L
.49514 .29402 L
.49659 .29118 L
.50165 .28147 L
.50486 .27533 L
.50664 .27176 L
.51161 .26204 L
.51457 .25628 L
.5165 .25233 L
.52139 .24262 L
.52428 .23688 L
.52619 .23291 L
.53099 .22319 L
.53399 .21713 L
.53571 .21348 L
.54042 .20377 L
.54371 .19703 L
.54508 .19406 L
.5497 .18434 L
.55342 .1766 L
.5543 .17463 L
.55883 .16492 L
.56313 .15583 L
.56341 .15521 L
.56783 .14549 L
.57236 .13578 L
.57284 .13473 L
.5767 .12607 L
.58116 .11636 L
.58256 .1133 L
.58545 .10664 L
.58984 .09693 L
.59227 .09155 L
.5941 .08722 L
.5984 .07751 L
.60198 .06948 L
.60268 .06779 L
.60686 .05808 L
.61114 .04837 L
.61169 .04711 L
.61522 .03866 L
.61944 .02894 L
.62141 .02444 L
.62351 .01923 L
.01923 .01923 L
F
0 g
.01923 .86263 m
.02743 .85451 L
.02894 .85292 L
.03707 .84479 L
.03866 .84321 L
.04678 .83508 L
.04837 .8335 L
.05649 .82537 L
.05808 .82378 L
.06621 .81566 L
.06779 .81407 L
.07592 .80594 L
.07751 .80436 L
.08563 .79623 L
.08722 .79465 L
.09534 .78652 L
.09693 .78493 L
.10506 .77681 L
.10664 .77522 L
.11477 .76709 L
.11636 .76551 L
.12448 .75738 L
.12607 .7558 L
.13419 .74767 L
.13578 .74608 L
.14391 .73796 L
.14549 .73637 L
.15362 .72824 L
.15521 .72666 L
.16333 .71853 L
.16492 .71695 L
.17304 .70882 L
.17463 .70723 L
.18276 .69911 L
.18434 .69752 L
.19247 .68939 L
.19406 .68781 L
.20218 .67968 L
.20377 .6781 L
.21189 .66997 L
.21348 .66838 L
.22161 .66026 L
.22319 .65867 L
.23132 .65054 L
.23291 .64896 L
.24103 .64083 L
.24262 .63925 L
.25074 .63112 L
.25233 .62953 L
.26046 .62141 L
Mistroke
.26204 .61982 L
.27017 .61169 L
.27176 .61011 L
.27988 .60198 L
.28147 .6004 L
.28959 .59227 L
.29118 .59068 L
.29931 .58256 L
.30089 .58097 L
.30902 .57284 L
.31061 .57126 L
.31873 .56313 L
.32032 .56155 L
.32844 .55342 L
.33003 .55183 L
.33832 .54371 L
.33974 .54212 L
.34585 .53399 L
.34946 .52897 L
.35292 .52428 L
.35917 .51578 L
.36005 .51457 L
.36708 .50486 L
.36888 .50235 L
.37399 .49514 L
.37859 .4886 L
.38079 .48543 L
.38749 .47572 L
.38831 .47453 L
.39404 .46601 L
.39802 .46005 L
.40049 .45629 L
.40685 .44658 L
.40773 .44522 L
.41306 .43687 L
.41744 .42997 L
.41919 .42716 L
.42524 .41744 L
.42716 .41434 L
.43115 .40773 L
.43687 .39831 L
.43704 .39802 L
.44278 .38831 L
.44658 .38188 L
.44847 .37859 L
.45409 .36888 L
.45629 .36507 L
.45961 .35917 L
.46512 .34946 L
.46601 .34788 L
Mistroke
.47048 .33974 L
.47572 .3303 L
.47586 .33003 L
.4811 .32032 L
.48543 .31234 L
.48633 .31061 L
.49148 .30089 L
.49514 .29402 L
.49659 .29118 L
.50165 .28147 L
.50486 .27533 L
.50664 .27176 L
.51161 .26204 L
.51457 .25628 L
.5165 .25233 L
.52139 .24262 L
.52428 .23688 L
.52619 .23291 L
.53099 .22319 L
.53399 .21713 L
.53571 .21348 L
.54042 .20377 L
.54371 .19703 L
.54508 .19406 L
.5497 .18434 L
.55342 .1766 L
.5543 .17463 L
.55883 .16492 L
.56313 .15583 L
.56341 .15521 L
.56783 .14549 L
.57236 .13578 L
.57284 .13473 L
.5767 .12607 L
.58116 .11636 L
.58256 .1133 L
.58545 .10664 L
.58984 .09693 L
.59227 .09155 L
.5941 .08722 L
.5984 .07751 L
.60198 .06948 L
.60268 .06779 L
.60686 .05808 L
.61114 .04837 L
.61169 .04711 L
.61522 .03866 L
.61944 .02894 L
.62141 .02444 L
.62351 .01923 L
Mistroke
Mfstroke
.5 g
.01923 .81893 m
.02251 .81566 L
.02894 .80922 L
.03222 .80594 L
.03866 .7995 L
.04193 .79623 L
.04837 .78979 L
.05164 .78652 L
.05808 .78008 L
.06135 .77681 L
.06779 .77037 L
.07107 .76709 L
.07751 .76065 L
.08078 .75738 L
.08722 .75094 L
.09049 .74767 L
.09693 .74123 L
.1002 .73796 L
.10664 .73152 L
.10992 .72824 L
.11636 .7218 L
.11963 .71853 L
.12607 .71209 L
.12934 .70882 L
.13578 .70238 L
.13905 .69911 L
.14549 .69267 L
.14877 .68939 L
.15521 .68295 L
.15848 .67968 L
.16492 .67324 L
.16819 .66997 L
.17463 .66353 L
.1779 .66026 L
.18434 .65382 L
.18762 .65054 L
.19406 .6441 L
.19733 .64083 L
.20377 .63439 L
.20704 .63112 L
.21348 .62468 L
.21675 .62141 L
.22319 .61497 L
.22647 .61169 L
.23291 .60525 L
.23618 .60198 L
.24262 .59554 L
.24589 .59227 L
.25233 .58583 L
.2556 .58256 L
.26204 .57612 L
.26532 .57284 L
.27176 .5664 L
.27503 .56313 L
.28147 .55669 L
.28474 .55342 L
.29118 .54698 L
.29445 .54371 L
.30089 .53727 L
.30417 .53399 L
.31061 .52755 L
.31388 .52428 L
.32032 .51784 L
.32359 .51457 L
.33003 .50813 L
.33338 .50486 L
.33974 .49842 L
.34277 .49514 L
.34946 .48772 L
.35147 .48543 L
.35917 .47643 L
.35976 .47572 L
.36773 .46601 L
.36888 .46457 L
.3754 .45629 L
.37859 .45215 L
.38282 .44658 L
.38831 .4392 L
.39001 .43687 L
.39701 .42716 L
.39802 .42573 L
.40382 .41744 L
.40773 .41176 L
.41047 .40773 L
.41697 .39802 L
.41744 .3973 L
.42333 .38831 L
.42716 .38237 L
.42956 .37859 L
.43568 .36888 L
.43687 .36698 L
.44169 .35917 L
.44658 .35114 L
.4476 .34946 L
.45341 .33974 L
.45629 .33486 L
.45912 .33003 L
.46477 .32032 L
.46601 .31816 L
.47032 .31061 L
.47572 .30104 L
.4758 .30089 L
.48121 .29118 L
.48543 .28352 L
.48655 .28147 L
.49183 .27176 L
.49514 .2656 L
.49704 .26204 L
.5022 .25233 L
.50486 .24729 L
.50729 .24262 L
.51234 .23291 L
.51457 .22859 L
.51733 .22319 L
.52228 .21348 L
.52428 .20952 L
.52717 .20377 L
.53203 .19406 L
.53399 .19009 L
.53682 .18434 L
.54159 .17463 L
.54371 .17029 L
.5463 .16492 L
.55099 .15521 L
.55342 .15014 L
.55563 .14549 L
.56024 .13578 L
.56313 .12964 L
.5648 .12607 L
.56934 .11636 L
.57284 .1088 L
.57383 .10664 L
.5783 .09693 L
.58256 .08762 L
.58274 .08722 L
.58713 .07751 L
.59151 .06779 L
.59227 .06611 L
.59584 .05808 L
.60017 .04837 L
.60198 .04427 L
.60444 .03866 L
.60871 .02894 L
.61169 .02211 L
.61293 .01923 L
.01923 .01923 L
F
0 g
.01923 .81893 m
.02251 .81566 L
.02894 .80922 L
.03222 .80594 L
.03866 .7995 L
.04193 .79623 L
.04837 .78979 L
.05164 .78652 L
.05808 .78008 L
.06135 .77681 L
.06779 .77037 L
.07107 .76709 L
.07751 .76065 L
.08078 .75738 L
.08722 .75094 L
.09049 .74767 L
.09693 .74123 L
.1002 .73796 L
.10664 .73152 L
.10992 .72824 L
.11636 .7218 L
.11963 .71853 L
.12607 .71209 L
.12934 .70882 L
.13578 .70238 L
.13905 .69911 L
.14549 .69267 L
.14877 .68939 L
.15521 .68295 L
.15848 .67968 L
.16492 .67324 L
.16819 .66997 L
.17463 .66353 L
.1779 .66026 L
.18434 .65382 L
.18762 .65054 L
.19406 .6441 L
.19733 .64083 L
.20377 .63439 L
.20704 .63112 L
.21348 .62468 L
.21675 .62141 L
.22319 .61497 L
.22647 .61169 L
.23291 .60525 L
.23618 .60198 L
.24262 .59554 L
.24589 .59227 L
.25233 .58583 L
.2556 .58256 L
Mistroke
.26204 .57612 L
.26532 .57284 L
.27176 .5664 L
.27503 .56313 L
.28147 .55669 L
.28474 .55342 L
.29118 .54698 L
.29445 .54371 L
.30089 .53727 L
.30417 .53399 L
.31061 .52755 L
.31388 .52428 L
.32032 .51784 L
.32359 .51457 L
.33003 .50813 L
.33338 .50486 L
.33974 .49842 L
.34277 .49514 L
.34946 .48772 L
.35147 .48543 L
.35917 .47643 L
.35976 .47572 L
.36773 .46601 L
.36888 .46457 L
.3754 .45629 L
.37859 .45215 L
.38282 .44658 L
.38831 .4392 L
.39001 .43687 L
.39701 .42716 L
.39802 .42573 L
.40382 .41744 L
.40773 .41176 L
.41047 .40773 L
.41697 .39802 L
.41744 .3973 L
.42333 .38831 L
.42716 .38237 L
.42956 .37859 L
.43568 .36888 L
.43687 .36698 L
.44169 .35917 L
.44658 .35114 L
.4476 .34946 L
.45341 .33974 L
.45629 .33486 L
.45912 .33003 L
.46477 .32032 L
.46601 .31816 L
.47032 .31061 L
Mistroke
.47572 .30104 L
.4758 .30089 L
.48121 .29118 L
.48543 .28352 L
.48655 .28147 L
.49183 .27176 L
.49514 .2656 L
.49704 .26204 L
.5022 .25233 L
.50486 .24729 L
.50729 .24262 L
.51234 .23291 L
.51457 .22859 L
.51733 .22319 L
.52228 .21348 L
.52428 .20952 L
.52717 .20377 L
.53203 .19406 L
.53399 .19009 L
.53682 .18434 L
.54159 .17463 L
.54371 .17029 L
.5463 .16492 L
.55099 .15521 L
.55342 .15014 L
.55563 .14549 L
.56024 .13578 L
.56313 .12964 L
.5648 .12607 L
.56934 .11636 L
.57284 .1088 L
.57383 .10664 L
.5783 .09693 L
.58256 .08762 L
.58274 .08722 L
.58713 .07751 L
.59151 .06779 L
.59227 .06611 L
.59584 .05808 L
.60017 .04837 L
.60198 .04427 L
.60444 .03866 L
.60871 .02894 L
.61169 .02211 L
.61293 .01923 L
Mfstroke
.6 g
.01923 .78352 m
.02594 .77681 L
.02894 .77381 L
.03566 .76709 L
.03866 .7641 L
.04537 .75738 L
.04837 .75438 L
.05508 .74767 L
.05808 .74467 L
.06479 .73796 L
.06779 .73496 L
.07451 .72824 L
.07751 .72525 L
.08422 .71853 L
.08722 .71553 L
.09393 .70882 L
.09693 .70582 L
.10365 .69911 L
.10664 .69611 L
.11336 .68939 L
.11636 .6864 L
.12307 .67968 L
.12607 .67668 L
.13278 .66997 L
.13578 .66697 L
.1425 .66026 L
.14549 .65726 L
.15221 .65054 L
.15521 .64755 L
.16192 .64083 L
.16492 .63783 L
.17163 .63112 L
.17463 .62812 L
.18135 .62141 L
.18434 .61841 L
.19106 .61169 L
.19406 .6087 L
.20077 .60198 L
.20377 .59898 L
.21048 .59227 L
.21348 .58927 L
.2202 .58256 L
.22319 .57956 L
.22991 .57284 L
.23291 .56985 L
.23962 .56313 L
.24262 .56013 L
.24933 .55342 L
.25233 .55042 L
.25905 .54371 L
.26204 .54071 L
.26876 .53399 L
.27176 .531 L
.27847 .52428 L
.28147 .52128 L
.28818 .51457 L
.29118 .51157 L
.2979 .50486 L
.30089 .50186 L
.30761 .49514 L
.31061 .49215 L
.31732 .48543 L
.32032 .48243 L
.32703 .47572 L
.33003 .47272 L
.33676 .46601 L
.33974 .46301 L
.34663 .45629 L
.34946 .45356 L
.35619 .44658 L
.35917 .44334 L
.36501 .43687 L
.36888 .43239 L
.37335 .42716 L
.37859 .42078 L
.3813 .41744 L
.38831 .40854 L
.38894 .40773 L
.39632 .39802 L
.39802 .39571 L
.40346 .38831 L
.40773 .38232 L
.41037 .37859 L
.41711 .36888 L
.41744 .36839 L
.4237 .35917 L
.42716 .35394 L
.43011 .34946 L
.43639 .33974 L
.43687 .33899 L
.44256 .33003 L
.44658 .32357 L
.4486 .32032 L
.45453 .31061 L
.45629 .30767 L
.46037 .30089 L
.46601 .29133 L
.46609 .29118 L
.47176 .28147 L
.47572 .27455 L
.47732 .27176 L
.48282 .26204 L
.48543 .25734 L
.48823 .25233 L
.49357 .24262 L
.49514 .23972 L
.49885 .23291 L
.50406 .22319 L
.50486 .22169 L
.50923 .21348 L
.51431 .20377 L
.51457 .20327 L
.51937 .19406 L
.52428 .18445 L
.52434 .18434 L
.52929 .17463 L
.53399 .16526 L
.53416 .16492 L
.53903 .15521 L
.54371 .14569 L
.54381 .14549 L
.54858 .13578 L
.55327 .12607 L
.55342 .12576 L
.55796 .11636 L
.56258 .10664 L
.56313 .10548 L
.56719 .09693 L
.57174 .08722 L
.57284 .08484 L
.57627 .07751 L
.58076 .06779 L
.58256 .06385 L
.58521 .05808 L
.58965 .04837 L
.59227 .04252 L
.59402 .03866 L
.5984 .02894 L
.60198 .02086 L
.60271 .01923 L
.01923 .01923 L
F
0 g
.01923 .78352 m
.02594 .77681 L
.02894 .77381 L
.03566 .76709 L
.03866 .7641 L
.04537 .75738 L
.04837 .75438 L
.05508 .74767 L
.05808 .74467 L
.06479 .73796 L
.06779 .73496 L
.07451 .72824 L
.07751 .72525 L
.08422 .71853 L
.08722 .71553 L
.09393 .70882 L
.09693 .70582 L
.10365 .69911 L
.10664 .69611 L
.11336 .68939 L
.11636 .6864 L
.12307 .67968 L
.12607 .67668 L
.13278 .66997 L
.13578 .66697 L
.1425 .66026 L
.14549 .65726 L
.15221 .65054 L
.15521 .64755 L
.16192 .64083 L
.16492 .63783 L
.17163 .63112 L
.17463 .62812 L
.18135 .62141 L
.18434 .61841 L
.19106 .61169 L
.19406 .6087 L
.20077 .60198 L
.20377 .59898 L
.21048 .59227 L
.21348 .58927 L
.2202 .58256 L
.22319 .57956 L
.22991 .57284 L
.23291 .56985 L
.23962 .56313 L
.24262 .56013 L
.24933 .55342 L
.25233 .55042 L
.25905 .54371 L
Mistroke
.26204 .54071 L
.26876 .53399 L
.27176 .531 L
.27847 .52428 L
.28147 .52128 L
.28818 .51457 L
.29118 .51157 L
.2979 .50486 L
.30089 .50186 L
.30761 .49514 L
.31061 .49215 L
.31732 .48543 L
.32032 .48243 L
.32703 .47572 L
.33003 .47272 L
.33676 .46601 L
.33974 .46301 L
.34663 .45629 L
.34946 .45356 L
.35619 .44658 L
.35917 .44334 L
.36501 .43687 L
.36888 .43239 L
.37335 .42716 L
.37859 .42078 L
.3813 .41744 L
.38831 .40854 L
.38894 .40773 L
.39632 .39802 L
.39802 .39571 L
.40346 .38831 L
.40773 .38232 L
.41037 .37859 L
.41711 .36888 L
.41744 .36839 L
.4237 .35917 L
.42716 .35394 L
.43011 .34946 L
.43639 .33974 L
.43687 .33899 L
.44256 .33003 L
.44658 .32357 L
.4486 .32032 L
.45453 .31061 L
.45629 .30767 L
.46037 .30089 L
.46601 .29133 L
.46609 .29118 L
.47176 .28147 L
.47572 .27455 L
Mistroke
.47732 .27176 L
.48282 .26204 L
.48543 .25734 L
.48823 .25233 L
.49357 .24262 L
.49514 .23972 L
.49885 .23291 L
.50406 .22319 L
.50486 .22169 L
.50923 .21348 L
.51431 .20377 L
.51457 .20327 L
.51937 .19406 L
.52428 .18445 L
.52434 .18434 L
.52929 .17463 L
.53399 .16526 L
.53416 .16492 L
.53903 .15521 L
.54371 .14569 L
.54381 .14549 L
.54858 .13578 L
.55327 .12607 L
.55342 .12576 L
.55796 .11636 L
.56258 .10664 L
.56313 .10548 L
.56719 .09693 L
.57174 .08722 L
.57284 .08484 L
.57627 .07751 L
.58076 .06779 L
.58256 .06385 L
.58521 .05808 L
.58965 .04837 L
.59227 .04252 L
.59402 .03866 L
.5984 .02894 L
.60198 .02086 L
.60271 .01923 L
Mfstroke
.7 g
.01923 .73982 m
.02105 .73796 L
.02894 .73011 L
.03081 .72824 L
.03866 .7204 L
.04052 .71853 L
.04837 .71068 L
.05023 .70882 L
.05808 .70097 L
.05995 .69911 L
.06779 .69126 L
.06966 .68939 L
.07751 .68155 L
.07937 .67968 L
.08722 .67183 L
.08908 .66997 L
.09693 .66212 L
.0988 .66026 L
.10664 .65241 L
.10851 .65054 L
.11636 .6427 L
.11822 .64083 L
.12607 .63298 L
.12793 .63112 L
.13578 .62327 L
.13765 .62141 L
.14549 .61356 L
.14736 .61169 L
.15521 .60385 L
.15707 .60198 L
.16492 .59413 L
.16678 .59227 L
.17463 .58442 L
.1765 .58256 L
.18434 .57471 L
.18621 .57284 L
.19406 .565 L
.19592 .56313 L
.20377 .55528 L
.20563 .55342 L
.21348 .54557 L
.21535 .54371 L
.22319 .53586 L
.22506 .53399 L
.23291 .52615 L
.23477 .52428 L
.24262 .51643 L
.24448 .51457 L
.25233 .50672 L
.2542 .50486 L
.26204 .49701 L
.26391 .49514 L
.27176 .4873 L
.27362 .48543 L
.28147 .47758 L
.28333 .47572 L
.29118 .46787 L
.29305 .46601 L
.30089 .45816 L
.30276 .45629 L
.31061 .44845 L
.31247 .44658 L
.32032 .43873 L
.32218 .43687 L
.33003 .42902 L
.33186 .42716 L
.33974 .41931 L
.34205 .41744 L
.34946 .41231 L
.35531 .40773 L
.35917 .404 L
.3657 .39802 L
.36888 .39462 L
.37511 .38831 L
.37859 .38433 L
.38383 .37859 L
.38831 .37323 L
.39203 .36888 L
.39802 .36138 L
.39981 .35917 L
.40731 .34946 L
.40773 .34886 L
.41462 .33974 L
.41744 .33572 L
.4216 .33003 L
.42716 .32196 L
.42832 .32032 L
.43499 .31061 L
.43687 .30767 L
.44143 .30089 L
.44658 .29282 L
.44765 .29118 L
.45389 .28147 L
.45629 .27747 L
.4599 .27176 L
.46576 .26204 L
.46601 .26161 L
.47167 .25233 L
.47572 .2453 L
.47732 .24262 L
.48302 .23291 L
.48543 .22852 L
.48853 .22319 L
.49399 .21348 L
.49514 .2113 L
.4994 .20377 L
.50465 .19406 L
.50486 .19364 L
.50999 .18434 L
.51457 .17557 L
.51508 .17463 L
.52031 .16492 L
.52428 .15709 L
.52528 .15521 L
.53039 .14549 L
.53399 .13822 L
.53526 .13578 L
.54026 .12607 L
.54371 .11895 L
.54503 .11636 L
.54994 .10664 L
.55342 .09931 L
.55461 .09693 L
.55943 .08722 L
.56313 .07929 L
.56401 .07751 L
.56876 .06779 L
.57284 .05891 L
.57324 .05808 L
.57792 .04837 L
.58235 .03866 L
.58256 .03817 L
.58693 .02894 L
.59136 .01923 L
.01923 .01923 L
F
0 g
.01923 .73982 m
.02105 .73796 L
.02894 .73011 L
.03081 .72824 L
.03866 .7204 L
.04052 .71853 L
.04837 .71068 L
.05023 .70882 L
.05808 .70097 L
.05995 .69911 L
.06779 .69126 L
.06966 .68939 L
.07751 .68155 L
.07937 .67968 L
.08722 .67183 L
.08908 .66997 L
.09693 .66212 L
.0988 .66026 L
.10664 .65241 L
.10851 .65054 L
.11636 .6427 L
.11822 .64083 L
.12607 .63298 L
.12793 .63112 L
.13578 .62327 L
.13765 .62141 L
.14549 .61356 L
.14736 .61169 L
.15521 .60385 L
.15707 .60198 L
.16492 .59413 L
.16678 .59227 L
.17463 .58442 L
.1765 .58256 L
.18434 .57471 L
.18621 .57284 L
.19406 .565 L
.19592 .56313 L
.20377 .55528 L
.20563 .55342 L
.21348 .54557 L
.21535 .54371 L
.22319 .53586 L
.22506 .53399 L
.23291 .52615 L
.23477 .52428 L
.24262 .51643 L
.24448 .51457 L
.25233 .50672 L
.2542 .50486 L
Mistroke
.26204 .49701 L
.26391 .49514 L
.27176 .4873 L
.27362 .48543 L
.28147 .47758 L
.28333 .47572 L
.29118 .46787 L
.29305 .46601 L
.30089 .45816 L
.30276 .45629 L
.31061 .44845 L
.31247 .44658 L
.32032 .43873 L
.32218 .43687 L
.33003 .42902 L
.33186 .42716 L
.33974 .41931 L
.34205 .41744 L
.34946 .41231 L
.35531 .40773 L
.35917 .404 L
.3657 .39802 L
.36888 .39462 L
.37511 .38831 L
.37859 .38433 L
.38383 .37859 L
.38831 .37323 L
.39203 .36888 L
.39802 .36138 L
.39981 .35917 L
.40731 .34946 L
.40773 .34886 L
.41462 .33974 L
.41744 .33572 L
.4216 .33003 L
.42716 .32196 L
.42832 .32032 L
.43499 .31061 L
.43687 .30767 L
.44143 .30089 L
.44658 .29282 L
.44765 .29118 L
.45389 .28147 L
.45629 .27747 L
.4599 .27176 L
.46576 .26204 L
.46601 .26161 L
.47167 .25233 L
.47572 .2453 L
.47732 .24262 L
Mistroke
.48302 .23291 L
.48543 .22852 L
.48853 .22319 L
.49399 .21348 L
.49514 .2113 L
.4994 .20377 L
.50465 .19406 L
.50486 .19364 L
.50999 .18434 L
.51457 .17557 L
.51508 .17463 L
.52031 .16492 L
.52428 .15709 L
.52528 .15521 L
.53039 .14549 L
.53399 .13822 L
.53526 .13578 L
.54026 .12607 L
.54371 .11895 L
.54503 .11636 L
.54994 .10664 L
.55342 .09931 L
.55461 .09693 L
.55943 .08722 L
.56313 .07929 L
.56401 .07751 L
.56876 .06779 L
.57284 .05891 L
.57324 .05808 L
.57792 .04837 L
.58235 .03866 L
.58256 .03817 L
.58693 .02894 L
.59136 .01923 L
Mfstroke
.6 g
.01923 .66124 m
.02048 .66026 L
.02894 .65153 L
.02993 .65054 L
.03866 .64182 L
.03964 .64083 L
.04837 .6321 L
.04935 .63112 L
.05808 .62239 L
.05907 .62141 L
.06779 .61268 L
.06878 .61169 L
.07751 .60297 L
.07849 .60198 L
.08722 .59325 L
.0882 .59227 L
.09693 .58354 L
.09792 .58256 L
.10664 .57383 L
.10763 .57284 L
.11636 .56412 L
.11734 .56313 L
.12607 .5544 L
.12705 .55342 L
.13578 .54469 L
.13677 .54371 L
.14549 .53498 L
.14648 .53399 L
.15521 .52527 L
.15619 .52428 L
.16492 .51555 L
.1659 .51457 L
.17463 .50584 L
.17562 .50486 L
.18434 .49613 L
.18533 .49514 L
.19406 .48642 L
.19504 .48543 L
.20377 .4767 L
.20475 .47572 L
.21348 .46699 L
.21447 .46601 L
.22319 .45728 L
.22418 .45629 L
.23291 .44757 L
.23389 .44658 L
.24262 .43785 L
.2436 .43687 L
.25233 .42814 L
.25332 .42716 L
.26204 .41843 L
.26303 .41744 L
.27176 .40872 L
.27274 .40773 L
.28147 .399 L
.28245 .39802 L
.29118 .38929 L
.29217 .38831 L
.30089 .37958 L
.30188 .37859 L
.31061 .36987 L
.31159 .36888 L
.32032 .36015 L
.3213 .35917 L
.33003 .35044 L
.33113 .34946 L
.33974 .34073 L
.34054 .33974 L
.34772 .33003 L
.34946 .3276 L
.35482 .32032 L
.35917 .31438 L
.36192 .31061 L
.36888 .30098 L
.36894 .30089 L
.37582 .29118 L
.37859 .28722 L
.38257 .28147 L
.38831 .27314 L
.38924 .27176 L
.39577 .26204 L
.39802 .25867 L
.40218 .25233 L
.40773 .24383 L
.40851 .24262 L
.4147 .23291 L
.41744 .22859 L
.42079 .22319 L
.42684 .21348 L
.42716 .21296 L
.43272 .20377 L
.43687 .19692 L
.43855 .19406 L
.44431 .18434 L
.44658 .1805 L
.44995 .17463 L
.45559 .16492 L
.45629 .16369 L
.46107 .15521 L
.46601 .14649 L
.46655 .14549 L
.47191 .13578 L
.47572 .12891 L
.47723 .12607 L
.4825 .11636 L
.48543 .11095 L
.48768 .10664 L
.49286 .09693 L
.49514 .09263 L
.49792 .08722 L
.503 .07751 L
.50486 .07394 L
.50795 .06779 L
.51294 .05808 L
.51457 .0549 L
.51779 .04837 L
.52269 .03866 L
.52428 .0355 L
.52745 .02894 L
.53227 .01923 L
.01923 .01923 L
F
0 g
.01923 .66124 m
.02048 .66026 L
.02894 .65153 L
.02993 .65054 L
.03866 .64182 L
.03964 .64083 L
.04837 .6321 L
.04935 .63112 L
.05808 .62239 L
.05907 .62141 L
.06779 .61268 L
.06878 .61169 L
.07751 .60297 L
.07849 .60198 L
.08722 .59325 L
.0882 .59227 L
.09693 .58354 L
.09792 .58256 L
.10664 .57383 L
.10763 .57284 L
.11636 .56412 L
.11734 .56313 L
.12607 .5544 L
.12705 .55342 L
.13578 .54469 L
.13677 .54371 L
.14549 .53498 L
.14648 .53399 L
.15521 .52527 L
.15619 .52428 L
.16492 .51555 L
.1659 .51457 L
.17463 .50584 L
.17562 .50486 L
.18434 .49613 L
.18533 .49514 L
.19406 .48642 L
.19504 .48543 L
.20377 .4767 L
.20475 .47572 L
.21348 .46699 L
.21447 .46601 L
.22319 .45728 L
.22418 .45629 L
.23291 .44757 L
.23389 .44658 L
.24262 .43785 L
.2436 .43687 L
.25233 .42814 L
.25332 .42716 L
Mistroke
.26204 .41843 L
.26303 .41744 L
.27176 .40872 L
.27274 .40773 L
.28147 .399 L
.28245 .39802 L
.29118 .38929 L
.29217 .38831 L
.30089 .37958 L
.30188 .37859 L
.31061 .36987 L
.31159 .36888 L
.32032 .36015 L
.3213 .35917 L
.33003 .35044 L
.33113 .34946 L
.33974 .34073 L
.34054 .33974 L
.34772 .33003 L
.34946 .3276 L
.35482 .32032 L
.35917 .31438 L
.36192 .31061 L
.36888 .30098 L
.36894 .30089 L
.37582 .29118 L
.37859 .28722 L
.38257 .28147 L
.38831 .27314 L
.38924 .27176 L
.39577 .26204 L
.39802 .25867 L
.40218 .25233 L
.40773 .24383 L
.40851 .24262 L
.4147 .23291 L
.41744 .22859 L
.42079 .22319 L
.42684 .21348 L
.42716 .21296 L
.43272 .20377 L
.43687 .19692 L
.43855 .19406 L
.44431 .18434 L
.44658 .1805 L
.44995 .17463 L
.45559 .16492 L
.45629 .16369 L
.46107 .15521 L
.46601 .14649 L
Mistroke
.46655 .14549 L
.47191 .13578 L
.47572 .12891 L
.47723 .12607 L
.4825 .11636 L
.48543 .11095 L
.48768 .10664 L
.49286 .09693 L
.49514 .09263 L
.49792 .08722 L
.503 .07751 L
.50486 .07394 L
.50795 .06779 L
.51294 .05808 L
.51457 .0549 L
.51779 .04837 L
.52269 .03866 L
.52428 .0355 L
.52745 .02894 L
.53227 .01923 L
Mfstroke
.5 g
.01923 .61755 m
.02509 .61169 L
.02894 .60783 L
.0348 .60198 L
.03866 .59812 L
.04451 .59227 L
.04837 .58841 L
.05422 .58256 L
.05808 .5787 L
.06393 .57284 L
.06779 .56898 L
.07365 .56313 L
.07751 .55927 L
.08336 .55342 L
.08722 .54956 L
.09307 .54371 L
.09693 .53985 L
.10278 .53399 L
.10664 .53013 L
.1125 .52428 L
.11636 .52042 L
.12221 .51457 L
.12607 .51071 L
.13192 .50486 L
.13578 .501 L
.14163 .49514 L
.14549 .49128 L
.15135 .48543 L
.15521 .48157 L
.16106 .47572 L
.16492 .47186 L
.17077 .46601 L
.17463 .46215 L
.18048 .45629 L
.18434 .45243 L
.1902 .44658 L
.19406 .44272 L
.19991 .43687 L
.20377 .43301 L
.20962 .42716 L
.21348 .4233 L
.21933 .41744 L
.22319 .41358 L
.22905 .40773 L
.23291 .40387 L
.23876 .39802 L
.24262 .39416 L
.24847 .38831 L
.25233 .38445 L
.25818 .37859 L
.26204 .37473 L
.2679 .36888 L
.27176 .36502 L
.27761 .35917 L
.28147 .35531 L
.28732 .34946 L
.29118 .3456 L
.29703 .33974 L
.30089 .33588 L
.30675 .33003 L
.31061 .32617 L
.31646 .32032 L
.32032 .31646 L
.32617 .31061 L
.33003 .30675 L
.33597 .30089 L
.33974 .29703 L
.34511 .29118 L
.34946 .28633 L
.35371 .28147 L
.35917 .27504 L
.36191 .27176 L
.36888 .26318 L
.36979 .26204 L
.3774 .25233 L
.37859 .25077 L
.38475 .24262 L
.38831 .23781 L
.39189 .23291 L
.39802 .22435 L
.39883 .22319 L
.4056 .21348 L
.40773 .21037 L
.41221 .20377 L
.41744 .19592 L
.41867 .19406 L
.425 .18434 L
.42716 .18098 L
.4312 .17463 L
.43687 .16559 L
.43729 .16492 L
.44327 .15521 L
.44658 .14975 L
.44915 .14549 L
.45494 .13578 L
.45629 .13348 L
.46063 .12607 L
.46601 .11678 L
.46625 .11636 L
.47178 .10664 L
.47572 .09966 L
.47724 .09693 L
.48264 .08722 L
.48543 .08213 L
.48795 .07751 L
.49322 .06779 L
.49514 .06421 L
.49841 .05808 L
.50356 .04837 L
.50486 .0459 L
.50864 .03866 L
.51368 .02894 L
.51457 .02721 L
.51865 .01923 L
.01923 .01923 L
F
0 g
.01923 .61755 m
.02509 .61169 L
.02894 .60783 L
.0348 .60198 L
.03866 .59812 L
.04451 .59227 L
.04837 .58841 L
.05422 .58256 L
.05808 .5787 L
.06393 .57284 L
.06779 .56898 L
.07365 .56313 L
.07751 .55927 L
.08336 .55342 L
.08722 .54956 L
.09307 .54371 L
.09693 .53985 L
.10278 .53399 L
.10664 .53013 L
.1125 .52428 L
.11636 .52042 L
.12221 .51457 L
.12607 .51071 L
.13192 .50486 L
.13578 .501 L
.14163 .49514 L
.14549 .49128 L
.15135 .48543 L
.15521 .48157 L
.16106 .47572 L
.16492 .47186 L
.17077 .46601 L
.17463 .46215 L
.18048 .45629 L
.18434 .45243 L
.1902 .44658 L
.19406 .44272 L
.19991 .43687 L
.20377 .43301 L
.20962 .42716 L
.21348 .4233 L
.21933 .41744 L
.22319 .41358 L
.22905 .40773 L
.23291 .40387 L
.23876 .39802 L
.24262 .39416 L
.24847 .38831 L
.25233 .38445 L
.25818 .37859 L
Mistroke
.26204 .37473 L
.2679 .36888 L
.27176 .36502 L
.27761 .35917 L
.28147 .35531 L
.28732 .34946 L
.29118 .3456 L
.29703 .33974 L
.30089 .33588 L
.30675 .33003 L
.31061 .32617 L
.31646 .32032 L
.32032 .31646 L
.32617 .31061 L
.33003 .30675 L
.33597 .30089 L
.33974 .29703 L
.34511 .29118 L
.34946 .28633 L
.35371 .28147 L
.35917 .27504 L
.36191 .27176 L
.36888 .26318 L
.36979 .26204 L
.3774 .25233 L
.37859 .25077 L
.38475 .24262 L
.38831 .23781 L
.39189 .23291 L
.39802 .22435 L
.39883 .22319 L
.4056 .21348 L
.40773 .21037 L
.41221 .20377 L
.41744 .19592 L
.41867 .19406 L
.425 .18434 L
.42716 .18098 L
.4312 .17463 L
.43687 .16559 L
.43729 .16492 L
.44327 .15521 L
.44658 .14975 L
.44915 .14549 L
.45494 .13578 L
.45629 .13348 L
.46063 .12607 L
.46601 .11678 L
.46625 .11636 L
.47178 .10664 L
Mistroke
.47572 .09966 L
.47724 .09693 L
.48264 .08722 L
.48543 .08213 L
.48795 .07751 L
.49322 .06779 L
.49514 .06421 L
.49841 .05808 L
.50356 .04837 L
.50486 .0459 L
.50864 .03866 L
.51368 .02894 L
.51457 .02721 L
.51865 .01923 L
Mfstroke
.4 g
.01923 .58213 m
.02852 .57284 L
.02894 .57242 L
.03823 .56313 L
.03866 .56271 L
.04795 .55342 L
.04837 .553 L
.05766 .54371 L
.05808 .54328 L
.06737 .53399 L
.06779 .53357 L
.07708 .52428 L
.07751 .52386 L
.0868 .51457 L
.08722 .51415 L
.09651 .50486 L
.09693 .50443 L
.10622 .49514 L
.10664 .49472 L
.11593 .48543 L
.11636 .48501 L
.12565 .47572 L
.12607 .4753 L
.13536 .46601 L
.13578 .46558 L
.14507 .45629 L
.14549 .45587 L
.15478 .44658 L
.15521 .44616 L
.1645 .43687 L
.16492 .43645 L
.17421 .42716 L
.17463 .42673 L
.18392 .41744 L
.18434 .41702 L
.19363 .40773 L
.19406 .40731 L
.20335 .39802 L
.20377 .3976 L
.21306 .38831 L
.21348 .38788 L
.22277 .37859 L
.22319 .37817 L
.23248 .36888 L
.23291 .36846 L
.2422 .35917 L
.24262 .35875 L
.25191 .34946 L
.25233 .34903 L
.26162 .33974 L
.26204 .33932 L
.27133 .33003 L
.27176 .32961 L
.28105 .32032 L
.28147 .3199 L
.29076 .31061 L
.29118 .31018 L
.30047 .30089 L
.30089 .30047 L
.31018 .29118 L
.31061 .29076 L
.3199 .28147 L
.32032 .28105 L
.32961 .27176 L
.33003 .27133 L
.33932 .26204 L
.33974 .26162 L
.3493 .25233 L
.34946 .25218 L
.35856 .24262 L
.35917 .24195 L
.36725 .23291 L
.36888 .23101 L
.3755 .22319 L
.37859 .2194 L
.38337 .21348 L
.38831 .20716 L
.39093 .20377 L
.39802 .19433 L
.39822 .19406 L
.40531 .18434 L
.40773 .18094 L
.41219 .17463 L
.41744 .167 L
.41887 .16492 L
.42541 .15521 L
.42716 .15255 L
.4318 .14549 L
.43687 .13761 L
.43804 .13578 L
.44418 .12607 L
.44658 .12218 L
.45019 .11636 L
.45608 .10664 L
.45629 .10629 L
.4619 .09693 L
.46601 .08995 L
.46761 .08722 L
.47325 .07751 L
.47572 .07317 L
.47879 .06779 L
.48426 .05808 L
.48543 .05596 L
.48966 .04837 L
.49497 .03866 L
.49514 .03834 L
.50025 .02894 L
.50486 .02031 L
.50543 .01923 L
.01923 .01923 L
F
0 g
.01923 .58213 m
.02852 .57284 L
.02894 .57242 L
.03823 .56313 L
.03866 .56271 L
.04795 .55342 L
.04837 .553 L
.05766 .54371 L
.05808 .54328 L
.06737 .53399 L
.06779 .53357 L
.07708 .52428 L
.07751 .52386 L
.0868 .51457 L
.08722 .51415 L
.09651 .50486 L
.09693 .50443 L
.10622 .49514 L
.10664 .49472 L
.11593 .48543 L
.11636 .48501 L
.12565 .47572 L
.12607 .4753 L
.13536 .46601 L
.13578 .46558 L
.14507 .45629 L
.14549 .45587 L
.15478 .44658 L
.15521 .44616 L
.1645 .43687 L
.16492 .43645 L
.17421 .42716 L
.17463 .42673 L
.18392 .41744 L
.18434 .41702 L
.19363 .40773 L
.19406 .40731 L
.20335 .39802 L
.20377 .3976 L
.21306 .38831 L
.21348 .38788 L
.22277 .37859 L
.22319 .37817 L
.23248 .36888 L
.23291 .36846 L
.2422 .35917 L
.24262 .35875 L
.25191 .34946 L
.25233 .34903 L
.26162 .33974 L
Mistroke
.26204 .33932 L
.27133 .33003 L
.27176 .32961 L
.28105 .32032 L
.28147 .3199 L
.29076 .31061 L
.29118 .31018 L
.30047 .30089 L
.30089 .30047 L
.31018 .29118 L
.31061 .29076 L
.3199 .28147 L
.32032 .28105 L
.32961 .27176 L
.33003 .27133 L
.33932 .26204 L
.33974 .26162 L
.3493 .25233 L
.34946 .25218 L
.35856 .24262 L
.35917 .24195 L
.36725 .23291 L
.36888 .23101 L
.3755 .22319 L
.37859 .2194 L
.38337 .21348 L
.38831 .20716 L
.39093 .20377 L
.39802 .19433 L
.39822 .19406 L
.40531 .18434 L
.40773 .18094 L
.41219 .17463 L
.41744 .167 L
.41887 .16492 L
.42541 .15521 L
.42716 .15255 L
.4318 .14549 L
.43687 .13761 L
.43804 .13578 L
.44418 .12607 L
.44658 .12218 L
.45019 .11636 L
.45608 .10664 L
.45629 .10629 L
.4619 .09693 L
.46601 .08995 L
.46761 .08722 L
.47325 .07751 L
.47572 .07317 L
Mistroke
.47879 .06779 L
.48426 .05808 L
.48543 .05596 L
.48966 .04837 L
.49497 .03866 L
.49514 .03834 L
.50025 .02894 L
.50486 .02031 L
.50543 .01923 L
Mfstroke
.3 g
.01923 .53846 m
.02362 .53399 L
.02894 .52875 L
.03341 .52428 L
.03866 .51904 L
.04312 .51457 L
.04837 .50932 L
.05284 .50486 L
.05808 .49961 L
.06255 .49514 L
.06779 .4899 L
.07226 .48543 L
.07751 .48019 L
.08197 .47572 L
.08722 .47047 L
.09169 .46601 L
.09693 .46076 L
.1014 .45629 L
.10664 .45105 L
.11111 .44658 L
.11636 .44134 L
.12082 .43687 L
.12607 .43162 L
.13054 .42716 L
.13578 .42191 L
.14025 .41744 L
.14549 .4122 L
.14996 .40773 L
.15521 .40249 L
.15967 .39802 L
.16492 .39277 L
.16939 .38831 L
.17463 .38306 L
.1791 .37859 L
.18434 .37335 L
.18881 .36888 L
.19406 .36364 L
.19852 .35917 L
.20377 .35392 L
.20824 .34946 L
.21348 .34421 L
.21795 .33974 L
.22319 .3345 L
.22766 .33003 L
.23291 .32479 L
.23737 .32032 L
.24262 .31507 L
.24709 .31061 L
.25233 .30536 L
.2568 .30089 L
.26204 .29565 L
.26651 .29118 L
.27176 .28594 L
.27622 .28147 L
.28147 .27622 L
.28594 .27176 L
.29118 .26651 L
.29565 .26204 L
.30089 .2568 L
.30536 .25233 L
.31061 .24709 L
.31507 .24262 L
.32032 .23737 L
.32479 .23291 L
.33003 .22766 L
.3344 .22319 L
.33974 .21795 L
.34557 .21348 L
.34946 .21092 L
.35811 .20377 L
.35917 .2026 L
.36816 .19406 L
.36888 .19322 L
.37742 .18434 L
.37859 .18294 L
.38605 .17463 L
.38831 .17184 L
.39418 .16492 L
.39802 .16 L
.40189 .15521 L
.40773 .14748 L
.40926 .14549 L
.41645 .13578 L
.41744 .13433 L
.42344 .12607 L
.42716 .12059 L
.43013 .11636 L
.43664 .10664 L
.43687 .10627 L
.44313 .09693 L
.44658 .09144 L
.44934 .08722 L
.45545 .07751 L
.45629 .07608 L
.46151 .06779 L
.46601 .06023 L
.46733 .05808 L
.47319 .04837 L
.47572 .04392 L
.47886 .03866 L
.48445 .02894 L
.48543 .02712 L
.49001 .01923 L
.01923 .01923 L
F
0 g
.01923 .53846 m
.02362 .53399 L
.02894 .52875 L
.03341 .52428 L
.03866 .51904 L
.04312 .51457 L
.04837 .50932 L
.05284 .50486 L
.05808 .49961 L
.06255 .49514 L
.06779 .4899 L
.07226 .48543 L
.07751 .48019 L
.08197 .47572 L
.08722 .47047 L
.09169 .46601 L
.09693 .46076 L
.1014 .45629 L
.10664 .45105 L
.11111 .44658 L
.11636 .44134 L
.12082 .43687 L
.12607 .43162 L
.13054 .42716 L
.13578 .42191 L
.14025 .41744 L
.14549 .4122 L
.14996 .40773 L
.15521 .40249 L
.15967 .39802 L
.16492 .39277 L
.16939 .38831 L
.17463 .38306 L
.1791 .37859 L
.18434 .37335 L
.18881 .36888 L
.19406 .36364 L
.19852 .35917 L
.20377 .35392 L
.20824 .34946 L
.21348 .34421 L
.21795 .33974 L
.22319 .3345 L
.22766 .33003 L
.23291 .32479 L
.23737 .32032 L
.24262 .31507 L
.24709 .31061 L
.25233 .30536 L
.2568 .30089 L
Mistroke
.26204 .29565 L
.26651 .29118 L
.27176 .28594 L
.27622 .28147 L
.28147 .27622 L
.28594 .27176 L
.29118 .26651 L
.29565 .26204 L
.30089 .2568 L
.30536 .25233 L
.31061 .24709 L
.31507 .24262 L
.32032 .23737 L
.32479 .23291 L
.33003 .22766 L
.3344 .22319 L
.33974 .21795 L
.34557 .21348 L
.34946 .21092 L
.35811 .20377 L
.35917 .2026 L
.36816 .19406 L
.36888 .19322 L
.37742 .18434 L
.37859 .18294 L
.38605 .17463 L
.38831 .17184 L
.39418 .16492 L
.39802 .16 L
.40189 .15521 L
.40773 .14748 L
.40926 .14549 L
.41645 .13578 L
.41744 .13433 L
.42344 .12607 L
.42716 .12059 L
.43013 .11636 L
.43664 .10664 L
.43687 .10627 L
.44313 .09693 L
.44658 .09144 L
.44934 .08722 L
.45545 .07751 L
.45629 .07608 L
.46151 .06779 L
.46601 .06023 L
.46733 .05808 L
.47319 .04837 L
.47572 .04392 L
.47886 .03866 L
Mistroke
.48445 .02894 L
.48543 .02712 L
.49001 .01923 L
Mfstroke
.4 g
.01923 .45983 m
.02313 .45629 L
.02894 .45012 L
.03248 .44658 L
.03866 .44041 L
.04219 .43687 L
.04837 .4307 L
.05191 .42716 L
.05808 .42098 L
.06162 .41744 L
.06779 .41127 L
.07133 .40773 L
.07751 .40156 L
.08104 .39802 L
.08722 .39184 L
.09076 .38831 L
.09693 .38213 L
.10047 .37859 L
.10664 .37242 L
.11018 .36888 L
.11636 .36271 L
.11989 .35917 L
.12607 .35299 L
.12961 .34946 L
.13578 .34328 L
.13932 .33974 L
.14549 .33357 L
.14903 .33003 L
.15521 .32386 L
.15874 .32032 L
.16492 .31414 L
.16846 .31061 L
.17463 .30443 L
.17817 .30089 L
.18434 .29472 L
.18788 .29118 L
.19406 .28501 L
.19759 .28147 L
.20377 .27529 L
.20731 .27176 L
.21348 .26558 L
.21702 .26204 L
.22319 .25587 L
.22673 .25233 L
.23291 .24616 L
.23644 .24262 L
.24262 .23644 L
.24616 .23291 L
.25233 .22673 L
.25587 .22319 L
.26204 .21702 L
.26558 .21348 L
.27176 .20731 L
.27529 .20377 L
.28147 .19759 L
.28501 .19406 L
.29118 .18788 L
.29472 .18434 L
.30089 .17817 L
.30443 .17463 L
.31061 .16846 L
.31414 .16492 L
.32032 .15874 L
.32386 .15521 L
.33003 .14903 L
.33386 .14549 L
.33974 .13932 L
.34251 .13578 L
.34946 .12624 L
.34958 .12607 L
.35672 .11636 L
.35917 .11301 L
.36379 .10664 L
.36888 .09957 L
.37076 .09693 L
.37763 .08722 L
.37859 .08585 L
.38436 .07751 L
.38831 .07175 L
.39097 .06779 L
.3975 .05808 L
.39802 .0573 L
.40387 .04837 L
.40773 .04244 L
.41015 .03866 L
.41635 .02894 L
.41744 .02723 L
.4224 .01923 L
.01923 .01923 L
F
0 g
.01923 .45983 m
.02313 .45629 L
.02894 .45012 L
.03248 .44658 L
.03866 .44041 L
.04219 .43687 L
.04837 .4307 L
.05191 .42716 L
.05808 .42098 L
.06162 .41744 L
.06779 .41127 L
.07133 .40773 L
.07751 .40156 L
.08104 .39802 L
.08722 .39184 L
.09076 .38831 L
.09693 .38213 L
.10047 .37859 L
.10664 .37242 L
.11018 .36888 L
.11636 .36271 L
.11989 .35917 L
.12607 .35299 L
.12961 .34946 L
.13578 .34328 L
.13932 .33974 L
.14549 .33357 L
.14903 .33003 L
.15521 .32386 L
.15874 .32032 L
.16492 .31414 L
.16846 .31061 L
.17463 .30443 L
.17817 .30089 L
.18434 .29472 L
.18788 .29118 L
.19406 .28501 L
.19759 .28147 L
.20377 .27529 L
.20731 .27176 L
.21348 .26558 L
.21702 .26204 L
.22319 .25587 L
.22673 .25233 L
.23291 .24616 L
.23644 .24262 L
.24262 .23644 L
.24616 .23291 L
.25233 .22673 L
.25587 .22319 L
Mistroke
.26204 .21702 L
.26558 .21348 L
.27176 .20731 L
.27529 .20377 L
.28147 .19759 L
.28501 .19406 L
.29118 .18788 L
.29472 .18434 L
.30089 .17817 L
.30443 .17463 L
.31061 .16846 L
.31414 .16492 L
.32032 .15874 L
.32386 .15521 L
.33003 .14903 L
.33386 .14549 L
.33974 .13932 L
.34251 .13578 L
.34946 .12624 L
.34958 .12607 L
.35672 .11636 L
.35917 .11301 L
.36379 .10664 L
.36888 .09957 L
.37076 .09693 L
.37763 .08722 L
.37859 .08585 L
.38436 .07751 L
.38831 .07175 L
.39097 .06779 L
.3975 .05808 L
.39802 .0573 L
.40387 .04837 L
.40773 .04244 L
.41015 .03866 L
.41635 .02894 L
.41744 .02723 L
.4224 .01923 L
Mfstroke
.5 g
.01923 .41616 m
.02767 .40773 L
.02894 .40645 L
.03738 .39802 L
.03866 .39674 L
.04709 .38831 L
.04837 .38703 L
.0568 .37859 L
.05808 .37731 L
.06651 .36888 L
.06779 .3676 L
.07623 .35917 L
.07751 .35789 L
.08594 .34946 L
.08722 .34818 L
.09565 .33974 L
.09693 .33846 L
.10536 .33003 L
.10664 .32875 L
.11508 .32032 L
.11636 .31904 L
.12479 .31061 L
.12607 .30933 L
.1345 .30089 L
.13578 .29961 L
.14421 .29118 L
.14549 .2899 L
.15393 .28147 L
.15521 .28019 L
.16364 .27176 L
.16492 .27048 L
.17335 .26204 L
.17463 .26076 L
.18306 .25233 L
.18434 .25105 L
.19278 .24262 L
.19406 .24134 L
.20249 .23291 L
.20377 .23163 L
.2122 .22319 L
.21348 .22191 L
.22191 .21348 L
.22319 .2122 L
.23163 .20377 L
.23291 .20249 L
.24134 .19406 L
.24262 .19278 L
.25105 .18434 L
.25233 .18306 L
.26076 .17463 L
.26204 .17335 L
.27048 .16492 L
.27176 .16364 L
.28019 .15521 L
.28147 .15393 L
.2899 .14549 L
.29118 .14421 L
.29961 .13578 L
.30089 .1345 L
.30933 .12607 L
.31061 .12479 L
.31904 .11636 L
.32032 .11508 L
.32875 .10664 L
.33003 .10536 L
.33851 .09693 L
.33974 .09565 L
.34743 .08722 L
.34946 .08495 L
.35592 .07751 L
.35917 .07366 L
.36403 .06779 L
.36888 .0618 L
.37184 .05808 L
.37859 .04938 L
.37937 .04837 L
.38667 .03866 L
.38831 .03643 L
.39375 .02894 L
.39802 .02297 L
.40065 .01923 L
.01923 .01923 L
F
0 g
.01923 .41616 m
.02767 .40773 L
.02894 .40645 L
.03738 .39802 L
.03866 .39674 L
.04709 .38831 L
.04837 .38703 L
.0568 .37859 L
.05808 .37731 L
.06651 .36888 L
.06779 .3676 L
.07623 .35917 L
.07751 .35789 L
.08594 .34946 L
.08722 .34818 L
.09565 .33974 L
.09693 .33846 L
.10536 .33003 L
.10664 .32875 L
.11508 .32032 L
.11636 .31904 L
.12479 .31061 L
.12607 .30933 L
.1345 .30089 L
.13578 .29961 L
.14421 .29118 L
.14549 .2899 L
.15393 .28147 L
.15521 .28019 L
.16364 .27176 L
.16492 .27048 L
.17335 .26204 L
.17463 .26076 L
.18306 .25233 L
.18434 .25105 L
.19278 .24262 L
.19406 .24134 L
.20249 .23291 L
.20377 .23163 L
.2122 .22319 L
.21348 .22191 L
.22191 .21348 L
.22319 .2122 L
.23163 .20377 L
.23291 .20249 L
.24134 .19406 L
.24262 .19278 L
.25105 .18434 L
.25233 .18306 L
.26076 .17463 L
Mistroke
.26204 .17335 L
.27048 .16492 L
.27176 .16364 L
.28019 .15521 L
.28147 .15393 L
.2899 .14549 L
.29118 .14421 L
.29961 .13578 L
.30089 .1345 L
.30933 .12607 L
.31061 .12479 L
.31904 .11636 L
.32032 .11508 L
.32875 .10664 L
.33003 .10536 L
.33851 .09693 L
.33974 .09565 L
.34743 .08722 L
.34946 .08495 L
.35592 .07751 L
.35917 .07366 L
.36403 .06779 L
.36888 .0618 L
.37184 .05808 L
.37859 .04938 L
.37937 .04837 L
.38667 .03866 L
.38831 .03643 L
.39375 .02894 L
.39802 .02297 L
.40065 .01923 L
Mfstroke
.6 g
.01923 .38075 m
.02139 .37859 L
.02894 .37104 L
.0311 .36888 L
.03866 .36133 L
.04081 .35917 L
.04837 .35161 L
.05053 .34946 L
.05808 .3419 L
.06024 .33974 L
.06779 .33219 L
.06995 .33003 L
.07751 .32248 L
.07966 .32032 L
.08722 .31276 L
.08938 .31061 L
.09693 .30305 L
.09909 .30089 L
.10664 .29334 L
.1088 .29118 L
.11636 .28363 L
.11851 .28147 L
.12607 .27391 L
.12823 .27176 L
.13578 .2642 L
.13794 .26204 L
.14549 .25449 L
.14765 .25233 L
.15521 .24478 L
.15736 .24262 L
.16492 .23506 L
.16708 .23291 L
.17463 .22535 L
.17679 .22319 L
.18434 .21564 L
.1865 .21348 L
.19406 .20593 L
.19621 .20377 L
.20377 .19621 L
.20593 .19406 L
.21348 .1865 L
.21564 .18434 L
.22319 .17679 L
.22535 .17463 L
.23291 .16708 L
.23506 .16492 L
.24262 .15736 L
.24478 .15521 L
.25233 .14765 L
.25449 .14549 L
.26204 .13794 L
.2642 .13578 L
.27176 .12823 L
.27391 .12607 L
.28147 .11851 L
.28363 .11636 L
.29118 .1088 L
.29334 .10664 L
.30089 .09909 L
.30305 .09693 L
.31061 .08938 L
.31276 .08722 L
.32032 .07966 L
.32248 .07751 L
.33003 .06995 L
.3322 .06779 L
.33974 .06024 L
.34194 .05808 L
.34946 .0508 L
.35184 .04837 L
.35917 .04057 L
.36092 .03866 L
.36888 .02962 L
.36947 .02894 L
.37761 .01923 L
.01923 .01923 L
F
0 g
.01923 .38075 m
.02139 .37859 L
.02894 .37104 L
.0311 .36888 L
.03866 .36133 L
.04081 .35917 L
.04837 .35161 L
.05053 .34946 L
.05808 .3419 L
.06024 .33974 L
.06779 .33219 L
.06995 .33003 L
.07751 .32248 L
.07966 .32032 L
.08722 .31276 L
.08938 .31061 L
.09693 .30305 L
.09909 .30089 L
.10664 .29334 L
.1088 .29118 L
.11636 .28363 L
.11851 .28147 L
.12607 .27391 L
.12823 .27176 L
.13578 .2642 L
.13794 .26204 L
.14549 .25449 L
.14765 .25233 L
.15521 .24478 L
.15736 .24262 L
.16492 .23506 L
.16708 .23291 L
.17463 .22535 L
.17679 .22319 L
.18434 .21564 L
.1865 .21348 L
.19406 .20593 L
.19621 .20377 L
.20377 .19621 L
.20593 .19406 L
.21348 .1865 L
.21564 .18434 L
.22319 .17679 L
.22535 .17463 L
.23291 .16708 L
.23506 .16492 L
.24262 .15736 L
.24478 .15521 L
.25233 .14765 L
.25449 .14549 L
Mistroke
.26204 .13794 L
.2642 .13578 L
.27176 .12823 L
.27391 .12607 L
.28147 .11851 L
.28363 .11636 L
.29118 .1088 L
.29334 .10664 L
.30089 .09909 L
.30305 .09693 L
.31061 .08938 L
.31276 .08722 L
.32032 .07966 L
.32248 .07751 L
.33003 .06995 L
.3322 .06779 L
.33974 .06024 L
.34194 .05808 L
.34946 .0508 L
.35184 .04837 L
.35917 .04057 L
.36092 .03866 L
.36888 .02962 L
.36947 .02894 L
.37761 .01923 L
Mfstroke
.7 g
.01923 .33708 m
.02621 .33003 L
.02894 .32737 L
.03599 .32032 L
.03866 .31765 L
.0457 .31061 L
.04837 .30794 L
.05542 .30089 L
.05808 .29823 L
.06513 .29118 L
.06779 .28852 L
.07484 .28147 L
.07751 .2788 L
.08455 .27176 L
.08722 .26909 L
.09427 .26204 L
.09693 .25938 L
.10398 .25233 L
.10664 .24967 L
.11369 .24262 L
.11636 .23995 L
.1234 .23291 L
.12607 .23024 L
.13312 .22319 L
.13578 .22053 L
.14283 .21348 L
.14549 .21082 L
.15254 .20377 L
.15521 .2011 L
.16225 .19406 L
.16492 .19139 L
.17197 .18434 L
.17463 .18168 L
.18168 .17463 L
.18434 .17197 L
.19139 .16492 L
.19406 .16225 L
.2011 .15521 L
.20377 .15254 L
.21082 .14549 L
.21348 .14283 L
.22053 .13578 L
.22319 .13312 L
.23024 .12607 L
.23291 .1234 L
.23995 .11636 L
.24262 .11369 L
.24967 .10664 L
.25233 .10398 L
.25938 .09693 L
.26204 .09427 L
.26909 .08722 L
.27176 .08455 L
.2788 .07751 L
.28147 .07484 L
.28852 .06779 L
.29118 .06513 L
.29823 .05808 L
.30089 .05542 L
.30794 .04837 L
.31061 .0457 L
.31765 .03866 L
.32032 .03599 L
.32737 .02894 L
.33003 .02621 L
.33696 .01923 L
.01923 .01923 L
F
0 g
.01923 .33708 m
.02621 .33003 L
.02894 .32737 L
.03599 .32032 L
.03866 .31765 L
.0457 .31061 L
.04837 .30794 L
.05542 .30089 L
.05808 .29823 L
.06513 .29118 L
.06779 .28852 L
.07484 .28147 L
.07751 .2788 L
.08455 .27176 L
.08722 .26909 L
.09427 .26204 L
.09693 .25938 L
.10398 .25233 L
.10664 .24967 L
.11369 .24262 L
.11636 .23995 L
.1234 .23291 L
.12607 .23024 L
.13312 .22319 L
.13578 .22053 L
.14283 .21348 L
.14549 .21082 L
.15254 .20377 L
.15521 .2011 L
.16225 .19406 L
.16492 .19139 L
.17197 .18434 L
.17463 .18168 L
.18168 .17463 L
.18434 .17197 L
.19139 .16492 L
.19406 .16225 L
.2011 .15521 L
.20377 .15254 L
.21082 .14549 L
.21348 .14283 L
.22053 .13578 L
.22319 .13312 L
.23024 .12607 L
.23291 .1234 L
.23995 .11636 L
.24262 .11369 L
.24967 .10664 L
.25233 .10398 L
.25938 .09693 L
Mistroke
.26204 .09427 L
.26909 .08722 L
.27176 .08455 L
.2788 .07751 L
.28147 .07484 L
.28852 .06779 L
.29118 .06513 L
.29823 .05808 L
.30089 .05542 L
.30794 .04837 L
.31061 .0457 L
.31765 .03866 L
.32032 .03599 L
.32737 .02894 L
.33003 .02621 L
.33696 .01923 L
Mfstroke
.6 g
.01923 .25846 m
.02556 .25233 L
.02894 .24875 L
.03507 .24262 L
.03866 .23903 L
.04478 .23291 L
.04837 .22932 L
.0545 .22319 L
.05808 .21961 L
.06421 .21348 L
.06779 .2099 L
.07392 .20377 L
.07751 .20018 L
.08363 .19406 L
.08722 .19047 L
.09335 .18434 L
.09693 .18076 L
.10306 .17463 L
.10664 .17105 L
.11277 .16492 L
.11636 .16133 L
.12248 .15521 L
.12607 .15162 L
.1322 .14549 L
.13578 .14191 L
.14191 .13578 L
.14549 .1322 L
.15162 .12607 L
.15521 .12248 L
.16133 .11636 L
.16492 .11277 L
.17105 .10664 L
.17463 .10306 L
.18076 .09693 L
.18434 .09335 L
.19047 .08722 L
.19406 .08363 L
.20018 .07751 L
.20377 .07392 L
.2099 .06779 L
.21348 .06421 L
.21961 .05808 L
.22319 .0545 L
.22932 .04837 L
.23291 .04478 L
.23903 .03866 L
.24262 .03507 L
.24875 .02894 L
.25233 .02556 L
.25846 .01923 L
.01923 .01923 L
F
0 g
.01923 .25846 m
.02556 .25233 L
.02894 .24875 L
.03507 .24262 L
.03866 .23903 L
.04478 .23291 L
.04837 .22932 L
.0545 .22319 L
.05808 .21961 L
.06421 .21348 L
.06779 .2099 L
.07392 .20377 L
.07751 .20018 L
.08363 .19406 L
.08722 .19047 L
.09335 .18434 L
.09693 .18076 L
.10306 .17463 L
.10664 .17105 L
.11277 .16492 L
.11636 .16133 L
.12248 .15521 L
.12607 .15162 L
.1322 .14549 L
.13578 .14191 L
.14191 .13578 L
.14549 .1322 L
.15162 .12607 L
.15521 .12248 L
.16133 .11636 L
.16492 .11277 L
.17105 .10664 L
.17463 .10306 L
.18076 .09693 L
.18434 .09335 L
.19047 .08722 L
.19406 .08363 L
.20018 .07751 L
.20377 .07392 L
.2099 .06779 L
.21348 .06421 L
.21961 .05808 L
.22319 .0545 L
.22932 .04837 L
.23291 .04478 L
.23903 .03866 L
.24262 .03507 L
.24875 .02894 L
.25233 .02556 L
.25846 .01923 L
Mistroke
Mfstroke
.5 g
.01923 .21478 m
.02054 .21348 L
.02894 .20507 L
.03024 .20377 L
.03866 .19535 L
.03995 .19406 L
.04837 .18564 L
.04967 .18434 L
.05808 .17593 L
.05938 .17463 L
.06779 .16622 L
.06909 .16492 L
.07751 .1565 L
.0788 .15521 L
.08722 .14679 L
.08852 .14549 L
.09693 .13708 L
.09823 .13578 L
.10664 .12737 L
.10794 .12607 L
.11636 .11765 L
.11765 .11636 L
.12607 .10794 L
.12737 .10664 L
.13578 .09823 L
.13708 .09693 L
.14549 .08852 L
.14679 .08722 L
.15521 .0788 L
.1565 .07751 L
.16492 .06909 L
.16622 .06779 L
.17463 .05938 L
.17593 .05808 L
.18434 .04967 L
.18564 .04837 L
.19406 .03995 L
.19535 .03866 L
.20377 .03024 L
.20507 .02894 L
.21348 .02054 L
.21478 .01923 L
.01923 .01923 L
F
0 g
.01923 .21478 m
.02054 .21348 L
.02894 .20507 L
.03024 .20377 L
.03866 .19535 L
.03995 .19406 L
.04837 .18564 L
.04967 .18434 L
.05808 .17593 L
.05938 .17463 L
.06779 .16622 L
.06909 .16492 L
.07751 .1565 L
.0788 .15521 L
.08722 .14679 L
.08852 .14549 L
.09693 .13708 L
.09823 .13578 L
.10664 .12737 L
.10794 .12607 L
.11636 .11765 L
.11765 .11636 L
.12607 .10794 L
.12737 .10664 L
.13578 .09823 L
.13708 .09693 L
.14549 .08852 L
.14679 .08722 L
.15521 .0788 L
.1565 .07751 L
.16492 .06909 L
.16622 .06779 L
.17463 .05938 L
.17593 .05808 L
.18434 .04967 L
.18564 .04837 L
.19406 .03995 L
.19535 .03866 L
.20377 .03024 L
.20507 .02894 L
.21348 .02054 L
.21478 .01923 L
s
.4 g
.01923 .17937 m
.02396 .17463 L
.02894 .16966 L
.03368 .16492 L
.03866 .15994 L
.04339 .15521 L
.04837 .15023 L
.05311 .14549 L
.05808 .14052 L
.06282 .13578 L
.06779 .13081 L
.07253 .12607 L
.07751 .12109 L
.08224 .11636 L
.08722 .11138 L
.09196 .10664 L
.09693 .10167 L
.10167 .09693 L
.10664 .09196 L
.11138 .08722 L
.11636 .08224 L
.12109 .07751 L
.12607 .07253 L
.13081 .06779 L
.13578 .06282 L
.14052 .05808 L
.14549 .05311 L
.15023 .04837 L
.15521 .04339 L
.15994 .03866 L
.16492 .03368 L
.16966 .02894 L
.17463 .02396 L
.17937 .01923 L
.01923 .01923 L
F
0 g
.01923 .17937 m
.02396 .17463 L
.02894 .16966 L
.03368 .16492 L
.03866 .15994 L
.04339 .15521 L
.04837 .15023 L
.05311 .14549 L
.05808 .14052 L
.06282 .13578 L
.06779 .13081 L
.07253 .12607 L
.07751 .12109 L
.08224 .11636 L
.08722 .11138 L
.09196 .10664 L
.09693 .10167 L
.10167 .09693 L
.10664 .09196 L
.11138 .08722 L
.11636 .08224 L
.12109 .07751 L
.12607 .07253 L
.13081 .06779 L
.13578 .06282 L
.14052 .05808 L
.14549 .05311 L
.15023 .04837 L
.15521 .04339 L
.15994 .03866 L
.16492 .03368 L
.16966 .02894 L
.17463 .02396 L
.17937 .01923 L
s
.3 g
.01923 .13565 m
.02881 .12607 L
.02894 .12594 L
.03853 .11636 L
.03866 .11623 L
.04824 .10664 L
.04837 .10651 L
.05795 .09693 L
.05808 .0968 L
.06766 .08722 L
.06779 .08709 L
.07738 .07751 L
.07751 .07738 L
.08709 .06779 L
.08722 .06766 L
.0968 .05808 L
.09693 .05795 L
.10651 .04837 L
.10664 .04824 L
.11623 .03866 L
.11636 .03853 L
.12594 .02894 L
.12607 .02881 L
.13565 .01923 L
.01923 .01923 L
F
0 g
.01923 .13565 m
.02881 .12607 L
.02894 .12594 L
.03853 .11636 L
.03866 .11623 L
.04824 .10664 L
.04837 .10651 L
.05795 .09693 L
.05808 .0968 L
.06766 .08722 L
.06779 .08709 L
.07738 .07751 L
.07751 .07738 L
.08709 .06779 L
.08722 .06766 L
.0968 .05808 L
.09693 .05795 L
.10651 .04837 L
.10664 .04824 L
.11623 .03866 L
.11636 .03853 L
.12594 .02894 L
.12607 .02881 L
.13565 .01923 L
s
.4 g
.01923 .0571 m
.02801 .04837 L
.02894 .04739 L
.03768 .03866 L
.03866 .03768 L
.04739 .02894 L
.04837 .02801 L
.0571 .01923 L
.01923 .01923 L
F
0 g
.01923 .0571 m
.02801 .04837 L
.02894 .04739 L
.03768 .03866 L
.03866 .03768 L
.04739 .02894 L
.04837 .02801 L
.0571 .01923 L
s
.5 g
.02336 .98077 m
.02894 .97518 L
.03308 .97106 L
.03866 .96548 L
.04279 .96134 L
.04837 .95577 L
.0525 .95163 L
.05808 .94605 L
.06222 .94192 L
.06779 .93634 L
.07193 .93221 L
.07751 .92663 L
.08164 .92249 L
.08722 .91692 L
.09135 .91278 L
.09693 .9072 L
.10107 .90307 L
.10664 .89749 L
.11078 .89336 L
.11636 .88778 L
.12049 .88364 L
.12607 .87807 L
.1302 .87393 L
.13578 .86835 L
.13992 .86422 L
.14549 .85864 L
.14963 .85451 L
.15521 .84893 L
.15934 .84479 L
.16492 .83922 L
.16905 .83508 L
.17463 .8295 L
.17877 .82537 L
.18434 .81979 L
.18848 .81566 L
.19406 .81008 L
.19819 .80594 L
.20377 .80037 L
.2079 .79623 L
.21348 .79065 L
.21762 .78652 L
.22319 .78094 L
.22733 .77681 L
.23291 .77123 L
.23704 .76709 L
.24262 .76152 L
.24675 .75738 L
.25233 .7518 L
.25647 .74767 L
.26204 .74209 L
.26618 .73796 L
.27176 .73238 L
.27589 .72824 L
.28147 .72267 L
.2856 .71853 L
.29118 .71295 L
.29532 .70882 L
.30089 .70324 L
.30503 .69911 L
.31061 .69353 L
.31474 .68939 L
.32032 .68382 L
.32445 .67968 L
.33003 .6741 L
.33418 .66997 L
.33974 .66439 L
.34396 .66026 L
.34946 .65495 L
.35375 .65054 L
.35917 .64472 L
.36271 .64083 L
.36888 .63378 L
.37116 .63112 L
.37859 .62216 L
.37921 .62141 L
.38694 .61169 L
.38831 .60993 L
.39439 .60198 L
.39802 .5971 L
.40158 .59227 L
.40773 .5837 L
.40855 .58256 L
.41535 .57284 L
.41744 .56977 L
.42196 .56313 L
.42716 .55532 L
.42842 .55342 L
.43474 .54371 L
.43687 .54038 L
.44094 .53399 L
.44658 .52495 L
.447 .52428 L
.45297 .51457 L
.45629 .50906 L
.45883 .50486 L
.46459 .49514 L
.46601 .49272 L
.47027 .48543 L
.47572 .47593 L
.47584 .47572 L
.48137 .46601 L
.48543 .45873 L
.48679 .45629 L
.49217 .44658 L
.49514 .4411 L
.49745 .43687 L
.50269 .42716 L
.50486 .42308 L
.50786 .41744 L
.51297 .40773 L
.51457 .40465 L
.51803 .39802 L
.52303 .38831 L
.52428 .38584 L
.52798 .37859 L
.53288 .36888 L
.53399 .36664 L
.53774 .35917 L
.54255 .34946 L
.54371 .34708 L
.54732 .33974 L
.55204 .33003 L
.55342 .32715 L
.55672 .32032 L
.56137 .31061 L
.56313 .30686 L
.56597 .30089 L
.57055 .29118 L
.57284 .28622 L
.57507 .28147 L
.57958 .27176 L
.58256 .26523 L
.58402 .26204 L
.58848 .25233 L
.59227 .24391 L
.59285 .24262 L
.59724 .23291 L
.60157 .22319 L
.60198 .22225 L
.60589 .21348 L
.61017 .20377 L
.61169 .20026 L
.61442 .19406 L
.61866 .18434 L
.62141 .17794 L
.62284 .17463 L
.62704 .16492 L
.63112 .15531 L
.63116 .15521 L
.63531 .14549 L
.63941 .13578 L
.64083 .13236 L
.64348 .12607 L
.64756 .11636 L
.65054 .1091 L
.65156 .10664 L
.6556 .09693 L
.65958 .08722 L
.66026 .08553 L
.66355 .07751 L
.66752 .06779 L
.66997 .06166 L
.67142 .05808 L
.67536 .04837 L
.67923 .03866 L
.67968 .03749 L
.68311 .02894 L
.68698 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.02336 .98077 m
.02894 .97518 L
.03308 .97106 L
.03866 .96548 L
.04279 .96134 L
.04837 .95577 L
.0525 .95163 L
.05808 .94605 L
.06222 .94192 L
.06779 .93634 L
.07193 .93221 L
.07751 .92663 L
.08164 .92249 L
.08722 .91692 L
.09135 .91278 L
.09693 .9072 L
.10107 .90307 L
.10664 .89749 L
.11078 .89336 L
.11636 .88778 L
.12049 .88364 L
.12607 .87807 L
.1302 .87393 L
.13578 .86835 L
.13992 .86422 L
.14549 .85864 L
.14963 .85451 L
.15521 .84893 L
.15934 .84479 L
.16492 .83922 L
.16905 .83508 L
.17463 .8295 L
.17877 .82537 L
.18434 .81979 L
.18848 .81566 L
.19406 .81008 L
.19819 .80594 L
.20377 .80037 L
.2079 .79623 L
.21348 .79065 L
.21762 .78652 L
.22319 .78094 L
.22733 .77681 L
.23291 .77123 L
.23704 .76709 L
.24262 .76152 L
.24675 .75738 L
.25233 .7518 L
.25647 .74767 L
.26204 .74209 L
Mistroke
.26618 .73796 L
.27176 .73238 L
.27589 .72824 L
.28147 .72267 L
.2856 .71853 L
.29118 .71295 L
.29532 .70882 L
.30089 .70324 L
.30503 .69911 L
.31061 .69353 L
.31474 .68939 L
.32032 .68382 L
.32445 .67968 L
.33003 .6741 L
.33418 .66997 L
.33974 .66439 L
.34396 .66026 L
.34946 .65495 L
.35375 .65054 L
.35917 .64472 L
.36271 .64083 L
.36888 .63378 L
.37116 .63112 L
.37859 .62216 L
.37921 .62141 L
.38694 .61169 L
.38831 .60993 L
.39439 .60198 L
.39802 .5971 L
.40158 .59227 L
.40773 .5837 L
.40855 .58256 L
.41535 .57284 L
.41744 .56977 L
.42196 .56313 L
.42716 .55532 L
.42842 .55342 L
.43474 .54371 L
.43687 .54038 L
.44094 .53399 L
.44658 .52495 L
.447 .52428 L
.45297 .51457 L
.45629 .50906 L
.45883 .50486 L
.46459 .49514 L
.46601 .49272 L
.47027 .48543 L
.47572 .47593 L
.47584 .47572 L
Mistroke
.48137 .46601 L
.48543 .45873 L
.48679 .45629 L
.49217 .44658 L
.49514 .4411 L
.49745 .43687 L
.50269 .42716 L
.50486 .42308 L
.50786 .41744 L
.51297 .40773 L
.51457 .40465 L
.51803 .39802 L
.52303 .38831 L
.52428 .38584 L
.52798 .37859 L
.53288 .36888 L
.53399 .36664 L
.53774 .35917 L
.54255 .34946 L
.54371 .34708 L
.54732 .33974 L
.55204 .33003 L
.55342 .32715 L
.55672 .32032 L
.56137 .31061 L
.56313 .30686 L
.56597 .30089 L
.57055 .29118 L
.57284 .28622 L
.57507 .28147 L
.57958 .27176 L
.58256 .26523 L
.58402 .26204 L
.58848 .25233 L
.59227 .24391 L
.59285 .24262 L
.59724 .23291 L
.60157 .22319 L
.60198 .22225 L
.60589 .21348 L
.61017 .20377 L
.61169 .20026 L
.61442 .19406 L
.61866 .18434 L
.62141 .17794 L
.62284 .17463 L
.62704 .16492 L
.63112 .15531 L
.63116 .15521 L
.63531 .14549 L
Mistroke
.63941 .13578 L
.64083 .13236 L
.64348 .12607 L
.64756 .11636 L
.65054 .1091 L
.65156 .10664 L
.6556 .09693 L
.65958 .08722 L
.66026 .08553 L
.66355 .07751 L
.66752 .06779 L
.66997 .06166 L
.67142 .05808 L
.67536 .04837 L
.67923 .03866 L
.67968 .03749 L
.68311 .02894 L
.68698 .01923 L
Mfstroke
.6 g
.05878 .98077 m
.06779 .97175 L
.06849 .97106 L
.07751 .96204 L
.0782 .96134 L
.08722 .95233 L
.08791 .95163 L
.09693 .94262 L
.09763 .94192 L
.10664 .9329 L
.10734 .93221 L
.11636 .92319 L
.11705 .92249 L
.12607 .91348 L
.12676 .91278 L
.13578 .90377 L
.13648 .90307 L
.14549 .89405 L
.14619 .89336 L
.15521 .88434 L
.1559 .88364 L
.16492 .87463 L
.16561 .87393 L
.17463 .86492 L
.17533 .86422 L
.18434 .8552 L
.18504 .85451 L
.19406 .84549 L
.19475 .84479 L
.20377 .83578 L
.20446 .83508 L
.21348 .82607 L
.21418 .82537 L
.22319 .81635 L
.22389 .81566 L
.23291 .80664 L
.2336 .80594 L
.24262 .79693 L
.24331 .79623 L
.25233 .78722 L
.25303 .78652 L
.26204 .7775 L
.26274 .77681 L
.27176 .76779 L
.27245 .76709 L
.28147 .75808 L
.28216 .75738 L
.29118 .74837 L
.29188 .74767 L
.30089 .73865 L
.30159 .73796 L
.31061 .72894 L
.3113 .72824 L
.32032 .71923 L
.32101 .71853 L
.33003 .70952 L
.33075 .70882 L
.33974 .6998 L
.34039 .69911 L
.3492 .68939 L
.34946 .6891 L
.3576 .67968 L
.35917 .67781 L
.36565 .66997 L
.36888 .66595 L
.37339 .66026 L
.37859 .65353 L
.38087 .65054 L
.38813 .64083 L
.38831 .64058 L
.39517 .63112 L
.39802 .62711 L
.40203 .62141 L
.40773 .61314 L
.40872 .61169 L
.41526 .60198 L
.41744 .59868 L
.42165 .59227 L
.42716 .58375 L
.42792 .58256 L
.43407 .57284 L
.43687 .56836 L
.4401 .56313 L
.44604 .55342 L
.44658 .55252 L
.45187 .54371 L
.45629 .53625 L
.45762 .53399 L
.46328 .52428 L
.46601 .51954 L
.46885 .51457 L
.47435 .50486 L
.47572 .50243 L
.47978 .49514 L
.48514 .48543 L
.48543 .4849 L
.49043 .47572 L
.49514 .46698 L
.49566 .46601 L
.50083 .45629 L
.50486 .44867 L
.50595 .44658 L
.51101 .43687 L
.51457 .42998 L
.51601 .42716 L
.52097 .41744 L
.52428 .41091 L
.52588 .40773 L
.53074 .39802 L
.53399 .39147 L
.53555 .38831 L
.54033 .37859 L
.54371 .37168 L
.54506 .36888 L
.54975 .35917 L
.55342 .35153 L
.5544 .34946 L
.55901 .33974 L
.56313 .33103 L
.5636 .33003 L
.56813 .32032 L
.57265 .31061 L
.57284 .31019 L
.57711 .30089 L
.58157 .29118 L
.58256 .28901 L
.58596 .28147 L
.59035 .27176 L
.59227 .26749 L
.59469 .26204 L
.59902 .25233 L
.60198 .24565 L
.60331 .24262 L
.60757 .23291 L
.61169 .22349 L
.61182 .22319 L
.61602 .21348 L
.62022 .20377 L
.62141 .20101 L
.62437 .19406 L
.62852 .18434 L
.63112 .17821 L
.63262 .17463 L
.63671 .16492 L
.64079 .15521 L
.64083 .15511 L
.64482 .14549 L
.64886 .13578 L
.65054 .1317 L
.65284 .12607 L
.65683 .11636 L
.66026 .10798 L
.66079 .10664 L
.66472 .09693 L
.66866 .08722 L
.66997 .08397 L
.67254 .07751 L
.67644 .06779 L
.67968 .05967 L
.6803 .05808 L
.68414 .04837 L
.68798 .03866 L
.68939 .03507 L
.69177 .02894 L
.69558 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.05878 .98077 m
.06779 .97175 L
.06849 .97106 L
.07751 .96204 L
.0782 .96134 L
.08722 .95233 L
.08791 .95163 L
.09693 .94262 L
.09763 .94192 L
.10664 .9329 L
.10734 .93221 L
.11636 .92319 L
.11705 .92249 L
.12607 .91348 L
.12676 .91278 L
.13578 .90377 L
.13648 .90307 L
.14549 .89405 L
.14619 .89336 L
.15521 .88434 L
.1559 .88364 L
.16492 .87463 L
.16561 .87393 L
.17463 .86492 L
.17533 .86422 L
.18434 .8552 L
.18504 .85451 L
.19406 .84549 L
.19475 .84479 L
.20377 .83578 L
.20446 .83508 L
.21348 .82607 L
.21418 .82537 L
.22319 .81635 L
.22389 .81566 L
.23291 .80664 L
.2336 .80594 L
.24262 .79693 L
.24331 .79623 L
.25233 .78722 L
.25303 .78652 L
.26204 .7775 L
.26274 .77681 L
.27176 .76779 L
.27245 .76709 L
.28147 .75808 L
.28216 .75738 L
.29118 .74837 L
.29188 .74767 L
.30089 .73865 L
Mistroke
.30159 .73796 L
.31061 .72894 L
.3113 .72824 L
.32032 .71923 L
.32101 .71853 L
.33003 .70952 L
.33075 .70882 L
.33974 .6998 L
.34039 .69911 L
.3492 .68939 L
.34946 .6891 L
.3576 .67968 L
.35917 .67781 L
.36565 .66997 L
.36888 .66595 L
.37339 .66026 L
.37859 .65353 L
.38087 .65054 L
.38813 .64083 L
.38831 .64058 L
.39517 .63112 L
.39802 .62711 L
.40203 .62141 L
.40773 .61314 L
.40872 .61169 L
.41526 .60198 L
.41744 .59868 L
.42165 .59227 L
.42716 .58375 L
.42792 .58256 L
.43407 .57284 L
.43687 .56836 L
.4401 .56313 L
.44604 .55342 L
.44658 .55252 L
.45187 .54371 L
.45629 .53625 L
.45762 .53399 L
.46328 .52428 L
.46601 .51954 L
.46885 .51457 L
.47435 .50486 L
.47572 .50243 L
.47978 .49514 L
.48514 .48543 L
.48543 .4849 L
.49043 .47572 L
.49514 .46698 L
.49566 .46601 L
.50083 .45629 L
Mistroke
.50486 .44867 L
.50595 .44658 L
.51101 .43687 L
.51457 .42998 L
.51601 .42716 L
.52097 .41744 L
.52428 .41091 L
.52588 .40773 L
.53074 .39802 L
.53399 .39147 L
.53555 .38831 L
.54033 .37859 L
.54371 .37168 L
.54506 .36888 L
.54975 .35917 L
.55342 .35153 L
.5544 .34946 L
.55901 .33974 L
.56313 .33103 L
.5636 .33003 L
.56813 .32032 L
.57265 .31061 L
.57284 .31019 L
.57711 .30089 L
.58157 .29118 L
.58256 .28901 L
.58596 .28147 L
.59035 .27176 L
.59227 .26749 L
.59469 .26204 L
.59902 .25233 L
.60198 .24565 L
.60331 .24262 L
.60757 .23291 L
.61169 .22349 L
.61182 .22319 L
.61602 .21348 L
.62022 .20377 L
.62141 .20101 L
.62437 .19406 L
.62852 .18434 L
.63112 .17821 L
.63262 .17463 L
.63671 .16492 L
.64079 .15521 L
.64083 .15511 L
.64482 .14549 L
.64886 .13578 L
.65054 .1317 L
.65284 .12607 L
Mistroke
.65683 .11636 L
.66026 .10798 L
.66079 .10664 L
.66472 .09693 L
.66866 .08722 L
.66997 .08397 L
.67254 .07751 L
.67644 .06779 L
.67968 .05967 L
.6803 .05808 L
.68414 .04837 L
.68798 .03866 L
.68939 .03507 L
.69177 .02894 L
.69558 .01923 L
Mfstroke
.7 g
.10245 .98077 m
.10664 .97666 L
.11217 .97106 L
.11636 .96687 L
.12188 .96134 L
.12607 .95715 L
.13159 .95163 L
.13578 .94744 L
.1413 .94192 L
.14549 .93773 L
.15102 .93221 L
.15521 .92802 L
.16073 .92249 L
.16492 .9183 L
.17044 .91278 L
.17463 .90859 L
.18015 .90307 L
.18434 .89888 L
.18987 .89336 L
.19406 .88917 L
.19958 .88364 L
.20377 .87945 L
.20929 .87393 L
.21348 .86974 L
.219 .86422 L
.22319 .86003 L
.22872 .85451 L
.23291 .85032 L
.23843 .84479 L
.24262 .8406 L
.24814 .83508 L
.25233 .83089 L
.25785 .82537 L
.26204 .82118 L
.26757 .81566 L
.27176 .81147 L
.27728 .80594 L
.28147 .80175 L
.28699 .79623 L
.29118 .79204 L
.2967 .78652 L
.30089 .78233 L
.30642 .77681 L
.31061 .77262 L
.31613 .76709 L
.32032 .7629 L
.32584 .75738 L
.33003 .75319 L
.33585 .74767 L
.33974 .74348 L
.34397 .73796 L
.34946 .73036 L
.35103 .72824 L
.35818 .71853 L
.35917 .71717 L
.36522 .70882 L
.36888 .70372 L
.37216 .69911 L
.37859 .69 L
.37901 .68939 L
.38572 .67968 L
.38831 .6759 L
.3923 .66997 L
.39802 .66145 L
.3988 .66026 L
.40516 .65054 L
.40773 .64659 L
.41141 .64083 L
.41744 .63137 L
.4176 .63112 L
.42363 .62141 L
.42716 .61572 L
.42959 .61169 L
.43549 .60198 L
.43687 .59969 L
.44125 .59227 L
.44658 .58327 L
.44699 .58256 L
.4526 .57284 L
.45629 .56645 L
.45815 .56313 L
.46366 .55342 L
.46601 .54925 L
.46905 .54371 L
.47444 .53399 L
.47572 .53168 L
.47969 .52428 L
.48498 .51457 L
.48543 .51373 L
.4901 .50486 L
.49514 .49541 L
.49528 .49514 L
.5003 .48543 L
.50486 .47672 L
.50535 .47572 L
.51029 .46601 L
.51457 .45767 L
.51524 .45629 L
.52009 .44658 L
.52428 .43827 L
.52495 .43687 L
.52971 .42716 L
.53399 .41852 L
.53449 .41744 L
.53916 .40773 L
.54371 .39842 L
.54389 .39802 L
.54846 .38831 L
.55313 .37859 L
.55342 .37799 L
.55761 .36888 L
.56221 .35917 L
.56313 .35721 L
.56663 .34946 L
.57116 .33974 L
.57284 .33611 L
.57553 .33003 L
.57997 .32032 L
.58256 .31468 L
.58431 .31061 L
.58867 .30089 L
.59227 .29294 L
.593 .29118 L
.59725 .28147 L
.60159 .27176 L
.60198 .27087 L
.60573 .26204 L
.61001 .25233 L
.61169 .24849 L
.61412 .24262 L
.61832 .23291 L
.62141 .2258 L
.62244 .22319 L
.62653 .21348 L
.63071 .20377 L
.63112 .20281 L
.63467 .19406 L
.63878 .18434 L
.64083 .1795 L
.64274 .17463 L
.64677 .16492 L
.65054 .15591 L
.65081 .15521 L
.65468 .14549 L
.6587 .13578 L
.66026 .13201 L
.66253 .12607 L
.66648 .11636 L
.66997 .10783 L
.6704 .10664 L
.67419 .09693 L
.67812 .08722 L
.67968 .08336 L
.68186 .07751 L
.68571 .06779 L
.68939 .0586 L
.68958 .05808 L
.69324 .04837 L
.69709 .03866 L
.69911 .03356 L
.70076 .02894 L
.70451 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.10245 .98077 m
.10664 .97666 L
.11217 .97106 L
.11636 .96687 L
.12188 .96134 L
.12607 .95715 L
.13159 .95163 L
.13578 .94744 L
.1413 .94192 L
.14549 .93773 L
.15102 .93221 L
.15521 .92802 L
.16073 .92249 L
.16492 .9183 L
.17044 .91278 L
.17463 .90859 L
.18015 .90307 L
.18434 .89888 L
.18987 .89336 L
.19406 .88917 L
.19958 .88364 L
.20377 .87945 L
.20929 .87393 L
.21348 .86974 L
.219 .86422 L
.22319 .86003 L
.22872 .85451 L
.23291 .85032 L
.23843 .84479 L
.24262 .8406 L
.24814 .83508 L
.25233 .83089 L
.25785 .82537 L
.26204 .82118 L
.26757 .81566 L
.27176 .81147 L
.27728 .80594 L
.28147 .80175 L
.28699 .79623 L
.29118 .79204 L
.2967 .78652 L
.30089 .78233 L
.30642 .77681 L
.31061 .77262 L
.31613 .76709 L
.32032 .7629 L
.32584 .75738 L
.33003 .75319 L
.33585 .74767 L
.33974 .74348 L
Mistroke
.34397 .73796 L
.34946 .73036 L
.35103 .72824 L
.35818 .71853 L
.35917 .71717 L
.36522 .70882 L
.36888 .70372 L
.37216 .69911 L
.37859 .69 L
.37901 .68939 L
.38572 .67968 L
.38831 .6759 L
.3923 .66997 L
.39802 .66145 L
.3988 .66026 L
.40516 .65054 L
.40773 .64659 L
.41141 .64083 L
.41744 .63137 L
.4176 .63112 L
.42363 .62141 L
.42716 .61572 L
.42959 .61169 L
.43549 .60198 L
.43687 .59969 L
.44125 .59227 L
.44658 .58327 L
.44699 .58256 L
.4526 .57284 L
.45629 .56645 L
.45815 .56313 L
.46366 .55342 L
.46601 .54925 L
.46905 .54371 L
.47444 .53399 L
.47572 .53168 L
.47969 .52428 L
.48498 .51457 L
.48543 .51373 L
.4901 .50486 L
.49514 .49541 L
.49528 .49514 L
.5003 .48543 L
.50486 .47672 L
.50535 .47572 L
.51029 .46601 L
.51457 .45767 L
.51524 .45629 L
.52009 .44658 L
.52428 .43827 L
Mistroke
.52495 .43687 L
.52971 .42716 L
.53399 .41852 L
.53449 .41744 L
.53916 .40773 L
.54371 .39842 L
.54389 .39802 L
.54846 .38831 L
.55313 .37859 L
.55342 .37799 L
.55761 .36888 L
.56221 .35917 L
.56313 .35721 L
.56663 .34946 L
.57116 .33974 L
.57284 .33611 L
.57553 .33003 L
.57997 .32032 L
.58256 .31468 L
.58431 .31061 L
.58867 .30089 L
.59227 .29294 L
.593 .29118 L
.59725 .28147 L
.60159 .27176 L
.60198 .27087 L
.60573 .26204 L
.61001 .25233 L
.61169 .24849 L
.61412 .24262 L
.61832 .23291 L
.62141 .2258 L
.62244 .22319 L
.62653 .21348 L
.63071 .20377 L
.63112 .20281 L
.63467 .19406 L
.63878 .18434 L
.64083 .1795 L
.64274 .17463 L
.64677 .16492 L
.65054 .15591 L
.65081 .15521 L
.65468 .14549 L
.6587 .13578 L
.66026 .13201 L
.66253 .12607 L
.66648 .11636 L
.66997 .10783 L
.6704 .10664 L
Mistroke
.67419 .09693 L
.67812 .08722 L
.67968 .08336 L
.68186 .07751 L
.68571 .06779 L
.68939 .0586 L
.68958 .05808 L
.69324 .04837 L
.69709 .03866 L
.69911 .03356 L
.70076 .02894 L
.70451 .01923 L
Mfstroke
.6 g
.18108 .98077 m
.18434 .97713 L
.19079 .97106 L
.19406 .96779 L
.2005 .96134 L
.20377 .95808 L
.21022 .95163 L
.21348 .94837 L
.21993 .94192 L
.22319 .93865 L
.22964 .93221 L
.23291 .92894 L
.23935 .92249 L
.24262 .91923 L
.24907 .91278 L
.25233 .90952 L
.25878 .90307 L
.26204 .8998 L
.26849 .89336 L
.27176 .89009 L
.2782 .88364 L
.28147 .88038 L
.28792 .87393 L
.29118 .87067 L
.29763 .86422 L
.30089 .86095 L
.30734 .85451 L
.31061 .85124 L
.31705 .84479 L
.32032 .84153 L
.32677 .83508 L
.33003 .83182 L
.33636 .82537 L
.33974 .8221 L
.34851 .81566 L
.34946 .81505 L
.35917 .80674 L
.36008 .80594 L
.36888 .79737 L
.37004 .79623 L
.37859 .78708 L
.37912 .78652 L
.38766 .77681 L
.38831 .77598 L
.39577 .76709 L
.39802 .76416 L
.40345 .75738 L
.40773 .75164 L
.41077 .74767 L
.41744 .73847 L
.41782 .73796 L
.42481 .72824 L
.42716 .72474 L
.4315 .71853 L
.43687 .71043 L
.43796 .70882 L
.4444 .69911 L
.44658 .69559 L
.45062 .68939 L
.45629 .68023 L
.45664 .67968 L
.46272 .66997 L
.46601 .66439 L
.46854 .66026 L
.47433 .65054 L
.47572 .64807 L
.48003 .64083 L
.48543 .63128 L
.48553 .63112 L
.49114 .62141 L
.49514 .61407 L
.49649 .61169 L
.50193 .60198 L
.50486 .59642 L
.50715 .59227 L
.51243 .58256 L
.51457 .57835 L
.51755 .57284 L
.52267 .56313 L
.52428 .55987 L
.5277 .55342 L
.53269 .54371 L
.53399 .54099 L
.53762 .53399 L
.54251 .52428 L
.54371 .52172 L
.54735 .51457 L
.55214 .50486 L
.55342 .50208 L
.55688 .49514 L
.56161 .48543 L
.56313 .48206 L
.56625 .47572 L
.57091 .46601 L
.57284 .46168 L
.57544 .45629 L
.58006 .44658 L
.58256 .44094 L
.58449 .43687 L
.58906 .42716 L
.59227 .41985 L
.59339 .41744 L
.59791 .40773 L
.60198 .39841 L
.60216 .39802 L
.60663 .38831 L
.6109 .37859 L
.61169 .37664 L
.61521 .36888 L
.61951 .35917 L
.62141 .35454 L
.62368 .34946 L
.62798 .33974 L
.63112 .3321 L
.63203 .33003 L
.6363 .32032 L
.64035 .31061 L
.64083 .30934 L
.64451 .30089 L
.64863 .29118 L
.65054 .28627 L
.6526 .28147 L
.65675 .27176 L
.66026 .26288 L
.66061 .26204 L
.66473 .25233 L
.66869 .24262 L
.66997 .23919 L
.6726 .23291 L
.67662 .22319 L
.67968 .21518 L
.68038 .21348 L
.6844 .20377 L
.68826 .19406 L
.68939 .19089 L
.69207 .18434 L
.696 .17463 L
.69911 .16628 L
.69966 .16492 L
.70358 .15521 L
.70738 .14549 L
.70882 .1414 L
.71106 .13578 L
.71493 .12607 L
.71848 .11636 L
.71853 .11621 L
.72232 .10664 L
.72608 .09693 L
.72824 .09075 L
.72962 .08722 L
.73342 .07751 L
.73703 .06779 L
.73796 .065 L
.74063 .05808 L
.74437 .04837 L
.74767 .03897 L
.74779 .03866 L
.75152 .02894 L
.75517 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.18108 .98077 m
.18434 .97713 L
.19079 .97106 L
.19406 .96779 L
.2005 .96134 L
.20377 .95808 L
.21022 .95163 L
.21348 .94837 L
.21993 .94192 L
.22319 .93865 L
.22964 .93221 L
.23291 .92894 L
.23935 .92249 L
.24262 .91923 L
.24907 .91278 L
.25233 .90952 L
.25878 .90307 L
.26204 .8998 L
.26849 .89336 L
.27176 .89009 L
.2782 .88364 L
.28147 .88038 L
.28792 .87393 L
.29118 .87067 L
.29763 .86422 L
.30089 .86095 L
.30734 .85451 L
.31061 .85124 L
.31705 .84479 L
.32032 .84153 L
.32677 .83508 L
.33003 .83182 L
.33636 .82537 L
.33974 .8221 L
.34851 .81566 L
.34946 .81505 L
.35917 .80674 L
.36008 .80594 L
.36888 .79737 L
.37004 .79623 L
.37859 .78708 L
.37912 .78652 L
.38766 .77681 L
.38831 .77598 L
.39577 .76709 L
.39802 .76416 L
.40345 .75738 L
.40773 .75164 L
.41077 .74767 L
.41744 .73847 L
Mistroke
.41782 .73796 L
.42481 .72824 L
.42716 .72474 L
.4315 .71853 L
.43687 .71043 L
.43796 .70882 L
.4444 .69911 L
.44658 .69559 L
.45062 .68939 L
.45629 .68023 L
.45664 .67968 L
.46272 .66997 L
.46601 .66439 L
.46854 .66026 L
.47433 .65054 L
.47572 .64807 L
.48003 .64083 L
.48543 .63128 L
.48553 .63112 L
.49114 .62141 L
.49514 .61407 L
.49649 .61169 L
.50193 .60198 L
.50486 .59642 L
.50715 .59227 L
.51243 .58256 L
.51457 .57835 L
.51755 .57284 L
.52267 .56313 L
.52428 .55987 L
.5277 .55342 L
.53269 .54371 L
.53399 .54099 L
.53762 .53399 L
.54251 .52428 L
.54371 .52172 L
.54735 .51457 L
.55214 .50486 L
.55342 .50208 L
.55688 .49514 L
.56161 .48543 L
.56313 .48206 L
.56625 .47572 L
.57091 .46601 L
.57284 .46168 L
.57544 .45629 L
.58006 .44658 L
.58256 .44094 L
.58449 .43687 L
.58906 .42716 L
Mistroke
.59227 .41985 L
.59339 .41744 L
.59791 .40773 L
.60198 .39841 L
.60216 .39802 L
.60663 .38831 L
.6109 .37859 L
.61169 .37664 L
.61521 .36888 L
.61951 .35917 L
.62141 .35454 L
.62368 .34946 L
.62798 .33974 L
.63112 .3321 L
.63203 .33003 L
.6363 .32032 L
.64035 .31061 L
.64083 .30934 L
.64451 .30089 L
.64863 .29118 L
.65054 .28627 L
.6526 .28147 L
.65675 .27176 L
.66026 .26288 L
.66061 .26204 L
.66473 .25233 L
.66869 .24262 L
.66997 .23919 L
.6726 .23291 L
.67662 .22319 L
.67968 .21518 L
.68038 .21348 L
.6844 .20377 L
.68826 .19406 L
.68939 .19089 L
.69207 .18434 L
.696 .17463 L
.69911 .16628 L
.69966 .16492 L
.70358 .15521 L
.70738 .14549 L
.70882 .1414 L
.71106 .13578 L
.71493 .12607 L
.71848 .11636 L
.71853 .11621 L
.72232 .10664 L
.72608 .09693 L
.72824 .09075 L
.72962 .08722 L
Mistroke
.73342 .07751 L
.73703 .06779 L
.73796 .065 L
.74063 .05808 L
.74437 .04837 L
.74767 .03897 L
.74779 .03866 L
.75152 .02894 L
.75517 .01923 L
Mfstroke
.5 g
.22475 .98077 m
.23291 .97261 L
.23446 .97106 L
.24262 .9629 L
.24417 .96134 L
.25233 .95319 L
.25389 .95163 L
.26204 .94347 L
.2636 .94192 L
.27176 .93376 L
.27331 .93221 L
.28147 .92405 L
.28302 .92249 L
.29118 .91434 L
.29274 .91278 L
.30089 .90462 L
.30245 .90307 L
.31061 .89491 L
.31216 .89336 L
.32032 .8852 L
.32187 .88364 L
.33003 .87549 L
.3316 .87393 L
.33974 .86577 L
.34132 .86422 L
.34946 .85633 L
.35126 .85451 L
.35917 .84611 L
.36037 .84479 L
.36888 .83516 L
.36895 .83508 L
.37712 .82537 L
.37859 .82355 L
.38493 .81566 L
.38831 .81131 L
.39244 .80594 L
.39802 .79848 L
.39968 .79623 L
.40672 .78652 L
.40773 .78509 L
.41356 .77681 L
.41744 .77116 L
.42022 .76709 L
.42671 .75738 L
.42716 .75671 L
.43308 .74767 L
.43687 .74176 L
.4393 .73796 L
.4454 .72824 L
.44658 .72633 L
.4514 .71853 L
.45629 .71044 L
.45727 .70882 L
.46307 .69911 L
.46601 .6941 L
.46877 .68939 L
.47438 .67968 L
.47572 .67732 L
.47991 .66997 L
.48535 .66026 L
.48543 .66011 L
.49075 .65054 L
.49514 .64249 L
.49605 .64083 L
.50131 .63112 L
.50486 .62446 L
.50649 .62141 L
.51163 .61169 L
.51457 .60603 L
.51669 .60198 L
.52171 .59227 L
.52428 .58722 L
.52667 .58256 L
.53159 .57284 L
.53399 .56803 L
.53645 .56313 L
.54128 .55342 L
.54371 .54846 L
.54605 .54371 L
.5508 .53399 L
.55342 .52853 L
.55548 .52428 L
.56014 .51457 L
.56313 .50824 L
.56474 .50486 L
.56934 .49514 L
.57284 .4876 L
.57386 .48543 L
.57839 .47572 L
.58256 .46662 L
.58284 .46601 L
.5873 .45629 L
.59169 .44658 L
.59227 .44529 L
.59608 .43687 L
.60043 .42716 L
.60198 .42363 L
.60474 .41744 L
.60904 .40773 L
.61169 .40164 L
.61329 .39802 L
.61754 .38831 L
.62141 .37933 L
.62172 .37859 L
.62593 .36888 L
.63008 .35917 L
.63112 .35669 L
.63421 .34946 L
.63833 .33974 L
.64083 .33374 L
.6424 .33003 L
.64648 .32032 L
.65049 .31061 L
.65054 .31048 L
.65453 .30089 L
.65853 .29118 L
.66026 .28692 L
.66249 .28147 L
.66647 .27176 L
.66997 .26304 L
.67037 .26204 L
.67431 .25233 L
.67821 .24262 L
.67968 .23888 L
.68207 .23291 L
.68596 .22319 L
.68939 .21441 L
.68976 .21348 L
.69361 .20377 L
.69742 .19406 L
.69911 .18966 L
.70119 .18434 L
.70498 .17463 L
.7087 .16492 L
.70882 .16461 L
.71246 .15521 L
.7162 .14549 L
.71853 .13929 L
.71987 .13578 L
.72359 .12607 L
.72726 .11636 L
.72824 .11368 L
.73091 .10664 L
.73458 .09693 L
.73796 .08779 L
.73817 .08722 L
.74181 .07751 L
.74543 .06779 L
.74767 .06162 L
.74898 .05808 L
.75259 .04837 L
.75614 .03866 L
.75738 .03519 L
.75967 .02894 L
.76324 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.22475 .98077 m
.23291 .97261 L
.23446 .97106 L
.24262 .9629 L
.24417 .96134 L
.25233 .95319 L
.25389 .95163 L
.26204 .94347 L
.2636 .94192 L
.27176 .93376 L
.27331 .93221 L
.28147 .92405 L
.28302 .92249 L
.29118 .91434 L
.29274 .91278 L
.30089 .90462 L
.30245 .90307 L
.31061 .89491 L
.31216 .89336 L
.32032 .8852 L
.32187 .88364 L
.33003 .87549 L
.3316 .87393 L
.33974 .86577 L
.34132 .86422 L
.34946 .85633 L
.35126 .85451 L
.35917 .84611 L
.36037 .84479 L
.36888 .83516 L
.36895 .83508 L
.37712 .82537 L
.37859 .82355 L
.38493 .81566 L
.38831 .81131 L
.39244 .80594 L
.39802 .79848 L
.39968 .79623 L
.40672 .78652 L
.40773 .78509 L
.41356 .77681 L
.41744 .77116 L
.42022 .76709 L
.42671 .75738 L
.42716 .75671 L
.43308 .74767 L
.43687 .74176 L
.4393 .73796 L
.4454 .72824 L
.44658 .72633 L
Mistroke
.4514 .71853 L
.45629 .71044 L
.45727 .70882 L
.46307 .69911 L
.46601 .6941 L
.46877 .68939 L
.47438 .67968 L
.47572 .67732 L
.47991 .66997 L
.48535 .66026 L
.48543 .66011 L
.49075 .65054 L
.49514 .64249 L
.49605 .64083 L
.50131 .63112 L
.50486 .62446 L
.50649 .62141 L
.51163 .61169 L
.51457 .60603 L
.51669 .60198 L
.52171 .59227 L
.52428 .58722 L
.52667 .58256 L
.53159 .57284 L
.53399 .56803 L
.53645 .56313 L
.54128 .55342 L
.54371 .54846 L
.54605 .54371 L
.5508 .53399 L
.55342 .52853 L
.55548 .52428 L
.56014 .51457 L
.56313 .50824 L
.56474 .50486 L
.56934 .49514 L
.57284 .4876 L
.57386 .48543 L
.57839 .47572 L
.58256 .46662 L
.58284 .46601 L
.5873 .45629 L
.59169 .44658 L
.59227 .44529 L
.59608 .43687 L
.60043 .42716 L
.60198 .42363 L
.60474 .41744 L
.60904 .40773 L
.61169 .40164 L
Mistroke
.61329 .39802 L
.61754 .38831 L
.62141 .37933 L
.62172 .37859 L
.62593 .36888 L
.63008 .35917 L
.63112 .35669 L
.63421 .34946 L
.63833 .33974 L
.64083 .33374 L
.6424 .33003 L
.64648 .32032 L
.65049 .31061 L
.65054 .31048 L
.65453 .30089 L
.65853 .29118 L
.66026 .28692 L
.66249 .28147 L
.66647 .27176 L
.66997 .26304 L
.67037 .26204 L
.67431 .25233 L
.67821 .24262 L
.67968 .23888 L
.68207 .23291 L
.68596 .22319 L
.68939 .21441 L
.68976 .21348 L
.69361 .20377 L
.69742 .19406 L
.69911 .18966 L
.70119 .18434 L
.70498 .17463 L
.7087 .16492 L
.70882 .16461 L
.71246 .15521 L
.7162 .14549 L
.71853 .13929 L
.71987 .13578 L
.72359 .12607 L
.72726 .11636 L
.72824 .11368 L
.73091 .10664 L
.73458 .09693 L
.73796 .08779 L
.73817 .08722 L
.74181 .07751 L
.74543 .06779 L
.74767 .06162 L
.74898 .05808 L
Mistroke
.75259 .04837 L
.75614 .03866 L
.75738 .03519 L
.75967 .02894 L
.76324 .01923 L
Mfstroke
.4 g
.26016 .98077 m
.26204 .97889 L
.26987 .97106 L
.27176 .96917 L
.27959 .96134 L
.28147 .95946 L
.2893 .95163 L
.29118 .94975 L
.29901 .94192 L
.30089 .94004 L
.30872 .93221 L
.31061 .93032 L
.31844 .92249 L
.32032 .92061 L
.32815 .91278 L
.33003 .9109 L
.33792 .90307 L
.33974 .90119 L
.34689 .89336 L
.34946 .89049 L
.35541 .88364 L
.35917 .8792 L
.36354 .87393 L
.36888 .86733 L
.37136 .86422 L
.37859 .85492 L
.37891 .85451 L
.38622 .84479 L
.38831 .84197 L
.39332 .83508 L
.39802 .8285 L
.40022 .82537 L
.40696 .81566 L
.40773 .81453 L
.41354 .80594 L
.41744 .80007 L
.41997 .79623 L
.42627 .78652 L
.42716 .78514 L
.43245 .77681 L
.43687 .76974 L
.43851 .76709 L
.44447 .75738 L
.44658 .75391 L
.45033 .74767 L
.4561 .73796 L
.45629 .73763 L
.46178 .72824 L
.46601 .72093 L
.46738 .71853 L
.4729 .70882 L
.47572 .70381 L
.47834 .69911 L
.48373 .68939 L
.48543 .68629 L
.48903 .67968 L
.49428 .66997 L
.49514 .66837 L
.49946 .66026 L
.5046 .65054 L
.50486 .65005 L
.50967 .64083 L
.51457 .63136 L
.51469 .63112 L
.51966 .62141 L
.52428 .61229 L
.52458 .61169 L
.52945 .60198 L
.53399 .59286 L
.53428 .59227 L
.53906 .58256 L
.54371 .57306 L
.54381 .57284 L
.54851 .56313 L
.55318 .55342 L
.55342 .55291 L
.55779 .54371 L
.56239 .53399 L
.56313 .53241 L
.56693 .52428 L
.57146 .51457 L
.57284 .51157 L
.57593 .50486 L
.58039 .49514 L
.58256 .49039 L
.5848 .48543 L
.58919 .47572 L
.59227 .46888 L
.59354 .46601 L
.59787 .45629 L
.60198 .44704 L
.60218 .44658 L
.60644 .43687 L
.6107 .42716 L
.61169 .42487 L
.6149 .41744 L
.61911 .40773 L
.62141 .40239 L
.62327 .39802 L
.62741 .38831 L
.63112 .3796 L
.63154 .37859 L
.63562 .36888 L
.63971 .35917 L
.64083 .35649 L
.64374 .34946 L
.64779 .33974 L
.65054 .33308 L
.65179 .33003 L
.65577 .32032 L
.65975 .31061 L
.66026 .30937 L
.66368 .30089 L
.66762 .29118 L
.66997 .28536 L
.67151 .28147 L
.6754 .27176 L
.67929 .26204 L
.67968 .26105 L
.68312 .25233 L
.68697 .24262 L
.68939 .23646 L
.69077 .23291 L
.69457 .22319 L
.69837 .21348 L
.69911 .21157 L
.7021 .20377 L
.70587 .19406 L
.70882 .1864 L
.7096 .18434 L
.7133 .17463 L
.71702 .16492 L
.71853 .16095 L
.72068 .15521 L
.72437 .14549 L
.72804 .13578 L
.72824 .13523 L
.73165 .12607 L
.73529 .11636 L
.73796 .10922 L
.7389 .10664 L
.74249 .09693 L
.74609 .08722 L
.74767 .08295 L
.74964 .07751 L
.75321 .06779 L
.75677 .05808 L
.75738 .0564 L
.76027 .04837 L
.76381 .03866 L
.76709 .02959 L
.76732 .02894 L
.77079 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.26016 .98077 m
.26204 .97889 L
.26987 .97106 L
.27176 .96917 L
.27959 .96134 L
.28147 .95946 L
.2893 .95163 L
.29118 .94975 L
.29901 .94192 L
.30089 .94004 L
.30872 .93221 L
.31061 .93032 L
.31844 .92249 L
.32032 .92061 L
.32815 .91278 L
.33003 .9109 L
.33792 .90307 L
.33974 .90119 L
.34689 .89336 L
.34946 .89049 L
.35541 .88364 L
.35917 .8792 L
.36354 .87393 L
.36888 .86733 L
.37136 .86422 L
.37859 .85492 L
.37891 .85451 L
.38622 .84479 L
.38831 .84197 L
.39332 .83508 L
.39802 .8285 L
.40022 .82537 L
.40696 .81566 L
.40773 .81453 L
.41354 .80594 L
.41744 .80007 L
.41997 .79623 L
.42627 .78652 L
.42716 .78514 L
.43245 .77681 L
.43687 .76974 L
.43851 .76709 L
.44447 .75738 L
.44658 .75391 L
.45033 .74767 L
.4561 .73796 L
.45629 .73763 L
.46178 .72824 L
.46601 .72093 L
.46738 .71853 L
Mistroke
.4729 .70882 L
.47572 .70381 L
.47834 .69911 L
.48373 .68939 L
.48543 .68629 L
.48903 .67968 L
.49428 .66997 L
.49514 .66837 L
.49946 .66026 L
.5046 .65054 L
.50486 .65005 L
.50967 .64083 L
.51457 .63136 L
.51469 .63112 L
.51966 .62141 L
.52428 .61229 L
.52458 .61169 L
.52945 .60198 L
.53399 .59286 L
.53428 .59227 L
.53906 .58256 L
.54371 .57306 L
.54381 .57284 L
.54851 .56313 L
.55318 .55342 L
.55342 .55291 L
.55779 .54371 L
.56239 .53399 L
.56313 .53241 L
.56693 .52428 L
.57146 .51457 L
.57284 .51157 L
.57593 .50486 L
.58039 .49514 L
.58256 .49039 L
.5848 .48543 L
.58919 .47572 L
.59227 .46888 L
.59354 .46601 L
.59787 .45629 L
.60198 .44704 L
.60218 .44658 L
.60644 .43687 L
.6107 .42716 L
.61169 .42487 L
.6149 .41744 L
.61911 .40773 L
.62141 .40239 L
.62327 .39802 L
.62741 .38831 L
Mistroke
.63112 .3796 L
.63154 .37859 L
.63562 .36888 L
.63971 .35917 L
.64083 .35649 L
.64374 .34946 L
.64779 .33974 L
.65054 .33308 L
.65179 .33003 L
.65577 .32032 L
.65975 .31061 L
.66026 .30937 L
.66368 .30089 L
.66762 .29118 L
.66997 .28536 L
.67151 .28147 L
.6754 .27176 L
.67929 .26204 L
.67968 .26105 L
.68312 .25233 L
.68697 .24262 L
.68939 .23646 L
.69077 .23291 L
.69457 .22319 L
.69837 .21348 L
.69911 .21157 L
.7021 .20377 L
.70587 .19406 L
.70882 .1864 L
.7096 .18434 L
.7133 .17463 L
.71702 .16492 L
.71853 .16095 L
.72068 .15521 L
.72437 .14549 L
.72804 .13578 L
.72824 .13523 L
.73165 .12607 L
.73529 .11636 L
.73796 .10922 L
.7389 .10664 L
.74249 .09693 L
.74609 .08722 L
.74767 .08295 L
.74964 .07751 L
.75321 .06779 L
.75677 .05808 L
.75738 .0564 L
.76027 .04837 L
.76381 .03866 L
Mistroke
.76709 .02959 L
.76732 .02894 L
.77079 .01923 L
Mfstroke
.3 g
.30383 .98077 m
.31061 .97407 L
.31355 .97106 L
.32032 .96428 L
.32326 .96134 L
.33003 .95457 L
.33323 .95163 L
.33974 .94486 L
.34206 .94192 L
.34915 .93221 L
.34946 .93177 L
.35628 .92249 L
.35917 .91854 L
.36335 .91278 L
.36888 .90511 L
.37034 .90307 L
.37721 .89336 L
.37859 .89138 L
.38394 .88364 L
.38831 .87728 L
.39057 .87393 L
.3971 .86422 L
.39802 .86283 L
.40347 .85451 L
.40773 .84798 L
.40976 .84479 L
.41596 .83508 L
.41744 .83274 L
.42202 .82537 L
.42716 .81711 L
.42803 .81566 L
.43392 .80594 L
.43687 .80107 L
.43972 .79623 L
.44548 .78652 L
.44658 .78465 L
.4511 .77681 L
.45629 .76784 L
.45671 .76709 L
.46219 .75738 L
.46601 .75064 L
.46763 .74767 L
.47301 .73796 L
.47572 .73306 L
.4783 .72824 L
.48358 .71853 L
.48543 .71511 L
.48873 .70882 L
.49391 .69911 L
.49514 .69679 L
.49895 .68939 L
.50403 .67968 L
.50486 .6781 L
.50896 .66997 L
.51396 .66026 L
.51457 .65906 L
.51878 .65054 L
.52369 .64083 L
.52428 .63965 L
.52843 .63112 L
.53325 .62141 L
.53399 .6199 L
.5379 .61169 L
.54265 .60198 L
.54371 .5998 L
.54723 .59227 L
.55189 .58256 L
.55342 .57937 L
.5564 .57284 L
.56099 .56313 L
.56313 .55859 L
.56545 .55342 L
.56995 .54371 L
.57284 .53749 L
.57437 .53399 L
.57879 .52428 L
.58256 .51607 L
.58319 .51457 L
.5875 .50486 L
.5919 .49514 L
.59227 .49432 L
.5961 .48543 L
.60044 .47572 L
.60198 .47225 L
.60461 .46601 L
.60887 .45629 L
.61169 .44987 L
.61303 .44658 L
.61719 .43687 L
.62141 .42719 L
.62142 .42716 L
.62543 .41744 L
.6296 .40773 L
.63112 .40419 L
.63359 .39802 L
.63769 .38831 L
.64083 .38089 L
.64172 .37859 L
.64569 .36888 L
.64976 .35917 L
.65054 .35729 L
.65362 .34946 L
.65763 .33974 L
.66026 .3334 L
.66152 .33003 L
.66542 .32032 L
.6694 .31061 L
.66997 .30922 L
.67315 .30089 L
.67708 .29118 L
.67968 .28474 L
.68088 .28147 L
.68468 .27176 L
.68857 .26204 L
.68939 .25998 L
.69223 .25233 L
.69607 .24262 L
.69911 .23494 L
.69982 .23291 L
.70349 .22319 L
.70731 .21348 L
.70882 .20962 L
.71091 .20377 L
.71464 .19406 L
.71841 .18434 L
.71853 .18403 L
.72192 .17463 L
.72565 .16492 L
.72824 .15815 L
.72924 .15521 L
.73282 .14549 L
.73653 .13578 L
.73796 .13201 L
.73999 .12607 L
.74361 .11636 L
.74728 .10664 L
.74767 .1056 L
.75067 .09693 L
.75428 .08722 L
.75738 .07892 L
.75783 .07751 L
.76124 .06779 L
.76484 .05808 L
.76709 .05198 L
.76826 .04837 L
.77171 .03866 L
.77529 .02894 L
.77681 .0248 L
.77861 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.30383 .98077 m
.31061 .97407 L
.31355 .97106 L
.32032 .96428 L
.32326 .96134 L
.33003 .95457 L
.33323 .95163 L
.33974 .94486 L
.34206 .94192 L
.34915 .93221 L
.34946 .93177 L
.35628 .92249 L
.35917 .91854 L
.36335 .91278 L
.36888 .90511 L
.37034 .90307 L
.37721 .89336 L
.37859 .89138 L
.38394 .88364 L
.38831 .87728 L
.39057 .87393 L
.3971 .86422 L
.39802 .86283 L
.40347 .85451 L
.40773 .84798 L
.40976 .84479 L
.41596 .83508 L
.41744 .83274 L
.42202 .82537 L
.42716 .81711 L
.42803 .81566 L
.43392 .80594 L
.43687 .80107 L
.43972 .79623 L
.44548 .78652 L
.44658 .78465 L
.4511 .77681 L
.45629 .76784 L
.45671 .76709 L
.46219 .75738 L
.46601 .75064 L
.46763 .74767 L
.47301 .73796 L
.47572 .73306 L
.4783 .72824 L
.48358 .71853 L
.48543 .71511 L
.48873 .70882 L
.49391 .69911 L
.49514 .69679 L
Mistroke
.49895 .68939 L
.50403 .67968 L
.50486 .6781 L
.50896 .66997 L
.51396 .66026 L
.51457 .65906 L
.51878 .65054 L
.52369 .64083 L
.52428 .63965 L
.52843 .63112 L
.53325 .62141 L
.53399 .6199 L
.5379 .61169 L
.54265 .60198 L
.54371 .5998 L
.54723 .59227 L
.55189 .58256 L
.55342 .57937 L
.5564 .57284 L
.56099 .56313 L
.56313 .55859 L
.56545 .55342 L
.56995 .54371 L
.57284 .53749 L
.57437 .53399 L
.57879 .52428 L
.58256 .51607 L
.58319 .51457 L
.5875 .50486 L
.5919 .49514 L
.59227 .49432 L
.5961 .48543 L
.60044 .47572 L
.60198 .47225 L
.60461 .46601 L
.60887 .45629 L
.61169 .44987 L
.61303 .44658 L
.61719 .43687 L
.62141 .42719 L
.62142 .42716 L
.62543 .41744 L
.6296 .40773 L
.63112 .40419 L
.63359 .39802 L
.63769 .38831 L
.64083 .38089 L
.64172 .37859 L
.64569 .36888 L
.64976 .35917 L
Mistroke
.65054 .35729 L
.65362 .34946 L
.65763 .33974 L
.66026 .3334 L
.66152 .33003 L
.66542 .32032 L
.6694 .31061 L
.66997 .30922 L
.67315 .30089 L
.67708 .29118 L
.67968 .28474 L
.68088 .28147 L
.68468 .27176 L
.68857 .26204 L
.68939 .25998 L
.69223 .25233 L
.69607 .24262 L
.69911 .23494 L
.69982 .23291 L
.70349 .22319 L
.70731 .21348 L
.70882 .20962 L
.71091 .20377 L
.71464 .19406 L
.71841 .18434 L
.71853 .18403 L
.72192 .17463 L
.72565 .16492 L
.72824 .15815 L
.72924 .15521 L
.73282 .14549 L
.73653 .13578 L
.73796 .13201 L
.73999 .12607 L
.74361 .11636 L
.74728 .10664 L
.74767 .1056 L
.75067 .09693 L
.75428 .08722 L
.75738 .07892 L
.75783 .07751 L
.76124 .06779 L
.76484 .05808 L
.76709 .05198 L
.76826 .04837 L
.77171 .03866 L
.77529 .02894 L
.77681 .0248 L
.77861 .01923 L
Mfstroke
.4 g
.38555 .98077 m
.38831 .97726 L
.39368 .97106 L
.39802 .96554 L
.40141 .96134 L
.40773 .95301 L
.40879 .95163 L
.41603 .94192 L
.41744 .93987 L
.42301 .93221 L
.42716 .92612 L
.42971 .92249 L
.43626 .91278 L
.43687 .91181 L
.44274 .90307 L
.44658 .89697 L
.44894 .89336 L
.45509 .88364 L
.45629 .88162 L
.46114 .87393 L
.46601 .86577 L
.46696 .86422 L
.47284 .85451 L
.47572 .84945 L
.4785 .84479 L
.48412 .83508 L
.48543 .83267 L
.48967 .82537 L
.49503 .81566 L
.49514 .81544 L
.50051 .80594 L
.50486 .7978 L
.50572 .79623 L
.51106 .78652 L
.51457 .77973 L
.51615 .77681 L
.52135 .76709 L
.52428 .76125 L
.52633 .75738 L
.5314 .74767 L
.53399 .74237 L
.53629 .73796 L
.54125 .72824 L
.54371 .72311 L
.54604 .71853 L
.55091 .70882 L
.55342 .70346 L
.5556 .69911 L
.56039 .68939 L
.56313 .68345 L
.56498 .67968 L
.5697 .66997 L
.57284 .66306 L
.5742 .66026 L
.57886 .65054 L
.58256 .64232 L
.58326 .64083 L
.58786 .63112 L
.5922 .62141 L
.59227 .62123 L
.59672 .61169 L
.60108 .60198 L
.60198 .5998 L
.60545 .59227 L
.60981 .58256 L
.61169 .57803 L
.61404 .57284 L
.6184 .56313 L
.62141 .55592 L
.62252 .55342 L
.62685 .54371 L
.63092 .53399 L
.63112 .53348 L
.63518 .52428 L
.63933 .51457 L
.64083 .51073 L
.64339 .50486 L
.64756 .49514 L
.65054 .48765 L
.6515 .48543 L
.65566 .47572 L
.65961 .46601 L
.66026 .46427 L
.66364 .45629 L
.66768 .44658 L
.66997 .44057 L
.67152 .43687 L
.67557 .42716 L
.67937 .41744 L
.67968 .41657 L
.68334 .40773 L
.68727 .39802 L
.68939 .39227 L
.69101 .38831 L
.69497 .37859 L
.69869 .36888 L
.69911 .36767 L
.70254 .35917 L
.7064 .34946 L
.70882 .34278 L
.71003 .33974 L
.71391 .33003 L
.7176 .32032 L
.71853 .3176 L
.7213 .31061 L
.72511 .30089 L
.72824 .29213 L
.72861 .29118 L
.73242 .28147 L
.73612 .27176 L
.73796 .26639 L
.73963 .26204 L
.74339 .25233 L
.74694 .24262 L
.74767 .24036 L
.75052 .23291 L
.75422 .22319 L
.75738 .21405 L
.7576 .21348 L
.76129 .20377 L
.7649 .19406 L
.76709 .18747 L
.76827 .18434 L
.77192 .17463 L
.77544 .16492 L
.77681 .16063 L
.77882 .15521 L
.78244 .14549 L
.78583 .13578 L
.78652 .13351 L
.78926 .12607 L
.79283 .11636 L
.79608 .10664 L
.79623 .10612 L
.7996 .09693 L
.80312 .08722 L
.80594 .07848 L
.80629 .07751 L
.80982 .06779 L
.81329 .05808 L
.81566 .05058 L
.81645 .04837 L
.81995 .03866 L
.82336 .02894 L
.82537 .02241 L
.8265 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.38555 .98077 m
.38831 .97726 L
.39368 .97106 L
.39802 .96554 L
.40141 .96134 L
.40773 .95301 L
.40879 .95163 L
.41603 .94192 L
.41744 .93987 L
.42301 .93221 L
.42716 .92612 L
.42971 .92249 L
.43626 .91278 L
.43687 .91181 L
.44274 .90307 L
.44658 .89697 L
.44894 .89336 L
.45509 .88364 L
.45629 .88162 L
.46114 .87393 L
.46601 .86577 L
.46696 .86422 L
.47284 .85451 L
.47572 .84945 L
.4785 .84479 L
.48412 .83508 L
.48543 .83267 L
.48967 .82537 L
.49503 .81566 L
.49514 .81544 L
.50051 .80594 L
.50486 .7978 L
.50572 .79623 L
.51106 .78652 L
.51457 .77973 L
.51615 .77681 L
.52135 .76709 L
.52428 .76125 L
.52633 .75738 L
.5314 .74767 L
.53399 .74237 L
.53629 .73796 L
.54125 .72824 L
.54371 .72311 L
.54604 .71853 L
.55091 .70882 L
.55342 .70346 L
.5556 .69911 L
.56039 .68939 L
.56313 .68345 L
Mistroke
.56498 .67968 L
.5697 .66997 L
.57284 .66306 L
.5742 .66026 L
.57886 .65054 L
.58256 .64232 L
.58326 .64083 L
.58786 .63112 L
.5922 .62141 L
.59227 .62123 L
.59672 .61169 L
.60108 .60198 L
.60198 .5998 L
.60545 .59227 L
.60981 .58256 L
.61169 .57803 L
.61404 .57284 L
.6184 .56313 L
.62141 .55592 L
.62252 .55342 L
.62685 .54371 L
.63092 .53399 L
.63112 .53348 L
.63518 .52428 L
.63933 .51457 L
.64083 .51073 L
.64339 .50486 L
.64756 .49514 L
.65054 .48765 L
.6515 .48543 L
.65566 .47572 L
.65961 .46601 L
.66026 .46427 L
.66364 .45629 L
.66768 .44658 L
.66997 .44057 L
.67152 .43687 L
.67557 .42716 L
.67937 .41744 L
.67968 .41657 L
.68334 .40773 L
.68727 .39802 L
.68939 .39227 L
.69101 .38831 L
.69497 .37859 L
.69869 .36888 L
.69911 .36767 L
.70254 .35917 L
.7064 .34946 L
.70882 .34278 L
Mistroke
.71003 .33974 L
.71391 .33003 L
.7176 .32032 L
.71853 .3176 L
.7213 .31061 L
.72511 .30089 L
.72824 .29213 L
.72861 .29118 L
.73242 .28147 L
.73612 .27176 L
.73796 .26639 L
.73963 .26204 L
.74339 .25233 L
.74694 .24262 L
.74767 .24036 L
.75052 .23291 L
.75422 .22319 L
.75738 .21405 L
.7576 .21348 L
.76129 .20377 L
.7649 .19406 L
.76709 .18747 L
.76827 .18434 L
.77192 .17463 L
.77544 .16492 L
.77681 .16063 L
.77882 .15521 L
.78244 .14549 L
.78583 .13578 L
.78652 .13351 L
.78926 .12607 L
.79283 .11636 L
.79608 .10664 L
.79623 .10612 L
.7996 .09693 L
.80312 .08722 L
.80594 .07848 L
.80629 .07751 L
.80982 .06779 L
.81329 .05808 L
.81566 .05058 L
.81645 .04837 L
.81995 .03866 L
.82336 .02894 L
.82537 .02241 L
.8265 .01923 L
Mfstroke
.5 g
.41177 .98077 m
.41744 .97254 L
.41846 .97106 L
.42501 .96134 L
.42716 .95809 L
.43141 .95163 L
.43687 .94314 L
.43765 .94192 L
.4438 .93221 L
.44658 .92772 L
.44982 .92249 L
.45572 .91278 L
.45629 .91183 L
.46155 .90307 L
.46601 .89548 L
.46726 .89336 L
.4729 .88364 L
.47572 .8787 L
.47845 .87393 L
.48392 .86422 L
.48543 .8615 L
.48932 .85451 L
.49465 .84479 L
.49514 .84387 L
.49992 .83508 L
.50486 .82584 L
.50511 .82537 L
.51027 .81566 L
.51457 .80742 L
.51534 .80594 L
.52039 .79623 L
.52428 .7886 L
.52535 .78652 L
.53029 .77681 L
.53399 .76941 L
.53516 .76709 L
.54001 .75738 L
.54371 .74985 L
.54478 .74767 L
.54954 .73796 L
.55342 .72992 L
.55423 .72824 L
.55891 .71853 L
.56313 .70963 L
.56352 .70882 L
.56812 .69911 L
.57266 .68939 L
.57284 .68899 L
.57719 .67968 L
.58166 .66997 L
.58256 .668 L
.58612 .66026 L
.59054 .65054 L
.59227 .64668 L
.59492 .64083 L
.59928 .63112 L
.60198 .62502 L
.60359 .62141 L
.60791 .61169 L
.61169 .60302 L
.61215 .60198 L
.61642 .59227 L
.62062 .58256 L
.62141 .58071 L
.62481 .57284 L
.62899 .56313 L
.63112 .55808 L
.63311 .55342 L
.63725 .54371 L
.64083 .53513 L
.64131 .53399 L
.6454 .52428 L
.64944 .51457 L
.65054 .51187 L
.65346 .50486 L
.65748 .49514 L
.66026 .4883 L
.66143 .48543 L
.66542 .47572 L
.66934 .46601 L
.66997 .46443 L
.67327 .45629 L
.67719 .44658 L
.67968 .44026 L
.68104 .43687 L
.68493 .42716 L
.68876 .41744 L
.68939 .4158 L
.69259 .40773 L
.69642 .39802 L
.69911 .39104 L
.70018 .38831 L
.70398 .37859 L
.70773 .36888 L
.70882 .366 L
.71146 .35917 L
.71521 .34946 L
.71853 .34067 L
.71889 .33974 L
.72261 .33003 L
.72629 .32032 L
.72824 .31506 L
.72993 .31061 L
.73361 .30089 L
.73722 .29118 L
.73796 .28917 L
.74084 .28147 L
.74447 .27176 L
.74767 .26301 L
.74803 .26204 L
.75163 .25233 L
.75521 .24262 L
.75738 .23657 L
.75873 .23291 L
.76229 .22319 L
.76582 .21348 L
.76709 .20987 L
.76931 .20377 L
.77284 .19406 L
.7763 .18434 L
.77681 .18289 L
.77978 .17463 L
.78327 .16492 L
.78652 .15565 L
.78668 .15521 L
.79014 .14549 L
.79359 .13578 L
.79623 .12816 L
.79697 .12607 L
.8004 .11636 L
.80381 .10664 L
.80594 .1004 L
.80715 .09693 L
.81056 .08722 L
.81393 .07751 L
.81566 .07238 L
.81725 .06779 L
.82062 .05808 L
.82395 .04837 L
.82537 .04411 L
.82724 .03866 L
.83059 .02894 L
.83388 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.41177 .98077 m
.41744 .97254 L
.41846 .97106 L
.42501 .96134 L
.42716 .95809 L
.43141 .95163 L
.43687 .94314 L
.43765 .94192 L
.4438 .93221 L
.44658 .92772 L
.44982 .92249 L
.45572 .91278 L
.45629 .91183 L
.46155 .90307 L
.46601 .89548 L
.46726 .89336 L
.4729 .88364 L
.47572 .8787 L
.47845 .87393 L
.48392 .86422 L
.48543 .8615 L
.48932 .85451 L
.49465 .84479 L
.49514 .84387 L
.49992 .83508 L
.50486 .82584 L
.50511 .82537 L
.51027 .81566 L
.51457 .80742 L
.51534 .80594 L
.52039 .79623 L
.52428 .7886 L
.52535 .78652 L
.53029 .77681 L
.53399 .76941 L
.53516 .76709 L
.54001 .75738 L
.54371 .74985 L
.54478 .74767 L
.54954 .73796 L
.55342 .72992 L
.55423 .72824 L
.55891 .71853 L
.56313 .70963 L
.56352 .70882 L
.56812 .69911 L
.57266 .68939 L
.57284 .68899 L
.57719 .67968 L
.58166 .66997 L
Mistroke
.58256 .668 L
.58612 .66026 L
.59054 .65054 L
.59227 .64668 L
.59492 .64083 L
.59928 .63112 L
.60198 .62502 L
.60359 .62141 L
.60791 .61169 L
.61169 .60302 L
.61215 .60198 L
.61642 .59227 L
.62062 .58256 L
.62141 .58071 L
.62481 .57284 L
.62899 .56313 L
.63112 .55808 L
.63311 .55342 L
.63725 .54371 L
.64083 .53513 L
.64131 .53399 L
.6454 .52428 L
.64944 .51457 L
.65054 .51187 L
.65346 .50486 L
.65748 .49514 L
.66026 .4883 L
.66143 .48543 L
.66542 .47572 L
.66934 .46601 L
.66997 .46443 L
.67327 .45629 L
.67719 .44658 L
.67968 .44026 L
.68104 .43687 L
.68493 .42716 L
.68876 .41744 L
.68939 .4158 L
.69259 .40773 L
.69642 .39802 L
.69911 .39104 L
.70018 .38831 L
.70398 .37859 L
.70773 .36888 L
.70882 .366 L
.71146 .35917 L
.71521 .34946 L
.71853 .34067 L
.71889 .33974 L
.72261 .33003 L
Mistroke
.72629 .32032 L
.72824 .31506 L
.72993 .31061 L
.73361 .30089 L
.73722 .29118 L
.73796 .28917 L
.74084 .28147 L
.74447 .27176 L
.74767 .26301 L
.74803 .26204 L
.75163 .25233 L
.75521 .24262 L
.75738 .23657 L
.75873 .23291 L
.76229 .22319 L
.76582 .21348 L
.76709 .20987 L
.76931 .20377 L
.77284 .19406 L
.7763 .18434 L
.77681 .18289 L
.77978 .17463 L
.78327 .16492 L
.78652 .15565 L
.78668 .15521 L
.79014 .14549 L
.79359 .13578 L
.79623 .12816 L
.79697 .12607 L
.8004 .11636 L
.80381 .10664 L
.80594 .1004 L
.80715 .09693 L
.81056 .08722 L
.81393 .07751 L
.81566 .07238 L
.81725 .06779 L
.82062 .05808 L
.82395 .04837 L
.82537 .04411 L
.82724 .03866 L
.83059 .02894 L
.83388 .01923 L
Mfstroke
.6 g
.43082 .98077 m
.43687 .97113 L
.43691 .97106 L
.4429 .96134 L
.44658 .95529 L
.44878 .95163 L
.45458 .94192 L
.45629 .93901 L
.46028 .93221 L
.4659 .92249 L
.46601 .92231 L
.47144 .91278 L
.47572 .90519 L
.47691 .90307 L
.4823 .89336 L
.48543 .88767 L
.48763 .88364 L
.4929 .87393 L
.49514 .86975 L
.49809 .86422 L
.50324 .85451 L
.50486 .85144 L
.50832 .84479 L
.51337 .83508 L
.51457 .83275 L
.51834 .82537 L
.52328 .81566 L
.52428 .81368 L
.52816 .80594 L
.53301 .79623 L
.53399 .79424 L
.5378 .78652 L
.54256 .77681 L
.54371 .77445 L
.54726 .76709 L
.55194 .75738 L
.55342 .7543 L
.55657 .74767 L
.56117 .73796 L
.56313 .7338 L
.56572 .72824 L
.57026 .71853 L
.57284 .71295 L
.57474 .70882 L
.57921 .69911 L
.58256 .69177 L
.58363 .68939 L
.58802 .67968 L
.59227 .67026 L
.5924 .66997 L
.59672 .66026 L
.60104 .65054 L
.60198 .64842 L
.60531 .64083 L
.60957 .63112 L
.61169 .62626 L
.61379 .62141 L
.61799 .61169 L
.62141 .60378 L
.62217 .60198 L
.62631 .59227 L
.63045 .58256 L
.63112 .58098 L
.63454 .57284 L
.63863 .56313 L
.64083 .55788 L
.64267 .55342 L
.64671 .54371 L
.65054 .53447 L
.65074 .53399 L
.65471 .52428 L
.6587 .51457 L
.66026 .51075 L
.66263 .50486 L
.66657 .49514 L
.66997 .48674 L
.67049 .48543 L
.67437 .47572 L
.67826 .46601 L
.67968 .46244 L
.6821 .45629 L
.68594 .44658 L
.68939 .43784 L
.68977 .43687 L
.69356 .42716 L
.69736 .41744 L
.69911 .41296 L
.70111 .40773 L
.70487 .39802 L
.70862 .38831 L
.70882 .38779 L
.71231 .37859 L
.71604 .36888 L
.71853 .36234 L
.71971 .35917 L
.72339 .34946 L
.72707 .33974 L
.72824 .33661 L
.73068 .33003 L
.73433 .32032 L
.73796 .31061 L
.73796 .31061 L
.74153 .30089 L
.74514 .29118 L
.74767 .28433 L
.7487 .28147 L
.75226 .27176 L
.75583 .26204 L
.75738 .25778 L
.75934 .25233 L
.76287 .24262 L
.7664 .23291 L
.76709 .23097 L
.76986 .22319 L
.77337 .21348 L
.77681 .2039 L
.77685 .20377 L
.78028 .19406 L
.78375 .18434 L
.78652 .17656 L
.78718 .17463 L
.79059 .16492 L
.79404 .15521 L
.79623 .14896 L
.79742 .14549 L
.80081 .13578 L
.80422 .12607 L
.80594 .1211 L
.80756 .11636 L
.81092 .10664 L
.8143 .09693 L
.81566 .09299 L
.8176 .08722 L
.82095 .07751 L
.82429 .06779 L
.82537 .06463 L
.82756 .05808 L
.83088 .04837 L
.83419 .03866 L
.83508 .03602 L
.83743 .02894 L
.84072 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.43082 .98077 m
.43687 .97113 L
.43691 .97106 L
.4429 .96134 L
.44658 .95529 L
.44878 .95163 L
.45458 .94192 L
.45629 .93901 L
.46028 .93221 L
.4659 .92249 L
.46601 .92231 L
.47144 .91278 L
.47572 .90519 L
.47691 .90307 L
.4823 .89336 L
.48543 .88767 L
.48763 .88364 L
.4929 .87393 L
.49514 .86975 L
.49809 .86422 L
.50324 .85451 L
.50486 .85144 L
.50832 .84479 L
.51337 .83508 L
.51457 .83275 L
.51834 .82537 L
.52328 .81566 L
.52428 .81368 L
.52816 .80594 L
.53301 .79623 L
.53399 .79424 L
.5378 .78652 L
.54256 .77681 L
.54371 .77445 L
.54726 .76709 L
.55194 .75738 L
.55342 .7543 L
.55657 .74767 L
.56117 .73796 L
.56313 .7338 L
.56572 .72824 L
.57026 .71853 L
.57284 .71295 L
.57474 .70882 L
.57921 .69911 L
.58256 .69177 L
.58363 .68939 L
.58802 .67968 L
.59227 .67026 L
.5924 .66997 L
Mistroke
.59672 .66026 L
.60104 .65054 L
.60198 .64842 L
.60531 .64083 L
.60957 .63112 L
.61169 .62626 L
.61379 .62141 L
.61799 .61169 L
.62141 .60378 L
.62217 .60198 L
.62631 .59227 L
.63045 .58256 L
.63112 .58098 L
.63454 .57284 L
.63863 .56313 L
.64083 .55788 L
.64267 .55342 L
.64671 .54371 L
.65054 .53447 L
.65074 .53399 L
.65471 .52428 L
.6587 .51457 L
.66026 .51075 L
.66263 .50486 L
.66657 .49514 L
.66997 .48674 L
.67049 .48543 L
.67437 .47572 L
.67826 .46601 L
.67968 .46244 L
.6821 .45629 L
.68594 .44658 L
.68939 .43784 L
.68977 .43687 L
.69356 .42716 L
.69736 .41744 L
.69911 .41296 L
.70111 .40773 L
.70487 .39802 L
.70862 .38831 L
.70882 .38779 L
.71231 .37859 L
.71604 .36888 L
.71853 .36234 L
.71971 .35917 L
.72339 .34946 L
.72707 .33974 L
.72824 .33661 L
.73068 .33003 L
.73433 .32032 L
Mistroke
.73796 .31061 L
.73796 .31061 L
.74153 .30089 L
.74514 .29118 L
.74767 .28433 L
.7487 .28147 L
.75226 .27176 L
.75583 .26204 L
.75738 .25778 L
.75934 .25233 L
.76287 .24262 L
.7664 .23291 L
.76709 .23097 L
.76986 .22319 L
.77337 .21348 L
.77681 .2039 L
.77685 .20377 L
.78028 .19406 L
.78375 .18434 L
.78652 .17656 L
.78718 .17463 L
.79059 .16492 L
.79404 .15521 L
.79623 .14896 L
.79742 .14549 L
.80081 .13578 L
.80422 .12607 L
.80594 .1211 L
.80756 .11636 L
.81092 .10664 L
.8143 .09693 L
.81566 .09299 L
.8176 .08722 L
.82095 .07751 L
.82429 .06779 L
.82537 .06463 L
.82756 .05808 L
.83088 .04837 L
.83419 .03866 L
.83508 .03602 L
.83743 .02894 L
.84072 .01923 L
Mfstroke
.7 g
.44961 .98077 m
.45524 .97106 L
.45629 .96923 L
.46073 .96134 L
.46601 .95203 L
.46622 .95163 L
.47158 .94192 L
.47572 .93445 L
.47691 .93221 L
.48217 .92249 L
.48543 .91649 L
.48737 .91278 L
.49254 .90307 L
.49514 .89817 L
.49761 .89336 L
.50269 .88364 L
.50486 .87948 L
.50764 .87393 L
.51263 .86422 L
.51457 .86043 L
.51749 .85451 L
.52239 .84479 L
.52428 .84103 L
.52716 .83508 L
.53197 .82537 L
.53399 .82128 L
.53666 .81566 L
.54139 .80594 L
.54371 .80118 L
.546 .79623 L
.55065 .78652 L
.55342 .78075 L
.55521 .77681 L
.55977 .76709 L
.56313 .75998 L
.56428 .75738 L
.56875 .74767 L
.57284 .73888 L
.57324 .73796 L
.5776 .72824 L
.58207 .71853 L
.58256 .71746 L
.58634 .70882 L
.59073 .69911 L
.59227 .6957 L
.59496 .68939 L
.59929 .67968 L
.60198 .67363 L
.6035 .66997 L
.60773 .66026 L
.61169 .65126 L
.61198 .65054 L
.61607 .64083 L
.6203 .63112 L
.62141 .62857 L
.62433 .62141 L
.62849 .61169 L
.63112 .60557 L
.63254 .60198 L
.63659 .59227 L
.64071 .58256 L
.64083 .58228 L
.64461 .57284 L
.64868 .56313 L
.65054 .55867 L
.65258 .55342 L
.65656 .54371 L
.66026 .53479 L
.66055 .53399 L
.66437 .52428 L
.66835 .51457 L
.66997 .5106 L
.67213 .50486 L
.67603 .49514 L
.67968 .48613 L
.67993 .48543 L
.68365 .47572 L
.68754 .46601 L
.68939 .46137 L
.69124 .45629 L
.69504 .44658 L
.69889 .43687 L
.69911 .43633 L
.70249 .42716 L
.7063 .41744 L
.70882 .411 L
.70996 .40773 L
.71363 .39802 L
.71741 .38831 L
.71853 .38541 L
.72095 .37859 L
.72465 .36888 L
.72824 .35954 L
.72837 .35917 L
.73184 .34946 L
.73554 .33974 L
.73796 .33339 L
.73908 .33003 L
.74264 .32032 L
.74631 .31061 L
.74767 .30698 L
.74973 .30089 L
.75332 .29118 L
.75695 .28147 L
.75738 .28031 L
.7603 .27176 L
.76388 .26204 L
.76709 .25337 L
.76742 .25233 L
.77077 .24262 L
.77434 .23291 L
.77681 .22616 L
.77774 .22319 L
.78114 .21348 L
.78468 .20377 L
.78652 .1987 L
.78799 .19406 L
.79141 .18434 L
.79493 .17463 L
.79623 .17099 L
.79816 .16492 L
.80158 .15521 L
.80507 .14549 L
.80594 .14302 L
.80824 .13578 L
.81166 .12607 L
.81511 .11636 L
.81566 .1148 L
.81824 .10664 L
.82164 .09693 L
.82506 .08722 L
.82537 .08632 L
.82815 .07751 L
.83152 .06779 L
.83492 .05808 L
.83508 .0576 L
.83797 .04837 L
.84133 .03866 L
.84469 .02894 L
.84479 .02864 L
.84771 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.44961 .98077 m
.45524 .97106 L
.45629 .96923 L
.46073 .96134 L
.46601 .95203 L
.46622 .95163 L
.47158 .94192 L
.47572 .93445 L
.47691 .93221 L
.48217 .92249 L
.48543 .91649 L
.48737 .91278 L
.49254 .90307 L
.49514 .89817 L
.49761 .89336 L
.50269 .88364 L
.50486 .87948 L
.50764 .87393 L
.51263 .86422 L
.51457 .86043 L
.51749 .85451 L
.52239 .84479 L
.52428 .84103 L
.52716 .83508 L
.53197 .82537 L
.53399 .82128 L
.53666 .81566 L
.54139 .80594 L
.54371 .80118 L
.546 .79623 L
.55065 .78652 L
.55342 .78075 L
.55521 .77681 L
.55977 .76709 L
.56313 .75998 L
.56428 .75738 L
.56875 .74767 L
.57284 .73888 L
.57324 .73796 L
.5776 .72824 L
.58207 .71853 L
.58256 .71746 L
.58634 .70882 L
.59073 .69911 L
.59227 .6957 L
.59496 .68939 L
.59929 .67968 L
.60198 .67363 L
.6035 .66997 L
.60773 .66026 L
Mistroke
.61169 .65126 L
.61198 .65054 L
.61607 .64083 L
.6203 .63112 L
.62141 .62857 L
.62433 .62141 L
.62849 .61169 L
.63112 .60557 L
.63254 .60198 L
.63659 .59227 L
.64071 .58256 L
.64083 .58228 L
.64461 .57284 L
.64868 .56313 L
.65054 .55867 L
.65258 .55342 L
.65656 .54371 L
.66026 .53479 L
.66055 .53399 L
.66437 .52428 L
.66835 .51457 L
.66997 .5106 L
.67213 .50486 L
.67603 .49514 L
.67968 .48613 L
.67993 .48543 L
.68365 .47572 L
.68754 .46601 L
.68939 .46137 L
.69124 .45629 L
.69504 .44658 L
.69889 .43687 L
.69911 .43633 L
.70249 .42716 L
.7063 .41744 L
.70882 .411 L
.70996 .40773 L
.71363 .39802 L
.71741 .38831 L
.71853 .38541 L
.72095 .37859 L
.72465 .36888 L
.72824 .35954 L
.72837 .35917 L
.73184 .34946 L
.73554 .33974 L
.73796 .33339 L
.73908 .33003 L
.74264 .32032 L
.74631 .31061 L
Mistroke
.74767 .30698 L
.74973 .30089 L
.75332 .29118 L
.75695 .28147 L
.75738 .28031 L
.7603 .27176 L
.76388 .26204 L
.76709 .25337 L
.76742 .25233 L
.77077 .24262 L
.77434 .23291 L
.77681 .22616 L
.77774 .22319 L
.78114 .21348 L
.78468 .20377 L
.78652 .1987 L
.78799 .19406 L
.79141 .18434 L
.79493 .17463 L
.79623 .17099 L
.79816 .16492 L
.80158 .15521 L
.80507 .14549 L
.80594 .14302 L
.80824 .13578 L
.81166 .12607 L
.81511 .11636 L
.81566 .1148 L
.81824 .10664 L
.82164 .09693 L
.82506 .08722 L
.82537 .08632 L
.82815 .07751 L
.83152 .06779 L
.83492 .05808 L
.83508 .0576 L
.83797 .04837 L
.84133 .03866 L
.84469 .02894 L
.84479 .02864 L
.84771 .01923 L
Mfstroke
.8 g
.50486 .52828 m
.51224 .53399 L
.50568 .54371 L
.50486 .54485 L
.49901 .54371 L
.50257 .53399 L
F
0 g
.50486 .52828 m
.51224 .53399 L
.50568 .54371 L
.50486 .54485 L
.49901 .54371 L
.50257 .53399 L
.50486 .52828 L
s
.2 g
.50486 .32689 m
.51391 .33003 L
.50748 .33974 L
.50486 .34347 L
.49989 .33974 L
.50359 .33003 L
F
0 g
.50486 .32689 m
.51391 .33003 L
.50748 .33974 L
.50486 .34347 L
.49989 .33974 L
.50359 .33003 L
.50486 .32689 L
s
.8 g
.8854 .01923 m
.88364 .02358 L
.88187 .02894 L
.88066 .03866 L
.87584 .04837 L
.87393 .05311 L
.87226 .05808 L
.87108 .06779 L
.86619 .07751 L
.86422 .08233 L
.86256 .08722 L
.86134 .09693 L
.85642 .10664 L
.85451 .11131 L
.85278 .11636 L
.85146 .12607 L
.84654 .13578 L
.84479 .14002 L
.8429 .14549 L
.84142 .15521 L
.83655 .16492 L
.83508 .16848 L
.83294 .17463 L
.83123 .18434 L
.82645 .19406 L
.82537 .19667 L
.82288 .20377 L
.82091 .21348 L
.81624 .22319 L
.81566 .2246 L
.81272 .23291 L
.81045 .24262 L
.80594 .25226 L
.80592 .25233 L
.80246 .26204 L
.79988 .27176 L
.79623 .27969 L
.79558 .28147 L
.79209 .29118 L
.7892 .30089 L
.78652 .30684 L
.78513 .31061 L
.78161 .32032 L
.77843 .33003 L
.77681 .33369 L
.77457 .33974 L
.77254 .34946 L
.76756 .35917 L
.76709 .36024 L
.76389 .36888 L
.76126 .37859 L
.75738 .38657 L
.75671 .38831 L
.75308 .39802 L
.74995 .40773 L
.74767 .41259 L
.74581 .41744 L
.74393 .42716 L
.7386 .43687 L
.73796 .43828 L
.73477 .44658 L
.73202 .45629 L
.72824 .46375 L
.72735 .46601 L
.72359 .47572 L
.72019 .48543 L
.71853 .48888 L
.71605 .49514 L
.71362 .50486 L
.70882 .51369 L
.70846 .51457 L
.7046 .52428 L
.70125 .53399 L
.69911 .53825 L
.69689 .54371 L
.69455 .55342 L
.68939 .56243 L
.68909 .56313 L
.68514 .57284 L
.68165 .58256 L
.67968 .58635 L
.67721 .59227 L
.67462 .60198 L
.66997 .60993 L
.6692 .61169 L
.66514 .62141 L
.66132 .63112 L
.66026 .63314 L
.65697 .64083 L
.65377 .65054 L
.65054 .6561 L
.64871 .66026 L
.64453 .66997 L
.64083 .67863 L
.64034 .67968 L
.63609 .68939 L
.63207 .69911 L
.63112 .70081 L
.62753 .70882 L
.62399 .71853 L
.62141 .72271 L
.61885 .72824 L
.61446 .73796 L
.61169 .74422 L
.61004 .74767 L
.60556 .75738 L
.60198 .7653 L
.60107 .76709 L
.59651 .77681 L
.59227 .78592 L
.59194 .78652 L
.58728 .79623 L
.58265 .80594 L
.58256 .8061 L
.57787 .81566 L
.57324 .82537 L
.57284 .82594 L
.56825 .83508 L
.56351 .84479 L
.56313 .8453 L
.55838 .85451 L
.55342 .86417 L
.55337 .86422 L
.54823 .87393 L
.54371 .88303 L
.54305 .88364 L
.53774 .89336 L
.53399 .90135 L
.53234 .90307 L
.52679 .91278 L
.52428 .9184 L
.52107 .92249 L
.51515 .93221 L
.51457 .93348 L
.50882 .94192 L
.50486 .94762 L
.50061 .94192 L
.50438 .93221 L
.50486 .93104 L
.50847 .92249 L
.51266 .91278 L
.51457 .9084 L
.51693 .90307 L
.52125 .89336 L
.52428 .88654 L
.52559 .88364 L
.52995 .87393 L
.53399 .86489 L
.5343 .86422 L
.53867 .85451 L
.54263 .84479 L
.54371 .84308 L
.54737 .83508 L
.55169 .82537 L
.55342 .82115 L
.55601 .81566 L
.56031 .80594 L
.56313 .79917 L
.5646 .79623 L
.56887 .78652 L
.57284 .77729 L
.57311 .77681 L
.57736 .76709 L
.58123 .75738 L
.58256 .75497 L
.58577 .74767 L
.58895 .73796 L
.59227 .7323 L
.59409 .72824 L
.59824 .71853 L
.60198 .70958 L
.60234 .70882 L
.60646 .69911 L
.6102 .68939 L
.61169 .68651 L
.6146 .67968 L
.6176 .66997 L
.62141 .66313 L
.62266 .66026 L
.62667 .65054 L
.63054 .64083 L
.63112 .63965 L
.63463 .63112 L
.63789 .62141 L
.64083 .61572 L
.64251 .61169 L
.64466 .60198 L
.65028 .59227 L
.65054 .5917 L
.65422 .58256 L
.65747 .57284 L
.66026 .56724 L
.66193 .56313 L
.66406 .55342 L
.6695 .54371 L
.66997 .54267 L
.67339 .53399 L
.67646 .52428 L
.67968 .51771 L
.68094 .51457 L
.68272 .50486 L
.68823 .49514 L
.68939 .49258 L
.69217 .48543 L
.69487 .47572 L
.69911 .46715 L
.69956 .46601 L
.70326 .45629 L
.70646 .44658 L
.70882 .44144 L
.71057 .43687 L
.71264 .42716 L
.7177 .41744 L
.71853 .41553 L
.72146 .40773 L
.72412 .39802 L
.72824 .38933 L
.72863 .38831 L
.73222 .37859 L
.73525 .36888 L
.73796 .36284 L
.73933 .35917 L
.74103 .34946 L
.74612 .33974 L
.74767 .33614 L
.74991 .33003 L
.75211 .32032 L
.75679 .31061 L
.75738 .30919 L
.76038 .30089 L
.76291 .29118 L
.76709 .28198 L
.76728 .28147 L
.77074 .27176 L
.77349 .26204 L
.77681 .25448 L
.77758 .25233 L
.78101 .24262 L
.7839 .23291 L
.78652 .22676 L
.78779 .22319 L
.78921 .21348 L
.79417 .20377 L
.79623 .19879 L
.7979 .19406 L
.79955 .18434 L
.8043 .17463 L
.80594 .17059 L
.80791 .16492 L
.80971 .15521 L
.81431 .14549 L
.81566 .14214 L
.81784 .13578 L
.81973 .12607 L
.82422 .11636 L
.82537 .11345 L
.82769 .10664 L
.8296 .09693 L
.83403 .08722 L
.83508 .08452 L
.83745 .07751 L
.83935 .06779 L
.84373 .05808 L
.84479 .05534 L
.84713 .04837 L
.84897 .03866 L
.85334 .02894 L
.85451 .02605 L
.85673 .01923 L
F
0 g
.8854 .01923 m
.88364 .02358 L
.88187 .02894 L
.88066 .03866 L
.87584 .04837 L
.87393 .05311 L
.87226 .05808 L
.87108 .06779 L
.86619 .07751 L
.86422 .08233 L
.86256 .08722 L
.86134 .09693 L
.85642 .10664 L
.85451 .11131 L
.85278 .11636 L
.85146 .12607 L
.84654 .13578 L
.84479 .14002 L
.8429 .14549 L
.84142 .15521 L
.83655 .16492 L
.83508 .16848 L
.83294 .17463 L
.83123 .18434 L
.82645 .19406 L
.82537 .19667 L
.82288 .20377 L
.82091 .21348 L
.81624 .22319 L
.81566 .2246 L
.81272 .23291 L
.81045 .24262 L
.80594 .25226 L
.80592 .25233 L
.80246 .26204 L
.79988 .27176 L
.79623 .27969 L
.79558 .28147 L
.79209 .29118 L
.7892 .30089 L
.78652 .30684 L
.78513 .31061 L
.78161 .32032 L
.77843 .33003 L
.77681 .33369 L
.77457 .33974 L
.77254 .34946 L
.76756 .35917 L
.76709 .36024 L
.76389 .36888 L
Mistroke
.76126 .37859 L
.75738 .38657 L
.75671 .38831 L
.75308 .39802 L
.74995 .40773 L
.74767 .41259 L
.74581 .41744 L
.74393 .42716 L
.7386 .43687 L
.73796 .43828 L
.73477 .44658 L
.73202 .45629 L
.72824 .46375 L
.72735 .46601 L
.72359 .47572 L
.72019 .48543 L
.71853 .48888 L
.71605 .49514 L
.71362 .50486 L
.70882 .51369 L
.70846 .51457 L
.7046 .52428 L
.70125 .53399 L
.69911 .53825 L
.69689 .54371 L
.69455 .55342 L
.68939 .56243 L
.68909 .56313 L
.68514 .57284 L
.68165 .58256 L
.67968 .58635 L
.67721 .59227 L
.67462 .60198 L
.66997 .60993 L
.6692 .61169 L
.66514 .62141 L
.66132 .63112 L
.66026 .63314 L
.65697 .64083 L
.65377 .65054 L
.65054 .6561 L
.64871 .66026 L
.64453 .66997 L
.64083 .67863 L
.64034 .67968 L
.63609 .68939 L
.63207 .69911 L
.63112 .70081 L
.62753 .70882 L
.62399 .71853 L
Mistroke
.62141 .72271 L
.61885 .72824 L
.61446 .73796 L
.61169 .74422 L
.61004 .74767 L
.60556 .75738 L
.60198 .7653 L
.60107 .76709 L
.59651 .77681 L
.59227 .78592 L
.59194 .78652 L
.58728 .79623 L
.58265 .80594 L
.58256 .8061 L
.57787 .81566 L
.57324 .82537 L
.57284 .82594 L
.56825 .83508 L
.56351 .84479 L
.56313 .8453 L
.55838 .85451 L
.55342 .86417 L
.55337 .86422 L
.54823 .87393 L
.54371 .88303 L
.54305 .88364 L
.53774 .89336 L
.53399 .90135 L
.53234 .90307 L
.52679 .91278 L
.52428 .9184 L
.52107 .92249 L
.51515 .93221 L
.51457 .93348 L
.50882 .94192 L
.50486 .94762 L
.50061 .94192 L
.50438 .93221 L
.50486 .93104 L
.50847 .92249 L
.51266 .91278 L
.51457 .9084 L
.51693 .90307 L
.52125 .89336 L
.52428 .88654 L
.52559 .88364 L
.52995 .87393 L
.53399 .86489 L
.5343 .86422 L
.53867 .85451 L
Mistroke
.54263 .84479 L
.54371 .84308 L
.54737 .83508 L
.55169 .82537 L
.55342 .82115 L
.55601 .81566 L
.56031 .80594 L
.56313 .79917 L
.5646 .79623 L
.56887 .78652 L
.57284 .77729 L
.57311 .77681 L
.57736 .76709 L
.58123 .75738 L
.58256 .75497 L
.58577 .74767 L
.58895 .73796 L
.59227 .7323 L
.59409 .72824 L
.59824 .71853 L
.60198 .70958 L
.60234 .70882 L
.60646 .69911 L
.6102 .68939 L
.61169 .68651 L
.6146 .67968 L
.6176 .66997 L
.62141 .66313 L
.62266 .66026 L
.62667 .65054 L
.63054 .64083 L
.63112 .63965 L
.63463 .63112 L
.63789 .62141 L
.64083 .61572 L
.64251 .61169 L
.64466 .60198 L
.65028 .59227 L
.65054 .5917 L
.65422 .58256 L
.65747 .57284 L
.66026 .56724 L
.66193 .56313 L
.66406 .55342 L
.6695 .54371 L
.66997 .54267 L
.67339 .53399 L
.67646 .52428 L
.67968 .51771 L
.68094 .51457 L
Mistroke
.68272 .50486 L
.68823 .49514 L
.68939 .49258 L
.69217 .48543 L
.69487 .47572 L
.69911 .46715 L
.69956 .46601 L
.70326 .45629 L
.70646 .44658 L
.70882 .44144 L
.71057 .43687 L
.71264 .42716 L
.7177 .41744 L
.71853 .41553 L
.72146 .40773 L
.72412 .39802 L
.72824 .38933 L
.72863 .38831 L
.73222 .37859 L
.73525 .36888 L
.73796 .36284 L
.73933 .35917 L
.74103 .34946 L
.74612 .33974 L
.74767 .33614 L
.74991 .33003 L
.75211 .32032 L
.75679 .31061 L
.75738 .30919 L
.76038 .30089 L
.76291 .29118 L
.76709 .28198 L
.76728 .28147 L
.77074 .27176 L
.77349 .26204 L
.77681 .25448 L
.77758 .25233 L
.78101 .24262 L
.7839 .23291 L
.78652 .22676 L
.78779 .22319 L
.78921 .21348 L
.79417 .20377 L
.79623 .19879 L
.7979 .19406 L
.79955 .18434 L
.8043 .17463 L
.80594 .17059 L
.80791 .16492 L
.80971 .15521 L
Mistroke
.81431 .14549 L
.81566 .14214 L
.81784 .13578 L
.81973 .12607 L
.82422 .11636 L
.82537 .11345 L
.82769 .10664 L
.8296 .09693 L
.83403 .08722 L
.83508 .08452 L
.83745 .07751 L
.83935 .06779 L
.84373 .05808 L
.84479 .05534 L
.84713 .04837 L
.84897 .03866 L
.85334 .02894 L
.85451 .02605 L
.85673 .01923 L
Mfstroke
.8 g
.5737 .01923 m
.57284 .02033 L
.56855 .02894 L
.56367 .03866 L
.56313 .0398 L
.55869 .04837 L
.55368 .05808 L
.55342 .05863 L
.54855 .06779 L
.54371 .07728 L
.54338 .07751 L
.53807 .08722 L
.53399 .09587 L
.53268 .09693 L
.52713 .10664 L
.52428 .11315 L
.52143 .11636 L
.51553 .12607 L
.51457 .12822 L
.50923 .13578 L
.50486 .14208 L
.50083 .13578 L
.50463 .12607 L
.50486 .12551 L
.50873 .11636 L
.51292 .10664 L
.51457 .10286 L
.5172 .09693 L
.52152 .08722 L
.52428 .08101 L
.52586 .07751 L
.53022 .06779 L
.53399 .05935 L
.53457 .05808 L
.53894 .04837 L
.54306 .03866 L
.54371 .03761 L
.54763 .02894 L
.55113 .01923 L
F
0 g
.5737 .01923 m
.57284 .02033 L
.56855 .02894 L
.56367 .03866 L
.56313 .0398 L
.55869 .04837 L
.55368 .05808 L
.55342 .05863 L
.54855 .06779 L
.54371 .07728 L
.54338 .07751 L
.53807 .08722 L
.53399 .09587 L
.53268 .09693 L
.52713 .10664 L
.52428 .11315 L
.52143 .11636 L
.51553 .12607 L
.51457 .12822 L
.50923 .13578 L
.50486 .14208 L
.50083 .13578 L
.50463 .12607 L
.50486 .12551 L
.50873 .11636 L
.51292 .10664 L
.51457 .10286 L
.5172 .09693 L
.52152 .08722 L
.52428 .08101 L
.52586 .07751 L
.53022 .06779 L
.53399 .05935 L
.53457 .05808 L
.53894 .04837 L
.54306 .03866 L
.54371 .03761 L
.54763 .02894 L
.55113 .01923 L
s
.2 g
.50486 .72966 m
.51055 .73796 L
.50486 .74624 L
.50157 .73796 L
F
0 g
.50486 .72966 m
.51055 .73796 L
.50486 .74624 L
.50157 .73796 L
.50486 .72966 L
s
.2 g
.81736 .01923 m
.81566 .02317 L
.81363 .02894 L
.81191 .03866 L
.80701 .04837 L
.80594 .0509 L
.80338 .05808 L
.80127 .06779 L
.79656 .07751 L
.79623 .07828 L
.79302 .08722 L
.79052 .09693 L
.78652 .10544 L
.78607 .10664 L
.78255 .11636 L
.77967 .12607 L
.77681 .13232 L
.77552 .13578 L
.77196 .14549 L
.76874 .15521 L
.76709 .15889 L
.76484 .16492 L
.76276 .17463 L
.75774 .18434 L
.75738 .18515 L
.75404 .19406 L
.75131 .20377 L
.74767 .21121 L
.74679 .21348 L
.74311 .22319 L
.73985 .23291 L
.73796 .23693 L
.73576 .24262 L
.73359 .25233 L
.72837 .26204 L
.72824 .26232 L
.72458 .27176 L
.72156 .28147 L
.71853 .28751 L
.71707 .29118 L
.71326 .30089 L
.70963 .31061 L
.70882 .3123 L
.70563 .32032 L
.70273 .33003 L
.69911 .33687 L
.69792 .33974 L
.69402 .34946 L
.69032 .35917 L
.68939 .36104 L
.68619 .36888 L
.68318 .37859 L
.67968 .38499 L
.67828 .38831 L
.67427 .39802 L
.67035 .40773 L
.66997 .40849 L
.66621 .41744 L
.66282 .42716 L
.66026 .4318 L
.65807 .43687 L
.65564 .44658 L
.65054 .4547 L
.64982 .45629 L
.64564 .46601 L
.64164 .47572 L
.64083 .47721 L
.63722 .48543 L
.63371 .49514 L
.63112 .49948 L
.62868 .50486 L
.62436 .51457 L
.62141 .52136 L
.62002 .52428 L
.61562 .53399 L
.61169 .54277 L
.61122 .54371 L
.60675 .55342 L
.60238 .56313 L
.60198 .56379 L
.59772 .57284 L
.59355 .58256 L
.59227 .58452 L
.58852 .59227 L
.58459 .60198 L
.58256 .60483 L
.57914 .61169 L
.57438 .62141 L
.57284 .62469 L
.56954 .63112 L
.56467 .64083 L
.56313 .64408 L
.55971 .65054 L
.55471 .66026 L
.55342 .66294 L
.5496 .66997 L
.54444 .67968 L
.54371 .68119 L
.53915 .68939 L
.53399 .69876 L
.5338 .69911 L
.52827 .70882 L
.52428 .71574 L
.52262 .71853 L
.51674 .72824 L
.51457 .73177 L
.50545 .72824 L
.50958 .71853 L
.51378 .70882 L
.51457 .70626 L
.51808 .69911 L
.5224 .68939 L
.52428 .68393 L
.52675 .67968 L
.53111 .66997 L
.53399 .66235 L
.53546 .66026 L
.53983 .65054 L
.54371 .64132 L
.54416 .64083 L
.54852 .63112 L
.55258 .62141 L
.55342 .61999 L
.55716 .61169 L
.56059 .60198 L
.56313 .59791 L
.56574 .59227 L
.57 .58256 L
.57284 .57573 L
.57424 .57284 L
.57848 .56313 L
.58256 .55364 L
.58267 .55342 L
.58688 .54371 L
.59064 .53399 L
.59227 .531 L
.5952 .52428 L
.59821 .51457 L
.60198 .50811 L
.60344 .50486 L
.60754 .49514 L
.61158 .48543 L
.61169 .48521 L
.61567 .47572 L
.61919 .46601 L
.62141 .46177 L
.62373 .45629 L
.62635 .44658 L
.63112 .43821 L
.63171 .43687 L
.63568 .42716 L
.63932 .41744 L
.64083 .41437 L
.64356 .40773 L
.6464 .39802 L
.65054 .39024 L
.65136 .38831 L
.65525 .37859 L
.65883 .36888 L
.66026 .36589 L
.66295 .35917 L
.66573 .34946 L
.66997 .34125 L
.67059 .33974 L
.6744 .33003 L
.67781 .32032 L
.67968 .31634 L
.68194 .31061 L
.68441 .30089 L
.68939 .29124 L
.68942 .29118 L
.69316 .28147 L
.69627 .27176 L
.69911 .26574 L
.70055 .26204 L
.70243 .25233 L
.7077 .24262 L
.70882 .24009 L
.71155 .23291 L
.71415 .22319 L
.71853 .21415 L
.71879 .21348 L
.72242 .20377 L
.72545 .19406 L
.72824 .18791 L
.72959 .18434 L
.73131 .17463 L
.73646 .16492 L
.73796 .16147 L
.74027 .15521 L
.74256 .14549 L
.74725 .13578 L
.74767 .13478 L
.75084 .12607 L
.75349 .11636 L
.75738 .1078 L
.75781 .10664 L
.7613 .09693 L
.76418 .08722 L
.76709 .08056 L
.7682 .07751 L
.76959 .06779 L
.77469 .05808 L
.77681 .05309 L
.7785 .04837 L
.78025 .03866 L
.78505 .02894 L
.78652 .02557 L
.78869 .01923 L
F
0 g
.81736 .01923 m
.81566 .02317 L
.81363 .02894 L
.81191 .03866 L
.80701 .04837 L
.80594 .0509 L
.80338 .05808 L
.80127 .06779 L
.79656 .07751 L
.79623 .07828 L
.79302 .08722 L
.79052 .09693 L
.78652 .10544 L
.78607 .10664 L
.78255 .11636 L
.77967 .12607 L
.77681 .13232 L
.77552 .13578 L
.77196 .14549 L
.76874 .15521 L
.76709 .15889 L
.76484 .16492 L
.76276 .17463 L
.75774 .18434 L
.75738 .18515 L
.75404 .19406 L
.75131 .20377 L
.74767 .21121 L
.74679 .21348 L
.74311 .22319 L
.73985 .23291 L
.73796 .23693 L
.73576 .24262 L
.73359 .25233 L
.72837 .26204 L
.72824 .26232 L
.72458 .27176 L
.72156 .28147 L
.71853 .28751 L
.71707 .29118 L
.71326 .30089 L
.70963 .31061 L
.70882 .3123 L
.70563 .32032 L
.70273 .33003 L
.69911 .33687 L
.69792 .33974 L
.69402 .34946 L
.69032 .35917 L
.68939 .36104 L
Mistroke
.68619 .36888 L
.68318 .37859 L
.67968 .38499 L
.67828 .38831 L
.67427 .39802 L
.67035 .40773 L
.66997 .40849 L
.66621 .41744 L
.66282 .42716 L
.66026 .4318 L
.65807 .43687 L
.65564 .44658 L
.65054 .4547 L
.64982 .45629 L
.64564 .46601 L
.64164 .47572 L
.64083 .47721 L
.63722 .48543 L
.63371 .49514 L
.63112 .49948 L
.62868 .50486 L
.62436 .51457 L
.62141 .52136 L
.62002 .52428 L
.61562 .53399 L
.61169 .54277 L
.61122 .54371 L
.60675 .55342 L
.60238 .56313 L
.60198 .56379 L
.59772 .57284 L
.59355 .58256 L
.59227 .58452 L
.58852 .59227 L
.58459 .60198 L
.58256 .60483 L
.57914 .61169 L
.57438 .62141 L
.57284 .62469 L
.56954 .63112 L
.56467 .64083 L
.56313 .64408 L
.55971 .65054 L
.55471 .66026 L
.55342 .66294 L
.5496 .66997 L
.54444 .67968 L
.54371 .68119 L
.53915 .68939 L
.53399 .69876 L
Mistroke
.5338 .69911 L
.52827 .70882 L
.52428 .71574 L
.52262 .71853 L
.51674 .72824 L
.51457 .73177 L
.50545 .72824 L
.50958 .71853 L
.51378 .70882 L
.51457 .70626 L
.51808 .69911 L
.5224 .68939 L
.52428 .68393 L
.52675 .67968 L
.53111 .66997 L
.53399 .66235 L
.53546 .66026 L
.53983 .65054 L
.54371 .64132 L
.54416 .64083 L
.54852 .63112 L
.55258 .62141 L
.55342 .61999 L
.55716 .61169 L
.56059 .60198 L
.56313 .59791 L
.56574 .59227 L
.57 .58256 L
.57284 .57573 L
.57424 .57284 L
.57848 .56313 L
.58256 .55364 L
.58267 .55342 L
.58688 .54371 L
.59064 .53399 L
.59227 .531 L
.5952 .52428 L
.59821 .51457 L
.60198 .50811 L
.60344 .50486 L
.60754 .49514 L
.61158 .48543 L
.61169 .48521 L
.61567 .47572 L
.61919 .46601 L
.62141 .46177 L
.62373 .45629 L
.62635 .44658 L
.63112 .43821 L
.63171 .43687 L
Mistroke
.63568 .42716 L
.63932 .41744 L
.64083 .41437 L
.64356 .40773 L
.6464 .39802 L
.65054 .39024 L
.65136 .38831 L
.65525 .37859 L
.65883 .36888 L
.66026 .36589 L
.66295 .35917 L
.66573 .34946 L
.66997 .34125 L
.67059 .33974 L
.6744 .33003 L
.67781 .32032 L
.67968 .31634 L
.68194 .31061 L
.68441 .30089 L
.68939 .29124 L
.68942 .29118 L
.69316 .28147 L
.69627 .27176 L
.69911 .26574 L
.70055 .26204 L
.70243 .25233 L
.7077 .24262 L
.70882 .24009 L
.71155 .23291 L
.71415 .22319 L
.71853 .21415 L
.71879 .21348 L
.72242 .20377 L
.72545 .19406 L
.72824 .18791 L
.72959 .18434 L
.73131 .17463 L
.73646 .16492 L
.73796 .16147 L
.74027 .15521 L
.74256 .14549 L
.74725 .13578 L
.74767 .13478 L
.75084 .12607 L
.75349 .11636 L
.75738 .1078 L
.75781 .10664 L
.7613 .09693 L
.76418 .08722 L
.76709 .08056 L
Mistroke
.7682 .07751 L
.76959 .06779 L
.77469 .05808 L
.77681 .05309 L
.7785 .04837 L
.78025 .03866 L
.78505 .02894 L
.78652 .02557 L
.78869 .01923 L
Mfstroke
.8 g
.51457 .50563 m
.52416 .51457 L
.51832 .52428 L
.51457 .53038 L
.50653 .52428 L
.51069 .51457 L
F
0 g
.51457 .50563 m
.52416 .51457 L
.51832 .52428 L
.51457 .53038 L
.50653 .52428 L
.51069 .51457 L
.51457 .50563 L
s
.2 g
.66431 .01923 m
.66026 .02894 L
.66026 .02895 L
.65613 .03866 L
.65251 .04837 L
.65054 .05192 L
.64786 .05808 L
.645 .06779 L
.64083 .07452 L
.63947 .07751 L
.63522 .08722 L
.63112 .09664 L
.63098 .09693 L
.62665 .10664 L
.62267 .11636 L
.62141 .11851 L
.61796 .12607 L
.61443 .13578 L
.61169 .14004 L
.60912 .14549 L
.60465 .15521 L
.60198 .16117 L
.60014 .16492 L
.59558 .17463 L
.59227 .18188 L
.59099 .18434 L
.58634 .19406 L
.58256 .20215 L
.58166 .20377 L
.5769 .21348 L
.57284 .22199 L
.57213 .22319 L
.56726 .23291 L
.56313 .24142 L
.56236 .24262 L
.55737 .25233 L
.55342 .26046 L
.55233 .26204 L
.54718 .27176 L
.54371 .27901 L
.54198 .28147 L
.53665 .29118 L
.53399 .29682 L
.53122 .30089 L
.52565 .31061 L
.52428 .3135 L
.51988 .32032 L
.51457 .329 L
.50763 .32032 L
.5118 .31061 L
.51457 .30425 L
.51606 .30089 L
.52037 .29118 L
.52428 .28239 L
.5247 .28147 L
.52907 .27176 L
.53341 .26204 L
.53399 .26057 L
.53778 .25233 L
.54213 .24262 L
.54371 .2387 L
.54648 .23291 L
.55081 .22319 L
.55342 .21684 L
.55513 .21348 L
.55944 .20377 L
.56313 .1951 L
.56372 .19406 L
.56801 .18434 L
.57205 .17463 L
.57284 .17319 L
.5765 .16492 L
.57994 .15521 L
.58256 .15073 L
.58491 .14549 L
.58742 .13578 L
.59227 .12815 L
.59325 .12607 L
.5974 .11636 L
.60138 .10664 L
.60198 .10548 L
.60562 .09693 L
.60903 .08722 L
.61169 .08231 L
.61377 .07751 L
.61619 .06779 L
.62141 .05904 L
.62184 .05808 L
.62586 .04837 L
.62951 .03866 L
.63112 .03545 L
.63382 .02894 L
.63668 .01923 L
F
0 g
.66431 .01923 m
.66026 .02894 L
.66026 .02895 L
.65613 .03866 L
.65251 .04837 L
.65054 .05192 L
.64786 .05808 L
.645 .06779 L
.64083 .07452 L
.63947 .07751 L
.63522 .08722 L
.63112 .09664 L
.63098 .09693 L
.62665 .10664 L
.62267 .11636 L
.62141 .11851 L
.61796 .12607 L
.61443 .13578 L
.61169 .14004 L
.60912 .14549 L
.60465 .15521 L
.60198 .16117 L
.60014 .16492 L
.59558 .17463 L
.59227 .18188 L
.59099 .18434 L
.58634 .19406 L
.58256 .20215 L
.58166 .20377 L
.5769 .21348 L
.57284 .22199 L
.57213 .22319 L
.56726 .23291 L
.56313 .24142 L
.56236 .24262 L
.55737 .25233 L
.55342 .26046 L
.55233 .26204 L
.54718 .27176 L
.54371 .27901 L
.54198 .28147 L
.53665 .29118 L
.53399 .29682 L
.53122 .30089 L
.52565 .31061 L
.52428 .3135 L
.51988 .32032 L
.51457 .329 L
.50763 .32032 L
.5118 .31061 L
Mistroke
.51457 .30425 L
.51606 .30089 L
.52037 .29118 L
.52428 .28239 L
.5247 .28147 L
.52907 .27176 L
.53341 .26204 L
.53399 .26057 L
.53778 .25233 L
.54213 .24262 L
.54371 .2387 L
.54648 .23291 L
.55081 .22319 L
.55342 .21684 L
.55513 .21348 L
.55944 .20377 L
.56313 .1951 L
.56372 .19406 L
.56801 .18434 L
.57205 .17463 L
.57284 .17319 L
.5765 .16492 L
.57994 .15521 L
.58256 .15073 L
.58491 .14549 L
.58742 .13578 L
.59227 .12815 L
.59325 .12607 L
.5974 .11636 L
.60138 .10664 L
.60198 .10548 L
.60562 .09693 L
.60903 .08722 L
.61169 .08231 L
.61377 .07751 L
.61619 .06779 L
.62141 .05904 L
.62184 .05808 L
.62586 .04837 L
.62951 .03866 L
.63112 .03545 L
.63382 .02894 L
.63668 .01923 L
Mfstroke
.6 g
.51475 .98077 m
.51999 .97106 L
.52428 .96263 L
.52496 .96134 L
.53008 .95163 L
.53399 .94375 L
.53495 .94192 L
.53996 .93221 L
.54371 .92449 L
.54472 .92249 L
.54964 .91278 L
.55342 .90484 L
.55431 .90307 L
.55914 .89336 L
.56313 .88483 L
.56371 .88364 L
.56847 .87393 L
.57284 .86444 L
.57295 .86422 L
.57763 .85451 L
.58209 .84479 L
.58256 .84371 L
.58665 .83508 L
.5911 .82537 L
.59227 .82262 L
.59552 .81566 L
.59996 .80594 L
.60198 .80119 L
.60426 .79623 L
.60868 .78652 L
.61169 .77941 L
.61287 .77681 L
.61726 .76709 L
.62137 .75738 L
.62141 .7573 L
.62571 .74767 L
.6299 .73796 L
.63112 .73487 L
.63404 .72824 L
.63826 .71853 L
.64083 .71211 L
.64226 .70882 L
.64647 .69911 L
.65041 .68939 L
.65054 .68904 L
.65456 .67968 L
.65861 .66997 L
.66026 .66565 L
.66254 .66026 L
.66663 .65054 L
.66997 .64195 L
.67044 .64083 L
.6745 .63112 L
.67842 .62141 L
.67968 .61796 L
.68227 .61169 L
.68625 .60198 L
.68939 .59365 L
.68996 .59227 L
.69393 .58256 L
.69776 .57284 L
.69911 .56906 L
.7015 .56313 L
.7054 .55342 L
.70882 .54416 L
.709 .54371 L
.71288 .53399 L
.71667 .52428 L
.71853 .51899 L
.72027 .51457 L
.72411 .50486 L
.72771 .49514 L
.72824 .49352 L
.73141 .48543 L
.73516 .47572 L
.73796 .46777 L
.73864 .46601 L
.7424 .45629 L
.74605 .44658 L
.74767 .44174 L
.74953 .43687 L
.75325 .42716 L
.75674 .41744 L
.75738 .41543 L
.76031 .40773 L
.76397 .39802 L
.76709 .38885 L
.7673 .38831 L
.77095 .37859 L
.77454 .36888 L
.77681 .36201 L
.77786 .35917 L
.78148 .34946 L
.78498 .33974 L
.78652 .33489 L
.78831 .33003 L
.7919 .32032 L
.79529 .31061 L
.79623 .30751 L
.79865 .30089 L
.8022 .29118 L
.80548 .28147 L
.80594 .27987 L
.80888 .27176 L
.81239 .26204 L
.81555 .25233 L
.81566 .25196 L
.81902 .24262 L
.82248 .23291 L
.82537 .2238 L
.82558 .22319 L
.82905 .21348 L
.83247 .20377 L
.83508 .19539 L
.83555 .19406 L
.83899 .18434 L
.84237 .17463 L
.84479 .16672 L
.84542 .16492 L
.84884 .15521 L
.85219 .14549 L
.85451 .1378 L
.8552 .13578 L
.85859 .12607 L
.86192 .11636 L
.86422 .10863 L
.8649 .10664 L
.86826 .09693 L
.87157 .08722 L
.87393 .07922 L
.87451 .07751 L
.87785 .06779 L
.88114 .05808 L
.88364 .04956 L
.88405 .04837 L
.88736 .03866 L
.89063 .02894 L
.89336 .01966 L
.8935 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.51475 .98077 m
.51999 .97106 L
.52428 .96263 L
.52496 .96134 L
.53008 .95163 L
.53399 .94375 L
.53495 .94192 L
.53996 .93221 L
.54371 .92449 L
.54472 .92249 L
.54964 .91278 L
.55342 .90484 L
.55431 .90307 L
.55914 .89336 L
.56313 .88483 L
.56371 .88364 L
.56847 .87393 L
.57284 .86444 L
.57295 .86422 L
.57763 .85451 L
.58209 .84479 L
.58256 .84371 L
.58665 .83508 L
.5911 .82537 L
.59227 .82262 L
.59552 .81566 L
.59996 .80594 L
.60198 .80119 L
.60426 .79623 L
.60868 .78652 L
.61169 .77941 L
.61287 .77681 L
.61726 .76709 L
.62137 .75738 L
.62141 .7573 L
.62571 .74767 L
.6299 .73796 L
.63112 .73487 L
.63404 .72824 L
.63826 .71853 L
.64083 .71211 L
.64226 .70882 L
.64647 .69911 L
.65041 .68939 L
.65054 .68904 L
.65456 .67968 L
.65861 .66997 L
.66026 .66565 L
.66254 .66026 L
.66663 .65054 L
Mistroke
.66997 .64195 L
.67044 .64083 L
.6745 .63112 L
.67842 .62141 L
.67968 .61796 L
.68227 .61169 L
.68625 .60198 L
.68939 .59365 L
.68996 .59227 L
.69393 .58256 L
.69776 .57284 L
.69911 .56906 L
.7015 .56313 L
.7054 .55342 L
.70882 .54416 L
.709 .54371 L
.71288 .53399 L
.71667 .52428 L
.71853 .51899 L
.72027 .51457 L
.72411 .50486 L
.72771 .49514 L
.72824 .49352 L
.73141 .48543 L
.73516 .47572 L
.73796 .46777 L
.73864 .46601 L
.7424 .45629 L
.74605 .44658 L
.74767 .44174 L
.74953 .43687 L
.75325 .42716 L
.75674 .41744 L
.75738 .41543 L
.76031 .40773 L
.76397 .39802 L
.76709 .38885 L
.7673 .38831 L
.77095 .37859 L
.77454 .36888 L
.77681 .36201 L
.77786 .35917 L
.78148 .34946 L
.78498 .33974 L
.78652 .33489 L
.78831 .33003 L
.7919 .32032 L
.79529 .31061 L
.79623 .30751 L
.79865 .30089 L
Mistroke
.8022 .29118 L
.80548 .28147 L
.80594 .27987 L
.80888 .27176 L
.81239 .26204 L
.81555 .25233 L
.81566 .25196 L
.81902 .24262 L
.82248 .23291 L
.82537 .2238 L
.82558 .22319 L
.82905 .21348 L
.83247 .20377 L
.83508 .19539 L
.83555 .19406 L
.83899 .18434 L
.84237 .17463 L
.84479 .16672 L
.84542 .16492 L
.84884 .15521 L
.85219 .14549 L
.85451 .1378 L
.8552 .13578 L
.85859 .12607 L
.86192 .11636 L
.86422 .10863 L
.8649 .10664 L
.86826 .09693 L
.87157 .08722 L
.87393 .07922 L
.87451 .07751 L
.87785 .06779 L
.88114 .05808 L
.88364 .04956 L
.88405 .04837 L
.88736 .03866 L
.89063 .02894 L
.89336 .01966 L
.8935 .01923 L
Mfstroke
.8 g
.74409 .01923 m
.74119 .02894 L
.73796 .03556 L
.73675 .03866 L
.73303 .04837 L
.7296 .05808 L
.72824 .06097 L
.72558 .06779 L
.72307 .07751 L
.71853 .0861 L
.71808 .08722 L
.71427 .09693 L
.71095 .10664 L
.70882 .11095 L
.70665 .11636 L
.70439 .12607 L
.69911 .13543 L
.69896 .13578 L
.69506 .14549 L
.69171 .15521 L
.68939 .1597 L
.68724 .16492 L
.68492 .17463 L
.67968 .18356 L
.67934 .18434 L
.67533 .19406 L
.67175 .20377 L
.66997 .20715 L
.66729 .21348 L
.66452 .22319 L
.66026 .23042 L
.65916 .23291 L
.65504 .24262 L
.65103 .25233 L
.65054 .25325 L
.64675 .26204 L
.64321 .27176 L
.64083 .27588 L
.63835 .28147 L
.63563 .29118 L
.63112 .29812 L
.62983 .30089 L
.62551 .31061 L
.62141 .31988 L
.62119 .32032 L
.61679 .33003 L
.61265 .33974 L
.61169 .34135 L
.60794 .34946 L
.60415 .35917 L
.60198 .36249 L
.59893 .36888 L
.59437 .37859 L
.59227 .38323 L
.58976 .38831 L
.5851 .39802 L
.58256 .40355 L
.5804 .40773 L
.57564 .41744 L
.57284 .42343 L
.57084 .42716 L
.56596 .43687 L
.56313 .44285 L
.56104 .44658 L
.55604 .45629 L
.55342 .46178 L
.55097 .46601 L
.54581 .47572 L
.54371 .48011 L
.54057 .48543 L
.53523 .49514 L
.53399 .49769 L
.52974 .50486 L
.52428 .51436 L
.51491 .50486 L
.51923 .49514 L
.52354 .48543 L
.52428 .48344 L
.52791 .47572 L
.53226 .46601 L
.53399 .4615 L
.53662 .45629 L
.54098 .44658 L
.54371 .43978 L
.54532 .43687 L
.54967 .42716 L
.55342 .41831 L
.55398 .41744 L
.5583 .40773 L
.56238 .39802 L
.56313 .3967 L
.56687 .38831 L
.57036 .37859 L
.57284 .37444 L
.57537 .36888 L
.57959 .35917 L
.58256 .35206 L
.58379 .34946 L
.58799 .33974 L
.5921 .33003 L
.59227 .32971 L
.5963 .32032 L
.59991 .31061 L
.60198 .30678 L
.60453 .30089 L
.6073 .29118 L
.61169 .28368 L
.61269 .28147 L
.61675 .27176 L
.62062 .26204 L
.62141 .26046 L
.6248 .25233 L
.62803 .24262 L
.63112 .23679 L
.63277 .23291 L
.63488 .22319 L
.64063 .21348 L
.64083 .21305 L
.6446 .20377 L
.64792 .19406 L
.65054 .18885 L
.6524 .18434 L
.65467 .17463 L
.66009 .16492 L
.66026 .16456 L
.66397 .15521 L
.6672 .14549 L
.66997 .13984 L
.6716 .13578 L
.67369 .12607 L
.67906 .11636 L
.67968 .115 L
.68294 .10664 L
.6859 .09693 L
.68939 .08978 L
.69041 .08722 L
.69414 .07751 L
.69755 .06779 L
.69911 .06438 L
.70153 .05808 L
.70402 .04837 L
.70882 .03874 L
.70885 .03866 L
.71252 .02894 L
.71552 .01923 L
F
0 g
.74409 .01923 m
.74119 .02894 L
.73796 .03556 L
.73675 .03866 L
.73303 .04837 L
.7296 .05808 L
.72824 .06097 L
.72558 .06779 L
.72307 .07751 L
.71853 .0861 L
.71808 .08722 L
.71427 .09693 L
.71095 .10664 L
.70882 .11095 L
.70665 .11636 L
.70439 .12607 L
.69911 .13543 L
.69896 .13578 L
.69506 .14549 L
.69171 .15521 L
.68939 .1597 L
.68724 .16492 L
.68492 .17463 L
.67968 .18356 L
.67934 .18434 L
.67533 .19406 L
.67175 .20377 L
.66997 .20715 L
.66729 .21348 L
.66452 .22319 L
.66026 .23042 L
.65916 .23291 L
.65504 .24262 L
.65103 .25233 L
.65054 .25325 L
.64675 .26204 L
.64321 .27176 L
.64083 .27588 L
.63835 .28147 L
.63563 .29118 L
.63112 .29812 L
.62983 .30089 L
.62551 .31061 L
.62141 .31988 L
.62119 .32032 L
.61679 .33003 L
.61265 .33974 L
.61169 .34135 L
.60794 .34946 L
.60415 .35917 L
Mistroke
.60198 .36249 L
.59893 .36888 L
.59437 .37859 L
.59227 .38323 L
.58976 .38831 L
.5851 .39802 L
.58256 .40355 L
.5804 .40773 L
.57564 .41744 L
.57284 .42343 L
.57084 .42716 L
.56596 .43687 L
.56313 .44285 L
.56104 .44658 L
.55604 .45629 L
.55342 .46178 L
.55097 .46601 L
.54581 .47572 L
.54371 .48011 L
.54057 .48543 L
.53523 .49514 L
.53399 .49769 L
.52974 .50486 L
.52428 .51436 L
.51491 .50486 L
.51923 .49514 L
.52354 .48543 L
.52428 .48344 L
.52791 .47572 L
.53226 .46601 L
.53399 .4615 L
.53662 .45629 L
.54098 .44658 L
.54371 .43978 L
.54532 .43687 L
.54967 .42716 L
.55342 .41831 L
.55398 .41744 L
.5583 .40773 L
.56238 .39802 L
.56313 .3967 L
.56687 .38831 L
.57036 .37859 L
.57284 .37444 L
.57537 .36888 L
.57959 .35917 L
.58256 .35206 L
.58379 .34946 L
.58799 .33974 L
.5921 .33003 L
Mistroke
.59227 .32971 L
.5963 .32032 L
.59991 .31061 L
.60198 .30678 L
.60453 .30089 L
.6073 .29118 L
.61169 .28368 L
.61269 .28147 L
.61675 .27176 L
.62062 .26204 L
.62141 .26046 L
.6248 .25233 L
.62803 .24262 L
.63112 .23679 L
.63277 .23291 L
.63488 .22319 L
.64063 .21348 L
.64083 .21305 L
.6446 .20377 L
.64792 .19406 L
.65054 .18885 L
.6524 .18434 L
.65467 .17463 L
.66009 .16492 L
.66026 .16456 L
.66397 .15521 L
.6672 .14549 L
.66997 .13984 L
.6716 .13578 L
.67369 .12607 L
.67906 .11636 L
.67968 .115 L
.68294 .10664 L
.6859 .09693 L
.68939 .08978 L
.69041 .08722 L
.69414 .07751 L
.69755 .06779 L
.69911 .06438 L
.70153 .05808 L
.70402 .04837 L
.70882 .03874 L
.70885 .03866 L
.71252 .02894 L
.71552 .01923 L
Mfstroke
.5 g
.52899 .98077 m
.53386 .97106 L
.53399 .9708 L
.53873 .96134 L
.54351 .95163 L
.54371 .95123 L
.54829 .94192 L
.55299 .93221 L
.55342 .9313 L
.55767 .92249 L
.5623 .91278 L
.56313 .91101 L
.56691 .90307 L
.57147 .89336 L
.57284 .89037 L
.57599 .88364 L
.58049 .87393 L
.58256 .86939 L
.58493 .86422 L
.58937 .85451 L
.59227 .84806 L
.59375 .84479 L
.59813 .83508 L
.60198 .8264 L
.60244 .82537 L
.60677 .81566 L
.61103 .80594 L
.61169 .80441 L
.61529 .79623 L
.61951 .78652 L
.62141 .7821 L
.6237 .77681 L
.62789 .76709 L
.63112 .75946 L
.63201 .75738 L
.63615 .74767 L
.64023 .73796 L
.64083 .73651 L
.64432 .72824 L
.64838 .71853 L
.65054 .71325 L
.65239 .70882 L
.65642 .69911 L
.66026 .68968 L
.66037 .68939 L
.66436 .67968 L
.66831 .66997 L
.66997 .66581 L
.67222 .66026 L
.67615 .65054 L
.67968 .64164 L
.68001 .64083 L
.6839 .63112 L
.68775 .62141 L
.68939 .61718 L
.69157 .61169 L
.69541 .60198 L
.69911 .59242 L
.69917 .59227 L
.70297 .58256 L
.70674 .57284 L
.70882 .56738 L
.71046 .56313 L
.71422 .55342 L
.71792 .54371 L
.71853 .54205 L
.72162 .53399 L
.72532 .52428 L
.72824 .51644 L
.72895 .51457 L
.73263 .50486 L
.73628 .49514 L
.73796 .49056 L
.73988 .48543 L
.74351 .47572 L
.74709 .46601 L
.74767 .46439 L
.75067 .45629 L
.75427 .44658 L
.75738 .43796 L
.75778 .43687 L
.76135 .42716 L
.76489 .41744 L
.76709 .41125 L
.76837 .40773 L
.77191 .39802 L
.7754 .38831 L
.77681 .38428 L
.77885 .37859 L
.78235 .36888 L
.78579 .35917 L
.78652 .35704 L
.78922 .34946 L
.79268 .33974 L
.79606 .33003 L
.79623 .32954 L
.79949 .32032 L
.80291 .31061 L
.80594 .30178 L
.80625 .30089 L
.80966 .29118 L
.81304 .28147 L
.81566 .27376 L
.81635 .27176 L
.81973 .26204 L
.82308 .25233 L
.82537 .24549 L
.82636 .24262 L
.8297 .23291 L
.83302 .22319 L
.83508 .21697 L
.83627 .21348 L
.83959 .20377 L
.84287 .19406 L
.84479 .1882 L
.84609 .18434 L
.84939 .17463 L
.85264 .16492 L
.85451 .15918 L
.85583 .15521 L
.8591 .14549 L
.86233 .13578 L
.86422 .12991 L
.86549 .12607 L
.86873 .11636 L
.87194 .10664 L
.87393 .1004 L
.87507 .09693 L
.87828 .08722 L
.88147 .07751 L
.88364 .07065 L
.88457 .06779 L
.88776 .05808 L
.89093 .04837 L
.89336 .04066 L
.894 .03866 L
.89716 .02894 L
.90031 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.52899 .98077 m
.53386 .97106 L
.53399 .9708 L
.53873 .96134 L
.54351 .95163 L
.54371 .95123 L
.54829 .94192 L
.55299 .93221 L
.55342 .9313 L
.55767 .92249 L
.5623 .91278 L
.56313 .91101 L
.56691 .90307 L
.57147 .89336 L
.57284 .89037 L
.57599 .88364 L
.58049 .87393 L
.58256 .86939 L
.58493 .86422 L
.58937 .85451 L
.59227 .84806 L
.59375 .84479 L
.59813 .83508 L
.60198 .8264 L
.60244 .82537 L
.60677 .81566 L
.61103 .80594 L
.61169 .80441 L
.61529 .79623 L
.61951 .78652 L
.62141 .7821 L
.6237 .77681 L
.62789 .76709 L
.63112 .75946 L
.63201 .75738 L
.63615 .74767 L
.64023 .73796 L
.64083 .73651 L
.64432 .72824 L
.64838 .71853 L
.65054 .71325 L
.65239 .70882 L
.65642 .69911 L
.66026 .68968 L
.66037 .68939 L
.66436 .67968 L
.66831 .66997 L
.66997 .66581 L
.67222 .66026 L
.67615 .65054 L
Mistroke
.67968 .64164 L
.68001 .64083 L
.6839 .63112 L
.68775 .62141 L
.68939 .61718 L
.69157 .61169 L
.69541 .60198 L
.69911 .59242 L
.69917 .59227 L
.70297 .58256 L
.70674 .57284 L
.70882 .56738 L
.71046 .56313 L
.71422 .55342 L
.71792 .54371 L
.71853 .54205 L
.72162 .53399 L
.72532 .52428 L
.72824 .51644 L
.72895 .51457 L
.73263 .50486 L
.73628 .49514 L
.73796 .49056 L
.73988 .48543 L
.74351 .47572 L
.74709 .46601 L
.74767 .46439 L
.75067 .45629 L
.75427 .44658 L
.75738 .43796 L
.75778 .43687 L
.76135 .42716 L
.76489 .41744 L
.76709 .41125 L
.76837 .40773 L
.77191 .39802 L
.7754 .38831 L
.77681 .38428 L
.77885 .37859 L
.78235 .36888 L
.78579 .35917 L
.78652 .35704 L
.78922 .34946 L
.79268 .33974 L
.79606 .33003 L
.79623 .32954 L
.79949 .32032 L
.80291 .31061 L
.80594 .30178 L
.80625 .30089 L
Mistroke
.80966 .29118 L
.81304 .28147 L
.81566 .27376 L
.81635 .27176 L
.81973 .26204 L
.82308 .25233 L
.82537 .24549 L
.82636 .24262 L
.8297 .23291 L
.83302 .22319 L
.83508 .21697 L
.83627 .21348 L
.83959 .20377 L
.84287 .19406 L
.84479 .1882 L
.84609 .18434 L
.84939 .17463 L
.85264 .16492 L
.85451 .15918 L
.85583 .15521 L
.8591 .14549 L
.86233 .13578 L
.86422 .12991 L
.86549 .12607 L
.86873 .11636 L
.87194 .10664 L
.87393 .1004 L
.87507 .09693 L
.87828 .08722 L
.88147 .07751 L
.88364 .07065 L
.88457 .06779 L
.88776 .05808 L
.89093 .04837 L
.89336 .04066 L
.894 .03866 L
.89716 .02894 L
.90031 .01923 L
Mfstroke
.4 g
.5413 .98077 m
.54371 .97583 L
.54601 .97106 L
.5507 .96134 L
.55342 .95568 L
.55534 .95163 L
.55995 .94192 L
.56313 .93518 L
.56452 .93221 L
.56906 .92249 L
.57284 .91434 L
.57356 .91278 L
.57802 .90307 L
.58247 .89336 L
.58256 .89316 L
.58686 .88364 L
.59124 .87393 L
.59227 .87165 L
.59557 .86422 L
.5999 .85451 L
.60198 .8498 L
.60418 .84479 L
.60844 .83508 L
.61169 .82764 L
.61267 .82537 L
.61688 .81566 L
.62107 .80594 L
.62141 .80516 L
.62521 .79623 L
.62936 .78652 L
.63112 .78236 L
.63345 .77681 L
.63755 .76709 L
.64083 .75926 L
.64161 .75738 L
.64564 .74767 L
.64967 .73796 L
.65054 .73585 L
.65365 .72824 L
.65764 .71853 L
.66026 .71214 L
.66159 .70882 L
.66553 .69911 L
.66946 .68939 L
.66997 .68813 L
.67333 .67968 L
.67723 .66997 L
.67968 .66382 L
.68108 .66026 L
.68492 .65054 L
.68876 .64083 L
.68939 .63922 L
.69255 .63112 L
.69635 .62141 L
.69911 .61434 L
.70012 .61169 L
.70387 .60198 L
.70763 .59227 L
.70882 .58917 L
.71133 .58256 L
.71505 .57284 L
.71853 .56372 L
.71875 .56313 L
.72241 .55342 L
.72609 .54371 L
.72824 .53799 L
.72972 .53399 L
.73336 .52428 L
.737 .51457 L
.73796 .51199 L
.74057 .50486 L
.74418 .49514 L
.74767 .48572 L
.74777 .48543 L
.75131 .47572 L
.75488 .46601 L
.75738 .45917 L
.75841 .45629 L
.76193 .44658 L
.76546 .43687 L
.76709 .43236 L
.76894 .42716 L
.77243 .41744 L
.77593 .40773 L
.77681 .40528 L
.77936 .39802 L
.78283 .38831 L
.78629 .37859 L
.78652 .37794 L
.78968 .36888 L
.79312 .35917 L
.79623 .35034 L
.79653 .34946 L
.7999 .33974 L
.80331 .33003 L
.80594 .32249 L
.80668 .32032 L
.81003 .31061 L
.81341 .30089 L
.81566 .29438 L
.81673 .29118 L
.82005 .28147 L
.82341 .27176 L
.82537 .26601 L
.82669 .26204 L
.82999 .25233 L
.83331 .24262 L
.83508 .2374 L
.83656 .23291 L
.83984 .22319 L
.84314 .21348 L
.84479 .20854 L
.84635 .20377 L
.8496 .19406 L
.85287 .18434 L
.85451 .17943 L
.85606 .17463 L
.85929 .16492 L
.86253 .15521 L
.86422 .15008 L
.86569 .14549 L
.86889 .13578 L
.8721 .12607 L
.87393 .12049 L
.87524 .11636 L
.87841 .10664 L
.8816 .09693 L
.88364 .09065 L
.88472 .08722 L
.88786 .07751 L
.89103 .06779 L
.89336 .06058 L
.89413 .05808 L
.89723 .04837 L
.90038 .03866 L
.90307 .03028 L
.90348 .02894 L
.90654 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.5413 .98077 m
.54371 .97583 L
.54601 .97106 L
.5507 .96134 L
.55342 .95568 L
.55534 .95163 L
.55995 .94192 L
.56313 .93518 L
.56452 .93221 L
.56906 .92249 L
.57284 .91434 L
.57356 .91278 L
.57802 .90307 L
.58247 .89336 L
.58256 .89316 L
.58686 .88364 L
.59124 .87393 L
.59227 .87165 L
.59557 .86422 L
.5999 .85451 L
.60198 .8498 L
.60418 .84479 L
.60844 .83508 L
.61169 .82764 L
.61267 .82537 L
.61688 .81566 L
.62107 .80594 L
.62141 .80516 L
.62521 .79623 L
.62936 .78652 L
.63112 .78236 L
.63345 .77681 L
.63755 .76709 L
.64083 .75926 L
.64161 .75738 L
.64564 .74767 L
.64967 .73796 L
.65054 .73585 L
.65365 .72824 L
.65764 .71853 L
.66026 .71214 L
.66159 .70882 L
.66553 .69911 L
.66946 .68939 L
.66997 .68813 L
.67333 .67968 L
.67723 .66997 L
.67968 .66382 L
.68108 .66026 L
.68492 .65054 L
Mistroke
.68876 .64083 L
.68939 .63922 L
.69255 .63112 L
.69635 .62141 L
.69911 .61434 L
.70012 .61169 L
.70387 .60198 L
.70763 .59227 L
.70882 .58917 L
.71133 .58256 L
.71505 .57284 L
.71853 .56372 L
.71875 .56313 L
.72241 .55342 L
.72609 .54371 L
.72824 .53799 L
.72972 .53399 L
.73336 .52428 L
.737 .51457 L
.73796 .51199 L
.74057 .50486 L
.74418 .49514 L
.74767 .48572 L
.74777 .48543 L
.75131 .47572 L
.75488 .46601 L
.75738 .45917 L
.75841 .45629 L
.76193 .44658 L
.76546 .43687 L
.76709 .43236 L
.76894 .42716 L
.77243 .41744 L
.77593 .40773 L
.77681 .40528 L
.77936 .39802 L
.78283 .38831 L
.78629 .37859 L
.78652 .37794 L
.78968 .36888 L
.79312 .35917 L
.79623 .35034 L
.79653 .34946 L
.7999 .33974 L
.80331 .33003 L
.80594 .32249 L
.80668 .32032 L
.81003 .31061 L
.81341 .30089 L
.81566 .29438 L
Mistroke
.81673 .29118 L
.82005 .28147 L
.82341 .27176 L
.82537 .26601 L
.82669 .26204 L
.82999 .25233 L
.83331 .24262 L
.83508 .2374 L
.83656 .23291 L
.83984 .22319 L
.84314 .21348 L
.84479 .20854 L
.84635 .20377 L
.8496 .19406 L
.85287 .18434 L
.85451 .17943 L
.85606 .17463 L
.85929 .16492 L
.86253 .15521 L
.86422 .15008 L
.86569 .14549 L
.86889 .13578 L
.8721 .12607 L
.87393 .12049 L
.87524 .11636 L
.87841 .10664 L
.8816 .09693 L
.88364 .09065 L
.88472 .08722 L
.88786 .07751 L
.89103 .06779 L
.89336 .06058 L
.89413 .05808 L
.89723 .04837 L
.90038 .03866 L
.90307 .03028 L
.90348 .02894 L
.90654 .01923 L
Mfstroke
.3 g
.55403 .98077 m
.55855 .97106 L
.56313 .96137 L
.56314 .96134 L
.56755 .95163 L
.57208 .94192 L
.57284 .94027 L
.57642 .93221 L
.58088 .92249 L
.58256 .91883 L
.58518 .91278 L
.58957 .90307 L
.59227 .89708 L
.59384 .89336 L
.59813 .88364 L
.60198 .87502 L
.60243 .87393 L
.60659 .86422 L
.61088 .85451 L
.61169 .85264 L
.61496 .84479 L
.61918 .83508 L
.62141 .82995 L
.62326 .82537 L
.62738 .81566 L
.63112 .80696 L
.63151 .80594 L
.6355 .79623 L
.63962 .78652 L
.64083 .78366 L
.64355 .77681 L
.6476 .76709 L
.65054 .76006 L
.65156 .75738 L
.65549 .74767 L
.65952 .73796 L
.66026 .73617 L
.66332 .72824 L
.66729 .71853 L
.66997 .71198 L
.67114 .70882 L
.67498 .69911 L
.67892 .68939 L
.67968 .68751 L
.68263 .67968 L
.68651 .66997 L
.68939 .66275 L
.69028 .66026 L
.69402 .65054 L
.69788 .64083 L
.69911 .63771 L
.7015 .63112 L
.70528 .62141 L
.70882 .61239 L
.70906 .61169 L
.71264 .60198 L
.71641 .59227 L
.71853 .58679 L
.72 .58256 L
.72366 .57284 L
.7274 .56313 L
.72824 .56092 L
.73088 .55342 L
.73456 .54371 L
.73796 .53478 L
.73821 .53399 L
.74167 .52428 L
.74534 .51457 L
.74767 .50837 L
.74883 .50486 L
.75235 .49514 L
.75599 .48543 L
.75738 .48169 L
.75938 .47572 L
.76292 .46601 L
.76653 .45629 L
.76709 .45475 L
.76984 .44658 L
.77339 .43687 L
.77681 .42755 L
.77693 .42716 L
.78021 .41744 L
.78374 .40773 L
.78652 .40009 L
.78715 .39802 L
.79048 .38831 L
.79399 .37859 L
.79623 .37237 L
.79731 .36888 L
.80066 .35917 L
.80414 .34946 L
.80594 .3444 L
.80738 .33974 L
.81074 .33003 L
.8142 .32032 L
.81566 .31618 L
.81737 .31061 L
.82072 .30089 L
.82415 .29118 L
.82537 .2877 L
.82728 .28147 L
.83062 .27176 L
.83402 .26204 L
.83508 .25898 L
.83711 .25233 L
.84043 .24262 L
.8438 .23291 L
.84479 .23002 L
.84685 .22319 L
.85015 .21348 L
.8535 .20377 L
.85451 .20081 L
.85652 .19406 L
.85978 .18434 L
.86311 .17463 L
.86422 .17136 L
.86611 .16492 L
.86934 .15521 L
.87265 .14549 L
.87393 .14167 L
.87562 .13578 L
.87882 .12607 L
.8821 .11636 L
.88364 .11174 L
.88507 .10664 L
.88822 .09693 L
.89148 .08722 L
.89336 .08157 L
.89446 .07751 L
.89755 .06779 L
.90079 .05808 L
.90307 .05118 L
.9038 .04837 L
.90681 .03866 L
.91002 .02894 L
.91278 .02056 L
.91311 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.55403 .98077 m
.55855 .97106 L
.56313 .96137 L
.56314 .96134 L
.56755 .95163 L
.57208 .94192 L
.57284 .94027 L
.57642 .93221 L
.58088 .92249 L
.58256 .91883 L
.58518 .91278 L
.58957 .90307 L
.59227 .89708 L
.59384 .89336 L
.59813 .88364 L
.60198 .87502 L
.60243 .87393 L
.60659 .86422 L
.61088 .85451 L
.61169 .85264 L
.61496 .84479 L
.61918 .83508 L
.62141 .82995 L
.62326 .82537 L
.62738 .81566 L
.63112 .80696 L
.63151 .80594 L
.6355 .79623 L
.63962 .78652 L
.64083 .78366 L
.64355 .77681 L
.6476 .76709 L
.65054 .76006 L
.65156 .75738 L
.65549 .74767 L
.65952 .73796 L
.66026 .73617 L
.66332 .72824 L
.66729 .71853 L
.66997 .71198 L
.67114 .70882 L
.67498 .69911 L
.67892 .68939 L
.67968 .68751 L
.68263 .67968 L
.68651 .66997 L
.68939 .66275 L
.69028 .66026 L
.69402 .65054 L
.69788 .64083 L
Mistroke
.69911 .63771 L
.7015 .63112 L
.70528 .62141 L
.70882 .61239 L
.70906 .61169 L
.71264 .60198 L
.71641 .59227 L
.71853 .58679 L
.72 .58256 L
.72366 .57284 L
.7274 .56313 L
.72824 .56092 L
.73088 .55342 L
.73456 .54371 L
.73796 .53478 L
.73821 .53399 L
.74167 .52428 L
.74534 .51457 L
.74767 .50837 L
.74883 .50486 L
.75235 .49514 L
.75599 .48543 L
.75738 .48169 L
.75938 .47572 L
.76292 .46601 L
.76653 .45629 L
.76709 .45475 L
.76984 .44658 L
.77339 .43687 L
.77681 .42755 L
.77693 .42716 L
.78021 .41744 L
.78374 .40773 L
.78652 .40009 L
.78715 .39802 L
.79048 .38831 L
.79399 .37859 L
.79623 .37237 L
.79731 .36888 L
.80066 .35917 L
.80414 .34946 L
.80594 .3444 L
.80738 .33974 L
.81074 .33003 L
.8142 .32032 L
.81566 .31618 L
.81737 .31061 L
.82072 .30089 L
.82415 .29118 L
.82537 .2877 L
Mistroke
.82728 .28147 L
.83062 .27176 L
.83402 .26204 L
.83508 .25898 L
.83711 .25233 L
.84043 .24262 L
.8438 .23291 L
.84479 .23002 L
.84685 .22319 L
.85015 .21348 L
.8535 .20377 L
.85451 .20081 L
.85652 .19406 L
.85978 .18434 L
.86311 .17463 L
.86422 .17136 L
.86611 .16492 L
.86934 .15521 L
.87265 .14549 L
.87393 .14167 L
.87562 .13578 L
.87882 .12607 L
.8821 .11636 L
.88364 .11174 L
.88507 .10664 L
.88822 .09693 L
.89148 .08722 L
.89336 .08157 L
.89446 .07751 L
.89755 .06779 L
.90079 .05808 L
.90307 .05118 L
.9038 .04837 L
.90681 .03866 L
.91002 .02894 L
.91278 .02056 L
.91311 .01923 L
Mfstroke
.2 g
.57168 .98077 m
.57284 .97887 L
.57623 .97106 L
.57952 .96134 L
.58256 .95624 L
.58465 .95163 L
.58883 .94192 L
.59227 .93371 L
.59299 .93221 L
.59714 .92249 L
.60105 .91278 L
.60198 .911 L
.60537 .90307 L
.60865 .89336 L
.61169 .88783 L
.61352 .88364 L
.61572 .87393 L
.62141 .86461 L
.62159 .86422 L
.62561 .85451 L
.62918 .84479 L
.63112 .84097 L
.63358 .83508 L
.63628 .82537 L
.64083 .81713 L
.64146 .81566 L
.6454 .80594 L
.64899 .79623 L
.65054 .79303 L
.65319 .78652 L
.65596 .77681 L
.66026 .76865 L
.6609 .76709 L
.66476 .75738 L
.66823 .74767 L
.66997 .74401 L
.67238 .73796 L
.67496 .72824 L
.67968 .71914 L
.67993 .71853 L
.68371 .70882 L
.68695 .69911 L
.68939 .69393 L
.69117 .68939 L
.69332 .67968 L
.69848 .66997 L
.69911 .66856 L
.70228 .66026 L
.70513 .65054 L
.70882 .64284 L
.7096 .64083 L
.71326 .63112 L
.7165 .62141 L
.71853 .61689 L
.7205 .61169 L
.72266 .60198 L
.72758 .59227 L
.72824 .59072 L
.73128 .58256 L
.73394 .57284 L
.73796 .56425 L
.73838 .56313 L
.74194 .55342 L
.74492 .54371 L
.74767 .53751 L
.74897 .53399 L
.75058 .52428 L
.75567 .51457 L
.75738 .51055 L
.75945 .50486 L
.76152 .49514 L
.76623 .48543 L
.76709 .48335 L
.76983 .47572 L
.7722 .46601 L
.77665 .45629 L
.77681 .4559 L
.7801 .44658 L
.78268 .43687 L
.78652 .42816 L
.78688 .42716 L
.79028 .41744 L
.79299 .40773 L
.79623 .40018 L
.797 .39802 L
.80037 .38831 L
.80316 .37859 L
.80594 .37197 L
.80703 .36888 L
.80821 .35917 L
.81321 .34946 L
.81566 .34351 L
.81696 .33974 L
.81827 .33003 L
.82314 .32032 L
.82537 .31482 L
.82681 .31061 L
.82818 .30089 L
.83295 .29118 L
.83508 .28589 L
.83658 .28147 L
.83794 .27176 L
.84267 .26204 L
.84479 .25671 L
.84627 .25233 L
.84757 .24262 L
.85229 .23291 L
.85451 .2273 L
.85588 .22319 L
.85705 .21348 L
.8618 .20377 L
.86422 .19766 L
.86542 .19406 L
.8664 .18434 L
.87122 .17463 L
.87393 .16778 L
.87488 .16492 L
.87803 .15521 L
.88054 .14549 L
.88364 .13767 L
.88427 .13578 L
.8874 .12607 L
.88975 .11636 L
.89336 .10735 L
.89359 .10664 L
.8967 .09693 L
.89884 .08722 L
.9028 .07751 L
.90307 .07678 L
.90593 .06779 L
.90781 .05808 L
.9119 .04837 L
.91278 .04597 L
.9151 .03866 L
.91664 .02894 L
.9209 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.57168 .98077 m
.57284 .97887 L
.57623 .97106 L
.57952 .96134 L
.58256 .95624 L
.58465 .95163 L
.58883 .94192 L
.59227 .93371 L
.59299 .93221 L
.59714 .92249 L
.60105 .91278 L
.60198 .911 L
.60537 .90307 L
.60865 .89336 L
.61169 .88783 L
.61352 .88364 L
.61572 .87393 L
.62141 .86461 L
.62159 .86422 L
.62561 .85451 L
.62918 .84479 L
.63112 .84097 L
.63358 .83508 L
.63628 .82537 L
.64083 .81713 L
.64146 .81566 L
.6454 .80594 L
.64899 .79623 L
.65054 .79303 L
.65319 .78652 L
.65596 .77681 L
.66026 .76865 L
.6609 .76709 L
.66476 .75738 L
.66823 .74767 L
.66997 .74401 L
.67238 .73796 L
.67496 .72824 L
.67968 .71914 L
.67993 .71853 L
.68371 .70882 L
.68695 .69911 L
.68939 .69393 L
.69117 .68939 L
.69332 .67968 L
.69848 .66997 L
.69911 .66856 L
.70228 .66026 L
.70513 .65054 L
.70882 .64284 L
Mistroke
.7096 .64083 L
.71326 .63112 L
.7165 .62141 L
.71853 .61689 L
.7205 .61169 L
.72266 .60198 L
.72758 .59227 L
.72824 .59072 L
.73128 .58256 L
.73394 .57284 L
.73796 .56425 L
.73838 .56313 L
.74194 .55342 L
.74492 .54371 L
.74767 .53751 L
.74897 .53399 L
.75058 .52428 L
.75567 .51457 L
.75738 .51055 L
.75945 .50486 L
.76152 .49514 L
.76623 .48543 L
.76709 .48335 L
.76983 .47572 L
.7722 .46601 L
.77665 .45629 L
.77681 .4559 L
.7801 .44658 L
.78268 .43687 L
.78652 .42816 L
.78688 .42716 L
.79028 .41744 L
.79299 .40773 L
.79623 .40018 L
.797 .39802 L
.80037 .38831 L
.80316 .37859 L
.80594 .37197 L
.80703 .36888 L
.80821 .35917 L
.81321 .34946 L
.81566 .34351 L
.81696 .33974 L
.81827 .33003 L
.82314 .32032 L
.82537 .31482 L
.82681 .31061 L
.82818 .30089 L
.83295 .29118 L
.83508 .28589 L
Mistroke
.83658 .28147 L
.83794 .27176 L
.84267 .26204 L
.84479 .25671 L
.84627 .25233 L
.84757 .24262 L
.85229 .23291 L
.85451 .2273 L
.85588 .22319 L
.85705 .21348 L
.8618 .20377 L
.86422 .19766 L
.86542 .19406 L
.8664 .18434 L
.87122 .17463 L
.87393 .16778 L
.87488 .16492 L
.87803 .15521 L
.88054 .14549 L
.88364 .13767 L
.88427 .13578 L
.8874 .12607 L
.88975 .11636 L
.89336 .10735 L
.89359 .10664 L
.8967 .09693 L
.89884 .08722 L
.9028 .07751 L
.90307 .07678 L
.90593 .06779 L
.90781 .05808 L
.9119 .04837 L
.91278 .04597 L
.9151 .03866 L
.91664 .02894 L
.9209 .01923 L
Mfstroke
.3 g
.5953 .98077 m
.59986 .97106 L
.60198 .9667 L
.60437 .96134 L
.60885 .95163 L
.61169 .94556 L
.61399 .94192 L
.61769 .93221 L
.62141 .92403 L
.62229 .92249 L
.62639 .91278 L
.63071 .90307 L
.63112 .90221 L
.63496 .89336 L
.63921 .88364 L
.64083 .88006 L
.64456 .87393 L
.6476 .86422 L
.65054 .85745 L
.65215 .85451 L
.65588 .84479 L
.66 .83508 L
.66026 .83452 L
.66406 .82537 L
.66812 .81566 L
.66997 .81133 L
.67292 .80594 L
.67615 .79623 L
.67968 .7877 L
.68027 .78652 L
.68409 .77681 L
.68804 .76709 L
.68939 .76386 L
.69287 .75738 L
.69585 .74767 L
.69911 .7396 L
.6999 .73796 L
.70358 .72824 L
.70743 .71853 L
.70882 .71511 L
.71205 .70882 L
.71504 .69911 L
.71853 .69023 L
.71892 .68939 L
.72436 .67968 L
.72635 .66997 L
.72824 .66514 L
.7306 .66026 L
.73378 .65054 L
.7375 .64083 L
.73796 .63968 L
.74231 .63112 L
.74483 .62141 L
.74767 .61395 L
.74869 .61169 L
.75408 .60198 L
.75575 .59227 L
.75738 .58797 L
.7599 .58256 L
.76293 .57284 L
.76653 .56313 L
.76709 .56165 L
.77106 .55342 L
.77362 .54371 L
.77681 .53505 L
.77726 .53399 L
.78215 .52428 L
.7842 .51457 L
.78652 .50821 L
.78798 .50486 L
.79319 .49514 L
.79465 .48543 L
.79623 .48109 L
.7986 .47572 L
.80154 .46601 L
.805 .45629 L
.80594 .45368 L
.80912 .44658 L
.81181 .43687 L
.81524 .42716 L
.81566 .42599 L
.81953 .41744 L
.82198 .40773 L
.82537 .39803 L
.82537 .39802 L
.82981 .38831 L
.83205 .37859 L
.83508 .36984 L
.83547 .36888 L
.83996 .35917 L
.84202 .34946 L
.84479 .34139 L
.84545 .33974 L
.84998 .33003 L
.8519 .32032 L
.85451 .31267 L
.85533 .31061 L
.85986 .30089 L
.86169 .29118 L
.86422 .2837 L
.8651 .28147 L
.86961 .27176 L
.8714 .26204 L
.87393 .25448 L
.87477 .25233 L
.87922 .24262 L
.88102 .23291 L
.88364 .225 L
.88435 .22319 L
.8887 .21348 L
.89056 .20377 L
.89336 .19528 L
.89382 .19406 L
.89807 .18434 L
.90003 .17463 L
.90307 .16531 L
.90322 .16492 L
.90733 .15521 L
.90942 .14549 L
.91256 .13578 L
.91278 .13511 L
.91651 .12607 L
.91874 .11636 L
.92185 .10664 L
.92249 .10468 L
.9256 .09693 L
.92799 .08722 L
.93108 .07751 L
.93221 .074 L
.93462 .06779 L
.93717 .05808 L
.94023 .04837 L
.94192 .04307 L
.94359 .03866 L
.94803 .02894 L
.94932 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.5953 .98077 m
.59986 .97106 L
.60198 .9667 L
.60437 .96134 L
.60885 .95163 L
.61169 .94556 L
.61399 .94192 L
.61769 .93221 L
.62141 .92403 L
.62229 .92249 L
.62639 .91278 L
.63071 .90307 L
.63112 .90221 L
.63496 .89336 L
.63921 .88364 L
.64083 .88006 L
.64456 .87393 L
.6476 .86422 L
.65054 .85745 L
.65215 .85451 L
.65588 .84479 L
.66 .83508 L
.66026 .83452 L
.66406 .82537 L
.66812 .81566 L
.66997 .81133 L
.67292 .80594 L
.67615 .79623 L
.67968 .7877 L
.68027 .78652 L
.68409 .77681 L
.68804 .76709 L
.68939 .76386 L
.69287 .75738 L
.69585 .74767 L
.69911 .7396 L
.6999 .73796 L
.70358 .72824 L
.70743 .71853 L
.70882 .71511 L
.71205 .70882 L
.71504 .69911 L
.71853 .69023 L
.71892 .68939 L
.72436 .67968 L
.72635 .66997 L
.72824 .66514 L
.7306 .66026 L
.73378 .65054 L
.7375 .64083 L
Mistroke
.73796 .63968 L
.74231 .63112 L
.74483 .62141 L
.74767 .61395 L
.74869 .61169 L
.75408 .60198 L
.75575 .59227 L
.75738 .58797 L
.7599 .58256 L
.76293 .57284 L
.76653 .56313 L
.76709 .56165 L
.77106 .55342 L
.77362 .54371 L
.77681 .53505 L
.77726 .53399 L
.78215 .52428 L
.7842 .51457 L
.78652 .50821 L
.78798 .50486 L
.79319 .49514 L
.79465 .48543 L
.79623 .48109 L
.7986 .47572 L
.80154 .46601 L
.805 .45629 L
.80594 .45368 L
.80912 .44658 L
.81181 .43687 L
.81524 .42716 L
.81566 .42599 L
.81953 .41744 L
.82198 .40773 L
.82537 .39803 L
.82537 .39802 L
.82981 .38831 L
.83205 .37859 L
.83508 .36984 L
.83547 .36888 L
.83996 .35917 L
.84202 .34946 L
.84479 .34139 L
.84545 .33974 L
.84998 .33003 L
.8519 .32032 L
.85451 .31267 L
.85533 .31061 L
.85986 .30089 L
.86169 .29118 L
.86422 .2837 L
Mistroke
.8651 .28147 L
.86961 .27176 L
.8714 .26204 L
.87393 .25448 L
.87477 .25233 L
.87922 .24262 L
.88102 .23291 L
.88364 .225 L
.88435 .22319 L
.8887 .21348 L
.89056 .20377 L
.89336 .19528 L
.89382 .19406 L
.89807 .18434 L
.90003 .17463 L
.90307 .16531 L
.90322 .16492 L
.90733 .15521 L
.90942 .14549 L
.91256 .13578 L
.91278 .13511 L
.91651 .12607 L
.91874 .11636 L
.92185 .10664 L
.92249 .10468 L
.9256 .09693 L
.92799 .08722 L
.93108 .07751 L
.93221 .074 L
.93462 .06779 L
.93717 .05808 L
.94023 .04837 L
.94192 .04307 L
.94359 .03866 L
.94803 .02894 L
.94932 .01923 L
Mfstroke
.4 g
.6117 .98077 m
.61611 .97106 L
.62034 .96134 L
.62141 .95869 L
.62456 .95163 L
.62882 .94192 L
.63112 .93626 L
.6329 .93221 L
.63716 .92249 L
.64083 .91349 L
.64114 .91278 L
.64536 .90307 L
.64942 .89336 L
.65054 .89043 L
.65345 .88364 L
.65757 .87393 L
.66026 .86704 L
.66145 .86422 L
.66556 .85451 L
.66944 .84479 L
.66997 .84334 L
.67343 .83508 L
.67742 .82537 L
.67968 .81934 L
.6812 .81566 L
.68521 .80594 L
.68898 .79623 L
.68939 .79504 L
.69288 .78652 L
.69678 .77681 L
.69911 .77044 L
.70046 .76709 L
.70438 .75738 L
.70809 .74767 L
.70882 .74555 L
.71185 .73796 L
.71569 .72824 L
.71853 .72037 L
.71925 .71853 L
.7231 .70882 L
.7268 .69911 L
.72824 .6949 L
.7304 .68939 L
.73418 .67968 L
.73769 .66997 L
.73796 .66915 L
.7414 .66026 L
.74511 .65054 L
.74767 .64312 L
.74854 .64083 L
.75227 .63112 L
.75587 .62141 L
.75738 .61682 L
.75932 .61169 L
.76301 .60198 L
.76646 .59227 L
.76709 .59024 L
.76998 .58256 L
.77361 .57284 L
.77681 .56339 L
.7769 .56313 L
.78052 .55342 L
.78409 .54371 L
.78652 .53627 L
.78736 .53399 L
.79095 .52428 L
.79444 .51457 L
.79623 .5089 L
.7977 .50486 L
.80126 .49514 L
.80467 .48543 L
.80594 .48125 L
.80795 .47572 L
.81147 .46601 L
.81479 .45629 L
.81566 .45335 L
.81809 .44658 L
.82158 .43687 L
.82481 .42716 L
.82537 .42519 L
.82813 .41744 L
.83158 .40773 L
.83474 .39802 L
.83508 .39677 L
.83807 .38831 L
.8415 .37859 L
.84459 .36888 L
.84479 .3681 L
.84793 .35917 L
.85132 .34946 L
.85436 .33974 L
.85451 .33918 L
.85769 .33003 L
.86106 .32032 L
.86407 .31061 L
.86422 .31002 L
.86737 .30089 L
.87071 .29118 L
.87371 .28147 L
.87393 .2806 L
.87696 .27176 L
.88029 .26204 L
.88329 .25233 L
.88364 .25095 L
.88647 .24262 L
.88978 .23291 L
.89281 .22319 L
.89336 .22105 L
.89591 .21348 L
.8992 .20377 L
.90225 .19406 L
.90307 .19092 L
.90526 .18434 L
.90853 .17463 L
.91163 .16492 L
.91278 .16054 L
.91455 .15521 L
.9178 .14549 L
.92092 .13578 L
.92249 .12993 L
.92376 .12607 L
.92699 .11636 L
.93014 .10664 L
.93221 .09908 L
.93291 .09693 L
.9361 .08722 L
.93927 .07751 L
.94192 .068 L
.94199 .06779 L
.94515 .05808 L
.94832 .04837 L
.95118 .03866 L
.95163 .0367 L
.95413 .02894 L
.9573 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.6117 .98077 m
.61611 .97106 L
.62034 .96134 L
.62141 .95869 L
.62456 .95163 L
.62882 .94192 L
.63112 .93626 L
.6329 .93221 L
.63716 .92249 L
.64083 .91349 L
.64114 .91278 L
.64536 .90307 L
.64942 .89336 L
.65054 .89043 L
.65345 .88364 L
.65757 .87393 L
.66026 .86704 L
.66145 .86422 L
.66556 .85451 L
.66944 .84479 L
.66997 .84334 L
.67343 .83508 L
.67742 .82537 L
.67968 .81934 L
.6812 .81566 L
.68521 .80594 L
.68898 .79623 L
.68939 .79504 L
.69288 .78652 L
.69678 .77681 L
.69911 .77044 L
.70046 .76709 L
.70438 .75738 L
.70809 .74767 L
.70882 .74555 L
.71185 .73796 L
.71569 .72824 L
.71853 .72037 L
.71925 .71853 L
.7231 .70882 L
.7268 .69911 L
.72824 .6949 L
.7304 .68939 L
.73418 .67968 L
.73769 .66997 L
.73796 .66915 L
.7414 .66026 L
.74511 .65054 L
.74767 .64312 L
.74854 .64083 L
Mistroke
.75227 .63112 L
.75587 .62141 L
.75738 .61682 L
.75932 .61169 L
.76301 .60198 L
.76646 .59227 L
.76709 .59024 L
.76998 .58256 L
.77361 .57284 L
.77681 .56339 L
.7769 .56313 L
.78052 .55342 L
.78409 .54371 L
.78652 .53627 L
.78736 .53399 L
.79095 .52428 L
.79444 .51457 L
.79623 .5089 L
.7977 .50486 L
.80126 .49514 L
.80467 .48543 L
.80594 .48125 L
.80795 .47572 L
.81147 .46601 L
.81479 .45629 L
.81566 .45335 L
.81809 .44658 L
.82158 .43687 L
.82481 .42716 L
.82537 .42519 L
.82813 .41744 L
.83158 .40773 L
.83474 .39802 L
.83508 .39677 L
.83807 .38831 L
.8415 .37859 L
.84459 .36888 L
.84479 .3681 L
.84793 .35917 L
.85132 .34946 L
.85436 .33974 L
.85451 .33918 L
.85769 .33003 L
.86106 .32032 L
.86407 .31061 L
.86422 .31002 L
.86737 .30089 L
.87071 .29118 L
.87371 .28147 L
.87393 .2806 L
Mistroke
.87696 .27176 L
.88029 .26204 L
.88329 .25233 L
.88364 .25095 L
.88647 .24262 L
.88978 .23291 L
.89281 .22319 L
.89336 .22105 L
.89591 .21348 L
.8992 .20377 L
.90225 .19406 L
.90307 .19092 L
.90526 .18434 L
.90853 .17463 L
.91163 .16492 L
.91278 .16054 L
.91455 .15521 L
.9178 .14549 L
.92092 .13578 L
.92249 .12993 L
.92376 .12607 L
.92699 .11636 L
.93014 .10664 L
.93221 .09908 L
.93291 .09693 L
.9361 .08722 L
.93927 .07751 L
.94192 .068 L
.94199 .06779 L
.94515 .05808 L
.94832 .04837 L
.95118 .03866 L
.95163 .0367 L
.95413 .02894 L
.9573 .01923 L
Mfstroke
.5 g
.62258 .98077 m
.62678 .97106 L
.63091 .96134 L
.63112 .96084 L
.63505 .95163 L
.63916 .94192 L
.64083 .9379 L
.64323 .93221 L
.64731 .92249 L
.65054 .91463 L
.65131 .91278 L
.65535 .90307 L
.65933 .89336 L
.66026 .89107 L
.66331 .88364 L
.66727 .87393 L
.66997 .8672 L
.67118 .86422 L
.67511 .85451 L
.67899 .84479 L
.67968 .84303 L
.68287 .83508 L
.68674 .82537 L
.68939 .81857 L
.69055 .81566 L
.69439 .80594 L
.69818 .79623 L
.69911 .79381 L
.70196 .78652 L
.70575 .77681 L
.70882 .76877 L
.70947 .76709 L
.71323 .75738 L
.71695 .74767 L
.71853 .74344 L
.72063 .73796 L
.72434 .72824 L
.72799 .71853 L
.72824 .71783 L
.73166 .70882 L
.73532 .69911 L
.73796 .69194 L
.73891 .68939 L
.74255 .67968 L
.74615 .66997 L
.74767 .66578 L
.74972 .66026 L
.75332 .65054 L
.75685 .64083 L
.75738 .63934 L
.7604 .63112 L
.76396 .62141 L
.76709 .61263 L
.76743 .61169 L
.77097 .60198 L
.77448 .59227 L
.77681 .58566 L
.77792 .58256 L
.78142 .57284 L
.78489 .56313 L
.78652 .55842 L
.7883 .55342 L
.79177 .54371 L
.79518 .53399 L
.79623 .53092 L
.79858 .52428 L
.80201 .51457 L
.80537 .50486 L
.80594 .50317 L
.80875 .49514 L
.81215 .48543 L
.81547 .47572 L
.81566 .47515 L
.81883 .46601 L
.8222 .45629 L
.82537 .44688 L
.82547 .44658 L
.82881 .43687 L
.83215 .42716 L
.83508 .41836 L
.83539 .41744 L
.83871 .40773 L
.84201 .39802 L
.84479 .38958 L
.84522 .38831 L
.84851 .37859 L
.85179 .36888 L
.85451 .36056 L
.85497 .35917 L
.85823 .34946 L
.86148 .33974 L
.86422 .3313 L
.86464 .33003 L
.86787 .32032 L
.8711 .31061 L
.87393 .30179 L
.87422 .30089 L
.87743 .29118 L
.88063 .28147 L
.88364 .27203 L
.88373 .27176 L
.88691 .26204 L
.89009 .25233 L
.89318 .24262 L
.89336 .24204 L
.89632 .23291 L
.89948 .22319 L
.90256 .21348 L
.90307 .21182 L
.90566 .20377 L
.9088 .19406 L
.91187 .18434 L
.91278 .18135 L
.91492 .17463 L
.91804 .16492 L
.92111 .15521 L
.92249 .15065 L
.92412 .14549 L
.92722 .13578 L
.93028 .12607 L
.93221 .11972 L
.93326 .11636 L
.93633 .10664 L
.93939 .09693 L
.94192 .08856 L
.94233 .08722 L
.94538 .07751 L
.94842 .06779 L
.95137 .05808 L
.95163 .05717 L
.95436 .04837 L
.95739 .03866 L
.96035 .02894 L
.96134 .02555 L
.96328 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.62258 .98077 m
.62678 .97106 L
.63091 .96134 L
.63112 .96084 L
.63505 .95163 L
.63916 .94192 L
.64083 .9379 L
.64323 .93221 L
.64731 .92249 L
.65054 .91463 L
.65131 .91278 L
.65535 .90307 L
.65933 .89336 L
.66026 .89107 L
.66331 .88364 L
.66727 .87393 L
.66997 .8672 L
.67118 .86422 L
.67511 .85451 L
.67899 .84479 L
.67968 .84303 L
.68287 .83508 L
.68674 .82537 L
.68939 .81857 L
.69055 .81566 L
.69439 .80594 L
.69818 .79623 L
.69911 .79381 L
.70196 .78652 L
.70575 .77681 L
.70882 .76877 L
.70947 .76709 L
.71323 .75738 L
.71695 .74767 L
.71853 .74344 L
.72063 .73796 L
.72434 .72824 L
.72799 .71853 L
.72824 .71783 L
.73166 .70882 L
.73532 .69911 L
.73796 .69194 L
.73891 .68939 L
.74255 .67968 L
.74615 .66997 L
.74767 .66578 L
.74972 .66026 L
.75332 .65054 L
.75685 .64083 L
.75738 .63934 L
Mistroke
.7604 .63112 L
.76396 .62141 L
.76709 .61263 L
.76743 .61169 L
.77097 .60198 L
.77448 .59227 L
.77681 .58566 L
.77792 .58256 L
.78142 .57284 L
.78489 .56313 L
.78652 .55842 L
.7883 .55342 L
.79177 .54371 L
.79518 .53399 L
.79623 .53092 L
.79858 .52428 L
.80201 .51457 L
.80537 .50486 L
.80594 .50317 L
.80875 .49514 L
.81215 .48543 L
.81547 .47572 L
.81566 .47515 L
.81883 .46601 L
.8222 .45629 L
.82537 .44688 L
.82547 .44658 L
.82881 .43687 L
.83215 .42716 L
.83508 .41836 L
.83539 .41744 L
.83871 .40773 L
.84201 .39802 L
.84479 .38958 L
.84522 .38831 L
.84851 .37859 L
.85179 .36888 L
.85451 .36056 L
.85497 .35917 L
.85823 .34946 L
.86148 .33974 L
.86422 .3313 L
.86464 .33003 L
.86787 .32032 L
.8711 .31061 L
.87393 .30179 L
.87422 .30089 L
.87743 .29118 L
.88063 .28147 L
.88364 .27203 L
Mistroke
.88373 .27176 L
.88691 .26204 L
.89009 .25233 L
.89318 .24262 L
.89336 .24204 L
.89632 .23291 L
.89948 .22319 L
.90256 .21348 L
.90307 .21182 L
.90566 .20377 L
.9088 .19406 L
.91187 .18434 L
.91278 .18135 L
.91492 .17463 L
.91804 .16492 L
.92111 .15521 L
.92249 .15065 L
.92412 .14549 L
.92722 .13578 L
.93028 .12607 L
.93221 .11972 L
.93326 .11636 L
.93633 .10664 L
.93939 .09693 L
.94192 .08856 L
.94233 .08722 L
.94538 .07751 L
.94842 .06779 L
.95137 .05808 L
.95163 .05717 L
.95436 .04837 L
.95739 .03866 L
.96035 .02894 L
.96134 .02555 L
.96328 .01923 L
Mfstroke
.6 g
.63237 .98077 m
.63646 .97106 L
.64054 .96134 L
.64083 .96064 L
.64457 .95163 L
.64861 .94192 L
.65054 .93723 L
.65259 .93221 L
.65659 .92249 L
.66026 .91352 L
.66055 .91278 L
.66448 .90307 L
.66842 .89336 L
.66997 .88951 L
.6723 .88364 L
.6762 .87393 L
.67968 .8652 L
.68007 .86422 L
.6839 .85451 L
.68775 .84479 L
.68939 .84061 L
.69154 .83508 L
.69534 .82537 L
.69911 .81573 L
.69913 .81566 L
.70287 .80594 L
.70663 .79623 L
.70882 .79056 L
.71035 .78652 L
.71406 .77681 L
.71778 .76709 L
.71853 .76511 L
.72143 .75738 L
.72512 .74767 L
.72824 .73938 L
.72877 .73796 L
.73239 .72824 L
.73604 .71853 L
.73796 .71337 L
.73962 .70882 L
.74322 .69911 L
.74682 .68939 L
.74767 .6871 L
.75036 .67968 L
.75393 .66997 L
.75738 .66055 L
.75749 .66026 L
.76099 .65054 L
.76453 .64083 L
.76709 .63374 L
.76802 .63112 L
.7715 .62141 L
.77501 .61169 L
.77681 .60666 L
.77845 .60198 L
.78191 .59227 L
.78538 .58256 L
.78652 .57932 L
.78877 .57284 L
.79221 .56313 L
.79564 .55342 L
.79623 .55173 L
.799 .54371 L
.80241 .53399 L
.8058 .52428 L
.80594 .52387 L
.80913 .51457 L
.81251 .50486 L
.81566 .49576 L
.81586 .49514 L
.81917 .48543 L
.82252 .47572 L
.82537 .4674 L
.82583 .46601 L
.82911 .45629 L
.83243 .44658 L
.83508 .43878 L
.83571 .43687 L
.83897 .42716 L
.84226 .41744 L
.84479 .40992 L
.84551 .40773 L
.84874 .39802 L
.85201 .38831 L
.85451 .38082 L
.85522 .37859 L
.85842 .36888 L
.86167 .35917 L
.86422 .35146 L
.86486 .34946 L
.86803 .33974 L
.87125 .33003 L
.87393 .32187 L
.87442 .32032 L
.87756 .31061 L
.88076 .30089 L
.88364 .29204 L
.88391 .29118 L
.88702 .28147 L
.89019 .27176 L
.89333 .26204 L
.89336 .26197 L
.8964 .25233 L
.89955 .24262 L
.90267 .23291 L
.90307 .23166 L
.90572 .22319 L
.90883 .21348 L
.91194 .20377 L
.91278 .20112 L
.91496 .19406 L
.91805 .18434 L
.92115 .17463 L
.92249 .17034 L
.92415 .16492 L
.9272 .15521 L
.93028 .14549 L
.93221 .13934 L
.93328 .13578 L
.93629 .12607 L
.93935 .11636 L
.94192 .1081 L
.94235 .10664 L
.94532 .09693 L
.94836 .08722 L
.95137 .07751 L
.95163 .07664 L
.95429 .06779 L
.9573 .05808 L
.9603 .04837 L
.96134 .04495 L
.96321 .03866 L
.96618 .02894 L
.96918 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.63237 .98077 m
.63646 .97106 L
.64054 .96134 L
.64083 .96064 L
.64457 .95163 L
.64861 .94192 L
.65054 .93723 L
.65259 .93221 L
.65659 .92249 L
.66026 .91352 L
.66055 .91278 L
.66448 .90307 L
.66842 .89336 L
.66997 .88951 L
.6723 .88364 L
.6762 .87393 L
.67968 .8652 L
.68007 .86422 L
.6839 .85451 L
.68775 .84479 L
.68939 .84061 L
.69154 .83508 L
.69534 .82537 L
.69911 .81573 L
.69913 .81566 L
.70287 .80594 L
.70663 .79623 L
.70882 .79056 L
.71035 .78652 L
.71406 .77681 L
.71778 .76709 L
.71853 .76511 L
.72143 .75738 L
.72512 .74767 L
.72824 .73938 L
.72877 .73796 L
.73239 .72824 L
.73604 .71853 L
.73796 .71337 L
.73962 .70882 L
.74322 .69911 L
.74682 .68939 L
.74767 .6871 L
.75036 .67968 L
.75393 .66997 L
.75738 .66055 L
.75749 .66026 L
.76099 .65054 L
.76453 .64083 L
.76709 .63374 L
Mistroke
.76802 .63112 L
.7715 .62141 L
.77501 .61169 L
.77681 .60666 L
.77845 .60198 L
.78191 .59227 L
.78538 .58256 L
.78652 .57932 L
.78877 .57284 L
.79221 .56313 L
.79564 .55342 L
.79623 .55173 L
.799 .54371 L
.80241 .53399 L
.8058 .52428 L
.80594 .52387 L
.80913 .51457 L
.81251 .50486 L
.81566 .49576 L
.81586 .49514 L
.81917 .48543 L
.82252 .47572 L
.82537 .4674 L
.82583 .46601 L
.82911 .45629 L
.83243 .44658 L
.83508 .43878 L
.83571 .43687 L
.83897 .42716 L
.84226 .41744 L
.84479 .40992 L
.84551 .40773 L
.84874 .39802 L
.85201 .38831 L
.85451 .38082 L
.85522 .37859 L
.85842 .36888 L
.86167 .35917 L
.86422 .35146 L
.86486 .34946 L
.86803 .33974 L
.87125 .33003 L
.87393 .32187 L
.87442 .32032 L
.87756 .31061 L
.88076 .30089 L
.88364 .29204 L
.88391 .29118 L
.88702 .28147 L
.89019 .27176 L
Mistroke
.89333 .26204 L
.89336 .26197 L
.8964 .25233 L
.89955 .24262 L
.90267 .23291 L
.90307 .23166 L
.90572 .22319 L
.90883 .21348 L
.91194 .20377 L
.91278 .20112 L
.91496 .19406 L
.91805 .18434 L
.92115 .17463 L
.92249 .17034 L
.92415 .16492 L
.9272 .15521 L
.93028 .14549 L
.93221 .13934 L
.93328 .13578 L
.93629 .12607 L
.93935 .11636 L
.94192 .1081 L
.94235 .10664 L
.94532 .09693 L
.94836 .08722 L
.95137 .07751 L
.95163 .07664 L
.95429 .06779 L
.9573 .05808 L
.9603 .04837 L
.96134 .04495 L
.96321 .03866 L
.96618 .02894 L
.96918 .01923 L
Mfstroke
.7 g
.6425 .98077 m
.64652 .97106 L
.65054 .96145 L
.65058 .96134 L
.65443 .95163 L
.65845 .94192 L
.66026 .93755 L
.6623 .93221 L
.66623 .92249 L
.66997 .91337 L
.67018 .91278 L
.67394 .90307 L
.67788 .89336 L
.67968 .88889 L
.68163 .88364 L
.68547 .87393 L
.68936 .86422 L
.68939 .86414 L
.693 .85451 L
.69685 .84479 L
.69911 .83909 L
.70054 .83508 L
.70427 .82537 L
.70809 .81566 L
.70882 .81378 L
.71165 .80594 L
.71541 .79623 L
.71853 .78818 L
.71909 .78652 L
.72267 .77681 L
.72641 .76709 L
.72824 .7623 L
.72994 .75738 L
.73357 .74767 L
.73728 .73796 L
.73796 .73616 L
.74071 .72824 L
.74436 .71853 L
.74767 .70975 L
.74797 .70882 L
.75139 .69911 L
.75503 .68939 L
.75738 .68307 L
.75849 .67968 L
.76197 .66997 L
.76558 .66026 L
.76709 .65613 L
.76893 .65054 L
.77244 .64083 L
.77601 .63112 L
.77681 .62893 L
.77929 .62141 L
.7828 .61169 L
.78634 .60198 L
.78652 .60148 L
.78956 .59227 L
.79306 .58256 L
.79623 .57376 L
.7965 .57284 L
.79974 .56313 L
.80322 .55342 L
.80594 .54578 L
.80656 .54371 L
.80982 .53399 L
.81328 .52428 L
.81566 .51756 L
.81655 .51457 L
.81982 .50486 L
.82325 .49514 L
.82537 .48909 L
.82645 .48543 L
.82972 .47572 L
.83312 .46601 L
.83508 .46037 L
.83628 .45629 L
.83953 .44658 L
.84291 .43687 L
.84479 .4314 L
.84603 .42716 L
.84926 .41744 L
.85261 .40773 L
.85451 .40219 L
.85571 .39802 L
.8589 .38831 L
.86223 .37859 L
.86422 .37274 L
.86531 .36888 L
.86846 .35917 L
.87177 .34946 L
.87393 .34305 L
.87484 .33974 L
.87795 .33003 L
.88123 .32032 L
.88364 .31312 L
.88432 .31061 L
.88736 .30089 L
.89062 .29118 L
.89336 .28296 L
.89374 .28147 L
.8967 .27176 L
.89993 .26204 L
.90307 .25256 L
.90313 .25233 L
.90597 .24262 L
.90917 .23291 L
.91237 .22319 L
.91278 .22193 L
.91518 .21348 L
.91834 .20377 L
.92153 .19406 L
.92249 .19107 L
.92434 .18434 L
.92744 .17463 L
.93061 .16492 L
.93221 .15997 L
.93345 .15521 L
.93647 .14549 L
.93963 .13578 L
.94192 .12865 L
.94255 .12607 L
.94545 .11636 L
.94858 .10664 L
.95163 .09711 L
.95167 .09693 L
.95437 .08722 L
.95747 .07751 L
.96057 .06779 L
.96134 .06534 L
.96326 .05808 L
.96629 .04837 L
.96939 .03866 L
.97106 .03335 L
.97242 .02894 L
.97536 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.6425 .98077 m
.64652 .97106 L
.65054 .96145 L
.65058 .96134 L
.65443 .95163 L
.65845 .94192 L
.66026 .93755 L
.6623 .93221 L
.66623 .92249 L
.66997 .91337 L
.67018 .91278 L
.67394 .90307 L
.67788 .89336 L
.67968 .88889 L
.68163 .88364 L
.68547 .87393 L
.68936 .86422 L
.68939 .86414 L
.693 .85451 L
.69685 .84479 L
.69911 .83909 L
.70054 .83508 L
.70427 .82537 L
.70809 .81566 L
.70882 .81378 L
.71165 .80594 L
.71541 .79623 L
.71853 .78818 L
.71909 .78652 L
.72267 .77681 L
.72641 .76709 L
.72824 .7623 L
.72994 .75738 L
.73357 .74767 L
.73728 .73796 L
.73796 .73616 L
.74071 .72824 L
.74436 .71853 L
.74767 .70975 L
.74797 .70882 L
.75139 .69911 L
.75503 .68939 L
.75738 .68307 L
.75849 .67968 L
.76197 .66997 L
.76558 .66026 L
.76709 .65613 L
.76893 .65054 L
.77244 .64083 L
.77601 .63112 L
Mistroke
.77681 .62893 L
.77929 .62141 L
.7828 .61169 L
.78634 .60198 L
.78652 .60148 L
.78956 .59227 L
.79306 .58256 L
.79623 .57376 L
.7965 .57284 L
.79974 .56313 L
.80322 .55342 L
.80594 .54578 L
.80656 .54371 L
.80982 .53399 L
.81328 .52428 L
.81566 .51756 L
.81655 .51457 L
.81982 .50486 L
.82325 .49514 L
.82537 .48909 L
.82645 .48543 L
.82972 .47572 L
.83312 .46601 L
.83508 .46037 L
.83628 .45629 L
.83953 .44658 L
.84291 .43687 L
.84479 .4314 L
.84603 .42716 L
.84926 .41744 L
.85261 .40773 L
.85451 .40219 L
.85571 .39802 L
.8589 .38831 L
.86223 .37859 L
.86422 .37274 L
.86531 .36888 L
.86846 .35917 L
.87177 .34946 L
.87393 .34305 L
.87484 .33974 L
.87795 .33003 L
.88123 .32032 L
.88364 .31312 L
.88432 .31061 L
.88736 .30089 L
.89062 .29118 L
.89336 .28296 L
.89374 .28147 L
.8967 .27176 L
Mistroke
.89993 .26204 L
.90307 .25256 L
.90313 .25233 L
.90597 .24262 L
.90917 .23291 L
.91237 .22319 L
.91278 .22193 L
.91518 .21348 L
.91834 .20377 L
.92153 .19406 L
.92249 .19107 L
.92434 .18434 L
.92744 .17463 L
.93061 .16492 L
.93221 .15997 L
.93345 .15521 L
.93647 .14549 L
.93963 .13578 L
.94192 .12865 L
.94255 .12607 L
.94545 .11636 L
.94858 .10664 L
.95163 .09711 L
.95167 .09693 L
.95437 .08722 L
.95747 .07751 L
.96057 .06779 L
.96134 .06534 L
.96326 .05808 L
.96629 .04837 L
.96939 .03866 L
.97106 .03335 L
.97242 .02894 L
.97536 .01923 L
Mfstroke
.8 g
.98077 .02559 m
.97981 .02894 L
.97706 .03866 L
.97416 .04837 L
.97106 .05787 L
.97098 .05808 L
.96726 .06779 L
.96516 .07751 L
.9622 .08722 L
.96134 .08998 L
.95876 .09693 L
.95428 .10664 L
.95335 .11636 L
.95163 .1219 L
.95012 .12607 L
.94596 .13578 L
.94444 .14549 L
.94192 .15361 L
.94135 .15521 L
.93743 .16492 L
.93547 .17463 L
.93244 .18434 L
.93221 .18508 L
.92872 .19406 L
.92644 .20377 L
.9234 .21348 L
.92249 .21631 L
.91987 .22319 L
.91526 .23291 L
.91429 .24262 L
.91278 .24734 L
.9109 .25233 L
.90652 .26204 L
.90512 .27176 L
.90307 .27814 L
.90183 .28147 L
.89761 .29118 L
.89588 .30089 L
.89336 .30873 L
.89266 .31061 L
.88856 .32032 L
.88657 .33003 L
.88364 .33908 L
.8834 .33974 L
.87938 .34946 L
.8772 .35917 L
.87404 .36888 L
.87393 .36919 L
.87008 .37859 L
.86775 .38831 L
.86457 .39802 L
.86422 .39906 L
.86068 .40773 L
.85823 .41744 L
.85503 .42716 L
.85451 .4287 L
.85116 .43687 L
.84864 .44658 L
.84541 .45629 L
.84479 .45811 L
.84155 .46601 L
.83897 .47572 L
.83572 .48543 L
.83508 .48728 L
.83182 .49514 L
.82922 .50486 L
.82594 .51457 L
.82537 .51622 L
.82198 .52428 L
.81939 .53399 L
.81608 .54371 L
.81566 .54492 L
.81203 .55342 L
.80948 .56313 L
.80613 .57284 L
.80594 .57338 L
.80195 .58256 L
.79948 .59227 L
.79623 .6016 L
.79608 .60198 L
.79173 .61169 L
.78938 .62141 L
.78652 .62955 L
.78589 .63112 L
.78135 .64083 L
.77919 .65054 L
.77681 .65726 L
.77556 .66026 L
.77078 .66997 L
.76891 .67968 L
.76709 .68471 L
.7651 .68939 L
.75998 .69911 L
.75852 .70882 L
.75738 .71193 L
.75447 .71853 L
.75155 .72824 L
.74803 .73796 L
.74767 .73892 L
.74362 .74767 L
.741 .75738 L
.73796 .76565 L
.73734 .76709 L
.73251 .77681 L
.73032 .78652 L
.72824 .79207 L
.72641 .79623 L
.72102 .80594 L
.71953 .81566 L
.71853 .81827 L
.71521 .82537 L
.71229 .83508 L
.70882 .84427 L
.70859 .84479 L
.70367 .85451 L
.7013 .86422 L
.69911 .86991 L
.69726 .87393 L
.69391 .88364 L
.69018 .89336 L
.68939 .89533 L
.68557 .90307 L
.68271 .91278 L
.67968 .92052 L
.67878 .92249 L
.67327 .93221 L
.67137 .94192 L
.66997 .94537 L
.66687 .95163 L
.66374 .96134 L
.66026 .97008 L
.6598 .97106 L
.65425 .98077 L
.98077 .98077 L
F
0 g
.98077 .02559 m
.97981 .02894 L
.97706 .03866 L
.97416 .04837 L
.97106 .05787 L
.97098 .05808 L
.96726 .06779 L
.96516 .07751 L
.9622 .08722 L
.96134 .08998 L
.95876 .09693 L
.95428 .10664 L
.95335 .11636 L
.95163 .1219 L
.95012 .12607 L
.94596 .13578 L
.94444 .14549 L
.94192 .15361 L
.94135 .15521 L
.93743 .16492 L
.93547 .17463 L
.93244 .18434 L
.93221 .18508 L
.92872 .19406 L
.92644 .20377 L
.9234 .21348 L
.92249 .21631 L
.91987 .22319 L
.91526 .23291 L
.91429 .24262 L
.91278 .24734 L
.9109 .25233 L
.90652 .26204 L
.90512 .27176 L
.90307 .27814 L
.90183 .28147 L
.89761 .29118 L
.89588 .30089 L
.89336 .30873 L
.89266 .31061 L
.88856 .32032 L
.88657 .33003 L
.88364 .33908 L
.8834 .33974 L
.87938 .34946 L
.8772 .35917 L
.87404 .36888 L
.87393 .36919 L
.87008 .37859 L
.86775 .38831 L
Mistroke
.86457 .39802 L
.86422 .39906 L
.86068 .40773 L
.85823 .41744 L
.85503 .42716 L
.85451 .4287 L
.85116 .43687 L
.84864 .44658 L
.84541 .45629 L
.84479 .45811 L
.84155 .46601 L
.83897 .47572 L
.83572 .48543 L
.83508 .48728 L
.83182 .49514 L
.82922 .50486 L
.82594 .51457 L
.82537 .51622 L
.82198 .52428 L
.81939 .53399 L
.81608 .54371 L
.81566 .54492 L
.81203 .55342 L
.80948 .56313 L
.80613 .57284 L
.80594 .57338 L
.80195 .58256 L
.79948 .59227 L
.79623 .6016 L
.79608 .60198 L
.79173 .61169 L
.78938 .62141 L
.78652 .62955 L
.78589 .63112 L
.78135 .64083 L
.77919 .65054 L
.77681 .65726 L
.77556 .66026 L
.77078 .66997 L
.76891 .67968 L
.76709 .68471 L
.7651 .68939 L
.75998 .69911 L
.75852 .70882 L
.75738 .71193 L
.75447 .71853 L
.75155 .72824 L
.74803 .73796 L
.74767 .73892 L
.74362 .74767 L
Mistroke
.741 .75738 L
.73796 .76565 L
.73734 .76709 L
.73251 .77681 L
.73032 .78652 L
.72824 .79207 L
.72641 .79623 L
.72102 .80594 L
.71953 .81566 L
.71853 .81827 L
.71521 .82537 L
.71229 .83508 L
.70882 .84427 L
.70859 .84479 L
.70367 .85451 L
.7013 .86422 L
.69911 .86991 L
.69726 .87393 L
.69391 .88364 L
.69018 .89336 L
.68939 .89533 L
.68557 .90307 L
.68271 .91278 L
.67968 .92052 L
.67878 .92249 L
.67327 .93221 L
.67137 .94192 L
.66997 .94537 L
.66687 .95163 L
.66374 .96134 L
.66026 .97008 L
.6598 .97106 L
.65425 .98077 L
Mfstroke
.7 g
.98077 .11842 m
.9785 .12607 L
.97555 .13578 L
.97254 .14549 L
.97106 .15029 L
.96952 .15521 L
.96653 .16492 L
.96415 .17463 L
.96134 .18191 L
.96057 .18434 L
.95755 .19406 L
.95544 .20377 L
.95163 .21327 L
.95157 .21348 L
.94852 .22319 L
.94671 .23291 L
.94259 .24262 L
.94192 .24444 L
.93942 .25233 L
.93795 .26204 L
.93358 .27176 L
.93221 .27537 L
.93025 .28147 L
.92914 .29118 L
.9245 .30089 L
.92249 .30607 L
.92102 .31061 L
.91791 .32032 L
.91536 .33003 L
.91278 .33651 L
.91172 .33974 L
.90859 .34946 L
.90614 .35917 L
.90307 .36672 L
.90235 .36888 L
.89919 .37859 L
.89683 .38831 L
.89336 .39667 L
.89291 .39802 L
.88972 .40773 L
.88742 .41744 L
.88364 .42639 L
.88338 .42716 L
.88017 .43687 L
.87791 .44658 L
.87393 .45585 L
.87378 .45629 L
.87054 .46601 L
.86828 .47572 L
.86422 .48508 L
.8641 .48543 L
.86082 .49514 L
.85853 .50486 L
.85451 .51405 L
.85433 .51457 L
.85102 .52428 L
.84865 .53399 L
.84479 .54277 L
.84447 .54371 L
.84114 .55342 L
.83865 .56313 L
.83508 .57124 L
.83452 .57284 L
.83116 .58256 L
.82852 .59227 L
.82537 .59945 L
.82447 .60198 L
.82108 .61169 L
.81826 .62141 L
.81566 .62739 L
.81433 .63112 L
.81091 .64083 L
.8079 .65054 L
.80594 .65506 L
.80408 .66026 L
.80244 .66997 L
.79742 .67968 L
.79623 .68246 L
.79373 .68939 L
.79161 .69911 L
.78684 .70882 L
.78652 .70957 L
.78326 .71853 L
.7807 .72824 L
.77681 .73645 L
.77624 .73796 L
.77268 .74767 L
.76971 .75738 L
.76709 .76305 L
.76557 .76709 L
.76198 .77681 L
.75864 .78652 L
.75738 .78933 L
.75478 .79623 L
.75244 .80594 L
.74767 .81532 L
.74754 .81566 L
.74386 .82537 L
.74087 .83508 L
.73796 .84109 L
.73651 .84479 L
.7328 .85451 L
.7293 .86422 L
.72824 .8665 L
.72535 .87393 L
.7227 .88364 L
.71853 .89165 L
.71784 .89336 L
.71403 .90307 L
.71063 .91278 L
.70882 .91648 L
.70641 .92249 L
.70398 .93221 L
.69911 .94099 L
.69872 .94192 L
.69481 .95163 L
.69137 .96134 L
.68939 .96523 L
.68699 .97106 L
.68449 .98077 L
.98077 .98077 L
F
0 g
.98077 .11842 m
.9785 .12607 L
.97555 .13578 L
.97254 .14549 L
.97106 .15029 L
.96952 .15521 L
.96653 .16492 L
.96415 .17463 L
.96134 .18191 L
.96057 .18434 L
.95755 .19406 L
.95544 .20377 L
.95163 .21327 L
.95157 .21348 L
.94852 .22319 L
.94671 .23291 L
.94259 .24262 L
.94192 .24444 L
.93942 .25233 L
.93795 .26204 L
.93358 .27176 L
.93221 .27537 L
.93025 .28147 L
.92914 .29118 L
.9245 .30089 L
.92249 .30607 L
.92102 .31061 L
.91791 .32032 L
.91536 .33003 L
.91278 .33651 L
.91172 .33974 L
.90859 .34946 L
.90614 .35917 L
.90307 .36672 L
.90235 .36888 L
.89919 .37859 L
.89683 .38831 L
.89336 .39667 L
.89291 .39802 L
.88972 .40773 L
.88742 .41744 L
.88364 .42639 L
.88338 .42716 L
.88017 .43687 L
.87791 .44658 L
.87393 .45585 L
.87378 .45629 L
.87054 .46601 L
.86828 .47572 L
.86422 .48508 L
Mistroke
.8641 .48543 L
.86082 .49514 L
.85853 .50486 L
.85451 .51405 L
.85433 .51457 L
.85102 .52428 L
.84865 .53399 L
.84479 .54277 L
.84447 .54371 L
.84114 .55342 L
.83865 .56313 L
.83508 .57124 L
.83452 .57284 L
.83116 .58256 L
.82852 .59227 L
.82537 .59945 L
.82447 .60198 L
.82108 .61169 L
.81826 .62141 L
.81566 .62739 L
.81433 .63112 L
.81091 .64083 L
.8079 .65054 L
.80594 .65506 L
.80408 .66026 L
.80244 .66997 L
.79742 .67968 L
.79623 .68246 L
.79373 .68939 L
.79161 .69911 L
.78684 .70882 L
.78652 .70957 L
.78326 .71853 L
.7807 .72824 L
.77681 .73645 L
.77624 .73796 L
.77268 .74767 L
.76971 .75738 L
.76709 .76305 L
.76557 .76709 L
.76198 .77681 L
.75864 .78652 L
.75738 .78933 L
.75478 .79623 L
.75244 .80594 L
.74767 .81532 L
.74754 .81566 L
.74386 .82537 L
.74087 .83508 L
.73796 .84109 L
Mistroke
.73651 .84479 L
.7328 .85451 L
.7293 .86422 L
.72824 .8665 L
.72535 .87393 L
.7227 .88364 L
.71853 .89165 L
.71784 .89336 L
.71403 .90307 L
.71063 .91278 L
.70882 .91648 L
.70641 .92249 L
.70398 .93221 L
.69911 .94099 L
.69872 .94192 L
.69481 .95163 L
.69137 .96134 L
.68939 .96523 L
.68699 .97106 L
.68449 .98077 L
Mfstroke
.6 g
.98077 .14279 m
.97997 .14549 L
.97705 .15521 L
.97409 .16492 L
.97109 .17463 L
.97106 .17478 L
.96847 .18434 L
.96537 .19406 L
.96223 .20377 L
.96134 .20654 L
.95953 .21348 L
.95646 .22319 L
.9533 .23291 L
.95163 .23808 L
.95049 .24262 L
.94749 .25233 L
.94431 .26204 L
.94192 .26939 L
.94135 .27176 L
.93845 .28147 L
.93525 .29118 L
.93221 .30046 L
.93211 .30089 L
.92933 .31061 L
.92613 .32032 L
.92291 .33003 L
.92249 .33131 L
.92013 .33974 L
.91694 .34946 L
.91369 .35917 L
.91278 .36192 L
.91085 .36888 L
.90767 .37859 L
.9044 .38831 L
.90307 .3923 L
.9015 .39802 L
.89833 .40773 L
.89503 .41744 L
.89336 .42244 L
.89207 .42716 L
.88891 .43687 L
.88559 .44658 L
.88364 .45234 L
.88257 .45629 L
.87941 .46601 L
.87607 .47572 L
.87393 .48199 L
.87299 .48543 L
.86984 .49514 L
.86647 .50486 L
.86422 .5114 L
.86335 .51457 L
.86018 .52428 L
.85679 .53399 L
.85451 .54057 L
.85363 .54371 L
.85043 .55342 L
.84702 .56313 L
.84479 .56949 L
.84384 .57284 L
.8406 .58256 L
.83716 .59227 L
.83508 .59816 L
.83397 .60198 L
.83067 .61169 L
.8272 .62141 L
.82537 .62657 L
.82401 .63112 L
.82066 .64083 L
.81716 .65054 L
.81566 .65473 L
.81396 .66026 L
.81054 .66997 L
.80701 .67968 L
.80594 .68263 L
.8038 .68939 L
.80032 .69911 L
.79676 .70882 L
.79623 .71028 L
.79354 .71853 L
.79 .72824 L
.78652 .73766 L
.78643 .73796 L
.78316 .74767 L
.77956 .75738 L
.77681 .76478 L
.77609 .76709 L
.77266 .77681 L
.76901 .78652 L
.76709 .79163 L
.7656 .79623 L
.76204 .80594 L
.75834 .81566 L
.75738 .8182 L
.75495 .82537 L
.75128 .83508 L
.74767 .8445 L
.74758 .84479 L
.74415 .85451 L
.7404 .86422 L
.73796 .87054 L
.73682 .87393 L
.73319 .88364 L
.72939 .89336 L
.72824 .89629 L
.72586 .90307 L
.72208 .91278 L
.71853 .92175 L
.71829 .92249 L
.71469 .93221 L
.71082 .94192 L
.70882 .94693 L
.70715 .95163 L
.70334 .96134 L
.69941 .97106 L
.69911 .97182 L
.69576 .98077 L
.98077 .98077 L
F
0 g
.98077 .14279 m
.97997 .14549 L
.97705 .15521 L
.97409 .16492 L
.97109 .17463 L
.97106 .17478 L
.96847 .18434 L
.96537 .19406 L
.96223 .20377 L
.96134 .20654 L
.95953 .21348 L
.95646 .22319 L
.9533 .23291 L
.95163 .23808 L
.95049 .24262 L
.94749 .25233 L
.94431 .26204 L
.94192 .26939 L
.94135 .27176 L
.93845 .28147 L
.93525 .29118 L
.93221 .30046 L
.93211 .30089 L
.92933 .31061 L
.92613 .32032 L
.92291 .33003 L
.92249 .33131 L
.92013 .33974 L
.91694 .34946 L
.91369 .35917 L
.91278 .36192 L
.91085 .36888 L
.90767 .37859 L
.9044 .38831 L
.90307 .3923 L
.9015 .39802 L
.89833 .40773 L
.89503 .41744 L
.89336 .42244 L
.89207 .42716 L
.88891 .43687 L
.88559 .44658 L
.88364 .45234 L
.88257 .45629 L
.87941 .46601 L
.87607 .47572 L
.87393 .48199 L
.87299 .48543 L
.86984 .49514 L
.86647 .50486 L
Mistroke
.86422 .5114 L
.86335 .51457 L
.86018 .52428 L
.85679 .53399 L
.85451 .54057 L
.85363 .54371 L
.85043 .55342 L
.84702 .56313 L
.84479 .56949 L
.84384 .57284 L
.8406 .58256 L
.83716 .59227 L
.83508 .59816 L
.83397 .60198 L
.83067 .61169 L
.8272 .62141 L
.82537 .62657 L
.82401 .63112 L
.82066 .64083 L
.81716 .65054 L
.81566 .65473 L
.81396 .66026 L
.81054 .66997 L
.80701 .67968 L
.80594 .68263 L
.8038 .68939 L
.80032 .69911 L
.79676 .70882 L
.79623 .71028 L
.79354 .71853 L
.79 .72824 L
.78652 .73766 L
.78643 .73796 L
.78316 .74767 L
.77956 .75738 L
.77681 .76478 L
.77609 .76709 L
.77266 .77681 L
.76901 .78652 L
.76709 .79163 L
.7656 .79623 L
.76204 .80594 L
.75834 .81566 L
.75738 .8182 L
.75495 .82537 L
.75128 .83508 L
.74767 .8445 L
.74758 .84479 L
.74415 .85451 L
.7404 .86422 L
Mistroke
.73796 .87054 L
.73682 .87393 L
.73319 .88364 L
.72939 .89336 L
.72824 .89629 L
.72586 .90307 L
.72208 .91278 L
.71853 .92175 L
.71829 .92249 L
.71469 .93221 L
.71082 .94192 L
.70882 .94693 L
.70715 .95163 L
.70334 .96134 L
.69941 .97106 L
.69911 .97182 L
.69576 .98077 L
Mfstroke
.5 g
.98077 .16302 m
.98021 .16492 L
.97565 .17463 L
.97384 .18434 L
.97135 .19406 L
.97106 .19509 L
.96849 .20377 L
.9655 .21348 L
.96249 .22319 L
.96134 .22693 L
.95958 .23291 L
.95659 .24262 L
.95356 .25233 L
.95163 .25855 L
.9506 .26204 L
.94762 .27176 L
.94457 .28147 L
.94192 .28994 L
.94155 .29118 L
.93858 .30089 L
.93551 .31061 L
.93245 .32032 L
.93221 .3211 L
.92948 .33003 L
.9264 .33974 L
.92331 .34946 L
.92249 .35203 L
.92031 .35917 L
.91722 .36888 L
.9141 .37859 L
.91278 .38273 L
.91107 .38831 L
.90797 .39802 L
.90483 .40773 L
.90307 .4132 L
.90176 .41744 L
.89865 .42716 L
.89548 .43687 L
.89336 .44343 L
.89238 .44658 L
.88925 .45629 L
.88607 .46601 L
.88364 .47342 L
.88293 .47572 L
.87979 .48543 L
.87658 .49514 L
.87393 .50317 L
.8734 .50486 L
.87025 .51457 L
.86701 .52428 L
.86422 .53268 L
.8638 .53399 L
.86062 .54371 L
.85736 .55342 L
.85451 .56195 L
.85413 .56313 L
.85092 .57284 L
.84764 .58256 L
.84479 .59097 L
.84437 .59227 L
.84114 .60198 L
.83782 .61169 L
.83508 .61974 L
.83454 .62141 L
.83127 .63112 L
.82792 .64083 L
.82537 .64826 L
.82461 .65054 L
.82131 .66026 L
.81793 .66997 L
.81566 .67653 L
.8146 .67968 L
.81125 .68939 L
.80785 .69911 L
.80594 .70455 L
.80449 .70882 L
.8011 .71853 L
.79766 .72824 L
.79623 .73231 L
.79429 .73796 L
.79085 .74767 L
.78738 .75738 L
.78652 .75981 L
.78398 .76709 L
.78049 .77681 L
.77699 .78652 L
.77681 .78704 L
.77355 .79623 L
.77003 .80594 L
.76709 .81402 L
.76652 .81566 L
.76302 .82537 L
.75945 .83508 L
.75738 .84072 L
.75593 .84479 L
.75236 .85451 L
.74876 .86422 L
.74767 .86716 L
.74521 .87393 L
.74159 .88364 L
.73796 .89332 L
.73794 .89336 L
.73435 .90307 L
.73068 .91278 L
.72824 .91921 L
.72703 .92249 L
.72336 .93221 L
.71964 .94192 L
.71853 .94482 L
.71597 .95163 L
.71223 .96134 L
.70882 .97015 L
.70848 .97106 L
.70475 .98077 L
.98077 .98077 L
F
0 g
.98077 .16302 m
.98021 .16492 L
.97565 .17463 L
.97384 .18434 L
.97135 .19406 L
.97106 .19509 L
.96849 .20377 L
.9655 .21348 L
.96249 .22319 L
.96134 .22693 L
.95958 .23291 L
.95659 .24262 L
.95356 .25233 L
.95163 .25855 L
.9506 .26204 L
.94762 .27176 L
.94457 .28147 L
.94192 .28994 L
.94155 .29118 L
.93858 .30089 L
.93551 .31061 L
.93245 .32032 L
.93221 .3211 L
.92948 .33003 L
.9264 .33974 L
.92331 .34946 L
.92249 .35203 L
.92031 .35917 L
.91722 .36888 L
.9141 .37859 L
.91278 .38273 L
.91107 .38831 L
.90797 .39802 L
.90483 .40773 L
.90307 .4132 L
.90176 .41744 L
.89865 .42716 L
.89548 .43687 L
.89336 .44343 L
.89238 .44658 L
.88925 .45629 L
.88607 .46601 L
.88364 .47342 L
.88293 .47572 L
.87979 .48543 L
.87658 .49514 L
.87393 .50317 L
.8734 .50486 L
.87025 .51457 L
.86701 .52428 L
Mistroke
.86422 .53268 L
.8638 .53399 L
.86062 .54371 L
.85736 .55342 L
.85451 .56195 L
.85413 .56313 L
.85092 .57284 L
.84764 .58256 L
.84479 .59097 L
.84437 .59227 L
.84114 .60198 L
.83782 .61169 L
.83508 .61974 L
.83454 .62141 L
.83127 .63112 L
.82792 .64083 L
.82537 .64826 L
.82461 .65054 L
.82131 .66026 L
.81793 .66997 L
.81566 .67653 L
.8146 .67968 L
.81125 .68939 L
.80785 .69911 L
.80594 .70455 L
.80449 .70882 L
.8011 .71853 L
.79766 .72824 L
.79623 .73231 L
.79429 .73796 L
.79085 .74767 L
.78738 .75738 L
.78652 .75981 L
.78398 .76709 L
.78049 .77681 L
.77699 .78652 L
.77681 .78704 L
.77355 .79623 L
.77003 .80594 L
.76709 .81402 L
.76652 .81566 L
.76302 .82537 L
.75945 .83508 L
.75738 .84072 L
.75593 .84479 L
.75236 .85451 L
.74876 .86422 L
.74767 .86716 L
.74521 .87393 L
.74159 .88364 L
Mistroke
.73796 .89332 L
.73794 .89336 L
.73435 .90307 L
.73068 .91278 L
.72824 .91921 L
.72703 .92249 L
.72336 .93221 L
.71964 .94192 L
.71853 .94482 L
.71597 .95163 L
.71223 .96134 L
.70882 .97015 L
.70848 .97106 L
.70475 .98077 L
Mfstroke
.4 g
.98077 .18229 m
.97995 .18434 L
.97694 .19406 L
.97419 .20377 L
.97134 .21348 L
.97106 .21443 L
.96838 .22319 L
.96539 .23291 L
.96243 .24262 L
.96134 .24634 L
.95951 .25233 L
.9565 .26204 L
.9535 .27176 L
.95163 .27803 L
.95057 .28147 L
.94755 .29118 L
.94452 .30089 L
.94192 .30949 L
.94157 .31061 L
.93854 .32032 L
.93548 .33003 L
.9325 .33974 L
.93221 .34072 L
.92947 .34946 L
.92639 .35917 L
.92336 .36888 L
.92249 .37173 L
.92033 .37859 L
.91723 .38831 L
.91416 .39802 L
.91278 .4025 L
.91112 .40773 L
.908 .41744 L
.9049 .42716 L
.90307 .43304 L
.90185 .43687 L
.89871 .44658 L
.89557 .45629 L
.89336 .46335 L
.8925 .46601 L
.88935 .47572 L
.88618 .48543 L
.88364 .49342 L
.88309 .49514 L
.87991 .50486 L
.87672 .51457 L
.87393 .52326 L
.8736 .52428 L
.8704 .53399 L
.86718 .54371 L
.86422 .55285 L
.86403 .55342 L
.86081 .56313 L
.85757 .57284 L
.85451 .5822 L
.85439 .58256 L
.85114 .59227 L
.84787 .60198 L
.84479 .61131 L
.84467 .61169 L
.84139 .62141 L
.83809 .63112 L
.83508 .64017 L
.83486 .64083 L
.83155 .65054 L
.82823 .66026 L
.82537 .66878 L
.82497 .66997 L
.82163 .67968 L
.81828 .68939 L
.81566 .69714 L
.81498 .69911 L
.81161 .70882 L
.80824 .71853 L
.80594 .72525 L
.80491 .72824 L
.8015 .73796 L
.7981 .74767 L
.79623 .75311 L
.79473 .75738 L
.79129 .76709 L
.78787 .77681 L
.78652 .78071 L
.78446 .78652 L
.78099 .79623 L
.77754 .80594 L
.77681 .80805 L
.77408 .81566 L
.77057 .82537 L
.76711 .83508 L
.76709 .83513 L
.76359 .84479 L
.76005 .85451 L
.75738 .86194 L
.75655 .86422 L
.75299 .87393 L
.74942 .88364 L
.74767 .88848 L
.74587 .89336 L
.74226 .90307 L
.73868 .91278 L
.73796 .91476 L
.73507 .92249 L
.73142 .93221 L
.72824 .94076 L
.72781 .94192 L
.72414 .95163 L
.72046 .96134 L
.71853 .96649 L
.71679 .97106 L
.71307 .98077 L
.98077 .98077 L
F
0 g
.98077 .18229 m
.97995 .18434 L
.97694 .19406 L
.97419 .20377 L
.97134 .21348 L
.97106 .21443 L
.96838 .22319 L
.96539 .23291 L
.96243 .24262 L
.96134 .24634 L
.95951 .25233 L
.9565 .26204 L
.9535 .27176 L
.95163 .27803 L
.95057 .28147 L
.94755 .29118 L
.94452 .30089 L
.94192 .30949 L
.94157 .31061 L
.93854 .32032 L
.93548 .33003 L
.9325 .33974 L
.93221 .34072 L
.92947 .34946 L
.92639 .35917 L
.92336 .36888 L
.92249 .37173 L
.92033 .37859 L
.91723 .38831 L
.91416 .39802 L
.91278 .4025 L
.91112 .40773 L
.908 .41744 L
.9049 .42716 L
.90307 .43304 L
.90185 .43687 L
.89871 .44658 L
.89557 .45629 L
.89336 .46335 L
.8925 .46601 L
.88935 .47572 L
.88618 .48543 L
.88364 .49342 L
.88309 .49514 L
.87991 .50486 L
.87672 .51457 L
.87393 .52326 L
.8736 .52428 L
.8704 .53399 L
.86718 .54371 L
Mistroke
.86422 .55285 L
.86403 .55342 L
.86081 .56313 L
.85757 .57284 L
.85451 .5822 L
.85439 .58256 L
.85114 .59227 L
.84787 .60198 L
.84479 .61131 L
.84467 .61169 L
.84139 .62141 L
.83809 .63112 L
.83508 .64017 L
.83486 .64083 L
.83155 .65054 L
.82823 .66026 L
.82537 .66878 L
.82497 .66997 L
.82163 .67968 L
.81828 .68939 L
.81566 .69714 L
.81498 .69911 L
.81161 .70882 L
.80824 .71853 L
.80594 .72525 L
.80491 .72824 L
.8015 .73796 L
.7981 .74767 L
.79623 .75311 L
.79473 .75738 L
.79129 .76709 L
.78787 .77681 L
.78652 .78071 L
.78446 .78652 L
.78099 .79623 L
.77754 .80594 L
.77681 .80805 L
.77408 .81566 L
.77057 .82537 L
.76711 .83508 L
.76709 .83513 L
.76359 .84479 L
.76005 .85451 L
.75738 .86194 L
.75655 .86422 L
.75299 .87393 L
.74942 .88364 L
.74767 .88848 L
.74587 .89336 L
.74226 .90307 L
Mistroke
.73868 .91278 L
.73796 .91476 L
.73507 .92249 L
.73142 .93221 L
.72824 .94076 L
.72781 .94192 L
.72414 .95163 L
.72046 .96134 L
.71853 .96649 L
.71679 .97106 L
.71307 .98077 L
Mfstroke
.3 g
.98077 .20252 m
.98038 .20377 L
.97746 .21348 L
.97459 .22319 L
.97163 .23291 L
.97106 .23473 L
.96857 .24262 L
.96547 .25233 L
.96252 .26204 L
.96134 .26672 L
.95975 .27176 L
.95664 .28147 L
.95358 .29118 L
.95163 .2985 L
.95087 .30089 L
.94775 .31061 L
.94463 .32032 L
.94192 .33003 L
.94192 .33004 L
.93879 .33974 L
.93564 .34946 L
.93274 .35917 L
.93221 .36136 L
.92977 .36888 L
.92659 .37859 L
.92358 .38831 L
.92249 .39245 L
.92069 .39802 L
.91749 .40773 L
.91439 .41744 L
.91278 .42331 L
.91153 .42716 L
.90831 .43687 L
.90515 .44658 L
.90307 .45394 L
.9023 .45629 L
.89907 .46601 L
.89586 .47572 L
.89336 .48435 L
.893 .48543 L
.88975 .49514 L
.88651 .50486 L
.88364 .51451 L
.88363 .51457 L
.88036 .52428 L
.87709 .53399 L
.87412 .54371 L
.87393 .54444 L
.87089 .55342 L
.8676 .56313 L
.86456 .57284 L
.86422 .57413 L
.86135 .58256 L
.85803 .59227 L
.85494 .60198 L
.85451 .60358 L
.85172 .61169 L
.84837 .62141 L
.84526 .63112 L
.84479 .63279 L
.84201 .64083 L
.83864 .65054 L
.8355 .66026 L
.83508 .66175 L
.83222 .66997 L
.82882 .67968 L
.82568 .68939 L
.82537 .69047 L
.82234 .69911 L
.81892 .70882 L
.81578 .71853 L
.81566 .71895 L
.81236 .72824 L
.80892 .73796 L
.80594 .74717 L
.80577 .74767 L
.80229 .75738 L
.79884 .76709 L
.79623 .77514 L
.79564 .77681 L
.79213 .78652 L
.78866 .79623 L
.78652 .80286 L
.7854 .80594 L
.78186 .81566 L
.7784 .82537 L
.77681 .83031 L
.77507 .83508 L
.77149 .84479 L
.76806 .85451 L
.76709 .85752 L
.76462 .86422 L
.76102 .87393 L
.75764 .88364 L
.75738 .88446 L
.75406 .89336 L
.75045 .90307 L
.74767 .91114 L
.74705 .91278 L
.74338 .92249 L
.73978 .93221 L
.73796 .93755 L
.7363 .94192 L
.73259 .95163 L
.72903 .96134 L
.72824 .96369 L
.72542 .97106 L
.72169 .98077 L
.98077 .98077 L
F
0 g
.98077 .20252 m
.98038 .20377 L
.97746 .21348 L
.97459 .22319 L
.97163 .23291 L
.97106 .23473 L
.96857 .24262 L
.96547 .25233 L
.96252 .26204 L
.96134 .26672 L
.95975 .27176 L
.95664 .28147 L
.95358 .29118 L
.95163 .2985 L
.95087 .30089 L
.94775 .31061 L
.94463 .32032 L
.94192 .33003 L
.94192 .33004 L
.93879 .33974 L
.93564 .34946 L
.93274 .35917 L
.93221 .36136 L
.92977 .36888 L
.92659 .37859 L
.92358 .38831 L
.92249 .39245 L
.92069 .39802 L
.91749 .40773 L
.91439 .41744 L
.91278 .42331 L
.91153 .42716 L
.90831 .43687 L
.90515 .44658 L
.90307 .45394 L
.9023 .45629 L
.89907 .46601 L
.89586 .47572 L
.89336 .48435 L
.893 .48543 L
.88975 .49514 L
.88651 .50486 L
.88364 .51451 L
.88363 .51457 L
.88036 .52428 L
.87709 .53399 L
.87412 .54371 L
.87393 .54444 L
.87089 .55342 L
.8676 .56313 L
Mistroke
.86456 .57284 L
.86422 .57413 L
.86135 .58256 L
.85803 .59227 L
.85494 .60198 L
.85451 .60358 L
.85172 .61169 L
.84837 .62141 L
.84526 .63112 L
.84479 .63279 L
.84201 .64083 L
.83864 .65054 L
.8355 .66026 L
.83508 .66175 L
.83222 .66997 L
.82882 .67968 L
.82568 .68939 L
.82537 .69047 L
.82234 .69911 L
.81892 .70882 L
.81578 .71853 L
.81566 .71895 L
.81236 .72824 L
.80892 .73796 L
.80594 .74717 L
.80577 .74767 L
.80229 .75738 L
.79884 .76709 L
.79623 .77514 L
.79564 .77681 L
.79213 .78652 L
.78866 .79623 L
.78652 .80286 L
.7854 .80594 L
.78186 .81566 L
.7784 .82537 L
.77681 .83031 L
.77507 .83508 L
.77149 .84479 L
.76806 .85451 L
.76709 .85752 L
.76462 .86422 L
.76102 .87393 L
.75764 .88364 L
.75738 .88446 L
.75406 .89336 L
.75045 .90307 L
.74767 .91114 L
.74705 .91278 L
.74338 .92249 L
Mistroke
.73978 .93221 L
.73796 .93755 L
.7363 .94192 L
.73259 .95163 L
.72903 .96134 L
.72824 .96369 L
.72542 .97106 L
.72169 .98077 L
Mfstroke
.2 g
.98077 .22687 m
.97909 .23291 L
.97631 .24262 L
.97335 .25233 L
.97106 .25923 L
.97006 .26204 L
.96611 .27176 L
.96438 .28147 L
.96141 .29118 L
.96134 .29139 L
.9577 .30089 L
.95553 .31061 L
.95255 .32032 L
.95163 .32328 L
.94911 .33003 L
.94462 .33974 L
.94364 .34946 L
.94192 .35498 L
.94039 .35917 L
.9362 .36888 L
.93467 .37859 L
.93221 .38646 L
.93154 .38831 L
.92757 .39802 L
.92563 .40773 L
.92258 .41744 L
.92249 .41772 L
.91878 .42716 L
.91654 .43687 L
.91347 .44658 L
.91278 .44873 L
.90985 .45629 L
.90738 .46601 L
.90429 .47572 L
.90307 .47952 L
.90081 .48543 L
.89626 .49514 L
.89505 .50486 L
.89336 .51009 L
.89166 .51457 L
.88727 .52428 L
.88574 .53399 L
.88364 .54044 L
.88241 .54371 L
.87813 .55342 L
.87636 .56313 L
.87393 .57056 L
.87307 .57284 L
.86886 .58256 L
.86691 .59227 L
.86422 .60045 L
.86364 .60198 L
.85947 .61169 L
.85739 .62141 L
.85451 .6301 L
.85412 .63112 L
.84996 .64083 L
.84779 .65054 L
.84479 .65951 L
.84451 .66026 L
.84034 .66997 L
.83811 .67968 L
.83508 .68869 L
.83481 .68939 L
.8306 .69911 L
.82836 .70882 L
.82537 .71762 L
.82502 .71853 L
.82075 .72824 L
.81852 .73796 L
.81566 .74631 L
.81512 .74767 L
.81076 .75738 L
.80859 .76709 L
.80594 .77476 L
.80513 .77681 L
.80064 .78652 L
.79858 .79623 L
.79623 .80296 L
.79502 .80594 L
.79036 .81566 L
.78848 .82537 L
.78652 .83091 L
.78479 .83508 L
.7799 .84479 L
.77828 .85451 L
.77681 .85862 L
.77442 .86422 L
.77144 .87393 L
.76799 .88364 L
.76709 .8861 L
.76389 .89336 L
.76109 .90307 L
.75759 .91278 L
.75738 .91335 L
.75318 .92249 L
.75062 .93221 L
.74767 .94031 L
.74699 .94192 L
.74221 .95163 L
.74005 .96134 L
.73796 .967 L
.73618 .97106 L
.73092 .98077 L
.98077 .98077 L
F
0 g
.98077 .22687 m
.97909 .23291 L
.97631 .24262 L
.97335 .25233 L
.97106 .25923 L
.97006 .26204 L
.96611 .27176 L
.96438 .28147 L
.96141 .29118 L
.96134 .29139 L
.9577 .30089 L
.95553 .31061 L
.95255 .32032 L
.95163 .32328 L
.94911 .33003 L
.94462 .33974 L
.94364 .34946 L
.94192 .35498 L
.94039 .35917 L
.9362 .36888 L
.93467 .37859 L
.93221 .38646 L
.93154 .38831 L
.92757 .39802 L
.92563 .40773 L
.92258 .41744 L
.92249 .41772 L
.91878 .42716 L
.91654 .43687 L
.91347 .44658 L
.91278 .44873 L
.90985 .45629 L
.90738 .46601 L
.90429 .47572 L
.90307 .47952 L
.90081 .48543 L
.89626 .49514 L
.89505 .50486 L
.89336 .51009 L
.89166 .51457 L
.88727 .52428 L
.88574 .53399 L
.88364 .54044 L
.88241 .54371 L
.87813 .55342 L
.87636 .56313 L
.87393 .57056 L
.87307 .57284 L
.86886 .58256 L
.86691 .59227 L
Mistroke
.86422 .60045 L
.86364 .60198 L
.85947 .61169 L
.85739 .62141 L
.85451 .6301 L
.85412 .63112 L
.84996 .64083 L
.84779 .65054 L
.84479 .65951 L
.84451 .66026 L
.84034 .66997 L
.83811 .67968 L
.83508 .68869 L
.83481 .68939 L
.8306 .69911 L
.82836 .70882 L
.82537 .71762 L
.82502 .71853 L
.82075 .72824 L
.81852 .73796 L
.81566 .74631 L
.81512 .74767 L
.81076 .75738 L
.80859 .76709 L
.80594 .77476 L
.80513 .77681 L
.80064 .78652 L
.79858 .79623 L
.79623 .80296 L
.79502 .80594 L
.79036 .81566 L
.78848 .82537 L
.78652 .83091 L
.78479 .83508 L
.7799 .84479 L
.77828 .85451 L
.77681 .85862 L
.77442 .86422 L
.77144 .87393 L
.76799 .88364 L
.76709 .8861 L
.76389 .89336 L
.76109 .90307 L
.75759 .91278 L
.75738 .91335 L
.75318 .92249 L
.75062 .93221 L
.74767 .94031 L
.74699 .94192 L
.74221 .95163 L
Mistroke
.74005 .96134 L
.73796 .967 L
.73618 .97106 L
.73092 .98077 L
Mfstroke
.3 g
.98077 .3198 m
.98062 .32032 L
.97773 .33003 L
.97475 .33974 L
.97174 .34946 L
.97106 .35166 L
.96873 .35917 L
.9675 .36888 L
.9631 .37859 L
.96134 .38329 L
.95977 .38831 L
.95675 .39802 L
.95432 .40773 L
.95163 .41468 L
.95075 .41744 L
.94771 .42716 L
.94551 .43687 L
.94192 .44582 L
.94168 .44658 L
.9386 .45629 L
.93666 .46601 L
.93258 .47572 L
.93221 .47674 L
.92943 .48543 L
.92775 .49514 L
.92347 .50486 L
.92249 .50744 L
.9202 .51457 L
.91878 .52428 L
.91429 .53399 L
.91278 .53789 L
.91089 .54371 L
.90973 .55342 L
.90503 .56313 L
.90307 .56811 L
.90151 .57284 L
.89835 .58256 L
.89568 .59227 L
.89336 .59807 L
.89206 .60198 L
.88887 .61169 L
.88625 .62141 L
.88364 .62779 L
.88253 .63112 L
.87931 .64083 L
.87671 .65054 L
.87393 .65726 L
.87292 .66026 L
.86968 .66997 L
.86706 .67968 L
.86422 .68649 L
.86323 .68939 L
.85996 .69911 L
.8573 .70882 L
.85451 .71546 L
.85345 .71853 L
.85015 .72824 L
.84743 .73796 L
.84479 .74418 L
.84358 .74767 L
.84026 .75738 L
.83743 .76709 L
.83508 .77264 L
.83362 .77681 L
.83027 .78652 L
.82732 .79623 L
.82537 .80084 L
.82357 .80594 L
.82206 .81566 L
.81709 .82537 L
.81566 .82877 L
.81342 .83508 L
.81156 .84479 L
.80675 .85451 L
.80594 .85643 L
.80316 .86422 L
.80093 .87393 L
.7963 .88364 L
.79623 .88381 L
.7928 .89336 L
.7902 .90307 L
.78652 .91098 L
.78585 .91278 L
.78233 .92249 L
.77937 .93221 L
.77681 .93785 L
.77529 .94192 L
.77174 .95163 L
.76846 .96134 L
.76709 .96442 L
.76462 .97106 L
.7624 .98077 L
.98077 .98077 L
F
0 g
.98077 .3198 m
.98062 .32032 L
.97773 .33003 L
.97475 .33974 L
.97174 .34946 L
.97106 .35166 L
.96873 .35917 L
.9675 .36888 L
.9631 .37859 L
.96134 .38329 L
.95977 .38831 L
.95675 .39802 L
.95432 .40773 L
.95163 .41468 L
.95075 .41744 L
.94771 .42716 L
.94551 .43687 L
.94192 .44582 L
.94168 .44658 L
.9386 .45629 L
.93666 .46601 L
.93258 .47572 L
.93221 .47674 L
.92943 .48543 L
.92775 .49514 L
.92347 .50486 L
.92249 .50744 L
.9202 .51457 L
.91878 .52428 L
.91429 .53399 L
.91278 .53789 L
.91089 .54371 L
.90973 .55342 L
.90503 .56313 L
.90307 .56811 L
.90151 .57284 L
.89835 .58256 L
.89568 .59227 L
.89336 .59807 L
.89206 .60198 L
.88887 .61169 L
.88625 .62141 L
.88364 .62779 L
.88253 .63112 L
.87931 .64083 L
.87671 .65054 L
.87393 .65726 L
.87292 .66026 L
.86968 .66997 L
.86706 .67968 L
Mistroke
.86422 .68649 L
.86323 .68939 L
.85996 .69911 L
.8573 .70882 L
.85451 .71546 L
.85345 .71853 L
.85015 .72824 L
.84743 .73796 L
.84479 .74418 L
.84358 .74767 L
.84026 .75738 L
.83743 .76709 L
.83508 .77264 L
.83362 .77681 L
.83027 .78652 L
.82732 .79623 L
.82537 .80084 L
.82357 .80594 L
.82206 .81566 L
.81709 .82537 L
.81566 .82877 L
.81342 .83508 L
.81156 .84479 L
.80675 .85451 L
.80594 .85643 L
.80316 .86422 L
.80093 .87393 L
.7963 .88364 L
.79623 .88381 L
.7928 .89336 L
.7902 .90307 L
.78652 .91098 L
.78585 .91278 L
.78233 .92249 L
.77937 .93221 L
.77681 .93785 L
.77529 .94192 L
.77174 .95163 L
.76846 .96134 L
.76709 .96442 L
.76462 .97106 L
.7624 .98077 L
Mfstroke
.4 g
.98077 .34418 m
.9792 .34946 L
.97627 .35917 L
.97157 .36888 L
.97106 .37617 L
.9705 .37859 L
.96767 .38831 L
.96453 .39802 L
.96141 .40773 L
.96134 .40793 L
.95875 .41744 L
.95562 .42716 L
.95246 .43687 L
.95163 .43947 L
.94974 .44658 L
.94665 .45629 L
.94346 .46601 L
.94192 .47078 L
.94065 .47572 L
.93761 .48543 L
.9344 .49514 L
.93221 .50185 L
.93146 .50486 L
.92849 .51457 L
.92527 .52428 L
.92249 .5327 L
.92219 .53399 L
.9193 .54371 L
.91607 .55342 L
.91284 .56313 L
.91278 .5633 L
.91003 .57284 L
.9068 .58256 L
.90354 .59227 L
.90307 .59368 L
.90069 .60198 L
.89745 .61169 L
.89416 .62141 L
.89336 .62382 L
.89127 .63112 L
.88803 .64083 L
.88472 .65054 L
.88364 .65372 L
.88178 .66026 L
.87853 .66997 L
.87519 .67968 L
.87393 .68338 L
.8722 .68939 L
.86895 .69911 L
.86558 .70882 L
.86422 .71279 L
.86256 .71853 L
.85928 .72824 L
.85589 .73796 L
.85451 .74195 L
.85283 .74767 L
.84953 .75738 L
.84611 .76709 L
.84479 .77087 L
.84303 .77681 L
.83969 .78652 L
.83624 .79623 L
.83508 .79954 L
.83314 .80594 L
.82976 .81566 L
.82629 .82537 L
.82537 .82795 L
.82316 .83508 L
.81973 .84479 L
.81623 .85451 L
.81566 .85611 L
.81308 .86422 L
.8096 .87393 L
.80608 .88364 L
.80594 .88402 L
.8029 .89336 L
.79937 .90307 L
.79623 .91166 L
.7959 .91278 L
.79262 .92249 L
.78904 .93221 L
.78652 .93905 L
.78563 .94192 L
.78222 .95163 L
.7786 .96134 L
.77681 .96616 L
.77523 .97106 L
.7717 .98077 L
.98077 .98077 L
F
0 g
.98077 .34418 m
.9792 .34946 L
.97627 .35917 L
.97157 .36888 L
.97106 .37617 L
.9705 .37859 L
.96767 .38831 L
.96453 .39802 L
.96141 .40773 L
.96134 .40793 L
.95875 .41744 L
.95562 .42716 L
.95246 .43687 L
.95163 .43947 L
.94974 .44658 L
.94665 .45629 L
.94346 .46601 L
.94192 .47078 L
.94065 .47572 L
.93761 .48543 L
.9344 .49514 L
.93221 .50185 L
.93146 .50486 L
.92849 .51457 L
.92527 .52428 L
.92249 .5327 L
.92219 .53399 L
.9193 .54371 L
.91607 .55342 L
.91284 .56313 L
.91278 .5633 L
.91003 .57284 L
.9068 .58256 L
.90354 .59227 L
.90307 .59368 L
.90069 .60198 L
.89745 .61169 L
.89416 .62141 L
.89336 .62382 L
.89127 .63112 L
.88803 .64083 L
.88472 .65054 L
.88364 .65372 L
.88178 .66026 L
.87853 .66997 L
.87519 .67968 L
.87393 .68338 L
.8722 .68939 L
.86895 .69911 L
.86558 .70882 L
Mistroke
.86422 .71279 L
.86256 .71853 L
.85928 .72824 L
.85589 .73796 L
.85451 .74195 L
.85283 .74767 L
.84953 .75738 L
.84611 .76709 L
.84479 .77087 L
.84303 .77681 L
.83969 .78652 L
.83624 .79623 L
.83508 .79954 L
.83314 .80594 L
.82976 .81566 L
.82629 .82537 L
.82537 .82795 L
.82316 .83508 L
.81973 .84479 L
.81623 .85451 L
.81566 .85611 L
.81308 .86422 L
.8096 .87393 L
.80608 .88364 L
.80594 .88402 L
.8029 .89336 L
.79937 .90307 L
.79623 .91166 L
.7959 .91278 L
.79262 .92249 L
.78904 .93221 L
.78652 .93905 L
.78563 .94192 L
.78222 .95163 L
.7786 .96134 L
.77681 .96616 L
.77523 .97106 L
.7717 .98077 L
Mfstroke
.5 g
.98077 .3644 m
.97712 .36888 L
.97524 .37859 L
.97323 .38831 L
.97106 .39647 L
.97061 .39802 L
.9677 .40773 L
.9647 .41744 L
.9617 .42716 L
.96134 .42832 L
.9588 .43687 L
.95578 .44658 L
.95276 .45629 L
.95163 .45993 L
.94982 .46601 L
.94681 .47572 L
.94376 .48543 L
.94192 .49133 L
.94078 .49514 L
.93777 .50486 L
.9347 .51457 L
.93221 .52249 L
.93167 .52428 L
.92867 .53399 L
.92558 .54371 L
.92249 .55342 L
.92249 .55342 L
.9195 .56313 L
.91639 .57284 L
.91328 .58256 L
.91278 .58412 L
.91025 .59227 L
.90713 .60198 L
.90399 .61169 L
.90307 .61458 L
.90094 .62141 L
.89781 .63112 L
.89464 .64083 L
.89336 .64481 L
.89156 .65054 L
.88841 .66026 L
.88522 .66997 L
.88364 .6748 L
.88211 .67968 L
.87894 .68939 L
.87572 .69911 L
.87393 .70456 L
.87258 .70882 L
.86939 .71853 L
.86615 .72824 L
.86422 .73407 L
.86297 .73796 L
.85976 .74767 L
.8565 .75738 L
.85451 .76333 L
.85329 .76709 L
.85005 .77681 L
.84676 .78652 L
.84479 .79235 L
.84353 .79623 L
.84026 .80594 L
.83694 .81566 L
.83508 .82113 L
.83368 .82537 L
.83038 .83508 L
.82703 .84479 L
.82537 .84965 L
.82375 .85451 L
.82041 .86422 L
.81704 .87393 L
.81566 .87792 L
.81372 .88364 L
.81035 .89336 L
.80694 .90307 L
.80594 .90593 L
.8036 .91278 L
.80019 .92249 L
.79675 .93221 L
.79623 .93369 L
.79338 .94192 L
.78993 .95163 L
.78652 .96119 L
.78647 .96134 L
.78306 .97106 L
.77956 .98077 L
.98077 .98077 L
F
0 g
.98077 .3644 m
.97712 .36888 L
.97524 .37859 L
.97323 .38831 L
.97106 .39647 L
.97061 .39802 L
.9677 .40773 L
.9647 .41744 L
.9617 .42716 L
.96134 .42832 L
.9588 .43687 L
.95578 .44658 L
.95276 .45629 L
.95163 .45993 L
.94982 .46601 L
.94681 .47572 L
.94376 .48543 L
.94192 .49133 L
.94078 .49514 L
.93777 .50486 L
.9347 .51457 L
.93221 .52249 L
.93167 .52428 L
.92867 .53399 L
.92558 .54371 L
.92249 .55342 L
.92249 .55342 L
.9195 .56313 L
.91639 .57284 L
.91328 .58256 L
.91278 .58412 L
.91025 .59227 L
.90713 .60198 L
.90399 .61169 L
.90307 .61458 L
.90094 .62141 L
.89781 .63112 L
.89464 .64083 L
.89336 .64481 L
.89156 .65054 L
.88841 .66026 L
.88522 .66997 L
.88364 .6748 L
.88211 .67968 L
.87894 .68939 L
.87572 .69911 L
.87393 .70456 L
.87258 .70882 L
.86939 .71853 L
.86615 .72824 L
Mistroke
.86422 .73407 L
.86297 .73796 L
.85976 .74767 L
.8565 .75738 L
.85451 .76333 L
.85329 .76709 L
.85005 .77681 L
.84676 .78652 L
.84479 .79235 L
.84353 .79623 L
.84026 .80594 L
.83694 .81566 L
.83508 .82113 L
.83368 .82537 L
.83038 .83508 L
.82703 .84479 L
.82537 .84965 L
.82375 .85451 L
.82041 .86422 L
.81704 .87393 L
.81566 .87792 L
.81372 .88364 L
.81035 .89336 L
.80694 .90307 L
.80594 .90593 L
.8036 .91278 L
.80019 .92249 L
.79675 .93221 L
.79623 .93369 L
.79338 .94192 L
.78993 .95163 L
.78652 .96119 L
.78647 .96134 L
.78306 .97106 L
.77956 .98077 L
Mfstroke
.6 g
.98077 .38367 m
.97905 .38831 L
.97621 .39802 L
.97345 .40773 L
.97106 .41581 L
.97056 .41744 L
.96759 .42716 L
.96459 .43687 L
.96168 .44658 L
.96134 .44772 L
.95871 .45629 L
.9557 .46601 L
.95272 .47572 L
.95163 .47941 L
.94978 .48543 L
.94674 .49514 L
.94373 .50486 L
.94192 .51087 L
.94078 .51457 L
.93773 .52428 L
.93468 .53399 L
.93221 .54211 L
.93171 .54371 L
.92865 .55342 L
.92557 .56313 L
.92257 .57284 L
.92249 .57311 L
.91951 .58256 L
.91641 .59227 L
.91336 .60198 L
.91278 .60389 L
.9103 .61169 L
.90717 .62141 L
.90409 .63112 L
.90307 .63443 L
.90102 .64083 L
.89787 .65054 L
.89476 .66026 L
.89336 .66474 L
.89167 .66997 L
.8885 .67968 L
.88535 .68939 L
.88364 .69481 L
.88225 .69911 L
.87906 .70882 L
.87588 .71853 L
.87393 .72464 L
.87275 .72824 L
.86954 .73796 L
.86634 .74767 L
.86422 .75423 L
.86318 .75738 L
.85995 .76709 L
.85671 .77681 L
.85451 .78358 L
.85353 .78652 L
.85027 .79623 L
.84701 .80594 L
.84479 .81269 L
.8438 .81566 L
.84051 .82537 L
.83723 .83508 L
.83508 .84155 L
.83399 .84479 L
.83067 .85451 L
.82736 .86422 L
.82537 .87017 L
.82408 .87393 L
.82074 .88364 L
.8174 .89336 L
.81566 .89853 L
.81409 .90307 L
.81071 .91278 L
.80735 .92249 L
.80594 .92664 L
.80401 .93221 L
.8006 .94192 L
.79721 .95163 L
.79623 .95449 L
.79382 .96134 L
.79038 .97106 L
.78697 .98077 L
.98077 .98077 L
F
0 g
.98077 .38367 m
.97905 .38831 L
.97621 .39802 L
.97345 .40773 L
.97106 .41581 L
.97056 .41744 L
.96759 .42716 L
.96459 .43687 L
.96168 .44658 L
.96134 .44772 L
.95871 .45629 L
.9557 .46601 L
.95272 .47572 L
.95163 .47941 L
.94978 .48543 L
.94674 .49514 L
.94373 .50486 L
.94192 .51087 L
.94078 .51457 L
.93773 .52428 L
.93468 .53399 L
.93221 .54211 L
.93171 .54371 L
.92865 .55342 L
.92557 .56313 L
.92257 .57284 L
.92249 .57311 L
.91951 .58256 L
.91641 .59227 L
.91336 .60198 L
.91278 .60389 L
.9103 .61169 L
.90717 .62141 L
.90409 .63112 L
.90307 .63443 L
.90102 .64083 L
.89787 .65054 L
.89476 .66026 L
.89336 .66474 L
.89167 .66997 L
.8885 .67968 L
.88535 .68939 L
.88364 .69481 L
.88225 .69911 L
.87906 .70882 L
.87588 .71853 L
.87393 .72464 L
.87275 .72824 L
.86954 .73796 L
.86634 .74767 L
Mistroke
.86422 .75423 L
.86318 .75738 L
.85995 .76709 L
.85671 .77681 L
.85451 .78358 L
.85353 .78652 L
.85027 .79623 L
.84701 .80594 L
.84479 .81269 L
.8438 .81566 L
.84051 .82537 L
.83723 .83508 L
.83508 .84155 L
.83399 .84479 L
.83067 .85451 L
.82736 .86422 L
.82537 .87017 L
.82408 .87393 L
.82074 .88364 L
.8174 .89336 L
.81566 .89853 L
.81409 .90307 L
.81071 .91278 L
.80735 .92249 L
.80594 .92664 L
.80401 .93221 L
.8006 .94192 L
.79721 .95163 L
.79623 .95449 L
.79382 .96134 L
.79038 .97106 L
.78697 .98077 L
Mfstroke
.7 g
.98077 .4039 m
.97958 .40773 L
.97671 .41744 L
.97381 .42716 L
.97106 .43612 L
.97082 .43687 L
.96775 .44658 L
.96465 .45629 L
.96184 .46601 L
.96134 .46811 L
.95893 .47572 L
.95581 .48543 L
.95284 .49514 L
.95163 .49988 L
.95005 .50486 L
.94691 .51457 L
.94384 .52428 L
.94192 .53142 L
.9411 .53399 L
.93795 .54371 L
.93483 .55342 L
.93221 .56275 L
.93208 .56313 L
.92893 .57284 L
.92576 .58256 L
.92288 .59227 L
.92249 .59384 L
.91984 .60198 L
.91664 .61169 L
.91364 .62141 L
.91278 .6247 L
.91068 .63112 L
.90746 .64083 L
.90437 .65054 L
.90307 .65533 L
.90145 .66026 L
.89821 .66997 L
.89506 .67968 L
.89336 .68573 L
.89214 .68939 L
.88888 .69911 L
.88569 .70882 L
.88364 .71589 L
.88277 .71853 L
.87949 .72824 L
.87625 .73796 L
.87393 .74582 L
.87331 .74767 L
.87002 .75738 L
.86674 .76709 L
.86422 .77551 L
.86378 .77681 L
.86046 .78652 L
.85716 .79623 L
.85451 .80497 L
.85417 .80594 L
.85083 .81566 L
.84751 .82537 L
.84479 .83417 L
.84448 .83508 L
.84112 .84479 L
.83777 .85451 L
.83508 .86314 L
.83471 .86422 L
.83131 .87393 L
.82794 .88364 L
.82537 .89186 L
.82485 .89336 L
.82142 .90307 L
.81803 .91278 L
.81566 .92033 L
.8149 .92249 L
.81144 .93221 L
.80804 .94192 L
.80594 .94855 L
.80485 .95163 L
.80137 .96134 L
.79796 .97106 L
.79623 .97653 L
.79471 .98077 L
.98077 .98077 L
F
0 g
.98077 .4039 m
.97958 .40773 L
.97671 .41744 L
.97381 .42716 L
.97106 .43612 L
.97082 .43687 L
.96775 .44658 L
.96465 .45629 L
.96184 .46601 L
.96134 .46811 L
.95893 .47572 L
.95581 .48543 L
.95284 .49514 L
.95163 .49988 L
.95005 .50486 L
.94691 .51457 L
.94384 .52428 L
.94192 .53142 L
.9411 .53399 L
.93795 .54371 L
.93483 .55342 L
.93221 .56275 L
.93208 .56313 L
.92893 .57284 L
.92576 .58256 L
.92288 .59227 L
.92249 .59384 L
.91984 .60198 L
.91664 .61169 L
.91364 .62141 L
.91278 .6247 L
.91068 .63112 L
.90746 .64083 L
.90437 .65054 L
.90307 .65533 L
.90145 .66026 L
.89821 .66997 L
.89506 .67968 L
.89336 .68573 L
.89214 .68939 L
.88888 .69911 L
.88569 .70882 L
.88364 .71589 L
.88277 .71853 L
.87949 .72824 L
.87625 .73796 L
.87393 .74582 L
.87331 .74767 L
.87002 .75738 L
.86674 .76709 L
Mistroke
.86422 .77551 L
.86378 .77681 L
.86046 .78652 L
.85716 .79623 L
.85451 .80497 L
.85417 .80594 L
.85083 .81566 L
.84751 .82537 L
.84479 .83417 L
.84448 .83508 L
.84112 .84479 L
.83777 .85451 L
.83508 .86314 L
.83471 .86422 L
.83131 .87393 L
.82794 .88364 L
.82537 .89186 L
.82485 .89336 L
.82142 .90307 L
.81803 .91278 L
.81566 .92033 L
.8149 .92249 L
.81144 .93221 L
.80804 .94192 L
.80594 .94855 L
.80485 .95163 L
.80137 .96134 L
.79796 .97106 L
.79623 .97653 L
.79471 .98077 L
Mfstroke
.8 g
.98077 .42827 m
.97836 .43687 L
.97555 .44658 L
.97252 .45629 L
.97106 .46061 L
.9691 .46601 L
.96486 .47572 L
.96359 .48543 L
.96134 .49276 L
.9605 .49514 L
.95656 .50486 L
.95474 .51457 L
.95176 .52428 L
.95163 .52468 L
.94805 .53399 L
.94584 .54371 L
.94284 .55342 L
.94192 .55636 L
.93938 .56313 L
.93485 .57284 L
.93386 .58256 L
.93221 .58783 L
.93057 .59227 L
.92633 .60198 L
.92483 .61169 L
.92249 .61909 L
.92165 .62141 L
.91761 .63112 L
.91573 .64083 L
.91278 .65013 L
.91263 .65054 L
.90873 .66026 L
.90656 .66997 L
.90347 .67968 L
.90307 .68092 L
.89973 .68939 L
.89733 .69911 L
.89422 .70882 L
.89336 .71148 L
.8906 .71853 L
.88584 .72824 L
.88491 .73796 L
.88364 .74182 L
.88137 .74767 L
.87675 .75738 L
.87552 .76709 L
.87393 .77193 L
.87205 .77681 L
.86752 .78652 L
.86607 .79623 L
.86422 .80181 L
.86262 .80594 L
.85815 .81566 L
.85654 .82537 L
.85451 .83146 L
.8531 .83508 L
.84866 .84479 L
.84693 .85451 L
.84479 .86088 L
.84349 .86422 L
.83903 .87393 L
.83725 .88364 L
.83508 .89005 L
.83378 .89336 L
.82928 .90307 L
.82748 .91278 L
.82537 .91898 L
.82397 .92249 L
.8194 .93221 L
.81764 .94192 L
.81566 .94767 L
.81406 .95163 L
.80938 .96134 L
.80771 .97106 L
.80594 .97619 L
.80404 .98077 L
.98077 .98077 L
F
0 g
.98077 .42827 m
.97836 .43687 L
.97555 .44658 L
.97252 .45629 L
.97106 .46061 L
.9691 .46601 L
.96486 .47572 L
.96359 .48543 L
.96134 .49276 L
.9605 .49514 L
.95656 .50486 L
.95474 .51457 L
.95176 .52428 L
.95163 .52468 L
.94805 .53399 L
.94584 .54371 L
.94284 .55342 L
.94192 .55636 L
.93938 .56313 L
.93485 .57284 L
.93386 .58256 L
.93221 .58783 L
.93057 .59227 L
.92633 .60198 L
.92483 .61169 L
.92249 .61909 L
.92165 .62141 L
.91761 .63112 L
.91573 .64083 L
.91278 .65013 L
.91263 .65054 L
.90873 .66026 L
.90656 .66997 L
.90347 .67968 L
.90307 .68092 L
.89973 .68939 L
.89733 .69911 L
.89422 .70882 L
.89336 .71148 L
.8906 .71853 L
.88584 .72824 L
.88491 .73796 L
.88364 .74182 L
.88137 .74767 L
.87675 .75738 L
.87552 .76709 L
.87393 .77193 L
.87205 .77681 L
.86752 .78652 L
.86607 .79623 L
Mistroke
.86422 .80181 L
.86262 .80594 L
.85815 .81566 L
.85654 .82537 L
.85451 .83146 L
.8531 .83508 L
.84866 .84479 L
.84693 .85451 L
.84479 .86088 L
.84349 .86422 L
.83903 .87393 L
.83725 .88364 L
.83508 .89005 L
.83378 .89336 L
.82928 .90307 L
.82748 .91278 L
.82537 .91898 L
.82397 .92249 L
.8194 .93221 L
.81764 .94192 L
.81566 .94767 L
.81406 .95163 L
.80938 .96134 L
.80771 .97106 L
.80594 .97619 L
.80404 .98077 L
Mfstroke
.7 g
.98077 .52121 m
.97986 .52428 L
.97694 .53399 L
.97395 .54371 L
.97106 .55303 L
.97094 .55342 L
.96793 .56313 L
.9662 .57284 L
.96211 .58256 L
.96134 .58466 L
.95897 .59227 L
.95767 .60198 L
.95327 .61169 L
.95163 .61607 L
.94994 .62141 L
.94691 .63112 L
.9444 .64083 L
.94192 .64723 L
.94086 .65054 L
.93779 .66026 L
.93547 .66997 L
.93221 .67814 L
.93171 .67968 L
.92861 .68939 L
.92649 .69911 L
.92249 .7088 L
.92249 .70882 L
.91937 .71853 L
.91745 .72824 L
.91327 .73796 L
.91278 .73926 L
.91006 .74767 L
.90832 .75738 L
.90398 .76709 L
.90307 .76948 L
.90067 .77681 L
.8991 .78652 L
.89461 .79623 L
.89336 .79945 L
.89121 .80594 L
.88976 .81566 L
.88515 .82537 L
.88364 .82917 L
.88167 .83508 L
.88031 .84479 L
.87559 .85451 L
.87393 .85865 L
.87206 .86422 L
.87072 .87393 L
.86593 .88364 L
.86422 .88787 L
.86236 .89336 L
.86098 .90307 L
.85616 .91278 L
.85451 .91684 L
.85257 .92249 L
.8511 .93221 L
.84628 .94192 L
.84479 .94555 L
.8427 .95163 L
.84106 .96134 L
.83629 .97106 L
.83508 .97389 L
.83273 .98077 L
.98077 .98077 L
F
0 g
.98077 .52121 m
.97986 .52428 L
.97694 .53399 L
.97395 .54371 L
.97106 .55303 L
.97094 .55342 L
.96793 .56313 L
.9662 .57284 L
.96211 .58256 L
.96134 .58466 L
.95897 .59227 L
.95767 .60198 L
.95327 .61169 L
.95163 .61607 L
.94994 .62141 L
.94691 .63112 L
.9444 .64083 L
.94192 .64723 L
.94086 .65054 L
.93779 .66026 L
.93547 .66997 L
.93221 .67814 L
.93171 .67968 L
.92861 .68939 L
.92649 .69911 L
.92249 .7088 L
.92249 .70882 L
.91937 .71853 L
.91745 .72824 L
.91327 .73796 L
.91278 .73926 L
.91006 .74767 L
.90832 .75738 L
.90398 .76709 L
.90307 .76948 L
.90067 .77681 L
.8991 .78652 L
.89461 .79623 L
.89336 .79945 L
.89121 .80594 L
.88976 .81566 L
.88515 .82537 L
.88364 .82917 L
.88167 .83508 L
.88031 .84479 L
.87559 .85451 L
.87393 .85865 L
.87206 .86422 L
.87072 .87393 L
.86593 .88364 L
Mistroke
.86422 .88787 L
.86236 .89336 L
.86098 .90307 L
.85616 .91278 L
.85451 .91684 L
.85257 .92249 L
.8511 .93221 L
.84628 .94192 L
.84479 .94555 L
.8427 .95163 L
.84106 .96134 L
.83629 .97106 L
.83508 .97389 L
.83273 .98077 L
Mfstroke
.6 g
.98077 .54556 m
.97843 .55342 L
.97548 .56313 L
.97168 .57284 L
.97106 .57755 L
.96982 .58256 L
.96684 .59227 L
.96369 .60198 L
.96134 .60931 L
.96079 .61169 L
.95794 .62141 L
.95478 .63112 L
.95164 .64083 L
.95163 .64085 L
.94895 .65054 L
.9458 .66026 L
.94263 .66997 L
.94192 .67216 L
.93988 .67968 L
.93676 .68939 L
.93355 .69911 L
.93221 .70324 L
.93073 .70882 L
.92764 .71853 L
.92441 .72824 L
.92249 .73408 L
.9215 .73796 L
.91845 .74767 L
.91521 .75738 L
.91278 .76469 L
.91218 .76709 L
.90919 .77681 L
.90593 .78652 L
.90307 .79507 L
.90278 .79623 L
.89985 .80594 L
.89658 .81566 L
.89336 .8252 L
.89332 .82537 L
.89044 .83508 L
.88715 .84479 L
.88384 .85451 L
.88364 .8551 L
.88094 .86422 L
.87764 .87393 L
.87431 .88364 L
.87393 .88476 L
.87137 .89336 L
.86805 .90307 L
.86469 .91278 L
.86422 .91417 L
.86172 .92249 L
.85838 .93221 L
.855 .94192 L
.85451 .94334 L
.85199 .95163 L
.84862 .96134 L
.84521 .97106 L
.84479 .97225 L
.84217 .98077 L
.98077 .98077 L
F
0 g
.98077 .54556 m
.97843 .55342 L
.97548 .56313 L
.97168 .57284 L
.97106 .57755 L
.96982 .58256 L
.96684 .59227 L
.96369 .60198 L
.96134 .60931 L
.96079 .61169 L
.95794 .62141 L
.95478 .63112 L
.95164 .64083 L
.95163 .64085 L
.94895 .65054 L
.9458 .66026 L
.94263 .66997 L
.94192 .67216 L
.93988 .67968 L
.93676 .68939 L
.93355 .69911 L
.93221 .70324 L
.93073 .70882 L
.92764 .71853 L
.92441 .72824 L
.92249 .73408 L
.9215 .73796 L
.91845 .74767 L
.91521 .75738 L
.91278 .76469 L
.91218 .76709 L
.90919 .77681 L
.90593 .78652 L
.90307 .79507 L
.90278 .79623 L
.89985 .80594 L
.89658 .81566 L
.89336 .8252 L
.89332 .82537 L
.89044 .83508 L
.88715 .84479 L
.88384 .85451 L
.88364 .8551 L
.88094 .86422 L
.87764 .87393 L
.87431 .88364 L
.87393 .88476 L
.87137 .89336 L
.86805 .90307 L
.86469 .91278 L
Mistroke
.86422 .91417 L
.86172 .92249 L
.85838 .93221 L
.855 .94192 L
.85451 .94334 L
.85199 .95163 L
.84862 .96134 L
.84521 .97106 L
.84479 .97225 L
.84217 .98077 L
Mfstroke
.5 g
.98077 .56579 m
.97641 .57284 L
.97479 .58256 L
.97258 .59227 L
.97106 .59786 L
.96986 .60198 L
.96691 .61169 L
.9639 .62141 L
.96134 .6297 L
.96093 .63112 L
.958 .64083 L
.95498 .65054 L
.95196 .66026 L
.95163 .66132 L
.94903 .66997 L
.946 .67968 L
.94295 .68939 L
.94192 .69271 L
.94 .69911 L
.93696 .70882 L
.93388 .71853 L
.93221 .72387 L
.93089 .72824 L
.92785 .73796 L
.92475 .74767 L
.92249 .7548 L
.92172 .75738 L
.91868 .76709 L
.91556 .77681 L
.91278 .7855 L
.91247 .78652 L
.90943 .79623 L
.9063 .80594 L
.90317 .81566 L
.90307 .81597 L
.90012 .82537 L
.89697 .83508 L
.89381 .84479 L
.89336 .8462 L
.89073 .85451 L
.88756 .86422 L
.88438 .87393 L
.88364 .87619 L
.88128 .88364 L
.87809 .89336 L
.87487 .90307 L
.87393 .90594 L
.87174 .91278 L
.86853 .92249 L
.86529 .93221 L
.86422 .93545 L
.86213 .94192 L
.8589 .95163 L
.85563 .96134 L
.85451 .96472 L
.85244 .97106 L
.84918 .98077 L
.98077 .98077 L
F
0 g
.98077 .56579 m
.97641 .57284 L
.97479 .58256 L
.97258 .59227 L
.97106 .59786 L
.96986 .60198 L
.96691 .61169 L
.9639 .62141 L
.96134 .6297 L
.96093 .63112 L
.958 .64083 L
.95498 .65054 L
.95196 .66026 L
.95163 .66132 L
.94903 .66997 L
.946 .67968 L
.94295 .68939 L
.94192 .69271 L
.94 .69911 L
.93696 .70882 L
.93388 .71853 L
.93221 .72387 L
.93089 .72824 L
.92785 .73796 L
.92475 .74767 L
.92249 .7548 L
.92172 .75738 L
.91868 .76709 L
.91556 .77681 L
.91278 .7855 L
.91247 .78652 L
.90943 .79623 L
.9063 .80594 L
.90317 .81566 L
.90307 .81597 L
.90012 .82537 L
.89697 .83508 L
.89381 .84479 L
.89336 .8462 L
.89073 .85451 L
.88756 .86422 L
.88438 .87393 L
.88364 .87619 L
.88128 .88364 L
.87809 .89336 L
.87487 .90307 L
.87393 .90594 L
.87174 .91278 L
.86853 .92249 L
.86529 .93221 L
Mistroke
.86422 .93545 L
.86213 .94192 L
.8589 .95163 L
.85563 .96134 L
.85451 .96472 L
.85244 .97106 L
.84918 .98077 L
Mfstroke
.4 g
.98077 .58506 m
.97825 .59227 L
.97549 .60198 L
.97269 .61169 L
.97106 .61719 L
.96978 .62141 L
.96679 .63112 L
.96381 .64083 L
.96134 .64911 L
.96091 .65054 L
.95791 .66026 L
.9549 .66997 L
.95196 .67968 L
.95163 .68079 L
.94897 .68939 L
.94594 .69911 L
.94294 .70882 L
.94192 .71226 L
.93997 .71853 L
.93692 .72824 L
.93388 .73796 L
.93221 .74349 L
.9309 .74767 L
.92783 .75738 L
.92476 .76709 L
.92249 .7745 L
.92177 .77681 L
.91868 .78652 L
.91559 .79623 L
.91278 .80527 L
.91257 .80594 L
.90947 .81566 L
.90635 .82537 L
.90329 .83508 L
.90307 .83581 L
.90019 .84479 L
.89704 .85451 L
.89395 .86422 L
.89336 .86612 L
.89083 .87393 L
.88766 .88364 L
.88453 .89336 L
.88364 .89619 L
.88141 .90307 L
.87821 .91278 L
.87505 .92249 L
.87393 .92602 L
.87191 .93221 L
.86869 .94192 L
.8655 .95163 L
.86422 .95562 L
.86233 .96134 L
.85908 .97106 L
.85587 .98077 L
.98077 .98077 L
F
0 g
.98077 .58506 m
.97825 .59227 L
.97549 .60198 L
.97269 .61169 L
.97106 .61719 L
.96978 .62141 L
.96679 .63112 L
.96381 .64083 L
.96134 .64911 L
.96091 .65054 L
.95791 .66026 L
.9549 .66997 L
.95196 .67968 L
.95163 .68079 L
.94897 .68939 L
.94594 .69911 L
.94294 .70882 L
.94192 .71226 L
.93997 .71853 L
.93692 .72824 L
.93388 .73796 L
.93221 .74349 L
.9309 .74767 L
.92783 .75738 L
.92476 .76709 L
.92249 .7745 L
.92177 .77681 L
.91868 .78652 L
.91559 .79623 L
.91278 .80527 L
.91257 .80594 L
.90947 .81566 L
.90635 .82537 L
.90329 .83508 L
.90307 .83581 L
.90019 .84479 L
.89704 .85451 L
.89395 .86422 L
.89336 .86612 L
.89083 .87393 L
.88766 .88364 L
.88453 .89336 L
.88364 .89619 L
.88141 .90307 L
.87821 .91278 L
.87505 .92249 L
.87393 .92602 L
.87191 .93221 L
.86869 .94192 L
.8655 .95163 L
Mistroke
.86422 .95562 L
.86233 .96134 L
.85908 .97106 L
.85587 .98077 L
Mfstroke
.3 g
.98077 .60529 m
.97881 .61169 L
.97594 .62141 L
.97303 .63112 L
.97106 .6375 L
.97001 .64083 L
.96692 .65054 L
.96385 .66026 L
.96134 .6695 L
.9612 .66997 L
.9581 .67968 L
.95499 .68939 L
.95214 .69911 L
.95163 .70126 L
.94922 .70882 L
.94608 .71853 L
.94309 .72824 L
.94192 .73281 L
.94027 .73796 L
.93711 .74767 L
.93403 .75738 L
.93221 .76413 L
.93125 .76709 L
.92808 .77681 L
.92494 .78652 L
.92249 .79522 L
.92217 .79623 L
.91899 .80594 L
.91581 .81566 L
.91295 .82537 L
.91278 .82608 L
.90982 .83508 L
.90661 .84479 L
.90364 .85451 L
.90307 .85671 L
.90059 .86422 L
.89735 .87393 L
.89429 .88364 L
.89336 .88711 L
.89128 .89336 L
.88802 .90307 L
.88489 .91278 L
.88364 .91727 L
.8819 .92249 L
.87862 .93221 L
.87544 .94192 L
.87393 .9472 L
.87244 .95163 L
.86914 .96134 L
.86592 .97106 L
.86422 .97691 L
.86291 .98077 L
.98077 .98077 L
F
0 g
.98077 .60529 m
.97881 .61169 L
.97594 .62141 L
.97303 .63112 L
.97106 .6375 L
.97001 .64083 L
.96692 .65054 L
.96385 .66026 L
.96134 .6695 L
.9612 .66997 L
.9581 .67968 L
.95499 .68939 L
.95214 .69911 L
.95163 .70126 L
.94922 .70882 L
.94608 .71853 L
.94309 .72824 L
.94192 .73281 L
.94027 .73796 L
.93711 .74767 L
.93403 .75738 L
.93221 .76413 L
.93125 .76709 L
.92808 .77681 L
.92494 .78652 L
.92249 .79522 L
.92217 .79623 L
.91899 .80594 L
.91581 .81566 L
.91295 .82537 L
.91278 .82608 L
.90982 .83508 L
.90661 .84479 L
.90364 .85451 L
.90307 .85671 L
.90059 .86422 L
.89735 .87393 L
.89429 .88364 L
.89336 .88711 L
.89128 .89336 L
.88802 .90307 L
.88489 .91278 L
.88364 .91727 L
.8819 .92249 L
.87862 .93221 L
.87544 .94192 L
.87393 .9472 L
.87244 .95163 L
.86914 .96134 L
.86592 .97106 L
Mistroke
.86422 .97691 L
.86291 .98077 L
Mfstroke
.2 g
.98077 .62966 m
.98036 .63112 L
.97763 .64083 L
.97477 .65054 L
.97166 .66026 L
.97106 .662 L
.96808 .66997 L
.96576 .67968 L
.9628 .68939 L
.96134 .69413 L
.95954 .69911 L
.95532 .70882 L
.95395 .71853 L
.95163 .72606 L
.95085 .72824 L
.94691 .73796 L
.94505 .74767 L
.94204 .75738 L
.94192 .75776 L
.9383 .76709 L
.93608 .77681 L
.93306 .78652 L
.93221 .78922 L
.92955 .79623 L
.92495 .80594 L
.92402 .81566 L
.92249 .82047 L
.92067 .82537 L
.91633 .83508 L
.91491 .84479 L
.91278 .8515 L
.91167 .85451 L
.90752 .86422 L
.90574 .87393 L
.90307 .88231 L
.90258 .88364 L
.89857 .89336 L
.89651 .90307 L
.89339 .91278 L
.89336 .91289 L
.88948 .92249 L
.88721 .93221 L
.88407 .94192 L
.88364 .94322 L
.88027 .95163 L
.87784 .96134 L
.87468 .97106 L
.87393 .97337 L
.87096 .98077 L
.98077 .98077 L
F
0 g
.98077 .62966 m
.98036 .63112 L
.97763 .64083 L
.97477 .65054 L
.97166 .66026 L
.97106 .662 L
.96808 .66997 L
.96576 .67968 L
.9628 .68939 L
.96134 .69413 L
.95954 .69911 L
.95532 .70882 L
.95395 .71853 L
.95163 .72606 L
.95085 .72824 L
.94691 .73796 L
.94505 .74767 L
.94204 .75738 L
.94192 .75776 L
.9383 .76709 L
.93608 .77681 L
.93306 .78652 L
.93221 .78922 L
.92955 .79623 L
.92495 .80594 L
.92402 .81566 L
.92249 .82047 L
.92067 .82537 L
.91633 .83508 L
.91491 .84479 L
.91278 .8515 L
.91167 .85451 L
.90752 .86422 L
.90574 .87393 L
.90307 .88231 L
.90258 .88364 L
.89857 .89336 L
.89651 .90307 L
.89339 .91278 L
.89336 .91289 L
.88948 .92249 L
.88721 .93221 L
.88407 .94192 L
.88364 .94322 L
.88027 .95163 L
.87784 .96134 L
.87468 .97106 L
.87393 .97337 L
.87096 .98077 L
s
.3 g
.98077 .72259 m
.9791 .72824 L
.97615 .73796 L
.97315 .74767 L
.97106 .75444 L
.97014 .75738 L
.96714 .76709 L
.965 .77681 L
.96134 .78604 L
.96119 .78652 L
.95817 .79623 L
.95636 .80594 L
.95228 .81566 L
.95163 .81744 L
.94913 .82537 L
.94771 .83508 L
.94335 .84479 L
.94192 .84861 L
.94004 .85451 L
.93903 .86422 L
.93437 .87393 L
.93221 .87953 L
.93088 .88364 L
.9278 .89336 L
.92534 .90307 L
.92249 .91022 L
.92166 .91278 L
.91855 .92249 L
.91623 .93221 L
.91278 .94065 L
.91237 .94192 L
.90922 .95163 L
.90705 .96134 L
.90307 .97085 L
.903 .97106 L
.89983 .98077 L
.98077 .98077 L
F
0 g
.98077 .72259 m
.9791 .72824 L
.97615 .73796 L
.97315 .74767 L
.97106 .75444 L
.97014 .75738 L
.96714 .76709 L
.965 .77681 L
.96134 .78604 L
.96119 .78652 L
.95817 .79623 L
.95636 .80594 L
.95228 .81566 L
.95163 .81744 L
.94913 .82537 L
.94771 .83508 L
.94335 .84479 L
.94192 .84861 L
.94004 .85451 L
.93903 .86422 L
.93437 .87393 L
.93221 .87953 L
.93088 .88364 L
.9278 .89336 L
.92534 .90307 L
.92249 .91022 L
.92166 .91278 L
.91855 .92249 L
.91623 .93221 L
.91278 .94065 L
.91237 .94192 L
.90922 .95163 L
.90705 .96134 L
.90307 .97085 L
.903 .97106 L
.89983 .98077 L
s
.4 g
.98077 .74694 m
.98055 .74767 L
.97765 .75738 L
.97469 .76709 L
.97143 .77681 L
.97106 .77893 L
.96907 .78652 L
.96601 .79623 L
.96286 .80594 L
.96134 .8107 L
.9601 .81566 L
.95711 .82537 L
.95394 .83508 L
.95163 .84223 L
.95103 .84479 L
.94813 .85451 L
.94495 .86422 L
.94192 .87354 L
.94183 .87393 L
.93908 .88364 L
.9359 .89336 L
.93271 .90307 L
.93221 .90462 L
.92995 .91278 L
.92679 .92249 L
.92356 .93221 L
.92249 .93547 L
.92074 .94192 L
.9176 .95163 L
.91435 .96134 L
.91278 .96608 L
.91145 .97106 L
.90833 .98077 L
.98077 .98077 L
F
0 g
.98077 .74694 m
.98055 .74767 L
.97765 .75738 L
.97469 .76709 L
.97143 .77681 L
.97106 .77893 L
.96907 .78652 L
.96601 .79623 L
.96286 .80594 L
.96134 .8107 L
.9601 .81566 L
.95711 .82537 L
.95394 .83508 L
.95163 .84223 L
.95103 .84479 L
.94813 .85451 L
.94495 .86422 L
.94192 .87354 L
.94183 .87393 L
.93908 .88364 L
.9359 .89336 L
.93271 .90307 L
.93221 .90462 L
.92995 .91278 L
.92679 .92249 L
.92356 .93221 L
.92249 .93547 L
.92074 .94192 L
.9176 .95163 L
.91435 .96134 L
.91278 .96608 L
.91145 .97106 L
.90833 .98077 L
s
.5 g
.98077 .76717 m
.97596 .77681 L
.97427 .78652 L
.9719 .79623 L
.97106 .79924 L
.96909 .80594 L
.96611 .81566 L
.9631 .82537 L
.96134 .83108 L
.96017 .83508 L
.9572 .84479 L
.95417 .85451 L
.95163 .8627 L
.95119 .86422 L
.94823 .87393 L
.94519 .88364 L
.94215 .89336 L
.94192 .89409 L
.9392 .90307 L
.93614 .91278 L
.93307 .92249 L
.93221 .92526 L
.9301 .93221 L
.92703 .94192 L
.92393 .95163 L
.92249 .95619 L
.92092 .96134 L
.91785 .97106 L
.91473 .98077 L
.98077 .98077 L
F
0 g
.98077 .76717 m
.97596 .77681 L
.97427 .78652 L
.9719 .79623 L
.97106 .79924 L
.96909 .80594 L
.96611 .81566 L
.9631 .82537 L
.96134 .83108 L
.96017 .83508 L
.9572 .84479 L
.95417 .85451 L
.95163 .8627 L
.95119 .86422 L
.94823 .87393 L
.94519 .88364 L
.94215 .89336 L
.94192 .89409 L
.9392 .90307 L
.93614 .91278 L
.93307 .92249 L
.93221 .92526 L
.9301 .93221 L
.92703 .94192 L
.92393 .95163 L
.92249 .95619 L
.92092 .96134 L
.91785 .97106 L
.91473 .98077 L
s
.6 g
.98077 .78644 m
.98074 .78652 L
.9775 .79623 L
.97476 .80594 L
.97193 .81566 L
.97106 .81858 L
.96899 .82537 L
.966 .83508 L
.96303 .84479 L
.96134 .85049 L
.96012 .85451 L
.95711 .86422 L
.9541 .87393 L
.95163 .88218 L
.95118 .88364 L
.94817 .89336 L
.94513 .90307 L
.94217 .91278 L
.94192 .91364 L
.93916 .92249 L
.9361 .93221 L
.93309 .94192 L
.93221 .94488 L
.93009 .95163 L
.92701 .96134 L
.92396 .97106 L
.92249 .97588 L
.92096 .98077 L
.98077 .98077 L
F
0 g
.98077 .78644 m
.98074 .78652 L
.9775 .79623 L
.97476 .80594 L
.97193 .81566 L
.97106 .81858 L
.96899 .82537 L
.966 .83508 L
.96303 .84479 L
.96134 .85049 L
.96012 .85451 L
.95711 .86422 L
.9541 .87393 L
.95163 .88218 L
.95118 .88364 L
.94817 .89336 L
.94513 .90307 L
.94217 .91278 L
.94192 .91364 L
.93916 .92249 L
.9361 .93221 L
.93309 .94192 L
.93221 .94488 L
.93009 .95163 L
.92701 .96134 L
.92396 .97106 L
.92249 .97588 L
.92096 .98077 L
s
.7 g
.98077 .80667 m
.97805 .81566 L
.97518 .82537 L
.97224 .83508 L
.97106 .83888 L
.9692 .84479 L
.9661 .85451 L
.96308 .86422 L
.96134 .87088 L
.96038 .87393 L
.95727 .88364 L
.95419 .89336 L
.95163 .90265 L
.9515 .90307 L
.94839 .91278 L
.94526 .92249 L
.9424 .93221 L
.94192 .93419 L
.93944 .94192 L
.93628 .95163 L
.93328 .96134 L
.93221 .96551 L
.93042 .97106 L
.92724 .98077 L
.98077 .98077 L
F
0 g
.98077 .80667 m
.97805 .81566 L
.97518 .82537 L
.97224 .83508 L
.97106 .83888 L
.9692 .84479 L
.9661 .85451 L
.96308 .86422 L
.96134 .87088 L
.96038 .87393 L
.95727 .88364 L
.95419 .89336 L
.95163 .90265 L
.9515 .90307 L
.94839 .91278 L
.94526 .92249 L
.9424 .93221 L
.94192 .93419 L
.93944 .94192 L
.93628 .95163 L
.93328 .96134 L
.93221 .96551 L
.93042 .97106 L
.92724 .98077 L
s
.8 g
.98077 .83103 m
.97964 .83508 L
.97689 .84479 L
.97398 .85451 L
.97106 .8634 L
.97077 .86422 L
.967 .87393 L
.96498 .88364 L
.96201 .89336 L
.96134 .89552 L
.95852 .90307 L
.95394 .91278 L
.95316 .92249 L
.95163 .92743 L
.94989 .93221 L
.94566 .94192 L
.94425 .95163 L
.94192 .95914 L
.94113 .96134 L
.93715 .97106 L
.93528 .98077 L
.98077 .98077 L
F
0 g
.98077 .83103 m
.97964 .83508 L
.97689 .84479 L
.97398 .85451 L
.97106 .8634 L
.97077 .86422 L
.967 .87393 L
.96498 .88364 L
.96201 .89336 L
.96134 .89552 L
.95852 .90307 L
.95394 .91278 L
.95316 .92249 L
.95163 .92743 L
.94989 .93221 L
.94566 .94192 L
.94425 .95163 L
.94192 .95914 L
.94113 .96134 L
.93715 .97106 L
.93528 .98077 L
s
.7 g
.98077 .92396 m
.97832 .93221 L
.97536 .94192 L
.97235 .95163 L
.97106 .95582 L
.96934 .96134 L
.96634 .97106 L
.9639 .98077 L
.98077 .98077 L
F
0 g
.98077 .92396 m
.97832 .93221 L
.97536 .94192 L
.97235 .95163 L
.97106 .95582 L
.96934 .96134 L
.96634 .97106 L
.9639 .98077 L
s
.6 g
.98077 .94833 m
.97979 .95163 L
.97687 .96134 L
.9739 .97106 L
.97106 .98031 L
.97096 .98077 L
.98077 .98077 L
F
0 g
.98077 .94833 m
.97979 .95163 L
.97687 .96134 L
.9739 .97106 L
.97106 .98031 L
.97096 .98077 L
s
.5 g
.98077 .96856 m
.98003 .97106 L
.97556 .98077 L
.98077 .98077 L
F
0 g
.98077 .96856 m
.98003 .97106 L
.97556 .98077 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00`_ooool2o`0000;ooooo0_l0
002Pooooo`00`_ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgJ3ooooo0033ooooo`04omgMgOl0
003o410@olc<c:7ooooo0033ooooo`04onk^k_lQ8B7o410@onk^kZ7ooooo0033ooooo`04ob4Q8Omg
MgOoMgMgoc8b<Z7ooooo0032ooooo`;o00000_ooool2o`000:3ooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0011oooo
o`;o000000?o410@ooooooooool08oooool5o`00023ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0T
ooooo`Go00009_ooool2o`000003oa0@4?oooooooooo02?ooooo00Gok^k^oc8b<_l0003o410@olc<
c00Tooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`08Oooool4o`000008oa0@4?ooooooooooonk^k_lb
<S;o0000oc8b<_o^k^h3ooooo`00@_ooool00ol0003oooooooooo`0Tooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@08?ooool01OmgMgOoV9RHoooooonHV9SoMgMg02Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A00Wooooo`03o`000?oooooooooo02Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@0Tooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B408oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00oooool003Oooooo1_l00002ooooo`Go00007Oooool6o`0000?ooooo00?oV9RHob4Q
8Oo^k^h08Oooool01Ol@413ooooooooooooooooo410@02Gooooo00?oV9RHob4Q8Oo^k^h09Oooool5
o`0002Gooooo00Go0000ooooooooooooooooo`00000Tooooo`05o`000?ooooooooooooooool00000
8oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool003oooooo
00CoA4A4omgMgOoooooo0000:?ooool00onHV9So8B4Qonk^kP0Pooooo`05o`000?oooooooooooooo
ool000009_ooool00onHV9So8B4Qonk^kP0Tooooo`04odA4A?oMgMgoooooo`0002Kooooo00Go0000
oiRHV?ooooooV9RHob4Q8@0Tooooo`05oc8b<_nHV9SooooooiRHV?lb<S808oooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool003oooooo00CogMgMoeEEEOoooooo
0000:Oooool00omgMgOoIVIVooooo`0Oooooo`05o`000?ooooooooooooooool000009oooool00omg
MgOoIVIVooooo`0Sooooo`04omgMgOmEEEGoooooo`0002Kooooo00Go0000oeEEEOl0003o410@olc<
c00Tooooo`05olc<c?l0003o0000o`000?o<c<`08oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000000oooool0043ooooo00?oMgMgolc<c?l00000:_ooool00ol0003ooooo
ooooo`0Nooooo`05oa0@4?ooooooooooooooool@4100:?ooool00ol0003oooooooooo`0Sooooo`03
ogMgMoo<c<co000002Kooooo00?oEEEEohN7Qoooool09_ooool01Ol@413o^[Zjoooooonj^[[o410@
02?ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo0010oooo
o`03onk^k_m4A4Co000002Kooooo00Go0000okZj^_ooooooV9RHoa0@400Pooooo`05ogMgMonHV9So
oooooiRHV?mgMgL09?ooool01Ol0003o^[ZjoooooonHV9So410@02Gooooo00?ok^k^odA4A?l00000
9_ooool00ooMgMgo410@oiRHV00Vooooo`05o`000?nj^[[ooooookZj^_l000008oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool0047ooooo00?oMgMgo`000?oo
ool09Oooool01OnHV9So410@o`000?lQ8B7oc<c<023ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0T
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`09_ooool00omgMgOo0000ooooo`0Vooooo`04olc<c?m4
A4Co0000oa0@42Cooooo00GoZJVYoa0@4?l0003o410@ojVYZ@0Qooooo`03oeEEEOmVIVKo000000Co
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`009?ooooooo`0004?o00000_ooool002Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`7o00000Oooool1ooooo`009?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo0Ol00001ooooo`7ooooo000T
ooooo`03o`000?oooooooooo0?oooooo?oooool1o`00007ooooo0Oooool002Cooooo00?o0000oooo
ooooool0ooooooloooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`3oooooocoo
oooo0Ol00001ooooo`7ooooo000Tooooo`;o00004?ooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00oooool01?l0003oooooooooool00003ooooo`04o`000?oooooooooo
o`0000?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`06o`000?oooooo
ooooo`000?oooooo00000_ooool01Ol0003ooooooooooooooooo000000Sooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooo`000002ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000
oooooooooooo00000_ooool01Ol0003oooooo`000?oooooo000000;ooooo00?o0000ooooooooool0
1_ooool02_l0003oooooooooool0003oooooo`000?oooooo0000ooooool00002ooooo`03o`000?oo
oooooooo00Kooooo00Wo0000ooooool0003oooooo`000?oooooo0000ooooool000001_ooool2o`00
00;ooooo000Tooooo`03o`000?oooooooooo00?ooooo2omVIVH00ol0003oC4a<oda<C00Goda<C003
o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0<oiVIV@03
o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`04ogmoO`03
o`000?mVIVKoIVIV00CoIVIV00?o0000oda<C?m<C4`04om<C4`00ol0003oIVIVofIVIP02ofIVIP05
o`000?moOgooOgmoogmoOol000001?nIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<
00Coc<c<00?o0000ok>c/onc/k<00onc/k<01?l0003oVIVIoiVIVOl00002ogmoO`05o`000?mVIVKo
IVIVofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`03o`000?m<C4coC4a<00;oC4a<00Ko
0000ofIVI_mVIVKo0000ogmoOol00002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01?l0
003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc
<c<01?l0003oC4a<oda<C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003o
c<c<olc<c006olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<
00?o0000oc<c<olc<c<01_lc<c<02_l0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc
/k<6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`[oIVIV00?o0000
oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000
oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00[oVIVI00?o0000
ogmoOomoOgl01OmoOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000
ofIVI_mVIVH00omVIVH01?l0003oOgmoogmoOol00004oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o
0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`02ok>c/`05o`000?nIVIWoVIVIoiVIVOl00000
0_moOgl01?l0003oIVIVofIVI_l00004oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<
C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`00
0008olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Go0000ogmoOol0003oIVIVo`000003oda<C003
o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH01ol0003oOgmoo`000?nIVIWo
0000ok>c/ol000002Oo<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003o
C4a<o`0000Wo<c<c00[o0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>c1_ooool1
o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool9ofIVIP03o`000?m<C4coC4a<
01OoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI
00coVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0:oiVIV@03o`000?moOgooOgmo
00GoOgmo00?o0000ofIVI_mVIVH01?mVIVH00ol0003oC4a<oda<C00Coda<C003o`000?mVIVKoIVIV
00;oIVIV00Go0000ogmoOomoOgooOgmoo`000004oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000
olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Go
0000ofIVI_mVIVKoIVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c00?o0000oda<C?m<C4`0
0_m<C4`01_l0003oIVIVofIVI_l0003oOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008
olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH01Ol0003oC4a<oda<
C?m<C4co000000So<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc
/k<00ol0003oc<c<olc<c007olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000
00;oC4a<00?o0000oc<c<olc<c<01_lc<c<00ol0003oC4a<o`000002ofIVIP;o000000GoVIVIo`00
0?nc/k?o/k>co`000005ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03oooo
o`SoIVIV0_l0000Hoda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0
003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0
003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV00CoIVIV00?o0000oda<C?m<C4`04om<C4`00ol0
003oIVIVofIVIP02ofIVIP03o`000?moOgooOgmo00;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000006
ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00onc/k<01Ol0003oVIVIoiVIVOnI
VIWo000000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c
00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Go0000ok>c
/onc/k?o/k>co`000008olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol000000_mV
IVH01?l0003oC4a<oda<C?l00008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Go0000ogmoOol0
003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00co0000ok>c/onc/k?o0000oiVIVOl0
003oOgmoo`000?mVIVKo0000oda<C?l00009oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`00
0?nIVIWo000000;o/k>c00?o0000ooooooooool00oooool1o`00007ooooo0Oooool002Cooooo00?o
0000ooooooooool00oooool7ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02omV
IVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00coVIVI00?o0000ok>c/onc/k<05_nc
/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00CoOgmo00?o0000ofIVI_mVIVH01OmV
IVH00ol0003oC4a<oda<C00Coda<C003o`000?mVIVKoIVIV00;oIVIV00?o0000ogmoOomoOgl00_mo
Ogl01Ol0003oVIVIoiVIVOnIVIWo000000Go/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>c
ok>c/`03ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01Ol0003oIVIVofIVI_mVIVKo0000
00?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Ko0000
ogmoOomoOgoo0000oiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o
00000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Co0000oda<
C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<
c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000Wo<c<c00Wo
0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oooooooooo`03oooo
o`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`KoIVIV00?o0000oda<C?m<
C4`05om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnI
VIT02onIVIT2o`0001So/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`04ogmoO`03
o`000?mVIVKoIVIV00GoIVIV00?o0000oda<C?m<C4`04om<C4`00ol0003oIVIVofIVIP02ofIVIP03
o`000?moOgooOgmo00;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000005ok>c/`03o`000?o<c<coc<c<
00Coc<c<00?o0000ok>c/onc/k<00onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Go0000
ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go<c<c00Go0000oda<C?m<C4coC4a<
o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<
c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l0
0009oc<c<`03o`000?m<C4co000000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`00
0?o<c<coc<c<00Ooc<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`0
0ol0003o<c<coc<c<`06oc<c<`03o`000?m<C4coC4a<00;o000000OoOgmoo`000?nIVIWoVIVIo`00
0?nc/k?o000000Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo1_mV
IVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00[oIVIV0_l0000:ogmoO`03o`000?nI
VIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<2o`0000coVIVI0_l00007ogmoO`03o`000?mV
IVKoIVIV00CoIVIV00?o0000oda<C?m<C4`05?m<C4`00ol0003oIVIVofIVIP02ofIVIP05o`000?mo
OgooOgmoogmoOol000001?nIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00Coc<c<
00?o0000ok>c/onc/k<00onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Co0000ofIVI_mV
IVKo00001?m<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH0
1?l0003oOgmoogmoOol00002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01?l0003o/k>c
ok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<00ol0
003oC4a<o`000002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007
olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc
<c<01_lc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?oo
oooooooo00Cooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo1OmVIVH0
0ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00[oIVIV00?o0000ogmoOomoOgl02OmoOgl0
0ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT03?nIVIT0
0ol0003oOgmoogmoO`06ogmoO`03o`000?mVIVKoIVIV00CoIVIV00?o0000oda<C?m<C4`04om<C4`0
0ol0003oIVIVofIVIP03ofIVIP05o`000?moOgooOgmoogmoOol000001?nIVIT00ol0003o/k>cok>c
/`03ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00onc/k<01?l0003oVIVIoiVI
VOl00003ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003o
C4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01Ol0003o/k>cok>c/onc
/k?o000000Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`00
0?m<C4coC4a<o`0000Wo<c<c00Go0000oda<C?l0003oIVIVo`000002ogmoO`03o`000?nIVIWo0000
00;o/k>c00?o0000olc<c?o<c<`01oo<c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIV
o`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000
oiVIVOl000000_nc/k<00ol0003oooooooooo`04ooooo`7o00000Oooool1ooooo`009?ooool00ol0
003oooooooooo`03ooooo`CoIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIV
IP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c
/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl01_moOgl00ol0003oIVIVofIVIP04ofIV
IP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo
000000CoVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o
/k>c00?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<
00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomo
Ogoo00000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Co0000ok>c/onc/k?o00000_nI
VIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000Wo<c<c00?o0000oda<C?l00000
0_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`02Ol0003o
/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Ko
0000oda<C?l0003oIVIVo`000?moOgl2o`0000;o/k>c00?o0000olc<c?ooool01Oooool1o`00007o
oooo0Oooool002Cooooo00?o0000ooooooooool00oooool3ofIVIP03o`000?m<C4coC4a<01KoC4a<
00?o0000ofIVI_mVIVH02_mVIVH2o`0000[oOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>c
ok>c/`0Fok>c/`;o00003OnIVIT00ol0003oOgmoogmoO`05ogmoO`;o00001_mVIVH00ol0003oC4a<
oda<C00Doda<C003o`000?mVIVKoIVIV00;oIVIV00?o0000ogmoOomoOgl00_moOgl01Ol0003oVIVI
oiVIVOnIVIWo000000Ko/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`03ok>c/`05
o`000?nIVIWoVIVIoiVIVOl000000omoOgl01?l0003oIVIVofIVI_l00004oda<C003o`000?lc<c?o
<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nI
VIWoVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;o
VIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`04o`000?m<C4coC4a<
o`0000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00[o
0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06
oc<c<`05o`000?m<C4coC4a<o`000?mVIVH00_l000001_nIVIWo0000ok>c/onc/k?o0000olc<c0Ko
oooo0Ol00001ooooo`7ooooo000Tooooo`;o00001?ooool2ofIVIP03o`000?m<C4coC4a<01KoC4a<
00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI
00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo00KoOgmo
00?o0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<C00Doda<C003o`000?mVIVKoIVIV00;oIVIV
00?o0000ogmoOomoOgl00_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Ko/k>c00?o0000olc<c?o<
c<`00oo<c<`00ol0003o/k>cok>c/`03ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01?l0
003oIVIVofIVI_l00004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`0
1?l0003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000;o/k>c00?o0000olc<c?o<c<`0
1_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<
C003o`000?lc<c?o<c<c00Oo<c<c00Co0000oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nI
VIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?mo
Ogoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4co0000ofIV
IP02o`000006oiVIVOl0003o/k>cok>c/ol0003oc<c<1Oooool2o`0000;ooooo000Tooooo`03o`00
0?oooooooooo00?ooooo00?oIVIVo`000?m<C4`05om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`00
0?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`00
0?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl01_moOgl00ol0003oIVIVofIVIP05ofIVIP03o`00
0?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH00_mVIVH00ol0003oOgmoogmoO`02ogmoO`05o`00
0?nIVIWoVIVIoiVIVOl000001_nc/k<00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c00?o
/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000
oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo0000
0_nIVIT01?l0003o/k>cok>c/ol00008olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT00ol0
003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000Wo<c<c00[o0000oda<C?m<C4co0000ofIV
I_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c007olc<c007o`000?nc/k?o0000
oiVIVOl0003oOgmoo`000002ofIVIP03o`000?m<C4co000000So<c<c00Go0000oda<C?m<C4co0000
ofIVIP02o`000005oiVIVOl0003o/k>cok>c/ol000000_o<c<`6ooooo`7o00000Oooool1ooooo`00
9?ooool00ol0003oooooooooo`03ooooo`03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH0
2omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<0
5_nc/k<00ol0003oVIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH0
1OmVIVH2o`0001GoC4a<00?o0000ofIVI_mVIVH00_mVIVH00ol0003oOgmoogmoO`02ogmoO`03o`00
0?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c004olc<c003o`00
0?nc/k?o/k>c00?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`05o`000?mVIVKoIVIVofIV
I_l000000om<C4`2o`0000Oo<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgoo
Ogmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c007o`000?nc/k?o/k>cok>c/ol0
003oVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<0
1_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<
olc<c006olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o
0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?l0003oIVIV00;o000000GoVIVIo`000?nc/k?o
/k>co`000002olc<c0Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo
6?m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT0
2onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI0_l00008ogmoO`03o`00
0?mVIVKoIVIV00KoIVIV00?o0000oda<C?m<C4`04om<C4`00ol0003oIVIVofIVIP03ofIVIP03o`00
0?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`03ok>c/`03o`00
0?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;o
Ogmo00Go0000ofIVI_mVIVKoIVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<
C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>c
o`000008olc<c007o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000002ogmoO`04o`000?mVIVKoIVIV
o`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo
00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c00:o`000?nc/k?o/k>co`000?nI
VIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<
C?l0003oIVIV00;o000000GoVIVIo`000?nc/k?o/k>co`000002olc<c0Kooooo0Ol00001ooooo`7o
oooo000Tooooo`03o`000?oooooooooo00?ooooo5om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`00
0?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`00
0?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP05ofIVIP03o`00
0?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH00_mVIVH00ol0003oOgmoogmoO`02ogmoO`03o`00
0?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c004olc<c003o`00
0?nc/k?o/k>c00?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`05o`000?mVIVKoIVIVofIV
I_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIV
I_mVIVKo00000_moOgl00ol0003oVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Co0000
ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c
00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<
c?o<c<`01oo<c<`01Ol0003o/k>co`000?nIVIWo000000;oOgmo0_l00002oda<C003o`000?lc<c?o
<c<c00Ko<c<c00Go0000oda<C?m<C4co0000ofIVIP02o`0000;oVIVI00?o0000ok>c/ol000000oo<
c<`6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03oooooaGoC4a<0_l0000=
ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0F
ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP05
ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH00omVIVH01Ol0003oOgmoogmoOomo
Ogoo000000CoVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c003olc<c003o`000?nc
/k?o/k>c00?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`04o`000?mVIVKoIVIVo`0000Co
C4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmo
OomoOgoo00000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Oo0000ok>c/onc/k?o/k>c
o`000?nIVIWo000000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`06
o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<co
c<c<00Ooc<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o
<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<o`000?mVIVH00_l00002oiVIV@03o`000?nc/k?o0000
00?oc<c<1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00ooooolDoda<C003
o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl02?moOgl2o`0000coVIVI00?o0000ok>c/onc
/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@;o00002OmoOgl00ol0003oIVIVofIVIP05ofIVIP03
o`000?m<C4coC4a<01GoC4a<00?o0000ofIVI_mVIVH00omVIVH01Ol0003oOgmoogmoOomoOgoo0000
00CoVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c
00?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o
0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo
00000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Oo0000ok>c/onc/k?o/k>co`000?nI
VIWo000000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`06o`000?m<
C4coC4a<o`000?mVIVKo00000_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Oo
c<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c
<`06oc<c<`05o`000?m<C4coC4a<o`000?mVIVH00_l00002oiVIV@03o`000?nc/k?o000000?oc<c<
1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00ooooolCoda<C003o`000?mV
IVKoIVIV00_oIVIV0_l0000:ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc
/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH01_mV
IVH00ol0003oC4a<oda<C00Doda<C003o`000?mVIVKoIVIV00?oIVIV00Go0000ogmoOomoOgooOgmo
o`000004oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>c
ok>c/`03ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01Ol0003oIVIVofIVI_mVIVKo0000
00?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000
ogmoOomoOgoo00000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Oo0000ok>c/onc/k?o
/k>co`000?nIVIWo000000;oOgmo00?o0000ofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c
<`04o`000?m<C4coC4a<o`0000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<
c<coc<c<00Ooc<c<00?o0000ok>c/ol000000_nIVIT2o`000005ofIVI_l0003oC4a<oda<C?l00000
2?lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Coc<c<
1_ooool1o`00007ooooo0Oooool001_ooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oo
oooooooo00?ooooo4_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o
0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o
0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP06ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o
0000ofIVI_mVIVH00omVIVH01Ol0003oOgmoogmoOomoOgoo000000CoVIVI00?o0000ok>c/onc/k<0
1Onc/k<00ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c00Co/k>c00Go0000oiVIVOnIVIWo
VIVIo`000002ogmoO`05o`000?mVIVKoIVIVofIVI_l000001?m<C4`00ol0003o<c<coc<c<`05oc<c
<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl0
0003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT01_l0003oOgmo
ogmoOol0003oIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01_l0003oC4a<oda<C?l0003o
IVIVo`0000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c00:o`000?nc
/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<0
3?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Coc<c<1_ooool1
o`00007ooooo0Oooool001cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03oooo
oa7oC4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI
00_oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0:oiVIV@;o00002_moOgl00ol0
003oIVIVofIVIP06ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH00omVIVH01Ol0
003oOgmoogmoOomoOgoo000000CoVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c003
olc<c003o`000?nc/k?o/k>c00Co/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`05o`000?mV
IVKoIVIVofIVI_l000001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<
00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<
00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT01_l0003oOgmoogmoOol0003oIVIVo`0000;oC4a<
00?o0000oc<c<olc<c<01olc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00?o0000oiVI
VOl000000_nc/k<00ol0003oc<c<olc<c006olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmo
Ool0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<03?l0003oC4a<oda<C?l0003oIVIV
o`000?moOgoo0000oiVIVOl0003o/k>co`0000Coc<c<1_ooool1o`00007ooooo0Oooool0017ooooo
1_l00002ooooo`Go00001_ooool3o`0000?ooooo4?m<C4`00ol0003oIVIVofIVIP0;ofIVIP;o0000
2_moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT0
2_nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00KoIVIV00?o0000oda<C?m<C4`0
5?m<C4`00ol0003oIVIVofIVIP03ofIVIP03o`000?moOgooOgmo00;oOgmo00Go0000oiVIVOnIVIWo
VIVIo`000007ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o0000ok>c/onc/k<01?nc/k<01Ol0003o
VIVIoiVIVOnIVIWo000000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o
<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nI
VIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@04
o`000?moOgooOgmoo`0000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<01?l0003oC4a<oda<C?m<
C4`2o`0000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c003o`000?nc
/k?o/k>c00;o000000OoOgmoo`000?mVIVKoIVIVo`000?m<C4co000000So<c<c00co0000oda<C?m<
C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00005olc<c0Cooooo0ol00002ooooo`00
6Oooool01?m4A4CogMgMooooool00007ooooo`03o`000?oooooooooo00?ooooo3om<C4`00ol0003o
IVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o
/k>cok>c/`0Fok>c/`;o00003?nIVIT00ol0003oOgmoogmoO`08ogmoO`;o00002?mVIVH00ol0003o
C4a<oda<C00Doda<C003o`000?mVIVKoIVIV00?oIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003o
VIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003o
/k>cok>c/`03ok>c/`04o`000?nIVIWoVIVIoiVIV@;o00000_moOgl01Ol0003oIVIVofIVI_mVIVKo
000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?m<C4`2o`0000;oIVIV00Co
0000ogmoOomoOgoo00000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Co0000ok>c/onc
/k?o00000_nIVIT01_l0003oOgmoogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01olc
<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003o
c<c<olc<c006olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<
00?o0000oc<c<olc<c<01_lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0
003o/k>co`0000Goc<c<1_ooool1o`00007ooooo0Oooool001Wooooo00CogMgMoeEEEOoooooo0000
1oooool00ol0003oooooooooo`03ooooo`koC4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003oOgmo
ogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVI
oiVIV@0:oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH01omVIVH00ol0003oC4a<
oda<C00Doda<C003o`000?mVIVKoIVIV00;oIVIV00?o0000ogmoOomoOgl00omoOgl00ol0003oVIVI
oiVIV@02oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>c
ok>c/`03ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01Ol0003oIVIVofIVI_mVIVKo0000
00?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000?oIVIV00Co0000
ogmoOomoOgoo00000_nIVIT01?l0003o/k>cok>c/ol00009olc<c004o`000?nc/k?o/k>co`0000;o
VIVI00Ko0000ogmoOomoOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Ko0000
oda<C?m<C4co0000ofIVI_l00002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`0
1_o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc
<c?o<c<c00Ko<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol0
0005olc<c0Kooooo0Ol00001ooooo`7ooooo000Jooooo`03ogMgMoo<c<co000000Oooooo00?o0000
ooooooooool00oooool=oda<C003o`000?mVIVKoIVIV00_oIVIV0_l0000:ogmoO`03o`000?nIVIWo
VIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0:oiVIV@03o`000?moOgoo
Ogmo00WoOgmo00?o0000ofIVI_mVIVH01omVIVH00ol0003oC4a<oda<C00Doda<C003o`000?mVIVKo
IVIV00?oIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@02oiVIV@03o`000?nc/k?o
/k>c00Co/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`03ok>c/`05o`000?nIVIWo
VIVIoiVIVOl000000omoOgl01Ol0003oIVIVofIVI_mVIVKo000000?oC4a<00?o0000oc<c<olc<c<0
1_lc<c<01Ol0003oC4a<oda<C?m<C4co000000?oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01Ol0
003o/k>cok>c/onc/k?o000000Soc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@05o`000?mo
Ogoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`06o`000?m<C4coC4a<o`000?mV
IVKo00000_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Go0000ok>c
/ol0003oVIVIo`000002ogmoO`;o00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4co
C4a<o`0000;oIVIV0_l000001OnIVIWo0000ok>c/onc/k?o000000Goc<c<1_ooool1o`00007ooooo
0Oooool001[ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`03ooooo`coC4a<00?o
0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o
0000ok>c/onc/k<05_nc/k<2o`0000coVIVI00?o0000ogmoOomoOgl02?moOgl2o`0000WoIVIV00?o
0000oda<C?m<C4`05?m<C4`00ol0003oIVIVofIVIP03ofIVIP03o`000?moOgooOgmo00;oOgmo00?o
0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`05ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o
0000ok>c/onc/k<01?nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Co0000ofIVI_mVIVKo
00001?m<C4`00ol0003o<c<coc<c<`05oc<c<`;o00000om<C4`01?l0003oIVIVofIVI_l00002ogmo
O`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc
/k?o000000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`08o`00
0?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVIV@03o`000?nc/k?o000000[oc<c<00Wo0000
ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0<
o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00001_o<c<`6ooooo`7o
00000Oooool1ooooo`006oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo00?ooooo
3?m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT0
2onIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00[oVIVI00?o0000ogmoOomoOgl0
2OmoOgl00ol0003oIVIVofIVIP07ofIVIP03o`000?m<C4coC4a<01GoC4a<00?o0000ofIVI_mVIVH0
0omVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<0
1Onc/k<00ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c00Co/k>c00Go0000oiVIVOnIVIWo
VIVIo`000003ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0
003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo00000onc
/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT00ol0003oOgmo
o`000002ofIVIP04o`000?m<C4coC4a<o`0000Wo<c<c00So0000oda<C?m<C4co0000ofIVI_l0003o
Ogmoo`0000;oVIVI00?o0000ok>c/ol000002_o<c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0
003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00?o0000oda<C?l000000_mVIVH01ol0
003oOgmoo`000?nIVIWo0000ok>c/ol000001_o<c<`6ooooo`7o00000Oooool1ooooo`009?ooool0
0ol0003oooooooooo`03ooooo`_oC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`09
ogmoO`03o`000?nIVIWoVIVI00[oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0;
oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02?mVIVH00ol0003oC4a<oda<C00D
oda<C003o`000?mVIVKoIVIV00?oIVIV00?o0000ogmoOomoOgl00omoOgl01Ol0003oVIVIoiVIVOnI
VIWo000000Oo/k>c00?o0000olc<c?o<c<`00_o<c<`00ol0003o/k>cok>c/`05ok>c/`04o`000?nI
VIWoVIVIo`0000?oOgmo00Go0000ofIVI_mVIVKoIVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko
<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVI
o`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Go
0000ogmoOol0003oIVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co
00000_mVIVH00ol0003oOgmoo`000002oiVIV@03o`000?nc/k?o000000Woc<c<00[o0000ok>c/onc
/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`05oc<c<`04o`00
0?m<C4coC4a<o`0000;oIVIV00Co0000ogmoOol0003oVIVI0_l00007olc<c0Kooooo0Ol00001oooo
o`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo2_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03
o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03
o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP08ofIVIP03
o`000?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`03ogmoO`03
o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c002olc<c003
o`000?nc/k?o/k>c00Co/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`04o`000?mVIVKoIVIV
o`0000CoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKo
IVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c005o`00
0?nc/k?o/k>cok>c/ol000000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`00
00Wo<c<c00Co0000oda<C?m<C4co00000_mVIVH2o`0000;oVIVI00Co0000ok>c/onc/k?o00002Oo<
c<`00ol0003o/k>co`000002oiVIV@;o000000GoIVIVo`000?m<C4coC4a<o`000008oc<c<`0<o`00
0?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00001oo<c<`6ooooo`7o0000
0Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`WoC4a<00?o0000ofIVI_mVIVH02omV
IVH00ol0003oOgmoogmoO`08ogmoO`;o00003OnIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nI
VIWoVIVI00[oVIVI0_l0000:ogmoO`03o`000?mVIVKoIVIV00WoIVIV00?o0000oda<C?m<C4`05?m<
C4`00ol0003oIVIVofIVIP03ofIVIP03o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00_nI
VIT00ol0003o/k>cok>c/`06ok>c/`05o`000?o<c<coc<c<olc<c?l000001_nc/k<01Ol0003oVIVI
oiVIVOnIVIWo000000?oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c
00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWo
VIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI
00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`09o`000?m<C4coC4a<oda<
C?l0003oIVIVo`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`02_l0003o/k>c
ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Wo
0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIT00_l00008olc<c0Kooooo0Ol00001oooo
o`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo2?m<C4`00ol0003oIVIVofIVIP0;ofIVIP03
o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`0Fok>c/`03
o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP09ofIVIP03
o`000?m<C4coC4a<01GoC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`02ogmoO`03
o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01_nc/k<01Ol0003oc<c<olc<c?o<c<co0000
00Ko/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`05o`000?mVIVKoIVIVofIVI_l000001?m<
C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo0000
0_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc
/k?o/k>co`000002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<0
2Ol0003oC4a<oda<C?m<C4co0000ofIVI_l0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`00
00Ooc<c<00_o0000ok>c/onc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003
o`000?lc<c?o<c<c00Ko<c<c00Wo0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIT00_l0
0008olc<c0Kooooo0Ol00001ooooo`7ooooo000Tooooo`;o00001?ooool7oda<C003o`000?mVIVKo
IVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@;o00006?nc/k<0
0ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02OmVIVH0
0ol0003oC4a<oda<C00Eoda<C003o`000?mVIVKoIVIV00?oIVIV00?o0000ogmoOomoOgl00_moOgl0
0ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c00Go/k>c00Go0000olc<c?o<c<coc<c<o`00
0006ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01Ol0003oIVIVofIVI_mVIVKo000000Co
C4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`00
00;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c007olc<c004o`000?nc/k?o
/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`09o`00
0?m<C4coC4a<oda<C?l0003oIVIVo`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<
c<`02?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo00000_mVIVH00ol0003oC4a<o`000008oc<c
<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00002?o<c<`5oooo
o`;o00000_ooool002Cooooo00?o0000ooooooooool00oooool6oda<C003o`000?mVIVKoIVIV00[o
IVIV0_l0000:ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<2o`0000co
VIVI0_l00009ogmoO`;o00002omVIVH00ol0003oC4a<oda<C00Eoda<C003o`000?mVIVKoIVIV00?o
IVIV00?o0000ogmoOomoOgl00_moOgl2o`0000CoVIVI00?o0000ok>c/onc/k<01Onc/k<01Ol0003o
c<c<olc<c?o<c<co000000Oo/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`04o`000?mVIVKo
IVIVo`0000GoC4a<00?o0000oc<c<olc<c<01?lc<c<2o`0000CoC4a<00Co0000ofIVI_mVIVKo0000
0_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Oo0000ok>c/onc
/k?o/k>co`000?nIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo00000_m<C4`00ol0003o<c<coc<c
<`06oc<c<`09o`000?m<C4coC4a<oda<C?l0003oIVIVo`000?moOgoo000000;oVIVI00Co0000ok>c
/onc/k?o00002?o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<
C003o`000?lc<c?o<c<c00Ko<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo
0000ok>c/ol00008olc<c003o`000?oooooooooo00?ooooo0Ol00001ooooo`7ooooo000Tooooo`03
o`000?oooooooooo00?ooooo1Om<C4`00ol0003oIVIVofIVIP0:ofIVIP03o`000?moOgooOgmo00Wo
Ogmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00co
VIVI00?o0000ogmoOomoOgl01omoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01Co
C4a<00?o0000ofIVI_mVIVH01?mVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00?o
VIVI00?o0000ok>c/onc/k<01Onc/k<01Ol0003oc<c<olc<c?o<c<co000000Ko/k>c00?o0000oiVI
VOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000;oIVIV00?o0000oda<C?m<C4`00om<C4`0
0ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Co0000ofIVI_mVIVKo00000_mo
Ogl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Oo0000ok>c/onc/k?o
/k>co`000?nIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06
oc<c<`09o`000?m<C4coC4a<oda<C?l0003oIVIVo`000?moOgoo000000;oVIVI00Co0000ok>c/onc
/k?o00002?o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003
o`000?lc<c?o<c<c00Ko<c<c00?o0000oda<C?m<C4`00_l00002ogmoO`05o`000?nIVIWo0000ok>c
/ol000002?o<c<`00ol0003oooooooooo`03ooooo`7o00000Oooool1ooooo`009?ooool00ol0003o
ooooooooo`03ooooo`CoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03
o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0<oiVIV@03
o`000?moOgooOgmo00OoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Eoda<C003
o`000?mVIVKoIVIV00?oIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@03oiVIV@03
o`000?nc/k?o/k>c00Go/k>c00Go0000olc<c?o<c<coc<c<o`000007ok>c/`05o`000?nIVIWoVIVI
oiVIVOl000000omoOgl01?l0003oIVIVofIVI_l00005oda<C003o`000?lc<c?o<c<c00Co<c<c00?o
0000oda<C?m<C4`00om<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000?o
/k>c00?o0000olc<c?o<c<`01_o<c<`01ol0003o/k>cok>c/onc/k?o0000oiVIVOl000000_moOgl0
1?l0003oIVIVofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Oo0000oda<C?m<C4coC4a<
o`000?mVIVKo000000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c006
o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl2o`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<0
2_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<
00Goc<c<00?o0000ooooooooool01?ooool1o`00007ooooo0Oooool002Cooooo00?o0000oooooooo
ool00oooool3oda<C003o`000?mVIVKoIVIV00[oIVIV0_l0000:ogmoO`03o`000?nIVIWoVIVI00_o
VIVI00?o0000ok>c/onc/k<05_nc/k<2o`0000goVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003o
IVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<01GoC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003o
OgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01_nc/k<01?l0003o
c<c<olc<c?l00007ok>c/`04o`000?nIVIWoVIVIoiVIV@;o00000_moOgl01Ol0003oIVIVofIVI_mV
IVKo000000CoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C005o`000?mV
IVKoIVIVofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Oo
c<c<00Co0000ok>c/onc/k?o00000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP04o`000?m<C4co
C4a<o`0000So<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVIV@03o`00
0?nc/k?o000000Woc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<
C4`00ol0003o<c<coc<c<`06oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVI
o`000?nc/k?o00002?o<c<`00ol0003oooooooooo`04ooooo`7o00000Oooool1ooooo`009?ooool0
0ol0003oooooooooo`03ooooo`;oC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`09
ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0<
oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00E
oda<C003o`000?mVIVKoIVIV00?oIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@03
oiVIV@03o`000?nc/k?o/k>c00Ko/k>c00Co0000olc<c?o<c<co00001onc/k<01Ol0003oVIVIoiVI
VOnIVIWo000000?oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go
<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Co0000oiVI
VOnIVIWo00000_nc/k<00ol0003oc<c<olc<c007olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Co
0000ogmoOomoOgoo00000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`04o`000?m<C4coC4a<o`00
00;oIVIV00?o0000ogmoOol000000_nIVIT00ol0003o/k>co`000009olc<c00:o`000?nc/k?o/k>c
o`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<00ol0003o
C4a<o`000002ofIVIP07o`000?moOgoo0000oiVIVOl0003o/k>co`000008olc<c003o`000?oooooo
oooo00Cooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo00?oC4a<o`00
0?mVIVH03?mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c
/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIV
I_mVIVH02omVIVH00ol0003oC4a<oda<C00Eoda<C003o`000?mVIVKoIVIV00?oIVIV00?o0000ogmo
OomoOgl00_moOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c00Ko/k>c00Co0000olc<
c?o<c<co00001onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000CoOgmo00Co0000ofIVI_mVIVKo0000
1?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00?oC4a<00Co0000ofIVI_mVIVKo
00000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c
/onc/k?o00000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c
00Go0000oda<C?m<C4coC4a<o`000002ofIVIP;o00000_nIVIT01?l0003o/k>cok>c/ol00008olc<
c004o`000?nc/k?o/k>co`0000;oVIVI0_l000001OmVIVKo0000oda<C?m<C4co000000So<c<c00So
0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000;oVIVI0_l00008olc<c003o`000?nc/k?ooooo
00Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo00?o0000ofIVI_mV
IVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc
/k<05_nc/k<00ol0003oVIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mV
IVH02omVIVH00ol0003oC4a<oda<C00Doda<C0;o00001OmVIVH00ol0003oOgmoogmoO`03ogmoO`03
o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01onc/k<00ol0003oc<c<o`000008ok>c/`05
o`000?nIVIWoVIVIoiVIVOl000000omoOgl01Ol0003oIVIVofIVI_mVIVKo000000?oC4a<00?o0000
oc<c<olc<c<01_lc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co
0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c005olc<c005o`000?nc/k?o/k>cok>c/ol0
00000_nIVIT01_l0003oOgmoogmoOol0003oIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<0
1?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o0000
2?o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc
<c?o<c<c00Ko<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol0
0008olc<c003o`000?nc/k?ooooo00Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooo
oooo00?ooooo3OmVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000
ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@;o00002_moOgl00ol0003oIVIVofIVIP0;
ofIVIP03o`000?m<C4coC4a<01GoC4a<00?o0000ofIVI_mVIVH01?mVIVH00ol0003oOgmoogmoO`03
ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01onc/k<00ol0003oc<c<o`000007
ok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`000003ofIVIP05o`000?m<
C4coC4a<oda<C?l000001olc<c<00ol0003oC4a<oda<C003oda<C004o`000?mVIVKoIVIVo`0000;o
Ogmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>c
ok>c/ol000000_nIVIT01_l0003oOgmoogmoOol0003oIVIVo`0000?oC4a<00?o0000oc<c<olc<c<0
1_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc
/k?o00001oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<
C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<o`000?mVIVH00_l00002oiVIV@03o`00
0?nc/k?o000000Soc<c<00?o0000ok>c/oooool01Oooool1o`00007ooooo0Oooool002Cooooo00?o
0000ooooooooool00oooool<ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onI
VIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02Omo
Ogl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01GoC4a<00?o0000ofIVI_mVIVH01?mV
IVH00ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<02Onc
/k<00ol0003o/k>cok>c/`06ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01Ol0003oIVIV
ofIVI_mVIVKo000000CoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004
o`000?mVIVKoIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c005
olc<c003o`000?nc/k?o/k>c00;o/k>c00So0000oiVIVOnIVIWo0000ogmoOol0003oIVIVo`0000?o
C4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo0000
00;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`02?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo
00000_mVIVH01?l0003oC4a<oda<C?l00007oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmo
Ool0003oVIVIo`000?nc/k?o00002?o<c<`01?l0003o/k>cok>c/ol00005ooooo`7o00000Oooool1
ooooo`009?ooool00ol0003oooooooooo`03ooooo`_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0
003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0
003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05Om<C4`00ol0
003oIVIVofIVIP04ofIVIP03o`000?moOgooOgmo00?oOgmo00?o0000oiVIVOnIVIT00_nIVIT2o`00
01?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`05o`000?mVIVKoIVIVofIVI_l000001Om<
C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Co0000ofIVI_mVIVKo0000
0_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc
/k?o/k>co`000002oiVIV@06o`000?moOgooOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c
<`07oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03
o`000?o<c<coc<c<00Ooc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000
0_m<C4`00ol0003o<c<coc<c<`06oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003o
VIVIo`000?nc/k?o00002?o<c<`01?l0003o/k>cok>c/ol00005ooooo`7o00000Oooool1ooooo`00
9?ooool2o`0000Cooooo2_mVIVH00ol0003oOgmoogmoO`08ogmoO`;o00003?nIVIT00ol0003o/k>c
ok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI0_l0000:ogmoO`03o`000?mVIVKoIVIV00_oIVIV
00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP04ofIVIP03o`000?moOgooOgmo00;oOgmo
00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0Bok>c/`05o`000?nIVIWoVIVIoiVIVOl0
00000omoOgl01Ol0003oIVIVofIVI_mVIVKo000000GoC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0
003oC4a<oda<C003oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo00000onc
/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01_l0003oOgmo
ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01olc<c<01?l0003oC4a<oda<C?l00002
ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c00:o`000?nc
/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<0
3?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Soc<c<00Co0000
ok>c/onc/k?o00001?ooool2o`0000;ooooo000Tooooo`03o`000?oooooooooo00?ooooo2?mVIVH2
o`0000[oOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWo
VIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4co
C4a<01KoC4a<00?o0000ofIVI_mVIVH01?mVIVH00ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWo
VIVI00;oVIVI00?o0000ok>c/onc/k<04_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000CoOgmo00Co
0000ofIVI_mVIVKo00001Om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<
00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<
00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@06o`000?moOgooOgmoo`000?mVIVKo0000
0om<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOomo
Ogl00_l00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002
ogmoO`;o00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000
ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003o/k>co`000006oooo
o`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`OoIVIV00?o0000ogmoOomo
Ogl02OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnI
VIT02onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<
C4`05_m<C4`00ol0003oIVIVofIVIP04ofIVIP03o`000?moOgooOgmo00?oOgmo00?o0000oiVIVOnI
VIT00onIVIT00ol0003o/k>cok>c/`0Aok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomo
OgooOgmoo`000003ofIVIP03o`000?m<C4coC4a<00;oC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0
003oC4a<oda<C002oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl0
0003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@03o`00
0?moOgoo000000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`04o`000?m<C4coC4a<o`00
00;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00[o0000
ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c
<`0;o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k<00_l00007olc<c004
o`000?nc/k?o/k>co`0000Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?o
oooo1omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc
/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@;o00002_moOgl00ol0003oIVIVofIVIP0;ofIVIP03
o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH01?mVIVH00ol0003oOgmoogmoO`03ogmoO`03
o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<04Onc/k<00ol0003oVIVIoiVIV@02oiVIV@05
o`000?moOgooOgmoogmoOol000000omVIVH00ol0003oC4a<oda<C002oda<C003o`000?lc<c?o<c<c
00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Co0000
oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol00000
0_nIVIT00ol0003oOgmoo`000002ofIVIP05o`000?m<C4coC4a<oda<C?l000001olc<c<01Ol0003o
C4a<oda<C?m<C4co000000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<co
c<c<00Ooc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0
003o<c<coc<c<`06oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc
/k?o00002?o<c<`01?l0003o/k>cok>c/ol00006ooooo`7o00000Oooool1ooooo`009?ooool00ol0
003oooooooooo`03ooooo`GoIVIV0_l0000:ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c
/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIV
I_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C0;o00001_mVIVH00ol0003oOgmoogmoO`03ogmo
O`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<04_nc/k<01Ol0003oVIVIoiVIVOnIVIWo
000000?oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o
0000oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo
00000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0
003oOgmoogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Co0000oda<C?m<C4co0000
0_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`02_l0003o
/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c
00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00008olc<c005o`00
0?nc/k?o/k>co`000?nIVIT01_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool0
0oooool4ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>c
ok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIV
ofIVIP0:ofIVIP;o00006?m<C4`00ol0003oIVIVofIVIP05ofIVIP03o`000?moOgooOgmo00?oOgmo
00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0Bok>c/`05o`000?nIVIWoVIVIoiVIVOl0
00000omoOgl01Ol0003oIVIVofIVI_mVIVKo000000GoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0
003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`00
0003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Ko0000ok>c/onc/k?o/k>co`000?nIVIT2o`000005
ogmoOol0003oIVIVofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`06o`000?m<C4coC4a<
o`000?mVIVKo00000_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00?o
0000ok>c/ol000000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<0
1_lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Soc<c<
00Ko0000ok>c/onc/k?o0000oiVIVOl00005ooooo`7o00000Oooool1ooooo`009?ooool00ol0003o
ooooooooo`03ooooo`CoIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03
o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`09ogmoO`03
o`000?mVIVKoIVIV00[oIVIV00?o0000oda<C?m<C4`06?m<C4`00ol0003oIVIVofIVIP05ofIVIP03
o`000?moOgooOgmo00?oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0Bok>c/`05
o`000?nIVIWoVIVIoiVIVOl000000omoOgl01Ol0003oIVIVofIVI_mVIVKo000000GoC4a<00?o0000
oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Go
0000oiVIVOnIVIWoVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o
00000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000Wo<c<c00Ko0000
oda<C?m<C4co0000ofIVI_l00002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`0
1_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0
003o<c<coc<c<`06oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc
/k?o00002?o<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000Gooooo0Ol00001ooooo`7ooooo000T
ooooo`03o`000?oooooooooo00?ooooo0_mVIVH2o`0000[oOgmo00?o0000oiVIVOnIVIT02onIVIT0
0ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00[oVIVI00?o0000ogmoOomoOgl02OmoOgl0
0ol0003oIVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<01SoC4a<00?o0000ofIVI_mVIVH01OmVIVH0
0ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<04_nc/k<0
1Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Go0000ofIVI_mVIVKoIVIVo`000005oda<C003o`00
0?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`05
o`000?nIVIWoVIVIoiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c007o`000?nc/k?o/k>c
ok>c/ol0003oVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000;oC4a<00?o0000oc<c<olc<c<0
1olc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo00000_nc/k<0
0ol0003oc<c<olc<c006olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP04
o`000?m<C4coC4a<o`0000Oo<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo
0000ok>c/ol00009olc<c005o`000?nc/k?o0000oiVIVOl000001_ooool1o`00007ooooo0Oooool0
02Cooooo00?o0000ooooooooool00oooool00omVIVKo0000ogmoO`0:ogmoO`03o`000?nIVIWoVIVI
00_oVIVI00?o0000ok>c/onc/k<05_nc/k<2o`0000coVIVI00?o0000ogmoOomoOgl02?moOgl2o`00
00coIVIV00?o0000oda<C?m<C4`06?m<C4`00ol0003oIVIVofIVIP05ofIVIP03o`000?moOgooOgmo
00?oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0Bok>c/`03o`000?nIVIWoVIVI
00;oVIVI00Go0000ogmoOomoOgooOgmoo`000003ofIVIP03o`000?m<C4coC4a<00?oC4a<00?o0000
oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C002oda<C005o`000?mVIVKoIVIVofIVI_l000000_mo
Ogl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Co0000ok>c/onc/k?o
00000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000Wo<c<c00Ko0000
oda<C?m<C4co0000ofIVI_l00002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`0
1_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0
003o<c<coc<c<`06oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc
/k?o00002Oo<c<`01Ol0003o/k>co`000?l0003oOgmo00Kooooo0Ol00001ooooo`7ooooo000Toooo
o`03o`000?oooooooooo00?ooooo00?oIVIVo`000?moOgl02OmoOgl00ol0003oVIVIoiVIV@0;oiVI
V@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`09ogmo
O`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP06ofIV
IP03o`000?moOgooOgmo00?oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0Bok>c
/`03o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`000003ofIVIP03o`000?m<C4co
C4a<00?oC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C002oda<C005o`000?mVIVKo
IVIVofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Ooc<c<
00Co0000ok>c/onc/k?o00000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP04o`000?m<C4coC4a<
o`0000Wo<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`03o`000?nIVIWo000000;o/k>c
00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000ofIV
I_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmo
Ool0003oVIVIo`000?nc/k?o00002Oo<c<`01Ol0003o/k>co`000?l0003oOgmo00Kooooo0Ol00001
ooooo`7ooooo000Tooooo`;o00001?ooool00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI
00[oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo
00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV
00KoIVIV00?o0000ogmoOomoOgl00omoOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c
01?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000
oda<C?m<C4`00_m<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Co0000
ofIVI_mVIVKo00000omoOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<
00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Co0000oda<
C?m<C4co00002?lc<c<01?l0003oC4a<oda<C?m<C4`2o`0000?oOgmo00?o0000oiVIVOl000000_nc
/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`0000;oVIVI0_l00002ofIVIP03o`00
0?m<C4co000000Wo<c<c00?o0000oda<C?m<C4`00_l00002ogmoO`05o`000?nIVIWo0000ok>c/ol0
00002?o<c<`00ol0003o/k>cok>c/`02o`000003ogmoOooooooooooo00?ooooo0_l00002ooooo`00
9?ooool00ol0003oooooooooo`03ooooo`_oOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>c
ok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIV
ofIVIP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH01omVIVH00ol0003oOgmo
ogmoO`03ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<04_nc/k<00ol0003oVIVI
oiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol000000omVIVH00ol0003oC4a<oda<C003oda<C003
o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo0000
00?oOgmo00Co0000oiVIVOnIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o
/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000Wo
<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000
olc<c?o<c<`01oo<c<`00ol0003o/k>co`000002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<
C4`00ol0003o<c<coc<c<`06oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVI
o`000?nc/k?o00002Oo<c<`01ol0003o/k>co`000?nIVIWo0000ogmoOol000001Oooool1o`00007o
oooo0Oooool002Cooooo00?o0000ooooooooool00oooool9ogmoO`;o00003OnIVIT00ol0003o/k>c
ok>c/`0Fok>c/`03o`000?nIVIWoVIVI00[oVIVI0_l0000:ogmoO`03o`000?mVIVKoIVIV00_oIVIV
00?o0000oda<C?m<C4`05om<C4`2o`0000SoIVIV00?o0000ogmoOomoOgl00omoOgl00ol0003oVIVI
oiVIV@03oiVIV@03o`000?nc/k?o/k>c01?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`05
o`000?mVIVKoIVIVofIVI_l000001Om<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<
00;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o
0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo
00000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`07o`000?m<C4coC4a<oda<C?l0003oIVIVo`00
0002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`00ol0003o/k>co`00
0002oiVIV@07o`000?moOgoo0000ofIVI_l0003oC4a<o`000009oc<c<`0<o`000?m<C4coC4a<o`00
0?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00002Oo<c<`01ol0003o/k>co`000?nIVIWo0000
ogmoOol000001Oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool8ogmo
O`03o`000?nIVIWoVIVI00coVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVI
V@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Goda<
C003o`000?mVIVKoIVIV00SoIVIV00?o0000ogmoOomoOgl00omoOgl00ol0003oVIVIoiVIV@03oiVI
V@03o`000?nc/k?o/k>c01?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`03o`000?mVIVKo
IVIV00;oIVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4co
C4a<00;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c
00?o0000olc<c?o<c<`01_o<c<`01ol0003o/k>cok>c/onc/k?o0000oiVIVOl000000omoOgl01?l0
003oIVIVofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mV
IVH01_l0003oOgmoogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01oo<c<`01Ol0003o
/k>co`000?nIVIWo000000;oOgmo00Go0000ofIVI_l0003oC4a<o`000009oc<c<`0<o`000?m<C4co
C4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00002Oo<c<`01ol0003o/k>co`000?nI
VIWo0000ogmoOol000001Oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00ooo
ool7ogmoO`03o`000?nIVIWoVIVI00_oVIVI0_l0000Hok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o
0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o
0000ofIVI_mVIVH02?mVIVH00ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o
0000ok>c/onc/k<04onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Go0000ofIVI_mVIVKo
IVIVo`000005oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0003o
IVIVofIVI_mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c005
olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP05o`00
0?m<C4coC4a<oda<C?l000001olc<c<01ol0003oC4a<oda<C?m<C4co0000ofIVI_l000000_moOgl0
0ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00?o0000ok>c/ol000000_nIVIT0
1Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<03?l0003oC4a<oda<
C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Woc<c<00Oo0000ok>c/ol0003oVIVI
o`000?moOgoo000000Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo
1_moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c0_l0000<oiVIV@;o0000
2OmoOgl2o`0000goIVIV00?o0000oda<C?m<C4`05om<C4`2o`0000WoIVIV00?o0000ogmoOomoOgl0
0omoOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c01;o/k>c00?o0000oiVIVOnIVIT0
0_nIVIT01Ol0003oOgmoogmoOomoOgoo000000?oIVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o
<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01Ol0
003oVIVIoiVIVOnIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc
/k?o000000;oVIVI00Ko0000ogmoOomoOgoo0000ofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko
<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00?o0000oiVIVOl000000_nc/k<0
0ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Go0000ogmoOol0003oIVIV
o`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmo
o`000?nIVIWo0000ok>c/ol00009olc<c007o`000?nc/k?o0000oiVIVOl0003oOgmoo`000006oooo
o`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`GoOgmo00?o0000oiVIVOnI
VIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomo
Ogl01omoOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mV
IVH02?mVIVH00ol0003oOgmoogmoO`04ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc
/k<04onc/k<00ol0003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol000000_mVIVH00ol0
003oC4a<oda<C004oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0
003oIVIVofIVI_mVIVKo000000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000003ok>c/`03o`000?o<
c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@06o`000?moOgooOgmoo`000?mV
IVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`07o`000?m<C4coC4a<oda<C?l0003oIVIVo`00
0002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c
/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0<
o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00002Oo<c<`01ol0003o
/k>co`000?nIVIWo0000ogmoOol000001_ooool1o`00007ooooo0Oooool002Cooooo00?o0000oooo
ooooool00oooool4ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0
003oVIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo00OoOgmo00?o0000ofIVI_mVIVH03?mVIVH00ol0
003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00SoIVIV00?o0000ogmoOomoOgl01?moOgl00ol0
003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c01;o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0
003oOgmoogmoOomoOgoo000000?oIVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`04
oc<c<`03o`000?m<C4coC4a<00?oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01Ol0003oVIVIoiVI
VOnIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;o
VIVI00Ko0000ogmoOomoOgoo0000ofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Oo0000
oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo00000_nc/k<00ol0003o
c<c<olc<c006olc<c003o`000?nc/k?o000000;oVIVI00Go0000ogmoOol0003oIVIVo`000003oda<
C003o`000?lc<c?o<c<c00Go<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo
00000_nc/k<00ol0003oc<c<olc<c006olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mV
IVKo000000Gooooo0Ol00001ooooo`7ooooo000Iooooo`Go00001_ooool00ol0003oooooooooo`03
ooooo`?oOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`;o00003OnIVIT0
0ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`2
o`0000WoIVIV00?o0000ogmoOomoOgl01?moOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o
/k>c01;o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000?oIVIV00?o
0000oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Go
0000ofIVI_mVIVKoIVIVo`000002ogmoO`03o`000?nIVIWoVIVI00;o00000onc/k<00ol0003oc<c<
olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT00ol0003oOgmoo`000002ofIVIP05
o`000?m<C4coC4a<oda<C?l000002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo
000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@05o`00
0?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0:o`000?m<C4coC4a<o`00
0?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02Ol0003o/k>c
o`000?nIVIWo0000ogmoOol0003oIVIVo`000005ooooo`7o00000Oooool1ooooo`006Oooool01OnH
V9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool00oooool2ogmoO`03o`000?nIVIWo
VIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0<oiVIV@03o`000?moOgoo
Ogmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKo
IVIV00SoIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o
/k>c01;o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000?oIVIV00?o
0000oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Go
0000ofIVI_mVIVKoIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<
c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`06o`000?nIVIWoVIVIo`000?moOgoo00000_mVIVH0
1Ol0003oC4a<oda<C?m<C4co000000So<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmo
o`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT2o`00
00;oIVIV00Co0000oda<C?m<C4co00002?lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo
0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Wo0000ok>c/ol0003oVIVIo`000?mo
Ogoo0000ofIVI_l000001Oooool1o`00007ooooo0Oooool0017ooooo1_l00003ooooo`03oiRHV?lQ
8B7ok^k^00Oooooo0ol00003ooooo`03ogmoOol0003oVIVI00coVIVI00?o0000ok>c/onc/k<05_nc
/k<00ol0003oVIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omV
IVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00WoIVIV00?o0000ogmoOomoOgl01?mo
Ogl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c01;o/k>c00?o0000oiVIVOnIVIT00_nI
VIT01Ol0003oOgmoogmoOomoOgoo000000?oIVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o<c<c
oc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`04
o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o
000000;oVIVI00?o0000ogmoOol000000omVIVH01?l0003oC4a<oda<C?l00008oc<c<`04o`000?m<
C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00009olc<c003
o`000?nc/k?o000000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c
00Ko<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003o
c<c<olc<c006olc<c003o`000?nc/k?o/k>c00;o000000CoOgmoo`000?mVIVKo00001?ooool3o`00
00;ooooo000Kooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool00oooool00ol0003o
VIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003o
OgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`2o`0000_o
IVIV00?o0000ogmoOomoOgl01?moOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c01;o
/k>c00?o0000oiVIVOnIVIT00_nIVIT00ol0003oOgmoogmoO`02ogmoO`05o`000?mVIVKoIVIVofIV
I_l000001Om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Co0000ofIV
I_mVIVKo00000omoOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Goc<c<00Go
0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Go0000oda<C?m<
C4coC4a<o`000008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT0
0ol0003o/k>co`00000:olc<c003o`000?nc/k?o000000;oVIVI00Oo0000ogmoOol0003oIVIVo`00
0?m<C4co000000Wo<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc
/k<00ol0003oc<c<olc<c006olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000
00Kooooo0Ol00001ooooo`7ooooo000Looooo`03ogMgMomVIVKooooo00Gooooo00?o0000oooooooo
ool00oooool=oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT2o`0000[o
Ogmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00[o
IVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c01;o
/k>c00?o0000oiVIVOnIVIT00_nIVIT00ol0003oOgmoogmoO`02ogmoO`04o`000?mVIVKoIVIVo`00
00KoC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C003oda<C004o`000?mVIVKoIVIV
o`0000?oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c005olc<c005o`000?nc
/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<
C?l000002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00?o0000
ok>c/ol000002_o<c<`01Ol0003o/k>co`000?nIVIWo000000;oOgmo00Go0000ofIVI_l0003oC4a<
o`000009oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o0000
2Oo<c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000006ooooo`7o00000Oooool1
ooooo`007Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo3?nIVIT00ol0
003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0
003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0
003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<04_nc/k<00ol0
003oVIVIoiVIV@02oiVIV@03o`000?moOgooOgmo00;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000006
oda<C003o`000?lc<c?o<c<c00?o<c<c00?o0000oda<C?m<C4`00om<C4`01?l0003oIVIVofIVI_l0
0003ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>c
ok>c/`02ok>c/`03o`000?nIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o
<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0
003o/k>cok>c/ol00009olc<c003o`000?nc/k?o000000;oVIVI00Go0000ogmoOol0003oIVIVo`00
0002oda<C003o`000?lc<c?o<c<c00Ko<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`00
0?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c00:o`000?nc/k?o0000oiVIVOl0003oOgmo
o`000?mVIVKo0000oda<C0Kooooo0Ol00001ooooo`7ooooo000Iooooo`05o`000?nj^[[ooooooiRH
V?l@41001_ooool00ol0003oooooooooo`03ooooo`_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0
003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0
003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00[oIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0
003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0
003oOgmoogmoOomoOgoo000000?oIVIV00?o0000oda<C?m<C4`01?m<C4`00ol0003o<c<coc<c<`04
oc<c<`03o`000?m<C4coC4a<00;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`05o`000?nI
VIWoVIVIoiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol0
00000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000Wo<c<c00Co0000
oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<
00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c
<olc<c<01_lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`00
00Woc<c<00[o0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<1_ooool1o`00007o
oooo0Oooool001Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo00?o
oooo2_nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI0_l0000:ogmoO`03
o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0:ofIVIP03
o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`0Cok>c/`03
o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`000003ofIVIP03o`000?m<C4coC4a<
00CoC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C002oda<C005o`000?mVIVKoIVIV
ofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go
0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Co0000oda<C?m<
C4co00002Olc<c<01?l0003oC4a<oda<C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl000000onc
/k<00ol0003oc<c<olc<c006olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl01Ol0003o
IVIVo`000?m<C4co000000Wo<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo
0000ok>c/ol00009olc<c00;o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l0
00001Oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool9oiVIV@03o`00
0?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`00
0?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`2o`0000coIVIV00?o0000ogmoOomoOgl0
1OmoOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT0
0_nIVIT01Ol0003oOgmoogmoOomoOgoo000000?oIVIV00?o0000oda<C?m<C4`01?m<C4`00ol0003o
<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmo
O`05o`000?nIVIWoVIVIoiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o
/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000Wo
<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVIV@05o`000?nc/k?o/k>c
ok>c/ol000002?o<c<`01Ol0003o/k>co`000?nIVIWo000000;oOgmo00?o0000ofIVI_l000000_m<
C4`00ol0003o<c<coc<c<`07oc<c<`0;o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000
ok>c/ol000002Oo<c<`00ol0003o/k>co`000002oiVIV@;o000000GoIVIVo`000?m<C4coC4a<o`00
0005ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`SoVIVI00?o0000
ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000
ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000
ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o0000
oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000CoIVIV00?o0000oda<C?m<C4`00om<
C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Go0000ofIVI_mVIVKoIVIV
o`000002ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o
/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01?l0003oC4a<oda<C?l0
0009oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>c
ok>c/ol00008olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl00ol0003oIVIVo`000002
oda<C003o`000?lc<c?o<c<c00Ko<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nI
VIWo0000ok>c/ol00009olc<c00;o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<
C?l000001_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool7oiVIV@03
o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT2o`0000[oOgmo00?o0000ofIVI_mV
IVH02omVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00[oIVIV00?o0000ogmoOomo
Ogl01OmoOgl00ol0003oVIVIoiVIV@05oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnI
VIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000CoIVIV00?o0000oda<C?m<C4`00om<C4`00ol0
003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002
ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c
/onc/k?o000000;oVIVI00?o0000ogmoOol000000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000Wo
<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000;o/k>c00?o
0000olc<c?o<c<`01_o<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00?o0000ofIVI_l0
00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0
003oVIVIo`000?nc/k?o00002Oo<c<`02ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`00
0?m<C4co000000Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo1_nI
VIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02Omo
Ogl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<0_l0000<ofIVIP03o`000?mo
OgooOgmo00GoOgmo00?o0000oiVIVOnIVIT01OnIVIT00ol0003o/k>cok>c/`0Cok>c/`03o`000?nI
VIWoVIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`000004ofIVIP03o`000?m<C4coC4a<00?oC4a<
00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C003oda<C005o`000?mVIVKoIVIVofIVI_l0
00000_moOgl01?l0003oVIVIoiVIVOl00005ok>c/`03o`000?o<c<coc<c<00Goc<c<00Go0000ok>c
/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<
o`000008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o
/k>cok>c/ol00008olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl00ol0003oIVIVo`00
0002oda<C003o`000?lc<c?o<c<c00Ko<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`00
0?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c003o`000?nc/k?o/k>c00;o000000OoOgmo
o`000?mVIVKoIVIVo`000?m<C4co000000Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oo
oooooooo00?ooooo1OnIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o
0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0:ofIVIP;o00006?m<C4`00ol0003oIVIVofIV
IP0;ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT01OnIVIT00ol0003o/k>cok>c
/`0Cok>c/`03o`000?nIVIWoVIVI00;oVIVI00?o0000ogmoOomoOgl00_moOgl01Ol0003oIVIVofIV
I_mVIVKo000000KoC4a<00?o0000oc<c<olc<c<00olc<c<2o`0000CoC4a<00Go0000ofIVI_mVIVKo
IVIVo`000003ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0
003o/k>cok>c/`02ok>c/`06o`000?nIVIWoVIVIo`000?moOgoo00000_mVIVH01?l0003oC4a<oda<
C?m<C4`2o`0000Oo<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00?o0000oiVI
VOl000000onc/k<00ol0003oc<c<olc<c006olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_mo
Ogl01Ol0003oIVIVo`000?m<C4co000000Wo<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmo
o`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c009o`000?nc/k?o0000oiVIVOl0003o
Ogmoo`000?mVIVKo000000;oC4a<00?o0000ooooooooool01?ooool1o`00007ooooo0Oooool002Co
oooo0_l00004ooooo`CoVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0:oiVIV@03
o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<oda<C00Goda<C003
o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl01_moOgl00ol0003oVIVIoiVIV@05oiVIV@03
o`000?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT00_nIVIT00ol0003oOgmoogmoO`02ogmoO`05
o`000?mVIVKoIVIVofIVI_l000001_m<C4`00ol0003o<c<coc<c<`03oc<c<`03o`000?m<C4coC4a<
00?oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc
/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Ko0000oiVIVOnIVIWo0000
ogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01ol0003oC4a<oda<C?m<C4co
0000ofIVI_l000000_moOgl00ol0003oVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Ko
0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`05o`000?mVIVKo0000oda<C?l000002Olc<c<02_l0
003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ko
c<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003ooooooooo
o`03ooooo`;o00000_ooool002Cooooo00?o0000ooooooooool00oooool3oiVIV@03o`000?nc/k?o
/k>c01Oo/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKo
IVIV00[oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgoo
Ogmo00KoOgmo00?o0000oiVIVOnIVIT01OnIVIT00ol0003o/k>cok>c/`0Cok>c/`03o`000?nIVIWo
VIVI00;oVIVI00?o0000ogmoOomoOgl00_moOgl01Ol0003oIVIVofIVI_mVIVKo000000KoC4a<00?o
0000oc<c<olc<c<00olc<c<00ol0003oC4a<oda<C003oda<C003o`000?mVIVKoIVIV00;oIVIV00Co
0000ogmoOomoOgoo00000_nIVIT00ol0003o/k>cok>c/`02ok>c/`03o`000?o<c<coc<c<00Goc<c<
00?o0000ok>c/onc/k<00_nc/k<01_l0003oVIVIoiVIVOl0003oOgmoo`0000;oIVIV00Go0000oda<
C?m<C4coC4a<o`000008oc<c<`07o`000?m<C4coC4a<oda<C?l0003oIVIVo`000002ogmoO`03o`00
0?nIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@05
o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0:o`000?m<C4coC4a<
o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01oo<c<`2o`000004
oiVIVOl0003oOgmoogmoO`;o00000_m<C4`00ol0003o<c<cooooo`05ooooo`7o00000Oooool1oooo
o`009?ooool00ol0003oooooooooo`03ooooo`;oVIVI00?o0000ok>c/onc/k<05_nc/k<2o`0000co
VIVI00?o0000ogmoOomoOgl02?moOgl2o`0000coIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003o
IVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00KoOgmo00?o0000oiVIVOnIVIT01OnIVIT00ol0003o
/k>cok>c/`0Cok>c/`03o`000?nIVIWoVIVI00?oVIVI00Go0000ogmoOomoOgooOgmoo`000004ofIV
IP03o`000?m<C4coC4a<00CoC4a<00?o0000oc<c<olc<c<00olc<c<00ol0003oC4a<oda<C003oda<
C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Co/k>c00?o
0000olc<c?o<c<`01Oo<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo
00000_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`07o`000?m<C4coC4a<oda<C?l0003oIVIVo`00
0002ogmoO`03o`000?nIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01_l0003o/k>cok>c
/ol0003oVIVIo`0000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0:
o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`0
1_o<c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o
oooo00Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo00?oVIVIo`00
0?nc/k<06?nc/k<00ol0003oVIVIoiVIV@0:oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIV
I_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmo
OomoOgl01omoOgl00ol0003oVIVIoiVIV@05oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o0000oiVI
VOnIVIT00onIVIT01Ol0003oOgmoogmoOomoOgoo000000CoIVIV00?o0000oda<C?m<C4`01?m<C4`0
0ol0003o<c<coc<c<`03oc<c<`03o`000?m<C4coC4a<00?oC4a<00Go0000ofIVI_mVIVKoIVIVo`00
0002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0003oc<c<olc<c005olc<c005o`00
0?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP04o`000?m<C4coC4a<
o`0000Wo<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00?o0000oiVIVOl00000
0_nc/k<00ol0003oc<c<olc<c007olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl00ol0
003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00[o0000oda<C?m<C4co0000ofIVI_l0
003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c009o`000?nc/k?o0000oiVI
VOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<oooool01Oooool1o`00007ooooo0Ooo
ool002Cooooo00?o0000ooooooooool00oooool00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWo
VIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4co
C4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`07ogmoO`03o`000?nIVIWo
VIVI00GoVIVI00?o0000ok>c/onc/k<04onc/k<00ol0003oVIVIoiVIV@03oiVIV@05o`000?moOgoo
OgmoogmoOol000001?mVIVH00ol0003oC4a<oda<C004oda<C003o`000?lc<c?o<c<c00?o<c<c00?o
0000oda<C?m<C4`00om<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Co0000oiVIVOnIVIWo
00001?nc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT00ol0
003oOgmoo`000002ofIVIP05o`000?m<C4coC4a<oda<C?l000002Olc<c<01?l0003oC4a<oda<C?l0
0002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`02_l0003o/k>c
ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c00co
0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00009olc<c00;o`000?nc
/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l000000_lc<c<6ooooo`7o00000Oooool1
ooooo`009?ooool00ol0003oooooooooo`03oooooaWo/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0
003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0
003oIVIVofIVIP0:ofIVIP03o`000?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0
003o/k>cok>c/`0Bok>c/`03o`000?nIVIWoVIVI00CoVIVI00Go0000ogmoOomoOgooOgmoo`000004
ofIVIP03o`000?m<C4coC4a<00?oC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C003
oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000?o/k>c
00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomo
Ogoo00000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Oo0000oda<C?m<C4coC4a<o`00
0?mVIVKo000000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c006o`00
0?nc/k?o/k>co`000?nIVIWo00000_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c
00Ko<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003o
c<c<olc<c006olc<c003o`000?nc/k?o000000;oVIVI0_l000001OmVIVKo0000oda<C?m<C4co0000
00;o<c<c1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00ooooolHok>c/`03
o`000?nIVIWoVIVI00[oVIVI0_l0000:ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<
C4`05_m<C4`2o`0000goIVIV00?o0000ogmoOomoOgl01_moOgl00ol0003oVIVIoiVIV@06oiVIV@03
o`000?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT00onIVIT01Ol0003oOgmoogmoOomoOgoo0000
00CoIVIV00?o0000oda<C?m<C4`01?m<C4`00ol0003o<c<coc<c<`03oc<c<`03o`000?m<C4coC4a<
00CoC4a<00Co0000ofIVI_mVIVKo00000omoOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<
c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;o
IVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Ko0000
ogmoOomoOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00So0000ok>c/onc/k?o
0000oiVIVOl0003oOgmoo`0000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<03?l0003oC4a<oda<
C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Woc<c<00Wo0000ok>c/ol0003oVIVI
o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06ooooo`7o00000Oooool1oooo
o`009?ooool00ol0003oooooooooo`03oooooaOo/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003o
OgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003o
IVIVofIVIP0<ofIVIP03o`000?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o
/k>cok>c/`0Cok>c/`03o`000?nIVIWoVIVI00?oVIVI00Go0000ogmoOomoOgooOgmoo`000004ofIV
IP03o`000?m<C4coC4a<00CoC4a<00?o0000oc<c<olc<c<00olc<c<00ol0003oC4a<oda<C004oda<
C004o`000?mVIVKoIVIVo`0000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<
c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;o
IVIV00Co0000oda<C?m<C4co00002Olc<c<01?l0003oC4a<oda<C?l00002ofIVIP06o`000?moOgoo
Ogmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c007olc<c008o`000?nc/k?o/k>co`000?nI
VIWo0000ogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00co0000oda<C?m<C4co0000
ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00009olc<c009o`000?nc/k?o0000oiVIVOl0003o
Ogmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_ooool1o`00007ooooo0Oooool002Co
oooo00?o0000ooooooooool00ooooolFok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomo
Ogl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mV
IVH02omVIVH00ol0003oOgmoogmoO`07ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc
/k<04onc/k<00ol0003oVIVIoiVIV@03oiVIV@03o`000?moOgooOgmo00;oOgmo00Go0000ofIVI_mV
IVKoIVIVo`000006oda<C003o`000?lc<c?o<c<c00?o<c<c00?o0000oda<C?m<C4`01?m<C4`01Ol0
003oIVIVofIVI_mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<
c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP05
o`000?m<C4coC4a<oda<C?l000002?lc<c<01ol0003oC4a<oda<C?m<C4co0000ofIVI_l000000_mo
Ogl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Ko0000ok>c/onc/k?o0000
oiVIVOl00002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02_l0003o
C4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<
00?o0000ok>c/onc/k<00_l000001omoOgoo0000ofIVI_mVIVKo0000oda<C?l000000olc<c<6oooo
o`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03oooooaCo/k>c0_l0000<oiVIV@;o
00002OmoOgl2o`0000goIVIV00?o0000oda<C?m<C4`05_m<C4`2o`0000goIVIV00?o0000ogmoOomo
Ogl01omoOgl00ol0003oVIVIoiVIV@05oiVIV@;o00005Onc/k<00ol0003oVIVIoiVIV@03oiVIV@03
o`000?moOgooOgmo00;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000007oda<C003o`000?lc<c?o<c<c
00?o<c<c00?o0000oda<C?m<C4`00om<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Go0000
oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc
/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000;oC4a<00?o0000oc<c<olc
<c<01olc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c
/onc/k?o00002Oo<c<`02?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo00000_mVIVH00ol0003o
C4a<o`000009oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c
00?o0000olc<c?o<c<`01_o<c<`02ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<
C4co000000Co<c<c1_ooool1o`00007ooooo0Oooool002Cooooo0_l00004oooooa?o/k>c00?o0000
oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`07ogmoO`03o`000?mVIVKoIVIV00coIVIV00?o0000
oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?moOgooOgmo00OoOgmo00?o0000
oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`0Dok>c/`03o`000?nIVIWoVIVI00?oVIVI00?o0000
ogmoOomoOgl00_moOgl01Ol0003oIVIVofIVI_mVIVKo000000OoC4a<00?o0000oc<c<olc<c<00_lc
<c<00ol0003oC4a<oda<C004oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01Ol0003oVIVI
oiVIVOnIVIWo000000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04
o`000?nIVIWoVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo00000_m<C4`00ol0003o<c<coc<c<`07
oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c
/ol00009olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP03o`000?m<C4co
000000Wo<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0
003oc<c<olc<c005olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<
C4co00001?lc<c<5ooooo`;o00000_ooool002Cooooo00?o0000ooooooooool00ooooolBok>c/`03
o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl01omoOgl00ol0003oIVIVofIVIP0<ofIVIP03
o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmoO`07ogmoO`03
o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc/k<05?nc/k<00ol0003oVIVIoiVIV@03oiVIV@03
o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C004oda<C003
o`000?lc<c?o<c<c00;o<c<c00?o0000oda<C?m<C4`01?m<C4`01Ol0003oIVIVofIVI_mVIVKo0000
00;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000
ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Co0000oda<C?m<C4co
00002Olc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c
/onc/k?o00002Oo<c<`02?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo00000_mVIVH01?l0003o
C4a<oda<C?l00008oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o
/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>co`000?nIVIWo000000;oOgmo0_l00002oda<
C003o`000?lc<c?o<c<c00;o<c<c1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000oooooooo
ool00ooooolAok>c/`;o00003OnIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_o
IVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP;o00002OmoOgl00ol0003o
VIVIoiVIV@07oiVIV@03o`000?nc/k?o/k>c01Co/k>c00?o0000oiVIVOnIVIT00_nIVIT00ol0003o
OgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01?m<C4`00ol0003o
<c<coc<c<`03oc<c<`03o`000?m<C4coC4a<00CoC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmo
O`05o`000?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0003oc<c<olc<c005olc<c005o`000?nc/k?o
/k>cok>c/ol000000onIVIT01?l0003oOgmoogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000Wo
<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>c
o`0000Soc<c<00Wo0000ok>c/onc/k?o/k>co`000?nIVIWo0000ogmoOol000000_mVIVH01?l0003o
C4a<oda<C?l00008oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o
/k>c00?o0000olc<c?o<c<`01_o<c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`00
0002oda<C003o`000?lc<c?o<c<c00;o<c<c1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000
ooooooooool00oooool@ok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl02?moOgl0
0ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH0
0ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00OoVIVI00?o0000ok>c/onc/k<05Onc/k<0
0ol0003oVIVIoiVIV@02oiVIV@03o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH00_mVIVH0
0ol0003oC4a<oda<C004oda<C003o`000?lc<c?o<c<c00?o<c<c00?o0000oda<C?m<C4`01?m<C4`0
1?l0003oIVIVofIVI_l00003ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000onc/k<00ol0003oc<c<
olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000onIVIT00ol0003oOgmoo`000002ofIVIP05
o`000?m<C4coC4a<oda<C?l000002Olc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo
000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`02Ol0003o/k>cok>c/onc/k?o0000oiVIVOl0
003oOgmoo`000002ofIVIP03o`000?m<C4co000000Wo<c<c00[o0000oda<C?m<C4co0000ofIVI_l0
003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c009o`000?nc/k?o0000oiVI
VOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<00_lc<c<6ooooo`7o00000Ooo
ool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`oo/k>c00?o0000oiVIVOnIVIT03?nIVIT0
0ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`0
0ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT01_nIVIT0
0ol0003o/k>cok>c/`0Eok>c/`03o`000?nIVIWoVIVI00;oVIVI00?o0000ogmoOomoOgl00_moOgl0
0ol0003oIVIVofIVIP02ofIVIP03o`000?m<C4coC4a<00CoC4a<00?o0000oc<c<olc<c<00olc<c<0
0ol0003oC4a<oda<C004oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01Ol0003oVIVIoiVI
VOnIVIWo000000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`00
0?nIVIWoVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo00000_m<C4`00ol0003o<c<coc<c<`07oc<c
<`04o`000?m<C4coC4a<o`0000;oIVIV00Ko0000ogmoOomoOgoo0000oiVIVOl00002ok>c/`03o`00
0?o<c<coc<c<00Koc<c<00Wo0000ok>c/onc/k?o/k>co`000?nIVIWo0000ogmoOol000000_mVIVH0
1?l0003oC4a<oda<C?l00009oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000
00;o/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003o/k>co`000002oiVIV@;o000000GoIVIVo`00
0?m<C4coC4a<o`000005oc<c<`Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo
00?ooooo3_nc/k<00ol0003oVIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIV
I_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmo
OomoOgl02OmoOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c01Co/k>c0_l00004oiVI
V@03o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C005oda<
C003o`000?lc<c?o<c<c00;o<c<c00?o0000oda<C?m<C4`01?m<C4`01Ol0003oIVIVofIVI_mVIVKo
000000?oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc
/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<
C?l000002?lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o0000ogmoOol000000_nIVIT0
1?l0003o/k>cok>c/ol00008olc<c009o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000?moOgoo0000
00;oIVIV00?o0000oda<C?l000002Olc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000
oiVIVOl0003o/k>co`0000Woc<c<00Co0000ok>c/ol0003oVIVI0ol000001OmVIVKo0000oda<C?m<
C4co000000Go<c<c1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool=
ok>c/`03o`000?nIVIWoVIVI00_oVIVI0_l0000:ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000
oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000
oiVIVOnIVIT01onIVIT00ol0003o/k>cok>c/`0Dok>c/`03o`000?nIVIWoVIVI00?oVIVI00?o0000
ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP02ofIVIP03o`000?m<C4coC4a<00GoC4a<00?o0000
oc<c<olc<c<00_lc<c<00ol0003oC4a<oda<C004oda<C005o`000?mVIVKoIVIVofIVI_l000000omo
Ogl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o
/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008
oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc
/k?o/k>co`0000Soc<c<00Wo0000ok>c/onc/k?o/k>co`000?nIVIWo0000ogmoOol000000_mVIVH0
0ol0003oC4a<o`000009oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`00
0?nc/k?o00002Oo<c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003
o`000?lc<c?o<c<c00?o<c<c1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool0
0oooool<ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIV
ofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmo
ogmoO`09ogmoO`03o`000?nIVIWoVIVI00OoVIVI00?o0000ok>c/onc/k<05?nc/k<00ol0003oVIVI
oiVIV@03oiVIV@03o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<
oda<C004oda<C003o`000?lc<c?o<c<c00;o<c<c00?o0000oda<C?m<C4`01?m<C4`01Ol0003oIVIV
ofIVI_mVIVKo000000?oOgmo00Go0000oiVIVOnIVIWoVIVIo`000003ok>c/`03o`000?o<c<coc<c<
00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Go
0000oda<C?m<C4coC4a<o`000008oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH00ol0003o
Ogmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Oo0000ok>c/onc/k?o/k>co`000?nI
VIWo000000;oOgmo00Go0000ofIVI_l0003oC4a<o`000009oc<c<`0:o`000?m<C4coC4a<o`000?mV
IVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01ol0003o/k>co`00
0?nIVIWo0000ogmoOol000000_mVIVH00ol0003oC4a<o`000006oc<c<`Kooooo0Ol00001ooooo`7o
oooo000Tooooo`03o`000?oooooooooo00?ooooo2onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`00
0?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`00
0?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@07oiVIV@03o`00
0?nc/k?o/k>c01Go/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`02ogmoO`03o`00
0?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01Om<C4`01Ol0003o<c<coc<c<olc<c?o000000Oo
C4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc/k<0
0ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_mo
Ogl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4co
C4a<o`000002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01?l0
003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV00?o0000oda<C?l000002Olc<c<0
2_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<
00Koc<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<c
oc<c<`04oc<c<`Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo2_nc
/k<00ol0003oVIVIoiVIV@0;oiVIV@;o00002_moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<
C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nI
VIWoVIVI00SoVIVI00?o0000ok>c/onc/k<05?nc/k<00ol0003oVIVIoiVIV@03oiVIV@03o`000?mo
OgooOgmo00?oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C004oda<C003o`000?lc
<c?o<c<c00;o<c<c00?o0000oda<C?m<C4`01Om<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo
00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc
/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000
oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o0000ogmoOol000000_nI
VIT01?l0003o/k>cok>c/ol00008olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol0
00000_mVIVH00ol0003oC4a<o`000009oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0
003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02Ol0003o/k>co`000?nIVIWo0000ogmo
Ool0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Co<c<c1_ooool1o`00007ooooo0Oooool0
02Cooooo0_l00004ooooo`Wo/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmo
O`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`2o`0000coIVIV00?o0000ogmo
OomoOgl02?moOgl2o`0000[oVIVI00?o0000ok>c/onc/k<05?nc/k<00ol0003oVIVIoiVIV@03oiVI
V@03o`000?moOgooOgmo00?oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C005oda<
C005o`000?lc<c?o<c<coc<c<ol000001om<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Go
0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<0
0_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c
<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o0000ogmoOol000000_nIVIT0
1?l0003o/k>cok>c/ol00009olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIV
IP03o`000?m<C4co000000Wo<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo
00000_nc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o0000oiVIVOl000000_moOgl2o`00
00;oC4a<00?o0000oc<c<olc<c<01Olc<c<5ooooo`;o00000_ooool002Cooooo00?o0000oooooooo
ool00oooool8ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003o
IVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003o
OgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00WoVIVI00?o0000ok>c/onc/k<05?nc/k<00ol0003o
VIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003o
C4a<oda<C005oda<C003o`000?lc<c?o<c<c00;o<c<c00?o0000oda<C?m<C4`01?m<C4`01Ol0003o
IVIVofIVI_mVIVKo000000?oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c006
olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIV
I_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo0000
00;oOgmo00Co0000oiVIVOnIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o
/k>co`0000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c
00[o0000oda<C?l0003o0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<
c006olc<c006o`000?nc/k?o0000oiVIVOl0003oOgmo0ol00002oda<C003o`000?lc<c?o<c<c00Go
<c<c1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool7ok>c/`03o`00
0?nIVIWoVIVI00_oVIVI0_l0000:ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`0
5om<C4`00ol0003oIVIVofIVIP0:ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT0
2?nIVIT00ol0003o/k>cok>c/`0Eok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl0
0_moOgl00ol0003oIVIVofIVIP02ofIVIP03o`000?m<C4coC4a<00GoC4a<00Go0000oc<c<olc<c?o
<c<co`000007oda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01?l0003oVIVIoiVIVOl00004
ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl0
0002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01ol0003oC4a<
oda<C?m<C4co0000ofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00002ok>c/`03o`000?o<c<co
c<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<
00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP05o`000?moOgoo0000oiVI
VOl000000_nc/k<00ol0003oc<c<olc<c006olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`00
0?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01Olc<c<6ooooo`7o00000Oooool1ooooo`009?oo
ool00ol0003oooooooooo`03ooooo`Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmo
O`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`2o`0000coIVIV00?o
0000ogmoOomoOgl02?moOgl2o`0000_oVIVI00?o0000ok>c/onc/k<05?nc/k<00ol0003oVIVIoiVI
V@04oiVIV@03o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<
C005oda<C003o`000?lc<c?o<c<c00;o<c<c00?o0000oda<C?m<C4`01?m<C4`01Ol0003oIVIVofIV
I_mVIVKo000000?oOgmo00Go0000oiVIVOnIVIWoVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Ko
c<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIV
o`0000?oC4a<00?o0000oc<c<olc<c<01olc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?mo
Ogoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@03
o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<00ol0003oC4a<o`000002ofIV
IP03o`000?moOgoo000000;oVIVI00?o0000ok>c/ol000002?o<c<`02Ol0003o/k>co`000?nIVIWo
0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c1_ooool1o`00007ooooo
0Oooool002Cooooo00?o0000ooooooooool00oooool5ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o
0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0:ofIVIP;o00006?m<C4`00ol0003oIVIVofIV
IP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02_nIVIT00ol0003o/k>cok>c
/`0Dok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIV
IP02ofIVIP03o`000?m<C4coC4a<00KoC4a<00Go0000oc<c<olc<c?o<c<co`000006oda<C0;o0000
0omVIVH01?l0003oOgmoogmoOol00003oiVIV@03o`000?nc/k?o/k>c00;o/k>c00?o0000olc<c?o<
c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Go0000ofIV
I_mVIVKoIVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mV
IVH01_l0003oOgmoogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01oo<c<`01?l0003o
/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07
oc<c<`03o`000?m<C4co000000;oIVIV00Oo0000ogmoOol0003oVIVIo`000?nc/k?o000000Woc<c<
00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06
oc<c<`03o`000?oooooooooo00?ooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo
00?ooooo1Onc/k<00ol0003oVIVIoiVIV@0:oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIV
I_mVIVH02_mVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmo
OomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Co/k>c00?o0000oiVI
VOnIVIT00onIVIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<
C?m<C4`01_m<C4`01Ol0003o<c<coc<c<olc<c?o000000KoC4a<00?o0000ofIVI_mVIVH00_mVIVH0
1?l0003oOgmoogmoOol00003oiVIV@03o`000?nc/k?o/k>c00;o/k>c00?o0000olc<c?o<c<`01Oo<
c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Go0000ofIVI_mVIVKo
IVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH01_l0
003oOgmoogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01oo<c<`01?l0003o/k>cok>c
/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`03
o`000?m<C4co000000;oIVIV00Oo0000ogmoOol0003oVIVIo`000?nc/k?o000000Woc<c<00Wo0000
ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`03
o`000?oooooooooo00?ooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo
1?nc/k<00ol0003oVIVIoiVIV@0:oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH0
2_mVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl0
2?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Co/k>c00?o0000oiVIVOnIVIT0
1?nIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`0
1_m<C4`3o`000003oc<c<ol0003oC4a<00GoC4a<00?o0000ofIVI_mVIVH00_mVIVH01?l0003oOgmo
ogmoOol00003oiVIV@03o`000?nc/k?o/k>c00;o/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o
/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000003
oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH01_l0003oOgmoogmo
Ool0003oVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVI
V@03o`000?moOgooOgmo00;o00000_m<C4`00ol0003o<c<coc<c<`07oc<c<`03o`000?m<C4co0000
00;oIVIV00?o0000ogmoOomoOgl00_l00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o0000ok>c
/ol000000_nIVIT2o`0000;oIVIV00Co0000oda<C?m<C4co00001olc<c<00ol0003oooooooooo`04
ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`;o/k>c0_l0000<oiVI
V@03o`000?moOgooOgmo00SoOgmo0_l0000<ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIV
I_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00[oVIVI0_l0000Fok>c
/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP03ofIV
IP03o`000?m<C4coC4a<00KoC4a<00Co0000oc<c<olc<c?o00001om<C4`01?l0003oIVIVofIVI_mV
IVH2o`0000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Goc<c<
00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`00
00?oC4a<00?o0000oc<c<olc<c<01olc<c<01?l0003oC4a<oda<C?l00002ofIVIP06o`000?moOgoo
Ogmoo`000?nIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`0000;o
VIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00?o0000oda<
C?l000000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`0
0ol0003o/k>co`000002oiVIV@;o00000_mVIVH00ol0003oC4a<o`000008oc<c<`03o`000?oooooo
oooo00Cooooo0Ol00001ooooo`7ooooo000Iooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool0
0ol0003oooooooooo`03ooooo`;o/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`09
ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;
ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0E
ok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP03
ofIVIP03o`000?m<C4coC4a<00KoC4a<00Co0000oc<c<olc<c?o00001om<C4`01Ol0003oIVIVofIV
I_mVIVKo000000?oOgmo00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Go
c<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIV
o`0000?oC4a<00?o0000oc<c<olc<c<01olc<c<01?l0003oC4a<oda<C?l00002ofIVIP06o`000?mo
OgooOgmoo`000?nIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`00
00;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00?o0000
oda<C?l000000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<
c<`00ol0003o/k>co`000002oiVIV@;o00000_mVIVH00ol0003oC4a<o`000008oc<c<`03o`000?oo
oooooooo00Cooooo0Ol00001ooooo`7ooooo000Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_oo
ool00ol0003oooooooooo`03ooooo`03ok>c/ol0003oVIVI00coVIVI00?o0000ogmoOomoOgl02?mo
Ogl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omV
IVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05Onc
/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH01?mV
IVH00ol0003oC4a<oda<C005oda<C004o`000?lc<c?o<c<co`0000OoC4a<00?o0000ofIVI_mVIVH0
0_mVIVH01Ol0003oOgmoogmoOomoOgoo000000;oVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003o
c<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0
003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`00
0002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01Ol0003o/k>c
ok>c/onc/k?o000000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c
00Ko<c<c00?o0000oda<C?l000000omVIVH01ol0003oOgmoo`000?nIVIWo0000ok>c/ol000002?o<
c<`01?l0003o/k>cok>c/ol00002oiVIV@;o000000CoIVIVo`000?m<C4co00002Olc<c<00ol0003o
ooooooooo`04ooooo`7o00000Oooool1ooooo`006Oooool01Ol@413ooooooooooooooooo410@00Ko
oooo00?o0000ooooooooool00oooool00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00So
Ogmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00[o
IVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Go
/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00?o
IVIV00?o0000oda<C?m<C4`01_m<C4`01?l0003o<c<coc<c<ol00007oda<C005o`000?mVIVKoIVIV
ofIVI_l000000omoOgl01Ol0003oVIVIoiVIVOnIVIWo000000Co/k>c00?o0000olc<c?o<c<`01Oo<
c<`00ol0003o/k>cok>c/`02ok>c/`07o`000?nIVIWoVIVIoiVIVOl0003oOgmoo`000003ofIVIP04
o`000?m<C4coC4a<o`0000So<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgoo
Ogmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`02ol0003o/k>cok>c/onc/k?o0000oiVI
VOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01olc<c<00ol0003oC4a<o`00
0002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c003o`00
0?nc/k?o000000;oVIVI0_l00002ofIVIP03o`000?m<C4co000000So<c<c00?o0000oda<C?ooool0
1Oooool1o`00007ooooo0Oooool001Wooooo00Go0000ooooooooooooooooo`000006ooooo`?o0000
0oooool<oiVIV@;o00002_moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<
0_l0000=ofIVIP03o`000?moOgooOgmo00OoOgmo0_l0000=oiVIV@03o`000?nc/k?o/k>c01Go/k>c
00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00?oIVIV
00?o0000oda<C?m<C4`01_m<C4`2o`000003oc<c<ol0003oC4a<00KoC4a<00?o0000ofIVI_mVIVH0
0_mVIVH01?l0003oOgmoogmoOol00003oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<
c<`01?o<c<`2o`0000Co/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00003
oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP03o`000?mo
Ogoo000000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c004o`000?nc/k?o/k>co`0000;o
VIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<
C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<
c<`00ol0003o/k>co`000002oiVIV@;o000000CoIVIVo`000?m<C4co00002Olc<c<00ol0003oC4a<
ooooo`03ooooo`?o00000_ooool001Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo00?ooooo3?nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV
00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?moOgooOgmo00OoOgmo
00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00CoVIVI
00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP02ofIVIP03o`000?m<C4coC4a<00WoC4a<
00?o0000oda<C?m<C4`01_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Go0000oiVIVOnI
VIWoVIVIo`000005ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00onc/k<01?l0
003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc
<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o0000ogmoOol000000_nIVIT01Ol0003o/k>c
ok>c/onc/k?o000000Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mVIVKo
000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP05o`000?mo
Ogoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c003o`000?nc/k?o000000;oVIVI
0_l000001?mVIVKo0000oda<C?l00009oc<c<`03o`000?m<C4co000000Gooooo0Ol00001ooooo`7o
oooo000Iooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`03ooooo`_o
VIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01Oo
C4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_o
VIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00;o
Ogmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C00Boda<C005o`000?mVIVKoIVIVofIV
I_l000000omoOgl01Ol0003oVIVIoiVIVOnIVIWo000000Go/k>c00?o0000olc<c?o<c<`01?o<c<`0
0ol0003o/k>cok>c/`03ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo0000
0om<C4`00ol0003o<c<coc<c<`06oc<c<`03o`000?m<C4coC4a<00;oC4a<00Go0000ofIVI_l0003o
Ogmoo`000002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01?l0003o/k>cok>c/ol00002
oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00001olc<c<01?l0003oC4a<oda<
C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00?o0000ok>c/ol000002?o<c<`00ol0003o/k>c
o`000002oiVIV@;o000000GoIVIVo`000?m<C4coC4a<o`000008oc<c<`04o`000?m<C4coC4a<o`00
00Gooooo0Ol00001ooooo`7ooooo000Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0
003oooooooooo`03ooooo`WoVIVI0_l00009ogmoO`;o00003OmVIVH00ol0003oC4a<oda<C00Foda<
C0;o00003OmVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c
/onc/k<05_nc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00;oOgmo0_l00004ofIV
IP03o`000?m<C4coC4a<01;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`05o`000?nIVIWo
VIVIoiVIVOl000001?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Go
0000oiVIVOnIVIWoVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc
<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0
003o/k>cok>c/ol00009olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl00ol0003oIVIV
o`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH01ol0003o
Ogmoo`000?nIVIWo0000ok>c/ol000002Oo<c<`00ol0003o/k>co`000002oiVIV@;o000000GoIVIV
o`000?m<C4coC4a<o`000008oc<c<`03o`000?m<C4co000000Kooooo0Ol00001ooooo`7ooooo000I
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`03ooooo`WoVIVI00?o
0000ogmoOomoOgl01omoOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o
0000ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o
0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00?oOgmo00?o
0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00Boda<C005o`000?mVIVKoIVIVofIVI_l00000
0omoOgl01Ol0003oVIVIoiVIVOnIVIWo000000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`01Ol0003o
/k>cok>c/onc/k?o000000CoVIVI00Co0000ogmoOomoOgoo00000_mVIVH01Ol0003oC4a<oda<C?m<
C4co000000So<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP03o`000?moOgoo000000;oVIVI
00Co0000ok>c/onc/k?o00002Oo<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00?o0000
ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Oo
0000ogmoOol0003oVIVIo`000?nc/k?o000000Woc<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo
0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`03o`000?m<C4co000000Kooooo0Ol0
0001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo2?nIVIT00ol0003oOgmoogmoO`07
ogmoO`03o`000?mVIVKoIVIV00coIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0<
ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0F
ok>c/`03o`000?nIVIWoVIVI00GoVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP03
ofIVIP03o`000?m<C4coC4a<01;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`05o`000?nI
VIWoVIVIoiVIVOl000001Onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00;o/k>c
00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c
<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o0000ogmoOol000000_nIVIT0
1?l0003o/k>cok>c/ol00009olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Go0000ogmoOol0003o
IVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00?o0000oda<C?l000000_mVIVH01Ol0003o
Ogmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003o/k>co`000002oiVI
V@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`05oc<c<`04o`000?m<C4co
C4a<o`0000Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo1onIVIT0
0ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`0
0ol0003oIVIVofIVIP0;ofIVIP;o00002_moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o
/k>c01Ko/k>c00?o0000oiVIVOnIVIT01OnIVIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKo
IVIV00;oIVIV00?o0000oda<C?m<C4`04_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Go
0000oiVIVOnIVIWoVIVIo`000005ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<0
0_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`05o`000?mVIVKoIVIVofIVI_l000000om<C4`00ol0
003o<c<coc<c<`05oc<c<`;o00000om<C4`00ol0003oIVIVo`000002ogmoO`04o`000?nIVIWoVIVI
o`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01ol0003o/k>cok>c/onc/k?o0000oiVIVOl00000
0_moOgl01Ol0003oIVIVo`000?m<C4co000000[o<c<c00Co0000oda<C?l0003oIVIV0_l000001?mo
Ogoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o0000ok>c/ol000000_nIVIT0
1ol0003oOgmoo`000?mVIVKo0000oda<C?l000002?lc<c<01?l0003oC4a<oda<C?l00006ooooo`7o
00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`KoVIVI00?o0000ogmoOomoOgl0
2?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH0
2omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<0
5onc/k<00ol0003oVIVIoiVIV@05oiVIV@03o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH0
0omVIVH00ol0003oC4a<oda<C00Boda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01Ol0003o
VIVIoiVIVOnIVIWo000000Go/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c
/`04o`000?nIVIWoVIVIo`0000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000003oda<C003o`000?lc
<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`00ol0003oIVIVo`000002ogmoO`04o`000?nI
VIWoVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@08
o`000?moOgooOgmoo`000?mVIVKo0000oda<C?l0000:oc<c<`05o`000?m<C4co0000ofIVI_l00000
0_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o0000ok>c/ol00000
0_nIVIT01?l0003oOgmoo`000?l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<
C4co00001_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool5oiVIV@03
o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003
o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03
o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT01OnIVIT00ol0003oOgmoogmoO`02ogmoO`03
o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<C4`04_m<C4`01Ol0003oIVIVofIVI_mVIVKo0000
00?oOgmo00Go0000oiVIVOnIVIWoVIVIo`000005ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000
ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`05o`000?mVIVKoIVIVofIVI_l00000
0om<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo
00000_moOgl00ol0003oVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Goc<c<00Oo0000ok>c/onc
/k?o/k>co`000?nIVIWo000000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07
oc<c<`03o`000?m<C4co000000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<
c<coc<c<00Koc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l0
0009oc<c<`05o`000?m<C4co0000ofIVI_l000001Oooool1o`00007ooooo0Oooool002Cooooo00?o
0000ooooooooool00oooool4oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omV
IVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02Omo
Ogl00ol0003oVIVIoiVIV@0:oiVIV@;o00006?nc/k<2o`0000OoVIVI00?o0000ogmoOomoOgl00omo
Ogl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<017oC4a<00?o0000ofIVI_mVIVH00_mV
IVH01Ol0003oOgmoogmoOomoOgoo000000?oVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<
olc<c004olc<c003o`000?nc/k?o/k>c00;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`04
o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co
000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01?l0003o/k>cok>c/ol00008olc<c007o`00
0?nc/k?o/k>cok>c/ol0003oVIVIo`000002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c
<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc
/k<00ol0003oc<c<olc<c006olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIV
o`000?m<C4co00002Olc<c<2o`000003ofIVI_l0003ooooo00Gooooo0Ol00001ooooo`7ooooo000T
ooooo`;o00001?ooool2oiVIV@;o00002_moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4co
C4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWo
VIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@07oiVIV@03o`000?moOgoo
Ogmo00?oOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00Aoda<C003o`000?mVIVKo
IVIV00;oIVIV00Co0000ogmoOomoOgoo00001?nIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<
c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo
00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<
C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Oo
0000ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o
<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Go0000ogmoOol0003oVIVIo`000002
ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o0000oiVIV@02o`0000;oIVIV00?o
0000oda<C?l000002Olc<c<2o`000003ofIVI_l0003ooooo00Cooooo0_l00002ooooo`009?ooool0
0ol0003oooooooooo`03ooooo`03oiVIVOl0003oOgmo00[oOgmo00?o0000ofIVI_mVIVH02omVIVH0
0ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02OmoOgl0
0ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT01_nIVIT0
0ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<C4`04Om<C4`0
0ol0003oIVIVofIVIP02ofIVIP05o`000?moOgooOgmoogmoOol000000onIVIT00ol0003o/k>cok>c
/`03ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00_nc/k<01Ol0003oVIVIoiVI
VOnIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`05
o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@04o`000?nc/k?o
/k>co`0000Soc<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo00Co0000ofIVI_mV
IVKo00000_m<C4`00ol0003o<c<coc<c<`05oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000
ogmoOol000000_nIVIT00ol0003o/k>co`000008olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000
ogmoOol0003oIVIVo`000?m<C4co00002Olc<c<01Ol0003oC4a<o`000?l0003oOgmo00Kooooo0Ol0
0001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo00?o0000ogmoOomoOgl02OmoOgl0
0ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH0
0ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00[oVIVI0_l0000Iok>c/`03o`000?nIVIWo
VIVI00KoVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4co
C4a<01;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`04o`000?nIVIWoVIVIoiVIV@;o0000
1?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00?o0000oiVIVOnIVIT0
0_l00002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003o
C4a<oda<C?m<C4co000000;oIVIV00Ko0000ogmoOomoOgoo0000oiVIVOl00003ok>c/`03o`000?o<
c<coc<c<00Koc<c<00So0000ok>c/onc/k?o/k>co`000?nIVIWo0000ogmoO`;o000000GoIVIVo`00
0?m<C4coC4a<o`000008oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl01Ol0003oVIVI
o`000?nc/k?o000000Woc<c<00?o0000ok>c/ol000000_nIVIT01ol0003oOgmoo`000?mVIVKo0000
oda<C?l000002?lc<c<00ol0003oC4a<oda<C002o`000003ogmoOooooooooooo00Cooooo0Ol00001
ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo00?o0000ogmoOomoOgl02?moOgl00ol0
003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0
003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0
003oVIVIoiVIV@06oiVIV@03o`000?moOgooOgmo00?oOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0
003oC4a<oda<C00Coda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01Ol0003oVIVIoiVIVOnI
VIWo000000Go/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nI
VIWoVIVIo`0000?oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`05
o`000?m<C4coC4a<oda<C?l000000_mVIVH01_l0003oOgmoogmoOol0003oVIVIo`0000?o/k>c00?o
0000olc<c?o<c<`01_o<c<`02Ol0003o/k>cok>c/onc/k?o0000oiVIVOl0003oOgmoo`000002ofIV
IP04o`000?m<C4coC4a<o`0000So<c<c00So0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000;o
VIVI00?o0000ok>c/ol000002Oo<c<`01Ol0003o/k>co`000?nIVIWo000000;oOgmo00Go0000ofIV
I_l0003oC4a<o`000008oc<c<`03o`000?m<C4coC4a<00;o000000?oOgmoooooooooool01?ooool1
o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool:ogmoO`03o`000?mVIVKoIVIV
00_oIVIV00?o0000oda<C?m<C4`05_m<C4`2o`0000coIVIV00?o0000ogmoOomoOgl02?moOgl2o`00
00goVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@06oiVIV@03o`000?moOgooOgmo
00CoOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00Boda<C005o`000?mVIVKoIVIV
ofIVI_l000000omoOgl01Ol0003oVIVIoiVIVOnIVIWo000000Go/k>c00?o0000olc<c?o<c<`01Oo<
c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000?oOgmo00Go0000ofIVI_mVIVKo
IVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIV
IP04o`000?moOgooOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`02Ol0003o/k>cok>c
/onc/k?o0000oiVIVOl0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Ko0000
oda<C?m<C4co0000ofIVI_l00002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`0
1_o<c<`00ol0003o/k>co`000002oiVIV@07o`000?moOgoo0000ofIVI_l0003oC4a<o`000009oc<c
<`07o`000?m<C4co0000ofIVI_l0003oOgmoo`000005ooooo`7o00000Oooool1ooooo`009?ooool0
0ol0003oooooooooo`03ooooo`WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00F
oda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0<
oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT01_nIVIT00ol0003oOgmoogmoO`04
ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<C4`04_m<C4`00ol0003oIVIVofIVIP02
ofIVIP05o`000?moOgooOgmoogmoOol000000onIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<
c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00onc/k<01?l0003oVIVIoiVIVOl00002ogmoO`05o`00
0?mVIVKoIVIVofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<
C?l000000_mVIVH01_l0003oOgmoo`000?l0003oVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<
c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co
00002?lc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00?o0000oiVIVOl000000_nc/k<0
0ol0003oc<c<olc<c006olc<c003o`000?nc/k?o000000;oVIVI00Oo0000ogmoOol0003oIVIVo`00
0?m<C4co000000So<c<c00Go0000oda<C?m<C4co0000ofIVIP02o`0000Kooooo0Ol00001ooooo`7o
oooo000Tooooo`03o`000?oooooooooo00?ooooo2?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`00
0?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`00
0?nIVIWoVIVI00[oVIVI0_l0000Iok>c/`03o`000?nIVIWoVIVI00OoVIVI00?o0000ogmoOomoOgl0
1?moOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<01;oC4a<00?o0000ofIVI_mVIVH0
0_mVIVH01?l0003oOgmoogmoOol00004oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<
c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Go0000ofIV
I_mVIVKoIVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mV
IVH01?l0003oOgmoogmoOol00002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01?l0003o
/k>cok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<0
1_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<
olc<c006olc<c003o`000?nc/k?o000000;oVIVI00Oo0000ogmoOol0003oIVIVo`000?m<C4co0000
00So<c<c00Go0000oda<C?m<C4co0000ofIVIP02o`0000Kooooo0Ol00001ooooo`7ooooo000Toooo
o`03o`000?oooooooooo00?ooooo1omoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<
01KoC4a<0_l0000<ofIVIP03o`000?moOgooOgmo00SoOgmo0_l0000<oiVIV@03o`000?nc/k?o/k>c
01So/k>c00?o0000oiVIVOnIVIT01onIVIT00ol0003oOgmoogmoO`04ogmoO`03o`000?mVIVKoIVIV
00?oIVIV00?o0000oda<C?m<C4`04_m<C4`00ol0003oIVIVofIVIP02ofIVIP05o`000?moOgooOgmo
ogmoOol000000onIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000
ok>c/onc/k<00onc/k<01?l0003oVIVIoiVIVOl00002ogmoO`05o`000?mVIVKoIVIVofIVI_l00000
0om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH00ol0003o
Ogmoo`000002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01?l0003o/k>cok>c/ol00002
oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<01?l0003oC4a<oda<
C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c00<
o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co00002?lc<c<02?l0003o
C4a<oda<C?l0003oIVIVo`000?moOgoo00001_ooool1o`00007ooooo0Oooool002Cooooo00?o0000
ooooooooool00oooool6ogmoO`03o`000?mVIVKoIVIV00[oIVIV0_l0000Hoda<C003o`000?mVIVKo
IVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o
/k>c01So/k>c00?o0000oiVIVOnIVIT01onIVIT2o`0000GoOgmo00?o0000ofIVI_mVIVH00omVIVH0
0ol0003oC4a<oda<C00Boda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgooOgmoo`00
0003oiVIV@03o`000?nc/k?o/k>c00?o/k>c0_l00006olc<c003o`000?nc/k?o/k>c00;o/k>c00Go
0000oiVIVOnIVIWoVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc
<c<01_lc<c<00ol0003oC4a<oda<C002oda<C006o`000?mVIVKoIVIVo`000?moOgoo00000_nIVIT0
1?l0003o/k>cok>c/ol00009olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol00000
0_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl0
0ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00co0000ok>c/onc/k?o0000oiVI
VOl0003oOgmoo`000?mVIVKo0000oda<C?l00008oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000
ogmoOol00006ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`GoOgmo
00?o0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00_oIVIV
00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@;o00006Onc/k<00ol0003oVIVI
oiVIV@08oiVIV@03o`000?moOgooOgmo00CoOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<
oda<C00Boda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgooOgmoo`000003oiVIV@03
o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04
o`000?nIVIWoVIVIo`0000?oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06
oc<c<`03o`000?m<C4coC4a<00;oC4a<00Ko0000ofIVI_mVIVKo0000ogmoOol00002oiVIV@04o`00
0?nc/k?o/k>co`0000Woc<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIV
IP04o`000?m<C4coC4a<o`0000So<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`03o`00
0?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`00
0?moOgoo0000ofIVI_l0003oC4a<o`0000So<c<c00So0000oda<C?m<C4co0000ofIVI_l0003oOgmo
o`0000Kooooo0Ol00001ooooo`7ooooo000Tooooo`;o00001?ooool4ogmoO`03o`000?mVIVKoIVIV
00[oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo
00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Hok>c/`03o`000?nIVIWoVIVI
00SoVIVI00?o0000ogmoOomoOgl01?moOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<
01;oC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000?oVIVI00?o0000
ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Go0000
oiVIVOnIVIWoVIVIo`000002ogmoO`05o`000?mVIVKoIVIVofIVI_l000000om<C4`00ol0003o<c<c
oc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Ko0000ofIVI_mVIVKo0000ogmoOol00002oiVI
V@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?mo
Ogoo000000?oIVIV00Co0000oda<C?m<C4co00001olc<c<01_l0003oC4a<oda<C?l0003oIVIVo`00
00;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c00<o`000?nc/k?o/k>c
o`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co00002?lc<c<02_l0003oC4a<oda<C?l0003o
IVIVo`000?moOgoo0000oiVIVOl00004ooooo`;o00000_ooool002Cooooo00?o0000ooooooooool0
0oooool2ogmoO`;o00003?mVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00_oIVIV
00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01So/k>c
00?o0000oiVIVOnIVIT02?nIVIT00ol0003oOgmoogmoO`04ogmoO`03o`000?mVIVKoIVIV00?oIVIV
00?o0000oda<C?m<C4`04om<C4`00ol0003oIVIVofIVIP02ofIVIP05o`000?moOgooOgmoogmoOol0
00000onIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc
/k<00onc/k<01?l0003oVIVIoiVIVOl00003ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000
oc<c<olc<c<01Olc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo0000
0_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0
003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00So0000oda<C?m<C4co0000ofIV
I_l0003oOgmoo`0000;oVIVI00?o0000ok>c/ol000002Oo<c<`00ol0003o/k>co`000002oiVIV@07
o`000?moOgoo0000ofIVI_l0003oC4a<o`000008oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000
ogmoOol0003oVIVIo`0000Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?o
oooo0_moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mV
IVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00coVIVI00?o0000ok>c/onc
/k<05onc/k<00ol0003oVIVIoiVIV@08oiVIV@03o`000?moOgooOgmo00GoOgmo00?o0000ofIVI_mV
IVH00omVIVH00ol0003oC4a<oda<C00Coda<C003o`000?mVIVKoIVIV00;oIVIV00Co0000ogmoOomo
Ogoo00001?nIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c
/onc/k<00onc/k<01?l0003oVIVIoiVIVOl00003ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o
0000oc<c<olc<c<01Olc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo
00000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT0
0ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00So0000oda<C?m<C4co0000
ofIVI_l0003oOgmoo`0000;oVIVI00?o0000ok>c/ol000002Oo<c<`00ol0003o/k>co`000002oiVI
V@07o`000?moOgoo0000ofIVI_l0003oC4a<o`000008oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo
0000ogmoOol0003oVIVIo`0000Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo
00?ooooo00?oOgmoo`000?mVIVH03?mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV
00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c
01Oo/k>c00?o0000oiVIVOnIVIT02OnIVIT00ol0003oOgmoogmoO`04ogmoO`03o`000?mVIVKoIVIV
00?oIVIV00?o0000oda<C?m<C4`04om<C4`00ol0003oIVIVofIVIP02ofIVIP05o`000?moOgooOgmo
ogmoOol000000onIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000
ok>c/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Go0000ofIVI_mVIVKoIVIV
o`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH01?l0003o
OgmoogmoOol00003oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Co0000ok>c/onc/k?o00000_nI
VIT01_l0003oOgmoogmoOol0003oIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<02?l0003o
C4a<oda<C?l0003oIVIVo`000?moOgoo00000_nIVIT00ol0003o/k>co`000009olc<c005o`000?nc
/k?o0000oiVIVOl000000_moOgl01Ol0003oIVIVo`000?m<C4co000000So<c<c00Go0000oda<C?m<
C4co0000ofIVIP02o`0000;oVIVI00?o0000ooooooooool00oooool1o`00007ooooo0Oooool002Co
oooo00?o0000ooooooooool00oooool00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01Oo
C4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00_o
VIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@09oiVIV@03o`000?moOgooOgmo00Co
Ogmo00?o0000ofIVI_mVIVH01?mVIVH00ol0003oC4a<oda<C00Coda<C003o`000?mVIVKoIVIV00;o
IVIV00Co0000ogmoOomoOgoo00001?nIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<
00Coc<c<00?o0000ok>c/onc/k<00onc/k<01?l0003oVIVIoiVIVOl00003ogmoO`04o`000?mVIVKo
IVIVo`0000CoC4a<00?o0000oc<c<olc<c<01Olc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV
00Co0000ogmoOomoOgoo00000onIVIT01?l0003o/k>cok>c/ol00008olc<c004o`000?nc/k?o/k>c
o`0000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`08o`000?m<
C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00?o0000
ok>c/ol000000_nIVIT01ol0003oOgmoo`000?mVIVKo0000oda<C?l000002Olc<c<02Ol0003oC4a<
o`000?mVIVKo0000ogmoOol0003oVIVIo`000006ooooo`7o00000Oooool1ooooo`009?ooool00ol0
003oooooooooo`03ooooo`goIVIV00?o0000oda<C?m<C4`05_m<C4`2o`0000goIVIV00?o0000ogmo
OomoOgl01omoOgl2o`0000goVIVI00?o0000ok>c/onc/k<05_nc/k<2o`0000_oVIVI00?o0000ogmo
OomoOgl01?moOgl00ol0003oIVIVofIVIP04ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000ofIV
I_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000?oVIVI00?o0000ok>c/onc/k<01?nc/k<0
0ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00;o/k>c00Go0000oiVIVOnIVIWoVIVIo`00
0002ogmoO`05o`000?mVIVKoIVIVofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`00
0?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@04o`000?nc/k?o/k>c
o`0000Soc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@05o`000?moOgoo0000ofIVI_l00000
0om<C4`00ol0003o<c<coc<c<`06oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002
oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00?o0000ok>c/ol000000_nIVIT01ol0003oOgmoo`00
0?mVIVKo0000oda<C?l000002?lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVI
VOl00006ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`coIVIV00?o
0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?moOgooOgmo00OoOgmo00?o
0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00[oVIVI00?o
0000ogmoOomoOgl01OmoOgl00ol0003oIVIVofIVIP04ofIVIP03o`000?m<C4coC4a<01?oC4a<00Go
0000ofIVI_mVIVKoIVIVo`000004ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001_nc/k<00ol0003o
c<c<olc<c004olc<c003o`000?nc/k?o/k>c00;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmo
O`05o`000?mVIVKoIVIVofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4co
C4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000So
c<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@05o`000?moOgoo0000ofIVI_l000000om<C4`0
0ol0003o<c<coc<c<`06oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVIV@04
o`000?nc/k?o/k>co`0000Soc<c<00?o0000ok>c/ol000000_nIVIT01?l0003oOgmoo`000?l00002
oda<C003o`000?lc<c?o<c<c00Ko<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nI
VIWo00001_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool;ofIVIP03
o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03
o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03
o`000?moOgooOgmo00CoOgmo00?o0000ofIVI_mVIVH01?mVIVH00ol0003oC4a<oda<C00Coda<C003
o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgooOgmoo`000003oiVIV@03o`000?nc/k?o/k>c
00Co/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`02ok>c/`05o`000?nIVIWoVIVI
oiVIVOl000000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc
<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01?l0003o
/k>cok>c/ol00009olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Go0000ogmoOol0003oIVIVo`00
0003oda<C003o`000?lc<c?o<c<c00Ko<c<c00So0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`00
00;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo
0000ofIVI_l0003oC4a<o`0000So<c<c00_o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nI
VIWo0000ok>c/`06ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`[o
IVIV00?o0000oda<C?m<C4`05_m<C4`2o`0000goIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003o
VIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02_nIVIT2o`0000Ko
Ogmo00?o0000ofIVI_mVIVH01?mVIVH00ol0003oC4a<oda<C00Coda<C003o`000?mVIVKoIVIV00;o
IVIV00?o0000ogmoOomoOgl00_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Go/k>c00?o0000olc<
c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl0
0ol0003oIVIVofIVIP02o`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<
C4co000000;oIVIV00Ko0000ogmoOomoOgoo0000oiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Oo
c<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`03o`000?mVIVKo000000?oC4a<00?o0000
oc<c<olc<c<01_lc<c<02?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo00000_nIVIT01?l0003o
/k>co`000?l00008olc<c003o`000?nc/k?o000000;oVIVI00Oo0000ogmoOol0003oIVIVo`000?m<
C4co000000So<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol0
0005ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`WoIVIV00?o0000
oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000
oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00[oVIVI00?o0000
ogmoOomoOgl01_moOgl00ol0003oIVIVofIVIP04ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000
ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000CoVIVI00?o0000ok>c/onc/k<00onc
/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Go0000oiVIVOnIVIWoVIVI
o`000002ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003o
C4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00?o0000oiVIVOl000000onc/k<00ol0
003oc<c<olc<c007olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP05o`00
0?m<C4coC4a<oda<C?l000002?lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVI
VOl00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00?o0000ok>c/ol000000_nIVIT01ol0003oOgmo
o`000?mVIVKo0000oda<C?l000002?lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000
oiVIVOl0003o/k>co`0000Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?o
oooo2?mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomo
Ogl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnI
VIT02onIVIT00ol0003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV00CoIVIV00?o0000oda<C?m<
C4`04om<C4`00ol0003oIVIVofIVIP02ofIVIP03o`000?moOgooOgmo00;oOgmo00Go0000oiVIVOnI
VIWoVIVIo`000005ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00onc/k<01Ol0
003oVIVIoiVIVOnIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c
<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01_l0003oOgmoogmoOol0003oVIVIo`00
00?o/k>c00?o0000olc<c?o<c<`01oo<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00?o
0000ofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo
0000ogmoOol00002oiVIV@03o`000?nc/k?o000000Woc<c<00?o0000ok>c/ol000000_nIVIT01ol0
003oOgmoo`000?mVIVKo0000oda<C?l000002Olc<c<02ol0003oC4a<o`000?mVIVKo0000ogmoOol0
003oVIVIo`000?nc/k?o000000Kooooo0Ol00001ooooo`7ooooo000Tooooo`;o00001?ooool7ofIV
IP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH2o`0000[oOgmo00?o0000oiVI
VOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmo
OomoOgl01OmoOgl00ol0003oIVIVofIVIP04ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000ofIV
I_mVIVH00omVIVH01Ol0003oOgmoogmoOomoOgoo000000?oVIVI00?o0000ok>c/onc/k<01?nc/k<0
0ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Co0000oiVIVOnIVIWo00000omo
Ogl01?l0003oIVIVofIVI_l00004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`0
0_m<C4`01_l0003oIVIVofIVI_l0003oOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008
olc<c007o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000002ogmoO`03o`000?mVIVKo000000;oC4a<
00?o0000oc<c<olc<c<01olc<c<02?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo00000_nIVIT0
0ol0003o/k>co`000009olc<c003o`000?nc/k?o000000;oVIVI00Oo0000ogmoOol0003oIVIVo`00
0?m<C4co000000Wo<c<c00_o0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`00
0005ooooo`;o00000_ooool002Cooooo00?o0000ooooooooool00oooool6ofIVIP03o`000?m<C4co
C4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWo
VIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgoo
Ogmo00GoOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<C00Coda<C003o`000?mVIVKo
IVIV00;oIVIV00?o0000ogmoOomoOgl00_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Go/k>c00?o
0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`05o`000?nIVIWoVIVIoiVIVOl00000
0omoOgl01?l0003oIVIVofIVI_l00004oda<C003o`000?lc<c?o<c<c00Go<c<c00Go0000oda<C?m<
C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`00
0008olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Ko0000ogmoOomoOgoo0000ofIVI_l00002oda<
C003o`000?lc<c?o<c<c00Oo<c<c00So0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000;oVIVI
00?o0000ok>c/ol000002Oo<c<`00ol0003o/k>co`000002oiVIV@07o`000?moOgoo0000ofIVI_l0
003oC4a<o`000009oc<c<`0;o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol0
00001_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool5ofIVIP03o`00
0?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`00
0?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`00
0?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH01?mVIVH00ol0003oC4a<oda<C00Coda<C003o`00
0?mVIVKoIVIV00?oIVIV00Go0000ogmoOomoOgooOgmoo`000003oiVIV@03o`000?nc/k?o/k>c00Co
/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`04o`000?nIVIWoVIVIo`00
00?oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4co
C4a<00;oC4a<00Ko0000ofIVI_mVIVKo0000ogmoOol00002oiVIV@03o`000?nc/k?o/k>c00;o/k>c
00?o0000olc<c?o<c<`01Oo<c<`01ol0003o/k>cok>c/onc/k?o0000oiVIVOl000000_moOgl00ol0
003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00So0000oda<C?m<C4co0000ofIVI_l0
003oOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`00ol0003o/k>co`000002oiVIV@07
o`000?moOgoo0000ofIVI_l0003oC4a<o`000009oc<c<`03o`000?m<C4coC4a<00;o000000OoOgmo
o`000?nIVIWo0000ok>c/ol0003oc<c<00Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oo
oooooooo00?ooooo1?mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o
0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0:oiVIV@;o00006?nc/k<00ol0003oVIVIoiVI
V@0;oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH01?mVIVH2o`0001GoC4a<00?o
0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000CoVIVI00?o0000ok>c/onc/k<0
1?nc/k<00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c00?o/k>c00Go0000oiVIVOnIVIWo
VIVIo`000002ogmoO`05o`000?mVIVKoIVIVofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c
<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@05o`000?nc
/k?o/k>cok>c/ol000002?o<c<`01ol0003o/k>cok>c/onc/k?o0000oiVIVOl000000_moOgl00ol0
003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00So0000oda<C?m<C4co0000ofIVI_l0
003oOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`00ol0003o/k>co`000002oiVIV@07
o`000?moOgoo0000ofIVI_l0003oC4a<o`000008oc<c<`;o000000_oC4a<o`000?mVIVKo0000ogmo
Ool0003oVIVIo`000?nc/k?o0000olc<c006ooooo`7o00000Oooool1ooooo`009?ooool00ol0003o
ooooooooo`03ooooo`?oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03
o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03
o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl01_moOgl00ol0003oIVIVofIVIP05ofIVIP03
o`000?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo0000
00CoVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c
00?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o
0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo
00000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Oo0000ok>c/onc/k?o/k>co`000?nI
VIWo000000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`08o`000?m<
C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00?o0000
ok>c/ol000000_nIVIT01ol0003oOgmoo`000?mVIVKo0000oda<C?l000002?lc<c<03Ol0003oC4a<
oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`000?o<c<`01_ooool1o`00007ooooo
0Oooool002Cooooo00?o0000ooooooooool00oooool2ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o
0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o
0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00KoOgmo00?o
0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<C00Doda<C003o`000?mVIVKoIVIV00;oIVIV00?o
0000ogmoOomoOgl00_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Ko/k>c00?o0000olc<c?o<c<`0
0oo<c<`00ol0003o/k>cok>c/`03ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01Ol0003o
IVIVofIVI_mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co
000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<
00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0
003o<c<coc<c<`07oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVIV@04o`00
0?nc/k?o/k>co`0000Soc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000
0_m<C4`00ol0003o<c<coc<c<`05oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003o
VIVIo`000?nc/k?o00000_o<c<`6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003ooooooooo
o`03ooooo`03ofIVI_l0003oC4a<01OoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmo
O`09ogmoO`03o`000?nIVIWoVIVI00[oVIVI0_l0000Hok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o
0000ogmoOomoOgl01_moOgl00ol0003oIVIVofIVIP05ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o
0000ofIVI_mVIVH00_mVIVH00ol0003oOgmoogmoO`02ogmoO`05o`000?nIVIWoVIVIoiVIVOl00000
1_nc/k<00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c00Co/k>c00Co0000oiVIVOnIVIWo
00000omoOgl01?l0003oIVIVofIVI_l00004oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<
C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>c
o`000008olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003o
C4a<oda<C?l00008oc<c<`09o`000?m<C4coC4a<oda<C?l0003oIVIVo`000?moOgoo000000;oVIVI
00?o0000ok>c/ol000002Oo<c<`00ol0003o/k>co`000002oiVIV@07o`000?moOgoo0000ofIVI_l0
003oC4a<o`000008oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc
/k?o00000_o<c<`6ooooo`7o00000Oooool1ooooo`006Oooool5o`0000Kooooo00?o0000oooooooo
ool00oooool00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00[oIVIV00?o0000ogmoOomo
Ogl02OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnI
VIT02onIVIT00ol0003oOgmoogmoO`07ogmoO`03o`000?mVIVKoIVIV00GoIVIV00?o0000oda<C?m<
C4`04om<C4`00ol0003oIVIVofIVIP03ofIVIP03o`000?moOgooOgmo00;oOgmo00Go0000oiVIVOnI
VIWoVIVIo`000006ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<01?nc/k<01?l0
003oVIVIoiVIVOl00003ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01_lc
<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01Ol0003o
/k>cok>c/onc/k?o000000Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002
ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00_o0000oda<C?m<C4coC4a<o`000?mVIVKo0000ogmo
Ool0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00?o0000ok>c/ol000000_nIVIT0
1ol0003oOgmoo`000?mVIVKo0000oda<C?l000002?lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`00
0?moOgoo0000oiVIVOl0003o/k>co`0000;oc<c<1_ooool1o`00007ooooo0Oooool001Wooooo00Go
V9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo00?ooooo6?m<C4`2o`0000coIVIV
00?o0000ogmoOomoOgl02?moOgl2o`0000goVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVI
oiVIV@0;oiVIV@03o`000?moOgooOgmo00OoOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<
oda<C00Coda<C003o`000?mVIVKoIVIV00?oIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVI
oiVIV@02oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>c
ok>c/`03ok>c/`04o`000?nIVIWoVIVIo`0000?oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0
003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol0
0002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@06
o`000?moOgooOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`09o`000?m<C4co
C4a<oda<C?l0003oIVIVo`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`00ol0
003o/k>co`000002oiVIV@07o`000?moOgoo0000ofIVI_l0003oC4a<o`000009oc<c<`03o`000?m<
C4co000000;oIVIV0_l000001OnIVIWo0000ok>c/onc/k?o000000;oc<c<1_ooool1o`00007ooooo
0Oooool001[ooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`03oooooaOoC4a<00?o
0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00coVIVI00?o
0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00OoOgmo00?o
0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<C00Doda<C003o`000?mVIVKoIVIV00;oIVIV00?o
0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o
0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`03ok>c/`05o`000?nIVIWoVIVIoiVIVOl00000
0_moOgl01Ol0003oIVIVofIVI_mVIVKo000000CoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003o
C4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<0
0ol0003oc<c<olc<c005olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT00ol0003oOgmoo`00
0002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Wo0000oda<C?m<C4coC4a<o`000?mVIVKo0000
ogmoOol000000_nIVIT00ol0003o/k>co`000009olc<c003o`000?nc/k?o000000;oVIVI00Oo0000
ogmoOol0003oIVIVo`000?m<C4co000000Wo<c<c00_o0000oda<C?l0003oIVIVo`000?moOgoo0000
oiVIVOl0003o/k>co`000003olc<c0Kooooo0Ol00001ooooo`7ooooo000Kooooo`03oiRHV?lQ8B7o
k^k^00Kooooo0ol00003oooooaOoC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`09
ogmoO`03o`000?nIVIWoVIVI00[oVIVI0_l0000Hok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000
ogmoOomoOgl01omoOgl00ol0003oIVIVofIVIP06ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000
ofIVI_mVIVH00_mVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000
ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c00?o/k>c00Go0000
oiVIVOnIVIWoVIVIo`000002ogmoO`05o`000?mVIVKoIVIVofIVI_l000001?m<C4`00ol0003o<c<c
oc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003o
VIVIoiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002
oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<02Ol0003oC4a<oda<
C?m<C4co0000ofIVI_l0003oOgmoo`000002oiVIV@03o`000?nc/k?o000000Woc<c<00?o0000ok>c
/ol000000_nIVIT01ol0003oOgmoo`000?mVIVKo0000oda<C?l000002Olc<c<02ol0003oC4a<o`00
0?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o000000?oc<c<1?ooool3o`0000;ooooo000Loooo
o`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool00ooooolEoda<C0;o00003?mVIVH00ol0
003oOgmoogmoO`08ogmoO`;o00003?nIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI
00_oVIVI00?o0000ogmoOomoOgl01omoOgl00ol0003oIVIVofIVIP06ofIVIP03o`000?m<C4coC4a<
01CoC4a<00?o0000ofIVI_mVIVH00_mVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI
00;oVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c
00?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o
0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo
00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o
/k>c00Go0000oiVIVOl0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Oo0000
oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00Go0000oiVIVOl0003o/k>co`000009olc<c003
o`000?nc/k?o000000;oVIVI00Oo0000ogmoOol0003oIVIVo`000?m<C4co000000Wo<c<c00?o0000
oda<C?m<C4`00_l000001?moOgoo0000oiVIVOnIVIT2o`0000Coc<c<1_ooool1o`00007ooooo0Ooo
ool001gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooooaCoC4a<00?o0000
ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000
ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00OoOgmo00?o0000
ofIVI_mVIVH01_mVIVH00ol0003oC4a<oda<C00Doda<C003o`000?mVIVKoIVIV00?oIVIV00Go0000
ogmoOomoOgooOgmoo`000004oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`00oo<
c<`00ol0003o/k>cok>c/`04ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01Ol0003oIVIV
ofIVI_mVIVKo000000CoC4a<00?o0000oc<c<olc<c<01Olc<c<01Ol0003oC4a<oda<C?m<C4co0000
00?oIVIV00?o0000ogmoOol000000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Go0000
ok>c/onc/k?o/k>co`000002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co0000
2?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0
003oc<c<olc<c007olc<c003o`000?nc/k?o000000;oVIVI00Oo0000ogmoOol0003oIVIVo`000?m<
C4co000000So<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol0
0004olc<c0Kooooo0Ol00001ooooo`7ooooo000Iooooo`05o`000?nj^[[ooooooiRHV?l@41001_oo
ool00ol0003oooooooooo`03oooooa?oC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmo
O`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI0_l0000Hok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o
0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP06ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o
0000ofIVI_mVIVH01?mVIVH01Ol0003oOgmoogmoOomoOgoo000000CoVIVI00?o0000ok>c/onc/k<0
1?nc/k<00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c00Co/k>c00Go0000oiVIVOnIVIWo
VIVIo`000002ogmoO`05o`000?mVIVKoIVIVofIVI_l000001?m<C4`00ol0003o<c<coc<c<`05oc<c
<`05o`000?m<C4coC4a<oda<C?l000000omVIVH00ol0003oOgmoo`000002oiVIV@05o`000?nc/k?o
/k>cok>c/ol000002?o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmoOol00000
0_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Go0000ogmo
Ool0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00?o0000ok>c/ol000000_nIVIT0
1ol0003oOgmoo`000?mVIVKo0000oda<C?l000002?lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`00
0?moOgoo0000oiVIVOl0003o/k>co`0000Coc<c<1_ooool1o`00007ooooo0Oooool000_ooooo0ol0
00000ol@413oooooooooo`08ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003ooooo
ooooo`03oooooa;oC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`00
0?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`00
0?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH01_mVIVH00ol0003oC4a<oda<C00Doda<C003o`00
0?mVIVKoIVIV00?oIVIV00Go0000ogmoOomoOgooOgmoo`000004oiVIV@03o`000?nc/k?o/k>c00Co
/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`04ok>c/`05o`000?nIVIWoVIVIoiVI
VOl000000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000CoC4a<00?o0000oc<c<olc<c<01Olc<c<0
1Ol0003oC4a<oda<C?m<C4co000000?oIVIV00?o0000ogmoOol000000_nIVIT01Ol0003o/k>cok>c
/onc/k?o000000Soc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@03o`000?moOgoo000000;o
IVIV00Co0000oda<C?m<C4co00002Olc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000
oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003o
Ogmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4co0000ofIVI_l0
00000_moOgl2o`000003ok>c/ol0003oc<c<00Coc<c<1_ooool1o`00007ooooo0Oooool000gooooo
00?o410@okZj^_ooool05?ooool00ol0003oooooooooo`03oooooa7oC4a<00?o0000ofIVI_mVIVH0
2omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<0
5onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH0
1_mVIVH00ol0003oC4a<oda<C00Doda<C003o`000?mVIVKoIVIV00?oIVIV00?o0000ogmoOomoOgl0
0_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Oo/k>c00?o0000olc<c?o<c<`00_o<c<`00ol0003o
/k>cok>c/`04ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01?l0003oIVIVofIVI_l00004
oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l0
0002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>c
ok>c/onc/k?o000000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00008oc<c
<`04o`000?m<C4coC4a<o`0000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<
c<coc<c<00Koc<c<0_l000002onc/k?o0000oiVIVOnIVIWo0000ogmoOol0003oIVIVo`000?m<C4co
000000So<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00005
olc<c0Kooooo0Ol00001ooooo`7ooooo000=ooooo`03oiRHV?lb<S;ooooo01Cooooo00?o0000oooo
ooooool00oooool@oda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0
003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0
003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00KoIVIV00?o0000oda<C?m<C4`05Om<C4`00ol0
003oIVIVofIVIP03ofIVIP03o`000?moOgooOgmo00;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000007
ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o0000ok>c/onc/k<01?nc/k<01Ol0003oVIVIoiVIVOnI
VIWo000000?oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`00
0?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00003ok>c
/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@03o`000?moOgoo
000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP05o`00
0?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`00
00;oVIVI00Oo0000ogmoOol0003oIVIVo`000?m<C4co000000So<c<c00co0000oda<C?m<C4co0000
ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00005olc<c0Kooooo0Ol00001ooooo`7ooooo000=
ooooo`03omgMgOl0003o^[Zj01Cooooo00?o0000ooooooooool00oooool?oda<C003o`000?mVIVKo
IVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o
/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKo
IVIV00KoIVIV00?o0000oda<C?m<C4`05?m<C4`00ol0003oIVIVofIVIP03ofIVIP03o`000?moOgoo
Ogmo00;oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`05ok>c/`03o`000?o<c<co
c<c<00;oc<c<00?o0000ok>c/onc/k<01?nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Co
0000ofIVI_mVIVKo00001Om<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<
00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00002ok>c/`03o`000?o<c<coc<c<
00Ooc<c<00Co0000ok>c/onc/k?o00000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP03o`000?m<
C4co000000Wo<c<c00Co0000oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o
/k>c00?o0000olc<c?o<c<`01_o<c<`02?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo00000_mV
IVH00ol0003oC4a<o`000008oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVI
o`000?nc/k?o00001Oo<c<`6ooooo`7o00000Oooool1ooooo`003Oooool00omEEEGoMgMgodA4A00D
ooooo`03o`000?oooooooooo00?ooooo3om<C4`00ol0003oIVIVofIVIP0:ofIVIP03o`000?moOgoo
Ogmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWo
VIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP06ofIVIP03o`000?m<C4co
C4a<01CoC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`03ogmoO`05o`000?nIVIWo
VIVIoiVIVOl000001onc/k<00ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c00Co/k>c00Go
0000oiVIVOnIVIWoVIVIo`000003ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc
<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co0000oiVI
VOnIVIWo00000onc/k<00ol0003oc<c<olc<c007olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o
0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`03o`000?m<C4co000000;oIVIV
00?o0000ogmoOol000000_nIVIT00ol0003o/k>co`000008olc<c004o`000?nc/k?o/k>co`0000;o
VIVI00Oo0000ogmoOol0003oIVIVo`000?m<C4co000000Wo<c<c00?o0000oda<C?l000000_mVIVH2
o`000005oiVIVOl0003o/k>cok>c/ol000001Oo<c<`6ooooo`7o00000Oooool1ooooo`003?ooool0
1OoMgMgo410@oooooolQ8B7ogMgM01?ooooo00?o0000ooooooooool00oooool=oda<C0;o00003OmV
IVH00ol0003oOgmoogmoO`07ogmoO`;o00003OnIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nI
VIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP07ofIVIP03o`000?m<
C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nI
VIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01Onc/k<01?l0003oc<c<olc<c?o<c<`2o`0000Ko/k>c
00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`05o`000?mVIVKoIVIVofIVI_l000001?m<C4`00ol0
003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl0
1?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Oo0000ok>c/onc/k?o/k>c
o`000?nIVIWo000000;oOgmo00Ko0000ofIVI_mVIVKo0000oda<C?l0000:oc<c<`03o`000?m<C4co
000000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Ko
0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`05o`000?mVIVKo0000oda<C?l000002Olc<c<02ol0
003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o000000Koc<c<1_ooool1o`00007o
oooo0Oooool000cooooo00GoIVIVohN7QoooooooV9RHoeEEE@0Cooooo`;o00001?ooool<oda<C003
o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@0<oiVIV@03
o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmoO`03
o`000?mVIVKoIVIV00OoIVIV00?o0000oda<C?m<C4`05Om<C4`00ol0003oIVIVofIVIP03ofIVIP03
o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`05ok>c/`05
o`000?o<c<coc<c<olc<c?l000001onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Go0000
ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<
C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<
c<`01_o<c<`01ol0003o/k>cok>c/onc/k?o0000oiVIVOl000000_moOgl01_l0003oIVIVofIVI_l0
003oC4a<o`0000[o<c<c00?o0000oda<C?l000000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o
/k>c00?o0000olc<c?o<c<`01_o<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00Go0000
ofIVI_l0003oC4a<o`000009oc<c<`0;o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000
ok>c/ol000001_o<c<`5ooooo`;o00000_ooool000_ooooo00?ok^k^o`000?o^k^h00_ooool00ol0
003ogMgMooooo`0Aooooo`03o`000?oooooooooo00?ooooo3?m<C4`00ol0003oIVIVofIVIP0;ofIV
IP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c
/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP07ofIV
IP03o`000?m<C4coC4a<01GoC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`02ogmo
O`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01Onc/k<01Ol0003oc<c<olc<c?o<c<co
000000Oo/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`05o`000?mVIVKoIVIVofIVI_l00000
1?m<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003o
OgmoogmoOol00002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01ol0003o/k>cok>c/onc
/k?o0000oiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo
<c<c00?o0000oda<C?l000000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<
c?o<c<`01oo<c<`00ol0003o/k>co`000002oiVIV@07o`000?moOgoo0000ofIVI_l0003oC4a<o`00
0009oc<c<`07o`000?m<C4co0000ofIVI_l0003oOgmoo`000002oiVIV@;o00001oo<c<`6ooooo`7o
00000Oooool1ooooo`002oooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo013o
oooo00?o0000ooooooooool00oooool:oda<C0;o00003OmVIVH00ol0003oOgmoogmoO`08ogmoO`03
o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03
o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02?mVIVH00ol0003oC4a<oda<C00Doda<C003
o`000?mVIVKoIVIV00?oIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@02oiVIV@03
o`000?nc/k?o/k>c00Go/k>c00?o0000olc<c?o<c<`00_o<c<`00ol0003o/k>cok>c/`04ok>c/`05
o`000?nIVIWoVIVIoiVIVOl000000omoOgl01Ol0003oIVIVofIVI_mVIVKo000000CoC4a<00?o0000
oc<c<olc<c<01Olc<c<01Ol0003oC4a<oda<C?m<C4co000000?oIVIV00Co0000ogmoOomoOgoo0000
0_nIVIT01?l0003o/k>cok>c/ol00009olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Ko0000ogmo
OomoOgoo0000ofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co0000
0_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`01Ol0003o
/k>co`000?nIVIWo000000;oOgmo00Go0000ofIVI_l0003oC4a<o`000009oc<c<`0;o`000?m<C4co
0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol000001oo<c<`6ooooo`7o00000Oooool1oooo
o`009?ooool00ol0003oooooooooo`03ooooo`WoC4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003o
OgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003o
VIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02?mVIVH00ol0003o
C4a<oda<C00Doda<C003o`000?mVIVKoIVIV00?oIVIV00?o0000ogmoOomoOgl00omoOgl00ol0003o
VIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c00Go/k>c0_l00003olc<c003o`000?nc/k?o/k>c00Co
/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`05o`000?mVIVKoIVIVofIVI_l000000om<C4`0
0ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000omVIVH01?l0003oOgmoogmo
Ool00002oiVIV@04o`000?nc/k?o/k>co`0000Woc<c<00Co0000ok>c/onc/k?o00000_nIVIT01_l0
003oOgmoogmoOol0003oIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<
C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c005
o`000?nc/k?o0000oiVIVOl000000_moOgl01Ol0003oIVIVo`000?m<C4co000000So<c<c00co0000
oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00007olc<c0Kooooo0Ol00001
ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo2?m<C4`00ol0003oIVIVofIVIP0<ofIV
IP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c
/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP08ofIV
IP03o`000?m<C4coC4a<01GoC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`02ogmo
O`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01Onc/k<01_l0003oc<c<olc<c?l0003o
c<c<o`0000Ko/k>c00?o0000oiVIVOnIVIT00_nIVIT01?l0003oOgmoogmoOol00003ofIVIP03o`00
0?m<C4coC4a<00;oC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`00
0?mVIVKoIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<
c004o`000?nc/k?o/k>co`0000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01?l0003oC4a<oda<
C?l00009oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o
0000olc<c?o<c<`01oo<c<`00ol0003o/k>cok>c/`02o`0000;oOgmo00?o0000ofIVI_l000000_m<
C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4co0000ofIVI_l000000_moOgl2o`0000;o/k>c
00?o0000olc<c?o<c<`01Oo<c<`6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003ooooooooo
o`03ooooo`OoC4a<00?o0000ofIVI_mVIVH02omVIVH2o`0000[oOgmo00?o0000oiVIVOnIVIT02onI
VIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02Omo
Ogl00ol0003oIVIVofIVIP08ofIVIP03o`000?m<C4coC4a<01GoC4a<00?o0000ofIVI_mVIVH00omV
IVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<01Onc
/k<01Ol0003oc<c<olc<c?o<c<co000000Oo/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`05
o`000?mVIVKoIVIVofIVI_l000001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<
00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000?o/k>c00?o
0000olc<c?o<c<`01Oo<c<`2o`0000;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl00ol0003oIVIV
o`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH01Ol0003o
Ogmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01_l0003o/k>cok>c/ol0003o
VIVIo`0000;oOgmo00Go0000ofIVI_l0003oC4a<o`000009oc<c<`09o`000?m<C4co0000ofIVI_l0
003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01Oo<c<`6ooooo`7o00000Oooool1
ooooo`009?ooool00ol0003oooooooooo`03ooooo`KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0
003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0
003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo0_l0000;ofIVIP03o`000?m<C4coC4a<
01GoC4a<00?o0000ofIVI_mVIVH00omVIVH01Ol0003oOgmoogmoOomoOgoo000000KoVIVI00?o0000
ok>c/onc/k<01Onc/k<01Ol0003oc<c<olc<c?o<c<co000000Ko/k>c00?o0000oiVIVOnIVIT00_nI
VIT01?l0003oOgmoogmoOol00003ofIVIP03o`000?m<C4coC4a<00;oC4a<00?o0000oc<c<olc<c<0
1Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Go0000oiVIVOnI
VIWoVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002
oiVIV@06o`000?moOgooOgmoo`000?mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`04o`00
0?m<C4coC4a<o`0000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<
00Koc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`05o`000?mVIVKo0000oda<C?l00000
2Olc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<co
c<c<00Goc<c<1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool5oda<
C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0;oiVI
V@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmo
O`03o`000?mVIVKoIVIV00[oIVIV00?o0000oda<C?m<C4`05Om<C4`00ol0003oIVIVofIVIP03ofIV
IP03o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`05ok>c
/`05o`000?o<c<coc<c<olc<c?l000001_nc/k<00ol0003oVIVIoiVIV@02oiVIV@04o`000?moOgoo
Ogmoo`0000?oIVIV00?o0000oda<C?m<C4`00_m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<
C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000?o
/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`03o`000?nIVIWo000000;o
Ogmo00?o0000ofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`00
00;oIVIV00?o0000ogmoOol000000_nIVIT00ol0003o/k>co`000008olc<c006o`000?nc/k?o/k>c
o`000?nIVIWo00000_moOgl01Ol0003oIVIVo`000?m<C4co000000Wo<c<c00Wo0000oda<C?l0003o
IVIVo`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c003o`000?oooooo
oooo00?ooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo1?m<C4`00ol0
003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02_nIVIT2o`00
01So/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV
00[oIVIV00?o0000oda<C?m<C4`05Om<C4`00ol0003oIVIVofIVIP03ofIVIP03o`000?moOgooOgmo
00?oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`05ok>c/`;o00000_o<c<`00ol0
003o/k>cok>c/`05ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01Ol0003oIVIVofIVI_mV
IVKo000000CoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mV
IVKoIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c005
o`000?nc/k?o/k>cok>c/ol000000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<
o`0000Wo<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`03o`000?nIVIWo000000;o/k>c
00?o0000olc<c?o<c<`01_o<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00Go0000ofIV
I_l0003oC4a<o`000009oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o
/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003oooooooooo`03ooooo`7o00000Oooool1ooooo`00
9?ooool00ol0003oooooooooo`03ooooo`?oC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmo
ogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVI
oiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<
oda<C00Foda<C003o`000?mVIVKoIVIV00?oIVIV00?o0000ogmoOomoOgl00omoOgl00ol0003oVIVI
oiVIV@02oiVIV@03o`000?nc/k?o/k>c00Go/k>c00Go0000ok>c/ol0003oc<c<o`000007ok>c/`05
o`000?nIVIWoVIVIoiVIVOl000000omoOgl01Ol0003oIVIVofIVI_mVIVKo000000CoC4a<00?o0000
oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co
0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol0
00000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000Wo<c<c00Ko0000oda<
C?m<C4co0000ofIVI_l00002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<
c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00Go0000ofIVI_l0003oC4a<o`000009oc<c
<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`0
1_o<c<`00ol0003oooooooooo`03ooooo`7o00000Oooool1ooooo`009?ooool2o`0000Cooooo0_m<
C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onI
VIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?mo
Ogl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01GoC4a<00?o0000ofIVI_mVIVH00omV
IVH00ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01_nc
/k<2o`000003ok>c/ol0003o/k>c00Ko/k>c00?o0000oiVIVOnIVIT00_nIVIT01?l0003oOgmoogmo
Ool00003ofIVIP03o`000?m<C4coC4a<00;oC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<
oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0
003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT00ol0003oOgmoo`000002
ofIVIP04o`000?m<C4coC4a<o`0000Wo<c<c00Co0000oda<C?m<C4co00000_mVIVH01Ol0003oOgmo
o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`00ol0003o/k>co`000002oiVIV@07
o`000?moOgoo0000ofIVI_l0003oC4a<o`000009oc<c<`07o`000?m<C4co0000ofIVI_l0003oOgmo
o`000002oiVIV@03o`000?nc/k?o000000Soc<c<00?o0000ooooooooool00oooool2o`0000;ooooo
000Tooooo`03o`000?oooooooooo00?ooooo00?oC4a<o`000?mVIVH03?mVIVH00ol0003oOgmoogmo
O`09ogmoO`03o`000?nIVIWoVIVI00[oVIVI0_l0000Hok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o
0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01GoC4a<00?o
0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o
0000ok>c/onc/k<01_nc/k<01?l0003oc<c<olc<c?l00007ok>c/`03o`000?nIVIWoVIVI00;oVIVI
00?o0000ogmoOomoOgl00_l00002ofIVIP03o`000?m<C4coC4a<00?oC4a<00?o0000oc<c<olc<c<0
1Olc<c<01?l0003oC4a<oda<C?m<C4`2o`0000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01Ol0
003o/k>cok>c/onc/k?o000000Soc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@03o`000?mo
Ogoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<2o`0000;oC4a<00?o0000ofIVI_l00000
0_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Co0000ok>c/ol0003o
VIVI0ol00002ofIVIP03o`000?m<C4co000000Wo<c<c00_o0000oda<C?l0003oIVIVo`000?moOgoo
0000oiVIVOl0003o/k>co`000009olc<c003o`000?oooooooooo00Cooooo0Ol00001ooooo`7ooooo
000Tooooo`03o`000?oooooooooo00?ooooo00?oC4a<o`000?mVIVH02omVIVH00ol0003oOgmoogmo
O`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVI
V@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH03?mVIVH00ol0003oC4a<oda<
C00Doda<C003o`000?mVIVKoIVIV00CoIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVI
V@03oiVIV@03o`000?nc/k?o/k>c00Ko/k>c00Co0000olc<c?o<c<co00001onc/k<00ol0003oVIVI
oiVIV@02oiVIV@04o`000?moOgooOgmoo`0000?oIVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o
<c<coc<c<`05oc<c<`05o`000?m<C4coC4a<oda<C?l000000omVIVH01?l0003oOgmoogmoOol00002
oiVIV@05o`000?nc/k?o/k>cok>c/ol000001oo<c<`00ol0003o/k>cok>c/`02ok>c/`06o`000?nI
VIWoVIVIo`000?moOgoo00000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`07o`000?m<C4coC4a<
oda<C?l0003oIVIVo`000002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01oo<
c<`01ol0003o/k>co`000?nIVIWo0000ogmoOol000000_mVIVH00ol0003oC4a<o`000008oc<c<`0<
o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00002Oo<c<`00ol0003o
ooooooooo`04ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`03o`00
0?mVIVKoIVIV00[oIVIV00?o0000ogmoOomoOgl02?moOgl2o`0000goVIVI00?o0000ok>c/onc/k<0
5_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH0
3?mVIVH00ol0003oC4a<oda<C00Doda<C003o`000?mVIVKoIVIV00CoIVIV00?o0000ogmoOomoOgl0
0omoOgl00ol0003oVIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c00Ko/k>c00Co0000olc<c?o<c<co
00001onc/k<00ol0003oVIVIoiVIV@02oiVIV@04o`000?moOgooOgmoo`0000CoIVIV00?o0000oda<
C?m<C4`00_m<C4`00ol0003o<c<coc<c<`05oc<c<`05o`000?m<C4coC4a<oda<C?l000000omVIVH0
1?l0003oOgmoogmoOol00002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01Ol0003o/k>c
ok>c/onc/k?o000000;oVIVI00Ko0000ogmoOomoOgoo0000ofIVI_l00003oda<C003o`000?lc<c?o
<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`2o`0000;oOgmo00?o0000oiVIVOl000000_nc/k<0
0ol0003oc<c<olc<c007olc<c007o`000?nc/k?o0000oiVIVOl0003oOgmoo`000002ofIVIP04o`00
0?m<C4coC4a<o`0000So<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl000000_nc
/k<00ol0003oc<c<olc<c006olc<c003o`000?nc/k?ooooo00Gooooo0Ol00001ooooo`7ooooo000T
ooooo`03o`000?oooooooooo00?ooooo3?mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWo
VIVI00coVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgoo
Ogmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH2o`0001KoC4a<00?o0000ofIVI_mVIVH01?mVIVH0
0ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01onc/k<3
o`0000So/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`05o`000?mVIVKoIVIVofIVI_l00000
1?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Go0000ofIVI_mVIVKo
IVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01_l0
003o/k>cok>c/onc/k?o0000oiVIV@;o000000GoOgmoo`000?mVIVKoIVIVo`000002oda<C003o`00
0?lc<c?o<c<c00Ko<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00?o0000oiVI
VOl000000_nc/k<00ol0003oc<c<olc<c006olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmo
Ool00002ofIVIP03o`000?m<C4co000000Wo<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000
oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c003o`000?nc/k?ooooo00Gooooo0Ol00001
ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo2omVIVH00ol0003oOgmoogmoO`09ogmo
O`03o`000?nIVIWoVIVI00[oVIVI0_l0000Hok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmo
OomoOgl02?moOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<01GoC4a<00?o0000ofIV
I_mVIVH01?mVIVH00ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c
/onc/k<02Onc/k<00ol0003o/k>cok>c/`06ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl0
1Ol0003oIVIVofIVI_mVIVKo000000CoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<
C002oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03
o`000?o<c<coc<c<00Koc<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo00Co0000
ofIVI_mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`07o`000?m<C4coC4a<oda<C?l0003o
IVIVo`000002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02?l0003o
/k>cok>c/ol0003oVIVIo`000?moOgoo00000_mVIVH00ol0003oC4a<o`000009oc<c<`09o`000?m<
C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0
003o/k>co`000005ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`[o
IVIV00?o0000ogmoOomoOgl02?moOgl2o`0000coVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003o
VIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH03?mVIVH00ol0003o
C4a<oda<C00Eoda<C003o`000?mVIVKoIVIV00CoIVIV00?o0000ogmoOomoOgl00omoOgl00ol0003o
VIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c01;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmo
O`05o`000?mVIVKoIVIVofIVI_l000001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4co
C4a<00;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c
00?o0000olc<c?o<c<`01_o<c<`01ol0003o/k>cok>c/onc/k?o0000oiVIVOl000000_moOgl01?l0
003oIVIVofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Ko0000oda<C?m<C4co0000ofIV
I_l00002ogmoO`04o`000?nIVIWoVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01Oo<c<`01_l0003o
/k>cok>c/ol0003oVIVIo`0000;oOgmo00Go0000ofIVI_l0003oC4a<o`000009oc<c<`09o`000?m<
C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0
003o/k>cok>c/ol00005ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03oooo
o`WoIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c
01Oo/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV
00_oIVIV0_l0000Goda<C003o`000?mVIVKoIVIV00CoIVIV00?o0000ogmoOomoOgl00omoOgl00ol0
003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c017o/k>c00?o0000oiVIVOnIVIT00_nIVIT00ol0
003oOgmoogmoO`02o`0000;oIVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`05oc<c
<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl0
0003ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Co0000ok>c/onc/k?o00000_nIVIT01?l0003oOgmo
ogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000Wo<c<c00Oo0000oda<C?m<C4co0000ofIVI_l0
003oOgmo00;o000000GoVIVIo`000?nc/k?o/k>co`000008olc<c007o`000?nc/k?o/k>co`000?nI
VIWo0000ogmoO`02o`000004ofIVI_l0003oC4a<o`0000Wo<c<c00Wo0000oda<C?l0003oIVIVo`00
0?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c003o`000?nc/k?o000000Ko
oooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo2?mVIVH00ol0003oOgmo
ogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI0_l0000Hok>c/`03o`000?nIVIWoVIVI00_oVIVI
00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<01KoC4a<
00?o0000ofIVI_mVIVH01?mVIVH00ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00?oVIVI
00?o0000ok>c/onc/k<04Onc/k<00ol0003oVIVIoiVIV@02oiVIV@04o`000?moOgooOgmoo`0000?o
IVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`05oc<c<`05o`000?m<C4coC4a<oda<
C?l000000omVIVH01?l0003oOgmoogmoOol00002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002Oo<
c<`01?l0003o/k>cok>c/ol00002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Co0000oda<C?m<
C4co00002Olc<c<02?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo00000_nIVIT01?l0003o/k>c
ok>c/ol00008olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP03o`000?m<
C4co000000Wo<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl000000_nc/k<00ol0
003oc<c<olc<c006olc<c003o`000?nc/k?o000000Kooooo0Ol00001ooooo`7ooooo000Tooooo`03
o`000?oooooooooo00?ooooo1omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_o
VIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00So
Ogmo00?o0000ofIVI_mVIVH03?mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00Co
IVIV00?o0000ogmoOomoOgl00omoOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c017o
/k>c00?o0000oiVIVOnIVIT00_nIVIT01?l0003oOgmoogmoOol00004ofIVIP03o`000?m<C4coC4a<
00;oC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C005o`000?mVIVKoIVIV
ofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Co
0000ok>c/onc/k?o00000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP04o`000?m<C4coC4a<o`00
00Wo<c<c00Co0000oda<C?m<C4co00000_mVIVH2o`0000;oVIVI00Co0000ok>c/onc/k?o00002?o<
c<`02?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo00000_mVIVH00ol0003oC4a<o`000009oc<c
<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000?o/k>c00?o0000olc<c?o<c<`0
1Oo<c<`01?l0003o/k>co`000?nIVIT6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003ooooo
ooooo`03ooooo`KoIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`00
0?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`00
0?mVIVKoIVIV00_oIVIV0_l0000Goda<C0;o00001_mVIVH00ol0003oOgmoogmoO`03ogmoO`03o`00
0?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<04_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?o
Ogmo00Go0000ofIVI_mVIVKoIVIVo`000005oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<
C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo00000onc
/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmo
ogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Co0000oda<C?m<C4co00000_mVIVH0
0ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00So0000ok>c/onc/k?o0000
oiVIVOl0003oOgmoo`0000;oIVIV00?o0000oda<C?l000002Olc<c<02Ol0003oC4a<o`000?mVIVKo
0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/ol0003o
VIVI1_ooool1o`00007ooooo0Oooool002Cooooo0_l00004ooooo`GoIVIV00?o0000ogmoOomoOgl0
2?moOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT0
2onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`0
5om<C4`00ol0003oIVIVofIVIP05ofIVIP03o`000?moOgooOgmo00?oOgmo00?o0000oiVIVOnIVIT0
0onIVIT00ol0003o/k>cok>c/`0Bok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01Ol0003o
IVIVofIVI_mVIVKo000000GoC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C002oda<
C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<
c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;o
IVIV00Co0000oda<C?m<C4co00002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo
000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`02?l0003o/k>cok>c/ol0003oVIVIo`000?mo
Ogoo00000_mVIVH00ol0003oC4a<o`000009oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`00
0?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>co`000?nIVIWo000000Co
oooo0_l00002ooooo`009?ooool00ol0003oooooooooo`03ooooo`CoIVIV00?o0000ogmoOomoOgl0
2?moOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT0
2onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00[oIVIV00?o0000oda<C?m<C4`0
5om<C4`00ol0003oIVIVofIVIP05ofIVIP03o`000?moOgooOgmo00?oOgmo00?o0000oiVIVOnIVIT0
0onIVIT00ol0003o/k>cok>c/`0Bok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl00ol0003o
IVIVofIVIP02ofIVIP03o`000?m<C4coC4a<00;oC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003o
C4a<oda<C002oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00003
ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000onIVIT01_l0003oOgmoogmo
Ool0003oIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIV
IP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00001oo<c<`01?l0003o/k>cok>c/ol0
0002oiVIV@03o`000?moOgoo000000;oIVIV00?o0000oda<C?l000002?lc<c<03?l0003oC4a<oda<
C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Woc<c<00Go0000ok>c/ol0003oVIVI
o`000005ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`?oIVIV00?o
0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o
0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00[oIVIV00?o
0000oda<C?m<C4`06?m<C4`00ol0003oIVIVofIVIP05ofIVIP03o`000?moOgooOgmo00?oOgmo00?o
0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0Bok>c/`05o`000?nIVIWoVIVIoiVIVOl00000
0omoOgl01Ol0003oIVIVofIVI_mVIVKo000000GoC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003o
C4a<oda<C002oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00004
ok>c/`03o`000?o<c<coc<c<00Goc<c<00Go0000ok>c/onc/k?o/k>co`000003oiVIV@03o`000?mo
Ogoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP03
o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`02?l0003o/k>cok>c/ol0003o
VIVIo`000?moOgoo00000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`09o`000?m<C4co0000ofIV
I_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>co`00
0?nIVIWo000000Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo0omV
IVH00ol0003oOgmoogmoO`07ogmoO`;o00003OnIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nI
VIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0:ofIVIP;o00006?m<
C4`2o`0000OoIVIV00?o0000ogmoOomoOgl00omoOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc
/k?o/k>c01;o/k>c00?o0000oiVIVOnIVIT00_nIVIT01?l0003oOgmoogmoOol00004ofIVIP03o`00
0?m<C4coC4a<00;oC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C005o`00
0?mVIVKoIVIVofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<
00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@06o`000?moOgooOgmoo`000?mVIVKo0000
0om<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol0
00000_nIVIT01?l0003o/k>cok>c/ol00008olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmo
Ool00002ofIVIP03o`000?m<C4co000000Wo<c<c00_o0000oda<C?l0003oIVIVo`000?moOgoo0000
oiVIVOl0003o/k>co`000009olc<c005o`000?nc/k?o0000oiVIVOl000001_ooool1o`00007ooooo
0Oooool002Cooooo00?o0000ooooooooool00oooool2ofIVIP03o`000?moOgooOgmo00OoOgmo00?o
0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o
0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<01SoC4a<00?o
0000ofIVI_mVIVH01_mVIVH00ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o
0000ok>c/onc/k<04Onc/k<00ol0003oVIVIoiVIV@03oiVIV@04o`000?moOgooOgmoo`0000CoIVIV
00?o0000oda<C?m<C4`00_m<C4`00ol0003o<c<coc<c<`05oc<c<`05o`000?m<C4coC4a<oda<C?l0
00000omVIVH01Ol0003oOgmoogmoOomoOgoo000000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008
olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01_l0003oOgmoogmoOol0003oIVIVo`0000?o
C4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo0000
00;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`02?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo
00000_mVIVH00ol0003oC4a<o`000009oc<c<`0;o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nI
VIWo0000ok>c/ol000002Oo<c<`01Ol0003o/k>co`000?nIVIWo000000Kooooo0Ol00001ooooo`7o
oooo000Tooooo`03o`000?oooooooooo00?ooooo00?oIVIVo`000?moOgl02OmoOgl00ol0003oVIVI
oiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmo
ogmoO`09ogmoO`03o`000?mVIVKoIVIV00[oIVIV00?o0000oda<C?m<C4`06?m<C4`00ol0003oIVIV
ofIVIP06ofIVIP03o`000?moOgooOgmo00?oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>c
ok>c/`0Bok>c/`03o`000?nIVIWoVIVI00;oVIVI00Co0000ogmoOomoOgoo00001?mVIVH00ol0003o
C4a<oda<C002oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003o
IVIVofIVI_l00003ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`0
1Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Ko0000ogmoOomoOgoo0000ofIVI_l00003oda<C003
o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH01_l0003oOgmoogmoOol0003o
VIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02?l0003o/k>cok>c/ol0003oVIVIo`000?mo
Ogoo00000_mVIVH00ol0003oC4a<o`000009oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`00
0?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003o/k>cok>c/`02o`000003ogmo
Oooooooooooo00Cooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo00?o
0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o
0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00[oIVIV0_l0
000Ioda<C003o`000?mVIVKoIVIV00KoIVIV00?o0000ogmoOomoOgl00omoOgl00ol0003oVIVIoiVI
V@03oiVIV@03o`000?nc/k?o/k>c01;o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmo
OomoOgoo000000?oIVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`00
0?m<C4coC4a<00?oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01Ol0003oVIVIoiVIVOnIVIWo0000
00?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000
ogmoOol000000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Co0000oda<C?m<C4co0000
0_mVIVH00ol0003oOgmoo`000002oiVIV@03o`000?nc/k?o000000Woc<c<00So0000ok>c/onc/k?o
0000oiVIVOl0003oOgmoo`0000;oIVIV00?o0000oda<C?l000002?lc<c<02_l0003oC4a<oda<C?l0
003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Oo0000ok>c
/ol0003oVIVIo`000?moOgoo000000Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooo
oooo00?ooooo2_moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000
oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00[oIVIV00?o0000
oda<C?m<C4`06?m<C4`00ol0003oIVIVofIVIP07ofIVIP03o`000?moOgooOgmo00?oOgmo00?o0000
oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0Bok>c/`05o`000?nIVIWoVIVIoiVIVOl000001?mo
Ogl01Ol0003oIVIVofIVI_mVIVKo000000GoC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<
oda<C003oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000003ok>c
/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01_l0003oVIVIoiVIVOl0003o
Ogmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`000007oc<c<`07o`000?m<C4coC4a<oda<C?l0
003oIVIVo`000002ogmoO`06o`000?nIVIWoVIVIo`000?nc/k?o00002Oo<c<`02?l0003o/k>cok>c
/ol0003oVIVIo`000?moOgoo00000_mVIVH00ol0003oC4a<o`000008oc<c<`0<o`000?m<C4coC4a<
o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00002Oo<c<`01ol0003o/k>co`000?nIVIWo
0000ogmoOol000001Oooool1o`00007ooooo0Oooool001_ooooo0_l000000ol@413oooooooooo`04
ooooo`03o`000?oooooooooo00?ooooo2OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o
/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKo
IVIV00[oIVIV00?o0000oda<C?m<C4`06?m<C4`00ol0003oIVIVofIVIP07ofIVIP03o`000?moOgoo
Ogmo00?oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0Bok>c/`03o`000?nIVIWo
VIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`000003ofIVIP03o`000?m<C4coC4a<00?oC4a<00?o
0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C003oda<C004o`000?mVIVKoIVIVo`0000;oOgmo
00Go0000oiVIVOnIVIWoVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc
/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Co0000oda<C?m<C4co00002?lc
<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o
00002?o<c<`02?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo00000_mVIVH00ol0003oC4a<o`00
0009oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<
c?o<c<`01_o<c<`00ol0003o/k>cok>c/`02o`000003ogmoOol0003ooooo00Gooooo0Ol00001oooo
o`7ooooo000Looooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool8ogmoO`03
o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03
o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02_mVIVH2o`0001WoC4a<00?o0000ofIVI_mV
IVH01omVIVH00ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc
/k<04onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0
003oC4a<oda<C003oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0
003oIVIVofIVI_mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<
c005olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP05
o`000?m<C4coC4a<oda<C?l000002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP05o`000?moOgoo
0000oiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c008o`000?nc/k?o/k>co`000?nIVIWo
0000ogmoOol00002ofIVIP03o`000?m<C4co000000Wo<c<c00Wo0000oda<C?l0003oIVIVo`000?mo
Ogoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c003o`000?nc/k?o/k>c00;o0000
00?oOgmoo`000?ooool01Oooool1o`00007ooooo0Oooool001Wooooo1Ol00006ooooo`?o00000ooo
ool7ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVI
V@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<oda<
C00Hoda<C003o`000?mVIVKoIVIV00OoIVIV00?o0000ogmoOomoOgl01?moOgl00ol0003oVIVIoiVI
V@03oiVIV@03o`000?nc/k?o/k>c01;o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmo
OomoOgoo000000?oIVIV00?o0000oda<C?m<C4`01?m<C4`00ol0003o<c<coc<c<`04oc<c<`03o`00
0?m<C4coC4a<00;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`00
00Co/k>c00?o0000olc<c?o<c<`01Oo<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000
ogmoOomoOgoo00000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Co0000oda<C?m<C4co
00000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`02?l0
003o/k>cok>c/ol0003oVIVIo`000?moOgoo00000_mVIVH00ol0003oC4a<o`000009oc<c<`09o`00
0?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`0
0ol0003o/k>cok>c/`02o`000003ogmoOol0003ooooo00?ooooo0ol00002ooooo`006Oooool01?m4
A4CogMgMooooool00007ooooo`03o`000?oooooooooo00?ooooo1_moOgl00ol0003oVIVIoiVIV@0;
oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09
ogmoO`03o`000?mVIVKoIVIV00[oIVIV00?o0000oda<C?m<C4`06?m<C4`00ol0003oIVIVofIVIP07
ofIVIP03o`000?moOgooOgmo00CoOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0C
ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01Ol0003oIVIVofIVI_mVIVKo000000KoC4a<
00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C002oda<C005o`000?mVIVKoIVIVofIVI_l0
00000_moOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c
/onc/k?o00000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<C?l00000
2?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc
/k?o00002?o<c<`02?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo00000_mVIVH01?l0003oC4a<
oda<C?l00008oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o
0000olc<c?o<c<`01oo<c<`01?l0003o/k>co`000?nIVIT2o`000003ofIVI_oooooooooo00Cooooo
0Ol00001ooooo`7ooooo000Iooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0
0oooool5ogmoO`03o`000?nIVIWoVIVI00[oVIVI0_l0000Hok>c/`03o`000?nIVIWoVIVI00_oVIVI
00?o0000ogmoOomoOgl02?moOgl2o`0000goIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIV
ofIVIP07ofIVIP03o`000?moOgooOgmo00CoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>c
ok>c/`0Bok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`000003ofIVIP03
o`000?m<C4coC4a<00?oC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004
o`000?mVIVKoIVIVo`0000?oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c007
olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01?l0003oC4a<
oda<C?l00009oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Co0000ogmoOol0003oVIVI0_l00002
ok>c/`03o`000?o<c<coc<c<00Koc<c<00Wo0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mV
IVH00_l000000om<C4co0000oc<c<`07oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0
003oVIVIo`000?nc/k?o00002_o<c<`01ol0003o/k>co`000?l0003oOgmoo`000?mVIVH01_ooool1
o`00007ooooo0Oooool001[ooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`03oooo
o`CoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI
00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<
01OoC4a<00?o0000ofIVI_mVIVH01omVIVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI
00CoVIVI00?o0000ok>c/onc/k<04_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000CoOgmo00Go0000
ofIVI_mVIVKoIVIVo`000005oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00om<
C4`01?l0003oIVIVofIVI_l00002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000onc/k<00ol0003o
c<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002
ofIVIP04o`000?m<C4coC4a<o`0000Wo<c<c00Co0000oda<C?m<C4co00000_mVIVH2o`0000;oVIVI
00Go0000ok>c/onc/k?o/k>co`000008olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0
003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`00
0?moOgoo0000oiVIVOl0003o/k>co`0000[oc<c<00So0000ok>c/ol0003o0000ogmoOol0003oIVIV
o`0000Gooooo0Ol00001ooooo`7ooooo000Jooooo`03onk^k_m4A4Co000000Oooooo00?o0000oooo
ooooool00oooool3ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0
003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH03?mVIVH00ol0
003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00OoIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0
003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c01;o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0
003oOgmoogmoOomoOgoo000000?oIVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`05
oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000omoOgl01Ol0003oVIVIoiVI
VOnIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;o
VIVI00Co0000ogmoOomoOgoo00000_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`04o`000?m<C4co
C4a<o`0000;oIVIV00Go0000ogmoOol0003oVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<
00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c
<`06oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl2o`0000;o/k>c00?o0000olc<c?o<
c<`01oo<c<`01?l0003o/k>co`000?nIVIT2o`0000;oIVIV00?o0000ooooooooool00oooool1o`00
007ooooo0Oooool001_ooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`03ooooo`;o
Ogmo00?o0000oiVIVOnIVIT02_nIVIT2o`0001So/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003o
OgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV0_l0000Ioda<C003o`000?mVIVKoIVIV00So
IVIV00?o0000ogmoOomoOgl01?moOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c01;o
/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000CoIVIV00?o0000oda<
C?m<C4`00om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00;oC4a<00Go0000ofIV
I_mVIVKoIVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000onc/k<00ol0003oc<c<olc<
c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP04
o`000?m<C4coC4a<o`0000So<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00?o
0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c00:o`000?nc/k?o/k>co`000?nIVIWo
0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02_l0003oC4a<oda<C?l0
003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c
/onc/k?o0000oiVIV@02o`000003ofIVI_l0003ooooo00Gooooo0Ol00001ooooo`7ooooo000Toooo
o`03o`000?oooooooooo00?ooooo00?oOgmoo`000?nIVIT03?nIVIT00ol0003o/k>cok>c/`0Fok>c
/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0<ofIV
IP03o`000?m<C4coC4a<01KoC4a<0_l0000;ofIVIP03o`000?moOgooOgmo00CoOgmo00?o0000oiVI
VOnIVIT00onIVIT00ol0003o/k>cok>c/`0Cok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000ogmo
OomoOgooOgmoo`000004ofIVIP03o`000?m<C4coC4a<00?oC4a<00?o0000oc<c<olc<c<01?lc<c<0
0ol0003oC4a<oda<C002oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01Ol0003oVIVIoiVI
VOnIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;o
VIVI00?o0000ogmoOol000000omVIVH01?l0003oC4a<oda<C?l00008oc<c<`07o`000?m<C4coC4a<
oda<C?l0003oIVIVo`000002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01oo<
c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o
<c<c00Ko<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0
003oc<c<olc<c006olc<c005o`000?nc/k?o/k>co`000?nIVIT00_l000000omVIVKo0000ooooo`05
ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`03o`000?nIVIWoVIVI
00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo
00SoOgmo00?o0000ofIVI_mVIVH03?mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV
00[oIVIV00?o0000ogmoOomoOgl01?moOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c
01?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000
oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00;oC4a<00Go0000
ofIVI_mVIVKoIVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0003oc<c<
olc<c005olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIV
IP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo
00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c00:o`000?nc/k?o/k>co`000?nI
VIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01olc<c<00ol0003oC4a<o`00
0002ofIVIP;o000000GoVIVIo`000?nc/k?o/k>co`000009olc<c006o`000?nc/k?o0000oiVIVOl0
003oOgmo0_l000000om<C4coooooooooo`04ooooo`7o00000Oooool1ooooo`009?ooool00ol0003o
ooooooooo`03ooooo`goVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03
o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH2o`0001SoC4a<00?o0000ofIVI_mV
IVH02OmVIVH2o`0000KoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`0Cok>c/`05
o`000?nIVIWoVIVIoiVIVOl000001?moOgl01Ol0003oIVIVofIVI_mVIVKo000000GoC4a<0_l00005
oc<c<`03o`000?m<C4coC4a<00?oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`04o`000?nI
VIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`00
0?nIVIWoVIVIo`0000;oOgmo00?o0000ofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`07
o`000?m<C4coC4a<oda<C?l0003oIVIVo`000002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000
olc<c?o<c<`01oo<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<
C003o`000?lc<c?o<c<c00Oo<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00000
0_nc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>co`000?nIVIT00_l000000omVIVKo
0000oda<C006ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`_oVIVI
0_l0000Hok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIV
ofIVIP0<ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmo
ogmoO`05ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<04onc/k<01Ol0003oVIVI
oiVIVOnIVIWo000000CoOgmo00Go0000ofIVI_mVIVKoIVIVo`000005oda<C003o`000?lc<c?o<c<c
00Co<c<c00?o0000oda<C?m<C4`00om<C4`01?l0003oIVIVofIVI_l00003ogmoO`04o`000?nIVIWo
VIVIo`0000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nI
VIWoVIVIo`0000;oOgmo00?o0000ofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`07o`00
0?m<C4coC4a<oda<C?l0003oIVIVo`000002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<
c?o<c<`01oo<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003
o`000?lc<c?o<c<c00Oo<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl000000_nc
/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>co`000?nIVIT00_l000000omVIVKo0000
oda<C006ooooo`7o00000Oooool1ooooo`009?ooool2o`0000Cooooo2_nIVIT00ol0003o/k>cok>c
/`0Gok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIV
IP0<ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmo
O`05ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<04onc/k<00ol0003oVIVIoiVI
V@02oiVIV@05o`000?moOgooOgmoogmoOol000000omVIVH00ol0003oC4a<oda<C003oda<C003o`00
0?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;o
Ogmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c
00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl00ol0003oIVIVo`000003oda<C003o`000?lc<c?o
<c<c00Ko<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00?o0000oiVIVOl00000
0onc/k<00ol0003oc<c<olc<c006olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003o
IVIVo`0000;oC4a<00?o0000oc<c<olc<c<01olc<c<00ol0003oC4a<oda<C002o`000007ogmoOol0
003oVIVIoiVIVOl0003o/k>co`000008olc<c00;o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0
003oIVIVo`000?m<C4`01Oooool2o`0000;ooooo000Tooooo`03o`000?oooooooooo00?ooooo2OnI
VIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?mo
Ogl00ol0003oIVIVofIVIP0;ofIVIP;o00005om<C4`2o`0000coIVIV00?o0000ogmoOomoOgl01Omo
Ogl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT00_nI
VIT01Ol0003oOgmoogmoOomoOgoo000000CoIVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o<c<c
oc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Co0000ofIVI_mVIVKo00000omoOgl01?l0003o
VIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Goc<c<00Go0000ok>c/onc/k?o/k>co`000003
oiVIV@03o`000?moOgoo000000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`07o`000?m<
C4coC4a<oda<C?l0003oIVIVo`000002ogmoO`03o`000?nIVIWo000000;o/k>c0_l00007olc<c00;
o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<c
oc<c<`06oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o
0000olc<c?o<c<`01_o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003o
C4a<o`0000Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo2?nIVIT2
o`0001So/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKo
IVIV00coIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0:ofIVIP03o`000?moOgoo
Ogmo00GoOgmo00?o0000oiVIVOnIVIT01OnIVIT00ol0003o/k>cok>c/`0Cok>c/`03o`000?nIVIWo
VIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`000004ofIVIP03o`000?m<C4coC4a<00?oC4a<00?o
0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C003oda<C004o`000?mVIVKoIVIVo`0000?oOgmo
00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c005olc<c005o`000?nc/k?o/k>cok>c
/ol000000onIVIT00ol0003oOgmoo`000002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<0
2Ol0003oC4a<oda<C?m<C4co0000ofIVI_l0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`00
00Soc<c<00_o0000ok>c/onc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003
o`000?lc<c?o<c<c00Ko<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000
0_nc/k<00ol0003oc<c<olc<c006olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003o
IVIVo`000?m<C4co00001Oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00ooo
ool7oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmo
O`08ogmoO`03o`000?mVIVKoIVIV00coIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIV
IP0:ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT01OnIVIT00ol0003o/k>cok>c
/`0Cok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`000004ofIVIP03o`00
0?m<C4coC4a<00?oC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C003oda<C004o`00
0?mVIVKoIVIVo`0000?oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c006olc<
c004o`000?nc/k?o/k>co`0000?oVIVI00?o0000ogmoOol000000_mVIVH01Ol0003oC4a<oda<C?m<
C4co000000So<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00?o0000oiVIVOl0
00000_nc/k<00ol0003oc<c<olc<c006olc<c009o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000?mo
Ogoo000000;oIVIV00?o0000oda<C?l000002?lc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;o
Ogmo0_l00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003o
Ogmoo`000?mVIVKo0000oda<C?l00006ooooo`7o00000Oooool1ooooo`009?ooool00ol0003ooooo
ooooo`03ooooo`KoVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`00
0?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH2o`0001OoC4a<0_l0000<ofIVIP03o`00
0?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT01OnIVIT00ol0003o/k>cok>c/`0Cok>c/`03o`00
0?nIVIWoVIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`000004ofIVIP03o`000?m<C4coC4a<00Co
C4a<00?o0000oc<c<olc<c<00olc<c<00ol0003oC4a<oda<C003oda<C005o`000?mVIVKoIVIVofIV
I_l000000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000?o/k>c0_l00007olc<c005o`000?nc/k?o
/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<C?l0
00002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c
/onc/k?o00002?o<c<`02ol0003o/k>cok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000
00;oC4a<00?o0000oc<c<olc<c<01_lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000
oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003o
Ogmoo`000?mVIVKo0000oda<C?l00006ooooo`7o00000Oooool1ooooo`009?ooool00ol0003ooooo
ooooo`03ooooo`KoVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`00
0?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`00
0?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@05oiVIV@03o`00
0?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000Co
IVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?o
C4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000onc/k<0
0ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmo
Ool00002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01?l0003oC4a<oda<C?l00002ofIV
IP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`02ol0003o/k>cok>c/onc
/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02_l0
003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ko
c<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00006ooooo`7o
00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`GoVIVI00?o0000ok>c/onc/k<0
5_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH0
2_mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl0
1OmoOgl00ol0003oVIVIoiVIV@05oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT0
0onIVIT01?l0003oOgmoogmoOol00004ofIVIP03o`000?m<C4coC4a<00CoC4a<00?o0000oc<c<olc
<c<01?lc<c<00ol0003oC4a<oda<C003oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Go0000oiVI
VOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`00
0002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`04
o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00008
olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl00ol0003oIVIVo`000002oda<C003o`00
0?lc<c?o<c<c00Ko<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c
/ol00009olc<c005o`000?nc/k?o/k>co`000?nIVIT00_l00002ofIVIP03o`000?m<C4co000000Ko
oooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo1?nIVIT00ol0003o/k>c
ok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIV
ofIVIP0:ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003oOgmo
ogmoO`06ogmoO`03o`000?nIVIWoVIVI00GoVIVI00?o0000ok>c/onc/k<04onc/k<00ol0003oVIVI
oiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol000001?mVIVH00ol0003oC4a<oda<C003oda<C003
o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00om<C4`01Ol0003oIVIVofIVI_mVIVKo0000
00;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000
ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Go0000oda<C?m<C4co
C4a<o`000008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0
003o/k>cok>c/ol00008olc<c00;o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIV
I_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`03o`000?m<C4co000000;oIVIV0_l000001OnI
VIWo0000ok>c/onc/k?o000000Woc<c<00co0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0
003oC4a<o`000?lc<c<6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03oooo
o`?oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo
00WoOgmo00?o0000ofIVI_mVIVH02_mVIVH2o`0001OoC4a<0_l0000=ofIVIP03o`000?moOgooOgmo
00KoOgmo00?o0000oiVIVOnIVIT01OnIVIT00ol0003o/k>cok>c/`0Cok>c/`03o`000?nIVIWoVIVI
00;oVIVI00?o0000ogmoOomoOgl00_moOgl01Ol0003oIVIVofIVI_mVIVKo000000KoC4a<00?o0000
oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C003oda<C004o`000?mVIVKoIVIVo`0000?oOgmo00Co
0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol0
00000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000Wo<c<c00Co0000
oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<
00Co0000ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c
<olc<c<01olc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c/`03o`00
0?o<c<coc<c<00Koc<c<00go0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<
C?l0003o<c<c00Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo0_nI
VIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02Omo
Ogl00ol0003oIVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH03?mV
IVH00ol0003oOgmoogmoO`06ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc/k<04onc
/k<00ol0003oVIVIoiVIV@02oiVIV@03o`000?moOgooOgmo00;oOgmo00Go0000ofIVI_mVIVKoIVIV
o`000006oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00om<C4`01?l0003oIVIV
ofIVI_l00003ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0
003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo00000_m<
C4`00ol0003o<c<coc<c<`07oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Go0000ogmoOol0003o
VIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT01Ol0
003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01olc<c<02Ol0003oC4a<o`000?mV
IVKo0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00go0000ok>c/onc
/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l0003o<c<c00Kooooo0Ol00001ooooo`7o
oooo000Tooooo`03o`000?oooooooooo00?ooooo00?oVIVIo`000?nc/k<05onc/k<00ol0003oVIVI
oiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<
oda<C00Foda<C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl01omoOgl00ol0003oVIVI
oiVIV@05oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT00_nIVIT00ol0003oOgmo
ogmoO`02ogmoO`05o`000?mVIVKoIVIVofIVI_l000001_m<C4`00ol0003o<c<coc<c<`04oc<c<`03
o`000?m<C4coC4a<00?oC4a<00Co0000ofIVI_mVIVKo00000omoOgl01?l0003oVIVIoiVIVOl00004
ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?mo
OgooOgmoo`0000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<01?l0003oC4a<oda<C?l00002ofIV
IP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`02_l0003o/k>cok>c/ol0
003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c00?o0000oda<
C?m<C4`00_l000001omoOgoo0000oiVIVOnIVIWo0000ok>c/ol000002?o<c<`03?l0003o/k>cok>c
/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000;o<c<c1_ooool1o`00007ooooo0Ooo
ool002Cooooo0_l00004ooooo`03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT0
0ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00[oIVIV0_l0000Hoda<C003o`000?mVIVKo
IVIV00_oIVIV00?o0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@05oiVIV@03o`000?nc/k?o
/k>c01?o/k>c00?o0000oiVIVOnIVIT00onIVIT01Ol0003oOgmoogmoOomoOgoo000000CoIVIV00?o
0000oda<C?m<C4`00om<C4`2o`0000Go<c<c00?o0000oda<C?m<C4`00om<C4`01Ol0003oIVIVofIV
I_mVIVKo000000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Go
c<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKo0000
o`0000;oC4a<00?o0000oc<c<olc<c<01olc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?mo
Ogoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@05
o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0:o`000?m<C4coC4a<
o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`03?l0003o
/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000;o<c<c1Oooool2o`0000;o
oooo000Tooooo`03o`000?oooooooooo00?ooooo6?nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`00
0?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<oda<C00Goda<C003o`00
0?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@06oiVIV@03o`00
0?nc/k?o/k>c01;o/k>c00?o0000oiVIVOnIVIT01?nIVIT01Ol0003oOgmoogmoOomoOgoo000000Co
IVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?o
C4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000onc/k<0
0ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmo
Ool00002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01ol0003oC4a<oda<C?m<C4co0000
ofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co
0000ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc
<c<01_lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`00
0?o<c<coc<c<00Koc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<
C?l00002oc<c<`Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo5onc
/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02_mV
IVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl01omo
Ogl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT00onI
VIT01Ol0003oOgmoogmoOomoOgoo000000CoIVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o<c<c
oc<c<`04oc<c<`03o`000?m<C4coC4a<00CoC4a<00Co0000ofIVI_mVIVKo00000_moOgl01Ol0003o
VIVIoiVIVOnIVIWo000000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c
/`04o`000?nIVIWoVIVIo`0000;oOgmo00?o0000ofIVI_l000000om<C4`00ol0003o<c<coc<c<`07
oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c
/ol00009olc<c003o`000?nc/k?o000000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003
o`000?lc<c?o<c<c00Ko<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`;o00000_nc/k<0
0ol0003oc<c<olc<c006olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`00
0?m<C4co00000olc<c<6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03oooo
oaKo/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV
00[oIVIV0_l0000Hoda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl01omoOgl00ol0
003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0
003oOgmoogmoO`02ogmoO`05o`000?mVIVKoIVIVofIVI_l000001_m<C4`00ol0003o<c<coc<c<`03
oc<c<`03o`000?m<C4coC4a<00CoC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`05o`000?nI
VIWoVIVIoiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol0
00000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<0
1Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o0000ogmoOol000000_nIVIT00ol0003o/k>co`00
000:olc<c003o`000?nc/k?o000000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`00
0?lc<c?o<c<c00Ko<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc
/k<00ol0003oc<c<olc<c006olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIV
o`000?m<C4co00000olc<c<6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03
oooooaGo/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKo
IVIV00[oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgoo
Ogmo00OoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`0Dok>c/`03o`000?nIVIWo
VIVI00?oVIVI00?o0000ogmoOomoOgl00_moOgl01Ol0003oIVIVofIVI_mVIVKo000000KoC4a<00?o
0000oc<c<olc<c<00olc<c<00ol0003oC4a<oda<C004oda<C005o`000?mVIVKoIVIVofIVI_l00000
0_moOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc
/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`00
0008oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH00ol0003oOgmoo`000002oiVIV@03o`00
0?nc/k?o000000[oc<c<00?o0000ok>c/ol000000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;o
C4a<00?o0000oc<c<olc<c<01_lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVI
VOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmo
o`000?mVIVKo0000oda<C?l00003oc<c<`Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oo
oooooooo00?ooooo5?nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o
0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00_oIVIV00?o
0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c01Co/k>c00?o
0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`02ogmoO`05o`000?mVIVKoIVIVofIVI_l00000
1_m<C4`00ol0003o<c<coc<c<`03oc<c<`03o`000?m<C4coC4a<00CoC4a<00Go0000ofIVI_mVIVKo
IVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<
c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP05o`000?m<
C4coC4a<oda<C?l000002Olc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;o
VIVI00Co0000ok>c/onc/k?o00002Oo<c<`00ol0003o/k>co`000002oiVIV@05o`000?moOgoo0000
ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV0_l0
00001OnIVIWo0000ok>c/onc/k?o000000Soc<c<00Co0000ok>c/onc/k?o/k>c0_l000001_moOgoo
0000ofIVI_l0003oC4a<o`0000Co<c<c1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000oooo
ooooool00ooooolCok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl2o`00
00goIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo
00SoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`0Cok>c/`03o`000?nIVIWoVIVI
00?oVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP02ofIVIP03o`000?m<C4coC4a<
00CoC4a<00?o0000oc<c<olc<c<00_lc<c<2o`0000GoC4a<00Go0000ofIVI_mVIVKoIVIVo`000003
ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c
/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01Ol0003oC4a<oda<C?m<C4co0000
00Wo<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000;o/k>c
00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000ofIV
I_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmo
Ool0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`03?l0003o/k>cok>c/ol0003oVIVI
o`000?moOgoo0000ofIVI_l0003oC4a<o`0000Co<c<c1_ooool1o`00007ooooo0Oooool002Cooooo
00?o0000ooooooooool00ooooolBok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl0
2?moOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH0
2omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc/k<0
5?nc/k<00ol0003oVIVIoiVIV@03oiVIV@03o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH0
0_mVIVH00ol0003oC4a<oda<C003oda<C003o`000?lc<c?o<c<c00?o<c<c00?o0000oda<C?m<C4`0
1?m<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0
003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol0
0002ofIVIP05o`000?m<C4coC4a<oda<C?l000002Olc<c<01_l0003oC4a<oda<C?l0003oIVIVo`00
00;oOgmo00?o0000oiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>c
o`0000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00[o
0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006
olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co00001?lc<c<6
ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03oooooa7o/k>c00?o0000oiVI
VOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00coIVIV00?o0000oda<
C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVI
VOnIVIT01_nIVIT00ol0003o/k>cok>c/`0Dok>c/`03o`000?nIVIWoVIVI00?oVIVI00?o0000ogmo
OomoOgl00_moOgl00ol0003oIVIVofIVIP02ofIVIP03o`000?m<C4coC4a<00CoC4a<00?o0000oc<c
<olc<c<00_lc<c<00ol0003oC4a<oda<C005oda<C004o`000?mVIVKoIVIVo`0000?oOgmo00Co0000
oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol00000
0_nIVIT01?l0003oOgmoogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<C?l000002Olc<c<01_l0
003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo00000_nc/k<00ol0003oc<c<
olc<c007olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o
0000oc<c<olc<c<01olc<c<00ol0003oC4a<oda<C002o`000007ogmoOol0003oVIVIoiVIVOl0003o
/k>co`000008olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co
00001Olc<c<6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03oooooa3o/k>c
00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV
0_l0000Hoda<C003o`000?mVIVKoIVIV00[oIVIV0_l0000:ogmoO`03o`000?nIVIWoVIVI00KoVIVI
00?o0000ok>c/onc/k<05?nc/k<00ol0003oVIVIoiVIV@03oiVIV@03o`000?moOgooOgmo00;oOgmo
00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C005oda<C003o`000?lc<c?o<c<c00;o<c<c
00?o0000oda<C?m<C4`01?m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Go0000oiVIVOnI
VIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0
003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc
<c<01?l0003oC4a<oda<C?l00002ofIVIP06o`000?moOgooOgmoo`000?nIVIWo00000onc/k<00ol0
003oc<c<olc<c006olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl00ol0003oIVIVo`00
0002oda<C003o`000?lc<c?o<c<c00Ko<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`00
0?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000
ogmoOol0003oIVIVo`000?m<C4co00001Olc<c<6ooooo`7o00000Oooool1ooooo`009?ooool2o`00
00Cooooo3onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIV
I_mVIVH03?mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00[oIVIV00?o0000ogmo
OomoOgl02OmoOgl00ol0003oVIVIoiVIV@07oiVIV@03o`000?nc/k?o/k>c01Co/k>c00?o0000oiVI
VOnIVIT00onIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<
C?m<C4`01Om<C4`00ol0003o<c<coc<c<`02oc<c<`03o`000?m<C4coC4a<00CoC4a<00Go0000ofIV
I_mVIVKoIVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0003oc<c<olc<
c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIV
ofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH01_l0
003oOgmoogmoOol0003oVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01_l0003o/k>cok>c
/ol0003oVIVIo`0000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0:
o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`0
1_o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000Go<c<c
1Oooool2o`0000;ooooo000Tooooo`03o`000?oooooooooo00?ooooo3_nc/k<00ol0003oVIVIoiVI
V@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH03?mVIVH00ol0003oC4a<oda<
C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVI
V@07oiVIV@03o`000?nc/k?o/k>c01Co/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmo
O`02ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01Om<C4`00ol0003o<c<coc<c
<`02oc<c<`03o`000?m<C4coC4a<00CoC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`04o`00
0?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04
o`000?nIVIWoVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06
oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000?o/k>c
00?o0000olc<c?o<c<`01_o<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00?o0000ofIV
I_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_mo
Ogl2o`0000;o/k>c00?o0000olc<c?o<c<`01oo<c<`00ol0003o/k>co`000002oiVIV@;o000000Go
IVIVo`000?m<C4coC4a<o`000005oc<c<`Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oo
oooooooo00?ooooo3Onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o
0000ofIVI_mVIVH02omVIVH2o`0001SoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmo
O`08ogmoO`03o`000?nIVIWoVIVI00OoVIVI00?o0000ok>c/onc/k<05?nc/k<00ol0003oVIVIoiVI
V@03oiVIV@03o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<
C005oda<C003o`000?lc<c?o<c<c00;o<c<c00?o0000oda<C?m<C4`01?m<C4`01Ol0003oIVIVofIV
I_mVIVKo000000?oOgmo00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Go
c<c<00Go0000ok>c/onc/k?o/k>co`000003oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Co0000
oda<C?m<C4co00002Olc<c<01?l0003oC4a<oda<C?l00002ofIVIP06o`000?moOgooOgmoo`000?nI
VIWo00000_nc/k<00ol0003oc<c<olc<c007olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_mo
Ogl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00[o0000oda<C?m<C4co0000
ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c007olc<c00;o`000?nc/k?o
0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l000001_lc<c<6ooooo`7o00000Oooool1oooo
o`009?ooool00ol0003oooooooooo`03ooooo`co/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003o
OgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00coIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003o
IVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02?nIVIT00ol0003o
/k>cok>c/`0Dok>c/`03o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003o
IVIVofIVIP02ofIVIP03o`000?m<C4coC4a<00GoC4a<00?o0000oc<c<olc<c<00_lc<c<00ol0003o
C4a<oda<C004oda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01Ol0003oVIVIoiVIVOnIVIWo
000000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`01Ol0003o/k>cok>c/onc/k?o000000?oVIVI00Co
0000ogmoOomoOgoo00000_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`04o`000?m<C4coC4a<o`00
00;oIVIV00Ko0000ogmoOomoOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Ko
0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc
<c<01_lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`00
0?o<c<coc<c<00Ooc<c<00_o0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`00
0006oc<c<`Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo2onc/k<0
0ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH03?mVIVH0
0ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl0
0ol0003oVIVIoiVIV@08oiVIV@03o`000?nc/k?o/k>c01Co/k>c00?o0000oiVIVOnIVIT00onIVIT0
0ol0003oOgmoogmoO`03ogmoO`05o`000?mVIVKoIVIVofIVI_l000001om<C4`00ol0003o<c<coc<c
<`02oc<c<`03o`000?m<C4coC4a<00GoC4a<00Co0000ofIVI_mVIVKo00000omoOgl01Ol0003oVIVI
oiVIVOnIVIWo000000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`01Ol0003o/k>cok>c/onc/k?o0000
00?oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`04o`000?m<
C4coC4a<o`0000;oIVIV00Ko0000ogmoOomoOgoo0000oiVIVOl00003ok>c/`03o`000?o<c<coc<c<
00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o
0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP;o000000GoVIVIo`000?nc/k?o
/k>co`000009olc<c007o`000?nc/k?o0000oiVIVOl0003oOgmoo`000002ofIVIP;o00001olc<c<6
ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`[o/k>c00?o0000oiVI
VOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV0_l0000Goda<
C0;o00003OmVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00SoVIVI00?o0000ok>c
/onc/k<05?nc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00;oOgmo00?o0000ofIV
I_mVIVH00_mVIVH00ol0003oC4a<oda<C005oda<C005o`000?lc<c?o<c<coc<c<ol000001om<C4`0
1Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`00
0?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04
o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01olc<c<01?l0003oC4a<oda<C?l00002
ofIVIP03o`000?moOgoo000000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c006o`000?nc
/k?o/k>co`000?nIVIWo00000_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko
<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<
olc<c006olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co0000
1olc<c<6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`Wo/k>c00?o
0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00coIVIV00?o
0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo0_l0
000:oiVIV@03o`000?nc/k?o/k>c01Co/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmo
O`03ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01Om<C4`01Ol0003o<c<coc<c
<olc<c?o000000OoC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVI
VOl000001?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVI
VOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Oo<c<c00Co
0000oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Wo
c<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000
oc<c<olc<c<01_lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c
/`03o`000?o<c<coc<c<00Koc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo
0000oda<C?l00007oc<c<`Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?o
oooo2?nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mV
IVH03?mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00[oIVIV0_l0000:ogmoO`03
o`000?nIVIWoVIVI00WoVIVI00?o0000ok>c/onc/k<05?nc/k<00ol0003oVIVIoiVIV@04oiVIV@03
o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C005oda<C005
o`000?lc<c?o<c<coc<c<ol000001om<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Co0000
oiVIVOnIVIWo00001Onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Co
0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo
<c<c00Co0000oda<C?m<C4co00000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@04o`000?nc/k?o
/k>co`0000Soc<c<00Co0000ok>c/onc/k?o/k>c0_l00002ogmoO`03o`000?mVIVKo000000;oC4a<
00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?m<C4`2o`000005ogmoOol0003oVIVIoiVI
VOl000000_nc/k<00ol0003oc<c<olc<c005olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_mo
Ogl2o`000003oda<C?l0003o<c<c00Oo<c<c1_ooool1o`00007ooooo0Oooool001Wooooo00Gok^k^
oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo00?ooooo1onc/k<00ol0003oVIVIoiVI
V@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH2o`0001OoC4a<0_l0
000<ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02OnIVIT00ol0003o/k>cok>c
/`0Dok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIV
IP02ofIVIP03o`000?m<C4coC4a<00GoC4a<00?o0000oc<c<olc<c<00_lc<c<00ol0003oC4a<oda<
C004oda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01Ol0003oVIVIoiVIVOnIVIWo000000Co
/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`00
00;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4co
C4a<oda<C?l000000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<
00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0
003o<c<coc<c<`06oc<c<`09o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVI00;o0000
00?o/k>co`000?o<c<`01oo<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0
003oC4a<o`0000So<c<c1_ooool1o`00007ooooo0Oooool001Wooooo00GoEEEEogMgMoooooooV9RH
ob4Q8@06ooooo`03o`000?oooooooooo00?ooooo1_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`00
0?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`00
0?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@09oiVIV@03o`00
0?nc/k?o/k>c01Co/k>c00?o0000oiVIVOnIVIT01?nIVIT01Ol0003oOgmoogmoOomoOgoo000000Go
IVIV00?o0000oda<C?m<C4`01Om<C4`00ol0003o<c<coc<c<`02oc<c<`03o`000?m<C4coC4a<00Co
C4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc/k<0
0ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_mo
Ogl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4co
C4a<o`000002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01ol0
003o/k>cok>c/onc/k?o0000oiVIVOl000000_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc
<c?o<c<c00Ko<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<0
0ol0003oc<c<olc<c006olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`00
0?m<C4co00002?lc<c<6ooooo`7o00000Oooool1ooooo`006Oooool01Ol0003ooooooooooooooooo
000000Kooooo0ol00003ooooo`Go/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09
ogmoO`03o`000?mVIVKoIVIV00[oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0<
ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02OnIVIT00ol0003o/k>cok>c/`0D
ok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP02
ofIVIP03o`000?m<C4coC4a<00KoC4a<00Go0000oc<c<olc<c?o<c<co`000006oda<C003o`000?mV
IVKoIVIV00;oIVIV00Co0000ogmoOomoOgoo00000onIVIT00ol0003o/k>cok>c/`03ok>c/`03o`00
0?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;o
Ogmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<
oda<C?l000000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Wo
0000ok>c/onc/k?o/k>co`000?nIVIWo0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00008
oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00002Oo<c<`0
0ol0003o/k>cok>c/`02o`0000;oOgmo00Go0000ofIVI_l0003oC4a<o`000008oc<c<`04o`000?oo
ooooooooooooo`?o00000_ooool001Wooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`03o`00
0?oooooooooo00?ooooo1?nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo
00?o0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00coIVIV
00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@09oiVIV@03o`000?nc/k?o/k>c01Go/k>c
00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00?oIVIV
00?o0000oda<C?m<C4`01Om<C4`00ol0003o<c<coc<c<`02oc<c<`03o`000?m<C4coC4a<00CoC4a<
00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0
003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl0
1?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<
o`000002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`01_l0003o
/k>cok>c/ol0003oVIVIo`0000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06
oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl2o`0000;o/k>c00?o0000olc<c?o<c<`0
1oo<c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o
<c<c00Ko<c<c00?o0000ooooooooool00oooool1o`00007ooooo0Oooool001Wooooo00Go0000oeEE
EOl0003o410@olc<c006ooooo`03o`000?oooooooooo00?ooooo0onc/k<00ol0003oVIVIoiVIV@0;
oiVIV@;o00002_moOgl00ol0003oIVIVofIVIP0:ofIVIP;o00005om<C4`2o`0000goIVIV00?o0000
ogmoOomoOgl02?moOgl2o`0000_oVIVI00?o0000ok>c/onc/k<05Onc/k<00ol0003oVIVIoiVIV@04
oiVIV@03o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C006
oda<C0?o000000?o<c<co`000?m<C4`01_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Go
0000oiVIVOnIVIWoVIVIo`000005ok>c/`03o`000?o<c<coc<c<00Goc<c<00Go0000ok>c/onc/k?o
/k>co`000003oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008
oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc
/k?o/k>co`0000Woc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV00Co0000
oda<C?m<C4co00002?lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o
/k>co`0000[oc<c<00_o0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`000008
oc<c<`03o`000?oooooooooo00Cooooo0Ol00001ooooo`7ooooo000Iooooo`03oeEEEOn7QhOooooo
00Sooooo00?o0000ooooooooool00oooool2ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmo
OomoOgl02OmoOgl00ol0003oIVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIV
I_mVIVH03?mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00[oVIVI00?o0000ok>c
/onc/k<05Onc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00;oOgmo00?o0000ofIV
I_mVIVH00_mVIVH00ol0003oC4a<oda<C006oda<C004o`000?m<C4coC4a<o`0000SoC4a<00Go0000
ofIVI_mVIVKoIVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0003oc<c<
olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000onIVIT01?l0003oOgmoogmoOol00002ofIV
IP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o
0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00008olc<c009o`000?nc/k?o/k>cok>c/ol0
003oVIVIo`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<03?l0003oC4a<oda<
C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000[oc<c<0_l00002oiVIV@07o`000?mo
Ogoo0000ofIVI_l0003oC4a<o`000008oc<c<`03o`000?oooooooooo00Cooooo0Ol00001ooooo`7o
oooo000Iooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool00oooool00onc/k?o0000
oiVIV@0<oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<
oda<C00Foda<C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVI
oiVIV@0:oiVIV@03o`000?nc/k?o/k>c01Go/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmo
ogmoO`02ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<C4`01Om<C4`00ol0003o<c<c
o`000009oda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01?l0003oVIVIoiVIVOl00005ok>c
/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002
ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<
C?m<C4co000000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00008olc<c005
o`000?nc/k?o/k>cok>c/ol000000_nIVIT2o`0000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<0
1?l0003oC4a<oda<C?l00002ofIVIP;o000000GoVIVIo`000?nc/k?o/k>co`000009olc<c007o`00
0?nc/k?o0000oiVIVOl0003oOgmoo`000002ofIVIP;o00002Olc<c<00ol0003oooooooooo`04oooo
o`7o00000Oooool1ooooo`006_ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo
00?ooooo00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV
00[oIVIV0_l0000Hoda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl2o`00
00coVIVI00?o0000ok>c/onc/k<05Onc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo
00;oOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C006oda<C004o`000?lc<c?o<c<c
o`0000OoC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`05o`000?nIVIWoVIVIoiVIVOl00000
1?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo
00000omoOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Go<c<c0_l00003oda<
C003o`000?mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo00000_nc/k<00ol0003oc<c<olc<c006
olc<c003o`000?nc/k?o/k>c00;o000000CoVIVIo`000?moOgoo00000_mVIVH01?l0003oC4a<oda<
C?l00008oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o
0000olc<c?o<c<`01_o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003o
C4a<o`0000Wo<c<c00?o0000ooooooooool01?ooool1o`00007ooooo0Oooool002Cooooo00?o0000
ooooooooool00oooool=oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02_mVIVH0
0ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl0
0ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT00onIVIT0
0ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<C4`01_m<C4`0
0ol0003o<c<co`000007oda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgooOgmoo`00
0003oiVIV@03o`000?nc/k?o/k>c00;o/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c
/`02ok>c/`04o`000?nIVIWoVIVIo`0000?oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o
<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00?o0000ofIVI_l000000_moOgl01?l0003o
VIVIoiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT0
0ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00?o0000oda<C?l000000_mV
IVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>c
ok>c/ol0003oVIVI00;o00000_mVIVH00ol0003oC4a<o`000009oc<c<`03o`000?oooooooooo00Co
oooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo3?nIVIT00ol0003oOgmo
ogmoO`09ogmoO`03o`000?mVIVKoIVIV00[oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIV
ofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>c
ok>c/`0Eok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIV
ofIVIP03ofIVIP03o`000?m<C4coC4a<00SoC4a<00?o0000oda<C?m<C4`01_m<C4`01Ol0003oIVIV
ofIVI_mVIVKo000000?oOgmo00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<
00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00003ogmoO`04o`000?mVIVKo
IVIVo`0000?oC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C006o`000?mV
IVKoIVIVo`000?moOgoo00000_nIVIT01?l0003o/k>cok>c/ol00008olc<c004o`000?nc/k?o/k>c
o`0000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`08o`000?m<
C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Ooc<c<00[o0000
ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c
<`03o`000?m<C4cooooo00Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?o
oooo2onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00[oIVIV0_l0000Hoda<C003
o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0<oiVIV@03
o`000?nc/k?o/k>c01Go/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`02ogmoO`03
o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<C4`04Om<C4`01?l0003oIVIVofIVI_mVIVH2o`00
00?oOgmo00Co0000oiVIVOnIVIWo00001Onc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o
/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00003oda<C003o`00
0?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP06o`000?moOgooOgmoo`00
0?nIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o
0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`0:o`000?m<C4coC4a<o`000?mV
IVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02_l0003o/k>cok>c
/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00?o0000
oda<C?l000001Oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool:oiVI
V@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<oda<C00Goda<
C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0<oiVI
V@03o`000?nc/k?o/k>c01Go/k>c00?o0000oiVIVOnIVIT01OnIVIT00ol0003oOgmoogmoO`02ogmo
O`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`04_m<C4`01Ol0003oIVIVofIVI_mVIVKo
000000CoOgmo00Co0000oiVIVOnIVIWo00001Onc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc
/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00003oda<C003
o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP06o`000?moOgooOgmo
o`000?nIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`0000;oVIVI
00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`0:o`000?m<C4coC4a<o`00
0?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02_l0003o/k>c
ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00?o
0000oda<C?l000001Oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool9
oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<oda<C00G
oda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;
oiVIV@;o00005onc/k<00ol0003oVIVIoiVIV@05oiVIV@03o`000?moOgooOgmo00;oOgmo00?o0000
ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00Aoda<C005o`000?mVIVKoIVIVofIVI_l000001?mo
Ogl01?l0003oVIVIoiVIVOl00005ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<0
0_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c
<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Ko0000ogmoOomoOgoo0000oiVI
VOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT01_l0003o
OgmoogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01_l0003oC4a<oda<C?l0
003oIVIVo`0000;oOgmo0_l00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Wo0000ok>c/ol0003o
VIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`03o`000?m<C4co
000000Kooooo0Ol00001ooooo`7ooooo000Tooooo`;o00001?ooool8oiVIV@03o`000?moOgooOgmo
00SoOgmo0_l0000=ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0
003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0
003oVIVIoiVIV@05oiVIV@03o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0
003oC4a<oda<C00Boda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01Ol0003oVIVIoiVIVOnI
VIWo000000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`;o00000_nI
VIT01?l0003oOgmoogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01Ol0003o
C4a<oda<C?m<C4co000000;oIVIV00Ko0000ogmoOomoOgoo0000oiVIVOl00003ok>c/`03o`000?o<
c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIVIP03o`00
0?m<C4co000000Wo<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc
/k<00ol0003oc<c<olc<c007olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000
00;oC4a<00?o0000oc<c<olc<c<01_lc<c<00ol0003oC4a<o`000005ooooo`;o00000_ooool002Co
oooo00?o0000ooooooooool00oooool7oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mV
IVH03?mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomo
Ogl02?moOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnI
VIT01OnIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<
C4`04Om<C4`00ol0003oIVIVofIVIP02ofIVIP05o`000?moOgooOgmoogmoOol000000onIVIT00ol0
003o/k>cok>c/`02ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01Ol0
003oVIVIoiVIVOnIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c
<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01_l0003oOgmoogmoOol0003oVIVIo`00
00?o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo
000000;oIVIV00?o0000oda<C?l000002Olc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo
0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Wo0000ok>c/ol0003oVIVIo`000?mo
Ogoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`03o`000?m<C4co000000Kooooo
0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo1_nIVIT00ol0003oOgmoogmo
O`08ogmoO`03o`000?mVIVKoIVIV00coIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIV
IP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT2o`0001So/k>c00?o
0000oiVIVOnIVIT01OnIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o
0000oda<C?m<C4`04_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00?o0000oiVIVOnIVIT0
0_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Ooc<c<00?o0000ok>c/onc/k<00_nc/k<01Ol0003o
VIVIoiVIVOnIVIWo000000?oOgmo00Co0000ofIVI_mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06
oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@04o`00
0?nc/k?o/k>co`0000Soc<c<00Co0000ok>c/onc/k?o00000onIVIT2o`0000;oIVIV00Co0000oda<
C?m<C4co00002?lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c
/`03o`000?o<c<coc<c<00Ooc<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00000
0_m<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4co0000ofIVIPKooooo0Ol00001ooooo`7o
oooo000Tooooo`03o`000?oooooooooo00?ooooo1OnIVIT00ol0003oOgmoogmoO`08ogmoO`03o`00
0?mVIVKoIVIV00_oIVIV0_l0000Hoda<C003o`000?mVIVKoIVIV00[oIVIV0_l0000:ogmoO`03o`00
0?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@05oiVIV@03o`00
0?moOgooOgmo00?oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C00Boda<C003o`00
0?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgooOgmoo`000003oiVIV@03o`000?nc/k?o/k>c00;o
/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`00
00?oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4co
C4a<oda<C?l000000_mVIVH00ol0003oOgmoo`000002oiVIV@05o`000?nc/k?o/k>cok>c/ol00000
2?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l000000om<C4`00ol0
003o<c<coc<c<`06oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o
/k>c00?o0000olc<c?o<c<`01_o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIV
I_l0003oC4a<o`0000Wo<c<c00Go0000oda<C?l0003oIVIVo`000005ooooo`7o00000Oooool1oooo
o`009?ooool00ol0003oooooooooo`03ooooo`CoVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003o
IVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003o
OgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003o
VIVIoiVIV@05oiVIV@03o`000?moOgooOgmo00?oOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003o
C4a<oda<C00Boda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl00ol0003oVIVIoiVIV@02oiVI
V@03o`000?nc/k?o/k>c00;o/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c
/`04o`000?nIVIWoVIVIo`0000?oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c
<`06oc<c<`04o`000?m<C4coC4a<o`0000?oIVIV00?o0000ogmoOol000000_nIVIT01Ol0003o/k>c
ok>c/onc/k?o000000Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mVIVKo
000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<00ol0003oC4a<o`000002ofIVIP05o`000?moOgoo
0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c00<o`000?nc/k?o/k>co`000?nIVIWo
0000ogmoOol0003oIVIVo`000?m<C4co00002Olc<c<01Ol0003oC4a<o`000?mVIVKo000000Gooooo
0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo0onIVIT00ol0003oOgmoogmo
O`08ogmoO`03o`000?mVIVKoIVIV00coIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIV
IP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c
/`0Gok>c/`03o`000?nIVIWoVIVI00KoVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIV
IP02ofIVIP03o`000?m<C4coC4a<01;oC4a<00?o0000ofIVI_mVIVH00_mVIVH01?l0003oOgmoogmo
Ool00004oiVIV@03o`000?nc/k?o/k>c00;o/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>c
ok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000?oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0
003o<c<coc<c<`05oc<c<`05o`000?m<C4coC4a<oda<C?l000000omVIVH2o`0000;oVIVI00Go0000
ok>c/onc/k?o/k>co`000008olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol00000
0_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0
0002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000
ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4co0000ofIVI_l000001_oo
ool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool2oiVIV@03o`000?moOgoo
Ogmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH2o`0001SoC4a<00?o0000ofIVI_mVIVH02_mVIVH2
o`0000[oOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWo
VIVI00KoVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4co
C4a<01;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`05o`000?nIVIWoVIVIoiVIVOl00000
1Onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Co0000oiVIVOnIVIWo
00000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0
003oC4a<oda<C?m<C4co000000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol0
0009olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Co0000ogmoOol0003oIVIV0_l00002oda<C003
o`000?lc<c?o<c<c00Ko<c<c00Wo0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIT00_l0
00000onc/k?o0000olc<c007olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIV
o`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<o`000?l0003oOgmo00Kooooo0Ol0
0001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo00?oVIVIo`000?moOgl02OmoOgl0
0ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02_mVIVH0
0ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<0
0ol0003oVIVIoiVIV@07oiVIV@03o`000?moOgooOgmo00?oOgmo00?o0000ofIVI_mVIVH00omVIVH0
0ol0003oC4a<oda<C00Aoda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgooOgmoo`00
0003oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c
/`02ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000?o
C4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o0000ogmo
Ool000000_nIVIT01?l0003o/k>cok>c/ol00009olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Go
0000ogmoOol0003oIVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c00[o0000oda<C?m<C4co
0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c00:o`000?nc
/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<0
1Ol0003oC4a<o`000?l0003oOgmo00Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooo
oooo00?ooooo00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4co
C4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWo
VIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@07oiVIV@03o`000?moOgoo
Ogmo00?oOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00Boda<C005o`000?mVIVKo
IVIVofIVI_l000000omoOgl00ol0003oVIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c00;o/k>c00?o
0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`04o`000?nIVIWoVIVIo`0000?oOgmo
00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<
C?l000000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Woc<c<00Co0000
ok>c/onc/k?o00000_nIVIT00ol0003oOgmoogmoO`02o`0000?oC4a<00?o0000oc<c<olc<c<01_lc
<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<co
c<c<00Ooc<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o
<c<coc<c<`06oc<c<`03o`000?m<C4coC4a<00;o000000?oOgmoooooooooool01?ooool1o`00007o
oooo0Oooool002Cooooo00?o0000ooooooooool00oooool:ogmoO`03o`000?mVIVKoIVIV00_oIVIV
0_l0000Goda<C0;o00003OmVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI
00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@06oiVIV@;o00001OmoOgl00ol0003oIVIV
ofIVIP03ofIVIP03o`000?m<C4coC4a<01;oC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmo
ogmoOomoOgoo000000?oVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c004olc<c003
o`000?nc/k?o/k>c00;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`04o`000?mVIVKoIVIV
o`0000CoC4a<00?o0000oc<c<olc<c<01Olc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co
0000ogmoOomoOgoo00000_nIVIT01?l0003o/k>cok>c/ol00009olc<c006o`000?nc/k?o/k>co`00
0?nIVIWo00000_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00[o0000
oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c007olc<
c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<0
1_lc<c<01ol0003oC4a<o`000?mVIVKo0000ogmoOol000001Oooool1o`00007ooooo0Oooool002Co
oooo0_l00004ooooo`WoOgmo00?o0000ofIVI_mVIVH03?mVIVH00ol0003oC4a<oda<C00Foda<C003
o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl2o`0000coVIVI00?o0000ok>c/onc
/k<06?nc/k<00ol0003oVIVIoiVIV@06oiVIV@03o`000?moOgooOgmo00CoOgmo00?o0000ofIVI_mV
IVH00omVIVH00ol0003oC4a<oda<C00Boda<C005o`000?mVIVKoIVIVofIVI_l000001?moOgl01Ol0
003oVIVIoiVIVOnIVIWo000000Go/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`02
ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00004oda<C003o`00
0?lc<c?o<c<c00Go<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`00
00;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01ol0003o/k>cok>c/onc/k?o0000oiVIVOl00000
0_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00[o0000oda<C?m<C4co
0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c007olc<c00;o`000?nc
/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l000002Olc<c<01ol0003oC4a<o`000?mV
IVKo0000ogmoOol000001?ooool2o`0000;ooooo000Tooooo`03o`000?oooooooooo00?ooooo2?mo
Ogl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02_mV
IVH2o`0000[oOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Hok>c/`03o`000?nI
VIWoVIVI00KoVIVI00?o0000ogmoOomoOgl01?moOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<
C4coC4a<01;oC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000?oVIVI
00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00;o/k>c
00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c
<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP05o`000?moOgooOgmoogmoOol000000_nI
VIT01?l0003o/k>cok>c/ol00008olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl00ol0
003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00[o0000oda<C?m<C4co0000ofIVI_l0
003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c007olc<c009o`000?nc/k?o0000oiVI
VOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01ol0003oC4a<o`00
0?mVIVKo0000ogmoOol000001_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool0
0oooool7ogmoO`03o`000?mVIVKoIVIV00_oIVIV0_l0000Goda<C0;o00003?mVIVH00ol0003oOgmo
ogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<06?nc/k<00ol0003oVIVI
oiVIV@06oiVIV@03o`000?moOgooOgmo00CoOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<
oda<C00Boda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgooOgmoo`000003oiVIV@03
o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`04
o`000?nIVIWoVIVIo`0000?oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06
oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@04o`00
0?nc/k?o/k>co`0000Soc<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo00?o0000
ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000
ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02_l0003o/k>cok>c/ol0003o
VIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Oo0000oda<C?l0
003oIVIVo`000?moOgoo000000Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo
00?ooooo1_moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIV
I_mVIVH03?mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00[oVIVI00?o0000ok>c
/onc/k<06?nc/k<00ol0003oVIVIoiVIV@07oiVIV@03o`000?moOgooOgmo00CoOgmo00?o0000ofIV
I_mVIVH00omVIVH00ol0003oC4a<oda<C00Boda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmo
OomoOgooOgmoo`000003oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`01?o<c<`0
0ol0003o/k>cok>c/`03ok>c/`04o`000?nIVIWoVIVIo`0000?oOgmo00Co0000ofIVI_mVIVKo0000
0om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003o
OgmoogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Oo0000ok>c/onc/k?o/k>co`00
0?nIVIWo000000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`03o`00
0?m<C4co000000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ko
c<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<c
oc<c<`06oc<c<`07o`000?m<C4co0000ofIVI_l0003oOgmoo`000006ooooo`7o00000Oooool1oooo
o`009?ooool00ol0003oooooooooo`03ooooo`KoOgmo00?o0000ofIVI_mVIVH02_mVIVH00ol0003o
C4a<oda<C00Foda<C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003o
VIVIoiVIV@0:oiVIV@03o`000?nc/k?o/k>c01So/k>c00?o0000oiVIVOnIVIT02?nIVIT00ol0003o
OgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<C4`04om<C4`01Ol0003o
IVIVofIVI_mVIVKo000000?oOgmo00Go0000oiVIVOnIVIWoVIVIo`000006ok>c/`03o`000?o<c<co
c<c<00Coc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00003ogmoO`05o`000?mV
IVKoIVIVofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l0
00000_mVIVH01_l0003oOgmoogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01oo<c<`0
1ol0003o/k>cok>c/onc/k?o0000oiVIVOl000000_moOgl00ol0003oIVIVo`000002oda<C003o`00
0?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH01?l0003oOgmoo`000?l00003ok>c
/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o0000oiVIV@02o`0000;oIVIV00?o0000
oda<C?l000002Olc<c<01ol0003oC4a<o`000?mVIVKo0000ogmoOol000001_ooool1o`00007ooooo
0Oooool002Cooooo00?o0000ooooooooool00oooool5ogmoO`03o`000?mVIVKoIVIV00[oIVIV00?o
0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?moOgooOgmo00WoOgmo00?o
0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00SoVIVI00?o
0000ogmoOomoOgl01?moOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<01;oC4a<00?o
0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000?oVIVI00?o0000ok>c/onc/k<0
0onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Co0000oiVIVOnIVIWo
00000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0
003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01?l0003o/k>cok>c
/ol00009olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl01?l0003oIVIVofIVI_l00002
oda<C003o`000?lc<c?o<c<c00Ko<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nI
VIWo00000onc/k<00ol0003oc<c<olc<c005olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmo
Ool0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02?l0003oC4a<o`000?mVIVKo0000
ogmoOol0003oVIVI1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool4
ogmoO`03o`000?mVIVKoIVIV00[oIVIV0_l0000Goda<C0;o00003OmVIVH00ol0003oOgmoogmoO`08
ogmoO`;o00003?nIVIT2o`0001So/k>c0_l00009oiVIV@;o00001_moOgl00ol0003oIVIVofIVIP03
ofIVIP03o`000?m<C4coC4a<01?oC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`03o`000?nI
VIWoVIVI00;oVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc
/k?o/k>c00?o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000?o
C4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Ko0000ogmo
OomoOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Soc<c<00Oo0000ok>c/onc/k?o0000
oiVIVOl0003oOgmo00;o000000GoIVIVo`000?m<C4coC4a<o`000008oc<c<`0;o`000?m<C4coC4a<
oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c00<
o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co00002Olc<c<02Ol0003o
C4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000005ooooo`7o00000Oooool1ooooo`009?ooool0
0ol0003oooooooooo`03ooooo`?oOgmo00?o0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<oda<C00F
oda<C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0:
oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02?nIVIT00ol0003oOgmoogmoO`05
ogmoO`03o`000?mVIVKoIVIV00CoIVIV00?o0000oda<C?m<C4`04om<C4`01Ol0003oIVIVofIVI_mV
IVKo000000?oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<
c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00onc/k<01?l0003oVIVIoiVIVOl00002ogmoO`05o`00
0?mVIVKoIVIVofIVI_l000000om<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;o
C4a<00Co0000ofIVI_mVIVKo00000_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<
00Soc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV00Co0000oda<C?m<C4co
00002?lc<c<02ol0003oC4a<oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c
00?o0000olc<c?o<c<`01_o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0
003oC4a<o`0000Wo<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl000001Oooool1
o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool2ogmoO`03o`000?mVIVKoIVIV
00[oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?moOgooOgmo
00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI
00WoVIVI00?o0000ogmoOomoOgl01?moOgl00ol0003oIVIVofIVIP04ofIVIP03o`000?m<C4coC4a<
01?oC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000
ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Co0000
oiVIVOnIVIWo00000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000?oC4a<00?o0000oc<c<olc<c<0
1_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01?l0
003o/k>cok>c/ol00009olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl00ol0003oIVIV
o`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmo
o`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c007olc<c009o`000?nc/k?o0000oiVIVOl0003o
Ogmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<00ol0003oC4a<oda<C002o`00
0004ogmoOol0003oVIVIo`0000Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo
00?ooooo00?oOgmoo`000?mVIVH02omVIVH2o`0001SoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0
003oOgmoogmoO`08ogmoO`;o00003?nIVIT2o`0001So/k>c0_l0000:oiVIV@03o`000?moOgooOgmo
00CoOgmo00?o0000ofIVI_mVIVH01?mVIVH00ol0003oC4a<oda<C00Coda<C003o`000?mVIVKoIVIV
00;oIVIV00Go0000ogmoOomoOgooOgmoo`000003oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000
olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_mo
Ogl01?l0003oIVIVofIVI_l00004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`0
0_m<C4`01_l0003oIVIVofIVI_l0003oOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008
olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Ko0000ogmoOomoOgoo0000ofIVI_l00002oda<C003
o`000?lc<c?o<c<c00Oo<c<c00?o0000oda<C?l000000_mVIVH01Ol0003oOgmoo`000?nIVIWo0000
00;o/k>c00?o0000olc<c?o<c<`01oo<c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIV
o`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000
oiVIVOl000001_ooool1o`00007ooooo0Oooool002Cooooo0_l00004ooooo`03o`000?mVIVKoIVIV
00[oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo
00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI
00WoVIVI00?o0000ogmoOomoOgl01OmoOgl00ol0003oIVIVofIVIP04ofIVIP03o`000?m<C4coC4a<
01?oC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000;oVIVI00?o0000
ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Go0000
oiVIVOnIVIWoVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<0
1Olc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01Ol0
003o/k>cok>c/onc/k?o000000Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT01_l0003oOgmoogmo
Ool0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01olc<c<01Ol0003oC4a<o`000?mVIVKo0000
00;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c00;o`000?nc/k?o0000
oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l000002Olc<c<02Ol0003oC4a<o`000?mVIVKo0000
ogmoOol0003oVIVIo`000005ooooo`;o00000_ooool002Cooooo00?o0000ooooooooool00oooool<
ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08
ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@09
oiVIV@03o`000?moOgooOgmo00GoOgmo00?o0000ofIVI_mVIVH01?mVIVH00ol0003oC4a<oda<C00C
oda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgooOgmoo`000003oiVIV@03o`000?nc
/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`03ok>c/`05o`000?nI
VIWoVIVIoiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00004oda<C003o`000?lc<c?o<c<c00Go
<c<c00?o0000oda<C?m<C4`00_m<C4`01_l0003oIVIVofIVI_l0003oOgmoo`0000;oVIVI00?o0000
ok>c/onc/k<00_nc/k<00ol0003oc<c<olc<c005olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Ko
0000ogmoOomoOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c00?o0000oda<C?l0
00000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`02Ol0
003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c
00Go0000oda<C?l0003oIVIVo`000002ogmoO`;o000000?o/k>cooooooooool01?ooool1o`00007o
oooo0Oooool002Cooooo00?o0000ooooooooool00oooool;ofIVIP;o00006?m<C4`00ol0003oIVIV
ofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>c
ok>c/`0Gok>c/`03o`000?nIVIWoVIVI00[oVIVI00?o0000ogmoOomoOgl01?moOgl00ol0003oIVIV
ofIVIP04ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmo
ogmoOomoOgoo000000CoVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c004olc<c003
o`000?nc/k?o/k>c00?o/k>c00Co0000oiVIVOnIVIWo00000omoOgl01?l0003oIVIVofIVI_l00003
oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?mo
OgooOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c004o`000?nc/k?o/k>co`00
00;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`04o`000?m<C4co
C4a<o`0000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<
00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c
<`06oc<c<`0:o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/`Kooooo0Ol00001
ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo2_mVIVH00ol0003oC4a<oda<C00Goda<
C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0<oiVI
V@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`05ogmo
O`03o`000?mVIVKoIVIV00CoIVIV00?o0000oda<C?m<C4`04om<C4`00ol0003oIVIVofIVIP02ofIV
IP05o`000?moOgooOgmoogmoOol000001?nIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<co
c<c<00Coc<c<00?o0000ok>c/onc/k<00onc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mV
IVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;o
IVIV00Co0000ogmoOomoOgoo00000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Co0000
ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000?oC4a<00?o0000oc<c<olc<c<0
1_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0
003oc<c<olc<c006olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;o
C4a<00?o0000oc<c<olc<c<01_lc<c<02_l0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`00
0?nc/k<6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`WoIVIV00?o
0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o
0000oiVIVOnIVIT02onIVIT2o`0001So/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmo
O`05ogmoO`03o`000?mVIVKoIVIV00CoIVIV00?o0000oda<C?m<C4`04om<C4`00ol0003oIVIVofIV
IP02ofIVIP05o`000?moOgooOgmoogmoOol000001?nIVIT00ol0003o/k>cok>c/`03ok>c/`03o`00
0?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00onc/k<01?l0003oVIVIoiVIVOl00003ogmoO`04
o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co
000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<
00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIVIP05o`000?m<C4coC4a<oda<
C?l000002?lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03
o`000?o<c<coc<c<00Ooc<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<
C4`00ol0003o<c<coc<c<`06oc<c<`03o`000?m<C4co000000;oIVIV0_l000001OnIVIWo0000ok>c
/onc/k?o000000Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo2OmV
IVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?mo
Ogl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02_nI
VIT00ol0003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV00CoIVIV00?o0000oda<C?m<C4`04om<
C4`00ol0003oIVIVofIVIP02ofIVIP03o`000?moOgooOgmo00;oOgmo00Go0000oiVIVOnIVIWoVIVI
o`000006ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00onc/k<01Ol0003oVIVI
oiVIVOnIVIWo000000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000003oda<C003o`000?lc<c?o<c<c
00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Go
0000ok>c/onc/k?o/k>co`000008olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol0
00000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Go0000
ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00co0000ok>c/onc/k?o0000
oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00009oc<c<`09o`000?m<C4co0000ofIVI_l0003o
Ogmoo`000?nIVIWo000000;o/k>c00?o0000ooooooooool00oooool1o`00007ooooo0Oooool002Co
oooo00?o0000ooooooooool00oooool8ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mV
IVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00coVIVI00?o0000ok>c/onc
/k<05_nc/k<00ol0003oVIVIoiVIV@0:oiVIV@03o`000?moOgooOgmo00GoOgmo00?o0000ofIVI_mV
IVH01OmVIVH00ol0003oC4a<oda<C00Coda<C003o`000?mVIVKoIVIV00;oIVIV00?o0000ogmoOomo
Ogl00_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Go/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0
003o/k>cok>c/`03ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01Ol0003oIVIVofIVI_mV
IVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV
00Ko0000ogmoOomoOgoo0000oiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c
/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Co
0000oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<
c<`01_o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000Wo
<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003ooooooooo
o`03ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`OoIVIV00?o0000
oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000
oiVIVOnIVIT02onIVIT2o`0001So/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`05
ogmoO`03o`000?mVIVKoIVIV00GoIVIV00?o0000oda<C?m<C4`04om<C4`00ol0003oIVIVofIVIP02
ofIVIP03o`000?moOgooOgmo00;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000005ok>c/`03o`000?o<
c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo
00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go<c<c00Go0000oda<C?m<
C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`00
0008olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<
oda<C?l00009oc<c<`03o`000?m<C4co000000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c
/`03o`000?o<c<coc<c<00Ooc<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00000
0_m<C4`00ol0003o<c<coc<c<`06oc<c<`03o`000?m<C4coC4a<00;o000000OoOgmoo`000?nIVIWo
VIVIo`000?nc/k?o000000Kooooo0Ol00001ooooo`7ooooo000Iooooo`05olc<c?lQ8B7o0000ob4Q
8Oo<c<`01_ooool00ol0003oooooooooo`03ooooo`GoIVIV0_l0000Hoda<C003o`000?mVIVKoIVIV
00[oIVIV0_l0000:ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<2o`00
00coVIVI00?o0000ogmoOomoOgl01_moOgl00ol0003oIVIVofIVIP04ofIVIP03o`000?m<C4coC4a<
01?oC4a<00?o0000ofIVI_mVIVH00omVIVH01Ol0003oOgmoogmoOomoOgoo000000CoVIVI00?o0000
ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Go0000
oiVIVOnIVIWoVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<0
1Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co0000oiVIVOnI
VIWo00000_nc/k<2o`0000Ooc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@03o`000?moOgoo
000000;oIVIV00?o0000oda<C?l000002_lc<c<00ol0003oC4a<o`000002ofIVIP05o`000?moOgoo
0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c009o`000?nc/k?o0000oiVIVOl0003o
Ogmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02Ol0003oC4a<o`000?mVIVKo
0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?oooooooooo00Cooooo0Ol00001ooooo`7ooooo
000Iooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`03ooooo`GoIVIV
00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0:ofIVIP03o`000?moOgooOgmo00WoOgmo
00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00coVIVI
00?o0000ogmoOomoOgl01OmoOgl00ol0003oIVIVofIVIP05ofIVIP03o`000?m<C4coC4a<01?oC4a<
00?o0000ofIVI_mVIVH00omVIVH01Ol0003oOgmoogmoOomoOgoo000000CoVIVI00?o0000ok>c/onc
/k<00onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Co0000oiVIVOnI
VIWo00000omoOgl01?l0003oIVIVofIVI_l00004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000
oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000;o/k>c
00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmoOol0
00000_mVIVH00ol0003oC4a<o`00000:oc<c<`03o`000?m<C4co000000;oIVIV00Go0000ogmoOol0
003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Wo0000ok>c/ol0003oVIVIo`000?mo
Ogoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`09o`000?m<C4co0000ofIVI_l0
003oOgmoo`000?nIVIWo000000;o/k>c00?o0000ooooooooool01?ooool1o`00007ooooo0Oooool0
01Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00?ooooo1?mVIVH0
0ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl0
0ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT03?nIVIT0
0ol0003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV00GoIVIV00?o0000oda<C?m<C4`05?m<C4`0
0ol0003oIVIVofIVIP02ofIVIP05o`000?moOgooOgmoogmoOol000001?nIVIT00ol0003o/k>cok>c
/`03ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00onc/k<01Ol0003oVIVIoiVI
VOnIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03
o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00002
ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@03o`000?mo
Ogoo000000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<00ol0003oC4a<o`000002ofIVIP05o`00
0?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c009o`000?nc/k?o0000oiVI
VOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01olc<c<01?l0003oC4a<o`00
0?l00002ogmoO`;o00000_nc/k<00ol0003oc<c<ooooo`05ooooo`7o00000Oooool1ooooo`006Ooo
ool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol00003ooooo`;oIVIV0_l0000Hoda<C003o`00
0?mVIVKoIVIV00[oIVIV0_l0000:ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<0
5_nc/k<00ol0003oVIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo00GoOgmo00?o0000ofIVI_mVIVH0
1OmVIVH00ol0003oC4a<oda<C00Doda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgoo
Ogmoo`000004oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003o
/k>cok>c/`03ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01Ol0003oIVIVofIVI_mVIVKo
000000CoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKo
IVIVo`0000;oOgmo00?o0000oiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc
/k?o/k>cok>c/ol000000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So
<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000
olc<c?o<c<`01_o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<
C003o`000?lc<c?o<c<c00Ko<c<c00?o0000oda<C?m<C4`00_l000001?moOgoo0000oiVIVOl00002
ok>c/`03o`000?o<c<cooooo00?ooooo0ol00002ooooo`006Oooool01Oo<c<co0000o`000?l0003o
c<c<00Kooooo00?o0000ooooooooool00oooool2ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000
ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000
ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@;o00002?moOgl00ol0003oIVIVofIVIP05
ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomo
Ogoo000000CoVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c003olc<c003o`000?nc
/k?o/k>c00?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`05o`000?mVIVKoIVIVofIVI_l0
00001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mV
IVKo00000_moOgl00ol0003oVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c
/onc/k?o/k>co`000002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c
<`07oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl00ol0003oVIVIo`000002ok>c/`03
o`000?o<c<coc<c<00Koc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000
0_m<C4`00ol0003o<c<coc<c<`06oc<c<`03o`000?m<C4coC4a<00;o000000CoOgmoo`000?nIVIWo
00000_nc/k<00ol0003oc<c<ooooo`05ooooo`7o00000Oooool1ooooo`006Oooool01Ol@413o^[Zj
oooooonj^[[o410@00Kooooo00?o0000ooooooooool00oooool00omVIVKo0000oda<C00Goda<C003
o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03
o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`07ogmoO`03
o`000?mVIVKoIVIV00GoIVIV00?o0000oda<C?m<C4`05?m<C4`00ol0003oIVIVofIVIP02ofIVIP05
o`000?moOgooOgmoogmoOol000001?nIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<
00?oc<c<00?o0000ok>c/onc/k<00onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Go0000
ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<
o`000002ofIVIP06o`000?moOgooOgmoo`000?nIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<
c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4co
C4a<o`0000Wo<c<c00?o0000oda<C?m<C4`00_l00002ogmoO`03o`000?nIVIWo000000;o/k>c00?o
0000olc<c?o<c<`01oo<c<`01ol0003o/k>co`000?nIVIWo0000ogmoOol000000_mVIVH00ol0003o
C4a<o`000009oc<c<`04o`000?m<C4co0000ofIVIP;o000000GoVIVIo`000?nc/k?o/k>co`000002
olc<c0Kooooo0Ol00001ooooo`7ooooo000Iooooo`05o`000?nj^[[ooooookZj^_l000001_ooool0
0ol0003oooooooooo`03ooooo`03o`000?m<C4coC4a<01GoC4a<0_l0000=ofIVIP03o`000?moOgoo
Ogmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWo
VIVI00_oVIVI00?o0000ogmoOomoOgl01omoOgl00ol0003oIVIVofIVIP05ofIVIP;o00005Om<C4`0
0ol0003oIVIVofIVIP02ofIVIP03o`000?moOgooOgmo00;oOgmo00Go0000oiVIVOnIVIWoVIVIo`00
0006ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00onc/k<01Ol0003oVIVIoiVI
VOnIVIWo000000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko
<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Go0000
ok>c/onc/k?o/k>co`000008olc<c007o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000002ogmoO`03
o`000?mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01_l0003oC4a<oda<C?l0003oIVIV
o`0000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c00<o`000?nc/k?o
/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co00002_lc<c<2o`000006ofIVI_l0003o
0000o`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006ooooo`7o00000Oooool1ooooo`006Ooo
ool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool00ooooolHoda<C003o`00
0?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl2o`0000coVIVI00?o0000ok>c/onc/k<0
5_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@;o00002?moOgl00ol0003oIVIVofIVIP06ofIVIP03o`00
0?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`02ogmoO`05o`00
0?nIVIWoVIVIoiVIVOl000001_nc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o
/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`05o`000?mVIVKoIVIVofIVI_l000000om<C4`0
0ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmo
Ool00002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01ol0003o/k>cok>c/onc/k?o0000
oiVIVOl000000_moOgl00ol0003oIVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Ko0000
oda<C?m<C4co0000ofIVI_l00002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`0
1_o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000[o<c<c
0_l000001_mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_ooool1o`00
007ooooo0Oooool002Cooooo00?o0000ooooooooool00ooooolGoda<C003o`000?mVIVKoIVIV00[o
IVIV0_l0000:ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003o
VIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00OoOgmo00?o0000ofIVI_mVIVH01_mVIVH00ol0003o
C4a<oda<C00Doda<C003o`000?mVIVKoIVIV00;oIVIV00?o0000ogmoOomoOgl00_moOgl01Ol0003o
VIVIoiVIVOnIVIWo000000Oo/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`03ok>c
/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000?oC4a<00?o
0000oc<c<olc<c<01_lc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo
00?o0000oiVIVOl000000onc/k<00ol0003oc<c<olc<c007olc<c004o`000?nc/k?o/k>co`0000;o
VIVI00Go0000ogmoOol0003oIVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Ko0000oda<
C?m<C4co0000ofIVI_l00002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01oo<
c<`01Ol0003o/k>co`000?nIVIWo000000;oOgmo0_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c
00Co0000oda<C?l0003oIVIV0_l00002oiVIV@03o`000?nc/k?o000000?oc<c<1_ooool1o`00007o
oooo0Oooool002Cooooo00?o0000ooooooooool00ooooolEoda<C0;o00003?mVIVH00ol0003oOgmo
ogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVI
oiVIV@0;oiVIV@03o`000?moOgooOgmo00OoOgmo00?o0000ofIVI_mVIVH01_mVIVH00ol0003oC4a<
oda<C00Doda<C003o`000?mVIVKoIVIV00;oIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVI
oiVIV@02oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>c
ok>c/`03ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01?l0003oIVIVofIVI_l00004oda<
C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgoo
Ogmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c007o`000?nc/k?o/k>cok>c/ol0
003oVIVIo`000002ogmoO`03o`000?mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01_l0
003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00Go0000oiVIVOl0003o/k>co`00000:olc<c009o`00
0?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<0
1Ol0003oC4a<o`000?l0003oIVIV00;o000000GoVIVIo`000?nc/k?o/k>co`000003olc<c0Kooooo
0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo5?m<C4`00ol0003oIVIVofIV
IP0<ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02_nIVIT00ol0003o/k>cok>c
/`0Fok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl01omoOgl00ol0003oIVIVofIV
IP05ofIVIP03o`000?m<C4coC4a<01GoC4a<00?o0000ofIVI_mVIVH00_mVIVH00ol0003oOgmoogmo
O`02ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<
c003olc<c003o`000?nc/k?o/k>c00?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`04o`00
0?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co0000
00;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Oo
0000ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo00?o0000ofIVI_l000000om<C4`00ol0003o
<c<coc<c<`06oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl01Ol0003oVIVIo`000?nc
/k?o000000[oc<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0
003o<c<coc<c<`06oc<c<`03o`000?m<C4co000000;oIVIV0_l000001OnIVIWo0000ok>c/onc/k?o
000000?oc<c<1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00ooooolCoda<
C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0:oiVI
V@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`07ogmo
O`03o`000?mVIVKoIVIV00KoIVIV00?o0000oda<C?m<C4`05?m<C4`00ol0003oIVIVofIVIP03ofIV
IP05o`000?moOgooOgmoogmoOol000001?nIVIT00ol0003o/k>cok>c/`05ok>c/`03o`000?o<c<co
c<c<00;oc<c<00?o0000ok>c/onc/k<01?nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Go
0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`0
0_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<
c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@06o`000?moOgooOgmoo`000?mVIVKo0000
0om<C4`00ol0003o<c<coc<c<`06oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl01Ol0
003oVIVIo`000?nc/k?o000000Woc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mV
IVKo0000oda<C?l00008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV0_l000001OnIVIWo0000ok>c
/onc/k?o000000?oc<c<1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00ooo
oolBoda<C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVI
V@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmo
O`08ogmoO`03o`000?mVIVKoIVIV00GoIVIV00?o0000oda<C?m<C4`05?m<C4`00ol0003oIVIVofIV
IP04ofIVIP05o`000?moOgooOgmoogmoOol000001?nIVIT00ol0003o/k>cok>c/`04ok>c/`03o`00
0?o<c<coc<c<00;oc<c<00?o0000ok>c/onc/k<01?nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?o
Ogmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<
oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@05o`000?nc/k?o/k>cok>c/ol00000
2?o<c<`01ol0003o/k>cok>c/onc/k?o0000oiVIVOl000000_moOgl00ol0003oIVIVo`000003oda<
C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nI
VIWo000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0
003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Oo0000oda<C?m<C4co0000ofIVI_l0
003oOgmo00;o00000_nc/k<00ol0003oc<c<olc<c002olc<c0Kooooo0Ol00001ooooo`7ooooo000T
ooooo`;o00001?oooolAoda<C0;o00003OmVIVH00ol0003oOgmoogmoO`08ogmoO`;o00003?nIVIT2
o`0001So/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKo
IVIV00KoIVIV00?o0000oda<C?m<C4`05?m<C4`00ol0003oIVIVofIVIP03ofIVIP05o`000?moOgoo
OgmoogmoOol000001?nIVIT00ol0003o/k>cok>c/`04ok>c/`;o00001?o<c<`00ol0003o/k>cok>c
/`04ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000Co
C4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`00
00;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o
/k>co`0000;oVIVI00Ko0000ogmoOomoOgoo0000ofIVI_l00002oda<C0;o00002?lc<c<01_l0003o
C4a<oda<C?l0003oIVIVo`0000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006
olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c
<olc<c<01_lc<c<01Ol0003oC4a<oda<C?l0003oIVIV00;o000000GoVIVIo`000?nc/k?o/k>co`00
0004olc<c0Gooooo0_l00002ooooo`009?ooool00ol0003oooooooooo`03oooooa3oC4a<00?o0000
ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00[oVIVI00?o0000
ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000
ofIVI_mVIVH01_mVIVH00ol0003oC4a<oda<C00Eoda<C003o`000?mVIVKoIVIV00?oIVIV00Go0000
ogmoOomoOgooOgmoo`000004oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`00oo<
c<`00ol0003o/k>cok>c/`04ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01Ol0003oIVIV
ofIVI_mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<00ol0003oC4a<oda<C002oda<C006
o`000?mVIVKoIVIVo`000?moOgoo00000_nIVIT00ol0003o/k>cok>c/`02ok>c/`03o`000?o<c<co
c<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<
C4coC4a<o`0000Wo<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`03o`000?nIVIWo0000
00;o/k>c00?o0000olc<c?o<c<`01_o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000
ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4co0000ofIVIP02o`00
0005oiVIVOl0003o/k>cok>c/ol000001?o<c<`6ooooo`7o00000Oooool1ooooo`009?ooool00ol0
003oooooooooo`03ooooo`ooC4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmoO`09ogmo
O`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVI
V@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH01_mVIVH00ol0003oC4a<oda<C00Eoda<
C003o`000?mVIVKoIVIV00?oIVIV00?o0000ogmoOomoOgl00_moOgl01Ol0003oVIVIoiVIVOnIVIWo
000000Ko/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`04ok>c/`05o`000?nIVIWo
VIVIoiVIVOl000000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000CoC4a<00?o0000oc<c<olc<c<0
1Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co0000oiVIVOnI
VIWo00000onc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Ko0000
ogmoOomoOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Ko0000oda<C?m<C4co
0000ofIVI_l00002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`01ol0
003o/k>co`000?nIVIWo0000ogmoOol000000_mVIVH00ol0003oC4a<o`000008oc<c<`07o`000?m<
C4coC4a<o`000?mVIVKo0000ogmoO`02o`0000;o/k>c00?o0000olc<c?o<c<`00oo<c<`6ooooo`7o
00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`ooC4a<00?o0000ofIVI_mVIVH0
2omVIVH00ol0003oOgmoogmoO`08ogmoO`;o00003?nIVIT2o`0001So/k>c00?o0000oiVIVOnIVIT0
2_nIVIT2o`0000[oOgmo00?o0000ofIVI_mVIVH01omVIVH00ol0003oC4a<oda<C00Doda<C003o`00
0?mVIVKoIVIV00;oIVIV0_l00004ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<0
1?nc/k<00ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c00Co/k>c00Go0000oiVIVOnIVIWo
VIVIo`000003ogmoO`05o`000?mVIVKoIVIVofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c
<`05o`000?m<C4coC4a<oda<C?l000000omVIVH01?l0003oOgmoogmoOol00002oiVIV@03o`000?nc
/k?o/k>c00;o00001oo<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmoOol00000
0_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0
0002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmo
o`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`07o`000?m<C4coC4a<o`000?mVIVKo
0000ogmoO`02o`0000;o/k>c00?o0000olc<c?o<c<`00oo<c<`6ooooo`7o00000Oooool1ooooo`00
9?ooool00ol0003oooooooooo`03ooooo`koC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmo
ogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVI
oiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02?mVIVH00ol0003oC4a<
oda<C00Coda<C003o`000?mVIVKoIVIV00?oIVIV00?o0000ogmoOomoOgl00omoOgl01Ol0003oVIVI
oiVIVOnIVIWo000000Oo/k>c00?o0000olc<c?o<c<`00_o<c<`00ol0003o/k>cok>c/`04ok>c/`05
o`000?nIVIWoVIVIoiVIVOl000000omoOgl01?l0003oIVIVofIVI_l00004oda<C003o`000?lc<c?o
<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000003ofIVIP04o`000?moOgooOgmoo`0000;oVIVI
00Co0000ok>c/onc/k?o00002?o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmo
Ool000000_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000
ogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0
003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`07o`000?m<C4coC4a<o`00
0?mVIVKo0000ogmoO`02o`0000;o/k>c00?o0000olc<c?o<c<`00oo<c<`6ooooo`7o00000Oooool1
ooooo`009?ooool00ol0003oooooooooo`03ooooo`goC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0
003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0
003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02?mVIVH00ol0
003oC4a<oda<C00Doda<C003o`000?mVIVKoIVIV00;oIVIV00?o0000ogmoOomoOgl00omoOgl00ol0
003oVIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`00_o<c<`00ol0
003o/k>cok>c/`04ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01Ol0003oIVIVofIVI_mV
IVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000?oIVIV
00Co0000ogmoOomoOgoo00000_nIVIT01?l0003o/k>cok>c/ol00008olc<c003o`000?nc/k?o/k>c
00;o/k>c00Go0000oiVIVOl0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000Wo<c<c00Ko
0000oda<C?m<C4co0000ofIVI_l00002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<
c<`01_o<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo0_l00002oda<C003o`000?lc<c?o
<c<c00Ko<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00006
olc<c0Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo3?m<C4`00ol0
003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0
003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00[oVIVI0_l0000:ogmoO`03o`000?mVIVKoIVIV
00OoIVIV0_l0000Foda<C003o`000?mVIVKoIVIV00?oIVIV00?o0000ogmoOomoOgl00_moOgl00ol0
003oVIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c00Go/k>c00?o0000olc<c?o<c<`00_o<c<`00ol0
003o/k>cok>c/`04ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01Ol0003oIVIVofIVI_mV
IVKo000000CoC4a<00?o0000oc<c<olc<c<01Olc<c<2o`0000?oC4a<00Co0000ofIVI_mVIVKo0000
0_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc
/k?o/k>co`000002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<0
2?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo00000_nIVIT00ol0003o/k>co`000009olc<c00:
o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<0
1_lc<c<03?l0003oC4a<o`000?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Koc<c<
1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool;oda<C003o`000?mV
IVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc
/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mV
IVKoIVIV00SoIVIV00?o0000oda<C?m<C4`05Om<C4`00ol0003oIVIVofIVIP03ofIVIP03o`000?mo
OgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<
c<coc<c<00?oc<c<00?o0000ok>c/onc/k<01?nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo
00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<
C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000
olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmoOol000000_mV
IVH01?l0003oC4a<oda<C?l00009oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002
oiVIV@03o`000?nc/k?o000000Woc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mV
IVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`03o`000?m<C4co000000;oIVIV00Oo0000ogmo
Ool0003oVIVIo`000?nc/k?o000000Koc<c<1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000
ooooooooool00oooool:oda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl0
0ol0003oVIVIoiVIV@0;oiVIV@;o00006?nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgoo
Ogmo00SoOgmo00?o0000ofIVI_mVIVH02?mVIVH00ol0003oC4a<oda<C00Eoda<C003o`000?mVIVKo
IVIV00?oIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@02oiVIV@03o`000?nc/k?o
/k>c00Go/k>c00?o0000olc<c?o<c<`00_o<c<`00ol0003o/k>cok>c/`04ok>c/`05o`000?nIVIWo
VIVIoiVIVOl000000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000CoC4a<00?o0000oc<c<olc<c<0
1Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co0000oiVIVOnI
VIWo00000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT0
0ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000Wo<c<c00Co0000oda<C?m<C4co0000
0_mVIVH2o`0000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01?l0003o/k>cok>c/ol00002oiVI
V@;o000000GoIVIVo`000?m<C4coC4a<o`000008oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000
ogmoOol0003oVIVIo`000?nc/k?o00001oo<c<`6ooooo`7o00000Oooool1ooooo`009?ooool00ol0
003oooooooooo`03ooooo`WoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmo
O`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0:oiVI
V@;o00002_moOgl00ol0003oIVIVofIVIP08ofIVIP03o`000?m<C4coC4a<01GoC4a<00?o0000ofIV
I_mVIVH00omVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c
/onc/k<01Onc/k<00ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c00Co/k>c00Go0000oiVI
VOnIVIWoVIVIo`000003ogmoO`05o`000?mVIVKoIVIVofIVI_l000001?m<C4`00ol0003o<c<coc<c
<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVI
oiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVI
V@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<02Ol0003oC4a<oda<C?m<
C4co0000ofIVI_l0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00[o0000ok>c
/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`09
o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVI00;o00002?o<c<`6ooooo`7o00000Ooo
ool1ooooo`009?ooool2o`0000Cooooo2?m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgoo
Ogmo00SoOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWo
VIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP09ofIVIP03o`000?m<C4co
C4a<01GoC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWo
VIVI00;oVIVI00?o0000ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c002olc<c003o`000?nc/k?o
/k>c00Co/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`05o`000?mVIVKoIVIVofIVI_l00000
1?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo
00000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c
/onc/k?o/k>co`000002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc
<c<02Ol0003oC4a<oda<C?m<C4co0000ofIVI_l0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>c
o`0000Ooc<c<00_o0000ok>c/onc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<
C003o`000?lc<c?o<c<c00Ko<c<c00Wo0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIT0
0_l00008olc<c0Gooooo0_l00002ooooo`009?ooool00ol0003oooooooooo`03ooooo`OoC4a<00?o
0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI0_l0
000Hok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIV
IP09ofIVIP03o`000?m<C4coC4a<01GoC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmo
O`02ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<
c002olc<c003o`000?nc/k?o/k>c00Co/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`05o`00
0?mVIVKoIVIVofIVI_l000001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;o
C4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<co
c<c<00Ooc<c<00Co0000ok>c/onc/k?o00000_nIVIT01_l0003oOgmoogmoOol0003oIVIVo`0000;o
C4a<00?o0000oc<c<olc<c<01_lc<c<02Ol0003oC4a<oda<C?m<C4co0000ofIVI_l0003oOgmoo`00
0002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmo
o`0000;oIVIV00?o0000oda<C?l000002?lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo
0000oiVIVOl0003o/k>co`0000Soc<c<1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000oooo
ooooool00oooool6oda<C003o`000?mVIVKoIVIV00[oIVIV0_l0000:ogmoO`03o`000?nIVIWoVIVI
00_oVIVI00?o0000ok>c/onc/k<05_nc/k<2o`0000goVIVI00?o0000ogmoOomoOgl02?moOgl00ol0
003oIVIVofIVIP09ofIVIP03o`000?m<C4coC4a<01GoC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0
003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<01Onc/k<01Ol0
003oc<c<olc<c?o<c<co000000Oo/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`04o`000?mV
IVKoIVIVo`0000GoC4a<00?o0000oc<c<olc<c<01Olc<c<01Ol0003oC4a<oda<C?m<C4co000000?o
IVIV00Co0000ogmoOomoOgoo00000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Oo0000
ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo00000_m<C4`00ol0003o
<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0
003o/k>cok>c/ol00008olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`00
00;oC4a<00?o0000oc<c<olc<c<01_lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000
oiVIVOl0003o/k>co`0000Soc<c<1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000oooooooo
ool00oooool5oda<C003o`000?mVIVKoIVIV00[oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003o
VIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT2o`0000[o
Ogmo00?o0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<oda<C00Doda<C003o`000?mVIVKoIVIV00Co
IVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c00Go
/k>c00Go0000olc<c?o<c<coc<c<o`000006ok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000ogmo
OomoOgooOgmoo`000002ofIVIP03o`000?m<C4coC4a<00?oC4a<00?o0000oc<c<olc<c<01?lc<c<0
0ol0003oC4a<oda<C002oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01?l0003oVIVIoiVI
VOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo0000
00;oOgmo00Co0000ofIVI_mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4co
C4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00008olc<c00:o`00
0?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc
<c<00ol0003oC4a<oda<C002o`0000;oOgmo00Go0000oiVIVOl0003o/k>co`000008olc<c003o`00
0?oooooooooo00?ooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo1?m<
C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onI
VIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02Omo
Ogl00ol0003oIVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<01GoC4a<00?o0000ofIVI_mVIVH00omV
IVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<01Onc
/k<01Ol0003oc<c<olc<c?o<c<co000000Oo/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`04
o`000?mVIVKoIVIVo`0000GoC4a<00?o0000oc<c<olc<c<01Olc<c<01Ol0003oC4a<oda<C?m<C4co
000000?oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<
00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo00000_m<C4`0
0ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Ko0000ogmoOomoOgoo0000
oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002
ogmoO`;o00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000
ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003oooooooooo`03oooo
o`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`?oC4a<00?o0000ofIVI_mV
IVH02_mVIVH2o`0000[oOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03
o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0:ofIVIP03
o`000?m<C4coC4a<01GoC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`03ogmoO`03
o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01_nc/k<01?l0003oc<c<olc<c?l00007ok>c
/`04o`000?nIVIWoVIVIoiVIV@;o00000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000CoC4a<00?o
0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo
00Go0000oiVIVOnIVIWoVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Co0000ok>c/onc
/k?o00000_nIVIT01_l0003oOgmoogmoOol0003oIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc
<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00?o0000ok>c/ol00000
2Oo<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc
<c?o<c<c00Ko<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol0
0008olc<c003o`000?oooooooooo00Cooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooo
oooo00?ooooo0_m<C4`00ol0003oIVIVofIVIP0:ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000
oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI0_l0000:
ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05Om<C4`00ol0003oIVIVofIVIP03
ofIVIP03o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`06
ok>c/`04o`000?o<c<coc<c<o`0000Oo/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`05o`00
0?mVIVKoIVIVofIVI_l000001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;o
C4a<00Co0000ofIVI_mVIVKo00000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000;o/k>c00?o0000
olc<c?o<c<`01oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@06o`000?moOgooOgmoo`000?mVIVKo
00000om<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmo
Ool000000_nIVIT00ol0003o/k>co`000009olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmo
Ool0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<00ol0003oC4a<o`000002ofIVIP07
o`000?moOgoo0000oiVIVOl0003o/k>co`000008olc<c003o`000?oooooooooo00Cooooo0Ol00001
ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo00?oC4a<o`000?mVIVH03?mVIVH00ol0
003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0
003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0
003oC4a<oda<C00Eoda<C003o`000?mVIVKoIVIV00?oIVIV00?o0000ogmoOomoOgl00_moOgl00ol0
003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c00Ko/k>c00Co0000olc<c?o<c<co00001onc/k<0
1Ol0003oVIVIoiVIVOnIVIWo000000CoOgmo00Co0000ofIVI_mVIVKo00001Om<C4`00ol0003o<c<c
oc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003o
VIVIoiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Co0000ok>c/onc/k?o00000_nIVIT0
1?l0003oOgmoogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Go0000oda<C?m<C4co
C4a<o`000002ofIVIP;o00000_nIVIT01?l0003o/k>cok>c/ol00008olc<c004o`000?nc/k?o/k>c
o`0000;oVIVI0_l000001OmVIVKo0000oda<C?m<C4co000000So<c<c00So0000oda<C?m<C4co0000
ofIVI_l0003oOgmoo`0000;oVIVI0_l00008olc<c003o`000?nc/k?ooooo00Gooooo0Ol00001oooo
o`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo00?o0000ofIVI_mVIVH02omVIVH00ol0003o
OgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003o
VIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003o
C4a<oda<C00Doda<C0;o00001OmVIVH00ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00;o
VIVI00?o0000ok>c/onc/k<01onc/k<00ol0003oc<c<o`000008ok>c/`05o`000?nIVIWoVIVIoiVI
VOl000000omoOgl01Ol0003oIVIVofIVI_mVIVKo000000CoC4a<00?o0000oc<c<olc<c<01Olc<c<0
0ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo0000
0onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01_l0003o
OgmoogmoOol0003oIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l0
0002ofIVIP05o`000?moOgoo0000oiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c00:o`00
0?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc
<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Soc<c<00?o
0000ok>c/oooool01Oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool=
ofIVIP03o`000?moOgooOgmo00SoOgmo0_l0000<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000
oiVIVOnIVIT02onIVIT2o`0000[oOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00E
oda<C003o`000?mVIVKoIVIV00CoIVIV00?o0000ogmoOomoOgl00omoOgl00ol0003oVIVIoiVIV@02
oiVIV@03o`000?nc/k?o/k>c00Oo/k>c00?o0000olc<c?l000001onc/k<00ol0003oVIVIoiVIV@02
oiVIV@05o`000?moOgooOgmoogmoOol000000omVIVH00ol0003oC4a<oda<C002oda<C003o`000?lc
<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00om<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`00
0?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o0000
00;oVIVI00Ko0000ogmoOomoOgoo0000ofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co
0000oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000?o/k>c00?o0000olc<c?o<
c<`01Oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`0
0ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<o`000?mVIVH00_l00002oiVIV@03o`000?nc
/k?o000000Soc<c<00?o0000ok>c/oooool01Oooool1o`00007ooooo0Oooool002Cooooo0_l00004
ooooo`_oIVIV0_l0000:ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<0
0ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH0
0ol0003oC4a<oda<C00Eoda<C003o`000?mVIVKoIVIV00CoIVIV00?o0000ogmoOomoOgl00omoOgl0
0ol0003oVIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c00Wo/k>c00?o0000ok>c/onc/k<01_nc/k<0
1Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`00
0?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04
o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c
/`08o`000?nIVIWoVIVIo`000?moOgoo0000ofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c
00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`00
00Soc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV00Co0000oda<C?m<C4co
00001olc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000So
c<c<00Co0000ok>c/onc/k?o00001?ooool2o`0000;ooooo000Tooooo`03o`000?oooooooooo00?o
oooo2_mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc
/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mV
IVH02omVIVH00ol0003oC4a<oda<C00Eoda<C003o`000?mVIVKoIVIV00CoIVIV00?o0000ogmoOomo
Ogl00omoOgl00ol0003oVIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c01;o/k>c00Go0000oiVIVOnI
VIWoVIVIo`000003ogmoO`05o`000?mVIVKoIVIVofIVI_l000001Om<C4`00ol0003o<c<coc<c<`04
oc<c<`03o`000?m<C4coC4a<00;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`04o`000?nI
VIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;o
VIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`04o`000?m<C4coC4a<
o`0000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00[o
0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06
oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00002?o<c<`0
1?l0003o/k>cok>c/ol00005ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03
ooooo`[oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0:oiVIV@03o`000?nc/k?o
/k>c01Ko/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKo
IVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP04ofIVIP03o`000?moOgoo
Ogmo00?oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`0Bok>c/`05o`000?nIVIWo
VIVIoiVIVOl000000omoOgl01Ol0003oIVIVofIVI_mVIVKo000000GoC4a<00?o0000oc<c<olc<c<0
1?lc<c<00ol0003oC4a<oda<C002oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01?l0003o
VIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002
oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<01?l0003oC4a<oda<
C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c00:
o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<0
1_lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Soc<c<
00Co0000ok>c/onc/k?o00001Oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool0
0oooool9ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02_nIVIT00ol0003o/k>c
ok>c/`0Fok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIV
ofIVIP0<ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmo
ogmoO`03ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<04Onc/k<00ol0003oVIVI
oiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol000000omVIVH00ol0003oC4a<oda<C002oda<C003
o`000?lc<c?o<c<c00Go<c<c00Go0000oda<C?m<C4coC4a<o`000003ofIVIP04o`000?moOgooOgmo
o`0000?oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c005o`000?nc/k?o/k>cok>c/ol00000
0_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000Wo<c<c00Ko0000oda<C?m<
C4co0000ofIVI_l00002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`0
0ol0003o/k>co`000002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c
<`06oc<c<`03o`000?m<C4coC4a<00;o00000_moOgl01Ol0003oVIVIo`000?nc/k?o000000Soc<c<
00Co0000ok>c/onc/k?o00001Oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool0
0oooool8ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>c
ok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIV
ofIVIP0<ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH01?mVIVH00ol0003oOgmo
ogmoO`03ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<04_nc/k<01Ol0003oVIVI
oiVIVOnIVIWo000000CoOgmo00Co0000ofIVI_mVIVKo00001Om<C4`00ol0003o<c<coc<c<`04oc<c
<`03o`000?m<C4coC4a<00;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`04o`000?nIVIWo
VIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI
00?o0000ogmoOol000000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Co0000oda<C?m<
C4co00000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`0
1_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo0_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c
00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<
c006olc<c003o`000?nc/k?o000000Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooo
oooo00?ooooo1omVIVH00ol0003oOgmoogmoO`08ogmoO`;o00003?nIVIT2o`0001So/k>c00?o0000
oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV0_l0000H
oda<C003o`000?mVIVKoIVIV00CoIVIV00?o0000ogmoOomoOgl00omoOgl00ol0003oVIVIoiVIV@03
oiVIV@03o`000?nc/k?o/k>c017o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomo
Ogoo000000?oIVIV00?o0000oda<C?m<C4`00_m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<
C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000omoOgl01?l0003oVIVIoiVIVOl00003ok>c/`03
o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@03o`000?moOgoo0000
00;oIVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Go
0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00?o0000ok>c/ol00000
0_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<03?l0003o
C4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Soc<c<00Co0000ok>c/onc
/k?o00001_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool6ofIVIP03
o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02_nIVIT00ol0003o/k>cok>c/`0Gok>c/`03
o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03
o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH01OmVIVH00ol0003oOgmoogmoO`03ogmoO`03
o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<04_nc/k<00ol0003oVIVIoiVIV@02oiVIV@05
o`000?moOgooOgmoogmoOol000000omVIVH00ol0003oC4a<oda<C002oda<C003o`000?lc<c?o<c<c
00Co<c<c00?o0000oda<C?m<C4`00om<C4`01?l0003oIVIVofIVI_l00003ogmoO`04o`000?nIVIWo
VIVIo`0000?o/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`06o`000?nI
VIWoVIVIo`000?moOgoo00000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`04o`000?m<C4coC4a<
o`0000?oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Go
0000ok>c/ol0003oVIVIo`000002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<0
1_lc<c<00ol0003oC4a<o`000002ofIVIP04o`000?moOgoo0000o`0000;o/k>c00?o0000olc<c?o<
c<`01_o<c<`01?l0003o/k>cok>c/ol00006ooooo`7o00000Oooool1ooooo`009?ooool00ol0003o
ooooooooo`03ooooo`GoIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03
o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03
o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP05ofIVIP03
o`000?moOgooOgmo00?oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`0Bok>c/`03
o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`000003ofIVIP03o`000?m<C4coC4a<
00;oC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIV
o`0000?oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc
/k?o/k>cok>c/ol000000_nIVIT01_l0003oOgmoogmoOol0003oIVIVo`0000?oC4a<00?o0000oc<c
<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc
/k<00ol0003oc<c<olc<c007olc<c003o`000?nc/k?o000000;oVIVI00Go0000ogmoOol0003oIVIV
o`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmo
o`000?nIVIWo0000ok>c/ol00008olc<c006o`000?nc/k?o/k>co`000?nIVIWo00001Oooool1o`00
007ooooo0Oooool001;ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^1_oo
ool00ol0003oooooooooo`03ooooo`CoIVIV00?o0000ogmoOomoOgl02?moOgl2o`0000coVIVI0_l0
000Hok>c/`03o`000?nIVIWoVIVI00[oVIVI0_l0000:ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o
0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP05ofIVIP03o`000?moOgooOgmo00?oOgmo00?o
0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0Bok>c/`05o`000?nIVIWoVIVIoiVIVOl00000
0omoOgl01Ol0003oIVIVofIVI_mVIVKo000000GoC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003o
C4a<oda<C003oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<0
0ol0003oc<c<olc<c006olc<c003o`000?nc/k?o/k>c00;o000000GoVIVIo`000?moOgooOgmoo`00
0002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo0000
00;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c003o`000?nc/k?o0000
00;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00co0000
oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00008olc<c006o`000?nc/k?o
/k>co`000?nIVIWo00001Oooool1o`00007ooooo0Oooool001Cooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool00oooool3ofIVIP03o`00
0?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`00
0?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`00
0?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0003oOgmoogmoO`03ogmoO`03o`00
0?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<04_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;o
Ogmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C003oda<C003o`000?lc<c?o<c<c00Co
<c<c00?o0000oda<C?m<C4`00om<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVI
o`0000Co/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@04o`000?mo
OgooOgmoo`0000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<01ol0003oC4a<oda<C?m<C4co0000
ofIVI_l000000_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000
ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<0
1_lc<c<01Ol0003oC4a<oda<C?l0003oIVIV00;o00000_nIVIT00ol0003o/k>co`000008olc<c006
o`000?nc/k?o/k>co`000?nIVIWo00001Oooool1o`00007ooooo0Oooool001Cooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool00oooool2
ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0G
ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;
ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0003oOgmoogmoO`03
ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<04_nc/k<01Ol0003oVIVIoiVIVOnI
VIWo000000?oOgmo00Go0000ofIVI_mVIVKoIVIVo`000005oda<C003o`000?lc<c?o<c<c00Co<c<c
00?o0000oda<C?m<C4`00om<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`00
00Co/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@04o`000?moOgoo
Ogmoo`0000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<01_l0003oC4a<oda<C?l0003oIVIVo`00
00;oOgmo00Co0000oiVIVOnIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c003o`000?nc/k?o
000000;oVIVI00?o0000ogmoOol000000_mVIVH00ol0003oC4a<o`000008oc<c<`0<o`000?m<C4co
C4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00002Oo<c<`01Ol0003o/k>co`000?nI
VIWo000000Kooooo0Ol00001ooooo`7ooooo000Dooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000006ooooo`?o00000oooool00omVIVKo0000ogmoO`09ogmoO`03o`000?nI
VIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?mo
OgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Hoda<C003o`000?mV
IVKoIVIV00GoIVIV00?o0000ogmoOomoOgl00omoOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc
/k?o/k>c01;o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000?oIVIV
00?o0000oda<C?m<C4`00_m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<
00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<
c?o<c<`01oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Co
0000oda<C?m<C4co00002Olc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00?o0000oiVI
VOl000000_nc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Go0000
ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00co0000oda<C?m<C4co0000
ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00009olc<c005o`000?nc/k?o0000o`000?moOgl0
1?ooool3o`0000;ooooo000Dooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo0?oooooo?oooool1o`00007ooooo0Oooool001Cooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool0
ooooooloooooo`7o00000Oooool1ooooo`005?ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3oooooocoooooo0Ol00001ooooo`7ooooo
000Booooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Wooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`03ooooo`7o0000
0Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo0Ol0
0001ooooo`7ooooo000Toooooooo0000@ol00002ooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-7.04757, -6.93977, 0.0606246, \
0.0606246}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.339744 0.0641026 0.339744 0.0641026 [
[.08333 -0.0125 -6 -9 ]
[.08333 -0.0125 6 0 ]
[.21154 -0.0125 -6 -9 ]
[.21154 -0.0125 6 0 ]
[.33974 -0.0125 -3 -9 ]
[.33974 -0.0125 3 0 ]
[.46795 -0.0125 -3 -9 ]
[.46795 -0.0125 3 0 ]
[.59615 -0.0125 -3 -9 ]
[.59615 -0.0125 3 0 ]
[.72436 -0.0125 -3 -9 ]
[.72436 -0.0125 3 0 ]
[.85256 -0.0125 -3 -9 ]
[.85256 -0.0125 3 0 ]
[.98077 -0.0125 -6 -9 ]
[.98077 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5 -21 ]
[.5 -0.0125 5 -9 ]
[-0.0125 .08333 -12 -4.5 ]
[-0.0125 .08333 0 4.5 ]
[-0.0125 .21154 -12 -4.5 ]
[-0.0125 .21154 0 4.5 ]
[-0.0125 .33974 -6 -4.5 ]
[-0.0125 .33974 0 4.5 ]
[-0.0125 .46795 -6 -4.5 ]
[-0.0125 .46795 0 4.5 ]
[-0.0125 .59615 -6 -4.5 ]
[-0.0125 .59615 0 4.5 ]
[-0.0125 .72436 -6 -4.5 ]
[-0.0125 .72436 0 4.5 ]
[-0.0125 .85256 -6 -4.5 ]
[-0.0125 .85256 0 4.5 ]
[-0.0125 .98077 -12 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -24 -5 ]
[-0.01875 .5 -12 5 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08333 0 m
.08333 .00625 L
s
[(-4)] .08333 -0.0125 0 1 Mshowa
.21154 0 m
.21154 .00625 L
s
[(-2)] .21154 -0.0125 0 1 Mshowa
.33974 0 m
.33974 .00625 L
s
[(0)] .33974 -0.0125 0 1 Mshowa
.46795 0 m
.46795 .00625 L
s
[(2)] .46795 -0.0125 0 1 Mshowa
.59615 0 m
.59615 .00625 L
s
[(4)] .59615 -0.0125 0 1 Mshowa
.72436 0 m
.72436 .00625 L
s
[(6)] .72436 -0.0125 0 1 Mshowa
.85256 0 m
.85256 .00625 L
s
[(8)] .85256 -0.0125 0 1 Mshowa
.98077 0 m
.98077 .00625 L
s
[(10)] .98077 -0.0125 0 1 Mshowa
.125 Mabswid
.11538 0 m
.11538 .00375 L
s
.14744 0 m
.14744 .00375 L
s
.17949 0 m
.17949 .00375 L
s
.24359 0 m
.24359 .00375 L
s
.27564 0 m
.27564 .00375 L
s
.30769 0 m
.30769 .00375 L
s
.37179 0 m
.37179 .00375 L
s
.40385 0 m
.40385 .00375 L
s
.4359 0 m
.4359 .00375 L
s
.5 0 m
.5 .00375 L
s
.53205 0 m
.53205 .00375 L
s
.5641 0 m
.5641 .00375 L
s
.62821 0 m
.62821 .00375 L
s
.66026 0 m
.66026 .00375 L
s
.69231 0 m
.69231 .00375 L
s
.75641 0 m
.75641 .00375 L
s
.78846 0 m
.78846 .00375 L
s
.82051 0 m
.82051 .00375 L
s
.88462 0 m
.88462 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.94872 0 m
.94872 .00375 L
s
.05128 0 m
.05128 .00375 L
s
.01923 0 m
.01923 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66 -25 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .08333 m
.00625 .08333 L
s
[(-4)] -0.0125 .08333 1 0 Mshowa
0 .21154 m
.00625 .21154 L
s
[(-2)] -0.0125 .21154 1 0 Mshowa
0 .33974 m
.00625 .33974 L
s
[(0)] -0.0125 .33974 1 0 Mshowa
0 .46795 m
.00625 .46795 L
s
[(2)] -0.0125 .46795 1 0 Mshowa
0 .59615 m
.00625 .59615 L
s
[(4)] -0.0125 .59615 1 0 Mshowa
0 .72436 m
.00625 .72436 L
s
[(6)] -0.0125 .72436 1 0 Mshowa
0 .85256 m
.00625 .85256 L
s
[(8)] -0.0125 .85256 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(10)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .11538 m
.00375 .11538 L
s
0 .14744 m
.00375 .14744 L
s
0 .17949 m
.00375 .17949 L
s
0 .24359 m
.00375 .24359 L
s
0 .27564 m
.00375 .27564 L
s
0 .30769 m
.00375 .30769 L
s
0 .37179 m
.00375 .37179 L
s
0 .40385 m
.00375 .40385 L
s
0 .4359 m
.00375 .4359 L
s
0 .5 m
.00375 .5 L
s
0 .53205 m
.00375 .53205 L
s
0 .5641 m
.00375 .5641 L
s
0 .62821 m
.00375 .62821 L
s
0 .66026 m
.00375 .66026 L
s
0 .69231 m
.00375 .69231 L
s
0 .75641 m
.00375 .75641 L
s
0 .78846 m
.00375 .78846 L
s
0 .82051 m
.00375 .82051 L
s
0 .88462 m
.00375 .88462 L
s
0 .91667 m
.00375 .91667 L
s
0 .94872 m
.00375 .94872 L
s
0 .05128 m
.00375 .05128 L
s
0 .01923 m
.00375 .01923 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
-0.01875 .5 -84 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
66 10 translate
90 rotate
-66 -10 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.08333 .99375 m
.08333 1 L
s
.21154 .99375 m
.21154 1 L
s
.33974 .99375 m
.33974 1 L
s
.46795 .99375 m
.46795 1 L
s
.59615 .99375 m
.59615 1 L
s
.72436 .99375 m
.72436 1 L
s
.85256 .99375 m
.85256 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.11538 .99625 m
.11538 1 L
s
.14744 .99625 m
.14744 1 L
s
.17949 .99625 m
.17949 1 L
s
.24359 .99625 m
.24359 1 L
s
.27564 .99625 m
.27564 1 L
s
.30769 .99625 m
.30769 1 L
s
.37179 .99625 m
.37179 1 L
s
.40385 .99625 m
.40385 1 L
s
.4359 .99625 m
.4359 1 L
s
.5 .99625 m
.5 1 L
s
.53205 .99625 m
.53205 1 L
s
.5641 .99625 m
.5641 1 L
s
.62821 .99625 m
.62821 1 L
s
.66026 .99625 m
.66026 1 L
s
.69231 .99625 m
.69231 1 L
s
.75641 .99625 m
.75641 1 L
s
.78846 .99625 m
.78846 1 L
s
.82051 .99625 m
.82051 1 L
s
.88462 .99625 m
.88462 1 L
s
.91667 .99625 m
.91667 1 L
s
.94872 .99625 m
.94872 1 L
s
.05128 .99625 m
.05128 1 L
s
.01923 .99625 m
.01923 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .08333 m
1 .08333 L
s
.99375 .21154 m
1 .21154 L
s
.99375 .33974 m
1 .33974 L
s
.99375 .46795 m
1 .46795 L
s
.99375 .59615 m
1 .59615 L
s
.99375 .72436 m
1 .72436 L
s
.99375 .85256 m
1 .85256 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .11538 m
1 .11538 L
s
.99625 .14744 m
1 .14744 L
s
.99625 .17949 m
1 .17949 L
s
.99625 .24359 m
1 .24359 L
s
.99625 .27564 m
1 .27564 L
s
.99625 .30769 m
1 .30769 L
s
.99625 .37179 m
1 .37179 L
s
.99625 .40385 m
1 .40385 L
s
.99625 .4359 m
1 .4359 L
s
.99625 .5 m
1 .5 L
s
.99625 .53205 m
1 .53205 L
s
.99625 .5641 m
1 .5641 L
s
.99625 .62821 m
1 .62821 L
s
.99625 .66026 m
1 .66026 L
s
.99625 .69231 m
1 .69231 L
s
.99625 .75641 m
1 .75641 L
s
.99625 .78846 m
1 .78846 L
s
.99625 .82051 m
1 .82051 L
s
.99625 .88462 m
1 .88462 L
s
.99625 .91667 m
1 .91667 L
s
.99625 .94872 m
1 .94872 L
s
.99625 .05128 m
1 .05128 L
s
.99625 .01923 m
1 .01923 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.3 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.4 g
.01923 .90293 m
.02881 .89336 L
.02894 .89321 L
.03851 .88364 L
.03866 .8835 L
.04823 .87393 L
.04837 .87379 L
.05794 .86422 L
.05808 .86408 L
.06765 .85451 L
.06779 .85436 L
.07736 .84479 L
.07751 .84465 L
.08708 .83508 L
.08722 .83494 L
.09679 .82537 L
.09693 .82523 L
.1065 .81566 L
.10664 .81551 L
.11621 .80594 L
.11636 .8058 L
.12593 .79623 L
.12607 .79609 L
.13564 .78652 L
.13578 .78638 L
.14535 .77681 L
.14549 .77666 L
.15506 .76709 L
.15521 .76695 L
.16478 .75738 L
.16492 .75724 L
.17449 .74767 L
.17463 .74753 L
.1842 .73796 L
.18434 .73781 L
.19391 .72824 L
.19406 .7281 L
.20363 .71853 L
.20377 .71839 L
.21334 .70882 L
.21348 .70868 L
.22305 .69911 L
.22319 .69896 L
.23276 .68939 L
.23291 .68925 L
.24248 .67968 L
.24262 .67954 L
.25219 .66997 L
.25233 .66983 L
.2619 .66026 L
.26204 .66011 L
.27161 .65054 L
.27176 .6504 L
.28133 .64083 L
.28147 .64069 L
.29104 .63112 L
.29118 .63098 L
.30075 .62141 L
.30089 .62126 L
.31046 .61169 L
.31061 .61155 L
.32018 .60198 L
.32032 .60184 L
.32989 .59227 L
.33003 .59213 L
.33962 .58256 L
.33974 .58241 L
.34689 .57284 L
.34946 .56925 L
.35398 .56313 L
.35917 .55605 L
.36109 .55342 L
.36811 .54371 L
.36888 .54263 L
.375 .53399 L
.37859 .52888 L
.38178 .52428 L
.38831 .51481 L
.38847 .51457 L
.395 .50486 L
.39802 .50033 L
.40142 .49514 L
.40773 .4855 L
.40778 .48543 L
.41397 .47572 L
.41744 .47025 L
.42008 .46601 L
.42612 .45629 L
.42716 .45462 L
.43202 .44658 L
.43687 .43858 L
.43788 .43687 L
.44363 .42716 L
.44658 .42216 L
.44929 .41744 L
.45492 .40773 L
.45629 .40535 L
.46041 .39802 L
.46592 .38831 L
.46601 .38816 L
.47127 .37859 L
.47572 .37057 L
.47662 .36888 L
.48187 .35917 L
.48543 .35262 L
.48708 .34946 L
.49224 .33974 L
.49514 .33429 L
.49732 .33003 L
.5024 .32032 L
.50486 .3156 L
.50736 .31061 L
.51235 .30089 L
.51457 .29656 L
.51721 .29118 L
.52211 .28147 L
.52428 .27716 L
.52689 .27176 L
.5317 .26204 L
.53399 .2574 L
.53639 .25233 L
.54112 .24262 L
.54371 .23731 L
.54574 .23291 L
.55039 .22319 L
.55342 .21687 L
.55495 .21348 L
.55951 .20377 L
.56313 .1961 L
.56404 .19406 L
.56849 .18434 L
.57284 .17501 L
.57301 .17463 L
.57735 .16492 L
.58181 .15521 L
.58256 .15358 L
.58609 .14549 L
.59049 .13578 L
.59227 .13183 L
.59472 .12607 L
.59904 .11636 L
.60198 .10976 L
.60327 .10664 L
.60749 .09693 L
.61169 .08739 L
.61176 .08722 L
.61584 .07751 L
.62006 .06779 L
.62141 .06469 L
.6241 .05808 L
.62826 .04837 L
.63112 .04169 L
.63231 .03866 L
.63636 .02894 L
.64048 .01923 L
.01923 .01923 L
F
0 g
.01923 .90293 m
.02881 .89336 L
.02894 .89321 L
.03851 .88364 L
.03866 .8835 L
.04823 .87393 L
.04837 .87379 L
.05794 .86422 L
.05808 .86408 L
.06765 .85451 L
.06779 .85436 L
.07736 .84479 L
.07751 .84465 L
.08708 .83508 L
.08722 .83494 L
.09679 .82537 L
.09693 .82523 L
.1065 .81566 L
.10664 .81551 L
.11621 .80594 L
.11636 .8058 L
.12593 .79623 L
.12607 .79609 L
.13564 .78652 L
.13578 .78638 L
.14535 .77681 L
.14549 .77666 L
.15506 .76709 L
.15521 .76695 L
.16478 .75738 L
.16492 .75724 L
.17449 .74767 L
.17463 .74753 L
.1842 .73796 L
.18434 .73781 L
.19391 .72824 L
.19406 .7281 L
.20363 .71853 L
.20377 .71839 L
.21334 .70882 L
.21348 .70868 L
.22305 .69911 L
.22319 .69896 L
.23276 .68939 L
.23291 .68925 L
.24248 .67968 L
.24262 .67954 L
.25219 .66997 L
.25233 .66983 L
.2619 .66026 L
Mistroke
.26204 .66011 L
.27161 .65054 L
.27176 .6504 L
.28133 .64083 L
.28147 .64069 L
.29104 .63112 L
.29118 .63098 L
.30075 .62141 L
.30089 .62126 L
.31046 .61169 L
.31061 .61155 L
.32018 .60198 L
.32032 .60184 L
.32989 .59227 L
.33003 .59213 L
.33962 .58256 L
.33974 .58241 L
.34689 .57284 L
.34946 .56925 L
.35398 .56313 L
.35917 .55605 L
.36109 .55342 L
.36811 .54371 L
.36888 .54263 L
.375 .53399 L
.37859 .52888 L
.38178 .52428 L
.38831 .51481 L
.38847 .51457 L
.395 .50486 L
.39802 .50033 L
.40142 .49514 L
.40773 .4855 L
.40778 .48543 L
.41397 .47572 L
.41744 .47025 L
.42008 .46601 L
.42612 .45629 L
.42716 .45462 L
.43202 .44658 L
.43687 .43858 L
.43788 .43687 L
.44363 .42716 L
.44658 .42216 L
.44929 .41744 L
.45492 .40773 L
.45629 .40535 L
.46041 .39802 L
.46592 .38831 L
.46601 .38816 L
Mistroke
.47127 .37859 L
.47572 .37057 L
.47662 .36888 L
.48187 .35917 L
.48543 .35262 L
.48708 .34946 L
.49224 .33974 L
.49514 .33429 L
.49732 .33003 L
.5024 .32032 L
.50486 .3156 L
.50736 .31061 L
.51235 .30089 L
.51457 .29656 L
.51721 .29118 L
.52211 .28147 L
.52428 .27716 L
.52689 .27176 L
.5317 .26204 L
.53399 .2574 L
.53639 .25233 L
.54112 .24262 L
.54371 .23731 L
.54574 .23291 L
.55039 .22319 L
.55342 .21687 L
.55495 .21348 L
.55951 .20377 L
.56313 .1961 L
.56404 .19406 L
.56849 .18434 L
.57284 .17501 L
.57301 .17463 L
.57735 .16492 L
.58181 .15521 L
.58256 .15358 L
.58609 .14549 L
.59049 .13578 L
.59227 .13183 L
.59472 .12607 L
.59904 .11636 L
.60198 .10976 L
.60327 .10664 L
.60749 .09693 L
.61169 .08739 L
.61176 .08722 L
.61584 .07751 L
.62006 .06779 L
.62141 .06469 L
.6241 .05808 L
Mistroke
.62826 .04837 L
.63112 .04169 L
.63231 .03866 L
.63636 .02894 L
.64048 .01923 L
Mfstroke
.5 g
.01923 .85921 m
.02394 .85451 L
.02894 .84949 L
.03364 .84479 L
.03866 .83978 L
.04336 .83508 L
.04837 .83007 L
.05307 .82537 L
.05808 .82036 L
.06278 .81566 L
.06779 .81064 L
.07249 .80594 L
.07751 .80093 L
.08221 .79623 L
.08722 .79122 L
.09192 .78652 L
.09693 .78151 L
.10163 .77681 L
.10664 .77179 L
.11134 .76709 L
.11636 .76208 L
.12106 .75738 L
.12607 .75237 L
.13077 .74767 L
.13578 .74266 L
.14048 .73796 L
.14549 .73294 L
.15019 .72824 L
.15521 .72323 L
.15991 .71853 L
.16492 .71352 L
.16962 .70882 L
.17463 .70381 L
.17933 .69911 L
.18434 .69409 L
.18904 .68939 L
.19406 .68438 L
.19876 .67968 L
.20377 .67467 L
.20847 .66997 L
.21348 .66496 L
.21818 .66026 L
.22319 .65524 L
.22789 .65054 L
.23291 .64553 L
.23761 .64083 L
.24262 .63582 L
.24732 .63112 L
.25233 .62611 L
.25703 .62141 L
.26204 .61639 L
.26674 .61169 L
.27176 .60668 L
.27646 .60198 L
.28147 .59697 L
.28617 .59227 L
.29118 .58726 L
.29588 .58256 L
.30089 .57754 L
.30559 .57284 L
.31061 .56783 L
.31531 .56313 L
.32032 .55812 L
.32502 .55342 L
.33003 .54841 L
.33482 .54371 L
.33974 .53869 L
.34407 .53399 L
.34946 .52799 L
.35271 .52428 L
.35917 .5167 L
.36096 .51457 L
.36887 .50486 L
.36888 .50484 L
.37651 .49514 L
.37859 .49243 L
.38389 .48543 L
.38831 .47948 L
.39105 .47572 L
.39802 .46601 L
.39802 .46601 L
.40481 .45629 L
.40773 .45203 L
.41143 .44658 L
.41744 .43758 L
.41791 .43687 L
.42425 .42716 L
.42716 .42264 L
.43047 .41744 L
.43657 .40773 L
.43687 .40725 L
.44256 .39802 L
.44658 .39141 L
.44845 .38831 L
.45425 .37859 L
.45629 .37514 L
.45996 .36888 L
.46559 .35917 L
.46601 .35844 L
.47113 .34946 L
.47572 .34132 L
.4766 .33974 L
.482 .33003 L
.48543 .32379 L
.48733 .32032 L
.4926 .31061 L
.49514 .30587 L
.4978 .30089 L
.50295 .29118 L
.50486 .28756 L
.50804 .28147 L
.51308 .27176 L
.51457 .26887 L
.51806 .26204 L
.523 .25233 L
.52428 .2498 L
.52788 .24262 L
.53274 .23291 L
.53399 .23037 L
.53752 .22319 L
.54229 .21348 L
.54371 .21057 L
.54699 .20377 L
.55168 .19406 L
.55342 .19042 L
.5563 .18434 L
.56091 .17463 L
.56313 .16992 L
.56547 .16492 L
.57 .15521 L
.57284 .14908 L
.57449 .14549 L
.57895 .13578 L
.58256 .1279 L
.58338 .12607 L
.58778 .11636 L
.59215 .10664 L
.59227 .10639 L
.59648 .09693 L
.6008 .08722 L
.60198 .08455 L
.60507 .07751 L
.60933 .06779 L
.61169 .06238 L
.61355 .05808 L
.61776 .04837 L
.62141 .0399 L
.62193 .03866 L
.62608 .02894 L
.63022 .01923 L
.01923 .01923 L
F
0 g
.01923 .85921 m
.02394 .85451 L
.02894 .84949 L
.03364 .84479 L
.03866 .83978 L
.04336 .83508 L
.04837 .83007 L
.05307 .82537 L
.05808 .82036 L
.06278 .81566 L
.06779 .81064 L
.07249 .80594 L
.07751 .80093 L
.08221 .79623 L
.08722 .79122 L
.09192 .78652 L
.09693 .78151 L
.10163 .77681 L
.10664 .77179 L
.11134 .76709 L
.11636 .76208 L
.12106 .75738 L
.12607 .75237 L
.13077 .74767 L
.13578 .74266 L
.14048 .73796 L
.14549 .73294 L
.15019 .72824 L
.15521 .72323 L
.15991 .71853 L
.16492 .71352 L
.16962 .70882 L
.17463 .70381 L
.17933 .69911 L
.18434 .69409 L
.18904 .68939 L
.19406 .68438 L
.19876 .67968 L
.20377 .67467 L
.20847 .66997 L
.21348 .66496 L
.21818 .66026 L
.22319 .65524 L
.22789 .65054 L
.23291 .64553 L
.23761 .64083 L
.24262 .63582 L
.24732 .63112 L
.25233 .62611 L
.25703 .62141 L
Mistroke
.26204 .61639 L
.26674 .61169 L
.27176 .60668 L
.27646 .60198 L
.28147 .59697 L
.28617 .59227 L
.29118 .58726 L
.29588 .58256 L
.30089 .57754 L
.30559 .57284 L
.31061 .56783 L
.31531 .56313 L
.32032 .55812 L
.32502 .55342 L
.33003 .54841 L
.33482 .54371 L
.33974 .53869 L
.34407 .53399 L
.34946 .52799 L
.35271 .52428 L
.35917 .5167 L
.36096 .51457 L
.36887 .50486 L
.36888 .50484 L
.37651 .49514 L
.37859 .49243 L
.38389 .48543 L
.38831 .47948 L
.39105 .47572 L
.39802 .46601 L
.39802 .46601 L
.40481 .45629 L
.40773 .45203 L
.41143 .44658 L
.41744 .43758 L
.41791 .43687 L
.42425 .42716 L
.42716 .42264 L
.43047 .41744 L
.43657 .40773 L
.43687 .40725 L
.44256 .39802 L
.44658 .39141 L
.44845 .38831 L
.45425 .37859 L
.45629 .37514 L
.45996 .36888 L
.46559 .35917 L
.46601 .35844 L
.47113 .34946 L
Mistroke
.47572 .34132 L
.4766 .33974 L
.482 .33003 L
.48543 .32379 L
.48733 .32032 L
.4926 .31061 L
.49514 .30587 L
.4978 .30089 L
.50295 .29118 L
.50486 .28756 L
.50804 .28147 L
.51308 .27176 L
.51457 .26887 L
.51806 .26204 L
.523 .25233 L
.52428 .2498 L
.52788 .24262 L
.53274 .23291 L
.53399 .23037 L
.53752 .22319 L
.54229 .21348 L
.54371 .21057 L
.54699 .20377 L
.55168 .19406 L
.55342 .19042 L
.5563 .18434 L
.56091 .17463 L
.56313 .16992 L
.56547 .16492 L
.57 .15521 L
.57284 .14908 L
.57449 .14549 L
.57895 .13578 L
.58256 .1279 L
.58338 .12607 L
.58778 .11636 L
.59215 .10664 L
.59227 .10639 L
.59648 .09693 L
.6008 .08722 L
.60198 .08455 L
.60507 .07751 L
.60933 .06779 L
.61169 .06238 L
.61355 .05808 L
.61776 .04837 L
.62141 .0399 L
.62193 .03866 L
.62608 .02894 L
.63022 .01923 L
Mistroke
Mfstroke
.6 g
.01923 .8238 m
.02737 .81566 L
.02894 .81408 L
.03708 .80594 L
.03866 .80437 L
.0468 .79623 L
.04837 .79466 L
.05651 .78652 L
.05808 .78495 L
.06622 .77681 L
.06779 .77523 L
.07593 .76709 L
.07751 .76552 L
.08565 .75738 L
.08722 .75581 L
.09536 .74767 L
.09693 .7461 L
.10507 .73796 L
.10664 .73638 L
.11478 .72824 L
.11636 .72667 L
.1245 .71853 L
.12607 .71696 L
.13421 .70882 L
.13578 .70725 L
.14392 .69911 L
.14549 .69753 L
.15363 .68939 L
.15521 .68782 L
.16335 .67968 L
.16492 .67811 L
.17306 .66997 L
.17463 .6684 L
.18277 .66026 L
.18434 .65868 L
.19248 .65054 L
.19406 .64897 L
.2022 .64083 L
.20377 .63926 L
.21191 .63112 L
.21348 .62955 L
.22162 .62141 L
.22319 .61983 L
.23133 .61169 L
.23291 .61012 L
.24105 .60198 L
.24262 .60041 L
.25076 .59227 L
.25233 .5907 L
.26047 .58256 L
.26204 .58098 L
.27018 .57284 L
.27176 .57127 L
.2799 .56313 L
.28147 .56156 L
.28961 .55342 L
.29118 .55185 L
.29932 .54371 L
.30089 .54213 L
.30903 .53399 L
.31061 .53242 L
.31875 .52428 L
.32032 .52271 L
.32846 .51457 L
.33003 .513 L
.33818 .50486 L
.33974 .50328 L
.34811 .49514 L
.34946 .49384 L
.35751 .48543 L
.35917 .48361 L
.36626 .47572 L
.36888 .47267 L
.37454 .46601 L
.37859 .46106 L
.38245 .45629 L
.38831 .44882 L
.39004 .44658 L
.39737 .43687 L
.39802 .43599 L
.40448 .42716 L
.40773 .4226 L
.41138 .41744 L
.41744 .40866 L
.41808 .40773 L
.42465 .39802 L
.42716 .39422 L
.43105 .38831 L
.43687 .37927 L
.4373 .37859 L
.44346 .36888 L
.44658 .36384 L
.44948 .35917 L
.45539 .34946 L
.45629 .34795 L
.46122 .33974 L
.46601 .33161 L
.46693 .33003 L
.47258 .32032 L
.47572 .31483 L
.47813 .31061 L
.48361 .30089 L
.48543 .29762 L
.48902 .29118 L
.49435 .28147 L
.49514 .28 L
.49963 .27176 L
.50482 .26204 L
.50486 .26197 L
.50998 .25233 L
.51457 .24354 L
.51505 .24262 L
.5201 .23291 L
.52428 .22473 L
.52507 .22319 L
.53002 .21348 L
.53399 .20554 L
.53488 .20377 L
.53974 .19406 L
.54371 .18597 L
.54451 .18434 L
.54928 .17463 L
.55342 .16604 L
.55396 .16492 L
.55865 .15521 L
.56313 .14575 L
.56325 .14549 L
.56786 .13578 L
.5724 .12607 L
.57284 .12511 L
.57693 .11636 L
.58141 .10664 L
.58256 .10413 L
.58587 .09693 L
.59029 .08722 L
.59227 .0828 L
.59467 .07751 L
.59904 .06779 L
.60198 .06114 L
.60335 .05808 L
.60767 .04837 L
.61169 .03915 L
.61191 .03866 L
.61618 .02894 L
.62039 .01923 L
.01923 .01923 L
F
0 g
.01923 .8238 m
.02737 .81566 L
.02894 .81408 L
.03708 .80594 L
.03866 .80437 L
.0468 .79623 L
.04837 .79466 L
.05651 .78652 L
.05808 .78495 L
.06622 .77681 L
.06779 .77523 L
.07593 .76709 L
.07751 .76552 L
.08565 .75738 L
.08722 .75581 L
.09536 .74767 L
.09693 .7461 L
.10507 .73796 L
.10664 .73638 L
.11478 .72824 L
.11636 .72667 L
.1245 .71853 L
.12607 .71696 L
.13421 .70882 L
.13578 .70725 L
.14392 .69911 L
.14549 .69753 L
.15363 .68939 L
.15521 .68782 L
.16335 .67968 L
.16492 .67811 L
.17306 .66997 L
.17463 .6684 L
.18277 .66026 L
.18434 .65868 L
.19248 .65054 L
.19406 .64897 L
.2022 .64083 L
.20377 .63926 L
.21191 .63112 L
.21348 .62955 L
.22162 .62141 L
.22319 .61983 L
.23133 .61169 L
.23291 .61012 L
.24105 .60198 L
.24262 .60041 L
.25076 .59227 L
.25233 .5907 L
.26047 .58256 L
Mistroke
.26204 .58098 L
.27018 .57284 L
.27176 .57127 L
.2799 .56313 L
.28147 .56156 L
.28961 .55342 L
.29118 .55185 L
.29932 .54371 L
.30089 .54213 L
.30903 .53399 L
.31061 .53242 L
.31875 .52428 L
.32032 .52271 L
.32846 .51457 L
.33003 .513 L
.33818 .50486 L
.33974 .50328 L
.34811 .49514 L
.34946 .49384 L
.35751 .48543 L
.35917 .48361 L
.36626 .47572 L
.36888 .47267 L
.37454 .46601 L
.37859 .46106 L
.38245 .45629 L
.38831 .44882 L
.39004 .44658 L
.39737 .43687 L
.39802 .43599 L
.40448 .42716 L
.40773 .4226 L
.41138 .41744 L
.41744 .40866 L
.41808 .40773 L
.42465 .39802 L
.42716 .39422 L
.43105 .38831 L
.43687 .37927 L
.4373 .37859 L
.44346 .36888 L
.44658 .36384 L
.44948 .35917 L
.45539 .34946 L
.45629 .34795 L
.46122 .33974 L
.46601 .33161 L
.46693 .33003 L
.47258 .32032 L
.47572 .31483 L
Mistroke
.47813 .31061 L
.48361 .30089 L
.48543 .29762 L
.48902 .29118 L
.49435 .28147 L
.49514 .28 L
.49963 .27176 L
.50482 .26204 L
.50486 .26197 L
.50998 .25233 L
.51457 .24354 L
.51505 .24262 L
.5201 .23291 L
.52428 .22473 L
.52507 .22319 L
.53002 .21348 L
.53399 .20554 L
.53488 .20377 L
.53974 .19406 L
.54371 .18597 L
.54451 .18434 L
.54928 .17463 L
.55342 .16604 L
.55396 .16492 L
.55865 .15521 L
.56313 .14575 L
.56325 .14549 L
.56786 .13578 L
.5724 .12607 L
.57284 .12511 L
.57693 .11636 L
.58141 .10664 L
.58256 .10413 L
.58587 .09693 L
.59029 .08722 L
.59227 .0828 L
.59467 .07751 L
.59904 .06779 L
.60198 .06114 L
.60335 .05808 L
.60767 .04837 L
.61169 .03915 L
.61191 .03866 L
.61618 .02894 L
.62039 .01923 L
Mfstroke
.7 g
.01923 .78011 m
.02247 .77681 L
.02894 .7704 L
.03225 .76709 L
.03866 .76069 L
.04196 .75738 L
.04837 .75098 L
.05167 .74767 L
.05808 .74126 L
.06139 .73796 L
.06779 .73155 L
.0711 .72824 L
.07751 .72184 L
.08081 .71853 L
.08722 .71213 L
.09052 .70882 L
.09693 .70241 L
.10024 .69911 L
.10664 .6927 L
.10995 .68939 L
.11636 .68299 L
.11966 .67968 L
.12607 .67328 L
.12937 .66997 L
.13578 .66356 L
.13909 .66026 L
.14549 .65385 L
.1488 .65054 L
.15521 .64414 L
.15851 .64083 L
.16492 .63443 L
.16822 .63112 L
.17463 .62471 L
.17794 .62141 L
.18434 .615 L
.18765 .61169 L
.19406 .60529 L
.19736 .60198 L
.20377 .59557 L
.20707 .59227 L
.21348 .58586 L
.21679 .58256 L
.22319 .57615 L
.2265 .57284 L
.23291 .56644 L
.23621 .56313 L
.24262 .55672 L
.24592 .55342 L
.25233 .54701 L
.25564 .54371 L
.26204 .5373 L
.26535 .53399 L
.27176 .52759 L
.27506 .52428 L
.28147 .51787 L
.28477 .51457 L
.29118 .50816 L
.29449 .50486 L
.30089 .49845 L
.3042 .49514 L
.31061 .48874 L
.31391 .48543 L
.32032 .47902 L
.32362 .47572 L
.33003 .46931 L
.33326 .46601 L
.33974 .4596 L
.34395 .45629 L
.34946 .45259 L
.35693 .44658 L
.35917 .44427 L
.3671 .43687 L
.36888 .43489 L
.37641 .42716 L
.37859 .42461 L
.38508 .41744 L
.38831 .41351 L
.39323 .40773 L
.39802 .40166 L
.40096 .39802 L
.40773 .38913 L
.40837 .38831 L
.41564 .37859 L
.41744 .37599 L
.42262 .36888 L
.42716 .36225 L
.42932 .35917 L
.43591 .34946 L
.43687 .34794 L
.44237 .33974 L
.44658 .3331 L
.44858 .33003 L
.45476 .32032 L
.45629 .31774 L
.46079 .31061 L
.46601 .30189 L
.46662 .30089 L
.47252 .29118 L
.47572 .28558 L
.47817 .28147 L
.48382 .27176 L
.48543 .2688 L
.48935 .26204 L
.49475 .25233 L
.49514 .25157 L
.5002 .24262 L
.50486 .23392 L
.50542 .23291 L
.51076 .22319 L
.51457 .21585 L
.51585 .21348 L
.52106 .20377 L
.52428 .19737 L
.52604 .19406 L
.53112 .18434 L
.53399 .1785 L
.536 .17463 L
.54098 .16492 L
.54371 .15923 L
.54576 .15521 L
.55064 .14549 L
.55342 .13959 L
.55532 .13578 L
.56012 .12607 L
.56313 .11957 L
.56471 .11636 L
.56944 .10664 L
.57284 .09919 L
.57393 .09693 L
.5786 .08722 L
.58256 .07844 L
.583 .07751 L
.5876 .06779 L
.59197 .05808 L
.59227 .05735 L
.59647 .04837 L
.60084 .03866 L
.60198 .03593 L
.60519 .02894 L
.60957 .01923 L
.01923 .01923 L
F
0 g
.01923 .78011 m
.02247 .77681 L
.02894 .7704 L
.03225 .76709 L
.03866 .76069 L
.04196 .75738 L
.04837 .75098 L
.05167 .74767 L
.05808 .74126 L
.06139 .73796 L
.06779 .73155 L
.0711 .72824 L
.07751 .72184 L
.08081 .71853 L
.08722 .71213 L
.09052 .70882 L
.09693 .70241 L
.10024 .69911 L
.10664 .6927 L
.10995 .68939 L
.11636 .68299 L
.11966 .67968 L
.12607 .67328 L
.12937 .66997 L
.13578 .66356 L
.13909 .66026 L
.14549 .65385 L
.1488 .65054 L
.15521 .64414 L
.15851 .64083 L
.16492 .63443 L
.16822 .63112 L
.17463 .62471 L
.17794 .62141 L
.18434 .615 L
.18765 .61169 L
.19406 .60529 L
.19736 .60198 L
.20377 .59557 L
.20707 .59227 L
.21348 .58586 L
.21679 .58256 L
.22319 .57615 L
.2265 .57284 L
.23291 .56644 L
.23621 .56313 L
.24262 .55672 L
.24592 .55342 L
.25233 .54701 L
.25564 .54371 L
Mistroke
.26204 .5373 L
.26535 .53399 L
.27176 .52759 L
.27506 .52428 L
.28147 .51787 L
.28477 .51457 L
.29118 .50816 L
.29449 .50486 L
.30089 .49845 L
.3042 .49514 L
.31061 .48874 L
.31391 .48543 L
.32032 .47902 L
.32362 .47572 L
.33003 .46931 L
.33326 .46601 L
.33974 .4596 L
.34395 .45629 L
.34946 .45259 L
.35693 .44658 L
.35917 .44427 L
.3671 .43687 L
.36888 .43489 L
.37641 .42716 L
.37859 .42461 L
.38508 .41744 L
.38831 .41351 L
.39323 .40773 L
.39802 .40166 L
.40096 .39802 L
.40773 .38913 L
.40837 .38831 L
.41564 .37859 L
.41744 .37599 L
.42262 .36888 L
.42716 .36225 L
.42932 .35917 L
.43591 .34946 L
.43687 .34794 L
.44237 .33974 L
.44658 .3331 L
.44858 .33003 L
.45476 .32032 L
.45629 .31774 L
.46079 .31061 L
.46601 .30189 L
.46662 .30089 L
.47252 .29118 L
.47572 .28558 L
.47817 .28147 L
Mistroke
.48382 .27176 L
.48543 .2688 L
.48935 .26204 L
.49475 .25233 L
.49514 .25157 L
.5002 .24262 L
.50486 .23392 L
.50542 .23291 L
.51076 .22319 L
.51457 .21585 L
.51585 .21348 L
.52106 .20377 L
.52428 .19737 L
.52604 .19406 L
.53112 .18434 L
.53399 .1785 L
.536 .17463 L
.54098 .16492 L
.54371 .15923 L
.54576 .15521 L
.55064 .14549 L
.55342 .13959 L
.55532 .13578 L
.56012 .12607 L
.56313 .11957 L
.56471 .11636 L
.56944 .10664 L
.57284 .09919 L
.57393 .09693 L
.5786 .08722 L
.58256 .07844 L
.583 .07751 L
.5876 .06779 L
.59197 .05808 L
.59227 .05735 L
.59647 .04837 L
.60084 .03866 L
.60198 .03593 L
.60519 .02894 L
.60957 .01923 L
Mfstroke
.6 g
.01923 .7015 m
.022 .69911 L
.02894 .69179 L
.03134 .68939 L
.03866 .68207 L
.04105 .67968 L
.04837 .67236 L
.05076 .66997 L
.05808 .66265 L
.06047 .66026 L
.06779 .65294 L
.07019 .65054 L
.07751 .64322 L
.0799 .64083 L
.08722 .63351 L
.08961 .63112 L
.09693 .6238 L
.09932 .62141 L
.10664 .61409 L
.10904 .61169 L
.11636 .60437 L
.11875 .60198 L
.12607 .59466 L
.12846 .59227 L
.13578 .58495 L
.13817 .58256 L
.14549 .57524 L
.14789 .57284 L
.15521 .56552 L
.1576 .56313 L
.16492 .55581 L
.16731 .55342 L
.17463 .5461 L
.17702 .54371 L
.18434 .53639 L
.18674 .53399 L
.19406 .52667 L
.19645 .52428 L
.20377 .51696 L
.20616 .51457 L
.21348 .50725 L
.21587 .50486 L
.22319 .49754 L
.22559 .49514 L
.23291 .48782 L
.2353 .48543 L
.24262 .47811 L
.24501 .47572 L
.25233 .4684 L
.25472 .46601 L
.26204 .45869 L
.26444 .45629 L
.27176 .44897 L
.27415 .44658 L
.28147 .43926 L
.28386 .43687 L
.29118 .42955 L
.29357 .42716 L
.30089 .41984 L
.30329 .41744 L
.31061 .41012 L
.313 .40773 L
.32032 .40041 L
.32271 .39802 L
.33003 .3907 L
.33265 .38831 L
.33974 .38099 L
.34164 .37859 L
.34875 .36888 L
.34946 .36789 L
.35588 .35917 L
.35917 .35466 L
.36295 .34946 L
.36888 .34124 L
.36995 .33974 L
.37682 .33003 L
.37859 .3275 L
.38356 .32032 L
.38831 .31341 L
.3902 .31061 L
.39673 .30089 L
.39802 .29896 L
.40311 .29118 L
.40773 .2841 L
.40941 .28147 L
.41561 .27176 L
.41744 .26887 L
.42168 .26204 L
.42716 .25323 L
.4277 .25233 L
.43359 .24262 L
.43687 .23719 L
.43939 .23291 L
.44516 .22319 L
.44658 .22078 L
.45078 .21348 L
.45629 .20397 L
.45641 .20377 L
.46188 .19406 L
.46601 .18676 L
.46733 .18434 L
.4727 .17463 L
.47572 .16918 L
.478 .16492 L
.48328 .15521 L
.48543 .15123 L
.48844 .14549 L
.49362 .13578 L
.49514 .13291 L
.49866 .12607 L
.50375 .11636 L
.50486 .11422 L
.50868 .10664 L
.51367 .09693 L
.51457 .09518 L
.51851 .08722 L
.52341 .07751 L
.52428 .07578 L
.52816 .06779 L
.53298 .05808 L
.53399 .05602 L
.53764 .04837 L
.54238 .03866 L
.54371 .03593 L
.54696 .02894 L
.55163 .01923 L
.01923 .01923 L
F
0 g
.01923 .7015 m
.022 .69911 L
.02894 .69179 L
.03134 .68939 L
.03866 .68207 L
.04105 .67968 L
.04837 .67236 L
.05076 .66997 L
.05808 .66265 L
.06047 .66026 L
.06779 .65294 L
.07019 .65054 L
.07751 .64322 L
.0799 .64083 L
.08722 .63351 L
.08961 .63112 L
.09693 .6238 L
.09932 .62141 L
.10664 .61409 L
.10904 .61169 L
.11636 .60437 L
.11875 .60198 L
.12607 .59466 L
.12846 .59227 L
.13578 .58495 L
.13817 .58256 L
.14549 .57524 L
.14789 .57284 L
.15521 .56552 L
.1576 .56313 L
.16492 .55581 L
.16731 .55342 L
.17463 .5461 L
.17702 .54371 L
.18434 .53639 L
.18674 .53399 L
.19406 .52667 L
.19645 .52428 L
.20377 .51696 L
.20616 .51457 L
.21348 .50725 L
.21587 .50486 L
.22319 .49754 L
.22559 .49514 L
.23291 .48782 L
.2353 .48543 L
.24262 .47811 L
.24501 .47572 L
.25233 .4684 L
.25472 .46601 L
Mistroke
.26204 .45869 L
.26444 .45629 L
.27176 .44897 L
.27415 .44658 L
.28147 .43926 L
.28386 .43687 L
.29118 .42955 L
.29357 .42716 L
.30089 .41984 L
.30329 .41744 L
.31061 .41012 L
.313 .40773 L
.32032 .40041 L
.32271 .39802 L
.33003 .3907 L
.33265 .38831 L
.33974 .38099 L
.34164 .37859 L
.34875 .36888 L
.34946 .36789 L
.35588 .35917 L
.35917 .35466 L
.36295 .34946 L
.36888 .34124 L
.36995 .33974 L
.37682 .33003 L
.37859 .3275 L
.38356 .32032 L
.38831 .31341 L
.3902 .31061 L
.39673 .30089 L
.39802 .29896 L
.40311 .29118 L
.40773 .2841 L
.40941 .28147 L
.41561 .27176 L
.41744 .26887 L
.42168 .26204 L
.42716 .25323 L
.4277 .25233 L
.43359 .24262 L
.43687 .23719 L
.43939 .23291 L
.44516 .22319 L
.44658 .22078 L
.45078 .21348 L
.45629 .20397 L
.45641 .20377 L
.46188 .19406 L
.46601 .18676 L
Mistroke
.46733 .18434 L
.4727 .17463 L
.47572 .16918 L
.478 .16492 L
.48328 .15521 L
.48543 .15123 L
.48844 .14549 L
.49362 .13578 L
.49514 .13291 L
.49866 .12607 L
.50375 .11636 L
.50486 .11422 L
.50868 .10664 L
.51367 .09693 L
.51457 .09518 L
.51851 .08722 L
.52341 .07751 L
.52428 .07578 L
.52816 .06779 L
.53298 .05808 L
.53399 .05602 L
.53764 .04837 L
.54238 .03866 L
.54371 .03593 L
.54696 .02894 L
.55163 .01923 L
Mfstroke
.5 g
.01923 .65782 m
.02652 .65054 L
.02894 .64811 L
.03622 .64083 L
.03866 .6384 L
.04594 .63112 L
.04837 .62869 L
.05565 .62141 L
.05808 .61897 L
.06536 .61169 L
.06779 .60926 L
.07507 .60198 L
.07751 .59955 L
.08479 .59227 L
.08722 .58984 L
.0945 .58256 L
.09693 .58012 L
.10421 .57284 L
.10664 .57041 L
.11392 .56313 L
.11636 .5607 L
.12364 .55342 L
.12607 .55099 L
.13335 .54371 L
.13578 .54127 L
.14306 .53399 L
.14549 .53156 L
.15277 .52428 L
.15521 .52185 L
.16249 .51457 L
.16492 .51214 L
.1722 .50486 L
.17463 .50242 L
.18191 .49514 L
.18434 .49271 L
.19162 .48543 L
.19406 .483 L
.20134 .47572 L
.20377 .47329 L
.21105 .46601 L
.21348 .46357 L
.22076 .45629 L
.22319 .45386 L
.23047 .44658 L
.23291 .44415 L
.24019 .43687 L
.24262 .43444 L
.2499 .42716 L
.25233 .42472 L
.25961 .41744 L
.26204 .41501 L
.26932 .40773 L
.27176 .4053 L
.27904 .39802 L
.28147 .39559 L
.28875 .38831 L
.29118 .38587 L
.29846 .37859 L
.30089 .37616 L
.30817 .36888 L
.31061 .36645 L
.31789 .35917 L
.32032 .35674 L
.3276 .34946 L
.33003 .34702 L
.33738 .33974 L
.33974 .33731 L
.3464 .33003 L
.34946 .32661 L
.35494 .32032 L
.35917 .31532 L
.36309 .31061 L
.36888 .30346 L
.37093 .30089 L
.37849 .29118 L
.37859 .29104 L
.38581 .28147 L
.38831 .27809 L
.39292 .27176 L
.39802 .26462 L
.39984 .26204 L
.40658 .25233 L
.40773 .25065 L
.41317 .24262 L
.41744 .23619 L
.41961 .23291 L
.42592 .22319 L
.42716 .22126 L
.4321 .21348 L
.43687 .20587 L
.43817 .20377 L
.44414 .19406 L
.44658 .19003 L
.45 .18434 L
.45578 .17463 L
.45629 .17375 L
.46146 .16492 L
.46601 .15705 L
.46706 .15521 L
.47259 .14549 L
.47572 .13993 L
.47804 .13578 L
.48342 .12607 L
.48543 .12241 L
.48873 .11636 L
.49399 .10664 L
.49514 .10449 L
.49917 .09693 L
.50431 .08722 L
.50486 .08618 L
.50938 .07751 L
.51441 .06779 L
.51457 .06749 L
.51938 .05808 L
.52428 .04842 L
.52431 .04837 L
.52918 .03866 L
.53399 .02898 L
.53401 .02894 L
.53879 .01923 L
.01923 .01923 L
F
0 g
.01923 .65782 m
.02652 .65054 L
.02894 .64811 L
.03622 .64083 L
.03866 .6384 L
.04594 .63112 L
.04837 .62869 L
.05565 .62141 L
.05808 .61897 L
.06536 .61169 L
.06779 .60926 L
.07507 .60198 L
.07751 .59955 L
.08479 .59227 L
.08722 .58984 L
.0945 .58256 L
.09693 .58012 L
.10421 .57284 L
.10664 .57041 L
.11392 .56313 L
.11636 .5607 L
.12364 .55342 L
.12607 .55099 L
.13335 .54371 L
.13578 .54127 L
.14306 .53399 L
.14549 .53156 L
.15277 .52428 L
.15521 .52185 L
.16249 .51457 L
.16492 .51214 L
.1722 .50486 L
.17463 .50242 L
.18191 .49514 L
.18434 .49271 L
.19162 .48543 L
.19406 .483 L
.20134 .47572 L
.20377 .47329 L
.21105 .46601 L
.21348 .46357 L
.22076 .45629 L
.22319 .45386 L
.23047 .44658 L
.23291 .44415 L
.24019 .43687 L
.24262 .43444 L
.2499 .42716 L
.25233 .42472 L
.25961 .41744 L
Mistroke
.26204 .41501 L
.26932 .40773 L
.27176 .4053 L
.27904 .39802 L
.28147 .39559 L
.28875 .38831 L
.29118 .38587 L
.29846 .37859 L
.30089 .37616 L
.30817 .36888 L
.31061 .36645 L
.31789 .35917 L
.32032 .35674 L
.3276 .34946 L
.33003 .34702 L
.33738 .33974 L
.33974 .33731 L
.3464 .33003 L
.34946 .32661 L
.35494 .32032 L
.35917 .31532 L
.36309 .31061 L
.36888 .30346 L
.37093 .30089 L
.37849 .29118 L
.37859 .29104 L
.38581 .28147 L
.38831 .27809 L
.39292 .27176 L
.39802 .26462 L
.39984 .26204 L
.40658 .25233 L
.40773 .25065 L
.41317 .24262 L
.41744 .23619 L
.41961 .23291 L
.42592 .22319 L
.42716 .22126 L
.4321 .21348 L
.43687 .20587 L
.43817 .20377 L
.44414 .19406 L
.44658 .19003 L
.45 .18434 L
.45578 .17463 L
.45629 .17375 L
.46146 .16492 L
.46601 .15705 L
.46706 .15521 L
.47259 .14549 L
Mistroke
.47572 .13993 L
.47804 .13578 L
.48342 .12607 L
.48543 .12241 L
.48873 .11636 L
.49399 .10664 L
.49514 .10449 L
.49917 .09693 L
.50431 .08722 L
.50486 .08618 L
.50938 .07751 L
.51441 .06779 L
.51457 .06749 L
.51938 .05808 L
.52428 .04842 L
.52431 .04837 L
.52918 .03866 L
.53399 .02898 L
.53401 .02894 L
.53879 .01923 L
Mfstroke
.4 g
.01923 .62241 m
.02023 .62141 L
.02894 .6127 L
.02995 .61169 L
.03866 .60299 L
.03966 .60198 L
.04837 .59327 L
.04937 .59227 L
.05808 .58356 L
.05909 .58256 L
.06779 .57385 L
.0688 .57284 L
.07751 .56414 L
.07851 .56313 L
.08722 .55442 L
.08822 .55342 L
.09693 .54471 L
.09794 .54371 L
.10664 .535 L
.10765 .53399 L
.11636 .52529 L
.11736 .52428 L
.12607 .51557 L
.12707 .51457 L
.13578 .50586 L
.13679 .50486 L
.14549 .49615 L
.1465 .49514 L
.15521 .48644 L
.15621 .48543 L
.16492 .47672 L
.16592 .47572 L
.17463 .46701 L
.17564 .46601 L
.18434 .4573 L
.18535 .45629 L
.19406 .44759 L
.19506 .44658 L
.20377 .43787 L
.20477 .43687 L
.21348 .42816 L
.21449 .42716 L
.22319 .41845 L
.2242 .41744 L
.23291 .40874 L
.23391 .40773 L
.24262 .39902 L
.24362 .39802 L
.25233 .38931 L
.25334 .38831 L
.26204 .3796 L
.26305 .37859 L
.27176 .36989 L
.27276 .36888 L
.28147 .36017 L
.28247 .35917 L
.29118 .35046 L
.29219 .34946 L
.30089 .34075 L
.3019 .33974 L
.31061 .33104 L
.31161 .33003 L
.32032 .32132 L
.32132 .32032 L
.33003 .31161 L
.33104 .31061 L
.33974 .3019 L
.34076 .30089 L
.34946 .29246 L
.35072 .29118 L
.35917 .28223 L
.35987 .28147 L
.36848 .27176 L
.36888 .27129 L
.37667 .26204 L
.37859 .25967 L
.3845 .25233 L
.38831 .24744 L
.39202 .24262 L
.39802 .23461 L
.39928 .23291 L
.40633 .22319 L
.40773 .22121 L
.41318 .21348 L
.41744 .20728 L
.41984 .20377 L
.42635 .19406 L
.42716 .19283 L
.43273 .18434 L
.43687 .17789 L
.43895 .17463 L
.44506 .16492 L
.44658 .16246 L
.45106 .15521 L
.45629 .14657 L
.45694 .14549 L
.46275 .13578 L
.46601 .13022 L
.46844 .12607 L
.47406 .11636 L
.47572 .11344 L
.4796 .10664 L
.48505 .09693 L
.48543 .09624 L
.49045 .08722 L
.49514 .07861 L
.49575 .07751 L
.50102 .06779 L
.50486 .06058 L
.50619 .05808 L
.51134 .04837 L
.51457 .04216 L
.5164 .03866 L
.52143 .02894 L
.52428 .02334 L
.52639 .01923 L
.01923 .01923 L
F
0 g
.01923 .62241 m
.02023 .62141 L
.02894 .6127 L
.02995 .61169 L
.03866 .60299 L
.03966 .60198 L
.04837 .59327 L
.04937 .59227 L
.05808 .58356 L
.05909 .58256 L
.06779 .57385 L
.0688 .57284 L
.07751 .56414 L
.07851 .56313 L
.08722 .55442 L
.08822 .55342 L
.09693 .54471 L
.09794 .54371 L
.10664 .535 L
.10765 .53399 L
.11636 .52529 L
.11736 .52428 L
.12607 .51557 L
.12707 .51457 L
.13578 .50586 L
.13679 .50486 L
.14549 .49615 L
.1465 .49514 L
.15521 .48644 L
.15621 .48543 L
.16492 .47672 L
.16592 .47572 L
.17463 .46701 L
.17564 .46601 L
.18434 .4573 L
.18535 .45629 L
.19406 .44759 L
.19506 .44658 L
.20377 .43787 L
.20477 .43687 L
.21348 .42816 L
.21449 .42716 L
.22319 .41845 L
.2242 .41744 L
.23291 .40874 L
.23391 .40773 L
.24262 .39902 L
.24362 .39802 L
.25233 .38931 L
.25334 .38831 L
Mistroke
.26204 .3796 L
.26305 .37859 L
.27176 .36989 L
.27276 .36888 L
.28147 .36017 L
.28247 .35917 L
.29118 .35046 L
.29219 .34946 L
.30089 .34075 L
.3019 .33974 L
.31061 .33104 L
.31161 .33003 L
.32032 .32132 L
.32132 .32032 L
.33003 .31161 L
.33104 .31061 L
.33974 .3019 L
.34076 .30089 L
.34946 .29246 L
.35072 .29118 L
.35917 .28223 L
.35987 .28147 L
.36848 .27176 L
.36888 .27129 L
.37667 .26204 L
.37859 .25967 L
.3845 .25233 L
.38831 .24744 L
.39202 .24262 L
.39802 .23461 L
.39928 .23291 L
.40633 .22319 L
.40773 .22121 L
.41318 .21348 L
.41744 .20728 L
.41984 .20377 L
.42635 .19406 L
.42716 .19283 L
.43273 .18434 L
.43687 .17789 L
.43895 .17463 L
.44506 .16492 L
.44658 .16246 L
.45106 .15521 L
.45629 .14657 L
.45694 .14549 L
.46275 .13578 L
.46601 .13022 L
.46844 .12607 L
.47406 .11636 L
Mistroke
.47572 .11344 L
.4796 .10664 L
.48505 .09693 L
.48543 .09624 L
.49045 .08722 L
.49514 .07861 L
.49575 .07751 L
.50102 .06779 L
.50486 .06058 L
.50619 .05808 L
.51134 .04837 L
.51457 .04216 L
.5164 .03866 L
.52143 .02894 L
.52428 .02334 L
.52639 .01923 L
Mfstroke
.3 g
.01923 .57874 m
.02505 .57284 L
.02894 .56903 L
.03484 .56313 L
.03866 .55932 L
.04455 .55342 L
.04837 .54961 L
.05427 .54371 L
.05808 .53989 L
.06398 .53399 L
.06779 .53018 L
.07369 .52428 L
.07751 .52047 L
.0834 .51457 L
.08722 .51076 L
.09312 .50486 L
.09693 .50104 L
.10283 .49514 L
.10664 .49133 L
.11254 .48543 L
.11636 .48162 L
.12225 .47572 L
.12607 .4719 L
.13197 .46601 L
.13578 .46219 L
.14168 .45629 L
.14549 .45248 L
.15139 .44658 L
.15521 .44277 L
.1611 .43687 L
.16492 .43305 L
.17082 .42716 L
.17463 .42334 L
.18053 .41744 L
.18434 .41363 L
.19024 .40773 L
.19406 .40392 L
.19995 .39802 L
.20377 .3942 L
.20967 .38831 L
.21348 .38449 L
.21938 .37859 L
.22319 .37478 L
.22909 .36888 L
.23291 .36507 L
.2388 .35917 L
.24262 .35535 L
.24852 .34946 L
.25233 .34564 L
.25823 .33974 L
.26204 .33593 L
.26794 .33003 L
.27176 .32622 L
.27765 .32032 L
.28147 .3165 L
.28737 .31061 L
.29118 .30679 L
.29708 .30089 L
.30089 .29708 L
.30679 .29118 L
.31061 .28737 L
.3165 .28147 L
.32032 .27765 L
.32622 .27176 L
.33003 .26794 L
.33581 .26204 L
.33974 .25823 L
.34767 .25233 L
.34946 .25119 L
.35917 .24286 L
.35945 .24262 L
.36888 .23349 L
.36948 .23291 L
.37859 .2232 L
.3786 .22319 L
.38723 .21348 L
.38831 .21211 L
.39533 .20377 L
.39802 .20028 L
.40302 .19406 L
.40773 .18776 L
.41035 .18434 L
.41742 .17463 L
.41744 .1746 L
.42443 .16492 L
.42716 .16087 L
.43112 .15521 L
.43687 .14655 L
.43758 .14549 L
.44405 .13578 L
.44658 .13172 L
.45026 .12607 L
.45629 .11636 L
.45629 .11635 L
.46239 .10664 L
.46601 .10051 L
.4682 .09693 L
.47402 .08722 L
.47572 .08419 L
.4797 .07751 L
.48523 .06779 L
.48543 .06741 L
.49083 .05808 L
.49514 .05019 L
.49618 .04837 L
.50163 .03866 L
.50486 .03254 L
.50685 .02894 L
.51214 .01923 L
.01923 .01923 L
F
0 g
.01923 .57874 m
.02505 .57284 L
.02894 .56903 L
.03484 .56313 L
.03866 .55932 L
.04455 .55342 L
.04837 .54961 L
.05427 .54371 L
.05808 .53989 L
.06398 .53399 L
.06779 .53018 L
.07369 .52428 L
.07751 .52047 L
.0834 .51457 L
.08722 .51076 L
.09312 .50486 L
.09693 .50104 L
.10283 .49514 L
.10664 .49133 L
.11254 .48543 L
.11636 .48162 L
.12225 .47572 L
.12607 .4719 L
.13197 .46601 L
.13578 .46219 L
.14168 .45629 L
.14549 .45248 L
.15139 .44658 L
.15521 .44277 L
.1611 .43687 L
.16492 .43305 L
.17082 .42716 L
.17463 .42334 L
.18053 .41744 L
.18434 .41363 L
.19024 .40773 L
.19406 .40392 L
.19995 .39802 L
.20377 .3942 L
.20967 .38831 L
.21348 .38449 L
.21938 .37859 L
.22319 .37478 L
.22909 .36888 L
.23291 .36507 L
.2388 .35917 L
.24262 .35535 L
.24852 .34946 L
.25233 .34564 L
.25823 .33974 L
Mistroke
.26204 .33593 L
.26794 .33003 L
.27176 .32622 L
.27765 .32032 L
.28147 .3165 L
.28737 .31061 L
.29118 .30679 L
.29708 .30089 L
.30089 .29708 L
.30679 .29118 L
.31061 .28737 L
.3165 .28147 L
.32032 .27765 L
.32622 .27176 L
.33003 .26794 L
.33581 .26204 L
.33974 .25823 L
.34767 .25233 L
.34946 .25119 L
.35917 .24286 L
.35945 .24262 L
.36888 .23349 L
.36948 .23291 L
.37859 .2232 L
.3786 .22319 L
.38723 .21348 L
.38831 .21211 L
.39533 .20377 L
.39802 .20028 L
.40302 .19406 L
.40773 .18776 L
.41035 .18434 L
.41742 .17463 L
.41744 .1746 L
.42443 .16492 L
.42716 .16087 L
.43112 .15521 L
.43687 .14655 L
.43758 .14549 L
.44405 .13578 L
.44658 .13172 L
.45026 .12607 L
.45629 .11636 L
.45629 .11635 L
.46239 .10664 L
.46601 .10051 L
.4682 .09693 L
.47402 .08722 L
.47572 .08419 L
.4797 .07751 L
Mistroke
.48523 .06779 L
.48543 .06741 L
.49083 .05808 L
.49514 .05019 L
.49618 .04837 L
.50163 .03866 L
.50486 .03254 L
.50685 .02894 L
.51214 .01923 L
Mfstroke
.4 g
.01923 .50011 m
.02448 .49514 L
.02894 .4904 L
.03391 .48543 L
.03866 .48069 L
.04362 .47572 L
.04837 .47098 L
.05334 .46601 L
.05808 .46126 L
.06305 .45629 L
.06779 .45155 L
.07276 .44658 L
.07751 .44184 L
.08247 .43687 L
.08722 .43212 L
.09219 .42716 L
.09693 .42241 L
.1019 .41744 L
.10664 .4127 L
.11161 .40773 L
.11636 .40299 L
.12132 .39802 L
.12607 .39327 L
.13104 .38831 L
.13578 .38356 L
.14075 .37859 L
.14549 .37385 L
.15046 .36888 L
.15521 .36414 L
.16017 .35917 L
.16492 .35442 L
.16989 .34946 L
.17463 .34471 L
.1796 .33974 L
.18434 .335 L
.18931 .33003 L
.19406 .32529 L
.19902 .32032 L
.20377 .31557 L
.20874 .31061 L
.21348 .30586 L
.21845 .30089 L
.22319 .29615 L
.22816 .29118 L
.23291 .28644 L
.23787 .28147 L
.24262 .27672 L
.24759 .27176 L
.25233 .26701 L
.2573 .26204 L
.26204 .2573 L
.26701 .25233 L
.27176 .24759 L
.27672 .24262 L
.28147 .23787 L
.28644 .23291 L
.29118 .22816 L
.29615 .22319 L
.30089 .21845 L
.30586 .21348 L
.31061 .20874 L
.31557 .20377 L
.32032 .19902 L
.32529 .19406 L
.33003 .18931 L
.33531 .18434 L
.33974 .1796 L
.34357 .17463 L
.34946 .16649 L
.35063 .16492 L
.35777 .15521 L
.35917 .15329 L
.36482 .14549 L
.36888 .13984 L
.37177 .13578 L
.37859 .12613 L
.37864 .12607 L
.38534 .11636 L
.38831 .11202 L
.39193 .10664 L
.39802 .09758 L
.39844 .09693 L
.4048 .08722 L
.40773 .08272 L
.41106 .07751 L
.41725 .06779 L
.41744 .06749 L
.42329 .05808 L
.42716 .05184 L
.42925 .04837 L
.43516 .03866 L
.43687 .03582 L
.44092 .02894 L
.44658 .01941 L
.44668 .01923 L
.01923 .01923 L
F
0 g
.01923 .50011 m
.02448 .49514 L
.02894 .4904 L
.03391 .48543 L
.03866 .48069 L
.04362 .47572 L
.04837 .47098 L
.05334 .46601 L
.05808 .46126 L
.06305 .45629 L
.06779 .45155 L
.07276 .44658 L
.07751 .44184 L
.08247 .43687 L
.08722 .43212 L
.09219 .42716 L
.09693 .42241 L
.1019 .41744 L
.10664 .4127 L
.11161 .40773 L
.11636 .40299 L
.12132 .39802 L
.12607 .39327 L
.13104 .38831 L
.13578 .38356 L
.14075 .37859 L
.14549 .37385 L
.15046 .36888 L
.15521 .36414 L
.16017 .35917 L
.16492 .35442 L
.16989 .34946 L
.17463 .34471 L
.1796 .33974 L
.18434 .335 L
.18931 .33003 L
.19406 .32529 L
.19902 .32032 L
.20377 .31557 L
.20874 .31061 L
.21348 .30586 L
.21845 .30089 L
.22319 .29615 L
.22816 .29118 L
.23291 .28644 L
.23787 .28147 L
.24262 .27672 L
.24759 .27176 L
.25233 .26701 L
.2573 .26204 L
Mistroke
.26204 .2573 L
.26701 .25233 L
.27176 .24759 L
.27672 .24262 L
.28147 .23787 L
.28644 .23291 L
.29118 .22816 L
.29615 .22319 L
.30089 .21845 L
.30586 .21348 L
.31061 .20874 L
.31557 .20377 L
.32032 .19902 L
.32529 .19406 L
.33003 .18931 L
.33531 .18434 L
.33974 .1796 L
.34357 .17463 L
.34946 .16649 L
.35063 .16492 L
.35777 .15521 L
.35917 .15329 L
.36482 .14549 L
.36888 .13984 L
.37177 .13578 L
.37859 .12613 L
.37864 .12607 L
.38534 .11636 L
.38831 .11202 L
.39193 .10664 L
.39802 .09758 L
.39844 .09693 L
.4048 .08722 L
.40773 .08272 L
.41106 .07751 L
.41725 .06779 L
.41744 .06749 L
.42329 .05808 L
.42716 .05184 L
.42925 .04837 L
.43516 .03866 L
.43687 .03582 L
.44092 .02894 L
.44658 .01941 L
.44668 .01923 L
Mfstroke
.5 g
.01923 .45644 m
.01938 .45629 L
.02894 .44673 L
.02909 .44658 L
.03866 .43702 L
.0388 .43687 L
.04837 .4273 L
.04852 .42716 L
.05808 .41759 L
.05823 .41744 L
.06779 .40788 L
.06794 .40773 L
.07751 .39817 L
.07765 .39802 L
.08722 .38845 L
.08737 .38831 L
.09693 .37874 L
.09708 .37859 L
.10664 .36903 L
.10679 .36888 L
.11636 .35932 L
.1165 .35917 L
.12607 .3496 L
.12622 .34946 L
.13578 .33989 L
.13593 .33974 L
.14549 .33018 L
.14564 .33003 L
.15521 .32047 L
.15535 .32032 L
.16492 .31075 L
.16507 .31061 L
.17463 .30104 L
.17478 .30089 L
.18434 .29133 L
.18449 .29118 L
.19406 .28162 L
.1942 .28147 L
.20377 .2719 L
.20392 .27176 L
.21348 .26219 L
.21363 .26204 L
.22319 .25248 L
.22334 .25233 L
.23291 .24277 L
.23305 .24262 L
.24262 .23305 L
.24277 .23291 L
.25233 .22334 L
.25248 .22319 L
.26204 .21363 L
.26219 .21348 L
.27176 .20392 L
.2719 .20377 L
.28147 .1942 L
.28162 .19406 L
.29118 .18449 L
.29133 .18434 L
.30089 .17478 L
.30104 .17463 L
.31061 .16507 L
.31075 .16492 L
.32032 .15535 L
.32047 .15521 L
.33003 .14564 L
.33018 .14549 L
.33974 .13593 L
.33988 .13578 L
.34871 .12607 L
.34946 .12523 L
.35713 .11636 L
.35917 .11394 L
.3652 .10664 L
.36888 .10207 L
.37296 .09693 L
.37859 .08966 L
.38046 .08722 L
.38772 .07751 L
.38831 .07671 L
.39478 .06779 L
.39802 .06324 L
.40165 .05808 L
.40773 .04927 L
.40834 .04837 L
.41489 .03866 L
.41744 .03481 L
.42129 .02894 L
.42716 .01988 L
.42757 .01923 L
.01923 .01923 L
F
0 g
.01923 .45644 m
.01938 .45629 L
.02894 .44673 L
.02909 .44658 L
.03866 .43702 L
.0388 .43687 L
.04837 .4273 L
.04852 .42716 L
.05808 .41759 L
.05823 .41744 L
.06779 .40788 L
.06794 .40773 L
.07751 .39817 L
.07765 .39802 L
.08722 .38845 L
.08737 .38831 L
.09693 .37874 L
.09708 .37859 L
.10664 .36903 L
.10679 .36888 L
.11636 .35932 L
.1165 .35917 L
.12607 .3496 L
.12622 .34946 L
.13578 .33989 L
.13593 .33974 L
.14549 .33018 L
.14564 .33003 L
.15521 .32047 L
.15535 .32032 L
.16492 .31075 L
.16507 .31061 L
.17463 .30104 L
.17478 .30089 L
.18434 .29133 L
.18449 .29118 L
.19406 .28162 L
.1942 .28147 L
.20377 .2719 L
.20392 .27176 L
.21348 .26219 L
.21363 .26204 L
.22319 .25248 L
.22334 .25233 L
.23291 .24277 L
.23305 .24262 L
.24262 .23305 L
.24277 .23291 L
.25233 .22334 L
.25248 .22319 L
Mistroke
.26204 .21363 L
.26219 .21348 L
.27176 .20392 L
.2719 .20377 L
.28147 .1942 L
.28162 .19406 L
.29118 .18449 L
.29133 .18434 L
.30089 .17478 L
.30104 .17463 L
.31061 .16507 L
.31075 .16492 L
.32032 .15535 L
.32047 .15521 L
.33003 .14564 L
.33018 .14549 L
.33974 .13593 L
.33988 .13578 L
.34871 .12607 L
.34946 .12523 L
.35713 .11636 L
.35917 .11394 L
.3652 .10664 L
.36888 .10207 L
.37296 .09693 L
.37859 .08966 L
.38046 .08722 L
.38772 .07751 L
.38831 .07671 L
.39478 .06779 L
.39802 .06324 L
.40165 .05808 L
.40773 .04927 L
.40834 .04837 L
.41489 .03866 L
.41744 .03481 L
.42129 .02894 L
.42716 .01988 L
.42757 .01923 L
Mfstroke
.6 g
.01923 .42103 m
.02281 .41744 L
.02894 .41132 L
.03253 .40773 L
.03866 .4016 L
.04224 .39802 L
.04837 .39189 L
.05195 .38831 L
.05808 .38218 L
.06167 .37859 L
.06779 .37247 L
.07138 .36888 L
.07751 .36275 L
.08109 .35917 L
.08722 .35304 L
.0908 .34946 L
.09693 .34333 L
.10052 .33974 L
.10664 .33362 L
.11023 .33003 L
.11636 .3239 L
.11994 .32032 L
.12607 .31419 L
.12965 .31061 L
.13578 .30448 L
.13937 .30089 L
.14549 .29477 L
.14908 .29118 L
.15521 .28505 L
.15879 .28147 L
.16492 .27534 L
.1685 .27176 L
.17463 .26563 L
.17822 .26204 L
.18434 .25592 L
.18793 .25233 L
.19406 .2462 L
.19764 .24262 L
.20377 .23649 L
.20735 .23291 L
.21348 .22678 L
.21707 .22319 L
.22319 .21707 L
.22678 .21348 L
.23291 .20735 L
.23649 .20377 L
.24262 .19764 L
.2462 .19406 L
.25233 .18793 L
.25592 .18434 L
.26204 .17822 L
.26563 .17463 L
.27176 .1685 L
.27534 .16492 L
.28147 .15879 L
.28505 .15521 L
.29118 .14908 L
.29477 .14549 L
.30089 .13937 L
.30448 .13578 L
.31061 .12965 L
.31419 .12607 L
.32032 .11994 L
.3239 .11636 L
.33003 .11023 L
.33363 .10664 L
.33974 .10052 L
.3434 .09693 L
.34946 .09107 L
.35323 .08722 L
.35917 .08085 L
.36222 .07751 L
.36888 .0699 L
.37069 .06779 L
.37859 .05829 L
.37876 .05808 L
.38652 .04837 L
.38831 .04605 L
.39397 .03866 L
.39802 .03322 L
.40118 .02894 L
.40773 .01983 L
.40816 .01923 L
.01923 .01923 L
F
0 g
.01923 .42103 m
.02281 .41744 L
.02894 .41132 L
.03253 .40773 L
.03866 .4016 L
.04224 .39802 L
.04837 .39189 L
.05195 .38831 L
.05808 .38218 L
.06167 .37859 L
.06779 .37247 L
.07138 .36888 L
.07751 .36275 L
.08109 .35917 L
.08722 .35304 L
.0908 .34946 L
.09693 .34333 L
.10052 .33974 L
.10664 .33362 L
.11023 .33003 L
.11636 .3239 L
.11994 .32032 L
.12607 .31419 L
.12965 .31061 L
.13578 .30448 L
.13937 .30089 L
.14549 .29477 L
.14908 .29118 L
.15521 .28505 L
.15879 .28147 L
.16492 .27534 L
.1685 .27176 L
.17463 .26563 L
.17822 .26204 L
.18434 .25592 L
.18793 .25233 L
.19406 .2462 L
.19764 .24262 L
.20377 .23649 L
.20735 .23291 L
.21348 .22678 L
.21707 .22319 L
.22319 .21707 L
.22678 .21348 L
.23291 .20735 L
.23649 .20377 L
.24262 .19764 L
.2462 .19406 L
.25233 .18793 L
.25592 .18434 L
Mistroke
.26204 .17822 L
.26563 .17463 L
.27176 .1685 L
.27534 .16492 L
.28147 .15879 L
.28505 .15521 L
.29118 .14908 L
.29477 .14549 L
.30089 .13937 L
.30448 .13578 L
.31061 .12965 L
.31419 .12607 L
.32032 .11994 L
.3239 .11636 L
.33003 .11023 L
.33363 .10664 L
.33974 .10052 L
.3434 .09693 L
.34946 .09107 L
.35323 .08722 L
.35917 .08085 L
.36222 .07751 L
.36888 .0699 L
.37069 .06779 L
.37859 .05829 L
.37876 .05808 L
.38652 .04837 L
.38831 .04605 L
.39397 .03866 L
.39802 .03322 L
.40118 .02894 L
.40773 .01983 L
.40816 .01923 L
Mfstroke
.7 g
.01923 .37734 m
.02764 .36888 L
.02894 .36763 L
.0374 .35917 L
.03866 .35791 L
.04711 .34946 L
.04837 .3482 L
.05683 .33974 L
.05808 .33849 L
.06654 .33003 L
.06779 .32878 L
.07625 .32032 L
.07751 .31906 L
.08596 .31061 L
.08722 .30935 L
.09568 .30089 L
.09693 .29964 L
.10539 .29118 L
.10664 .28993 L
.1151 .28147 L
.11636 .28021 L
.12481 .27176 L
.12607 .2705 L
.13453 .26204 L
.13578 .26079 L
.14424 .25233 L
.14549 .25108 L
.15395 .24262 L
.15521 .24136 L
.16366 .23291 L
.16492 .23165 L
.17338 .22319 L
.17463 .22194 L
.18309 .21348 L
.18434 .21223 L
.1928 .20377 L
.19406 .20251 L
.20251 .19406 L
.20377 .1928 L
.21223 .18434 L
.21348 .18309 L
.22194 .17463 L
.22319 .17338 L
.23165 .16492 L
.23291 .16366 L
.24136 .15521 L
.24262 .15395 L
.25108 .14549 L
.25233 .14424 L
.26079 .13578 L
.26204 .13453 L
.2705 .12607 L
.27176 .12481 L
.28021 .11636 L
.28147 .1151 L
.28993 .10664 L
.29118 .10539 L
.29964 .09693 L
.30089 .09568 L
.30935 .08722 L
.31061 .08596 L
.31906 .07751 L
.32032 .07625 L
.32878 .06779 L
.33003 .06654 L
.33841 .05808 L
.33974 .05683 L
.34946 .0498 L
.35135 .04837 L
.35917 .0415 L
.36236 .03866 L
.36888 .03213 L
.37208 .02894 L
.37859 .0218 L
.381 .01923 L
.01923 .01923 L
F
0 g
.01923 .37734 m
.02764 .36888 L
.02894 .36763 L
.0374 .35917 L
.03866 .35791 L
.04711 .34946 L
.04837 .3482 L
.05683 .33974 L
.05808 .33849 L
.06654 .33003 L
.06779 .32878 L
.07625 .32032 L
.07751 .31906 L
.08596 .31061 L
.08722 .30935 L
.09568 .30089 L
.09693 .29964 L
.10539 .29118 L
.10664 .28993 L
.1151 .28147 L
.11636 .28021 L
.12481 .27176 L
.12607 .2705 L
.13453 .26204 L
.13578 .26079 L
.14424 .25233 L
.14549 .25108 L
.15395 .24262 L
.15521 .24136 L
.16366 .23291 L
.16492 .23165 L
.17338 .22319 L
.17463 .22194 L
.18309 .21348 L
.18434 .21223 L
.1928 .20377 L
.19406 .20251 L
.20251 .19406 L
.20377 .1928 L
.21223 .18434 L
.21348 .18309 L
.22194 .17463 L
.22319 .17338 L
.23165 .16492 L
.23291 .16366 L
.24136 .15521 L
.24262 .15395 L
.25108 .14549 L
.25233 .14424 L
.26079 .13578 L
Mistroke
.26204 .13453 L
.2705 .12607 L
.27176 .12481 L
.28021 .11636 L
.28147 .1151 L
.28993 .10664 L
.29118 .10539 L
.29964 .09693 L
.30089 .09568 L
.30935 .08722 L
.31061 .08596 L
.31906 .07751 L
.32032 .07625 L
.32878 .06779 L
.33003 .06654 L
.33841 .05808 L
.33974 .05683 L
.34946 .0498 L
.35135 .04837 L
.35917 .0415 L
.36236 .03866 L
.36888 .03213 L
.37208 .02894 L
.37859 .0218 L
.381 .01923 L
Mfstroke
.6 g
.01923 .29875 m
.02691 .29118 L
.02894 .28904 L
.03651 .28147 L
.03866 .27933 L
.04623 .27176 L
.04837 .26961 L
.05594 .26204 L
.05808 .2599 L
.06565 .25233 L
.06779 .25019 L
.07536 .24262 L
.07751 .24048 L
.08508 .23291 L
.08722 .23076 L
.09479 .22319 L
.09693 .22105 L
.1045 .21348 L
.10664 .21134 L
.11421 .20377 L
.11636 .20163 L
.12393 .19406 L
.12607 .19191 L
.13364 .18434 L
.13578 .1822 L
.14335 .17463 L
.14549 .17249 L
.15306 .16492 L
.15521 .16278 L
.16278 .15521 L
.16492 .15306 L
.17249 .14549 L
.17463 .14335 L
.1822 .13578 L
.18434 .13364 L
.19191 .12607 L
.19406 .12393 L
.20163 .11636 L
.20377 .11421 L
.21134 .10664 L
.21348 .1045 L
.22105 .09693 L
.22319 .09479 L
.23076 .08722 L
.23291 .08508 L
.24048 .07751 L
.24262 .07536 L
.25019 .06779 L
.25233 .06565 L
.2599 .05808 L
.26204 .05594 L
.26961 .04837 L
.27176 .04623 L
.27933 .03866 L
.28147 .03651 L
.28904 .02894 L
.29118 .02691 L
.29875 .01923 L
.01923 .01923 L
F
0 g
.01923 .29875 m
.02691 .29118 L
.02894 .28904 L
.03651 .28147 L
.03866 .27933 L
.04623 .27176 L
.04837 .26961 L
.05594 .26204 L
.05808 .2599 L
.06565 .25233 L
.06779 .25019 L
.07536 .24262 L
.07751 .24048 L
.08508 .23291 L
.08722 .23076 L
.09479 .22319 L
.09693 .22105 L
.1045 .21348 L
.10664 .21134 L
.11421 .20377 L
.11636 .20163 L
.12393 .19406 L
.12607 .19191 L
.13364 .18434 L
.13578 .1822 L
.14335 .17463 L
.14549 .17249 L
.15306 .16492 L
.15521 .16278 L
.16278 .15521 L
.16492 .15306 L
.17249 .14549 L
.17463 .14335 L
.1822 .13578 L
.18434 .13364 L
.19191 .12607 L
.19406 .12393 L
.20163 .11636 L
.20377 .11421 L
.21134 .10664 L
.21348 .1045 L
.22105 .09693 L
.22319 .09479 L
.23076 .08722 L
.23291 .08508 L
.24048 .07751 L
.24262 .07536 L
.25019 .06779 L
.25233 .06565 L
.2599 .05808 L
Mistroke
.26204 .05594 L
.26961 .04837 L
.27176 .04623 L
.27933 .03866 L
.28147 .03651 L
.28904 .02894 L
.29118 .02691 L
.29875 .01923 L
Mfstroke
.5 g
.01923 .25505 m
.02196 .25233 L
.02894 .24534 L
.03167 .24262 L
.03866 .23563 L
.04138 .23291 L
.04837 .22592 L
.05109 .22319 L
.05808 .2162 L
.0608 .21348 L
.06779 .20649 L
.07052 .20377 L
.07751 .19678 L
.08023 .19406 L
.08722 .18707 L
.08994 .18434 L
.09693 .17735 L
.09965 .17463 L
.10664 .16764 L
.10937 .16492 L
.11636 .15793 L
.11908 .15521 L
.12607 .14822 L
.12879 .14549 L
.13578 .1385 L
.1385 .13578 L
.14549 .12879 L
.14822 .12607 L
.15521 .11908 L
.15793 .11636 L
.16492 .10937 L
.16764 .10664 L
.17463 .09965 L
.17735 .09693 L
.18434 .08994 L
.18707 .08722 L
.19406 .08023 L
.19678 .07751 L
.20377 .07052 L
.20649 .06779 L
.21348 .0608 L
.2162 .05808 L
.22319 .05109 L
.22592 .04837 L
.23291 .04138 L
.23563 .03866 L
.24262 .03167 L
.24534 .02894 L
.25233 .02196 L
.25505 .01923 L
.01923 .01923 L
F
0 g
.01923 .25505 m
.02196 .25233 L
.02894 .24534 L
.03167 .24262 L
.03866 .23563 L
.04138 .23291 L
.04837 .22592 L
.05109 .22319 L
.05808 .2162 L
.0608 .21348 L
.06779 .20649 L
.07052 .20377 L
.07751 .19678 L
.08023 .19406 L
.08722 .18707 L
.08994 .18434 L
.09693 .17735 L
.09965 .17463 L
.10664 .16764 L
.10937 .16492 L
.11636 .15793 L
.11908 .15521 L
.12607 .14822 L
.12879 .14549 L
.13578 .1385 L
.1385 .13578 L
.14549 .12879 L
.14822 .12607 L
.15521 .11908 L
.15793 .11636 L
.16492 .10937 L
.16764 .10664 L
.17463 .09965 L
.17735 .09693 L
.18434 .08994 L
.18707 .08722 L
.19406 .08023 L
.19678 .07751 L
.20377 .07052 L
.20649 .06779 L
.21348 .0608 L
.2162 .05808 L
.22319 .05109 L
.22592 .04837 L
.23291 .04138 L
.23563 .03866 L
.24262 .03167 L
.24534 .02894 L
.25233 .02196 L
.25505 .01923 L
Mistroke
Mfstroke
.4 g
.01923 .21965 m
.02539 .21348 L
.02894 .20993 L
.03511 .20377 L
.03866 .20022 L
.04482 .19406 L
.04837 .19051 L
.05453 .18434 L
.05808 .1808 L
.06425 .17463 L
.06779 .17108 L
.07396 .16492 L
.07751 .16137 L
.08367 .15521 L
.08722 .15166 L
.09338 .14549 L
.09693 .14195 L
.1031 .13578 L
.10664 .13223 L
.11281 .12607 L
.11636 .12252 L
.12252 .11636 L
.12607 .11281 L
.13223 .10664 L
.13578 .1031 L
.14195 .09693 L
.14549 .09338 L
.15166 .08722 L
.15521 .08367 L
.16137 .07751 L
.16492 .07396 L
.17108 .06779 L
.17463 .06425 L
.1808 .05808 L
.18434 .05453 L
.19051 .04837 L
.19406 .04482 L
.20022 .03866 L
.20377 .03511 L
.20993 .02894 L
.21348 .02539 L
.21965 .01923 L
.01923 .01923 L
F
0 g
.01923 .21965 m
.02539 .21348 L
.02894 .20993 L
.03511 .20377 L
.03866 .20022 L
.04482 .19406 L
.04837 .19051 L
.05453 .18434 L
.05808 .1808 L
.06425 .17463 L
.06779 .17108 L
.07396 .16492 L
.07751 .16137 L
.08367 .15521 L
.08722 .15166 L
.09338 .14549 L
.09693 .14195 L
.1031 .13578 L
.10664 .13223 L
.11281 .12607 L
.11636 .12252 L
.12252 .11636 L
.12607 .11281 L
.13223 .10664 L
.13578 .1031 L
.14195 .09693 L
.14549 .09338 L
.15166 .08722 L
.15521 .08367 L
.16137 .07751 L
.16492 .07396 L
.17108 .06779 L
.17463 .06425 L
.1808 .05808 L
.18434 .05453 L
.19051 .04837 L
.19406 .04482 L
.20022 .03866 L
.20377 .03511 L
.20993 .02894 L
.21348 .02539 L
.21965 .01923 L
s
.3 g
.01923 .17594 m
.02051 .17463 L
.02894 .16623 L
.03025 .16492 L
.03866 .15651 L
.03996 .15521 L
.04837 .1468 L
.04968 .14549 L
.05808 .13709 L
.05939 .13578 L
.06779 .12738 L
.0691 .12607 L
.07751 .11766 L
.07881 .11636 L
.08722 .10795 L
.08853 .10664 L
.09693 .09824 L
.09824 .09693 L
.10664 .08853 L
.10795 .08722 L
.11636 .07881 L
.11766 .07751 L
.12607 .0691 L
.12738 .06779 L
.13578 .05939 L
.13709 .05808 L
.14549 .04968 L
.1468 .04837 L
.15521 .03996 L
.15651 .03866 L
.16492 .03025 L
.16623 .02894 L
.17463 .02051 L
.17594 .01923 L
.01923 .01923 L
F
0 g
.01923 .17594 m
.02051 .17463 L
.02894 .16623 L
.03025 .16492 L
.03866 .15651 L
.03996 .15521 L
.04837 .1468 L
.04968 .14549 L
.05808 .13709 L
.05939 .13578 L
.06779 .12738 L
.0691 .12607 L
.07751 .11766 L
.07881 .11636 L
.08722 .10795 L
.08853 .10664 L
.09693 .09824 L
.09824 .09693 L
.10664 .08853 L
.10795 .08722 L
.11636 .07881 L
.11766 .07751 L
.12607 .0691 L
.12738 .06779 L
.13578 .05939 L
.13709 .05808 L
.14549 .04968 L
.1468 .04837 L
.15521 .03996 L
.15651 .03866 L
.16492 .03025 L
.16623 .02894 L
.17463 .02051 L
.17594 .01923 L
s
.4 g
.01923 .09738 m
.01982 .09693 L
.02894 .08767 L
.02939 .08722 L
.03866 .07795 L
.0391 .07751 L
.04837 .06824 L
.04882 .06779 L
.05808 .05853 L
.05853 .05808 L
.06779 .04882 L
.06824 .04837 L
.07751 .0391 L
.07795 .03866 L
.08722 .02939 L
.08767 .02894 L
.09693 .01982 L
.09738 .01923 L
.01923 .01923 L
F
0 g
.01923 .09738 m
.01982 .09693 L
.02894 .08767 L
.02939 .08722 L
.03866 .07795 L
.0391 .07751 L
.04837 .06824 L
.04882 .06779 L
.05808 .05853 L
.05853 .05808 L
.06779 .04882 L
.06824 .04837 L
.07751 .0391 L
.07795 .03866 L
.08722 .02939 L
.08767 .02894 L
.09693 .01982 L
.09738 .01923 L
s
.5 g
.01923 .05367 m
.02454 .04837 L
.02894 .04396 L
.03425 .03866 L
.03866 .03425 L
.04396 .02894 L
.04837 .02454 L
.05367 .01923 L
.01923 .01923 L
F
0 g
.01923 .05367 m
.02454 .04837 L
.02894 .04396 L
.03425 .03866 L
.03866 .03425 L
.04396 .02894 L
.04837 .02454 L
.05367 .01923 L
s
.4 g
.01991 .98077 m
.02894 .97173 L
.02964 .97106 L
.03866 .96204 L
.03936 .96134 L
.04837 .95233 L
.04907 .95163 L
.05808 .94262 L
.05878 .94192 L
.06779 .93291 L
.06849 .93221 L
.07751 .92319 L
.07821 .92249 L
.08722 .91348 L
.08792 .91278 L
.09693 .90377 L
.09763 .90307 L
.10664 .89406 L
.10734 .89336 L
.11636 .88434 L
.11706 .88364 L
.12607 .87463 L
.12677 .87393 L
.13578 .86492 L
.13648 .86422 L
.14549 .85521 L
.14619 .85451 L
.15521 .84549 L
.15591 .84479 L
.16492 .83578 L
.16562 .83508 L
.17463 .82607 L
.17533 .82537 L
.18434 .81636 L
.18504 .81566 L
.19406 .80664 L
.19476 .80594 L
.20377 .79693 L
.20447 .79623 L
.21348 .78722 L
.21418 .78652 L
.22319 .77751 L
.22389 .77681 L
.23291 .76779 L
.23361 .76709 L
.24262 .75808 L
.24332 .75738 L
.25233 .74837 L
.25303 .74767 L
.26204 .73866 L
.26274 .73796 L
.27176 .72894 L
.27246 .72824 L
.28147 .71923 L
.28217 .71853 L
.29118 .70952 L
.29188 .70882 L
.30089 .69981 L
.30159 .69911 L
.31061 .69009 L
.31131 .68939 L
.32032 .68038 L
.32102 .67968 L
.33003 .67067 L
.33072 .66997 L
.33974 .66096 L
.34059 .66026 L
.34946 .65396 L
.3539 .65054 L
.35917 .64566 L
.36451 .64083 L
.36888 .63628 L
.37401 .63112 L
.37859 .62599 L
.3828 .62141 L
.38831 .61489 L
.39105 .61169 L
.39802 .60304 L
.39888 .60198 L
.40648 .59227 L
.40773 .59053 L
.41378 .58256 L
.41744 .57738 L
.42076 .57284 L
.42716 .56362 L
.4275 .56313 L
.43423 .55342 L
.43687 .54933 L
.44066 .54371 L
.44658 .53447 L
.44689 .53399 L
.45317 .52428 L
.45629 .51913 L
.45918 .51457 L
.4651 .50486 L
.46601 .50328 L
.47098 .49514 L
.47572 .48696 L
.47663 .48543 L
.48236 .47572 L
.48543 .47018 L
.48786 .46601 L
.49337 .45629 L
.49514 .45296 L
.49876 .44658 L
.50406 .43687 L
.50486 .43531 L
.50936 .42716 L
.51446 .41744 L
.51457 .41723 L
.5197 .40773 L
.52428 .39875 L
.52467 .39802 L
.5298 .38831 L
.53399 .37988 L
.53466 .37859 L
.53968 .36888 L
.54371 .36061 L
.54444 .35917 L
.54936 .34946 L
.55342 .34097 L
.55403 .33974 L
.55887 .33003 L
.56313 .32095 L
.56344 .32032 L
.5682 .31061 L
.5727 .30089 L
.57284 .30057 L
.57737 .29118 L
.58185 .28147 L
.58256 .27983 L
.58639 .27176 L
.59086 .26204 L
.59227 .25874 L
.59527 .25233 L
.59972 .24262 L
.60198 .23731 L
.60401 .23291 L
.60844 .22319 L
.61169 .21553 L
.61262 .21348 L
.61702 .20377 L
.62116 .19406 L
.62141 .19343 L
.62547 .18434 L
.62967 .17463 L
.63112 .171 L
.6338 .16492 L
.63802 .15521 L
.64083 .14824 L
.64202 .14549 L
.64624 .13578 L
.65021 .12607 L
.65054 .12516 L
.65432 .11636 L
.65839 .10664 L
.66026 .10178 L
.66231 .09693 L
.6664 .08722 L
.66997 .07808 L
.67021 .07751 L
.67427 .06779 L
.67821 .05808 L
.67968 .05408 L
.68204 .04837 L
.68603 .03866 L
.68939 .02977 L
.68973 .02894 L
.69371 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.01991 .98077 m
.02894 .97173 L
.02964 .97106 L
.03866 .96204 L
.03936 .96134 L
.04837 .95233 L
.04907 .95163 L
.05808 .94262 L
.05878 .94192 L
.06779 .93291 L
.06849 .93221 L
.07751 .92319 L
.07821 .92249 L
.08722 .91348 L
.08792 .91278 L
.09693 .90377 L
.09763 .90307 L
.10664 .89406 L
.10734 .89336 L
.11636 .88434 L
.11706 .88364 L
.12607 .87463 L
.12677 .87393 L
.13578 .86492 L
.13648 .86422 L
.14549 .85521 L
.14619 .85451 L
.15521 .84549 L
.15591 .84479 L
.16492 .83578 L
.16562 .83508 L
.17463 .82607 L
.17533 .82537 L
.18434 .81636 L
.18504 .81566 L
.19406 .80664 L
.19476 .80594 L
.20377 .79693 L
.20447 .79623 L
.21348 .78722 L
.21418 .78652 L
.22319 .77751 L
.22389 .77681 L
.23291 .76779 L
.23361 .76709 L
.24262 .75808 L
.24332 .75738 L
.25233 .74837 L
.25303 .74767 L
.26204 .73866 L
Mistroke
.26274 .73796 L
.27176 .72894 L
.27246 .72824 L
.28147 .71923 L
.28217 .71853 L
.29118 .70952 L
.29188 .70882 L
.30089 .69981 L
.30159 .69911 L
.31061 .69009 L
.31131 .68939 L
.32032 .68038 L
.32102 .67968 L
.33003 .67067 L
.33072 .66997 L
.33974 .66096 L
.34059 .66026 L
.34946 .65396 L
.3539 .65054 L
.35917 .64566 L
.36451 .64083 L
.36888 .63628 L
.37401 .63112 L
.37859 .62599 L
.3828 .62141 L
.38831 .61489 L
.39105 .61169 L
.39802 .60304 L
.39888 .60198 L
.40648 .59227 L
.40773 .59053 L
.41378 .58256 L
.41744 .57738 L
.42076 .57284 L
.42716 .56362 L
.4275 .56313 L
.43423 .55342 L
.43687 .54933 L
.44066 .54371 L
.44658 .53447 L
.44689 .53399 L
.45317 .52428 L
.45629 .51913 L
.45918 .51457 L
.4651 .50486 L
.46601 .50328 L
.47098 .49514 L
.47572 .48696 L
.47663 .48543 L
.48236 .47572 L
Mistroke
.48543 .47018 L
.48786 .46601 L
.49337 .45629 L
.49514 .45296 L
.49876 .44658 L
.50406 .43687 L
.50486 .43531 L
.50936 .42716 L
.51446 .41744 L
.51457 .41723 L
.5197 .40773 L
.52428 .39875 L
.52467 .39802 L
.5298 .38831 L
.53399 .37988 L
.53466 .37859 L
.53968 .36888 L
.54371 .36061 L
.54444 .35917 L
.54936 .34946 L
.55342 .34097 L
.55403 .33974 L
.55887 .33003 L
.56313 .32095 L
.56344 .32032 L
.5682 .31061 L
.5727 .30089 L
.57284 .30057 L
.57737 .29118 L
.58185 .28147 L
.58256 .27983 L
.58639 .27176 L
.59086 .26204 L
.59227 .25874 L
.59527 .25233 L
.59972 .24262 L
.60198 .23731 L
.60401 .23291 L
.60844 .22319 L
.61169 .21553 L
.61262 .21348 L
.61702 .20377 L
.62116 .19406 L
.62141 .19343 L
.62547 .18434 L
.62967 .17463 L
.63112 .171 L
.6338 .16492 L
.63802 .15521 L
.64083 .14824 L
Mistroke
.64202 .14549 L
.64624 .13578 L
.65021 .12607 L
.65054 .12516 L
.65432 .11636 L
.65839 .10664 L
.66026 .10178 L
.66231 .09693 L
.6664 .08722 L
.66997 .07808 L
.67021 .07751 L
.67427 .06779 L
.67821 .05808 L
.67968 .05408 L
.68204 .04837 L
.68603 .03866 L
.68939 .02977 L
.68973 .02894 L
.69371 .01923 L
Mfstroke
.5 g
.06364 .98077 m
.06779 .97661 L
.07336 .97106 L
.07751 .96691 L
.08307 .96134 L
.08722 .95719 L
.09278 .95163 L
.09693 .94748 L
.10249 .94192 L
.10664 .93777 L
.11221 .93221 L
.11636 .92806 L
.12192 .92249 L
.12607 .91834 L
.13163 .91278 L
.13578 .90863 L
.14134 .90307 L
.14549 .89892 L
.15106 .89336 L
.15521 .88921 L
.16077 .88364 L
.16492 .87949 L
.17048 .87393 L
.17463 .86978 L
.18019 .86422 L
.18434 .86007 L
.18991 .85451 L
.19406 .85036 L
.19962 .84479 L
.20377 .84064 L
.20933 .83508 L
.21348 .83093 L
.21904 .82537 L
.22319 .82122 L
.22876 .81566 L
.23291 .81151 L
.23847 .80594 L
.24262 .80179 L
.24818 .79623 L
.25233 .79208 L
.25789 .78652 L
.26204 .78237 L
.26761 .77681 L
.27176 .77266 L
.27732 .76709 L
.28147 .76294 L
.28703 .75738 L
.29118 .75323 L
.29674 .74767 L
.30089 .74352 L
.30646 .73796 L
.31061 .73381 L
.31617 .72824 L
.32032 .72409 L
.32588 .71853 L
.33003 .71438 L
.33561 .70882 L
.33974 .70467 L
.34544 .69911 L
.34946 .69523 L
.35511 .68939 L
.35917 .685 L
.36399 .67968 L
.36888 .67405 L
.37238 .66997 L
.37859 .66244 L
.38037 .66026 L
.38804 .65054 L
.38831 .6502 L
.39546 .64083 L
.39802 .63737 L
.40262 .63112 L
.40773 .62398 L
.40956 .62141 L
.41632 .61169 L
.41744 .61005 L
.42292 .60198 L
.42716 .5956 L
.42936 .59227 L
.43566 .58256 L
.43687 .58065 L
.44184 .57284 L
.44658 .56523 L
.44788 .56313 L
.45384 .55342 L
.45629 .54934 L
.45968 .54371 L
.46542 .53399 L
.46601 .53299 L
.4711 .52428 L
.47572 .51621 L
.47666 .51457 L
.48217 .50486 L
.48543 .499 L
.48759 .49514 L
.49295 .48543 L
.49514 .48138 L
.49823 .47572 L
.50345 .46601 L
.50486 .46335 L
.50862 .45629 L
.51371 .44658 L
.51457 .44493 L
.51877 .43687 L
.52375 .42716 L
.52428 .42611 L
.52871 .41744 L
.53359 .40773 L
.53399 .40692 L
.53845 .39802 L
.54324 .38831 L
.54371 .38736 L
.54802 .37859 L
.55272 .36888 L
.55342 .36743 L
.55741 .35917 L
.56204 .34946 L
.56313 .34714 L
.56665 .33974 L
.57121 .33003 L
.57284 .3265 L
.57573 .32032 L
.58023 .31061 L
.58256 .30551 L
.58468 .30089 L
.58912 .29118 L
.59227 .28418 L
.5935 .28147 L
.59789 .27176 L
.60198 .26252 L
.6022 .26204 L
.60652 .25233 L
.61079 .24262 L
.61169 .24053 L
.61505 .23291 L
.61928 .22319 L
.62141 .21822 L
.62346 .21348 L
.62765 .20377 L
.63112 .19558 L
.63177 .19406 L
.63592 .18434 L
.64001 .17463 L
.64083 .17264 L
.64408 .16492 L
.64815 .15521 L
.65054 .14937 L
.65216 .14549 L
.65619 .13578 L
.66015 .12607 L
.66026 .12581 L
.66414 .11636 L
.66809 .10664 L
.66997 .10194 L
.672 .09693 L
.67593 .08722 L
.67968 .07777 L
.67979 .07751 L
.68368 .06779 L
.68754 .05808 L
.68939 .05331 L
.69135 .04837 L
.69519 .03866 L
.69896 .02894 L
.69911 .02855 L
.70276 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.06364 .98077 m
.06779 .97661 L
.07336 .97106 L
.07751 .96691 L
.08307 .96134 L
.08722 .95719 L
.09278 .95163 L
.09693 .94748 L
.10249 .94192 L
.10664 .93777 L
.11221 .93221 L
.11636 .92806 L
.12192 .92249 L
.12607 .91834 L
.13163 .91278 L
.13578 .90863 L
.14134 .90307 L
.14549 .89892 L
.15106 .89336 L
.15521 .88921 L
.16077 .88364 L
.16492 .87949 L
.17048 .87393 L
.17463 .86978 L
.18019 .86422 L
.18434 .86007 L
.18991 .85451 L
.19406 .85036 L
.19962 .84479 L
.20377 .84064 L
.20933 .83508 L
.21348 .83093 L
.21904 .82537 L
.22319 .82122 L
.22876 .81566 L
.23291 .81151 L
.23847 .80594 L
.24262 .80179 L
.24818 .79623 L
.25233 .79208 L
.25789 .78652 L
.26204 .78237 L
.26761 .77681 L
.27176 .77266 L
.27732 .76709 L
.28147 .76294 L
.28703 .75738 L
.29118 .75323 L
.29674 .74767 L
.30089 .74352 L
Mistroke
.30646 .73796 L
.31061 .73381 L
.31617 .72824 L
.32032 .72409 L
.32588 .71853 L
.33003 .71438 L
.33561 .70882 L
.33974 .70467 L
.34544 .69911 L
.34946 .69523 L
.35511 .68939 L
.35917 .685 L
.36399 .67968 L
.36888 .67405 L
.37238 .66997 L
.37859 .66244 L
.38037 .66026 L
.38804 .65054 L
.38831 .6502 L
.39546 .64083 L
.39802 .63737 L
.40262 .63112 L
.40773 .62398 L
.40956 .62141 L
.41632 .61169 L
.41744 .61005 L
.42292 .60198 L
.42716 .5956 L
.42936 .59227 L
.43566 .58256 L
.43687 .58065 L
.44184 .57284 L
.44658 .56523 L
.44788 .56313 L
.45384 .55342 L
.45629 .54934 L
.45968 .54371 L
.46542 .53399 L
.46601 .53299 L
.4711 .52428 L
.47572 .51621 L
.47666 .51457 L
.48217 .50486 L
.48543 .499 L
.48759 .49514 L
.49295 .48543 L
.49514 .48138 L
.49823 .47572 L
.50345 .46601 L
.50486 .46335 L
Mistroke
.50862 .45629 L
.51371 .44658 L
.51457 .44493 L
.51877 .43687 L
.52375 .42716 L
.52428 .42611 L
.52871 .41744 L
.53359 .40773 L
.53399 .40692 L
.53845 .39802 L
.54324 .38831 L
.54371 .38736 L
.54802 .37859 L
.55272 .36888 L
.55342 .36743 L
.55741 .35917 L
.56204 .34946 L
.56313 .34714 L
.56665 .33974 L
.57121 .33003 L
.57284 .3265 L
.57573 .32032 L
.58023 .31061 L
.58256 .30551 L
.58468 .30089 L
.58912 .29118 L
.59227 .28418 L
.5935 .28147 L
.59789 .27176 L
.60198 .26252 L
.6022 .26204 L
.60652 .25233 L
.61079 .24262 L
.61169 .24053 L
.61505 .23291 L
.61928 .22319 L
.62141 .21822 L
.62346 .21348 L
.62765 .20377 L
.63112 .19558 L
.63177 .19406 L
.63592 .18434 L
.64001 .17463 L
.64083 .17264 L
.64408 .16492 L
.64815 .15521 L
.65054 .14937 L
.65216 .14549 L
.65619 .13578 L
.66015 .12607 L
Mistroke
.66026 .12581 L
.66414 .11636 L
.66809 .10664 L
.66997 .10194 L
.672 .09693 L
.67593 .08722 L
.67968 .07777 L
.67979 .07751 L
.68368 .06779 L
.68754 .05808 L
.68939 .05331 L
.69135 .04837 L
.69519 .03866 L
.69896 .02894 L
.69911 .02855 L
.70276 .01923 L
Mfstroke
.6 g
.09905 .98077 m
.10664 .97318 L
.10877 .97106 L
.11636 .96347 L
.11848 .96134 L
.12607 .95375 L
.12819 .95163 L
.13578 .94404 L
.1379 .94192 L
.14549 .93433 L
.14762 .93221 L
.15521 .92462 L
.15733 .92249 L
.16492 .9149 L
.16704 .91278 L
.17463 .90519 L
.17675 .90307 L
.18434 .89548 L
.18647 .89336 L
.19406 .88577 L
.19618 .88364 L
.20377 .87605 L
.20589 .87393 L
.21348 .86634 L
.2156 .86422 L
.22319 .85663 L
.22532 .85451 L
.23291 .84692 L
.23503 .84479 L
.24262 .8372 L
.24474 .83508 L
.25233 .82749 L
.25445 .82537 L
.26204 .81778 L
.26417 .81566 L
.27176 .80807 L
.27388 .80594 L
.28147 .79835 L
.28359 .79623 L
.29118 .78864 L
.2933 .78652 L
.30089 .77893 L
.30302 .77681 L
.31061 .76922 L
.31273 .76709 L
.32032 .7595 L
.32244 .75738 L
.33003 .74979 L
.33221 .74767 L
.33974 .74008 L
.34171 .73796 L
.34946 .72938 L
.35046 .72824 L
.3588 .71853 L
.35917 .71809 L
.3668 .70882 L
.36888 .70623 L
.37451 .69911 L
.37859 .69381 L
.38195 .68939 L
.38831 .68086 L
.38917 .67968 L
.39619 .66997 L
.39802 .66739 L
.40302 .66026 L
.40773 .65342 L
.40969 .65054 L
.41621 .64083 L
.41744 .63896 L
.42258 .63112 L
.42716 .62403 L
.42883 .62141 L
.43496 .61169 L
.43687 .60864 L
.44098 .60198 L
.44658 .5928 L
.4469 .59227 L
.45272 .58256 L
.45629 .57652 L
.45845 .57284 L
.4641 .56313 L
.46601 .55982 L
.46966 .55342 L
.47516 .54371 L
.47572 .5427 L
.48057 .53399 L
.48543 .52518 L
.48592 .52428 L
.4912 .51457 L
.49514 .50726 L
.49643 .50486 L
.50159 .49514 L
.50486 .48895 L
.50669 .48543 L
.51175 .47572 L
.51457 .47025 L
.51674 .46601 L
.5217 .45629 L
.52428 .45119 L
.52659 .44658 L
.53145 .43687 L
.53399 .43175 L
.53626 .42716 L
.54103 .41744 L
.54371 .41195 L
.54575 .40773 L
.55044 .39802 L
.55342 .3918 L
.55508 .38831 L
.55969 .37859 L
.56313 .3713 L
.56426 .36888 L
.5688 .35917 L
.57284 .35046 L
.57331 .34946 L
.57777 .33974 L
.58222 .33003 L
.58256 .32928 L
.58661 .32032 L
.591 .31061 L
.59227 .30777 L
.59533 .30089 L
.59966 .29118 L
.60198 .28593 L
.60393 .28147 L
.6082 .27176 L
.61169 .26377 L
.61244 .26204 L
.61664 .25233 L
.62083 .24262 L
.62141 .24129 L
.62498 .23291 L
.62912 .22319 L
.63112 .21849 L
.63322 .21348 L
.63731 .20377 L
.64083 .19538 L
.64138 .19406 L
.64541 .18434 L
.64945 .17463 L
.65054 .17197 L
.65343 .16492 L
.65742 .15521 L
.66026 .14826 L
.66137 .14549 L
.6653 .13578 L
.66924 .12607 L
.66997 .12425 L
.67311 .11636 L
.67701 .10664 L
.67968 .09994 L
.68086 .09693 L
.6847 .08722 L
.68855 .07751 L
.68939 .07535 L
.69233 .06779 L
.69614 .05808 L
.69911 .05046 L
.69991 .04837 L
.70366 .03866 L
.70742 .02894 L
.70882 .0253 L
.71112 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.09905 .98077 m
.10664 .97318 L
.10877 .97106 L
.11636 .96347 L
.11848 .96134 L
.12607 .95375 L
.12819 .95163 L
.13578 .94404 L
.1379 .94192 L
.14549 .93433 L
.14762 .93221 L
.15521 .92462 L
.15733 .92249 L
.16492 .9149 L
.16704 .91278 L
.17463 .90519 L
.17675 .90307 L
.18434 .89548 L
.18647 .89336 L
.19406 .88577 L
.19618 .88364 L
.20377 .87605 L
.20589 .87393 L
.21348 .86634 L
.2156 .86422 L
.22319 .85663 L
.22532 .85451 L
.23291 .84692 L
.23503 .84479 L
.24262 .8372 L
.24474 .83508 L
.25233 .82749 L
.25445 .82537 L
.26204 .81778 L
.26417 .81566 L
.27176 .80807 L
.27388 .80594 L
.28147 .79835 L
.28359 .79623 L
.29118 .78864 L
.2933 .78652 L
.30089 .77893 L
.30302 .77681 L
.31061 .76922 L
.31273 .76709 L
.32032 .7595 L
.32244 .75738 L
.33003 .74979 L
.33221 .74767 L
.33974 .74008 L
Mistroke
.34171 .73796 L
.34946 .72938 L
.35046 .72824 L
.3588 .71853 L
.35917 .71809 L
.3668 .70882 L
.36888 .70623 L
.37451 .69911 L
.37859 .69381 L
.38195 .68939 L
.38831 .68086 L
.38917 .67968 L
.39619 .66997 L
.39802 .66739 L
.40302 .66026 L
.40773 .65342 L
.40969 .65054 L
.41621 .64083 L
.41744 .63896 L
.42258 .63112 L
.42716 .62403 L
.42883 .62141 L
.43496 .61169 L
.43687 .60864 L
.44098 .60198 L
.44658 .5928 L
.4469 .59227 L
.45272 .58256 L
.45629 .57652 L
.45845 .57284 L
.4641 .56313 L
.46601 .55982 L
.46966 .55342 L
.47516 .54371 L
.47572 .5427 L
.48057 .53399 L
.48543 .52518 L
.48592 .52428 L
.4912 .51457 L
.49514 .50726 L
.49643 .50486 L
.50159 .49514 L
.50486 .48895 L
.50669 .48543 L
.51175 .47572 L
.51457 .47025 L
.51674 .46601 L
.5217 .45629 L
.52428 .45119 L
.52659 .44658 L
Mistroke
.53145 .43687 L
.53399 .43175 L
.53626 .42716 L
.54103 .41744 L
.54371 .41195 L
.54575 .40773 L
.55044 .39802 L
.55342 .3918 L
.55508 .38831 L
.55969 .37859 L
.56313 .3713 L
.56426 .36888 L
.5688 .35917 L
.57284 .35046 L
.57331 .34946 L
.57777 .33974 L
.58222 .33003 L
.58256 .32928 L
.58661 .32032 L
.591 .31061 L
.59227 .30777 L
.59533 .30089 L
.59966 .29118 L
.60198 .28593 L
.60393 .28147 L
.6082 .27176 L
.61169 .26377 L
.61244 .26204 L
.61664 .25233 L
.62083 .24262 L
.62141 .24129 L
.62498 .23291 L
.62912 .22319 L
.63112 .21849 L
.63322 .21348 L
.63731 .20377 L
.64083 .19538 L
.64138 .19406 L
.64541 .18434 L
.64945 .17463 L
.65054 .17197 L
.65343 .16492 L
.65742 .15521 L
.66026 .14826 L
.66137 .14549 L
.6653 .13578 L
.66924 .12607 L
.66997 .12425 L
.67311 .11636 L
.67701 .10664 L
Mistroke
.67968 .09994 L
.68086 .09693 L
.6847 .08722 L
.68855 .07751 L
.68939 .07535 L
.69233 .06779 L
.69614 .05808 L
.69911 .05046 L
.69991 .04837 L
.70366 .03866 L
.70742 .02894 L
.70882 .0253 L
.71112 .01923 L
Mfstroke
.7 g
.14274 .98077 m
.14549 .97808 L
.15246 .97106 L
.15521 .96831 L
.16217 .96134 L
.16492 .95859 L
.17188 .95163 L
.17463 .94888 L
.18159 .94192 L
.18434 .93917 L
.19131 .93221 L
.19406 .92946 L
.20102 .92249 L
.20377 .91974 L
.21073 .91278 L
.21348 .91003 L
.22044 .90307 L
.22319 .90032 L
.23016 .89336 L
.23291 .89061 L
.23987 .88364 L
.24262 .88089 L
.24958 .87393 L
.25233 .87118 L
.25929 .86422 L
.26204 .86147 L
.26901 .85451 L
.27176 .85176 L
.27872 .84479 L
.28147 .84204 L
.28843 .83508 L
.29118 .83233 L
.29814 .82537 L
.30089 .82262 L
.30786 .81566 L
.31061 .81291 L
.31757 .80594 L
.32032 .80319 L
.32728 .79623 L
.33003 .79348 L
.33724 .78652 L
.33974 .78377 L
.34502 .77681 L
.34946 .77063 L
.35208 .76709 L
.35917 .75746 L
.35922 .75738 L
.36625 .74767 L
.36888 .744 L
.37317 .73796 L
.37859 .73026 L
.38 .72824 L
.3867 .71853 L
.38831 .71618 L
.39326 .70882 L
.39802 .70172 L
.39973 .69911 L
.4061 .68939 L
.40773 .68688 L
.41232 .67968 L
.41744 .67163 L
.41848 .66997 L
.42452 .66026 L
.42716 .656 L
.43045 .65054 L
.43635 .64083 L
.43687 .63997 L
.4421 .63112 L
.44658 .62354 L
.4478 .62141 L
.45343 .61169 L
.45629 .60673 L
.45895 .60198 L
.46446 .59227 L
.46601 .58953 L
.46984 .58256 L
.47523 .57284 L
.47572 .57196 L
.48047 .56313 L
.48543 .55401 L
.48574 .55342 L
.49087 .54371 L
.49514 .53568 L
.496 .53399 L
.50105 .52428 L
.50486 .51699 L
.50606 .51457 L
.51102 .50486 L
.51457 .49794 L
.51594 .49514 L
.52081 .48543 L
.52428 .47854 L
.52563 .47572 L
.53042 .46601 L
.53399 .45879 L
.53516 .45629 L
.53986 .44658 L
.54371 .43869 L
.54454 .43687 L
.54915 .42716 L
.55342 .41826 L
.55379 .41744 L
.55829 .40773 L
.56288 .39802 L
.56313 .39749 L
.56729 .38831 L
.57182 .37859 L
.57284 .37639 L
.57617 .36888 L
.58063 .35917 L
.58256 .35496 L
.58494 .34946 L
.58932 .33974 L
.59227 .33321 L
.59361 .33003 L
.59789 .32032 L
.60198 .31115 L
.6022 .31061 L
.60635 .30089 L
.61064 .29118 L
.61169 .28877 L
.61472 .28147 L
.61894 .27176 L
.62141 .26607 L
.62303 .26204 L
.62715 .25233 L
.63112 .24308 L
.6313 .24262 L
.63527 .23291 L
.63939 .22319 L
.64083 .21978 L
.64332 .21348 L
.64737 .20377 L
.65054 .19618 L
.65135 .19406 L
.65526 .18434 L
.65929 .17463 L
.66026 .17229 L
.6631 .16492 L
.66707 .15521 L
.66997 .14811 L
.67093 .14549 L
.67476 .13578 L
.6787 .12607 L
.67968 .12364 L
.68241 .11636 L
.68629 .10664 L
.68939 .09888 L
.69008 .09693 L
.6938 .08722 L
.69766 .07751 L
.69911 .07383 L
.70129 .06779 L
.70507 .05808 L
.70882 .04852 L
.70887 .04837 L
.71242 .03866 L
.7162 .02894 L
.71853 .02295 L
.7198 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.14274 .98077 m
.14549 .97808 L
.15246 .97106 L
.15521 .96831 L
.16217 .96134 L
.16492 .95859 L
.17188 .95163 L
.17463 .94888 L
.18159 .94192 L
.18434 .93917 L
.19131 .93221 L
.19406 .92946 L
.20102 .92249 L
.20377 .91974 L
.21073 .91278 L
.21348 .91003 L
.22044 .90307 L
.22319 .90032 L
.23016 .89336 L
.23291 .89061 L
.23987 .88364 L
.24262 .88089 L
.24958 .87393 L
.25233 .87118 L
.25929 .86422 L
.26204 .86147 L
.26901 .85451 L
.27176 .85176 L
.27872 .84479 L
.28147 .84204 L
.28843 .83508 L
.29118 .83233 L
.29814 .82537 L
.30089 .82262 L
.30786 .81566 L
.31061 .81291 L
.31757 .80594 L
.32032 .80319 L
.32728 .79623 L
.33003 .79348 L
.33724 .78652 L
.33974 .78377 L
.34502 .77681 L
.34946 .77063 L
.35208 .76709 L
.35917 .75746 L
.35922 .75738 L
.36625 .74767 L
.36888 .744 L
.37317 .73796 L
Mistroke
.37859 .73026 L
.38 .72824 L
.3867 .71853 L
.38831 .71618 L
.39326 .70882 L
.39802 .70172 L
.39973 .69911 L
.4061 .68939 L
.40773 .68688 L
.41232 .67968 L
.41744 .67163 L
.41848 .66997 L
.42452 .66026 L
.42716 .656 L
.43045 .65054 L
.43635 .64083 L
.43687 .63997 L
.4421 .63112 L
.44658 .62354 L
.4478 .62141 L
.45343 .61169 L
.45629 .60673 L
.45895 .60198 L
.46446 .59227 L
.46601 .58953 L
.46984 .58256 L
.47523 .57284 L
.47572 .57196 L
.48047 .56313 L
.48543 .55401 L
.48574 .55342 L
.49087 .54371 L
.49514 .53568 L
.496 .53399 L
.50105 .52428 L
.50486 .51699 L
.50606 .51457 L
.51102 .50486 L
.51457 .49794 L
.51594 .49514 L
.52081 .48543 L
.52428 .47854 L
.52563 .47572 L
.53042 .46601 L
.53399 .45879 L
.53516 .45629 L
.53986 .44658 L
.54371 .43869 L
.54454 .43687 L
.54915 .42716 L
Mistroke
.55342 .41826 L
.55379 .41744 L
.55829 .40773 L
.56288 .39802 L
.56313 .39749 L
.56729 .38831 L
.57182 .37859 L
.57284 .37639 L
.57617 .36888 L
.58063 .35917 L
.58256 .35496 L
.58494 .34946 L
.58932 .33974 L
.59227 .33321 L
.59361 .33003 L
.59789 .32032 L
.60198 .31115 L
.6022 .31061 L
.60635 .30089 L
.61064 .29118 L
.61169 .28877 L
.61472 .28147 L
.61894 .27176 L
.62141 .26607 L
.62303 .26204 L
.62715 .25233 L
.63112 .24308 L
.6313 .24262 L
.63527 .23291 L
.63939 .22319 L
.64083 .21978 L
.64332 .21348 L
.64737 .20377 L
.65054 .19618 L
.65135 .19406 L
.65526 .18434 L
.65929 .17463 L
.66026 .17229 L
.6631 .16492 L
.66707 .15521 L
.66997 .14811 L
.67093 .14549 L
.67476 .13578 L
.6787 .12607 L
.67968 .12364 L
.68241 .11636 L
.68629 .10664 L
.68939 .09888 L
.69008 .09693 L
.6938 .08722 L
Mistroke
.69766 .07751 L
.69911 .07383 L
.70129 .06779 L
.70507 .05808 L
.70882 .04852 L
.70887 .04837 L
.71242 .03866 L
.7162 .02894 L
.71853 .02295 L
.7198 .01923 L
Mfstroke
.6 g
.22135 .98077 m
.22319 .97856 L
.23106 .97106 L
.23291 .96921 L
.24077 .96134 L
.24262 .9595 L
.25048 .95163 L
.25233 .94978 L
.2602 .94192 L
.26204 .94007 L
.26991 .93221 L
.27176 .93036 L
.27962 .92249 L
.28147 .92065 L
.28933 .91278 L
.29118 .91093 L
.29905 .90307 L
.30089 .90122 L
.30876 .89336 L
.31061 .89151 L
.31847 .88364 L
.32032 .8818 L
.32818 .87393 L
.33003 .87208 L
.33779 .86422 L
.33974 .86237 L
.34946 .85533 L
.35055 .85451 L
.35917 .84703 L
.36169 .84479 L
.36888 .83766 L
.37148 .83508 L
.37859 .82737 L
.38044 .82537 L
.38831 .81626 L
.38883 .81566 L
.39688 .80594 L
.39802 .80443 L
.40455 .79623 L
.40773 .79191 L
.41186 .78652 L
.41744 .77876 L
.41887 .77681 L
.42578 .76709 L
.42716 .76502 L
.43248 .75738 L
.43687 .75071 L
.43893 .74767 L
.4453 .73796 L
.44658 .73587 L
.45154 .72824 L
.45629 .72051 L
.45754 .71853 L
.46358 .70882 L
.46601 .70467 L
.46941 .69911 L
.47514 .68939 L
.47572 .68834 L
.48087 .67968 L
.48543 .67156 L
.48636 .66997 L
.49194 .66026 L
.49514 .65435 L
.4973 .65054 L
.5027 .64083 L
.50486 .63669 L
.50794 .63112 L
.51317 .62141 L
.51457 .61862 L
.51832 .61169 L
.52338 .60198 L
.52428 .60014 L
.52845 .59227 L
.53338 .58256 L
.53399 .58126 L
.53836 .57284 L
.54318 .56313 L
.54371 .562 L
.54807 .55342 L
.5528 .54371 L
.55342 .54235 L
.55759 .53399 L
.56226 .52428 L
.56313 .52234 L
.56694 .51457 L
.57156 .50486 L
.57284 .50196 L
.57613 .49514 L
.58071 .48543 L
.58256 .48122 L
.58517 .47572 L
.58971 .46601 L
.59227 .46013 L
.59406 .45629 L
.59856 .44658 L
.60198 .43869 L
.60282 .43687 L
.60728 .42716 L
.61148 .41744 L
.61169 .41692 L
.61586 .40773 L
.62011 .39802 L
.62141 .39481 L
.62431 .38831 L
.62859 .37859 L
.63112 .37238 L
.63266 .36888 L
.63692 .35917 L
.64083 .34962 L
.6409 .34946 L
.64513 .33974 L
.6492 .33003 L
.65054 .32655 L
.65322 .32032 L
.65734 .31061 L
.66026 .30316 L
.66121 .30089 L
.66533 .29118 L
.66924 .28147 L
.66997 .27946 L
.6732 .27176 L
.6772 .26204 L
.67968 .25546 L
.68097 .25233 L
.68499 .24262 L
.68878 .23291 L
.68939 .23116 L
.69265 .22319 L
.69656 .21348 L
.69911 .20656 L
.70023 .20377 L
.70416 .19406 L
.7079 .18434 L
.70882 .18167 L
.71163 .17463 L
.71548 .16492 L
.71853 .15649 L
.71904 .15521 L
.72288 .14549 L
.72661 .13578 L
.72824 .13103 L
.73018 .12607 L
.73397 .11636 L
.73751 .10664 L
.73796 .10528 L
.74119 .09693 L
.74491 .08722 L
.74767 .07925 L
.74833 .07751 L
.75206 .06779 L
.75568 .05808 L
.75738 .05294 L
.75911 .04837 L
.7628 .03866 L
.76628 .02894 L
.76709 .02636 L
.76978 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.22135 .98077 m
.22319 .97856 L
.23106 .97106 L
.23291 .96921 L
.24077 .96134 L
.24262 .9595 L
.25048 .95163 L
.25233 .94978 L
.2602 .94192 L
.26204 .94007 L
.26991 .93221 L
.27176 .93036 L
.27962 .92249 L
.28147 .92065 L
.28933 .91278 L
.29118 .91093 L
.29905 .90307 L
.30089 .90122 L
.30876 .89336 L
.31061 .89151 L
.31847 .88364 L
.32032 .8818 L
.32818 .87393 L
.33003 .87208 L
.33779 .86422 L
.33974 .86237 L
.34946 .85533 L
.35055 .85451 L
.35917 .84703 L
.36169 .84479 L
.36888 .83766 L
.37148 .83508 L
.37859 .82737 L
.38044 .82537 L
.38831 .81626 L
.38883 .81566 L
.39688 .80594 L
.39802 .80443 L
.40455 .79623 L
.40773 .79191 L
.41186 .78652 L
.41744 .77876 L
.41887 .77681 L
.42578 .76709 L
.42716 .76502 L
.43248 .75738 L
.43687 .75071 L
.43893 .74767 L
.4453 .73796 L
.44658 .73587 L
Mistroke
.45154 .72824 L
.45629 .72051 L
.45754 .71853 L
.46358 .70882 L
.46601 .70467 L
.46941 .69911 L
.47514 .68939 L
.47572 .68834 L
.48087 .67968 L
.48543 .67156 L
.48636 .66997 L
.49194 .66026 L
.49514 .65435 L
.4973 .65054 L
.5027 .64083 L
.50486 .63669 L
.50794 .63112 L
.51317 .62141 L
.51457 .61862 L
.51832 .61169 L
.52338 .60198 L
.52428 .60014 L
.52845 .59227 L
.53338 .58256 L
.53399 .58126 L
.53836 .57284 L
.54318 .56313 L
.54371 .562 L
.54807 .55342 L
.5528 .54371 L
.55342 .54235 L
.55759 .53399 L
.56226 .52428 L
.56313 .52234 L
.56694 .51457 L
.57156 .50486 L
.57284 .50196 L
.57613 .49514 L
.58071 .48543 L
.58256 .48122 L
.58517 .47572 L
.58971 .46601 L
.59227 .46013 L
.59406 .45629 L
.59856 .44658 L
.60198 .43869 L
.60282 .43687 L
.60728 .42716 L
.61148 .41744 L
.61169 .41692 L
Mistroke
.61586 .40773 L
.62011 .39802 L
.62141 .39481 L
.62431 .38831 L
.62859 .37859 L
.63112 .37238 L
.63266 .36888 L
.63692 .35917 L
.64083 .34962 L
.6409 .34946 L
.64513 .33974 L
.6492 .33003 L
.65054 .32655 L
.65322 .32032 L
.65734 .31061 L
.66026 .30316 L
.66121 .30089 L
.66533 .29118 L
.66924 .28147 L
.66997 .27946 L
.6732 .27176 L
.6772 .26204 L
.67968 .25546 L
.68097 .25233 L
.68499 .24262 L
.68878 .23291 L
.68939 .23116 L
.69265 .22319 L
.69656 .21348 L
.69911 .20656 L
.70023 .20377 L
.70416 .19406 L
.7079 .18434 L
.70882 .18167 L
.71163 .17463 L
.71548 .16492 L
.71853 .15649 L
.71904 .15521 L
.72288 .14549 L
.72661 .13578 L
.72824 .13103 L
.73018 .12607 L
.73397 .11636 L
.73751 .10664 L
.73796 .10528 L
.74119 .09693 L
.74491 .08722 L
.74767 .07925 L
.74833 .07751 L
.75206 .06779 L
Mistroke
.75568 .05808 L
.75738 .05294 L
.75911 .04837 L
.7628 .03866 L
.76628 .02894 L
.76709 .02636 L
.76978 .01923 L
Mfstroke
.5 g
.26503 .98077 m
.27176 .97403 L
.27474 .97106 L
.28147 .96433 L
.28445 .96134 L
.29118 .95462 L
.29416 .95163 L
.30089 .9449 L
.30388 .94192 L
.31061 .93519 L
.31359 .93221 L
.32032 .92548 L
.3233 .92249 L
.33003 .91577 L
.33303 .91278 L
.33974 .90605 L
.34278 .90307 L
.34946 .89661 L
.35265 .89336 L
.35917 .88638 L
.36167 .88364 L
.36888 .87544 L
.37018 .87393 L
.37828 .86422 L
.37859 .86383 L
.38605 .85451 L
.38831 .85159 L
.39352 .84479 L
.39802 .83876 L
.40074 .83508 L
.40773 .82537 L
.40773 .82536 L
.41455 .81566 L
.41744 .81143 L
.42119 .80594 L
.42716 .79698 L
.42765 .79623 L
.434 .78652 L
.43687 .78204 L
.44021 .77681 L
.44628 .76709 L
.44658 .76661 L
.45227 .75738 L
.45629 .75072 L
.45813 .74767 L
.46391 .73796 L
.46601 .73438 L
.4696 .72824 L
.47519 .71853 L
.47572 .7176 L
.48072 .70882 L
.48543 .70039 L
.48615 .69911 L
.49154 .68939 L
.49514 .68277 L
.49683 .67968 L
.50208 .66997 L
.50486 .66474 L
.50725 .66026 L
.51237 .65054 L
.51457 .64631 L
.51743 .64083 L
.52244 .63112 L
.52428 .6275 L
.5274 .62141 L
.53231 .61169 L
.53399 .60831 L
.53717 .60198 L
.54198 .59227 L
.54371 .58874 L
.54675 .58256 L
.55148 .57284 L
.55342 .56881 L
.55617 .56313 L
.56082 .55342 L
.56313 .54852 L
.56542 .54371 L
.57001 .53399 L
.57284 .52788 L
.57453 .52428 L
.57905 .51457 L
.58256 .50689 L
.58349 .50486 L
.58795 .49514 L
.59227 .48557 L
.59233 .48543 L
.59673 .47572 L
.60106 .46601 L
.60198 .46391 L
.60538 .45629 L
.60967 .44658 L
.61169 .44192 L
.61391 .43687 L
.61816 .42716 L
.62141 .4196 L
.62234 .41744 L
.62654 .40773 L
.63068 .39802 L
.63112 .39697 L
.63482 .38831 L
.63893 .37859 L
.64083 .37402 L
.643 .36888 L
.64708 .35917 L
.65054 .35076 L
.65109 .34946 L
.65512 .33974 L
.65911 .33003 L
.66026 .32719 L
.66308 .32032 L
.66705 .31061 L
.66997 .30332 L
.67095 .30089 L
.67489 .29118 L
.67877 .28147 L
.67968 .27915 L
.68265 .27176 L
.68652 .26204 L
.68939 .25469 L
.69033 .25233 L
.69417 .24262 L
.69797 .23291 L
.69911 .22993 L
.70175 .22319 L
.70554 .21348 L
.70882 .20489 L
.70925 .20377 L
.71301 .19406 L
.71674 .18434 L
.71853 .17956 L
.72042 .17463 L
.72413 .16492 L
.72778 .15521 L
.72824 .15395 L
.73145 .14549 L
.73511 .13578 L
.73796 .12806 L
.7387 .12607 L
.74235 .11636 L
.74595 .10664 L
.74767 .1019 L
.74951 .09693 L
.75311 .08722 L
.75665 .07751 L
.75738 .07546 L
.7602 .06779 L
.76376 .05808 L
.76709 .04876 L
.76724 .04837 L
.77077 .03866 L
.77428 .02894 L
.77681 .02178 L
.77772 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.26503 .98077 m
.27176 .97403 L
.27474 .97106 L
.28147 .96433 L
.28445 .96134 L
.29118 .95462 L
.29416 .95163 L
.30089 .9449 L
.30388 .94192 L
.31061 .93519 L
.31359 .93221 L
.32032 .92548 L
.3233 .92249 L
.33003 .91577 L
.33303 .91278 L
.33974 .90605 L
.34278 .90307 L
.34946 .89661 L
.35265 .89336 L
.35917 .88638 L
.36167 .88364 L
.36888 .87544 L
.37018 .87393 L
.37828 .86422 L
.37859 .86383 L
.38605 .85451 L
.38831 .85159 L
.39352 .84479 L
.39802 .83876 L
.40074 .83508 L
.40773 .82537 L
.40773 .82536 L
.41455 .81566 L
.41744 .81143 L
.42119 .80594 L
.42716 .79698 L
.42765 .79623 L
.434 .78652 L
.43687 .78204 L
.44021 .77681 L
.44628 .76709 L
.44658 .76661 L
.45227 .75738 L
.45629 .75072 L
.45813 .74767 L
.46391 .73796 L
.46601 .73438 L
.4696 .72824 L
.47519 .71853 L
.47572 .7176 L
Mistroke
.48072 .70882 L
.48543 .70039 L
.48615 .69911 L
.49154 .68939 L
.49514 .68277 L
.49683 .67968 L
.50208 .66997 L
.50486 .66474 L
.50725 .66026 L
.51237 .65054 L
.51457 .64631 L
.51743 .64083 L
.52244 .63112 L
.52428 .6275 L
.5274 .62141 L
.53231 .61169 L
.53399 .60831 L
.53717 .60198 L
.54198 .59227 L
.54371 .58874 L
.54675 .58256 L
.55148 .57284 L
.55342 .56881 L
.55617 .56313 L
.56082 .55342 L
.56313 .54852 L
.56542 .54371 L
.57001 .53399 L
.57284 .52788 L
.57453 .52428 L
.57905 .51457 L
.58256 .50689 L
.58349 .50486 L
.58795 .49514 L
.59227 .48557 L
.59233 .48543 L
.59673 .47572 L
.60106 .46601 L
.60198 .46391 L
.60538 .45629 L
.60967 .44658 L
.61169 .44192 L
.61391 .43687 L
.61816 .42716 L
.62141 .4196 L
.62234 .41744 L
.62654 .40773 L
.63068 .39802 L
.63112 .39697 L
.63482 .38831 L
Mistroke
.63893 .37859 L
.64083 .37402 L
.643 .36888 L
.64708 .35917 L
.65054 .35076 L
.65109 .34946 L
.65512 .33974 L
.65911 .33003 L
.66026 .32719 L
.66308 .32032 L
.66705 .31061 L
.66997 .30332 L
.67095 .30089 L
.67489 .29118 L
.67877 .28147 L
.67968 .27915 L
.68265 .27176 L
.68652 .26204 L
.68939 .25469 L
.69033 .25233 L
.69417 .24262 L
.69797 .23291 L
.69911 .22993 L
.70175 .22319 L
.70554 .21348 L
.70882 .20489 L
.70925 .20377 L
.71301 .19406 L
.71674 .18434 L
.71853 .17956 L
.72042 .17463 L
.72413 .16492 L
.72778 .15521 L
.72824 .15395 L
.73145 .14549 L
.73511 .13578 L
.73796 .12806 L
.7387 .12607 L
.74235 .11636 L
.74595 .10664 L
.74767 .1019 L
.74951 .09693 L
.75311 .08722 L
.75665 .07751 L
.75738 .07546 L
.7602 .06779 L
.76376 .05808 L
.76709 .04876 L
.76724 .04837 L
.77077 .03866 L
Mistroke
.77428 .02894 L
.77681 .02178 L
.77772 .01923 L
Mfstroke
.4 g
.30044 .98077 m
.30089 .98031 L
.31015 .97106 L
.31061 .9706 L
.31986 .96134 L
.32032 .96089 L
.32958 .95163 L
.33003 .95118 L
.33931 .94192 L
.33974 .94146 L
.34817 .93221 L
.34946 .93076 L
.35662 .92249 L
.35917 .91947 L
.36471 .91278 L
.36888 .90761 L
.37249 .90307 L
.37859 .8952 L
.38 .89336 L
.38728 .88364 L
.38831 .88225 L
.39435 .87393 L
.39802 .86877 L
.40122 .86422 L
.40773 .8548 L
.40793 .85451 L
.41449 .84479 L
.41744 .84034 L
.4209 .83508 L
.42716 .82541 L
.42719 .82537 L
.43335 .81566 L
.43687 .81002 L
.43939 .80594 L
.44534 .79623 L
.44658 .79418 L
.45118 .78652 L
.45629 .77791 L
.45694 .77681 L
.46261 .76709 L
.46601 .7612 L
.46819 .75738 L
.47371 .74767 L
.47572 .74409 L
.47914 .73796 L
.48451 .72824 L
.48543 .72656 L
.48981 .71853 L
.49505 .70882 L
.49514 .70864 L
.50022 .69911 L
.50486 .69033 L
.50535 .68939 L
.51041 .67968 L
.51457 .67164 L
.51542 .66997 L
.52038 .66026 L
.52428 .65257 L
.5253 .65054 L
.53016 .64083 L
.53399 .63313 L
.53499 .63112 L
.53976 .62141 L
.54371 .61334 L
.5445 .61169 L
.54919 .60198 L
.55342 .59319 L
.55386 .59227 L
.55847 .58256 L
.56306 .57284 L
.56313 .57269 L
.56759 .56313 L
.57212 .55342 L
.57284 .55185 L
.57658 .54371 L
.58104 .53399 L
.58256 .53067 L
.58544 .52428 L
.58983 .51457 L
.59227 .50915 L
.59418 .50486 L
.59851 .49514 L
.60198 .48731 L
.6028 .48543 L
.60707 .47572 L
.61132 .46601 L
.61169 .46515 L
.61552 .45629 L
.61972 .44658 L
.62141 .44267 L
.62387 .43687 L
.62802 .42716 L
.63112 .41987 L
.63214 .41744 L
.63623 .40773 L
.64031 .39802 L
.64083 .39677 L
.64434 .38831 L
.64838 .37859 L
.65054 .37336 L
.65237 .36888 L
.65636 .35917 L
.66026 .34965 L
.66033 .34946 L
.66426 .33974 L
.6682 .33003 L
.66997 .32563 L
.67208 .32032 L
.67598 .31061 L
.67968 .30133 L
.67985 .30089 L
.68368 .29118 L
.68753 .28147 L
.68939 .27673 L
.69132 .27176 L
.69513 .26204 L
.69892 .25233 L
.69911 .25185 L
.70266 .24262 L
.70642 .23291 L
.70882 .22668 L
.71014 .22319 L
.71385 .21348 L
.71757 .20377 L
.71853 .20123 L
.72122 .19406 L
.72491 .18434 L
.72824 .1755 L
.72856 .17463 L
.73218 .16492 L
.73583 .15521 L
.73796 .1495 L
.73942 .14549 L
.74302 .13578 L
.74662 .12607 L
.74767 .12322 L
.75016 .11636 L
.75373 .10664 L
.75729 .09693 L
.75738 .09668 L
.76079 .08722 L
.76433 .07751 L
.76709 .06986 L
.76782 .06779 L
.7713 .05808 L
.77481 .04837 L
.77681 .04279 L
.77825 .03866 L
.78171 .02894 L
.78518 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.30044 .98077 m
.30089 .98031 L
.31015 .97106 L
.31061 .9706 L
.31986 .96134 L
.32032 .96089 L
.32958 .95163 L
.33003 .95118 L
.33931 .94192 L
.33974 .94146 L
.34817 .93221 L
.34946 .93076 L
.35662 .92249 L
.35917 .91947 L
.36471 .91278 L
.36888 .90761 L
.37249 .90307 L
.37859 .8952 L
.38 .89336 L
.38728 .88364 L
.38831 .88225 L
.39435 .87393 L
.39802 .86877 L
.40122 .86422 L
.40773 .8548 L
.40793 .85451 L
.41449 .84479 L
.41744 .84034 L
.4209 .83508 L
.42716 .82541 L
.42719 .82537 L
.43335 .81566 L
.43687 .81002 L
.43939 .80594 L
.44534 .79623 L
.44658 .79418 L
.45118 .78652 L
.45629 .77791 L
.45694 .77681 L
.46261 .76709 L
.46601 .7612 L
.46819 .75738 L
.47371 .74767 L
.47572 .74409 L
.47914 .73796 L
.48451 .72824 L
.48543 .72656 L
.48981 .71853 L
.49505 .70882 L
.49514 .70864 L
Mistroke
.50022 .69911 L
.50486 .69033 L
.50535 .68939 L
.51041 .67968 L
.51457 .67164 L
.51542 .66997 L
.52038 .66026 L
.52428 .65257 L
.5253 .65054 L
.53016 .64083 L
.53399 .63313 L
.53499 .63112 L
.53976 .62141 L
.54371 .61334 L
.5445 .61169 L
.54919 .60198 L
.55342 .59319 L
.55386 .59227 L
.55847 .58256 L
.56306 .57284 L
.56313 .57269 L
.56759 .56313 L
.57212 .55342 L
.57284 .55185 L
.57658 .54371 L
.58104 .53399 L
.58256 .53067 L
.58544 .52428 L
.58983 .51457 L
.59227 .50915 L
.59418 .50486 L
.59851 .49514 L
.60198 .48731 L
.6028 .48543 L
.60707 .47572 L
.61132 .46601 L
.61169 .46515 L
.61552 .45629 L
.61972 .44658 L
.62141 .44267 L
.62387 .43687 L
.62802 .42716 L
.63112 .41987 L
.63214 .41744 L
.63623 .40773 L
.64031 .39802 L
.64083 .39677 L
.64434 .38831 L
.64838 .37859 L
.65054 .37336 L
Mistroke
.65237 .36888 L
.65636 .35917 L
.66026 .34965 L
.66033 .34946 L
.66426 .33974 L
.6682 .33003 L
.66997 .32563 L
.67208 .32032 L
.67598 .31061 L
.67968 .30133 L
.67985 .30089 L
.68368 .29118 L
.68753 .28147 L
.68939 .27673 L
.69132 .27176 L
.69513 .26204 L
.69892 .25233 L
.69911 .25185 L
.70266 .24262 L
.70642 .23291 L
.70882 .22668 L
.71014 .22319 L
.71385 .21348 L
.71757 .20377 L
.71853 .20123 L
.72122 .19406 L
.72491 .18434 L
.72824 .1755 L
.72856 .17463 L
.73218 .16492 L
.73583 .15521 L
.73796 .1495 L
.73942 .14549 L
.74302 .13578 L
.74662 .12607 L
.74767 .12322 L
.75016 .11636 L
.75373 .10664 L
.75729 .09693 L
.75738 .09668 L
.76079 .08722 L
.76433 .07751 L
.76709 .06986 L
.76782 .06779 L
.7713 .05808 L
.77481 .04837 L
.77681 .04279 L
.77825 .03866 L
.78171 .02894 L
.78518 .01923 L
Mistroke
Mfstroke
.3 g
.34312 .98077 m
.34946 .97206 L
.35018 .97106 L
.35733 .96134 L
.35917 .95882 L
.36439 .95163 L
.36888 .94538 L
.37135 .94192 L
.37821 .93221 L
.37859 .93166 L
.38493 .92249 L
.38831 .91756 L
.39153 .91278 L
.39802 .90312 L
.39805 .90307 L
.40441 .89336 L
.40773 .88825 L
.41067 .88364 L
.41687 .87393 L
.41744 .87303 L
.42291 .86422 L
.42716 .85738 L
.42889 .85451 L
.43479 .84479 L
.43687 .84135 L
.44057 .83508 L
.44633 .82537 L
.44658 .82494 L
.45193 .81566 L
.45629 .80811 L
.45751 .80594 L
.463 .79623 L
.46601 .79091 L
.46841 .78652 L
.4738 .77681 L
.47572 .77334 L
.47907 .76709 L
.48435 .75738 L
.48543 .75539 L
.48949 .74767 L
.49467 .73796 L
.49514 .73707 L
.49969 .72824 L
.50478 .71853 L
.50486 .71838 L
.50969 .70882 L
.51457 .69933 L
.51468 .69911 L
.5195 .68939 L
.52428 .67993 L
.5244 .67968 L
.52914 .66997 L
.53396 .66026 L
.53399 .66018 L
.5386 .65054 L
.54334 .64083 L
.54371 .64008 L
.54791 .63112 L
.55258 .62141 L
.55342 .61965 L
.55707 .61169 L
.56167 .60198 L
.56313 .59887 L
.5661 .59227 L
.57062 .58256 L
.57284 .57777 L
.57501 .57284 L
.57944 .56313 L
.58256 .55634 L
.58381 .55342 L
.58815 .54371 L
.59227 .5346 L
.59252 .53399 L
.59674 .52428 L
.60108 .51457 L
.60198 .51253 L
.60522 .50486 L
.6095 .49514 L
.61169 .49015 L
.61363 .48543 L
.61782 .47572 L
.62141 .46746 L
.62198 .46601 L
.62604 .45629 L
.63021 .44658 L
.63112 .44446 L
.63418 .43687 L
.63829 .42716 L
.64083 .42116 L
.64228 .41744 L
.64628 .40773 L
.65036 .39802 L
.65054 .39757 L
.6542 .38831 L
.65823 .37859 L
.66026 .37367 L
.66208 .36888 L
.66601 .35917 L
.66997 .3495 L
.66998 .34946 L
.67372 .33974 L
.67766 .33003 L
.67968 .32502 L
.68141 .32032 L
.68525 .31061 L
.68914 .30089 L
.68939 .30026 L
.69279 .29118 L
.69663 .28147 L
.69911 .27522 L
.70033 .27176 L
.70405 .26204 L
.70787 .25233 L
.70882 .2499 L
.71144 .24262 L
.71519 .23291 L
.71853 .2243 L
.7189 .22319 L
.72246 .21348 L
.7262 .20377 L
.72824 .19843 L
.72974 .19406 L
.73336 .18434 L
.73707 .17463 L
.73796 .17229 L
.74051 .16492 L
.74415 .15521 L
.74767 .14588 L
.74779 .14549 L
.75119 .13578 L
.75482 .12607 L
.75738 .1192 L
.7583 .11636 L
.76176 .10664 L
.76537 .09693 L
.76709 .09226 L
.76874 .08722 L
.77224 .07751 L
.77581 .06779 L
.77681 .06506 L
.7791 .05808 L
.7826 .04837 L
.78614 .03866 L
.78652 .0376 L
.78937 .02894 L
.79286 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.34312 .98077 m
.34946 .97206 L
.35018 .97106 L
.35733 .96134 L
.35917 .95882 L
.36439 .95163 L
.36888 .94538 L
.37135 .94192 L
.37821 .93221 L
.37859 .93166 L
.38493 .92249 L
.38831 .91756 L
.39153 .91278 L
.39802 .90312 L
.39805 .90307 L
.40441 .89336 L
.40773 .88825 L
.41067 .88364 L
.41687 .87393 L
.41744 .87303 L
.42291 .86422 L
.42716 .85738 L
.42889 .85451 L
.43479 .84479 L
.43687 .84135 L
.44057 .83508 L
.44633 .82537 L
.44658 .82494 L
.45193 .81566 L
.45629 .80811 L
.45751 .80594 L
.463 .79623 L
.46601 .79091 L
.46841 .78652 L
.4738 .77681 L
.47572 .77334 L
.47907 .76709 L
.48435 .75738 L
.48543 .75539 L
.48949 .74767 L
.49467 .73796 L
.49514 .73707 L
.49969 .72824 L
.50478 .71853 L
.50486 .71838 L
.50969 .70882 L
.51457 .69933 L
.51468 .69911 L
.5195 .68939 L
.52428 .67993 L
Mistroke
.5244 .67968 L
.52914 .66997 L
.53396 .66026 L
.53399 .66018 L
.5386 .65054 L
.54334 .64083 L
.54371 .64008 L
.54791 .63112 L
.55258 .62141 L
.55342 .61965 L
.55707 .61169 L
.56167 .60198 L
.56313 .59887 L
.5661 .59227 L
.57062 .58256 L
.57284 .57777 L
.57501 .57284 L
.57944 .56313 L
.58256 .55634 L
.58381 .55342 L
.58815 .54371 L
.59227 .5346 L
.59252 .53399 L
.59674 .52428 L
.60108 .51457 L
.60198 .51253 L
.60522 .50486 L
.6095 .49514 L
.61169 .49015 L
.61363 .48543 L
.61782 .47572 L
.62141 .46746 L
.62198 .46601 L
.62604 .45629 L
.63021 .44658 L
.63112 .44446 L
.63418 .43687 L
.63829 .42716 L
.64083 .42116 L
.64228 .41744 L
.64628 .40773 L
.65036 .39802 L
.65054 .39757 L
.6542 .38831 L
.65823 .37859 L
.66026 .37367 L
.66208 .36888 L
.66601 .35917 L
.66997 .3495 L
.66998 .34946 L
Mistroke
.67372 .33974 L
.67766 .33003 L
.67968 .32502 L
.68141 .32032 L
.68525 .31061 L
.68914 .30089 L
.68939 .30026 L
.69279 .29118 L
.69663 .28147 L
.69911 .27522 L
.70033 .27176 L
.70405 .26204 L
.70787 .25233 L
.70882 .2499 L
.71144 .24262 L
.71519 .23291 L
.71853 .2243 L
.7189 .22319 L
.72246 .21348 L
.7262 .20377 L
.72824 .19843 L
.72974 .19406 L
.73336 .18434 L
.73707 .17463 L
.73796 .17229 L
.74051 .16492 L
.74415 .15521 L
.74767 .14588 L
.74779 .14549 L
.75119 .13578 L
.75482 .12607 L
.75738 .1192 L
.7583 .11636 L
.76176 .10664 L
.76537 .09693 L
.76709 .09226 L
.76874 .08722 L
.77224 .07751 L
.77581 .06779 L
.77681 .06506 L
.7791 .05808 L
.7826 .04837 L
.78614 .03866 L
.78652 .0376 L
.78937 .02894 L
.79286 .01923 L
Mfstroke
.4 g
.41701 .98077 m
.41744 .9801 L
.42402 .97106 L
.42716 .9664 L
.4307 .96134 L
.43687 .95208 L
.43717 .95163 L
.44366 .94192 L
.44658 .93725 L
.44987 .93221 L
.45594 .92249 L
.45629 .92189 L
.46202 .91278 L
.46601 .90605 L
.46784 .90307 L
.47367 .89336 L
.47572 .88973 L
.47935 .88364 L
.4849 .87393 L
.48543 .87295 L
.49049 .86422 L
.49514 .85572 L
.49583 .85451 L
.5013 .84479 L
.50486 .83808 L
.50651 .83508 L
.51182 .82537 L
.51457 .82001 L
.51692 .81566 L
.52208 .80594 L
.52428 .80153 L
.52709 .79623 L
.53212 .78652 L
.53399 .78265 L
.53703 .77681 L
.54195 .76709 L
.54371 .76339 L
.54676 .75738 L
.55159 .74767 L
.55342 .74374 L
.55631 .73796 L
.56107 .72824 L
.56313 .72372 L
.56568 .71853 L
.57037 .70882 L
.57284 .70334 L
.57489 .69911 L
.57952 .68939 L
.58256 .6826 L
.58394 .67968 L
.58853 .66997 L
.59227 .66151 L
.59285 .66026 L
.59738 .65054 L
.60167 .64083 L
.60198 .64007 L
.6061 .63112 L
.61042 .62141 L
.61169 .6183 L
.61469 .61169 L
.61902 .60198 L
.62141 .5962 L
.62316 .59227 L
.62748 .58256 L
.63112 .57376 L
.63152 .57284 L
.6358 .56313 L
.6399 .55342 L
.64083 .55101 L
.64401 .54371 L
.64816 .53399 L
.65054 .52793 L
.65211 .52428 L
.65626 .51457 L
.66014 .50486 L
.66026 .50454 L
.66424 .49514 L
.66824 .48543 L
.66997 .48085 L
.67212 .47572 L
.67616 .46601 L
.67968 .45684 L
.67991 .45629 L
.68393 .44658 L
.68782 .43687 L
.68939 .43255 L
.6916 .42716 L
.69555 .41744 L
.69911 .40794 L
.69919 .40773 L
.70312 .39802 L
.70695 .38831 L
.70882 .38306 L
.7106 .37859 L
.71447 .36888 L
.7181 .35917 L
.71853 .35788 L
.72186 .34946 L
.72565 .33974 L
.72824 .33241 L
.72917 .33003 L
.73297 .32032 L
.73663 .31061 L
.73796 .30666 L
.74019 .30089 L
.74394 .29118 L
.7474 .28147 L
.74767 .28063 L
.75107 .27176 L
.75475 .26204 L
.75738 .25433 L
.75814 .25233 L
.76183 .24262 L
.76541 .23291 L
.76709 .22775 L
.7688 .22319 L
.77246 .21348 L
.77591 .20377 L
.77681 .2009 L
.77935 .19406 L
.78296 .18434 L
.78627 .17463 L
.78652 .17378 L
.78979 .16492 L
.79334 .15521 L
.79623 .1464 L
.79656 .14549 L
.80012 .13578 L
.80361 .12607 L
.80594 .11876 L
.80681 .11636 L
.81034 .10664 L
.81377 .09693 L
.81566 .09086 L
.81696 .08722 L
.82046 .07751 L
.82383 .06779 L
.82537 .0627 L
.82701 .05808 L
.83048 .04837 L
.83379 .03866 L
.83508 .03428 L
.83696 .02894 L
.84041 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.41701 .98077 m
.41744 .9801 L
.42402 .97106 L
.42716 .9664 L
.4307 .96134 L
.43687 .95208 L
.43717 .95163 L
.44366 .94192 L
.44658 .93725 L
.44987 .93221 L
.45594 .92249 L
.45629 .92189 L
.46202 .91278 L
.46601 .90605 L
.46784 .90307 L
.47367 .89336 L
.47572 .88973 L
.47935 .88364 L
.4849 .87393 L
.48543 .87295 L
.49049 .86422 L
.49514 .85572 L
.49583 .85451 L
.5013 .84479 L
.50486 .83808 L
.50651 .83508 L
.51182 .82537 L
.51457 .82001 L
.51692 .81566 L
.52208 .80594 L
.52428 .80153 L
.52709 .79623 L
.53212 .78652 L
.53399 .78265 L
.53703 .77681 L
.54195 .76709 L
.54371 .76339 L
.54676 .75738 L
.55159 .74767 L
.55342 .74374 L
.55631 .73796 L
.56107 .72824 L
.56313 .72372 L
.56568 .71853 L
.57037 .70882 L
.57284 .70334 L
.57489 .69911 L
.57952 .68939 L
.58256 .6826 L
.58394 .67968 L
Mistroke
.58853 .66997 L
.59227 .66151 L
.59285 .66026 L
.59738 .65054 L
.60167 .64083 L
.60198 .64007 L
.6061 .63112 L
.61042 .62141 L
.61169 .6183 L
.61469 .61169 L
.61902 .60198 L
.62141 .5962 L
.62316 .59227 L
.62748 .58256 L
.63112 .57376 L
.63152 .57284 L
.6358 .56313 L
.6399 .55342 L
.64083 .55101 L
.64401 .54371 L
.64816 .53399 L
.65054 .52793 L
.65211 .52428 L
.65626 .51457 L
.66014 .50486 L
.66026 .50454 L
.66424 .49514 L
.66824 .48543 L
.66997 .48085 L
.67212 .47572 L
.67616 .46601 L
.67968 .45684 L
.67991 .45629 L
.68393 .44658 L
.68782 .43687 L
.68939 .43255 L
.6916 .42716 L
.69555 .41744 L
.69911 .40794 L
.69919 .40773 L
.70312 .39802 L
.70695 .38831 L
.70882 .38306 L
.7106 .37859 L
.71447 .36888 L
.7181 .35917 L
.71853 .35788 L
.72186 .34946 L
.72565 .33974 L
.72824 .33241 L
Mistroke
.72917 .33003 L
.73297 .32032 L
.73663 .31061 L
.73796 .30666 L
.74019 .30089 L
.74394 .29118 L
.7474 .28147 L
.74767 .28063 L
.75107 .27176 L
.75475 .26204 L
.75738 .25433 L
.75814 .25233 L
.76183 .24262 L
.76541 .23291 L
.76709 .22775 L
.7688 .22319 L
.77246 .21348 L
.77591 .20377 L
.77681 .2009 L
.77935 .19406 L
.78296 .18434 L
.78627 .17463 L
.78652 .17378 L
.78979 .16492 L
.79334 .15521 L
.79623 .1464 L
.79656 .14549 L
.80012 .13578 L
.80361 .12607 L
.80594 .11876 L
.80681 .11636 L
.81034 .10664 L
.81377 .09693 L
.81566 .09086 L
.81696 .08722 L
.82046 .07751 L
.82383 .06779 L
.82537 .0627 L
.82701 .05808 L
.83048 .04837 L
.83379 .03866 L
.83508 .03428 L
.83696 .02894 L
.84041 .01923 L
Mfstroke
.5 g
.43857 .98077 m
.44469 .97106 L
.44658 .968 L
.45069 .96134 L
.45629 .9521 L
.45658 .95163 L
.46239 .94192 L
.46601 .93576 L
.46809 .93221 L
.47372 .92249 L
.47572 .91898 L
.47926 .91278 L
.48471 .90307 L
.48543 .90177 L
.49011 .89336 L
.49514 .88415 L
.49542 .88364 L
.50069 .87393 L
.50486 .86612 L
.50587 .86422 L
.51102 .85451 L
.51457 .8477 L
.51609 .84479 L
.52112 .83508 L
.52428 .82888 L
.52608 .82537 L
.53101 .81566 L
.53399 .80969 L
.53587 .80594 L
.54071 .79623 L
.54371 .79012 L
.54548 .78652 L
.55024 .77681 L
.55342 .77019 L
.55492 .76709 L
.55959 .75738 L
.56313 .74991 L
.5642 .74767 L
.5688 .73796 L
.57284 .72926 L
.57332 .72824 L
.57785 .71853 L
.58231 .70882 L
.58256 .70828 L
.58677 .69911 L
.59118 .68939 L
.59227 .68695 L
.59556 .67968 L
.59992 .66997 L
.60198 .66529 L
.60423 .66026 L
.60854 .65054 L
.61169 .6433 L
.61278 .64083 L
.61704 .63112 L
.62123 .62141 L
.62141 .62099 L
.62543 .61169 L
.62959 .60198 L
.63112 .59835 L
.63372 .59227 L
.63785 .58256 L
.64083 .5754 L
.64191 .57284 L
.646 .56313 L
.65002 .55342 L
.65054 .55214 L
.65405 .54371 L
.65806 .53399 L
.66026 .52858 L
.66202 .52428 L
.666 .51457 L
.66991 .50486 L
.66997 .50471 L
.67385 .49514 L
.67775 .48543 L
.67968 .48054 L
.68161 .47572 L
.6855 .46601 L
.68931 .45629 L
.68939 .45607 L
.69315 .44658 L
.69697 .43687 L
.69911 .43132 L
.70074 .42716 L
.70453 .41744 L
.70827 .40773 L
.70882 .40627 L
.71202 .39802 L
.71576 .38831 L
.71853 .38095 L
.71943 .37859 L
.72315 .36888 L
.72683 .35917 L
.72824 .35534 L
.73047 .34946 L
.73415 .33974 L
.73775 .33003 L
.73796 .32945 L
.74138 .32032 L
.745 .31061 L
.74767 .30328 L
.74855 .30089 L
.75216 .29118 L
.75573 .28147 L
.75738 .27685 L
.75925 .27176 L
.76282 .26204 L
.76632 .25233 L
.76709 .25014 L
.76983 .24262 L
.77336 .23291 L
.7768 .22319 L
.77681 .22317 L
.7803 .21348 L
.78378 .20377 L
.78652 .19593 L
.78719 .19406 L
.79065 .18434 L
.79409 .17463 L
.79623 .16843 L
.79747 .16492 L
.80091 .15521 L
.8043 .14549 L
.80594 .14067 L
.80765 .13578 L
.81106 .12607 L
.81442 .11636 L
.81566 .11266 L
.81774 .10664 L
.82112 .09693 L
.82443 .08722 L
.82537 .08439 L
.82773 .07751 L
.83108 .06779 L
.83436 .05808 L
.83508 .05587 L
.83764 .04837 L
.84095 .03866 L
.84419 .02894 L
.84479 .02709 L
.84745 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.43857 .98077 m
.44469 .97106 L
.44658 .968 L
.45069 .96134 L
.45629 .9521 L
.45658 .95163 L
.46239 .94192 L
.46601 .93576 L
.46809 .93221 L
.47372 .92249 L
.47572 .91898 L
.47926 .91278 L
.48471 .90307 L
.48543 .90177 L
.49011 .89336 L
.49514 .88415 L
.49542 .88364 L
.50069 .87393 L
.50486 .86612 L
.50587 .86422 L
.51102 .85451 L
.51457 .8477 L
.51609 .84479 L
.52112 .83508 L
.52428 .82888 L
.52608 .82537 L
.53101 .81566 L
.53399 .80969 L
.53587 .80594 L
.54071 .79623 L
.54371 .79012 L
.54548 .78652 L
.55024 .77681 L
.55342 .77019 L
.55492 .76709 L
.55959 .75738 L
.56313 .74991 L
.5642 .74767 L
.5688 .73796 L
.57284 .72926 L
.57332 .72824 L
.57785 .71853 L
.58231 .70882 L
.58256 .70828 L
.58677 .69911 L
.59118 .68939 L
.59227 .68695 L
.59556 .67968 L
.59992 .66997 L
.60198 .66529 L
Mistroke
.60423 .66026 L
.60854 .65054 L
.61169 .6433 L
.61278 .64083 L
.61704 .63112 L
.62123 .62141 L
.62141 .62099 L
.62543 .61169 L
.62959 .60198 L
.63112 .59835 L
.63372 .59227 L
.63785 .58256 L
.64083 .5754 L
.64191 .57284 L
.646 .56313 L
.65002 .55342 L
.65054 .55214 L
.65405 .54371 L
.65806 .53399 L
.66026 .52858 L
.66202 .52428 L
.666 .51457 L
.66991 .50486 L
.66997 .50471 L
.67385 .49514 L
.67775 .48543 L
.67968 .48054 L
.68161 .47572 L
.6855 .46601 L
.68931 .45629 L
.68939 .45607 L
.69315 .44658 L
.69697 .43687 L
.69911 .43132 L
.70074 .42716 L
.70453 .41744 L
.70827 .40773 L
.70882 .40627 L
.71202 .39802 L
.71576 .38831 L
.71853 .38095 L
.71943 .37859 L
.72315 .36888 L
.72683 .35917 L
.72824 .35534 L
.73047 .34946 L
.73415 .33974 L
.73775 .33003 L
.73796 .32945 L
.74138 .32032 L
Mistroke
.745 .31061 L
.74767 .30328 L
.74855 .30089 L
.75216 .29118 L
.75573 .28147 L
.75738 .27685 L
.75925 .27176 L
.76282 .26204 L
.76632 .25233 L
.76709 .25014 L
.76983 .24262 L
.77336 .23291 L
.7768 .22319 L
.77681 .22317 L
.7803 .21348 L
.78378 .20377 L
.78652 .19593 L
.78719 .19406 L
.79065 .18434 L
.79409 .17463 L
.79623 .16843 L
.79747 .16492 L
.80091 .15521 L
.8043 .14549 L
.80594 .14067 L
.80765 .13578 L
.81106 .12607 L
.81442 .11636 L
.81566 .11266 L
.81774 .10664 L
.82112 .09693 L
.82443 .08722 L
.82537 .08439 L
.82773 .07751 L
.83108 .06779 L
.83436 .05808 L
.83508 .05587 L
.83764 .04837 L
.84095 .03866 L
.84419 .02894 L
.84479 .02709 L
.84745 .01923 L
Mfstroke
.6 g
.45542 .98077 m
.45629 .97929 L
.46111 .97106 L
.46601 .96259 L
.46672 .96134 L
.47225 .95163 L
.47572 .94547 L
.4777 .94192 L
.48309 .93221 L
.48543 .92795 L
.4884 .92249 L
.49366 .91278 L
.49514 .91003 L
.49885 .90307 L
.50399 .89336 L
.50486 .89172 L
.50907 .88364 L
.5141 .87393 L
.51457 .87302 L
.51907 .86422 L
.524 .85451 L
.52428 .85396 L
.52887 .84479 L
.53372 .83508 L
.53399 .83452 L
.5385 .82537 L
.54325 .81566 L
.54371 .81472 L
.54795 .80594 L
.55263 .79623 L
.55342 .79457 L
.55724 .78652 L
.56185 .77681 L
.56313 .77407 L
.56639 .76709 L
.57092 .75738 L
.57284 .75323 L
.5754 .74767 L
.57986 .73796 L
.58256 .73205 L
.58427 .72824 L
.58867 .71853 L
.59227 .71054 L
.59303 .70882 L
.59736 .69911 L
.60167 .68939 L
.60198 .6887 L
.60593 .67968 L
.6102 .66997 L
.61169 .66653 L
.6144 .66026 L
.61861 .65054 L
.62141 .64405 L
.62277 .64083 L
.62692 .63112 L
.63106 .62141 L
.63112 .62126 L
.63514 .61169 L
.63923 .60198 L
.64083 .59815 L
.64327 .59227 L
.64731 .58256 L
.65054 .57474 L
.65132 .57284 L
.6553 .56313 L
.65928 .55342 L
.66026 .55103 L
.66321 .54371 L
.66715 .53399 L
.66997 .52702 L
.67105 .52428 L
.67494 .51457 L
.67883 .50486 L
.67968 .50271 L
.68266 .49514 L
.68651 .48543 L
.68939 .47812 L
.69032 .47572 L
.69412 .46601 L
.69792 .45629 L
.69911 .45323 L
.70166 .44658 L
.70542 .43687 L
.70882 .42806 L
.70916 .42716 L
.71286 .41744 L
.71658 .40773 L
.71853 .40261 L
.72025 .39802 L
.72393 .38831 L
.7276 .37859 L
.72824 .37689 L
.73122 .36888 L
.73486 .35917 L
.73796 .35088 L
.73848 .34946 L
.74206 .33974 L
.74567 .33003 L
.74767 .32461 L
.74922 .32032 L
.75278 .31061 L
.75635 .30089 L
.75738 .29806 L
.75985 .29118 L
.76339 .28147 L
.76691 .27176 L
.76709 .27125 L
.77037 .26204 L
.77388 .25233 L
.77681 .24417 L
.77735 .24262 L
.78079 .23291 L
.78426 .22319 L
.78652 .21683 L
.78768 .21348 L
.7911 .20377 L
.79454 .19406 L
.79623 .18923 L
.79791 .18434 L
.80131 .17463 L
.80471 .16492 L
.80594 .16138 L
.80805 .15521 L
.81142 .14549 L
.81479 .13578 L
.81566 .13327 L
.81809 .12607 L
.82144 .11636 L
.82478 .10664 L
.82537 .10491 L
.82804 .09693 L
.83136 .08722 L
.83467 .07751 L
.83508 .07629 L
.83791 .06779 L
.8412 .05808 L
.84448 .04837 L
.84479 .04743 L
.84769 .03866 L
.85095 .02894 L
.85421 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.45542 .98077 m
.45629 .97929 L
.46111 .97106 L
.46601 .96259 L
.46672 .96134 L
.47225 .95163 L
.47572 .94547 L
.4777 .94192 L
.48309 .93221 L
.48543 .92795 L
.4884 .92249 L
.49366 .91278 L
.49514 .91003 L
.49885 .90307 L
.50399 .89336 L
.50486 .89172 L
.50907 .88364 L
.5141 .87393 L
.51457 .87302 L
.51907 .86422 L
.524 .85451 L
.52428 .85396 L
.52887 .84479 L
.53372 .83508 L
.53399 .83452 L
.5385 .82537 L
.54325 .81566 L
.54371 .81472 L
.54795 .80594 L
.55263 .79623 L
.55342 .79457 L
.55724 .78652 L
.56185 .77681 L
.56313 .77407 L
.56639 .76709 L
.57092 .75738 L
.57284 .75323 L
.5754 .74767 L
.57986 .73796 L
.58256 .73205 L
.58427 .72824 L
.58867 .71853 L
.59227 .71054 L
.59303 .70882 L
.59736 .69911 L
.60167 .68939 L
.60198 .6887 L
.60593 .67968 L
.6102 .66997 L
.61169 .66653 L
Mistroke
.6144 .66026 L
.61861 .65054 L
.62141 .64405 L
.62277 .64083 L
.62692 .63112 L
.63106 .62141 L
.63112 .62126 L
.63514 .61169 L
.63923 .60198 L
.64083 .59815 L
.64327 .59227 L
.64731 .58256 L
.65054 .57474 L
.65132 .57284 L
.6553 .56313 L
.65928 .55342 L
.66026 .55103 L
.66321 .54371 L
.66715 .53399 L
.66997 .52702 L
.67105 .52428 L
.67494 .51457 L
.67883 .50486 L
.67968 .50271 L
.68266 .49514 L
.68651 .48543 L
.68939 .47812 L
.69032 .47572 L
.69412 .46601 L
.69792 .45629 L
.69911 .45323 L
.70166 .44658 L
.70542 .43687 L
.70882 .42806 L
.70916 .42716 L
.71286 .41744 L
.71658 .40773 L
.71853 .40261 L
.72025 .39802 L
.72393 .38831 L
.7276 .37859 L
.72824 .37689 L
.73122 .36888 L
.73486 .35917 L
.73796 .35088 L
.73848 .34946 L
.74206 .33974 L
.74567 .33003 L
.74767 .32461 L
.74922 .32032 L
Mistroke
.75278 .31061 L
.75635 .30089 L
.75738 .29806 L
.75985 .29118 L
.76339 .28147 L
.76691 .27176 L
.76709 .27125 L
.77037 .26204 L
.77388 .25233 L
.77681 .24417 L
.77735 .24262 L
.78079 .23291 L
.78426 .22319 L
.78652 .21683 L
.78768 .21348 L
.7911 .20377 L
.79454 .19406 L
.79623 .18923 L
.79791 .18434 L
.80131 .17463 L
.80471 .16492 L
.80594 .16138 L
.80805 .15521 L
.81142 .14549 L
.81479 .13578 L
.81566 .13327 L
.81809 .12607 L
.82144 .11636 L
.82478 .10664 L
.82537 .10491 L
.82804 .09693 L
.83136 .08722 L
.83467 .07751 L
.83508 .07629 L
.83791 .06779 L
.8412 .05808 L
.84448 .04837 L
.84479 .04743 L
.84769 .03866 L
.85095 .02894 L
.85421 .01923 L
Mfstroke
.7 g
.47237 .98077 m
.47572 .97474 L
.47768 .97106 L
.48295 .96134 L
.48543 .95677 L
.48812 .95163 L
.4933 .94192 L
.49514 .93845 L
.49835 .93221 L
.50343 .92249 L
.50486 .91976 L
.50837 .91278 L
.51336 .90307 L
.51457 .90071 L
.5182 .89336 L
.52311 .88364 L
.52428 .88131 L
.52786 .87393 L
.53268 .86422 L
.53399 .86156 L
.53735 .85451 L
.54209 .84479 L
.54371 .84146 L
.54668 .83508 L
.55134 .82537 L
.55342 .82103 L
.55587 .81566 L
.56045 .80594 L
.56313 .80025 L
.56492 .79623 L
.56942 .78652 L
.57284 .77915 L
.57386 .77681 L
.57826 .76709 L
.58256 .75773 L
.5827 .75738 L
.58698 .74767 L
.59138 .73796 L
.59227 .73598 L
.59559 .72824 L
.59992 .71853 L
.60198 .71391 L
.60411 .70882 L
.60836 .69911 L
.61169 .69153 L
.61256 .68939 L
.61669 .67968 L
.62092 .66997 L
.62141 .66885 L
.62494 .66026 L
.62911 .65054 L
.63112 .64585 L
.63312 .64083 L
.6372 .63112 L
.64083 .62255 L
.64127 .62141 L
.6452 .61169 L
.64928 .60198 L
.65054 .59895 L
.65315 .59227 L
.65715 .58256 L
.66026 .57506 L
.66108 .57284 L
.66495 .56313 L
.66893 .55342 L
.66997 .55088 L
.67269 .54371 L
.67661 .53399 L
.67968 .5264 L
.68045 .52428 L
.68422 .51457 L
.68811 .50486 L
.68939 .50164 L
.69179 .49514 L
.69561 .48543 L
.69911 .47661 L
.69941 .47572 L
.70305 .46601 L
.70686 .45629 L
.70882 .45128 L
.71048 .44658 L
.71419 .43687 L
.71797 .42716 L
.71853 .42569 L
.72148 .41744 L
.7252 .40773 L
.72824 .39981 L
.72884 .39802 L
.73238 .38831 L
.73609 .37859 L
.73796 .37367 L
.73958 .36888 L
.74318 .35917 L
.74685 .34946 L
.74767 .34726 L
.75025 .33974 L
.75385 .33003 L
.75738 .32059 L
.75746 .32032 L
.76082 .31061 L
.76441 .30089 L
.76709 .29364 L
.76787 .29118 L
.77129 .28147 L
.77486 .27176 L
.77681 .26644 L
.77821 .26204 L
.78166 .25233 L
.7852 .24262 L
.78652 .23898 L
.78847 .23291 L
.79193 .22319 L
.79544 .21348 L
.79623 .21126 L
.79865 .20377 L
.80209 .19406 L
.80557 .18434 L
.80594 .1833 L
.80873 .17463 L
.81216 .16492 L
.81561 .15521 L
.81566 .15507 L
.81873 .14549 L
.82214 .13578 L
.82537 .1266 L
.82552 .12607 L
.82863 .11636 L
.83203 .10664 L
.83508 .09788 L
.83535 .09693 L
.83845 .08722 L
.84182 .07751 L
.84479 .06891 L
.8451 .06779 L
.84819 .05808 L
.85153 .04837 L
.85451 .0397 L
.85479 .03866 L
.85784 .02894 L
.86116 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.47237 .98077 m
.47572 .97474 L
.47768 .97106 L
.48295 .96134 L
.48543 .95677 L
.48812 .95163 L
.4933 .94192 L
.49514 .93845 L
.49835 .93221 L
.50343 .92249 L
.50486 .91976 L
.50837 .91278 L
.51336 .90307 L
.51457 .90071 L
.5182 .89336 L
.52311 .88364 L
.52428 .88131 L
.52786 .87393 L
.53268 .86422 L
.53399 .86156 L
.53735 .85451 L
.54209 .84479 L
.54371 .84146 L
.54668 .83508 L
.55134 .82537 L
.55342 .82103 L
.55587 .81566 L
.56045 .80594 L
.56313 .80025 L
.56492 .79623 L
.56942 .78652 L
.57284 .77915 L
.57386 .77681 L
.57826 .76709 L
.58256 .75773 L
.5827 .75738 L
.58698 .74767 L
.59138 .73796 L
.59227 .73598 L
.59559 .72824 L
.59992 .71853 L
.60198 .71391 L
.60411 .70882 L
.60836 .69911 L
.61169 .69153 L
.61256 .68939 L
.61669 .67968 L
.62092 .66997 L
.62141 .66885 L
.62494 .66026 L
Mistroke
.62911 .65054 L
.63112 .64585 L
.63312 .64083 L
.6372 .63112 L
.64083 .62255 L
.64127 .62141 L
.6452 .61169 L
.64928 .60198 L
.65054 .59895 L
.65315 .59227 L
.65715 .58256 L
.66026 .57506 L
.66108 .57284 L
.66495 .56313 L
.66893 .55342 L
.66997 .55088 L
.67269 .54371 L
.67661 .53399 L
.67968 .5264 L
.68045 .52428 L
.68422 .51457 L
.68811 .50486 L
.68939 .50164 L
.69179 .49514 L
.69561 .48543 L
.69911 .47661 L
.69941 .47572 L
.70305 .46601 L
.70686 .45629 L
.70882 .45128 L
.71048 .44658 L
.71419 .43687 L
.71797 .42716 L
.71853 .42569 L
.72148 .41744 L
.7252 .40773 L
.72824 .39981 L
.72884 .39802 L
.73238 .38831 L
.73609 .37859 L
.73796 .37367 L
.73958 .36888 L
.74318 .35917 L
.74685 .34946 L
.74767 .34726 L
.75025 .33974 L
.75385 .33003 L
.75738 .32059 L
.75746 .32032 L
.76082 .31061 L
Mistroke
.76441 .30089 L
.76709 .29364 L
.76787 .29118 L
.77129 .28147 L
.77486 .27176 L
.77681 .26644 L
.77821 .26204 L
.78166 .25233 L
.7852 .24262 L
.78652 .23898 L
.78847 .23291 L
.79193 .22319 L
.79544 .21348 L
.79623 .21126 L
.79865 .20377 L
.80209 .19406 L
.80557 .18434 L
.80594 .1833 L
.80873 .17463 L
.81216 .16492 L
.81561 .15521 L
.81566 .15507 L
.81873 .14549 L
.82214 .13578 L
.82537 .1266 L
.82552 .12607 L
.82863 .11636 L
.83203 .10664 L
.83508 .09788 L
.83535 .09693 L
.83845 .08722 L
.84182 .07751 L
.84479 .06891 L
.8451 .06779 L
.84819 .05808 L
.85153 .04837 L
.85451 .0397 L
.85479 .03866 L
.85784 .02894 L
.86116 .01923 L
Mfstroke
.8 g
.50486 .56856 m
.51317 .57284 L
.50668 .58256 L
.50486 .58513 L
.49949 .58256 L
.50313 .57284 L
F
0 g
.50486 .56856 m
.51317 .57284 L
.50668 .58256 L
.50486 .58513 L
.49949 .58256 L
.50313 .57284 L
.50486 .56856 L
s
.2 g
.68135 .01923 m
.67968 .02237 L
.67699 .02894 L
.67424 .03866 L
.66997 .04607 L
.66897 .04837 L
.66491 .05808 L
.66102 .06779 L
.66026 .06925 L
.65674 .07751 L
.65341 .08722 L
.65054 .09222 L
.64847 .09693 L
.64429 .10664 L
.64083 .11477 L
.6401 .11636 L
.63585 .12607 L
.63175 .13578 L
.63112 .13692 L
.62729 .14549 L
.6236 .15521 L
.62141 .15883 L
.6186 .16492 L
.61421 .17463 L
.61169 .18035 L
.60978 .18434 L
.60531 .19406 L
.60198 .20144 L
.60081 .20377 L
.59625 .21348 L
.59227 .22209 L
.59168 .22319 L
.58702 .23291 L
.58256 .24228 L
.58236 .24262 L
.5776 .25233 L
.57284 .26204 L
.57284 .26204 L
.56797 .27176 L
.56313 .28142 L
.56309 .28147 L
.5581 .29118 L
.55342 .3005 L
.55308 .30089 L
.54794 .31061 L
.54371 .31926 L
.54275 .32032 L
.53743 .33003 L
.53399 .33739 L
.53203 .33974 L
.52647 .34946 L
.52428 .35428 L
.52074 .35917 L
.51481 .36888 L
.51457 .3694 L
.50845 .37859 L
.50486 .38374 L
.5004 .37859 L
.50416 .36888 L
.50486 .36717 L
.50824 .35917 L
.51242 .34946 L
.51457 .34452 L
.51669 .33974 L
.52101 .33003 L
.52428 .32267 L
.52534 .32032 L
.52971 .31061 L
.53399 .30101 L
.53405 .30089 L
.53842 .29118 L
.54221 .28147 L
.54371 .27915 L
.54712 .27176 L
.55145 .26204 L
.55342 .25722 L
.55577 .25233 L
.56007 .24262 L
.56313 .23529 L
.56435 .23291 L
.56863 .22319 L
.57284 .21352 L
.57287 .21348 L
.57712 .20377 L
.58088 .19406 L
.58256 .19107 L
.58553 .18434 L
.58855 .17463 L
.59227 .16841 L
.59386 .16492 L
.598 .15521 L
.60198 .14576 L
.60211 .14549 L
.60623 .13578 L
.60988 .12607 L
.61169 .12262 L
.61437 .11636 L
.61723 .10664 L
.62141 .09926 L
.62243 .09693 L
.62645 .08722 L
.63026 .07751 L
.63112 .07576 L
.63441 .06779 L
.63756 .05808 L
.64083 .05184 L
.64229 .04837 L
.64425 .03866 L
.65001 .02894 L
.65054 .02793 L
.654 .01923 L
F
0 g
.68135 .01923 m
.67968 .02237 L
.67699 .02894 L
.67424 .03866 L
.66997 .04607 L
.66897 .04837 L
.66491 .05808 L
.66102 .06779 L
.66026 .06925 L
.65674 .07751 L
.65341 .08722 L
.65054 .09222 L
.64847 .09693 L
.64429 .10664 L
.64083 .11477 L
.6401 .11636 L
.63585 .12607 L
.63175 .13578 L
.63112 .13692 L
.62729 .14549 L
.6236 .15521 L
.62141 .15883 L
.6186 .16492 L
.61421 .17463 L
.61169 .18035 L
.60978 .18434 L
.60531 .19406 L
.60198 .20144 L
.60081 .20377 L
.59625 .21348 L
.59227 .22209 L
.59168 .22319 L
.58702 .23291 L
.58256 .24228 L
.58236 .24262 L
.5776 .25233 L
.57284 .26204 L
.57284 .26204 L
.56797 .27176 L
.56313 .28142 L
.56309 .28147 L
.5581 .29118 L
.55342 .3005 L
.55308 .30089 L
.54794 .31061 L
.54371 .31926 L
.54275 .32032 L
.53743 .33003 L
.53399 .33739 L
.53203 .33974 L
Mistroke
.52647 .34946 L
.52428 .35428 L
.52074 .35917 L
.51481 .36888 L
.51457 .3694 L
.50845 .37859 L
.50486 .38374 L
.5004 .37859 L
.50416 .36888 L
.50486 .36717 L
.50824 .35917 L
.51242 .34946 L
.51457 .34452 L
.51669 .33974 L
.52101 .33003 L
.52428 .32267 L
.52534 .32032 L
.52971 .31061 L
.53399 .30101 L
.53405 .30089 L
.53842 .29118 L
.54221 .28147 L
.54371 .27915 L
.54712 .27176 L
.55145 .26204 L
.55342 .25722 L
.55577 .25233 L
.56007 .24262 L
.56313 .23529 L
.56435 .23291 L
.56863 .22319 L
.57284 .21352 L
.57287 .21348 L
.57712 .20377 L
.58088 .19406 L
.58256 .19107 L
.58553 .18434 L
.58855 .17463 L
.59227 .16841 L
.59386 .16492 L
.598 .15521 L
.60198 .14576 L
.60211 .14549 L
.60623 .13578 L
.60988 .12607 L
.61169 .12262 L
.61437 .11636 L
.61723 .10664 L
.62141 .09926 L
.62243 .09693 L
Mistroke
.62645 .08722 L
.63026 .07751 L
.63112 .07576 L
.63441 .06779 L
.63756 .05808 L
.64083 .05184 L
.64229 .04837 L
.64425 .03866 L
.65001 .02894 L
.65054 .02793 L
.654 .01923 L
Mfstroke
.8 g
.50978 .98077 m
.50486 .97132 L
.50114 .98077 L
F
0 g
.50978 .98077 m
.50486 .97132 L
.50114 .98077 L
s
.8 g
.50486 .16578 m
.51018 .17463 L
.50486 .18236 L
.50136 .17463 L
F
0 g
.50486 .16578 m
.51018 .17463 L
.50486 .18236 L
.50136 .17463 L
.50486 .16578 L
s
.2 g
.50486 .76994 m
.51149 .77681 L
.50486 .78652 L
.50212 .77681 L
F
0 g
.50486 .76994 m
.51149 .77681 L
.50486 .78652 L
.50212 .77681 L
.50486 .76994 L
s
.8 g
.90024 .01923 m
.89545 .02894 L
.89336 .0342 L
.89188 .03866 L
.88869 .04837 L
.88601 .05808 L
.88364 .06392 L
.88235 .06779 L
.87913 .07751 L
.87646 .08722 L
.87393 .09339 L
.87273 .09693 L
.86949 .10664 L
.86681 .11636 L
.86422 .12261 L
.86304 .12607 L
.85977 .13578 L
.85705 .14549 L
.85451 .15159 L
.85326 .15521 L
.84996 .16492 L
.84718 .17463 L
.84479 .1803 L
.84339 .18434 L
.84007 .19406 L
.83718 .20377 L
.83508 .20876 L
.83343 .21348 L
.83209 .22319 L
.82707 .23291 L
.82537 .23696 L
.82338 .24262 L
.82173 .25233 L
.81685 .26204 L
.81566 .26489 L
.81322 .27176 L
.81124 .28147 L
.80651 .29118 L
.80594 .29255 L
.80297 .30089 L
.80063 .31061 L
.79623 .31995 L
.79609 .32032 L
.7926 .33003 L
.78992 .33974 L
.78652 .34711 L
.78565 .34946 L
.78213 .35917 L
.7791 .36888 L
.77681 .37397 L
.77509 .37859 L
.77344 .38831 L
.76821 .39802 L
.76709 .40054 L
.76441 .40773 L
.76207 .41744 L
.75738 .42682 L
.75725 .42716 L
.75361 .43687 L
.75068 .44658 L
.74767 .45287 L
.74635 .45629 L
.74268 .46601 L
.73928 .47572 L
.73796 .47858 L
.73532 .48543 L
.73286 .49514 L
.72824 .504 L
.7279 .50486 L
.72414 .51457 L
.72093 .52428 L
.71853 .52917 L
.71661 .53399 L
.71458 .54371 L
.70907 .55342 L
.70882 .55395 L
.70517 .56313 L
.70205 .57284 L
.69911 .57853 L
.69746 .58256 L
.69356 .59227 L
.68974 .60198 L
.68939 .60269 L
.68572 .61169 L
.68248 .62141 L
.67968 .62665 L
.6778 .63112 L
.6738 .64083 L
.66997 .65016 L
.6698 .65054 L
.66573 .66026 L
.66213 .66997 L
.66026 .67345 L
.65758 .67968 L
.65477 .68939 L
.65054 .69638 L
.64933 .69911 L
.64514 .70882 L
.641 .71853 L
.64083 .71884 L
.63671 .72824 L
.63295 .73796 L
.63112 .74112 L
.62817 .74767 L
.62505 .75738 L
.62141 .76301 L
.6195 .76709 L
.6151 .77681 L
.61169 .78449 L
.61069 .78652 L
.60622 .79623 L
.60198 .80548 L
.60174 .80594 L
.59718 .81566 L
.59275 .82537 L
.59227 .82613 L
.58797 .83508 L
.58368 .84479 L
.58256 .84643 L
.57857 .85451 L
.57381 .86422 L
.57284 .86629 L
.56896 .87393 L
.56409 .88364 L
.56313 .88566 L
.55912 .89336 L
.55411 .90307 L
.55342 .9045 L
.54899 .91278 L
.54383 .92249 L
.54371 .92274 L
.53852 .93221 L
.53399 .94042 L
.53315 .94192 L
.52761 .95163 L
.52428 .9574 L
.52193 .96134 L
.51603 .97106 L
.51457 .97343 L
.50497 .97106 L
.50908 .96134 L
.51328 .95163 L
.51457 .94867 L
.51757 .94192 L
.52189 .93221 L
.52428 .92501 L
.52623 .92249 L
.53059 .91278 L
.53399 .90391 L
.53494 .90307 L
.53931 .89336 L
.54362 .88364 L
.54371 .8835 L
.548 .87393 L
.55177 .86422 L
.55342 .86155 L
.55665 .85451 L
.56094 .84479 L
.56313 .8395 L
.56523 .83508 L
.5695 .82537 L
.57284 .81742 L
.57374 .81566 L
.57798 .80594 L
.58206 .79623 L
.58256 .79531 L
.58638 .78652 L
.58992 .77681 L
.59227 .77261 L
.59471 .76709 L
.59735 .75738 L
.60198 .74978 L
.60295 .74767 L
.60706 .73796 L
.61098 .72824 L
.61169 .72683 L
.61519 .71853 L
.61851 .70882 L
.62141 .70341 L
.62325 .69911 L
.62551 .68939 L
.63112 .67993 L
.63123 .67968 L
.63521 .66997 L
.6387 .66026 L
.64083 .65601 L
.64309 .65054 L
.64566 .64083 L
.65054 .63194 L
.65089 .63112 L
.65479 .62141 L
.65824 .61169 L
.66026 .60753 L
.6625 .60198 L
.66501 .59227 L
.66997 .58295 L
.67013 .58256 L
.67395 .57284 L
.67722 .56313 L
.67968 .55799 L
.68149 .55342 L
.68369 .54371 L
.6889 .53399 L
.68939 .53288 L
.69271 .52428 L
.69566 .51457 L
.69911 .50741 L
.70011 .50486 L
.7038 .49514 L
.70715 .48543 L
.70882 .48173 L
.71111 .47572 L
.7135 .46601 L
.71833 .45629 L
.71853 .45583 L
.72199 .44658 L
.72487 .43687 L
.72824 .42958 L
.72916 .42716 L
.73275 .41744 L
.73593 .40773 L
.73796 .40312 L
.73985 .39802 L
.74189 .38831 L
.74675 .37859 L
.74767 .37643 L
.75042 .36888 L
.75289 .35917 L
.75738 .34949 L
.75739 .34946 L
.76089 .33974 L
.76363 .33003 L
.76709 .32223 L
.76779 .32032 L
.77125 .31061 L
.77417 .30089 L
.77681 .29475 L
.77809 .29118 L
.77956 .28147 L
.78455 .27176 L
.78652 .26704 L
.78829 .26204 L
.79005 .25233 L
.79479 .24262 L
.79623 .23908 L
.79839 .23291 L
.80035 .22319 L
.8049 .21348 L
.80594 .21088 L
.8084 .20377 L
.81048 .19406 L
.8149 .18434 L
.81566 .18243 L
.81833 .17463 L
.82047 .16492 L
.8248 .15521 L
.82537 .15374 L
.82817 .14549 L
.83033 .13578 L
.83459 .12607 L
.83508 .12481 L
.83793 .11636 L
.84007 .10664 L
.8443 .09693 L
.84479 .09563 L
.8476 .08722 L
.84969 .07751 L
.85391 .06779 L
.85451 .06622 L
.85721 .05808 L
.8592 .04837 L
.86343 .03866 L
.86422 .03657 L
.86673 .02894 L
.86858 .01923 L
F
0 g
.90024 .01923 m
.89545 .02894 L
.89336 .0342 L
.89188 .03866 L
.88869 .04837 L
.88601 .05808 L
.88364 .06392 L
.88235 .06779 L
.87913 .07751 L
.87646 .08722 L
.87393 .09339 L
.87273 .09693 L
.86949 .10664 L
.86681 .11636 L
.86422 .12261 L
.86304 .12607 L
.85977 .13578 L
.85705 .14549 L
.85451 .15159 L
.85326 .15521 L
.84996 .16492 L
.84718 .17463 L
.84479 .1803 L
.84339 .18434 L
.84007 .19406 L
.83718 .20377 L
.83508 .20876 L
.83343 .21348 L
.83209 .22319 L
.82707 .23291 L
.82537 .23696 L
.82338 .24262 L
.82173 .25233 L
.81685 .26204 L
.81566 .26489 L
.81322 .27176 L
.81124 .28147 L
.80651 .29118 L
.80594 .29255 L
.80297 .30089 L
.80063 .31061 L
.79623 .31995 L
.79609 .32032 L
.7926 .33003 L
.78992 .33974 L
.78652 .34711 L
.78565 .34946 L
.78213 .35917 L
.7791 .36888 L
.77681 .37397 L
Mistroke
.77509 .37859 L
.77344 .38831 L
.76821 .39802 L
.76709 .40054 L
.76441 .40773 L
.76207 .41744 L
.75738 .42682 L
.75725 .42716 L
.75361 .43687 L
.75068 .44658 L
.74767 .45287 L
.74635 .45629 L
.74268 .46601 L
.73928 .47572 L
.73796 .47858 L
.73532 .48543 L
.73286 .49514 L
.72824 .504 L
.7279 .50486 L
.72414 .51457 L
.72093 .52428 L
.71853 .52917 L
.71661 .53399 L
.71458 .54371 L
.70907 .55342 L
.70882 .55395 L
.70517 .56313 L
.70205 .57284 L
.69911 .57853 L
.69746 .58256 L
.69356 .59227 L
.68974 .60198 L
.68939 .60269 L
.68572 .61169 L
.68248 .62141 L
.67968 .62665 L
.6778 .63112 L
.6738 .64083 L
.66997 .65016 L
.6698 .65054 L
.66573 .66026 L
.66213 .66997 L
.66026 .67345 L
.65758 .67968 L
.65477 .68939 L
.65054 .69638 L
.64933 .69911 L
.64514 .70882 L
.641 .71853 L
.64083 .71884 L
Mistroke
.63671 .72824 L
.63295 .73796 L
.63112 .74112 L
.62817 .74767 L
.62505 .75738 L
.62141 .76301 L
.6195 .76709 L
.6151 .77681 L
.61169 .78449 L
.61069 .78652 L
.60622 .79623 L
.60198 .80548 L
.60174 .80594 L
.59718 .81566 L
.59275 .82537 L
.59227 .82613 L
.58797 .83508 L
.58368 .84479 L
.58256 .84643 L
.57857 .85451 L
.57381 .86422 L
.57284 .86629 L
.56896 .87393 L
.56409 .88364 L
.56313 .88566 L
.55912 .89336 L
.55411 .90307 L
.55342 .9045 L
.54899 .91278 L
.54383 .92249 L
.54371 .92274 L
.53852 .93221 L
.53399 .94042 L
.53315 .94192 L
.52761 .95163 L
.52428 .9574 L
.52193 .96134 L
.51603 .97106 L
.51457 .97343 L
.50497 .97106 L
.50908 .96134 L
.51328 .95163 L
.51457 .94867 L
.51757 .94192 L
.52189 .93221 L
.52428 .92501 L
.52623 .92249 L
.53059 .91278 L
.53399 .90391 L
.53494 .90307 L
Mistroke
.53931 .89336 L
.54362 .88364 L
.54371 .8835 L
.548 .87393 L
.55177 .86422 L
.55342 .86155 L
.55665 .85451 L
.56094 .84479 L
.56313 .8395 L
.56523 .83508 L
.5695 .82537 L
.57284 .81742 L
.57374 .81566 L
.57798 .80594 L
.58206 .79623 L
.58256 .79531 L
.58638 .78652 L
.58992 .77681 L
.59227 .77261 L
.59471 .76709 L
.59735 .75738 L
.60198 .74978 L
.60295 .74767 L
.60706 .73796 L
.61098 .72824 L
.61169 .72683 L
.61519 .71853 L
.61851 .70882 L
.62141 .70341 L
.62325 .69911 L
.62551 .68939 L
.63112 .67993 L
.63123 .67968 L
.63521 .66997 L
.6387 .66026 L
.64083 .65601 L
.64309 .65054 L
.64566 .64083 L
.65054 .63194 L
.65089 .63112 L
.65479 .62141 L
.65824 .61169 L
.66026 .60753 L
.6625 .60198 L
.66501 .59227 L
.66997 .58295 L
.67013 .58256 L
.67395 .57284 L
.67722 .56313 L
.67968 .55799 L
Mistroke
.68149 .55342 L
.68369 .54371 L
.6889 .53399 L
.68939 .53288 L
.69271 .52428 L
.69566 .51457 L
.69911 .50741 L
.70011 .50486 L
.7038 .49514 L
.70715 .48543 L
.70882 .48173 L
.71111 .47572 L
.7135 .46601 L
.71833 .45629 L
.71853 .45583 L
.72199 .44658 L
.72487 .43687 L
.72824 .42958 L
.72916 .42716 L
.73275 .41744 L
.73593 .40773 L
.73796 .40312 L
.73985 .39802 L
.74189 .38831 L
.74675 .37859 L
.74767 .37643 L
.75042 .36888 L
.75289 .35917 L
.75738 .34949 L
.75739 .34946 L
.76089 .33974 L
.76363 .33003 L
.76709 .32223 L
.76779 .32032 L
.77125 .31061 L
.77417 .30089 L
.77681 .29475 L
.77809 .29118 L
.77956 .28147 L
.78455 .27176 L
.78652 .26704 L
.78829 .26204 L
.79005 .25233 L
.79479 .24262 L
.79623 .23908 L
.79839 .23291 L
.80035 .22319 L
.8049 .21348 L
.80594 .21088 L
.8084 .20377 L
Mistroke
.81048 .19406 L
.8149 .18434 L
.81566 .18243 L
.81833 .17463 L
.82047 .16492 L
.8248 .15521 L
.82537 .15374 L
.82817 .14549 L
.83033 .13578 L
.83459 .12607 L
.83508 .12481 L
.83793 .11636 L
.84007 .10664 L
.8443 .09693 L
.84479 .09563 L
.8476 .08722 L
.84969 .07751 L
.85391 .06779 L
.85451 .06622 L
.85721 .05808 L
.8592 .04837 L
.86343 .03866 L
.86422 .03657 L
.86673 .02894 L
.86858 .01923 L
Mfstroke
.8 g
.59316 .01923 m
.59227 .02052 L
.58826 .02894 L
.58414 .03866 L
.58256 .04093 L
.57887 .04837 L
.57411 .05808 L
.57284 .06079 L
.56927 .06779 L
.56439 .07751 L
.56313 .08017 L
.55943 .08722 L
.55442 .09693 L
.55342 .09902 L
.54931 .10664 L
.54415 .11636 L
.54371 .11726 L
.53885 .12607 L
.53399 .13489 L
.53349 .13578 L
.52795 .14549 L
.52428 .15186 L
.52229 .15521 L
.5164 .16492 L
.51457 .16789 L
.50522 .16492 L
.50934 .15521 L
.51354 .14549 L
.51457 .14203 L
.51784 .13578 L
.52215 .12607 L
.52428 .1198 L
.5265 .11636 L
.53086 .10664 L
.53399 .0984 L
.53521 .09693 L
.53958 .08722 L
.54371 .07767 L
.54392 .07751 L
.54827 .06779 L
.5522 .05808 L
.55342 .05607 L
.55691 .04837 L
.56016 .03866 L
.56313 .03399 L
.56549 .02894 L
.56976 .01923 L
F
0 g
.59316 .01923 m
.59227 .02052 L
.58826 .02894 L
.58414 .03866 L
.58256 .04093 L
.57887 .04837 L
.57411 .05808 L
.57284 .06079 L
.56927 .06779 L
.56439 .07751 L
.56313 .08017 L
.55943 .08722 L
.55442 .09693 L
.55342 .09902 L
.54931 .10664 L
.54415 .11636 L
.54371 .11726 L
.53885 .12607 L
.53399 .13489 L
.53349 .13578 L
.52795 .14549 L
.52428 .15186 L
.52229 .15521 L
.5164 .16492 L
.51457 .16789 L
.50522 .16492 L
.50934 .15521 L
.51354 .14549 L
.51457 .14203 L
.51784 .13578 L
.52215 .12607 L
.52428 .1198 L
.5265 .11636 L
.53086 .10664 L
.53399 .0984 L
.53521 .09693 L
.53958 .08722 L
.54371 .07767 L
.54392 .07751 L
.54827 .06779 L
.5522 .05808 L
.55342 .05607 L
.55691 .04837 L
.56016 .03866 L
.56313 .03399 L
.56549 .02894 L
.56976 .01923 L
s
.2 g
.83097 .01923 m
.82825 .02894 L
.82537 .03558 L
.82428 .03866 L
.82089 .04837 L
.81801 .05808 L
.81566 .06352 L
.81413 .06779 L
.8128 .07751 L
.80765 .08722 L
.80594 .09119 L
.80388 .09693 L
.8021 .10664 L
.79718 .11636 L
.79623 .11858 L
.79353 .12607 L
.7913 .13578 L
.7866 .14549 L
.78652 .14569 L
.78306 .15521 L
.78041 .16492 L
.77681 .17258 L
.77604 .17463 L
.77248 .18434 L
.76943 .19406 L
.76709 .19917 L
.76537 .20377 L
.76367 .21348 L
.75839 .22319 L
.75738 .22545 L
.75458 .23291 L
.75212 .24262 L
.74767 .25146 L
.74733 .25233 L
.74365 .26204 L
.74058 .27176 L
.73796 .27722 L
.7363 .28147 L
.73455 .29118 L
.72904 .30089 L
.72824 .30261 L
.72514 .31061 L
.72238 .32032 L
.71853 .32778 L
.71763 .33003 L
.71382 .33974 L
.71035 .34946 L
.70882 .3526 L
.70619 .35917 L
.70362 .36888 L
.69911 .37713 L
.6985 .37859 L
.69459 .38831 L
.69107 .39802 L
.68939 .40134 L
.68677 .40773 L
.68411 .41744 L
.67968 .42525 L
.67887 .42716 L
.67486 .43687 L
.67111 .44658 L
.66997 .44879 L
.66681 .45629 L
.66373 .46601 L
.66026 .47209 L
.65867 .47572 L
.65455 .48543 L
.65054 .49491 L
.65044 .49514 L
.64625 .50486 L
.64249 .51457 L
.64083 .51752 L
.63784 .52428 L
.63473 .53399 L
.63112 .53978 L
.62932 .54371 L
.625 .55342 L
.62141 .5616 L
.62067 .56313 L
.61627 .57284 L
.61194 .58256 L
.61169 .58297 L
.60741 .59227 L
.60332 .60198 L
.60198 .60411 L
.59839 .61169 L
.59464 .62141 L
.59227 .62485 L
.5892 .63112 L
.58455 .64083 L
.58256 .64517 L
.57983 .65054 L
.57508 .66026 L
.57284 .66504 L
.57026 .66997 L
.56538 .67968 L
.56313 .68445 L
.56045 .68939 L
.55544 .69911 L
.55342 .70335 L
.55036 .70882 L
.5452 .71853 L
.54371 .72163 L
.53993 .72824 L
.53459 .73796 L
.53399 .73917 L
.52909 .74767 L
.52428 .75602 L
.52347 .75738 L
.51761 .76709 L
.51457 .77204 L
.50605 .76709 L
.51019 .75738 L
.5144 .74767 L
.51457 .74717 L
.51872 .73796 L
.52303 .72824 L
.52428 .72477 L
.52739 .71853 L
.53174 .70882 L
.53399 .70291 L
.53611 .69911 L
.54046 .68939 L
.54371 .68139 L
.54481 .67968 L
.54915 .66997 L
.55342 .66031 L
.55346 .66026 L
.55779 .65054 L
.56163 .64083 L
.56313 .63828 L
.56637 .63112 L
.56948 .62141 L
.57284 .61604 L
.57487 .61169 L
.5791 .60198 L
.58256 .59376 L
.58329 .59227 L
.58749 .58256 L
.59147 .57284 L
.59227 .57133 L
.59581 .56313 L
.59918 .55342 L
.60198 .5484 L
.60405 .54371 L
.60642 .53399 L
.61169 .52539 L
.6122 .52428 L
.61627 .51457 L
.62 .50486 L
.62141 .50208 L
.62432 .49514 L
.62731 .48543 L
.63112 .47845 L
.63229 .47572 L
.63626 .46601 L
.64005 .45629 L
.64083 .45468 L
.64414 .44658 L
.64727 .43687 L
.65054 .4305 L
.65193 .42716 L
.65384 .41744 L
.65954 .40773 L
.66026 .4062 L
.66352 .39802 L
.66656 .38831 L
.66997 .3815 L
.67115 .37859 L
.67288 .36888 L
.67852 .35917 L
.67968 .35664 L
.6825 .34946 L
.68526 .33974 L
.68939 .33146 L
.68997 .33003 L
.6937 .32032 L
.69699 .31061 L
.69911 .30602 L
.70109 .30089 L
.70333 .29118 L
.70835 .28147 L
.70882 .28039 L
.71208 .27176 L
.71493 .26204 L
.71853 .2544 L
.71933 .25233 L
.72295 .24262 L
.72615 .23291 L
.72824 .22819 L
.73012 .22319 L
.73219 .21348 L
.7371 .20377 L
.73796 .20176 L
.74079 .19406 L
.74333 .18434 L
.74767 .17506 L
.74783 .17463 L
.75136 .16492 L
.7542 .15521 L
.75738 .14806 L
.75832 .14549 L
.76181 .13578 L
.76485 .12607 L
.76709 .12083 L
.76871 .11636 L
.77046 .10664 L
.77533 .09693 L
.77681 .09338 L
.779 .08722 L
.78106 .07751 L
.78566 .06779 L
.78652 .06567 L
.78919 .05808 L
.79145 .04837 L
.79586 .03866 L
.79623 .03772 L
.79929 .02894 L
.80168 .01923 L
F
0 g
.83097 .01923 m
.82825 .02894 L
.82537 .03558 L
.82428 .03866 L
.82089 .04837 L
.81801 .05808 L
.81566 .06352 L
.81413 .06779 L
.8128 .07751 L
.80765 .08722 L
.80594 .09119 L
.80388 .09693 L
.8021 .10664 L
.79718 .11636 L
.79623 .11858 L
.79353 .12607 L
.7913 .13578 L
.7866 .14549 L
.78652 .14569 L
.78306 .15521 L
.78041 .16492 L
.77681 .17258 L
.77604 .17463 L
.77248 .18434 L
.76943 .19406 L
.76709 .19917 L
.76537 .20377 L
.76367 .21348 L
.75839 .22319 L
.75738 .22545 L
.75458 .23291 L
.75212 .24262 L
.74767 .25146 L
.74733 .25233 L
.74365 .26204 L
.74058 .27176 L
.73796 .27722 L
.7363 .28147 L
.73455 .29118 L
.72904 .30089 L
.72824 .30261 L
.72514 .31061 L
.72238 .32032 L
.71853 .32778 L
.71763 .33003 L
.71382 .33974 L
.71035 .34946 L
.70882 .3526 L
.70619 .35917 L
.70362 .36888 L
Mistroke
.69911 .37713 L
.6985 .37859 L
.69459 .38831 L
.69107 .39802 L
.68939 .40134 L
.68677 .40773 L
.68411 .41744 L
.67968 .42525 L
.67887 .42716 L
.67486 .43687 L
.67111 .44658 L
.66997 .44879 L
.66681 .45629 L
.66373 .46601 L
.66026 .47209 L
.65867 .47572 L
.65455 .48543 L
.65054 .49491 L
.65044 .49514 L
.64625 .50486 L
.64249 .51457 L
.64083 .51752 L
.63784 .52428 L
.63473 .53399 L
.63112 .53978 L
.62932 .54371 L
.625 .55342 L
.62141 .5616 L
.62067 .56313 L
.61627 .57284 L
.61194 .58256 L
.61169 .58297 L
.60741 .59227 L
.60332 .60198 L
.60198 .60411 L
.59839 .61169 L
.59464 .62141 L
.59227 .62485 L
.5892 .63112 L
.58455 .64083 L
.58256 .64517 L
.57983 .65054 L
.57508 .66026 L
.57284 .66504 L
.57026 .66997 L
.56538 .67968 L
.56313 .68445 L
.56045 .68939 L
.55544 .69911 L
.55342 .70335 L
Mistroke
.55036 .70882 L
.5452 .71853 L
.54371 .72163 L
.53993 .72824 L
.53459 .73796 L
.53399 .73917 L
.52909 .74767 L
.52428 .75602 L
.52347 .75738 L
.51761 .76709 L
.51457 .77204 L
.50605 .76709 L
.51019 .75738 L
.5144 .74767 L
.51457 .74717 L
.51872 .73796 L
.52303 .72824 L
.52428 .72477 L
.52739 .71853 L
.53174 .70882 L
.53399 .70291 L
.53611 .69911 L
.54046 .68939 L
.54371 .68139 L
.54481 .67968 L
.54915 .66997 L
.55342 .66031 L
.55346 .66026 L
.55779 .65054 L
.56163 .64083 L
.56313 .63828 L
.56637 .63112 L
.56948 .62141 L
.57284 .61604 L
.57487 .61169 L
.5791 .60198 L
.58256 .59376 L
.58329 .59227 L
.58749 .58256 L
.59147 .57284 L
.59227 .57133 L
.59581 .56313 L
.59918 .55342 L
.60198 .5484 L
.60405 .54371 L
.60642 .53399 L
.61169 .52539 L
.6122 .52428 L
.61627 .51457 L
.62 .50486 L
Mistroke
.62141 .50208 L
.62432 .49514 L
.62731 .48543 L
.63112 .47845 L
.63229 .47572 L
.63626 .46601 L
.64005 .45629 L
.64083 .45468 L
.64414 .44658 L
.64727 .43687 L
.65054 .4305 L
.65193 .42716 L
.65384 .41744 L
.65954 .40773 L
.66026 .4062 L
.66352 .39802 L
.66656 .38831 L
.66997 .3815 L
.67115 .37859 L
.67288 .36888 L
.67852 .35917 L
.67968 .35664 L
.6825 .34946 L
.68526 .33974 L
.68939 .33146 L
.68997 .33003 L
.6937 .32032 L
.69699 .31061 L
.69911 .30602 L
.70109 .30089 L
.70333 .29118 L
.70835 .28147 L
.70882 .28039 L
.71208 .27176 L
.71493 .26204 L
.71853 .2544 L
.71933 .25233 L
.72295 .24262 L
.72615 .23291 L
.72824 .22819 L
.73012 .22319 L
.73219 .21348 L
.7371 .20377 L
.73796 .20176 L
.74079 .19406 L
.74333 .18434 L
.74767 .17506 L
.74783 .17463 L
.75136 .16492 L
.7542 .15521 L
Mistroke
.75738 .14806 L
.75832 .14549 L
.76181 .13578 L
.76485 .12607 L
.76709 .12083 L
.76871 .11636 L
.77046 .10664 L
.77533 .09693 L
.77681 .09338 L
.779 .08722 L
.78106 .07751 L
.78566 .06779 L
.78652 .06567 L
.78919 .05808 L
.79145 .04837 L
.79586 .03866 L
.79623 .03772 L
.79929 .02894 L
.80168 .01923 L
Mfstroke
.8 g
.75962 .01923 m
.75738 .024 L
.75554 .02894 L
.75371 .03866 L
.74843 .04837 L
.74767 .05007 L
.74463 .05808 L
.74199 .06779 L
.73796 .07582 L
.73729 .07751 L
.73357 .08722 L
.73032 .09693 L
.72824 .10126 L
.72614 .10664 L
.72399 .11636 L
.71866 .12607 L
.71853 .12634 L
.71483 .13578 L
.71173 .14549 L
.70882 .15124 L
.70722 .15521 L
.70336 .16492 L
.69963 .17463 L
.69911 .17571 L
.69563 .18434 L
.69253 .19406 L
.68939 .19998 L
.68782 .20377 L
.68387 .21348 L
.67999 .22319 L
.67968 .22381 L
.67592 .23291 L
.67259 .24262 L
.66997 .24745 L
.66789 .25233 L
.66558 .26204 L
.66026 .27066 L
.65977 .27176 L
.65565 .28147 L
.65183 .29118 L
.65054 .29356 L
.64736 .30089 L
.64417 .31061 L
.64083 .31618 L
.63897 .32032 L
.63472 .33003 L
.63112 .33836 L
.63046 .33974 L
.62614 .34946 L
.62196 .35917 L
.62141 .36014 L
.61744 .36888 L
.6136 .37859 L
.61169 .38167 L
.60859 .38831 L
.60528 .39802 L
.60198 .40281 L
.5996 .40773 L
.59504 .41744 L
.59227 .42354 L
.59044 .42716 L
.58578 .43687 L
.58256 .44384 L
.5811 .44658 L
.57634 .45629 L
.57284 .46371 L
.57155 .46601 L
.56668 .47572 L
.56313 .48315 L
.56177 .48543 L
.55677 .49514 L
.55342 .50214 L
.55172 .50486 L
.54657 .51457 L
.54371 .52057 L
.54135 .52428 L
.53602 .53399 L
.53399 .53824 L
.53056 .54371 L
.52498 .55342 L
.52428 .55486 L
.51918 .56313 L
.51457 .57066 L
.50714 .56313 L
.5113 .55342 L
.51457 .54591 L
.51554 .54371 L
.51986 .53399 L
.52418 .52428 L
.52428 .52401 L
.52855 .51457 L
.5329 .50486 L
.53399 .50205 L
.53727 .49514 L
.54162 .48543 L
.54371 .48021 L
.54596 .47572 L
.5503 .46601 L
.55342 .45847 L
.55462 .45629 L
.55893 .44658 L
.56313 .43699 L
.56321 .43687 L
.5675 .42716 L
.57133 .41744 L
.57284 .41479 L
.57599 .40773 L
.57911 .39802 L
.58256 .39235 L
.58441 .38831 L
.5886 .37859 L
.59227 .36987 L
.59275 .36888 L
.59691 .35917 L
.60075 .34946 L
.60198 .3471 L
.60514 .33974 L
.60829 .33003 L
.61169 .32395 L
.61329 .32032 L
.61734 .31061 L
.62135 .30089 L
.62141 .30077 L
.62539 .29118 L
.62887 .28147 L
.63112 .27708 L
.63335 .27176 L
.63591 .26204 L
.64083 .25327 L
.64124 .25233 L
.64518 .24262 L
.6487 .23291 L
.65054 .22914 L
.65297 .22319 L
.65562 .21348 L
.66026 .20479 L
.66069 .20377 L
.66454 .19406 L
.66795 .18434 L
.66997 .18013 L
.67216 .17463 L
.67462 .16492 L
.67968 .15529 L
.67972 .15521 L
.68349 .14549 L
.68667 .13578 L
.68939 .13006 L
.69096 .12607 L
.69296 .11636 L
.69823 .10664 L
.69911 .10467 L
.70207 .09693 L
.70483 .08722 L
.70882 .07897 L
.70939 .07751 L
.71305 .06779 L
.71623 .05808 L
.71853 .05301 L
.72029 .04837 L
.72233 .03866 L
.72733 .02894 L
.72824 .02697 L
.73107 .01923 L
F
0 g
.75962 .01923 m
.75738 .024 L
.75554 .02894 L
.75371 .03866 L
.74843 .04837 L
.74767 .05007 L
.74463 .05808 L
.74199 .06779 L
.73796 .07582 L
.73729 .07751 L
.73357 .08722 L
.73032 .09693 L
.72824 .10126 L
.72614 .10664 L
.72399 .11636 L
.71866 .12607 L
.71853 .12634 L
.71483 .13578 L
.71173 .14549 L
.70882 .15124 L
.70722 .15521 L
.70336 .16492 L
.69963 .17463 L
.69911 .17571 L
.69563 .18434 L
.69253 .19406 L
.68939 .19998 L
.68782 .20377 L
.68387 .21348 L
.67999 .22319 L
.67968 .22381 L
.67592 .23291 L
.67259 .24262 L
.66997 .24745 L
.66789 .25233 L
.66558 .26204 L
.66026 .27066 L
.65977 .27176 L
.65565 .28147 L
.65183 .29118 L
.65054 .29356 L
.64736 .30089 L
.64417 .31061 L
.64083 .31618 L
.63897 .32032 L
.63472 .33003 L
.63112 .33836 L
.63046 .33974 L
.62614 .34946 L
.62196 .35917 L
Mistroke
.62141 .36014 L
.61744 .36888 L
.6136 .37859 L
.61169 .38167 L
.60859 .38831 L
.60528 .39802 L
.60198 .40281 L
.5996 .40773 L
.59504 .41744 L
.59227 .42354 L
.59044 .42716 L
.58578 .43687 L
.58256 .44384 L
.5811 .44658 L
.57634 .45629 L
.57284 .46371 L
.57155 .46601 L
.56668 .47572 L
.56313 .48315 L
.56177 .48543 L
.55677 .49514 L
.55342 .50214 L
.55172 .50486 L
.54657 .51457 L
.54371 .52057 L
.54135 .52428 L
.53602 .53399 L
.53399 .53824 L
.53056 .54371 L
.52498 .55342 L
.52428 .55486 L
.51918 .56313 L
.51457 .57066 L
.50714 .56313 L
.5113 .55342 L
.51457 .54591 L
.51554 .54371 L
.51986 .53399 L
.52418 .52428 L
.52428 .52401 L
.52855 .51457 L
.5329 .50486 L
.53399 .50205 L
.53727 .49514 L
.54162 .48543 L
.54371 .48021 L
.54596 .47572 L
.5503 .46601 L
.55342 .45847 L
.55462 .45629 L
Mistroke
.55893 .44658 L
.56313 .43699 L
.56321 .43687 L
.5675 .42716 L
.57133 .41744 L
.57284 .41479 L
.57599 .40773 L
.57911 .39802 L
.58256 .39235 L
.58441 .38831 L
.5886 .37859 L
.59227 .36987 L
.59275 .36888 L
.59691 .35917 L
.60075 .34946 L
.60198 .3471 L
.60514 .33974 L
.60829 .33003 L
.61169 .32395 L
.61329 .32032 L
.61734 .31061 L
.62135 .30089 L
.62141 .30077 L
.62539 .29118 L
.62887 .28147 L
.63112 .27708 L
.63335 .27176 L
.63591 .26204 L
.64083 .25327 L
.64124 .25233 L
.64518 .24262 L
.6487 .23291 L
.65054 .22914 L
.65297 .22319 L
.65562 .21348 L
.66026 .20479 L
.66069 .20377 L
.66454 .19406 L
.66795 .18434 L
.66997 .18013 L
.67216 .17463 L
.67462 .16492 L
.67968 .15529 L
.67972 .15521 L
.68349 .14549 L
.68667 .13578 L
.68939 .13006 L
.69096 .12607 L
.69296 .11636 L
.69823 .10664 L
Mistroke
.69911 .10467 L
.70207 .09693 L
.70483 .08722 L
.70882 .07897 L
.70939 .07751 L
.71305 .06779 L
.71623 .05808 L
.71853 .05301 L
.72029 .04837 L
.72233 .03866 L
.72733 .02894 L
.72824 .02697 L
.73107 .01923 L
Mfstroke
.6 g
.53569 .98077 m
.54068 .97106 L
.54371 .96477 L
.54545 .96134 L
.55034 .95163 L
.55342 .94512 L
.55502 .94192 L
.55983 .93221 L
.56313 .9251 L
.56441 .92249 L
.56915 .91278 L
.57284 .90472 L
.57364 .90307 L
.57831 .89336 L
.58256 .88398 L
.58272 .88364 L
.58732 .87393 L
.59171 .86422 L
.59227 .86289 L
.59619 .85451 L
.60058 .84479 L
.60198 .84146 L
.60492 .83508 L
.60931 .82537 L
.61169 .81969 L
.61352 .81566 L
.61789 .80594 L
.62141 .79758 L
.62201 .79623 L
.62634 .78652 L
.63047 .77681 L
.63112 .77515 L
.63467 .76709 L
.63885 .75738 L
.64083 .75239 L
.64288 .74767 L
.64708 .73796 L
.65054 .72931 L
.651 .72824 L
.65517 .71853 L
.65917 .70882 L
.66026 .70593 L
.66315 .69911 L
.66721 .68939 L
.66997 .68223 L
.67103 .67968 L
.6751 .66997 L
.67895 .66026 L
.67968 .65823 L
.68286 .65054 L
.68682 .64083 L
.68939 .63393 L
.69054 .63112 L
.69451 .62141 L
.69828 .61169 L
.69911 .60933 L
.70208 .60198 L
.70596 .59227 L
.70882 .58444 L
.70957 .58256 L
.71345 .57284 L
.71719 .56313 L
.71853 .55926 L
.72084 .55342 L
.72466 .54371 L
.72818 .53399 L
.72824 .53379 L
.73197 .52428 L
.7357 .51457 L
.73796 .50805 L
.73919 .50486 L
.74295 .49514 L
.74655 .48543 L
.74767 .48202 L
.75008 .47572 L
.75379 .46601 L
.7572 .45629 L
.75738 .45571 L
.76085 .44658 L
.76449 .43687 L
.76709 .42913 L
.76783 .42716 L
.77149 .41744 L
.77504 .40773 L
.77681 .40229 L
.77839 .39802 L
.78201 .38831 L
.78546 .37859 L
.78652 .37517 L
.78884 .36888 L
.79242 .35917 L
.79574 .34946 L
.79623 .34779 L
.79917 .33974 L
.80271 .33003 L
.80589 .32032 L
.80594 .32014 L
.8094 .31061 L
.81289 .30089 L
.81566 .29224 L
.81603 .29118 L
.81953 .28147 L
.82297 .27176 L
.82537 .26408 L
.82609 .26204 L
.82956 .25233 L
.83295 .24262 L
.83508 .23566 L
.83605 .23291 L
.83949 .22319 L
.84285 .21348 L
.84479 .207 L
.84592 .20377 L
.84934 .19406 L
.85266 .18434 L
.85451 .17808 L
.8557 .17463 L
.85909 .16492 L
.86238 .15521 L
.86422 .14891 L
.86539 .14549 L
.86876 .13578 L
.87203 .12607 L
.87393 .1195 L
.875 .11636 L
.87834 .10664 L
.8816 .09693 L
.88364 .08984 L
.88453 .08722 L
.88784 .07751 L
.8911 .06779 L
.89336 .05994 L
.89398 .05808 L
.89727 .04837 L
.90051 .03866 L
.90307 .02981 L
.90335 .02894 L
.90661 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.53569 .98077 m
.54068 .97106 L
.54371 .96477 L
.54545 .96134 L
.55034 .95163 L
.55342 .94512 L
.55502 .94192 L
.55983 .93221 L
.56313 .9251 L
.56441 .92249 L
.56915 .91278 L
.57284 .90472 L
.57364 .90307 L
.57831 .89336 L
.58256 .88398 L
.58272 .88364 L
.58732 .87393 L
.59171 .86422 L
.59227 .86289 L
.59619 .85451 L
.60058 .84479 L
.60198 .84146 L
.60492 .83508 L
.60931 .82537 L
.61169 .81969 L
.61352 .81566 L
.61789 .80594 L
.62141 .79758 L
.62201 .79623 L
.62634 .78652 L
.63047 .77681 L
.63112 .77515 L
.63467 .76709 L
.63885 .75738 L
.64083 .75239 L
.64288 .74767 L
.64708 .73796 L
.65054 .72931 L
.651 .72824 L
.65517 .71853 L
.65917 .70882 L
.66026 .70593 L
.66315 .69911 L
.66721 .68939 L
.66997 .68223 L
.67103 .67968 L
.6751 .66997 L
.67895 .66026 L
.67968 .65823 L
.68286 .65054 L
Mistroke
.68682 .64083 L
.68939 .63393 L
.69054 .63112 L
.69451 .62141 L
.69828 .61169 L
.69911 .60933 L
.70208 .60198 L
.70596 .59227 L
.70882 .58444 L
.70957 .58256 L
.71345 .57284 L
.71719 .56313 L
.71853 .55926 L
.72084 .55342 L
.72466 .54371 L
.72818 .53399 L
.72824 .53379 L
.73197 .52428 L
.7357 .51457 L
.73796 .50805 L
.73919 .50486 L
.74295 .49514 L
.74655 .48543 L
.74767 .48202 L
.75008 .47572 L
.75379 .46601 L
.7572 .45629 L
.75738 .45571 L
.76085 .44658 L
.76449 .43687 L
.76709 .42913 L
.76783 .42716 L
.77149 .41744 L
.77504 .40773 L
.77681 .40229 L
.77839 .39802 L
.78201 .38831 L
.78546 .37859 L
.78652 .37517 L
.78884 .36888 L
.79242 .35917 L
.79574 .34946 L
.79623 .34779 L
.79917 .33974 L
.80271 .33003 L
.80589 .32032 L
.80594 .32014 L
.8094 .31061 L
.81289 .30089 L
.81566 .29224 L
Mistroke
.81603 .29118 L
.81953 .28147 L
.82297 .27176 L
.82537 .26408 L
.82609 .26204 L
.82956 .25233 L
.83295 .24262 L
.83508 .23566 L
.83605 .23291 L
.83949 .22319 L
.84285 .21348 L
.84479 .207 L
.84592 .20377 L
.84934 .19406 L
.85266 .18434 L
.85451 .17808 L
.8557 .17463 L
.85909 .16492 L
.86238 .15521 L
.86422 .14891 L
.86539 .14549 L
.86876 .13578 L
.87203 .12607 L
.87393 .1195 L
.875 .11636 L
.87834 .10664 L
.8816 .09693 L
.88364 .08984 L
.88453 .08722 L
.88784 .07751 L
.8911 .06779 L
.89336 .05994 L
.89398 .05808 L
.89727 .04837 L
.90051 .03866 L
.90307 .02981 L
.90335 .02894 L
.90661 .01923 L
Mfstroke
.5 g
.54898 .98077 m
.55342 .97158 L
.55367 .97106 L
.55836 .96134 L
.56297 .95163 L
.56313 .95129 L
.56758 .94192 L
.57213 .93221 L
.57284 .93065 L
.57665 .92249 L
.58114 .91278 L
.58256 .90966 L
.58559 .90307 L
.59002 .89336 L
.59227 .88834 L
.5944 .88364 L
.59877 .87393 L
.60198 .86668 L
.60308 .86422 L
.6074 .85451 L
.61165 .84479 L
.61169 .84469 L
.61591 .83508 L
.62013 .82537 L
.62141 .82237 L
.62432 .81566 L
.6285 .80594 L
.63112 .79974 L
.63262 .79623 L
.63676 .78652 L
.64082 .77681 L
.64083 .77679 L
.64492 .76709 L
.64897 .75738 L
.65054 .75353 L
.65298 .74767 L
.65701 .73796 L
.66026 .72996 L
.66096 .72824 L
.66495 .71853 L
.66888 .70882 L
.66997 .70609 L
.6728 .69911 L
.67672 .68939 L
.67968 .68192 L
.68058 .67968 L
.68447 .66997 L
.68831 .66026 L
.68939 .65746 L
.69213 .65054 L
.69597 .64083 L
.69911 .6327 L
.69973 .63112 L
.70353 .62141 L
.70729 .61169 L
.70882 .60766 L
.71102 .60198 L
.71477 .59227 L
.71845 .58256 L
.71853 .58233 L
.72216 .57284 L
.72586 .56313 L
.72824 .55672 L
.72949 .55342 L
.73317 .54371 L
.7368 .53399 L
.73796 .53083 L
.74041 .52428 L
.74405 .51457 L
.7476 .50486 L
.74767 .50467 L
.7512 .49514 L
.75479 .48543 L
.75738 .47823 L
.7583 .47572 L
.76187 .46601 L
.7654 .45629 L
.76709 .45153 L
.76889 .44658 L
.77242 .43687 L
.7759 .42716 L
.77681 .42455 L
.77937 .41744 L
.78286 .40773 L
.78628 .39802 L
.78652 .39732 L
.78973 .38831 L
.79319 .37859 L
.79623 .36982 L
.79656 .36888 L
.8 .35917 L
.80341 .34946 L
.80594 .34206 L
.80675 .33974 L
.81016 .33003 L
.81354 .32032 L
.81566 .31404 L
.81685 .31061 L
.82022 .30089 L
.82356 .29118 L
.82537 .28577 L
.82685 .28147 L
.83019 .27176 L
.8335 .26204 L
.83508 .25725 L
.83675 .25233 L
.84007 .24262 L
.84335 .23291 L
.84479 .22848 L
.84658 .22319 L
.84987 .21348 L
.85311 .20377 L
.85451 .19946 L
.85631 .19406 L
.85958 .18434 L
.8628 .17463 L
.86422 .17019 L
.86597 .16492 L
.86921 .15521 L
.8724 .14549 L
.87393 .14068 L
.87554 .13578 L
.87876 .12607 L
.88193 .11636 L
.88364 .11093 L
.88504 .10664 L
.88823 .09693 L
.89139 .08722 L
.89336 .08094 L
.89447 .07751 L
.89763 .06779 L
.90077 .05808 L
.90307 .05071 L
.90382 .04837 L
.90695 .03866 L
.91008 .02894 L
.91278 .02024 L
.9131 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.54898 .98077 m
.55342 .97158 L
.55367 .97106 L
.55836 .96134 L
.56297 .95163 L
.56313 .95129 L
.56758 .94192 L
.57213 .93221 L
.57284 .93065 L
.57665 .92249 L
.58114 .91278 L
.58256 .90966 L
.58559 .90307 L
.59002 .89336 L
.59227 .88834 L
.5944 .88364 L
.59877 .87393 L
.60198 .86668 L
.60308 .86422 L
.6074 .85451 L
.61165 .84479 L
.61169 .84469 L
.61591 .83508 L
.62013 .82537 L
.62141 .82237 L
.62432 .81566 L
.6285 .80594 L
.63112 .79974 L
.63262 .79623 L
.63676 .78652 L
.64082 .77681 L
.64083 .77679 L
.64492 .76709 L
.64897 .75738 L
.65054 .75353 L
.65298 .74767 L
.65701 .73796 L
.66026 .72996 L
.66096 .72824 L
.66495 .71853 L
.66888 .70882 L
.66997 .70609 L
.6728 .69911 L
.67672 .68939 L
.67968 .68192 L
.68058 .67968 L
.68447 .66997 L
.68831 .66026 L
.68939 .65746 L
.69213 .65054 L
Mistroke
.69597 .64083 L
.69911 .6327 L
.69973 .63112 L
.70353 .62141 L
.70729 .61169 L
.70882 .60766 L
.71102 .60198 L
.71477 .59227 L
.71845 .58256 L
.71853 .58233 L
.72216 .57284 L
.72586 .56313 L
.72824 .55672 L
.72949 .55342 L
.73317 .54371 L
.7368 .53399 L
.73796 .53083 L
.74041 .52428 L
.74405 .51457 L
.7476 .50486 L
.74767 .50467 L
.7512 .49514 L
.75479 .48543 L
.75738 .47823 L
.7583 .47572 L
.76187 .46601 L
.7654 .45629 L
.76709 .45153 L
.76889 .44658 L
.77242 .43687 L
.7759 .42716 L
.77681 .42455 L
.77937 .41744 L
.78286 .40773 L
.78628 .39802 L
.78652 .39732 L
.78973 .38831 L
.79319 .37859 L
.79623 .36982 L
.79656 .36888 L
.8 .35917 L
.80341 .34946 L
.80594 .34206 L
.80675 .33974 L
.81016 .33003 L
.81354 .32032 L
.81566 .31404 L
.81685 .31061 L
.82022 .30089 L
.82356 .29118 L
Mistroke
.82537 .28577 L
.82685 .28147 L
.83019 .27176 L
.8335 .26204 L
.83508 .25725 L
.83675 .25233 L
.84007 .24262 L
.84335 .23291 L
.84479 .22848 L
.84658 .22319 L
.84987 .21348 L
.85311 .20377 L
.85451 .19946 L
.85631 .19406 L
.85958 .18434 L
.8628 .17463 L
.86422 .17019 L
.86597 .16492 L
.86921 .15521 L
.8724 .14549 L
.87393 .14068 L
.87554 .13578 L
.87876 .12607 L
.88193 .11636 L
.88364 .11093 L
.88504 .10664 L
.88823 .09693 L
.89139 .08722 L
.89336 .08094 L
.89447 .07751 L
.89763 .06779 L
.90077 .05808 L
.90307 .05071 L
.90382 .04837 L
.90695 .03866 L
.91008 .02894 L
.91278 .02024 L
.9131 .01923 L
Mfstroke
.4 g
.56063 .98077 m
.56313 .97546 L
.56518 .97106 L
.56972 .96134 L
.57284 .95461 L
.57421 .95163 L
.57868 .94192 L
.58256 .93343 L
.58311 .93221 L
.5875 .92249 L
.59188 .91278 L
.59227 .91192 L
.59621 .90307 L
.60053 .89336 L
.60198 .89008 L
.6048 .88364 L
.60907 .87393 L
.61169 .86792 L
.61329 .86422 L
.6175 .85451 L
.62141 .84544 L
.62168 .84479 L
.62582 .83508 L
.62996 .82537 L
.63112 .82264 L
.63405 .81566 L
.63815 .80594 L
.64083 .79954 L
.6422 .79623 L
.64623 .78652 L
.65026 .77681 L
.65054 .77613 L
.65424 .76709 L
.65823 .75738 L
.66026 .75241 L
.66217 .74767 L
.66611 .73796 L
.66997 .7284 L
.67003 .72824 L
.67391 .71853 L
.6778 .70882 L
.67968 .7041 L
.68164 .69911 L
.68549 .68939 L
.68932 .67968 L
.68939 .6795 L
.6931 .66997 L
.69691 .66026 L
.69911 .65462 L
.70067 .65054 L
.70442 .64083 L
.70818 .63112 L
.70882 .62945 L
.71187 .62141 L
.7156 .61169 L
.71853 .604 L
.71928 .60198 L
.72295 .59227 L
.72663 .58256 L
.72824 .57827 L
.73025 .57284 L
.73389 .56313 L
.73753 .55342 L
.73796 .55227 L
.7411 .54371 L
.74471 .53399 L
.74767 .52599 L
.74828 .52428 L
.75183 .51457 L
.75541 .50486 L
.75738 .49945 L
.75892 .49514 L
.76245 .48543 L
.76598 .47572 L
.76709 .47263 L
.76945 .46601 L
.77295 .45629 L
.77644 .44658 L
.77681 .44556 L
.77987 .43687 L
.78334 .42716 L
.78652 .41822 L
.78679 .41744 L
.79019 .40773 L
.79363 .39802 L
.79623 .39062 L
.79702 .38831 L
.8004 .37859 L
.80381 .36888 L
.80594 .36276 L
.80716 .35917 L
.81052 .34946 L
.8139 .33974 L
.81566 .33465 L
.81721 .33003 L
.82055 .32032 L
.8239 .31061 L
.82537 .30629 L
.82717 .30089 L
.83048 .29118 L
.8338 .28147 L
.83508 .27768 L
.83704 .27176 L
.84033 .26204 L
.84362 .25233 L
.84479 .24882 L
.84683 .24262 L
.85009 .23291 L
.85335 .22319 L
.85451 .21971 L
.85653 .21348 L
.85976 .20377 L
.863 .19406 L
.86422 .19036 L
.86616 .18434 L
.86936 .17463 L
.87257 .16492 L
.87393 .16076 L
.8757 .15521 L
.87888 .14549 L
.88207 .13578 L
.88364 .13093 L
.88518 .12607 L
.88832 .11636 L
.89149 .10664 L
.89336 .10086 L
.89458 .09693 L
.8977 .08722 L
.90084 .07751 L
.90307 .07055 L
.90392 .06779 L
.907 .05808 L
.91012 .04837 L
.91278 .04001 L
.91319 .03866 L
.91623 .02894 L
.91933 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.56063 .98077 m
.56313 .97546 L
.56518 .97106 L
.56972 .96134 L
.57284 .95461 L
.57421 .95163 L
.57868 .94192 L
.58256 .93343 L
.58311 .93221 L
.5875 .92249 L
.59188 .91278 L
.59227 .91192 L
.59621 .90307 L
.60053 .89336 L
.60198 .89008 L
.6048 .88364 L
.60907 .87393 L
.61169 .86792 L
.61329 .86422 L
.6175 .85451 L
.62141 .84544 L
.62168 .84479 L
.62582 .83508 L
.62996 .82537 L
.63112 .82264 L
.63405 .81566 L
.63815 .80594 L
.64083 .79954 L
.6422 .79623 L
.64623 .78652 L
.65026 .77681 L
.65054 .77613 L
.65424 .76709 L
.65823 .75738 L
.66026 .75241 L
.66217 .74767 L
.66611 .73796 L
.66997 .7284 L
.67003 .72824 L
.67391 .71853 L
.6778 .70882 L
.67968 .7041 L
.68164 .69911 L
.68549 .68939 L
.68932 .67968 L
.68939 .6795 L
.6931 .66997 L
.69691 .66026 L
.69911 .65462 L
.70067 .65054 L
Mistroke
.70442 .64083 L
.70818 .63112 L
.70882 .62945 L
.71187 .62141 L
.7156 .61169 L
.71853 .604 L
.71928 .60198 L
.72295 .59227 L
.72663 .58256 L
.72824 .57827 L
.73025 .57284 L
.73389 .56313 L
.73753 .55342 L
.73796 .55227 L
.7411 .54371 L
.74471 .53399 L
.74767 .52599 L
.74828 .52428 L
.75183 .51457 L
.75541 .50486 L
.75738 .49945 L
.75892 .49514 L
.76245 .48543 L
.76598 .47572 L
.76709 .47263 L
.76945 .46601 L
.77295 .45629 L
.77644 .44658 L
.77681 .44556 L
.77987 .43687 L
.78334 .42716 L
.78652 .41822 L
.78679 .41744 L
.79019 .40773 L
.79363 .39802 L
.79623 .39062 L
.79702 .38831 L
.8004 .37859 L
.80381 .36888 L
.80594 .36276 L
.80716 .35917 L
.81052 .34946 L
.8139 .33974 L
.81566 .33465 L
.81721 .33003 L
.82055 .32032 L
.8239 .31061 L
.82537 .30629 L
.82717 .30089 L
.83048 .29118 L
Mistroke
.8338 .28147 L
.83508 .27768 L
.83704 .27176 L
.84033 .26204 L
.84362 .25233 L
.84479 .24882 L
.84683 .24262 L
.85009 .23291 L
.85335 .22319 L
.85451 .21971 L
.85653 .21348 L
.85976 .20377 L
.863 .19406 L
.86422 .19036 L
.86616 .18434 L
.86936 .17463 L
.87257 .16492 L
.87393 .16076 L
.8757 .15521 L
.87888 .14549 L
.88207 .13578 L
.88364 .13093 L
.88518 .12607 L
.88832 .11636 L
.89149 .10664 L
.89336 .10086 L
.89458 .09693 L
.8977 .08722 L
.90084 .07751 L
.90307 .07055 L
.90392 .06779 L
.907 .05808 L
.91012 .04837 L
.91278 .04001 L
.91319 .03866 L
.91623 .02894 L
.91933 .01923 L
Mfstroke
.3 g
.57274 .98077 m
.57284 .98055 L
.57707 .97106 L
.58154 .96134 L
.58256 .95911 L
.58582 .95163 L
.59021 .94192 L
.59227 .93736 L
.59446 .93221 L
.59877 .92249 L
.60198 .9153 L
.60302 .91278 L
.60722 .90307 L
.6115 .89336 L
.61169 .89292 L
.61558 .88364 L
.6198 .87393 L
.62141 .87023 L
.62385 .86422 L
.628 .85451 L
.63112 .84723 L
.63207 .84479 L
.6361 .83508 L
.64023 .82537 L
.64083 .82394 L
.64413 .81566 L
.6482 .80594 L
.65054 .80033 L
.65212 .79623 L
.65608 .78652 L
.66011 .77681 L
.66026 .77645 L
.6639 .76709 L
.66788 .75738 L
.66997 .75226 L
.67169 .74767 L
.67556 .73796 L
.6795 .72824 L
.67968 .72779 L
.68319 .71853 L
.68708 .70882 L
.68939 .70303 L
.69081 .69911 L
.69458 .68939 L
.69844 .67968 L
.69911 .67799 L
.70205 .66997 L
.70585 .66026 L
.70882 .65267 L
.70955 .65054 L
.71319 .64083 L
.71697 .63112 L
.71853 .62707 L
.72052 .62141 L
.72421 .61169 L
.72795 .60198 L
.72824 .6012 L
.73141 .59227 L
.7351 .58256 L
.73796 .57505 L
.73869 .57284 L
.7422 .56313 L
.74588 .55342 L
.74767 .54864 L
.74932 .54371 L
.75289 .53399 L
.75652 .52428 L
.75738 .52197 L
.75988 .51457 L
.76346 .50486 L
.76705 .49514 L
.76709 .49503 L
.77035 .48543 L
.77391 .47572 L
.77681 .46782 L
.77737 .46601 L
.78072 .45629 L
.78426 .44658 L
.78652 .44036 L
.78761 .43687 L
.79099 .42716 L
.79451 .41744 L
.79623 .41265 L
.79777 .40773 L
.80117 .39802 L
.80465 .38831 L
.80594 .38468 L
.80785 .37859 L
.81125 .36888 L
.8147 .35917 L
.81566 .35645 L
.81785 .34946 L
.82123 .33974 L
.82466 .33003 L
.82537 .32798 L
.82776 .32032 L
.83112 .31061 L
.83452 .30089 L
.83508 .29926 L
.83758 .29118 L
.84092 .28147 L
.84429 .27176 L
.84479 .2703 L
.84732 .26204 L
.85064 .25233 L
.85399 .24262 L
.85451 .24109 L
.85698 .23291 L
.86027 .22319 L
.8636 .21348 L
.86422 .21164 L
.86657 .20377 L
.86983 .19406 L
.87313 .18434 L
.87393 .18195 L
.87607 .17463 L
.8793 .16492 L
.88258 .15521 L
.88364 .15202 L
.88551 .14549 L
.8887 .13578 L
.89196 .12607 L
.89336 .12185 L
.89489 .11636 L
.89802 .10664 L
.90126 .09693 L
.90307 .09145 L
.90421 .08722 L
.90728 .07751 L
.9105 .06779 L
.91278 .06082 L
.91349 .05808 L
.91646 .04837 L
.91966 .03866 L
.92249 .02996 L
.92274 .02894 L
.92559 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.57274 .98077 m
.57284 .98055 L
.57707 .97106 L
.58154 .96134 L
.58256 .95911 L
.58582 .95163 L
.59021 .94192 L
.59227 .93736 L
.59446 .93221 L
.59877 .92249 L
.60198 .9153 L
.60302 .91278 L
.60722 .90307 L
.6115 .89336 L
.61169 .89292 L
.61558 .88364 L
.6198 .87393 L
.62141 .87023 L
.62385 .86422 L
.628 .85451 L
.63112 .84723 L
.63207 .84479 L
.6361 .83508 L
.64023 .82537 L
.64083 .82394 L
.64413 .81566 L
.6482 .80594 L
.65054 .80033 L
.65212 .79623 L
.65608 .78652 L
.66011 .77681 L
.66026 .77645 L
.6639 .76709 L
.66788 .75738 L
.66997 .75226 L
.67169 .74767 L
.67556 .73796 L
.6795 .72824 L
.67968 .72779 L
.68319 .71853 L
.68708 .70882 L
.68939 .70303 L
.69081 .69911 L
.69458 .68939 L
.69844 .67968 L
.69911 .67799 L
.70205 .66997 L
.70585 .66026 L
.70882 .65267 L
.70955 .65054 L
Mistroke
.71319 .64083 L
.71697 .63112 L
.71853 .62707 L
.72052 .62141 L
.72421 .61169 L
.72795 .60198 L
.72824 .6012 L
.73141 .59227 L
.7351 .58256 L
.73796 .57505 L
.73869 .57284 L
.7422 .56313 L
.74588 .55342 L
.74767 .54864 L
.74932 .54371 L
.75289 .53399 L
.75652 .52428 L
.75738 .52197 L
.75988 .51457 L
.76346 .50486 L
.76705 .49514 L
.76709 .49503 L
.77035 .48543 L
.77391 .47572 L
.77681 .46782 L
.77737 .46601 L
.78072 .45629 L
.78426 .44658 L
.78652 .44036 L
.78761 .43687 L
.79099 .42716 L
.79451 .41744 L
.79623 .41265 L
.79777 .40773 L
.80117 .39802 L
.80465 .38831 L
.80594 .38468 L
.80785 .37859 L
.81125 .36888 L
.8147 .35917 L
.81566 .35645 L
.81785 .34946 L
.82123 .33974 L
.82466 .33003 L
.82537 .32798 L
.82776 .32032 L
.83112 .31061 L
.83452 .30089 L
.83508 .29926 L
.83758 .29118 L
Mistroke
.84092 .28147 L
.84429 .27176 L
.84479 .2703 L
.84732 .26204 L
.85064 .25233 L
.85399 .24262 L
.85451 .24109 L
.85698 .23291 L
.86027 .22319 L
.8636 .21348 L
.86422 .21164 L
.86657 .20377 L
.86983 .19406 L
.87313 .18434 L
.87393 .18195 L
.87607 .17463 L
.8793 .16492 L
.88258 .15521 L
.88364 .15202 L
.88551 .14549 L
.8887 .13578 L
.89196 .12607 L
.89336 .12185 L
.89489 .11636 L
.89802 .10664 L
.90126 .09693 L
.90307 .09145 L
.90421 .08722 L
.90728 .07751 L
.9105 .06779 L
.91278 .06082 L
.91349 .05808 L
.91646 .04837 L
.91966 .03866 L
.92249 .02996 L
.92274 .02894 L
.92559 .01923 L
Mfstroke
.2 g
.58809 .98077 m
.59227 .97423 L
.5936 .97106 L
.59775 .96134 L
.60182 .95163 L
.60198 .95132 L
.60597 .94192 L
.60953 .93221 L
.61169 .92814 L
.61412 .92249 L
.6168 .91278 L
.62141 .90481 L
.62218 .90307 L
.6262 .89336 L
.62995 .88364 L
.63112 .88128 L
.63416 .87393 L
.6372 .86422 L
.64083 .85738 L
.64205 .85451 L
.64597 .84479 L
.64971 .83508 L
.65054 .83334 L
.65376 .82537 L
.65682 .81566 L
.66026 .8089 L
.66147 .80594 L
.66324 .79623 L
.66894 .78652 L
.66997 .78431 L
.67294 .77681 L
.67581 .76709 L
.67968 .75938 L
.68049 .75738 L
.68426 .74767 L
.68767 .73796 L
.68939 .73423 L
.69172 .72824 L
.6942 .71853 L
.69911 .70886 L
.69912 .70882 L
.70282 .69911 L
.70588 .68939 L
.70882 .6831 L
.71014 .67968 L
.7119 .66997 L
.71717 .66026 L
.71853 .65718 L
.72103 .65054 L
.72349 .64083 L
.7282 .63112 L
.72824 .63102 L
.7318 .62141 L
.73468 .61169 L
.73796 .6045 L
.7389 .60198 L
.74245 .59227 L
.74559 .58256 L
.74767 .57779 L
.74949 .57284 L
.75145 .56313 L
.7563 .55342 L
.75738 .55084 L
.75996 .54371 L
.7623 .53399 L
.76683 .52428 L
.76709 .52365 L
.77033 .51457 L
.77293 .50486 L
.77681 .49616 L
.77718 .49514 L
.7806 .48543 L
.78337 .47572 L
.78652 .46842 L
.78738 .46601 L
.79078 .45629 L
.79365 .44658 L
.79623 .44045 L
.7975 .43687 L
.79887 .42716 L
.8038 .41744 L
.80594 .41224 L
.80752 .40773 L
.80906 .39802 L
.81383 .38831 L
.81566 .38379 L
.81745 .37859 L
.8191 .36888 L
.82374 .35917 L
.82537 .3551 L
.8273 .34946 L
.82899 .33974 L
.83355 .33003 L
.83508 .32617 L
.83706 .32032 L
.83874 .31061 L
.84326 .30089 L
.84479 .297 L
.84675 .29118 L
.84836 .28147 L
.85288 .27176 L
.85451 .26758 L
.85635 .26204 L
.85786 .25233 L
.8624 .24262 L
.86422 .23794 L
.86589 .23291 L
.86722 .22319 L
.87182 .21348 L
.87393 .20805 L
.87534 .20377 L
.87644 .19406 L
.88114 .18434 L
.88364 .17794 L
.88473 .17463 L
.88786 .16492 L
.89037 .15521 L
.89336 .14761 L
.89405 .14549 L
.89716 .13578 L
.89948 .12607 L
.90307 .11705 L
.9033 .11636 L
.90639 .10664 L
.90848 .09693 L
.91243 .08722 L
.91278 .08625 L
.91555 .07751 L
.91734 .06779 L
.92145 .05808 L
.92249 .05522 L
.92465 .04837 L
.92604 .03866 L
.93036 .02894 L
.93221 .02411 L
.93369 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.58809 .98077 m
.59227 .97423 L
.5936 .97106 L
.59775 .96134 L
.60182 .95163 L
.60198 .95132 L
.60597 .94192 L
.60953 .93221 L
.61169 .92814 L
.61412 .92249 L
.6168 .91278 L
.62141 .90481 L
.62218 .90307 L
.6262 .89336 L
.62995 .88364 L
.63112 .88128 L
.63416 .87393 L
.6372 .86422 L
.64083 .85738 L
.64205 .85451 L
.64597 .84479 L
.64971 .83508 L
.65054 .83334 L
.65376 .82537 L
.65682 .81566 L
.66026 .8089 L
.66147 .80594 L
.66324 .79623 L
.66894 .78652 L
.66997 .78431 L
.67294 .77681 L
.67581 .76709 L
.67968 .75938 L
.68049 .75738 L
.68426 .74767 L
.68767 .73796 L
.68939 .73423 L
.69172 .72824 L
.6942 .71853 L
.69911 .70886 L
.69912 .70882 L
.70282 .69911 L
.70588 .68939 L
.70882 .6831 L
.71014 .67968 L
.7119 .66997 L
.71717 .66026 L
.71853 .65718 L
.72103 .65054 L
.72349 .64083 L
Mistroke
.7282 .63112 L
.72824 .63102 L
.7318 .62141 L
.73468 .61169 L
.73796 .6045 L
.7389 .60198 L
.74245 .59227 L
.74559 .58256 L
.74767 .57779 L
.74949 .57284 L
.75145 .56313 L
.7563 .55342 L
.75738 .55084 L
.75996 .54371 L
.7623 .53399 L
.76683 .52428 L
.76709 .52365 L
.77033 .51457 L
.77293 .50486 L
.77681 .49616 L
.77718 .49514 L
.7806 .48543 L
.78337 .47572 L
.78652 .46842 L
.78738 .46601 L
.79078 .45629 L
.79365 .44658 L
.79623 .44045 L
.7975 .43687 L
.79887 .42716 L
.8038 .41744 L
.80594 .41224 L
.80752 .40773 L
.80906 .39802 L
.81383 .38831 L
.81566 .38379 L
.81745 .37859 L
.8191 .36888 L
.82374 .35917 L
.82537 .3551 L
.8273 .34946 L
.82899 .33974 L
.83355 .33003 L
.83508 .32617 L
.83706 .32032 L
.83874 .31061 L
.84326 .30089 L
.84479 .297 L
.84675 .29118 L
.84836 .28147 L
Mistroke
.85288 .27176 L
.85451 .26758 L
.85635 .26204 L
.85786 .25233 L
.8624 .24262 L
.86422 .23794 L
.86589 .23291 L
.86722 .22319 L
.87182 .21348 L
.87393 .20805 L
.87534 .20377 L
.87644 .19406 L
.88114 .18434 L
.88364 .17794 L
.88473 .17463 L
.88786 .16492 L
.89037 .15521 L
.89336 .14761 L
.89405 .14549 L
.89716 .13578 L
.89948 .12607 L
.90307 .11705 L
.9033 .11636 L
.90639 .10664 L
.90848 .09693 L
.91243 .08722 L
.91278 .08625 L
.91555 .07751 L
.91734 .06779 L
.92145 .05808 L
.92249 .05522 L
.92465 .04837 L
.92604 .03866 L
.93036 .02894 L
.93221 .02411 L
.93369 .01923 L
Mfstroke
.3 g
.61507 .98077 m
.61833 .97106 L
.62141 .96435 L
.6232 .96134 L
.62702 .95163 L
.63112 .94244 L
.6314 .94192 L
.63558 .93221 L
.63984 .92249 L
.64083 .92032 L
.64565 .91278 L
.64821 .90307 L
.65054 .89775 L
.65302 .89336 L
.65648 .88364 L
.66026 .87478 L
.66069 .87393 L
.66466 .86422 L
.66872 .85451 L
.66997 .85161 L
.67383 .84479 L
.67674 .83508 L
.67968 .828 L
.68102 .82537 L
.68467 .81566 L
.68863 .80594 L
.68939 .80412 L
.69377 .79623 L
.69642 .78652 L
.69911 .77989 L
.70063 .77681 L
.70415 .76709 L
.708 .75738 L
.70882 .75538 L
.71289 .74767 L
.7156 .73796 L
.71853 .73052 L
.71961 .72824 L
.72314 .71853 L
.7269 .70882 L
.72824 .70542 L
.73137 .69911 L
.73433 .68939 L
.73796 .67993 L
.73807 .67968 L
.74318 .66997 L
.74537 .66026 L
.74767 .65425 L
.74938 .65054 L
.75265 .64083 L
.75628 .63112 L
.75738 .62824 L
.76064 .62141 L
.76346 .61169 L
.76706 .60198 L
.76709 .60189 L
.77186 .59227 L
.77415 .58256 L
.77681 .57534 L
.7779 .57284 L
.78303 .56313 L
.78471 .55342 L
.78652 .5485 L
.78865 .54371 L
.79168 .53399 L
.79517 .52428 L
.79623 .52136 L
.7993 .51457 L
.80205 .50486 L
.80551 .49514 L
.80594 .49394 L
.80984 .48543 L
.81232 .47572 L
.81566 .46625 L
.81575 .46601 L
.82027 .45629 L
.82248 .44658 L
.82537 .43832 L
.82596 .43687 L
.83058 .42716 L
.83254 .41744 L
.83508 .41013 L
.83606 .40773 L
.84075 .39802 L
.84251 .38831 L
.84479 .38168 L
.84605 .37859 L
.85078 .36888 L
.85238 .35917 L
.85451 .35296 L
.85593 .34946 L
.86066 .33974 L
.86217 .33003 L
.86422 .32399 L
.8657 .32032 L
.8704 .31061 L
.87187 .30089 L
.87393 .29477 L
.87536 .29118 L
.88 .28147 L
.88149 .27176 L
.88364 .26529 L
.88492 .26204 L
.88946 .25233 L
.89103 .24262 L
.89336 .23557 L
.89439 .23291 L
.8988 .22319 L
.90049 .21348 L
.90307 .2056 L
.90377 .20377 L
.90804 .19406 L
.90988 .18434 L
.91278 .17538 L
.91306 .17463 L
.91718 .16492 L
.91919 .15521 L
.92231 .14549 L
.92249 .14494 L
.92624 .13578 L
.92844 .12607 L
.93153 .11636 L
.93221 .11427 L
.93523 .10664 L
.93762 .09693 L
.94068 .08722 L
.94192 .08335 L
.94417 .07751 L
.94882 .06779 L
.94977 .05808 L
.95163 .05219 L
.95306 .04837 L
.95738 .03866 L
.9588 .02894 L
.96134 .02076 L
.96191 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.61507 .98077 m
.61833 .97106 L
.62141 .96435 L
.6232 .96134 L
.62702 .95163 L
.63112 .94244 L
.6314 .94192 L
.63558 .93221 L
.63984 .92249 L
.64083 .92032 L
.64565 .91278 L
.64821 .90307 L
.65054 .89775 L
.65302 .89336 L
.65648 .88364 L
.66026 .87478 L
.66069 .87393 L
.66466 .86422 L
.66872 .85451 L
.66997 .85161 L
.67383 .84479 L
.67674 .83508 L
.67968 .828 L
.68102 .82537 L
.68467 .81566 L
.68863 .80594 L
.68939 .80412 L
.69377 .79623 L
.69642 .78652 L
.69911 .77989 L
.70063 .77681 L
.70415 .76709 L
.708 .75738 L
.70882 .75538 L
.71289 .74767 L
.7156 .73796 L
.71853 .73052 L
.71961 .72824 L
.72314 .71853 L
.7269 .70882 L
.72824 .70542 L
.73137 .69911 L
.73433 .68939 L
.73796 .67993 L
.73807 .67968 L
.74318 .66997 L
.74537 .66026 L
.74767 .65425 L
.74938 .65054 L
.75265 .64083 L
Mistroke
.75628 .63112 L
.75738 .62824 L
.76064 .62141 L
.76346 .61169 L
.76706 .60198 L
.76709 .60189 L
.77186 .59227 L
.77415 .58256 L
.77681 .57534 L
.7779 .57284 L
.78303 .56313 L
.78471 .55342 L
.78652 .5485 L
.78865 .54371 L
.79168 .53399 L
.79517 .52428 L
.79623 .52136 L
.7993 .51457 L
.80205 .50486 L
.80551 .49514 L
.80594 .49394 L
.80984 .48543 L
.81232 .47572 L
.81566 .46625 L
.81575 .46601 L
.82027 .45629 L
.82248 .44658 L
.82537 .43832 L
.82596 .43687 L
.83058 .42716 L
.83254 .41744 L
.83508 .41013 L
.83606 .40773 L
.84075 .39802 L
.84251 .38831 L
.84479 .38168 L
.84605 .37859 L
.85078 .36888 L
.85238 .35917 L
.85451 .35296 L
.85593 .34946 L
.86066 .33974 L
.86217 .33003 L
.86422 .32399 L
.8657 .32032 L
.8704 .31061 L
.87187 .30089 L
.87393 .29477 L
.87536 .29118 L
.88 .28147 L
Mistroke
.88149 .27176 L
.88364 .26529 L
.88492 .26204 L
.88946 .25233 L
.89103 .24262 L
.89336 .23557 L
.89439 .23291 L
.8988 .22319 L
.90049 .21348 L
.90307 .2056 L
.90377 .20377 L
.90804 .19406 L
.90988 .18434 L
.91278 .17538 L
.91306 .17463 L
.91718 .16492 L
.91919 .15521 L
.92231 .14549 L
.92249 .14494 L
.92624 .13578 L
.92844 .12607 L
.93153 .11636 L
.93221 .11427 L
.93523 .10664 L
.93762 .09693 L
.94068 .08722 L
.94192 .08335 L
.94417 .07751 L
.94882 .06779 L
.94977 .05808 L
.95163 .05219 L
.95306 .04837 L
.95738 .03866 L
.9588 .02894 L
.96134 .02076 L
.96191 .01923 L
Mfstroke
.4 g
.62942 .98077 m
.63112 .9765 L
.63353 .97106 L
.63777 .96134 L
.64083 .95377 L
.64176 .95163 L
.64598 .94192 L
.64998 .93221 L
.65054 .9307 L
.65407 .92249 L
.65815 .91278 L
.66026 .90731 L
.66205 .90307 L
.66615 .89336 L
.66996 .88364 L
.66997 .88361 L
.67402 .87393 L
.67798 .86422 L
.67968 .85962 L
.68179 .85451 L
.68579 .84479 L
.68939 .83531 L
.68949 .83508 L
.69346 .82537 L
.69732 .81566 L
.69911 .81072 L
.70103 .80594 L
.70495 .79623 L
.70859 .78652 L
.70882 .78582 L
.71242 .77681 L
.71624 .76709 L
.71853 .76065 L
.71982 .75738 L
.72366 .74767 L
.72731 .73796 L
.72824 .73518 L
.73096 .72824 L
.73473 .71853 L
.73796 .70943 L
.73819 .70882 L
.74196 .69911 L
.74563 .68939 L
.74767 .6834 L
.74909 .67968 L
.75282 .66997 L
.75636 .66026 L
.75738 .6571 L
.75987 .65054 L
.76354 .64083 L
.76691 .63112 L
.76709 .63051 L
.77052 .62141 L
.77413 .61169 L
.77681 .60367 L
.77743 .60198 L
.78106 .59227 L
.78459 .58256 L
.78652 .57655 L
.78788 .57284 L
.79147 .56313 L
.79491 .55342 L
.79623 .54917 L
.79823 .54371 L
.80178 .53399 L
.80512 .52428 L
.80594 .52153 L
.80846 .51457 L
.81198 .50486 L
.81522 .49514 L
.81566 .49362 L
.8186 .48543 L
.82208 .47572 L
.82522 .46601 L
.82537 .46546 L
.82864 .45629 L
.83208 .44658 L
.83508 .43704 L
.83514 .43687 L
.83858 .42716 L
.84198 .41744 L
.84479 .40838 L
.84502 .40773 L
.84843 .39802 L
.8518 .38831 L
.85451 .37946 L
.85481 .37859 L
.85819 .36888 L
.86154 .35917 L
.86422 .35029 L
.86451 .34946 L
.86786 .33974 L
.87119 .33003 L
.87393 .32088 L
.87412 .32032 L
.87745 .31061 L
.88076 .30089 L
.88364 .29122 L
.88366 .29118 L
.88696 .28147 L
.89025 .27176 L
.89318 .26204 L
.89336 .26133 L
.89639 .25233 L
.89967 .24262 L
.90264 .23291 L
.90307 .23119 L
.90574 .22319 L
.90901 .21348 L
.91203 .20377 L
.91278 .20082 L
.91502 .19406 L
.91827 .18434 L
.92134 .17463 L
.92249 .17021 L
.92423 .16492 L
.92746 .15521 L
.93057 .14549 L
.93221 .13936 L
.93337 .13578 L
.93658 .12607 L
.93972 .11636 L
.94192 .10828 L
.94245 .10664 L
.94562 .09693 L
.94878 .08722 L
.95152 .07751 L
.95163 .07697 L
.9546 .06779 L
.95776 .05808 L
.96065 .04837 L
.96134 .04544 L
.96352 .03866 L
.96666 .02894 L
.96967 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.62942 .98077 m
.63112 .9765 L
.63353 .97106 L
.63777 .96134 L
.64083 .95377 L
.64176 .95163 L
.64598 .94192 L
.64998 .93221 L
.65054 .9307 L
.65407 .92249 L
.65815 .91278 L
.66026 .90731 L
.66205 .90307 L
.66615 .89336 L
.66996 .88364 L
.66997 .88361 L
.67402 .87393 L
.67798 .86422 L
.67968 .85962 L
.68179 .85451 L
.68579 .84479 L
.68939 .83531 L
.68949 .83508 L
.69346 .82537 L
.69732 .81566 L
.69911 .81072 L
.70103 .80594 L
.70495 .79623 L
.70859 .78652 L
.70882 .78582 L
.71242 .77681 L
.71624 .76709 L
.71853 .76065 L
.71982 .75738 L
.72366 .74767 L
.72731 .73796 L
.72824 .73518 L
.73096 .72824 L
.73473 .71853 L
.73796 .70943 L
.73819 .70882 L
.74196 .69911 L
.74563 .68939 L
.74767 .6834 L
.74909 .67968 L
.75282 .66997 L
.75636 .66026 L
.75738 .6571 L
.75987 .65054 L
.76354 .64083 L
Mistroke
.76691 .63112 L
.76709 .63051 L
.77052 .62141 L
.77413 .61169 L
.77681 .60367 L
.77743 .60198 L
.78106 .59227 L
.78459 .58256 L
.78652 .57655 L
.78788 .57284 L
.79147 .56313 L
.79491 .55342 L
.79623 .54917 L
.79823 .54371 L
.80178 .53399 L
.80512 .52428 L
.80594 .52153 L
.80846 .51457 L
.81198 .50486 L
.81522 .49514 L
.81566 .49362 L
.8186 .48543 L
.82208 .47572 L
.82522 .46601 L
.82537 .46546 L
.82864 .45629 L
.83208 .44658 L
.83508 .43704 L
.83514 .43687 L
.83858 .42716 L
.84198 .41744 L
.84479 .40838 L
.84502 .40773 L
.84843 .39802 L
.8518 .38831 L
.85451 .37946 L
.85481 .37859 L
.85819 .36888 L
.86154 .35917 L
.86422 .35029 L
.86451 .34946 L
.86786 .33974 L
.87119 .33003 L
.87393 .32088 L
.87412 .32032 L
.87745 .31061 L
.88076 .30089 L
.88364 .29122 L
.88366 .29118 L
.88696 .28147 L
Mistroke
.89025 .27176 L
.89318 .26204 L
.89336 .26133 L
.89639 .25233 L
.89967 .24262 L
.90264 .23291 L
.90307 .23119 L
.90574 .22319 L
.90901 .21348 L
.91203 .20377 L
.91278 .20082 L
.91502 .19406 L
.91827 .18434 L
.92134 .17463 L
.92249 .17021 L
.92423 .16492 L
.92746 .15521 L
.93057 .14549 L
.93221 .13936 L
.93337 .13578 L
.93658 .12607 L
.93972 .11636 L
.94192 .10828 L
.94245 .10664 L
.94562 .09693 L
.94878 .08722 L
.95152 .07751 L
.95163 .07697 L
.9546 .06779 L
.95776 .05808 L
.96065 .04837 L
.96134 .04544 L
.96352 .03866 L
.96666 .02894 L
.96967 .01923 L
Mfstroke
.5 g
.63976 .98077 m
.64083 .97817 L
.64383 .97106 L
.6479 .96134 L
.65054 .95491 L
.65191 .95163 L
.65594 .94192 L
.65991 .93221 L
.66026 .93134 L
.66389 .92249 L
.66785 .91278 L
.66997 .90747 L
.67176 .90307 L
.67569 .89336 L
.67955 .88364 L
.67968 .88331 L
.68344 .87393 L
.6873 .86422 L
.68939 .85884 L
.69111 .85451 L
.69495 .84479 L
.69873 .83508 L
.69911 .83409 L
.70252 .82537 L
.7063 .81566 L
.70882 .80904 L
.71002 .80594 L
.71378 .79623 L
.71748 .78652 L
.71853 .78372 L
.72118 .77681 L
.72489 .76709 L
.72824 .7581 L
.72852 .75738 L
.7322 .74767 L
.73585 .73796 L
.73796 .73222 L
.73944 .72824 L
.74309 .71853 L
.74667 .70882 L
.74767 .70605 L
.75025 .69911 L
.75384 .68939 L
.75736 .67968 L
.75738 .67962 L
.76093 .66997 L
.76448 .66026 L
.76709 .65291 L
.76795 .65054 L
.77149 .64083 L
.77499 .63112 L
.77681 .62594 L
.77844 .62141 L
.78194 .61169 L
.78538 .60198 L
.78652 .5987 L
.78881 .59227 L
.79228 .58256 L
.79567 .57284 L
.79623 .5712 L
.79908 .56313 L
.80251 .55342 L
.80586 .54371 L
.80594 .54344 L
.80925 .53399 L
.81265 .52428 L
.81566 .51543 L
.81595 .51457 L
.81933 .50486 L
.82268 .49514 L
.82537 .48716 L
.82596 .48543 L
.8293 .47572 L
.83263 .46601 L
.83508 .45863 L
.83588 .45629 L
.83919 .44658 L
.84249 .43687 L
.84479 .42986 L
.8457 .42716 L
.849 .41744 L
.85226 .40773 L
.85451 .40084 L
.85545 .39802 L
.85871 .38831 L
.86195 .37859 L
.86422 .37157 L
.86511 .36888 L
.86835 .35917 L
.87156 .34946 L
.87393 .34206 L
.87469 .33974 L
.8779 .33003 L
.8811 .32032 L
.88364 .31231 L
.8842 .31061 L
.88738 .30089 L
.89056 .29118 L
.89336 .28232 L
.89363 .28147 L
.89679 .27176 L
.89994 .26204 L
.903 .25233 L
.90307 .25209 L
.90612 .24262 L
.90926 .23291 L
.91231 .22319 L
.91278 .22163 L
.91538 .21348 L
.9185 .20377 L
.92155 .19406 L
.92249 .19093 L
.92458 .18434 L
.92767 .17463 L
.93072 .16492 L
.93221 .16 L
.93371 .15521 L
.93678 .14549 L
.93983 .13578 L
.94192 .12883 L
.94278 .12607 L
.94583 .11636 L
.94886 .10664 L
.95163 .09744 L
.95179 .09693 L
.95481 .08722 L
.95783 .07751 L
.96077 .06779 L
.96134 .06582 L
.96373 .05808 L
.96674 .04837 L
.96969 .03866 L
.97106 .03398 L
.97244 .02894 L
.97468 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.63976 .98077 m
.64083 .97817 L
.64383 .97106 L
.6479 .96134 L
.65054 .95491 L
.65191 .95163 L
.65594 .94192 L
.65991 .93221 L
.66026 .93134 L
.66389 .92249 L
.66785 .91278 L
.66997 .90747 L
.67176 .90307 L
.67569 .89336 L
.67955 .88364 L
.67968 .88331 L
.68344 .87393 L
.6873 .86422 L
.68939 .85884 L
.69111 .85451 L
.69495 .84479 L
.69873 .83508 L
.69911 .83409 L
.70252 .82537 L
.7063 .81566 L
.70882 .80904 L
.71002 .80594 L
.71378 .79623 L
.71748 .78652 L
.71853 .78372 L
.72118 .77681 L
.72489 .76709 L
.72824 .7581 L
.72852 .75738 L
.7322 .74767 L
.73585 .73796 L
.73796 .73222 L
.73944 .72824 L
.74309 .71853 L
.74667 .70882 L
.74767 .70605 L
.75025 .69911 L
.75384 .68939 L
.75736 .67968 L
.75738 .67962 L
.76093 .66997 L
.76448 .66026 L
.76709 .65291 L
.76795 .65054 L
.77149 .64083 L
Mistroke
.77499 .63112 L
.77681 .62594 L
.77844 .62141 L
.78194 .61169 L
.78538 .60198 L
.78652 .5987 L
.78881 .59227 L
.79228 .58256 L
.79567 .57284 L
.79623 .5712 L
.79908 .56313 L
.80251 .55342 L
.80586 .54371 L
.80594 .54344 L
.80925 .53399 L
.81265 .52428 L
.81566 .51543 L
.81595 .51457 L
.81933 .50486 L
.82268 .49514 L
.82537 .48716 L
.82596 .48543 L
.8293 .47572 L
.83263 .46601 L
.83508 .45863 L
.83588 .45629 L
.83919 .44658 L
.84249 .43687 L
.84479 .42986 L
.8457 .42716 L
.849 .41744 L
.85226 .40773 L
.85451 .40084 L
.85545 .39802 L
.85871 .38831 L
.86195 .37859 L
.86422 .37157 L
.86511 .36888 L
.86835 .35917 L
.87156 .34946 L
.87393 .34206 L
.87469 .33974 L
.8779 .33003 L
.8811 .32032 L
.88364 .31231 L
.8842 .31061 L
.88738 .30089 L
.89056 .29118 L
.89336 .28232 L
.89363 .28147 L
Mistroke
.89679 .27176 L
.89994 .26204 L
.903 .25233 L
.90307 .25209 L
.90612 .24262 L
.90926 .23291 L
.91231 .22319 L
.91278 .22163 L
.91538 .21348 L
.9185 .20377 L
.92155 .19406 L
.92249 .19093 L
.92458 .18434 L
.92767 .17463 L
.93072 .16492 L
.93221 .16 L
.93371 .15521 L
.93678 .14549 L
.93983 .13578 L
.94192 .12883 L
.94278 .12607 L
.94583 .11636 L
.94886 .10664 L
.95163 .09744 L
.95179 .09693 L
.95481 .08722 L
.95783 .07751 L
.96077 .06779 L
.96134 .06582 L
.96373 .05808 L
.96674 .04837 L
.96969 .03866 L
.97106 .03398 L
.97244 .02894 L
.97468 .01923 L
Mfstroke
.6 g
.98077 .02119 m
.97809 .02894 L
.97533 .03866 L
.97253 .04837 L
.97106 .05332 L
.96961 .05808 L
.96662 .06779 L
.96364 .07751 L
.96134 .08523 L
.96074 .08722 L
.95774 .09693 L
.95473 .10664 L
.9518 .11636 L
.95163 .11692 L
.9488 .12607 L
.94576 .13578 L
.94278 .14549 L
.94192 .14838 L
.9398 .15521 L
.93674 .16492 L
.93371 .17463 L
.93221 .17962 L
.93073 .18434 L
.92766 .19406 L
.92459 .20377 L
.92249 .21062 L
.9216 .21348 L
.91851 .22319 L
.91541 .23291 L
.91278 .2414 L
.9124 .24262 L
.90929 .25233 L
.90617 .26204 L
.90312 .27176 L
.90307 .27194 L
.90001 .28147 L
.89686 .29118 L
.89377 .30089 L
.89336 .30224 L
.89065 .31061 L
.88748 .32032 L
.88436 .33003 L
.88364 .33232 L
.88123 .33974 L
.87803 .34946 L
.87487 .35917 L
.87393 .36215 L
.87172 .36888 L
.86851 .37859 L
.86532 .38831 L
.86422 .39174 L
.86214 .39802 L
.8589 .40773 L
.85569 .41744 L
.85451 .42109 L
.85249 .42716 L
.84922 .43687 L
.84597 .44658 L
.84479 .4502 L
.84275 .45629 L
.83945 .46601 L
.83618 .47572 L
.83508 .47906 L
.83292 .48543 L
.8296 .49514 L
.8263 .50486 L
.82537 .50767 L
.82301 .51457 L
.81966 .52428 L
.81634 .53399 L
.81566 .53604 L
.81301 .54371 L
.80962 .55342 L
.80629 .56313 L
.80594 .56415 L
.80291 .57284 L
.7995 .58256 L
.79623 .592 L
.79614 .59227 L
.79272 .60198 L
.78927 .61169 L
.78652 .6196 L
.78588 .62141 L
.78242 .63112 L
.77895 .64083 L
.77681 .64694 L
.77552 .65054 L
.77202 .66026 L
.76853 .66997 L
.76709 .67402 L
.76505 .67968 L
.76151 .68939 L
.758 .69911 L
.75738 .70083 L
.75446 .70882 L
.75088 .71853 L
.74767 .72738 L
.74735 .72824 L
.74375 .73796 L
.74015 .74767 L
.73796 .75365 L
.73657 .75738 L
.73293 .76709 L
.72929 .77681 L
.72824 .77965 L
.72566 .78652 L
.72197 .79623 L
.71853 .80538 L
.71832 .80594 L
.71461 .81566 L
.71089 .82537 L
.70882 .83083 L
.70719 .83508 L
.70342 .84479 L
.69968 .85451 L
.69911 .856 L
.6959 .86422 L
.6921 .87393 L
.68939 .88089 L
.68831 .88364 L
.68447 .89336 L
.68063 .90307 L
.67968 .90548 L
.67677 .91278 L
.67287 .92249 L
.66997 .92979 L
.669 .93221 L
.66506 .94192 L
.66113 .95163 L
.66026 .9538 L
.65717 .96134 L
.65318 .97106 L
.65054 .97751 L
.6492 .98077 L
.98077 .98077 L
F
0 g
.98077 .02119 m
.97809 .02894 L
.97533 .03866 L
.97253 .04837 L
.97106 .05332 L
.96961 .05808 L
.96662 .06779 L
.96364 .07751 L
.96134 .08523 L
.96074 .08722 L
.95774 .09693 L
.95473 .10664 L
.9518 .11636 L
.95163 .11692 L
.9488 .12607 L
.94576 .13578 L
.94278 .14549 L
.94192 .14838 L
.9398 .15521 L
.93674 .16492 L
.93371 .17463 L
.93221 .17962 L
.93073 .18434 L
.92766 .19406 L
.92459 .20377 L
.92249 .21062 L
.9216 .21348 L
.91851 .22319 L
.91541 .23291 L
.91278 .2414 L
.9124 .24262 L
.90929 .25233 L
.90617 .26204 L
.90312 .27176 L
.90307 .27194 L
.90001 .28147 L
.89686 .29118 L
.89377 .30089 L
.89336 .30224 L
.89065 .31061 L
.88748 .32032 L
.88436 .33003 L
.88364 .33232 L
.88123 .33974 L
.87803 .34946 L
.87487 .35917 L
.87393 .36215 L
.87172 .36888 L
.86851 .37859 L
.86532 .38831 L
Mistroke
.86422 .39174 L
.86214 .39802 L
.8589 .40773 L
.85569 .41744 L
.85451 .42109 L
.85249 .42716 L
.84922 .43687 L
.84597 .44658 L
.84479 .4502 L
.84275 .45629 L
.83945 .46601 L
.83618 .47572 L
.83508 .47906 L
.83292 .48543 L
.8296 .49514 L
.8263 .50486 L
.82537 .50767 L
.82301 .51457 L
.81966 .52428 L
.81634 .53399 L
.81566 .53604 L
.81301 .54371 L
.80962 .55342 L
.80629 .56313 L
.80594 .56415 L
.80291 .57284 L
.7995 .58256 L
.79623 .592 L
.79614 .59227 L
.79272 .60198 L
.78927 .61169 L
.78652 .6196 L
.78588 .62141 L
.78242 .63112 L
.77895 .64083 L
.77681 .64694 L
.77552 .65054 L
.77202 .66026 L
.76853 .66997 L
.76709 .67402 L
.76505 .67968 L
.76151 .68939 L
.758 .69911 L
.75738 .70083 L
.75446 .70882 L
.75088 .71853 L
.74767 .72738 L
.74735 .72824 L
.74375 .73796 L
.74015 .74767 L
Mistroke
.73796 .75365 L
.73657 .75738 L
.73293 .76709 L
.72929 .77681 L
.72824 .77965 L
.72566 .78652 L
.72197 .79623 L
.71853 .80538 L
.71832 .80594 L
.71461 .81566 L
.71089 .82537 L
.70882 .83083 L
.70719 .83508 L
.70342 .84479 L
.69968 .85451 L
.69911 .856 L
.6959 .86422 L
.6921 .87393 L
.68939 .88089 L
.68831 .88364 L
.68447 .89336 L
.68063 .90307 L
.67968 .90548 L
.67677 .91278 L
.67287 .92249 L
.66997 .92979 L
.669 .93221 L
.66506 .94192 L
.66113 .95163 L
.66026 .9538 L
.65717 .96134 L
.65318 .97106 L
.65054 .97751 L
.6492 .98077 L
Mfstroke
.7 g
.98077 .04141 m
.97865 .04837 L
.97578 .05808 L
.97286 .06779 L
.97106 .07362 L
.96984 .07751 L
.96675 .08722 L
.96369 .09693 L
.96134 .10562 L
.96102 .10664 L
.95793 .11636 L
.95482 .12607 L
.95201 .13578 L
.95163 .13739 L
.94904 .14549 L
.9459 .15521 L
.94294 .16492 L
.94192 .16893 L
.94009 .17463 L
.93693 .18434 L
.93387 .19406 L
.93221 .20025 L
.93108 .20377 L
.9279 .21348 L
.92477 .22319 L
.92249 .23134 L
.92199 .23291 L
.91881 .24262 L
.91563 .25233 L
.91282 .26204 L
.91278 .26221 L
.90964 .27176 L
.90643 .28147 L
.90349 .29118 L
.90307 .29284 L
.90041 .30089 L
.89717 .31061 L
.89413 .32032 L
.89336 .32323 L
.8911 .33003 L
.88784 .33974 L
.88473 .34946 L
.88364 .3534 L
.88172 .35917 L
.87843 .36888 L
.87527 .37859 L
.87393 .38333 L
.87226 .38831 L
.86895 .39802 L
.86574 .40773 L
.86422 .41302 L
.86272 .41744 L
.85939 .42716 L
.85615 .43687 L
.85451 .44247 L
.8531 .44658 L
.84975 .45629 L
.84648 .46601 L
.84479 .47168 L
.8434 .47572 L
.84003 .48543 L
.83673 .49514 L
.83508 .50064 L
.83362 .50486 L
.83022 .51457 L
.82691 .52428 L
.82537 .52936 L
.82375 .53399 L
.82032 .54371 L
.817 .55342 L
.81566 .55784 L
.81379 .56313 L
.81033 .57284 L
.80701 .58256 L
.80594 .58606 L
.80373 .59227 L
.80025 .60198 L
.79694 .61169 L
.79623 .61403 L
.79358 .62141 L
.79007 .63112 L
.7868 .64083 L
.78652 .64175 L
.78332 .65054 L
.7798 .66026 L
.77681 .66921 L
.77653 .66997 L
.77296 .67968 L
.76943 .68939 L
.76709 .69641 L
.7661 .69911 L
.7625 .70882 L
.75897 .71853 L
.75738 .72335 L
.75556 .72824 L
.75192 .73796 L
.74844 .74767 L
.74767 .75003 L
.7449 .75738 L
.74124 .76709 L
.73796 .77644 L
.73782 .77681 L
.73412 .78652 L
.73046 .79623 L
.72824 .80258 L
.72696 .80594 L
.72322 .81566 L
.71959 .82537 L
.71853 .82845 L
.71596 .83508 L
.71219 .84479 L
.70882 .85405 L
.70864 .85451 L
.70483 .86422 L
.70107 .87393 L
.69911 .87937 L
.69742 .88364 L
.69356 .89336 L
.68987 .90307 L
.68939 .90441 L
.68604 .91278 L
.68218 .92249 L
.67968 .92917 L
.67846 .93221 L
.67452 .94192 L
.67071 .95163 L
.66997 .95364 L
.66682 .96134 L
.66286 .97106 L
.66026 .97784 L
.65904 .98077 L
.98077 .98077 L
F
0 g
.98077 .04141 m
.97865 .04837 L
.97578 .05808 L
.97286 .06779 L
.97106 .07362 L
.96984 .07751 L
.96675 .08722 L
.96369 .09693 L
.96134 .10562 L
.96102 .10664 L
.95793 .11636 L
.95482 .12607 L
.95201 .13578 L
.95163 .13739 L
.94904 .14549 L
.9459 .15521 L
.94294 .16492 L
.94192 .16893 L
.94009 .17463 L
.93693 .18434 L
.93387 .19406 L
.93221 .20025 L
.93108 .20377 L
.9279 .21348 L
.92477 .22319 L
.92249 .23134 L
.92199 .23291 L
.91881 .24262 L
.91563 .25233 L
.91282 .26204 L
.91278 .26221 L
.90964 .27176 L
.90643 .28147 L
.90349 .29118 L
.90307 .29284 L
.90041 .30089 L
.89717 .31061 L
.89413 .32032 L
.89336 .32323 L
.8911 .33003 L
.88784 .33974 L
.88473 .34946 L
.88364 .3534 L
.88172 .35917 L
.87843 .36888 L
.87527 .37859 L
.87393 .38333 L
.87226 .38831 L
.86895 .39802 L
.86574 .40773 L
Mistroke
.86422 .41302 L
.86272 .41744 L
.85939 .42716 L
.85615 .43687 L
.85451 .44247 L
.8531 .44658 L
.84975 .45629 L
.84648 .46601 L
.84479 .47168 L
.8434 .47572 L
.84003 .48543 L
.83673 .49514 L
.83508 .50064 L
.83362 .50486 L
.83022 .51457 L
.82691 .52428 L
.82537 .52936 L
.82375 .53399 L
.82032 .54371 L
.817 .55342 L
.81566 .55784 L
.81379 .56313 L
.81033 .57284 L
.80701 .58256 L
.80594 .58606 L
.80373 .59227 L
.80025 .60198 L
.79694 .61169 L
.79623 .61403 L
.79358 .62141 L
.79007 .63112 L
.7868 .64083 L
.78652 .64175 L
.78332 .65054 L
.7798 .66026 L
.77681 .66921 L
.77653 .66997 L
.77296 .67968 L
.76943 .68939 L
.76709 .69641 L
.7661 .69911 L
.7625 .70882 L
.75897 .71853 L
.75738 .72335 L
.75556 .72824 L
.75192 .73796 L
.74844 .74767 L
.74767 .75003 L
.7449 .75738 L
.74124 .76709 L
Mistroke
.73796 .77644 L
.73782 .77681 L
.73412 .78652 L
.73046 .79623 L
.72824 .80258 L
.72696 .80594 L
.72322 .81566 L
.71959 .82537 L
.71853 .82845 L
.71596 .83508 L
.71219 .84479 L
.70882 .85405 L
.70864 .85451 L
.70483 .86422 L
.70107 .87393 L
.69911 .87937 L
.69742 .88364 L
.69356 .89336 L
.68987 .90307 L
.68939 .90441 L
.68604 .91278 L
.68218 .92249 L
.67968 .92917 L
.67846 .93221 L
.67452 .94192 L
.67071 .95163 L
.66997 .95364 L
.66682 .96134 L
.66286 .97106 L
.66026 .97784 L
.65904 .98077 L
Mfstroke
.8 g
.98077 .06578 m
.98021 .06779 L
.97747 .07751 L
.9746 .08722 L
.97148 .09693 L
.97106 .09813 L
.96786 .10664 L
.96559 .11636 L
.96264 .12607 L
.96134 .13025 L
.95932 .13578 L
.95504 .14549 L
.95379 .15521 L
.95163 .16218 L
.95065 .16492 L
.94665 .17463 L
.94488 .18434 L
.94192 .19389 L
.94186 .19406 L
.93806 .20377 L
.93591 .21348 L
.93289 .22319 L
.93221 .22534 L
.92932 .23291 L
.92463 .24262 L
.92384 .25233 L
.92249 .25659 L
.92045 .26204 L
.91604 .27176 L
.91474 .28147 L
.91278 .28762 L
.91146 .29118 L
.90725 .30089 L
.90557 .31061 L
.90307 .31843 L
.90238 .32032 L
.89831 .33003 L
.89633 .33974 L
.89336 .34902 L
.8932 .34946 L
.88923 .35917 L
.88703 .36888 L
.88389 .37859 L
.88364 .37935 L
.88003 .38831 L
.87766 .39802 L
.8745 .40773 L
.87393 .40945 L
.87072 .41744 L
.86822 .42716 L
.86504 .43687 L
.86422 .43932 L
.86131 .44658 L
.8587 .45629 L
.8555 .46601 L
.85451 .46897 L
.85179 .47572 L
.84911 .48543 L
.84589 .49514 L
.84479 .49837 L
.84218 .50486 L
.83726 .51457 L
.8362 .52428 L
.83508 .52755 L
.83246 .53399 L
.8297 .54371 L
.82642 .55342 L
.82537 .55648 L
.82263 .56313 L
.81988 .57284 L
.81657 .58256 L
.81566 .58518 L
.81269 .59227 L
.80997 .60198 L
.80663 .61169 L
.80594 .61364 L
.80263 .62141 L
.79997 .63112 L
.7966 .64083 L
.79623 .64186 L
.79244 .65054 L
.78988 .66026 L
.78652 .66985 L
.78647 .66997 L
.7821 .67968 L
.7797 .68939 L
.77681 .69755 L
.77617 .69911 L
.77158 .70882 L
.76942 .71853 L
.76709 .725 L
.76573 .72824 L
.76085 .73796 L
.75904 .74767 L
.75738 .75221 L
.75514 .75738 L
.75207 .76709 L
.74855 .77681 L
.74767 .77918 L
.74435 .78652 L
.74152 .79623 L
.73796 .80594 L
.73796 .80594 L
.73332 .81566 L
.73085 .82537 L
.72824 .83237 L
.72706 .83508 L
.72195 .84479 L
.72007 .85451 L
.71853 .85854 L
.71594 .86422 L
.71283 .87393 L
.70916 .88364 L
.70882 .88452 L
.70449 .89336 L
.70184 .90307 L
.69911 .9102 L
.69795 .91278 L
.69256 .92249 L
.69073 .93221 L
.68939 .93559 L
.68635 .94192 L
.68326 .95163 L
.67968 .96083 L
.67945 .96134 L
.67424 .97106 L
.67193 .98077 L
.98077 .98077 L
F
0 g
.98077 .06578 m
.98021 .06779 L
.97747 .07751 L
.9746 .08722 L
.97148 .09693 L
.97106 .09813 L
.96786 .10664 L
.96559 .11636 L
.96264 .12607 L
.96134 .13025 L
.95932 .13578 L
.95504 .14549 L
.95379 .15521 L
.95163 .16218 L
.95065 .16492 L
.94665 .17463 L
.94488 .18434 L
.94192 .19389 L
.94186 .19406 L
.93806 .20377 L
.93591 .21348 L
.93289 .22319 L
.93221 .22534 L
.92932 .23291 L
.92463 .24262 L
.92384 .25233 L
.92249 .25659 L
.92045 .26204 L
.91604 .27176 L
.91474 .28147 L
.91278 .28762 L
.91146 .29118 L
.90725 .30089 L
.90557 .31061 L
.90307 .31843 L
.90238 .32032 L
.89831 .33003 L
.89633 .33974 L
.89336 .34902 L
.8932 .34946 L
.88923 .35917 L
.88703 .36888 L
.88389 .37859 L
.88364 .37935 L
.88003 .38831 L
.87766 .39802 L
.8745 .40773 L
.87393 .40945 L
.87072 .41744 L
.86822 .42716 L
Mistroke
.86504 .43687 L
.86422 .43932 L
.86131 .44658 L
.8587 .45629 L
.8555 .46601 L
.85451 .46897 L
.85179 .47572 L
.84911 .48543 L
.84589 .49514 L
.84479 .49837 L
.84218 .50486 L
.83726 .51457 L
.8362 .52428 L
.83508 .52755 L
.83246 .53399 L
.8297 .54371 L
.82642 .55342 L
.82537 .55648 L
.82263 .56313 L
.81988 .57284 L
.81657 .58256 L
.81566 .58518 L
.81269 .59227 L
.80997 .60198 L
.80663 .61169 L
.80594 .61364 L
.80263 .62141 L
.79997 .63112 L
.7966 .64083 L
.79623 .64186 L
.79244 .65054 L
.78988 .66026 L
.78652 .66985 L
.78647 .66997 L
.7821 .67968 L
.7797 .68939 L
.77681 .69755 L
.77617 .69911 L
.77158 .70882 L
.76942 .71853 L
.76709 .725 L
.76573 .72824 L
.76085 .73796 L
.75904 .74767 L
.75738 .75221 L
.75514 .75738 L
.75207 .76709 L
.74855 .77681 L
.74767 .77918 L
.74435 .78652 L
Mistroke
.74152 .79623 L
.73796 .80594 L
.73796 .80594 L
.73332 .81566 L
.73085 .82537 L
.72824 .83237 L
.72706 .83508 L
.72195 .84479 L
.72007 .85451 L
.71853 .85854 L
.71594 .86422 L
.71283 .87393 L
.70916 .88364 L
.70882 .88452 L
.70449 .89336 L
.70184 .90307 L
.69911 .9102 L
.69795 .91278 L
.69256 .92249 L
.69073 .93221 L
.68939 .93559 L
.68635 .94192 L
.68326 .95163 L
.67968 .96083 L
.67945 .96134 L
.67424 .97106 L
.67193 .98077 L
Mfstroke
.7 g
.98077 .15871 m
.97893 .16492 L
.97598 .17463 L
.97298 .18434 L
.97106 .19057 L
.96997 .19406 L
.96697 .20377 L
.96476 .21348 L
.96134 .22217 L
.96102 .22319 L
.95799 .23291 L
.9561 .24262 L
.95208 .25233 L
.95163 .25356 L
.94896 .26204 L
.94742 .27176 L
.94314 .28147 L
.94192 .28473 L
.93987 .29118 L
.93872 .30089 L
.93415 .31061 L
.93221 .31566 L
.93071 .32032 L
.92762 .33003 L
.9251 .33974 L
.92249 .34634 L
.92148 .34946 L
.91837 .35917 L
.91598 .36888 L
.91278 .37678 L
.91219 .37859 L
.90905 .38831 L
.90679 .39802 L
.90307 .40698 L
.90282 .40773 L
.89965 .41744 L
.8975 .42716 L
.89338 .43687 L
.89336 .43693 L
.89018 .44658 L
.88812 .45629 L
.88389 .46601 L
.88364 .46666 L
.88064 .47572 L
.87862 .48543 L
.87431 .49514 L
.87393 .49613 L
.87101 .50486 L
.869 .51457 L
.86464 .52428 L
.86422 .52535 L
.8613 .53399 L
.85925 .54371 L
.85486 .55342 L
.85451 .55432 L
.85151 .56313 L
.84937 .57284 L
.84498 .58256 L
.84479 .58304 L
.84162 .59227 L
.83936 .60198 L
.83508 .6115 L
.83501 .61169 L
.83165 .62141 L
.82922 .63112 L
.82537 .63971 L
.82497 .64083 L
.82158 .65054 L
.81895 .66026 L
.81566 .66767 L
.81483 .66997 L
.81141 .67968 L
.80856 .68939 L
.80594 .69535 L
.80459 .69911 L
.80114 .70882 L
.79807 .71853 L
.79623 .72274 L
.79424 .72824 L
.79246 .73796 L
.78746 .74767 L
.78652 .74986 L
.78378 .75738 L
.78149 .76709 L
.77681 .7767 L
.77677 .77681 L
.7732 .78652 L
.77044 .79623 L
.76709 .80332 L
.7661 .80594 L
.76251 .81566 L
.75933 .82537 L
.75738 .82962 L
.75532 .83508 L
.75332 .84479 L
.74816 .85451 L
.74767 .8556 L
.7444 .86422 L
.74165 .87393 L
.73796 .88136 L
.73706 .88364 L
.73334 .89336 L
.73001 .90307 L
.72824 .90679 L
.7259 .91278 L
.7236 .92249 L
.71853 .93189 L
.7184 .93221 L
.71459 .94192 L
.7114 .95163 L
.70882 .95677 L
.70698 .96134 L
.70497 .97106 L
.69933 .98077 L
.98077 .98077 L
F
0 g
.98077 .15871 m
.97893 .16492 L
.97598 .17463 L
.97298 .18434 L
.97106 .19057 L
.96997 .19406 L
.96697 .20377 L
.96476 .21348 L
.96134 .22217 L
.96102 .22319 L
.95799 .23291 L
.9561 .24262 L
.95208 .25233 L
.95163 .25356 L
.94896 .26204 L
.94742 .27176 L
.94314 .28147 L
.94192 .28473 L
.93987 .29118 L
.93872 .30089 L
.93415 .31061 L
.93221 .31566 L
.93071 .32032 L
.92762 .33003 L
.9251 .33974 L
.92249 .34634 L
.92148 .34946 L
.91837 .35917 L
.91598 .36888 L
.91278 .37678 L
.91219 .37859 L
.90905 .38831 L
.90679 .39802 L
.90307 .40698 L
.90282 .40773 L
.89965 .41744 L
.8975 .42716 L
.89338 .43687 L
.89336 .43693 L
.89018 .44658 L
.88812 .45629 L
.88389 .46601 L
.88364 .46666 L
.88064 .47572 L
.87862 .48543 L
.87431 .49514 L
.87393 .49613 L
.87101 .50486 L
.869 .51457 L
.86464 .52428 L
Mistroke
.86422 .52535 L
.8613 .53399 L
.85925 .54371 L
.85486 .55342 L
.85451 .55432 L
.85151 .56313 L
.84937 .57284 L
.84498 .58256 L
.84479 .58304 L
.84162 .59227 L
.83936 .60198 L
.83508 .6115 L
.83501 .61169 L
.83165 .62141 L
.82922 .63112 L
.82537 .63971 L
.82497 .64083 L
.82158 .65054 L
.81895 .66026 L
.81566 .66767 L
.81483 .66997 L
.81141 .67968 L
.80856 .68939 L
.80594 .69535 L
.80459 .69911 L
.80114 .70882 L
.79807 .71853 L
.79623 .72274 L
.79424 .72824 L
.79246 .73796 L
.78746 .74767 L
.78652 .74986 L
.78378 .75738 L
.78149 .76709 L
.77681 .7767 L
.77677 .77681 L
.7732 .78652 L
.77044 .79623 L
.76709 .80332 L
.7661 .80594 L
.76251 .81566 L
.75933 .82537 L
.75738 .82962 L
.75532 .83508 L
.75332 .84479 L
.74816 .85451 L
.74767 .8556 L
.7444 .86422 L
.74165 .87393 L
.73796 .88136 L
Mistroke
.73706 .88364 L
.73334 .89336 L
.73001 .90307 L
.72824 .90679 L
.7259 .91278 L
.7236 .92249 L
.71853 .93189 L
.7184 .93221 L
.71459 .94192 L
.7114 .95163 L
.70882 .95677 L
.70698 .96134 L
.70497 .97106 L
.69933 .98077 L
Mfstroke
.6 g
.98077 .18307 m
.98039 .18434 L
.97749 .19406 L
.97452 .20377 L
.97135 .21348 L
.97106 .21506 L
.96891 .22319 L
.96583 .23291 L
.96269 .24262 L
.96134 .24682 L
.95995 .25233 L
.95693 .26204 L
.95376 .27176 L
.95163 .27836 L
.95088 .28147 L
.94795 .29118 L
.94477 .30089 L
.94192 .30967 L
.94171 .31061 L
.93891 .32032 L
.93572 .33003 L
.93253 .33974 L
.93221 .34074 L
.92978 .34946 L
.9266 .35917 L
.92338 .36888 L
.92249 .37159 L
.92057 .37859 L
.91741 .38831 L
.91416 .39802 L
.91278 .4022 L
.91129 .40773 L
.90815 .41744 L
.90488 .42716 L
.90307 .43258 L
.90192 .43687 L
.89881 .44658 L
.89552 .45629 L
.89336 .46272 L
.89249 .46601 L
.88939 .47572 L
.88608 .48543 L
.88364 .49261 L
.88298 .49514 L
.8799 .50486 L
.87656 .51457 L
.87393 .52227 L
.8734 .52428 L
.87032 .53399 L
.86697 .54371 L
.86422 .55168 L
.86376 .55342 L
.86067 .56313 L
.85729 .57284 L
.85451 .58085 L
.85404 .58256 L
.85092 .59227 L
.84752 .60198 L
.84479 .60976 L
.84426 .61169 L
.8411 .62141 L
.83766 .63112 L
.83508 .63843 L
.8344 .64083 L
.83118 .65054 L
.82771 .66026 L
.82537 .66685 L
.82446 .66997 L
.82117 .67968 L
.81767 .68939 L
.81566 .69501 L
.81442 .69911 L
.81106 .70882 L
.80753 .71853 L
.80594 .72291 L
.80429 .72824 L
.80084 .73796 L
.79728 .74767 L
.79623 .75056 L
.79404 .75738 L
.79052 .76709 L
.78693 .77681 L
.78652 .77793 L
.78368 .78652 L
.78009 .79623 L
.77681 .80505 L
.77654 .80594 L
.77319 .81566 L
.76955 .82537 L
.76709 .8319 L
.76608 .83508 L
.76258 .84479 L
.75889 .85451 L
.75738 .85848 L
.75546 .86422 L
.75183 .87393 L
.7481 .88364 L
.74767 .88478 L
.74468 .89336 L
.74096 .90307 L
.73796 .91081 L
.73731 .91278 L
.73374 .92249 L
.72995 .93221 L
.72824 .93656 L
.72639 .94192 L
.72264 .95163 L
.7188 .96134 L
.71853 .96203 L
.71525 .97106 L
.71139 .98077 L
.98077 .98077 L
F
0 g
.98077 .18307 m
.98039 .18434 L
.97749 .19406 L
.97452 .20377 L
.97135 .21348 L
.97106 .21506 L
.96891 .22319 L
.96583 .23291 L
.96269 .24262 L
.96134 .24682 L
.95995 .25233 L
.95693 .26204 L
.95376 .27176 L
.95163 .27836 L
.95088 .28147 L
.94795 .29118 L
.94477 .30089 L
.94192 .30967 L
.94171 .31061 L
.93891 .32032 L
.93572 .33003 L
.93253 .33974 L
.93221 .34074 L
.92978 .34946 L
.9266 .35917 L
.92338 .36888 L
.92249 .37159 L
.92057 .37859 L
.91741 .38831 L
.91416 .39802 L
.91278 .4022 L
.91129 .40773 L
.90815 .41744 L
.90488 .42716 L
.90307 .43258 L
.90192 .43687 L
.89881 .44658 L
.89552 .45629 L
.89336 .46272 L
.89249 .46601 L
.88939 .47572 L
.88608 .48543 L
.88364 .49261 L
.88298 .49514 L
.8799 .50486 L
.87656 .51457 L
.87393 .52227 L
.8734 .52428 L
.87032 .53399 L
.86697 .54371 L
Mistroke
.86422 .55168 L
.86376 .55342 L
.86067 .56313 L
.85729 .57284 L
.85451 .58085 L
.85404 .58256 L
.85092 .59227 L
.84752 .60198 L
.84479 .60976 L
.84426 .61169 L
.8411 .62141 L
.83766 .63112 L
.83508 .63843 L
.8344 .64083 L
.83118 .65054 L
.82771 .66026 L
.82537 .66685 L
.82446 .66997 L
.82117 .67968 L
.81767 .68939 L
.81566 .69501 L
.81442 .69911 L
.81106 .70882 L
.80753 .71853 L
.80594 .72291 L
.80429 .72824 L
.80084 .73796 L
.79728 .74767 L
.79623 .75056 L
.79404 .75738 L
.79052 .76709 L
.78693 .77681 L
.78652 .77793 L
.78368 .78652 L
.78009 .79623 L
.77681 .80505 L
.77654 .80594 L
.77319 .81566 L
.76955 .82537 L
.76709 .8319 L
.76608 .83508 L
.76258 .84479 L
.75889 .85451 L
.75738 .85848 L
.75546 .86422 L
.75183 .87393 L
.7481 .88364 L
.74767 .88478 L
.74468 .89336 L
.74096 .90307 L
Mistroke
.73796 .91081 L
.73731 .91278 L
.73374 .92249 L
.72995 .93221 L
.72824 .93656 L
.72639 .94192 L
.72264 .95163 L
.7188 .96134 L
.71853 .96203 L
.71525 .97106 L
.71139 .98077 L
Mfstroke
.5 g
.98077 .2033 m
.98063 .20377 L
.97587 .21348 L
.97416 .22319 L
.97174 .23291 L
.97106 .23536 L
.96892 .24262 L
.96594 .25233 L
.96293 .26204 L
.96134 .26721 L
.96001 .27176 L
.95703 .28147 L
.954 .29118 L
.95163 .29883 L
.95103 .30089 L
.94806 .31061 L
.94501 .32032 L
.94198 .33003 L
.94192 .33022 L
.93903 .33974 L
.93597 .34946 L
.9329 .35917 L
.93221 .36138 L
.92992 .36888 L
.92685 .37859 L
.92376 .38831 L
.92249 .39231 L
.92075 .39802 L
.91767 .40773 L
.91456 .41744 L
.91278 .42301 L
.91151 .42716 L
.90843 .43687 L
.90529 .44658 L
.90307 .45348 L
.9022 .45629 L
.89911 .46601 L
.89595 .47572 L
.89336 .48371 L
.89282 .48543 L
.88972 .49514 L
.88654 .50486 L
.88364 .5137 L
.88337 .51457 L
.88026 .52428 L
.87705 .53399 L
.87393 .54345 L
.87385 .54371 L
.87072 .55342 L
.86749 .56313 L
.86426 .57284 L
.86422 .57296 L
.8611 .58256 L
.85784 .59227 L
.85459 .60198 L
.85451 .60222 L
.8514 .61169 L
.84812 .62141 L
.84484 .63112 L
.84479 .63124 L
.84162 .64083 L
.83831 .65054 L
.83508 .66002 L
.835 .66026 L
.83175 .66997 L
.82842 .67968 L
.82537 .68854 L
.82509 .68939 L
.8218 .69911 L
.81843 .70882 L
.81566 .71681 L
.81508 .71853 L
.81175 .72824 L
.80835 .73796 L
.80594 .74483 L
.80498 .74767 L
.8016 .75738 L
.79817 .76709 L
.79623 .77259 L
.79478 .77681 L
.79136 .78652 L
.78789 .79623 L
.78652 .80008 L
.78448 .80594 L
.78101 .81566 L
.77751 .82537 L
.77681 .82732 L
.77407 .83508 L
.77055 .84479 L
.76709 .85429 L
.76702 .85451 L
.76354 .86422 L
.75998 .87393 L
.75738 .881 L
.75644 .88364 L
.75289 .89336 L
.74929 .90307 L
.74767 .90744 L
.74573 .91278 L
.74212 .92249 L
.73848 .93221 L
.73796 .9336 L
.73489 .94192 L
.73122 .95163 L
.72824 .95949 L
.72756 .96134 L
.72391 .97106 L
.72019 .98077 L
.98077 .98077 L
F
0 g
.98077 .2033 m
.98063 .20377 L
.97587 .21348 L
.97416 .22319 L
.97174 .23291 L
.97106 .23536 L
.96892 .24262 L
.96594 .25233 L
.96293 .26204 L
.96134 .26721 L
.96001 .27176 L
.95703 .28147 L
.954 .29118 L
.95163 .29883 L
.95103 .30089 L
.94806 .31061 L
.94501 .32032 L
.94198 .33003 L
.94192 .33022 L
.93903 .33974 L
.93597 .34946 L
.9329 .35917 L
.93221 .36138 L
.92992 .36888 L
.92685 .37859 L
.92376 .38831 L
.92249 .39231 L
.92075 .39802 L
.91767 .40773 L
.91456 .41744 L
.91278 .42301 L
.91151 .42716 L
.90843 .43687 L
.90529 .44658 L
.90307 .45348 L
.9022 .45629 L
.89911 .46601 L
.89595 .47572 L
.89336 .48371 L
.89282 .48543 L
.88972 .49514 L
.88654 .50486 L
.88364 .5137 L
.88337 .51457 L
.88026 .52428 L
.87705 .53399 L
.87393 .54345 L
.87385 .54371 L
.87072 .55342 L
.86749 .56313 L
Mistroke
.86426 .57284 L
.86422 .57296 L
.8611 .58256 L
.85784 .59227 L
.85459 .60198 L
.85451 .60222 L
.8514 .61169 L
.84812 .62141 L
.84484 .63112 L
.84479 .63124 L
.84162 .64083 L
.83831 .65054 L
.83508 .66002 L
.835 .66026 L
.83175 .66997 L
.82842 .67968 L
.82537 .68854 L
.82509 .68939 L
.8218 .69911 L
.81843 .70882 L
.81566 .71681 L
.81508 .71853 L
.81175 .72824 L
.80835 .73796 L
.80594 .74483 L
.80498 .74767 L
.8016 .75738 L
.79817 .76709 L
.79623 .77259 L
.79478 .77681 L
.79136 .78652 L
.78789 .79623 L
.78652 .80008 L
.78448 .80594 L
.78101 .81566 L
.77751 .82537 L
.77681 .82732 L
.77407 .83508 L
.77055 .84479 L
.76709 .85429 L
.76702 .85451 L
.76354 .86422 L
.75998 .87393 L
.75738 .881 L
.75644 .88364 L
.75289 .89336 L
.74929 .90307 L
.74767 .90744 L
.74573 .91278 L
.74212 .92249 L
Mistroke
.73848 .93221 L
.73796 .9336 L
.73489 .94192 L
.73122 .95163 L
.72824 .95949 L
.72756 .96134 L
.72391 .97106 L
.72019 .98077 L
Mfstroke
.4 g
.98077 .22257 m
.9805 .22319 L
.97734 .23291 L
.9746 .24262 L
.97177 .25233 L
.97106 .2547 L
.96882 .26204 L
.96583 .27176 L
.96286 .28147 L
.96134 .28661 L
.95995 .29118 L
.95694 .30089 L
.95394 .31061 L
.95163 .3183 L
.95101 .32032 L
.948 .33003 L
.94496 .33974 L
.94201 .34946 L
.94192 .34977 L
.93899 .35917 L
.93593 .36888 L
.93293 .37859 L
.93221 .381 L
.92992 .38831 L
.92684 .39802 L
.92379 .40773 L
.92249 .412 L
.92078 .41744 L
.91768 .42716 L
.9146 .43687 L
.91278 .44278 L
.91158 .44658 L
.90846 .45629 L
.90535 .46601 L
.90307 .47332 L
.90231 .47572 L
.89917 .48543 L
.89603 .49514 L
.89336 .50363 L
.89296 .50486 L
.88981 .51457 L
.88664 .52428 L
.88364 .5337 L
.88355 .53399 L
.88038 .54371 L
.87719 .55342 L
.87406 .56313 L
.87393 .56353 L
.87087 .57284 L
.86765 .58256 L
.86449 .59227 L
.86422 .59313 L
.86129 .60198 L
.85804 .61169 L
.85485 .62141 L
.85451 .62248 L
.85162 .63112 L
.84835 .64083 L
.84513 .65054 L
.84479 .65158 L
.84187 .66026 L
.83858 .66997 L
.83533 .67968 L
.83508 .68045 L
.83204 .68939 L
.82872 .69911 L
.82545 .70882 L
.82537 .70906 L
.82212 .71853 L
.81877 .72824 L
.81566 .73742 L
.81547 .73796 L
.81211 .74767 L
.80873 .75738 L
.80594 .76553 L
.8054 .76709 L
.802 .77681 L
.7986 .78652 L
.79623 .79339 L
.79523 .79623 L
.7918 .80594 L
.78837 .81566 L
.78652 .82098 L
.78497 .82537 L
.7815 .83508 L
.77804 .84479 L
.77681 .84832 L
.77459 .85451 L
.77109 .86422 L
.76761 .87393 L
.76709 .8754 L
.76411 .88364 L
.76057 .89336 L
.75738 .90221 L
.75707 .90307 L
.75351 .91278 L
.74994 .92249 L
.74767 .92876 L
.7464 .93221 L
.74279 .94192 L
.7392 .95163 L
.73796 .95504 L
.7356 .96134 L
.73196 .97106 L
.72834 .98077 L
.98077 .98077 L
F
0 g
.98077 .22257 m
.9805 .22319 L
.97734 .23291 L
.9746 .24262 L
.97177 .25233 L
.97106 .2547 L
.96882 .26204 L
.96583 .27176 L
.96286 .28147 L
.96134 .28661 L
.95995 .29118 L
.95694 .30089 L
.95394 .31061 L
.95163 .3183 L
.95101 .32032 L
.948 .33003 L
.94496 .33974 L
.94201 .34946 L
.94192 .34977 L
.93899 .35917 L
.93593 .36888 L
.93293 .37859 L
.93221 .381 L
.92992 .38831 L
.92684 .39802 L
.92379 .40773 L
.92249 .412 L
.92078 .41744 L
.91768 .42716 L
.9146 .43687 L
.91278 .44278 L
.91158 .44658 L
.90846 .45629 L
.90535 .46601 L
.90307 .47332 L
.90231 .47572 L
.89917 .48543 L
.89603 .49514 L
.89336 .50363 L
.89296 .50486 L
.88981 .51457 L
.88664 .52428 L
.88364 .5337 L
.88355 .53399 L
.88038 .54371 L
.87719 .55342 L
.87406 .56313 L
.87393 .56353 L
.87087 .57284 L
.86765 .58256 L
Mistroke
.86449 .59227 L
.86422 .59313 L
.86129 .60198 L
.85804 .61169 L
.85485 .62141 L
.85451 .62248 L
.85162 .63112 L
.84835 .64083 L
.84513 .65054 L
.84479 .65158 L
.84187 .66026 L
.83858 .66997 L
.83533 .67968 L
.83508 .68045 L
.83204 .68939 L
.82872 .69911 L
.82545 .70882 L
.82537 .70906 L
.82212 .71853 L
.81877 .72824 L
.81566 .73742 L
.81547 .73796 L
.81211 .74767 L
.80873 .75738 L
.80594 .76553 L
.8054 .76709 L
.802 .77681 L
.7986 .78652 L
.79623 .79339 L
.79523 .79623 L
.7918 .80594 L
.78837 .81566 L
.78652 .82098 L
.78497 .82537 L
.7815 .83508 L
.77804 .84479 L
.77681 .84832 L
.77459 .85451 L
.77109 .86422 L
.76761 .87393 L
.76709 .8754 L
.76411 .88364 L
.76057 .89336 L
.75738 .90221 L
.75707 .90307 L
.75351 .91278 L
.74994 .92249 L
.74767 .92876 L
.7464 .93221 L
.74279 .94192 L
Mistroke
.7392 .95163 L
.73796 .95504 L
.7356 .96134 L
.73196 .97106 L
.72834 .98077 L
Mfstroke
.3 g
.98077 .2428 m
.97789 .25233 L
.97501 .26204 L
.97207 .27176 L
.97106 .27501 L
.96902 .28147 L
.96592 .29118 L
.96292 .30089 L
.96134 .307 L
.96021 .31061 L
.9571 .32032 L
.95402 .33003 L
.95163 .33877 L
.95133 .33974 L
.94821 .34946 L
.94508 .35917 L
.94226 .36888 L
.94192 .37032 L
.93926 .37859 L
.9361 .38831 L
.93313 .39802 L
.93221 .40163 L
.93024 .40773 L
.92706 .41744 L
.92399 .42716 L
.92249 .43273 L
.92115 .43687 L
.91796 .44658 L
.91482 .45629 L
.91278 .46359 L
.912 .46601 L
.90879 .47572 L
.9056 .48543 L
.90307 .49422 L
.90277 .49514 L
.89955 .50486 L
.89632 .51457 L
.89344 .52428 L
.89336 .52462 L
.89023 .53399 L
.88698 .54371 L
.884 .55342 L
.88364 .55479 L
.88084 .56313 L
.87757 .57284 L
.87451 .58256 L
.87393 .58471 L
.87138 .59227 L
.86808 .60198 L
.86497 .61169 L
.86422 .6144 L
.86184 .62141 L
.85851 .63112 L
.85536 .64083 L
.85451 .64385 L
.85222 .65054 L
.84886 .66026 L
.84568 .66997 L
.84479 .67306 L
.84251 .67968 L
.83913 .68939 L
.83593 .69911 L
.83508 .70203 L
.83272 .70882 L
.82932 .71853 L
.8261 .72824 L
.82537 .73075 L
.82284 .73796 L
.81941 .74767 L
.81619 .75738 L
.81566 .75922 L
.81287 .76709 L
.80942 .77681 L
.80621 .78652 L
.80594 .78745 L
.80281 .79623 L
.79934 .80594 L
.79623 .81542 L
.79615 .81566 L
.79264 .82537 L
.78916 .83508 L
.78652 .84313 L
.78592 .84479 L
.78238 .85451 L
.77889 .86422 L
.77681 .87059 L
.77559 .87393 L
.77201 .88364 L
.76854 .89336 L
.76709 .89779 L
.76515 .90307 L
.76154 .91278 L
.7581 .92249 L
.75738 .92473 L
.75459 .93221 L
.75097 .94192 L
.74767 .95142 L
.74759 .95163 L
.74392 .96134 L
.74029 .97106 L
.73796 .97783 L
.73684 .98077 L
.98077 .98077 L
F
0 g
.98077 .2428 m
.97789 .25233 L
.97501 .26204 L
.97207 .27176 L
.97106 .27501 L
.96902 .28147 L
.96592 .29118 L
.96292 .30089 L
.96134 .307 L
.96021 .31061 L
.9571 .32032 L
.95402 .33003 L
.95163 .33877 L
.95133 .33974 L
.94821 .34946 L
.94508 .35917 L
.94226 .36888 L
.94192 .37032 L
.93926 .37859 L
.9361 .38831 L
.93313 .39802 L
.93221 .40163 L
.93024 .40773 L
.92706 .41744 L
.92399 .42716 L
.92249 .43273 L
.92115 .43687 L
.91796 .44658 L
.91482 .45629 L
.91278 .46359 L
.912 .46601 L
.90879 .47572 L
.9056 .48543 L
.90307 .49422 L
.90277 .49514 L
.89955 .50486 L
.89632 .51457 L
.89344 .52428 L
.89336 .52462 L
.89023 .53399 L
.88698 .54371 L
.884 .55342 L
.88364 .55479 L
.88084 .56313 L
.87757 .57284 L
.87451 .58256 L
.87393 .58471 L
.87138 .59227 L
.86808 .60198 L
.86497 .61169 L
Mistroke
.86422 .6144 L
.86184 .62141 L
.85851 .63112 L
.85536 .64083 L
.85451 .64385 L
.85222 .65054 L
.84886 .66026 L
.84568 .66997 L
.84479 .67306 L
.84251 .67968 L
.83913 .68939 L
.83593 .69911 L
.83508 .70203 L
.83272 .70882 L
.82932 .71853 L
.8261 .72824 L
.82537 .73075 L
.82284 .73796 L
.81941 .74767 L
.81619 .75738 L
.81566 .75922 L
.81287 .76709 L
.80942 .77681 L
.80621 .78652 L
.80594 .78745 L
.80281 .79623 L
.79934 .80594 L
.79623 .81542 L
.79615 .81566 L
.79264 .82537 L
.78916 .83508 L
.78652 .84313 L
.78592 .84479 L
.78238 .85451 L
.77889 .86422 L
.77681 .87059 L
.77559 .87393 L
.77201 .88364 L
.76854 .89336 L
.76709 .89779 L
.76515 .90307 L
.76154 .91278 L
.7581 .92249 L
.75738 .92473 L
.75459 .93221 L
.75097 .94192 L
.74767 .95142 L
.74759 .95163 L
.74392 .96134 L
.74029 .97106 L
Mistroke
.73796 .97783 L
.73684 .98077 L
Mfstroke
.2 g
.98077 .26715 m
.97949 .27176 L
.97673 .28147 L
.9738 .29118 L
.97106 .29952 L
.97058 .30089 L
.96676 .31061 L
.96481 .32032 L
.96185 .33003 L
.96134 .33165 L
.9583 .33974 L
.95597 .34946 L
.95299 .35917 L
.95163 .36355 L
.94968 .36888 L
.94538 .37859 L
.94408 .38831 L
.94192 .39526 L
.94092 .39802 L
.93689 .40773 L
.93511 .41744 L
.93221 .42675 L
.93206 .42716 L
.92822 .43687 L
.92608 .44658 L
.92303 .45629 L
.92249 .45798 L
.91939 .46601 L
.91698 .47572 L
.91392 .48543 L
.91278 .489 L
.91044 .49514 L
.9059 .50486 L
.90475 .51457 L
.90307 .5198 L
.90138 .52428 L
.89703 .53399 L
.89551 .54371 L
.89336 .55038 L
.89222 .55342 L
.888 .56313 L
.8862 .57284 L
.88364 .58073 L
.88296 .58256 L
.87883 .59227 L
.87682 .60198 L
.87393 .61085 L
.87362 .61169 L
.86955 .62141 L
.86738 .63112 L
.86422 .64074 L
.86418 .64083 L
.86015 .65054 L
.85786 .66026 L
.85464 .66997 L
.85451 .67038 L
.85064 .67968 L
.84826 .68939 L
.84503 .69911 L
.84479 .69978 L
.84102 .70882 L
.83859 .71853 L
.83533 .72824 L
.83508 .72896 L
.83129 .73796 L
.82884 .74767 L
.82555 .75738 L
.82537 .7579 L
.82144 .76709 L
.819 .77681 L
.81569 .78652 L
.81566 .7866 L
.81148 .79623 L
.80908 .80594 L
.80594 .81505 L
.80571 .81566 L
.80138 .82537 L
.79908 .83508 L
.79623 .84325 L
.79561 .84479 L
.79114 .85451 L
.78898 .86422 L
.78652 .8712 L
.7854 .87393 L
.78072 .88364 L
.77879 .89336 L
.77681 .89891 L
.77506 .90307 L
.7701 .91278 L
.7685 .92249 L
.76709 .92637 L
.76457 .93221 L
.7616 .94192 L
.75811 .95163 L
.75738 .9536 L
.7539 .96134 L
.75114 .97106 L
.74767 .98061 L
.7476 .98077 L
.98077 .98077 L
F
0 g
.98077 .26715 m
.97949 .27176 L
.97673 .28147 L
.9738 .29118 L
.97106 .29952 L
.97058 .30089 L
.96676 .31061 L
.96481 .32032 L
.96185 .33003 L
.96134 .33165 L
.9583 .33974 L
.95597 .34946 L
.95299 .35917 L
.95163 .36355 L
.94968 .36888 L
.94538 .37859 L
.94408 .38831 L
.94192 .39526 L
.94092 .39802 L
.93689 .40773 L
.93511 .41744 L
.93221 .42675 L
.93206 .42716 L
.92822 .43687 L
.92608 .44658 L
.92303 .45629 L
.92249 .45798 L
.91939 .46601 L
.91698 .47572 L
.91392 .48543 L
.91278 .489 L
.91044 .49514 L
.9059 .50486 L
.90475 .51457 L
.90307 .5198 L
.90138 .52428 L
.89703 .53399 L
.89551 .54371 L
.89336 .55038 L
.89222 .55342 L
.888 .56313 L
.8862 .57284 L
.88364 .58073 L
.88296 .58256 L
.87883 .59227 L
.87682 .60198 L
.87393 .61085 L
.87362 .61169 L
.86955 .62141 L
.86738 .63112 L
Mistroke
.86422 .64074 L
.86418 .64083 L
.86015 .65054 L
.85786 .66026 L
.85464 .66997 L
.85451 .67038 L
.85064 .67968 L
.84826 .68939 L
.84503 .69911 L
.84479 .69978 L
.84102 .70882 L
.83859 .71853 L
.83533 .72824 L
.83508 .72896 L
.83129 .73796 L
.82884 .74767 L
.82555 .75738 L
.82537 .7579 L
.82144 .76709 L
.819 .77681 L
.81569 .78652 L
.81566 .7866 L
.81148 .79623 L
.80908 .80594 L
.80594 .81505 L
.80571 .81566 L
.80138 .82537 L
.79908 .83508 L
.79623 .84325 L
.79561 .84479 L
.79114 .85451 L
.78898 .86422 L
.78652 .8712 L
.7854 .87393 L
.78072 .88364 L
.77879 .89336 L
.77681 .89891 L
.77506 .90307 L
.7701 .91278 L
.7685 .92249 L
.76709 .92637 L
.76457 .93221 L
.7616 .94192 L
.75811 .95163 L
.75738 .9536 L
.7539 .96134 L
.75114 .97106 L
.74767 .98061 L
.7476 .98077 L
Mfstroke
.3 g
.98077 .36008 m
.97816 .36888 L
.97519 .37859 L
.97218 .38831 L
.97106 .39194 L
.96917 .39802 L
.96829 .40773 L
.96368 .41744 L
.96134 .42357 L
.96022 .42716 L
.9572 .43687 L
.95493 .44658 L
.95163 .45495 L
.9512 .45629 L
.94816 .46601 L
.94616 .47572 L
.94216 .48543 L
.94192 .48609 L
.93905 .49514 L
.93735 .50486 L
.93313 .51457 L
.93221 .51703 L
.92989 .52428 L
.9285 .53399 L
.92403 .54371 L
.92249 .54772 L
.92065 .55342 L
.91958 .56313 L
.91487 .57284 L
.91278 .57818 L
.91135 .58256 L
.90822 .59227 L
.90563 .60198 L
.90307 .60838 L
.90198 .61169 L
.89882 .62141 L
.89631 .63112 L
.89336 .63835 L
.89253 .64083 L
.88934 .65054 L
.88689 .66026 L
.88364 .66806 L
.883 .66997 L
.87979 .67968 L
.87736 .68939 L
.87393 .69753 L
.8734 .69911 L
.87015 .70882 L
.86772 .71853 L
.86422 .72675 L
.86371 .72824 L
.86044 .73796 L
.85797 .74767 L
.85451 .75573 L
.85393 .75738 L
.85063 .76709 L
.84809 .77681 L
.84479 .78445 L
.84407 .78652 L
.84074 .79623 L
.83809 .80594 L
.83508 .81291 L
.83412 .81566 L
.83076 .82537 L
.82797 .83508 L
.82537 .84112 L
.82407 .84479 L
.82068 .85451 L
.81773 .86422 L
.81566 .86905 L
.81392 .87393 L
.81242 .88364 L
.80738 .89336 L
.80594 .89672 L
.80367 .90307 L
.80174 .91278 L
.79691 .92249 L
.79623 .92411 L
.79331 .93221 L
.79096 .94192 L
.78652 .95123 L
.78637 .95163 L
.78284 .96134 L
.78009 .97106 L
.77681 .97776 L
.77582 .98077 L
.98077 .98077 L
F
0 g
.98077 .36008 m
.97816 .36888 L
.97519 .37859 L
.97218 .38831 L
.97106 .39194 L
.96917 .39802 L
.96829 .40773 L
.96368 .41744 L
.96134 .42357 L
.96022 .42716 L
.9572 .43687 L
.95493 .44658 L
.95163 .45495 L
.9512 .45629 L
.94816 .46601 L
.94616 .47572 L
.94216 .48543 L
.94192 .48609 L
.93905 .49514 L
.93735 .50486 L
.93313 .51457 L
.93221 .51703 L
.92989 .52428 L
.9285 .53399 L
.92403 .54371 L
.92249 .54772 L
.92065 .55342 L
.91958 .56313 L
.91487 .57284 L
.91278 .57818 L
.91135 .58256 L
.90822 .59227 L
.90563 .60198 L
.90307 .60838 L
.90198 .61169 L
.89882 .62141 L
.89631 .63112 L
.89336 .63835 L
.89253 .64083 L
.88934 .65054 L
.88689 .66026 L
.88364 .66806 L
.883 .66997 L
.87979 .67968 L
.87736 .68939 L
.87393 .69753 L
.8734 .69911 L
.87015 .70882 L
.86772 .71853 L
.86422 .72675 L
Mistroke
.86371 .72824 L
.86044 .73796 L
.85797 .74767 L
.85451 .75573 L
.85393 .75738 L
.85063 .76709 L
.84809 .77681 L
.84479 .78445 L
.84407 .78652 L
.84074 .79623 L
.83809 .80594 L
.83508 .81291 L
.83412 .81566 L
.83076 .82537 L
.82797 .83508 L
.82537 .84112 L
.82407 .84479 L
.82068 .85451 L
.81773 .86422 L
.81566 .86905 L
.81392 .87393 L
.81242 .88364 L
.80738 .89336 L
.80594 .89672 L
.80367 .90307 L
.80174 .91278 L
.79691 .92249 L
.79623 .92411 L
.79331 .93221 L
.79096 .94192 L
.78652 .95123 L
.78637 .95163 L
.78284 .96134 L
.78009 .97106 L
.77681 .97776 L
.77582 .98077 L
Mfstroke
.4 g
.98077 .38445 m
.97963 .38831 L
.9767 .39802 L
.97126 .40773 L
.97106 .41644 L
.97084 .41744 L
.96812 .42716 L
.96499 .43687 L
.96186 .44658 L
.96134 .4482 L
.95919 .45629 L
.95609 .46601 L
.95292 .47572 L
.95163 .47974 L
.95017 .48543 L
.94712 .49514 L
.94393 .50486 L
.94192 .51105 L
.94105 .51457 L
.93807 .52428 L
.93487 .53399 L
.93221 .54213 L
.93183 .54371 L
.92896 .55342 L
.92574 .56313 L
.92254 .57284 L
.92249 .57297 L
.91976 .58256 L
.91655 .59227 L
.91331 .60198 L
.91278 .60358 L
.91049 .61169 L
.90728 .62141 L
.90401 .63112 L
.90307 .63396 L
.90114 .64083 L
.89794 .65054 L
.89465 .66026 L
.89336 .6641 L
.89172 .66997 L
.88852 .67968 L
.8852 .68939 L
.88364 .694 L
.88222 .69911 L
.87902 .70882 L
.87568 .71853 L
.87393 .72365 L
.87265 .72824 L
.86944 .73796 L
.86607 .74767 L
.86422 .75307 L
.863 .75738 L
.85978 .76709 L
.85639 .77681 L
.85451 .78223 L
.85328 .78652 L
.85003 .79623 L
.84661 .80594 L
.84479 .81115 L
.84348 .81566 L
.84019 .82537 L
.83675 .83508 L
.83508 .83982 L
.8336 .84479 L
.83027 .85451 L
.82679 .86422 L
.82537 .86823 L
.82363 .87393 L
.82024 .88364 L
.81674 .89336 L
.81566 .89639 L
.81357 .90307 L
.81012 .91278 L
.80659 .92249 L
.80594 .92429 L
.8034 .93221 L
.7999 .94192 L
.79634 .95163 L
.79623 .95194 L
.79313 .96134 L
.78957 .97106 L
.78652 .9793 L
.78609 .98077 L
.98077 .98077 L
F
0 g
.98077 .38445 m
.97963 .38831 L
.9767 .39802 L
.97126 .40773 L
.97106 .41644 L
.97084 .41744 L
.96812 .42716 L
.96499 .43687 L
.96186 .44658 L
.96134 .4482 L
.95919 .45629 L
.95609 .46601 L
.95292 .47572 L
.95163 .47974 L
.95017 .48543 L
.94712 .49514 L
.94393 .50486 L
.94192 .51105 L
.94105 .51457 L
.93807 .52428 L
.93487 .53399 L
.93221 .54213 L
.93183 .54371 L
.92896 .55342 L
.92574 .56313 L
.92254 .57284 L
.92249 .57297 L
.91976 .58256 L
.91655 .59227 L
.91331 .60198 L
.91278 .60358 L
.91049 .61169 L
.90728 .62141 L
.90401 .63112 L
.90307 .63396 L
.90114 .64083 L
.89794 .65054 L
.89465 .66026 L
.89336 .6641 L
.89172 .66997 L
.88852 .67968 L
.8852 .68939 L
.88364 .694 L
.88222 .69911 L
.87902 .70882 L
.87568 .71853 L
.87393 .72365 L
.87265 .72824 L
.86944 .73796 L
.86607 .74767 L
Mistroke
.86422 .75307 L
.863 .75738 L
.85978 .76709 L
.85639 .77681 L
.85451 .78223 L
.85328 .78652 L
.85003 .79623 L
.84661 .80594 L
.84479 .81115 L
.84348 .81566 L
.84019 .82537 L
.83675 .83508 L
.83508 .83982 L
.8336 .84479 L
.83027 .85451 L
.82679 .86422 L
.82537 .86823 L
.82363 .87393 L
.82024 .88364 L
.81674 .89336 L
.81566 .89639 L
.81357 .90307 L
.81012 .91278 L
.80659 .92249 L
.80594 .92429 L
.8034 .93221 L
.7999 .94192 L
.79634 .95163 L
.79623 .95194 L
.79313 .96134 L
.78957 .97106 L
.78652 .9793 L
.78609 .98077 L
Mfstroke
.5 g
.98077 .40468 m
.97778 .40773 L
.97547 .41744 L
.97358 .42716 L
.97106 .43675 L
.97102 .43687 L
.96814 .44658 L
.96514 .45629 L
.96214 .46601 L
.96134 .46859 L
.95923 .47572 L
.95623 .48543 L
.9532 .49514 L
.95163 .50021 L
.95026 .50486 L
.94726 .51457 L
.9442 .52428 L
.94192 .5316 L
.94121 .53399 L
.93822 .54371 L
.93515 .55342 L
.93221 .56276 L
.9321 .56313 L
.92912 .57284 L
.92603 .58256 L
.92294 .59227 L
.92249 .5937 L
.91995 .60198 L
.91685 .61169 L
.91373 .62141 L
.91278 .6244 L
.91071 .63112 L
.90759 .64083 L
.90445 .65054 L
.90307 .65486 L
.9014 .66026 L
.89827 .66997 L
.89511 .67968 L
.89336 .68509 L
.89202 .68939 L
.88888 .69911 L
.88569 .70882 L
.88364 .71508 L
.88256 .71853 L
.87941 .72824 L
.8762 .73796 L
.87393 .74483 L
.87304 .74767 L
.86986 .75738 L
.86663 .76709 L
.86422 .77434 L
.86343 .77681 L
.86024 .78652 L
.85698 .79623 L
.85451 .80361 L
.85376 .80594 L
.85054 .81566 L
.84725 .82537 L
.84479 .83263 L
.844 .83508 L
.84075 .84479 L
.83743 .85451 L
.83508 .8614 L
.83416 .86422 L
.83087 .87393 L
.82753 .88364 L
.82537 .88992 L
.82423 .89336 L
.82091 .90307 L
.81753 .91278 L
.81566 .91819 L
.81421 .92249 L
.81085 .93221 L
.80744 .94192 L
.80594 .94621 L
.8041 .95163 L
.80069 .96134 L
.79726 .97106 L
.79623 .97397 L
.79388 .98077 L
.98077 .98077 L
F
0 g
.98077 .40468 m
.97778 .40773 L
.97547 .41744 L
.97358 .42716 L
.97106 .43675 L
.97102 .43687 L
.96814 .44658 L
.96514 .45629 L
.96214 .46601 L
.96134 .46859 L
.95923 .47572 L
.95623 .48543 L
.9532 .49514 L
.95163 .50021 L
.95026 .50486 L
.94726 .51457 L
.9442 .52428 L
.94192 .5316 L
.94121 .53399 L
.93822 .54371 L
.93515 .55342 L
.93221 .56276 L
.9321 .56313 L
.92912 .57284 L
.92603 .58256 L
.92294 .59227 L
.92249 .5937 L
.91995 .60198 L
.91685 .61169 L
.91373 .62141 L
.91278 .6244 L
.91071 .63112 L
.90759 .64083 L
.90445 .65054 L
.90307 .65486 L
.9014 .66026 L
.89827 .66997 L
.89511 .67968 L
.89336 .68509 L
.89202 .68939 L
.88888 .69911 L
.88569 .70882 L
.88364 .71508 L
.88256 .71853 L
.87941 .72824 L
.8762 .73796 L
.87393 .74483 L
.87304 .74767 L
.86986 .75738 L
.86663 .76709 L
Mistroke
.86422 .77434 L
.86343 .77681 L
.86024 .78652 L
.85698 .79623 L
.85451 .80361 L
.85376 .80594 L
.85054 .81566 L
.84725 .82537 L
.84479 .83263 L
.844 .83508 L
.84075 .84479 L
.83743 .85451 L
.83508 .8614 L
.83416 .86422 L
.83087 .87393 L
.82753 .88364 L
.82537 .88992 L
.82423 .89336 L
.82091 .90307 L
.81753 .91278 L
.81566 .91819 L
.81421 .92249 L
.81085 .93221 L
.80744 .94192 L
.80594 .94621 L
.8041 .95163 L
.80069 .96134 L
.79726 .97106 L
.79623 .97397 L
.79388 .98077 L
Mfstroke
.6 g
.98077 .42395 m
.97953 .42716 L
.97661 .43687 L
.97386 .44658 L
.97106 .45609 L
.97099 .45629 L
.96803 .46601 L
.96503 .47572 L
.96209 .48543 L
.96134 .488 L
.95916 .49514 L
.95614 .50486 L
.95315 .51457 L
.95163 .51969 L
.95022 .52428 L
.94719 .53399 L
.94416 .54371 L
.94192 .55115 L
.94122 .55342 L
.93818 .56313 L
.93512 .57284 L
.93221 .58238 L
.93215 .58256 L
.9291 .59227 L
.92602 .60198 L
.923 .61169 L
.92249 .61339 L
.91996 .62141 L
.91686 .63112 L
.9138 .64083 L
.91278 .64416 L
.91076 .65054 L
.90763 .66026 L
.90454 .66997 L
.90307 .67471 L
.90148 .67968 L
.89834 .68939 L
.89521 .69911 L
.89336 .70501 L
.89213 .70882 L
.88897 .71853 L
.88581 .72824 L
.88364 .73508 L
.88271 .73796 L
.87953 .74767 L
.87634 .75738 L
.87393 .76492 L
.87322 .76709 L
.87002 .77681 L
.8668 .78652 L
.86422 .79451 L
.86365 .79623 L
.86042 .80594 L
.85718 .81566 L
.85451 .82386 L
.85401 .82537 L
.85075 .83508 L
.84749 .84479 L
.84479 .85297 L
.84428 .85451 L
.841 .86422 L
.8377 .87393 L
.83508 .88183 L
.83447 .88364 L
.83116 .89336 L
.82784 .90307 L
.82537 .91044 L
.82457 .91278 L
.82123 .92249 L
.81788 .93221 L
.81566 .9388 L
.81459 .94192 L
.81121 .95163 L
.80784 .96134 L
.80594 .96691 L
.8045 .97106 L
.8011 .98077 L
.98077 .98077 L
F
0 g
.98077 .42395 m
.97953 .42716 L
.97661 .43687 L
.97386 .44658 L
.97106 .45609 L
.97099 .45629 L
.96803 .46601 L
.96503 .47572 L
.96209 .48543 L
.96134 .488 L
.95916 .49514 L
.95614 .50486 L
.95315 .51457 L
.95163 .51969 L
.95022 .52428 L
.94719 .53399 L
.94416 .54371 L
.94192 .55115 L
.94122 .55342 L
.93818 .56313 L
.93512 .57284 L
.93221 .58238 L
.93215 .58256 L
.9291 .59227 L
.92602 .60198 L
.923 .61169 L
.92249 .61339 L
.91996 .62141 L
.91686 .63112 L
.9138 .64083 L
.91278 .64416 L
.91076 .65054 L
.90763 .66026 L
.90454 .66997 L
.90307 .67471 L
.90148 .67968 L
.89834 .68939 L
.89521 .69911 L
.89336 .70501 L
.89213 .70882 L
.88897 .71853 L
.88581 .72824 L
.88364 .73508 L
.88271 .73796 L
.87953 .74767 L
.87634 .75738 L
.87393 .76492 L
.87322 .76709 L
.87002 .77681 L
.8668 .78652 L
Mistroke
.86422 .79451 L
.86365 .79623 L
.86042 .80594 L
.85718 .81566 L
.85451 .82386 L
.85401 .82537 L
.85075 .83508 L
.84749 .84479 L
.84479 .85297 L
.84428 .85451 L
.841 .86422 L
.8377 .87393 L
.83508 .88183 L
.83447 .88364 L
.83116 .89336 L
.82784 .90307 L
.82537 .91044 L
.82457 .91278 L
.82123 .92249 L
.81788 .93221 L
.81566 .9388 L
.81459 .94192 L
.81121 .95163 L
.80784 .96134 L
.80594 .96691 L
.8045 .97106 L
.8011 .98077 L
Mfstroke
.7 g
.98077 .44418 m
.98002 .44658 L
.97713 .45629 L
.97424 .46601 L
.97127 .47572 L
.97106 .4764 L
.9682 .48543 L
.9651 .49514 L
.9622 .50486 L
.96134 .50838 L
.95939 .51457 L
.95627 .52428 L
.95324 .53399 L
.95163 .54016 L
.95051 .54371 L
.94737 .55342 L
.94428 .56313 L
.94192 .5717 L
.94156 .57284 L
.93842 .58256 L
.93527 .59227 L
.93245 .60198 L
.93221 .60302 L
.9294 .61169 L
.92622 .62141 L
.92326 .63112 L
.92249 .63411 L
.92031 .64083 L
.91711 .65054 L
.91405 .66026 L
.91278 .66497 L
.91115 .66997 L
.90793 .67968 L
.9048 .68939 L
.90307 .6956 L
.90192 .69911 L
.89868 .70882 L
.8955 .71853 L
.89336 .72601 L
.89262 .72824 L
.88936 .73796 L
.88614 .74767 L
.88364 .75617 L
.88324 .75738 L
.87997 .76709 L
.87671 .77681 L
.87393 .7861 L
.87379 .78652 L
.8705 .79623 L
.86721 .80594 L
.86425 .81566 L
.86422 .81579 L
.86095 .82537 L
.85764 .83508 L
.85463 .84479 L
.85451 .84524 L
.85132 .85451 L
.84798 .86422 L
.84493 .87393 L
.84479 .87445 L
.84161 .88364 L
.83825 .89336 L
.83518 .90307 L
.83508 .90342 L
.83181 .91278 L
.82843 .92249 L
.82537 .93214 L
.82535 .93221 L
.82193 .94192 L
.81852 .95163 L
.81566 .96061 L
.8154 .96134 L
.81195 .97106 L
.80853 .98077 L
.98077 .98077 L
F
0 g
.98077 .44418 m
.98002 .44658 L
.97713 .45629 L
.97424 .46601 L
.97127 .47572 L
.97106 .4764 L
.9682 .48543 L
.9651 .49514 L
.9622 .50486 L
.96134 .50838 L
.95939 .51457 L
.95627 .52428 L
.95324 .53399 L
.95163 .54016 L
.95051 .54371 L
.94737 .55342 L
.94428 .56313 L
.94192 .5717 L
.94156 .57284 L
.93842 .58256 L
.93527 .59227 L
.93245 .60198 L
.93221 .60302 L
.9294 .61169 L
.92622 .62141 L
.92326 .63112 L
.92249 .63411 L
.92031 .64083 L
.91711 .65054 L
.91405 .66026 L
.91278 .66497 L
.91115 .66997 L
.90793 .67968 L
.9048 .68939 L
.90307 .6956 L
.90192 .69911 L
.89868 .70882 L
.8955 .71853 L
.89336 .72601 L
.89262 .72824 L
.88936 .73796 L
.88614 .74767 L
.88364 .75617 L
.88324 .75738 L
.87997 .76709 L
.87671 .77681 L
.87393 .7861 L
.87379 .78652 L
.8705 .79623 L
.86721 .80594 L
Mistroke
.86425 .81566 L
.86422 .81579 L
.86095 .82537 L
.85764 .83508 L
.85463 .84479 L
.85451 .84524 L
.85132 .85451 L
.84798 .86422 L
.84493 .87393 L
.84479 .87445 L
.84161 .88364 L
.83825 .89336 L
.83518 .90307 L
.83508 .90342 L
.83181 .91278 L
.82843 .92249 L
.82537 .93214 L
.82535 .93221 L
.82193 .94192 L
.81852 .95163 L
.81566 .96061 L
.8154 .96134 L
.81195 .97106 L
.80853 .98077 L
Mfstroke
.8 g
.98077 .46854 m
.97877 .47572 L
.97597 .48543 L
.97298 .49514 L
.97106 .50089 L
.96964 .50486 L
.96557 .51457 L
.96403 .52428 L
.96134 .53304 L
.96101 .53399 L
.9572 .54371 L
.95518 .55342 L
.9522 .56313 L
.95163 .56495 L
.94865 .57284 L
.94628 .58256 L
.94328 .59227 L
.94192 .59663 L
.93994 .60198 L
.93562 .61169 L
.93431 .62141 L
.93221 .62812 L
.93111 .63112 L
.92703 .64083 L
.92527 .65054 L
.92249 .65938 L
.92218 .66026 L
.91827 .66997 L
.91617 .67968 L
.91311 .68939 L
.91278 .6904 L
.90936 .69911 L
.90701 .70882 L
.90393 .71853 L
.90307 .72118 L
.90033 .72824 L
.89561 .73796 L
.89468 .74767 L
.89336 .75175 L
.89119 .75738 L
.88665 .76709 L
.88537 .77681 L
.88364 .7821 L
.88195 .78652 L
.87753 .79623 L
.87599 .80594 L
.87393 .81222 L
.87262 .81566 L
.86828 .82537 L
.86653 .83508 L
.86422 .8421 L
.86319 .84479 L
.8589 .85451 L
.85701 .86422 L
.85451 .87175 L
.85367 .87393 L
.84939 .88364 L
.8474 .89336 L
.84479 .90116 L
.84406 .90307 L
.83977 .91278 L
.83773 .92249 L
.83508 .93034 L
.83436 .93221 L
.83003 .94192 L
.82797 .95163 L
.82537 .95927 L
.82456 .96134 L
.82016 .97106 L
.81812 .98077 L
.98077 .98077 L
F
0 g
.98077 .46854 m
.97877 .47572 L
.97597 .48543 L
.97298 .49514 L
.97106 .50089 L
.96964 .50486 L
.96557 .51457 L
.96403 .52428 L
.96134 .53304 L
.96101 .53399 L
.9572 .54371 L
.95518 .55342 L
.9522 .56313 L
.95163 .56495 L
.94865 .57284 L
.94628 .58256 L
.94328 .59227 L
.94192 .59663 L
.93994 .60198 L
.93562 .61169 L
.93431 .62141 L
.93221 .62812 L
.93111 .63112 L
.92703 .64083 L
.92527 .65054 L
.92249 .65938 L
.92218 .66026 L
.91827 .66997 L
.91617 .67968 L
.91311 .68939 L
.91278 .6904 L
.90936 .69911 L
.90701 .70882 L
.90393 .71853 L
.90307 .72118 L
.90033 .72824 L
.89561 .73796 L
.89468 .74767 L
.89336 .75175 L
.89119 .75738 L
.88665 .76709 L
.88537 .77681 L
.88364 .7821 L
.88195 .78652 L
.87753 .79623 L
.87599 .80594 L
.87393 .81222 L
.87262 .81566 L
.86828 .82537 L
.86653 .83508 L
Mistroke
.86422 .8421 L
.86319 .84479 L
.8589 .85451 L
.85701 .86422 L
.85451 .87175 L
.85367 .87393 L
.84939 .88364 L
.8474 .89336 L
.84479 .90116 L
.84406 .90307 L
.83977 .91278 L
.83773 .92249 L
.83508 .93034 L
.83436 .93221 L
.83003 .94192 L
.82797 .95163 L
.82537 .95927 L
.82456 .96134 L
.82016 .97106 L
.81812 .98077 L
Mfstroke
.7 g
.98077 .56148 m
.98028 .56313 L
.97738 .57284 L
.97439 .58256 L
.97138 .59227 L
.97106 .59331 L
.96837 .60198 L
.9669 .61169 L
.96265 .62141 L
.96134 .62495 L
.95941 .63112 L
.95845 .64083 L
.95385 .65054 L
.95163 .65635 L
.95039 .66026 L
.94735 .66997 L
.945 .67968 L
.94192 .6875 L
.94131 .68939 L
.93824 .69911 L
.93612 .70882 L
.93221 .7184 L
.93216 .71853 L
.92907 .72824 L
.92717 .73796 L
.92303 .74767 L
.92249 .74909 L
.91983 .75738 L
.91817 .76709 L
.91383 .77681 L
.91278 .77955 L
.91052 .78652 L
.90908 .79623 L
.90455 .80594 L
.90307 .80976 L
.90114 .81566 L
.89989 .82537 L
.8952 .83508 L
.89336 .83973 L
.89168 .84479 L
.89059 .85451 L
.88575 .86422 L
.88364 .86945 L
.88215 .87393 L
.87894 .88364 L
.8762 .89336 L
.87393 .89893 L
.87253 .90307 L
.86929 .91278 L
.86655 .92249 L
.86422 .92815 L
.86284 .93221 L
.85957 .94192 L
.85678 .95163 L
.85451 .95712 L
.85306 .96134 L
.84976 .97106 L
.84691 .98077 L
.98077 .98077 L
F
0 g
.98077 .56148 m
.98028 .56313 L
.97738 .57284 L
.97439 .58256 L
.97138 .59227 L
.97106 .59331 L
.96837 .60198 L
.9669 .61169 L
.96265 .62141 L
.96134 .62495 L
.95941 .63112 L
.95845 .64083 L
.95385 .65054 L
.95163 .65635 L
.95039 .66026 L
.94735 .66997 L
.945 .67968 L
.94192 .6875 L
.94131 .68939 L
.93824 .69911 L
.93612 .70882 L
.93221 .7184 L
.93216 .71853 L
.92907 .72824 L
.92717 .73796 L
.92303 .74767 L
.92249 .74909 L
.91983 .75738 L
.91817 .76709 L
.91383 .77681 L
.91278 .77955 L
.91052 .78652 L
.90908 .79623 L
.90455 .80594 L
.90307 .80976 L
.90114 .81566 L
.89989 .82537 L
.8952 .83508 L
.89336 .83973 L
.89168 .84479 L
.89059 .85451 L
.88575 .86422 L
.88364 .86945 L
.88215 .87393 L
.87894 .88364 L
.8762 .89336 L
.87393 .89893 L
.87253 .90307 L
.86929 .91278 L
.86655 .92249 L
Mistroke
.86422 .92815 L
.86284 .93221 L
.85957 .94192 L
.85678 .95163 L
.85451 .95712 L
.85306 .96134 L
.84976 .97106 L
.84691 .98077 L
Mfstroke
.6 g
.98077 .58584 m
.97886 .59227 L
.97592 .60198 L
.97167 .61169 L
.97106 .61783 L
.97021 .62141 L
.9673 .63112 L
.96416 .64083 L
.96134 .64959 L
.96114 .65054 L
.95839 .66026 L
.95525 .66997 L
.95209 .67968 L
.95163 .68113 L
.94939 .68939 L
.94627 .69911 L
.94309 .70882 L
.94192 .71244 L
.94031 .71853 L
.93723 .72824 L
.93402 .73796 L
.93221 .74351 L
.93115 .74767 L
.92811 .75738 L
.92489 .76709 L
.92249 .77436 L
.92189 .77681 L
.91892 .78652 L
.91569 .79623 L
.91278 .80497 L
.91255 .80594 L
.90966 .81566 L
.90641 .82537 L
.90316 .83508 L
.90307 .83534 L
.90032 .84479 L
.89706 .85451 L
.89378 .86422 L
.89336 .86548 L
.8909 .87393 L
.88764 .88364 L
.88433 .89336 L
.88364 .89538 L
.88141 .90307 L
.87813 .91278 L
.8748 .92249 L
.87393 .92504 L
.87184 .93221 L
.86855 .94192 L
.86518 .95163 L
.86422 .95445 L
.86219 .96134 L
.85888 .97106 L
.85549 .98077 L
.98077 .98077 L
F
0 g
.98077 .58584 m
.97886 .59227 L
.97592 .60198 L
.97167 .61169 L
.97106 .61783 L
.97021 .62141 L
.9673 .63112 L
.96416 .64083 L
.96134 .64959 L
.96114 .65054 L
.95839 .66026 L
.95525 .66997 L
.95209 .67968 L
.95163 .68113 L
.94939 .68939 L
.94627 .69911 L
.94309 .70882 L
.94192 .71244 L
.94031 .71853 L
.93723 .72824 L
.93402 .73796 L
.93221 .74351 L
.93115 .74767 L
.92811 .75738 L
.92489 .76709 L
.92249 .77436 L
.92189 .77681 L
.91892 .78652 L
.91569 .79623 L
.91278 .80497 L
.91255 .80594 L
.90966 .81566 L
.90641 .82537 L
.90316 .83508 L
.90307 .83534 L
.90032 .84479 L
.89706 .85451 L
.89378 .86422 L
.89336 .86548 L
.8909 .87393 L
.88764 .88364 L
.88433 .89336 L
.88364 .89538 L
.88141 .90307 L
.87813 .91278 L
.8748 .92249 L
.87393 .92504 L
.87184 .93221 L
.86855 .94192 L
.86518 .95163 L
Mistroke
.86422 .95445 L
.86219 .96134 L
.85888 .97106 L
.85549 .98077 L
Mfstroke
.5 g
.98077 .60607 m
.97675 .61169 L
.97505 .62141 L
.97295 .63112 L
.97106 .63813 L
.97028 .64083 L
.96735 .65054 L
.96434 .66026 L
.96135 .66997 L
.96134 .66998 L
.95844 .67968 L
.95542 .68939 L
.9524 .69911 L
.95163 .7016 L
.94947 .70882 L
.94645 .71853 L
.9434 .72824 L
.94192 .73299 L
.94043 .73796 L
.93741 .74767 L
.93433 .75738 L
.93221 .76415 L
.93133 .76709 L
.9283 .77681 L
.92521 .78652 L
.92249 .79508 L
.92215 .79623 L
.91913 .80594 L
.91602 .81566 L
.91291 .82537 L
.91278 .82578 L
.90989 .83508 L
.90676 .84479 L
.90363 .85451 L
.90307 .85624 L
.90058 .86422 L
.89743 .87393 L
.89427 .88364 L
.89336 .88647 L
.89119 .89336 L
.88803 .90307 L
.88484 .91278 L
.88364 .91647 L
.88174 .92249 L
.87856 .93221 L
.87534 .94192 L
.87393 .94622 L
.87221 .95163 L
.86901 .96134 L
.86577 .97106 L
.86422 .97572 L
.8626 .98077 L
.98077 .98077 L
F
0 g
.98077 .60607 m
.97675 .61169 L
.97505 .62141 L
.97295 .63112 L
.97106 .63813 L
.97028 .64083 L
.96735 .65054 L
.96434 .66026 L
.96135 .66997 L
.96134 .66998 L
.95844 .67968 L
.95542 .68939 L
.9524 .69911 L
.95163 .7016 L
.94947 .70882 L
.94645 .71853 L
.9434 .72824 L
.94192 .73299 L
.94043 .73796 L
.93741 .74767 L
.93433 .75738 L
.93221 .76415 L
.93133 .76709 L
.9283 .77681 L
.92521 .78652 L
.92249 .79508 L
.92215 .79623 L
.91913 .80594 L
.91602 .81566 L
.91291 .82537 L
.91278 .82578 L
.90989 .83508 L
.90676 .84479 L
.90363 .85451 L
.90307 .85624 L
.90058 .86422 L
.89743 .87393 L
.89427 .88364 L
.89336 .88647 L
.89119 .89336 L
.88803 .90307 L
.88484 .91278 L
.88364 .91647 L
.88174 .92249 L
.87856 .93221 L
.87534 .94192 L
.87393 .94622 L
.87221 .95163 L
.86901 .96134 L
.86577 .97106 L
Mistroke
.86422 .97572 L
.8626 .98077 L
Mfstroke
.4 g
.98077 .62534 m
.97869 .63112 L
.97589 .64083 L
.97311 .65054 L
.97106 .65747 L
.97021 .66026 L
.96723 .66997 L
.96424 .67968 L
.96134 .68938 L
.96134 .68939 L
.95836 .69911 L
.95534 .70882 L
.95238 .71853 L
.95163 .72107 L
.94942 .72824 L
.94638 .73796 L
.94338 .74767 L
.94192 .75253 L
.94042 .75738 L
.93736 .76709 L
.93432 .77681 L
.93221 .78377 L
.93135 .78652 L
.92829 .79623 L
.92521 .80594 L
.92249 .81477 L
.92222 .81566 L
.91914 .82537 L
.91604 .83508 L
.91301 .84479 L
.91278 .84555 L
.90993 .85451 L
.9068 .86422 L
.90373 .87393 L
.90307 .87609 L
.90065 .88364 L
.8975 .89336 L
.89439 .90307 L
.89336 .9064 L
.8913 .91278 L
.88813 .92249 L
.88499 .93221 L
.88364 .93647 L
.88187 .94192 L
.87868 .95163 L
.87551 .96134 L
.87393 .9663 L
.87238 .97106 L
.86916 .98077 L
.98077 .98077 L
F
0 g
.98077 .62534 m
.97869 .63112 L
.97589 .64083 L
.97311 .65054 L
.97106 .65747 L
.97021 .66026 L
.96723 .66997 L
.96424 .67968 L
.96134 .68938 L
.96134 .68939 L
.95836 .69911 L
.95534 .70882 L
.95238 .71853 L
.95163 .72107 L
.94942 .72824 L
.94638 .73796 L
.94338 .74767 L
.94192 .75253 L
.94042 .75738 L
.93736 .76709 L
.93432 .77681 L
.93221 .78377 L
.93135 .78652 L
.92829 .79623 L
.92521 .80594 L
.92249 .81477 L
.92222 .81566 L
.91914 .82537 L
.91604 .83508 L
.91301 .84479 L
.91278 .84555 L
.90993 .85451 L
.9068 .86422 L
.90373 .87393 L
.90307 .87609 L
.90065 .88364 L
.8975 .89336 L
.89439 .90307 L
.89336 .9064 L
.8913 .91278 L
.88813 .92249 L
.88499 .93221 L
.88364 .93647 L
.88187 .94192 L
.87868 .95163 L
.87551 .96134 L
.87393 .9663 L
.87238 .97106 L
.86916 .98077 L
s
.3 g
.98077 .64556 m
.97924 .65054 L
.97637 .66026 L
.97346 .66997 L
.97106 .67778 L
.97046 .67968 L
.96738 .68939 L
.96429 .69911 L
.96156 .70882 L
.96134 .70977 L
.95856 .71853 L
.95544 .72824 L
.95252 .73796 L
.95163 .74154 L
.94968 .74767 L
.94654 .75738 L
.9435 .76709 L
.94192 .77308 L
.94073 .77681 L
.93758 .78652 L
.93447 .79623 L
.93221 .80441 L
.93171 .80594 L
.92855 .81566 L
.92539 .82537 L
.92259 .83508 L
.92249 .8355 L
.91946 .84479 L
.91627 .85451 L
.91332 .86422 L
.91278 .86636 L
.9103 .87393 L
.90708 .88364 L
.90403 .89336 L
.90307 .89699 L
.90106 .90307 L
.89782 .91278 L
.89471 .92249 L
.89336 .92739 L
.89176 .93221 L
.8885 .94192 L
.88533 .95163 L
.88364 .95755 L
.88238 .96134 L
.8791 .97106 L
.87588 .98077 L
.98077 .98077 L
F
0 g
.98077 .64556 m
.97924 .65054 L
.97637 .66026 L
.97346 .66997 L
.97106 .67778 L
.97046 .67968 L
.96738 .68939 L
.96429 .69911 L
.96156 .70882 L
.96134 .70977 L
.95856 .71853 L
.95544 .72824 L
.95252 .73796 L
.95163 .74154 L
.94968 .74767 L
.94654 .75738 L
.9435 .76709 L
.94192 .77308 L
.94073 .77681 L
.93758 .78652 L
.93447 .79623 L
.93221 .80441 L
.93171 .80594 L
.92855 .81566 L
.92539 .82537 L
.92259 .83508 L
.92249 .8355 L
.91946 .84479 L
.91627 .85451 L
.91332 .86422 L
.91278 .86636 L
.9103 .87393 L
.90708 .88364 L
.90403 .89336 L
.90307 .89699 L
.90106 .90307 L
.89782 .91278 L
.89471 .92249 L
.89336 .92739 L
.89176 .93221 L
.8885 .94192 L
.88533 .95163 L
.88364 .95755 L
.88238 .96134 L
.8791 .97106 L
.87588 .98077 L
s
.2 g
.98077 .66994 m
.98076 .66997 L
.97804 .67968 L
.9752 .68939 L
.97214 .69911 L
.97106 .70227 L
.96865 .70882 L
.96426 .71853 L
.96324 .72824 L
.96134 .73441 L
.96007 .73796 L
.95602 .74767 L
.95439 .75738 L
.95163 .76635 L
.95137 .76709 L
.94755 .77681 L
.94549 .78652 L
.94248 .79623 L
.94192 .79803 L
.93891 .80594 L
.93652 .81566 L
.93351 .82537 L
.93221 .82949 L
.93012 .83508 L
.92573 .84479 L
.92447 .85451 L
.92249 .86075 L
.92122 .86422 L
.91705 .87393 L
.91536 .88364 L
.91278 .89179 L
.91221 .89336 L
.9082 .90307 L
.9062 .91278 L
.9031 .92249 L
.90307 .9226 L
.89922 .93221 L
.89696 .94192 L
.89385 .95163 L
.89336 .95315 L
.89011 .96134 L
.88767 .97106 L
.88453 .98077 L
.98077 .98077 L
F
0 g
.98077 .66994 m
.98076 .66997 L
.97804 .67968 L
.9752 .68939 L
.97214 .69911 L
.97106 .70227 L
.96865 .70882 L
.96426 .71853 L
.96324 .72824 L
.96134 .73441 L
.96007 .73796 L
.95602 .74767 L
.95439 .75738 L
.95163 .76635 L
.95137 .76709 L
.94755 .77681 L
.94549 .78652 L
.94248 .79623 L
.94192 .79803 L
.93891 .80594 L
.93652 .81566 L
.93351 .82537 L
.93221 .82949 L
.93012 .83508 L
.92573 .84479 L
.92447 .85451 L
.92249 .86075 L
.92122 .86422 L
.91705 .87393 L
.91536 .88364 L
.91278 .89179 L
.91221 .89336 L
.9082 .90307 L
.9062 .91278 L
.9031 .92249 L
.90307 .9226 L
.89922 .93221 L
.89696 .94192 L
.89385 .95163 L
.89336 .95315 L
.89011 .96134 L
.88767 .97106 L
.88453 .98077 L
s
.3 g
.98077 .76287 m
.97952 .76709 L
.97659 .77681 L
.97359 .78652 L
.97106 .79471 L
.97058 .79623 L
.96758 .80594 L
.96565 .81566 L
.96169 .82537 L
.96134 .82632 L
.95861 .83508 L
.95707 .84479 L
.95283 .85451 L
.95163 .85772 L
.94958 .86422 L
.94848 .87393 L
.94392 .88364 L
.94192 .88889 L
.94049 .89336 L
.93743 .90307 L
.93497 .91278 L
.93221 .91981 L
.93134 .92249 L
.92825 .93221 L
.92597 .94192 L
.92249 .95048 L
.92212 .95163 L
.919 .96134 L
.91689 .97106 L
.91284 .98077 L
.98077 .98077 L
F
0 g
.98077 .76287 m
.97952 .76709 L
.97659 .77681 L
.97359 .78652 L
.97106 .79471 L
.97058 .79623 L
.96758 .80594 L
.96565 .81566 L
.96169 .82537 L
.96134 .82632 L
.95861 .83508 L
.95707 .84479 L
.95283 .85451 L
.95163 .85772 L
.94958 .86422 L
.94848 .87393 L
.94392 .88364 L
.94192 .88889 L
.94049 .89336 L
.93743 .90307 L
.93497 .91278 L
.93221 .91981 L
.93134 .92249 L
.92825 .93221 L
.92597 .94192 L
.92249 .95048 L
.92212 .95163 L
.919 .96134 L
.91689 .97106 L
.91284 .98077 L
s
.4 g
.98077 .78722 m
.97808 .79623 L
.97513 .80594 L
.9716 .81566 L
.97106 .81921 L
.96949 .82537 L
.96647 .83508 L
.96332 .84479 L
.96134 .85098 L
.9605 .85451 L
.95757 .86422 L
.9544 .87393 L
.95163 .88251 L
.95138 .88364 L
.94859 .89336 L
.94542 .90307 L
.94225 .91278 L
.94192 .91382 L
.93953 .92249 L
.93638 .93221 L
.93318 .94192 L
.93221 .9449 L
.93039 .95163 L
.92726 .96134 L
.92403 .97106 L
.92249 .97572 L
.92117 .98077 L
.98077 .98077 L
F
0 g
.98077 .78722 m
.97808 .79623 L
.97513 .80594 L
.9716 .81566 L
.97106 .81921 L
.96949 .82537 L
.96647 .83508 L
.96332 .84479 L
.96134 .85098 L
.9605 .85451 L
.95757 .86422 L
.9544 .87393 L
.95163 .88251 L
.95138 .88364 L
.94859 .89336 L
.94542 .90307 L
.94225 .91278 L
.94192 .91382 L
.93953 .92249 L
.93638 .93221 L
.93318 .94192 L
.93221 .9449 L
.93039 .95163 L
.92726 .96134 L
.92403 .97106 L
.92249 .97572 L
.92117 .98077 L
s
.5 g
.98077 .80745 m
.97619 .81566 L
.97456 .82537 L
.97228 .83508 L
.97106 .83952 L
.96952 .84479 L
.96655 .85451 L
.96354 .86422 L
.96134 .87136 L
.9606 .87393 L
.95765 .88364 L
.95462 .89336 L
.95163 .90298 L
.95161 .90307 L
.94868 .91278 L
.94564 .92249 L
.94259 .93221 L
.94192 .93437 L
.93964 .94192 L
.93659 .95163 L
.93352 .96134 L
.93221 .96553 L
.93054 .97106 L
.92748 .98077 L
.98077 .98077 L
F
0 g
.98077 .80745 m
.97619 .81566 L
.97456 .82537 L
.97228 .83508 L
.97106 .83952 L
.96952 .84479 L
.96655 .85451 L
.96354 .86422 L
.96134 .87136 L
.9606 .87393 L
.95765 .88364 L
.95462 .89336 L
.95163 .90298 L
.95161 .90307 L
.94868 .91278 L
.94564 .92249 L
.94259 .93221 L
.94192 .93437 L
.93964 .94192 L
.93659 .95163 L
.93352 .96134 L
.93221 .96553 L
.93054 .97106 L
.92748 .98077 L
s
.6 g
.98077 .82672 m
.97791 .83508 L
.97516 .84479 L
.97235 .85451 L
.97106 .85885 L
.96943 .86422 L
.96644 .87393 L
.96346 .88364 L
.96134 .89077 L
.96056 .89336 L
.95756 .90307 L
.95454 .91278 L
.95163 .92246 L
.95162 .92249 L
.94861 .93221 L
.94558 .94192 L
.9426 .95163 L
.94192 .95392 L
.93961 .96134 L
.93655 .97106 L
.93353 .98077 L
.98077 .98077 L
F
0 g
.98077 .82672 m
.97791 .83508 L
.97516 .84479 L
.97235 .85451 L
.97106 .85885 L
.96943 .86422 L
.96644 .87393 L
.96346 .88364 L
.96134 .89077 L
.96056 .89336 L
.95756 .90307 L
.95454 .91278 L
.95163 .92246 L
.95162 .92249 L
.94861 .93221 L
.94558 .94192 L
.9426 .95163 L
.94192 .95392 L
.93961 .96134 L
.93655 .97106 L
.93353 .98077 L
s
.7 g
.98077 .84695 m
.97847 .85451 L
.9756 .86422 L
.97267 .87393 L
.97106 .87916 L
.96965 .88364 L
.96655 .89336 L
.96351 .90307 L
.96134 .91116 L
.96083 .91278 L
.95773 .92249 L
.95463 .93221 L
.95186 .94192 L
.95163 .94293 L
.94885 .95163 L
.94571 .96134 L
.94277 .97106 L
.94192 .97448 L
.9399 .98077 L
.98077 .98077 L
F
0 g
.98077 .84695 m
.97847 .85451 L
.9756 .86422 L
.97267 .87393 L
.97106 .87916 L
.96965 .88364 L
.96655 .89336 L
.96351 .90307 L
.96134 .91116 L
.96083 .91278 L
.95773 .92249 L
.95463 .93221 L
.95186 .94192 L
.95163 .94293 L
.94885 .95163 L
.94571 .96134 L
.94277 .97106 L
.94192 .97448 L
.9399 .98077 L
s
.8 g
.98077 .87131 m
.98004 .87393 L
.9773 .88364 L
.97442 .89336 L
.97127 .90307 L
.97106 .90367 L
.96761 .91278 L
.96541 .92249 L
.96245 .93221 L
.96134 .93579 L
.95909 .94192 L
.95472 .95163 L
.9536 .96134 L
.95163 .96771 L
.95043 .97106 L
.94637 .98077 L
.98077 .98077 L
F
0 g
.98077 .87131 m
.98004 .87393 L
.9773 .88364 L
.97442 .89336 L
.97127 .90307 L
.97106 .90367 L
.96761 .91278 L
.96541 .92249 L
.96245 .93221 L
.96134 .93579 L
.95909 .94192 L
.95472 .95163 L
.9536 .96134 L
.95163 .96771 L
.95043 .97106 L
.94637 .98077 L
s
.7 g
.98077 .96424 m
.97875 .97106 L
.9758 .98077 L
.98077 .98077 L
F
0 g
.98077 .96424 m
.97875 .97106 L
.9758 .98077 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00`_ooool2o`0000;ooooo0_l0
002Pooooo`00`_ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgJ3ooooo0033ooooo`04omgMgOl0
003o410@olc<c:7ooooo0033ooooo`04onk^k_lQ8B7o410@onk^kZ7ooooo0033ooooo`04ob4Q8Omg
MgOoMgMgoc8b<Z7ooooo0032ooooo`;o00000_ooool2o`000:3ooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0011oooo
o`;o000000?o410@ooooooooool08oooool5o`00023ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0T
ooooo`Go00009_ooool2o`000003oa0@4?oooooooooo02?ooooo00Gok^k^oc8b<_l0003o410@olc<
c00Tooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`08Oooool4o`000008oa0@4?ooooooooooonk^k_lb
<S;o0000oc8b<_o^k^h3ooooo`00@_ooool00ol0003oooooooooo`0Tooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@08?ooool01OmgMgOoV9RHoooooonHV9SoMgMg02Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A00Wooooo`03o`000?oooooooooo02Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@0Tooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B408oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00oooool003Oooooo1_l00002ooooo`Go00007Oooool6o`0000?ooooo00?oV9RHob4Q
8Oo^k^h08Oooool01Ol@413ooooooooooooooooo410@02Gooooo00?oV9RHob4Q8Oo^k^h09Oooool5
o`0002Gooooo00Go0000ooooooooooooooooo`00000Tooooo`05o`000?ooooooooooooooool00000
8oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool003oooooo
00CoA4A4omgMgOoooooo0000:?ooool00onHV9So8B4Qonk^kP0Pooooo`05o`000?oooooooooooooo
ool000009_ooool00onHV9So8B4Qonk^kP0Tooooo`04odA4A?oMgMgoooooo`0002Kooooo00Go0000
oiRHV?ooooooV9RHob4Q8@0Tooooo`05oc8b<_nHV9SooooooiRHV?lb<S808oooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool003oooooo00CogMgMoeEEEOoooooo
0000:Oooool00omgMgOoIVIVooooo`0Oooooo`05o`000?ooooooooooooooool000009oooool00omg
MgOoIVIVooooo`0Sooooo`04omgMgOmEEEGoooooo`0002Kooooo00Go0000oeEEEOl0003o410@olc<
c00Tooooo`05olc<c?l0003o0000o`000?o<c<`08oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000000oooool0043ooooo00?oMgMgolc<c?l00000:_ooool00ol0003ooooo
ooooo`0Nooooo`05oa0@4?ooooooooooooooool@4100:?ooool00ol0003oooooooooo`0Sooooo`03
ogMgMoo<c<co000002Kooooo00?oEEEEohN7Qoooool09_ooool01Ol@413o^[Zjoooooonj^[[o410@
02?ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo0010oooo
o`03onk^k_m4A4Co000002Kooooo00Go0000okZj^_ooooooV9RHoa0@400Pooooo`05ogMgMonHV9So
oooooiRHV?mgMgL09?ooool01Ol0003o^[ZjoooooonHV9So410@02Gooooo00?ok^k^odA4A?l00000
9_ooool00ooMgMgo410@oiRHV00Vooooo`05o`000?nj^[[ooooookZj^_l000008oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool0047ooooo00?oMgMgo`000?oo
ool09Oooool01OnHV9So410@o`000?lQ8B7oc<c<023ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0T
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`09_ooool00omgMgOo0000ooooo`0Vooooo`04olc<c?m4
A4Co0000oa0@42Cooooo00GoZJVYoa0@4?l0003o410@ojVYZ@0Qooooo`03oeEEEOmVIVKo000000Co
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`009?ooooooo`0004?o00000_ooool002Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`7o00000Oooool1ooooo`009?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo0Ol00001ooooo`7ooooo000T
ooooo`03o`000?oooooooooo0?oooooo?oooool1o`00007ooooo0Oooool002Cooooo00?o0000oooo
ooooool0ooooooloooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`3oooooocoo
oooo0Ol00001ooooo`7ooooo000Tooooo`;o00003oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`00
00;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Kooooo00Go0000
ooooooooooooooooo`000002ooooo`03o`000?oooooo000000;ooooo00Go0000oooooooooooooooo
o`000008ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooool000000_ooool00ol0003o
ooooo`000009ooooo`08o`000?ooooooooooo`000?oooooo0000ooooool00002ooooo`03o`000?oo
oooo000000Wooooo00Wo0000ooooool0003oooooo`000?oooooo0000ooooool000000_ooool00ol0
003oooooooooo`06ooooo`05o`000?oooooo0000ooooool000001_ooool2o`0000;ooooo000Toooo
o`03o`000?oooooooooo00?ooooo2_moOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<
01KoC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI
00_oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@07oiVIV@03o`000?moOgooOgmo
00?oOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00Boda<C003o`000?mVIVKoIVIV
00;oIVIV00Go0000ogmoOomoOgooOgmoo`000003oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000
olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Go
0000ofIVI_mVIVKoIVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4co
C4a<o`000002ofIVIP03o`000?moOgoo000000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<
c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl01_l0003oIVIVofIVI_l0003oC4a<o`0000Wo
<c<c00So0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000;oVIVI00?o0000ok>c/ol000002Oo<
c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c
00Ko<c<c00Oo0000oda<C?l0003oIVIVo`000?moOgoo000000Gooooo0Ol00001ooooo`7ooooo000T
ooooo`03o`000?oooooooooo00?ooooo2OmoOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4co
C4a<01KoC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWo
VIVI00_oVIVI00?o0000ok>c/onc/k<06?nc/k<00ol0003oVIVIoiVIV@07oiVIV@03o`000?moOgoo
Ogmo00?oOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00Boda<C005o`000?mVIVKo
IVIVofIVI_l000000omoOgl01Ol0003oVIVIoiVIVOnIVIWo000000Go/k>c00?o0000olc<c?o<c<`0
1Oo<c<`00ol0003o/k>cok>c/`02ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01?l0003o
IVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002
ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01?l0003o/k>c
ok>c/ol00002oiVIV@06o`000?moOgooOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`07
oc<c<`03o`000?m<C4coC4a<00;o00000_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<co
c<c<00Ooc<c<00_o0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`000009oc<c
<`07o`000?m<C4co0000ofIVI_l0003oOgmoo`000005ooooo`7o00000Oooool1ooooo`009?ooool0
0ol0003oooooooooo`03ooooo`WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00F
oda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;
oiVIV@03o`000?nc/k?o/k>c01So/k>c00?o0000oiVIVOnIVIT01onIVIT00ol0003oOgmoogmoO`03
ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<C4`04_m<C4`00ol0003oIVIVofIVIP02
ofIVIP05o`000?moOgooOgmoogmoOol000000onIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<
c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00onc/k<01?l0003oVIVIoiVIVOl00002ogmoO`05o`00
0?mVIVKoIVIVofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`07o`000?m<C4coC4a<oda<
C?l0003oIVIVo`000003ogmoO`04o`000?nIVIWoVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<
c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co
00002?lc<c<02?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo00000_nIVIT00ol0003o/k>co`00
0009olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c
<olc<c<01_lc<c<01ol0003oC4a<o`000?mVIVKo0000ogmoOol000001_ooool1o`00007ooooo0Ooo
ool002Cooooo00?o0000ooooooooool00oooool7ogmoO`;o00003OmVIVH00ol0003oC4a<oda<C00F
oda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;
oiVIV@;o00006Onc/k<00ol0003oVIVIoiVIV@07oiVIV@03o`000?moOgooOgmo00?oOgmo00?o0000
ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00Coda<C005o`000?mVIVKoIVIVofIVI_l000000omo
Ogl01Ol0003oVIVIoiVIVOnIVIWo000000Go/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>c
ok>c/`02ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00004oda<
C003o`000?lc<c?o<c<c00Go<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgoo
Ogmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@05
o`000?moOgoo0000ofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`0:o`000?m<C4coC4a<
o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01oo<c<`02Ol0003o
/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Oo
0000oda<C?l0003oIVIVo`000?moOgoo000000Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`00
0?oooooooooo00?ooooo1_moOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<01KoC4a<
00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI
00?o0000ok>c/onc/k<06?nc/k<00ol0003oVIVIoiVIV@07oiVIV@03o`000?moOgooOgmo00CoOgmo
00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00Boda<C003o`000?mVIVKoIVIV00;oIVIV
00Go0000ogmoOomoOgooOgmoo`000003oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<
c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01?l0
003oIVIVofIVI_l00004oda<C003o`000?lc<c?o<c<c00Go<c<c00Go0000oda<C?m<C4coC4a<o`00
0002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`01?l0003o
/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l000000om<C4`00ol0003o<c<coc<c<`06
oc<c<`03o`000?m<C4co000000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<
c<coc<c<00Koc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`0
0ol0003o<c<coc<c<`06oc<c<`07o`000?m<C4co0000ofIVI_l0003oOgmoo`000006ooooo`7o0000
0Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`KoOgmo00?o0000ofIVI_mVIVH02omV
IVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?mo
Ogl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01So/k>c00?o0000oiVIVOnIVIT01onI
VIT00ol0003oOgmoogmoO`04ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<C4`04om<
C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Go0000oiVIVOnIVIWoVIVIo`000006ok>c/`03
o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo0000
00;oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`05oc<c<`05o`000?m<C4co
C4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Wo
c<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<
o`0000So<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000onc/k<00ol0
003oc<c<olc<c006olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<
00?o0000oc<c<olc<c<01_lc<c<00ol0003oC4a<o`000002ofIVIP;o000000?oVIVIooooooooool0
1?ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool4ogmoO`;o00003?mV
IVH2o`0001OoC4a<0_l0000=ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onI
VIT00ol0003o/k>cok>c/`0Hok>c/`03o`000?nIVIWoVIVI00OoVIVI00?o0000ogmoOomoOgl01?mo
Ogl00ol0003oIVIVofIVIP04ofIVIP03o`000?m<C4coC4a<01;oC4a<00?o0000ofIVI_mVIVH00_mV
IVH01Ol0003oOgmoogmoOomoOgoo000000?oVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<
olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Co0000oiVIVOnIVIWo00000_moOgl2o`0000;o
IVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH0
1?l0003oOgmoogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Woc<c<00Ko0000ok>c/onc/k?o
0000oiVIVOl00002ogmoO`03o`000?mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<02_l0
003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ko
c<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00009oc<c<`08
o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIT6ooooo`7o00000Oooool1ooooo`009?ooool0
0ol0003oooooooooo`03ooooo`?oOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00G
oda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;
oiVIV@03o`000?nc/k?o/k>c01So/k>c00?o0000oiVIVOnIVIT01onIVIT00ol0003oOgmoogmoO`05
ogmoO`03o`000?mVIVKoIVIV00CoIVIV00?o0000oda<C?m<C4`04_m<C4`01Ol0003oIVIVofIVI_mV
IVKo000000CoOgmo00Go0000oiVIVOnIVIWoVIVIo`000005ok>c/`03o`000?o<c<coc<c<00Coc<c<
00?o0000ok>c/onc/k<00onc/k<01?l0003oVIVIoiVIVOl00002ogmoO`05o`000?mVIVKoIVIVofIV
I_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH0
1?l0003oOgmoogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Woc<c<00So0000ok>c/onc/k?o
0000oiVIVOl0003oOgmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`0:o`000?m<
C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`0
3?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000Wo<c<c00Wo0000
oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl000001Oooool1o`00007ooooo0Oooool002Cooooo
00?o0000ooooooooool00oooool2ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`0
5om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT0
2onIVIT00ol0003o/k>cok>c/`0Hok>c/`03o`000?nIVIWoVIVI00OoVIVI00?o0000ogmoOomoOgl0
1OmoOgl00ol0003oIVIVofIVIP04ofIVIP03o`000?m<C4coC4a<01;oC4a<00?o0000ofIVI_mVIVH0
0_mVIVH01Ol0003oOgmoogmoOomoOgoo000000?oVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003o
c<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Co0000oiVIVOnIVIWo00000_moOgl00ol0
003oIVIVofIVIP02ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Go0000oda<C?m<C4coC4a<o`00
0002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`01_l0003o
/k>cok>c/ol0003oVIVIo`0000;oOgmo00?o0000ofIVI_l000000om<C4`00ol0003o<c<coc<c<`06
oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<
c?o<c<`01_o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003
o`000?lc<c?o<c<c00Ko<c<c00?o0000oda<C?m<C4`00_l000001OmoOgoo0000oiVIVOnIVIWo0000
00Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo00?oOgmoo`000?mV
IVH03?mVIVH00ol0003oC4a<oda<C00Foda<C0;o00003OmVIVH00ol0003oOgmoogmoO`08ogmoO`03
o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<2o`0000[oVIVI00?o0000ogmoOomo
Ogl01?moOgl00ol0003oIVIVofIVIP04ofIVIP03o`000?m<C4coC4a<01;oC4a<00?o0000ofIVI_mV
IVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000?oVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0
003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002
ogmoO`05o`000?mVIVKoIVIVofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<
C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@04o`000?nc/k?o/k>co`00
00Soc<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo00?o0000ofIVI_l000000_m<
C4`00ol0003o<c<coc<c<`07oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVI
o`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo
0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00?o0000oda<C?m<C4`00_l000001?mo
Ogoo0000oiVIVOl00006ooooo`7o00000Oooool1ooooo`009?ooool2o`0000Cooooo00?oOgmoo`00
0?mVIVH02omVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmo
OomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVI
VOnIVIT02OnIVIT00ol0003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<
C?m<C4`04om<C4`00ol0003oIVIVofIVIP02ofIVIP05o`000?moOgooOgmoogmoOol000000onIVIT0
0ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00_nc/k<0
1Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000003oda<C003o`00
0?lc<c?o<c<c00Ko<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00Go0000oiVI
VOnIVIWoVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nI
VIT01_l0003oOgmoogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01olc<c<02_l0003o
C4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<
00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c
<`06oc<c<`03o`000?m<C4coC4a<00;o000000CoOgmoo`000?nIVIWo00001Oooool2o`0000;ooooo
000Tooooo`03o`000?oooooooooo00?ooooo00?o0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<oda<
C00Goda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVI
V@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02OnIVIT00ol0003oOgmoogmo
O`05ogmoO`03o`000?mVIVKoIVIV00CoIVIV00?o0000oda<C?m<C4`04_m<C4`00ol0003oIVIVofIV
IP02ofIVIP05o`000?moOgooOgmoogmoOol000000onIVIT00ol0003o/k>cok>c/`04ok>c/`03o`00
0?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;o
Ogmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go<c<c00Go0000oda<
C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>c
o`000007olc<c007o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000002ogmoO`03o`000?mVIVKo0000
00;oC4a<00?o0000oc<c<olc<c<01olc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000
oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00?o0000ok>c/ol000000_nIVIT2o`000005
ofIVI_l0003oC4a<oda<C?l000002Olc<c<01_l0003oC4a<o`000?mVIVKo0000ogmoO`;o000000?o
/k>cooooooooool01?ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool<
ofIVIP03o`000?m<C4coC4a<01KoC4a<0_l0000=ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000
oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`;o00002onIVIT00ol0003oOgmoogmoO`05
ogmoO`03o`000?mVIVKoIVIV00CoIVIV00?o0000oda<C?m<C4`04_m<C4`00ol0003oIVIVofIVIP02
ofIVIP03o`000?moOgooOgmo00;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000005ok>c/`03o`000?o<
c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo
00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;o
C4a<00Ko0000ofIVI_mVIVKo0000ogmoOol00002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<
c<`01ol0003o/k>cok>c/onc/k?o0000oiVIVOl000000_moOgl00ol0003oIVIVo`000002oda<C003
o`000?lc<c?o<c<c00Oo<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000
0_nc/k<00ol0003oc<c<olc<c007olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo
000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?l0003oIVIV00;o000000?o
VIVIo`000?nc/k<01_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool;
ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08
ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0:
oiVIV@03o`000?moOgooOgmo00GoOgmo00?o0000ofIVI_mVIVH01?mVIVH00ol0003oC4a<oda<C00B
oda<C003o`000?mVIVKoIVIV00;oIVIV00?o0000ogmoOomoOgl00_moOgl01Ol0003oVIVIoiVIVOnI
VIWo000000Go/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`04o`000?nI
VIWoVIVIo`0000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go
<c<c00?o0000oda<C?m<C4`00_m<C4`01_l0003oIVIVofIVI_l0003oOgmoo`0000;oVIVI00Go0000
ok>c/onc/k?o/k>co`000008olc<c007o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000002ogmoO`03
o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01olc<c<00ol0003oC4a<o`000002ofIVIP05
o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c009o`000?nc/k?o0000
oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<
oda<C?l0003oIVIV00;o000000?oVIVIo`000?nc/k<01_ooool1o`00007ooooo0Oooool002Cooooo
00?o0000ooooooooool00oooool:ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH0
2omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<0
5onc/k<00ol0003oVIVIoiVIV@0:oiVIV@03o`000?moOgooOgmo00GoOgmo00?o0000ofIVI_mVIVH0
1?mVIVH00ol0003oC4a<oda<C00Boda<C003o`000?mVIVKoIVIV00?oIVIV00Go0000ogmoOomoOgoo
Ogmoo`000003oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o
/k>cok>c/`02ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00004
oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01_l0003oIVIVofIVI_l0
003oOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c007o`000?nc/k?o/k>cok>c
/ol0003oVIVIo`000002ogmoO`03o`000?mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<0
2_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<
00Ooc<c<00?o0000ok>c/onc/k<00_l000001omoOgoo0000ofIVI_mVIVKo0000oda<C?l000002Olc
<c<01?l0003oC4a<o`000?mVIVH2o`000005oiVIVOl0003o/k>cok>c/ol000001Oooool1o`00007o
oooo0Oooool002Cooooo00?o0000ooooooooool00oooool9ofIVIP03o`000?m<C4coC4a<01OoC4a<
00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI
00?o0000ok>c/onc/k<05_nc/k<2o`0000coVIVI00?o0000ogmoOomoOgl01OmoOgl00ol0003oIVIV
ofIVIP04ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmo
ogmoOomoOgoo000000?oVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c004olc<c003
o`000?nc/k?o/k>c00?o/k>c00Co0000oiVIVOnIVIWo00000omoOgl01?l0003oIVIVofIVI_l00004
oda<C003o`000?lc<c?o<c<c00Go<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?mo
OgooOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c004o`000?nc/k?o/k>co`00
00;oVIVI00Ko0000ogmoOomoOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00_o
0000oda<C?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<co
c<c<00Koc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0
003o<c<coc<c<`07oc<c<`04o`000?m<C4co0000ofIVIP;o000000GoVIVIo`000?nc/k?o/k>co`00
0005ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`SoIVIV00?o0000
oda<C?m<C4`05_m<C4`2o`0000goIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0<
oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`05
ogmoO`03o`000?mVIVKoIVIV00GoIVIV00?o0000oda<C?m<C4`04om<C4`00ol0003oIVIVofIVIP02
ofIVIP05o`000?moOgooOgmoogmoOol000000onIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<
c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00onc/k<01?l0003oVIVIoiVIVOl00003ogmoO`04o`00
0?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01Olc<c<01Ol0003oC4a<oda<C?m<C4co0000
00;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Co
0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So
<c<c00_o0000oda<C?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c/`03o`00
0?o<c<coc<c<00Koc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<
C4`00ol0003o<c<coc<c<`07oc<c<`04o`000?m<C4co0000ofIVIP;o000000GoVIVIo`000?nc/k?o
/k>co`000005ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`OoIVIV
00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP;o00002_moOgl00ol0003oVIVI
oiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmo
ogmoO`05ogmoO`03o`000?mVIVKoIVIV00GoIVIV00?o0000oda<C?m<C4`04om<C4`00ol0003oIVIV
ofIVIP02ofIVIP05o`000?moOgooOgmoogmoOol000000onIVIT00ol0003o/k>cok>c/`04ok>c/`03
o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00onc/k<01?l0003oVIVIoiVIVOl00003ogmo
O`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l0
0002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c004
o`000?nc/k?o/k>co`0000;oVIVI00Ko0000ogmoOomoOgoo0000ofIVI_l00002oda<C003o`000?lc
<c?o<c<c00Oo<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<0
0ol0003oc<c<olc<c006olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl2o`0000;oC4a<
00?o0000oc<c<olc<c<01olc<c<01?l0003oC4a<o`000?mVIVH2o`0000;oVIVI00?o0000ok>c/ol0
00001_ooool1o`00007ooooo0Oooool001_ooooo0_l000000ol@413oooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo1_mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV
00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@;o00005onc/k<2o`0000coVIVI
00?o0000ogmoOomoOgl01OmoOgl00ol0003oIVIVofIVIP05ofIVIP03o`000?m<C4coC4a<01?oC4a<
00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000CoVIVI00?o0000ok>c/onc
/k<00onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Go0000oiVIVOnI
VIWoVIVIo`000002ogmoO`05o`000?mVIVKoIVIVofIVI_l000000om<C4`2o`0000Oo<c<c00Go0000
oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o
/k>co`000008olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0
003oC4a<oda<C?l00009oc<c<`03o`000?m<C4co000000;oIVIV00Go0000ogmoOol0003oVIVIo`00
0002ok>c/`03o`000?o<c<coc<c<00Koc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`00
0?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<o`000?mVIVH00_l0
00001OnIVIWo0000ok>c/onc/k?o000000Kooooo0Ol00001ooooo`7ooooo000Looooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool00oooool5ofIVIP03o`000?m<C4coC4a<01KoC4a<0_l0
000<ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c
/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl01_moOgl00ol0003oIVIVofIV
IP05ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmo
OomoOgoo000000CoVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c004olc<c003o`00
0?nc/k?o/k>c00?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`05o`000?mVIVKoIVIVofIV
I_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH0
1?l0003oOgmoogmoOol00002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01?l0003o/k>c
ok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<00ol0
003oC4a<o`000002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006
olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c
<olc<c<01_lc<c<01Ol0003oC4a<oda<C?l0003oIVIV00;o000000GoVIVIo`000?nc/k?o/k>co`00
0006ooooo`7o00000Oooool1ooooo`004Oooool6o`0000;ooooo1Ol00006ooooo`?o00000oooool4
ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`09
ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;
oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<C00C
oda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgooOgmoo`000004oiVIV@03o`000?nc
/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`04ok>c/`04o`000?nI
VIWoVIVIo`0000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko
<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Go0000
ok>c/onc/k?o/k>co`000008olc<c009o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000?moOgoo0000
00;oIVIV00Co0000oda<C?m<C4co00002Olc<c<00ol0003oC4a<o`000002ofIVIP05o`000?moOgoo
0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`0000;oVIVI
0_l000001OmVIVKo0000oda<C?m<C4co000000Wo<c<c00Ko0000oda<C?l0003oIVIVo`000?moOgl2
o`0000;o/k>c00?o0000olc<c?ooool00oooool3o`0000;ooooo000Iooooo`04odA4A?oMgMgooooo
o`0000Oooooo00?o0000ooooooooool00oooool3ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000
ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000
ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000
ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<C00Coda<C003o`000?mVIVKoIVIV00;oIVIV00?o0000
ogmoOomoOgl00_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Ko/k>c00?o0000olc<c?o<c<`00oo<
c<`00ol0003o/k>cok>c/`04ok>c/`04o`000?nIVIWoVIVIo`0000?oOgmo00Co0000ofIVI_mVIVKo
00001?m<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0
003oOgmoogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Go0000ok>c/onc/k?o/k>c
o`000002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<01?l0003o
C4a<oda<C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006
olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c
<olc<c<01_lc<c<01ol0003oC4a<oda<C?l0003oIVIVo`000?moOgl00_l00002ok>c/`03o`000?o<
c<cooooo00Gooooo0Ol00001ooooo`7ooooo000Iooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o
0000ooooooooool00oooool2ofIVIP;o00005om<C4`2o`0000coIVIV00?o0000ogmoOomoOgl02Omo
Ogl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT03?nI
VIT00ol0003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV00KoIVIV00?o0000oda<C?m<C4`04om<
C4`00ol0003oIVIVofIVIP02ofIVIP03o`000?moOgooOgmo00;oOgmo00Go0000oiVIVOnIVIWoVIVI
o`000006ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<01?nc/k<01?l0003oVIVI
oiVIVOl00003ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0
003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01?l0003o/k>cok>c
/ol00008olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT00ol0003oOgmoo`000002ofIVIP04
o`000?m<C4coC4a<o`0000So<c<c00Co0000oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nI
VIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?mo
Ogoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Oo0000oda<C?m<C4co0000ofIV
I_l0003oOgmo00;o00000_nc/k<00ol0003oc<c<ooooo`05ooooo`7o00000Oooool1ooooo`006_oo
ool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo00?ooooo00?oIVIVo`000?m<C4`05om<
C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onI
VIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI0_l00007ogmoO`03o`000?mV
IVKoIVIV00KoIVIV00?o0000oda<C?m<C4`04om<C4`00ol0003oIVIVofIVIP02ofIVIP03o`000?mo
OgooOgmo00;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000006ok>c/`03o`000?o<c<coc<c<00?oc<c<
00?o0000ok>c/onc/k<01?nc/k<01?l0003oVIVIoiVIVOl00003ogmoO`04o`000?mVIVKoIVIVo`00
00CoC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000
ogmoOomoOgoo00000_nIVIT01?l0003o/k>cok>c/ol00008olc<c005o`000?nc/k?o/k>cok>c/ol0
00000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000Wo<c<c00[o0000oda<
C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c007olc<c003
o`000?nc/k?o/k>c00;o000000OoOgmoo`000?mVIVKoIVIVo`000?m<C4co000000So<c<c00co0000
oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00002olc<c0Kooooo0Ol00001
ooooo`7ooooo000Jooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool00oooool00ol0
003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0
003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0
003oOgmoogmoO`06ogmoO`03o`000?mVIVKoIVIV00KoIVIV00?o0000oda<C?m<C4`04om<C4`00ol0
003oIVIVofIVIP03ofIVIP05o`000?moOgooOgmoogmoOol000001?nIVIT00ol0003o/k>cok>c/`04
ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00onc/k<01Ol0003oVIVIoiVIVOnI
VIWo000000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go<c<c
00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`03o`000?nIVIWo000000?o
/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmo
Ool000000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Go
0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00[o0000ok>c/onc/k?o
0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0<o`000?m<
C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00000_o<c<`6ooooo`7o00000Ooo
ool1ooooo`006oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000
oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0:ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000
oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000
ogmoOomoOgl01_moOgl00ol0003oIVIVofIVIP06ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000
ofIVI_mVIVH00omVIVH01Ol0003oOgmoogmoOomoOgoo000000CoVIVI00?o0000ok>c/onc/k<00onc
/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Go0000oiVIVOnIVIWoVIVI
o`000002ogmoO`05o`000?mVIVKoIVIVofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`03
o`000?m<C4coC4a<00;oC4a<00Ko0000ofIVI_mVIVKo0000ogmoOol00002oiVIV@05o`000?nc/k?o
/k>cok>c/ol000002?o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmoOol00000
0_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Go0000ogmo
Ool0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00[o0000ok>c/onc/k?o0000oiVI
VOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0<o`000?m<C4coC4a<
o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00000_o<c<`6ooooo`7o00000Oooool1oooo
o`009?ooool00ol0003oooooooooo`03oooooaSoC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003o
OgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003o
VIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH01omVIVH00ol0003o
C4a<oda<C00Boda<C003o`000?mVIVKoIVIV00?oIVIV00Go0000ogmoOomoOgooOgmoo`000004oiVI
V@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c
/`04o`000?nIVIWoVIVIo`0000?oOgmo00Go0000ofIVI_mVIVKoIVIVo`000003oda<C003o`000?lc
<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;o
VIVI00Co0000ok>c/onc/k?o00002Oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@04o`000?moOgoo
Ogmoo`0000;oIVIV00?o0000oda<C?l000002Olc<c<01?l0003oC4a<oda<C?l00002ofIVIP;o0000
0_nIVIT01?l0003o/k>cok>c/ol00008olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0
003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01ol0003oC4a<oda<C?l0003oIVIVo`00
0?moOgl00_l00002ok>c/`03o`000?o<c<coc<c<00Kooooo0Ol00001ooooo`7ooooo000Tooooo`03
o`000?oooooooooo00?ooooo5om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00So
Ogmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00co
VIVI00?o0000ogmoOomoOgl01omoOgl00ol0003oIVIVofIVIP06ofIVIP03o`000?m<C4coC4a<01?o
C4a<00?o0000ofIVI_mVIVH00omVIVH01Ol0003oOgmoogmoOomoOgoo000000CoVIVI00?o0000ok>c
/onc/k<00onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Go0000oiVI
VOnIVIWoVIVIo`000002ogmoO`05o`000?mVIVKoIVIVofIVI_l000000om<C4`00ol0003o<c<coc<c
<`06oc<c<`03o`000?m<C4coC4a<00;oC4a<00Ko0000ofIVI_mVIVKo0000ogmoOol00002oiVIV@05
o`000?nc/k?o/k>cok>c/ol000002Oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo
000000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<00ol0003oC4a<o`000002ofIVIP05o`000?mo
Ogoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c006o`000?nc/k?o/k>co`000?nI
VIWo00000_moOgl2o`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<03?l0003oC4a<oda<C?l0003o
IVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000?oc<c<1_ooool1o`00007ooooo0Oooool002Co
oooo00?o0000ooooooooool00ooooolFoda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomo
Ogl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@;o00005onc/k<2o`0000goVIVI00?o0000ogmoOomo
Ogl01omoOgl00ol0003oIVIVofIVIP05ofIVIP;o00005Om<C4`00ol0003oIVIVofIVIP03ofIVIP05
o`000?moOgooOgmoogmoOol000001?nIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<
00?oc<c<00?o0000ok>c/onc/k<01?nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Go0000
ofIVI_mVIVKoIVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<
o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<
c007o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000002ogmoO`06o`000?mVIVKoIVIVo`000?m<C4co
00002_lc<c<00ol0003oC4a<o`000002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0
003oc<c<olc<c006olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;o
C4a<00?o0000oc<c<olc<c<01_lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVI
VOl0003o/k>co`0000?oc<c<1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool0
0ooooolEoda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVI
oiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003oOgmo
ogmoO`07ogmoO`03o`000?mVIVKoIVIV00GoIVIV00?o0000oda<C?m<C4`05Om<C4`00ol0003oIVIV
ofIVIP03ofIVIP05o`000?moOgooOgmoogmoOol000001?nIVIT00ol0003o/k>cok>c/`04ok>c/`03
o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<01?nc/k<01Ol0003oVIVIoiVIVOnIVIWo0000
00;oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4co
C4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@05o`000?nc/k?o/k>cok>c/ol0
00002?o<c<`01ol0003o/k>cok>c/onc/k?o0000oiVIVOl000000_moOgl01_l0003oIVIVofIVI_l0
003oC4a<o`0000[o<c<c00?o0000oda<C?l000000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o
/k>c00?o0000olc<c?o<c<`01_o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIV
I_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmo
o`000?nIVIWo0000ok>c/ol00003olc<c0Kooooo0Ol00001ooooo`7ooooo000Tooooo`;o00001?oo
oolDoda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVI
V@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmo
O`07ogmoO`03o`000?mVIVKoIVIV00KoIVIV00?o0000oda<C?m<C4`05?m<C4`00ol0003oIVIVofIV
IP03ofIVIP05o`000?moOgooOgmoogmoOol000001?nIVIT00ol0003o/k>cok>c/`04ok>c/`03o`00
0?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<01?nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;o
Ogmo00Go0000ofIVI_mVIVKoIVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<
C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>c
o`000008olc<c007o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000002ogmoO`04o`000?mVIVKoIVIV
o`0000;oC4a<00?o0000oc<c<olc<c<01olc<c<00ol0003oC4a<o`000002ofIVIP05o`000?moOgoo
0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`0000;oVIVI
0_l000001OmVIVKo0000oda<C?m<C4co000000So<c<c00co0000oda<C?m<C4co0000ofIVI_l0003o
Ogmoo`000?nIVIWo0000ok>c/ol00004olc<c0Gooooo0_l00002ooooo`009?ooool00ol0003ooooo
ooooo`03oooooa;oC4a<0_l0000=ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT0
2onIVIT00ol0003o/k>cok>c/`0Fok>c/`;o00003OnIVIT00ol0003oOgmoogmoO`07ogmoO`03o`00
0?mVIVKoIVIV00KoIVIV00?o0000oda<C?m<C4`05?m<C4`00ol0003oIVIVofIVIP03ofIVIP03o`00
0?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`04ok>c/`03o`00
0?o<c<coc<c<00;oc<c<0_l00005ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01?l0003o
IVIVofIVI_l00004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0
003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01oo<
c<`01ol0003o/k>cok>c/onc/k?o0000oiVIVOl000000_moOgl00ol0003oIVIVo`000003oda<C003
o`000?lc<c?o<c<c00Ko<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`03o`000?nIVIWo
000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo
0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00co0000oda<C?m<C4co0000ofIVI_l0
003oOgmoo`000?nIVIWo0000ok>c/ol00004olc<c0Kooooo0Ol00001ooooo`7ooooo000Tooooo`03
o`000?oooooooooo00?ooooo4_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00So
Ogmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00co
VIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP06ofIVIP03o`000?m<C4coC4a<01Co
C4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00;o
VIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c00Co
/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000
oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co
0000oiVIVOnIVIWo00000_nc/k<00ol0003oc<c<olc<c007olc<c007o`000?nc/k?o/k>cok>c/ol0
003oVIVIo`000002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01olc<c<01_l0
003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<
c006olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000
oc<c<olc<c<01_lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>c
o`0000Coc<c<1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00ooooolAoda<
C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVI
V@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`08ogmo
O`03o`000?mVIVKoIVIV00KoIVIV00?o0000oda<C?m<C4`05?m<C4`00ol0003oIVIVofIVIP03ofIV
IP03o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`04ok>c
/`03o`000?o<c<coc<c<00;oc<c<00?o0000ok>c/onc/k<01Onc/k<01?l0003oVIVIoiVIVOl00003
ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<
C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003o
c<c<olc<c006olc<c007o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000002ogmoO`04o`000?mVIVKo
IVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?m<C4`2o`0000;oOgmo
00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c003o`000?nc/k?o/k>c00;o0000
00OoOgmoo`000?mVIVKoIVIVo`000?m<C4co000000So<c<c00co0000oda<C?m<C4co0000ofIVI_l0
003oOgmoo`000?nIVIWo0000ok>c/ol00005olc<c0Kooooo0Ol00001ooooo`7ooooo000Tooooo`03
o`000?oooooooooo00?ooooo3om<C4`2o`0000goIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003o
VIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02_nIVIT2o`0000[o
Ogmo00?o0000ofIVI_mVIVH01_mVIVH00ol0003oC4a<oda<C00Doda<C003o`000?mVIVKoIVIV00?o
IVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c00Co
/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`04ok>c/`05o`000?nIVIWoVIVIoiVI
VOl000000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000CoC4a<00?o0000oc<c<olc<c<01Olc<c<0
0ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo0000
0onc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Ko0000ogmoOomo
Ogoo0000ofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Ko0000oda<C?m<C4co0000ofIV
I_l00002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02_l0003o/k>c
ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00co
0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00005olc<c0Kooooo0Ol0
0001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo3om<C4`00ol0003oIVIVofIVIP0;
ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0G
ok>c/`03o`000?nIVIWoVIVI00[oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP07
ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH00_mVIVH00ol0003oOgmoogmoO`03
ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c003
olc<c003o`000?nc/k?o/k>c00Co/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`05o`000?mV
IVKoIVIVofIVI_l000001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<
00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00002ok>c/`03o`000?o<c<coc<c<
00Ooc<c<00Co0000ok>c/onc/k?o00000_nIVIT01_l0003oOgmoogmoOol0003oIVIVo`0000?oC4a<
00?o0000oc<c<olc<c<01_lc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00?o0000oiVI
VOl000000_nc/k<00ol0003oc<c<olc<c006olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmo
Ool0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<03?l0003oC4a<oda<C?l0003oIVIV
o`000?moOgoo0000oiVIVOl0003o/k>co`0000Goc<c<1_ooool1o`00007ooooo0Oooool002Cooooo
00?o0000ooooooooool00oooool>oda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl0
2?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT0
2_nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00OoIVIV00?o0000oda<C?m<C4`0
5?m<C4`00ol0003oIVIVofIVIP03ofIVIP03o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT0
0_nIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<0
1?nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<
C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002
ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01ol0003o/k>cok>c
/onc/k?o0000oiVIVOl000000_moOgl00ol0003oIVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko
<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000
olc<c?o<c<`01_o<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo0_l00002oda<C003o`00
0?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH2o`000005oiVIVOl0003o/k>cok>c
/ol000001Oo<c<`6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`co
C4a<0_l0000=ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o
/k>cok>c/`0Fok>c/`;o00003?nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00Oo
IVIV00?o0000oda<C?m<C4`05?m<C4`00ol0003oIVIVofIVIP03ofIVIP03o`000?moOgooOgmo00;o
Ogmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`05ok>c/`03o`000?o<c<coc<c<00;o
c<c<00?o0000ok>c/onc/k<01?nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Co0000ofIV
I_mVIVKo00001Om<C4`00ol0003o<c<coc<c<`05oc<c<`05o`000?m<C4coC4a<oda<C?l000000omV
IVH01?l0003oOgmoogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Go0000ok>c/onc
/k?o/k>co`000002oiVIV@06o`000?moOgooOgmoo`000?mVIVKo00000om<C4`00ol0003o<c<coc<c
<`06oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl00ol0003oVIVIo`000002ok>c/`03
o`000?o<c<coc<c<00Koc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000
0_m<C4`00ol0003o<c<coc<c<`06oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003o
VIVIo`000?nc/k?o00001_o<c<`6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003ooooooooo
o`03ooooo`coC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nI
VIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0:oiVIV@03o`000?mo
OgooOgmo00WoOgmo00?o0000ofIVI_mVIVH01omVIVH00ol0003oC4a<oda<C00Eoda<C003o`000?mV
IVKoIVIV00?oIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@02oiVIV@03o`000?nc
/k?o/k>c00Go/k>c00?o0000olc<c?o<c<`00_o<c<`00ol0003o/k>cok>c/`04ok>c/`05o`000?nI
VIWoVIVIoiVIVOl000000omoOgl01?l0003oIVIVofIVI_l00005oda<C003o`000?lc<c?o<c<c00Go
<c<c00Go0000oda<C?m<C4coC4a<o`000003ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Co0000
ok>c/onc/k?o00002?o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Ko0000ogmoOomoOgoo
0000ofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Ko0000oda<C?m<C4co0000ofIVI_l0
0002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02_l0003o/k>cok>c
/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00?o0000
oda<C?l000000_mVIVH01ol0003oOgmoo`000?nIVIWo0000ok>c/ol000001_o<c<`6ooooo`7o0000
0Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`_oC4a<00?o0000ofIVI_mVIVH02omV
IVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05onc
/k<00ol0003oVIVIoiVIV@0:oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02?mV
IVH00ol0003oC4a<oda<C00Doda<C003o`000?mVIVKoIVIV00?oIVIV00?o0000ogmoOomoOgl00omo
Ogl01Ol0003oVIVIoiVIVOnIVIWo000000Oo/k>c00?o0000olc<c?o<c<`00_o<c<`00ol0003o/k>c
ok>c/`05ok>c/`04o`000?nIVIWoVIVIo`0000?oOgmo00Co0000ofIVI_mVIVKo00001Om<C4`00ol0
003o<c<coc<c<`05oc<c<`05o`000?m<C4coC4a<oda<C?l000000omVIVH01?l0003oOgmoogmoOol0
0002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@06
o`000?moOgooOgmoo`000?mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4co
C4a<o`0000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<
00Co0000ok>c/onc/k?o00000_nIVIT2o`000005ofIVI_l0003oC4a<oda<C?l000002?lc<c<03?l0
003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Ooc<c<1_ooool1o`00
007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool:oda<C003o`000?mVIVKoIVIV00_o
IVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko
/k>c0_l0000<oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02?mVIVH00ol0003o
C4a<oda<C00Doda<C003o`000?mVIVKoIVIV00?oIVIV0_l00004ogmoO`03o`000?nIVIWoVIVI00;o
VIVI00?o0000ok>c/onc/k<01Onc/k<01Ol0003oc<c<olc<c?o<c<co000000Oo/k>c00Go0000oiVI
VOnIVIWoVIVIo`000002ogmoO`05o`000?mVIVKoIVIVofIVI_l000001?m<C4`00ol0003o<c<coc<c
<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVI
oiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVI
V@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<01_l0003oC4a<oda<C?l0
003oIVIVo`0000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c00:o`00
0?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc
<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Ooc<c<1_oo
ool1o`00007ooooo0Oooool002Cooooo0_l00004ooooo`SoC4a<0_l0000=ofIVIP03o`000?moOgoo
Ogmo00SoOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWo
VIVI00[oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP09ofIVIP03o`000?m<C4co
C4a<01CoC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWo
VIVI00;oVIVI00?o0000ok>c/onc/k<01Onc/k<01Ol0003oc<c<olc<c?o<c<co000000Oo/k>c00Go
0000oiVIVOnIVIWoVIVIo`000002ogmoO`05o`000?mVIVKoIVIVofIVI_l000001?m<C4`00ol0003o
<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0
003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`00
0002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<01_l0003oC4a<
oda<C?l0003oIVIVo`0000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<
c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc
<c<01_lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Oo
c<c<1Oooool2o`0000;ooooo000Tooooo`03o`000?oooooooooo00?ooooo1om<C4`00ol0003oIVIV
ofIVIP0;ofIVIP;o00002_moOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c
00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00WoIVIV
00?o0000oda<C?m<C4`05?m<C4`00ol0003oIVIVofIVIP03ofIVIP03o`000?moOgooOgmo00?oOgmo
00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`05ok>c/`05o`000?o<c<coc<c<olc<c?l0
00001onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`0
0ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00?oC4a<00Co0000ofIVI_mVIVKo00000_mo
Ogl01?l0003oVIVIoiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Co0000ok>c/onc/k?o
00000_nIVIT01_l0003oOgmoogmoOol0003oIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<0
1_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<
olc<c006olc<c004o`000?nc/k?o/k>cok>c/`;o000000GoOgmoo`000?mVIVKoIVIVo`000002oda<
C003o`000?lc<c?o<c<c00Go<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`;o000000?o
/k>co`000?o<c<`01oo<c<`6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03
ooooo`KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWo
VIVI00_oVIVI0_l0000Gok>c/`;o00003?nIVIT00ol0003oOgmoogmoO`08ogmoO`;o00002omVIVH0
0ol0003oC4a<oda<C00Doda<C003o`000?mVIVKoIVIV00CoIVIV00?o0000ogmoOomoOgl00_moOgl0
0ol0003oVIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c00Go/k>c00?o0000olc<c?o<c<`00_o<c<`0
0ol0003o/k>cok>c/`04ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01Ol0003oIVIVofIV
I_mVIVKo000000CoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`00
0?mVIVKoIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<
c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4co
C4a<o`0000So<c<c00Wo0000oda<C?m<C4coC4a<o`000?mVIVKo0000ogmoOol000000_nIVIT01?l0
003o/k>cok>c/ol00008olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`00
00;oC4a<00?o0000oc<c<olc<c<01_lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000
oiVIVOl0003o/k>co`0000Soc<c<1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000oooooooo
ool00oooool5oda<C0;o00003?mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00_o
VIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00So
Ogmo00?o0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<oda<C00Eoda<C003o`000?mVIVKoIVIV00Co
IVIV00Go0000ogmoOomoOgooOgmoo`000005oiVIV@03o`000?nc/k?o/k>c00Go/k>c00?o0000olc<
c?o<c<`00_o<c<`00ol0003o/k>cok>c/`04ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl0
1Ol0003oIVIVofIVI_mVIVKo000000CoC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<
C003oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003o
c<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT00ol0003oOgmoo`000002ofIV
IP04o`000?m<C4coC4a<o`0000So<c<c00Wo0000oda<C?m<C4coC4a<o`000?mVIVKo0000ogmoOol0
00000_nIVIT01?l0003o/k>cok>c/ol00008olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmo
Ool0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<03?l0003oC4a<oda<C?l0003oIVIV
o`000?moOgoo0000oiVIVOl0003o/k>co`0000Soc<c<00?o0000ooooooooool00oooool1o`00007o
oooo0Oooool002Cooooo00?o0000ooooooooool00oooool4oda<C003o`000?mVIVKoIVIV00_oIVIV
00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c
00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00[oIVIV
00?o0000oda<C?m<C4`05Om<C4`00ol0003oIVIVofIVIP04ofIVIP03o`000?moOgooOgmo00;oOgmo
00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`05ok>c/`03o`000?o<c<coc<c<00;oc<c<
00?o0000ok>c/onc/k<01?nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Go0000ofIVI_mV
IVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0
003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<
c<`00ol0003o/k>cok>c/`02ok>c/`05o`000?nIVIWo0000ogmoOol000000_mVIVH01?l0003oC4a<
oda<C?l00009oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl00ol0003oVIVIo`000002
ok>c/`03o`000?o<c<coc<c<00Koc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`;o0000
0_m<C4`00ol0003o<c<coc<c<`07oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo
000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003oooooooooo`03ooooo`7o00000Oooool1
ooooo`009?ooool00ol0003oooooooooo`03ooooo`?oC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0
003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0
003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02_mVIVH00ol0
003oC4a<oda<C00Eoda<C003o`000?mVIVKoIVIV00CoIVIV00?o0000ogmoOomoOgl00_moOgl00ol0
003oVIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c00Ko/k>c0ol000000oo<c<co0000ok>c/`06ok>c
/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000GoC4a<00?o
0000oc<c<olc<c<01Olc<c<01Ol0003oC4a<oda<C?m<C4co000000?oIVIV00Co0000ogmoOomoOgoo
00000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Oo0000ok>c/onc/k?o/k>co`000?nI
VIWo000000;oOgmo00Co0000ofIVI_mVIVKo00000_m<C4`00ol0003o<c<coc<c<`07oc<c<`08o`00
0?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVIV@03o`000?nc/k?o000000Woc<c<00[o0000
ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`07oc<c
<`0;o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol000002?o<c<`00ol0003o
ooooooooo`04ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`;oC4a<
0_l0000<ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>c
ok>c/`0Fok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl01omoOgl00ol0003oIVIV
ofIVIP0;ofIVIP03o`000?m<C4coC4a<01GoC4a<00?o0000ofIVI_mVIVH01?mVIVH00ol0003oOgmo
ogmoO`02ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01_nc/k<01?l0003o/k>c
ok>c/ol00008ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01Ol0003oIVIVofIVI_mVIVKo
000000CoC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000?oIVIV00Co
0000ogmoOomoOgoo00000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Oo0000ok>c/onc
/k?o/k>co`000?nIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo00000_m<C4`00ol0003o<c<coc<c
<`07oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVIV@03o`000?nc/k?o0000
00Woc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o
<c<coc<c<`07oc<c<`0;o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00000
2?o<c<`00ol0003oooooooooo`04ooooo`7o00000Oooool1ooooo`009?ooool00ol0003ooooooooo
o`03ooooo`03oda<C?l0003oIVIV00coIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVI
V@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT2o`0000WoOgmo00?o
0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Eoda<C003o`000?mVIVKoIVIV00CoIVIV00?o
0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c00Ko/k>c0_l0
0009ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01?l0003oIVIVofIVI_l00005oda<C003
o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmo
O`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01ol0003o/k>cok>c/onc
/k?o0000oiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo
<c<c00Co0000oda<C?m<C4co00000_mVIVH2o`0000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`0
1?l0003o/k>cok>c/ol00002oiVIV@;o000000GoIVIVo`000?m<C4coC4a<o`000009oc<c<`07o`00
0?m<C4co0000ofIVI_l0003oOgmoo`000002oiVIV@;o00002?o<c<`00ol0003o/k>cooooo`05oooo
o`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`03o`000?mVIVKoIVIV00_o
IVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko
/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_o
IVIV00?o0000oda<C?m<C4`05Om<C4`00ol0003oIVIVofIVIP04ofIVIP03o`000?moOgooOgmo00;o
Ogmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`06ok>c/`04o`000?o<c<coc<c<o`00
00Oo/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`05o`000?mVIVKoIVIVofIVI_l000001?m<
C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00?o0000ofIVI_mVIVH00_l0
00000omoOgoo0000o`000002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01?l0003o/k>c
ok>c/ol00002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<0
0ol0003oC4a<oda<C002o`000004ofIVI_l0003oOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o0000
2?o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc
<c?o<c<c00Ko<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol0
0008olc<c003o`000?nc/k?ooooo00Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooo
oooo00?ooooo00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWo
VIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0<oiVIV@03o`000?moOgoo
Ogmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Eoda<C003o`000?mVIVKo
IVIV00CoIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o
/k>c00Ko/k>c00Co0000olc<c?o<c<co00001onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo
00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<
C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000onc/k<0
0ol0003oc<c<olc<c005olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmo
Ool00002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0
003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00[o0000ok>c/onc/k?o0000oiVI
VOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0<o`000?m<C4coC4a<
o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00002?o<c<`00ol0003o/k>cooooo`05oooo
o`7o00000Oooool1ooooo`009?ooool2o`0000Cooooo3?mVIVH00ol0003oOgmoogmoO`09ogmoO`03
o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0<oiVIV@03
o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Eoda<C003
o`000?mVIVKoIVIV00CoIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@03oiVIV@03
o`000?nc/k?o/k>c00So/k>c0_l00007ok>c/`03o`000?nIVIWoVIVI00;oVIVI00Co0000ogmoOomo
Ogoo00001?mVIVH00ol0003oC4a<oda<C002oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<
C?m<C4`00om<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o
0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Ko0000ogmoOomoOgoo
0000ofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH0
1Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c
/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`05
o`000?m<C4coC4a<o`000?mVIVH00_l00002oiVIV@03o`000?nc/k?o000000Soc<c<00?o0000ok>c
/oooool01?ooool2o`0000;ooooo000Tooooo`03o`000?oooooooooo00?ooooo3?mVIVH00ol0003o
OgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003o
VIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003o
C4a<oda<C00Foda<C003o`000?mVIVKoIVIV00CoIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003o
VIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c00So/k>c00?o0000ok>c/onc/k<01_nc/k<01Ol0003o
VIVIoiVIVOnIVIWo000000?oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o
<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`05o`000?nI
VIWoVIVIoiVIVOl000000onc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c
00Ko0000oiVIVOnIVIWo0000ogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Co0000
oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<
00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV00Co0000oda<C?m<C4co00001olc
<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Soc<c<00Co
0000ok>c/onc/k?o00001Oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00ooo
ool;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT2o`0001Oo/k>c0_l0
000=oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<
C00Foda<C003o`000?mVIVKoIVIV00CoIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVI
V@02oiVIV@;o00004onc/k<01?l0003oVIVIoiVIVOnIVIT2o`0000;oOgmo00Go0000ofIVI_mVIVKo
IVIVo`000005oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003o
IVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`0
1Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Ko0000ogmoOomoOgoo0000ofIVI_l00003oda<C003
o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVI
V@04o`000?nc/k?o/k>co`0000Soc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mV
IVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmo
Ool0003oVIVIo`000?nc/k?o00002?o<c<`01?l0003o/k>cok>c/ol00005ooooo`7o00000Oooool1
ooooo`009?ooool00ol0003oooooooooo`03ooooo`[oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0
003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0
003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0
003oIVIVofIVIP04ofIVIP03o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0
003o/k>cok>c/`0Bok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01Ol0003oIVIVofIVI_mV
IVKo000000GoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mV
IVKoIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c005
o`000?nc/k?o/k>cok>c/ol000000_nIVIT01_l0003oOgmoogmoOol0003oIVIVo`0000?oC4a<00?o
0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI
00Co0000ok>c/onc/k?o00002?o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIV
I_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmo
o`000?nIVIWo0000ok>c/ol00008olc<c004o`000?nc/k?o/k>co`0000Gooooo0Ol00001ooooo`7o
oooo000Tooooo`03o`000?oooooooooo00?ooooo2OmVIVH00ol0003oOgmoogmoO`08ogmoO`03o`00
0?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0<oiVIV@03o`00
0?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`00
0?mVIVKoIVIV00CoIVIV00?o0000ogmoOomoOgl00omoOgl00ol0003oVIVIoiVIV@02oiVIV@03o`00
0?nc/k?o/k>c01;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000004ogmoO`04o`000?mVIVKoIVIVo`00
00GoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIV
o`0000;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc
/k?o/k>cok>c/ol000000_nIVIT01_l0003oOgmoogmoOol0003oIVIVo`0000?oC4a<00?o0000oc<c
<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP06o`000?moOgooOgmoo`000?nIVIWo0000
0_nc/k<00ol0003oc<c<olc<c006olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl2o`00
00;oC4a<00?o0000oc<c<olc<c<01olc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVI
o`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o0000ok>c/ol000001_ooool1o`00007ooooo
0Oooool002Cooooo00?o0000ooooooooool00oooool8ofIVIP03o`000?moOgooOgmo00SoOgmo00?o
0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`;o00003OnIVIT00ol0003oOgmoogmo
O`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIV
IP05ofIVIP03o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c
/`0Bok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01Ol0003oIVIVofIVI_mVIVKo000000Co
C4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C005o`000?mVIVKoIVIVofIV
I_l000000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000
ok>c/onc/k?o/k>co`000002oiVIV@06o`000?moOgooOgmoo`000?mVIVKo00000om<C4`00ol0003o
<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT00ol0
003o/k>co`000009olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<
C4co00002_lc<c<02_l0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k<2o`0000So
c<c<00?o0000ok>c/ol000001_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool0
0oooool7ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>c
ok>c/`0Fok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIV
ofIVIP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH01OmVIVH00ol0003oOgmo
ogmoO`02ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<04Onc/k<00ol0003oVIVI
oiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol000000omVIVH00ol0003oC4a<oda<C002oda<C003
o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo0000
00;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o
/k>cok>c/ol000000_nIVIT01_l0003oOgmoogmoOol0003oIVIVo`0000?oC4a<00?o0000oc<c<olc
<c<01Olc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o0000ogmoOol000000_nIVIT00ol0
003o/k>co`000009olc<c003o`000?nc/k?o/k>c00;o00000_moOgl01Ol0003oIVIVo`000?m<C4co
000000[o<c<c00_o0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`000009olc<
c003o`000?nc/k?o000000Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?o
oooo1_mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc
/k<05_nc/k<00ol0003oVIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mV
IVH02omVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00GoIVIV00?o0000ogmoOomo
Ogl00_moOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c01;o/k>c00Go0000oiVIVOnI
VIWoVIVIo`000003ogmoO`05o`000?mVIVKoIVIVofIVI_l000001?m<C4`00ol0003o<c<coc<c<`05
oc<c<`03o`000?m<C4coC4a<00;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`04o`000?nI
VIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;o
VIVI00Co0000ogmoOomoOgoo00000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`04o`000?m<C4co
C4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00008olc<c00:o`00
0?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01olc
<c<02ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o000000Woc<c<00Co0000
ok>c/ol0003oVIVI1_ooool1o`00007ooooo0Oooool001Wooooo1Ol00006ooooo`03o`000?oooooo
oooo00?ooooo1OmVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000
ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0:oiVIV@;o00002_moOgl00ol0003oIVIVofIVIP0:
ofIVIP;o00006Om<C4`00ol0003oIVIVofIVIP05ofIVIP03o`000?moOgooOgmo00;oOgmo00?o0000
oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0Bok>c/`04o`000?nIVIWoVIVIoiVIV@;o00000_mo
Ogl00ol0003oIVIVofIVIP02ofIVIP03o`000?m<C4coC4a<00;oC4a<00?o0000oc<c<olc<c<01Olc
<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000?oOgmo00Co0000oiVIVOnIVIWo
00000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT00ol0
003oOgmoo`000002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01?l0003oC4a<oda<C?l0
0002ofIVIP05o`000?moOgoo0000oiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c00:o`00
0?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc
<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Woc<c<00Go
0000ok>c/ol0003oVIVIo`000005ooooo`7o00000Oooool1ooooo`006Oooool01OnHV9So8B4Qonk^
k_ooooooA4A400Kooooo00?o0000ooooooooool00oooool4ofIVIP03o`000?moOgooOgmo00SoOgmo
00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00[oVIVI
00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<01SoC4a<
00?o0000ofIVI_mVIVH01OmVIVH00ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00?oVIVI
00?o0000ok>c/onc/k<04_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00?o0000ofIVI_mV
IVH00_mVIVH00ol0003oC4a<oda<C002oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<
C4`00_m<C4`01?l0003oIVIVofIVI_l00003ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000
olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00003oiVIV@03o`000?moOgoo000000;oIVIV00Go
0000oda<C?m<C4coC4a<o`000008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Go0000ogmoOol0
003oVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Goc<c<00Co0000ok>c/onc/k?o00000_nIVIT0
1Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<03?l0003oC4a<oda<
C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Woc<c<00Go0000ok>c/ol0003oVIVI
o`000005ooooo`7o00000Oooool1ooooo`004Oooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h01ooo
ool3o`0000?ooooo0omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o
0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0:oiVIV@03o`000?moOgooOgmo00WoOgmo00?o
0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00GoIVIV00?o
0000ogmoOomoOgl01?moOgl00ol0003oVIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c01;o/k>c00Go
0000oiVIVOnIVIWoVIVIo`000003ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`0
0_m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo
00000omoOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c
/onc/k?o/k>co`000002oiVIV@03o`000?moOgoo000000;oIVIV00Go0000oda<C?m<C4coC4a<o`00
0008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>c
ok>c/ol00008olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP04o`000?m<
C4coC4a<o`0000Oo<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc
/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o0000oiVIVOl000001?ooool3o`0000;ooooo
000Kooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool00oooool2ofIVIP03o`000?mo
OgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`;o00003?nI
VIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05om<
C4`00ol0003oIVIVofIVIP05ofIVIP03o`000?moOgooOgmo00CoOgmo00?o0000oiVIVOnIVIT00onI
VIT00ol0003o/k>cok>c/`0Aok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomoOgooOgmo
o`000003ofIVIP03o`000?m<C4coC4a<00?oC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<
oda<C003oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0
003oc<c<olc<c007olc<c007o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000002ogmoO`04o`000?mV
IVKoIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01olc<c<01?l0003oC4a<oda<C?l00002ofIVIP05
o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c00:o`000?nc/k?o/k>c
o`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02_l0003o
C4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<
00Go0000ok>c/ol0003o0000ogmoO`06ooooo`7o00000Oooool1ooooo`007?ooool00omgMgOoIVIV
ooooo`05ooooo`03o`000?oooooooooo00?ooooo00?oIVIVo`000?moOgl02OmoOgl00ol0003oVIVI
oiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmo
ogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIV
ofIVIP06ofIVIP03o`000?moOgooOgmo00?oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>c
ok>c/`0Bok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`000003ofIVIP03
o`000?m<C4coC4a<00?oC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C002oda<C004
o`000?mVIVKoIVIVo`0000?oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c007
olc<c007o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000;o
C4a<00?o0000oc<c<olc<c<01olc<c<01?l0003oC4a<oda<C?l00002ofIVIP05o`000?moOgoo0000
oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000
ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02_l0003oC4a<oda<C?l0003o
IVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/ol0
003o0000ogmoO`06ooooo`7o00000Oooool1ooooo`007Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00?ooooo00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03
o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`09ogmoO`03
o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP06ofIVIP03
o`000?moOgooOgmo00?oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0Cok>c/`05
o`000?nIVIWoVIVIoiVIVOl000000omoOgl00ol0003oIVIVofIVIP02ofIVIP03o`000?m<C4coC4a<
00;oC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C003oda<C004o`000?mVIVKoIVIV
o`0000?oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c007o`000?nc
/k?o/k>cok>c/ol0003oVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000;oC4a<00?o0000oc<c
<olc<c<01olc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgooOgmo00;o00000_nc/k<0
0ol0003oc<c<olc<c007olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`00
00;oC4a<00?o0000oc<c<olc<c<01olc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVI
o`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Ko0000ok>c/ol0003oVIVIo`000?moOgl6oooo
o`7o00000Oooool1ooooo`006Oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000oooo
ooooool00oooool:ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<2o`00
00coVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<
01OoC4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0003oOgmoogmoO`04ogmoO`03o`000?nIVIWoVIVI
00?oVIVI00?o0000ok>c/onc/k<04_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00?o0000
ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C002oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000
oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo0000
1?nc/k<00ol0003oc<c<olc<c005olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003o
OgmoogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Ko0000oda<C?m<C4coC4a<o`00
0?mVIVH2o`000004ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01oo<c<`03?l0003o
/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000[o<c<c00Wo0000oda<C?l0
003oIVIVo`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c007o`000?nc
/k?o0000oiVIVOl0003oOgmoo`000005ooooo`7o00000Oooool1ooooo`006Oooool01OnHV9So410@
o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool00oooool9ogmoO`03o`000?nIVIWoVIVI00co
VIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0:oiVIV@03o`000?moOgooOgmo00Wo
Ogmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00Oo
IVIV00?o0000ogmoOomoOgl01?moOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c01;o
/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<
C?m<C4`00_m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Go0000ofIV
I_mVIVKoIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01Oo<
c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01?l0003o
C4a<oda<C?l00008oc<c<`07o`000?m<C4coC4a<oda<C?l0003oIVIVo`000002ogmoO`03o`000?nI
VIWo000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?mo
Ogoo0000ofIVI_l0003oC4a<o`0000[o<c<c00_o0000oda<C?l0003oIVIVo`000?moOgoo0000oiVI
VOl0003o/k>co`000009olc<c007o`000?nc/k?o0000oiVIVOl0003oOgmoo`000005ooooo`7o0000
0Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`SoOgmo00?o0000oiVIVOnIVIT03?nI
VIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00[oVIVI00?o0000ogmoOomoOgl02Omo
Ogl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH01omV
IVH00ol0003oOgmoogmoO`04ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<04_nc
/k<00ol0003oVIVIoiVIV@02oiVIV@04o`000?moOgooOgmoo`0000CoIVIV00?o0000oda<C?m<C4`0
0_m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Go0000ofIVI_mVIVKo
IVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`01Ol0
003o/k>cok>c/onc/k?o000000;oVIVI00Oo0000ogmoOomoOgooOgmoo`000?mVIVKo000000?oC4a<
00?o0000oc<c<olc<c<01_lc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00?o0000oiVI
VOl000000_nc/k<00ol0003oc<c<olc<c007olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmo
Ool0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01olc<c<02Ol0003oC4a<o`000?mVIVKo0000
ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Oo0000ok>c/ol0003oVIVI
o`000?moOgoo000000Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo
1omoOgl00ol0003oVIVIoiVIV@0;oiVIV@;o00005onc/k<2o`0000coVIVI00?o0000ogmoOomoOgl0
2?moOgl2o`0000goIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP07ofIVIP03o`00
0?moOgooOgmo00CoOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0Bok>c/`03o`00
0?nIVIWoVIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`000003ofIVIP03o`000?m<C4coC4a<00?o
C4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C003oda<C004o`000?mVIVKoIVIVo`00
00?oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o
/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000So
<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00?o0000oiVIVOl000000_nc/k<0
0ol0003oc<c<olc<c007olc<c003o`000?nc/k?o000000;oVIVI00Go0000ogmoOol0003oIVIVo`00
0002oda<C003o`000?lc<c?o<c<c00Ko<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`00
0?nIVIWo0000ok>c/ol00009olc<c007o`000?nc/k?o0000oiVIVOl0003oOgmoo`000006ooooo`7o
00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`KoOgmo00?o0000oiVIVOnIVIT0
2onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl0
2?moOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH0
2?mVIVH00ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<0
4_nc/k<00ol0003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol000000omVIVH00ol0003o
C4a<oda<C003oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00om<C4`01?l0003o
IVIVofIVI_l00003ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`0
1Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01?l0003oC4a<
oda<C?l00008oc<c<`07o`000?m<C4coC4a<oda<C?l0003oIVIVo`000002ogmoO`03o`000?nIVIWo
000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`00ol0003o/k>co`000002oiVIV@05o`000?moOgoo
0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo
0000ogmoOol0003oVIVIo`000?nc/k?o00002Oo<c<`01ol0003o/k>co`000?nIVIWo0000ogmoOol0
00001_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool5ogmoO`03o`00
0?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`00
0?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH03?mVIVH00ol0003oC4a<oda<C00Goda<C003o`00
0?mVIVKoIVIV00SoIVIV00?o0000ogmoOomoOgl00omoOgl00ol0003oVIVIoiVIV@04oiVIV@03o`00
0?nc/k?o/k>c01;o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000?o
IVIV00?o0000oda<C?m<C4`01?m<C4`00ol0003o<c<coc<c<`03oc<c<`03o`000?m<C4coC4a<00?o
C4a<00Co0000ofIVI_mVIVKo00000omoOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<co
c<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV
00Co0000oda<C?m<C4co00002?lc<c<01ol0003oC4a<oda<C?m<C4co0000ofIVI_l000000_moOgl0
1?l0003oVIVIoiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00[o0000ok>c/onc/k?o0000
oiVIVOl0003oOgmoo`000?mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`0;o`000?m<C4co
0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol000002Oo<c<`00ol0003o/k>co`000002oiVI
V@;o000000?oIVIVooooooooool01?ooool1o`00007ooooo0Oooool002Cooooo00?o0000oooooooo
ool00oooool4ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003o
VIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH03?mVIVH00ol0003o
C4a<oda<C00Goda<C003o`000?mVIVKoIVIV00SoIVIV00?o0000ogmoOomoOgl00omoOgl00ol0003o
VIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c01;o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003o
OgmoogmoOomoOgoo000000CoIVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`04oc<c
<`03o`000?m<C4coC4a<00;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`05o`000?nIVIWo
VIVIoiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol00000
0_nIVIT01_l0003oOgmoogmoOol0003oIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01ol0
003oC4a<oda<C?m<C4co0000ofIVI_l000000_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<
c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;o
C4a<00?o0000oc<c<olc<c<01_lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVI
VOl0003o/k>co`0000Woc<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000001Ooo
ool1o`00007ooooo0Oooool002Cooooo0_l00004ooooo`?oOgmo00?o0000oiVIVOnIVIT02onIVIT0
0ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl0
0ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02?mVIVH0
0ol0003oOgmoogmoO`04ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<04_nc/k<0
0ol0003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol000001?mVIVH00ol0003oC4a<oda<
C003oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIV
I_mVIVKo000000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Ko
c<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@06o`000?moOgooOgmoo`000?mVIVKo00000om<
C4`00ol0003o<c<coc<c<`06oc<c<`09o`000?m<C4coC4a<oda<C?l0003oIVIVo`000?moOgoo0000
00;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@05o`000?mo
Ogoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0<o`000?m<C4coC4a<o`000?mV
IVKo0000ogmoOol0003oVIVIo`000?nc/k?o00002Oo<c<`02Ol0003o/k>co`000?nIVIWo0000ogmo
Ool0003oIVIVo`000004ooooo`;o00000_ooool002Cooooo00?o0000ooooooooool00oooool2ogmo
O`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVI
V@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH2o`0001WoC4a<00?o0000ofIV
I_mVIVH02?mVIVH00ol0003oOgmoogmoO`04ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c
/onc/k<04_nc/k<00ol0003oVIVIoiVIV@03oiVIV@04o`000?moOgooOgmoo`0000CoIVIV00?o0000
oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00;oC4a<00Go0000
ofIVI_mVIVKoIVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000onc/k<00ol0003oc<c<
olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIV
IP04o`000?m<C4coC4a<o`0000So<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo
00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c003o`000?nc/k?o000000;oVIVI
00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Wo0000oda<C?l0
003oIVIVo`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c003o`000?nc
/k?o/k>c00;o000000CoOgmoo`000?mVIVKo00001_ooool1o`00007ooooo0Oooool002Cooooo00?o
0000ooooooooool00oooool00omoOgoo0000oiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o
0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o
0000oda<C?m<C4`05om<C4`2o`0000[oIVIV00?o0000ogmoOomoOgl01?moOgl2o`0000GoVIVI00?o
0000ok>c/onc/k<04onc/k<00ol0003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol00000
0omVIVH00ol0003oC4a<oda<C003oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`0
0om<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0
003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Ko0000oiVIVOnIVIWo0000ogmoOol0
0002ofIVIP;o00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV
00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00009olc<c003o`000?nc/k?o000000;o
VIVI00Oo0000ogmoOol0003oIVIVo`000?m<C4co000000[o<c<c00Wo0000oda<C?l0003oIVIVo`00
0?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c009o`000?nc/k?o0000oiVI
VOl0003oOgmoo`000?mVIVKo000000Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooo
oooo00?ooooo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWo
VIVI00coVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4co
C4a<01KoC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`04ogmoO`03o`000?nIVIWo
VIVI00CoVIVI00?o0000ok>c/onc/k<04onc/k<00ol0003oVIVIoiVIV@02oiVIV@05o`000?moOgoo
OgmoogmoOol000000omVIVH00ol0003oC4a<oda<C003oda<C003o`000?lc<c?o<c<c00Co<c<c00?o
0000oda<C?m<C4`00om<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo
00001?nc/k<00ol0003oc<c<olc<c005olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0
003oOgmoogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01?l0003oC4a<oda<
C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`00ol0003o
/k>co`000002oiVIV@07o`000?moOgoo0000ofIVI_l0003oC4a<o`00000:oc<c<`09o`000?m<C4co
0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02Ol0003o
/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000006ooooo`7o00000Oooool1ooooo`009?ooool0
0ol0003oooooooooo`03ooooo`goVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0<
oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00F
oda<C003o`000?mVIVKoIVIV00[oIVIV00?o0000ogmoOomoOgl01?moOgl00ol0003oVIVIoiVIV@05
oiVIV@03o`000?nc/k?o/k>c01;o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomo
Ogoo000000?oIVIV00?o0000oda<C?m<C4`01?m<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<
C4coC4a<00;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`04o`000?nIVIWoVIVIo`0000Co
/k>c00?o0000olc<c?o<c<`01Oo<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmo
OomoOgoo00000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Co0000oda<C?m<C4co0000
0_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Ko0000ok>c/onc
/k?o0000oiVIVOl00002ogmoO`05o`000?mVIVKo0000oda<C?l000002Olc<c<00ol0003oC4a<o`00
0002ofIVIP07o`000?moOgoo0000oiVIVOl0003o/k>co`000009olc<c009o`000?nc/k?o0000oiVI
VOl0003oOgmoo`000?mVIVKo000000Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooo
oooo00?ooooo3?nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000
ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000
ofIVI_mVIVH02OmVIVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000
ok>c/onc/k<04onc/k<01?l0003oVIVIoiVIVOnIVIT2o`0000?oOgmo00Go0000ofIVI_mVIVKoIVIV
o`000006oda<C003o`000?lc<c?o<c<c00?o<c<c00?o0000oda<C?m<C4`00om<C4`01Ol0003oIVIV
ofIVI_mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c006olc<
c004o`000?nc/k?o/k>co`0000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01Ol0003oC4a<oda<
C?m<C4co000000So<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVIV@04
o`000?nc/k?o/k>co`0000Woc<c<00?o0000ok>c/ol000000_nIVIT01Ol0003oOgmoo`000?mVIVKo
000000;oC4a<00?o0000oc<c<olc<c<01olc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003o
VIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00[o0000ok>c/ol0003oVIVIo`000?moOgoo
0000ofIVI_l0003oC4a<1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00ooo
ool;oiVIV@;o00005onc/k<2o`0000goVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIV
IP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<0_l0000<ofIVIP03o`000?moOgooOgmo00CoOgmo00?o
0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`0Cok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go
0000ogmoOomoOgooOgmoo`000004ofIVIP03o`000?m<C4coC4a<00?oC4a<00?o0000oc<c<olc<c<0
1?lc<c<00ol0003oC4a<oda<C003oda<C004o`000?mVIVKoIVIVo`0000;oOgmo0_l00002oiVIV@05
o`000?nc/k?o/k>cok>c/ol000002Oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@04o`000?moOgoo
Ogmoo`0000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<01?l0003oC4a<oda<C?l00002ofIVIP03
o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01?l0003o/k>cok>c/ol00002
oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0:o`000?m<
C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`0
2_l0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4`6ooooo`7o00000Oooool1oooo
o`009?ooool00ol0003oooooooooo`03ooooo`[oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003o
VIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003o
C4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003o
VIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003o
OgmoogmoOomoOgoo000000CoIVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`04oc<c
<`03o`000?m<C4coC4a<00?oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl0
0004ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`00
0?moOgooOgmoo`0000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<01?l0003oC4a<oda<C?l00002
ofIVIP05o`000?moOgoo0000oiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc
/k?o/k>co`0000;oVIVI00Oo0000ogmoOol0003oIVIVo`000?m<C4co000000Wo<c<c00[o0000oda<
C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c00;
o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l000001Oooool1o`00007ooooo
0Oooool002Cooooo00?o0000ooooooooool00oooool9oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o
0000oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o
0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00GoOgmo00?o
0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`0Cok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go
0000ogmoOomoOgooOgmoo`000004ofIVIP03o`000?m<C4coC4a<00?oC4a<00?o0000oc<c<olc<c<0
1?lc<c<00ol0003oC4a<oda<C003oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Go0000oiVIVOnI
VIWoVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002
oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`04o`00
0?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT01Ol0003o/k>cok>c/onc/k?o0000
00Soc<c<00?o0000ok>c/ol000000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000
oc<c<olc<c<01olc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c/`03
o`000?o<c<coc<c<00Koc<c<00?o0000ok>c/ol000000_nIVIT2o`000005ofIVI_l0003oC4a<oda<
C?l000001Oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool8oiVIV@03
o`000?nc/k?o/k>c01Ko/k>c0_l0000=oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mV
IVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomo
Ogl01OmoOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnI
VIT00_nIVIT00ol0003oOgmoogmoO`02ogmoO`05o`000?mVIVKoIVIVofIVI_l000001_m<C4`00ol0
003o<c<coc<c<`03oc<c<`03o`000?m<C4coC4a<00?oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002
ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc
/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<
C?l000002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000
ok>c/onc/k?o00002?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l0
00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0
003oVIVIo`000?nc/k?o00002Oo<c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`00
0002oda<C003o`000?oooooooooo00?ooooo0Ol00001ooooo`7ooooo000Tooooo`;o00001?ooool7
oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`08
ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0:
ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT01OnIVIT00ol0003o/k>cok>c/`0C
ok>c/`03o`000?nIVIWoVIVI00;oVIVI00?o0000ogmoOomoOgl00_moOgl01?l0003oIVIVofIVI_l0
0006oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00om<C4`01Ol0003oIVIVofIV
I_mVIVKo000000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Ko
c<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@03o`000?moOgoo000000;oIVIV00?o0000oda<
C?m<C4`00_m<C4`00ol0003o<c<coc<c<`05oc<c<`07o`000?m<C4coC4a<oda<C?l0003oIVIVo`00
0002ogmoO`04o`000?nIVIWoVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>c
ok>c/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c
<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00002Oo<c<`02Ol0
003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003o`000?oooooooooo00;ooooo
0_l00002ooooo`009?ooool00ol0003oooooooooo`03ooooo`KoVIVI00?o0000ok>c/onc/k<05_nc
/k<00ol0003oVIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omV
IVH00ol0003oC4a<oda<C00Foda<C0;o00003?mVIVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nI
VIWoVIVI00GoVIVI00?o0000ok>c/onc/k<04onc/k<00ol0003oVIVIoiVIV@02oiVIV@03o`000?mo
OgooOgmo00;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000005oda<C003o`000?lc<c?o<c<c00Co<c<c
00?o0000oda<C?m<C4`00om<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Go0000oiVIVOnI
VIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Goc<c<00Go0000ok>c/onc/k?o/k>co`000002
oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`04o`00
0?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00008olc<
c004o`000?nc/k?o/k>co`0000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc
<c?o<c<c00Oo<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl000000_nc/k<00ol0
003oc<c<olc<c006olc<c003o`000?nc/k?o/k>c00;o000000OoOgmoo`000?mVIVKoIVIVo`000?m<
C4co000000Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo1OnIVIT0
0ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00[oVIVI0_l0000:ogmoO`03o`000?mVIVKo
IVIV00[oIVIV0_l0000Hoda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl01_moOgl0
0ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT00onIVIT0
1Ol0003oOgmoogmoOomoOgoo000000?oIVIV00?o0000oda<C?m<C4`01?m<C4`00ol0003o<c<coc<c
<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Co0000ofIVI_mVIVKo00000omoOgl01?l0003oVIVI
oiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003o
VIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<0
1Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o0000ogmoOol000000_nIVIT00ol0003o/k>co`00
0009olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl01Ol0003oIVIVo`000?m<C4co0000
00[o<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<
olc<c006olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000
ooooooooool01?ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool4oiVI
V@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`09ogmo
O`03o`000?mVIVKoIVIV00[oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0;ofIV
IP03o`000?moOgooOgmo00KoOgmo00?o0000oiVIVOnIVIT01OnIVIT00ol0003o/k>cok>c/`0Cok>c
/`03o`000?nIVIWoVIVI00?oVIVI00Go0000ogmoOomoOgooOgmoo`000003ofIVIP03o`000?m<C4co
C4a<00CoC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C003oda<C004o`000?mVIVKo
IVIVo`0000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Goc<c<
00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`00
00;oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o0000
ogmoOol000000_nIVIT00ol0003o/k>co`000009olc<c006o`000?nc/k?o/k>co`000?nIVIWo0000
0_moOgl01Ol0003oIVIVo`000?m<C4co000000[o<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo
0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c009o`000?nc/k?o0000oiVIVOl0003o
Ogmoo`000?mVIVKo000000;oC4a<00?o0000ooooooooool01?ooool1o`00007ooooo0Oooool002Co
oooo00?o0000ooooooooool00oooool3oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnI
VIT02_nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<
C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00KoOgmo00?o0000oiVIVOnI
VIT01OnIVIT00ol0003o/k>cok>c/`0Dok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomo
OgooOgmoo`000003ofIVIP03o`000?m<C4coC4a<00CoC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0
003oC4a<oda<C003oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl0
0004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVI
VOl00002ogmoO`04o`000?mVIVKoIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01olc<c<01?l0003o
C4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`0
1?l0003o/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<c
oc<c<`07oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000
olc<c?o<c<`01oo<c<`2o`000004oiVIVOl0003oOgmoogmoO`;o00000_m<C4`00ol0003o<c<coooo
o`05ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`;oVIVI00?o0000
ok>c/onc/k<05_nc/k<2o`0000coVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0;
ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`06
ogmoO`03o`000?nIVIWoVIVI00GoVIVI00?o0000ok>c/onc/k<05?nc/k<00ol0003oVIVIoiVIV@02
oiVIV@05o`000?moOgooOgmoogmoOol000001?mVIVH00ol0003oC4a<oda<C004oda<C003o`000?lc
<c?o<c<c00?o<c<c00?o0000oda<C?m<C4`00om<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo
00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc
/k<00_nc/k<01_l0003oVIVIoiVIVOl0003oOgmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`00
0009oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00002ok>c
/`03o`000?o<c<coc<c<00Koc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`03o`000?mV
IVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?mo
Ogoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Wo0000ok>c/ol0003oVIVIo`00
0?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<cooooo`05ooooo`7o00000Oooool1ooooo`00
9?ooool00ol0003oooooooooo`03ooooo`03oiVIVOl0003o/k>c01So/k>c00?o0000oiVIVOnIVIT0
2_nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`0
5_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT0
1OnIVIT00ol0003o/k>cok>c/`0Dok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomoOgoo
Ogmoo`000004ofIVIP03o`000?m<C4coC4a<00CoC4a<00?o0000oc<c<olc<c<00olc<c<00ol0003o
C4a<oda<C003oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01Ol0003oVIVIoiVIVOnIVIWo
000000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`06o`000?nIVIWo
VIVIo`000?moOgoo00000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000Wo<c<c00Ko0000oda<C?m<
C4co0000ofIVI_l00002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`0
1_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<c
oc<c<`06oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o
0000olc<c?o<c<`01_o<c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<
C003o`000?lc<c?ooooo00Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?o
oooo00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0:oiVIV@03o`000?moOgooOgmo00Wo
Ogmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_o
IVIV00?o0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@05oiVIV@03o`000?nc/k?o/k>c01Co
/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000CoIVIV00?o0000oda<
C?m<C4`01?m<C4`00ol0003o<c<coc<c<`03oc<c<`03o`000?m<C4coC4a<00?oC4a<00Go0000ofIV
I_mVIVKoIVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0003oc<c<olc<
c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT00ol0003oOgmoo`000002ofIVIP05o`00
0?m<C4coC4a<oda<C?l000002Olc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00Co0000
oiVIVOnIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c006o`000?nc/k?o/k>co`000?nIVIWo
00000_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Oo0000oda<C?l0
003oIVIVo`000?moOgoo000000;oVIVI00?o0000ok>c/ol000002?o<c<`00ol0003o/k>co`000002
oiVIV@;o000000GoIVIVo`000?m<C4coC4a<o`000002oc<c<`Kooooo0Ol00001ooooo`7ooooo000T
ooooo`03o`000?oooooooooo00?ooooo6?nc/k<2o`0000coVIVI00?o0000ogmoOomoOgl02OmoOgl0
0ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH0
0ol0003oOgmoogmoO`07ogmoO`03o`000?nIVIWoVIVI00GoVIVI00?o0000ok>c/onc/k<04onc/k<2
o`0000CoVIVI00?o0000ogmoOomoOgl00_moOgl01Ol0003oIVIVofIVI_mVIVKo000000KoC4a<00?o
0000oc<c<olc<c<00olc<c<2o`0000GoC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`05o`00
0?nIVIWoVIVIoiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c
/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc
<c<01ol0003oC4a<oda<C?m<C4co0000ofIVI_l000000_moOgl00ol0003oVIVIo`000003ok>c/`03
o`000?o<c<coc<c<00Koc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`03o`000?mVIVKo
000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo
0000oiVIVOl0003o/k>co`0000Woc<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0
00000_m<C4`00ol0003o<c<coc<c<`06ooooo`7o00000Oooool1ooooo`009?ooool00ol0003ooooo
ooooo`03oooooaSo/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`00
0?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`00
0?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`0Cok>c/`03o`00
0?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl00_moOgl01Ol0003oIVIVofIVI_mVIVKo000000Ko
C4a<00?o0000oc<c<olc<c<00olc<c<00ol0003oC4a<oda<C004oda<C005o`000?mVIVKoIVIVofIV
I_l000000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`0
1Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01Ol0003oC4a<
oda<C?m<C4co000000So<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00?o0000
oiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c006o`000?nc/k?o/k>co`000?nIVIWo0000
0_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00co0000oda<C?m<C4co
0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00009olc<c009o`000?nc/k?o0000oiVIVOl0
003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_ooool1o`00007ooooo0Oooool0
02Cooooo0_l00004oooooaOo/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`09ogmo
O`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIV
IP03o`000?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`0Cok>c
/`03o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl00_moOgl01Ol0003oIVIVofIVI_mVIVKo
000000KoC4a<00?o0000oc<c<olc<c<00olc<c<00ol0003oC4a<oda<C004oda<C005o`000?mVIVKo
IVIVofIVI_l000000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000?o/k>c00?o0000olc<c?o<c<`0
1_o<c<`00ol0003o/k>cok>c/`02ok>c/`06o`000?nIVIWoVIVIo`000?moOgoo00000_mVIVH01Ol0
003oC4a<oda<C?m<C4co000000Wo<c<c00Co0000oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`00
0?nIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01_l0003o/k>cok>c/ol0003oVIVIo`00
00;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`06o`000?m<C4coC4a<
o`000?mVIVKo00000_moOgl2o`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003o/k>cok>c
/`02o`000007ogmoOol0003oIVIVofIVI_l0003oC4a<o`000003oc<c<`Gooooo0_l00002ooooo`00
9?ooool00ol0003oooooooooo`03oooooaGo/k>c0_l0000<oiVIV@03o`000?moOgooOgmo00WoOgmo
00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV
00?o0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c01Co/k>c
00?o0000oiVIVOnIVIT00_nIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00;oIVIV
00?o0000oda<C?m<C4`01?m<C4`00ol0003o<c<coc<c<`03oc<c<`03o`000?m<C4coC4a<00?oC4a<
00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<
c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mV
IVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Co0000oda<C?m<C4co00000_mVIVH01_l0003o
OgmoogmoOol0003oVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01_l0003o/k>cok>c/ol0
003oVIVIo`0000;oOgmo00Go0000ofIVI_l0003oC4a<o`000009oc<c<`0:o`000?m<C4coC4a<o`00
0?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003o/k>c
o`000002o`000006ogmoOol0003oIVIVo`000?m<C4co00001?lc<c<6ooooo`7o00000Oooool1oooo
o`009?ooool00ol0003oooooooooo`03oooooaCo/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003o
OgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003o
IVIVofIVIP0;ofIVIP;o00002OmoOgl00ol0003oVIVIoiVIV@05oiVIV@03o`000?nc/k?o/k>c01Go
/k>c00?o0000oiVIVOnIVIT00_nIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00;o
IVIV00?o0000oda<C?m<C4`01?m<C4`00ol0003o<c<coc<c<`03oc<c<`03o`000?m<C4coC4a<00?o
C4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000
olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo0000
0_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Co0000oda<C?m<C4co00000_mVIVH01_l0
003oOgmoogmoOol0003oVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01_l0003o/k>cok>c
/ol0003oVIVIo`0000;oOgmo00Go0000ofIVI_l0003oC4a<o`000009oc<c<`0:o`000?m<C4coC4a<
o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02ol0003o
/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co000000Co<c<c1_ooool1o`00007ooooo
0Oooool002Cooooo00?o0000ooooooooool00ooooolCok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o
0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o
0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o
0000ok>c/onc/k<05?nc/k<00ol0003oVIVIoiVIV@03oiVIV@05o`000?moOgooOgmoogmoOol00000
1?mVIVH00ol0003oC4a<oda<C004oda<C003o`000?lc<c?o<c<c00?o<c<c00?o0000oda<C?m<C4`0
0om<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0
003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol0
0002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP06
o`000?moOgooOgmoo`000?nIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o
/k>co`0000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c
00Co0000oda<C?m<C4co00000_mVIVH2o`000005oiVIVOl0003o/k>cok>c/ol000002?o<c<`00ol0
003o/k>cok>c/`02o`0000;oOgmo0_l00002oda<C003o`000?lc<c?o<c<c00;o<c<c1_ooool1o`00
007ooooo0Oooool002Cooooo00?o0000ooooooooool00ooooolBok>c/`03o`000?nIVIWoVIVI00_o
VIVI00?o0000ogmoOomoOgl02?moOgl2o`0000goIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003o
IVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o
/k>cok>c/`0Dok>c/`03o`000?nIVIWoVIVI00?oVIVI00Go0000ogmoOomoOgooOgmoo`000004ofIV
IP03o`000?m<C4coC4a<00GoC4a<00?o0000oc<c<olc<c<00_lc<c<00ol0003oC4a<oda<C004oda<
C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Co/k>c00?o
0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo
00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`00
00;oIVIV00Ko0000ogmoOomoOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00So
0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<0
2_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<
00Koc<c<00?o0000ok>c/onc/k<00_l000001?moOgoo0000o`000?l00002oda<C003o`000?lc<c?o
<c<c00;o<c<c1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00ooooolAok>c
/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0<ofIV
IP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH2o`0000WoOgmo00?o0000oiVI
VOnIVIT01onIVIT00ol0003o/k>cok>c/`0Dok>c/`03o`000?nIVIWoVIVI00?oVIVI00Go0000ogmo
OomoOgooOgmoo`000004ofIVIP03o`000?m<C4coC4a<00CoC4a<00?o0000oc<c<olc<c<00olc<c<0
0ol0003oC4a<oda<C004oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01Ol0003oVIVIoiVI
VOnIVIWo000000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`00
0?nIVIWoVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c
<`04o`000?m<C4coC4a<o`0000;oIVIV00Ko0000ogmoOomoOgoo0000oiVIVOl00002ok>c/`03o`00
0?o<c<coc<c<00Ooc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV00Co0000
oda<C?m<C4co00002?lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002
ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o0000ok>c/onc/k<00_l000001?moOgoo0000ofIVI_l0
0002oda<C003o`000?lc<c?o<c<c00;o<c<c1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000
ooooooooool00oooool@ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl0
0ol0003oIVIVofIVIP0;ofIVIP;o00006?m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgoo
Ogmo00SoOgmo00?o0000oiVIVOnIVIT01onIVIT00ol0003o/k>cok>c/`0Dok>c/`03o`000?nIVIWo
VIVI00?oVIVI00?o0000ogmoOomoOgl00_moOgl01Ol0003oIVIVofIVI_mVIVKo000000OoC4a<00?o
0000oc<c<olc<c<00_lc<c<00ol0003oC4a<oda<C004oda<C005o`000?mVIVKoIVIVofIVI_l00000
0_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o
/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`0
0ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Ko0000ogmoOomoOgoo0000
oiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003o
Ogmoo`0000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<00ol0003oC4a<oda<C002o`000007ogmo
Ool0003oVIVIoiVIVOl0003o/k>co`000008olc<c005o`000?nc/k?o/k>co`000?nIVIT00_l00000
1OmVIVKo0000oda<C?m<C4co000000Go<c<c1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000
ooooooooool00oooool?ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl0
0ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02omVIVH0
0ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00OoVIVI00?o0000ok>c/onc/k<05?nc/k<0
0ol0003oVIVIoiVIV@03oiVIV@03o`000?moOgooOgmo00;oOgmo00Go0000ofIVI_mVIVKoIVIVo`00
0007oda<C003o`000?lc<c?o<c<c00;o<c<c00?o0000oda<C?m<C4`01?m<C4`01Ol0003oIVIVofIV
I_mVIVKo000000?oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c006olc<c005
o`000?nc/k?o/k>cok>c/ol000000onIVIT00ol0003oOgmoo`000003ofIVIP04o`000?m<C4coC4a<
o`0000So<c<c0_l00002oda<C006o`000?mVIVKoIVIVo`000?moOgoo00000_nIVIT01?l0003o/k>c
ok>c/ol00008olc<c009o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000?moOgoo000000;oIVIV00Co
0000oda<C?m<C4co00002?lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0
003o/k>co`0000Woc<c<00Go0000ok>c/onc/k?o0000oiVIV@02o`000005ofIVI_l0003oC4a<oda<
C?l000001Olc<c<6ooooo`7o00000Oooool1ooooo`006Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Kooooo00?o0000ooooooooool00oooool>ok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmo
OomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIV
I_mVIVH02omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00OoVIVI00?o0000ok>c
/onc/k<04onc/k<00ol0003oVIVIoiVIV@03oiVIV@03o`000?moOgooOgmo00?oOgmo00Go0000ofIV
I_mVIVKoIVIVo`000007oda<C003o`000?lc<c?o<c<c00;o<c<c00?o0000oda<C?m<C4`01?m<C4`0
1Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<
olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000onIVIT00ol0003oOgmoo`000003ofIVIP04
o`000?m<C4coC4a<o`0000So<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP03o`000?moOgoo
000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`02Ol0003o/k>cok>c/onc/k?o0000oiVIVOl0
003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00co0000oda<C?m<C4co0000ofIV
I_l0003oOgmoo`000?nIVIWo0000ok>c/ol00009olc<c005o`000?nc/k?o/k>co`000?nIVIT00_l0
00001OmVIVKo0000oda<C?m<C4co000000Go<c<c1_ooool1o`00007ooooo0Oooool001Wooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00?ooooo3Onc/k<00ol0003oVIVI
oiVIV@0<oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<
oda<C00Foda<C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVI
oiVIV@07oiVIV@03o`000?nc/k?o/k>c01Co/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmo
ogmoO`02ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01Om<C4`01Ol0003o<c<c
oc<c<olc<c?o000000OoC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`05o`000?nIVIWoVIVI
oiVIVOl000001?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000
oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c
00Go0000oda<C?m<C4coC4a<o`000002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc
/k?o00002?o<c<`02Ol0003o/k>cok>c/onc/k?o0000oiVIVOl0003oOgmoo`000002ofIVIP03o`00
0?m<C4co000000Wo<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c
/ol00009olc<c003o`000?nc/k?o000000;oVIVI0_l000001OmVIVKo0000oda<C?m<C4co000000Go
<c<c1_ooool1o`00007ooooo0Oooool001Wooooo00Go410@oooooooooooooooooa0@4006ooooo`03
o`000?oooooooooo00?ooooo3?nc/k<00ol0003oVIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo00So
Ogmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00_o
IVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@08oiVIV@03o`000?nc/k?o/k>c01?o
/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00;o
IVIV00?o0000oda<C?m<C4`01?m<C4`00ol0003o<c<coc<c<`02oc<c<`03o`000?m<C4coC4a<00Co
C4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000
olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000?oVIVI00?o0000ogmoOol000000omV
IVH01?l0003oC4a<oda<C?l00008oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH00ol0003o
Ogmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Woc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl0
0002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02_l0003oC4a<oda<
C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000
ok>c/onc/k?o0000oiVIV@02o`0000;oIVIV00?o0000oda<C?l000001_lc<c<6ooooo`7o00000Ooo
ool1ooooo`006Oooool01Ol0003ooooooooooooooooo000000Kooooo0ol00003ooooo`_o/k>c0_l0
000=oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<
C00Foda<C0;o00003?mVIVH2o`0000[oOgmo00?o0000oiVIVOnIVIT01onIVIT2o`0001Ko/k>c00?o
0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o
0000oda<C?m<C4`01Om<C4`00ol0003o<c<coc<c<`02oc<c<`03o`000?m<C4coC4a<00CoC4a<00Go
0000ofIVI_mVIVKoIVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0003o
c<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0
003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`00
0002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`02?l0003o/k>c
ok>c/ol0003oVIVIo`000?moOgoo00000_mVIVH00ol0003oC4a<o`000009oc<c<`0:o`000?m<C4co
C4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0
003o/k>co`000002oiVIV@;o00000_mVIVH00ol0003oC4a<o`000006oc<c<`Cooooo0ol00002oooo
o`006Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00oooool:ok>c
/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIV
IP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmoO`08ogmo
O`03o`000?nIVIWoVIVI00SoVIVI00?o0000ok>c/onc/k<05?nc/k<00ol0003oVIVIoiVIV@03oiVI
V@03o`000?moOgooOgmo00?oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C004oda<
C003o`000?lc<c?o<c<c00?o<c<c00?o0000oda<C?m<C4`01?m<C4`01Ol0003oIVIVofIVI_mVIVKo
000000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o
0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000?o
C4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o0000ogmo
Ool000000_nIVIT01?l0003o/k>cok>c/ol00009olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000
ogmoOol00002ofIVIP03o`000?m<C4co000000Wo<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003o
Ogmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c003o`000?nc/k?o000000;oVIVI
0_l00002ofIVIP03o`000?m<C4co000000Ko<c<c1_ooool1o`00007ooooo0Oooool001Wooooo00Go
410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00?ooooo2Onc/k<00ol0003oVIVI
oiVIV@0<oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<
oda<C00Foda<C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVI
oiVIV@08oiVIV@03o`000?nc/k?o/k>c01Co/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmo
ogmoO`03ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01Om<C4`00ol0003o<c<c
oc<c<`02oc<c<`03o`000?m<C4coC4a<00CoC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`05
o`000?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c
00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc
<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP03o`000?moOgoo000000;oVIVI
00Co0000ok>c/onc/k?o00002Oo<c<`02?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo00000_mV
IVH01?l0003oC4a<oda<C?l00008oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003o
VIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?mo
Ogoo0000ofIVI_l0003oC4a<o`0000Oo<c<c1_ooool1o`00007ooooo0Oooool001Wooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00?ooooo2?nc/k<2o`0000goVIVI00?o
0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o
0000ofIVI_mVIVH02omVIVH2o`0000[oOgmo00?o0000oiVIVOnIVIT02?nIVIT00ol0003o/k>cok>c
/`0Eok>c/`03o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIV
IP02ofIVIP03o`000?m<C4coC4a<00GoC4a<00?o0000oc<c<olc<c<00_lc<c<00ol0003oC4a<oda<
C004oda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01Ol0003oVIVIoiVIVOnIVIWo000000Co
/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`00
00;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`07o`000?m<C4co
C4a<oda<C?l0003oIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000;o/k>c00?o0000olc<c?o<
c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<
C?m<C4co00002?lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c
/`03o`000?o<c<coc<c<00Koc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo
0000oda<C?l00007oc<c<`Kooooo0Ol00001ooooo`7ooooo000Iooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01_ooool00ol0003oooooooooo`03ooooo`Oo/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0
003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0
003oIVIVofIVIP0:ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02?nIVIT00ol0
003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl00_moOgl00ol0
003oIVIVofIVIP02ofIVIP03o`000?m<C4coC4a<00GoC4a<00Go0000oc<c<olc<c?o<c<co`000007
oda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01?l0003oVIVIoiVIVOl00005ok>c/`03o`00
0?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04
o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01ol0003oC4a<oda<C?m<C4co
0000ofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<
00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`00
00Oo<c<c00_o0000oda<C?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c/`03
o`000?o<c<coc<c<00Koc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000
oda<C?l00007oc<c<`Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo
1_nc/k<00ol0003oVIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH0
2omVIVH00ol0003oC4a<oda<C00Foda<C0;o00003?mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`00
0?nIVIWoVIVI00WoVIVI00?o0000ok>c/onc/k<05Onc/k<00ol0003oVIVIoiVIV@03oiVIV@03o`00
0?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C004oda<C003o`00
0?lc<c?o<c<c00;o<c<c00?o0000oda<C?m<C4`01?m<C4`01Ol0003oIVIVofIVI_mVIVKo000000?o
Ogmo00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c
/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o
0000oc<c<olc<c<01olc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI
00Co0000ok>c/onc/k?o00002?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo0000
00;oIVIV00Co0000oda<C?m<C4co00002?lc<c<02?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo
00000_nIVIT00ol0003o/k>co`000008olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0
003oIVIVo`000?m<C4co00002?lc<c<6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003ooooo
ooooo`03ooooo`Ko/k>c00?o0000oiVIVOnIVIT02_nIVIT2o`0000[oOgmo00?o0000ofIVI_mVIVH0
2_mVIVH2o`0001SoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`;o0000
2onIVIT00ol0003o/k>cok>c/`0Eok>c/`03o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl0
0_moOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<00GoC4a<00Go0000oc<c<olc<c?o
<c<co`000006oda<C0;o00000omVIVH01?l0003oOgmoogmoOol00003oiVIV@03o`000?nc/k?o/k>c
00?o/k>c00?o0000olc<c?o<c<`01?o<c<`2o`0000?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002
ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01ol0003oC4a<oda<
C?m<C4co0000ofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00002ok>c/`03o`000?o<c<coc<c<
00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIVIP03o`000?m<C4co
000000Wo<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0
003oc<c<olc<c006olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<
C4co00002?lc<c<00ol0003oooooooooo`03ooooo`7o00000Oooool1ooooo`009?ooool00ol0003o
ooooooooo`03ooooo`Go/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`09ogmoO`03
o`000?mVIVKoIVIV00[oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0;ofIVIP03
o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Dok>c/`03
o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIVIP03ofIVIP03
o`000?m<C4coC4a<00GoC4a<00Go0000oc<c<olc<c?o<c<co`000006oda<C003o`000?mVIVKoIVIV
00;oIVIV00Co0000ogmoOomoOgoo00000onIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<co
c<c<00Coc<c<00?o0000ok>c/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Co
0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`07o`000?m<C4coC4a<oda<C?l0
003oIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`0
1?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV00?o0000oda<C?l000002Olc
<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<co
c<c<00Koc<c<00?o0000ok>c/onc/k<00_l00002ogmoO`05o`000?mVIVKo0000oda<C?l000002?lc
<c<00ol0003oooooooooo`03ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03
ooooo`Co/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKo
IVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgoo
Ogmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Dok>c/`03o`000?nIVIWo
VIVI00CoVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4co
C4a<00GoC4a<00Go0000oc<c<olc<c?o<c<co`000006oda<C003o`000?mVIVKoIVIV00;oIVIV00Co
0000ogmoOomoOgoo00000onIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00Coc<c<
00?o0000ok>c/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Co0000ofIVI_mV
IVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`07o`000?m<C4coC4a<oda<C?l0003oIVIVo`00
0002ogmoO`04o`000?nIVIWoVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>c
ok>c/ol00002oiVIV@08o`000?moOgooOgmoo`000?mVIVKo0000oda<C?l00009oc<c<`06o`000?m<
C4coC4a<o`000?mVIVKo00000_moOgl2o`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02_l0003o
/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Go<c<c
00?o0000ooooooooool01?ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00ooo
ool2ok>c/`;o00003?nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o
0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo0_l0
000<oiVIV@03o`000?nc/k?o/k>c01Co/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmo
O`02ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<C4`01_m<C4`01?l0003o<c<coc<c
<ol00007oda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01Ol0003oVIVIoiVIVOnIVIWo0000
00Co/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVI
o`0000;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`07oc<c<`04o`000?m<
C4coC4a<o`0000;oIVIV00Ko0000ogmoOomoOgoo0000oiVIVOl00003ok>c/`03o`000?o<c<coc<c<
00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o
0000oc<c<olc<c<01olc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002
ok>c/`03o`000?o<c<coc<c<00Koc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mV
IVKo0000oda<C?l00008oc<c<`03o`000?oooooooooo00Cooooo0Ol00001ooooo`7ooooo000Toooo
o`;o00001?ooool2ok>c/`03o`000?nIVIWoVIVI00[oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0
003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0
003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05Onc/k<00ol0
003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0
003oC4a<oda<C006oda<C004o`000?lc<c?o<c<co`0000OoC4a<00Go0000ofIVI_mVIVKoIVIVo`00
0003ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0003oc<c<olc<c005olc<c003o`00
0?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00003oda<
C003o`000?lc<c?o<c<c00Oo<c<c00Co0000oda<C?m<C4co00000_mVIVH01_l0003oOgmoogmoOol0
003oVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@05
o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`0:o`000?m<C4coC4a<
o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003o
/k>co`000002oiVIV@07o`000?moOgoo0000ofIVI_l0003oC4a<o`000008oc<c<`03o`000?oooooo
oooo00?ooooo0_l00002ooooo`009?ooool00ol0003oooooooooo`03ooooo`03ok>c/ol0003oVIVI
00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<
01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI
00_oVIVI00?o0000ok>c/onc/k<05Onc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo
00;oOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C006oda<C004o`000?lc<c?o<c<c
o`0000OoC4a<00Go0000ofIVI_mVIVKoIVIVo`000004ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c
00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`03ok>c/`04o`000?nIVIWoVIVIo`0000;o
Ogmo00Co0000ofIVI_mVIVKo00000_m<C4`00ol0003o<c<coc<c<`07oc<c<`04o`000?m<C4coC4a<
o`0000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01?l0003o/k>cok>c/ol00008olc<c00;o`00
0?nc/k?o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c
<`07oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV0_l000001OnIVIWo0000ok>c/onc/k?o000000So
c<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00008oc<c<`03
o`000?m<C4cooooo00Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo
00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV
00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo
0_l0000<oiVIV@03o`000?nc/k?o/k>c01Go/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmo
ogmoO`03ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01_m<C4`01?l0003o<c<c
oc<c<ol00007oda<C0;o00000omVIVH01Ol0003oOgmoogmoOomoOgoo000000;oVIVI00?o0000ok>c
/onc/k<00onc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVI
VOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go
0000oda<C?m<C4coC4a<o`000002ofIVIP06o`000?moOgooOgmoo`000?nIVIWo00000onc/k<00ol0
003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Go0000ogmoOol0003oIVIVo`00
0002oda<C003o`000?lc<c?o<c<c00Oo<c<c00?o0000oda<C?l000000_mVIVH01Ol0003oOgmoo`00
0?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`00
0?moOgoo0000ofIVI_l0003oC4a<o`0000So<c<c00?o0000oda<C?ooool01Oooool1o`00007ooooo
0Oooool002Cooooo00?o0000ooooooooool00oooool<oiVIV@03o`000?moOgooOgmo00WoOgmo00?o
0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o
0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Go/k>c00?o
0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o
0000oda<C?m<C4`01om<C4`00ol0003o<c<co`000007oda<C003o`000?mVIVKoIVIV00;oIVIV00Go
0000ogmoOomoOgooOgmoo`000002oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`0
1?o<c<`00ol0003o/k>cok>c/`03ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co0000ofIVI_mV
IVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH0
1_l0003oOgmoogmoOol0003oVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>c
ok>c/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c
<`04o`000?m<C4coC4a<o`0000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<
c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o0000oiVIV@02o`0000;oIVIV00?o0000oda<C?l00000
2?lc<c<00ol0003oC4a<ooooo`05ooooo`7o00000Oooool1ooooo`009?ooool00ol0003ooooooooo
o`03ooooo`_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<
C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nI
VIWoVIVI00coVIVI00?o0000ok>c/onc/k<05Onc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?mo
OgooOgmo00?oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C009oda<C003o`000?m<
C4coC4a<00GoC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000;oVIVI
00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c
00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00004oda<C003o`000?lc<c?o<c<c
00Go<c<c00?o0000oda<C?m<C4`00_m<C4`02?l0003oIVIVofIVI_l0003oOgmoo`000?nIVIWo0000
0onc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol0
00000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmo
Ool00002oiVIV@03o`000?nc/k?o000000Soc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmo
o`000?mVIVKo0000oda<C?l00008oc<c<`04o`000?m<C4coC4a<o`0000Gooooo0Ol00001ooooo`7o
oooo000Tooooo`03o`000?oooooooooo00?ooooo2_nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`00
0?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`00
0?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`0Eok>c/`03o`00
0?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIVIP02ofIVIP03o`00
0?m<C4coC4a<01;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`05o`000?nIVIWoVIVIoiVI
VOl000001Onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00;o/k>c00Go0000oiVI
VOnIVIWoVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc
<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>c
ok>c/ol00009olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Go0000ogmoOol0003oIVIVo`000002
oda<C003o`000?lc<c?o<c<c00Oo<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nI
VIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmo
Ool0003oIVIVo`000?m<C4co00002?lc<c<01?l0003oC4a<oda<C?l00005ooooo`7o00000Oooool1
ooooo`009?ooool00ol0003oooooooooo`03ooooo`WoVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0
003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH2o`00
00[oOgmo00?o0000oiVIVOnIVIT02_nIVIT2o`0001So/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0
003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<C4`04_m<C4`01Ol0
003oIVIVofIVI_mVIVKo000000?oOgmo00Go0000oiVIVOnIVIWoVIVIo`000005ok>c/`03o`000?o<
c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo
00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<
C?l000000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Woc<c<00Co0000
ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<0
1olc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<
c<coc<c<00Koc<c<00?o0000ok>c/onc/k<00_l00002ogmoO`05o`000?mVIVKo0000oda<C?l00000
2?lc<c<01?l0003oC4a<oda<C?l00005ooooo`7o00000Oooool1ooooo`009?ooool00ol0003ooooo
ooooo`03ooooo`SoVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`00
0?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`00
0?nIVIWoVIVI00[oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`00
0?moOgooOgmo00?oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C00Boda<C005o`00
0?mVIVKoIVIVofIVI_l000001?moOgl01?l0003oVIVIoiVIVOl00005ok>c/`03o`000?o<c<coc<c<
00Coc<c<00?o0000ok>c/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Co0000
ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l00000
0_mVIVH00ol0003oOgmoo`000002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01?l0003o
/k>cok>c/ol00002oiVIV@03o`000?moOgooOgmo00;o00000_m<C4`00ol0003o<c<coc<c<`07oc<c
<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl2o`0000;o/k>c00?o0000olc<c?o<c<`01_o<
c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o
<c<c00Ko<c<c00?o0000oda<C?l000001_ooool1o`00007ooooo0Oooool002Cooooo00?o0000oooo
ooooool00oooool7oiVIV@03o`000?moOgooOgmo00SoOgmo0_l0000=ofIVIP03o`000?m<C4coC4a<
01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`;o00003?nIVIT00ol0
003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl00omoOgl00ol0
003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<017oC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0
003oOgmoogmoOomoOgoo000000?oVIVI00?o0000ok>c/onc/k<00_nc/k<00ol0003oc<c<olc<c005
olc<c003o`000?nc/k?o/k>c00;o/k>c00?o0000oiVIVOnIVIT00_l000000omoOgoo0000o`000002
ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV
00?o0000ogmoOol000000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Go0000ok>c/onc
/k?o0000oiVIV@02o`000004ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01olc<c<0
0ol0003oC4a<o`000002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<
c006olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co00002?lc
<c<01?l0003oC4a<oda<C?l00006ooooo`7o00000Oooool1ooooo`009?ooool00ol0003ooooooooo
o`03ooooo`KoVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<
C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH2o`0000[oOgmo00?o0000oiVIVOnIVIT02_nI
VIT2o`0001Wo/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mV
IVKoIVIV00?oIVIV00?o0000oda<C?m<C4`04Om<C4`00ol0003oIVIVofIVIP02ofIVIP05o`000?mo
OgooOgmoogmoOol000000onIVIT00ol0003o/k>cok>c/`02ok>c/`03o`000?o<c<coc<c<00Goc<c<
00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`05o`000?mVIVKoIVIVofIV
I_l000000om<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Ko0000ofIV
I_mVIVKo0000ogmoOol00002oiVIV@05o`000?nc/k?o/k>cok>c/ol000001oo<c<`01ol0003o/k>c
ok>c/onc/k?o0000oiVIVOl000000_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c
00Oo<c<c00Go0000oda<C?l0003oIVIVo`000002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000
olc<c?o<c<`01_o<c<`01ol0003o/k>cok>c/ol0003oVIVIo`000?moOgl00_l00002oda<C003o`00
0?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00001_ooool1o`00007ooooo0Oooool002Cooooo
0_l00004ooooo`GoVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP;o0000
6?m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT0
2_nIVIT00ol0003o/k>cok>c/`0Gok>c/`;o00001_nIVIT00ol0003oOgmoogmoO`03ogmoO`03o`00
0?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<C4`04_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000?o
Ogmo00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c
/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`05o`000?mVIVKoIVIVofIVI_l000000om<
C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmo
ogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl0
0002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01olc<c<00ol0003oC4a<o`00
0002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c00<o`00
0?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co00002Olc<c<01Ol0003oC4a<
o`000?mVIVKo000000Cooooo0_l00002ooooo`009?ooool00ol0003oooooooooo`03ooooo`CoVIVI
00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<
00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`;o00003?nIVIT00ol0003o/k>c
ok>c/`0Gok>c/`03o`000?nIVIWoVIVI00GoVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIV
ofIVIP03ofIVIP03o`000?m<C4coC4a<01;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`05
o`000?nIVIWoVIVIoiVIVOl000001Onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c
00?o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00004oda<C003o`000?lc
<c?o<c<c00Go<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP;o000000GoOgmoo`000?nIVIWo
VIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo
000000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4co
C4a<o`0000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<
00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00009oc<c<`;o0000
00?oIVIVo`000?ooool01Oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00ooo
ool4oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<
C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVI
V@0:oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT01_nIVIT00ol0003oOgmoogmo
O`03ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<C4`04_m<C4`01Ol0003oIVIVofIV
I_mVIVKo000000?oOgmo00Go0000oiVIVOnIVIWoVIVIo`000005ok>c/`03o`000?o<c<coc<c<00Co
c<c<00?o0000ok>c/onc/k<00onc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIV
o`0000CoC4a<00?o0000oc<c<olc<c<01Olc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co
0000ogmoOomoOgoo00000_nIVIT01?l0003o/k>cok>c/ol00008olc<c007o`000?nc/k?o/k>cok>c
/ol0003oVIVIo`000002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<0
1?l0003oC4a<oda<C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<
olc<c006olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co0000
2Olc<c<2o`000003ofIVI_l0003ooooo00Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oo
oooooooo00?ooooo0onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o
0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?moOgooOgmo00SoOgmo00?o
0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00OoVIVI00?o
0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<01;oC4a<00?o
0000ofIVI_mVIVH00_mVIVH01?l0003oOgmoogmoOol00004oiVIV@03o`000?nc/k?o/k>c00;o/k>c
00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`05o`000?nIVIWoVIVIoiVIVOl0
00000_moOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<
C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o0000
2?o<c<`01ol0003o/k>cok>c/onc/k?o0000oiVIVOl000000_moOgl00ol0003oIVIVo`000002oda<
C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nI
VIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/ol0003oVIVI00;o0000
0_mVIVH00ol0003oC4a<o`000009oc<c<`;o000000?oIVIVo`000?ooool01Oooool1o`00007ooooo
0Oooool002Cooooo00?o0000ooooooooool00oooool2oiVIV@03o`000?moOgooOgmo00SoOgmo00?o
0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00_oIVIV00?o
0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o
0000oiVIVOnIVIT01_nIVIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o
0000oda<C?m<C4`04_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Go0000oiVIVOnIVIWo
VIVIo`000005ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00_nc/k<01Ol0003o
VIVIoiVIVOnIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`06
oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01?l0003o/k>c
ok>c/ol00009olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl01?l0003oIVIVofIVI_l0
0002oda<C003o`000?lc<c?o<c<c00Go<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmo
o`000002oiVIV@03o`000?nc/k?o000000Soc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmo
o`000?mVIVKo0000oda<C?l00009oc<c<`05o`000?m<C4co0000o`000?moOgl01_ooool1o`00007o
oooo0Oooool002Cooooo00?o0000ooooooooool00oooool00onIVIWo0000ogmoO`09ogmoO`03o`00
0?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`2o`0000coIVIV0_l0000:ogmoO`03o`00
0?nIVIWoVIVI00[oVIVI0_l0000Iok>c/`03o`000?nIVIWoVIVI00KoVIVI00?o0000ogmoOomoOgl0
0omoOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<01;oC4a<00?o0000ofIVI_mVIVH0
0_mVIVH01Ol0003oOgmoogmoOomoOgoo000000?oVIVI00?o0000ok>c/onc/k<00_nc/k<00ol0003o
c<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00?o0000oiVIVOnIVIT00_l00002ogmoO`04
o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01olc<c<01?l0003oC4a<oda<C?l00002
ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`01_l0003o/k>c
ok>c/ol0003oVIVIo`0000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c
<`04o`000?m<C4coC4a<o`0000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<
c<coc<c<00Koc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l0
0009oc<c<`05o`000?m<C4co0000o`000?moOgl01_ooool1o`00007ooooo0Oooool002Cooooo00?o
0000ooooooooool00oooool00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o
0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?moOgooOgmo00SoOgmo00?o
0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00KoVIVI00?o
0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<01?oC4a<00Go
0000ofIVI_mVIVKoIVIVo`000004ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0003o
c<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000omoOgl01?l0
003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`00
0002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`01_l0003o
/k>cok>c/ol0003oVIVIo`0000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06
oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV0_l00002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<
00?o0000ok>c/onc/k<00_l00002ogmoO`05o`000?mVIVKo0000oda<C?l000002Olc<c<01Ol0003o
C4a<o`000?l0003oOgmo00Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?o
oooo2_moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mV
IVH03?mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc
/k<05onc/k<00ol0003oVIVIoiVIV@07oiVIV@03o`000?moOgooOgmo00?oOgmo00?o0000ofIVI_mV
IVH00omVIVH00ol0003oC4a<oda<C00Boda<C005o`000?mVIVKoIVIVofIVI_l000001?moOgl01Ol0
003oVIVIoiVIVOnIVIWo000000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02
ok>c/`04o`000?nIVIWoVIVIo`0000?oOgmo00Go0000ofIVI_mVIVKoIVIVo`000002oda<C003o`00
0?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`00
00;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo
00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`03o`000?m<C4co000000;oIVIV
00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00co0000ok>c/onc
/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00009oc<c<`07o`000?m<C4co0000ofIV
I_l0003oOgmoo`000005ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03oooo
o`WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV
00_oIVIV0_l0000:ogmoO`03o`000?nIVIWoVIVI00[oVIVI0_l0000Iok>c/`;o00002?nIVIT00ol0
003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<C4`04_m<C4`00ol0
003oIVIVofIVIP02ofIVIP05o`000?moOgooOgmoogmoOol000000onIVIT00ol0003o/k>cok>c/`03
ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00onc/k<01?l0003oVIVIoiVIVOl0
0003ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<
oda<C?m<C4co000000;oIVIV00Ko0000ogmoOomoOgoo0000oiVIVOl00003ok>c/`03o`000?o<c<co
c<c<00Koc<c<00?o0000ok>c/onc/k<00_l000001?nIVIWo0000ogmoOol00002ofIVIP03o`000?m<
C4co000000[o<c<c00?o0000oda<C?l000000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c
00?o0000olc<c?o<c<`01_o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0
003oC4a<o`0000So<c<c00So0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000Gooooo0Ol00001
ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo2?moOgl00ol0003oIVIVofIVIP0;ofIV
IP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`09ogmo
O`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@08oiVI
V@03o`000?moOgooOgmo00?oOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00Boda<
C003o`000?mVIVKoIVIV00;oIVIV00Co0000ogmoOomoOgoo00001?nIVIT00ol0003o/k>cok>c/`03
ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00onc/k<01?l0003oVIVIoiVIVOl0
0003ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<
oda<C?l00002ofIVIP07o`000?moOgooOgmoogmoOol0003oVIVIo`000003ok>c/`03o`000?o<c<co
c<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIVIP03o`000?m<
C4co000000[o<c<c00Go0000oda<C?l0003oIVIVo`000002ogmoO`03o`000?nIVIWo000000;o/k>c
00?o0000olc<c?o<c<`01_o<c<`00ol0003o/k>co`000002oiVIV@04o`000?moOgoo0000o`0000;o
C4a<00?o0000oc<c<olc<c<01_lc<c<02?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo00001Ooo
ool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool7ogmoO`03o`000?mVIVKo
IVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`2o`0000coIVIV00?o0000ogmoOomoOgl02OmoOgl0
0ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02?nIVIT0
0ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<C4`04_m<C4`0
0ol0003oIVIVofIVIP02ofIVIP05o`000?moOgooOgmoogmoOol000000onIVIT00ol0003o/k>cok>c
/`03ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00onc/k<01?l0003oVIVIoiVI
VOl00003ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01Olc<c<01Ol0003o
C4a<oda<C?m<C4co000000;oIVIV00Ko0000ogmoOomoOgoo0000oiVIVOl00003ok>c/`03o`000?o<
c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`00
0?m<C4coC4a<o`0000Wo<c<c00?o0000oda<C?l000000_mVIVH01Ol0003oOgmoo`000?nIVIWo0000
00;o/k>c00?o0000olc<c?o<c<`01_o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000
ofIVI_l0003oC4a<o`0000So<c<c00So0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000Kooooo
0Ol00001ooooo`7ooooo000Tooooo`;o00001?ooool6ogmoO`03o`000?mVIVKoIVIV00[oIVIV0_l0
000Hoda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl2o`0000goVIVI00?o
0000ok>c/onc/k<05onc/k<2o`0000SoVIVI0_l00005ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o
0000oda<C?m<C4`04om<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Co0000oiVIVOnIVIWo
VIVI0_l00005ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00_nc/k<01Ol0003o
VIVIoiVIVOnIVIWo000000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000003oda<C003o`000?lc<c?o
<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP03o`000?moOgoo000000;oVIVI00Go
0000ok>c/onc/k?o/k>co`000008olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol0
00000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Go0000
ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00co0000ok>c/onc/k?o0000
oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00008oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo
0000ogmoOol00005ooooo`;o00000_ooool002Cooooo00?o0000ooooooooool00oooool5ogmoO`03
o`000?mVIVKoIVIV00[oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0;ofIVIP03
o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`0Gok>c/`03
o`000?nIVIWoVIVI00SoVIVI00?o0000ogmoOomoOgl01?moOgl00ol0003oIVIVofIVIP03ofIVIP03
o`000?m<C4coC4a<01?oC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`05o`000?nIVIWoVIVI
oiVIVOl000001_nc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000
oiVIVOnIVIWo00000omoOgl01Ol0003oIVIVofIVI_mVIVKo000000?oC4a<00?o0000oc<c<olc<c<0
1_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o0000ogmoOol000000_nIVIT01Ol0003o
/k>cok>c/onc/k?o000000Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002
ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Co0000oda<C?m<C4co00000_mVIVH01Ol0003oOgmo
o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`03?l0003o/k>cok>c/ol0003oVIVI
o`000?moOgoo0000ofIVI_l0003oC4a<o`0000So<c<c00So0000oda<C?m<C4co0000ofIVI_l0003o
Ogmoo`0000Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo1?moOgl0
0ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH0
0ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00coVIVI00?o0000ok>c/onc/k<05onc/k<0
0ol0003oVIVIoiVIV@08oiVIV@03o`000?moOgooOgmo00CoOgmo00?o0000ofIVI_mVIVH00omVIVH0
0ol0003oC4a<oda<C00Coda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01Ol0003oVIVIoiVI
VOnIVIWo000000Ko/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`02ok>c/`05o`00
0?nIVIWoVIVIoiVIVOl000000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000?oC4a<00?o0000oc<c
<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o0000ogmoOol000000_nIVIT0
1Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmo
o`000003ofIVIP04o`000?m<C4coC4a<o`0000Oo<c<c00Co0000oda<C?m<C4co00000_mVIVH01Ol0
003oOgmoo`000?nIVIWo000000?o/k>c00?o0000olc<c?o<c<`01Oo<c<`03?l0003o/k>cok>c/ol0
003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000Wo<c<c00Wo0000oda<C?l0003oIVIVo`00
0?moOgoo0000oiVIVOl000001Oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool0
0oooool3ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIV
ofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo0_l0000=oiVIV@03o`000?nc/k?o/k>c01Oo/k>c
00?o0000oiVIVOnIVIT02?nIVIT00ol0003oOgmoogmoO`04ogmoO`03o`000?mVIVKoIVIV00?oIVIV
00?o0000oda<C?m<C4`04om<C4`00ol0003oIVIVofIVIP02ofIVIP05o`000?moOgooOgmoogmoOol0
00000onIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc
/k<00onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`0
0ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00?o0000ofIVI_l000000_moOgl0
1?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o0000
0_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Ko0000oda<C?m<
C4co0000ofIVI_l00002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`0
3?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000Wo<c<c00Wo0000
oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl000001Oooool1o`00007ooooo0Oooool002Cooooo
00?o0000ooooooooool00oooool2ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`0
5_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT0
3?nIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00SoVIVI00?o0000ogmoOomoOgl0
1OmoOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH0
0_mVIVH01?l0003oOgmoogmoOol00004oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<
c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01?l0
003oIVIVofIVI_l00004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`0
0ol0003oIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<
c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co
00002?lc<c<02?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo00000_nIVIT01?l0003o/k>cok>c
/ol00008olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co0000
2Olc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000005ooooo`7o00000Oooool1
ooooo`009?ooool00ol0003oooooooooo`03ooooo`03ogmoOol0003oIVIV00coIVIV00?o0000oda<
C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVI
VOnIVIT03?nIVIT00ol0003o/k>cok>c/`0Fok>c/`;o00002onIVIT00ol0003oOgmoogmoO`04ogmo
O`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<C4`04om<C4`00ol0003oIVIVofIVIP02ofIV
IP05o`000?moOgooOgmoogmoOol000000onIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<co
c<c<00Coc<c<00?o0000ok>c/onc/k<00onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Co
0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`06oc<c<`07o`000?m<C4coC4a<oda<C?l0
003oIVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000_nc/k<00ol0003oc<c<olc<c006
olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<
C?l00008oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl00ol0003oVIVIo`000002ok>c
/`03o`000?o<c<coc<c<00Koc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo
0000oda<C?l00009oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000Kooooo
0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo00?o0000ofIVI_mVIVH02omV
IVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?mo
Ogl2o`0000goVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0:oiVIV@03o`000?mo
OgooOgmo00CoOgmo00?o0000ofIVI_mVIVH01?mVIVH00ol0003oC4a<oda<C00Boda<C003o`000?mV
IVKoIVIV00;oIVIV00Go0000ogmoOomoOgooOgmoo`000004oiVIV@03o`000?nc/k?o/k>c00?o/k>c
00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`04o`000?nIVIWoVIVIo`0000?o
Ogmo00Co0000ofIVI_mVIVKo00000om<C4`2o`0000Oo<c<c00Go0000oda<C?m<C4coC4a<o`000002
ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c004o`00
0?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00008oc<c
<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<
c<coc<c<00Koc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l0
0008oc<c<`;o000000SoC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000Kooooo0Ol00001oooo
o`7ooooo000Iooooo`Go00001_ooool00ol0003oooooooooo`03ooooo`goIVIV00?o0000oda<C?m<
C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnI
VIT02onIVIT2o`0001So/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`05ogmoO`03
o`000?mVIVKoIVIV00CoIVIV00?o0000oda<C?m<C4`04_m<C4`00ol0003oIVIVofIVIP02ofIVIP05
o`000?moOgooOgmoogmoOol000000onIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<
00Coc<c<00?o0000ok>c/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Co0000
ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l00000
0_mVIVH01?l0003oOgmoogmoOol00002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01?l0
003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc
<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003o
c<c<olc<c006olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co
00002?lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00006ooooo`7o0000
0Oooool1ooooo`006Oooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0
0oooool<ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmo
ogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVI
oiVIV@0:oiVIV@03o`000?moOgooOgmo00GoOgmo00?o0000ofIVI_mVIVH01?mVIVH00ol0003oC4a<
oda<C00Boda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgooOgmoo`000004oiVIV@03
o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`03ok>c/`04
o`000?nIVIWoVIVIo`0000?oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06
oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@05o`00
0?nc/k?o/k>cok>c/ol000002?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo0000
00;oIVIV00Co0000oda<C?m<C4co00002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP05o`000?mo
Ogoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c00:o`000?nc/k?o/k>co`000?nI
VIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02_l0003oC4a<o`00
0?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k<6ooooo`7o00000Oooool1ooooo`006_ooool00onH
V9So8B4Qonk^kP07ooooo`03o`000?oooooooooo00?ooooo2omVIVH00ol0003oC4a<oda<C00Foda<
C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVI
V@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`05ogmo
O`03o`000?mVIVKoIVIV00CoIVIV00?o0000oda<C?m<C4`04_m<C4`00ol0003oIVIVofIVIP02ofIV
IP03o`000?moOgooOgmo00;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000006ok>c/`03o`000?o<c<co
c<c<00?oc<c<00?o0000ok>c/onc/k<00onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Go
0000ofIVI_mVIVKoIVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4co
C4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`0
1Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<
C?l00008oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl00ol0003oVIVIo`000002ok>c
/`03o`000?o<c<coc<c<00Koc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo
0000oda<C?l00009oc<c<`0:o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/`Ko
oooo0Ol00001ooooo`7ooooo000Kooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol00003ooooo`[oIVIV
00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP;o00002_moOgl00ol0003oVIVI
oiVIV@0:oiVIV@;o00006?nc/k<00ol0003oVIVIoiVIV@0:oiVIV@03o`000?moOgooOgmo00GoOgmo
00?o0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<C00Boda<C003o`000?mVIVKoIVIV00;oIVIV
00?o0000ogmoOomoOgl00_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Ko/k>c00?o0000olc<c?o<
c<`00oo<c<`00ol0003o/k>cok>c/`03ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01?l0
003oIVIVofIVI_l00004oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`00
0002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01Ol0003o
/k>cok>c/onc/k?o000000;oVIVI00Go0000ogmoOol0003oIVIVo`000003oda<C003o`000?lc<c?o
<c<c00Ko<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`05o`000?nIVIWo0000ok>c/ol0
00002Oo<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000Wo
<c<c00_o0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`000003ooooo`?o0000
0_ooool001cooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`03ooooo`WoIVIV00?o
0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o
0000oiVIVOnIVIT02_nIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00[oVIVI00?o
0000ogmoOomoOgl01OmoOgl00ol0003oIVIVofIVIP05ofIVIP03o`000?m<C4coC4a<01?oC4a<00Go
0000ofIVI_mVIVKoIVIVo`000004ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001_nc/k<00ol0003o
c<c<olc<c003olc<c003o`000?nc/k?o/k>c00?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmo
O`05o`000?mVIVKoIVIVofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4co
C4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000So
c<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@03o`000?moOgoo000000;oIVIV00Go0000oda<
C?m<C4coC4a<o`000007oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl00ol0003oVIVI
o`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmo
o`000?mVIVKo0000oda<C?l00009oc<c<`03o`000?m<C4co000000;oIVIV0_l000001OnIVIWo0000
ok>c/onc/k?o000000Gooooo0Ol00001ooooo`7ooooo000Mooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00oooool8ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH0
2omVIVH00ol0003oOgmoogmoO`08ogmoO`;o00003?nIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`00
0?nIVIWoVIVI00[oVIVI00?o0000ogmoOomoOgl01OmoOgl00ol0003oIVIVofIVIP05ofIVIP03o`00
0?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000Co
VIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o
/k>c00Co0000oiVIVOnIVIWo00000omoOgl01?l0003oIVIVofIVI_l00004oda<C003o`000?lc<c?o
<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nI
VIWoVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01ol0003o/k>cok>c/onc/k?o0000oiVI
VOl000000_moOgl00ol0003oIVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c00So0000oda<
C?m<C4co0000ofIVI_l0003oOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`03?l0003o
/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000Wo<c<c00_o0000oda<C?l0
003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`000006ooooo`7o00000Oooool1ooooo`006Ooo
ool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool00oooool7ofIVIP03o`00
0?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH2o`0000[oOgmo00?o0000oiVIVOnIVIT0
2_nIVIT2o`0001So/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`05ogmoO`03o`00
0?mVIVKoIVIV00GoIVIV00?o0000oda<C?m<C4`04om<C4`00ol0003oIVIVofIVIP02ofIVIP05o`00
0?moOgooOgmoogmoOol000000onIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00Co
c<c<00?o0000ok>c/onc/k<00onc/k<01?l0003oVIVIoiVIVOl00003ogmoO`04o`000?mVIVKoIVIV
o`0000CoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C006o`000?mVIVKo
IVIVo`000?moOgoo00000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Oo0000ok>c/onc
/k?o/k>co`000?nIVIWo000000;oOgmo00?o0000ofIVI_l000000om<C4`00ol0003o<c<coc<c<`06
oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVIV@04o`000?nc/k?o/k>co`00
00Soc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00009oc<c
<`0;o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol000001_ooool1o`00007o
oooo0Oooool000_ooooo0ol000000ol@413oooooooooo`08ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`01_ooool00ol0003oooooooooo`03ooooo`GoIVIV0_l0000Hoda<C003o`000?mVIVKoIVIV00_o
IVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0:oiVIV@03o`000?nc/k?o/k>c01Oo
/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV00Go
IVIV00?o0000oda<C?m<C4`04om<C4`00ol0003oIVIVofIVIP02ofIVIP05o`000?moOgooOgmoogmo
Ool000001?nIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c
/onc/k<00onc/k<01?l0003oVIVIoiVIVOl00003ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o
0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo
00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`00
00;oVIVI00Go0000ogmoOol0003oIVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Ko0000
oda<C?m<C4co0000ofIVI_l00002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`0
1_o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000Wo<c<c
00?o0000oda<C?m<C4`00_l000001?moOgoo0000oiVIVOnIVIT2o`000003olc<c?oooooooooo00Co
oooo0Ol00001ooooo`7ooooo000=ooooo`03oa0@4?nj^[[ooooo01Cooooo00?o0000ooooooooool0
0oooool4ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmo
ogmoO`08ogmoO`;o00003?nIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00_oVIVI
00?o0000ogmoOomoOgl01OmoOgl00ol0003oIVIVofIVIP05ofIVIP03o`000?m<C4coC4a<01?oC4a<
00?o0000ofIVI_mVIVH00_mVIVH00ol0003oOgmoogmoO`02ogmoO`05o`000?nIVIWoVIVIoiVIVOl0
00001_nc/k<00ol0003oc<c<olc<c003olc<c0;o00001?nc/k<01Ol0003oVIVIoiVIVOnIVIWo0000
00;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000
oda<C?m<C4coC4a<o`000003ofIVIP03o`000?moOgoo000000;oVIVI00Go0000ok>c/onc/k?o/k>c
o`000008olc<c007o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000002ogmoO`03o`000?mVIVKo0000
00?oC4a<00?o0000oc<c<olc<c<01_lc<c<02?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000
0_nIVIT01?l0003o/k>cok>c/ol00008olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0
003oIVIVo`000?m<C4co00002Olc<c<03?l0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`00
0?nc/k?o0000olc<c0Kooooo0Ol00001ooooo`7ooooo000=ooooo`03oiRHV?lb<S;ooooo01Cooooo
00?o0000ooooooooool00oooool4ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH0
2omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00[oVIVI00?o0000ok>c/onc/k<0
5onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH0
1OmVIVH00ol0003oC4a<oda<C00Coda<C003o`000?mVIVKoIVIV00;oIVIV00?o0000ogmoOomoOgl0
0_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Ko/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003o
/k>cok>c/`03ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01Ol0003oIVIVofIVI_mVIVKo
000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000?oIVIV00?o
0000ogmoOol000000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Oo0000ok>c/onc/k?o
/k>co`000?nIVIWo000000;oOgmo00?o0000ofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c
<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000So
c<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00009oc<c<`0<
o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol0003oc<c<1_ooool1o`00007o
oooo0Oooool000gooooo00?ogMgMo`000?nj^[X05?ooool00ol0003oooooooooo`03ooooo`?oIVIV
00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?moOgooOgmo00SoOgmo
00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI
00?o0000ogmoOomoOgl01_moOgl00ol0003oIVIVofIVIP05ofIVIP03o`000?m<C4coC4a<01CoC4a<
00Go0000ofIVI_mVIVKoIVIVo`000004ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001_nc/k<00ol0
003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002
ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<
C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003o
c<c<olc<c006olc<c007o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000002ogmoO`03o`000?mVIVKo
000000?oC4a<00?o0000oc<c<olc<c<01Olc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?mo
Ogoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`00ol0003o/k>co`000002oiVIV@04o`00
0?moOgoo0000o`0000;oC4a<00?o0000oc<c<olc<c<01olc<c<03?l0003oC4a<o`000?mVIVKo0000
ogmoOol0003oVIVIo`000?nc/k?o0000olc<c0Kooooo0Ol00001ooooo`7ooooo000=ooooo`03oeEE
EOmgMgOoA4A401Cooooo00?o0000ooooooooool00oooool2ofIVIP03o`000?m<C4coC4a<01OoC4a<
00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI
00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00KoOgmo
00?o0000ofIVI_mVIVH01_mVIVH00ol0003oC4a<oda<C00Coda<C003o`000?mVIVKoIVIV00;oIVIV
00?o0000ogmoOomoOgl00_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Ko/k>c00?o0000olc<c?o<
c<`00oo<c<`00ol0003o/k>cok>c/`03ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01Ol0
003oIVIVofIVI_mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<
C4co000000?oIVIV00?o0000ogmoOol000000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<
00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo00?o0000ofIVI_l000000om<C4`00ol0
003o<c<coc<c<`06oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVIV@04o`00
0?nc/k?o/k>co`0000Soc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000
0_m<C4`00ol0003o<c<coc<c<`06oc<c<`0;o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo
0000ok>c/ol000000_o<c<`6ooooo`7o00000Oooool1ooooo`003?ooool01OoMgMgo410@oooooolQ
8B7ogMgM01?ooooo00?o0000ooooooooool00oooool00omVIVKo0000oda<C00Goda<C0;o00003?mV
IVH2o`0000[oOgmo00?o0000oiVIVOnIVIT02_nIVIT2o`0001So/k>c00?o0000oiVIVOnIVIT02onI
VIT2o`0000SoOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<C00Coda<C003o`000?mV
IVKoIVIV00;oIVIV00?o0000ogmoOomoOgl00_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Ko/k>c
00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`05o`000?nIVIWoVIVIoiVIVOl0
00000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0
003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01Ol0003o/k>cok>c
/onc/k?o000000Soc<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo00?o0000ofIV
I_l000000_m<C4`2o`0000So<c<c00So0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000;oVIVI
00Co0000ok>c/onc/k?o00002?o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIV
I_l0003oC4a<o`0000Wo<c<c00_o0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>c
o`000002olc<c0Kooooo0Ol00001ooooo`7ooooo000<ooooo`05ofIVI_n7QhOooooooiRHV?mEEED0
4oooool2o`0000Cooooo00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`00
0?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`00
0?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl01omoOgl00ol0003oIVIVofIVIP05ofIVIP03o`00
0?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`02ogmoO`05o`00
0?nIVIWoVIVIoiVIVOl000001_nc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o
/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`05o`000?mVIVKoIVIVofIVI_l000000om<C4`0
0ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmo
Ool00002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`02Ol0003o/k>cok>c/onc/k?o0000
oiVIVOl0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000Wo<c<c00[o0000oda<C?m<C4co
0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c007olc<c00<o`000?nc
/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co00002Olc<c<02ol0003oC4a<o`00
0?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o000000;oc<c<1Oooool2o`0000;ooooo000;oooo
o`03onk^k_l0003ok^k^00;ooooo00?o0000omgMgOooool04Oooool00ol0003oooooooooo`03oooo
oaSoC4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI
00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo
00OoOgmo00?o0000ofIVI_mVIVH01_mVIVH00ol0003oC4a<oda<C00Boda<C003o`000?mVIVKoIVIV
00CoIVIV00Go0000ogmoOomoOgooOgmoo`000003oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000
olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_mo
Ogl01Ol0003oIVIVofIVI_mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<
oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01Ol0003o/k>cok>c/onc/k?o
000000Soc<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo00?o0000ofIVI_l00000
0_m<C4`00ol0003o<c<coc<c<`07oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002
oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`00
0?mVIVKo0000oda<C?l00009oc<c<`03o`000?m<C4co000000;oIVIV0_l000001OnIVIWo0000ok>c
/onc/k?o000000;oc<c<1_ooool1o`00007ooooo0Oooool000_ooooo00Co410@o`000?l0003ooooo
0_l000000ol@413oooooooooo`0@ooooo`03o`000?oooooooooo00?ooooo5om<C4`00ol0003oIVIV
ofIVIP0;ofIVIP;o00002_moOgl00ol0003oVIVIoiVIV@0:oiVIV@;o00006?nc/k<00ol0003oVIVI
oiVIV@0;oiVIV@03o`000?moOgooOgmo00OoOgmo00?o0000ofIVI_mVIVH01_mVIVH00ol0003oC4a<
oda<C00Coda<C003o`000?mVIVKoIVIV00?oIVIV00Go0000ogmoOomoOgooOgmoo`000004oiVIV@03
o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`03ok>c/`05
o`000?nIVIWoVIVIoiVIVOl000000omoOgl01?l0003oIVIVofIVI_l00004oda<C003o`000?lc<c?o
<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nI
VIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@06
o`000?moOgooOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`07oc<c<`08o`000?m<C4co
C4a<o`000?mVIVKo0000ogmoOol00002oiVIV@03o`000?nc/k?o000000Woc<c<00co0000ok>c/onc
/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00009oc<c<`0;o`000?m<C4co0000ofIV
I_l0003oOgmoo`000?nIVIWo0000ok>c/ol000000oo<c<`6ooooo`7o00000Oooool1ooooo`009?oo
ool00ol0003oooooooooo`03oooooaOoC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmo
O`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVI
V@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<
C00Doda<C003o`000?mVIVKoIVIV00?oIVIV00Go0000ogmoOomoOgooOgmoo`000004oiVIV@03o`00
0?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`03ok>c/`05o`00
0?nIVIWoVIVIoiVIVOl000000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000CoC4a<00?o0000oc<c
<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co0000
oiVIVOnIVIWo00000_nc/k<00ol0003oc<c<olc<c007olc<c004o`000?nc/k?o/k>co`0000;oVIVI
00Ko0000ogmoOomoOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c00So0000oda<
C?m<C4co0000ofIVI_l0003oOgmoo`0000;oVIVI00?o0000ok>c/ol000002Oo<c<`03?l0003o/k>c
ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000Wo<c<c00_o0000oda<C?l0003o
IVIVo`000?moOgoo0000oiVIVOl0003o/k>co`000003olc<c0Kooooo0Ol00001ooooo`7ooooo000T
ooooo`03o`000?oooooooooo00?ooooo5Om<C4`2o`0000coIVIV00?o0000ogmoOomoOgl02OmoOgl0
0ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT0
0ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00GoIVIV00?o0000oda<C?m<C4`05?m<C4`0
0ol0003oIVIVofIVIP03ofIVIP05o`000?moOgooOgmoogmoOol000001?nIVIT00ol0003o/k>cok>c
/`04ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00onc/k<01Ol0003oVIVIoiVI
VOnIVIWo000000?oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03
o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00003
ok>c/`03o`000?o<c<coc<c<00Koc<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo
00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`06o`000?m<C4coC4a<o`000?mV
IVKo00000_moOgl01Ol0003oVIVIo`000?nc/k?o000000Woc<c<00[o0000ok>c/onc/k?o0000oiVI
VOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`03o`000?m<C4coC4a<
00;o000000CoOgmoo`000?nIVIWoVIVI0_l00004olc<c0Kooooo0Ol00001ooooo`7ooooo000Toooo
o`03o`000?oooooooooo00?ooooo5?m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo
00SoOgmo0_l0000=oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0
003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00GoIVIV00?o0000oda<C?m<C4`05?m<C4`00ol0
003oIVIVofIVIP03ofIVIP03o`000?moOgooOgmo00;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000007
ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o0000ok>c/onc/k<01?nc/k<01Ol0003oVIVIoiVIVOnI
VIWo000000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go<c<c
00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`00
00;o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000
ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo
0000ogmoOol00002oiVIV@03o`000?nc/k?o000000Woc<c<00?o0000ok>c/ol000000_nIVIT01Ol0
003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02ol0003oC4a<o`000?mV
IVKo0000ogmoOol0003oVIVIo`000?nc/k?o000000Coc<c<1_ooool1o`00007ooooo0Oooool002Co
oooo00?o0000ooooooooool00ooooolCoda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomo
Ogl02?moOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnI
VIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00KoIVIV00?o0000oda<C?m<
C4`04om<C4`00ol0003oIVIVofIVIP04ofIVIP03o`000?moOgooOgmo00;oOgmo00Go0000oiVIVOnI
VIWoVIVIo`000007ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o0000ok>c/onc/k<01?nc/k<01Ol0
003oVIVIoiVIVOnIVIWo000000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc
<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`00
0?nIVIWoVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o0000
00;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`08o`000?m<C4co
C4a<o`000?mVIVKo0000ogmoOol00002oiVIV@03o`000?nc/k?o000000Woc<c<00?o0000ok>c/ol0
00000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01Olc<c<03?l0
003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Coc<c<1_ooool1o`00
007ooooo0Oooool002Cooooo00?o0000ooooooooool00ooooolBoda<C003o`000?mVIVKoIVIV00_o
IVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Ko
/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00Ko
IVIV00?o0000oda<C?m<C4`05?m<C4`00ol0003oIVIVofIVIP03ofIVIP03o`000?moOgooOgmo00;o
Ogmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00;o
c<c<00?o0000ok>c/onc/k<01?nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Go0000ofIV
I_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`00
0002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01Ol0003o
/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00009
oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVIV@03o`000?nc/k?o000000Wo
c<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<c
oc<c<`06oc<c<`05o`000?m<C4co0000ofIVI_l000000_moOgl2o`0000;o/k>c00?o0000olc<c?o<
c<`00_o<c<`6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03oooooa7oC4a<
00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`;o00003OnIVIT00ol0003o/k>c
ok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIV
ofIVIP06ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmo
ogmoO`02ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<
olc<c003olc<c003o`000?nc/k?o/k>c00?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`04
o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co
000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<
00Go0000ok>c/onc/k?o/k>co`000002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<
C4co00002?lc<c<02Ol0003oC4a<oda<C?m<C4co0000ofIVI_l0003oOgmoo`000002oiVIV@03o`00
0?nc/k?o000000Woc<c<00?o0000ok>c/ol000000_nIVIT01ol0003oOgmoo`000?mVIVKo0000oda<
C?l000002Olc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c/`03o`00
0?o<c<coc<c<00;oc<c<1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00ooo
ool@oda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVI
V@0<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmo
O`08ogmoO`03o`000?mVIVKoIVIV00KoIVIV00?o0000oda<C?m<C4`05Om<C4`00ol0003oIVIVofIV
IP03ofIVIP03o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c
/`04ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00onc/k<01Ol0003oVIVIoiVI
VOnIVIWo000000?oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`06oc<c<`05
o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@05o`000?nc/k?o
/k>cok>c/ol000002?o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmoOol00000
0_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`09o`000?m<C4coC4a<oda<C?l0003oIVIVo`000?mo
Ogoo000000;oVIVI00?o0000ok>c/ol000002Oo<c<`00ol0003o/k>co`000002oiVIV@07o`000?mo
Ogoo0000ofIVI_l0003oC4a<o`000009oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nI
VIWo000000;o/k>c00?o0000olc<c?o<c<`00_o<c<`6ooooo`7o00000Oooool1ooooo`009?ooool2
o`0000Cooooo3om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000
oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000
ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP07ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000
ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000
ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c00?o/k>c00?o0000
oiVIVOnIVIT00_nIVIT01?l0003oOgmoogmoOol00002ofIVIP03o`000?m<C4coC4a<00;oC4a<00?o
0000oc<c<olc<c<01_lc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo
00Co0000oiVIVOnIVIWo00000_nc/k<00ol0003oc<c<olc<c007olc<c004o`000?nc/k?o/k>co`00
00;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`09o`000?m<C4co
C4a<oda<C?l0003oIVIVo`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`00ol0
003o/k>co`000002oiVIV@07o`000?moOgoo0000ofIVI_l0003oC4a<o`000009oc<c<`03o`000?m<
C4co000000;oIVIV0_l000001OnIVIWo0000ok>c/onc/k?o000000Goc<c<1Oooool2o`0000;ooooo
000Tooooo`03o`000?oooooooooo00?ooooo3_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?mo
OgooOgmo00SoOgmo0_l0000=oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onI
VIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00OoIVIV00?o0000oda<C?m<C4`05?m<
C4`00ol0003oIVIVofIVIP03ofIVIP03o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00_nI
VIT00ol0003o/k>cok>c/`05ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o0000ok>c/onc/k<01?nc
/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003
o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmo
o`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c005o`000?nc/k?o/k>cok>c/ol00000
0_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Co0000oda<C?m<
C4co00000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`0
0ol0003o/k>co`000002oiVIV@07o`000?moOgoo0000ofIVI_l0003oC4a<o`000009oc<c<`09o`00
0?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`00oo<c<`6
ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`goC4a<00?o0000ofIV
I_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI0_l0000Hok>c
/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP07ofIV
IP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`02ogmo
O`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01Onc/k<01Ol0003oc<c<olc<c?o<c<co
000000Oo/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`05o`000?mVIVKoIVIVofIVI_l00000
1?m<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003o
OgmoogmoOol00002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01Ol0003o/k>cok>c/onc
/k?o000000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`04o`00
0?m<C4coC4a<o`0000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<
00Ooc<c<00?o0000ok>c/ol000000_nIVIT01ol0003oOgmoo`000?mVIVKo0000oda<C?l000002Olc
<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<
00?oc<c<1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool<oda<C003
o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03
o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`;o
00002OmVIVH00ol0003oC4a<oda<C00Doda<C003o`000?mVIVKoIVIV00?oIVIV00?o0000ogmoOomo
Ogl00_moOgl00ol0003oVIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c00Go/k>c00?o0000olc<c?o<
c<`00_o<c<`00ol0003o/k>cok>c/`04ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01Ol0
003oIVIVofIVI_mVIVKo000000CoC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<
C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000So
c<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<
C?m<C4co00002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgooOgmo00;o00000_nc
/k<00ol0003oc<c<olc<c007olc<c003o`000?nc/k?o000000;oVIVI00Go0000ogmoOol0003oIVIV
o`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Oo0000oda<C?l0003oIVIVo`000?moOgoo0000
00;oVIVI00?o0000ok>c/ol000001_o<c<`6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003o
ooooooooo`03ooooo`_oC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03
o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03
o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02?mVIVH00ol0003oC4a<oda<C00Doda<C003
o`000?mVIVKoIVIV00?oIVIV00?o0000ogmoOomoOgl00_moOgl2o`0000?oVIVI00?o0000ok>c/onc
/k<01Onc/k<00ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c00Co/k>c0_l00002oiVIV@05
o`000?moOgooOgmoogmoOol000000omVIVH00ol0003oC4a<oda<C002oda<C003o`000?lc<c?o<c<c
00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWo
VIVIo`0000;o/k>c00?o0000olc<c?o<c<`01oo<c<`01ol0003o/k>cok>c/onc/k?o0000oiVIVOl0
00000_moOgl01?l0003oIVIVofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<
C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01oo<
c<`00ol0003o/k>co`000002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<c
oc<c<`06oc<c<`0;o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol000001oo<
c<`6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`[oC4a<00?o0000
ofIVI_mVIVH02omVIVH2o`0000[oOgmo00?o0000oiVIVOnIVIT02_nIVIT2o`0001So/k>c00?o0000
oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00SoIVIV00?o0000
oda<C?m<C4`05?m<C4`00ol0003oIVIVofIVIP03ofIVIP03o`000?moOgooOgmo00;oOgmo00?o0000
oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`05ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o0000
ok>c/onc/k<01?nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Go0000ofIVI_mVIVKoIVIV
o`000004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIV
ofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01oo<c<`01ol0
003o/k>cok>c/onc/k?o0000oiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00002oda<C003o`00
0?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nIVIWo0000
00;o/k>c00?o0000olc<c?o<c<`01oo<c<`00ol0003o/k>co`000002oiVIV@05o`000?moOgoo0000
ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`05oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000
ogmoOol0003oVIVIo`000?nc/k?o00001oo<c<`6ooooo`7o00000Oooool1ooooo`009?ooool00ol0
003oooooooooo`03ooooo`WoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`09ogmo
O`03o`000?nIVIWoVIVI00[oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0;oiVI
V@03o`000?moOgooOgmo00SoOgmo0_l0000:ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIV
I_mVIVH00omVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c
/onc/k<01_nc/k<01Ol0003oc<c<olc<c?o<c<co000000Ko/k>c00?o0000oiVIVOnIVIT00_nIVIT0
1?l0003oOgmoogmoOol00003ofIVIP03o`000?m<C4coC4a<00;oC4a<00?o0000oc<c<olc<c<01Olc
<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo
00000onc/k<00ol0003oc<c<olc<c006olc<c007o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000002
ogmoO`04o`000?mVIVKoIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01olc<c<02_l0003oC4a<oda<
C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00[o0000
ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c
<`05o`000?m<C4co0000ofIVI_l000000_moOgl2o`0000;o/k>c00?o0000olc<c?o<c<`01Oo<c<`6
ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`SoC4a<00?o0000ofIV
I_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`;o00003?nIVIT00ol0003o/k>cok>c/`0Gok>c
/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP09ofIV
IP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH01?mVIVH00ol0003oOgmoogmoO`02ogmo
O`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01Onc/k<01Ol0003oc<c<olc<c?o<c<co
000000Oo/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<
00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?m<C4`2o`0000;oIVIV00Co0000ogmoOomo
Ogoo00000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Co0000ok>c/onc/k?o00000_nI
VIT01_l0003oOgmoogmoOol0003oIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003o
C4a<oda<C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007
olc<c00:o`000?nc/k?o0000o`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c
<olc<c<01_lc<c<01_l0003oC4a<o`000?mVIVKo0000ogmoO`?o00000_nc/k<00ol0003oc<c<olc<
c005olc<c0Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo1om<C4`0
0ol0003oIVIVofIVIP0;ofIVIP;o00002_moOgl00ol0003oVIVIoiVIV@0:oiVIV@;o00006?nc/k<0
0ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02?mVIVH0
0ol0003oC4a<oda<C00Eoda<C003o`000?mVIVKoIVIV00CoIVIV00Go0000ogmoOomoOgooOgmoo`00
0005oiVIV@03o`000?nc/k?o/k>c00Go/k>c00Go0000olc<c?o<c<coc<c<o`000007ok>c/`05o`00
0?nIVIWoVIVIoiVIVOl000000omoOgl01?l0003oIVIVofIVI_l00004oda<C003o`000?lc<c?o<c<c
00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000003ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Go
0000ok>c/onc/k?o/k>co`000008olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Ko0000ogmoOomo
Ogoo0000ofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mV
IVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>c
ok>c/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c
<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`0
1Oo<c<`6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`KoC4a<00?o
0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00[oVIVI00?o
0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo0_l0
000:ofIVIP03o`000?m<C4coC4a<01GoC4a<00?o0000ofIVI_mVIVH01?mVIVH01Ol0003oOgmoogmo
OomoOgoo000000GoVIVI00?o0000ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c002olc<c003o`00
0?nc/k?o/k>c00Co/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`05o`000?mVIVKoIVIVofIV
I_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000omVIVH0
1?l0003oOgmoogmoOol00002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01Ol0003o/k>c
ok>c/onc/k?o000000;oVIVI00Go0000ogmoOol0003oIVIVo`000003oda<C003o`000?lc<c?o<c<c
00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o
/k>co`0000Soc<c<00?o0000ok>c/ol000000_nIVIT00ol0003oOgmoo`000002ofIVIP03o`000?m<
C4co000000So<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl000000_nc/k<00ol0
003oc<c<olc<c006olc<c0Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?o
oooo1Om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo0_l0000<oiVIV@03
o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03
o`000?mVIVKoIVIV00WoIVIV00?o0000oda<C?m<C4`05Om<C4`00ol0003oIVIVofIVIP04ofIVIP03
o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`06ok>c/`05
o`000?o<c<coc<c<olc<c?l000001_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Go0000
ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<
C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<
c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Ko0000ogmoOomoOgoo0000ofIVI_l0
0002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Co0000oda<C?m<C4co00000_mVIVH01Ol0003oOgmo
o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVI
V@07o`000?moOgoo0000ofIVI_l0003oC4a<o`000009oc<c<`09o`000?m<C4co0000ofIVI_l0003o
Ogmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003oooooooooo`03oooo
o`7o00000Oooool1ooooo`009?ooool2o`0000Cooooo1?m<C4`00ol0003oIVIVofIVIP0;ofIVIP03
o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02_nIVIT00ol0003o/k>cok>c/`0Gok>c/`03
o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0:ofIVIP03
o`000?m<C4coC4a<01GoC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`03ogmoO`03
o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01_nc/k<01Ol0003oc<c<olc<c?o<c<co0000
00Ko/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`05o`000?mVIVKoIVIVofIVI_l000001?m<
C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo0000
0_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc
/k?o/k>co`000002oiVIV@06o`000?moOgooOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c
<`07oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03
o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT01ol0003oOgmoo`000?mVIVKo
0000oda<C?l000002Olc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c
/`03o`000?o<c<coc<c<00Koc<c<00?o0000ooooooooool00_ooool2o`0000;ooooo000Tooooo`03
o`000?oooooooooo00?ooooo0om<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?moOgooOgmo00So
Ogmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_o
VIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<01Ko
C4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00;o
VIVI00?o0000ok>c/onc/k<01_nc/k<3o`000003olc<c?l0003o/k>c00Ko/k>c00Go0000oiVIVOnI
VIWoVIVIo`000003ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01_lc<c<0
0ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo0000
0onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT00ol0003o
Ogmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000Wo<c<c00Ko0000oda<C?m<C4co0000ofIVI_l0
0002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c
/ol00002oiVIV@07o`000?moOgoo0000ofIVI_l0003oC4a<o`000009oc<c<`09o`000?m<C4co0000
ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003ooooo
ooooo`03ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`?oC4a<00?o
0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o
0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o
0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<oda<C00Eoda<C003o`000?mVIVKoIVIV00?oIVIV00?o
0000ogmoOomoOgl00omoOgl00ol0003oVIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c00Ko/k>c00Co
0000olc<c?l0003o00001onc/k<00ol0003oVIVIoiVIV@02oiVIV@04o`000?moOgooOgmoo`0000?o
IVIV00?o0000oda<C?m<C4`00_m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;o
C4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<co
c<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@06o`000?moOgooOgmoo`000?mVIVKo
00000om<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Go0000ogmo
Ool0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00?o0000ok>c/ol000000_nIVIT0
1Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01ol0003oC4a<o`00
0?mVIVKo0000ogmoOol000000_nIVIT00ol0003o/k>co`000008olc<c003o`000?oooooooooo00Co
oooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo00?oC4a<o`000?l00000
3?mVIVH2o`0000[oOgmo00?o0000oiVIVOnIVIT02_nIVIT2o`0001So/k>c00?o0000oiVIVOnIVIT0
2onIVIT00ol0003oOgmoogmoO`08ogmoO`;o00003?mVIVH00ol0003oC4a<oda<C00Eoda<C003o`00
0?mVIVKoIVIV00CoIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@02oiVIV@03o`00
0?nc/k?o/k>c00Ko/k>c00Go0000olc<c?o<c<coc<c<o`000007ok>c/`05o`000?nIVIWoVIVIoiVI
VOl000000omoOgl01?l0003oIVIVofIVI_l00005oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000
oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c
00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmoOol0
00000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000Oo<c<c0_l00002oda<C003o`000?mVIVKo0000
00;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c003o`000?nc/k?o0000
00;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Wo0000
oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c003
o`000?oooooooooo00Cooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo
00?o0000ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI
00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo
00?o0000ofIVI_mVIVH03?mVIVH00ol0003oC4a<oda<C00Doda<C003o`000?mVIVKoIVIV00CoIVIV
00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c00Ko/k>c
00Go0000olc<c?o<c<coc<c<o`000006ok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomo
OgooOgmoo`000002ofIVIP03o`000?m<C4coC4a<00?oC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0
003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo00000onc
/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Ko0000oiVIVOnIVIWo0000
ogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Oo0000oda<C?m<C4coC4a<o`000?mV
IVKo000000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c003o`000?nc
/k?o000000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Go<c<c
00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<
c006olc<c003o`000?oooooooooo00Cooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooo
oooo00?ooooo3_mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000
ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000
ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Eoda<C003o`000?mVIVKoIVIV00?oIVIV00?o0000
ogmoOomoOgl00omoOgl00ol0003oVIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c00Ko/k>c00Go0000
olc<c?o<c<coc<c<o`000006ok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomoOgooOgmo
o`000003ofIVIP03o`000?m<C4coC4a<00;oC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<
oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0
003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01_l0003oOgmoogmoOol0
003oIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?m<C4`2o`0000;o
Ogmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c003o`000?nc/k?o000000;o
VIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Wo0000oda<
C?l0003oIVIVo`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c003o`00
0?nc/k?ooooo00Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo3?mV
IVH2o`0000[oOgmo00?o0000oiVIVOnIVIT02_nIVIT2o`0001So/k>c00?o0000oiVIVOnIVIT02onI
VIT00ol0003oOgmoogmoO`08ogmoO`;o00003OmVIVH00ol0003oC4a<oda<C00Eoda<C003o`000?mV
IVKoIVIV00CoIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc
/k?o/k>c00Ko/k>c0_l000000oo<c<co0000ok>c/`06ok>c/`05o`000?nIVIWoVIVIoiVIVOl00000
0omoOgl01Ol0003oIVIVofIVI_mVIVKo000000GoC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003o
C4a<oda<C002oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00003
ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@03o`000?mo
Ogoo000000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<01_l0003oC4a<oda<C?l0003oIVIVo`00
00;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>c
o`0000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Wo
0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<
c003o`000?nc/k?ooooo00Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?o
oooo2omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc
/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mV
IVH03?mVIVH00ol0003oC4a<oda<C00Eoda<C003o`000?mVIVKoIVIV00GoIVIV00?o0000ogmoOomo
Ogl00_moOgl00ol0003oVIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c00Wo/k>c00?o0000ok>c/onc
/k<01_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Go0000ofIVI_mVIVKoIVIVo`000005
oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mV
IVKo000000;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c005o`00
0?nc/k?o/k>cok>c/ol000000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`00
00Wo<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`03o`000?nIVIWo000000;o/k>c00?o
0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l0
00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nI
VIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003o/k>co`000005ooooo`7o00000Ooo
ool1ooooo`006oooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool00oooool:
ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0F
ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0;
ofIVIP03o`000?m<C4coC4a<01GoC4a<00?o0000ofIVI_mVIVH01OmVIVH00ol0003oOgmoogmoO`02
ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<04_nc/k<01Ol0003oVIVIoiVIVOnI
VIWo000000?oOgmo00Go0000ofIVI_mVIVKoIVIVo`000005oda<C003o`000?lc<c?o<c<c00Co<c<c
00?o0000oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Co0000oiVIVOnI
VIWo00000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT0
0ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000Wo<c<c00Ko0000oda<C?m<C4co0000
ofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01Oo<c<`01?l0
003o/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c
<`06oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<
c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00005ooooo`7o00000Oooool1ooooo`007?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo2OmVIVH00ol0003oOgmoogmoO`08ogmo
O`;o00003OnIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmo
OomoOgl02?moOgl2o`0000goIVIV00?o0000oda<C?m<C4`05Om<C4`00ol0003oIVIVofIVIP05ofIV
IP03o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0Bok>c
/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01Ol0003oIVIVofIVI_mVIVKo000000CoC4a<00?o
0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo
00Go0000oiVIVOnIVIWoVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Oo0000ok>c/onc
/k?o/k>co`000?nIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo00000_m<C4`00ol0003o<c<coc<c
<`07oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl00ol0003oVIVIo`000002ok>c/`03
o`000?o<c<coc<c<00Koc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`05o`000?mVIVKo
0000oda<C?l000002Olc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c
/`03o`000?o<c<coc<c<00Koc<c<00?o0000ok>c/ol000001_ooool1o`00007ooooo0Oooool001Wo
oooo1Ol00006ooooo`?o00000oooool8ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnI
VIT03?nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomo
Ogl02?moOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mV
IVH01?mVIVH00ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc
/k<04Onc/k<00ol0003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol000000omVIVH00ol0
003oC4a<oda<C002oda<C003o`000?lc<c?o<c<c00Go<c<c00Go0000oda<C?m<C4coC4a<o`000003
ofIVIP04o`000?moOgooOgmoo`0000?oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`01ol0003o/k>c
ok>c/onc/k?o0000oiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00002oda<C003o`000?lc<c?o
<c<c00Oo<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`03o`000?nIVIWo000000;o/k>c
00?o0000olc<c?o<c<`01_o<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00Go0000ofIV
I_l0003oC4a<o`000009oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o
/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003o/k>co`000004ooooo`?o00000_ooool001Wooooo
00CoA4A4omgMgOoooooo00001oooool00ol0003oooooooooo`03ooooo`OoIVIV00?o0000ogmoOomo
Ogl02?moOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnI
VIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00coIVIV00?o0000oda<C?m<
C4`05_m<C4`00ol0003oIVIVofIVIP05ofIVIP03o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnI
VIT00onIVIT00ol0003o/k>cok>c/`0Aok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomo
OgooOgmoo`000003ofIVIP03o`000?m<C4coC4a<00;oC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0
003oC4a<oda<C002oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl0
0003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo000000;o
Ogmo00Co0000ofIVI_mVIVKo00000_m<C4`00ol0003o<c<coc<c<`07oc<c<`04o`000?m<C4coC4a<
o`0000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Go
0000ok>c/ol0003oVIVIo`000002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<0
1_lc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000003ok>c/`03o`000?o<c<co
c<c<00Goc<c<00Co0000ok>c/ol0003oVIVI1_ooool1o`00007ooooo0Oooool001Wooooo00CogMgM
oeEEEOoooooo00001oooool00ol0003oooooooooo`03ooooo`KoIVIV00?o0000ogmoOomoOgl02?mo
Ogl2o`0000goVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?mo
OgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH2o`0001SoC4a<00?o0000ofIVI_mVIVH01OmV
IVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<04_nc
/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Go0000ofIVI_mVIVKoIVIVo`000005oda<C003
o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmo
O`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`01Ol0003o/k>cok>c/onc
/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`03
o`000?m<C4coC4a<00;o000000OoIVIVo`000?moOgooOgmoo`000?nIVIWo000000;o/k>c00?o0000
olc<c?o<c<`01oo<c<`01Ol0003o/k>co`000?nIVIWo000000;oOgmo00?o0000ofIVI_l000000_m<
C4`00ol0003o<c<coc<c<`06oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000
00;o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>co`000?nIVIT6ooooo`7o00000Oooool1
ooooo`006_ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo00?ooooo1OmVIVH00ol0
003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00coVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0
003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0
003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00KoIVIV00?o0000ogmoOomoOgl00_moOgl00ol0
003oVIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c01?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000003
ogmoO`05o`000?mVIVKoIVIVofIVI_l000001Om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<
C4coC4a<00?oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00004ok>c/`03
o`000?o<c<coc<c<00Goc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmo
o`0000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP06o`00
0?moOgooOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c007olc<c005o`000?nc/k?o0000
oiVIVOl000000_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Wo0000
oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c005
o`000?nc/k?o0000oiVIVOl000001Oooool1o`00007ooooo0Oooool001[ooooo00?ok^k^odA4A?l0
00001oooool00ol0003oooooooooo`03ooooo`CoIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003o
VIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003o
OgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003o
IVIVofIVIP06ofIVIP03o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o
/k>cok>c/`0Bok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01Ol0003oIVIVofIVI_mVIVKo
000000GoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKo
IVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c005olc<c005o`00
0?nc/k?o/k>cok>c/ol000000onIVIT01_l0003oOgmoogmoOol0003oIVIVo`0000?oC4a<00?o0000
oc<c<olc<c<01Olc<c<01ol0003oC4a<oda<C?m<C4co0000ofIVI_l000000_moOgl00ol0003oVIVI
o`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Go0000ok>c/ol0003oVIVIo`000002ogmoO`03
o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02Ol0003oC4a<o`000?mVIVKo0000
ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<0_l00002oiVIV@03o`000?oo
oooooooo00?ooooo0Ol00001ooooo`7ooooo000Kooooo`03ogMgMol0003ooooo00Kooooo00?o0000
ooooooooool00oooool3ofIVIP03o`000?moOgooOgmo00SoOgmo0_l0000=oiVIV@03o`000?nc/k?o
/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKo
IVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP05ofIVIP;o00001?moOgl0
0ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c01;o/k>c00?o0000oiVIVOnIVIT00_nIVIT0
1Ol0003oOgmoogmoOomoOgoo000000?oIVIV00?o0000oda<C?m<C4`00_m<C4`00ol0003o<c<coc<c
<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`04o`00
0?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o0000
00;oVIVI00Ko0000ogmoOomoOgoo0000ofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Wo
0000oda<C?m<C4coC4a<o`000?mVIVKo0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00008
olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl00ol0003oIVIVo`000002oda<C003o`00
0?lc<c?o<c<c00Ko<c<c00_o0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`00
000:olc<c0;o000000?oVIVIo`000?ooool01Oooool1o`00007ooooo0Oooool002Cooooo00?o0000
ooooooooool00oooool2ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT2
o`0001So/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKo
IVIV00[oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP06ofIVIP03o`000?moOgoo
Ogmo00?oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0Bok>c/`03o`000?nIVIWo
VIVI00;oVIVI00Co0000ogmoOomoOgoo00001?mVIVH00ol0003oC4a<oda<C002oda<C003o`000?lc
<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo
00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c
/ol000000_nIVIT01_l0003oOgmoogmoOol0003oIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc
<c<02Ol0003oC4a<oda<C?m<C4co0000ofIVI_l0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>c
o`0000Soc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`03o`000?mVIVKo000000;oC4a<
00?o0000oc<c<olc<c<01_lc<c<02ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc
/k?o000000[oc<c<0_l000000onIVIWo0000ooooo`05ooooo`7o00000Oooool1ooooo`009?ooool0
0ol0003oooooooooo`03ooooo`03ofIVI_l0003oOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT0
0ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl2
o`0000coIVIV00?o0000oda<C?m<C4`06?m<C4`00ol0003oIVIVofIVIP05ofIVIP03o`000?moOgoo
Ogmo00?oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0Bok>c/`03o`000?nIVIWo
VIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`000003ofIVIP03o`000?m<C4coC4a<00?oC4a<00?o
0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C002oda<C005o`000?mVIVKoIVIVofIVI_l00000
0_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc
/k?o/k>co`000002oiVIV@06o`000?moOgooOgmoo`000?mVIVKo00000om<C4`00ol0003o<c<coc<c
<`06oc<c<`07o`000?m<C4coC4a<oda<C?l0003oIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`00
00;o/k>c00?o0000olc<c?o<c<`01Oo<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00Ko
0000ofIVI_mVIVKo0000oda<C?l00008oc<c<`05o`000?m<C4co0000ofIVI_l000000_moOgl2o`00
00;o/k>c00?o0000olc<c?o<c<`01oo<c<`01Ol0003o/k>co`000?l0003oOgmo00Kooooo0Ol00001
ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo00?o0000ogmoOomoOgl02?moOgl00ol0
003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0
003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`06?m<C4`00ol0
003oIVIVofIVIP05ofIVIP03o`000?moOgooOgmo00?oOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0
003o/k>cok>c/`0Bok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01?l0003oIVIVofIVI_mV
IVH2o`0000CoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mV
IVKoIVIVo`0000?oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c005
o`000?nc/k?o/k>cok>c/ol000000_nIVIT01_l0003oOgmoogmoOol0003oIVIVo`0000?oC4a<00?o
0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP06o`000?moOgoo0000o`000?nI
VIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmo
Ool00002ofIVIP03o`000?m<C4co000000Wo<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000
oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c003o`000?nc/k?o/k>c00;o000000?oOgmo
ooooooooool01?ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool00ol0
003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00[oVIVI0_l0000Hok>c/`03o`000?nIVIWoVIVI
00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<
01SoC4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI
00?oVIVI00?o0000ok>c/onc/k<04onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Go0000
ofIVI_mVIVKoIVIVo`000005oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00om<
C4`01?l0003oIVIVofIVI_l00003ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<
c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Ko0000ogmoOomoOgoo0000ofIVI_l0
0003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmo
o`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003o
Ogmoo`0000;oIVIV00?o0000oda<C?l000002Olc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0
003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o0000ok>c/onc/k<00_l000000omo
Ogoo0000ooooo`04ooooo`7o00000Oooool1ooooo`009?ooool2o`0000Cooooo2_moOgl00ol0003o
VIVIoiVIV@0:oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003o
OgmoogmoO`08ogmoO`;o00003?mVIVH00ol0003oC4a<oda<C00Hoda<C003o`000?mVIVKoIVIV00Ko
IVIV00?o0000ogmoOomoOgl00omoOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c01;o
/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`05o`000?mVIVKoIVIVofIVI_l000001Om<C4`0
0ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000omo
Ogl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o
/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<0
1?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o0000
2?o<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0
003o<c<coc<c<`06oc<c<`03o`000?m<C4co000000;oIVIV0_l00002oiVIV@03o`000?nc/k?o0000
00Woc<c<00Co0000ok>c/ol0003o00000_moOgl00ol0003oooooooooo`02ooooo`;o00000_ooool0
02Cooooo00?o0000ooooooooool00oooool8ogmoO`;o00003?nIVIT00ol0003o/k>cok>c/`0Gok>c
/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIV
IP03o`000?m<C4coC4a<01SoC4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0003oOgmoogmoO`03ogmo
O`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<04_nc/k<00ol0003oVIVIoiVIV@02oiVI
V@05o`000?moOgooOgmoogmoOol000000omVIVH00ol0003oC4a<oda<C003oda<C003o`000?lc<c?o
<c<c00Co<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Co
0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol0
00000_nIVIT01_l0003oOgmoo`000?l0003oIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<0
1?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o0000
2?o<c<`02?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo00000_mVIVH01?l0003oC4a<oda<C?l0
0008oc<c<`07o`000?m<C4co0000ofIVI_l0003oOgmoo`000002oiVIV@03o`000?nc/k?o000000So
c<c<00?o0000ok>c/onc/k<00_l000000omoOgoo0000ooooo`05ooooo`7o00000Oooool1ooooo`00
9?ooool00ol0003oooooooooo`03ooooo`SoOgmo00?o0000oiVIVOnIVIT02_nIVIT2o`0001So/k>c
00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00[oIVIV
00?o0000oda<C?m<C4`06?m<C4`00ol0003oIVIVofIVIP07ofIVIP03o`000?moOgooOgmo00?oOgmo
00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`0Bok>c/`03o`000?nIVIWoVIVI00;oVIVI
00Co0000ogmoOomoOgoo00001?mVIVH00ol0003oC4a<oda<C003oda<C003o`000?lc<c?o<c<c00Co
<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Co0000oiVI
VOnIVIWo00001?nc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Co
0000ogmoOomoOgoo00000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Co0000oda<C?m<
C4co00000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00So0000
ok>c/onc/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<02Ol0
003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<
00?o0000ok>c/onc/k<00_l000000omoOgoo0000ooooo`05ooooo`7o00000Oooool1ooooo`009?oo
ool00ol0003oooooooooo`03ooooo`OoOgmo00?o0000oiVIVOnIVIT02_nIVIT00ol0003o/k>cok>c
/`0Gok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl2o`0000coIVIV00?o
0000oda<C?m<C4`06?m<C4`00ol0003oIVIVofIVIP07ofIVIP03o`000?moOgooOgmo00?oOgmo00?o
0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`0Bok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go
0000ogmoOomoOgooOgmoo`000003ofIVIP03o`000?m<C4coC4a<00?oC4a<00?o0000oc<c<olc<c<0
1?lc<c<00ol0003oC4a<oda<C002oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01?l0003o
VIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002
oiVIV@03o`000?moOgoo000000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`04o`000?m<
C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00008olc<c008
o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c
00?o0000oda<C?m<C4`00_l000001omoOgoo0000oiVIVOnIVIWo0000ok>c/ol000002Oo<c<`01?l0
003o/k>co`000?nIVIT2o`000003ofIVI_oooooooooo00Cooooo0Ol00001ooooo`7ooooo000Toooo
o`03o`000?oooooooooo00?ooooo1OmoOgl2o`0000coVIVI00?o0000ok>c/onc/k<05_nc/k<2o`00
00goVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<
01SoC4a<00?o0000ofIVI_mVIVH01omVIVH00ol0003oOgmoogmoO`03ogmoO`;o00001OnIVIT00ol0
003o/k>cok>c/`0Bok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`000003
ofIVIP03o`000?m<C4coC4a<00?oC4a<0_l00006oc<c<`03o`000?m<C4coC4a<00;oC4a<00Go0000
ofIVI_mVIVKoIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`0
1_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01?l0
003oC4a<oda<C?l00009oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nI
VIT01?l0003o/k>cok>c/ol00008olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002
ofIVIP04o`000?m<C4co0000o`0000So<c<c00Oo0000oda<C?l0003oIVIVo`000?moOgoo000000;o
VIVI00?o0000ok>c/ol000002Oo<c<`01?l0003o/k>co`000?nIVIT2o`000003ofIVI_oooooooooo
00Cooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo1OmoOgl00ol0003o
VIVIoiVIV@0:oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003o
OgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00coIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003o
IVIVofIVIP07ofIVIP03o`000?moOgooOgmo00CoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o
/k>cok>c/`0Bok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`000003ofIV
IP03o`000?m<C4coC4a<00?oC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<
C004o`000?mVIVKoIVIVo`0000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000003ok>c/`03o`000?o<
c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;o
IVIV00Co0000oda<C?m<C4co00002Olc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo
000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?mo
Ogoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Oo0000oda<C?l0003oIVIVo`00
0?moOgoo000000;oVIVI00?o0000ok>c/ol000002Oo<c<`01?l0003o/k>co`000?nIVIT2o`000003
ofIVI_oooooooooo00Cooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo
1?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT0
2onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00coIVIV00?o0000oda<C?m<C4`0
5om<C4`00ol0003oIVIVofIVIP07ofIVIP03o`000?moOgooOgmo00CoOgmo00?o0000oiVIVOnIVIT0
1?nIVIT00ol0003o/k>cok>c/`0Bok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomoOgoo
Ogmoo`000004ofIVIP03o`000?m<C4coC4a<00?oC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003o
C4a<oda<C003oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000003
ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl0
0002ogmoO`04o`000?mVIVKoIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01olc<c<01?l0003oC4a<
oda<C?l00002ofIVIP;o00000onIVIT01?l0003o/k>cok>c/ol00008olc<c00:o`000?nc/k?o/k>c
o`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01olc<c<01ol0003o
C4a<o`000?mVIVKo0000ogmoOol000000_nIVIT00ol0003o/k>co`000008olc<c003o`000?nc/k?o
000000;oVIVI0_l000000omVIVKo0000ooooo`04ooooo`7o00000Oooool1ooooo`009?ooool00ol0
003oooooooooo`03ooooo`?oOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c
/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0;ofIV
IP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH01omVIVH00ol0003oOgmoogmoO`05ogmo
O`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<04_nc/k<00ol0003oVIVIoiVIV@02oiVI
V@05o`000?moOgooOgmoogmoOol000000omVIVH00ol0003oC4a<oda<C003oda<C003o`000?lc<c?o
<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00003ogmoO`05o`000?nI
VIWoVIVIoiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol0
00000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000Wo<c<c00Co0000
oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<
00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV00?o0000oda<C?l000002Olc<c<0
1Ol0003oC4a<o`000?mVIVKo000000;oOgmo00Go0000oiVIVOl0003o/k>co`000009olc<c009o`00
0?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000Gooooo0Ol00001ooooo`7ooooo000Toooo
o`03o`000?oooooooooo00?ooooo0_moOgl00ol0003oVIVIoiVIV@0:oiVIV@;o00006?nc/k<00ol0
003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo0_l0000=ofIVIP03o`000?m<C4coC4a<
01OoC4a<00?o0000ofIVI_mVIVH02?mVIVH00ol0003oOgmoogmoO`04ogmoO`03o`000?nIVIWoVIVI
00CoVIVI00?o0000ok>c/onc/k<04_nc/k<00ol0003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmo
ogmoOol000001?mVIVH00ol0003oC4a<oda<C003oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000
oda<C?m<C4`00om<C4`01?l0003oIVIVofIVI_l00003ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c
00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomo
Ogoo00000_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`05o`000?m<C4coC4a<o`000?mVIVH00_l0
00001?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00So0000ok>c/onc/k?o
0000oiVIVOl0003oOgmoo`0000;oIVIV00?o0000oda<C?l000002Olc<c<01ol0003oC4a<o`000?mV
IVKo0000ogmoOol000000_nIVIT00ol0003o/k>co`000008olc<c00:o`000?nc/k?o/k>co`000?nI
VIWo0000ogmoOol0003oIVIVo`0000Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooo
oooo00?ooooo00?oOgmoo`000?nIVIT03?nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWo
VIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4co
C4a<01KoC4a<0_l0000;ofIVIP03o`000?moOgooOgmo00CoOgmo00?o0000oiVIVOnIVIT00onIVIT0
0ol0003o/k>cok>c/`0Cok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`00
0004ofIVIP03o`000?m<C4coC4a<00?oC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<
C003oda<C004o`000?mVIVKoIVIVo`0000?oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003o
c<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT00ol0003oOgmoo`000003ofIV
IP04o`000?m<C4coC4a<o`0000So<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo
00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c008o`000?nc/k?o/k>co`000?nI
VIWo0000ogmoOol00002ofIVIP03o`000?m<C4co000000Wo<c<c00Oo0000oda<C?l0003oIVIVo`00
0?moOgoo000000;oVIVI00?o0000ok>c/ol000002?o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`00
0?moOgoo0000ofIVI_l00005ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03
ooooo`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;
oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00F
oda<C003o`000?mVIVKoIVIV00[oIVIV00?o0000ogmoOomoOgl01?moOgl00ol0003oVIVIoiVIV@04
oiVIV@03o`000?nc/k?o/k>c01?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`04o`000?mV
IVKoIVIVofIVIP;o00001Om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<
00Co0000ofIVI_mVIVKo00000omoOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<
00Goc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Go
0000oda<C?m<C4coC4a<o`000008oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl00ol0
003oVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00So0000ok>c/onc/k?o0000oiVIVOl0
003oOgmoo`0000;oIVIV00?o0000oda<C?l000002Olc<c<00ol0003oC4a<o`000002ofIVIP;o0000
0_nIVIT00ol0003o/k>co`000009olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo
000000Kooooo0Ol00001ooooo`7ooooo000Tooooo`;o00001?ooool<oiVIV@;o00006?nc/k<00ol0
003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo0_l0000=ofIVIP03o`000?m<C4coC4a<
01KoC4a<00?o0000ofIVI_mVIVH02OmVIVH2o`0000KoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0
003o/k>cok>c/`0Cok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`000003
ofIVIP03o`000?m<C4coC4a<00CoC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C002
oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000?o/k>c
00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomo
Ogoo00000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`07o`000?m<C4coC4a<oda<C?l0003oIVIV
o`000002ogmoO`03o`000?nIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`02?l0003o/k>c
ok>c/ol0003oVIVIo`000?moOgoo00000_mVIVH00ol0003oC4a<o`000009oc<c<`07o`000?m<C4co
0000ofIVI_l0003oOgmoo`000002oiVIV@03o`000?nc/k?o000000Soc<c<00[o0000ok>c/onc/k?o
0000oiVIVOl0003oOgmoo`000?mVIVKo00001Oooool2o`0000;ooooo000Tooooo`03o`000?oooooo
oooo00?ooooo3?nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000
ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000
ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000
ok>c/onc/k<04onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000CoOgmo00Go0000ofIVI_mVIVKoIVIV
o`000006oda<C003o`000?lc<c?o<c<c00?o<c<c00?o0000oda<C?m<C4`00om<C4`01?l0003oIVIV
ofIVI_l00003ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0
003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01?l0003oC4a<oda<
C?l00008oc<c<`07o`000?m<C4coC4a<oda<C?l0003oIVIVo`000002ogmoO`03o`000?nIVIWo0000
00?o/k>c00?o0000olc<c?o<c<`01_o<c<`02?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000
0_mVIVH00ol0003oC4a<o`000009oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo
000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo
0000ofIVI_l00006ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`_o
VIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00Wo
Ogmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00[o
IVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c01?o
/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000?oIVIV00?o0000oda<
C?m<C4`01?m<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00;oC4a<00Go0000ofIV
I_mVIVKoIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01_o<
c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01?l0003o
C4a<oda<C?l00009oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl00ol0003oVIVIo`00
0003ok>c/`03o`000?o<c<coc<c<00Koc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`00
00;oIVIV00?o0000oda<C?l000002Olc<c<00ol0003oC4a<oda<C002o`000007ogmoOol0003oVIVI
oiVIVOl0003o/k>co`000008olc<c00;o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIV
o`000?m<C4`01_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool:oiVI
V@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmo
O`;o00003OmVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00[oIVIV00?o0000ogmo
OomoOgl01OmoOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o0000oiVI
VOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000CoIVIV00?o0000oda<C?m<C4`00om<C4`0
0ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Co0000ofIVI_mVIVKo00000omo
Ogl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o
/k>co`000002oiVIV@03o`000?moOgoo000000;oIVIV00Go0000oda<C?m<C4coC4a<o`000009oc<c
<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl00ol0003oVIVIo`000003ok>c/`03o`000?o<
c<coc<c<00Koc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV00?o0000oda<
C?l000002Olc<c<01ol0003oC4a<o`000?mVIVKo0000ogmoOol000000_nIVIT00ol0003o/k>co`00
0008olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co00001Ooo
ool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool9oiVIV@03o`000?nc/k?o
/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKo
IVIV00coIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0:ofIVIP03o`000?moOgoo
Ogmo00KoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`0Cok>c/`03o`000?nIVIWo
VIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`000004ofIVIP03o`000?m<C4coC4a<00?oC4a<00?o
0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C003oda<C004o`000?mVIVKoIVIVo`0000?oOgmo
00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o
/k>c00Ko0000oiVIVOnIVIWo0000ogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<C?l000002Olc
<c<02?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo00000_nIVIT01Ol0003o/k>cok>c/onc/k?o
000000Soc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0
003o<c<coc<c<`07oc<c<`07o`000?m<C4co0000ofIVI_l0003oOgmoo`000002oiVIV@03o`000?nc
/k?o000000Soc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l0
0005ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`SoVIVI00?o0000
ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000
ofIVI_mVIVH03?mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000
ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o0000
oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000CoIVIV00?o0000oda<C?m<C4`00om<
C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Co0000ofIVI_mVIVKo0000
0omoOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc
/k?o/k>co`000002oiVIV@03o`000?moOgoo000000;oIVIV00Go0000oda<C?m<C4coC4a<o`000009
oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl00ol0003oVIVIo`000003ok>c/`03o`00
0?o<c<coc<c<00Koc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV00?o0000
oda<C?l000002Olc<c<01Ol0003oC4a<o`000?mVIVKo000000;oOgmo00Go0000oiVIVOl0003o/k>c
o`000008olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co0000
1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool7oiVIV@03o`000?nc
/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mV
IVKoIVIV00_oIVIV0_l0000Hoda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl01?mo
Ogl2o`0000KoVIVI00?o0000ok>c/onc/k<04onc/k<00ol0003oVIVIoiVIV@02oiVIV@03o`000?mo
OgooOgmo00;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000005oda<C0;o00001Olc<c<00ol0003oC4a<
oda<C003oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01Ol0003oVIVIoiVIVOnIVIWo0000
00Co/k>c00?o0000olc<c?o<c<`01Oo<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000
ogmoOomoOgoo00000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Co0000oda<C?m<C4co
00000_mVIVH01_l0003oOgmoogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01oo<c<`0
2?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo00000_mVIVH00ol0003oC4a<o`000009oc<c<`07
o`000?m<C4co0000ofIVI_l0003oOgmoo`000002oiVIV@03o`000?nc/k?o000000Soc<c<00co0000
ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00006ooooo`7o00000Oooool1
ooooo`009?ooool00ol0003oooooooooo`03ooooo`KoVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0
003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0
003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0
003oVIVIoiVIV@05oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT00_nIVIT00ol0
003oOgmoogmoO`02ogmoO`05o`000?mVIVKoIVIVofIVI_l000001Om<C4`00ol0003o<c<coc<c<`04
oc<c<`03o`000?m<C4coC4a<00?oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`05o`000?nI
VIWoVIVIoiVIVOl000001?nc/k<00ol0003oc<c<olc<c005olc<c005o`000?nc/k?o/k>cok>c/ol0
00000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<0
1?l0003oC4a<oda<C?l00002ofIVIP06o`000?moOgooOgmoo`000?nIVIWo00000_nc/k<00ol0003o
c<c<olc<c007olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP03o`000?m<
C4co000000Wo<c<c00Oo0000oda<C?l0003oIVIVo`000?moOgoo000000;oVIVI00?o0000ok>c/ol0
00002?o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000Ko
oooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo1OnIVIT00ol0003o/k>c
ok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIV
ofIVIP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmo
ogmoO`05ogmoO`03o`000?nIVIWoVIVI00GoVIVI00?o0000ok>c/onc/k<04onc/k<00ol0003oVIVI
oiVIV@03oiVIV@05o`000?moOgooOgmoogmoOol000000omVIVH00ol0003oC4a<oda<C003oda<C003
o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00om<C4`01?l0003oIVIVofIVI_l00002ogmo
O`05o`000?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o
/k>c00;o/k>c00Ko0000oiVIVOnIVIWo0000ogmoOol00002ofIVIP03o`000?m<C4coC4a<00;oC4a<
00?o0000oc<c<olc<c<01Olc<c<01ol0003oC4a<oda<C?m<C4co0000ofIVI_l000000_moOgl00ol0
003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00So0000ok>c/onc/k?o0000oiVIVOl0
003oOgmoo`0000;oIVIV00?o0000oda<C?l000002Olc<c<00ol0003oC4a<o`000002ofIVIP;o0000
0_nIVIT00ol0003o/k>co`000009olc<c00<o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo
0000oda<C?l0003o<c<c1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00ooo
ool4oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmo
O`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`2o`0000goIVIV00?o
0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@05oiVIV@03o`000?nc/k?o/k>c01?o/k>c0_l0
0004oiVIV@05o`000?moOgooOgmoogmoOol000001?mVIVH00ol0003oC4a<oda<C003oda<C003o`00
0?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00om<C4`01Ol0003oIVIVofIVI_mVIVKo000000;o
Ogmo00Go0000oiVIVOnIVIWoVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c
/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<
o`000008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o
/k>cok>c/ol00009olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;o
C4a<00?o0000oc<c<olc<c<01olc<c<01ol0003oC4a<o`000?mVIVKo0000ogmoOol000000_nIVIT0
0ol0003o/k>co`000008olc<c00=o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`00
0?m<C4co0000oc<c<`06ooooo`7o00000Oooool1ooooo`009?ooool2o`0000Cooooo0onIVIT00ol0
003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0
003oIVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0
003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc/k<04onc/k<00ol0
003oVIVIoiVIV@03oiVIV@05o`000?moOgooOgmoogmoOol000001?mVIVH00ol0003oC4a<oda<C003
oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00om<C4`01Ol0003oIVIVofIVI_mV
IVKo000000;oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c006olc<c005o`00
0?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP05o`000?m<C4coC4a<
oda<C?l000002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00Co
0000ok>c/onc/k?o00002Oo<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0
0002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Oo0000oda<C?l0003oIVIVo`000?moOgoo000000;o
VIVI00?o0000ok>c/ol000002?o<c<`03Ol0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIV
I_l0003oC4a<o`000?lc<c<01Oooool2o`0000;ooooo000Tooooo`03o`000?oooooooooo00?ooooo
0_nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl0
2?moOgl2o`0000coIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`00
0?moOgooOgmo00KoOgmo00?o0000oiVIVOnIVIT01OnIVIT00ol0003o/k>cok>c/`0Cok>c/`03o`00
0?nIVIWoVIVI00?oVIVI00Go0000ogmoOomoOgooOgmoo`000004ofIVIP03o`000?m<C4coC4a<00?o
C4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C003oda<C005o`000?mVIVKoIVIVofIV
I_l000000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`0
1Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01Ol0003oC4a<
oda<C?m<C4co000000So<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVI
V@04o`000?nc/k?o/k>co`0000Woc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mV
IVKo00000_m<C4`00ol0003o<c<coc<c<`07oc<c<`03o`000?m<C4coC4a<00;o000000OoOgmoo`00
0?nIVIWoVIVIo`000?nc/k?o000000Soc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`00
0?mVIVKo0000oda<C?l00002oc<c<`Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooo
oooo00?ooooo00?oVIVIo`000?nc/k<05onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgoo
Ogmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C0;o00003OmVIVH0
0ol0003oOgmoogmoO`06ogmoO`03o`000?nIVIWoVIVI00GoVIVI00?o0000ok>c/onc/k<05?nc/k<0
0ol0003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol000001?mVIVH00ol0003oC4a<oda<
C004oda<C003o`000?lc<c?o<c<c00?o<c<c00?o0000oda<C?m<C4`00om<C4`01Ol0003oIVIVofIV
I_mVIVKo000000?oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c005olc<c003
o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00003
oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`00
0002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT01Ol0003o
Ogmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<2o`000006oda<C?l0003oIVIV
o`000?moOgoo00000_nIVIT00ol0003o/k>co`000008olc<c00<o`000?nc/k?o/k>co`000?nIVIWo
0000ogmoOol0003oIVIVo`000?m<C4co00000_lc<c<6ooooo`7o00000Oooool1ooooo`009?ooool0
0ol0003oooooooooo`03ooooo`03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT0
0ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00[oIVIV00?o0000oda<C?m<C4`05_m<C4`0
0ol0003oIVIVofIVIP0<ofIVIP03o`000?moOgooOgmo00KoOgmo00?o0000oiVIVOnIVIT01_nIVIT0
0ol0003o/k>cok>c/`0Cok>c/`03o`000?nIVIWoVIVI00?oVIVI00Go0000ogmoOomoOgooOgmoo`00
0004ofIVIP03o`000?m<C4coC4a<00?oC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<
C003oda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01?l0003oVIVIoiVIVOl00004ok>c/`03
o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmo
O`03o`000?mVIVKo000000CoC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002
ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01?l0003o/k>cok>c
/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`08
o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVIV@03o`000?nc/k?o000000Soc<c<00co
0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00002oc<c<`Kooooo0Ol0
0001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo6?nc/k<00ol0003oVIVIoiVIV@0;
oiVIV@03o`000?moOgooOgmo00SoOgmo0_l0000<ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000
ofIVI_mVIVH02omVIVH2o`0000SoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`0C
ok>c/`03o`000?nIVIWoVIVI00?oVIVI00Go0000ogmoOomoOgooOgmoo`000004ofIVIP03o`000?m<
C4coC4a<00CoC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C003oda<C004o`000?mV
IVKoIVIVo`0000?oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c005olc<c003
o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00003
oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH01_l0003oOgmoogmo
Ool0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVI
V@03o`000?moOgoo000000;oIVIV00?o0000oda<C?l000002?lc<c<01_l0003oC4a<oda<C?l0003o
IVIVo`0000;oOgmo00Go0000oiVIVOl0003o/k>co`000009olc<c003o`000?nc/k?o000000;oVIVI
0_l000001OmVIVKo0000oda<C?m<C4co000000;o<c<c1_ooool1o`00007ooooo0Oooool002Cooooo
00?o0000ooooooooool00ooooolGok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl0
2?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH0
2omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00GoVIVI00?o0000ok>c/onc/k<0
5?nc/k<00ol0003oVIVIoiVIV@02oiVIV@03o`000?moOgooOgmo00;oOgmo00Go0000ofIVI_mVIVKo
IVIVo`000007oda<C003o`000?lc<c?o<c<c00?o<c<c00?o0000oda<C?m<C4`00om<C4`01Ol0003o
IVIVofIVI_mVIVKo000000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000003ok>c/`03o`000?o<c<co
c<c<00Koc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mV
IVKoIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;o
IVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00008olc<c004o`000?nc/k?o/k>c
o`0000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00So
0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000;oVIVI00?o0000ok>c/ol000002Oo<c<`02ol0
003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co000000?o<c<c1_ooool1o`00007o
oooo0Oooool002Cooooo00?o0000ooooooooool00ooooolFok>c/`03o`000?nIVIWoVIVI00_oVIVI
00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<01KoC4a<
0_l0000=ofIVIP03o`000?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>c
ok>c/`0Dok>c/`03o`000?nIVIWoVIVI00;oVIVI00?o0000ogmoOomoOgl00_moOgl01Ol0003oIVIV
ofIVI_mVIVKo000000OoC4a<00?o0000oc<c<olc<c<00olc<c<00ol0003oC4a<oda<C003oda<C005
o`000?mVIVKoIVIVofIVI_l000000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000?o/k>c00?o0000
olc<c?o<c<`01_o<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co
0000ofIVI_mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l0
00000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Co0000ok>c
/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc
<c<02?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo00000_nIVIT00ol0003o/k>co`000009olc<
c00;o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l000000olc<c<6ooooo`7o
00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03oooooaGo/k>c00?o0000oiVIVOnIVIT0
2onIVIT00ol0003oOgmoogmoO`08ogmoO`;o00003?mVIVH00ol0003oC4a<oda<C00Foda<C003o`00
0?mVIVKoIVIV00_oIVIV0_l00009ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc/k<0
5?nc/k<00ol0003oVIVIoiVIV@02oiVIV@03o`000?moOgooOgmo00;oOgmo00Go0000ofIVI_mVIVKo
IVIVo`000007oda<C003o`000?lc<c?o<c<c00?o<c<c00?o0000oda<C?m<C4`00om<C4`01Ol0003o
IVIVofIVI_mVIVKo000000?oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006
olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIV
I_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP03
o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01?l0003o/k>cok>c/ol00002
oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`03o`000?m<
C4co000000;oIVIV0_l00002oiVIV@03o`000?nc/k?o000000Woc<c<00?o0000ok>c/onc/k<00_l0
00001?moOgoo0000ofIVI_mVIVH2o`0000Co<c<c1_ooool1o`00007ooooo0Oooool001Wooooo00Go
k^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo00?ooooo4onc/k<2o`0000goVIVI
00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<
00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00KoVIVI
00?o0000ok>c/onc/k<05?nc/k<00ol0003oVIVIoiVIV@02oiVIV@;o00000omoOgl00ol0003oIVIV
ofIVIP02ofIVIP03o`000?m<C4coC4a<00CoC4a<00?o0000oc<c<olc<c<00olc<c<00ol0003oC4a<
oda<C003oda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01?l0003oVIVIoiVIVOl00004ok>c
/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgoo
Ogmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`05o`000?m<C4coC4a<oda<C?l0
00000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Co0000ok>c
/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01olc
<c<01ol0003oC4a<o`000?mVIVKo0000ogmoOol000000_nIVIT00ol0003o/k>co`000008olc<c00<
o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co00001?lc<c<6ooooo`7o
00000Oooool1ooooo`006Oooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000oooooooo
ool00ooooolBok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003o
IVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003o
OgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc/k<04onc/k<00ol0003o
VIVIoiVIV@03oiVIV@03o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003o
C4a<oda<C004oda<C003o`000?lc<c?o<c<c00;o<c<c00?o0000oda<C?m<C4`01?m<C4`01Ol0003o
IVIVofIVI_mVIVKo000000?oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c006
olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP05o`00
0?m<C4coC4a<oda<C?l000002?lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o0000ogmo
Ool000000_nIVIT01?l0003o/k>cok>c/ol00008olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Go
0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Oo0000oda<C?l0003o
IVIVo`000?moOgoo000000;oVIVI00?o0000ok>c/ol000002?o<c<`03?l0003o/k>cok>c/ol0003o
VIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000Co<c<c1_ooool1o`00007ooooo0Oooool001Wo
oooo00Go0000ooooooooooooooooo`000006ooooo`?o00000ooooolBok>c/`03o`000?nIVIWoVIVI
00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<
01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI
00KoVIVI00?o0000ok>c/onc/k<05?nc/k<00ol0003oVIVIoiVIV@03oiVIV@05o`000?moOgooOgmo
ogmoOol000001?mVIVH00ol0003oC4a<oda<C004oda<C003o`000?lc<c?o<c<c00?o<c<c00?o0000
oda<C?m<C4`01?m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Go0000oiVIVOnIVIWoVIVI
o`000003ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@06
o`000?moOgooOgmoo`000?mVIVKo00001?m<C4`00ol0003o<c<coc<c<`06oc<c<`09o`000?m<C4co
C4a<oda<C?l0003oIVIVo`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`01?l0
003o/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c
<`06oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000
olc<c?o<c<`01_o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<
o`0000Co<c<c1?ooool3o`0000;ooooo000Iooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool0
0ol0003oooooooooo`03oooooa7o/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09
ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;
ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT01onIVIT00ol0003o/k>cok>c/`0C
ok>c/`03o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP02
ofIVIP03o`000?m<C4coC4a<00CoC4a<00?o0000oc<c<olc<c<00_lc<c<00ol0003oC4a<oda<C005
oda<C004o`000?mVIVKoIVIVo`0000?oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<
olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIV
IP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o
0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00009olc<c00:o`000?nc/k?o/k>co`000?nI
VIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01olc<c<00ol0003oC4a<oda<
C002o`000007ogmoOol0003oVIVIoiVIVOl0003o/k>co`000008olc<c00<o`000?nc/k?o/k>co`00
0?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co00001Olc<c<6ooooo`7o00000Oooool1ooooo`00
6Oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool00oooool@ok>c/`03
o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl2o`0000goIVIV00?o0000oda<C?m<
C4`05_m<C4`00ol0003oIVIVofIVIP0:ofIVIP;o00002_moOgl00ol0003oVIVIoiVIV@06oiVIV@;o
00005_nc/k<00ol0003oVIVIoiVIV@03oiVIV@05o`000?moOgooOgmoogmoOol000001?mVIVH00ol0
003oC4a<oda<C005oda<C003o`000?lc<c?o<c<c00;o<c<c00?o0000oda<C?m<C4`01?m<C4`01Ol0
003oIVIVofIVI_mVIVKo000000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<
c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`00
0?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01ol0003oC4a<oda<C?m<C4co0000
ofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co
0000ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc
<c<01_lc<c<02?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo00000_nIVIT00ol0003o/k>co`00
0008olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co00001Olc
<c<6ooooo`7o00000Oooool1ooooo`006Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooo
oooo00?ooooo3onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000
ofIVI_mVIVH03?mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00[oIVIV00?o0000
ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@07oiVIV@03o`000?nc/k?o/k>c01Co/k>c00?o0000
oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000
oda<C?m<C4`01Om<C4`00ol0003o<c<coc<c<`02oc<c<`03o`000?m<C4coC4a<00CoC4a<00Go0000
ofIVI_mVIVKoIVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0003oc<c<
olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0003o
IVIVofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Oo0000oda<C?m<C4coC4a<o`000?mV
IVKo000000;oOgmo00Co0000oiVIVOnIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c004o`00
0?nc/k?o/k>co`0000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c
00Ko<c<c00So0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000;oVIVI00?o0000ok>c/ol00000
2?o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000Go<c<c
1_ooool1o`00007ooooo0Oooool001Wooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003ooooooooo
o`03ooooo`ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mV
IVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?mo
OgooOgmo00SoOgmo00?o0000oiVIVOnIVIT01onIVIT00ol0003o/k>cok>c/`0Dok>c/`03o`000?nI
VIWoVIVI00?oVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP02ofIVIP03o`000?m<
C4coC4a<00GoC4a<00?o0000oc<c<olc<c<00_lc<c<00ol0003oC4a<oda<C004oda<C005o`000?mV
IVKoIVIVofIVI_l000000omoOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Go
c<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIV
o`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o
0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00008olc<c004o`000?nc/k?o/k>co`0000;o
VIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Ko0000oda<
C?m<C4co0000ofIVI_l00002ogmoO`05o`000?nIVIWo0000ok>c/ol000002Oo<c<`00ol0003o/k>c
o`000002oiVIV@;o000000GoIVIVo`000?m<C4coC4a<o`000005oc<c<`Kooooo0Ol00001ooooo`7o
oooo000Jooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool00oooool=ok>c/`03
o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl2o`0000goIVIV00?o0000oda<C?m<
C4`05_m<C4`00ol0003oIVIVofIVIP0:ofIVIP;o00002_moOgl00ol0003oVIVIoiVIV@08oiVIV@03
o`000?nc/k?o/k>c01Co/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`02ogmoO`03
o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01?m<C4`00ol0003o<c<coc<c<`02oc<c<`03
o`000?m<C4coC4a<00CoC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`05o`000?nIVIWoVIVI
oiVIVOl000001?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000
oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c
00Co0000oda<C?m<C4co00000_mVIVH01_l0003oOgmoogmoOol0003oVIVIo`0000;o/k>c00?o0000
olc<c?o<c<`01oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l00000
0_m<C4`00ol0003o<c<coc<c<`06oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002
oiVIV@03o`000?nc/k?o000000Woc<c<00_o0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0
003oC4a<o`000006oc<c<`Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?o
oooo3?nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mV
IVH03?mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00[oIVIV00?o0000ogmoOomo
Ogl02OmoOgl00ol0003oVIVIoiVIV@08oiVIV@03o`000?nc/k?o/k>c01Go/k>c00?o0000oiVIVOnI
VIT00onIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<
C4`01?m<C4`00ol0003o<c<coc<c<`02oc<c<`03o`000?m<C4coC4a<00CoC4a<00Go0000ofIVI_mV
IVKoIVIVo`000003ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0003oc<c<olc<c005
olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIV
I_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH01_l0003o
OgmoogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01oo<c<`01?l0003o/k>cok>c/ol0
0002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`08o`00
0?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVIV@03o`000?nc/k?o000000Woc<c<0_l00002
oiVIV@07o`000?moOgoo0000ofIVI_l0003oC4a<o`000006oc<c<`Kooooo0Ol00001ooooo`7ooooo
000Tooooo`03o`000?oooooooooo00?ooooo2onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?mo
OgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mV
IVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@08oiVIV@03o`000?nc
/k?o/k>c01Go/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mV
IVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01?m<C4`00ol0003o<c<coc<c<`02oc<c<`03o`000?m<
C4coC4a<00GoC4a<00Co0000ofIVI_mVIVKo00000omoOgl01Ol0003oVIVIoiVIVOnIVIWo000000Co
/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmo
OomoOgoo00000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Co0000oda<C?m<C4co0000
0_mVIVH01_l0003oOgmoogmoOol0003oVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0
003o/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c
<`07oc<c<`03o`000?m<C4co000000;oIVIV0_l00002oiVIV@03o`000?nc/k?o000000Woc<c<00Oo
0000ok>c/ol0003oVIVIo`000?moOgoo000000;oIVIV0_l00007oc<c<`Kooooo0Ol00001ooooo`7o
oooo000Tooooo`03o`000?oooooooooo00?ooooo2_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`00
0?moOgooOgmo00SoOgmo0_l0000=ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH0
2omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00SoVIVI00?o0000ok>c/onc/k<0
5Onc/k<00ol0003oVIVIoiVIV@03oiVIV@03o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH0
0_mVIVH00ol0003oC4a<oda<C005oda<C003o`000?lc<c?o<c<c00;o<c<c00?o0000oda<C?m<C4`0
1?m<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0
003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000onIVIT01?l0003oOgmoogmoOol0
0002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP06
o`000?moOgooOgmoo`000?nIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c006o`000?nc/k?o
/k>co`000?nIVIWo00000_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c
00Oo0000oda<C?l0003oIVIVo`000?moOgoo000000;oVIVI00?o0000ok>c/ol000002?o<c<`03?l0
003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000Oo<c<c1_ooool1o`00
007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool9ok>c/`03o`000?nIVIWoVIVI00_o
VIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<01Ko
C4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00Wo
VIVI00?o0000ok>c/onc/k<05?nc/k<00ol0003oVIVIoiVIV@03oiVIV@03o`000?moOgooOgmo00?o
Ogmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C005oda<C005o`000?lc<c?o<c<coc<c
<ol000001om<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Co0000oiVIVOnIVIWo00001?nc
/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000onIVIT00ol0003oOgmo
o`000002ofIVIP03o`000?m<C4coC4a<00;oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<
oda<C?l00002ofIVIP06o`000?moOgooOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c007
olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl00ol0003oIVIVo`000002oda<C003o`00
0?lc<c?o<c<c00Ko<c<c00So0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000;oVIVI00?o0000
ok>c/ol000002?o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<
o`0000Oo<c<c1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool8ok>c
/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0<ofIV
IP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmo
O`03o`000?nIVIWoVIVI00WoVIVI00?o0000ok>c/onc/k<05Onc/k<00ol0003oVIVIoiVIV@03oiVI
V@03o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C005oda<
C005o`000?lc<c?o<c<coc<c<ol000001om<C4`00ol0003oIVIVofIVIP02ofIVIP04o`000?moOgoo
Ogmoo`0000;oVIVI00?o0000ok>c/onc/k<00_nc/k<00ol0003oc<c<olc<c006olc<c003o`000?nc
/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00003oda<C003
o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH01?l0003oOgmoogmoOol00002
oiVIV@04o`000?nc/k?o/k>co`0000Woc<c<00?o0000ok>c/onc/k<00_l00002ogmoO`03o`000?mV
IVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?m<C4`2o`000005ogmo
Ool0003oVIVIoiVIVOl000000_nc/k<00ol0003oc<c<olc<c005olc<c006o`000?nc/k?o/k>co`00
0?nIVIWo00000_moOgl2o`0000;oC4a<00?o0000oc<c<olc<c<01Olc<c<6ooooo`7o00000Oooool1
ooooo`009?ooool2o`0000Cooooo1onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo
00SoOgmo00?o0000ofIVI_mVIVH02omVIVH2o`0001SoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0
003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00WoVIVI00?o0000ok>c/onc/k<05Onc/k<00ol0
003oVIVIoiVIV@03oiVIV@03o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0
003oC4a<oda<C006oda<C005o`000?lc<c?o<c<coc<c<ol000001_m<C4`00ol0003oIVIVofIVIP02
ofIVIP04o`000?moOgooOgmoo`0000?oVIVI00?o0000ok>c/onc/k<00_nc/k<00ol0003oc<c<olc<
c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP05
o`000?m<C4coC4a<oda<C?l000002?lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o0000
ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00009olc<c006o`000?nc/k?o/k>co`000?nIVIWo
00000_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00So0000oda<C?m<
C4co0000ofIVI_l0003oOgmoo`0000;oVIVI00?o0000ok>c/ol000002?o<c<`02_l0003o/k>cok>c
/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Go<c<c1Oooool2
o`0000;ooooo000Tooooo`03o`000?oooooooooo00?ooooo1_nc/k<00ol0003oVIVIoiVIV@0;oiVI
V@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Goda<
C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl2o`0000_oVIVI00?o0000ok>c
/onc/k<05?nc/k<00ol0003oVIVIoiVIV@04oiVIV@05o`000?moOgooOgmoogmoOol000001OmVIVH0
0ol0003oC4a<oda<C006oda<C005o`000?lc<c?o<c<coc<c<ol000001_m<C4`00ol0003oIVIVofIV
IP02ofIVIP04o`000?moOgooOgmoo`0000?oVIVI00?o0000ok>c/onc/k<00_nc/k<00ol0003oc<c<
olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0003o
IVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002
ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`01_l0003o/k>cok>c
/ol0003oVIVIo`0000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`08
o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVIV@03o`000?nc/k?o000000Soc<c<00[o
0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`05
oc<c<`Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo1Onc/k<00ol0
003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0
003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0
003oVIVIoiVIV@0:oiVIV@03o`000?nc/k?o/k>c01Co/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0
003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01_m<C4`01Ol0
003o<c<coc<c<olc<c?o000000KoC4a<00?o0000ofIVI_mVIVH00_mVIVH01?l0003oOgmoogmoOol0
0003oiVIV@03o`000?nc/k?o/k>c00;o/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c
/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o
<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Go0000ofIVI_l0003oOgmoo`000002oiVI
V@04o`000?nc/k?o/k>co`0000Woc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`06o`00
0?mVIVKoIVIVo`000?m<C4co00002?lc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00Go
0000oiVIVOl0003o/k>co`000009olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo
000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<00ol0003oooooooooo`03ooooo`7o00000Oooool1
ooooo`009?ooool00ol0003oooooooooo`03ooooo`Co/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0
003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`2o`00
00goIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0:oiVIV@03o`000?nc/k?o/k>c
01Co/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV
00?oIVIV00?o0000oda<C?m<C4`01Om<C4`2o`0000;o<c<c00?o0000oda<C?m<C4`01Om<C4`01Ol0
003oIVIVofIVI_mVIVKo000000?oOgmo00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<
c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`00
0?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co0000
00;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00009olc<c006o`000?nc/k?o
/k>co`000?nIVIWo00000_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c
00So0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000;oVIVI00?o0000ok>c/ol000002Oo<c<`0
2Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko
<c<c00?o0000ooooooooool00oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool0
0oooool3ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIV
ofIVIP0:ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmo
ogmoO`08ogmoO`03o`000?nIVIWoVIVI00[oVIVI00?o0000ok>c/onc/k<05Onc/k<00ol0003oVIVI
oiVIV@04oiVIV@03o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<
oda<C005oda<C005o`000?m<C4co0000oc<c<ol000001om<C4`01Ol0003oIVIVofIVI_mVIVKo0000
00?oOgmo00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000
ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<
00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o0000ogmoOol0
00000_nIVIT01?l0003o/k>cok>c/ol00009olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_mo
Ogl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00So0000oda<C?m<C4co0000
ofIVI_l0003oOgmoo`0000;oVIVI00?o0000ok>c/ol000002Oo<c<`02Ol0003o/k>co`000?nIVIWo
0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00?o0000ooooooooool0
0oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool2ok>c/`03o`000?nI
VIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl2o`0000coIVIV00?o0000oda<C?m<C4`05om<
C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onI
VIT00ol0003o/k>cok>c/`0Dok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl00_mo
Ogl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<00KoC4a<0_l000000om<C4co0000oda<
C006oda<C003o`000?mVIVKoIVIV00;oIVIV00Co0000ogmoOomoOgoo00000onIVIT00ol0003o/k>c
ok>c/`02ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVI
oiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0
003oC4a<oda<C?m<C4co000000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol0
0009olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003
o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH2o`0000;oVIVI00?o0000ok>c
/ol000002Oo<c<`01ol0003o/k>co`000?nIVIWo0000ogmoOol000000_mVIVH00ol0003oC4a<o`00
0008oc<c<`03o`000?oooooooooo00Cooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooo
oooo00?ooooo00?o/k>co`000?nIVIT03?nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKo
IVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`2o`0000goIVIV00?o0000ogmoOomoOgl02?moOgl0
0ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Co/k>c00?o0000oiVIVOnIVIT01?nIVIT0
0ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01_m<C4`0
1?l0003o<c<coc<c<ol00007oda<C003o`000?mVIVKoIVIV00;oIVIV00Co0000ogmoOomoOgoo0000
0onIVIT00ol0003o/k>cok>c/`02ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<0
0_nc/k<2o`0000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01Ol0003oC4a<oda<C?m<C4co0000
00So<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000
ok>c/onc/k?o00002?o<c<`2o`0000;o/k>c00Go0000oiVIVOl0003oOgmoo`000002ofIVIP04o`00
0?m<C4coC4a<o`0000So<c<c00So0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000;oVIVI00?o
0000ok>c/ol000002?o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003o
C4a<o`0000Wo<c<c00?o0000ooooooooool01?ooool1o`00007ooooo0Oooool002Cooooo00?o0000
ooooooooool00oooool00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000
ofIVI_mVIVH02_mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00coIVIV00?o0000
ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Go/k>c00?o0000
oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000
oda<C?m<C4`01_m<C4`01?l0003o<c<coc<c<ol00007oda<C003o`000?mVIVKoIVIV00;oIVIV00Co
0000ogmoOomoOgoo00000onIVIT00ol0003o/k>cok>c/`02ok>c/`03o`000?o<c<coc<c<00Goc<c<
00?o0000ok>c/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Co0000ofIVI_mV
IVKo00000om<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Ko0000ofIV
I_mVIVKo0000ogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Wo0000ok>c/onc/k?o
/k>co`000?nIVIWo0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`08o`000?m<
C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVIV@03o`000?nc/k?o000000Soc<c<00co0000ok>c
/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00009oc<c<`03o`000?oooooooooo
00Cooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo3OnIVIT00ol0003o
OgmoogmoO`08ogmoO`;o00003?mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_o
IVIV0_l0000:ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05Onc/k<00ol0003o
VIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00?oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003o
C4a<oda<C008oda<C0;o00001om<C4`00ol0003oIVIVofIVIP02ofIVIP04o`000?moOgooOgmoo`00
00CoVIVI00Go0000ok>c/onc/k?o/k>co`000007olc<c003o`000?nc/k?o/k>c00;o/k>c00Go0000
oiVIVOnIVIWoVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<0
1_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Ko0000ogmoOomoOgoo0000oiVIVOl00003
ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<2o`000005ogmoOol0003o
IVIVofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo
0000ogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Wo0000ok>c/ol0003oVIVIo`00
0?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`03o`000?m<C4cooooo00Go
oooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo3?nIVIT00ol0003oOgmo
ogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIV
ofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>c
ok>c/`0Eok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIV
ofIVIP02ofIVIP03o`000?m<C4coC4a<00WoC4a<00?o0000oda<C?m<C4`01_m<C4`01Ol0003oIVIV
ofIVI_mVIVKo000000?oOgmo00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<
00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`05o`000?mVIVKo
IVIVofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`03o`000?m<C4coC4a<00;o000000Go
IVIVo`000?moOgooOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Wo0000ok>c/onc
/k?o/k>co`000?nIVIWo0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`08o`00
0?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVIV@03o`000?nc/k?o000000Soc<c<00[o0000
ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c
<`03o`000?m<C4cooooo00Gooooo0Ol00001ooooo`7ooooo000Tooooo`;o00001?ooool;oiVIV@03
o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<oda<C00Foda<C0;o
00003OmVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00coVIVI00?o0000ok>c/onc
/k<05Onc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00?oOgmo00?o0000ofIVI_mV
IVH00_mVIVH00ol0003oC4a<oda<C00Boda<C004o`000?mVIVKoIVIVo`0000CoOgmo00Go0000oiVI
VOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<0
1?l0003oVIVIoiVIVOl00002ogmoO`05o`000?mVIVKoIVIVofIVI_l000000om<C4`00ol0003o<c<c
oc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01?l0
003o/k>cok>c/ol00008olc<c009o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000?moOgoo000000;o
IVIV00Co0000oda<C?m<C4co00002?lc<c<02?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000
0_nIVIT00ol0003o/k>co`000008olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003o
IVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<00ol0003oC4a<o`000004ooooo`;o00000_oo
ool002Cooooo00?o0000ooooooooool00oooool:oiVIV@03o`000?moOgooOgmo00SoOgmo0_l0000<
ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH2o`0000[oOgmo00?o0000
oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`0Eok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000
ogmoOomoOgl00omoOgl00ol0003oIVIVofIVIP02ofIVIP03o`000?m<C4coC4a<01;oC4a<00Go0000
ofIVI_mVIVKoIVIVo`000003ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0003oc<c<
olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01Ol0003o
IVIVofIVI_mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002
ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01ol0003o/k>c
ok>c/onc/k?o0000oiVIVOl000000_moOgl01_l0003oIVIVofIVI_l0003oC4a<o`0000So<c<c00Ko
0000oda<C?m<C4co0000ofIVI_l00002ogmoO`05o`000?nIVIWo0000ok>c/ol000002Oo<c<`02Ol0
003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c
00Co0000oda<C?m<C4co00001Oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool0
0oooool9oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<
oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVI
oiVIV@0;oiVIV@;o00005onc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00?oOgmo
00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C00Boda<C005o`000?mVIVKoIVIVofIVI_l0
00000omoOgl2o`0000;oVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c005olc<c003
o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00003
oda<C003o`000?lc<c?o<c<c00Oo<c<c00Co0000oda<C?m<C4co00000_mVIVH01_l0003oOgmoogmo
Ool0003oVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVI
V@06o`000?moOgoo0000o`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`07o`000?m<
C4coC4a<o`000?mVIVKo0000ogmoO`02o`000004oiVIVOl0003o/k>co`0000Woc<c<00Wo0000ok>c
/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`03o`00
0?m<C4co000000Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo2?nI
VIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05om<
C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT03?nI
VIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl00omo
Ogl00ol0003oIVIVofIVIP02ofIVIP03o`000?m<C4coC4a<01;oC4a<00Go0000ofIVI_mVIVKoIVIV
o`000003ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001Onc/k<00ol0003oc<c<olc<c005olc<c005
o`000?nc/k?o/k>cok>c/ol000000onIVIT01?l0003oOgmoogmoOol00002ofIVIP05o`000?m<C4co
C4a<oda<C?l000002Olc<c<01?l0003oC4a<oda<C?l00002ofIVIP06o`000?moOgooOgmoo`000?nI
VIWo00000onc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000
ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo
0000ogmoOol00002oiVIV@03o`000?nc/k?o000000Woc<c<00Wo0000ok>c/ol0003oVIVIo`000?mo
Ogoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`03o`000?m<C4co000000Kooooo
0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo1onIVIT00ol0003oOgmoogmo
O`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIV
IP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c
/`0Fok>c/`03o`000?nIVIWoVIVI00GoVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIV
IP03ofIVIP03o`000?m<C4coC4a<017oC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmo
OomoOgoo000000?oVIVI00?o0000ok>c/onc/k<00_nc/k<00ol0003oc<c<olc<c005olc<c003o`00
0?nc/k?o/k>c00;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`00
00?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o0000
ogmoOol000000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Ooc<c<00Co0000ok>c/onc/k?o0000
0onIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00?o0000oda<C?m<
C4`00_l00002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003o
/k>co`000002oiVIV@04o`000?moOgoo0000o`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<00ol0
003oC4a<o`000006ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`Ko
VIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<01Oo
C4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00_o
VIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@05oiVIV@03o`000?moOgooOgmo00?o
Ogmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C00Boda<C005o`000?mVIVKoIVIVofIV
I_l000000omoOgl00ol0003oVIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c00;o/k>c00?o0000olc<
c?o<c<`01?o<c<`00ol0003o/k>cok>c/`02ok>c/`03o`000?nIVIWoVIVI00;oVIVI00?o0000ogmo
Ool000000omVIVH01?l0003oC4a<oda<C?l00008oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mV
IVH01?l0003oOgmoogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Co0000ok>c/onc
/k?o00000onIVIT2o`0000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<02?l0003oC4a<oda<C?l0
003oIVIVo`000?moOgoo00000_nIVIT00ol0003o/k>co`000009olc<c009o`000?nc/k?o0000oiVI
VOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<o`00
0?mVIVH6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`GoVIVI00?o
0000ogmoOomoOgl02?moOgl2o`0000goIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIV
IP0:ofIVIP;o00002_moOgl2o`0000coVIVI0_l0000Hok>c/`03o`000?nIVIWoVIVI00GoVIVI00?o
0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIVIP02ofIVIP;o00004om<C4`00ol0003oIVIVofIV
IP02ofIVIP05o`000?moOgooOgmoogmoOol000000onIVIT00ol0003o/k>cok>c/`02ok>c/`03o`00
0?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;o
Ogmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<
oda<C?l000000_mVIVH01_l0003oOgmoogmoOol0003oVIVIo`0000?o/k>c00?o0000olc<c?o<c<`0
1_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<
C4co00002?lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03
o`000?o<c<coc<c<00Koc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000
0_m<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4co0000ofIVI_l000001Oooool1o`00007o
oooo0Oooool002Cooooo00?o0000ooooooooool00oooool4oiVIV@03o`000?moOgooOgmo00SoOgmo
00?o0000ofIVI_mVIVH03?mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00[oIVIV
00?o0000ogmoOomoOgl02_moOgl00ol0003oVIVIoiVIV@0:oiVIV@03o`000?nc/k?o/k>c01So/k>c
00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00?oIVIV
00?o0000oda<C?m<C4`04_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00?o0000oiVIVOnI
VIT00_nIVIT00ol0003o/k>cok>c/`02ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc
/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`0
0ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000?oIVIV00Ko0000ogmoOomoOgoo0000
oiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0
003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00?o0000oda<C?l000000_mVIVH0
1Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02_l0003o/k>cok>c
/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000
oda<C?l0003oIVIVo`000005ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03
ooooo`?oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4co
C4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWo
VIVI00[oVIVI00?o0000ok>c/onc/k<06?nc/k<00ol0003oVIVIoiVIV@05oiVIV@03o`000?moOgoo
Ogmo00?oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C00Boda<C003o`000?mVIVKo
IVIV00;oIVIV00Co0000ogmoOomoOgoo00001?nIVIT00ol0003o/k>cok>c/`02ok>c/`03o`000?o<
c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo
00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<
C?l000000omVIVH01Ol0003oOgmoo`000?nIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`0
1?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co0000
2?lc<c<02?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo00000_nIVIT01?l0003o/k>cok>c/ol0
0008olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c
<olc<c<01_lc<c<01Ol0003oC4a<o`000?mVIVKo000000Kooooo0Ol00001ooooo`7ooooo000Toooo
o`03o`000?oooooooooo00?ooooo0_nIVIT00ol0003oOgmoogmoO`08ogmoO`;o00003OmVIVH00ol0
003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00[oIVIV0_l0000:ogmoO`;o00003?nIVIT2o`00
01So/k>c0_l00007oiVIV@03o`000?moOgooOgmo00?oOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0
003oC4a<oda<C00Boda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01Ol0003oVIVIoiVIVOnI
VIWo000000Go/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nI
VIWoVIVIo`0000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko
<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c
/onc/k?o00002Oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV00Co
0000oda<C?m<C4co00002?lc<c<02?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo00000_nIVIT0
0ol0003o/k>co`000008olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`00
00;oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<o`000?mVIVKo000000Kooooo0Ol00001
ooooo`7ooooo000Tooooo`;o00001?ooool00onIVIWo0000ogmoO`09ogmoO`03o`000?mVIVKoIVIV
00coIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0:ofIVIP03o`000?moOgooOgmo
00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Hok>c/`03o`000?nIVIWoVIVI
00KoVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<
017oC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000?oVIVI00?o0000
ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c005olc<c005o`000?nc/k?o/k>cok>c/ol000000onI
VIT01?l0003oOgmoogmoOol00003ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01Ol0003o
C4a<oda<C?m<C4co000000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00009
olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<
C?l00008oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVIV@03o`000?nc/k?o
000000Soc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0
003o<c<coc<c<`06oc<c<`05o`000?m<C4co0000ofIVI_l000001Oooool2o`0000;ooooo000Toooo
o`03o`000?oooooooooo00?ooooo00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0;ofIV
IP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmo
O`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<06?nc/k<00ol0003oVIVIoiVIV@06oiVI
V@03o`000?moOgooOgmo00?oOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00Boda<
C005o`000?mVIVKoIVIVofIVI_l000000omoOgl00ol0003oVIVIoiVIV@02oiVIV@03o`000?nc/k?o
/k>c00;o/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWo
VIVIo`0000?oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`00
0?m<C4coC4a<oda<C?l000000_mVIVH00ol0003oOgmoo`000002oiVIV@05o`000?nc/k?o/k>cok>c
/ol000002?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@06o`000?moOgooOgmoo`000?mVIVKo0000
0_m<C4`00ol0003o<c<coc<c<`06oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002
oiVIV@03o`000?nc/k?o000000Woc<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0
00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`03o`000?m<C4coC4a<00;o000000?oOgmooooooooo
ool01?ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool:ogmoO`;o0000
3OmVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl0
2?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c0_l00008oiVIV@03o`00
0?moOgooOgmo00?oOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00Boda<C003o`00
0?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgooOgmoo`000003oiVIV@03o`000?nc/k?o/k>c00?o
/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`04o`000?nIVIWoVIVIo`00
00;oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4co
C4a<oda<C?l000000_mVIVH00ol0003oOgmoo`000002oiVIV@05o`000?nc/k?o/k>cok>c/ol00000
2?o<c<`01Ol0003o/k>cok>c/ol0003oVIVI00;o000000CoOgmoo`000?mVIVKo00000_m<C4`00ol0
003o<c<coc<c<`07oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o
/k>c00?o0000olc<c?o<c<`01oo<c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`00
0002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Oo0000oda<C?l0003oIVIVo`000?moOgoo000000Go
oooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo2OmoOgl00ol0003oIVIV
ofIVIP0<ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmo
ogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<06?nc/k<00ol0003oVIVI
oiVIV@06oiVIV@03o`000?moOgooOgmo00CoOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<
oda<C00Boda<C005o`000?mVIVKoIVIVofIVI_l000001?moOgl01Ol0003oVIVIoiVIVOnIVIWo0000
00Go/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`04o`000?nIVIWoVIVI
o`0000;oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<
C4coC4a<00;oC4a<00Ko0000ofIVI_mVIVKo0000ogmoOol00002oiVIV@05o`000?nc/k?o/k>cok>c
/ol000001oo<c<`01ol0003o/k>cok>c/onc/k?o0000oiVIVOl000000_moOgl00ol0003oIVIVo`00
0002oda<C003o`000?lc<c?o<c<c00Oo<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`00
0?nIVIWo00000_nc/k<00ol0003oc<c<olc<c007olc<c00;o`000?nc/k?o0000oiVIVOl0003oOgmo
o`000?mVIVKo0000oda<C?l000002Olc<c<01ol0003oC4a<o`000?mVIVKo0000ogmoOol000001Ooo
ool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool8ogmoO`03o`000?mVIVKo
IVIV00coIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgoo
Ogmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Hok>c/`03o`000?nIVIWo
VIVI00KoVIVI00?o0000ogmoOomoOgl01?moOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4co
C4a<01;oC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000?oVIVI00?o
0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Co
0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00004oda<C003o`000?lc<c?o<c<c00Ko
<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Co0000
ok>c/onc/k?o00002?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l0
00000om<C4`00ol0003o<c<coc<c<`06oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0
003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01oo<c<`02Ol0003o/k>co`000?nIVIWo0000ogmo
Ool0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Oo0000oda<C?l0003oIVIVo`00
0?moOgoo000000Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo1omo
Ogl00ol0003oIVIVofIVIP0;ofIVIP;o00006?m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?mo
OgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Hok>c/`03o`000?nI
VIWoVIVI00KoVIVI00?o0000ogmoOomoOgl01?moOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<
C4coC4a<01;oC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000?oVIVI
00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c
00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c
<olc<c<01Olc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nI
VIT01?l0003o/k>cok>c/ol00008olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01Ol0003o
Ogmoo`000?mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<02_l0003oC4a<oda<C?l0003o
IVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00[o0000ok>c/onc
/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`07o`00
0?m<C4co0000ofIVI_l0003oOgmoo`000006ooooo`7o00000Oooool1ooooo`009?ooool00ol0003o
ooooooooo`03ooooo`KoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Goda<C003
o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl2o`0000coVIVI00?o0000ok>c/onc
/k<06?nc/k<00ol0003oVIVIoiVIV@07oiVIV@03o`000?moOgooOgmo00CoOgmo00?o0000ofIVI_mV
IVH00omVIVH00ol0003oC4a<oda<C00Boda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomo
OgooOgmoo`000003oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0
003o/k>cok>c/`02ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01?l0003oIVIVofIVI_l0
0004oda<C003o`000?lc<c?o<c<c00Go<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`00
0?moOgooOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01Ol0003o/k>cok>c/onc/k?o
000000;oVIVI00Go0000ogmoOol0003oIVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c00?o
0000oda<C?l000000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`0
1_o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc
<c?o<c<c00Ko<c<c00Oo0000oda<C?l0003oIVIVo`000?moOgoo000000Kooooo0Ol00001ooooo`7o
oooo000Tooooo`03o`000?oooooooooo00?ooooo1OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`00
0?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`00
0?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<06?nc/k<00ol0003oVIVIoiVIV@07oiVIV@03o`00
0?moOgooOgmo00CoOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00Coda<C005o`00
0?mVIVKoIVIVofIVI_l000000omoOgl01Ol0003oVIVIoiVIVOnIVIWo000000Ko/k>c00?o0000olc<
c?o<c<`01?o<c<`00ol0003o/k>cok>c/`02ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl0
1?l0003oIVIVofIVI_l00004oda<C003o`000?lc<c?o<c<c00Go<c<c00Go0000oda<C?m<C4coC4a<
o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`01?l0
003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc
<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00003ok>c/`03o`000?o<c<co
c<c<00Koc<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o
<c<coc<c<`06oc<c<`03o`000?m<C4co000000;oIVIV0_l000000onIVIWoooooooooo`04ooooo`7o
00000Oooool1ooooo`006Oooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000oooooooo
ool00oooool4ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`2o`0000go
IVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01So
/k>c00?o0000oiVIVOnIVIT01onIVIT00ol0003oOgmoogmoO`04ogmoO`03o`000?mVIVKoIVIV00?o
IVIV00?o0000oda<C?m<C4`04om<C4`00ol0003oIVIVofIVIP02ofIVIP05o`000?moOgooOgmoogmo
Ool000000onIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c
/onc/k<00onc/k<01?l0003oVIVIoiVIVOl00002ogmoO`05o`000?mVIVKoIVIVofIVI_l000000om<
C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmo
ogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Woc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl0
0002ogmoO`05o`000?mVIVKo0000o`000?m<C4`00_l00008oc<c<`0:o`000?m<C4coC4a<o`000?mV
IVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`03?l0003o/k>cok>c
/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000Wo<c<c00So0000oda<C?l0003oIVIV
o`000?moOgoo0000oiVIV@Kooooo0Ol00001ooooo`7ooooo000Iooooo`05ob4Q8OnHV9SooooooiRH
V?lQ8B401_ooool00ol0003oooooooooo`03ooooo`CoOgmo00?o0000ofIVI_mVIVH02_mVIVH00ol0
003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0
003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c0_l00009oiVIV@03o`000?moOgooOgmo
00GoOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00Coda<C005o`000?mVIVKoIVIV
ofIVI_l000001?moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Go/k>c00?o0000olc<c?o<c<`01?o<
c<`00ol0003o/k>cok>c/`03ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Go0000ofIVI_mVIVKo
IVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIV
IP04o`000?moOgooOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`02?l0003o/k>cok>c
/ol0003oVIVIo`000?moOgoo00000_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`0:o`000?m<C4co
C4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`03?l0
003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000Wo<c<c00Wo0000oda<
C?l0003oIVIVo`000?moOgoo0000oiVIVOl000001Oooool1o`00007ooooo0Oooool001Wooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00?ooooo0_moOgl2o`0000coIVIV
00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo
00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00SoVIVI
00?o0000ogmoOomoOgl01OmoOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<01?oC4a<
00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000?oVIVI00?o0000ok>c/onc
/k<00onc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnI
VIWo00000_moOgl00ol0003oIVIVofIVIP02ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Go0000
oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o
00002Oo<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00?o0000ofIVI_l000000_m<C4`0
0ol0003o<c<coc<c<`07oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`00
00;o/k>c00?o0000olc<c?o<c<`01oo<c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIV
o`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00?o0000oda<C?m<C4`00_l000001OmoOgoo0000
oiVIVOnIVIWo000000Gooooo0Ol00001ooooo`7ooooo000Iooooo`05oc8b<_nHV9SooooooiRHV?lb
<S801_ooool3o`0000?ooooo00?oOgmoo`000?mVIVH03?mVIVH00ol0003oC4a<oda<C00Foda<C0;o
00003OmVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc
/k<05onc/k<00ol0003oVIVIoiVIV@09oiVIV@03o`000?moOgooOgmo00CoOgmo00?o0000ofIVI_mV
IVH00omVIVH00ol0003oC4a<oda<C00Coda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomo
OgooOgmoo`000003oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0
003o/k>cok>c/`02ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01Ol0003oIVIVofIVI_mV
IVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV
00Go0000ogmoOomoOgoo0000oiVIV@02o`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01ol0003o
/k>cok>c/onc/k?o0000oiVIVOl000000_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o
<c<c00Oo<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0
003oc<c<olc<c007olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<
00?o0000oc<c<olc<c<01_lc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000004
ooooo`?o00000_ooool001Wooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooo
oooo00?ooooo00?oOgmoo`000?mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKo
IVIV00coIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o
/k>c01Oo/k>c00?o0000oiVIVOnIVIT02OnIVIT00ol0003oOgmoogmoO`05ogmoO`03o`000?mVIVKo
IVIV00?oIVIV00?o0000oda<C?m<C4`04om<C4`00ol0003oIVIVofIVIP02ofIVIP05o`000?moOgoo
OgmoogmoOol000000onIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o
0000ok>c/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Go0000ofIVI_mVIVKo
IVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIV
IP03o`000?moOgoo000000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c004o`000?nc/k?o
/k>co`0000;oVIVI00Ko0000ogmoOomoOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo
<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<
olc<c007olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000
oc<c<olc<c<01_lc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000006ooooo`7o
00000Oooool1ooooo`006Oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000oooooooo
ool00oooool00ol0003oIVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mV
IVH02omVIVH2o`0000[oOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Gok>c/`03
o`000?nIVIWoVIVI00WoVIVI00?o0000ogmoOomoOgl01OmoOgl00ol0003oIVIVofIVIP04ofIVIP03
o`000?m<C4coC4a<01;oC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo0000
00?oVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c
00;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`05o`000?mVIVKoIVIVofIVI_l000000om<
C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01_l0003oOgmo
ogmoOol0003oVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01_o<c<`01_l0003o/k>cok>c/ol0003o
VIVIo`0000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`0:o`000?m<
C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01oo<c<`0
0ol0003o/k>co`000002oiVIV@;o000000GoIVIVo`000?m<C4coC4a<o`000009oc<c<`04o`000?m<
C4co0000o`0000;oOgmo0_l000000onc/k?oooooooooo`04ooooo`7o00000Oooool1ooooo`006Ooo
ool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool00oooool<ofIVIP03o`00
0?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`00
0?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<2o`0000_oVIVI00?o0000ogmoOomoOgl0
1OmoOgl00ol0003oIVIVofIVIP04ofIVIP03o`000?m<C4coC4a<01;oC4a<00?o0000ofIVI_mVIVH0
0_mVIVH01Ol0003oOgmoogmoOomoOgoo000000CoVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003o
c<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmo
O`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<00ol0003oC4a<oda<C002
oda<C006o`000?mVIVKoIVIVo`000?moOgoo00000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000So
c<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo00?o0000ofIVI_l000000_m<C4`0
0ol0003o<c<coc<c<`07oc<c<`03o`000?m<C4co000000;oIVIV00Go0000ogmoOol0003oVIVIo`00
0002ok>c/`03o`000?o<c<coc<c<00Koc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`00
0?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`03o`000?m<C4coC4a<00;o000000GoOgmo
o`000?nIVIWo0000ok>c/`06ooooo`7o00000Oooool1ooooo`006Oooool01OnYZJWo410@o`000?l@
413oZJVY00Kooooo00?o0000ooooooooool00oooool;ofIVIP03o`000?m<C4coC4a<01KoC4a<0_l0
000=ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c
/`0Fok>c/`03o`000?nIVIWoVIVI00[oVIVI00?o0000ogmoOomoOgl01OmoOgl00ol0003oIVIVofIV
IP04ofIVIP03o`000?m<C4coC4a<01;oC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmo
OomoOgoo000000CoVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c004olc<c003o`00
0?nc/k?o/k>c00?o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01Ol0003oIVIVofIVI_mVIVKo0000
00?oC4a<00?o0000oc<c<olc<c<01_lc<c<00ol0003oC4a<oda<C002oda<C006o`000?mVIVKoIVIV
o`000?moOgoo00000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Oo0000ok>c/onc/k?o
/k>co`000?nIVIWo000000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c
<`03o`000?m<C4co000000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<co
c<c<00Koc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0
003o<c<coc<c<`06oc<c<`03o`000?m<C4coC4a<00;o000000GoOgmoo`000?nIVIWo0000ok>c/`06
ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`[oIVIV00?o0000oda<
C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP;o00002_moOgl00ol0003oVIVIoiVIV@0<oiVI
V@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`04ogmo
O`;o00001_mVIVH00ol0003oC4a<oda<C00Boda<C003o`000?mVIVKoIVIV00?oIVIV00Co0000ogmo
OomoOgoo00001?nIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000
ok>c/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo0000
1?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Ko0000ofIVI_mVIVKo
0000ogmoOol00002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01ol0003o/k>cok>c/onc
/k?o0000oiVIVOl000000_moOgl00ol0003oIVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c
00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<
c007olc<c003o`000?nc/k?o/k>c00;o000000OoOgmoo`000?mVIVKoIVIVo`000?m<C4co000000Wo
<c<c00Co0000oda<C?l0003oIVIV0_l000001?nIVIWo0000ok>c/onc/k<6ooooo`7o00000Oooool1
ooooo`009?ooool00ol0003oooooooooo`03ooooo`WoIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0
003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT2o`00
01Oo/k>c0_l0000<oiVIV@03o`000?moOgooOgmo00CoOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0
003oC4a<oda<C00Coda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgooOgmoo`000003
oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`02
ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000CoC4a<
00?o0000oc<c<olc<c<01Olc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomo
Ogoo00000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Co0000ok>c/onc/k?o00000_nI
VIT00ol0003oOgmoo`000002ofIVIP03o`000?m<C4coC4a<00;o00001olc<c<01?l0003oC4a<oda<
C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c00:
o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<0
1olc<c<01?l0003oC4a<o`000?mVIVH2o`000005oiVIVOl0003o/k>cok>c/ol000001Oooool1o`00
007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool8ofIVIP03o`000?m<C4coC4a<01Oo
C4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00co
VIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0:oiVIV@03o`000?moOgooOgmo00Go
Ogmo00?o0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<C00Coda<C003o`000?mVIVKoIVIV00;o
IVIV00Go0000ogmoOomoOgooOgmoo`000003oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<
c?o<c<`01?o<c<`00ol0003o/k>cok>c/`02ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl0
1Ol0003oIVIVofIVI_mVIVKo000000CoC4a<00?o0000oc<c<olc<c<01Olc<c<01Ol0003oC4a<oda<
C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01Ol0003o/k>cok>c/onc/k?o0000
00Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4co
C4a<o`0000So<c<c00Co0000oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o
/k>c00?o0000olc<c?o<c<`01_o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIV
I_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Co0000oda<C?l0003oIVIV0_l000001OnIVIWo
0000ok>c/onc/k?o000000Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?o
oooo1omVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomo
Ogl02OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnI
VIT02onIVIT00ol0003oOgmoogmoO`04ogmoO`03o`000?mVIVKoIVIV00GoIVIV00?o0000oda<C?m<
C4`04om<C4`00ol0003oIVIVofIVIP02ofIVIP05o`000?moOgooOgmoogmoOol000000onIVIT00ol0
003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00onc/k<01Ol0
003oVIVIoiVIVOnIVIWo000000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000003oda<C003o`000?lc
<c?o<c<c00Ko<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00Co0000oiVIVOnI
VIWo00001?nc/k<00ol0003oc<c<olc<c005olc<c007o`000?nc/k?o/k>cok>c/ol0003oVIVIo`00
0002ogmoO`04o`000?mVIVKoIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<
oda<C?l00002ofIVIP;o00000_nIVIT01?l0003o/k>cok>c/ol00008olc<c00:o`000?nc/k?o/k>c
o`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<00ol0003o
C4a<o`000002ofIVIP;o000000GoVIVIo`000?nc/k?o/k>co`000005ooooo`7o00000Oooool1oooo
o`009?ooool00ol0003oooooooooo`03ooooo`KoIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003o
IVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o
/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl01?moOgl00ol0003o
IVIVofIVIP06ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003o
OgmoogmoOomoOgoo000000?oVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c005olc<
c003o`000?nc/k?o/k>c00;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`05o`000?mVIVKo
IVIVofIVI_l000001?m<C4`00ol0003o<c<coc<c<`05oc<c<`05o`000?m<C4coC4a<oda<C?l00000
0_mVIVH01?l0003oOgmoogmoOol00002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01?l0
003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002Olc
<c<00ol0003oC4a<o`000002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<
olc<c006olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o
0000oc<c<olc<c<01olc<c<01?l0003oC4a<o`000?mVIVH2o`0000;oVIVI00?o0000ok>c/ol00000
1_ooool1o`00007ooooo0Oooool002Cooooo0_l00004ooooo`KoIVIV00?o0000oda<C?m<C4`05_m<
C4`00ol0003oIVIVofIVIP0:ofIVIP;o00002_moOgl2o`0000coVIVI0_l0000Gok>c/`;o00003?nI
VIT2o`0000OoOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<C00Coda<C003o`000?mV
IVKoIVIV00;oIVIV00Go0000ogmoOomoOgooOgmoo`000004oiVIV@03o`000?nc/k?o/k>c00?o/k>c
00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`05o`000?nIVIWoVIVIoiVIVOl0
00000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0
003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01Ol0003o/k>cok>c
/onc/k?o000000Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIVIP04
o`000?m<C4coC4a<o`0000Wo<c<c00?o0000oda<C?l000000_mVIVH01Ol0003oOgmoo`000?nIVIWo
000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo
0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4co0000ofIVIP02
o`000005oiVIVOl0003o/k>cok>c/ol000001Oooool2o`0000;ooooo000Tooooo`03o`000?oooooo
oooo00?ooooo1OmVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00[oIVIV00?o0000
ogmoOomoOgl02_moOgl00ol0003oVIVIoiVIV@0:oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000
oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`06ogmoO`03o`000?mVIVKoIVIV00CoIVIV00?o0000
oda<C?m<C4`04om<C4`00ol0003oIVIVofIVIP03ofIVIP05o`000?moOgooOgmoogmoOol000001?nI
VIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00onc
/k<01?l0003oVIVIoiVIVOl00003ogmoO`05o`000?mVIVKoIVIVofIVI_l000000om<C4`00ol0003o
<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002
oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`00
0?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<00ol0003oC4a<o`000002ofIVIP05
o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c00:o`000?nc/k?o/k>c
o`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003o
C4a<oda<C?l0003oIVIV00;o000000GoVIVIo`000?nc/k?o/k>co`000006ooooo`7o00000Oooool1
ooooo`009?ooool00ol0003oooooooooo`03ooooo`CoIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0
003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02_nIVIT00ol0
003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl01_moOgl00ol0
003oIVIVofIVIP05ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0
003oOgmoogmoOomoOgoo000000CoVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c004
olc<c003o`000?nc/k?o/k>c00?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`05o`000?mV
IVKoIVIVofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l0
00000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`0
1?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co0000
2Olc<c<00ol0003oC4a<o`000002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003o
c<c<olc<c006olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<
00?o0000oc<c<olc<c<01olc<c<01_l0003oC4a<o`000?mVIVKo0000ogmoO`;o00000_nc/k<00ol0
003oc<c<ooooo`05ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`?o
IVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0:ofIVIP;o00002_moOgl2o`0000co
VIVI0_l0000Gok>c/`;o00003OnIVIT00ol0003oOgmoogmoO`05ogmoO`;o00001omVIVH00ol0003o
C4a<oda<C00Coda<C003o`000?mVIVKoIVIV00;oIVIV00?o0000ogmoOomoOgl00_moOgl01Ol0003o
VIVIoiVIVOnIVIWo000000Ko/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`04ok>c
/`04o`000?nIVIWoVIVIo`0000?oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c
<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@04
o`000?nc/k?o/k>co`0000Soc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@03o`000?moOgoo
000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP05o`00
0?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c00:o`000?nc/k?o/k>co`00
0?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<
oda<C?l0003oIVIV00;o000000KoVIVIo`000?nc/k?o/k>co`000?o<c<`6ooooo`7o00000Oooool1
ooooo`009?ooool00ol0003oooooooooo`03ooooo`;oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0
003oIVIVofIVIP0:ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0
003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl01_moOgl00ol0
003oIVIVofIVIP06ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH00_mVIVH00ol0
003oOgmoogmoO`02ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001_nc/k<00ol0003oc<c<olc<c003
olc<c003o`000?nc/k?o/k>c00Co/k>c00Co0000oiVIVOnIVIWo00000omoOgl01?l0003oIVIVofIV
I_l00004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIV
ofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0
003o/k>cok>c/onc/k?o000000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc
<c?o<c<c00Oo<c<c00Co0000oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o
/k>c00?o0000olc<c?o<c<`01_o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIV
I_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4co0000ofIVIP02o`000006
oiVIVOl0003o/k>cok>c/ol0003oc<c<1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000oooo
ooooool00oooool00omVIVKo0000oda<C00Goda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmo
OomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVI
VOnIVIT03?nIVIT00ol0003oOgmoogmoO`06ogmoO`03o`000?mVIVKoIVIV00KoIVIV00?o0000oda<
C?m<C4`04om<C4`00ol0003oIVIVofIVIP02ofIVIP03o`000?moOgooOgmo00;oOgmo00Go0000oiVI
VOnIVIWoVIVIo`000006ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<01?nc/k<0
1?l0003oVIVIoiVIVOl00003ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<0
1_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01?l0
003o/k>cok>c/ol00008olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT00ol0003oOgmoo`00
0002ofIVIP04o`000?m<C4coC4a<o`0000Wo<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmo
o`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c007olc<c007o`000?nc/k?o0000oiVIVOl0003o
Ogmoo`000002ofIVIP03o`000?m<C4co000000So<c<c00Oo0000oda<C?m<C4co0000ofIVI_l0003o
Ogmo00;o00000_nc/k<00ol0003oc<c<olc<c006ooooo`7o00000Oooool1ooooo`009?ooool00ol0
003oooooooooo`03ooooo`03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0
003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<2o`00
00goVIVI00?o0000ogmoOomoOgl01_moOgl00ol0003oIVIVofIVIP06ofIVIP03o`000?m<C4coC4a<
01?oC4a<00?o0000ofIVI_mVIVH00_mVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI
00;oVIVI00?o0000ok>c/onc/k<00onc/k<2o`0000Goc<c<00?o0000ok>c/onc/k<00onc/k<01Ol0
003oVIVIoiVIVOnIVIWo000000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000003oda<C0;o00001olc
<c<01Ol0003oC4a<oda<C?m<C4co000000?oIVIV00?o0000ogmoOol000000_nIVIT01Ol0003o/k>c
ok>c/onc/k?o000000Soc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@03o`000?moOgoo0000
00;oIVIV00Co0000oda<C?m<C4co00002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP05o`000?mo
Ogoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c00:o`000?nc/k?o/k>co`000?nI
VIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01ol0003oC4a<oda<
C?l0003oIVIVo`000?moOgl00_l00002ok>c/`03o`000?o<c<coc<c<00Kooooo0Ol00001ooooo`7o
oooo000Tooooo`03o`000?oooooooooo00?ooooo6?m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`00
0?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`00
0?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl01_moOgl00ol0003oIVIVofIVIP06ofIVIP03o`00
0?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`02ogmoO`03o`00
0?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c004olc<c003o`00
0?nc/k?o/k>c00?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`05o`000?mVIVKoIVIVofIV
I_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH0
1?l0003oOgmoogmoOol00002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01ol0003o/k>c
ok>c/onc/k?o0000oiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00002oda<C003o`000?lc<c?o
<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c
00?o0000olc<c?o<c<`01_o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0
0002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Oo0000oda<C?m<C4co0000ofIVI_l0003oOgmo00;o
00000_nc/k<00ol0003oc<c<olc<c006ooooo`7o00000Oooool1ooooo`009?ooool00ol0003ooooo
ooooo`03oooooaOoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`00
0?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0<oiVIV@03o`00
0?moOgooOgmo00OoOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<C00Doda<C003o`00
0?mVIVKoIVIV00;oIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@02oiVIV@03o`00
0?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`05o`00
0?nIVIWoVIVIoiVIVOl000000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000?oC4a<00?o0000oc<c
<olc<c<01_lc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00?o0000
oiVIVOl000000onc/k<00ol0003oc<c<olc<c007olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o
0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`04o`000?m<C4coC4a<o`0000;o
IVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Ko0000ok>c
/onc/k?o0000oiVIVOl00002ogmoO`;o00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0<o`000?m<
C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00000oo<c<`6ooooo`7o00000Ooo
ool1ooooo`009?ooool00ol0003oooooooooo`03oooooaKoC4a<00?o0000ofIVI_mVIVH02omVIVH0
0ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<2
o`0000goVIVI00?o0000ogmoOomoOgl01omoOgl00ol0003oIVIVofIVIP05ofIVIP03o`000?m<C4co
C4a<01CoC4a<00?o0000ofIVI_mVIVH00omVIVH01Ol0003oOgmoogmoOomoOgoo000000CoVIVI00?o
0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c00Co/k>c00Co
0000oiVIVOnIVIWo00000omoOgl01?l0003oIVIVofIVI_l00004oda<C003o`000?lc<c?o<c<c00Ko
<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Go0000
ok>c/onc/k?o/k>co`000008olc<c007o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000002ogmoO`03
o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01olc<c<01_l0003oC4a<oda<C?l0003oIVIV
o`0000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c00:o`000?nc/k?o
/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<03?l0
003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000?oc<c<1_ooool1o`00
007ooooo0Oooool002Cooooo0_l00004oooooaGoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003o
OgmoogmoO`08ogmoO`;o00003?nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00co
VIVI00?o0000ogmoOomoOgl01omoOgl00ol0003oIVIVofIVIP05ofIVIP03o`000?m<C4coC4a<01Go
C4a<00?o0000ofIVI_mVIVH00omVIVH01Ol0003oOgmoogmoOomoOgoo000000CoVIVI00?o0000ok>c
/onc/k<01?nc/k<00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c00Co/k>c00Co0000oiVI
VOnIVIWo00000omoOgl01?l0003oIVIVofIVI_l00004oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go
0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Go0000ok>c/onc
/k?o/k>co`000008olc<c007o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000002ogmoO`03o`000?mV
IVKo000000;oC4a<00?o0000oc<c<olc<c<01olc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;o
Ogmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c00:o`000?nc/k?o/k>co`00
0?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<03?l0003oC4a<
oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000?oc<c<1Oooool2o`0000;ooooo
000Tooooo`03o`000?oooooooooo00?ooooo5?m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?mo
OgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nI
VIWoVIVI00coVIVI00?o0000ogmoOomoOgl01omoOgl00ol0003oIVIVofIVIP06ofIVIP03o`000?m<
C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH00omVIVH01Ol0003oOgmoogmoOomoOgoo000000CoVIVI
00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c00Co/k>c
00Co0000oiVIVOnIVIWo00000omoOgl01Ol0003oIVIVofIVI_mVIVKo000000?oC4a<00?o0000oc<c
<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nI
VIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo0000
00;oOgmo00?o0000ofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<
o`0000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co
0000ok>c/onc/k?o00000_nIVIT2o`000005ofIVI_l0003oC4a<oda<C?l000002?lc<c<03?l0003o
C4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Coc<c<1_ooool1o`00007o
oooo0Oooool002Cooooo00?o0000ooooooooool00ooooolBoda<C0;o00003OmVIVH00ol0003oOgmo
ogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVI
oiVIV@0<oiVIV@03o`000?moOgooOgmo00OoOgmo00?o0000ofIVI_mVIVH01_mVIVH00ol0003oC4a<
oda<C00Doda<C003o`000?mVIVKoIVIV00?oIVIV00?o0000ogmoOomoOgl00_moOgl01Ol0003oVIVI
oiVIVOnIVIWo000000Oo/k>c00?o0000olc<c?o<c<`00_o<c<`00ol0003o/k>cok>c/`04ok>c/`05
o`000?nIVIWoVIVIoiVIVOl000000omoOgl01?l0003oIVIVofIVI_l00004oda<C003o`000?lc<c?o
<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nI
VIWoVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01oo<c<`01ol0003o/k>cok>c/onc/k?o0000oiVI
VOl000000_moOgl00ol0003oIVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Ko0000oda<
C?m<C4co0000ofIVI_l00002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<
c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o
<c<c00Ko<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00004
olc<c0Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo4_m<C4`00ol0
003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0
003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00[oVIVI0_l0000:ogmoO`03o`000?mVIVKoIVIV
00KoIVIV00?o0000oda<C?m<C4`05?m<C4`00ol0003oIVIVofIVIP03ofIVIP03o`000?moOgooOgmo
00;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000006ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000
ok>c/onc/k<01?nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Co0000ofIVI_mVIVKo0000
1?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo
00000_moOgl01?l0003oVIVIoiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Oo0000ok>c
/onc/k?o/k>co`000?nIVIWo000000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c
<`07oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl00ol0003oVIVIo`000002ok>c/`03
o`000?o<c<coc<c<00Koc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000
0_m<C4`00ol0003o<c<coc<c<`06oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003o
VIVIo`000?nc/k?o00001?o<c<`6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003ooooooooo
o`03oooooa7oC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nI
VIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0:oiVIV@03o`000?mo
OgooOgmo00WoOgmo00?o0000ofIVI_mVIVH01_mVIVH00ol0003oC4a<oda<C00Doda<C003o`000?mV
IVKoIVIV00?oIVIV00?o0000ogmoOomoOgl00_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Oo/k>c
00?o0000olc<c?o<c<`00_o<c<`00ol0003o/k>cok>c/`05ok>c/`04o`000?nIVIWoVIVIo`0000?o
Ogmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<
00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<
c<coc<c<00Koc<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo00Co0000ofIVI_mV
IVKo00000_m<C4`00ol0003o<c<coc<c<`07oc<c<`03o`000?m<C4coC4a<00;o00000_moOgl00ol0
003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00?o0000ok>c/onc/k<00_l000001omo
Ogoo0000ofIVI_mVIVKo0000oda<C?l000002?lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?mo
Ogoo0000oiVIVOl0003o/k>co`0000Goc<c<1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000
ooooooooool00oooool?oda<C0;o00003OmVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWo
VIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<2o`0000coVIVI00?o0000ogmoOomoOgl02OmoOgl0
0ol0003oIVIVofIVIP06ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH00omVIVH0
0ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01?nc/k<0
0ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c00Co/k>c00Go0000oiVIVOnIVIWoVIVIo`00
0002ogmoO`05o`000?mVIVKoIVIVofIVI_l000001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`00
0?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00003ok>c
/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT01_l0003oOgmoogmoOol0
003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01olc<c<01_l0003oC4a<oda<C?l0003oIVIVo`00
00;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c00:o`000?nc/k?o/k>c
o`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<03?l0003o
C4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Goc<c<1_ooool1o`00007o
oooo0Oooool002Cooooo00?o0000ooooooooool00oooool>oda<C003o`000?mVIVKoIVIV00coIVIV
00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c
00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00OoIVIV
00?o0000oda<C?m<C4`05?m<C4`00ol0003oIVIVofIVIP02ofIVIP03o`000?moOgooOgmo00?oOgmo
00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00?oc<c<
00?o0000ok>c/onc/k<01?nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Go0000ofIVI_mV
IVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0
003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01oo<
c<`01?l0003o/k>cok>c/ol00002oiVIV@06o`000?moOgooOgmoo`000?mVIVKo00000_m<C4`00ol0
003o<c<coc<c<`07oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl00ol0003oVIVIo`00
0002ok>c/`03o`000?o<c<coc<c<00Koc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`00
0?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000
ogmoOol0003oVIVIo`000?nc/k?o00001Oo<c<`6ooooo`7o00000Oooool1ooooo`009?ooool00ol0
003oooooooooo`03ooooo`goC4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmoO`08ogmo
O`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0:oiVI
V@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH01omVIVH00ol0003oC4a<oda<C00Doda<
C003o`000?mVIVKoIVIV00?oIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@02oiVI
V@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`04ok>c
/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01?l0003oIVIVofIVI_l00004oda<C003o`000?lc
<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`00
0?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o0000
00;oVIVI00Go0000ogmoOol0003oIVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Ko0000
oda<C?m<C4co0000ofIVI_l00002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`0
1_o<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo0_l00002oda<C003o`000?lc<c?o<c<c
00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH2o`000005oiVIVOl0003o/k>cok>c/ol000001Oo<
c<`6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`coC4a<00?o0000
ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000
ok>c/onc/k<05_nc/k<2o`0000coVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP07
ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`02
ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c002
olc<c003o`000?nc/k?o/k>c00Co/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`04o`000?mV
IVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000?o
IVIV00?o0000ogmoOol000000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Go0000ok>c
/onc/k?o/k>co`000002oiVIV@03o`000?moOgoo000000;oIVIV00Go0000oda<C?m<C4coC4a<o`00
0008oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl00ol0003oVIVIo`000002ok>c/`03
o`000?o<c<coc<c<00Koc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000
0_m<C4`00ol0003o<c<coc<c<`06oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003o
VIVIo`000?nc/k?o00001_o<c<`6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003ooooooooo
o`03ooooo`_oC4a<0_l0000=ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT03?nI
VIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00[oVIVI00?o0000ogmoOomoOgl02Omo
Ogl00ol0003oIVIVofIVIP07ofIVIP03o`000?m<C4coC4a<01GoC4a<00?o0000ofIVI_mVIVH00omV
IVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01Onc
/k<00ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c00Co/k>c00Go0000oiVIVOnIVIWoVIVI
o`000003ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003o
C4a<oda<C?m<C4co000000?oIVIV00?o0000ogmoOol000000_nIVIT01Ol0003o/k>cok>c/onc/k?o
000000Soc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@03o`000?moOgoo000000;oIVIV00Go
0000oda<C?m<C4coC4a<o`000008oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl00ol0
003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0
003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`03o`000?m<C4co000000;o
IVIV00Oo0000ogmoOol0003oVIVIo`000?nc/k?o000000Koc<c<1_ooool1o`00007ooooo0Oooool0
02Cooooo0_l00004ooooo`[oC4a<00?o0000ofIVI_mVIVH02omVIVH2o`0000[oOgmo00?o0000oiVI
VOnIVIT03?nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00[oVIVI00?o0000ogmo
OomoOgl02OmoOgl00ol0003oIVIVofIVIP08ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIV
I_mVIVH00omVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c
/onc/k<01Onc/k<00ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c00Go/k>c00Co0000oiVI
VOnIVIWo00000omoOgl01?l0003oIVIVofIVI_l00004oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go
0000oda<C?m<C4coC4a<o`000003ofIVIP03o`000?moOgoo000000;oVIVI00Go0000ok>c/onc/k?o
/k>co`000008olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT00ol0003oOgmoo`000002ofIV
IP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP05o`000?mo
Ogoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`0000;o
VIVI0_l000001OmVIVKo0000oda<C?m<C4co000000So<c<c00So0000oda<C?m<C4co0000ofIVI_l0
003oOgmoo`0000;oVIVI0_l00007olc<c0Gooooo0_l00002ooooo`009?ooool00ol0003ooooooooo
o`03ooooo`WoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nI
VIWoVIVI00_oVIVI0_l0000Gok>c/`;o00003?nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mV
IVKoIVIV00SoIVIV00?o0000oda<C?m<C4`05?m<C4`00ol0003oIVIVofIVIP03ofIVIP03o`000?mo
OgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`05ok>c/`05o`000?o<
c<coc<c<olc<c?l000001onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Go0000ofIVI_mV
IVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0
003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<
c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<
oda<C?l00008oc<c<`;o00000_m<C4`01Ol0003oIVIVo`000?moOgoo000000;oVIVI00Co0000ok>c
/onc/k?o00002?o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<
C003o`000?lc<c?o<c<c00Ko<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo
0000ok>c/ol00007olc<c0Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?o
oooo2Om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnI
VIT03?nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00[oVIVI00?o0000ogmoOomo
Ogl02OmoOgl00ol0003oIVIVofIVIP09ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIVI_mV
IVH00omVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc
/k<01Onc/k<01Ol0003oc<c<olc<c?o<c<co000000Oo/k>c00Go0000oiVIVOnIVIWoVIVIo`000002
ogmoO`05o`000?mVIVKoIVIVofIVI_l000001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<
C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03
o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@03o`000?moOgoo0000
00;oIVIV00Co0000oda<C?m<C4co00002?lc<c<02Ol0003oC4a<oda<C?m<C4co0000ofIVI_l0003o
Ogmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0
003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0<o`000?m<C4coC4a<o`00
0?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00001oo<c<`6ooooo`7o00000Oooool1ooooo`00
9?ooool00ol0003oooooooooo`03ooooo`SoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmo
ogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVI
oiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02OmVIVH00ol0003oC4a<
oda<C00Eoda<C003o`000?mVIVKoIVIV00?oIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVI
oiVIV@02oiVIV@03o`000?nc/k?o/k>c00Go/k>c00Go0000olc<c?o<c<coc<c<o`000007ok>c/`05
o`000?nIVIWoVIVIoiVIVOl000000omoOgl01?l0003oIVIVofIVI_l00005oda<C003o`000?lc<c?o
<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nI
VIWoVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01oo<c<`01ol0003o/k>cok>c/onc/k?o0000oiVI
VOl000000_moOgl01?l0003oIVIVofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00_o0000
oda<C?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<
00Koc<c<00_o0000ok>c/onc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003
o`000?lc<c?o<c<c00Ko<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000
ok>c/ol00007olc<c0Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo
1om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT0
2onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl0
2?moOgl00ol0003oIVIVofIVIP09ofIVIP03o`000?m<C4coC4a<01GoC4a<00?o0000ofIVI_mVIVH0
0omVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<0
1Onc/k<01Ol0003oc<c<olc<c?o<c<co000000Oo/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmo
O`05o`000?mVIVKoIVIVofIVI_l000001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4co
C4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`00
0?o<c<coc<c<00Ooc<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIVIP04
o`000?m<C4coC4a<o`0000So<c<c00Wo0000oda<C?m<C4coC4a<o`000?mVIVKo0000ogmoOol00000
0_nIVIT01?l0003o/k>cok>c/ol00008olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0
0002ofIVIP03o`000?m<C4co000000So<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`00
0?nIVIWo0000ok>c/ol00008olc<c0Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooo
oooo00?ooooo1_m<C4`00ol0003oIVIVofIVIP0:ofIVIP;o00002_moOgl2o`0000coVIVI0_l0000G
ok>c/`;o00003?nIVIT2o`0000[oOgmo00?o0000ofIVI_mVIVH02OmVIVH00ol0003oC4a<oda<C00E
oda<C003o`000?mVIVKoIVIV00?oIVIV00?o0000ogmoOomoOgl00_moOgl2o`0000CoVIVI00?o0000
ok>c/onc/k<01Onc/k<01Ol0003oc<c<olc<c?o<c<co000000Oo/k>c00Go0000oiVIVOnIVIWoVIVI
o`000003ogmoO`05o`000?mVIVKoIVIVofIVI_l000001?m<C4`00ol0003o<c<coc<c<`04oc<c<`;o
00001?m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000
olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmoOol000000_mV
IVH01?l0003oC4a<oda<C?l00008oc<c<`09o`000?m<C4coC4a<oda<C?l0003oIVIVo`000?moOgoo
000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?mo
Ogoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00co0000oda<C?m<C4co0000ofIV
I_l0003oOgmoo`000?nIVIWo0000ok>c/ol00008olc<c003o`000?oooooooooo00?ooooo0Ol00001
ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo1Om<C4`00ol0003oIVIVofIVIP0:ofIV
IP03o`000?moOgooOgmo00[oOgmo00?o0000oiVIVOnIVIT02_nIVIT00ol0003o/k>cok>c/`0Fok>c
/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0:ofIV
IP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH01?mVIVH00ol0003oOgmoogmoO`02ogmo
O`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<01Onc/k<01Ol0003oc<c<olc<c?o<c<co
000000Ko/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000?oIVIV00?o
0000oda<C?m<C4`00_m<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Co
0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Ko
c<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<
C?m<C4co00002?lc<c<02Ol0003oC4a<oda<C?m<C4co0000ofIVI_l0003oOgmoo`000002oiVIV@04
o`000?nc/k?o/k>co`0000Soc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo
00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`03o`000?m<C4coC4a<00;o00000_moOgl01Ol0003o
VIVIo`000?nc/k?o000000Soc<c<00?o0000ooooooooool00oooool1o`00007ooooo0Oooool002Co
oooo00?o0000ooooooooool00oooool4oda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomo
Ogl02OmoOgl00ol0003oVIVIoiVIV@0:oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnI
VIT03?nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00[oIVIV00?o0000oda<C?m<
C4`05Om<C4`00ol0003oIVIVofIVIP03ofIVIP03o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnI
VIT00onIVIT00ol0003o/k>cok>c/`05ok>c/`05o`000?o<c<coc<c<olc<c?l000001onc/k<01Ol0
003oVIVIoiVIVOnIVIWo000000?oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc
<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00om<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`00
0?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o0000
00;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`07o`000?m<C4co
C4a<oda<C?l0003oIVIVo`000002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`0
1_o<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo0_l00002oda<C003o`000?lc<c?o<c<c
00Ko<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003o
c<c<olc<c005olc<c003o`000?oooooooooo00Cooooo0Ol00001ooooo`7ooooo000Booooo`Co0000
00So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo00?o0000ooooooooool00oooool3
oda<C003o`000?mVIVKoIVIV00[oIVIV0_l0000:ogmoO`;o00003?nIVIT2o`0001Oo/k>c0_l0000=
oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<oda<C00E
oda<C003o`000?mVIVKoIVIV00CoIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@02
oiVIV@03o`000?nc/k?o/k>c00Ko/k>c1Ol00006ok>c/`03o`000?nIVIWoVIVI00;oVIVI00Co0000
ogmoOomoOgoo00000omVIVH00ol0003oC4a<oda<C002oda<C003o`000?lc<c?o<c<c00Go<c<c00?o
0000oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo
00000_nc/k<00ol0003oc<c<olc<c007olc<c007o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000002
ogmoO`04o`000?mVIVKoIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02Ol0003oC4a<oda<
C?m<C4co0000ofIVI_l0003oOgmoo`000002oiVIV@03o`000?nc/k?o000000Woc<c<00[o0000ok>c
/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0<
o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00002?o<c<`00ol0003o
ooooooooo`04ooooo`7o00000Oooool1ooooo`005?ooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`03ooooo`;oC4a<00?o0000ofIVI_mV
IVH02_mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc
/k<05_nc/k<00ol0003oVIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mV
IVH02omVIVH00ol0003oC4a<oda<C00Eoda<C003o`000?mVIVKoIVIV00CoIVIV00Go0000ogmoOomo
OgooOgmoo`000005oiVIV@03o`000?nc/k?o/k>c00Ko/k>c00?o0000ok>c/onc/k<02?nc/k<00ol0
003oVIVIoiVIV@02oiVIV@04o`000?moOgooOgmoo`0000?oIVIV00?o0000oda<C?m<C4`00_m<C4`0
0ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Go0000ofIVI_mVIVKoIVIVo`00
0002ogmoO`04o`000?nIVIWoVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01oo<c<`01ol0003o/k>c
ok>c/onc/k?o0000oiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00002oda<C003o`000?lc<c?o
<c<c00Ko<c<c00Wo0000oda<C?m<C4coC4a<o`000?mVIVKo0000ogmoOol000000_nIVIT00ol0003o
/k>co`000009olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<
00?o0000oc<c<olc<c<01_lc<c<00ol0003oC4a<o`000002ofIVIP07o`000?moOgoo0000oiVIVOl0
003o/k>co`000008olc<c003o`000?oooooooooo00Cooooo0Ol00001ooooo`7ooooo000Dooooo`03
o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo
00?ooooo00?oC4a<o`000?mVIVH03?mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI
00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo
00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Eoda<C003o`000?mVIVKoIVIV
00CoIVIV00Go0000ogmoOomoOgooOgmoo`000005oiVIV@03o`000?nc/k?o/k>c00Ko/k>c00?o0000
olc<c?l000002?nc/k<00ol0003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol000000_mV
IVH00ol0003oC4a<oda<C003oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00om<
C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<
c<`01_o<c<`01ol0003o/k>cok>c/onc/k?o0000oiVIVOl000000_moOgl01?l0003oIVIVofIVI_l0
0002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP;o0000
0_nIVIT01?l0003o/k>cok>c/ol00008olc<c004o`000?nc/k?o/k>co`0000;oVIVI0_l000001OmV
IVKo0000oda<C?m<C4co000000So<c<c00So0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000;o
VIVI0_l00008olc<c003o`000?nc/k?ooooo00Gooooo0Ol00001ooooo`7ooooo000Dooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`?o00000oooool00ol0003o
IVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o
/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003o
IVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01GoC4a<00?o0000ofIVI_mVIVH01?mVIVH00ol0003o
OgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01onc/k<01?l0003o
c<c<olc<c?l00007ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01Ol0003oIVIVofIVI_mV
IVKo000000CoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mV
IVKoIVIVo`0000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Go
c<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Co0000
oda<C?m<C4co00002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI
00Co0000ok>c/onc/k?o00002?o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIV
I_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmo
o`000?nIVIWo0000ok>c/ol00008olc<c003o`000?nc/k?ooooo00?ooooo0ol00002ooooo`005?oo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooo
ooooo`3oooooocoooooo0Ol00001ooooo`7ooooo000Dooooo`03o`000?oooooooooo00;ooooo00Go
410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo0?oooooo?oooool1o`00007ooooo
0Oooool001Cooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo
00?o0000ooooooooool0ooooooloooooo`7o00000Oooool1ooooo`004_ooool00omEEEGoIVIVo`00
0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool00oooool1o`00007ooooo0Oooool002Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`7o00000Oooool1ooooo`009?oooooo
o`0004?o00000_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-7.04757, -6.93977, 0.0606246, \
0.0606246}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.339744 0.0641026 0.339744 0.0641026 [
[.08333 -0.0125 -6 -9 ]
[.08333 -0.0125 6 0 ]
[.21154 -0.0125 -6 -9 ]
[.21154 -0.0125 6 0 ]
[.33974 -0.0125 -3 -9 ]
[.33974 -0.0125 3 0 ]
[.46795 -0.0125 -3 -9 ]
[.46795 -0.0125 3 0 ]
[.59615 -0.0125 -3 -9 ]
[.59615 -0.0125 3 0 ]
[.72436 -0.0125 -3 -9 ]
[.72436 -0.0125 3 0 ]
[.85256 -0.0125 -3 -9 ]
[.85256 -0.0125 3 0 ]
[.98077 -0.0125 -6 -9 ]
[.98077 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5 -21 ]
[.5 -0.0125 5 -9 ]
[-0.0125 .08333 -12 -4.5 ]
[-0.0125 .08333 0 4.5 ]
[-0.0125 .21154 -12 -4.5 ]
[-0.0125 .21154 0 4.5 ]
[-0.0125 .33974 -6 -4.5 ]
[-0.0125 .33974 0 4.5 ]
[-0.0125 .46795 -6 -4.5 ]
[-0.0125 .46795 0 4.5 ]
[-0.0125 .59615 -6 -4.5 ]
[-0.0125 .59615 0 4.5 ]
[-0.0125 .72436 -6 -4.5 ]
[-0.0125 .72436 0 4.5 ]
[-0.0125 .85256 -6 -4.5 ]
[-0.0125 .85256 0 4.5 ]
[-0.0125 .98077 -12 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -24 -5 ]
[-0.01875 .5 -12 5 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08333 0 m
.08333 .00625 L
s
[(-4)] .08333 -0.0125 0 1 Mshowa
.21154 0 m
.21154 .00625 L
s
[(-2)] .21154 -0.0125 0 1 Mshowa
.33974 0 m
.33974 .00625 L
s
[(0)] .33974 -0.0125 0 1 Mshowa
.46795 0 m
.46795 .00625 L
s
[(2)] .46795 -0.0125 0 1 Mshowa
.59615 0 m
.59615 .00625 L
s
[(4)] .59615 -0.0125 0 1 Mshowa
.72436 0 m
.72436 .00625 L
s
[(6)] .72436 -0.0125 0 1 Mshowa
.85256 0 m
.85256 .00625 L
s
[(8)] .85256 -0.0125 0 1 Mshowa
.98077 0 m
.98077 .00625 L
s
[(10)] .98077 -0.0125 0 1 Mshowa
.125 Mabswid
.11538 0 m
.11538 .00375 L
s
.14744 0 m
.14744 .00375 L
s
.17949 0 m
.17949 .00375 L
s
.24359 0 m
.24359 .00375 L
s
.27564 0 m
.27564 .00375 L
s
.30769 0 m
.30769 .00375 L
s
.37179 0 m
.37179 .00375 L
s
.40385 0 m
.40385 .00375 L
s
.4359 0 m
.4359 .00375 L
s
.5 0 m
.5 .00375 L
s
.53205 0 m
.53205 .00375 L
s
.5641 0 m
.5641 .00375 L
s
.62821 0 m
.62821 .00375 L
s
.66026 0 m
.66026 .00375 L
s
.69231 0 m
.69231 .00375 L
s
.75641 0 m
.75641 .00375 L
s
.78846 0 m
.78846 .00375 L
s
.82051 0 m
.82051 .00375 L
s
.88462 0 m
.88462 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.94872 0 m
.94872 .00375 L
s
.05128 0 m
.05128 .00375 L
s
.01923 0 m
.01923 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66 -25 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .08333 m
.00625 .08333 L
s
[(-4)] -0.0125 .08333 1 0 Mshowa
0 .21154 m
.00625 .21154 L
s
[(-2)] -0.0125 .21154 1 0 Mshowa
0 .33974 m
.00625 .33974 L
s
[(0)] -0.0125 .33974 1 0 Mshowa
0 .46795 m
.00625 .46795 L
s
[(2)] -0.0125 .46795 1 0 Mshowa
0 .59615 m
.00625 .59615 L
s
[(4)] -0.0125 .59615 1 0 Mshowa
0 .72436 m
.00625 .72436 L
s
[(6)] -0.0125 .72436 1 0 Mshowa
0 .85256 m
.00625 .85256 L
s
[(8)] -0.0125 .85256 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(10)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .11538 m
.00375 .11538 L
s
0 .14744 m
.00375 .14744 L
s
0 .17949 m
.00375 .17949 L
s
0 .24359 m
.00375 .24359 L
s
0 .27564 m
.00375 .27564 L
s
0 .30769 m
.00375 .30769 L
s
0 .37179 m
.00375 .37179 L
s
0 .40385 m
.00375 .40385 L
s
0 .4359 m
.00375 .4359 L
s
0 .5 m
.00375 .5 L
s
0 .53205 m
.00375 .53205 L
s
0 .5641 m
.00375 .5641 L
s
0 .62821 m
.00375 .62821 L
s
0 .66026 m
.00375 .66026 L
s
0 .69231 m
.00375 .69231 L
s
0 .75641 m
.00375 .75641 L
s
0 .78846 m
.00375 .78846 L
s
0 .82051 m
.00375 .82051 L
s
0 .88462 m
.00375 .88462 L
s
0 .91667 m
.00375 .91667 L
s
0 .94872 m
.00375 .94872 L
s
0 .05128 m
.00375 .05128 L
s
0 .01923 m
.00375 .01923 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
-0.01875 .5 -84 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
66 10 translate
90 rotate
-66 -10 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.08333 .99375 m
.08333 1 L
s
.21154 .99375 m
.21154 1 L
s
.33974 .99375 m
.33974 1 L
s
.46795 .99375 m
.46795 1 L
s
.59615 .99375 m
.59615 1 L
s
.72436 .99375 m
.72436 1 L
s
.85256 .99375 m
.85256 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.11538 .99625 m
.11538 1 L
s
.14744 .99625 m
.14744 1 L
s
.17949 .99625 m
.17949 1 L
s
.24359 .99625 m
.24359 1 L
s
.27564 .99625 m
.27564 1 L
s
.30769 .99625 m
.30769 1 L
s
.37179 .99625 m
.37179 1 L
s
.40385 .99625 m
.40385 1 L
s
.4359 .99625 m
.4359 1 L
s
.5 .99625 m
.5 1 L
s
.53205 .99625 m
.53205 1 L
s
.5641 .99625 m
.5641 1 L
s
.62821 .99625 m
.62821 1 L
s
.66026 .99625 m
.66026 1 L
s
.69231 .99625 m
.69231 1 L
s
.75641 .99625 m
.75641 1 L
s
.78846 .99625 m
.78846 1 L
s
.82051 .99625 m
.82051 1 L
s
.88462 .99625 m
.88462 1 L
s
.91667 .99625 m
.91667 1 L
s
.94872 .99625 m
.94872 1 L
s
.05128 .99625 m
.05128 1 L
s
.01923 .99625 m
.01923 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .08333 m
1 .08333 L
s
.99375 .21154 m
1 .21154 L
s
.99375 .33974 m
1 .33974 L
s
.99375 .46795 m
1 .46795 L
s
.99375 .59615 m
1 .59615 L
s
.99375 .72436 m
1 .72436 L
s
.99375 .85256 m
1 .85256 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .11538 m
1 .11538 L
s
.99625 .14744 m
1 .14744 L
s
.99625 .17949 m
1 .17949 L
s
.99625 .24359 m
1 .24359 L
s
.99625 .27564 m
1 .27564 L
s
.99625 .30769 m
1 .30769 L
s
.99625 .37179 m
1 .37179 L
s
.99625 .40385 m
1 .40385 L
s
.99625 .4359 m
1 .4359 L
s
.99625 .5 m
1 .5 L
s
.99625 .53205 m
1 .53205 L
s
.99625 .5641 m
1 .5641 L
s
.99625 .62821 m
1 .62821 L
s
.99625 .66026 m
1 .66026 L
s
.99625 .69231 m
1 .69231 L
s
.99625 .75641 m
1 .75641 L
s
.99625 .78846 m
1 .78846 L
s
.99625 .82051 m
1 .82051 L
s
.99625 .88462 m
1 .88462 L
s
.99625 .91667 m
1 .91667 L
s
.99625 .94872 m
1 .94872 L
s
.99625 .05128 m
1 .05128 L
s
.99625 .01923 m
1 .01923 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.3 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.4 g
.01923 .94317 m
.02079 .94192 L
.02894 .93346 L
.0302 .93221 L
.03866 .92375 L
.03991 .92249 L
.04837 .91404 L
.04962 .91278 L
.05808 .90432 L
.05934 .90307 L
.06779 .89461 L
.06905 .89336 L
.07751 .8849 L
.07876 .88364 L
.08722 .87519 L
.08847 .87393 L
.09693 .86547 L
.09819 .86422 L
.10664 .85576 L
.1079 .85451 L
.11636 .84605 L
.11761 .84479 L
.12607 .83634 L
.12732 .83508 L
.13578 .82662 L
.13704 .82537 L
.14549 .81691 L
.14675 .81566 L
.15521 .8072 L
.15646 .80594 L
.16492 .79749 L
.16617 .79623 L
.17463 .78777 L
.17589 .78652 L
.18434 .77806 L
.1856 .77681 L
.19406 .76835 L
.19531 .76709 L
.20377 .75864 L
.20502 .75738 L
.21348 .74892 L
.21474 .74767 L
.22319 .73921 L
.22445 .73796 L
.23291 .7295 L
.23416 .72824 L
.24262 .71979 L
.24387 .71853 L
.25233 .71007 L
.25359 .70882 L
.26204 .70036 L
.2633 .69911 L
.27176 .69065 L
.27301 .68939 L
.28147 .68094 L
.28272 .67968 L
.29118 .67122 L
.29244 .66997 L
.30089 .66151 L
.30215 .66026 L
.31061 .6518 L
.31186 .65054 L
.32032 .64209 L
.32157 .64083 L
.33003 .63237 L
.33143 .63112 L
.33974 .62266 L
.34076 .62141 L
.34792 .61169 L
.34946 .60954 L
.35503 .60198 L
.35917 .59632 L
.36212 .59227 L
.36888 .58291 L
.36913 .58256 L
.37601 .57284 L
.37859 .56916 L
.38276 .56313 L
.38831 .55507 L
.38942 .55342 L
.39596 .54371 L
.39802 .54061 L
.40236 .53399 L
.40773 .52577 L
.40868 .52428 L
.41488 .51457 L
.41744 .51052 L
.42096 .50486 L
.42701 .49514 L
.42716 .4949 L
.43289 .48543 L
.43687 .47886 L
.43871 .47572 L
.44448 .46601 L
.44658 .46243 L
.45011 .45629 L
.45575 .44658 L
.45629 .44563 L
.46122 .43687 L
.46601 .42843 L
.4667 .42716 L
.47206 .41744 L
.47572 .41085 L
.47738 .40773 L
.48265 .39802 L
.48543 .39289 L
.48783 .38831 L
.49301 .37859 L
.49514 .37457 L
.49806 .36888 L
.50314 .35917 L
.50486 .35588 L
.50809 .34946 L
.51308 .33974 L
.51457 .33684 L
.51793 .33003 L
.52283 .32032 L
.52428 .31743 L
.52759 .31061 L
.53241 .30089 L
.53399 .29768 L
.53708 .29118 L
.54182 .28147 L
.54371 .27759 L
.54642 .27176 L
.55107 .26204 L
.55342 .25715 L
.55561 .25233 L
.56019 .24262 L
.56313 .23638 L
.56468 .23291 L
.56916 .22319 L
.57284 .21528 L
.57362 .21348 L
.578 .20377 L
.58247 .19406 L
.58256 .19386 L
.58673 .18434 L
.59113 .17463 L
.59227 .1721 L
.59535 .16492 L
.59968 .15521 L
.60198 .15004 L
.60388 .14549 L
.60812 .13578 L
.61169 .12766 L
.61233 .12607 L
.61645 .11636 L
.62068 .10664 L
.62141 .10497 L
.6247 .09693 L
.62887 .08722 L
.63112 .08197 L
.63289 .07751 L
.63696 .06779 L
.64083 .05868 L
.64106 .05808 L
.64498 .04837 L
.64905 .03866 L
.65054 .03508 L
.65293 .02894 L
.65693 .01923 L
.01923 .01923 L
F
0 g
.01923 .94317 m
.02079 .94192 L
.02894 .93346 L
.0302 .93221 L
.03866 .92375 L
.03991 .92249 L
.04837 .91404 L
.04962 .91278 L
.05808 .90432 L
.05934 .90307 L
.06779 .89461 L
.06905 .89336 L
.07751 .8849 L
.07876 .88364 L
.08722 .87519 L
.08847 .87393 L
.09693 .86547 L
.09819 .86422 L
.10664 .85576 L
.1079 .85451 L
.11636 .84605 L
.11761 .84479 L
.12607 .83634 L
.12732 .83508 L
.13578 .82662 L
.13704 .82537 L
.14549 .81691 L
.14675 .81566 L
.15521 .8072 L
.15646 .80594 L
.16492 .79749 L
.16617 .79623 L
.17463 .78777 L
.17589 .78652 L
.18434 .77806 L
.1856 .77681 L
.19406 .76835 L
.19531 .76709 L
.20377 .75864 L
.20502 .75738 L
.21348 .74892 L
.21474 .74767 L
.22319 .73921 L
.22445 .73796 L
.23291 .7295 L
.23416 .72824 L
.24262 .71979 L
.24387 .71853 L
.25233 .71007 L
.25359 .70882 L
Mistroke
.26204 .70036 L
.2633 .69911 L
.27176 .69065 L
.27301 .68939 L
.28147 .68094 L
.28272 .67968 L
.29118 .67122 L
.29244 .66997 L
.30089 .66151 L
.30215 .66026 L
.31061 .6518 L
.31186 .65054 L
.32032 .64209 L
.32157 .64083 L
.33003 .63237 L
.33143 .63112 L
.33974 .62266 L
.34076 .62141 L
.34792 .61169 L
.34946 .60954 L
.35503 .60198 L
.35917 .59632 L
.36212 .59227 L
.36888 .58291 L
.36913 .58256 L
.37601 .57284 L
.37859 .56916 L
.38276 .56313 L
.38831 .55507 L
.38942 .55342 L
.39596 .54371 L
.39802 .54061 L
.40236 .53399 L
.40773 .52577 L
.40868 .52428 L
.41488 .51457 L
.41744 .51052 L
.42096 .50486 L
.42701 .49514 L
.42716 .4949 L
.43289 .48543 L
.43687 .47886 L
.43871 .47572 L
.44448 .46601 L
.44658 .46243 L
.45011 .45629 L
.45575 .44658 L
.45629 .44563 L
.46122 .43687 L
.46601 .42843 L
Mistroke
.4667 .42716 L
.47206 .41744 L
.47572 .41085 L
.47738 .40773 L
.48265 .39802 L
.48543 .39289 L
.48783 .38831 L
.49301 .37859 L
.49514 .37457 L
.49806 .36888 L
.50314 .35917 L
.50486 .35588 L
.50809 .34946 L
.51308 .33974 L
.51457 .33684 L
.51793 .33003 L
.52283 .32032 L
.52428 .31743 L
.52759 .31061 L
.53241 .30089 L
.53399 .29768 L
.53708 .29118 L
.54182 .28147 L
.54371 .27759 L
.54642 .27176 L
.55107 .26204 L
.55342 .25715 L
.55561 .25233 L
.56019 .24262 L
.56313 .23638 L
.56468 .23291 L
.56916 .22319 L
.57284 .21528 L
.57362 .21348 L
.578 .20377 L
.58247 .19406 L
.58256 .19386 L
.58673 .18434 L
.59113 .17463 L
.59227 .1721 L
.59535 .16492 L
.59968 .15521 L
.60198 .15004 L
.60388 .14549 L
.60812 .13578 L
.61169 .12766 L
.61233 .12607 L
.61645 .11636 L
.62068 .10664 L
.62141 .10497 L
Mistroke
.6247 .09693 L
.62887 .08722 L
.63112 .08197 L
.63289 .07751 L
.63696 .06779 L
.64083 .05868 L
.64106 .05808 L
.64498 .04837 L
.64905 .03866 L
.65054 .03508 L
.65293 .02894 L
.65693 .01923 L
Mfstroke
.5 g
.01923 .89948 m
.02537 .89336 L
.02894 .88977 L
.03507 .88364 L
.03866 .88006 L
.04478 .87393 L
.04837 .87035 L
.0545 .86422 L
.05808 .86063 L
.06421 .85451 L
.06779 .85092 L
.07392 .84479 L
.07751 .84121 L
.08363 .83508 L
.08722 .8315 L
.09335 .82537 L
.09693 .82178 L
.10306 .81566 L
.10664 .81207 L
.11277 .80594 L
.11636 .80236 L
.12248 .79623 L
.12607 .79265 L
.1322 .78652 L
.13578 .78293 L
.14191 .77681 L
.14549 .77322 L
.15162 .76709 L
.15521 .76351 L
.16133 .75738 L
.16492 .7538 L
.17105 .74767 L
.17463 .74408 L
.18076 .73796 L
.18434 .73437 L
.19047 .72824 L
.19406 .72466 L
.20018 .71853 L
.20377 .71495 L
.2099 .70882 L
.21348 .70523 L
.21961 .69911 L
.22319 .69552 L
.22932 .68939 L
.23291 .68581 L
.23903 .67968 L
.24262 .6761 L
.24875 .66997 L
.25233 .66638 L
.25846 .66026 L
.26204 .65667 L
.26817 .65054 L
.27176 .64696 L
.27788 .64083 L
.28147 .63725 L
.2876 .63112 L
.29118 .62753 L
.29731 .62141 L
.30089 .61782 L
.30702 .61169 L
.31061 .60811 L
.31673 .60198 L
.32032 .5984 L
.32645 .59227 L
.33003 .58868 L
.33624 .58256 L
.33974 .57897 L
.34536 .57284 L
.34946 .56827 L
.35395 .56313 L
.35917 .55698 L
.36214 .55342 L
.36888 .54512 L
.37001 .54371 L
.37761 .53399 L
.37859 .5327 L
.38496 .52428 L
.38831 .51975 L
.39209 .51457 L
.39802 .50628 L
.39903 .50486 L
.40579 .49514 L
.40773 .49231 L
.41239 .48543 L
.41744 .47785 L
.41885 .47572 L
.42518 .46601 L
.42716 .46292 L
.43137 .45629 L
.43687 .44753 L
.43746 .44658 L
.44344 .43687 L
.44658 .43169 L
.44931 .42716 L
.4551 .41744 L
.45629 .41542 L
.46079 .40773 L
.46601 .39871 L
.4664 .39802 L
.47194 .38831 L
.47572 .3816 L
.4774 .37859 L
.48279 .36888 L
.48543 .36407 L
.4881 .35917 L
.49337 .34946 L
.49514 .34615 L
.49856 .33974 L
.5037 .33003 L
.50486 .32784 L
.50878 .32032 L
.51382 .31061 L
.51457 .30915 L
.51879 .30089 L
.52373 .29118 L
.52428 .29008 L
.5286 .28147 L
.53344 .27176 L
.53399 .27064 L
.53823 .26204 L
.54298 .25233 L
.54371 .25085 L
.54768 .24262 L
.55236 .23291 L
.55342 .2307 L
.55698 .22319 L
.56159 .21348 L
.56313 .2102 L
.56613 .20377 L
.57066 .19406 L
.57284 .18935 L
.57514 .18434 L
.57961 .17463 L
.58256 .16817 L
.58403 .16492 L
.58842 .15521 L
.59227 .14666 L
.59279 .14549 L
.59711 .13578 L
.60143 .12607 L
.60198 .12482 L
.60569 .11636 L
.60996 .10664 L
.61169 .10266 L
.61417 .09693 L
.61837 .08722 L
.62141 .08018 L
.62254 .07751 L
.62669 .06779 L
.63082 .05808 L
.63112 .05738 L
.63491 .04837 L
.639 .03866 L
.64083 .03428 L
.64304 .02894 L
.64708 .01923 L
.01923 .01923 L
F
0 g
.01923 .89948 m
.02537 .89336 L
.02894 .88977 L
.03507 .88364 L
.03866 .88006 L
.04478 .87393 L
.04837 .87035 L
.0545 .86422 L
.05808 .86063 L
.06421 .85451 L
.06779 .85092 L
.07392 .84479 L
.07751 .84121 L
.08363 .83508 L
.08722 .8315 L
.09335 .82537 L
.09693 .82178 L
.10306 .81566 L
.10664 .81207 L
.11277 .80594 L
.11636 .80236 L
.12248 .79623 L
.12607 .79265 L
.1322 .78652 L
.13578 .78293 L
.14191 .77681 L
.14549 .77322 L
.15162 .76709 L
.15521 .76351 L
.16133 .75738 L
.16492 .7538 L
.17105 .74767 L
.17463 .74408 L
.18076 .73796 L
.18434 .73437 L
.19047 .72824 L
.19406 .72466 L
.20018 .71853 L
.20377 .71495 L
.2099 .70882 L
.21348 .70523 L
.21961 .69911 L
.22319 .69552 L
.22932 .68939 L
.23291 .68581 L
.23903 .67968 L
.24262 .6761 L
.24875 .66997 L
.25233 .66638 L
.25846 .66026 L
Mistroke
.26204 .65667 L
.26817 .65054 L
.27176 .64696 L
.27788 .64083 L
.28147 .63725 L
.2876 .63112 L
.29118 .62753 L
.29731 .62141 L
.30089 .61782 L
.30702 .61169 L
.31061 .60811 L
.31673 .60198 L
.32032 .5984 L
.32645 .59227 L
.33003 .58868 L
.33624 .58256 L
.33974 .57897 L
.34536 .57284 L
.34946 .56827 L
.35395 .56313 L
.35917 .55698 L
.36214 .55342 L
.36888 .54512 L
.37001 .54371 L
.37761 .53399 L
.37859 .5327 L
.38496 .52428 L
.38831 .51975 L
.39209 .51457 L
.39802 .50628 L
.39903 .50486 L
.40579 .49514 L
.40773 .49231 L
.41239 .48543 L
.41744 .47785 L
.41885 .47572 L
.42518 .46601 L
.42716 .46292 L
.43137 .45629 L
.43687 .44753 L
.43746 .44658 L
.44344 .43687 L
.44658 .43169 L
.44931 .42716 L
.4551 .41744 L
.45629 .41542 L
.46079 .40773 L
.46601 .39871 L
.4664 .39802 L
.47194 .38831 L
Mistroke
.47572 .3816 L
.4774 .37859 L
.48279 .36888 L
.48543 .36407 L
.4881 .35917 L
.49337 .34946 L
.49514 .34615 L
.49856 .33974 L
.5037 .33003 L
.50486 .32784 L
.50878 .32032 L
.51382 .31061 L
.51457 .30915 L
.51879 .30089 L
.52373 .29118 L
.52428 .29008 L
.5286 .28147 L
.53344 .27176 L
.53399 .27064 L
.53823 .26204 L
.54298 .25233 L
.54371 .25085 L
.54768 .24262 L
.55236 .23291 L
.55342 .2307 L
.55698 .22319 L
.56159 .21348 L
.56313 .2102 L
.56613 .20377 L
.57066 .19406 L
.57284 .18935 L
.57514 .18434 L
.57961 .17463 L
.58256 .16817 L
.58403 .16492 L
.58842 .15521 L
.59227 .14666 L
.59279 .14549 L
.59711 .13578 L
.60143 .12607 L
.60198 .12482 L
.60569 .11636 L
.60996 .10664 L
.61169 .10266 L
.61417 .09693 L
.61837 .08722 L
.62141 .08018 L
.62254 .07751 L
.62669 .06779 L
.63082 .05808 L
Mistroke
.63112 .05738 L
.63491 .04837 L
.639 .03866 L
.64083 .03428 L
.64304 .02894 L
.64708 .01923 L
Mfstroke
.6 g
.01923 .86407 m
.0288 .85451 L
.02894 .85436 L
.03851 .84479 L
.03866 .84465 L
.04822 .83508 L
.04837 .83493 L
.05793 .82537 L
.05808 .82522 L
.06765 .81566 L
.06779 .81551 L
.07736 .80594 L
.07751 .8058 L
.08707 .79623 L
.08722 .79608 L
.09678 .78652 L
.09693 .78637 L
.1065 .77681 L
.10664 .77666 L
.11621 .76709 L
.11636 .76695 L
.12592 .75738 L
.12607 .75723 L
.13563 .74767 L
.13578 .74752 L
.14535 .73796 L
.14549 .73781 L
.15506 .72824 L
.15521 .7281 L
.16477 .71853 L
.16492 .71838 L
.17448 .70882 L
.17463 .70867 L
.1842 .69911 L
.18434 .69896 L
.19391 .68939 L
.19406 .68925 L
.20362 .67968 L
.20377 .67953 L
.21333 .66997 L
.21348 .66982 L
.22305 .66026 L
.22319 .66011 L
.23276 .65054 L
.23291 .6504 L
.24247 .64083 L
.24262 .64068 L
.25218 .63112 L
.25233 .63097 L
.2619 .62141 L
.26204 .62126 L
.27161 .61169 L
.27176 .61155 L
.28132 .60198 L
.28147 .60183 L
.29103 .59227 L
.29118 .59212 L
.30075 .58256 L
.30089 .58241 L
.31046 .57284 L
.31061 .5727 L
.32017 .56313 L
.32032 .56298 L
.32988 .55342 L
.33003 .55327 L
.3396 .54371 L
.33974 .54356 L
.34946 .53412 L
.34958 .53399 L
.35881 .52428 L
.35917 .52389 L
.36749 .51457 L
.36888 .51295 L
.37572 .50486 L
.37859 .50134 L
.38359 .49514 L
.38831 .4891 L
.39114 .48543 L
.39802 .47627 L
.39842 .47572 L
.40551 .46601 L
.40773 .46287 L
.41238 .45629 L
.41744 .44894 L
.41906 .44658 L
.42559 .43687 L
.42716 .43449 L
.43198 .42716 L
.43687 .41955 L
.43821 .41744 L
.44435 .40773 L
.44658 .40412 L
.45036 .39802 L
.45625 .38831 L
.45629 .38823 L
.46207 .37859 L
.46601 .37189 L
.46777 .36888 L
.4734 .35917 L
.47572 .3551 L
.47895 .34946 L
.48441 .33974 L
.48543 .3379 L
.48981 .33003 L
.49512 .32032 L
.49514 .32027 L
.5004 .31061 L
.50486 .30224 L
.50558 .30089 L
.51073 .29118 L
.51457 .28382 L
.5158 .28147 L
.52084 .27176 L
.52428 .26501 L
.5258 .26204 L
.53074 .25233 L
.53399 .24581 L
.5356 .24262 L
.54044 .23291 L
.54371 .22625 L
.54521 .22319 L
.54997 .21348 L
.55342 .20632 L
.55465 .20377 L
.55933 .19406 L
.56313 .18603 L
.56393 .18434 L
.56854 .17463 L
.57284 .16539 L
.57306 .16492 L
.5776 .15521 L
.58206 .14549 L
.58256 .1444 L
.58652 .13578 L
.59093 .12607 L
.59227 .12308 L
.59531 .11636 L
.59967 .10664 L
.60198 .10142 L
.60398 .09693 L
.6083 .08722 L
.61169 .07943 L
.61254 .07751 L
.6168 .06779 L
.62099 .05808 L
.62141 .05711 L
.62519 .04837 L
.62936 .03866 L
.63112 .03448 L
.63348 .02894 L
.63762 .01923 L
.01923 .01923 L
F
0 g
.01923 .86407 m
.0288 .85451 L
.02894 .85436 L
.03851 .84479 L
.03866 .84465 L
.04822 .83508 L
.04837 .83493 L
.05793 .82537 L
.05808 .82522 L
.06765 .81566 L
.06779 .81551 L
.07736 .80594 L
.07751 .8058 L
.08707 .79623 L
.08722 .79608 L
.09678 .78652 L
.09693 .78637 L
.1065 .77681 L
.10664 .77666 L
.11621 .76709 L
.11636 .76695 L
.12592 .75738 L
.12607 .75723 L
.13563 .74767 L
.13578 .74752 L
.14535 .73796 L
.14549 .73781 L
.15506 .72824 L
.15521 .7281 L
.16477 .71853 L
.16492 .71838 L
.17448 .70882 L
.17463 .70867 L
.1842 .69911 L
.18434 .69896 L
.19391 .68939 L
.19406 .68925 L
.20362 .67968 L
.20377 .67953 L
.21333 .66997 L
.21348 .66982 L
.22305 .66026 L
.22319 .66011 L
.23276 .65054 L
.23291 .6504 L
.24247 .64083 L
.24262 .64068 L
.25218 .63112 L
.25233 .63097 L
.2619 .62141 L
Mistroke
.26204 .62126 L
.27161 .61169 L
.27176 .61155 L
.28132 .60198 L
.28147 .60183 L
.29103 .59227 L
.29118 .59212 L
.30075 .58256 L
.30089 .58241 L
.31046 .57284 L
.31061 .5727 L
.32017 .56313 L
.32032 .56298 L
.32988 .55342 L
.33003 .55327 L
.3396 .54371 L
.33974 .54356 L
.34946 .53412 L
.34958 .53399 L
.35881 .52428 L
.35917 .52389 L
.36749 .51457 L
.36888 .51295 L
.37572 .50486 L
.37859 .50134 L
.38359 .49514 L
.38831 .4891 L
.39114 .48543 L
.39802 .47627 L
.39842 .47572 L
.40551 .46601 L
.40773 .46287 L
.41238 .45629 L
.41744 .44894 L
.41906 .44658 L
.42559 .43687 L
.42716 .43449 L
.43198 .42716 L
.43687 .41955 L
.43821 .41744 L
.44435 .40773 L
.44658 .40412 L
.45036 .39802 L
.45625 .38831 L
.45629 .38823 L
.46207 .37859 L
.46601 .37189 L
.46777 .36888 L
.4734 .35917 L
.47572 .3551 L
Mistroke
.47895 .34946 L
.48441 .33974 L
.48543 .3379 L
.48981 .33003 L
.49512 .32032 L
.49514 .32027 L
.5004 .31061 L
.50486 .30224 L
.50558 .30089 L
.51073 .29118 L
.51457 .28382 L
.5158 .28147 L
.52084 .27176 L
.52428 .26501 L
.5258 .26204 L
.53074 .25233 L
.53399 .24581 L
.5356 .24262 L
.54044 .23291 L
.54371 .22625 L
.54521 .22319 L
.54997 .21348 L
.55342 .20632 L
.55465 .20377 L
.55933 .19406 L
.56313 .18603 L
.56393 .18434 L
.56854 .17463 L
.57284 .16539 L
.57306 .16492 L
.5776 .15521 L
.58206 .14549 L
.58256 .1444 L
.58652 .13578 L
.59093 .12607 L
.59227 .12308 L
.59531 .11636 L
.59967 .10664 L
.60198 .10142 L
.60398 .09693 L
.6083 .08722 L
.61169 .07943 L
.61254 .07751 L
.6168 .06779 L
.62099 .05808 L
.62141 .05711 L
.62519 .04837 L
.62936 .03866 L
.63112 .03448 L
.63348 .02894 L
Mistroke
.63762 .01923 L
Mfstroke
.7 g
.01923 .8204 m
.02389 .81566 L
.02894 .81069 L
.03369 .80594 L
.03866 .80098 L
.0434 .79623 L
.04837 .79126 L
.05311 .78652 L
.05808 .78155 L
.06282 .77681 L
.06779 .77184 L
.07254 .76709 L
.07751 .76213 L
.08225 .75738 L
.08722 .75241 L
.09196 .74767 L
.09693 .7427 L
.10167 .73796 L
.10664 .73299 L
.11139 .72824 L
.11636 .72328 L
.1211 .71853 L
.12607 .71356 L
.13081 .70882 L
.13578 .70385 L
.14052 .69911 L
.14549 .69414 L
.15024 .68939 L
.15521 .68443 L
.15995 .67968 L
.16492 .67471 L
.16966 .66997 L
.17463 .665 L
.17937 .66026 L
.18434 .65529 L
.18909 .65054 L
.19406 .64558 L
.1988 .64083 L
.20377 .63586 L
.20851 .63112 L
.21348 .62615 L
.21822 .62141 L
.22319 .61644 L
.22794 .61169 L
.23291 .60673 L
.23765 .60198 L
.24262 .59701 L
.24736 .59227 L
.25233 .5873 L
.25707 .58256 L
.26204 .57759 L
.26679 .57284 L
.27176 .56788 L
.2765 .56313 L
.28147 .55816 L
.28621 .55342 L
.29118 .54845 L
.29592 .54371 L
.30089 .53874 L
.30564 .53399 L
.31061 .52902 L
.31535 .52428 L
.32032 .51931 L
.32506 .51457 L
.33003 .5096 L
.33467 .50486 L
.33974 .49989 L
.34597 .49514 L
.34946 .49286 L
.35837 .48543 L
.35917 .48454 L
.3684 .47572 L
.36888 .47516 L
.37765 .46601 L
.37859 .46488 L
.38628 .45629 L
.38831 .45378 L
.3944 .44658 L
.39802 .44194 L
.40211 .43687 L
.40773 .42942 L
.40947 .42716 L
.41664 .41744 L
.41744 .41626 L
.42363 .40773 L
.42716 .40253 L
.43032 .39802 L
.43681 .38831 L
.43687 .38821 L
.44331 .37859 L
.44658 .37338 L
.44952 .36888 L
.45562 .35917 L
.45629 .35802 L
.46168 .34946 L
.46601 .34217 L
.4675 .33974 L
.47336 .33003 L
.47572 .32586 L
.47902 .32032 L
.4846 .31061 L
.48543 .30907 L
.49017 .30089 L
.49514 .29185 L
.49552 .29118 L
.50099 .28147 L
.50486 .2742 L
.50621 .27176 L
.51153 .26204 L
.51457 .25613 L
.51663 .25233 L
.5218 .24262 L
.52428 .23765 L
.5268 .23291 L
.53184 .22319 L
.53399 .21878 L
.53674 .21348 L
.54168 .20377 L
.54371 .19951 L
.54648 .19406 L
.55133 .18434 L
.55342 .17987 L
.55604 .17463 L
.56081 .16492 L
.56313 .15985 L
.56541 .15521 L
.57012 .14549 L
.57284 .13947 L
.57462 .13578 L
.57927 .12607 L
.58256 .11872 L
.58368 .11636 L
.58827 .10664 L
.59227 .09763 L
.5926 .09693 L
.59713 .08722 L
.60144 .07751 L
.60198 .0762 L
.60585 .06779 L
.61019 .05808 L
.61169 .05443 L
.61444 .04837 L
.61878 .03866 L
.62141 .03232 L
.62291 .02894 L
.62724 .01923 L
.01923 .01923 L
F
0 g
.01923 .8204 m
.02389 .81566 L
.02894 .81069 L
.03369 .80594 L
.03866 .80098 L
.0434 .79623 L
.04837 .79126 L
.05311 .78652 L
.05808 .78155 L
.06282 .77681 L
.06779 .77184 L
.07254 .76709 L
.07751 .76213 L
.08225 .75738 L
.08722 .75241 L
.09196 .74767 L
.09693 .7427 L
.10167 .73796 L
.10664 .73299 L
.11139 .72824 L
.11636 .72328 L
.1211 .71853 L
.12607 .71356 L
.13081 .70882 L
.13578 .70385 L
.14052 .69911 L
.14549 .69414 L
.15024 .68939 L
.15521 .68443 L
.15995 .67968 L
.16492 .67471 L
.16966 .66997 L
.17463 .665 L
.17937 .66026 L
.18434 .65529 L
.18909 .65054 L
.19406 .64558 L
.1988 .64083 L
.20377 .63586 L
.20851 .63112 L
.21348 .62615 L
.21822 .62141 L
.22319 .61644 L
.22794 .61169 L
.23291 .60673 L
.23765 .60198 L
.24262 .59701 L
.24736 .59227 L
.25233 .5873 L
.25707 .58256 L
Mistroke
.26204 .57759 L
.26679 .57284 L
.27176 .56788 L
.2765 .56313 L
.28147 .55816 L
.28621 .55342 L
.29118 .54845 L
.29592 .54371 L
.30089 .53874 L
.30564 .53399 L
.31061 .52902 L
.31535 .52428 L
.32032 .51931 L
.32506 .51457 L
.33003 .5096 L
.33467 .50486 L
.33974 .49989 L
.34597 .49514 L
.34946 .49286 L
.35837 .48543 L
.35917 .48454 L
.3684 .47572 L
.36888 .47516 L
.37765 .46601 L
.37859 .46488 L
.38628 .45629 L
.38831 .45378 L
.3944 .44658 L
.39802 .44194 L
.40211 .43687 L
.40773 .42942 L
.40947 .42716 L
.41664 .41744 L
.41744 .41626 L
.42363 .40773 L
.42716 .40253 L
.43032 .39802 L
.43681 .38831 L
.43687 .38821 L
.44331 .37859 L
.44658 .37338 L
.44952 .36888 L
.45562 .35917 L
.45629 .35802 L
.46168 .34946 L
.46601 .34217 L
.4675 .33974 L
.47336 .33003 L
.47572 .32586 L
.47902 .32032 L
Mistroke
.4846 .31061 L
.48543 .30907 L
.49017 .30089 L
.49514 .29185 L
.49552 .29118 L
.50099 .28147 L
.50486 .2742 L
.50621 .27176 L
.51153 .26204 L
.51457 .25613 L
.51663 .25233 L
.5218 .24262 L
.52428 .23765 L
.5268 .23291 L
.53184 .22319 L
.53399 .21878 L
.53674 .21348 L
.54168 .20377 L
.54371 .19951 L
.54648 .19406 L
.55133 .18434 L
.55342 .17987 L
.55604 .17463 L
.56081 .16492 L
.56313 .15985 L
.56541 .15521 L
.57012 .14549 L
.57284 .13947 L
.57462 .13578 L
.57927 .12607 L
.58256 .11872 L
.58368 .11636 L
.58827 .10664 L
.59227 .09763 L
.5926 .09693 L
.59713 .08722 L
.60144 .07751 L
.60198 .0762 L
.60585 .06779 L
.61019 .05808 L
.61169 .05443 L
.61444 .04837 L
.61878 .03866 L
.62141 .03232 L
.62291 .02894 L
.62724 .01923 L
Mfstroke
.6 g
.01923 .74177 m
.0234 .73796 L
.02894 .73206 L
.03276 .72824 L
.03866 .72235 L
.04247 .71853 L
.04837 .71263 L
.05218 .70882 L
.05808 .70292 L
.06189 .69911 L
.06779 .69321 L
.07161 .68939 L
.07751 .6835 L
.08132 .67968 L
.08722 .67378 L
.09103 .66997 L
.09693 .66407 L
.10074 .66026 L
.10664 .65436 L
.11046 .65054 L
.11636 .64465 L
.12017 .64083 L
.12607 .63493 L
.12988 .63112 L
.13578 .62522 L
.13959 .62141 L
.14549 .61551 L
.14931 .61169 L
.15521 .6058 L
.15902 .60198 L
.16492 .59608 L
.16873 .59227 L
.17463 .58637 L
.17844 .58256 L
.18434 .57666 L
.18816 .57284 L
.19406 .56695 L
.19787 .56313 L
.20377 .55723 L
.20758 .55342 L
.21348 .54752 L
.21729 .54371 L
.22319 .53781 L
.22701 .53399 L
.23291 .5281 L
.23672 .52428 L
.24262 .51838 L
.24643 .51457 L
.25233 .50867 L
.25614 .50486 L
.26204 .49896 L
.26586 .49514 L
.27176 .48924 L
.27557 .48543 L
.28147 .47953 L
.28528 .47572 L
.29118 .46982 L
.29499 .46601 L
.30089 .46011 L
.30471 .45629 L
.31061 .45039 L
.31442 .44658 L
.32032 .44068 L
.32413 .43687 L
.33003 .43097 L
.33414 .42716 L
.33974 .42126 L
.34272 .41744 L
.34946 .40817 L
.34978 .40773 L
.35693 .39802 L
.35917 .39495 L
.36399 .38831 L
.36888 .38151 L
.37096 .37859 L
.37783 .36888 L
.37859 .36779 L
.38455 .35917 L
.38831 .35368 L
.39116 .34946 L
.39768 .33974 L
.39802 .33924 L
.40405 .33003 L
.40773 .32438 L
.41032 .32032 L
.41652 .31061 L
.41744 .30915 L
.42257 .30089 L
.42716 .2935 L
.42856 .29118 L
.43446 .28147 L
.43687 .27747 L
.44024 .27176 L
.446 .26204 L
.44658 .26106 L
.45161 .25233 L
.45629 .24424 L
.4572 .24262 L
.46269 .23291 L
.46601 .22704 L
.46811 .22319 L
.4735 .21348 L
.47572 .20946 L
.47877 .20377 L
.48405 .19406 L
.48543 .19151 L
.4892 .18434 L
.49438 .17463 L
.49514 .17319 L
.49941 .16492 L
.50449 .15521 L
.50486 .15451 L
.50941 .14549 L
.5144 .13578 L
.51457 .13546 L
.51923 .12607 L
.52413 .11636 L
.52428 .11606 L
.52886 .10664 L
.53368 .09693 L
.53399 .0963 L
.53833 .08722 L
.54308 .07751 L
.54371 .07621 L
.54765 .06779 L
.55231 .05808 L
.55342 .05577 L
.55681 .04837 L
.56141 .03866 L
.56313 .035 L
.56585 .02894 L
.57036 .01923 L
.01923 .01923 L
F
0 g
.01923 .74177 m
.0234 .73796 L
.02894 .73206 L
.03276 .72824 L
.03866 .72235 L
.04247 .71853 L
.04837 .71263 L
.05218 .70882 L
.05808 .70292 L
.06189 .69911 L
.06779 .69321 L
.07161 .68939 L
.07751 .6835 L
.08132 .67968 L
.08722 .67378 L
.09103 .66997 L
.09693 .66407 L
.10074 .66026 L
.10664 .65436 L
.11046 .65054 L
.11636 .64465 L
.12017 .64083 L
.12607 .63493 L
.12988 .63112 L
.13578 .62522 L
.13959 .62141 L
.14549 .61551 L
.14931 .61169 L
.15521 .6058 L
.15902 .60198 L
.16492 .59608 L
.16873 .59227 L
.17463 .58637 L
.17844 .58256 L
.18434 .57666 L
.18816 .57284 L
.19406 .56695 L
.19787 .56313 L
.20377 .55723 L
.20758 .55342 L
.21348 .54752 L
.21729 .54371 L
.22319 .53781 L
.22701 .53399 L
.23291 .5281 L
.23672 .52428 L
.24262 .51838 L
.24643 .51457 L
.25233 .50867 L
.25614 .50486 L
Mistroke
.26204 .49896 L
.26586 .49514 L
.27176 .48924 L
.27557 .48543 L
.28147 .47953 L
.28528 .47572 L
.29118 .46982 L
.29499 .46601 L
.30089 .46011 L
.30471 .45629 L
.31061 .45039 L
.31442 .44658 L
.32032 .44068 L
.32413 .43687 L
.33003 .43097 L
.33414 .42716 L
.33974 .42126 L
.34272 .41744 L
.34946 .40817 L
.34978 .40773 L
.35693 .39802 L
.35917 .39495 L
.36399 .38831 L
.36888 .38151 L
.37096 .37859 L
.37783 .36888 L
.37859 .36779 L
.38455 .35917 L
.38831 .35368 L
.39116 .34946 L
.39768 .33974 L
.39802 .33924 L
.40405 .33003 L
.40773 .32438 L
.41032 .32032 L
.41652 .31061 L
.41744 .30915 L
.42257 .30089 L
.42716 .2935 L
.42856 .29118 L
.43446 .28147 L
.43687 .27747 L
.44024 .27176 L
.446 .26204 L
.44658 .26106 L
.45161 .25233 L
.45629 .24424 L
.4572 .24262 L
.46269 .23291 L
.46601 .22704 L
Mistroke
.46811 .22319 L
.4735 .21348 L
.47572 .20946 L
.47877 .20377 L
.48405 .19406 L
.48543 .19151 L
.4892 .18434 L
.49438 .17463 L
.49514 .17319 L
.49941 .16492 L
.50449 .15521 L
.50486 .15451 L
.50941 .14549 L
.5144 .13578 L
.51457 .13546 L
.51923 .12607 L
.52413 .11636 L
.52428 .11606 L
.52886 .10664 L
.53368 .09693 L
.53399 .0963 L
.53833 .08722 L
.54308 .07751 L
.54371 .07621 L
.54765 .06779 L
.55231 .05808 L
.55342 .05577 L
.55681 .04837 L
.56141 .03866 L
.56313 .035 L
.56585 .02894 L
.57036 .01923 L
Mfstroke
.5 g
.01923 .6981 m
.02794 .68939 L
.02894 .68839 L
.03765 .67968 L
.03866 .67868 L
.04736 .66997 L
.04837 .66896 L
.05708 .66026 L
.05808 .65925 L
.06679 .65054 L
.06779 .64954 L
.0765 .64083 L
.07751 .63983 L
.08621 .63112 L
.08722 .63011 L
.09593 .62141 L
.09693 .6204 L
.10564 .61169 L
.10664 .61069 L
.11535 .60198 L
.11636 .60098 L
.12506 .59227 L
.12607 .59126 L
.13478 .58256 L
.13578 .58155 L
.14449 .57284 L
.14549 .57184 L
.1542 .56313 L
.15521 .56213 L
.16391 .55342 L
.16492 .55241 L
.17363 .54371 L
.17463 .5427 L
.18334 .53399 L
.18434 .53299 L
.19305 .52428 L
.19406 .52328 L
.20276 .51457 L
.20377 .51356 L
.21248 .50486 L
.21348 .50385 L
.22219 .49514 L
.22319 .49414 L
.2319 .48543 L
.23291 .48443 L
.24161 .47572 L
.24262 .47471 L
.25133 .46601 L
.25233 .465 L
.26104 .45629 L
.26204 .45529 L
.27075 .44658 L
.27176 .44558 L
.28046 .43687 L
.28147 .43586 L
.29018 .42716 L
.29118 .42615 L
.29989 .41744 L
.30089 .41644 L
.3096 .40773 L
.31061 .40673 L
.31931 .39802 L
.32032 .39701 L
.32903 .38831 L
.33003 .3873 L
.33877 .37859 L
.33974 .37759 L
.34768 .36888 L
.34946 .36689 L
.35616 .35917 L
.35917 .3556 L
.36426 .34946 L
.36888 .34373 L
.37205 .33974 L
.37859 .33132 L
.37958 .33003 L
.38687 .32032 L
.38831 .31837 L
.39395 .31061 L
.39802 .3049 L
.40084 .30089 L
.40756 .29118 L
.40773 .29093 L
.41412 .28147 L
.41744 .27647 L
.42054 .27176 L
.42683 .26204 L
.42716 .26154 L
.433 .25233 L
.43687 .24615 L
.43905 .24262 L
.44501 .23291 L
.44658 .23031 L
.45086 .22319 L
.45629 .21403 L
.45662 .21348 L
.46229 .20377 L
.46601 .19733 L
.46788 .19406 L
.4734 .18434 L
.47572 .18021 L
.47883 .17463 L
.48421 .16492 L
.48543 .16269 L
.48951 .15521 L
.49475 .14549 L
.49514 .14477 L
.49993 .13578 L
.50486 .12646 L
.50506 .12607 L
.51012 .11636 L
.51457 .10776 L
.51514 .10664 L
.5201 .09693 L
.52428 .08869 L
.52502 .08722 L
.52989 .07751 L
.53399 .06926 L
.53472 .06779 L
.53949 .05808 L
.54371 .04946 L
.54424 .04837 L
.54893 .03866 L
.55342 .02931 L
.55359 .02894 L
.55821 .01923 L
.01923 .01923 L
F
0 g
.01923 .6981 m
.02794 .68939 L
.02894 .68839 L
.03765 .67968 L
.03866 .67868 L
.04736 .66997 L
.04837 .66896 L
.05708 .66026 L
.05808 .65925 L
.06679 .65054 L
.06779 .64954 L
.0765 .64083 L
.07751 .63983 L
.08621 .63112 L
.08722 .63011 L
.09593 .62141 L
.09693 .6204 L
.10564 .61169 L
.10664 .61069 L
.11535 .60198 L
.11636 .60098 L
.12506 .59227 L
.12607 .59126 L
.13478 .58256 L
.13578 .58155 L
.14449 .57284 L
.14549 .57184 L
.1542 .56313 L
.15521 .56213 L
.16391 .55342 L
.16492 .55241 L
.17363 .54371 L
.17463 .5427 L
.18334 .53399 L
.18434 .53299 L
.19305 .52428 L
.19406 .52328 L
.20276 .51457 L
.20377 .51356 L
.21248 .50486 L
.21348 .50385 L
.22219 .49514 L
.22319 .49414 L
.2319 .48543 L
.23291 .48443 L
.24161 .47572 L
.24262 .47471 L
.25133 .46601 L
.25233 .465 L
.26104 .45629 L
Mistroke
.26204 .45529 L
.27075 .44658 L
.27176 .44558 L
.28046 .43687 L
.28147 .43586 L
.29018 .42716 L
.29118 .42615 L
.29989 .41744 L
.30089 .41644 L
.3096 .40773 L
.31061 .40673 L
.31931 .39802 L
.32032 .39701 L
.32903 .38831 L
.33003 .3873 L
.33877 .37859 L
.33974 .37759 L
.34768 .36888 L
.34946 .36689 L
.35616 .35917 L
.35917 .3556 L
.36426 .34946 L
.36888 .34373 L
.37205 .33974 L
.37859 .33132 L
.37958 .33003 L
.38687 .32032 L
.38831 .31837 L
.39395 .31061 L
.39802 .3049 L
.40084 .30089 L
.40756 .29118 L
.40773 .29093 L
.41412 .28147 L
.41744 .27647 L
.42054 .27176 L
.42683 .26204 L
.42716 .26154 L
.433 .25233 L
.43687 .24615 L
.43905 .24262 L
.44501 .23291 L
.44658 .23031 L
.45086 .22319 L
.45629 .21403 L
.45662 .21348 L
.46229 .20377 L
.46601 .19733 L
.46788 .19406 L
.4734 .18434 L
Mistroke
.47572 .18021 L
.47883 .17463 L
.48421 .16492 L
.48543 .16269 L
.48951 .15521 L
.49475 .14549 L
.49514 .14477 L
.49993 .13578 L
.50486 .12646 L
.50506 .12607 L
.51012 .11636 L
.51457 .10776 L
.51514 .10664 L
.5201 .09693 L
.52428 .08869 L
.52502 .08722 L
.52989 .07751 L
.53399 .06926 L
.53472 .06779 L
.53949 .05808 L
.54371 .04946 L
.54424 .04837 L
.54893 .03866 L
.55342 .02931 L
.55359 .02894 L
.55821 .01923 L
Mfstroke
.4 g
.01923 .66269 m
.02166 .66026 L
.02894 .65298 L
.03138 .65054 L
.03866 .64326 L
.04109 .64083 L
.04837 .63355 L
.0508 .63112 L
.05808 .62384 L
.06051 .62141 L
.06779 .61413 L
.07023 .61169 L
.07751 .60441 L
.07994 .60198 L
.08722 .5947 L
.08965 .59227 L
.09693 .58499 L
.09936 .58256 L
.10664 .57528 L
.10908 .57284 L
.11636 .56556 L
.11879 .56313 L
.12607 .55585 L
.1285 .55342 L
.13578 .54614 L
.13821 .54371 L
.14549 .53643 L
.14793 .53399 L
.15521 .52671 L
.15764 .52428 L
.16492 .517 L
.16735 .51457 L
.17463 .50729 L
.17706 .50486 L
.18434 .49758 L
.18678 .49514 L
.19406 .48786 L
.19649 .48543 L
.20377 .47815 L
.2062 .47572 L
.21348 .46844 L
.21591 .46601 L
.22319 .45873 L
.22563 .45629 L
.23291 .44901 L
.23534 .44658 L
.24262 .4393 L
.24505 .43687 L
.25233 .42959 L
.25476 .42716 L
.26204 .41988 L
.26448 .41744 L
.27176 .41016 L
.27419 .40773 L
.28147 .40045 L
.2839 .39802 L
.29118 .39074 L
.29361 .38831 L
.30089 .38103 L
.30333 .37859 L
.31061 .37131 L
.31304 .36888 L
.32032 .3616 L
.32275 .35917 L
.33003 .35189 L
.33248 .34946 L
.33974 .34218 L
.34222 .33974 L
.34946 .33273 L
.35211 .33003 L
.35917 .32251 L
.36117 .32032 L
.36888 .31156 L
.36971 .31061 L
.37783 .30089 L
.37859 .29995 L
.38562 .29118 L
.38831 .28771 L
.3931 .28147 L
.39802 .27488 L
.40033 .27176 L
.40734 .26204 L
.40773 .26149 L
.41417 .25233 L
.41744 .24756 L
.42081 .24262 L
.42716 .23311 L
.42729 .23291 L
.43365 .22319 L
.43687 .21816 L
.43986 .21348 L
.44594 .20377 L
.44658 .20273 L
.45194 .19406 L
.45629 .18684 L
.4578 .18434 L
.46359 .17463 L
.46601 .1705 L
.46928 .16492 L
.47488 .15521 L
.47572 .15372 L
.48041 .14549 L
.48543 .13651 L
.48584 .13578 L
.49123 .12607 L
.49514 .11889 L
.49653 .11636 L
.50178 .10664 L
.50486 .10086 L
.50695 .09693 L
.51208 .08722 L
.51457 .08244 L
.51714 .07751 L
.52216 .06779 L
.52428 .06362 L
.52712 .05808 L
.53203 .04837 L
.53399 .04443 L
.53689 .03866 L
.54171 .02894 L
.54371 .02486 L
.54648 .01923 L
.01923 .01923 L
F
0 g
.01923 .66269 m
.02166 .66026 L
.02894 .65298 L
.03138 .65054 L
.03866 .64326 L
.04109 .64083 L
.04837 .63355 L
.0508 .63112 L
.05808 .62384 L
.06051 .62141 L
.06779 .61413 L
.07023 .61169 L
.07751 .60441 L
.07994 .60198 L
.08722 .5947 L
.08965 .59227 L
.09693 .58499 L
.09936 .58256 L
.10664 .57528 L
.10908 .57284 L
.11636 .56556 L
.11879 .56313 L
.12607 .55585 L
.1285 .55342 L
.13578 .54614 L
.13821 .54371 L
.14549 .53643 L
.14793 .53399 L
.15521 .52671 L
.15764 .52428 L
.16492 .517 L
.16735 .51457 L
.17463 .50729 L
.17706 .50486 L
.18434 .49758 L
.18678 .49514 L
.19406 .48786 L
.19649 .48543 L
.20377 .47815 L
.2062 .47572 L
.21348 .46844 L
.21591 .46601 L
.22319 .45873 L
.22563 .45629 L
.23291 .44901 L
.23534 .44658 L
.24262 .4393 L
.24505 .43687 L
.25233 .42959 L
.25476 .42716 L
Mistroke
.26204 .41988 L
.26448 .41744 L
.27176 .41016 L
.27419 .40773 L
.28147 .40045 L
.2839 .39802 L
.29118 .39074 L
.29361 .38831 L
.30089 .38103 L
.30333 .37859 L
.31061 .37131 L
.31304 .36888 L
.32032 .3616 L
.32275 .35917 L
.33003 .35189 L
.33248 .34946 L
.33974 .34218 L
.34222 .33974 L
.34946 .33273 L
.35211 .33003 L
.35917 .32251 L
.36117 .32032 L
.36888 .31156 L
.36971 .31061 L
.37783 .30089 L
.37859 .29995 L
.38562 .29118 L
.38831 .28771 L
.3931 .28147 L
.39802 .27488 L
.40033 .27176 L
.40734 .26204 L
.40773 .26149 L
.41417 .25233 L
.41744 .24756 L
.42081 .24262 L
.42716 .23311 L
.42729 .23291 L
.43365 .22319 L
.43687 .21816 L
.43986 .21348 L
.44594 .20377 L
.44658 .20273 L
.45194 .19406 L
.45629 .18684 L
.4578 .18434 L
.46359 .17463 L
.46601 .1705 L
.46928 .16492 L
.47488 .15521 L
Mistroke
.47572 .15372 L
.48041 .14549 L
.48543 .13651 L
.48584 .13578 L
.49123 .12607 L
.49514 .11889 L
.49653 .11636 L
.50178 .10664 L
.50486 .10086 L
.50695 .09693 L
.51208 .08722 L
.51457 .08244 L
.51714 .07751 L
.52216 .06779 L
.52428 .06362 L
.52712 .05808 L
.53203 .04837 L
.53399 .04443 L
.53689 .03866 L
.54171 .02894 L
.54371 .02486 L
.54648 .01923 L
Mfstroke
.3 g
.01923 .61901 m
.02648 .61169 L
.02894 .6093 L
.03626 .60198 L
.03866 .59959 L
.04598 .59227 L
.04837 .58988 L
.05569 .58256 L
.05808 .58016 L
.0654 .57284 L
.06779 .57045 L
.07511 .56313 L
.07751 .56074 L
.08483 .55342 L
.08722 .55103 L
.09454 .54371 L
.09693 .54131 L
.10425 .53399 L
.10664 .5316 L
.11396 .52428 L
.11636 .52189 L
.12368 .51457 L
.12607 .51218 L
.13339 .50486 L
.13578 .50246 L
.1431 .49514 L
.14549 .49275 L
.15281 .48543 L
.15521 .48304 L
.16253 .47572 L
.16492 .47333 L
.17224 .46601 L
.17463 .46361 L
.18195 .45629 L
.18434 .4539 L
.19166 .44658 L
.19406 .44419 L
.20138 .43687 L
.20377 .43448 L
.21109 .42716 L
.21348 .42476 L
.2208 .41744 L
.22319 .41505 L
.23051 .40773 L
.23291 .40534 L
.24023 .39802 L
.24262 .39563 L
.24994 .38831 L
.25233 .38591 L
.25965 .37859 L
.26204 .3762 L
.26936 .36888 L
.27176 .36649 L
.27908 .35917 L
.28147 .35678 L
.28879 .34946 L
.29118 .34706 L
.2985 .33974 L
.30089 .33735 L
.30821 .33003 L
.31061 .32764 L
.31793 .32032 L
.32032 .31793 L
.32764 .31061 L
.33003 .30821 L
.33724 .30089 L
.33974 .2985 L
.34946 .29145 L
.34981 .29118 L
.35917 .28315 L
.36107 .28147 L
.36888 .27378 L
.37093 .27176 L
.37859 .26349 L
.37993 .26204 L
.38831 .25238 L
.38835 .25233 L
.39646 .24262 L
.39802 .24055 L
.40413 .23291 L
.40773 .22804 L
.41144 .22319 L
.41744 .21488 L
.41847 .21348 L
.42541 .20377 L
.42716 .20114 L
.43211 .19406 L
.43687 .18683 L
.43855 .18434 L
.44496 .17463 L
.44658 .17199 L
.45118 .16492 L
.45629 .15663 L
.4572 .15521 L
.46325 .14549 L
.46601 .14079 L
.46908 .13578 L
.47483 .12607 L
.47572 .12447 L
.48054 .11636 L
.48543 .10769 L
.48604 .10664 L
.49164 .09693 L
.49514 .09047 L
.49699 .08722 L
.5024 .07751 L
.50486 .07282 L
.50764 .06779 L
.51288 .05808 L
.51457 .05475 L
.51802 .04837 L
.52311 .03866 L
.52428 .03627 L
.52816 .02894 L
.53312 .01923 L
.01923 .01923 L
F
0 g
.01923 .61901 m
.02648 .61169 L
.02894 .6093 L
.03626 .60198 L
.03866 .59959 L
.04598 .59227 L
.04837 .58988 L
.05569 .58256 L
.05808 .58016 L
.0654 .57284 L
.06779 .57045 L
.07511 .56313 L
.07751 .56074 L
.08483 .55342 L
.08722 .55103 L
.09454 .54371 L
.09693 .54131 L
.10425 .53399 L
.10664 .5316 L
.11396 .52428 L
.11636 .52189 L
.12368 .51457 L
.12607 .51218 L
.13339 .50486 L
.13578 .50246 L
.1431 .49514 L
.14549 .49275 L
.15281 .48543 L
.15521 .48304 L
.16253 .47572 L
.16492 .47333 L
.17224 .46601 L
.17463 .46361 L
.18195 .45629 L
.18434 .4539 L
.19166 .44658 L
.19406 .44419 L
.20138 .43687 L
.20377 .43448 L
.21109 .42716 L
.21348 .42476 L
.2208 .41744 L
.22319 .41505 L
.23051 .40773 L
.23291 .40534 L
.24023 .39802 L
.24262 .39563 L
.24994 .38831 L
.25233 .38591 L
.25965 .37859 L
Mistroke
.26204 .3762 L
.26936 .36888 L
.27176 .36649 L
.27908 .35917 L
.28147 .35678 L
.28879 .34946 L
.29118 .34706 L
.2985 .33974 L
.30089 .33735 L
.30821 .33003 L
.31061 .32764 L
.31793 .32032 L
.32032 .31793 L
.32764 .31061 L
.33003 .30821 L
.33724 .30089 L
.33974 .2985 L
.34946 .29145 L
.34981 .29118 L
.35917 .28315 L
.36107 .28147 L
.36888 .27378 L
.37093 .27176 L
.37859 .26349 L
.37993 .26204 L
.38831 .25238 L
.38835 .25233 L
.39646 .24262 L
.39802 .24055 L
.40413 .23291 L
.40773 .22804 L
.41144 .22319 L
.41744 .21488 L
.41847 .21348 L
.42541 .20377 L
.42716 .20114 L
.43211 .19406 L
.43687 .18683 L
.43855 .18434 L
.44496 .17463 L
.44658 .17199 L
.45118 .16492 L
.45629 .15663 L
.4572 .15521 L
.46325 .14549 L
.46601 .14079 L
.46908 .13578 L
.47483 .12607 L
.47572 .12447 L
.48054 .11636 L
Mistroke
.48543 .10769 L
.48604 .10664 L
.49164 .09693 L
.49514 .09047 L
.49699 .08722 L
.5024 .07751 L
.50486 .07282 L
.50764 .06779 L
.51288 .05808 L
.51457 .05475 L
.51802 .04837 L
.52311 .03866 L
.52428 .03627 L
.52816 .02894 L
.53312 .01923 L
Mfstroke
.4 g
.01923 .5404 m
.02582 .53399 L
.02894 .53069 L
.03535 .52428 L
.03866 .52098 L
.04506 .51457 L
.04837 .51126 L
.05477 .50486 L
.05808 .50155 L
.06449 .49514 L
.06779 .49184 L
.0742 .48543 L
.07751 .48213 L
.08391 .47572 L
.08722 .47241 L
.09362 .46601 L
.09693 .4627 L
.10334 .45629 L
.10664 .45299 L
.11305 .44658 L
.11636 .44328 L
.12276 .43687 L
.12607 .43356 L
.13247 .42716 L
.13578 .42385 L
.14219 .41744 L
.14549 .41414 L
.1519 .40773 L
.15521 .40443 L
.16161 .39802 L
.16492 .39471 L
.17132 .38831 L
.17463 .385 L
.18104 .37859 L
.18434 .37529 L
.19075 .36888 L
.19406 .36557 L
.20046 .35917 L
.20377 .35586 L
.21017 .34946 L
.21348 .34615 L
.21989 .33974 L
.22319 .33644 L
.2296 .33003 L
.23291 .32672 L
.23931 .32032 L
.24262 .31701 L
.24902 .31061 L
.25233 .3073 L
.25874 .30089 L
.26204 .29759 L
.26845 .29118 L
.27176 .28787 L
.27816 .28147 L
.28147 .27816 L
.28787 .27176 L
.29118 .26845 L
.29759 .26204 L
.30089 .25874 L
.3073 .25233 L
.31061 .24902 L
.31701 .24262 L
.32032 .23931 L
.32672 .23291 L
.33003 .2296 L
.33671 .22319 L
.33974 .21989 L
.34462 .21348 L
.34946 .20676 L
.35167 .20377 L
.35882 .19406 L
.35917 .19358 L
.36585 .18434 L
.36888 .18012 L
.37278 .17463 L
.37859 .16639 L
.37962 .16492 L
.38632 .15521 L
.38831 .15231 L
.39289 .14549 L
.39802 .13784 L
.39937 .13578 L
.40574 .12607 L
.40773 .123 L
.41197 .11636 L
.41744 .10776 L
.41814 .10664 L
.42418 .09693 L
.42716 .09212 L
.43012 .08722 L
.43602 .07751 L
.43687 .0761 L
.44177 .06779 L
.44658 .05967 L
.44749 .05808 L
.45311 .04837 L
.45629 .04285 L
.45864 .03866 L
.46415 .02894 L
.46601 .02569 L
.46953 .01923 L
.01923 .01923 L
F
0 g
.01923 .5404 m
.02582 .53399 L
.02894 .53069 L
.03535 .52428 L
.03866 .52098 L
.04506 .51457 L
.04837 .51126 L
.05477 .50486 L
.05808 .50155 L
.06449 .49514 L
.06779 .49184 L
.0742 .48543 L
.07751 .48213 L
.08391 .47572 L
.08722 .47241 L
.09362 .46601 L
.09693 .4627 L
.10334 .45629 L
.10664 .45299 L
.11305 .44658 L
.11636 .44328 L
.12276 .43687 L
.12607 .43356 L
.13247 .42716 L
.13578 .42385 L
.14219 .41744 L
.14549 .41414 L
.1519 .40773 L
.15521 .40443 L
.16161 .39802 L
.16492 .39471 L
.17132 .38831 L
.17463 .385 L
.18104 .37859 L
.18434 .37529 L
.19075 .36888 L
.19406 .36557 L
.20046 .35917 L
.20377 .35586 L
.21017 .34946 L
.21348 .34615 L
.21989 .33974 L
.22319 .33644 L
.2296 .33003 L
.23291 .32672 L
.23931 .32032 L
.24262 .31701 L
.24902 .31061 L
.25233 .3073 L
.25874 .30089 L
Mistroke
.26204 .29759 L
.26845 .29118 L
.27176 .28787 L
.27816 .28147 L
.28147 .27816 L
.28787 .27176 L
.29118 .26845 L
.29759 .26204 L
.30089 .25874 L
.3073 .25233 L
.31061 .24902 L
.31701 .24262 L
.32032 .23931 L
.32672 .23291 L
.33003 .2296 L
.33671 .22319 L
.33974 .21989 L
.34462 .21348 L
.34946 .20676 L
.35167 .20377 L
.35882 .19406 L
.35917 .19358 L
.36585 .18434 L
.36888 .18012 L
.37278 .17463 L
.37859 .16639 L
.37962 .16492 L
.38632 .15521 L
.38831 .15231 L
.39289 .14549 L
.39802 .13784 L
.39937 .13578 L
.40574 .12607 L
.40773 .123 L
.41197 .11636 L
.41744 .10776 L
.41814 .10664 L
.42418 .09693 L
.42716 .09212 L
.43012 .08722 L
.43602 .07751 L
.43687 .0761 L
.44177 .06779 L
.44658 .05967 L
.44749 .05808 L
.45311 .04837 L
.45629 .04285 L
.45864 .03866 L
.46415 .02894 L
.46601 .02569 L
Mistroke
.46953 .01923 L
Mfstroke
.5 g
.01923 .49672 m
.02081 .49514 L
.02894 .487 L
.03052 .48543 L
.03866 .47729 L
.04023 .47572 L
.04837 .46758 L
.04994 .46601 L
.05808 .45787 L
.05965 .45629 L
.06779 .44815 L
.06937 .44658 L
.07751 .43844 L
.07908 .43687 L
.08722 .42873 L
.08879 .42716 L
.09693 .41902 L
.0985 .41744 L
.10664 .4093 L
.10822 .40773 L
.11636 .39959 L
.11793 .39802 L
.12607 .38988 L
.12764 .38831 L
.13578 .38017 L
.13735 .37859 L
.14549 .37045 L
.14707 .36888 L
.15521 .36074 L
.15678 .35917 L
.16492 .35103 L
.16649 .34946 L
.17463 .34132 L
.1762 .33974 L
.18434 .3316 L
.18592 .33003 L
.19406 .32189 L
.19563 .32032 L
.20377 .31218 L
.20534 .31061 L
.21348 .30247 L
.21505 .30089 L
.22319 .29275 L
.22477 .29118 L
.23291 .28304 L
.23448 .28147 L
.24262 .27333 L
.24419 .27176 L
.25233 .26362 L
.2539 .26204 L
.26204 .2539 L
.26362 .25233 L
.27176 .24419 L
.27333 .24262 L
.28147 .23448 L
.28304 .23291 L
.29118 .22477 L
.29275 .22319 L
.30089 .21505 L
.30247 .21348 L
.31061 .20534 L
.31218 .20377 L
.32032 .19563 L
.32189 .19406 L
.33003 .18592 L
.33164 .18434 L
.33974 .1762 L
.34121 .17463 L
.34946 .1655 L
.34997 .16492 L
.35834 .15521 L
.35917 .15421 L
.36636 .14549 L
.36888 .14235 L
.37408 .13578 L
.37859 .12994 L
.38154 .12607 L
.38831 .11699 L
.38877 .11636 L
.3958 .10664 L
.39802 .10352 L
.40264 .09693 L
.40773 .08954 L
.40932 .08722 L
.41584 .07751 L
.41744 .07509 L
.42222 .06779 L
.42716 .06015 L
.42848 .05808 L
.43462 .04837 L
.43687 .04476 L
.44064 .03866 L
.44657 .02894 L
.44658 .02892 L
.45239 .01923 L
.01923 .01923 L
F
0 g
.01923 .49672 m
.02081 .49514 L
.02894 .487 L
.03052 .48543 L
.03866 .47729 L
.04023 .47572 L
.04837 .46758 L
.04994 .46601 L
.05808 .45787 L
.05965 .45629 L
.06779 .44815 L
.06937 .44658 L
.07751 .43844 L
.07908 .43687 L
.08722 .42873 L
.08879 .42716 L
.09693 .41902 L
.0985 .41744 L
.10664 .4093 L
.10822 .40773 L
.11636 .39959 L
.11793 .39802 L
.12607 .38988 L
.12764 .38831 L
.13578 .38017 L
.13735 .37859 L
.14549 .37045 L
.14707 .36888 L
.15521 .36074 L
.15678 .35917 L
.16492 .35103 L
.16649 .34946 L
.17463 .34132 L
.1762 .33974 L
.18434 .3316 L
.18592 .33003 L
.19406 .32189 L
.19563 .32032 L
.20377 .31218 L
.20534 .31061 L
.21348 .30247 L
.21505 .30089 L
.22319 .29275 L
.22477 .29118 L
.23291 .28304 L
.23448 .28147 L
.24262 .27333 L
.24419 .27176 L
.25233 .26362 L
.2539 .26204 L
Mistroke
.26204 .2539 L
.26362 .25233 L
.27176 .24419 L
.27333 .24262 L
.28147 .23448 L
.28304 .23291 L
.29118 .22477 L
.29275 .22319 L
.30089 .21505 L
.30247 .21348 L
.31061 .20534 L
.31218 .20377 L
.32032 .19563 L
.32189 .19406 L
.33003 .18592 L
.33164 .18434 L
.33974 .1762 L
.34121 .17463 L
.34946 .1655 L
.34997 .16492 L
.35834 .15521 L
.35917 .15421 L
.36636 .14549 L
.36888 .14235 L
.37408 .13578 L
.37859 .12994 L
.38154 .12607 L
.38831 .11699 L
.38877 .11636 L
.3958 .10664 L
.39802 .10352 L
.40264 .09693 L
.40773 .08954 L
.40932 .08722 L
.41584 .07751 L
.41744 .07509 L
.42222 .06779 L
.42716 .06015 L
.42848 .05808 L
.43462 .04837 L
.43687 .04476 L
.44064 .03866 L
.44657 .02894 L
.44658 .02892 L
.45239 .01923 L
Mfstroke
.6 g
.01923 .46131 m
.02424 .45629 L
.02894 .45159 L
.03396 .44658 L
.03866 .44188 L
.04367 .43687 L
.04837 .43217 L
.05338 .42716 L
.05808 .42246 L
.06309 .41744 L
.06779 .41274 L
.07281 .40773 L
.07751 .40303 L
.08252 .39802 L
.08722 .39332 L
.09223 .38831 L
.09693 .38361 L
.10194 .37859 L
.10664 .37389 L
.11166 .36888 L
.11636 .36418 L
.12137 .35917 L
.12607 .35447 L
.13108 .34946 L
.13578 .34476 L
.14079 .33974 L
.14549 .33504 L
.15051 .33003 L
.15521 .32533 L
.16022 .32032 L
.16492 .31562 L
.16993 .31061 L
.17463 .30591 L
.17964 .30089 L
.18434 .29619 L
.18936 .29118 L
.19406 .28648 L
.19907 .28147 L
.20377 .27677 L
.20878 .27176 L
.21348 .26706 L
.21849 .26204 L
.22319 .25734 L
.22821 .25233 L
.23291 .24763 L
.23792 .24262 L
.24262 .23792 L
.24763 .23291 L
.25233 .22821 L
.25734 .22319 L
.26204 .21849 L
.26706 .21348 L
.27176 .20878 L
.27677 .20377 L
.28147 .19907 L
.28648 .19406 L
.29118 .18936 L
.29619 .18434 L
.30089 .17964 L
.30591 .17463 L
.31061 .16993 L
.31562 .16492 L
.32032 .16022 L
.32533 .15521 L
.33003 .15051 L
.33506 .14549 L
.33974 .14079 L
.34487 .13578 L
.34946 .13135 L
.35459 .12607 L
.35917 .12112 L
.3635 .11636 L
.36888 .11018 L
.37191 .10664 L
.37859 .09857 L
.37993 .09693 L
.38762 .08722 L
.38831 .08633 L
.39505 .07751 L
.39802 .0735 L
.40222 .06779 L
.40773 .0601 L
.40917 .05808 L
.41595 .04837 L
.41744 .04617 L
.42255 .03866 L
.42716 .03172 L
.42899 .02894 L
.43531 .01923 L
.01923 .01923 L
F
0 g
.01923 .46131 m
.02424 .45629 L
.02894 .45159 L
.03396 .44658 L
.03866 .44188 L
.04367 .43687 L
.04837 .43217 L
.05338 .42716 L
.05808 .42246 L
.06309 .41744 L
.06779 .41274 L
.07281 .40773 L
.07751 .40303 L
.08252 .39802 L
.08722 .39332 L
.09223 .38831 L
.09693 .38361 L
.10194 .37859 L
.10664 .37389 L
.11166 .36888 L
.11636 .36418 L
.12137 .35917 L
.12607 .35447 L
.13108 .34946 L
.13578 .34476 L
.14079 .33974 L
.14549 .33504 L
.15051 .33003 L
.15521 .32533 L
.16022 .32032 L
.16492 .31562 L
.16993 .31061 L
.17463 .30591 L
.17964 .30089 L
.18434 .29619 L
.18936 .29118 L
.19406 .28648 L
.19907 .28147 L
.20377 .27677 L
.20878 .27176 L
.21348 .26706 L
.21849 .26204 L
.22319 .25734 L
.22821 .25233 L
.23291 .24763 L
.23792 .24262 L
.24262 .23792 L
.24763 .23291 L
.25233 .22821 L
.25734 .22319 L
Mistroke
.26204 .21849 L
.26706 .21348 L
.27176 .20878 L
.27677 .20377 L
.28147 .19907 L
.28648 .19406 L
.29118 .18936 L
.29619 .18434 L
.30089 .17964 L
.30591 .17463 L
.31061 .16993 L
.31562 .16492 L
.32032 .16022 L
.32533 .15521 L
.33003 .15051 L
.33506 .14549 L
.33974 .14079 L
.34487 .13578 L
.34946 .13135 L
.35459 .12607 L
.35917 .12112 L
.3635 .11636 L
.36888 .11018 L
.37191 .10664 L
.37859 .09857 L
.37993 .09693 L
.38762 .08722 L
.38831 .08633 L
.39505 .07751 L
.39802 .0735 L
.40222 .06779 L
.40773 .0601 L
.40917 .05808 L
.41595 .04837 L
.41744 .04617 L
.42255 .03866 L
.42716 .03172 L
.42899 .02894 L
.43531 .01923 L
Mfstroke
.7 g
.01923 .41759 m
.01937 .41744 L
.02894 .40787 L
.02909 .40773 L
.03866 .39816 L
.0388 .39802 L
.04837 .38845 L
.04851 .38831 L
.05808 .37874 L
.05822 .37859 L
.06779 .36902 L
.06794 .36888 L
.07751 .35931 L
.07765 .35917 L
.08722 .3496 L
.08736 .34946 L
.09693 .33989 L
.09707 .33974 L
.10664 .33017 L
.10679 .33003 L
.11636 .32046 L
.1165 .32032 L
.12607 .31075 L
.12621 .31061 L
.13578 .30104 L
.13592 .30089 L
.14549 .29132 L
.14564 .29118 L
.15521 .28161 L
.15535 .28147 L
.16492 .2719 L
.16506 .27176 L
.17463 .26219 L
.17477 .26204 L
.18434 .25247 L
.18449 .25233 L
.19406 .24276 L
.1942 .24262 L
.20377 .23305 L
.20391 .23291 L
.21348 .22334 L
.21362 .22319 L
.22319 .21362 L
.22334 .21348 L
.23291 .20391 L
.23305 .20377 L
.24262 .1942 L
.24276 .19406 L
.25233 .18449 L
.25247 .18434 L
.26204 .17477 L
.26219 .17463 L
.27176 .16506 L
.2719 .16492 L
.28147 .15535 L
.28161 .15521 L
.29118 .14564 L
.29132 .14549 L
.30089 .13592 L
.30104 .13578 L
.31061 .12621 L
.31075 .12607 L
.32032 .1165 L
.32046 .11636 L
.33003 .10679 L
.33017 .10664 L
.33974 .09707 L
.33991 .09693 L
.34946 .09008 L
.35321 .08722 L
.35917 .08178 L
.36392 .07751 L
.36888 .07241 L
.37348 .06779 L
.37859 .06212 L
.3823 .05808 L
.38831 .05101 L
.39058 .04837 L
.39802 .03916 L
.39843 .03866 L
.40608 .02894 L
.40773 .02663 L
.41337 .01923 L
.01923 .01923 L
F
0 g
.01923 .41759 m
.01937 .41744 L
.02894 .40787 L
.02909 .40773 L
.03866 .39816 L
.0388 .39802 L
.04837 .38845 L
.04851 .38831 L
.05808 .37874 L
.05822 .37859 L
.06779 .36902 L
.06794 .36888 L
.07751 .35931 L
.07765 .35917 L
.08722 .3496 L
.08736 .34946 L
.09693 .33989 L
.09707 .33974 L
.10664 .33017 L
.10679 .33003 L
.11636 .32046 L
.1165 .32032 L
.12607 .31075 L
.12621 .31061 L
.13578 .30104 L
.13592 .30089 L
.14549 .29132 L
.14564 .29118 L
.15521 .28161 L
.15535 .28147 L
.16492 .2719 L
.16506 .27176 L
.17463 .26219 L
.17477 .26204 L
.18434 .25247 L
.18449 .25233 L
.19406 .24276 L
.1942 .24262 L
.20377 .23305 L
.20391 .23291 L
.21348 .22334 L
.21362 .22319 L
.22319 .21362 L
.22334 .21348 L
.23291 .20391 L
.23305 .20377 L
.24262 .1942 L
.24276 .19406 L
.25233 .18449 L
.25247 .18434 L
Mistroke
.26204 .17477 L
.26219 .17463 L
.27176 .16506 L
.2719 .16492 L
.28147 .15535 L
.28161 .15521 L
.29118 .14564 L
.29132 .14549 L
.30089 .13592 L
.30104 .13578 L
.31061 .12621 L
.31075 .12607 L
.32032 .1165 L
.32046 .11636 L
.33003 .10679 L
.33017 .10664 L
.33974 .09707 L
.33991 .09693 L
.34946 .09008 L
.35321 .08722 L
.35917 .08178 L
.36392 .07751 L
.36888 .07241 L
.37348 .06779 L
.37859 .06212 L
.3823 .05808 L
.38831 .05101 L
.39058 .04837 L
.39802 .03916 L
.39843 .03866 L
.40608 .02894 L
.40773 .02663 L
.41337 .01923 L
Mfstroke
.6 g
.01923 .33904 m
.02827 .33003 L
.02894 .32933 L
.03796 .32032 L
.03866 .31962 L
.04767 .31061 L
.04837 .30991 L
.05738 .30089 L
.05808 .30019 L
.06709 .29118 L
.06779 .29048 L
.07681 .28147 L
.07751 .28077 L
.08652 .27176 L
.08722 .27106 L
.09623 .26204 L
.09693 .26134 L
.10594 .25233 L
.10664 .25163 L
.11566 .24262 L
.11636 .24192 L
.12537 .23291 L
.12607 .23221 L
.13508 .22319 L
.13578 .22249 L
.14479 .21348 L
.14549 .21278 L
.15451 .20377 L
.15521 .20307 L
.16422 .19406 L
.16492 .19336 L
.17393 .18434 L
.17463 .18364 L
.18364 .17463 L
.18434 .17393 L
.19336 .16492 L
.19406 .16422 L
.20307 .15521 L
.20377 .15451 L
.21278 .14549 L
.21348 .14479 L
.22249 .13578 L
.22319 .13508 L
.23221 .12607 L
.23291 .12537 L
.24192 .11636 L
.24262 .11566 L
.25163 .10664 L
.25233 .10594 L
.26134 .09693 L
.26204 .09623 L
.27106 .08722 L
.27176 .08652 L
.28077 .07751 L
.28147 .07681 L
.29048 .06779 L
.29118 .06709 L
.30019 .05808 L
.30089 .05738 L
.30991 .04837 L
.31061 .04767 L
.31962 .03866 L
.32032 .03796 L
.32933 .02894 L
.33003 .02827 L
.33912 .01923 L
.01923 .01923 L
F
0 g
.01923 .33904 m
.02827 .33003 L
.02894 .32933 L
.03796 .32032 L
.03866 .31962 L
.04767 .31061 L
.04837 .30991 L
.05738 .30089 L
.05808 .30019 L
.06709 .29118 L
.06779 .29048 L
.07681 .28147 L
.07751 .28077 L
.08652 .27176 L
.08722 .27106 L
.09623 .26204 L
.09693 .26134 L
.10594 .25233 L
.10664 .25163 L
.11566 .24262 L
.11636 .24192 L
.12537 .23291 L
.12607 .23221 L
.13508 .22319 L
.13578 .22249 L
.14479 .21348 L
.14549 .21278 L
.15451 .20377 L
.15521 .20307 L
.16422 .19406 L
.16492 .19336 L
.17393 .18434 L
.17463 .18364 L
.18364 .17463 L
.18434 .17393 L
.19336 .16492 L
.19406 .16422 L
.20307 .15521 L
.20377 .15451 L
.21278 .14549 L
.21348 .14479 L
.22249 .13578 L
.22319 .13508 L
.23221 .12607 L
.23291 .12537 L
.24192 .11636 L
.24262 .11566 L
.25163 .10664 L
.25233 .10594 L
.26134 .09693 L
Mistroke
.26204 .09623 L
.27106 .08722 L
.27176 .08652 L
.28077 .07751 L
.28147 .07681 L
.29048 .06779 L
.29118 .06709 L
.30019 .05808 L
.30089 .05738 L
.30991 .04837 L
.31061 .04767 L
.31962 .03866 L
.32032 .03796 L
.32933 .02894 L
.33003 .02827 L
.33912 .01923 L
Mfstroke
.5 g
.01923 .29533 m
.02339 .29118 L
.02894 .28562 L
.03309 .28147 L
.03866 .27591 L
.04281 .27176 L
.04837 .26619 L
.05252 .26204 L
.05808 .25648 L
.06223 .25233 L
.06779 .24677 L
.07194 .24262 L
.07751 .23706 L
.08166 .23291 L
.08722 .22734 L
.09137 .22319 L
.09693 .21763 L
.10108 .21348 L
.10664 .20792 L
.11079 .20377 L
.11636 .19821 L
.12051 .19406 L
.12607 .18849 L
.13022 .18434 L
.13578 .17878 L
.13993 .17463 L
.14549 .16907 L
.14964 .16492 L
.15521 .15936 L
.15936 .15521 L
.16492 .14964 L
.16907 .14549 L
.17463 .13993 L
.17878 .13578 L
.18434 .13022 L
.18849 .12607 L
.19406 .12051 L
.19821 .11636 L
.20377 .11079 L
.20792 .10664 L
.21348 .10108 L
.21763 .09693 L
.22319 .09137 L
.22734 .08722 L
.23291 .08166 L
.23706 .07751 L
.24262 .07194 L
.24677 .06779 L
.25233 .06223 L
.25648 .05808 L
.26204 .05252 L
.26619 .04837 L
.27176 .04281 L
.27591 .03866 L
.28147 .03309 L
.28562 .02894 L
.29118 .02339 L
.29533 .01923 L
.01923 .01923 L
F
0 g
.01923 .29533 m
.02339 .29118 L
.02894 .28562 L
.03309 .28147 L
.03866 .27591 L
.04281 .27176 L
.04837 .26619 L
.05252 .26204 L
.05808 .25648 L
.06223 .25233 L
.06779 .24677 L
.07194 .24262 L
.07751 .23706 L
.08166 .23291 L
.08722 .22734 L
.09137 .22319 L
.09693 .21763 L
.10108 .21348 L
.10664 .20792 L
.11079 .20377 L
.11636 .19821 L
.12051 .19406 L
.12607 .18849 L
.13022 .18434 L
.13578 .17878 L
.13993 .17463 L
.14549 .16907 L
.14964 .16492 L
.15521 .15936 L
.15936 .15521 L
.16492 .14964 L
.16907 .14549 L
.17463 .13993 L
.17878 .13578 L
.18434 .13022 L
.18849 .12607 L
.19406 .12051 L
.19821 .11636 L
.20377 .11079 L
.20792 .10664 L
.21348 .10108 L
.21763 .09693 L
.22319 .09137 L
.22734 .08722 L
.23291 .08166 L
.23706 .07751 L
.24262 .07194 L
.24677 .06779 L
.25233 .06223 L
.25648 .05808 L
Mistroke
.26204 .05252 L
.26619 .04837 L
.27176 .04281 L
.27591 .03866 L
.28147 .03309 L
.28562 .02894 L
.29118 .02339 L
.29533 .01923 L
Mfstroke
.4 g
.01923 .25992 m
.02682 .25233 L
.02894 .25021 L
.03653 .24262 L
.03866 .2405 L
.04625 .23291 L
.04837 .23078 L
.05596 .22319 L
.05808 .22107 L
.06567 .21348 L
.06779 .21136 L
.07538 .20377 L
.07751 .20165 L
.0851 .19406 L
.08722 .19193 L
.09481 .18434 L
.09693 .18222 L
.10452 .17463 L
.10664 .17251 L
.11423 .16492 L
.11636 .1628 L
.12395 .15521 L
.12607 .15308 L
.13366 .14549 L
.13578 .14337 L
.14337 .13578 L
.14549 .13366 L
.15308 .12607 L
.15521 .12395 L
.1628 .11636 L
.16492 .11423 L
.17251 .10664 L
.17463 .10452 L
.18222 .09693 L
.18434 .09481 L
.19193 .08722 L
.19406 .0851 L
.20165 .07751 L
.20377 .07538 L
.21136 .06779 L
.21348 .06567 L
.22107 .05808 L
.22319 .05596 L
.23078 .04837 L
.23291 .04625 L
.2405 .03866 L
.24262 .03653 L
.25021 .02894 L
.25233 .02682 L
.25992 .01923 L
.01923 .01923 L
F
0 g
.01923 .25992 m
.02682 .25233 L
.02894 .25021 L
.03653 .24262 L
.03866 .2405 L
.04625 .23291 L
.04837 .23078 L
.05596 .22319 L
.05808 .22107 L
.06567 .21348 L
.06779 .21136 L
.07538 .20377 L
.07751 .20165 L
.0851 .19406 L
.08722 .19193 L
.09481 .18434 L
.09693 .18222 L
.10452 .17463 L
.10664 .17251 L
.11423 .16492 L
.11636 .1628 L
.12395 .15521 L
.12607 .15308 L
.13366 .14549 L
.13578 .14337 L
.14337 .13578 L
.14549 .13366 L
.15308 .12607 L
.15521 .12395 L
.1628 .11636 L
.16492 .11423 L
.17251 .10664 L
.17463 .10452 L
.18222 .09693 L
.18434 .09481 L
.19193 .08722 L
.19406 .0851 L
.20165 .07751 L
.20377 .07538 L
.21136 .06779 L
.21348 .06567 L
.22107 .05808 L
.22319 .05596 L
.23078 .04837 L
.23291 .04625 L
.2405 .03866 L
.24262 .03653 L
.25021 .02894 L
.25233 .02682 L
.25992 .01923 L
Mistroke
Mfstroke
.3 g
.01923 .21623 m
.02192 .21348 L
.02894 .20652 L
.03169 .20377 L
.03866 .19681 L
.04141 .19406 L
.04837 .18709 L
.05112 .18434 L
.05808 .17738 L
.06083 .17463 L
.06779 .16767 L
.07054 .16492 L
.07751 .15796 L
.08026 .15521 L
.08722 .14824 L
.08997 .14549 L
.09693 .13853 L
.09968 .13578 L
.10664 .12882 L
.10939 .12607 L
.11636 .11911 L
.11911 .11636 L
.12607 .10939 L
.12882 .10664 L
.13578 .09968 L
.13853 .09693 L
.14549 .08997 L
.14824 .08722 L
.15521 .08026 L
.15796 .07751 L
.16492 .07054 L
.16767 .06779 L
.17463 .06083 L
.17738 .05808 L
.18434 .05112 L
.18709 .04837 L
.19406 .04141 L
.19681 .03866 L
.20377 .03169 L
.20652 .02894 L
.21348 .02192 L
.21623 .01923 L
.01923 .01923 L
F
0 g
.01923 .21623 m
.02192 .21348 L
.02894 .20652 L
.03169 .20377 L
.03866 .19681 L
.04141 .19406 L
.04837 .18709 L
.05112 .18434 L
.05808 .17738 L
.06083 .17463 L
.06779 .16767 L
.07054 .16492 L
.07751 .15796 L
.08026 .15521 L
.08722 .14824 L
.08997 .14549 L
.09693 .13853 L
.09968 .13578 L
.10664 .12882 L
.10939 .12607 L
.11636 .11911 L
.11911 .11636 L
.12607 .10939 L
.12882 .10664 L
.13578 .09968 L
.13853 .09693 L
.14549 .08997 L
.14824 .08722 L
.15521 .08026 L
.15796 .07751 L
.16492 .07054 L
.16767 .06779 L
.17463 .06083 L
.17738 .05808 L
.18434 .05112 L
.18709 .04837 L
.19406 .04141 L
.19681 .03866 L
.20377 .03169 L
.20652 .02894 L
.21348 .02192 L
.21623 .01923 L
s
.4 g
.01923 .13763 m
.02144 .13578 L
.02894 .12792 L
.03079 .12607 L
.03866 .1182 L
.0405 .11636 L
.04837 .10849 L
.05022 .10664 L
.05808 .09878 L
.05993 .09693 L
.06779 .08907 L
.06964 .08722 L
.07751 .07935 L
.07935 .07751 L
.08722 .06964 L
.08907 .06779 L
.09693 .05993 L
.09878 .05808 L
.10664 .05022 L
.10849 .04837 L
.11636 .0405 L
.1182 .03866 L
.12607 .03079 L
.12792 .02894 L
.13578 .02144 L
.13763 .01923 L
.01923 .01923 L
F
0 g
.01923 .13763 m
.02144 .13578 L
.02894 .12792 L
.03079 .12607 L
.03866 .1182 L
.0405 .11636 L
.04837 .10849 L
.05022 .10664 L
.05808 .09878 L
.05993 .09693 L
.06779 .08907 L
.06964 .08722 L
.07751 .07935 L
.07935 .07751 L
.08722 .06964 L
.08907 .06779 L
.09693 .05993 L
.09878 .05808 L
.10664 .05022 L
.10849 .04837 L
.11636 .0405 L
.1182 .03866 L
.12607 .03079 L
.12792 .02894 L
.13578 .02144 L
.13763 .01923 L
s
.5 g
.01923 .09395 m
.02597 .08722 L
.02894 .08423 L
.03567 .07751 L
.03866 .07452 L
.04538 .06779 L
.04837 .06481 L
.0551 .05808 L
.05808 .0551 L
.06481 .04837 L
.06779 .04538 L
.07452 .03866 L
.07751 .03567 L
.08423 .02894 L
.08722 .02597 L
.09395 .01923 L
.01923 .01923 L
F
0 g
.01923 .09395 m
.02597 .08722 L
.02894 .08423 L
.03567 .07751 L
.03866 .07452 L
.04538 .06779 L
.04837 .06481 L
.0551 .05808 L
.05808 .0551 L
.06481 .04837 L
.06779 .04538 L
.07452 .03866 L
.07751 .03567 L
.08423 .02894 L
.08722 .02597 L
.09395 .01923 L
s
.6 g
.01923 .05854 m
.01969 .05808 L
.02894 .04882 L
.0294 .04837 L
.03866 .03911 L
.03911 .03866 L
.04837 .0294 L
.04882 .02894 L
.05808 .01969 L
.05854 .01923 L
.01923 .01923 L
F
0 g
.01923 .05854 m
.01969 .05808 L
.02894 .04882 L
.0294 .04837 L
.03866 .03911 L
.03911 .03866 L
.04837 .0294 L
.04882 .02894 L
.05808 .01969 L
.05854 .01923 L
s
.4 g
.06022 .98077 m
.06779 .97309 L
.06994 .97106 L
.07751 .96349 L
.07965 .96134 L
.08722 .95377 L
.08936 .95163 L
.09693 .94406 L
.09907 .94192 L
.10664 .93435 L
.10879 .93221 L
.11636 .92464 L
.1185 .92249 L
.12607 .91492 L
.12821 .91278 L
.13578 .90521 L
.13792 .90307 L
.14549 .8955 L
.14764 .89336 L
.15521 .88579 L
.15735 .88364 L
.16492 .87607 L
.16706 .87393 L
.17463 .86636 L
.17677 .86422 L
.18434 .85665 L
.18649 .85451 L
.19406 .84694 L
.1962 .84479 L
.20377 .83722 L
.20591 .83508 L
.21348 .82751 L
.21562 .82537 L
.22319 .8178 L
.22534 .81566 L
.23291 .80809 L
.23505 .80594 L
.24262 .79837 L
.24476 .79623 L
.25233 .78866 L
.25447 .78652 L
.26204 .77895 L
.26419 .77681 L
.27176 .76924 L
.2739 .76709 L
.28147 .75952 L
.28361 .75738 L
.29118 .74981 L
.29332 .74767 L
.30089 .7401 L
.30304 .73796 L
.31061 .73039 L
.31275 .72824 L
.32032 .72067 L
.32246 .71853 L
.33003 .71096 L
.33213 .70882 L
.33974 .70125 L
.34241 .69911 L
.34946 .69425 L
.35563 .68939 L
.35917 .68594 L
.36598 .67968 L
.36888 .67656 L
.37536 .66997 L
.37859 .66627 L
.38407 .66026 L
.38831 .65517 L
.39226 .65054 L
.39802 .64332 L
.40003 .64083 L
.4075 .63112 L
.40773 .63079 L
.41482 .62141 L
.41744 .61766 L
.42179 .61169 L
.42716 .6039 L
.42851 .60198 L
.43517 .59227 L
.43687 .5896 L
.44161 .58256 L
.44658 .57475 L
.44783 .57284 L
.45406 .56313 L
.45629 .55941 L
.46007 .55342 L
.46592 .54371 L
.46601 .54355 L
.47183 .53399 L
.47572 .52724 L
.47748 .52428 L
.48317 .51457 L
.48543 .51046 L
.48869 .50486 L
.49414 .49514 L
.49514 .49324 L
.49956 .48543 L
.50479 .47572 L
.50486 .47558 L
.51014 .46601 L
.51457 .45751 L
.51523 .45629 L
.52045 .44658 L
.52428 .43903 L
.52543 .43687 L
.53053 .42716 L
.53399 .42016 L
.5354 .41744 L
.5404 .40773 L
.54371 .40089 L
.54517 .39802 L
.55007 .38831 L
.55342 .38125 L
.55474 .37859 L
.55956 .36888 L
.56313 .36123 L
.56414 .35917 L
.56889 .34946 L
.57284 .34084 L
.57337 .33974 L
.57805 .33003 L
.58247 .32032 L
.58256 .3201 L
.58706 .31061 L
.59148 .30089 L
.59227 .29902 L
.59593 .29118 L
.60035 .28147 L
.60198 .27759 L
.60466 .27176 L
.60907 .26204 L
.61169 .25581 L
.61327 .25233 L
.61765 .24262 L
.62141 .2337 L
.62176 .23291 L
.6261 .22319 L
.63025 .21348 L
.63112 .21127 L
.63443 .20377 L
.63862 .19406 L
.64083 .18852 L
.64264 .18434 L
.64685 .17463 L
.65054 .16544 L
.65077 .16492 L
.65493 .15521 L
.65896 .14549 L
.66026 .14206 L
.66291 .13578 L
.66699 .12607 L
.66997 .11836 L
.6708 .11636 L
.67487 .10664 L
.67875 .09693 L
.67968 .09436 L
.68263 .08722 L
.6866 .07751 L
.68939 .07005 L
.69032 .06779 L
.69429 .05808 L
.69808 .04837 L
.69911 .04546 L
.70185 .03866 L
.70574 .02894 L
.70882 .02056 L
.70935 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.06022 .98077 m
.06779 .97309 L
.06994 .97106 L
.07751 .96349 L
.07965 .96134 L
.08722 .95377 L
.08936 .95163 L
.09693 .94406 L
.09907 .94192 L
.10664 .93435 L
.10879 .93221 L
.11636 .92464 L
.1185 .92249 L
.12607 .91492 L
.12821 .91278 L
.13578 .90521 L
.13792 .90307 L
.14549 .8955 L
.14764 .89336 L
.15521 .88579 L
.15735 .88364 L
.16492 .87607 L
.16706 .87393 L
.17463 .86636 L
.17677 .86422 L
.18434 .85665 L
.18649 .85451 L
.19406 .84694 L
.1962 .84479 L
.20377 .83722 L
.20591 .83508 L
.21348 .82751 L
.21562 .82537 L
.22319 .8178 L
.22534 .81566 L
.23291 .80809 L
.23505 .80594 L
.24262 .79837 L
.24476 .79623 L
.25233 .78866 L
.25447 .78652 L
.26204 .77895 L
.26419 .77681 L
.27176 .76924 L
.2739 .76709 L
.28147 .75952 L
.28361 .75738 L
.29118 .74981 L
.29332 .74767 L
.30089 .7401 L
Mistroke
.30304 .73796 L
.31061 .73039 L
.31275 .72824 L
.32032 .72067 L
.32246 .71853 L
.33003 .71096 L
.33213 .70882 L
.33974 .70125 L
.34241 .69911 L
.34946 .69425 L
.35563 .68939 L
.35917 .68594 L
.36598 .67968 L
.36888 .67656 L
.37536 .66997 L
.37859 .66627 L
.38407 .66026 L
.38831 .65517 L
.39226 .65054 L
.39802 .64332 L
.40003 .64083 L
.4075 .63112 L
.40773 .63079 L
.41482 .62141 L
.41744 .61766 L
.42179 .61169 L
.42716 .6039 L
.42851 .60198 L
.43517 .59227 L
.43687 .5896 L
.44161 .58256 L
.44658 .57475 L
.44783 .57284 L
.45406 .56313 L
.45629 .55941 L
.46007 .55342 L
.46592 .54371 L
.46601 .54355 L
.47183 .53399 L
.47572 .52724 L
.47748 .52428 L
.48317 .51457 L
.48543 .51046 L
.48869 .50486 L
.49414 .49514 L
.49514 .49324 L
.49956 .48543 L
.50479 .47572 L
.50486 .47558 L
.51014 .46601 L
Mistroke
.51457 .45751 L
.51523 .45629 L
.52045 .44658 L
.52428 .43903 L
.52543 .43687 L
.53053 .42716 L
.53399 .42016 L
.5354 .41744 L
.5404 .40773 L
.54371 .40089 L
.54517 .39802 L
.55007 .38831 L
.55342 .38125 L
.55474 .37859 L
.55956 .36888 L
.56313 .36123 L
.56414 .35917 L
.56889 .34946 L
.57284 .34084 L
.57337 .33974 L
.57805 .33003 L
.58247 .32032 L
.58256 .3201 L
.58706 .31061 L
.59148 .30089 L
.59227 .29902 L
.59593 .29118 L
.60035 .28147 L
.60198 .27759 L
.60466 .27176 L
.60907 .26204 L
.61169 .25581 L
.61327 .25233 L
.61765 .24262 L
.62141 .2337 L
.62176 .23291 L
.6261 .22319 L
.63025 .21348 L
.63112 .21127 L
.63443 .20377 L
.63862 .19406 L
.64083 .18852 L
.64264 .18434 L
.64685 .17463 L
.65054 .16544 L
.65077 .16492 L
.65493 .15521 L
.65896 .14549 L
.66026 .14206 L
.66291 .13578 L
Mistroke
.66699 .12607 L
.66997 .11836 L
.6708 .11636 L
.67487 .10664 L
.67875 .09693 L
.67968 .09436 L
.68263 .08722 L
.6866 .07751 L
.68939 .07005 L
.69032 .06779 L
.69429 .05808 L
.69808 .04837 L
.69911 .04546 L
.70185 .03866 L
.70574 .02894 L
.70882 .02056 L
.70935 .01923 L
Mfstroke
.5 g
.10392 .98077 m
.10664 .97804 L
.11363 .97106 L
.11636 .96833 L
.12334 .96134 L
.12607 .95862 L
.13306 .95163 L
.13578 .94891 L
.14277 .94192 L
.14549 .9392 L
.15248 .93221 L
.15521 .92948 L
.16219 .92249 L
.16492 .91977 L
.17191 .91278 L
.17463 .91006 L
.18162 .90307 L
.18434 .90035 L
.19133 .89336 L
.19406 .89063 L
.20105 .88364 L
.20377 .88092 L
.21076 .87393 L
.21348 .87121 L
.22047 .86422 L
.22319 .8615 L
.23018 .85451 L
.23291 .85178 L
.2399 .84479 L
.24262 .84207 L
.24961 .83508 L
.25233 .83236 L
.25932 .82537 L
.26204 .82265 L
.26903 .81566 L
.27176 .81293 L
.27875 .80594 L
.28147 .80322 L
.28846 .79623 L
.29118 .79351 L
.29817 .78652 L
.30089 .7838 L
.30788 .77681 L
.31061 .77408 L
.3176 .76709 L
.32032 .76437 L
.32731 .75738 L
.33003 .75466 L
.33703 .74767 L
.33974 .74495 L
.34691 .73796 L
.34946 .7355 L
.35645 .72824 L
.35917 .72528 L
.36525 .71853 L
.36888 .71433 L
.37358 .70882 L
.37859 .70272 L
.38152 .69911 L
.38831 .69048 L
.38915 .68939 L
.39652 .67968 L
.39802 .67765 L
.40365 .66997 L
.40773 .66426 L
.41057 .66026 L
.41729 .65054 L
.41744 .65032 L
.42388 .64083 L
.42716 .63588 L
.43029 .63112 L
.43657 .62141 L
.43687 .62093 L
.44274 .61169 L
.44658 .6055 L
.44877 .60198 L
.4547 .59227 L
.45629 .58961 L
.46053 .58256 L
.46601 .57327 L
.46626 .57284 L
.47192 .56313 L
.47572 .55649 L
.47748 .55342 L
.48297 .54371 L
.48543 .53928 L
.48838 .53399 L
.49372 .52428 L
.49514 .52166 L
.499 .51457 L
.50421 .50486 L
.50486 .50363 L
.50937 .49514 L
.51445 .48543 L
.51457 .4852 L
.51951 .47572 L
.52428 .46639 L
.52448 .46601 L
.52943 .45629 L
.53399 .4472 L
.5343 .44658 L
.53916 .43687 L
.54371 .42763 L
.54394 .42716 L
.54871 .41744 L
.5534 .40773 L
.55342 .4077 L
.5581 .39802 L
.56271 .38831 L
.56313 .38741 L
.56732 .37859 L
.57187 .36888 L
.57284 .36677 L
.5764 .35917 L
.58089 .34946 L
.58256 .34579 L
.58534 .33974 L
.58977 .33003 L
.59227 .32446 L
.59415 .32032 L
.59852 .31061 L
.60198 .3028 L
.60283 .30089 L
.60716 .29118 L
.61141 .28147 L
.61169 .28081 L
.61567 .27176 L
.61989 .26204 L
.62141 .2585 L
.62408 .25233 L
.62826 .24262 L
.63112 .23586 L
.63238 .23291 L
.63652 .22319 L
.6406 .21348 L
.64083 .21291 L
.64469 .20377 L
.64874 .19406 L
.65054 .18965 L
.65275 .18434 L
.65678 .17463 L
.66026 .16608 L
.66073 .16492 L
.66472 .15521 L
.66866 .14549 L
.66997 .14221 L
.67258 .13578 L
.6765 .12607 L
.67968 .11805 L
.68036 .11636 L
.68425 .10664 L
.6881 .09693 L
.68939 .09358 L
.69191 .08722 L
.69575 .07751 L
.69911 .06883 L
.69951 .06779 L
.70331 .05808 L
.70708 .04837 L
.70882 .04378 L
.7108 .03866 L
.71456 .02894 L
.71824 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.10392 .98077 m
.10664 .97804 L
.11363 .97106 L
.11636 .96833 L
.12334 .96134 L
.12607 .95862 L
.13306 .95163 L
.13578 .94891 L
.14277 .94192 L
.14549 .9392 L
.15248 .93221 L
.15521 .92948 L
.16219 .92249 L
.16492 .91977 L
.17191 .91278 L
.17463 .91006 L
.18162 .90307 L
.18434 .90035 L
.19133 .89336 L
.19406 .89063 L
.20105 .88364 L
.20377 .88092 L
.21076 .87393 L
.21348 .87121 L
.22047 .86422 L
.22319 .8615 L
.23018 .85451 L
.23291 .85178 L
.2399 .84479 L
.24262 .84207 L
.24961 .83508 L
.25233 .83236 L
.25932 .82537 L
.26204 .82265 L
.26903 .81566 L
.27176 .81293 L
.27875 .80594 L
.28147 .80322 L
.28846 .79623 L
.29118 .79351 L
.29817 .78652 L
.30089 .7838 L
.30788 .77681 L
.31061 .77408 L
.3176 .76709 L
.32032 .76437 L
.32731 .75738 L
.33003 .75466 L
.33703 .74767 L
.33974 .74495 L
Mistroke
.34691 .73796 L
.34946 .7355 L
.35645 .72824 L
.35917 .72528 L
.36525 .71853 L
.36888 .71433 L
.37358 .70882 L
.37859 .70272 L
.38152 .69911 L
.38831 .69048 L
.38915 .68939 L
.39652 .67968 L
.39802 .67765 L
.40365 .66997 L
.40773 .66426 L
.41057 .66026 L
.41729 .65054 L
.41744 .65032 L
.42388 .64083 L
.42716 .63588 L
.43029 .63112 L
.43657 .62141 L
.43687 .62093 L
.44274 .61169 L
.44658 .6055 L
.44877 .60198 L
.4547 .59227 L
.45629 .58961 L
.46053 .58256 L
.46601 .57327 L
.46626 .57284 L
.47192 .56313 L
.47572 .55649 L
.47748 .55342 L
.48297 .54371 L
.48543 .53928 L
.48838 .53399 L
.49372 .52428 L
.49514 .52166 L
.499 .51457 L
.50421 .50486 L
.50486 .50363 L
.50937 .49514 L
.51445 .48543 L
.51457 .4852 L
.51951 .47572 L
.52428 .46639 L
.52448 .46601 L
.52943 .45629 L
.53399 .4472 L
Mistroke
.5343 .44658 L
.53916 .43687 L
.54371 .42763 L
.54394 .42716 L
.54871 .41744 L
.5534 .40773 L
.55342 .4077 L
.5581 .39802 L
.56271 .38831 L
.56313 .38741 L
.56732 .37859 L
.57187 .36888 L
.57284 .36677 L
.5764 .35917 L
.58089 .34946 L
.58256 .34579 L
.58534 .33974 L
.58977 .33003 L
.59227 .32446 L
.59415 .32032 L
.59852 .31061 L
.60198 .3028 L
.60283 .30089 L
.60716 .29118 L
.61141 .28147 L
.61169 .28081 L
.61567 .27176 L
.61989 .26204 L
.62141 .2585 L
.62408 .25233 L
.62826 .24262 L
.63112 .23586 L
.63238 .23291 L
.63652 .22319 L
.6406 .21348 L
.64083 .21291 L
.64469 .20377 L
.64874 .19406 L
.65054 .18965 L
.65275 .18434 L
.65678 .17463 L
.66026 .16608 L
.66073 .16492 L
.66472 .15521 L
.66866 .14549 L
.66997 .14221 L
.67258 .13578 L
.6765 .12607 L
.67968 .11805 L
.68036 .11636 L
Mistroke
.68425 .10664 L
.6881 .09693 L
.68939 .09358 L
.69191 .08722 L
.69575 .07751 L
.69911 .06883 L
.69951 .06779 L
.70331 .05808 L
.70708 .04837 L
.70882 .04378 L
.7108 .03866 L
.71456 .02894 L
.71824 .01923 L
Mfstroke
.6 g
.13933 .98077 m
.14549 .97461 L
.14904 .97106 L
.15521 .96489 L
.15875 .96134 L
.16492 .95518 L
.16847 .95163 L
.17463 .94547 L
.17818 .94192 L
.18434 .93575 L
.18789 .93221 L
.19406 .92604 L
.1976 .92249 L
.20377 .91633 L
.20732 .91278 L
.21348 .90662 L
.21703 .90307 L
.22319 .8969 L
.22674 .89336 L
.23291 .88719 L
.23645 .88364 L
.24262 .87748 L
.24617 .87393 L
.25233 .86777 L
.25588 .86422 L
.26204 .85805 L
.26559 .85451 L
.27176 .84834 L
.2753 .84479 L
.28147 .83863 L
.28502 .83508 L
.29118 .82892 L
.29473 .82537 L
.30089 .8192 L
.30444 .81566 L
.31061 .80949 L
.31415 .80594 L
.32032 .79978 L
.32387 .79623 L
.33003 .79007 L
.33366 .78652 L
.33974 .78035 L
.34302 .77681 L
.34946 .76965 L
.35171 .76709 L
.35917 .75837 L
.35999 .75738 L
.36795 .74767 L
.36888 .7465 L
.37562 .73796 L
.37859 .73409 L
.38303 .72824 L
.38831 .72114 L
.39022 .71853 L
.3972 .70882 L
.39802 .70767 L
.40401 .69911 L
.40773 .6937 L
.41065 .68939 L
.41715 .67968 L
.41744 .67924 L
.42351 .66997 L
.42716 .66431 L
.42974 .66026 L
.43585 .65054 L
.43687 .64891 L
.44186 .64083 L
.44658 .63307 L
.44776 .63112 L
.45357 .62141 L
.45629 .6168 L
.45929 .61169 L
.46492 .60198 L
.46601 .6001 L
.47047 .59227 L
.47572 .58298 L
.47596 .58256 L
.48136 .57284 L
.48543 .56546 L
.4867 .56313 L
.49198 .55342 L
.49514 .54753 L
.49719 .54371 L
.50234 .53399 L
.50486 .52922 L
.50744 .52428 L
.51249 .51457 L
.51457 .51053 L
.51747 .50486 L
.52242 .49514 L
.52428 .49146 L
.52731 .48543 L
.53216 .47572 L
.53399 .47203 L
.53696 .46601 L
.54173 .45629 L
.54371 .45223 L
.54644 .44658 L
.55112 .43687 L
.55342 .43208 L
.55576 .42716 L
.56037 .41744 L
.56313 .41158 L
.56493 .40773 L
.56946 .39802 L
.57284 .39074 L
.57396 .38831 L
.57842 .37859 L
.58256 .36956 L
.58286 .36888 L
.58725 .35917 L
.59164 .34946 L
.59227 .34805 L
.59596 .33974 L
.60029 .33003 L
.60198 .32621 L
.60456 .32032 L
.60883 .31061 L
.61169 .30404 L
.61305 .30089 L
.61726 .29118 L
.62141 .28156 L
.62145 .28147 L
.62558 .27176 L
.62973 .26204 L
.63112 .25877 L
.63382 .25233 L
.63791 .24262 L
.64083 .23566 L
.64197 .23291 L
.64601 .22319 L
.65004 .21348 L
.65054 .21225 L
.65401 .20377 L
.658 .19406 L
.66026 .18854 L
.66194 .18434 L
.66588 .17463 L
.66981 .16492 L
.66997 .16453 L
.67369 .15521 L
.67758 .14549 L
.67968 .14022 L
.68142 .13578 L
.68527 .12607 L
.68911 .11636 L
.68939 .11563 L
.69289 .10664 L
.6967 .09693 L
.69911 .09074 L
.70045 .08722 L
.70421 .07751 L
.70797 .06779 L
.70882 .06557 L
.71166 .05808 L
.71539 .04837 L
.71853 .04012 L
.71908 .03866 L
.72274 .02894 L
.72642 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.13933 .98077 m
.14549 .97461 L
.14904 .97106 L
.15521 .96489 L
.15875 .96134 L
.16492 .95518 L
.16847 .95163 L
.17463 .94547 L
.17818 .94192 L
.18434 .93575 L
.18789 .93221 L
.19406 .92604 L
.1976 .92249 L
.20377 .91633 L
.20732 .91278 L
.21348 .90662 L
.21703 .90307 L
.22319 .8969 L
.22674 .89336 L
.23291 .88719 L
.23645 .88364 L
.24262 .87748 L
.24617 .87393 L
.25233 .86777 L
.25588 .86422 L
.26204 .85805 L
.26559 .85451 L
.27176 .84834 L
.2753 .84479 L
.28147 .83863 L
.28502 .83508 L
.29118 .82892 L
.29473 .82537 L
.30089 .8192 L
.30444 .81566 L
.31061 .80949 L
.31415 .80594 L
.32032 .79978 L
.32387 .79623 L
.33003 .79007 L
.33366 .78652 L
.33974 .78035 L
.34302 .77681 L
.34946 .76965 L
.35171 .76709 L
.35917 .75837 L
.35999 .75738 L
.36795 .74767 L
.36888 .7465 L
.37562 .73796 L
Mistroke
.37859 .73409 L
.38303 .72824 L
.38831 .72114 L
.39022 .71853 L
.3972 .70882 L
.39802 .70767 L
.40401 .69911 L
.40773 .6937 L
.41065 .68939 L
.41715 .67968 L
.41744 .67924 L
.42351 .66997 L
.42716 .66431 L
.42974 .66026 L
.43585 .65054 L
.43687 .64891 L
.44186 .64083 L
.44658 .63307 L
.44776 .63112 L
.45357 .62141 L
.45629 .6168 L
.45929 .61169 L
.46492 .60198 L
.46601 .6001 L
.47047 .59227 L
.47572 .58298 L
.47596 .58256 L
.48136 .57284 L
.48543 .56546 L
.4867 .56313 L
.49198 .55342 L
.49514 .54753 L
.49719 .54371 L
.50234 .53399 L
.50486 .52922 L
.50744 .52428 L
.51249 .51457 L
.51457 .51053 L
.51747 .50486 L
.52242 .49514 L
.52428 .49146 L
.52731 .48543 L
.53216 .47572 L
.53399 .47203 L
.53696 .46601 L
.54173 .45629 L
.54371 .45223 L
.54644 .44658 L
.55112 .43687 L
.55342 .43208 L
Mistroke
.55576 .42716 L
.56037 .41744 L
.56313 .41158 L
.56493 .40773 L
.56946 .39802 L
.57284 .39074 L
.57396 .38831 L
.57842 .37859 L
.58256 .36956 L
.58286 .36888 L
.58725 .35917 L
.59164 .34946 L
.59227 .34805 L
.59596 .33974 L
.60029 .33003 L
.60198 .32621 L
.60456 .32032 L
.60883 .31061 L
.61169 .30404 L
.61305 .30089 L
.61726 .29118 L
.62141 .28156 L
.62145 .28147 L
.62558 .27176 L
.62973 .26204 L
.63112 .25877 L
.63382 .25233 L
.63791 .24262 L
.64083 .23566 L
.64197 .23291 L
.64601 .22319 L
.65004 .21348 L
.65054 .21225 L
.65401 .20377 L
.658 .19406 L
.66026 .18854 L
.66194 .18434 L
.66588 .17463 L
.66981 .16492 L
.66997 .16453 L
.67369 .15521 L
.67758 .14549 L
.67968 .14022 L
.68142 .13578 L
.68527 .12607 L
.68911 .11636 L
.68939 .11563 L
.69289 .10664 L
.6967 .09693 L
.69911 .09074 L
Mistroke
.70045 .08722 L
.70421 .07751 L
.70797 .06779 L
.70882 .06557 L
.71166 .05808 L
.71539 .04837 L
.71853 .04012 L
.71908 .03866 L
.72274 .02894 L
.72642 .01923 L
Mfstroke
.7 g
.18304 .98077 m
.18434 .97949 L
.19275 .97106 L
.19406 .96975 L
.20246 .96134 L
.20377 .96004 L
.21217 .95163 L
.21348 .95032 L
.22189 .94192 L
.22319 .94061 L
.2316 .93221 L
.23291 .9309 L
.24131 .92249 L
.24262 .92119 L
.25102 .91278 L
.25233 .91147 L
.26074 .90307 L
.26204 .90176 L
.27045 .89336 L
.27176 .89205 L
.28016 .88364 L
.28147 .88234 L
.28987 .87393 L
.29118 .87262 L
.29959 .86422 L
.30089 .86291 L
.3093 .85451 L
.31061 .8532 L
.31901 .84479 L
.32032 .84349 L
.32872 .83508 L
.33003 .83377 L
.33857 .82537 L
.33974 .82406 L
.34605 .81566 L
.34946 .81091 L
.35313 .80594 L
.35917 .79772 L
.36025 .79623 L
.36728 .78652 L
.36888 .78429 L
.37418 .77681 L
.37859 .77054 L
.38098 .76709 L
.38768 .75738 L
.38831 .75647 L
.39422 .74767 L
.39802 .74199 L
.40067 .73796 L
.40703 .72824 L
.40773 .72716 L
.41323 .71853 L
.41744 .71191 L
.41936 .70882 L
.42541 .69911 L
.42716 .69628 L
.43132 .68939 L
.43687 .68025 L
.4372 .67968 L
.44294 .66997 L
.44658 .66382 L
.44862 .66026 L
.45425 .65054 L
.45629 .64701 L
.45976 .64083 L
.46527 .63112 L
.46601 .62981 L
.47063 .62141 L
.47572 .61224 L
.47601 .61169 L
.48125 .60198 L
.48543 .59428 L
.48648 .59227 L
.49163 .58256 L
.49514 .57595 L
.49673 .57284 L
.50179 .56313 L
.50486 .55727 L
.50678 .55342 L
.51176 .54371 L
.51457 .53822 L
.51664 .53399 L
.52153 .52428 L
.52428 .51882 L
.52632 .51457 L
.53113 .50486 L
.53399 .49906 L
.53584 .49514 L
.54056 .48543 L
.54371 .47897 L
.5452 .47572 L
.54983 .46601 L
.55342 .45854 L
.55443 .45629 L
.55896 .44658 L
.56313 .43777 L
.56353 .43687 L
.56796 .42716 L
.57249 .41744 L
.57284 .41667 L
.57682 .40773 L
.58129 .39802 L
.58256 .39524 L
.58557 .38831 L
.58996 .37859 L
.59227 .37349 L
.59422 .36888 L
.59852 .35917 L
.60198 .35142 L
.60279 .34946 L
.60698 .33974 L
.61126 .33003 L
.61169 .32905 L
.61534 .32032 L
.61956 .31061 L
.62141 .30635 L
.62362 .30089 L
.62776 .29118 L
.63112 .28336 L
.63186 .28147 L
.63587 .27176 L
.63999 .26204 L
.64083 .26006 L
.64391 .25233 L
.64797 .24262 L
.65054 .23646 L
.6519 .23291 L
.65586 .22319 L
.65988 .21348 L
.66026 .21257 L
.66368 .20377 L
.66765 .19406 L
.66997 .18838 L
.67147 .18434 L
.67534 .17463 L
.67928 .16492 L
.67968 .16391 L
.68297 .15521 L
.68686 .14549 L
.68939 .13915 L
.69061 .13578 L
.69437 .12607 L
.69822 .11636 L
.69911 .11411 L
.70184 .10664 L
.70563 .09693 L
.70882 .08879 L
.70936 .08722 L
.71297 .07751 L
.71675 .06779 L
.71853 .06319 L
.72032 .05808 L
.724 .04837 L
.72774 .03866 L
.72824 .03732 L
.73121 .02894 L
.73489 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.18304 .98077 m
.18434 .97949 L
.19275 .97106 L
.19406 .96975 L
.20246 .96134 L
.20377 .96004 L
.21217 .95163 L
.21348 .95032 L
.22189 .94192 L
.22319 .94061 L
.2316 .93221 L
.23291 .9309 L
.24131 .92249 L
.24262 .92119 L
.25102 .91278 L
.25233 .91147 L
.26074 .90307 L
.26204 .90176 L
.27045 .89336 L
.27176 .89205 L
.28016 .88364 L
.28147 .88234 L
.28987 .87393 L
.29118 .87262 L
.29959 .86422 L
.30089 .86291 L
.3093 .85451 L
.31061 .8532 L
.31901 .84479 L
.32032 .84349 L
.32872 .83508 L
.33003 .83377 L
.33857 .82537 L
.33974 .82406 L
.34605 .81566 L
.34946 .81091 L
.35313 .80594 L
.35917 .79772 L
.36025 .79623 L
.36728 .78652 L
.36888 .78429 L
.37418 .77681 L
.37859 .77054 L
.38098 .76709 L
.38768 .75738 L
.38831 .75647 L
.39422 .74767 L
.39802 .74199 L
.40067 .73796 L
.40703 .72824 L
Mistroke
.40773 .72716 L
.41323 .71853 L
.41744 .71191 L
.41936 .70882 L
.42541 .69911 L
.42716 .69628 L
.43132 .68939 L
.43687 .68025 L
.4372 .67968 L
.44294 .66997 L
.44658 .66382 L
.44862 .66026 L
.45425 .65054 L
.45629 .64701 L
.45976 .64083 L
.46527 .63112 L
.46601 .62981 L
.47063 .62141 L
.47572 .61224 L
.47601 .61169 L
.48125 .60198 L
.48543 .59428 L
.48648 .59227 L
.49163 .58256 L
.49514 .57595 L
.49673 .57284 L
.50179 .56313 L
.50486 .55727 L
.50678 .55342 L
.51176 .54371 L
.51457 .53822 L
.51664 .53399 L
.52153 .52428 L
.52428 .51882 L
.52632 .51457 L
.53113 .50486 L
.53399 .49906 L
.53584 .49514 L
.54056 .48543 L
.54371 .47897 L
.5452 .47572 L
.54983 .46601 L
.55342 .45854 L
.55443 .45629 L
.55896 .44658 L
.56313 .43777 L
.56353 .43687 L
.56796 .42716 L
.57249 .41744 L
.57284 .41667 L
Mistroke
.57682 .40773 L
.58129 .39802 L
.58256 .39524 L
.58557 .38831 L
.58996 .37859 L
.59227 .37349 L
.59422 .36888 L
.59852 .35917 L
.60198 .35142 L
.60279 .34946 L
.60698 .33974 L
.61126 .33003 L
.61169 .32905 L
.61534 .32032 L
.61956 .31061 L
.62141 .30635 L
.62362 .30089 L
.62776 .29118 L
.63112 .28336 L
.63186 .28147 L
.63587 .27176 L
.63999 .26204 L
.64083 .26006 L
.64391 .25233 L
.64797 .24262 L
.65054 .23646 L
.6519 .23291 L
.65586 .22319 L
.65988 .21348 L
.66026 .21257 L
.66368 .20377 L
.66765 .19406 L
.66997 .18838 L
.67147 .18434 L
.67534 .17463 L
.67928 .16492 L
.67968 .16391 L
.68297 .15521 L
.68686 .14549 L
.68939 .13915 L
.69061 .13578 L
.69437 .12607 L
.69822 .11636 L
.69911 .11411 L
.70184 .10664 L
.70563 .09693 L
.70882 .08879 L
.70936 .08722 L
.71297 .07751 L
.71675 .06779 L
Mistroke
.71853 .06319 L
.72032 .05808 L
.724 .04837 L
.72774 .03866 L
.72824 .03732 L
.73121 .02894 L
.73489 .01923 L
Mfstroke
.6 g
.2616 .98077 m
.26204 .98018 L
.27131 .97106 L
.27176 .97061 L
.28102 .96134 L
.28147 .9609 L
.29073 .95163 L
.29118 .95118 L
.30045 .94192 L
.30089 .94147 L
.31016 .93221 L
.31061 .93176 L
.31987 .92249 L
.32032 .92205 L
.32958 .91278 L
.33003 .91233 L
.33926 .90307 L
.33974 .90262 L
.34946 .89562 L
.35244 .89336 L
.35917 .88732 L
.36327 .88364 L
.36888 .87794 L
.3729 .87393 L
.37859 .86765 L
.38176 .86422 L
.38831 .85654 L
.39006 .85451 L
.39794 .84479 L
.39802 .84469 L
.40563 .83508 L
.40773 .83219 L
.41293 .82537 L
.41744 .81904 L
.41992 .81566 L
.42673 .80594 L
.42716 .80529 L
.43345 .79623 L
.43687 .79099 L
.43989 .78652 L
.44618 .77681 L
.44658 .77614 L
.45245 .76709 L
.45629 .76079 L
.45845 .75738 L
.46443 .74767 L
.46601 .74494 L
.47028 .73796 L
.47572 .72861 L
.47594 .72824 L
.4817 .71853 L
.48543 .71184 L
.48719 .70882 L
.49274 .69911 L
.49514 .69462 L
.49811 .68939 L
.50346 .67968 L
.50486 .67697 L
.50873 .66997 L
.51389 .66026 L
.51457 .6589 L
.51908 .65054 L
.52408 .64083 L
.52428 .64041 L
.5292 .63112 L
.53399 .62154 L
.53406 .62141 L
.53909 .61169 L
.54371 .60227 L
.54385 .60198 L
.54879 .59227 L
.55342 .58262 L
.55345 .58256 L
.5583 .57284 L
.5629 .56313 L
.56313 .56261 L
.56764 .55342 L
.5722 .54371 L
.57284 .54223 L
.57682 .53399 L
.58135 .52428 L
.58256 .52149 L
.58584 .51457 L
.59035 .50486 L
.59227 .50041 L
.59473 .49514 L
.59921 .48543 L
.60198 .47897 L
.60348 .47572 L
.60792 .46601 L
.61169 .45719 L
.6121 .45629 L
.6165 .44658 L
.6207 .43687 L
.62141 .43509 L
.62495 .42716 L
.62919 .41744 L
.63112 .41266 L
.63329 .40773 L
.63753 .39802 L
.64083 .3899 L
.64152 .38831 L
.64574 .37859 L
.64977 .36888 L
.65054 .36683 L
.65383 .35917 L
.65792 .34946 L
.66026 .34344 L
.66182 .33974 L
.66592 .33003 L
.66976 .32032 L
.66997 .31974 L
.67379 .31061 L
.67776 .30089 L
.67968 .29574 L
.68157 .29118 L
.68557 .28147 L
.68928 .27176 L
.68939 .27144 L
.69324 .26204 L
.69711 .25233 L
.69911 .24684 L
.70081 .24262 L
.70473 .23291 L
.7084 .22319 L
.70882 .22195 L
.7122 .21348 L
.71603 .20377 L
.71853 .19677 L
.7196 .19406 L
.72344 .18434 L
.72712 .17463 L
.72824 .1713 L
.73074 .16492 L
.73452 .15521 L
.73796 .14555 L
.73798 .14549 L
.74174 .13578 L
.74543 .12607 L
.74767 .11953 L
.74888 .11636 L
.75261 .10664 L
.75617 .09693 L
.75738 .09322 L
.75966 .08722 L
.76334 .07751 L
.76674 .06779 L
.76709 .06664 L
.77031 .05808 L
.77393 .04837 L
.77681 .03979 L
.77723 .03866 L
.78085 .02894 L
.78439 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.2616 .98077 m
.26204 .98018 L
.27131 .97106 L
.27176 .97061 L
.28102 .96134 L
.28147 .9609 L
.29073 .95163 L
.29118 .95118 L
.30045 .94192 L
.30089 .94147 L
.31016 .93221 L
.31061 .93176 L
.31987 .92249 L
.32032 .92205 L
.32958 .91278 L
.33003 .91233 L
.33926 .90307 L
.33974 .90262 L
.34946 .89562 L
.35244 .89336 L
.35917 .88732 L
.36327 .88364 L
.36888 .87794 L
.3729 .87393 L
.37859 .86765 L
.38176 .86422 L
.38831 .85654 L
.39006 .85451 L
.39794 .84479 L
.39802 .84469 L
.40563 .83508 L
.40773 .83219 L
.41293 .82537 L
.41744 .81904 L
.41992 .81566 L
.42673 .80594 L
.42716 .80529 L
.43345 .79623 L
.43687 .79099 L
.43989 .78652 L
.44618 .77681 L
.44658 .77614 L
.45245 .76709 L
.45629 .76079 L
.45845 .75738 L
.46443 .74767 L
.46601 .74494 L
.47028 .73796 L
.47572 .72861 L
.47594 .72824 L
Mistroke
.4817 .71853 L
.48543 .71184 L
.48719 .70882 L
.49274 .69911 L
.49514 .69462 L
.49811 .68939 L
.50346 .67968 L
.50486 .67697 L
.50873 .66997 L
.51389 .66026 L
.51457 .6589 L
.51908 .65054 L
.52408 .64083 L
.52428 .64041 L
.5292 .63112 L
.53399 .62154 L
.53406 .62141 L
.53909 .61169 L
.54371 .60227 L
.54385 .60198 L
.54879 .59227 L
.55342 .58262 L
.55345 .58256 L
.5583 .57284 L
.5629 .56313 L
.56313 .56261 L
.56764 .55342 L
.5722 .54371 L
.57284 .54223 L
.57682 .53399 L
.58135 .52428 L
.58256 .52149 L
.58584 .51457 L
.59035 .50486 L
.59227 .50041 L
.59473 .49514 L
.59921 .48543 L
.60198 .47897 L
.60348 .47572 L
.60792 .46601 L
.61169 .45719 L
.6121 .45629 L
.6165 .44658 L
.6207 .43687 L
.62141 .43509 L
.62495 .42716 L
.62919 .41744 L
.63112 .41266 L
.63329 .40773 L
.63753 .39802 L
Mistroke
.64083 .3899 L
.64152 .38831 L
.64574 .37859 L
.64977 .36888 L
.65054 .36683 L
.65383 .35917 L
.65792 .34946 L
.66026 .34344 L
.66182 .33974 L
.66592 .33003 L
.66976 .32032 L
.66997 .31974 L
.67379 .31061 L
.67776 .30089 L
.67968 .29574 L
.68157 .29118 L
.68557 .28147 L
.68928 .27176 L
.68939 .27144 L
.69324 .26204 L
.69711 .25233 L
.69911 .24684 L
.70081 .24262 L
.70473 .23291 L
.7084 .22319 L
.70882 .22195 L
.7122 .21348 L
.71603 .20377 L
.71853 .19677 L
.7196 .19406 L
.72344 .18434 L
.72712 .17463 L
.72824 .1713 L
.73074 .16492 L
.73452 .15521 L
.73796 .14555 L
.73798 .14549 L
.74174 .13578 L
.74543 .12607 L
.74767 .11953 L
.74888 .11636 L
.75261 .10664 L
.75617 .09693 L
.75738 .09322 L
.75966 .08722 L
.76334 .07751 L
.76674 .06779 L
.76709 .06664 L
.77031 .05808 L
.77393 .04837 L
Mistroke
.77681 .03979 L
.77723 .03866 L
.78085 .02894 L
.78439 .01923 L
Mfstroke
.5 g
.3053 .98077 m
.31061 .97546 L
.31502 .97106 L
.32032 .96575 L
.32473 .96134 L
.33003 .95604 L
.33446 .95163 L
.33974 .94633 L
.34425 .94192 L
.34946 .93689 L
.35402 .93221 L
.35917 .92666 L
.36296 .92249 L
.36888 .91572 L
.3714 .91278 L
.37859 .9041 L
.37944 .90307 L
.38716 .89336 L
.38831 .89187 L
.3946 .88364 L
.39802 .87904 L
.40178 .87393 L
.40773 .86564 L
.40874 .86422 L
.41553 .85451 L
.41744 .85171 L
.42215 .84479 L
.42716 .83726 L
.4286 .83508 L
.43492 .82537 L
.43687 .82231 L
.44111 .81566 L
.44658 .80689 L
.44717 .80594 L
.45314 .79623 L
.45629 .791 L
.45899 .78652 L
.46475 .77681 L
.46601 .77465 L
.47043 .76709 L
.47572 .75787 L
.476 .75738 L
.48152 .74767 L
.48543 .74067 L
.48694 .73796 L
.49232 .72824 L
.49514 .72304 L
.4976 .71853 L
.50284 .70882 L
.50486 .70501 L
.508 .69911 L
.51312 .68939 L
.51457 .68659 L
.51817 .67968 L
.52317 .66997 L
.52428 .66777 L
.52812 .66026 L
.53302 .65054 L
.53399 .64858 L
.53788 .64083 L
.54268 .63112 L
.54371 .62902 L
.54745 .62141 L
.55217 .61169 L
.55342 .60909 L
.55685 .60198 L
.5615 .59227 L
.56313 .5888 L
.5661 .58256 L
.57067 .57284 L
.57284 .56816 L
.57519 .56313 L
.57971 .55342 L
.58256 .54717 L
.58415 .54371 L
.5886 .53399 L
.59227 .52585 L
.59298 .52428 L
.59737 .51457 L
.60169 .50486 L
.60198 .50418 L
.60601 .49514 L
.61029 .48543 L
.61169 .4822 L
.61454 .47572 L
.61878 .46601 L
.62141 .45988 L
.62296 .45629 L
.62716 .44658 L
.63112 .43724 L
.63128 .43687 L
.63543 .42716 L
.63953 .41744 L
.64083 .4143 L
.6436 .40773 L
.64767 .39802 L
.65054 .39104 L
.65168 .38831 L
.65572 .37859 L
.65969 .36888 L
.66026 .36747 L
.66367 .35917 L
.66763 .34946 L
.66997 .3436 L
.67153 .33974 L
.67547 .33003 L
.67933 .32032 L
.67968 .31943 L
.68322 .31061 L
.68708 .30089 L
.68939 .29497 L
.69089 .29118 L
.69474 .28147 L
.69852 .27176 L
.69911 .27021 L
.7023 .26204 L
.70609 .25233 L
.70882 .24517 L
.7098 .24262 L
.71357 .23291 L
.71728 .22319 L
.71853 .21984 L
.72097 .21348 L
.72468 .20377 L
.72824 .19423 L
.72831 .19406 L
.73199 .18434 L
.73564 .17463 L
.73796 .16834 L
.73924 .16492 L
.74288 .15521 L
.74647 .14549 L
.74767 .14218 L
.75004 .13578 L
.75364 .12607 L
.75716 .11636 L
.75738 .11574 L
.76072 .10664 L
.76428 .09693 L
.76709 .08903 L
.76775 .08722 L
.77129 .07751 L
.77479 .06779 L
.77681 .06206 L
.77824 .05808 L
.78174 .04837 L
.78519 .03866 L
.78652 .03482 L
.78861 .02894 L
.79208 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.3053 .98077 m
.31061 .97546 L
.31502 .97106 L
.32032 .96575 L
.32473 .96134 L
.33003 .95604 L
.33446 .95163 L
.33974 .94633 L
.34425 .94192 L
.34946 .93689 L
.35402 .93221 L
.35917 .92666 L
.36296 .92249 L
.36888 .91572 L
.3714 .91278 L
.37859 .9041 L
.37944 .90307 L
.38716 .89336 L
.38831 .89187 L
.3946 .88364 L
.39802 .87904 L
.40178 .87393 L
.40773 .86564 L
.40874 .86422 L
.41553 .85451 L
.41744 .85171 L
.42215 .84479 L
.42716 .83726 L
.4286 .83508 L
.43492 .82537 L
.43687 .82231 L
.44111 .81566 L
.44658 .80689 L
.44717 .80594 L
.45314 .79623 L
.45629 .791 L
.45899 .78652 L
.46475 .77681 L
.46601 .77465 L
.47043 .76709 L
.47572 .75787 L
.476 .75738 L
.48152 .74767 L
.48543 .74067 L
.48694 .73796 L
.49232 .72824 L
.49514 .72304 L
.4976 .71853 L
.50284 .70882 L
.50486 .70501 L
Mistroke
.508 .69911 L
.51312 .68939 L
.51457 .68659 L
.51817 .67968 L
.52317 .66997 L
.52428 .66777 L
.52812 .66026 L
.53302 .65054 L
.53399 .64858 L
.53788 .64083 L
.54268 .63112 L
.54371 .62902 L
.54745 .62141 L
.55217 .61169 L
.55342 .60909 L
.55685 .60198 L
.5615 .59227 L
.56313 .5888 L
.5661 .58256 L
.57067 .57284 L
.57284 .56816 L
.57519 .56313 L
.57971 .55342 L
.58256 .54717 L
.58415 .54371 L
.5886 .53399 L
.59227 .52585 L
.59298 .52428 L
.59737 .51457 L
.60169 .50486 L
.60198 .50418 L
.60601 .49514 L
.61029 .48543 L
.61169 .4822 L
.61454 .47572 L
.61878 .46601 L
.62141 .45988 L
.62296 .45629 L
.62716 .44658 L
.63112 .43724 L
.63128 .43687 L
.63543 .42716 L
.63953 .41744 L
.64083 .4143 L
.6436 .40773 L
.64767 .39802 L
.65054 .39104 L
.65168 .38831 L
.65572 .37859 L
.65969 .36888 L
Mistroke
.66026 .36747 L
.66367 .35917 L
.66763 .34946 L
.66997 .3436 L
.67153 .33974 L
.67547 .33003 L
.67933 .32032 L
.67968 .31943 L
.68322 .31061 L
.68708 .30089 L
.68939 .29497 L
.69089 .29118 L
.69474 .28147 L
.69852 .27176 L
.69911 .27021 L
.7023 .26204 L
.70609 .25233 L
.70882 .24517 L
.7098 .24262 L
.71357 .23291 L
.71728 .22319 L
.71853 .21984 L
.72097 .21348 L
.72468 .20377 L
.72824 .19423 L
.72831 .19406 L
.73199 .18434 L
.73564 .17463 L
.73796 .16834 L
.73924 .16492 L
.74288 .15521 L
.74647 .14549 L
.74767 .14218 L
.75004 .13578 L
.75364 .12607 L
.75716 .11636 L
.75738 .11574 L
.76072 .10664 L
.76428 .09693 L
.76709 .08903 L
.76775 .08722 L
.77129 .07751 L
.77479 .06779 L
.77681 .06206 L
.77824 .05808 L
.78174 .04837 L
.78519 .03866 L
.78652 .03482 L
.78861 .02894 L
.79208 .01923 L
Mistroke
Mfstroke
.4 g
.34065 .98077 m
.34944 .97106 L
.34946 .97104 L
.35783 .96134 L
.35917 .95975 L
.36587 .95163 L
.36888 .94789 L
.37361 .94192 L
.37859 .93547 L
.38108 .93221 L
.38831 .92252 L
.38833 .92249 L
.39537 .91278 L
.39802 .90905 L
.40222 .90307 L
.40773 .89508 L
.40891 .89336 L
.41544 .88364 L
.41744 .88062 L
.42183 .87393 L
.42716 .86569 L
.4281 .86422 L
.43424 .85451 L
.43687 .8503 L
.44027 .84479 L
.44621 .83508 L
.44658 .83446 L
.45204 .82537 L
.45629 .81818 L
.45778 .81566 L
.46343 .80594 L
.46601 .80148 L
.46901 .79623 L
.47451 .78652 L
.47572 .78436 L
.47993 .77681 L
.48529 .76709 L
.48543 .76684 L
.49058 .75738 L
.49514 .74892 L
.49581 .74767 L
.50098 .73796 L
.50486 .73061 L
.50609 .72824 L
.51115 .71853 L
.51457 .71191 L
.51615 .70882 L
.52111 .69911 L
.52428 .69285 L
.52601 .68939 L
.53088 .67968 L
.53399 .67341 L
.53569 .66997 L
.54046 .66026 L
.54371 .65362 L
.54519 .65054 L
.54988 .64083 L
.55342 .63346 L
.55453 .63112 L
.55915 .62141 L
.56313 .61297 L
.56372 .61169 L
.56826 .60198 L
.57278 .59227 L
.57284 .59212 L
.57724 .58256 L
.58169 .57284 L
.58256 .57094 L
.58609 .56313 L
.59048 .55342 L
.59227 .54943 L
.59481 .54371 L
.59914 .53399 L
.60198 .52759 L
.60343 .52428 L
.6077 .51457 L
.61169 .50543 L
.61194 .50486 L
.61614 .49514 L
.62034 .48543 L
.62141 .48295 L
.62448 .47572 L
.62863 .46601 L
.63112 .46015 L
.63273 .45629 L
.63683 .44658 L
.64083 .43705 L
.6409 .43687 L
.64493 .42716 L
.64897 .41744 L
.65054 .41363 L
.65295 .40773 L
.65695 .39802 L
.66026 .38992 L
.66091 .38831 L
.66484 .37859 L
.66877 .36888 L
.66997 .36591 L
.67265 .35917 L
.67655 .34946 L
.67968 .34161 L
.68041 .33974 L
.68425 .33003 L
.68809 .32032 L
.68939 .31701 L
.69188 .31061 L
.69569 .30089 L
.69911 .29213 L
.69947 .29118 L
.70321 .28147 L
.70697 .27176 L
.70882 .26696 L
.71068 .26204 L
.7144 .25233 L
.71811 .24262 L
.71853 .24151 L
.72176 .23291 L
.72545 .22319 L
.72824 .21578 L
.72909 .21348 L
.73272 .20377 L
.73636 .19406 L
.73796 .18978 L
.73995 .18434 L
.74355 .17463 L
.74715 .16492 L
.74767 .1635 L
.75068 .15521 L
.75426 .14549 L
.75738 .13695 L
.7578 .13578 L
.76131 .12607 L
.76485 .11636 L
.76709 .11014 L
.76833 .10664 L
.77182 .09693 L
.77532 .08722 L
.77681 .08306 L
.77876 .07751 L
.78222 .06779 L
.78569 .05808 L
.78652 .05573 L
.78908 .04837 L
.79252 .03866 L
.79595 .02894 L
.79623 .02813 L
.79931 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.34065 .98077 m
.34944 .97106 L
.34946 .97104 L
.35783 .96134 L
.35917 .95975 L
.36587 .95163 L
.36888 .94789 L
.37361 .94192 L
.37859 .93547 L
.38108 .93221 L
.38831 .92252 L
.38833 .92249 L
.39537 .91278 L
.39802 .90905 L
.40222 .90307 L
.40773 .89508 L
.40891 .89336 L
.41544 .88364 L
.41744 .88062 L
.42183 .87393 L
.42716 .86569 L
.4281 .86422 L
.43424 .85451 L
.43687 .8503 L
.44027 .84479 L
.44621 .83508 L
.44658 .83446 L
.45204 .82537 L
.45629 .81818 L
.45778 .81566 L
.46343 .80594 L
.46601 .80148 L
.46901 .79623 L
.47451 .78652 L
.47572 .78436 L
.47993 .77681 L
.48529 .76709 L
.48543 .76684 L
.49058 .75738 L
.49514 .74892 L
.49581 .74767 L
.50098 .73796 L
.50486 .73061 L
.50609 .72824 L
.51115 .71853 L
.51457 .71191 L
.51615 .70882 L
.52111 .69911 L
.52428 .69285 L
.52601 .68939 L
Mistroke
.53088 .67968 L
.53399 .67341 L
.53569 .66997 L
.54046 .66026 L
.54371 .65362 L
.54519 .65054 L
.54988 .64083 L
.55342 .63346 L
.55453 .63112 L
.55915 .62141 L
.56313 .61297 L
.56372 .61169 L
.56826 .60198 L
.57278 .59227 L
.57284 .59212 L
.57724 .58256 L
.58169 .57284 L
.58256 .57094 L
.58609 .56313 L
.59048 .55342 L
.59227 .54943 L
.59481 .54371 L
.59914 .53399 L
.60198 .52759 L
.60343 .52428 L
.6077 .51457 L
.61169 .50543 L
.61194 .50486 L
.61614 .49514 L
.62034 .48543 L
.62141 .48295 L
.62448 .47572 L
.62863 .46601 L
.63112 .46015 L
.63273 .45629 L
.63683 .44658 L
.64083 .43705 L
.6409 .43687 L
.64493 .42716 L
.64897 .41744 L
.65054 .41363 L
.65295 .40773 L
.65695 .39802 L
.66026 .38992 L
.66091 .38831 L
.66484 .37859 L
.66877 .36888 L
.66997 .36591 L
.67265 .35917 L
.67655 .34946 L
Mistroke
.67968 .34161 L
.68041 .33974 L
.68425 .33003 L
.68809 .32032 L
.68939 .31701 L
.69188 .31061 L
.69569 .30089 L
.69911 .29213 L
.69947 .29118 L
.70321 .28147 L
.70697 .27176 L
.70882 .26696 L
.71068 .26204 L
.7144 .25233 L
.71811 .24262 L
.71853 .24151 L
.72176 .23291 L
.72545 .22319 L
.72824 .21578 L
.72909 .21348 L
.73272 .20377 L
.73636 .19406 L
.73796 .18978 L
.73995 .18434 L
.74355 .17463 L
.74715 .16492 L
.74767 .1635 L
.75068 .15521 L
.75426 .14549 L
.75738 .13695 L
.7578 .13578 L
.76131 .12607 L
.76485 .11636 L
.76709 .11014 L
.76833 .10664 L
.77182 .09693 L
.77532 .08722 L
.77681 .08306 L
.77876 .07751 L
.78222 .06779 L
.78569 .05808 L
.78652 .05573 L
.78908 .04837 L
.79252 .03866 L
.79595 .02894 L
.79623 .02813 L
.79931 .01923 L
Mfstroke
.3 g
.37236 .98077 m
.37859 .97195 L
.3792 .97106 L
.38591 .96134 L
.38831 .95784 L
.39249 .95163 L
.39802 .94338 L
.39898 .94192 L
.40534 .93221 L
.40773 .92853 L
.41158 .92249 L
.41744 .9133 L
.41777 .91278 L
.4238 .90307 L
.42716 .89765 L
.42975 .89336 L
.43566 .88364 L
.43687 .88163 L
.44141 .87393 L
.44658 .86521 L
.44715 .86422 L
.45276 .85451 L
.45629 .84839 L
.45831 .84479 L
.46381 .83508 L
.46601 .83119 L
.4692 .82537 L
.47459 .81566 L
.47572 .81362 L
.47984 .80594 L
.48513 .79623 L
.48543 .79567 L
.49025 .78652 L
.49514 .77735 L
.49542 .77681 L
.50044 .76709 L
.50486 .75865 L
.50549 .75738 L
.51043 .74767 L
.51457 .73961 L
.51537 .73796 L
.52022 .72824 L
.52428 .7202 L
.52508 .71853 L
.52984 .70882 L
.53399 .70045 L
.53462 .69911 L
.5393 .68939 L
.54371 .68036 L
.54402 .67968 L
.54859 .66997 L
.55326 .66026 L
.55342 .65993 L
.55774 .65054 L
.56234 .64083 L
.56313 .63915 L
.56676 .63112 L
.57129 .62141 L
.57284 .61805 L
.57565 .61169 L
.5801 .60198 L
.58256 .59662 L
.58443 .59227 L
.58879 .58256 L
.59227 .57487 L
.59312 .57284 L
.59737 .56313 L
.60171 .55342 L
.60198 .55281 L
.60585 .54371 L
.61013 .53399 L
.61169 .53042 L
.61423 .52428 L
.61844 .51457 L
.62141 .50773 L
.62256 .50486 L
.62665 .49514 L
.63083 .48543 L
.63112 .48474 L
.63478 .47572 L
.6389 .46601 L
.64083 .46144 L
.64285 .45629 L
.64688 .44658 L
.65054 .43785 L
.65091 .43687 L
.65479 .42716 L
.65882 .41744 L
.66026 .41395 L
.66264 .40773 L
.66659 .39802 L
.66997 .38977 L
.6705 .38831 L
.6743 .37859 L
.67824 .36888 L
.67968 .36529 L
.68196 .35917 L
.68582 .34946 L
.68939 .34054 L
.68967 .33974 L
.69335 .33003 L
.6972 .32032 L
.69911 .31549 L
.70086 .31061 L
.70461 .30089 L
.70843 .29118 L
.70882 .29018 L
.71198 .28147 L
.71575 .27176 L
.71853 .26458 L
.7194 .26204 L
.723 .25233 L
.72675 .24262 L
.72824 .23871 L
.73026 .23291 L
.73391 .22319 L
.73761 .21348 L
.73796 .21257 L
.74104 .20377 L
.74469 .19406 L
.74767 .18615 L
.74825 .18434 L
.75172 .17463 L
.75535 .16492 L
.75738 .15947 L
.75878 .15521 L
.76229 .14549 L
.7659 .13578 L
.76709 .13253 L
.76924 .12607 L
.77276 .11636 L
.77633 .10664 L
.77681 .10534 L
.7796 .09693 L
.78312 .08722 L
.78652 .07788 L
.78663 .07751 L
.78987 .06779 L
.79338 .05808 L
.79623 .05016 L
.79677 .04837 L
.80005 .03866 L
.80353 .02894 L
.80594 .02221 L
.80684 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.37236 .98077 m
.37859 .97195 L
.3792 .97106 L
.38591 .96134 L
.38831 .95784 L
.39249 .95163 L
.39802 .94338 L
.39898 .94192 L
.40534 .93221 L
.40773 .92853 L
.41158 .92249 L
.41744 .9133 L
.41777 .91278 L
.4238 .90307 L
.42716 .89765 L
.42975 .89336 L
.43566 .88364 L
.43687 .88163 L
.44141 .87393 L
.44658 .86521 L
.44715 .86422 L
.45276 .85451 L
.45629 .84839 L
.45831 .84479 L
.46381 .83508 L
.46601 .83119 L
.4692 .82537 L
.47459 .81566 L
.47572 .81362 L
.47984 .80594 L
.48513 .79623 L
.48543 .79567 L
.49025 .78652 L
.49514 .77735 L
.49542 .77681 L
.50044 .76709 L
.50486 .75865 L
.50549 .75738 L
.51043 .74767 L
.51457 .73961 L
.51537 .73796 L
.52022 .72824 L
.52428 .7202 L
.52508 .71853 L
.52984 .70882 L
.53399 .70045 L
.53462 .69911 L
.5393 .68939 L
.54371 .68036 L
.54402 .67968 L
Mistroke
.54859 .66997 L
.55326 .66026 L
.55342 .65993 L
.55774 .65054 L
.56234 .64083 L
.56313 .63915 L
.56676 .63112 L
.57129 .62141 L
.57284 .61805 L
.57565 .61169 L
.5801 .60198 L
.58256 .59662 L
.58443 .59227 L
.58879 .58256 L
.59227 .57487 L
.59312 .57284 L
.59737 .56313 L
.60171 .55342 L
.60198 .55281 L
.60585 .54371 L
.61013 .53399 L
.61169 .53042 L
.61423 .52428 L
.61844 .51457 L
.62141 .50773 L
.62256 .50486 L
.62665 .49514 L
.63083 .48543 L
.63112 .48474 L
.63478 .47572 L
.6389 .46601 L
.64083 .46144 L
.64285 .45629 L
.64688 .44658 L
.65054 .43785 L
.65091 .43687 L
.65479 .42716 L
.65882 .41744 L
.66026 .41395 L
.66264 .40773 L
.66659 .39802 L
.66997 .38977 L
.6705 .38831 L
.6743 .37859 L
.67824 .36888 L
.67968 .36529 L
.68196 .35917 L
.68582 .34946 L
.68939 .34054 L
.68967 .33974 L
Mistroke
.69335 .33003 L
.6972 .32032 L
.69911 .31549 L
.70086 .31061 L
.70461 .30089 L
.70843 .29118 L
.70882 .29018 L
.71198 .28147 L
.71575 .27176 L
.71853 .26458 L
.7194 .26204 L
.723 .25233 L
.72675 .24262 L
.72824 .23871 L
.73026 .23291 L
.73391 .22319 L
.73761 .21348 L
.73796 .21257 L
.74104 .20377 L
.74469 .19406 L
.74767 .18615 L
.74825 .18434 L
.75172 .17463 L
.75535 .16492 L
.75738 .15947 L
.75878 .15521 L
.76229 .14549 L
.7659 .13578 L
.76709 .13253 L
.76924 .12607 L
.77276 .11636 L
.77633 .10664 L
.77681 .10534 L
.7796 .09693 L
.78312 .08722 L
.78652 .07788 L
.78663 .07751 L
.78987 .06779 L
.79338 .05808 L
.79623 .05016 L
.79677 .04837 L
.80005 .03866 L
.80353 .02894 L
.80594 .02221 L
.80684 .01923 L
Mfstroke
.4 g
.44458 .98077 m
.44658 .97746 L
.4508 .97106 L
.45629 .96217 L
.45681 .96134 L
.46289 .95163 L
.46601 .94633 L
.46871 .94192 L
.47449 .93221 L
.47572 .93001 L
.48019 .92249 L
.48543 .91322 L
.48569 .91278 L
.4913 .90307 L
.49514 .896 L
.49664 .89336 L
.50208 .88364 L
.50486 .87836 L
.5073 .87393 L
.51257 .86422 L
.51457 .86028 L
.5177 .85451 L
.52281 .84479 L
.52428 .84181 L
.52784 .83508 L
.53282 .82537 L
.53399 .82293 L
.53777 .81566 L
.54264 .80594 L
.54371 .80366 L
.54749 .79623 L
.55227 .78652 L
.55342 .78402 L
.55702 .77681 L
.56173 .76709 L
.56313 .764 L
.56638 .75738 L
.57104 .74767 L
.57284 .74362 L
.57558 .73796 L
.58018 .72824 L
.58256 .72288 L
.58462 .71853 L
.58918 .70882 L
.59227 .70179 L
.59352 .69911 L
.59804 .68939 L
.60198 .68035 L
.60229 .67968 L
.60675 .66997 L
.61102 .66026 L
.61169 .65858 L
.61534 .65054 L
.61963 .64083 L
.62141 .63648 L
.6238 .63112 L
.62809 .62141 L
.63112 .61404 L
.63215 .61169 L
.63642 .60198 L
.64046 .59227 L
.64083 .59128 L
.64463 .58256 L
.64874 .57284 L
.65054 .56821 L
.65272 .56313 L
.65686 .55342 L
.66026 .54482 L
.66073 .54371 L
.66484 .53399 L
.6688 .52428 L
.66997 .52113 L
.67271 .51457 L
.67674 .50486 L
.67968 .49712 L
.6805 .49514 L
.68451 .48543 L
.68836 .47572 L
.68939 .47282 L
.69218 .46601 L
.69611 .45629 L
.69911 .44822 L
.69977 .44658 L
.7037 .43687 L
.70748 .42716 L
.70882 .42334 L
.71117 .41744 L
.71503 .40773 L
.71853 .39815 L
.71858 .39802 L
.72243 .38831 L
.72618 .37859 L
.72824 .37269 L
.72973 .36888 L
.73353 .35917 L
.73713 .34946 L
.73796 .34694 L
.74074 .33974 L
.74448 .33003 L
.74767 .32091 L
.74789 .32032 L
.75162 .31061 L
.75527 .30089 L
.75738 .2946 L
.75868 .29118 L
.76237 .28147 L
.7659 .27176 L
.76709 .26803 L
.76934 .26204 L
.77299 .25233 L
.77637 .24262 L
.77681 .24118 L
.77989 .23291 L
.78348 .22319 L
.78652 .21406 L
.78673 .21348 L
.79032 .20377 L
.79385 .19406 L
.79623 .18668 L
.79708 .18434 L
.80064 .17463 L
.8041 .16492 L
.80594 .15904 L
.80733 .15521 L
.81086 .14549 L
.81425 .13578 L
.81566 .13113 L
.81747 .12607 L
.82097 .11636 L
.82429 .10664 L
.82537 .10297 L
.82752 .09693 L
.83099 .08722 L
.83424 .07751 L
.83508 .07456 L
.83747 .06779 L
.84091 .05808 L
.8441 .04837 L
.84479 .04589 L
.84733 .03866 L
.85073 .02894 L
.85389 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.44458 .98077 m
.44658 .97746 L
.4508 .97106 L
.45629 .96217 L
.45681 .96134 L
.46289 .95163 L
.46601 .94633 L
.46871 .94192 L
.47449 .93221 L
.47572 .93001 L
.48019 .92249 L
.48543 .91322 L
.48569 .91278 L
.4913 .90307 L
.49514 .896 L
.49664 .89336 L
.50208 .88364 L
.50486 .87836 L
.5073 .87393 L
.51257 .86422 L
.51457 .86028 L
.5177 .85451 L
.52281 .84479 L
.52428 .84181 L
.52784 .83508 L
.53282 .82537 L
.53399 .82293 L
.53777 .81566 L
.54264 .80594 L
.54371 .80366 L
.54749 .79623 L
.55227 .78652 L
.55342 .78402 L
.55702 .77681 L
.56173 .76709 L
.56313 .764 L
.56638 .75738 L
.57104 .74767 L
.57284 .74362 L
.57558 .73796 L
.58018 .72824 L
.58256 .72288 L
.58462 .71853 L
.58918 .70882 L
.59227 .70179 L
.59352 .69911 L
.59804 .68939 L
.60198 .68035 L
.60229 .67968 L
.60675 .66997 L
Mistroke
.61102 .66026 L
.61169 .65858 L
.61534 .65054 L
.61963 .64083 L
.62141 .63648 L
.6238 .63112 L
.62809 .62141 L
.63112 .61404 L
.63215 .61169 L
.63642 .60198 L
.64046 .59227 L
.64083 .59128 L
.64463 .58256 L
.64874 .57284 L
.65054 .56821 L
.65272 .56313 L
.65686 .55342 L
.66026 .54482 L
.66073 .54371 L
.66484 .53399 L
.6688 .52428 L
.66997 .52113 L
.67271 .51457 L
.67674 .50486 L
.67968 .49712 L
.6805 .49514 L
.68451 .48543 L
.68836 .47572 L
.68939 .47282 L
.69218 .46601 L
.69611 .45629 L
.69911 .44822 L
.69977 .44658 L
.7037 .43687 L
.70748 .42716 L
.70882 .42334 L
.71117 .41744 L
.71503 .40773 L
.71853 .39815 L
.71858 .39802 L
.72243 .38831 L
.72618 .37859 L
.72824 .37269 L
.72973 .36888 L
.73353 .35917 L
.73713 .34946 L
.73796 .34694 L
.74074 .33974 L
.74448 .33003 L
.74767 .32091 L
Mistroke
.74789 .32032 L
.75162 .31061 L
.75527 .30089 L
.75738 .2946 L
.75868 .29118 L
.76237 .28147 L
.7659 .27176 L
.76709 .26803 L
.76934 .26204 L
.77299 .25233 L
.77637 .24262 L
.77681 .24118 L
.77989 .23291 L
.78348 .22319 L
.78652 .21406 L
.78673 .21348 L
.79032 .20377 L
.79385 .19406 L
.79623 .18668 L
.79708 .18434 L
.80064 .17463 L
.8041 .16492 L
.80594 .15904 L
.80733 .15521 L
.81086 .14549 L
.81425 .13578 L
.81566 .13113 L
.81747 .12607 L
.82097 .11636 L
.82429 .10664 L
.82537 .10297 L
.82752 .09693 L
.83099 .08722 L
.83424 .07751 L
.83508 .07456 L
.83747 .06779 L
.84091 .05808 L
.8441 .04837 L
.84479 .04589 L
.84733 .03866 L
.85073 .02894 L
.85389 .01923 L
Mfstroke
.5 g
.46324 .98077 m
.46601 .97603 L
.46893 .97106 L
.47453 .96134 L
.47572 .95926 L
.48007 .95163 L
.48543 .94205 L
.4855 .94192 L
.4909 .93221 L
.49514 .92443 L
.4962 .92249 L
.50146 .91278 L
.50486 .9064 L
.50663 .90307 L
.51177 .89336 L
.51457 .88797 L
.51683 .88364 L
.52185 .87393 L
.52428 .86916 L
.52681 .86422 L
.53173 .85451 L
.53399 .84997 L
.53659 .84479 L
.54142 .83508 L
.54371 .8304 L
.54619 .82537 L
.55093 .81566 L
.55342 .81047 L
.55561 .80594 L
.56028 .79623 L
.56313 .79018 L
.56487 .78652 L
.56947 .77681 L
.57284 .76954 L
.57399 .76709 L
.57851 .75738 L
.58256 .74856 L
.58296 .74767 L
.58743 .73796 L
.59182 .72824 L
.59227 .72723 L
.59621 .71853 L
.60055 .70882 L
.60198 .70557 L
.60486 .69911 L
.60916 .68939 L
.61169 .68358 L
.61341 .67968 L
.61766 .66997 L
.62141 .66126 L
.62184 .66026 L
.62605 .65054 L
.63019 .64083 L
.63112 .63863 L
.63433 .63112 L
.63845 .62141 L
.64083 .61568 L
.64251 .61169 L
.6466 .60198 L
.65054 .59242 L
.65061 .59227 L
.65465 .58256 L
.65864 .57284 L
.66026 .56885 L
.66261 .56313 L
.66658 .55342 L
.66997 .54498 L
.67049 .54371 L
.67443 .53399 L
.67832 .52428 L
.67968 .52081 L
.68218 .51457 L
.68606 .50486 L
.68939 .49635 L
.68987 .49514 L
.69372 .48543 L
.69752 .47572 L
.69911 .4716 L
.70129 .46601 L
.70509 .45629 L
.70881 .44658 L
.70882 .44655 L
.71257 .43687 L
.7163 .42716 L
.71853 .42122 L
.71998 .41744 L
.7237 .40773 L
.72736 .39802 L
.72824 .39561 L
.73101 .38831 L
.73468 .37859 L
.73796 .36972 L
.73827 .36888 L
.74191 .35917 L
.74553 .34946 L
.74767 .34356 L
.74908 .33974 L
.75269 .33003 L
.75624 .32032 L
.75738 .31713 L
.75977 .31061 L
.76334 .30089 L
.76683 .29118 L
.76709 .29042 L
.77035 .28147 L
.77387 .27176 L
.77681 .26345 L
.77731 .26204 L
.78081 .25233 L
.78429 .24262 L
.78652 .23621 L
.78769 .23291 L
.79116 .22319 L
.79459 .21348 L
.79623 .20871 L
.79797 .20377 L
.80141 .19406 L
.80479 .18434 L
.80594 .18095 L
.80815 .17463 L
.81156 .16492 L
.8149 .15521 L
.81566 .15293 L
.81824 .14549 L
.82161 .13578 L
.82491 .12607 L
.82537 .12466 L
.82823 .11636 L
.83157 .10664 L
.83482 .09693 L
.83508 .09614 L
.83812 .08722 L
.84144 .07751 L
.84466 .06779 L
.84479 .06737 L
.84793 .05808 L
.85122 .04837 L
.85441 .03866 L
.85451 .03835 L
.85766 .02894 L
.86092 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.46324 .98077 m
.46601 .97603 L
.46893 .97106 L
.47453 .96134 L
.47572 .95926 L
.48007 .95163 L
.48543 .94205 L
.4855 .94192 L
.4909 .93221 L
.49514 .92443 L
.4962 .92249 L
.50146 .91278 L
.50486 .9064 L
.50663 .90307 L
.51177 .89336 L
.51457 .88797 L
.51683 .88364 L
.52185 .87393 L
.52428 .86916 L
.52681 .86422 L
.53173 .85451 L
.53399 .84997 L
.53659 .84479 L
.54142 .83508 L
.54371 .8304 L
.54619 .82537 L
.55093 .81566 L
.55342 .81047 L
.55561 .80594 L
.56028 .79623 L
.56313 .79018 L
.56487 .78652 L
.56947 .77681 L
.57284 .76954 L
.57399 .76709 L
.57851 .75738 L
.58256 .74856 L
.58296 .74767 L
.58743 .73796 L
.59182 .72824 L
.59227 .72723 L
.59621 .71853 L
.60055 .70882 L
.60198 .70557 L
.60486 .69911 L
.60916 .68939 L
.61169 .68358 L
.61341 .67968 L
.61766 .66997 L
.62141 .66126 L
Mistroke
.62184 .66026 L
.62605 .65054 L
.63019 .64083 L
.63112 .63863 L
.63433 .63112 L
.63845 .62141 L
.64083 .61568 L
.64251 .61169 L
.6466 .60198 L
.65054 .59242 L
.65061 .59227 L
.65465 .58256 L
.65864 .57284 L
.66026 .56885 L
.66261 .56313 L
.66658 .55342 L
.66997 .54498 L
.67049 .54371 L
.67443 .53399 L
.67832 .52428 L
.67968 .52081 L
.68218 .51457 L
.68606 .50486 L
.68939 .49635 L
.68987 .49514 L
.69372 .48543 L
.69752 .47572 L
.69911 .4716 L
.70129 .46601 L
.70509 .45629 L
.70881 .44658 L
.70882 .44655 L
.71257 .43687 L
.7163 .42716 L
.71853 .42122 L
.71998 .41744 L
.7237 .40773 L
.72736 .39802 L
.72824 .39561 L
.73101 .38831 L
.73468 .37859 L
.73796 .36972 L
.73827 .36888 L
.74191 .35917 L
.74553 .34946 L
.74767 .34356 L
.74908 .33974 L
.75269 .33003 L
.75624 .32032 L
.75738 .31713 L
Mistroke
.75977 .31061 L
.76334 .30089 L
.76683 .29118 L
.76709 .29042 L
.77035 .28147 L
.77387 .27176 L
.77681 .26345 L
.77731 .26204 L
.78081 .25233 L
.78429 .24262 L
.78652 .23621 L
.78769 .23291 L
.79116 .22319 L
.79459 .21348 L
.79623 .20871 L
.79797 .20377 L
.80141 .19406 L
.80479 .18434 L
.80594 .18095 L
.80815 .17463 L
.81156 .16492 L
.8149 .15521 L
.81566 .15293 L
.81824 .14549 L
.82161 .13578 L
.82491 .12607 L
.82537 .12466 L
.82823 .11636 L
.83157 .10664 L
.83482 .09693 L
.83508 .09614 L
.83812 .08722 L
.84144 .07751 L
.84466 .06779 L
.84479 .06737 L
.84793 .05808 L
.85122 .04837 L
.85441 .03866 L
.85451 .03835 L
.85766 .02894 L
.86092 .01923 L
Mfstroke
.6 g
.4785 .98077 m
.48388 .97106 L
.48543 .96822 L
.48918 .96134 L
.49443 .95163 L
.49514 .9503 L
.49961 .94192 L
.50474 .93221 L
.50486 .93199 L
.50981 .92249 L
.51457 .9133 L
.51483 .91278 L
.5198 .90307 L
.52428 .89423 L
.52472 .89336 L
.52959 .88364 L
.53399 .8748 L
.53442 .87393 L
.5392 .86422 L
.54371 .855 L
.54394 .85451 L
.54864 .84479 L
.55331 .83508 L
.55342 .83485 L
.55792 .82537 L
.56252 .81566 L
.56313 .81435 L
.56706 .80594 L
.57158 .79623 L
.57284 .79351 L
.57605 .78652 L
.58051 .77681 L
.58256 .77233 L
.58492 .76709 L
.58931 .75738 L
.59227 .75081 L
.59367 .74767 L
.598 .73796 L
.60198 .72897 L
.6023 .72824 L
.60656 .71853 L
.61082 .70882 L
.61169 .70681 L
.61502 .69911 L
.61923 .68939 L
.62141 .68433 L
.62338 .67968 L
.62753 .66997 L
.63112 .66153 L
.63165 .66026 L
.63574 .65054 L
.63983 .64083 L
.64083 .63843 L
.64386 .63112 L
.6479 .62141 L
.65054 .61502 L
.6519 .61169 L
.65589 .60198 L
.65986 .59227 L
.66026 .59131 L
.66379 .58256 L
.66773 .57284 L
.66997 .56729 L
.67162 .56313 L
.67551 .55342 L
.6794 .54371 L
.67968 .54299 L
.68322 .53399 L
.68707 .52428 L
.68939 .51839 L
.69088 .51457 L
.69468 .50486 L
.69847 .49514 L
.69911 .49351 L
.70221 .48543 L
.70598 .47572 L
.70882 .46834 L
.7097 .46601 L
.71341 .45629 L
.71713 .44658 L
.71853 .44289 L
.72079 .43687 L
.72447 .42716 L
.72814 .41744 L
.72824 .41716 L
.73175 .40773 L
.7354 .39802 L
.73796 .39116 L
.739 .38831 L
.74259 .37859 L
.7462 .36888 L
.74767 .36488 L
.74974 .35917 L
.75331 .34946 L
.75687 .33974 L
.75738 .33834 L
.76037 .33003 L
.76391 .32032 L
.76709 .31153 L
.76742 .31061 L
.77089 .30089 L
.77439 .29118 L
.77681 .28445 L
.77785 .28147 L
.7813 .27176 L
.78477 .26204 L
.78652 .25711 L
.78818 .25233 L
.79161 .24262 L
.79504 .23291 L
.79623 .22951 L
.79841 .22319 L
.80181 .21348 L
.80521 .20377 L
.80594 .20166 L
.80854 .19406 L
.81192 .18434 L
.81528 .17463 L
.81566 .17355 L
.81858 .16492 L
.82193 .15521 L
.82526 .14549 L
.82537 .14518 L
.82853 .13578 L
.83185 .12607 L
.83508 .11657 L
.83515 .11636 L
.83839 .10664 L
.84169 .09693 L
.84479 .08771 L
.84495 .08722 L
.84816 .07751 L
.85144 .06779 L
.85451 .0586 L
.85467 .05808 L
.85786 .04837 L
.8611 .03866 L
.86422 .02925 L
.86432 .02894 L
.86747 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.4785 .98077 m
.48388 .97106 L
.48543 .96822 L
.48918 .96134 L
.49443 .95163 L
.49514 .9503 L
.49961 .94192 L
.50474 .93221 L
.50486 .93199 L
.50981 .92249 L
.51457 .9133 L
.51483 .91278 L
.5198 .90307 L
.52428 .89423 L
.52472 .89336 L
.52959 .88364 L
.53399 .8748 L
.53442 .87393 L
.5392 .86422 L
.54371 .855 L
.54394 .85451 L
.54864 .84479 L
.55331 .83508 L
.55342 .83485 L
.55792 .82537 L
.56252 .81566 L
.56313 .81435 L
.56706 .80594 L
.57158 .79623 L
.57284 .79351 L
.57605 .78652 L
.58051 .77681 L
.58256 .77233 L
.58492 .76709 L
.58931 .75738 L
.59227 .75081 L
.59367 .74767 L
.598 .73796 L
.60198 .72897 L
.6023 .72824 L
.60656 .71853 L
.61082 .70882 L
.61169 .70681 L
.61502 .69911 L
.61923 .68939 L
.62141 .68433 L
.62338 .67968 L
.62753 .66997 L
.63112 .66153 L
.63165 .66026 L
Mistroke
.63574 .65054 L
.63983 .64083 L
.64083 .63843 L
.64386 .63112 L
.6479 .62141 L
.65054 .61502 L
.6519 .61169 L
.65589 .60198 L
.65986 .59227 L
.66026 .59131 L
.66379 .58256 L
.66773 .57284 L
.66997 .56729 L
.67162 .56313 L
.67551 .55342 L
.6794 .54371 L
.67968 .54299 L
.68322 .53399 L
.68707 .52428 L
.68939 .51839 L
.69088 .51457 L
.69468 .50486 L
.69847 .49514 L
.69911 .49351 L
.70221 .48543 L
.70598 .47572 L
.70882 .46834 L
.7097 .46601 L
.71341 .45629 L
.71713 .44658 L
.71853 .44289 L
.72079 .43687 L
.72447 .42716 L
.72814 .41744 L
.72824 .41716 L
.73175 .40773 L
.7354 .39802 L
.73796 .39116 L
.739 .38831 L
.74259 .37859 L
.7462 .36888 L
.74767 .36488 L
.74974 .35917 L
.75331 .34946 L
.75687 .33974 L
.75738 .33834 L
.76037 .33003 L
.76391 .32032 L
.76709 .31153 L
.76742 .31061 L
Mistroke
.77089 .30089 L
.77439 .29118 L
.77681 .28445 L
.77785 .28147 L
.7813 .27176 L
.78477 .26204 L
.78652 .25711 L
.78818 .25233 L
.79161 .24262 L
.79504 .23291 L
.79623 .22951 L
.79841 .22319 L
.80181 .21348 L
.80521 .20377 L
.80594 .20166 L
.80854 .19406 L
.81192 .18434 L
.81528 .17463 L
.81566 .17355 L
.81858 .16492 L
.82193 .15521 L
.82526 .14549 L
.82537 .14518 L
.82853 .13578 L
.83185 .12607 L
.83508 .11657 L
.83515 .11636 L
.83839 .10664 L
.84169 .09693 L
.84479 .08771 L
.84495 .08722 L
.84816 .07751 L
.85144 .06779 L
.85451 .0586 L
.85467 .05808 L
.85786 .04837 L
.8611 .03866 L
.86422 .02925 L
.86432 .02894 L
.86747 .01923 L
Mfstroke
.7 g
.49406 .98077 m
.49514 .97874 L
.49909 .97106 L
.50418 .96134 L
.50486 .96004 L
.5091 .95163 L
.5141 .94192 L
.51457 .94099 L
.51892 .93221 L
.52383 .92249 L
.52428 .92159 L
.52856 .91278 L
.53339 .90307 L
.53399 .90184 L
.53804 .89336 L
.54278 .88364 L
.54371 .88174 L
.54736 .87393 L
.55203 .86422 L
.55342 .8613 L
.55653 .85451 L
.56112 .84479 L
.56313 .84053 L
.56557 .83508 L
.57008 .82537 L
.57284 .81943 L
.57449 .81566 L
.57891 .80594 L
.58256 .79801 L
.58331 .79623 L
.58762 .78652 L
.59202 .77681 L
.59227 .77626 L
.59622 .76709 L
.60056 .75738 L
.60198 .75419 L
.60472 .74767 L
.60899 .73796 L
.61169 .73181 L
.61315 .72824 L
.61731 .71853 L
.62141 .70912 L
.62153 .70882 L
.62555 .69911 L
.62972 .68939 L
.63112 .68612 L
.6337 .67968 L
.63781 .66997 L
.64083 .66282 L
.64182 .66026 L
.6458 .65054 L
.64988 .64083 L
.65054 .63923 L
.65373 .63112 L
.65775 .62141 L
.66026 .61533 L
.66163 .61169 L
.66553 .60198 L
.66952 .59227 L
.66997 .59116 L
.67326 .58256 L
.67719 .57284 L
.67968 .56668 L
.68098 .56313 L
.68479 .55342 L
.68868 .54371 L
.68939 .54192 L
.69234 .53399 L
.69618 .52428 L
.69911 .51688 L
.69992 .51457 L
.7036 .50486 L
.70742 .49514 L
.70882 .49156 L
.71101 .48543 L
.71474 .47572 L
.71852 .46601 L
.71853 .46597 L
.72202 .45629 L
.72575 .44658 L
.72824 .44009 L
.72934 .43687 L
.73293 .42716 L
.73663 .41744 L
.73796 .41395 L
.74009 .40773 L
.74372 .39802 L
.74738 .38831 L
.74767 .38754 L
.75077 .37859 L
.75439 .36888 L
.75738 .36086 L
.75792 .35917 L
.76134 .34946 L
.76494 .33974 L
.76709 .33392 L
.76835 .33003 L
.77181 .32032 L
.77539 .31061 L
.77681 .30672 L
.7787 .30089 L
.78218 .29118 L
.78572 .28147 L
.78652 .27926 L
.78897 .27176 L
.79244 .26204 L
.79595 .25233 L
.79623 .25154 L
.79914 .24262 L
.80261 .23291 L
.80594 .22357 L
.80605 .22319 L
.80923 .21348 L
.81267 .20377 L
.81566 .19535 L
.81603 .19406 L
.81922 .18434 L
.82265 .17463 L
.82537 .16687 L
.82593 .16492 L
.82913 .15521 L
.83253 .14549 L
.83508 .13815 L
.83576 .13578 L
.83894 .12607 L
.84232 .11636 L
.84479 .10919 L
.84551 .10664 L
.84867 .09693 L
.85203 .08722 L
.85451 .07998 L
.8552 .07751 L
.85832 .06779 L
.86165 .05808 L
.86422 .05053 L
.86481 .04837 L
.86789 .03866 L
.87119 .02894 L
.87393 .02086 L
.87436 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.49406 .98077 m
.49514 .97874 L
.49909 .97106 L
.50418 .96134 L
.50486 .96004 L
.5091 .95163 L
.5141 .94192 L
.51457 .94099 L
.51892 .93221 L
.52383 .92249 L
.52428 .92159 L
.52856 .91278 L
.53339 .90307 L
.53399 .90184 L
.53804 .89336 L
.54278 .88364 L
.54371 .88174 L
.54736 .87393 L
.55203 .86422 L
.55342 .8613 L
.55653 .85451 L
.56112 .84479 L
.56313 .84053 L
.56557 .83508 L
.57008 .82537 L
.57284 .81943 L
.57449 .81566 L
.57891 .80594 L
.58256 .79801 L
.58331 .79623 L
.58762 .78652 L
.59202 .77681 L
.59227 .77626 L
.59622 .76709 L
.60056 .75738 L
.60198 .75419 L
.60472 .74767 L
.60899 .73796 L
.61169 .73181 L
.61315 .72824 L
.61731 .71853 L
.62141 .70912 L
.62153 .70882 L
.62555 .69911 L
.62972 .68939 L
.63112 .68612 L
.6337 .67968 L
.63781 .66997 L
.64083 .66282 L
.64182 .66026 L
Mistroke
.6458 .65054 L
.64988 .64083 L
.65054 .63923 L
.65373 .63112 L
.65775 .62141 L
.66026 .61533 L
.66163 .61169 L
.66553 .60198 L
.66952 .59227 L
.66997 .59116 L
.67326 .58256 L
.67719 .57284 L
.67968 .56668 L
.68098 .56313 L
.68479 .55342 L
.68868 .54371 L
.68939 .54192 L
.69234 .53399 L
.69618 .52428 L
.69911 .51688 L
.69992 .51457 L
.7036 .50486 L
.70742 .49514 L
.70882 .49156 L
.71101 .48543 L
.71474 .47572 L
.71852 .46601 L
.71853 .46597 L
.72202 .45629 L
.72575 .44658 L
.72824 .44009 L
.72934 .43687 L
.73293 .42716 L
.73663 .41744 L
.73796 .41395 L
.74009 .40773 L
.74372 .39802 L
.74738 .38831 L
.74767 .38754 L
.75077 .37859 L
.75439 .36888 L
.75738 .36086 L
.75792 .35917 L
.76134 .34946 L
.76494 .33974 L
.76709 .33392 L
.76835 .33003 L
.77181 .32032 L
.77539 .31061 L
.77681 .30672 L
Mistroke
.7787 .30089 L
.78218 .29118 L
.78572 .28147 L
.78652 .27926 L
.78897 .27176 L
.79244 .26204 L
.79595 .25233 L
.79623 .25154 L
.79914 .24262 L
.80261 .23291 L
.80594 .22357 L
.80605 .22319 L
.80923 .21348 L
.81267 .20377 L
.81566 .19535 L
.81603 .19406 L
.81922 .18434 L
.82265 .17463 L
.82537 .16687 L
.82593 .16492 L
.82913 .15521 L
.83253 .14549 L
.83508 .13815 L
.83576 .13578 L
.83894 .12607 L
.84232 .11636 L
.84479 .10919 L
.84551 .10664 L
.84867 .09693 L
.85203 .08722 L
.85451 .07998 L
.8552 .07751 L
.85832 .06779 L
.86165 .05808 L
.86422 .05053 L
.86481 .04837 L
.86789 .03866 L
.87119 .02894 L
.87393 .02086 L
.87436 .01923 L
Mfstroke
.2 g
.50486 .81022 m
.51242 .81566 L
.50587 .82537 L
.50486 .82679 L
.4991 .82537 L
.50267 .81566 L
F
0 g
.50486 .81022 m
.51242 .81566 L
.50587 .82537 L
.50486 .82679 L
.4991 .82537 L
.50267 .81566 L
.50486 .81022 L
s
.2 g
.5063 .01923 m
.50486 .02082 L
.4993 .01923 L
F
0 g
.5063 .01923 m
.50486 .02082 L
.4993 .01923 L
s
.8 g
.50486 .60883 m
.51409 .61169 L
.50766 .62141 L
.50486 .6254 L
.49999 .62141 L
.5037 .61169 L
F
0 g
.50486 .60883 m
.51409 .61169 L
.50766 .62141 L
.50486 .6254 L
.49999 .62141 L
.5037 .61169 L
.50486 .60883 L
s
.2 g
.69724 .01923 m
.69518 .02894 L
.68946 .03866 L
.68939 .0388 L
.6855 .04837 L
.68216 .05808 L
.67968 .06277 L
.67757 .06779 L
.67527 .07751 L
.66997 .08631 L
.66957 .08722 L
.6655 .09693 L
.66181 .10664 L
.66026 .10956 L
.65734 .11636 L
.65437 .12607 L
.65054 .13251 L
.64909 .13578 L
.6449 .14549 L
.64083 .15498 L
.64072 .15521 L
.63647 .16492 L
.63261 .17463 L
.63112 .17723 L
.62792 .18434 L
.62462 .19406 L
.62141 .19913 L
.61925 .20377 L
.61486 .21348 L
.61169 .22062 L
.61044 .22319 L
.60596 .23291 L
.60198 .24166 L
.60148 .24262 L
.59692 .25233 L
.59239 .26204 L
.59227 .26224 L
.5877 .27176 L
.58327 .28147 L
.58256 .28253 L
.5783 .29118 L
.57392 .30089 L
.57284 .30238 L
.56869 .31061 L
.56381 .32032 L
.56313 .32175 L
.55883 .33003 L
.55383 .33974 L
.55342 .34059 L
.5487 .34946 L
.54371 .35907 L
.54353 .35917 L
.53822 .36888 L
.53399 .37781 L
.53284 .37859 L
.52729 .38831 L
.52428 .39524 L
.5216 .39802 L
.5157 .40773 L
.51457 .41031 L
.50941 .41744 L
.50486 .42402 L
.50093 .41744 L
.50474 .40773 L
.50486 .40744 L
.50885 .39802 L
.51304 .38831 L
.51457 .3848 L
.51732 .37859 L
.52164 .36888 L
.52428 .36295 L
.52598 .35917 L
.53034 .34946 L
.53399 .34129 L
.53469 .33974 L
.53906 .33003 L
.54325 .32032 L
.54371 .31957 L
.54776 .31061 L
.55135 .30089 L
.55342 .29763 L
.5564 .29118 L
.5607 .28147 L
.56313 .27559 L
.56498 .27176 L
.56926 .26204 L
.57284 .25358 L
.5735 .25233 L
.57774 .24262 L
.58175 .23291 L
.58256 .23141 L
.58614 .22319 L
.58956 .21348 L
.59227 .20872 L
.59447 .20377 L
.59691 .19406 L
.60198 .18593 L
.60272 .18434 L
.60683 .17463 L
.61068 .16492 L
.61169 .16294 L
.61496 .15521 L
.61817 .14549 L
.62141 .13953 L
.62302 .13578 L
.62508 .12607 L
.63098 .11636 L
.63112 .11607 L
.63499 .10664 L
.63839 .09693 L
.64083 .09213 L
.64287 .08722 L
.64528 .07751 L
.65054 .06809 L
.65067 .06779 L
.65457 .05808 L
.65794 .04837 L
.66026 .04365 L
.66228 .03866 L
.66466 .02894 L
.66991 .01923 L
F
0 g
.69724 .01923 m
.69518 .02894 L
.68946 .03866 L
.68939 .0388 L
.6855 .04837 L
.68216 .05808 L
.67968 .06277 L
.67757 .06779 L
.67527 .07751 L
.66997 .08631 L
.66957 .08722 L
.6655 .09693 L
.66181 .10664 L
.66026 .10956 L
.65734 .11636 L
.65437 .12607 L
.65054 .13251 L
.64909 .13578 L
.6449 .14549 L
.64083 .15498 L
.64072 .15521 L
.63647 .16492 L
.63261 .17463 L
.63112 .17723 L
.62792 .18434 L
.62462 .19406 L
.62141 .19913 L
.61925 .20377 L
.61486 .21348 L
.61169 .22062 L
.61044 .22319 L
.60596 .23291 L
.60198 .24166 L
.60148 .24262 L
.59692 .25233 L
.59239 .26204 L
.59227 .26224 L
.5877 .27176 L
.58327 .28147 L
.58256 .28253 L
.5783 .29118 L
.57392 .30089 L
.57284 .30238 L
.56869 .31061 L
.56381 .32032 L
.56313 .32175 L
.55883 .33003 L
.55383 .33974 L
.55342 .34059 L
.5487 .34946 L
Mistroke
.54371 .35907 L
.54353 .35917 L
.53822 .36888 L
.53399 .37781 L
.53284 .37859 L
.52729 .38831 L
.52428 .39524 L
.5216 .39802 L
.5157 .40773 L
.51457 .41031 L
.50941 .41744 L
.50486 .42402 L
.50093 .41744 L
.50474 .40773 L
.50486 .40744 L
.50885 .39802 L
.51304 .38831 L
.51457 .3848 L
.51732 .37859 L
.52164 .36888 L
.52428 .36295 L
.52598 .35917 L
.53034 .34946 L
.53399 .34129 L
.53469 .33974 L
.53906 .33003 L
.54325 .32032 L
.54371 .31957 L
.54776 .31061 L
.55135 .30089 L
.55342 .29763 L
.5564 .29118 L
.5607 .28147 L
.56313 .27559 L
.56498 .27176 L
.56926 .26204 L
.57284 .25358 L
.5735 .25233 L
.57774 .24262 L
.58175 .23291 L
.58256 .23141 L
.58614 .22319 L
.58956 .21348 L
.59227 .20872 L
.59447 .20377 L
.59691 .19406 L
.60198 .18593 L
.60272 .18434 L
.60683 .17463 L
.61068 .16492 L
Mistroke
.61169 .16294 L
.61496 .15521 L
.61817 .14549 L
.62141 .13953 L
.62302 .13578 L
.62508 .12607 L
.63098 .11636 L
.63112 .11607 L
.63499 .10664 L
.63839 .09693 L
.64083 .09213 L
.64287 .08722 L
.64528 .07751 L
.65054 .06809 L
.65067 .06779 L
.65457 .05808 L
.65794 .04837 L
.66026 .04365 L
.66228 .03866 L
.66466 .02894 L
.66991 .01923 L
Mfstroke
.8 g
.50486 .20606 m
.51113 .21348 L
.50486 .22264 L
.50191 .21348 L
F
0 g
.50486 .20606 m
.51113 .21348 L
.50486 .22264 L
.50191 .21348 L
.50486 .20606 L
s
.8 g
.61163 .01923 m
.60715 .02894 L
.60295 .03866 L
.60198 .04022 L
.59813 .04837 L
.59421 .05808 L
.59227 .06095 L
.58894 .06779 L
.58428 .07751 L
.58256 .08127 L
.57957 .08722 L
.57481 .09693 L
.57284 .10114 L
.56998 .10664 L
.56511 .11636 L
.56313 .12054 L
.56016 .12607 L
.55516 .13578 L
.55342 .13942 L
.55007 .14549 L
.54491 .15521 L
.54371 .15769 L
.53963 .16492 L
.53429 .17463 L
.53399 .17523 L
.52877 .18434 L
.52428 .19214 L
.52314 .19406 L
.51728 .20377 L
.51457 .20817 L
.50582 .20377 L
.50995 .19406 L
.51416 .18434 L
.51457 .18309 L
.51847 .17463 L
.52279 .16492 L
.52428 .1607 L
.52714 .15521 L
.5315 .14549 L
.53399 .13892 L
.53586 .13578 L
.54022 .12607 L
.54371 .11755 L
.54456 .11636 L
.54891 .10664 L
.55314 .09693 L
.55342 .09645 L
.55755 .08722 L
.56124 .07751 L
.56313 .07437 L
.56612 .06779 L
.56903 .05808 L
.57284 .05215 L
.57463 .04837 L
.57886 .03866 L
.58256 .02993 L
.58305 .02894 L
.58726 .01923 L
F
0 g
.61163 .01923 m
.60715 .02894 L
.60295 .03866 L
.60198 .04022 L
.59813 .04837 L
.59421 .05808 L
.59227 .06095 L
.58894 .06779 L
.58428 .07751 L
.58256 .08127 L
.57957 .08722 L
.57481 .09693 L
.57284 .10114 L
.56998 .10664 L
.56511 .11636 L
.56313 .12054 L
.56016 .12607 L
.55516 .13578 L
.55342 .13942 L
.55007 .14549 L
.54491 .15521 L
.54371 .15769 L
.53963 .16492 L
.53429 .17463 L
.53399 .17523 L
.52877 .18434 L
.52428 .19214 L
.52314 .19406 L
.51728 .20377 L
.51457 .20817 L
.50582 .20377 L
.50995 .19406 L
.51416 .18434 L
.51457 .18309 L
.51847 .17463 L
.52279 .16492 L
.52428 .1607 L
.52714 .15521 L
.5315 .14549 L
.53399 .13892 L
.53586 .13578 L
.54022 .12607 L
.54371 .11755 L
.54456 .11636 L
.54891 .10664 L
.55314 .09693 L
.55342 .09645 L
.55755 .08722 L
.56124 .07751 L
.56313 .07437 L
Mistroke
.56612 .06779 L
.56903 .05808 L
.57284 .05215 L
.57463 .04837 L
.57886 .03866 L
.58256 .02993 L
.58305 .02894 L
.58726 .01923 L
Mfstroke
.2 g
.84477 .01923 m
.84144 .02894 L
.83908 .03866 L
.83508 .04763 L
.83482 .04837 L
.83146 .05808 L
.82894 .06779 L
.82537 .07585 L
.82478 .07751 L
.82139 .08722 L
.81868 .09693 L
.81566 .10379 L
.81464 .10664 L
.81122 .11636 L
.8083 .12607 L
.80594 .13147 L
.80439 .13578 L
.80299 .14549 L
.79781 .15521 L
.79623 .15887 L
.79404 .16492 L
.79213 .17463 L
.78722 .18434 L
.78652 .18598 L
.78358 .19406 L
.78118 .20377 L
.77681 .21284 L
.77656 .21348 L
.773 .22319 L
.77015 .23291 L
.76709 .23945 L
.7659 .24262 L
.7623 .25233 L
.75906 .26204 L
.75738 .26574 L
.75511 .27176 L
.75297 .28147 L
.74791 .29118 L
.74767 .29172 L
.74419 .30089 L
.74134 .31061 L
.73796 .31749 L
.73685 .32032 L
.73313 .33003 L
.72973 .33974 L
.72824 .34291 L
.72569 .34946 L
.72324 .35917 L
.71853 .36803 L
.71819 .36888 L
.71438 .37859 L
.7111 .38831 L
.70882 .39289 L
.70676 .39802 L
.70458 .40773 L
.69911 .41736 L
.69907 .41744 L
.69517 .42716 L
.69186 .43687 L
.68939 .44164 L
.68735 .44658 L
.68512 .45629 L
.67968 .46549 L
.67946 .46601 L
.67545 .47572 L
.67191 .48543 L
.66997 .4891 L
.66741 .49514 L
.66472 .50486 L
.66026 .51236 L
.65928 .51457 L
.65516 .52428 L
.65118 .53399 L
.65054 .5352 L
.64686 .54371 L
.64339 .55342 L
.64083 .55783 L
.63847 .56313 L
.63422 .57284 L
.63112 .58005 L
.62995 .58256 L
.62563 .59227 L
.62141 .60179 L
.62131 .60198 L
.61692 .61169 L
.61283 .62141 L
.61169 .6233 L
.60806 .63112 L
.60436 .64083 L
.60198 .64444 L
.59906 .65054 L
.5945 .66026 L
.59227 .66518 L
.58989 .66997 L
.58523 .67968 L
.58256 .68549 L
.58053 .68939 L
.57577 .69911 L
.57284 .70537 L
.57097 .70882 L
.5661 .71853 L
.56313 .7248 L
.56118 .72824 L
.55618 .73796 L
.55342 .74374 L
.55111 .74767 L
.54596 .75738 L
.54371 .76209 L
.54072 .76709 L
.53538 .77681 L
.53399 .77968 L
.5299 .78652 L
.52432 .79623 L
.52428 .7963 L
.51848 .80594 L
.51457 .81232 L
.50665 .80594 L
.51081 .79623 L
.51457 .78757 L
.51503 .78652 L
.51935 .77681 L
.52367 .76709 L
.52428 .76544 L
.52803 .75738 L
.53238 .74767 L
.53399 .74349 L
.53675 .73796 L
.5411 .72824 L
.54371 .72174 L
.54545 .71853 L
.54979 .70882 L
.55342 .70021 L
.5541 .69911 L
.55842 .68939 L
.56255 .67968 L
.56313 .67865 L
.56699 .66997 L
.57055 .66026 L
.57284 .65639 L
.57549 .65054 L
.57818 .64083 L
.58256 .634 L
.58391 .63112 L
.5881 .62141 L
.59225 .61169 L
.59227 .61166 L
.59642 .60198 L
.60007 .59227 L
.60198 .58872 L
.60465 .58256 L
.6075 .57284 L
.61169 .56562 L
.6128 .56313 L
.61686 .55342 L
.62076 .54371 L
.62141 .5424 L
.62491 .53399 L
.6282 .52428 L
.63112 .51873 L
.63288 .51457 L
.63508 .50486 L
.64076 .49514 L
.64083 .49499 L
.64471 .48543 L
.64808 .47572 L
.65054 .47079 L
.65251 .46601 L
.65486 .45629 L
.66022 .44658 L
.66026 .4465 L
.66408 .43687 L
.66735 .42716 L
.66997 .42178 L
.67171 .41744 L
.67388 .40773 L
.67919 .39802 L
.67968 .39694 L
.68305 .38831 L
.68605 .37859 L
.68939 .37172 L
.69052 .36888 L
.69218 .35917 L
.69769 .34946 L
.69911 .34632 L
.70163 .33974 L
.70418 .33003 L
.70882 .32066 L
.70896 .32032 L
.71262 .31061 L
.71566 .30089 L
.71853 .29467 L
.71986 .29118 L
.7216 .28147 L
.72681 .27176 L
.72824 .26848 L
.73065 .26204 L
.73302 .25233 L
.73772 .24262 L
.73796 .24206 L
.74132 .23291 L
.74408 .22319 L
.74767 .21531 L
.74835 .21348 L
.75187 .20377 L
.75488 .19406 L
.75738 .18833 L
.75884 .18434 L
.76052 .17463 L
.76549 .16492 L
.76709 .16112 L
.76922 .15521 L
.77128 .14549 L
.77594 .13578 L
.77681 .13367 L
.7795 .12607 L
.78182 .11636 L
.78625 .10664 L
.78652 .10596 L
.78969 .09693 L
.79217 .08722 L
.79623 .07799 L
.79641 .07751 L
.79978 .06779 L
.80237 .05808 L
.80594 .04977 L
.80644 .04837 L
.80978 .03866 L
.81244 .02894 L
.81566 .0216 L
.81638 .01923 L
F
0 g
.84477 .01923 m
.84144 .02894 L
.83908 .03866 L
.83508 .04763 L
.83482 .04837 L
.83146 .05808 L
.82894 .06779 L
.82537 .07585 L
.82478 .07751 L
.82139 .08722 L
.81868 .09693 L
.81566 .10379 L
.81464 .10664 L
.81122 .11636 L
.8083 .12607 L
.80594 .13147 L
.80439 .13578 L
.80299 .14549 L
.79781 .15521 L
.79623 .15887 L
.79404 .16492 L
.79213 .17463 L
.78722 .18434 L
.78652 .18598 L
.78358 .19406 L
.78118 .20377 L
.77681 .21284 L
.77656 .21348 L
.773 .22319 L
.77015 .23291 L
.76709 .23945 L
.7659 .24262 L
.7623 .25233 L
.75906 .26204 L
.75738 .26574 L
.75511 .27176 L
.75297 .28147 L
.74791 .29118 L
.74767 .29172 L
.74419 .30089 L
.74134 .31061 L
.73796 .31749 L
.73685 .32032 L
.73313 .33003 L
.72973 .33974 L
.72824 .34291 L
.72569 .34946 L
.72324 .35917 L
.71853 .36803 L
.71819 .36888 L
Mistroke
.71438 .37859 L
.7111 .38831 L
.70882 .39289 L
.70676 .39802 L
.70458 .40773 L
.69911 .41736 L
.69907 .41744 L
.69517 .42716 L
.69186 .43687 L
.68939 .44164 L
.68735 .44658 L
.68512 .45629 L
.67968 .46549 L
.67946 .46601 L
.67545 .47572 L
.67191 .48543 L
.66997 .4891 L
.66741 .49514 L
.66472 .50486 L
.66026 .51236 L
.65928 .51457 L
.65516 .52428 L
.65118 .53399 L
.65054 .5352 L
.64686 .54371 L
.64339 .55342 L
.64083 .55783 L
.63847 .56313 L
.63422 .57284 L
.63112 .58005 L
.62995 .58256 L
.62563 .59227 L
.62141 .60179 L
.62131 .60198 L
.61692 .61169 L
.61283 .62141 L
.61169 .6233 L
.60806 .63112 L
.60436 .64083 L
.60198 .64444 L
.59906 .65054 L
.5945 .66026 L
.59227 .66518 L
.58989 .66997 L
.58523 .67968 L
.58256 .68549 L
.58053 .68939 L
.57577 .69911 L
.57284 .70537 L
.57097 .70882 L
Mistroke
.5661 .71853 L
.56313 .7248 L
.56118 .72824 L
.55618 .73796 L
.55342 .74374 L
.55111 .74767 L
.54596 .75738 L
.54371 .76209 L
.54072 .76709 L
.53538 .77681 L
.53399 .77968 L
.5299 .78652 L
.52432 .79623 L
.52428 .7963 L
.51848 .80594 L
.51457 .81232 L
.50665 .80594 L
.51081 .79623 L
.51457 .78757 L
.51503 .78652 L
.51935 .77681 L
.52367 .76709 L
.52428 .76544 L
.52803 .75738 L
.53238 .74767 L
.53399 .74349 L
.53675 .73796 L
.5411 .72824 L
.54371 .72174 L
.54545 .71853 L
.54979 .70882 L
.55342 .70021 L
.5541 .69911 L
.55842 .68939 L
.56255 .67968 L
.56313 .67865 L
.56699 .66997 L
.57055 .66026 L
.57284 .65639 L
.57549 .65054 L
.57818 .64083 L
.58256 .634 L
.58391 .63112 L
.5881 .62141 L
.59225 .61169 L
.59227 .61166 L
.59642 .60198 L
.60007 .59227 L
.60198 .58872 L
.60465 .58256 L
Mistroke
.6075 .57284 L
.61169 .56562 L
.6128 .56313 L
.61686 .55342 L
.62076 .54371 L
.62141 .5424 L
.62491 .53399 L
.6282 .52428 L
.63112 .51873 L
.63288 .51457 L
.63508 .50486 L
.64076 .49514 L
.64083 .49499 L
.64471 .48543 L
.64808 .47572 L
.65054 .47079 L
.65251 .46601 L
.65486 .45629 L
.66022 .44658 L
.66026 .4465 L
.66408 .43687 L
.66735 .42716 L
.66997 .42178 L
.67171 .41744 L
.67388 .40773 L
.67919 .39802 L
.67968 .39694 L
.68305 .38831 L
.68605 .37859 L
.68939 .37172 L
.69052 .36888 L
.69218 .35917 L
.69769 .34946 L
.69911 .34632 L
.70163 .33974 L
.70418 .33003 L
.70882 .32066 L
.70896 .32032 L
.71262 .31061 L
.71566 .30089 L
.71853 .29467 L
.71986 .29118 L
.7216 .28147 L
.72681 .27176 L
.72824 .26848 L
.73065 .26204 L
.73302 .25233 L
.73772 .24262 L
.73796 .24206 L
.74132 .23291 L
Mistroke
.74408 .22319 L
.74767 .21531 L
.74835 .21348 L
.75187 .20377 L
.75488 .19406 L
.75738 .18833 L
.75884 .18434 L
.76052 .17463 L
.76549 .16492 L
.76709 .16112 L
.76922 .15521 L
.77128 .14549 L
.77594 .13578 L
.77681 .13367 L
.7795 .12607 L
.78182 .11636 L
.78625 .10664 L
.78652 .10596 L
.78969 .09693 L
.79217 .08722 L
.79623 .07799 L
.79641 .07751 L
.79978 .06779 L
.80237 .05808 L
.80594 .04977 L
.80644 .04837 L
.80978 .03866 L
.81244 .02894 L
.81566 .0216 L
.81638 .01923 L
Mfstroke
.8 g
.77395 .01923 m
.77154 .02894 L
.76709 .03803 L
.76686 .03866 L
.76326 .04837 L
.76035 .05808 L
.75738 .06437 L
.75608 .06779 L
.75244 .07751 L
.74911 .08722 L
.74767 .09037 L
.74517 .09693 L
.74284 .10664 L
.73796 .11606 L
.73784 .11636 L
.73412 .12607 L
.73107 .13578 L
.72824 .14154 L
.72669 .14549 L
.72293 .15521 L
.71934 .16492 L
.71853 .16664 L
.71539 .17463 L
.71256 .18434 L
.70882 .19151 L
.70778 .19406 L
.70393 .20377 L
.70035 .21348 L
.69911 .21601 L
.6962 .22319 L
.69341 .23291 L
.68939 .24025 L
.6884 .24262 L
.68445 .25233 L
.68073 .26204 L
.67968 .26411 L
.67651 .27176 L
.67347 .28147 L
.66997 .28773 L
.66849 .29118 L
.66443 .30089 L
.6604 .31061 L
.66026 .31089 L
.65625 .32032 L
.65268 .33003 L
.65054 .33387 L
.64798 .33974 L
.64521 .34946 L
.64083 .35645 L
.6396 .35917 L
.63534 .36888 L
.63112 .37855 L
.6311 .37859 L
.62678 .38831 L
.62284 .39802 L
.62141 .40046 L
.61808 .40773 L
.61464 .41744 L
.61169 .42199 L
.60925 .42716 L
.60478 .43687 L
.60198 .44311 L
.60027 .44658 L
.59571 .45629 L
.59227 .46381 L
.59112 .46601 L
.58647 .47572 L
.58256 .48407 L
.5818 .48543 L
.57704 .49514 L
.57284 .5039 L
.57226 .50486 L
.5674 .51457 L
.56313 .52333 L
.5625 .52428 L
.55751 .53399 L
.55342 .54237 L
.55247 .54371 L
.54733 .55342 L
.54371 .56096 L
.54213 .56313 L
.5368 .57284 L
.53399 .57882 L
.53137 .58256 L
.52581 .59227 L
.52428 .59552 L
.52005 .60198 L
.51457 .61094 L
.50774 .60198 L
.51192 .59227 L
.51457 .58618 L
.51618 .58256 L
.5205 .57284 L
.52428 .56433 L
.52482 .56313 L
.52919 .55342 L
.53353 .54371 L
.53399 .54255 L
.53791 .53399 L
.54225 .52428 L
.54371 .52067 L
.5466 .51457 L
.55093 .50486 L
.55342 .4988 L
.55525 .49514 L
.55956 .48543 L
.56313 .47701 L
.56384 .47572 L
.56813 .46601 L
.57221 .45629 L
.57284 .45515 L
.57662 .44658 L
.58013 .43687 L
.58256 .43268 L
.58503 .42716 L
.58765 .41744 L
.59227 .41008 L
.59336 .40773 L
.59751 .39802 L
.60153 .38831 L
.60198 .38743 L
.60574 .37859 L
.6092 .36888 L
.61169 .36425 L
.61389 .35917 L
.6164 .34946 L
.62141 .34096 L
.62195 .33974 L
.62597 .33003 L
.62965 .32032 L
.63112 .31739 L
.63394 .31061 L
.63685 .30089 L
.64083 .29351 L
.64182 .29118 L
.64575 .28147 L
.64944 .27176 L
.65054 .26945 L
.65354 .26204 L
.65649 .25233 L
.66026 .24503 L
.66125 .24262 L
.6651 .23291 L
.66867 .22319 L
.66997 .22043 L
.67272 .21348 L
.67549 .20377 L
.67968 .19552 L
.68027 .19406 L
.68405 .18434 L
.6874 .17463 L
.68939 .17034 L
.69151 .16492 L
.69387 .15521 L
.69888 .14549 L
.69911 .14497 L
.70261 .13578 L
.70559 .12607 L
.70882 .11923 L
.70993 .11636 L
.71153 .10664 L
.71692 .09693 L
.71853 .0933 L
.72083 .08722 L
.72317 .07751 L
.72796 .06779 L
.72824 .06713 L
.7316 .05808 L
.7344 .04837 L
.73796 .04063 L
.7387 .03866 L
.74225 .02894 L
.74534 .01923 L
F
0 g
.77395 .01923 m
.77154 .02894 L
.76709 .03803 L
.76686 .03866 L
.76326 .04837 L
.76035 .05808 L
.75738 .06437 L
.75608 .06779 L
.75244 .07751 L
.74911 .08722 L
.74767 .09037 L
.74517 .09693 L
.74284 .10664 L
.73796 .11606 L
.73784 .11636 L
.73412 .12607 L
.73107 .13578 L
.72824 .14154 L
.72669 .14549 L
.72293 .15521 L
.71934 .16492 L
.71853 .16664 L
.71539 .17463 L
.71256 .18434 L
.70882 .19151 L
.70778 .19406 L
.70393 .20377 L
.70035 .21348 L
.69911 .21601 L
.6962 .22319 L
.69341 .23291 L
.68939 .24025 L
.6884 .24262 L
.68445 .25233 L
.68073 .26204 L
.67968 .26411 L
.67651 .27176 L
.67347 .28147 L
.66997 .28773 L
.66849 .29118 L
.66443 .30089 L
.6604 .31061 L
.66026 .31089 L
.65625 .32032 L
.65268 .33003 L
.65054 .33387 L
.64798 .33974 L
.64521 .34946 L
.64083 .35645 L
.6396 .35917 L
Mistroke
.63534 .36888 L
.63112 .37855 L
.6311 .37859 L
.62678 .38831 L
.62284 .39802 L
.62141 .40046 L
.61808 .40773 L
.61464 .41744 L
.61169 .42199 L
.60925 .42716 L
.60478 .43687 L
.60198 .44311 L
.60027 .44658 L
.59571 .45629 L
.59227 .46381 L
.59112 .46601 L
.58647 .47572 L
.58256 .48407 L
.5818 .48543 L
.57704 .49514 L
.57284 .5039 L
.57226 .50486 L
.5674 .51457 L
.56313 .52333 L
.5625 .52428 L
.55751 .53399 L
.55342 .54237 L
.55247 .54371 L
.54733 .55342 L
.54371 .56096 L
.54213 .56313 L
.5368 .57284 L
.53399 .57882 L
.53137 .58256 L
.52581 .59227 L
.52428 .59552 L
.52005 .60198 L
.51457 .61094 L
.50774 .60198 L
.51192 .59227 L
.51457 .58618 L
.51618 .58256 L
.5205 .57284 L
.52428 .56433 L
.52482 .56313 L
.52919 .55342 L
.53353 .54371 L
.53399 .54255 L
.53791 .53399 L
.54225 .52428 L
Mistroke
.54371 .52067 L
.5466 .51457 L
.55093 .50486 L
.55342 .4988 L
.55525 .49514 L
.55956 .48543 L
.56313 .47701 L
.56384 .47572 L
.56813 .46601 L
.57221 .45629 L
.57284 .45515 L
.57662 .44658 L
.58013 .43687 L
.58256 .43268 L
.58503 .42716 L
.58765 .41744 L
.59227 .41008 L
.59336 .40773 L
.59751 .39802 L
.60153 .38831 L
.60198 .38743 L
.60574 .37859 L
.6092 .36888 L
.61169 .36425 L
.61389 .35917 L
.6164 .34946 L
.62141 .34096 L
.62195 .33974 L
.62597 .33003 L
.62965 .32032 L
.63112 .31739 L
.63394 .31061 L
.63685 .30089 L
.64083 .29351 L
.64182 .29118 L
.64575 .28147 L
.64944 .27176 L
.65054 .26945 L
.65354 .26204 L
.65649 .25233 L
.66026 .24503 L
.66125 .24262 L
.6651 .23291 L
.66867 .22319 L
.66997 .22043 L
.67272 .21348 L
.67549 .20377 L
.67968 .19552 L
.68027 .19406 L
.68405 .18434 L
Mistroke
.6874 .17463 L
.68939 .17034 L
.69151 .16492 L
.69387 .15521 L
.69888 .14549 L
.69911 .14497 L
.70261 .13578 L
.70559 .12607 L
.70882 .11923 L
.70993 .11636 L
.71153 .10664 L
.71692 .09693 L
.71853 .0933 L
.72083 .08722 L
.72317 .07751 L
.72796 .06779 L
.72824 .06713 L
.7316 .05808 L
.7344 .04837 L
.73796 .04063 L
.7387 .03866 L
.74225 .02894 L
.74534 .01923 L
Mfstroke
.8 g
.5182 .98077 m
.52252 .97106 L
.52428 .96599 L
.52687 .96134 L
.53123 .95163 L
.53399 .94434 L
.53559 .94192 L
.53995 .93221 L
.54371 .92318 L
.54429 .92249 L
.54864 .91278 L
.55276 .90307 L
.55342 .90195 L
.55728 .89336 L
.5608 .88364 L
.56313 .87986 L
.56586 .87393 L
.57012 .86422 L
.57284 .85767 L
.57436 .85451 L
.5786 .84479 L
.58256 .83554 L
.58279 .83508 L
.587 .82537 L
.5908 .81566 L
.59227 .81294 L
.59532 .80594 L
.59841 .79623 L
.60198 .79005 L
.60356 .78652 L
.60766 .77681 L
.61169 .76714 L
.61172 .76709 L
.61579 .75738 L
.61935 .74767 L
.62141 .74372 L
.62384 .73796 L
.62654 .72824 L
.63112 .72013 L
.63182 .71853 L
.6358 .70882 L
.63946 .69911 L
.64083 .69632 L
.64367 .68939 L
.64657 .67968 L
.65054 .67217 L
.65147 .66997 L
.65536 .66026 L
.65897 .65054 L
.66026 .64783 L
.66306 .64083 L
.66589 .63112 L
.66997 .62318 L
.6707 .62141 L
.6745 .61169 L
.67795 .60198 L
.67968 .59828 L
.68205 .59227 L
.68458 .58256 L
.68939 .57316 L
.68952 .57284 L
.69326 .56313 L
.69641 .55342 L
.69911 .54768 L
.70065 .54371 L
.70261 .53399 L
.70782 .52428 L
.70882 .52203 L
.71165 .51457 L
.71431 .50486 L
.71853 .49608 L
.7189 .49514 L
.72252 .48543 L
.72559 .47572 L
.72824 .46985 L
.72969 .46601 L
.73148 .45629 L
.73659 .44658 L
.73796 .44341 L
.74037 .43687 L
.74271 .42716 L
.74737 .41744 L
.74767 .41673 L
.75094 .40773 L
.75363 .39802 L
.75738 .38973 L
.75791 .38831 L
.7614 .37859 L
.76431 .36888 L
.76709 .36249 L
.7683 .35917 L
.76976 .34946 L
.77482 .33974 L
.77681 .33503 L
.77859 .33003 L
.78041 .32032 L
.78517 .31061 L
.78652 .30732 L
.78879 .30089 L
.79084 .29118 L
.79539 .28147 L
.79623 .27937 L
.79889 .27176 L
.8011 .26204 L
.80548 .25233 L
.80594 .25117 L
.80889 .24262 L
.81121 .23291 L
.81547 .22319 L
.81566 .22272 L
.81882 .21348 L
.82118 .20377 L
.82536 .19406 L
.82537 .19403 L
.82865 .18434 L
.83103 .17463 L
.83508 .16509 L
.83514 .16492 L
.8384 .15521 L
.84076 .14549 L
.84479 .13592 L
.84484 .13578 L
.84808 .12607 L
.85038 .11636 L
.85446 .10664 L
.85451 .10651 L
.85768 .09693 L
.85989 .08722 L
.86398 .07751 L
.86422 .07686 L
.8672 .06779 L
.86929 .05808 L
.87341 .04837 L
.87393 .04697 L
.87665 .03866 L
.87857 .02894 L
.88275 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.5182 .98077 m
.52252 .97106 L
.52428 .96599 L
.52687 .96134 L
.53123 .95163 L
.53399 .94434 L
.53559 .94192 L
.53995 .93221 L
.54371 .92318 L
.54429 .92249 L
.54864 .91278 L
.55276 .90307 L
.55342 .90195 L
.55728 .89336 L
.5608 .88364 L
.56313 .87986 L
.56586 .87393 L
.57012 .86422 L
.57284 .85767 L
.57436 .85451 L
.5786 .84479 L
.58256 .83554 L
.58279 .83508 L
.587 .82537 L
.5908 .81566 L
.59227 .81294 L
.59532 .80594 L
.59841 .79623 L
.60198 .79005 L
.60356 .78652 L
.60766 .77681 L
.61169 .76714 L
.61172 .76709 L
.61579 .75738 L
.61935 .74767 L
.62141 .74372 L
.62384 .73796 L
.62654 .72824 L
.63112 .72013 L
.63182 .71853 L
.6358 .70882 L
.63946 .69911 L
.64083 .69632 L
.64367 .68939 L
.64657 .67968 L
.65054 .67217 L
.65147 .66997 L
.65536 .66026 L
.65897 .65054 L
.66026 .64783 L
Mistroke
.66306 .64083 L
.66589 .63112 L
.66997 .62318 L
.6707 .62141 L
.6745 .61169 L
.67795 .60198 L
.67968 .59828 L
.68205 .59227 L
.68458 .58256 L
.68939 .57316 L
.68952 .57284 L
.69326 .56313 L
.69641 .55342 L
.69911 .54768 L
.70065 .54371 L
.70261 .53399 L
.70782 .52428 L
.70882 .52203 L
.71165 .51457 L
.71431 .50486 L
.71853 .49608 L
.7189 .49514 L
.72252 .48543 L
.72559 .47572 L
.72824 .46985 L
.72969 .46601 L
.73148 .45629 L
.73659 .44658 L
.73796 .44341 L
.74037 .43687 L
.74271 .42716 L
.74737 .41744 L
.74767 .41673 L
.75094 .40773 L
.75363 .39802 L
.75738 .38973 L
.75791 .38831 L
.7614 .37859 L
.76431 .36888 L
.76709 .36249 L
.7683 .35917 L
.76976 .34946 L
.77482 .33974 L
.77681 .33503 L
.77859 .33003 L
.78041 .32032 L
.78517 .31061 L
.78652 .30732 L
.78879 .30089 L
.79084 .29118 L
Mistroke
.79539 .28147 L
.79623 .27937 L
.79889 .27176 L
.8011 .26204 L
.80548 .25233 L
.80594 .25117 L
.80889 .24262 L
.81121 .23291 L
.81547 .22319 L
.81566 .22272 L
.81882 .21348 L
.82118 .20377 L
.82536 .19406 L
.82537 .19403 L
.82865 .18434 L
.83103 .17463 L
.83508 .16509 L
.83514 .16492 L
.8384 .15521 L
.84076 .14549 L
.84479 .13592 L
.84484 .13578 L
.84808 .12607 L
.85038 .11636 L
.85446 .10664 L
.85451 .10651 L
.85768 .09693 L
.85989 .08722 L
.86398 .07751 L
.86422 .07686 L
.8672 .06779 L
.86929 .05808 L
.87341 .04837 L
.87393 .04697 L
.87665 .03866 L
.87857 .02894 L
.88275 .01923 L
Mfstroke
.7 g
.53396 .98077 m
.53399 .9807 L
.5393 .97106 L
.54371 .96316 L
.54459 .96134 L
.54975 .95163 L
.55342 .9449 L
.55485 .94192 L
.55985 .93221 L
.56313 .92604 L
.56481 .92249 L
.56968 .91278 L
.57284 .90665 L
.57451 .90307 L
.57927 .89336 L
.58256 .88678 L
.584 .88364 L
.58865 .87393 L
.59227 .86647 L
.59375 .86422 L
.59785 .85451 L
.60198 .84573 L
.60255 .84479 L
.60687 .83508 L
.61135 .82537 L
.61169 .82469 L
.61575 .81566 L
.62015 .80594 L
.62141 .80329 L
.62448 .79623 L
.6288 .78652 L
.63112 .78143 L
.6339 .77681 L
.63734 .76709 L
.64083 .75915 L
.6418 .75738 L
.64575 .74767 L
.64994 .73796 L
.65054 .73663 L
.65406 .72824 L
.65818 .71853 L
.66026 .71374 L
.66299 .70882 L
.66633 .69911 L
.66997 .69043 L
.6705 .68939 L
.67438 .67968 L
.67839 .66997 L
.67968 .66693 L
.68336 .66026 L
.6863 .65054 L
.68939 .64299 L
.69046 .64083 L
.69413 .63112 L
.69803 .62141 L
.69911 .61881 L
.70289 .61169 L
.70573 .60198 L
.70882 .59424 L
.70976 .59227 L
.71337 .58256 L
.71717 .57284 L
.71853 .56945 L
.72171 .56313 L
.72469 .55342 L
.72824 .54426 L
.7285 .54371 L
.73377 .53399 L
.73586 .52428 L
.73796 .51887 L
.73998 .51457 L
.74322 .50486 L
.74689 .49514 L
.74767 .49314 L
.75146 .48543 L
.75414 .47572 L
.75738 .4671 L
.75786 .46601 L
.76293 .45629 L
.76494 .44658 L
.76709 .44083 L
.76888 .43687 L
.77206 .42716 L
.77562 .41744 L
.77681 .41425 L
.77981 .40773 L
.78264 .39802 L
.78617 .38831 L
.78652 .38737 L
.79067 .37859 L
.79311 .36888 L
.79623 .36022 L
.79668 .35917 L
.80143 .34946 L
.80347 .33974 L
.80594 .33284 L
.80713 .33003 L
.81208 .32032 L
.81373 .31061 L
.81566 .30518 L
.81748 .30089 L
.82049 .29118 L
.82388 .28147 L
.82537 .27724 L
.82772 .27176 L
.83057 .26204 L
.83393 .25233 L
.83508 .24904 L
.83783 .24262 L
.84056 .23291 L
.84388 .22319 L
.84479 .22058 L
.84783 .21348 L
.85045 .20377 L
.85375 .19406 L
.85451 .19186 L
.85771 .18434 L
.86025 .17463 L
.86352 .16492 L
.86422 .16288 L
.86747 .15521 L
.86997 .14549 L
.87321 .13578 L
.87393 .13366 L
.87711 .12607 L
.8796 .11636 L
.88282 .10664 L
.88364 .10419 L
.88664 .09693 L
.88916 .08722 L
.89235 .07751 L
.89336 .07447 L
.89607 .06779 L
.89864 .05808 L
.9018 .04837 L
.90307 .04451 L
.9054 .03866 L
.90804 .02894 L
.91117 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.53396 .98077 m
.53399 .9807 L
.5393 .97106 L
.54371 .96316 L
.54459 .96134 L
.54975 .95163 L
.55342 .9449 L
.55485 .94192 L
.55985 .93221 L
.56313 .92604 L
.56481 .92249 L
.56968 .91278 L
.57284 .90665 L
.57451 .90307 L
.57927 .89336 L
.58256 .88678 L
.584 .88364 L
.58865 .87393 L
.59227 .86647 L
.59375 .86422 L
.59785 .85451 L
.60198 .84573 L
.60255 .84479 L
.60687 .83508 L
.61135 .82537 L
.61169 .82469 L
.61575 .81566 L
.62015 .80594 L
.62141 .80329 L
.62448 .79623 L
.6288 .78652 L
.63112 .78143 L
.6339 .77681 L
.63734 .76709 L
.64083 .75915 L
.6418 .75738 L
.64575 .74767 L
.64994 .73796 L
.65054 .73663 L
.65406 .72824 L
.65818 .71853 L
.66026 .71374 L
.66299 .70882 L
.66633 .69911 L
.66997 .69043 L
.6705 .68939 L
.67438 .67968 L
.67839 .66997 L
.67968 .66693 L
.68336 .66026 L
Mistroke
.6863 .65054 L
.68939 .64299 L
.69046 .64083 L
.69413 .63112 L
.69803 .62141 L
.69911 .61881 L
.70289 .61169 L
.70573 .60198 L
.70882 .59424 L
.70976 .59227 L
.71337 .58256 L
.71717 .57284 L
.71853 .56945 L
.72171 .56313 L
.72469 .55342 L
.72824 .54426 L
.7285 .54371 L
.73377 .53399 L
.73586 .52428 L
.73796 .51887 L
.73998 .51457 L
.74322 .50486 L
.74689 .49514 L
.74767 .49314 L
.75146 .48543 L
.75414 .47572 L
.75738 .4671 L
.75786 .46601 L
.76293 .45629 L
.76494 .44658 L
.76709 .44083 L
.76888 .43687 L
.77206 .42716 L
.77562 .41744 L
.77681 .41425 L
.77981 .40773 L
.78264 .39802 L
.78617 .38831 L
.78652 .38737 L
.79067 .37859 L
.79311 .36888 L
.79623 .36022 L
.79668 .35917 L
.80143 .34946 L
.80347 .33974 L
.80594 .33284 L
.80713 .33003 L
.81208 .32032 L
.81373 .31061 L
.81566 .30518 L
Mistroke
.81748 .30089 L
.82049 .29118 L
.82388 .28147 L
.82537 .27724 L
.82772 .27176 L
.83057 .26204 L
.83393 .25233 L
.83508 .24904 L
.83783 .24262 L
.84056 .23291 L
.84388 .22319 L
.84479 .22058 L
.84783 .21348 L
.85045 .20377 L
.85375 .19406 L
.85451 .19186 L
.85771 .18434 L
.86025 .17463 L
.86352 .16492 L
.86422 .16288 L
.86747 .15521 L
.86997 .14549 L
.87321 .13578 L
.87393 .13366 L
.87711 .12607 L
.8796 .11636 L
.88282 .10664 L
.88364 .10419 L
.88664 .09693 L
.88916 .08722 L
.89235 .07751 L
.89336 .07447 L
.89607 .06779 L
.89864 .05808 L
.9018 .04837 L
.90307 .04451 L
.9054 .03866 L
.90804 .02894 L
.91117 .01923 L
Mfstroke
.6 g
.55573 .98077 m
.56052 .97106 L
.56313 .96538 L
.56511 .96134 L
.56983 .95163 L
.57284 .945 L
.57433 .94192 L
.57899 .93221 L
.58256 .92426 L
.58339 .92249 L
.58799 .91278 L
.59227 .90317 L
.59231 .90307 L
.59685 .89336 L
.60119 .88364 L
.60198 .88174 L
.60557 .87393 L
.60993 .86422 L
.61169 .85997 L
.61417 .85451 L
.61852 .84479 L
.62141 .83786 L
.62265 .83508 L
.62697 .82537 L
.63103 .81566 L
.63112 .81542 L
.6353 .80594 L
.63944 .79623 L
.64083 .79267 L
.64351 .78652 L
.64768 .77681 L
.65054 .76959 L
.65161 .76709 L
.65578 .75738 L
.65972 .74767 L
.66026 .74621 L
.66375 .73796 L
.66779 .72824 L
.66997 .72251 L
.67163 .71853 L
.67568 .70882 L
.67947 .69911 L
.67968 .69851 L
.68345 .68939 L
.68738 .67968 L
.68939 .67421 L
.69112 .66997 L
.69508 .66026 L
.69879 .65054 L
.69911 .64961 L
.70265 .64083 L
.70651 .63112 L
.70882 .62472 L
.71014 .62141 L
.71402 .61169 L
.7177 .60198 L
.71853 .59954 L
.72141 .59227 L
.72521 .58256 L
.72824 .57407 L
.72872 .57284 L
.73253 .56313 L
.73622 .55342 L
.73796 .54832 L
.73974 .54371 L
.7435 .53399 L
.74703 .52428 L
.74767 .52229 L
.75063 .51457 L
.75432 .50486 L
.75738 .49599 L
.7577 .49514 L
.76139 .48543 L
.765 .47572 L
.76709 .46941 L
.76837 .46601 L
.77203 .45629 L
.77553 .44658 L
.77681 .44256 L
.77892 .43687 L
.78254 .42716 L
.78591 .41744 L
.78652 .41545 L
.78936 .40773 L
.79293 .39802 L
.79616 .38831 L
.79623 .38806 L
.7997 .37859 L
.80321 .36888 L
.80594 .36042 L
.80639 .35917 L
.80992 .34946 L
.81338 .33974 L
.81566 .33252 L
.81654 .33003 L
.82005 .32032 L
.82345 .31061 L
.82537 .30436 L
.8266 .30089 L
.83007 .29118 L
.83342 .28147 L
.83508 .27594 L
.83655 .27176 L
.84 .26204 L
.84331 .25233 L
.84479 .24727 L
.84642 .24262 L
.84984 .23291 L
.85311 .22319 L
.85451 .21836 L
.8562 .21348 L
.85959 .20377 L
.86283 .19406 L
.86422 .18919 L
.86588 .18434 L
.86925 .17463 L
.87248 .16492 L
.87393 .15978 L
.87549 .15521 L
.87883 .14549 L
.88205 .13578 L
.88364 .13012 L
.88501 .12607 L
.88833 .11636 L
.89155 .10664 L
.89336 .10022 L
.89446 .09693 L
.89775 .08722 L
.90097 .07751 L
.90307 .07008 L
.90383 .06779 L
.9071 .05808 L
.91032 .04837 L
.91278 .03971 L
.91313 .03866 L
.91637 .02894 L
.91958 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.55573 .98077 m
.56052 .97106 L
.56313 .96538 L
.56511 .96134 L
.56983 .95163 L
.57284 .945 L
.57433 .94192 L
.57899 .93221 L
.58256 .92426 L
.58339 .92249 L
.58799 .91278 L
.59227 .90317 L
.59231 .90307 L
.59685 .89336 L
.60119 .88364 L
.60198 .88174 L
.60557 .87393 L
.60993 .86422 L
.61169 .85997 L
.61417 .85451 L
.61852 .84479 L
.62141 .83786 L
.62265 .83508 L
.62697 .82537 L
.63103 .81566 L
.63112 .81542 L
.6353 .80594 L
.63944 .79623 L
.64083 .79267 L
.64351 .78652 L
.64768 .77681 L
.65054 .76959 L
.65161 .76709 L
.65578 .75738 L
.65972 .74767 L
.66026 .74621 L
.66375 .73796 L
.66779 .72824 L
.66997 .72251 L
.67163 .71853 L
.67568 .70882 L
.67947 .69911 L
.67968 .69851 L
.68345 .68939 L
.68738 .67968 L
.68939 .67421 L
.69112 .66997 L
.69508 .66026 L
.69879 .65054 L
.69911 .64961 L
Mistroke
.70265 .64083 L
.70651 .63112 L
.70882 .62472 L
.71014 .62141 L
.71402 .61169 L
.7177 .60198 L
.71853 .59954 L
.72141 .59227 L
.72521 .58256 L
.72824 .57407 L
.72872 .57284 L
.73253 .56313 L
.73622 .55342 L
.73796 .54832 L
.73974 .54371 L
.7435 .53399 L
.74703 .52428 L
.74767 .52229 L
.75063 .51457 L
.75432 .50486 L
.75738 .49599 L
.7577 .49514 L
.76139 .48543 L
.765 .47572 L
.76709 .46941 L
.76837 .46601 L
.77203 .45629 L
.77553 .44658 L
.77681 .44256 L
.77892 .43687 L
.78254 .42716 L
.78591 .41744 L
.78652 .41545 L
.78936 .40773 L
.79293 .39802 L
.79616 .38831 L
.79623 .38806 L
.7997 .37859 L
.80321 .36888 L
.80594 .36042 L
.80639 .35917 L
.80992 .34946 L
.81338 .33974 L
.81566 .33252 L
.81654 .33003 L
.82005 .32032 L
.82345 .31061 L
.82537 .30436 L
.8266 .30089 L
.83007 .29118 L
Mistroke
.83342 .28147 L
.83508 .27594 L
.83655 .27176 L
.84 .26204 L
.84331 .25233 L
.84479 .24727 L
.84642 .24262 L
.84984 .23291 L
.85311 .22319 L
.85451 .21836 L
.8562 .21348 L
.85959 .20377 L
.86283 .19406 L
.86422 .18919 L
.86588 .18434 L
.86925 .17463 L
.87248 .16492 L
.87393 .15978 L
.87549 .15521 L
.87883 .14549 L
.88205 .13578 L
.88364 .13012 L
.88501 .12607 L
.88833 .11636 L
.89155 .10664 L
.89336 .10022 L
.89446 .09693 L
.89775 .08722 L
.90097 .07751 L
.90307 .07008 L
.90383 .06779 L
.9071 .05808 L
.91032 .04837 L
.91278 .03971 L
.91313 .03866 L
.91637 .02894 L
.91958 .01923 L
Mfstroke
.5 g
.56825 .98077 m
.57278 .97106 L
.57284 .97093 L
.57732 .96134 L
.58179 .95163 L
.58256 .94994 L
.58624 .94192 L
.59066 .93221 L
.59227 .92861 L
.59504 .92249 L
.59941 .91278 L
.60198 .90695 L
.60371 .90307 L
.60803 .89336 L
.61169 .88496 L
.61227 .88364 L
.61654 .87393 L
.62074 .86422 L
.62141 .86265 L
.62493 .85451 L
.6291 .84479 L
.63112 .84001 L
.63323 .83508 L
.63736 .82537 L
.64083 .81706 L
.64142 .81566 L
.64552 .80594 L
.64955 .79623 L
.65054 .7938 L
.65358 .78652 L
.65759 .77681 L
.66026 .77024 L
.66155 .76709 L
.66553 .75738 L
.66945 .74767 L
.66997 .74637 L
.67338 .73796 L
.67729 .72824 L
.67968 .7222 L
.68115 .71853 L
.68504 .70882 L
.68886 .69911 L
.68939 .69773 L
.6927 .68939 L
.69652 .67968 L
.69911 .67298 L
.70028 .66997 L
.70409 .66026 L
.70783 .65054 L
.70882 .64794 L
.71157 .64083 L
.71532 .63112 L
.71853 .62261 L
.71899 .62141 L
.72271 .61169 L
.7264 .60198 L
.72824 .597 L
.73003 .59227 L
.73371 .58256 L
.73733 .57284 L
.73796 .57111 L
.74095 .56313 L
.74458 .55342 L
.74767 .54495 L
.74813 .54371 L
.75173 .53399 L
.75531 .52428 L
.75738 .51851 L
.75883 .51457 L
.7624 .50486 L
.76591 .49514 L
.76709 .4918 L
.76941 .48543 L
.77294 .47572 L
.7764 .46601 L
.77681 .46483 L
.77988 .45629 L
.78337 .44658 L
.78652 .43759 L
.78678 .43687 L
.79024 .42716 L
.79369 .41744 L
.79623 .41009 L
.79706 .40773 L
.8005 .39802 L
.80391 .38831 L
.80594 .38233 L
.80725 .37859 L
.81066 .36888 L
.81402 .35917 L
.81566 .35432 L
.81734 .34946 L
.82072 .33974 L
.82404 .33003 L
.82537 .32605 L
.82734 .32032 L
.83068 .31061 L
.83397 .30089 L
.83508 .29753 L
.83724 .29118 L
.84056 .28147 L
.84382 .27176 L
.84479 .26875 L
.84706 .26204 L
.85035 .25233 L
.85358 .24262 L
.85451 .23973 L
.85679 .23291 L
.86006 .22319 L
.86326 .21348 L
.86422 .21047 L
.86644 .20377 L
.86968 .19406 L
.87286 .18434 L
.87393 .18096 L
.87601 .17463 L
.87923 .16492 L
.88239 .15521 L
.88364 .15121 L
.88551 .14549 L
.8887 .13578 L
.89184 .12607 L
.89336 .12121 L
.89493 .11636 L
.89809 .10664 L
.90122 .09693 L
.90307 .09098 L
.90428 .08722 L
.90742 .07751 L
.91053 .06779 L
.91278 .06052 L
.91356 .05808 L
.91667 .04837 L
.91977 .03866 L
.92249 .02982 L
.92277 .02894 L
.92585 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.56825 .98077 m
.57278 .97106 L
.57284 .97093 L
.57732 .96134 L
.58179 .95163 L
.58256 .94994 L
.58624 .94192 L
.59066 .93221 L
.59227 .92861 L
.59504 .92249 L
.59941 .91278 L
.60198 .90695 L
.60371 .90307 L
.60803 .89336 L
.61169 .88496 L
.61227 .88364 L
.61654 .87393 L
.62074 .86422 L
.62141 .86265 L
.62493 .85451 L
.6291 .84479 L
.63112 .84001 L
.63323 .83508 L
.63736 .82537 L
.64083 .81706 L
.64142 .81566 L
.64552 .80594 L
.64955 .79623 L
.65054 .7938 L
.65358 .78652 L
.65759 .77681 L
.66026 .77024 L
.66155 .76709 L
.66553 .75738 L
.66945 .74767 L
.66997 .74637 L
.67338 .73796 L
.67729 .72824 L
.67968 .7222 L
.68115 .71853 L
.68504 .70882 L
.68886 .69911 L
.68939 .69773 L
.6927 .68939 L
.69652 .67968 L
.69911 .67298 L
.70028 .66997 L
.70409 .66026 L
.70783 .65054 L
.70882 .64794 L
Mistroke
.71157 .64083 L
.71532 .63112 L
.71853 .62261 L
.71899 .62141 L
.72271 .61169 L
.7264 .60198 L
.72824 .597 L
.73003 .59227 L
.73371 .58256 L
.73733 .57284 L
.73796 .57111 L
.74095 .56313 L
.74458 .55342 L
.74767 .54495 L
.74813 .54371 L
.75173 .53399 L
.75531 .52428 L
.75738 .51851 L
.75883 .51457 L
.7624 .50486 L
.76591 .49514 L
.76709 .4918 L
.76941 .48543 L
.77294 .47572 L
.7764 .46601 L
.77681 .46483 L
.77988 .45629 L
.78337 .44658 L
.78652 .43759 L
.78678 .43687 L
.79024 .42716 L
.79369 .41744 L
.79623 .41009 L
.79706 .40773 L
.8005 .39802 L
.80391 .38831 L
.80594 .38233 L
.80725 .37859 L
.81066 .36888 L
.81402 .35917 L
.81566 .35432 L
.81734 .34946 L
.82072 .33974 L
.82404 .33003 L
.82537 .32605 L
.82734 .32032 L
.83068 .31061 L
.83397 .30089 L
.83508 .29753 L
.83724 .29118 L
Mistroke
.84056 .28147 L
.84382 .27176 L
.84479 .26875 L
.84706 .26204 L
.85035 .25233 L
.85358 .24262 L
.85451 .23973 L
.85679 .23291 L
.86006 .22319 L
.86326 .21348 L
.86422 .21047 L
.86644 .20377 L
.86968 .19406 L
.87286 .18434 L
.87393 .18096 L
.87601 .17463 L
.87923 .16492 L
.88239 .15521 L
.88364 .15121 L
.88551 .14549 L
.8887 .13578 L
.89184 .12607 L
.89336 .12121 L
.89493 .11636 L
.89809 .10664 L
.90122 .09693 L
.90307 .09098 L
.90428 .08722 L
.90742 .07751 L
.91053 .06779 L
.91278 .06052 L
.91356 .05808 L
.91667 .04837 L
.91977 .03866 L
.92249 .02982 L
.92277 .02894 L
.92585 .01923 L
Mfstroke
.4 g
.57933 .98077 m
.58256 .97371 L
.58375 .97106 L
.58815 .96134 L
.59227 .9522 L
.59252 .95163 L
.59685 .94192 L
.60117 .93221 L
.60198 .93036 L
.60543 .92249 L
.60969 .91278 L
.61169 .90819 L
.61391 .90307 L
.61811 .89336 L
.62141 .88571 L
.62228 .88364 L
.62643 .87393 L
.63057 .86422 L
.63112 .86292 L
.63465 .85451 L
.63875 .84479 L
.64083 .83981 L
.64279 .83508 L
.64683 .82537 L
.65054 .8164 L
.65085 .81566 L
.65483 .80594 L
.65881 .79623 L
.66026 .79269 L
.66274 .78652 L
.66669 .77681 L
.66997 .76868 L
.6706 .76709 L
.67448 .75738 L
.67837 .74767 L
.67968 .74437 L
.6822 .73796 L
.68605 .72824 L
.68939 .71978 L
.68988 .71853 L
.69366 .70882 L
.69747 .69911 L
.69911 .69489 L
.70121 .68939 L
.70498 .67968 L
.70873 .66997 L
.70882 .66973 L
.71242 .66026 L
.71614 .65054 L
.71853 .64428 L
.71982 .64083 L
.72349 .63112 L
.72717 .62141 L
.72824 .61855 L
.73079 .61169 L
.73443 .60198 L
.73796 .59254 L
.73806 .59227 L
.74163 .58256 L
.74524 .57284 L
.74767 .56627 L
.7488 .56313 L
.75236 .55342 L
.75593 .54371 L
.75738 .53972 L
.75943 .53399 L
.76297 .52428 L
.7665 .51457 L
.76709 .51291 L
.76996 .50486 L
.77346 .49514 L
.77681 .48583 L
.77695 .48543 L
.78038 .47572 L
.78385 .46601 L
.78652 .45849 L
.78728 .45629 L
.79069 .44658 L
.79413 .43687 L
.79623 .43089 L
.79751 .42716 L
.8009 .41744 L
.80431 .40773 L
.80594 .40304 L
.80765 .39802 L
.81102 .38831 L
.8144 .37859 L
.81566 .37493 L
.8177 .36888 L
.82104 .35917 L
.82438 .34946 L
.82537 .34657 L
.82765 .33974 L
.83097 .33003 L
.83428 .32032 L
.83508 .31795 L
.83752 .31061 L
.84081 .30089 L
.8441 .29118 L
.84479 .28909 L
.8473 .28147 L
.85057 .27176 L
.85382 .26204 L
.85451 .25999 L
.857 .25233 L
.86024 .24262 L
.86347 .23291 L
.86422 .23063 L
.86662 .22319 L
.86983 .21348 L
.87304 .20377 L
.87393 .20104 L
.87617 .19406 L
.87935 .18434 L
.88253 .17463 L
.88364 .17121 L
.88563 .16492 L
.88879 .15521 L
.89195 .14549 L
.89336 .14114 L
.89503 .13578 L
.89816 .12607 L
.9013 .11636 L
.90307 .11083 L
.90436 .10664 L
.90746 .09693 L
.91058 .08722 L
.91278 .08029 L
.91363 .07751 L
.91669 .06779 L
.91979 .05808 L
.92249 .04951 L
.92284 .04837 L
.92585 .03866 L
.92893 .02894 L
.93198 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.57933 .98077 m
.58256 .97371 L
.58375 .97106 L
.58815 .96134 L
.59227 .9522 L
.59252 .95163 L
.59685 .94192 L
.60117 .93221 L
.60198 .93036 L
.60543 .92249 L
.60969 .91278 L
.61169 .90819 L
.61391 .90307 L
.61811 .89336 L
.62141 .88571 L
.62228 .88364 L
.62643 .87393 L
.63057 .86422 L
.63112 .86292 L
.63465 .85451 L
.63875 .84479 L
.64083 .83981 L
.64279 .83508 L
.64683 .82537 L
.65054 .8164 L
.65085 .81566 L
.65483 .80594 L
.65881 .79623 L
.66026 .79269 L
.66274 .78652 L
.66669 .77681 L
.66997 .76868 L
.6706 .76709 L
.67448 .75738 L
.67837 .74767 L
.67968 .74437 L
.6822 .73796 L
.68605 .72824 L
.68939 .71978 L
.68988 .71853 L
.69366 .70882 L
.69747 .69911 L
.69911 .69489 L
.70121 .68939 L
.70498 .67968 L
.70873 .66997 L
.70882 .66973 L
.71242 .66026 L
.71614 .65054 L
.71853 .64428 L
Mistroke
.71982 .64083 L
.72349 .63112 L
.72717 .62141 L
.72824 .61855 L
.73079 .61169 L
.73443 .60198 L
.73796 .59254 L
.73806 .59227 L
.74163 .58256 L
.74524 .57284 L
.74767 .56627 L
.7488 .56313 L
.75236 .55342 L
.75593 .54371 L
.75738 .53972 L
.75943 .53399 L
.76297 .52428 L
.7665 .51457 L
.76709 .51291 L
.76996 .50486 L
.77346 .49514 L
.77681 .48583 L
.77695 .48543 L
.78038 .47572 L
.78385 .46601 L
.78652 .45849 L
.78728 .45629 L
.79069 .44658 L
.79413 .43687 L
.79623 .43089 L
.79751 .42716 L
.8009 .41744 L
.80431 .40773 L
.80594 .40304 L
.80765 .39802 L
.81102 .38831 L
.8144 .37859 L
.81566 .37493 L
.8177 .36888 L
.82104 .35917 L
.82438 .34946 L
.82537 .34657 L
.82765 .33974 L
.83097 .33003 L
.83428 .32032 L
.83508 .31795 L
.83752 .31061 L
.84081 .30089 L
.8441 .29118 L
.84479 .28909 L
Mistroke
.8473 .28147 L
.85057 .27176 L
.85382 .26204 L
.85451 .25999 L
.857 .25233 L
.86024 .24262 L
.86347 .23291 L
.86422 .23063 L
.86662 .22319 L
.86983 .21348 L
.87304 .20377 L
.87393 .20104 L
.87617 .19406 L
.87935 .18434 L
.88253 .17463 L
.88364 .17121 L
.88563 .16492 L
.88879 .15521 L
.89195 .14549 L
.89336 .14114 L
.89503 .13578 L
.89816 .12607 L
.9013 .11636 L
.90307 .11083 L
.90436 .10664 L
.90746 .09693 L
.91058 .08722 L
.91278 .08029 L
.91363 .07751 L
.91669 .06779 L
.91979 .05808 L
.92249 .04951 L
.92284 .04837 L
.92585 .03866 L
.92893 .02894 L
.93198 .01923 L
Mfstroke
.3 g
.59086 .98077 m
.59227 .97765 L
.59508 .97106 L
.59941 .96134 L
.60198 .95557 L
.60362 .95163 L
.60785 .94192 L
.61169 .9332 L
.61209 .93221 L
.61619 .92249 L
.62042 .91278 L
.62141 .91051 L
.62445 .90307 L
.62861 .89336 L
.63112 .88751 L
.63265 .88364 L
.63671 .87393 L
.64083 .86422 L
.64083 .86422 L
.64472 .85451 L
.6488 .84479 L
.65054 .84061 L
.65269 .83508 L
.65668 .82537 L
.66026 .81672 L
.66065 .81566 L
.66448 .80594 L
.66846 .79623 L
.66997 .79254 L
.67224 .78652 L
.67614 .77681 L
.67968 .76807 L
.68003 .76709 L
.68376 .75738 L
.68765 .74767 L
.68939 .7433 L
.69135 .73796 L
.69515 .72824 L
.699 .71853 L
.69911 .71827 L
.7026 .70882 L
.70641 .69911 L
.70882 .69294 L
.71006 .68939 L
.71374 .67968 L
.71752 .66997 L
.71853 .66735 L
.72105 .66026 L
.72476 .65054 L
.72824 .64148 L
.72846 .64083 L
.73195 .63112 L
.73565 .62141 L
.73796 .61533 L
.73918 .61169 L
.74274 .60198 L
.74641 .59227 L
.74767 .58892 L
.74983 .58256 L
.75342 .57284 L
.75705 .56313 L
.75738 .56225 L
.7604 .55342 L
.76399 .54371 L
.76709 .5353 L
.7675 .53399 L
.77087 .52428 L
.77444 .51457 L
.77681 .5081 L
.77783 .50486 L
.78124 .49514 L
.78478 .48543 L
.78652 .48064 L
.78808 .47572 L
.79151 .46601 L
.79502 .45629 L
.79623 .45292 L
.79825 .44658 L
.80168 .43687 L
.80516 .42716 L
.80594 .42495 L
.80834 .41744 L
.81175 .40773 L
.81521 .39802 L
.81566 .39673 L
.81833 .38831 L
.82173 .37859 L
.82515 .36888 L
.82537 .36826 L
.82824 .35917 L
.83162 .34946 L
.83501 .33974 L
.83508 .33954 L
.83806 .33003 L
.84142 .32032 L
.84478 .31061 L
.84479 .31058 L
.8478 .30089 L
.85113 .29118 L
.85447 .28147 L
.85451 .28137 L
.85745 .27176 L
.86076 .26204 L
.86408 .25233 L
.86422 .25192 L
.86703 .24262 L
.87031 .23291 L
.87361 .22319 L
.87393 .22222 L
.87653 .21348 L
.87979 .20377 L
.88306 .19406 L
.88364 .19229 L
.88596 .18434 L
.88918 .17463 L
.89243 .16492 L
.89336 .16213 L
.89533 .15521 L
.8985 .14549 L
.90174 .13578 L
.90307 .13173 L
.90463 .12607 L
.90775 .11636 L
.91097 .10664 L
.91278 .1011 L
.91389 .09693 L
.91693 .08722 L
.92013 .07751 L
.92249 .07024 L
.92311 .06779 L
.92604 .05808 L
.92922 .04837 L
.93221 .03915 L
.93232 .03866 L
.9351 .02894 L
.93824 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.59086 .98077 m
.59227 .97765 L
.59508 .97106 L
.59941 .96134 L
.60198 .95557 L
.60362 .95163 L
.60785 .94192 L
.61169 .9332 L
.61209 .93221 L
.61619 .92249 L
.62042 .91278 L
.62141 .91051 L
.62445 .90307 L
.62861 .89336 L
.63112 .88751 L
.63265 .88364 L
.63671 .87393 L
.64083 .86422 L
.64083 .86422 L
.64472 .85451 L
.6488 .84479 L
.65054 .84061 L
.65269 .83508 L
.65668 .82537 L
.66026 .81672 L
.66065 .81566 L
.66448 .80594 L
.66846 .79623 L
.66997 .79254 L
.67224 .78652 L
.67614 .77681 L
.67968 .76807 L
.68003 .76709 L
.68376 .75738 L
.68765 .74767 L
.68939 .7433 L
.69135 .73796 L
.69515 .72824 L
.699 .71853 L
.69911 .71827 L
.7026 .70882 L
.70641 .69911 L
.70882 .69294 L
.71006 .68939 L
.71374 .67968 L
.71752 .66997 L
.71853 .66735 L
.72105 .66026 L
.72476 .65054 L
.72824 .64148 L
Mistroke
.72846 .64083 L
.73195 .63112 L
.73565 .62141 L
.73796 .61533 L
.73918 .61169 L
.74274 .60198 L
.74641 .59227 L
.74767 .58892 L
.74983 .58256 L
.75342 .57284 L
.75705 .56313 L
.75738 .56225 L
.7604 .55342 L
.76399 .54371 L
.76709 .5353 L
.7675 .53399 L
.77087 .52428 L
.77444 .51457 L
.77681 .5081 L
.77783 .50486 L
.78124 .49514 L
.78478 .48543 L
.78652 .48064 L
.78808 .47572 L
.79151 .46601 L
.79502 .45629 L
.79623 .45292 L
.79825 .44658 L
.80168 .43687 L
.80516 .42716 L
.80594 .42495 L
.80834 .41744 L
.81175 .40773 L
.81521 .39802 L
.81566 .39673 L
.81833 .38831 L
.82173 .37859 L
.82515 .36888 L
.82537 .36826 L
.82824 .35917 L
.83162 .34946 L
.83501 .33974 L
.83508 .33954 L
.83806 .33003 L
.84142 .32032 L
.84478 .31061 L
.84479 .31058 L
.8478 .30089 L
.85113 .29118 L
.85447 .28147 L
Mistroke
.85451 .28137 L
.85745 .27176 L
.86076 .26204 L
.86408 .25233 L
.86422 .25192 L
.86703 .24262 L
.87031 .23291 L
.87361 .22319 L
.87393 .22222 L
.87653 .21348 L
.87979 .20377 L
.88306 .19406 L
.88364 .19229 L
.88596 .18434 L
.88918 .17463 L
.89243 .16492 L
.89336 .16213 L
.89533 .15521 L
.8985 .14549 L
.90174 .13578 L
.90307 .13173 L
.90463 .12607 L
.90775 .11636 L
.91097 .10664 L
.91278 .1011 L
.91389 .09693 L
.91693 .08722 L
.92013 .07751 L
.92249 .07024 L
.92311 .06779 L
.92604 .05808 L
.92922 .04837 L
.93221 .03915 L
.93232 .03866 L
.9351 .02894 L
.93824 .01923 L
Mfstroke
.2 g
.60657 .98077 m
.61035 .97106 L
.61169 .96846 L
.61471 .96134 L
.61778 .95163 L
.62141 .94507 L
.62277 .94192 L
.62679 .93221 L
.63068 .92249 L
.63112 .92159 L
.63474 .91278 L
.63805 .90307 L
.64083 .89766 L
.64262 .89336 L
.64486 .88364 L
.65041 .87393 L
.65054 .87364 L
.65433 .86422 L
.65762 .85451 L
.66026 .84918 L
.66204 .84479 L
.66425 .83508 L
.66963 .82537 L
.66997 .82462 L
.6735 .81566 L
.67661 .80594 L
.67968 .79965 L
.68105 .79623 L
.68291 .78652 L
.68836 .77681 L
.68939 .77452 L
.69227 .76709 L
.69503 .75738 L
.69911 .74909 L
.69967 .74767 L
.70336 .73796 L
.7066 .72824 L
.70882 .72338 L
.71068 .71853 L
.71281 .70882 L
.71782 .69911 L
.71853 .69748 L
.72156 .68939 L
.72427 .67968 L
.72824 .67126 L
.72874 .66997 L
.73233 .66026 L
.73538 .65054 L
.73796 .64478 L
.73943 .64083 L
.7412 .63112 L
.74624 .62141 L
.74767 .61808 L
.75001 .61169 L
.75226 .60198 L
.75691 .59227 L
.75738 .59114 L
.76048 .58256 L
.76305 .57284 L
.76709 .56391 L
.76738 .56313 L
.77084 .55342 L
.77363 .54371 L
.77681 .53642 L
.77768 .53399 L
.78111 .52428 L
.78403 .51457 L
.78652 .50869 L
.78788 .50486 L
.78937 .49514 L
.79429 .48543 L
.79623 .48073 L
.79799 .47572 L
.79971 .46601 L
.80442 .45629 L
.80594 .45253 L
.80801 .44658 L
.80987 .43687 L
.81443 .42716 L
.81566 .42408 L
.81794 .41744 L
.81987 .40773 L
.82433 .39802 L
.82537 .39539 L
.82778 .38831 L
.82975 .37859 L
.83414 .36888 L
.83508 .36646 L
.83754 .35917 L
.83949 .34946 L
.84384 .33974 L
.84479 .33728 L
.84722 .33003 L
.84911 .32032 L
.85345 .31061 L
.85451 .30787 L
.85683 .30089 L
.85861 .29118 L
.86297 .28147 L
.86422 .27822 L
.86635 .27176 L
.86799 .26204 L
.8724 .25233 L
.87393 .24834 L
.87581 .24262 L
.87724 .23291 L
.88173 .22319 L
.88364 .21822 L
.88519 .21348 L
.88634 .20377 L
.89097 .19406 L
.89336 .18788 L
.89451 .18434 L
.89761 .17463 L
.9001 .16492 L
.90307 .15731 L
.90375 .15521 L
.90684 .14549 L
.90912 .13578 L
.91278 .12653 L
.91293 .12607 L
.916 .11636 L
.91802 .10664 L
.92198 .09693 L
.92249 .0955 L
.9251 .08722 L
.92676 .07751 L
.93091 .06779 L
.93221 .06424 L
.93414 .05808 L
.93533 .04837 L
.93973 .03866 L
.94192 .03276 L
.94311 .02894 L
.94611 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.60657 .98077 m
.61035 .97106 L
.61169 .96846 L
.61471 .96134 L
.61778 .95163 L
.62141 .94507 L
.62277 .94192 L
.62679 .93221 L
.63068 .92249 L
.63112 .92159 L
.63474 .91278 L
.63805 .90307 L
.64083 .89766 L
.64262 .89336 L
.64486 .88364 L
.65041 .87393 L
.65054 .87364 L
.65433 .86422 L
.65762 .85451 L
.66026 .84918 L
.66204 .84479 L
.66425 .83508 L
.66963 .82537 L
.66997 .82462 L
.6735 .81566 L
.67661 .80594 L
.67968 .79965 L
.68105 .79623 L
.68291 .78652 L
.68836 .77681 L
.68939 .77452 L
.69227 .76709 L
.69503 .75738 L
.69911 .74909 L
.69967 .74767 L
.70336 .73796 L
.7066 .72824 L
.70882 .72338 L
.71068 .71853 L
.71281 .70882 L
.71782 .69911 L
.71853 .69748 L
.72156 .68939 L
.72427 .67968 L
.72824 .67126 L
.72874 .66997 L
.73233 .66026 L
.73538 .65054 L
.73796 .64478 L
.73943 .64083 L
Mistroke
.7412 .63112 L
.74624 .62141 L
.74767 .61808 L
.75001 .61169 L
.75226 .60198 L
.75691 .59227 L
.75738 .59114 L
.76048 .58256 L
.76305 .57284 L
.76709 .56391 L
.76738 .56313 L
.77084 .55342 L
.77363 .54371 L
.77681 .53642 L
.77768 .53399 L
.78111 .52428 L
.78403 .51457 L
.78652 .50869 L
.78788 .50486 L
.78937 .49514 L
.79429 .48543 L
.79623 .48073 L
.79799 .47572 L
.79971 .46601 L
.80442 .45629 L
.80594 .45253 L
.80801 .44658 L
.80987 .43687 L
.81443 .42716 L
.81566 .42408 L
.81794 .41744 L
.81987 .40773 L
.82433 .39802 L
.82537 .39539 L
.82778 .38831 L
.82975 .37859 L
.83414 .36888 L
.83508 .36646 L
.83754 .35917 L
.83949 .34946 L
.84384 .33974 L
.84479 .33728 L
.84722 .33003 L
.84911 .32032 L
.85345 .31061 L
.85451 .30787 L
.85683 .30089 L
.85861 .29118 L
.86297 .28147 L
.86422 .27822 L
Mistroke
.86635 .27176 L
.86799 .26204 L
.8724 .25233 L
.87393 .24834 L
.87581 .24262 L
.87724 .23291 L
.88173 .22319 L
.88364 .21822 L
.88519 .21348 L
.88634 .20377 L
.89097 .19406 L
.89336 .18788 L
.89451 .18434 L
.89761 .17463 L
.9001 .16492 L
.90307 .15731 L
.90375 .15521 L
.90684 .14549 L
.90912 .13578 L
.91278 .12653 L
.91293 .12607 L
.916 .11636 L
.91802 .10664 L
.92198 .09693 L
.92249 .0955 L
.9251 .08722 L
.92676 .07751 L
.93091 .06779 L
.93221 .06424 L
.93414 .05808 L
.93533 .04837 L
.93973 .03866 L
.94192 .03276 L
.94311 .02894 L
.94611 .01923 L
Mfstroke
.3 g
.63224 .98077 m
.63621 .97106 L
.64046 .96134 L
.64083 .96055 L
.64464 .95163 L
.64883 .94192 L
.65054 .93804 L
.65396 .93221 L
.65709 .92249 L
.66026 .91508 L
.66147 .91278 L
.66525 .90307 L
.66932 .89336 L
.66997 .89186 L
.67482 .88364 L
.67733 .87393 L
.67968 .8683 L
.68181 .86422 L
.68525 .85451 L
.68921 .84479 L
.68939 .84436 L
.69474 .83508 L
.697 .82537 L
.69911 .82019 L
.7014 .81566 L
.70471 .80594 L
.70857 .79623 L
.70882 .79562 L
.7138 .78652 L
.71616 .77681 L
.71853 .77082 L
.72033 .76709 L
.72369 .75738 L
.72745 .74767 L
.72824 .74568 L
.73218 .73796 L
.73488 .72824 L
.73796 .72023 L
.73873 .71853 L
.74411 .70882 L
.74591 .69911 L
.74767 .69453 L
.75009 .68939 L
.75318 .67968 L
.75682 .66997 L
.75738 .6685 L
.76141 .66026 L
.76399 .65054 L
.76709 .64218 L
.76768 .64083 L
.77271 .63112 L
.77467 .62141 L
.77681 .61563 L
.77855 .61169 L
.78171 .60198 L
.78523 .59227 L
.78652 .58878 L
.78934 .58256 L
.79219 .57284 L
.79568 .56313 L
.79623 .56163 L
.80002 .55342 L
.80256 .54371 L
.80594 .5342 L
.80603 .53399 L
.8106 .52428 L
.81282 .51457 L
.81566 .50654 L
.81635 .50486 L
.82106 .49514 L
.82298 .48543 L
.82537 .47861 L
.82657 .47572 L
.83139 .46601 L
.83303 .45629 L
.83508 .45042 L
.83667 .44658 L
.84158 .43687 L
.843 .42716 L
.84479 .42196 L
.84666 .41744 L
.85163 .40773 L
.85287 .39802 L
.85451 .39324 L
.85654 .38831 L
.86151 .37859 L
.86265 .36888 L
.86422 .36427 L
.86631 .35917 L
.87125 .34946 L
.87235 .33974 L
.87393 .33505 L
.87596 .33003 L
.88083 .32032 L
.88196 .31061 L
.88364 .30558 L
.88551 .30089 L
.89027 .29118 L
.8915 .28147 L
.89336 .27585 L
.89497 .27176 L
.89958 .26204 L
.90096 .25233 L
.90307 .24588 L
.90433 .24262 L
.90878 .23291 L
.91034 .22319 L
.91278 .21567 L
.91361 .21348 L
.91788 .20377 L
.91965 .19406 L
.92249 .18521 L
.92282 .18434 L
.92691 .17463 L
.92889 .16492 L
.93199 .15521 L
.93221 .15453 L
.93586 .14549 L
.93807 .13578 L
.94114 .12607 L
.94192 .12362 L
.94477 .11636 L
.94718 .10664 L
.95022 .09693 L
.95163 .09247 L
.95362 .08722 L
.95814 .07751 L
.95924 .06779 L
.96134 .06107 L
.96244 .05808 L
.96663 .04837 L
.9682 .03866 L
.97106 .02943 L
.97121 .02894 L
.97422 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.63224 .98077 m
.63621 .97106 L
.64046 .96134 L
.64083 .96055 L
.64464 .95163 L
.64883 .94192 L
.65054 .93804 L
.65396 .93221 L
.65709 .92249 L
.66026 .91508 L
.66147 .91278 L
.66525 .90307 L
.66932 .89336 L
.66997 .89186 L
.67482 .88364 L
.67733 .87393 L
.67968 .8683 L
.68181 .86422 L
.68525 .85451 L
.68921 .84479 L
.68939 .84436 L
.69474 .83508 L
.697 .82537 L
.69911 .82019 L
.7014 .81566 L
.70471 .80594 L
.70857 .79623 L
.70882 .79562 L
.7138 .78652 L
.71616 .77681 L
.71853 .77082 L
.72033 .76709 L
.72369 .75738 L
.72745 .74767 L
.72824 .74568 L
.73218 .73796 L
.73488 .72824 L
.73796 .72023 L
.73873 .71853 L
.74411 .70882 L
.74591 .69911 L
.74767 .69453 L
.75009 .68939 L
.75318 .67968 L
.75682 .66997 L
.75738 .6685 L
.76141 .66026 L
.76399 .65054 L
.76709 .64218 L
.76768 .64083 L
Mistroke
.77271 .63112 L
.77467 .62141 L
.77681 .61563 L
.77855 .61169 L
.78171 .60198 L
.78523 .59227 L
.78652 .58878 L
.78934 .58256 L
.79219 .57284 L
.79568 .56313 L
.79623 .56163 L
.80002 .55342 L
.80256 .54371 L
.80594 .5342 L
.80603 .53399 L
.8106 .52428 L
.81282 .51457 L
.81566 .50654 L
.81635 .50486 L
.82106 .49514 L
.82298 .48543 L
.82537 .47861 L
.82657 .47572 L
.83139 .46601 L
.83303 .45629 L
.83508 .45042 L
.83667 .44658 L
.84158 .43687 L
.843 .42716 L
.84479 .42196 L
.84666 .41744 L
.85163 .40773 L
.85287 .39802 L
.85451 .39324 L
.85654 .38831 L
.86151 .37859 L
.86265 .36888 L
.86422 .36427 L
.86631 .35917 L
.87125 .34946 L
.87235 .33974 L
.87393 .33505 L
.87596 .33003 L
.88083 .32032 L
.88196 .31061 L
.88364 .30558 L
.88551 .30089 L
.89027 .29118 L
.8915 .28147 L
.89336 .27585 L
Mistroke
.89497 .27176 L
.89958 .26204 L
.90096 .25233 L
.90307 .24588 L
.90433 .24262 L
.90878 .23291 L
.91034 .22319 L
.91278 .21567 L
.91361 .21348 L
.91788 .20377 L
.91965 .19406 L
.92249 .18521 L
.92282 .18434 L
.92691 .17463 L
.92889 .16492 L
.93199 .15521 L
.93221 .15453 L
.93586 .14549 L
.93807 .13578 L
.94114 .12607 L
.94192 .12362 L
.94477 .11636 L
.94718 .10664 L
.95022 .09693 L
.95163 .09247 L
.95362 .08722 L
.95814 .07751 L
.95924 .06779 L
.96134 .06107 L
.96244 .05808 L
.96663 .04837 L
.9682 .03866 L
.97106 .02943 L
.97121 .02894 L
.97422 .01923 L
Mfstroke
.4 g
.98077 .02195 m
.97869 .02894 L
.97575 .03866 L
.97169 .04837 L
.97106 .05395 L
.97006 .05808 L
.96712 .06779 L
.96398 .07751 L
.96134 .08571 L
.96101 .08722 L
.95821 .09693 L
.95507 .10664 L
.95192 .11636 L
.95163 .11725 L
.94922 .12607 L
.94609 .13578 L
.94291 .14549 L
.94192 .14856 L
.94015 .15521 L
.93705 .16492 L
.93384 .17463 L
.93221 .17964 L
.93099 .18434 L
.92793 .19406 L
.9247 .20377 L
.92249 .21048 L
.92174 .21348 L
.91874 .22319 L
.9155 .23291 L
.91278 .24109 L
.91241 .24262 L
.90948 .25233 L
.90623 .26204 L
.90307 .27147 L
.903 .27176 L
.90014 .28147 L
.89688 .29118 L
.89359 .30089 L
.89336 .3016 L
.89072 .31061 L
.88745 .32032 L
.88414 .33003 L
.88364 .3315 L
.88123 .33974 L
.87795 .34946 L
.87461 .35917 L
.87393 .36116 L
.87166 .36888 L
.86836 .37859 L
.865 .38831 L
.86422 .39057 L
.86201 .39802 L
.85869 .40773 L
.8553 .41744 L
.85451 .41974 L
.85228 .42716 L
.84893 .43687 L
.84552 .44658 L
.84479 .44866 L
.84247 .45629 L
.83909 .46601 L
.83564 .47572 L
.83508 .47732 L
.83257 .48543 L
.82915 .49514 L
.82568 .50486 L
.82537 .50574 L
.82258 .51457 L
.81912 .52428 L
.81566 .5339 L
.81563 .53399 L
.81249 .54371 L
.80898 .55342 L
.80594 .5618 L
.80556 .56313 L
.8023 .57284 L
.79875 .58256 L
.79623 .58945 L
.79538 .59227 L
.792 .60198 L
.78841 .61169 L
.78652 .61683 L
.78507 .62141 L
.78159 .63112 L
.77796 .64083 L
.77681 .64395 L
.77464 .65054 L
.77106 .66026 L
.7674 .66997 L
.76709 .67079 L
.76407 .67968 L
.76041 .68939 L
.75738 .69737 L
.75683 .69911 L
.75336 .70882 L
.74964 .71853 L
.74767 .72368 L
.74614 .72824 L
.74251 .73796 L
.73874 .74767 L
.73796 .7497 L
.73527 .75738 L
.73152 .76709 L
.72824 .77545 L
.7278 .77681 L
.72422 .78652 L
.72038 .79623 L
.71853 .80092 L
.71677 .80594 L
.71299 .81566 L
.70911 .82537 L
.70882 .8261 L
.70551 .83508 L
.70161 .84479 L
.69911 .851 L
.69786 .85451 L
.69404 .86422 L
.69007 .87393 L
.68939 .87559 L
.68636 .88364 L
.68238 .89336 L
.67968 .89989 L
.67852 .90307 L
.67462 .91278 L
.67055 .92249 L
.66997 .92389 L
.66674 .93221 L
.66266 .94192 L
.66026 .94759 L
.65872 .95163 L
.65468 .96134 L
.65054 .97097 L
.65051 .97106 L
.64659 .98077 L
.98077 .98077 L
F
0 g
.98077 .02195 m
.97869 .02894 L
.97575 .03866 L
.97169 .04837 L
.97106 .05395 L
.97006 .05808 L
.96712 .06779 L
.96398 .07751 L
.96134 .08571 L
.96101 .08722 L
.95821 .09693 L
.95507 .10664 L
.95192 .11636 L
.95163 .11725 L
.94922 .12607 L
.94609 .13578 L
.94291 .14549 L
.94192 .14856 L
.94015 .15521 L
.93705 .16492 L
.93384 .17463 L
.93221 .17964 L
.93099 .18434 L
.92793 .19406 L
.9247 .20377 L
.92249 .21048 L
.92174 .21348 L
.91874 .22319 L
.9155 .23291 L
.91278 .24109 L
.91241 .24262 L
.90948 .25233 L
.90623 .26204 L
.90307 .27147 L
.903 .27176 L
.90014 .28147 L
.89688 .29118 L
.89359 .30089 L
.89336 .3016 L
.89072 .31061 L
.88745 .32032 L
.88414 .33003 L
.88364 .3315 L
.88123 .33974 L
.87795 .34946 L
.87461 .35917 L
.87393 .36116 L
.87166 .36888 L
.86836 .37859 L
.865 .38831 L
Mistroke
.86422 .39057 L
.86201 .39802 L
.85869 .40773 L
.8553 .41744 L
.85451 .41974 L
.85228 .42716 L
.84893 .43687 L
.84552 .44658 L
.84479 .44866 L
.84247 .45629 L
.83909 .46601 L
.83564 .47572 L
.83508 .47732 L
.83257 .48543 L
.82915 .49514 L
.82568 .50486 L
.82537 .50574 L
.82258 .51457 L
.81912 .52428 L
.81566 .5339 L
.81563 .53399 L
.81249 .54371 L
.80898 .55342 L
.80594 .5618 L
.80556 .56313 L
.8023 .57284 L
.79875 .58256 L
.79623 .58945 L
.79538 .59227 L
.792 .60198 L
.78841 .61169 L
.78652 .61683 L
.78507 .62141 L
.78159 .63112 L
.77796 .64083 L
.77681 .64395 L
.77464 .65054 L
.77106 .66026 L
.7674 .66997 L
.76709 .67079 L
.76407 .67968 L
.76041 .68939 L
.75738 .69737 L
.75683 .69911 L
.75336 .70882 L
.74964 .71853 L
.74767 .72368 L
.74614 .72824 L
.74251 .73796 L
.73874 .74767 L
Mistroke
.73796 .7497 L
.73527 .75738 L
.73152 .76709 L
.72824 .77545 L
.7278 .77681 L
.72422 .78652 L
.72038 .79623 L
.71853 .80092 L
.71677 .80594 L
.71299 .81566 L
.70911 .82537 L
.70882 .8261 L
.70551 .83508 L
.70161 .84479 L
.69911 .851 L
.69786 .85451 L
.69404 .86422 L
.69007 .87393 L
.68939 .87559 L
.68636 .88364 L
.68238 .89336 L
.67968 .89989 L
.67852 .90307 L
.67462 .91278 L
.67055 .92249 L
.66997 .92389 L
.66674 .93221 L
.66266 .94192 L
.66026 .94759 L
.65872 .95163 L
.65468 .96134 L
.65054 .97097 L
.65051 .97106 L
.64659 .98077 L
Mfstroke
.5 g
.98077 .04219 m
.97661 .04837 L
.97495 .05808 L
.97281 .06779 L
.97106 .07426 L
.97012 .07751 L
.96718 .08722 L
.96417 .09693 L
.96134 .1061 L
.96119 .10664 L
.95827 .11636 L
.95525 .12607 L
.95223 .13578 L
.95163 .13772 L
.9493 .14549 L
.94627 .15521 L
.94322 .16492 L
.94192 .16911 L
.94026 .17463 L
.93723 .18434 L
.93416 .19406 L
.93221 .20027 L
.93116 .20377 L
.92813 .21348 L
.92503 .22319 L
.92249 .2312 L
.92198 .23291 L
.91895 .24262 L
.91584 .25233 L
.91278 .2619 L
.91274 .26204 L
.90971 .27176 L
.90658 .28147 L
.90345 .29118 L
.90307 .29237 L
.9004 .30089 L
.89725 .31061 L
.89409 .32032 L
.89336 .3226 L
.89102 .33003 L
.88785 .33974 L
.88466 .34946 L
.88364 .35259 L
.88156 .35917 L
.87838 .36888 L
.87516 .37859 L
.87393 .38234 L
.87203 .38831 L
.86882 .39802 L
.86558 .40773 L
.86422 .41185 L
.86242 .41744 L
.85919 .42716 L
.85593 .43687 L
.85451 .44112 L
.85273 .44658 L
.84948 .45629 L
.84619 .46601 L
.84479 .47014 L
.84297 .47572 L
.83968 .48543 L
.83636 .49514 L
.83508 .49891 L
.83311 .50486 L
.8298 .51457 L
.82645 .52428 L
.82537 .52743 L
.82317 .53399 L
.81982 .54371 L
.81645 .55342 L
.81566 .5557 L
.81314 .56313 L
.80975 .57284 L
.80635 .58256 L
.80594 .58372 L
.80301 .59227 L
.79959 .60198 L
.79623 .61148 L
.79616 .61169 L
.79278 .62141 L
.78932 .63112 L
.78652 .63898 L
.78588 .64083 L
.78245 .65054 L
.77895 .66026 L
.77681 .66621 L
.77549 .66997 L
.77201 .67968 L
.76847 .68939 L
.76709 .69319 L
.76499 .69911 L
.76145 .70882 L
.75788 .71853 L
.75738 .71989 L
.75437 .72824 L
.75078 .73796 L
.74767 .74633 L
.74719 .74767 L
.74362 .75738 L
.73998 .76709 L
.73796 .77249 L
.73638 .77681 L
.73274 .78652 L
.72906 .79623 L
.72824 .79838 L
.72543 .80594 L
.72172 .81566 L
.71853 .82399 L
.71802 .82537 L
.71433 .83508 L
.71057 .84479 L
.70882 .84932 L
.70685 .85451 L
.70308 .86422 L
.69928 .87393 L
.69911 .87436 L
.69551 .88364 L
.69168 .89336 L
.68939 .89912 L
.68786 .90307 L
.68401 .91278 L
.68012 .92249 L
.67968 .92358 L
.67626 .93221 L
.67234 .94192 L
.66997 .94775 L
.66842 .95163 L
.66448 .96134 L
.66049 .97106 L
.66026 .97162 L
.65653 .98077 L
.98077 .98077 L
F
0 g
.98077 .04219 m
.97661 .04837 L
.97495 .05808 L
.97281 .06779 L
.97106 .07426 L
.97012 .07751 L
.96718 .08722 L
.96417 .09693 L
.96134 .1061 L
.96119 .10664 L
.95827 .11636 L
.95525 .12607 L
.95223 .13578 L
.95163 .13772 L
.9493 .14549 L
.94627 .15521 L
.94322 .16492 L
.94192 .16911 L
.94026 .17463 L
.93723 .18434 L
.93416 .19406 L
.93221 .20027 L
.93116 .20377 L
.92813 .21348 L
.92503 .22319 L
.92249 .2312 L
.92198 .23291 L
.91895 .24262 L
.91584 .25233 L
.91278 .2619 L
.91274 .26204 L
.90971 .27176 L
.90658 .28147 L
.90345 .29118 L
.90307 .29237 L
.9004 .30089 L
.89725 .31061 L
.89409 .32032 L
.89336 .3226 L
.89102 .33003 L
.88785 .33974 L
.88466 .34946 L
.88364 .35259 L
.88156 .35917 L
.87838 .36888 L
.87516 .37859 L
.87393 .38234 L
.87203 .38831 L
.86882 .39802 L
.86558 .40773 L
Mistroke
.86422 .41185 L
.86242 .41744 L
.85919 .42716 L
.85593 .43687 L
.85451 .44112 L
.85273 .44658 L
.84948 .45629 L
.84619 .46601 L
.84479 .47014 L
.84297 .47572 L
.83968 .48543 L
.83636 .49514 L
.83508 .49891 L
.83311 .50486 L
.8298 .51457 L
.82645 .52428 L
.82537 .52743 L
.82317 .53399 L
.81982 .54371 L
.81645 .55342 L
.81566 .5557 L
.81314 .56313 L
.80975 .57284 L
.80635 .58256 L
.80594 .58372 L
.80301 .59227 L
.79959 .60198 L
.79623 .61148 L
.79616 .61169 L
.79278 .62141 L
.78932 .63112 L
.78652 .63898 L
.78588 .64083 L
.78245 .65054 L
.77895 .66026 L
.77681 .66621 L
.77549 .66997 L
.77201 .67968 L
.76847 .68939 L
.76709 .69319 L
.76499 .69911 L
.76145 .70882 L
.75788 .71853 L
.75738 .71989 L
.75437 .72824 L
.75078 .73796 L
.74767 .74633 L
.74719 .74767 L
.74362 .75738 L
.73998 .76709 L
Mistroke
.73796 .77249 L
.73638 .77681 L
.73274 .78652 L
.72906 .79623 L
.72824 .79838 L
.72543 .80594 L
.72172 .81566 L
.71853 .82399 L
.71802 .82537 L
.71433 .83508 L
.71057 .84479 L
.70882 .84932 L
.70685 .85451 L
.70308 .86422 L
.69928 .87393 L
.69911 .87436 L
.69551 .88364 L
.69168 .89336 L
.68939 .89912 L
.68786 .90307 L
.68401 .91278 L
.68012 .92249 L
.67968 .92358 L
.67626 .93221 L
.67234 .94192 L
.66997 .94775 L
.66842 .95163 L
.66448 .96134 L
.66049 .97106 L
.66026 .97162 L
.65653 .98077 L
Mfstroke
.6 g
.98077 .06146 m
.97852 .06779 L
.97574 .07751 L
.97295 .08722 L
.97106 .0936 L
.97005 .09693 L
.96706 .10664 L
.96407 .11636 L
.96134 .12551 L
.96117 .12607 L
.95819 .13578 L
.95517 .14549 L
.95222 .15521 L
.95163 .1572 L
.94925 .16492 L
.94621 .17463 L
.94321 .18434 L
.94192 .18866 L
.94024 .19406 L
.93719 .20377 L
.93415 .21348 L
.93221 .21989 L
.93118 .22319 L
.92811 .23291 L
.92504 .24262 L
.92249 .2509 L
.92205 .25233 L
.91896 .26204 L
.91587 .27176 L
.91284 .28147 L
.91278 .28167 L
.90975 .29118 L
.90663 .30089 L
.90356 .31061 L
.90307 .31221 L
.90047 .32032 L
.89732 .33003 L
.89422 .33974 L
.89336 .34252 L
.89112 .34946 L
.88795 .35917 L
.88481 .36888 L
.88364 .37259 L
.88169 .37859 L
.8785 .38831 L
.87533 .39802 L
.87393 .40243 L
.87219 .40773 L
.86898 .41744 L
.86578 .42716 L
.86422 .43202 L
.86262 .43687 L
.85938 .44658 L
.85615 .45629 L
.85451 .46137 L
.85296 .46601 L
.8497 .47572 L
.84645 .48543 L
.84479 .49048 L
.84323 .49514 L
.83993 .50486 L
.83666 .51457 L
.83508 .51934 L
.83341 .52428 L
.83009 .53399 L
.82678 .54371 L
.82537 .54795 L
.8235 .55342 L
.82015 .56313 L
.81682 .57284 L
.81566 .57631 L
.8135 .58256 L
.81012 .59227 L
.80677 .60198 L
.80594 .60442 L
.80341 .61169 L
.8 .62141 L
.79663 .63112 L
.79623 .63228 L
.79322 .64083 L
.78978 .65054 L
.78652 .65988 L
.78639 .66026 L
.78293 .66997 L
.77946 .67968 L
.77681 .68722 L
.77603 .68939 L
.77253 .69911 L
.76903 .70882 L
.76709 .71429 L
.76556 .71853 L
.76203 .72824 L
.75851 .73796 L
.75738 .74111 L
.75498 .74767 L
.75141 .75738 L
.74787 .76709 L
.74767 .76765 L
.74428 .77681 L
.74068 .78652 L
.73796 .79393 L
.7371 .79623 L
.73346 .80594 L
.72982 .81566 L
.72824 .81993 L
.7262 .82537 L
.72251 .83508 L
.71885 .84479 L
.71853 .84566 L
.71516 .85451 L
.71143 .86422 L
.70882 .87111 L
.70773 .87393 L
.70398 .88364 L
.70022 .89336 L
.69911 .89628 L
.69646 .90307 L
.69265 .91278 L
.68939 .92116 L
.68887 .92249 L
.68503 .93221 L
.68119 .94192 L
.67968 .94576 L
.67734 .95163 L
.67345 .96134 L
.66997 .97006 L
.66957 .97106 L
.66564 .98077 L
.98077 .98077 L
F
0 g
.98077 .06146 m
.97852 .06779 L
.97574 .07751 L
.97295 .08722 L
.97106 .0936 L
.97005 .09693 L
.96706 .10664 L
.96407 .11636 L
.96134 .12551 L
.96117 .12607 L
.95819 .13578 L
.95517 .14549 L
.95222 .15521 L
.95163 .1572 L
.94925 .16492 L
.94621 .17463 L
.94321 .18434 L
.94192 .18866 L
.94024 .19406 L
.93719 .20377 L
.93415 .21348 L
.93221 .21989 L
.93118 .22319 L
.92811 .23291 L
.92504 .24262 L
.92249 .2509 L
.92205 .25233 L
.91896 .26204 L
.91587 .27176 L
.91284 .28147 L
.91278 .28167 L
.90975 .29118 L
.90663 .30089 L
.90356 .31061 L
.90307 .31221 L
.90047 .32032 L
.89732 .33003 L
.89422 .33974 L
.89336 .34252 L
.89112 .34946 L
.88795 .35917 L
.88481 .36888 L
.88364 .37259 L
.88169 .37859 L
.8785 .38831 L
.87533 .39802 L
.87393 .40243 L
.87219 .40773 L
.86898 .41744 L
.86578 .42716 L
Mistroke
.86422 .43202 L
.86262 .43687 L
.85938 .44658 L
.85615 .45629 L
.85451 .46137 L
.85296 .46601 L
.8497 .47572 L
.84645 .48543 L
.84479 .49048 L
.84323 .49514 L
.83993 .50486 L
.83666 .51457 L
.83508 .51934 L
.83341 .52428 L
.83009 .53399 L
.82678 .54371 L
.82537 .54795 L
.8235 .55342 L
.82015 .56313 L
.81682 .57284 L
.81566 .57631 L
.8135 .58256 L
.81012 .59227 L
.80677 .60198 L
.80594 .60442 L
.80341 .61169 L
.8 .62141 L
.79663 .63112 L
.79623 .63228 L
.79322 .64083 L
.78978 .65054 L
.78652 .65988 L
.78639 .66026 L
.78293 .66997 L
.77946 .67968 L
.77681 .68722 L
.77603 .68939 L
.77253 .69911 L
.76903 .70882 L
.76709 .71429 L
.76556 .71853 L
.76203 .72824 L
.75851 .73796 L
.75738 .74111 L
.75498 .74767 L
.75141 .75738 L
.74787 .76709 L
.74767 .76765 L
.74428 .77681 L
.74068 .78652 L
Mistroke
.73796 .79393 L
.7371 .79623 L
.73346 .80594 L
.72982 .81566 L
.72824 .81993 L
.7262 .82537 L
.72251 .83508 L
.71885 .84479 L
.71853 .84566 L
.71516 .85451 L
.71143 .86422 L
.70882 .87111 L
.70773 .87393 L
.70398 .88364 L
.70022 .89336 L
.69911 .89628 L
.69646 .90307 L
.69265 .91278 L
.68939 .92116 L
.68887 .92249 L
.68503 .93221 L
.68119 .94192 L
.67968 .94576 L
.67734 .95163 L
.67345 .96134 L
.66997 .97006 L
.66957 .97106 L
.66564 .98077 L
Mfstroke
.7 g
.98077 .08169 m
.97907 .08722 L
.9762 .09693 L
.97329 .10664 L
.97106 .1139 L
.97029 .11636 L
.9672 .12607 L
.96412 .13578 L
.96143 .14549 L
.96134 .1459 L
.95838 .15521 L
.95527 .16492 L
.95237 .17463 L
.95163 .17766 L
.9495 .18434 L
.94636 .19406 L
.94334 .20377 L
.94192 .20921 L
.94055 .21348 L
.9374 .22319 L
.9343 .23291 L
.93221 .24053 L
.93154 .24262 L
.92837 .25233 L
.92522 .26204 L
.92249 .27162 L
.92245 .27176 L
.91928 .28147 L
.91609 .29118 L
.91318 .30089 L
.91278 .30248 L
.91012 .31061 L
.9069 .32032 L
.90388 .33003 L
.90307 .33311 L
.90088 .33974 L
.89764 .34946 L
.89454 .35917 L
.89336 .36351 L
.89158 .36888 L
.88831 .37859 L
.88516 .38831 L
.88364 .39368 L
.8822 .39802 L
.87891 .40773 L
.87571 .41744 L
.87393 .42361 L
.87274 .42716 L
.86943 .43687 L
.86619 .44658 L
.86422 .4533 L
.86321 .45629 L
.85988 .46601 L
.85661 .47572 L
.85451 .48275 L
.85359 .48543 L
.85024 .49514 L
.84694 .50486 L
.84479 .51196 L
.8439 .51457 L
.84052 .52428 L
.8372 .53399 L
.83508 .54092 L
.83412 .54371 L
.83072 .55342 L
.82737 .56313 L
.82537 .56964 L
.82425 .57284 L
.82082 .58256 L
.81746 .59227 L
.81566 .59811 L
.81429 .60198 L
.81084 .61169 L
.80747 .62141 L
.80594 .62634 L
.80424 .63112 L
.80076 .64083 L
.7974 .65054 L
.79623 .65431 L
.79409 .66026 L
.79058 .66997 L
.78724 .67968 L
.78652 .68202 L
.78384 .68939 L
.78031 .69911 L
.77701 .70882 L
.77681 .70949 L
.77349 .71853 L
.76994 .72824 L
.76709 .73669 L
.76663 .73796 L
.76303 .74767 L
.75947 .75738 L
.75738 .76363 L
.75609 .76709 L
.75245 .77681 L
.74892 .78652 L
.74767 .7903 L
.74544 .79623 L
.74177 .80594 L
.7383 .81566 L
.73796 .81672 L
.73466 .82537 L
.73098 .83508 L
.72824 .84286 L
.72751 .84479 L
.72376 .85451 L
.7201 .86422 L
.71853 .86873 L
.71652 .87393 L
.71274 .88364 L
.70915 .89336 L
.70882 .89433 L
.70539 .90307 L
.70161 .91278 L
.69911 .91965 L
.69798 .92249 L
.69413 .93221 L
.69038 .94192 L
.68939 .94469 L
.68662 .95163 L
.68274 .96134 L
.67968 .96945 L
.67904 .97106 L
.6751 .98077 L
.98077 .98077 L
F
0 g
.98077 .08169 m
.97907 .08722 L
.9762 .09693 L
.97329 .10664 L
.97106 .1139 L
.97029 .11636 L
.9672 .12607 L
.96412 .13578 L
.96143 .14549 L
.96134 .1459 L
.95838 .15521 L
.95527 .16492 L
.95237 .17463 L
.95163 .17766 L
.9495 .18434 L
.94636 .19406 L
.94334 .20377 L
.94192 .20921 L
.94055 .21348 L
.9374 .22319 L
.9343 .23291 L
.93221 .24053 L
.93154 .24262 L
.92837 .25233 L
.92522 .26204 L
.92249 .27162 L
.92245 .27176 L
.91928 .28147 L
.91609 .29118 L
.91318 .30089 L
.91278 .30248 L
.91012 .31061 L
.9069 .32032 L
.90388 .33003 L
.90307 .33311 L
.90088 .33974 L
.89764 .34946 L
.89454 .35917 L
.89336 .36351 L
.89158 .36888 L
.88831 .37859 L
.88516 .38831 L
.88364 .39368 L
.8822 .39802 L
.87891 .40773 L
.87571 .41744 L
.87393 .42361 L
.87274 .42716 L
.86943 .43687 L
.86619 .44658 L
Mistroke
.86422 .4533 L
.86321 .45629 L
.85988 .46601 L
.85661 .47572 L
.85451 .48275 L
.85359 .48543 L
.85024 .49514 L
.84694 .50486 L
.84479 .51196 L
.8439 .51457 L
.84052 .52428 L
.8372 .53399 L
.83508 .54092 L
.83412 .54371 L
.83072 .55342 L
.82737 .56313 L
.82537 .56964 L
.82425 .57284 L
.82082 .58256 L
.81746 .59227 L
.81566 .59811 L
.81429 .60198 L
.81084 .61169 L
.80747 .62141 L
.80594 .62634 L
.80424 .63112 L
.80076 .64083 L
.7974 .65054 L
.79623 .65431 L
.79409 .66026 L
.79058 .66997 L
.78724 .67968 L
.78652 .68202 L
.78384 .68939 L
.78031 .69911 L
.77701 .70882 L
.77681 .70949 L
.77349 .71853 L
.76994 .72824 L
.76709 .73669 L
.76663 .73796 L
.76303 .74767 L
.75947 .75738 L
.75738 .76363 L
.75609 .76709 L
.75245 .77681 L
.74892 .78652 L
.74767 .7903 L
.74544 .79623 L
.74177 .80594 L
Mistroke
.7383 .81566 L
.73796 .81672 L
.73466 .82537 L
.73098 .83508 L
.72824 .84286 L
.72751 .84479 L
.72376 .85451 L
.7201 .86422 L
.71853 .86873 L
.71652 .87393 L
.71274 .88364 L
.70915 .89336 L
.70882 .89433 L
.70539 .90307 L
.70161 .91278 L
.69911 .91965 L
.69798 .92249 L
.69413 .93221 L
.69038 .94192 L
.68939 .94469 L
.68662 .95163 L
.68274 .96134 L
.67968 .96945 L
.67904 .97106 L
.6751 .98077 L
Mfstroke
.8 g
.98077 .10607 m
.98061 .10664 L
.97788 .11636 L
.97504 .12607 L
.97196 .13578 L
.97106 .1384 L
.96844 .14549 L
.96396 .15521 L
.96307 .16492 L
.96134 .17053 L
.95987 .17463 L
.95575 .18434 L
.95422 .19406 L
.95163 .20247 L
.95117 .20377 L
.94731 .21348 L
.94532 .22319 L
.94231 .23291 L
.94192 .23415 L
.93868 .24262 L
.93635 .25233 L
.93333 .26204 L
.93221 .26562 L
.9299 .27176 L
.92543 .28147 L
.92429 .29118 L
.92249 .29687 L
.92101 .30089 L
.91678 .31061 L
.91519 .32032 L
.91278 .32791 L
.912 .33003 L
.90795 .33974 L
.90602 .34946 L
.90307 .35872 L
.90291 .35917 L
.89897 .36888 L
.89679 .37859 L
.89368 .38831 L
.89336 .38928 L
.88987 .39802 L
.88749 .40773 L
.88436 .41744 L
.88364 .41961 L
.88066 .42716 L
.87812 .43687 L
.87497 .44658 L
.87393 .44972 L
.87134 .45629 L
.86656 .46601 L
.86551 .47572 L
.86422 .47959 L
.86192 .48543 L
.85721 .49514 L
.85597 .50486 L
.85451 .50924 L
.8524 .51457 L
.84772 .52428 L
.84636 .53399 L
.84479 .53865 L
.84279 .54371 L
.8381 .55342 L
.83668 .56313 L
.83508 .56782 L
.83307 .57284 L
.82834 .58256 L
.82691 .59227 L
.82537 .59676 L
.82325 .60198 L
.81844 .61169 L
.81706 .62141 L
.81566 .62545 L
.81333 .63112 L
.80838 .64083 L
.80712 .65054 L
.80594 .65391 L
.80329 .66026 L
.80046 .66997 L
.7971 .67968 L
.79623 .68212 L
.79312 .68939 L
.79038 .69911 L
.78698 .70882 L
.78652 .7101 L
.78281 .71853 L
.7802 .72824 L
.77681 .73784 L
.77676 .73796 L
.77234 .74767 L
.76993 .75738 L
.76709 .76529 L
.76635 .76709 L
.76167 .77681 L
.75955 .78652 L
.75738 .79249 L
.75579 .79623 L
.75075 .80594 L
.74907 .81566 L
.74767 .81945 L
.74505 .82537 L
.74204 .83508 L
.73848 .84479 L
.73796 .84618 L
.73409 .85451 L
.73138 .86422 L
.72824 .87266 L
.7277 .87393 L
.72282 .88364 L
.7206 .89336 L
.71853 .89883 L
.71663 .90307 L
.71336 .91278 L
.7097 .92249 L
.70882 .92477 L
.70528 .93221 L
.70239 .94192 L
.69911 .9505 L
.69861 .95163 L
.69349 .96134 L
.69128 .97106 L
.68939 .97599 L
.68709 .98077 L
.98077 .98077 L
F
0 g
.98077 .10607 m
.98061 .10664 L
.97788 .11636 L
.97504 .12607 L
.97196 .13578 L
.97106 .1384 L
.96844 .14549 L
.96396 .15521 L
.96307 .16492 L
.96134 .17053 L
.95987 .17463 L
.95575 .18434 L
.95422 .19406 L
.95163 .20247 L
.95117 .20377 L
.94731 .21348 L
.94532 .22319 L
.94231 .23291 L
.94192 .23415 L
.93868 .24262 L
.93635 .25233 L
.93333 .26204 L
.93221 .26562 L
.9299 .27176 L
.92543 .28147 L
.92429 .29118 L
.92249 .29687 L
.92101 .30089 L
.91678 .31061 L
.91519 .32032 L
.91278 .32791 L
.912 .33003 L
.90795 .33974 L
.90602 .34946 L
.90307 .35872 L
.90291 .35917 L
.89897 .36888 L
.89679 .37859 L
.89368 .38831 L
.89336 .38928 L
.88987 .39802 L
.88749 .40773 L
.88436 .41744 L
.88364 .41961 L
.88066 .42716 L
.87812 .43687 L
.87497 .44658 L
.87393 .44972 L
.87134 .45629 L
.86656 .46601 L
Mistroke
.86551 .47572 L
.86422 .47959 L
.86192 .48543 L
.85721 .49514 L
.85597 .50486 L
.85451 .50924 L
.8524 .51457 L
.84772 .52428 L
.84636 .53399 L
.84479 .53865 L
.84279 .54371 L
.8381 .55342 L
.83668 .56313 L
.83508 .56782 L
.83307 .57284 L
.82834 .58256 L
.82691 .59227 L
.82537 .59676 L
.82325 .60198 L
.81844 .61169 L
.81706 .62141 L
.81566 .62545 L
.81333 .63112 L
.80838 .64083 L
.80712 .65054 L
.80594 .65391 L
.80329 .66026 L
.80046 .66997 L
.7971 .67968 L
.79623 .68212 L
.79312 .68939 L
.79038 .69911 L
.78698 .70882 L
.78652 .7101 L
.78281 .71853 L
.7802 .72824 L
.77681 .73784 L
.77676 .73796 L
.77234 .74767 L
.76993 .75738 L
.76709 .76529 L
.76635 .76709 L
.76167 .77681 L
.75955 .78652 L
.75738 .79249 L
.75579 .79623 L
.75075 .80594 L
.74907 .81566 L
.74767 .81945 L
.74505 .82537 L
Mistroke
.74204 .83508 L
.73848 .84479 L
.73796 .84618 L
.73409 .85451 L
.73138 .86422 L
.72824 .87266 L
.7277 .87393 L
.72282 .88364 L
.7206 .89336 L
.71853 .89883 L
.71663 .90307 L
.71336 .91278 L
.7097 .92249 L
.70882 .92477 L
.70528 .93221 L
.70239 .94192 L
.69911 .9505 L
.69861 .95163 L
.69349 .96134 L
.69128 .97106 L
.68939 .97599 L
.68709 .98077 L
Mfstroke
.7 g
.98077 .19899 m
.97936 .20377 L
.97642 .21348 L
.97342 .22319 L
.97106 .23084 L
.97041 .23291 L
.96741 .24262 L
.9654 .25233 L
.96149 .26204 L
.96134 .26244 L
.95844 .27176 L
.95679 .28147 L
.95261 .29118 L
.95163 .29384 L
.94941 .30089 L
.94818 .31061 L
.9437 .32032 L
.94192 .32501 L
.94032 .33003 L
.93726 .33974 L
.93474 .34946 L
.93221 .35593 L
.93116 .35917 L
.92808 .36888 L
.92572 .37859 L
.92249 .38661 L
.92194 .38831 L
.91883 .39802 L
.91663 .40773 L
.91278 .41704 L
.91265 .41744 L
.90951 .42716 L
.90747 .43687 L
.90332 .44658 L
.90307 .44725 L
.90012 .45629 L
.89821 .46601 L
.89393 .47572 L
.89336 .47722 L
.89065 .48543 L
.88884 .49514 L
.88446 .50486 L
.88364 .50694 L
.88111 .51457 L
.87936 .52428 L
.87489 .53399 L
.87393 .53642 L
.87149 .54371 L
.86976 .55342 L
.86522 .56313 L
.86422 .56564 L
.86178 .57284 L
.86001 .58256 L
.85545 .59227 L
.85451 .59461 L
.85199 .60198 L
.85013 .61169 L
.84557 .62141 L
.84479 .62333 L
.84211 .63112 L
.84011 .64083 L
.83558 .65054 L
.83508 .65178 L
.83214 .66026 L
.82995 .66997 L
.82549 .67968 L
.82537 .67997 L
.82208 .68939 L
.81967 .69911 L
.81566 .70792 L
.81533 .70882 L
.81191 .71853 L
.80926 .72824 L
.80594 .73562 L
.8051 .73796 L
.80164 .74767 L
.79874 .75738 L
.79623 .76303 L
.79475 .76709 L
.79127 .77681 L
.78811 .78652 L
.78652 .79015 L
.7843 .79623 L
.78232 .80594 L
.77738 .81566 L
.77681 .81699 L
.77373 .82537 L
.77121 .83508 L
.76709 .84358 L
.76663 .84479 L
.76303 .85451 L
.76004 .86422 L
.75738 .8699 L
.75585 .87393 L
.75222 .88364 L
.74882 .89336 L
.74767 .8959 L
.74494 .90307 L
.74248 .91278 L
.73796 .92161 L
.73761 .92249 L
.73389 .93221 L
.73075 .94192 L
.72824 .94708 L
.72645 .95163 L
.72456 .96134 L
.71905 .97106 L
.71853 .9721 L
.71515 .98077 L
.98077 .98077 L
F
0 g
.98077 .19899 m
.97936 .20377 L
.97642 .21348 L
.97342 .22319 L
.97106 .23084 L
.97041 .23291 L
.96741 .24262 L
.9654 .25233 L
.96149 .26204 L
.96134 .26244 L
.95844 .27176 L
.95679 .28147 L
.95261 .29118 L
.95163 .29384 L
.94941 .30089 L
.94818 .31061 L
.9437 .32032 L
.94192 .32501 L
.94032 .33003 L
.93726 .33974 L
.93474 .34946 L
.93221 .35593 L
.93116 .35917 L
.92808 .36888 L
.92572 .37859 L
.92249 .38661 L
.92194 .38831 L
.91883 .39802 L
.91663 .40773 L
.91278 .41704 L
.91265 .41744 L
.90951 .42716 L
.90747 .43687 L
.90332 .44658 L
.90307 .44725 L
.90012 .45629 L
.89821 .46601 L
.89393 .47572 L
.89336 .47722 L
.89065 .48543 L
.88884 .49514 L
.88446 .50486 L
.88364 .50694 L
.88111 .51457 L
.87936 .52428 L
.87489 .53399 L
.87393 .53642 L
.87149 .54371 L
.86976 .55342 L
.86522 .56313 L
Mistroke
.86422 .56564 L
.86178 .57284 L
.86001 .58256 L
.85545 .59227 L
.85451 .59461 L
.85199 .60198 L
.85013 .61169 L
.84557 .62141 L
.84479 .62333 L
.84211 .63112 L
.84011 .64083 L
.83558 .65054 L
.83508 .65178 L
.83214 .66026 L
.82995 .66997 L
.82549 .67968 L
.82537 .67997 L
.82208 .68939 L
.81967 .69911 L
.81566 .70792 L
.81533 .70882 L
.81191 .71853 L
.80926 .72824 L
.80594 .73562 L
.8051 .73796 L
.80164 .74767 L
.79874 .75738 L
.79623 .76303 L
.79475 .76709 L
.79127 .77681 L
.78811 .78652 L
.78652 .79015 L
.7843 .79623 L
.78232 .80594 L
.77738 .81566 L
.77681 .81699 L
.77373 .82537 L
.77121 .83508 L
.76709 .84358 L
.76663 .84479 L
.76303 .85451 L
.76004 .86422 L
.75738 .8699 L
.75585 .87393 L
.75222 .88364 L
.74882 .89336 L
.74767 .8959 L
.74494 .90307 L
.74248 .91278 L
.73796 .92161 L
Mistroke
.73761 .92249 L
.73389 .93221 L
.73075 .94192 L
.72824 .94708 L
.72645 .95163 L
.72456 .96134 L
.71905 .97106 L
.71853 .9721 L
.71515 .98077 L
Mfstroke
.6 g
.98077 .22334 m
.97792 .23291 L
.97496 .24262 L
.97155 .25233 L
.97106 .25533 L
.96933 .26204 L
.96629 .27176 L
.96314 .28147 L
.96134 .2871 L
.96035 .29118 L
.95739 .30089 L
.95422 .31061 L
.95163 .31864 L
.95125 .32032 L
.94841 .33003 L
.94524 .33974 L
.94208 .34946 L
.94192 .34994 L
.93936 .35917 L
.93619 .36888 L
.933 .37859 L
.93221 .38102 L
.93022 .38831 L
.92708 .39802 L
.92385 .40773 L
.92249 .41187 L
.921 .41744 L
.91789 .42716 L
.91464 .43687 L
.91278 .44248 L
.91171 .44658 L
.90863 .45629 L
.90536 .46601 L
.90307 .47285 L
.90233 .47572 L
.89929 .48543 L
.896 .49514 L
.89336 .50299 L
.89288 .50486 L
.88987 .51457 L
.88657 .52428 L
.88364 .53289 L
.88336 .53399 L
.88038 .54371 L
.87706 .55342 L
.87393 .56254 L
.87378 .56313 L
.8708 .57284 L
.86746 .58256 L
.86422 .59195 L
.86414 .59227 L
.86115 .60198 L
.85779 .61169 L
.85451 .62112 L
.85443 .62141 L
.85141 .63112 L
.84802 .64083 L
.84479 .65004 L
.84466 .65054 L
.84159 .66026 L
.83817 .66997 L
.83508 .67871 L
.83482 .67968 L
.83168 .68939 L
.82823 .69911 L
.82537 .70712 L
.82489 .70882 L
.82167 .71853 L
.81818 .72824 L
.81566 .73529 L
.81487 .73796 L
.81157 .74767 L
.80805 .75738 L
.80594 .76319 L
.80476 .76709 L
.80136 .77681 L
.7978 .78652 L
.79623 .79083 L
.79453 .79623 L
.79105 .80594 L
.78746 .81566 L
.78652 .81821 L
.78418 .82537 L
.78063 .83508 L
.777 .84479 L
.77681 .84533 L
.77371 .85451 L
.77009 .86422 L
.76709 .87218 L
.76655 .87393 L
.76311 .88364 L
.75943 .89336 L
.75738 .89876 L
.75597 .90307 L
.75238 .91278 L
.74865 .92249 L
.74767 .92506 L
.74521 .93221 L
.74151 .94192 L
.73796 .95109 L
.73778 .95163 L
.73429 .96134 L
.7305 .97106 L
.72824 .97681 L
.7269 .98077 L
.98077 .98077 L
F
0 g
.98077 .22334 m
.97792 .23291 L
.97496 .24262 L
.97155 .25233 L
.97106 .25533 L
.96933 .26204 L
.96629 .27176 L
.96314 .28147 L
.96134 .2871 L
.96035 .29118 L
.95739 .30089 L
.95422 .31061 L
.95163 .31864 L
.95125 .32032 L
.94841 .33003 L
.94524 .33974 L
.94208 .34946 L
.94192 .34994 L
.93936 .35917 L
.93619 .36888 L
.933 .37859 L
.93221 .38102 L
.93022 .38831 L
.92708 .39802 L
.92385 .40773 L
.92249 .41187 L
.921 .41744 L
.91789 .42716 L
.91464 .43687 L
.91278 .44248 L
.91171 .44658 L
.90863 .45629 L
.90536 .46601 L
.90307 .47285 L
.90233 .47572 L
.89929 .48543 L
.896 .49514 L
.89336 .50299 L
.89288 .50486 L
.88987 .51457 L
.88657 .52428 L
.88364 .53289 L
.88336 .53399 L
.88038 .54371 L
.87706 .55342 L
.87393 .56254 L
.87378 .56313 L
.8708 .57284 L
.86746 .58256 L
.86422 .59195 L
Mistroke
.86414 .59227 L
.86115 .60198 L
.85779 .61169 L
.85451 .62112 L
.85443 .62141 L
.85141 .63112 L
.84802 .64083 L
.84479 .65004 L
.84466 .65054 L
.84159 .66026 L
.83817 .66997 L
.83508 .67871 L
.83482 .67968 L
.83168 .68939 L
.82823 .69911 L
.82537 .70712 L
.82489 .70882 L
.82167 .71853 L
.81818 .72824 L
.81566 .73529 L
.81487 .73796 L
.81157 .74767 L
.80805 .75738 L
.80594 .76319 L
.80476 .76709 L
.80136 .77681 L
.7978 .78652 L
.79623 .79083 L
.79453 .79623 L
.79105 .80594 L
.78746 .81566 L
.78652 .81821 L
.78418 .82537 L
.78063 .83508 L
.777 .84479 L
.77681 .84533 L
.77371 .85451 L
.77009 .86422 L
.76709 .87218 L
.76655 .87393 L
.76311 .88364 L
.75943 .89336 L
.75738 .89876 L
.75597 .90307 L
.75238 .91278 L
.74865 .92249 L
.74767 .92506 L
.74521 .93221 L
.74151 .94192 L
.73796 .95109 L
Mistroke
.73778 .95163 L
.73429 .96134 L
.7305 .97106 L
.72824 .97681 L
.7269 .98077 L
Mfstroke
.5 g
.98077 .24357 m
.9761 .25233 L
.97445 .26204 L
.97213 .27176 L
.97106 .27564 L
.96935 .28147 L
.96638 .29118 L
.96337 .30089 L
.96134 .30749 L
.96043 .31061 L
.95748 .32032 L
.95445 .33003 L
.95163 .3391 L
.95145 .33974 L
.94851 .34946 L
.94546 .35917 L
.94242 .36888 L
.94192 .37049 L
.93947 .37859 L
.93642 .38831 L
.93335 .39802 L
.93221 .40166 L
.93037 .40773 L
.92731 .41744 L
.92421 .42716 L
.92249 .43259 L
.9212 .43687 L
.91813 .44658 L
.91501 .45629 L
.91278 .46329 L
.91195 .46601 L
.90889 .47572 L
.90575 .48543 L
.90307 .49375 L
.90264 .49514 L
.89957 .50486 L
.89641 .51457 L
.89336 .52398 L
.89326 .52428 L
.89018 .53399 L
.887 .54371 L
.88382 .55342 L
.88364 .55397 L
.88072 .56313 L
.87752 .57284 L
.87431 .58256 L
.87393 .58372 L
.87119 .59227 L
.86796 .60198 L
.86473 .61169 L
.86422 .61323 L
.86157 .62141 L
.85832 .63112 L
.85506 .64083 L
.85451 .6425 L
.85188 .65054 L
.8486 .66026 L
.84532 .66997 L
.84479 .67152 L
.8421 .67968 L
.8388 .68939 L
.83548 .69911 L
.83508 .70029 L
.83224 .70882 L
.82891 .71853 L
.82556 .72824 L
.82537 .72882 L
.82229 .73796 L
.81892 .74767 L
.81566 .75709 L
.81556 .75738 L
.81225 .76709 L
.80885 .77681 L
.80594 .7851 L
.80547 .78652 L
.80211 .79623 L
.79867 .80594 L
.79623 .81286 L
.79528 .81566 L
.79187 .82537 L
.7884 .83508 L
.78652 .84036 L
.78498 .84479 L
.78152 .85451 L
.77802 .86422 L
.77681 .8676 L
.77458 .87393 L
.77107 .88364 L
.76753 .89336 L
.76709 .89457 L
.76406 .90307 L
.7605 .91278 L
.75738 .92128 L
.75695 .92249 L
.75342 .93221 L
.74982 .94192 L
.74767 .94771 L
.74625 .95163 L
.74265 .96134 L
.73901 .97106 L
.73796 .97387 L
.73542 .98077 L
.98077 .98077 L
F
0 g
.98077 .24357 m
.9761 .25233 L
.97445 .26204 L
.97213 .27176 L
.97106 .27564 L
.96935 .28147 L
.96638 .29118 L
.96337 .30089 L
.96134 .30749 L
.96043 .31061 L
.95748 .32032 L
.95445 .33003 L
.95163 .3391 L
.95145 .33974 L
.94851 .34946 L
.94546 .35917 L
.94242 .36888 L
.94192 .37049 L
.93947 .37859 L
.93642 .38831 L
.93335 .39802 L
.93221 .40166 L
.93037 .40773 L
.92731 .41744 L
.92421 .42716 L
.92249 .43259 L
.9212 .43687 L
.91813 .44658 L
.91501 .45629 L
.91278 .46329 L
.91195 .46601 L
.90889 .47572 L
.90575 .48543 L
.90307 .49375 L
.90264 .49514 L
.89957 .50486 L
.89641 .51457 L
.89336 .52398 L
.89326 .52428 L
.89018 .53399 L
.887 .54371 L
.88382 .55342 L
.88364 .55397 L
.88072 .56313 L
.87752 .57284 L
.87431 .58256 L
.87393 .58372 L
.87119 .59227 L
.86796 .60198 L
.86473 .61169 L
Mistroke
.86422 .61323 L
.86157 .62141 L
.85832 .63112 L
.85506 .64083 L
.85451 .6425 L
.85188 .65054 L
.8486 .66026 L
.84532 .66997 L
.84479 .67152 L
.8421 .67968 L
.8388 .68939 L
.83548 .69911 L
.83508 .70029 L
.83224 .70882 L
.82891 .71853 L
.82556 .72824 L
.82537 .72882 L
.82229 .73796 L
.81892 .74767 L
.81566 .75709 L
.81556 .75738 L
.81225 .76709 L
.80885 .77681 L
.80594 .7851 L
.80547 .78652 L
.80211 .79623 L
.79867 .80594 L
.79623 .81286 L
.79528 .81566 L
.79187 .82537 L
.7884 .83508 L
.78652 .84036 L
.78498 .84479 L
.78152 .85451 L
.77802 .86422 L
.77681 .8676 L
.77458 .87393 L
.77107 .88364 L
.76753 .89336 L
.76709 .89457 L
.76406 .90307 L
.7605 .91278 L
.75738 .92128 L
.75695 .92249 L
.75342 .93221 L
.74982 .94192 L
.74767 .94771 L
.74625 .95163 L
.74265 .96134 L
.73901 .97106 L
Mistroke
.73796 .97387 L
.73542 .98077 L
Mfstroke
.4 g
.98077 .26284 m
.97775 .27176 L
.97501 .28147 L
.97219 .29118 L
.97106 .29498 L
.96926 .30089 L
.96627 .31061 L
.96329 .32032 L
.96134 .32689 L
.96039 .33003 L
.95739 .33974 L
.95437 .34946 L
.95163 .35858 L
.95145 .35917 L
.94844 .36888 L
.94541 .37859 L
.94243 .38831 L
.94192 .39004 L
.93944 .39802 L
.93638 .40773 L
.93336 .41744 L
.93221 .42128 L
.93037 .42716 L
.92729 .43687 L
.92423 .44658 L
.92249 .45228 L
.92123 .45629 L
.91814 .46601 L
.91505 .47572 L
.91278 .48306 L
.91203 .48543 L
.90892 .49514 L
.9058 .50486 L
.90307 .5136 L
.90276 .51457 L
.89964 .52428 L
.89649 .53399 L
.89342 .54371 L
.89336 .54391 L
.89028 .55342 L
.88711 .56313 L
.884 .57284 L
.88364 .57398 L
.88085 .58256 L
.87765 .59227 L
.87451 .60198 L
.87393 .60381 L
.87134 .61169 L
.86812 .62141 L
.86495 .63112 L
.86422 .6334 L
.86176 .64083 L
.85852 .65054 L
.85531 .66026 L
.85451 .66275 L
.8521 .66997 L
.84883 .67968 L
.8456 .68939 L
.84479 .69186 L
.84236 .69911 L
.83906 .70882 L
.8358 .71853 L
.83508 .72072 L
.83253 .72824 L
.8292 .73796 L
.82592 .74767 L
.82537 .74933 L
.82261 .75738 L
.81926 .76709 L
.81595 .77681 L
.81566 .7777 L
.81261 .78652 L
.80922 .79623 L
.80594 .80581 L
.8059 .80594 L
.80251 .81566 L
.7991 .82537 L
.79623 .83366 L
.79574 .83508 L
.79231 .84479 L
.78887 .85451 L
.78652 .86126 L
.78547 .86422 L
.78201 .87393 L
.77854 .88364 L
.77681 .8886 L
.77511 .89336 L
.7716 .90307 L
.76812 .91278 L
.76709 .91568 L
.76463 .92249 L
.76109 .93221 L
.75758 .94192 L
.75738 .94249 L
.75404 .95163 L
.75046 .96134 L
.74767 .96904 L
.74693 .97106 L
.74333 .98077 L
.98077 .98077 L
F
0 g
.98077 .26284 m
.97775 .27176 L
.97501 .28147 L
.97219 .29118 L
.97106 .29498 L
.96926 .30089 L
.96627 .31061 L
.96329 .32032 L
.96134 .32689 L
.96039 .33003 L
.95739 .33974 L
.95437 .34946 L
.95163 .35858 L
.95145 .35917 L
.94844 .36888 L
.94541 .37859 L
.94243 .38831 L
.94192 .39004 L
.93944 .39802 L
.93638 .40773 L
.93336 .41744 L
.93221 .42128 L
.93037 .42716 L
.92729 .43687 L
.92423 .44658 L
.92249 .45228 L
.92123 .45629 L
.91814 .46601 L
.91505 .47572 L
.91278 .48306 L
.91203 .48543 L
.90892 .49514 L
.9058 .50486 L
.90307 .5136 L
.90276 .51457 L
.89964 .52428 L
.89649 .53399 L
.89342 .54371 L
.89336 .54391 L
.89028 .55342 L
.88711 .56313 L
.884 .57284 L
.88364 .57398 L
.88085 .58256 L
.87765 .59227 L
.87451 .60198 L
.87393 .60381 L
.87134 .61169 L
.86812 .62141 L
.86495 .63112 L
Mistroke
.86422 .6334 L
.86176 .64083 L
.85852 .65054 L
.85531 .66026 L
.85451 .66275 L
.8521 .66997 L
.84883 .67968 L
.8456 .68939 L
.84479 .69186 L
.84236 .69911 L
.83906 .70882 L
.8358 .71853 L
.83508 .72072 L
.83253 .72824 L
.8292 .73796 L
.82592 .74767 L
.82537 .74933 L
.82261 .75738 L
.81926 .76709 L
.81595 .77681 L
.81566 .7777 L
.81261 .78652 L
.80922 .79623 L
.80594 .80581 L
.8059 .80594 L
.80251 .81566 L
.7991 .82537 L
.79623 .83366 L
.79574 .83508 L
.79231 .84479 L
.78887 .85451 L
.78652 .86126 L
.78547 .86422 L
.78201 .87393 L
.77854 .88364 L
.77681 .8886 L
.77511 .89336 L
.7716 .90307 L
.76812 .91278 L
.76709 .91568 L
.76463 .92249 L
.76109 .93221 L
.75758 .94192 L
.75738 .94249 L
.75404 .95163 L
.75046 .96134 L
.74767 .96904 L
.74693 .97106 L
.74333 .98077 L
Mfstroke
.3 g
.98077 .28307 m
.97831 .29118 L
.97544 .30089 L
.97251 .31061 L
.97106 .31529 L
.96948 .32032 L
.96638 .33003 L
.96334 .33974 L
.96134 .34728 L
.96066 .34946 L
.95756 .35917 L
.95446 .36888 L
.95173 .37859 L
.95163 .37905 L
.94867 .38831 L
.94553 .39802 L
.94262 .40773 L
.94192 .41059 L
.93972 .41744 L
.93656 .42716 L
.93353 .43687 L
.93221 .44191 L
.9307 .44658 L
.92753 .45629 L
.92442 .46601 L
.92249 .473 L
.92162 .47572 L
.91843 .48543 L
.91527 .49514 L
.91278 .50387 L
.91246 .50486 L
.90926 .51457 L
.90606 .52428 L
.90319 .53399 L
.90307 .5345 L
.90002 .54371 L
.89679 .55342 L
.89381 .56313 L
.89336 .5649 L
.89071 .57284 L
.88745 .58256 L
.88439 .59227 L
.88364 .59506 L
.88133 .60198 L
.87804 .61169 L
.87492 .62141 L
.87393 .62499 L
.87187 .63112 L
.86856 .64083 L
.86539 .65054 L
.86422 .65468 L
.86233 .66026 L
.859 .66997 L
.85579 .67968 L
.85451 .68413 L
.85271 .68939 L
.84935 .69911 L
.84612 .70882 L
.84479 .71334 L
.84301 .71853 L
.83963 .72824 L
.83637 .73796 L
.83508 .74231 L
.83322 .74767 L
.82981 .75738 L
.82654 .76709 L
.82537 .77103 L
.82334 .77681 L
.81991 .78652 L
.81663 .79623 L
.81566 .7995 L
.81338 .80594 L
.80992 .81566 L
.80665 .82537 L
.80594 .82772 L
.80332 .83508 L
.79984 .84479 L
.79658 .85451 L
.79623 .85569 L
.79316 .86422 L
.78966 .87393 L
.78652 .88341 L
.78644 .88364 L
.7829 .89336 L
.77939 .90307 L
.77681 .91087 L
.77611 .91278 L
.77254 .92249 L
.76903 .93221 L
.76709 .93807 L
.76568 .94192 L
.76207 .95163 L
.75858 .96134 L
.75738 .96501 L
.75513 .97106 L
.75149 .98077 L
.98077 .98077 L
F
0 g
.98077 .28307 m
.97831 .29118 L
.97544 .30089 L
.97251 .31061 L
.97106 .31529 L
.96948 .32032 L
.96638 .33003 L
.96334 .33974 L
.96134 .34728 L
.96066 .34946 L
.95756 .35917 L
.95446 .36888 L
.95173 .37859 L
.95163 .37905 L
.94867 .38831 L
.94553 .39802 L
.94262 .40773 L
.94192 .41059 L
.93972 .41744 L
.93656 .42716 L
.93353 .43687 L
.93221 .44191 L
.9307 .44658 L
.92753 .45629 L
.92442 .46601 L
.92249 .473 L
.92162 .47572 L
.91843 .48543 L
.91527 .49514 L
.91278 .50387 L
.91246 .50486 L
.90926 .51457 L
.90606 .52428 L
.90319 .53399 L
.90307 .5345 L
.90002 .54371 L
.89679 .55342 L
.89381 .56313 L
.89336 .5649 L
.89071 .57284 L
.88745 .58256 L
.88439 .59227 L
.88364 .59506 L
.88133 .60198 L
.87804 .61169 L
.87492 .62141 L
.87393 .62499 L
.87187 .63112 L
.86856 .64083 L
.86539 .65054 L
Mistroke
.86422 .65468 L
.86233 .66026 L
.859 .66997 L
.85579 .67968 L
.85451 .68413 L
.85271 .68939 L
.84935 .69911 L
.84612 .70882 L
.84479 .71334 L
.84301 .71853 L
.83963 .72824 L
.83637 .73796 L
.83508 .74231 L
.83322 .74767 L
.82981 .75738 L
.82654 .76709 L
.82537 .77103 L
.82334 .77681 L
.81991 .78652 L
.81663 .79623 L
.81566 .7995 L
.81338 .80594 L
.80992 .81566 L
.80665 .82537 L
.80594 .82772 L
.80332 .83508 L
.79984 .84479 L
.79658 .85451 L
.79623 .85569 L
.79316 .86422 L
.78966 .87393 L
.78652 .88341 L
.78644 .88364 L
.7829 .89336 L
.77939 .90307 L
.77681 .91087 L
.77611 .91278 L
.77254 .92249 L
.76903 .93221 L
.76709 .93807 L
.76568 .94192 L
.76207 .95163 L
.75858 .96134 L
.75738 .96501 L
.75513 .97106 L
.75149 .98077 L
Mfstroke
.2 g
.98077 .30743 m
.97989 .31061 L
.97714 .32032 L
.97425 .33003 L
.97108 .33974 L
.97106 .33981 L
.96738 .34946 L
.96524 .35917 L
.96228 .36888 L
.96134 .37192 L
.95887 .37859 L
.95443 .38831 L
.95343 .39802 L
.95163 .40383 L
.95022 .40773 L
.9461 .41744 L
.94452 .42716 L
.94192 .43555 L
.94145 .43687 L
.93755 .44658 L
.93555 .45629 L
.93253 .46601 L
.93221 .46702 L
.92884 .47572 L
.92652 .48543 L
.92348 .49514 L
.92249 .49825 L
.91998 .50486 L
.91541 .51457 L
.91438 .52428 L
.91278 .52928 L
.91101 .53399 L
.90666 .54371 L
.9052 .55342 L
.90307 .56008 L
.90194 .56313 L
.89775 .57284 L
.89597 .58256 L
.89336 .59067 L
.89276 .59227 L
.88869 .60198 L
.88666 .61169 L
.88364 .62102 L
.8835 .62141 L
.87951 .63112 L
.87729 .64083 L
.87413 .65054 L
.87393 .65112 L
.87021 .66026 L
.86784 .66997 L
.86466 .67968 L
.86422 .68099 L
.8608 .68939 L
.85833 .69911 L
.85512 .70882 L
.85451 .71063 L
.85129 .71853 L
.84873 .72824 L
.8455 .73796 L
.84479 .74004 L
.84167 .74767 L
.83906 .75738 L
.83581 .76709 L
.83508 .76921 L
.83194 .77681 L
.82932 .78652 L
.82603 .79623 L
.82537 .79815 L
.82211 .80594 L
.81949 .81566 L
.81617 .82537 L
.81566 .82685 L
.81216 .83508 L
.80957 .84479 L
.80623 .85451 L
.80594 .85531 L
.80209 .86422 L
.79957 .87393 L
.79623 .88354 L
.79619 .88364 L
.79187 .89336 L
.78948 .90307 L
.78652 .91149 L
.786 .91278 L
.7815 .92249 L
.77929 .93221 L
.77681 .9392 L
.77568 .94192 L
.77094 .95163 L
.76901 .96134 L
.76709 .96665 L
.76522 .97106 L
.76015 .98077 L
.98077 .98077 L
F
0 g
.98077 .30743 m
.97989 .31061 L
.97714 .32032 L
.97425 .33003 L
.97108 .33974 L
.97106 .33981 L
.96738 .34946 L
.96524 .35917 L
.96228 .36888 L
.96134 .37192 L
.95887 .37859 L
.95443 .38831 L
.95343 .39802 L
.95163 .40383 L
.95022 .40773 L
.9461 .41744 L
.94452 .42716 L
.94192 .43555 L
.94145 .43687 L
.93755 .44658 L
.93555 .45629 L
.93253 .46601 L
.93221 .46702 L
.92884 .47572 L
.92652 .48543 L
.92348 .49514 L
.92249 .49825 L
.91998 .50486 L
.91541 .51457 L
.91438 .52428 L
.91278 .52928 L
.91101 .53399 L
.90666 .54371 L
.9052 .55342 L
.90307 .56008 L
.90194 .56313 L
.89775 .57284 L
.89597 .58256 L
.89336 .59067 L
.89276 .59227 L
.88869 .60198 L
.88666 .61169 L
.88364 .62102 L
.8835 .62141 L
.87951 .63112 L
.87729 .64083 L
.87413 .65054 L
.87393 .65112 L
.87021 .66026 L
.86784 .66997 L
Mistroke
.86466 .67968 L
.86422 .68099 L
.8608 .68939 L
.85833 .69911 L
.85512 .70882 L
.85451 .71063 L
.85129 .71853 L
.84873 .72824 L
.8455 .73796 L
.84479 .74004 L
.84167 .74767 L
.83906 .75738 L
.83581 .76709 L
.83508 .76921 L
.83194 .77681 L
.82932 .78652 L
.82603 .79623 L
.82537 .79815 L
.82211 .80594 L
.81949 .81566 L
.81617 .82537 L
.81566 .82685 L
.81216 .83508 L
.80957 .84479 L
.80623 .85451 L
.80594 .85531 L
.80209 .86422 L
.79957 .87393 L
.79623 .88354 L
.79619 .88364 L
.79187 .89336 L
.78948 .90307 L
.78652 .91149 L
.786 .91278 L
.7815 .92249 L
.77929 .93221 L
.77681 .9392 L
.77568 .94192 L
.77094 .95163 L
.76901 .96134 L
.76709 .96665 L
.76522 .97106 L
.76015 .98077 L
Mfstroke
.3 g
.98077 .40036 m
.97859 .40773 L
.97563 .41744 L
.97262 .42716 L
.97106 .43223 L
.96961 .43687 L
.96661 .44658 L
.96427 .45629 L
.96134 .46384 L
.96066 .46601 L
.95764 .47572 L
.95557 .48543 L
.95166 .49514 L
.95163 .49521 L
.9486 .50486 L
.94685 .51457 L
.9427 .52428 L
.94192 .52638 L
.9395 .53399 L
.93809 .54371 L
.93369 .55342 L
.93221 .55731 L
.93034 .56313 L
.92929 .57284 L
.92462 .58256 L
.92249 .58801 L
.92111 .59227 L
.918 .60198 L
.91548 .61169 L
.91278 .61845 L
.91181 .62141 L
.90868 .63112 L
.90626 .64083 L
.90307 .64865 L
.90244 .65054 L
.89928 .66026 L
.89696 .66997 L
.89336 .67861 L
.893 .67968 L
.88981 .68939 L
.88756 .69911 L
.88364 .70832 L
.88348 .70882 L
.88026 .71853 L
.87804 .72824 L
.87393 .73779 L
.87387 .73796 L
.87063 .74767 L
.86842 .75738 L
.86422 .76701 L
.86419 .76709 L
.86092 .77681 L
.85866 .78652 L
.85451 .79598 L
.85442 .79623 L
.85112 .80594 L
.84879 .81566 L
.84479 .82471 L
.84456 .82537 L
.84123 .83508 L
.83878 .84479 L
.83508 .85318 L
.83461 .85451 L
.83125 .86422 L
.82865 .87393 L
.82537 .88139 L
.82457 .88364 L
.82118 .89336 L
.81839 .90307 L
.81566 .90933 L
.81442 .91278 L
.811 .92249 L
.80802 .93221 L
.80594 .937 L
.80418 .94192 L
.80261 .95163 L
.79754 .96134 L
.79623 .9644 L
.79382 .97106 L
.79177 .98077 L
.98077 .98077 L
F
0 g
.98077 .40036 m
.97859 .40773 L
.97563 .41744 L
.97262 .42716 L
.97106 .43223 L
.96961 .43687 L
.96661 .44658 L
.96427 .45629 L
.96134 .46384 L
.96066 .46601 L
.95764 .47572 L
.95557 .48543 L
.95166 .49514 L
.95163 .49521 L
.9486 .50486 L
.94685 .51457 L
.9427 .52428 L
.94192 .52638 L
.9395 .53399 L
.93809 .54371 L
.93369 .55342 L
.93221 .55731 L
.93034 .56313 L
.92929 .57284 L
.92462 .58256 L
.92249 .58801 L
.92111 .59227 L
.918 .60198 L
.91548 .61169 L
.91278 .61845 L
.91181 .62141 L
.90868 .63112 L
.90626 .64083 L
.90307 .64865 L
.90244 .65054 L
.89928 .66026 L
.89696 .66997 L
.89336 .67861 L
.893 .67968 L
.88981 .68939 L
.88756 .69911 L
.88364 .70832 L
.88348 .70882 L
.88026 .71853 L
.87804 .72824 L
.87393 .73779 L
.87387 .73796 L
.87063 .74767 L
.86842 .75738 L
.86422 .76701 L
Mistroke
.86419 .76709 L
.86092 .77681 L
.85866 .78652 L
.85451 .79598 L
.85442 .79623 L
.85112 .80594 L
.84879 .81566 L
.84479 .82471 L
.84456 .82537 L
.84123 .83508 L
.83878 .84479 L
.83508 .85318 L
.83461 .85451 L
.83125 .86422 L
.82865 .87393 L
.82537 .88139 L
.82457 .88364 L
.82118 .89336 L
.81839 .90307 L
.81566 .90933 L
.81442 .91278 L
.811 .92249 L
.80802 .93221 L
.80594 .937 L
.80418 .94192 L
.80261 .95163 L
.79754 .96134 L
.79623 .9644 L
.79382 .97106 L
.79177 .98077 L
Mfstroke
.4 g
.98077 .42473 m
.98005 .42716 L
.97714 .43687 L
.97417 .44658 L
.97114 .45629 L
.97106 .45672 L
.96856 .46601 L
.96546 .47572 L
.96232 .48543 L
.96134 .48848 L
.95961 .49514 L
.95655 .50486 L
.95339 .51457 L
.95163 .52002 L
.95057 .52428 L
.94758 .53399 L
.9444 .54371 L
.94192 .55133 L
.94142 .55342 L
.93854 .56313 L
.93534 .57284 L
.93221 .5824 L
.93217 .58256 L
.92941 .59227 L
.92622 .60198 L
.923 .61169 L
.92249 .61325 L
.92021 .62141 L
.91703 .63112 L
.91378 .64083 L
.91278 .64386 L
.91094 .65054 L
.90776 .66026 L
.90449 .66997 L
.90307 .67424 L
.90158 .67968 L
.89842 .68939 L
.89513 .69911 L
.89336 .70438 L
.89215 .70882 L
.889 .71853 L
.88569 .72824 L
.88364 .73427 L
.88265 .73796 L
.87951 .74767 L
.87617 .75738 L
.87393 .76393 L
.87307 .76709 L
.86993 .77681 L
.86657 .78652 L
.86422 .79334 L
.86343 .79623 L
.86027 .80594 L
.85689 .81566 L
.85451 .82251 L
.85371 .82537 L
.85053 .83508 L
.84711 .84479 L
.84479 .85143 L
.84392 .85451 L
.84069 .86422 L
.83726 .87393 L
.83508 .88009 L
.83405 .88364 L
.83077 .89336 L
.8273 .90307 L
.82537 .90851 L
.8241 .91278 L
.82076 .92249 L
.81726 .93221 L
.81566 .93667 L
.81405 .94192 L
.81064 .95163 L
.80711 .96134 L
.80594 .96457 L
.8039 .97106 L
.80042 .98077 L
.98077 .98077 L
F
0 g
.98077 .42473 m
.98005 .42716 L
.97714 .43687 L
.97417 .44658 L
.97114 .45629 L
.97106 .45672 L
.96856 .46601 L
.96546 .47572 L
.96232 .48543 L
.96134 .48848 L
.95961 .49514 L
.95655 .50486 L
.95339 .51457 L
.95163 .52002 L
.95057 .52428 L
.94758 .53399 L
.9444 .54371 L
.94192 .55133 L
.94142 .55342 L
.93854 .56313 L
.93534 .57284 L
.93221 .5824 L
.93217 .58256 L
.92941 .59227 L
.92622 .60198 L
.923 .61169 L
.92249 .61325 L
.92021 .62141 L
.91703 .63112 L
.91378 .64083 L
.91278 .64386 L
.91094 .65054 L
.90776 .66026 L
.90449 .66997 L
.90307 .67424 L
.90158 .67968 L
.89842 .68939 L
.89513 .69911 L
.89336 .70438 L
.89215 .70882 L
.889 .71853 L
.88569 .72824 L
.88364 .73427 L
.88265 .73796 L
.87951 .74767 L
.87617 .75738 L
.87393 .76393 L
.87307 .76709 L
.86993 .77681 L
.86657 .78652 L
Mistroke
.86422 .79334 L
.86343 .79623 L
.86027 .80594 L
.85689 .81566 L
.85451 .82251 L
.85371 .82537 L
.85053 .83508 L
.84711 .84479 L
.84479 .85143 L
.84392 .85451 L
.84069 .86422 L
.83726 .87393 L
.83508 .88009 L
.83405 .88364 L
.83077 .89336 L
.8273 .90307 L
.82537 .90851 L
.8241 .91278 L
.82076 .92249 L
.81726 .93221 L
.81566 .93667 L
.81405 .94192 L
.81064 .95163 L
.80711 .96134 L
.80594 .96457 L
.8039 .97106 L
.80042 .98077 L
Mfstroke
.5 g
.98077 .44496 m
.98029 .44658 L
.9757 .45629 L
.9739 .46601 L
.97143 .47572 L
.97106 .47703 L
.96857 .48543 L
.96558 .49514 L
.96257 .50486 L
.96134 .50887 L
.95966 .51457 L
.95667 .52428 L
.95364 .53399 L
.95163 .54049 L
.95068 .54371 L
.9477 .55342 L
.94465 .56313 L
.94192 .57188 L
.94164 .57284 L
.93867 .58256 L
.9356 .59227 L
.93254 .60198 L
.93221 .60304 L
.92956 .61169 L
.92649 .62141 L
.92339 .63112 L
.92249 .63397 L
.92039 .64083 L
.9173 .65054 L
.91419 .66026 L
.91278 .66467 L
.91115 .66997 L
.90806 .67968 L
.90491 .68939 L
.90307 .69514 L
.90184 .69911 L
.89874 .70882 L
.89557 .71853 L
.89336 .72537 L
.89246 .72824 L
.88934 .73796 L
.88616 .74767 L
.88364 .75536 L
.88301 .75738 L
.87988 .76709 L
.87667 .77681 L
.87393 .78511 L
.87349 .78652 L
.87034 .79623 L
.8671 .80594 L
.86422 .81462 L
.86389 .81566 L
.86072 .82537 L
.85746 .83508 L
.85451 .84389 L
.85422 .84479 L
.85102 .85451 L
.84773 .86422 L
.84479 .87291 L
.84446 .87393 L
.84123 .88364 L
.83792 .89336 L
.83508 .90168 L
.83463 .90307 L
.83136 .91278 L
.82802 .92249 L
.82537 .9302 L
.82471 .93221 L
.8214 .94192 L
.81803 .95163 L
.81566 .95847 L
.81469 .96134 L
.81135 .97106 L
.80794 .98077 L
.98077 .98077 L
F
0 g
.98077 .44496 m
.98029 .44658 L
.9757 .45629 L
.9739 .46601 L
.97143 .47572 L
.97106 .47703 L
.96857 .48543 L
.96558 .49514 L
.96257 .50486 L
.96134 .50887 L
.95966 .51457 L
.95667 .52428 L
.95364 .53399 L
.95163 .54049 L
.95068 .54371 L
.9477 .55342 L
.94465 .56313 L
.94192 .57188 L
.94164 .57284 L
.93867 .58256 L
.9356 .59227 L
.93254 .60198 L
.93221 .60304 L
.92956 .61169 L
.92649 .62141 L
.92339 .63112 L
.92249 .63397 L
.92039 .64083 L
.9173 .65054 L
.91419 .66026 L
.91278 .66467 L
.91115 .66997 L
.90806 .67968 L
.90491 .68939 L
.90307 .69514 L
.90184 .69911 L
.89874 .70882 L
.89557 .71853 L
.89336 .72537 L
.89246 .72824 L
.88934 .73796 L
.88616 .74767 L
.88364 .75536 L
.88301 .75738 L
.87988 .76709 L
.87667 .77681 L
.87393 .78511 L
.87349 .78652 L
.87034 .79623 L
.8671 .80594 L
Mistroke
.86422 .81462 L
.86389 .81566 L
.86072 .82537 L
.85746 .83508 L
.85451 .84389 L
.85422 .84479 L
.85102 .85451 L
.84773 .86422 L
.84479 .87291 L
.84446 .87393 L
.84123 .88364 L
.83792 .89336 L
.83508 .90168 L
.83463 .90307 L
.83136 .91278 L
.82802 .92249 L
.82537 .9302 L
.82471 .93221 L
.8214 .94192 L
.81803 .95163 L
.81566 .95847 L
.81469 .96134 L
.81135 .97106 L
.80794 .98077 L
Mfstroke
.6 g
.98077 .46423 m
.98005 .46601 L
.97702 .47572 L
.97427 .48543 L
.97142 .49514 L
.97106 .49636 L
.96847 .50486 L
.96547 .51457 L
.96252 .52428 L
.96134 .52828 L
.9596 .53399 L
.95658 .54371 L
.95359 .55342 L
.95163 .55996 L
.95066 .56313 L
.94764 .57284 L
.9446 .58256 L
.94192 .59143 L
.94166 .59227 L
.93863 .60198 L
.93557 .61169 L
.93258 .62141 L
.93221 .62266 L
.92955 .63112 L
.92647 .64083 L
.92344 .65054 L
.92249 .65367 L
.92042 .66026 L
.91732 .66997 L
.91424 .67968 L
.91278 .68444 L
.91121 .68939 L
.90809 .69911 L
.90499 .70882 L
.90307 .71498 L
.90194 .71853 L
.8988 .72824 L
.89566 .73796 L
.89336 .74529 L
.89259 .74767 L
.88944 .75738 L
.88627 .76709 L
.88364 .77536 L
.88318 .77681 L
.88 .78652 L
.87681 .79623 L
.87393 .80519 L
.87369 .80594 L
.87049 .81566 L
.86727 .82537 L
.86422 .83479 L
.86412 .83508 L
.8609 .84479 L
.85766 .85451 L
.85451 .86414 L
.85448 .86422 L
.85123 .87393 L
.84796 .88364 L
.84479 .89325 L
.84476 .89336 L
.84148 .90307 L
.83819 .91278 L
.83508 .92211 L
.83495 .92249 L
.83165 .93221 L
.82832 .94192 L
.82537 .95072 L
.82506 .95163 L
.82172 .96134 L
.81837 .97106 L
.81566 .97908 L
.81508 .98077 L
.98077 .98077 L
F
0 g
.98077 .46423 m
.98005 .46601 L
.97702 .47572 L
.97427 .48543 L
.97142 .49514 L
.97106 .49636 L
.96847 .50486 L
.96547 .51457 L
.96252 .52428 L
.96134 .52828 L
.9596 .53399 L
.95658 .54371 L
.95359 .55342 L
.95163 .55996 L
.95066 .56313 L
.94764 .57284 L
.9446 .58256 L
.94192 .59143 L
.94166 .59227 L
.93863 .60198 L
.93557 .61169 L
.93258 .62141 L
.93221 .62266 L
.92955 .63112 L
.92647 .64083 L
.92344 .65054 L
.92249 .65367 L
.92042 .66026 L
.91732 .66997 L
.91424 .67968 L
.91278 .68444 L
.91121 .68939 L
.90809 .69911 L
.90499 .70882 L
.90307 .71498 L
.90194 .71853 L
.8988 .72824 L
.89566 .73796 L
.89336 .74529 L
.89259 .74767 L
.88944 .75738 L
.88627 .76709 L
.88364 .77536 L
.88318 .77681 L
.88 .78652 L
.87681 .79623 L
.87393 .80519 L
.87369 .80594 L
.87049 .81566 L
.86727 .82537 L
Mistroke
.86422 .83479 L
.86412 .83508 L
.8609 .84479 L
.85766 .85451 L
.85451 .86414 L
.85448 .86422 L
.85123 .87393 L
.84796 .88364 L
.84479 .89325 L
.84476 .89336 L
.84148 .90307 L
.83819 .91278 L
.83508 .92211 L
.83495 .92249 L
.83165 .93221 L
.82832 .94192 L
.82537 .95072 L
.82506 .95163 L
.82172 .96134 L
.81837 .97106 L
.81566 .97908 L
.81508 .98077 L
Mfstroke
.7 g
.98077 .48446 m
.98046 .48543 L
.97755 .49514 L
.97467 .50486 L
.97171 .51457 L
.97106 .51667 L
.96866 .52428 L
.96555 .53399 L
.96259 .54371 L
.96134 .54866 L
.95984 .55342 L
.95672 .56313 L
.95367 .57284 L
.95163 .58043 L
.95096 .58256 L
.94784 .59227 L
.94472 .60198 L
.94198 .61169 L
.94192 .61198 L
.93888 .62141 L
.93573 .63112 L
.93282 .64083 L
.93221 .6433 L
.92986 .65054 L
.92668 .66026 L
.92366 .66997 L
.92249 .67439 L
.92078 .67968 L
.91758 .68939 L
.91447 .69911 L
.91278 .70525 L
.91162 .70882 L
.9084 .71853 L
.90524 .72824 L
.90307 .73588 L
.90239 .73796 L
.89916 .74767 L
.89595 .75738 L
.89336 .76628 L
.89309 .76709 L
.88984 .77681 L
.8866 .78652 L
.8837 .79623 L
.88364 .79645 L
.88045 .80594 L
.87718 .81566 L
.87419 .82537 L
.87393 .82638 L
.87099 .83508 L
.86769 .84479 L
.86464 .85451 L
.86422 .85607 L
.86144 .86422 L
.85812 .87393 L
.85502 .88364 L
.85451 .88552 L
.85182 .89336 L
.84847 .90307 L
.84534 .91278 L
.84479 .91473 L
.84211 .92249 L
.83874 .93221 L
.83558 .94192 L
.83508 .94369 L
.83232 .95163 L
.82892 .96134 L
.82576 .97106 L
.82537 .97242 L
.82243 .98077 L
.98077 .98077 L
F
0 g
.98077 .48446 m
.98046 .48543 L
.97755 .49514 L
.97467 .50486 L
.97171 .51457 L
.97106 .51667 L
.96866 .52428 L
.96555 .53399 L
.96259 .54371 L
.96134 .54866 L
.95984 .55342 L
.95672 .56313 L
.95367 .57284 L
.95163 .58043 L
.95096 .58256 L
.94784 .59227 L
.94472 .60198 L
.94198 .61169 L
.94192 .61198 L
.93888 .62141 L
.93573 .63112 L
.93282 .64083 L
.93221 .6433 L
.92986 .65054 L
.92668 .66026 L
.92366 .66997 L
.92249 .67439 L
.92078 .67968 L
.91758 .68939 L
.91447 .69911 L
.91278 .70525 L
.91162 .70882 L
.9084 .71853 L
.90524 .72824 L
.90307 .73588 L
.90239 .73796 L
.89916 .74767 L
.89595 .75738 L
.89336 .76628 L
.89309 .76709 L
.88984 .77681 L
.8866 .78652 L
.8837 .79623 L
.88364 .79645 L
.88045 .80594 L
.87718 .81566 L
.87419 .82537 L
.87393 .82638 L
.87099 .83508 L
.86769 .84479 L
Mistroke
.86464 .85451 L
.86422 .85607 L
.86144 .86422 L
.85812 .87393 L
.85502 .88364 L
.85451 .88552 L
.85182 .89336 L
.84847 .90307 L
.84534 .91278 L
.84479 .91473 L
.84211 .92249 L
.83874 .93221 L
.83558 .94192 L
.83508 .94369 L
.83232 .95163 L
.82892 .96134 L
.82576 .97106 L
.82537 .97242 L
.82243 .98077 L
Mfstroke
.8 g
.98077 .50881 m
.97917 .51457 L
.97639 .52428 L
.97344 .53399 L
.97106 .54117 L
.97016 .54371 L
.96624 .55342 L
.96446 .56313 L
.96149 .57284 L
.96134 .57332 L
.95782 .58256 L
.95562 .59227 L
.95264 .60198 L
.95163 .60522 L
.94922 .61169 L
.94477 .62141 L
.94373 .63112 L
.94192 .63691 L
.94049 .64083 L
.93634 .65054 L
.93475 .66026 L
.93221 .6684 L
.93164 .66997 L
.9277 .67968 L
.92572 .68939 L
.92267 .69911 L
.92249 .69966 L
.9189 .70882 L
.91662 .71853 L
.91356 .72824 L
.91278 .73066 L
.90997 .73796 L
.90525 .74767 L
.90438 .75738 L
.90307 .76146 L
.90092 .76709 L
.89641 .77681 L
.89514 .78652 L
.89336 .79203 L
.89177 .79623 L
.88741 .80594 L
.88583 .81566 L
.88364 .82238 L
.88252 .82537 L
.87827 .83508 L
.87645 .84479 L
.87393 .8525 L
.87318 .85451 L
.86899 .86422 L
.867 .87393 L
.86422 .88239 L
.86375 .88364 L
.8596 .89336 L
.85748 .90307 L
.85451 .91204 L
.85423 .91278 L
.85009 .92249 L
.84788 .93221 L
.84479 .94145 L
.84462 .94192 L
.84047 .95163 L
.8382 .96134 L
.83508 .97063 L
.83492 .97106 L
.83074 .98077 L
.98077 .98077 L
F
0 g
.98077 .50881 m
.97917 .51457 L
.97639 .52428 L
.97344 .53399 L
.97106 .54117 L
.97016 .54371 L
.96624 .55342 L
.96446 .56313 L
.96149 .57284 L
.96134 .57332 L
.95782 .58256 L
.95562 .59227 L
.95264 .60198 L
.95163 .60522 L
.94922 .61169 L
.94477 .62141 L
.94373 .63112 L
.94192 .63691 L
.94049 .64083 L
.93634 .65054 L
.93475 .66026 L
.93221 .6684 L
.93164 .66997 L
.9277 .67968 L
.92572 .68939 L
.92267 .69911 L
.92249 .69966 L
.9189 .70882 L
.91662 .71853 L
.91356 .72824 L
.91278 .73066 L
.90997 .73796 L
.90525 .74767 L
.90438 .75738 L
.90307 .76146 L
.90092 .76709 L
.89641 .77681 L
.89514 .78652 L
.89336 .79203 L
.89177 .79623 L
.88741 .80594 L
.88583 .81566 L
.88364 .82238 L
.88252 .82537 L
.87827 .83508 L
.87645 .84479 L
.87393 .8525 L
.87318 .85451 L
.86899 .86422 L
.867 .87393 L
Mistroke
.86422 .88239 L
.86375 .88364 L
.8596 .89336 L
.85748 .90307 L
.85451 .91204 L
.85423 .91278 L
.85009 .92249 L
.84788 .93221 L
.84479 .94145 L
.84462 .94192 L
.84047 .95163 L
.8382 .96134 L
.83508 .97063 L
.83492 .97106 L
.83074 .98077 L
Mfstroke
.7 g
.98077 .60174 m
.9807 .60198 L
.97781 .61169 L
.97483 .62141 L
.97182 .63112 L
.97106 .6336 L
.96881 .64083 L
.96765 .65054 L
.96321 .66026 L
.96134 .66523 L
.95986 .66997 L
.95684 .67968 L
.95444 .68939 L
.95163 .69662 L
.95084 .69911 L
.9478 .70882 L
.94563 .71853 L
.94192 .72776 L
.94176 .72824 L
.93869 .73796 L
.93679 .74767 L
.93269 .75738 L
.93221 .75868 L
.92952 .76709 L
.92789 .77681 L
.92358 .78652 L
.92249 .78938 L
.92028 .79623 L
.91893 .80594 L
.9144 .81566 L
.91278 .81983 L
.91098 .82537 L
.90989 .83508 L
.90514 .84479 L
.90307 .85004 L
.9016 .85451 L
.89844 .86422 L
.8958 .87393 L
.89336 .88001 L
.89215 .88364 L
.88896 .89336 L
.88637 .90307 L
.88364 .90973 L
.88262 .91278 L
.87941 .92249 L
.87683 .93221 L
.87393 .9392 L
.87301 .94192 L
.86977 .95163 L
.86719 .96134 L
.86422 .96842 L
.86332 .97106 L
.86005 .98077 L
.98077 .98077 L
F
0 g
.98077 .60174 m
.9807 .60198 L
.97781 .61169 L
.97483 .62141 L
.97182 .63112 L
.97106 .6336 L
.96881 .64083 L
.96765 .65054 L
.96321 .66026 L
.96134 .66523 L
.95986 .66997 L
.95684 .67968 L
.95444 .68939 L
.95163 .69662 L
.95084 .69911 L
.9478 .70882 L
.94563 .71853 L
.94192 .72776 L
.94176 .72824 L
.93869 .73796 L
.93679 .74767 L
.93269 .75738 L
.93221 .75868 L
.92952 .76709 L
.92789 .77681 L
.92358 .78652 L
.92249 .78938 L
.92028 .79623 L
.91893 .80594 L
.9144 .81566 L
.91278 .81983 L
.91098 .82537 L
.90989 .83508 L
.90514 .84479 L
.90307 .85004 L
.9016 .85451 L
.89844 .86422 L
.8958 .87393 L
.89336 .88001 L
.89215 .88364 L
.88896 .89336 L
.88637 .90307 L
.88364 .90973 L
.88262 .91278 L
.87941 .92249 L
.87683 .93221 L
.87393 .9392 L
.87301 .94192 L
.86977 .95163 L
.86719 .96134 L
Mistroke
.86422 .96842 L
.86332 .97106 L
.86005 .98077 L
Mfstroke
.6 g
.98077 .62611 m
.97929 .63112 L
.97635 .64083 L
.97152 .65054 L
.97106 .6581 L
.97057 .66026 L
.96775 .66997 L
.96462 .67968 L
.96149 .68939 L
.96134 .68986 L
.95883 .69911 L
.95571 .70882 L
.95255 .71853 L
.95163 .7214 L
.94983 .72824 L
.94674 .73796 L
.94355 .74767 L
.94192 .75271 L
.94073 .75738 L
.9377 .76709 L
.93449 .77681 L
.93221 .78379 L
.93154 .78652 L
.92858 .79623 L
.92536 .80594 L
.92249 .81463 L
.92225 .81566 L
.91939 .82537 L
.91616 .83508 L
.91293 .84479 L
.91278 .84524 L
.91012 .85451 L
.90689 .86422 L
.90363 .87393 L
.90307 .87562 L
.90078 .88364 L
.89755 .89336 L
.89426 .90307 L
.89336 .90576 L
.89136 .91278 L
.88813 .92249 L
.88481 .93221 L
.88364 .93566 L
.88186 .94192 L
.87863 .95163 L
.87528 .96134 L
.87393 .96531 L
.87229 .97106 L
.86904 .98077 L
.98077 .98077 L
F
0 g
.98077 .62611 m
.97929 .63112 L
.97635 .64083 L
.97152 .65054 L
.97106 .6581 L
.97057 .66026 L
.96775 .66997 L
.96462 .67968 L
.96149 .68939 L
.96134 .68986 L
.95883 .69911 L
.95571 .70882 L
.95255 .71853 L
.95163 .7214 L
.94983 .72824 L
.94674 .73796 L
.94355 .74767 L
.94192 .75271 L
.94073 .75738 L
.9377 .76709 L
.93449 .77681 L
.93221 .78379 L
.93154 .78652 L
.92858 .79623 L
.92536 .80594 L
.92249 .81463 L
.92225 .81566 L
.91939 .82537 L
.91616 .83508 L
.91293 .84479 L
.91278 .84524 L
.91012 .85451 L
.90689 .86422 L
.90363 .87393 L
.90307 .87562 L
.90078 .88364 L
.89755 .89336 L
.89426 .90307 L
.89336 .90576 L
.89136 .91278 L
.88813 .92249 L
.88481 .93221 L
.88364 .93566 L
.88186 .94192 L
.87863 .95163 L
.87528 .96134 L
.87393 .96531 L
.87229 .97106 L
.86904 .98077 L
s
.5 g
.98077 .64634 m
.97723 .65054 L
.97529 .66026 L
.9733 .66997 L
.97106 .67841 L
.97069 .67968 L
.96779 .68939 L
.96478 .69911 L
.96178 .70882 L
.96134 .71025 L
.95888 .71853 L
.95587 .72824 L
.95284 .73796 L
.95163 .74187 L
.94991 .74767 L
.9469 .75738 L
.94384 .76709 L
.94192 .77326 L
.94087 .77681 L
.93786 .78652 L
.93478 .79623 L
.93221 .80443 L
.93176 .80594 L
.92875 .81566 L
.92566 .82537 L
.92258 .83508 L
.92249 .83536 L
.91958 .84479 L
.91648 .85451 L
.91336 .86422 L
.91278 .86606 L
.91034 .87393 L
.90722 .88364 L
.90408 .89336 L
.90307 .89652 L
.90103 .90307 L
.8979 .91278 L
.89473 .92249 L
.89336 .92675 L
.89165 .93221 L
.8885 .94192 L
.88531 .95163 L
.88364 .95674 L
.8822 .96134 L
.87903 .97106 L
.87582 .98077 L
.98077 .98077 L
F
0 g
.98077 .64634 m
.97723 .65054 L
.97529 .66026 L
.9733 .66997 L
.97106 .67841 L
.97069 .67968 L
.96779 .68939 L
.96478 .69911 L
.96178 .70882 L
.96134 .71025 L
.95888 .71853 L
.95587 .72824 L
.95284 .73796 L
.95163 .74187 L
.94991 .74767 L
.9469 .75738 L
.94384 .76709 L
.94192 .77326 L
.94087 .77681 L
.93786 .78652 L
.93478 .79623 L
.93221 .80443 L
.93176 .80594 L
.92875 .81566 L
.92566 .82537 L
.92258 .83508 L
.92249 .83536 L
.91958 .84479 L
.91648 .85451 L
.91336 .86422 L
.91278 .86606 L
.91034 .87393 L
.90722 .88364 L
.90408 .89336 L
.90307 .89652 L
.90103 .90307 L
.8979 .91278 L
.89473 .92249 L
.89336 .92675 L
.89165 .93221 L
.8885 .94192 L
.88531 .95163 L
.88364 .95674 L
.8822 .96134 L
.87903 .97106 L
.87582 .98077 L
s
.4 g
.98077 .66561 m
.97914 .66997 L
.97629 .67968 L
.97353 .68939 L
.97106 .69775 L
.97065 .69911 L
.96767 .70882 L
.96468 .71853 L
.96176 .72824 L
.96134 .72966 L
.9588 .73796 L
.95578 .74767 L
.95281 .75738 L
.95163 .76135 L
.94986 .76709 L
.94683 .77681 L
.94381 .78652 L
.94192 .79281 L
.94086 .79623 L
.93781 .80594 L
.93476 .81566 L
.93221 .82405 L
.9318 .82537 L
.92874 .83508 L
.92566 .84479 L
.92266 .85451 L
.92249 .85505 L
.9196 .86422 L
.91649 .87393 L
.91345 .88364 L
.91278 .88582 L
.91039 .89336 L
.90726 .90307 L
.90418 .91278 L
.90307 .91637 L
.90111 .92249 L
.89796 .93221 L
.89484 .94192 L
.89336 .94667 L
.89176 .95163 L
.88859 .96134 L
.88544 .97106 L
.88364 .97675 L
.88234 .98077 L
.98077 .98077 L
F
0 g
.98077 .66561 m
.97914 .66997 L
.97629 .67968 L
.97353 .68939 L
.97106 .69775 L
.97065 .69911 L
.96767 .70882 L
.96468 .71853 L
.96176 .72824 L
.96134 .72966 L
.9588 .73796 L
.95578 .74767 L
.95281 .75738 L
.95163 .76135 L
.94986 .76709 L
.94683 .77681 L
.94381 .78652 L
.94192 .79281 L
.94086 .79623 L
.93781 .80594 L
.93476 .81566 L
.93221 .82405 L
.9318 .82537 L
.92874 .83508 L
.92566 .84479 L
.92266 .85451 L
.92249 .85505 L
.9196 .86422 L
.91649 .87393 L
.91345 .88364 L
.91278 .88582 L
.91039 .89336 L
.90726 .90307 L
.90418 .91278 L
.90307 .91637 L
.90111 .92249 L
.89796 .93221 L
.89484 .94192 L
.89336 .94667 L
.89176 .95163 L
.88859 .96134 L
.88544 .97106 L
.88364 .97675 L
.88234 .98077 L
s
.3 g
.98077 .68584 m
.97967 .68939 L
.97679 .69911 L
.97389 .70882 L
.97106 .71806 L
.97091 .71853 L
.96784 .72824 L
.96474 .73796 L
.9619 .74767 L
.96134 .75005 L
.95902 .75738 L
.9559 .76709 L
.95291 .77681 L
.95163 .78182 L
.95014 .78652 L
.947 .79623 L
.94393 .80594 L
.94192 .81336 L
.94119 .81566 L
.93804 .82537 L
.93491 .83508 L
.93221 .84468 L
.93217 .84479 L
.92902 .85451 L
.92585 .86422 L
.92295 .87393 L
.92249 .87577 L
.91993 .88364 L
.91673 .89336 L
.91371 .90307 L
.91278 .90663 L
.91077 .91278 L
.90755 .92249 L
.90445 .93221 L
.90307 .93726 L
.90154 .94192 L
.8983 .95163 L
.89514 .96134 L
.89336 .96766 L
.89223 .97106 L
.88898 .98077 L
.98077 .98077 L
F
0 g
.98077 .68584 m
.97967 .68939 L
.97679 .69911 L
.97389 .70882 L
.97106 .71806 L
.97091 .71853 L
.96784 .72824 L
.96474 .73796 L
.9619 .74767 L
.96134 .75005 L
.95902 .75738 L
.9559 .76709 L
.95291 .77681 L
.95163 .78182 L
.95014 .78652 L
.947 .79623 L
.94393 .80594 L
.94192 .81336 L
.94119 .81566 L
.93804 .82537 L
.93491 .83508 L
.93221 .84468 L
.93217 .84479 L
.92902 .85451 L
.92585 .86422 L
.92295 .87393 L
.92249 .87577 L
.91993 .88364 L
.91673 .89336 L
.91371 .90307 L
.91278 .90663 L
.91077 .91278 L
.90755 .92249 L
.90445 .93221 L
.90307 .93726 L
.90154 .94192 L
.8983 .95163 L
.89514 .96134 L
.89336 .96766 L
.89223 .97106 L
.88898 .98077 L
s
.2 g
.98077 .7102 m
.97844 .71853 L
.97563 .72824 L
.97261 .73796 L
.97106 .74255 L
.96921 .74767 L
.965 .75738 L
.96367 .76709 L
.96134 .7747 L
.9606 .77681 L
.95669 .78652 L
.95483 .79623 L
.95184 .80594 L
.95163 .80662 L
.94817 .81566 L
.94592 .82537 L
.94293 .83508 L
.94192 .83829 L
.93949 .84479 L
.935 .85451 L
.93395 .86422 L
.93221 .86977 L
.93068 .87393 L
.92646 .88364 L
.92491 .89336 L
.92249 .90103 L
.92176 .90307 L
.91774 .91278 L
.91581 .92249 L
.91278 .93207 L
.91273 .93221 L
.90886 .94192 L
.90665 .95163 L
.90356 .96134 L
.90307 .96285 L
.89984 .97106 L
.89742 .98077 L
.98077 .98077 L
F
0 g
.98077 .7102 m
.97844 .71853 L
.97563 .72824 L
.97261 .73796 L
.97106 .74255 L
.96921 .74767 L
.965 .75738 L
.96367 .76709 L
.96134 .7747 L
.9606 .77681 L
.95669 .78652 L
.95483 .79623 L
.95184 .80594 L
.95163 .80662 L
.94817 .81566 L
.94592 .82537 L
.94293 .83508 L
.94192 .83829 L
.93949 .84479 L
.935 .85451 L
.93395 .86422 L
.93221 .86977 L
.93068 .87393 L
.92646 .88364 L
.92491 .89336 L
.92249 .90103 L
.92176 .90307 L
.91774 .91278 L
.91581 .92249 L
.91278 .93207 L
.91273 .93221 L
.90886 .94192 L
.90665 .95163 L
.90356 .96134 L
.90307 .96285 L
.89984 .97106 L
.89742 .98077 L
s
.3 g
.98077 .80314 m
.97994 .80594 L
.97703 .81566 L
.97404 .82537 L
.97106 .83497 L
.97102 .83508 L
.96801 .84479 L
.96633 .85451 L
.96222 .86422 L
.96134 .8666 L
.95905 .87393 L
.95781 .88364 L
.95338 .89336 L
.95163 .898 L
.95003 .90307 L
.94699 .91278 L
.94451 .92249 L
.94192 .92916 L
.94095 .93221 L
.93788 .94192 L
.93559 .95163 L
.93221 .96007 L
.9318 .96134 L
.9287 .97106 L
.92662 .98077 L
.98077 .98077 L
F
0 g
.98077 .80314 m
.97994 .80594 L
.97703 .81566 L
.97404 .82537 L
.97106 .83497 L
.97102 .83508 L
.96801 .84479 L
.96633 .85451 L
.96222 .86422 L
.96134 .8666 L
.95905 .87393 L
.95781 .88364 L
.95338 .89336 L
.95163 .898 L
.95003 .90307 L
.94699 .91278 L
.94451 .92249 L
.94192 .92916 L
.94095 .93221 L
.93788 .94192 L
.93559 .95163 L
.93221 .96007 L
.9318 .96134 L
.9287 .97106 L
.92662 .98077 L
s
.4 g
.98077 .8275 m
.97851 .83508 L
.97557 .84479 L
.97169 .85451 L
.97106 .85949 L
.9699 .86422 L
.96693 .87393 L
.96378 .88364 L
.96134 .89125 L
.96086 .89336 L
.95802 .90307 L
.95487 .91278 L
.95172 .92249 L
.95163 .92278 L
.94904 .93221 L
.94589 .94192 L
.94271 .95163 L
.94192 .9541 L
.93997 .96134 L
.93685 .97106 L
.93364 .98077 L
.98077 .98077 L
F
0 g
.98077 .8275 m
.97851 .83508 L
.97557 .84479 L
.97169 .85451 L
.97106 .85949 L
.9699 .86422 L
.96693 .87393 L
.96378 .88364 L
.96134 .89125 L
.96086 .89336 L
.95802 .90307 L
.95487 .91278 L
.95172 .92249 L
.95163 .92278 L
.94904 .93221 L
.94589 .94192 L
.94271 .95163 L
.94192 .9541 L
.93997 .96134 L
.93685 .97106 L
.93364 .98077 L
s
.5 g
.98077 .84773 m
.97647 .85451 L
.97484 .86422 L
.97265 .87393 L
.97106 .87979 L
.96994 .88364 L
.96699 .89336 L
.96398 .90307 L
.96134 .91164 L
.96101 .91278 L
.95809 .92249 L
.95506 .93221 L
.95204 .94192 L
.95163 .94326 L
.94912 .95163 L
.94608 .96134 L
.94304 .97106 L
.94192 .97464 L
.94008 .98077 L
.98077 .98077 L
F
0 g
.98077 .84773 m
.97647 .85451 L
.97484 .86422 L
.97265 .87393 L
.97106 .87979 L
.96994 .88364 L
.96699 .89336 L
.96398 .90307 L
.96134 .91164 L
.96101 .91278 L
.95809 .92249 L
.95506 .93221 L
.95204 .94192 L
.95163 .94326 L
.94912 .95163 L
.94608 .96134 L
.94304 .97106 L
.94192 .97464 L
.94008 .98077 L
s
.6 g
.98077 .867 m
.97833 .87393 L
.97557 .88364 L
.97278 .89336 L
.97106 .89913 L
.96986 .90307 L
.96688 .91278 L
.96389 .92249 L
.96134 .93104 L
.96099 .93221 L
.958 .94192 L
.95498 .95163 L
.95204 .96134 L
.95163 .96273 L
.94906 .97106 L
.94602 .98077 L
.98077 .98077 L
F
0 g
.98077 .867 m
.97833 .87393 L
.97557 .88364 L
.97278 .89336 L
.97106 .89913 L
.96986 .90307 L
.96688 .91278 L
.96389 .92249 L
.96134 .93104 L
.96099 .93221 L
.958 .94192 L
.95498 .95163 L
.95204 .96134 L
.95163 .96273 L
.94906 .97106 L
.94602 .98077 L
s
.7 g
.98077 .88722 m
.97889 .89336 L
.97602 .90307 L
.97311 .91278 L
.97106 .91944 L
.9701 .92249 L
.96701 .93221 L
.96394 .94192 L
.96134 .95143 L
.96128 .95163 L
.95819 .96134 L
.95508 .97106 L
.95221 .98077 L
.98077 .98077 L
F
0 g
.98077 .88722 m
.97889 .89336 L
.97602 .90307 L
.97311 .91278 L
.97106 .91944 L
.9701 .92249 L
.96701 .93221 L
.96394 .94192 L
.96134 .95143 L
.96128 .95163 L
.95819 .96134 L
.95508 .97106 L
.95221 .98077 L
s
.8 g
.98077 .9116 m
.98044 .91278 L
.97771 .92249 L
.97485 .93221 L
.97176 .94192 L
.97106 .94394 L
.9682 .95163 L
.96362 .96134 L
.96289 .97106 L
.96134 .97612 L
.95964 .98077 L
.98077 .98077 L
F
0 g
.98077 .9116 m
.98044 .91278 L
.97771 .92249 L
.97485 .93221 L
.97176 .94192 L
.97106 .94394 L
.9682 .95163 L
.96362 .96134 L
.96289 .97106 L
.96134 .97612 L
.95964 .98077 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00`_ooool2o`0000;ooooo0_l0
002Pooooo`00`_ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgJ3ooooo0033ooooo`04omgMgOl0
003o410@olc<c:7ooooo0033ooooo`04onk^k_lQ8B7o410@onk^kZ7ooooo0033ooooo`04ob4Q8Omg
MgOoMgMgoc8b<Z7ooooo0032ooooo`;o00000_ooool2o`000:3ooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0011oooo
o`;o000000?o410@ooooooooool08oooool5o`00023ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0T
ooooo`Go00009_ooool2o`000003oa0@4?oooooooooo02?ooooo00Gok^k^oc8b<_l0003o410@olc<
c00Tooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`08Oooool4o`000008oa0@4?ooooooooooonk^k_lb
<S;o0000oc8b<_o^k^h3ooooo`00@_ooool00ol0003oooooooooo`0Tooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@08?ooool01OmgMgOoV9RHoooooonHV9SoMgMg02Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A00Wooooo`03o`000?oooooooooo02Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@0Tooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B408oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00oooool003Oooooo1_l00002ooooo`Go00007Oooool6o`0000?ooooo00?oV9RHob4Q
8Oo^k^h08Oooool01Ol@413ooooooooooooooooo410@02Gooooo00?oV9RHob4Q8Oo^k^h09Oooool5
o`0002Gooooo00Go0000ooooooooooooooooo`00000Tooooo`05o`000?ooooooooooooooool00000
8oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool003oooooo
00CoA4A4omgMgOoooooo0000:?ooool00onHV9So8B4Qonk^kP0Pooooo`05o`000?oooooooooooooo
ool000009_ooool00onHV9So8B4Qonk^kP0Tooooo`04odA4A?oMgMgoooooo`0002Kooooo00Go0000
oiRHV?ooooooV9RHob4Q8@0Tooooo`05oc8b<_nHV9SooooooiRHV?lb<S808oooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool003oooooo00CogMgMoeEEEOoooooo
0000:Oooool00omgMgOoIVIVooooo`0Oooooo`05o`000?ooooooooooooooool000009oooool00omg
MgOoIVIVooooo`0Sooooo`04omgMgOmEEEGoooooo`0002Kooooo00Go0000oeEEEOl0003o410@olc<
c00Tooooo`05olc<c?l0003o0000o`000?o<c<`08oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000000oooool0043ooooo00?oMgMgolc<c?l00000:_ooool00ol0003ooooo
ooooo`0Nooooo`05oa0@4?ooooooooooooooool@4100:?ooool00ol0003oooooooooo`0Sooooo`03
ogMgMoo<c<co000002Kooooo00?oEEEEohN7Qoooool09_ooool01Ol@413o^[Zjoooooonj^[[o410@
02?ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo0010oooo
o`03onk^k_m4A4Co000002Kooooo00Go0000okZj^_ooooooV9RHoa0@400Pooooo`05ogMgMonHV9So
oooooiRHV?mgMgL09?ooool01Ol0003o^[ZjoooooonHV9So410@02Gooooo00?ok^k^odA4A?l00000
9_ooool00ooMgMgo410@oiRHV00Vooooo`05o`000?nj^[[ooooookZj^_l000008oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool0047ooooo00?oMgMgo`000?oo
ool09Oooool01OnHV9So410@o`000?lQ8B7oc<c<023ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0T
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`09_ooool00omgMgOo0000ooooo`0Vooooo`04olc<c?m4
A4Co0000oa0@42Cooooo00GoZJVYoa0@4?l0003o410@ojVYZ@0Qooooo`03oeEEEOmVIVKo000000Co
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`009?ooooooo`0004?o00000_ooool002Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`7o00000Oooool1ooooo`009?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo0Ol00001ooooo`7ooooo000T
ooooo`03o`000?oooooooooo0?oooooo?oooool1o`00007ooooo0Oooool002Cooooo00?o0000oooo
ooooool0ooooooloooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`3oooooocoo
oooo0Ol00001ooooo`7ooooo000Tooooo`;o00004?ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Kooooo0ol00008ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00003ooooo`03o`000?oo
oooooooo00Kooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo000000;ooooo
00Co0000oooooooooooo00002?ooool01ol0003ooooooooooooooooo0000ooooool000000_ooool0
0ol0003oooooo`000002ooooo`03o`000?oooooooooo00Kooooo00Ko0000oooooooooooo0000oooo
ool00002ooooo`05o`000?oooooo0000ooooool000002Oooool02Ol0003oooooo`000?oooooo0000
ooooool0003oooooo`000002ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?oo
ool2o`0000;ooooo000Tooooo`03o`000?oooooooooo00?ooooo3?nIVIT00ol0003oOgmoogmoO`09
ogmoO`03o`000?mVIVKoIVIV00[oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0<
ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0E
ok>c/`03o`000?nIVIWoVIVI00GoVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP03
ofIVIP03o`000?m<C4coC4a<00SoC4a<00?o0000oda<C?m<C4`01_m<C4`01Ol0003oIVIVofIVI_mV
IVKo000000?oOgmo00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Goc<c<
00?o0000ok>c/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Co0000ofIVI_mV
IVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH0
0ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Oo0000ok>c/onc/k?o/k>c
o`000?nIVIWo000000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`06
o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl01Ol0003oVIVIo`000?nc/k?o000000Woc<c<00Wo
0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c
<`03o`000?m<C4co000000Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?o
oooo2onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<
C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnI
VIT02onIVIT00ol0003o/k>cok>c/`0Eok>c/`03o`000?nIVIWoVIVI00GoVIVI00?o0000ogmoOomo
Ogl00_moOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<017oC4a<00Go0000ofIVI_mV
IVKoIVIVo`000004ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0003oc<c<olc<c005
olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01Ol0003oIVIVofIV
I_mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01olc<c<01ol0003oC4a<oda<C?m<C4co0000ofIV
I_l000000_moOgl01?l0003oVIVIoiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Wo0000
ok>c/onc/k?o/k>co`000?nIVIWo0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00008oc<c
<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl01Ol0003oVIVIo`000?nc/k?o000000Woc<c<
00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06
oc<c<`03o`000?m<C4co000000Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo
00?ooooo2_nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<
C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVI
VOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00GoVIVI00Co0000ogmo
OomoOgooOgmo0_l00004ofIVIP03o`000?m<C4coC4a<01;oC4a<00Go0000ofIVI_mVIVKoIVIVo`00
0003ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0003oc<c<olc<c005olc<c003o`00
0?nc/k?o/k>c00;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`00
00?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o0000
ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00009olc<c006o`000?nc/k?o/k>co`000?nIVIWo
00000_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Ko0000oda<C?m<
C4co0000ofIVI_l00002ogmoO`05o`000?nIVIWo0000ok>c/ol000002Oo<c<`02Ol0003o/k>co`00
0?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00?o0000oda<
C?l000001_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool9oiVIV@03
o`000?moOgooOgmo00SoOgmo0_l0000<ofIVIP;o00006?m<C4`00ol0003oIVIVofIVIP0;ofIVIP03
o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03
o`000?nIVIWoVIVI00GoVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP03ofIVIP03
o`000?m<C4coC4a<017oC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo0000
00?oVIVI00?o0000ok>c/onc/k<00_nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c
00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000;oC4a<00?o
0000oc<c<olc<c<01olc<c<01ol0003oC4a<oda<C?m<C4co0000ofIVI_l000000_moOgl01?l0003o
VIVIoiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl0
0002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01_l0003oC4a<oda<
C?l0003oIVIVo`0000;oOgmo00Go0000oiVIVOl0003o/k>co`000009olc<c009o`000?nc/k?o0000
oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<00ol0003oC4a<
o`000006ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`SoVIVI00?o
0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o
0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00coVIVI00?o
0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00?oOgmo00?o
0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00Aoda<C003o`000?mVIVKoIVIV00;oIVIV00Go
0000ogmoOomoOgooOgmoo`000003oiVIV@03o`000?nc/k?o/k>c00;o/k>c00?o0000olc<c?o<c<`0
1Oo<c<`01Ol0003o/k>cok>c/onc/k?o000000?oVIVI00Co0000ogmoOomoOgoo00000omVIVH01?l0
003oC4a<oda<C?l00009oc<c<`07o`000?m<C4coC4a<oda<C?l0003oIVIVo`000002ogmoO`04o`00
0?nIVIWoVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01oo<c<`01_l0003o/k>cok>c/ol0003oVIVI
o`0000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`06o`000?m<C4co
C4a<o`000?mVIVKo00000_moOgl01Ol0003oVIVIo`000?nc/k?o000000Woc<c<00Wo0000ok>c/ol0
003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`03o`000?m<
C4co000000Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo1onIVIT0
0ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00coIVIV00?o0000oda<C?m<C4`05_m<C4`0
0ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT03?nIVIT0
0ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl00omoOgl0
0ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<017oC4a<00?o0000ofIVI_mVIVH00_mVIVH0
1Ol0003oOgmoogmoOomoOgoo000000?oVIVI00?o0000ok>c/onc/k<00_nc/k<00ol0003oc<c<olc<
c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`04o`00
0?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01ol0003oC4a<oda<C?m<C4co0000
ofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Co
0000ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc
<c<01_lc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00?o0000oiVIVOl000000_nc/k<0
0ol0003oc<c<olc<c006olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000?o
C4a<00?o0000oc<c<olc<c<01Olc<c<01?l0003oC4a<o`000?mVIVH6ooooo`7o00000Oooool1oooo
o`009?ooool00ol0003oooooooooo`03ooooo`KoVIVI00?o0000ogmoOomoOgl02?moOgl2o`0000co
IVIV0_l0000Hoda<C003o`000?mVIVKoIVIV00[oIVIV0_l0000:ogmoO`03o`000?nIVIWoVIVI00_o
VIVI0_l0000Hok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003o
IVIVofIVIP03ofIVIP03o`000?m<C4coC4a<01;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmo
O`05o`000?nIVIWoVIVIoiVIVOl000001Onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o
/k>c00?o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00004oda<C003o`00
0?lc<c?o<c<c00Go<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`00
00;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`00ol0003o/k>cok>c/`02o`000004oiVIVOl0003o
Ogmoo`0000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<01_l0003oC4a<oda<C?l0003oIVIVo`00
00;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c009o`000?nc/k?o0000
oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<
o`000?mVIVH6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`GoVIVI
00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<
00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI
00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@05oiVIV@03o`000?moOgooOgmo00?oOgmo
00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C00Coda<C005o`000?mVIVKoIVIVofIVI_l0
00000omoOgl01Ol0003oVIVIoiVIVOnIVIWo000000Go/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0
003o/k>cok>c/`03ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo00000om<
C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmo
ogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT0
0ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Ko0000oda<C?m<C4co0000
ofIVI_l00002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02Ol0003o
/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go
0000oda<C?l0003oIVIVo`000005ooooo`7o00000Oooool1ooooo`009?ooool00ol0003ooooooooo
o`03ooooo`CoVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<
C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nI
VIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@05oiVIV@03o`000?mo
OgooOgmo00?oOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00Boda<C005o`000?mV
IVKoIVIVofIVI_l000000omoOgl01Ol0003oVIVIoiVIVOnIVIWo000000Go/k>c00?o0000olc<c?o<
c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co0000ofIV
I_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`05oc<c<`05o`000?m<C4coC4a<oda<C?l000000omV
IVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Co0000ok>c/onc/k?o
00000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Ko0000oda<
C?m<C4co0000ofIVI_l00002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<
c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c
00Ko<c<c00?o0000oda<C?l000000_mVIVH00ol0003oooooooooo`03ooooo`7o00000Oooool1oooo
o`009?ooool00ol0003oooooooooo`03ooooo`?oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003o
IVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02_mVIVH2o`0000[o
Ogmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00Go
VIVI00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<01;o
C4a<00?o0000ofIVI_mVIVH00_mVIVH00ol0003oOgmoogmoO`02o`0000?oVIVI00?o0000ok>c/onc
/k<00_nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Go0000oiVIVOnI
VIWoVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<0
1Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Ko0000ogmoOomoOgoo0000oiVIVOl00003ok>c/`03
o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIV
IP04o`000?m<C4coC4a<o`0000So<c<c00So0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000;o
VIVI00?o0000ok>c/ol000002Oo<c<`02ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`00
0?m<C4co000000Wo<c<c00Go0000oda<C?l0003oIVIVo`000006ooooo`7o00000Oooool1ooooo`00
9?ooool2o`0000Cooooo0_nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV
00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0:ofIVIP03o`000?moOgooOgmo00WoOgmo
00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00KoVIVI
00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<01;oC4a<
00?o0000ofIVI_mVIVH00_mVIVH01?l0003oOgmoogmoOol00004oiVIV@03o`000?nc/k?o/k>c00;o
/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`05o`000?nIVIWoVIVIoiVI
VOl000000_moOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000
oda<C?m<C4coC4a<o`000002ofIVIP06o`000?moOgooOgmoo`000?nIVIWo00000onc/k<00ol0003o
c<c<olc<c006olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0
003oC4a<oda<C?l00008oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVIV@03
o`000?nc/k?o000000Woc<c<00_o0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<
o`000009oc<c<`05o`000?m<C4co0000ofIVI_l000001Oooool2o`0000;ooooo000Tooooo`03o`00
0?oooooooooo00?ooooo00?oVIVIo`000?moOgl02OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`00
0?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`00
0?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<06?nc/k<00ol0003oVIVIoiVIV@05oiVIV@03o`00
0?moOgooOgmo00?oOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00Boda<C003o`00
0?mVIVKoIVIV00;oIVIV00Co0000ogmoOomoOgoo00001?nIVIT00ol0003o/k>cok>c/`03ok>c/`03
o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo0000
00;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4co
C4a<oda<C?l000000_mVIVH01_l0003oOgmoogmoOol0003oVIVIo`0000?o/k>c00?o0000olc<c?o<
c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@06o`000?moOgooOgmoo`000?mVIVKo00000_m<
C4`00ol0003o<c<coc<c<`06oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol00003oiVI
V@;o00002Oo<c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003o`00
0?lc<c?o<c<c00Ko<c<c00?o0000oda<C?m<C4`00_l000000omoOgooooooooooo`04ooooo`7o0000
0Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`03o`000?moOgooOgmo00SoOgmo00?o
0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00[oIVIV0_l0
000:ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<2o`0000OoVIVI00?o
0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<01?oC4a<00Go
0000ofIVI_mVIVKoIVIVo`000003ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001Onc/k<00ol0003o
c<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl2o`00
00;oIVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mV
IVH00ol0003oOgmoo`000002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01?l0003o/k>c
ok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<02?l0
003oC4a<oda<C?l0003oIVIVo`000?moOgoo00000_nIVIT00ol0003o/k>co`000009olc<c009o`00
0?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<0
0ol0003oC4a<oda<C002o`000003ogmoOooooooooooo00Cooooo0Ol00001ooooo`7ooooo000Toooo
o`03o`000?oooooooooo00?ooooo2_moOgl00ol0003oIVIVofIVIP0;ofIVIP;o00005om<C4`2o`00
00coIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c
01Oo/k>c00?o0000oiVIVOnIVIT01onIVIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV
00?oIVIV00?o0000oda<C?m<C4`04om<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Go0000
oiVIVOnIVIWoVIVIo`000005ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00onc
/k<01?l0003oVIVIoiVIVOl00002ogmoO`05o`000?mVIVKoIVIVofIVI_l000000om<C4`00ol0003o
<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Ko0000ofIVI_mVIVKo0000ogmoOol00002
oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;o
Ogmo00Co0000ofIVI_mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`08o`000?m<C4coC4a<
o`000?mVIVKo0000ogmoOol00002oiVIV@03o`000?nc/k?o000000Woc<c<00Wo0000ok>c/ol0003o
VIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`03o`000?m<C4co
C4a<00;o000000?oOgmoo`000?ooool01?ooool1o`00007ooooo0Oooool002Cooooo00?o0000oooo
ooooool00oooool9ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0
003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0
003o/k>cok>c/`0Hok>c/`03o`000?nIVIWoVIVI00KoVIVI00?o0000ogmoOomoOgl00omoOgl00ol0
003oIVIVofIVIP04ofIVIP03o`000?m<C4coC4a<01;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000003
ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001Onc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc
/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000?o
C4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmo
OomoOgoo00000_nIVIT01?l0003o/k>cok>c/ol00008olc<c004o`000?nc/k?o/k>co`0000;oVIVI
00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`08o`000?m<C4coC4a<o`00
0?mVIVKo0000ogmoOol00002oiVIV@03o`000?nc/k?o000000Woc<c<00?o0000ok>c/ol000000_nI
VIT2o`000005ofIVI_l0003oC4a<oda<C?l000002Olc<c<01?l0003oC4a<o`000?l00002ogmoO`03
o`000?oooooooooo00?ooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo
2?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH0
3?mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<0
6?nc/k<00ol0003oVIVIoiVIV@06oiVIV@03o`000?moOgooOgmo00?oOgmo00?o0000ofIVI_mVIVH0
1?mVIVH00ol0003oC4a<oda<C00Boda<C005o`000?mVIVKoIVIVofIVI_l000001?moOgl01Ol0003o
VIVIoiVIVOnIVIWo000000Go/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`02ok>c
/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00004oda<C003o`000?lc
<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01_l0003oIVIVo`000?l0003oOgmoo`0000;o
VIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000
ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo
0000ogmoOol00002oiVIV@03o`000?nc/k?o000000Woc<c<00Wo0000ok>c/ol0003oVIVIo`000?mo
Ogoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`03o`000?m<C4coC4a<00;o0000
00?oOgmoo`000?ooool01Oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00ooo
ool7ogmoO`03o`000?mVIVKoIVIV00_oIVIV0_l0000Goda<C0;o00003OmVIVH00ol0003oOgmoogmo
O`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<06?nc/k<00ol0003oVIVIoiVI
V@07oiVIV@03o`000?moOgooOgmo00?oOgmo00?o0000ofIVI_mVIVH01?mVIVH00ol0003oC4a<oda<
C00Boda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl00ol0003oVIVIoiVIV@02oiVIV@03o`00
0?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`02ok>c/`05o`00
0?nIVIWoVIVIoiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00004oda<C003o`000?lc<c?o<c<c
00Go<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Go
0000ok>c/onc/k?o/k>co`000008olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol0
00000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmo
Ool00002oiVIV@03o`000?nc/k?o000000Woc<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000
ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`03o`000?m<C4coC4a<00;o000000?oOgmo
o`000?ooool01Oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool6ogmo
O`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0<ofIV
IP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Hok>c
/`03o`000?nIVIWoVIVI00OoVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIVIP04ofIV
IP03o`000?m<C4coC4a<01;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000004ogmoO`05o`000?nIVIWo
VIVIoiVIVOl000001Onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00;o/k>c00Go
0000oiVIVOnIVIWoVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc
<c<01_lc<c<01ol0003oC4a<oda<C?m<C4co0000ofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl0
0003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmo
o`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00So0000oda<C?m<C4co0000ofIVI_l0003o
Ogmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`00ol0003o/k>cok>c/`02o`000007ogmo
Ool0003oIVIVofIVI_l0003oC4a<o`000009oc<c<`04o`000?m<C4co0000ofIVIP;o000000?oVIVI
ooooooooool01?ooool1o`00007ooooo0Oooool001_ooooo0_l000000ol@413oooooooooo`04oooo
o`03o`000?oooooooooo00?ooooo1OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<
01KoC4a<00?o0000ofIVI_mVIVH02omVIVH2o`0000[oOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0
003o/k>cok>c/`0Hok>c/`03o`000?nIVIWoVIVI00OoVIVI00?o0000ogmoOomoOgl00omoOgl00ol0
003oIVIVofIVIP04ofIVIP03o`000?m<C4coC4a<01;oC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0
003oOgmoogmoOomoOgoo000000?oVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c004
olc<c003o`000?nc/k?o/k>c00?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`04o`000?mV
IVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01olc<c<01?l0003oC4a<oda<C?l00002ofIVIP04
o`000?moOgooOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`01?l0003o/k>cok>c/ol0
0002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<02?l0003oC4a<
oda<C?l0003oIVIVo`000?moOgoo00000_nIVIT01?l0003o/k>co`000?l00008olc<c009o`000?nc
/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01olc<c<01?l0
003oC4a<o`000?mVIVH2o`000003oiVIVOoooooooooo00Cooooo0Ol00001ooooo`7ooooo000Loooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool4ogmoO`03o`000?mVIVKoIVIV
00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?moOgooOgmo
00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Hok>c/`03o`000?nIVIWoVIVI
00OoVIVI00?o0000ogmoOomoOgl01?moOgl00ol0003oIVIVofIVIP04ofIVIP03o`000?m<C4coC4a<
01;oC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000?oVIVI00?o0000
ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Co0000
oiVIVOnIVIWo00000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000?oC4a<00?o0000oc<c<olc<c<0
1olc<c<01?l0003oC4a<oda<C?l00002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Co0000ok>c
/onc/k?o00002Oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV00Co
0000oda<C?m<C4co00002?lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0
0002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIV
I_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`04o`000?m<C4co0000ofIVIP;o000000?oVIVI
ooooooooool01?ooool1o`00007ooooo0Oooool0017ooooo1_l00002ooooo`Go00001_ooool3o`00
00?ooooo0omoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIV
I_mVIVH03?mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c
/onc/k<05onc/k<2o`0000WoVIVI00?o0000ogmoOomoOgl01?moOgl00ol0003oIVIVofIVIP04ofIV
IP03o`000?m<C4coC4a<01;oC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo
000000?oVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o
/k>c00;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`05o`000?mVIVKoIVIVofIVI_l00000
0_m<C4`00ol0003o<c<coc<c<`07oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Co0000ogmoOomo
Ogoo00000_nIVIT01?l0003o/k>cok>c/ol00009olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o
0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`08o`000?m<C4coC4a<o`000?mV
IVKo0000ogmoOol00002oiVIV@03o`000?nc/k?o000000Woc<c<00Go0000ok>c/ol0003oVIVIo`00
0002ogmoO`;o00000_m<C4`00ol0003o<c<coc<c<`07oc<c<`04o`000?m<C4co0000ofIVIP;o0000
0_nIVIT01?l0003oooooooooooooool3o`0000;ooooo000Iooooo`04odA4A?oMgMgoooooo`0000Oo
oooo00?o0000ooooooooool00oooool2ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<
C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP;o00002_moOgl00ol0003oVIVIoiVIV@0;oiVIV@03
o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02?nIVIT00ol0003oOgmoogmoO`04ogmoO`03
o`000?mVIVKoIVIV00CoIVIV00?o0000oda<C?m<C4`04_m<C4`00ol0003oIVIVofIVIP02ofIVIP05
o`000?moOgooOgmoogmoOol000001?nIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<
00Coc<c<00?o0000ok>c/onc/k<00onc/k<01?l0003oVIVIoiVIVOl00002ogmoO`05o`000?mVIVKo
IVIVofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l00000
0_mVIVH01?l0003oOgmoogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Oo0000ok>c
/onc/k?o/k>co`000?nIVIWo000000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c
<`07oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVIV@03o`000?nc/k?o0000
00Woc<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<c
oc<c<`06oc<c<`05o`000?m<C4coC4a<o`000?mVIVH00_l000000onIVIWo0000ooooo`05ooooo`7o
00000Oooool1ooooo`006Oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo00?o
oooo0_moOgl00ol0003oIVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mV
IVH03?mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc
/k<05_nc/k<2o`0000_oVIVI00?o0000ogmoOomoOgl01?moOgl00ol0003oIVIVofIVIP04ofIVIP03
o`000?m<C4coC4a<01;oC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo0000
00CoVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c
00?o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000?oC4a<00?o
0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o0000ogmoOol00000
0onIVIT01?l0003o/k>cok>c/ol00008olc<c007o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000002
ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01olc<c<02?l0003oC4a<oda<C?l0
003oIVIVo`000?moOgoo00000_nIVIT00ol0003o/k>co`000009olc<c009o`000?nc/k?o0000oiVI
VOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<
C?l0003oIVIV00;o000000?oVIVIo`000?ooool01Oooool1o`00007ooooo0Oooool001[ooooo00?o
MgMgolc<c?l000001oooool00ol0003oooooooooo`03ooooo`03ogmoOol0003oIVIV00_oIVIV00?o
0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?moOgooOgmo00SoOgmo00?o
0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00[oVIVI00?o
0000ogmoOomoOgl01?moOgl00ol0003oIVIVofIVIP04ofIVIP03o`000?m<C4coC4a<01?oC4a<00Go
0000ofIVI_mVIVKoIVIVo`000004ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001Onc/k<00ol0003o
c<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01Ol0
003oIVIVofIVI_mVIVKo000000CoC4a<00?o0000oc<c<olc<c<01Olc<c<01Ol0003oC4a<oda<C?m<
C4co000000;oIVIV00Co0000ogmoOomoOgoo00000onIVIT01?l0003o/k>cok>c/ol00008olc<c004
o`000?nc/k?o/k>co`0000;oVIVI00Go0000ogmoOol0003oIVIVo`000003oda<C003o`000?lc<c?o
<c<c00Ko<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`05o`000?nIVIWo0000ok>c/ol0
00002Oo<c<`00ol0003o/k>co`000002oiVIV@;o000000GoIVIVo`000?m<C4coC4a<o`000009oc<c
<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000Kooooo0Ol00001ooooo`7ooooo
000Jooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool00oooool00ol0003oIVIVofIV
IP0:ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH2o`0000[oOgmo00?o
0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00[oVIVI00?o
0000ogmoOomoOgl01?moOgl00ol0003oIVIVofIVIP04ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o
0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000?oVIVI00?o0000ok>c/onc/k<0
0onc/k<2o`0000Goc<c<00?o0000ok>c/onc/k<00onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;o
Ogmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<
oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<
00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo00?o0000ofIVI_l000000om<C4`00ol0
003o<c<coc<c<`06oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVIV@03o`00
0?nc/k?o000000Woc<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`0
0ol0003o<c<coc<c<`06oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`00
00Kooooo0Ol00001ooooo`7ooooo000Kooooo`03ogMgMol0003ooooo00Kooooo00?o0000oooooooo
ool00oooool<ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003o
OgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003o
VIVIoiVIV@09oiVIV@03o`000?moOgooOgmo00GoOgmo00?o0000ofIVI_mVIVH01?mVIVH00ol0003o
C4a<oda<C00Coda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgooOgmoo`000003oiVI
V@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c
/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00004oda<C003o`000?lc
<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;o
VIVI00Co0000ok>c/onc/k?o00002?o<c<`01ol0003o/k>cok>c/onc/k?o0000oiVIVOl000000_mo
Ogl00ol0003oIVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c00So0000oda<C?m<C4co0000
ofIVI_l0003oOgmoo`0000;oVIVI00?o0000ok>c/ol000002Oo<c<`02Ol0003o/k>co`000?nIVIWo
0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00[o0000oda<C?m<C4co
0000ofIVI_l0003oOgmoo`000?nIVIWo00001_ooool1o`00007ooooo0Oooool002Cooooo00?o0000
ooooooooool00oooool<ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH0
0ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<0
0ol0003oVIVIoiVIV@0:oiVIV@03o`000?moOgooOgmo00CoOgmo00?o0000ofIVI_mVIVH01?mVIVH0
0ol0003oC4a<oda<C00Coda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgooOgmoo`00
0004oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c
/`03ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo00001Om<C4`00ol0003o
<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Ko0000ofIVI_mVIVKo0000ogmoOol00002
oiVIV@04o`000?nc/k?o/k>co`0000Woc<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo000000;o
Ogmo0_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH01Ol0
003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02_l0003o/k>cok>c/ol0
003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00?o0000oda<
C?m<C4`00_l00002ogmoO`03o`000?nIVIWo000000Kooooo0Ol00001ooooo`7ooooo000Tooooo`03
o`000?oooooooooo00?ooooo2omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_o
IVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo
/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV00Co
IVIV00?o0000oda<C?m<C4`04om<C4`00ol0003oIVIVofIVIP02ofIVIP05o`000?moOgooOgmoogmo
Ool000000onIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c
/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo00001?m<
C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmo
ogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Oo0000ok>c/onc/k?o/k>co`000?nI
VIWo000000;oOgmo00?o0000ofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`08o`000?m<
C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVIV@03o`000?nc/k?o000000Woc<c<00?o0000ok>c
/onc/k<00_l000001omoOgoo0000ofIVI_mVIVKo0000oda<C?l000002?lc<c<03?l0003oC4a<oda<
C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Gooooo0Ol00001ooooo`7ooooo000T
ooooo`03o`000?oooooooooo00?ooooo2OmVIVH2o`0001OoC4a<0_l0000=ofIVIP03o`000?moOgoo
Ogmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWo
VIVI00[oVIVI00?o0000ogmoOomoOgl01OmoOgl00ol0003oIVIVofIVIP04ofIVIP03o`000?m<C4co
C4a<01?oC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000CoVIVI00?o
0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Co
0000oiVIVOnIVIWo00000omoOgl01?l0003oIVIVofIVI_l00004oda<C003o`000?lc<c?o<c<c00Go
<c<c00?o0000oda<C?m<C4`00_m<C4`01_l0003oIVIVofIVI_l0003oOgmoo`0000;oVIVI00Co0000
ok>c/onc/k?o00002Oo<c<`01ol0003o/k>cok>c/onc/k?o0000oiVIVOl000000_moOgl00ol0003o
IVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003o
Ogmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c008o`000?nc/k?o/k>co`000?nI
VIWo0000ogmoOol00002ofIVIP03o`000?m<C4co000000So<c<c00co0000oda<C?m<C4co0000ofIV
I_l0003oOgmoo`000?nIVIWo0000ok>c/ol00005ooooo`7o00000Oooool1ooooo`009?ooool00ol0
003oooooooooo`03ooooo`WoIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIV
IP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`0Fok>c
/`03o`000?nIVIWoVIVI00[oVIVI00?o0000ogmoOomoOgl01_moOgl00ol0003oIVIVofIVIP04ofIV
IP03o`000?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo
000000CoVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o
/k>c00?o/k>c00Co0000oiVIVOnIVIWo00000omoOgl01?l0003oIVIVofIVI_l00004oda<C003o`00
0?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01_l0003oIVIVofIVI_l0003oOgmoo`00
00;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`02Ol0003o/k>cok>c/onc/k?o0000oiVIVOl0003o
Ogmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000Wo<c<c00[o0000oda<C?m<C4co0000ofIVI_l0
003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c008o`000?nc/k?o/k>co`00
0?nIVIWo0000ogmoOol00002ofIVIP03o`000?m<C4co000000So<c<c00co0000oda<C?m<C4co0000
ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00005ooooo`7o00000Oooool1ooooo`009?ooool2
o`0000Cooooo2?mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000
ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000
oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`06ogmoO`03o`000?mVIVKoIVIV00CoIVIV00?o0000
oda<C?m<C4`04om<C4`00ol0003oIVIVofIVIP02ofIVIP05o`000?moOgooOgmoogmoOol000001?nI
VIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00onc
/k<01?l0003oVIVIoiVIVOl00003ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc
<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o0000ogmoOol000000_nIVIT01Ol0
003o/k>cok>c/onc/k?o000000Soc<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo
00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`0:o`000?m<C4coC4a<o`000?mV
IVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01_l0003o/k>cok>c
/ol0003oVIVIo`0000;oOgmo00Go0000ofIVI_l0003oC4a<o`000008oc<c<`0<o`000?m<C4coC4a<
o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00001Oooool2o`0000;ooooo000Tooooo`03
o`000?oooooooooo00?ooooo1_mVIVH2o`0001SoC4a<00?o0000ofIVI_mVIVH02_mVIVH2o`0000[o
Ogmo00?o0000oiVIVOnIVIT02onIVIT2o`0001Oo/k>c0_l0000<oiVIV@03o`000?moOgooOgmo00Go
Ogmo0_l00006ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH00_mVIVH00ol0003o
OgmoogmoO`02ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001Onc/k<2o`0000Goc<c<00?o0000ok>c
/onc/k<00onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`00
0003oda<C0;o00001olc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo
00000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT0
1_l0003oOgmoogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02ol0003oC4a<
oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<
c<`02?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo00000_mVIVH00ol0003oC4a<o`000008oc<c
<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00001_ooool1o`00
007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool5ofIVIP03o`000?m<C4coC4a<01Oo
C4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00_o
VIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00Ko
Ogmo00?o0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<C00Coda<C003o`000?mVIVKoIVIV00;o
IVIV00?o0000ogmoOomoOgl00_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Go/k>c00?o0000olc<
c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl0
1Ol0003oIVIVofIVI_mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<
C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01Ol0003o/k>cok>c/onc/k?o0000
00Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT01_l0003oOgmoogmoOol0003oIVIVo`0000;oC4a<
00?o0000oc<c<olc<c<01_lc<c<02ol0003oC4a<oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nI
VIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02?l0003o/k>cok>c/ol0003oVIVIo`000?mo
Ogoo00000_mVIVH00ol0003oC4a<o`000008oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmo
Ool0003oVIVIo`000?nc/k?o00001_ooool1o`00007ooooo0Oooool002Cooooo00?o0000oooooooo
ool00oooool4ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003o
OgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003o
VIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo00GoOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0003o
C4a<oda<C00Coda<C003o`000?mVIVKoIVIV00?oIVIV00Go0000ogmoOomoOgooOgmoo`000003oiVI
V@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c
/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000?oC4a<00?o
0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo
00000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Oo0000ok>c/onc/k?o/k>co`000?nI
VIWo000000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`0:o`000?m<
C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01oo<c<`0
0ol0003o/k>co`000002oiVIV@;o00000_mVIVH00ol0003oC4a<o`000009oc<c<`0<o`000?m<C4co
0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol0003oc<c<1_ooool1o`00007ooooo0Oooool0
02Cooooo00?o0000ooooooooool00oooool3ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIV
I_mVIVH02_mVIVH2o`0000[oOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c
/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl01OmoOgl00ol0003oIVIVofIVIP05ofIV
IP03o`000?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH00omVIVH01Ol0003oOgmoogmoOomoOgoo
000000CoVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o
/k>c00?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<
00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomo
Ogoo00000_nIVIT01?l0003o/k>cok>c/ol00009olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o
0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`03o`000?m<C4co000000;oIVIV
00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Oo0000ok>c/ol0
003oVIVIo`000?moOgoo000000;oIVIV00?o0000oda<C?l000002?lc<c<03Ol0003oC4a<oda<C?l0
003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`000?o<c<`01_ooool1o`00007ooooo0Oooool0
02Cooooo00?o0000ooooooooool00oooool2ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIV
I_mVIVH02_mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c
/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo00GoOgmo00?o0000ofIV
I_mVIVH01_mVIVH00ol0003oC4a<oda<C00Coda<C003o`000?mVIVKoIVIV00?oIVIV00Go0000ogmo
OomoOgooOgmoo`000004oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`01?o<c<`0
0ol0003o/k>cok>c/`03ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01?l0003oIVIVofIV
I_l00004oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04
o`000?moOgooOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`01?l0003o/k>cok>c/ol0
0002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<00ol0003oC4a<
o`000002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c007
o`000?nc/k?o0000oiVIVOl0003oOgmoo`000002ofIVIP03o`000?m<C4co000000So<c<c00go0000
oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol0003oc<c<00Kooooo0Ol00001
ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo00?oIVIVo`000?m<C4`06?m<C4`00ol0
003oIVIVofIVIP0:ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0
003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI0_l00008ogmoO`03o`000?mVIVKoIVIV
00GoIVIV00?o0000oda<C?m<C4`04om<C4`00ol0003oIVIVofIVIP03ofIVIP05o`000?moOgooOgmo
ogmoOol000001?nIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000
ok>c/onc/k<00onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo0000
1?m<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003o
OgmoogmoOol00002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01?l0003o/k>cok>c/ol0
0002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<02_l0003oC4a<
oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00?o
0000ok>c/onc/k<00_l000001omoOgoo0000ofIVI_mVIVKo0000oda<C?l000002?lc<c<03?l0003o
C4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000;oc<c<1_ooool1o`00007o
oooo0Oooool002Cooooo00?o0000ooooooooool00oooool00ol0003oC4a<oda<C00Goda<C003o`00
0?mVIVKoIVIV00[oIVIV0_l0000:ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<0
5_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00OoOgmo00?o0000ofIVI_mVIVH0
1OmVIVH00ol0003oC4a<oda<C00Coda<C003o`000?mVIVKoIVIV00?oIVIV00Go0000ogmoOomoOgoo
Ogmoo`000004oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003o
/k>cok>c/`03ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01?l0003oIVIVofIVI_l00004
oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l0
0002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>c
ok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<01?l0
003oC4a<oda<C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<
c006olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP03o`000?m<C4co0000
00So<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00002olc<
c0Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo00?o0000oda<C?m<
C4`05Om<C4`2o`0000coIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03
o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`06ogmoO`03
o`000?mVIVKoIVIV00KoIVIV00?o0000oda<C?m<C4`04om<C4`00ol0003oIVIVofIVIP03ofIVIP05
o`000?moOgooOgmoogmoOol000001?nIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<
00Coc<c<00?o0000ok>c/onc/k<00onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Co0000
ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`03o`000?m<C4coC4a<00;oC4a<00Ko
0000ofIVI_mVIVKo0000ogmoOol00002oiVIV@03o`000?nc/k?o/k>c00;o/k>c00?o0000olc<c?o<
c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<
C?m<C4co00002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl00000
0_nc/k<00ol0003oc<c<olc<c006olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002
ofIVIP03o`000?m<C4co000000So<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nI
VIWo0000ok>c/ol00002olc<c0Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo
00?ooooo5om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVI
VOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI0_l00008ogmo
O`03o`000?mVIVKoIVIV00KoIVIV00?o0000oda<C?m<C4`04om<C4`00ol0003oIVIVofIVIP03ofIV
IP05o`000?moOgooOgmoogmoOol000001?nIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<co
c<c<00?oc<c<00?o0000ok>c/onc/k<01?nc/k<01?l0003oVIVIoiVIVOl00003ogmoO`04o`000?mV
IVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`00
0?mVIVKoIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<
c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l0
0009oc<c<`03o`000?m<C4co000000;oIVIV00?o0000ogmoOol000000_nIVIT00ol0003o/k>co`00
0008olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl01Ol0003oIVIVo`000?m<C4co0000
00Wo<c<c00?o0000oda<C?l000000_mVIVH2o`000005oiVIVOl0003o/k>cok>c/ol000000_o<c<`6
ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03oooooaKoC4a<00?o0000ofIV
I_mVIVH03?mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c
/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00OoOgmo00?o0000ofIV
I_mVIVH01_mVIVH00ol0003oC4a<oda<C00Doda<C003o`000?mVIVKoIVIV00;oIVIV00?o0000ogmo
OomoOgl00_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Ko/k>c00?o0000olc<c?o<c<`00oo<c<`0
0ol0003o/k>cok>c/`04ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01Ol0003oIVIVofIV
I_mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000?o
IVIV00?o0000ogmoOol000000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Go0000ok>c
/onc/k?o/k>co`000002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002Olc
<c<00ol0003oC4a<o`000002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<
olc<c006olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP03o`000?m<C4co
000000Wo<c<c00_o0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`000003olc<
c0Kooooo0Ol00001ooooo`7ooooo000Tooooo`;o00001?oooolEoda<C0;o00003OmVIVH00ol0003o
OgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003o
VIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo00OoOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0003o
C4a<oda<C00Eoda<C003o`000?mVIVKoIVIV00;oIVIV00?o0000ogmoOomoOgl00_moOgl01Ol0003o
VIVIoiVIVOnIVIWo000000Ko/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`04ok>c
/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000?oC4a<00?o
0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000?oIVIV00?o0000ogmoOol00000
0_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVI
V@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<00ol0003oC4a<o`000002
ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c008o`000?nc
/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP03o`000?m<C4co000000Wo<c<c00_o0000oda<
C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`000003olc<c0Gooooo0_l00002ooooo`00
9?ooool00ol0003oooooooooo`03oooooaCoC4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003oOgmo
ogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVI
oiVIV@0;oiVIV@;o00002OmoOgl00ol0003oIVIVofIVIP05ofIVIP03o`000?m<C4coC4a<01GoC4a<
00?o0000ofIVI_mVIVH00_mVIVH00ol0003oOgmoogmoO`02ogmoO`05o`000?nIVIWoVIVIoiVIVOl0
00001_nc/k<00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c00Co/k>c00Go0000oiVIVOnI
VIWoVIVIo`000002ogmoO`05o`000?mVIVKoIVIVofIVI_l000000om<C4`00ol0003o<c<coc<c<`06
oc<c<`05o`000?m<C4coC4a<oda<C?l000000omVIVH00ol0003oOgmoo`000002oiVIV@05o`000?nc
/k?o/k>cok>c/ol000002?o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmoOol0
00000_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`03o`000?m<C4co000000;oIVIV00Go0000ogmo
Ool0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00?o0000ok>c/ol000000_nIVIT2
o`0000;oIVIV00?o0000oda<C?l000002Olc<c<00ol0003oC4a<oda<C002o`000006ogmoOol0003o
VIVIo`000?nc/k?o00001?o<c<`6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003ooooooooo
o`03oooooa?oC4a<00?o0000ofIVI_mVIVH02omVIVH2o`0000[oOgmo00?o0000oiVIVOnIVIT02onI
VIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?mo
Ogl00ol0003oIVIVofIVIP06ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH00_mV
IVH2o`0000?oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<
c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo
00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<
C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<
c<`01ol0003o/k>cok>c/onc/k?o0000oiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00002oda<
C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nI
VIWo000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`01ol0003o/k>co`000?nIVIWo0000ogmoOol0
00000_mVIVH00ol0003oC4a<o`000008oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0
003oVIVIo`000?nc/k?o00001?o<c<`6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003ooooo
ooooo`03oooooa;oC4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`00
0?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0<oiVIV@03o`00
0?moOgooOgmo00OoOgmo00?o0000ofIVI_mVIVH01omVIVH00ol0003oC4a<oda<C00Coda<C003o`00
0?mVIVKoIVIV00?oIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@02oiVIV@03o`00
0?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`00_o<c<`00ol0003o/k>cok>c/`04ok>c/`05o`00
0?nIVIWoVIVIoiVIVOl000000omoOgl01?l0003oIVIVofIVI_l00004oda<C003o`000?lc<c?o<c<c
00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Go
0000ok>c/onc/k?o/k>co`000008olc<c007o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000002ogmo
O`04o`000?mVIVKoIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l0
0002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c007o`00
0?nc/k?o0000oiVIVOl0003oOgmoo`000002ofIVIP03o`000?m<C4co000000So<c<c00co0000oda<
C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00004olc<c0Kooooo0Ol00001oooo
o`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo4Om<C4`00ol0003oIVIVofIVIP0<ofIVIP03
o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03
o`000?nIVIWoVIVI00_oVIVI0_l00009ogmoO`03o`000?mVIVKoIVIV00OoIVIV00?o0000oda<C?m<
C4`05?m<C4`00ol0003oIVIVofIVIP02ofIVIP03o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnI
VIT00_nIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc
/k<01?nc/k<01?l0003oVIVIoiVIVOl00003ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000
oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo0000
0_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo
000000;oOgmo00Co0000ofIVI_mVIVKo00000_m<C4`00ol0003o<c<coc<c<`07oc<c<`0:o`000?m<
C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01oo<c<`0
0ol0003o/k>cok>c/`02o`000005ogmoOol0003oIVIVofIVI_l000000_m<C4`00ol0003o<c<coc<c
<`05oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl2o`000003ok>c/ol0003oc<c<00Co
c<c<1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool@oda<C003o`00
0?mVIVKoIVIV00_oIVIV0_l0000:ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<0
5_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH0
1omVIVH00ol0003oC4a<oda<C00Doda<C003o`000?mVIVKoIVIV00;oIVIV00?o0000ogmoOomoOgl0
0_moOgl2o`0000?oVIVI00?o0000ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c002olc<c003o`00
0?nc/k?o/k>c00Co/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`05o`000?mVIVKoIVIVofIV
I_l000001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIV
I_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Oo
0000ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo00?o0000ofIVI_l000000om<C4`00ol0003o
<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Go0000ogmoOol0003oVIVIo`000002
ok>c/`03o`000?o<c<coc<c<00Koc<c<0_l000001_nc/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV
00?o0000oda<C?l000002?lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0
003o/k>co`0000Goc<c<1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00ooo
ool?oda<C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVI
V@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmo
O`08ogmoO`;o00002?mVIVH00ol0003oC4a<oda<C00Eoda<C003o`000?mVIVKoIVIV00;oIVIV00?o
0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c00Go/k>c00?o
0000olc<c?o<c<`00_o<c<`00ol0003o/k>cok>c/`04ok>c/`05o`000?nIVIWoVIVIoiVIVOl00000
0_moOgl01Ol0003oIVIVofIVI_mVIVKo000000CoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003o
C4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<0
0ol0003oc<c<olc<c006olc<c007o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000002ogmoO`03o`00
0?mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP05
o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c008o`000?nc/k?o/k>c
o`000?nIVIWo0000ogmoOol00002ofIVIP03o`000?m<C4co000000So<c<c00co0000oda<C?m<C4co
0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00005olc<c0Kooooo0Ol00001ooooo`7ooooo
000Tooooo`03o`000?oooooooooo00?ooooo3_m<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?mo
OgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nI
VIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP07ofIVIP03o`000?m<
C4coC4a<01GoC4a<00?o0000ofIVI_mVIVH00_mVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nI
VIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c002olc<c003o`000?nc
/k?o/k>c00Co/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`04o`000?mVIVKoIVIVo`0000Co
C4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C003oda<C006o`000?mVIVKoIVIVo`00
0?moOgoo00000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Woc<c<00Co0000ok>c/onc/k?o0000
0_nIVIT01Ol0003oOgmoo`000?mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003o
C4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00?o0000ok>c/ol000002?o<c<`01_l0
003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00Go0000ofIVI_l0003oC4a<o`000009oc<c<`03o`00
0?m<C4co000000;oIVIV0_l000001OnIVIWo0000ok>c/onc/k?o000000Goc<c<1_ooool1o`00007o
oooo0Oooool002Cooooo00?o0000ooooooooool00oooool=oda<C003o`000?mVIVKoIVIV00_oIVIV
0_l0000:ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVI
oiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH01omVIVH00ol0003oC4a<
oda<C00Eoda<C003o`000?mVIVKoIVIV00?oIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVI
oiVIV@02oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`00_o<c<`00ol0003o/k>c
ok>c/`04ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01Ol0003oIVIVofIVI_mVIVKo0000
00CoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIV
o`0000;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc
/k?o/k>co`0000;oVIVI00Ko0000ogmoOomoOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c
00Oo<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`03o`000?nIVIWo000000;o/k>c00?o
0000olc<c?o<c<`01_o<c<`02?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo00000_mVIVH00ol0
003oC4a<o`000009oc<c<`0;o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol0
00001_o<c<`6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`coC4a<
00?o0000ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI
00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0:oiVIV@03o`000?moOgooOgmo00WoOgmo
00?o0000ofIVI_mVIVH01omVIVH00ol0003oC4a<oda<C00Eoda<C003o`000?mVIVKoIVIV00?oIVIV
00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c00Co/k>c
00?o0000olc<c?o<c<`00_o<c<`00ol0003o/k>cok>c/`04ok>c/`05o`000?nIVIWoVIVIoiVIVOl0
00000omoOgl01Ol0003oIVIVofIVI_mVIVKo000000CoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0
003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo00000onc
/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Ko0000ogmoOomoOgoo
0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Ko0000oda<C?m<C4co0000ofIVI_l0
0002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02?l0003o/k>cok>c
/ol0003oVIVIo`000?moOgoo00000_mVIVH00ol0003oC4a<o`000009oc<c<`0;o`000?m<C4co0000
ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol000001_o<c<`6ooooo`7o00000Oooool1ooooo`00
9?ooool2o`0000Cooooo3?m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo
00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00[oVIVI
00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP07ofIVIP03o`000?m<C4coC4a<01GoC4a<
00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00;oVIVI
00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c00Co/k>c
00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c
<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000onI
VIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT01_l0003o
OgmoogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01olc<c<01_l0003oC4a<oda<C?l0
003oIVIVo`0000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c008o`00
0?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP03o`000?m<C4co000000So<c<c00?o0000
oda<C?l000000_mVIVH01ol0003oOgmoo`000?nIVIWo0000ok>c/ol000001_o<c<`5ooooo`;o0000
0_ooool002Cooooo00?o0000ooooooooool00oooool;oda<C003o`000?mVIVKoIVIV00_oIVIV00?o
0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o
0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00SoIVIV00?o
0000oda<C?m<C4`05Om<C4`00ol0003oIVIVofIVIP03ofIVIP03o`000?moOgooOgmo00;oOgmo00?o
0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o
0000ok>c/onc/k<01Onc/k<01?l0003oVIVIoiVIVOl00003ogmoO`05o`000?mVIVKoIVIVofIVI_l0
00001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mV
IVKo00000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000
ok>c/onc/k?o00000_nIVIT01_l0003oOgmoogmoOol0003oIVIVo`0000?oC4a<00?o0000oc<c<olc
<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<0
0ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`0000;oVIVI0_l00002ofIVIP03o`000?m<
C4co000000Wo<c<c00_o0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`000007
olc<c0Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo2Om<C4`2o`00
00goIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c
01Oo/k>c00?o0000oiVIVOnIVIT02_nIVIT2o`0000[oOgmo00?o0000ofIVI_mVIVH02?mVIVH00ol0
003oC4a<oda<C00Doda<C0;o00001?mVIVH2o`0000CoOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0
003o/k>cok>c/`05ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o0000ok>c/onc/k<01?nc/k<01Ol0
003oVIVIoiVIVOnIVIWo000000?oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c
<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00003oiVIV@05
o`000?nc/k?o/k>cok>c/ol000002?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@06o`000?moOgoo
Ogmoo`000?mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`06o`000?m<C4coC4a<o`000?mV
IVKo00000_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00So0000ok>c
/onc/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV00?o0000oda<C?l000002?lc<c<03?l0003oC4a<
oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Ooc<c<1_ooool1o`00007ooooo
0Oooool002Cooooo00?o0000ooooooooool00oooool9oda<C003o`000?mVIVKoIVIV00_oIVIV00?o
0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o
0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00WoIVIV00?o
0000oda<C?m<C4`05?m<C4`00ol0003oIVIVofIVIP03ofIVIP03o`000?moOgooOgmo00?oOgmo00?o
0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`05ok>c/`05o`000?o<c<coc<c<olc<c?l00000
1onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<
C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgoo
Ogmoo`0000;oVIVI00?o0000ok>c/onc/k<00_nc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc
/k?o/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`06
o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<co
c<c<00Koc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV00?o0000oda<C?l0
00002?lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Oo
c<c<1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool8oda<C003o`00
0?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`00
0?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`00
0?mVIVKoIVIV00WoIVIV00?o0000oda<C?m<C4`05?m<C4`00ol0003oIVIVofIVIP03ofIVIP03o`00
0?moOgooOgmo00?oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`05ok>c/`05o`00
0?o<c<coc<c<olc<c?l000001onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Co0000ofIV
I_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`06oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000
ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<
00Co0000ok>c/onc/k?o00000_nIVIT01_l0003oOgmoogmoOol0003oIVIVo`0000?oC4a<00?o0000
oc<c<olc<c<01_lc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00?o0000oiVIVOl00000
0_nc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>cok>c/`;o000000GoOgmoo`000?mV
IVKoIVIVo`000002oda<C003o`000?lc<c?o<c<c00Go<c<c00Ko0000oda<C?m<C4co0000ofIVI_l0
0002ogmoO`;o000000?o/k>co`000?o<c<`01oo<c<`6ooooo`7o00000Oooool1ooooo`009?ooool0
0ol0003oooooooooo`03ooooo`OoC4a<00?o0000ofIVI_mVIVH02_mVIVH2o`0000[oOgmo00?o0000
oiVIVOnIVIT02onIVIT2o`0001Oo/k>c0_l0000<oiVIV@;o00002_moOgl00ol0003oIVIVofIVIP09
ofIVIP03o`000?m<C4coC4a<01GoC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`02
ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01_nc/k<01Ol0003oc<c<olc<c?o<
c<co000000Ko/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`05o`000?mVIVKoIVIVofIVI_l0
00001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mV
IVKo00000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000
ok>c/onc/k?o/k>co`000002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co0000
2Olc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0
003oc<c<olc<c006olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP03o`00
0?m<C4co000000So<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c
/ol00008olc<c0Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo1_m<
C4`00ol0003oIVIVofIVIP0:ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onI
VIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02Omo
Ogl00ol0003oIVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH01?mV
IVH01Ol0003oOgmoogmoOomoOgoo000000GoVIVI00?o0000ok>c/onc/k<01_nc/k<01Ol0003oc<c<
olc<c?o<c<co000000Go/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo0000
00?oIVIV00?o0000oda<C?m<C4`00_m<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<
00?oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<
c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@03o`000?moOgoo000000;oIVIV
00Co0000oda<C?m<C4co00002Olc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00?o0000
oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000
ogmoOol00002ofIVIP03o`000?m<C4co000000So<c<c00co0000oda<C?m<C4co0000ofIVI_l0003o
Ogmoo`000?nIVIWo0000ok>c/ol00008olc<c003o`000?oooooooooo00?ooooo0Ol00001ooooo`7o
oooo000Tooooo`03o`000?oooooooooo00?ooooo1Om<C4`00ol0003oIVIVofIVIP0:ofIVIP03o`00
0?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`00
0?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0:ofIVIP03o`00
0?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH01?mVIVH00ol0003oOgmoogmoO`02ogmoO`03o`00
0?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01_nc/k<01Ol0003oc<c<olc<c?o<c<co000000Ko
/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`05o`000?mVIVKoIVIVofIVI_l000001?m<C4`0
0ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_mo
Ogl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o0000ok>c/onc/k<0
0_nc/k<01Ol0003oVIVIo`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<01_l0
003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<
c006olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl01Ol0003oIVIVo`000?m<C4co0000
00Wo<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<
olc<c006olc<c003o`000?oooooooooo00?ooooo0Ol00001ooooo`7ooooo000Iooooo`Go00001_oo
ool00ol0003oooooooooo`03ooooo`CoC4a<00?o0000ofIVI_mVIVH02_mVIVH2o`0000[oOgmo00?o
0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI0_l0
0009ogmoO`;o00003?mVIVH00ol0003oC4a<oda<C00Doda<C003o`000?mVIVKoIVIV00CoIVIV00?o
0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c00Go/k>c0ol0
00000oo<c<co0000ok>c/`06ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01?l0003oIVIV
ofIVI_l00005oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003o
IVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`0
1Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<
C?l00009oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl00ol0003oVIVIo`000002ok>c
/`03o`000?o<c<coc<c<00Koc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV
00?o0000oda<C?l000002Olc<c<02ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc
/k?o000000Woc<c<00?o0000ooooooooool00oooool1o`00007ooooo0Oooool001Wooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo00?ooooo0om<C4`00ol0003oIVIVofIV
IP0:ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c
/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIV
IP0:ofIVIP03o`000?m<C4coC4a<01GoC4a<00?o0000ofIVI_mVIVH01?mVIVH00ol0003oOgmoogmo
O`02ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<01Onc/k<01?l0003o/k>cok>c
/ol00008ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01?l0003oIVIVofIVI_l00004oda<
C003o`000?lc<c?o<c<c00Ko<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002
ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c
/onc/k?o000000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`06
o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<co
c<c<00Koc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV00?o0000oda<C?l0
00002Olc<c<02ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o000000Woc<c<
00?o0000ooooooooool00oooool1o`00007ooooo0Oooool0017ooooo1_l00003ooooo`03oiRHV?lQ
8B7ok^k^00Oooooo0ol00003ooooo`;oC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmo
O`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVI
V@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<oda<
C00Eoda<C003o`000?mVIVKoIVIV00CoIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVI
V@03oiVIV@03o`000?nc/k?o/k>c00Ko/k>c0_l00009ok>c/`05o`000?nIVIWoVIVIoiVIVOl00000
0omoOgl01?l0003oIVIVofIVI_l00005oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<
C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000
olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmoOol000000_mV
IVH01?l0003oC4a<oda<C?l00009oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Go0000ogmoOol0
003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT2
o`0000;oIVIV00?o0000oda<C?l000002Olc<c<01ol0003oC4a<o`000?mVIVKo0000ogmoOol00000
0_nIVIT2o`0000Woc<c<00?o0000ooooooooool00_ooool3o`0000;ooooo000Kooooo`03oiRHV?lQ
8B7ok^k^00Kooooo00?o0000ooooooooool00oooool00om<C4co0000ofIVIP0;ofIVIP;o00002_mo
Ogl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onI
VIT00ol0003oOgmoogmoO`08ogmoO`;o00003?mVIVH00ol0003oC4a<oda<C00Eoda<C003o`000?mV
IVKoIVIV00CoIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc
/k?o/k>c00Ko/k>c00Co0000olc<c?o<c<co00001onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?o
Ogmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<
C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo00000onc
/k<00ol0003oc<c<olc<c006olc<c007o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000002ogmoO`04
o`000?mVIVKoIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02Ol0003oC4a<oda<C?m<C4co
0000ofIVI_l0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00[o0000ok>c/onc
/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0<o`00
0?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00002Oo<c<`00ol0003ooooo
ooooo`04ooooo`7o00000Oooool1ooooo`007?ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nI
VIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0<oiVIV@03o`000?mo
OgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Eoda<C003o`000?mV
IVKoIVIV00?oIVIV00?o0000ogmoOomoOgl00omoOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc
/k?o/k>c00Ko/k>c00Co0000olc<c?o<c<co00001onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?o
Ogmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<
C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo00000onc
/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00?o0000oiVIVOl000000_mo
Ogl01?l0003oIVIVofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Wo0000oda<C?m<C4co
C4a<o`000?mVIVKo0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00008olc<c00:o`000?nc
/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<0
3?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Woc<c<00?o0000
ooooooooool01?ooool1o`00007ooooo0Oooool001gooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`03ooooo`coIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0;oiVI
V@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT2o`0000[oOgmo00?o0000ofIV
I_mVIVH02omVIVH00ol0003oC4a<oda<C00Eoda<C003o`000?mVIVKoIVIV00CoIVIV00?o0000ogmo
OomoOgl00_moOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c00So/k>c0_l00007ok>c
/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl00ol0003oIVIVofIVIP02ofIVIP05o`000?m<C4co
C4a<oda<C?l000001olc<c<00ol0003oC4a<oda<C002oda<C005o`000?mVIVKoIVIVofIVI_l00000
0_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc
/k?o/k>co`000002oiVIV@06o`000?moOgooOgmoo`000?mVIVKo00000om<C4`00ol0003o<c<coc<c
<`05oc<c<`09o`000?m<C4coC4a<oda<C?l0003oIVIVo`000?moOgoo000000;oVIVI00Co0000ok>c
/onc/k?o00002?o<c<`02?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo00000_mVIVH01?l0003o
C4a<oda<C?l00008oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c
00?o0000olc<c?o<c<`01_o<c<`00ol0003o/k>cooooo`05ooooo`7o00000Oooool1ooooo`006Ooo
ool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool00oooool<ofIVIP03o`00
0?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`00
0?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`00
0?m<C4coC4a<01GoC4a<00?o0000ofIVI_mVIVH01?mVIVH00ol0003oOgmoogmoO`03ogmoO`03o`00
0?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<02Onc/k<00ol0003o/k>cok>c/`06ok>c/`05o`00
0?nIVIWoVIVIoiVIVOl000000omoOgl01Ol0003oIVIVofIVI_mVIVKo000000CoC4a<00?o0000oc<c
<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co0000
oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c005olc<c004o`000?nc/k?o/k>cok>c/`;o0000
00GoVIVIo`000?moOgooOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Wo0000oda<
C?m<C4coC4a<o`000?mVIVKo0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00008olc<c008
o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP03o`000?m<C4co000000So<c<c00[o
0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006
olc<c003o`000?nc/k?o000000Gooooo0Ol00001ooooo`7ooooo000Iooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`03ooooo`_oIVIV00?o0000ogmoOomoOgl02?moOgl0
0ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT03?nIVIT0
0ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`0
0ol0003oIVIVofIVIP04ofIVIP03o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00_nIVIT0
0ol0003o/k>cok>c/`0Cok>c/`04o`000?nIVIWoVIVIo`0000CoOgmo00Go0000ofIVI_mVIVKoIVIV
o`000004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIV
ofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`01Ol0
003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01?l0003oC4a<oda<
C?l00008oc<c<`09o`000?m<C4coC4a<oda<C?l0003oIVIVo`000?moOgoo000000;oVIVI00Co0000
ok>c/onc/k?o00002?o<c<`02?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo00000_mVIVH00ol0
003oC4a<o`000008oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o
/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003o/k>co`000005ooooo`7o00000Oooool1ooooo`00
9?ooool00ol0003oooooooooo`03ooooo`[oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVI
oiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT2o`0000[oOgmo
00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00CoIVIV
00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c01;o/k>c
00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`05o`000?mVIVKoIVIVofIVI_l000001?m<C4`00ol0
003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl0
1?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o0000
0_nIVIT01?l0003oOgmoogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Oo0000oda<
C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<
c006olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl01Ol0003oIVIVo`000?m<C4co0000
00Wo<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<
olc<c006olc<c003o`000?nc/k?o000000Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oo
oooooooo00?ooooo2?mVIVH2o`0000[oOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c
/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIV
IP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH01?mVIVH00ol0003oOgmoogmo
O`03ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<04_nc/k<01Ol0003oVIVIoiVI
VOnIVIWo000000?oOgmo0_l00002ofIVIP03o`000?m<C4coC4a<00?oC4a<00?o0000oc<c<olc<c<0
1?lc<c<00ol0003oC4a<oda<C002oda<C0;o00000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@05
o`000?nc/k?o/k>cok>c/ol000002Oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@06o`000?moOgoo
Ogmoo`000?mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;o
IVIV00?o0000ogmoOol000000_nIVIT00ol0003o/k>co`000009olc<c00:o`000?nc/k?o/k>co`00
0?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01olc<c<02Ol0003oC4a<
o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o0000
ok>c/ol000001_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool8ofIV
IP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c
/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl01omoOgl2o`0000goIVIV00?o0000oda<
C?m<C4`05om<C4`00ol0003oIVIVofIVIP04ofIVIP03o`000?moOgooOgmo00?oOgmo00?o0000oiVI
VOnIVIT00_nIVIT00ol0003o/k>cok>c/`0Bok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl0
1Ol0003oIVIVofIVI_mVIVKo000000GoC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<
C002oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03
o`000?o<c<coc<c<00Ooc<c<00Co0000ok>c/onc/k?o00000_nIVIT01_l0003oOgmoogmoOol0003o
IVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`00
0?moOgoo000000;oVIVI00?o0000ok>c/ol000002Oo<c<`02_l0003o/k>cok>c/ol0003oVIVIo`00
0?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Wo0000oda<C?l0003oIVIV
o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c003o`000?nc/k?o0000
00Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo1omVIVH00ol0003o
OgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003o
VIVIoiVIV@0;oiVIV@;o00002OmoOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<01Oo
C4a<00?o0000ofIVI_mVIVH01?mVIVH00ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00;o
VIVI00?o0000ok>c/onc/k<04_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00?o0000ofIV
I_mVIVH00_mVIVH00ol0003oC4a<oda<C002oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<
C?m<C4`00_m<C4`00ol0003oIVIVofIVIP02ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Co0000
ok>c/onc/k?o00002Oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@04o`000?moOgooOgmoo`0000;o
IVIV00Co0000oda<C?m<C4co00002?lc<c<01?l0003oC4a<oda<C?l00003ofIVIP;o00000_nIVIT0
1?l0003o/k>cok>c/ol00008olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIV
o`0000;oC4a<00?o0000oc<c<olc<c<01olc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003o
VIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/ol0003oVIVI1_ooool1o`00
007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool5ofIVIP;o00002_moOgl00ol0003o
VIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003o
OgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV0_l0000Hoda<C0;o00001_mVIVH00ol0003o
OgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<04Onc/k<00ol0003o
VIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol000000omVIVH00ol0003oC4a<oda<C002oda<
C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo
000000;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc
/k?o/k>cok>c/ol000000_nIVIT01_l0003oOgmoogmoOol0003oIVIVo`0000?oC4a<00?o0000oc<c
<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000
ok>c/onc/k?o00002?o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002
oda<C003o`000?lc<c?o<c<c00Ko<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nI
VIWo0000ok>c/ol00009olc<c004o`000?nc/k?o0000oiVIV@Kooooo0Ol00001ooooo`7ooooo000T
ooooo`;o00001?ooool5ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT0
0ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl2
o`0000coIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP06ofIVIP03o`000?moOgoo
Ogmo00;oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0Bok>c/`05o`000?nIVIWo
VIVIoiVIVOl000001?moOgl01Ol0003oIVIVofIVI_mVIVKo000000CoC4a<00?o0000oc<c<olc<c<0
1Olc<c<00ol0003oC4a<oda<C002oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01?l0003o
VIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002
oiVIV@06o`000?moOgooOgmoo`000?mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`04o`00
0?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00008olc<
c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc
<c<01_lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Wo
c<c<00Go0000ok>c/ol0003oVIVIo`000004ooooo`;o00000_ooool002Cooooo00?o0000oooooooo
ool00oooool4ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o
/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003o
IVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0003o
OgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<04Onc/k<00ol0003o
VIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol000000omVIVH00ol0003oC4a<oda<C002oda<
C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo
000000;oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c005olc<c005o`000?nc
/k?o/k>cok>c/ol000000onIVIT01Ol0003oOgmoo`000?mVIVKo000000?oC4a<00?o0000oc<c<olc
<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c
/onc/k?o00002?o<c<`02?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo00000_mVIVH01?l0003o
C4a<oda<C?l00008oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c
00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>co`000?nIVIWo000000Kooooo0Ol00001ooooo`7o
oooo000Tooooo`03o`000?oooooooooo00?ooooo0_mVIVH2o`0000[oOgmo00?o0000oiVIVOnIVIT0
2onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl0
2?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH0
1_mVIVH00ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<0
4_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Go0000ofIVI_mVIVKoIVIVo`000005oda<
C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002
ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc
/k?o/k>cok>c/ol000000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000Wo
<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>c
o`0000Soc<c<00Wo0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVH00_l000000om<C4co
0000oc<c<`07oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c
00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>co`000?l0003oOgmo00Kooooo0Ol00001ooooo`7o
oooo000Tooooo`03o`000?oooooooooo00?ooooo0_mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`00
0?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0:oiVIV@03o`00
0?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Goda<C003o`00
0?mVIVKoIVIV00KoIVIV00?o0000ogmoOomoOgl00omoOgl00ol0003oVIVIoiVIV@03oiVIV@03o`00
0?nc/k?o/k>c01;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`05o`000?mVIVKoIVIVofIV
I_l000001Om<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIV
I_mVIVKo00000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<
c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<
oda<C?l00009oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0
003o/k>cok>c/ol00008olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`00
00;oC4a<00?o0000oc<c<olc<c<01_lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000
oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/ol0003o0000ogmoO`06oooo
o`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`03ofIVI_l0003oOgmo00Wo
Ogmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00[o
VIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01Oo
C4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00?o
VIVI00?o0000ok>c/onc/k<04_nc/k<00ol0003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmo
Ool000000omVIVH00ol0003oC4a<oda<C003oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<
C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00003ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o
0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`03o`000?nIVIWo000000;oOgmo00Co
0000ofIVI_mVIVKo00000_m<C4`00ol0003o<c<coc<c<`07oc<c<`04o`000?m<C4coC4a<o`0000;o
IVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Go0000ok>c
/onc/k?o0000oiVIV@02o`0000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<02_l0003oC4a<oda<
C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000
ok>c/ol0003o0000ogmoO`06ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03
ooooo`03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0G
ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;
ofIVIP03o`000?m<C4coC4a<01SoC4a<00?o0000ofIVI_mVIVH01OmVIVH00ol0003oOgmoogmoO`03
ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<04onc/k<01Ol0003oVIVIoiVIVOnI
VIWo000000?oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C002oda<C003o`000?lc
<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00003ogmoO`04o`00
0?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o0000
00;oVIVI00?o0000ogmoOol000000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Co0000
oda<C?m<C4co00000_mVIVH01_l0003oOgmoogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<
c<`01_o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`00
0?lc<c?o<c<c00Oo<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl000000_nc/k<0
0ol0003oc<c<olc<c006olc<c006o`000?nc/k?o0000oiVIVOl0003oOgmo1_ooool1o`00007ooooo
0Oooool002Cooooo00?o0000ooooooooool00oooool:ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o
0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0:oiVIV@;o00002_moOgl00ol0003oIVIVofIV
IP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<0_l00008ofIVIP03o`000?moOgooOgmo00?oOgmo00?o
0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0Bok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go
0000ogmoOomoOgooOgmoo`000003ofIVIP03o`000?m<C4coC4a<00?oC4a<00?o0000oc<c<olc<c<0
1?lc<c<00ol0003oC4a<oda<C002oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01?l0003o
VIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<00ol0
003oVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<0
1Ol0003oC4a<oda<C?l0003oIVIV00;o000000CoOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<
olc<c007olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o
0000oc<c<olc<c<01olc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c
/`03o`000?o<c<coc<c<00Koc<c<00Oo0000ok>c/ol0003oVIVIo`000?moOgoo000000Gooooo0Ol0
0001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo2OmoOgl00ol0003oVIVIoiVIV@0;
oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`09
ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`06?m<C4`00ol0003oIVIVofIVIP06
ofIVIP03o`000?moOgooOgmo00CoOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0B
ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl00ol0003oIVIVofIVIP02ofIVIP03o`000?m<
C4coC4a<00?oC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C002oda<C005o`000?mV
IVKoIVIVofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Go
c<c<00?o0000ok>c/onc/k<00_nc/k<00ol0003oVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`00
00?oC4a<00?o0000oc<c<olc<c<01Olc<c<01ol0003oC4a<oda<C?m<C4co0000ofIVI_l000000_mo
Ogl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00[o0000ok>c/onc/k?o0000
oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`07oc<c<`0;o`000?m<C4co
0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol000002Oo<c<`01ol0003o/k>co`000?nIVIWo
0000ogmoOol000001Oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool8
ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0;
oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00H
oda<C003o`000?mVIVKoIVIV00KoIVIV00?o0000ogmoOomoOgl01?moOgl00ol0003oVIVIoiVIV@03
oiVIV@03o`000?nc/k?o/k>c01;o/k>c00?o0000oiVIVOnIVIT00_nIVIT01?l0003oOgmoogmoOol0
0004ofIVIP03o`000?m<C4coC4a<00?oC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<
C002oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00004ok>c/`03
o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<00ol0003oVIVIo`000003ogmoO`03
o`000?mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01_l0003oC4a<oda<C?l0003oIVIV
o`0000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c00:o`000?nc/k?o
/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01olc<c<02Ol0
003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<
00Oo0000ok>c/ol0003oVIVIo`000?moOgoo000000Kooooo0Ol00001ooooo`7ooooo000Tooooo`03
o`000?oooooooooo00?ooooo1omoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo
/k>c00?o0000oiVIVOnIVIT02_nIVIT2o`0000[oOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003o
C4a<oda<C00Goda<C0;o00002?mVIVH00ol0003oOgmoogmoO`04ogmoO`03o`000?nIVIWoVIVI00?o
VIVI00?o0000ok>c/onc/k<04_nc/k<00ol0003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmo
Ool000000omVIVH00ol0003oC4a<oda<C003oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<
C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo00000onc
/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmo
ogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Oo0000oda<C?m<C4coC4a<o`000?mV
IVKo000000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c00:o`000?nc
/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<0
2_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<
00Koc<c<00Oo0000ok>c/ol0003oVIVIo`000?moOgoo000000Kooooo0Ol00001ooooo`7ooooo000T
ooooo`;o00001?ooool6ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<0
0ol0003oVIVIoiVIV@0:oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH0
0ol0003oC4a<oda<C00Hoda<C003o`000?mVIVKoIVIV00OoIVIV00?o0000ogmoOomoOgl00omoOgl0
0ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c01;o/k>c00?o0000oiVIVOnIVIT00_nIVIT0
1Ol0003oOgmoogmoOomoOgoo000000?oIVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o<c<coc<c
<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`04o`00
0?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o0000
00;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`07o`000?m<
C4coC4a<oda<C?l0003oIVIVo`000002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<
c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`0
0ol0003o<c<coc<c<`06oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`00
00;o/k>c00?o0000olc<c?o<c<`01_o<c<`01ol0003o/k>co`000?nIVIWo0000ogmoOol000001Ooo
ool2o`0000;ooooo000Tooooo`03o`000?oooooooooo00?ooooo1OmoOgl00ol0003oVIVIoiVIV@0;
oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08
ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`06?m<C4`00ol0003oIVIVofIVIP07
ofIVIP03o`000?moOgooOgmo00CoOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0C
ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01Ol0003oIVIVofIVI_mVIVKo000000KoC4a<
00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C002oda<C005o`000?mVIVKoIVIVofIVI_l0
00000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c
/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Co0000oda<C?m<C4co0000
2Olc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo00000_nc/k<0
0ol0003oc<c<olc<c006olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`00
00?oC4a<00?o0000oc<c<olc<c<01_lc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVI
o`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o0000ok>c/ol000000_nIVIT2o`000003ofIV
I_oooooooooo00Cooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo1?mo
Ogl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c0_l0000<oiVIV@;o00002Omo
Ogl2o`0000goIVIV00?o0000oda<C?m<C4`05om<C4`2o`0000WoIVIV00?o0000ogmoOomoOgl01?mo
Ogl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c01?o/k>c00Go0000oiVIVOnIVIWoVIVI
o`000004ogmoO`05o`000?mVIVKoIVIVofIVI_l000001Om<C4`00ol0003o<c<coc<c<`04oc<c<`03
o`000?m<C4coC4a<00?oC4a<00Co0000ofIVI_mVIVKo00000_moOgl2o`0000;oVIVI00Go0000ok>c
/onc/k?o/k>co`000008olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmo
Ool00002ofIVIP04o`000?m<C4coC4a<o`0000Wo<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002
ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`02_l0003o/k>cok>c/ol0
003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00co0000oda<
C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00009olc<c009o`000?nc/k?o0000
oiVIVOl0003oOgmoo`000?mVIVKo000000Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oo
oooooooo00?ooooo0omoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o
0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o
0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP08ofIVIP03o`000?moOgooOgmo00GoOgmo00?o
0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0Cok>c/`05o`000?nIVIWoVIVIoiVIVOl00000
1?moOgl01Ol0003oIVIVofIVI_mVIVKo000000GoC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003o
C4a<oda<C003oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000003
ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?mo
OgooOgmoo`0000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<02?l0003oC4a<oda<C?l0003oIVIV
o`000?moOgoo00000_nIVIT01?l0003o/k>cok>c/ol00009olc<c00:o`000?nc/k?o/k>co`000?nI
VIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<03?l0003oC4a<oda<
C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Woc<c<00Wo0000ok>c/ol0003oVIVI
o`000?moOgoo0000ofIVI_l000001Oooool1o`00007ooooo0Oooool002Cooooo00?o0000oooooooo
ool00oooool2ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003o
VIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003o
C4a<oda<C00Goda<C003o`000?mVIVKoIVIV00SoIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003o
VIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003o
OgmoogmoOomoOgoo000000?oIVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`04oc<c
<`03o`000?m<C4coC4a<00?oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01Ol0003oVIVIoiVIVOnI
VIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI
00Co0000ogmoOomoOgoo00000_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`06o`000?m<C4coC4a<
o`000?mVIVKo00000_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00[o
0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`07
oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<
c<`01_o<c<`00ol0003o/k>cok>c/`02o`000004ogmoOol0003oIVIVo`0000Kooooo0Ol00001oooo
o`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo00?oOgmoo`000?nIVIT03?nIVIT00ol0003o
/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl2o`0000go
IVIV00?o0000oda<C?m<C4`05_m<C4`2o`0000_oIVIV00?o0000ogmoOomoOgl01?moOgl00ol0003o
VIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003o
OgmoogmoOomoOgoo000000?oIVIV00?o0000oda<C?m<C4`01?m<C4`00ol0003o<c<coc<c<`04oc<c
<`03o`000?m<C4coC4a<00;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`04o`000?nIVIWo
VIVIo`0000Co/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI
00Go0000ogmoOol0003o0000ofIVIP02o`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01ol0003o
C4a<oda<C?m<C4co0000ofIVI_l000000_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<co
c<c<00Koc<c<00_o0000ok>c/onc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<
C003o`000?lc<c?o<c<c00Oo<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00000
0_nc/k<00ol0003oc<c<olc<c006olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo
000000Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo00?o0000oiVI
VOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmo
OomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIV
I_mVIVH02_mVIVH00ol0003oOgmoogmoO`04ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c
/onc/k<04onc/k<00ol0003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol000000omVIVH0
0ol0003oC4a<oda<C004oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00_m<C4`0
1Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<
olc<c006olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01Ol0
003oC4a<oda<C?m<C4co000000So<c<c00Co0000oda<C?m<C4co00000_mVIVH01_l0003oOgmoogmo
Ool0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02ol0003o/k>cok>c/onc/k?o0000
oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01olc<c<02Ol0003oC4a<
o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Wo0000
ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000001_ooool1o`00007ooooo0Oooool002Cooooo
00?o0000ooooooooool00oooool=oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT0
2onIVIT2o`0000[oOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`00
0?mVIVKoIVIV00[oIVIV00?o0000ogmoOomoOgl01?moOgl00ol0003oVIVIoiVIV@04oiVIV@03o`00
0?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000?o
IVIV00?o0000oda<C?m<C4`01?m<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00;o
C4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000
olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmoOol000000_mV
IVH00ol0003oC4a<oda<C002oda<C003o`000?lc<c?o<c<c00Go<c<c00Oo0000oda<C?m<C4coC4a<
o`000?mVIVKo000000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c00;
o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<c
oc<c<`07oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000
olc<c?o<c<`01oo<c<`2o`000004oiVIVOl0003oOgmoogmoO`;o000000?oC4a<ooooooooool01?oo
ool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool<oiVIV@03o`000?nc/k?o
/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKo
IVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0:ofIVIP03o`000?moOgoo
Ogmo00CoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`0Cok>c/`03o`000?nIVIWo
VIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`000004ofIVIP03o`000?m<C4coC4a<00?oC4a<00?o
0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C003oda<C004o`000?mVIVKoIVIVo`0000?oOgmo
00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c003o`000?nc/k?o/k>c00;o
/k>c00Ko0000oiVIVOnIVIWo0000ogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc
<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o
00002?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`0
0ol0003o<c<coc<c<`06oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`00
00;o/k>c00?o0000olc<c?o<c<`01_o<c<`02_l0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIV
o`000?m<C4`6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`_oVIVI
00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo00SoOgmo
00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00[oIVIV
00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c01?o/k>c
00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000CoIVIV00?o0000oda<C?m<
C4`00om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Co0000ofIVI_mV
IVKo00000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`0
0ol0003o/k>cok>c/`02ok>c/`06o`000?nIVIWoVIVIo`000?moOgoo00000_mVIVH01Ol0003oC4a<
oda<C?m<C4co000000So<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVI
V@04o`000?nc/k?o/k>co`0000Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`00
0?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`00
0?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00[o0000ok>c/ol0003oVIVI
o`000?moOgoo0000ofIVI_l0003oC4a<1_ooool1o`00007ooooo0Oooool002Cooooo0_l00004oooo
o`[oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@;o00002_moOgl00ol0
003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0
003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<04onc/k<00ol0
003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol000001?mVIVH00ol0003oC4a<oda<C003
oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00om<C4`01Ol0003oIVIVofIVI_mV
IVKo000000;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c003o`00
0?nc/k?o/k>c00;o/k>c00Ko0000oiVIVOnIVIWo0000ogmoOol00002ofIVIP05o`000?m<C4coC4a<
oda<C?l000002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00Go
0000ok>c/onc/k?o/k>co`000008olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003o
IVIVo`0000;oC4a<00?o0000oc<c<olc<c<01olc<c<01ol0003oC4a<o`000?mVIVKo0000ogmoOol0
00000_nIVIT00ol0003o/k>co`000009olc<c0;o00000_nIVIT2o`000005ofIVI_l0003oC4a<oda<
C?l000001?ooool2o`0000;ooooo000Tooooo`03o`000?oooooooooo00?ooooo2OnIVIT00ol0003o
/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003o
IVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003o
OgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00GoVIVI00?o0000ok>c/onc/k<04_nc/k<2o`0000?o
VIVI00?o0000ogmoOomoOgl00_moOgl01Ol0003oIVIVofIVI_mVIVKo000000KoC4a<00?o0000oc<c
<olc<c<00olc<c<00ol0003oC4a<oda<C003oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl0
1Ol0003oVIVIoiVIVOnIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c
/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01Ol0003oC4a<oda<C?m<C4co0000
00So<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o
/k>co`0000Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;o
C4a<00?o0000oc<c<olc<c<01_lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVI
VOl0003o/k>co`0000[oc<c<0_l000001_nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000
ooooooooool00oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool8oiVI
V@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`07ogmo
O`;o00003OmVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00[oIVIV00?o0000ogmo
OomoOgl01OmoOgl00ol0003oVIVIoiVIV@05oiVIV@03o`000?nc/k?o/k>c01;o/k>c00?o0000oiVI
VOnIVIT00_nIVIT00ol0003oOgmoogmoO`02ogmoO`05o`000?mVIVKoIVIVofIVI_l000001_m<C4`0
0ol0003o<c<coc<c<`03oc<c<`03o`000?m<C4coC4a<00?oC4a<00Go0000ofIVI_mVIVKoIVIVo`00
0002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c005o`00
0?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP05o`000?m<C4coC4a<
oda<C?l000002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00Co
0000ok>c/onc/k?o00002?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000ofIV
I_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmo
Ool0003oVIVIo`000?nc/k?o00002_o<c<`2o`000006oiVIVOl0003oOgmoo`000?mVIVKo00000_m<
C4`00ol0003oooooooooo`03ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03
ooooo`OoVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@;o00002OmoOgl0
0ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02_mVIVH0
0ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00GoVIVI00?o0000ok>c/onc/k<04_nc/k<0
0ol0003oVIVIoiVIV@02oiVIV@03o`000?moOgooOgmo00;oOgmo00Go0000ofIVI_mVIVKoIVIVo`00
0006oda<C003o`000?lc<c?o<c<c00?o<c<c00?o0000oda<C?m<C4`00om<C4`01Ol0003oIVIVofIV
I_mVIVKo000000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Go
c<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Go0000
oda<C?m<C4coC4a<o`000008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Ko0000ogmoOomoOgoo
0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00?o0000ok>c/ol000000_nIVIT01Ol0
003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01olc<c<01Ol0003oC4a<o`000?mV
IVKo000000;oOgmo0_l00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Co0000ok>c/ol0003oVIVI
0_l00002ofIVIP03o`000?m<C4co000000Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oo
oooooooo00?ooooo1_nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o
0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP;o00006?m<C4`2o`0000coIVIV00?o
0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@05oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o
0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000CoIVIV00?o0000oda<C?m<C4`0
0om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Go0000ofIVI_mVIVKo
IVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0
003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01Ol0003oC4a<oda<
C?m<C4co000000So<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVIV@04
o`000?nc/k?o/k>co`0000Woc<c<00?o0000ok>c/ol000000_nIVIT01Ol0003oOgmoo`000?mVIVKo
000000;oC4a<00?o0000oc<c<olc<c<01olc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003o
VIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o0000oiVIV@02o`00
0005ofIVI_l0003oC4a<oda<C?l000001_ooool1o`00007ooooo0Oooool002Cooooo00?o0000oooo
ooooool00oooool5oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0
003oOgmoogmoO`08ogmoO`;o00003?mVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV
00_oIVIV00?o0000ogmoOomoOgl01_moOgl00ol0003oVIVIoiVIV@05oiVIV@03o`000?nc/k?o/k>c
01?o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000CoIVIV00?o0000
oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Go0000
ofIVI_mVIVKoIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`0
1_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01Ol0
003oC4a<oda<C?m<C4co000000So<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`00
0002oiVIV@04o`000?nc/k?o/k>co`0000Woc<c<00?o0000ok>c/ol000000_nIVIT01Ol0003oOgmo
o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01olc<c<02Ol0003oC4a<o`000?mVIVKo0000
ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o0000
oiVIV@02o`000005ofIVI_l0003oC4a<oda<C?l000001_ooool1o`00007ooooo0Oooool002Cooooo
00?o0000ooooooooool00oooool4oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT0
2onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`0
5om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00KoOgmo00?o0000oiVIVOnIVIT0
1?nIVIT2o`0001Go/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000Co
IVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?o
C4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000
olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo0000
0_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Wo0000oda<C?m<C4coC4a<o`000?mVIVKo
0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00009olc<c003o`000?nc/k?o000000;oVIVI
00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00?o0000oda<C?l0
00000_mVIVH2o`000005oiVIVOl0003o/k>cok>c/ol000002Oo<c<`01_l0003o/k>co`000?nIVIWo
0000ogmoO`;o00000_m<C4`00ol0003o<c<cooooo`05ooooo`7o00000Oooool1ooooo`009?ooool0
0ol0003oooooooooo`03ooooo`?oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;
oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00G
oda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl01_moOgl00ol0003oVIVIoiVIV@04
oiVIV@03o`000?nc/k?o/k>c01Co/k>c00?o0000oiVIVOnIVIT00_nIVIT00ol0003oOgmoogmoO`02
ogmoO`05o`000?mVIVKoIVIVofIVI_l000001_m<C4`00ol0003o<c<coc<c<`03oc<c<`03o`000?m<
C4coC4a<00?oC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`04o`000?nIVIWoVIVIo`0000Co
/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`00
00;oOgmo00Co0000ofIVI_mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4co
C4a<oda<C?l000000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<
00Co0000ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c
<olc<c<01_lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03
o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o0000oiVIV@02o`000006ofIVI_l0003oC4a<
oda<C?l0003o<c<c1_ooool1o`00007ooooo0Oooool001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP06ooooo`03o`000?oooooooooo00?ooooo0_nIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nI
VIWoVIVI00[oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<
C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`06ogmoO`03o`000?nI
VIWoVIVI00GoVIVI00?o0000ok>c/onc/k<05?nc/k<00ol0003oVIVIoiVIV@02oiVIV@03o`000?mo
OgooOgmo00;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000006oda<C003o`000?lc<c?o<c<c00?o<c<c
00?o0000oda<C?m<C4`00om<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Co0000oiVIVOnI
VIWo00001?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVI
VOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go
0000oda<C?m<C4coC4a<o`000002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o
00002?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`0
0ol0003o<c<coc<c<`06oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`00
00;o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/ol0003oVIVI00;o000000KoIVIV
o`000?m<C4coC4a<o`000?lc<c<6ooooo`7o00000Oooool1ooooo`006Oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Kooooo00?o0000ooooooooool00oooool00onIVIWo0000ok>c/`0Hok>c/`03o`00
0?nIVIWoVIVI00[oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`00
0?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmoO`06ogmoO`03o`00
0?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<05?nc/k<00ol0003oVIVIoiVIV@02oiVIV@03o`00
0?moOgooOgmo00;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000007oda<C003o`000?lc<c?o<c<c00?o
<c<c00?o0000oda<C?m<C4`00om<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Go0000oiVI
VOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Goc<c<00Go0000ok>c/onc/k?o/k>co`00
0003oiVIV@03o`000?moOgoo000000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`09o`00
0?m<C4coC4a<oda<C?l0003oIVIVo`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002Oo<
c<`01?l0003o/k>cok>c/ol00002oiVIV@07o`000?moOgoo0000ofIVI_l0003oC4a<o`000009oc<c
<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<
c<`01_o<c<`00ol0003o/k>cok>c/`02o`000004ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c
<oooool01Oooool1o`00007ooooo0Oooool001Wooooo00Go410@oooooooooooooooooa0@4006oooo
o`03o`000?oooooooooo00?ooooo00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0;oiVI
V@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<
C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl01_moOgl00ol0003oVIVIoiVIV@05oiVI
V@03o`000?nc/k?o/k>c01Co/k>c00?o0000oiVIVOnIVIT00_nIVIT00ol0003oOgmoogmoO`02ogmo
O`05o`000?mVIVKoIVIVofIVI_l000001_m<C4`00ol0003o<c<coc<c<`03oc<c<`03o`000?m<C4co
C4a<00?oC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c
00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomo
Ogoo00000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mV
IVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Co0000ok>c/onc/k?o
00000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01olc<c<02Ol0
003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<
00Go0000ok>c/onc/k?o0000oiVIV@02o`000005ofIVI_l0003oC4a<oda<C?l000000_lc<c<6oooo
o`7o00000Oooool1ooooo`006Oooool01Ol0003ooooooooooooooooo000000Kooooo0ol00003oooo
oaWo/k>c00?o0000oiVIVOnIVIT02_nIVIT2o`0000[oOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0
003oC4a<oda<C00Foda<C0;o00003?mVIVH2o`0000SoOgmo00?o0000oiVIVOnIVIT01OnIVIT00ol0
003o/k>cok>c/`0Cok>c/`;o00001?nIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV
00;oIVIV00?o0000oda<C?m<C4`00om<C4`2o`0000Go<c<c00?o0000oda<C?m<C4`00om<C4`01Ol0
003oIVIVofIVI_mVIVKo000000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000003ok>c/`;o00001oo<
c<`01Ol0003o/k>cok>c/onc/k?o000000?oVIVI00?o0000ogmoOol000000_mVIVH01Ol0003oC4a<
oda<C?m<C4co000000So<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00Co0000
oiVIVOnIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`0000;oVIVI
00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00[o0000oda<C?m<
C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c005o`00
0?nc/k?o/k>co`000?nIVIT00_l000001OmVIVKo0000oda<C?m<C4co000000;o<c<c1?ooool3o`00
00;ooooo000Iooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`03oooo
oaSo/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV
00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo
00OoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`0Cok>c/`03o`000?nIVIWoVIVI
00?oVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP02ofIVIP03o`000?m<C4coC4a<
00?oC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C003oda<C005o`000?mVIVKoIVIV
ofIVI_l000000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<
c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01Ol0003o
C4a<oda<C?m<C4co000000So<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00Co
0000oiVIVOnIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`0000;o
VIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00[o0000oda<
C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c005
o`000?nc/k?o/k>co`000?nIVIT00_l000001OmVIVKo0000oda<C?m<C4co000000;o<c<c1_ooool1
o`00007ooooo0Oooool001Wooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooo
oooo00?ooooo5onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000
ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000
ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@05oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o0000
oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000
oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Go0000
ofIVI_mVIVKoIVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000onc/k<00ol0003oc<c<
olc<c006olc<c003o`000?nc/k?o/k>c00;o/k>c00Ko0000oiVIVOnIVIWo0000ogmoOol00002ofIV
IP05o`000?m<C4coC4a<oda<C?l000002Olc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?mo
Ogoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@05
o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`09o`000?m<C4co0000
ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`03?l0003o/k>c
ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000?o<c<c1_ooool1o`00007ooooo
0Oooool001Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00?ooooo
5_nc/k<00ol0003oVIVIoiVIV@0:oiVIV@;o00002_moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`00
0?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`00
0?nIVIWoVIVI00GoVIVI00?o0000ok>c/onc/k<05?nc/k<00ol0003oVIVIoiVIV@03oiVIV@05o`00
0?moOgooOgmoogmoOol000001?mVIVH00ol0003oC4a<oda<C004oda<C003o`000?lc<c?o<c<c00?o
<c<c00?o0000oda<C?m<C4`01?m<C4`01?l0003oIVIVofIVI_l00003ogmoO`04o`000?nIVIWoVIVI
o`0000Co/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co
0000ogmoOomoOgoo00000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Oo0000oda<C?m<
C4coC4a<o`000?mVIVKo000000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007
olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl00ol0003oIVIVo`000002oda<C003o`00
0?lc<c?o<c<c00Oo<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl000000_nc/k<0
0ol0003oc<c<olc<c006olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`00
0?m<C4co00000olc<c<6ooooo`7o00000Oooool1ooooo`006Oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Kooooo00?o0000ooooooooool00ooooolEok>c/`03o`000?nIVIWoVIVI00[oVIVI00?o0000
ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000
ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00GoVIVI00?o0000
ok>c/onc/k<05?nc/k<00ol0003oVIVIoiVIV@04oiVIV@05o`000?moOgooOgmoogmoOol000001?mV
IVH00ol0003oC4a<oda<C004oda<C003o`000?lc<c?o<c<c00?o<c<c00?o0000oda<C?m<C4`01?m<
C4`01?l0003oIVIVofIVI_l00003ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<
c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH0
1Ol0003oC4a<oda<C?m<C4co000000So<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo000000;o
Ogmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c006o`000?nc/k?o/k>co`00
0?nIVIWo00000_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Wo0000
oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c00<
o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co00000olc<c<6ooooo`7o
00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03oooooaCo/k>c00?o0000oiVIVOnIVIT0
2onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`0
5_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT0
1_nIVIT00ol0003o/k>cok>c/`0Cok>c/`03o`000?nIVIWoVIVI00CoVIVI00Go0000ogmoOomoOgoo
Ogmoo`000004ofIVIP03o`000?m<C4coC4a<00CoC4a<00?o0000oc<c<olc<c<00olc<c<00ol0003o
C4a<oda<C004oda<C004o`000?mVIVKoIVIVo`0000?oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<0
0ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmo
Ool00002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01ol0003oC4a<oda<C?m<C4co0000
ofIVI_l000000_moOgl00ol0003oVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000
ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<0
1olc<c<00ol0003oC4a<o`000002ofIVIP;o000000GoVIVIo`000?nc/k?o/k>co`000008olc<c00<
o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co00001?lc<c<6ooooo`7o
00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03oooooa;o/k>c0_l0000<oiVIV@;o0000
2OmoOgl2o`0000goIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`00
0?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`0Dok>c/`03o`00
0?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl00_moOgl01Ol0003oIVIVofIVI_mVIVKo000000Oo
C4a<00?o0000oc<c<olc<c<00_lc<c<00ol0003oC4a<oda<C004oda<C005o`000?mVIVKoIVIVofIV
I_l000000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`0
0ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo0000
0_m<C4`00ol0003o<c<coc<c<`07oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Ko0000ogmoOomo
Ogoo0000oiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Ko0000ok>c/onc/k?o0000oiVI
VOl00002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02_l0003oC4a<
oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00co
0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00004oc<c<`Kooooo0Ol0
0001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo4Onc/k<00ol0003oVIVIoiVIV@0;
oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00F
oda<C003o`000?mVIVKoIVIV00_oIVIV0_l00009ogmoO`03o`000?nIVIWoVIVI00OoVIVI00?o0000
ok>c/onc/k<05?nc/k<00ol0003oVIVIoiVIV@03oiVIV@05o`000?moOgooOgmoogmoOol000001?mV
IVH00ol0003oC4a<oda<C004oda<C003o`000?lc<c?o<c<c00?o<c<c00?o0000oda<C?m<C4`01?m<
C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000003ok>c/`03
o`000?o<c<coc<c<00Koc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmo
O`04o`000?mVIVKoIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01olc<c<01?l0003oC4a<oda<C?l0
0002ofIVIP06o`000?moOgooOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c007olc<c006
o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o
<c<c00Ko<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0
003oc<c<olc<c006olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<
C4co00001?lc<c<6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03oooooa3o
/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00_o
IVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00So
Ogmo00?o0000oiVIVOnIVIT01onIVIT00ol0003o/k>cok>c/`0Dok>c/`03o`000?nIVIWoVIVI00?o
VIVI00?o0000ogmoOomoOgl00_moOgl01Ol0003oIVIVofIVI_mVIVKo000000OoC4a<00?o0000oc<c
<olc<c<00_lc<c<00ol0003oC4a<oda<C004oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl0
1Ol0003oVIVIoiVIVOnIVIWo000000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c
/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o
<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Ko0000ogmoOomoOgoo0000oiVIVOl0
0003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`03
o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01olc<c<01ol0003oC4a<o`000?mVIVKo0000
ogmoOol000000_nIVIT00ol0003o/k>co`000008olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000
ogmoOol0003oIVIVo`000?m<C4co00001Olc<c<6ooooo`7o00000Oooool1ooooo`009?ooool00ol0
003oooooooooo`03ooooo`oo/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmo
O`;o00003OmVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmo
OomoOgl02?moOgl00ol0003oVIVIoiVIV@07oiVIV@03o`000?nc/k?o/k>c01Co/k>c00?o0000oiVI
VOnIVIT00onIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<
C?m<C4`01?m<C4`00ol0003o<c<coc<c<`03oc<c<`03o`000?m<C4coC4a<00CoC4a<00Co0000ofIV
I_mVIVKo00000omoOgl01Ol0003oVIVIoiVIVOnIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<
c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo
00000om<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Ko0000ogmo
OomoOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Ko0000ok>c/onc/k?o0000
oiVIVOl00002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02_l0003o
C4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<
00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00005oc<c<`Kooooo
0Ol00001ooooo`7ooooo000Tooooo`;o00001?ooool>ok>c/`03o`000?nIVIWoVIVI00coVIVI00?o
0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o
0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00OoVIVI00?o
0000ok>c/onc/k<04onc/k<00ol0003oVIVIoiVIV@03oiVIV@03o`000?moOgooOgmo00?oOgmo00?o
0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C004oda<C003o`000?lc<c?o<c<c00?o<c<c00?o
0000oda<C?m<C4`01?m<C4`01?l0003oIVIVofIVI_l00003ogmoO`04o`000?nIVIWoVIVIo`0000Co
/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`00
00;oOgmo00Co0000ofIVI_mVIVKo00000_m<C4`00ol0003o<c<coc<c<`07oc<c<`04o`000?m<C4co
C4a<o`0000;oIVIV00Ko0000ogmoOomoOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Oo
c<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000
oc<c<olc<c<01_lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c
/`03o`000?o<c<coc<c<00Koc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo
0000oda<C?l00005oc<c<`Gooooo0_l00002ooooo`009?ooool00ol0003oooooooooo`03ooooo`go
/k>c00?o0000oiVIVOnIVIT02onIVIT2o`0000[oOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003o
C4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003o
VIVIoiVIV@07oiVIV@03o`000?nc/k?o/k>c01Co/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003o
OgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01?m<C4`00ol0003o
<c<coc<c<`03oc<c<`03o`000?m<C4coC4a<00CoC4a<00Co0000ofIVI_mVIVKo00000omoOgl01Ol0
003oVIVIoiVIVOnIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003o/k>cok>c/`02
ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<c
oc<c<`06oc<c<`07o`000?m<C4coC4a<oda<C?l0003oIVIVo`000002ogmoO`03o`000?nIVIWo0000
00;o/k>c00?o0000olc<c?o<c<`01oo<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00?o
0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`05o`000?m<C4co0000ofIVI_l00000
0_moOgl2o`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`00
0?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00?o<c<c1_ooool1o`00007ooooo0Ooo
ool002Cooooo00?o0000ooooooooool00oooool<ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000
ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000
ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00OoVIVI00?o0000
ok>c/onc/k<05?nc/k<00ol0003oVIVIoiVIV@03oiVIV@03o`000?moOgooOgmo00;oOgmo00?o0000
ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C005oda<C003o`000?lc<c?o<c<c00;o<c<c00?o0000
oda<C?m<C4`01?m<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Co0000oiVIVOnIVIWo0000
1?nc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003o
OgmoogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01Ol0003oC4a<oda<C?m<
C4co000000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00009olc<c008o`00
0?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP03o`000?m<C4co000000[o<c<c00Wo0000
oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c00<
o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co00001_lc<c<6ooooo`7o
00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`_o/k>c00?o0000oiVIVOnIVIT0
3?nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`0
5_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT0
1onIVIT00ol0003o/k>cok>c/`0Eok>c/`03o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl0
0_moOgl00ol0003oIVIVofIVIP02ofIVIP03o`000?m<C4coC4a<00GoC4a<00?o0000oc<c<olc<c<0
0_lc<c<00ol0003oC4a<oda<C004oda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01?l0003o
VIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002
oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`05o`00
0?m<C4coC4a<oda<C?l000000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`00
00Woc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV00?o0000oda<C?l00000
2_lc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<co
c<c<00Koc<c<00?o0000ok>c/ol000000_nIVIT01ol0003oOgmoo`000?mVIVKo0000oda<C?l00000
1_lc<c<6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`[o/k>c00?o
0000oiVIVOnIVIT02onIVIT2o`0000[oOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<
C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVI
V@08oiVIV@03o`000?nc/k?o/k>c01Co/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmo
O`02ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01Om<C4`00ol0003o<c<coc<c
<`02oc<c<`03o`000?m<C4coC4a<00CoC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`04o`00
0?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o0000
00;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Go
0000oda<C?m<C4coC4a<o`000002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o
00002Oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@;o00000_mVIVH01?l0003oC4a<oda<C?l00009
oc<c<`03o`000?m<C4co000000;oIVIV0_l000001OnIVIWo0000ok>c/onc/k?o000000Soc<c<00co
0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00007oc<c<`Kooooo0Ol0
0001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo2Onc/k<00ol0003oVIVIoiVIV@0;
oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00F
oda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl2o`0000[oVIVI00?o0000
ok>c/onc/k<05?nc/k<00ol0003oVIVIoiVIV@03oiVIV@03o`000?moOgooOgmo00;oOgmo00?o0000
ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C006oda<C005o`000?lc<c?o<c<coc<c<ol000001_m<
C4`00ol0003oIVIVofIVIP02ofIVIP04o`000?moOgooOgmoo`0000?oVIVI00?o0000ok>c/onc/k<0
0_nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo
00000_moOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<
C?m<C4coC4a<o`000002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<
c<`2o`0000;o/k>c00Go0000oiVIVOl0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So
<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<
olc<c006olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co0000
1olc<c<6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`So/k>c00?o
0000oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`07ogmoO`;o00003OmVIVH00ol0003oC4a<oda<
C00Goda<C003o`000?mVIVKoIVIV00[oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVI
V@08oiVIV@03o`000?nc/k?o/k>c01Go/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmo
O`02ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01_m<C4`01Ol0003o<c<coc<c
<olc<c?o000000KoC4a<00?o0000ofIVI_mVIVH00_mVIVH01?l0003oOgmoogmoOol00003oiVIV@03
o`000?nc/k?o/k>c00;o/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04
o`000?nIVIWoVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06
oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc
/k?o/k>co`0000Soc<c<00Wo0000ok>c/onc/k?o/k>co`000?nIVIWo0000ogmoOol000000_mVIVH0
1?l0003oC4a<oda<C?l00008oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVI
o`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo
0000ofIVI_l0003oC4a<o`0000Oo<c<c1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000oooo
ooooool00oooool7ok>c/`03o`000?nIVIWoVIVI00_oVIVI0_l00009ogmoO`03o`000?mVIVKoIVIV
00coIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0:ofIVIP03o`000?moOgooOgmo
00WoOgmo00?o0000oiVIVOnIVIT02?nIVIT00ol0003o/k>cok>c/`0Eok>c/`03o`000?nIVIWoVIVI
00?oVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<
00GoC4a<00Go0000oc<c<olc<c?o<c<co`000006oda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000
ogmoOomoOgooOgmoo`000002oiVIV@03o`000?nc/k?o/k>c00;o/k>c00?o0000olc<c?o<c<`01Oo<
c<`00ol0003o/k>cok>c/`03ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo
00000_m<C4`00ol0003o<c<coc<c<`07oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Ko0000ogmo
OomoOgoo0000oiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Goc<c<00Wo0000ok>c/onc/k?o/k>c
o`000?nIVIWo0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`04o`000?m<C4co
C4a<oda<C0;o000000GoOgmoo`000?nIVIWoVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Goc<c<
00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`;o000000?oC4a<o`000?lc<c<01olc<c<6oooo
o`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`Ko/k>c00?o0000oiVIVOnI
VIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV0_l0000Hoda<C0;o
00003?mVIVH00ol0003oOgmoogmoO`08ogmoO`;o00002_nIVIT00ol0003o/k>cok>c/`0Eok>c/`03
o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIVIP02ofIVIP03
o`000?m<C4coC4a<00GoC4a<00Go0000oc<c<olc<c?o<c<co`000007oda<C005o`000?mVIVKoIVIV
ofIVI_l000000omoOgl01Ol0003oVIVIoiVIVOnIVIWo000000Co/k>c00?o0000olc<c?o<c<`01Oo<
c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo
00000om<C4`00ol0003o<c<coc<c<`06oc<c<`06o`000?m<C4coC4a<oda<C?l0003oIVIV0_l00000
1OmoOgoo0000oiVIVOnIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02Ol0003o/k>cok>c
/onc/k?o0000oiVIVOl0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00[o0000
oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<
c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co00002?lc<c<6oooo
o`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`Go/k>c00?o0000oiVIVOnI
VIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`;o00003?mVIVH00ol0003oC4a<oda<C00Goda<C003
o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0:oiVIV@03
o`000?nc/k?o/k>c01Go/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`02ogmoO`03
o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<C4`01Om<C4`01Ol0003o<c<coc<c<olc<c?o0000
00KoC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000?oVIVI00?o0000
ok>c/onc/k<00_nc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Co0000
oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c
00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo00000_nc/k<0
0ol0003oc<c<olc<c006olc<c009o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000?moOgoo000000;o
IVIV00Co0000oda<C?m<C4co00002?lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000
oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003o
Ogmoo`000?mVIVKo0000oda<C?l00008oc<c<`03o`000?oooooooooo00?ooooo0Ol00001ooooo`7o
oooo000Tooooo`;o00001?ooool4ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl0
2?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH0
2omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00[oVIVI00?o0000ok>c/onc/k<0
5Onc/k<00ol0003oVIVIoiVIV@03oiVIV@03o`000?moOgooOgmo00?oOgmo00?o0000ofIVI_mVIVH0
0_mVIVH00ol0003oC4a<oda<C005oda<C005o`000?lc<c?o<c<coc<c<ol000001om<C4`01Ol0003o
IVIVofIVI_mVIVKo000000?oOgmo00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<co
c<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mV
IVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01ol0003oC4a<oda<C?m<C4co0000ofIV
I_l000000_moOgl01?l0003oVIVIoiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Oo0000
ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<c
oc<c<`06oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl2o`0000;o/k>c00?o0000olc<
c?o<c<`01_o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003
o`000?lc<c?o<c<c00Ko<c<c00?o0000ooooooooool00_ooool2o`0000;ooooo000Tooooo`03o`00
0?oooooooooo00?ooooo0onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo
00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00_oIVIV
00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0:oiVIV@03o`000?nc/k?o/k>c01Go/k>c
00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00;oIVIV
00?o0000oda<C?m<C4`01_m<C4`01?l0003o<c<coc<c<ol00007oda<C003o`000?mVIVKoIVIV00;o
IVIV00Co0000ogmoOomoOgoo00000onIVIT00ol0003o/k>cok>c/`02ok>c/`03o`000?o<c<coc<c<
00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Co0000
ofIVI_mVIVKo00000_m<C4`00ol0003o<c<coc<c<`07oc<c<`07o`000?m<C4coC4a<oda<C?l0003o
IVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0
003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV00?o0000oda<C?l000002Olc<c<0
2_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<
00Koc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00008oc<c
<`03o`000?oooooooooo00Cooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?o
oooo0onc/k<00ol0003oVIVIoiVIV@0:oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mV
IVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomo
Ogl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Go/k>c00?o0000oiVIVOnI
VIT00onIVIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<
C4`01_m<C4`01?l0003o<c<coc<c<ol00007oda<C003o`000?mVIVKoIVIV00;oIVIV00Co0000ogmo
OomoOgoo00000onIVIT00ol0003o/k>cok>c/`02ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000
ok>c/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo0000
0_m<C4`00ol0003o<c<coc<c<`07oc<c<`07o`000?m<C4coC4a<oda<C?l0003oIVIVo`000002ogmo
O`04o`000?nIVIWoVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol0
0002oiVIV@03o`000?moOgoo000000;oIVIV00?o0000oda<C?l000002Olc<c<02_l0003oC4a<oda<
C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00co0000
ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00008oc<c<`03o`000?oooooo
oooo00Cooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo0_nc/k<00ol0
003oVIVIoiVIV@0:oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0
003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl01omoOgl00ol0
003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Co/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0
003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<C4`01_m<C4`01?l0
003o<c<coc<c<ol00007oda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01?l0003oVIVIoiVI
VOl00005ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVI
oiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0
003oC4a<oda<C?m<C4co000000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol0
0008olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT00ol0003oOgmoo`000002ofIVIP03o`00
0?m<C4co000000Wo<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc
/k<00ol0003oc<c<olc<c005olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Oo0000ogmoOol0003o
IVIVo`000?m<C4co000000So<c<c00?o0000ooooooooool01?ooool1o`00007ooooo0Oooool002Co
oooo00?o0000ooooooooool00oooool00onc/k?o0000oiVIV@0<oiVIV@03o`000?moOgooOgmo00So
Ogmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00co
IVIV00?o0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Co
/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00?o
IVIV00?o0000oda<C?m<C4`01_m<C4`01?l0003o<c<coc<c<ol00007oda<C003o`000?mVIVKoIVIV
00;oIVIV00Go0000ogmoOomoOgooOgmoo`000002oiVIV@03o`000?nc/k?o/k>c00;o/k>c00?o0000
olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`03ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co
0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`07o`000?m<C4coC4a<oda<C?l0
003oIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`0
2Ol0003o/k>cok>c/onc/k?o0000oiVIVOl0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`00
00So<c<c00Co0000oda<C?m<C4co00000_mVIVH2o`000005oiVIVOl0003o/k>cok>c/ol000002?o<
c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000So<c<c00?o
0000oda<C?ooool01Oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool0
0ol0003oVIVIoiVIV@0:oiVIV@;o00002_moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4co
C4a<01KoC4a<0_l0000<ofIVIP;o00002OmoOgl2o`0000goVIVI00?o0000ok>c/onc/k<05Onc/k<0
0ol0003oVIVIoiVIV@03oiVIV@03o`000?moOgooOgmo00?oOgmo00?o0000ofIVI_mVIVH00_mVIVH0
0ol0003oC4a<oda<C007oda<C003o`000?lc<c?o000000OoC4a<0_l00003ofIVIP05o`000?moOgoo
OgmoogmoOol000000onIVIT00ol0003o/k>cok>c/`02ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o
0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000Co
C4a<00?o0000oc<c<olc<c<01Olc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Ko0000ogmo
OomoOgoo0000oiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o0000
0_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00[o0000oda<C?l0
003o0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c00<o`00
0?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co00002?lc<c<00ol0003oC4a<
ooooo`05ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`coVIVI00?o
0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o
0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00coVIVI00?o
0000ok>c/onc/k<05Onc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00?oOgmo00?o
0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C007oda<C003o`000?lc<c?o000000OoC4a<00?o
0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000?oVIVI00?o0000ok>c/onc/k<0
0_nc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Co0000oiVIVOnIVIWo
00000_moOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<
C?m<C4coC4a<o`000002ofIVIP06o`000?moOgooOgmoo`000?nIVIWo00000onc/k<00ol0003oc<c<
olc<c006olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003o
C4a<oda<C?l00007oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Go0000ogmoOol0003oVIVIo`00
0002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o0000oiVIV@02o`0000;oIVIV
00?o0000oda<C?l000002?lc<c<00ol0003oC4a<ooooo`05ooooo`7o00000Oooool1ooooo`009?oo
ool00ol0003oooooooooo`03ooooo`coVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIV
IP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmo
O`08ogmoO`03o`000?nIVIWoVIVI00coVIVI00?o0000ok>c/onc/k<05Onc/k<00ol0003oVIVIoiVI
V@04oiVIV@03o`000?moOgooOgmo00?oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<
C009oda<C003o`000?m<C4coC4a<00GoC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmo
OomoOgoo000000?oVIVI00?o0000ok>c/onc/k<00_nc/k<00ol0003oc<c<olc<c005olc<c003o`00
0?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00004oda<
C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`02?l0003oIVIVofIVI_l0003o
Ogmoo`000?nIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`0000;o
VIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`08o`000?m<C4coC4a<
o`000?mVIVKo0000ogmoOol00002oiVIV@03o`000?nc/k?o000000Soc<c<00co0000ok>c/onc/k?o
0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00008oc<c<`04o`000?m<C4coC4a<o`0000Go
oooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo2_nIVIT2o`0000[oOgmo
00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV
00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Go/k>c
00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00;oIVIV
0_l0000Coda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01Ol0003oVIVIoiVIVOnIVIWo0000
00Go/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVI
o`0000;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<
C4coC4a<oda<C?l000000_mVIVH01_l0003oOgmoogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<
c?o<c<`01oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV00?o0000
oda<C?l000002Olc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c
/`03o`000?o<c<coc<c<00Koc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo
0000oda<C?l00008oc<c<`04o`000?m<C4coC4a<o`0000Gooooo0Ol00001ooooo`7ooooo000Toooo
o`03o`000?oooooooooo00?ooooo2OnIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV
00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo
00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI
00CoVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<
01;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc
/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000onIVIT01?l0003oOgmo
ogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01Ol0003oC4a<oda<C?m<C4co
000000;oIVIV00Ko0000ogmoOomoOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<
00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIVIP03o`000?m<C4co000000Wo
<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<
olc<c006olc<c003o`000?nc/k?o/k>c00;o00000_moOgl01Ol0003oIVIVo`000?m<C4co000000So
<c<c00Co0000oda<C?m<C4co00001Oooool1o`00007ooooo0Oooool002Cooooo00?o0000oooooooo
ool00oooool9oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003o
C4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003o
VIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0003o
OgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`04_m<C4`01Ol0003o
IVIVofIVI_mVIVKo000000CoOgmo00Co0000oiVIVOnIVIWo00001Onc/k<00ol0003oc<c<olc<c005
olc<c005o`000?nc/k?o/k>cok>c/ol000000onIVIT01?l0003oOgmoogmoOol00002ofIVIP05o`00
0?m<C4coC4a<oda<C?l000002?lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Ko0000ogmo
OomoOgoo0000oiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o0000
0_nIVIT02?l0003oOgmoogmoOol0003oIVIVo`000?m<C4co00002Olc<c<01_l0003oC4a<oda<C?l0
003oIVIVo`0000;oOgmo0_l00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00[o0000ok>c/onc/k?o
0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`03o`000?m<
C4co000000Kooooo0Ol00001ooooo`7ooooo000Tooooo`;o00001?ooool7oiVIV@;o00002OmoOgl2
o`0000goIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgoo
Ogmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWo
VIVI00CoVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4co
C4a<01;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`05o`000?nIVIWoVIVIoiVIVOl00000
1?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Go0000oiVIVOnIVIWo
VIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0
003oC4a<oda<C?m<C4co000000;oIVIV00?o0000ogmoOol000000_nIVIT01Ol0003o/k>cok>c/onc
/k?o000000Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;o
C4a<00?o0000oc<c<olc<c<01olc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVI
VOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmo
o`000?mVIVKo0000oda<C?l00008oc<c<`04o`000?m<C4coC4a<o`0000Gooooo0_l00002ooooo`00
9?ooool00ol0003oooooooooo`03ooooo`KoVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIV
ofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH2o`0000[oOgmo
00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00GoVIVI
00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<017oC4a<
00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000?oVIVI00?o0000ok>c/onc
/k<00_nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Go0000oiVIVOnI
VIWoVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01Olc<c<0
0ol0003oC4a<oda<C002oda<C006o`000?mVIVKoIVIVo`000?moOgoo00000_nIVIT01Ol0003o/k>c
ok>c/onc/k?o000000Ooc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@05o`000?moOgoo0000
ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`03o`000?m<C4coC4a<00;o00000_moOgl0
0ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Oo0000ok>c/onc/k?o0000oiVI
VOl0003oOgmo00;o00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000Ko
oooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo1OnIVIT00ol0003oOgmo
ogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIV
ofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>c
ok>c/`0Fok>c/`03o`000?nIVIWoVIVI00GoVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIV
ofIVIP03ofIVIP03o`000?m<C4coC4a<01;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`05
o`000?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c
00;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o
0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo
00000_nIVIT01?l0003o/k>cok>c/ol00008olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Go0000
ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00[o0000oda<C?m<C4co0000
ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c00<o`000?nc/k?o
/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co00002?lc<c<01_l0003oC4a<oda<C?l0
003oIVIVo`0000Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo1?nI
VIT00ol0003oOgmoogmoO`08ogmoO`;o00003OmVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mV
IVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0:oiVIV@;o00006?nc
/k<00ol0003oVIVIoiVIV@05oiVIV@03o`000?moOgooOgmo00?oOgmo00?o0000ofIVI_mVIVH00omV
IVH00ol0003oC4a<oda<C00Boda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01Ol0003oVIVI
oiVIVOnIVIWo000000Go/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04
o`000?nIVIWoVIVIo`0000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000003oda<C003o`000?lc<c?o
<c<c00Ko<c<c00?o0000oda<C?m<C4`00_l00002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000
ok>c/onc/k?o00002Oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l0
00000_m<C4`00ol0003o<c<coc<c<`07oc<c<`03o`000?m<C4co000000;oIVIV00Go0000ogmoOol0
003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00co0000ok>c/onc/k?o0000oiVIVOl0
003oOgmoo`000?mVIVKo0000oda<C?l00008oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00001Ooo
ool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool4oiVIV@03o`000?moOgoo
Ogmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKo
IVIV00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0:oiVIV@03o`000?nc/k?o
/k>c01Oo/k>c00?o0000oiVIVOnIVIT01_nIVIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKo
IVIV00?oIVIV00?o0000oda<C?m<C4`04_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Go
0000oiVIVOnIVIWoVIVIo`000005ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<0
0_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`05o`000?mVIVKoIVIVofIVI_l000000om<C4`00ol0
003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000?oIVIV00?o0000ogmoOol000000_nIVIT0
1?l0003o/k>cok>c/ol00009olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Go0000ogmoOol0003o
IVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH01Ol0
003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`03?l0003o/k>cok>c/ol0
003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000So<c<c00Ko0000oda<C?m<C4co0000ofIV
I_l00005ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`;oVIVI0_l0
000:ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIV
IP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c
/`0Fok>c/`03o`000?nIVIWoVIVI00KoVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIV
IP03ofIVIP03o`000?m<C4coC4a<01;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`05o`00
0?nIVIWoVIVIoiVIVOl000001Onc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o
/k>c00Co0000oiVIVOnIVIWo00000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000?oC4a<00?o0000
oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00003ofIVIP03o`000?moOgoo000000;oVIVI00Co
0000ok>c/onc/k?o00002Oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo000000;o
IVIV00Co0000oda<C?m<C4co00002?lc<c<02?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000
0_nIVIT01?l0003o/k>cok>c/ol00007olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0
003oIVIVo`000?m<C4co00002Olc<c<01Ol0003oC4a<o`000?mVIVKo000000Kooooo0Ol00001oooo
o`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo00?oVIVIo`000?moOgl02_moOgl00ol0003o
IVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003o
OgmoogmoO`08ogmoO`;o00003?nIVIT2o`0001Wo/k>c00?o0000oiVIVOnIVIT01OnIVIT00ol0003o
OgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<C4`04_m<C4`00ol0003o
IVIVofIVIP02ofIVIP05o`000?moOgooOgmoogmoOol000000onIVIT00ol0003o/k>cok>c/`03ok>c
/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo
000000;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`07oc<c<`04o`000?m<
C4coC4a<o`0000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01?l0003o/k>cok>c/ol00009olc<
c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc
<c?o<c<c00Ko<c<c00_o0000oda<C?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002
ok>c/`03o`000?o<c<coc<c<00Koc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mV
IVKo0000oda<C?l00009oc<c<`05o`000?m<C4co0000o`000?moOgl01_ooool1o`00007ooooo0Ooo
ool001Wooooo1Ol00006ooooo`03o`000?oooooooooo00?ooooo00?oVIVIo`000?moOgl02OmoOgl0
0ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH0
0ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00[oVIVI00?o0000ok>c/onc/k<06?nc/k<0
0ol0003oVIVIoiVIV@06oiVIV@03o`000?moOgooOgmo00?oOgmo00?o0000ofIVI_mVIVH00omVIVH0
0ol0003oC4a<oda<C00Boda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgooOgmoo`00
0003oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c
/`02ok>c/`04o`000?nIVIWoVIVIo`0000?oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o
<c<coc<c<`07oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT0
1?l0003o/k>cok>c/ol00009olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl00ol0003o
IVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00_o0000oda<C?m<C4coC4a<o`000?mVIVKo
0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00co0000ok>c/onc/k?o
0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00009oc<c<`05o`000?m<C4co0000o`000?mo
Ogl01_ooool1o`00007ooooo0Oooool001Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03
o`000?oooooooooo00?ooooo00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03
o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`09ogmoO`03
o`000?nIVIWoVIVI00[oVIVI00?o0000ok>c/onc/k<06?nc/k<00ol0003oVIVIoiVIV@06oiVIV@03
o`000?moOgooOgmo00?oOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00Boda<C003
o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgooOgmoo`000003oiVIV@03o`000?nc/k?o/k>c
00?o/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`02ok>c/`05o`000?nIVIWoVIVI
oiVIVOl000000omoOgl01?l0003oIVIVofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Co
0000oda<C?m<C4co00000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@04o`000?nc/k?o/k>co`00
00Woc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00003ogmoO`;o00000_m<C4`00ol0003o<c<coc<c
<`07oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000
olc<c?o<c<`01_o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<
o`0000Wo<c<c00Ko0000oda<C?l0003oIVIVo`000?moOgl6ooooo`7o00000Oooool1ooooo`006_oo
ool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo00?ooooo2_moOgl00ol0003oIVIVofIV
IP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmo
O`08ogmoO`;o00003?nIVIT00ol0003o/k>cok>c/`0Hok>c/`03o`000?nIVIWoVIVI00KoVIVI00?o
0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIVIP04ofIVIP03o`000?m<C4coC4a<01;oC4a<00Go
0000ofIVI_mVIVKoIVIVo`000003ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001Onc/k<00ol0003o
c<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmo
O`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<
C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01?l0003o/k>cok>c/ol00008olc<c007
o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000
oc<c<olc<c<01olc<c<00ol0003oC4a<o`000002ofIVIP07o`000?moOgoo0000oiVIVOl0003o/k>c
o`000009olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co0000
2Olc<c<01ol0003oC4a<o`000?mVIVKo0000ogmoOol000001Oooool1o`00007ooooo0Oooool001_o
oooo00?oV9RHob4Q8Oo^k^h01_ooool3o`0000?ooooo2?moOgl2o`0000goIVIV00?o0000oda<C?m<
C4`05om<C4`00ol0003oIVIVofIVIP0:ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnI
VIT02_nIVIT00ol0003o/k>cok>c/`0Hok>c/`03o`000?nIVIWoVIVI00OoVIVI00?o0000ogmoOomo
Ogl00omoOgl00ol0003oIVIVofIVIP04ofIVIP03o`000?m<C4coC4a<01;oC4a<00Go0000ofIVI_mV
IVKoIVIVo`000003ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001Onc/k<00ol0003oc<c<olc<c005
olc<c003o`000?nc/k?o/k>c00;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`04o`000?mV
IVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;o
IVIV00Co0000ogmoOomoOgoo00000_nIVIT01?l0003o/k>cok>c/ol00008olc<c004o`000?nc/k?o
/k>co`0000;oVIVI00Ko0000ogmoOomoOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo
<c<c00?o0000oda<C?l000000_mVIVH01ol0003oOgmoo`000?nIVIWo0000ok>c/ol000002Oo<c<`0
3?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000Wo<c<c00Oo0000
oda<C?l0003oIVIVo`000?moOgoo000000?ooooo0ol00002ooooo`007?ooool00omgMgOoIVIVoooo
o`05ooooo`03o`000?oooooooooo00?ooooo1omoOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<
C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nI
VIWoVIVI00[oVIVI00?o0000ok>c/onc/k<06?nc/k<00ol0003oVIVIoiVIV@07oiVIV@03o`000?mo
OgooOgmo00?oOgmo00?o0000ofIVI_mVIVH01?mVIVH00ol0003oC4a<oda<C00Boda<C005o`000?mV
IVKoIVIVofIVI_l000000omoOgl01Ol0003oVIVIoiVIVOnIVIWo000000Go/k>c00?o0000olc<c?o<
c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01?l0
003oIVIVofIVI_l00004oda<C003o`000?lc<c?o<c<c00Go<c<c00Go0000oda<C?m<C4coC4a<o`00
0002ofIVIP07o`000?moOgooOgmoogmoOol0003oVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Ko
c<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000
oc<c<olc<c<01olc<c<00ol0003oC4a<o`000002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc
/k<00ol0003oc<c<olc<c006olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIV
o`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01ol0003oC4a<o`000?mVIVKo0000ogmoOol00000
1_ooool1o`00007ooooo0Oooool001gooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`03ooooo`KoOgmo00?o0000ofIVI_mVIVH02omVIVH2o`0001SoC4a<0_l0000<ofIVIP03o`000?mo
OgooOgmo00SoOgmo0_l0000<oiVIV@03o`000?nc/k?o/k>c01So/k>c00?o0000oiVIVOnIVIT01onI
VIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00CoIVIV00?o0000oda<C?m<C4`04_m<
C4`00ol0003oIVIVofIVIP02ofIVIP05o`000?moOgooOgmoogmoOol000000onIVIT00ol0003o/k>c
ok>c/`03ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00onc/k<01?l0003oVIVI
oiVIVOl00002ogmoO`05o`000?mVIVKoIVIVofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c
<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01_l0003oOgmoogmoOol0003oVIVIo`0000?o/k>c
00?o0000olc<c?o<c<`01_o<c<`01ol0003o/k>cok>c/onc/k?o0000oiVIVOl000000_moOgl00ol0
003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH0
1Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`03?l0003o/k>cok>c
/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000Wo<c<c00Oo0000oda<C?l0003oIVIV
o`000?moOgoo000000Kooooo0Ol00001ooooo`7ooooo000Iooooo`05o`000?nj^[[ooooooiRHV?l@
41001_ooool00ol0003oooooooooo`03ooooo`GoOgmo0_l0000<ofIVIP03o`000?m<C4coC4a<01Oo
C4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00co
VIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@07oiVIV@;o00001OmoOgl00ol0003o
IVIVofIVIP03ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003o
OgmoogmoOomoOgoo000000;oVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c004olc<
c003o`000?nc/k?o/k>c00;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`05o`000?mVIVKo
IVIVofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l00000
0_mVIVH01_l0003oOgmoogmoOol0003oVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01ol0
003o/k>cok>c/onc/k?o0000oiVIVOl000000_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc
<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o
/k>c00?o0000olc<c?o<c<`01_o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIV
I_l0003oC4a<o`0000Wo<c<c00Oo0000oda<C?l0003oIVIVo`000?moOgoo000000Kooooo0Ol00001
ooooo`7ooooo000;ooooo`?o000000?o410@ooooooooool02?ooool01OnHV9So410@o`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool00oooool4ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000
oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000
oiVIVOnIVIT02onIVIT2o`0001Wo/k>c00?o0000oiVIVOnIVIT01onIVIT00ol0003oOgmoogmoO`04
ogmoO`03o`000?mVIVKoIVIV00CoIVIV00?o0000oda<C?m<C4`04_m<C4`00ol0003oIVIVofIVIP02
ofIVIP05o`000?moOgooOgmoogmoOol000000onIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<
c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00onc/k<01?l0003oVIVIoiVIVOl00002ogmoO`05o`00
0?mVIVKoIVIVofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<
C?l000000_mVIVH01_l0003oOgmoogmoOol0003oVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<
c<`01ol0003o/k>cok>c/onc/k?o0000oiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00002oda<
C003o`000?lc<c?o<c<c00Ko<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo
00000onc/k<00ol0003oc<c<olc<c006olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mV
IVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<00ol0003oC4a<o`000002ofIVIP;o000000?o
VIVIooooooooool01?ooool1o`00007ooooo0Oooool000gooooo00?o410@okZj^_ooool05?ooool0
0ol0003oooooooooo`03ooooo`?oOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00G
oda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;
oiVIV@03o`000?nc/k?o/k>c01So/k>c00?o0000oiVIVOnIVIT01onIVIT00ol0003oOgmoogmoO`04
ogmoO`03o`000?mVIVKoIVIV00CoIVIV00?o0000oda<C?m<C4`04_m<C4`00ol0003oIVIVofIVIP02
ofIVIP05o`000?moOgooOgmoogmoOol000000onIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<
c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo
00?o0000ofIVI_mVIVH00_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4co
C4a<o`000002ofIVIP03o`000?moOgoo000000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<
c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l0
0008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03
o`000?o<c<coc<c<00Koc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000
0_m<C4`00ol0003o<c<coc<c<`06oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo
000000Gooooo0Ol00001ooooo`7ooooo000=ooooo`03oiRHV?lb<S;ooooo01Cooooo00?o0000oooo
ooooool00oooool3ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0
003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0
003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00SoVIVI00?o0000ogmoOomoOgl01?moOgl00ol0
003oIVIVofIVIP04ofIVIP03o`000?m<C4coC4a<01;oC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0
003oOgmoogmoOomoOgoo000000?oVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c004
olc<c003o`000?nc/k?o/k>c00;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`04o`000?mV
IVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;o
IVIV00?o0000ogmoOol000000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Co0000ok>c
/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Co
0000oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<
c<`01_o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`00
0?lc<c?o<c<c00Ko<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl000001Oooool1
o`00007ooooo0Oooool000gooooo00?ogMgMo`000?nj^[X05?ooool00ol0003oooooooooo`03oooo
o`;oOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV
00coIVIV00?o0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c
01Oo/k>c00?o0000oiVIVOnIVIT02?nIVIT00ol0003oOgmoogmoO`04ogmoO`03o`000?mVIVKoIVIV
00CoIVIV00?o0000oda<C?m<C4`04_m<C4`00ol0003oIVIVofIVIP02ofIVIP05o`000?moOgooOgmo
ogmoOol000001?nIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000
ok>c/onc/k<00onc/k<01?l0003oVIVIoiVIVOl00003ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<
00?o0000oc<c<olc<c<01Olc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o0000ogmoOol0
00000onIVIT01Ol0003o/k>cok>c/onc/k?o000000Ooc<c<00Oo0000ok>c/onc/k?o/k>co`000?nI
VIWo000000;oOgmo00Ko0000ofIVI_mVIVKo0000oda<C?l00009oc<c<`04o`000?m<C4coC4a<o`00
00;oIVIV0_l00002oiVIV@03o`000?nc/k?o000000Woc<c<00?o0000ok>c/onc/k<00_l00002ogmo
O`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02Ol0003oC4a<o`000?mVIVKo
0000ogmoOol0003oVIVIo`000005ooooo`7o00000Oooool1ooooo`003Oooool00omEEEGoMgMgodA4
A00Dooooo`03o`000?oooooooooo00?ooooo00?oOgmoo`000?mVIVH03?mVIVH00ol0003oC4a<oda<
C00Foda<C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVI
V@0<oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02OnIVIT00ol0003oOgmoogmo
O`04ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<C4`04om<C4`00ol0003oIVIVofIV
IP02ofIVIP05o`000?moOgooOgmoogmoOol000000onIVIT00ol0003o/k>cok>c/`04ok>c/`03o`00
0?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;o
Ogmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<
oda<C?l000000_mVIVH00ol0003oOgmoo`000003oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Co
0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000Wo
<c<c00?o0000oda<C?l000000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<
c?o<c<`01_o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003
o`000?lc<c?o<c<c00Ko<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl000001_oo
ool1o`00007ooooo0Oooool000cooooo00GogMgMoa0@4?oooooo8B4QomgMg@0Cooooo`03o`000?oo
oooooooo00?ooooo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C0;o00003?mV
IVH2o`0000WoOgmo0_l0000=oiVIV@03o`000?nc/k?o/k>c01Ko/k>c0_l0000;oiVIV@03o`000?mo
OgooOgmo00CoOgmo00?o0000ofIVI_mVIVH01?mVIVH00ol0003oC4a<oda<C00Boda<C003o`000?mV
IVKoIVIV00;oIVIV00?o0000ogmoOomoOgl00_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Go/k>c
00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`04o`000?nIVIWoVIVIo`0000?o
Ogmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`05oc<c<`05o`000?m<C4coC4a<
oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@05o`000?nc/k?o/k>cok>c/ol00000
2?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV00?o0000oda<C?l0
00002_lc<c<00ol0003oC4a<o`000002ofIVIP07o`000?moOgoo0000oiVIVOl0003o/k>co`000009
olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c
<olc<c<01_lc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000006ooooo`7o0000
0Oooool1ooooo`003?ooool01OmVIVKoQhN7oooooonHV9SoEEEE01?ooooo0_l00004ooooo`goIVIV
00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo
00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00[oVIVI
00?o0000ogmoOomoOgl01OmoOgl00ol0003oIVIVofIVIP04ofIVIP03o`000?m<C4coC4a<01;oC4a<
00?o0000ofIVI_mVIVH00_mVIVH00ol0003oOgmoogmoO`02ogmoO`04o`000?nIVIWoVIVIo`0000Ko
/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`02ok>c/`05o`000?nIVIWoVIVIoiVI
VOl000000omoOgl01?l0003oIVIVofIVI_l00004oda<C003o`000?lc<c?o<c<c00Go<c<c00Go0000
oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o
/k>co`000008olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH00ol0
003oC4a<o`00000:oc<c<`05o`000?m<C4co0000ofIVI_l000000_moOgl01Ol0003oVIVIo`000?nc
/k?o000000Woc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l0
0009oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000Gooooo0_l00002oooo
o`002oooool00oo^k^ko0000onk^kP02ooooo`03o`000?oMgMgooooo017ooooo00?o0000oooooooo
ool00oooool<ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003o
OgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00coVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003o
VIVIoiVIV@0:oiVIV@03o`000?moOgooOgmo00GoOgmo00?o0000ofIVI_mVIVH01?mVIVH00ol0003o
C4a<oda<C00Boda<C003o`000?mVIVKoIVIV00;oIVIV00?o0000ogmoOomoOgl00_moOgl01Ol0003o
VIVIoiVIVOnIVIWo000000Ko/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`03ok>c
/`04o`000?nIVIWoVIVIo`0000?oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c
<`05oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@05
o`000?nc/k?o/k>cok>c/ol000002?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo
000000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<00ol0003oC4a<o`000002ofIVIP05o`000?mo
Ogoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c00:o`000?nc/k?o/k>co`000?nI
VIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02_l0003oC4a<o`00
0?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k<6ooooo`7o00000Oooool1ooooo`002oooool01?l@
413o0000o`000?ooool2o`000003oa0@4?oooooooooo013ooooo00?o0000ooooooooool00oooool;
ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08
ogmoO`;o00003OnIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00[oVIVI00?o0000
ogmoOomoOgl01OmoOgl00ol0003oIVIVofIVIP04ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000
ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000?oVIVI00?o0000ok>c/onc/k<01?nc
/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00;o/k>c00Go0000oiVIVOnIVIWoVIVI
o`000002ogmoO`05o`000?mVIVKoIVIVofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`05
o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@04o`000?nc/k?o
/k>co`0000Woc<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`00
0?m<C4coC4a<o`0000So<c<c00Co0000oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nIVIWo
000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo
0000ofIVI_l0003oC4a<o`0000Wo<c<c00[o0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0
003o/k>c1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool:ofIVIP03
o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03
o`000?nIVIWoVIVI00coVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0:oiVIV@03
o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH01?mVIVH00ol0003oC4a<oda<C00Boda<C003
o`000?mVIVKoIVIV00?oIVIV00Go0000ogmoOomoOgooOgmoo`000003oiVIV@03o`000?nc/k?o/k>c
00Co/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`02ok>c/`05o`000?nIVIWoVIVI
oiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00004oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go
0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Co0000ok>c/onc
/k?o00002Oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l000000om<
C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Oo0000ogmoOol0003o
VIVIo`000?nc/k?o000000Woc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo
0000oda<C?l00009oc<c<`0;o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol0
00001Oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool9ofIVIP03o`00
0?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`00
0?nIVIWoVIVI00coVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0:oiVIV@03o`00
0?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH01?mVIVH00ol0003oC4a<oda<C00Coda<C003o`00
0?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgooOgmoo`000003oiVIV@03o`000?nc/k?o/k>c00Co
/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`02ok>c/`05o`000?nIVIWoVIVIoiVI
VOl000000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<0
1Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01?l0003o/k>c
ok>c/ol00009olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH01Ol0
003oC4a<oda<C?m<C4co000000Oo<c<c00Co0000oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`00
0?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`00
0?moOgoo0000ofIVI_l0003oC4a<o`0000Wo<c<c00?o0000oda<C?l000000_mVIVH2o`000005oiVI
VOl0003o/k>cok>c/ol000001Oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool0
0oooool8ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmo
ogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVI
oiVIV@0;oiVIV@03o`000?moOgooOgmo00CoOgmo0_l00006ofIVIP03o`000?m<C4coC4a<01?oC4a<
00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000CoVIVI00?o0000ok>c/onc
/k<00onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Go0000oiVIVOnI
VIWoVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01_lc<c<0
1Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01?l0003o/k>c
ok>c/ol00009olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0
003oC4a<oda<C?l00008oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl00ol0003oVIVI
o`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmo
o`000?mVIVKo0000oda<C?l00009oc<c<`0;o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo
0000ok>c/ol000001_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool7
ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH2o`0000[oOgmo00?o0000
oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000
ogmoOomoOgl01?moOgl00ol0003oIVIVofIVIP06ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000
ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000?oVIVI00?o0000ok>c/onc/k<01?nc
/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Go0000oiVIVOnIVIWoVIVI
o`000002ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003o
C4a<oda<C?m<C4co000000;oIVIV00?o0000ogmoOol000000_nIVIT01Ol0003o/k>cok>c/onc/k?o
000000Soc<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo
00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0
0002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmo
o`000?mVIVKo0000oda<C?l00009oc<c<`0;o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo
0000ok>c/ol000001_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool6
ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`09
ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;
oiVIV@03o`000?moOgooOgmo00GoOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<C00C
oda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgooOgmoo`000004oiVIV@03o`000?nc
/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`05o`000?nI
VIWoVIVIoiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00005oda<C003o`000?lc<c?o<c<c00Go
<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Go0000
ok>c/onc/k?o/k>co`000008olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol00000
0_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl0
0ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00[o0000ok>c/onc/k?o0000oiVI
VOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`03o`000?m<C4coC4a<
00;o000000CoOgmoo`000?nIVIWo00000_nc/k<00ol0003oooooooooo`04ooooo`7o00000Oooool1
ooooo`009?ooool00ol0003oooooooooo`03ooooo`GoIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0
003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02_nIVIT2o`00
01Oo/k>c0_l0000=oiVIV@03o`000?moOgooOgmo00GoOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0
003oC4a<oda<C00Coda<C003o`000?mVIVKoIVIV00;oIVIV00?o0000ogmoOomoOgl00_moOgl01Ol0
003oVIVIoiVIVOnIVIWo000000Ko/k>c00?o0000olc<c?o<c<`00oo<c<`2o`0000Go/k>c00Co0000
oiVIVOnIVIWo00000omoOgl01?l0003oIVIVofIVI_l00004oda<C003o`000?lc<c?o<c<c00Go<c<c
00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`03o`000?nIVIWo000000?o
/k>c00?o0000olc<c?o<c<`01_o<c<`01ol0003o/k>cok>c/onc/k?o0000oiVIVOl000000_moOgl0
0ol0003oIVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Ko0000oda<C?m<C4co0000ofIV
I_l00002ogmoO`05o`000?nIVIWo0000ok>c/ol000002Oo<c<`02_l0003o/k>cok>c/ol0003oVIVI
o`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Wo0000oda<C?l0003o
IVIVo`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oooooooooo`04ooooo`7o00000Oooool1
ooooo`009?ooool00ol0003oooooooooo`03ooooo`CoIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0
003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02_nIVIT00ol0
003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl01_moOgl00ol0
003oIVIVofIVIP05ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH00_mVIVH00ol0
003oOgmoogmoO`02ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001_nc/k<00ol0003oc<c<olc<c003
olc<c003o`000?nc/k?o/k>c00Co/k>c00Co0000oiVIVOnIVIWo00000_moOgl01Ol0003oIVIVofIV
I_mVIVKo000000CoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`00
0?mVIVKoIVIVo`0000;oOgmo00?o0000oiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c007
o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000002ogmoO`03o`000?mVIVKo000000?oC4a<00?o0000
oc<c<olc<c<01_lc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00Go0000oiVIVOl0003o
/k>co`000009olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<
00?o0000oc<c<olc<c<01_lc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002
ok>c/`03o`000?oooooooooo00Cooooo0Ol00001ooooo`7ooooo000Tooooo`;o00001?ooool3ofIV
IP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`09ogmo
O`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVI
V@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<C00Coda<
C003o`000?mVIVKoIVIV00;oIVIV00?o0000ogmoOomoOgl00_moOgl01Ol0003oVIVIoiVIVOnIVIWo
000000Ko/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`04ok>c/`04o`000?nIVIWo
VIVIo`0000?oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`00
0?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl00ol0003oVIVIo`000003ok>c/`03
o`000?o<c<coc<c<00Ooc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`03o`000?mVIVKo
000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP05o`000?mo
Ogoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c00:o`000?nc/k?o/k>co`000?nI
VIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01olc<c<2o`000004ofIVI_l0
003oOgmoogmoO`;o00000_nc/k<00ol0003oc<c<ooooo`04ooooo`;o00000_ooool002Cooooo00?o
0000ooooooooool00oooool2ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omV
IVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00[oVIVI0_l0000Hok>c/`03o`000?nI
VIWoVIVI00_oVIVI00?o0000ogmoOomoOgl01_moOgl00ol0003oIVIVofIVIP05ofIVIP03o`000?m<
C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH00omVIVH01Ol0003oOgmoogmoOomoOgoo000000CoVIVI
00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c00?o/k>c
00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`05o`000?mVIVKoIVIVofIVI_l000001?m<C4`00ol0
003o<c<coc<c<`05oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol0
0002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002Oo<c<`01_l0003o/k>cok>c/ol0003oVIVIo`00
00;oOgmo00?o0000ofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`06o`000?m<C4coC4a<
o`000?mVIVKo00000_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00[o
0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06
oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?oo
ool01Oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool00omVIVKo0000
oda<C00Goda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVI
oiVIV@0:oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmo
ogmoO`07ogmoO`03o`000?mVIVKoIVIV00GoIVIV00?o0000oda<C?m<C4`04om<C4`00ol0003oIVIV
ofIVIP03ofIVIP05o`000?moOgooOgmoogmoOol000000onIVIT00ol0003o/k>cok>c/`05ok>c/`03
o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00onc/k<01Ol0003oVIVIoiVIVOnIVIWo0000
00;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go<c<c00Go0000
oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o
/k>co`000009olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl00ol0003oIVIVo`000002
oda<C003o`000?lc<c?o<c<c00Oo<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`03o`00
0?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`00
0?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Wo0000oda<C?l0003oIVIV
o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<ooooo`05ooooo`7o00000Oooool1oooo
o`009?ooool00ol0003oooooooooo`03ooooo`03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mV
IVH02omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00[oVIVI00?o0000ok>c/onc
/k<05onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00OoOgmo00?o0000ofIVI_mV
IVH01OmVIVH00ol0003oC4a<oda<C00Coda<C003o`000?mVIVKoIVIV00?oIVIV00Go0000ogmoOomo
OgooOgmoo`000004oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0
003o/k>cok>c/`03ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01Ol0003oIVIVofIVI_mV
IVKo000000CoC4a<00?o0000oc<c<olc<c<01Olc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV
00Co0000ogmoOomoOgoo00000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Woc<c<00Ko0000ok>c
/onc/k?o0000oiVIVOl00002ogmoO`03o`000?mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc
<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003o
c<c<olc<c007olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o
0000oc<c<olc<c<01_lc<c<00ol0003oC4a<o`000002ofIVIP;o000000GoVIVIo`000?nc/k?o/k>c
o`000002olc<c0Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo6?m<
C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo0_l0000<oiVIV@03o`000?nc
/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`07ogmoO`03o`000?mV
IVKoIVIV00GoIVIV00?o0000oda<C?m<C4`04om<C4`00ol0003oIVIVofIVIP03ofIVIP05o`000?mo
OgooOgmoogmoOol000001?nIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00?oc<c<
0_l00005ok>c/`04o`000?nIVIWoVIVIo`0000?oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0
003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol0
0002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@06
o`000?moOgooOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`07oc<c<`08o`000?m<C4co
C4a<o`000?mVIVKo0000ogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00co0000ok>c
/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00009oc<c<`09o`000?m<C4co0000
ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_ooool1o`00007ooooo
0Oooool002Cooooo00?o0000ooooooooool00ooooolHoda<C003o`000?mVIVKoIVIV00[oIVIV00?o
0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0:oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o
0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`07ogmoO`03o`000?mVIVKoIVIV00KoIVIV00?o
0000oda<C?m<C4`04om<C4`00ol0003oIVIVofIVIP03ofIVIP05o`000?moOgooOgmoogmoOol00000
1?nIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<0
1?nc/k<01?l0003oVIVIoiVIVOl00003ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c
<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nI
VIT01?l0003o/k>cok>c/ol00009olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Ko0000ogmoOomo
Ogoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c00So0000oda<C?m<C4co0000ofIV
I_l0003oOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`03?l0003o/k>cok>c/ol0003o
VIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000Wo<c<c00Wo0000oda<C?l0003oIVIVo`000?mo
Ogoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006ooooo`7o00000Oooool1ooooo`009?oo
ool00ol0003oooooooooo`03oooooaOoC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmo
O`09ogmoO`03o`000?nIVIWoVIVI00[oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVI
V@0;oiVIV@03o`000?moOgooOgmo00OoOgmo00?o0000ofIVI_mVIVH01_mVIVH00ol0003oC4a<oda<
C00Coda<C003o`000?mVIVKoIVIV00?oIVIV00?o0000ogmoOomoOgl00_moOgl01Ol0003oVIVIoiVI
VOnIVIWo000000Ko/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`04ok>c/`05o`00
0?nIVIWoVIVIoiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00004oda<C003o`000?lc<c?o<c<c
00Ko<c<c00?o0000oda<C?m<C4`00_m<C4`01_l0003oIVIVofIVI_l0003oOgmoo`0000;oVIVI00Go
0000ok>c/onc/k?o/k>co`000008olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01Ol0003o
Ogmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01olc<c<01_l0003oC4a<oda<C?l0003o
IVIVo`0000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c00:o`000?nc
/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<0
0ol0003oC4a<oda<C002o`000007ogmoOol0003oVIVIoiVIVOl0003o/k>co`000003olc<c0Kooooo
0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo5Om<C4`2o`0000coIVIV00?o
0000ogmoOomoOgl02?moOgl2o`0000coVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVI
V@0;oiVIV@03o`000?moOgooOgmo00OoOgmo00?o0000ofIVI_mVIVH01_mVIVH00ol0003oC4a<oda<
C00Doda<C003o`000?mVIVKoIVIV00;oIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVI
V@02oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c
/`03ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000Co
C4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`00
00;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o
/k>co`0000;oVIVI00Ko0000ogmoOomoOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo
<c<c00So0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000;oVIVI00?o0000ok>c/ol000002Oo<
c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o
<c<c00Ko<c<c00?o0000oda<C?l000000_l000001_moOgoo0000oiVIVOl0003o/k>co`0000Coc<c<
1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00ooooolDoda<C003o`000?mV
IVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc
/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`07ogmoO`03o`000?mV
IVKoIVIV00KoIVIV00?o0000oda<C?m<C4`05?m<C4`00ol0003oIVIVofIVIP03ofIVIP03o`000?mo
OgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<
c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo
00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<
C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000
olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@06o`000?moOgooOgmoo`000?mVIVKo
00000_m<C4`00ol0003o<c<coc<c<`07oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0
0002oiVIV@03o`000?nc/k?o000000Woc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`00
0?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0;o`000?m<C4co0000ofIVI_l0003oOgmo
o`000?nIVIWo0000ok>c/ol000001?o<c<`6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003o
ooooooooo`03oooooa?oC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03
o`000?nIVIWoVIVI00_oVIVI0_l0000Gok>c/`;o00003OnIVIT00ol0003oOgmoogmoO`07ogmoO`03
o`000?mVIVKoIVIV00OoIVIV00?o0000oda<C?m<C4`04om<C4`00ol0003oIVIVofIVIP03ofIVIP03
o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`04ok>c/`03
o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00onc/k<01Ol0003oVIVIoiVIVOnIVIWo0000
00;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000
oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o
/k>co`000008olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Ko0000ogmoOomoOgoo0000ofIVI_l0
0002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Co0000oda<C?m<C4co00000_mVIVH2o`0000;oVIVI
00Co0000ok>c/onc/k?o00002?o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIV
I_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?l0003oIVIVo`000002ogmoO`;o
00000_nc/k<00ol0003oc<c<olc<c002olc<c0Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`00
0?oooooooooo00?ooooo4_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo
00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00coVIVI
00?o0000ogmoOomoOgl01omoOgl00ol0003oIVIVofIVIP07ofIVIP03o`000?m<C4coC4a<01CoC4a<
00?o0000ofIVI_mVIVH00_mVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00;oVIVI
00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c00Co/k>c
00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`05o`000?mVIVKoIVIVofIVI_l000001?m<C4`00ol0
003o<c<coc<c<`05oc<c<`05o`000?m<C4coC4a<oda<C?l000000omVIVH01?l0003oOgmoogmoOol0
0002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@03
o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<2o`0000;oC4a<00Go0000ofIV
I_l0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00[o0000ok>c/onc/k?o0000
oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`09o`000?m<C4co
0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`00_o<c<`6ooooo`7o
00000Oooool1ooooo`009?ooool2o`0000Cooooo4Om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`00
0?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`00
0?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP06ofIVIP03o`00
0?m<C4coC4a<01GoC4a<00?o0000ofIVI_mVIVH00_mVIVH00ol0003oOgmoogmoO`02ogmoO`03o`00
0?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c003olc<c003o`00
0?nc/k?o/k>c00Co/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`05o`000?mVIVKoIVIVofIV
I_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000omVIVH0
1?l0003oOgmoogmoOol00002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01?l0003o/k>c
ok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<02Ol0
003oC4a<oda<C?m<C4co0000ofIVI_l0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000So
c<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<c
oc<c<`06oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000
olc<c?o<c<`00_o<c<`5ooooo`;o00000_ooool002Cooooo00?o0000ooooooooool00oooool@oda<
C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@0<oiVI
V@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmo
O`03o`000?mVIVKoIVIV00KoIVIV00?o0000oda<C?m<C4`05Om<C4`00ol0003oIVIVofIVIP03ofIV
IP03o`000?moOgooOgmo00;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000007ok>c/`03o`000?o<c<co
c<c<00;oc<c<00?o0000ok>c/onc/k<01?nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Go
0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4co
C4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008
olc<c007o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000;o
C4a<00?o0000oc<c<olc<c<01_lc<c<02ol0003oC4a<oda<C?m<C4co0000ofIVI_l0003oOgmoo`00
0?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`03?l0003o/k>cok>c/ol0003oVIVIo`00
0?moOgoo0000ofIVI_l0003oC4a<o`0000Wo<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000
oiVIVOl000000_nc/k<00ol0003oc<c<olc<c002olc<c0Kooooo0Ol00001ooooo`7ooooo000Toooo
o`03o`000?oooooooooo00?ooooo3om<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?moOgooOgmo
00OoOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI
00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP06ofIVIP03o`000?m<C4coC4a<
01GoC4a<00?o0000ofIVI_mVIVH00_mVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI
00;oVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c
00Co/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`05o`000?mVIVKoIVIVofIVI_l000000om<
C4`00ol0003o<c<coc<c<`06oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo0000
0_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc
/k?o00000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Wo0000
oda<C?m<C4coC4a<o`000?mVIVKo0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00008olc<
c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc
<c<01_lc<c<00ol0003oC4a<o`000002ofIVIP;o000000GoVIVIo`000?nc/k?o/k>co`000005olc<
c0Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo3_m<C4`2o`0000co
IVIV0_l00009ogmoO`;o00003OnIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_o
VIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP06ofIVIP03o`000?m<C4coC4a<01Co
C4a<0_l00004ofIVIP;o00000omoOgl00ol0003oVIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c00Go
/k>c00?o0000olc<c?o<c<`00_o<c<`00ol0003o/k>cok>c/`04ok>c/`05o`000?nIVIWoVIVIoiVI
VOl000000omoOgl01?l0003oIVIVofIVI_l00004oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000
oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o
/k>co`000008olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT00ol0003oOgmoo`000002ofIV
IP04o`000?m<C4coC4a<o`0000So<c<c00Wo0000oda<C?m<C4coC4a<o`000?mVIVKo0000ogmoOol0
00000_nIVIT00ol0003o/k>co`000009olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0
003oIVIVo`000?m<C4co00002Olc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`00
0002ok>c/`03o`000?o<c<coc<c<00?oc<c<1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000
ooooooooool00oooool=oda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl0
0ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT0
0ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00OoIVIV00?o0000oda<C?m<C4`05?m<C4`0
0ol0003oIVIVofIVIP03ofIVIP03o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00_nIVIT0
0ol0003o/k>cok>c/`05ok>c/`05o`000?o<c<coc<c<olc<c?l000001onc/k<01Ol0003oVIVIoiVI
VOnIVIWo000000?oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`06oc<c<`05
o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@05o`000?nc/k?o
/k>cok>c/ol000002?o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmoOol00000
0_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`09o`000?m<C4coC4a<oda<C?l0003oIVIVo`000?mo
Ogoo000000;oVIVI00?o0000ok>c/ol000002Oo<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?mo
Ogoo0000ofIVI_l0003oC4a<o`0000Wo<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000oiVI
VOl000000_nc/k<00ol0003oc<c<olc<c003olc<c0Kooooo0Ol00001ooooo`7ooooo000Tooooo`03
o`000?oooooooooo00?ooooo3?m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00So
Ogmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_o
VIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP07ofIVIP03o`000?m<C4coC4a<01Co
C4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00?o
VIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c00Co
/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000
oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo0000
0_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVI
V@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<01ol0003oC4a<oda<C?m<
C4co0000ofIVI_l000000_moOgl01Ol0003oVIVIo`000?nc/k?o000000Woc<c<00[o0000ok>c/onc
/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`07o`00
0?m<C4co0000ofIVI_l0003oOgmoo`000002oiVIV@03o`000?nc/k?o000000Koc<c<1_ooool1o`00
007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool;oda<C003o`000?mVIVKoIVIV00_o
IVIV00?o0000ogmoOomoOgl02?moOgl2o`0000goVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003o
VIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH01omVIVH00ol0003o
C4a<oda<C00Eoda<C003o`000?mVIVKoIVIV00?oIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003o
VIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c00Go/k>c00Go0000olc<c?o<c<coc<c<o`000007ok>c
/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000CoC4a<00?o
0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo
00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c
/ol000000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Co0000
oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVIV@03o`000?nc/k?o000000Woc<c<00[o
0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06
oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<
c<`01?o<c<`6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`[oC4a<
00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00coVIVI
00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo
00?o0000ofIVI_mVIVH02?mVIVH00ol0003oC4a<oda<C00Doda<C003o`000?mVIVKoIVIV00?oIVIV
00?o0000ogmoOomoOgl00omoOgl00ol0003oVIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c00Co/k>c
00?o0000olc<c?o<c<`00_o<c<`00ol0003o/k>cok>c/`05ok>c/`05o`000?nIVIWoVIVIoiVIVOl0
00000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000CoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0
003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo00000onc
/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT00ol0003oOgmo
o`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0
003oOgmoo`000002oiVIV@03o`000?nc/k?o000000Woc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0
003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`05oc<c<`0:o`000?m<C4coC4a<o`00
0?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01?o<c<`6ooooo`7o0000
0Oooool1ooooo`006oooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool00ooo
ool9oda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVI
V@0<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmo
O`09ogmoO`03o`000?mVIVKoIVIV00SoIVIV00?o0000oda<C?m<C4`05?m<C4`00ol0003oIVIVofIV
IP03ofIVIP03o`000?moOgooOgmo00?oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c
/`05ok>c/`05o`000?o<c<coc<c<olc<c?l000001onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;o
Ogmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<
C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o
0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmoOol00000
0_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0
0002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmo
o`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4co0000ofIVI_l00000
0_moOgl2o`0000;o/k>c00?o0000olc<c?o<c<`01Oo<c<`6ooooo`7o00000Oooool1ooooo`007?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo2?m<C4`00ol0003oIVIVofIV
IP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c
/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIV
IP08ofIVIP03o`000?m<C4coC4a<01GoC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmo
O`02ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<
c002olc<c003o`000?nc/k?o/k>c00Co/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`05o`00
0?mVIVKoIVIVofIVI_l000001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;o
C4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<co
c<c<00Koc<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo
00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Go0000ogmo
Ool0003oVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00[o0000ok>c/ol0003o0000oiVI
VOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`06o`000?m<C4co0000
ofIVI_l0003oOgmo0ol00002ok>c/`03o`000?o<c<coc<c<00Goc<c<1_ooool1o`00007ooooo0Ooo
ool001Wooooo1Ol00006ooooo`?o00000oooool7oda<C003o`000?mVIVKoIVIV00_oIVIV0_l0000:
ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;
oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02?mVIVH00ol0003oC4a<oda<C00E
oda<C003o`000?mVIVKoIVIV00CoIVIV00Go0000ogmoOomoOgooOgmoo`000005oiVIV@03o`000?nc
/k?o/k>c00Go/k>c00Go0000olc<c?o<c<coc<c<o`000007ok>c/`05o`000?nIVIWoVIVIoiVIVOl0
00000omoOgl01?l0003oIVIVofIVI_l00005oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<
C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o
0000olc<c?o<c<`01_o<c<`01ol0003o/k>cok>c/onc/k?o0000oiVIVOl000000_moOgl01?l0003o
IVIVofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH0
1Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c
/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`09
o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01Oo<
c<`4ooooo`?o00000_ooool001Wooooo00CoA4A4omgMgOoooooo00001oooool00ol0003ooooooooo
o`03ooooo`KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nI
VIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?mo
OgooOgmo00SoOgmo0_l0000;ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH01?mV
IVH01Ol0003oOgmoogmoOomoOgoo000000GoVIVI00?o0000ok>c/onc/k<01Onc/k<00ol0003oc<c<
olc<c002olc<c003o`000?nc/k?o/k>c00Co/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`05
o`000?mVIVKoIVIVofIVI_l000001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<
00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<
c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@03o`000?moOgoo000000;oIVIV
00Co0000oda<C?m<C4co00002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo0000
00;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`02?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo
00000_mVIVH00ol0003oC4a<o`000008oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nI
VIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`6ooooo`7o00000Oooool1ooooo`006Oooool0
1?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo00?ooooo1Om<C4`00ol0003oIVIVofIV
IP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02_nIVIT2o`0001Oo/k>c0_l0
000=oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<oda<
C00Doda<C003o`000?mVIVKoIVIV00CoIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVI
V@02oiVIV@03o`000?nc/k?o/k>c00Ko/k>c00Go0000olc<c?o<c<coc<c<o`000006ok>c/`03o`00
0?nIVIWoVIVI00;oVIVI00Co0000ogmoOomoOgoo00000omVIVH00ol0003oC4a<oda<C002oda<C003
o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo0000
00;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o
/k>co`0000;oVIVI00Ko0000ogmoOomoOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo
<c<c00Co0000oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000
olc<c?o<c<`01oo<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<
o`0000Wo<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003o
c<c<olc<c006olc<c003o`000?oooooooooo00?ooooo0Ol00001ooooo`7ooooo000Jooooo`03ogMg
Moo<c<co000000Oooooo00?o0000ooooooooool00oooool4oda<C003o`000?mVIVKoIVIV00_oIVIV
00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0:oiVIV@03o`000?nc/k?o/k>c01Ko/k>c
00?o0000oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00[oIVIV
00?o0000oda<C?m<C4`05Om<C4`00ol0003oIVIVofIVIP03ofIVIP03o`000?moOgooOgmo00?oOgmo
00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`06ok>c/`05o`000?o<c<coc<c<olc<c?l0
00001_nc/k<00ol0003oVIVIoiVIV@02oiVIV@04o`000?moOgooOgmoo`0000?oIVIV00?o0000oda<
C?m<C4`00_m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Go0000ofIV
I_mVIVKoIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<
c<`01?l0003o/k>cok>c/ol00002oiVIV@06o`000?moOgooOgmoo`000?mVIVKo00000_m<C4`00ol0
003o<c<coc<c<`07oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Go0000ogmoOol0003oVIVIo`00
0002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`00
0?mVIVKo0000oda<C?l00009oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000
00;o/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003oooooooooo`03ooooo`7o00000Oooool1oooo
o`006_ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo00?ooooo0om<C4`00ol0003o
IVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o
/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003o
IVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<01GoC4a<00?o0000ofIVI_mVIVH01?mVIVH00ol0003o
OgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01_nc/k<3o`000003
olc<c?l0003o/k>c00Go/k>c00?o0000oiVIVOnIVIT00_nIVIT01?l0003oOgmoogmoOol00003ofIV
IP03o`000?m<C4coC4a<00;oC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<
C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<
c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT01_l0003oOgmoogmoOol0003oIVIVo`00
00?oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo
Ogmo00;o00000_nc/k<00ol0003oc<c<olc<c007olc<c006o`000?nc/k?o/k>co`000?nIVIWo0000
0_moOgl2o`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<00ol0003oC4a<o`000002ofIVIP;o0000
0_nIVIT01?l0003o/k>cok>c/ol00007olc<c003o`000?oooooooooo00Cooooo0Ol00001ooooo`7o
oooo000Kooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool00oooool2oda<C003o`00
0?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0:oiVIV@;o0000
6?nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH0
2_mVIVH00ol0003oC4a<oda<C00Eoda<C003o`000?mVIVKoIVIV00CoIVIV00?o0000ogmoOomoOgl0
0_moOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c00Ko/k>c00Co0000olc<c?o<c<co
00001onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004
oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l0
0002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01oo<c<`01?l0003o/k>c
ok>c/ol00002oiVIV@06o`000?moOgooOgmoo`000?mVIVKo00000om<C4`00ol0003o<c<coc<c<`06
oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`00
0?o<c<coc<c<00Ooc<c<00?o0000ok>c/ol000000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;o
C4a<00?o0000oc<c<olc<c<01_lc<c<00ol0003oC4a<o`000002ofIVIP;o00000_nIVIT00ol0003o
/k>co`000008olc<c003o`000?oooooooooo00Cooooo0Ol00001ooooo`7ooooo000Tooooo`03o`00
0?oooooooooo00?ooooo00?oC4a<o`000?mVIVH03?mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`00
0?nIVIWoVIVI00[oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`00
0?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Eoda<C003o`00
0?mVIVKoIVIV00CoIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@03oiVIV@03o`00
0?nc/k?o/k>c00Ko/k>c00Co0000olc<c?o<c<co00001onc/k<01Ol0003oVIVIoiVIVOnIVIWo0000
00?oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000
oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c
00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Ko0000ogmoOomo
Ogoo0000ofIVI_l00003oda<C003o`000?lc<c?o<c<c00Go<c<c00Go0000oda<C?m<C4coC4a<o`00
0002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c003o`00
0?nc/k?o000000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko
<c<c00?o0000oda<C?l000000_mVIVH2o`0000;oVIVI00?o0000ok>c/ol000002?o<c<`00ol0003o
ooooooooo`04ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`03o`00
0?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0:oiVIV@03o`00
0?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`00
0?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05Om<C4`00ol0003oIVIVofIVIP04ofIVIP03o`00
0?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`06ok>c/`04o`00
0?o<c<coc<c<o`0000Oo/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`05o`000?mVIVKoIVIV
ofIVI_l000001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00?oC4a<00Co0000
ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<
00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Co0000oda<
C?m<C4co00002?lc<c<02ol0003oC4a<oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000
00;o/k>c00?o0000olc<c?o<c<`01oo<c<`00ol0003o/k>co`000003oiVIV@;o000000GoIVIVo`00
0?m<C4coC4a<o`000008oc<c<`05o`000?m<C4coC4a<o`000?mVIVH00_l00002oiVIV@03o`000?nc
/k?o000000Soc<c<00?o0000ok>c/oooool01Oooool1o`00007ooooo0Oooool002Cooooo00?o0000
ooooooooool00oooool=ofIVIP03o`000?moOgooOgmo00SoOgmo0_l0000<oiVIV@03o`000?nc/k?o
/k>c01Oo/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKo
IVIV00_oIVIV00?o0000oda<C?m<C4`05Om<C4`00ol0003oIVIVofIVIP04ofIVIP03o`000?moOgoo
Ogmo00;oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`06ok>c/`;o000000?oc<c<
o`000?nc/k<01_nc/k<00ol0003oVIVIoiVIV@02oiVIV@04o`000?moOgooOgmoo`0000?oIVIV00?o
0000oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co
0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Ko
c<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@03o`000?moOgoo000000;oIVIV00Go0000oda<
C?m<C4coC4a<o`000008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Go0000ogmoOol0003oVIVI
o`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00?o0000ok>c/ol000000_nIVIT01Ol0003oOgmo
o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?l0003oIVIV
00;o00000_nIVIT2o`0000Woc<c<00?o0000ok>c/oooool01Oooool1o`00007ooooo0Oooool002Co
oooo00?o0000ooooooooool00oooool<ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnI
VIT02_nIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomo
Ogl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP;o00005om<C4`00ol0003oIVIVofIVIP04ofIVIP03
o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`08ok>c/`03
o`000?nc/k?o/k>c00Ko/k>c00?o0000oiVIVOnIVIT00_nIVIT01?l0003oOgmoogmoOol00003ofIV
IP03o`000?m<C4coC4a<00?oC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C003oda<
C004o`000?mVIVKoIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<
c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT00ol0003oOgmoo`000002ofIVIP05o`00
0?m<C4coC4a<oda<C?l000002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP05o`000?moOgoo0000
oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Go
0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4co
0000ofIVIP02o`0000;oVIVI0_l00009olc<c003o`000?nc/k?ooooo00Gooooo0Ol00001ooooo`7o
oooo000Tooooo`;o00001?ooool;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT0
2_nIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl0
2?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH0
1?mVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<0
4Onc/k<00ol0003oVIVIoiVIV@02oiVIV@04o`000?moOgooOgmoo`0000?oIVIV00?o0000oda<C?m<
C4`00om<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mV
IVKo00000_moOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000
ok>c/onc/k<00_nc/k<00ol0003oVIVIoiVIV@02o`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`00
0008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>c
ok>c/ol00008olc<c003o`000?nc/k?o000000;oVIVI00?o0000ogmoOol000000_mVIVH00ol0003o
C4a<o`000008oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o
00002?o<c<`01?l0003o/k>cok>c/ol00004ooooo`;o00000_ooool002Cooooo00?o0000oooooooo
ool00oooool:ofIVIP03o`000?moOgooOgmo00SoOgmo0_l0000<oiVIV@03o`000?nc/k?o/k>c01Oo
/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_o
IVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP04ofIVIP03o`000?moOgooOgmo00?o
Ogmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`0Bok>c/`05o`000?nIVIWoVIVIoiVI
VOl000000omoOgl01Ol0003oIVIVofIVI_mVIVKo000000CoC4a<00?o0000oc<c<olc<c<01Olc<c<0
0ol0003oC4a<oda<C002oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01?l0003oVIVIoiVI
VOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@03
o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<01_l0003oC4a<oda<C?l0003o
IVIVo`0000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc
/k?o/k>co`0000;oVIVI00Oo0000ogmoOol0003oIVIVo`000?m<C4co000000Wo<c<c00?o0000oda<
C?l000000_mVIVH01ol0003oOgmoo`000?nIVIWo0000ok>c/ol000002?o<c<`01?l0003o/k>cok>c
/ol00005ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`WoIVIV00?o
0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o
0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV0_l0
000Goda<C003o`000?mVIVKoIVIV00GoIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVI
V@03oiVIV@03o`000?nc/k?o/k>c01;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`05o`00
0?mVIVKoIVIVofIVI_l000001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;o
C4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000
olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmoOol000000_mV
IVH01?l0003oC4a<oda<C?l00009oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl00ol0
003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT0
1ol0003oOgmoo`000?mVIVKo0000oda<C?l000002Olc<c<01Ol0003oC4a<o`000?mVIVKo000000;o
Ogmo00Go0000oiVIVOl0003o/k>co`000008olc<c004o`000?nc/k?o/k>co`0000Gooooo0Ol00001
ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo2?mVIVH00ol0003oOgmoogmoO`08ogmo
O`03o`000?nIVIWoVIVI00_oVIVI0_l0000Gok>c/`;o00003OnIVIT00ol0003oOgmoogmoO`08ogmo
O`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP05ofIV
IP03o`000?moOgooOgmo00?oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`0Bok>c
/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01Ol0003oIVIVofIVI_mVIVKo000000GoC4a<00?o
0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C002oda<C005o`000?mVIVKoIVIVofIVI_l00000
0_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc
/k?o/k>co`000002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<0
1?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgooOgmo00;o00000_nc/k<00ol0003oc<c<olc<
c007olc<c003o`000?nc/k?o000000;oVIVI00?o0000ogmoOomoOgl00_l00002oda<C003o`000?lc
<c?o<c<c00Ko<c<c00?o0000oda<C?l000000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c
00?o0000olc<c?o<c<`01_o<c<`00ol0003o/k>co`000006ooooo`7o00000Oooool1ooooo`009?oo
ool00ol0003oooooooooo`03ooooo`OoIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVI
V@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmo
O`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIV
IP05ofIVIP03o`000?moOgooOgmo00?oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c
/`0Bok>c/`03o`000?nIVIWoVIVI00;oVIVI00Co0000ogmoOomoOgoo00000omVIVH2o`0000CoC4a<
00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C003o`000?mVIVKoIVIV00;o0000
00?oOgmoo`000?l000000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Oo0000ok>c/onc
/k?o/k>co`000?nIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo00000_m<C4`00ol0003o<c<coc<c
<`06oc<c<`06o`000?m<C4coC4a<oda<C?l0003oIVIV0_l000001?moOgoo0000oiVIVOl00002ok>c
/`03o`000?o<c<coc<c<00Ooc<c<00?o0000ok>c/ol000000_nIVIT01Ol0003oOgmoo`000?mVIVKo
000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<00ol0003oC4a<o`000002ofIVIP07o`000?moOgoo
0000oiVIVOl0003o/k>co`000008olc<c004o`000?nc/k?o/k>co`0000Kooooo0Ol00001ooooo`7o
oooo000Tooooo`03o`000?oooooooooo00?ooooo1_mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`00
0?nIVIWoVIVI00coVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`00
0?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH03?mVIVH00ol0003oC4a<oda<C00Foda<C003o`00
0?mVIVKoIVIV00GoIVIV00?o0000ogmoOomoOgl00omoOgl00ol0003oVIVIoiVIV@02oiVIV@03o`00
0?nc/k?o/k>c01;o/k>c00?o0000oiVIVOnIVIT00_nIVIT01?l0003oOgmoogmoOol00003ofIVIP03
o`000?m<C4coC4a<00?oC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004
o`000?mVIVKoIVIVo`0000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000003ok>c/`03o`000?o<c<co
c<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<00ol0003oVIVIo`000002ogmoO`04o`000?mVIVKo
IVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP06o`00
0?moOgooOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c007olc<c005o`000?nc/k?o0000
oiVIVOl000000_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00?o0000
oda<C?l000000_mVIVH01?l0003oOgmoo`000?l00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co
0000ok>c/onc/k?o00001_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00ooo
ool6ofIVIP03o`000?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c
/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIV
IP0<ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH01?mVIVH00ol0003oOgmoogmo
O`03ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<04_nc/k<00ol0003oVIVIoiVI
V@02oiVIV@05o`000?moOgooOgmoogmoOol000000omVIVH00ol0003oC4a<oda<C003oda<C003o`00
0?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;o
Ogmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>c
ok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c
00Co0000oda<C?m<C4co00000_mVIVH01_l0003oOgmoogmoOol0003oVIVIo`0000;o/k>c00?o0000
olc<c?o<c<`01_o<c<`00ol0003o/k>co`000002oiVIV@06o`000?moOgooOgmoo`000?mVIVKo0000
0_m<C4`00ol0003o<c<coc<c<`05oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Co0000ogmoOol0
003o00000_nc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o0000oiVIVOl000001Oooool1
o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool5ofIVIP03o`000?moOgooOgmo
00OoOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI
00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<
01OoC4a<00?o0000ofIVI_mVIVH01?mVIVH00ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI
00?oVIVI00?o0000ok>c/onc/k<04_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Go0000
ofIVI_mVIVKoIVIVo`000005oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<
C4`01?l0003oIVIVofIVI_l00002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000onc/k<00ol0003o
c<c<olc<c005olc<c005o`000?nc/k?o/k>cok>c/ol000000onIVIT01_l0003oOgmoogmoOol0003o
IVIVo`0000?oC4a<00?o0000oc<c<olc<c<01Olc<c<01ol0003oC4a<oda<C?m<C4co0000ofIVI_l0
00000_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00?o0000ok>c/ol0
00000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<03?l0
003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Woc<c<00Go0000ok>c
/ol0003oVIVIo`000005ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03oooo
o`?oIVIV0_l00009ogmoO`;o00003OnIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI
00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0:ofIVIP;o00006?m<C4`2o`00
00OoIVIV00?o0000ogmoOomoOgl00omoOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c
017o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000?oIVIV00?o0000
oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00;oC4a<00Go0000
ofIVI_mVIVKoIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`0
1_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01?l0
003oC4a<oda<C?l00008oc<c<`07o`000?m<C4coC4a<oda<C?l0003oIVIVo`000002ogmoO`03o`00
0?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@05
o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0<o`000?m<C4coC4a<
o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00002Oo<c<`2o`000003oiVIVOl0003ooooo
00Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo0omVIVH00ol0003o
OgmoogmoO`07ogmoO`03o`000?nIVIWoVIVI00coVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003o
VIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003o
C4a<oda<C00Foda<C003o`000?mVIVKoIVIV00OoIVIV00?o0000ogmoOomoOgl00omoOgl00ol0003o
VIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c017o/k>c00?o0000oiVIVOnIVIT00_nIVIT01?l0003o
OgmoogmoOol00004ofIVIP03o`000?m<C4coC4a<00;oC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0
003oC4a<oda<C002oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl0
0003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`00
0?moOgooOgmoo`0000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<01ol0003oC4a<oda<C?m<C4co
0000ofIVI_l000000_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co
0000ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc
<c<01_lc<c<01Ol0003oC4a<oda<C?l0003oIVIV00;o00000_nIVIT00ol0003o/k>co`000009olc<
c0;o000000?oVIVIo`000?ooool01Oooool1o`00007ooooo0Oooool002Cooooo00?o0000oooooooo
ool00oooool2ofIVIP03o`000?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o
/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003o
IVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0003o
OgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<04Onc/k<00ol0003o
VIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol000000omVIVH00ol0003oC4a<oda<C003oda<
C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo
000000;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc
/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP04o`000?m<C4coC4a<o`00
00So<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo0000
0_nc/k<00ol0003oc<c<olc<c005olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol0
00000_mVIVH00ol0003oC4a<o`000008oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0
003oVIVIo`000?nc/k?o00002Oo<c<`01Ol0003o/k>co`000?l0003oOgmo00Kooooo0Ol00001oooo
o`7ooooo000Tooooo`;o00001?ooool2o`0000WoOgmo0_l0000=oiVIV@03o`000?nc/k?o/k>c01Ko
/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00[o
IVIV0_l0000Ioda<C003o`000?mVIVKoIVIV00KoIVIV00?o0000ogmoOomoOgl00omoOgl00ol0003o
VIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c01;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmo
O`04o`000?mVIVKoIVIVofIVIP;o00001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4co
C4a<00;oC4a<00?o0000ofIVI_mVIVH00_l00002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o
0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Ko0000ogmoOomoOgoo
0000ofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00So0000oda<C?m<C4coC4a<o`000?mV
IVKo0000ogmoO`;o000000GoVIVIo`000?nc/k?o/k>co`000008olc<c007o`000?nc/k?o/k>co`00
0?nIVIWo0000ogmoO`02o`000004ofIVI_l0003oC4a<o`0000Wo<c<c00co0000oda<C?m<C4co0000
ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00008olc<c003o`000?nc/k?o/k>c00;o000000?o
Ogmoooooooooool00oooool2o`0000;ooooo000Tooooo`03o`000?oooooooooo00?ooooo2_moOgl0
0ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT0
0ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`0
0ol0003oIVIVofIVIP06ofIVIP03o`000?moOgooOgmo00?oOgmo00?o0000oiVIVOnIVIT00onIVIT0
0ol0003o/k>cok>c/`0Cok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01Ol0003oIVIVofIV
I_mVIVKo000000GoC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C003oda<C004o`00
0?mVIVKoIVIVo`0000?oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<
c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01_l0003oOgmoogmoOol0003oIVIVo`0000?oC4a<
00?o0000oc<c<olc<c<01_lc<c<02Ol0003oC4a<oda<C?m<C4co0000ofIVI_l0003oOgmoo`000002
oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`00
00;oIVIV00?o0000oda<C?l000002Olc<c<00ol0003oC4a<oda<C002o`0000;oOgmo00Go0000oiVI
VOl0003o/k>co`000008olc<c003o`000?nc/k?o/k>c00;o000000?oOgmoo`000?ooool01?ooool1
o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool9ogmoO`03o`000?nIVIWoVIVI
00coVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo
00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV
00KoIVIV00?o0000ogmoOomoOgl01?moOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c
01;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`05o`000?mVIVKoIVIVofIVI_l000001Om<
C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo0000
0omoOgl01Ol0003oVIVIoiVIVOnIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o
/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01?l0003oC4a<oda<C?l0
0008oc<c<`09o`000?m<C4coC4a<oda<C?l0003oIVIVo`000?moOgoo000000;oVIVI00Co0000ok>c
/onc/k?o00002?o<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00?o0000ofIVI_l00000
0_m<C4`00ol0003o<c<coc<c<`06oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003o
VIVIo`000?nc/k?o00002Oo<c<`01ol0003o/k>co`000?nIVIWo0000ogmoOol000001Oooool1o`00
007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool9ogmoO`03o`000?nIVIWoVIVI00_o
VIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00Wo
Ogmo00?o0000ofIVI_mVIVH02_mVIVH2o`0001WoC4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0003o
OgmoogmoO`04ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<04_nc/k<00ol0003o
VIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol000000omVIVH00ol0003oC4a<oda<C003oda<
C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00om<C4`01?l0003oIVIVofIVI_l00002
ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc
/k?o/k>cok>c/ol000000_nIVIT01_l0003oOgmoo`000?l0003oIVIVo`0000?oC4a<00?o0000oc<c
<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000
ok>c/onc/k?o00002?o<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00?o0000ofIVI_l0
00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`03o`000?m<C4co000000;oIVIV00Oo0000ogmoOol0
003oVIVIo`000?nc/k?o000000Soc<c<00Go0000ok>c/onc/k?o0000oiVIV@02o`0000Kooooo0Ol0
0001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo2?moOgl00ol0003oVIVIoiVIV@0;
oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09
ogmoO`03o`000?mVIVKoIVIV00[oIVIV00?o0000oda<C?m<C4`06?m<C4`00ol0003oIVIVofIVIP07
ofIVIP03o`000?moOgooOgmo00CoOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0B
ok>c/`03o`000?nIVIWoVIVI00;oVIVI00Co0000ogmoOomoOgoo00001?mVIVH00ol0003oC4a<oda<
C003oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00om<C4`01?l0003oIVIVofIV
I_l00002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c004
o`000?nc/k?o/k>co`0000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01Ol0003oC4a<oda<C?m<
C4co000000So<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`00
0?nc/k?o/k>co`0000Soc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`03o`000?mVIVKo
000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<00ol0003oC4a<o`000002ofIVIP04o`000?moOgoo
0000o`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/ol0003oVIVI00;o0000
1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool7ogmoO`03o`000?nI
VIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?mo
OgooOgmo00SoOgmo0_l0000<ofIVIP03o`000?m<C4coC4a<01SoC4a<00?o0000ofIVI_mVIVH01omV
IVH00ol0003oOgmoogmoO`04ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<04_nc
/k<00ol0003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol000000omVIVH00ol0003oC4a<
oda<C003oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00om<C4`01?l0003oIVIV
ofIVI_l00002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0003oc<c<olc<c005olc<
c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT00ol0003oOgmoo`000002ofIVIP05o`000?m<C4co
C4a<oda<C?l000002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI
00Co0000ok>c/onc/k?o00002?o<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00?o0000
ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000
ogmoOol0003oVIVIo`000?nc/k?o00002?o<c<`02?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo
00001_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool6ogmoO`03o`00
0?nIVIWoVIVI00[oVIVI0_l0000Gok>c/`;o00003OnIVIT00ol0003oOgmoogmoO`08ogmoO`03o`00
0?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`06?m<C4`00ol0003oIVIVofIVIP07ofIVIP03o`00
0?moOgooOgmo00CoOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0Bok>c/`03o`00
0?nIVIWoVIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`000003ofIVIP;o00001?m<C4`2o`0000Ko
<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Co0000oiVI
VOnIVIWo00001?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Ko0000
oiVIVOnIVIWo0000ogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000Wo<c<c00Co0000oda<C?m<
C4co00000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Ko0000
ok>c/onc/k?o0000oiVIVOl00002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<0
1_lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Soc<c<
00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`0000Kooooo0Ol00001ooooo`7ooooo000Toooo
o`03o`000?oooooooooo00?ooooo1OmoOgl00ol0003oVIVIoiVIV@0:oiVIV@03o`000?nc/k?o/k>c
01Ko/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV
00_oIVIV00?o0000oda<C?m<C4`06?m<C4`00ol0003oIVIVofIVIP08ofIVIP03o`000?moOgooOgmo
00CoOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0Bok>c/`03o`000?nIVIWoVIVI
00;oVIVI00Go0000ogmoOomoOgooOgmoo`000003ofIVIP03o`000?m<C4coC4a<00?oC4a<00?o0000
oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Go
0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<0
0_nc/k<01_l0003oVIVIoiVIVOl0003oOgmoo`0000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<0
1?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o0000
2?o<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo0_l00003oda<C003o`000?lc<c?o<c<c
00Ko<c<c00Go0000oda<C?m<C4co0000ofIVIP02o`0000;oVIVI00?o0000ok>c/ol000002?o<c<`0
2?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo00001_ooool1o`00007ooooo0Oooool002Cooooo
00?o0000ooooooooool00oooool4ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<0
5_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH0
2omVIVH00ol0003oC4a<oda<C00Hoda<C003o`000?mVIVKoIVIV00SoIVIV00?o0000ogmoOomoOgl0
1?moOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c01;o/k>c00?o0000oiVIVOnIVIT0
0_nIVIT01Ol0003oOgmoogmoOomoOgoo000000?oIVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o
<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmo
O`05o`000?nIVIWoVIVIoiVIVOl000000onc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o
/k>c00;o/k>c00Ko0000oiVIVOnIVIWo0000ogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<C?l0
00002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo000000?oVIVI00Co0000ok>c
/onc/k?o00001oo<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00?o0000ofIVI_l00000
0_m<C4`00ol0003o<c<coc<c<`06oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003o
VIVIo`000?nc/k?o00002Oo<c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000005
ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`?oOgmo00?o0000oiVI
VOnIVIT02_nIVIT2o`0001So/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmo
O`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`06?m<C4`00ol0003oIVIVofIVIP07ofIV
IP;o00001_moOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o0000oiVI
VOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000?oIVIV00?o0000oda<C?m<C4`00om<C4`0
0ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Co0000ofIVI_mVIVKo00000omo
Ogl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Goc<c<00Go0000ok>c/onc/k?o
/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008
oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c
/ol00008olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl01Ol0003oIVIVo`000?m<C4co
000000Wo<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00009
olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000Gooooo0Ol00001ooooo`7o
oooo000Tooooo`;o00001?ooool2ogmoO`03o`000?nIVIWoVIVI00[oVIVI00?o0000ok>c/onc/k<0
5onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH0
2omVIVH00ol0003oC4a<oda<C00Hoda<C003o`000?mVIVKoIVIV00SoIVIV00?o0000ogmoOomoOgl0
1?moOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT0
0_nIVIT01?l0003oOgmoogmoOol00004ofIVIP03o`000?m<C4coC4a<00?oC4a<00?o0000oc<c<olc
<c<01?lc<c<00ol0003oC4a<oda<C003oda<C004o`000?mVIVKoIVIVo`0000?oOgmo00Co0000oiVI
VOnIVIWo00001?nc/k<00ol0003oc<c<olc<c005olc<c005o`000?nc/k?o/k>cok>c/ol000000_nI
VIT01?l0003oOgmoogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01_l0003o
C4a<oda<C?l0003oIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo00000_nc/k<00ol0003oc<c<olc<
c006olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP03o`000?m<C4co0000
00Wo<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00009olc<
c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000Cooooo0_l00002ooooo`009?oo
ool00ol0003oooooooooo`03ooooo`03ogmoOol0003oVIVI00_oVIVI00?o0000ok>c/onc/k<05onc
/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omV
IVH00ol0003oC4a<oda<C00Goda<C0;o00002_mVIVH00ol0003oOgmoogmoO`04ogmoO`03o`000?nI
VIWoVIVI00CoVIVI00?o0000ok>c/onc/k<04onc/k<00ol0003oVIVIoiVIV@02oiVIV@05o`000?mo
OgooOgmoogmoOol000000omVIVH00ol0003oC4a<oda<C003oda<C003o`000?lc<c?o<c<c00Co<c<c
00?o0000oda<C?m<C4`00om<C4`01?l0003oIVIVofIVI_l00003ogmoO`04o`000?nIVIWoVIVIo`00
00Co/k>c00?o0000olc<c?o<c<`01Oo<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000
ogmoOomoOgoo00000omVIVH01?l0003oC4a<oda<C?l00008oc<c<`04o`000?m<C4coC4a<o`0000;o
IVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00008olc<c006o`000?nc/k?o/k>c
o`000?nIVIWo00000_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00co
0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00009olc<c009o`000?nc
/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000Kooooo0Ol00001ooooo`7ooooo000Tooooo`03
o`000?oooooooooo00?ooooo00?o0000oiVIVOnIVIT02_nIVIT00ol0003o/k>cok>c/`0Gok>c/`03
o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03
o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02OmVIVH00ol0003oOgmoogmoO`04ogmoO`03
o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<04onc/k<00ol0003oVIVIoiVIV@02oiVIV@05
o`000?moOgooOgmoogmoOol000000omVIVH00ol0003oC4a<oda<C004oda<C003o`000?lc<c?o<c<c
00Co<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Go0000
oiVIVOnIVIWoVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>c
o`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00?o0000oda<C?m<C4`00_l00007oc<c<`05
o`000?m<C4coC4a<oda<C?l000000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>c
o`0000Soc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV00Co0000oda<C?m<
C4co00002?lc<c<00ol0003oC4a<o`000002ofIVIP07o`000?moOgoo0000oiVIVOl0003o/k>co`00
0008olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000Kooooo0Ol00001
ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo3?nIVIT00ol0003o/k>cok>c/`0Gok>c
/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIV
IP;o00005om<C4`2o`0000_oIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@04oiVI
V@03o`000?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo
000000?oIVIV00?o0000oda<C?m<C4`01?m<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4co
C4a<00;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVIVOl00000
0onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003o
OgmoogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Go0000oda<C?m<C4coC4a<o`00
0002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`02?l0003o/k>c
ok>c/ol0003oVIVIo`000?moOgoo00000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`03o`000?m<
C4co000000;oIVIV00Oo0000ogmoOol0003oVIVIo`000?nc/k?o000000Soc<c<00[o0000ok>c/onc
/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00001_ooool1o`00007ooooo0Oooool002Cooooo00?o
0000ooooooooool00oooool;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02onI
VIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<
C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00CoOgmo00?o0000oiVIVOnIVIT01?nI
VIT00ol0003o/k>cok>c/`0Cok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomoOgooOgmo
o`000004ofIVIP03o`000?m<C4coC4a<00?oC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<
oda<C003oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000003ok>c
/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgoo
Ogmoo`0000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<01?l0003oC4a<oda<C?l00002ofIVIP03
o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01?l0003o/k>cok>c/ol00002
oiVIV@;o00000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo
0000ogmoOol0003oVIVIo`000?nc/k?o00002?o<c<`02ol0003o/k>cok>c/ol0003oVIVIo`000?mo
Ogoo0000ofIVI_l0003oC4a<00Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo
00?ooooo2_nIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmo
OomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIV
I_mVIVH02omVIVH00ol0003oOgmoogmoO`04ogmoO`;o00001OnIVIT00ol0003o/k>cok>c/`0Cok>c
/`03o`000?nIVIWoVIVI00;oVIVI00?o0000ogmoOomoOgl00_moOgl01Ol0003oIVIVofIVI_mVIVKo
000000GoC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C003oda<C005o`000?mVIVKo
IVIVofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Koc<c<
00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Co0000oda<
C?m<C4co00002Olc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00?o0000oiVIVOl00000
0onc/k<00ol0003oc<c<olc<c006olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002
ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00?o0000oda<C?l000000_mVIVH01ol0003oOgmoo`00
0?nIVIWo0000ok>c/ol000002?o<c<`02ol0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIV
I_l0003oC4a<00Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo2_nI
VIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?mo
Ogl00ol0003oIVIVofIVIP0;ofIVIP;o00005om<C4`2o`0000coIVIV00?o0000ogmoOomoOgl01Omo
Ogl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT00_nI
VIT01Ol0003oOgmoogmoOomoOgoo000000CoIVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o<c<c
oc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`04
o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o
000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`06o`00
0?m<C4coC4a<o`000?mVIVKo00000_moOgl00ol0003oVIVIo`000003ok>c/`03o`000?o<c<coc<c<
00Koc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV00?o0000oda<C?l00000
2Olc<c<00ol0003oC4a<o`000002ofIVIP07o`000?moOgoo0000oiVIVOl0003o/k>co`000008olc<
c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co00001Oooool1o`00
007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool8oiVIV@;o00005onc/k<2o`0000go
VIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01Ko
C4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00Co
VIVI00?o0000ok>c/onc/k<04onc/k<00ol0003oVIVIoiVIV@02oiVIV@03o`000?moOgooOgmo00;o
Ogmo00Go0000ofIVI_mVIVKoIVIVo`000005oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<
C?m<C4`00om<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo00001?nc
/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmo
ogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000Wo<c<c00Ko0000oda<C?m<C4co0000ofIVI_l0
0002ogmoO`04o`000?nIVIWoVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02?l0003o/k>c
ok>c/ol0003oVIVIo`000?moOgoo00000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`03o`000?m<
C4co000000;oIVIV00Oo0000ogmoOol0003oVIVIo`000?nc/k?o000000Woc<c<00?o0000ok>c/ol0
00000_nIVIT2o`000005ofIVI_l0003oC4a<oda<C?l000001Oooool1o`00007ooooo0Oooool001Wo
oooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo00?ooooo1onIVIT00ol0
003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl02?moOgl00ol0
003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0
003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<04onc/k<00ol0
003oVIVIoiVIV@03oiVIV@05o`000?moOgooOgmoogmoOol000000omVIVH00ol0003oC4a<oda<C004
oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00om<C4`01?l0003oIVIVofIVI_l0
0003ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>c
ok>c/`02ok>c/`06o`000?nIVIWoVIVIo`000?moOgoo00000_mVIVH01Ol0003oC4a<oda<C?m<C4co
000000So<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00?o0000oiVIVOl00000
0_nc/k<00ol0003oc<c<olc<c007olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002
ofIVIP03o`000?m<C4co000000Wo<c<c00?o0000oda<C?l000000_mVIVH01ol0003oOgmoo`000?nI
VIWo0000ok>c/ol000002Oo<c<`02ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<
C4co000000Kooooo0Ol00001ooooo`7ooooo000Iooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_oo
ool00ol0003oooooooooo`03ooooo`OoVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVI
V@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH03?mVIVH00ol0003oC4a<oda<
C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl01?moOgl00ol0003oVIVIoiVI
V@05oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT00onIVIT01Ol0003oOgmoogmo
OomoOgoo000000?oIVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`05oc<c<`03o`00
0?m<C4coC4a<00?oC4a<00Co0000ofIVI_mVIVKo00000omoOgl01?l0003oVIVIoiVIVOl00004ok>c
/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01_l0003oVIVIoiVIVOl0003o
Ogmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`07o`000?m<C4coC4a<oda<C?l0
003oIVIVo`000002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`02?l0
003o/k>cok>c/ol0003oVIVIo`000?moOgoo00000_mVIVH00ol0003oC4a<o`000009oc<c<`03o`00
0?m<C4co000000;oIVIV00Oo0000ogmoOol0003oVIVIo`000?nc/k?o000000Woc<c<00_o0000ok>c
/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`000006ooooo`7o00000Oooool1ooooo`00
6Oooool01Ol0003ooooooooooooooooo000000Kooooo0ol00003ooooo`KoVIVI00?o0000ok>c/onc
/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mV
IVH03?mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomo
Ogl01OmoOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c01Co/k>c00?o0000oiVIVOnI
VIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000CoIVIV00?o0000oda<C?m<C4`00om<C4`00ol0
003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Co0000ofIVI_mVIVKo00000omoOgl0
1Ol0003oVIVIoiVIVOnIVIWo000000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`01Ol0003o/k>cok>c
/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01Ol0003oC4a<oda<C?m<C4co0000
00So<c<c00Co0000oda<C?m<C4co00000_mVIVH01_l0003oOgmoogmoOol0003oVIVIo`0000;o/k>c
00?o0000olc<c?o<c<`01oo<c<`02?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo00000_mVIVH0
0ol0003oC4a<o`000009oc<c<`05o`000?m<C4co0000ofIVI_l000000_moOgl01Ol0003oVIVIo`00
0?nc/k?o000000Soc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<
C?l00004ooooo`?o00000_ooool001Wooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`03o`00
0?oooooooooo00?ooooo1OnIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI
00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<
00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00GoVIVI
00?o0000ok>c/onc/k<04onc/k<00ol0003oVIVIoiVIV@03oiVIV@05o`000?moOgooOgmoogmoOol0
00000omVIVH00ol0003oC4a<oda<C004oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<
C4`00om<C4`01?l0003oIVIVofIVI_l00003ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000
olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`06o`000?nIVIWoVIVIo`000?moOgoo0000
0_mVIVH00ol0003oC4a<oda<C002oda<C003o`000?lc<c?o<c<c00Go<c<c00Oo0000oda<C?m<C4co
C4a<o`000?mVIVKo000000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<
c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000So
<c<c00?o0000oda<C?l000000_mVIVH01ol0003oOgmoo`000?nIVIWo0000ok>c/ol000002Oo<c<`0
3?l0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co0000oc<c<`Kooooo0Ol00001
ooooo`7ooooo000Iooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`03
ooooo`CoVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgoo
Ogmo00WoOgmo00?o0000ofIVI_mVIVH02_mVIVH2o`0001OoC4a<0_l0000=ofIVIP03o`000?moOgoo
Ogmo00GoOgmo0_l00006oiVIV@03o`000?nc/k?o/k>c01Co/k>c00?o0000oiVIVOnIVIT00_nIVIT0
1Ol0003oOgmoogmoOomoOgoo000000CoIVIV00?o0000oda<C?m<C4`01?m<C4`00ol0003o<c<coc<c
<`03oc<c<`03o`000?m<C4coC4a<00?oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`05o`00
0?nIVIWoVIVIoiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c
/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc
<c<01ol0003oC4a<oda<C?m<C4co0000ofIVI_l000000_moOgl00ol0003oVIVIo`000002ok>c/`03
o`000?o<c<coc<c<00Ooc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV00Co
0000oda<C?m<C4co00002?lc<c<00ol0003oC4a<o`000002ofIVIP07o`000?moOgoo0000oiVIVOl0
003o/k>co`000008olc<c00=o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<
C4co0000oc<c<`06ooooo`7o00000Oooool1ooooo`006Oooool00omEEEGoQhN7ooooo`08ooooo`03
o`000?oooooooooo00?ooooo0onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_o
VIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01Ko
C4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00Ko
VIVI00?o0000ok>c/onc/k<05?nc/k<00ol0003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmo
Ool000001?mVIVH00ol0003oC4a<oda<C004oda<C003o`000?lc<c?o<c<c00?o<c<c00?o0000oda<
C?m<C4`00om<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo00001?nc
/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmo
ogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01ol0003oC4a<oda<C?m<C4co
0000ofIVI_l000000_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00So
0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<0
0ol0003oC4a<o`000002ofIVIP07o`000?moOgoo0000oiVIVOl0003o/k>co`000008olc<c00=o`00
0?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co0000oc<c<`06ooooo`7o0000
0Oooool1ooooo`006Oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo00?ooooo0_nI
VIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02Omo
Ogl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omV
IVH00ol0003oOgmoogmoO`06ogmoO`03o`000?nIVIWoVIVI00GoVIVI00?o0000ok>c/onc/k<05?nc
/k<00ol0003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol000001?mVIVH00ol0003oC4a<
oda<C004oda<C003o`000?lc<c?o<c<c00?o<c<c00?o0000oda<C?m<C4`00om<C4`01Ol0003oIVIV
ofIVI_mVIVKo000000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000003ok>c/`03o`000?o<c<coc<c<
00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Go
0000oda<C?m<C4coC4a<o`000008oc<c<`07o`000?m<C4coC4a<oda<C?l0003oIVIVo`000002ogmo
O`03o`000?nIVIWo000000;o/k>c0_l00008olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmo
Ool00002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00co0000oda<C?m<C4co0000ofIVI_l0003o
Ogmoo`000?nIVIWo0000ok>c/ol00008olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0
003oIVIVo`000?m<C4co00000_lc<c<6ooooo`7o00000Oooool1ooooo`006_ooool01?o<c<coA4A4
o`000?l@4106ooooo`03o`000?oooooooooo00?ooooo00?oVIVIo`000?nc/k<05onc/k<00ol0003o
VIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02_mVIVH2o`0001Oo
C4a<0_l0000=ofIVIP03o`000?moOgooOgmo00KoOgmo00?o0000oiVIVOnIVIT01OnIVIT00ol0003o
/k>cok>c/`0Dok>c/`03o`000?nIVIWoVIVI00;oVIVI00?o0000ogmoOomoOgl00_moOgl01Ol0003o
IVIVofIVI_mVIVKo000000KoC4a<00?o0000oc<c<olc<c<00olc<c<00ol0003oC4a<oda<C004oda<
C004o`000?mVIVKoIVIVo`0000?oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<
c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP05
o`000?m<C4coC4a<oda<C?l000002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP06o`000?moOgoo
Ogmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c009o`000?nc/k?o/k>cok>c/ol0
003oVIVIo`000?moOgoo000000;oIVIV00?o0000oda<C?l000002Olc<c<00ol0003oC4a<o`000002
ofIVIP07o`000?moOgoo0000oiVIVOl0003o/k>co`000008olc<c00<o`000?nc/k?o/k>co`000?nI
VIWo0000ogmoOol0003oIVIVo`000?m<C4co00000_lc<c<6ooooo`7o00000Oooool1ooooo`009?oo
ool00ol0003oooooooooo`03ooooo`03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onI
VIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<
C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00KoOgmo00?o0000oiVIVOnIVIT01_nI
VIT00ol0003o/k>cok>c/`0Cok>c/`03o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl00_mo
Ogl01Ol0003oIVIVofIVI_mVIVKo000000GoC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<
oda<C003oda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01?l0003oVIVIoiVIVOl00004ok>c
/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@06o`000?moOgoo
Ogmoo`000?mVIVKo00001?m<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;o
IVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00008olc<c00;o`000?nc/k?o/k>c
ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`03
o`000?m<C4co000000;oIVIV00Oo0000ogmoOol0003oVIVIo`000?nc/k?o000000Soc<c<00co0000
ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00002oc<c<`Kooooo0Ol00001
ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo6?nc/k<00ol0003oVIVIoiVIV@0;oiVI
V@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<
C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl01_moOgl00ol0003oVIVIoiVIV@06oiVI
V@03o`000?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`02ogmo
O`05o`000?mVIVKoIVIVofIVI_l000001_m<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4co
C4a<00?oC4a<00Co0000ofIVI_mVIVKo00000omoOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`00
0?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`00
00;oIVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Ko
0000ogmoOomoOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Wo0000ok>c/onc
/k?o/k>co`000?nIVIWo0000ogmoOol000000_mVIVH00ol0003oC4a<o`000009oc<c<`03o`000?m<
C4co000000;oIVIV00Oo0000ogmoOol0003oVIVIo`000?nc/k?o000000Woc<c<00?o0000ok>c/ol0
00000_nIVIT2o`000005ofIVI_l0003oC4a<oda<C?l000000_lc<c<6ooooo`7o00000Oooool1oooo
o`009?ooool00ol0003oooooooooo`03oooooaOo/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003o
OgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00[oIVIV0_l0000Goda<C0;o00003OmVIVH00ol0003o
OgmoogmoO`07ogmoO`03o`000?nIVIWoVIVI00GoVIVI00?o0000ok>c/onc/k<05?nc/k<00ol0003o
VIVIoiVIV@02oiVIV@03o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003o
C4a<oda<C004oda<C003o`000?lc<c?o<c<c00?o<c<c00?o0000oda<C?m<C4`00om<C4`01Ol0003o
IVIVofIVI_mVIVKo000000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<co
c<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mV
IVKoIVIVo`0000;oC4a<0_l00008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol0
00000_nIVIT01?l0003o/k>cok>c/ol00008olc<c009o`000?nc/k?o/k>cok>c/ol0003oVIVIo`00
0?moOgoo000000;oIVIV00?o0000oda<C?l000002Olc<c<00ol0003oC4a<o`000002ofIVIP07o`00
0?moOgoo0000oiVIVOl0003o/k>co`000009olc<c00;o`000?nc/k?o0000oiVIVOl0003oOgmoo`00
0?mVIVKo0000oda<C?l000000olc<c<6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003ooooo
ooooo`03oooooaKo/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`00
0?mVIVKoIVIV00[oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`00
0?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`0Dok>c/`03o`00
0?nIVIWoVIVI00;oVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP02ofIVIP03o`00
0?m<C4coC4a<00CoC4a<00?o0000oc<c<olc<c<00olc<c<00ol0003oC4a<oda<C003oda<C005o`00
0?mVIVKoIVIVofIVI_l000000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Co/k>c00?o0000olc<
c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co0000
ofIVI_mVIVKo00000_m<C4`00ol0003o<c<coc<c<`07oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV
00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00008olc<c009o`000?nc/k?o/k>cok>c
/ol0003oVIVIo`000?moOgoo000000;oIVIV00?o0000oda<C?l000002Olc<c<00ol0003oC4a<o`00
0002ofIVIP07o`000?moOgoo0000oiVIVOl0003o/k>co`000009olc<c00;o`000?nc/k?o0000oiVI
VOl0003oOgmoo`000?mVIVKo0000oda<C?l000000olc<c<6ooooo`7o00000Oooool1ooooo`009?oo
ool00ol0003oooooooooo`03oooooaGo/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmo
O`08ogmoO`;o00003?mVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00_oIVIV00?o
0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c01Co/k>c00?o
0000oiVIVOnIVIT00_nIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o
0000oda<C?m<C4`01?m<C4`00ol0003o<c<coc<c<`03oc<c<`03o`000?m<C4coC4a<00?oC4a<00Go
0000ofIVI_mVIVKoIVIVo`000003ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<
c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co0000ofIV
I_mVIVKo00000_m<C4`00ol0003o<c<coc<c<`07oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o
0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00008olc<c009o`000?nc/k?o/k>cok>c/ol0
003oVIVIo`000?moOgoo000000;oIVIV00?o0000oda<C?l000002Olc<c<00ol0003oC4a<o`000002
ofIVIP07o`000?moOgoo0000oiVIVOl0003o/k>co`000009olc<c003o`000?nc/k?o/k>c00;o0000
00CoOgmoo`000?mVIVKoIVIV0_l00004oc<c<`Kooooo0Ol00001ooooo`7ooooo000Tooooo`;o0000
1?oooolCok>c/`;o00003OnIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV
00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00OoOgmo
00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`0Dok>c/`03o`000?nIVIWoVIVI00?oVIVI
00Go0000ogmoOomoOgooOgmoo`000004ofIVIP03o`000?m<C4coC4a<00CoC4a<00?o0000oc<c<olc
<c<00olc<c<00ol0003oC4a<oda<C004oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01Ol0
003oVIVIoiVIVOnIVIWo000000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`01Ol0003o/k>cok>c/onc
/k?o000000?oVIVI00?o0000ogmoOol000000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c
00Go0000oda<C?m<C4coC4a<o`000002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc
/k?o00002?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<
C4`00ol0003o<c<coc<c<`07oc<c<`03o`000?m<C4co000000;oIVIV00Oo0000ogmoOol0003oVIVI
o`000?nc/k?o000000Soc<c<0_l000002_nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<
C?l00004oc<c<`Gooooo0_l00002ooooo`009?ooool00ol0003oooooooooo`03oooooa;o/k>c00?o
0000oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o
0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o
0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`0Cok>c/`03o`000?nIVIWoVIVI00CoVIVI00Go
0000ogmoOomoOgooOgmoo`000004ofIVIP03o`000?m<C4coC4a<00CoC4a<00?o0000oc<c<olc<c<0
0_lc<c<00ol0003oC4a<oda<C005oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01Ol0003o
VIVIoiVIVOnIVIWo000000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`01Ol0003o/k>cok>c/onc/k?o
000000?oVIVI00?o0000ogmoOol000000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Go
0000oda<C?m<C4coC4a<o`000002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o
00002?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`0
0ol0003o<c<coc<c<`07oc<c<`03o`000?m<C4co000000;oIVIV00Oo0000ogmoOol0003oVIVIo`00
0?nc/k?o000000Soc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<
C?l00004oc<c<`Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo4_nc
/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omV
IVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?mo
Ogl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c01Co/k>c00?o0000oiVIVOnIVIT00onI
VIT01Ol0003oOgmoogmoOomoOgoo000000CoIVIV00?o0000oda<C?m<C4`01?m<C4`00ol0003o<c<c
oc<c<`03oc<c<`03o`000?m<C4coC4a<00CoC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`05
o`000?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0003oc<c<olc<c005olc<c005o`000?nc/k?o/k>c
ok>c/ol000000onIVIT00ol0003oOgmoo`000002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc
<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>c
ok>c/ol00009olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<
00?o0000oc<c<olc<c<01olc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0
0002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/ol0003oVIVIo`000002ogmoO`;o0000
0_m<C4`00ol0003o<c<coc<c<`02oc<c<`Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oo
oooooooo00?ooooo4Onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o
0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00[oIVIV0_l0
000:ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc/k<05?nc/k<00ol0003oVIVIoiVI
V@03oiVIV@03o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<
C004oda<C003o`000?lc<c?o<c<c00;o<c<c00?o0000oda<C?m<C4`01?m<C4`01Ol0003oIVIVofIV
I_mVIVKo000000?oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c006olc<c005
o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP05o`000?m<C4co
C4a<oda<C?l000002?lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o0000ogmoOol00000
0_nIVIT01?l0003o/k>cok>c/ol00008olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Go0000ogmo
Ool0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00?o0000oda<C?l000000_mVIVH0
1ol0003oOgmoo`000?nIVIWo0000ok>c/ol000002Oo<c<`02Ol0003o/k>co`000?nIVIWo0000ogmo
Ool0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00;o<c<c1_ooool1o`00007ooooo0Oooool0
02Cooooo00?o0000ooooooooool00oooool@ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmo
OomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIV
I_mVIVH02_mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c
/onc/k<05Onc/k<00ol0003oVIVIoiVIV@02oiVIV@03o`000?moOgooOgmo00?oOgmo00?o0000ofIV
I_mVIVH00_mVIVH00ol0003oC4a<oda<C004oda<C003o`000?lc<c?o<c<c00;o<c<c00?o0000oda<
C?m<C4`01?m<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Co0000oiVIVOnIVIWo00001?nc
/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmo
ogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01Ol0003oC4a<oda<C?m<C4co
000000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00008olc<c004o`000?nc
/k?o/k>co`0000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo
<c<c00?o0000oda<C?l000000_mVIVH01ol0003oOgmoo`000?nIVIWo0000ok>c/ol000002Oo<c<`0
2Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00;o
<c<c1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool?ok>c/`03o`00
0?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`00
0?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`00
0?nIVIWoVIVI00OoVIVI00?o0000ok>c/onc/k<05?nc/k<00ol0003oVIVIoiVIV@02oiVIV@03o`00
0?moOgooOgmo00?oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C004oda<C003o`00
0?lc<c?o<c<c00;o<c<c00?o0000oda<C?m<C4`01?m<C4`00ol0003oIVIVofIVIP02ofIVIP04o`00
0?moOgooOgmoo`0000;oVIVI00?o0000ok>c/onc/k<00_nc/k<00ol0003oc<c<olc<c006olc<c003
o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl00ol0003oIVIVo`000003oda<
C003o`000?lc<c?o<c<c00Oo<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002
oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmo
o`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00?o0000oda<C?l000000_mVIVH01ol0003o
Ogmoo`000?nIVIWo0000ok>c/ol000002Oo<c<`00ol0003o/k>co`000002oiVIV@;o000000GoIVIV
o`000?m<C4coC4a<o`000005oc<c<`Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooo
oooo00?ooooo3_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000
ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00[oIVIV0_l0000:
ogmoO`03o`000?nIVIWoVIVI00OoVIVI00?o0000ok>c/onc/k<05?nc/k<00ol0003oVIVIoiVIV@03
oiVIV@03o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C005
oda<C003o`000?lc<c?o<c<c00;o<c<c00?o0000oda<C?m<C4`01?m<C4`01Ol0003oIVIVofIVI_mV
IVKo000000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Goc<c<
00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`00
00?oC4a<00?o0000oc<c<olc<c<01_lc<c<01ol0003oC4a<oda<C?m<C4co0000ofIVI_l000000_mo
Ogl01?l0003oVIVIoiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o
00000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0
003oC4a<oda<C?l00002ofIVIP07o`000?moOgoo0000oiVIVOl0003o/k>co`000009olc<c009o`00
0?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<00olc<c<6
ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`go/k>c00?o0000oiVI
VOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV0_l0000Goda<
C0;o00003?mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00SoVIVI00?o0000ok>c
/onc/k<05?nc/k<00ol0003oVIVIoiVIV@03oiVIV@03o`000?moOgooOgmo00;oOgmo00?o0000ofIV
I_mVIVH00_mVIVH00ol0003oC4a<oda<C005oda<C005o`000?lc<c?o<c<coc<c<ol000001om<C4`0
1Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`00
0?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04
o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01ol0003oC4a<oda<C?m<C4co
0000ofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<
00Co0000ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c
<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP07o`000?moOgoo0000oiVIVOl0003o/k>c
o`000009olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000
oc<c<olc<c<00olc<c<6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03oooo
o`co/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV
00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo
00WoOgmo00?o0000oiVIVOnIVIT02?nIVIT00ol0003o/k>cok>c/`0Dok>c/`03o`000?nIVIWoVIVI
00?oVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP02ofIVIP03o`000?m<C4coC4a<
00GoC4a<00?o0000oc<c<olc<c<00_lc<c<00ol0003oC4a<oda<C004oda<C005o`000?mVIVKoIVIV
ofIVI_l000000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Co/k>c00?o0000olc<c?o<c<`01_o<
c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01Ol0003o
C4a<oda<C?m<C4co000000So<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00Co
0000oiVIVOnIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`0000;o
VIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00?o0000oda<
C?l000000_mVIVH01ol0003oOgmoo`000?nIVIWo0000ok>c/ol000002Oo<c<`01ol0003o/k>co`00
0?nIVIWo0000ogmoOol000000_mVIVH00ol0003oC4a<o`000006oc<c<`Kooooo0Ol00001ooooo`7o
oooo000Tooooo`03o`000?oooooooooo00?ooooo2onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`00
0?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`00
0?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@08oiVIV@03o`00
0?nc/k?o/k>c01Co/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`02ogmoO`;o0000
0omVIVH00ol0003oC4a<oda<C005oda<C003o`000?lc<c?o<c<c00;o<c<c00?o0000oda<C?m<C4`0
1?m<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Go0000oiVIVOnIVIWoVIVIo`000004ok>c
/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002
ogmoO`04o`000?mVIVKoIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01olc<c<01?l0003oC4a<oda<
C?l00002ofIVIP06o`000?moOgooOgmoo`000?nIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<
c004o`000?nc/k?o/k>co`0000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc
<c?o<c<c00Oo<c<c00Co0000oda<C?l0003oIVIV0_l000001_moOgoo0000oiVIVOl0003o/k>co`00
00Woc<c<00_o0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`000007oc<c<`Ko
oooo0Ol00001ooooo`7ooooo000Tooooo`;o00001?ooool:ok>c/`03o`000?nIVIWoVIVI00_oVIVI
00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP;o00005om<C4`2o`0000goIVIV
00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@08oiVIV@03o`000?nc/k?o/k>c01Go/k>c
00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00;oIVIV
00?o0000oda<C?m<C4`01Om<C4`00ol0003o<c<coc<c<`02oc<c<`03o`000?m<C4coC4a<00CoC4a<
00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000onc/k<00ol0
003oc<c<olc<c006olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl0
1?l0003oIVIVofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Co0000oda<C?m<C4co0000
0_mVIVH01_l0003oOgmoogmoOol0003oVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0
003o/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c
<`07oc<c<`05o`000?m<C4co0000ofIVI_l000000_moOgl01Ol0003oVIVIo`000?nc/k?o000000So
c<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00007oc<c<`Go
oooo0_l00002ooooo`009?ooool00ol0003oooooooooo`03ooooo`So/k>c0_l0000=oiVIV@03o`00
0?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`00
0?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@08oiVIV@03o`00
0?nc/k?o/k>c01Go/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`02ogmoO`03o`00
0?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01_m<C4`01Ol0003o<c<coc<c<olc<c?o000000Ko
C4a<00?o0000ofIVI_mVIVH00_mVIVH01?l0003oOgmoogmoOol00003oiVIV@03o`000?nc/k?o/k>c
00;o/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVI
o`0000;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<
C4coC4a<o`0000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01?l0003o/k>cok>c/ol00009olc<
c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc
<c<01olc<c<00ol0003oC4a<oda<C002o`0000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003o
c<c<olc<c006olc<c005o`000?nc/k?o0000oiVIVOl000000_moOgl2o`0000;oC4a<00?o0000oc<c
<olc<c<01Olc<c<6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`Oo
/k>c00?o0000oiVIVOnIVIT02onIVIT2o`0000[oOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003o
C4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV0_l0000:ogmoO`03o`000?nIVIWoVIVI00So
VIVI00?o0000ok>c/onc/k<05Onc/k<00ol0003oVIVIoiVIV@03oiVIV@03o`000?moOgooOgmo00;o
Ogmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C005oda<C005o`000?lc<c?o<c<coc<c
<ol000001om<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo0_l00002oiVIV@03o`000?nc/k?o
/k>c00;o/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`03o`000?nIVIWo
VIVI00;o000000?oOgmoo`000?mVIVH00_mVIVH01Ol0003oC4a<oda<C?m<C4co000000Oo<c<c0_l0
0002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00?o0000oiVIVOl000000onc/k<00ol0003oc<c<
olc<c006olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<
C003o`000?lc<c?o<c<c00Ko<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`05o`000?nI
VIWo0000ok>c/ol000002Oo<c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002
oda<C003o`000?lc<c?o<c<c00Go<c<c1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000oooo
ooooool00oooool7ok>c/`03o`000?nIVIWoVIVI00[oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0
003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0
003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00SoVIVI00?o0000ok>c/onc/k<05Onc/k<00ol0
003oVIVIoiVIV@03oiVIV@03o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0
003oC4a<oda<C005oda<C005o`000?lc<c?o<c<coc<c<ol000001om<C4`01Ol0003oIVIVofIVI_mV
IVKo000000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Goc<c<
00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`05o`000?mVIVKoIVIVofIV
I_l000000om<C4`00ol0003o<c<coc<c<`05oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH0
1_l0003oOgmoogmoOol0003oVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>c
ok>c/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c
<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl01Ol0003oVIVIo`000?nc/k?o000000Woc<c<
00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`05
oc<c<`Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo1_nc/k<00ol0
003oVIVIoiVIV@0:oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH03?mVIVH00ol0
003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0
003oVIVIoiVIV@09oiVIV@03o`000?nc/k?o/k>c01Co/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0
003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<C4`01Om<C4`01Ol0
003o<c<coc<c<olc<c?o000000OoC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`05o`000?nI
VIWoVIVIoiVIVOl000001?nc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c
00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c
00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000
ok>c/onc/k?o00002Oo<c<`02?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo00000_mVIVH01?l0
003oC4a<oda<C?l00008oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVIV@03
o`000?nc/k?o000000Woc<c<00Co0000ok>c/ol0003o00000_moOgl00ol0003oIVIVo`000002oda<
C003o`000?lc<c?o<c<c00Go<c<c1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000oooooooo
ool00oooool5ok>c/`03o`000?nIVIWoVIVI00[oVIVI00?o0000ogmoOomoOgl02_moOgl00ol0003o
IVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003o
OgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00WoVIVI00?o0000ok>c/onc/k<05?nc/k<00ol0003o
VIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003o
C4a<oda<C005oda<C005o`000?lc<c?o<c<coc<c<ol000001_m<C4`00ol0003oIVIVofIVIP02ofIV
IP04o`000?moOgooOgmoo`0000?oVIVI00?o0000ok>c/onc/k<00_nc/k<00ol0003oc<c<olc<c005
olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01Ol0003oIVIVofIV
I_mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C003o`00
0?mVIVKo000000;oOgmo00?o0000oiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c004o`00
0?nc/k?o/k>co`0000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c
00Ko<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`05o`000?nIVIWo0000ok>c/ol00000
2Oo<c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o
<c<c00Ko<c<c00?o0000ooooooooool00oooool1o`00007ooooo0Oooool002Cooooo00?o0000oooo
ooooool00oooool4ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0
003oIVIVofIVIP0:ofIVIP;o00005om<C4`2o`0000goIVIV00?o0000ogmoOomoOgl02?moOgl2o`00
00_oVIVI00?o0000ok>c/onc/k<05Onc/k<00ol0003oVIVIoiVIV@03oiVIV@03o`000?moOgooOgmo
00?oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C005oda<C0;o00000_lc<c<00ol0
003oC4a<oda<C005oda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01Ol0003oVIVIoiVIVOnI
VIWo000000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nI
VIWoVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`05
o`000?m<C4coC4a<oda<C?l000000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>c
o`0000Woc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`03o`000?mVIVKo000000;oC4a<
00?o0000oc<c<olc<c<01_lc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00Go0000oiVI
VOl0003o/k>co`000009olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000;o
C4a<00?o0000oc<c<olc<c<01_lc<c<00ol0003oooooooooo`03ooooo`7o00000Oooool1ooooo`00
9?ooool00ol0003oooooooooo`03ooooo`?o/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmo
ogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIV
ofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02_nIVIT00ol0003o/k>c
ok>c/`0Fok>c/`03o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIV
ofIVIP02ofIVIP03o`000?m<C4coC4a<00GoC4a<00Go0000oda<C?l0003o<c<co`000007oda<C005
o`000?mVIVKoIVIVofIVI_l000000omoOgl01Ol0003oVIVIoiVIVOnIVIWo000000Co/k>c00?o0000
olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co
0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l0
00000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Woc<c<00Ko0000ok>c
/onc/k?o0000oiVIVOl00002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc
<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00Go0000oiVIVOl0003o/k>co`000009olc<
c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<0
1_lc<c<00ol0003oooooooooo`03ooooo`7o00000Oooool1ooooo`009?ooool00ol0003ooooooooo
o`03ooooo`;o/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mV
IVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?mo
OgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Eok>c/`03o`000?nI
VIWoVIVI00?oVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIVIP02ofIVIP03o`000?m<
C4coC4a<00KoC4a<0_l000000om<C4co0000oda<C006oda<C003o`000?mVIVKoIVIV00;oIVIV00Co
0000ogmoOomoOgoo00000onIVIT00ol0003o/k>cok>c/`02ok>c/`03o`000?o<c<coc<c<00Goc<c<
00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`00
00?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o0000
ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00009olc<c004o`000?nc/k?o/k>co`0000;oVIVI
00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00?o0000oda<C?l0
00000_mVIVH01ol0003oOgmoo`000?nIVIWo0000ok>c/ol000002Oo<c<`01ol0003o/k>co`000?nI
VIWo0000ogmoOol000000_mVIVH00ol0003oC4a<o`000008oc<c<`03o`000?oooooooooo00Cooooo
0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo00?o/k>co`000?nIVIT03?nI
VIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00[oIVIV0_l0000Goda<C0;o00003OmV
IVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05Onc
/k<00ol0003oVIVIoiVIV@03oiVIV@03o`000?moOgooOgmo00;oOgmo0_l00004ofIVIP03o`000?m<
C4coC4a<00KoC4a<00Co0000oc<c<olc<c?o00002?m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;o
Ogmo00Go0000oiVIVOnIVIWoVIVIo`000005ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c
/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o
0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o0000ogmoOol00000
0_nIVIT01?l0003o/k>cok>c/ol00008olc<c0;o00000_nc/k<00ol0003oVIVIo`000002ogmoO`03
o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01olc<c<01Ol0003oC4a<o`000?mVIVKo0000
00;oOgmo00Go0000oiVIVOl0003o/k>co`000009olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmo
o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<00ol0003oooooooooo`04ooooo`7o
00000Oooool1ooooo`009?ooool2o`0000Cooooo00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmo
ogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIV
ofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>c
ok>c/`0Eok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIV
ofIVIP03ofIVIP03o`000?m<C4coC4a<00KoC4a<00Co0000oc<c<olc<c?o00001om<C4`00ol0003o
IVIVofIVIP02ofIVIP04o`000?moOgooOgmoo`0000?oVIVI00?o0000ok>c/onc/k<00onc/k<00ol0
003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl0
1?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<
C4`01_l0003oIVIVofIVI_l0003oOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01ol0
003o/k>cok>c/onc/k?o0000oiVIVOl000000_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc
<c?o<c<c00Oo<c<c00Go0000oda<C?l0003oIVIVo`000002ogmoO`05o`000?nIVIWo0000ok>c/ol0
00002?o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`00
0?lc<c?o<c<c00Ko<c<c00?o0000ooooooooool00oooool2o`0000;ooooo000Tooooo`03o`000?oo
oooooooo00?ooooo3OnIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o
0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o
0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Eok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o
0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<00KoC4a<00Co
0000oc<c<olc<c?o00001om<C4`00ol0003oIVIVofIVIP02ofIVIP04o`000?moOgooOgmoo`0000Co
VIVI00?o0000ok>c/onc/k<00_nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o
/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o
<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP06o`000?moOgooOgmoo`000?nIVIWo
00000onc/k<00ol0003oc<c<olc<c005olc<c007o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000002
ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01olc<c<01Ol0003oC4a<o`000?mV
IVKo000000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c009o`000?nc
/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<00ol0
003oC4a<ooooo`05ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`co
VIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0:ofIVIP;o00005om<C4`2o`0000go
IVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Go
/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00;o
IVIV00?o0000oda<C?m<C4`01om<C4`3o`0000SoC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmo
O`05o`000?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o
/k>c00;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<
00?o0000oc<c<olc<c<01_lc<c<01ol0003oC4a<oda<C?m<C4co0000ofIVI_l000000_moOgl01?l0
003oVIVIoiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Oo0000ok>c/onc/k?o/k>co`00
0?nIVIWo000000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`08o`00
0?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVIV@03o`000?nc/k?o000000Woc<c<00Wo0000
ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`03
o`000?m<C4co000000Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo
2onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00[oIVIV00?o0000oda<C?m<C4`0
5om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT0
2onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl0
0omoOgl00ol0003oIVIVofIVIP02ofIVIP03o`000?m<C4coC4a<01;oC4a<00Co0000ofIVI_mVIVKo
00001?moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0
003o/k>cok>c/`02ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01?l0003oIVIVofIVI_l0
0003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo000000;o
Ogmo00Co0000oiVIVOnIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c007o`000?nc/k?o/k>c
ok>c/ol0003oVIVIo`000002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc
<c<02?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo00000_nIVIT00ol0003o/k>co`000009olc<
c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<0
1_lc<c<00ol0003oC4a<o`000005ooooo`7o00000Oooool1ooooo`009?ooool00ol0003ooooooooo
o`03ooooo`[oVIVI00?o0000ogmoOomoOgl02?moOgl2o`0000coIVIV00?o0000oda<C?m<C4`05om<
C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onI
VIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl00omo
Ogl00ol0003oIVIVofIVIP02ofIVIP03o`000?m<C4coC4a<01;oC4a<00Go0000ofIVI_mVIVKoIVIV
o`000003ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0003oc<c<olc<c005olc<c003
o`000?nc/k?o/k>c00;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`04o`000?mVIVKoIVIV
o`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01ol0003oC4a<oda<C?m<C4co0000ofIVI_l00000
0_moOgl01?l0003oVIVIoiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Ko0000ok>c/onc
/k?o0000oiVIVOl00002ogmoO`06o`000?mVIVKoIVIVo`000?m<C4co00002?lc<c<01_l0003oC4a<
oda<C?l0003oIVIVo`0000;oOgmo00Go0000oiVIVOl0003o/k>co`000009olc<c009o`000?nc/k?o
0000oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<00ol0003o
C4a<o`000006ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`WoVIVI
00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<
00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI
00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00?oOgmo
00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00Aoda<C003o`000?mVIVKoIVIV00;oIVIV
00Go0000ogmoOomoOgooOgmoo`000002oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<
c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co0000ofIV
I_mVIVKo00000om<C4`00ol0003o<c<coc<c<`07oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Co
0000ogmoOomoOgoo00000_nIVIT01?l0003o/k>cok>c/ol00009olc<c008o`000?nc/k?o/k>co`00
0?nIVIWo0000ogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Oo0000oda<C?m<C4co
0000ofIVI_l0003oOgmo00;o000000CoVIVIo`000?nc/k?o00002Oo<c<`02Ol0003o/k>co`000?nI
VIWo0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00?o0000oda<C?l0
00001_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool8oiVIV@03o`00
0?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Goda<C003o`00
0?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`00
0?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`03ogmoO`03o`00
0?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<C4`04Om<C4`00ol0003oIVIVofIVIP02ofIVIP05o`00
0?moOgooOgmoogmoOol000000_nIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00Go
c<c<00Go0000ok>c/onc/k?o/k>co`000003oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Go0000
oda<C?m<C4coC4a<o`000009oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Co0000ogmoOomoOgoo
00000_nIVIT01?l0003o/k>cok>c/ol00009olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmo
Ool00002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00So0000oda<C?m<C4co0000ofIVI_l0003o
Ogmoo`0000;oVIVI00?o0000ok>c/ol000002Oo<c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0
003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00?o0000oda<C?l000001_ooool1o`00
007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool7oiVIV@03o`000?moOgooOgmo00So
Ogmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00_o
IVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Ko
/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00?o
IVIV00?o0000oda<C?m<C4`04Om<C4`00ol0003oIVIVofIVIP02ofIVIP05o`000?moOgooOgmoogmo
Ool000000onIVIT00ol0003o/k>cok>c/`02ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c
/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo00000_m<
C4`00ol0003o<c<coc<c<`07oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Co0000ogmoOomoOgoo
00000_nIVIT01?l0003o/k>cok>c/ol00009olc<c004o`000?nc/k?o/k>co`0000;oVIVI0_l00002
ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00So0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`00
00;oVIVI00?o0000ok>c/ol000002Oo<c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIV
o`000003oda<C003o`000?lc<c?o<c<c00Go<c<c00Co0000oda<C?l0003oIVIV1_ooool1o`00007o
oooo0Oooool001Wooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo00?o
oooo1_nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<
C4`05om<C4`00ol0003oIVIVofIVIP0:ofIVIP;o00002_moOgl00ol0003oVIVIoiVIV@0;oiVIV@;o
00006?nc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00?oOgmo00?o0000ofIVI_mV
IVH00omVIVH00ol0003oC4a<oda<C00Boda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01Ol0
003oVIVIoiVIVOnIVIWo000000Go/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`02
ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00003oda<C003o`00
0?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`00
00;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?mo
Ogoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<02?l0003oC4a<oda<C?l0003oIVIVo`00
0?moOgoo00000_nIVIT00ol0003o/k>co`000009olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmo
o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<o`000?mVIVH6oooo
o`7o00000Oooool1ooooo`006Oooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000oooo
ooooool00oooool5oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0
003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00[oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0
003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT01OnIVIT00ol0
003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`04om<C4`01Ol0
003oIVIVofIVI_mVIVKo000000?oOgmo00Go0000oiVIVOnIVIWoVIVIo`000005ok>c/`03o`000?o<
c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo
00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<
C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Co
0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So
<c<c00So0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000;oVIVI00?o0000ok>c/ol000002Oo<
c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c
00Ko<c<c00Go0000oda<C?l0003oIVIVo`000005ooooo`7o00000Oooool1ooooo`006Oooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00oooool4oiVIV@03o`000?moOgoo
Ogmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKo
IVIV00[oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o
/k>c01Oo/k>c00?o0000oiVIVOnIVIT01OnIVIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKo
IVIV00?oIVIV00?o0000oda<C?m<C4`04_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Go
0000oiVIVOnIVIWoVIVIo`000005ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<0
0_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0
003o<c<coc<c<`05oc<c<`05o`000?m<C4coC4a<oda<C?l000000omVIVH00ol0003oOgmoo`000002
oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmo
o`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00So0000oda<C?m<C4co0000ofIVI_l0003o
Ogmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`02Ol0003o/k>co`000?nIVIWo0000ogmo
Ool0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00?o0000oda<C?l000000_mVIVH0
0ol0003oooooooooo`03ooooo`7o00000Oooool1ooooo`006Oooool01Olb<S;oV9RHoooooonHV9So
<S8b00Kooooo0ol00003ooooo`?oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;
ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02_mVIVH2o`0000[oOgmo00?o0000
oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00GoVIVI00?o0000
ogmoOomoOgl00omoOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<01;oC4a<00?o0000
ofIVI_mVIVH00_mVIVH01?l0003oOgmoogmoOol00004oiVIV@03o`000?nc/k?o/k>c00;o/k>c00?o
0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`05o`000?nIVIWoVIVIoiVIVOl00000
0_moOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<
C4coC4a<o`000002ofIVIP06o`000?moOgooOgmoo`000?nIVIWo00000onc/k<00ol0003oc<c<olc<
c006olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<
oda<C?l00008oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVIV@04o`000?nc
/k?o0000o`0000Soc<c<00_o0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`00
0009oc<c<`05o`000?m<C4co0000ofIVI_l000001?ooool3o`0000;ooooo000Iooooo`05olc<c?l0
003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`03ooooo`;oVIVI00?o0000ogmoOomoOgl0
2?moOgl00ol0003oIVIVofIVIP0;ofIVIP;o00005om<C4`2o`0000coIVIV00?o0000ogmoOomoOgl0
2OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT0
1_nIVIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<C4`0
4_m<C4`00ol0003oIVIVofIVIP02ofIVIP04o`000?moOgooOgmoo`0000CoVIVI00?o0000ok>c/onc
/k<00_nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Go0000oiVIVOnI
VIWoVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<0
1Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Ko0000ogmoOomoOgoo0000oiVIVOl00003ok>c/`03
o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIV
IP04o`000?m<C4coC4a<o`0000So<c<c00So0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000;o
VIVI00?o0000ok>c/ol000002Oo<c<`02ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`00
0?m<C4co000000Wo<c<c00Go0000oda<C?l0003oIVIVo`000006ooooo`7o00000Oooool1ooooo`00
6Oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool00oooool00onIVIWo
0000ogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003o
IVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o
/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00KoVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003o
IVIVofIVIP03ofIVIP03o`000?m<C4coC4a<01;oC4a<00?o0000ofIVI_mVIVH00_mVIVH01?l0003o
OgmoogmoOol00004oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0
003o/k>cok>c/`02ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01?l0003oIVIVofIVI_l0
0003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP06o`00
0?moOgooOgmoo`000?nIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>c
o`0000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH00ol0003oC4a<o`000008oc<c<`08o`000?m<
C4coC4a<o`000?mVIVKo0000ogmoOol00003oiVIV@;o00002Oo<c<`02Ol0003o/k>co`000?nIVIWo
0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00?o0000oda<C?m<C4`0
0_l000000omoOgooooooooooo`04ooooo`7o00000Oooool1ooooo`006Oooool01Ol0003o^[Zjoooo
oonj^[[o000000Kooooo00?o0000ooooooooool00oooool00ol0003oOgmoogmoO`08ogmoO`03o`00
0?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`00
0?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`00
0?nIVIWoVIVI00KoVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIVIP03ofIVIP03o`00
0?m<C4coC4a<01;oC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000?o
VIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o
/k>c00Co0000oiVIVOnIVIWo00000_moOgl2o`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008
oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH00ol0003oOgmoo`000002oiVIV@05o`000?nc
/k?o/k>cok>c/ol000002?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo000000;o
IVIV00Co0000oda<C?m<C4co00002?lc<c<01ol0003oC4a<oda<C?l0003oIVIVo`000?moOgl00_l0
00001?nIVIWo0000ok>c/ol00009olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo
000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<00ol0003oC4a<oda<C002o`000003ogmoOooooooo
oooo00Cooooo0Ol00001ooooo`7ooooo000Iooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool0
0ol0003oooooooooo`03ooooo`[oOgmo00?o0000ofIVI_mVIVH02omVIVH2o`0001OoC4a<0_l0000=
ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0G
ok>c/`03o`000?nIVIWoVIVI00OoVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIVIP03
ofIVIP03o`000?m<C4coC4a<01;oC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomo
Ogoo000000?oVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc
/k?o/k>c00?o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000?o
C4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o0000ogmo
Ool000000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Ko0000ok>c/onc/k?o0000oiVI
VOl00002ogmoO`04o`000?mVIVKoIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02?l0003o
C4a<oda<C?l0003oIVIVo`000?moOgoo00000_nIVIT00ol0003o/k>co`000009olc<c009o`000?nc
/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<00ol0
003oC4a<oda<C002o`000003ogmoOol0003ooooo00Cooooo0Ol00001ooooo`7ooooo000Tooooo`03
o`000?oooooooooo00?ooooo2OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01Ko
C4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_o
VIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@07oiVIV@03o`000?moOgooOgmo00?o
Ogmo00?o0000ofIVI_mVIVH01?mVIVH00ol0003oC4a<oda<C00Aoda<C003o`000?mVIVKoIVIV00;o
IVIV00Go0000ogmoOomoOgooOgmoo`000003oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<
c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Go0000
ofIVI_mVIVKoIVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<
o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01?l0
003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc
<c<02?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo00000_nIVIT00ol0003o/k>co`000009olc<
c003o`000?nc/k?o000000;oVIVI0_l000001OmVIVKo0000oda<C?m<C4co000000Wo<c<c00Co0000
oda<C?l0003o00000_moOgl00ol0003oooooooooo`03ooooo`7o00000Oooool1ooooo`009?ooool0
0ol0003oooooooooo`03ooooo`SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00F
oda<C003o`000?mVIVKoIVIV00_oIVIV0_l0000:ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000
ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@07oiVIV@03o`000?moOgooOgmo00?oOgmo00?o0000
ofIVI_mVIVH01?mVIVH00ol0003oC4a<oda<C00Boda<C005o`000?mVIVKoIVIVofIVI_l000000omo
Ogl00ol0003oVIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`01?o<
c<`00ol0003o/k>cok>c/`02ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01?l0003oIVIV
ofIVI_l00004oda<C003o`000?lc<c?o<c<c00Go<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIV
IP03o`000?moOgooOgmo00;o000000?oVIVIo`000?nc/k<00_nc/k<00ol0003oc<c<olc<c006olc<
c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l0
0008oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVIV@03o`000?nc/k?o0000
00Woc<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<c
oc<c<`06oc<c<`03o`000?m<C4coC4a<00;o000000?oOgmoo`000?ooool01Oooool1o`00007ooooo
0Oooool002Cooooo00?o0000ooooooooool00oooool7ogmoO`03o`000?mVIVKoIVIV00coIVIV00?o
0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o
0000oiVIVOnIVIT02_nIVIT00ol0003o/k>cok>c/`0Hok>c/`03o`000?nIVIWoVIVI00OoVIVI00?o
0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIVIP04ofIVIP03o`000?m<C4coC4a<01;oC4a<00Go
0000ofIVI_mVIVKoIVIVo`000003ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<0
0onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00;o/k>c00Go0000oiVIVOnIVIWo
VIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01Olc<c<01Ol0
003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01Ol0003o/k>cok>c
/onc/k?o000000Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIVIP04
o`000?m<C4coC4a<o`0000So<c<c00So0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000;oVIVI
00?o0000ok>c/ol000002Oo<c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002
oda<C003o`000?lc<c?o<c<c00Ko<c<c00?o0000oda<C?m<C4`00_l000000omoOgoo0000ooooo`05
ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`KoOgmo00?o0000ofIV
I_mVIVH03?mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmo
OomoOgl02OmoOgl00ol0003oVIVIoiVIV@0:oiVIV@03o`000?nc/k?o/k>c01So/k>c00?o0000oiVI
VOnIVIT01onIVIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00CoIVIV00?o0000oda<
C?m<C4`04_m<C4`00ol0003oIVIVofIVIP02ofIVIP05o`000?moOgooOgmoogmoOol000000onIVIT0
0ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00_nc/k<0
1Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<c
oc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVI
V@04o`000?nc/k?o/k>co`0000Soc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@05o`000?mo
Ogoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;o
IVIV00?o0000ogmoOol000000_nIVIT00ol0003o/k>co`000008olc<c00:o`000?nc/k?o/k>co`00
0?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<00ol0003oC4a<
oda<C002o`000003ogmoOol0003ooooo00Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oo
oooooooo00?ooooo1_moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o
0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00[oVIVI00?o
0000ok>c/onc/k<06?nc/k<00ol0003oVIVIoiVIV@07oiVIV@03o`000?moOgooOgmo00CoOgmo00?o
0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00Coda<C005o`000?mVIVKoIVIVofIVI_l00000
0omoOgl01Ol0003oVIVIoiVIVOnIVIWo000000Ko/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o
/k>cok>c/`02ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00004
oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH01?l0003oOgmoogmo
Ool00002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01?l0003o/k>cok>c/ol00002oiVI
V@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<02?l0003oC4a<oda<C?l0
003oIVIVo`000?moOgoo00000_nIVIT01?l0003o/k>cok>c/ol00008olc<c009o`000?nc/k?o0000
oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01olc<c<01?l0003oC4a<
o`000?mVIVH2o`000003oiVIVOoooooooooo00Cooooo0Ol00001ooooo`7ooooo000Tooooo`;o0000
1?ooool5ogmoO`03o`000?mVIVKoIVIV00[oIVIV0_l0000Goda<C0;o00003OmVIVH00ol0003oOgmo
ogmoO`08ogmoO`;o00003?nIVIT2o`0001Wo/k>c00?o0000oiVIVOnIVIT01onIVIT00ol0003oOgmo
ogmoO`04ogmoO`03o`000?mVIVKoIVIV00CoIVIV00?o0000oda<C?m<C4`04_m<C4`00ol0003oIVIV
ofIVIP02ofIVIP05o`000?moOgooOgmoogmoOol000000onIVIT00ol0003o/k>cok>c/`03ok>c/`03
o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00onc/k<01?l0003oVIVIoiVIVOl00002ogmo
O`;o00000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000Wo<c<c00Co0000oda<C?m<C4co00000_mV
IVH01?l0003oOgmoogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Go0000ok>c/onc
/k?o/k>co`000002oiVIV@05o`000?moOgoo0000ofIVI_l000000om<C4`00ol0003o<c<coc<c<`06
oc<c<`09o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVI00;o000000?o/k>co`000?o<
c<`01oo<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`00
0?lc<c?o<c<c00Oo<c<c00Co0000oda<C?l0003oIVIV0_l000000onIVIWoooooooooo`03ooooo`;o
00000_ooool002Cooooo00?o0000ooooooooool00oooool4ogmoO`03o`000?mVIVKoIVIV00_oIVIV
00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo
00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Hok>c/`03o`000?nIVIWoVIVI00OoVIVI
00?o0000ogmoOomoOgl01OmoOgl00ol0003oIVIVofIVIP04ofIVIP03o`000?m<C4coC4a<01;oC4a<
00Go0000ofIVI_mVIVKoIVIVo`000004ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001Onc/k<00ol0
003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Co0000oiVIVOnIVIWo00000_moOgl0
1Ol0003oIVIVofIVI_mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<
C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01?l0003o/k>cok>c/ol00008olc<
c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT2o`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`00
0008oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000
olc<c?o<c<`01_o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<
C003o`000?lc<c?o<c<c00Oo<c<c00Co0000oda<C?l0003oIVIV0_l000000onIVIWo0000ooooo`04
ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`?oOgmo00?o0000ofIV
I_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmo
OomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01So/k>c00?o0000oiVI
VOnIVIT01onIVIT00ol0003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV00CoIVIV00?o0000oda<
C?m<C4`04_m<C4`00ol0003oIVIVofIVIP02ofIVIP05o`000?moOgooOgmoogmoOol000000onIVIT0
0ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<0
1?l0003oVIVIoiVIVOl00002ogmoO`03o`000?mVIVKoIVIV00;oIVIV00Co0000oda<C?m<C4co0000
2?lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01?l0
003o/k>cok>c/ol00008olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01Ol0003oOgmoo`00
0?mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<02?l0003oC4a<oda<C?l0003oIVIVo`00
0?moOgoo00000_nIVIT00ol0003o/k>co`000008olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000
ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01olc<c<01?l0003oC4a<o`000?mVIVH2
o`0000;oVIVI00?o0000ooooooooool00oooool1o`00007ooooo0Oooool002Cooooo00?o0000oooo
ooooool00oooool2ogmoO`03o`000?mVIVKoIVIV00[oIVIV0_l0000Goda<C0;o00003OmVIVH00ol0
003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI0_l0000Hok>c/`;o00002_nIVIT00ol0
003oOgmoogmoO`04ogmoO`03o`000?mVIVKoIVIV00CoIVIV00?o0000oda<C?m<C4`04_m<C4`00ol0
003oIVIVofIVIP02ofIVIP05o`000?moOgooOgmoogmoOol000001?nIVIT00ol0003o/k>cok>c/`03
ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00onc/k<01?l0003oVIVIoiVIVOl0
0002ogmoO`05o`000?mVIVKoIVIVofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`00
0?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@04o`000?nc/k?o/k>c
o`0000Soc<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo00?o0000ofIVI_l00000
0_m<C4`00ol0003o<c<coc<c<`07oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002
oiVIV@03o`000?nc/k?o000000Soc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mV
IVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<o`000?mVIVH00_l00000
0onIVIWo0000ooooo`05ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03oooo
o`03ogmoOol0003oIVIV00coIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIV
IP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Gok>c
/`03o`000?nIVIWoVIVI00[oVIVI00?o0000ogmoOomoOgl01?moOgl00ol0003oIVIVofIVIP03ofIV
IP03o`000?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo
000000?oVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o
/k>c00?o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000?oC4a<
00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o0000ogmoOol0
00000onIVIT01?l0003o/k>cok>c/ol00008olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Ko0000
ogmoOomoOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c00So0000oda<C?m<C4co
0000ofIVI_l0003oOgmoo`0000;oVIVI00?o0000ok>c/ol000002?o<c<`02_l0003o/k>cok>c/ol0
003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<
C?m<C4co0000ofIVIP02o`000003oiVIVOl0003ooooo00Gooooo0Ol00001ooooo`7ooooo000Toooo
o`03o`000?oooooooooo00?ooooo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<
C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVI
V@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`04ogmo
O`03o`000?mVIVKoIVIV00CoIVIV00?o0000oda<C?m<C4`04om<C4`01Ol0003oIVIVofIVI_mVIVKo
000000?oOgmo00Go0000oiVIVOnIVIWoVIVIo`000006ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o
0000ok>c/onc/k<00onc/k<01?l0003oVIVIoiVIVOl00002ogmoO`05o`000?mVIVKoIVIVofIVI_l0
00001?m<C4`00ol0003o<c<coc<c<`05oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0
003oOgmoogmoOol00002oiVIV@05o`000?nc/k?o/k>cok>c/ol000001oo<c<`01ol0003o/k>cok>c
/onc/k?o0000oiVIVOl000000_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo
<c<c00So0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000;oVIVI00?o0000ok>c/ol000002Oo<
c<`00ol0003o/k>co`000002oiVIV@;o000000GoIVIVo`000?m<C4coC4a<o`000009oc<c<`06o`00
0?m<C4co0000ofIVI_l0003oOgmo0_l000000onc/k?oooooooooo`04ooooo`7o00000Oooool1oooo
o`009?ooool00ol0003oooooooooo`03ooooo`coIVIV0_l0000Goda<C0;o00003OmVIVH00ol0003o
OgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003o
VIVIoiVIV@09oiVIV@;o00001_moOgl00ol0003oIVIVofIVIP04ofIVIP03o`000?m<C4coC4a<01?o
C4a<00Go0000ofIVI_mVIVKoIVIVo`000004ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001Onc/k<0
0ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Go0000oiVIVOnIVIWoVIVIo`00
0002ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<
oda<C?m<C4co000000;oIVIV00Ko0000ogmoOomoOgoo0000oiVIVOl00003ok>c/`03o`000?o<c<co
c<c<00Koc<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo00?o0000ofIVI_l00000
0_m<C4`00ol0003o<c<coc<c<`07oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003o
VIVIo`0000;o/k>c00?o0000olc<c?o<c<`01oo<c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0
003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4co0000ofIVIP02
o`000003oiVIVOl0003o/k>c00Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo
00?ooooo2omVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmo
OomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVI
VOnIVIT02_nIVIT00ol0003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV00CoIVIV00?o0000oda<
C?m<C4`04om<C4`01Ol0003oIVIVofIVI_mVIVKo000000CoOgmo00Go0000oiVIVOnIVIWoVIVIo`00
0005ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00onc/k<01?l0003oVIVIoiVI
VOl00002ogmoO`05o`000?mVIVKoIVIVofIVI_l000001?m<C4`00ol0003o<c<coc<c<`06oc<c<`05
o`000?m<C4coC4a<oda<C?l000000_mVIVH01_l0003oOgmoogmoOol0003oVIVIo`0000?o/k>c00?o
0000olc<c?o<c<`01_o<c<`01ol0003o/k>cok>c/onc/k?o0000oiVIVOl000000_moOgl00ol0003o
IVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003o
Ogmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c007olc<c009o`000?nc/k?o0000oiVIVOl0
003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?l0
003oIVIV00;o000000?oVIVIo`000?nc/k<01_ooool1o`00007ooooo0Oooool002Cooooo00?o0000
ooooooooool00oooool:ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02omVIVH0
0ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<0
0ol0003oVIVIoiVIV@0:oiVIV@03o`000?moOgooOgmo00GoOgmo00?o0000ofIVI_mVIVH01?mVIVH0
0ol0003oC4a<oda<C00Coda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgooOgmoo`00
0003oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c
/`02ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00004oda<C003
o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP06o`000?moOgooOgmo
o`000?nIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c007o`000?nc/k?o/k>cok>c/ol0003o
VIVIo`000002ogmoO`03o`000?mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<02_l0003o
C4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<
00?o0000ok>c/onc/k<00_l000001omoOgoo0000ofIVI_mVIVKo0000oda<C?l000002?lc<c<02ol0
003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>c00Kooooo0Ol00001ooooo`7o
oooo000Tooooo`03o`000?oooooooooo00?ooooo2OmVIVH00ol0003oC4a<oda<C00Goda<C003o`00
0?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`00
0?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`05ogmoO`03o`00
0?mVIVKoIVIV00CoIVIV00?o0000oda<C?m<C4`04om<C4`00ol0003oIVIVofIVIP02ofIVIP05o`00
0?moOgooOgmoogmoOol000001?nIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00Co
c<c<00?o0000ok>c/onc/k<00onc/k<01?l0003oVIVIoiVIVOl00003ogmoO`04o`000?mVIVKoIVIV
o`0000CoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C006o`000?mVIVKo
IVIVo`000?moOgoo00000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Oo0000ok>c/onc
/k?o/k>co`000?nIVIWo000000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06
oc<c<`0;o`000?m<C4coC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl000000_nc/k<00ol0
003oc<c<olc<c006olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;o
C4a<00?o0000oc<c<olc<c<01_lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVI
VOl0003o/k>co`0000Gooooo0Ol00001ooooo`7ooooo000Tooooo`;o00001?ooool8ofIVIP03o`00
0?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`00
0?nIVIWoVIVI00coVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0:oiVIV@03o`00
0?moOgooOgmo00GoOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<C00Coda<C003o`00
0?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgooOgmoo`000004oiVIV@03o`000?nc/k?o/k>c00?o
/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`04o`000?nIVIWoVIVIo`00
00?oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4co
C4a<00;oC4a<00Ko0000ofIVI_mVIVKo0000ogmoOol00002oiVIV@05o`000?nc/k?o/k>cok>c/ol0
00002?o<c<`02Ol0003o/k>cok>c/onc/k?o0000oiVIVOl0003oOgmoo`000002ofIVIP04o`000?m<
C4coC4a<o`0000So<c<c00_o0000oda<C?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`00
0002ok>c/`03o`000?o<c<coc<c<00Koc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`00
0?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000
ogmoOol0003oVIVIo`000?nc/k?o00001?ooool2o`0000;ooooo000Tooooo`03o`000?oooooooooo
00?ooooo1omVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmo
OomoOgl02?moOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVI
VOnIVIT02_nIVIT00ol0003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV00GoIVIV00?o0000oda<
C?m<C4`04om<C4`00ol0003oIVIVofIVIP02ofIVIP05o`000?moOgooOgmoogmoOol000001?nIVIT0
0ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00onc/k<0
1?l0003oVIVIoiVIVOl00003ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<0
1_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o0000ogmoOol000000_nIVIT01Ol0003o
/k>cok>c/onc/k?o000000Soc<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo00?o
0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`09o`000?m<C4coC4a<oda<C?l0003o
IVIVo`000?moOgoo000000;oVIVI00?o0000ok>c/ol000002?o<c<`01_l0003o/k>cok>c/ol0003o
VIVIo`0000;oOgmo0_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00co0000oda<C?m<C4co0000
ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00006ooooo`7o00000Oooool1ooooo`009?ooool0
0ol0003oooooooooo`03ooooo`KoIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0:
ofIVIP;o00002_moOgl00ol0003oVIVIoiVIV@0;oiVIV@;o00005onc/k<2o`0000coVIVI00?o0000
ogmoOomoOgl01OmoOgl00ol0003oIVIVofIVIP05ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000
ofIVI_mVIVH00_mVIVH00ol0003oOgmoogmoO`02ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001Onc
/k<2o`0000Goc<c<00?o0000ok>c/onc/k<00onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo
00Go0000ofIVI_mVIVKoIVIVo`000003oda<C0;o00001olc<c<01Ol0003oC4a<oda<C?m<C4co0000
00;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Co
0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So
<c<c00_o0000oda<C?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c/`03o`00
0?o<c<coc<c<00Koc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<
C4`00ol0003o<c<coc<c<`06oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVI
o`000?nc/k?o00001_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool5
ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`09
ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;
oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<C00C
oda<C003o`000?mVIVKoIVIV00;oIVIV00?o0000ogmoOomoOgl00_moOgl01Ol0003oVIVIoiVIVOnI
VIWo000000Go/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`05o`000?nI
VIWoVIVIoiVIVOl000000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000?oC4a<00?o0000oc<c<olc
<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT0
1Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmo
o`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00_o0000oda<C?m<C4coC4a<o`000?mVIVKo
0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00[o0000ok>c/onc/k?o
0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0<o`000?m<
C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00001_ooool1o`00007ooooo0Ooo
ool002Cooooo00?o0000ooooooooool00oooool4ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000
ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000
ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000
ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<C00Coda<C003o`000?mVIVKoIVIV00;oIVIV00?o0000
ogmoOomoOgl00_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Go/k>c00?o0000olc<c?o<c<`01Oo<
c<`00ol0003o/k>cok>c/`03ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Go0000ofIVI_mVIVKo
IVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIV
IP04o`000?moOgooOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c009o`000?nc
/k?o/k>cok>c/ol0003oVIVIo`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<0
2ol0003oC4a<oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<
c?o<c<`01oo<c<`00ol0003o/k>co`000002oiVIV@;o000000GoIVIVo`000?m<C4coC4a<o`000009
oc<c<`0<o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol0003oc<c<1_ooool1
o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool3ofIVIP03o`000?m<C4coC4a<
01OoC4a<00?o0000ofIVI_mVIVH02_mVIVH2o`0000[oOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0
003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl01_moOgl00ol0
003oIVIVofIVIP05ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH00_mVIVH00ol0
003oOgmoogmoO`02ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001_nc/k<00ol0003oc<c<olc<c004
olc<c003o`000?nc/k?o/k>c00?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`04o`000?mV
IVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;o
IVIV00Co0000ogmoOomoOgoo00000_nIVIT01?l0003o/k>cok>c/ol00009olc<c004o`000?nc/k?o
/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`04o`00
0?m<C4coC4a<o`0000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<
00Ooc<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<c
oc<c<`06oc<c<`0=o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o0000
olc<c006ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`;oIVIV0_l0
000Goda<C0;o00003?mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o
0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo00GoOgmo00?o
0000ofIVI_mVIVH01_mVIVH00ol0003oC4a<oda<C00Coda<C003o`000?mVIVKoIVIV00;oIVIV00?o
0000ogmoOomoOgl00_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Ko/k>c00?o0000olc<c?o<c<`0
1?o<c<`00ol0003o/k>cok>c/`03ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01?l0003o
IVIVofIVI_l00004oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002
ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`01?l0003o/k>c
ok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<01?l0
003oC4a<oda<C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<
c007olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c
<olc<c<01_lc<c<03Ol0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`00
0?o<c<`01_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool00omVIVKo
0000oda<C00Goda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003o
VIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT2o`0000So
Ogmo00?o0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<C00Coda<C003o`000?mVIVKoIVIV00;o
IVIV00?o0000ogmoOomoOgl00_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Ko/k>c00?o0000olc<
c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl0
1?l0003oIVIVofIVI_l00004oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<
o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`01?l0
003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002Olc
<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<co
c<c<00Ooc<c<00?o0000ok>c/onc/k<00_l000001omoOgoo0000ofIVI_mVIVKo0000oda<C?l00000
2?lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000;oc<c<
1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool00ol0003oC4a<oda<
C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVI
V@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmo
O`07ogmoO`03o`000?mVIVKoIVIV00GoIVIV00?o0000oda<C?m<C4`04om<C4`00ol0003oIVIVofIV
IP03ofIVIP05o`000?moOgooOgmoogmoOol000001?nIVIT00ol0003o/k>cok>c/`04ok>c/`03o`00
0?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?o
Ogmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<
00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00002ok>c/`03o`000?o<
c<coc<c<00Ooc<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`00
0?m<C4coC4a<o`0000So<c<c00Co0000oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nIVIWo
000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo
00000_mVIVH00ol0003oC4a<o`000008oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0
003oVIVIo`000?nc/k?o00000_o<c<`6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?m<C4coC4a<01GoC4a<0_l0000=ofIVIP03o`000?moOgooOgmo00SoOgmo
00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00coVIVI
00?o0000ogmoOomoOgl01_moOgl00ol0003oIVIVofIVIP06ofIVIP03o`000?m<C4coC4a<01?oC4a<
00?o0000ofIVI_mVIVH00omVIVH01Ol0003oOgmoogmoOomoOgoo000000CoVIVI00?o0000ok>c/onc
/k<00onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Go0000oiVIVOnI
VIWoVIVIo`000003ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<0
0ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00?o0000oiVIVOl000000onc
/k<00ol0003oc<c<olc<c007olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol00000
0_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Go0000ogmo
Ool0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00So0000ok>c/onc/k?o0000oiVI
VOl0003oOgmoo`0000;oIVIV00?o0000oda<C?l000002?lc<c<03?l0003oC4a<oda<C?l0003oIVIV
o`000?moOgoo0000oiVIVOl0003o/k>co`0000;oc<c<1_ooool1o`00007ooooo0Oooool002Cooooo
0_l00004oooooaOoC4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`00
0?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@;o0000
2?moOgl00ol0003oIVIVofIVIP06ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH0
0omVIVH01Ol0003oOgmoogmoOomoOgoo000000CoVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003o
c<c<olc<c003olc<c003o`000?nc/k?o/k>c00Co/k>c00Co0000oiVIVOnIVIWo00000omoOgl01?l0
003oIVIVofIVI_l00004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`0
1?l0003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000;o/k>c00?o0000olc<c?o<c<`0
1oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<
C4co00002Olc<c<00ol0003oC4a<o`000002ofIVIP03o`000?moOgoo000000;oVIVI00?o0000ok>c
/ol000002?o<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00Go0000ofIVI_l0003oC4a<
o`000008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV0_l000001OnIVIWo0000ok>c/onc/k?o0000
00;oc<c<1Oooool2o`0000;ooooo000Tooooo`03o`000?oooooooooo00?ooooo5_m<C4`00ol0003o
IVIVofIVIP0;ofIVIP;o00002_moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko
/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`07ogmoO`03o`000?mVIVKoIVIV00Ko
IVIV00?o0000oda<C?m<C4`04om<C4`00ol0003oIVIVofIVIP03ofIVIP03o`000?moOgooOgmo00;o
Ogmo00Go0000oiVIVOnIVIWoVIVIo`000006ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c
/onc/k<01?nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`00
0003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000003ofIVIP03o`00
0?moOgoo000000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c005o`000?nc/k?o/k>cok>c
/ol000000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000Wo<c<c00?o0000
oda<C?l000000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<
c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o
<c<c00Ko<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00003
olc<c0Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo5_m<C4`00ol0
003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02_nIVIT00ol0
003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl01omoOgl00ol0
003oIVIVofIVIP05ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0
003oOgmoogmoO`02ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001_nc/k<00ol0003oc<c<olc<c003
olc<c003o`000?nc/k?o/k>c00Co/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`05o`000?mV
IVKoIVIVofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l0
00000omVIVH00ol0003oOgmoo`000002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01Ol0
003o/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l0
0009oc<c<`03o`000?m<C4co000000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`00
0?o<c<coc<c<00Koc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<
C4`00ol0003o<c<coc<c<`06oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVI
o`000?nc/k?o00000oo<c<`6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03
oooooaGoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWo
VIVI00[oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0<oiVIV@03o`000?moOgoo
Ogmo00OoOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<C00Doda<C003o`000?mVIVKo
IVIV00?oIVIV00?o0000ogmoOomoOgl00_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Oo/k>c00?o
0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`03ok>c/`05o`000?nIVIWoVIVIoiVIVOl00000
0omoOgl01?l0003oIVIVofIVI_l00004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<
C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000
olc<c?o<c<`01_o<c<`01ol0003o/k>cok>c/onc/k?o0000oiVIVOl000000_moOgl01?l0003oIVIV
ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002
ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02_l0003o/k>cok>c/ol0
003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Go<c<c00[o0000oda<
C?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVI0_l00004olc<c0Kooooo0Ol00001ooooo`7o
oooo000Tooooo`03o`000?oooooooooo00?ooooo5?m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`00
0?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02_nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`00
0?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl01omoOgl00ol0003oIVIVofIVIP06ofIVIP03o`00
0?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`02ogmoO`05o`00
0?nIVIWoVIVIoiVIVOl000001_nc/k<00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c00Co
/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`05o`000?mVIVKoIVIVofIVI_l000000om<C4`0
0ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000omVIVH00ol0003oOgmoo`00
0002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002Oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@03
o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<00ol0003oC4a<o`000002ofIV
IP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o
/k>co`0000;oVIVI0_l000001OmVIVKo0000oda<C?m<C4co000000So<c<c00co0000oda<C?m<C4co
0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00004olc<c0Kooooo0Ol00001ooooo`7ooooo
000Tooooo`03o`000?oooooooooo00?ooooo4_m<C4`2o`0000goIVIV00?o0000ogmoOomoOgl02?mo
Ogl2o`0000coVIVI0_l0000Hok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?mo
Ogl00ol0003oIVIVofIVIP06ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH00omV
IVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01?nc
/k<00ol0003oc<c<olc<c002olc<c0;o00001Onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo
00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<
C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002Oo<
c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo00000_m<C4`00ol0
003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Go0000ogmoOol0003oVIVIo`00
0002ok>c/`03o`000?o<c<coc<c<00Koc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`00
0?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`09o`000?m<C4coC4a<o`000?mVIVKo0000
ogmoOol0003oVIVI00;o00001Oo<c<`6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003ooooo
ooooo`03oooooa;oC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`00
0?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`00
0?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH01omVIVH00ol0003oC4a<oda<C00Coda<C003o`00
0?mVIVKoIVIV00?oIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@02oiVIV@03o`00
0?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`04ok>c/`05o`00
0?nIVIWoVIVIoiVIVOl000000omoOgl01?l0003oIVIVofIVI_l00004oda<C003o`000?lc<c?o<c<c
00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Go
0000ok>c/onc/k?o/k>co`000009olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl00ol0
003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Co0000oda<C?m<C4co00000_mVIVH0
1Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02_l0003o/k>cok>c
/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Wo0000
oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIT00_l00005olc<c0Kooooo0Ol00001ooooo`7o
oooo000Tooooo`03o`000?oooooooooo00?ooooo4Om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`00
0?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`00
0?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP07ofIVIP03o`00
0?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`02ogmoO`03o`00
0?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c002olc<c003o`00
0?nc/k?o/k>c00Go/k>c00Co0000oiVIVOnIVIWo00000omoOgl01?l0003oIVIVofIVI_l00004oda<
C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgoo
Ogmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`000009olc<c006o`000?nc/k?o/k>co`000?nI
VIWo00000_moOgl01?l0003oIVIVofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c00[o0000
oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c007olc<
c003o`000?nc/k?o/k>c00;o000000OoOgmoo`000?mVIVKoIVIVo`000?m<C4co000000So<c<c00co
0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00005olc<c0Kooooo0Ol0
0001ooooo`7ooooo000Booooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKo
oooo00?o0000ooooooooool00oooool?oda<C0;o00003OmVIVH00ol0003oOgmoogmoO`08ogmoO`03
o`000?nIVIWoVIVI00_oVIVI0_l0000Hok>c/`03o`000?nIVIWoVIVI00[oVIVI0_l0000:ogmoO`03
o`000?mVIVKoIVIV00KoIVIV0_l0000Foda<C003o`000?mVIVKoIVIV00;oIVIV00?o0000ogmoOomo
Ogl00_moOgl00ol0003oVIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c00Go/k>c00?o0000olc<c?o<
c<`00_o<c<`00ol0003o/k>cok>c/`04ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01Ol0
003oIVIVofIVI_mVIVKo000000CoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002
oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<
olc<c006olc<c007o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000002ogmoO`03o`000?mVIVKo0000
00?oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP05o`000?moOgoo
0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c008o`000?nc/k?o/k>co`000?nIVIWo
0000ogmoOol00002ofIVIP03o`000?m<C4co000000So<c<c00co0000oda<C?m<C4co0000ofIVI_l0
003oOgmoo`000?nIVIWo0000ok>c/ol00005olc<c0Kooooo0Ol00001ooooo`7ooooo000Dooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo
00?ooooo3om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVI
VOnIVIT02onIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00[oVIVI00?o0000ogmo
OomoOgl02OmoOgl00ol0003oIVIVofIVIP07ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIV
I_mVIVH00_mVIVH00ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c
/onc/k<01Onc/k<00ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c00Co/k>c00Go0000oiVI
VOnIVIWoVIVIo`000002ogmoO`05o`000?mVIVKoIVIVofIVI_l000001?m<C4`00ol0003o<c<coc<c
<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVI
oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Co0000ok>c/onc/k?o00000_nIVIT01_l0
003oOgmoogmoOol0003oIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<
C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c008
o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP03o`000?m<C4co000000So<c<c00co
0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00005olc<c0Kooooo0Ol0
0001ooooo`7ooooo000Dooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4006ooooo`03o`000?oooooooooo00?ooooo3_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?mo
OgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nI
VIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP07ofIVIP03o`000?m<
C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nI
VIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c002olc<c003o`000?nc
/k?o/k>c00Co/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`04o`000?mVIVKoIVIVo`0000Co
C4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`00
00;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o
/k>cok>c/ol000000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000?oC4a<00?o0000oc<c<olc<c<0
1_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0
003oc<c<olc<c006olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl01Ol0003oIVIVo`00
0?m<C4co000000Wo<c<c00?o0000oda<C?l000000_mVIVH2o`000005oiVIVOl0003o/k>cok>c/ol0
00001Oo<c<`6ooooo`7o00000Oooool1ooooo`005?ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000001_ooool3o`0000?ooooo3Om<C4`00ol0003oIVIVofIVIP0;ofIVIP03
o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Gok>c/`03
o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP07ofIVIP03
o`000?m<C4coC4a<01GoC4a<00?o0000ofIVI_mVIVH00omVIVH01Ol0003oOgmoogmoOomoOgoo0000
00CoVIVI00?o0000ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c
00Co/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`05o`000?mVIVKoIVIVofIVI_l000001?m<
C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo0000
0_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc
/k?o00000_nIVIT01_l0003oOgmoogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01olc
<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003o
c<c<olc<c006olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<
00?o0000oc<c<olc<c<01olc<c<02ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc
/k?o000000Koc<c<1?ooool3o`0000;ooooo000Dooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo?oooool1o`00007ooooo0Ooo
ool001Cooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Kooooo00?o
0000ooooooooool0ooooooloooooo`7o00000Oooool1ooooo`005?ooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3oooooocoooooo0Ol0
0001ooooo`7ooooo000Booooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP06ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool09oooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`0Wooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`03ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00?ooooo0Ol00001ooooo`7ooooo000Toooooooo0000@ol00002ooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-7.04757, -6.93977, 0.0606246, \
0.0606246}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.339744 0.0641026 0.339744 0.0641026 [
[.08333 -0.0125 -6 -9 ]
[.08333 -0.0125 6 0 ]
[.21154 -0.0125 -6 -9 ]
[.21154 -0.0125 6 0 ]
[.33974 -0.0125 -3 -9 ]
[.33974 -0.0125 3 0 ]
[.46795 -0.0125 -3 -9 ]
[.46795 -0.0125 3 0 ]
[.59615 -0.0125 -3 -9 ]
[.59615 -0.0125 3 0 ]
[.72436 -0.0125 -3 -9 ]
[.72436 -0.0125 3 0 ]
[.85256 -0.0125 -3 -9 ]
[.85256 -0.0125 3 0 ]
[.98077 -0.0125 -6 -9 ]
[.98077 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5 -21 ]
[.5 -0.0125 5 -9 ]
[-0.0125 .08333 -12 -4.5 ]
[-0.0125 .08333 0 4.5 ]
[-0.0125 .21154 -12 -4.5 ]
[-0.0125 .21154 0 4.5 ]
[-0.0125 .33974 -6 -4.5 ]
[-0.0125 .33974 0 4.5 ]
[-0.0125 .46795 -6 -4.5 ]
[-0.0125 .46795 0 4.5 ]
[-0.0125 .59615 -6 -4.5 ]
[-0.0125 .59615 0 4.5 ]
[-0.0125 .72436 -6 -4.5 ]
[-0.0125 .72436 0 4.5 ]
[-0.0125 .85256 -6 -4.5 ]
[-0.0125 .85256 0 4.5 ]
[-0.0125 .98077 -12 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -24 -5 ]
[-0.01875 .5 -12 5 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08333 0 m
.08333 .00625 L
s
[(-4)] .08333 -0.0125 0 1 Mshowa
.21154 0 m
.21154 .00625 L
s
[(-2)] .21154 -0.0125 0 1 Mshowa
.33974 0 m
.33974 .00625 L
s
[(0)] .33974 -0.0125 0 1 Mshowa
.46795 0 m
.46795 .00625 L
s
[(2)] .46795 -0.0125 0 1 Mshowa
.59615 0 m
.59615 .00625 L
s
[(4)] .59615 -0.0125 0 1 Mshowa
.72436 0 m
.72436 .00625 L
s
[(6)] .72436 -0.0125 0 1 Mshowa
.85256 0 m
.85256 .00625 L
s
[(8)] .85256 -0.0125 0 1 Mshowa
.98077 0 m
.98077 .00625 L
s
[(10)] .98077 -0.0125 0 1 Mshowa
.125 Mabswid
.11538 0 m
.11538 .00375 L
s
.14744 0 m
.14744 .00375 L
s
.17949 0 m
.17949 .00375 L
s
.24359 0 m
.24359 .00375 L
s
.27564 0 m
.27564 .00375 L
s
.30769 0 m
.30769 .00375 L
s
.37179 0 m
.37179 .00375 L
s
.40385 0 m
.40385 .00375 L
s
.4359 0 m
.4359 .00375 L
s
.5 0 m
.5 .00375 L
s
.53205 0 m
.53205 .00375 L
s
.5641 0 m
.5641 .00375 L
s
.62821 0 m
.62821 .00375 L
s
.66026 0 m
.66026 .00375 L
s
.69231 0 m
.69231 .00375 L
s
.75641 0 m
.75641 .00375 L
s
.78846 0 m
.78846 .00375 L
s
.82051 0 m
.82051 .00375 L
s
.88462 0 m
.88462 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.94872 0 m
.94872 .00375 L
s
.05128 0 m
.05128 .00375 L
s
.01923 0 m
.01923 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66 -25 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .08333 m
.00625 .08333 L
s
[(-4)] -0.0125 .08333 1 0 Mshowa
0 .21154 m
.00625 .21154 L
s
[(-2)] -0.0125 .21154 1 0 Mshowa
0 .33974 m
.00625 .33974 L
s
[(0)] -0.0125 .33974 1 0 Mshowa
0 .46795 m
.00625 .46795 L
s
[(2)] -0.0125 .46795 1 0 Mshowa
0 .59615 m
.00625 .59615 L
s
[(4)] -0.0125 .59615 1 0 Mshowa
0 .72436 m
.00625 .72436 L
s
[(6)] -0.0125 .72436 1 0 Mshowa
0 .85256 m
.00625 .85256 L
s
[(8)] -0.0125 .85256 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(10)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .11538 m
.00375 .11538 L
s
0 .14744 m
.00375 .14744 L
s
0 .17949 m
.00375 .17949 L
s
0 .24359 m
.00375 .24359 L
s
0 .27564 m
.00375 .27564 L
s
0 .30769 m
.00375 .30769 L
s
0 .37179 m
.00375 .37179 L
s
0 .40385 m
.00375 .40385 L
s
0 .4359 m
.00375 .4359 L
s
0 .5 m
.00375 .5 L
s
0 .53205 m
.00375 .53205 L
s
0 .5641 m
.00375 .5641 L
s
0 .62821 m
.00375 .62821 L
s
0 .66026 m
.00375 .66026 L
s
0 .69231 m
.00375 .69231 L
s
0 .75641 m
.00375 .75641 L
s
0 .78846 m
.00375 .78846 L
s
0 .82051 m
.00375 .82051 L
s
0 .88462 m
.00375 .88462 L
s
0 .91667 m
.00375 .91667 L
s
0 .94872 m
.00375 .94872 L
s
0 .05128 m
.00375 .05128 L
s
0 .01923 m
.00375 .01923 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
-0.01875 .5 -84 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
66 10 translate
90 rotate
-66 -10 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.08333 .99375 m
.08333 1 L
s
.21154 .99375 m
.21154 1 L
s
.33974 .99375 m
.33974 1 L
s
.46795 .99375 m
.46795 1 L
s
.59615 .99375 m
.59615 1 L
s
.72436 .99375 m
.72436 1 L
s
.85256 .99375 m
.85256 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.11538 .99625 m
.11538 1 L
s
.14744 .99625 m
.14744 1 L
s
.17949 .99625 m
.17949 1 L
s
.24359 .99625 m
.24359 1 L
s
.27564 .99625 m
.27564 1 L
s
.30769 .99625 m
.30769 1 L
s
.37179 .99625 m
.37179 1 L
s
.40385 .99625 m
.40385 1 L
s
.4359 .99625 m
.4359 1 L
s
.5 .99625 m
.5 1 L
s
.53205 .99625 m
.53205 1 L
s
.5641 .99625 m
.5641 1 L
s
.62821 .99625 m
.62821 1 L
s
.66026 .99625 m
.66026 1 L
s
.69231 .99625 m
.69231 1 L
s
.75641 .99625 m
.75641 1 L
s
.78846 .99625 m
.78846 1 L
s
.82051 .99625 m
.82051 1 L
s
.88462 .99625 m
.88462 1 L
s
.91667 .99625 m
.91667 1 L
s
.94872 .99625 m
.94872 1 L
s
.05128 .99625 m
.05128 1 L
s
.01923 .99625 m
.01923 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .08333 m
1 .08333 L
s
.99375 .21154 m
1 .21154 L
s
.99375 .33974 m
1 .33974 L
s
.99375 .46795 m
1 .46795 L
s
.99375 .59615 m
1 .59615 L
s
.99375 .72436 m
1 .72436 L
s
.99375 .85256 m
1 .85256 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .11538 m
1 .11538 L
s
.99625 .14744 m
1 .14744 L
s
.99625 .17949 m
1 .17949 L
s
.99625 .24359 m
1 .24359 L
s
.99625 .27564 m
1 .27564 L
s
.99625 .30769 m
1 .30769 L
s
.99625 .37179 m
1 .37179 L
s
.99625 .40385 m
1 .40385 L
s
.99625 .4359 m
1 .4359 L
s
.99625 .5 m
1 .5 L
s
.99625 .53205 m
1 .53205 L
s
.99625 .5641 m
1 .5641 L
s
.99625 .62821 m
1 .62821 L
s
.99625 .66026 m
1 .66026 L
s
.99625 .69231 m
1 .69231 L
s
.99625 .75641 m
1 .75641 L
s
.99625 .78846 m
1 .78846 L
s
.99625 .82051 m
1 .82051 L
s
.99625 .88462 m
1 .88462 L
s
.99625 .91667 m
1 .91667 L
s
.99625 .94872 m
1 .94872 L
s
.99625 .05128 m
1 .05128 L
s
.99625 .01923 m
1 .01923 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.4 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.5 g
.01923 .93976 m
.02679 .93221 L
.02894 .93005 L
.0365 .92249 L
.03866 .92034 L
.04621 .91278 L
.04837 .91062 L
.05592 .90307 L
.05808 .90091 L
.06564 .89336 L
.06779 .8912 L
.07535 .88364 L
.07751 .88149 L
.08506 .87393 L
.08722 .87177 L
.09477 .86422 L
.09693 .86206 L
.10449 .85451 L
.10664 .85235 L
.1142 .84479 L
.11636 .84264 L
.12391 .83508 L
.12607 .83292 L
.13362 .82537 L
.13578 .82321 L
.14334 .81566 L
.14549 .8135 L
.15305 .80594 L
.15521 .80379 L
.16276 .79623 L
.16492 .79407 L
.17247 .78652 L
.17463 .78436 L
.18219 .77681 L
.18434 .77465 L
.1919 .76709 L
.19406 .76494 L
.20161 .75738 L
.20377 .75522 L
.21132 .74767 L
.21348 .74551 L
.22104 .73796 L
.22319 .7358 L
.23075 .72824 L
.23291 .72609 L
.24046 .71853 L
.24262 .71637 L
.25017 .70882 L
.25233 .70666 L
.25989 .69911 L
.26204 .69695 L
.2696 .68939 L
.27176 .68724 L
.27931 .67968 L
.28147 .67752 L
.28902 .66997 L
.29118 .66781 L
.29874 .66026 L
.30089 .6581 L
.30845 .65054 L
.31061 .64839 L
.31816 .64083 L
.32032 .63867 L
.32787 .63112 L
.33003 .62896 L
.33765 .62141 L
.33974 .61925 L
.34664 .61169 L
.34946 .60855 L
.35517 .60198 L
.35917 .59726 L
.36332 .59227 L
.36888 .5854 L
.37114 .58256 L
.37859 .57298 L
.3787 .57284 L
.38602 .56313 L
.38831 .56003 L
.39312 .55342 L
.39802 .54656 L
.40003 .54371 L
.40677 .53399 L
.40773 .53259 L
.41335 .52428 L
.41744 .51813 L
.41979 .51457 L
.42609 .50486 L
.42716 .5032 L
.43227 .49514 L
.43687 .48781 L
.43834 .48543 L
.44431 .47572 L
.44658 .47197 L
.45017 .46601 L
.45594 .45629 L
.45629 .45569 L
.46162 .44658 L
.46601 .43899 L
.46722 .43687 L
.47274 .42716 L
.47572 .42187 L
.47819 .41744 L
.48357 .40773 L
.48543 .40435 L
.48888 .39802 L
.49414 .38831 L
.49514 .38643 L
.49932 .37859 L
.50446 .36888 L
.50486 .36812 L
.50952 .35917 L
.51455 .34946 L
.51457 .34942 L
.51952 .33974 L
.52428 .33036 L
.52444 .33003 L
.52931 .32032 L
.53399 .31092 L
.53415 .31061 L
.53893 .30089 L
.54368 .29118 L
.54371 .29113 L
.54837 .28147 L
.55305 .27176 L
.55342 .27097 L
.55766 .26204 L
.56226 .25233 L
.56313 .25047 L
.5668 .24262 L
.57133 .23291 L
.57284 .22963 L
.5758 .22319 L
.58026 .21348 L
.58256 .20845 L
.58467 .20377 L
.58907 .19406 L
.59227 .18694 L
.59342 .18434 L
.59775 .17463 L
.60198 .1651 L
.60206 .16492 L
.60632 .15521 L
.61058 .14549 L
.61169 .14294 L
.61478 .13578 L
.61899 .12607 L
.62141 .12045 L
.62315 .11636 L
.6273 .10664 L
.63112 .09766 L
.63142 .09693 L
.63551 .08722 L
.6396 .07751 L
.64083 .07455 L
.64363 .06779 L
.64767 .05808 L
.65054 .05114 L
.65167 .04837 L
.65566 .03866 L
.65964 .02894 L
.66026 .02743 L
.66357 .01923 L
.01923 .01923 L
F
0 g
.01923 .93976 m
.02679 .93221 L
.02894 .93005 L
.0365 .92249 L
.03866 .92034 L
.04621 .91278 L
.04837 .91062 L
.05592 .90307 L
.05808 .90091 L
.06564 .89336 L
.06779 .8912 L
.07535 .88364 L
.07751 .88149 L
.08506 .87393 L
.08722 .87177 L
.09477 .86422 L
.09693 .86206 L
.10449 .85451 L
.10664 .85235 L
.1142 .84479 L
.11636 .84264 L
.12391 .83508 L
.12607 .83292 L
.13362 .82537 L
.13578 .82321 L
.14334 .81566 L
.14549 .8135 L
.15305 .80594 L
.15521 .80379 L
.16276 .79623 L
.16492 .79407 L
.17247 .78652 L
.17463 .78436 L
.18219 .77681 L
.18434 .77465 L
.1919 .76709 L
.19406 .76494 L
.20161 .75738 L
.20377 .75522 L
.21132 .74767 L
.21348 .74551 L
.22104 .73796 L
.22319 .7358 L
.23075 .72824 L
.23291 .72609 L
.24046 .71853 L
.24262 .71637 L
.25017 .70882 L
.25233 .70666 L
.25989 .69911 L
Mistroke
.26204 .69695 L
.2696 .68939 L
.27176 .68724 L
.27931 .67968 L
.28147 .67752 L
.28902 .66997 L
.29118 .66781 L
.29874 .66026 L
.30089 .6581 L
.30845 .65054 L
.31061 .64839 L
.31816 .64083 L
.32032 .63867 L
.32787 .63112 L
.33003 .62896 L
.33765 .62141 L
.33974 .61925 L
.34664 .61169 L
.34946 .60855 L
.35517 .60198 L
.35917 .59726 L
.36332 .59227 L
.36888 .5854 L
.37114 .58256 L
.37859 .57298 L
.3787 .57284 L
.38602 .56313 L
.38831 .56003 L
.39312 .55342 L
.39802 .54656 L
.40003 .54371 L
.40677 .53399 L
.40773 .53259 L
.41335 .52428 L
.41744 .51813 L
.41979 .51457 L
.42609 .50486 L
.42716 .5032 L
.43227 .49514 L
.43687 .48781 L
.43834 .48543 L
.44431 .47572 L
.44658 .47197 L
.45017 .46601 L
.45594 .45629 L
.45629 .45569 L
.46162 .44658 L
.46601 .43899 L
.46722 .43687 L
.47274 .42716 L
Mistroke
.47572 .42187 L
.47819 .41744 L
.48357 .40773 L
.48543 .40435 L
.48888 .39802 L
.49414 .38831 L
.49514 .38643 L
.49932 .37859 L
.50446 .36888 L
.50486 .36812 L
.50952 .35917 L
.51455 .34946 L
.51457 .34942 L
.51952 .33974 L
.52428 .33036 L
.52444 .33003 L
.52931 .32032 L
.53399 .31092 L
.53415 .31061 L
.53893 .30089 L
.54368 .29118 L
.54371 .29113 L
.54837 .28147 L
.55305 .27176 L
.55342 .27097 L
.55766 .26204 L
.56226 .25233 L
.56313 .25047 L
.5668 .24262 L
.57133 .23291 L
.57284 .22963 L
.5758 .22319 L
.58026 .21348 L
.58256 .20845 L
.58467 .20377 L
.58907 .19406 L
.59227 .18694 L
.59342 .18434 L
.59775 .17463 L
.60198 .1651 L
.60206 .16492 L
.60632 .15521 L
.61058 .14549 L
.61169 .14294 L
.61478 .13578 L
.61899 .12607 L
.62141 .12045 L
.62315 .11636 L
.6273 .10664 L
.63112 .09766 L
Mistroke
.63142 .09693 L
.63551 .08722 L
.6396 .07751 L
.64083 .07455 L
.64363 .06779 L
.64767 .05808 L
.65054 .05114 L
.65167 .04837 L
.65566 .03866 L
.65964 .02894 L
.66026 .02743 L
.66357 .01923 L
Mfstroke
.6 g
.01923 .90435 m
.02051 .90307 L
.02894 .89464 L
.03022 .89336 L
.03866 .88492 L
.03994 .88364 L
.04837 .87521 L
.04965 .87393 L
.05808 .8655 L
.05936 .86422 L
.06779 .85579 L
.06907 .85451 L
.07751 .84607 L
.07879 .84479 L
.08722 .83636 L
.0885 .83508 L
.09693 .82665 L
.09821 .82537 L
.10664 .81694 L
.10792 .81566 L
.11636 .80722 L
.11764 .80594 L
.12607 .79751 L
.12735 .79623 L
.13578 .7878 L
.13706 .78652 L
.14549 .77809 L
.14677 .77681 L
.15521 .76837 L
.15649 .76709 L
.16492 .75866 L
.1662 .75738 L
.17463 .74895 L
.17591 .74767 L
.18434 .73924 L
.18562 .73796 L
.19406 .72952 L
.19534 .72824 L
.20377 .71981 L
.20505 .71853 L
.21348 .7101 L
.21476 .70882 L
.22319 .70039 L
.22447 .69911 L
.23291 .69067 L
.23419 .68939 L
.24262 .68096 L
.2439 .67968 L
.25233 .67125 L
.25361 .66997 L
.26204 .66154 L
.26332 .66026 L
.27176 .65182 L
.27304 .65054 L
.28147 .64211 L
.28275 .64083 L
.29118 .6324 L
.29246 .63112 L
.30089 .62269 L
.30217 .62141 L
.31061 .61297 L
.31189 .61169 L
.32032 .60326 L
.3216 .60198 L
.33003 .59355 L
.33132 .59227 L
.33974 .58384 L
.34104 .58256 L
.34946 .57439 L
.35099 .57284 L
.35917 .56417 L
.36012 .56313 L
.36871 .55342 L
.36888 .55322 L
.37689 .54371 L
.37859 .54161 L
.38471 .53399 L
.38831 .52937 L
.39223 .52428 L
.39802 .51654 L
.39948 .51457 L
.40652 .50486 L
.40773 .50315 L
.41337 .49514 L
.41744 .48922 L
.42003 .48543 L
.42653 .47572 L
.42716 .47477 L
.4329 .46601 L
.43687 .45982 L
.43913 .45629 L
.44523 .44658 L
.44658 .4444 L
.45123 .43687 L
.45629 .4285 L
.45711 .42716 L
.46291 .41744 L
.46601 .41216 L
.4686 .40773 L
.47422 .39802 L
.47572 .39538 L
.47976 .38831 L
.4852 .37859 L
.48543 .37817 L
.4906 .36888 L
.49514 .36055 L
.4959 .35917 L
.50116 .34946 L
.50486 .34252 L
.50634 .33974 L
.51148 .33003 L
.51457 .3241 L
.51654 .32032 L
.52157 .31061 L
.52428 .30528 L
.52653 .30089 L
.53146 .29118 L
.53399 .28609 L
.53631 .28147 L
.54115 .27176 L
.54371 .26653 L
.54591 .26204 L
.55066 .25233 L
.55342 .2466 L
.55534 .24262 L
.56001 .23291 L
.56313 .22631 L
.56461 .22319 L
.56921 .21348 L
.57284 .20567 L
.57373 .20377 L
.57826 .19406 L
.58256 .18468 L
.58271 .18434 L
.58717 .17463 L
.59157 .16492 L
.59227 .16335 L
.59596 .15521 L
.60031 .14549 L
.60198 .14169 L
.60462 .13578 L
.60892 .12607 L
.61169 .1197 L
.61317 .11636 L
.61742 .10664 L
.62141 .09739 L
.6216 .09693 L
.62581 .08722 L
.62996 .07751 L
.63112 .07475 L
.63409 .06779 L
.63822 .05808 L
.64083 .0518 L
.64228 .04837 L
.64637 .03866 L
.65038 .02894 L
.65054 .02854 L
.65442 .01923 L
.01923 .01923 L
F
0 g
.01923 .90435 m
.02051 .90307 L
.02894 .89464 L
.03022 .89336 L
.03866 .88492 L
.03994 .88364 L
.04837 .87521 L
.04965 .87393 L
.05808 .8655 L
.05936 .86422 L
.06779 .85579 L
.06907 .85451 L
.07751 .84607 L
.07879 .84479 L
.08722 .83636 L
.0885 .83508 L
.09693 .82665 L
.09821 .82537 L
.10664 .81694 L
.10792 .81566 L
.11636 .80722 L
.11764 .80594 L
.12607 .79751 L
.12735 .79623 L
.13578 .7878 L
.13706 .78652 L
.14549 .77809 L
.14677 .77681 L
.15521 .76837 L
.15649 .76709 L
.16492 .75866 L
.1662 .75738 L
.17463 .74895 L
.17591 .74767 L
.18434 .73924 L
.18562 .73796 L
.19406 .72952 L
.19534 .72824 L
.20377 .71981 L
.20505 .71853 L
.21348 .7101 L
.21476 .70882 L
.22319 .70039 L
.22447 .69911 L
.23291 .69067 L
.23419 .68939 L
.24262 .68096 L
.2439 .67968 L
.25233 .67125 L
.25361 .66997 L
Mistroke
.26204 .66154 L
.26332 .66026 L
.27176 .65182 L
.27304 .65054 L
.28147 .64211 L
.28275 .64083 L
.29118 .6324 L
.29246 .63112 L
.30089 .62269 L
.30217 .62141 L
.31061 .61297 L
.31189 .61169 L
.32032 .60326 L
.3216 .60198 L
.33003 .59355 L
.33132 .59227 L
.33974 .58384 L
.34104 .58256 L
.34946 .57439 L
.35099 .57284 L
.35917 .56417 L
.36012 .56313 L
.36871 .55342 L
.36888 .55322 L
.37689 .54371 L
.37859 .54161 L
.38471 .53399 L
.38831 .52937 L
.39223 .52428 L
.39802 .51654 L
.39948 .51457 L
.40652 .50486 L
.40773 .50315 L
.41337 .49514 L
.41744 .48922 L
.42003 .48543 L
.42653 .47572 L
.42716 .47477 L
.4329 .46601 L
.43687 .45982 L
.43913 .45629 L
.44523 .44658 L
.44658 .4444 L
.45123 .43687 L
.45629 .4285 L
.45711 .42716 L
.46291 .41744 L
.46601 .41216 L
.4686 .40773 L
.47422 .39802 L
Mistroke
.47572 .39538 L
.47976 .38831 L
.4852 .37859 L
.48543 .37817 L
.4906 .36888 L
.49514 .36055 L
.4959 .35917 L
.50116 .34946 L
.50486 .34252 L
.50634 .33974 L
.51148 .33003 L
.51457 .3241 L
.51654 .32032 L
.52157 .31061 L
.52428 .30528 L
.52653 .30089 L
.53146 .29118 L
.53399 .28609 L
.53631 .28147 L
.54115 .27176 L
.54371 .26653 L
.54591 .26204 L
.55066 .25233 L
.55342 .2466 L
.55534 .24262 L
.56001 .23291 L
.56313 .22631 L
.56461 .22319 L
.56921 .21348 L
.57284 .20567 L
.57373 .20377 L
.57826 .19406 L
.58256 .18468 L
.58271 .18434 L
.58717 .17463 L
.59157 .16492 L
.59227 .16335 L
.59596 .15521 L
.60031 .14549 L
.60198 .14169 L
.60462 .13578 L
.60892 .12607 L
.61169 .1197 L
.61317 .11636 L
.61742 .10664 L
.62141 .09739 L
.6216 .09693 L
.62581 .08722 L
.62996 .07751 L
.63112 .07475 L
Mistroke
.63409 .06779 L
.63822 .05808 L
.64083 .0518 L
.64228 .04837 L
.64637 .03866 L
.65038 .02894 L
.65054 .02854 L
.65442 .01923 L
Mfstroke
.7 g
.01923 .86068 m
.02532 .85451 L
.02894 .85097 L
.03512 .84479 L
.03866 .84126 L
.04483 .83508 L
.04837 .83154 L
.05454 .82537 L
.05808 .82183 L
.06425 .81566 L
.06779 .81212 L
.07397 .80594 L
.07751 .80241 L
.08368 .79623 L
.08722 .79269 L
.09339 .78652 L
.09693 .78298 L
.1031 .77681 L
.10664 .77327 L
.11282 .76709 L
.11636 .76356 L
.12253 .75738 L
.12607 .75384 L
.13224 .74767 L
.13578 .74413 L
.14195 .73796 L
.14549 .73442 L
.15167 .72824 L
.15521 .72471 L
.16138 .71853 L
.16492 .71499 L
.17109 .70882 L
.17463 .70528 L
.1808 .69911 L
.18434 .69557 L
.19052 .68939 L
.19406 .68586 L
.20023 .67968 L
.20377 .67614 L
.20994 .66997 L
.21348 .66643 L
.21965 .66026 L
.22319 .65672 L
.22937 .65054 L
.23291 .64701 L
.23908 .64083 L
.24262 .63729 L
.24879 .63112 L
.25233 .62758 L
.2585 .62141 L
.26204 .61787 L
.26822 .61169 L
.27176 .60816 L
.27793 .60198 L
.28147 .59844 L
.28764 .59227 L
.29118 .58873 L
.29735 .58256 L
.30089 .57902 L
.30707 .57284 L
.31061 .5693 L
.31678 .56313 L
.32032 .55959 L
.32649 .55342 L
.33003 .54988 L
.33609 .54371 L
.33974 .54017 L
.34809 .53399 L
.34946 .53312 L
.35917 .5248 L
.35976 .52428 L
.36888 .51543 L
.36976 .51457 L
.37859 .50514 L
.37886 .50486 L
.38745 .49514 L
.38831 .49405 L
.39555 .48543 L
.39802 .48222 L
.40323 .47572 L
.40773 .4697 L
.41056 .46601 L
.41744 .45653 L
.41762 .45629 L
.42462 .44658 L
.42716 .4428 L
.43131 .43687 L
.43687 .42849 L
.43777 .42716 L
.44423 .41744 L
.44658 .41365 L
.45044 .40773 L
.45629 .39829 L
.45646 .39802 L
.46255 .38831 L
.46601 .38245 L
.46837 .37859 L
.47418 .36888 L
.47572 .36613 L
.47986 .35917 L
.48537 .34946 L
.48543 .34934 L
.49098 .33974 L
.49514 .33213 L
.49633 .33003 L
.50178 .32032 L
.50486 .31448 L
.507 .31061 L
.51228 .30089 L
.51457 .29641 L
.5174 .29118 L
.52253 .28147 L
.52428 .27793 L
.52755 .27176 L
.53255 .26204 L
.53399 .25905 L
.53748 .25233 L
.54237 .24262 L
.54371 .23979 L
.54721 .23291 L
.55201 .22319 L
.55342 .22014 L
.55675 .21348 L
.56148 .20377 L
.56313 .20013 L
.56611 .19406 L
.57078 .18434 L
.57284 .17974 L
.57531 .17463 L
.57993 .16492 L
.58256 .159 L
.58436 .15521 L
.58893 .14549 L
.59227 .13791 L
.59326 .13578 L
.59779 .12607 L
.60198 .11647 L
.60203 .11636 L
.6065 .10664 L
.61079 .09693 L
.61169 .0947 L
.61509 .08722 L
.6194 .07751 L
.62141 .0726 L
.62355 .06779 L
.62786 .05808 L
.63112 .05016 L
.63191 .04837 L
.63618 .03866 L
.64024 .02894 L
.64083 .0274 L
.64439 .01923 L
.01923 .01923 L
F
0 g
.01923 .86068 m
.02532 .85451 L
.02894 .85097 L
.03512 .84479 L
.03866 .84126 L
.04483 .83508 L
.04837 .83154 L
.05454 .82537 L
.05808 .82183 L
.06425 .81566 L
.06779 .81212 L
.07397 .80594 L
.07751 .80241 L
.08368 .79623 L
.08722 .79269 L
.09339 .78652 L
.09693 .78298 L
.1031 .77681 L
.10664 .77327 L
.11282 .76709 L
.11636 .76356 L
.12253 .75738 L
.12607 .75384 L
.13224 .74767 L
.13578 .74413 L
.14195 .73796 L
.14549 .73442 L
.15167 .72824 L
.15521 .72471 L
.16138 .71853 L
.16492 .71499 L
.17109 .70882 L
.17463 .70528 L
.1808 .69911 L
.18434 .69557 L
.19052 .68939 L
.19406 .68586 L
.20023 .67968 L
.20377 .67614 L
.20994 .66997 L
.21348 .66643 L
.21965 .66026 L
.22319 .65672 L
.22937 .65054 L
.23291 .64701 L
.23908 .64083 L
.24262 .63729 L
.24879 .63112 L
.25233 .62758 L
.2585 .62141 L
Mistroke
.26204 .61787 L
.26822 .61169 L
.27176 .60816 L
.27793 .60198 L
.28147 .59844 L
.28764 .59227 L
.29118 .58873 L
.29735 .58256 L
.30089 .57902 L
.30707 .57284 L
.31061 .5693 L
.31678 .56313 L
.32032 .55959 L
.32649 .55342 L
.33003 .54988 L
.33609 .54371 L
.33974 .54017 L
.34809 .53399 L
.34946 .53312 L
.35917 .5248 L
.35976 .52428 L
.36888 .51543 L
.36976 .51457 L
.37859 .50514 L
.37886 .50486 L
.38745 .49514 L
.38831 .49405 L
.39555 .48543 L
.39802 .48222 L
.40323 .47572 L
.40773 .4697 L
.41056 .46601 L
.41744 .45653 L
.41762 .45629 L
.42462 .44658 L
.42716 .4428 L
.43131 .43687 L
.43687 .42849 L
.43777 .42716 L
.44423 .41744 L
.44658 .41365 L
.45044 .40773 L
.45629 .39829 L
.45646 .39802 L
.46255 .38831 L
.46601 .38245 L
.46837 .37859 L
.47418 .36888 L
.47572 .36613 L
.47986 .35917 L
Mistroke
.48537 .34946 L
.48543 .34934 L
.49098 .33974 L
.49514 .33213 L
.49633 .33003 L
.50178 .32032 L
.50486 .31448 L
.507 .31061 L
.51228 .30089 L
.51457 .29641 L
.5174 .29118 L
.52253 .28147 L
.52428 .27793 L
.52755 .27176 L
.53255 .26204 L
.53399 .25905 L
.53748 .25233 L
.54237 .24262 L
.54371 .23979 L
.54721 .23291 L
.55201 .22319 L
.55342 .22014 L
.55675 .21348 L
.56148 .20377 L
.56313 .20013 L
.56611 .19406 L
.57078 .18434 L
.57284 .17974 L
.57531 .17463 L
.57993 .16492 L
.58256 .159 L
.58436 .15521 L
.58893 .14549 L
.59227 .13791 L
.59326 .13578 L
.59779 .12607 L
.60198 .11647 L
.60203 .11636 L
.6065 .10664 L
.61079 .09693 L
.61169 .0947 L
.61509 .08722 L
.6194 .07751 L
.62141 .0726 L
.62355 .06779 L
.62786 .05808 L
.63112 .05016 L
.63191 .04837 L
.63618 .03866 L
.64024 .02894 L
Mistroke
.64083 .0274 L
.64439 .01923 L
Mfstroke
.6 g
.01923 .78205 m
.02474 .77681 L
.02894 .77234 L
.03419 .76709 L
.03866 .76263 L
.0439 .75738 L
.04837 .75291 L
.05361 .74767 L
.05808 .7432 L
.06333 .73796 L
.06779 .73349 L
.07304 .72824 L
.07751 .72378 L
.08275 .71853 L
.08722 .71406 L
.09246 .70882 L
.09693 .70435 L
.10218 .69911 L
.10664 .69464 L
.11189 .68939 L
.11636 .68493 L
.1216 .67968 L
.12607 .67521 L
.13131 .66997 L
.13578 .6655 L
.14103 .66026 L
.14549 .65579 L
.15074 .65054 L
.15521 .64608 L
.16045 .64083 L
.16492 .63636 L
.17016 .63112 L
.17463 .62665 L
.17988 .62141 L
.18434 .61694 L
.18959 .61169 L
.19406 .60723 L
.1993 .60198 L
.20377 .59751 L
.20901 .59227 L
.21348 .5878 L
.21873 .58256 L
.22319 .57809 L
.22844 .57284 L
.23291 .56838 L
.23815 .56313 L
.24262 .55866 L
.24786 .55342 L
.25233 .54895 L
.25758 .54371 L
.26204 .53924 L
.26729 .53399 L
.27176 .52953 L
.277 .52428 L
.28147 .51981 L
.28671 .51457 L
.29118 .5101 L
.29643 .50486 L
.30089 .50039 L
.30614 .49514 L
.31061 .49068 L
.31585 .48543 L
.32032 .48096 L
.32556 .47572 L
.33003 .47125 L
.33558 .46601 L
.33974 .46154 L
.34377 .45629 L
.34946 .44843 L
.35083 .44658 L
.35798 .43687 L
.35917 .43523 L
.36502 .42716 L
.36888 .42178 L
.37197 .41744 L
.37859 .40806 L
.37883 .40773 L
.38553 .39802 L
.38831 .39396 L
.39212 .38831 L
.39802 .37951 L
.39862 .37859 L
.40498 .36888 L
.40773 .36466 L
.41123 .35917 L
.41743 .34946 L
.41744 .34943 L
.42346 .33974 L
.42716 .33378 L
.42942 .33003 L
.43532 .32032 L
.43687 .31775 L
.44109 .31061 L
.44658 .30134 L
.44683 .30089 L
.45244 .29118 L
.45629 .28451 L
.458 .28147 L
.4635 .27176 L
.46601 .26732 L
.46889 .26204 L
.47429 .25233 L
.47572 .24974 L
.47954 .24262 L
.48483 .23291 L
.48543 .23179 L
.48996 .22319 L
.49514 .21348 L
.49514 .21347 L
.50015 .20377 L
.50486 .19478 L
.50522 .19406 L
.51015 .18434 L
.51457 .17573 L
.5151 .17463 L
.51995 .16492 L
.52428 .15633 L
.52482 .15521 L
.52957 .14549 L
.53399 .13658 L
.53437 .13578 L
.53903 .12607 L
.54371 .11649 L
.54377 .11636 L
.54833 .10664 L
.553 .09693 L
.55342 .09605 L
.55748 .08722 L
.56208 .07751 L
.56313 .07528 L
.56651 .06779 L
.57103 .05808 L
.57284 .05417 L
.5754 .04837 L
.57985 .03866 L
.58256 .03274 L
.58419 .02894 L
.58854 .01923 L
.01923 .01923 L
F
0 g
.01923 .78205 m
.02474 .77681 L
.02894 .77234 L
.03419 .76709 L
.03866 .76263 L
.0439 .75738 L
.04837 .75291 L
.05361 .74767 L
.05808 .7432 L
.06333 .73796 L
.06779 .73349 L
.07304 .72824 L
.07751 .72378 L
.08275 .71853 L
.08722 .71406 L
.09246 .70882 L
.09693 .70435 L
.10218 .69911 L
.10664 .69464 L
.11189 .68939 L
.11636 .68493 L
.1216 .67968 L
.12607 .67521 L
.13131 .66997 L
.13578 .6655 L
.14103 .66026 L
.14549 .65579 L
.15074 .65054 L
.15521 .64608 L
.16045 .64083 L
.16492 .63636 L
.17016 .63112 L
.17463 .62665 L
.17988 .62141 L
.18434 .61694 L
.18959 .61169 L
.19406 .60723 L
.1993 .60198 L
.20377 .59751 L
.20901 .59227 L
.21348 .5878 L
.21873 .58256 L
.22319 .57809 L
.22844 .57284 L
.23291 .56838 L
.23815 .56313 L
.24262 .55866 L
.24786 .55342 L
.25233 .54895 L
.25758 .54371 L
Mistroke
.26204 .53924 L
.26729 .53399 L
.27176 .52953 L
.277 .52428 L
.28147 .51981 L
.28671 .51457 L
.29118 .5101 L
.29643 .50486 L
.30089 .50039 L
.30614 .49514 L
.31061 .49068 L
.31585 .48543 L
.32032 .48096 L
.32556 .47572 L
.33003 .47125 L
.33558 .46601 L
.33974 .46154 L
.34377 .45629 L
.34946 .44843 L
.35083 .44658 L
.35798 .43687 L
.35917 .43523 L
.36502 .42716 L
.36888 .42178 L
.37197 .41744 L
.37859 .40806 L
.37883 .40773 L
.38553 .39802 L
.38831 .39396 L
.39212 .38831 L
.39802 .37951 L
.39862 .37859 L
.40498 .36888 L
.40773 .36466 L
.41123 .35917 L
.41743 .34946 L
.41744 .34943 L
.42346 .33974 L
.42716 .33378 L
.42942 .33003 L
.43532 .32032 L
.43687 .31775 L
.44109 .31061 L
.44658 .30134 L
.44683 .30089 L
.45244 .29118 L
.45629 .28451 L
.458 .28147 L
.4635 .27176 L
.46601 .26732 L
Mistroke
.46889 .26204 L
.47429 .25233 L
.47572 .24974 L
.47954 .24262 L
.48483 .23291 L
.48543 .23179 L
.48996 .22319 L
.49514 .21348 L
.49514 .21347 L
.50015 .20377 L
.50486 .19478 L
.50522 .19406 L
.51015 .18434 L
.51457 .17573 L
.5151 .17463 L
.51995 .16492 L
.52428 .15633 L
.52482 .15521 L
.52957 .14549 L
.53399 .13658 L
.53437 .13578 L
.53903 .12607 L
.54371 .11649 L
.54377 .11636 L
.54833 .10664 L
.553 .09693 L
.55342 .09605 L
.55748 .08722 L
.56208 .07751 L
.56313 .07528 L
.56651 .06779 L
.57103 .05808 L
.57284 .05417 L
.5754 .04837 L
.57985 .03866 L
.58256 .03274 L
.58419 .02894 L
.58854 .01923 L
Mfstroke
.5 g
.01923 .73838 m
.01966 .73796 L
.02894 .72867 L
.02936 .72824 L
.03866 .71895 L
.03908 .71853 L
.04837 .70924 L
.04879 .70882 L
.05808 .69953 L
.0585 .69911 L
.06779 .68982 L
.06821 .68939 L
.07751 .6801 L
.07793 .67968 L
.08722 .67039 L
.08764 .66997 L
.09693 .66068 L
.09735 .66026 L
.10664 .65097 L
.10706 .65054 L
.11636 .64125 L
.11678 .64083 L
.12607 .63154 L
.12649 .63112 L
.13578 .62183 L
.1362 .62141 L
.14549 .61212 L
.14591 .61169 L
.15521 .6024 L
.15563 .60198 L
.16492 .59269 L
.16534 .59227 L
.17463 .58298 L
.17505 .58256 L
.18434 .57327 L
.18476 .57284 L
.19406 .56355 L
.19448 .56313 L
.20377 .55384 L
.20419 .55342 L
.21348 .54413 L
.2139 .54371 L
.22319 .53442 L
.22362 .53399 L
.23291 .5247 L
.23333 .52428 L
.24262 .51499 L
.24304 .51457 L
.25233 .50528 L
.25275 .50486 L
.26204 .49557 L
.26247 .49514 L
.27176 .48585 L
.27218 .48543 L
.28147 .47614 L
.28189 .47572 L
.29118 .46643 L
.2916 .46601 L
.30089 .45672 L
.30132 .45629 L
.31061 .447 L
.31103 .44658 L
.32032 .43729 L
.32074 .43687 L
.33003 .42758 L
.33046 .42716 L
.33974 .41787 L
.34014 .41744 L
.34895 .40773 L
.34946 .40716 L
.35737 .39802 L
.35917 .39587 L
.36542 .38831 L
.36888 .38401 L
.37318 .37859 L
.37859 .3716 L
.38067 .36888 L
.38792 .35917 L
.38831 .35865 L
.39497 .34946 L
.39802 .34518 L
.40184 .33974 L
.40773 .33121 L
.40853 .33003 L
.41508 .32032 L
.41744 .31675 L
.42147 .31061 L
.42716 .30181 L
.42775 .30089 L
.4339 .29118 L
.43687 .28642 L
.43993 .28147 L
.44587 .27176 L
.44658 .27058 L
.45171 .26204 L
.45629 .25431 L
.45745 .25233 L
.46312 .24262 L
.46601 .23761 L
.46869 .23291 L
.4742 .22319 L
.47572 .22049 L
.47963 .21348 L
.48499 .20377 L
.48543 .20297 L
.49028 .19406 L
.49514 .18504 L
.49552 .18434 L
.50069 .17463 L
.50486 .16673 L
.5058 .16492 L
.51086 .15521 L
.51457 .14804 L
.51587 .14549 L
.52083 .13578 L
.52428 .12897 L
.52574 .12607 L
.5306 .11636 L
.53399 .10954 L
.53542 .10664 L
.54019 .09693 L
.54371 .08974 L
.54492 .08722 L
.54962 .07751 L
.55342 .06959 L
.55427 .06779 L
.55888 .05808 L
.56313 .04909 L
.56347 .04837 L
.568 .03866 L
.57252 .02894 L
.57284 .02825 L
.57699 .01923 L
.01923 .01923 L
F
0 g
.01923 .73838 m
.01966 .73796 L
.02894 .72867 L
.02936 .72824 L
.03866 .71895 L
.03908 .71853 L
.04837 .70924 L
.04879 .70882 L
.05808 .69953 L
.0585 .69911 L
.06779 .68982 L
.06821 .68939 L
.07751 .6801 L
.07793 .67968 L
.08722 .67039 L
.08764 .66997 L
.09693 .66068 L
.09735 .66026 L
.10664 .65097 L
.10706 .65054 L
.11636 .64125 L
.11678 .64083 L
.12607 .63154 L
.12649 .63112 L
.13578 .62183 L
.1362 .62141 L
.14549 .61212 L
.14591 .61169 L
.15521 .6024 L
.15563 .60198 L
.16492 .59269 L
.16534 .59227 L
.17463 .58298 L
.17505 .58256 L
.18434 .57327 L
.18476 .57284 L
.19406 .56355 L
.19448 .56313 L
.20377 .55384 L
.20419 .55342 L
.21348 .54413 L
.2139 .54371 L
.22319 .53442 L
.22362 .53399 L
.23291 .5247 L
.23333 .52428 L
.24262 .51499 L
.24304 .51457 L
.25233 .50528 L
.25275 .50486 L
Mistroke
.26204 .49557 L
.26247 .49514 L
.27176 .48585 L
.27218 .48543 L
.28147 .47614 L
.28189 .47572 L
.29118 .46643 L
.2916 .46601 L
.30089 .45672 L
.30132 .45629 L
.31061 .447 L
.31103 .44658 L
.32032 .43729 L
.32074 .43687 L
.33003 .42758 L
.33046 .42716 L
.33974 .41787 L
.34014 .41744 L
.34895 .40773 L
.34946 .40716 L
.35737 .39802 L
.35917 .39587 L
.36542 .38831 L
.36888 .38401 L
.37318 .37859 L
.37859 .3716 L
.38067 .36888 L
.38792 .35917 L
.38831 .35865 L
.39497 .34946 L
.39802 .34518 L
.40184 .33974 L
.40773 .33121 L
.40853 .33003 L
.41508 .32032 L
.41744 .31675 L
.42147 .31061 L
.42716 .30181 L
.42775 .30089 L
.4339 .29118 L
.43687 .28642 L
.43993 .28147 L
.44587 .27176 L
.44658 .27058 L
.45171 .26204 L
.45629 .25431 L
.45745 .25233 L
.46312 .24262 L
.46601 .23761 L
.46869 .23291 L
Mistroke
.4742 .22319 L
.47572 .22049 L
.47963 .21348 L
.48499 .20377 L
.48543 .20297 L
.49028 .19406 L
.49514 .18504 L
.49552 .18434 L
.50069 .17463 L
.50486 .16673 L
.5058 .16492 L
.51086 .15521 L
.51457 .14804 L
.51587 .14549 L
.52083 .13578 L
.52428 .12897 L
.52574 .12607 L
.5306 .11636 L
.53399 .10954 L
.53542 .10664 L
.54019 .09693 L
.54371 .08974 L
.54492 .08722 L
.54962 .07751 L
.55342 .06959 L
.55427 .06779 L
.55888 .05808 L
.56313 .04909 L
.56347 .04837 L
.568 .03866 L
.57252 .02894 L
.57284 .02825 L
.57699 .01923 L
Mfstroke
.4 g
.01923 .70297 m
.02309 .69911 L
.02894 .69325 L
.0328 .68939 L
.03866 .68354 L
.04252 .67968 L
.04837 .67383 L
.05223 .66997 L
.05808 .66412 L
.06194 .66026 L
.06779 .6544 L
.07165 .65054 L
.07751 .64469 L
.08137 .64083 L
.08722 .63498 L
.09108 .63112 L
.09693 .62527 L
.10079 .62141 L
.10664 .61555 L
.1105 .61169 L
.11636 .60584 L
.12022 .60198 L
.12607 .59613 L
.12993 .59227 L
.13578 .58642 L
.13964 .58256 L
.14549 .5767 L
.14935 .57284 L
.15521 .56699 L
.15907 .56313 L
.16492 .55728 L
.16878 .55342 L
.17463 .54757 L
.17849 .54371 L
.18434 .53785 L
.1882 .53399 L
.19406 .52814 L
.19792 .52428 L
.20377 .51843 L
.20763 .51457 L
.21348 .50872 L
.21734 .50486 L
.22319 .499 L
.22705 .49514 L
.23291 .48929 L
.23677 .48543 L
.24262 .47958 L
.24648 .47572 L
.25233 .46987 L
.25619 .46601 L
.26204 .46015 L
.2659 .45629 L
.27176 .45044 L
.27562 .44658 L
.28147 .44073 L
.28533 .43687 L
.29118 .43102 L
.29504 .42716 L
.30089 .4213 L
.30475 .41744 L
.31061 .41159 L
.31447 .40773 L
.32032 .40188 L
.32418 .39802 L
.33003 .39217 L
.33391 .38831 L
.33974 .38245 L
.34368 .37859 L
.34946 .37301 L
.35349 .36888 L
.35917 .36278 L
.36246 .35917 L
.36888 .35184 L
.37093 .34946 L
.37859 .34023 L
.37899 .33974 L
.38673 .33003 L
.38831 .32799 L
.39418 .32032 L
.39802 .31516 L
.40138 .31061 L
.40773 .30176 L
.40835 .30089 L
.41516 .29118 L
.41744 .28783 L
.42178 .28147 L
.42716 .27338 L
.42823 .27176 L
.43457 .26204 L
.43687 .25844 L
.44076 .25233 L
.44658 .24301 L
.44683 .24262 L
.45281 .23291 L
.45629 .22712 L
.45866 .22319 L
.46443 .21348 L
.46601 .21078 L
.47011 .20377 L
.47568 .19406 L
.47572 .194 L
.48121 .18434 L
.48543 .17679 L
.48664 .17463 L
.49202 .16492 L
.49514 .15917 L
.4973 .15521 L
.50255 .14549 L
.50486 .14114 L
.50771 .13578 L
.51283 .12607 L
.51457 .12271 L
.51789 .11636 L
.52289 .10664 L
.52428 .1039 L
.52784 .09693 L
.53275 .08722 L
.53399 .08471 L
.5376 .07751 L
.54241 .06779 L
.54371 .06514 L
.54718 .05808 L
.55191 .04837 L
.55342 .04521 L
.55659 .03866 L
.56124 .02894 L
.56313 .02492 L
.56584 .01923 L
.01923 .01923 L
F
0 g
.01923 .70297 m
.02309 .69911 L
.02894 .69325 L
.0328 .68939 L
.03866 .68354 L
.04252 .67968 L
.04837 .67383 L
.05223 .66997 L
.05808 .66412 L
.06194 .66026 L
.06779 .6544 L
.07165 .65054 L
.07751 .64469 L
.08137 .64083 L
.08722 .63498 L
.09108 .63112 L
.09693 .62527 L
.10079 .62141 L
.10664 .61555 L
.1105 .61169 L
.11636 .60584 L
.12022 .60198 L
.12607 .59613 L
.12993 .59227 L
.13578 .58642 L
.13964 .58256 L
.14549 .5767 L
.14935 .57284 L
.15521 .56699 L
.15907 .56313 L
.16492 .55728 L
.16878 .55342 L
.17463 .54757 L
.17849 .54371 L
.18434 .53785 L
.1882 .53399 L
.19406 .52814 L
.19792 .52428 L
.20377 .51843 L
.20763 .51457 L
.21348 .50872 L
.21734 .50486 L
.22319 .499 L
.22705 .49514 L
.23291 .48929 L
.23677 .48543 L
.24262 .47958 L
.24648 .47572 L
.25233 .46987 L
.25619 .46601 L
Mistroke
.26204 .46015 L
.2659 .45629 L
.27176 .45044 L
.27562 .44658 L
.28147 .44073 L
.28533 .43687 L
.29118 .43102 L
.29504 .42716 L
.30089 .4213 L
.30475 .41744 L
.31061 .41159 L
.31447 .40773 L
.32032 .40188 L
.32418 .39802 L
.33003 .39217 L
.33391 .38831 L
.33974 .38245 L
.34368 .37859 L
.34946 .37301 L
.35349 .36888 L
.35917 .36278 L
.36246 .35917 L
.36888 .35184 L
.37093 .34946 L
.37859 .34023 L
.37899 .33974 L
.38673 .33003 L
.38831 .32799 L
.39418 .32032 L
.39802 .31516 L
.40138 .31061 L
.40773 .30176 L
.40835 .30089 L
.41516 .29118 L
.41744 .28783 L
.42178 .28147 L
.42716 .27338 L
.42823 .27176 L
.43457 .26204 L
.43687 .25844 L
.44076 .25233 L
.44658 .24301 L
.44683 .24262 L
.45281 .23291 L
.45629 .22712 L
.45866 .22319 L
.46443 .21348 L
.46601 .21078 L
.47011 .20377 L
.47568 .19406 L
Mistroke
.47572 .194 L
.48121 .18434 L
.48543 .17679 L
.48664 .17463 L
.49202 .16492 L
.49514 .15917 L
.4973 .15521 L
.50255 .14549 L
.50486 .14114 L
.50771 .13578 L
.51283 .12607 L
.51457 .12271 L
.51789 .11636 L
.52289 .10664 L
.52428 .1039 L
.52784 .09693 L
.53275 .08722 L
.53399 .08471 L
.5376 .07751 L
.54241 .06779 L
.54371 .06514 L
.54718 .05808 L
.55191 .04837 L
.55342 .04521 L
.55659 .03866 L
.56124 .02894 L
.56313 .02492 L
.56584 .01923 L
Mfstroke
.3 g
.01923 .65927 m
.02792 .65054 L
.02894 .64956 L
.03767 .64083 L
.03866 .63985 L
.04738 .63112 L
.04837 .63013 L
.0571 .62141 L
.05808 .62042 L
.06681 .61169 L
.06779 .61071 L
.07652 .60198 L
.07751 .601 L
.08623 .59227 L
.08722 .59128 L
.09595 .58256 L
.09693 .58157 L
.10566 .57284 L
.10664 .57186 L
.11537 .56313 L
.11636 .56215 L
.12508 .55342 L
.12607 .55243 L
.1348 .54371 L
.13578 .54272 L
.14451 .53399 L
.14549 .53301 L
.15422 .52428 L
.15521 .5233 L
.16393 .51457 L
.16492 .51358 L
.17365 .50486 L
.17463 .50387 L
.18336 .49514 L
.18434 .49416 L
.19307 .48543 L
.19406 .48445 L
.20278 .47572 L
.20377 .47473 L
.2125 .46601 L
.21348 .46502 L
.22221 .45629 L
.22319 .45531 L
.23192 .44658 L
.23291 .4456 L
.24163 .43687 L
.24262 .43588 L
.25135 .42716 L
.25233 .42617 L
.26106 .41744 L
.26204 .41646 L
.27077 .40773 L
.27176 .40675 L
.28048 .39802 L
.28147 .39703 L
.2902 .38831 L
.29118 .38732 L
.29991 .37859 L
.30089 .37761 L
.30962 .36888 L
.31061 .3679 L
.31933 .35917 L
.32032 .35818 L
.32905 .34946 L
.33003 .34847 L
.33869 .33974 L
.33974 .33876 L
.34946 .33174 L
.35172 .33003 L
.35917 .32344 L
.36267 .32032 L
.36888 .31406 L
.37235 .31061 L
.37859 .30377 L
.38125 .30089 L
.38831 .29266 L
.38958 .29118 L
.39754 .28147 L
.39802 .28082 L
.40522 .27176 L
.40773 .26832 L
.41252 .26204 L
.41744 .25516 L
.41952 .25233 L
.42637 .24262 L
.42716 .24141 L
.43308 .23291 L
.43687 .22711 L
.43952 .22319 L
.44584 .21348 L
.44658 .21226 L
.4521 .20377 L
.45629 .19691 L
.4581 .19406 L
.46411 .18434 L
.46601 .18107 L
.46995 .17463 L
.47562 .16492 L
.47572 .16474 L
.48138 .15521 L
.48543 .14797 L
.48687 .14549 L
.49243 .13578 L
.49514 .13075 L
.4978 .12607 L
.50317 .11636 L
.50486 .1131 L
.50842 .10664 L
.51361 .09693 L
.51457 .09502 L
.51879 .08722 L
.52381 .07751 L
.52428 .07654 L
.52891 .06779 L
.5338 .05808 L
.53399 .05766 L
.53881 .04837 L
.54359 .03866 L
.54371 .0384 L
.54851 .02894 L
.5532 .01923 L
.01923 .01923 L
F
0 g
.01923 .65927 m
.02792 .65054 L
.02894 .64956 L
.03767 .64083 L
.03866 .63985 L
.04738 .63112 L
.04837 .63013 L
.0571 .62141 L
.05808 .62042 L
.06681 .61169 L
.06779 .61071 L
.07652 .60198 L
.07751 .601 L
.08623 .59227 L
.08722 .59128 L
.09595 .58256 L
.09693 .58157 L
.10566 .57284 L
.10664 .57186 L
.11537 .56313 L
.11636 .56215 L
.12508 .55342 L
.12607 .55243 L
.1348 .54371 L
.13578 .54272 L
.14451 .53399 L
.14549 .53301 L
.15422 .52428 L
.15521 .5233 L
.16393 .51457 L
.16492 .51358 L
.17365 .50486 L
.17463 .50387 L
.18336 .49514 L
.18434 .49416 L
.19307 .48543 L
.19406 .48445 L
.20278 .47572 L
.20377 .47473 L
.2125 .46601 L
.21348 .46502 L
.22221 .45629 L
.22319 .45531 L
.23192 .44658 L
.23291 .4456 L
.24163 .43687 L
.24262 .43588 L
.25135 .42716 L
.25233 .42617 L
.26106 .41744 L
Mistroke
.26204 .41646 L
.27077 .40773 L
.27176 .40675 L
.28048 .39802 L
.28147 .39703 L
.2902 .38831 L
.29118 .38732 L
.29991 .37859 L
.30089 .37761 L
.30962 .36888 L
.31061 .3679 L
.31933 .35917 L
.32032 .35818 L
.32905 .34946 L
.33003 .34847 L
.33869 .33974 L
.33974 .33876 L
.34946 .33174 L
.35172 .33003 L
.35917 .32344 L
.36267 .32032 L
.36888 .31406 L
.37235 .31061 L
.37859 .30377 L
.38125 .30089 L
.38831 .29266 L
.38958 .29118 L
.39754 .28147 L
.39802 .28082 L
.40522 .27176 L
.40773 .26832 L
.41252 .26204 L
.41744 .25516 L
.41952 .25233 L
.42637 .24262 L
.42716 .24141 L
.43308 .23291 L
.43687 .22711 L
.43952 .22319 L
.44584 .21348 L
.44658 .21226 L
.4521 .20377 L
.45629 .19691 L
.4581 .19406 L
.46411 .18434 L
.46601 .18107 L
.46995 .17463 L
.47562 .16492 L
.47572 .16474 L
.48138 .15521 L
Mistroke
.48543 .14797 L
.48687 .14549 L
.49243 .13578 L
.49514 .13075 L
.4978 .12607 L
.50317 .11636 L
.50486 .1131 L
.50842 .10664 L
.51361 .09693 L
.51457 .09502 L
.51879 .08722 L
.52381 .07751 L
.52428 .07654 L
.52891 .06779 L
.5338 .05808 L
.53399 .05766 L
.53881 .04837 L
.54359 .03866 L
.54371 .0384 L
.54851 .02894 L
.5532 .01923 L
Mfstroke
.4 g
.01923 .58069 m
.02717 .57284 L
.02894 .57098 L
.03679 .56313 L
.03866 .56127 L
.0465 .55342 L
.04837 .55155 L
.05622 .54371 L
.05808 .54184 L
.06593 .53399 L
.06779 .53213 L
.07564 .52428 L
.07751 .52242 L
.08535 .51457 L
.08722 .5127 L
.09507 .50486 L
.09693 .50299 L
.10478 .49514 L
.10664 .49328 L
.11449 .48543 L
.11636 .48357 L
.1242 .47572 L
.12607 .47385 L
.13392 .46601 L
.13578 .46414 L
.14363 .45629 L
.14549 .45443 L
.15334 .44658 L
.15521 .44472 L
.16305 .43687 L
.16492 .435 L
.17277 .42716 L
.17463 .42529 L
.18248 .41744 L
.18434 .41558 L
.19219 .40773 L
.19406 .40587 L
.2019 .39802 L
.20377 .39615 L
.21162 .38831 L
.21348 .38644 L
.22133 .37859 L
.22319 .37673 L
.23104 .36888 L
.23291 .36702 L
.24075 .35917 L
.24262 .3573 L
.25047 .34946 L
.25233 .34759 L
.26018 .33974 L
.26204 .33788 L
.26989 .33003 L
.27176 .32817 L
.2796 .32032 L
.28147 .31845 L
.28932 .31061 L
.29118 .30874 L
.29903 .30089 L
.30089 .29903 L
.30874 .29118 L
.31061 .28932 L
.31845 .28147 L
.32032 .2796 L
.32817 .27176 L
.33003 .26989 L
.33806 .26204 L
.33974 .26018 L
.34565 .25233 L
.34946 .24703 L
.35272 .24262 L
.35917 .23385 L
.35986 .23291 L
.36689 .22319 L
.36888 .22041 L
.3738 .21348 L
.37859 .20666 L
.3806 .20377 L
.38731 .19406 L
.38831 .19259 L
.39385 .18434 L
.39802 .17812 L
.40031 .17463 L
.40667 .16492 L
.40773 .16328 L
.41288 .15521 L
.41744 .14803 L
.41902 .14549 L
.42507 .13578 L
.42716 .1324 L
.43099 .12607 L
.43687 .11638 L
.43688 .11636 L
.44262 .10664 L
.44658 .09994 L
.44831 .09693 L
.45394 .08722 L
.45629 .08313 L
.45945 .07751 L
.46496 .06779 L
.46601 .06594 L
.47032 .05808 L
.47572 .04837 L
.47572 .04836 L
.48095 .03866 L
.48543 .0304 L
.48619 .02894 L
.49133 .01923 L
.01923 .01923 L
F
0 g
.01923 .58069 m
.02717 .57284 L
.02894 .57098 L
.03679 .56313 L
.03866 .56127 L
.0465 .55342 L
.04837 .55155 L
.05622 .54371 L
.05808 .54184 L
.06593 .53399 L
.06779 .53213 L
.07564 .52428 L
.07751 .52242 L
.08535 .51457 L
.08722 .5127 L
.09507 .50486 L
.09693 .50299 L
.10478 .49514 L
.10664 .49328 L
.11449 .48543 L
.11636 .48357 L
.1242 .47572 L
.12607 .47385 L
.13392 .46601 L
.13578 .46414 L
.14363 .45629 L
.14549 .45443 L
.15334 .44658 L
.15521 .44472 L
.16305 .43687 L
.16492 .435 L
.17277 .42716 L
.17463 .42529 L
.18248 .41744 L
.18434 .41558 L
.19219 .40773 L
.19406 .40587 L
.2019 .39802 L
.20377 .39615 L
.21162 .38831 L
.21348 .38644 L
.22133 .37859 L
.22319 .37673 L
.23104 .36888 L
.23291 .36702 L
.24075 .35917 L
.24262 .3573 L
.25047 .34946 L
.25233 .34759 L
.26018 .33974 L
Mistroke
.26204 .33788 L
.26989 .33003 L
.27176 .32817 L
.2796 .32032 L
.28147 .31845 L
.28932 .31061 L
.29118 .30874 L
.29903 .30089 L
.30089 .29903 L
.30874 .29118 L
.31061 .28932 L
.31845 .28147 L
.32032 .2796 L
.32817 .27176 L
.33003 .26989 L
.33806 .26204 L
.33974 .26018 L
.34565 .25233 L
.34946 .24703 L
.35272 .24262 L
.35917 .23385 L
.35986 .23291 L
.36689 .22319 L
.36888 .22041 L
.3738 .21348 L
.37859 .20666 L
.3806 .20377 L
.38731 .19406 L
.38831 .19259 L
.39385 .18434 L
.39802 .17812 L
.40031 .17463 L
.40667 .16492 L
.40773 .16328 L
.41288 .15521 L
.41744 .14803 L
.41902 .14549 L
.42507 .13578 L
.42716 .1324 L
.43099 .12607 L
.43687 .11638 L
.43688 .11636 L
.44262 .10664 L
.44658 .09994 L
.44831 .09693 L
.45394 .08722 L
.45629 .08313 L
.45945 .07751 L
.46496 .06779 L
.46601 .06594 L
Mistroke
.47032 .05808 L
.47572 .04837 L
.47572 .04836 L
.48095 .03866 L
.48543 .0304 L
.48619 .02894 L
.49133 .01923 L
Mfstroke
.5 g
.01923 .53699 m
.02224 .53399 L
.02894 .52728 L
.03194 .52428 L
.03866 .51757 L
.04165 .51457 L
.04837 .50785 L
.05137 .50486 L
.05808 .49814 L
.06108 .49514 L
.06779 .48843 L
.07079 .48543 L
.07751 .47872 L
.0805 .47572 L
.08722 .469 L
.09022 .46601 L
.09693 .45929 L
.09993 .45629 L
.10664 .44958 L
.10964 .44658 L
.11636 .43987 L
.11935 .43687 L
.12607 .43015 L
.12907 .42716 L
.13578 .42044 L
.13878 .41744 L
.14549 .41073 L
.14849 .40773 L
.15521 .40102 L
.1582 .39802 L
.16492 .3913 L
.16792 .38831 L
.17463 .38159 L
.17763 .37859 L
.18434 .37188 L
.18734 .36888 L
.19406 .36217 L
.19705 .35917 L
.20377 .35245 L
.20677 .34946 L
.21348 .34274 L
.21648 .33974 L
.22319 .33303 L
.22619 .33003 L
.23291 .32332 L
.2359 .32032 L
.24262 .3136 L
.24562 .31061 L
.25233 .30389 L
.25533 .30089 L
.26204 .29418 L
.26504 .29118 L
.27176 .28447 L
.27475 .28147 L
.28147 .27475 L
.28447 .27176 L
.29118 .26504 L
.29418 .26204 L
.30089 .25533 L
.30389 .25233 L
.31061 .24562 L
.3136 .24262 L
.32032 .2359 L
.32332 .23291 L
.33003 .22619 L
.3331 .22319 L
.33974 .21648 L
.34252 .21348 L
.34946 .20578 L
.35123 .20377 L
.35917 .19449 L
.35953 .19406 L
.36751 .18434 L
.36888 .18263 L
.37519 .17463 L
.37859 .17021 L
.38261 .16492 L
.38831 .15726 L
.38981 .15521 L
.39681 .14549 L
.39802 .14379 L
.40363 .13578 L
.40773 .12982 L
.41028 .12607 L
.41679 .11636 L
.41744 .11536 L
.42315 .10664 L
.42716 .10043 L
.42939 .09693 L
.43551 .08722 L
.43687 .08504 L
.44152 .07751 L
.44658 .0692 L
.44743 .06779 L
.45324 .05808 L
.45629 .05292 L
.45896 .04837 L
.46461 .03866 L
.46601 .03622 L
.47016 .02894 L
.47565 .01923 L
.01923 .01923 L
F
0 g
.01923 .53699 m
.02224 .53399 L
.02894 .52728 L
.03194 .52428 L
.03866 .51757 L
.04165 .51457 L
.04837 .50785 L
.05137 .50486 L
.05808 .49814 L
.06108 .49514 L
.06779 .48843 L
.07079 .48543 L
.07751 .47872 L
.0805 .47572 L
.08722 .469 L
.09022 .46601 L
.09693 .45929 L
.09993 .45629 L
.10664 .44958 L
.10964 .44658 L
.11636 .43987 L
.11935 .43687 L
.12607 .43015 L
.12907 .42716 L
.13578 .42044 L
.13878 .41744 L
.14549 .41073 L
.14849 .40773 L
.15521 .40102 L
.1582 .39802 L
.16492 .3913 L
.16792 .38831 L
.17463 .38159 L
.17763 .37859 L
.18434 .37188 L
.18734 .36888 L
.19406 .36217 L
.19705 .35917 L
.20377 .35245 L
.20677 .34946 L
.21348 .34274 L
.21648 .33974 L
.22319 .33303 L
.22619 .33003 L
.23291 .32332 L
.2359 .32032 L
.24262 .3136 L
.24562 .31061 L
.25233 .30389 L
.25533 .30089 L
Mistroke
.26204 .29418 L
.26504 .29118 L
.27176 .28447 L
.27475 .28147 L
.28147 .27475 L
.28447 .27176 L
.29118 .26504 L
.29418 .26204 L
.30089 .25533 L
.30389 .25233 L
.31061 .24562 L
.3136 .24262 L
.32032 .2359 L
.32332 .23291 L
.33003 .22619 L
.3331 .22319 L
.33974 .21648 L
.34252 .21348 L
.34946 .20578 L
.35123 .20377 L
.35917 .19449 L
.35953 .19406 L
.36751 .18434 L
.36888 .18263 L
.37519 .17463 L
.37859 .17021 L
.38261 .16492 L
.38831 .15726 L
.38981 .15521 L
.39681 .14549 L
.39802 .14379 L
.40363 .13578 L
.40773 .12982 L
.41028 .12607 L
.41679 .11636 L
.41744 .11536 L
.42315 .10664 L
.42716 .10043 L
.42939 .09693 L
.43551 .08722 L
.43687 .08504 L
.44152 .07751 L
.44658 .0692 L
.44743 .06779 L
.45324 .05808 L
.45629 .05292 L
.45896 .04837 L
.46461 .03866 L
.46601 .03622 L
.47016 .02894 L
Mistroke
.47565 .01923 L
Mfstroke
.6 g
.01923 .50158 m
.02567 .49514 L
.02894 .49187 L
.03538 .48543 L
.03866 .48216 L
.0451 .47572 L
.04837 .47245 L
.05481 .46601 L
.05808 .46273 L
.06452 .45629 L
.06779 .45302 L
.07423 .44658 L
.07751 .44331 L
.08395 .43687 L
.08722 .4336 L
.09366 .42716 L
.09693 .42388 L
.10337 .41744 L
.10664 .41417 L
.11308 .40773 L
.11636 .40446 L
.1228 .39802 L
.12607 .39475 L
.13251 .38831 L
.13578 .38503 L
.14222 .37859 L
.14549 .37532 L
.15193 .36888 L
.15521 .36561 L
.16165 .35917 L
.16492 .3559 L
.17136 .34946 L
.17463 .34618 L
.18107 .33974 L
.18434 .33647 L
.19078 .33003 L
.19406 .32676 L
.2005 .32032 L
.20377 .31705 L
.21021 .31061 L
.21348 .30733 L
.21992 .30089 L
.22319 .29762 L
.22963 .29118 L
.23291 .28791 L
.23935 .28147 L
.24262 .2782 L
.24906 .27176 L
.25233 .26848 L
.25877 .26204 L
.26204 .25877 L
.26848 .25233 L
.27176 .24906 L
.2782 .24262 L
.28147 .23935 L
.28791 .23291 L
.29118 .22963 L
.29762 .22319 L
.30089 .21992 L
.30733 .21348 L
.31061 .21021 L
.31705 .20377 L
.32032 .2005 L
.32676 .19406 L
.33003 .19078 L
.33648 .18434 L
.33974 .18107 L
.34634 .17463 L
.34946 .17163 L
.35593 .16492 L
.35917 .1614 L
.36476 .15521 L
.36888 .15046 L
.37312 .14549 L
.37859 .13884 L
.38108 .13578 L
.38831 .1266 L
.38872 .12607 L
.39611 .11636 L
.39802 .11378 L
.40326 .10664 L
.40773 .10038 L
.41018 .09693 L
.41692 .08722 L
.41744 .08645 L
.42351 .07751 L
.42716 .072 L
.42993 .06779 L
.43622 .05808 L
.43687 .05705 L
.44239 .04837 L
.44658 .04163 L
.44843 .03866 L
.45437 .02894 L
.45629 .02573 L
.46021 .01923 L
.01923 .01923 L
F
0 g
.01923 .50158 m
.02567 .49514 L
.02894 .49187 L
.03538 .48543 L
.03866 .48216 L
.0451 .47572 L
.04837 .47245 L
.05481 .46601 L
.05808 .46273 L
.06452 .45629 L
.06779 .45302 L
.07423 .44658 L
.07751 .44331 L
.08395 .43687 L
.08722 .4336 L
.09366 .42716 L
.09693 .42388 L
.10337 .41744 L
.10664 .41417 L
.11308 .40773 L
.11636 .40446 L
.1228 .39802 L
.12607 .39475 L
.13251 .38831 L
.13578 .38503 L
.14222 .37859 L
.14549 .37532 L
.15193 .36888 L
.15521 .36561 L
.16165 .35917 L
.16492 .3559 L
.17136 .34946 L
.17463 .34618 L
.18107 .33974 L
.18434 .33647 L
.19078 .33003 L
.19406 .32676 L
.2005 .32032 L
.20377 .31705 L
.21021 .31061 L
.21348 .30733 L
.21992 .30089 L
.22319 .29762 L
.22963 .29118 L
.23291 .28791 L
.23935 .28147 L
.24262 .2782 L
.24906 .27176 L
.25233 .26848 L
.25877 .26204 L
Mistroke
.26204 .25877 L
.26848 .25233 L
.27176 .24906 L
.2782 .24262 L
.28147 .23935 L
.28791 .23291 L
.29118 .22963 L
.29762 .22319 L
.30089 .21992 L
.30733 .21348 L
.31061 .21021 L
.31705 .20377 L
.32032 .2005 L
.32676 .19406 L
.33003 .19078 L
.33648 .18434 L
.33974 .18107 L
.34634 .17463 L
.34946 .17163 L
.35593 .16492 L
.35917 .1614 L
.36476 .15521 L
.36888 .15046 L
.37312 .14549 L
.37859 .13884 L
.38108 .13578 L
.38831 .1266 L
.38872 .12607 L
.39611 .11636 L
.39802 .11378 L
.40326 .10664 L
.40773 .10038 L
.41018 .09693 L
.41692 .08722 L
.41744 .08645 L
.42351 .07751 L
.42716 .072 L
.42993 .06779 L
.43622 .05808 L
.43687 .05705 L
.44239 .04837 L
.44658 .04163 L
.44843 .03866 L
.45437 .02894 L
.45629 .02573 L
.46021 .01923 L
Mfstroke
.7 g
.01923 .45788 m
.02078 .45629 L
.02894 .44817 L
.03053 .44658 L
.03866 .43845 L
.04024 .43687 L
.04837 .42874 L
.04995 .42716 L
.05808 .41903 L
.05967 .41744 L
.06779 .40932 L
.06938 .40773 L
.07751 .3996 L
.07909 .39802 L
.08722 .38989 L
.0888 .38831 L
.09693 .38018 L
.09852 .37859 L
.10664 .37047 L
.10823 .36888 L
.11636 .36075 L
.11794 .35917 L
.12607 .35104 L
.12765 .34946 L
.13578 .34133 L
.13737 .33974 L
.14549 .33162 L
.14708 .33003 L
.15521 .3219 L
.15679 .32032 L
.16492 .31219 L
.1665 .31061 L
.17463 .30248 L
.17622 .30089 L
.18434 .29277 L
.18593 .29118 L
.19406 .28305 L
.19564 .28147 L
.20377 .27334 L
.20535 .27176 L
.21348 .26363 L
.21507 .26204 L
.22319 .25392 L
.22478 .25233 L
.23291 .2442 L
.23449 .24262 L
.24262 .23449 L
.2442 .23291 L
.25233 .22478 L
.25392 .22319 L
.26204 .21507 L
.26363 .21348 L
.27176 .20535 L
.27334 .20377 L
.28147 .19564 L
.28305 .19406 L
.29118 .18593 L
.29277 .18434 L
.30089 .17622 L
.30248 .17463 L
.31061 .1665 L
.31219 .16492 L
.32032 .15679 L
.3219 .15521 L
.33003 .14708 L
.33158 .14549 L
.33974 .13737 L
.34169 .13578 L
.34946 .13037 L
.35498 .12607 L
.35917 .12206 L
.36542 .11636 L
.36888 .11269 L
.37485 .10664 L
.37859 .1024 L
.38359 .09693 L
.38831 .09129 L
.3918 .08722 L
.39802 .07944 L
.39959 .07751 L
.40711 .06779 L
.40773 .06692 L
.41442 .05808 L
.41744 .05378 L
.4214 .04837 L
.42716 .04003 L
.42812 .03866 L
.43481 .02894 L
.43687 .0257 L
.44125 .01923 L
.01923 .01923 L
F
0 g
.01923 .45788 m
.02078 .45629 L
.02894 .44817 L
.03053 .44658 L
.03866 .43845 L
.04024 .43687 L
.04837 .42874 L
.04995 .42716 L
.05808 .41903 L
.05967 .41744 L
.06779 .40932 L
.06938 .40773 L
.07751 .3996 L
.07909 .39802 L
.08722 .38989 L
.0888 .38831 L
.09693 .38018 L
.09852 .37859 L
.10664 .37047 L
.10823 .36888 L
.11636 .36075 L
.11794 .35917 L
.12607 .35104 L
.12765 .34946 L
.13578 .34133 L
.13737 .33974 L
.14549 .33162 L
.14708 .33003 L
.15521 .3219 L
.15679 .32032 L
.16492 .31219 L
.1665 .31061 L
.17463 .30248 L
.17622 .30089 L
.18434 .29277 L
.18593 .29118 L
.19406 .28305 L
.19564 .28147 L
.20377 .27334 L
.20535 .27176 L
.21348 .26363 L
.21507 .26204 L
.22319 .25392 L
.22478 .25233 L
.23291 .2442 L
.23449 .24262 L
.24262 .23449 L
.2442 .23291 L
.25233 .22478 L
.25392 .22319 L
Mistroke
.26204 .21507 L
.26363 .21348 L
.27176 .20535 L
.27334 .20377 L
.28147 .19564 L
.28305 .19406 L
.29118 .18593 L
.29277 .18434 L
.30089 .17622 L
.30248 .17463 L
.31061 .1665 L
.31219 .16492 L
.32032 .15679 L
.3219 .15521 L
.33003 .14708 L
.33158 .14549 L
.33974 .13737 L
.34169 .13578 L
.34946 .13037 L
.35498 .12607 L
.35917 .12206 L
.36542 .11636 L
.36888 .11269 L
.37485 .10664 L
.37859 .1024 L
.38359 .09693 L
.38831 .09129 L
.3918 .08722 L
.39802 .07944 L
.39959 .07751 L
.40711 .06779 L
.40773 .06692 L
.41442 .05808 L
.41744 .05378 L
.4214 .04837 L
.42716 .04003 L
.42812 .03866 L
.43481 .02894 L
.43687 .0257 L
.44125 .01923 L
Mfstroke
.6 g
.01923 .37931 m
.02016 .37859 L
.02894 .3696 L
.02966 .36888 L
.03866 .35989 L
.03937 .35917 L
.04837 .35017 L
.04908 .34946 L
.05808 .34046 L
.0588 .33974 L
.06779 .33075 L
.06851 .33003 L
.07751 .32104 L
.07822 .32032 L
.08722 .31132 L
.08793 .31061 L
.09693 .30161 L
.09765 .30089 L
.10664 .2919 L
.10736 .29118 L
.11636 .28219 L
.11707 .28147 L
.12607 .27247 L
.12678 .27176 L
.13578 .26276 L
.1365 .26204 L
.14549 .25305 L
.14621 .25233 L
.15521 .24334 L
.15592 .24262 L
.16492 .23362 L
.16563 .23291 L
.17463 .22391 L
.17535 .22319 L
.18434 .2142 L
.18506 .21348 L
.19406 .20448 L
.19477 .20377 L
.20377 .19477 L
.20448 .19406 L
.21348 .18506 L
.2142 .18434 L
.22319 .17535 L
.22391 .17463 L
.23291 .16563 L
.23362 .16492 L
.24262 .15592 L
.24334 .15521 L
.25233 .14621 L
.25305 .14549 L
.26204 .1365 L
.26276 .13578 L
.27176 .12678 L
.27247 .12607 L
.28147 .11707 L
.28219 .11636 L
.29118 .10736 L
.2919 .10664 L
.30089 .09765 L
.30161 .09693 L
.31061 .08793 L
.31132 .08722 L
.32032 .07822 L
.32104 .07751 L
.33003 .06851 L
.33083 .06779 L
.33974 .0588 L
.34033 .05808 L
.34752 .04837 L
.34946 .04566 L
.35462 .03866 L
.35917 .03244 L
.36172 .02894 L
.36874 .01923 L
.01923 .01923 L
F
0 g
.01923 .37931 m
.02016 .37859 L
.02894 .3696 L
.02966 .36888 L
.03866 .35989 L
.03937 .35917 L
.04837 .35017 L
.04908 .34946 L
.05808 .34046 L
.0588 .33974 L
.06779 .33075 L
.06851 .33003 L
.07751 .32104 L
.07822 .32032 L
.08722 .31132 L
.08793 .31061 L
.09693 .30161 L
.09765 .30089 L
.10664 .2919 L
.10736 .29118 L
.11636 .28219 L
.11707 .28147 L
.12607 .27247 L
.12678 .27176 L
.13578 .26276 L
.1365 .26204 L
.14549 .25305 L
.14621 .25233 L
.15521 .24334 L
.15592 .24262 L
.16492 .23362 L
.16563 .23291 L
.17463 .22391 L
.17535 .22319 L
.18434 .2142 L
.18506 .21348 L
.19406 .20448 L
.19477 .20377 L
.20377 .19477 L
.20448 .19406 L
.21348 .18506 L
.2142 .18434 L
.22319 .17535 L
.22391 .17463 L
.23291 .16563 L
.23362 .16492 L
.24262 .15592 L
.24334 .15521 L
.25233 .14621 L
.25305 .14549 L
Mistroke
.26204 .1365 L
.26276 .13578 L
.27176 .12678 L
.27247 .12607 L
.28147 .11707 L
.28219 .11636 L
.29118 .10736 L
.2919 .10664 L
.30089 .09765 L
.30161 .09693 L
.31061 .08793 L
.31132 .08722 L
.32032 .07822 L
.32104 .07751 L
.33003 .06851 L
.33083 .06779 L
.33974 .0588 L
.34033 .05808 L
.34752 .04837 L
.34946 .04566 L
.35462 .03866 L
.35917 .03244 L
.36172 .02894 L
.36874 .01923 L
Mfstroke
.5 g
.01923 .33561 m
.02482 .33003 L
.02894 .3259 L
.03452 .32032 L
.03866 .31618 L
.04423 .31061 L
.04837 .30647 L
.05395 .30089 L
.05808 .29676 L
.06366 .29118 L
.06779 .28705 L
.07337 .28147 L
.07751 .27733 L
.08308 .27176 L
.08722 .26762 L
.0928 .26204 L
.09693 .25791 L
.10251 .25233 L
.10664 .2482 L
.11222 .24262 L
.11636 .23848 L
.12193 .23291 L
.12607 .22877 L
.13165 .22319 L
.13578 .21906 L
.14136 .21348 L
.14549 .20935 L
.15107 .20377 L
.15521 .19963 L
.16078 .19406 L
.16492 .18992 L
.1705 .18434 L
.17463 .18021 L
.18021 .17463 L
.18434 .1705 L
.18992 .16492 L
.19406 .16078 L
.19963 .15521 L
.20377 .15107 L
.20935 .14549 L
.21348 .14136 L
.21906 .13578 L
.22319 .13165 L
.22877 .12607 L
.23291 .12193 L
.23848 .11636 L
.24262 .11222 L
.2482 .10664 L
.25233 .10251 L
.25791 .09693 L
.26204 .0928 L
.26762 .08722 L
.27176 .08308 L
.27733 .07751 L
.28147 .07337 L
.28705 .06779 L
.29118 .06366 L
.29676 .05808 L
.30089 .05395 L
.30647 .04837 L
.31061 .04423 L
.31618 .03866 L
.32032 .03452 L
.3259 .02894 L
.33003 .02482 L
.3357 .01923 L
.01923 .01923 L
F
0 g
.01923 .33561 m
.02482 .33003 L
.02894 .3259 L
.03452 .32032 L
.03866 .31618 L
.04423 .31061 L
.04837 .30647 L
.05395 .30089 L
.05808 .29676 L
.06366 .29118 L
.06779 .28705 L
.07337 .28147 L
.07751 .27733 L
.08308 .27176 L
.08722 .26762 L
.0928 .26204 L
.09693 .25791 L
.10251 .25233 L
.10664 .2482 L
.11222 .24262 L
.11636 .23848 L
.12193 .23291 L
.12607 .22877 L
.13165 .22319 L
.13578 .21906 L
.14136 .21348 L
.14549 .20935 L
.15107 .20377 L
.15521 .19963 L
.16078 .19406 L
.16492 .18992 L
.1705 .18434 L
.17463 .18021 L
.18021 .17463 L
.18434 .1705 L
.18992 .16492 L
.19406 .16078 L
.19963 .15521 L
.20377 .15107 L
.20935 .14549 L
.21348 .14136 L
.21906 .13578 L
.22319 .13165 L
.22877 .12607 L
.23291 .12193 L
.23848 .11636 L
.24262 .11222 L
.2482 .10664 L
.25233 .10251 L
.25791 .09693 L
Mistroke
.26204 .0928 L
.26762 .08722 L
.27176 .08308 L
.27733 .07751 L
.28147 .07337 L
.28705 .06779 L
.29118 .06366 L
.29676 .05808 L
.30089 .05395 L
.30647 .04837 L
.31061 .04423 L
.31618 .03866 L
.32032 .03452 L
.3259 .02894 L
.33003 .02482 L
.3357 .01923 L
Mfstroke
.4 g
.01923 .3002 m
.02825 .29118 L
.02894 .29048 L
.03796 .28147 L
.03866 .28077 L
.04767 .27176 L
.04837 .27106 L
.05738 .26204 L
.05808 .26135 L
.0671 .25233 L
.06779 .25163 L
.07681 .24262 L
.07751 .24192 L
.08652 .23291 L
.08722 .23221 L
.09623 .22319 L
.09693 .2225 L
.10595 .21348 L
.10664 .21278 L
.11566 .20377 L
.11636 .20307 L
.12537 .19406 L
.12607 .19336 L
.13508 .18434 L
.13578 .18365 L
.1448 .17463 L
.14549 .17393 L
.15451 .16492 L
.15521 .16422 L
.16422 .15521 L
.16492 .15451 L
.17393 .14549 L
.17463 .1448 L
.18365 .13578 L
.18434 .13508 L
.19336 .12607 L
.19406 .12537 L
.20307 .11636 L
.20377 .11566 L
.21278 .10664 L
.21348 .10595 L
.2225 .09693 L
.22319 .09623 L
.23221 .08722 L
.23291 .08652 L
.24192 .07751 L
.24262 .07681 L
.25163 .06779 L
.25233 .0671 L
.26135 .05808 L
.26204 .05738 L
.27106 .04837 L
.27176 .04767 L
.28077 .03866 L
.28147 .03796 L
.29048 .02894 L
.29118 .02825 L
.3002 .01923 L
.01923 .01923 L
F
0 g
.01923 .3002 m
.02825 .29118 L
.02894 .29048 L
.03796 .28147 L
.03866 .28077 L
.04767 .27176 L
.04837 .27106 L
.05738 .26204 L
.05808 .26135 L
.0671 .25233 L
.06779 .25163 L
.07681 .24262 L
.07751 .24192 L
.08652 .23291 L
.08722 .23221 L
.09623 .22319 L
.09693 .2225 L
.10595 .21348 L
.10664 .21278 L
.11566 .20377 L
.11636 .20307 L
.12537 .19406 L
.12607 .19336 L
.13508 .18434 L
.13578 .18365 L
.1448 .17463 L
.14549 .17393 L
.15451 .16492 L
.15521 .16422 L
.16422 .15521 L
.16492 .15451 L
.17393 .14549 L
.17463 .1448 L
.18365 .13578 L
.18434 .13508 L
.19336 .12607 L
.19406 .12537 L
.20307 .11636 L
.20377 .11566 L
.21278 .10664 L
.21348 .10595 L
.2225 .09693 L
.22319 .09623 L
.23221 .08722 L
.23291 .08652 L
.24192 .07751 L
.24262 .07681 L
.25163 .06779 L
.25233 .0671 L
.26135 .05808 L
Mistroke
.26204 .05738 L
.27106 .04837 L
.27176 .04767 L
.28077 .03866 L
.28147 .03796 L
.29048 .02894 L
.29118 .02825 L
.3002 .01923 L
Mfstroke
.3 g
.01923 .25652 m
.02334 .25233 L
.02894 .24681 L
.03313 .24262 L
.03866 .2371 L
.04285 .23291 L
.04837 .22738 L
.05256 .22319 L
.05808 .21767 L
.06227 .21348 L
.06779 .20796 L
.07198 .20377 L
.07751 .19825 L
.0817 .19406 L
.08722 .18853 L
.09141 .18434 L
.09693 .17882 L
.10112 .17463 L
.10664 .16911 L
.11083 .16492 L
.11636 .1594 L
.12055 .15521 L
.12607 .14968 L
.13026 .14549 L
.13578 .13997 L
.13997 .13578 L
.14549 .13026 L
.14968 .12607 L
.15521 .12055 L
.1594 .11636 L
.16492 .11083 L
.16911 .10664 L
.17463 .10112 L
.17882 .09693 L
.18434 .09141 L
.18853 .08722 L
.19406 .0817 L
.19825 .07751 L
.20377 .07198 L
.20796 .06779 L
.21348 .06227 L
.21767 .05808 L
.22319 .05256 L
.22738 .04837 L
.23291 .04285 L
.2371 .03866 L
.24262 .03313 L
.24681 .02894 L
.25233 .02334 L
.25652 .01923 L
.01923 .01923 L
F
0 g
.01923 .25652 m
.02334 .25233 L
.02894 .24681 L
.03313 .24262 L
.03866 .2371 L
.04285 .23291 L
.04837 .22738 L
.05256 .22319 L
.05808 .21767 L
.06227 .21348 L
.06779 .20796 L
.07198 .20377 L
.07751 .19825 L
.0817 .19406 L
.08722 .18853 L
.09141 .18434 L
.09693 .17882 L
.10112 .17463 L
.10664 .16911 L
.11083 .16492 L
.11636 .1594 L
.12055 .15521 L
.12607 .14968 L
.13026 .14549 L
.13578 .13997 L
.13997 .13578 L
.14549 .13026 L
.14968 .12607 L
.15521 .12055 L
.1594 .11636 L
.16492 .11083 L
.16911 .10664 L
.17463 .10112 L
.17882 .09693 L
.18434 .09141 L
.18853 .08722 L
.19406 .0817 L
.19825 .07751 L
.20377 .07198 L
.20796 .06779 L
.21348 .06227 L
.21767 .05808 L
.22319 .05256 L
.22738 .04837 L
.23291 .04285 L
.2371 .03866 L
.24262 .03313 L
.24681 .02894 L
.25233 .02334 L
.25652 .01923 L
Mistroke
Mfstroke
.4 g
.01923 .1779 m
.02287 .17463 L
.02894 .16818 L
.03221 .16492 L
.03866 .15847 L
.04192 .15521 L
.04837 .14876 L
.05163 .14549 L
.05808 .13905 L
.06135 .13578 L
.06779 .12933 L
.07106 .12607 L
.07751 .11962 L
.08077 .11636 L
.08722 .10991 L
.09048 .10664 L
.09693 .1002 L
.1002 .09693 L
.10664 .09048 L
.10991 .08722 L
.11636 .08077 L
.11962 .07751 L
.12607 .07106 L
.12933 .06779 L
.13578 .06135 L
.13905 .05808 L
.14549 .05163 L
.14876 .04837 L
.15521 .04192 L
.15847 .03866 L
.16492 .03221 L
.16818 .02894 L
.17463 .02287 L
.1779 .01923 L
.01923 .01923 L
F
0 g
.01923 .1779 m
.02287 .17463 L
.02894 .16818 L
.03221 .16492 L
.03866 .15847 L
.04192 .15521 L
.04837 .14876 L
.05163 .14549 L
.05808 .13905 L
.06135 .13578 L
.06779 .12933 L
.07106 .12607 L
.07751 .11962 L
.08077 .11636 L
.08722 .10991 L
.09048 .10664 L
.09693 .1002 L
.1002 .09693 L
.10664 .09048 L
.10991 .08722 L
.11636 .08077 L
.11962 .07751 L
.12607 .07106 L
.12933 .06779 L
.13578 .06135 L
.13905 .05808 L
.14549 .05163 L
.14876 .04837 L
.15521 .04192 L
.15847 .03866 L
.16492 .03221 L
.16818 .02894 L
.17463 .02287 L
.1779 .01923 L
s
.5 g
.01923 .13423 m
.02739 .12607 L
.02894 .12451 L
.0371 .11636 L
.03866 .1148 L
.04681 .10664 L
.04837 .10509 L
.05653 .09693 L
.05808 .09538 L
.06624 .08722 L
.06779 .08566 L
.07595 .07751 L
.07751 .07595 L
.08566 .06779 L
.08722 .06624 L
.09538 .05808 L
.09693 .05653 L
.10509 .04837 L
.10664 .04681 L
.1148 .03866 L
.11636 .0371 L
.12451 .02894 L
.12607 .02739 L
.13423 .01923 L
.01923 .01923 L
F
0 g
.01923 .13423 m
.02739 .12607 L
.02894 .12451 L
.0371 .11636 L
.03866 .1148 L
.04681 .10664 L
.04837 .10509 L
.05653 .09693 L
.05808 .09538 L
.06624 .08722 L
.06779 .08566 L
.07595 .07751 L
.07751 .07595 L
.08566 .06779 L
.08722 .06624 L
.09538 .05808 L
.09693 .05653 L
.10509 .04837 L
.10664 .04681 L
.1148 .03866 L
.11636 .0371 L
.12451 .02894 L
.12607 .02739 L
.13423 .01923 L
s
.6 g
.01923 .09881 m
.02111 .09693 L
.02894 .0891 L
.03083 .08722 L
.03866 .07939 L
.04054 .07751 L
.04837 .06968 L
.05025 .06779 L
.05808 .05996 L
.05996 .05808 L
.06779 .05025 L
.06968 .04837 L
.07751 .04054 L
.07939 .03866 L
.08722 .03083 L
.0891 .02894 L
.09693 .02111 L
.09881 .01923 L
.01923 .01923 L
F
0 g
.01923 .09881 m
.02111 .09693 L
.02894 .0891 L
.03083 .08722 L
.03866 .07939 L
.04054 .07751 L
.04837 .06968 L
.05025 .06779 L
.05808 .05996 L
.05996 .05808 L
.06779 .05025 L
.06968 .04837 L
.07751 .04054 L
.07939 .03866 L
.08722 .03083 L
.0891 .02894 L
.09693 .02111 L
.09881 .01923 L
s
.7 g
.01923 .05514 m
.02593 .04837 L
.02894 .04543 L
.03572 .03866 L
.03866 .03572 L
.04543 .02894 L
.04837 .02593 L
.05514 .01923 L
.01923 .01923 L
F
0 g
.01923 .05514 m
.02593 .04837 L
.02894 .04543 L
.03572 .03866 L
.03866 .03572 L
.04543 .02894 L
.04837 .02593 L
.05514 .01923 L
s
.3 g
.02228 .98077 m
.02894 .97379 L
.03161 .97106 L
.03866 .96401 L
.04132 .96134 L
.04837 .9543 L
.05103 .95163 L
.05808 .94458 L
.06075 .94192 L
.06779 .93487 L
.07046 .93221 L
.07751 .92516 L
.08017 .92249 L
.08722 .91545 L
.08988 .91278 L
.09693 .90573 L
.0996 .90307 L
.10664 .89602 L
.10931 .89336 L
.11636 .88631 L
.11902 .88364 L
.12607 .8766 L
.12873 .87393 L
.13578 .86688 L
.13845 .86422 L
.14549 .85717 L
.14816 .85451 L
.15521 .84746 L
.15787 .84479 L
.16492 .83775 L
.16758 .83508 L
.17463 .82803 L
.1773 .82537 L
.18434 .81832 L
.18701 .81566 L
.19406 .80861 L
.19672 .80594 L
.20377 .7989 L
.20643 .79623 L
.21348 .78918 L
.21615 .78652 L
.22319 .77947 L
.22586 .77681 L
.23291 .76976 L
.23557 .76709 L
.24262 .76005 L
.24528 .75738 L
.25233 .75033 L
.255 .74767 L
.26204 .74062 L
.26471 .73796 L
.27176 .73091 L
.27442 .72824 L
.28147 .7212 L
.28413 .71853 L
.29118 .71148 L
.29385 .70882 L
.30089 .70177 L
.30356 .69911 L
.31061 .69206 L
.31327 .68939 L
.32032 .68235 L
.32298 .67968 L
.33003 .67263 L
.33294 .66997 L
.33974 .66292 L
.34185 .66026 L
.34895 .65054 L
.34946 .64983 L
.35608 .64083 L
.35917 .6366 L
.36315 .63112 L
.36888 .62317 L
.37014 .62141 L
.37702 .61169 L
.37859 .60944 L
.38375 .60198 L
.38831 .59534 L
.39038 .59227 L
.39691 .58256 L
.39802 .5809 L
.40329 .57284 L
.40773 .56604 L
.40959 .56313 L
.41579 .55342 L
.41744 .5508 L
.42185 .54371 L
.42716 .53517 L
.42787 .53399 L
.43376 .52428 L
.43687 .51913 L
.43956 .51457 L
.44532 .50486 L
.44658 .50272 L
.45094 .49514 L
.45629 .48591 L
.45656 .48543 L
.46203 .47572 L
.46601 .4687 L
.46748 .46601 L
.47286 .45629 L
.47572 .45112 L
.47815 .44658 L
.48343 .43687 L
.48543 .43317 L
.48859 .42716 L
.49377 .41744 L
.49514 .41485 L
.4988 .40773 L
.50389 .39802 L
.50486 .39616 L
.50882 .38831 L
.51381 .37859 L
.51457 .37712 L
.51865 .36888 L
.52355 .35917 L
.52428 .35771 L
.52829 .34946 L
.53311 .33974 L
.53399 .33796 L
.53777 .33003 L
.54251 .32032 L
.54371 .31787 L
.5471 .31061 L
.55176 .30089 L
.55342 .29743 L
.55628 .29118 L
.56086 .28147 L
.56313 .27666 L
.56532 .27176 L
.56983 .26204 L
.57284 .25556 L
.57425 .25233 L
.57866 .24262 L
.58256 .23413 L
.58308 .23291 L
.58737 .22319 L
.59178 .21348 L
.59227 .21238 L
.59598 .20377 L
.60032 .19406 L
.60198 .19031 L
.60449 .18434 L
.60875 .17463 L
.61169 .16793 L
.61292 .16492 L
.61707 .15521 L
.6213 .14549 L
.62141 .14525 L
.62531 .13578 L
.62948 .12607 L
.63112 .12225 L
.63348 .11636 L
.63757 .10664 L
.64083 .09895 L
.64161 .09693 L
.64557 .08722 L
.64965 .07751 L
.65054 .07535 L
.65351 .06779 L
.65752 .05808 L
.66026 .05146 L
.66142 .04837 L
.66531 .03866 L
.66929 .02894 L
.66997 .02729 L
.67304 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.02228 .98077 m
.02894 .97379 L
.03161 .97106 L
.03866 .96401 L
.04132 .96134 L
.04837 .9543 L
.05103 .95163 L
.05808 .94458 L
.06075 .94192 L
.06779 .93487 L
.07046 .93221 L
.07751 .92516 L
.08017 .92249 L
.08722 .91545 L
.08988 .91278 L
.09693 .90573 L
.0996 .90307 L
.10664 .89602 L
.10931 .89336 L
.11636 .88631 L
.11902 .88364 L
.12607 .8766 L
.12873 .87393 L
.13578 .86688 L
.13845 .86422 L
.14549 .85717 L
.14816 .85451 L
.15521 .84746 L
.15787 .84479 L
.16492 .83775 L
.16758 .83508 L
.17463 .82803 L
.1773 .82537 L
.18434 .81832 L
.18701 .81566 L
.19406 .80861 L
.19672 .80594 L
.20377 .7989 L
.20643 .79623 L
.21348 .78918 L
.21615 .78652 L
.22319 .77947 L
.22586 .77681 L
.23291 .76976 L
.23557 .76709 L
.24262 .76005 L
.24528 .75738 L
.25233 .75033 L
.255 .74767 L
.26204 .74062 L
Mistroke
.26471 .73796 L
.27176 .73091 L
.27442 .72824 L
.28147 .7212 L
.28413 .71853 L
.29118 .71148 L
.29385 .70882 L
.30089 .70177 L
.30356 .69911 L
.31061 .69206 L
.31327 .68939 L
.32032 .68235 L
.32298 .67968 L
.33003 .67263 L
.33294 .66997 L
.33974 .66292 L
.34185 .66026 L
.34895 .65054 L
.34946 .64983 L
.35608 .64083 L
.35917 .6366 L
.36315 .63112 L
.36888 .62317 L
.37014 .62141 L
.37702 .61169 L
.37859 .60944 L
.38375 .60198 L
.38831 .59534 L
.39038 .59227 L
.39691 .58256 L
.39802 .5809 L
.40329 .57284 L
.40773 .56604 L
.40959 .56313 L
.41579 .55342 L
.41744 .5508 L
.42185 .54371 L
.42716 .53517 L
.42787 .53399 L
.43376 .52428 L
.43687 .51913 L
.43956 .51457 L
.44532 .50486 L
.44658 .50272 L
.45094 .49514 L
.45629 .48591 L
.45656 .48543 L
.46203 .47572 L
.46601 .4687 L
.46748 .46601 L
Mistroke
.47286 .45629 L
.47572 .45112 L
.47815 .44658 L
.48343 .43687 L
.48543 .43317 L
.48859 .42716 L
.49377 .41744 L
.49514 .41485 L
.4988 .40773 L
.50389 .39802 L
.50486 .39616 L
.50882 .38831 L
.51381 .37859 L
.51457 .37712 L
.51865 .36888 L
.52355 .35917 L
.52428 .35771 L
.52829 .34946 L
.53311 .33974 L
.53399 .33796 L
.53777 .33003 L
.54251 .32032 L
.54371 .31787 L
.5471 .31061 L
.55176 .30089 L
.55342 .29743 L
.55628 .29118 L
.56086 .28147 L
.56313 .27666 L
.56532 .27176 L
.56983 .26204 L
.57284 .25556 L
.57425 .25233 L
.57866 .24262 L
.58256 .23413 L
.58308 .23291 L
.58737 .22319 L
.59178 .21348 L
.59227 .21238 L
.59598 .20377 L
.60032 .19406 L
.60198 .19031 L
.60449 .18434 L
.60875 .17463 L
.61169 .16793 L
.61292 .16492 L
.61707 .15521 L
.6213 .14549 L
.62141 .14525 L
.62531 .13578 L
Mistroke
.62948 .12607 L
.63112 .12225 L
.63348 .11636 L
.63757 .10664 L
.64083 .09895 L
.64161 .09693 L
.64557 .08722 L
.64965 .07751 L
.65054 .07535 L
.65351 .06779 L
.65752 .05808 L
.66026 .05146 L
.66142 .04837 L
.66531 .03866 L
.66929 .02894 L
.66997 .02729 L
.67304 .01923 L
Mfstroke
.4 g
.10051 .98077 m
.10664 .97444 L
.11023 .97106 L
.11636 .96493 L
.11994 .96134 L
.12607 .95522 L
.12965 .95163 L
.13578 .9455 L
.13936 .94192 L
.14549 .93579 L
.14908 .93221 L
.15521 .92608 L
.15879 .92249 L
.16492 .91637 L
.1685 .91278 L
.17463 .90665 L
.17821 .90307 L
.18434 .89694 L
.18793 .89336 L
.19406 .88723 L
.19764 .88364 L
.20377 .87752 L
.20735 .87393 L
.21348 .8678 L
.21706 .86422 L
.22319 .85809 L
.22678 .85451 L
.23291 .84838 L
.23649 .84479 L
.24262 .83867 L
.2462 .83508 L
.25233 .82895 L
.25591 .82537 L
.26204 .81924 L
.26563 .81566 L
.27176 .80953 L
.27534 .80594 L
.28147 .79982 L
.28505 .79623 L
.29118 .7901 L
.29476 .78652 L
.30089 .78039 L
.30448 .77681 L
.31061 .77068 L
.31419 .76709 L
.32032 .76097 L
.3239 .75738 L
.33003 .75125 L
.33354 .74767 L
.33974 .74154 L
.34433 .73796 L
.34946 .73453 L
.35722 .72824 L
.35917 .72621 L
.36736 .71853 L
.36888 .71683 L
.37666 .70882 L
.37859 .70654 L
.38531 .69911 L
.38831 .69544 L
.39346 .68939 L
.39802 .6836 L
.40119 .67968 L
.40773 .67107 L
.40858 .66997 L
.41584 .66026 L
.41744 .65793 L
.42282 .65054 L
.42716 .64419 L
.42951 .64083 L
.43608 .63112 L
.43687 .62987 L
.44256 .62141 L
.44658 .61504 L
.44876 .61169 L
.45493 .60198 L
.45629 .59968 L
.46096 .59227 L
.46601 .58383 L
.46679 .58256 L
.47268 .57284 L
.47572 .56752 L
.47833 .56313 L
.48397 .55342 L
.48543 .55074 L
.48951 .54371 L
.49489 .53399 L
.49514 .53351 L
.50036 .52428 L
.50486 .51586 L
.50557 .51457 L
.51091 .50486 L
.51457 .49779 L
.516 .49514 L
.5212 .48543 L
.52428 .47931 L
.52619 .47572 L
.53126 .46601 L
.53399 .46044 L
.53614 .45629 L
.54111 .44658 L
.54371 .44117 L
.5459 .43687 L
.55077 .42716 L
.55342 .42153 L
.55546 .41744 L
.56025 .40773 L
.56313 .40151 L
.56484 .39802 L
.56957 .38831 L
.57284 .38112 L
.57406 .37859 L
.57873 .36888 L
.58256 .36038 L
.58313 .35917 L
.58773 .34946 L
.59208 .33974 L
.59227 .33929 L
.59659 .33003 L
.60096 .32032 L
.60198 .31786 L
.60532 .31061 L
.60969 .30089 L
.61169 .29609 L
.61392 .29118 L
.61828 .28147 L
.62141 .27398 L
.6224 .27176 L
.62673 .26204 L
.63082 .25233 L
.63112 .25155 L
.63505 .24262 L
.63921 .23291 L
.64083 .22879 L
.64327 .22319 L
.64745 .21348 L
.65054 .20572 L
.65138 .20377 L
.65554 .19406 L
.65951 .18434 L
.66026 .18233 L
.66352 .17463 L
.66757 .16492 L
.66997 .15863 L
.6714 .15521 L
.67546 .14549 L
.67927 .13578 L
.67968 .13463 L
.68322 .12607 L
.68716 .11636 L
.68939 .11033 L
.6909 .10664 L
.69486 .09693 L
.69859 .08722 L
.69911 .08573 L
.70243 .07751 L
.7063 .06779 L
.70882 .06084 L
.70992 .05808 L
.7138 .04837 L
.71751 .03866 L
.71853 .03566 L
.72119 .02894 L
.725 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.10051 .98077 m
.10664 .97444 L
.11023 .97106 L
.11636 .96493 L
.11994 .96134 L
.12607 .95522 L
.12965 .95163 L
.13578 .9455 L
.13936 .94192 L
.14549 .93579 L
.14908 .93221 L
.15521 .92608 L
.15879 .92249 L
.16492 .91637 L
.1685 .91278 L
.17463 .90665 L
.17821 .90307 L
.18434 .89694 L
.18793 .89336 L
.19406 .88723 L
.19764 .88364 L
.20377 .87752 L
.20735 .87393 L
.21348 .8678 L
.21706 .86422 L
.22319 .85809 L
.22678 .85451 L
.23291 .84838 L
.23649 .84479 L
.24262 .83867 L
.2462 .83508 L
.25233 .82895 L
.25591 .82537 L
.26204 .81924 L
.26563 .81566 L
.27176 .80953 L
.27534 .80594 L
.28147 .79982 L
.28505 .79623 L
.29118 .7901 L
.29476 .78652 L
.30089 .78039 L
.30448 .77681 L
.31061 .77068 L
.31419 .76709 L
.32032 .76097 L
.3239 .75738 L
.33003 .75125 L
.33354 .74767 L
.33974 .74154 L
Mistroke
.34433 .73796 L
.34946 .73453 L
.35722 .72824 L
.35917 .72621 L
.36736 .71853 L
.36888 .71683 L
.37666 .70882 L
.37859 .70654 L
.38531 .69911 L
.38831 .69544 L
.39346 .68939 L
.39802 .6836 L
.40119 .67968 L
.40773 .67107 L
.40858 .66997 L
.41584 .66026 L
.41744 .65793 L
.42282 .65054 L
.42716 .64419 L
.42951 .64083 L
.43608 .63112 L
.43687 .62987 L
.44256 .62141 L
.44658 .61504 L
.44876 .61169 L
.45493 .60198 L
.45629 .59968 L
.46096 .59227 L
.46601 .58383 L
.46679 .58256 L
.47268 .57284 L
.47572 .56752 L
.47833 .56313 L
.48397 .55342 L
.48543 .55074 L
.48951 .54371 L
.49489 .53399 L
.49514 .53351 L
.50036 .52428 L
.50486 .51586 L
.50557 .51457 L
.51091 .50486 L
.51457 .49779 L
.516 .49514 L
.5212 .48543 L
.52428 .47931 L
.52619 .47572 L
.53126 .46601 L
.53399 .46044 L
.53614 .45629 L
Mistroke
.54111 .44658 L
.54371 .44117 L
.5459 .43687 L
.55077 .42716 L
.55342 .42153 L
.55546 .41744 L
.56025 .40773 L
.56313 .40151 L
.56484 .39802 L
.56957 .38831 L
.57284 .38112 L
.57406 .37859 L
.57873 .36888 L
.58256 .36038 L
.58313 .35917 L
.58773 .34946 L
.59208 .33974 L
.59227 .33929 L
.59659 .33003 L
.60096 .32032 L
.60198 .31786 L
.60532 .31061 L
.60969 .30089 L
.61169 .29609 L
.61392 .29118 L
.61828 .28147 L
.62141 .27398 L
.6224 .27176 L
.62673 .26204 L
.63082 .25233 L
.63112 .25155 L
.63505 .24262 L
.63921 .23291 L
.64083 .22879 L
.64327 .22319 L
.64745 .21348 L
.65054 .20572 L
.65138 .20377 L
.65554 .19406 L
.65951 .18434 L
.66026 .18233 L
.66352 .17463 L
.66757 .16492 L
.66997 .15863 L
.6714 .15521 L
.67546 .14549 L
.67927 .13578 L
.67968 .13463 L
.68322 .12607 L
.68716 .11636 L
Mistroke
.68939 .11033 L
.6909 .10664 L
.69486 .09693 L
.69859 .08722 L
.69911 .08573 L
.70243 .07751 L
.7063 .06779 L
.70882 .06084 L
.70992 .05808 L
.7138 .04837 L
.71751 .03866 L
.71853 .03566 L
.72119 .02894 L
.725 .01923 L
Mfstroke
.5 g
.1442 .98077 m
.14549 .97946 L
.15391 .97106 L
.15521 .96976 L
.16362 .96134 L
.16492 .96005 L
.17333 .95163 L
.17463 .95033 L
.18305 .94192 L
.18434 .94062 L
.19276 .93221 L
.19406 .93091 L
.20247 .92249 L
.20377 .9212 L
.21218 .91278 L
.21348 .91148 L
.2219 .90307 L
.22319 .90177 L
.23161 .89336 L
.23291 .89206 L
.24132 .88364 L
.24262 .88235 L
.25103 .87393 L
.25233 .87263 L
.26075 .86422 L
.26204 .86292 L
.27046 .85451 L
.27176 .85321 L
.28017 .84479 L
.28147 .8435 L
.28988 .83508 L
.29118 .83378 L
.2996 .82537 L
.30089 .82407 L
.30931 .81566 L
.31061 .81436 L
.31902 .80594 L
.32032 .80465 L
.32873 .79623 L
.33003 .79493 L
.33845 .78652 L
.33974 .78522 L
.34839 .77681 L
.34946 .77578 L
.35776 .76709 L
.35917 .76555 L
.3665 .75738 L
.36888 .75461 L
.37477 .74767 L
.37859 .743 L
.38267 .73796 L
.38831 .73076 L
.39025 .72824 L
.39757 .71853 L
.39802 .71793 L
.40468 .70882 L
.40773 .70453 L
.41157 .69911 L
.41744 .6906 L
.41827 .68939 L
.42483 .67968 L
.42716 .67615 L
.43123 .66997 L
.43687 .66121 L
.43748 .66026 L
.44363 .65054 L
.44658 .64578 L
.44965 .64083 L
.45556 .63112 L
.45629 .62989 L
.46138 .62141 L
.46601 .61355 L
.46709 .61169 L
.47274 .60198 L
.47572 .59677 L
.47829 .59227 L
.48377 .58256 L
.48543 .57956 L
.48917 .57284 L
.4945 .56313 L
.49514 .56193 L
.49978 .55342 L
.50486 .5439 L
.50496 .54371 L
.51013 .53399 L
.51457 .52548 L
.5152 .52428 L
.52025 .51457 L
.52428 .50667 L
.52521 .50486 L
.53016 .49514 L
.53399 .48747 L
.53502 .48543 L
.53987 .47572 L
.54371 .46791 L
.54464 .46601 L
.54941 .45629 L
.55342 .44798 L
.5541 .44658 L
.55878 .43687 L
.56313 .42769 L
.56339 .42716 L
.56799 .41744 L
.57253 .40773 L
.57284 .40705 L
.57706 .39802 L
.58154 .38831 L
.58256 .38606 L
.58599 .37859 L
.59041 .36888 L
.59227 .36474 L
.59479 .35917 L
.59916 .34946 L
.60198 .34308 L
.60347 .33974 L
.60779 .33003 L
.61169 .32109 L
.61203 .32032 L
.6163 .31061 L
.6205 .30089 L
.62141 .29877 L
.6247 .29118 L
.62887 .28147 L
.63112 .27614 L
.63299 .27176 L
.63713 .26204 L
.64083 .25319 L
.64119 .25233 L
.64529 .24262 L
.64933 .23291 L
.65054 .22993 L
.65335 .22319 L
.65737 .21348 L
.66026 .20636 L
.66132 .20377 L
.66531 .19406 L
.66923 .18434 L
.66997 .18249 L
.67316 .17463 L
.67708 .16492 L
.67968 .15832 L
.68093 .15521 L
.68482 .14549 L
.68865 .13578 L
.68939 .13386 L
.69248 .12607 L
.69631 .11636 L
.69911 .1091 L
.70007 .10664 L
.70387 .09693 L
.70762 .08722 L
.70882 .08406 L
.71136 .07751 L
.71511 .06779 L
.71853 .05873 L
.71878 .05808 L
.7225 .04837 L
.72619 .03866 L
.72824 .03312 L
.72983 .02894 L
.7335 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.1442 .98077 m
.14549 .97946 L
.15391 .97106 L
.15521 .96976 L
.16362 .96134 L
.16492 .96005 L
.17333 .95163 L
.17463 .95033 L
.18305 .94192 L
.18434 .94062 L
.19276 .93221 L
.19406 .93091 L
.20247 .92249 L
.20377 .9212 L
.21218 .91278 L
.21348 .91148 L
.2219 .90307 L
.22319 .90177 L
.23161 .89336 L
.23291 .89206 L
.24132 .88364 L
.24262 .88235 L
.25103 .87393 L
.25233 .87263 L
.26075 .86422 L
.26204 .86292 L
.27046 .85451 L
.27176 .85321 L
.28017 .84479 L
.28147 .8435 L
.28988 .83508 L
.29118 .83378 L
.2996 .82537 L
.30089 .82407 L
.30931 .81566 L
.31061 .81436 L
.31902 .80594 L
.32032 .80465 L
.32873 .79623 L
.33003 .79493 L
.33845 .78652 L
.33974 .78522 L
.34839 .77681 L
.34946 .77578 L
.35776 .76709 L
.35917 .76555 L
.3665 .75738 L
.36888 .75461 L
.37477 .74767 L
.37859 .743 L
Mistroke
.38267 .73796 L
.38831 .73076 L
.39025 .72824 L
.39757 .71853 L
.39802 .71793 L
.40468 .70882 L
.40773 .70453 L
.41157 .69911 L
.41744 .6906 L
.41827 .68939 L
.42483 .67968 L
.42716 .67615 L
.43123 .66997 L
.43687 .66121 L
.43748 .66026 L
.44363 .65054 L
.44658 .64578 L
.44965 .64083 L
.45556 .63112 L
.45629 .62989 L
.46138 .62141 L
.46601 .61355 L
.46709 .61169 L
.47274 .60198 L
.47572 .59677 L
.47829 .59227 L
.48377 .58256 L
.48543 .57956 L
.48917 .57284 L
.4945 .56313 L
.49514 .56193 L
.49978 .55342 L
.50486 .5439 L
.50496 .54371 L
.51013 .53399 L
.51457 .52548 L
.5152 .52428 L
.52025 .51457 L
.52428 .50667 L
.52521 .50486 L
.53016 .49514 L
.53399 .48747 L
.53502 .48543 L
.53987 .47572 L
.54371 .46791 L
.54464 .46601 L
.54941 .45629 L
.55342 .44798 L
.5541 .44658 L
.55878 .43687 L
Mistroke
.56313 .42769 L
.56339 .42716 L
.56799 .41744 L
.57253 .40773 L
.57284 .40705 L
.57706 .39802 L
.58154 .38831 L
.58256 .38606 L
.58599 .37859 L
.59041 .36888 L
.59227 .36474 L
.59479 .35917 L
.59916 .34946 L
.60198 .34308 L
.60347 .33974 L
.60779 .33003 L
.61169 .32109 L
.61203 .32032 L
.6163 .31061 L
.6205 .30089 L
.62141 .29877 L
.6247 .29118 L
.62887 .28147 L
.63112 .27614 L
.63299 .27176 L
.63713 .26204 L
.64083 .25319 L
.64119 .25233 L
.64529 .24262 L
.64933 .23291 L
.65054 .22993 L
.65335 .22319 L
.65737 .21348 L
.66026 .20636 L
.66132 .20377 L
.66531 .19406 L
.66923 .18434 L
.66997 .18249 L
.67316 .17463 L
.67708 .16492 L
.67968 .15832 L
.68093 .15521 L
.68482 .14549 L
.68865 .13578 L
.68939 .13386 L
.69248 .12607 L
.69631 .11636 L
.69911 .1091 L
.70007 .10664 L
.70387 .09693 L
Mistroke
.70762 .08722 L
.70882 .08406 L
.71136 .07751 L
.71511 .06779 L
.71853 .05873 L
.71878 .05808 L
.7225 .04837 L
.72619 .03866 L
.72824 .03312 L
.72983 .02894 L
.7335 .01923 L
Mfstroke
.6 g
.17961 .98077 m
.18434 .97604 L
.18932 .97106 L
.19406 .96632 L
.19903 .96134 L
.20377 .95661 L
.20874 .95163 L
.21348 .94689 L
.21846 .94192 L
.22319 .93718 L
.22817 .93221 L
.23291 .92747 L
.23788 .92249 L
.24262 .91776 L
.24759 .91278 L
.25233 .90804 L
.25731 .90307 L
.26204 .89833 L
.26702 .89336 L
.27176 .88862 L
.27673 .88364 L
.28147 .87891 L
.28644 .87393 L
.29118 .86919 L
.29616 .86422 L
.30089 .85948 L
.30587 .85451 L
.31061 .84977 L
.31558 .84479 L
.32032 .84006 L
.32529 .83508 L
.33003 .83034 L
.33509 .82537 L
.33974 .82063 L
.34432 .81566 L
.34946 .80993 L
.35295 .80594 L
.35917 .79864 L
.36118 .79623 L
.36888 .78678 L
.36909 .78652 L
.37672 .77681 L
.37859 .77437 L
.3841 .76709 L
.38831 .76141 L
.39125 .75738 L
.39802 .74795 L
.39821 .74767 L
.405 .73796 L
.40773 .73397 L
.41162 .72824 L
.41744 .71951 L
.41809 .71853 L
.42443 .70882 L
.42716 .70458 L
.43064 .69911 L
.43674 .68939 L
.43687 .68919 L
.44273 .67968 L
.44658 .67335 L
.44862 .66997 L
.45442 .66026 L
.45629 .65708 L
.46012 .65054 L
.46574 .64083 L
.46601 .64038 L
.47128 .63112 L
.47572 .62326 L
.47675 .62141 L
.48215 .61169 L
.48543 .60573 L
.48748 .60198 L
.49275 .59227 L
.49514 .58781 L
.49795 .58256 L
.5031 .57284 L
.50486 .5695 L
.50818 .56313 L
.51322 .55342 L
.51457 .55081 L
.5182 .54371 L
.52314 .53399 L
.52428 .53174 L
.52802 .52428 L
.53287 .51457 L
.53399 .5123 L
.53766 .50486 L
.54242 .49514 L
.54371 .49251 L
.54713 .48543 L
.55181 .47572 L
.55342 .47236 L
.55643 .46601 L
.56104 .45629 L
.56313 .45186 L
.56559 .44658 L
.57013 .43687 L
.57284 .43102 L
.57461 .42716 L
.57908 .41744 L
.58256 .40984 L
.58351 .40773 L
.5879 .39802 L
.59227 .38832 L
.59228 .38831 L
.5966 .37859 L
.60092 .36888 L
.60198 .36648 L
.60519 .35917 L
.60945 .34946 L
.61169 .34432 L
.61367 .33974 L
.61787 .33003 L
.62141 .32184 L
.62205 .32032 L
.6262 .31061 L
.63034 .30089 L
.63112 .29904 L
.63442 .29118 L
.63851 .28147 L
.64083 .27594 L
.64256 .27176 L
.6466 .26204 L
.65054 .25253 L
.65062 .25233 L
.6546 .24262 L
.65859 .23291 L
.66026 .22881 L
.66252 .22319 L
.66646 .21348 L
.66997 .2048 L
.67038 .20377 L
.67426 .19406 L
.67815 .18434 L
.67968 .1805 L
.68199 .17463 L
.68584 .16492 L
.68939 .1559 L
.68966 .15521 L
.69345 .14549 L
.69725 .13578 L
.69911 .13102 L
.701 .12607 L
.70476 .11636 L
.70851 .10664 L
.70882 .10585 L
.71221 .09693 L
.71593 .08722 L
.71853 .0804 L
.71961 .07751 L
.72328 .06779 L
.72696 .05808 L
.72824 .05467 L
.73058 .04837 L
.73422 .03866 L
.73785 .02894 L
.73796 .02867 L
.74143 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.17961 .98077 m
.18434 .97604 L
.18932 .97106 L
.19406 .96632 L
.19903 .96134 L
.20377 .95661 L
.20874 .95163 L
.21348 .94689 L
.21846 .94192 L
.22319 .93718 L
.22817 .93221 L
.23291 .92747 L
.23788 .92249 L
.24262 .91776 L
.24759 .91278 L
.25233 .90804 L
.25731 .90307 L
.26204 .89833 L
.26702 .89336 L
.27176 .88862 L
.27673 .88364 L
.28147 .87891 L
.28644 .87393 L
.29118 .86919 L
.29616 .86422 L
.30089 .85948 L
.30587 .85451 L
.31061 .84977 L
.31558 .84479 L
.32032 .84006 L
.32529 .83508 L
.33003 .83034 L
.33509 .82537 L
.33974 .82063 L
.34432 .81566 L
.34946 .80993 L
.35295 .80594 L
.35917 .79864 L
.36118 .79623 L
.36888 .78678 L
.36909 .78652 L
.37672 .77681 L
.37859 .77437 L
.3841 .76709 L
.38831 .76141 L
.39125 .75738 L
.39802 .74795 L
.39821 .74767 L
.405 .73796 L
.40773 .73397 L
Mistroke
.41162 .72824 L
.41744 .71951 L
.41809 .71853 L
.42443 .70882 L
.42716 .70458 L
.43064 .69911 L
.43674 .68939 L
.43687 .68919 L
.44273 .67968 L
.44658 .67335 L
.44862 .66997 L
.45442 .66026 L
.45629 .65708 L
.46012 .65054 L
.46574 .64083 L
.46601 .64038 L
.47128 .63112 L
.47572 .62326 L
.47675 .62141 L
.48215 .61169 L
.48543 .60573 L
.48748 .60198 L
.49275 .59227 L
.49514 .58781 L
.49795 .58256 L
.5031 .57284 L
.50486 .5695 L
.50818 .56313 L
.51322 .55342 L
.51457 .55081 L
.5182 .54371 L
.52314 .53399 L
.52428 .53174 L
.52802 .52428 L
.53287 .51457 L
.53399 .5123 L
.53766 .50486 L
.54242 .49514 L
.54371 .49251 L
.54713 .48543 L
.55181 .47572 L
.55342 .47236 L
.55643 .46601 L
.56104 .45629 L
.56313 .45186 L
.56559 .44658 L
.57013 .43687 L
.57284 .43102 L
.57461 .42716 L
.57908 .41744 L
Mistroke
.58256 .40984 L
.58351 .40773 L
.5879 .39802 L
.59227 .38832 L
.59228 .38831 L
.5966 .37859 L
.60092 .36888 L
.60198 .36648 L
.60519 .35917 L
.60945 .34946 L
.61169 .34432 L
.61367 .33974 L
.61787 .33003 L
.62141 .32184 L
.62205 .32032 L
.6262 .31061 L
.63034 .30089 L
.63112 .29904 L
.63442 .29118 L
.63851 .28147 L
.64083 .27594 L
.64256 .27176 L
.6466 .26204 L
.65054 .25253 L
.65062 .25233 L
.6546 .24262 L
.65859 .23291 L
.66026 .22881 L
.66252 .22319 L
.66646 .21348 L
.66997 .2048 L
.67038 .20377 L
.67426 .19406 L
.67815 .18434 L
.67968 .1805 L
.68199 .17463 L
.68584 .16492 L
.68939 .1559 L
.68966 .15521 L
.69345 .14549 L
.69725 .13578 L
.69911 .13102 L
.701 .12607 L
.70476 .11636 L
.70851 .10664 L
.70882 .10585 L
.71221 .09693 L
.71593 .08722 L
.71853 .0804 L
.71961 .07751 L
Mistroke
.72328 .06779 L
.72696 .05808 L
.72824 .05467 L
.73058 .04837 L
.73422 .03866 L
.73785 .02894 L
.73796 .02867 L
.74143 .01923 L
Mfstroke
.7 g
.22332 .98077 m
.23291 .97119 L
.23304 .97106 L
.24262 .96147 L
.24275 .96134 L
.25233 .95176 L
.25246 .95163 L
.26204 .94205 L
.26217 .94192 L
.27176 .93234 L
.27189 .93221 L
.28147 .92262 L
.2816 .92249 L
.29118 .91291 L
.29131 .91278 L
.30089 .9032 L
.30102 .90307 L
.31061 .89349 L
.31074 .89336 L
.32032 .88377 L
.32045 .88364 L
.33003 .87406 L
.33018 .87393 L
.33974 .86435 L
.33985 .86422 L
.34709 .85451 L
.34946 .85119 L
.35418 .84479 L
.35917 .83798 L
.36129 .83508 L
.36831 .82537 L
.36888 .82457 L
.3752 .81566 L
.37859 .81081 L
.38197 .80594 L
.38831 .79674 L
.38865 .79623 L
.39518 .78652 L
.39802 .78227 L
.4016 .77681 L
.40773 .76744 L
.40795 .76709 L
.41414 .75738 L
.41744 .75218 L
.42025 .74767 L
.42629 .73796 L
.42716 .73656 L
.43219 .72824 L
.43687 .72052 L
.43804 .71853 L
.44379 .70882 L
.44658 .70409 L
.44945 .69911 L
.45508 .68939 L
.45629 .68729 L
.46057 .67968 L
.46601 .67009 L
.46607 .66997 L
.47142 .66026 L
.47572 .65251 L
.47676 .65054 L
.48202 .64083 L
.48543 .63455 L
.48722 .63112 L
.49239 .62141 L
.49514 .61623 L
.49747 .61169 L
.50254 .60198 L
.50486 .59754 L
.5075 .59227 L
.51249 .58256 L
.51457 .5785 L
.51735 .57284 L
.52225 .56313 L
.52428 .55909 L
.52702 .55342 L
.53184 .54371 L
.53399 .53934 L
.53652 .53399 L
.54126 .52428 L
.54371 .51925 L
.54587 .51457 L
.55052 .50486 L
.55342 .49881 L
.55508 .49514 L
.55964 .48543 L
.56313 .47804 L
.56416 .47572 L
.56862 .46601 L
.57284 .45694 L
.57312 .45629 L
.57748 .44658 L
.58194 .43687 L
.58256 .43552 L
.58621 .42716 L
.59061 .41744 L
.59227 .41376 L
.59484 .40773 L
.59916 .39802 L
.60198 .3917 L
.60339 .38831 L
.60761 .37859 L
.61169 .36932 L
.61187 .36888 L
.61595 .35917 L
.62018 .34946 L
.62141 .34663 L
.62422 .33974 L
.62838 .33003 L
.63112 .32363 L
.63243 .32032 L
.63647 .31061 L
.6406 .30089 L
.64083 .30034 L
.6445 .29118 L
.64857 .28147 L
.65054 .27674 L
.65247 .27176 L
.65645 .26204 L
.66026 .25285 L
.66045 .25233 L
.66426 .24262 L
.66824 .23291 L
.66997 .22866 L
.67203 .22319 L
.67592 .21348 L
.67968 .20419 L
.67983 .20377 L
.68354 .19406 L
.68743 .18434 L
.68939 .17943 L
.69114 .17463 L
.69493 .16492 L
.69879 .15521 L
.69911 .15439 L
.70239 .14549 L
.70619 .13578 L
.70882 .12907 L
.70986 .12607 L
.71353 .11636 L
.71731 .10664 L
.71853 .10347 L
.72084 .09693 L
.72455 .08722 L
.72824 .0776 L
.72828 .07751 L
.73174 .06779 L
.73544 .05808 L
.73796 .05145 L
.73899 .04837 L
.74253 .03866 L
.74621 .02894 L
.74767 .02507 L
.74963 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.22332 .98077 m
.23291 .97119 L
.23304 .97106 L
.24262 .96147 L
.24275 .96134 L
.25233 .95176 L
.25246 .95163 L
.26204 .94205 L
.26217 .94192 L
.27176 .93234 L
.27189 .93221 L
.28147 .92262 L
.2816 .92249 L
.29118 .91291 L
.29131 .91278 L
.30089 .9032 L
.30102 .90307 L
.31061 .89349 L
.31074 .89336 L
.32032 .88377 L
.32045 .88364 L
.33003 .87406 L
.33018 .87393 L
.33974 .86435 L
.33985 .86422 L
.34709 .85451 L
.34946 .85119 L
.35418 .84479 L
.35917 .83798 L
.36129 .83508 L
.36831 .82537 L
.36888 .82457 L
.3752 .81566 L
.37859 .81081 L
.38197 .80594 L
.38831 .79674 L
.38865 .79623 L
.39518 .78652 L
.39802 .78227 L
.4016 .77681 L
.40773 .76744 L
.40795 .76709 L
.41414 .75738 L
.41744 .75218 L
.42025 .74767 L
.42629 .73796 L
.42716 .73656 L
.43219 .72824 L
.43687 .72052 L
.43804 .71853 L
Mistroke
.44379 .70882 L
.44658 .70409 L
.44945 .69911 L
.45508 .68939 L
.45629 .68729 L
.46057 .67968 L
.46601 .67009 L
.46607 .66997 L
.47142 .66026 L
.47572 .65251 L
.47676 .65054 L
.48202 .64083 L
.48543 .63455 L
.48722 .63112 L
.49239 .62141 L
.49514 .61623 L
.49747 .61169 L
.50254 .60198 L
.50486 .59754 L
.5075 .59227 L
.51249 .58256 L
.51457 .5785 L
.51735 .57284 L
.52225 .56313 L
.52428 .55909 L
.52702 .55342 L
.53184 .54371 L
.53399 .53934 L
.53652 .53399 L
.54126 .52428 L
.54371 .51925 L
.54587 .51457 L
.55052 .50486 L
.55342 .49881 L
.55508 .49514 L
.55964 .48543 L
.56313 .47804 L
.56416 .47572 L
.56862 .46601 L
.57284 .45694 L
.57312 .45629 L
.57748 .44658 L
.58194 .43687 L
.58256 .43552 L
.58621 .42716 L
.59061 .41744 L
.59227 .41376 L
.59484 .40773 L
.59916 .39802 L
.60198 .3917 L
Mistroke
.60339 .38831 L
.60761 .37859 L
.61169 .36932 L
.61187 .36888 L
.61595 .35917 L
.62018 .34946 L
.62141 .34663 L
.62422 .33974 L
.62838 .33003 L
.63112 .32363 L
.63243 .32032 L
.63647 .31061 L
.6406 .30089 L
.64083 .30034 L
.6445 .29118 L
.64857 .28147 L
.65054 .27674 L
.65247 .27176 L
.65645 .26204 L
.66026 .25285 L
.66045 .25233 L
.66426 .24262 L
.66824 .23291 L
.66997 .22866 L
.67203 .22319 L
.67592 .21348 L
.67968 .20419 L
.67983 .20377 L
.68354 .19406 L
.68743 .18434 L
.68939 .17943 L
.69114 .17463 L
.69493 .16492 L
.69879 .15521 L
.69911 .15439 L
.70239 .14549 L
.70619 .13578 L
.70882 .12907 L
.70986 .12607 L
.71353 .11636 L
.71731 .10664 L
.71853 .10347 L
.72084 .09693 L
.72455 .08722 L
.72824 .0776 L
.72828 .07751 L
.73174 .06779 L
.73544 .05808 L
.73796 .05145 L
.73899 .04837 L
Mistroke
.74253 .03866 L
.74621 .02894 L
.74767 .02507 L
.74963 .01923 L
Mfstroke
.6 g
.30187 .98077 m
.31061 .97199 L
.31158 .97106 L
.32032 .96232 L
.3213 .96134 L
.33003 .95261 L
.33099 .95163 L
.33974 .9429 L
.34093 .94192 L
.34946 .9359 L
.35425 .93221 L
.35917 .9276 L
.3648 .92249 L
.36888 .91822 L
.37428 .91278 L
.37859 .90793 L
.38305 .90307 L
.38831 .89682 L
.39128 .89336 L
.39802 .88497 L
.3991 .88364 L
.40668 .87393 L
.40773 .87246 L
.41398 .86422 L
.41744 .85932 L
.42096 .85451 L
.42716 .84556 L
.4277 .84479 L
.43441 .83508 L
.43687 .83127 L
.44085 .82537 L
.44658 .81641 L
.44708 .81566 L
.45334 .80594 L
.45629 .80107 L
.45935 .79623 L
.46526 .78652 L
.46601 .78522 L
.47114 .77681 L
.47572 .76889 L
.47679 .76709 L
.48252 .75738 L
.48543 .75212 L
.48802 .74767 L
.49352 .73796 L
.49514 .7349 L
.49891 .72824 L
.5042 .71853 L
.50486 .71724 L
.50951 .70882 L
.51457 .69917 L
.5146 .69911 L
.51984 .68939 L
.52428 .68069 L
.52482 .67968 L
.52994 .66997 L
.53399 .66182 L
.5348 .66026 L
.53982 .65054 L
.54371 .64255 L
.54458 .64083 L
.5495 .63112 L
.55342 .62291 L
.55417 .62141 L
.559 .61169 L
.56313 .60289 L
.56358 .60198 L
.56833 .59227 L
.57282 .58256 L
.57284 .5825 L
.5775 .57284 L
.58197 .56313 L
.58256 .56177 L
.58652 .55342 L
.59098 .54371 L
.59227 .54068 L
.59539 .53399 L
.59984 .52428 L
.60198 .51925 L
.60413 .51457 L
.60856 .50486 L
.61169 .49747 L
.61275 .49514 L
.61714 .48543 L
.62127 .47572 L
.62141 .47536 L
.62559 .46601 L
.62978 .45629 L
.63112 .45293 L
.63392 .44658 L
.63814 .43687 L
.64083 .43018 L
.64214 .42716 L
.64635 .41744 L
.65031 .40773 L
.65054 .4071 L
.65444 .39802 L
.6585 .38831 L
.66026 .38372 L
.66243 .37859 L
.66651 .36888 L
.66997 .36001 L
.67032 .35917 L
.67439 .34946 L
.67831 .33974 L
.67968 .33602 L
.68216 .33003 L
.68614 .32032 L
.68939 .31171 L
.68984 .31061 L
.69382 .30089 L
.69765 .29118 L
.69911 .28712 L
.70139 .28147 L
.70529 .27176 L
.70882 .26222 L
.70889 .26204 L
.71278 .25233 L
.71657 .24262 L
.71853 .23705 L
.72017 .23291 L
.724 .22319 L
.72761 .21348 L
.72824 .21158 L
.7313 .20377 L
.73506 .19406 L
.73796 .18583 L
.73853 .18434 L
.74229 .17463 L
.74595 .16492 L
.74767 .1598 L
.74943 .15521 L
.75315 .14549 L
.75665 .13578 L
.75738 .1335 L
.7602 .12607 L
.76386 .11636 L
.76709 .10691 L
.7672 .10664 L
.77085 .09693 L
.77444 .08722 L
.77681 .08007 L
.77776 .07751 L
.78138 .06779 L
.78489 .05808 L
.78652 .05296 L
.78821 .04837 L
.7918 .03866 L
.7952 .02894 L
.79623 .02556 L
.79855 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.30187 .98077 m
.31061 .97199 L
.31158 .97106 L
.32032 .96232 L
.3213 .96134 L
.33003 .95261 L
.33099 .95163 L
.33974 .9429 L
.34093 .94192 L
.34946 .9359 L
.35425 .93221 L
.35917 .9276 L
.3648 .92249 L
.36888 .91822 L
.37428 .91278 L
.37859 .90793 L
.38305 .90307 L
.38831 .89682 L
.39128 .89336 L
.39802 .88497 L
.3991 .88364 L
.40668 .87393 L
.40773 .87246 L
.41398 .86422 L
.41744 .85932 L
.42096 .85451 L
.42716 .84556 L
.4277 .84479 L
.43441 .83508 L
.43687 .83127 L
.44085 .82537 L
.44658 .81641 L
.44708 .81566 L
.45334 .80594 L
.45629 .80107 L
.45935 .79623 L
.46526 .78652 L
.46601 .78522 L
.47114 .77681 L
.47572 .76889 L
.47679 .76709 L
.48252 .75738 L
.48543 .75212 L
.48802 .74767 L
.49352 .73796 L
.49514 .7349 L
.49891 .72824 L
.5042 .71853 L
.50486 .71724 L
.50951 .70882 L
Mistroke
.51457 .69917 L
.5146 .69911 L
.51984 .68939 L
.52428 .68069 L
.52482 .67968 L
.52994 .66997 L
.53399 .66182 L
.5348 .66026 L
.53982 .65054 L
.54371 .64255 L
.54458 .64083 L
.5495 .63112 L
.55342 .62291 L
.55417 .62141 L
.559 .61169 L
.56313 .60289 L
.56358 .60198 L
.56833 .59227 L
.57282 .58256 L
.57284 .5825 L
.5775 .57284 L
.58197 .56313 L
.58256 .56177 L
.58652 .55342 L
.59098 .54371 L
.59227 .54068 L
.59539 .53399 L
.59984 .52428 L
.60198 .51925 L
.60413 .51457 L
.60856 .50486 L
.61169 .49747 L
.61275 .49514 L
.61714 .48543 L
.62127 .47572 L
.62141 .47536 L
.62559 .46601 L
.62978 .45629 L
.63112 .45293 L
.63392 .44658 L
.63814 .43687 L
.64083 .43018 L
.64214 .42716 L
.64635 .41744 L
.65031 .40773 L
.65054 .4071 L
.65444 .39802 L
.6585 .38831 L
.66026 .38372 L
.66243 .37859 L
Mistroke
.66651 .36888 L
.66997 .36001 L
.67032 .35917 L
.67439 .34946 L
.67831 .33974 L
.67968 .33602 L
.68216 .33003 L
.68614 .32032 L
.68939 .31171 L
.68984 .31061 L
.69382 .30089 L
.69765 .29118 L
.69911 .28712 L
.70139 .28147 L
.70529 .27176 L
.70882 .26222 L
.70889 .26204 L
.71278 .25233 L
.71657 .24262 L
.71853 .23705 L
.72017 .23291 L
.724 .22319 L
.72761 .21348 L
.72824 .21158 L
.7313 .20377 L
.73506 .19406 L
.73796 .18583 L
.73853 .18434 L
.74229 .17463 L
.74595 .16492 L
.74767 .1598 L
.74943 .15521 L
.75315 .14549 L
.75665 .13578 L
.75738 .1335 L
.7602 .12607 L
.76386 .11636 L
.76709 .10691 L
.7672 .10664 L
.77085 .09693 L
.77444 .08722 L
.77681 .08007 L
.77776 .07751 L
.78138 .06779 L
.78489 .05808 L
.78652 .05296 L
.78821 .04837 L
.7918 .03866 L
.7952 .02894 L
.79623 .02556 L
Mistroke
.79855 .01923 L
Mfstroke
.5 g
.34572 .98077 m
.34946 .97715 L
.35537 .97106 L
.35917 .96694 L
.36423 .96134 L
.36888 .95599 L
.37261 .95163 L
.37859 .94438 L
.38059 .94192 L
.38826 .93221 L
.38831 .93214 L
.39566 .92249 L
.39802 .91931 L
.40282 .91278 L
.40773 .90592 L
.40975 .90307 L
.41651 .89336 L
.41744 .89199 L
.42311 .88364 L
.42716 .87754 L
.42954 .87393 L
.43583 .86422 L
.43687 .86259 L
.44201 .85451 L
.44658 .84716 L
.44805 .84479 L
.454 .83508 L
.45629 .83127 L
.45985 .82537 L
.46558 .81566 L
.46601 .81493 L
.47126 .80594 L
.47572 .79815 L
.47682 .79623 L
.48233 .78652 L
.48543 .78094 L
.48774 .77681 L
.4931 .76709 L
.49514 .76332 L
.49838 .75738 L
.5036 .74767 L
.50486 .74529 L
.50876 .73796 L
.51386 .72824 L
.51457 .72686 L
.51891 .71853 L
.52389 .70882 L
.52428 .70805 L
.52885 .69911 L
.53373 .68939 L
.53399 .68886 L
.53859 .67968 L
.54338 .66997 L
.54371 .66929 L
.54815 .66026 L
.55286 .65054 L
.55342 .64936 L
.55754 .64083 L
.56217 .63112 L
.56313 .62907 L
.56678 .62141 L
.57134 .61169 L
.57284 .60844 L
.57586 .60198 L
.58036 .59227 L
.58256 .58745 L
.58481 .58256 L
.58925 .57284 L
.59227 .56612 L
.59362 .56313 L
.59801 .55342 L
.60198 .54446 L
.60232 .54371 L
.60665 .53399 L
.61091 .52428 L
.61169 .52247 L
.61517 .51457 L
.6194 .50486 L
.62141 .50016 L
.62358 .49514 L
.62777 .48543 L
.63112 .47752 L
.63189 .47572 L
.63604 .46601 L
.64012 .45629 L
.64083 .45457 L
.6442 .44658 L
.64826 .43687 L
.65054 .43131 L
.65227 .42716 L
.65631 .41744 L
.66026 .40774 L
.66026 .40773 L
.66425 .39802 L
.6682 .38831 L
.66997 .38388 L
.67211 .37859 L
.67604 .36888 L
.67968 .35971 L
.6799 .35917 L
.68379 .34946 L
.68764 .33974 L
.68939 .33524 L
.69146 .33003 L
.6953 .32032 L
.69906 .31061 L
.69911 .31049 L
.70286 .30089 L
.70664 .29118 L
.70882 .28544 L
.71036 .28147 L
.71412 .27176 L
.71781 .26204 L
.71853 .26012 L
.72151 .25233 L
.72522 .24262 L
.72824 .23451 L
.72885 .23291 L
.73253 .22319 L
.73617 .21348 L
.73796 .20862 L
.73977 .20377 L
.74341 .19406 L
.74699 .18434 L
.74767 .18245 L
.75057 .17463 L
.75416 .16492 L
.75738 .15602 L
.75768 .15521 L
.76125 .14549 L
.76479 .13578 L
.76709 .12931 L
.76827 .12607 L
.77181 .11636 L
.7753 .10664 L
.77681 .10234 L
.77875 .09693 L
.78225 .08722 L
.78569 .07751 L
.78652 .0751 L
.78912 .06779 L
.79259 .05808 L
.79597 .04837 L
.79623 .0476 L
.79939 .03866 L
.80282 .02894 L
.80594 .01984 L
.80616 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.34572 .98077 m
.34946 .97715 L
.35537 .97106 L
.35917 .96694 L
.36423 .96134 L
.36888 .95599 L
.37261 .95163 L
.37859 .94438 L
.38059 .94192 L
.38826 .93221 L
.38831 .93214 L
.39566 .92249 L
.39802 .91931 L
.40282 .91278 L
.40773 .90592 L
.40975 .90307 L
.41651 .89336 L
.41744 .89199 L
.42311 .88364 L
.42716 .87754 L
.42954 .87393 L
.43583 .86422 L
.43687 .86259 L
.44201 .85451 L
.44658 .84716 L
.44805 .84479 L
.454 .83508 L
.45629 .83127 L
.45985 .82537 L
.46558 .81566 L
.46601 .81493 L
.47126 .80594 L
.47572 .79815 L
.47682 .79623 L
.48233 .78652 L
.48543 .78094 L
.48774 .77681 L
.4931 .76709 L
.49514 .76332 L
.49838 .75738 L
.5036 .74767 L
.50486 .74529 L
.50876 .73796 L
.51386 .72824 L
.51457 .72686 L
.51891 .71853 L
.52389 .70882 L
.52428 .70805 L
.52885 .69911 L
.53373 .68939 L
Mistroke
.53399 .68886 L
.53859 .67968 L
.54338 .66997 L
.54371 .66929 L
.54815 .66026 L
.55286 .65054 L
.55342 .64936 L
.55754 .64083 L
.56217 .63112 L
.56313 .62907 L
.56678 .62141 L
.57134 .61169 L
.57284 .60844 L
.57586 .60198 L
.58036 .59227 L
.58256 .58745 L
.58481 .58256 L
.58925 .57284 L
.59227 .56612 L
.59362 .56313 L
.59801 .55342 L
.60198 .54446 L
.60232 .54371 L
.60665 .53399 L
.61091 .52428 L
.61169 .52247 L
.61517 .51457 L
.6194 .50486 L
.62141 .50016 L
.62358 .49514 L
.62777 .48543 L
.63112 .47752 L
.63189 .47572 L
.63604 .46601 L
.64012 .45629 L
.64083 .45457 L
.6442 .44658 L
.64826 .43687 L
.65054 .43131 L
.65227 .42716 L
.65631 .41744 L
.66026 .40774 L
.66026 .40773 L
.66425 .39802 L
.6682 .38831 L
.66997 .38388 L
.67211 .37859 L
.67604 .36888 L
.67968 .35971 L
.6799 .35917 L
Mistroke
.68379 .34946 L
.68764 .33974 L
.68939 .33524 L
.69146 .33003 L
.6953 .32032 L
.69906 .31061 L
.69911 .31049 L
.70286 .30089 L
.70664 .29118 L
.70882 .28544 L
.71036 .28147 L
.71412 .27176 L
.71781 .26204 L
.71853 .26012 L
.72151 .25233 L
.72522 .24262 L
.72824 .23451 L
.72885 .23291 L
.73253 .22319 L
.73617 .21348 L
.73796 .20862 L
.73977 .20377 L
.74341 .19406 L
.74699 .18434 L
.74767 .18245 L
.75057 .17463 L
.75416 .16492 L
.75738 .15602 L
.75768 .15521 L
.76125 .14549 L
.76479 .13578 L
.76709 .12931 L
.76827 .12607 L
.77181 .11636 L
.7753 .10664 L
.77681 .10234 L
.77875 .09693 L
.78225 .08722 L
.78569 .07751 L
.78652 .0751 L
.78912 .06779 L
.79259 .05808 L
.79597 .04837 L
.79623 .0476 L
.79939 .03866 L
.80282 .02894 L
.80594 .01984 L
.80616 .01923 L
Mfstroke
.4 g
.37472 .98077 m
.37859 .97575 L
.38216 .97106 L
.38831 .9628 L
.38937 .96134 L
.39639 .95163 L
.39802 .94933 L
.40321 .94192 L
.40773 .93536 L
.40988 .93221 L
.41639 .92249 L
.41744 .9209 L
.42276 .91278 L
.42716 .90597 L
.42901 .90307 L
.43514 .89336 L
.43687 .89058 L
.44115 .88364 L
.44658 .87474 L
.44707 .87393 L
.45289 .86422 L
.45629 .85846 L
.45861 .85451 L
.46426 .84479 L
.46601 .84176 L
.46982 .83508 L
.47531 .82537 L
.47572 .82464 L
.48072 .81566 L
.48543 .80712 L
.48607 .80594 L
.49135 .79623 L
.49514 .7892 L
.49657 .78652 L
.50174 .77681 L
.50486 .77088 L
.50684 .76709 L
.51189 .75738 L
.51457 .75219 L
.51688 .74767 L
.52184 .73796 L
.52428 .73312 L
.52673 .72824 L
.53159 .71853 L
.53399 .71369 L
.53639 .70882 L
.54116 .69911 L
.54371 .69389 L
.54588 .68939 L
.55057 .67968 L
.55342 .67374 L
.55521 .66997 L
.55982 .66026 L
.56313 .65324 L
.56439 .65054 L
.56893 .64083 L
.57284 .6324 L
.57343 .63112 L
.57789 .62141 L
.58234 .61169 L
.58256 .61122 L
.58673 .60198 L
.59112 .59227 L
.59227 .58971 L
.59545 .58256 L
.59978 .57284 L
.60198 .56787 L
.60405 .56313 L
.60832 .55342 L
.61169 .5457 L
.61255 .54371 L
.61676 .53399 L
.62095 .52428 L
.62141 .52322 L
.62509 .51457 L
.62924 .50486 L
.63112 .50043 L
.63333 .49514 L
.63743 .48543 L
.64083 .47732 L
.64149 .47572 L
.64553 .46601 L
.64956 .45629 L
.65054 .45391 L
.65354 .44658 L
.65753 .43687 L
.66026 .4302 L
.66148 .42716 L
.66542 .41744 L
.66935 .40773 L
.66997 .40619 L
.67322 .39802 L
.67712 .38831 L
.67968 .38188 L
.68097 .37859 L
.68481 .36888 L
.68865 .35917 L
.68939 .35729 L
.69244 .34946 L
.69625 .33974 L
.69911 .3324 L
.70001 .33003 L
.70376 .32032 L
.70752 .31061 L
.70882 .30723 L
.71122 .30089 L
.71495 .29118 L
.71853 .28178 L
.71865 .28147 L
.7223 .27176 L
.72599 .26204 L
.72824 .25606 L
.72962 .25233 L
.73326 .24262 L
.7369 .23291 L
.73796 .23005 L
.74047 .22319 L
.74408 .21348 L
.74767 .20378 L
.74767 .20377 L
.75121 .19406 L
.75478 .18434 L
.75738 .17723 L
.75831 .17463 L
.76183 .16492 L
.76536 .15521 L
.76709 .15042 L
.76884 .14549 L
.77233 .13578 L
.77583 .12607 L
.77681 .12334 L
.77926 .11636 L
.78273 .10664 L
.78619 .09693 L
.78652 .096 L
.78958 .08722 L
.79303 .07751 L
.79623 .0684 L
.79644 .06779 L
.79981 .05808 L
.80322 .04837 L
.80594 .04055 L
.80658 .03866 L
.80993 .02894 L
.81331 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.37472 .98077 m
.37859 .97575 L
.38216 .97106 L
.38831 .9628 L
.38937 .96134 L
.39639 .95163 L
.39802 .94933 L
.40321 .94192 L
.40773 .93536 L
.40988 .93221 L
.41639 .92249 L
.41744 .9209 L
.42276 .91278 L
.42716 .90597 L
.42901 .90307 L
.43514 .89336 L
.43687 .89058 L
.44115 .88364 L
.44658 .87474 L
.44707 .87393 L
.45289 .86422 L
.45629 .85846 L
.45861 .85451 L
.46426 .84479 L
.46601 .84176 L
.46982 .83508 L
.47531 .82537 L
.47572 .82464 L
.48072 .81566 L
.48543 .80712 L
.48607 .80594 L
.49135 .79623 L
.49514 .7892 L
.49657 .78652 L
.50174 .77681 L
.50486 .77088 L
.50684 .76709 L
.51189 .75738 L
.51457 .75219 L
.51688 .74767 L
.52184 .73796 L
.52428 .73312 L
.52673 .72824 L
.53159 .71853 L
.53399 .71369 L
.53639 .70882 L
.54116 .69911 L
.54371 .69389 L
.54588 .68939 L
.55057 .67968 L
Mistroke
.55342 .67374 L
.55521 .66997 L
.55982 .66026 L
.56313 .65324 L
.56439 .65054 L
.56893 .64083 L
.57284 .6324 L
.57343 .63112 L
.57789 .62141 L
.58234 .61169 L
.58256 .61122 L
.58673 .60198 L
.59112 .59227 L
.59227 .58971 L
.59545 .58256 L
.59978 .57284 L
.60198 .56787 L
.60405 .56313 L
.60832 .55342 L
.61169 .5457 L
.61255 .54371 L
.61676 .53399 L
.62095 .52428 L
.62141 .52322 L
.62509 .51457 L
.62924 .50486 L
.63112 .50043 L
.63333 .49514 L
.63743 .48543 L
.64083 .47732 L
.64149 .47572 L
.64553 .46601 L
.64956 .45629 L
.65054 .45391 L
.65354 .44658 L
.65753 .43687 L
.66026 .4302 L
.66148 .42716 L
.66542 .41744 L
.66935 .40773 L
.66997 .40619 L
.67322 .39802 L
.67712 .38831 L
.67968 .38188 L
.68097 .37859 L
.68481 .36888 L
.68865 .35917 L
.68939 .35729 L
.69244 .34946 L
.69625 .33974 L
Mistroke
.69911 .3324 L
.70001 .33003 L
.70376 .32032 L
.70752 .31061 L
.70882 .30723 L
.71122 .30089 L
.71495 .29118 L
.71853 .28178 L
.71865 .28147 L
.7223 .27176 L
.72599 .26204 L
.72824 .25606 L
.72962 .25233 L
.73326 .24262 L
.7369 .23291 L
.73796 .23005 L
.74047 .22319 L
.74408 .21348 L
.74767 .20378 L
.74767 .20377 L
.75121 .19406 L
.75478 .18434 L
.75738 .17723 L
.75831 .17463 L
.76183 .16492 L
.76536 .15521 L
.76709 .15042 L
.76884 .14549 L
.77233 .13578 L
.77583 .12607 L
.77681 .12334 L
.77926 .11636 L
.78273 .10664 L
.78619 .09693 L
.78652 .096 L
.78958 .08722 L
.79303 .07751 L
.79623 .0684 L
.79644 .06779 L
.79981 .05808 L
.80322 .04837 L
.80594 .04055 L
.80658 .03866 L
.80993 .02894 L
.81331 .01923 L
Mfstroke
.3 g
.39991 .98077 m
.40628 .97106 L
.40773 .96881 L
.4125 .96134 L
.41744 .95357 L
.41865 .95163 L
.42469 .94192 L
.42716 .93793 L
.43062 .93221 L
.43652 .92249 L
.43687 .92191 L
.44226 .91278 L
.44658 .90548 L
.44796 .90307 L
.45359 .89336 L
.45629 .88867 L
.45911 .88364 L
.46462 .87393 L
.46601 .87147 L
.46999 .86422 L
.47538 .85451 L
.47572 .8539 L
.48062 .84479 L
.48543 .83594 L
.48588 .83508 L
.49101 .82537 L
.49514 .81762 L
.49614 .81566 L
.50119 .80594 L
.50486 .79893 L
.5062 .79623 L
.51116 .78652 L
.51457 .77988 L
.51607 .77681 L
.52095 .76709 L
.52428 .76048 L
.52576 .75738 L
.53055 .74767 L
.53399 .74073 L
.53529 .73796 L
.53999 .72824 L
.54371 .72063 L
.54467 .71853 L
.54928 .70882 L
.55342 .7002 L
.55391 .69911 L
.55842 .68939 L
.56301 .67968 L
.56313 .67943 L
.56742 .66997 L
.57195 .66026 L
.57284 .65833 L
.5763 .65054 L
.58076 .64083 L
.58256 .6369 L
.58506 .63112 L
.58944 .62141 L
.59227 .61515 L
.59372 .61169 L
.59801 .60198 L
.60198 .59309 L
.60231 .59227 L
.60647 .58256 L
.61076 .57284 L
.61169 .5707 L
.61484 .56313 L
.61906 .55342 L
.62141 .54801 L
.62314 .54371 L
.62727 .53399 L
.63112 .52502 L
.6314 .52428 L
.63538 .51457 L
.63951 .50486 L
.64083 .50172 L
.64343 .49514 L
.64748 .48543 L
.65054 .47812 L
.65146 .47572 L
.65538 .46601 L
.65941 .45629 L
.66026 .45423 L
.66321 .44658 L
.66718 .43687 L
.66997 .43004 L
.67104 .42716 L
.67487 .41744 L
.67881 .40773 L
.67968 .40557 L
.68252 .39802 L
.6864 .38831 L
.68939 .38081 L
.69018 .37859 L
.69391 .36888 L
.69777 .35917 L
.69911 .35577 L
.7014 .34946 L
.70518 .33974 L
.70882 .33046 L
.70896 .33003 L
.71253 .32032 L
.7163 .31061 L
.71853 .30485 L
.7199 .30089 L
.72355 .29118 L
.72729 .28147 L
.72824 .27898 L
.73078 .27176 L
.73445 .26204 L
.73796 .25284 L
.73812 .25233 L
.74157 .24262 L
.74523 .23291 L
.74767 .22643 L
.74873 .22319 L
.75225 .21348 L
.75589 .20377 L
.75738 .19975 L
.75928 .19406 L
.76282 .18434 L
.76643 .17463 L
.76709 .17281 L
.76974 .16492 L
.77329 .15521 L
.77681 .14561 L
.77684 .14549 L
.78011 .13578 L
.78364 .12607 L
.78652 .11815 L
.78707 .11636 L
.79038 .10664 L
.7939 .09693 L
.79623 .09043 L
.79722 .08722 L
.80056 .07751 L
.80405 .06779 L
.80594 .06246 L
.80729 .05808 L
.81064 .04837 L
.8141 .03866 L
.81566 .03424 L
.81728 .02894 L
.82063 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.39991 .98077 m
.40628 .97106 L
.40773 .96881 L
.4125 .96134 L
.41744 .95357 L
.41865 .95163 L
.42469 .94192 L
.42716 .93793 L
.43062 .93221 L
.43652 .92249 L
.43687 .92191 L
.44226 .91278 L
.44658 .90548 L
.44796 .90307 L
.45359 .89336 L
.45629 .88867 L
.45911 .88364 L
.46462 .87393 L
.46601 .87147 L
.46999 .86422 L
.47538 .85451 L
.47572 .8539 L
.48062 .84479 L
.48543 .83594 L
.48588 .83508 L
.49101 .82537 L
.49514 .81762 L
.49614 .81566 L
.50119 .80594 L
.50486 .79893 L
.5062 .79623 L
.51116 .78652 L
.51457 .77988 L
.51607 .77681 L
.52095 .76709 L
.52428 .76048 L
.52576 .75738 L
.53055 .74767 L
.53399 .74073 L
.53529 .73796 L
.53999 .72824 L
.54371 .72063 L
.54467 .71853 L
.54928 .70882 L
.55342 .7002 L
.55391 .69911 L
.55842 .68939 L
.56301 .67968 L
.56313 .67943 L
.56742 .66997 L
Mistroke
.57195 .66026 L
.57284 .65833 L
.5763 .65054 L
.58076 .64083 L
.58256 .6369 L
.58506 .63112 L
.58944 .62141 L
.59227 .61515 L
.59372 .61169 L
.59801 .60198 L
.60198 .59309 L
.60231 .59227 L
.60647 .58256 L
.61076 .57284 L
.61169 .5707 L
.61484 .56313 L
.61906 .55342 L
.62141 .54801 L
.62314 .54371 L
.62727 .53399 L
.63112 .52502 L
.6314 .52428 L
.63538 .51457 L
.63951 .50486 L
.64083 .50172 L
.64343 .49514 L
.64748 .48543 L
.65054 .47812 L
.65146 .47572 L
.65538 .46601 L
.65941 .45629 L
.66026 .45423 L
.66321 .44658 L
.66718 .43687 L
.66997 .43004 L
.67104 .42716 L
.67487 .41744 L
.67881 .40773 L
.67968 .40557 L
.68252 .39802 L
.6864 .38831 L
.68939 .38081 L
.69018 .37859 L
.69391 .36888 L
.69777 .35917 L
.69911 .35577 L
.7014 .34946 L
.70518 .33974 L
.70882 .33046 L
.70896 .33003 L
Mistroke
.71253 .32032 L
.7163 .31061 L
.71853 .30485 L
.7199 .30089 L
.72355 .29118 L
.72729 .28147 L
.72824 .27898 L
.73078 .27176 L
.73445 .26204 L
.73796 .25284 L
.73812 .25233 L
.74157 .24262 L
.74523 .23291 L
.74767 .22643 L
.74873 .22319 L
.75225 .21348 L
.75589 .20377 L
.75738 .19975 L
.75928 .19406 L
.76282 .18434 L
.76643 .17463 L
.76709 .17281 L
.76974 .16492 L
.77329 .15521 L
.77681 .14561 L
.77684 .14549 L
.78011 .13578 L
.78364 .12607 L
.78652 .11815 L
.78707 .11636 L
.79038 .10664 L
.7939 .09693 L
.79623 .09043 L
.79722 .08722 L
.80056 .07751 L
.80405 .06779 L
.80594 .06246 L
.80729 .05808 L
.81064 .04837 L
.8141 .03866 L
.81566 .03424 L
.81728 .02894 L
.82063 .01923 L
Mfstroke
.4 g
.46958 .98077 m
.47529 .97106 L
.47572 .97028 L
.48103 .96134 L
.48543 .9535 L
.48652 .95163 L
.4921 .94192 L
.49514 .93628 L
.49745 .93221 L
.50285 .92249 L
.50486 .91863 L
.50809 .91278 L
.51331 .90307 L
.51457 .90056 L
.51846 .89336 L
.52352 .88364 L
.52428 .88208 L
.52859 .87393 L
.53351 .86422 L
.53399 .8632 L
.5385 .85451 L
.54331 .84479 L
.54371 .84393 L
.54821 .83508 L
.55293 .82537 L
.55342 .82429 L
.55773 .81566 L
.56239 .80594 L
.56313 .80427 L
.56708 .79623 L
.57169 .78652 L
.57284 .78389 L
.57626 .77681 L
.58083 .76709 L
.58256 .76316 L
.5853 .75738 L
.58983 .74767 L
.59227 .74207 L
.59419 .73796 L
.59869 .72824 L
.60198 .72063 L
.60295 .71853 L
.6074 .70882 L
.61159 .69911 L
.61169 .69885 L
.61598 .68939 L
.62023 .67968 L
.62141 .67675 L
.62444 .66997 L
.62871 .66026 L
.63112 .65432 L
.63278 .65054 L
.63704 .64083 L
.64083 .63156 L
.64102 .63112 L
.64524 .62141 L
.64931 .61169 L
.65054 .60849 L
.65334 .60198 L
.65745 .59227 L
.66026 .5851 L
.66133 .58256 L
.66544 .57284 L
.66934 .56313 L
.66997 .5614 L
.67331 .55342 L
.67731 .54371 L
.67968 .5374 L
.68109 .53399 L
.6851 .52428 L
.68888 .51457 L
.68939 .5131 L
.69276 .50486 L
.69667 .49514 L
.69911 .4885 L
.70034 .48543 L
.70427 .47572 L
.70799 .46601 L
.70882 .46361 L
.71174 .45629 L
.71559 .44658 L
.71853 .43843 L
.71915 .43687 L
.72299 .42716 L
.72671 .41744 L
.72824 .41297 L
.73029 .40773 L
.73408 .39802 L
.7376 .38831 L
.73796 .38721 L
.7413 .37859 L
.74501 .36888 L
.74767 .36118 L
.74844 .35917 L
.75217 .34946 L
.75577 .33974 L
.75738 .33488 L
.75922 .33003 L
.76291 .32032 L
.76637 .31061 L
.76709 .3083 L
.76988 .30089 L
.77351 .29118 L
.7768 .28147 L
.77681 .28145 L
.78042 .27176 L
.78399 .26204 L
.78652 .25434 L
.78726 .25233 L
.79085 .24262 L
.79434 .23291 L
.79623 .22696 L
.7976 .22319 L
.80116 .21348 L
.80458 .20377 L
.80594 .19931 L
.80785 .19406 L
.81137 .18434 L
.8147 .17463 L
.81566 .17141 L
.81799 .16492 L
.82148 .15521 L
.82473 .14549 L
.82537 .14325 L
.82803 .13578 L
.83149 .12607 L
.83466 .11636 L
.83508 .11483 L
.83798 .10664 L
.8414 .09693 L
.84451 .08722 L
.84479 .08616 L
.84783 .07751 L
.85123 .06779 L
.85429 .05808 L
.85451 .05725 L
.85759 .04837 L
.86096 .03866 L
.86399 .02894 L
.86422 .02808 L
.86727 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.46958 .98077 m
.47529 .97106 L
.47572 .97028 L
.48103 .96134 L
.48543 .9535 L
.48652 .95163 L
.4921 .94192 L
.49514 .93628 L
.49745 .93221 L
.50285 .92249 L
.50486 .91863 L
.50809 .91278 L
.51331 .90307 L
.51457 .90056 L
.51846 .89336 L
.52352 .88364 L
.52428 .88208 L
.52859 .87393 L
.53351 .86422 L
.53399 .8632 L
.5385 .85451 L
.54331 .84479 L
.54371 .84393 L
.54821 .83508 L
.55293 .82537 L
.55342 .82429 L
.55773 .81566 L
.56239 .80594 L
.56313 .80427 L
.56708 .79623 L
.57169 .78652 L
.57284 .78389 L
.57626 .77681 L
.58083 .76709 L
.58256 .76316 L
.5853 .75738 L
.58983 .74767 L
.59227 .74207 L
.59419 .73796 L
.59869 .72824 L
.60198 .72063 L
.60295 .71853 L
.6074 .70882 L
.61159 .69911 L
.61169 .69885 L
.61598 .68939 L
.62023 .67968 L
.62141 .67675 L
.62444 .66997 L
.62871 .66026 L
Mistroke
.63112 .65432 L
.63278 .65054 L
.63704 .64083 L
.64083 .63156 L
.64102 .63112 L
.64524 .62141 L
.64931 .61169 L
.65054 .60849 L
.65334 .60198 L
.65745 .59227 L
.66026 .5851 L
.66133 .58256 L
.66544 .57284 L
.66934 .56313 L
.66997 .5614 L
.67331 .55342 L
.67731 .54371 L
.67968 .5374 L
.68109 .53399 L
.6851 .52428 L
.68888 .51457 L
.68939 .5131 L
.69276 .50486 L
.69667 .49514 L
.69911 .4885 L
.70034 .48543 L
.70427 .47572 L
.70799 .46601 L
.70882 .46361 L
.71174 .45629 L
.71559 .44658 L
.71853 .43843 L
.71915 .43687 L
.72299 .42716 L
.72671 .41744 L
.72824 .41297 L
.73029 .40773 L
.73408 .39802 L
.7376 .38831 L
.73796 .38721 L
.7413 .37859 L
.74501 .36888 L
.74767 .36118 L
.74844 .35917 L
.75217 .34946 L
.75577 .33974 L
.75738 .33488 L
.75922 .33003 L
.76291 .32032 L
.76637 .31061 L
Mistroke
.76709 .3083 L
.76988 .30089 L
.77351 .29118 L
.7768 .28147 L
.77681 .28145 L
.78042 .27176 L
.78399 .26204 L
.78652 .25434 L
.78726 .25233 L
.79085 .24262 L
.79434 .23291 L
.79623 .22696 L
.7976 .22319 L
.80116 .21348 L
.80458 .20377 L
.80594 .19931 L
.80785 .19406 L
.81137 .18434 L
.8147 .17463 L
.81566 .17141 L
.81799 .16492 L
.82148 .15521 L
.82473 .14549 L
.82537 .14325 L
.82803 .13578 L
.83149 .12607 L
.83466 .11636 L
.83508 .11483 L
.83798 .10664 L
.8414 .09693 L
.84451 .08722 L
.84479 .08616 L
.84783 .07751 L
.85123 .06779 L
.85429 .05808 L
.85451 .05725 L
.85759 .04837 L
.86096 .03866 L
.86399 .02894 L
.86422 .02808 L
.86727 .01923 L
Mfstroke
.5 g
.4863 .98077 m
.49169 .97106 L
.49514 .9647 L
.49698 .96134 L
.50222 .95163 L
.50486 .94667 L
.50739 .94192 L
.51252 .93221 L
.51457 .92825 L
.51757 .92249 L
.52258 .91278 L
.52428 .90944 L
.52754 .90307 L
.53245 .89336 L
.53399 .89024 L
.5373 .88364 L
.54212 .87393 L
.54371 .87068 L
.54689 .86422 L
.55162 .85451 L
.55342 .85075 L
.5563 .84479 L
.56095 .83508 L
.56313 .83046 L
.56555 .82537 L
.57014 .81566 L
.57284 .80982 L
.57466 .80594 L
.57917 .79623 L
.58256 .78883 L
.58362 .78652 L
.58808 .77681 L
.59227 .76751 L
.59246 .76709 L
.59685 .75738 L
.60118 .74767 L
.60198 .74585 L
.6055 .73796 L
.60979 .72824 L
.61169 .72386 L
.61403 .71853 L
.61828 .70882 L
.62141 .70154 L
.62246 .69911 L
.62666 .68939 L
.63079 .67968 L
.63112 .67891 L
.63494 .66997 L
.63905 .66026 L
.64083 .65596 L
.64311 .65054 L
.64719 .64083 L
.65054 .6327 L
.6512 .63112 L
.65524 .62141 L
.65922 .61169 L
.66026 .60913 L
.66319 .60198 L
.66716 .59227 L
.66997 .58526 L
.67107 .58256 L
.675 .57284 L
.67888 .56313 L
.67968 .56109 L
.68276 .55342 L
.68663 .54371 L
.68939 .53663 L
.69044 .53399 L
.69428 .52428 L
.69807 .51457 L
.69911 .51187 L
.70185 .50486 L
.70564 .49514 L
.70882 .48683 L
.70936 .48543 L
.71312 .47572 L
.71684 .46601 L
.71853 .4615 L
.72052 .45629 L
.72424 .44658 L
.72788 .43687 L
.72824 .43589 L
.73155 .42716 L
.73522 .41744 L
.73796 .41 L
.73881 .40773 L
.74245 .39802 L
.74605 .38831 L
.74767 .38384 L
.74961 .37859 L
.75322 .36888 L
.75675 .35917 L
.75738 .3574 L
.7603 .34946 L
.76386 .33974 L
.76709 .3307 L
.76733 .33003 L
.77087 .32032 L
.77438 .31061 L
.77681 .30372 L
.77782 .30089 L
.78132 .29118 L
.78479 .28147 L
.78652 .27649 L
.7882 .27176 L
.79167 .26204 L
.79509 .25233 L
.79623 .24899 L
.79848 .24262 L
.80191 .23291 L
.80528 .22319 L
.80594 .22123 L
.80866 .21348 L
.81206 .20377 L
.81538 .19406 L
.81566 .19321 L
.81873 .18434 L
.8221 .17463 L
.82537 .16494 L
.82538 .16492 L
.82872 .15521 L
.83205 .14549 L
.83508 .13642 L
.8353 .13578 L
.83861 .12607 L
.84192 .11636 L
.84479 .10765 L
.84513 .10664 L
.84842 .09693 L
.85169 .08722 L
.85451 .07863 L
.85488 .07751 L
.85814 .06779 L
.86139 .05808 L
.86422 .04936 L
.86455 .04837 L
.86778 .03866 L
.87101 .02894 L
.87393 .01985 L
.87413 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.4863 .98077 m
.49169 .97106 L
.49514 .9647 L
.49698 .96134 L
.50222 .95163 L
.50486 .94667 L
.50739 .94192 L
.51252 .93221 L
.51457 .92825 L
.51757 .92249 L
.52258 .91278 L
.52428 .90944 L
.52754 .90307 L
.53245 .89336 L
.53399 .89024 L
.5373 .88364 L
.54212 .87393 L
.54371 .87068 L
.54689 .86422 L
.55162 .85451 L
.55342 .85075 L
.5563 .84479 L
.56095 .83508 L
.56313 .83046 L
.56555 .82537 L
.57014 .81566 L
.57284 .80982 L
.57466 .80594 L
.57917 .79623 L
.58256 .78883 L
.58362 .78652 L
.58808 .77681 L
.59227 .76751 L
.59246 .76709 L
.59685 .75738 L
.60118 .74767 L
.60198 .74585 L
.6055 .73796 L
.60979 .72824 L
.61169 .72386 L
.61403 .71853 L
.61828 .70882 L
.62141 .70154 L
.62246 .69911 L
.62666 .68939 L
.63079 .67968 L
.63112 .67891 L
.63494 .66997 L
.63905 .66026 L
.64083 .65596 L
Mistroke
.64311 .65054 L
.64719 .64083 L
.65054 .6327 L
.6512 .63112 L
.65524 .62141 L
.65922 .61169 L
.66026 .60913 L
.66319 .60198 L
.66716 .59227 L
.66997 .58526 L
.67107 .58256 L
.675 .57284 L
.67888 .56313 L
.67968 .56109 L
.68276 .55342 L
.68663 .54371 L
.68939 .53663 L
.69044 .53399 L
.69428 .52428 L
.69807 .51457 L
.69911 .51187 L
.70185 .50486 L
.70564 .49514 L
.70882 .48683 L
.70936 .48543 L
.71312 .47572 L
.71684 .46601 L
.71853 .4615 L
.72052 .45629 L
.72424 .44658 L
.72788 .43687 L
.72824 .43589 L
.73155 .42716 L
.73522 .41744 L
.73796 .41 L
.73881 .40773 L
.74245 .39802 L
.74605 .38831 L
.74767 .38384 L
.74961 .37859 L
.75322 .36888 L
.75675 .35917 L
.75738 .3574 L
.7603 .34946 L
.76386 .33974 L
.76709 .3307 L
.76733 .33003 L
.77087 .32032 L
.77438 .31061 L
.77681 .30372 L
Mistroke
.77782 .30089 L
.78132 .29118 L
.78479 .28147 L
.78652 .27649 L
.7882 .27176 L
.79167 .26204 L
.79509 .25233 L
.79623 .24899 L
.79848 .24262 L
.80191 .23291 L
.80528 .22319 L
.80594 .22123 L
.80866 .21348 L
.81206 .20377 L
.81538 .19406 L
.81566 .19321 L
.81873 .18434 L
.8221 .17463 L
.82537 .16494 L
.82538 .16492 L
.82872 .15521 L
.83205 .14549 L
.83508 .13642 L
.8353 .13578 L
.83861 .12607 L
.84192 .11636 L
.84479 .10765 L
.84513 .10664 L
.84842 .09693 L
.85169 .08722 L
.85451 .07863 L
.85488 .07751 L
.85814 .06779 L
.86139 .05808 L
.86422 .04936 L
.86455 .04837 L
.86778 .03866 L
.87101 .02894 L
.87393 .01985 L
.87413 .01923 L
Mfstroke
.8 g
.50486 .24634 m
.51206 .25233 L
.50548 .26204 L
.50486 .26292 L
.49892 .26204 L
.50246 .25233 L
F
0 g
.50486 .24634 m
.51206 .25233 L
.50548 .26204 L
.50486 .26292 L
.49892 .26204 L
.50246 .25233 L
.50486 .24634 L
s
.2 g
.50486 .85049 m
.51334 .85451 L
.50687 .86422 L
.50486 .86707 L
.49959 .86422 L
.50324 .85451 L
F
0 g
.50486 .85049 m
.51334 .85451 L
.50687 .86422 L
.50486 .86707 L
.49959 .86422 L
.50324 .85451 L
.50486 .85049 L
s
.2 g
.50486 .04496 m
.51373 .04837 L
.50729 .05808 L
.50486 .06153 L
.4998 .05808 L
.50348 .04837 L
F
0 g
.50486 .04496 m
.51373 .04837 L
.50729 .05808 L
.50486 .06153 L
.4998 .05808 L
.50348 .04837 L
.50486 .04496 L
s
.6 g
.50037 .98077 m
.50486 .97227 L
.50549 .97106 L
.51055 .96134 L
.51457 .95358 L
.51556 .95163 L
.52052 .94192 L
.52428 .93451 L
.52544 .93221 L
.5303 .92249 L
.53399 .91507 L
.53512 .91278 L
.5399 .90307 L
.54371 .89528 L
.54463 .89336 L
.54933 .88364 L
.55342 .87513 L
.55399 .87393 L
.5586 .86422 L
.56313 .85463 L
.56319 .85451 L
.56772 .84479 L
.57224 .83508 L
.57284 .83378 L
.57671 .82537 L
.58117 .81566 L
.58256 .8126 L
.58557 .80594 L
.58996 .79623 L
.59227 .79109 L
.5943 .78652 L
.59863 .77681 L
.60198 .76925 L
.60292 .76709 L
.60719 .75738 L
.61144 .74767 L
.61169 .74709 L
.61564 .73796 L
.61984 .72824 L
.62141 .72461 L
.62399 .71853 L
.62814 .70882 L
.63112 .70181 L
.63225 .69911 L
.63634 .68939 L
.64042 .67968 L
.64083 .67871 L
.64445 .66997 L
.64849 .66026 L
.65054 .6553 L
.65248 .65054 L
.65647 .64083 L
.66026 .63158 L
.66044 .63112 L
.66437 .62141 L
.66831 .61169 L
.66997 .60757 L
.67219 .60198 L
.67609 .59227 L
.67968 .58327 L
.67996 .58256 L
.68379 .57284 L
.68764 .56313 L
.68939 .55867 L
.69143 .55342 L
.69523 .54371 L
.69903 .53399 L
.69911 .53379 L
.70276 .52428 L
.70653 .51457 L
.70882 .50862 L
.71024 .50486 L
.71396 .49514 L
.71767 .48543 L
.71853 .48317 L
.72133 .47572 L
.72501 .46601 L
.72824 .45744 L
.72867 .45629 L
.73229 .44658 L
.73593 .43687 L
.73796 .43144 L
.73952 .42716 L
.74312 .41744 L
.74672 .40773 L
.74767 .40516 L
.75026 .39802 L
.75383 .38831 L
.75738 .37862 L
.75739 .37859 L
.76089 .36888 L
.76443 .35917 L
.76709 .3518 L
.76792 .34946 L
.7714 .33974 L
.77491 .33003 L
.77681 .32472 L
.77835 .32032 L
.78181 .31061 L
.78528 .30089 L
.78652 .29739 L
.78868 .29118 L
.79211 .28147 L
.79554 .27176 L
.79623 .26979 L
.7989 .26204 L
.80231 .25233 L
.80571 .24262 L
.80594 .24193 L
.80903 .23291 L
.81241 .22319 L
.81566 .21382 L
.81577 .21348 L
.81907 .20377 L
.82242 .19406 L
.82537 .18546 L
.82574 .18434 L
.82902 .17463 L
.83234 .16492 L
.83508 .15685 L
.83562 .15521 L
.83887 .14549 L
.84217 .13578 L
.84479 .12799 L
.84542 .12607 L
.84864 .11636 L
.85192 .10664 L
.85451 .09888 L
.85513 .09693 L
.85833 .08722 L
.86158 .07751 L
.86422 .06953 L
.86477 .06779 L
.86794 .05808 L
.87116 .04837 L
.87393 .03993 L
.87433 .03866 L
.87747 .02894 L
.88067 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.50037 .98077 m
.50486 .97227 L
.50549 .97106 L
.51055 .96134 L
.51457 .95358 L
.51556 .95163 L
.52052 .94192 L
.52428 .93451 L
.52544 .93221 L
.5303 .92249 L
.53399 .91507 L
.53512 .91278 L
.5399 .90307 L
.54371 .89528 L
.54463 .89336 L
.54933 .88364 L
.55342 .87513 L
.55399 .87393 L
.5586 .86422 L
.56313 .85463 L
.56319 .85451 L
.56772 .84479 L
.57224 .83508 L
.57284 .83378 L
.57671 .82537 L
.58117 .81566 L
.58256 .8126 L
.58557 .80594 L
.58996 .79623 L
.59227 .79109 L
.5943 .78652 L
.59863 .77681 L
.60198 .76925 L
.60292 .76709 L
.60719 .75738 L
.61144 .74767 L
.61169 .74709 L
.61564 .73796 L
.61984 .72824 L
.62141 .72461 L
.62399 .71853 L
.62814 .70882 L
.63112 .70181 L
.63225 .69911 L
.63634 .68939 L
.64042 .67968 L
.64083 .67871 L
.64445 .66997 L
.64849 .66026 L
.65054 .6553 L
Mistroke
.65248 .65054 L
.65647 .64083 L
.66026 .63158 L
.66044 .63112 L
.66437 .62141 L
.66831 .61169 L
.66997 .60757 L
.67219 .60198 L
.67609 .59227 L
.67968 .58327 L
.67996 .58256 L
.68379 .57284 L
.68764 .56313 L
.68939 .55867 L
.69143 .55342 L
.69523 .54371 L
.69903 .53399 L
.69911 .53379 L
.70276 .52428 L
.70653 .51457 L
.70882 .50862 L
.71024 .50486 L
.71396 .49514 L
.71767 .48543 L
.71853 .48317 L
.72133 .47572 L
.72501 .46601 L
.72824 .45744 L
.72867 .45629 L
.73229 .44658 L
.73593 .43687 L
.73796 .43144 L
.73952 .42716 L
.74312 .41744 L
.74672 .40773 L
.74767 .40516 L
.75026 .39802 L
.75383 .38831 L
.75738 .37862 L
.75739 .37859 L
.76089 .36888 L
.76443 .35917 L
.76709 .3518 L
.76792 .34946 L
.7714 .33974 L
.77491 .33003 L
.77681 .32472 L
.77835 .32032 L
.78181 .31061 L
.78528 .30089 L
Mistroke
.78652 .29739 L
.78868 .29118 L
.79211 .28147 L
.79554 .27176 L
.79623 .26979 L
.7989 .26204 L
.80231 .25233 L
.80571 .24262 L
.80594 .24193 L
.80903 .23291 L
.81241 .22319 L
.81566 .21382 L
.81577 .21348 L
.81907 .20377 L
.82242 .19406 L
.82537 .18546 L
.82574 .18434 L
.82902 .17463 L
.83234 .16492 L
.83508 .15685 L
.83562 .15521 L
.83887 .14549 L
.84217 .13578 L
.84479 .12799 L
.84542 .12607 L
.84864 .11636 L
.85192 .10664 L
.85451 .09888 L
.85513 .09693 L
.85833 .08722 L
.86158 .07751 L
.86422 .06953 L
.86477 .06779 L
.86794 .05808 L
.87116 .04837 L
.87393 .03993 L
.87433 .03866 L
.87747 .02894 L
.88067 .01923 L
Mfstroke
.8 g
.78907 .01923 m
.78652 .02482 L
.78503 .02894 L
.78151 .03866 L
.7783 .04837 L
.77681 .05175 L
.77447 .05808 L
.77237 .06779 L
.76744 .07751 L
.76709 .0783 L
.76378 .08722 L
.76111 .09693 L
.75738 .10463 L
.75661 .10664 L
.75298 .11636 L
.74981 .12607 L
.74767 .13066 L
.74571 .13578 L
.74375 .14549 L
.73847 .15521 L
.73796 .15634 L
.73466 .16492 L
.73186 .17463 L
.72824 .18182 L
.72724 .18434 L
.72348 .19406 L
.72005 .20377 L
.71853 .20694 L
.71595 .21348 L
.71344 .22319 L
.70882 .23176 L
.70835 .23291 L
.70449 .24262 L
.7011 .25233 L
.69911 .25631 L
.69677 .26204 L
.69436 .27176 L
.68939 .2805 L
.68898 .28147 L
.68503 .29118 L
.6815 .30089 L
.67968 .30441 L
.6771 .31061 L
.67443 .32032 L
.66997 .328 L
.66909 .33003 L
.66502 .33974 L
.66117 .34946 L
.66026 .3512 L
.65686 .35917 L
.65359 .36888 L
.65054 .37416 L
.64859 .37859 L
.64441 .38831 L
.64083 .3967 L
.64022 .39802 L
.63597 .40773 L
.63191 .41744 L
.63112 .41886 L
.62741 .42716 L
.62379 .43687 L
.62141 .44077 L
.61873 .44658 L
.61433 .45629 L
.61169 .46229 L
.60991 .46601 L
.60543 .47572 L
.60198 .48337 L
.60094 .48543 L
.59638 .49514 L
.59227 .50401 L
.59181 .50486 L
.58715 .51457 L
.58256 .52418 L
.58249 .52428 L
.57774 .53399 L
.57304 .54371 L
.57284 .54399 L
.56811 .55342 L
.56329 .56313 L
.56313 .56334 L
.55824 .57284 L
.55342 .58235 L
.55323 .58256 L
.54809 .59227 L
.54371 .60115 L
.5429 .60198 L
.53759 .61169 L
.53399 .61937 L
.53218 .62141 L
.52663 .63112 L
.52428 .63634 L
.52091 .64083 L
.51498 .65054 L
.51457 .65143 L
.50864 .66026 L
.50486 .66568 L
.5005 .66026 L
.50427 .65054 L
.50486 .64911 L
.50835 .64083 L
.51254 .63112 L
.51457 .62646 L
.51681 .62141 L
.52113 .61169 L
.52428 .60461 L
.52546 .60198 L
.52983 .59227 L
.53399 .58295 L
.53417 .58256 L
.53855 .57284 L
.54243 .56313 L
.54371 .56112 L
.54724 .55342 L
.55157 .54371 L
.55342 .53918 L
.55589 .53399 L
.56019 .52428 L
.56313 .51723 L
.56448 .51457 L
.56875 .50486 L
.57284 .4954 L
.57299 .49514 L
.57724 .48543 L
.58106 .47572 L
.58256 .47302 L
.58565 .46601 L
.58875 .45629 L
.59227 .45035 L
.59398 .44658 L
.59812 .43687 L
.60198 .42767 L
.60223 .42716 L
.60634 .41744 L
.61004 .40773 L
.61169 .40456 L
.61448 .39802 L
.61741 .38831 L
.62141 .3812 L
.62255 .37859 L
.62656 .36888 L
.6304 .35917 L
.63112 .3577 L
.63452 .34946 L
.63773 .33974 L
.64083 .33378 L
.6424 .33003 L
.64446 .32032 L
.65014 .31061 L
.65054 .30976 L
.65411 .30089 L
.65731 .29118 L
.66026 .2853 L
.66182 .28147 L
.66387 .27176 L
.66937 .26204 L
.66997 .26073 L
.67328 .25233 L
.67631 .24262 L
.67968 .23577 L
.68083 .23291 L
.68252 .22319 L
.6881 .21348 L
.68939 .21064 L
.69206 .20377 L
.69471 .19406 L
.69911 .18522 L
.69946 .18434 L
.70315 .17463 L
.70632 .16492 L
.70882 .1595 L
.71047 .15521 L
.71247 .14549 L
.71758 .13578 L
.71853 .13359 L
.72136 .12607 L
.72397 .11636 L
.72824 .10739 L
.72853 .10664 L
.73212 .09693 L
.73511 .08722 L
.73796 .0809 L
.73923 .07751 L
.74085 .06779 L
.746 .05808 L
.74767 .0542 L
.74981 .04837 L
.75195 .03866 L
.75668 .02894 L
.75738 .02734 L
.76028 .01923 L
F
0 g
.78907 .01923 m
.78652 .02482 L
.78503 .02894 L
.78151 .03866 L
.7783 .04837 L
.77681 .05175 L
.77447 .05808 L
.77237 .06779 L
.76744 .07751 L
.76709 .0783 L
.76378 .08722 L
.76111 .09693 L
.75738 .10463 L
.75661 .10664 L
.75298 .11636 L
.74981 .12607 L
.74767 .13066 L
.74571 .13578 L
.74375 .14549 L
.73847 .15521 L
.73796 .15634 L
.73466 .16492 L
.73186 .17463 L
.72824 .18182 L
.72724 .18434 L
.72348 .19406 L
.72005 .20377 L
.71853 .20694 L
.71595 .21348 L
.71344 .22319 L
.70882 .23176 L
.70835 .23291 L
.70449 .24262 L
.7011 .25233 L
.69911 .25631 L
.69677 .26204 L
.69436 .27176 L
.68939 .2805 L
.68898 .28147 L
.68503 .29118 L
.6815 .30089 L
.67968 .30441 L
.6771 .31061 L
.67443 .32032 L
.66997 .328 L
.66909 .33003 L
.66502 .33974 L
.66117 .34946 L
.66026 .3512 L
.65686 .35917 L
Mistroke
.65359 .36888 L
.65054 .37416 L
.64859 .37859 L
.64441 .38831 L
.64083 .3967 L
.64022 .39802 L
.63597 .40773 L
.63191 .41744 L
.63112 .41886 L
.62741 .42716 L
.62379 .43687 L
.62141 .44077 L
.61873 .44658 L
.61433 .45629 L
.61169 .46229 L
.60991 .46601 L
.60543 .47572 L
.60198 .48337 L
.60094 .48543 L
.59638 .49514 L
.59227 .50401 L
.59181 .50486 L
.58715 .51457 L
.58256 .52418 L
.58249 .52428 L
.57774 .53399 L
.57304 .54371 L
.57284 .54399 L
.56811 .55342 L
.56329 .56313 L
.56313 .56334 L
.55824 .57284 L
.55342 .58235 L
.55323 .58256 L
.54809 .59227 L
.54371 .60115 L
.5429 .60198 L
.53759 .61169 L
.53399 .61937 L
.53218 .62141 L
.52663 .63112 L
.52428 .63634 L
.52091 .64083 L
.51498 .65054 L
.51457 .65143 L
.50864 .66026 L
.50486 .66568 L
.5005 .66026 L
.50427 .65054 L
.50486 .64911 L
Mistroke
.50835 .64083 L
.51254 .63112 L
.51457 .62646 L
.51681 .62141 L
.52113 .61169 L
.52428 .60461 L
.52546 .60198 L
.52983 .59227 L
.53399 .58295 L
.53417 .58256 L
.53855 .57284 L
.54243 .56313 L
.54371 .56112 L
.54724 .55342 L
.55157 .54371 L
.55342 .53918 L
.55589 .53399 L
.56019 .52428 L
.56313 .51723 L
.56448 .51457 L
.56875 .50486 L
.57284 .4954 L
.57299 .49514 L
.57724 .48543 L
.58106 .47572 L
.58256 .47302 L
.58565 .46601 L
.58875 .45629 L
.59227 .45035 L
.59398 .44658 L
.59812 .43687 L
.60198 .42767 L
.60223 .42716 L
.60634 .41744 L
.61004 .40773 L
.61169 .40456 L
.61448 .39802 L
.61741 .38831 L
.62141 .3812 L
.62255 .37859 L
.62656 .36888 L
.6304 .35917 L
.63112 .3577 L
.63452 .34946 L
.63773 .33974 L
.64083 .33378 L
.6424 .33003 L
.64446 .32032 L
.65014 .31061 L
.65054 .30976 L
Mistroke
.65411 .30089 L
.65731 .29118 L
.66026 .2853 L
.66182 .28147 L
.66387 .27176 L
.66937 .26204 L
.66997 .26073 L
.67328 .25233 L
.67631 .24262 L
.67968 .23577 L
.68083 .23291 L
.68252 .22319 L
.6881 .21348 L
.68939 .21064 L
.69206 .20377 L
.69471 .19406 L
.69911 .18522 L
.69946 .18434 L
.70315 .17463 L
.70632 .16492 L
.70882 .1595 L
.71047 .15521 L
.71247 .14549 L
.71758 .13578 L
.71853 .13359 L
.72136 .12607 L
.72397 .11636 L
.72824 .10739 L
.72853 .10664 L
.73212 .09693 L
.73511 .08722 L
.73796 .0809 L
.73923 .07751 L
.74085 .06779 L
.746 .05808 L
.74767 .0542 L
.74981 .04837 L
.75195 .03866 L
.75668 .02894 L
.75738 .02734 L
.76028 .01923 L
Mfstroke
.2 g
.50486 .44772 m
.51036 .45629 L
.50486 .4643 L
.50147 .45629 L
F
0 g
.50486 .44772 m
.51036 .45629 L
.50486 .4643 L
.50147 .45629 L
.50486 .44772 L
s
.2 g
.71315 .01923 m
.70949 .02894 L
.70882 .03036 L
.70552 .03866 L
.70256 .04837 L
.69911 .05493 L
.69781 .05808 L
.69391 .06779 L
.69018 .07751 L
.68939 .0791 L
.68608 .08722 L
.68301 .09693 L
.67968 .10305 L
.67816 .10664 L
.67416 .11636 L
.67021 .12607 L
.66997 .12655 L
.6661 .13578 L
.66265 .14549 L
.66026 .14986 L
.65795 .15521 L
.65543 .16492 L
.65054 .17277 L
.6497 .17463 L
.64552 .18434 L
.64149 .19406 L
.64083 .19527 L
.6371 .20377 L
.63353 .21348 L
.63112 .21754 L
.62856 .22319 L
.62424 .23291 L
.62141 .23942 L
.6199 .24262 L
.6155 .25233 L
.61169 .26085 L
.6111 .26204 L
.60662 .27176 L
.6022 .28147 L
.60198 .28184 L
.59759 .29118 L
.59335 .30089 L
.59227 .30257 L
.58839 .31061 L
.58436 .32032 L
.58256 .32288 L
.579 .33003 L
.57424 .33974 L
.57284 .34274 L
.5694 .34946 L
.56453 .35917 L
.56313 .36212 L
.55957 .36888 L
.55456 .37859 L
.55342 .38098 L
.54945 .38831 L
.5443 .39802 L
.54371 .39922 L
.539 .40773 L
.53399 .41683 L
.53365 .41744 L
.52811 .42716 L
.52428 .4338 L
.52245 .43687 L
.51657 .44658 L
.51457 .44983 L
.50533 .44658 L
.50946 .43687 L
.51366 .42716 L
.51457 .42415 L
.51796 .41744 L
.52228 .40773 L
.52428 .40187 L
.52663 .39802 L
.53098 .38831 L
.53399 .38037 L
.53534 .37859 L
.5397 .36888 L
.54371 .35948 L
.54404 .35917 L
.54839 .34946 L
.55239 .33974 L
.55342 .33803 L
.55704 .33003 L
.56038 .32032 L
.56313 .31595 L
.56562 .31061 L
.56988 .30089 L
.57284 .2938 L
.57412 .29118 L
.57836 .28147 L
.58255 .27176 L
.58256 .27175 L
.58676 .26204 L
.59047 .25233 L
.59227 .24905 L
.59508 .24262 L
.59802 .23291 L
.60198 .22617 L
.60332 .22319 L
.60743 .21348 L
.61144 .20377 L
.61169 .20326 L
.61556 .19406 L
.61903 .18434 L
.62141 .17983 L
.62362 .17463 L
.62616 .16492 L
.63112 .15628 L
.63159 .15521 L
.63557 .14549 L
.63917 .13578 L
.64083 .13243 L
.64345 .12607 L
.64623 .11636 L
.65054 .10831 L
.65125 .10664 L
.65514 .09693 L
.65869 .08722 L
.66026 .08395 L
.66285 .07751 L
.66556 .06779 L
.66997 .05932 L
.67048 .05808 L
.67429 .04837 L
.67767 .03866 L
.67968 .0344 L
.68183 .02894 L
.68424 .01923 L
F
0 g
.71315 .01923 m
.70949 .02894 L
.70882 .03036 L
.70552 .03866 L
.70256 .04837 L
.69911 .05493 L
.69781 .05808 L
.69391 .06779 L
.69018 .07751 L
.68939 .0791 L
.68608 .08722 L
.68301 .09693 L
.67968 .10305 L
.67816 .10664 L
.67416 .11636 L
.67021 .12607 L
.66997 .12655 L
.6661 .13578 L
.66265 .14549 L
.66026 .14986 L
.65795 .15521 L
.65543 .16492 L
.65054 .17277 L
.6497 .17463 L
.64552 .18434 L
.64149 .19406 L
.64083 .19527 L
.6371 .20377 L
.63353 .21348 L
.63112 .21754 L
.62856 .22319 L
.62424 .23291 L
.62141 .23942 L
.6199 .24262 L
.6155 .25233 L
.61169 .26085 L
.6111 .26204 L
.60662 .27176 L
.6022 .28147 L
.60198 .28184 L
.59759 .29118 L
.59335 .30089 L
.59227 .30257 L
.58839 .31061 L
.58436 .32032 L
.58256 .32288 L
.579 .33003 L
.57424 .33974 L
.57284 .34274 L
.5694 .34946 L
Mistroke
.56453 .35917 L
.56313 .36212 L
.55957 .36888 L
.55456 .37859 L
.55342 .38098 L
.54945 .38831 L
.5443 .39802 L
.54371 .39922 L
.539 .40773 L
.53399 .41683 L
.53365 .41744 L
.52811 .42716 L
.52428 .4338 L
.52245 .43687 L
.51657 .44658 L
.51457 .44983 L
.50533 .44658 L
.50946 .43687 L
.51366 .42716 L
.51457 .42415 L
.51796 .41744 L
.52228 .40773 L
.52428 .40187 L
.52663 .39802 L
.53098 .38831 L
.53399 .38037 L
.53534 .37859 L
.5397 .36888 L
.54371 .35948 L
.54404 .35917 L
.54839 .34946 L
.55239 .33974 L
.55342 .33803 L
.55704 .33003 L
.56038 .32032 L
.56313 .31595 L
.56562 .31061 L
.56988 .30089 L
.57284 .2938 L
.57412 .29118 L
.57836 .28147 L
.58255 .27176 L
.58256 .27175 L
.58676 .26204 L
.59047 .25233 L
.59227 .24905 L
.59508 .24262 L
.59802 .23291 L
.60198 .22617 L
.60332 .22319 L
Mistroke
.60743 .21348 L
.61144 .20377 L
.61169 .20326 L
.61556 .19406 L
.61903 .18434 L
.62141 .17983 L
.62362 .17463 L
.62616 .16492 L
.63112 .15628 L
.63159 .15521 L
.63557 .14549 L
.63917 .13578 L
.64083 .13243 L
.64345 .12607 L
.64623 .11636 L
.65054 .10831 L
.65125 .10664 L
.65514 .09693 L
.65869 .08722 L
.66026 .08395 L
.66285 .07751 L
.66556 .06779 L
.66997 .05932 L
.67048 .05808 L
.67429 .04837 L
.67767 .03866 L
.67968 .0344 L
.68183 .02894 L
.68424 .01923 L
Mfstroke
.8 g
.51457 .22369 m
.52399 .23291 L
.51815 .24262 L
.51457 .24844 L
.50642 .24262 L
.51057 .23291 L
F
0 g
.51457 .22369 m
.52399 .23291 L
.51815 .24262 L
.51457 .24844 L
.50642 .24262 L
.51057 .23291 L
.51457 .22369 L
s
.2 g
.85971 .01923 m
.85522 .02894 L
.85451 .03073 L
.85181 .03866 L
.84983 .04837 L
.84534 .05808 L
.84479 .05945 L
.84193 .06779 L
.83982 .07751 L
.83536 .08722 L
.83508 .0879 L
.83195 .09693 L
.82967 .10664 L
.82537 .1161 L
.82528 .11636 L
.82188 .12607 L
.81939 .13578 L
.81566 .14406 L
.81514 .14549 L
.81172 .15521 L
.80899 .16492 L
.80594 .17174 L
.8049 .17463 L
.80145 .18434 L
.79847 .19406 L
.79623 .19915 L
.79455 .20377 L
.79301 .21348 L
.78786 .22319 L
.78652 .22627 L
.7841 .23291 L
.78199 .24262 L
.77714 .25233 L
.77681 .25311 L
.77352 .26204 L
.77091 .27176 L
.76709 .27972 L
.76643 .28147 L
.76283 .29118 L
.75976 .30089 L
.75738 .30603 L
.75564 .31061 L
.7539 .32032 L
.74856 .33003 L
.74767 .33201 L
.74473 .33974 L
.74215 .34946 L
.73796 .35775 L
.7374 .35917 L
.73368 .36888 L
.73046 .37859 L
.72824 .3832 L
.72624 .38831 L
.72418 .39802 L
.71879 .40773 L
.71853 .40828 L
.71494 .41744 L
.71189 .42716 L
.70882 .43318 L
.70732 .43687 L
.70347 .44658 L
.69976 .45629 L
.69911 .45765 L
.69574 .46601 L
.6927 .47572 L
.68939 .48192 L
.68793 .48543 L
.68398 .49514 L
.68013 .50486 L
.67968 .50575 L
.67604 .51457 L
.67275 .52428 L
.66997 .52939 L
.66801 .53399 L
.66395 .54371 L
.66026 .55259 L
.65989 .55342 L
.65576 .56313 L
.65199 .57284 L
.65054 .57551 L
.64748 .58256 L
.64436 .59227 L
.64083 .59812 L
.63909 .60198 L
.63484 .61169 L
.63112 .62029 L
.63059 .62141 L
.62626 .63112 L
.62212 .64083 L
.62141 .64208 L
.61756 .65054 L
.6138 .66026 L
.61169 .66362 L
.60872 .66997 L
.60425 .67968 L
.60198 .68476 L
.59973 .68939 L
.59517 .69911 L
.59227 .70548 L
.59057 .70882 L
.58592 .71853 L
.58256 .72577 L
.58123 .72824 L
.57647 .73796 L
.57284 .74564 L
.57169 .74767 L
.56682 .75738 L
.56313 .76508 L
.56191 .76709 L
.55691 .77681 L
.55342 .78408 L
.55187 .78652 L
.54672 .79623 L
.54371 .80253 L
.5415 .80594 L
.53617 .81566 L
.53399 .82023 L
.53072 .82537 L
.52514 .83508 L
.52428 .83686 L
.51935 .84479 L
.51457 .8526 L
.50725 .84479 L
.51142 .83508 L
.51457 .82784 L
.51567 .82537 L
.51998 .81566 L
.52428 .80599 L
.5243 .80594 L
.52867 .79623 L
.53302 .78652 L
.53399 .78404 L
.53739 .77681 L
.54174 .76709 L
.54371 .76218 L
.54609 .75738 L
.55042 .74767 L
.55342 .74041 L
.55474 .73796 L
.55905 .72824 L
.56313 .71886 L
.56333 .71853 L
.56762 .70882 L
.5715 .69911 L
.57284 .69674 L
.57611 .68939 L
.57931 .67968 L
.58256 .6743 L
.58453 .66997 L
.58872 .66026 L
.59227 .65179 L
.59287 .65054 L
.59702 .64083 L
.6009 .63112 L
.60198 .62905 L
.60525 .62141 L
.60847 .61169 L
.61169 .60589 L
.6134 .60198 L
.61746 .59227 L
.62141 .5827 L
.62147 .58256 L
.6255 .57284 L
.62902 .56313 L
.63112 .55903 L
.63346 .55342 L
.6361 .54371 L
.64083 .5352 L
.64135 .53399 L
.64529 .52428 L
.64884 .51457 L
.65054 .51109 L
.65308 .50486 L
.65579 .49514 L
.66026 .48672 L
.66079 .48543 L
.66465 .47572 L
.66809 .46601 L
.66997 .46207 L
.67227 .45629 L
.6748 .44658 L
.67968 .43722 L
.67983 .43687 L
.6836 .42716 L
.68681 .41744 L
.68939 .41199 L
.69107 .40773 L
.69314 .39802 L
.69835 .38831 L
.69911 .38662 L
.70218 .37859 L
.70498 .36888 L
.70882 .3609 L
.7095 .35917 L
.71315 .34946 L
.71637 .33974 L
.71853 .33495 L
.7204 .33003 L
.7225 .32032 L
.72746 .31061 L
.72824 .30878 L
.73117 .30089 L
.7338 .29118 L
.73796 .28232 L
.73828 .28147 L
.74184 .27176 L
.74478 .26204 L
.74767 .25557 L
.74887 .25233 L
.75041 .24262 L
.75554 .23291 L
.75738 .22861 L
.75935 .22319 L
.76136 .21348 L
.76611 .20377 L
.76709 .20141 L
.76973 .19406 L
.77205 .18434 L
.77653 .17463 L
.77681 .17396 L
.78001 .16492 L
.78254 .15521 L
.78652 .14623 L
.78678 .14549 L
.79019 .13578 L
.79286 .12607 L
.79623 .11825 L
.7969 .11636 L
.80027 .10664 L
.80304 .09693 L
.80594 .09003 L
.80693 .08722 L
.81027 .07751 L
.81309 .06779 L
.81566 .06158 L
.81687 .05808 L
.81811 .04837 L
.82302 .03866 L
.82537 .03288 L
.82672 .02894 L
.82802 .01923 L
F
0 g
.85971 .01923 m
.85522 .02894 L
.85451 .03073 L
.85181 .03866 L
.84983 .04837 L
.84534 .05808 L
.84479 .05945 L
.84193 .06779 L
.83982 .07751 L
.83536 .08722 L
.83508 .0879 L
.83195 .09693 L
.82967 .10664 L
.82537 .1161 L
.82528 .11636 L
.82188 .12607 L
.81939 .13578 L
.81566 .14406 L
.81514 .14549 L
.81172 .15521 L
.80899 .16492 L
.80594 .17174 L
.8049 .17463 L
.80145 .18434 L
.79847 .19406 L
.79623 .19915 L
.79455 .20377 L
.79301 .21348 L
.78786 .22319 L
.78652 .22627 L
.7841 .23291 L
.78199 .24262 L
.77714 .25233 L
.77681 .25311 L
.77352 .26204 L
.77091 .27176 L
.76709 .27972 L
.76643 .28147 L
.76283 .29118 L
.75976 .30089 L
.75738 .30603 L
.75564 .31061 L
.7539 .32032 L
.74856 .33003 L
.74767 .33201 L
.74473 .33974 L
.74215 .34946 L
.73796 .35775 L
.7374 .35917 L
.73368 .36888 L
Mistroke
.73046 .37859 L
.72824 .3832 L
.72624 .38831 L
.72418 .39802 L
.71879 .40773 L
.71853 .40828 L
.71494 .41744 L
.71189 .42716 L
.70882 .43318 L
.70732 .43687 L
.70347 .44658 L
.69976 .45629 L
.69911 .45765 L
.69574 .46601 L
.6927 .47572 L
.68939 .48192 L
.68793 .48543 L
.68398 .49514 L
.68013 .50486 L
.67968 .50575 L
.67604 .51457 L
.67275 .52428 L
.66997 .52939 L
.66801 .53399 L
.66395 .54371 L
.66026 .55259 L
.65989 .55342 L
.65576 .56313 L
.65199 .57284 L
.65054 .57551 L
.64748 .58256 L
.64436 .59227 L
.64083 .59812 L
.63909 .60198 L
.63484 .61169 L
.63112 .62029 L
.63059 .62141 L
.62626 .63112 L
.62212 .64083 L
.62141 .64208 L
.61756 .65054 L
.6138 .66026 L
.61169 .66362 L
.60872 .66997 L
.60425 .67968 L
.60198 .68476 L
.59973 .68939 L
.59517 .69911 L
.59227 .70548 L
.59057 .70882 L
Mistroke
.58592 .71853 L
.58256 .72577 L
.58123 .72824 L
.57647 .73796 L
.57284 .74564 L
.57169 .74767 L
.56682 .75738 L
.56313 .76508 L
.56191 .76709 L
.55691 .77681 L
.55342 .78408 L
.55187 .78652 L
.54672 .79623 L
.54371 .80253 L
.5415 .80594 L
.53617 .81566 L
.53399 .82023 L
.53072 .82537 L
.52514 .83508 L
.52428 .83686 L
.51935 .84479 L
.51457 .8526 L
.50725 .84479 L
.51142 .83508 L
.51457 .82784 L
.51567 .82537 L
.51998 .81566 L
.52428 .80599 L
.5243 .80594 L
.52867 .79623 L
.53302 .78652 L
.53399 .78404 L
.53739 .77681 L
.54174 .76709 L
.54371 .76218 L
.54609 .75738 L
.55042 .74767 L
.55342 .74041 L
.55474 .73796 L
.55905 .72824 L
.56313 .71886 L
.56333 .71853 L
.56762 .70882 L
.5715 .69911 L
.57284 .69674 L
.57611 .68939 L
.57931 .67968 L
.58256 .6743 L
.58453 .66997 L
.58872 .66026 L
Mistroke
.59227 .65179 L
.59287 .65054 L
.59702 .64083 L
.6009 .63112 L
.60198 .62905 L
.60525 .62141 L
.60847 .61169 L
.61169 .60589 L
.6134 .60198 L
.61746 .59227 L
.62141 .5827 L
.62147 .58256 L
.6255 .57284 L
.62902 .56313 L
.63112 .55903 L
.63346 .55342 L
.6361 .54371 L
.64083 .5352 L
.64135 .53399 L
.64529 .52428 L
.64884 .51457 L
.65054 .51109 L
.65308 .50486 L
.65579 .49514 L
.66026 .48672 L
.66079 .48543 L
.66465 .47572 L
.66809 .46601 L
.66997 .46207 L
.67227 .45629 L
.6748 .44658 L
.67968 .43722 L
.67983 .43687 L
.6836 .42716 L
.68681 .41744 L
.68939 .41199 L
.69107 .40773 L
.69314 .39802 L
.69835 .38831 L
.69911 .38662 L
.70218 .37859 L
.70498 .36888 L
.70882 .3609 L
.7095 .35917 L
.71315 .34946 L
.71637 .33974 L
.71853 .33495 L
.7204 .33003 L
.7225 .32032 L
.72746 .31061 L
Mistroke
.72824 .30878 L
.73117 .30089 L
.7338 .29118 L
.73796 .28232 L
.73828 .28147 L
.74184 .27176 L
.74478 .26204 L
.74767 .25557 L
.74887 .25233 L
.75041 .24262 L
.75554 .23291 L
.75738 .22861 L
.75935 .22319 L
.76136 .21348 L
.76611 .20377 L
.76709 .20141 L
.76973 .19406 L
.77205 .18434 L
.77653 .17463 L
.77681 .17396 L
.78001 .16492 L
.78254 .15521 L
.78652 .14623 L
.78678 .14549 L
.79019 .13578 L
.79286 .12607 L
.79623 .11825 L
.7969 .11636 L
.80027 .10664 L
.80304 .09693 L
.80594 .09003 L
.80693 .08722 L
.81027 .07751 L
.81309 .06779 L
.81566 .06158 L
.81687 .05808 L
.81811 .04837 L
.82302 .03866 L
.82537 .03288 L
.82672 .02894 L
.82802 .01923 L
Mfstroke
.2 g
.53106 .01923 m
.52549 .02894 L
.52428 .03148 L
.51971 .03866 L
.51457 .04706 L
.50751 .03866 L
.51168 .02894 L
.51457 .0223 L
.51593 .01923 L
F
0 g
.53106 .01923 m
.52549 .02894 L
.52428 .03148 L
.51971 .03866 L
.51457 .04706 L
.50751 .03866 L
.51168 .02894 L
.51457 .0223 L
.51593 .01923 L
s
.8 g
.62971 .01923 m
.62539 .02894 L
.62141 .03796 L
.62106 .03866 L
.61667 .04837 L
.61248 .05808 L
.61169 .0594 L
.60781 .06779 L
.60395 .07751 L
.60198 .08054 L
.5988 .08722 L
.59424 .09693 L
.59227 .10128 L
.58962 .10664 L
.58497 .11636 L
.58256 .1216 L
.58026 .12607 L
.57551 .13578 L
.57284 .14148 L
.5707 .14549 L
.56582 .15521 L
.56313 .1609 L
.5609 .16492 L
.55589 .17463 L
.55342 .17982 L
.55082 .18434 L
.54567 .19406 L
.54371 .19814 L
.54042 .20377 L
.53508 .21348 L
.53399 .21571 L
.52959 .22319 L
.52428 .23242 L
.51479 .22319 L
.51911 .21348 L
.52342 .20377 L
.52428 .20143 L
.52778 .19406 L
.53214 .18434 L
.53399 .1795 L
.5365 .17463 L
.54086 .16492 L
.54371 .15782 L
.5452 .15521 L
.54954 .14549 L
.55342 .13643 L
.55386 .13578 L
.55818 .12607 L
.5622 .11636 L
.56313 .11474 L
.56675 .10664 L
.57016 .09693 L
.57284 .09248 L
.57525 .08722 L
.57948 .07751 L
.58256 .07013 L
.58367 .06779 L
.58787 .05808 L
.59196 .04837 L
.59227 .04777 L
.59618 .03866 L
.59974 .02894 L
.60198 .02614 L
.60442 .01923 L
F
0 g
.62971 .01923 m
.62539 .02894 L
.62141 .03796 L
.62106 .03866 L
.61667 .04837 L
.61248 .05808 L
.61169 .0594 L
.60781 .06779 L
.60395 .07751 L
.60198 .08054 L
.5988 .08722 L
.59424 .09693 L
.59227 .10128 L
.58962 .10664 L
.58497 .11636 L
.58256 .1216 L
.58026 .12607 L
.57551 .13578 L
.57284 .14148 L
.5707 .14549 L
.56582 .15521 L
.56313 .1609 L
.5609 .16492 L
.55589 .17463 L
.55342 .17982 L
.55082 .18434 L
.54567 .19406 L
.54371 .19814 L
.54042 .20377 L
.53508 .21348 L
.53399 .21571 L
.52959 .22319 L
.52428 .23242 L
.51479 .22319 L
.51911 .21348 L
.52342 .20377 L
.52428 .20143 L
.52778 .19406 L
.53214 .18434 L
.53399 .1795 L
.5365 .17463 L
.54086 .16492 L
.54371 .15782 L
.5452 .15521 L
.54954 .14549 L
.55342 .13643 L
.55386 .13578 L
.55818 .12607 L
.5622 .11636 L
.56313 .11474 L
Mistroke
.56675 .10664 L
.57016 .09693 L
.57284 .09248 L
.57525 .08722 L
.57948 .07751 L
.58256 .07013 L
.58367 .06779 L
.58787 .05808 L
.59196 .04837 L
.59227 .04777 L
.59618 .03866 L
.59974 .02894 L
.60198 .02614 L
.60442 .01923 L
Mfstroke
.7 g
.51481 .98077 m
.51964 .97106 L
.52428 .96187 L
.52453 .96134 L
.52927 .95163 L
.53399 .94212 L
.53409 .94192 L
.53873 .93221 L
.54348 .92249 L
.54371 .92202 L
.54804 .91278 L
.55271 .90307 L
.55342 .90158 L
.5572 .89336 L
.5618 .88364 L
.56313 .88081 L
.56623 .87393 L
.57075 .86422 L
.57284 .85971 L
.57513 .85451 L
.57957 .84479 L
.58256 .83828 L
.58393 .83508 L
.58827 .82537 L
.59227 .81654 L
.59263 .81566 L
.59686 .80594 L
.6012 .79623 L
.60198 .79447 L
.60534 .78652 L
.60962 .77681 L
.61169 .77208 L
.61375 .76709 L
.61794 .75738 L
.62141 .7494 L
.62209 .74767 L
.62616 .73796 L
.63033 .72824 L
.63112 .7264 L
.6343 .71853 L
.63841 .70882 L
.64083 .7031 L
.64239 .69911 L
.6464 .68939 L
.65047 .67968 L
.65054 .67951 L
.65431 .66997 L
.65834 .66026 L
.66026 .65561 L
.66219 .65054 L
.66612 .64083 L
.66997 .63143 L
.67008 .63112 L
.67383 .62141 L
.67777 .61169 L
.67968 .60695 L
.68152 .60198 L
.68536 .59227 L
.68925 .58256 L
.68939 .5822 L
.6929 .57284 L
.69674 .56313 L
.69911 .55715 L
.70044 .55342 L
.70416 .54371 L
.70798 .53399 L
.70882 .53184 L
.71155 .52428 L
.7153 .51457 L
.71853 .50624 L
.719 .50486 L
.72256 .49514 L
.7263 .48543 L
.72824 .48037 L
.72984 .47572 L
.73347 .46601 L
.73717 .45629 L
.73796 .45423 L
.74061 .44658 L
.74426 .43687 L
.74767 .42782 L
.74788 .42716 L
.75129 .41744 L
.75492 .40773 L
.75738 .40113 L
.75839 .39802 L
.76187 .38831 L
.76547 .37859 L
.76709 .37419 L
.76884 .36888 L
.77234 .35917 L
.77591 .34946 L
.77681 .34699 L
.7792 .33974 L
.7827 .33003 L
.78624 .32032 L
.78652 .31954 L
.78947 .31061 L
.79296 .30089 L
.79623 .29182 L
.79642 .29118 L
.79964 .28147 L
.80312 .27176 L
.80594 .26385 L
.80648 .26204 L
.80973 .25233 L
.81318 .24262 L
.81566 .23562 L
.81646 .23291 L
.81972 .22319 L
.82315 .21348 L
.82537 .20715 L
.82637 .20377 L
.82962 .19406 L
.83303 .18434 L
.83508 .17843 L
.8362 .17463 L
.83943 .16492 L
.84281 .15521 L
.84479 .14946 L
.84595 .14549 L
.84916 .13578 L
.85252 .12607 L
.85451 .12025 L
.85562 .11636 L
.85881 .10664 L
.86214 .09693 L
.86422 .0908 L
.86523 .08722 L
.86837 .07751 L
.87168 .06779 L
.87393 .06111 L
.87476 .05808 L
.87786 .04837 L
.88114 .03866 L
.88364 .03119 L
.88424 .02894 L
.88727 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.51481 .98077 m
.51964 .97106 L
.52428 .96187 L
.52453 .96134 L
.52927 .95163 L
.53399 .94212 L
.53409 .94192 L
.53873 .93221 L
.54348 .92249 L
.54371 .92202 L
.54804 .91278 L
.55271 .90307 L
.55342 .90158 L
.5572 .89336 L
.5618 .88364 L
.56313 .88081 L
.56623 .87393 L
.57075 .86422 L
.57284 .85971 L
.57513 .85451 L
.57957 .84479 L
.58256 .83828 L
.58393 .83508 L
.58827 .82537 L
.59227 .81654 L
.59263 .81566 L
.59686 .80594 L
.6012 .79623 L
.60198 .79447 L
.60534 .78652 L
.60962 .77681 L
.61169 .77208 L
.61375 .76709 L
.61794 .75738 L
.62141 .7494 L
.62209 .74767 L
.62616 .73796 L
.63033 .72824 L
.63112 .7264 L
.6343 .71853 L
.63841 .70882 L
.64083 .7031 L
.64239 .69911 L
.6464 .68939 L
.65047 .67968 L
.65054 .67951 L
.65431 .66997 L
.65834 .66026 L
.66026 .65561 L
.66219 .65054 L
Mistroke
.66612 .64083 L
.66997 .63143 L
.67008 .63112 L
.67383 .62141 L
.67777 .61169 L
.67968 .60695 L
.68152 .60198 L
.68536 .59227 L
.68925 .58256 L
.68939 .5822 L
.6929 .57284 L
.69674 .56313 L
.69911 .55715 L
.70044 .55342 L
.70416 .54371 L
.70798 .53399 L
.70882 .53184 L
.71155 .52428 L
.7153 .51457 L
.71853 .50624 L
.719 .50486 L
.72256 .49514 L
.7263 .48543 L
.72824 .48037 L
.72984 .47572 L
.73347 .46601 L
.73717 .45629 L
.73796 .45423 L
.74061 .44658 L
.74426 .43687 L
.74767 .42782 L
.74788 .42716 L
.75129 .41744 L
.75492 .40773 L
.75738 .40113 L
.75839 .39802 L
.76187 .38831 L
.76547 .37859 L
.76709 .37419 L
.76884 .36888 L
.77234 .35917 L
.77591 .34946 L
.77681 .34699 L
.7792 .33974 L
.7827 .33003 L
.78624 .32032 L
.78652 .31954 L
.78947 .31061 L
.79296 .30089 L
.79623 .29182 L
Mistroke
.79642 .29118 L
.79964 .28147 L
.80312 .27176 L
.80594 .26385 L
.80648 .26204 L
.80973 .25233 L
.81318 .24262 L
.81566 .23562 L
.81646 .23291 L
.81972 .22319 L
.82315 .21348 L
.82537 .20715 L
.82637 .20377 L
.82962 .19406 L
.83303 .18434 L
.83508 .17843 L
.8362 .17463 L
.83943 .16492 L
.84281 .15521 L
.84479 .14946 L
.84595 .14549 L
.84916 .13578 L
.85252 .12607 L
.85451 .12025 L
.85562 .11636 L
.85881 .10664 L
.86214 .09693 L
.86422 .0908 L
.86523 .08722 L
.86837 .07751 L
.87168 .06779 L
.87393 .06111 L
.87476 .05808 L
.87786 .04837 L
.88114 .03866 L
.88364 .03119 L
.88424 .02894 L
.88727 .01923 L
Mfstroke
.8 g
.53623 .98077 m
.54059 .97106 L
.54371 .96333 L
.54493 .96134 L
.54928 .95163 L
.55342 .94214 L
.55359 .94192 L
.55791 .93221 L
.56181 .92249 L
.56313 .92024 L
.56649 .91278 L
.5697 .90307 L
.57284 .89799 L
.57499 .89336 L
.57921 .88364 L
.58256 .87568 L
.58341 .87393 L
.58761 .86422 L
.59162 .85451 L
.59227 .85328 L
.59593 .84479 L
.59936 .83508 L
.60198 .83035 L
.60416 .82537 L
.60664 .81566 L
.61169 .80731 L
.61232 .80594 L
.61638 .79623 L
.62015 .78652 L
.62141 .78403 L
.62443 .77681 L
.62749 .76709 L
.63112 .76038 L
.63241 .75738 L
.63638 .74767 L
.64019 .73796 L
.64083 .73663 L
.64425 .72824 L
.64743 .71853 L
.65054 .71244 L
.65204 .70882 L
.65405 .69911 L
.65967 .68939 L
.66026 .68814 L
.66363 .67968 L
.66671 .66997 L
.66997 .66344 L
.67126 .66026 L
.67308 .65054 L
.67865 .64083 L
.67968 .63858 L
.6826 .63112 L
.68541 .62141 L
.68939 .6134 L
.69007 .61169 L
.69381 .60198 L
.69713 .59227 L
.69911 .58796 L
.7012 .58256 L
.7035 .57284 L
.70847 .56313 L
.70882 .56233 L
.71219 .55342 L
.71507 .54371 L
.71853 .53633 L
.71943 .53399 L
.72305 .52428 L
.72628 .51457 L
.72824 .51013 L
.73022 .50486 L
.73235 .49514 L
.73722 .48543 L
.73796 .4837 L
.74089 .47572 L
.74348 .46601 L
.74767 .45699 L
.74793 .45629 L
.75146 .44658 L
.75433 .43687 L
.75738 .42999 L
.75842 .42716 L
.7598 .41744 L
.76497 .40773 L
.76709 .40277 L
.76881 .39802 L
.77062 .38831 L
.77545 .37859 L
.77681 .37532 L
.7791 .36888 L
.78121 .35917 L
.78577 .34946 L
.78652 .34761 L
.78929 .33974 L
.79159 .33003 L
.79597 .32032 L
.79623 .31966 L
.79938 .31061 L
.80182 .30089 L
.80594 .29145 L
.80604 .29118 L
.80938 .28147 L
.8119 .27176 L
.81566 .26298 L
.81599 .26204 L
.8193 .25233 L
.82186 .24262 L
.82537 .23428 L
.82585 .23291 L
.82913 .22319 L
.83169 .21348 L
.83508 .20534 L
.83562 .20377 L
.83888 .19406 L
.84142 .18434 L
.84479 .17617 L
.84532 .17463 L
.84855 .16492 L
.85104 .15521 L
.85451 .14676 L
.85494 .14549 L
.85814 .13578 L
.86055 .12607 L
.86422 .11713 L
.86448 .11636 L
.86766 .10664 L
.86996 .09693 L
.87393 .08726 L
.87395 .08722 L
.87711 .07751 L
.87925 .06779 L
.8833 .05808 L
.88364 .05714 L
.88648 .04837 L
.88843 .03866 L
.89256 .02894 L
.89336 .02686 L
.89579 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.53623 .98077 m
.54059 .97106 L
.54371 .96333 L
.54493 .96134 L
.54928 .95163 L
.55342 .94214 L
.55359 .94192 L
.55791 .93221 L
.56181 .92249 L
.56313 .92024 L
.56649 .91278 L
.5697 .90307 L
.57284 .89799 L
.57499 .89336 L
.57921 .88364 L
.58256 .87568 L
.58341 .87393 L
.58761 .86422 L
.59162 .85451 L
.59227 .85328 L
.59593 .84479 L
.59936 .83508 L
.60198 .83035 L
.60416 .82537 L
.60664 .81566 L
.61169 .80731 L
.61232 .80594 L
.61638 .79623 L
.62015 .78652 L
.62141 .78403 L
.62443 .77681 L
.62749 .76709 L
.63112 .76038 L
.63241 .75738 L
.63638 .74767 L
.64019 .73796 L
.64083 .73663 L
.64425 .72824 L
.64743 .71853 L
.65054 .71244 L
.65204 .70882 L
.65405 .69911 L
.65967 .68939 L
.66026 .68814 L
.66363 .67968 L
.66671 .66997 L
.66997 .66344 L
.67126 .66026 L
.67308 .65054 L
.67865 .64083 L
Mistroke
.67968 .63858 L
.6826 .63112 L
.68541 .62141 L
.68939 .6134 L
.69007 .61169 L
.69381 .60198 L
.69713 .59227 L
.69911 .58796 L
.7012 .58256 L
.7035 .57284 L
.70847 .56313 L
.70882 .56233 L
.71219 .55342 L
.71507 .54371 L
.71853 .53633 L
.71943 .53399 L
.72305 .52428 L
.72628 .51457 L
.72824 .51013 L
.73022 .50486 L
.73235 .49514 L
.73722 .48543 L
.73796 .4837 L
.74089 .47572 L
.74348 .46601 L
.74767 .45699 L
.74793 .45629 L
.75146 .44658 L
.75433 .43687 L
.75738 .42999 L
.75842 .42716 L
.7598 .41744 L
.76497 .40773 L
.76709 .40277 L
.76881 .39802 L
.77062 .38831 L
.77545 .37859 L
.77681 .37532 L
.7791 .36888 L
.78121 .35917 L
.78577 .34946 L
.78652 .34761 L
.78929 .33974 L
.79159 .33003 L
.79597 .32032 L
.79623 .31966 L
.79938 .31061 L
.80182 .30089 L
.80594 .29145 L
.80604 .29118 L
Mistroke
.80938 .28147 L
.8119 .27176 L
.81566 .26298 L
.81599 .26204 L
.8193 .25233 L
.82186 .24262 L
.82537 .23428 L
.82585 .23291 L
.82913 .22319 L
.83169 .21348 L
.83508 .20534 L
.83562 .20377 L
.83888 .19406 L
.84142 .18434 L
.84479 .17617 L
.84532 .17463 L
.84855 .16492 L
.85104 .15521 L
.85451 .14676 L
.85494 .14549 L
.85814 .13578 L
.86055 .12607 L
.86422 .11713 L
.86448 .11636 L
.86766 .10664 L
.86996 .09693 L
.87393 .08726 L
.87395 .08722 L
.87711 .07751 L
.87925 .06779 L
.8833 .05808 L
.88364 .05714 L
.88648 .04837 L
.88843 .03866 L
.89256 .02894 L
.89336 .02686 L
.89579 .01923 L
Mfstroke
.7 g
.55558 .98077 m
.56059 .97106 L
.56313 .96641 L
.56552 .96134 L
.5704 .95163 L
.57284 .94699 L
.57521 .94192 L
.57997 .93221 L
.58256 .92712 L
.58468 .92249 L
.58934 .91278 L
.59227 .9068 L
.59487 .90307 L
.59852 .89336 L
.60198 .88606 L
.60351 .88364 L
.60753 .87393 L
.61169 .86492 L
.6121 .86422 L
.61639 .85451 L
.62079 .84479 L
.62141 .84353 L
.62512 .83508 L
.62944 .82537 L
.63112 .82172 L
.63494 .81566 L
.63796 .80594 L
.64083 .79946 L
.64266 .79623 L
.64637 .78652 L
.65054 .77683 L
.65056 .77681 L
.65467 .76709 L
.65879 .75738 L
.66026 .75403 L
.66392 .74767 L
.66693 .73796 L
.66997 .73074 L
.67126 .72824 L
.67497 .71853 L
.67898 .70882 L
.67968 .70718 L
.6843 .69911 L
.68688 .68939 L
.68939 .68329 L
.69122 .67968 L
.6947 .66997 L
.69861 .66026 L
.69911 .65906 L
.7038 .65054 L
.7063 .64083 L
.70882 .63454 L
.71049 .63112 L
.71393 .62141 L
.71773 .61169 L
.71853 .60971 L
.72254 .60198 L
.72524 .59227 L
.72824 .58455 L
.72917 .58256 L
.73269 .57284 L
.73641 .56313 L
.73796 .55915 L
.74072 .55342 L
.74375 .54371 L
.74743 .53399 L
.74767 .53339 L
.75228 .52428 L
.75468 .51457 L
.75738 .50739 L
.75852 .50486 L
.76385 .49514 L
.76547 .48543 L
.76709 .48111 L
.76957 .47572 L
.77258 .46601 L
.77614 .45629 L
.77681 .45452 L
.78055 .44658 L
.78316 .43687 L
.78652 .42763 L
.78672 .42716 L
.79146 .41744 L
.79363 .40773 L
.79623 .40052 L
.7973 .39802 L
.80227 .38831 L
.80398 .37859 L
.80594 .37313 L
.80777 .36888 L
.81081 .35917 L
.81423 .34946 L
.81566 .34546 L
.81813 .33974 L
.82099 .33003 L
.82437 .32032 L
.82537 .31752 L
.82838 .31061 L
.83106 .30089 L
.83442 .29118 L
.83508 .28931 L
.83851 .28147 L
.84104 .27176 L
.84437 .26204 L
.84479 .26084 L
.84851 .25233 L
.85093 .24262 L
.85423 .23291 L
.85451 .23212 L
.85839 .22319 L
.86073 .21348 L
.864 .20377 L
.86422 .20314 L
.86815 .19406 L
.87044 .18434 L
.87369 .17463 L
.87393 .17392 L
.87778 .16492 L
.88007 .15521 L
.88329 .14549 L
.88364 .14445 L
.88729 .13578 L
.88963 .12607 L
.89282 .11636 L
.89336 .11474 L
.8967 .10664 L
.8991 .09693 L
.90226 .08722 L
.90307 .08478 L
.90602 .07751 L
.9085 .06779 L
.91164 .05808 L
.91278 .05458 L
.91524 .04837 L
.91783 .03866 L
.92094 .02894 L
.92249 .02407 L
.92439 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.55558 .98077 m
.56059 .97106 L
.56313 .96641 L
.56552 .96134 L
.5704 .95163 L
.57284 .94699 L
.57521 .94192 L
.57997 .93221 L
.58256 .92712 L
.58468 .92249 L
.58934 .91278 L
.59227 .9068 L
.59487 .90307 L
.59852 .89336 L
.60198 .88606 L
.60351 .88364 L
.60753 .87393 L
.61169 .86492 L
.6121 .86422 L
.61639 .85451 L
.62079 .84479 L
.62141 .84353 L
.62512 .83508 L
.62944 .82537 L
.63112 .82172 L
.63494 .81566 L
.63796 .80594 L
.64083 .79946 L
.64266 .79623 L
.64637 .78652 L
.65054 .77683 L
.65056 .77681 L
.65467 .76709 L
.65879 .75738 L
.66026 .75403 L
.66392 .74767 L
.66693 .73796 L
.66997 .73074 L
.67126 .72824 L
.67497 .71853 L
.67898 .70882 L
.67968 .70718 L
.6843 .69911 L
.68688 .68939 L
.68939 .68329 L
.69122 .67968 L
.6947 .66997 L
.69861 .66026 L
.69911 .65906 L
.7038 .65054 L
Mistroke
.7063 .64083 L
.70882 .63454 L
.71049 .63112 L
.71393 .62141 L
.71773 .61169 L
.71853 .60971 L
.72254 .60198 L
.72524 .59227 L
.72824 .58455 L
.72917 .58256 L
.73269 .57284 L
.73641 .56313 L
.73796 .55915 L
.74072 .55342 L
.74375 .54371 L
.74743 .53399 L
.74767 .53339 L
.75228 .52428 L
.75468 .51457 L
.75738 .50739 L
.75852 .50486 L
.76385 .49514 L
.76547 .48543 L
.76709 .48111 L
.76957 .47572 L
.77258 .46601 L
.77614 .45629 L
.77681 .45452 L
.78055 .44658 L
.78316 .43687 L
.78652 .42763 L
.78672 .42716 L
.79146 .41744 L
.79363 .40773 L
.79623 .40052 L
.7973 .39802 L
.80227 .38831 L
.80398 .37859 L
.80594 .37313 L
.80777 .36888 L
.81081 .35917 L
.81423 .34946 L
.81566 .34546 L
.81813 .33974 L
.82099 .33003 L
.82437 .32032 L
.82537 .31752 L
.82838 .31061 L
.83106 .30089 L
.83442 .29118 L
Mistroke
.83508 .28931 L
.83851 .28147 L
.84104 .27176 L
.84437 .26204 L
.84479 .26084 L
.84851 .25233 L
.85093 .24262 L
.85423 .23291 L
.85451 .23212 L
.85839 .22319 L
.86073 .21348 L
.864 .20377 L
.86422 .20314 L
.86815 .19406 L
.87044 .18434 L
.87369 .17463 L
.87393 .17392 L
.87778 .16492 L
.88007 .15521 L
.88329 .14549 L
.88364 .14445 L
.88729 .13578 L
.88963 .12607 L
.89282 .11636 L
.89336 .11474 L
.8967 .10664 L
.8991 .09693 L
.90226 .08722 L
.90307 .08478 L
.90602 .07751 L
.9085 .06779 L
.91164 .05808 L
.91278 .05458 L
.91524 .04837 L
.91783 .03866 L
.92094 .02894 L
.92249 .02407 L
.92439 .01923 L
Mfstroke
.6 g
.57502 .98077 m
.57965 .97106 L
.58256 .96454 L
.58407 .96134 L
.58865 .95163 L
.59227 .94345 L
.59298 .94192 L
.59751 .93221 L
.60178 .92249 L
.60198 .92201 L
.60623 .91278 L
.61054 .90307 L
.61169 .90024 L
.61482 .89336 L
.61914 .88364 L
.62141 .87814 L
.62328 .87393 L
.6276 .86422 L
.63112 .8557 L
.63164 .85451 L
.63592 .84479 L
.64001 .83508 L
.64083 .83295 L
.64413 .82537 L
.64827 .81566 L
.65054 .80987 L
.65223 .80594 L
.65638 .79623 L
.66024 .78652 L
.66026 .78648 L
.66436 .77681 L
.66835 .76709 L
.66997 .76279 L
.67223 .75738 L
.67627 .74767 L
.67968 .73878 L
.68002 .73796 L
.68404 .72824 L
.68793 .71853 L
.68939 .71449 L
.69171 .70882 L
.69565 .69911 L
.69911 .68988 L
.6993 .68939 L
.70323 .67968 L
.70705 .66997 L
.70882 .665 L
.71071 .66026 L
.71458 .65054 L
.71819 .64083 L
.71853 .63981 L
.72197 .63112 L
.72575 .62141 L
.72824 .61435 L
.72928 .61169 L
.73308 .60198 L
.73673 .59227 L
.73796 .5886 L
.74029 .58256 L
.74404 .57284 L
.74749 .56313 L
.74767 .56257 L
.75118 .55342 L
.75485 .54371 L
.75738 .53626 L
.75824 .53399 L
.76193 .52428 L
.7655 .51457 L
.76709 .50969 L
.76891 .50486 L
.77256 .49514 L
.776 .48543 L
.77681 .48284 L
.77946 .47572 L
.78306 .46601 L
.78635 .45629 L
.78652 .45572 L
.78989 .44658 L
.79344 .43687 L
.79623 .42834 L
.79666 .42716 L
.80022 .41744 L
.80371 .40773 L
.80594 .4007 L
.80691 .39802 L
.81044 .38831 L
.81387 .37859 L
.81566 .37279 L
.81706 .36888 L
.82056 .35917 L
.82392 .34946 L
.82537 .34463 L
.82711 .33974 L
.83058 .33003 L
.83388 .32032 L
.83508 .31622 L
.83706 .31061 L
.8405 .30089 L
.84376 .29118 L
.84479 .28755 L
.84692 .28147 L
.85034 .27176 L
.85355 .26204 L
.85451 .25863 L
.85669 .25233 L
.86008 .24262 L
.86327 .23291 L
.86422 .22947 L
.86638 .22319 L
.86974 .21348 L
.87291 .20377 L
.87393 .20005 L
.87598 .19406 L
.87932 .18434 L
.88248 .17463 L
.88364 .1704 L
.8855 .16492 L
.88882 .15521 L
.89199 .14549 L
.89336 .1405 L
.89494 .13578 L
.89824 .12607 L
.90141 .11636 L
.90307 .11036 L
.90431 .10664 L
.90758 .09693 L
.91077 .08722 L
.91278 .07999 L
.9136 .07751 L
.91684 .06779 L
.92004 .05808 L
.92249 .04937 L
.92282 .04837 L
.92604 .03866 L
.92924 .02894 L
.93205 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.57502 .98077 m
.57965 .97106 L
.58256 .96454 L
.58407 .96134 L
.58865 .95163 L
.59227 .94345 L
.59298 .94192 L
.59751 .93221 L
.60178 .92249 L
.60198 .92201 L
.60623 .91278 L
.61054 .90307 L
.61169 .90024 L
.61482 .89336 L
.61914 .88364 L
.62141 .87814 L
.62328 .87393 L
.6276 .86422 L
.63112 .8557 L
.63164 .85451 L
.63592 .84479 L
.64001 .83508 L
.64083 .83295 L
.64413 .82537 L
.64827 .81566 L
.65054 .80987 L
.65223 .80594 L
.65638 .79623 L
.66024 .78652 L
.66026 .78648 L
.66436 .77681 L
.66835 .76709 L
.66997 .76279 L
.67223 .75738 L
.67627 .74767 L
.67968 .73878 L
.68002 .73796 L
.68404 .72824 L
.68793 .71853 L
.68939 .71449 L
.69171 .70882 L
.69565 .69911 L
.69911 .68988 L
.6993 .68939 L
.70323 .67968 L
.70705 .66997 L
.70882 .665 L
.71071 .66026 L
.71458 .65054 L
.71819 .64083 L
Mistroke
.71853 .63981 L
.72197 .63112 L
.72575 .62141 L
.72824 .61435 L
.72928 .61169 L
.73308 .60198 L
.73673 .59227 L
.73796 .5886 L
.74029 .58256 L
.74404 .57284 L
.74749 .56313 L
.74767 .56257 L
.75118 .55342 L
.75485 .54371 L
.75738 .53626 L
.75824 .53399 L
.76193 .52428 L
.7655 .51457 L
.76709 .50969 L
.76891 .50486 L
.77256 .49514 L
.776 .48543 L
.77681 .48284 L
.77946 .47572 L
.78306 .46601 L
.78635 .45629 L
.78652 .45572 L
.78989 .44658 L
.79344 .43687 L
.79623 .42834 L
.79666 .42716 L
.80022 .41744 L
.80371 .40773 L
.80594 .4007 L
.80691 .39802 L
.81044 .38831 L
.81387 .37859 L
.81566 .37279 L
.81706 .36888 L
.82056 .35917 L
.82392 .34946 L
.82537 .34463 L
.82711 .33974 L
.83058 .33003 L
.83388 .32032 L
.83508 .31622 L
.83706 .31061 L
.8405 .30089 L
.84376 .29118 L
.84479 .28755 L
Mistroke
.84692 .28147 L
.85034 .27176 L
.85355 .26204 L
.85451 .25863 L
.85669 .25233 L
.86008 .24262 L
.86327 .23291 L
.86422 .22947 L
.86638 .22319 L
.86974 .21348 L
.87291 .20377 L
.87393 .20005 L
.87598 .19406 L
.87932 .18434 L
.88248 .17463 L
.88364 .1704 L
.8855 .16492 L
.88882 .15521 L
.89199 .14549 L
.89336 .1405 L
.89494 .13578 L
.89824 .12607 L
.90141 .11636 L
.90307 .11036 L
.90431 .10664 L
.90758 .09693 L
.91077 .08722 L
.91278 .07999 L
.9136 .07751 L
.91684 .06779 L
.92004 .05808 L
.92249 .04937 L
.92282 .04837 L
.92604 .03866 L
.92924 .02894 L
.93205 .01923 L
Mfstroke
.5 g
.5869 .98077 m
.5913 .97106 L
.59227 .96889 L
.59569 .96134 L
.60004 .95163 L
.60198 .94723 L
.60435 .94192 L
.60866 .93221 L
.61169 .92524 L
.6129 .92249 L
.61716 .91278 L
.62134 .90307 L
.62141 .90292 L
.62555 .89336 L
.62971 .88364 L
.63112 .88029 L
.63384 .87393 L
.63796 .86422 L
.64083 .85734 L
.64203 .85451 L
.64611 .84479 L
.65014 .83508 L
.65054 .83408 L
.65417 .82537 L
.65818 .81566 L
.66026 .81051 L
.66213 .80594 L
.66611 .79623 L
.66997 .78664 L
.67002 .78652 L
.67396 .77681 L
.67786 .76709 L
.67968 .76248 L
.68172 .75738 L
.68561 .74767 L
.68939 .73801 L
.68942 .73796 L
.69326 .72824 L
.69708 .71853 L
.69911 .71326 L
.70084 .70882 L
.70464 .69911 L
.70837 .68939 L
.70882 .68821 L
.71212 .67968 L
.71586 .66997 L
.71853 .66288 L
.71954 .66026 L
.72326 .65054 L
.72693 .64083 L
.72824 .63728 L
.73058 .63112 L
.73425 .62141 L
.73784 .61169 L
.73796 .61139 L
.74148 .60198 L
.7451 .59227 L
.74767 .58522 L
.74866 .58256 L
.75226 .57284 L
.75583 .56313 L
.75738 .55879 L
.75935 .55342 L
.76292 .54371 L
.76642 .53399 L
.76709 .53208 L
.76993 .52428 L
.77345 .51457 L
.77681 .50511 L
.7769 .50486 L
.7804 .49514 L
.78388 .48543 L
.78652 .47787 L
.78728 .47572 L
.79075 .46601 L
.79419 .45629 L
.79623 .45037 L
.79757 .44658 L
.801 .43687 L
.8044 .42716 L
.80594 .42261 L
.80775 .41744 L
.81116 .40773 L
.81451 .39802 L
.81566 .3946 L
.81784 .38831 L
.82121 .37859 L
.82452 .36888 L
.82537 .36633 L
.82783 .35917 L
.83117 .34946 L
.83445 .33974 L
.83508 .3378 L
.83773 .33003 L
.84104 .32032 L
.84428 .31061 L
.84479 .30903 L
.84754 .30089 L
.85083 .29118 L
.85404 .28147 L
.85451 .28001 L
.85727 .27176 L
.86053 .26204 L
.86372 .25233 L
.86422 .25074 L
.86692 .24262 L
.87015 .23291 L
.87331 .22319 L
.87393 .22123 L
.87649 .21348 L
.8797 .20377 L
.88284 .19406 L
.88364 .19148 L
.88598 .18434 L
.88916 .17463 L
.89229 .16492 L
.89336 .16149 L
.89539 .15521 L
.89856 .14549 L
.90167 .13578 L
.90307 .13126 L
.90474 .12607 L
.90788 .11636 L
.91098 .10664 L
.91278 .1008 L
.91401 .09693 L
.91713 .08722 L
.92022 .07751 L
.92249 .0701 L
.92322 .06779 L
.92631 .05808 L
.92939 .04837 L
.93221 .03916 L
.93237 .03866 L
.93543 .02894 L
.93849 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.5869 .98077 m
.5913 .97106 L
.59227 .96889 L
.59569 .96134 L
.60004 .95163 L
.60198 .94723 L
.60435 .94192 L
.60866 .93221 L
.61169 .92524 L
.6129 .92249 L
.61716 .91278 L
.62134 .90307 L
.62141 .90292 L
.62555 .89336 L
.62971 .88364 L
.63112 .88029 L
.63384 .87393 L
.63796 .86422 L
.64083 .85734 L
.64203 .85451 L
.64611 .84479 L
.65014 .83508 L
.65054 .83408 L
.65417 .82537 L
.65818 .81566 L
.66026 .81051 L
.66213 .80594 L
.66611 .79623 L
.66997 .78664 L
.67002 .78652 L
.67396 .77681 L
.67786 .76709 L
.67968 .76248 L
.68172 .75738 L
.68561 .74767 L
.68939 .73801 L
.68942 .73796 L
.69326 .72824 L
.69708 .71853 L
.69911 .71326 L
.70084 .70882 L
.70464 .69911 L
.70837 .68939 L
.70882 .68821 L
.71212 .67968 L
.71586 .66997 L
.71853 .66288 L
.71954 .66026 L
.72326 .65054 L
.72693 .64083 L
Mistroke
.72824 .63728 L
.73058 .63112 L
.73425 .62141 L
.73784 .61169 L
.73796 .61139 L
.74148 .60198 L
.7451 .59227 L
.74767 .58522 L
.74866 .58256 L
.75226 .57284 L
.75583 .56313 L
.75738 .55879 L
.75935 .55342 L
.76292 .54371 L
.76642 .53399 L
.76709 .53208 L
.76993 .52428 L
.77345 .51457 L
.77681 .50511 L
.7769 .50486 L
.7804 .49514 L
.78388 .48543 L
.78652 .47787 L
.78728 .47572 L
.79075 .46601 L
.79419 .45629 L
.79623 .45037 L
.79757 .44658 L
.801 .43687 L
.8044 .42716 L
.80594 .42261 L
.80775 .41744 L
.81116 .40773 L
.81451 .39802 L
.81566 .3946 L
.81784 .38831 L
.82121 .37859 L
.82452 .36888 L
.82537 .36633 L
.82783 .35917 L
.83117 .34946 L
.83445 .33974 L
.83508 .3378 L
.83773 .33003 L
.84104 .32032 L
.84428 .31061 L
.84479 .30903 L
.84754 .30089 L
.85083 .29118 L
.85404 .28147 L
Mistroke
.85451 .28001 L
.85727 .27176 L
.86053 .26204 L
.86372 .25233 L
.86422 .25074 L
.86692 .24262 L
.87015 .23291 L
.87331 .22319 L
.87393 .22123 L
.87649 .21348 L
.8797 .20377 L
.88284 .19406 L
.88364 .19148 L
.88598 .18434 L
.88916 .17463 L
.89229 .16492 L
.89336 .16149 L
.89539 .15521 L
.89856 .14549 L
.90167 .13578 L
.90307 .13126 L
.90474 .12607 L
.90788 .11636 L
.91098 .10664 L
.91278 .1008 L
.91401 .09693 L
.91713 .08722 L
.92022 .07751 L
.92249 .0701 L
.92322 .06779 L
.92631 .05808 L
.92939 .04837 L
.93221 .03916 L
.93237 .03866 L
.93543 .02894 L
.93849 .01923 L
Mfstroke
.4 g
.59748 .98077 m
.6018 .97106 L
.60198 .97064 L
.60606 .96134 L
.61032 .95163 L
.61169 .94847 L
.61452 .94192 L
.61873 .93221 L
.62141 .92599 L
.62289 .92249 L
.62704 .91278 L
.63112 .9032 L
.63117 .90307 L
.63525 .89336 L
.63934 .88364 L
.64083 .88009 L
.64338 .87393 L
.64742 .86422 L
.65054 .85668 L
.65143 .85451 L
.65541 .84479 L
.6594 .83508 L
.66026 .83297 L
.66332 .82537 L
.66726 .81566 L
.66997 .80896 L
.67116 .80594 L
.67505 .79623 L
.67894 .78652 L
.67968 .78465 L
.68277 .77681 L
.68662 .76709 L
.68939 .76005 L
.69043 .75738 L
.69422 .74767 L
.69802 .73796 L
.69911 .73517 L
.70177 .72824 L
.70553 .71853 L
.70882 .71 L
.70926 .70882 L
.71297 .69911 L
.71669 .68939 L
.71853 .68455 L
.72035 .67968 L
.72403 .66997 L
.72771 .66026 L
.72824 .65882 L
.73132 .65054 L
.73497 .64083 L
.73796 .63282 L
.73858 .63112 L
.74216 .62141 L
.74577 .61169 L
.74767 .60654 L
.74932 .60198 L
.75288 .59227 L
.75645 .58256 L
.75738 .58 L
.75995 .57284 L
.76349 .56313 L
.76701 .55342 L
.76709 .55319 L
.77047 .54371 L
.77398 .53399 L
.77681 .52611 L
.77744 .52428 L
.78089 .51457 L
.78436 .50486 L
.78652 .49877 L
.78777 .49514 L
.7912 .48543 L
.79464 .47572 L
.79623 .47117 L
.79801 .46601 L
.80141 .45629 L
.80481 .44658 L
.80594 .44332 L
.80814 .43687 L
.81152 .42716 L
.81489 .41744 L
.81566 .41521 L
.81818 .40773 L
.82153 .39802 L
.82487 .38831 L
.82537 .38684 L
.82814 .37859 L
.83146 .36888 L
.83477 .35917 L
.83508 .35823 L
.838 .34946 L
.8413 .33974 L
.84457 .33003 L
.84479 .32937 L
.84778 .32032 L
.85105 .31061 L
.8543 .30089 L
.85451 .30026 L
.85747 .29118 L
.86072 .28147 L
.86394 .27176 L
.86422 .27091 L
.86709 .26204 L
.87031 .25233 L
.87351 .24262 L
.87393 .24132 L
.87663 .23291 L
.87982 .22319 L
.883 .21348 L
.88364 .21149 L
.88609 .20377 L
.88926 .19406 L
.89242 .18434 L
.89336 .18141 L
.89549 .17463 L
.89862 .16492 L
.90176 .15521 L
.90307 .15111 L
.90481 .14549 L
.90792 .13578 L
.91104 .12607 L
.91278 .12056 L
.91407 .11636 L
.91714 .10664 L
.92024 .09693 L
.92249 .08979 L
.92327 .08722 L
.9263 .07751 L
.92938 .06779 L
.93221 .05879 L
.93242 .05808 L
.9354 .04837 L
.93845 .03866 L
.94149 .02894 L
.94192 .02755 L
.94443 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.59748 .98077 m
.6018 .97106 L
.60198 .97064 L
.60606 .96134 L
.61032 .95163 L
.61169 .94847 L
.61452 .94192 L
.61873 .93221 L
.62141 .92599 L
.62289 .92249 L
.62704 .91278 L
.63112 .9032 L
.63117 .90307 L
.63525 .89336 L
.63934 .88364 L
.64083 .88009 L
.64338 .87393 L
.64742 .86422 L
.65054 .85668 L
.65143 .85451 L
.65541 .84479 L
.6594 .83508 L
.66026 .83297 L
.66332 .82537 L
.66726 .81566 L
.66997 .80896 L
.67116 .80594 L
.67505 .79623 L
.67894 .78652 L
.67968 .78465 L
.68277 .77681 L
.68662 .76709 L
.68939 .76005 L
.69043 .75738 L
.69422 .74767 L
.69802 .73796 L
.69911 .73517 L
.70177 .72824 L
.70553 .71853 L
.70882 .71 L
.70926 .70882 L
.71297 .69911 L
.71669 .68939 L
.71853 .68455 L
.72035 .67968 L
.72403 .66997 L
.72771 .66026 L
.72824 .65882 L
.73132 .65054 L
.73497 .64083 L
Mistroke
.73796 .63282 L
.73858 .63112 L
.74216 .62141 L
.74577 .61169 L
.74767 .60654 L
.74932 .60198 L
.75288 .59227 L
.75645 .58256 L
.75738 .58 L
.75995 .57284 L
.76349 .56313 L
.76701 .55342 L
.76709 .55319 L
.77047 .54371 L
.77398 .53399 L
.77681 .52611 L
.77744 .52428 L
.78089 .51457 L
.78436 .50486 L
.78652 .49877 L
.78777 .49514 L
.7912 .48543 L
.79464 .47572 L
.79623 .47117 L
.79801 .46601 L
.80141 .45629 L
.80481 .44658 L
.80594 .44332 L
.80814 .43687 L
.81152 .42716 L
.81489 .41744 L
.81566 .41521 L
.81818 .40773 L
.82153 .39802 L
.82487 .38831 L
.82537 .38684 L
.82814 .37859 L
.83146 .36888 L
.83477 .35917 L
.83508 .35823 L
.838 .34946 L
.8413 .33974 L
.84457 .33003 L
.84479 .32937 L
.84778 .32032 L
.85105 .31061 L
.8543 .30089 L
.85451 .30026 L
.85747 .29118 L
.86072 .28147 L
Mistroke
.86394 .27176 L
.86422 .27091 L
.86709 .26204 L
.87031 .25233 L
.87351 .24262 L
.87393 .24132 L
.87663 .23291 L
.87982 .22319 L
.883 .21348 L
.88364 .21149 L
.88609 .20377 L
.88926 .19406 L
.89242 .18434 L
.89336 .18141 L
.89549 .17463 L
.89862 .16492 L
.90176 .15521 L
.90307 .15111 L
.90481 .14549 L
.90792 .13578 L
.91104 .12607 L
.91278 .12056 L
.91407 .11636 L
.91714 .10664 L
.92024 .09693 L
.92249 .08979 L
.92327 .08722 L
.9263 .07751 L
.92938 .06779 L
.93221 .05879 L
.93242 .05808 L
.9354 .04837 L
.93845 .03866 L
.94149 .02894 L
.94192 .02755 L
.94443 .01923 L
Mfstroke
.3 g
.60848 .98077 m
.61169 .97348 L
.61267 .97106 L
.61681 .96134 L
.62104 .95163 L
.62141 .95078 L
.62506 .94192 L
.62923 .93221 L
.63112 .92778 L
.63323 .92249 L
.63732 .91278 L
.64083 .90449 L
.64137 .90307 L
.64532 .89336 L
.6494 .88364 L
.65054 .88089 L
.65326 .87393 L
.65727 .86422 L
.66026 .857 L
.66119 .85451 L
.66506 .84479 L
.66905 .83508 L
.66997 .83281 L
.6728 .82537 L
.67672 .81566 L
.67968 .80834 L
.68055 .80594 L
.68433 .79623 L
.68822 .78652 L
.68939 .78358 L
.69189 .77681 L
.69572 .76709 L
.69911 .75854 L
.69951 .75738 L
.70315 .74767 L
.70697 .73796 L
.70882 .73322 L
.71058 .72824 L
.71429 .71853 L
.71807 .70882 L
.71853 .70763 L
.72158 .69911 L
.72531 .68939 L
.72824 .68175 L
.72894 .67968 L
.73249 .66997 L
.73619 .66026 L
.73796 .65561 L
.73968 .65054 L
.74328 .64083 L
.74695 .63112 L
.74767 .6292 L
.75035 .62141 L
.75396 .61169 L
.75738 .60252 L
.75755 .60198 L
.76092 .59227 L
.76452 .58256 L
.76709 .57558 L
.76796 .57284 L
.77139 .56313 L
.77496 .55342 L
.77681 .54838 L
.77831 .54371 L
.78176 .53399 L
.7853 .52428 L
.78652 .52092 L
.78857 .51457 L
.79203 .50486 L
.79554 .49514 L
.79623 .4932 L
.79874 .48543 L
.80219 .47572 L
.80567 .46601 L
.80594 .46523 L
.80883 .45629 L
.81226 .44658 L
.81566 .43701 L
.8157 .43687 L
.81882 .42716 L
.82224 .41744 L
.82537 .40854 L
.8256 .40773 L
.82873 .39802 L
.83212 .38831 L
.83508 .37982 L
.83542 .37859 L
.83855 .36888 L
.84192 .35917 L
.84479 .35085 L
.84518 .34946 L
.84828 .33974 L
.85163 .33003 L
.85451 .32164 L
.85487 .32032 L
.85793 .31061 L
.86126 .30089 L
.86422 .29219 L
.86449 .29118 L
.86751 .28147 L
.8708 .27176 L
.87393 .2625 L
.87405 .26204 L
.877 .25233 L
.88027 .24262 L
.88353 .23291 L
.88364 .23257 L
.88642 .22319 L
.88966 .21348 L
.89291 .20377 L
.89336 .20241 L
.89578 .19406 L
.89898 .18434 L
.90221 .17463 L
.90307 .17201 L
.90507 .16492 L
.90822 .15521 L
.91144 .14549 L
.91278 .14137 L
.9143 .13578 L
.9174 .12607 L
.9206 .11636 L
.92249 .11051 L
.9235 .10664 L
.92651 .09693 L
.92968 .08722 L
.93221 .07942 L
.93267 .07751 L
.93555 .06779 L
.9387 .05808 L
.94184 .04837 L
.94192 .04811 L
.94455 .03866 L
.94766 .02894 L
.95078 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.60848 .98077 m
.61169 .97348 L
.61267 .97106 L
.61681 .96134 L
.62104 .95163 L
.62141 .95078 L
.62506 .94192 L
.62923 .93221 L
.63112 .92778 L
.63323 .92249 L
.63732 .91278 L
.64083 .90449 L
.64137 .90307 L
.64532 .89336 L
.6494 .88364 L
.65054 .88089 L
.65326 .87393 L
.65727 .86422 L
.66026 .857 L
.66119 .85451 L
.66506 .84479 L
.66905 .83508 L
.66997 .83281 L
.6728 .82537 L
.67672 .81566 L
.67968 .80834 L
.68055 .80594 L
.68433 .79623 L
.68822 .78652 L
.68939 .78358 L
.69189 .77681 L
.69572 .76709 L
.69911 .75854 L
.69951 .75738 L
.70315 .74767 L
.70697 .73796 L
.70882 .73322 L
.71058 .72824 L
.71429 .71853 L
.71807 .70882 L
.71853 .70763 L
.72158 .69911 L
.72531 .68939 L
.72824 .68175 L
.72894 .67968 L
.73249 .66997 L
.73619 .66026 L
.73796 .65561 L
.73968 .65054 L
.74328 .64083 L
Mistroke
.74695 .63112 L
.74767 .6292 L
.75035 .62141 L
.75396 .61169 L
.75738 .60252 L
.75755 .60198 L
.76092 .59227 L
.76452 .58256 L
.76709 .57558 L
.76796 .57284 L
.77139 .56313 L
.77496 .55342 L
.77681 .54838 L
.77831 .54371 L
.78176 .53399 L
.7853 .52428 L
.78652 .52092 L
.78857 .51457 L
.79203 .50486 L
.79554 .49514 L
.79623 .4932 L
.79874 .48543 L
.80219 .47572 L
.80567 .46601 L
.80594 .46523 L
.80883 .45629 L
.81226 .44658 L
.81566 .43701 L
.8157 .43687 L
.81882 .42716 L
.82224 .41744 L
.82537 .40854 L
.8256 .40773 L
.82873 .39802 L
.83212 .38831 L
.83508 .37982 L
.83542 .37859 L
.83855 .36888 L
.84192 .35917 L
.84479 .35085 L
.84518 .34946 L
.84828 .33974 L
.85163 .33003 L
.85451 .32164 L
.85487 .32032 L
.85793 .31061 L
.86126 .30089 L
.86422 .29219 L
.86449 .29118 L
.86751 .28147 L
Mistroke
.8708 .27176 L
.87393 .2625 L
.87405 .26204 L
.877 .25233 L
.88027 .24262 L
.88353 .23291 L
.88364 .23257 L
.88642 .22319 L
.88966 .21348 L
.89291 .20377 L
.89336 .20241 L
.89578 .19406 L
.89898 .18434 L
.90221 .17463 L
.90307 .17201 L
.90507 .16492 L
.90822 .15521 L
.91144 .14549 L
.91278 .14137 L
.9143 .13578 L
.9174 .12607 L
.9206 .11636 L
.92249 .11051 L
.9235 .10664 L
.92651 .09693 L
.92968 .08722 L
.93221 .07942 L
.93267 .07751 L
.93555 .06779 L
.9387 .05808 L
.94184 .04837 L
.94192 .04811 L
.94455 .03866 L
.94766 .02894 L
.95078 .01923 L
Mfstroke
.2 g
.62337 .98077 m
.62572 .97106 L
.63112 .96185 L
.63134 .96134 L
.63533 .95163 L
.63885 .94192 L
.64083 .93795 L
.6432 .93221 L
.64584 .92249 L
.65054 .91387 L
.65101 .91278 L
.6549 .90307 L
.65838 .89336 L
.66026 .88948 L
.66261 .88364 L
.66519 .87393 L
.66997 .86487 L
.67024 .86422 L
.67406 .85451 L
.67736 .84479 L
.67968 .83993 L
.6816 .83508 L
.68386 .82537 L
.68902 .81566 L
.68939 .81482 L
.69282 .80594 L
.69581 .79623 L
.69911 .78934 L
.70021 .78652 L
.70183 .77681 L
.70728 .76709 L
.70882 .76367 L
.71122 .75738 L
.71366 .74767 L
.71845 .73796 L
.71853 .73777 L
.72209 .72824 L
.72501 .71853 L
.72824 .71151 L
.72927 .70882 L
.73074 .69911 L
.73606 .68939 L
.73796 .68506 L
.73995 .67968 L
.74205 .66997 L
.74687 .66026 L
.74767 .65837 L
.75052 .65054 L
.75303 .64083 L
.75738 .63142 L
.75749 .63112 L
.76099 .62141 L
.76376 .61169 L
.76709 .60416 L
.76789 .60198 L
.77135 .59227 L
.77429 .58256 L
.77681 .57669 L
.77819 .57284 L
.77973 .56313 L
.78467 .55342 L
.78652 .54897 L
.78838 .54371 L
.79021 .53399 L
.7949 .52428 L
.79623 .52102 L
.79849 .51457 L
.80049 .50486 L
.80501 .49514 L
.80594 .49282 L
.8085 .48543 L
.81062 .47572 L
.81501 .46601 L
.81566 .46437 L
.81842 .45629 L
.82061 .44658 L
.82491 .43687 L
.82537 .43568 L
.82826 .42716 L
.83047 .41744 L
.8347 .40773 L
.83508 .40675 L
.83802 .39802 L
.84021 .38831 L
.8444 .37859 L
.84479 .37757 L
.8477 .36888 L
.84983 .35917 L
.85401 .34946 L
.85451 .34816 L
.8573 .33974 L
.85933 .33003 L
.86353 .32032 L
.86422 .31851 L
.86682 .31061 L
.86872 .30089 L
.87296 .29118 L
.87393 .28862 L
.87627 .28147 L
.87799 .27176 L
.8823 .26204 L
.88364 .2585 L
.88565 .25233 L
.88712 .24262 L
.89155 .23291 L
.89336 .22816 L
.89496 .22319 L
.89611 .21348 L
.9007 .20377 L
.90307 .19758 L
.90421 .19406 L
.90729 .18434 L
.90974 .17463 L
.91278 .16679 L
.91338 .16492 L
.91645 .15521 L
.91866 .14549 L
.92249 .13579 L
.9225 .13578 L
.92555 .12607 L
.92744 .11636 L
.93144 .10664 L
.93221 .10452 L
.93458 .09693 L
.93606 .08722 L
.94028 .07751 L
.94192 .07304 L
.94356 .06779 L
.94447 .05808 L
.949 .04837 L
.95163 .04134 L
.95247 .03866 L
.95545 .02894 L
.95758 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.62337 .98077 m
.62572 .97106 L
.63112 .96185 L
.63134 .96134 L
.63533 .95163 L
.63885 .94192 L
.64083 .93795 L
.6432 .93221 L
.64584 .92249 L
.65054 .91387 L
.65101 .91278 L
.6549 .90307 L
.65838 .89336 L
.66026 .88948 L
.66261 .88364 L
.66519 .87393 L
.66997 .86487 L
.67024 .86422 L
.67406 .85451 L
.67736 .84479 L
.67968 .83993 L
.6816 .83508 L
.68386 .82537 L
.68902 .81566 L
.68939 .81482 L
.69282 .80594 L
.69581 .79623 L
.69911 .78934 L
.70021 .78652 L
.70183 .77681 L
.70728 .76709 L
.70882 .76367 L
.71122 .75738 L
.71366 .74767 L
.71845 .73796 L
.71853 .73777 L
.72209 .72824 L
.72501 .71853 L
.72824 .71151 L
.72927 .70882 L
.73074 .69911 L
.73606 .68939 L
.73796 .68506 L
.73995 .67968 L
.74205 .66997 L
.74687 .66026 L
.74767 .65837 L
.75052 .65054 L
.75303 .64083 L
.75738 .63142 L
Mistroke
.75749 .63112 L
.76099 .62141 L
.76376 .61169 L
.76709 .60416 L
.76789 .60198 L
.77135 .59227 L
.77429 .58256 L
.77681 .57669 L
.77819 .57284 L
.77973 .56313 L
.78467 .55342 L
.78652 .54897 L
.78838 .54371 L
.79021 .53399 L
.7949 .52428 L
.79623 .52102 L
.79849 .51457 L
.80049 .50486 L
.80501 .49514 L
.80594 .49282 L
.8085 .48543 L
.81062 .47572 L
.81501 .46601 L
.81566 .46437 L
.81842 .45629 L
.82061 .44658 L
.82491 .43687 L
.82537 .43568 L
.82826 .42716 L
.83047 .41744 L
.8347 .40773 L
.83508 .40675 L
.83802 .39802 L
.84021 .38831 L
.8444 .37859 L
.84479 .37757 L
.8477 .36888 L
.84983 .35917 L
.85401 .34946 L
.85451 .34816 L
.8573 .33974 L
.85933 .33003 L
.86353 .32032 L
.86422 .31851 L
.86682 .31061 L
.86872 .30089 L
.87296 .29118 L
.87393 .28862 L
.87627 .28147 L
.87799 .27176 L
Mistroke
.8823 .26204 L
.88364 .2585 L
.88565 .25233 L
.88712 .24262 L
.89155 .23291 L
.89336 .22816 L
.89496 .22319 L
.89611 .21348 L
.9007 .20377 L
.90307 .19758 L
.90421 .19406 L
.90729 .18434 L
.90974 .17463 L
.91278 .16679 L
.91338 .16492 L
.91645 .15521 L
.91866 .14549 L
.92249 .13579 L
.9225 .13578 L
.92555 .12607 L
.92744 .11636 L
.93144 .10664 L
.93221 .10452 L
.93458 .09693 L
.93606 .08722 L
.94028 .07751 L
.94192 .07304 L
.94356 .06779 L
.94447 .05808 L
.949 .04837 L
.95163 .04134 L
.95247 .03866 L
.95545 .02894 L
.95758 .01923 L
Mfstroke
.3 g
.98077 .03787 m
.98054 .03866 L
.97764 .04837 L
.97466 .05808 L
.97165 .06779 L
.97106 .06972 L
.96864 .07751 L
.96736 .08722 L
.96299 .09693 L
.96134 .10135 L
.95968 .10664 L
.95667 .11636 L
.95421 .12607 L
.95163 .13275 L
.95067 .13578 L
.94762 .14549 L
.94539 .15521 L
.94192 .16389 L
.94159 .16492 L
.93852 .17463 L
.93652 .18434 L
.93248 .19406 L
.93221 .1948 L
.92935 .20377 L
.92761 .21348 L
.92336 .22319 L
.92249 .2255 L
.92011 .23291 L
.91863 .24262 L
.91418 .25233 L
.91278 .25596 L
.9108 .26204 L
.90957 .27176 L
.90491 .28147 L
.90307 .28617 L
.90142 .29118 L
.90041 .30089 L
.89557 .31061 L
.89336 .31613 L
.89197 .32032 L
.88878 .33003 L
.88613 .33974 L
.88364 .34585 L
.88244 .34946 L
.87922 .35917 L
.87659 .36888 L
.87393 .37533 L
.87283 .37859 L
.86959 .38831 L
.86694 .39802 L
.86422 .40455 L
.86313 .40773 L
.85986 .41744 L
.85718 .42716 L
.85451 .43352 L
.85335 .43687 L
.85006 .44658 L
.8473 .45629 L
.84479 .46224 L
.84349 .46601 L
.84016 .47572 L
.83731 .48543 L
.83508 .4907 L
.83353 .49514 L
.83226 .50486 L
.82719 .51457 L
.82537 .5189 L
.82347 .52428 L
.8219 .53399 L
.81697 .54371 L
.81566 .54683 L
.81332 .55342 L
.8114 .56313 L
.80663 .57284 L
.80594 .57449 L
.80306 .58256 L
.80078 .59227 L
.79623 .60188 L
.79619 .60198 L
.7927 .61169 L
.79006 .62141 L
.78652 .62905 L
.78575 .63112 L
.78223 .64083 L
.77924 .65054 L
.77681 .65591 L
.77519 .66026 L
.77362 .66997 L
.76833 .67968 L
.76709 .68248 L
.76452 .68939 L
.76223 .69911 L
.75738 .70875 L
.75735 .70882 L
.75371 .71853 L
.75083 .72824 L
.74767 .73481 L
.74646 .73796 L
.74278 .74767 L
.73941 .75738 L
.73796 .76052 L
.73542 .76709 L
.73303 .77681 L
.72824 .78593 L
.72801 .78652 L
.72424 .79623 L
.72108 .80594 L
.71853 .81111 L
.71672 .81566 L
.71477 .82537 L
.7092 .83508 L
.70882 .83589 L
.70528 .84479 L
.70221 .85451 L
.69911 .86047 L
.69757 .86422 L
.69367 .87393 L
.68987 .88364 L
.68939 .88463 L
.68583 .89336 L
.68264 .90307 L
.67968 .90859 L
.67792 .91278 L
.67391 .92249 L
.66997 .93208 L
.66991 .93221 L
.66585 .94192 L
.66229 .95163 L
.66026 .95539 L
.6577 .96134 L
.65497 .97106 L
.65054 .97712 L
.64944 .98077 L
.98077 .98077 L
F
0 g
.98077 .03787 m
.98054 .03866 L
.97764 .04837 L
.97466 .05808 L
.97165 .06779 L
.97106 .06972 L
.96864 .07751 L
.96736 .08722 L
.96299 .09693 L
.96134 .10135 L
.95968 .10664 L
.95667 .11636 L
.95421 .12607 L
.95163 .13275 L
.95067 .13578 L
.94762 .14549 L
.94539 .15521 L
.94192 .16389 L
.94159 .16492 L
.93852 .17463 L
.93652 .18434 L
.93248 .19406 L
.93221 .1948 L
.92935 .20377 L
.92761 .21348 L
.92336 .22319 L
.92249 .2255 L
.92011 .23291 L
.91863 .24262 L
.91418 .25233 L
.91278 .25596 L
.9108 .26204 L
.90957 .27176 L
.90491 .28147 L
.90307 .28617 L
.90142 .29118 L
.90041 .30089 L
.89557 .31061 L
.89336 .31613 L
.89197 .32032 L
.88878 .33003 L
.88613 .33974 L
.88364 .34585 L
.88244 .34946 L
.87922 .35917 L
.87659 .36888 L
.87393 .37533 L
.87283 .37859 L
.86959 .38831 L
.86694 .39802 L
Mistroke
.86422 .40455 L
.86313 .40773 L
.85986 .41744 L
.85718 .42716 L
.85451 .43352 L
.85335 .43687 L
.85006 .44658 L
.8473 .45629 L
.84479 .46224 L
.84349 .46601 L
.84016 .47572 L
.83731 .48543 L
.83508 .4907 L
.83353 .49514 L
.83226 .50486 L
.82719 .51457 L
.82537 .5189 L
.82347 .52428 L
.8219 .53399 L
.81697 .54371 L
.81566 .54683 L
.81332 .55342 L
.8114 .56313 L
.80663 .57284 L
.80594 .57449 L
.80306 .58256 L
.80078 .59227 L
.79623 .60188 L
.79619 .60198 L
.7927 .61169 L
.79006 .62141 L
.78652 .62905 L
.78575 .63112 L
.78223 .64083 L
.77924 .65054 L
.77681 .65591 L
.77519 .66026 L
.77362 .66997 L
.76833 .67968 L
.76709 .68248 L
.76452 .68939 L
.76223 .69911 L
.75738 .70875 L
.75735 .70882 L
.75371 .71853 L
.75083 .72824 L
.74767 .73481 L
.74646 .73796 L
.74278 .74767 L
.73941 .75738 L
Mistroke
.73796 .76052 L
.73542 .76709 L
.73303 .77681 L
.72824 .78593 L
.72801 .78652 L
.72424 .79623 L
.72108 .80594 L
.71853 .81111 L
.71672 .81566 L
.71477 .82537 L
.7092 .83508 L
.70882 .83589 L
.70528 .84479 L
.70221 .85451 L
.69911 .86047 L
.69757 .86422 L
.69367 .87393 L
.68987 .88364 L
.68939 .88463 L
.68583 .89336 L
.68264 .90307 L
.67968 .90859 L
.67792 .91278 L
.67391 .92249 L
.66997 .93208 L
.66991 .93221 L
.66585 .94192 L
.66229 .95163 L
.66026 .95539 L
.6577 .96134 L
.65497 .97106 L
.65054 .97712 L
.64944 .98077 L
Mfstroke
.4 g
.98077 .06224 m
.97912 .06779 L
.97618 .07751 L
.9716 .08722 L
.97106 .09423 L
.97043 .09693 L
.96758 .10664 L
.96444 .11636 L
.96134 .12599 L
.96133 .12607 L
.95866 .13578 L
.95553 .14549 L
.95238 .15521 L
.95163 .15753 L
.94966 .16492 L
.94656 .17463 L
.94337 .18434 L
.94192 .18884 L
.94057 .19406 L
.93752 .20377 L
.93431 .21348 L
.93221 .21992 L
.93139 .22319 L
.9284 .23291 L
.92518 .24262 L
.92249 .25076 L
.92212 .25233 L
.91921 .26204 L
.91598 .27176 L
.91278 .28137 L
.91276 .28147 L
.90995 .29118 L
.90671 .30089 L
.90345 .31061 L
.90307 .31174 L
.9006 .32032 L
.89736 .33003 L
.89407 .33974 L
.89336 .34188 L
.89118 .34946 L
.88794 .35917 L
.88462 .36888 L
.88364 .37178 L
.88169 .37859 L
.87844 .38831 L
.8751 .39802 L
.87393 .40144 L
.87212 .40773 L
.86885 .41744 L
.86549 .42716 L
.86422 .43085 L
.86247 .43687 L
.85919 .44658 L
.85579 .45629 L
.85451 .46002 L
.85274 .46601 L
.84943 .47572 L
.84602 .48543 L
.84479 .48893 L
.84294 .49514 L
.83959 .50486 L
.83615 .51457 L
.83508 .5176 L
.83305 .52428 L
.82966 .53399 L
.82619 .54371 L
.82537 .54602 L
.82306 .55342 L
.81963 .56313 L
.81613 .57284 L
.81566 .57418 L
.81299 .58256 L
.8095 .59227 L
.80598 .60198 L
.80594 .60208 L
.80281 .61169 L
.79927 .62141 L
.79623 .62972 L
.79582 .63112 L
.79252 .64083 L
.78894 .65054 L
.78652 .65711 L
.78555 .66026 L
.78211 .66997 L
.77849 .67968 L
.77681 .68422 L
.77514 .68939 L
.77159 .69911 L
.76794 .70882 L
.76709 .71107 L
.76459 .71853 L
.76095 .72824 L
.75738 .73765 L
.75729 .73796 L
.75389 .74767 L
.75019 .75738 L
.74767 .76396 L
.74664 .76709 L
.74306 .77681 L
.73929 .78652 L
.73796 .78998 L
.7358 .79623 L
.73207 .80594 L
.72827 .81566 L
.72824 .81573 L
.72477 .82537 L
.72095 .83508 L
.71853 .8412 L
.71729 .84479 L
.71356 .85451 L
.70968 .86422 L
.70882 .86638 L
.70607 .87393 L
.70219 .88364 L
.69911 .89127 L
.69838 .89336 L
.69462 .90307 L
.69065 .91278 L
.68939 .91587 L
.68693 .92249 L
.68298 .93221 L
.67968 .94017 L
.67905 .94192 L
.67521 .95163 L
.67115 .96134 L
.66997 .96417 L
.66732 .97106 L
.66326 .98077 L
.98077 .98077 L
F
0 g
.98077 .06224 m
.97912 .06779 L
.97618 .07751 L
.9716 .08722 L
.97106 .09423 L
.97043 .09693 L
.96758 .10664 L
.96444 .11636 L
.96134 .12599 L
.96133 .12607 L
.95866 .13578 L
.95553 .14549 L
.95238 .15521 L
.95163 .15753 L
.94966 .16492 L
.94656 .17463 L
.94337 .18434 L
.94192 .18884 L
.94057 .19406 L
.93752 .20377 L
.93431 .21348 L
.93221 .21992 L
.93139 .22319 L
.9284 .23291 L
.92518 .24262 L
.92249 .25076 L
.92212 .25233 L
.91921 .26204 L
.91598 .27176 L
.91278 .28137 L
.91276 .28147 L
.90995 .29118 L
.90671 .30089 L
.90345 .31061 L
.90307 .31174 L
.9006 .32032 L
.89736 .33003 L
.89407 .33974 L
.89336 .34188 L
.89118 .34946 L
.88794 .35917 L
.88462 .36888 L
.88364 .37178 L
.88169 .37859 L
.87844 .38831 L
.8751 .39802 L
.87393 .40144 L
.87212 .40773 L
.86885 .41744 L
.86549 .42716 L
Mistroke
.86422 .43085 L
.86247 .43687 L
.85919 .44658 L
.85579 .45629 L
.85451 .46002 L
.85274 .46601 L
.84943 .47572 L
.84602 .48543 L
.84479 .48893 L
.84294 .49514 L
.83959 .50486 L
.83615 .51457 L
.83508 .5176 L
.83305 .52428 L
.82966 .53399 L
.82619 .54371 L
.82537 .54602 L
.82306 .55342 L
.81963 .56313 L
.81613 .57284 L
.81566 .57418 L
.81299 .58256 L
.8095 .59227 L
.80598 .60198 L
.80594 .60208 L
.80281 .61169 L
.79927 .62141 L
.79623 .62972 L
.79582 .63112 L
.79252 .64083 L
.78894 .65054 L
.78652 .65711 L
.78555 .66026 L
.78211 .66997 L
.77849 .67968 L
.77681 .68422 L
.77514 .68939 L
.77159 .69911 L
.76794 .70882 L
.76709 .71107 L
.76459 .71853 L
.76095 .72824 L
.75738 .73765 L
.75729 .73796 L
.75389 .74767 L
.75019 .75738 L
.74767 .76396 L
.74664 .76709 L
.74306 .77681 L
.73929 .78652 L
Mistroke
.73796 .78998 L
.7358 .79623 L
.73207 .80594 L
.72827 .81566 L
.72824 .81573 L
.72477 .82537 L
.72095 .83508 L
.71853 .8412 L
.71729 .84479 L
.71356 .85451 L
.70968 .86422 L
.70882 .86638 L
.70607 .87393 L
.70219 .88364 L
.69911 .89127 L
.69838 .89336 L
.69462 .90307 L
.69065 .91278 L
.68939 .91587 L
.68693 .92249 L
.68298 .93221 L
.67968 .94017 L
.67905 .94192 L
.67521 .95163 L
.67115 .96134 L
.66997 .96417 L
.66732 .97106 L
.66326 .98077 L
Mfstroke
.5 g
.98077 .08247 m
.97703 .08722 L
.9752 .09693 L
.97317 .10664 L
.97106 .11453 L
.97053 .11636 L
.96762 .12607 L
.96461 .13578 L
.96161 .14549 L
.96134 .14638 L
.95871 .15521 L
.9557 .16492 L
.95267 .17463 L
.95163 .178 L
.94974 .18434 L
.94672 .19406 L
.94367 .20377 L
.94192 .20939 L
.9407 .21348 L
.93768 .22319 L
.93461 .23291 L
.93221 .24055 L
.93159 .24262 L
.92858 .25233 L
.92549 .26204 L
.92249 .27148 L
.92241 .27176 L
.91941 .28147 L
.9163 .29118 L
.91319 .30089 L
.91278 .30218 L
.91017 .31061 L
.90704 .32032 L
.90391 .33003 L
.90307 .33265 L
.90086 .33974 L
.89772 .34946 L
.89455 .35917 L
.89336 .36287 L
.89147 .36888 L
.88832 .37859 L
.88513 .38831 L
.88364 .39287 L
.88202 .39802 L
.87885 .40773 L
.87563 .41744 L
.87393 .42262 L
.87249 .42716 L
.8693 .43687 L
.86606 .44658 L
.86422 .45213 L
.86288 .45629 L
.85967 .46601 L
.85641 .47572 L
.85451 .48139 L
.8532 .48543 L
.84996 .49514 L
.84667 .50486 L
.84479 .51041 L
.84344 .51457 L
.84017 .52428 L
.83685 .53399 L
.83508 .53919 L
.83359 .54371 L
.83029 .55342 L
.82694 .56313 L
.82537 .56771 L
.82366 .57284 L
.82032 .58256 L
.81694 .59227 L
.81566 .59598 L
.81363 .60198 L
.81025 .61169 L
.80685 .62141 L
.80594 .624 L
.80351 .63112 L
.80009 .64083 L
.79666 .65054 L
.79623 .65175 L
.79329 .66026 L
.78983 .66997 L
.78652 .67925 L
.78637 .67968 L
.78296 .68939 L
.77946 .69911 L
.77681 .70649 L
.776 .70882 L
.77252 .71853 L
.76899 .72824 L
.76709 .73346 L
.7655 .73796 L
.76197 .74767 L
.7584 .75738 L
.75738 .76017 L
.75489 .76709 L
.75131 .77681 L
.7477 .78652 L
.74767 .78661 L
.74415 .79623 L
.74051 .80594 L
.73796 .81277 L
.7369 .81566 L
.73328 .82537 L
.7296 .83508 L
.72824 .83866 L
.72596 .84479 L
.72227 .85451 L
.71855 .86422 L
.71853 .86427 L
.71488 .87393 L
.71112 .88364 L
.70882 .8896 L
.7074 .89336 L
.70364 .90307 L
.69983 .91278 L
.69911 .91464 L
.69607 .92249 L
.69224 .93221 L
.68939 .9394 L
.68842 .94192 L
.68458 .95163 L
.68069 .96134 L
.67968 .96386 L
.67683 .97106 L
.67291 .98077 L
.98077 .98077 L
F
0 g
.98077 .08247 m
.97703 .08722 L
.9752 .09693 L
.97317 .10664 L
.97106 .11453 L
.97053 .11636 L
.96762 .12607 L
.96461 .13578 L
.96161 .14549 L
.96134 .14638 L
.95871 .15521 L
.9557 .16492 L
.95267 .17463 L
.95163 .178 L
.94974 .18434 L
.94672 .19406 L
.94367 .20377 L
.94192 .20939 L
.9407 .21348 L
.93768 .22319 L
.93461 .23291 L
.93221 .24055 L
.93159 .24262 L
.92858 .25233 L
.92549 .26204 L
.92249 .27148 L
.92241 .27176 L
.91941 .28147 L
.9163 .29118 L
.91319 .30089 L
.91278 .30218 L
.91017 .31061 L
.90704 .32032 L
.90391 .33003 L
.90307 .33265 L
.90086 .33974 L
.89772 .34946 L
.89455 .35917 L
.89336 .36287 L
.89147 .36888 L
.88832 .37859 L
.88513 .38831 L
.88364 .39287 L
.88202 .39802 L
.87885 .40773 L
.87563 .41744 L
.87393 .42262 L
.87249 .42716 L
.8693 .43687 L
.86606 .44658 L
Mistroke
.86422 .45213 L
.86288 .45629 L
.85967 .46601 L
.85641 .47572 L
.85451 .48139 L
.8532 .48543 L
.84996 .49514 L
.84667 .50486 L
.84479 .51041 L
.84344 .51457 L
.84017 .52428 L
.83685 .53399 L
.83508 .53919 L
.83359 .54371 L
.83029 .55342 L
.82694 .56313 L
.82537 .56771 L
.82366 .57284 L
.82032 .58256 L
.81694 .59227 L
.81566 .59598 L
.81363 .60198 L
.81025 .61169 L
.80685 .62141 L
.80594 .624 L
.80351 .63112 L
.80009 .64083 L
.79666 .65054 L
.79623 .65175 L
.79329 .66026 L
.78983 .66997 L
.78652 .67925 L
.78637 .67968 L
.78296 .68939 L
.77946 .69911 L
.77681 .70649 L
.776 .70882 L
.77252 .71853 L
.76899 .72824 L
.76709 .73346 L
.7655 .73796 L
.76197 .74767 L
.7584 .75738 L
.75738 .76017 L
.75489 .76709 L
.75131 .77681 L
.7477 .78652 L
.74767 .78661 L
.74415 .79623 L
.74051 .80594 L
Mistroke
.73796 .81277 L
.7369 .81566 L
.73328 .82537 L
.7296 .83508 L
.72824 .83866 L
.72596 .84479 L
.72227 .85451 L
.71855 .86422 L
.71853 .86427 L
.71488 .87393 L
.71112 .88364 L
.70882 .8896 L
.7074 .89336 L
.70364 .90307 L
.69983 .91278 L
.69911 .91464 L
.69607 .92249 L
.69224 .93221 L
.68939 .9394 L
.68842 .94192 L
.68458 .95163 L
.68069 .96134 L
.67968 .96386 L
.67683 .97106 L
.67291 .98077 L
Mfstroke
.6 g
.98077 .10174 m
.97896 .10664 L
.97614 .11636 L
.97337 .12607 L
.97106 .13387 L
.97048 .13578 L
.96751 .14549 L
.96451 .15521 L
.9616 .16492 L
.96134 .16578 L
.95863 .17463 L
.95561 .18434 L
.95264 .19406 L
.95163 .19747 L
.94969 .20377 L
.94666 .21348 L
.94364 .22319 L
.94192 .22893 L
.94069 .23291 L
.93764 .24262 L
.93459 .25233 L
.93221 .26017 L
.93162 .26204 L
.92856 .27176 L
.92549 .28147 L
.92249 .29118 L
.92249 .29118 L
.91942 .30089 L
.91632 .31061 L
.91328 .32032 L
.91278 .32195 L
.91021 .33003 L
.90709 .33974 L
.904 .34946 L
.90307 .35249 L
.90093 .35917 L
.89779 .36888 L
.89467 .37859 L
.89336 .3828 L
.89158 .38831 L
.88841 .39802 L
.88527 .40773 L
.88364 .41287 L
.88216 .41744 L
.87897 .42716 L
.87579 .43687 L
.87393 .4427 L
.87266 .44658 L
.86945 .45629 L
.86625 .46601 L
.86422 .4723 L
.86309 .47572 L
.85986 .48543 L
.85662 .49514 L
.85451 .50165 L
.85344 .50486 L
.85018 .51457 L
.84692 .52428 L
.84479 .53075 L
.84371 .53399 L
.84042 .54371 L
.83713 .55342 L
.83508 .55961 L
.83389 .56313 L
.83057 .57284 L
.82726 .58256 L
.82537 .58823 L
.82399 .59227 L
.82064 .60198 L
.8173 .61169 L
.81566 .61659 L
.814 .62141 L
.81062 .63112 L
.80726 .64083 L
.80594 .6447 L
.80391 .65054 L
.8005 .66026 L
.79712 .66997 L
.79623 .67256 L
.79373 .67968 L
.79028 .68939 L
.78688 .69911 L
.78652 .70015 L
.78344 .70882 L
.77997 .71853 L
.77681 .72749 L
.77654 .72824 L
.77305 .73796 L
.76955 .74767 L
.76709 .75457 L
.76608 .75738 L
.76255 .76709 L
.75902 .77681 L
.75738 .78138 L
.75551 .78652 L
.75193 .79623 L
.74838 .80594 L
.74767 .80793 L
.74481 .81566 L
.7412 .82537 L
.73796 .83421 L
.73763 .83508 L
.734 .84479 L
.73036 .85451 L
.72824 .86021 L
.72674 .86422 L
.72305 .87393 L
.71939 .88364 L
.71853 .88594 L
.7157 .89336 L
.71198 .90307 L
.70882 .91139 L
.70828 .91278 L
.70453 .92249 L
.70077 .93221 L
.69911 .93655 L
.69702 .94192 L
.69321 .95163 L
.68943 .96134 L
.68939 .96144 L
.6856 .97106 L
.68175 .98077 L
.98077 .98077 L
F
0 g
.98077 .10174 m
.97896 .10664 L
.97614 .11636 L
.97337 .12607 L
.97106 .13387 L
.97048 .13578 L
.96751 .14549 L
.96451 .15521 L
.9616 .16492 L
.96134 .16578 L
.95863 .17463 L
.95561 .18434 L
.95264 .19406 L
.95163 .19747 L
.94969 .20377 L
.94666 .21348 L
.94364 .22319 L
.94192 .22893 L
.94069 .23291 L
.93764 .24262 L
.93459 .25233 L
.93221 .26017 L
.93162 .26204 L
.92856 .27176 L
.92549 .28147 L
.92249 .29118 L
.92249 .29118 L
.91942 .30089 L
.91632 .31061 L
.91328 .32032 L
.91278 .32195 L
.91021 .33003 L
.90709 .33974 L
.904 .34946 L
.90307 .35249 L
.90093 .35917 L
.89779 .36888 L
.89467 .37859 L
.89336 .3828 L
.89158 .38831 L
.88841 .39802 L
.88527 .40773 L
.88364 .41287 L
.88216 .41744 L
.87897 .42716 L
.87579 .43687 L
.87393 .4427 L
.87266 .44658 L
.86945 .45629 L
.86625 .46601 L
Mistroke
.86422 .4723 L
.86309 .47572 L
.85986 .48543 L
.85662 .49514 L
.85451 .50165 L
.85344 .50486 L
.85018 .51457 L
.84692 .52428 L
.84479 .53075 L
.84371 .53399 L
.84042 .54371 L
.83713 .55342 L
.83508 .55961 L
.83389 .56313 L
.83057 .57284 L
.82726 .58256 L
.82537 .58823 L
.82399 .59227 L
.82064 .60198 L
.8173 .61169 L
.81566 .61659 L
.814 .62141 L
.81062 .63112 L
.80726 .64083 L
.80594 .6447 L
.80391 .65054 L
.8005 .66026 L
.79712 .66997 L
.79623 .67256 L
.79373 .67968 L
.79028 .68939 L
.78688 .69911 L
.78652 .70015 L
.78344 .70882 L
.77997 .71853 L
.77681 .72749 L
.77654 .72824 L
.77305 .73796 L
.76955 .74767 L
.76709 .75457 L
.76608 .75738 L
.76255 .76709 L
.75902 .77681 L
.75738 .78138 L
.75551 .78652 L
.75193 .79623 L
.74838 .80594 L
.74767 .80793 L
.74481 .81566 L
.7412 .82537 L
Mistroke
.73796 .83421 L
.73763 .83508 L
.734 .84479 L
.73036 .85451 L
.72824 .86021 L
.72674 .86422 L
.72305 .87393 L
.71939 .88364 L
.71853 .88594 L
.7157 .89336 L
.71198 .90307 L
.70882 .91139 L
.70828 .91278 L
.70453 .92249 L
.70077 .93221 L
.69911 .93655 L
.69702 .94192 L
.69321 .95163 L
.68943 .96134 L
.68939 .96144 L
.6856 .97106 L
.68175 .98077 L
Mfstroke
.7 g
.98077 .12196 m
.9795 .12607 L
.97662 .13578 L
.97373 .14549 L
.97106 .15418 L
.97074 .15521 L
.96766 .16492 L
.96457 .17463 L
.96177 .18434 L
.96134 .18617 L
.95884 .19406 L
.95572 .20377 L
.95276 .21348 L
.95163 .21794 L
.94996 .22319 L
.94682 .23291 L
.94376 .24262 L
.94192 .24949 L
.94101 .25233 L
.93786 .26204 L
.93474 .27176 L
.93221 .28081 L
.932 .28147 L
.92884 .29118 L
.92567 .30089 L
.92281 .31061 L
.92249 .3119 L
.91975 .32032 L
.91655 .33003 L
.91356 .33974 L
.91278 .34276 L
.91059 .34946 L
.90737 .35917 L
.90429 .36888 L
.90307 .37339 L
.90136 .37859 L
.89812 .38831 L
.89497 .39802 L
.89336 .40379 L
.89205 .40773 L
.88879 .41744 L
.8856 .42716 L
.88364 .43395 L
.88267 .43687 L
.87939 .44658 L
.87616 .45629 L
.87393 .46388 L
.87322 .46601 L
.86992 .47572 L
.86665 .48543 L
.86422 .49358 L
.86369 .49514 L
.86037 .50486 L
.85707 .51457 L
.85451 .52303 L
.85408 .52428 L
.85074 .53399 L
.84741 .54371 L
.84479 .55224 L
.84439 .55342 L
.84102 .56313 L
.83767 .57284 L
.83508 .5812 L
.83461 .58256 L
.83122 .59227 L
.82785 .60198 L
.82537 .60992 L
.82475 .61169 L
.82133 .62141 L
.81794 .63112 L
.81566 .63839 L
.8148 .64083 L
.81134 .65054 L
.80795 .66026 L
.80594 .66661 L
.80475 .66997 L
.80127 .67968 L
.79787 .68939 L
.79623 .69458 L
.79461 .69911 L
.79109 .70882 L
.7877 .71853 L
.78652 .7223 L
.78436 .72824 L
.78082 .73796 L
.77746 .74767 L
.77681 .74976 L
.77402 .75738 L
.77045 .76709 L
.76714 .77681 L
.76709 .77697 L
.76356 .78652 L
.75998 .79623 L
.75738 .80391 L
.75663 .80594 L
.75299 .81566 L
.74942 .82537 L
.74767 .83058 L
.74598 .83508 L
.74231 .84479 L
.73878 .85451 L
.73796 .85699 L
.73521 .86422 L
.73152 .87393 L
.72824 .88314 L
.72805 .88364 L
.72431 .89336 L
.72062 .90307 L
.71853 .90901 L
.71707 .91278 L
.71329 .92249 L
.70965 .93221 L
.70882 .9346 L
.70595 .94192 L
.70215 .95163 L
.69911 .95993 L
.69855 .96134 L
.69469 .97106 L
.69091 .98077 L
.98077 .98077 L
F
0 g
.98077 .12196 m
.9795 .12607 L
.97662 .13578 L
.97373 .14549 L
.97106 .15418 L
.97074 .15521 L
.96766 .16492 L
.96457 .17463 L
.96177 .18434 L
.96134 .18617 L
.95884 .19406 L
.95572 .20377 L
.95276 .21348 L
.95163 .21794 L
.94996 .22319 L
.94682 .23291 L
.94376 .24262 L
.94192 .24949 L
.94101 .25233 L
.93786 .26204 L
.93474 .27176 L
.93221 .28081 L
.932 .28147 L
.92884 .29118 L
.92567 .30089 L
.92281 .31061 L
.92249 .3119 L
.91975 .32032 L
.91655 .33003 L
.91356 .33974 L
.91278 .34276 L
.91059 .34946 L
.90737 .35917 L
.90429 .36888 L
.90307 .37339 L
.90136 .37859 L
.89812 .38831 L
.89497 .39802 L
.89336 .40379 L
.89205 .40773 L
.88879 .41744 L
.8856 .42716 L
.88364 .43395 L
.88267 .43687 L
.87939 .44658 L
.87616 .45629 L
.87393 .46388 L
.87322 .46601 L
.86992 .47572 L
.86665 .48543 L
Mistroke
.86422 .49358 L
.86369 .49514 L
.86037 .50486 L
.85707 .51457 L
.85451 .52303 L
.85408 .52428 L
.85074 .53399 L
.84741 .54371 L
.84479 .55224 L
.84439 .55342 L
.84102 .56313 L
.83767 .57284 L
.83508 .5812 L
.83461 .58256 L
.83122 .59227 L
.82785 .60198 L
.82537 .60992 L
.82475 .61169 L
.82133 .62141 L
.81794 .63112 L
.81566 .63839 L
.8148 .64083 L
.81134 .65054 L
.80795 .66026 L
.80594 .66661 L
.80475 .66997 L
.80127 .67968 L
.79787 .68939 L
.79623 .69458 L
.79461 .69911 L
.79109 .70882 L
.7877 .71853 L
.78652 .7223 L
.78436 .72824 L
.78082 .73796 L
.77746 .74767 L
.77681 .74976 L
.77402 .75738 L
.77045 .76709 L
.76714 .77681 L
.76709 .77697 L
.76356 .78652 L
.75998 .79623 L
.75738 .80391 L
.75663 .80594 L
.75299 .81566 L
.74942 .82537 L
.74767 .83058 L
.74598 .83508 L
.74231 .84479 L
Mistroke
.73878 .85451 L
.73796 .85699 L
.73521 .86422 L
.73152 .87393 L
.72824 .88314 L
.72805 .88364 L
.72431 .89336 L
.72062 .90307 L
.71853 .90901 L
.71707 .91278 L
.71329 .92249 L
.70965 .93221 L
.70882 .9346 L
.70595 .94192 L
.70215 .95163 L
.69911 .95993 L
.69855 .96134 L
.69469 .97106 L
.69091 .98077 L
Mfstroke
.8 g
.98077 .14633 m
.97829 .15521 L
.97547 .16492 L
.97243 .17463 L
.97106 .17867 L
.969 .18434 L
.96472 .19406 L
.96351 .20377 L
.96134 .21082 L
.9604 .21348 L
.95643 .22319 L
.95466 .23291 L
.95167 .24262 L
.95163 .24275 L
.94793 .25233 L
.94576 .26204 L
.94276 .27176 L
.94192 .27442 L
.93927 .28147 L
.9347 .29118 L
.93378 .30089 L
.93221 .30589 L
.93046 .31061 L
.92619 .32032 L
.92474 .33003 L
.92249 .33715 L
.92155 .33974 L
.91748 .34946 L
.91564 .35917 L
.91278 .36819 L
.91253 .36888 L
.90861 .37859 L
.90647 .38831 L
.90338 .39802 L
.90307 .39898 L
.89961 .40773 L
.89724 .41744 L
.89413 .42716 L
.89336 .42954 L
.89049 .43687 L
.88795 .44658 L
.88482 .45629 L
.88364 .45988 L
.88126 .46601 L
.8766 .47572 L
.87543 .48543 L
.87393 .48999 L
.87193 .49514 L
.86737 .50486 L
.86598 .51457 L
.86422 .51988 L
.86251 .52428 L
.85801 .53399 L
.85644 .54371 L
.85451 .54952 L
.85299 .55342 L
.84851 .56313 L
.84684 .57284 L
.84479 .57894 L
.84338 .58256 L
.83889 .59227 L
.83716 .60198 L
.83508 .60811 L
.83367 .61169 L
.82914 .62141 L
.82739 .63112 L
.82537 .63704 L
.82386 .64083 L
.81925 .65054 L
.81754 .66026 L
.81566 .66573 L
.81395 .66997 L
.80922 .67968 L
.80761 .68939 L
.80594 .69418 L
.80392 .69911 L
.79903 .70882 L
.79759 .71853 L
.79623 .72239 L
.79378 .72824 L
.79087 .73796 L
.78748 .74767 L
.78652 .75036 L
.7835 .75738 L
.7807 .76709 L
.77727 .77681 L
.77681 .77809 L
.77306 .78652 L
.77043 .79623 L
.76709 .80559 L
.76695 .80594 L
.76245 .81566 L
.76006 .82537 L
.75738 .83278 L
.75642 .83508 L
.75161 .84479 L
.74959 .85451 L
.74767 .85973 L
.74572 .86422 L
.74046 .87393 L
.73901 .88364 L
.73796 .88644 L
.73482 .89336 L
.7319 .90307 L
.72831 .91278 L
.72824 .91295 L
.72364 .92249 L
.72113 .93221 L
.71853 .93912 L
.7173 .94192 L
.71208 .95163 L
.71024 .96134 L
.70882 .96504 L
.70602 .97106 L
.70293 .98077 L
.98077 .98077 L
F
0 g
.98077 .14633 m
.97829 .15521 L
.97547 .16492 L
.97243 .17463 L
.97106 .17867 L
.969 .18434 L
.96472 .19406 L
.96351 .20377 L
.96134 .21082 L
.9604 .21348 L
.95643 .22319 L
.95466 .23291 L
.95167 .24262 L
.95163 .24275 L
.94793 .25233 L
.94576 .26204 L
.94276 .27176 L
.94192 .27442 L
.93927 .28147 L
.9347 .29118 L
.93378 .30089 L
.93221 .30589 L
.93046 .31061 L
.92619 .32032 L
.92474 .33003 L
.92249 .33715 L
.92155 .33974 L
.91748 .34946 L
.91564 .35917 L
.91278 .36819 L
.91253 .36888 L
.90861 .37859 L
.90647 .38831 L
.90338 .39802 L
.90307 .39898 L
.89961 .40773 L
.89724 .41744 L
.89413 .42716 L
.89336 .42954 L
.89049 .43687 L
.88795 .44658 L
.88482 .45629 L
.88364 .45988 L
.88126 .46601 L
.8766 .47572 L
.87543 .48543 L
.87393 .48999 L
.87193 .49514 L
.86737 .50486 L
.86598 .51457 L
Mistroke
.86422 .51988 L
.86251 .52428 L
.85801 .53399 L
.85644 .54371 L
.85451 .54952 L
.85299 .55342 L
.84851 .56313 L
.84684 .57284 L
.84479 .57894 L
.84338 .58256 L
.83889 .59227 L
.83716 .60198 L
.83508 .60811 L
.83367 .61169 L
.82914 .62141 L
.82739 .63112 L
.82537 .63704 L
.82386 .64083 L
.81925 .65054 L
.81754 .66026 L
.81566 .66573 L
.81395 .66997 L
.80922 .67968 L
.80761 .68939 L
.80594 .69418 L
.80392 .69911 L
.79903 .70882 L
.79759 .71853 L
.79623 .72239 L
.79378 .72824 L
.79087 .73796 L
.78748 .74767 L
.78652 .75036 L
.7835 .75738 L
.7807 .76709 L
.77727 .77681 L
.77681 .77809 L
.77306 .78652 L
.77043 .79623 L
.76709 .80559 L
.76695 .80594 L
.76245 .81566 L
.76006 .82537 L
.75738 .83278 L
.75642 .83508 L
.75161 .84479 L
.74959 .85451 L
.74767 .85973 L
.74572 .86422 L
.74046 .87393 L
Mistroke
.73901 .88364 L
.73796 .88644 L
.73482 .89336 L
.7319 .90307 L
.72831 .91278 L
.72824 .91295 L
.72364 .92249 L
.72113 .93221 L
.71853 .93912 L
.7173 .94192 L
.71208 .95163 L
.71024 .96134 L
.70882 .96504 L
.70602 .97106 L
.70293 .98077 L
Mfstroke
.7 g
.98077 .23927 m
.97978 .24262 L
.97686 .25233 L
.97387 .26204 L
.97106 .2711 L
.97085 .27176 L
.96785 .28147 L
.96606 .29118 L
.96201 .30089 L
.96134 .30272 L
.95888 .31061 L
.95752 .32032 L
.95317 .33003 L
.95163 .33413 L
.94986 .33974 L
.94898 .34946 L
.94428 .35917 L
.94192 .36529 L
.94077 .36888 L
.93771 .37859 L
.93535 .38831 L
.93221 .3962 L
.93162 .39802 L
.92853 .40773 L
.92637 .41744 L
.92249 .42687 L
.9224 .42716 L
.91928 .43687 L
.91731 .44658 L
.91317 .45629 L
.91278 .45732 L
.90997 .46601 L
.90818 .47572 L
.90387 .48543 L
.90307 .48754 L
.90058 .49514 L
.89895 .50486 L
.8945 .51457 L
.89336 .51751 L
.89112 .52428 L
.88961 .53399 L
.88503 .54371 L
.88364 .54723 L
.88158 .55342 L
.88015 .56313 L
.87547 .57284 L
.87393 .57671 L
.87196 .58256 L
.87056 .59227 L
.86581 .60198 L
.86422 .60593 L
.86226 .61169 L
.86082 .62141 L
.85604 .63112 L
.85451 .6349 L
.85248 .64083 L
.85094 .65054 L
.84617 .66026 L
.84479 .66361 L
.8426 .66997 L
.84091 .67968 L
.83618 .68939 L
.83508 .69207 L
.83264 .69911 L
.83073 .70882 L
.82608 .71853 L
.82537 .72026 L
.82257 .72824 L
.82042 .73796 L
.81587 .74767 L
.81566 .74819 L
.81241 .75738 L
.80999 .76709 L
.80594 .77588 L
.8056 .77681 L
.80215 .78652 L
.79943 .79623 L
.79623 .8033 L
.79526 .80594 L
.79178 .81566 L
.78878 .82537 L
.78652 .83044 L
.78481 .83508 L
.78321 .84479 L
.77802 .85451 L
.77681 .85728 L
.77425 .86422 L
.77202 .87393 L
.76717 .88364 L
.76709 .88383 L
.76356 .89336 L
.76078 .90307 L
.75738 .91018 L
.75639 .91278 L
.75275 .92249 L
.74951 .93221 L
.74767 .93619 L
.74548 .94192 L
.74336 .95163 L
.73819 .96134 L
.73796 .96187 L
.73443 .97106 L
.73152 .98077 L
.98077 .98077 L
F
0 g
.98077 .23927 m
.97978 .24262 L
.97686 .25233 L
.97387 .26204 L
.97106 .2711 L
.97085 .27176 L
.96785 .28147 L
.96606 .29118 L
.96201 .30089 L
.96134 .30272 L
.95888 .31061 L
.95752 .32032 L
.95317 .33003 L
.95163 .33413 L
.94986 .33974 L
.94898 .34946 L
.94428 .35917 L
.94192 .36529 L
.94077 .36888 L
.93771 .37859 L
.93535 .38831 L
.93221 .3962 L
.93162 .39802 L
.92853 .40773 L
.92637 .41744 L
.92249 .42687 L
.9224 .42716 L
.91928 .43687 L
.91731 .44658 L
.91317 .45629 L
.91278 .45732 L
.90997 .46601 L
.90818 .47572 L
.90387 .48543 L
.90307 .48754 L
.90058 .49514 L
.89895 .50486 L
.8945 .51457 L
.89336 .51751 L
.89112 .52428 L
.88961 .53399 L
.88503 .54371 L
.88364 .54723 L
.88158 .55342 L
.88015 .56313 L
.87547 .57284 L
.87393 .57671 L
.87196 .58256 L
.87056 .59227 L
.86581 .60198 L
Mistroke
.86422 .60593 L
.86226 .61169 L
.86082 .62141 L
.85604 .63112 L
.85451 .6349 L
.85248 .64083 L
.85094 .65054 L
.84617 .66026 L
.84479 .66361 L
.8426 .66997 L
.84091 .67968 L
.83618 .68939 L
.83508 .69207 L
.83264 .69911 L
.83073 .70882 L
.82608 .71853 L
.82537 .72026 L
.82257 .72824 L
.82042 .73796 L
.81587 .74767 L
.81566 .74819 L
.81241 .75738 L
.80999 .76709 L
.80594 .77588 L
.8056 .77681 L
.80215 .78652 L
.79943 .79623 L
.79623 .8033 L
.79526 .80594 L
.79178 .81566 L
.78878 .82537 L
.78652 .83044 L
.78481 .83508 L
.78321 .84479 L
.77802 .85451 L
.77681 .85728 L
.77425 .86422 L
.77202 .87393 L
.76717 .88364 L
.76709 .88383 L
.76356 .89336 L
.76078 .90307 L
.75738 .91018 L
.75639 .91278 L
.75275 .92249 L
.74951 .93221 L
.74767 .93619 L
.74548 .94192 L
.74336 .95163 L
.73819 .96134 L
Mistroke
.73796 .96187 L
.73443 .97106 L
.73152 .98077 L
Mfstroke
.6 g
.98077 .26362 m
.97835 .27176 L
.9754 .28147 L
.97167 .29118 L
.97106 .29561 L
.96974 .30089 L
.96675 .31061 L
.96361 .32032 L
.96134 .32738 L
.96072 .33003 L
.95785 .33974 L
.95469 .34946 L
.95163 .35891 L
.95158 .35917 L
.94886 .36888 L
.94571 .37859 L
.94254 .38831 L
.94192 .39022 L
.9398 .39802 L
.93667 .40773 L
.93346 .41744 L
.93221 .4213 L
.93065 .42716 L
.92755 .43687 L
.92432 .44658 L
.92249 .45215 L
.92142 .45629 L
.91836 .46601 L
.91512 .47572 L
.91278 .48276 L
.91211 .48543 L
.9091 .49514 L
.90584 .50486 L
.90307 .51313 L
.90271 .51457 L
.89976 .52428 L
.89648 .53399 L
.89336 .54326 L
.89325 .54371 L
.89035 .55342 L
.88706 .56313 L
.88375 .57284 L
.88364 .57316 L
.88085 .58256 L
.87755 .59227 L
.87422 .60198 L
.87393 .60282 L
.87128 .61169 L
.86796 .62141 L
.8646 .63112 L
.86422 .63223 L
.86163 .64083 L
.85829 .65054 L
.8549 .66026 L
.85451 .6614 L
.8519 .66997 L
.84853 .67968 L
.84511 .68939 L
.84479 .69032 L
.84208 .69911 L
.83868 .70882 L
.83524 .71853 L
.83508 .71898 L
.83217 .72824 L
.82874 .73796 L
.82537 .7474 L
.8253 .74767 L
.82217 .75738 L
.8187 .76709 L
.81566 .77556 L
.8153 .77681 L
.81208 .78652 L
.80856 .79623 L
.80594 .80347 L
.80521 .80594 L
.80188 .81566 L
.79833 .82537 L
.79623 .83111 L
.795 .83508 L
.79158 .84479 L
.78798 .85451 L
.78652 .85849 L
.78468 .86422 L
.78116 .87393 L
.77753 .88364 L
.77681 .88561 L
.77423 .89336 L
.77062 .90307 L
.76709 .91245 L
.76699 .91278 L
.76364 .92249 L
.75997 .93221 L
.75738 .93903 L
.75645 .94192 L
.75292 .95163 L
.7492 .96134 L
.74767 .96534 L
.74573 .97106 L
.74206 .98077 L
.98077 .98077 L
F
0 g
.98077 .26362 m
.97835 .27176 L
.9754 .28147 L
.97167 .29118 L
.97106 .29561 L
.96974 .30089 L
.96675 .31061 L
.96361 .32032 L
.96134 .32738 L
.96072 .33003 L
.95785 .33974 L
.95469 .34946 L
.95163 .35891 L
.95158 .35917 L
.94886 .36888 L
.94571 .37859 L
.94254 .38831 L
.94192 .39022 L
.9398 .39802 L
.93667 .40773 L
.93346 .41744 L
.93221 .4213 L
.93065 .42716 L
.92755 .43687 L
.92432 .44658 L
.92249 .45215 L
.92142 .45629 L
.91836 .46601 L
.91512 .47572 L
.91278 .48276 L
.91211 .48543 L
.9091 .49514 L
.90584 .50486 L
.90307 .51313 L
.90271 .51457 L
.89976 .52428 L
.89648 .53399 L
.89336 .54326 L
.89325 .54371 L
.89035 .55342 L
.88706 .56313 L
.88375 .57284 L
.88364 .57316 L
.88085 .58256 L
.87755 .59227 L
.87422 .60198 L
.87393 .60282 L
.87128 .61169 L
.86796 .62141 L
.8646 .63112 L
Mistroke
.86422 .63223 L
.86163 .64083 L
.85829 .65054 L
.8549 .66026 L
.85451 .6614 L
.8519 .66997 L
.84853 .67968 L
.84511 .68939 L
.84479 .69032 L
.84208 .69911 L
.83868 .70882 L
.83524 .71853 L
.83508 .71898 L
.83217 .72824 L
.82874 .73796 L
.82537 .7474 L
.8253 .74767 L
.82217 .75738 L
.8187 .76709 L
.81566 .77556 L
.8153 .77681 L
.81208 .78652 L
.80856 .79623 L
.80594 .80347 L
.80521 .80594 L
.80188 .81566 L
.79833 .82537 L
.79623 .83111 L
.795 .83508 L
.79158 .84479 L
.78798 .85451 L
.78652 .85849 L
.78468 .86422 L
.78116 .87393 L
.77753 .88364 L
.77681 .88561 L
.77423 .89336 L
.77062 .90307 L
.76709 .91245 L
.76699 .91278 L
.76364 .92249 L
.75997 .93221 L
.75738 .93903 L
.75645 .94192 L
.75292 .95163 L
.7492 .96134 L
.74767 .96534 L
.74573 .97106 L
.74206 .98077 L
Mfstroke
.5 g
.98077 .28385 m
.97636 .29118 L
.97473 .30089 L
.97251 .31061 L
.97106 .31592 L
.96978 .32032 L
.96682 .33003 L
.96381 .33974 L
.96134 .34776 L
.96085 .34946 L
.95792 .35917 L
.95489 .36888 L
.95187 .37859 L
.95163 .37938 L
.94895 .38831 L
.94591 .39802 L
.94286 .40773 L
.94192 .41077 L
.93991 .41744 L
.93687 .42716 L
.9338 .43687 L
.93221 .44193 L
.93081 .44658 L
.92776 .45629 L
.92467 .46601 L
.92249 .47287 L
.92163 .47572 L
.91859 .48543 L
.91547 .49514 L
.91278 .50356 L
.91239 .50486 L
.90934 .51457 L
.90621 .52428 L
.90308 .53399 L
.90307 .53403 L
.90003 .54371 L
.89688 .55342 L
.89372 .56313 L
.89336 .56426 L
.89065 .57284 L
.88747 .58256 L
.88429 .59227 L
.88364 .59425 L
.88119 .60198 L
.87799 .61169 L
.87478 .62141 L
.87393 .624 L
.87165 .63112 L
.86844 .64083 L
.8652 .65054 L
.86422 .65351 L
.86204 .66026 L
.8588 .66997 L
.85554 .67968 L
.85451 .68278 L
.85235 .68939 L
.84909 .69911 L
.8458 .70882 L
.84479 .7118 L
.84258 .71853 L
.83929 .72824 L
.83597 .73796 L
.83508 .74057 L
.83272 .74767 L
.8294 .75738 L
.82605 .76709 L
.82537 .76909 L
.82278 .77681 L
.81942 .78652 L
.81605 .79623 L
.81566 .79736 L
.81274 .80594 L
.80935 .81566 L
.80595 .82537 L
.80594 .82538 L
.80261 .83508 L
.79918 .84479 L
.79623 .85314 L
.79577 .85451 L
.79237 .86422 L
.78891 .87393 L
.78652 .88064 L
.78548 .88364 L
.78204 .89336 L
.77854 .90307 L
.77681 .90788 L
.77509 .91278 L
.77159 .92249 L
.76805 .93221 L
.76709 .93485 L
.76457 .94192 L
.76103 .95163 L
.75746 .96134 L
.75738 .96155 L
.75394 .97106 L
.75035 .98077 L
.98077 .98077 L
F
0 g
.98077 .28385 m
.97636 .29118 L
.97473 .30089 L
.97251 .31061 L
.97106 .31592 L
.96978 .32032 L
.96682 .33003 L
.96381 .33974 L
.96134 .34776 L
.96085 .34946 L
.95792 .35917 L
.95489 .36888 L
.95187 .37859 L
.95163 .37938 L
.94895 .38831 L
.94591 .39802 L
.94286 .40773 L
.94192 .41077 L
.93991 .41744 L
.93687 .42716 L
.9338 .43687 L
.93221 .44193 L
.93081 .44658 L
.92776 .45629 L
.92467 .46601 L
.92249 .47287 L
.92163 .47572 L
.91859 .48543 L
.91547 .49514 L
.91278 .50356 L
.91239 .50486 L
.90934 .51457 L
.90621 .52428 L
.90308 .53399 L
.90307 .53403 L
.90003 .54371 L
.89688 .55342 L
.89372 .56313 L
.89336 .56426 L
.89065 .57284 L
.88747 .58256 L
.88429 .59227 L
.88364 .59425 L
.88119 .60198 L
.87799 .61169 L
.87478 .62141 L
.87393 .624 L
.87165 .63112 L
.86844 .64083 L
.8652 .65054 L
Mistroke
.86422 .65351 L
.86204 .66026 L
.8588 .66997 L
.85554 .67968 L
.85451 .68278 L
.85235 .68939 L
.84909 .69911 L
.8458 .70882 L
.84479 .7118 L
.84258 .71853 L
.83929 .72824 L
.83597 .73796 L
.83508 .74057 L
.83272 .74767 L
.8294 .75738 L
.82605 .76709 L
.82537 .76909 L
.82278 .77681 L
.81942 .78652 L
.81605 .79623 L
.81566 .79736 L
.81274 .80594 L
.80935 .81566 L
.80595 .82537 L
.80594 .82538 L
.80261 .83508 L
.79918 .84479 L
.79623 .85314 L
.79577 .85451 L
.79237 .86422 L
.78891 .87393 L
.78652 .88064 L
.78548 .88364 L
.78204 .89336 L
.77854 .90307 L
.77681 .90788 L
.77509 .91278 L
.77159 .92249 L
.76805 .93221 L
.76709 .93485 L
.76457 .94192 L
.76103 .95163 L
.75746 .96134 L
.75738 .96155 L
.75394 .97106 L
.75035 .98077 L
Mfstroke
.4 g
.98077 .30312 m
.97817 .31061 L
.97541 .32032 L
.97261 .33003 L
.97106 .33526 L
.9697 .33974 L
.96671 .34946 L
.96372 .35917 L
.96134 .36717 L
.96082 .36888 L
.95783 .37859 L
.95481 .38831 L
.95188 .39802 L
.95163 .39886 L
.94889 .40773 L
.94585 .41744 L
.94286 .42716 L
.94192 .43032 L
.93988 .43687 L
.93683 .44658 L
.9338 .45629 L
.93221 .46155 L
.93082 .46601 L
.92774 .47572 L
.92468 .48543 L
.92249 .49256 L
.92168 .49514 L
.9186 .50486 L
.9155 .51457 L
.91278 .52333 L
.91248 .52428 L
.90938 .53399 L
.90626 .54371 L
.90321 .55342 L
.90307 .55388 L
.9001 .56313 L
.89695 .57284 L
.89386 .58256 L
.89336 .58418 L
.89074 .59227 L
.88757 .60198 L
.88445 .61169 L
.88364 .61425 L
.88132 .62141 L
.87812 .63112 L
.87496 .64083 L
.87393 .64409 L
.87181 .65054 L
.8686 .66026 L
.86541 .66997 L
.86422 .67368 L
.86224 .67968 L
.85899 .68939 L
.85578 .69911 L
.85451 .70303 L
.85258 .70882 L
.84931 .71853 L
.84606 .72824 L
.84479 .73214 L
.84284 .73796 L
.83954 .74767 L
.83627 .75738 L
.83508 .761 L
.83302 .76709 L
.82969 .77681 L
.8264 .78652 L
.82537 .78961 L
.8231 .79623 L
.81975 .80594 L
.81643 .81566 L
.81566 .81797 L
.8131 .82537 L
.80972 .83508 L
.80638 .84479 L
.80594 .84608 L
.80301 .85451 L
.79959 .86422 L
.79623 .87393 L
.79623 .87394 L
.79281 .88364 L
.78937 .89336 L
.78652 .90154 L
.78598 .90307 L
.78252 .91278 L
.77905 .92249 L
.77681 .92888 L
.77562 .93221 L
.77212 .94192 L
.76862 .95163 L
.76709 .95595 L
.76515 .96134 L
.76161 .97106 L
.75809 .98077 L
.98077 .98077 L
F
0 g
.98077 .30312 m
.97817 .31061 L
.97541 .32032 L
.97261 .33003 L
.97106 .33526 L
.9697 .33974 L
.96671 .34946 L
.96372 .35917 L
.96134 .36717 L
.96082 .36888 L
.95783 .37859 L
.95481 .38831 L
.95188 .39802 L
.95163 .39886 L
.94889 .40773 L
.94585 .41744 L
.94286 .42716 L
.94192 .43032 L
.93988 .43687 L
.93683 .44658 L
.9338 .45629 L
.93221 .46155 L
.93082 .46601 L
.92774 .47572 L
.92468 .48543 L
.92249 .49256 L
.92168 .49514 L
.9186 .50486 L
.9155 .51457 L
.91278 .52333 L
.91248 .52428 L
.90938 .53399 L
.90626 .54371 L
.90321 .55342 L
.90307 .55388 L
.9001 .56313 L
.89695 .57284 L
.89386 .58256 L
.89336 .58418 L
.89074 .59227 L
.88757 .60198 L
.88445 .61169 L
.88364 .61425 L
.88132 .62141 L
.87812 .63112 L
.87496 .64083 L
.87393 .64409 L
.87181 .65054 L
.8686 .66026 L
.86541 .66997 L
Mistroke
.86422 .67368 L
.86224 .67968 L
.85899 .68939 L
.85578 .69911 L
.85451 .70303 L
.85258 .70882 L
.84931 .71853 L
.84606 .72824 L
.84479 .73214 L
.84284 .73796 L
.83954 .74767 L
.83627 .75738 L
.83508 .761 L
.83302 .76709 L
.82969 .77681 L
.8264 .78652 L
.82537 .78961 L
.8231 .79623 L
.81975 .80594 L
.81643 .81566 L
.81566 .81797 L
.8131 .82537 L
.80972 .83508 L
.80638 .84479 L
.80594 .84608 L
.80301 .85451 L
.79959 .86422 L
.79623 .87393 L
.79623 .87394 L
.79281 .88364 L
.78937 .89336 L
.78652 .90154 L
.78598 .90307 L
.78252 .91278 L
.77905 .92249 L
.77681 .92888 L
.77562 .93221 L
.77212 .94192 L
.76862 .95163 L
.76709 .95595 L
.76515 .96134 L
.76161 .97106 L
.75809 .98077 L
Mfstroke
.3 g
.98077 .32335 m
.97873 .33003 L
.97586 .33974 L
.97294 .34946 L
.97106 .35556 L
.96993 .35917 L
.96683 .36888 L
.96377 .37859 L
.96134 .38756 L
.96111 .38831 L
.95801 .39802 L
.9549 .40773 L
.95207 .41744 L
.95163 .41933 L
.94913 .42716 L
.94599 .43687 L
.94301 .44658 L
.94192 .45087 L
.94018 .45629 L
.93702 .46601 L
.93395 .47572 L
.93221 .48219 L
.93116 .48543 L
.92799 .49514 L
.92486 .50486 L
.92249 .51328 L
.92208 .51457 L
.9189 .52428 L
.91572 .53399 L
.91289 .54371 L
.91278 .54415 L
.90973 .55342 L
.90652 .56313 L
.90356 .57284 L
.90307 .57477 L
.9005 .58256 L
.89726 .59227 L
.89421 .60198 L
.89336 .60517 L
.89119 .61169 L
.88793 .62141 L
.88481 .63112 L
.88364 .63534 L
.88181 .64083 L
.87852 .65054 L
.87535 .66026 L
.87393 .66527 L
.87235 .66997 L
.86904 .67968 L
.86583 .68939 L
.86422 .69496 L
.86281 .69911 L
.85948 .70882 L
.85624 .71853 L
.85451 .72441 L
.8532 .72824 L
.84984 .73796 L
.84657 .74767 L
.84479 .75362 L
.8435 .75738 L
.84012 .76709 L
.83682 .77681 L
.83508 .78258 L
.83372 .78652 L
.83031 .79623 L
.827 .80594 L
.82537 .8113 L
.82385 .81566 L
.82041 .82537 L
.81709 .83508 L
.81566 .83977 L
.81389 .84479 L
.81043 .85451 L
.8071 .86422 L
.80594 .868 L
.80383 .87393 L
.80034 .88364 L
.79703 .89336 L
.79623 .89597 L
.79368 .90307 L
.79017 .91278 L
.78688 .92249 L
.78652 .92369 L
.78342 .93221 L
.7799 .94192 L
.77681 .95115 L
.77663 .95163 L
.77306 .96134 L
.76953 .97106 L
.76709 .97836 L
.7662 .98077 L
.98077 .98077 L
F
0 g
.98077 .32335 m
.97873 .33003 L
.97586 .33974 L
.97294 .34946 L
.97106 .35556 L
.96993 .35917 L
.96683 .36888 L
.96377 .37859 L
.96134 .38756 L
.96111 .38831 L
.95801 .39802 L
.9549 .40773 L
.95207 .41744 L
.95163 .41933 L
.94913 .42716 L
.94599 .43687 L
.94301 .44658 L
.94192 .45087 L
.94018 .45629 L
.93702 .46601 L
.93395 .47572 L
.93221 .48219 L
.93116 .48543 L
.92799 .49514 L
.92486 .50486 L
.92249 .51328 L
.92208 .51457 L
.9189 .52428 L
.91572 .53399 L
.91289 .54371 L
.91278 .54415 L
.90973 .55342 L
.90652 .56313 L
.90356 .57284 L
.90307 .57477 L
.9005 .58256 L
.89726 .59227 L
.89421 .60198 L
.89336 .60517 L
.89119 .61169 L
.88793 .62141 L
.88481 .63112 L
.88364 .63534 L
.88181 .64083 L
.87852 .65054 L
.87535 .66026 L
.87393 .66527 L
.87235 .66997 L
.86904 .67968 L
.86583 .68939 L
Mistroke
.86422 .69496 L
.86281 .69911 L
.85948 .70882 L
.85624 .71853 L
.85451 .72441 L
.8532 .72824 L
.84984 .73796 L
.84657 .74767 L
.84479 .75362 L
.8435 .75738 L
.84012 .76709 L
.83682 .77681 L
.83508 .78258 L
.83372 .78652 L
.83031 .79623 L
.827 .80594 L
.82537 .8113 L
.82385 .81566 L
.82041 .82537 L
.81709 .83508 L
.81566 .83977 L
.81389 .84479 L
.81043 .85451 L
.8071 .86422 L
.80594 .868 L
.80383 .87393 L
.80034 .88364 L
.79703 .89336 L
.79623 .89597 L
.79368 .90307 L
.79017 .91278 L
.78688 .92249 L
.78652 .92369 L
.78342 .93221 L
.7799 .94192 L
.77681 .95115 L
.77663 .95163 L
.77306 .96134 L
.76953 .97106 L
.76709 .97836 L
.7662 .98077 L
Mfstroke
.2 g
.98077 .34772 m
.98029 .34946 L
.97755 .35917 L
.97469 .36888 L
.97157 .37859 L
.97106 .38007 L
.96797 .38831 L
.96567 .39802 L
.96272 .40773 L
.96134 .41219 L
.95943 .41744 L
.95518 .42716 L
.95387 .43687 L
.95163 .44412 L
.95075 .44658 L
.94678 .45629 L
.94496 .46601 L
.94195 .47572 L
.94192 .47583 L
.93818 .48543 L
.93599 .49514 L
.93297 .50486 L
.93221 .50728 L
.92943 .51457 L
.92479 .52428 L
.92393 .53399 L
.92249 .53853 L
.92056 .54371 L
.91618 .55342 L
.91483 .56313 L
.91278 .56956 L
.91157 .57284 L
.90739 .58256 L
.90566 .59227 L
.90307 .60037 L
.90248 .60198 L
.89844 .61169 L
.89642 .62141 L
.89336 .63096 L
.8933 .63112 L
.88935 .64083 L
.88712 .65054 L
.88398 .66026 L
.88364 .66128 L
.88015 .66997 L
.87775 .67968 L
.87459 .68939 L
.87393 .69138 L
.87084 .69911 L
.86831 .70882 L
.86513 .71853 L
.86422 .72126 L
.86143 .72824 L
.85879 .73796 L
.85559 .74767 L
.85451 .7509 L
.85191 .75738 L
.84705 .76709 L
.84598 .77681 L
.84479 .78031 L
.8423 .78652 L
.83743 .79623 L
.83629 .80594 L
.83508 .80948 L
.83258 .81566 L
.82766 .82537 L
.82652 .83508 L
.82537 .83842 L
.82275 .84479 L
.81997 .85451 L
.81666 .86422 L
.81566 .86712 L
.81282 .87393 L
.81006 .88364 L
.80672 .89336 L
.80594 .89557 L
.80276 .90307 L
.80006 .91278 L
.79669 .92249 L
.79623 .92379 L
.79258 .93221 L
.78998 .94192 L
.78657 .95163 L
.78652 .95178 L
.78224 .96134 L
.77979 .97106 L
.77681 .97952 L
.77629 .98077 L
.98077 .98077 L
F
0 g
.98077 .34772 m
.98029 .34946 L
.97755 .35917 L
.97469 .36888 L
.97157 .37859 L
.97106 .38007 L
.96797 .38831 L
.96567 .39802 L
.96272 .40773 L
.96134 .41219 L
.95943 .41744 L
.95518 .42716 L
.95387 .43687 L
.95163 .44412 L
.95075 .44658 L
.94678 .45629 L
.94496 .46601 L
.94195 .47572 L
.94192 .47583 L
.93818 .48543 L
.93599 .49514 L
.93297 .50486 L
.93221 .50728 L
.92943 .51457 L
.92479 .52428 L
.92393 .53399 L
.92249 .53853 L
.92056 .54371 L
.91618 .55342 L
.91483 .56313 L
.91278 .56956 L
.91157 .57284 L
.90739 .58256 L
.90566 .59227 L
.90307 .60037 L
.90248 .60198 L
.89844 .61169 L
.89642 .62141 L
.89336 .63096 L
.8933 .63112 L
.88935 .64083 L
.88712 .65054 L
.88398 .66026 L
.88364 .66128 L
.88015 .66997 L
.87775 .67968 L
.87459 .68939 L
.87393 .69138 L
.87084 .69911 L
.86831 .70882 L
Mistroke
.86513 .71853 L
.86422 .72126 L
.86143 .72824 L
.85879 .73796 L
.85559 .74767 L
.85451 .7509 L
.85191 .75738 L
.84705 .76709 L
.84598 .77681 L
.84479 .78031 L
.8423 .78652 L
.83743 .79623 L
.83629 .80594 L
.83508 .80948 L
.83258 .81566 L
.82766 .82537 L
.82652 .83508 L
.82537 .83842 L
.82275 .84479 L
.81997 .85451 L
.81666 .86422 L
.81566 .86712 L
.81282 .87393 L
.81006 .88364 L
.80672 .89336 L
.80594 .89557 L
.80276 .90307 L
.80006 .91278 L
.79669 .92249 L
.79623 .92379 L
.79258 .93221 L
.78998 .94192 L
.78657 .95163 L
.78652 .95178 L
.78224 .96134 L
.77979 .97106 L
.77681 .97952 L
.77629 .98077 L
Mfstroke
.3 g
.98077 .44065 m
.97901 .44658 L
.97607 .45629 L
.97307 .46601 L
.97106 .4725 L
.97005 .47572 L
.96705 .48543 L
.96488 .49514 L
.96134 .50411 L
.96111 .50486 L
.95808 .51457 L
.95623 .52428 L
.95218 .53399 L
.95163 .5355 L
.94905 .54371 L
.94757 .55342 L
.94325 .56313 L
.94192 .56667 L
.93996 .57284 L
.93888 .58256 L
.93426 .59227 L
.93221 .5976 L
.9308 .60198 L
.92771 .61169 L
.92522 .62141 L
.92249 .62828 L
.92157 .63112 L
.91846 .64083 L
.91611 .65054 L
.91278 .65872 L
.91228 .66026 L
.90914 .66997 L
.90692 .67968 L
.90307 .68891 L
.90291 .68939 L
.89974 .69911 L
.89764 .70882 L
.89349 .71853 L
.89336 .71887 L
.89027 .72824 L
.88825 .73796 L
.884 .74767 L
.88364 .7486 L
.88073 .75738 L
.87876 .76709 L
.87442 .77681 L
.87393 .77807 L
.8711 .78652 L
.86914 .79623 L
.86475 .80594 L
.86422 .80729 L
.86139 .81566 L
.85939 .82537 L
.85497 .83508 L
.85451 .83626 L
.8516 .84479 L
.84951 .85451 L
.8451 .86422 L
.84479 .86498 L
.84172 .87393 L
.8395 .88364 L
.83511 .89336 L
.83508 .89343 L
.83174 .90307 L
.82936 .91278 L
.82537 .92165 L
.82507 .92249 L
.82167 .93221 L
.81909 .94192 L
.81566 .9496 L
.81493 .95163 L
.81151 .96134 L
.8087 .97106 L
.80594 .97698 L
.80469 .98077 L
.98077 .98077 L
F
0 g
.98077 .44065 m
.97901 .44658 L
.97607 .45629 L
.97307 .46601 L
.97106 .4725 L
.97005 .47572 L
.96705 .48543 L
.96488 .49514 L
.96134 .50411 L
.96111 .50486 L
.95808 .51457 L
.95623 .52428 L
.95218 .53399 L
.95163 .5355 L
.94905 .54371 L
.94757 .55342 L
.94325 .56313 L
.94192 .56667 L
.93996 .57284 L
.93888 .58256 L
.93426 .59227 L
.93221 .5976 L
.9308 .60198 L
.92771 .61169 L
.92522 .62141 L
.92249 .62828 L
.92157 .63112 L
.91846 .64083 L
.91611 .65054 L
.91278 .65872 L
.91228 .66026 L
.90914 .66997 L
.90692 .67968 L
.90307 .68891 L
.90291 .68939 L
.89974 .69911 L
.89764 .70882 L
.89349 .71853 L
.89336 .71887 L
.89027 .72824 L
.88825 .73796 L
.884 .74767 L
.88364 .7486 L
.88073 .75738 L
.87876 .76709 L
.87442 .77681 L
.87393 .77807 L
.8711 .78652 L
.86914 .79623 L
.86475 .80594 L
Mistroke
.86422 .80729 L
.86139 .81566 L
.85939 .82537 L
.85497 .83508 L
.85451 .83626 L
.8516 .84479 L
.84951 .85451 L
.8451 .86422 L
.84479 .86498 L
.84172 .87393 L
.8395 .88364 L
.83511 .89336 L
.83508 .89343 L
.83174 .90307 L
.82936 .91278 L
.82537 .92165 L
.82507 .92249 L
.82167 .93221 L
.81909 .94192 L
.81566 .9496 L
.81493 .95163 L
.81151 .96134 L
.8087 .97106 L
.80594 .97698 L
.80469 .98077 L
Mfstroke
.4 g
.98077 .465 m
.98047 .46601 L
.97757 .47572 L
.97461 .48543 L
.97139 .49514 L
.97106 .49699 L
.96899 .50486 L
.96592 .51457 L
.96277 .52428 L
.96134 .52876 L
.96003 .53399 L
.95702 .54371 L
.95385 .55342 L
.95163 .5603 L
.95096 .56313 L
.94804 .57284 L
.94486 .58256 L
.94192 .5916 L
.94177 .59227 L
.93899 .60198 L
.93581 .61169 L
.93262 .62141 L
.93221 .62268 L
.92986 .63112 L
.9267 .64083 L
.92347 .65054 L
.92249 .65353 L
.92066 .66026 L
.91751 .66997 L
.91426 .67968 L
.91278 .68414 L
.91137 .68939 L
.90824 .69911 L
.90497 .70882 L
.90307 .71452 L
.902 .71853 L
.8989 .72824 L
.89561 .73796 L
.89336 .74465 L
.89256 .74767 L
.88949 .75738 L
.88617 .76709 L
.88364 .77455 L
.88305 .77681 L
.87999 .78652 L
.87666 .79623 L
.87393 .80421 L
.87348 .80594 L
.87042 .81566 L
.86706 .82537 L
.86422 .83362 L
.86383 .83508 L
.86076 .84479 L
.85738 .85451 L
.85451 .86278 L
.85412 .86422 L
.85102 .87393 L
.84762 .88364 L
.84479 .8917 L
.84434 .89336 L
.84119 .90307 L
.83776 .91278 L
.83508 .92037 L
.83448 .92249 L
.83128 .93221 L
.82781 .94192 L
.82537 .94879 L
.82454 .95163 L
.82126 .96134 L
.81777 .97106 L
.81566 .97692 L
.81451 .98077 L
.98077 .98077 L
F
0 g
.98077 .465 m
.98047 .46601 L
.97757 .47572 L
.97461 .48543 L
.97139 .49514 L
.97106 .49699 L
.96899 .50486 L
.96592 .51457 L
.96277 .52428 L
.96134 .52876 L
.96003 .53399 L
.95702 .54371 L
.95385 .55342 L
.95163 .5603 L
.95096 .56313 L
.94804 .57284 L
.94486 .58256 L
.94192 .5916 L
.94177 .59227 L
.93899 .60198 L
.93581 .61169 L
.93262 .62141 L
.93221 .62268 L
.92986 .63112 L
.9267 .64083 L
.92347 .65054 L
.92249 .65353 L
.92066 .66026 L
.91751 .66997 L
.91426 .67968 L
.91278 .68414 L
.91137 .68939 L
.90824 .69911 L
.90497 .70882 L
.90307 .71452 L
.902 .71853 L
.8989 .72824 L
.89561 .73796 L
.89336 .74465 L
.89256 .74767 L
.88949 .75738 L
.88617 .76709 L
.88364 .77455 L
.88305 .77681 L
.87999 .78652 L
.87666 .79623 L
.87393 .80421 L
.87348 .80594 L
.87042 .81566 L
.86706 .82537 L
Mistroke
.86422 .83362 L
.86383 .83508 L
.86076 .84479 L
.85738 .85451 L
.85451 .86278 L
.85412 .86422 L
.85102 .87393 L
.84762 .88364 L
.84479 .8917 L
.84434 .89336 L
.84119 .90307 L
.83776 .91278 L
.83508 .92037 L
.83448 .92249 L
.83128 .93221 L
.82781 .94192 L
.82537 .94879 L
.82454 .95163 L
.82126 .96134 L
.81777 .97106 L
.81566 .97692 L
.81451 .98077 L
Mfstroke
.5 g
.98077 .48523 m
.98071 .48543 L
.97591 .49514 L
.97421 .50486 L
.97182 .51457 L
.97106 .5173 L
.96901 .52428 L
.96603 .53399 L
.96301 .54371 L
.96134 .54915 L
.96009 .55342 L
.95712 .56313 L
.95409 .57284 L
.95163 .58076 L
.95111 .58256 L
.94815 .59227 L
.9451 .60198 L
.94206 .61169 L
.94192 .61216 L
.93911 .62141 L
.93605 .63112 L
.93298 .64083 L
.93221 .64332 L
.93001 .65054 L
.92694 .66026 L
.92385 .66997 L
.92249 .67425 L
.92084 .67968 L
.91776 .68939 L
.91464 .69911 L
.91278 .70495 L
.9116 .70882 L
.90852 .71853 L
.90537 .72824 L
.90307 .73541 L
.90229 .73796 L
.8992 .74767 L
.89604 .75738 L
.89336 .76564 L
.89291 .76709 L
.88981 .77681 L
.88663 .78652 L
.88364 .79563 L
.88346 .79623 L
.88035 .80594 L
.87714 .81566 L
.87394 .82537 L
.87393 .82539 L
.87081 .83508 L
.86758 .84479 L
.86435 .85451 L
.86422 .8549 L
.86119 .86422 L
.85794 .87393 L
.85468 .88364 L
.85451 .88416 L
.85149 .89336 L
.84821 .90307 L
.84493 .91278 L
.84479 .91318 L
.84171 .92249 L
.83841 .93221 L
.83509 .94192 L
.83508 .94195 L
.83185 .95163 L
.82851 .96134 L
.82537 .97048 L
.82518 .97106 L
.82189 .98077 L
.98077 .98077 L
F
0 g
.98077 .48523 m
.98071 .48543 L
.97591 .49514 L
.97421 .50486 L
.97182 .51457 L
.97106 .5173 L
.96901 .52428 L
.96603 .53399 L
.96301 .54371 L
.96134 .54915 L
.96009 .55342 L
.95712 .56313 L
.95409 .57284 L
.95163 .58076 L
.95111 .58256 L
.94815 .59227 L
.9451 .60198 L
.94206 .61169 L
.94192 .61216 L
.93911 .62141 L
.93605 .63112 L
.93298 .64083 L
.93221 .64332 L
.93001 .65054 L
.92694 .66026 L
.92385 .66997 L
.92249 .67425 L
.92084 .67968 L
.91776 .68939 L
.91464 .69911 L
.91278 .70495 L
.9116 .70882 L
.90852 .71853 L
.90537 .72824 L
.90307 .73541 L
.90229 .73796 L
.8992 .74767 L
.89604 .75738 L
.89336 .76564 L
.89291 .76709 L
.88981 .77681 L
.88663 .78652 L
.88364 .79563 L
.88346 .79623 L
.88035 .80594 L
.87714 .81566 L
.87394 .82537 L
.87393 .82539 L
.87081 .83508 L
.86758 .84479 L
Mistroke
.86435 .85451 L
.86422 .8549 L
.86119 .86422 L
.85794 .87393 L
.85468 .88364 L
.85451 .88416 L
.85149 .89336 L
.84821 .90307 L
.84493 .91278 L
.84479 .91318 L
.84171 .92249 L
.83841 .93221 L
.83509 .94192 L
.83508 .94195 L
.83185 .95163 L
.82851 .96134 L
.82537 .97048 L
.82518 .97106 L
.82189 .98077 L
Mfstroke
.6 g
.98077 .50451 m
.98062 .50486 L
.97742 .51457 L
.97468 .52428 L
.97185 .53399 L
.97106 .53664 L
.96891 .54371 L
.96591 .55342 L
.96294 .56313 L
.96134 .56855 L
.96003 .57284 L
.95703 .58256 L
.95402 .59227 L
.95163 .60024 L
.9511 .60198 L
.94808 .61169 L
.94505 .62141 L
.94209 .63112 L
.94192 .6317 L
.93908 .64083 L
.93602 .65054 L
.93301 .66026 L
.93221 .66294 L
.93001 .66997 L
.92693 .67968 L
.92388 .68939 L
.92249 .69394 L
.92087 .69911 L
.91777 .70882 L
.91469 .71853 L
.91278 .72472 L
.91167 .72824 L
.90855 .73796 L
.90544 .74767 L
.90307 .75526 L
.90239 .75738 L
.89926 .76709 L
.89612 .77681 L
.89336 .78557 L
.89305 .78652 L
.8899 .79623 L
.88673 .80594 L
.88364 .81564 L
.88364 .81566 L
.88047 .82537 L
.87728 .83508 L
.87414 .84479 L
.87393 .84547 L
.87096 .85451 L
.86774 .86422 L
.86458 .87393 L
.86422 .87506 L
.86138 .88364 L
.85813 .89336 L
.85494 .90307 L
.85451 .90441 L
.85171 .91278 L
.84844 .92249 L
.84522 .93221 L
.84479 .93352 L
.84197 .94192 L
.83867 .95163 L
.83542 .96134 L
.83508 .96238 L
.83213 .97106 L
.82881 .98077 L
.98077 .98077 L
F
0 g
.98077 .50451 m
.98062 .50486 L
.97742 .51457 L
.97468 .52428 L
.97185 .53399 L
.97106 .53664 L
.96891 .54371 L
.96591 .55342 L
.96294 .56313 L
.96134 .56855 L
.96003 .57284 L
.95703 .58256 L
.95402 .59227 L
.95163 .60024 L
.9511 .60198 L
.94808 .61169 L
.94505 .62141 L
.94209 .63112 L
.94192 .6317 L
.93908 .64083 L
.93602 .65054 L
.93301 .66026 L
.93221 .66294 L
.93001 .66997 L
.92693 .67968 L
.92388 .68939 L
.92249 .69394 L
.92087 .69911 L
.91777 .70882 L
.91469 .71853 L
.91278 .72472 L
.91167 .72824 L
.90855 .73796 L
.90544 .74767 L
.90307 .75526 L
.90239 .75738 L
.89926 .76709 L
.89612 .77681 L
.89336 .78557 L
.89305 .78652 L
.8899 .79623 L
.88673 .80594 L
.88364 .81564 L
.88364 .81566 L
.88047 .82537 L
.87728 .83508 L
.87414 .84479 L
.87393 .84547 L
.87096 .85451 L
.86774 .86422 L
Mistroke
.86458 .87393 L
.86422 .87506 L
.86138 .88364 L
.85813 .89336 L
.85494 .90307 L
.85451 .90441 L
.85171 .91278 L
.84844 .92249 L
.84522 .93221 L
.84479 .93352 L
.84197 .94192 L
.83867 .95163 L
.83542 .96134 L
.83508 .96238 L
.83213 .97106 L
.82881 .98077 L
Mfstroke
.7 g
.98077 .52474 m
.97797 .53399 L
.97509 .54371 L
.97215 .55342 L
.97106 .55695 L
.96911 .56313 L
.96601 .57284 L
.963 .58256 L
.96134 .58894 L
.9603 .59227 L
.95718 .60198 L
.9541 .61169 L
.95163 .62071 L
.95141 .62141 L
.9483 .63112 L
.94517 .64083 L
.94233 .65054 L
.94192 .65225 L
.93935 .66026 L
.93619 .66997 L
.9332 .67968 L
.93221 .68357 L
.93033 .68939 L
.92715 .69911 L
.92407 .70882 L
.92249 .71466 L
.92124 .71853 L
.91805 .72824 L
.91491 .73796 L
.91278 .74553 L
.91209 .74767 L
.90888 .75738 L
.90569 .76709 L
.90307 .77616 L
.90286 .77681 L
.89964 .78652 L
.89641 .79623 L
.89351 .80594 L
.89336 .80656 L
.89032 .81566 L
.88707 .82537 L
.88407 .83508 L
.88364 .83672 L
.88094 .84479 L
.87766 .85451 L
.87459 .86422 L
.87393 .86665 L
.87147 .87393 L
.86817 .88364 L
.86505 .89336 L
.86422 .89634 L
.86193 .90307 L
.8586 .91278 L
.85544 .92249 L
.85451 .92579 L
.85231 .93221 L
.84896 .94192 L
.84576 .95163 L
.84479 .955 L
.84261 .96134 L
.83923 .97106 L
.83601 .98077 L
.98077 .98077 L
F
0 g
.98077 .52474 m
.97797 .53399 L
.97509 .54371 L
.97215 .55342 L
.97106 .55695 L
.96911 .56313 L
.96601 .57284 L
.963 .58256 L
.96134 .58894 L
.9603 .59227 L
.95718 .60198 L
.9541 .61169 L
.95163 .62071 L
.95141 .62141 L
.9483 .63112 L
.94517 .64083 L
.94233 .65054 L
.94192 .65225 L
.93935 .66026 L
.93619 .66997 L
.9332 .67968 L
.93221 .68357 L
.93033 .68939 L
.92715 .69911 L
.92407 .70882 L
.92249 .71466 L
.92124 .71853 L
.91805 .72824 L
.91491 .73796 L
.91278 .74553 L
.91209 .74767 L
.90888 .75738 L
.90569 .76709 L
.90307 .77616 L
.90286 .77681 L
.89964 .78652 L
.89641 .79623 L
.89351 .80594 L
.89336 .80656 L
.89032 .81566 L
.88707 .82537 L
.88407 .83508 L
.88364 .83672 L
.88094 .84479 L
.87766 .85451 L
.87459 .86422 L
.87393 .86665 L
.87147 .87393 L
.86817 .88364 L
.86505 .89336 L
Mistroke
.86422 .89634 L
.86193 .90307 L
.8586 .91278 L
.85544 .92249 L
.85451 .92579 L
.85231 .93221 L
.84896 .94192 L
.84576 .95163 L
.84479 .955 L
.84261 .96134 L
.83923 .97106 L
.83601 .98077 L
Mfstroke
.8 g
.98077 .54909 m
.97957 .55342 L
.97681 .56313 L
.97389 .57284 L
.97106 .58146 L
.97067 .58256 L
.96688 .59227 L
.96489 .60198 L
.96193 .61169 L
.96134 .61358 L
.95841 .62141 L
.95378 .63112 L
.95308 .64083 L
.95163 .64549 L
.94978 .65054 L
.94552 .66026 L
.94417 .66997 L
.94192 .6772 L
.94103 .67968 L
.93702 .68939 L
.9352 .69911 L
.93221 .70869 L
.93216 .70882 L
.92834 .71853 L
.92616 .72824 L
.92312 .73796 L
.92249 .73992 L
.91951 .74767 L
.91707 .75738 L
.91401 .76709 L
.91278 .77094 L
.91055 .77681 L
.90605 .78652 L
.90484 .79623 L
.90307 .80174 L
.90149 .80594 L
.89717 .81566 L
.8956 .82537 L
.89336 .83232 L
.89233 .83508 L
.88813 .84479 L
.88629 .85451 L
.88364 .86267 L
.88307 .86422 L
.87897 .87393 L
.87691 .88364 L
.87393 .89279 L
.87372 .89336 L
.86968 .90307 L
.86747 .91278 L
.86428 .92249 L
.86422 .92267 L
.86028 .93221 L
.85795 .94192 L
.85474 .95163 L
.85451 .95231 L
.85076 .96134 L
.84835 .97106 L
.84512 .98077 L
.98077 .98077 L
F
0 g
.98077 .54909 m
.97957 .55342 L
.97681 .56313 L
.97389 .57284 L
.97106 .58146 L
.97067 .58256 L
.96688 .59227 L
.96489 .60198 L
.96193 .61169 L
.96134 .61358 L
.95841 .62141 L
.95378 .63112 L
.95308 .64083 L
.95163 .64549 L
.94978 .65054 L
.94552 .66026 L
.94417 .66997 L
.94192 .6772 L
.94103 .67968 L
.93702 .68939 L
.9352 .69911 L
.93221 .70869 L
.93216 .70882 L
.92834 .71853 L
.92616 .72824 L
.92312 .73796 L
.92249 .73992 L
.91951 .74767 L
.91707 .75738 L
.91401 .76709 L
.91278 .77094 L
.91055 .77681 L
.90605 .78652 L
.90484 .79623 L
.90307 .80174 L
.90149 .80594 L
.89717 .81566 L
.8956 .82537 L
.89336 .83232 L
.89233 .83508 L
.88813 .84479 L
.88629 .85451 L
.88364 .86267 L
.88307 .86422 L
.87897 .87393 L
.87691 .88364 L
.87393 .89279 L
.87372 .89336 L
.86968 .90307 L
.86747 .91278 L
Mistroke
.86428 .92249 L
.86422 .92267 L
.86028 .93221 L
.85795 .94192 L
.85474 .95163 L
.85451 .95231 L
.85076 .96134 L
.84835 .97106 L
.84512 .98077 L
Mfstroke
.7 g
.98077 .64202 m
.97824 .65054 L
.97528 .66026 L
.97226 .66997 L
.97106 .67388 L
.96925 .67968 L
.96845 .68939 L
.96379 .69911 L
.96134 .70551 L
.9603 .70882 L
.95728 .71853 L
.95505 .72824 L
.95163 .73688 L
.95129 .73796 L
.94824 .74767 L
.94629 .75738 L
.94226 .76709 L
.94192 .76803 L
.93914 .77681 L
.93749 .78652 L
.93323 .79623 L
.93221 .79897 L
.92998 .80594 L
.92865 .81566 L
.92414 .82537 L
.92249 .82966 L
.92074 .83508 L
.91974 .84479 L
.91499 .85451 L
.91278 .86011 L
.91144 .86422 L
.90831 .87393 L
.90575 .88364 L
.90307 .89032 L
.90207 .89336 L
.8989 .90307 L
.89643 .91278 L
.89336 .92028 L
.89262 .92249 L
.88943 .93221 L
.88701 .94192 L
.88364 .95 L
.88309 .95163 L
.87988 .96134 L
.87749 .97106 L
.87393 .97928 L
.87349 .98077 L
.98077 .98077 L
F
0 g
.98077 .64202 m
.97824 .65054 L
.97528 .66026 L
.97226 .66997 L
.97106 .67388 L
.96925 .67968 L
.96845 .68939 L
.96379 .69911 L
.96134 .70551 L
.9603 .70882 L
.95728 .71853 L
.95505 .72824 L
.95163 .73688 L
.95129 .73796 L
.94824 .74767 L
.94629 .75738 L
.94226 .76709 L
.94192 .76803 L
.93914 .77681 L
.93749 .78652 L
.93323 .79623 L
.93221 .79897 L
.92998 .80594 L
.92865 .81566 L
.92414 .82537 L
.92249 .82966 L
.92074 .83508 L
.91974 .84479 L
.91499 .85451 L
.91278 .86011 L
.91144 .86422 L
.90831 .87393 L
.90575 .88364 L
.90307 .89032 L
.90207 .89336 L
.8989 .90307 L
.89643 .91278 L
.89336 .92028 L
.89262 .92249 L
.88943 .93221 L
.88701 .94192 L
.88364 .95 L
.88309 .95163 L
.87988 .96134 L
.87749 .97106 L
.87393 .97928 L
.87349 .98077 L
s
.6 g
.98077 .66639 m
.97971 .66997 L
.97679 .67968 L
.97118 .68939 L
.97106 .69838 L
.9709 .69911 L
.9682 .70882 L
.96508 .71853 L
.96195 .72824 L
.96134 .73014 L
.95927 .73796 L
.95618 .74767 L
.95301 .75738 L
.95163 .76168 L
.95025 .76709 L
.94721 .77681 L
.94402 .78652 L
.94192 .79299 L
.94112 .79623 L
.93816 .80594 L
.93496 .81566 L
.93221 .82407 L
.9319 .82537 L
.92904 .83508 L
.92584 .84479 L
.92263 .85451 L
.92249 .85491 L
.91985 .86422 L
.91664 .87393 L
.9134 .88364 L
.91278 .88552 L
.91058 .89336 L
.90737 .90307 L
.90411 .91278 L
.90307 .9159 L
.90123 .92249 L
.89803 .93221 L
.89474 .94192 L
.89336 .94604 L
.8918 .95163 L
.88861 .96134 L
.88529 .97106 L
.88364 .97591 L
.8823 .98077 L
.98077 .98077 L
F
0 g
.98077 .66639 m
.97971 .66997 L
.97679 .67968 L
.97118 .68939 L
.97106 .69838 L
.9709 .69911 L
.9682 .70882 L
.96508 .71853 L
.96195 .72824 L
.96134 .73014 L
.95927 .73796 L
.95618 .74767 L
.95301 .75738 L
.95163 .76168 L
.95025 .76709 L
.94721 .77681 L
.94402 .78652 L
.94192 .79299 L
.94112 .79623 L
.93816 .80594 L
.93496 .81566 L
.93221 .82407 L
.9319 .82537 L
.92904 .83508 L
.92584 .84479 L
.92263 .85451 L
.92249 .85491 L
.91985 .86422 L
.91664 .87393 L
.9134 .88364 L
.91278 .88552 L
.91058 .89336 L
.90737 .90307 L
.90411 .91278 L
.90307 .9159 L
.90123 .92249 L
.89803 .93221 L
.89474 .94192 L
.89336 .94604 L
.8918 .95163 L
.88861 .96134 L
.88529 .97106 L
.88364 .97591 L
.8823 .98077 L
s
.5 g
.98077 .68662 m
.97795 .68939 L
.97552 .69911 L
.97364 .70882 L
.9711 .71853 L
.97106 .71869 L
.96822 .72824 L
.96522 .73796 L
.96222 .74767 L
.96134 .75053 L
.95931 .75738 L
.95631 .76709 L
.95328 .77681 L
.95163 .78215 L
.95034 .78652 L
.94734 .79623 L
.94429 .80594 L
.94192 .81354 L
.94129 .81566 L
.93831 .82537 L
.93524 .83508 L
.93221 .8447 L
.93218 .84479 L
.9292 .85451 L
.92612 .86422 L
.92303 .87393 L
.92249 .87563 L
.92003 .88364 L
.91693 .89336 L
.91382 .90307 L
.91278 .90633 L
.91079 .91278 L
.90768 .92249 L
.90454 .93221 L
.90307 .9368 L
.90148 .94192 L
.89836 .95163 L
.8952 .96134 L
.89336 .96703 L
.8921 .97106 L
.88897 .98077 L
.98077 .98077 L
F
0 g
.98077 .68662 m
.97795 .68939 L
.97552 .69911 L
.97364 .70882 L
.9711 .71853 L
.97106 .71869 L
.96822 .72824 L
.96522 .73796 L
.96222 .74767 L
.96134 .75053 L
.95931 .75738 L
.95631 .76709 L
.95328 .77681 L
.95163 .78215 L
.95034 .78652 L
.94734 .79623 L
.94429 .80594 L
.94192 .81354 L
.94129 .81566 L
.93831 .82537 L
.93524 .83508 L
.93221 .8447 L
.93218 .84479 L
.9292 .85451 L
.92612 .86422 L
.92303 .87393 L
.92249 .87563 L
.92003 .88364 L
.91693 .89336 L
.91382 .90307 L
.91278 .90633 L
.91079 .91278 L
.90768 .92249 L
.90454 .93221 L
.90307 .9368 L
.90148 .94192 L
.89836 .95163 L
.8952 .96134 L
.89336 .96703 L
.8921 .97106 L
.88897 .98077 L
s
.4 g
.98077 .70589 m
.97963 .70882 L
.97669 .71853 L
.97394 .72824 L
.97108 .73796 L
.97106 .73803 L
.96811 .74767 L
.96512 .75738 L
.96217 .76709 L
.96134 .76994 L
.95924 .77681 L
.95623 .78652 L
.95324 .79623 L
.95163 .80162 L
.9503 .80594 L
.94728 .81566 L
.94425 .82537 L
.94192 .83309 L
.9413 .83508 L
.93826 .84479 L
.93521 .85451 L
.93224 .86422 L
.93221 .86432 L
.92919 .87393 L
.92611 .88364 L
.92309 .89336 L
.92249 .89533 L
.92005 .90307 L
.91695 .91278 L
.91389 .92249 L
.91278 .9261 L
.91084 .93221 L
.90772 .94192 L
.90462 .95163 L
.90307 .95664 L
.90157 .96134 L
.89843 .97106 L
.8953 .98077 L
.98077 .98077 L
F
0 g
.98077 .70589 m
.97963 .70882 L
.97669 .71853 L
.97394 .72824 L
.97108 .73796 L
.97106 .73803 L
.96811 .74767 L
.96512 .75738 L
.96217 .76709 L
.96134 .76994 L
.95924 .77681 L
.95623 .78652 L
.95324 .79623 L
.95163 .80162 L
.9503 .80594 L
.94728 .81566 L
.94425 .82537 L
.94192 .83309 L
.9413 .83508 L
.93826 .84479 L
.93521 .85451 L
.93224 .86422 L
.93221 .86432 L
.92919 .87393 L
.92611 .88364 L
.92309 .89336 L
.92249 .89533 L
.92005 .90307 L
.91695 .91278 L
.91389 .92249 L
.91278 .9261 L
.91084 .93221 L
.90772 .94192 L
.90462 .95163 L
.90307 .95664 L
.90157 .96134 L
.89843 .97106 L
.8953 .98077 L
s
.3 g
.98077 .72612 m
.9801 .72824 L
.97721 .73796 L
.97432 .74767 L
.97135 .75738 L
.97106 .75833 L
.96829 .76709 L
.96519 .77681 L
.96228 .78652 L
.96134 .79032 L
.95948 .79623 L
.95635 .80594 L
.95333 .81566 L
.95163 .82209 L
.95059 .82537 L
.94746 .83508 L
.94436 .84479 L
.94192 .85364 L
.94164 .85451 L
.93851 .86422 L
.93536 .87393 L
.93252 .88364 L
.93221 .88496 L
.92949 .89336 L
.92631 .90307 L
.92333 .91278 L
.92249 .91605 L
.9204 .92249 L
.9172 .93221 L
.91413 .94192 L
.91278 .94691 L
.91124 .95163 L
.90802 .96134 L
.90488 .97106 L
.90307 .97755 L
.90201 .98077 L
.98077 .98077 L
F
0 g
.98077 .72612 m
.9801 .72824 L
.97721 .73796 L
.97432 .74767 L
.97135 .75738 L
.97106 .75833 L
.96829 .76709 L
.96519 .77681 L
.96228 .78652 L
.96134 .79032 L
.95948 .79623 L
.95635 .80594 L
.95333 .81566 L
.95163 .82209 L
.95059 .82537 L
.94746 .83508 L
.94436 .84479 L
.94192 .85364 L
.94164 .85451 L
.93851 .86422 L
.93536 .87393 L
.93252 .88364 L
.93221 .88496 L
.92949 .89336 L
.92631 .90307 L
.92333 .91278 L
.92249 .91605 L
.9204 .92249 L
.9172 .93221 L
.91413 .94192 L
.91278 .94691 L
.91124 .95163 L
.90802 .96134 L
.90488 .97106 L
.90307 .97755 L
.90201 .98077 L
s
.2 g
.98077 .75047 m
.97884 .75738 L
.97605 .76709 L
.97307 .77681 L
.97106 .78283 L
.96974 .78652 L
.9657 .79623 L
.96411 .80594 L
.96134 .81498 L
.96111 .81566 L
.95732 .82537 L
.95526 .83508 L
.95228 .84479 L
.95163 .84688 L
.94876 .85451 L
.94413 .86422 L
.94337 .87393 L
.94192 .87857 L
.94005 .88364 L
.93576 .89336 L
.93439 .90307 L
.93221 .91006 L
.93122 .91278 L
.92716 .92249 L
.92536 .93221 L
.92249 .94132 L
.92228 .94192 L
.91839 .95163 L
.91626 .96134 L
.91319 .97106 L
.91278 .97236 L
.90948 .98077 L
.98077 .98077 L
F
0 g
.98077 .75047 m
.97884 .75738 L
.97605 .76709 L
.97307 .77681 L
.97106 .78283 L
.96974 .78652 L
.9657 .79623 L
.96411 .80594 L
.96134 .81498 L
.96111 .81566 L
.95732 .82537 L
.95526 .83508 L
.95228 .84479 L
.95163 .84688 L
.94876 .85451 L
.94413 .86422 L
.94337 .87393 L
.94192 .87857 L
.94005 .88364 L
.93576 .89336 L
.93439 .90307 L
.93221 .91006 L
.93122 .91278 L
.92716 .92249 L
.92536 .93221 L
.92249 .94132 L
.92228 .94192 L
.91839 .95163 L
.91626 .96134 L
.91319 .97106 L
.91278 .97236 L
.90948 .98077 L
s
.3 g
.98077 .84341 m
.98036 .84479 L
.97746 .85451 L
.97448 .86422 L
.97146 .87393 L
.97106 .87525 L
.96846 .88364 L
.96704 .89336 L
.96276 .90307 L
.96134 .90689 L
.9595 .91278 L
.95861 .92249 L
.95396 .93221 L
.95163 .93828 L
.95048 .94192 L
.94744 .95163 L
.94512 .96134 L
.94192 .96943 L
.9414 .97106 L
.93833 .98077 L
.98077 .98077 L
F
0 g
.98077 .84341 m
.98036 .84479 L
.97746 .85451 L
.97448 .86422 L
.97146 .87393 L
.97106 .87525 L
.96846 .88364 L
.96704 .89336 L
.96276 .90307 L
.96134 .90689 L
.9595 .91278 L
.95861 .92249 L
.95396 .93221 L
.95163 .93828 L
.95048 .94192 L
.94744 .95163 L
.94512 .96134 L
.94192 .96943 L
.9414 .97106 L
.93833 .98077 L
s
.4 g
.98077 .86777 m
.97894 .87393 L
.976 .88364 L
.97166 .89336 L
.97106 .89976 L
.97028 .90307 L
.96739 .91278 L
.96425 .92249 L
.96134 .93153 L
.9612 .93221 L
.95847 .94192 L
.95534 .95163 L
.95218 .96134 L
.95163 .96306 L
.94948 .97106 L
.94636 .98077 L
.98077 .98077 L
F
0 g
.98077 .86777 m
.97894 .87393 L
.976 .88364 L
.97166 .89336 L
.97106 .89976 L
.97028 .90307 L
.96739 .91278 L
.96425 .92249 L
.96134 .93153 L
.9612 .93221 L
.95847 .94192 L
.95534 .95163 L
.95218 .96134 L
.95163 .96306 L
.94948 .97106 L
.94636 .98077 L
s
.5 g
.98077 .888 m
.97683 .89336 L
.97509 .90307 L
.97302 .91278 L
.97106 .92007 L
.97036 .92249 L
.96743 .93221 L
.96442 .94192 L
.96143 .95163 L
.96134 .95191 L
.95853 .96134 L
.95551 .97106 L
.95248 .98077 L
.98077 .98077 L
F
0 g
.98077 .888 m
.97683 .89336 L
.97509 .90307 L
.97302 .91278 L
.97106 .92007 L
.97036 .92249 L
.96743 .93221 L
.96442 .94192 L
.96143 .95163 L
.96134 .95191 L
.95853 .96134 L
.95551 .97106 L
.95248 .98077 L
s
.6 g
.98077 .90727 m
.97877 .91278 L
.97597 .92249 L
.97319 .93221 L
.97106 .93941 L
.9703 .94192 L
.96732 .95163 L
.96433 .96134 L
.96142 .97106 L
.96134 .97132 L
.95844 .98077 L
.98077 .98077 L
F
0 g
.98077 .90727 m
.97877 .91278 L
.97597 .92249 L
.97319 .93221 L
.97106 .93941 L
.9703 .94192 L
.96732 .95163 L
.96433 .96134 L
.96142 .97106 L
.96134 .97132 L
.95844 .98077 L
s
.7 g
.98077 .9275 m
.97932 .93221 L
.97645 .94192 L
.97354 .95163 L
.97106 .95972 L
.97055 .96134 L
.96747 .97106 L
.96438 .98077 L
.98077 .98077 L
F
0 g
.98077 .9275 m
.97932 .93221 L
.97645 .94192 L
.97354 .95163 L
.97106 .95972 L
.97055 .96134 L
.96747 .97106 L
.96438 .98077 L
s
.8 g
.98077 .95188 m
.97811 .96134 L
.97528 .97106 L
.97223 .98077 L
.98077 .98077 L
F
0 g
.98077 .95188 m
.97811 .96134 L
.97528 .97106 L
.97223 .98077 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00`_ooool2o`0000;ooooo0_l0
002Pooooo`00`_ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgJ3ooooo0033ooooo`04omgMgOl0
003o410@olc<c:7ooooo0033ooooo`04onk^k_lQ8B7o410@onk^kZ7ooooo0033ooooo`04ob4Q8Omg
MgOoMgMgoc8b<Z7ooooo0032ooooo`;o00000_ooool2o`000:3ooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0011oooo
o`;o000000?o410@ooooooooool08oooool5o`00023ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0T
ooooo`Go00009_ooool2o`000003oa0@4?oooooooooo02?ooooo00Gok^k^oc8b<_l0003o410@olc<
c00Tooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`08Oooool4o`000008oa0@4?ooooooooooonk^k_lb
<S;o0000oc8b<_o^k^h3ooooo`00@_ooool00ol0003oooooooooo`0Tooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@08?ooool01OmgMgOoV9RHoooooonHV9SoMgMg02Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A00Wooooo`03o`000?oooooooooo02Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@0Tooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B408oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00oooool003Oooooo1_l00002ooooo`Go00007Oooool6o`0000?ooooo00?oV9RHob4Q
8Oo^k^h08Oooool01Ol@413ooooooooooooooooo410@02Gooooo00?oV9RHob4Q8Oo^k^h09Oooool5
o`0002Gooooo00Go0000ooooooooooooooooo`00000Tooooo`05o`000?ooooooooooooooool00000
8oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool003oooooo
00CoA4A4omgMgOoooooo0000:?ooool00onHV9So8B4Qonk^kP0Pooooo`05o`000?oooooooooooooo
ool000009_ooool00onHV9So8B4Qonk^kP0Tooooo`04odA4A?oMgMgoooooo`0002Kooooo00Go0000
oiRHV?ooooooV9RHob4Q8@0Tooooo`05oc8b<_nHV9SooooooiRHV?lb<S808oooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool003oooooo00CogMgMoeEEEOoooooo
0000:Oooool00omgMgOoIVIVooooo`0Oooooo`05o`000?ooooooooooooooool000009oooool00omg
MgOoIVIVooooo`0Sooooo`04omgMgOmEEEGoooooo`0002Kooooo00Go0000oeEEEOl0003o410@olc<
c00Tooooo`05olc<c?l0003o0000o`000?o<c<`08oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000000oooool0043ooooo00?oMgMgolc<c?l00000:_ooool00ol0003ooooo
ooooo`0Nooooo`05oa0@4?ooooooooooooooool@4100:?ooool00ol0003oooooooooo`0Sooooo`03
ogMgMoo<c<co000002Kooooo00?oEEEEohN7Qoooool09_ooool01Ol@413o^[Zjoooooonj^[[o410@
02?ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo0010oooo
o`03onk^k_m4A4Co000002Kooooo00Go0000okZj^_ooooooV9RHoa0@400Pooooo`05ogMgMonHV9So
oooooiRHV?mgMgL09?ooool01Ol0003o^[ZjoooooonHV9So410@02Gooooo00?ok^k^odA4A?l00000
9_ooool00ooMgMgo410@oiRHV00Vooooo`05o`000?nj^[[ooooookZj^_l000008oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool0047ooooo00?oMgMgo`000?oo
ool09Oooool01OnHV9So410@o`000?lQ8B7oc<c<023ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0T
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`09_ooool00omgMgOo0000ooooo`0Vooooo`04olc<c?m4
A4Co0000oa0@42Cooooo00GoZJVYoa0@4?l0003o410@ojVYZ@0Qooooo`03oeEEEOmVIVKo000000Co
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`009?ooooooo`0004?o00000_ooool002Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`7o00000Oooool1ooooo`009?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo0Ol00001ooooo`7ooooo000T
ooooo`03o`000?oooooooooo0?oooooo?oooool1o`00007ooooo0Oooool002Cooooo00?o0000oooo
ooooool0ooooooloooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`3oooooocoo
oooo0Ol00001ooooo`7ooooo000Tooooo`;o00003oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`06
ooooo`07o`000?ooooooooooooooool0003oooooo`000002ooooo`04o`000?ooooooooooo`0000;o
oooo00?o0000ooooooooool01_ooool01?l0003oooooooooool00002ooooo`05o`000?oooooo0000
ooooool000000_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo000000;ooooo00Go0000
ooooool0003oooooo`000002ooooo`03o`000?oooooooooo00Kooooo00Wo0000ooooool0003ooooo
o`000?oooooo0000ooooool000000_ooool00ol0003oooooooooo`09ooooo`;o00000_ooool002Co
oooo00?o0000ooooooooool00oooool;ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomo
Ogl02?moOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mV
IVH02_mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00SoVIVI00?o0000ok>c/onc
/k<05?nc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mV
IVH00_mVIVH00ol0003oC4a<oda<C004oda<C003o`000?lc<c?o<c<c00;o<c<c00?o0000oda<C?m<
C4`01?m<C4`00ol0003oIVIVofIVIP02ofIVIP04o`000?moOgooOgmoo`0000?oVIVI00?o0000ok>c
/onc/k<00_nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVI
VOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Oo
0000oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo00000_nc/k<00ol0
003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Go0000ogmoOol0003oIVIVo`00
0002oda<C003o`000?lc<c?o<c<c00Oo<c<c00?o0000oda<C?l000000_mVIVH01Ol0003oOgmoo`00
0?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02Ol0003o/k>co`000?nIVIWo0000ogmo
Ool0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Co<c<c1_ooool1o`00007ooooo0Oooool0
02Cooooo00?o0000ooooooooool00oooool:ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmo
OomoOgl02?moOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIV
I_mVIVH02_mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00SoVIVI00?o0000ok>c
/onc/k<05?nc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00;oOgmo00?o0000ofIV
I_mVIVH00_mVIVH00ol0003oC4a<oda<C005oda<C003o`000?lc<c?o<c<c00;o<c<c00?o0000oda<
C?m<C4`01?m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`00
0004ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`00
0?moOgooOgmoo`0000;oIVIV00?o0000oda<C?m<C4`00_m<C4`00ol0003o<c<coc<c<`06oc<c<`07
o`000?m<C4coC4a<oda<C?l0003oIVIVo`000002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000
olc<c?o<c<`01oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l00000
0_m<C4`00ol0003o<c<coc<c<`07oc<c<`03o`000?m<C4co000000;oIVIV00Oo0000ogmoOol0003o
VIVIo`000?nc/k?o000000Soc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo
00000_m<C4`00ol0003o<c<coc<c<`04oc<c<`Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`00
0?oooooooooo00?ooooo2Onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo
00?o0000ofIVI_mVIVH03?mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00[oIVIV
00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@09oiVIV@03o`000?nc/k?o/k>c01Co/k>c
00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00;oIVIV
00?o0000oda<C?m<C4`01?m<C4`00ol0003o<c<coc<c<`02oc<c<`03o`000?m<C4coC4a<00CoC4a<
00?o0000ofIVI_mVIVH00_mVIVH01?l0003oOgmoogmoOol00003oiVIV@03o`000?nc/k?o/k>c00;o
/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`00
00;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`07o`000?m<C4co
C4a<oda<C?l0003oIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000;o/k>c00?o0000olc<c?o<
c<`01oo<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`00
0?lc<c?o<c<c00Oo<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc
/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o0000oiVIVOl000000_moOgl2o`0000;oC4a<
00?o0000oc<c<olc<c<01Olc<c<6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003ooooooooo
o`03ooooo`So/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`;o00003OmV
IVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?mo
Ogl00ol0003oVIVIoiVIV@09oiVIV@03o`000?nc/k?o/k>c01Co/k>c00?o0000oiVIVOnIVIT01?nI
VIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01Om<
C4`01?l0003o<c<coc<c<olc<c<2o`0000KoC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`04
o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o
000000?oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c
00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo00000_nc/k<0
0ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Go0000ogmoOol0003oIVIV
o`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c0_l000002Om<C4co0000ofIVI_mVIVKo0000ogmo
Ool0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Wo0000ok>c/ol0003oVIVIo`00
0?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`05oc<c<`Kooooo0Ol00001ooooo`7o
oooo000Tooooo`03o`000?oooooooooo00?ooooo1onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`00
0?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH03?mVIVH00ol0003oC4a<oda<C00Foda<C003o`00
0?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@09oiVIV@03o`00
0?nc/k?o/k>c01Go/k>c00?o0000oiVIVOnIVIT01?nIVIT01Ol0003oOgmoogmoOomoOgoo000000Go
IVIV00?o0000oda<C?m<C4`01Om<C4`01Ol0003o<c<coc<c<olc<c?o000000OoC4a<00Go0000ofIV
I_mVIVKoIVIVo`000003ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01_o<
c<`01Ol0003o/k>cok>c/onc/k?o000000?oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01?l0003o
C4a<oda<C?l00009oc<c<`07o`000?m<C4coC4a<oda<C?l0003oIVIVo`000002ogmoO`04o`000?nI
VIWoVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@05
o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<
o`0000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Wo
0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`05oc<c
<`Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo1_nc/k<00ol0003o
VIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH03?mVIVH00ol0003o
C4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003o
VIVIoiVIV@0:oiVIV@03o`000?nc/k?o/k>c01Co/k>c00?o0000oiVIVOnIVIT01?nIVIT01Ol0003o
OgmoogmoOomoOgoo000000GoIVIV00?o0000oda<C?m<C4`01Om<C4`01Ol0003o<c<coc<c<olc<c?o
000000OoC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`05o`000?nIVIWoVIVIoiVIVOl00000
0onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000onIVIT01?l0003o
OgmoogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01Ol0003oC4a<oda<C?m<
C4co000000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00008olc<c004o`00
0?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00008oc<c
<`03o`000?m<C4co000000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<co
c<c<00Koc<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o
<c<coc<c<`06oc<c<`03o`000?oooooooooo00?ooooo0Ol00001ooooo`7ooooo000Tooooo`03o`00
0?oooooooooo00?ooooo1Onc/k<00ol0003oVIVIoiVIV@0:oiVIV@;o00002_moOgl00ol0003oIVIV
ofIVIP0;ofIVIP;o00005om<C4`2o`0000goIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVI
oiVIV@0:oiVIV@03o`000?nc/k?o/k>c01Co/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmo
ogmoO`02ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01_m<C4`01Ol0003o<c<c
oc<c<olc<c?o000000KoC4a<00?o0000ofIVI_mVIVH00_mVIVH01?l0003oOgmoogmoOol00003oiVI
V@03o`000?nc/k?o/k>c00;o/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c
/`04o`000?nIVIWoVIVIo`0000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000003oda<C003o`000?lc
<c?o<c<c00Go<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP06o`000?moOgooOgmoo`000?nI
VIWo00000_nc/k<00ol0003oc<c<olc<c007olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Go0000
ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00?o0000oda<C?l000000_mV
IVH01ol0003oOgmoo`000?nIVIWo0000ok>c/ol000002Oo<c<`02Ol0003o/k>co`000?nIVIWo0000
ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00?o0000ooooooooool00ooo
ool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool4ok>c/`03o`000?nIVIWo
VIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4co
C4a<01KoC4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWo
VIVI00[oVIVI00?o0000ok>c/onc/k<05Onc/k<00ol0003oVIVIoiVIV@03oiVIV@03o`000?moOgoo
Ogmo00?oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C007oda<C003o`000?lc<c?o
000000OoC4a<00?o0000ofIVI_mVIVH00_mVIVH01?l0003oOgmoogmoOol00003oiVIV@03o`000?nc
/k?o/k>c00;o/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nI
VIWoVIVIo`0000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000003oda<C003o`000?lc<c?o<c<c00Go
<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP06o`000?moOgooOgmoo`000?nIVIWo00000_nc
/k<00ol0003oc<c<olc<c007olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Go0000ogmoOol0003o
IVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00?o0000oda<C?l000000_mVIVH01ol0003o
Ogmoo`000?nIVIWo0000ok>c/ol000002Oo<c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0003o
IVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00?o0000ooooooooool00oooool1o`00007o
oooo0Oooool002Cooooo00?o0000ooooooooool00oooool3ok>c/`03o`000?nIVIWoVIVI00_oVIVI
00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<
00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00[oVIVI
00?o0000ok>c/onc/k<05Onc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00;oOgmo
00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C006oda<C0Co00001om<C4`00ol0003oIVIV
ofIVIP02ofIVIP04o`000?moOgooOgmoo`0000?oVIVI00?o0000ok>c/onc/k<00_nc/k<00ol0003o
c<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01Ol0
003oIVIVofIVI_mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l0
0002ofIVIP06o`000?moOgooOgmoo`000?nIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c004
o`000?nc/k?o/k>co`0000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o
<c<c00Oo<c<c00?o0000oda<C?l000000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o
0000olc<c?o<c<`01_o<c<`01ol0003o/k>co`000?nIVIWo0000ogmoOol000000_mVIVH01?l0003o
C4a<oda<C?l00007oc<c<`03o`000?oooooooooo00Cooooo0Ol00001ooooo`7ooooo000Tooooo`03
o`000?oooooooooo00?ooooo0_nc/k<00ol0003oVIVIoiVIV@0:oiVIV@;o00002_moOgl00ol0003o
IVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<0_l0000=ofIVIP03o`000?moOgooOgmo00So
Ogmo00?o0000oiVIVOnIVIT02_nIVIT00ol0003o/k>cok>c/`0Eok>c/`03o`000?nIVIWoVIVI00Co
VIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<00Go
C4a<00Go0000oc<c<olc<c?o<c<co`000007oda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl0
1Ol0003oVIVIoiVIVOnIVIWo000000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c
/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o
<c<coc<c<`07oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Ko0000ogmoOomoOgoo0000oiVIVOl0
0003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT01Ol0003oOgmo
o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01olc<c<00ol0003oC4a<o`000002ofIVIP05
o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c008o`000?nc/k?o0000
oiVIVOl0003oOgmoo`000?mVIVH2o`000003oda<C?l0003o<c<c00Oo<c<c00?o0000ooooooooool0
1?ooool1o`00007ooooo0Oooool002Cooooo0_l00004ooooo`03ok>c/ol0003oVIVI00coVIVI00?o
0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o
0000ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o
0000ok>c/onc/k<05Onc/k<00ol0003oVIVIoiVIV@04oiVIV@05o`000?moOgooOgmoogmoOol00000
1_mVIVH00ol0003oC4a<oda<C005oda<C005o`000?lc<c?o<c<coc<c<ol000001om<C4`01Ol0003o
IVIVofIVI_mVIVKo000000?oOgmo00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<co
c<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mV
IVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;o
IVIV00Ko0000ogmoOomoOgoo0000oiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Goc<c<00Go0000
ok>c/onc/k?o/k>co`000002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<c
oc<c<`07oc<c<`03o`000?m<C4co000000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03
o`000?o<c<coc<c<00Koc<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<
C4`00ol0003o<c<coc<c<`06oc<c<`03o`000?oooooooooo00?ooooo0_l00002ooooo`009?ooool0
0ol0003oooooooooo`03ooooo`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl0
0ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02omVIVH0
0ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05Onc/k<0
0ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH00omVIVH0
0ol0003oC4a<oda<C005oda<C005o`000?lc<c?o<c<coc<c<ol000001om<C4`01Ol0003oIVIVofIV
I_mVIVKo000000?oOgmo00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Go
c<c<00?o0000ok>c/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Co0000ofIV
I_mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mV
IVH01?l0003oOgmoogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00_o0000ok>c/onc
/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c
00?o0000oda<C?l000000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<
c<`01_o<c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc
<c?o<c<c00Ko<c<c00?o0000oda<C?ooool01Oooool1o`00007ooooo0Oooool002Cooooo00?o0000
ooooooooool00oooool=oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH0
0ol0003oC4a<oda<C00Foda<C0;o00003OmVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWo
VIVI00_oVIVI00?o0000ok>c/onc/k<05Onc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgoo
Ogmo00;oOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C006oda<C0;o000000?o<c<c
o`000?m<C4`01_m<C4`00ol0003oIVIVofIVIP02ofIVIP04o`000?moOgooOgmoo`0000?oVIVI00?o
0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c004olc<c0;o00000onc/k<01Ol0003oVIVIoiVI
VOnIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`05
o`000?m<C4coC4a<oda<C?l000000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>c
o`0000Woc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`03o`000?mVIVKo000000;oC4a<
00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP05o`000?moOgoo0000oiVI
VOl000000_nc/k<00ol0003oc<c<olc<c006olc<c00;o`000?nc/k?o0000oiVIVOl0003oOgmoo`00
0?mVIVKo0000oda<C?l000002Olc<c<00ol0003oC4a<ooooo`05ooooo`7o00000Oooool1ooooo`00
9?ooool00ol0003oooooooooo`03ooooo`coVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIV
ofIVIP0:ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003oOgmo
ogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVI
oiVIV@04oiVIV@03o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<
oda<C008oda<C003o`000?m<C4coC4a<00KoC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`05
o`000?nIVIWoVIVIoiVIVOl000001Onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c
00;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o
0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o0000ogmoOol00000
0_nIVIT01?l0003o/k>cok>c/ol00009olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl0
0ol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mV
IVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02ol0003o/k>c
o`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co000000Wo<c<c00?o0000oda<C?l000001Ooo
ool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool;oiVIV@03o`000?moOgoo
Ogmo00WoOgmo00?o0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKo
IVIV00coIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o
/k>c01Ko/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKo
IVIV00?oIVIV00?o0000oda<C?m<C4`04Om<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Go
0000oiVIVOnIVIWoVIVIo`000005ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<0
0_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0
003o<c<coc<c<`06oc<c<`03o`000?m<C4coC4a<00;oC4a<00Go0000ofIVI_l0003oOgmoo`000002
oiVIV@04o`000?nc/k?o/k>co`0000Woc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`04
o`000?mVIVKoIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01Olc<c<01?l0003oC4a<oda<C?l00002
ofIVIP03o`000?moOgoo000000;oVIVI00?o0000ok>c/ol000002?o<c<`02Ol0003o/k>co`000?nI
VIWo0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<
C4co00001Oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool:oiVIV@03
o`000?moOgooOgmo00SoOgmo0_l0000<ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mV
IVH02omVIVH2o`0000[oOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Eok>c/`;o
00001_nIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<
C4`04_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Go0000oiVIVOnIVIWoVIVIo`000004
ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl0
0003ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<
oda<C?m<C4co000000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00009olc<
c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc
<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH01ol0003oOgmoo`000?nIVIWo0000ok>c
/ol000002Oo<c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003o`00
0?lc<c?o<c<c00Ko<c<c00?o0000oda<C?l000001_ooool1o`00007ooooo0Oooool002Cooooo00?o
0000ooooooooool00oooool9oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omV
IVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl02?mo
Ogl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT01?nI
VIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<C4`04_m<
C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03
o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00003ogmo
O`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<
C4co000000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00009olc<c006o`00
0?nc/k?o/k>co`000?nIVIWo00000_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c
00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH01ol0003oOgmoo`000?nIVIWo0000ok>c/ol00000
2Oo<c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o
<c<c00Ko<c<c00?o0000oda<C?l000001_ooool1o`00007ooooo0Oooool002Cooooo00?o0000oooo
ooooool00oooool8oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0
003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl02?moOgl00ol0
003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT01OnIVIT00ol0
003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`04_m<C4`01Ol0
003oIVIVofIVI_mVIVKo000000?oOgmo00Go0000oiVIVOnIVIWoVIVIo`000005ok>c/`03o`000?o<
c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo
00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<
C?l000000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Woc<c<00Co0000
ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<0
1olc<c<00ol0003oC4a<o`000002ofIVIP03o`000?moOgooOgmo00;o00000_nc/k<00ol0003oc<c<
olc<c006olc<c003o`000?nc/k?o000000;oVIVI0_l00002ofIVIP04o`000?m<C4coC4a<o`0000So
<c<c00?o0000oda<C?l000001_ooool1o`00007ooooo0Oooool001_ooooo0_l000000ol@413ooooo
ooooo`04ooooo`03o`000?oooooooooo00?ooooo1onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`00
0?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP;o0000
2_moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT0
1OnIVIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`0
4_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Co0000oiVIVOnIVIWoVIVI0_l00004ok>c
/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002
ogmoO`03o`000?mVIVKoIVIV00;o00000om<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4co
C4a<o`0000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01?l0003o/k>cok>c/ol00008olc<c007
o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000
oc<c<olc<c<01olc<c<00ol0003oC4a<o`000002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc
/k<00ol0003oc<c<olc<c006olc<c003o`000?nc/k?o000000;oVIVI0_l00002ofIVIP03o`000?m<
C4co000000So<c<c00Co0000oda<C?m<C4co00001_ooool1o`00007ooooo0Oooool001cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`GoVIVI0_l0000:ogmoO`03o`000?mV
IVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0:ofIVIP03o`000?mo
OgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nI
VIWoVIVI00GoVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIVIP02ofIVIP03o`000?m<
C4coC4a<01;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`05o`000?nIVIWoVIVIoiVIVOl0
00001Onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Co0000oiVIVOnI
VIWo00000_moOgl01?l0003oIVIVofIVI_l00004oda<C003o`000?lc<c?o<c<c00Go<c<c00Go0000
oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o
00002?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@06o`000?moOgooOgmoo`000?mVIVKo00000_m<
C4`00ol0003o<c<coc<c<`07oc<c<`05o`000?m<C4co0000ofIVI_l000000_moOgl00ol0003oVIVI
o`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o0000ok>c/ol000000_nIVIT2o`000005ofIV
I_l0003oC4a<oda<C?l000002?lc<c<01?l0003oC4a<oda<C?l00006ooooo`7o00000Oooool1oooo
o`004Oooool6o`0000;ooooo1Ol00006ooooo`?o00000oooool4oiVIV@03o`000?moOgooOgmo00Wo
Ogmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C0;o00003?mVIVH00ol0003o
OgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003o
VIVIoiVIV@05oiVIV@03o`000?moOgooOgmo00?oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003o
C4a<oda<C00Boda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01Ol0003oVIVIoiVIVOnIVIWo
000000Go/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWo
VIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`06oc<c<`04o`00
0?m<C4coC4a<o`0000?oIVIV00Ko0000ogmoOomoOgoo0000oiVIVOl00003ok>c/`03o`000?o<c<co
c<c<00Goc<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo00?o0000ofIVI_l00000
0_m<C4`00ol0003o<c<coc<c<`07oc<c<`03o`000?m<C4co000000;oIVIV00Go0000ogmoOol0003o
VIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003o
Ogmoo`000?mVIVKo0000oda<C?l00009oc<c<`05o`000?m<C4co0000ofIVI_l000000oooool3o`00
00;ooooo000Iooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool00oooool3oiVI
V@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<
C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0;oiVI
V@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT01OnIVIT00ol0003oOgmoogmoO`03ogmo
O`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<C4`04Om<C4`00ol0003oIVIVofIVIP02ofIV
IP05o`000?moOgooOgmoogmoOol000000onIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<co
c<c<00Coc<c<00?o0000ok>c/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Co
0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l0
00000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Oo0000
ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<c
oc<c<`06oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl00ol0003oVIVIo`000002ok>c
/`03o`000?o<c<coc<c<00Koc<c<00?o0000ok>c/ol000000_nIVIT01ol0003oOgmoo`000?mVIVKo
0000oda<C?l000002Olc<c<2o`000003ofIVI_l0003ooooo00Gooooo0Ol00001ooooo`7ooooo000I
ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool00oooool2oiVIV@;o00002_mo
Ogl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02_mV
IVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05onc
/k<00ol0003oVIVIoiVIV@05oiVIV@03o`000?moOgooOgmo00CoOgmo00?o0000ofIVI_mVIVH00omV
IVH00ol0003oC4a<oda<C00Aoda<C003o`000?mVIVKoIVIV00;oIVIV00Co0000ogmoOomoOgoo0000
1?nIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<0
0_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0
003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol0
0002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo0000
00;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`06o`000?m<C4coC4a<
o`000?mVIVKo00000_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o
0000ok>c/ol000000_nIVIT2o`0000;oIVIV00?o0000oda<C?l000002Olc<c<2o`000003ofIVI_l0
003ooooo00Gooooo0Ol00001ooooo`7ooooo000Jooooo`03ogMgMoo<c<co000000Oooooo00?o0000
ooooooooool00oooool00onIVIWo0000ogmoO`0:ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000
oda<C?m<C4`05_m<C4`2o`0000coIVIV00?o0000ogmoOomoOgl02?moOgl2o`0000goVIVI00?o0000
ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@05oiVIV@03o`000?moOgooOgmo00CoOgmo00?o0000
ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00Aoda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000
ogmoOomoOgooOgmoo`000003oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`01?o<
c<`00ol0003o/k>cok>c/`02ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01?l0003oIVIV
ofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIV
IP04o`000?moOgooOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01ol0003o/k>cok>c
/onc/k?o0000oiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00002oda<C003o`000?lc<c?o<c<c
00Ko<c<c00Go0000oda<C?l0003oIVIVo`000002ogmoO`06o`000?nIVIWoVIVIo`000?nc/k?o0000
2?o<c<`00ol0003o/k>co`000002oiVIV@07o`000?moOgoo0000ofIVI_l0003oC4a<o`000009oc<c
<`05o`000?m<C4co0000o`000?moOgl01_ooool1o`00007ooooo0Oooool001[ooooo00?ok^k^odA4
A?l000001oooool00ol0003oooooooooo`03ooooo`03o`000?moOgooOgmo00WoOgmo00?o0000ofIV
I_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmo
OomoOgl02?moOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVI
VOnIVIT01OnIVIT00ol0003oOgmoogmoO`04ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<
C?m<C4`04_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Co0000oiVIVOnIVIWoVIVI0_l0
0004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVI
VOl00003ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003o
C4a<oda<C?m<C4co000000;oIVIV00Ko0000ogmoOomoOgoo0000oiVIVOl00003ok>c/`03o`000?o<
c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT01_l0003oOgmoo`000?l0003oIVIVo`00
00;oC4a<00?o0000oc<c<olc<c<01_lc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00Go
0000oiVIVOl0003o/k>co`000009olc<c003o`000?nc/k?o000000;oVIVI00Oo0000ogmoOol0003o
IVIVo`000?m<C4co000000So<c<c00?o0000oda<C?m<C4`00_l000000omoOgooooooooooo`04oooo
o`7o00000Oooool1ooooo`006oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo00?o
oooo00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<01Ko
C4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00_o
VIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@06oiVIV@03o`000?moOgooOgmo00Co
Ogmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C00Coda<C005o`000?mVIVKoIVIVofIV
I_l000000omoOgl01Ol0003oVIVIoiVIVOnIVIWo000000Go/k>c00?o0000olc<c?o<c<`01Oo<c<`0
0ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000?oOgmo00Co0000ofIVI_mVIVKo0000
0om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01_l0003o
OgmoogmoOol0003oVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol0
0002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<02?l0003oC4a<
oda<C?l0003oIVIVo`000?moOgoo00000_nIVIT00ol0003o/k>co`000009olc<c003o`000?nc/k?o
000000;oVIVI00Oo0000ogmoOol0003oIVIVo`000?m<C4co000000So<c<c00?o0000oda<C?m<C4`0
0_l000000omoOgooooooooooo`04ooooo`7o00000Oooool1ooooo`009?ooool00ol0003ooooooooo
o`03ooooo`[oOgmo00?o0000ofIVI_mVIVH03?mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mV
IVKoIVIV00[oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc
/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT01onIVIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mV
IVKoIVIV00?oIVIV00?o0000oda<C?m<C4`04_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000CoOgmo
00Go0000oiVIVOnIVIWoVIVIo`000005ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc
/k<00onc/k<01?l0003oVIVIoiVIVOl00003ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000
oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C006o`000?mVIVKoIVIVo`000?moOgoo0000
0_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Ooc<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo
000000;oOgmo00Co0000ofIVI_mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`08o`000?m<
C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVIV@03o`000?nc/k?o000000Woc<c<00Go0000ok>c
/ol0003oVIVIo`000002ogmoO`04o`000?mVIVKo0000o`0000Wo<c<c00?o0000oda<C?m<C4`00_l0
00000omoOgoo0000ooooo`04ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03
ooooo`WoOgmo00?o0000ofIVI_mVIVH03?mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKo
IVIV00[oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o
/k>c01So/k>c00?o0000oiVIVOnIVIT01_nIVIT00ol0003oOgmoogmoO`04ogmoO`03o`000?mVIVKo
IVIV00;oIVIV00?o0000oda<C?m<C4`04om<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Go
0000oiVIVOnIVIWoVIVIo`000005ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<0
0_nc/k<01?l0003oVIVIoiVIVOl00003ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c
<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nI
VIT01?l0003o/k>cok>c/ol00008olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol0
00000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_mo
Ogl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o0000ok>c/ol000000_nI
VIT01ol0003oOgmoo`000?mVIVKo0000oda<C?l000002Olc<c<01ol0003oC4a<o`000?mVIVKo0000
ogmoOol000001Oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool8ogmo
O`;o00003OmVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmo
OomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01So/k>c00?o0000oiVI
VOnIVIT01_nIVIT00ol0003oOgmoogmoO`04ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<
C?m<C4`04_m<C4`00ol0003oIVIVofIVIP02ofIVIP05o`000?moOgooOgmoogmoOol000000onIVIT0
0ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00onc/k<0
1?l0003oVIVIoiVIVOl00002ogmoO`05o`000?mVIVKoIVIVofIVI_l000000om<C4`00ol0003o<c<c
oc<c<`06oc<c<`06o`000?m<C4coC4a<oda<C?l0003oIVIV0_l000001OmoOgoo0000oiVIVOnIVIWo
000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?mo
Ogoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<01_l0003oC4a<oda<C?l0003oIVIVo`00
00;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c003o`000?nc/k?o0000
00;oVIVI00Oo0000ogmoOol0003oIVIVo`000?m<C4co000000So<c<c00Go0000oda<C?m<C4co0000
ofIVIP02o`0000Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo1omo
Ogl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omV
IVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<06?nc
/k<00ol0003oVIVIoiVIV@07oiVIV@03o`000?moOgooOgmo00?oOgmo00?o0000ofIVI_mVIVH01?mV
IVH00ol0003oC4a<oda<C00Boda<C003o`000?mVIVKoIVIV00;oIVIV00Co0000ogmoOomoOgoo0000
1?nIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<0
0onc/k<01?l0003oVIVIoiVIVOl00002ogmoO`05o`000?mVIVKoIVIVofIVI_l000000om<C4`00ol0
003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Co0000ogmoOomoOgoo00000_nI
VIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0003o
Ogmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Ko0000oda<C?m<C4co0000ofIVI_l0
0002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003o/k>co`00
0002oiVIV@04o`000?moOgoo0000o`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<
oda<C?l0003oIVIV00;o00001_ooool1o`00007ooooo0Oooool002Cooooo0_l00004ooooo`KoOgmo
00?o0000ofIVI_mVIVH03?mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV
00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01So/k>c
00?o0000oiVIVOnIVIT01onIVIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00CoIVIV
00?o0000oda<C?m<C4`04_m<C4`00ol0003oIVIVofIVIP02ofIVIP05o`000?moOgooOgmoogmoOol0
00000onIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc
/k<00onc/k<01?l0003oVIVIoiVIVOl00002ogmoO`05o`000?mVIVKoIVIVofIVI_l000000om<C4`0
0ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH00ol0003oOgmoo`00
0002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@03
o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<01_l0003oC4a<oda<C?l0003o
IVIVo`0000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c00<o`000?nc
/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co00002?lc<c<02?l0003oC4a<oda<
C?l0003oIVIVo`000?moOgoo00001Oooool2o`0000;ooooo000Tooooo`03o`000?oooooooooo00?o
oooo1OmoOgl00ol0003oIVIVofIVIP0;ofIVIP;o00005om<C4`2o`0000goIVIV00?o0000ogmoOomo
Ogl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01So/k>c00?o0000oiVIVOnI
VIT01onIVIT00ol0003oOgmoogmoO`04ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<
C4`04_m<C4`00ol0003oIVIVofIVIP02ofIVIP05o`000?moOgooOgmoogmoOol000000onIVIT00ol0
003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01Ol0
003oVIVIoiVIVOnIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c
<`06oc<c<`03o`000?m<C4coC4a<00;oC4a<00Ko0000ofIVI_mVIVKo0000ogmoOol00002oiVIV@04
o`000?nc/k?o/k>co`0000Woc<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002
ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`03
o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003o/k>co`000002oiVIV@07
o`000?moOgoo0000ofIVI_l0003oC4a<o`000008oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000
ogmoOol00006ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`CoOgmo
00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00coIVIV
00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01So/k>c
00?o0000oiVIVOnIVIT02?nIVIT00ol0003oOgmoogmoO`04ogmoO`03o`000?mVIVKoIVIV00?oIVIV
00?o0000oda<C?m<C4`04_m<C4`00ol0003oIVIVofIVIP02ofIVIP05o`000?moOgooOgmoogmoOol0
00000onIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc
/k<00onc/k<01?l0003oVIVIoiVIVOl00002ogmoO`05o`000?mVIVKoIVIVofIVI_l000000om<C4`0
0ol0003o<c<coc<c<`06oc<c<`03o`000?m<C4coC4a<00;oC4a<00Ko0000ofIVI_mVIVKo0000ogmo
Ool00002oiVIV@04o`000?nc/k?o/k>co`0000Woc<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0
003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Ko0000oda<C?m<C4co0000ofIV
I_l00002ogmoO`;o00000onc/k<00ol0003oc<c<olc<c006olc<c003o`000?nc/k?o000000;oVIVI
0_l00002ofIVIP03o`000?m<C4co000000So<c<c00So0000oda<C?m<C4co0000ofIVI_l0003oOgmo
o`0000Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo0omoOgl00ol0
003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0
003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<06?nc/k<00ol0
003oVIVIoiVIV@08oiVIV@03o`000?moOgooOgmo00CoOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0
003oC4a<oda<C00Boda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgooOgmoo`000003
oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02
ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000?oC4a<
00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C006o`000?mVIVKoIVIVo`000?mo
Ogoo00000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Co0000ok>c/onc/k?o00000_nI
VIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Ko0000oda<C?m<C4co
0000ofIVI_l00002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0
003o/k>co`000002oiVIV@07o`000?moOgoo0000ofIVI_l0003oC4a<o`000008oc<c<`0:o`000?m<
C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000Gooooo0Ol00001ooooo`7ooooo000Toooo
o`03o`000?oooooooooo00?ooooo0_moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<
01KoC4a<0_l0000=ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0
003o/k>cok>c/`0Gok>c/`;o00002OnIVIT2o`0000KoOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0
003oC4a<oda<C00Coda<C005o`000?mVIVKoIVIVofIVI_l000001?moOgl01Ol0003oVIVIoiVIVOnI
VIWo000000Go/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`04o`000?nI
VIWoVIVIo`0000?oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`05oc<c<`05
o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@05o`000?nc/k?o
/k>cok>c/ol000002?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV
00Co0000oda<C?m<C4co00002?lc<c<02?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo00000_nI
VIT00ol0003o/k>co`000009olc<c003o`000?nc/k?o000000;oVIVI00Oo0000ogmoOol0003oIVIV
o`000?m<C4co000000So<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000
1Oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool00omoOgoo0000ofIV
IP0<ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmo
O`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<2o`0000_oVIVI00?o
0000ogmoOomoOgl01?moOgl00ol0003oIVIVofIVIP04ofIVIP03o`000?m<C4coC4a<01;oC4a<00?o
0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000CoVIVI00?o0000ok>c/onc/k<0
0onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Co0000oiVIVOnIVIWo
00000omoOgl01?l0003oIVIVofIVI_l00004oda<C003o`000?lc<c?o<c<c00Go<c<c00Go0000oda<
C?m<C4coC4a<o`000002ofIVIP03o`000?moOgoo000000?oVIVI00Go0000ok>c/onc/k?o/k>co`00
0007olc<c007o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`00
00;oC4a<00?o0000oc<c<olc<c<01_lc<c<02?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000
0_nIVIT00ol0003o/k>co`000009olc<c003o`000?nc/k?o000000;oVIVI00Oo0000ogmoOol0003o
IVIVo`000?m<C4co000000So<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo
00001Oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool00ol0003oIVIV
ofIVIP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmo
ogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVI
oiVIV@0:oiVIV@03o`000?moOgooOgmo00CoOgmo00?o0000ofIVI_mVIVH01?mVIVH00ol0003oC4a<
oda<C00Coda<C005o`000?mVIVKoIVIVofIVI_l000001?moOgl01Ol0003oVIVIoiVIVOnIVIWo0000
00Go/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`04o`000?nIVIWoVIVI
o`0000?oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`05oc<c<`05o`000?m<
C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00003oiVIV@04o`000?nc/k?o/k>co`00
00Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4co
C4a<o`0000So<c<c00So0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000;oVIVI00Co0000ok>c
/onc/k?o00002?o<c<`00ol0003o/k>co`000002oiVIV@07o`000?moOgoo0000ofIVI_l0003oC4a<
o`000009oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000Kooooo0Ol00001
ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo3OmVIVH00ol0003oC4a<oda<C00Foda<
C0;o00003OmVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c
/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0:oiVIV@03o`000?moOgooOgmo00CoOgmo00?o0000ofIV
I_mVIVH01?mVIVH00ol0003oC4a<oda<C00Coda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmo
OomoOgooOgmoo`000003oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`01?o<c<`0
0ol0003o/k>cok>c/`02ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01Ol0003oIVIVofIV
I_mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;o
IVIV00Co0000ogmoOomoOgoo00000_nIVIT01?l0003o/k>cok>c/ol00008olc<c005o`000?nc/k?o
/k>cok>c/ol000000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000?oC4a<00?o0000oc<c<olc<c<0
1_lc<c<02?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo00000_nIVIT01?l0003o/k>cok>c/ol0
0008olc<c003o`000?nc/k?o000000;oVIVI00Oo0000ogmoOol0003oIVIVo`000?m<C4co000000So
<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00001_ooool1o`00007ooooo
0Oooool002Cooooo00?o0000ooooooooool00oooool<ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o
0000ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o
0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0:oiVIV@03o`000?moOgooOgmo00GoOgmo00?o
0000ofIVI_mVIVH01?mVIVH00ol0003oC4a<oda<C00Coda<C003o`000?mVIVKoIVIV00;oIVIV00Go
0000ogmoOomoOgooOgmoo`000003oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`0
1?o<c<`00ol0003o/k>cok>c/`02ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01Ol0003o
IVIVofIVI_mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co
000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01?l0003o/k>cok>c/ol00008olc<c005o`00
0?nc/k?o/k>cok>c/ol000000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000?oC4a<00?o0000oc<c
<olc<c<01_lc<c<02?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo00000_nIVIT01?l0003o/k>c
ok>c/ol00008olc<c003o`000?nc/k?o000000;oVIVI00Oo0000ogmoOol0003oIVIVo`000?m<C4co
000000So<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00001_ooool1o`00
007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool;ofIVIP03o`000?m<C4coC4a<01Ko
C4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_o
VIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00Co
Ogmo00?o0000ofIVI_mVIVH01?mVIVH00ol0003oC4a<oda<C00Coda<C003o`000?mVIVKoIVIV00;o
IVIV00Go0000ogmoOomoOgooOgmoo`000003oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<
c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Go0000
ofIVI_mVIVKoIVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<
o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`01?l0
003o/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l000000om<C4`00ol0003o<c<coc<c
<`06oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVIV@04o`000?nc/k?o/k>c
o`0000Soc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00008
oc<c<`0;o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k<01_ooool1o`00
007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool:ofIVIP03o`000?m<C4coC4a<01Ko
C4a<00?o0000ofIVI_mVIVH02omVIVH2o`0000[oOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o
/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl01?moOgl2o`0000Go
IVIV00?o0000oda<C?m<C4`04om<C4`00ol0003oIVIVofIVIP02ofIVIP05o`000?moOgooOgmoogmo
Ool000001?nIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c
/onc/k<00onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo00001?m<
C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01_l0003oOgmo
ogmoOol0003oVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01oo<c<`01_l0003o/k>cok>c/ol0003o
VIVIo`0000;oOgmo00?o0000ofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`08o`000?m<
C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00?o0000
ok>c/ol000000_nIVIT01ol0003oOgmoo`000?mVIVKo0000oda<C?l000002?lc<c<03?l0003oC4a<
oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Gooooo0Ol00001ooooo`7ooooo
000Tooooo`;o00001?ooool9ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH03?mV
IVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc
/k<2o`0000coVIVI00?o0000ogmoOomoOgl01OmoOgl00ol0003oIVIVofIVIP04ofIVIP03o`000?m<
C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000CoVIVI
00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c
00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c
<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Ko0000ogmoOomoOgoo0000oiVI
VOl00003ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmo
O`03o`000?mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<02_l0003oC4a<oda<C?l0003o
IVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00?o0000ok>c/ol0
00000_nIVIT01ol0003oOgmoo`000?mVIVKo0000oda<C?l000002?lc<c<03?l0003oC4a<oda<C?l0
003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Cooooo0_l00002ooooo`009?ooool00ol0
003oooooooooo`03ooooo`SoIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0<ofIV
IP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c
/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl01OmoOgl00ol0003oIVIVofIVIP04ofIV
IP03o`000?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH00_mVIVH00ol0003oOgmoogmoO`02ogmo
O`05o`000?nIVIWoVIVIoiVIVOl000001Onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o
/k>c00?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<
00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Ko0000ogmoOomo
Ogoo0000oiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Ko0000ok>c/onc/k?o0000oiVI
VOl00002ogmoO`03o`000?mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<02?l0003oC4a<
oda<C?l0003oIVIVo`000?moOgoo00000_nIVIT01?l0003o/k>cok>c/ol00008olc<c003o`000?nc
/k?o000000;oVIVI00Oo0000ogmoOol0003oIVIVo`000?m<C4co000000Wo<c<c00_o0000oda<C?l0
003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`000006ooooo`7o00000Oooool1ooooo`009?oo
ool00ol0003oooooooooo`03ooooo`OoIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIV
IP0;ofIVIP;o00002_moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o
0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV00CoIVIV00?o
0000oda<C?m<C4`04om<C4`00ol0003oIVIVofIVIP02ofIVIP03o`000?moOgooOgmo00;oOgmo00Go
0000oiVIVOnIVIWoVIVIo`000006ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<0
0_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0
003o<c<coc<c<`05oc<c<`05o`000?m<C4coC4a<oda<C?l000000omVIVH00ol0003oOgmoo`000002
oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01ol0003o/k>cok>c/onc/k?o0000oiVIVOl0
00000_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00So0000oda<C?m<
C4co0000ofIVI_l0003oOgmoo`0000;oVIVI00?o0000ok>c/ol000002Oo<c<`00ol0003o/k>co`00
0002oiVIV@07o`000?moOgoo0000ofIVI_l0003oC4a<o`000009oc<c<`0;o`000?m<C4co0000ofIV
I_l0003oOgmoo`000?nIVIWo0000ok>c/ol000001_ooool1o`00007ooooo0Oooool002Cooooo00?o
0000ooooooooool00oooool6ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02_mV
IVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc
/k<2o`0000coVIVI00?o0000ogmoOomoOgl01OmoOgl00ol0003oIVIVofIVIP05ofIVIP03o`000?m<
C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH00_mVIVH00ol0003oOgmoogmoO`02ogmoO`05o`000?nI
VIWoVIVIoiVIVOl000001Onc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c
00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c
<olc<c<01Olc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nI
VIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo0000
00;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`08o`000?m<C4coC4a<
o`000?mVIVKo0000ogmoOol00002oiVIV@03o`000?nc/k?o000000Woc<c<00?o0000ok>c/ol00000
0_nIVIT01ol0003oOgmoo`000?mVIVKo0000oda<C?l000002Olc<c<02ol0003oC4a<o`000?mVIVKo
0000ogmoOol0003oVIVIo`000?nc/k?o000000Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`00
0?oooooooooo00?ooooo1OmVIVH00ol0003oC4a<oda<C00Foda<C0;o00003?mVIVH00ol0003oOgmo
ogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVI
oiVIV@0;oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH01?mVIVH00ol0003oC4a<
oda<C00Coda<C003o`000?mVIVKoIVIV00?oIVIV00Go0000ogmoOomoOgooOgmoo`000004oiVIV@03
o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`04
o`000?nIVIWoVIVIo`0000?oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`05
oc<c<`03o`000?m<C4coC4a<00;oC4a<00Ko0000ofIVI_mVIVKo0000ogmoOol00002oiVIV@03o`00
0?nc/k?o/k>c00;o/k>c00?o0000olc<c?o<c<`01_o<c<`01_l0003o/k>cok>c/ol0003oVIVIo`00
00;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`06o`000?m<C4coC4a<
o`000?mVIVKo00000_moOgl01Ol0003oVIVIo`000?nc/k?o000000Woc<c<00?o0000ok>c/ol00000
0_nIVIT01ol0003oOgmoo`000?mVIVKo0000oda<C?l000002Olc<c<00ol0003oC4a<oda<C002o`00
0007ogmoOol0003oVIVIo`000?nc/k?o0000olc<c006ooooo`7o00000Oooool1ooooo`009?ooool0
0ol0003oooooooooo`03ooooo`CoIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;
ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0F
ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl01_moOgl00ol0003oIVIVofIVIP04
ofIVIP;o00005Om<C4`00ol0003oIVIVofIVIP02ofIVIP05o`000?moOgooOgmoogmoOol000001?nI
VIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00onc
/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000003oda<C003
o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmo
o`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c004o`000?nc/k?o/k>co`0000;oVIVI
00Ko0000ogmoOomoOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c00So0000oda<
C?m<C4co0000ofIVI_l0003oOgmoo`0000;oVIVI00?o0000ok>c/ol000002Oo<c<`00ol0003o/k>c
o`000002oiVIV@07o`000?moOgoo0000ofIVI_l0003oC4a<o`000008oc<c<`;o000000_oC4a<o`00
0?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o0000olc<c006ooooo`7o00000Oooool1ooooo`00
9?ooool00ol0003oooooooooo`03ooooo`?oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIV
ofIVIP0:ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>c
ok>c/`0Fok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl01OmoOgl00ol0003oIVIV
ofIVIP05ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmo
ogmoOomoOgoo000000CoVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c003olc<c003
o`000?nc/k?o/k>c00?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`04o`000?mVIVKoIVIV
o`0000CoC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co
0000ogmoOomoOgoo00000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Co0000ok>c/onc
/k?o00000_nIVIT01_l0003oOgmoogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01olc
<c<02?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo00000_nIVIT00ol0003o/k>co`000009olc<
c003o`000?nc/k?o000000;oVIVI00Oo0000ogmoOol0003oIVIVo`000?m<C4co000000So<c<c00go
0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol0003oc<c<00Kooooo0Ol0
0001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo0_mVIVH00ol0003oC4a<oda<C00F
oda<C0;o00003?mVIVH00ol0003oOgmoogmoO`08ogmoO`;o00003OnIVIT00ol0003o/k>cok>c/`0F
ok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl01OmoOgl00ol0003oIVIVofIVIP05
ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH00_mVIVH00ol0003oOgmoogmoO`02
ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001_nc/k<00ol0003oc<c<olc<c003olc<c003o`000?nc
/k?o/k>c00?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`05o`000?mVIVKoIVIVofIVI_l0
00000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0
003oOgmoogmoOol00002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01?l0003o/k>cok>c
/ol00002oiVIV@06o`000?moOgooOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`07oc<c
<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVIV@03o`000?nc/k?o000000Woc<c<
00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c
<`05oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl2o`000004ok>c/ol0003oc<c<olc<
c0Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo00?oIVIVo`000?m<
C4`05om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnI
VIT03?nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI0_l00007ogmoO`03
o`000?mVIVKoIVIV00GoIVIV00?o0000oda<C?m<C4`05?m<C4`00ol0003oIVIVofIVIP02ofIVIP03
o`000?moOgooOgmo00;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000006ok>c/`03o`000?o<c<coc<c<
00?oc<c<00?o0000ok>c/onc/k<01?nc/k<01?l0003oVIVIoiVIVOl00003ogmoO`04o`000?mVIVKo
IVIVo`0000CoC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV
00Co0000ogmoOomoOgoo00000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Co0000ok>c
/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c0_l0
0002oda<C007o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Oo
c<c<00?o0000ok>c/ol000000_nIVIT01ol0003oOgmoo`000?mVIVKo0000oda<C?l000002?lc<c<0
3?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000;oc<c<1_ooool1
o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool00omVIVKo0000oda<C00Goda<
C003o`000?mVIVKoIVIV00[oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0;oiVI
V@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`06ogmo
O`03o`000?mVIVKoIVIV00GoIVIV00?o0000oda<C?m<C4`05?m<C4`00ol0003oIVIVofIVIP02ofIV
IP03o`000?moOgooOgmo00;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000006ok>c/`03o`000?o<c<co
c<c<00?oc<c<00?o0000ok>c/onc/k<01?nc/k<01?l0003oVIVIoiVIVOl00003ogmoO`04o`000?mV
IVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;o
IVIV00Co0000ogmoOomoOgoo00000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Co0000
ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c
00_o0000oda<C?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<
c<coc<c<00Ooc<c<00?o0000ok>c/ol000000_nIVIT01ol0003oOgmoo`000?mVIVKo0000oda<C?l0
00002?lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000;o
c<c<1_ooool1o`00007ooooo0Oooool002Cooooo0_l00004ooooo`03o`000?m<C4coC4a<01KoC4a<
00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI
00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00KoOgmo
00?o0000ofIVI_mVIVH01_mVIVH00ol0003oC4a<oda<C00Coda<C003o`000?mVIVKoIVIV00?oIVIV
00Go0000ogmoOomoOgooOgmoo`000004oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<
c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01Ol0
003oIVIVofIVI_mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<
C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT00ol0003o/k>cok>c/`02ok>c/`03o`00
0?o<c<coc<c<00Goc<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo00Co0000ofIV
I_mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0;o`000?m<C4coC4a<oda<C?l0003oIVIV
o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c003o`000?nc/k?o0000
00;oVIVI0_l00002ofIVIP03o`000?m<C4co000000So<c<c00co0000oda<C?m<C4co0000ofIVI_l0
003oOgmoo`000?nIVIWo0000ok>c/ol00002olc<c0Gooooo0_l00002ooooo`009?ooool00ol0003o
ooooooooo`03oooooaSoC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`09ogmoO`03
o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03
o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH01_mVIVH00ol0003oC4a<oda<C00Coda<C003
o`000?mVIVKoIVIV00?oIVIV00?o0000ogmoOomoOgl00_moOgl01Ol0003oVIVIoiVIVOnIVIWo0000
00Ko/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`04o`000?nIVIWoVIVI
o`0000?oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<
C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@05o`000?nc/k?o/k>cok>c
/ol000002?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000
oda<C?m<C4co00002?lc<c<02Ol0003oC4a<oda<C?m<C4co0000ofIVI_l0003oOgmoo`000002oiVI
V@03o`000?nc/k?o000000Woc<c<00?o0000ok>c/ol000000_nIVIT01ol0003oOgmoo`000?mVIVKo
0000oda<C?l000002Olc<c<00ol0003oC4a<o`000002ofIVIP;o000000GoVIVIo`000?nc/k?o/k>c
o`000002olc<c0Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo5om<
C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onI
VIT00ol0003o/k>cok>c/`0Fok>c/`;o00003OnIVIT00ol0003oOgmoogmoO`07ogmoO`03o`000?mV
IVKoIVIV00GoIVIV00?o0000oda<C?m<C4`05?m<C4`00ol0003oIVIVofIVIP02ofIVIP03o`000?mo
OgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<
c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo
00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<
C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000;o/k>c0_l00007
olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<
C4coC4a<o`0000So<c<c00_o0000oda<C?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`00
0002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00?o0000ok>c/ol000000_nIVIT01ol0003oOgmoo`00
0?mVIVKo0000oda<C?l000002Olc<c<02ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`00
0?nc/k?o000000?oc<c<1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00ooo
oolFoda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVI
V@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmo
O`07ogmoO`03o`000?mVIVKoIVIV00GoIVIV00?o0000oda<C?m<C4`05Om<C4`00ol0003oIVIVofIV
IP02ofIVIP03o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c
/`04ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00onc/k<01Ol0003oVIVIoiVI
VOnIVIWo000000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go
<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVI
o`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o
0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`0;o`000?m<C4coC4a<oda<C?l0
003oIVIVo`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c003o`000?nc
/k?o000000;oVIVI00Oo0000ogmoOol0003oIVIVo`000?m<C4co000000Wo<c<c00_o0000oda<C?l0
003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`000003olc<c0Kooooo0Ol00001ooooo`7ooooo
000Tooooo`03o`000?oooooooooo00?ooooo5Om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?mo
OgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nI
VIWoVIVI00_oVIVI00?o0000ogmoOomoOgl01omoOgl00ol0003oIVIVofIVIP05ofIVIP03o`000?m<
C4coC4a<01GoC4a<00?o0000ofIVI_mVIVH00_mVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nI
VIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c003olc<c003o`000?nc
/k?o/k>c00?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`05o`000?mVIVKoIVIVofIVI_l0
00001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mV
IVKo00000_moOgl01?l0003oVIVIoiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000
ok>c/onc/k?o/k>co`000002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co0000
2?lc<c<02ol0003oC4a<oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o
0000olc<c?o<c<`01oo<c<`00ol0003o/k>co`000002oiVIV@07o`000?moOgoo0000ofIVI_l0003o
C4a<o`000009oc<c<`03o`000?m<C4coC4a<00;o000000KoOgmoo`000?nIVIWo0000ok>c/ol00004
olc<c0Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo4om<C4`2o`00
00goIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c
01Ko/k>c0_l0000=oiVIV@03o`000?moOgooOgmo00OoOgmo00?o0000ofIVI_mVIVH01_mVIVH00ol0
003oC4a<oda<C00Doda<C003o`000?mVIVKoIVIV00?oIVIV00Go0000ogmoOomoOgooOgmoo`000004
oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`04
ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000CoC4a<
00?o0000oc<c<olc<c<01Olc<c<01Ol0003oC4a<oda<C?m<C4co000000?oIVIV00?o0000ogmoOol0
00000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Go0000ok>c/onc/k?o/k>co`000002
oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<01?l0003oC4a<oda<
C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c003
o`000?nc/k?o000000;oVIVI00Oo0000ogmoOol0003oIVIVo`000?m<C4co000000So<c<c00co0000
oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00004olc<c0Kooooo0Ol00001
ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo4_m<C4`00ol0003oIVIVofIVIP0<ofIV
IP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c
/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP06ofIV
IP03o`000?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH01?mVIVH01Ol0003oOgmoogmoOomoOgoo
000000CoVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c002olc<c003o`000?nc/k?o
/k>c00Go/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`05o`000?mVIVKoIVIVofIVI_l00000
1?m<C4`00ol0003o<c<coc<c<`05oc<c<`05o`000?m<C4coC4a<oda<C?l000000omVIVH00ol0003o
Ogmoo`000002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01Ol0003o/k>cok>c/onc/k?o
000000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`04o`000?m<
C4coC4a<o`0000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Oo
c<c<00?o0000ok>c/ol000000_nIVIT01ol0003oOgmoo`000?mVIVKo0000oda<C?l000002?lc<c<0
3?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Coc<c<1_ooool1
o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00ooooolBoda<C003o`000?mVIVKoIVIV
00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c
01Ko/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV
00KoIVIV00?o0000oda<C?m<C4`05?m<C4`00ol0003oIVIVofIVIP03ofIVIP05o`000?moOgooOgmo
ogmoOol000001?nIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000
ok>c/onc/k<01?nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Go0000ofIVI_mVIVKoIVIV
o`000004oda<C003o`000?lc<c?o<c<c00Go<c<c00Go0000oda<C?m<C4coC4a<o`000003ofIVIP03
o`000?moOgoo000000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c005o`000?nc/k?o/k>c
ok>c/ol000000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000Wo<c<c00[o
0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c007
olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c
<olc<c<01Olc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo0_l000000onc/k?o0000olc<
c004olc<c0Kooooo0Ol00001ooooo`7ooooo000Iooooo`Go00001_ooool00ol0003oooooooooo`03
oooooa3oC4a<0_l0000=ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT0
0ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI0_l00009ogmoO`;o00002?mVIVH0
0ol0003oC4a<oda<C00Doda<C003o`000?mVIVKoIVIV00?oIVIV00?o0000ogmoOomoOgl00_moOgl0
1Ol0003oVIVIoiVIVOnIVIWo000000Oo/k>c00?o0000olc<c?o<c<`00_o<c<`00ol0003o/k>cok>c
/`04ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01?l0003oIVIVofIVI_l00004oda<C003
o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmo
O`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01ol0003o/k>cok>c/onc
/k?o0000oiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko
<c<c00Co0000oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000
olc<c?o<c<`01_o<c<`2o`000004ok>c/ol0003oVIVIo`0000;oOgmo00Go0000ofIVI_l0003oC4a<
o`000008oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o0000
1Oo<c<`6ooooo`7o00000Oooool1ooooo`006Oooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo
00?o0000ooooooooool00oooool?oda<C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl0
2?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT0
2onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00KoIVIV00?o0000oda<C?m<C4`0
5Om<C4`00ol0003oIVIVofIVIP02ofIVIP03o`000?moOgooOgmo00?oOgmo00Go0000oiVIVOnIVIWo
VIVIo`000007ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o0000ok>c/onc/k<01?nc/k<01Ol0003o
VIVIoiVIVOnIVIWo000000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o
<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nI
VIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01ol0003o/k>cok>c/onc/k?o0000oiVI
VOl000000_moOgl01?l0003oIVIVofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000
oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`0
1_o<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00Go0000ofIVI_l0003oC4a<o`000008
oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00001Oo<c<`6
ooooo`7o00000Oooool1ooooo`004Oooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h01oooool3o`00
00?ooooo3om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVI
VOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmo
OomoOgl02OmoOgl00ol0003oIVIVofIVIP07ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIV
I_mVIVH00_mVIVH00ol0003oOgmoogmoO`03ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001onc/k<0
0ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c00Co/k>c00Go0000oiVIVOnIVIWoVIVIo`00
0003ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<
oda<C002oda<C007o`000?mVIVKoIVIVofIVI_l0003oOgmoo`000002oiVIV@05o`000?nc/k?o/k>c
ok>c/ol000002Oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV00Co
0000oda<C?m<C4co00002Olc<c<00ol0003oC4a<o`000002ofIVIP03o`000?moOgoo000000;oVIVI
00?o0000ok>c/ol000002?o<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00Go0000ofIV
I_l0003oC4a<o`000009oc<c<`03o`000?m<C4co000000;oIVIV0_l000001OnIVIWo0000ok>c/onc
/k?o000000Goc<c<1?ooool3o`0000;ooooo000Kooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000
ooooooooool00oooool=oda<C0;o00003OmVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWo
VIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgoo
Ogmo00WoOgmo00?o0000ofIVI_mVIVH01omVIVH00ol0003oC4a<oda<C00Doda<C003o`000?mVIVKo
IVIV00?oIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@02oiVIV@03o`000?nc/k?o
/k>c00Go/k>c00?o0000olc<c?o<c<`00_o<c<`00ol0003o/k>cok>c/`04ok>c/`05o`000?nIVIWo
VIVIoiVIVOl000000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000CoC4a<00?o0000oc<c<olc<c<0
1Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co0000oiVIVOnI
VIWo00000onc/k<00ol0003oc<c<olc<c006olc<c007o`000?nc/k?o/k>cok>c/ol0003oVIVIo`00
0002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<02?lc<c<00ol0003oC4a<o`00
0002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c006o`00
0?nc/k?o/k>co`000?nIVIWo00000_moOgl01Ol0003oIVIVo`000?m<C4co000000Wo<c<c00_o0000
oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`000006olc<c0Kooooo0Ol00001oooo
o`7ooooo000Looooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool00oooool<oda<C003
o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03
o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmoO`03
o`000?mVIVKoIVIV00OoIVIV00?o0000oda<C?m<C4`05Om<C4`00ol0003oIVIVofIVIP03ofIVIP03
o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`05ok>c/`05
o`000?o<c<coc<c<olc<c?l000001onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Go0000
ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<
C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<
c<`01_o<c<`01ol0003o/k>cok>c/onc/k?o0000oiVIVOl000000_moOgl00ol0003oIVIVo`000002
oda<C003o`000?lc<c?o<c<c00So<c<c00?o0000oda<C?l000000_mVIVH01Ol0003oOgmoo`000?nI
VIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;o
Ogmo00Go0000ofIVI_l0003oC4a<o`000009oc<c<`0;o`000?m<C4co0000ofIVI_l0003oOgmoo`00
0?nIVIWo0000ok>c/ol000001_o<c<`6ooooo`7o00000Oooool1ooooo`007Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00?ooooo2om<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`00
0?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`00
0?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP07ofIVIP03o`00
0?m<C4coC4a<01GoC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`02ogmoO`03o`00
0?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c002olc<c003o`00
0?nc/k?o/k>c00Co/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`05o`000?mVIVKoIVIVofIV
I_l000001?m<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH0
1?l0003oOgmoogmoOol00002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01ol0003o/k>c
ok>c/onc/k?o0000oiVIVOl000000_moOgl00ol0003oIVIVo`000003oda<C003o`000?lc<c?o<c<c
00Oo<c<c00?o0000oda<C?l000000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000
olc<c?o<c<`01oo<c<`00ol0003o/k>co`000002oiVIV@07o`000?moOgoo0000ofIVI_l0003oC4a<
o`000009oc<c<`07o`000?m<C4co0000ofIVI_l0003oOgmoo`000002oiVIV@;o00001oo<c<`6oooo
o`7o00000Oooool1ooooo`006Oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000oooo
ooooool00oooool:oda<C003o`000?mVIVKoIVIV00_oIVIV0_l0000:ogmoO`03o`000?nIVIWoVIVI
00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo
00WoOgmo00?o0000ofIVI_mVIVH02?mVIVH00ol0003oC4a<oda<C00Doda<C003o`000?mVIVKoIVIV
00?oIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c
00Go/k>c00?o0000olc<c?o<c<`00_o<c<`00ol0003o/k>cok>c/`04ok>c/`05o`000?nIVIWoVIVI
oiVIVOl000000omoOgl01?l0003oIVIVofIVI_l00005oda<C003o`000?lc<c?o<c<c00Go<c<c00Go
0000oda<C?m<C4coC4a<o`000003ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Co0000ok>c/onc
/k?o00002Oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@06o`000?moOgooOgmoo`000?mVIVKo0000
0om<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Go0000ogmoOol0
003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Go0000ok>c/ol0003oVIVIo`000002
ogmoO`05o`000?mVIVKo0000oda<C?l000002Olc<c<02ol0003oC4a<o`000?mVIVKo0000ogmoOol0
003oVIVIo`000?nc/k?o000000Ooc<c<1_ooool1o`00007ooooo0Oooool001Wooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo00?ooooo2Om<C4`00ol0003oIVIVofIVIP0<
ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0F
ok>c/`;o00003?nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00SoIVIV00?o0000
oda<C?m<C4`05?m<C4`00ol0003oIVIVofIVIP03ofIVIP03o`000?moOgooOgmo00?oOgmo00?o0000
oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`05ok>c/`;o00000oo<c<`00ol0003o/k>cok>c/`04
ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01?l0003oIVIVofIVI_l00004oda<C003o`00
0?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000003ofIVIP04o`000?moOgooOgmoo`00
00;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@06o`000?mo
OgooOgmoo`000?mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`00
00;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Go0000
ok>c/ol0003oVIVIo`000002ogmoO`05o`000?mVIVKo0000oda<C?l000002?lc<c<03?l0003oC4a<
oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Ooc<c<1_ooool1o`00007ooooo
0Oooool002Cooooo00?o0000ooooooooool00oooool8oda<C003o`000?mVIVKoIVIV00coIVIV00?o
0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o
0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00SoIVIV00?o
0000oda<C?m<C4`05Om<C4`00ol0003oIVIVofIVIP03ofIVIP03o`000?moOgooOgmo00;oOgmo00?o
0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`05ok>c/`06o`000?o<c<coc<c<o`000?o<c<co
00001_nc/k<00ol0003oVIVIoiVIV@02oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00?o0000oda<
C?m<C4`00om<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIV
I_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co
0000ok>c/onc/k?o00000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP04o`000?m<C4coC4a<o`00
00Wo<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003o
c<c<olc<c007olc<c003o`000?nc/k?o/k>c00;o00000_moOgl00ol0003oIVIVo`000002oda<C003
o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?l0003oIVIVo`000002ogmoO`;o00000_nc/k<00ol0
003oc<c<olc<c005olc<c0Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?o
oooo1om<C4`00ol0003oIVIVofIVIP0;ofIVIP;o00002_moOgl00ol0003oVIVIoiVIV@0;oiVIV@03
o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmoO`03
o`000?mVIVKoIVIV00SoIVIV00?o0000oda<C?m<C4`05Om<C4`00ol0003oIVIVofIVIP03ofIVIP03
o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00_nIVIT2o`0000Oo/k>c00Go0000olc<c?o<
c<coc<c<o`000007ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01Ol0003oIVIVofIVI_mV
IVKo000000CoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mV
IVKoIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c005olc<c0;o
00000_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`03o`000?mVIVKo000000?oC4a<00?o0000oc<c
<olc<c<01_lc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00?o0000oiVIVOl000000_nc
/k<00ol0003oc<c<olc<c006olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl01Ol0003o
IVIVo`000?m<C4co000000So<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo
00000_nc/k<00ol0003oc<c<olc<c005olc<c0Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`00
0?oooooooooo00?ooooo1om<C4`00ol0003oIVIVofIVIP0:ofIVIP03o`000?moOgooOgmo00WoOgmo
00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`;o00003?nIVIT00ol0003oOgmo
ogmoO`08ogmoO`;o00002omVIVH00ol0003oC4a<oda<C00Eoda<C003o`000?mVIVKoIVIV00?oIVIV
00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c00Ko/k>c
00Go0000olc<c?o<c<coc<c<o`000006ok>c/`03o`000?nIVIWoVIVI00;oVIVI00Co0000ogmoOomo
Ogoo00000omVIVH00ol0003oC4a<oda<C002oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<
C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o
0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Ko0000ogmoOomoOgoo
0000ofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Ko0000oda<C?m<C4co0000ofIVI_l0
0002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01_l0003o/k>cok>c
/ol0003oVIVIo`0000;oOgmo00Go0000ofIVI_l0003oC4a<o`000008oc<c<`0:o`000?m<C4coC4a<
o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01Oo<c<`6ooooo`7o
00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`GoC4a<0_l0000<ofIVIP03o`00
0?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`00
0?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0:ofIVIP03o`00
0?m<C4coC4a<01GoC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`02ogmoO`03o`00
0?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01_nc/k<01Ol0003oc<c<olc<c?o<c<co000000Ko
/k>c00?o0000oiVIVOnIVIT00_nIVIT01?l0003oOgmoogmoOol00004ofIVIP05o`000?m<C4coC4a<
oda<C?l000001olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co
0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c
00So0000oiVIVOnIVIWo0000ogmoOol0003oIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<0
1_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo00000_nc/k<00ol0003o
c<c<olc<c005olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl01Ol0003oIVIVo`000?m<
C4co000000Wo<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl000000_nc/k<00ol0
003oc<c<olc<c006olc<c003o`000?oooooooooo00?ooooo0Ol00001ooooo`7ooooo000Tooooo`03
o`000?oooooooooo00?ooooo1?m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00Wo
Ogmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_o
VIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<01Go
C4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00?o
VIVI00?o0000ok>c/onc/k<01Onc/k<2o`0000;oc<c<00?o0000ok>c/onc/k<01Onc/k<01Ol0003o
VIVIoiVIVOnIVIWo000000?oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o
<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nI
VIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;o
VIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`06o`000?m<C4coC4a<
o`000?mVIVKo00000_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Ko
0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`05o`000?mVIVKo0000oda<C?l000002Olc<c<02Ol0
003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<
00?o0000ooooooooool00oooool1o`00007ooooo0Oooool002Cooooo0_l00004ooooo`CoC4a<00?o
0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o
0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o
0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Doda<C003o`000?mVIVKoIVIV00CoIVIV00?o
0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c00Oo/k>c00?o
0000olc<c?l000001onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Go0000ofIVI_mVIVKo
IVIVo`000004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003o
IVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`0
1Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<
C?l00009oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl00ol0003oVIVIo`000002ok>c
/`03o`000?o<c<coc<c<00Koc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`05o`000?mV
IVKo0000oda<C?l000002Olc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002
ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o0000ooooooooool00_ooool2o`0000;ooooo000Toooo
o`03o`000?oooooooooo00?ooooo0_m<C4`2o`0000coIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0
003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0
003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05?m<C4`00ol0
003oIVIVofIVIP04ofIVIP03o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0
003o/k>cok>c/`06ok>c/`;o000000?o/k>co`000?nc/k<01_nc/k<00ol0003oVIVIoiVIV@02oiVI
V@04o`000?moOgooOgmoo`0000?oIVIV00?o0000oda<C?m<C4`00_m<C4`00ol0003o<c<coc<c<`05
oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVI
VOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@03
o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<01?l0003oC4a<oda<C?l00002
ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc
/k?o/k>co`0000;oVIVI00Oo0000ogmoOol0003oIVIVo`000?m<C4co000000Wo<c<c00Oo0000oda<
C?l0003oIVIVo`000?moOgoo000000;oVIVI00?o0000ok>c/ol000002?o<c<`00ol0003ooooooooo
o`04ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`03oda<C?l0003o
IVIV00coIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o
/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKo
IVIV00_oIVIV00?o0000oda<C?m<C4`05?m<C4`00ol0003oIVIVofIVIP04ofIVIP03o`000?moOgoo
Ogmo00?oOgmo00?o0000oiVIVOnIVIT00_nIVIT2o`0000Oo/k>c00Co0000olc<c?o<c<co00001onc
/k<00ol0003oVIVIoiVIV@02oiVIV@03o`000?moOgooOgmo00;o00000_mVIVH00ol0003oC4a<oda<
C002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4coC4a<0_l00002ofIVIP04o`00
0?moOgooOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c005o`000?nc/k?o/k>c
ok>c/ol000000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000Wo<c<c00Ko
0000oda<C?m<C4co0000ofIVI_l00002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<
c<`01_o<c<`01Ol0003o/k>cok>c/ol0003oVIVI00?o00000_mVIVH00ol0003oC4a<o`000009oc<c
<`08o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIT3o`0000Woc<c<00?o0000ooooooooool0
1?ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool00om<C4co0000ofIV
IP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c
/`0Fok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl01omoOgl00ol0003oIVIVofIV
IP0<ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH01?mVIVH00ol0003oOgmoogmo
O`02ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<01_nc/k<01?l0003oc<c<olc<
c?l00007ok>c/`03o`000?nIVIWoVIVI00;oVIVI00Co0000ogmoOomoOgoo00000omVIVH00ol0003o
C4a<oda<C002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000003ofIV
IP04o`000?moOgooOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c005o`000?nc
/k?o/k>cok>c/ol000000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So
<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00?o0000oiVIVOl000000_nc/k<0
0ol0003oc<c<olc<c006olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP03
o`000?m<C4co000000Wo<c<c00_o0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>c
o`000009olc<c003o`000?oooooooooo00Cooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oo
oooooooo00?ooooo00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nI
VIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?mo
OgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Eoda<C003o`000?mV
IVKoIVIV00?oIVIV00?o0000ogmoOomoOgl00omoOgl00ol0003oVIVIoiVIV@02oiVIV@03o`000?nc
/k?o/k>c00Oo/k>c00?o0000olc<c?l000001onc/k<00ol0003oVIVIoiVIV@02oiVIV@05o`000?mo
OgooOgmoogmoOol000000omVIVH00ol0003oC4a<oda<C002oda<C003o`000?lc<c?o<c<c00Go<c<c
00?o0000oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Co0000oiVIVOnI
VIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c003o`000?nc/k?o/k>c00;o/k>c00?o0000oiVI
VOl000000_moOgl01?l0003oIVIVofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Oo0000
oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<
olc<c005olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH00ol0003o
C4a<o`000008oc<c<`05o`000?m<C4coC4a<o`000?mVIVH00_l00002oiVIV@03o`000?nc/k?o0000
00Woc<c<00?o0000ooooooooool01?ooool1o`00007ooooo0Oooool002Cooooo00?o0000oooooooo
ool00oooool<ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o
/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003o
IVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01GoC4a<00?o0000ofIVI_mVIVH01?mVIVH00ol0003o
OgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<01_nc/k<01?l0003o
c<c<olc<c?l00007ok>c/`03o`000?nIVIWoVIVI00;oVIVI00Co0000ogmoOomoOgoo00001?mVIVH0
1Ol0003oC4a<oda<C?m<C4co000000Oo<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIV
I_mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c005
o`000?nc/k?o/k>cok>c/ol000000_nIVIT01_l0003oOgmoogmoOol0003oIVIVo`0000?oC4a<00?o
0000oc<c<olc<c<01Olc<c<01ol0003oC4a<oda<C?m<C4co0000ofIVI_l000000_moOgl00ol0003o
VIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003o
Ogmoo`0000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmo
Ool0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o0000ok>c/oooool01Oooool1
o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool;ofIVIP;o00002_moOgl00ol0
003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c0_l0000=oiVIV@03o`000?moOgooOgmo
00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Eoda<C003o`000?mVIVKoIVIV
00CoIVIV00?o0000ogmoOomoOgl00omoOgl00ol0003oVIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c
00Oo/k>c0ol00008ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01Ol0003oIVIVofIVI_mV
IVKo000000CoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mV
IVKoIVIVo`0000?oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c007
o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000;oC4a<00?o
0000oc<c<olc<c<01_lc<c<01ol0003oC4a<oda<C?m<C4co0000ofIVI_l000000_moOgl00ol0003o
VIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003o
Ogmoo`0000;oIVIV00?o0000oda<C?l000002?lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?mo
Ogoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o0000ok>c/ol000001Oooool1
o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool:ofIVIP03o`000?moOgooOgmo
00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI
00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<
01KoC4a<00?o0000ofIVI_mVIVH01?mVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI
00;oVIVI00?o0000ok>c/onc/k<04onc/k<01?l0003oVIVIoiVIVOl00004ogmoO`05o`000?mVIVKo
IVIVofIVI_l000001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co
0000ofIVI_mVIVKo00000omoOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Ko
c<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo00000_m<
C4`00ol0003o<c<coc<c<`06oc<c<`07o`000?m<C4coC4a<oda<C?l0003oIVIVo`000002ogmoO`03
o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02?l0003o/k>cok>c/ol0003oVIVI
o`000?moOgoo00000_mVIVH00ol0003oC4a<o`000008oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo
0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003o/k>co`000005
ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`WoIVIV00?o0000ogmo
OomoOgl02OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVI
VOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<
C?m<C4`05_m<C4`00ol0003oIVIVofIVIP04ofIVIP03o`000?moOgooOgmo00;oOgmo00?o0000oiVI
VOnIVIT00onIVIT00ol0003o/k>cok>c/`0Bok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl0
1Ol0003oIVIVofIVI_mVIVKo000000CoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<
C002oda<C004o`000?mVIVKoIVIVo`0000?oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003o
c<c<olc<c006olc<c007o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000002ogmoO`04o`000?mVIVKo
IVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01ol0003oC4a<oda<C?m<C4co0000ofIVI_l0
00000_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Ko0000ok>c/onc
/k?o0000oiVIVOl00002ogmoO`05o`000?mVIVKo0000oda<C?l000002Olc<c<02Ol0003oC4a<o`00
0?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o0000ok>c
/ol000001_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool9ofIVIP03
o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`;o
00003OnIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<
C4`05_m<C4`00ol0003oIVIVofIVIP04ofIVIP03o`000?moOgooOgmo00?oOgmo00?o0000oiVIVOnI
VIT00onIVIT00ol0003o/k>cok>c/`0Aok>c/`03o`000?nIVIWoVIVI00;oVIVI00Co0000ogmoOomo
Ogoo00000omVIVH00ol0003oC4a<oda<C003oda<C003o`000?lc<c?o<c<c00Go<c<c00Co0000oda<
C?m<C4coC4a<0_l00002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>c
o`000009olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01?l0
003oC4a<oda<C?l00008oc<c<`09o`000?m<C4coC4a<oda<C?l0003oIVIVo`000?moOgoo000000;o
VIVI00Co0000ok>c/onc/k?o00002?o<c<`02?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000
0_mVIVH00ol0003oC4a<o`000009oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo
000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003o/k>co`000006ooooo`7o00000Oooool1
ooooo`009?ooool2o`0000Cooooo2?mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI
00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo
00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV
00CoIVIV00?o0000ogmoOomoOgl00omoOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c
017o/k>c00?o0000oiVIVOnIVIT00_nIVIT01?l0003oOgmoogmoOol00003ofIVIP03o`000?m<C4co
C4a<00?oC4a<00?o0000oc<c<olc<c<01Olc<c<01Ol0003oC4a<oda<C?m<C4co000000?oIVIV00Co
0000ogmoOomoOgoo00000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Woc<c<00Co0000ok>c/onc
/k?o00000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Wo
0000oda<C?m<C4coC4a<o`000?mVIVKo0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00008
olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP03o`000?m<C4co000000Wo
<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<
c006olc<c003o`000?nc/k?o000000Gooooo0_l00002ooooo`009?ooool00ol0003oooooooooo`03
ooooo`OoIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o
/k>c01Ko/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKo
IVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP04ofIVIP03o`000?moOgoo
Ogmo00?oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0Aok>c/`03o`000?nIVIWo
VIVI00;oVIVI00Co0000ogmoOomoOgoo00001?mVIVH00ol0003oC4a<oda<C002oda<C003o`000?lc
<c?o<c<c00Go<c<c00Go0000oda<C?m<C4coC4a<o`000004ofIVIP04o`000?moOgooOgmoo`0000;o
VIVI00Co0000ok>c/onc/k?o00002Oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@04o`000?moOgoo
Ogmoo`0000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<01Ol0003oC4a<oda<C?m<C4co000000;o
IVIV0_l00002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00So0000ok>c/onc/k?o0000oiVIVOl0
003oOgmoo`0000;oIVIV00?o0000oda<C?l000002Olc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmo
Ool0003oVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Goc<c<00Co0000ok>c/ol0003oVIVI1_oo
ool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool6ofIVIP03o`000?moOgoo
Ogmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWo
VIVI00_oVIVI0_l0000:ogmoO`03o`000?mVIVKoIVIV00[oIVIV0_l0000Hoda<C0;o00001_mVIVH0
0ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<04_nc/k<0
1Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Go0000ofIVI_mVIVKoIVIVo`000005oda<C003o`00
0?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;o
Ogmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>c
ok>c/ol000000_nIVIT01_l0003oOgmoogmoOol0003oIVIVo`0000?oC4a<00?o0000oc<c<olc<c<0
1_lc<c<00ol0003oC4a<oda<C002o`000004ofIVI_l0003oOgmoo`0000;oVIVI00Co0000ok>c/onc
/k?o00002?o<c<`02?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo00000_mVIVH00ol0003oC4a<
o`000009oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000
olc<c?o<c<`01_o<c<`01?l0003o/k>co`000?nIVIT6ooooo`7o00000Oooool1ooooo`009?ooool0
0ol0003oooooooooo`03ooooo`GoIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;
oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09
ogmoO`03o`000?mVIVKoIVIV00[oIVIV00?o0000oda<C?m<C4`06?m<C4`00ol0003oIVIVofIVIP05
ofIVIP03o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0C
ok>c/`04o`000?nIVIWoVIVIo`0000CoOgmo00Go0000ofIVI_mVIVKoIVIVo`000005oda<C003o`00
0?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;o
Ogmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>c
ok>c/ol000000_nIVIT01_l0003oOgmoogmoOol0003oIVIVo`0000?oC4a<00?o0000oc<c<olc<c<0
1_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc
/k?o00002?o<c<`02?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo00000_mVIVH00ol0003oC4a<
o`000008oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o
0000olc<c?o<c<`01_o<c<`01Ol0003o/k>co`000?nIVIWo000000Gooooo0Ol00001ooooo`7ooooo
000Tooooo`03o`000?oooooooooo00?ooooo1?mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nI
VIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?mo
OgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<oda<C00Hoda<C003o`000?mV
IVKoIVIV00GoIVIV00?o0000ogmoOomoOgl00omoOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc
/k?o/k>c01;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`05o`000?mVIVKoIVIVofIVI_l0
00001Om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00;oC4a<00Go0000ofIVI_mV
IVKoIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`0
1Ol0003o/k>cok>c/onc/k?o000000?oVIVI00Go0000ogmoOol0003oIVIVo`000003oda<C003o`00
0?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVIV@04
o`000?nc/k?o/k>co`0000Soc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV
00Co0000oda<C?m<C4co00002?lc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`00
0002ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o0000ok>c/ol000000_nIVIT00ol0003ooooooooo
o`03ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`?oIVIV00?o0000
ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000
oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00[oIVIV0_l0000H
oda<C0;o00001omVIVH00ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000
ok>c/onc/k<04_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo0_l00002ofIVIP03o`000?m<
C4coC4a<00?oC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mV
IVKoIVIVo`0000?oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c005
o`000?nc/k?o/k>cok>c/ol000000_nIVIT00ol0003oOgmoo`000002ofIVIP05o`000?m<C4coC4a<
oda<C?l000002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00Co
0000ok>c/onc/k?o00002?o<c<`02?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo00000_mVIVH0
0ol0003oC4a<o`000008oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`00
0?nc/k?o00002Oo<c<`01Ol0003o/k>co`000?nIVIWo000000Kooooo0Ol00001ooooo`7ooooo000T
ooooo`03o`000?oooooooooo00?ooooo0_mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWo
VIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgoo
Ogmo00WoOgmo00?o0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<oda<C00Hoda<C003o`000?mVIVKo
IVIV00KoIVIV00?o0000ogmoOomoOgl00omoOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o
/k>c01;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`05o`000?mVIVKoIVIVofIVI_l00000
1Om<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo
00000omoOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c
/onc/k?o/k>co`000002oiVIV@03o`000?moOgoo000000;oIVIV00Go0000oda<C?m<C4coC4a<o`00
0008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>c
ok>c/ol00008olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP03o`000?m<
C4co000000So<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol0
0009olc<c005o`000?nc/k?o0000oiVIVOl000001_ooool1o`00007ooooo0Oooool002Cooooo00?o
0000ooooooooool00oooool00omVIVKo0000ogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o
0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o
0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<oda<C00Hoda<C003o`000?mVIVKoIVIV00KoIVIV00?o
0000ogmoOomoOgl00omoOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c01;o/k>c00Go
0000oiVIVOnIVIWoVIVIo`000003ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`0
0om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo
00000omoOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c
/onc/k?o/k>co`000002oiVIV@03o`000?moOgoo000000;oIVIV00Go0000oda<C?m<C4coC4a<o`00
0008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Ko0000ogmoOomoOgoo0000oiVIVOl00002ok>c
/`03o`000?o<c<coc<c<00Koc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV
00?o0000oda<C?l000002Olc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002
ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o0000ok>c/onc/k<00_l000000omoOgooooooooooo`04
ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`03o`000?moOgooOgmo
00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI
00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<
01OoC4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI
00?oVIVI00?o0000ok>c/onc/k<04_nc/k<00ol0003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmo
ogmoOol000000omVIVH00ol0003oC4a<oda<C003oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000
oda<C?m<C4`00om<C4`01?l0003oIVIVofIVI_l00002ogmoO`05o`000?nIVIWoVIVIoiVIVOl00000
0onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT00ol0003o
Ogmoo`000002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01?l0003oC4a<oda<C?l00002
ofIVIP03o`000?moOgoo000000;oVIVI00?o0000ok>c/ol000002Oo<c<`02?l0003o/k>cok>c/ol0
003oVIVIo`000?moOgoo00000_mVIVH00ol0003oC4a<o`000009oc<c<`09o`000?m<C4co0000ofIV
I_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01_l0003o/k>co`00
0?nIVIWo0000ogmoO`Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo
2_moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c0_l0000<oiVIV@03o`00
0?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Goda<C003o`00
0?mVIVKoIVIV00OoIVIV00?o0000ogmoOomoOgl00omoOgl00ol0003oVIVIoiVIV@03oiVIV@03o`00
0?nc/k?o/k>c01;o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000?o
IVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?o
C4a<00Co0000ofIVI_mVIVKo00000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000?o/k>c00?o0000
olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`06o`000?nIVIWoVIVIo`000?moOgoo0000
0_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002
ogmoO`06o`000?nIVIWoVIVIo`000?nc/k?o00002Oo<c<`02?l0003o/k>cok>c/ol0003oVIVIo`00
0?moOgoo00000_mVIVH00ol0003oC4a<o`000009oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmo
o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01ol0003o/k>co`000?nIVIWo0000
ogmoOol000001Oooool1o`00007ooooo0Oooool002Cooooo0_l00004ooooo`WoOgmo00?o0000oiVI
VOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmo
OomoOgl02OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIV
I_mVIVH01omVIVH00ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c
/onc/k<04_nc/k<00ol0003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol000000omVIVH0
0ol0003oC4a<oda<C003oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`0
1?l0003oIVIVofIVI_l00002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000onc/k<00ol0003oc<c<
olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIV
IP04o`000?m<C4coC4a<o`0000So<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`00
0002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmo
o`0000;oIVIV00?o0000oda<C?l000002Olc<c<00ol0003oC4a<o`000002ofIVIP;o000000GoVIVI
o`000?nc/k?o/k>co`000009olc<c0;o000000GoVIVIo`000?moOgooOgmoo`000004ooooo`;o0000
0_ooool002Cooooo00?o0000ooooooooool00oooool8ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o
0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o
0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00OoIVIV00?o
0000ogmoOomoOgl00omoOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c01?o/k>c00Go
0000oiVIVOnIVIWoVIVIo`000003ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`0
0_m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Go0000ofIVI_mVIVKo
IVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`01Ol0
003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01Ol0003oC4a<oda<
C?m<C4co000000So<c<c00Co0000oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nIVIWo0000
00?o/k>c00?o0000olc<c?o<c<`01_o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000
ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo
0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c007o`000?nc/k?o0000oiVIVOl0003o
Ogmoo`000006ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`OoOgmo
00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`;o00003?nIVIT00ol0003oOgmo
ogmoO`08ogmoO`;o00003OmVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00SoIVIV
00?o0000ogmoOomoOgl00omoOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c01;o/k>c
00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000CoIVIV00?o0000oda<C?m<
C4`00_m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Go0000ofIVI_mV
IVKoIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`0
1Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01Ol0003oC4a<
oda<C?m<C4co000000So<c<c00Co0000oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nIVIWo
000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo
0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Wo0000oda<C?l0003oIVIVo`000?mo
Ogoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c007o`000?nc/k?o0000oiVIVOl0
003oOgmoo`000006ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`Ko
Ogmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_o
VIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<01Oo
C4a<00?o0000ofIVI_mVIVH01omVIVH2o`0000GoOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o
/k>cok>c/`0Cok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl00ol0003oIVIVofIVIP02ofIV
IP03o`000?m<C4coC4a<00?oC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C002oda<
C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<
c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<00ol0003oVIVIo`000002ogmoO`04o`000?mV
IVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP03
o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`02?l0003o/k>cok>c/ol0003o
VIVIo`000?moOgoo00000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`03o`000?m<C4coC4a<00;o
000000OoOgmoo`000?nIVIWoVIVIo`000?nc/k?o000000Woc<c<0_l00002oiVIV@;o000000?oIVIV
ooooooooool01?ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool5ogmo
O`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVI
V@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH2o`0001WoC4a<00?o0000ofIV
I_mVIVH01omVIVH00ol0003oOgmoogmoO`04ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c
/onc/k<04_nc/k<00ol0003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol000000omVIVH0
0ol0003oC4a<oda<C003oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00om<C4`0
1?l0003oIVIVofIVI_l00003ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`0
1_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01?l0
003oC4a<oda<C?l00009oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl01?l0003oVIVI
o`000?l00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003o
Ogmoo`0000;oIVIV00Co0000oda<C?l0003o00001olc<c<03?l0003oC4a<oda<C?l0003oIVIVo`00
0?moOgoo0000oiVIVOl0003o/k>co`0000[oc<c<0_l000001OnIVIWo0000ogmoOol0003oIVIV00Ko
oooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo1?moOgl00ol0003oVIVI
oiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmo
ogmoO`08ogmoO`03o`000?mVIVKoIVIV00coIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIV
ofIVIP08ofIVIP03o`000?moOgooOgmo00CoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>c
ok>c/`0Bok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`000003ofIVIP03
o`000?m<C4coC4a<00?oC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C003oda<C004
o`000?mVIVKoIVIVo`0000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000003ok>c/`03o`000?o<c<co
c<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV
00Co0000oda<C?m<C4co00002Olc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00?o0000
oiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000
ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<03?l0003oC4a<oda<C?l0003o
IVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000[oc<c<0_l000001_nIVIWo0000ogmoOol0003o
IVIVo`0000Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo0omoOgl0
0ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT0
0ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00coIVIV00?o0000oda<C?m<C4`05om<C4`0
0ol0003oIVIVofIVIP08ofIVIP03o`000?moOgooOgmo00CoOgmo00?o0000oiVIVOnIVIT01?nIVIT0
0ol0003o/k>cok>c/`0Bok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`00
0003ofIVIP03o`000?m<C4coC4a<00?oC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<
C002oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000;o
/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmo
OomoOgoo00000_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo
00000_moOgl00ol0003oVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00So0000ok>c/onc
/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV00?o0000oda<C?l000002?lc<c<01_l0003oC4a<oda<
C?l0003oIVIVo`0000;oOgmo0_l00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Co0000ok>c/ol0
003oVIVI0_l00002ofIVIP03o`000?oooooooooo00?ooooo0Ol00001ooooo`7ooooo000Tooooo`03
o`000?oooooooooo00?ooooo0_moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko
/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_o
IVIV0_l0000Ioda<C003o`000?mVIVKoIVIV00SoIVIV00?o0000ogmoOomoOgl01?moOgl00ol0003o
VIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c01;o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003o
OgmoogmoOomoOgoo000000CoIVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`04oc<c
<`03o`000?m<C4coC4a<00;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`05o`000?nIVIWo
VIVIoiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol00000
0_nIVIT01?l0003oOgmoogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Oo0000oda<
C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<
c007olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000
oc<c<olc<c<01_lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c
/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o0000oiVIV@02o`000003ofIVI_l0003o
oooo00Gooooo0Ol00001ooooo`7ooooo000Iooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool0
0ol0003oooooooooo`03ooooo`03ogmoOol0003oVIVI00coVIVI00?o0000ok>c/onc/k<05_nc/k<0
0ol0003oVIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo00OoOgmo00?o0000ofIVI_mVIVH03?mVIVH0
0ol0003oC4a<oda<C00Foda<C0;o00002omVIVH00ol0003oOgmoogmoO`04ogmoO`03o`000?nIVIWo
VIVI00CoVIVI00?o0000ok>c/onc/k<04_nc/k<00ol0003oVIVIoiVIV@02oiVIV@05o`000?moOgoo
OgmoogmoOol000001?mVIVH00ol0003oC4a<oda<C003oda<C003o`000?lc<c?o<c<c00Co<c<c00?o
0000oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Go0000oiVIVOnIVIWo
VIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVI
V@03o`000?moOgoo000000?oIVIV00Co0000oda<C?m<C4co00002?lc<c<01ol0003oC4a<oda<C?m<
C4co0000ofIVI_l000000_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<
00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c
<`06oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000
olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/ol0003oVIVI00;o000000?oIVIVo`000?ooool01Ooo
ool1o`00007ooooo0Oooool001Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oo
oooooooo00?ooooo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nI
VIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<
C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nI
VIWoVIVI00?oVIVI00?o0000ok>c/onc/k<04onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000CoOgmo
00Go0000ofIVI_mVIVKoIVIVo`000005oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<
C4`00_m<C4`00ol0003oIVIVofIVIP02ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00?o0000ok>c
/onc/k<00_nc/k<00ol0003oc<c<olc<c005olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT0
1?l0003oOgmoogmoOol00003ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Co0000oda<C?m<C4co
00000_mVIVH01_l0003oOgmoogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01oo<c<`0
0ol0003o/k>cok>c/`02o`0000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06
oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00002Oo<c<`0
1Ol0003o/k>cok>c/ol0003oVIVI00;o000000?oIVIVo`000?ooool01Oooool1o`00007ooooo0Ooo
ool001Wooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00?ooooo3OnI
VIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?mo
Ogl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02_mV
IVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<04_nc
/k<00ol0003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol000000omVIVH00ol0003oC4a<
oda<C004oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0003oIVIV
ofIVI_mVIVKo000000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<
00Goc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@03o`000?moOgoo000000?oIVIV00Go0000
oda<C?m<C4coC4a<o`000007oc<c<`07o`000?m<C4coC4a<oda<C?l0003oIVIVo`000002ogmoO`03
o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`02_l0003o/k>cok>c/ol0003oVIVI
o`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Wo0000oda<C?l0003o
IVIVo`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c006o`000?nc/k?o
0000oiVIVOl0003oOgmo0_l000000om<C4coooooooooo`04ooooo`7o00000Oooool1ooooo`006Ooo
ool01Ol0003ooooooooooooooooo000000Kooooo0ol00003ooooo`coVIVI00?o0000ok>c/onc/k<0
5_nc/k<2o`0000goVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`00
0?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`05ogmoO`03o`00
0?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<04_nc/k<00ol0003oVIVIoiVIV@02oiVIV@03o`00
0?moOgooOgmo00;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000005oda<C003o`000?lc<c?o<c<c00Co
<c<c00?o0000oda<C?m<C4`00om<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Co0000oiVI
VOnIVIWo00001?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Ko0000
oiVIVOnIVIWo0000ogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01ol0003o
C4a<oda<C?m<C4co0000ofIVI_l000000_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<co
c<c<00Ooc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0
003o<c<coc<c<`07oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c
00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/ol0003oVIVI00;o000000?oIVIVo`000?m<
C4`01?ooool3o`0000;ooooo000Iooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`03ooooo`_oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03
o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003
o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl01?moOgl00ol0003oVIVIoiVIV@05oiVIV@03
o`000?nc/k?o/k>c01;o/k>c00?o0000oiVIVOnIVIT00_nIVIT00ol0003oOgmoogmoO`02ogmoO`05
o`000?mVIVKoIVIVofIVI_l000001Om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<
00?oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Co/k>c00?o
0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`06o`000?nIVIWoVIVIo`000?moOgoo
00000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Oo0000oda<C?m<C4coC4a<o`000?mV
IVKo000000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc
/k?o/k>co`0000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo
<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<
c006olc<c005o`000?nc/k?o/k>co`000?nIVIT00_l000000omVIVKo0000oda<C006ooooo`7o0000
0Oooool1ooooo`006Oooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool0
0oooool:oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmo
ogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIV
ofIVIP0;ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>c
ok>c/`0Bok>c/`03o`000?nIVIWoVIVI00;oVIVI00?o0000ogmoOomoOgl00_moOgl01Ol0003oIVIV
ofIVI_mVIVKo000000GoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C005
o`000?mVIVKoIVIVofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<co
c<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01_l0003oVIVIoiVIVOl0003oOgmoo`0000;oIVIV
00Go0000oda<C?m<C4coC4a<o`000008oc<c<`07o`000?m<C4coC4a<oda<C?l0003oIVIVo`000002
ogmoO`03o`000?nIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`02_l0003o/k>cok>c/ol0
003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Oo0000oda<
C?l0003oIVIVo`000?moOgoo000000;oVIVI00?o0000ok>c/ol000002Oo<c<`01?l0003o/k>co`00
0?nIVIT2o`000005ofIVI_l0003oC4a<oda<C?l000001Oooool1o`00007ooooo0Oooool001Wooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00?ooooo2OnIVIT00ol0003o
/k>cok>c/`0Fok>c/`;o00003OnIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_o
IVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0:ofIVIP;o00001omoOgl00ol0003o
VIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003o
OgmoogmoOomoOgoo000000?oIVIV00?o0000oda<C?m<C4`01?m<C4`00ol0003o<c<coc<c<`04oc<c
<`03o`000?m<C4coC4a<00?oC4a<00Co0000ofIVI_mVIVKo00000omoOgl01?l0003oVIVIoiVIVOl0
0004ok>c/`03o`000?o<c<coc<c<00Goc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`00
0?moOgooOgmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`04o`000?m<C4coC4a<
o`0000;oIVIV00Ko0000ogmoOol0003o0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<
00_o0000ok>c/onc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc
<c?o<c<c00Ko<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<0
0ol0003oc<c<olc<c007olc<c004o`000?nc/k?o0000oiVIV@;o000000GoIVIVo`000?m<C4coC4a<
o`000005ooooo`7o00000Oooool1ooooo`006Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo
00?o0000ooooooooool00oooool8oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT0
3?nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`0
5om<C4`00ol0003oIVIVofIVIP0:ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT0
1OnIVIT00ol0003o/k>cok>c/`0Cok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomoOgoo
Ogmoo`000003ofIVIP03o`000?m<C4coC4a<00CoC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003o
C4a<oda<C003oda<C004o`000?mVIVKoIVIVo`0000?oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<0
0ol0003oc<c<olc<c005olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmo
Ool00002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01?l0003oC4a<oda<C?l00002ofIV
IP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`02ol0003o/k>cok>c/onc
/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02_l0
003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Oo
c<c<00Co0000ok>c/ol0003oVIVI0_l000001OmVIVKo0000oda<C?m<C4co000000Gooooo0Ol00001
ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo1onIVIT00ol0003o/k>cok>c/`0Fok>c
/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIV
IP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`05ogmo
O`03o`000?nIVIWoVIVI00GoVIVI00?o0000ok>c/onc/k<04onc/k<00ol0003oVIVIoiVIV@02oiVI
V@05o`000?moOgooOgmoogmoOol000000omVIVH00ol0003oC4a<oda<C004oda<C003o`000?lc<c?o
<c<c00Co<c<c00?o0000oda<C?m<C4`00om<C4`01?l0003oIVIVofIVI_l00003ogmoO`04o`000?nI
VIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`01Ol0003o/k>cok>c/onc/k?o000000;o
VIVI00Co0000ogmoOomoOgoo00000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Co0000
oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<
00_o0000ok>c/onc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc
<c?o<c<c00Ko<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`;o00000_nc/k<00ol0003o
c<c<olc<c007olc<c00;o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00000
1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool6oiVIV@03o`000?nc
/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT2o`0000[oOgmo00?o0000ofIVI_mVIVH02_mV
IVH2o`0001SoC4a<0_l0000<ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT01OnI
VIT00ol0003o/k>cok>c/`0Cok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomoOgooOgmo
o`000004ofIVIP03o`000?m<C4coC4a<00?oC4a<0_l00005oc<c<`03o`000?m<C4coC4a<00?oC4a<
00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000onc/k<00ol0
003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol0
0002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP03
o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01?l0003o/k>cok>c/ol00002
oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0:o`000?m<
C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`0
3?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000Kooooo0Ol00001
ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo1OnIVIT00ol0003o/k>cok>c/`0Fok>c
/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0:ofIV
IP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`06ogmo
O`03o`000?nIVIWoVIVI00GoVIVI00?o0000ok>c/onc/k<04onc/k<00ol0003oVIVIoiVIV@02oiVI
V@05o`000?moOgooOgmoogmoOol000001?mVIVH00ol0003oC4a<oda<C003oda<C003o`000?lc<c?o
<c<c00Co<c<c00?o0000oda<C?m<C4`00om<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Go
0000oiVIVOnIVIWoVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o
/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008
oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c
/ol00008olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<
C003o`000?lc<c?o<c<c00Ko<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo
00000_nc/k<00ol0003oc<c<olc<c006olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0
003oIVIVo`000?m<C4co00001_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool0
0oooool4oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmo
ogmoO`09ogmoO`03o`000?mVIVKoIVIV00[oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIV
ofIVIP0;ofIVIP03o`000?moOgooOgmo00KoOgmo00?o0000oiVIVOnIVIT01OnIVIT00ol0003o/k>c
ok>c/`0Cok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`000004ofIVIP03
o`000?m<C4coC4a<00?oC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C005
o`000?mVIVKoIVIVofIVI_l000000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000?o/k>c00?o0000
olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo0000
0_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0
003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Co0000ok>c/onc/k?o00000_nI
VIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<
oda<C?l00002ofIVIP;o000000GoVIVIo`000?nc/k?o/k>co`000009olc<c00<o`000?nc/k?o0000
oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l0003o<c<c1_ooool1o`00007ooooo0Oooool002Co
oooo00?o0000ooooooooool00oooool3oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnI
VIT02onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00[oIVIV0_l0000Hoda<C003
o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl01_moOgl00ol0003oVIVIoiVIV@05oiVIV@03
o`000?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT00_nIVIT00ol0003oOgmoogmoO`02ogmoO`05
o`000?mVIVKoIVIVofIVI_l000001_m<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<
00?oC4a<00Co0000ofIVI_mVIVKo00000omoOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<
c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;o
IVIV00Co0000oda<C?m<C4co00002Olc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo
000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@05o`00
0?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0:o`000?m<C4coC4a<o`00
0?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`03Ol0003o/k>c
ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`000?lc<c<01_ooool1o`00007ooooo
0Oooool002Cooooo0_l00004ooooo`;oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVI
V@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<oda<
C00Goda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl01_moOgl00ol0003oVIVIoiVI
V@06oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT00_nIVIT00ol0003oOgmoogmo
O`02ogmoO`05o`000?mVIVKoIVIVofIVI_l000001_m<C4`00ol0003o<c<coc<c<`04oc<c<`03o`00
0?m<C4coC4a<00?oC4a<00Co0000ofIVI_mVIVKo00000omoOgl01?l0003oVIVIoiVIVOl00004ok>c
/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgoo
Ogmoo`0000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<01?l0003oC4a<oda<C?l00002ofIVIP03
o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01?l0003o/k>cok>c/ol00002
oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0:o`000?m<
C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`0
3Ol0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`000?lc<c<01Oooool2
o`0000;ooooo000Tooooo`03o`000?oooooooooo00?ooooo00?oVIVIo`000?nc/k<05onc/k<00ol0
003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02_mVIVH00ol0
003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl01omoOgl00ol0
003oVIVIoiVIV@05oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT00_nIVIT00ol0
003oOgmoogmoO`02ogmoO`05o`000?mVIVKoIVIVofIVI_l000001_m<C4`00ol0003o<c<coc<c<`04
oc<c<`03o`000?m<C4coC4a<00?oC4a<00Co0000ofIVI_mVIVKo00000omoOgl01?l0003oVIVIoiVI
VOl00004ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04
o`000?moOgooOgmoo`0000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<01?l0003oC4a<oda<C?l0
0002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`02_l0003o/k>c
ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c00?o
0000oda<C?m<C4`00_l000001omoOgoo0000oiVIVOnIVIWo0000ok>c/ol000002?o<c<`03?l0003o
/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000;o<c<c1_ooool1o`00007o
oooo0Oooool002Cooooo00?o0000ooooooooool00oooool00ol0003o/k>cok>c/`0Fok>c/`03o`00
0?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`00
0?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`07ogmoO`03o`00
0?nIVIWoVIVI00GoVIVI00?o0000ok>c/onc/k<04onc/k<00ol0003oVIVIoiVIV@03oiVIV@05o`00
0?moOgooOgmoogmoOol000001?mVIVH00ol0003oC4a<oda<C004oda<C003o`000?lc<c?o<c<c00?o
<c<c00?o0000oda<C?m<C4`00om<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Go0000oiVI
VOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<0
1?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000;oC4a<00?o0000oc<c<olc<c<0
1_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o
/k>cok>c/ol00008olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Go0000ogmoOol0003oIVIVo`00
0002oda<C003o`000?lc<c?o<c<c00Ko<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`00
0?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000
ogmoOol0003oIVIVo`000?m<C4co00000_lc<c<6ooooo`7o00000Oooool1ooooo`009?ooool00ol0
003oooooooooo`03oooooaSo/k>c0_l0000<oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIV
I_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmo
OomoOgl01omoOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c01;o/k>c00?o0000oiVI
VOnIVIT01?nIVIT01Ol0003oOgmoogmoOomoOgoo000000CoIVIV00?o0000oda<C?m<C4`00om<C4`0
0ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Go0000ofIVI_mVIVKoIVIVo`00
0002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c003o`00
0?nc/k?o/k>c00;o/k>c00Ko0000oiVIVOnIVIWo0000ogmoOol00002ofIVIP05o`000?m<C4coC4a<
oda<C?l000002?lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o0000ogmoOol000000_nI
VIT01?l0003o/k>cok>c/ol00008olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Go0000ogmoOol0
003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00[o0000oda<C?m<C4co0000ofIVI_l0
003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c00<o`000?nc/k?o/k>co`00
0?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co00000_lc<c<6ooooo`7o00000Oooool1ooooo`00
9?ooool00ol0003oooooooooo`03oooooaOo/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmo
ogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIV
ofIVIP0;ofIVIP03o`000?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>c
ok>c/`0Cok>c/`03o`000?nIVIWoVIVI00?oVIVI00Go0000ogmoOomoOgooOgmoo`000004ofIVIP03
o`000?m<C4coC4a<00CoC4a<00?o0000oc<c<olc<c<00olc<c<00ol0003oC4a<oda<C004oda<C004
o`000?mVIVKoIVIVo`0000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<co
c<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mV
IVKoIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01olc<c<01?l0003oC4a<oda<C?l00002ofIVIP03
o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`00ol0003o/k>co`000002oiVI
V@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`06o`000?m<C4co
C4a<o`000?mVIVKo00000_moOgl2o`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02_l0003o/k>c
ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Kooooo0Ol0
0001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo5_nc/k<00ol0003oVIVIoiVIV@0;
oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00F
oda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@06
oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT00onIVIT01?l0003oOgmoogmoOomo
Ogl2o`0000?oIVIV00?o0000oda<C?m<C4`01?m<C4`00ol0003o<c<coc<c<`03oc<c<`03o`000?m<
C4coC4a<00CoC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVIVOl0
00000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0
003oOgmoogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01Ol0003oC4a<oda<
C?m<C4co000000;oIVIV00?o0000ogmoOol000000_nIVIT00ol0003o/k>co`00000:olc<c003o`00
0?nc/k?o000000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko
<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<
olc<c006olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co0000
0olc<c<6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03oooooaGo/k>c0_l0
000<oiVIV@03o`000?moOgooOgmo00SoOgmo0_l0000=ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o
0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00GoVIVI00?o
0000ok>c/onc/k<05?nc/k<00ol0003oVIVIoiVIV@03oiVIV@05o`000?moOgooOgmoogmoOol00000
1?mVIVH00ol0003oC4a<oda<C004oda<C003o`000?lc<c?o<c<c00?o<c<c00?o0000oda<C?m<C4`0
1?m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0
003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol0
0002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01Ol0003oC4a<oda<C?m<C4co000000;o
IVIV00?o0000ogmoOol000000_nIVIT00ol0003o/k>co`00000:olc<c003o`000?nc/k?o000000;o
VIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00[o0000oda<
C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c00<
o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co00000olc<c<6ooooo`7o
00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03oooooaCo/k>c00?o0000oiVIVOnIVIT0
2onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00coIVIV00?o0000oda<C?m<C4`0
5_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT0
1OnIVIT00ol0003o/k>cok>c/`0Dok>c/`03o`000?nIVIWoVIVI00?oVIVI00Go0000ogmoOomoOgoo
Ogmoo`000004ofIVIP03o`000?m<C4coC4a<00CoC4a<00?o0000oc<c<olc<c<00olc<c<00ol0003o
C4a<oda<C004oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01Ol0003oVIVIoiVIVOnIVIWo
000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co
0000ogmoOomoOgoo00000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Go0000oda<C?m<
C4coC4a<o`000002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`0
0ol0003o/k>co`000002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c
<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV0_l000001OnIVIWo0000ok>c/onc/k?o000000So
c<c<00Co0000ok>c/onc/k?o/k>c0_l000001_moOgoo0000ofIVI_l0003oC4a<o`0000Co<c<c1_oo
ool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00ooooolCok>c/`03o`000?nIVIWo
VIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP;o00006?m<C4`0
0ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00OoOgmo0_l00008oiVIV@03o`000?nc/k?o
/k>c01?o/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKo
IVIV00;oIVIV00?o0000oda<C?m<C4`01?m<C4`00ol0003o<c<coc<c<`03oc<c<`03o`000?m<C4co
C4a<00?oC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c
00?o0000olc<c?o<c<`01Oo<c<`2o`0000?o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0003o
IVIVofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Oo0000oda<C?m<C4coC4a<o`000?mV
IVKo000000;oOgmo00?o0000oiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc
/k?o/k>co`0000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko
<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<
olc<c006olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co0000
1?lc<c<6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03oooooa;o/k>c00?o
0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00coIVIV00?o
0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?moOgooOgmo00OoOgmo00?o
0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`0Dok>c/`03o`000?nIVIWoVIVI00?oVIVI00?o
0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP02ofIVIP03o`000?m<C4coC4a<00CoC4a<00?o
0000oc<c<olc<c<00_lc<c<00ol0003oC4a<oda<C004oda<C005o`000?mVIVKoIVIVofIVI_l00000
0omoOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc
/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000;oC4a<00?o0000
oc<c<olc<c<01olc<c<01ol0003oC4a<oda<C?m<C4co0000ofIVI_l000000_moOgl00ol0003oVIVI
o`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT01Ol0003o
Ogmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02_l0003oC4a<oda<C?l0003o
IVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00co0000ok>c/onc
/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00004oc<c<`Kooooo0Ol00001ooooo`7o
oooo000Tooooo`;o00001?oooolAok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl0
2?moOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH0
2omVIVH2o`0000WoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`0Dok>c/`03o`00
0?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP02ofIVIP03o`00
0?m<C4coC4a<00CoC4a<00?o0000oc<c<olc<c<00olc<c<00ol0003oC4a<oda<C004oda<C004o`00
0?mVIVKoIVIVo`0000?oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c005olc<
c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l0
0003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo000000;o
Ogmo00Co0000oiVIVOnIVIWo00000_nc/k<00ol0003oc<c<olc<c007olc<c00:o`000?nc/k?o/k>c
o`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01olc<c<00ol0003o
C4a<oda<C002o`000005ogmoOol0003oVIVIoiVIVOl000000_nc/k<00ol0003oc<c<olc<c005olc<
c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl2o`000003oda<C?l0003o<c<c00Co<c<c1Ooo
ool2o`0000;ooooo000Tooooo`03o`000?oooooooooo00?ooooo4?nc/k<00ol0003oVIVIoiVIV@0;
oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH2o`0001SoC4a<00?o0000
ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o0000
ok>c/onc/k<05?nc/k<00ol0003oVIVIoiVIV@03oiVIV@03o`000?moOgooOgmo00;oOgmo00?o0000
ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C005oda<C003o`000?lc<c?o<c<c00;o<c<c00?o0000
oda<C?m<C4`01?m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Go0000oiVIVOnIVIWoVIVI
o`000004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVI
oiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0
003oC4a<oda<C?l00002ofIVIP06o`000?moOgooOgmoo`000?nIVIWo00000onc/k<00ol0003oc<c<
olc<c006olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl00ol0003oIVIVo`000002oda<
C003o`000?lc<c?o<c<c00Ko<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo
00000_nc/k<00ol0003oc<c<olc<c006olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0
003oIVIVo`000?m<C4co00001Olc<c<6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003ooooo
ooooo`03ooooo`oo/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`07ogmoO`03o`00
0?mVIVKoIVIV00coIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`00
0?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`0Dok>c/`03o`00
0?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP02ofIVIP03o`00
0?m<C4coC4a<00GoC4a<00?o0000oc<c<olc<c<00_lc<c<00ol0003oC4a<oda<C004oda<C005o`00
0?mVIVKoIVIVofIVI_l000000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Co/k>c00?o0000olc<
c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co0000
ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV
00Ko0000ogmoOomoOgoo0000oiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Ko0000ok>c
/onc/k?o0000oiVIVOl00002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc
<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<co
c<c<00Koc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00005
oc<c<`Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo3onc/k<00ol0
003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0
003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0
003oVIVIoiVIV@07oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0
003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01Om<C4`00ol0
003o<c<coc<c<`02oc<c<`03o`000?m<C4coC4a<00CoC4a<00Go0000ofIVI_mVIVKoIVIVo`000003
ogmoO`04o`000?nIVIWoVIVIo`0000Go/k>c00?o0000olc<c?o<c<`01Oo<c<`01Ol0003o/k>cok>c
/onc/k?o000000?oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01?l0003oC4a<oda<C?l00009oc<c
<`04o`000?m<C4coC4a<o`0000;oIVIV00Ko0000ogmoOomoOgoo0000oiVIVOl00002ok>c/`03o`00
0?o<c<coc<c<00Ooc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV00Co0000
oda<C?m<C4co00002?lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002
ok>c/`03o`000?o<c<coc<c<00Koc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mV
IVKo0000oda<C?l00005oc<c<`Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo
00?ooooo3_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIV
I_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmo
OomoOgl02?moOgl00ol0003oVIVIoiVIV@07oiVIV@03o`000?nc/k?o/k>c01Co/k>c00?o0000oiVI
VOnIVIT00onIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<
C?m<C4`01Om<C4`01Ol0003o<c<coc<c<olc<c?o000000OoC4a<00Go0000ofIVI_mVIVKoIVIVo`00
0002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0003oc<c<olc<c005olc<c003o`00
0?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00003oda<
C003o`000?lc<c?o<c<c00Ko<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00?o
0000oiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c006o`000?nc/k?o/k>co`000?nIVIWo
00000_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Ko0000oda<C?m<
C4co0000ofIVI_l00002ogmoO`;o00000_nc/k<00ol0003oc<c<olc<c007olc<c009o`000?nc/k?o
0000oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<00olc<c<6ooooo`7o
00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`co/k>c0_l0000=oiVIV@03o`00
0?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C0;o0000
3?mVIVH2o`0000[oOgmo00?o0000oiVIVOnIVIT01onIVIT00ol0003o/k>cok>c/`0Dok>c/`03o`00
0?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP02ofIVIP03o`00
0?m<C4coC4a<00GoC4a<00?o0000oc<c<olc<c<00_lc<c<00ol0003oC4a<oda<C004oda<C005o`00
0?mVIVKoIVIVofIVI_l000000omoOgl01Ol0003oVIVIoiVIVOnIVIWo000000Co/k>c00?o0000olc<
c?o<c<`01Oo<c<`01Ol0003o/k>cok>c/onc/k?o000000?oVIVI00Co0000ogmoOomoOgoo00000_mV
IVH01?l0003oC4a<oda<C?l00008oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01_l0003o
OgmoogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01oo<c<`01_l0003o/k>cok>c/ol0
003oVIVIo`0000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0:o`00
0?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01oo<
c<`02ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co000000Ko<c<c1_ooool1
o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool<ok>c/`03o`000?nIVIWoVIVI
00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<
01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI
00OoVIVI00?o0000ok>c/onc/k<05Onc/k<00ol0003oVIVIoiVIV@03oiVIV@03o`000?moOgooOgmo
00;oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C005oda<C003o`000?lc<c?o<c<c
00;o<c<c00?o0000oda<C?m<C4`01?m<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Go0000
oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Goc<c<00Go0000ok>c/onc/k?o/k>c
o`000003oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<01Ol0
003oC4a<oda<C?m<C4co000000;oIVIV00Ko0000ogmoOomoOgoo0000oiVIVOl00002ok>c/`03o`00
0?o<c<coc<c<00Ooc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`03o`000?mVIVKo0000
00;oC4a<00?o0000oc<c<olc<c<01_lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000
oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<0_l00002oiVIV@07o`000?moOgoo0000ofIV
I_l0003oC4a<o`000006oc<c<`Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo
00?ooooo2onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIV
I_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmo
OomoOgl02OmoOgl00ol0003oVIVIoiVIV@08oiVIV@03o`000?nc/k?o/k>c01Co/k>c00?o0000oiVI
VOnIVIT00onIVIT00ol0003oOgmoogmoO`03ogmoO`05o`000?mVIVKoIVIVofIVI_l000001om<C4`0
0ol0003o<c<coc<c<`02oc<c<`03o`000?m<C4coC4a<00GoC4a<00Co0000ofIVI_mVIVKo00000omo
Ogl01Ol0003oVIVIoiVIVOnIVIWo000000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`01Ol0003o/k>c
ok>c/onc/k?o000000?oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01?l0003oC4a<oda<C?l00009
oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Ko0000ogmoOomoOgoo0000oiVIVOl00002ok>c/`03
o`000?o<c<coc<c<00Ooc<c<00Co0000ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mVIVKo
000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP;o000000Go
VIVIo`000?nc/k?o/k>co`000009olc<c00;o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo
0000oda<C?l000001olc<c<6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03
ooooo`Wo/k>c0_l0000=oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH0
0ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02OmoOgl0
0ol0003oVIVIoiVIV@08oiVIV@03o`000?nc/k?o/k>c01Co/k>c00?o0000oiVIVOnIVIT00onIVIT2
o`0000CoOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C005oda<C005o`000?lc<c?o
<c<coc<c<ol000001om<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Go0000oiVIVOnIVIWo
VIVIo`000004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003o
VIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01olc<c<0
1?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o0000
2Oo<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0
003o<c<coc<c<`06oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o
/k>c00?o0000olc<c?o<c<`01_o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIV
I_l0003oC4a<o`0000Oo<c<c1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool0
0oooool8ok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIV
ofIVIP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmo
ogmoO`09ogmoO`03o`000?nIVIWoVIVI00SoVIVI00?o0000ok>c/onc/k<05Onc/k<00ol0003oVIVI
oiVIV@03oiVIV@03o`000?moOgooOgmo00?oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<
oda<C005oda<C005o`000?lc<c?o<c<coc<c<ol000001om<C4`01Ol0003oIVIVofIVI_mVIVKo0000
00;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000
ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<
00?o0000oc<c<olc<c<01olc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;o
VIVI00Co0000ok>c/onc/k?o00002Oo<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00?o
0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo
0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`03?l0003o/k>cok>c/ol0
003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000Oo<c<c1_ooool1o`00007ooooo0Oooool0
02Cooooo00?o0000ooooooooool00oooool7ok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmo
OomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIV
I_mVIVH02_mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00SoVIVI00?o0000ok>c
/onc/k<05Onc/k<00ol0003oVIVIoiVIV@03oiVIV@03o`000?moOgooOgmo00?oOgmo00?o0000ofIV
I_mVIVH00_mVIVH00ol0003oC4a<oda<C005oda<C005o`000?lc<c?o<c<coc<c<ol000001om<C4`0
1Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<
olc<c005olc<c003o`000?nc/k?o/k>c00?o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0003o
IVIVofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Co0000oda<C?m<C4co00000_mVIVH0
1_l0003oOgmoogmoOol0003oVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01_l0003o/k>c
ok>c/ol0003oVIVIo`0000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c
<`04o`000?m<C4coC4a<oda<C0;o000000OoOgmoo`000?nIVIWoVIVIo`000?nc/k?o000000Soc<c<
00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`;o000000?oC4a<o`000?lc<c<01olc<c<6oooo
o`7o00000Oooool1ooooo`009?ooool2o`0000Cooooo1_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@;o
00002_moOgl00ol0003oIVIVofIVIP0:ofIVIP;o00006?m<C4`2o`0000coIVIV00?o0000ogmoOomo
Ogl02OmoOgl00ol0003oVIVIoiVIV@09oiVIV@03o`000?nc/k?o/k>c01Co/k>c00?o0000oiVIVOnI
VIT01?nIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<
C4`01Om<C4`00ol0003o<c<coc<c<`02oc<c<`03o`000?m<C4coC4a<00CoC4a<00Go0000ofIVI_mV
IVKoIVIVo`000003ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0003oc<c<olc<c005
olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIV
I_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP03
o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`02Ol0003o/k>cok>c/onc/k?o
0000oiVIVOl0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00[o0000oda<C?m<
C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c00<o`00
0?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co00002?lc<c<5ooooo`;o0000
0_ooool002Cooooo00?o0000ooooooooool00oooool5ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o
0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o
0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00WoVIVI00?o
0000ok>c/onc/k<05Onc/k<00ol0003oVIVIoiVIV@03oiVIV@03o`000?moOgooOgmo00;oOgmo00?o
0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C005oda<C003o`000?lc<c?o<c<c00;o<c<c00?o
0000oda<C?m<C4`00om<C4`00ol0003oIVIVofIVIP02ofIVIP05o`000?moOgooOgmoogmoOol00000
0onIVIT00ol0003o/k>cok>c/`02ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<0
0onc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c
<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o0000ogmoOol000000_nIVIT0
1?l0003o/k>cok>c/ol00008olc<c009o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000?moOgoo0000
00;oIVIV00Co0000oda<C?m<C4co00002?lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo
0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o0000ok>c/onc/k<00_l00002ogmo
O`05o`000?mVIVKo0000oda<C?l000002?lc<c<00ol0003oooooooooo`03ooooo`7o00000Oooool1
ooooo`009?ooool00ol0003oooooooooo`03ooooo`Co/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0
003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00[oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0
003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02OnIVIT00ol0
003o/k>cok>c/`0Eok>c/`03o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl00omoOgl00ol0
003oIVIVofIVIP02ofIVIP03o`000?m<C4coC4a<00GoC4a<00?o0000oc<c<olc<c<00_lc<c<00ol0
003oC4a<oda<C004oda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01Ol0003oVIVIoiVIVOnI
VIWo000000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nI
VIWoVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`05
o`000?m<C4coC4a<oda<C?l000000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>c
o`0000Woc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`03o`000?mVIVKo000000;oC4a<
00?o0000oc<c<olc<c<01_lc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo0_l00002ok>c
/`03o`000?o<c<coc<c<00Ooc<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00000
0_m<C4`00ol0003o<c<coc<c<`06oc<c<`03o`000?oooooooooo00?ooooo0Ol00001ooooo`7ooooo
000Tooooo`03o`000?oooooooooo00?ooooo0onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?mo
OgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02_mVIVH2o`0001SoC4a<00?o0000ofIVI_mVIVH02omV
IVH00ol0003oOgmoogmoO`08ogmoO`;o00002onIVIT00ol0003o/k>cok>c/`0Eok>c/`03o`000?nI
VIWoVIVI00CoVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP02ofIVIP03o`000?m<
C4coC4a<00KoC4a<0ol000000olc<c?o0000oda<C006oda<C005o`000?mVIVKoIVIVofIVI_l00000
0_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Go/k>c00?o0000olc<c?o<c<`01Oo<c<`01Ol0003o
/k>cok>c/onc/k?o000000?oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01Ol0003oC4a<oda<C?m<
C4co000000So<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00Co0000oiVIVOnI
VIWo00000_nc/k<00ol0003oc<c<olc<c007olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmo
Ool00002ofIVIP03o`000?m<C4co000000Wo<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmo
o`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c007olc<c00;o`000?nc/k?o0000oiVIVOl0003o
Ogmoo`000?mVIVKo0000oda<C?l000002?lc<c<00ol0003oooooooooo`04ooooo`7o00000Oooool1
ooooo`009?ooool00ol0003oooooooooo`03ooooo`;o/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0
003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00[oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0
003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0
003o/k>cok>c/`0Eok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl00_moOgl00ol0
003oIVIVofIVIP02ofIVIP03o`000?m<C4coC4a<00KoC4a<00Co0000oda<C?m<C4co00002?m<C4`0
1Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`00
0?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000003oiVIV@04o`000?moOgooOgmoo`00
00;oIVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`07o`000?m<C4coC4a<oda<C?l0003oIVIV
o`000002ogmoO`04o`000?nIVIWoVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01oo<c<`02?l0003o
/k>cok>c/ol0003oVIVIo`000?moOgoo00000_mVIVH00ol0003oC4a<o`000009oc<c<`0:o`000?m<
C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01oo<c<`0
2ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co000000So<c<c00?o0000oooo
ooooool01?ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool00onc/k?o
0000oiVIV@0<oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02_mVIVH00ol0003o
C4a<oda<C00Goda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003o
VIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Go/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0003o
OgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<C4`01Om<C4`00ol0003o
<c<co`000009oda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01?l0003oVIVIoiVIVOl00005
ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl0
0002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01ol0003oC4a<
oda<C?m<C4co0000ofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00002ok>c/`03o`000?o<c<co
c<c<00Ooc<c<00Co0000ok>c/onc/k?o00000_nIVIT2o`0000;oIVIV00Co0000oda<C?m<C4co0000
2?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP;o000000GoVIVIo`000?nc/k?o/k>co`000009olc<
c007o`000?nc/k?o0000oiVIVOl0003oOgmoo`000002ofIVIP;o00002?lc<c<00ol0003oC4a<oooo
o`05ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`03o`000?nIVIWo
VIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4co
C4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWo
VIVI00_oVIVI00?o0000ok>c/onc/k<05Onc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgoo
Ogmo00;oOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C006oda<C004o`000?lc<c?o
<c<co`0000OoC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`05o`000?nIVIWoVIVIoiVIVOl0
00001?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00?o0000oiVIVOnI
VIT00_l000000omoOgoo0000ofIVIP02ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01?l0
003oC4a<oda<C?l00002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o0000
2?o<c<`00ol0003o/k>cok>c/`02o`000004oiVIVOl0003oOgmoo`0000;oIVIV00Co0000oda<C?m<
C4co00002?lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03
o`000?o<c<coc<c<00Koc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000
oda<C?l00008oc<c<`03o`000?m<C4cooooo00Gooooo0Ol00001ooooo`7ooooo000Iooooo`Go0000
1_ooool00ol0003oooooooooo`03ooooo`03o`000?nIVIWoVIVI00[oVIVI00?o0000ogmoOomoOgl0
2OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH0
2omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00coVIVI00?o0000ok>c/onc/k<0
5Onc/k<00ol0003oVIVIoiVIV@03oiVIV@03o`000?moOgooOgmo00?oOgmo00?o0000ofIVI_mVIVH0
0omVIVH00ol0003oC4a<oda<C006oda<C004o`000?lc<c?o<c<co`0000KoC4a<00?o0000ofIVI_mV
IVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000?oVIVI00?o0000ok>c/onc/k<00_nc/k<00ol0
003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl0
1Ol0003oIVIVofIVI_mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01Olc<c<01Ol0003oC4a<oda<
C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01?l0003o/k>cok>c/ol00008olc<
c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l0
0008oc<c<`03o`000?m<C4co000000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`00
0?o<c<coc<c<00Koc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<
C?l00008oc<c<`03o`000?m<C4cooooo00Gooooo0Ol00001ooooo`7ooooo000Iooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`03ooooo`coVIVI00?o0000ogmoOomoOgl0
2OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH0
2omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI0_l0000Gok>c/`03o`00
0?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP03ofIVIP03o`00
0?m<C4coC4a<00SoC4a<0_l00007oda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01Ol0003o
VIVIoiVIVOnIVIWo000000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c
/`04o`000?nIVIWoVIVIo`0000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000003oda<C003o`000?lc
<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP03o`000?moOgoo000000;oVIVI
00Co0000ok>c/onc/k?o00002?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo0000
00;oIVIV00Co0000oda<C?m<C4co00002?lc<c<02?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo
00000_nIVIT01?l0003o/k>cok>c/ol00007olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmo
Ool0003oIVIVo`000?m<C4co00002Olc<c<00ol0003oC4a<ooooo`05ooooo`7o00000Oooool1oooo
o`006_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo00?ooooo2onIVIT00ol0003o
OgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003o
IVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o
/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003o
IVIVofIVIP03ofIVIP03o`000?m<C4coC4a<00WoC4a<00?o0000oda<C?m<C4`01Om<C4`00ol0003o
IVIVofIVIP02ofIVIP05o`000?moOgooOgmoogmoOol000000_nIVIT00ol0003o/k>cok>c/`03ok>c
/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002
ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<
C?m<C4co000000;oIVIV00Ko0000ogmoOomoOgoo0000oiVIVOl00003ok>c/`03o`000?o<c<coc<c<
00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4co
C4a<o`0000So<c<c00Wo0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIT00_l000000onc
/k?o0000olc<c007olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<
C4co00002Olc<c<00ol0003oC4a<o`000005ooooo`7o00000Oooool1ooooo`006oooool00onHV9So
8B4Qonk^kP06ooooo`?o00000oooool:oiVIV@03o`000?moOgooOgmo00SoOgmo0_l0000=ofIVIP03
o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03
o`000?nIVIWoVIVI00coVIVI00?o0000ok>c/onc/k<05Onc/k<00ol0003oVIVIoiVIV@05oiVIV@03
o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C00Boda<C005
o`000?mVIVKoIVIVofIVI_l000001?moOgl01?l0003oVIVIoiVIVOl00005ok>c/`03o`000?o<c<co
c<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mV
IVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;o
IVIV00Ko0000ogmoOomoOgoo0000oiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000
ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c
00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<
c006olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co00002Olc
<c<00ol0003oC4a<o`000003ooooo`?o00000_ooool001cooooo00?oMgMgofIVI_ooool01Oooool0
0ol0003oooooooooo`03ooooo`WoVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0<
ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08
ogmoO`03o`000?nIVIWoVIVI00_oVIVI0_l0000Gok>c/`03o`000?nIVIWoVIVI00GoVIVI00?o0000
ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<017oC4a<00?o0000
ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000;oVIVI00?o0000ok>c/onc/k<00onc
/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo0000
0_moOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<
C4coC4a<o`000002ofIVIP06o`000?moOgooOgmoo`000?nIVIWo00000onc/k<00ol0003oc<c<olc<
c006olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Ko0000ogmoOomoOgoo0000ofIVI_l00002oda<
C003o`000?lc<c?o<c<c00Ko<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`;o00000_nc
/k<00ol0003oc<c<olc<c007olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000
00;oC4a<00?o0000oc<c<olc<c<01_lc<c<00ol0003oC4a<o`000006ooooo`7o00000Oooool1oooo
o`007Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo2?nIVIT00ol0003o
OgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV0_l0000Hoda<C003o`000?mVIVKoIVIV00_o
IVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko
/k>c00?o0000oiVIVOnIVIT01OnIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00?o
IVIV00?o0000oda<C?m<C4`04_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Go0000oiVI
VOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<0
1Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<c
oc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01_l0003oOgmoogmoOol0003oVIVI
o`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?mo
Ogoo000000;oIVIV00?o0000oda<C?l000002Olc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?mo
Ogoo0000oiVIVOl0003o/k>co`0000[oc<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIV
I_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`03o`000?m<C4co000000Kooooo0Ol00001oooo
o`7ooooo000Iooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`03oooo
o`OoVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<
01KoC4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmoO`07ogmoO`03o`000?nIVIWoVIVI
00coVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@05oiVIV@03o`000?moOgooOgmo
00;oOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00Aoda<C003o`000?mVIVKoIVIV
00;oIVIV00Go0000ogmoOomoOgooOgmoo`000003oiVIV@03o`000?nc/k?o/k>c00;o/k>c00?o0000
olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_mo
Ogl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4co
C4a<o`000002ofIVIP06o`000?moOgooOgmoo`000?nIVIWo00000onc/k<00ol0003oc<c<olc<c006
olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH00ol0003oC4a<o`00
0009oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00002_o<
c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c
00Ko<c<c00?o0000oda<C?l000001_ooool1o`00007ooooo0Oooool000_ooooo0ol000000ol@413o
ooooooooo`08ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`03oooo
o`KoVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<
01KoC4a<00?o0000ofIVI_mVIVH02omVIVH2o`0000WoOgmo00?o0000oiVIVOnIVIT02onIVIT2o`00
01So/k>c00?o0000oiVIVOnIVIT01OnIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV
00?oIVIV00?o0000oda<C?m<C4`04_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00?o0000
oiVIVOnIVIT00_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Ooc<c<00?o0000ok>c/onc/k<00_nc
/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Co0000ofIVI_mVIVKo00000_m<C4`00ol0003o
<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002
oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Co0000ok>c/onc/k?o00000onIVIT2o`0000;oIVIV
00Co0000oda<C?m<C4co00002?lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVI
VOl00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000
ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4co0000ofIVIPKooooo0Ol0
0001ooooo`7ooooo000=ooooo`03oa0@4?nj^[[ooooo01Cooooo00?o0000ooooooooool00oooool5
oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH2o`0001SoC4a<00?o0000
ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000
ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@05oiVIV@03o`000?moOgooOgmo00?oOgmo00?o0000
ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C00Boda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000
ogmoOomoOgooOgmoo`000003oiVIV@03o`000?nc/k?o/k>c00;o/k>c00?o0000olc<c?o<c<`01Oo<
c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000?oOgmo00Co0000ofIVI_mVIVKo
00000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01_l0
003oOgmoo`000?l0003oVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c
/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`0:
o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`0
1_o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000Wo<c<c
00Go0000oda<C?l0003oIVIVo`000005ooooo`7o00000Oooool1ooooo`003Oooool00onHV9So<S8b
ooooo`0Dooooo`03o`000?oooooooooo00?ooooo1OnIVIT00ol0003oOgmoogmoO`07ogmoO`03o`00
0?mVIVKoIVIV00coIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`00
0?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02_nIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`00
0?nIVIWoVIVI00KoVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP03ofIVIP03o`00
0?m<C4coC4a<01;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000004ogmoO`05o`000?nIVIWoVIVIoiVI
VOl000001?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVI
VOnIVIWo00000omoOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co
0000oda<C?m<C4co00000omVIVH00ol0003oOgmoo`000002oiVIV@05o`000?nc/k?o/k>cok>c/ol0
00002?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l000000om<C4`0
0ol0003o<c<coc<c<`06oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`00
00;o/k>c00?o0000olc<c?o<c<`01_o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000
ofIVI_l0003oC4a<o`0000Wo<c<c00Go0000oda<C?l0003oIVIVo`000005ooooo`7o00000Oooool1
ooooo`003Oooool00ooMgMgo0000okZj^P0Dooooo`03o`000?oooooooooo00?ooooo1?nIVIT00ol0
003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0
003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02_nIVIT00ol0
003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00KoVIVI00?o0000ogmoOomoOgl00omoOgl00ol0
003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<01;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000003
ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001Onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc
/k?o/k>c00?o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00004oda<C003
o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000omVIVH00ol0003oOgmoo`000002oiVI
V@04o`000?nc/k?o/k>co`0000Woc<c<00Co0000ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`00
0?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP05
o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>c
o`000?nIVIT00_l00002ofIVIP03o`000?m<C4co000000Wo<c<c00Co0000oda<C?l0003o00001_oo
ool1o`00007ooooo0Oooool000gooooo00?oEEEEogMgMom4A4@05?ooool00ol0003oooooooooo`03
ooooo`?oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4co
C4a<01KoC4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWo
VIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@06oiVIV@03o`000?moOgoo
Ogmo00?oOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00Boda<C005o`000?mVIVKo
IVIVofIVI_l000000omoOgl00ol0003oVIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c00;o/k>c00?o
0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000?oOgmo
00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<
C?l000000_mVIVH00ol0003oOgmoo`000002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`0
1?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co0000
2?lc<c<02?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo00000_nIVIT01?l0003o/k>cok>c/ol0
0007olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000
oc<c<olc<c<01_lc<c<01Ol0003oC4a<o`000?mVIVKo000000Kooooo0Ol00001ooooo`7ooooo000<
ooooo`05omgMgOl@413oooooob4Q8OoMgMd04oooool00ol0003oooooooooo`03ooooo`;oVIVI00?o
0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<0_l0
000<ofIVIP;o00002_moOgl00ol0003oVIVIoiVIV@0:oiVIV@;o00006Onc/k<00ol0003oVIVIoiVI
V@05oiVIV@03o`000?moOgooOgmo00CoOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<
C00Aoda<C0;o00000omVIVH01Ol0003oOgmoogmoOomoOgoo000000?oVIVI00?o0000ok>c/onc/k<0
0onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00;o/k>c0_l00002oiVIV@04o`00
0?moOgooOgmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`000009oc<c<`05o`000?m<C4coC4a<
oda<C?l000000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Woc<c<00Co
0000ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc
<c<01olc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`00
0?o<c<coc<c<00Koc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<
C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4co0000o`000?moOgl01_ooool1o`00007ooooo
0Oooool000cooooo00GoIVIVohN7QoooooooV9RHoeEEE@0Cooooo`;o00001?ooool00onIVIWo0000
ogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIV
ofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02_nIVIT00ol0003o/k>c
ok>c/`0Hok>c/`03o`000?nIVIWoVIVI00KoVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIV
ofIVIP03ofIVIP03o`000?m<C4coC4a<01;oC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmo
ogmoOomoOgoo000000?oVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c004olc<c003
o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000omoOgl01?l0003oIVIVofIVI_l00003
oda<C003o`000?lc<c?o<c<c00Oo<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP03o`000?mo
Ogoo000000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@05
o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`0:o`000?m<C4coC4a<
o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02_l0003o
/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c
00Go0000oda<C?l0003o0000ogmoO`05ooooo`;o00000_ooool000_ooooo00?ok^k^o`000?o^k^h0
0_ooool00ol0003ogMgMooooo`0Aooooo`03o`000?oooooooooo00?ooooo00?o0000ogmoOomoOgl0
2?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH0
2omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<0
5onc/k<00ol0003oVIVIoiVIV@06oiVIV@03o`000?moOgooOgmo00?oOgmo00?o0000ofIVI_mVIVH0
0omVIVH00ol0003oC4a<oda<C00Boda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgoo
Ogmoo`000004oiVIV@03o`000?nc/k?o/k>c00;o/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o
/k>cok>c/`02ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01?l0003oIVIVofIVI_l00003
oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP03o`000?mo
Ogoo000000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@03
o`000?moOgooOgmo00;o00000_m<C4`00ol0003o<c<coc<c<`07oc<c<`0:o`000?m<C4coC4a<o`00
0?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01oo<c<`02Ol0003o/k>c
o`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Ko0000
oda<C?l0003oIVIVo`000?moOgl6ooooo`7o00000Oooool1ooooo`002oooool01?l@413o0000o`00
0?ooool2o`000003oa0@4?oooooooooo013ooooo00?o0000ooooooooool00oooool:ogmoO`03o`00
0?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`00
0?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02_nIVIT2o`0001Wo/k>c00?o0000oiVIVOnIVIT0
1_nIVIT00ol0003oOgmoogmoO`04ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<C4`0
4_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o
/k>cok>c/`02ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01Ol0003o
VIVIoiVIVOnIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`05
oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@04o`00
0?nc/k?o/k>co`0000Woc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`03o`000?mVIVKo
000000;oC4a<00?o0000oc<c<olc<c<01olc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo
0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00[o0000ok>c/ol0003oVIVIo`000?mo
Ogoo0000ofIVI_l0003oC4a<0_l00008oc<c<`07o`000?m<C4co0000ofIVI_l0003oOgmoo`000005
ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`WoOgmo00?o0000ofIV
I_mVIVH02omVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00[oIVIV00?o0000ogmo
OomoOgl02OmoOgl00ol0003oVIVIoiVIV@0:oiVIV@03o`000?nc/k?o/k>c01So/k>c00?o0000oiVI
VOnIVIT01onIVIT00ol0003oOgmoogmoO`04ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<
C?m<C4`04_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00?o0000oiVIVOnIVIT00_nIVIT0
0ol0003o/k>cok>c/`02ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<0
1Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<c
oc<c<`05oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVI
V@04o`000?nc/k?o/k>co`0000Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT01_l0003oOgmoogmo
Ool0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01olc<c<00ol0003oC4a<oda<C002o`0000;o
Ogmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c00;o`000?nc/k?o0000oiVI
VOl0003oOgmoo`000?mVIVKo0000oda<C?l000002Olc<c<01ol0003oC4a<o`000?mVIVKo0000ogmo
Ool000001Oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool8ogmoO`03
o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0:ofIVIP03
o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Gok>c/`03
o`000?nIVIWoVIVI00OoVIVI00?o0000ogmoOomoOgl01?moOgl00ol0003oIVIVofIVIP03ofIVIP03
o`000?m<C4coC4a<01;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`03o`000?nIVIWoVIVI
00;oVIVI00?o0000ok>c/onc/k<00_nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c
00;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o
0000oc<c<olc<c<01Olc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Oo0000ogmoOomoOgoo
Ogmoo`000?nIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01_l0003o/k>cok>c/ol0003o
VIVIo`0000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`0:o`000?m<
C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01oo<c<`0
2ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co000000Wo<c<c00Oo0000oda<
C?l0003oIVIVo`000?moOgoo000000Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooo
oooo00?ooooo1omoOgl00ol0003oIVIVofIVIP0:ofIVIP;o00006?m<C4`2o`0000coIVIV00?o0000
ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000
oiVIVOnIVIT01onIVIT00ol0003oOgmoogmoO`04ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000
oda<C?m<C4`04_m<C4`00ol0003oIVIVofIVIP02ofIVIP05o`000?moOgooOgmoogmoOol000000onI
VIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00onc
/k<01?l0003oVIVIoiVIVOl00003ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc
<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT0
1?l0003o/k>cok>c/ol00008olc<c007o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000002ogmoO`03
o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01olc<c<00ol0003oC4a<o`000002ofIVIP05
o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c00<o`000?nc/k?o/k>c
o`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co00002Olc<c<01ol0003oC4a<o`000?mVIVKo
0000ogmoOol000001_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool6
ogmoO`03o`000?mVIVKoIVIV00[oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0;
ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0G
ok>c/`03o`000?nIVIWoVIVI00SoVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIVIP03
ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomo
Ogoo000000;oVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc
/k?o/k>c00;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`04o`000?mVIVKoIVIVo`0000?o
C4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmo
OomoOgoo00000_nIVIT01?l0003o/k>cok>c/ol00008olc<c007o`000?nc/k?o/k>cok>c/ol0003o
VIVIo`000002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003o
C4a<oda<C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006
olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co00002Olc<c<0
1ol0003oC4a<o`000?mVIVKo0000ogmoOol000001_ooool1o`00007ooooo0Oooool002Cooooo00?o
0000ooooooooool00oooool5ogmoO`03o`000?mVIVKoIVIV00[oIVIV00?o0000oda<C?m<C4`05om<
C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onI
VIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00SoVIVI00?o0000ogmoOomoOgl00omo
Ogl00ol0003oIVIVofIVIP04ofIVIP03o`000?m<C4coC4a<01;oC4a<00?o0000ofIVI_mVIVH00_mV
IVH01Ol0003oOgmoogmoOomoOgoo000000?oVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<
olc<c003olc<c003o`000?nc/k?o/k>c00?o/k>c00Co0000oiVIVOnIVIWo00000omoOgl01?l0003o
IVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002
ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`01_l0003o/k>c
ok>c/ol0003oVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06
oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000?o/k>c00?o0000olc<
c?o<c<`01_o<c<`02ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co000000Wo
<c<c00?o0000oda<C?l000000_mVIVH2o`000003oiVIVOoooooooooo00Cooooo0Ol00001ooooo`7o
oooo000Tooooo`03o`000?oooooooooo00?ooooo1?moOgl00ol0003oIVIVofIVIP0:ofIVIP;o0000
6?m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo0_l0000=oiVIV@03o`00
0?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02?nIVIT00ol0003oOgmoogmoO`03ogmoO`03o`00
0?mVIVKoIVIV00CoIVIV00?o0000oda<C?m<C4`04_m<C4`00ol0003oIVIVofIVIP02ofIVIP05o`00
0?moOgooOgmoogmoOol000001?nIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00Co
c<c<00?o0000ok>c/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Go0000ofIV
I_mVIVKoIVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`00
0002ofIVIP06o`000?moOgooOgmoo`000?nIVIWo00000onc/k<00ol0003oc<c<olc<c007olc<c006
o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o
<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c
00?o0000olc<c?o<c<`01_o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0
003oC4a<o`0000Wo<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl000001Oooool1
o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool3ogmoO`03o`000?mVIVKoIVIV
00[oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo
00SoOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI
00SoVIVI00?o0000ogmoOomoOgl01?moOgl00ol0003oIVIVofIVIP04ofIVIP03o`000?m<C4coC4a<
01;oC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000CoVIVI00?o0000
ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00;o/k>c00Go0000
oiVIVOnIVIWoVIVIo`000002ogmoO`05o`000?mVIVKoIVIVofIVI_l000000om<C4`00ol0003o<c<c
oc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01_l0003oOgmoogmoOol0003oVIVI
o`0000?o/k>c00?o0000olc<c?o<c<`01oo<c<`02?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo
00000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Go0000
ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00co0000ok>c/onc/k?o0000
oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00009oc<c<`09o`000?m<C4co0000ofIVI_l0003o
Ogmoo`000?nIVIWo000000Gooooo0Ol00001ooooo`7ooooo000Tooooo`;o00001?ooool2ogmoO`03
o`000?mVIVKoIVIV00[oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0;ofIVIP03
o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`0Gok>c/`03
o`000?nIVIWoVIVI00SoVIVI00?o0000ogmoOomoOgl01?moOgl00ol0003oIVIVofIVIP04ofIVIP03
o`000?m<C4coC4a<01;oC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo0000
00CoVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c
00;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`05o`000?mVIVKoIVIVofIVI_l000000om<
C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmo
ogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Woc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl0
0002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01olc<c<00ol0003oC4a<o`00
0002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c009o`00
0?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<0
0ol0003oC4a<oda<C002o`000004ogmoOol0003oVIVIo`0000Gooooo0_l00002ooooo`009?ooool0
0ol0003oooooooooo`03ooooo`03ogmoOol0003oIVIV00coIVIV00?o0000oda<C?m<C4`05_m<C4`0
0ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT03?nIVIT0
0ol0003o/k>cok>c/`0Fok>c/`;o00002_nIVIT00ol0003oOgmoogmoO`04ogmoO`;o00001OmVIVH0
0ol0003oC4a<oda<C00Coda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgooOgmoo`00
0003oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c
/`03ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00004oda<C003
o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01_l0003oIVIVofIVI_l0003oOgmo
o`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c004o`000?nc/k?o/k>co`0000;oVIVI
00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`03o`000?m<C4co000000;o
IVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Wo0000ok>c
/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`09o`00
0?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000Kooooo0Ol00001ooooo`7ooooo000Toooo
o`03o`000?oooooooooo00?ooooo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<
C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0<oiVI
V@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`04ogmo
O`03o`000?mVIVKoIVIV00CoIVIV00?o0000oda<C?m<C4`04om<C4`00ol0003oIVIVofIVIP02ofIV
IP05o`000?moOgooOgmoogmoOol000000onIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<co
c<c<00Coc<c<00?o0000ok>c/onc/k<00onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Co
0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`05oc<c<`05o`000?m<C4coC4a<oda<C?l0
00000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`0
1?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co0000
2Olc<c<00ol0003oC4a<o`000002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003o
c<c<olc<c007olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o
0000oc<c<olc<c<01_lc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000006oooo
o`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`goIVIV00?o0000oda<C?m<
C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnI
VIT02onIVIT2o`0001So/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`04ogmoO`03
o`000?mVIVKoIVIV00CoIVIV00?o0000oda<C?m<C4`04om<C4`00ol0003oIVIVofIVIP02ofIVIP05
o`000?moOgooOgmoogmoOol000000onIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<
00?oc<c<00?o0000ok>c/onc/k<00onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Co0000
ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Ko
0000ofIVI_mVIVKo0000ogmoOol00002oiVIV@03o`000?nc/k?o/k>c00;o/k>c00?o0000olc<c?o<
c<`01Oo<c<`02Ol0003o/k>cok>c/onc/k?o0000oiVIVOl0003oOgmoo`000002ofIVIP04o`000?m<
C4coC4a<o`0000Wo<c<c00?o0000oda<C?l000000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o
/k>c00?o0000olc<c?o<c<`01oo<c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`00
0002oda<C003o`000?lc<c?o<c<c00Oo<c<c0_l000001?mVIVKo0000ogmoOomoOgl2o`000003ok>c
/ooooooooooo00Cooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo3?mV
IVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?mo
Ogl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02_nI
VIT00ol0003oOgmoogmoO`04ogmoO`03o`000?mVIVKoIVIV00CoIVIV00?o0000oda<C?m<C4`04om<
C4`00ol0003oIVIVofIVIP02ofIVIP05o`000?moOgooOgmoogmoOol000001?nIVIT00ol0003o/k>c
ok>c/`03ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00onc/k<01?l0003oVIVI
oiVIVOl00003ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0
003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01Ol0003o/k>cok>c
/onc/k?o000000Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIVIP04
o`000?m<C4coC4a<o`0000So<c<c00Co0000oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nI
VIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?mo
Ogoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00[o0000oda<C?l0003oIVIVo`00
0?moOgoo0000oiVIVOl0003o/k>c1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000oooooooo
ool00oooool;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003o
OgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00coVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003o
VIVIoiVIV@0:oiVIV@03o`000?moOgooOgmo00GoOgmo00?o0000ofIVI_mVIVH01?mVIVH00ol0003o
C4a<oda<C00Coda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgooOgmoo`000004oiVI
V@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c
/`04o`000?nIVIWoVIVIo`0000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000003oda<C003o`000?lc
<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;o
VIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000
ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV
00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00[o0000ok>c/onc
/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0:o`00
0?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/`Kooooo0Ol00001ooooo`7ooooo000T
ooooo`03o`000?oooooooooo00?ooooo2_mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKo
IVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@;o00006?nc/k<0
0ol0003oVIVIoiVIV@0:oiVIV@03o`000?moOgooOgmo00GoOgmo00?o0000ofIVI_mVIVH01?mVIVH0
0ol0003oC4a<oda<C00Coda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgooOgmoo`00
0004oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c
/`03ok>c/`04o`000?nIVIWoVIVIo`0000?oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o
<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002
oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`00
0?moOgoo000000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`0:o`000?m<C4coC4a<o`00
0?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01oo<c<`02Ol0003o/k>c
o`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00?o0000
oda<C?l000000_mVIVH2o`000005oiVIVOl0003o/k>cok>c/ol000001Oooool1o`00007ooooo0Ooo
ool002Cooooo00?o0000ooooooooool00oooool8ofIVIP;o00006?m<C4`00ol0003oIVIVofIVIP0;
ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0G
ok>c/`03o`000?nIVIWoVIVI00[oVIVI00?o0000ogmoOomoOgl01OmoOgl00ol0003oIVIVofIVIP04
ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH00_mVIVH00ol0003oOgmoogmoO`02
ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001_nc/k<00ol0003oc<c<olc<c003olc<c003o`000?nc
/k?o/k>c00?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`05o`000?mVIVKoIVIVofIVI_l0
00000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0
003oOgmoogmoOol00002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01?l0003o/k>cok>c
/ol00002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<01?l0003o
C4a<oda<C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006
olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co00002Olc<c<0
2Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?oooooooooo00?o
oooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo2?mVIVH00ol0003oC4a<
oda<C00Foda<C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl01omoOgl00ol0003oVIVI
oiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmo
ogmoO`05ogmoO`03o`000?mVIVKoIVIV00GoIVIV00?o0000oda<C?m<C4`04om<C4`00ol0003oIVIV
ofIVIP02ofIVIP03o`000?moOgooOgmo00;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000006ok>c/`03
o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00onc/k<01Ol0003oVIVIoiVIVOnIVIWo0000
00;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000
oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o
/k>co`000008olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0
003oC4a<oda<C?l00008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Go0000ogmoOol0003oVIVI
o`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmo
o`000?mVIVKo0000oda<C?l00009oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo
000000;o/k>c00?o0000ooooooooool00oooool1o`00007ooooo0Oooool002Cooooo00?o0000oooo
ooooool00oooool7ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH2o`00
00WoOgmo00?o0000oiVIVOnIVIT02onIVIT2o`0001Oo/k>c0_l0000<oiVIV@03o`000?moOgooOgmo
00GoOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<C00Coda<C003o`000?mVIVKoIVIV
00;oIVIV00?o0000ogmoOomoOgl00_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Ko/k>c00?o0000
olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`03ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_mo
Ogl01Ol0003oIVIVofIVI_mVIVKo000000CoC4a<00?o0000oc<c<olc<c<01Olc<c<01Ol0003oC4a<
oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01Ol0003o/k>cok>c/onc/k?o
000000Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<
C4coC4a<o`0000Wo<c<c00?o0000oda<C?l000000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o
/k>c00?o0000olc<c?o<c<`01oo<c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`00
0002oda<C003o`000?lc<c?o<c<c00Ko<c<c00?o0000oda<C?m<C4`00_l000001omoOgoo0000oiVI
VOnIVIWo0000ok>c/ol000001_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool0
0oooool5ofIVIP;o00006?m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo
00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI
00?o0000ogmoOomoOgl01_moOgl00ol0003oIVIVofIVIP04ofIVIP03o`000?m<C4coC4a<01?oC4a<
00?o0000ofIVI_mVIVH00omVIVH01Ol0003oOgmoogmoOomoOgoo000000CoVIVI00?o0000ok>c/onc
/k<00onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Co0000oiVIVOnI
VIWo00000omoOgl01?l0003oIVIVofIVI_l00004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000
oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000;o/k>c
0_l00007olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT00ol0003oOgmoo`000002ofIVIP03
o`000?m<C4co000000[o<c<c00?o0000oda<C?l000000_mVIVH01ol0003oOgmoo`000?nIVIWo0000
ok>c/ol000002_o<c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003
o`000?lc<c?o<c<c00Ko<c<c00?o0000oda<C?l000000_l000001?moOgoo0000oiVIVOl00002ok>c
/`03o`000?oooooooooo00Cooooo0Ol00001ooooo`7ooooo000Tooooo`;o00001?ooool5ofIVIP03
o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`09ogmoO`03
o`000?nIVIWoVIVI00[oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0<oiVIV@03
o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH01?mVIVH00ol0003oC4a<oda<C00Coda<C003
o`000?mVIVKoIVIV00?oIVIV00Go0000ogmoOomoOgooOgmoo`000004oiVIV@03o`000?nc/k?o/k>c
00?o/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`04o`000?nIVIWoVIVI
o`0000?oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<
C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00002ok>c/`03
o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@03o`000?moOgoo0000
00;oIVIV00?o0000oda<C?l000002_lc<c<00ol0003oC4a<o`000002ofIVIP07o`000?moOgoo0000
oiVIVOl0003o/k>co`00000:olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000
00;oC4a<00?o0000oc<c<olc<c<01_lc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVI
o`000002ok>c/`03o`000?oooooooooo00?ooooo0_l00002ooooo`009?ooool00ol0003ooooooooo
o`03ooooo`CoIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?mo
OgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02_nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nI
VIWoVIVI00coVIVI00?o0000ogmoOomoOgl01_moOgl00ol0003oIVIVofIVIP05ofIVIP03o`000?m<
C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000CoVIVI
00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00;o/k>c
00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000GoC4a<00?o0000oc<c
<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C006o`000?mVIVKoIVIVo`000?moOgoo00000_nI
VIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo0000
00;oOgmo00Ko0000ofIVI_mVIVKo0000oda<C?l00009oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo
00000_moOgl01Ol0003oVIVIo`000?nc/k?o000000Woc<c<00co0000ok>c/onc/k?o0000oiVIVOl0
003oOgmoo`000?mVIVKo0000oda<C?l00009oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`00
0?nIVIWo000000;o/k>c00?o0000ooooooooool01?ooool1o`00007ooooo0Oooool002Cooooo00?o
0000ooooooooool00oooool3ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH03?mV
IVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc
/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH01OmV
IVH00ol0003oC4a<oda<C00Doda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgooOgmo
o`000004oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>c
ok>c/`03ok>c/`04o`000?nIVIWoVIVIo`0000?oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0
003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl0
1?l0003oVIVIoiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>c
o`000002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<00ol0003o
C4a<o`000002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<
c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<0
1olc<c<2o`000004ofIVI_l0003oOgmoogmoO`;o00000_nc/k<00ol0003oc<c<ooooo`05ooooo`7o
00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`;oIVIV00?o0000oda<C?m<C4`0
5_m<C4`2o`0000coIVIV0_l0000:ogmoO`03o`000?nIVIWoVIVI00[oVIVI0_l0000Hok>c/`03o`00
0?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl01_moOgl00ol0003oIVIVofIVIP05ofIVIP03o`00
0?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000Co
VIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c00?o
/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`05o`000?mVIVKoIVIVofIVI_l000001?m<C4`0
0ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Ko0000ofIVI_mVIVKo0000ogmo
Ool00002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01ol0003o/k>cok>c/onc/k?o0000
oiVIVOl000000_moOgl01?l0003oIVIVo`000?l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Ko
0000oda<C?m<C4co0000ofIVI_l00002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<
c<`01_o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`00
0?lc<c?o<c<c00Ko<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl000000_nc/k<0
0ol0003oc<c<ooooo`05ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03oooo
o`03ofIVI_l0003oC4a<01OoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`09ogmo
O`03o`000?nIVIWoVIVI00[oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0;oiVI
V@03o`000?moOgooOgmo00OoOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<C00Doda<
C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgooOgmoo`000003oiVIV@03o`000?nc/k?o
/k>c00Go/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`03ok>c/`05o`000?nIVIWo
VIVIoiVIVOl000000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000CoC4a<00?o0000oc<c<olc<c<0
1Olc<c<00ol0003oC4a<oda<C002oda<C006o`000?mVIVKoIVIVo`000?moOgoo00000_nIVIT01Ol0
003o/k>cok>c/onc/k?o000000Soc<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo
00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`06o`000?m<C4coC4a<o`000?mV
IVKo00000_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00[o0000ok>c
/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`09
o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?ooool01Ooo
ool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool00ol0003oC4a<oda<C00F
oda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0;
oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`07
ogmoO`03o`000?mVIVKoIVIV00GoIVIV00?o0000oda<C?m<C4`05?m<C4`00ol0003oIVIVofIVIP02
ofIVIP05o`000?moOgooOgmoogmoOol000001?nIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<
c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo
00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<
C4`00_m<C4`01_l0003oIVIVofIVI_l0003oOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`00
0008olc<c007o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000002ogmoO`03o`000?mVIVKo000000?o
C4a<00?o0000oc<c<olc<c<01_lc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00?o0000
oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmo
o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01olc<c<2o`0000;oIVIV0_l000001OnIVIWo
0000ok>c/onc/k?o000000;oc<c<1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000oooooooo
ool00ooooolHoda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003o
VIVIoiVIV@0:oiVIV@;o00006?nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00Oo
Ogmo00?o0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<C00Coda<C0;o00001?mVIVH00ol0003o
OgmoogmoO`02ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001_nc/k<00ol0003oc<c<olc<c003olc<
c0;o00001Onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`00
0003oda<C0;o00001olc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo
00000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Oo0000ok>c/onc/k?o/k>co`000?nI
VIWo000000;oOgmo00?o0000ofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`06o`000?m<
C4coC4a<o`000?mVIVKo00000_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ko
c<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l0000:oc<c<`;o
000000KoIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Kooooo0Ol00001
ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo5om<C4`00ol0003oIVIVofIVIP0;ofIV
IP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02_nIVIT00ol0003o/k>cok>c/`0Gok>c
/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl01omoOgl00ol0003oIVIVofIVIP06ofIV
IP03o`000?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH00omVIVH01Ol0003oOgmoogmoOomoOgoo
000000CoVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o
/k>c00Co/k>c00Co0000oiVIVOnIVIWo00000omoOgl01Ol0003oIVIVofIVI_mVIVKo000000?oC4a<
00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomo
Ogoo00000_nIVIT01?l0003o/k>cok>c/ol00009olc<c007o`000?nc/k?o/k>cok>c/ol0003oVIVI
o`000002ogmoO`03o`000?mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01_l0003oC4a<
oda<C?l0003oIVIVo`0000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<
c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co00002_lc<c<2o`00
0006ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006ooooo`7o00000Ooo
ool1ooooo`006oooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool00ooooolF
oda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0;
oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`07
ogmoO`03o`000?mVIVKoIVIV00KoIVIV00?o0000oda<C?m<C4`04om<C4`00ol0003oIVIVofIVIP03
ofIVIP03o`000?moOgooOgmo00;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000006ok>c/`03o`000?o<
c<coc<c<00?oc<c<00?o0000ok>c/onc/k<01?nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo
00Go0000ofIVI_mVIVKoIVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c00?o0000oda<C?m<
C4`00_m<C4`01_l0003oIVIVofIVI_l0003oOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`00
0008olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000?o
C4a<00?o0000oc<c<olc<c<01_lc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00?o0000
oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmo
o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01olc<c<01?l0003oC4a<o`000?mVIVH2o`00
00;oVIVI00?o0000ok>c/ol000000oo<c<`6ooooo`7o00000Oooool1ooooo`007?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00?ooooo5Om<C4`00ol0003oIVIVofIVIP0;ofIVIP03
o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02_nIVIT2o`0001So/k>c00?o0000oiVIVOnI
VIT02onIVIT00ol0003oOgmoogmoO`07ogmoO`03o`000?mVIVKoIVIV00KoIVIV00?o0000oda<C?m<
C4`05?m<C4`00ol0003oIVIVofIVIP02ofIVIP03o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnI
VIT00_nIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc
/k<00onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`0
0ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmo
Ool00002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01ol0003o/k>cok>c/onc/k?o0000
oiVIVOl000000_moOgl00ol0003oIVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Ko0000
oda<C?m<C4co0000ofIVI_l00002ogmoO`05o`000?nIVIWo0000ok>c/ol000002_o<c<`02Ol0003o
/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go
0000oda<C?l0003o0000ofIVIP02o`000005oiVIVOl0003o/k>cok>c/ol000000oo<c<`6ooooo`7o
00000Oooool1ooooo`006Oooool5o`0000Kooooo0ol00003oooooaCoC4a<00?o0000ofIVI_mVIVH0
2omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00[oVIVI00?o0000ok>c/onc/k<0
5onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00OoOgmo00?o0000ofIVI_mVIVH0
1_mVIVH00ol0003oC4a<oda<C00Doda<C003o`000?mVIVKoIVIV00?oIVIV00?o0000ogmoOomoOgl0
0_moOgl00ol0003oVIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`0
0oo<c<`00ol0003o/k>cok>c/`03ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01?l0003o
IVIVofIVI_l00004oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002
ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c007o`00
0?nc/k?o/k>cok>c/ol0003oVIVIo`000002ogmoO`03o`000?mVIVKo000000?oC4a<00?o0000oc<c
<olc<c<01_lc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00Go0000oiVIVOl0003o/k>c
o`00000:olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000
oc<c<olc<c<01_lc<c<00ol0003oC4a<o`000002ofIVIP;o000000GoVIVIo`000?nc/k?o/k>co`00
0003olc<c0Cooooo0ol00002ooooo`006Oooool01?m4A4CogMgMooooool00007ooooo`03o`000?oo
oooooooo00?ooooo4om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o
0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o
0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP06ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o
0000ofIVI_mVIVH01?mVIVH01Ol0003oOgmoogmoOomoOgoo000000CoVIVI00?o0000ok>c/onc/k<0
1?nc/k<00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c00?o/k>c00Go0000oiVIVOnIVIWo
VIVIo`000003ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0
003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01Ol0003o/k>cok>c
/onc/k?o000000Soc<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo00?o0000ofIV
I_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Go0000
ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Wo0000ok>c/ol0003oVIVI
o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`07o`000?m<C4coC4a<
o`000?mVIVKo0000ogmoO`02o`0000;o/k>c00?o0000olc<c?o<c<`00_o<c<`6ooooo`7o00000Ooo
ool1ooooo`006Oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo00?ooooo4_m<
C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo0_l0000=oiVIV@03o`000?nc
/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mV
IVKoIVIV00KoIVIV00?o0000oda<C?m<C4`05?m<C4`00ol0003oIVIVofIVIP03ofIVIP05o`000?mo
OgooOgmoogmoOol000001?nIVIT00ol0003o/k>cok>c/`05ok>c/`03o`000?o<c<coc<c<00;oc<c<
00?o0000ok>c/onc/k<01?nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Go0000ofIVI_mV
IVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0
003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<
c<`01?l0003o/k>cok>c/ol00002oiVIV@06o`000?moOgooOgmoo`000?mVIVKo00000om<C4`00ol0
003o<c<coc<c<`06oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVIV@04o`00
0?nc/k?o/k>co`0000Soc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000
0_m<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<o`000?mVIVH00_l000001OnIVIWo
0000ok>c/onc/k?o000000Coc<c<1_ooool1o`00007ooooo0Oooool001[ooooo00?oMgMgolc<c?l0
00001oooool00ol0003oooooooooo`03oooooa7oC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003o
OgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00coVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003o
VIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH01_mVIVH00ol0003o
C4a<oda<C00Eoda<C003o`000?mVIVKoIVIV00?oIVIV00Go0000ogmoOomoOgooOgmoo`000004oiVI
V@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`04ok>c
/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000?oC4a<00?o
0000oc<c<olc<c<01_lc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo
00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`00
00;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`08o`000?m<C4co
C4a<o`000?mVIVKo0000ogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00[o0000ok>c
/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`05
o`000?m<C4coC4a<o`000?mVIVH00_l000001OnIVIWo0000ok>c/onc/k?o000000Coc<c<1_ooool1
o`00007ooooo0Oooool001[ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`03oooo
oa3oC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI
00coVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo
00SoOgmo00?o0000ofIVI_mVIVH01_mVIVH00ol0003oC4a<oda<C00Eoda<C003o`000?mVIVKoIVIV
00?oIVIV00?o0000ogmoOomoOgl00_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Oo/k>c00?o0000
olc<c?o<c<`00_o<c<`00ol0003o/k>cok>c/`04ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_mo
Ogl01Ol0003oIVIVofIVI_mVIVKo000000CoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<
oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0
003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Ko0000ogmoOomoOgoo0000ofIV
I_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00So0000oda<C?m<C4co0000ofIVI_l0003oOgmo
o`0000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`01ol0003o/k>co`000?nIVIWo0000ogmoOol0
00000_mVIVH00ol0003oC4a<o`000008oc<c<`05o`000?m<C4coC4a<o`000?mVIVH00_l000001OnI
VIWo0000ok>c/onc/k?o000000Goc<c<1_ooool1o`00007ooooo0Oooool001_ooooo00?oMgMgo`00
0?ooool01_ooool00ol0003oooooooooo`03ooooo`ooC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0
003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00coVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0
003oVIVIoiVIV@0:oiVIV@;o00002_moOgl00ol0003oIVIVofIVIP07ofIVIP03o`000?m<C4coC4a<
01CoC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI
00;oVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c
00Co/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`05o`000?mVIVKoIVIVofIVI_l000000om<
C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000omVIVH00ol0003oOgmo
o`000003oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVI
V@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<02?l0003oC4a<oda<C?l0
003oIVIVo`000?moOgoo00000_nIVIT01?l0003o/k>cok>c/ol00008olc<c00:o`000?nc/k?o/k>c
o`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003o
C4a<oda<C?l0003oIVIV00;o000000GoVIVIo`000?nc/k?o/k>co`000005olc<c0Kooooo0Ol00001
ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo3_m<C4`00ol0003oIVIVofIVIP0;ofIV
IP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`0Fok>c
/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP08ofIV
IP03o`000?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`03ogmo
O`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c002olc<
c003o`000?nc/k?o/k>c00Co/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`04o`000?mVIVKo
IVIVo`0000CoC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000?oIVIV
00?o0000ogmoOol000000onIVIT01?l0003o/k>cok>c/ol00008olc<c005o`000?nc/k?o/k>cok>c
/ol000000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000Wo<c<c00So0000
oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`02_l0
003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko
<c<c00Go0000oda<C?m<C4co0000ofIVIP02o`000005oiVIVOl0003o/k>cok>c/ol000001Oo<c<`6
ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`goC4a<00?o0000ofIV
I_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI0_l0000Hok>c
/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP08ofIV
IP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`02ogmo
O`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c002olc<
c003o`000?nc/k?o/k>c00Co/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`05o`000?mVIVKo
IVIVofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l00000
0omVIVH00ol0003oOgmoo`000003oiVIV@05o`000?nc/k?o/k>cok>c/ol000001oo<c<`00ol0003o
/k>cok>c/`02ok>c/`05o`000?nIVIWo0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00009
oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl00ol0003oVIVIo`000002ok>c/`03o`00
0?o<c<coc<c<00Koc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`;o00000_m<C4`00ol0
003o<c<coc<c<`06oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o
/k>c00?o0000olc<c?o<c<`00oo<c<`6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003ooooo
ooooo`03ooooo`coC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`00
0?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`00
0?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02?mVIVH00ol0003oC4a<oda<C00Doda<C003o`00
0?mVIVKoIVIV00?oIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@02oiVIV@03o`00
0?nc/k?o/k>c00Go/k>c00?o0000olc<c?o<c<`00_o<c<`00ol0003o/k>cok>c/`04ok>c/`05o`00
0?nIVIWoVIVIoiVIVOl000000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000CoC4a<00?o0000oc<c
<olc<c<01Olc<c<2o`0000?oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl0
0003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@03o`00
0?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<02?l0003oC4a<oda<C?l0003oIVIV
o`000?moOgoo00000_nIVIT00ol0003o/k>co`000009olc<c00:o`000?nc/k?o/k>co`000?nIVIWo
0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<03?l0003oC4a<oda<C?l0
003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Koc<c<1_ooool1o`00007ooooo0Oooool0
02Cooooo00?o0000ooooooooool00oooool;oda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmo
OomoOgl02?moOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVI
VOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00OoIVIV00?o0000oda<
C?m<C4`05Om<C4`00ol0003oIVIVofIVIP03ofIVIP03o`000?moOgooOgmo00;oOgmo00?o0000oiVI
VOnIVIT00_nIVIT00ol0003o/k>cok>c/`05ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o0000ok>c
/onc/k<01?nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`00
0004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIV
I_l00002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o
/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00009
oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVIV@03o`000?nc/k?o000000Wo
c<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<c
oc<c<`06oc<c<`03o`000?m<C4co000000;oIVIV00Oo0000ogmoOol0003oVIVIo`000?nc/k?o0000
00Koc<c<1_ooool1o`00007ooooo0Oooool002Cooooo0_l00004ooooo`[oC4a<00?o0000ofIVI_mV
IVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI0_l0000Hok>c/`03
o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP07ofIVIP03
o`000?m<C4coC4a<01GoC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`02ogmoO`03
o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c002olc<c003
o`000?nc/k?o/k>c00Co/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`05o`000?mVIVKoIVIV
ofIVI_l000001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000
ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<
00Go0000ok>c/onc/k?o/k>co`000002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<
C4co00002Olc<c<01?l0003oC4a<oda<C?l00002ofIVIP;o00000_nIVIT01?l0003o/k>cok>c/ol0
0008olc<c004o`000?nc/k?o/k>co`0000;oVIVI0_l000001OmVIVKo0000oda<C?m<C4co000000So
<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00007olc<c0Go
oooo0_l00002ooooo`009?ooool00ol0003oooooooooo`03ooooo`WoC4a<00?o0000ofIVI_mVIVH0
2omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<0
5onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo0_l00009ofIVIP03o`00
0?m<C4coC4a<01GoC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`02ogmoO`03o`00
0?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c002olc<c003o`00
0?nc/k?o/k>c00Co/k>c00Co0000oiVIVOnIVIWoVIVI0_l00002ogmoO`05o`000?mVIVKoIVIVofIV
I_l000001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIV
I_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go
0000ok>c/onc/k?o/k>co`000002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co
00002?lc<c<2o`0000;oC4a<00Go0000ofIVI_l0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>c
o`0000Soc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0
003o<c<coc<c<`06oc<c<`09o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVI00;o0000
2?o<c<`6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`SoC4a<00?o
0000ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmoO`07ogmoO`03o`000?nIVIWoVIVI00coVIVI00?o
0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0:oiVIV@;o00002omoOgl00ol0003oIVIVofIV
IP08ofIVIP03o`000?m<C4coC4a<01GoC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmo
O`02ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<
c002olc<c003o`000?nc/k?o/k>c00Co/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`05o`00
0?mVIVKoIVIVofIVI_l000001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;o
C4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<co
c<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@03o`000?moOgoo000000;oIVIV00Co
0000oda<C?m<C4co00002?lc<c<02Ol0003oC4a<oda<C?m<C4co0000ofIVI_l0003oOgmoo`000002
oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`00
0?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`09o`000?m<C4coC4a<o`000?mVIVKo0000
ogmoOol0003oVIVI00;o00002?o<c<`6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003ooooo
ooooo`03ooooo`OoC4a<00?o0000ofIVI_mVIVH02omVIVH2o`0000WoOgmo00?o0000oiVIVOnIVIT0
2onIVIT2o`0001Oo/k>c0_l0000<oiVIV@03o`000?moOgooOgmo00[oOgmo00?o0000ofIVI_mVIVH0
2?mVIVH00ol0003oC4a<oda<C00Eoda<C003o`000?mVIVKoIVIV00?oIVIV00?o0000ogmoOomoOgl0
0_moOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`0
0_o<c<`00ol0003o/k>cok>c/`04ok>c/`05o`000?nIVIWoVIVIoiVIVOl000001?moOgl01?l0003o
IVIVofIVI_l00004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01ol0
003oIVIVofIVI_mVIVKo0000ogmoOol000000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Woc<c<
00Co0000ok>c/onc/k?o00000_nIVIT01_l0003oOgmoogmoOol0003oIVIVo`0000;oC4a<00?o0000
oc<c<olc<c<01_lc<c<02Ol0003oC4a<oda<C?m<C4co0000ofIVI_l0003oOgmoo`000002oiVIV@04
o`000?nc/k?o/k>co`0000Soc<c<00Co0000ok>c/onc/k?o/k>c0_l000001omoOgoo0000ofIVI_mV
IVKo0000oda<C?l000002?lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0
003o/k>co`0000Soc<c<1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00ooo
ool6oda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVI
V@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmo
O`09ogmoO`;o00002_mVIVH00ol0003oC4a<oda<C00Eoda<C003o`000?mVIVKoIVIV00?oIVIV00?o
0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c00Go/k>c00Go
0000olc<c?o<c<coc<c<o`000007ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01?l0003o
IVIVofIVI_l00005oda<C003o`000?lc<c?o<c<c00Go<c<c00Go0000oda<C?m<C4coC4a<o`000003
ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c007o`00
0?nc/k?o/k>cok>c/ol0003oVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000;oC4a<00?o0000
oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00Co
0000ok>c/onc/k?o00002?o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0
0002oda<C003o`000?lc<c?o<c<c00Ko<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`00
0?nIVIWo0000ok>c/ol00008olc<c0Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooo
oooo00?ooooo1Om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000
oiVIVOnIVIT02_nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000
ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<01GoC4a<00?o0000
ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000
ok>c/onc/k<01Onc/k<01Ol0003oc<c<olc<c?o<c<co000000Ko/k>c00?o0000oiVIVOnIVIT00_nI
VIT01Ol0003oOgmoogmoOomoOgoo000000;oIVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o<c<c
oc<c<`04oc<c<`03o`000?m<C4coC4a<00;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`04
o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01ol0003o/k>cok>c/onc/k?o
0000oiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c
00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`00
00Soc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o
<c<coc<c<`06oc<c<`03o`000?m<C4coC4a<00;o00000_moOgl01Ol0003oVIVIo`000?nc/k?o0000
00Soc<c<00?o0000ooooooooool00oooool1o`00007ooooo0Oooool002Cooooo00?o0000oooooooo
ool00oooool4oda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003o
VIVIoiVIV@0:oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003o
OgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00[oIVIV00?o0000oda<C?m<C4`05Om<C4`00ol0003o
IVIVofIVIP03ofIVIP03o`000?moOgooOgmo00?oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o
/k>cok>c/`05ok>c/`05o`000?o<c<coc<c<olc<c?l000001onc/k<01Ol0003oVIVIoiVIVOnIVIWo
000000?oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o
0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`05o`000?nIVIWoVIVIoiVIVOl0
00000_nc/k<00ol0003oc<c<olc<c007olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Ko0000ogmo
OomoOgoo0000ofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co0000
0_mVIVH00ol0003oOgmoo`000002oiVIV@03o`000?nc/k?o000000Woc<c<00[o0000ok>c/onc/k?o
0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`03o`000?m<
C4coC4a<00;o00000_moOgl01Ol0003oVIVIo`000?nc/k?o000000Soc<c<00?o0000ooooooooool0
0oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool3oda<C003o`000?mV
IVKoIVIV00coIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc
/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mV
IVKoIVIV00[oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP03ofIVIP03o`000?mo
OgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`05ok>c/`05o`000?o<
c<coc<c<olc<c?l000001_nc/k<00ol0003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol0
00000_mVIVH00ol0003oC4a<oda<C003oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<
C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<0
0ol0003oc<c<olc<c006olc<c007o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000002ogmoO`04o`00
0?mVIVKoIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIV
IP06o`000?moOgooOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c00:o`000?nc
/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<0
2_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<
00Goc<c<00?o0000ooooooooool01?ooool1o`00007ooooo0Oooool002Cooooo00?o0000oooooooo
ool00oooool2oda<C0;o00003?mVIVH2o`0000[oOgmo00?o0000oiVIVOnIVIT02_nIVIT2o`0001So
/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`;o00003?mVIVH00ol0003o
C4a<oda<C00Eoda<C003o`000?mVIVKoIVIV00?oIVIV00?o0000ogmoOomoOgl00omoOgl00ol0003o
VIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c00Ko/k>c00Co0000olc<c?o<c<co00001onc/k<01Ol0
003oVIVIoiVIVOnIVIWo000000?oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc
<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`05o`00
0?nIVIWoVIVIoiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c004o`000?nc/k?o/k>co`00
00;oVIVI00Ko0000ogmoOomoOgoo0000ofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co
0000oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVIV@03o`000?nc/k?o000000Woc<c<
00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c
<`06oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00002?o<
c<`00ol0003oooooooooo`04ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03
ooooo`03oda<C?l0003oIVIV00coIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0:
oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08
ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05Om<C4`00ol0003oIVIVofIVIP04
ofIVIP03o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`06
ok>c/`04o`000?o<c<coc<c<o`0000Oo/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`05o`00
0?mVIVKoIVIVofIVI_l000001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;o
C4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<co
c<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@06o`000?moOgooOgmoo`000?mVIVKo
00000om<C4`00ol0003o<c<coc<c<`05oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH00ol0
003oOgmoo`000002oiVIV@03o`000?nc/k?o000000Woc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0
003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`03o`000?m<C4co000000;o
IVIV00Oo0000ogmoOol0003oVIVIo`000?nc/k?o000000Soc<c<00?o0000ooooooooool01?ooool1
o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool00ol0003oIVIVofIVIP0;ofIV
IP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c
/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIV
IP03o`000?m<C4coC4a<01GoC4a<00?o0000ofIVI_mVIVH01?mVIVH00ol0003oOgmoogmoO`02ogmo
O`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<01_nc/k<01?l0003oc<c<olc<c?l00007
ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01Ol0003oIVIVofIVI_mVIVKo000000CoC4a<
00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C003oda<C004o`000?mVIVKoIVIVo`0000;o
Ogmo00Co0000oiVIVOnIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>c
ok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c
00Wo0000oda<C?m<C4coC4a<o`000?mVIVKo0000ogmoOol000000_nIVIT00ol0003o/k>co`000009
olc<c004o`000?nc/k?o/k>co`0000;oVIVI0_l000001OmVIVKo0000oda<C?m<C4co000000So<c<c
00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00008olc<c003o`00
0?nc/k?ooooo00Gooooo0Ol00001ooooo`7ooooo000Tooooo`;o00001?ooool=ofIVIP03o`000?mo
OgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02_nIVIT2o`0001So/k>c00?o0000oiVIVOnIVIT02onI
VIT00ol0003oOgmoogmoO`08ogmoO`;o00003?mVIVH00ol0003oC4a<oda<C00Eoda<C003o`000?mV
IVKoIVIV00CoIVIV00?o0000ogmoOomoOgl00omoOgl00ol0003oVIVIoiVIV@02oiVIV@03o`000?nc
/k?o/k>c00Oo/k>c00?o0000olc<c?l000001onc/k<2o`0000?oVIVI00Go0000ogmoOomoOgooOgmo
o`000003ofIVIP03o`000?m<C4coC4a<00;oC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<
oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0
003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01_l0003oOgmoogmoOol0
003oIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP05
o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c00:o`000?nc/k?o0000
o`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<03?l0003o
C4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Soc<c<00?o0000ok>c/ooo
ool01?ooool2o`0000;ooooo000Tooooo`03o`000?oooooooooo00?ooooo3?mVIVH00ol0003oOgmo
ogmoO`09ogmoO`03o`000?nIVIWoVIVI00[oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVI
oiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH03?mVIVH00ol0003oC4a<
oda<C00Eoda<C003o`000?mVIVKoIVIV00CoIVIV00?o0000ogmoOomoOgl00omoOgl00ol0003oVIVI
oiVIV@02oiVIV@03o`000?nc/k?o/k>c00So/k>c00?o0000ok>c/onc/k<01_nc/k<00ol0003oVIVI
oiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol000000omVIVH00ol0003oC4a<oda<C002oda<C003
o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00om<C4`01?l0003oIVIVofIVI_l00002ogmo
O`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc
/k?o000000;oVIVI00Ko0000ogmoOomoOgoo0000ofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko
<c<c00Co0000oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000
olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l00000
0_m<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<o`000?mVIVH00_l00002oiVIV@03
o`000?nc/k?o000000Soc<c<00?o0000ok>c/oooool01Oooool1o`00007ooooo0Oooool002Cooooo
00?o0000ooooooooool00oooool;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT0
2onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl0
2?moOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<01GoC4a<00?o0000ofIVI_mVIVH0
1?mVIVH00ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<0
4Onc/k<00ol0003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol000000omVIVH00ol0003o
C4a<oda<C002oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003o
IVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`0
0ol0003o/k>cok>c/`02ok>c/`08o`000?nIVIWoVIVIo`000?moOgoo0000ofIVI_l00003oda<C003
o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVI
V@04o`000?nc/k?o/k>co`0000Soc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`0000;o
IVIV00?o0000oda<C?l000002?lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVI
VOl0003o/k>co`0000Soc<c<00Co0000ok>c/onc/k?o00001Oooool1o`00007ooooo0Oooool002Co
oooo00?o0000ooooooooool00oooool:ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnI
VIT02_nIVIT2o`0001So/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03
o`000?mVIVKoIVIV00coIVIV00?o0000oda<C?m<C4`05Om<C4`00ol0003oIVIVofIVIP04ofIVIP03
o`000?moOgooOgmo00?oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`0Bok>c/`05
o`000?nIVIWoVIVIoiVIVOl000000omoOgl01Ol0003oIVIVofIVI_mVIVKo000000GoC4a<00?o0000
oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C002oda<C005o`000?mVIVKoIVIVofIVI_l000000_mo
Ogl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o
/k>co`000002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<01?l0
003oC4a<oda<C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<
c007olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000
oc<c<olc<c<01_lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>c
o`0000Soc<c<00Co0000ok>c/onc/k?o00001Oooool1o`00007ooooo0Oooool002Cooooo00?o0000
ooooooooool00oooool9ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02_nIVIT0
0ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl0
0ol0003oIVIVofIVIP0;ofIVIP;o00006?m<C4`00ol0003oIVIVofIVIP04ofIVIP03o`000?moOgoo
Ogmo00;oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0Bok>c/`05o`000?nIVIWo
VIVIoiVIVOl000000omoOgl01Ol0003oIVIVofIVI_mVIVKo000000CoC4a<00?o0000oc<c<olc<c<0
1Olc<c<00ol0003oC4a<oda<C002oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01?l0003o
VIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002
oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<01?l0003oC4a<oda<
C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c00:
o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<0
1_lc<c<00ol0003oC4a<oda<C002o`0000;oOgmo00Go0000oiVIVOl0003o/k>co`000008olc<c004
o`000?nc/k?o/k>co`0000Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?o
oooo2?mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc
/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mV
IVH02omVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00CoIVIV00?o0000ogmoOomo
Ogl00omoOgl00ol0003oVIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c01;o/k>c00Go0000oiVIVOnI
VIWoVIVIo`000004ogmoO`04o`000?mVIVKoIVIVo`0000GoC4a<00?o0000oc<c<olc<c<01?lc<c<0
0ol0003oC4a<oda<C002oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01?l0003oVIVIoiVI
VOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@03
o`000?moOgoo000000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`04o`000?m<C4coC4a<
o`0000;oIVIV00?o0000ogmoOomoOgl00_l00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Ko0000
ok>c/onc/k?o0000oiVIVOl00002ogmoO`;o00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0:o`00
0?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<
c<`00ol0003o/k>co`000006ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03
ooooo`OoIVIV00?o0000ogmoOomoOgl02?moOgl2o`0000goVIVI00?o0000ok>c/onc/k<05_nc/k<0
0ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH0
0ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00CoIVIV00?o0000ogmoOomoOgl00omoOgl0
0ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c017o/k>c00?o0000oiVIVOnIVIT00_nIVIT0
1Ol0003oOgmoogmoOomoOgoo000000?oIVIV00?o0000oda<C?m<C4`00_m<C4`00ol0003o<c<coc<c
<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00?o0000ofIVI_mVIVH00_l00002ogmoO`04o`000?nI
VIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;o
VIVI00?o0000ogmoOol000000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Go0000oda<
C?m<C4co0000ofIVIP02o`000004ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01oo<
c<`00ol0003o/k>co`000002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<c
oc<c<`06oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o0000
2?o<c<`01?l0003o/k>cok>c/ol00006ooooo`7o00000Oooool1ooooo`009?ooool00ol0003ooooo
ooooo`03ooooo`KoIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`00
0?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`00
0?mVIVKoIVIV00_oIVIV0_l0000Hoda<C003o`000?mVIVKoIVIV00GoIVIV00?o0000ogmoOomoOgl0
0omoOgl00ol0003oVIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c01;o/k>c00?o0000oiVIVOnIVIT0
0_nIVIT01Ol0003oOgmoogmoOomoOgoo000000?oIVIV00?o0000oda<C?m<C4`00_m<C4`00ol0003o
<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000omoOgl01?l0
003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<0
1_l0003oVIVIoiVIVOl0003oOgmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`000007oc<c<`04
o`000?m<C4coC4a<o`0000;oIVIV00Ko0000ogmoOomoOgoo0000oiVIVOl00002ok>c/`03o`000?o<
c<coc<c<00Ooc<c<00Go0000ok>c/ol0003oVIVIo`000002ogmoO`03o`000?mVIVKo000000;oC4a<
00?o0000oc<c<olc<c<01_lc<c<00ol0003oC4a<o`000002ofIVIP04o`000?moOgoo0000o`0000;o
/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00006ooooo`7o00000Oooool1oooo
o`009?ooool00ol0003oooooooooo`03ooooo`GoIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003o
VIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003o
OgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003o
IVIVofIVIP05ofIVIP03o`000?moOgooOgmo00?oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o
/k>cok>c/`0Bok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`000003ofIV
IP03o`000?m<C4coC4a<00;oC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<
C004o`000?mVIVKoIVIVo`0000?oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<
c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP04
o`000?m<C4coC4a<o`0000So<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`03o`000?nI
VIWo000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`00ol0003o/k>co`000002oiVIV@05o`000?mo
Ogoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0<o`000?m<C4coC4a<o`000?mV
IVKo0000ogmoOol0003oVIVIo`000?nc/k?o00002Oo<c<`01Ol0003o/k>co`000?nIVIWo000000Go
oooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo1?mVIVH00ol0003oOgmo
ogmoO`08ogmoO`03o`000?nIVIWoVIVI00coVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVI
oiVIV@0:oiVIV@;o00002_moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<
00?o0000ofIVI_mVIVH01OmVIVH00ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00?oVIVI
00?o0000ok>c/onc/k<04_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Go0000ofIVI_mV
IVKoIVIVo`000005oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00om<C4`01?l0
003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01Oo<
c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI0_l000001OmoOgoo0000ofIVI_mVIVKo000000;o
C4a<00?o0000oc<c<olc<c<01_lc<c<01ol0003oC4a<oda<C?m<C4co0000ofIVI_l000000_moOgl0
0ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nI
VIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<03?l0003oC4a<
oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Woc<c<0_l000000onIVIWo0000
ooooo`05ooooo`7o00000Oooool1ooooo`009?ooool2o`0000Cooooo0omVIVH00ol0003oOgmoogmo
O`08ogmoO`03o`000?nIVIWoVIVI00coVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVI
V@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<
C00Goda<C003o`000?mVIVKoIVIV00KoIVIV00?o0000ogmoOomoOgl00omoOgl00ol0003oVIVIoiVI
V@03oiVIV@03o`000?nc/k?o/k>c01;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`03o`00
0?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`00
0?m<C4coC4a<00?oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00004ok>c
/`03o`000?o<c<coc<c<00Goc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgoo
Ogmoo`0000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<01ol0003oC4a<oda<C?m<C4co0000ofIV
I_l000000_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c
/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc
<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Woc<c<0_l0
00000onIVIWo0000ooooo`04ooooo`;o00000_ooool002Cooooo00?o0000ooooooooool00oooool2
ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT2o`0001So/k>c00?o0000
oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000
oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP06ofIVIP03o`000?moOgooOgmo00?oOgmo00?o0000
oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0Bok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omo
Ogl01Ol0003oIVIVofIVI_mVIVKo000000GoC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<
oda<C003oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0
003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Co0000ogmoOomoOgoo00000_mV
IVH01?l0003oC4a<oda<C?l00009oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl01?l0
003oVIVIoiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o0000ok>c/ol000000_nIVIT0
0ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000Oo<c<c00co0000oda<C?m<C4co0000
ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00009olc<c005o`000?nc/k?o0000o`000?moOgl0
1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool00omVIVKo0000ogmo
O`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVI
V@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<
C00Goda<C003o`000?mVIVKoIVIV00KoIVIV00?o0000ogmoOomoOgl00omoOgl00ol0003oVIVIoiVI
V@03oiVIV@03o`000?nc/k?o/k>c01;o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmo
OomoOgoo000000?oIVIV00?o0000oda<C?m<C4`00_m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`00
0?m<C4coC4a<00;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`00
00?o/k>c00?o0000olc<c?o<c<`01oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@04o`000?moOgoo
Ogmoo`0000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<01_l0003oC4a<oda<C?l0003oIVIVo`00
00;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>c
o`0000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00co
0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00009olc<c005o`000?nc
/k?o0000o`000?moOgl01_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00ooo
ool00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00coVIVI00?o0000ok>c/onc/k<05_nc
/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02_mV
IVH00ol0003oC4a<oda<C00Hoda<C003o`000?mVIVKoIVIV00KoIVIV00?o0000ogmoOomoOgl00omo
Ogl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c01;o/k>c00?o0000oiVIVOnIVIT00_nI
VIT01Ol0003oOgmoogmoOomoOgoo000000?oIVIV00?o0000oda<C?m<C4`00_m<C4`00ol0003o<c<c
oc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000omoOgl01?l0003o
VIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Co0000ok>c/onc/k?o00000_nIVIT0
1?l0003oOgmoogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000Wo<c<c00Ko0000oda<C?m<C4co
0000ofIVI_l00002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0
003o/k>cok>c/ol00002oiVIV@;o00000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`0<o`000?m<
C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00002Oo<c<`01Ol0003o/k>co`00
0?l0003oOgmo00Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo2_mo
Ogl00ol0003oVIVIoiVIV@0;oiVIV@;o00006?nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?mo
OgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<oda<C00Hoda<C003o`000?mV
IVKoIVIV00KoIVIV00?o0000ogmoOomoOgl00omoOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc
/k?o/k>c01;o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000?oIVIV
00?o0000oda<C?m<C4`00_m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<
00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`04o`000?nIVIWoVIVIo`0000;o/k>c00?o0000olc<
c?o<c<`01oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Co
0000oda<C?m<C4co00002Olc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000?oOgmo0_l00002ok>c
/`03o`000?o<c<coc<c<00Ooc<c<00?o0000ok>c/ol000000_nIVIT01Ol0003oOgmoo`000?mVIVKo
000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo
0000oiVIVOl0003o/k>co`0000Woc<c<00Oo0000ok>c/ol0003oVIVIo`000?moOgoo000000Gooooo
0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo2OmoOgl00ol0003oVIVIoiVI
V@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmo
O`08ogmoO`;o00003?mVIVH00ol0003oC4a<oda<C00Hoda<C003o`000?mVIVKoIVIV00KoIVIV00?o
0000ogmoOomoOgl00omoOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c01;o/k>c00?o
0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000?oIVIV00?o0000oda<C?m<C4`0
0om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Co0000ofIVI_mVIVKo
00000omoOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c
/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Co0000oda<C?m<C4co0000
2?lc<c<01ol0003oC4a<oda<C?m<C4co0000ofIVI_l000000_moOgl00ol0003oVIVIo`000002ok>c
/`03o`000?o<c<coc<c<00Ooc<c<00?o0000ok>c/ol000000_nIVIT01Ol0003oOgmoo`000?mVIVKo
000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo
0000oiVIVOl0003o/k>co`0000Soc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`0000Go
oooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo2?moOgl00ol0003oVIVI
oiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02_nIVIT2o`0000_oOgmo
00?o0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<oda<C00Hoda<C003o`000?mVIVKoIVIV00OoIVIV
00?o0000ogmoOomoOgl00omoOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c01;o/k>c
00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000?oIVIV00?o0000oda<C?m<
C4`00om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Co0000ofIVI_mV
IVKo00000omoOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000
ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Co0000oda<C?m<C4co
00002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP06o`000?moOgooOgmoo`000?nIVIWo00000_nc
/k<00ol0003oc<c<olc<c007olc<c005o`000?nc/k?o0000oiVIVOl000000_moOgl00ol0003oIVIV
o`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmo
o`000?nIVIWo0000ok>c/ol00008olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00005
ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`OoOgmo00?o0000oiVI
VOnIVIT02onIVIT2o`0001Oo/k>c0_l0000<oiVIV@03o`000?moOgooOgmo00[oOgmo00?o0000ofIV
I_mVIVH02_mVIVH00ol0003oC4a<oda<C00Hoda<C003o`000?mVIVKoIVIV00OoIVIV00?o0000ogmo
OomoOgl00omoOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c01;o/k>c00?o0000oiVI
VOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000?oIVIV00?o0000oda<C?m<C4`00om<C4`0
0ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Co0000ofIVI_mVIVKo00000omo
Ogl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Goc<c<00Go0000ok>c/onc/k?o
/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`000007
oc<c<`07o`000?m<C4coC4a<oda<C?l0003oIVIVo`000002ogmoO`03o`000?nIVIWo000000;o/k>c
00?o0000olc<c?o<c<`01oo<c<`00ol0003o/k>co`000002oiVIV@05o`000?moOgoo0000ofIVI_l0
00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0
003oVIVIo`000?nc/k?o00002?o<c<`02?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo00001_oo
ool1o`00007ooooo0Oooool001Wooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oo
oooooooo00?ooooo1_moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o
0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmoO`;o00003?mVIVH00ol0003oC4a<oda<
C00Hoda<C003o`000?mVIVKoIVIV00KoIVIV0_l00005ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o
0000ok>c/onc/k<04onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000CoOgmo00Go0000ofIVI_mVIVKo
IVIVo`000005oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0003o
IVIVofIVI_mVIVKo000000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000003ok>c/`03o`000?o<c<co
c<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@03o`000?moOgoo000000;oIVIV00Go
0000oda<C?m<C4coC4a<o`000008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol0
00000_nIVIT01?l0003o/k>cok>c/ol00008olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Go0000
ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00co0000oda<C?m<C4co0000
ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00008olc<c008o`000?nc/k?o/k>co`000?nIVIWo
0000ogmoOol00006ooooo`7o00000Oooool1ooooo`006Oooool01OmEEEGoMgMgoooooonHV9So8B4Q
00Kooooo00?o0000ooooooooool00oooool6ogmoO`03o`000?nIVIWoVIVI00[oVIVI00?o0000ok>c
/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIV
I_mVIVH02omVIVH00ol0003oC4a<oda<C00Hoda<C003o`000?mVIVKoIVIV00OoIVIV00?o0000ogmo
OomoOgl01?moOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c01?o/k>c00Go0000oiVI
VOnIVIWoVIVIo`000004ogmoO`04o`000?mVIVKoIVIVo`0000KoC4a<00?o0000oc<c<olc<c<01?lc
<c<00ol0003oC4a<oda<C002oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01Ol0003oVIVI
oiVIVOnIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o0000
00;oVIVI00?o0000ogmoOol000000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Co0000
oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<
00Co0000ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c
<olc<c<01_lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`00
00Soc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`0000Kooooo0Ol00001ooooo`7ooooo
000Iooooo`05o`000?ooooooooooooooool000001_ooool3o`0000?ooooo1OmoOgl00ol0003oVIVI
oiVIV@0:oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003oOgmo
ogmoO`08ogmoO`03o`000?mVIVKoIVIV00coIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIV
ofIVIP07ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>c
ok>c/`0Bok>c/`05o`000?nIVIWoVIVIoiVIVOl000001?moOgl01Ol0003oIVIVofIVI_mVIVKo0000
00KoC4a<00?o0000oc<c<olc<c<00olc<c<00ol0003oC4a<oda<C003oda<C004o`000?mVIVKoIVIV
o`0000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o
0000ok>c/onc/k<00_nc/k<01_l0003oVIVIoiVIVOl0003oOgmoo`0000;oIVIV00Go0000oda<C?m<
C4coC4a<o`000008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV0_l00003oiVIV@04o`000?nc/k?o
/k>co`0000Soc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`;o00000om<C4`00ol0003o
<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<o`000?mVIVH00_l00002oiVIV@03o`000?nc/k?o0000
00Soc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`0000Cooooo0ol00002ooooo`006Ooo
ool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool00oooool4ogmoO`03o`00
0?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`00
0?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH03?mVIVH00ol0003oC4a<oda<C00Goda<C003o`00
0?mVIVKoIVIV00SoIVIV00?o0000ogmoOomoOgl01?moOgl00ol0003oVIVIoiVIV@03oiVIV@03o`00
0?nc/k?o/k>c01?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000004ogmoO`04o`000?mVIVKoIVIVo`00
00KoC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C002oda<C005o`000?mVIVKoIVIV
ofIVI_l000000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<
c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmoOol000000_mVIVH01Ol0003oC4a<
oda<C?m<C4co000000So<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000003oiVI
V@04o`000?nc/k?o/k>co`0000Ooc<c<00Co0000ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`00
0?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`00
0?moOgoo0000oiVIVOl0003o/k>co`0000Woc<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000
ofIVI_l000001Oooool1o`00007ooooo0Oooool001Wooooo00Go0000oeEEEOl0003o410@olc<c006
ooooo`03o`000?oooooooooo00?ooooo0omoOgl00ol0003oVIVIoiVIV@0:oiVIV@;o00006?nc/k<0
0ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo0_l0000<ofIVIP;o00006Om<C4`0
0ol0003oIVIVofIVIP07ofIVIP;o00001_moOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o
/k>c01;o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000?oIVIV00?o
0000oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Go
0000ofIVI_mVIVKoIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<
c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`06o`000?nIVIWoVIVIo`000?moOgoo00000_mVIVH0
1Ol0003oC4a<oda<C?m<C4co000000So<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmo
o`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002
ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<03?l0003oC4a<oda<C?l0
003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Woc<c<00Wo0000ok>c/ol0003oVIVIo`00
0?moOgoo0000ofIVI_l000001Oooool1o`00007ooooo0Oooool001Wooooo00?oEEEEohN7Qoooool0
2?ooool00ol0003oooooooooo`03ooooo`;oOgmo00?o0000oiVIVOnIVIT02_nIVIT00ol0003o/k>c
ok>c/`0Gok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIV
ofIVIP0<ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02?mVIVH00ol0003oOgmo
ogmoO`04ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<04onc/k<00ol0003oVIVI
oiVIV@02oiVIV@04o`000?moOgooOgmoo`0000CoIVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o
<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmo
O`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02
ok>c/`06o`000?nIVIWoVIVIo`000?moOgoo00000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So
<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000;o/k>c00?o
0000olc<c?o<c<`01_o<c<`02?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo00000_mVIVH01?l0
003oC4a<oda<C?l00008oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`00
0?nc/k?o00002Oo<c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000005ooooo`7o
00000Oooool1ooooo`006Oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo00?ooooo
00?oOgmoo`000?nIVIT03?nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI
00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<01KoC4a<
0_l0000:ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>c
ok>c/`0Cok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`000003ofIVIP03
o`000?m<C4coC4a<00?oC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C003oda<C005
o`000?mVIVKoIVIVofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<co
c<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01_l0003oVIVIoiVIVOl0003oOgmoo`0000?oIVIV
00Co0000oda<C?m<C4co00002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo0000
00;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo
00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0<o`000?m<C4coC4a<o`000?mV
IVKo0000ogmoOol0003oVIVIo`000?nc/k?o00002Oo<c<`02Ol0003o/k>co`000?nIVIWo0000ogmo
Ool0003oIVIVo`000006ooooo`7o00000Oooool1ooooo`006_ooool01?o<c<coA4A4o`000?l@4106
ooooo`03o`000?oooooooooo00?ooooo00?o0000oiVIVOnIVIT02_nIVIT2o`0001So/k>c00?o0000
oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`;o00003OmVIVH00ol0003oC4a<oda<C00F
oda<C003o`000?mVIVKoIVIV00WoIVIV0_l00006ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000
ok>c/onc/k<04_nc/k<00ol0003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol000001?mV
IVH00ol0003oC4a<oda<C003oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00om<
C4`01?l0003oIVIVofIVI_l00003ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<
c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH0
1Ol0003oC4a<oda<C?m<C4co000000So<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmo
o`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002
ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<03?l0003oC4a<oda<C?l0
003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Woc<c<00Wo0000ok>c/ol0003oVIVIo`00
0?moOgoo0000ofIVI_l000001_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool0
0oooool<oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmo
ogmoO`08ogmoO`03o`000?mVIVKoIVIV00coIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIV
ofIVIP09ofIVIP03o`000?moOgooOgmo00KoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>c
ok>c/`0Bok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`000003ofIVIP03
o`000?m<C4coC4a<00CoC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C002oda<C005
o`000?mVIVKoIVIVofIVI_l000000omoOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<co
c<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV
00Go0000oda<C?m<C4coC4a<o`000008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmo
Ool000000_nIVIT01?l0003o/k>cok>c/ol00008olc<c006o`000?nc/k?o/k>co`000?nIVIWo0000
0_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00co0000oda<C?m<C4co
0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00009olc<c009o`000?nc/k?o0000oiVIVOl0
003oOgmoo`000?mVIVKo000000Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo
00?ooooo3?nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmo
OomoOgl02?moOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIV
I_mVIVH02_mVIVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c
/onc/k<04_nc/k<00ol0003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol000001?mVIVH0
0ol0003oC4a<oda<C003oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00om<C4`0
1?l0003oIVIVofIVI_l00003ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`0
1_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01Ol0
003oC4a<oda<C?m<C4co000000So<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`00
0002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT01Ol0003o
Ogmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<03?l0003oC4a<oda<C?l0003o
IVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Woc<c<00[o0000ok>c/ol0003oVIVIo`000?mo
Ogoo0000ofIVI_l0003oC4a<1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool0
0oooool:oiVIV@;o00006?nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo
0_l0000=ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmo
ogmoO`05ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<04onc/k<00ol0003oVIVI
oiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol000000omVIVH00ol0003oC4a<oda<C004oda<C003
o`000?lc<c?o<c<c00?o<c<c00?o0000oda<C?m<C4`00om<C4`01Ol0003oIVIVofIVI_mVIVKo0000
00;oOgmo00?o0000oiVIVOnIVIT00_l00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c
/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Co0000oda<C?m<C4co0000
2?lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOol0003oVIVI0_l00002ok>c
/`03o`000?o<c<coc<c<00Koc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`03o`000?mV
IVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?mo
Ogoo0000oiVIVOl0003o/k>co`0000Woc<c<00[o0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIV
I_l0003oC4a<1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool9oiVI
V@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmo
O`03o`000?mVIVKoIVIV00_oIVIV0_l0000Hoda<C003o`000?mVIVKoIVIV00[oIVIV00?o0000ogmo
OomoOgl01OmoOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o0000oiVI
VOnIVIT00onIVIT01?l0003oOgmoogmoOol00004ofIVIP03o`000?m<C4coC4a<00CoC4a<00?o0000
oc<c<olc<c<00olc<c<00ol0003oC4a<oda<C003oda<C005o`000?mVIVKoIVIVofIVI_l000000_mo
Ogl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o
/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<0
1Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Go0000ogmoOol0003oVIVIo`000003ok>c/`03o`00
0?o<c<coc<c<00Koc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`05o`000?mVIVKo0000
oda<C?l000002Olc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>c
o`0000Woc<c<00_o0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`000005oooo
o`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`WoVIVI00?o0000ok>c/onc
/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mV
IVH02omVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00[oIVIV00?o0000ogmoOomo
Ogl01OmoOgl00ol0003oVIVIoiVIV@05oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnI
VIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000?oIVIV00?o0000oda<C?m<C4`01?m<C4`00ol0
003o<c<coc<c<`03oc<c<`03o`000?m<C4coC4a<00?oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002
ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c
/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01?l0003oC4a<oda<C?l00008oc<c
<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000Co/k>c00?o
0000olc<c?o<c<`01Oo<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00?o0000ofIVI_l0
00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0
003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003o/k>co`000002oiVIV@;o0000
00GoIVIVo`000?m<C4coC4a<o`000005ooooo`7o00000Oooool1ooooo`009?ooool2o`0000Cooooo
2?nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl0
2?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH0
2_mVIVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00GoVIVI00?o0000ok>c/onc/k<0
4onc/k<00ol0003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol000001?mVIVH00ol0003o
C4a<oda<C003oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00om<C4`01Ol0003o
IVIVofIVI_mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c005
olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIVo`00
0?l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo0000
00;oOgmo00?o0000oiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c006o`000?nc/k?o/k>c
o`000?nIVIWo00000_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00[o
0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006
olc<c00;o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l000001Oooool2o`00
00;ooooo000Tooooo`03o`000?oooooooooo00?ooooo1onIVIT00ol0003o/k>cok>c/`0Fok>c/`03
o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP;o
00006?m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00CoOgmo00?o0000oiVIVOnI
VIT01_nIVIT00ol0003o/k>cok>c/`0Cok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomo
OgooOgmoo`000003ofIVIP03o`000?m<C4coC4a<00?oC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0
003oC4a<oda<C003oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl0
0004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01_l0003oVIVIoiVI
VOl0003oOgmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`07o`000?m<C4coC4a<
oda<C?l0003oIVIVo`000002ogmoO`03o`000?nIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<
c<`02?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo00000_mVIVH01?l0003oC4a<oda<C?l00008
oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<
c?o<c<`01_o<c<`02ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co000000Ko
oooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo1_nIVIT00ol0003o/k>c
ok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIV
ofIVIP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmo
ogmoO`05ogmoO`03o`000?nIVIWoVIVI00GoVIVI00?o0000ok>c/onc/k<04onc/k<00ol0003oVIVI
oiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol000001?mVIVH00ol0003oC4a<oda<C003oda<C003
o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00om<C4`01Ol0003oIVIVofIVI_mVIVKo0000
00;oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o
/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl00ol0003oIVIVo`000004oda<C003o`000?lc
<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000?o
/k>c00?o0000olc<c?o<c<`01_o<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00?o0000
ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000
ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003o/k>cok>c/`02o`00
0007ogmoOol0003oIVIVo`000?m<C4co0000oc<c<`06ooooo`7o00000Oooool1ooooo`009?ooool0
0ol0003oooooooooo`03ooooo`GoVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0:
oiVIV@;o00002_moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<0_l0000=
ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT01OnIVIT00ol0003o/k>cok>c/`0C
ok>c/`03o`000?nIVIWoVIVI00;oVIVI00?o0000ogmoOomoOgl00_moOgl01Ol0003oIVIVofIVI_mV
IVKo000000KoC4a<00?o0000oc<c<olc<c<00olc<c<00ol0003oC4a<oda<C003oda<C005o`000?mV
IVKoIVIVofIVI_l000000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000?o/k>c00?o0000olc<c?o<
c<`01_o<c<`00ol0003o/k>cok>c/`02ok>c/`06o`000?nIVIWoVIVIo`000?moOgoo00000_mVIVH0
1Ol0003oC4a<oda<C?m<C4co000000So<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo000000;o
Ogmo00?o0000oiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c008o`000?nc/k?o/k>co`00
0?nIVIWo0000ogmoOol00002ofIVIP03o`000?m<C4co000000Wo<c<c00[o0000oda<C?m<C4co0000
ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c00<o`000?nc/k?o
0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l0003o<c<c1_ooool1o`00007ooooo0Oooool0
02Cooooo00?o0000ooooooooool00oooool4oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVI
VOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<
C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVI
VOnIVIT01_nIVIT00ol0003o/k>cok>c/`0Cok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000ogmo
OomoOgooOgmoo`000004ofIVIP03o`000?m<C4coC4a<00CoC4a<00?o0000oc<c<olc<c<00olc<c<0
0ol0003oC4a<oda<C003oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01Ol0003oVIVIoiVI
VOnIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003o/k>cok>c/`02ok>c/`06o`00
0?nIVIWoVIVIo`000?moOgoo00000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Oo0000
oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00?o0000oiVIVOl000000onc/k<00ol0003oc<c<
olc<c006olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP03o`000?m<C4co
000000Wo<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00009
olc<c00<o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l0003o<c<c1_ooool1
o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool2oiVIV@;o00006?nc/k<00ol0
003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0
003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0
003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT00_nIVIT00ol0
003oOgmoogmoO`02ogmoO`05o`000?mVIVKoIVIVofIVI_l000001_m<C4`00ol0003o<c<coc<c<`03
oc<c<`03o`000?m<C4coC4a<00?oC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`04o`000?nI
VIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003o/k>cok>c/`02ok>c/`06o`00
0?nIVIWoVIVIo`000?moOgoo00000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Oo0000
oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00?o0000oiVIVOl000000onc/k<00ol0003oc<c<
olc<c006olc<c004o`000?nc/k?o/k>co`0000;oVIVI0_l00002ofIVIP04o`000?m<C4coC4a<o`00
00So<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003o
c<c<olc<c006olc<c005o`000?nc/k?o0000oiVIVOl000000_moOgl2o`0000;oC4a<00?o0000oc<c
<oooool01Oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool00onIVIWo
0000ok>c/`0Hok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003o
IVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003o
OgmoogmoO`06ogmoO`03o`000?nIVIWoVIVI00GoVIVI00?o0000ok>c/onc/k<04onc/k<00ol0003o
VIVIoiVIV@02oiVIV@03o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003o
C4a<oda<C003oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00om<C4`01Ol0003o
IVIVofIVI_mVIVKo000000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000003ok>c/`03o`000?o<c<co
c<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV
00Co0000oda<C?m<C4co00002Olc<c<01ol0003oC4a<oda<C?m<C4co0000ofIVI_l000000_moOgl0
0ol0003oVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00So0000ok>c/onc/k?o0000oiVI
VOl0003oOgmoo`0000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<03?l0003oC4a<oda<C?l0003o
IVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Woc<c<00Wo0000ok>c/ol0003oVIVIo`000?mo
Ogoo0000ofIVI_l000000_m<C4`00ol0003o<c<cooooo`05ooooo`7o00000Oooool1ooooo`009?oo
ool00ol0003oooooooooo`03ooooo`03oiVIVOl0003o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02onI
VIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00[oIVIV00?o0000oda<C?m<C4`05_m<
C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?moOgooOgmo00KoOgmo00?o0000oiVIVOnIVIT01_nI
VIT00ol0003o/k>cok>c/`0Cok>c/`03o`000?nIVIWoVIVI00;oVIVI00?o0000ogmoOomoOgl00_mo
Ogl01Ol0003oIVIVofIVI_mVIVKo000000KoC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<
oda<C003oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01Ol0003oVIVIoiVIVOnIVIWo0000
00?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000
ogmoOomoOgoo00000_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`07o`000?m<C4coC4a<oda<C?l0
003oIVIVo`000002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`02?l0
003o/k>cok>c/ol0003oVIVIo`000?moOgoo00000_mVIVH00ol0003oC4a<o`000009oc<c<`0<o`00
0?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00002Oo<c<`02Ol0003o/k>c
o`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?ooooo00Gooooo0Ol00001
ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo00?o0000ok>c/onc/k<05_nc/k<00ol0
003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02_mVIVH00ol0
003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl01_moOgl00ol0
003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT00onIVIT01Ol0
003oOgmoogmoOomoOgoo000000CoIVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`04
oc<c<`03o`000?m<C4coC4a<00?oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`05o`000?nI
VIWoVIVIoiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol0
00000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<0
1ol0003oC4a<oda<C?m<C4co0000ofIVI_l000000_moOgl00ol0003oVIVIo`000003ok>c/`03o`00
0?o<c<coc<c<00Koc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV00Co0000
oda<C?m<C4co00002Olc<c<02ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o
000000Woc<c<00?o0000ok>c/ol000000_nIVIT2o`000005ofIVI_l0003oC4a<oda<C?l000000_lc
<c<6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03oooooaSo/k>c00?o0000
oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`;o00003?mVIVH00ol0003oC4a<oda<C00F
oda<C003o`000?mVIVKoIVIV00_oIVIV0_l00008ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o0000
ok>c/onc/k<04onc/k<00ol0003oVIVIoiVIV@03oiVIV@05o`000?moOgooOgmoogmoOol000001?mV
IVH00ol0003oC4a<oda<C004oda<C003o`000?lc<c?o<c<c00?o<c<c0_l00004oda<C005o`000?mV
IVKoIVIVofIVI_l000000omoOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Go
c<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIV
o`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP06o`000?mo
OgooOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c007olc<c008o`000?nc/k?o/k>co`00
0?nIVIWo0000ogmoOol00002ofIVIP03o`000?m<C4co000000Wo<c<c00co0000oda<C?m<C4co0000
ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00009olc<c00;o`000?nc/k?o0000oiVIVOl0003o
Ogmoo`000?mVIVKo0000oda<C?l000000olc<c<6ooooo`7o00000Oooool1ooooo`009?ooool2o`00
00Cooooo5onc/k<00ol0003oVIVIoiVIV@0:oiVIV@;o00002omoOgl00ol0003oIVIVofIVIP0:ofIV
IP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmoO`07ogmo
O`03o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc/k<04onc/k<00ol0003oVIVIoiVIV@03oiVI
V@05o`000?moOgooOgmoogmoOol000001?mVIVH00ol0003oC4a<oda<C004oda<C003o`000?lc<c?o
<c<c00?o<c<c00?o0000oda<C?m<C4`00om<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Co
0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c
00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00002oda<C003o`000?lc<c?o<c<c
00Oo<c<c00Co0000oda<C?m<C4co00000_mVIVH01_l0003oOgmoogmoOol0003oVIVIo`0000;o/k>c
00?o0000olc<c?o<c<`01oo<c<`02?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo00000_mVIVH0
0ol0003oC4a<o`000009oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`00
0?nc/k?o00002Oo<c<`02ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co0000
00?o<c<c1Oooool2o`0000;ooooo000Tooooo`03o`000?oooooooooo00?ooooo5Onc/k<2o`0000co
VIVI00?o0000ogmoOomoOgl02_moOgl00ol0003oIVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<01Ko
C4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmoO`07ogmoO`03o`000?nIVIWoVIVI00Ko
VIVI00?o0000ok>c/onc/k<04onc/k<00ol0003oVIVIoiVIV@03oiVIV@03o`000?moOgooOgmo00;o
Ogmo00Go0000ofIVI_mVIVKoIVIVo`000006oda<C003o`000?lc<c?o<c<c00?o<c<c00?o0000oda<
C?m<C4`00om<C4`00ol0003oIVIVofIVIP02ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00?o0000
ok>c/onc/k<00_nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000
oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c
00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0
003oc<c<olc<c007olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl01Ol0003oIVIVo`00
0?m<C4co000000Wo<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc
/k<00ol0003oc<c<olc<c006olc<c003o`000?nc/k?o/k>c00;o000000CoOgmoo`000?mVIVKoIVIV
0_l00004oc<c<`Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo5?nc
/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo0_l0000<ofIVIP03o`000?m<
C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH2o`0000WoOgmo00?o0000oiVIVOnIVIT01_nI
VIT00ol0003o/k>cok>c/`0Cok>c/`03o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl00_mo
Ogl01Ol0003oIVIVofIVI_mVIVKo000000OoC4a<00?o0000oc<c<olc<c<00_lc<c<00ol0003oC4a<
oda<C004oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01Ol0003oVIVIoiVIVOnIVIWo0000
00Co/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVI
o`0000;oOgmo00Co0000ofIVI_mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<
C4coC4a<oda<C?l000000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Wo
c<c<00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV00?o0000oda<C?l000002Olc
<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<co
c<c<00Koc<c<00_o0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`000004oc<c
<`Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo4onc/k<00ol0003o
VIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003o
C4a<oda<C00Goda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl01omoOgl00ol0003o
VIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c01Co/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003o
OgmoogmoO`02ogmoO`05o`000?mVIVKoIVIVofIVI_l000001om<C4`00ol0003o<c<coc<c<`02oc<c
<`03o`000?m<C4coC4a<00CoC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`05o`000?nIVIWo
VIVIoiVIVOl000001?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co
0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko
<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c
/onc/k?o00002Oo<c<`02?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo00000_mVIVH00ol0003o
C4a<o`000009oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c
00?o0000olc<c?o<c<`01Oo<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0
003oC4a<o`0000Co<c<c1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00ooo
oolBok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIV
IP0<ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmo
O`08ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc/k<04onc/k<00ol0003oVIVIoiVI
V@04oiVIV@05o`000?moOgooOgmoogmoOol000001?mVIVH00ol0003oC4a<oda<C004oda<C003o`00
0?lc<c?o<c<c00;o<c<c00?o0000oda<C?m<C4`01?m<C4`01Ol0003oIVIVofIVI_mVIVKo000000?o
Ogmo00Go0000oiVIVOnIVIWoVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c
/onc/k?o/k>co`000003oiVIV@03o`000?moOgoo000000;oIVIV00Go0000oda<C?m<C4coC4a<o`00
0008oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o
/k>c00?o0000olc<c?o<c<`01oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo0000
00;oIVIV00?o0000oda<C?l000002Olc<c<00ol0003oC4a<o`000002ofIVIP07o`000?moOgoo0000
oiVIVOl0003o/k>co`000008olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIV
o`000?m<C4co00001?lc<c<6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03
oooooa;o/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKo
IVIV00coIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgoo
Ogmo00SoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`0Dok>c/`03o`000?nIVIWo
VIVI00?oVIVI00?o0000ogmoOomoOgl00_moOgl01Ol0003oIVIVofIVI_mVIVKo000000KoC4a<0_l0
0004oc<c<`03o`000?m<C4coC4a<00CoC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`05o`00
0?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o
/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00002oda<C003o`000?lc<c?o
<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP03o`000?moOgoo000000;oVIVI00Co
0000ok>c/onc/k?o00002Oo<c<`02?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo00000_mVIVH0
1?l0003oC4a<oda<C?l00008oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVI
o`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>co`000?nIVIWo000000;oOgmo0_l0
0002oda<C003o`000?lc<c?o<c<c00;o<c<c1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000
ooooooooool00ooooolAok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl2
o`0000coIVIV0_l0000Hoda<C003o`000?mVIVKoIVIV00[oIVIV0_l0000:ogmoO`03o`000?nIVIWo
VIVI00KoVIVI00?o0000ok>c/onc/k<05?nc/k<00ol0003oVIVIoiVIV@03oiVIV@03o`000?moOgoo
Ogmo00;oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C004oda<C003o`000?lc<c?o
<c<c00?o<c<c00?o0000oda<C?m<C4`00om<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Go
0000oiVIVOnIVIWoVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o
/k>co`000003oiVIV@03o`000?moOgoo000000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c
<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o
/k>co`0000Soc<c<00Wo0000ok>c/onc/k?o/k>co`000?nIVIWo0000ogmoOol000000_mVIVH01?l0
003oC4a<oda<C?l00008oc<c<`03o`000?m<C4co000000;oIVIV00Oo0000ogmoOol0003oVIVIo`00
0?nc/k?o000000Woc<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`0
0ol0003o<c<coc<c<`02oc<c<`Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo
00?ooooo4?nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIV
I_mVIVH03?mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00[oIVIV00?o0000ogmo
OomoOgl02OmoOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c01Go/k>c00?o0000oiVI
VOnIVIT00_nIVIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<
C?m<C4`01?m<C4`00ol0003o<c<coc<c<`03oc<c<`03o`000?m<C4coC4a<00?oC4a<00Go0000ofIV
I_mVIVKoIVIVo`000003ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000onc/k<00ol0003oc<c<olc<
c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP05
o`000?m<C4coC4a<oda<C?l000002?lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o0000
ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00008olc<c00;o`000?nc/k?o/k>cok>c/ol0003o
VIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`03o`000?m<C4co
000000;oIVIV00Oo0000ogmoOol0003oVIVIo`000?nc/k?o000000Woc<c<00Wo0000ok>c/ol0003o
VIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`02oc<c<`Kooooo0Ol00001
ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo3onc/k<00ol0003oVIVIoiVIV@0;oiVI
V@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH03?mVIVH00ol0003oC4a<oda<C00Foda<
C003o`000?mVIVKoIVIV00[oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@07oiVI
V@03o`000?nc/k?o/k>c01Co/k>c00?o0000oiVIVOnIVIT00_nIVIT00ol0003oOgmoogmoO`03ogmo
O`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01?m<C4`00ol0003o<c<coc<c<`03oc<c
<`03o`000?m<C4coC4a<00?oC4a<00?o0000ofIVI_mVIVH00_mVIVH01?l0003oOgmoogmoOol00003
oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nI
VIWoVIVIo`0000;oOgmo00?o0000ofIVI_l000000om<C4`00ol0003o<c<coc<c<`07oc<c<`04o`00
0?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00008olc<
c009o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co
00002?lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Wo
c<c<00?o0000ok>c/ol000000_nIVIT2o`000005ofIVI_l0003oC4a<oda<C?l000001Olc<c<6oooo
o`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`ko/k>c00?o0000oiVIVOnI
VIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`;o00003OmVIVH00ol0003oC4a<oda<C00Foda<C003
o`000?mVIVKoIVIV00[oIVIV0_l0000:ogmoO`03o`000?nIVIWoVIVI00OoVIVI00?o0000ok>c/onc
/k<05?nc/k<00ol0003oVIVIoiVIV@03oiVIV@03o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mV
IVH00_mVIVH00ol0003oC4a<oda<C005oda<C003o`000?lc<c?o<c<c00;o<c<c00?o0000oda<C?m<
C4`01?m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000004
ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?mo
OgooOgmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`05o`000?m<C4coC4a<oda<
C?l000000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Co0000
ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIVIP03o`000?m<C4co000000Wo<c<c00co
0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00009olc<c009o`000?nc
/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<00olc<c<6oooo
o`7o00000Oooool1ooooo`009?ooool2o`0000Cooooo3Onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03
o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH03?mVIVH00ol0003oC4a<oda<C00Foda<C003
o`000?mVIVKoIVIV00[oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@08oiVIV@03
o`000?nc/k?o/k>c01Co/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`02ogmoO`03
o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01Om<C4`01Ol0003o<c<coc<c<olc<c?o0000
00OoC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc
/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmo
ogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01Ol0003oC4a<oda<C?m<C4co
000000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00008olc<c004o`000?nc
/k?o/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH00ol0003oC4a<o`000009oc<c<`0<o`00
0?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00002Oo<c<`02Ol0003o/k>c
o`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00?o<c<c1Oooool2
o`0000;ooooo000Tooooo`03o`000?oooooooooo00?ooooo3?nc/k<00ol0003oVIVIoiVIV@0;oiVI
V@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH03?mVIVH00ol0003oC4a<oda<C00Foda<
C003o`000?mVIVKoIVIV00[oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@08oiVI
V@03o`000?nc/k?o/k>c01Co/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`02ogmo
O`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01Om<C4`00ol0003o<c<coc<c<`02oc<c
<`03o`000?m<C4coC4a<00CoC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`05o`000?nIVIWo
VIVIoiVIVOl000001?nc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol00000
0_nIVIT01?l0003oOgmoogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01Ol0
003oC4a<oda<C?m<C4co000000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol0
0008olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH00ol0003oC4a<
o`000009oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o
0000olc<c?o<c<`01_o<c<`01ol0003o/k>co`000?nIVIWo0000ogmoOol000000_mVIVH00ol0003o
C4a<o`000006oc<c<`Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo
2onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo0_l0000=ofIVIP03o`00
0?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02_mVIVH2o`0000[oOgmo00?o0000oiVIVOnIVIT0
2?nIVIT00ol0003o/k>cok>c/`0Dok>c/`03o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl0
0_moOgl2o`0000?oIVIV00?o0000oda<C?m<C4`01Om<C4`00ol0003o<c<coc<c<`02oc<c<`03o`00
0?m<C4coC4a<00CoC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`05o`000?nIVIWoVIVIoiVI
VOl000001?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVI
VOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Oo
0000oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo00000_nc/k<00ol0
003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Go0000ogmoOol0003oIVIVo`00
0002oda<C003o`000?lc<c?o<c<c00Oo<c<c00?o0000oda<C?l000000_mVIVH01Ol0003oOgmoo`00
0?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02ol0003o/k>co`000?nIVIWo0000ogmo
Ool0003oIVIVo`000?m<C4co000000Oo<c<c1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000
ooooooooool00oooool:ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl0
0ol0003oIVIVofIVIP0;ofIVIP;o00006?m<C4`00ol0003oIVIVofIVIP0:ofIVIP03o`000?moOgoo
Ogmo00WoOgmo00?o0000oiVIVOnIVIT02OnIVIT00ol0003o/k>cok>c/`0Dok>c/`03o`000?nIVIWo
VIVI00?oVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP02ofIVIP03o`000?m<C4co
C4a<00GoC4a<00?o0000oc<c<olc<c<00_lc<c<00ol0003oC4a<oda<C004oda<C005o`000?mVIVKo
IVIVofIVI_l000000omoOgl01Ol0003oVIVIoiVIVOnIVIWo000000?o/k>c00?o0000olc<c?o<c<`0
1_o<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co0000ofIVI_mV
IVKo00000_m<C4`00ol0003o<c<coc<c<`07oc<c<`07o`000?m<C4coC4a<oda<C?l0003oIVIVo`00
0002ogmoO`03o`000?nIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c
/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`03
o`000?m<C4co000000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<
00Goc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00007oc<c
<`Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo2Onc/k<00ol0003o
VIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003o
C4a<oda<C00Goda<C003o`000?mVIVKoIVIV00[oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003o
VIVIoiVIV@09oiVIV@03o`000?nc/k?o/k>c01Co/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003o
OgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01_m<C4`01Ol0003o
<c<coc<c<olc<c?o000000KoC4a<00?o0000ofIVI_mVIVH00_mVIVH01?l0003oOgmoogmoOol00003
oiVIV@03o`000?nc/k?o/k>c00;o/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02
ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<c
oc<c<`06oc<c<`07o`000?m<C4coC4a<oda<C?l0003oIVIVo`000002ogmoO`04o`000?nIVIWoVIVI
o`0000;o/k>c00?o0000olc<c?o<c<`01oo<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo
0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c00[o0000oda<C?m<C4co0000ofIVI_l0
003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o0000oiVI
VOl000000_moOgl2o`0000;oC4a<00?o0000oc<c<olc<c<01Olc<c<6ooooo`7o00000Oooool1oooo
o`009?ooool00ol0003oooooooooo`03ooooo`So/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003o
OgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003o
IVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02OnIVIT00ol0003o
/k>cok>c/`0Dok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003o
IVIVofIVIP02ofIVIP03o`000?m<C4coC4a<00GoC4a<00Go0000oc<c<olc<c?o<c<co`000007oda<
C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<
c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000003oiVIV@04o`000?moOgooOgmoo`0000;o
IVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Ko0000
ogmoOomoOgoo0000oiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o
00000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<2o`00
0009oda<C?l0003oIVIVofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`0
1_o<c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o
<c<c00Go<c<c1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool7ok>c
/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIV
IP;o00006?m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVI
VOnIVIT02?nIVIT00ol0003o/k>cok>c/`0Eok>c/`03o`000?nIVIWoVIVI00CoVIVI00Go0000ogmo
OomoOgooOgmoo`000005ofIVIP03o`000?m<C4coC4a<00GoC4a<00Go0000oc<c<olc<c?o<c<co`00
0007oda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01?l0003oVIVIoiVIVOl00004ok>c/`03
o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000003oiVIV@04o`000?moOgooOgmo
o`0000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<01?l0003oC4a<oda<C?l00002ofIVIP06o`00
0?moOgooOgmoo`000?nIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>c
o`0000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co
0000oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<
c<`01_o<c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc
<c?o<c<c00Go<c<c1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool6
ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;
ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08
ogmoO`;o00002_nIVIT00ol0003o/k>cok>c/`0Eok>c/`03o`000?nIVIWoVIVI00CoVIVI00Go0000
ogmoOomoOgooOgmoo`000005ofIVIP03o`000?m<C4coC4a<00GoC4a<00Go0000oc<c<olc<c?o<c<c
o`000007oda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01Ol0003oVIVIoiVIVOnIVIWo0000
00?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000?oVIVI00Co0000
ogmoOomoOgoo00000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Go0000oda<C?m<C4co
C4a<o`000002ofIVIP05o`000?moOgoo0000oiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<
c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l0
0007oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03
o`000?o<c<coc<c<00Koc<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<
C4`00ol0003o<c<coc<c<`06oc<c<`Kooooo0Ol00001ooooo`7ooooo000Iooooo`05olc<c?lQ8B7o
0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`03ooooo`Go/k>c00?o0000oiVIVOnIVIT02_nI
VIT2o`0000[oOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C0;o00003OmV
IVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00WoVIVI00?o0000ok>c/onc/k<05Onc
/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH00_mV
IVH00ol0003oC4a<oda<C006oda<C005o`000?lc<c?o<c<coc<c<ol000001_m<C4`01Ol0003oIVIV
ofIVI_mVIVKo000000?oOgmo00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<
00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKo
IVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV
00Ko0000ogmoOomoOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Co0000ok>c
/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc
<c<01?l0003oC4a<oda<C?l00002ofIVIP07o`000?moOgoo0000oiVIVOl0003o/k>co`000009olc<
c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<0
1_lc<c<00ol0003oooooooooo`03ooooo`7o00000Oooool1ooooo`006Oooool01OlQ8B7oV9RHoooo
oonHV9So8B4Q00Kooooo00?o0000ooooooooool00oooool4ok>c/`03o`000?nIVIWoVIVI00_oVIVI
00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<
00?o0000ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00[oVIVI
00?o0000ok>c/onc/k<05Onc/k<00ol0003oVIVIoiVIV@03oiVIV@03o`000?moOgooOgmo00?oOgmo
00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C006oda<C005o`000?lc<c?o<c<coc<c<ol0
00001_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Go0000oiVIVOnIVIWoVIVIo`000004
ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl0
0002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<
oda<C?m<C4co000000;oIVIV00Ko0000ogmoOomoOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<co
c<c<00Ooc<c<00Co0000ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<
00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP07o`000?moOgoo0000oiVI
VOl0003o/k>co`000009olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000;o
C4a<00?o0000oc<c<olc<c<01_lc<c<00ol0003oooooooooo`03ooooo`7o00000Oooool1ooooo`00
6Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00oooool3ok>c/`03
o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03
o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmoO`08ogmoO`03
o`000?nIVIWoVIVI00[oVIVI00?o0000ok>c/onc/k<05Onc/k<00ol0003oVIVIoiVIV@04oiVIV@03
o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C006oda<C0?o
000000?o<c<co`000?m<C4`01Om<C4`00ol0003oIVIVofIVIP02ofIVIP04o`000?moOgooOgmoo`00
00?oVIVI00?o0000ok>c/onc/k<00_nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c
00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc
<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP06o`000?moOgooOgmoo`000?nI
VIWo00000onc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Go0000
ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00?o0000oda<C?l000000_mV
IVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01ol0003o/k>c
o`000?nIVIWo0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00007oc<c<`03o`000?oooooo
oooo00Cooooo0Ol00001ooooo`7ooooo000Iooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3
o`0000?ooooo0_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000
ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00coIVIV00?o0000
ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0:oiVIV@03o`000?nc/k?o/k>c01Go/k>c00?o0000
oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00;oIVIV0_l00007
oda<C005o`000?lc<c?o<c<coc<c<ol000001om<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo
00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc
/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000
oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o0000ogmoOol000000_nI
VIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Go0000ok>c/onc/k?o0000oiVIV@02o`000004
ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01olc<c<00ol0003oC4a<o`000002ofIV
IP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c008o`000?nc/k?o
0000oiVIVOl0003oOgmoo`000?mVIVH2o`000003oda<C?l0003o<c<c00Oo<c<c00?o0000oooooooo
ool00_ooool3o`0000;ooooo000Iooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003o
ooooooooo`03ooooo`03ok>c/ol0003oVIVI00coVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003o
IVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003o
OgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05Onc/k<00ol0003o
VIVIoiVIV@04oiVIV@05o`000?moOgooOgmoogmoOol000001OmVIVH00ol0003oC4a<oda<C006oda<
C005o`000?lc<c?o<c<coc<c<ol000001om<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Go
0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<0
0_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c
<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o0000ogmoOol000000_nIVIT0
1Ol0003o/k>cok>c/onc/k?o000000Ooc<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo000000;o
Ogmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`03o`000?m<C4co000000;o
IVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Wo0000ok>c
/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`03o`00
0?oooooooooo00Cooooo0Ol00001ooooo`7ooooo000Iooooo`05oa0@4?nj^[[ooooookZj^_l@4100
1_ooool00ol0003oooooooooo`03ooooo`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl0
2OmoOgl00ol0003oIVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH0
3?mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<0
5Onc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH0
0_mVIVH00ol0003oC4a<oda<C006oda<C005o`000?lc<c?o<c<coc<c<ol000001om<C4`01Ol0003o
IVIVofIVI_mVIVKo000000?oOgmo00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<co
c<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Co
0000ofIVI_mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l0
00000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Co0000
ok>c/onc/k?o/k>c0_l00002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01olc
<c<00ol0003oC4a<o`000002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<
olc<c006olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000
oc<c<olc<c<01_lc<c<00ol0003oC4a<ooooo`05ooooo`7o00000Oooool1ooooo`006Oooool01Ol0
003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool00oooool=oiVIV@03o`000?moOgoo
Ogmo00SoOgmo0_l0000<ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH2
o`0000[oOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Eok>c/`03o`000?nIVIWo
VIVI00CoVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4co
C4a<00KoC4a<0_l000000olc<c?o0000oda<C006oda<C005o`000?mVIVKoIVIVofIVI_l000000omo
Ogl01Ol0003oVIVIoiVIVOnIVIWo000000Go/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>c
ok>c/`02ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00003oda<
C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP03o`000?moOgoo
000000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;o
Ogmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`00
00;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00_o0000
ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`000009oc<c<`03o`000?m<C4cooooo
00Gooooo0Ol00001ooooo`7ooooo000Iooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0
003oooooooooo`03ooooo`coVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0:ofIV
IP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmoO`08ogmo
O`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@04oiVI
V@03o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C008oda<
C003o`000?m<C4coC4a<00KoC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`05o`000?nIVIWo
VIVIoiVIVOl000001Onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00;o/k>c00Go
0000oiVIVOnIVIWoVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc
<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0
003o/k>cok>c/ol00009olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl00ol0003oIVIV
o`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH01Ol0003o
Ogmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02ol0003o/k>co`000?nIVIWo
0000ogmoOol0003oIVIVo`000?m<C4co000000Wo<c<c00?o0000oda<C?l000001Oooool1o`00007o
oooo0Oooool002Cooooo00?o0000ooooooooool00oooool;oiVIV@03o`000?moOgooOgmo00WoOgmo
00?o0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00coIVIV
00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c
00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00?oIVIV
00?o0000oda<C?m<C4`04Om<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Go0000oiVIVOnI
VIWoVIVIo`000005ok>c/`03o`000?o<c<coc<c<00Goc<c<00Go0000ok>c/onc/k?o/k>co`000003
oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`03o`00
0?m<C4coC4a<00;oC4a<00Go0000ofIVI_l0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`00
00Woc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000;oC4a<
00?o0000oc<c<olc<c<01_lc<c<00ol0003oC4a<o`000002ofIVIP03o`000?moOgoo000000;oVIVI
00?o0000ok>c/ol000002?o<c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002
oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00001Oooool1o`00007ooooo0Ooo
ool002Cooooo00?o0000ooooooooool00oooool:oiVIV@03o`000?moOgooOgmo00SoOgmo0_l0000<
ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH2o`0000[oOgmo00?o0000
oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Eok>c/`;o00001_nIVIT00ol0003oOgmoogmoO`02
ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<C4`04_m<C4`01Ol0003oIVIVofIVI_mV
IVKo000000?oOgmo00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Goc<c<
00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`05o`000?mVIVKoIVIVofIV
I_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`07o`000?m<C4coC4a<oda<C?l0003oIVIVo`00
0002ogmoO`04o`000?nIVIWoVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01oo<c<`01_l0003o/k>c
ok>c/ol0003oVIVIo`0000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c
<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl01Ol0003oVIVIo`000?nc/k?o000000Woc<c<
00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06
oc<c<`03o`000?m<C4co000000Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo
00?ooooo2OnIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<
C?m<C4`05om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVI
VOnIVIT03?nIVIT00ol0003o/k>cok>c/`0Eok>c/`03o`000?nIVIWoVIVI00GoVIVI00?o0000ogmo
OomoOgl00_moOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<01;oC4a<00Go0000ofIV
I_mVIVKoIVIVo`000003ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0003oc<c<olc<
c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01Ol0003oIVIV
ofIVI_mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01olc<c<01ol0003oC4a<oda<C?m<C4co0000
ofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Ko
0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc
<c<01_lc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00Go0000oiVIVOl0003o/k>co`00
0009olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c
<olc<c<01_lc<c<00ol0003oC4a<o`000006ooooo`7o00000Oooool1ooooo`009?ooool00ol0003o
ooooooooo`03ooooo`SoVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0<ofIVIP03
o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03
o`000?nIVIWoVIVI00coVIVI00?o0000ok>c/onc/k<05Onc/k<00ol0003oVIVIoiVIV@05oiVIV@03
o`000?moOgooOgmo00?oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C00Boda<C005
o`000?mVIVKoIVIVofIVI_l000001?moOgl01?l0003oVIVIoiVIVOl00005ok>c/`03o`000?o<c<co
c<c<00Goc<c<00Go0000ok>c/onc/k?o/k>co`000003oiVIV@04o`000?moOgooOgmoo`0000;oIVIV
00Go0000oda<C?m<C4coC4a<o`000008oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01_l0
003oOgmoogmoOol0003oVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01ol0003o/k>cok>c
/onc/k?o0000oiVIVOl000000_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko
<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`05o`000?nIVIWo0000ok>c/ol000002Oo<
c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c
00Ko<c<c00?o0000oda<C?l000001_ooool1o`00007ooooo0Oooool002Cooooo00?o0000oooooooo
ool00oooool7oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH03?mVIVH00ol0003o
C4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003o
VIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT01OnIVIT00ol0003o
OgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<C4`04Om<C4`00ol0003o
IVIVofIVIP02ofIVIP05o`000?moOgooOgmoogmoOol000000onIVIT00ol0003o/k>cok>c/`02ok>c
/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo
000000;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`07o`000?m<
C4coC4a<oda<C?l0003oIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000;o/k>c00?o0000olc<
c?o<c<`01oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<
C4`00ol0003o<c<coc<c<`07oc<c<`05o`000?m<C4co0000ofIVI_l000000_moOgl00ol0003oVIVI
o`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000
ofIVI_l000000om<C4`00ol0003o<c<coc<c<`05oc<c<`04o`000?m<C4co0000ofIVIPKooooo0Ol0
0001ooooo`7ooooo000Tooooo`;o00001?ooool6oiVIV@03o`000?moOgooOgmo00SoOgmo0_l0000<
ofIVIP;o00006?m<C4`00ol0003oIVIVofIVIP0:ofIVIP;o00002_moOgl2o`0000coVIVI0_l0000H
ok>c/`03o`000?nIVIWoVIVI00GoVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP03
ofIVIP03o`000?m<C4coC4a<01;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`05o`000?nI
VIWoVIVIoiVIVOl000001Onc/k<00ol0003oc<c<olc<c004olc<c0;o00001?nc/k<01?l0003oVIVI
oiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01Olc<c<01Ol0
003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01?l0003o/k>cok>c
/ol00008olc<c003o`000?nc/k?o/k>c00;o000000OoVIVIo`000?moOgooOgmoo`000?mVIVKo0000
00;oC4a<00?o0000oc<c<olc<c<01olc<c<01Ol0003oC4a<o`000?mVIVKo000000;oOgmo00?o0000
oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmo
o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<o`000?mVIVH5oooo
o`;o00000_ooool002Cooooo00?o0000ooooooooool00oooool5oiVIV@03o`000?moOgooOgmo00So
Ogmo00?o0000ofIVI_mVIVH03?mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00[o
IVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo
/k>c00?o0000oiVIVOnIVIT01OnIVIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00;o
IVIV00?o0000oda<C?m<C4`04om<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Go0000oiVI
VOnIVIWoVIVIo`000005ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00onc/k<0
1?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<0
1_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01?l0
003o/k>cok>c/ol00008olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Ko0000ogmoOomoOgoo0000
ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Go0000oda<C?l0003oIVIVo`000002ogmo
O`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02Ol0003o/k>co`000?nIVIWo
0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?l0003o
IVIVo`000005ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`CoVIVI
00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<01KoC4a<
00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI
00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@05oiVIV@03o`000?moOgooOgmo00?oOgmo
00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00Boda<C005o`000?mVIVKoIVIVofIVI_l0
00000omoOgl01Ol0003oVIVIoiVIVOnIVIWo000000Go/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0
003o/k>cok>c/`03ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo00001?m<
C4`00ol0003o<c<coc<c<`05oc<c<`05o`000?m<C4coC4a<oda<C?l000000omVIVH00ol0003oOgmo
o`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo
000000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`;o000000CoC4a<
o`000?mVIVKo00000_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Oo
0000ok>c/ol0003oVIVIo`000?moOgoo000000;oIVIV00?o0000oda<C?l000002Olc<c<2o`0000;o
IVIV00?o0000ooooooooool00oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool0
0oooool3oiVIV@03o`000?moOgooOgmo00SoOgmo0_l0000=ofIVIP03o`000?m<C4coC4a<01KoC4a<
00?o0000ofIVI_mVIVH02_mVIVH2o`0000[oOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>c
ok>c/`0Gok>c/`03o`000?nIVIWoVIVI00KoVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIV
ofIVIP03ofIVIP03o`000?m<C4coC4a<01;oC4a<00?o0000ofIVI_mVIVH00_mVIVH00ol0003oOgmo
ogmoO`02o`0000?oVIVI00?o0000ok>c/onc/k<00_nc/k<00ol0003oc<c<olc<c005olc<c003o`00
0?nc/k?o/k>c00;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`00
00?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000
ogmoOomoOgoo00000_nIVIT01?l0003o/k>cok>c/ol00008olc<c009o`000?nc/k?o/k>cok>c/ol0
003oVIVIo`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<01_l0003oC4a<oda<
C?l0003oIVIVo`0000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c007
o`000?nc/k?o0000oiVIVOl0003oOgmoo`000002ofIVIP03o`000?m<C4co000000Wo<c<c0_l00000
0omVIVKo0000ooooo`05ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03oooo
o`;oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<
01KoC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI
00_oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@06oiVIV@03o`000?moOgooOgmo
00?oOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00Boda<C003o`000?mVIVKoIVIV
00;oIVIV00Co0000ogmoOomoOgoo00001?nIVIT00ol0003o/k>cok>c/`02ok>c/`03o`000?o<c<co
c<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Co
0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l0
00000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Wo0000
ok>c/onc/k?o/k>co`000?nIVIWo0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00008oc<c
<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<
c<coc<c<00Koc<c<00Oo0000ok>c/ol0003oVIVIo`000?moOgoo000000;oIVIV00?o0000oda<C?l0
00002Olc<c<2o`000003ofIVI_l0003ooooo00Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`00
0?oooooooooo00?ooooo00?oVIVIo`000?moOgl02OmoOgl00ol0003oIVIVofIVIP0<ofIVIP03o`00
0?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`00
0?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<06?nc/k<00ol0003oVIVIoiVIV@05oiVIV@03o`00
0?moOgooOgmo00?oOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00Boda<C003o`00
0?mVIVKoIVIV00;oIVIV00Co0000ogmoOomoOgoo00001?nIVIT00ol0003o/k>cok>c/`03ok>c/`03
o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo0000
00;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4co
C4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000So
c<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo00?o0000ofIVI_l000000_m<C4`0
0ol0003o<c<coc<c<`06oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl01_l0003oVIVI
oiVIVOl0003o/k>co`0000Soc<c<00Oo0000ok>c/ol0003oVIVIo`000?moOgoo000000;oIVIV00?o
0000oda<C?l000002Olc<c<01Ol0003oC4a<o`000?l0003oOgmo00Kooooo0Ol00001ooooo`7ooooo
000Tooooo`03o`000?oooooooooo00?ooooo00?o0000ogmoOomoOgl02?moOgl2o`0000goIVIV00?o
0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0:ofIVIP;o00002_moOgl00ol0003oVIVIoiVI
V@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c0_l00007oiVIV@03o`000?moOgooOgmo00CoOgmo00?o
0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00Boda<C005o`000?mVIVKoIVIVofIVI_l00000
0omoOgl01Ol0003oVIVIoiVIVOnIVIWo000000Go/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o
/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000?oOgmo00Co0000ofIVI_mVIVKo00000om<C4`0
0ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01_l0003oOgmoogmo
Ool0003oVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVI
V@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<01ol0003oC4a<oda<C?l0
003oIVIVo`000?moOgl00_l000001?nIVIWo0000ok>c/ol00009olc<c009o`000?nc/k?o0000oiVI
VOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<00ol0003oC4a<oda<
C002o`000003ogmoOooooooooooo00Cooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooo
oooo00?ooooo2_moOgl00ol0003oIVIVofIVIP0;ofIVIP;o00006?m<C4`00ol0003oIVIVofIVIP0:
ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0G
ok>c/`03o`000?nIVIWoVIVI00OoVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIVIP03
ofIVIP03o`000?m<C4coC4a<01?oC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`05o`000?nI
VIWoVIVIoiVIVOl000001Onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c
00Co0000oiVIVOnIVIWo00000omoOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c
00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP06o`000?moOgooOgmoo`000?nIVIWo0000
0onc/k<00ol0003oc<c<olc<c006olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl01?l0
003oIVIVofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00So0000oda<C?m<C4co0000ofIV
I_l0003oOgmoo`0000;oVIVI00?o0000ok>c/ol000002Oo<c<`02Ol0003o/k>co`000?nIVIWo0000
ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00?o0000oda<C?m<C4`00_l0
00000omoOgoo0000ooooo`04ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03
ooooo`WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKo
IVIV00[oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o
/k>c01So/k>c00?o0000oiVIVOnIVIT01_nIVIT00ol0003oOgmoogmoO`04ogmoO`03o`000?mVIVKo
IVIV00?oIVIV00?o0000oda<C?m<C4`04_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Go
0000oiVIVOnIVIWoVIVIo`000005ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<0
0_nc/k<01?l0003oVIVIoiVIVOl00003ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c
<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nI
VIT01?l0003o/k>cok>c/ol00008olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol0
00000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmo
Ool00002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00?o0000ok>c/ol000000_nIVIT2o`0000;o
IVIV00?o0000oda<C?l000002Olc<c<01ol0003oC4a<o`000?mVIVKo0000ogmoOol000001Oooool1
o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool8ogmoO`03o`000?mVIVKoIVIV
00_oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo
00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Hok>c/`03o`000?nIVIWoVIVI
00KoVIVI00?o0000ogmoOomoOgl01?moOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<
01;oC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000?oVIVI00?o0000
ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Co0000
oiVIVOnIVIWo00000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000?oC4a<00?o0000oc<c<olc<c<0
1_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o0000ogmoOol000000_nIVIT01Ol0003o
/k>cok>c/onc/k?o000000Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002
ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00So0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`00
00;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01ol0003o/k>co`000?nIVIWo0000ogmoOol00000
0_mVIVH00ol0003oC4a<o`000008oc<c<`05o`000?m<C4coC4a<o`000?mVIVH00_l00006ooooo`7o
00000Oooool1ooooo`009?ooool2o`0000Cooooo1omoOgl00ol0003oIVIVofIVIP0;ofIVIP;o0000
6?m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT0
2_nIVIT00ol0003o/k>cok>c/`0Hok>c/`03o`000?nIVIWoVIVI00OoVIVI00?o0000ogmoOomoOgl0
1?moOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<01;oC4a<00?o0000ofIVI_mVIVH0
0_mVIVH01?l0003oOgmoogmoOol00004oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<
c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Go0000ofIV
I_mVIVKoIVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mV
IVH01?l0003oOgmoogmoOol00002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01?l0003o
/k>cok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<0
2?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo00000_nIVIT01?l0003o/k>cok>c/ol00008olc<
c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<0
1_lc<c<01Ol0003oC4a<oda<C?l0003oIVIV00;o00001Oooool2o`0000;ooooo000Tooooo`03o`00
0?oooooooooo00?ooooo1_moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<
00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`;o00003?nIVIT00ol0003o/k>c
ok>c/`0Hok>c/`03o`000?nIVIWoVIVI00OoVIVI00?o0000ogmoOomoOgl01?moOgl00ol0003oIVIV
ofIVIP03ofIVIP03o`000?m<C4coC4a<01;oC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmo
ogmoOomoOgoo000000?oVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c004olc<c003
o`000?nc/k?o/k>c00?o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01Ol0003oIVIVofIVI_mVIVKo
000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o
0000ogmoOol000000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Co0000ok>c/onc/k?o
00000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00So0000oda<
C?m<C4co0000ofIVI_l0003oOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`00ol0003o
/k>cok>c/`02o`000007ogmoOol0003oIVIVofIVI_l0003oC4a<o`000009oc<c<`04o`000?m<C4co
0000ofIVIP;o000000?oVIVIooooooooool01?ooool1o`00007ooooo0Oooool002Cooooo00?o0000
ooooooooool00oooool5ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`2
o`0000goIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o
/k>c01So/k>c00?o0000oiVIVOnIVIT01onIVIT00ol0003oOgmoogmoO`03ogmoO`;o00001OmVIVH0
0ol0003oC4a<oda<C00Boda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgooOgmoo`00
0003oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c
/`02ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00003oda<C003
o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmo
o`0000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`00
0?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<02?l0003oC4a<oda<C?l0003oIVIV
o`000?moOgoo00000_nIVIT01?l0003o/k>cok>c/ol00008olc<c007o`000?nc/k?o0000oiVIVOl0
003oOgmoo`000002ofIVIP03o`000?m<C4co000000Wo<c<c00Co0000oda<C?l0003oIVIV0_l00000
0onIVIWoooooooooo`04ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03oooo
o`CoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV
00coIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c
01So/k>c00?o0000oiVIVOnIVIT01onIVIT00ol0003oOgmoogmoO`04ogmoO`03o`000?mVIVKoIVIV
00CoIVIV00?o0000oda<C?m<C4`04_m<C4`00ol0003oIVIVofIVIP02ofIVIP05o`000?moOgooOgmo
ogmoOol000000onIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000
ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`05o`000?mVIVKoIVIVofIVI_l00000
0om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003o
OgmoogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Woc<c<00Co0000ok>c/onc/k?o00000_nI
VIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00[o0000oda<C?m<C4co
0000ofIVI_l0003oOgmoo`000?nIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c007o`000?nc
/k?o0000oiVIVOl0003oOgmoo`000002ofIVIP03o`000?m<C4co000000Wo<c<c00Co0000oda<C?l0
003oIVIV0_l000000onIVIWoooooooooo`04ooooo`7o00000Oooool1ooooo`009?ooool00ol0003o
ooooooooo`03ooooo`?oOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003
o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03
o`000?nc/k?o/k>c01Oo/k>c0_l00009oiVIV@03o`000?moOgooOgmo00CoOgmo00?o0000ofIVI_mV
IVH01?mVIVH00ol0003oC4a<oda<C00Boda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomo
OgooOgmoo`000003oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0
003o/k>cok>c/`02ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01Ol0003oIVIVofIVI_mV
IVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV
00Co0000ogmoOomoOgoo00000_nIVIT01?l0003o/k>cok>c/ol00009olc<c004o`000?nc/k?o/k>c
o`0000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`08o`000?m<
C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Go0000
ok>c/ol0003oVIVIo`000002ogmoO`05o`000?mVIVKo0000oda<C?l000002Olc<c<02Ol0003oC4a<
o`000?mVIVKo0000ogmoOol0003oVIVIo`000005ooooo`7o00000Oooool1ooooo`009?ooool00ol0
003oooooooooo`03ooooo`;oOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<
C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVI
V@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02?nIVIT2o`0000GoOgmo00?o0000ofIV
I_mVIVH01?mVIVH00ol0003oC4a<oda<C00Coda<C005o`000?mVIVKoIVIVofIVI_l000001?moOgl0
1Ol0003oVIVIoiVIVOnIVIWo000000Go/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c
/`03ok>c/`04o`000?nIVIWoVIVIo`0000?oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o
<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002
oiVIV@04o`000?nc/k?o/k>co`0000Woc<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmo
o`000002ofIVIP03o`000?m<C4co000000Wo<c<c00So0000oda<C?m<C4co0000ofIVI_l0003oOgmo
o`0000;oVIVI00?o0000ok>c/ol000002Oo<c<`01Ol0003o/k>co`000?nIVIWo000000;oOgmo00Go
0000ofIVI_l0003oC4a<o`000008oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003o
VIVIo`0000Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo0_moOgl0
0ol0003oIVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH03?mVIVH0
0ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<2
o`0000_oVIVI00?o0000ogmoOomoOgl01?moOgl00ol0003oIVIVofIVIP04ofIVIP03o`000?m<C4co
C4a<01;oC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000CoVIVI00?o
0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Co
0000oiVIVOnIVIWo00000omoOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko
<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Co0000
ok>c/onc/k?o00002?o<c<`01ol0003o/k>cok>c/onc/k?o0000oiVIVOl000000_moOgl01_l0003o
IVIVofIVI_l0003oC4a<o`0000Wo<c<c00So0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000;o
VIVI00?o0000ok>c/ol000002Oo<c<`01Ol0003o/k>co`000?nIVIWo000000;oOgmo00Go0000ofIV
I_l0003oC4a<o`000008oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`00
00Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo00?oOgmoo`000?mV
IVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomo
Ogl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnI
VIT02_nIVIT00ol0003oOgmoogmoO`04ogmoO`03o`000?mVIVKoIVIV00CoIVIV00?o0000oda<C?m<
C4`04om<C4`01Ol0003oIVIVofIVI_mVIVKo000000CoOgmo00Go0000oiVIVOnIVIWoVIVIo`000005
ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00onc/k<01?l0003oVIVIoiVIVOl0
0003ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01Olc<c<01Ol0003oC4a<
oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000onIVIT01?l0003o/k>cok>c/ol00008
olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<
C?l00008oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl01Ol0003oVIVIo`000?nc/k?o
000000Woc<c<00?o0000ok>c/ol000000_nIVIT01ol0003oOgmoo`000?mVIVKo0000oda<C?l00000
2Olc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000006ooooo`7o00000Oooool1
ooooo`009?ooool00ol0003oooooooooo`03ooooo`03o`000?mVIVKoIVIV00[oIVIV00?o0000oda<
C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP;o00002_moOgl00ol0003oVIVIoiVIV@0;oiVI
V@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`04ogmo
O`03o`000?mVIVKoIVIV00CoIVIV00?o0000oda<C?m<C4`04om<C4`00ol0003oIVIVofIVIP02ofIV
IP05o`000?moOgooOgmoogmoOol000000onIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<co
c<c<00Coc<c<00?o0000ok>c/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Go
0000ofIVI_mVIVKoIVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4co
C4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`0
1ol0003o/k>cok>c/onc/k?o0000oiVIVOl000000_moOgl00ol0003oIVIVo`000003oda<C003o`00
0?lc<c?o<c<c00Ko<c<c00So0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000;oVIVI00?o0000
ok>c/ol000002Oo<c<`01Ol0003o/k>co`000?nIVIWo000000;oOgmo00Go0000ofIVI_l0003oC4a<
o`000008oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000Kooooo0Ol0
0001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo3?mVIVH00ol0003oC4a<oda<C00F
oda<C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;
oiVIV@03o`000?nc/k?o/k>c01Ko/k>c0_l0000;oiVIV@03o`000?moOgooOgmo00GoOgmo00?o0000
ofIVI_mVIVH01?mVIVH00ol0003oC4a<oda<C00Coda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000
ogmoOomoOgooOgmoo`000003oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`01?o<
c<`00ol0003o/k>cok>c/`02ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01Ol0003oIVIV
ofIVI_mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co0000
00;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01?l0003o/k>cok>c/ol00008olc<c007o`000?nc
/k?o/k>cok>c/ol0003oVIVIo`000002ogmoO`03o`000?mVIVKo000000?oC4a<00?o0000oc<c<olc
<c<01_lc<c<02?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo00000_nIVIT00ol0003o/k>co`00
0009olc<c005o`000?nc/k?o0000oiVIVOl000000_moOgl01Ol0003oIVIVo`000?m<C4co000000So
<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00001_ooool1o`00007ooooo
0Oooool002Cooooo0_l00004ooooo`_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIV
IP0<ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c
/`0Fok>c/`03o`000?nIVIWoVIVI00[oVIVI00?o0000ogmoOomoOgl01OmoOgl00ol0003oIVIVofIV
IP04ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmo
OomoOgoo000000?oVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c004olc<c003o`00
0?nc/k?o/k>c00?o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01Ol0003oIVIVofIVI_mVIVKo0000
00?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000
ogmoOomoOgoo00000_nIVIT01?l0003o/k>cok>c/ol00009olc<c006o`000?nc/k?o/k>co`000?nI
VIWo00000_moOgl00ol0003oIVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c00So0000oda<
C?m<C4co0000ofIVI_l0003oOgmoo`0000;oVIVI00?o0000ok>c/ol000002Oo<c<`00ol0003o/k>c
ok>c/`02o`0000;oOgmo00Go0000ofIVI_l0003oC4a<o`000008oc<c<`0;o`000?m<C4coC4a<o`00
0?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k<01Oooool2o`0000;ooooo000Tooooo`03o`000?oo
oooooooo00?ooooo2_mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV0_l0
000:ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVI
V@0:oiVIV@03o`000?moOgooOgmo00GoOgmo0_l00005ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o
0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000CoVIVI00?o0000ok>c/onc/k<0
0onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Go0000oiVIVOnIVIWo
VIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0
003oC4a<oda<C?m<C4co000000;oIVIV00Ko0000ogmoOomoOgoo0000oiVIVOl00003ok>c/`03o`00
0?o<c<coc<c<00Ooc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`03o`000?mVIVKo0000
00?oC4a<00?o0000oc<c<olc<c<01_lc<c<02?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000
0_nIVIT00ol0003o/k>co`000009olc<c005o`000?nc/k?o0000oiVIVOl000000_moOgl01Ol0003o
IVIVo`000?m<C4co000000So<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo
0000ok>c/ol00005ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`Wo
IVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00So
Ogmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00[o
VIVI00?o0000ogmoOomoOgl01OmoOgl00ol0003oIVIVofIVIP04ofIVIP03o`000?m<C4coC4a<01?o
C4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000CoVIVI00?o0000ok>c
/onc/k<00onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Go0000oiVI
VOnIVIWoVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01_lc
<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Ko0000ogmoOomoOgoo0000oiVIVOl00003ok>c
/`03o`000?o<c<coc<c<00Ooc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`03o`000?mV
IVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?mo
Ogoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Go0000ok>c/ol0003oVIVIo`00
0002ogmoO`05o`000?mVIVKo0000oda<C?l000002?lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`00
0?moOgoo0000oiVIVOl0003o/k>co`0000Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oo
oooooooo00?ooooo2OmVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o
0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o
0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV00GoIVIV00?o
0000oda<C?m<C4`04om<C4`01Ol0003oIVIVofIVI_mVIVKo000000CoOgmo00Go0000oiVIVOnIVIWo
VIVIo`000006ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00onc/k<01Ol0003o
VIVIoiVIVOnIVIWo000000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o
<c<c00Go<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP06o`000?moOgooOgmoo`000?nIVIWo
00001?nc/k<00ol0003oc<c<olc<c006olc<c009o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000?mo
Ogoo000000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<02_l0003oC4a<oda<C?l0003oIVIVo`00
0?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Oo0000ok>c/ol0003oVIVI
o`000?moOgoo000000;oIVIV00?o0000oda<C?l000002?lc<c<01ol0003oC4a<oda<C?l0003oIVIV
o`000?moOgl00_l00002ok>c/`03o`000?oooooooooo00?ooooo0Ol00001ooooo`7ooooo000Toooo
o`03o`000?oooooooooo00?ooooo2?mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV
00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c
01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV
00CoIVIV00?o0000oda<C?m<C4`04om<C4`00ol0003oIVIVofIVIP02ofIVIP05o`000?moOgooOgmo
ogmoOol000001?nIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000
ok>c/onc/k<00onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo0000
1?m<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01_l0003o
Ogmoo`000?l0003oVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01oo<c<`01_l0003o/k>cok>c/ol0
003oVIVIo`0000;oOgmo00?o0000ofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`08o`00
0?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVIV@03o`000?nc/k?o000000Woc<c<00Go0000
ok>c/ol0003oVIVIo`000002ogmoO`05o`000?mVIVKo0000oda<C?l000002Olc<c<02ol0003oC4a<
o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o000000Kooooo0Ol00001ooooo`7ooooo000T
ooooo`03o`000?oooooooooo00?ooooo1_mVIVH2o`0001SoC4a<00?o0000ofIVI_mVIVH02_mVIVH2
o`0000[oOgmo0_l0000<oiVIV@;o00006?nc/k<00ol0003oVIVIoiVIV@0:oiVIV@;o00001_moOgl2
o`0000KoIVIV00?o0000oda<C?m<C4`04om<C4`00ol0003oIVIVofIVIP02ofIVIP03o`000?moOgoo
Ogmo00;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000005ok>c/`;o00001Oo<c<`00ol0003o/k>cok>c
/`03ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000Co
C4a<00?o0000oc<c<olc<c<01Olc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmo
OomoOgoo00000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Oo0000ok>c/onc/k?o/k>c
o`000?nIVIWo000000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`08
o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVIV@03o`000?nc/k?o000000Woc<c<00Go
0000ok>c/ol0003oVIVIo`000002ogmoO`05o`000?mVIVKo0000oda<C?l000002Olc<c<02ol0003o
C4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o000000Kooooo0Ol00001ooooo`7ooooo
000Tooooo`03o`000?oooooooooo00?ooooo1_mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mV
IVKoIVIV00[oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc
/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`06ogmoO`03o`000?mV
IVKoIVIV00GoIVIV00?o0000oda<C?m<C4`04om<C4`00ol0003oIVIVofIVIP02ofIVIP03o`000?mo
OgooOgmo00;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000005ok>c/`03o`000?o<c<coc<c<00Coc<c<
00?o0000ok>c/onc/k<00onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Go0000ofIVI_mV
IVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go<c<c00Go0000oda<C?m<C4coC4a<o`000002
ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c004o`00
0?nc/k?o/k>co`0000;oVIVI00Ko0000ogmoOomoOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o
<c<c00Oo<c<c00So0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000;oVIVI00?o0000ok>c/ol0
00002Oo<c<`01Ol0003o/k>co`000?nIVIWo000000;oOgmo00Go0000ofIVI_l0003oC4a<o`000009
oc<c<`0;o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol000001_ooool1o`00
007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool5ofIVIP03o`000?m<C4coC4a<01Ko
C4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00_o
VIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00Go
Ogmo00?o0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<C00Coda<C003o`000?mVIVKoIVIV00?o
IVIV00Go0000ogmoOomoOgooOgmoo`000003oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<
c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`03ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Go0000
ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go<c<c00Go0000oda<C?m<C4coC4a<
o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00?o0000ok>c/onc/k<00_nc/k<00ol0003o
c<c<olc<c005olc<c007o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000002ogmoO`03o`000?mVIVKo
000000;oC4a<00?o0000oc<c<olc<c<01olc<c<02?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo
00000_nIVIT00ol0003o/k>co`000009olc<c003o`000?nc/k?o000000;oVIVI00Oo0000ogmoOol0
003oIVIVo`000?m<C4co000000Wo<c<c00co0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0
003o/k>co`000?o<c<`6ooooo`7o00000Oooool1ooooo`004_ooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^h6ooooo`03o`000?oooooooooo00?ooooo1?mVIVH00ol0003oC4a<
oda<C00Foda<C003o`000?mVIVKoIVIV00[oIVIV0_l0000:ogmoO`03o`000?nIVIWoVIVI00_oVIVI
00?o0000ok>c/onc/k<05_nc/k<2o`0000goVIVI00?o0000ogmoOomoOgl01OmoOgl00ol0003oIVIV
ofIVIP05ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH00omVIVH01Ol0003oOgmo
ogmoOomoOgoo000000CoVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c004olc<c003
o`000?nc/k?o/k>c00?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`03o`000?mVIVKoIVIV
00;o00000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH0
1?l0003oOgmoogmoOol00002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01?l0003o/k>c
ok>c/ol00002oiVIV@06o`000?moOgooOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`07
oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<
c?o<c<`01oo<c<`01Ol0003o/k>co`000?nIVIWo000000;oOgmo00Go0000ofIVI_l0003oC4a<o`00
0008oc<c<`0=o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o0000olc<
c006ooooo`7o00000Oooool1ooooo`005?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01_ooool00ol0003oooooooooo`03ooooo`?oIVIV00?o0000oda<C?m<C4`05_m<
C4`00ol0003oIVIVofIVIP0:ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onI
VIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl01Omo
Ogl00ol0003oIVIVofIVIP06ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH00omV
IVH01Ol0003oOgmoogmoOomoOgoo000000CoVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<
olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`04
o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co
000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<
00Co0000ok>c/onc/k?o00000_nIVIT01_l0003oOgmoogmoOol0003oIVIVo`0000;oC4a<00?o0000
oc<c<olc<c<01olc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c
/`03o`000?o<c<coc<c<00Ooc<c<00Go0000ok>c/ol0003oVIVIo`000002ogmoO`05o`000?mVIVKo
0000oda<C?l000002?lc<c<03Ol0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o
/k>co`000?o<c<`01_ooool1o`00007ooooo0Oooool001Cooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool00oooool2ofIVIP03o`000?m<
C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nI
VIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?mo
OgooOgmo00KoOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<C00Coda<C003o`000?mV
IVKoIVIV00?oIVIV00Go0000ogmoOomoOgooOgmoo`000004oiVIV@03o`000?nc/k?o/k>c00?o/k>c
00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`05o`000?nIVIWoVIVIoiVIVOl0
00000_moOgl01?l0003oIVIVofIVI_l00004oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<
C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>c
o`000008olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Ko0000ogmoOomoOgoo0000ofIVI_l00002
oda<C003o`000?lc<c?o<c<c00Oo<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nI
VIWo00000_nc/k<00ol0003oc<c<olc<c007olc<c003o`000?nc/k?o/k>c00;o00000_moOgl01Ol0
003oIVIVo`000?m<C4co000000So<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nI
VIWo0000ok>c/ol00002olc<c0Kooooo0Ol00001ooooo`7ooooo000Dooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`000006ooooo`?o00000oooool00omVIVKo0000oda<C00G
oda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;
oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`06
ogmoO`03o`000?mVIVKoIVIV00GoIVIV00?o0000oda<C?m<C4`05?m<C4`00ol0003oIVIVofIVIP02
ofIVIP05o`000?moOgooOgmoogmoOol000001?nIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<
c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo
00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;o
C4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<co
c<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<
C4coC4a<o`0000So<c<c00_o0000oda<C?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`00
0002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`05
o`000?mVIVKo0000oda<C?l000002?lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000
oiVIVOl0003o/k>co`0000;oc<c<1?ooool3o`0000;ooooo000Dooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo?oooool1o`00
007ooooo0Oooool001Cooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@
00Kooooo00?o0000ooooooooool0ooooooloooooo`7o00000Oooool1ooooo`005?ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooo
ocoooooo0Ol00001ooooo`7ooooo000Booooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP06ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`03ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00?ooooo0Ol00001ooooo`7ooooo000Toooooooo0000@ol00002ooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-7.04757, -6.93977, 0.0606246, \
0.0606246}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.339744 0.0641026 0.339744 0.0641026 [
[.08333 -0.0125 -6 -9 ]
[.08333 -0.0125 6 0 ]
[.21154 -0.0125 -6 -9 ]
[.21154 -0.0125 6 0 ]
[.33974 -0.0125 -3 -9 ]
[.33974 -0.0125 3 0 ]
[.46795 -0.0125 -3 -9 ]
[.46795 -0.0125 3 0 ]
[.59615 -0.0125 -3 -9 ]
[.59615 -0.0125 3 0 ]
[.72436 -0.0125 -3 -9 ]
[.72436 -0.0125 3 0 ]
[.85256 -0.0125 -3 -9 ]
[.85256 -0.0125 3 0 ]
[.98077 -0.0125 -6 -9 ]
[.98077 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5 -21 ]
[.5 -0.0125 5 -9 ]
[-0.0125 .08333 -12 -4.5 ]
[-0.0125 .08333 0 4.5 ]
[-0.0125 .21154 -12 -4.5 ]
[-0.0125 .21154 0 4.5 ]
[-0.0125 .33974 -6 -4.5 ]
[-0.0125 .33974 0 4.5 ]
[-0.0125 .46795 -6 -4.5 ]
[-0.0125 .46795 0 4.5 ]
[-0.0125 .59615 -6 -4.5 ]
[-0.0125 .59615 0 4.5 ]
[-0.0125 .72436 -6 -4.5 ]
[-0.0125 .72436 0 4.5 ]
[-0.0125 .85256 -6 -4.5 ]
[-0.0125 .85256 0 4.5 ]
[-0.0125 .98077 -12 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -24 -5 ]
[-0.01875 .5 -12 5 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08333 0 m
.08333 .00625 L
s
[(-4)] .08333 -0.0125 0 1 Mshowa
.21154 0 m
.21154 .00625 L
s
[(-2)] .21154 -0.0125 0 1 Mshowa
.33974 0 m
.33974 .00625 L
s
[(0)] .33974 -0.0125 0 1 Mshowa
.46795 0 m
.46795 .00625 L
s
[(2)] .46795 -0.0125 0 1 Mshowa
.59615 0 m
.59615 .00625 L
s
[(4)] .59615 -0.0125 0 1 Mshowa
.72436 0 m
.72436 .00625 L
s
[(6)] .72436 -0.0125 0 1 Mshowa
.85256 0 m
.85256 .00625 L
s
[(8)] .85256 -0.0125 0 1 Mshowa
.98077 0 m
.98077 .00625 L
s
[(10)] .98077 -0.0125 0 1 Mshowa
.125 Mabswid
.11538 0 m
.11538 .00375 L
s
.14744 0 m
.14744 .00375 L
s
.17949 0 m
.17949 .00375 L
s
.24359 0 m
.24359 .00375 L
s
.27564 0 m
.27564 .00375 L
s
.30769 0 m
.30769 .00375 L
s
.37179 0 m
.37179 .00375 L
s
.40385 0 m
.40385 .00375 L
s
.4359 0 m
.4359 .00375 L
s
.5 0 m
.5 .00375 L
s
.53205 0 m
.53205 .00375 L
s
.5641 0 m
.5641 .00375 L
s
.62821 0 m
.62821 .00375 L
s
.66026 0 m
.66026 .00375 L
s
.69231 0 m
.69231 .00375 L
s
.75641 0 m
.75641 .00375 L
s
.78846 0 m
.78846 .00375 L
s
.82051 0 m
.82051 .00375 L
s
.88462 0 m
.88462 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.94872 0 m
.94872 .00375 L
s
.05128 0 m
.05128 .00375 L
s
.01923 0 m
.01923 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66 -25 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .08333 m
.00625 .08333 L
s
[(-4)] -0.0125 .08333 1 0 Mshowa
0 .21154 m
.00625 .21154 L
s
[(-2)] -0.0125 .21154 1 0 Mshowa
0 .33974 m
.00625 .33974 L
s
[(0)] -0.0125 .33974 1 0 Mshowa
0 .46795 m
.00625 .46795 L
s
[(2)] -0.0125 .46795 1 0 Mshowa
0 .59615 m
.00625 .59615 L
s
[(4)] -0.0125 .59615 1 0 Mshowa
0 .72436 m
.00625 .72436 L
s
[(6)] -0.0125 .72436 1 0 Mshowa
0 .85256 m
.00625 .85256 L
s
[(8)] -0.0125 .85256 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(10)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .11538 m
.00375 .11538 L
s
0 .14744 m
.00375 .14744 L
s
0 .17949 m
.00375 .17949 L
s
0 .24359 m
.00375 .24359 L
s
0 .27564 m
.00375 .27564 L
s
0 .30769 m
.00375 .30769 L
s
0 .37179 m
.00375 .37179 L
s
0 .40385 m
.00375 .40385 L
s
0 .4359 m
.00375 .4359 L
s
0 .5 m
.00375 .5 L
s
0 .53205 m
.00375 .53205 L
s
0 .5641 m
.00375 .5641 L
s
0 .62821 m
.00375 .62821 L
s
0 .66026 m
.00375 .66026 L
s
0 .69231 m
.00375 .69231 L
s
0 .75641 m
.00375 .75641 L
s
0 .78846 m
.00375 .78846 L
s
0 .82051 m
.00375 .82051 L
s
0 .88462 m
.00375 .88462 L
s
0 .91667 m
.00375 .91667 L
s
0 .94872 m
.00375 .94872 L
s
0 .05128 m
.00375 .05128 L
s
0 .01923 m
.00375 .01923 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
-0.01875 .5 -84 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
66 10 translate
90 rotate
-66 -10 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.08333 .99375 m
.08333 1 L
s
.21154 .99375 m
.21154 1 L
s
.33974 .99375 m
.33974 1 L
s
.46795 .99375 m
.46795 1 L
s
.59615 .99375 m
.59615 1 L
s
.72436 .99375 m
.72436 1 L
s
.85256 .99375 m
.85256 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.11538 .99625 m
.11538 1 L
s
.14744 .99625 m
.14744 1 L
s
.17949 .99625 m
.17949 1 L
s
.24359 .99625 m
.24359 1 L
s
.27564 .99625 m
.27564 1 L
s
.30769 .99625 m
.30769 1 L
s
.37179 .99625 m
.37179 1 L
s
.40385 .99625 m
.40385 1 L
s
.4359 .99625 m
.4359 1 L
s
.5 .99625 m
.5 1 L
s
.53205 .99625 m
.53205 1 L
s
.5641 .99625 m
.5641 1 L
s
.62821 .99625 m
.62821 1 L
s
.66026 .99625 m
.66026 1 L
s
.69231 .99625 m
.69231 1 L
s
.75641 .99625 m
.75641 1 L
s
.78846 .99625 m
.78846 1 L
s
.82051 .99625 m
.82051 1 L
s
.88462 .99625 m
.88462 1 L
s
.91667 .99625 m
.91667 1 L
s
.94872 .99625 m
.94872 1 L
s
.05128 .99625 m
.05128 1 L
s
.01923 .99625 m
.01923 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .08333 m
1 .08333 L
s
.99375 .21154 m
1 .21154 L
s
.99375 .33974 m
1 .33974 L
s
.99375 .46795 m
1 .46795 L
s
.99375 .59615 m
1 .59615 L
s
.99375 .72436 m
1 .72436 L
s
.99375 .85256 m
1 .85256 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .11538 m
1 .11538 L
s
.99625 .14744 m
1 .14744 L
s
.99625 .17949 m
1 .17949 L
s
.99625 .24359 m
1 .24359 L
s
.99625 .27564 m
1 .27564 L
s
.99625 .30769 m
1 .30769 L
s
.99625 .37179 m
1 .37179 L
s
.99625 .40385 m
1 .40385 L
s
.99625 .4359 m
1 .4359 L
s
.99625 .5 m
1 .5 L
s
.99625 .53205 m
1 .53205 L
s
.99625 .5641 m
1 .5641 L
s
.99625 .62821 m
1 .62821 L
s
.99625 .66026 m
1 .66026 L
s
.99625 .69231 m
1 .69231 L
s
.99625 .75641 m
1 .75641 L
s
.99625 .78846 m
1 .78846 L
s
.99625 .82051 m
1 .82051 L
s
.99625 .88462 m
1 .88462 L
s
.99625 .91667 m
1 .91667 L
s
.99625 .94872 m
1 .94872 L
s
.99625 .05128 m
1 .05128 L
s
.99625 .01923 m
1 .01923 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.4 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.5 g
.01923 .98004 m
.02821 .97106 L
.02894 .97033 L
.03793 .96134 L
.03866 .96061 L
.04764 .95163 L
.04837 .9509 L
.05735 .94192 L
.05808 .94119 L
.06706 .93221 L
.06779 .93148 L
.07678 .92249 L
.07751 .92176 L
.08649 .91278 L
.08722 .91205 L
.0962 .90307 L
.09693 .90234 L
.10591 .89336 L
.10664 .89263 L
.11563 .88364 L
.11636 .88291 L
.12534 .87393 L
.12607 .8732 L
.13505 .86422 L
.13578 .86349 L
.14476 .85451 L
.14549 .85378 L
.15448 .84479 L
.15521 .84406 L
.16419 .83508 L
.16492 .83435 L
.1739 .82537 L
.17463 .82464 L
.18361 .81566 L
.18434 .81493 L
.19333 .80594 L
.19406 .80521 L
.20304 .79623 L
.20377 .7955 L
.21275 .78652 L
.21348 .78579 L
.22246 .77681 L
.22319 .77608 L
.23218 .76709 L
.23291 .76636 L
.24189 .75738 L
.24262 .75665 L
.2516 .74767 L
.25233 .74694 L
.26131 .73796 L
.26204 .73723 L
.27103 .72824 L
.27176 .72751 L
.28074 .71853 L
.28147 .7178 L
.29045 .70882 L
.29118 .70809 L
.30016 .69911 L
.30089 .69838 L
.30988 .68939 L
.31061 .68866 L
.31959 .67968 L
.32032 .67895 L
.3293 .66997 L
.33003 .66924 L
.33904 .66026 L
.33974 .65953 L
.34792 .65054 L
.34946 .64883 L
.35639 .64083 L
.35917 .63753 L
.36448 .63112 L
.36888 .62567 L
.37227 .62141 L
.37859 .61326 L
.37979 .61169 L
.38707 .60198 L
.38831 .60031 L
.39415 .59227 L
.39802 .58684 L
.40103 .58256 L
.40773 .57287 L
.40775 .57284 L
.41431 .56313 L
.41744 .55841 L
.42072 .55342 L
.42701 .54371 L
.42716 .54348 L
.43317 .53399 L
.43687 .52808 L
.43922 .52428 L
.44517 .51457 L
.44658 .51224 L
.45102 .50486 L
.45629 .49597 L
.45678 .49514 L
.46245 .48543 L
.46601 .47927 L
.46804 .47572 L
.47355 .46601 L
.47572 .46215 L
.47898 .45629 L
.48436 .44658 L
.48543 .44463 L
.48966 .43687 L
.4949 .42716 L
.49514 .42671 L
.50008 .41744 L
.50486 .40839 L
.5052 .40773 L
.51027 .39802 L
.51457 .3897 L
.51528 .38831 L
.52024 .37859 L
.52428 .37063 L
.52516 .36888 L
.53003 .35917 L
.53399 .3512 L
.53485 .34946 L
.53963 .33974 L
.54371 .3314 L
.54437 .33003 L
.54906 .32032 L
.55342 .31125 L
.55372 .31061 L
.55834 .30089 L
.56293 .29118 L
.56313 .29075 L
.56747 .28147 L
.57199 .27176 L
.57284 .26991 L
.57646 .26204 L
.58091 .25233 L
.58256 .24873 L
.58532 .24262 L
.58971 .23291 L
.59227 .22722 L
.59406 .22319 L
.59839 .21348 L
.60198 .20538 L
.60268 .20377 L
.60695 .19406 L
.6112 .18434 L
.61169 .18321 L
.6154 .17463 L
.61961 .16492 L
.62141 .16073 L
.62376 .15521 L
.62791 .14549 L
.63112 .13794 L
.63202 .13578 L
.63611 .12607 L
.64019 .11636 L
.64083 .11483 L
.64422 .10664 L
.64827 .09693 L
.65054 .09142 L
.65226 .08722 L
.65625 .07751 L
.66022 .06779 L
.66026 .06771 L
.66414 .05808 L
.66809 .04837 L
.66997 .0437 L
.67197 .03866 L
.67587 .02894 L
.67968 .01939 L
.67974 .01923 L
.01923 .01923 L
F
0 g
.01923 .98004 m
.02821 .97106 L
.02894 .97033 L
.03793 .96134 L
.03866 .96061 L
.04764 .95163 L
.04837 .9509 L
.05735 .94192 L
.05808 .94119 L
.06706 .93221 L
.06779 .93148 L
.07678 .92249 L
.07751 .92176 L
.08649 .91278 L
.08722 .91205 L
.0962 .90307 L
.09693 .90234 L
.10591 .89336 L
.10664 .89263 L
.11563 .88364 L
.11636 .88291 L
.12534 .87393 L
.12607 .8732 L
.13505 .86422 L
.13578 .86349 L
.14476 .85451 L
.14549 .85378 L
.15448 .84479 L
.15521 .84406 L
.16419 .83508 L
.16492 .83435 L
.1739 .82537 L
.17463 .82464 L
.18361 .81566 L
.18434 .81493 L
.19333 .80594 L
.19406 .80521 L
.20304 .79623 L
.20377 .7955 L
.21275 .78652 L
.21348 .78579 L
.22246 .77681 L
.22319 .77608 L
.23218 .76709 L
.23291 .76636 L
.24189 .75738 L
.24262 .75665 L
.2516 .74767 L
.25233 .74694 L
.26131 .73796 L
Mistroke
.26204 .73723 L
.27103 .72824 L
.27176 .72751 L
.28074 .71853 L
.28147 .7178 L
.29045 .70882 L
.29118 .70809 L
.30016 .69911 L
.30089 .69838 L
.30988 .68939 L
.31061 .68866 L
.31959 .67968 L
.32032 .67895 L
.3293 .66997 L
.33003 .66924 L
.33904 .66026 L
.33974 .65953 L
.34792 .65054 L
.34946 .64883 L
.35639 .64083 L
.35917 .63753 L
.36448 .63112 L
.36888 .62567 L
.37227 .62141 L
.37859 .61326 L
.37979 .61169 L
.38707 .60198 L
.38831 .60031 L
.39415 .59227 L
.39802 .58684 L
.40103 .58256 L
.40773 .57287 L
.40775 .57284 L
.41431 .56313 L
.41744 .55841 L
.42072 .55342 L
.42701 .54371 L
.42716 .54348 L
.43317 .53399 L
.43687 .52808 L
.43922 .52428 L
.44517 .51457 L
.44658 .51224 L
.45102 .50486 L
.45629 .49597 L
.45678 .49514 L
.46245 .48543 L
.46601 .47927 L
.46804 .47572 L
.47355 .46601 L
Mistroke
.47572 .46215 L
.47898 .45629 L
.48436 .44658 L
.48543 .44463 L
.48966 .43687 L
.4949 .42716 L
.49514 .42671 L
.50008 .41744 L
.50486 .40839 L
.5052 .40773 L
.51027 .39802 L
.51457 .3897 L
.51528 .38831 L
.52024 .37859 L
.52428 .37063 L
.52516 .36888 L
.53003 .35917 L
.53399 .3512 L
.53485 .34946 L
.53963 .33974 L
.54371 .3314 L
.54437 .33003 L
.54906 .32032 L
.55342 .31125 L
.55372 .31061 L
.55834 .30089 L
.56293 .29118 L
.56313 .29075 L
.56747 .28147 L
.57199 .27176 L
.57284 .26991 L
.57646 .26204 L
.58091 .25233 L
.58256 .24873 L
.58532 .24262 L
.58971 .23291 L
.59227 .22722 L
.59406 .22319 L
.59839 .21348 L
.60198 .20538 L
.60268 .20377 L
.60695 .19406 L
.6112 .18434 L
.61169 .18321 L
.6154 .17463 L
.61961 .16492 L
.62141 .16073 L
.62376 .15521 L
.62791 .14549 L
.63112 .13794 L
Mistroke
.63202 .13578 L
.63611 .12607 L
.64019 .11636 L
.64083 .11483 L
.64422 .10664 L
.64827 .09693 L
.65054 .09142 L
.65226 .08722 L
.65625 .07751 L
.66022 .06779 L
.66026 .06771 L
.66414 .05808 L
.66809 .04837 L
.66997 .0437 L
.67197 .03866 L
.67587 .02894 L
.67968 .01939 L
.67974 .01923 L
Mfstroke
.6 g
.01923 .94463 m
.02194 .94192 L
.02894 .93491 L
.03165 .93221 L
.03866 .9252 L
.04136 .92249 L
.04837 .91549 L
.05108 .91278 L
.05808 .90578 L
.06079 .90307 L
.06779 .89606 L
.0705 .89336 L
.07751 .88635 L
.08021 .88364 L
.08722 .87664 L
.08993 .87393 L
.09693 .86693 L
.09964 .86422 L
.10664 .85721 L
.10935 .85451 L
.11636 .8475 L
.11906 .84479 L
.12607 .83779 L
.12878 .83508 L
.13578 .82808 L
.13849 .82537 L
.14549 .81836 L
.1482 .81566 L
.15521 .80865 L
.15791 .80594 L
.16492 .79894 L
.16763 .79623 L
.17463 .78923 L
.17734 .78652 L
.18434 .77951 L
.18705 .77681 L
.19406 .7698 L
.19676 .76709 L
.20377 .76009 L
.20648 .75738 L
.21348 .75038 L
.21619 .74767 L
.22319 .74066 L
.2259 .73796 L
.23291 .73095 L
.23561 .72824 L
.24262 .72124 L
.24533 .71853 L
.25233 .71153 L
.25504 .70882 L
.26204 .70181 L
.26475 .69911 L
.27176 .6921 L
.27446 .68939 L
.28147 .68239 L
.28418 .67968 L
.29118 .67268 L
.29389 .66997 L
.30089 .66296 L
.3036 .66026 L
.31061 .65325 L
.31331 .65054 L
.32032 .64354 L
.32303 .64083 L
.33003 .63383 L
.33275 .63112 L
.33974 .62411 L
.3425 .62141 L
.34946 .61467 L
.35238 .61169 L
.35917 .60445 L
.36142 .60198 L
.36888 .5935 L
.36994 .59227 L
.37805 .58256 L
.37859 .58189 L
.38583 .57284 L
.38831 .56965 L
.39331 .56313 L
.39802 .55682 L
.40053 .55342 L
.40753 .54371 L
.40773 .54343 L
.41436 .53399 L
.41744 .5295 L
.421 .52428 L
.42716 .51504 L
.42747 .51457 L
.43383 .50486 L
.43687 .5001 L
.44003 .49514 L
.44611 .48543 L
.44658 .48467 L
.4521 .47572 L
.45629 .46878 L
.45797 .46601 L
.46375 .45629 L
.46601 .45244 L
.46944 .44658 L
.47503 .43687 L
.47572 .43566 L
.48056 .42716 L
.48543 .41845 L
.48599 .41744 L
.49138 .40773 L
.49514 .40083 L
.49668 .39802 L
.50193 .38831 L
.50486 .3828 L
.5071 .37859 L
.51223 .36888 L
.51457 .36437 L
.51729 .35917 L
.5223 .34946 L
.52428 .34556 L
.52726 .33974 L
.53217 .33003 L
.53399 .32637 L
.53703 .32032 L
.54185 .31061 L
.54371 .3068 L
.54662 .30089 L
.55135 .29118 L
.55342 .28687 L
.55603 .28147 L
.56069 .27176 L
.56313 .26658 L
.56529 .26204 L
.56988 .25233 L
.57284 .24594 L
.5744 .24262 L
.57892 .23291 L
.58256 .22496 L
.58337 .22319 L
.58783 .21348 L
.59221 .20377 L
.59227 .20363 L
.5966 .19406 L
.60094 .18434 L
.60198 .18197 L
.60525 .17463 L
.60955 .16492 L
.61169 .15998 L
.61379 .15521 L
.61804 .14549 L
.62141 .13766 L
.62222 .13578 L
.62643 .12607 L
.63056 .11636 L
.63112 .11503 L
.6347 .10664 L
.63882 .09693 L
.64083 .09208 L
.64288 .08722 L
.64696 .07751 L
.65054 .06882 L
.65097 .06779 L
.65501 .05808 L
.659 .04837 L
.66026 .04525 L
.66297 .03866 L
.66694 .02894 L
.66997 .02138 L
.67084 .01923 L
.01923 .01923 L
F
0 g
.01923 .94463 m
.02194 .94192 L
.02894 .93491 L
.03165 .93221 L
.03866 .9252 L
.04136 .92249 L
.04837 .91549 L
.05108 .91278 L
.05808 .90578 L
.06079 .90307 L
.06779 .89606 L
.0705 .89336 L
.07751 .88635 L
.08021 .88364 L
.08722 .87664 L
.08993 .87393 L
.09693 .86693 L
.09964 .86422 L
.10664 .85721 L
.10935 .85451 L
.11636 .8475 L
.11906 .84479 L
.12607 .83779 L
.12878 .83508 L
.13578 .82808 L
.13849 .82537 L
.14549 .81836 L
.1482 .81566 L
.15521 .80865 L
.15791 .80594 L
.16492 .79894 L
.16763 .79623 L
.17463 .78923 L
.17734 .78652 L
.18434 .77951 L
.18705 .77681 L
.19406 .7698 L
.19676 .76709 L
.20377 .76009 L
.20648 .75738 L
.21348 .75038 L
.21619 .74767 L
.22319 .74066 L
.2259 .73796 L
.23291 .73095 L
.23561 .72824 L
.24262 .72124 L
.24533 .71853 L
.25233 .71153 L
.25504 .70882 L
Mistroke
.26204 .70181 L
.26475 .69911 L
.27176 .6921 L
.27446 .68939 L
.28147 .68239 L
.28418 .67968 L
.29118 .67268 L
.29389 .66997 L
.30089 .66296 L
.3036 .66026 L
.31061 .65325 L
.31331 .65054 L
.32032 .64354 L
.32303 .64083 L
.33003 .63383 L
.33275 .63112 L
.33974 .62411 L
.3425 .62141 L
.34946 .61467 L
.35238 .61169 L
.35917 .60445 L
.36142 .60198 L
.36888 .5935 L
.36994 .59227 L
.37805 .58256 L
.37859 .58189 L
.38583 .57284 L
.38831 .56965 L
.39331 .56313 L
.39802 .55682 L
.40053 .55342 L
.40753 .54371 L
.40773 .54343 L
.41436 .53399 L
.41744 .5295 L
.421 .52428 L
.42716 .51504 L
.42747 .51457 L
.43383 .50486 L
.43687 .5001 L
.44003 .49514 L
.44611 .48543 L
.44658 .48467 L
.4521 .47572 L
.45629 .46878 L
.45797 .46601 L
.46375 .45629 L
.46601 .45244 L
.46944 .44658 L
.47503 .43687 L
Mistroke
.47572 .43566 L
.48056 .42716 L
.48543 .41845 L
.48599 .41744 L
.49138 .40773 L
.49514 .40083 L
.49668 .39802 L
.50193 .38831 L
.50486 .3828 L
.5071 .37859 L
.51223 .36888 L
.51457 .36437 L
.51729 .35917 L
.5223 .34946 L
.52428 .34556 L
.52726 .33974 L
.53217 .33003 L
.53399 .32637 L
.53703 .32032 L
.54185 .31061 L
.54371 .3068 L
.54662 .30089 L
.55135 .29118 L
.55342 .28687 L
.55603 .28147 L
.56069 .27176 L
.56313 .26658 L
.56529 .26204 L
.56988 .25233 L
.57284 .24594 L
.5744 .24262 L
.57892 .23291 L
.58256 .22496 L
.58337 .22319 L
.58783 .21348 L
.59221 .20377 L
.59227 .20363 L
.5966 .19406 L
.60094 .18434 L
.60198 .18197 L
.60525 .17463 L
.60955 .16492 L
.61169 .15998 L
.61379 .15521 L
.61804 .14549 L
.62141 .13766 L
.62222 .13578 L
.62643 .12607 L
.63056 .11636 L
.63112 .11503 L
Mistroke
.6347 .10664 L
.63882 .09693 L
.64083 .09208 L
.64288 .08722 L
.64696 .07751 L
.65054 .06882 L
.65097 .06779 L
.65501 .05808 L
.659 .04837 L
.66026 .04525 L
.66297 .03866 L
.66694 .02894 L
.66997 .02138 L
.67084 .01923 L
Mfstroke
.7 g
.01923 .90095 m
.02676 .89336 L
.02894 .89124 L
.03654 .88364 L
.03866 .88152 L
.04625 .87393 L
.04837 .87181 L
.05596 .86422 L
.05808 .8621 L
.06567 .85451 L
.06779 .85239 L
.07539 .84479 L
.07751 .84267 L
.0851 .83508 L
.08722 .83296 L
.09481 .82537 L
.09693 .82325 L
.10452 .81566 L
.10664 .81354 L
.11424 .80594 L
.11636 .80382 L
.12395 .79623 L
.12607 .79411 L
.13366 .78652 L
.13578 .7844 L
.14337 .77681 L
.14549 .77469 L
.15309 .76709 L
.15521 .76497 L
.1628 .75738 L
.16492 .75526 L
.17251 .74767 L
.17463 .74555 L
.18222 .73796 L
.18434 .73584 L
.19194 .72824 L
.19406 .72612 L
.20165 .71853 L
.20377 .71641 L
.21136 .70882 L
.21348 .7067 L
.22107 .69911 L
.22319 .69699 L
.23079 .68939 L
.23291 .68727 L
.2405 .67968 L
.24262 .67756 L
.25021 .66997 L
.25233 .66785 L
.25992 .66026 L
.26204 .65814 L
.26964 .65054 L
.27176 .64842 L
.27935 .64083 L
.28147 .63871 L
.28906 .63112 L
.29118 .629 L
.29877 .62141 L
.30089 .61929 L
.30849 .61169 L
.31061 .60957 L
.3182 .60198 L
.32032 .59986 L
.32791 .59227 L
.33003 .59015 L
.33752 .58256 L
.33974 .58044 L
.34946 .57339 L
.35018 .57284 L
.35917 .56509 L
.36138 .56313 L
.36888 .55572 L
.3712 .55342 L
.37859 .54543 L
.38019 .54371 L
.38831 .53432 L
.38859 .53399 L
.39667 .52428 L
.39802 .52249 L
.40434 .51457 L
.40773 .50998 L
.41165 .50486 L
.41744 .49682 L
.41867 .49514 L
.4256 .48543 L
.42716 .48308 L
.4323 .47572 L
.43687 .46877 L
.43874 .46601 L
.44513 .45629 L
.44658 .45393 L
.45136 .44658 L
.45629 .43857 L
.45737 .43687 L
.46342 .42716 L
.46601 .42273 L
.46925 .41744 L
.47498 .40773 L
.47572 .4064 L
.4807 .39802 L
.48543 .38962 L
.4862 .38831 L
.49179 .37859 L
.49514 .37241 L
.49714 .36888 L
.50255 .35917 L
.50486 .35476 L
.50779 .34946 L
.51302 .33974 L
.51457 .33669 L
.51817 .33003 L
.52325 .32032 L
.52428 .3182 L
.5283 .31061 L
.53325 .30089 L
.53399 .29933 L
.53822 .29118 L
.54305 .28147 L
.54371 .28006 L
.54793 .27176 L
.55268 .26204 L
.55342 .26042 L
.55746 .25233 L
.56214 .24262 L
.56313 .2404 L
.56681 .23291 L
.57144 .22319 L
.57284 .22002 L
.576 .21348 L
.58058 .20377 L
.58256 .19928 L
.58504 .19406 L
.58958 .18434 L
.59227 .17819 L
.59393 .17463 L
.59844 .16492 L
.60198 .15675 L
.60269 .15521 L
.60715 .14549 L
.61137 .13578 L
.61169 .13498 L
.61573 .12607 L
.62 .11636 L
.62141 .11288 L
.62419 .10664 L
.62847 .09693 L
.63112 .09044 L
.63254 .08722 L
.6368 .07751 L
.64079 .06779 L
.64083 .06768 L
.64501 .05808 L
.6491 .04837 L
.65054 .04461 L
.6531 .03866 L
.65723 .02894 L
.66026 .02121 L
.6611 .01923 L
.01923 .01923 L
F
0 g
.01923 .90095 m
.02676 .89336 L
.02894 .89124 L
.03654 .88364 L
.03866 .88152 L
.04625 .87393 L
.04837 .87181 L
.05596 .86422 L
.05808 .8621 L
.06567 .85451 L
.06779 .85239 L
.07539 .84479 L
.07751 .84267 L
.0851 .83508 L
.08722 .83296 L
.09481 .82537 L
.09693 .82325 L
.10452 .81566 L
.10664 .81354 L
.11424 .80594 L
.11636 .80382 L
.12395 .79623 L
.12607 .79411 L
.13366 .78652 L
.13578 .7844 L
.14337 .77681 L
.14549 .77469 L
.15309 .76709 L
.15521 .76497 L
.1628 .75738 L
.16492 .75526 L
.17251 .74767 L
.17463 .74555 L
.18222 .73796 L
.18434 .73584 L
.19194 .72824 L
.19406 .72612 L
.20165 .71853 L
.20377 .71641 L
.21136 .70882 L
.21348 .7067 L
.22107 .69911 L
.22319 .69699 L
.23079 .68939 L
.23291 .68727 L
.2405 .67968 L
.24262 .67756 L
.25021 .66997 L
.25233 .66785 L
.25992 .66026 L
Mistroke
.26204 .65814 L
.26964 .65054 L
.27176 .64842 L
.27935 .64083 L
.28147 .63871 L
.28906 .63112 L
.29118 .629 L
.29877 .62141 L
.30089 .61929 L
.30849 .61169 L
.31061 .60957 L
.3182 .60198 L
.32032 .59986 L
.32791 .59227 L
.33003 .59015 L
.33752 .58256 L
.33974 .58044 L
.34946 .57339 L
.35018 .57284 L
.35917 .56509 L
.36138 .56313 L
.36888 .55572 L
.3712 .55342 L
.37859 .54543 L
.38019 .54371 L
.38831 .53432 L
.38859 .53399 L
.39667 .52428 L
.39802 .52249 L
.40434 .51457 L
.40773 .50998 L
.41165 .50486 L
.41744 .49682 L
.41867 .49514 L
.4256 .48543 L
.42716 .48308 L
.4323 .47572 L
.43687 .46877 L
.43874 .46601 L
.44513 .45629 L
.44658 .45393 L
.45136 .44658 L
.45629 .43857 L
.45737 .43687 L
.46342 .42716 L
.46601 .42273 L
.46925 .41744 L
.47498 .40773 L
.47572 .4064 L
.4807 .39802 L
Mistroke
.48543 .38962 L
.4862 .38831 L
.49179 .37859 L
.49514 .37241 L
.49714 .36888 L
.50255 .35917 L
.50486 .35476 L
.50779 .34946 L
.51302 .33974 L
.51457 .33669 L
.51817 .33003 L
.52325 .32032 L
.52428 .3182 L
.5283 .31061 L
.53325 .30089 L
.53399 .29933 L
.53822 .29118 L
.54305 .28147 L
.54371 .28006 L
.54793 .27176 L
.55268 .26204 L
.55342 .26042 L
.55746 .25233 L
.56214 .24262 L
.56313 .2404 L
.56681 .23291 L
.57144 .22319 L
.57284 .22002 L
.576 .21348 L
.58058 .20377 L
.58256 .19928 L
.58504 .19406 L
.58958 .18434 L
.59227 .17819 L
.59393 .17463 L
.59844 .16492 L
.60198 .15675 L
.60269 .15521 L
.60715 .14549 L
.61137 .13578 L
.61169 .13498 L
.61573 .12607 L
.62 .11636 L
.62141 .11288 L
.62419 .10664 L
.62847 .09693 L
.63112 .09044 L
.63254 .08722 L
.6368 .07751 L
.64079 .06779 L
Mistroke
.64083 .06768 L
.64501 .05808 L
.6491 .04837 L
.65054 .04461 L
.6531 .03866 L
.65723 .02894 L
.66026 .02121 L
.6611 .01923 L
Mfstroke
.6 g
.01923 .82234 m
.02608 .81566 L
.02894 .81263 L
.03563 .80594 L
.03866 .80292 L
.04534 .79623 L
.04837 .7932 L
.05505 .78652 L
.05808 .78349 L
.06476 .77681 L
.06779 .77378 L
.07448 .76709 L
.07751 .76407 L
.08419 .75738 L
.08722 .75435 L
.0939 .74767 L
.09693 .74464 L
.10361 .73796 L
.10664 .73493 L
.11333 .72824 L
.11636 .72522 L
.12304 .71853 L
.12607 .7155 L
.13275 .70882 L
.13578 .70579 L
.14246 .69911 L
.14549 .69608 L
.15218 .68939 L
.15521 .68637 L
.16189 .67968 L
.16492 .67665 L
.1716 .66997 L
.17463 .66694 L
.18131 .66026 L
.18434 .65723 L
.19103 .65054 L
.19406 .64752 L
.20074 .64083 L
.20377 .6378 L
.21045 .63112 L
.21348 .62809 L
.22017 .62141 L
.22319 .61838 L
.22988 .61169 L
.23291 .60867 L
.23959 .60198 L
.24262 .59895 L
.2493 .59227 L
.25233 .58924 L
.25902 .58256 L
.26204 .57953 L
.26873 .57284 L
.27176 .56982 L
.27844 .56313 L
.28147 .5601 L
.28815 .55342 L
.29118 .55039 L
.29787 .54371 L
.30089 .54068 L
.30758 .53399 L
.31061 .53097 L
.31729 .52428 L
.32032 .52125 L
.327 .51457 L
.33003 .51154 L
.33697 .50486 L
.33974 .50183 L
.34482 .49514 L
.34946 .48869 L
.35188 .48543 L
.35902 .47572 L
.35917 .47552 L
.36605 .46601 L
.36888 .46206 L
.37298 .45629 L
.37859 .44833 L
.37981 .44658 L
.38651 .43687 L
.38831 .43424 L
.39308 .42716 L
.39802 .41978 L
.39955 .41744 L
.40592 .40773 L
.40773 .40494 L
.41214 .39802 L
.41744 .3897 L
.41831 .38831 L
.42435 .37859 L
.42716 .37406 L
.43029 .36888 L
.43619 .35917 L
.43687 .35804 L
.44193 .34946 L
.44658 .34161 L
.44765 .33974 L
.45327 .33003 L
.45629 .32479 L
.4588 .32032 L
.46431 .31061 L
.46601 .3076 L
.46968 .30089 L
.47508 .29118 L
.47572 .29002 L
.48032 .28147 L
.48543 .27207 L
.48559 .27176 L
.49072 .26204 L
.49514 .25374 L
.49586 .25233 L
.5009 .24262 L
.50486 .23505 L
.50593 .23291 L
.51088 .22319 L
.51457 .216 L
.5158 .21348 L
.52067 .20377 L
.52428 .1966 L
.5255 .19406 L
.53028 .18434 L
.53399 .17685 L
.53503 .17463 L
.53972 .16492 L
.54371 .15676 L
.54442 .15521 L
.54901 .14549 L
.55342 .13633 L
.55366 .13578 L
.55816 .12607 L
.56276 .11636 L
.56313 .11556 L
.56717 .10664 L
.57169 .09693 L
.57284 .09445 L
.57605 .08722 L
.5805 .07751 L
.58256 .07302 L
.58482 .06779 L
.58919 .05808 L
.59227 .05127 L
.59349 .04837 L
.59776 .03866 L
.60198 .02921 L
.60209 .02894 L
.60623 .01923 L
.01923 .01923 L
F
0 g
.01923 .82234 m
.02608 .81566 L
.02894 .81263 L
.03563 .80594 L
.03866 .80292 L
.04534 .79623 L
.04837 .7932 L
.05505 .78652 L
.05808 .78349 L
.06476 .77681 L
.06779 .77378 L
.07448 .76709 L
.07751 .76407 L
.08419 .75738 L
.08722 .75435 L
.0939 .74767 L
.09693 .74464 L
.10361 .73796 L
.10664 .73493 L
.11333 .72824 L
.11636 .72522 L
.12304 .71853 L
.12607 .7155 L
.13275 .70882 L
.13578 .70579 L
.14246 .69911 L
.14549 .69608 L
.15218 .68939 L
.15521 .68637 L
.16189 .67968 L
.16492 .67665 L
.1716 .66997 L
.17463 .66694 L
.18131 .66026 L
.18434 .65723 L
.19103 .65054 L
.19406 .64752 L
.20074 .64083 L
.20377 .6378 L
.21045 .63112 L
.21348 .62809 L
.22017 .62141 L
.22319 .61838 L
.22988 .61169 L
.23291 .60867 L
.23959 .60198 L
.24262 .59895 L
.2493 .59227 L
.25233 .58924 L
.25902 .58256 L
Mistroke
.26204 .57953 L
.26873 .57284 L
.27176 .56982 L
.27844 .56313 L
.28147 .5601 L
.28815 .55342 L
.29118 .55039 L
.29787 .54371 L
.30089 .54068 L
.30758 .53399 L
.31061 .53097 L
.31729 .52428 L
.32032 .52125 L
.327 .51457 L
.33003 .51154 L
.33697 .50486 L
.33974 .50183 L
.34482 .49514 L
.34946 .48869 L
.35188 .48543 L
.35902 .47572 L
.35917 .47552 L
.36605 .46601 L
.36888 .46206 L
.37298 .45629 L
.37859 .44833 L
.37981 .44658 L
.38651 .43687 L
.38831 .43424 L
.39308 .42716 L
.39802 .41978 L
.39955 .41744 L
.40592 .40773 L
.40773 .40494 L
.41214 .39802 L
.41744 .3897 L
.41831 .38831 L
.42435 .37859 L
.42716 .37406 L
.43029 .36888 L
.43619 .35917 L
.43687 .35804 L
.44193 .34946 L
.44658 .34161 L
.44765 .33974 L
.45327 .33003 L
.45629 .32479 L
.4588 .32032 L
.46431 .31061 L
.46601 .3076 L
Mistroke
.46968 .30089 L
.47508 .29118 L
.47572 .29002 L
.48032 .28147 L
.48543 .27207 L
.48559 .27176 L
.49072 .26204 L
.49514 .25374 L
.49586 .25233 L
.5009 .24262 L
.50486 .23505 L
.50593 .23291 L
.51088 .22319 L
.51457 .216 L
.5158 .21348 L
.52067 .20377 L
.52428 .1966 L
.5255 .19406 L
.53028 .18434 L
.53399 .17685 L
.53503 .17463 L
.53972 .16492 L
.54371 .15676 L
.54442 .15521 L
.54901 .14549 L
.55342 .13633 L
.55366 .13578 L
.55816 .12607 L
.56276 .11636 L
.56313 .11556 L
.56717 .10664 L
.57169 .09693 L
.57284 .09445 L
.57605 .08722 L
.5805 .07751 L
.58256 .07302 L
.58482 .06779 L
.58919 .05808 L
.59227 .05127 L
.59349 .04837 L
.59776 .03866 L
.60198 .02921 L
.60209 .02894 L
.60623 .01923 L
Mfstroke
.5 g
.01923 .77865 m
.02109 .77681 L
.02894 .76894 L
.03079 .76709 L
.03866 .75923 L
.0405 .75738 L
.04837 .74952 L
.05022 .74767 L
.05808 .7398 L
.05993 .73796 L
.06779 .73009 L
.06964 .72824 L
.07751 .72038 L
.07935 .71853 L
.08722 .71067 L
.08907 .70882 L
.09693 .70095 L
.09878 .69911 L
.10664 .69124 L
.10849 .68939 L
.11636 .68153 L
.1182 .67968 L
.12607 .67182 L
.12792 .66997 L
.13578 .6621 L
.13763 .66026 L
.14549 .65239 L
.14734 .65054 L
.15521 .64268 L
.15705 .64083 L
.16492 .63297 L
.16677 .63112 L
.17463 .62325 L
.17648 .62141 L
.18434 .61354 L
.18619 .61169 L
.19406 .60383 L
.1959 .60198 L
.20377 .59412 L
.20562 .59227 L
.21348 .5844 L
.21533 .58256 L
.22319 .57469 L
.22504 .57284 L
.23291 .56498 L
.23475 .56313 L
.24262 .55527 L
.24447 .55342 L
.25233 .54555 L
.25418 .54371 L
.26204 .53584 L
.26389 .53399 L
.27176 .52613 L
.2736 .52428 L
.28147 .51642 L
.28332 .51457 L
.29118 .5067 L
.29303 .50486 L
.30089 .49699 L
.30274 .49514 L
.31061 .48728 L
.31245 .48543 L
.32032 .47757 L
.32217 .47572 L
.33003 .46785 L
.33193 .46601 L
.33974 .45814 L
.34146 .45629 L
.34946 .44744 L
.35022 .44658 L
.35857 .43687 L
.35917 .43615 L
.36658 .42716 L
.36888 .42429 L
.37429 .41744 L
.37859 .41187 L
.38175 .40773 L
.38831 .39892 L
.38897 .39802 L
.39599 .38831 L
.39802 .38545 L
.40283 .37859 L
.40773 .37148 L
.4095 .36888 L
.41602 .35917 L
.41744 .35702 L
.4224 .34946 L
.42716 .34209 L
.42866 .33974 L
.43479 .33003 L
.43687 .3267 L
.44081 .32032 L
.44658 .31086 L
.44674 .31061 L
.45256 .30089 L
.45629 .29458 L
.45829 .29118 L
.46394 .28147 L
.46601 .27788 L
.46951 .27176 L
.475 .26204 L
.47572 .26077 L
.48042 .25233 L
.48543 .24324 L
.48577 .24262 L
.49106 .23291 L
.49514 .22532 L
.49628 .22319 L
.50144 .21348 L
.50486 .20701 L
.50655 .20377 L
.5116 .19406 L
.51457 .18832 L
.5166 .18434 L
.52156 .17463 L
.52428 .16925 L
.52645 .16492 L
.53131 .15521 L
.53399 .14981 L
.53612 .14549 L
.54089 .13578 L
.54371 .13002 L
.54561 .12607 L
.55031 .11636 L
.55342 .10987 L
.55495 .10664 L
.55956 .09693 L
.56313 .08937 L
.56413 .08722 L
.56867 .07751 L
.57284 .06852 L
.57318 .06779 L
.57764 .05808 L
.58209 .04837 L
.58256 .04734 L
.58648 .03866 L
.59087 .02894 L
.59227 .02584 L
.59521 .01923 L
.01923 .01923 L
F
0 g
.01923 .77865 m
.02109 .77681 L
.02894 .76894 L
.03079 .76709 L
.03866 .75923 L
.0405 .75738 L
.04837 .74952 L
.05022 .74767 L
.05808 .7398 L
.05993 .73796 L
.06779 .73009 L
.06964 .72824 L
.07751 .72038 L
.07935 .71853 L
.08722 .71067 L
.08907 .70882 L
.09693 .70095 L
.09878 .69911 L
.10664 .69124 L
.10849 .68939 L
.11636 .68153 L
.1182 .67968 L
.12607 .67182 L
.12792 .66997 L
.13578 .6621 L
.13763 .66026 L
.14549 .65239 L
.14734 .65054 L
.15521 .64268 L
.15705 .64083 L
.16492 .63297 L
.16677 .63112 L
.17463 .62325 L
.17648 .62141 L
.18434 .61354 L
.18619 .61169 L
.19406 .60383 L
.1959 .60198 L
.20377 .59412 L
.20562 .59227 L
.21348 .5844 L
.21533 .58256 L
.22319 .57469 L
.22504 .57284 L
.23291 .56498 L
.23475 .56313 L
.24262 .55527 L
.24447 .55342 L
.25233 .54555 L
.25418 .54371 L
Mistroke
.26204 .53584 L
.26389 .53399 L
.27176 .52613 L
.2736 .52428 L
.28147 .51642 L
.28332 .51457 L
.29118 .5067 L
.29303 .50486 L
.30089 .49699 L
.30274 .49514 L
.31061 .48728 L
.31245 .48543 L
.32032 .47757 L
.32217 .47572 L
.33003 .46785 L
.33193 .46601 L
.33974 .45814 L
.34146 .45629 L
.34946 .44744 L
.35022 .44658 L
.35857 .43687 L
.35917 .43615 L
.36658 .42716 L
.36888 .42429 L
.37429 .41744 L
.37859 .41187 L
.38175 .40773 L
.38831 .39892 L
.38897 .39802 L
.39599 .38831 L
.39802 .38545 L
.40283 .37859 L
.40773 .37148 L
.4095 .36888 L
.41602 .35917 L
.41744 .35702 L
.4224 .34946 L
.42716 .34209 L
.42866 .33974 L
.43479 .33003 L
.43687 .3267 L
.44081 .32032 L
.44658 .31086 L
.44674 .31061 L
.45256 .30089 L
.45629 .29458 L
.45829 .29118 L
.46394 .28147 L
.46601 .27788 L
.46951 .27176 L
Mistroke
.475 .26204 L
.47572 .26077 L
.48042 .25233 L
.48543 .24324 L
.48577 .24262 L
.49106 .23291 L
.49514 .22532 L
.49628 .22319 L
.50144 .21348 L
.50486 .20701 L
.50655 .20377 L
.5116 .19406 L
.51457 .18832 L
.5166 .18434 L
.52156 .17463 L
.52428 .16925 L
.52645 .16492 L
.53131 .15521 L
.53399 .14981 L
.53612 .14549 L
.54089 .13578 L
.54371 .13002 L
.54561 .12607 L
.55031 .11636 L
.55342 .10987 L
.55495 .10664 L
.55956 .09693 L
.56313 .08937 L
.56413 .08722 L
.56867 .07751 L
.57284 .06852 L
.57318 .06779 L
.57764 .05808 L
.58209 .04837 L
.58256 .04734 L
.58648 .03866 L
.59087 .02894 L
.59227 .02584 L
.59521 .01923 L
Mfstroke
.4 g
.01923 .74324 m
.02451 .73796 L
.02894 .73353 L
.03423 .72824 L
.03866 .72382 L
.04394 .71853 L
.04837 .71411 L
.05366 .70882 L
.05808 .70439 L
.06337 .69911 L
.06779 .69468 L
.07308 .68939 L
.07751 .68497 L
.08279 .67968 L
.08722 .67526 L
.09251 .66997 L
.09693 .66554 L
.10222 .66026 L
.10664 .65583 L
.11193 .65054 L
.11636 .64612 L
.12164 .64083 L
.12607 .63641 L
.13136 .63112 L
.13578 .62669 L
.14107 .62141 L
.14549 .61698 L
.15078 .61169 L
.15521 .60727 L
.16049 .60198 L
.16492 .59756 L
.17021 .59227 L
.17463 .58784 L
.17992 .58256 L
.18434 .57813 L
.18963 .57284 L
.19406 .56842 L
.19934 .56313 L
.20377 .55871 L
.20906 .55342 L
.21348 .54899 L
.21877 .54371 L
.22319 .53928 L
.22848 .53399 L
.23291 .52957 L
.23819 .52428 L
.24262 .51986 L
.24791 .51457 L
.25233 .51014 L
.25762 .50486 L
.26204 .50043 L
.26733 .49514 L
.27176 .49072 L
.27704 .48543 L
.28147 .48101 L
.28676 .47572 L
.29118 .47129 L
.29647 .46601 L
.30089 .46158 L
.30618 .45629 L
.31061 .45187 L
.31589 .44658 L
.32032 .44216 L
.32561 .43687 L
.33003 .43244 L
.33533 .42716 L
.33974 .42273 L
.34515 .41744 L
.34946 .41329 L
.35485 .40773 L
.35917 .40306 L
.36374 .39802 L
.36888 .39212 L
.37214 .38831 L
.37859 .3805 L
.38015 .37859 L
.38783 .36888 L
.38831 .36827 L
.39525 .35917 L
.39802 .35544 L
.40242 .34946 L
.40773 .34204 L
.40937 .33974 L
.41613 .33003 L
.41744 .32811 L
.42274 .32032 L
.42716 .31366 L
.42918 .31061 L
.43548 .30089 L
.43687 .29872 L
.44166 .29118 L
.44658 .28329 L
.44771 .28147 L
.45367 .27176 L
.45629 .2674 L
.45952 .26204 L
.46526 .25233 L
.46601 .25105 L
.47094 .24262 L
.47572 .23427 L
.4765 .23291 L
.48202 .22319 L
.48543 .21707 L
.48743 .21348 L
.4928 .20377 L
.49514 .19944 L
.49808 .19406 L
.50331 .18434 L
.50486 .18141 L
.50847 .17463 L
.51357 .16492 L
.51457 .16299 L
.51863 .15521 L
.52361 .14549 L
.52428 .14418 L
.52857 .13578 L
.53346 .12607 L
.53399 .12498 L
.53832 .11636 L
.54311 .10664 L
.54371 .10542 L
.54788 .09693 L
.55259 .08722 L
.55342 .08549 L
.55728 .07751 L
.56191 .06779 L
.56313 .0652 L
.56651 .05808 L
.57108 .04837 L
.57284 .04456 L
.5756 .03866 L
.58011 .02894 L
.58256 .02357 L
.58455 .01923 L
.01923 .01923 L
F
0 g
.01923 .74324 m
.02451 .73796 L
.02894 .73353 L
.03423 .72824 L
.03866 .72382 L
.04394 .71853 L
.04837 .71411 L
.05366 .70882 L
.05808 .70439 L
.06337 .69911 L
.06779 .69468 L
.07308 .68939 L
.07751 .68497 L
.08279 .67968 L
.08722 .67526 L
.09251 .66997 L
.09693 .66554 L
.10222 .66026 L
.10664 .65583 L
.11193 .65054 L
.11636 .64612 L
.12164 .64083 L
.12607 .63641 L
.13136 .63112 L
.13578 .62669 L
.14107 .62141 L
.14549 .61698 L
.15078 .61169 L
.15521 .60727 L
.16049 .60198 L
.16492 .59756 L
.17021 .59227 L
.17463 .58784 L
.17992 .58256 L
.18434 .57813 L
.18963 .57284 L
.19406 .56842 L
.19934 .56313 L
.20377 .55871 L
.20906 .55342 L
.21348 .54899 L
.21877 .54371 L
.22319 .53928 L
.22848 .53399 L
.23291 .52957 L
.23819 .52428 L
.24262 .51986 L
.24791 .51457 L
.25233 .51014 L
.25762 .50486 L
Mistroke
.26204 .50043 L
.26733 .49514 L
.27176 .49072 L
.27704 .48543 L
.28147 .48101 L
.28676 .47572 L
.29118 .47129 L
.29647 .46601 L
.30089 .46158 L
.30618 .45629 L
.31061 .45187 L
.31589 .44658 L
.32032 .44216 L
.32561 .43687 L
.33003 .43244 L
.33533 .42716 L
.33974 .42273 L
.34515 .41744 L
.34946 .41329 L
.35485 .40773 L
.35917 .40306 L
.36374 .39802 L
.36888 .39212 L
.37214 .38831 L
.37859 .3805 L
.38015 .37859 L
.38783 .36888 L
.38831 .36827 L
.39525 .35917 L
.39802 .35544 L
.40242 .34946 L
.40773 .34204 L
.40937 .33974 L
.41613 .33003 L
.41744 .32811 L
.42274 .32032 L
.42716 .31366 L
.42918 .31061 L
.43548 .30089 L
.43687 .29872 L
.44166 .29118 L
.44658 .28329 L
.44771 .28147 L
.45367 .27176 L
.45629 .2674 L
.45952 .26204 L
.46526 .25233 L
.46601 .25105 L
.47094 .24262 L
.47572 .23427 L
Mistroke
.4765 .23291 L
.48202 .22319 L
.48543 .21707 L
.48743 .21348 L
.4928 .20377 L
.49514 .19944 L
.49808 .19406 L
.50331 .18434 L
.50486 .18141 L
.50847 .17463 L
.51357 .16492 L
.51457 .16299 L
.51863 .15521 L
.52361 .14549 L
.52428 .14418 L
.52857 .13578 L
.53346 .12607 L
.53399 .12498 L
.53832 .11636 L
.54311 .10664 L
.54371 .10542 L
.54788 .09693 L
.55259 .08722 L
.55342 .08549 L
.55728 .07751 L
.56191 .06779 L
.56313 .0652 L
.56651 .05808 L
.57108 .04837 L
.57284 .04456 L
.5756 .03866 L
.58011 .02894 L
.58256 .02357 L
.58455 .01923 L
Mfstroke
.3 g
.01923 .69953 m
.01964 .69911 L
.02894 .68981 L
.02936 .68939 L
.03866 .6801 L
.03908 .67968 L
.04837 .67039 L
.04879 .66997 L
.05808 .66068 L
.0585 .66026 L
.06779 .65096 L
.06821 .65054 L
.07751 .64125 L
.07793 .64083 L
.08722 .63154 L
.08764 .63112 L
.09693 .62183 L
.09735 .62141 L
.10664 .61211 L
.10706 .61169 L
.11636 .6024 L
.11678 .60198 L
.12607 .59269 L
.12649 .59227 L
.13578 .58298 L
.1362 .58256 L
.14549 .57326 L
.14591 .57284 L
.15521 .56355 L
.15563 .56313 L
.16492 .55384 L
.16534 .55342 L
.17463 .54413 L
.17505 .54371 L
.18434 .53441 L
.18476 .53399 L
.19406 .5247 L
.19448 .52428 L
.20377 .51499 L
.20419 .51457 L
.21348 .50528 L
.2139 .50486 L
.22319 .49556 L
.22361 .49514 L
.23291 .48585 L
.23333 .48543 L
.24262 .47614 L
.24304 .47572 L
.25233 .46643 L
.25275 .46601 L
.26204 .45671 L
.26246 .45629 L
.27176 .447 L
.27218 .44658 L
.28147 .43729 L
.28189 .43687 L
.29118 .42758 L
.2916 .42716 L
.30089 .41786 L
.30131 .41744 L
.31061 .40815 L
.31103 .40773 L
.32032 .39844 L
.32074 .39802 L
.33003 .38873 L
.33044 .38831 L
.33974 .37901 L
.34025 .37859 L
.34946 .37202 L
.35356 .36888 L
.35917 .36372 L
.36421 .35917 L
.36888 .35435 L
.37375 .34946 L
.37859 .34405 L
.38255 .33974 L
.38831 .33295 L
.39081 .33003 L
.39802 .3211 L
.39865 .32032 L
.40628 .31061 L
.40773 .30859 L
.41358 .30089 L
.41744 .29544 L
.42056 .29118 L
.42716 .28168 L
.42731 .28147 L
.43404 .27176 L
.43687 .26739 L
.44048 .26204 L
.44658 .25253 L
.44671 .25233 L
.453 .24262 L
.45629 .23719 L
.459 .23291 L
.46494 .22319 L
.46601 .22134 L
.47081 .21348 L
.47572 .20502 L
.47646 .20377 L
.4822 .19406 L
.48543 .18825 L
.4877 .18434 L
.49322 .17463 L
.49514 .17103 L
.4986 .16492 L
.50391 .15521 L
.50486 .15337 L
.50921 .14549 L
.51433 .13578 L
.51457 .13529 L
.51955 .12607 L
.52428 .11681 L
.52452 .11636 L
.52965 .10664 L
.53399 .09794 L
.53452 .09693 L
.53954 .08722 L
.54371 .07867 L
.5443 .07751 L
.54923 .06779 L
.55342 .05903 L
.55389 .05808 L
.55873 .04837 L
.56313 .03901 L
.5633 .03866 L
.56807 .02894 L
.57258 .01923 L
.01923 .01923 L
F
0 g
.01923 .69953 m
.01964 .69911 L
.02894 .68981 L
.02936 .68939 L
.03866 .6801 L
.03908 .67968 L
.04837 .67039 L
.04879 .66997 L
.05808 .66068 L
.0585 .66026 L
.06779 .65096 L
.06821 .65054 L
.07751 .64125 L
.07793 .64083 L
.08722 .63154 L
.08764 .63112 L
.09693 .62183 L
.09735 .62141 L
.10664 .61211 L
.10706 .61169 L
.11636 .6024 L
.11678 .60198 L
.12607 .59269 L
.12649 .59227 L
.13578 .58298 L
.1362 .58256 L
.14549 .57326 L
.14591 .57284 L
.15521 .56355 L
.15563 .56313 L
.16492 .55384 L
.16534 .55342 L
.17463 .54413 L
.17505 .54371 L
.18434 .53441 L
.18476 .53399 L
.19406 .5247 L
.19448 .52428 L
.20377 .51499 L
.20419 .51457 L
.21348 .50528 L
.2139 .50486 L
.22319 .49556 L
.22361 .49514 L
.23291 .48585 L
.23333 .48543 L
.24262 .47614 L
.24304 .47572 L
.25233 .46643 L
.25275 .46601 L
Mistroke
.26204 .45671 L
.26246 .45629 L
.27176 .447 L
.27218 .44658 L
.28147 .43729 L
.28189 .43687 L
.29118 .42758 L
.2916 .42716 L
.30089 .41786 L
.30131 .41744 L
.31061 .40815 L
.31103 .40773 L
.32032 .39844 L
.32074 .39802 L
.33003 .38873 L
.33044 .38831 L
.33974 .37901 L
.34025 .37859 L
.34946 .37202 L
.35356 .36888 L
.35917 .36372 L
.36421 .35917 L
.36888 .35435 L
.37375 .34946 L
.37859 .34405 L
.38255 .33974 L
.38831 .33295 L
.39081 .33003 L
.39802 .3211 L
.39865 .32032 L
.40628 .31061 L
.40773 .30859 L
.41358 .30089 L
.41744 .29544 L
.42056 .29118 L
.42716 .28168 L
.42731 .28147 L
.43404 .27176 L
.43687 .26739 L
.44048 .26204 L
.44658 .25253 L
.44671 .25233 L
.453 .24262 L
.45629 .23719 L
.459 .23291 L
.46494 .22319 L
.46601 .22134 L
.47081 .21348 L
.47572 .20502 L
.47646 .20377 L
Mistroke
.4822 .19406 L
.48543 .18825 L
.4877 .18434 L
.49322 .17463 L
.49514 .17103 L
.4986 .16492 L
.50391 .15521 L
.50486 .15337 L
.50921 .14549 L
.51433 .13578 L
.51457 .13529 L
.51955 .12607 L
.52428 .11681 L
.52452 .11636 L
.52965 .10664 L
.53399 .09794 L
.53452 .09693 L
.53954 .08722 L
.54371 .07867 L
.5443 .07751 L
.54923 .06779 L
.55342 .05903 L
.55389 .05808 L
.55873 .04837 L
.56313 .03901 L
.5633 .03866 L
.56807 .02894 L
.57258 .01923 L
Mfstroke
.4 g
.01923 .62099 m
.02854 .61169 L
.02894 .61127 L
.03823 .60198 L
.03866 .60156 L
.04795 .59227 L
.04837 .59185 L
.05766 .58256 L
.05808 .58214 L
.06737 .57284 L
.06779 .57242 L
.07708 .56313 L
.07751 .56271 L
.0868 .55342 L
.08722 .553 L
.09651 .54371 L
.09693 .54329 L
.10622 .53399 L
.10664 .53357 L
.11593 .52428 L
.11636 .52386 L
.12565 .51457 L
.12607 .51415 L
.13536 .50486 L
.13578 .50444 L
.14507 .49514 L
.14549 .49472 L
.15478 .48543 L
.15521 .48501 L
.1645 .47572 L
.16492 .4753 L
.17421 .46601 L
.17463 .46559 L
.18392 .45629 L
.18434 .45587 L
.19363 .44658 L
.19406 .44616 L
.20335 .43687 L
.20377 .43645 L
.21306 .42716 L
.21348 .42674 L
.22277 .41744 L
.22319 .41702 L
.23248 .40773 L
.23291 .40731 L
.2422 .39802 L
.24262 .3976 L
.25191 .38831 L
.25233 .38789 L
.26162 .37859 L
.26204 .37817 L
.27134 .36888 L
.27176 .36846 L
.28105 .35917 L
.28147 .35875 L
.29076 .34946 L
.29118 .34904 L
.30047 .33974 L
.30089 .33932 L
.31019 .33003 L
.31061 .32961 L
.3199 .32032 L
.32032 .3199 L
.32961 .31061 L
.33003 .31019 L
.33937 .30089 L
.33974 .30047 L
.34669 .29118 L
.34946 .28732 L
.35377 .28147 L
.35917 .27411 L
.36089 .27176 L
.36791 .26204 L
.36888 .26069 L
.37481 .25233 L
.37859 .24694 L
.38159 .24262 L
.38828 .23291 L
.38831 .23287 L
.39481 .22319 L
.39802 .21839 L
.40124 .21348 L
.4076 .20377 L
.40773 .20356 L
.41379 .19406 L
.41744 .18831 L
.4199 .18434 L
.42595 .17463 L
.42716 .17268 L
.43185 .16492 L
.43687 .15665 L
.43772 .15521 L
.44347 .14549 L
.44658 .14022 L
.44913 .13578 L
.45476 .12607 L
.45629 .12341 L
.46026 .11636 L
.46577 .10664 L
.46601 .10622 L
.47112 .09693 L
.47572 .08863 L
.47647 .08722 L
.48172 .07751 L
.48543 .07068 L
.48693 .06779 L
.4921 .05808 L
.49514 .05235 L
.49718 .04837 L
.50225 .03866 L
.50486 .03367 L
.50722 .02894 L
.51221 .01923 L
.01923 .01923 L
F
0 g
.01923 .62099 m
.02854 .61169 L
.02894 .61127 L
.03823 .60198 L
.03866 .60156 L
.04795 .59227 L
.04837 .59185 L
.05766 .58256 L
.05808 .58214 L
.06737 .57284 L
.06779 .57242 L
.07708 .56313 L
.07751 .56271 L
.0868 .55342 L
.08722 .553 L
.09651 .54371 L
.09693 .54329 L
.10622 .53399 L
.10664 .53357 L
.11593 .52428 L
.11636 .52386 L
.12565 .51457 L
.12607 .51415 L
.13536 .50486 L
.13578 .50444 L
.14507 .49514 L
.14549 .49472 L
.15478 .48543 L
.15521 .48501 L
.1645 .47572 L
.16492 .4753 L
.17421 .46601 L
.17463 .46559 L
.18392 .45629 L
.18434 .45587 L
.19363 .44658 L
.19406 .44616 L
.20335 .43687 L
.20377 .43645 L
.21306 .42716 L
.21348 .42674 L
.22277 .41744 L
.22319 .41702 L
.23248 .40773 L
.23291 .40731 L
.2422 .39802 L
.24262 .3976 L
.25191 .38831 L
.25233 .38789 L
.26162 .37859 L
Mistroke
.26204 .37817 L
.27134 .36888 L
.27176 .36846 L
.28105 .35917 L
.28147 .35875 L
.29076 .34946 L
.29118 .34904 L
.30047 .33974 L
.30089 .33932 L
.31019 .33003 L
.31061 .32961 L
.3199 .32032 L
.32032 .3199 L
.32961 .31061 L
.33003 .31019 L
.33937 .30089 L
.33974 .30047 L
.34669 .29118 L
.34946 .28732 L
.35377 .28147 L
.35917 .27411 L
.36089 .27176 L
.36791 .26204 L
.36888 .26069 L
.37481 .25233 L
.37859 .24694 L
.38159 .24262 L
.38828 .23291 L
.38831 .23287 L
.39481 .22319 L
.39802 .21839 L
.40124 .21348 L
.4076 .20377 L
.40773 .20356 L
.41379 .19406 L
.41744 .18831 L
.4199 .18434 L
.42595 .17463 L
.42716 .17268 L
.43185 .16492 L
.43687 .15665 L
.43772 .15521 L
.44347 .14549 L
.44658 .14022 L
.44913 .13578 L
.45476 .12607 L
.45629 .12341 L
.46026 .11636 L
.46577 .10664 L
.46601 .10622 L
Mistroke
.47112 .09693 L
.47572 .08863 L
.47647 .08722 L
.48172 .07751 L
.48543 .07068 L
.48693 .06779 L
.4921 .05808 L
.49514 .05235 L
.49718 .04837 L
.50225 .03866 L
.50486 .03367 L
.50722 .02894 L
.51221 .01923 L
Mfstroke
.5 g
.01923 .57727 m
.02367 .57284 L
.02894 .56756 L
.03337 .56313 L
.03866 .55784 L
.04308 .55342 L
.04837 .54813 L
.05279 .54371 L
.05808 .53842 L
.06251 .53399 L
.06779 .52871 L
.07222 .52428 L
.07751 .51899 L
.08193 .51457 L
.08722 .50928 L
.09164 .50486 L
.09693 .49957 L
.10136 .49514 L
.10664 .48986 L
.11107 .48543 L
.11636 .48014 L
.12078 .47572 L
.12607 .47043 L
.13049 .46601 L
.13578 .46072 L
.14021 .45629 L
.14549 .45101 L
.14992 .44658 L
.15521 .44129 L
.15963 .43687 L
.16492 .43158 L
.16934 .42716 L
.17463 .42187 L
.17906 .41744 L
.18434 .41216 L
.18877 .40773 L
.19406 .40244 L
.19848 .39802 L
.20377 .39273 L
.20819 .38831 L
.21348 .38302 L
.21791 .37859 L
.22319 .37331 L
.22762 .36888 L
.23291 .36359 L
.23733 .35917 L
.24262 .35388 L
.24704 .34946 L
.25233 .34417 L
.25676 .33974 L
.26204 .33446 L
.26647 .33003 L
.27176 .32474 L
.27618 .32032 L
.28147 .31503 L
.28589 .31061 L
.29118 .30532 L
.29561 .30089 L
.30089 .29561 L
.30532 .29118 L
.31061 .28589 L
.31503 .28147 L
.32032 .27618 L
.32474 .27176 L
.33003 .26647 L
.33454 .26204 L
.33974 .25676 L
.34382 .25233 L
.34946 .24606 L
.35247 .24262 L
.35917 .23477 L
.36073 .23291 L
.36865 .22319 L
.36888 .22291 L
.3763 .21348 L
.37859 .21049 L
.38369 .20377 L
.38831 .19754 L
.39085 .19406 L
.39783 .18434 L
.39802 .18407 L
.40462 .17463 L
.40773 .1701 L
.41125 .16492 L
.41744 .15564 L
.41773 .15521 L
.42408 .14549 L
.42716 .14071 L
.43029 .13578 L
.4364 .12607 L
.43687 .12532 L
.4424 .11636 L
.44658 .10948 L
.44829 .10664 L
.45409 .09693 L
.45629 .0932 L
.4598 .08722 L
.46543 .07751 L
.46601 .0765 L
.47097 .06779 L
.47572 .05938 L
.47645 .05808 L
.48185 .04837 L
.48543 .04186 L
.48718 .03866 L
.49245 .02894 L
.49514 .02394 L
.49765 .01923 L
.01923 .01923 L
F
0 g
.01923 .57727 m
.02367 .57284 L
.02894 .56756 L
.03337 .56313 L
.03866 .55784 L
.04308 .55342 L
.04837 .54813 L
.05279 .54371 L
.05808 .53842 L
.06251 .53399 L
.06779 .52871 L
.07222 .52428 L
.07751 .51899 L
.08193 .51457 L
.08722 .50928 L
.09164 .50486 L
.09693 .49957 L
.10136 .49514 L
.10664 .48986 L
.11107 .48543 L
.11636 .48014 L
.12078 .47572 L
.12607 .47043 L
.13049 .46601 L
.13578 .46072 L
.14021 .45629 L
.14549 .45101 L
.14992 .44658 L
.15521 .44129 L
.15963 .43687 L
.16492 .43158 L
.16934 .42716 L
.17463 .42187 L
.17906 .41744 L
.18434 .41216 L
.18877 .40773 L
.19406 .40244 L
.19848 .39802 L
.20377 .39273 L
.20819 .38831 L
.21348 .38302 L
.21791 .37859 L
.22319 .37331 L
.22762 .36888 L
.23291 .36359 L
.23733 .35917 L
.24262 .35388 L
.24704 .34946 L
.25233 .34417 L
.25676 .33974 L
Mistroke
.26204 .33446 L
.26647 .33003 L
.27176 .32474 L
.27618 .32032 L
.28147 .31503 L
.28589 .31061 L
.29118 .30532 L
.29561 .30089 L
.30089 .29561 L
.30532 .29118 L
.31061 .28589 L
.31503 .28147 L
.32032 .27618 L
.32474 .27176 L
.33003 .26647 L
.33454 .26204 L
.33974 .25676 L
.34382 .25233 L
.34946 .24606 L
.35247 .24262 L
.35917 .23477 L
.36073 .23291 L
.36865 .22319 L
.36888 .22291 L
.3763 .21348 L
.37859 .21049 L
.38369 .20377 L
.38831 .19754 L
.39085 .19406 L
.39783 .18434 L
.39802 .18407 L
.40462 .17463 L
.40773 .1701 L
.41125 .16492 L
.41744 .15564 L
.41773 .15521 L
.42408 .14549 L
.42716 .14071 L
.43029 .13578 L
.4364 .12607 L
.43687 .12532 L
.4424 .11636 L
.44658 .10948 L
.44829 .10664 L
.45409 .09693 L
.45629 .0932 L
.4598 .08722 L
.46543 .07751 L
.46601 .0765 L
.47097 .06779 L
Mistroke
.47572 .05938 L
.47645 .05808 L
.48185 .04837 L
.48543 .04186 L
.48718 .03866 L
.49245 .02894 L
.49514 .02394 L
.49765 .01923 L
Mfstroke
.6 g
.01923 .54186 m
.02709 .53399 L
.02894 .53215 L
.03681 .52428 L
.03866 .52243 L
.04652 .51457 L
.04837 .51272 L
.05623 .50486 L
.05808 .50301 L
.06595 .49514 L
.06779 .4933 L
.07566 .48543 L
.07751 .48358 L
.08537 .47572 L
.08722 .47387 L
.09508 .46601 L
.09693 .46416 L
.1048 .45629 L
.10664 .45445 L
.11451 .44658 L
.11636 .44473 L
.12422 .43687 L
.12607 .43502 L
.13393 .42716 L
.13578 .42531 L
.14365 .41744 L
.14549 .4156 L
.15336 .40773 L
.15521 .40588 L
.16307 .39802 L
.16492 .39617 L
.17278 .38831 L
.17463 .38646 L
.1825 .37859 L
.18434 .37675 L
.19221 .36888 L
.19406 .36703 L
.20192 .35917 L
.20377 .35732 L
.21163 .34946 L
.21348 .34761 L
.22135 .33974 L
.22319 .3379 L
.23106 .33003 L
.23291 .32818 L
.24077 .32032 L
.24262 .31847 L
.25048 .31061 L
.25233 .30876 L
.2602 .30089 L
.26204 .29905 L
.26991 .29118 L
.27176 .28933 L
.27962 .28147 L
.28147 .27962 L
.28933 .27176 L
.29118 .26991 L
.29905 .26204 L
.30089 .2602 L
.30876 .25233 L
.31061 .25048 L
.31847 .24262 L
.32032 .24077 L
.32818 .23291 L
.33003 .23106 L
.3379 .22319 L
.33974 .22135 L
.34782 .21348 L
.34946 .2119 L
.35726 .20377 L
.35917 .20168 L
.36602 .19406 L
.36888 .19073 L
.37431 .18434 L
.37859 .17912 L
.38223 .17463 L
.38831 .16688 L
.38983 .16492 L
.39717 .15521 L
.39802 .15405 L
.40429 .14549 L
.40773 .14066 L
.41119 .13578 L
.41744 .12673 L
.41789 .12607 L
.42446 .11636 L
.42716 .11228 L
.43087 .10664 L
.43687 .09733 L
.43712 .09693 L
.44328 .08722 L
.44658 .08191 L
.44931 .07751 L
.45523 .06779 L
.45629 .06601 L
.46106 .05808 L
.46601 .04967 L
.46677 .04837 L
.47243 .03866 L
.47572 .03289 L
.47798 .02894 L
.48346 .01923 L
.01923 .01923 L
F
0 g
.01923 .54186 m
.02709 .53399 L
.02894 .53215 L
.03681 .52428 L
.03866 .52243 L
.04652 .51457 L
.04837 .51272 L
.05623 .50486 L
.05808 .50301 L
.06595 .49514 L
.06779 .4933 L
.07566 .48543 L
.07751 .48358 L
.08537 .47572 L
.08722 .47387 L
.09508 .46601 L
.09693 .46416 L
.1048 .45629 L
.10664 .45445 L
.11451 .44658 L
.11636 .44473 L
.12422 .43687 L
.12607 .43502 L
.13393 .42716 L
.13578 .42531 L
.14365 .41744 L
.14549 .4156 L
.15336 .40773 L
.15521 .40588 L
.16307 .39802 L
.16492 .39617 L
.17278 .38831 L
.17463 .38646 L
.1825 .37859 L
.18434 .37675 L
.19221 .36888 L
.19406 .36703 L
.20192 .35917 L
.20377 .35732 L
.21163 .34946 L
.21348 .34761 L
.22135 .33974 L
.22319 .3379 L
.23106 .33003 L
.23291 .32818 L
.24077 .32032 L
.24262 .31847 L
.25048 .31061 L
.25233 .30876 L
.2602 .30089 L
Mistroke
.26204 .29905 L
.26991 .29118 L
.27176 .28933 L
.27962 .28147 L
.28147 .27962 L
.28933 .27176 L
.29118 .26991 L
.29905 .26204 L
.30089 .2602 L
.30876 .25233 L
.31061 .25048 L
.31847 .24262 L
.32032 .24077 L
.32818 .23291 L
.33003 .23106 L
.3379 .22319 L
.33974 .22135 L
.34782 .21348 L
.34946 .2119 L
.35726 .20377 L
.35917 .20168 L
.36602 .19406 L
.36888 .19073 L
.37431 .18434 L
.37859 .17912 L
.38223 .17463 L
.38831 .16688 L
.38983 .16492 L
.39717 .15521 L
.39802 .15405 L
.40429 .14549 L
.40773 .14066 L
.41119 .13578 L
.41744 .12673 L
.41789 .12607 L
.42446 .11636 L
.42716 .11228 L
.43087 .10664 L
.43687 .09733 L
.43712 .09693 L
.44328 .08722 L
.44658 .08191 L
.44931 .07751 L
.45523 .06779 L
.45629 .06601 L
.46106 .05808 L
.46601 .04967 L
.46677 .04837 L
.47243 .03866 L
.47572 .03289 L
Mistroke
.47798 .02894 L
.48346 .01923 L
Mfstroke
.7 g
.01923 .49817 m
.02219 .49514 L
.02894 .48846 L
.03197 .48543 L
.03866 .47875 L
.04168 .47572 L
.04837 .46903 L
.0514 .46601 L
.05808 .45932 L
.06111 .45629 L
.06779 .44961 L
.07082 .44658 L
.07751 .4399 L
.08053 .43687 L
.08722 .43018 L
.09025 .42716 L
.09693 .42047 L
.09996 .41744 L
.10664 .41076 L
.10967 .40773 L
.11636 .40105 L
.11938 .39802 L
.12607 .39133 L
.1291 .38831 L
.13578 .38162 L
.13881 .37859 L
.14549 .37191 L
.14852 .36888 L
.15521 .3622 L
.15823 .35917 L
.16492 .35248 L
.16795 .34946 L
.17463 .34277 L
.17766 .33974 L
.18434 .33306 L
.18737 .33003 L
.19406 .32335 L
.19708 .32032 L
.20377 .31363 L
.2068 .31061 L
.21348 .30392 L
.21651 .30089 L
.22319 .29421 L
.22622 .29118 L
.23291 .2845 L
.23593 .28147 L
.24262 .27478 L
.24565 .27176 L
.25233 .26507 L
.25536 .26204 L
.26204 .25536 L
.26507 .25233 L
.27176 .24565 L
.27478 .24262 L
.28147 .23593 L
.2845 .23291 L
.29118 .22622 L
.29421 .22319 L
.30089 .21651 L
.30392 .21348 L
.31061 .2068 L
.31363 .20377 L
.32032 .19708 L
.32335 .19406 L
.33003 .18737 L
.33299 .18434 L
.33974 .17766 L
.34358 .17463 L
.34946 .17065 L
.35663 .16492 L
.35917 .16234 L
.36684 .15521 L
.36888 .15296 L
.37616 .14549 L
.37859 .14267 L
.38484 .13578 L
.38831 .13157 L
.393 .12607 L
.39802 .11972 L
.40074 .11636 L
.40773 .10719 L
.40816 .10664 L
.41545 .09693 L
.41744 .09406 L
.42242 .08722 L
.42716 .08031 L
.42913 .07751 L
.43573 .06779 L
.43687 .066 L
.44219 .05808 L
.44658 .05116 L
.44841 .04837 L
.45459 .03866 L
.45629 .03581 L
.46062 .02894 L
.46601 .01995 L
.46645 .01923 L
.01923 .01923 L
F
0 g
.01923 .49817 m
.02219 .49514 L
.02894 .48846 L
.03197 .48543 L
.03866 .47875 L
.04168 .47572 L
.04837 .46903 L
.0514 .46601 L
.05808 .45932 L
.06111 .45629 L
.06779 .44961 L
.07082 .44658 L
.07751 .4399 L
.08053 .43687 L
.08722 .43018 L
.09025 .42716 L
.09693 .42047 L
.09996 .41744 L
.10664 .41076 L
.10967 .40773 L
.11636 .40105 L
.11938 .39802 L
.12607 .39133 L
.1291 .38831 L
.13578 .38162 L
.13881 .37859 L
.14549 .37191 L
.14852 .36888 L
.15521 .3622 L
.15823 .35917 L
.16492 .35248 L
.16795 .34946 L
.17463 .34277 L
.17766 .33974 L
.18434 .33306 L
.18737 .33003 L
.19406 .32335 L
.19708 .32032 L
.20377 .31363 L
.2068 .31061 L
.21348 .30392 L
.21651 .30089 L
.22319 .29421 L
.22622 .29118 L
.23291 .2845 L
.23593 .28147 L
.24262 .27478 L
.24565 .27176 L
.25233 .26507 L
.25536 .26204 L
Mistroke
.26204 .25536 L
.26507 .25233 L
.27176 .24565 L
.27478 .24262 L
.28147 .23593 L
.2845 .23291 L
.29118 .22622 L
.29421 .22319 L
.30089 .21651 L
.30392 .21348 L
.31061 .2068 L
.31363 .20377 L
.32032 .19708 L
.32335 .19406 L
.33003 .18737 L
.33299 .18434 L
.33974 .17766 L
.34358 .17463 L
.34946 .17065 L
.35663 .16492 L
.35917 .16234 L
.36684 .15521 L
.36888 .15296 L
.37616 .14549 L
.37859 .14267 L
.38484 .13578 L
.38831 .13157 L
.393 .12607 L
.39802 .11972 L
.40074 .11636 L
.40773 .10719 L
.40816 .10664 L
.41545 .09693 L
.41744 .09406 L
.42242 .08722 L
.42716 .08031 L
.42913 .07751 L
.43573 .06779 L
.43687 .066 L
.44219 .05808 L
.44658 .05116 L
.44841 .04837 L
.45459 .03866 L
.45629 .03581 L
.46062 .02894 L
.46601 .01995 L
.46645 .01923 L
Mfstroke
.6 g
.01923 .41956 m
.02172 .41744 L
.02894 .40985 L
.03106 .40773 L
.03866 .40014 L
.04078 .39802 L
.04837 .39043 L
.05049 .38831 L
.05808 .38071 L
.0602 .37859 L
.06779 .371 L
.06991 .36888 L
.07751 .36129 L
.07963 .35917 L
.08722 .35158 L
.08934 .34946 L
.09693 .34186 L
.09905 .33974 L
.10664 .33215 L
.10876 .33003 L
.11636 .32244 L
.11848 .32032 L
.12607 .31273 L
.12819 .31061 L
.13578 .30301 L
.1379 .30089 L
.14549 .2933 L
.14761 .29118 L
.15521 .28359 L
.15733 .28147 L
.16492 .27388 L
.16704 .27176 L
.17463 .26416 L
.17675 .26204 L
.18434 .25445 L
.18646 .25233 L
.19406 .24474 L
.19618 .24262 L
.20377 .23503 L
.20589 .23291 L
.21348 .22531 L
.2156 .22319 L
.22319 .2156 L
.22531 .21348 L
.23291 .20589 L
.23503 .20377 L
.24262 .19618 L
.24474 .19406 L
.25233 .18646 L
.25445 .18434 L
.26204 .17675 L
.26416 .17463 L
.27176 .16704 L
.27388 .16492 L
.28147 .15733 L
.28359 .15521 L
.29118 .14761 L
.2933 .14549 L
.30089 .1379 L
.30301 .13578 L
.31061 .12819 L
.31273 .12607 L
.32032 .11848 L
.32244 .11636 L
.33003 .10876 L
.33236 .10664 L
.33974 .09905 L
.34143 .09693 L
.34855 .08722 L
.34946 .08595 L
.35567 .07751 L
.35917 .07272 L
.36275 .06779 L
.36888 .0593 L
.36975 .05808 L
.37663 .04837 L
.37859 .04556 L
.38337 .03866 L
.38831 .03147 L
.39001 .02894 L
.39655 .01923 L
.01923 .01923 L
F
0 g
.01923 .41956 m
.02172 .41744 L
.02894 .40985 L
.03106 .40773 L
.03866 .40014 L
.04078 .39802 L
.04837 .39043 L
.05049 .38831 L
.05808 .38071 L
.0602 .37859 L
.06779 .371 L
.06991 .36888 L
.07751 .36129 L
.07963 .35917 L
.08722 .35158 L
.08934 .34946 L
.09693 .34186 L
.09905 .33974 L
.10664 .33215 L
.10876 .33003 L
.11636 .32244 L
.11848 .32032 L
.12607 .31273 L
.12819 .31061 L
.13578 .30301 L
.1379 .30089 L
.14549 .2933 L
.14761 .29118 L
.15521 .28359 L
.15733 .28147 L
.16492 .27388 L
.16704 .27176 L
.17463 .26416 L
.17675 .26204 L
.18434 .25445 L
.18646 .25233 L
.19406 .24474 L
.19618 .24262 L
.20377 .23503 L
.20589 .23291 L
.21348 .22531 L
.2156 .22319 L
.22319 .2156 L
.22531 .21348 L
.23291 .20589 L
.23503 .20377 L
.24262 .19618 L
.24474 .19406 L
.25233 .18646 L
.25445 .18434 L
Mistroke
.26204 .17675 L
.26416 .17463 L
.27176 .16704 L
.27388 .16492 L
.28147 .15733 L
.28359 .15521 L
.29118 .14761 L
.2933 .14549 L
.30089 .1379 L
.30301 .13578 L
.31061 .12819 L
.31273 .12607 L
.32032 .11848 L
.32244 .11636 L
.33003 .10876 L
.33236 .10664 L
.33974 .09905 L
.34143 .09693 L
.34855 .08722 L
.34946 .08595 L
.35567 .07751 L
.35917 .07272 L
.36275 .06779 L
.36888 .0593 L
.36975 .05808 L
.37663 .04837 L
.37859 .04556 L
.38337 .03866 L
.38831 .03147 L
.39001 .02894 L
.39655 .01923 L
Mfstroke
.5 g
.01923 .37589 m
.02624 .36888 L
.02894 .36617 L
.03595 .35917 L
.03866 .35646 L
.04566 .34946 L
.04837 .34675 L
.05537 .33974 L
.05808 .33704 L
.06509 .33003 L
.06779 .32732 L
.0748 .32032 L
.07751 .31761 L
.08451 .31061 L
.08722 .3079 L
.09422 .30089 L
.09693 .29819 L
.10394 .29118 L
.10664 .28847 L
.11365 .28147 L
.11636 .27876 L
.12336 .27176 L
.12607 .26905 L
.13307 .26204 L
.13578 .25934 L
.14279 .25233 L
.14549 .24962 L
.1525 .24262 L
.15521 .23991 L
.16221 .23291 L
.16492 .2302 L
.17192 .22319 L
.17463 .22049 L
.18164 .21348 L
.18434 .21077 L
.19135 .20377 L
.19406 .20106 L
.20106 .19406 L
.20377 .19135 L
.21077 .18434 L
.21348 .18164 L
.22049 .17463 L
.22319 .17192 L
.2302 .16492 L
.23291 .16221 L
.23991 .15521 L
.24262 .1525 L
.24962 .14549 L
.25233 .14279 L
.25934 .13578 L
.26204 .13307 L
.26905 .12607 L
.27176 .12336 L
.27876 .11636 L
.28147 .11365 L
.28847 .10664 L
.29118 .10394 L
.29819 .09693 L
.30089 .09422 L
.3079 .08722 L
.31061 .08451 L
.31761 .07751 L
.32032 .0748 L
.32732 .06779 L
.33003 .06509 L
.33711 .05808 L
.33974 .05537 L
.34615 .04837 L
.34946 .04467 L
.3547 .03866 L
.35917 .03338 L
.36286 .02894 L
.36888 .02153 L
.37071 .01923 L
.01923 .01923 L
F
0 g
.01923 .37589 m
.02624 .36888 L
.02894 .36617 L
.03595 .35917 L
.03866 .35646 L
.04566 .34946 L
.04837 .34675 L
.05537 .33974 L
.05808 .33704 L
.06509 .33003 L
.06779 .32732 L
.0748 .32032 L
.07751 .31761 L
.08451 .31061 L
.08722 .3079 L
.09422 .30089 L
.09693 .29819 L
.10394 .29118 L
.10664 .28847 L
.11365 .28147 L
.11636 .27876 L
.12336 .27176 L
.12607 .26905 L
.13307 .26204 L
.13578 .25934 L
.14279 .25233 L
.14549 .24962 L
.1525 .24262 L
.15521 .23991 L
.16221 .23291 L
.16492 .2302 L
.17192 .22319 L
.17463 .22049 L
.18164 .21348 L
.18434 .21077 L
.19135 .20377 L
.19406 .20106 L
.20106 .19406 L
.20377 .19135 L
.21077 .18434 L
.21348 .18164 L
.22049 .17463 L
.22319 .17192 L
.2302 .16492 L
.23291 .16221 L
.23991 .15521 L
.24262 .1525 L
.24962 .14549 L
.25233 .14279 L
.25934 .13578 L
Mistroke
.26204 .13307 L
.26905 .12607 L
.27176 .12336 L
.27876 .11636 L
.28147 .11365 L
.28847 .10664 L
.29118 .10394 L
.29819 .09693 L
.30089 .09422 L
.3079 .08722 L
.31061 .08451 L
.31761 .07751 L
.32032 .0748 L
.32732 .06779 L
.33003 .06509 L
.33711 .05808 L
.33974 .05537 L
.34615 .04837 L
.34946 .04467 L
.3547 .03866 L
.35917 .03338 L
.36286 .02894 L
.36888 .02153 L
.37071 .01923 L
Mfstroke
.4 g
.01923 .34047 m
.01996 .33974 L
.02894 .33076 L
.02967 .33003 L
.03866 .32105 L
.03939 .32032 L
.04837 .31134 L
.0491 .31061 L
.05808 .30162 L
.05881 .30089 L
.06779 .29191 L
.06852 .29118 L
.07751 .2822 L
.07824 .28147 L
.08722 .27249 L
.08795 .27176 L
.09693 .26277 L
.09766 .26204 L
.10664 .25306 L
.10737 .25233 L
.11636 .24335 L
.11709 .24262 L
.12607 .23364 L
.1268 .23291 L
.13578 .22392 L
.13651 .22319 L
.14549 .21421 L
.14622 .21348 L
.15521 .2045 L
.15594 .20377 L
.16492 .19479 L
.16565 .19406 L
.17463 .18507 L
.17536 .18434 L
.18434 .17536 L
.18507 .17463 L
.19406 .16565 L
.19479 .16492 L
.20377 .15594 L
.2045 .15521 L
.21348 .14622 L
.21421 .14549 L
.22319 .13651 L
.22392 .13578 L
.23291 .1268 L
.23364 .12607 L
.24262 .11709 L
.24335 .11636 L
.25233 .10737 L
.25306 .10664 L
.26204 .09766 L
.26277 .09693 L
.27176 .08795 L
.27249 .08722 L
.28147 .07824 L
.2822 .07751 L
.29118 .06852 L
.29191 .06779 L
.30089 .05881 L
.30162 .05808 L
.31061 .0491 L
.31134 .04837 L
.32032 .03939 L
.32105 .03866 L
.33003 .02967 L
.33077 .02894 L
.33974 .01996 L
.34048 .01923 L
.01923 .01923 L
F
0 g
.01923 .34047 m
.01996 .33974 L
.02894 .33076 L
.02967 .33003 L
.03866 .32105 L
.03939 .32032 L
.04837 .31134 L
.0491 .31061 L
.05808 .30162 L
.05881 .30089 L
.06779 .29191 L
.06852 .29118 L
.07751 .2822 L
.07824 .28147 L
.08722 .27249 L
.08795 .27176 L
.09693 .26277 L
.09766 .26204 L
.10664 .25306 L
.10737 .25233 L
.11636 .24335 L
.11709 .24262 L
.12607 .23364 L
.1268 .23291 L
.13578 .22392 L
.13651 .22319 L
.14549 .21421 L
.14622 .21348 L
.15521 .2045 L
.15594 .20377 L
.16492 .19479 L
.16565 .19406 L
.17463 .18507 L
.17536 .18434 L
.18434 .17536 L
.18507 .17463 L
.19406 .16565 L
.19479 .16492 L
.20377 .15594 L
.2045 .15521 L
.21348 .14622 L
.21421 .14549 L
.22319 .13651 L
.22392 .13578 L
.23291 .1268 L
.23364 .12607 L
.24262 .11709 L
.24335 .11636 L
.25233 .10737 L
.25306 .10664 L
Mistroke
.26204 .09766 L
.26277 .09693 L
.27176 .08795 L
.27249 .08722 L
.28147 .07824 L
.2822 .07751 L
.29118 .06852 L
.29191 .06779 L
.30089 .05881 L
.30162 .05808 L
.31061 .0491 L
.31134 .04837 L
.32032 .03939 L
.32105 .03866 L
.33003 .02967 L
.33077 .02894 L
.33974 .01996 L
.34048 .01923 L
Mfstroke
.3 g
.01923 .2968 m
.02477 .29118 L
.02894 .28709 L
.03457 .28147 L
.03866 .27738 L
.04428 .27176 L
.04837 .26767 L
.05399 .26204 L
.05808 .25795 L
.0637 .25233 L
.06779 .24824 L
.07342 .24262 L
.07751 .23853 L
.08313 .23291 L
.08722 .22882 L
.09284 .22319 L
.09693 .2191 L
.10255 .21348 L
.10664 .20939 L
.11227 .20377 L
.11636 .19968 L
.12198 .19406 L
.12607 .18997 L
.13169 .18434 L
.13578 .18025 L
.1414 .17463 L
.14549 .17054 L
.15112 .16492 L
.15521 .16083 L
.16083 .15521 L
.16492 .15112 L
.17054 .14549 L
.17463 .1414 L
.18025 .13578 L
.18434 .13169 L
.18997 .12607 L
.19406 .12198 L
.19968 .11636 L
.20377 .11227 L
.20939 .10664 L
.21348 .10255 L
.2191 .09693 L
.22319 .09284 L
.22882 .08722 L
.23291 .08313 L
.23853 .07751 L
.24262 .07342 L
.24824 .06779 L
.25233 .0637 L
.25795 .05808 L
.26204 .05399 L
.26767 .04837 L
.27176 .04428 L
.27738 .03866 L
.28147 .03457 L
.28709 .02894 L
.29118 .02477 L
.2968 .01923 L
.01923 .01923 L
F
0 g
.01923 .2968 m
.02477 .29118 L
.02894 .28709 L
.03457 .28147 L
.03866 .27738 L
.04428 .27176 L
.04837 .26767 L
.05399 .26204 L
.05808 .25795 L
.0637 .25233 L
.06779 .24824 L
.07342 .24262 L
.07751 .23853 L
.08313 .23291 L
.08722 .22882 L
.09284 .22319 L
.09693 .2191 L
.10255 .21348 L
.10664 .20939 L
.11227 .20377 L
.11636 .19968 L
.12198 .19406 L
.12607 .18997 L
.13169 .18434 L
.13578 .18025 L
.1414 .17463 L
.14549 .17054 L
.15112 .16492 L
.15521 .16083 L
.16083 .15521 L
.16492 .15112 L
.17054 .14549 L
.17463 .1414 L
.18025 .13578 L
.18434 .13169 L
.18997 .12607 L
.19406 .12198 L
.19968 .11636 L
.20377 .11227 L
.20939 .10664 L
.21348 .10255 L
.2191 .09693 L
.22319 .09284 L
.22882 .08722 L
.23291 .08313 L
.23853 .07751 L
.24262 .07342 L
.24824 .06779 L
.25233 .0637 L
.25795 .05808 L
Mistroke
.26204 .05399 L
.26767 .04837 L
.27176 .04428 L
.27738 .03866 L
.28147 .03457 L
.28709 .02894 L
.29118 .02477 L
.2968 .01923 L
Mfstroke
.4 g
.01923 .21817 m
.02422 .21348 L
.02894 .20846 L
.03364 .20377 L
.03866 .19875 L
.04335 .19406 L
.04837 .18904 L
.05306 .18434 L
.05808 .17932 L
.06277 .17463 L
.06779 .16961 L
.07249 .16492 L
.07751 .1599 L
.0822 .15521 L
.08722 .15019 L
.09191 .14549 L
.09693 .14047 L
.10162 .13578 L
.10664 .13076 L
.11134 .12607 L
.11636 .12105 L
.12105 .11636 L
.12607 .11134 L
.13076 .10664 L
.13578 .10162 L
.14047 .09693 L
.14549 .09191 L
.15019 .08722 L
.15521 .0822 L
.1599 .07751 L
.16492 .07249 L
.16961 .06779 L
.17463 .06277 L
.17932 .05808 L
.18434 .05306 L
.18904 .04837 L
.19406 .04335 L
.19875 .03866 L
.20377 .03364 L
.20846 .02894 L
.21348 .02422 L
.21817 .01923 L
.01923 .01923 L
F
0 g
.01923 .21817 m
.02422 .21348 L
.02894 .20846 L
.03364 .20377 L
.03866 .19875 L
.04335 .19406 L
.04837 .18904 L
.05306 .18434 L
.05808 .17932 L
.06277 .17463 L
.06779 .16961 L
.07249 .16492 L
.07751 .1599 L
.0822 .15521 L
.08722 .15019 L
.09191 .14549 L
.09693 .14047 L
.10162 .13578 L
.10664 .13076 L
.11134 .12607 L
.11636 .12105 L
.12105 .11636 L
.12607 .11134 L
.13076 .10664 L
.13578 .10162 L
.14047 .09693 L
.14549 .09191 L
.15019 .08722 L
.15521 .0822 L
.1599 .07751 L
.16492 .07249 L
.16961 .06779 L
.17463 .06277 L
.17932 .05808 L
.18434 .05306 L
.18904 .04837 L
.19406 .04335 L
.19875 .03866 L
.20377 .03364 L
.20846 .02894 L
.21348 .02422 L
.21817 .01923 L
s
.5 g
.01923 .1745 m
.02882 .16492 L
.02894 .16479 L
.03853 .15521 L
.03866 .15508 L
.04824 .14549 L
.04837 .14537 L
.05795 .13578 L
.05808 .13565 L
.06767 .12607 L
.06779 .12594 L
.07738 .11636 L
.07751 .11623 L
.08709 .10664 L
.08722 .10652 L
.0968 .09693 L
.09693 .0968 L
.10652 .08722 L
.10664 .08709 L
.11623 .07751 L
.11636 .07738 L
.12594 .06779 L
.12607 .06767 L
.13565 .05808 L
.13578 .05795 L
.14537 .04837 L
.14549 .04824 L
.15508 .03866 L
.15521 .03853 L
.16479 .02894 L
.16492 .02882 L
.1745 .01923 L
.01923 .01923 L
F
0 g
.01923 .1745 m
.02882 .16492 L
.02894 .16479 L
.03853 .15521 L
.03866 .15508 L
.04824 .14549 L
.04837 .14537 L
.05795 .13578 L
.05808 .13565 L
.06767 .12607 L
.06779 .12594 L
.07738 .11636 L
.07751 .11623 L
.08709 .10664 L
.08722 .10652 L
.0968 .09693 L
.09693 .0968 L
.10652 .08722 L
.10664 .08709 L
.11623 .07751 L
.11636 .07738 L
.12594 .06779 L
.12607 .06767 L
.13565 .05808 L
.13578 .05795 L
.14537 .04837 L
.14549 .04824 L
.15508 .03866 L
.15521 .03853 L
.16479 .02894 L
.16492 .02882 L
.1745 .01923 L
s
.6 g
.01923 .13909 m
.02254 .13578 L
.02894 .12938 L
.03225 .12607 L
.03866 .11967 L
.04197 .11636 L
.04837 .10995 L
.05168 .10664 L
.05808 .10024 L
.06139 .09693 L
.06779 .09053 L
.0711 .08722 L
.07751 .08082 L
.08082 .07751 L
.08722 .0711 L
.09053 .06779 L
.09693 .06139 L
.10024 .05808 L
.10664 .05168 L
.10995 .04837 L
.11636 .04197 L
.11967 .03866 L
.12607 .03225 L
.12938 .02894 L
.13578 .02254 L
.13909 .01923 L
.01923 .01923 L
F
0 g
.01923 .13909 m
.02254 .13578 L
.02894 .12938 L
.03225 .12607 L
.03866 .11967 L
.04197 .11636 L
.04837 .10995 L
.05168 .10664 L
.05808 .10024 L
.06139 .09693 L
.06779 .09053 L
.0711 .08722 L
.07751 .08082 L
.08082 .07751 L
.08722 .0711 L
.09053 .06779 L
.09693 .06139 L
.10024 .05808 L
.10664 .05168 L
.10995 .04837 L
.11636 .04197 L
.11967 .03866 L
.12607 .03225 L
.12938 .02894 L
.13578 .02254 L
.13909 .01923 L
s
.7 g
.01923 .0954 m
.02737 .08722 L
.02894 .08569 L
.03713 .07751 L
.03866 .07598 L
.04684 .06779 L
.04837 .06627 L
.05655 .05808 L
.05808 .05655 L
.06627 .04837 L
.06779 .04684 L
.07598 .03866 L
.07751 .03713 L
.08569 .02894 L
.08722 .02737 L
.0954 .01923 L
.01923 .01923 L
F
0 g
.01923 .0954 m
.02737 .08722 L
.02894 .08569 L
.03713 .07751 L
.03866 .07598 L
.04684 .06779 L
.04837 .06627 L
.05655 .05808 L
.05808 .05655 L
.06627 .04837 L
.06779 .04684 L
.07598 .03866 L
.07751 .03713 L
.08569 .02894 L
.08722 .02737 L
.0954 .01923 L
s
.3 g
.06217 .98077 m
.06779 .97523 L
.07188 .97106 L
.07751 .96543 L
.08159 .96134 L
.08722 .95572 L
.09131 .95163 L
.09693 .94601 L
.10102 .94192 L
.10664 .9363 L
.11073 .93221 L
.11636 .92658 L
.12044 .92249 L
.12607 .91687 L
.13016 .91278 L
.13578 .90716 L
.13987 .90307 L
.14549 .89745 L
.14958 .89336 L
.15521 .88773 L
.15929 .88364 L
.16492 .87802 L
.16901 .87393 L
.17463 .86831 L
.17872 .86422 L
.18434 .8586 L
.18843 .85451 L
.19406 .84888 L
.19814 .84479 L
.20377 .83917 L
.20786 .83508 L
.21348 .82946 L
.21757 .82537 L
.22319 .81975 L
.22728 .81566 L
.23291 .81003 L
.23699 .80594 L
.24262 .80032 L
.24671 .79623 L
.25233 .79061 L
.25642 .78652 L
.26204 .7809 L
.26613 .77681 L
.27176 .77118 L
.27585 .76709 L
.28147 .76147 L
.28556 .75738 L
.29118 .75176 L
.29527 .74767 L
.30089 .74205 L
.30498 .73796 L
.31061 .73233 L
.3147 .72824 L
.32032 .72262 L
.32441 .71853 L
.33003 .71291 L
.33442 .70882 L
.33974 .7032 L
.34292 .69911 L
.34946 .6901 L
.34998 .68939 L
.35713 .67968 L
.35917 .67688 L
.36419 .66997 L
.36888 .66344 L
.37115 .66026 L
.37802 .65054 L
.37859 .64972 L
.38474 .64083 L
.38831 .63562 L
.39134 .63112 L
.39787 .62141 L
.39802 .62118 L
.40423 .61169 L
.40773 .60632 L
.4105 .60198 L
.4167 .59227 L
.41744 .59109 L
.42274 .58256 L
.42716 .57544 L
.42872 .57284 L
.43462 .56313 L
.43687 .55941 L
.4404 .55342 L
.44616 .54371 L
.44658 .543 L
.45177 .53399 L
.45629 .52618 L
.45735 .52428 L
.46284 .51457 L
.46601 .50898 L
.46826 .50486 L
.47365 .49514 L
.47572 .4914 L
.47892 .48543 L
.4842 .47572 L
.48543 .47345 L
.48934 .46601 L
.49453 .45629 L
.49514 .45513 L
.49955 .44658 L
.50464 .43687 L
.50486 .43644 L
.50955 .42716 L
.51455 .41744 L
.51457 .4174 L
.51936 .40773 L
.52427 .39802 L
.52428 .398 L
.529 .38831 L
.53382 .37859 L
.53399 .37824 L
.53847 .36888 L
.54321 .35917 L
.54371 .35815 L
.54778 .34946 L
.55245 .33974 L
.55342 .33771 L
.55694 .33003 L
.56154 .32032 L
.56313 .31693 L
.56597 .31061 L
.57049 .30089 L
.57284 .29583 L
.57488 .29118 L
.57932 .28147 L
.58256 .27441 L
.58369 .27176 L
.58802 .26204 L
.59227 .25266 L
.59241 .25233 L
.59661 .24262 L
.60095 .23291 L
.60198 .23059 L
.6051 .22319 L
.60938 .21348 L
.61169 .20821 L
.61351 .20377 L
.6177 .19406 L
.62141 .18552 L
.62187 .18434 L
.62592 .17463 L
.6301 .16492 L
.63112 .16253 L
.63407 .15521 L
.63818 .14549 L
.64083 .13923 L
.64217 .13578 L
.64617 .12607 L
.65024 .11636 L
.65054 .11563 L
.65409 .10664 L
.65811 .09693 L
.66026 .09174 L
.66197 .08722 L
.66589 .07751 L
.66987 .06779 L
.66997 .06756 L
.67361 .05808 L
.67755 .04837 L
.67968 .04308 L
.68131 .03866 L
.68514 .02894 L
.68903 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.06217 .98077 m
.06779 .97523 L
.07188 .97106 L
.07751 .96543 L
.08159 .96134 L
.08722 .95572 L
.09131 .95163 L
.09693 .94601 L
.10102 .94192 L
.10664 .9363 L
.11073 .93221 L
.11636 .92658 L
.12044 .92249 L
.12607 .91687 L
.13016 .91278 L
.13578 .90716 L
.13987 .90307 L
.14549 .89745 L
.14958 .89336 L
.15521 .88773 L
.15929 .88364 L
.16492 .87802 L
.16901 .87393 L
.17463 .86831 L
.17872 .86422 L
.18434 .8586 L
.18843 .85451 L
.19406 .84888 L
.19814 .84479 L
.20377 .83917 L
.20786 .83508 L
.21348 .82946 L
.21757 .82537 L
.22319 .81975 L
.22728 .81566 L
.23291 .81003 L
.23699 .80594 L
.24262 .80032 L
.24671 .79623 L
.25233 .79061 L
.25642 .78652 L
.26204 .7809 L
.26613 .77681 L
.27176 .77118 L
.27585 .76709 L
.28147 .76147 L
.28556 .75738 L
.29118 .75176 L
.29527 .74767 L
.30089 .74205 L
Mistroke
.30498 .73796 L
.31061 .73233 L
.3147 .72824 L
.32032 .72262 L
.32441 .71853 L
.33003 .71291 L
.33442 .70882 L
.33974 .7032 L
.34292 .69911 L
.34946 .6901 L
.34998 .68939 L
.35713 .67968 L
.35917 .67688 L
.36419 .66997 L
.36888 .66344 L
.37115 .66026 L
.37802 .65054 L
.37859 .64972 L
.38474 .64083 L
.38831 .63562 L
.39134 .63112 L
.39787 .62141 L
.39802 .62118 L
.40423 .61169 L
.40773 .60632 L
.4105 .60198 L
.4167 .59227 L
.41744 .59109 L
.42274 .58256 L
.42716 .57544 L
.42872 .57284 L
.43462 .56313 L
.43687 .55941 L
.4404 .55342 L
.44616 .54371 L
.44658 .543 L
.45177 .53399 L
.45629 .52618 L
.45735 .52428 L
.46284 .51457 L
.46601 .50898 L
.46826 .50486 L
.47365 .49514 L
.47572 .4914 L
.47892 .48543 L
.4842 .47572 L
.48543 .47345 L
.48934 .46601 L
.49453 .45629 L
.49514 .45513 L
Mistroke
.49955 .44658 L
.50464 .43687 L
.50486 .43644 L
.50955 .42716 L
.51455 .41744 L
.51457 .4174 L
.51936 .40773 L
.52427 .39802 L
.52428 .398 L
.529 .38831 L
.53382 .37859 L
.53399 .37824 L
.53847 .36888 L
.54321 .35917 L
.54371 .35815 L
.54778 .34946 L
.55245 .33974 L
.55342 .33771 L
.55694 .33003 L
.56154 .32032 L
.56313 .31693 L
.56597 .31061 L
.57049 .30089 L
.57284 .29583 L
.57488 .29118 L
.57932 .28147 L
.58256 .27441 L
.58369 .27176 L
.58802 .26204 L
.59227 .25266 L
.59241 .25233 L
.59661 .24262 L
.60095 .23291 L
.60198 .23059 L
.6051 .22319 L
.60938 .21348 L
.61169 .20821 L
.61351 .20377 L
.6177 .19406 L
.62141 .18552 L
.62187 .18434 L
.62592 .17463 L
.6301 .16492 L
.63112 .16253 L
.63407 .15521 L
.63818 .14549 L
.64083 .13923 L
.64217 .13578 L
.64617 .12607 L
.65024 .11636 L
Mistroke
.65054 .11563 L
.65409 .10664 L
.65811 .09693 L
.66026 .09174 L
.66197 .08722 L
.66589 .07751 L
.66987 .06779 L
.66997 .06756 L
.67361 .05808 L
.67755 .04837 L
.67968 .04308 L
.68131 .03866 L
.68514 .02894 L
.68903 .01923 L
Mfstroke
.4 g
.1408 .98077 m
.14549 .97578 L
.15051 .97106 L
.15521 .96636 L
.16023 .96134 L
.16492 .95665 L
.16994 .95163 L
.17463 .94694 L
.17965 .94192 L
.18434 .93723 L
.18936 .93221 L
.19406 .92751 L
.19908 .92249 L
.20377 .9178 L
.20879 .91278 L
.21348 .90809 L
.2185 .90307 L
.22319 .89838 L
.22821 .89336 L
.23291 .88866 L
.23793 .88364 L
.24262 .87895 L
.24764 .87393 L
.25233 .86924 L
.25735 .86422 L
.26204 .85953 L
.26706 .85451 L
.27176 .84981 L
.27678 .84479 L
.28147 .8401 L
.28649 .83508 L
.29118 .83039 L
.2962 .82537 L
.30089 .82068 L
.30591 .81566 L
.31061 .81096 L
.31563 .80594 L
.32032 .80125 L
.32534 .79623 L
.33003 .79154 L
.33495 .78652 L
.33974 .78183 L
.34637 .77681 L
.34946 .7748 L
.35862 .76709 L
.35917 .76647 L
.36864 .75738 L
.36888 .75709 L
.37788 .74767 L
.37859 .74681 L
.38651 .73796 L
.38831 .73572 L
.39463 .72824 L
.39802 .72388 L
.40232 .71853 L
.40773 .71135 L
.40968 .70882 L
.41683 .69911 L
.41744 .6982 L
.42382 .68939 L
.42716 .68446 L
.43051 .67968 L
.43687 .67014 L
.43699 .66997 L
.44349 .66026 L
.44658 .65532 L
.44969 .65054 L
.45578 .64083 L
.45629 .63995 L
.46185 .63112 L
.46601 .62411 L
.46767 .62141 L
.47351 .61169 L
.47572 .60779 L
.47918 .60198 L
.48475 .59227 L
.48543 .59101 L
.49033 .58256 L
.49514 .57379 L
.49568 .57284 L
.50115 .56313 L
.50486 .55614 L
.50636 .55342 L
.51167 .54371 L
.51457 .53807 L
.51677 .53399 L
.52194 .52428 L
.52428 .51959 L
.52694 .51457 L
.53198 .50486 L
.53399 .50071 L
.53689 .49514 L
.54182 .48543 L
.54371 .48145 L
.54662 .47572 L
.55146 .46601 L
.55342 .4618 L
.55617 .45629 L
.56094 .44658 L
.56313 .44179 L
.56555 .43687 L
.57024 .42716 L
.57284 .4214 L
.57475 .41744 L
.5794 .40773 L
.58256 .40066 L
.58381 .39802 L
.5884 .38831 L
.59227 .37957 L
.59272 .37859 L
.59726 .36888 L
.60156 .35917 L
.60198 .35814 L
.60598 .34946 L
.6103 .33974 L
.61169 .33637 L
.61457 .33003 L
.6189 .32032 L
.62141 .31426 L
.62304 .31061 L
.62736 .30089 L
.63112 .29182 L
.6314 .29118 L
.63568 .28147 L
.63979 .27176 L
.64083 .26907 L
.64389 .26204 L
.64804 .25233 L
.65054 .246 L
.65199 .24262 L
.65615 .23291 L
.66004 .22319 L
.66026 .2226 L
.66412 .21348 L
.66814 .20377 L
.66997 .19891 L
.672 .19406 L
.67604 .18434 L
.67968 .17491 L
.67979 .17463 L
.68381 .16492 L
.68772 .15521 L
.68939 .15061 L
.69148 .14549 L
.69544 .13578 L
.69909 .12607 L
.69911 .12601 L
.70301 .11636 L
.70684 .10664 L
.70882 .10112 L
.71049 .09693 L
.71437 .08722 L
.71801 .07751 L
.71853 .07594 L
.72175 .06779 L
.72554 .05808 L
.72824 .05047 L
.72906 .04837 L
.73287 .03866 L
.73653 .02894 L
.73796 .02471 L
.74008 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.1408 .98077 m
.14549 .97578 L
.15051 .97106 L
.15521 .96636 L
.16023 .96134 L
.16492 .95665 L
.16994 .95163 L
.17463 .94694 L
.17965 .94192 L
.18434 .93723 L
.18936 .93221 L
.19406 .92751 L
.19908 .92249 L
.20377 .9178 L
.20879 .91278 L
.21348 .90809 L
.2185 .90307 L
.22319 .89838 L
.22821 .89336 L
.23291 .88866 L
.23793 .88364 L
.24262 .87895 L
.24764 .87393 L
.25233 .86924 L
.25735 .86422 L
.26204 .85953 L
.26706 .85451 L
.27176 .84981 L
.27678 .84479 L
.28147 .8401 L
.28649 .83508 L
.29118 .83039 L
.2962 .82537 L
.30089 .82068 L
.30591 .81566 L
.31061 .81096 L
.31563 .80594 L
.32032 .80125 L
.32534 .79623 L
.33003 .79154 L
.33495 .78652 L
.33974 .78183 L
.34637 .77681 L
.34946 .7748 L
.35862 .76709 L
.35917 .76647 L
.36864 .75738 L
.36888 .75709 L
.37788 .74767 L
.37859 .74681 L
Mistroke
.38651 .73796 L
.38831 .73572 L
.39463 .72824 L
.39802 .72388 L
.40232 .71853 L
.40773 .71135 L
.40968 .70882 L
.41683 .69911 L
.41744 .6982 L
.42382 .68939 L
.42716 .68446 L
.43051 .67968 L
.43687 .67014 L
.43699 .66997 L
.44349 .66026 L
.44658 .65532 L
.44969 .65054 L
.45578 .64083 L
.45629 .63995 L
.46185 .63112 L
.46601 .62411 L
.46767 .62141 L
.47351 .61169 L
.47572 .60779 L
.47918 .60198 L
.48475 .59227 L
.48543 .59101 L
.49033 .58256 L
.49514 .57379 L
.49568 .57284 L
.50115 .56313 L
.50486 .55614 L
.50636 .55342 L
.51167 .54371 L
.51457 .53807 L
.51677 .53399 L
.52194 .52428 L
.52428 .51959 L
.52694 .51457 L
.53198 .50486 L
.53399 .50071 L
.53689 .49514 L
.54182 .48543 L
.54371 .48145 L
.54662 .47572 L
.55146 .46601 L
.55342 .4618 L
.55617 .45629 L
.56094 .44658 L
.56313 .44179 L
Mistroke
.56555 .43687 L
.57024 .42716 L
.57284 .4214 L
.57475 .41744 L
.5794 .40773 L
.58256 .40066 L
.58381 .39802 L
.5884 .38831 L
.59227 .37957 L
.59272 .37859 L
.59726 .36888 L
.60156 .35917 L
.60198 .35814 L
.60598 .34946 L
.6103 .33974 L
.61169 .33637 L
.61457 .33003 L
.6189 .32032 L
.62141 .31426 L
.62304 .31061 L
.62736 .30089 L
.63112 .29182 L
.6314 .29118 L
.63568 .28147 L
.63979 .27176 L
.64083 .26907 L
.64389 .26204 L
.64804 .25233 L
.65054 .246 L
.65199 .24262 L
.65615 .23291 L
.66004 .22319 L
.66026 .2226 L
.66412 .21348 L
.66814 .20377 L
.66997 .19891 L
.672 .19406 L
.67604 .18434 L
.67968 .17491 L
.67979 .17463 L
.68381 .16492 L
.68772 .15521 L
.68939 .15061 L
.69148 .14549 L
.69544 .13578 L
.69909 .12607 L
.69911 .12601 L
.70301 .11636 L
.70684 .10664 L
.70882 .10112 L
Mistroke
.71049 .09693 L
.71437 .08722 L
.71801 .07751 L
.71853 .07594 L
.72175 .06779 L
.72554 .05808 L
.72824 .05047 L
.72906 .04837 L
.73287 .03866 L
.73653 .02894 L
.73796 .02471 L
.74008 .01923 L
Mfstroke
.5 g
.18447 .98077 m
.19406 .97118 L
.19418 .97106 L
.20377 .96147 L
.2039 .96134 L
.21348 .95176 L
.21361 .95163 L
.22319 .94205 L
.22332 .94192 L
.23291 .93233 L
.23303 .93221 L
.24262 .92262 L
.24275 .92249 L
.25233 .91291 L
.25246 .91278 L
.26204 .9032 L
.26217 .90307 L
.27176 .89348 L
.27188 .89336 L
.28147 .88377 L
.2816 .88364 L
.29118 .87406 L
.29131 .87393 L
.30089 .86435 L
.30102 .86422 L
.31061 .85463 L
.31073 .85451 L
.32032 .84492 L
.32045 .84479 L
.33003 .83521 L
.33016 .83508 L
.33974 .8255 L
.33987 .82537 L
.34946 .81605 L
.34985 .81566 L
.35906 .80594 L
.35917 .80583 L
.36773 .79623 L
.36888 .79488 L
.37595 .78652 L
.37859 .78327 L
.3838 .77681 L
.38831 .77104 L
.39135 .76709 L
.39802 .7582 L
.39863 .75738 L
.4057 .74767 L
.40773 .74481 L
.41257 .73796 L
.41744 .73088 L
.41925 .72824 L
.42577 .71853 L
.42716 .71643 L
.43216 .70882 L
.43687 .70148 L
.43839 .69911 L
.44452 .68939 L
.44658 .68606 L
.45053 .67968 L
.45629 .67016 L
.45641 .66997 L
.46223 .66026 L
.46601 .65382 L
.46793 .65054 L
.47356 .64083 L
.47572 .63704 L
.4791 .63112 L
.48456 .62141 L
.48543 .61983 L
.48996 .61169 L
.49514 .60221 L
.49527 .60198 L
.50055 .59227 L
.50486 .58418 L
.50572 .58256 L
.51088 .57284 L
.51457 .56576 L
.51594 .56313 L
.52098 .55342 L
.52428 .54694 L
.52594 .54371 L
.53088 .53399 L
.53399 .52775 L
.53574 .52428 L
.54058 .51457 L
.54371 .50819 L
.54535 .50486 L
.5501 .49514 L
.55342 .48826 L
.55479 .48543 L
.55946 .47572 L
.56313 .46797 L
.56406 .46601 L
.56867 .45629 L
.57284 .44733 L
.57319 .44658 L
.57773 .43687 L
.58219 .42716 L
.58256 .42634 L
.58665 .41744 L
.59106 .40773 L
.59227 .40502 L
.59544 .39802 L
.5998 .38831 L
.60198 .38335 L
.60411 .37859 L
.60842 .36888 L
.61169 .36136 L
.61266 .35917 L
.61692 .34946 L
.62111 .33974 L
.62141 .33905 L
.62531 .33003 L
.62948 .32032 L
.63112 .31642 L
.6336 .31061 L
.63773 .30089 L
.64083 .29347 L
.64179 .29118 L
.64588 .28147 L
.64991 .27176 L
.65054 .27021 L
.65394 .26204 L
.65795 .25233 L
.66026 .24664 L
.66191 .24262 L
.66589 .23291 L
.6698 .22319 L
.66997 .22277 L
.67374 .21348 L
.67764 .20377 L
.67968 .1986 L
.6815 .19406 L
.68539 .18434 L
.6892 .17463 L
.68939 .17414 L
.69305 .16492 L
.69686 .15521 L
.69911 .14938 L
.70063 .14549 L
.70443 .13578 L
.70817 .12607 L
.70882 .12434 L
.71191 .11636 L
.71565 .10664 L
.71853 .09901 L
.71933 .09693 L
.72305 .08722 L
.72672 .07751 L
.72824 .0734 L
.73037 .06779 L
.73404 .05808 L
.73765 .04837 L
.73796 .04751 L
.74128 .03866 L
.7449 .02894 L
.74767 .02135 L
.74845 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.18447 .98077 m
.19406 .97118 L
.19418 .97106 L
.20377 .96147 L
.2039 .96134 L
.21348 .95176 L
.21361 .95163 L
.22319 .94205 L
.22332 .94192 L
.23291 .93233 L
.23303 .93221 L
.24262 .92262 L
.24275 .92249 L
.25233 .91291 L
.25246 .91278 L
.26204 .9032 L
.26217 .90307 L
.27176 .89348 L
.27188 .89336 L
.28147 .88377 L
.2816 .88364 L
.29118 .87406 L
.29131 .87393 L
.30089 .86435 L
.30102 .86422 L
.31061 .85463 L
.31073 .85451 L
.32032 .84492 L
.32045 .84479 L
.33003 .83521 L
.33016 .83508 L
.33974 .8255 L
.33987 .82537 L
.34946 .81605 L
.34985 .81566 L
.35906 .80594 L
.35917 .80583 L
.36773 .79623 L
.36888 .79488 L
.37595 .78652 L
.37859 .78327 L
.3838 .77681 L
.38831 .77104 L
.39135 .76709 L
.39802 .7582 L
.39863 .75738 L
.4057 .74767 L
.40773 .74481 L
.41257 .73796 L
.41744 .73088 L
Mistroke
.41925 .72824 L
.42577 .71853 L
.42716 .71643 L
.43216 .70882 L
.43687 .70148 L
.43839 .69911 L
.44452 .68939 L
.44658 .68606 L
.45053 .67968 L
.45629 .67016 L
.45641 .66997 L
.46223 .66026 L
.46601 .65382 L
.46793 .65054 L
.47356 .64083 L
.47572 .63704 L
.4791 .63112 L
.48456 .62141 L
.48543 .61983 L
.48996 .61169 L
.49514 .60221 L
.49527 .60198 L
.50055 .59227 L
.50486 .58418 L
.50572 .58256 L
.51088 .57284 L
.51457 .56576 L
.51594 .56313 L
.52098 .55342 L
.52428 .54694 L
.52594 .54371 L
.53088 .53399 L
.53399 .52775 L
.53574 .52428 L
.54058 .51457 L
.54371 .50819 L
.54535 .50486 L
.5501 .49514 L
.55342 .48826 L
.55479 .48543 L
.55946 .47572 L
.56313 .46797 L
.56406 .46601 L
.56867 .45629 L
.57284 .44733 L
.57319 .44658 L
.57773 .43687 L
.58219 .42716 L
.58256 .42634 L
.58665 .41744 L
Mistroke
.59106 .40773 L
.59227 .40502 L
.59544 .39802 L
.5998 .38831 L
.60198 .38335 L
.60411 .37859 L
.60842 .36888 L
.61169 .36136 L
.61266 .35917 L
.61692 .34946 L
.62111 .33974 L
.62141 .33905 L
.62531 .33003 L
.62948 .32032 L
.63112 .31642 L
.6336 .31061 L
.63773 .30089 L
.64083 .29347 L
.64179 .29118 L
.64588 .28147 L
.64991 .27176 L
.65054 .27021 L
.65394 .26204 L
.65795 .25233 L
.66026 .24664 L
.66191 .24262 L
.66589 .23291 L
.6698 .22319 L
.66997 .22277 L
.67374 .21348 L
.67764 .20377 L
.67968 .1986 L
.6815 .19406 L
.68539 .18434 L
.6892 .17463 L
.68939 .17414 L
.69305 .16492 L
.69686 .15521 L
.69911 .14938 L
.70063 .14549 L
.70443 .13578 L
.70817 .12607 L
.70882 .12434 L
.71191 .11636 L
.71565 .10664 L
.71853 .09901 L
.71933 .09693 L
.72305 .08722 L
.72672 .07751 L
.72824 .0734 L
Mistroke
.73037 .06779 L
.73404 .05808 L
.73765 .04837 L
.73796 .04751 L
.74128 .03866 L
.7449 .02894 L
.74767 .02135 L
.74845 .01923 L
Mfstroke
.6 g
.21988 .98077 m
.22319 .97746 L
.2296 .97106 L
.23291 .96775 L
.23931 .96134 L
.24262 .95803 L
.24902 .95163 L
.25233 .94832 L
.25873 .94192 L
.26204 .93861 L
.26845 .93221 L
.27176 .9289 L
.27816 .92249 L
.28147 .91918 L
.28787 .91278 L
.29118 .90947 L
.29758 .90307 L
.30089 .89976 L
.3073 .89336 L
.31061 .89005 L
.31701 .88364 L
.32032 .88033 L
.32672 .87393 L
.33003 .87062 L
.33652 .86422 L
.33974 .86091 L
.34561 .85451 L
.34946 .85021 L
.35418 .84479 L
.35917 .83892 L
.36237 .83508 L
.36888 .82706 L
.37023 .82537 L
.37782 .81566 L
.37859 .81464 L
.38516 .80594 L
.38831 .80169 L
.39229 .79623 L
.39802 .78822 L
.39922 .78652 L
.40598 .77681 L
.40773 .77425 L
.41258 .76709 L
.41744 .75979 L
.41903 .75738 L
.42535 .74767 L
.42716 .74486 L
.43155 .73796 L
.43687 .72947 L
.43763 .72824 L
.4436 .71853 L
.44658 .71363 L
.44948 .70882 L
.45526 .69911 L
.45629 .69735 L
.46095 .68939 L
.46601 .68065 L
.46656 .67968 L
.47209 .66997 L
.47572 .66353 L
.47755 .66026 L
.48294 .65054 L
.48543 .64601 L
.48825 .64083 L
.49352 .63112 L
.49514 .62809 L
.49871 .62141 L
.50385 .61169 L
.50486 .60978 L
.50892 .60198 L
.51396 .59227 L
.51457 .59108 L
.51893 .58256 L
.52386 .57284 L
.52428 .57202 L
.52874 .56313 L
.53358 .55342 L
.53399 .55258 L
.53836 .54371 L
.54312 .53399 L
.54371 .53279 L
.54782 .52428 L
.55249 .51457 L
.55342 .51264 L
.55711 .50486 L
.56172 .49514 L
.56313 .49214 L
.56626 .48543 L
.57079 .47572 L
.57284 .47129 L
.57527 .46601 L
.57973 .45629 L
.58256 .45011 L
.58415 .44658 L
.58855 .43687 L
.59227 .4286 L
.59291 .42716 L
.59724 .41744 L
.60155 .40773 L
.60198 .40676 L
.60581 .39802 L
.61008 .38831 L
.61169 .3846 L
.61428 .37859 L
.61849 .36888 L
.62141 .36211 L
.62266 .35917 L
.6268 .34946 L
.63094 .33974 L
.63112 .33932 L
.63502 .33003 L
.63911 .32032 L
.64083 .31621 L
.64315 .31061 L
.64719 .30089 L
.65054 .2928 L
.6512 .29118 L
.65519 .28147 L
.65917 .27176 L
.66026 .26909 L
.6631 .26204 L
.66704 .25233 L
.66997 .24508 L
.67095 .24262 L
.67483 .23291 L
.67872 .22319 L
.67968 .22078 L
.68255 .21348 L
.6864 .20377 L
.68939 .19618 L
.69021 .19406 L
.69401 .18434 L
.69781 .17463 L
.69911 .17129 L
.70155 .16492 L
.70532 .15521 L
.70882 .14613 L
.70906 .14549 L
.71276 .13578 L
.71648 .12607 L
.71853 .12068 L
.72015 .11636 L
.72382 .10664 L
.7275 .09693 L
.72824 .09495 L
.73111 .08722 L
.73476 .07751 L
.73796 .06895 L
.73838 .06779 L
.74196 .05808 L
.74557 .04837 L
.74767 .04267 L
.74912 .03866 L
.75268 .02894 L
.75625 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.21988 .98077 m
.22319 .97746 L
.2296 .97106 L
.23291 .96775 L
.23931 .96134 L
.24262 .95803 L
.24902 .95163 L
.25233 .94832 L
.25873 .94192 L
.26204 .93861 L
.26845 .93221 L
.27176 .9289 L
.27816 .92249 L
.28147 .91918 L
.28787 .91278 L
.29118 .90947 L
.29758 .90307 L
.30089 .89976 L
.3073 .89336 L
.31061 .89005 L
.31701 .88364 L
.32032 .88033 L
.32672 .87393 L
.33003 .87062 L
.33652 .86422 L
.33974 .86091 L
.34561 .85451 L
.34946 .85021 L
.35418 .84479 L
.35917 .83892 L
.36237 .83508 L
.36888 .82706 L
.37023 .82537 L
.37782 .81566 L
.37859 .81464 L
.38516 .80594 L
.38831 .80169 L
.39229 .79623 L
.39802 .78822 L
.39922 .78652 L
.40598 .77681 L
.40773 .77425 L
.41258 .76709 L
.41744 .75979 L
.41903 .75738 L
.42535 .74767 L
.42716 .74486 L
.43155 .73796 L
.43687 .72947 L
.43763 .72824 L
Mistroke
.4436 .71853 L
.44658 .71363 L
.44948 .70882 L
.45526 .69911 L
.45629 .69735 L
.46095 .68939 L
.46601 .68065 L
.46656 .67968 L
.47209 .66997 L
.47572 .66353 L
.47755 .66026 L
.48294 .65054 L
.48543 .64601 L
.48825 .64083 L
.49352 .63112 L
.49514 .62809 L
.49871 .62141 L
.50385 .61169 L
.50486 .60978 L
.50892 .60198 L
.51396 .59227 L
.51457 .59108 L
.51893 .58256 L
.52386 .57284 L
.52428 .57202 L
.52874 .56313 L
.53358 .55342 L
.53399 .55258 L
.53836 .54371 L
.54312 .53399 L
.54371 .53279 L
.54782 .52428 L
.55249 .51457 L
.55342 .51264 L
.55711 .50486 L
.56172 .49514 L
.56313 .49214 L
.56626 .48543 L
.57079 .47572 L
.57284 .47129 L
.57527 .46601 L
.57973 .45629 L
.58256 .45011 L
.58415 .44658 L
.58855 .43687 L
.59227 .4286 L
.59291 .42716 L
.59724 .41744 L
.60155 .40773 L
.60198 .40676 L
Mistroke
.60581 .39802 L
.61008 .38831 L
.61169 .3846 L
.61428 .37859 L
.61849 .36888 L
.62141 .36211 L
.62266 .35917 L
.6268 .34946 L
.63094 .33974 L
.63112 .33932 L
.63502 .33003 L
.63911 .32032 L
.64083 .31621 L
.64315 .31061 L
.64719 .30089 L
.65054 .2928 L
.6512 .29118 L
.65519 .28147 L
.65917 .27176 L
.66026 .26909 L
.6631 .26204 L
.66704 .25233 L
.66997 .24508 L
.67095 .24262 L
.67483 .23291 L
.67872 .22319 L
.67968 .22078 L
.68255 .21348 L
.6864 .20377 L
.68939 .19618 L
.69021 .19406 L
.69401 .18434 L
.69781 .17463 L
.69911 .17129 L
.70155 .16492 L
.70532 .15521 L
.70882 .14613 L
.70906 .14549 L
.71276 .13578 L
.71648 .12607 L
.71853 .12068 L
.72015 .11636 L
.72382 .10664 L
.7275 .09693 L
.72824 .09495 L
.73111 .08722 L
.73476 .07751 L
.73796 .06895 L
.73838 .06779 L
.74196 .05808 L
Mistroke
.74557 .04837 L
.74767 .04267 L
.74912 .03866 L
.75268 .02894 L
.75625 .01923 L
Mfstroke
.7 g
.26357 .98077 m
.27176 .97263 L
.27328 .97106 L
.28147 .96287 L
.28299 .96134 L
.29118 .95316 L
.29271 .95163 L
.30089 .94345 L
.30242 .94192 L
.31061 .93373 L
.31213 .93221 L
.32032 .92402 L
.32184 .92249 L
.33003 .91431 L
.33172 .91278 L
.33974 .9046 L
.34097 .90307 L
.34811 .89336 L
.34946 .89148 L
.35523 .88364 L
.35917 .87826 L
.36232 .87393 L
.36888 .86485 L
.36933 .86422 L
.3762 .85451 L
.37859 .8511 L
.38295 .84479 L
.38831 .83701 L
.38961 .83508 L
.39614 .82537 L
.39802 .82255 L
.40254 .81566 L
.40773 .8077 L
.40885 .80594 L
.41506 .79623 L
.41744 .79246 L
.42113 .78652 L
.42716 .77684 L
.42718 .77681 L
.43306 .76709 L
.43687 .76079 L
.43888 .75738 L
.44464 .74767 L
.44658 .74437 L
.45027 .73796 L
.45591 .72824 L
.45629 .72757 L
.46138 .71853 L
.46601 .71036 L
.46685 .70882 L
.47222 .69911 L
.47572 .69278 L
.47753 .68939 L
.4828 .67968 L
.48543 .67483 L
.48798 .66997 L
.49315 .66026 L
.49514 .65651 L
.49821 .65054 L
.50329 .64083 L
.50486 .63782 L
.50823 .63112 L
.51322 .62141 L
.51457 .61877 L
.51807 .61169 L
.52297 .60198 L
.52428 .59937 L
.52772 .59227 L
.53254 .58256 L
.53399 .57962 L
.53721 .57284 L
.54195 .56313 L
.54371 .55952 L
.54655 .55342 L
.55121 .54371 L
.55342 .53909 L
.55574 .53399 L
.56032 .52428 L
.56313 .51832 L
.5648 .51457 L
.56929 .50486 L
.57284 .49722 L
.57374 .49514 L
.57813 .48543 L
.58256 .4758 L
.58259 .47572 L
.58685 .46601 L
.59126 .45629 L
.59227 .45404 L
.59547 .44658 L
.5998 .43687 L
.60198 .43197 L
.60399 .42716 L
.60824 .41744 L
.61169 .4096 L
.61245 .40773 L
.61657 .39802 L
.6208 .38831 L
.62141 .38691 L
.62482 .37859 L
.62899 .36888 L
.63112 .36391 L
.633 .35917 L
.63708 .34946 L
.64083 .34061 L
.64116 .33974 L
.64509 .33003 L
.64917 .32032 L
.65054 .31701 L
.65304 .31061 L
.65704 .30089 L
.66026 .29312 L
.66098 .29118 L
.66484 .28147 L
.66882 .27176 L
.66997 .26894 L
.67259 .26204 L
.6765 .25233 L
.67968 .24447 L
.68035 .24262 L
.68411 .23291 L
.688 .22319 L
.68939 .21971 L
.69168 .21348 L
.6955 .20377 L
.69911 .19467 L
.69932 .19406 L
.70294 .18434 L
.70675 .17463 L
.70882 .16934 L
.71038 .16492 L
.71408 .15521 L
.71786 .14549 L
.71853 .14375 L
.72138 .13578 L
.7251 .12607 L
.72824 .11788 L
.72875 .11636 L
.73228 .10664 L
.73598 .09693 L
.73796 .09173 L
.73948 .08722 L
.74307 .07751 L
.74674 .06779 L
.74767 .06532 L
.75015 .05808 L
.75375 .04837 L
.75738 .03866 L
.75738 .03865 L
.76072 .02894 L
.76431 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.26357 .98077 m
.27176 .97263 L
.27328 .97106 L
.28147 .96287 L
.28299 .96134 L
.29118 .95316 L
.29271 .95163 L
.30089 .94345 L
.30242 .94192 L
.31061 .93373 L
.31213 .93221 L
.32032 .92402 L
.32184 .92249 L
.33003 .91431 L
.33172 .91278 L
.33974 .9046 L
.34097 .90307 L
.34811 .89336 L
.34946 .89148 L
.35523 .88364 L
.35917 .87826 L
.36232 .87393 L
.36888 .86485 L
.36933 .86422 L
.3762 .85451 L
.37859 .8511 L
.38295 .84479 L
.38831 .83701 L
.38961 .83508 L
.39614 .82537 L
.39802 .82255 L
.40254 .81566 L
.40773 .8077 L
.40885 .80594 L
.41506 .79623 L
.41744 .79246 L
.42113 .78652 L
.42716 .77684 L
.42718 .77681 L
.43306 .76709 L
.43687 .76079 L
.43888 .75738 L
.44464 .74767 L
.44658 .74437 L
.45027 .73796 L
.45591 .72824 L
.45629 .72757 L
.46138 .71853 L
.46601 .71036 L
.46685 .70882 L
Mistroke
.47222 .69911 L
.47572 .69278 L
.47753 .68939 L
.4828 .67968 L
.48543 .67483 L
.48798 .66997 L
.49315 .66026 L
.49514 .65651 L
.49821 .65054 L
.50329 .64083 L
.50486 .63782 L
.50823 .63112 L
.51322 .62141 L
.51457 .61877 L
.51807 .61169 L
.52297 .60198 L
.52428 .59937 L
.52772 .59227 L
.53254 .58256 L
.53399 .57962 L
.53721 .57284 L
.54195 .56313 L
.54371 .55952 L
.54655 .55342 L
.55121 .54371 L
.55342 .53909 L
.55574 .53399 L
.56032 .52428 L
.56313 .51832 L
.5648 .51457 L
.56929 .50486 L
.57284 .49722 L
.57374 .49514 L
.57813 .48543 L
.58256 .4758 L
.58259 .47572 L
.58685 .46601 L
.59126 .45629 L
.59227 .45404 L
.59547 .44658 L
.5998 .43687 L
.60198 .43197 L
.60399 .42716 L
.60824 .41744 L
.61169 .4096 L
.61245 .40773 L
.61657 .39802 L
.6208 .38831 L
.62141 .38691 L
.62482 .37859 L
Mistroke
.62899 .36888 L
.63112 .36391 L
.633 .35917 L
.63708 .34946 L
.64083 .34061 L
.64116 .33974 L
.64509 .33003 L
.64917 .32032 L
.65054 .31701 L
.65304 .31061 L
.65704 .30089 L
.66026 .29312 L
.66098 .29118 L
.66484 .28147 L
.66882 .27176 L
.66997 .26894 L
.67259 .26204 L
.6765 .25233 L
.67968 .24447 L
.68035 .24262 L
.68411 .23291 L
.688 .22319 L
.68939 .21971 L
.69168 .21348 L
.6955 .20377 L
.69911 .19467 L
.69932 .19406 L
.70294 .18434 L
.70675 .17463 L
.70882 .16934 L
.71038 .16492 L
.71408 .15521 L
.71786 .14549 L
.71853 .14375 L
.72138 .13578 L
.7251 .12607 L
.72824 .11788 L
.72875 .11636 L
.73228 .10664 L
.73598 .09693 L
.73796 .09173 L
.73948 .08722 L
.74307 .07751 L
.74674 .06779 L
.74767 .06532 L
.75015 .05808 L
.75375 .04837 L
.75738 .03866 L
.75738 .03865 L
.76072 .02894 L
Mistroke
.76431 .01923 L
Mfstroke
.6 g
.34277 .98077 m
.34946 .97597 L
.35595 .97106 L
.35917 .96787 L
.36625 .96134 L
.36888 .9585 L
.37562 .95163 L
.37859 .94821 L
.38431 .94192 L
.38831 .9371 L
.39249 .93221 L
.39802 .92526 L
.40026 .92249 L
.40769 .91278 L
.40773 .91273 L
.41502 .90307 L
.41744 .89959 L
.42199 .89336 L
.42716 .88584 L
.4287 .88364 L
.43534 .87393 L
.43687 .87154 L
.4418 .86422 L
.44658 .85669 L
.44801 .85451 L
.45423 .84479 L
.45629 .84134 L
.46025 .83508 L
.46601 .82549 L
.46608 .82537 L
.472 .81566 L
.47572 .80918 L
.47765 .80594 L
.48333 .79623 L
.48543 .7924 L
.48884 .78652 L
.49429 .77681 L
.49514 .77517 L
.49971 .76709 L
.50486 .75752 L
.50493 .75738 L
.51029 .74767 L
.51457 .73945 L
.51538 .73796 L
.5206 .72824 L
.52428 .72097 L
.52557 .71853 L
.53067 .70882 L
.53399 .7021 L
.53555 .69911 L
.54054 .68939 L
.54371 .68283 L
.54531 .67968 L
.55021 .66997 L
.55342 .66319 L
.55488 .66026 L
.5597 .65054 L
.56313 .64317 L
.56428 .64083 L
.56902 .63112 L
.57284 .62278 L
.57351 .62141 L
.57818 .61169 L
.58256 .60204 L
.58258 .60198 L
.58719 .59227 L
.5916 .58256 L
.59227 .58096 L
.59606 .57284 L
.60047 .56313 L
.60198 .55952 L
.60479 .55342 L
.60919 .54371 L
.61169 .53775 L
.6134 .53399 L
.61777 .52428 L
.62141 .51564 L
.62188 .51457 L
.62622 .50486 L
.63036 .49514 L
.63112 .49321 L
.63455 .48543 L
.63874 .47572 L
.64083 .47045 L
.64276 .46601 L
.64696 .45629 L
.65054 .44738 L
.65088 .44658 L
.65505 .43687 L
.65906 .42716 L
.66026 .42399 L
.66303 .41744 L
.6671 .40773 L
.66997 .40029 L
.67092 .39802 L
.67498 .38831 L
.67885 .37859 L
.67968 .37629 L
.68275 .36888 L
.68671 .35917 L
.68939 .35199 L
.69043 .34946 L
.6944 .33974 L
.69818 .33003 L
.69911 .3274 L
.70197 .32032 L
.70585 .31061 L
.70882 .3025 L
.70946 .30089 L
.71334 .29118 L
.71709 .28147 L
.71853 .27732 L
.72073 .27176 L
.72456 .26204 L
.72809 .25233 L
.72824 .25185 L
.73186 .24262 L
.73559 .23291 L
.73796 .22611 L
.73908 .22319 L
.74285 .21348 L
.74645 .20377 L
.74767 .20008 L
.74998 .19406 L
.75369 .18434 L
.75711 .17463 L
.75738 .17377 L
.76074 .16492 L
.76439 .15521 L
.76709 .14719 L
.76773 .14549 L
.77139 .13578 L
.77495 .12607 L
.77681 .12035 L
.77829 .11636 L
.78191 .10664 L
.78537 .09693 L
.78652 .09323 L
.78873 .08722 L
.79232 .07751 L
.79565 .06779 L
.79623 .06585 L
.79907 .05808 L
.80261 .04837 L
.80582 .03866 L
.80594 .0382 L
.8093 .02894 L
.81279 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.34277 .98077 m
.34946 .97597 L
.35595 .97106 L
.35917 .96787 L
.36625 .96134 L
.36888 .9585 L
.37562 .95163 L
.37859 .94821 L
.38431 .94192 L
.38831 .9371 L
.39249 .93221 L
.39802 .92526 L
.40026 .92249 L
.40769 .91278 L
.40773 .91273 L
.41502 .90307 L
.41744 .89959 L
.42199 .89336 L
.42716 .88584 L
.4287 .88364 L
.43534 .87393 L
.43687 .87154 L
.4418 .86422 L
.44658 .85669 L
.44801 .85451 L
.45423 .84479 L
.45629 .84134 L
.46025 .83508 L
.46601 .82549 L
.46608 .82537 L
.472 .81566 L
.47572 .80918 L
.47765 .80594 L
.48333 .79623 L
.48543 .7924 L
.48884 .78652 L
.49429 .77681 L
.49514 .77517 L
.49971 .76709 L
.50486 .75752 L
.50493 .75738 L
.51029 .74767 L
.51457 .73945 L
.51538 .73796 L
.5206 .72824 L
.52428 .72097 L
.52557 .71853 L
.53067 .70882 L
.53399 .7021 L
.53555 .69911 L
Mistroke
.54054 .68939 L
.54371 .68283 L
.54531 .67968 L
.55021 .66997 L
.55342 .66319 L
.55488 .66026 L
.5597 .65054 L
.56313 .64317 L
.56428 .64083 L
.56902 .63112 L
.57284 .62278 L
.57351 .62141 L
.57818 .61169 L
.58256 .60204 L
.58258 .60198 L
.58719 .59227 L
.5916 .58256 L
.59227 .58096 L
.59606 .57284 L
.60047 .56313 L
.60198 .55952 L
.60479 .55342 L
.60919 .54371 L
.61169 .53775 L
.6134 .53399 L
.61777 .52428 L
.62141 .51564 L
.62188 .51457 L
.62622 .50486 L
.63036 .49514 L
.63112 .49321 L
.63455 .48543 L
.63874 .47572 L
.64083 .47045 L
.64276 .46601 L
.64696 .45629 L
.65054 .44738 L
.65088 .44658 L
.65505 .43687 L
.65906 .42716 L
.66026 .42399 L
.66303 .41744 L
.6671 .40773 L
.66997 .40029 L
.67092 .39802 L
.67498 .38831 L
.67885 .37859 L
.67968 .37629 L
.68275 .36888 L
.68671 .35917 L
Mistroke
.68939 .35199 L
.69043 .34946 L
.6944 .33974 L
.69818 .33003 L
.69911 .3274 L
.70197 .32032 L
.70585 .31061 L
.70882 .3025 L
.70946 .30089 L
.71334 .29118 L
.71709 .28147 L
.71853 .27732 L
.72073 .27176 L
.72456 .26204 L
.72809 .25233 L
.72824 .25185 L
.73186 .24262 L
.73559 .23291 L
.73796 .22611 L
.73908 .22319 L
.74285 .21348 L
.74645 .20377 L
.74767 .20008 L
.74998 .19406 L
.75369 .18434 L
.75711 .17463 L
.75738 .17377 L
.76074 .16492 L
.76439 .15521 L
.76709 .14719 L
.76773 .14549 L
.77139 .13578 L
.77495 .12607 L
.77681 .12035 L
.77829 .11636 L
.78191 .10664 L
.78537 .09693 L
.78652 .09323 L
.78873 .08722 L
.79232 .07751 L
.79565 .06779 L
.79623 .06585 L
.79907 .05808 L
.80261 .04837 L
.80582 .03866 L
.80594 .0382 L
.8093 .02894 L
.81279 .01923 L
Mfstroke
.5 g
.38175 .98077 m
.38831 .97242 L
.38936 .97106 L
.39672 .96134 L
.39802 .95959 L
.40385 .95163 L
.40773 .9462 L
.41076 .94192 L
.41744 .93226 L
.41748 .93221 L
.42406 .92249 L
.42716 .91781 L
.43047 .91278 L
.43674 .90307 L
.43687 .90287 L
.44291 .89336 L
.44658 .88744 L
.44894 .88364 L
.45487 .87393 L
.45629 .87155 L
.4607 .86422 L
.46601 .85521 L
.46642 .85451 L
.47208 .84479 L
.47572 .83843 L
.47763 .83508 L
.48313 .82537 L
.48543 .82122 L
.48853 .81566 L
.49387 .80594 L
.49514 .8036 L
.49915 .79623 L
.50435 .78652 L
.50486 .78557 L
.50952 .77681 L
.51457 .76714 L
.51459 .76709 L
.51965 .75738 L
.52428 .74833 L
.52462 .74767 L
.52957 .73796 L
.53399 .72913 L
.53444 .72824 L
.5393 .71853 L
.54371 .70957 L
.54408 .70882 L
.54885 .69911 L
.55342 .68964 L
.55354 .68939 L
.55823 .67968 L
.56284 .66997 L
.56313 .66935 L
.56745 .66026 L
.572 .65054 L
.57284 .64871 L
.57653 .64083 L
.58101 .63112 L
.58256 .62773 L
.58546 .62141 L
.58989 .61169 L
.59227 .6064 L
.59427 .60198 L
.59865 .59227 L
.60198 .58474 L
.60296 .58256 L
.60728 .57284 L
.61153 .56313 L
.61169 .56275 L
.61579 .55342 L
.62001 .54371 L
.62141 .54043 L
.6242 .53399 L
.62838 .52428 L
.63112 .5178 L
.6325 .51457 L
.63664 .50486 L
.64071 .49514 L
.64083 .49485 L
.6448 .48543 L
.64885 .47572 L
.65054 .47159 L
.65287 .46601 L
.65689 .45629 L
.66026 .44802 L
.66085 .44658 L
.66484 .43687 L
.66877 .42716 L
.66997 .42415 L
.67269 .41744 L
.67661 .40773 L
.67968 .39998 L
.68047 .39802 L
.68436 .38831 L
.6882 .37859 L
.68939 .37552 L
.69202 .36888 L
.69586 .35917 L
.69911 .35076 L
.69962 .34946 L
.70342 .33974 L
.70718 .33003 L
.70882 .32572 L
.71091 .32032 L
.71466 .31061 L
.71835 .30089 L
.71853 .30039 L
.72206 .29118 L
.72576 .28147 L
.72824 .27478 L
.72939 .27176 L
.73307 .26204 L
.7367 .25233 L
.73796 .2489 L
.74031 .24262 L
.74394 .23291 L
.7475 .22319 L
.74767 .22273 L
.7511 .21348 L
.75469 .20377 L
.75738 .19629 L
.7582 .19406 L
.76177 .18434 L
.76531 .17463 L
.76709 .16959 L
.76879 .16492 L
.77232 .15521 L
.7758 .14549 L
.77681 .14262 L
.77927 .13578 L
.78276 .12607 L
.78618 .11636 L
.78652 .11538 L
.78963 .10664 L
.79309 .09693 L
.79623 .08788 L
.79646 .08722 L
.7999 .07751 L
.80332 .06779 L
.80594 .06012 L
.80666 .05808 L
.81006 .04837 L
.81344 .03866 L
.81566 .0321 L
.81675 .02894 L
.82013 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.38175 .98077 m
.38831 .97242 L
.38936 .97106 L
.39672 .96134 L
.39802 .95959 L
.40385 .95163 L
.40773 .9462 L
.41076 .94192 L
.41744 .93226 L
.41748 .93221 L
.42406 .92249 L
.42716 .91781 L
.43047 .91278 L
.43674 .90307 L
.43687 .90287 L
.44291 .89336 L
.44658 .88744 L
.44894 .88364 L
.45487 .87393 L
.45629 .87155 L
.4607 .86422 L
.46601 .85521 L
.46642 .85451 L
.47208 .84479 L
.47572 .83843 L
.47763 .83508 L
.48313 .82537 L
.48543 .82122 L
.48853 .81566 L
.49387 .80594 L
.49514 .8036 L
.49915 .79623 L
.50435 .78652 L
.50486 .78557 L
.50952 .77681 L
.51457 .76714 L
.51459 .76709 L
.51965 .75738 L
.52428 .74833 L
.52462 .74767 L
.52957 .73796 L
.53399 .72913 L
.53444 .72824 L
.5393 .71853 L
.54371 .70957 L
.54408 .70882 L
.54885 .69911 L
.55342 .68964 L
.55354 .68939 L
.55823 .67968 L
Mistroke
.56284 .66997 L
.56313 .66935 L
.56745 .66026 L
.572 .65054 L
.57284 .64871 L
.57653 .64083 L
.58101 .63112 L
.58256 .62773 L
.58546 .62141 L
.58989 .61169 L
.59227 .6064 L
.59427 .60198 L
.59865 .59227 L
.60198 .58474 L
.60296 .58256 L
.60728 .57284 L
.61153 .56313 L
.61169 .56275 L
.61579 .55342 L
.62001 .54371 L
.62141 .54043 L
.6242 .53399 L
.62838 .52428 L
.63112 .5178 L
.6325 .51457 L
.63664 .50486 L
.64071 .49514 L
.64083 .49485 L
.6448 .48543 L
.64885 .47572 L
.65054 .47159 L
.65287 .46601 L
.65689 .45629 L
.66026 .44802 L
.66085 .44658 L
.66484 .43687 L
.66877 .42716 L
.66997 .42415 L
.67269 .41744 L
.67661 .40773 L
.67968 .39998 L
.68047 .39802 L
.68436 .38831 L
.6882 .37859 L
.68939 .37552 L
.69202 .36888 L
.69586 .35917 L
.69911 .35076 L
.69962 .34946 L
.70342 .33974 L
Mistroke
.70718 .33003 L
.70882 .32572 L
.71091 .32032 L
.71466 .31061 L
.71835 .30089 L
.71853 .30039 L
.72206 .29118 L
.72576 .28147 L
.72824 .27478 L
.72939 .27176 L
.73307 .26204 L
.7367 .25233 L
.73796 .2489 L
.74031 .24262 L
.74394 .23291 L
.7475 .22319 L
.74767 .22273 L
.7511 .21348 L
.75469 .20377 L
.75738 .19629 L
.7582 .19406 L
.76177 .18434 L
.76531 .17463 L
.76709 .16959 L
.76879 .16492 L
.77232 .15521 L
.7758 .14549 L
.77681 .14262 L
.77927 .13578 L
.78276 .12607 L
.78618 .11636 L
.78652 .11538 L
.78963 .10664 L
.79309 .09693 L
.79623 .08788 L
.79646 .08722 L
.7999 .07751 L
.80332 .06779 L
.80594 .06012 L
.80666 .05808 L
.81006 .04837 L
.81344 .03866 L
.81566 .0321 L
.81675 .02894 L
.82013 .01923 L
Mfstroke
.4 g
.4042 .98077 m
.40773 .97564 L
.41084 .97106 L
.41733 .96134 L
.41744 .96118 L
.42369 .95163 L
.42716 .94624 L
.42991 .94192 L
.43603 .93221 L
.43687 .93085 L
.44203 .92249 L
.44658 .91501 L
.44793 .91278 L
.45373 .90307 L
.45629 .89874 L
.45945 .89336 L
.46508 .88364 L
.46601 .88204 L
.47063 .87393 L
.47572 .86492 L
.47611 .86422 L
.48151 .85451 L
.48543 .84739 L
.48685 .84479 L
.49213 .83508 L
.49514 .82947 L
.49733 .82537 L
.50249 .81566 L
.50486 .81116 L
.50758 .80594 L
.51263 .79623 L
.51457 .79247 L
.51761 .78652 L
.52256 .77681 L
.52428 .7734 L
.52744 .76709 L
.5323 .75738 L
.53399 .75397 L
.53709 .74767 L
.54186 .73796 L
.54371 .73417 L
.54657 .72824 L
.55126 .71853 L
.55342 .71402 L
.55589 .70882 L
.5605 .69911 L
.56313 .69352 L
.56506 .68939 L
.56959 .67968 L
.57284 .67268 L
.57409 .66997 L
.57855 .66026 L
.58256 .6515 L
.58299 .65054 L
.58738 .64083 L
.59176 .63112 L
.59227 .62998 L
.59609 .62141 L
.60041 .61169 L
.60198 .60814 L
.60468 .60198 L
.60895 .59227 L
.61169 .58598 L
.61317 .58256 L
.61738 .57284 L
.62141 .5635 L
.62156 .56313 L
.6257 .55342 L
.62985 .54371 L
.63112 .5407 L
.63393 .53399 L
.63803 .52428 L
.64083 .5176 L
.64208 .51457 L
.64612 .50486 L
.65015 .49514 L
.65054 .49419 L
.65413 .48543 L
.65812 .47572 L
.66026 .47048 L
.66206 .46601 L
.666 .45629 L
.66992 .44658 L
.66997 .44647 L
.6738 .43687 L
.67769 .42716 L
.67968 .42216 L
.68153 .41744 L
.68538 .40773 L
.68922 .39802 L
.68939 .39756 L
.693 .38831 L
.6968 .37859 L
.69911 .37268 L
.70056 .36888 L
.70432 .35917 L
.70807 .34946 L
.70882 .34751 L
.71177 .33974 L
.71549 .33003 L
.71853 .32206 L
.71918 .32032 L
.72284 .31061 L
.72653 .30089 L
.72824 .29633 L
.73015 .29118 L
.73379 .28147 L
.73743 .27176 L
.73796 .27033 L
.741 .26204 L
.74461 .25233 L
.74767 .24405 L
.74819 .24262 L
.75173 .23291 L
.75531 .22319 L
.75738 .21751 L
.75882 .21348 L
.76235 .20377 L
.76588 .19406 L
.76709 .19069 L
.76935 .18434 L
.77285 .17463 L
.77634 .16492 L
.77681 .16362 L
.77977 .15521 L
.78324 .14549 L
.78652 .13628 L
.78669 .13578 L
.79009 .12607 L
.79353 .11636 L
.79623 .10868 L
.79693 .10664 L
.80031 .09693 L
.80372 .08722 L
.80594 .08082 L
.80707 .07751 L
.81043 .06779 L
.81381 .05808 L
.81566 .05271 L
.81712 .04837 L
.82045 .03866 L
.8238 .02894 L
.82537 .02436 L
.82708 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.4042 .98077 m
.40773 .97564 L
.41084 .97106 L
.41733 .96134 L
.41744 .96118 L
.42369 .95163 L
.42716 .94624 L
.42991 .94192 L
.43603 .93221 L
.43687 .93085 L
.44203 .92249 L
.44658 .91501 L
.44793 .91278 L
.45373 .90307 L
.45629 .89874 L
.45945 .89336 L
.46508 .88364 L
.46601 .88204 L
.47063 .87393 L
.47572 .86492 L
.47611 .86422 L
.48151 .85451 L
.48543 .84739 L
.48685 .84479 L
.49213 .83508 L
.49514 .82947 L
.49733 .82537 L
.50249 .81566 L
.50486 .81116 L
.50758 .80594 L
.51263 .79623 L
.51457 .79247 L
.51761 .78652 L
.52256 .77681 L
.52428 .7734 L
.52744 .76709 L
.5323 .75738 L
.53399 .75397 L
.53709 .74767 L
.54186 .73796 L
.54371 .73417 L
.54657 .72824 L
.55126 .71853 L
.55342 .71402 L
.55589 .70882 L
.5605 .69911 L
.56313 .69352 L
.56506 .68939 L
.56959 .67968 L
.57284 .67268 L
Mistroke
.57409 .66997 L
.57855 .66026 L
.58256 .6515 L
.58299 .65054 L
.58738 .64083 L
.59176 .63112 L
.59227 .62998 L
.59609 .62141 L
.60041 .61169 L
.60198 .60814 L
.60468 .60198 L
.60895 .59227 L
.61169 .58598 L
.61317 .58256 L
.61738 .57284 L
.62141 .5635 L
.62156 .56313 L
.6257 .55342 L
.62985 .54371 L
.63112 .5407 L
.63393 .53399 L
.63803 .52428 L
.64083 .5176 L
.64208 .51457 L
.64612 .50486 L
.65015 .49514 L
.65054 .49419 L
.65413 .48543 L
.65812 .47572 L
.66026 .47048 L
.66206 .46601 L
.666 .45629 L
.66992 .44658 L
.66997 .44647 L
.6738 .43687 L
.67769 .42716 L
.67968 .42216 L
.68153 .41744 L
.68538 .40773 L
.68922 .39802 L
.68939 .39756 L
.693 .38831 L
.6968 .37859 L
.69911 .37268 L
.70056 .36888 L
.70432 .35917 L
.70807 .34946 L
.70882 .34751 L
.71177 .33974 L
.71549 .33003 L
Mistroke
.71853 .32206 L
.71918 .32032 L
.72284 .31061 L
.72653 .30089 L
.72824 .29633 L
.73015 .29118 L
.73379 .28147 L
.73743 .27176 L
.73796 .27033 L
.741 .26204 L
.74461 .25233 L
.74767 .24405 L
.74819 .24262 L
.75173 .23291 L
.75531 .22319 L
.75738 .21751 L
.75882 .21348 L
.76235 .20377 L
.76588 .19406 L
.76709 .19069 L
.76935 .18434 L
.77285 .17463 L
.77634 .16492 L
.77681 .16362 L
.77977 .15521 L
.78324 .14549 L
.78652 .13628 L
.78669 .13578 L
.79009 .12607 L
.79353 .11636 L
.79623 .10868 L
.79693 .10664 L
.80031 .09693 L
.80372 .08722 L
.80594 .08082 L
.80707 .07751 L
.81043 .06779 L
.81381 .05808 L
.81566 .05271 L
.81712 .04837 L
.82045 .03866 L
.8238 .02894 L
.82537 .02436 L
.82708 .01923 L
Mfstroke
.3 g
.42558 .98077 m
.42716 .97823 L
.43149 .97106 L
.43687 .96219 L
.43736 .96134 L
.44311 .95163 L
.44658 .94575 L
.44878 .94192 L
.45441 .93221 L
.45629 .92894 L
.45992 .92249 L
.46543 .91278 L
.46601 .91175 L
.47078 .90307 L
.47572 .89417 L
.47615 .89336 L
.4814 .88364 L
.48543 .87622 L
.48662 .87393 L
.49178 .86422 L
.49514 .85789 L
.49687 .85451 L
.50194 .84479 L
.50486 .8392 L
.50692 .83508 L
.5119 .82537 L
.51457 .82016 L
.51678 .81566 L
.52167 .80594 L
.52428 .80075 L
.52646 .79623 L
.53126 .78652 L
.53399 .781 L
.53597 .77681 L
.54069 .76709 L
.54371 .76091 L
.54533 .75738 L
.54997 .74767 L
.55342 .74047 L
.55455 .73796 L
.55909 .72824 L
.56313 .71971 L
.56365 .71853 L
.56808 .70882 L
.57261 .69911 L
.57284 .69861 L
.57695 .68939 L
.58141 .67968 L
.58256 .67718 L
.5857 .66997 L
.59009 .66026 L
.59227 .65542 L
.59434 .65054 L
.59865 .64083 L
.60198 .63336 L
.6029 .63112 L
.6071 .62141 L
.61138 .61169 L
.61169 .61098 L
.61546 .60198 L
.61968 .59227 L
.62141 .58829 L
.62373 .58256 L
.62788 .57284 L
.63112 .56529 L
.63196 .56313 L
.63599 .55342 L
.64011 .54371 L
.64083 .542 L
.64402 .53399 L
.64808 .52428 L
.65054 .5184 L
.65201 .51457 L
.65597 .50486 L
.66 .49514 L
.66026 .49451 L
.66379 .48543 L
.66776 .47572 L
.66997 .47032 L
.67158 .46601 L
.67545 .45629 L
.67939 .44658 L
.67968 .44585 L
.68308 .43687 L
.68697 .42716 L
.68939 .42109 L
.69071 .41744 L
.69448 .40773 L
.69833 .39802 L
.69911 .39605 L
.70194 .38831 L
.70574 .37859 L
.70882 .37073 L
.70945 .36888 L
.71308 .35917 L
.71686 .34946 L
.71853 .34513 L
.72042 .33974 L
.7241 .33003 L
.72784 .32032 L
.72824 .31926 L
.73131 .31061 L
.735 .30089 L
.73796 .29312 L
.73859 .29118 L
.7421 .28147 L
.74577 .27176 L
.74767 .2667 L
.74923 .26204 L
.75278 .25233 L
.75642 .24262 L
.75738 .24003 L
.75979 .23291 L
.76335 .22319 L
.76695 .21348 L
.76709 .21309 L
.77025 .20377 L
.77381 .19406 L
.77681 .18589 L
.77728 .18434 L
.78062 .17463 L
.78416 .16492 L
.78652 .15843 L
.78752 .15521 L
.7909 .14549 L
.79441 .13578 L
.79623 .13071 L
.79768 .12607 L
.80107 .11636 L
.80456 .10664 L
.80594 .10274 L
.80776 .09693 L
.81115 .08722 L
.8146 .07751 L
.81566 .07452 L
.81776 .06779 L
.82113 .05808 L
.82456 .04837 L
.82537 .04604 L
.82767 .03866 L
.83102 .02894 L
.83442 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.42558 .98077 m
.42716 .97823 L
.43149 .97106 L
.43687 .96219 L
.43736 .96134 L
.44311 .95163 L
.44658 .94575 L
.44878 .94192 L
.45441 .93221 L
.45629 .92894 L
.45992 .92249 L
.46543 .91278 L
.46601 .91175 L
.47078 .90307 L
.47572 .89417 L
.47615 .89336 L
.4814 .88364 L
.48543 .87622 L
.48662 .87393 L
.49178 .86422 L
.49514 .85789 L
.49687 .85451 L
.50194 .84479 L
.50486 .8392 L
.50692 .83508 L
.5119 .82537 L
.51457 .82016 L
.51678 .81566 L
.52167 .80594 L
.52428 .80075 L
.52646 .79623 L
.53126 .78652 L
.53399 .781 L
.53597 .77681 L
.54069 .76709 L
.54371 .76091 L
.54533 .75738 L
.54997 .74767 L
.55342 .74047 L
.55455 .73796 L
.55909 .72824 L
.56313 .71971 L
.56365 .71853 L
.56808 .70882 L
.57261 .69911 L
.57284 .69861 L
.57695 .68939 L
.58141 .67968 L
.58256 .67718 L
.5857 .66997 L
Mistroke
.59009 .66026 L
.59227 .65542 L
.59434 .65054 L
.59865 .64083 L
.60198 .63336 L
.6029 .63112 L
.6071 .62141 L
.61138 .61169 L
.61169 .61098 L
.61546 .60198 L
.61968 .59227 L
.62141 .58829 L
.62373 .58256 L
.62788 .57284 L
.63112 .56529 L
.63196 .56313 L
.63599 .55342 L
.64011 .54371 L
.64083 .542 L
.64402 .53399 L
.64808 .52428 L
.65054 .5184 L
.65201 .51457 L
.65597 .50486 L
.66 .49514 L
.66026 .49451 L
.66379 .48543 L
.66776 .47572 L
.66997 .47032 L
.67158 .46601 L
.67545 .45629 L
.67939 .44658 L
.67968 .44585 L
.68308 .43687 L
.68697 .42716 L
.68939 .42109 L
.69071 .41744 L
.69448 .40773 L
.69833 .39802 L
.69911 .39605 L
.70194 .38831 L
.70574 .37859 L
.70882 .37073 L
.70945 .36888 L
.71308 .35917 L
.71686 .34946 L
.71853 .34513 L
.72042 .33974 L
.7241 .33003 L
.72784 .32032 L
Mistroke
.72824 .31926 L
.73131 .31061 L
.735 .30089 L
.73796 .29312 L
.73859 .29118 L
.7421 .28147 L
.74577 .27176 L
.74767 .2667 L
.74923 .26204 L
.75278 .25233 L
.75642 .24262 L
.75738 .24003 L
.75979 .23291 L
.76335 .22319 L
.76695 .21348 L
.76709 .21309 L
.77025 .20377 L
.77381 .19406 L
.77681 .18589 L
.77728 .18434 L
.78062 .17463 L
.78416 .16492 L
.78652 .15843 L
.78752 .15521 L
.7909 .14549 L
.79441 .13578 L
.79623 .13071 L
.79768 .12607 L
.80107 .11636 L
.80456 .10664 L
.80594 .10274 L
.80776 .09693 L
.81115 .08722 L
.8146 .07751 L
.81566 .07452 L
.81776 .06779 L
.82113 .05808 L
.82456 .04837 L
.82537 .04604 L
.82767 .03866 L
.83102 .02894 L
.83442 .01923 L
Mfstroke
.4 g
.49289 .98077 m
.49514 .97651 L
.49826 .97106 L
.5036 .96134 L
.50486 .95891 L
.50888 .95163 L
.51403 .94192 L
.51457 .94083 L
.51923 .93221 L
.52421 .92249 L
.52428 .92235 L
.52934 .91278 L
.53399 .90347 L
.5342 .90307 L
.53923 .89336 L
.54371 .88421 L
.54399 .88364 L
.54893 .87393 L
.55342 .86456 L
.55359 .86422 L
.55844 .85451 L
.56302 .84479 L
.56313 .84455 L
.56777 .83508 L
.57232 .82537 L
.57284 .82417 L
.57695 .81566 L
.58147 .80594 L
.58256 .80343 L
.58597 .79623 L
.59047 .78652 L
.59227 .78234 L
.59486 .77681 L
.59933 .76709 L
.60198 .76091 L
.6036 .75738 L
.60804 .74767 L
.61169 .73913 L
.61223 .73796 L
.61662 .72824 L
.62081 .71853 L
.62141 .71703 L
.62507 .70882 L
.62931 .69911 L
.63112 .6946 L
.63341 .68939 L
.63765 .67968 L
.64083 .67184 L
.64164 .66997 L
.64586 .66026 L
.64987 .65054 L
.65054 .64876 L
.65395 .64083 L
.65804 .63112 L
.66026 .62538 L
.66194 .62141 L
.66604 .61169 L
.66986 .60198 L
.66997 .60168 L
.67391 .59227 L
.67787 .58256 L
.67968 .57768 L
.68168 .57284 L
.68568 .56313 L
.68938 .55342 L
.68939 .55337 L
.69335 .54371 L
.69722 .53399 L
.69911 .52878 L
.70092 .52428 L
.70484 .51457 L
.70849 .50486 L
.70882 .50389 L
.71231 .49514 L
.71613 .48543 L
.71853 .47871 L
.71971 .47572 L
.72355 .46601 L
.72721 .45629 L
.72824 .45324 L
.73085 .44658 L
.73463 .43687 L
.73796 .42749 L
.73808 .42716 L
.74185 .41744 L
.74553 .40773 L
.74767 .40146 L
.74899 .39802 L
.75271 .38831 L
.75627 .37859 L
.75738 .37516 L
.75976 .36888 L
.76344 .35917 L
.76683 .34946 L
.76709 .34858 L
.77042 .33974 L
.77403 .33003 L
.77681 .32173 L
.77733 .32032 L
.78095 .31061 L
.78449 .30089 L
.78652 .29462 L
.78778 .29118 L
.79137 .28147 L
.79482 .27176 L
.79623 .26724 L
.79813 .26204 L
.80168 .25233 L
.80504 .24262 L
.80594 .23959 L
.80836 .23291 L
.81188 .22319 L
.81514 .21348 L
.81566 .21169 L
.8185 .20377 L
.82198 .19406 L
.82514 .18434 L
.82537 .18352 L
.82854 .17463 L
.83198 .16492 L
.83506 .15521 L
.83508 .15511 L
.83848 .14549 L
.84189 .13578 L
.84479 .12644 L
.84492 .12607 L
.84833 .11636 L
.85171 .10664 L
.85451 .09752 L
.85471 .09693 L
.85809 .08722 L
.86145 .07751 L
.86422 .06835 L
.86441 .06779 L
.86777 .05808 L
.8711 .04837 L
.87393 .03894 L
.87403 .03866 L
.87736 .02894 L
.88067 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.49289 .98077 m
.49514 .97651 L
.49826 .97106 L
.5036 .96134 L
.50486 .95891 L
.50888 .95163 L
.51403 .94192 L
.51457 .94083 L
.51923 .93221 L
.52421 .92249 L
.52428 .92235 L
.52934 .91278 L
.53399 .90347 L
.5342 .90307 L
.53923 .89336 L
.54371 .88421 L
.54399 .88364 L
.54893 .87393 L
.55342 .86456 L
.55359 .86422 L
.55844 .85451 L
.56302 .84479 L
.56313 .84455 L
.56777 .83508 L
.57232 .82537 L
.57284 .82417 L
.57695 .81566 L
.58147 .80594 L
.58256 .80343 L
.58597 .79623 L
.59047 .78652 L
.59227 .78234 L
.59486 .77681 L
.59933 .76709 L
.60198 .76091 L
.6036 .75738 L
.60804 .74767 L
.61169 .73913 L
.61223 .73796 L
.61662 .72824 L
.62081 .71853 L
.62141 .71703 L
.62507 .70882 L
.62931 .69911 L
.63112 .6946 L
.63341 .68939 L
.63765 .67968 L
.64083 .67184 L
.64164 .66997 L
.64586 .66026 L
Mistroke
.64987 .65054 L
.65054 .64876 L
.65395 .64083 L
.65804 .63112 L
.66026 .62538 L
.66194 .62141 L
.66604 .61169 L
.66986 .60198 L
.66997 .60168 L
.67391 .59227 L
.67787 .58256 L
.67968 .57768 L
.68168 .57284 L
.68568 .56313 L
.68938 .55342 L
.68939 .55337 L
.69335 .54371 L
.69722 .53399 L
.69911 .52878 L
.70092 .52428 L
.70484 .51457 L
.70849 .50486 L
.70882 .50389 L
.71231 .49514 L
.71613 .48543 L
.71853 .47871 L
.71971 .47572 L
.72355 .46601 L
.72721 .45629 L
.72824 .45324 L
.73085 .44658 L
.73463 .43687 L
.73796 .42749 L
.73808 .42716 L
.74185 .41744 L
.74553 .40773 L
.74767 .40146 L
.74899 .39802 L
.75271 .38831 L
.75627 .37859 L
.75738 .37516 L
.75976 .36888 L
.76344 .35917 L
.76683 .34946 L
.76709 .34858 L
.77042 .33974 L
.77403 .33003 L
.77681 .32173 L
.77733 .32032 L
.78095 .31061 L
Mistroke
.78449 .30089 L
.78652 .29462 L
.78778 .29118 L
.79137 .28147 L
.79482 .27176 L
.79623 .26724 L
.79813 .26204 L
.80168 .25233 L
.80504 .24262 L
.80594 .23959 L
.80836 .23291 L
.81188 .22319 L
.81514 .21348 L
.81566 .21169 L
.8185 .20377 L
.82198 .19406 L
.82514 .18434 L
.82537 .18352 L
.82854 .17463 L
.83198 .16492 L
.83506 .15521 L
.83508 .15511 L
.83848 .14549 L
.84189 .13578 L
.84479 .12644 L
.84492 .12607 L
.84833 .11636 L
.85171 .10664 L
.85451 .09752 L
.85471 .09693 L
.85809 .08722 L
.86145 .07751 L
.86422 .06835 L
.86441 .06779 L
.86777 .05808 L
.8711 .04837 L
.87393 .03894 L
.87403 .03866 L
.87736 .02894 L
.88067 .01923 L
Mfstroke
.8 g
.50486 .28662 m
.51299 .29118 L
.50649 .30089 L
.50486 .30319 L
.4994 .30089 L
.50302 .29118 L
F
0 g
.50486 .28662 m
.51299 .29118 L
.50649 .30089 L
.50486 .30319 L
.4994 .30089 L
.50302 .29118 L
.50486 .28662 L
s
.2 g
.50486 .89077 m
.51426 .89336 L
.50785 .90307 L
.50486 .90734 L
.50009 .90307 L
.50381 .89336 L
F
0 g
.50486 .89077 m
.51426 .89336 L
.50785 .90307 L
.50486 .90734 L
.50009 .90307 L
.50381 .89336 L
.50486 .89077 L
s
.2 g
.55294 .01923 m
.5478 .02894 L
.54371 .03735 L
.5426 .03866 L
.53728 .04837 L
.53399 .0554 L
.53187 .05808 L
.52631 .06779 L
.52428 .07223 L
.52057 .07751 L
.51464 .08722 L
.51457 .08737 L
.50826 .09693 L
.50486 .10181 L
.5003 .09693 L
.50405 .08722 L
.50486 .08523 L
.50812 .07751 L
.5123 .06779 L
.51457 .06259 L
.51657 .05808 L
.52089 .04837 L
.52428 .04073 L
.52522 .03866 L
.52958 .02894 L
.53389 .01923 L
F
0 g
.55294 .01923 m
.5478 .02894 L
.54371 .03735 L
.5426 .03866 L
.53728 .04837 L
.53399 .0554 L
.53187 .05808 L
.52631 .06779 L
.52428 .07223 L
.52057 .07751 L
.51464 .08722 L
.51457 .08737 L
.50826 .09693 L
.50486 .10181 L
.5003 .09693 L
.50405 .08722 L
.50486 .08523 L
.50812 .07751 L
.5123 .06779 L
.51457 .06259 L
.51657 .05808 L
.52089 .04837 L
.52428 .04073 L
.52522 .03866 L
.52958 .02894 L
.53389 .01923 L
s
.8 g
.80287 .01923 m
.80048 .02894 L
.79623 .03801 L
.796 .03866 L
.7925 .04837 L
.78978 .05808 L
.78652 .06517 L
.78555 .06779 L
.78203 .07751 L
.77897 .08722 L
.77681 .09204 L
.77499 .09693 L
.77326 .10664 L
.76808 .11636 L
.76709 .1186 L
.76431 .12607 L
.76191 .13578 L
.75738 .14489 L
.75715 .14549 L
.75351 .15521 L
.75054 .16492 L
.74767 .17094 L
.74625 .17463 L
.74257 .18434 L
.73915 .19406 L
.73796 .19664 L
.73521 .20377 L
.7327 .21348 L
.72824 .22207 L
.72779 .22319 L
.72403 .23291 L
.72078 .24262 L
.71853 .24723 L
.71651 .25233 L
.71439 .26204 L
.70894 .27176 L
.70882 .272 L
.70506 .28147 L
.70189 .29118 L
.69911 .2966 L
.69735 .30089 L
.69345 .31061 L
.6896 .32032 L
.68939 .32074 L
.68561 .33003 L
.68232 .33974 L
.67968 .34471 L
.67769 .34946 L
.67547 .35917 L
.66997 .36823 L
.66968 .36888 L
.66562 .37859 L
.66197 .38831 L
.66026 .3915 L
.65746 .39802 L
.65457 .40773 L
.65054 .41444 L
.64921 .41744 L
.64502 .42716 L
.64085 .43687 L
.64083 .4369 L
.63659 .44658 L
.63278 .45629 L
.63112 .45917 L
.62805 .46601 L
.62483 .47572 L
.62141 .48107 L
.61937 .48543 L
.61498 .49514 L
.61169 .50255 L
.61057 .50486 L
.60609 .51457 L
.60198 .52357 L
.60161 .52428 L
.59705 .53399 L
.59257 .54371 L
.59227 .54418 L
.58784 .55342 L
.58347 .56313 L
.58256 .56448 L
.57844 .57284 L
.57414 .58256 L
.57284 .58434 L
.56883 .59227 L
.56395 .60198 L
.56313 .60371 L
.55898 .61169 L
.55397 .62141 L
.55342 .62255 L
.54884 .63112 L
.54371 .64082 L
.54368 .64083 L
.53837 .65054 L
.53399 .65849 L
.53299 .66026 L
.52745 .66997 L
.52428 .67546 L
.52176 .67968 L
.51587 .68939 L
.51457 .69242 L
.5096 .69911 L
.50486 .70596 L
.50103 .69911 L
.50485 .68939 L
.50486 .68938 L
.50896 .67968 L
.51316 .66997 L
.51457 .66674 L
.51745 .66026 L
.52176 .65054 L
.52428 .64488 L
.52611 .64083 L
.53047 .63112 L
.53399 .62323 L
.53482 .62141 L
.53919 .61169 L
.54344 .60198 L
.54371 .60154 L
.54788 .59227 L
.55156 .58256 L
.55342 .57959 L
.55653 .57284 L
.56082 .56313 L
.56313 .55754 L
.56511 .55342 L
.56938 .54371 L
.57284 .5355 L
.57362 .53399 L
.57786 .52428 L
.58191 .51457 L
.58256 .51336 L
.58626 .50486 L
.58974 .49514 L
.59227 .49067 L
.59459 .48543 L
.59714 .47572 L
.60198 .46786 L
.60283 .46601 L
.60694 .45629 L
.61083 .44658 L
.61169 .44489 L
.61508 .43687 L
.61834 .42716 L
.62141 .42147 L
.62314 .41744 L
.6253 .40773 L
.63112 .39802 L
.63112 .39802 L
.6351 .38831 L
.63854 .37859 L
.64083 .37407 L
.64298 .36888 L
.64547 .35917 L
.65054 .35002 L
.65078 .34946 L
.65468 .33974 L
.65809 .33003 L
.66026 .32559 L
.66239 .32032 L
.66483 .31061 L
.66997 .30103 L
.67002 .30089 L
.67384 .29118 L
.67708 .28147 L
.67968 .27605 L
.68139 .27176 L
.68351 .26204 L
.68877 .25233 L
.68939 .25094 L
.69261 .24262 L
.69551 .23291 L
.69911 .22547 L
.7 .22319 L
.70369 .21348 L
.70702 .20377 L
.70882 .19979 L
.71101 .19406 L
.71334 .18434 L
.71821 .17463 L
.71853 .17389 L
.72189 .16492 L
.72473 .15521 L
.72824 .14764 L
.72906 .14549 L
.73265 .13578 L
.7358 .12607 L
.73796 .12118 L
.73975 .11636 L
.74173 .10664 L
.74663 .09693 L
.74767 .09449 L
.75032 .08722 L
.75274 .07751 L
.75728 .06779 L
.75738 .06755 L
.76079 .05808 L
.76349 .04837 L
.76709 .04029 L
.76769 .03866 L
.77115 .02894 L
.77404 .01923 L
F
0 g
.80287 .01923 m
.80048 .02894 L
.79623 .03801 L
.796 .03866 L
.7925 .04837 L
.78978 .05808 L
.78652 .06517 L
.78555 .06779 L
.78203 .07751 L
.77897 .08722 L
.77681 .09204 L
.77499 .09693 L
.77326 .10664 L
.76808 .11636 L
.76709 .1186 L
.76431 .12607 L
.76191 .13578 L
.75738 .14489 L
.75715 .14549 L
.75351 .15521 L
.75054 .16492 L
.74767 .17094 L
.74625 .17463 L
.74257 .18434 L
.73915 .19406 L
.73796 .19664 L
.73521 .20377 L
.7327 .21348 L
.72824 .22207 L
.72779 .22319 L
.72403 .23291 L
.72078 .24262 L
.71853 .24723 L
.71651 .25233 L
.71439 .26204 L
.70894 .27176 L
.70882 .272 L
.70506 .28147 L
.70189 .29118 L
.69911 .2966 L
.69735 .30089 L
.69345 .31061 L
.6896 .32032 L
.68939 .32074 L
.68561 .33003 L
.68232 .33974 L
.67968 .34471 L
.67769 .34946 L
.67547 .35917 L
.66997 .36823 L
Mistroke
.66968 .36888 L
.66562 .37859 L
.66197 .38831 L
.66026 .3915 L
.65746 .39802 L
.65457 .40773 L
.65054 .41444 L
.64921 .41744 L
.64502 .42716 L
.64085 .43687 L
.64083 .4369 L
.63659 .44658 L
.63278 .45629 L
.63112 .45917 L
.62805 .46601 L
.62483 .47572 L
.62141 .48107 L
.61937 .48543 L
.61498 .49514 L
.61169 .50255 L
.61057 .50486 L
.60609 .51457 L
.60198 .52357 L
.60161 .52428 L
.59705 .53399 L
.59257 .54371 L
.59227 .54418 L
.58784 .55342 L
.58347 .56313 L
.58256 .56448 L
.57844 .57284 L
.57414 .58256 L
.57284 .58434 L
.56883 .59227 L
.56395 .60198 L
.56313 .60371 L
.55898 .61169 L
.55397 .62141 L
.55342 .62255 L
.54884 .63112 L
.54371 .64082 L
.54368 .64083 L
.53837 .65054 L
.53399 .65849 L
.53299 .66026 L
.52745 .66997 L
.52428 .67546 L
.52176 .67968 L
.51587 .68939 L
.51457 .69242 L
Mistroke
.5096 .69911 L
.50486 .70596 L
.50103 .69911 L
.50485 .68939 L
.50486 .68938 L
.50896 .67968 L
.51316 .66997 L
.51457 .66674 L
.51745 .66026 L
.52176 .65054 L
.52428 .64488 L
.52611 .64083 L
.53047 .63112 L
.53399 .62323 L
.53482 .62141 L
.53919 .61169 L
.54344 .60198 L
.54371 .60154 L
.54788 .59227 L
.55156 .58256 L
.55342 .57959 L
.55653 .57284 L
.56082 .56313 L
.56313 .55754 L
.56511 .55342 L
.56938 .54371 L
.57284 .5355 L
.57362 .53399 L
.57786 .52428 L
.58191 .51457 L
.58256 .51336 L
.58626 .50486 L
.58974 .49514 L
.59227 .49067 L
.59459 .48543 L
.59714 .47572 L
.60198 .46786 L
.60283 .46601 L
.60694 .45629 L
.61083 .44658 L
.61169 .44489 L
.61508 .43687 L
.61834 .42716 L
.62141 .42147 L
.62314 .41744 L
.6253 .40773 L
.63112 .39802 L
.63112 .39802 L
.6351 .38831 L
.63854 .37859 L
Mistroke
.64083 .37407 L
.64298 .36888 L
.64547 .35917 L
.65054 .35002 L
.65078 .34946 L
.65468 .33974 L
.65809 .33003 L
.66026 .32559 L
.66239 .32032 L
.66483 .31061 L
.66997 .30103 L
.67002 .30089 L
.67384 .29118 L
.67708 .28147 L
.67968 .27605 L
.68139 .27176 L
.68351 .26204 L
.68877 .25233 L
.68939 .25094 L
.69261 .24262 L
.69551 .23291 L
.69911 .22547 L
.7 .22319 L
.70369 .21348 L
.70702 .20377 L
.70882 .19979 L
.71101 .19406 L
.71334 .18434 L
.71821 .17463 L
.71853 .17389 L
.72189 .16492 L
.72473 .15521 L
.72824 .14764 L
.72906 .14549 L
.73265 .13578 L
.7358 .12607 L
.73796 .12118 L
.73975 .11636 L
.74173 .10664 L
.74663 .09693 L
.74767 .09449 L
.75032 .08722 L
.75274 .07751 L
.75728 .06779 L
.75738 .06755 L
.76079 .05808 L
.76349 .04837 L
.76709 .04029 L
.76769 .03866 L
.77115 .02894 L
Mistroke
.77404 .01923 L
Mfstroke
.2 g
.50486 .488 m
.51131 .49514 L
.50486 .50458 L
.50201 .49514 L
F
0 g
.50486 .488 m
.51131 .49514 L
.50486 .50458 L
.50201 .49514 L
.50486 .488 L
s
.2 g
.72891 .01923 m
.72824 .02063 L
.72503 .02894 L
.72222 .03866 L
.71853 .04584 L
.71752 .04837 L
.71371 .05808 L
.71021 .06779 L
.70882 .07066 L
.70608 .07751 L
.70344 .08722 L
.69911 .0952 L
.69839 .09693 L
.69448 .10664 L
.69093 .11636 L
.68939 .1194 L
.68666 .12607 L
.68393 .13578 L
.67968 .14332 L
.67875 .14549 L
.67475 .15521 L
.67096 .16492 L
.66997 .16685 L
.6667 .17463 L
.66355 .18434 L
.66026 .19015 L
.65856 .19406 L
.65444 .20377 L
.65054 .21299 L
.65032 .21348 L
.64613 .22319 L
.64232 .23291 L
.64083 .23558 L
.63772 .24262 L
.63453 .25233 L
.63112 .25784 L
.62919 .26204 L
.62487 .27176 L
.62141 .27967 L
.62054 .28147 L
.61615 .29118 L
.61177 .30089 L
.61169 .30103 L
.60728 .31061 L
.60313 .32032 L
.60198 .32216 L
.59826 .33003 L
.59442 .33974 L
.59227 .3429 L
.58907 .34946 L
.58442 .35917 L
.58256 .36322 L
.5797 .36888 L
.57494 .37859 L
.57284 .38309 L
.57012 .38831 L
.56525 .39802 L
.56313 .4025 L
.5603 .40773 L
.5553 .41744 L
.55342 .42138 L
.55021 .42716 L
.54506 .43687 L
.54371 .43966 L
.53978 .44658 L
.53444 .45629 L
.53399 .4572 L
.52893 .46601 L
.52428 .47408 L
.52331 .47572 L
.51745 .48543 L
.51457 .4901 L
.50593 .48543 L
.51007 .47572 L
.51428 .46601 L
.51457 .46514 L
.51859 .45629 L
.52291 .44658 L
.52428 .44273 L
.52727 .43687 L
.53162 .42716 L
.53399 .42091 L
.53598 .41744 L
.54034 .40773 L
.54371 .39946 L
.54468 .39802 L
.54903 .38831 L
.55331 .37859 L
.55342 .37841 L
.55767 .36888 L
.56144 .35917 L
.56313 .35632 L
.56624 .34946 L
.56926 .33974 L
.57284 .3341 L
.57475 .33003 L
.57898 .32032 L
.58256 .31184 L
.58317 .31061 L
.58737 .30089 L
.59131 .29118 L
.59227 .28938 L
.59569 .28147 L
.599 .27176 L
.60198 .26646 L
.60393 .26204 L
.6062 .25233 L
.61169 .24347 L
.61209 .24262 L
.61616 .23291 L
.61985 .22319 L
.62141 .22014 L
.62421 .21348 L
.62713 .20377 L
.63112 .19651 L
.63218 .19406 L
.63615 .18434 L
.63991 .17463 L
.64083 .17274 L
.64402 .16492 L
.6471 .15521 L
.65054 .14856 L
.65182 .14549 L
.65364 .13578 L
.6594 .12607 L
.66026 .12425 L
.66341 .11636 L
.6664 .10664 L
.66997 .09957 L
.67104 .09693 L
.67485 .08722 L
.67838 .07751 L
.67968 .0747 L
.68239 .06779 L
.6851 .05808 L
.68939 .04953 L
.68986 .04837 L
.6936 .03866 L
.69686 .02894 L
.69911 .02455 L
.70099 .01923 L
F
0 g
.72891 .01923 m
.72824 .02063 L
.72503 .02894 L
.72222 .03866 L
.71853 .04584 L
.71752 .04837 L
.71371 .05808 L
.71021 .06779 L
.70882 .07066 L
.70608 .07751 L
.70344 .08722 L
.69911 .0952 L
.69839 .09693 L
.69448 .10664 L
.69093 .11636 L
.68939 .1194 L
.68666 .12607 L
.68393 .13578 L
.67968 .14332 L
.67875 .14549 L
.67475 .15521 L
.67096 .16492 L
.66997 .16685 L
.6667 .17463 L
.66355 .18434 L
.66026 .19015 L
.65856 .19406 L
.65444 .20377 L
.65054 .21299 L
.65032 .21348 L
.64613 .22319 L
.64232 .23291 L
.64083 .23558 L
.63772 .24262 L
.63453 .25233 L
.63112 .25784 L
.62919 .26204 L
.62487 .27176 L
.62141 .27967 L
.62054 .28147 L
.61615 .29118 L
.61177 .30089 L
.61169 .30103 L
.60728 .31061 L
.60313 .32032 L
.60198 .32216 L
.59826 .33003 L
.59442 .33974 L
.59227 .3429 L
.58907 .34946 L
Mistroke
.58442 .35917 L
.58256 .36322 L
.5797 .36888 L
.57494 .37859 L
.57284 .38309 L
.57012 .38831 L
.56525 .39802 L
.56313 .4025 L
.5603 .40773 L
.5553 .41744 L
.55342 .42138 L
.55021 .42716 L
.54506 .43687 L
.54371 .43966 L
.53978 .44658 L
.53444 .45629 L
.53399 .4572 L
.52893 .46601 L
.52428 .47408 L
.52331 .47572 L
.51745 .48543 L
.51457 .4901 L
.50593 .48543 L
.51007 .47572 L
.51428 .46601 L
.51457 .46514 L
.51859 .45629 L
.52291 .44658 L
.52428 .44273 L
.52727 .43687 L
.53162 .42716 L
.53399 .42091 L
.53598 .41744 L
.54034 .40773 L
.54371 .39946 L
.54468 .39802 L
.54903 .38831 L
.55331 .37859 L
.55342 .37841 L
.55767 .36888 L
.56144 .35917 L
.56313 .35632 L
.56624 .34946 L
.56926 .33974 L
.57284 .3341 L
.57475 .33003 L
.57898 .32032 L
.58256 .31184 L
.58317 .31061 L
.58737 .30089 L
Mistroke
.59131 .29118 L
.59227 .28938 L
.59569 .28147 L
.599 .27176 L
.60198 .26646 L
.60393 .26204 L
.6062 .25233 L
.61169 .24347 L
.61209 .24262 L
.61616 .23291 L
.61985 .22319 L
.62141 .22014 L
.62421 .21348 L
.62713 .20377 L
.63112 .19651 L
.63218 .19406 L
.63615 .18434 L
.63991 .17463 L
.64083 .17274 L
.64402 .16492 L
.6471 .15521 L
.65054 .14856 L
.65182 .14549 L
.65364 .13578 L
.6594 .12607 L
.66026 .12425 L
.66341 .11636 L
.6664 .10664 L
.66997 .09957 L
.67104 .09693 L
.67485 .08722 L
.67838 .07751 L
.67968 .0747 L
.68239 .06779 L
.6851 .05808 L
.68939 .04953 L
.68986 .04837 L
.6936 .03866 L
.69686 .02894 L
.69911 .02455 L
.70099 .01923 L
Mfstroke
.8 g
.64724 .01923 m
.64398 .02894 L
.64083 .03424 L
.63885 .03866 L
.6346 .04837 L
.63112 .05643 L
.63034 .05808 L
.62602 .06779 L
.6218 .07751 L
.62141 .07819 L
.61731 .08722 L
.61341 .09693 L
.61169 .09972 L
.60847 .10664 L
.60505 .11636 L
.60198 .12087 L
.59947 .12607 L
.59491 .13578 L
.59227 .1416 L
.59031 .14549 L
.58565 .15521 L
.58256 .1619 L
.58096 .16492 L
.5762 .17463 L
.57284 .18178 L
.57141 .18434 L
.56654 .19406 L
.56313 .20122 L
.56163 .20377 L
.55663 .21348 L
.55342 .22019 L
.55158 .22319 L
.54643 .23291 L
.54371 .2386 L
.5412 .24262 L
.53586 .25233 L
.53399 .25624 L
.5304 .26204 L
.52483 .27176 L
.52428 .27287 L
.51902 .28147 L
.51457 .28872 L
.50702 .28147 L
.51118 .27176 L
.51457 .26397 L
.51542 .26204 L
.51974 .25233 L
.52406 .24262 L
.52428 .24203 L
.52843 .23291 L
.53277 .22319 L
.53399 .22006 L
.53714 .21348 L
.54149 .20377 L
.54371 .19824 L
.54584 .19406 L
.55018 .18434 L
.55342 .17654 L
.55449 .17463 L
.55881 .16492 L
.56307 .15521 L
.56313 .1551 L
.56738 .14549 L
.57115 .13578 L
.57284 .13284 L
.57587 .12607 L
.5789 .11636 L
.58256 .11041 L
.58429 .10664 L
.58848 .09693 L
.59227 .08796 L
.59263 .08722 L
.59679 .07751 L
.60059 .06779 L
.60198 .06515 L
.60502 .05808 L
.60811 .04837 L
.61169 .04201 L
.61317 .03866 L
.61723 .02894 L
.62121 .01923 L
F
0 g
.64724 .01923 m
.64398 .02894 L
.64083 .03424 L
.63885 .03866 L
.6346 .04837 L
.63112 .05643 L
.63034 .05808 L
.62602 .06779 L
.6218 .07751 L
.62141 .07819 L
.61731 .08722 L
.61341 .09693 L
.61169 .09972 L
.60847 .10664 L
.60505 .11636 L
.60198 .12087 L
.59947 .12607 L
.59491 .13578 L
.59227 .1416 L
.59031 .14549 L
.58565 .15521 L
.58256 .1619 L
.58096 .16492 L
.5762 .17463 L
.57284 .18178 L
.57141 .18434 L
.56654 .19406 L
.56313 .20122 L
.56163 .20377 L
.55663 .21348 L
.55342 .22019 L
.55158 .22319 L
.54643 .23291 L
.54371 .2386 L
.5412 .24262 L
.53586 .25233 L
.53399 .25624 L
.5304 .26204 L
.52483 .27176 L
.52428 .27287 L
.51902 .28147 L
.51457 .28872 L
.50702 .28147 L
.51118 .27176 L
.51457 .26397 L
.51542 .26204 L
.51974 .25233 L
.52406 .24262 L
.52428 .24203 L
.52843 .23291 L
Mistroke
.53277 .22319 L
.53399 .22006 L
.53714 .21348 L
.54149 .20377 L
.54371 .19824 L
.54584 .19406 L
.55018 .18434 L
.55342 .17654 L
.55449 .17463 L
.55881 .16492 L
.56307 .15521 L
.56313 .1551 L
.56738 .14549 L
.57115 .13578 L
.57284 .13284 L
.57587 .12607 L
.5789 .11636 L
.58256 .11041 L
.58429 .10664 L
.58848 .09693 L
.59227 .08796 L
.59263 .08722 L
.59679 .07751 L
.60059 .06779 L
.60198 .06515 L
.60502 .05808 L
.60811 .04837 L
.61169 .04201 L
.61317 .03866 L
.61723 .02894 L
.62121 .01923 L
Mfstroke
.2 g
.87178 .01923 m
.87024 .02894 L
.86558 .03866 L
.86422 .04205 L
.86208 .04837 L
.8605 .05808 L
.85581 .06779 L
.85451 .07102 L
.85229 .07751 L
.85062 .08722 L
.84593 .09693 L
.84479 .09974 L
.84241 .10664 L
.84059 .11636 L
.83595 .12607 L
.83508 .12819 L
.83245 .13578 L
.83043 .14549 L
.82585 .15521 L
.82537 .15638 L
.82238 .16492 L
.82013 .17463 L
.81566 .18431 L
.81564 .18434 L
.81222 .19406 L
.8097 .20377 L
.80594 .21201 L
.80541 .21348 L
.80195 .22319 L
.79916 .23291 L
.79623 .23943 L
.79507 .24262 L
.79158 .25233 L
.78852 .26204 L
.78652 .26656 L
.78461 .27176 L
.78286 .28147 L
.77777 .29118 L
.77681 .2934 L
.77405 .30089 L
.7717 .31061 L
.76709 .31996 L
.76696 .32032 L
.76336 .33003 L
.76049 .33974 L
.75738 .3463 L
.75618 .34946 L
.75255 .35917 L
.74924 .36888 L
.74767 .37231 L
.74527 .37859 L
.74301 .38831 L
.73796 .39799 L
.73795 .39802 L
.73422 .40773 L
.73122 .41744 L
.72824 .42348 L
.72679 .42716 L
.72304 .43687 L
.71947 .44658 L
.71853 .44858 L
.71549 .45629 L
.71273 .46601 L
.70882 .47344 L
.70789 .47572 L
.70404 .48543 L
.70049 .49514 L
.69911 .49795 L
.69631 .50486 L
.69359 .51457 L
.68939 .52219 L
.68851 .52428 L
.68456 .53399 L
.68087 .54371 L
.67968 .54606 L
.67662 .55342 L
.67365 .56313 L
.66997 .56967 L
.6686 .57284 L
.66454 .58256 L
.66055 .59227 L
.66026 .59284 L
.65637 .60198 L
.65285 .61169 L
.65054 .61581 L
.64809 .62141 L
.64543 .63112 L
.64083 .63839 L
.63972 .64083 L
.63546 .65054 L
.63125 .66026 L
.63112 .66049 L
.6269 .66997 L
.62302 .67968 L
.62141 .6824 L
.61821 .68939 L
.61486 .69911 L
.61169 .70393 L
.60938 .70882 L
.6049 .71853 L
.60198 .72505 L
.6004 .72824 L
.59584 .73796 L
.59227 .74574 L
.59126 .74767 L
.5866 .75738 L
.58256 .76598 L
.58193 .76709 L
.57717 .77681 L
.57284 .7858 L
.5724 .78652 L
.56753 .79623 L
.56313 .80522 L
.56264 .80594 L
.55765 .81566 L
.55342 .82428 L
.55262 .82537 L
.54748 .83508 L
.54371 .8429 L
.54228 .84479 L
.53695 .85451 L
.53399 .86081 L
.53153 .86422 L
.52597 .87393 L
.52428 .87755 L
.52021 .88364 L
.51457 .89288 L
.50786 .88364 L
.51204 .87393 L
.51457 .86812 L
.5163 .86422 L
.52062 .85451 L
.52428 .84627 L
.52494 .84479 L
.52931 .83508 L
.53345 .82537 L
.53399 .82452 L
.53803 .81566 L
.54237 .80594 L
.54371 .80264 L
.54673 .79623 L
.55106 .78652 L
.55342 .78075 L
.55538 .77681 L
.55968 .76709 L
.56313 .75892 L
.56397 .75738 L
.56825 .74767 L
.57237 .73796 L
.57284 .7371 L
.57674 .72824 L
.58032 .71853 L
.58256 .71463 L
.58515 .70882 L
.58787 .69911 L
.59227 .69201 L
.59348 .68939 L
.59763 .67968 L
.60168 .66997 L
.60198 .66937 L
.60586 .66026 L
.60937 .65054 L
.61169 .64619 L
.614 .64083 L
.6166 .63112 L
.62141 .62289 L
.62207 .62141 L
.62609 .61169 L
.6298 .60198 L
.63112 .59933 L
.63405 .59227 L
.63703 .58256 L
.64083 .57544 L
.64193 .57284 L
.64586 .56313 L
.64958 .55342 L
.65054 .55139 L
.65365 .54371 L
.65665 .53399 L
.66026 .52697 L
.66136 .52428 L
.66521 .51457 L
.66881 .50486 L
.66997 .50237 L
.67283 .49514 L
.67565 .48543 L
.67968 .47745 L
.68038 .47572 L
.68415 .46601 L
.68753 .45629 L
.68939 .45228 L
.69162 .44658 L
.69404 .43687 L
.699 .42716 L
.69911 .42692 L
.70272 .41744 L
.70574 .40773 L
.70882 .40116 L
.71004 .39802 L
.71172 .38831 L
.71705 .37859 L
.71853 .37524 L
.72093 .36888 L
.72333 .35917 L
.72808 .34946 L
.72824 .34907 L
.7317 .33974 L
.73454 .33003 L
.73796 .32257 L
.7388 .32032 L
.74235 .31061 L
.74546 .30089 L
.74767 .29585 L
.74939 .29118 L
.75128 .28147 L
.75618 .27176 L
.75738 .2689 L
.75987 .26204 L
.76216 .25233 L
.76672 .24262 L
.76709 .2417 L
.77024 .23291 L
.77279 .22319 L
.77681 .21423 L
.77708 .21348 L
.78051 .20377 L
.78324 .19406 L
.78652 .18649 L
.78729 .18434 L
.79068 .17463 L
.79353 .16492 L
.79623 .15852 L
.7974 .15521 L
.7987 .14549 L
.80368 .13578 L
.80594 .13031 L
.80742 .12607 L
.8089 .11636 L
.81371 .10664 L
.81566 .10186 L
.81736 .09693 L
.81894 .08722 L
.82363 .07751 L
.82537 .07316 L
.8272 .06779 L
.82883 .05808 L
.83344 .04837 L
.83508 .04423 L
.83697 .03866 L
.83859 .02894 L
.84315 .01923 L
F
0 g
.87178 .01923 m
.87024 .02894 L
.86558 .03866 L
.86422 .04205 L
.86208 .04837 L
.8605 .05808 L
.85581 .06779 L
.85451 .07102 L
.85229 .07751 L
.85062 .08722 L
.84593 .09693 L
.84479 .09974 L
.84241 .10664 L
.84059 .11636 L
.83595 .12607 L
.83508 .12819 L
.83245 .13578 L
.83043 .14549 L
.82585 .15521 L
.82537 .15638 L
.82238 .16492 L
.82013 .17463 L
.81566 .18431 L
.81564 .18434 L
.81222 .19406 L
.8097 .20377 L
.80594 .21201 L
.80541 .21348 L
.80195 .22319 L
.79916 .23291 L
.79623 .23943 L
.79507 .24262 L
.79158 .25233 L
.78852 .26204 L
.78652 .26656 L
.78461 .27176 L
.78286 .28147 L
.77777 .29118 L
.77681 .2934 L
.77405 .30089 L
.7717 .31061 L
.76709 .31996 L
.76696 .32032 L
.76336 .33003 L
.76049 .33974 L
.75738 .3463 L
.75618 .34946 L
.75255 .35917 L
.74924 .36888 L
.74767 .37231 L
Mistroke
.74527 .37859 L
.74301 .38831 L
.73796 .39799 L
.73795 .39802 L
.73422 .40773 L
.73122 .41744 L
.72824 .42348 L
.72679 .42716 L
.72304 .43687 L
.71947 .44658 L
.71853 .44858 L
.71549 .45629 L
.71273 .46601 L
.70882 .47344 L
.70789 .47572 L
.70404 .48543 L
.70049 .49514 L
.69911 .49795 L
.69631 .50486 L
.69359 .51457 L
.68939 .52219 L
.68851 .52428 L
.68456 .53399 L
.68087 .54371 L
.67968 .54606 L
.67662 .55342 L
.67365 .56313 L
.66997 .56967 L
.6686 .57284 L
.66454 .58256 L
.66055 .59227 L
.66026 .59284 L
.65637 .60198 L
.65285 .61169 L
.65054 .61581 L
.64809 .62141 L
.64543 .63112 L
.64083 .63839 L
.63972 .64083 L
.63546 .65054 L
.63125 .66026 L
.63112 .66049 L
.6269 .66997 L
.62302 .67968 L
.62141 .6824 L
.61821 .68939 L
.61486 .69911 L
.61169 .70393 L
.60938 .70882 L
.6049 .71853 L
Mistroke
.60198 .72505 L
.6004 .72824 L
.59584 .73796 L
.59227 .74574 L
.59126 .74767 L
.5866 .75738 L
.58256 .76598 L
.58193 .76709 L
.57717 .77681 L
.57284 .7858 L
.5724 .78652 L
.56753 .79623 L
.56313 .80522 L
.56264 .80594 L
.55765 .81566 L
.55342 .82428 L
.55262 .82537 L
.54748 .83508 L
.54371 .8429 L
.54228 .84479 L
.53695 .85451 L
.53399 .86081 L
.53153 .86422 L
.52597 .87393 L
.52428 .87755 L
.52021 .88364 L
.51457 .89288 L
.50786 .88364 L
.51204 .87393 L
.51457 .86812 L
.5163 .86422 L
.52062 .85451 L
.52428 .84627 L
.52494 .84479 L
.52931 .83508 L
.53345 .82537 L
.53399 .82452 L
.53803 .81566 L
.54237 .80594 L
.54371 .80264 L
.54673 .79623 L
.55106 .78652 L
.55342 .78075 L
.55538 .77681 L
.55968 .76709 L
.56313 .75892 L
.56397 .75738 L
.56825 .74767 L
.57237 .73796 L
.57284 .7371 L
Mistroke
.57674 .72824 L
.58032 .71853 L
.58256 .71463 L
.58515 .70882 L
.58787 .69911 L
.59227 .69201 L
.59348 .68939 L
.59763 .67968 L
.60168 .66997 L
.60198 .66937 L
.60586 .66026 L
.60937 .65054 L
.61169 .64619 L
.614 .64083 L
.6166 .63112 L
.62141 .62289 L
.62207 .62141 L
.62609 .61169 L
.6298 .60198 L
.63112 .59933 L
.63405 .59227 L
.63703 .58256 L
.64083 .57544 L
.64193 .57284 L
.64586 .56313 L
.64958 .55342 L
.65054 .55139 L
.65365 .54371 L
.65665 .53399 L
.66026 .52697 L
.66136 .52428 L
.66521 .51457 L
.66881 .50486 L
.66997 .50237 L
.67283 .49514 L
.67565 .48543 L
.67968 .47745 L
.68038 .47572 L
.68415 .46601 L
.68753 .45629 L
.68939 .45228 L
.69162 .44658 L
.69404 .43687 L
.699 .42716 L
.69911 .42692 L
.70272 .41744 L
.70574 .40773 L
.70882 .40116 L
.71004 .39802 L
.71172 .38831 L
Mistroke
.71705 .37859 L
.71853 .37524 L
.72093 .36888 L
.72333 .35917 L
.72808 .34946 L
.72824 .34907 L
.7317 .33974 L
.73454 .33003 L
.73796 .32257 L
.7388 .32032 L
.74235 .31061 L
.74546 .30089 L
.74767 .29585 L
.74939 .29118 L
.75128 .28147 L
.75618 .27176 L
.75738 .2689 L
.75987 .26204 L
.76216 .25233 L
.76672 .24262 L
.76709 .2417 L
.77024 .23291 L
.77279 .22319 L
.77681 .21423 L
.77708 .21348 L
.78051 .20377 L
.78324 .19406 L
.78652 .18649 L
.78729 .18434 L
.79068 .17463 L
.79353 .16492 L
.79623 .15852 L
.7974 .15521 L
.7987 .14549 L
.80368 .13578 L
.80594 .13031 L
.80742 .12607 L
.8089 .11636 L
.81371 .10664 L
.81566 .10186 L
.81736 .09693 L
.81894 .08722 L
.82363 .07751 L
.82537 .07316 L
.8272 .06779 L
.82883 .05808 L
.83344 .04837 L
.83508 .04423 L
.83697 .03866 L
.83859 .02894 L
Mistroke
.84315 .01923 L
Mfstroke
.5 g
.50815 .98077 m
.51326 .97106 L
.51457 .96853 L
.51831 .96134 L
.52331 .95163 L
.52428 .94971 L
.52826 .94192 L
.53316 .93221 L
.53399 .93052 L
.53802 .92249 L
.54282 .91278 L
.54371 .91095 L
.54759 .90307 L
.5523 .89336 L
.55342 .89102 L
.55699 .88364 L
.56163 .87393 L
.56313 .87074 L
.56623 .86422 L
.5708 .85451 L
.57284 .8501 L
.57532 .84479 L
.57983 .83508 L
.58256 .82911 L
.58428 .82537 L
.58873 .81566 L
.59227 .80778 L
.5931 .80594 L
.59749 .79623 L
.60181 .78652 L
.60198 .78612 L
.60613 .77681 L
.61041 .76709 L
.61169 .76413 L
.61466 .75738 L
.6189 .74767 L
.62141 .74182 L
.62308 .73796 L
.62728 .72824 L
.63112 .71918 L
.6314 .71853 L
.63555 .70882 L
.63964 .69911 L
.64083 .69623 L
.64372 .68939 L
.64779 .67968 L
.65054 .67297 L
.65179 .66997 L
.65583 .66026 L
.6598 .65054 L
.66026 .64941 L
.66378 .64083 L
.66774 .63112 L
.66997 .62554 L
.67164 .62141 L
.67558 .61169 L
.67944 .60198 L
.67968 .60137 L
.68333 .59227 L
.68719 .58256 L
.68939 .5769 L
.691 .57284 L
.69484 .56313 L
.69862 .55342 L
.69911 .55215 L
.70241 .54371 L
.70619 .53399 L
.70882 .52711 L
.70991 .52428 L
.71367 .51457 L
.71738 .50486 L
.71853 .50178 L
.72107 .49514 L
.72478 .48543 L
.72824 .47617 L
.72841 .47572 L
.73209 .46601 L
.73575 .45629 L
.73796 .45028 L
.73934 .44658 L
.74298 .43687 L
.74657 .42716 L
.74767 .42412 L
.75014 .41744 L
.75374 .40773 L
.75726 .39802 L
.75738 .39768 L
.76082 .38831 L
.76438 .37859 L
.76709 .37097 L
.76785 .36888 L
.77139 .35917 L
.77489 .34946 L
.77681 .344 L
.77834 .33974 L
.78184 .33003 L
.78529 .32032 L
.78652 .31676 L
.78871 .31061 L
.79218 .30089 L
.79558 .29118 L
.79623 .28926 L
.79898 .28147 L
.80241 .27176 L
.80576 .26204 L
.80594 .2615 L
.80916 .25233 L
.81255 .24262 L
.81566 .23349 L
.81586 .23291 L
.81923 .22319 L
.82259 .21348 L
.82537 .20522 L
.82587 .20377 L
.82921 .19406 L
.83254 .18434 L
.83508 .1767 L
.83578 .17463 L
.8391 .16492 L
.8424 .15521 L
.84479 .14792 L
.84561 .14549 L
.8489 .13578 L
.85217 .12607 L
.85451 .1189 L
.85536 .11636 L
.85862 .10664 L
.86186 .09693 L
.86422 .08964 L
.86502 .08722 L
.86826 .07751 L
.87147 .06779 L
.87393 .06013 L
.8746 .05808 L
.87781 .04837 L
.88101 .03866 L
.88364 .03037 L
.88411 .02894 L
.88729 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.50815 .98077 m
.51326 .97106 L
.51457 .96853 L
.51831 .96134 L
.52331 .95163 L
.52428 .94971 L
.52826 .94192 L
.53316 .93221 L
.53399 .93052 L
.53802 .92249 L
.54282 .91278 L
.54371 .91095 L
.54759 .90307 L
.5523 .89336 L
.55342 .89102 L
.55699 .88364 L
.56163 .87393 L
.56313 .87074 L
.56623 .86422 L
.5708 .85451 L
.57284 .8501 L
.57532 .84479 L
.57983 .83508 L
.58256 .82911 L
.58428 .82537 L
.58873 .81566 L
.59227 .80778 L
.5931 .80594 L
.59749 .79623 L
.60181 .78652 L
.60198 .78612 L
.60613 .77681 L
.61041 .76709 L
.61169 .76413 L
.61466 .75738 L
.6189 .74767 L
.62141 .74182 L
.62308 .73796 L
.62728 .72824 L
.63112 .71918 L
.6314 .71853 L
.63555 .70882 L
.63964 .69911 L
.64083 .69623 L
.64372 .68939 L
.64779 .67968 L
.65054 .67297 L
.65179 .66997 L
.65583 .66026 L
.6598 .65054 L
Mistroke
.66026 .64941 L
.66378 .64083 L
.66774 .63112 L
.66997 .62554 L
.67164 .62141 L
.67558 .61169 L
.67944 .60198 L
.67968 .60137 L
.68333 .59227 L
.68719 .58256 L
.68939 .5769 L
.691 .57284 L
.69484 .56313 L
.69862 .55342 L
.69911 .55215 L
.70241 .54371 L
.70619 .53399 L
.70882 .52711 L
.70991 .52428 L
.71367 .51457 L
.71738 .50486 L
.71853 .50178 L
.72107 .49514 L
.72478 .48543 L
.72824 .47617 L
.72841 .47572 L
.73209 .46601 L
.73575 .45629 L
.73796 .45028 L
.73934 .44658 L
.74298 .43687 L
.74657 .42716 L
.74767 .42412 L
.75014 .41744 L
.75374 .40773 L
.75726 .39802 L
.75738 .39768 L
.76082 .38831 L
.76438 .37859 L
.76709 .37097 L
.76785 .36888 L
.77139 .35917 L
.77489 .34946 L
.77681 .344 L
.77834 .33974 L
.78184 .33003 L
.78529 .32032 L
.78652 .31676 L
.78871 .31061 L
.79218 .30089 L
Mistroke
.79558 .29118 L
.79623 .28926 L
.79898 .28147 L
.80241 .27176 L
.80576 .26204 L
.80594 .2615 L
.80916 .25233 L
.81255 .24262 L
.81566 .23349 L
.81586 .23291 L
.81923 .22319 L
.82259 .21348 L
.82537 .20522 L
.82587 .20377 L
.82921 .19406 L
.83254 .18434 L
.83508 .1767 L
.83578 .17463 L
.8391 .16492 L
.8424 .15521 L
.84479 .14792 L
.84561 .14549 L
.8489 .13578 L
.85217 .12607 L
.85451 .1189 L
.85536 .11636 L
.85862 .10664 L
.86186 .09693 L
.86422 .08964 L
.86502 .08722 L
.86826 .07751 L
.87147 .06779 L
.87393 .06013 L
.8746 .05808 L
.87781 .04837 L
.88101 .03866 L
.88364 .03037 L
.88411 .02894 L
.88729 .01923 L
Mfstroke
.6 g
.52125 .98077 m
.52428 .97479 L
.52615 .97106 L
.53101 .96134 L
.53399 .95535 L
.53582 .95163 L
.5406 .94192 L
.54371 .93555 L
.54532 .93221 L
.55002 .92249 L
.55342 .9154 L
.55466 .91278 L
.55928 .90307 L
.56313 .8949 L
.56385 .89336 L
.56839 .88364 L
.57284 .87406 L
.5729 .87393 L
.57737 .86422 L
.58182 .85451 L
.58256 .85288 L
.58621 .84479 L
.5906 .83508 L
.59227 .83137 L
.59494 .82537 L
.59927 .81566 L
.60198 .80953 L
.60355 .80594 L
.60782 .79623 L
.61169 .78737 L
.61206 .78652 L
.61626 .77681 L
.62046 .76709 L
.62141 .76488 L
.6246 .75738 L
.62875 .74767 L
.63112 .74209 L
.63285 .73796 L
.63694 .72824 L
.64083 .71898 L
.64102 .71853 L
.64505 .70882 L
.64908 .69911 L
.65054 .69557 L
.65307 .68939 L
.65706 .67968 L
.66026 .67186 L
.66102 .66997 L
.66495 .66026 L
.66888 .65054 L
.66997 .64785 L
.67276 .64083 L
.67666 .63112 L
.67968 .62354 L
.68052 .62141 L
.68436 .61169 L
.6882 .60198 L
.68939 .59895 L
.69199 .59227 L
.69579 .58256 L
.69911 .57406 L
.69957 .57284 L
.70332 .56313 L
.70708 .55342 L
.70882 .54889 L
.71078 .54371 L
.7145 .53399 L
.71821 .52428 L
.71853 .52345 L
.72187 .51457 L
.72555 .50486 L
.72824 .49772 L
.72919 .49514 L
.73282 .48543 L
.73647 .47572 L
.73796 .47171 L
.74005 .46601 L
.74365 .45629 L
.74725 .44658 L
.74767 .44544 L
.75078 .43687 L
.75436 .42716 L
.75738 .41889 L
.7579 .41744 L
.76141 .40773 L
.76495 .39802 L
.76709 .39208 L
.76843 .38831 L
.77192 .37859 L
.77542 .36888 L
.77681 .365 L
.77885 .35917 L
.78232 .34946 L
.78578 .33974 L
.78652 .33766 L
.78918 .33003 L
.79262 .32032 L
.79604 .31061 L
.79623 .31007 L
.7994 .30089 L
.80281 .29118 L
.80594 .28221 L
.80619 .28147 L
.80953 .27176 L
.81291 .26204 L
.81566 .2541 L
.81625 .25233 L
.81956 .24262 L
.82291 .23291 L
.82537 .22574 L
.82621 .22319 L
.8295 .21348 L
.83283 .20377 L
.83508 .19712 L
.83609 .19406 L
.83936 .18434 L
.84265 .17463 L
.84479 .16826 L
.84588 .16492 L
.84912 .15521 L
.85239 .14549 L
.85451 .13915 L
.8556 .13578 L
.85881 .12607 L
.86205 .11636 L
.86422 .1098 L
.86523 .10664 L
.86841 .09693 L
.87163 .08722 L
.87393 .08021 L
.87479 .07751 L
.87794 .06779 L
.88114 .05808 L
.88364 .05038 L
.88427 .04837 L
.88739 .03866 L
.89056 .02894 L
.89336 .02031 L
.89369 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.52125 .98077 m
.52428 .97479 L
.52615 .97106 L
.53101 .96134 L
.53399 .95535 L
.53582 .95163 L
.5406 .94192 L
.54371 .93555 L
.54532 .93221 L
.55002 .92249 L
.55342 .9154 L
.55466 .91278 L
.55928 .90307 L
.56313 .8949 L
.56385 .89336 L
.56839 .88364 L
.57284 .87406 L
.5729 .87393 L
.57737 .86422 L
.58182 .85451 L
.58256 .85288 L
.58621 .84479 L
.5906 .83508 L
.59227 .83137 L
.59494 .82537 L
.59927 .81566 L
.60198 .80953 L
.60355 .80594 L
.60782 .79623 L
.61169 .78737 L
.61206 .78652 L
.61626 .77681 L
.62046 .76709 L
.62141 .76488 L
.6246 .75738 L
.62875 .74767 L
.63112 .74209 L
.63285 .73796 L
.63694 .72824 L
.64083 .71898 L
.64102 .71853 L
.64505 .70882 L
.64908 .69911 L
.65054 .69557 L
.65307 .68939 L
.65706 .67968 L
.66026 .67186 L
.66102 .66997 L
.66495 .66026 L
.66888 .65054 L
Mistroke
.66997 .64785 L
.67276 .64083 L
.67666 .63112 L
.67968 .62354 L
.68052 .62141 L
.68436 .61169 L
.6882 .60198 L
.68939 .59895 L
.69199 .59227 L
.69579 .58256 L
.69911 .57406 L
.69957 .57284 L
.70332 .56313 L
.70708 .55342 L
.70882 .54889 L
.71078 .54371 L
.7145 .53399 L
.71821 .52428 L
.71853 .52345 L
.72187 .51457 L
.72555 .50486 L
.72824 .49772 L
.72919 .49514 L
.73282 .48543 L
.73647 .47572 L
.73796 .47171 L
.74005 .46601 L
.74365 .45629 L
.74725 .44658 L
.74767 .44544 L
.75078 .43687 L
.75436 .42716 L
.75738 .41889 L
.7579 .41744 L
.76141 .40773 L
.76495 .39802 L
.76709 .39208 L
.76843 .38831 L
.77192 .37859 L
.77542 .36888 L
.77681 .365 L
.77885 .35917 L
.78232 .34946 L
.78578 .33974 L
.78652 .33766 L
.78918 .33003 L
.79262 .32032 L
.79604 .31061 L
.79623 .31007 L
.7994 .30089 L
Mistroke
.80281 .29118 L
.80594 .28221 L
.80619 .28147 L
.80953 .27176 L
.81291 .26204 L
.81566 .2541 L
.81625 .25233 L
.81956 .24262 L
.82291 .23291 L
.82537 .22574 L
.82621 .22319 L
.8295 .21348 L
.83283 .20377 L
.83508 .19712 L
.83609 .19406 L
.83936 .18434 L
.84265 .17463 L
.84479 .16826 L
.84588 .16492 L
.84912 .15521 L
.85239 .14549 L
.85451 .13915 L
.8556 .13578 L
.85881 .12607 L
.86205 .11636 L
.86422 .1098 L
.86523 .10664 L
.86841 .09693 L
.87163 .08722 L
.87393 .08021 L
.87479 .07751 L
.87794 .06779 L
.88114 .05808 L
.88364 .05038 L
.88427 .04837 L
.88739 .03866 L
.89056 .02894 L
.89336 .02031 L
.89369 .01923 L
Mfstroke
.7 g
.53475 .98077 m
.53943 .97106 L
.54371 .9623 L
.54414 .96134 L
.54873 .95163 L
.55339 .94192 L
.55342 .94186 L
.55787 .93221 L
.56247 .92249 L
.56313 .92109 L
.56689 .91278 L
.57141 .90307 L
.57284 .89999 L
.57577 .89336 L
.58023 .88364 L
.58256 .87856 L
.58455 .87393 L
.58892 .86422 L
.59227 .85681 L
.59323 .85451 L
.59749 .84479 L
.60183 .83508 L
.60198 .83475 L
.60597 .82537 L
.61025 .81566 L
.61169 .81236 L
.61435 .80594 L
.61856 .79623 L
.62141 .78967 L
.62267 .78652 L
.62677 .77681 L
.63094 .76709 L
.63112 .76668 L
.6349 .75738 L
.63902 .74767 L
.64083 .74338 L
.64296 .73796 L
.647 .72824 L
.65054 .71978 L
.65101 .71853 L
.6549 .70882 L
.65893 .69911 L
.66026 .69589 L
.66275 .68939 L
.66671 .67968 L
.66997 .67171 L
.6706 .66997 L
.67441 .66026 L
.67835 .65054 L
.67968 .64723 L
.68207 .64083 L
.68593 .63112 L
.68939 .62248 L
.68977 .62141 L
.69346 .61169 L
.69731 .60198 L
.69911 .59743 L
.70096 .59227 L
.70472 .58256 L
.70854 .57284 L
.70882 .57212 L
.71209 .56313 L
.71586 .55342 L
.71853 .54651 L
.71949 .54371 L
.72311 .53399 L
.72685 .52428 L
.72824 .52064 L
.73036 .51457 L
.73401 .50486 L
.73772 .49514 L
.73796 .49451 L
.74114 .48543 L
.7448 .47572 L
.74767 .46809 L
.74835 .46601 L
.75182 .45629 L
.75546 .44658 L
.75738 .44141 L
.75888 .43687 L
.76239 .42716 L
.766 .41744 L
.76709 .41447 L
.76933 .40773 L
.77286 .39802 L
.77643 .38831 L
.77681 .38727 L
.7797 .37859 L
.78322 .36888 L
.78652 .35981 L
.78671 .35917 L
.78997 .34946 L
.79348 .33974 L
.79623 .33209 L
.79685 .33003 L
.80015 .32032 L
.80363 .31061 L
.80594 .30412 L
.80692 .30089 L
.81023 .29118 L
.81369 .28147 L
.81566 .2759 L
.81691 .27176 L
.82022 .26204 L
.82365 .25233 L
.82537 .24743 L
.82682 .24262 L
.83012 .23291 L
.83353 .22319 L
.83508 .21871 L
.83665 .21348 L
.83993 .20377 L
.84331 .19406 L
.84479 .18974 L
.84639 .18434 L
.84965 .17463 L
.85301 .16492 L
.85451 .16053 L
.85606 .15521 L
.8593 .14549 L
.86263 .13578 L
.86422 .13108 L
.86566 .12607 L
.86886 .11636 L
.87216 .10664 L
.87393 .10139 L
.87519 .09693 L
.87834 .08722 L
.88162 .07751 L
.88364 .07146 L
.88465 .06779 L
.88774 .05808 L
.89101 .04837 L
.89336 .0413 L
.89405 .03866 L
.89708 .02894 L
.90031 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.53475 .98077 m
.53943 .97106 L
.54371 .9623 L
.54414 .96134 L
.54873 .95163 L
.55339 .94192 L
.55342 .94186 L
.55787 .93221 L
.56247 .92249 L
.56313 .92109 L
.56689 .91278 L
.57141 .90307 L
.57284 .89999 L
.57577 .89336 L
.58023 .88364 L
.58256 .87856 L
.58455 .87393 L
.58892 .86422 L
.59227 .85681 L
.59323 .85451 L
.59749 .84479 L
.60183 .83508 L
.60198 .83475 L
.60597 .82537 L
.61025 .81566 L
.61169 .81236 L
.61435 .80594 L
.61856 .79623 L
.62141 .78967 L
.62267 .78652 L
.62677 .77681 L
.63094 .76709 L
.63112 .76668 L
.6349 .75738 L
.63902 .74767 L
.64083 .74338 L
.64296 .73796 L
.647 .72824 L
.65054 .71978 L
.65101 .71853 L
.6549 .70882 L
.65893 .69911 L
.66026 .69589 L
.66275 .68939 L
.66671 .67968 L
.66997 .67171 L
.6706 .66997 L
.67441 .66026 L
.67835 .65054 L
.67968 .64723 L
Mistroke
.68207 .64083 L
.68593 .63112 L
.68939 .62248 L
.68977 .62141 L
.69346 .61169 L
.69731 .60198 L
.69911 .59743 L
.70096 .59227 L
.70472 .58256 L
.70854 .57284 L
.70882 .57212 L
.71209 .56313 L
.71586 .55342 L
.71853 .54651 L
.71949 .54371 L
.72311 .53399 L
.72685 .52428 L
.72824 .52064 L
.73036 .51457 L
.73401 .50486 L
.73772 .49514 L
.73796 .49451 L
.74114 .48543 L
.7448 .47572 L
.74767 .46809 L
.74835 .46601 L
.75182 .45629 L
.75546 .44658 L
.75738 .44141 L
.75888 .43687 L
.76239 .42716 L
.766 .41744 L
.76709 .41447 L
.76933 .40773 L
.77286 .39802 L
.77643 .38831 L
.77681 .38727 L
.7797 .37859 L
.78322 .36888 L
.78652 .35981 L
.78671 .35917 L
.78997 .34946 L
.79348 .33974 L
.79623 .33209 L
.79685 .33003 L
.80015 .32032 L
.80363 .31061 L
.80594 .30412 L
.80692 .30089 L
.81023 .29118 L
Mistroke
.81369 .28147 L
.81566 .2759 L
.81691 .27176 L
.82022 .26204 L
.82365 .25233 L
.82537 .24743 L
.82682 .24262 L
.83012 .23291 L
.83353 .22319 L
.83508 .21871 L
.83665 .21348 L
.83993 .20377 L
.84331 .19406 L
.84479 .18974 L
.84639 .18434 L
.84965 .17463 L
.85301 .16492 L
.85451 .16053 L
.85606 .15521 L
.8593 .14549 L
.86263 .13578 L
.86422 .13108 L
.86566 .12607 L
.86886 .11636 L
.87216 .10664 L
.87393 .10139 L
.87519 .09693 L
.87834 .08722 L
.88162 .07751 L
.88364 .07146 L
.88465 .06779 L
.88774 .05808 L
.89101 .04837 L
.89336 .0413 L
.89405 .03866 L
.89708 .02894 L
.90031 .01923 L
Mfstroke
.8 g
.55423 .98077 m
.55855 .97106 L
.56272 .96134 L
.56313 .96061 L
.56711 .95163 L
.57074 .94192 L
.57284 .93834 L
.57561 .93221 L
.57841 .92249 L
.58256 .91594 L
.58403 .91278 L
.58822 .90307 L
.59227 .89356 L
.59237 .89336 L
.59653 .88364 L
.60024 .87393 L
.60198 .87067 L
.60477 .86422 L
.6077 .85451 L
.61169 .84755 L
.61292 .84479 L
.61698 .83508 L
.6209 .82537 L
.62141 .82435 L
.62502 .81566 L
.62836 .80594 L
.63112 .80067 L
.63299 .79623 L
.63529 .78652 L
.64083 .77692 L
.64088 .77681 L
.64482 .76709 L
.64823 .75738 L
.65054 .75273 L
.65262 .74767 L
.65504 .73796 L
.66026 .72843 L
.66034 .72824 L
.66419 .71853 L
.66749 .70882 L
.66997 .70372 L
.67182 .69911 L
.67406 .68939 L
.67932 .67968 L
.67968 .67888 L
.68316 .66997 L
.6862 .66026 L
.68939 .65366 L
.69063 .65054 L
.69237 .64083 L
.69782 .63112 L
.69911 .62826 L
.70174 .62141 L
.70434 .61169 L
.70882 .60259 L
.70906 .60198 L
.71272 .59227 L
.7158 .58256 L
.71853 .5766 L
.71997 .57284 L
.72178 .56313 L
.72694 .55342 L
.72824 .55042 L
.73075 .54371 L
.73317 .53399 L
.73784 .52428 L
.73796 .524 L
.74142 .51457 L
.74421 .50486 L
.74767 .49724 L
.74845 .49514 L
.75197 .48543 L
.75501 .47572 L
.75738 .47027 L
.75894 .46601 L
.76069 .45629 L
.76561 .44658 L
.76709 .44306 L
.76932 .43687 L
.77143 .42716 L
.77606 .41744 L
.77681 .41561 L
.7796 .40773 L
.78196 .39802 L
.78636 .38831 L
.78652 .38791 L
.78978 .37859 L
.79231 .36888 L
.79623 .35993 L
.7965 .35917 L
.79987 .34946 L
.8025 .33974 L
.80594 .3317 L
.80653 .33003 L
.80987 .32032 L
.81257 .31061 L
.81566 .30324 L
.81647 .30089 L
.81978 .29118 L
.82251 .28147 L
.82537 .27455 L
.82633 .27176 L
.82961 .26204 L
.83234 .25233 L
.83508 .24561 L
.8361 .24262 L
.83936 .23291 L
.84206 .22319 L
.84479 .21644 L
.8458 .21348 L
.84902 .20377 L
.85167 .19406 L
.85451 .18703 L
.85541 .18434 L
.85861 .17463 L
.86119 .16492 L
.86422 .15739 L
.86495 .15521 L
.86813 .14549 L
.8706 .13578 L
.87393 .12751 L
.87441 .12607 L
.87757 .11636 L
.87991 .10664 L
.88364 .09742 L
.8838 .09693 L
.88694 .08722 L
.8891 .07751 L
.89309 .06779 L
.89336 .06708 L
.89625 .05808 L
.89818 .04837 L
.90227 .03866 L
.90307 .03649 L
.90548 .02894 L
.90711 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.55423 .98077 m
.55855 .97106 L
.56272 .96134 L
.56313 .96061 L
.56711 .95163 L
.57074 .94192 L
.57284 .93834 L
.57561 .93221 L
.57841 .92249 L
.58256 .91594 L
.58403 .91278 L
.58822 .90307 L
.59227 .89356 L
.59237 .89336 L
.59653 .88364 L
.60024 .87393 L
.60198 .87067 L
.60477 .86422 L
.6077 .85451 L
.61169 .84755 L
.61292 .84479 L
.61698 .83508 L
.6209 .82537 L
.62141 .82435 L
.62502 .81566 L
.62836 .80594 L
.63112 .80067 L
.63299 .79623 L
.63529 .78652 L
.64083 .77692 L
.64088 .77681 L
.64482 .76709 L
.64823 .75738 L
.65054 .75273 L
.65262 .74767 L
.65504 .73796 L
.66026 .72843 L
.66034 .72824 L
.66419 .71853 L
.66749 .70882 L
.66997 .70372 L
.67182 .69911 L
.67406 .68939 L
.67932 .67968 L
.67968 .67888 L
.68316 .66997 L
.6862 .66026 L
.68939 .65366 L
.69063 .65054 L
.69237 .64083 L
Mistroke
.69782 .63112 L
.69911 .62826 L
.70174 .62141 L
.70434 .61169 L
.70882 .60259 L
.70906 .60198 L
.71272 .59227 L
.7158 .58256 L
.71853 .5766 L
.71997 .57284 L
.72178 .56313 L
.72694 .55342 L
.72824 .55042 L
.73075 .54371 L
.73317 .53399 L
.73784 .52428 L
.73796 .524 L
.74142 .51457 L
.74421 .50486 L
.74767 .49724 L
.74845 .49514 L
.75197 .48543 L
.75501 .47572 L
.75738 .47027 L
.75894 .46601 L
.76069 .45629 L
.76561 .44658 L
.76709 .44306 L
.76932 .43687 L
.77143 .42716 L
.77606 .41744 L
.77681 .41561 L
.7796 .40773 L
.78196 .39802 L
.78636 .38831 L
.78652 .38791 L
.78978 .37859 L
.79231 .36888 L
.79623 .35993 L
.7965 .35917 L
.79987 .34946 L
.8025 .33974 L
.80594 .3317 L
.80653 .33003 L
.80987 .32032 L
.81257 .31061 L
.81566 .30324 L
.81647 .30089 L
.81978 .29118 L
.82251 .28147 L
Mistroke
.82537 .27455 L
.82633 .27176 L
.82961 .26204 L
.83234 .25233 L
.83508 .24561 L
.8361 .24262 L
.83936 .23291 L
.84206 .22319 L
.84479 .21644 L
.8458 .21348 L
.84902 .20377 L
.85167 .19406 L
.85451 .18703 L
.85541 .18434 L
.85861 .17463 L
.86119 .16492 L
.86422 .15739 L
.86495 .15521 L
.86813 .14549 L
.8706 .13578 L
.87393 .12751 L
.87441 .12607 L
.87757 .11636 L
.87991 .10664 L
.88364 .09742 L
.8838 .09693 L
.88694 .08722 L
.8891 .07751 L
.89309 .06779 L
.89336 .06708 L
.89625 .05808 L
.89818 .04837 L
.90227 .03866 L
.90307 .03649 L
.90548 .02894 L
.90711 .01923 L
Mfstroke
.7 g
.57591 .98077 m
.58067 .97106 L
.58256 .96743 L
.58536 .96134 L
.59002 .95163 L
.59227 .94712 L
.59463 .94192 L
.59919 .93221 L
.60198 .92639 L
.60457 .92249 L
.60819 .91278 L
.61169 .90524 L
.61301 .90307 L
.61704 .89336 L
.62141 .88371 L
.62145 .88364 L
.62575 .87393 L
.63007 .86422 L
.63112 .86198 L
.63434 .85451 L
.63859 .84479 L
.64083 .83977 L
.64357 .83508 L
.64698 .82537 L
.65054 .81714 L
.65133 .81566 L
.65527 .80594 L
.6594 .79623 L
.66026 .79429 L
.66492 .78652 L
.66752 .77681 L
.66997 .77104 L
.67207 .76709 L
.67556 .75738 L
.67957 .74767 L
.67968 .74741 L
.68533 .73796 L
.68746 .72824 L
.68939 .72358 L
.69202 .71853 L
.69528 .70882 L
.69911 .6993 L
.6992 .69911 L
.70477 .68939 L
.70687 .67968 L
.70882 .67483 L
.71125 .66997 L
.71448 .66026 L
.71829 .65054 L
.71853 .64996 L
.72342 .64083 L
.7258 .63112 L
.72824 .62485 L
.72987 .62141 L
.73324 .61169 L
.73696 .60198 L
.73796 .59943 L
.7415 .59227 L
.74429 .58256 L
.74767 .57366 L
.74803 .57284 L
.75315 .56313 L
.75521 .55342 L
.75738 .54768 L
.75919 .54371 L
.76241 .53399 L
.766 .52428 L
.76709 .52139 L
.7703 .51457 L
.7731 .50486 L
.77666 .49514 L
.77681 .49477 L
.78133 .48543 L
.78368 .47572 L
.78652 .46792 L
.78734 .46601 L
.79229 .45629 L
.79414 .44658 L
.79623 .44081 L
.79794 .43687 L
.80104 .42716 L
.80449 .41744 L
.80594 .41341 L
.80843 .40773 L
.81131 .39802 L
.81473 .38831 L
.81566 .38573 L
.81882 .37859 L
.82148 .36888 L
.82487 .35917 L
.82537 .35778 L
.82908 .34946 L
.83155 .33974 L
.83492 .33003 L
.83508 .32956 L
.83922 .32032 L
.84153 .31061 L
.84479 .3011 L
.84487 .30089 L
.84923 .29118 L
.85141 .28147 L
.85451 .27238 L
.85475 .27176 L
.85911 .26204 L
.86121 .25233 L
.86422 .24341 L
.86453 .24262 L
.86886 .23291 L
.87092 .22319 L
.87393 .21419 L
.87421 .21348 L
.87848 .20377 L
.88055 .19406 L
.88364 .18472 L
.88379 .18434 L
.88798 .17463 L
.89009 .16492 L
.89329 .15521 L
.89336 .155 L
.89737 .14549 L
.89956 .13578 L
.90273 .12607 L
.90307 .12505 L
.90666 .11636 L
.90896 .10664 L
.9121 .09693 L
.91278 .09485 L
.91586 .08722 L
.91828 .07751 L
.92139 .06779 L
.92249 .06441 L
.92498 .05808 L
.92754 .04837 L
.93062 .03866 L
.93221 .03372 L
.93404 .02894 L
.93857 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.57591 .98077 m
.58067 .97106 L
.58256 .96743 L
.58536 .96134 L
.59002 .95163 L
.59227 .94712 L
.59463 .94192 L
.59919 .93221 L
.60198 .92639 L
.60457 .92249 L
.60819 .91278 L
.61169 .90524 L
.61301 .90307 L
.61704 .89336 L
.62141 .88371 L
.62145 .88364 L
.62575 .87393 L
.63007 .86422 L
.63112 .86198 L
.63434 .85451 L
.63859 .84479 L
.64083 .83977 L
.64357 .83508 L
.64698 .82537 L
.65054 .81714 L
.65133 .81566 L
.65527 .80594 L
.6594 .79623 L
.66026 .79429 L
.66492 .78652 L
.66752 .77681 L
.66997 .77104 L
.67207 .76709 L
.67556 .75738 L
.67957 .74767 L
.67968 .74741 L
.68533 .73796 L
.68746 .72824 L
.68939 .72358 L
.69202 .71853 L
.69528 .70882 L
.69911 .6993 L
.6992 .69911 L
.70477 .68939 L
.70687 .67968 L
.70882 .67483 L
.71125 .66997 L
.71448 .66026 L
.71829 .65054 L
.71853 .64996 L
Mistroke
.72342 .64083 L
.7258 .63112 L
.72824 .62485 L
.72987 .62141 L
.73324 .61169 L
.73696 .60198 L
.73796 .59943 L
.7415 .59227 L
.74429 .58256 L
.74767 .57366 L
.74803 .57284 L
.75315 .56313 L
.75521 .55342 L
.75738 .54768 L
.75919 .54371 L
.76241 .53399 L
.766 .52428 L
.76709 .52139 L
.7703 .51457 L
.7731 .50486 L
.77666 .49514 L
.77681 .49477 L
.78133 .48543 L
.78368 .47572 L
.78652 .46792 L
.78734 .46601 L
.79229 .45629 L
.79414 .44658 L
.79623 .44081 L
.79794 .43687 L
.80104 .42716 L
.80449 .41744 L
.80594 .41341 L
.80843 .40773 L
.81131 .39802 L
.81473 .38831 L
.81566 .38573 L
.81882 .37859 L
.82148 .36888 L
.82487 .35917 L
.82537 .35778 L
.82908 .34946 L
.83155 .33974 L
.83492 .33003 L
.83508 .32956 L
.83922 .32032 L
.84153 .31061 L
.84479 .3011 L
.84487 .30089 L
.84923 .29118 L
Mistroke
.85141 .28147 L
.85451 .27238 L
.85475 .27176 L
.85911 .26204 L
.86121 .25233 L
.86422 .24341 L
.86453 .24262 L
.86886 .23291 L
.87092 .22319 L
.87393 .21419 L
.87421 .21348 L
.87848 .20377 L
.88055 .19406 L
.88364 .18472 L
.88379 .18434 L
.88798 .17463 L
.89009 .16492 L
.89329 .15521 L
.89336 .155 L
.89737 .14549 L
.89956 .13578 L
.90273 .12607 L
.90307 .12505 L
.90666 .11636 L
.90896 .10664 L
.9121 .09693 L
.91278 .09485 L
.91586 .08722 L
.91828 .07751 L
.92139 .06779 L
.92249 .06441 L
.92498 .05808 L
.92754 .04837 L
.93062 .03866 L
.93221 .03372 L
.93404 .02894 L
.93857 .01923 L
Mfstroke
.6 g
.59365 .98077 m
.59816 .97106 L
.60198 .96229 L
.60241 .96134 L
.60688 .95163 L
.61113 .94192 L
.61169 .94052 L
.61546 .93221 L
.61975 .92249 L
.62141 .91841 L
.62392 .91278 L
.62821 .90307 L
.63112 .89598 L
.63227 .89336 L
.63654 .88364 L
.64056 .87393 L
.64083 .87322 L
.64475 .86422 L
.64885 .85451 L
.65054 .85015 L
.65284 .84479 L
.65698 .83508 L
.66026 .82676 L
.66084 .82537 L
.66496 .81566 L
.6689 .80594 L
.66997 .80306 L
.67283 .79623 L
.67685 .78652 L
.67968 .77906 L
.68061 .77681 L
.68463 .76709 L
.68846 .75738 L
.68939 .75476 L
.69229 .74767 L
.69622 .73796 L
.69911 .73016 L
.69988 .72824 L
.70381 .71853 L
.70758 .70882 L
.70882 .70527 L
.71128 .69911 L
.71514 .68939 L
.71853 .68009 L
.71869 .67968 L
.72253 .66997 L
.72628 .66026 L
.72824 .65463 L
.72984 .65054 L
.73364 .64083 L
.73722 .63112 L
.73796 .62888 L
.74085 .62141 L
.74458 .61169 L
.74767 .60284 L
.748 .60198 L
.75173 .59227 L
.75536 .58256 L
.75738 .57654 L
.75878 .57284 L
.76247 .56313 L
.76599 .55342 L
.76709 .54997 L
.76944 .54371 L
.77309 .53399 L
.77645 .52428 L
.77681 .52311 L
.77999 .51457 L
.78358 .50486 L
.78652 .496 L
.78683 .49514 L
.79042 .48543 L
.79394 .47572 L
.79623 .46862 L
.79718 .46601 L
.80074 .45629 L
.80419 .44658 L
.80594 .44098 L
.80743 .43687 L
.81096 .42716 L
.81433 .41744 L
.81566 .41307 L
.81757 .40773 L
.82107 .39802 L
.82437 .38831 L
.82537 .38491 L
.82762 .37859 L
.83108 .36888 L
.83432 .35917 L
.83508 .3565 L
.83757 .34946 L
.841 .33974 L
.84418 .33003 L
.84479 .32783 L
.84742 .32032 L
.85083 .31061 L
.85397 .30089 L
.85451 .29891 L
.85719 .29118 L
.86057 .28147 L
.86368 .27176 L
.86422 .26974 L
.86687 .26204 L
.87023 .25233 L
.87332 .24262 L
.87393 .24033 L
.87647 .23291 L
.8798 .22319 L
.8829 .21348 L
.88364 .21067 L
.88599 .20377 L
.8893 .19406 L
.89241 .18434 L
.89336 .18078 L
.89542 .17463 L
.89872 .16492 L
.90184 .15521 L
.90307 .15064 L
.90478 .14549 L
.90806 .13578 L
.9112 .12607 L
.91278 .12026 L
.91407 .11636 L
.91732 .10664 L
.92049 .09693 L
.92249 .08965 L
.92329 .08722 L
.92651 .07751 L
.92969 .06779 L
.93221 .0588 L
.93244 .05808 L
.93563 .04837 L
.93882 .03866 L
.94164 .02894 L
.94192 .02772 L
.94468 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.59365 .98077 m
.59816 .97106 L
.60198 .96229 L
.60241 .96134 L
.60688 .95163 L
.61113 .94192 L
.61169 .94052 L
.61546 .93221 L
.61975 .92249 L
.62141 .91841 L
.62392 .91278 L
.62821 .90307 L
.63112 .89598 L
.63227 .89336 L
.63654 .88364 L
.64056 .87393 L
.64083 .87322 L
.64475 .86422 L
.64885 .85451 L
.65054 .85015 L
.65284 .84479 L
.65698 .83508 L
.66026 .82676 L
.66084 .82537 L
.66496 .81566 L
.6689 .80594 L
.66997 .80306 L
.67283 .79623 L
.67685 .78652 L
.67968 .77906 L
.68061 .77681 L
.68463 .76709 L
.68846 .75738 L
.68939 .75476 L
.69229 .74767 L
.69622 .73796 L
.69911 .73016 L
.69988 .72824 L
.70381 .71853 L
.70758 .70882 L
.70882 .70527 L
.71128 .69911 L
.71514 .68939 L
.71853 .68009 L
.71869 .67968 L
.72253 .66997 L
.72628 .66026 L
.72824 .65463 L
.72984 .65054 L
.73364 .64083 L
Mistroke
.73722 .63112 L
.73796 .62888 L
.74085 .62141 L
.74458 .61169 L
.74767 .60284 L
.748 .60198 L
.75173 .59227 L
.75536 .58256 L
.75738 .57654 L
.75878 .57284 L
.76247 .56313 L
.76599 .55342 L
.76709 .54997 L
.76944 .54371 L
.77309 .53399 L
.77645 .52428 L
.77681 .52311 L
.77999 .51457 L
.78358 .50486 L
.78652 .496 L
.78683 .49514 L
.79042 .48543 L
.79394 .47572 L
.79623 .46862 L
.79718 .46601 L
.80074 .45629 L
.80419 .44658 L
.80594 .44098 L
.80743 .43687 L
.81096 .42716 L
.81433 .41744 L
.81566 .41307 L
.81757 .40773 L
.82107 .39802 L
.82437 .38831 L
.82537 .38491 L
.82762 .37859 L
.83108 .36888 L
.83432 .35917 L
.83508 .3565 L
.83757 .34946 L
.841 .33974 L
.84418 .33003 L
.84479 .32783 L
.84742 .32032 L
.85083 .31061 L
.85397 .30089 L
.85451 .29891 L
.85719 .29118 L
.86057 .28147 L
Mistroke
.86368 .27176 L
.86422 .26974 L
.86687 .26204 L
.87023 .25233 L
.87332 .24262 L
.87393 .24033 L
.87647 .23291 L
.8798 .22319 L
.8829 .21348 L
.88364 .21067 L
.88599 .20377 L
.8893 .19406 L
.89241 .18434 L
.89336 .18078 L
.89542 .17463 L
.89872 .16492 L
.90184 .15521 L
.90307 .15064 L
.90478 .14549 L
.90806 .13578 L
.9112 .12607 L
.91278 .12026 L
.91407 .11636 L
.91732 .10664 L
.92049 .09693 L
.92249 .08965 L
.92329 .08722 L
.92651 .07751 L
.92969 .06779 L
.93221 .0588 L
.93244 .05808 L
.93563 .04837 L
.93882 .03866 L
.94164 .02894 L
.94192 .02772 L
.94468 .01923 L
Mfstroke
.5 g
.60499 .98077 m
.60929 .97106 L
.61169 .96552 L
.61353 .96134 L
.61778 .95163 L
.62141 .9432 L
.62196 .94192 L
.62617 .93221 L
.63031 .92249 L
.63112 .92057 L
.63445 .91278 L
.63856 .90307 L
.64083 .89762 L
.64263 .89336 L
.64671 .88364 L
.65054 .87436 L
.65072 .87393 L
.65476 .86422 L
.65876 .85451 L
.66026 .85079 L
.66272 .84479 L
.66669 .83508 L
.66997 .82692 L
.6706 .82537 L
.67454 .81566 L
.67843 .80594 L
.67968 .80275 L
.6823 .79623 L
.68617 .78652 L
.68939 .77829 L
.68998 .77681 L
.69383 .76709 L
.69763 .75738 L
.69911 .75353 L
.7014 .74767 L
.7052 .73796 L
.70882 .72849 L
.70891 .72824 L
.71267 .71853 L
.71641 .70882 L
.71853 .70316 L
.72008 .69911 L
.7238 .68939 L
.72746 .67968 L
.72824 .67755 L
.73112 .66997 L
.73478 .66026 L
.73796 .65166 L
.73837 .65054 L
.74202 .64083 L
.74563 .63112 L
.74767 .6255 L
.74919 .62141 L
.75279 .61169 L
.75634 .60198 L
.75738 .59906 L
.75988 .59227 L
.76344 .58256 L
.76692 .57284 L
.76709 .57236 L
.77045 .56313 L
.77397 .55342 L
.77681 .54538 L
.77741 .54371 L
.78091 .53399 L
.78438 .52428 L
.78652 .51815 L
.78779 .51457 L
.79126 .50486 L
.79469 .49514 L
.79623 .49065 L
.79807 .48543 L
.80151 .47572 L
.80489 .46601 L
.80594 .46289 L
.80825 .45629 L
.81165 .44658 L
.81499 .43687 L
.81566 .43487 L
.81833 .42716 L
.8217 .41744 L
.825 .40773 L
.82537 .4066 L
.82832 .39802 L
.83166 .38831 L
.83491 .37859 L
.83508 .37808 L
.83822 .36888 L
.84153 .35917 L
.84475 .34946 L
.84479 .34931 L
.84803 .33974 L
.85131 .33003 L
.8545 .32032 L
.85451 .32029 L
.85775 .31061 L
.86101 .30089 L
.86417 .29118 L
.86422 .29102 L
.86739 .28147 L
.87063 .27176 L
.87376 .26204 L
.87393 .26151 L
.87696 .25233 L
.88017 .24262 L
.88329 .23291 L
.88364 .23176 L
.88644 .22319 L
.88963 .21348 L
.89274 .20377 L
.89336 .20177 L
.89586 .19406 L
.89902 .18434 L
.90212 .17463 L
.90307 .17154 L
.9052 .16492 L
.90834 .15521 L
.91143 .14549 L
.91278 .14107 L
.91447 .13578 L
.91759 .12607 L
.92067 .11636 L
.92249 .11037 L
.92367 .10664 L
.92677 .09693 L
.92984 .08722 L
.93221 .07944 L
.93281 .07751 L
.93588 .06779 L
.93894 .05808 L
.94189 .04837 L
.94192 .04828 L
.94493 .03866 L
.94798 .02894 L
.95095 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.60499 .98077 m
.60929 .97106 L
.61169 .96552 L
.61353 .96134 L
.61778 .95163 L
.62141 .9432 L
.62196 .94192 L
.62617 .93221 L
.63031 .92249 L
.63112 .92057 L
.63445 .91278 L
.63856 .90307 L
.64083 .89762 L
.64263 .89336 L
.64671 .88364 L
.65054 .87436 L
.65072 .87393 L
.65476 .86422 L
.65876 .85451 L
.66026 .85079 L
.66272 .84479 L
.66669 .83508 L
.66997 .82692 L
.6706 .82537 L
.67454 .81566 L
.67843 .80594 L
.67968 .80275 L
.6823 .79623 L
.68617 .78652 L
.68939 .77829 L
.68998 .77681 L
.69383 .76709 L
.69763 .75738 L
.69911 .75353 L
.7014 .74767 L
.7052 .73796 L
.70882 .72849 L
.70891 .72824 L
.71267 .71853 L
.71641 .70882 L
.71853 .70316 L
.72008 .69911 L
.7238 .68939 L
.72746 .67968 L
.72824 .67755 L
.73112 .66997 L
.73478 .66026 L
.73796 .65166 L
.73837 .65054 L
.74202 .64083 L
Mistroke
.74563 .63112 L
.74767 .6255 L
.74919 .62141 L
.75279 .61169 L
.75634 .60198 L
.75738 .59906 L
.75988 .59227 L
.76344 .58256 L
.76692 .57284 L
.76709 .57236 L
.77045 .56313 L
.77397 .55342 L
.77681 .54538 L
.77741 .54371 L
.78091 .53399 L
.78438 .52428 L
.78652 .51815 L
.78779 .51457 L
.79126 .50486 L
.79469 .49514 L
.79623 .49065 L
.79807 .48543 L
.80151 .47572 L
.80489 .46601 L
.80594 .46289 L
.80825 .45629 L
.81165 .44658 L
.81499 .43687 L
.81566 .43487 L
.81833 .42716 L
.8217 .41744 L
.825 .40773 L
.82537 .4066 L
.82832 .39802 L
.83166 .38831 L
.83491 .37859 L
.83508 .37808 L
.83822 .36888 L
.84153 .35917 L
.84475 .34946 L
.84479 .34931 L
.84803 .33974 L
.85131 .33003 L
.8545 .32032 L
.85451 .32029 L
.85775 .31061 L
.86101 .30089 L
.86417 .29118 L
.86422 .29102 L
.86739 .28147 L
Mistroke
.87063 .27176 L
.87376 .26204 L
.87393 .26151 L
.87696 .25233 L
.88017 .24262 L
.88329 .23291 L
.88364 .23176 L
.88644 .22319 L
.88963 .21348 L
.89274 .20377 L
.89336 .20177 L
.89586 .19406 L
.89902 .18434 L
.90212 .17463 L
.90307 .17154 L
.9052 .16492 L
.90834 .15521 L
.91143 .14549 L
.91278 .14107 L
.91447 .13578 L
.91759 .12607 L
.92067 .11636 L
.92249 .11037 L
.92367 .10664 L
.92677 .09693 L
.92984 .08722 L
.93221 .07944 L
.93281 .07751 L
.93588 .06779 L
.93894 .05808 L
.94189 .04837 L
.94192 .04828 L
.94493 .03866 L
.94798 .02894 L
.95095 .01923 L
Mfstroke
.4 g
.61514 .98077 m
.61935 .97106 L
.62141 .96627 L
.6235 .96134 L
.62765 .95163 L
.63112 .94347 L
.63177 .94192 L
.63586 .93221 L
.63994 .92249 L
.64083 .92037 L
.64397 .91278 L
.64802 .90307 L
.65054 .89696 L
.65201 .89336 L
.656 .88364 L
.65998 .87393 L
.66026 .87324 L
.6639 .86422 L
.66784 .85451 L
.66997 .84923 L
.67173 .84479 L
.67562 .83508 L
.67951 .82537 L
.67968 .82493 L
.68333 .81566 L
.68718 .80594 L
.68939 .80033 L
.69098 .79623 L
.69478 .78652 L
.69858 .77681 L
.69911 .77545 L
.70232 .76709 L
.70608 .75738 L
.70882 .75028 L
.7098 .74767 L
.71351 .73796 L
.71723 .72824 L
.71853 .72483 L
.72089 .71853 L
.72457 .70882 L
.72824 .69911 L
.72824 .6991 L
.73185 .68939 L
.7355 .67968 L
.73796 .6731 L
.7391 .66997 L
.74269 .66026 L
.7463 .65054 L
.74767 .64682 L
.74984 .64083 L
.75341 .63112 L
.75697 .62141 L
.75738 .62028 L
.76047 .61169 L
.76401 .60198 L
.76709 .59346 L
.76751 .59227 L
.77099 .58256 L
.77449 .57284 L
.77681 .56639 L
.77794 .56313 L
.7814 .55342 L
.78487 .54371 L
.78652 .53905 L
.78827 .53399 L
.7917 .52428 L
.79514 .51457 L
.79623 .51145 L
.7985 .50486 L
.80191 .49514 L
.80531 .48543 L
.80594 .48359 L
.80864 .47572 L
.81201 .46601 L
.81538 .45629 L
.81566 .45548 L
.81867 .44658 L
.82203 .43687 L
.82536 .42716 L
.82537 .42712 L
.82862 .41744 L
.83195 .40773 L
.83508 .39851 L
.83524 .39802 L
.83848 .38831 L
.84178 .37859 L
.84479 .36965 L
.84504 .36888 L
.84826 .35917 L
.85153 .34946 L
.85451 .34054 L
.85476 .33974 L
.85795 .33003 L
.86119 .32032 L
.86422 .31119 L
.8644 .31061 L
.86756 .30089 L
.87078 .29118 L
.87393 .2816 L
.87397 .28147 L
.8771 .27176 L
.88029 .26204 L
.88346 .25233 L
.88364 .25176 L
.88656 .24262 L
.88972 .23291 L
.89287 .22319 L
.89336 .22169 L
.89594 .21348 L
.89908 .20377 L
.90222 .19406 L
.90307 .19138 L
.90526 .18434 L
.90837 .17463 L
.91149 .16492 L
.91278 .16084 L
.91452 .15521 L
.9176 .14549 L
.92069 .13578 L
.92249 .13007 L
.92371 .12607 L
.92675 .11636 L
.92983 .10664 L
.93221 .09906 L
.93284 .09693 L
.93584 .08722 L
.9389 .07751 L
.94192 .06783 L
.94193 .06779 L
.94488 .05808 L
.94791 .04837 L
.95093 .03866 L
.95163 .03637 L
.95385 .02894 L
.95686 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.61514 .98077 m
.61935 .97106 L
.62141 .96627 L
.6235 .96134 L
.62765 .95163 L
.63112 .94347 L
.63177 .94192 L
.63586 .93221 L
.63994 .92249 L
.64083 .92037 L
.64397 .91278 L
.64802 .90307 L
.65054 .89696 L
.65201 .89336 L
.656 .88364 L
.65998 .87393 L
.66026 .87324 L
.6639 .86422 L
.66784 .85451 L
.66997 .84923 L
.67173 .84479 L
.67562 .83508 L
.67951 .82537 L
.67968 .82493 L
.68333 .81566 L
.68718 .80594 L
.68939 .80033 L
.69098 .79623 L
.69478 .78652 L
.69858 .77681 L
.69911 .77545 L
.70232 .76709 L
.70608 .75738 L
.70882 .75028 L
.7098 .74767 L
.71351 .73796 L
.71723 .72824 L
.71853 .72483 L
.72089 .71853 L
.72457 .70882 L
.72824 .69911 L
.72824 .6991 L
.73185 .68939 L
.7355 .67968 L
.73796 .6731 L
.7391 .66997 L
.74269 .66026 L
.7463 .65054 L
.74767 .64682 L
.74984 .64083 L
Mistroke
.75341 .63112 L
.75697 .62141 L
.75738 .62028 L
.76047 .61169 L
.76401 .60198 L
.76709 .59346 L
.76751 .59227 L
.77099 .58256 L
.77449 .57284 L
.77681 .56639 L
.77794 .56313 L
.7814 .55342 L
.78487 .54371 L
.78652 .53905 L
.78827 .53399 L
.7917 .52428 L
.79514 .51457 L
.79623 .51145 L
.7985 .50486 L
.80191 .49514 L
.80531 .48543 L
.80594 .48359 L
.80864 .47572 L
.81201 .46601 L
.81538 .45629 L
.81566 .45548 L
.81867 .44658 L
.82203 .43687 L
.82536 .42716 L
.82537 .42712 L
.82862 .41744 L
.83195 .40773 L
.83508 .39851 L
.83524 .39802 L
.83848 .38831 L
.84178 .37859 L
.84479 .36965 L
.84504 .36888 L
.84826 .35917 L
.85153 .34946 L
.85451 .34054 L
.85476 .33974 L
.85795 .33003 L
.86119 .32032 L
.86422 .31119 L
.8644 .31061 L
.86756 .30089 L
.87078 .29118 L
.87393 .2816 L
.87397 .28147 L
Mistroke
.8771 .27176 L
.88029 .26204 L
.88346 .25233 L
.88364 .25176 L
.88656 .24262 L
.88972 .23291 L
.89287 .22319 L
.89336 .22169 L
.89594 .21348 L
.89908 .20377 L
.90222 .19406 L
.90307 .19138 L
.90526 .18434 L
.90837 .17463 L
.91149 .16492 L
.91278 .16084 L
.91452 .15521 L
.9176 .14549 L
.92069 .13578 L
.92249 .13007 L
.92371 .12607 L
.92675 .11636 L
.92983 .10664 L
.93221 .09906 L
.93284 .09693 L
.93584 .08722 L
.9389 .07751 L
.94192 .06783 L
.94193 .06779 L
.94488 .05808 L
.94791 .04837 L
.95093 .03866 L
.95163 .03637 L
.95385 .02894 L
.95686 .01923 L
Mfstroke
.3 g
.62566 .98077 m
.62984 .97106 L
.63112 .96806 L
.63382 .96134 L
.63792 .95163 L
.64083 .94476 L
.64193 .94192 L
.64592 .93221 L
.64999 .92249 L
.65054 .92117 L
.65384 .91278 L
.65786 .90307 L
.66026 .89727 L
.66174 .89336 L
.66565 .88364 L
.66963 .87393 L
.66997 .87309 L
.67337 .86422 L
.6773 .85451 L
.67968 .84862 L
.68108 .84479 L
.6849 .83508 L
.68879 .82537 L
.68939 .82386 L
.69245 .81566 L
.69629 .80594 L
.69911 .79882 L
.70002 .79623 L
.70371 .78652 L
.70753 .77681 L
.70882 .7735 L
.71111 .76709 L
.71485 .75738 L
.71853 .7479 L
.71861 .74767 L
.72212 .73796 L
.72586 .72824 L
.72824 .72203 L
.72943 .71853 L
.73303 .70882 L
.73674 .69911 L
.73796 .69589 L
.74019 .68939 L
.74382 .67968 L
.74749 .66997 L
.74767 .66948 L
.75087 .66026 L
.75449 .65054 L
.75738 .6428 L
.75801 .64083 L
.76144 .63112 L
.76505 .62141 L
.76709 .61586 L
.76844 .61169 L
.77191 .60198 L
.77549 .59227 L
.77681 .58865 L
.7788 .58256 L
.78228 .57284 L
.78582 .56313 L
.78652 .5612 L
.78906 .55342 L
.79254 .54371 L
.79605 .53399 L
.79623 .53348 L
.79924 .52428 L
.80271 .51457 L
.80594 .50551 L
.80613 .50486 L
.80932 .49514 L
.81277 .48543 L
.81566 .47729 L
.81611 .47572 L
.81932 .46601 L
.82274 .45629 L
.82537 .44881 L
.82602 .44658 L
.82922 .43687 L
.83262 .42716 L
.83508 .42009 L
.83584 .41744 L
.83904 .40773 L
.84241 .39802 L
.84479 .39113 L
.8456 .38831 L
.84877 .37859 L
.85212 .36888 L
.85451 .36192 L
.85528 .35917 L
.85842 .34946 L
.86174 .33974 L
.86422 .33247 L
.86489 .33003 L
.86798 .32032 L
.87129 .31061 L
.87393 .30278 L
.87443 .30089 L
.87747 .29118 L
.88075 .28147 L
.88364 .27285 L
.88393 .27176 L
.88689 .26204 L
.89014 .25233 L
.89336 .24269 L
.89337 .24262 L
.89624 .23291 L
.89945 .22319 L
.90268 .21348 L
.90307 .21229 L
.90552 .20377 L
.90869 .19406 L
.91191 .18434 L
.91278 .18165 L
.91474 .17463 L
.91787 .16492 L
.92106 .15521 L
.92249 .15079 L
.92391 .14549 L
.92697 .13578 L
.93015 .12607 L
.93221 .1197 L
.93305 .11636 L
.93601 .10664 L
.93917 .09693 L
.94192 .08838 L
.94219 .08722 L
.94499 .07751 L
.94812 .06779 L
.95124 .05808 L
.95163 .05684 L
.95393 .04837 L
.95701 .03866 L
.96012 .02894 L
.96134 .02508 L
.96284 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.62566 .98077 m
.62984 .97106 L
.63112 .96806 L
.63382 .96134 L
.63792 .95163 L
.64083 .94476 L
.64193 .94192 L
.64592 .93221 L
.64999 .92249 L
.65054 .92117 L
.65384 .91278 L
.65786 .90307 L
.66026 .89727 L
.66174 .89336 L
.66565 .88364 L
.66963 .87393 L
.66997 .87309 L
.67337 .86422 L
.6773 .85451 L
.67968 .84862 L
.68108 .84479 L
.6849 .83508 L
.68879 .82537 L
.68939 .82386 L
.69245 .81566 L
.69629 .80594 L
.69911 .79882 L
.70002 .79623 L
.70371 .78652 L
.70753 .77681 L
.70882 .7735 L
.71111 .76709 L
.71485 .75738 L
.71853 .7479 L
.71861 .74767 L
.72212 .73796 L
.72586 .72824 L
.72824 .72203 L
.72943 .71853 L
.73303 .70882 L
.73674 .69911 L
.73796 .69589 L
.74019 .68939 L
.74382 .67968 L
.74749 .66997 L
.74767 .66948 L
.75087 .66026 L
.75449 .65054 L
.75738 .6428 L
.75801 .64083 L
Mistroke
.76144 .63112 L
.76505 .62141 L
.76709 .61586 L
.76844 .61169 L
.77191 .60198 L
.77549 .59227 L
.77681 .58865 L
.7788 .58256 L
.78228 .57284 L
.78582 .56313 L
.78652 .5612 L
.78906 .55342 L
.79254 .54371 L
.79605 .53399 L
.79623 .53348 L
.79924 .52428 L
.80271 .51457 L
.80594 .50551 L
.80613 .50486 L
.80932 .49514 L
.81277 .48543 L
.81566 .47729 L
.81611 .47572 L
.81932 .46601 L
.82274 .45629 L
.82537 .44881 L
.82602 .44658 L
.82922 .43687 L
.83262 .42716 L
.83508 .42009 L
.83584 .41744 L
.83904 .40773 L
.84241 .39802 L
.84479 .39113 L
.8456 .38831 L
.84877 .37859 L
.85212 .36888 L
.85451 .36192 L
.85528 .35917 L
.85842 .34946 L
.86174 .33974 L
.86422 .33247 L
.86489 .33003 L
.86798 .32032 L
.87129 .31061 L
.87393 .30278 L
.87443 .30089 L
.87747 .29118 L
.88075 .28147 L
.88364 .27285 L
Mistroke
.88393 .27176 L
.88689 .26204 L
.89014 .25233 L
.89336 .24269 L
.89337 .24262 L
.89624 .23291 L
.89945 .22319 L
.90268 .21348 L
.90307 .21229 L
.90552 .20377 L
.90869 .19406 L
.91191 .18434 L
.91278 .18165 L
.91474 .17463 L
.91787 .16492 L
.92106 .15521 L
.92249 .15079 L
.92391 .14549 L
.92697 .13578 L
.93015 .12607 L
.93221 .1197 L
.93305 .11636 L
.93601 .10664 L
.93917 .09693 L
.94192 .08838 L
.94219 .08722 L
.94499 .07751 L
.94812 .06779 L
.95124 .05808 L
.95163 .05684 L
.95393 .04837 L
.95701 .03866 L
.96012 .02894 L
.96134 .02508 L
.96284 .01923 L
Mfstroke
.2 g
.63961 .98077 m
.64083 .97837 L
.64378 .97106 L
.64674 .96134 L
.65054 .95411 L
.65158 .95163 L
.65547 .94192 L
.65911 .93221 L
.66026 .92978 L
.66317 .92249 L
.66605 .91278 L
.66997 .90511 L
.6708 .90307 L
.67461 .89336 L
.67809 .88364 L
.67968 .88022 L
.68216 .87393 L
.68474 .86422 L
.68939 .85509 L
.68963 .85451 L
.69337 .84479 L
.69655 .83508 L
.69911 .82962 L
.70076 .82537 L
.70278 .81566 L
.70795 .80594 L
.70882 .80397 L
.71175 .79623 L
.71446 .78652 L
.71853 .77801 L
.719 .77681 L
.72262 .76709 L
.72572 .75738 L
.72824 .75179 L
.7298 .74767 L
.73166 .73796 L
.73671 .72824 L
.73796 .72535 L
.74047 .71853 L
.74286 .70882 L
.74749 .69911 L
.74767 .69867 L
.75104 .68939 L
.75376 .67968 L
.75738 .67166 L
.75801 .66997 L
.7615 .66026 L
.76444 .65054 L
.76709 .64443 L
.7684 .64083 L
.76993 .63112 L
.77494 .62141 L
.77681 .61697 L
.77869 .61169 L
.78057 .60198 L
.78529 .59227 L
.78652 .58926 L
.78888 .58256 L
.79099 .57284 L
.7955 .56313 L
.79623 .56131 L
.79898 .55342 L
.80124 .54371 L
.80559 .53399 L
.80594 .53311 L
.80899 .52428 L
.81134 .51457 L
.81558 .50486 L
.81566 .50466 L
.81891 .49514 L
.82131 .48543 L
.82537 .47596 L
.82545 .47572 L
.82874 .46601 L
.83116 .45629 L
.83508 .44702 L
.83523 .44658 L
.8385 .43687 L
.84089 .42716 L
.84479 .41785 L
.84493 .41744 L
.84817 .40773 L
.85051 .39802 L
.85451 .38844 L
.85455 .38831 L
.85777 .37859 L
.86002 .36888 L
.86408 .35917 L
.86422 .3588 L
.86729 .34946 L
.86942 .33974 L
.87351 .33003 L
.87393 .32891 L
.87674 .32032 L
.8787 .31061 L
.88286 .30089 L
.88364 .29879 L
.88611 .29118 L
.88786 .28147 L
.89211 .27176 L
.89336 .26844 L
.89542 .26204 L
.89688 .25233 L
.90127 .24262 L
.90307 .23786 L
.90466 .23291 L
.90575 .22319 L
.91033 .21348 L
.91278 .20706 L
.91384 .20377 L
.9169 .19406 L
.91928 .18434 L
.92249 .17605 L
.92295 .17463 L
.92599 .16492 L
.9281 .15521 L
.93196 .14549 L
.93221 .14481 L
.93503 .13578 L
.93676 .12607 L
.94082 .11636 L
.94192 .11332 L
.944 .10664 L
.94524 .09693 L
.94957 .08722 L
.95163 .08162 L
.95291 .07751 L
.95588 .06779 L
.95818 .05808 L
.96134 .04971 L
.96176 .04837 L
.96473 .03866 L
.96664 .02894 L
.97048 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.63961 .98077 m
.64083 .97837 L
.64378 .97106 L
.64674 .96134 L
.65054 .95411 L
.65158 .95163 L
.65547 .94192 L
.65911 .93221 L
.66026 .92978 L
.66317 .92249 L
.66605 .91278 L
.66997 .90511 L
.6708 .90307 L
.67461 .89336 L
.67809 .88364 L
.67968 .88022 L
.68216 .87393 L
.68474 .86422 L
.68939 .85509 L
.68963 .85451 L
.69337 .84479 L
.69655 .83508 L
.69911 .82962 L
.70076 .82537 L
.70278 .81566 L
.70795 .80594 L
.70882 .80397 L
.71175 .79623 L
.71446 .78652 L
.71853 .77801 L
.719 .77681 L
.72262 .76709 L
.72572 .75738 L
.72824 .75179 L
.7298 .74767 L
.73166 .73796 L
.73671 .72824 L
.73796 .72535 L
.74047 .71853 L
.74286 .70882 L
.74749 .69911 L
.74767 .69867 L
.75104 .68939 L
.75376 .67968 L
.75738 .67166 L
.75801 .66997 L
.7615 .66026 L
.76444 .65054 L
.76709 .64443 L
.7684 .64083 L
Mistroke
.76993 .63112 L
.77494 .62141 L
.77681 .61697 L
.77869 .61169 L
.78057 .60198 L
.78529 .59227 L
.78652 .58926 L
.78888 .58256 L
.79099 .57284 L
.7955 .56313 L
.79623 .56131 L
.79898 .55342 L
.80124 .54371 L
.80559 .53399 L
.80594 .53311 L
.80899 .52428 L
.81134 .51457 L
.81558 .50486 L
.81566 .50466 L
.81891 .49514 L
.82131 .48543 L
.82537 .47596 L
.82545 .47572 L
.82874 .46601 L
.83116 .45629 L
.83508 .44702 L
.83523 .44658 L
.8385 .43687 L
.84089 .42716 L
.84479 .41785 L
.84493 .41744 L
.84817 .40773 L
.85051 .39802 L
.85451 .38844 L
.85455 .38831 L
.85777 .37859 L
.86002 .36888 L
.86408 .35917 L
.86422 .3588 L
.86729 .34946 L
.86942 .33974 L
.87351 .33003 L
.87393 .32891 L
.87674 .32032 L
.8787 .31061 L
.88286 .30089 L
.88364 .29879 L
.88611 .29118 L
.88786 .28147 L
.89211 .27176 L
Mistroke
.89336 .26844 L
.89542 .26204 L
.89688 .25233 L
.90127 .24262 L
.90307 .23786 L
.90466 .23291 L
.90575 .22319 L
.91033 .21348 L
.91278 .20706 L
.91384 .20377 L
.9169 .19406 L
.91928 .18434 L
.92249 .17605 L
.92295 .17463 L
.92599 .16492 L
.9281 .15521 L
.93196 .14549 L
.93221 .14481 L
.93503 .13578 L
.93676 .12607 L
.94082 .11636 L
.94192 .11332 L
.944 .10664 L
.94524 .09693 L
.94957 .08722 L
.95163 .08162 L
.95291 .07751 L
.95588 .06779 L
.95818 .05808 L
.96134 .04971 L
.96176 .04837 L
.96473 .03866 L
.96664 .02894 L
.97048 .01923 L
Mfstroke
.3 g
.98077 .07814 m
.97807 .08722 L
.97511 .09693 L
.97209 .10664 L
.97106 .11001 L
.96908 .11636 L
.96814 .12607 L
.96356 .13578 L
.96134 .14163 L
.96013 .14549 L
.95711 .15521 L
.95481 .16492 L
.95163 .17301 L
.95112 .17463 L
.94807 .18434 L
.94603 .19406 L
.94206 .20377 L
.94192 .20415 L
.93897 .21348 L
.93722 .22319 L
.93302 .23291 L
.93221 .23509 L
.9298 .24262 L
.92835 .25233 L
.92392 .26204 L
.92249 .26578 L
.92057 .27176 L
.91942 .28147 L
.91476 .29118 L
.91278 .29624 L
.91126 .30089 L
.90813 .31061 L
.90552 .32032 L
.90307 .32645 L
.90189 .33003 L
.89873 .33974 L
.89619 .34946 L
.89336 .35641 L
.89244 .35917 L
.88925 .36888 L
.88676 .37859 L
.88364 .38613 L
.88291 .38831 L
.87969 .39802 L
.87723 .40773 L
.87393 .4156 L
.8733 .41744 L
.87006 .42716 L
.8676 .43687 L
.86422 .44482 L
.86361 .44658 L
.86034 .45629 L
.85784 .46601 L
.85451 .47379 L
.85384 .47572 L
.85054 .48543 L
.84796 .49514 L
.84479 .50251 L
.84398 .50486 L
.84065 .51457 L
.83796 .52428 L
.83508 .53098 L
.83402 .53399 L
.83067 .54371 L
.82784 .55342 L
.82537 .55918 L
.82397 .56313 L
.82059 .57284 L
.8176 .58256 L
.81566 .58711 L
.81382 .59227 L
.81225 .60198 L
.80725 .61169 L
.80594 .61478 L
.80357 .62141 L
.80158 .63112 L
.79679 .64083 L
.79623 .64217 L
.79321 .65054 L
.79081 .66026 L
.78652 .6693 L
.78627 .66997 L
.78274 .67968 L
.77995 .68939 L
.77681 .69619 L
.77572 .69911 L
.77216 .70882 L
.76901 .71853 L
.76709 .72277 L
.76505 .72824 L
.7631 .73796 L
.75799 .74767 L
.75738 .74904 L
.75425 .75738 L
.75161 .76709 L
.74767 .77508 L
.747 .77681 L
.74332 .78652 L
.74012 .79623 L
.73796 .80081 L
.73597 .80594 L
.73395 .81566 L
.72862 .82537 L
.72824 .8262 L
.7248 .83508 L
.72187 .84479 L
.71853 .85139 L
.71728 .85451 L
.71348 .86422 L
.7099 .87393 L
.70882 .87619 L
.70584 .88364 L
.70306 .89336 L
.69911 .90074 L
.69814 .90307 L
.69424 .91278 L
.69061 .92249 L
.68939 .92493 L
.68641 .93221 L
.68353 .94192 L
.67968 .94886 L
.6785 .95163 L
.6745 .96134 L
.67064 .97106 L
.66997 .97226 L
.66645 .98077 L
.98077 .98077 L
F
0 g
.98077 .07814 m
.97807 .08722 L
.97511 .09693 L
.97209 .10664 L
.97106 .11001 L
.96908 .11636 L
.96814 .12607 L
.96356 .13578 L
.96134 .14163 L
.96013 .14549 L
.95711 .15521 L
.95481 .16492 L
.95163 .17301 L
.95112 .17463 L
.94807 .18434 L
.94603 .19406 L
.94206 .20377 L
.94192 .20415 L
.93897 .21348 L
.93722 .22319 L
.93302 .23291 L
.93221 .23509 L
.9298 .24262 L
.92835 .25233 L
.92392 .26204 L
.92249 .26578 L
.92057 .27176 L
.91942 .28147 L
.91476 .29118 L
.91278 .29624 L
.91126 .30089 L
.90813 .31061 L
.90552 .32032 L
.90307 .32645 L
.90189 .33003 L
.89873 .33974 L
.89619 .34946 L
.89336 .35641 L
.89244 .35917 L
.88925 .36888 L
.88676 .37859 L
.88364 .38613 L
.88291 .38831 L
.87969 .39802 L
.87723 .40773 L
.87393 .4156 L
.8733 .41744 L
.87006 .42716 L
.8676 .43687 L
.86422 .44482 L
Mistroke
.86361 .44658 L
.86034 .45629 L
.85784 .46601 L
.85451 .47379 L
.85384 .47572 L
.85054 .48543 L
.84796 .49514 L
.84479 .50251 L
.84398 .50486 L
.84065 .51457 L
.83796 .52428 L
.83508 .53098 L
.83402 .53399 L
.83067 .54371 L
.82784 .55342 L
.82537 .55918 L
.82397 .56313 L
.82059 .57284 L
.8176 .58256 L
.81566 .58711 L
.81382 .59227 L
.81225 .60198 L
.80725 .61169 L
.80594 .61478 L
.80357 .62141 L
.80158 .63112 L
.79679 .64083 L
.79623 .64217 L
.79321 .65054 L
.79081 .66026 L
.78652 .6693 L
.78627 .66997 L
.78274 .67968 L
.77995 .68939 L
.77681 .69619 L
.77572 .69911 L
.77216 .70882 L
.76901 .71853 L
.76709 .72277 L
.76505 .72824 L
.7631 .73796 L
.75799 .74767 L
.75738 .74904 L
.75425 .75738 L
.75161 .76709 L
.74767 .77508 L
.747 .77681 L
.74332 .78652 L
.74012 .79623 L
.73796 .80081 L
Mistroke
.73597 .80594 L
.73395 .81566 L
.72862 .82537 L
.72824 .8262 L
.7248 .83508 L
.72187 .84479 L
.71853 .85139 L
.71728 .85451 L
.71348 .86422 L
.7099 .87393 L
.70882 .87619 L
.70584 .88364 L
.70306 .89336 L
.69911 .90074 L
.69814 .90307 L
.69424 .91278 L
.69061 .92249 L
.68939 .92493 L
.68641 .93221 L
.68353 .94192 L
.67968 .94886 L
.6785 .95163 L
.6745 .96134 L
.67064 .97106 L
.66997 .97226 L
.66645 .98077 L
Mfstroke
.4 g
.98077 .10252 m
.97955 .10664 L
.97662 .11636 L
.97134 .12607 L
.97106 .1345 L
.97078 .13578 L
.96803 .14549 L
.9649 .15521 L
.96177 .16492 L
.96134 .16627 L
.9591 .17463 L
.956 .18434 L
.95284 .19406 L
.95163 .19781 L
.95009 .20377 L
.94703 .21348 L
.94384 .22319 L
.94192 .22911 L
.94097 .23291 L
.93798 .24262 L
.93478 .25233 L
.93221 .26019 L
.93176 .26204 L
.92887 .27176 L
.92565 .28147 L
.92249 .29103 L
.92246 .29118 L
.91967 .30089 L
.91646 .31061 L
.91322 .32032 L
.91278 .32165 L
.9104 .33003 L
.90719 .33974 L
.90392 .34946 L
.90307 .35202 L
.90106 .35917 L
.89785 .36888 L
.89455 .37859 L
.89336 .38216 L
.89163 .38831 L
.88843 .39802 L
.88511 .40773 L
.88364 .41206 L
.88213 .41744 L
.87893 .42716 L
.87558 .43687 L
.87393 .44172 L
.87256 .44658 L
.86935 .45629 L
.86598 .46601 L
.86422 .47113 L
.86292 .47572 L
.85968 .48543 L
.85629 .49514 L
.85451 .50029 L
.8532 .50486 L
.84993 .51457 L
.84652 .52428 L
.84479 .52921 L
.8434 .53399 L
.8401 .54371 L
.83665 .55342 L
.83508 .55788 L
.83351 .56313 L
.83017 .57284 L
.8267 .58256 L
.82537 .5863 L
.82354 .59227 L
.82014 .60198 L
.81664 .61169 L
.81566 .61445 L
.81348 .62141 L
.81002 .63112 L
.80649 .64083 L
.80594 .64236 L
.80331 .65054 L
.7998 .66026 L
.79624 .66997 L
.79623 .67 L
.79303 .67968 L
.78947 .68939 L
.78652 .69738 L
.786 .69911 L
.78264 .70882 L
.77903 .71853 L
.77681 .7245 L
.77562 .72824 L
.77213 .73796 L
.76847 .74767 L
.76709 .75135 L
.7651 .75738 L
.7615 .76709 L
.7578 .77681 L
.75738 .77792 L
.75443 .78652 L
.75074 .79623 L
.74767 .80423 L
.74712 .80594 L
.7436 .81566 L
.73985 .82537 L
.73796 .83026 L
.73632 .83508 L
.73263 .84479 L
.72883 .85451 L
.72824 .85601 L
.72532 .86422 L
.72151 .87393 L
.71853 .88148 L
.7178 .88364 L
.71413 .89336 L
.71025 .90307 L
.70882 .90666 L
.70661 .91278 L
.70277 .92249 L
.69911 .93154 L
.69888 .93221 L
.69519 .94192 L
.69124 .95163 L
.68939 .95615 L
.68748 .96134 L
.68357 .97106 L
.67968 .98044 L
.67957 .98077 L
.98077 .98077 L
F
0 g
.98077 .10252 m
.97955 .10664 L
.97662 .11636 L
.97134 .12607 L
.97106 .1345 L
.97078 .13578 L
.96803 .14549 L
.9649 .15521 L
.96177 .16492 L
.96134 .16627 L
.9591 .17463 L
.956 .18434 L
.95284 .19406 L
.95163 .19781 L
.95009 .20377 L
.94703 .21348 L
.94384 .22319 L
.94192 .22911 L
.94097 .23291 L
.93798 .24262 L
.93478 .25233 L
.93221 .26019 L
.93176 .26204 L
.92887 .27176 L
.92565 .28147 L
.92249 .29103 L
.92246 .29118 L
.91967 .30089 L
.91646 .31061 L
.91322 .32032 L
.91278 .32165 L
.9104 .33003 L
.90719 .33974 L
.90392 .34946 L
.90307 .35202 L
.90106 .35917 L
.89785 .36888 L
.89455 .37859 L
.89336 .38216 L
.89163 .38831 L
.88843 .39802 L
.88511 .40773 L
.88364 .41206 L
.88213 .41744 L
.87893 .42716 L
.87558 .43687 L
.87393 .44172 L
.87256 .44658 L
.86935 .45629 L
.86598 .46601 L
Mistroke
.86422 .47113 L
.86292 .47572 L
.85968 .48543 L
.85629 .49514 L
.85451 .50029 L
.8532 .50486 L
.84993 .51457 L
.84652 .52428 L
.84479 .52921 L
.8434 .53399 L
.8401 .54371 L
.83665 .55342 L
.83508 .55788 L
.83351 .56313 L
.83017 .57284 L
.8267 .58256 L
.82537 .5863 L
.82354 .59227 L
.82014 .60198 L
.81664 .61169 L
.81566 .61445 L
.81348 .62141 L
.81002 .63112 L
.80649 .64083 L
.80594 .64236 L
.80331 .65054 L
.7998 .66026 L
.79624 .66997 L
.79623 .67 L
.79303 .67968 L
.78947 .68939 L
.78652 .69738 L
.786 .69911 L
.78264 .70882 L
.77903 .71853 L
.77681 .7245 L
.77562 .72824 L
.77213 .73796 L
.76847 .74767 L
.76709 .75135 L
.7651 .75738 L
.7615 .76709 L
.7578 .77681 L
.75738 .77792 L
.75443 .78652 L
.75074 .79623 L
.74767 .80423 L
.74712 .80594 L
.7436 .81566 L
.73985 .82537 L
Mistroke
.73796 .83026 L
.73632 .83508 L
.73263 .84479 L
.72883 .85451 L
.72824 .85601 L
.72532 .86422 L
.72151 .87393 L
.71853 .88148 L
.7178 .88364 L
.71413 .89336 L
.71025 .90307 L
.70882 .90666 L
.70661 .91278 L
.70277 .92249 L
.69911 .93154 L
.69888 .93221 L
.69519 .94192 L
.69124 .95163 L
.68939 .95615 L
.68748 .96134 L
.68357 .97106 L
.67968 .98044 L
.67957 .98077 L
Mfstroke
.5 g
.98077 .12274 m
.97763 .12607 L
.97543 .13578 L
.97351 .14549 L
.97106 .15481 L
.97094 .15521 L
.96806 .16492 L
.96505 .17463 L
.96205 .18434 L
.96134 .18665 L
.95915 .19406 L
.95614 .20377 L
.95311 .21348 L
.95163 .21827 L
.95017 .22319 L
.94717 .23291 L
.94412 .24262 L
.94192 .24966 L
.94113 .25233 L
.93813 .26204 L
.93506 .27176 L
.93221 .28083 L
.93202 .28147 L
.92903 .29118 L
.92594 .30089 L
.92286 .31061 L
.92249 .31176 L
.91986 .32032 L
.91676 .33003 L
.91364 .33974 L
.91278 .34246 L
.91062 .34946 L
.90751 .35917 L
.90437 .36888 L
.90307 .37292 L
.90131 .37859 L
.89818 .38831 L
.89502 .39802 L
.89336 .40315 L
.89193 .40773 L
.88879 .41744 L
.8856 .42716 L
.88364 .43314 L
.88247 .43687 L
.87932 .44658 L
.8761 .45629 L
.87393 .46289 L
.87295 .46601 L
.86977 .47572 L
.86653 .48543 L
.86422 .4924 L
.86335 .49514 L
.86015 .50486 L
.85688 .51457 L
.85451 .52167 L
.85367 .52428 L
.85044 .53399 L
.84715 .54371 L
.84479 .55069 L
.84391 .55342 L
.84065 .56313 L
.83734 .57284 L
.83508 .57946 L
.83407 .58256 L
.83078 .59227 L
.82743 .60198 L
.82537 .60799 L
.82414 .61169 L
.82081 .62141 L
.81744 .63112 L
.81566 .63626 L
.81412 .64083 L
.81075 .65054 L
.80735 .66026 L
.80594 .66427 L
.804 .66997 L
.8006 .67968 L
.79716 .68939 L
.79623 .69203 L
.79379 .69911 L
.79034 .70882 L
.78687 .71853 L
.78652 .71953 L
.78347 .72824 L
.77998 .73796 L
.77681 .74677 L
.77649 .74767 L
.77304 .75738 L
.76951 .76709 L
.76709 .77374 L
.76601 .77681 L
.7625 .78652 L
.75893 .79623 L
.75738 .80045 L
.75541 .80594 L
.75183 .81566 L
.74823 .82537 L
.74767 .82688 L
.74468 .83508 L
.74105 .84479 L
.73796 .85305 L
.73743 .85451 L
.73382 .86422 L
.73014 .87393 L
.72824 .87894 L
.7265 .88364 L
.72282 .89336 L
.7191 .90307 L
.71853 .90455 L
.71542 .91278 L
.71168 .92249 L
.70882 .92987 L
.70794 .93221 L
.70419 .94192 L
.70039 .95163 L
.69911 .95492 L
.69663 .96134 L
.69281 .97106 L
.68939 .97967 L
.68897 .98077 L
.98077 .98077 L
F
0 g
.98077 .12274 m
.97763 .12607 L
.97543 .13578 L
.97351 .14549 L
.97106 .15481 L
.97094 .15521 L
.96806 .16492 L
.96505 .17463 L
.96205 .18434 L
.96134 .18665 L
.95915 .19406 L
.95614 .20377 L
.95311 .21348 L
.95163 .21827 L
.95017 .22319 L
.94717 .23291 L
.94412 .24262 L
.94192 .24966 L
.94113 .25233 L
.93813 .26204 L
.93506 .27176 L
.93221 .28083 L
.93202 .28147 L
.92903 .29118 L
.92594 .30089 L
.92286 .31061 L
.92249 .31176 L
.91986 .32032 L
.91676 .33003 L
.91364 .33974 L
.91278 .34246 L
.91062 .34946 L
.90751 .35917 L
.90437 .36888 L
.90307 .37292 L
.90131 .37859 L
.89818 .38831 L
.89502 .39802 L
.89336 .40315 L
.89193 .40773 L
.88879 .41744 L
.8856 .42716 L
.88364 .43314 L
.88247 .43687 L
.87932 .44658 L
.8761 .45629 L
.87393 .46289 L
.87295 .46601 L
.86977 .47572 L
.86653 .48543 L
Mistroke
.86422 .4924 L
.86335 .49514 L
.86015 .50486 L
.85688 .51457 L
.85451 .52167 L
.85367 .52428 L
.85044 .53399 L
.84715 .54371 L
.84479 .55069 L
.84391 .55342 L
.84065 .56313 L
.83734 .57284 L
.83508 .57946 L
.83407 .58256 L
.83078 .59227 L
.82743 .60198 L
.82537 .60799 L
.82414 .61169 L
.82081 .62141 L
.81744 .63112 L
.81566 .63626 L
.81412 .64083 L
.81075 .65054 L
.80735 .66026 L
.80594 .66427 L
.804 .66997 L
.8006 .67968 L
.79716 .68939 L
.79623 .69203 L
.79379 .69911 L
.79034 .70882 L
.78687 .71853 L
.78652 .71953 L
.78347 .72824 L
.77998 .73796 L
.77681 .74677 L
.77649 .74767 L
.77304 .75738 L
.76951 .76709 L
.76709 .77374 L
.76601 .77681 L
.7625 .78652 L
.75893 .79623 L
.75738 .80045 L
.75541 .80594 L
.75183 .81566 L
.74823 .82537 L
.74767 .82688 L
.74468 .83508 L
.74105 .84479 L
Mistroke
.73796 .85305 L
.73743 .85451 L
.73382 .86422 L
.73014 .87393 L
.72824 .87894 L
.7265 .88364 L
.72282 .89336 L
.7191 .90307 L
.71853 .90455 L
.71542 .91278 L
.71168 .92249 L
.70882 .92987 L
.70794 .93221 L
.70419 .94192 L
.70039 .95163 L
.69911 .95492 L
.69663 .96134 L
.69281 .97106 L
.68939 .97967 L
.68897 .98077 L
Mfstroke
.6 g
.98077 .14201 m
.97944 .14549 L
.97654 .15521 L
.97378 .16492 L
.97106 .17415 L
.97091 .17463 L
.96795 .18434 L
.96495 .19406 L
.96201 .20377 L
.96134 .20606 L
.95907 .21348 L
.95605 .22319 L
.95307 .23291 L
.95163 .23775 L
.95013 .24262 L
.9471 .25233 L
.94408 .26204 L
.94192 .26921 L
.94113 .27176 L
.93809 .28147 L
.93504 .29118 L
.93221 .30045 L
.93207 .30089 L
.92902 .31061 L
.92594 .32032 L
.92292 .33003 L
.92249 .33145 L
.91988 .33974 L
.91677 .34946 L
.91372 .35917 L
.91278 .36223 L
.91067 .36888 L
.90754 .37859 L
.90445 .38831 L
.90307 .39277 L
.90139 .39802 L
.89825 .40773 L
.89512 .41744 L
.89336 .42307 L
.89204 .42716 L
.88888 .43687 L
.88572 .44658 L
.88364 .45315 L
.88262 .45629 L
.87944 .46601 L
.87625 .47572 L
.87393 .48298 L
.87313 .48543 L
.86992 .49514 L
.86671 .50486 L
.86422 .51257 L
.86356 .51457 L
.86033 .52428 L
.85709 .53399 L
.85451 .54192 L
.85392 .54371 L
.85066 .55342 L
.84739 .56313 L
.84479 .57103 L
.84419 .57284 L
.8409 .58256 L
.83761 .59227 L
.83508 .59989 L
.83438 .60198 L
.83106 .61169 L
.82775 .62141 L
.82537 .6285 L
.82448 .63112 L
.82114 .64083 L
.81779 .65054 L
.81566 .65687 L
.81449 .66026 L
.81112 .66997 L
.80775 .67968 L
.80594 .68498 L
.80441 .68939 L
.801 .69911 L
.79761 .70882 L
.79623 .71283 L
.79423 .71853 L
.79079 .72824 L
.78737 .73796 L
.78652 .74043 L
.78395 .74767 L
.78048 .75738 L
.77704 .76709 L
.77681 .76777 L
.77356 .77681 L
.77006 .78652 L
.76709 .79485 L
.7666 .79623 L
.76307 .80594 L
.75953 .81566 L
.75738 .82166 L
.75603 .82537 L
.75246 .83508 L
.7489 .84479 L
.74767 .84821 L
.74534 .85451 L
.74173 .86422 L
.73816 .87393 L
.73796 .87448 L
.73453 .88364 L
.73089 .89336 L
.72824 .90049 L
.72727 .90307 L
.7236 .91278 L
.71992 .92249 L
.71853 .92621 L
.71625 .93221 L
.71252 .94192 L
.70883 .95163 L
.70882 .95166 L
.70508 .96134 L
.70132 .97106 L
.69911 .97683 L
.69758 .98077 L
.98077 .98077 L
F
0 g
.98077 .14201 m
.97944 .14549 L
.97654 .15521 L
.97378 .16492 L
.97106 .17415 L
.97091 .17463 L
.96795 .18434 L
.96495 .19406 L
.96201 .20377 L
.96134 .20606 L
.95907 .21348 L
.95605 .22319 L
.95307 .23291 L
.95163 .23775 L
.95013 .24262 L
.9471 .25233 L
.94408 .26204 L
.94192 .26921 L
.94113 .27176 L
.93809 .28147 L
.93504 .29118 L
.93221 .30045 L
.93207 .30089 L
.92902 .31061 L
.92594 .32032 L
.92292 .33003 L
.92249 .33145 L
.91988 .33974 L
.91677 .34946 L
.91372 .35917 L
.91278 .36223 L
.91067 .36888 L
.90754 .37859 L
.90445 .38831 L
.90307 .39277 L
.90139 .39802 L
.89825 .40773 L
.89512 .41744 L
.89336 .42307 L
.89204 .42716 L
.88888 .43687 L
.88572 .44658 L
.88364 .45315 L
.88262 .45629 L
.87944 .46601 L
.87625 .47572 L
.87393 .48298 L
.87313 .48543 L
.86992 .49514 L
.86671 .50486 L
Mistroke
.86422 .51257 L
.86356 .51457 L
.86033 .52428 L
.85709 .53399 L
.85451 .54192 L
.85392 .54371 L
.85066 .55342 L
.84739 .56313 L
.84479 .57103 L
.84419 .57284 L
.8409 .58256 L
.83761 .59227 L
.83508 .59989 L
.83438 .60198 L
.83106 .61169 L
.82775 .62141 L
.82537 .6285 L
.82448 .63112 L
.82114 .64083 L
.81779 .65054 L
.81566 .65687 L
.81449 .66026 L
.81112 .66997 L
.80775 .67968 L
.80594 .68498 L
.80441 .68939 L
.801 .69911 L
.79761 .70882 L
.79623 .71283 L
.79423 .71853 L
.79079 .72824 L
.78737 .73796 L
.78652 .74043 L
.78395 .74767 L
.78048 .75738 L
.77704 .76709 L
.77681 .76777 L
.77356 .77681 L
.77006 .78652 L
.76709 .79485 L
.7666 .79623 L
.76307 .80594 L
.75953 .81566 L
.75738 .82166 L
.75603 .82537 L
.75246 .83508 L
.7489 .84479 L
.74767 .84821 L
.74534 .85451 L
.74173 .86422 L
Mistroke
.73816 .87393 L
.73796 .87448 L
.73453 .88364 L
.73089 .89336 L
.72824 .90049 L
.72727 .90307 L
.7236 .91278 L
.71992 .92249 L
.71853 .92621 L
.71625 .93221 L
.71252 .94192 L
.70883 .95163 L
.70882 .95166 L
.70508 .96134 L
.70132 .97106 L
.69911 .97683 L
.69758 .98077 L
Mfstroke
.7 g
.98077 .16224 m
.97994 .16492 L
.97704 .17463 L
.97416 .18434 L
.97118 .19406 L
.97106 .19446 L
.96812 .20377 L
.96502 .21348 L
.96213 .22319 L
.96134 .22645 L
.9593 .23291 L
.95618 .24262 L
.95316 .25233 L
.95163 .25822 L
.95042 .26204 L
.94728 .27176 L
.94419 .28147 L
.94192 .28976 L
.94147 .29118 L
.93833 .30089 L
.93519 .31061 L
.93239 .32032 L
.93221 .32108 L
.92931 .33003 L
.92613 .33974 L
.92318 .34946 L
.92249 .35217 L
.92022 .35917 L
.91702 .36888 L
.91397 .37859 L
.91278 .38303 L
.91106 .38831 L
.90784 .39802 L
.90471 .40773 L
.90307 .41367 L
.90183 .41744 L
.89859 .42716 L
.89541 .43687 L
.89336 .44407 L
.89253 .44658 L
.88927 .45629 L
.88605 .46601 L
.88364 .47423 L
.88315 .47572 L
.87988 .48543 L
.87662 .49514 L
.87393 .50416 L
.8737 .50486 L
.87041 .51457 L
.86712 .52428 L
.86422 .53385 L
.86417 .53399 L
.86086 .54371 L
.85755 .55342 L
.85455 .56313 L
.85451 .56331 L
.85123 .57284 L
.84789 .58256 L
.84486 .59227 L
.84479 .59251 L
.84152 .60198 L
.83815 .61169 L
.8351 .62141 L
.83508 .62148 L
.83172 .63112 L
.82833 .64083 L
.82537 .6502 L
.82525 .65054 L
.82183 .66026 L
.81843 .66997 L
.81566 .67867 L
.8153 .67968 L
.81185 .68939 L
.80843 .69911 L
.80594 .70689 L
.80526 .70882 L
.80178 .71853 L
.79835 .72824 L
.79623 .73486 L
.79512 .73796 L
.79161 .74767 L
.78818 .75738 L
.78652 .76258 L
.78488 .76709 L
.78134 .77681 L
.77792 .78652 L
.77681 .79004 L
.77454 .79623 L
.77097 .80594 L
.76759 .81566 L
.76709 .81724 L
.76409 .82537 L
.7605 .83508 L
.75738 .84419 L
.75716 .84479 L
.75352 .85451 L
.74993 .86422 L
.74767 .87086 L
.74652 .87393 L
.74284 .88364 L
.73927 .89336 L
.73796 .89727 L
.73575 .90307 L
.73205 .91278 L
.72855 .92249 L
.72824 .92341 L
.72487 .93221 L
.72115 .94192 L
.71853 .94928 L
.71763 .95163 L
.71385 .96134 L
.71016 .97106 L
.70882 .97489 L
.70652 .98077 L
.98077 .98077 L
F
0 g
.98077 .16224 m
.97994 .16492 L
.97704 .17463 L
.97416 .18434 L
.97118 .19406 L
.97106 .19446 L
.96812 .20377 L
.96502 .21348 L
.96213 .22319 L
.96134 .22645 L
.9593 .23291 L
.95618 .24262 L
.95316 .25233 L
.95163 .25822 L
.95042 .26204 L
.94728 .27176 L
.94419 .28147 L
.94192 .28976 L
.94147 .29118 L
.93833 .30089 L
.93519 .31061 L
.93239 .32032 L
.93221 .32108 L
.92931 .33003 L
.92613 .33974 L
.92318 .34946 L
.92249 .35217 L
.92022 .35917 L
.91702 .36888 L
.91397 .37859 L
.91278 .38303 L
.91106 .38831 L
.90784 .39802 L
.90471 .40773 L
.90307 .41367 L
.90183 .41744 L
.89859 .42716 L
.89541 .43687 L
.89336 .44407 L
.89253 .44658 L
.88927 .45629 L
.88605 .46601 L
.88364 .47423 L
.88315 .47572 L
.87988 .48543 L
.87662 .49514 L
.87393 .50416 L
.8737 .50486 L
.87041 .51457 L
.86712 .52428 L
Mistroke
.86422 .53385 L
.86417 .53399 L
.86086 .54371 L
.85755 .55342 L
.85455 .56313 L
.85451 .56331 L
.85123 .57284 L
.84789 .58256 L
.84486 .59227 L
.84479 .59251 L
.84152 .60198 L
.83815 .61169 L
.8351 .62141 L
.83508 .62148 L
.83172 .63112 L
.82833 .64083 L
.82537 .6502 L
.82525 .65054 L
.82183 .66026 L
.81843 .66997 L
.81566 .67867 L
.8153 .67968 L
.81185 .68939 L
.80843 .69911 L
.80594 .70689 L
.80526 .70882 L
.80178 .71853 L
.79835 .72824 L
.79623 .73486 L
.79512 .73796 L
.79161 .74767 L
.78818 .75738 L
.78652 .76258 L
.78488 .76709 L
.78134 .77681 L
.77792 .78652 L
.77681 .79004 L
.77454 .79623 L
.77097 .80594 L
.76759 .81566 L
.76709 .81724 L
.76409 .82537 L
.7605 .83508 L
.75738 .84419 L
.75716 .84479 L
.75352 .85451 L
.74993 .86422 L
.74767 .87086 L
.74652 .87393 L
.74284 .88364 L
Mistroke
.73927 .89336 L
.73796 .89727 L
.73575 .90307 L
.73205 .91278 L
.72855 .92249 L
.72824 .92341 L
.72487 .93221 L
.72115 .94192 L
.71853 .94928 L
.71763 .95163 L
.71385 .96134 L
.71016 .97106 L
.70882 .97489 L
.70652 .98077 L
Mfstroke
.8 g
.98077 .1866 m
.97869 .19406 L
.97589 .20377 L
.9729 .21348 L
.97106 .21895 L
.96954 .22319 L
.96543 .23291 L
.96394 .24262 L
.96134 .2511 L
.96091 .25233 L
.95708 .26204 L
.9551 .27176 L
.95211 .28147 L
.95163 .28301 L
.94853 .29118 L
.94619 .30089 L
.9432 .31061 L
.94192 .3147 L
.93984 .32032 L
.93547 .33003 L
.93422 .33974 L
.93221 .34618 L
.93101 .34946 L
.9269 .35917 L
.92519 .36888 L
.92249 .37744 L
.92208 .37859 L
.91814 .38831 L
.91609 .39802 L
.91302 .40773 L
.91278 .40846 L
.90924 .41744 L
.90693 .42716 L
.90384 .43687 L
.90307 .43925 L
.90022 .44658 L
.8977 .45629 L
.89459 .46601 L
.89336 .46982 L
.89108 .47572 L
.8865 .48543 L
.88528 .49514 L
.88364 .50016 L
.88184 .50486 L
.87739 .51457 L
.8759 .52428 L
.87393 .53028 L
.87251 .53399 L
.86814 .54371 L
.86644 .55342 L
.86422 .56016 L
.86308 .56313 L
.85876 .57284 L
.85692 .58256 L
.85451 .58981 L
.85356 .59227 L
.84925 .60198 L
.84731 .61169 L
.84479 .61922 L
.84395 .62141 L
.83963 .63112 L
.83763 .64083 L
.83508 .6484 L
.83425 .65054 L
.82989 .66026 L
.82787 .66997 L
.82537 .67733 L
.82445 .67968 L
.82002 .68939 L
.81803 .69911 L
.81566 .70602 L
.81454 .70882 L
.81001 .71853 L
.8081 .72824 L
.80594 .73447 L
.80453 .73796 L
.79986 .74767 L
.79809 .75738 L
.79623 .76267 L
.79441 .76709 L
.78954 .77681 L
.78798 .78652 L
.78652 .79063 L
.78415 .79623 L
.7812 .80594 L
.77778 .81566 L
.77681 .81835 L
.77376 .82537 L
.77094 .83508 L
.76748 .84479 L
.76709 .84584 L
.76319 .85451 L
.76057 .86422 L
.75738 .87308 L
.75703 .87393 L
.75241 .88364 L
.75011 .89336 L
.74767 .90002 L
.74637 .90307 L
.74137 .91278 L
.73953 .92249 L
.73796 .92671 L
.73551 .93221 L
.73243 .94192 L
.72884 .95163 L
.72824 .95319 L
.72441 .96134 L
.72167 .97106 L
.71853 .97946 L
.71795 .98077 L
.98077 .98077 L
F
0 g
.98077 .1866 m
.97869 .19406 L
.97589 .20377 L
.9729 .21348 L
.97106 .21895 L
.96954 .22319 L
.96543 .23291 L
.96394 .24262 L
.96134 .2511 L
.96091 .25233 L
.95708 .26204 L
.9551 .27176 L
.95211 .28147 L
.95163 .28301 L
.94853 .29118 L
.94619 .30089 L
.9432 .31061 L
.94192 .3147 L
.93984 .32032 L
.93547 .33003 L
.93422 .33974 L
.93221 .34618 L
.93101 .34946 L
.9269 .35917 L
.92519 .36888 L
.92249 .37744 L
.92208 .37859 L
.91814 .38831 L
.91609 .39802 L
.91302 .40773 L
.91278 .40846 L
.90924 .41744 L
.90693 .42716 L
.90384 .43687 L
.90307 .43925 L
.90022 .44658 L
.8977 .45629 L
.89459 .46601 L
.89336 .46982 L
.89108 .47572 L
.8865 .48543 L
.88528 .49514 L
.88364 .50016 L
.88184 .50486 L
.87739 .51457 L
.8759 .52428 L
.87393 .53028 L
.87251 .53399 L
.86814 .54371 L
.86644 .55342 L
Mistroke
.86422 .56016 L
.86308 .56313 L
.85876 .57284 L
.85692 .58256 L
.85451 .58981 L
.85356 .59227 L
.84925 .60198 L
.84731 .61169 L
.84479 .61922 L
.84395 .62141 L
.83963 .63112 L
.83763 .64083 L
.83508 .6484 L
.83425 .65054 L
.82989 .66026 L
.82787 .66997 L
.82537 .67733 L
.82445 .67968 L
.82002 .68939 L
.81803 .69911 L
.81566 .70602 L
.81454 .70882 L
.81001 .71853 L
.8081 .72824 L
.80594 .73447 L
.80453 .73796 L
.79986 .74767 L
.79809 .75738 L
.79623 .76267 L
.79441 .76709 L
.78954 .77681 L
.78798 .78652 L
.78652 .79063 L
.78415 .79623 L
.7812 .80594 L
.77778 .81566 L
.77681 .81835 L
.77376 .82537 L
.77094 .83508 L
.76748 .84479 L
.76709 .84584 L
.76319 .85451 L
.76057 .86422 L
.75738 .87308 L
.75703 .87393 L
.75241 .88364 L
.75011 .89336 L
.74767 .90002 L
.74637 .90307 L
.74137 .91278 L
Mistroke
.73953 .92249 L
.73796 .92671 L
.73551 .93221 L
.73243 .94192 L
.72884 .95163 L
.72824 .95319 L
.72441 .96134 L
.72167 .97106 L
.71853 .97946 L
.71795 .98077 L
Mfstroke
.7 g
.98077 .27954 m
.9802 .28147 L
.97729 .29118 L
.97431 .30089 L
.97129 .31061 L
.97106 .31137 L
.96829 .32032 L
.96676 .33003 L
.96255 .33974 L
.96134 .34301 L
.95933 .34946 L
.9583 .35917 L
.95374 .36888 L
.95163 .37441 L
.95031 .37859 L
.94726 .38831 L
.94488 .39802 L
.94192 .40556 L
.94122 .40773 L
.93815 .41744 L
.93599 .42716 L
.93221 .43646 L
.93208 .43687 L
.92898 .44658 L
.92704 .45629 L
.92292 .46601 L
.92249 .46715 L
.91974 .47572 L
.91802 .48543 L
.91372 .49514 L
.91278 .49761 L
.91043 .50486 L
.90893 .51457 L
.90444 .52428 L
.90307 .52782 L
.90105 .53399 L
.89973 .54371 L
.89508 .55342 L
.89336 .55779 L
.89159 .56313 L
.89043 .57284 L
.88563 .58256 L
.88364 .58751 L
.88205 .59227 L
.88099 .60198 L
.87608 .61169 L
.87393 .61699 L
.87244 .62141 L
.8692 .63112 L
.86643 .64083 L
.86422 .64621 L
.86274 .65054 L
.85948 .66026 L
.85666 .66997 L
.85451 .67518 L
.85296 .67968 L
.8518 .68939 L
.84678 .69911 L
.84479 .7039 L
.84309 .70882 L
.84175 .71853 L
.83679 .72824 L
.83508 .73236 L
.83313 .73796 L
.83156 .74767 L
.82669 .75738 L
.82537 .76055 L
.82307 .76709 L
.82122 .77681 L
.81647 .78652 L
.81566 .78848 L
.81291 .79623 L
.81075 .80594 L
.80614 .81566 L
.80594 .81614 L
.80266 .82537 L
.80016 .83508 L
.79623 .84356 L
.79578 .84479 L
.79229 .85451 L
.78947 .86422 L
.78652 .87071 L
.78533 .87393 L
.78181 .88364 L
.77868 .89336 L
.77681 .89757 L
.77477 .90307 L
.77288 .91278 L
.76781 .92249 L
.76709 .92412 L
.76409 .93221 L
.76157 .94192 L
.75738 .95044 L
.75692 .95163 L
.75328 .96134 L
.75023 .97106 L
.74767 .9761 L
.74602 .98077 L
.98077 .98077 L
F
0 g
.98077 .27954 m
.9802 .28147 L
.97729 .29118 L
.97431 .30089 L
.97129 .31061 L
.97106 .31137 L
.96829 .32032 L
.96676 .33003 L
.96255 .33974 L
.96134 .34301 L
.95933 .34946 L
.9583 .35917 L
.95374 .36888 L
.95163 .37441 L
.95031 .37859 L
.94726 .38831 L
.94488 .39802 L
.94192 .40556 L
.94122 .40773 L
.93815 .41744 L
.93599 .42716 L
.93221 .43646 L
.93208 .43687 L
.92898 .44658 L
.92704 .45629 L
.92292 .46601 L
.92249 .46715 L
.91974 .47572 L
.91802 .48543 L
.91372 .49514 L
.91278 .49761 L
.91043 .50486 L
.90893 .51457 L
.90444 .52428 L
.90307 .52782 L
.90105 .53399 L
.89973 .54371 L
.89508 .55342 L
.89336 .55779 L
.89159 .56313 L
.89043 .57284 L
.88563 .58256 L
.88364 .58751 L
.88205 .59227 L
.88099 .60198 L
.87608 .61169 L
.87393 .61699 L
.87244 .62141 L
.8692 .63112 L
.86643 .64083 L
Mistroke
.86422 .64621 L
.86274 .65054 L
.85948 .66026 L
.85666 .66997 L
.85451 .67518 L
.85296 .67968 L
.8518 .68939 L
.84678 .69911 L
.84479 .7039 L
.84309 .70882 L
.84175 .71853 L
.83679 .72824 L
.83508 .73236 L
.83313 .73796 L
.83156 .74767 L
.82669 .75738 L
.82537 .76055 L
.82307 .76709 L
.82122 .77681 L
.81647 .78652 L
.81566 .78848 L
.81291 .79623 L
.81075 .80594 L
.80614 .81566 L
.80594 .81614 L
.80266 .82537 L
.80016 .83508 L
.79623 .84356 L
.79578 .84479 L
.79229 .85451 L
.78947 .86422 L
.78652 .87071 L
.78533 .87393 L
.78181 .88364 L
.77868 .89336 L
.77681 .89757 L
.77477 .90307 L
.77288 .91278 L
.76781 .92249 L
.76709 .92412 L
.76409 .93221 L
.76157 .94192 L
.75738 .95044 L
.75692 .95163 L
.75328 .96134 L
.75023 .97106 L
.74767 .9761 L
.74602 .98077 L
Mfstroke
.6 g
.98077 .3039 m
.97878 .31061 L
.97583 .32032 L
.97169 .33003 L
.97106 .33589 L
.97014 .33974 L
.96721 .34946 L
.96407 .35917 L
.96134 .36765 L
.96107 .36888 L
.9583 .37859 L
.95516 .38831 L
.95201 .39802 L
.95163 .39919 L
.94931 .40773 L
.94618 .41744 L
.943 .42716 L
.94192 .4305 L
.94023 .43687 L
.93714 .44658 L
.93393 .45629 L
.93221 .46158 L
.93107 .46601 L
.92802 .47572 L
.9248 .48543 L
.92249 .49242 L
.92182 .49514 L
.91883 .50486 L
.91559 .51457 L
.91278 .52303 L
.91248 .52428 L
.90957 .53399 L
.90632 .54371 L
.90307 .5534 L
.90307 .55342 L
.90023 .56313 L
.89697 .57284 L
.89369 .58256 L
.89336 .58354 L
.89081 .59227 L
.88754 .60198 L
.88423 .61169 L
.88364 .61344 L
.88132 .62141 L
.87804 .63112 L
.8747 .64083 L
.87393 .6431 L
.87175 .65054 L
.86845 .66026 L
.86509 .66997 L
.86422 .67251 L
.8621 .67968 L
.85878 .68939 L
.85539 .69911 L
.85451 .70168 L
.85237 .70882 L
.84903 .71853 L
.84561 .72824 L
.84479 .73059 L
.84256 .73796 L
.83918 .74767 L
.83574 .75738 L
.83508 .75926 L
.83266 .76709 L
.82925 .77681 L
.82578 .78652 L
.82537 .78768 L
.82267 .79623 L
.81921 .80594 L
.81572 .81566 L
.81566 .81583 L
.81258 .82537 L
.80908 .83508 L
.80594 .84374 L
.80564 .84479 L
.80239 .85451 L
.79885 .86422 L
.79623 .87139 L
.79546 .87393 L
.7921 .88364 L
.78851 .89336 L
.78652 .89877 L
.78517 .90307 L
.78169 .91278 L
.77806 .92249 L
.77681 .92588 L
.77473 .93221 L
.77116 .94192 L
.7675 .95163 L
.76709 .95273 L
.76417 .96134 L
.76051 .97106 L
.75738 .97929 L
.75692 .98077 L
.98077 .98077 L
F
0 g
.98077 .3039 m
.97878 .31061 L
.97583 .32032 L
.97169 .33003 L
.97106 .33589 L
.97014 .33974 L
.96721 .34946 L
.96407 .35917 L
.96134 .36765 L
.96107 .36888 L
.9583 .37859 L
.95516 .38831 L
.95201 .39802 L
.95163 .39919 L
.94931 .40773 L
.94618 .41744 L
.943 .42716 L
.94192 .4305 L
.94023 .43687 L
.93714 .44658 L
.93393 .45629 L
.93221 .46158 L
.93107 .46601 L
.92802 .47572 L
.9248 .48543 L
.92249 .49242 L
.92182 .49514 L
.91883 .50486 L
.91559 .51457 L
.91278 .52303 L
.91248 .52428 L
.90957 .53399 L
.90632 .54371 L
.90307 .5534 L
.90307 .55342 L
.90023 .56313 L
.89697 .57284 L
.89369 .58256 L
.89336 .58354 L
.89081 .59227 L
.88754 .60198 L
.88423 .61169 L
.88364 .61344 L
.88132 .62141 L
.87804 .63112 L
.8747 .64083 L
.87393 .6431 L
.87175 .65054 L
.86845 .66026 L
.86509 .66997 L
Mistroke
.86422 .67251 L
.8621 .67968 L
.85878 .68939 L
.85539 .69911 L
.85451 .70168 L
.85237 .70882 L
.84903 .71853 L
.84561 .72824 L
.84479 .73059 L
.84256 .73796 L
.83918 .74767 L
.83574 .75738 L
.83508 .75926 L
.83266 .76709 L
.82925 .77681 L
.82578 .78652 L
.82537 .78768 L
.82267 .79623 L
.81921 .80594 L
.81572 .81566 L
.81566 .81583 L
.81258 .82537 L
.80908 .83508 L
.80594 .84374 L
.80564 .84479 L
.80239 .85451 L
.79885 .86422 L
.79623 .87139 L
.79546 .87393 L
.7921 .88364 L
.78851 .89336 L
.78652 .89877 L
.78517 .90307 L
.78169 .91278 L
.77806 .92249 L
.77681 .92588 L
.77473 .93221 L
.77116 .94192 L
.7675 .95163 L
.76709 .95273 L
.76417 .96134 L
.76051 .97106 L
.75738 .97929 L
.75692 .98077 L
Mfstroke
.5 g
.98077 .32413 m
.97668 .33003 L
.975 .33974 L
.97288 .34946 L
.97106 .3562 L
.9702 .35917 L
.96726 .36888 L
.96425 .37859 L
.96134 .38804 L
.96127 .38831 L
.95836 .39802 L
.95534 .40773 L
.95231 .41744 L
.95163 .41966 L
.94939 .42716 L
.94636 .43687 L
.94331 .44658 L
.94192 .45105 L
.94035 .45629 L
.93732 .46601 L
.93425 .47572 L
.93221 .48221 L
.93124 .48543 L
.92822 .49514 L
.92512 .50486 L
.92249 .51314 L
.92207 .51457 L
.91904 .52428 L
.91593 .53399 L
.91282 .54371 L
.91278 .54384 L
.9098 .55342 L
.90667 .56313 L
.90354 .57284 L
.90307 .57431 L
.90049 .58256 L
.89734 .59227 L
.89418 .60198 L
.89336 .60454 L
.89111 .61169 L
.88794 .62141 L
.88475 .63112 L
.88364 .63453 L
.88165 .64083 L
.87847 .65054 L
.87525 .66026 L
.87393 .66428 L
.87212 .66997 L
.86891 .67968 L
.86568 .68939 L
.86422 .69379 L
.86251 .69911 L
.85928 .70882 L
.85602 .71853 L
.85451 .72306 L
.85282 .72824 L
.84957 .73796 L
.84628 .74767 L
.84479 .75208 L
.84306 .75738 L
.83977 .76709 L
.83646 .77681 L
.83508 .78085 L
.8332 .78652 L
.82989 .79623 L
.82654 .80594 L
.82537 .80937 L
.82327 .81566 L
.81992 .82537 L
.81654 .83508 L
.81566 .83764 L
.81323 .84479 L
.80985 .85451 L
.80645 .86422 L
.80594 .86566 L
.80311 .87393 L
.79968 .88364 L
.79625 .89336 L
.79623 .89341 L
.79288 .90307 L
.78942 .91278 L
.78652 .92091 L
.78598 .92249 L
.78255 .93221 L
.77905 .94192 L
.77681 .94815 L
.77559 .95163 L
.77211 .96134 L
.76857 .97106 L
.76709 .97512 L
.76509 .98077 L
.98077 .98077 L
F
0 g
.98077 .32413 m
.97668 .33003 L
.975 .33974 L
.97288 .34946 L
.97106 .3562 L
.9702 .35917 L
.96726 .36888 L
.96425 .37859 L
.96134 .38804 L
.96127 .38831 L
.95836 .39802 L
.95534 .40773 L
.95231 .41744 L
.95163 .41966 L
.94939 .42716 L
.94636 .43687 L
.94331 .44658 L
.94192 .45105 L
.94035 .45629 L
.93732 .46601 L
.93425 .47572 L
.93221 .48221 L
.93124 .48543 L
.92822 .49514 L
.92512 .50486 L
.92249 .51314 L
.92207 .51457 L
.91904 .52428 L
.91593 .53399 L
.91282 .54371 L
.91278 .54384 L
.9098 .55342 L
.90667 .56313 L
.90354 .57284 L
.90307 .57431 L
.90049 .58256 L
.89734 .59227 L
.89418 .60198 L
.89336 .60454 L
.89111 .61169 L
.88794 .62141 L
.88475 .63112 L
.88364 .63453 L
.88165 .64083 L
.87847 .65054 L
.87525 .66026 L
.87393 .66428 L
.87212 .66997 L
.86891 .67968 L
.86568 .68939 L
Mistroke
.86422 .69379 L
.86251 .69911 L
.85928 .70882 L
.85602 .71853 L
.85451 .72306 L
.85282 .72824 L
.84957 .73796 L
.84628 .74767 L
.84479 .75208 L
.84306 .75738 L
.83977 .76709 L
.83646 .77681 L
.83508 .78085 L
.8332 .78652 L
.82989 .79623 L
.82654 .80594 L
.82537 .80937 L
.82327 .81566 L
.81992 .82537 L
.81654 .83508 L
.81566 .83764 L
.81323 .84479 L
.80985 .85451 L
.80645 .86422 L
.80594 .86566 L
.80311 .87393 L
.79968 .88364 L
.79625 .89336 L
.79623 .89341 L
.79288 .90307 L
.78942 .91278 L
.78652 .92091 L
.78598 .92249 L
.78255 .93221 L
.77905 .94192 L
.77681 .94815 L
.77559 .95163 L
.77211 .96134 L
.76857 .97106 L
.76709 .97512 L
.76509 .98077 L
Mfstroke
.4 g
.98077 .3434 m
.9786 .34946 L
.97581 .35917 L
.97303 .36888 L
.97106 .37553 L
.97013 .37859 L
.96715 .38831 L
.96416 .39802 L
.96134 .40745 L
.96126 .40773 L
.95827 .41744 L
.95525 .42716 L
.9523 .43687 L
.95163 .43913 L
.94933 .44658 L
.9463 .45629 L
.94329 .46601 L
.94192 .4706 L
.94033 .47572 L
.93728 .48543 L
.93424 .49514 L
.93221 .50183 L
.93126 .50486 L
.9282 .51457 L
.92512 .52428 L
.92249 .53284 L
.92213 .53399 L
.91905 .54371 L
.91595 .55342 L
.91293 .56313 L
.91278 .56361 L
.90984 .57284 L
.90672 .58256 L
.90365 .59227 L
.90307 .59415 L
.90056 .60198 L
.89741 .61169 L
.89431 .62141 L
.89336 .62446 L
.89121 .63112 L
.88804 .64083 L
.8849 .65054 L
.88364 .65453 L
.88178 .66026 L
.87859 .66997 L
.87542 .67968 L
.87393 .68436 L
.87228 .68939 L
.86907 .69911 L
.86587 .70882 L
.86422 .71396 L
.86271 .71853 L
.85947 .72824 L
.85624 .73796 L
.85451 .74331 L
.85306 .74767 L
.84979 .75738 L
.84654 .76709 L
.84479 .77241 L
.84332 .77681 L
.84003 .78652 L
.83675 .79623 L
.83508 .80128 L
.8335 .80594 L
.83018 .81566 L
.82687 .82537 L
.82537 .82989 L
.82359 .83508 L
.82024 .84479 L
.81691 .85451 L
.81566 .85825 L
.8136 .86422 L
.81022 .87393 L
.80686 .88364 L
.80594 .88636 L
.80351 .89336 L
.80009 .90307 L
.79672 .91278 L
.79623 .91422 L
.79332 .92249 L
.78988 .93221 L
.78652 .94182 L
.78648 .94192 L
.78303 .95163 L
.77956 .96134 L
.77681 .96915 L
.77613 .97106 L
.77263 .98077 L
.98077 .98077 L
F
0 g
.98077 .3434 m
.9786 .34946 L
.97581 .35917 L
.97303 .36888 L
.97106 .37553 L
.97013 .37859 L
.96715 .38831 L
.96416 .39802 L
.96134 .40745 L
.96126 .40773 L
.95827 .41744 L
.95525 .42716 L
.9523 .43687 L
.95163 .43913 L
.94933 .44658 L
.9463 .45629 L
.94329 .46601 L
.94192 .4706 L
.94033 .47572 L
.93728 .48543 L
.93424 .49514 L
.93221 .50183 L
.93126 .50486 L
.9282 .51457 L
.92512 .52428 L
.92249 .53284 L
.92213 .53399 L
.91905 .54371 L
.91595 .55342 L
.91293 .56313 L
.91278 .56361 L
.90984 .57284 L
.90672 .58256 L
.90365 .59227 L
.90307 .59415 L
.90056 .60198 L
.89741 .61169 L
.89431 .62141 L
.89336 .62446 L
.89121 .63112 L
.88804 .64083 L
.8849 .65054 L
.88364 .65453 L
.88178 .66026 L
.87859 .66997 L
.87542 .67968 L
.87393 .68436 L
.87228 .68939 L
.86907 .69911 L
.86587 .70882 L
Mistroke
.86422 .71396 L
.86271 .71853 L
.85947 .72824 L
.85624 .73796 L
.85451 .74331 L
.85306 .74767 L
.84979 .75738 L
.84654 .76709 L
.84479 .77241 L
.84332 .77681 L
.84003 .78652 L
.83675 .79623 L
.83508 .80128 L
.8335 .80594 L
.83018 .81566 L
.82687 .82537 L
.82537 .82989 L
.82359 .83508 L
.82024 .84479 L
.81691 .85451 L
.81566 .85825 L
.8136 .86422 L
.81022 .87393 L
.80686 .88364 L
.80594 .88636 L
.80351 .89336 L
.80009 .90307 L
.79672 .91278 L
.79623 .91422 L
.79332 .92249 L
.78988 .93221 L
.78652 .94182 L
.78648 .94192 L
.78303 .95163 L
.77956 .96134 L
.77681 .96915 L
.77613 .97106 L
.77263 .98077 L
Mfstroke
.3 g
.98077 .36363 m
.97915 .36888 L
.97628 .37859 L
.97338 .38831 L
.97106 .39584 L
.97038 .39802 L
.96729 .40773 L
.96421 .41744 L
.96149 .42716 L
.96134 .42783 L
.95847 .43687 L
.95535 .44658 L
.95244 .45629 L
.95163 .4596 L
.94959 .46601 L
.94645 .47572 L
.94342 .48543 L
.94192 .49115 L
.94064 .49514 L
.93749 .50486 L
.93438 .51457 L
.93221 .52247 L
.93162 .52428 L
.92846 .53399 L
.92531 .54371 L
.92253 .55342 L
.92249 .55356 L
.91937 .56313 L
.91618 .57284 L
.91325 .58256 L
.91278 .58442 L
.91021 .59227 L
.90699 .60198 L
.90396 .61169 L
.90307 .61505 L
.90097 .62141 L
.89773 .63112 L
.89462 .64083 L
.89336 .64545 L
.89167 .65054 L
.88841 .66026 L
.88524 .66997 L
.88364 .67561 L
.88229 .67968 L
.87901 .68939 L
.8758 .69911 L
.87393 .70554 L
.87283 .70882 L
.86953 .71853 L
.86628 .72824 L
.86422 .73523 L
.8633 .73796 L
.85997 .74767 L
.8567 .75738 L
.85451 .76469 L
.85369 .76709 L
.85034 .77681 L
.84703 .78652 L
.84479 .7939 L
.84399 .79623 L
.84062 .80594 L
.83729 .81566 L
.83508 .82286 L
.83421 .82537 L
.83081 .83508 L
.82746 .84479 L
.82537 .85158 L
.82435 .85451 L
.82092 .86422 L
.81756 .87393 L
.81566 .88005 L
.81439 .88364 L
.81093 .89336 L
.80756 .90307 L
.80594 .90827 L
.80434 .91278 L
.80085 .92249 L
.79749 .93221 L
.79623 .93624 L
.79419 .94192 L
.79068 .95163 L
.78733 .96134 L
.78652 .96396 L
.78394 .97106 L
.78041 .98077 L
.98077 .98077 L
F
0 g
.98077 .36363 m
.97915 .36888 L
.97628 .37859 L
.97338 .38831 L
.97106 .39584 L
.97038 .39802 L
.96729 .40773 L
.96421 .41744 L
.96149 .42716 L
.96134 .42783 L
.95847 .43687 L
.95535 .44658 L
.95244 .45629 L
.95163 .4596 L
.94959 .46601 L
.94645 .47572 L
.94342 .48543 L
.94192 .49115 L
.94064 .49514 L
.93749 .50486 L
.93438 .51457 L
.93221 .52247 L
.93162 .52428 L
.92846 .53399 L
.92531 .54371 L
.92253 .55342 L
.92249 .55356 L
.91937 .56313 L
.91618 .57284 L
.91325 .58256 L
.91278 .58442 L
.91021 .59227 L
.90699 .60198 L
.90396 .61169 L
.90307 .61505 L
.90097 .62141 L
.89773 .63112 L
.89462 .64083 L
.89336 .64545 L
.89167 .65054 L
.88841 .66026 L
.88524 .66997 L
.88364 .67561 L
.88229 .67968 L
.87901 .68939 L
.8758 .69911 L
.87393 .70554 L
.87283 .70882 L
.86953 .71853 L
.86628 .72824 L
Mistroke
.86422 .73523 L
.8633 .73796 L
.85997 .74767 L
.8567 .75738 L
.85451 .76469 L
.85369 .76709 L
.85034 .77681 L
.84703 .78652 L
.84479 .7939 L
.84399 .79623 L
.84062 .80594 L
.83729 .81566 L
.83508 .82286 L
.83421 .82537 L
.83081 .83508 L
.82746 .84479 L
.82537 .85158 L
.82435 .85451 L
.82092 .86422 L
.81756 .87393 L
.81566 .88005 L
.81439 .88364 L
.81093 .89336 L
.80756 .90307 L
.80594 .90827 L
.80434 .91278 L
.80085 .92249 L
.79749 .93221 L
.79623 .93624 L
.79419 .94192 L
.79068 .95163 L
.78733 .96134 L
.78652 .96396 L
.78394 .97106 L
.78041 .98077 L
Mfstroke
.2 g
.98077 .388 m
.98069 .38831 L
.97796 .39802 L
.97512 .40773 L
.97205 .41744 L
.97106 .42033 L
.96855 .42716 L
.96411 .43687 L
.96316 .44658 L
.96134 .45247 L
.95997 .45629 L
.95589 .46601 L
.95431 .47572 L
.95163 .48441 L
.95127 .48543 L
.94743 .49514 L
.9454 .50486 L
.9424 .51457 L
.94192 .51609 L
.93879 .52428 L
.93644 .53399 L
.93342 .54371 L
.93221 .54755 L
.93001 .55342 L
.92558 .56313 L
.92438 .57284 L
.92249 .57881 L
.92111 .58256 L
.91691 .59227 L
.91528 .60198 L
.91278 .60985 L
.91211 .61169 L
.90808 .62141 L
.90611 .63112 L
.90307 .64066 L
.90301 .64083 L
.89909 .65054 L
.89688 .66026 L
.89376 .66997 L
.89336 .67121 L
.88999 .67968 L
.88758 .68939 L
.88445 .69911 L
.88364 .70155 L
.88077 .70882 L
.87821 .71853 L
.87506 .72824 L
.87393 .73165 L
.87145 .73796 L
.86672 .74767 L
.8656 .75738 L
.86422 .76153 L
.86203 .76709 L
.85737 .77681 L
.85606 .78652 L
.85451 .79118 L
.85252 .79623 L
.84788 .80594 L
.84646 .81566 L
.84479 .82059 L
.8429 .82537 L
.83826 .83508 L
.83677 .84479 L
.83508 .84976 L
.83319 .85451 L
.8285 .86422 L
.827 .87393 L
.82537 .8787 L
.82337 .88364 L
.8186 .89336 L
.81715 .90307 L
.81566 .90739 L
.81345 .91278 L
.80855 .92249 L
.80722 .93221 L
.80594 .93584 L
.80341 .94192 L
.80056 .95163 L
.79719 .96134 L
.79623 .96405 L
.79325 .97106 L
.79047 .98077 L
.98077 .98077 L
F
0 g
.98077 .388 m
.98069 .38831 L
.97796 .39802 L
.97512 .40773 L
.97205 .41744 L
.97106 .42033 L
.96855 .42716 L
.96411 .43687 L
.96316 .44658 L
.96134 .45247 L
.95997 .45629 L
.95589 .46601 L
.95431 .47572 L
.95163 .48441 L
.95127 .48543 L
.94743 .49514 L
.9454 .50486 L
.9424 .51457 L
.94192 .51609 L
.93879 .52428 L
.93644 .53399 L
.93342 .54371 L
.93221 .54755 L
.93001 .55342 L
.92558 .56313 L
.92438 .57284 L
.92249 .57881 L
.92111 .58256 L
.91691 .59227 L
.91528 .60198 L
.91278 .60985 L
.91211 .61169 L
.90808 .62141 L
.90611 .63112 L
.90307 .64066 L
.90301 .64083 L
.89909 .65054 L
.89688 .66026 L
.89376 .66997 L
.89336 .67121 L
.88999 .67968 L
.88758 .68939 L
.88445 .69911 L
.88364 .70155 L
.88077 .70882 L
.87821 .71853 L
.87506 .72824 L
.87393 .73165 L
.87145 .73796 L
.86672 .74767 L
Mistroke
.8656 .75738 L
.86422 .76153 L
.86203 .76709 L
.85737 .77681 L
.85606 .78652 L
.85451 .79118 L
.85252 .79623 L
.84788 .80594 L
.84646 .81566 L
.84479 .82059 L
.8429 .82537 L
.83826 .83508 L
.83677 .84479 L
.83508 .84976 L
.83319 .85451 L
.8285 .86422 L
.827 .87393 L
.82537 .8787 L
.82337 .88364 L
.8186 .89336 L
.81715 .90307 L
.81566 .90739 L
.81345 .91278 L
.80855 .92249 L
.80722 .93221 L
.80594 .93584 L
.80341 .94192 L
.80056 .95163 L
.79719 .96134 L
.79623 .96405 L
.79325 .97106 L
.79047 .98077 L
Mfstroke
.3 g
.98077 .48093 m
.97944 .48543 L
.97651 .49514 L
.97351 .50486 L
.97106 .51277 L
.97049 .51457 L
.96749 .52428 L
.96552 .53399 L
.96159 .54371 L
.96134 .54438 L
.95852 .55342 L
.95693 .56313 L
.95272 .57284 L
.95163 .57578 L
.9495 .58256 L
.94833 .59227 L
.94381 .60198 L
.94192 .60695 L
.94041 .61169 L
.93734 .62141 L
.93486 .63112 L
.93221 .63787 L
.93125 .64083 L
.92816 .65054 L
.92584 .66026 L
.92249 .66855 L
.92203 .66997 L
.91891 .67968 L
.91676 .68939 L
.91278 .69898 L
.91274 .69911 L
.9096 .70882 L
.9076 .71853 L
.90343 .72824 L
.90307 .72919 L
.90021 .73796 L
.89835 .74767 L
.89404 .75738 L
.89336 .75916 L
.89074 .76709 L
.88899 .77681 L
.88457 .78652 L
.88364 .78888 L
.8812 .79623 L
.87951 .80594 L
.875 .81566 L
.87393 .81836 L
.87158 .82537 L
.86991 .83508 L
.86533 .84479 L
.86422 .84758 L
.86188 .85451 L
.86016 .86422 L
.85556 .87393 L
.85451 .87655 L
.85209 .88364 L
.85028 .89336 L
.84568 .90307 L
.84479 .90527 L
.84221 .91278 L
.84026 .92249 L
.83569 .93221 L
.83508 .93372 L
.83224 .94192 L
.8301 .95163 L
.8256 .96134 L
.82537 .96191 L
.82217 .97106 L
.81981 .98077 L
.98077 .98077 L
F
0 g
.98077 .48093 m
.97944 .48543 L
.97651 .49514 L
.97351 .50486 L
.97106 .51277 L
.97049 .51457 L
.96749 .52428 L
.96552 .53399 L
.96159 .54371 L
.96134 .54438 L
.95852 .55342 L
.95693 .56313 L
.95272 .57284 L
.95163 .57578 L
.9495 .58256 L
.94833 .59227 L
.94381 .60198 L
.94192 .60695 L
.94041 .61169 L
.93734 .62141 L
.93486 .63112 L
.93221 .63787 L
.93125 .64083 L
.92816 .65054 L
.92584 .66026 L
.92249 .66855 L
.92203 .66997 L
.91891 .67968 L
.91676 .68939 L
.91278 .69898 L
.91274 .69911 L
.9096 .70882 L
.9076 .71853 L
.90343 .72824 L
.90307 .72919 L
.90021 .73796 L
.89835 .74767 L
.89404 .75738 L
.89336 .75916 L
.89074 .76709 L
.88899 .77681 L
.88457 .78652 L
.88364 .78888 L
.8812 .79623 L
.87951 .80594 L
.875 .81566 L
.87393 .81836 L
.87158 .82537 L
.86991 .83508 L
.86533 .84479 L
Mistroke
.86422 .84758 L
.86188 .85451 L
.86016 .86422 L
.85556 .87393 L
.85451 .87655 L
.85209 .88364 L
.85028 .89336 L
.84568 .90307 L
.84479 .90527 L
.84221 .91278 L
.84026 .92249 L
.83569 .93221 L
.83508 .93372 L
.83224 .94192 L
.8301 .95163 L
.8256 .96134 L
.82537 .96191 L
.82217 .97106 L
.81981 .98077 L
Mfstroke
.4 g
.98077 .50528 m
.978 .51457 L
.97504 .52428 L
.97158 .53399 L
.97106 .53727 L
.96941 .54371 L
.96638 .55342 L
.96323 .56313 L
.96134 .56904 L
.96042 .57284 L
.95748 .58256 L
.95431 .59227 L
.95163 .60057 L
.95131 .60198 L
.9485 .61169 L
.94533 .62141 L
.94216 .63112 L
.94192 .63188 L
.93944 .64083 L
.93629 .65054 L
.93309 .66026 L
.93221 .66296 L
.93031 .66997 L
.92717 .67968 L
.92394 .68939 L
.92249 .69381 L
.92109 .69911 L
.91798 .70882 L
.91473 .71853 L
.91278 .72442 L
.91178 .72824 L
.90872 .73796 L
.90545 .74767 L
.90307 .75479 L
.90241 .75738 L
.89938 .76709 L
.89609 .77681 L
.89336 .78493 L
.89295 .78652 L
.88996 .79623 L
.88666 .80594 L
.88364 .81482 L
.88344 .81566 L
.88047 .82537 L
.87715 .83508 L
.87393 .84448 L
.87385 .84479 L
.8709 .85451 L
.86756 .86422 L
.86422 .87389 L
.86421 .87393 L
.86124 .88364 L
.85788 .89336 L
.85451 .90306 L
.8545 .90307 L
.85151 .91278 L
.84812 .92249 L
.84479 .93198 L
.84473 .93221 L
.84169 .94192 L
.83827 .95163 L
.83508 .96064 L
.83489 .96134 L
.83177 .97106 L
.82832 .98077 L
.98077 .98077 L
F
0 g
.98077 .50528 m
.978 .51457 L
.97504 .52428 L
.97158 .53399 L
.97106 .53727 L
.96941 .54371 L
.96638 .55342 L
.96323 .56313 L
.96134 .56904 L
.96042 .57284 L
.95748 .58256 L
.95431 .59227 L
.95163 .60057 L
.95131 .60198 L
.9485 .61169 L
.94533 .62141 L
.94216 .63112 L
.94192 .63188 L
.93944 .64083 L
.93629 .65054 L
.93309 .66026 L
.93221 .66296 L
.93031 .66997 L
.92717 .67968 L
.92394 .68939 L
.92249 .69381 L
.92109 .69911 L
.91798 .70882 L
.91473 .71853 L
.91278 .72442 L
.91178 .72824 L
.90872 .73796 L
.90545 .74767 L
.90307 .75479 L
.90241 .75738 L
.89938 .76709 L
.89609 .77681 L
.89336 .78493 L
.89295 .78652 L
.88996 .79623 L
.88666 .80594 L
.88364 .81482 L
.88344 .81566 L
.88047 .82537 L
.87715 .83508 L
.87393 .84448 L
.87385 .84479 L
.8709 .85451 L
.86756 .86422 L
.86422 .87389 L
Mistroke
.86421 .87393 L
.86124 .88364 L
.85788 .89336 L
.85451 .90306 L
.8545 .90307 L
.85151 .91278 L
.84812 .92249 L
.84479 .93198 L
.84473 .93221 L
.84169 .94192 L
.83827 .95163 L
.83508 .96064 L
.83489 .96134 L
.83177 .97106 L
.82832 .98077 L
Mfstroke
.5 g
.98077 .52551 m
.97615 .53399 L
.97451 .54371 L
.97221 .55342 L
.97106 .55758 L
.96943 .56313 L
.96647 .57284 L
.96345 .58256 L
.96134 .58942 L
.96052 .59227 L
.95756 .60198 L
.95453 .61169 L
.95163 .62104 L
.95153 .62141 L
.94859 .63112 L
.94555 .64083 L
.94251 .65054 L
.94192 .65243 L
.93956 .66026 L
.9365 .66997 L
.93343 .67968 L
.93221 .68359 L
.93045 .68939 L
.9274 .69911 L
.9243 .70882 L
.92249 .71453 L
.92128 .71853 L
.91822 .72824 L
.9151 .73796 L
.91278 .74523 L
.91204 .74767 L
.90897 .75738 L
.90584 .76709 L
.90307 .77569 L
.90273 .77681 L
.89966 .78652 L
.8965 .79623 L
.89336 .80592 L
.89335 .80594 L
.89027 .81566 L
.88709 .82537 L
.88391 .83508 L
.88364 .83591 L
.88081 .84479 L
.87761 .85451 L
.8744 .86422 L
.87393 .86566 L
.87128 .87393 L
.86805 .88364 L
.86482 .89336 L
.86422 .89517 L
.86166 .90307 L
.85842 .91278 L
.85516 .92249 L
.85451 .92444 L
.85197 .93221 L
.8487 .94192 L
.84541 .95163 L
.84479 .95346 L
.84219 .96134 L
.83889 .97106 L
.83558 .98077 L
.98077 .98077 L
F
0 g
.98077 .52551 m
.97615 .53399 L
.97451 .54371 L
.97221 .55342 L
.97106 .55758 L
.96943 .56313 L
.96647 .57284 L
.96345 .58256 L
.96134 .58942 L
.96052 .59227 L
.95756 .60198 L
.95453 .61169 L
.95163 .62104 L
.95153 .62141 L
.94859 .63112 L
.94555 .64083 L
.94251 .65054 L
.94192 .65243 L
.93956 .66026 L
.9365 .66997 L
.93343 .67968 L
.93221 .68359 L
.93045 .68939 L
.9274 .69911 L
.9243 .70882 L
.92249 .71453 L
.92128 .71853 L
.91822 .72824 L
.9151 .73796 L
.91278 .74523 L
.91204 .74767 L
.90897 .75738 L
.90584 .76709 L
.90307 .77569 L
.90273 .77681 L
.89966 .78652 L
.8965 .79623 L
.89336 .80592 L
.89335 .80594 L
.89027 .81566 L
.88709 .82537 L
.88391 .83508 L
.88364 .83591 L
.88081 .84479 L
.87761 .85451 L
.8744 .86422 L
.87393 .86566 L
.87128 .87393 L
.86805 .88364 L
.86482 .89336 L
Mistroke
.86422 .89517 L
.86166 .90307 L
.85842 .91278 L
.85516 .92249 L
.85451 .92444 L
.85197 .93221 L
.8487 .94192 L
.84541 .95163 L
.84479 .95346 L
.84219 .96134 L
.83889 .97106 L
.83558 .98077 L
Mfstroke
.6 g
.98077 .54478 m
.97783 .55342 L
.97509 .56313 L
.97227 .57284 L
.97106 .57692 L
.96934 .58256 L
.96635 .59227 L
.96337 .60198 L
.96134 .60883 L
.96047 .61169 L
.95747 .62141 L
.95446 .63112 L
.95163 .64052 L
.95154 .64083 L
.94853 .65054 L
.94549 .66026 L
.94252 .66997 L
.94192 .67198 L
.93952 .67968 L
.93647 .68939 L
.93344 .69911 L
.93221 .70321 L
.93045 .70882 L
.92738 .71853 L
.92432 .72824 L
.92249 .73422 L
.92132 .73796 L
.91823 .74767 L
.91514 .75738 L
.91278 .76499 L
.91212 .76709 L
.90901 .77681 L
.90589 .78652 L
.90307 .79554 L
.90285 .79623 L
.89972 .80594 L
.89658 .81566 L
.8935 .82537 L
.89336 .82584 L
.89037 .83508 L
.8872 .84479 L
.88408 .85451 L
.88364 .85591 L
.88094 .86422 L
.87774 .87393 L
.8746 .88364 L
.87393 .88575 L
.87143 .89336 L
.86821 .90307 L
.86504 .91278 L
.86422 .91534 L
.86185 .92249 L
.85861 .93221 L
.8554 .94192 L
.85451 .94469 L
.85219 .95163 L
.84892 .96134 L
.84569 .97106 L
.84479 .9738 L
.84245 .98077 L
.98077 .98077 L
F
0 g
.98077 .54478 m
.97783 .55342 L
.97509 .56313 L
.97227 .57284 L
.97106 .57692 L
.96934 .58256 L
.96635 .59227 L
.96337 .60198 L
.96134 .60883 L
.96047 .61169 L
.95747 .62141 L
.95446 .63112 L
.95163 .64052 L
.95154 .64083 L
.94853 .65054 L
.94549 .66026 L
.94252 .66997 L
.94192 .67198 L
.93952 .67968 L
.93647 .68939 L
.93344 .69911 L
.93221 .70321 L
.93045 .70882 L
.92738 .71853 L
.92432 .72824 L
.92249 .73422 L
.92132 .73796 L
.91823 .74767 L
.91514 .75738 L
.91278 .76499 L
.91212 .76709 L
.90901 .77681 L
.90589 .78652 L
.90307 .79554 L
.90285 .79623 L
.89972 .80594 L
.89658 .81566 L
.8935 .82537 L
.89336 .82584 L
.89037 .83508 L
.8872 .84479 L
.88408 .85451 L
.88364 .85591 L
.88094 .86422 L
.87774 .87393 L
.8746 .88364 L
.87393 .88575 L
.87143 .89336 L
.86821 .90307 L
.86504 .91278 L
Mistroke
.86422 .91534 L
.86185 .92249 L
.85861 .93221 L
.8554 .94192 L
.85451 .94469 L
.85219 .95163 L
.84892 .96134 L
.84569 .97106 L
.84479 .9738 L
.84245 .98077 L
Mfstroke
.7 g
.98077 .56501 m
.97839 .57284 L
.97552 .58256 L
.97259 .59227 L
.97106 .59722 L
.96956 .60198 L
.96647 .61169 L
.96342 .62141 L
.96134 .62922 L
.96075 .63112 L
.95764 .64083 L
.95454 .65054 L
.9518 .66026 L
.95163 .66099 L
.94876 .66997 L
.94562 .67968 L
.9427 .68939 L
.94192 .69253 L
.93981 .69911 L
.93665 .70882 L
.93361 .71853 L
.93221 .72385 L
.93079 .72824 L
.92762 .73796 L
.9245 .74767 L
.92249 .75494 L
.92171 .75738 L
.91852 .76709 L
.91535 .77681 L
.91278 .78581 L
.91255 .78652 L
.90935 .79623 L
.90615 .80594 L
.90326 .81566 L
.90307 .81644 L
.90011 .82537 L
.89688 .83508 L
.89389 .84479 L
.89336 .84683 L
.8908 .85451 L
.88754 .86422 L
.88447 .87393 L
.88364 .877 L
.88142 .88364 L
.87814 .89336 L
.875 .90307 L
.87393 .90693 L
.87196 .91278 L
.86865 .92249 L
.86547 .93221 L
.86422 .93662 L
.86242 .94192 L
.85909 .95163 L
.85588 .96134 L
.85451 .96607 L
.8528 .97106 L
.84945 .98077 L
.98077 .98077 L
F
0 g
.98077 .56501 m
.97839 .57284 L
.97552 .58256 L
.97259 .59227 L
.97106 .59722 L
.96956 .60198 L
.96647 .61169 L
.96342 .62141 L
.96134 .62922 L
.96075 .63112 L
.95764 .64083 L
.95454 .65054 L
.9518 .66026 L
.95163 .66099 L
.94876 .66997 L
.94562 .67968 L
.9427 .68939 L
.94192 .69253 L
.93981 .69911 L
.93665 .70882 L
.93361 .71853 L
.93221 .72385 L
.93079 .72824 L
.92762 .73796 L
.9245 .74767 L
.92249 .75494 L
.92171 .75738 L
.91852 .76709 L
.91535 .77681 L
.91278 .78581 L
.91255 .78652 L
.90935 .79623 L
.90615 .80594 L
.90326 .81566 L
.90307 .81644 L
.90011 .82537 L
.89688 .83508 L
.89389 .84479 L
.89336 .84683 L
.8908 .85451 L
.88754 .86422 L
.88447 .87393 L
.88364 .877 L
.88142 .88364 L
.87814 .89336 L
.875 .90307 L
.87393 .90693 L
.87196 .91278 L
.86865 .92249 L
.86547 .93221 L
Mistroke
.86422 .93662 L
.86242 .94192 L
.85909 .95163 L
.85588 .96134 L
.85451 .96607 L
.8528 .97106 L
.84945 .98077 L
Mfstroke
.8 g
.98077 .58937 m
.97997 .59227 L
.97722 .60198 L
.97433 .61169 L
.97117 .62141 L
.97106 .62174 L
.96749 .63112 L
.96532 .64083 L
.96237 .65054 L
.96134 .65385 L
.95898 .66026 L
.95457 .66997 L
.95352 .67968 L
.95163 .68577 L
.95033 .68939 L
.94623 .69911 L
.94461 .70882 L
.94192 .71749 L
.94155 .71853 L
.93768 .72824 L
.93564 .73796 L
.93261 .74767 L
.93221 .74895 L
.92895 .75738 L
.92661 .76709 L
.92357 .77681 L
.92249 .78019 L
.9201 .78652 L
.91556 .79623 L
.91446 .80594 L
.91278 .81122 L
.91112 .81566 L
.90681 .82537 L
.90529 .83508 L
.90307 .84202 L
.90204 .84479 L
.89788 .85451 L
.89605 .86422 L
.89336 .87261 L
.89287 .87393 L
.88882 .88364 L
.88675 .89336 L
.88364 .90296 L
.8836 .90307 L
.87963 .91278 L
.87738 .92249 L
.87422 .93221 L
.87393 .93306 L
.87033 .94192 L
.86793 .95163 L
.86475 .96134 L
.86422 .96293 L
.86092 .97106 L
.85842 .98077 L
.98077 .98077 L
F
0 g
.98077 .58937 m
.97997 .59227 L
.97722 .60198 L
.97433 .61169 L
.97117 .62141 L
.97106 .62174 L
.96749 .63112 L
.96532 .64083 L
.96237 .65054 L
.96134 .65385 L
.95898 .66026 L
.95457 .66997 L
.95352 .67968 L
.95163 .68577 L
.95033 .68939 L
.94623 .69911 L
.94461 .70882 L
.94192 .71749 L
.94155 .71853 L
.93768 .72824 L
.93564 .73796 L
.93261 .74767 L
.93221 .74895 L
.92895 .75738 L
.92661 .76709 L
.92357 .77681 L
.92249 .78019 L
.9201 .78652 L
.91556 .79623 L
.91446 .80594 L
.91278 .81122 L
.91112 .81566 L
.90681 .82537 L
.90529 .83508 L
.90307 .84202 L
.90204 .84479 L
.89788 .85451 L
.89605 .86422 L
.89336 .87261 L
.89287 .87393 L
.88882 .88364 L
.88675 .89336 L
.88364 .90296 L
.8836 .90307 L
.87963 .91278 L
.87738 .92249 L
.87422 .93221 L
.87393 .93306 L
.87033 .94192 L
.86793 .95163 L
Mistroke
.86475 .96134 L
.86422 .96293 L
.86092 .97106 L
.85842 .98077 L
Mfstroke
.7 g
.98077 .6823 m
.97867 .68939 L
.97571 .69911 L
.97271 .70882 L
.97106 .71416 L
.96969 .71853 L
.9667 .72824 L
.96438 .73796 L
.96134 .74578 L
.96075 .74767 L
.95772 .75738 L
.95569 .76709 L
.95176 .77681 L
.95163 .77715 L
.94869 .78652 L
.94698 .79623 L
.9428 .80594 L
.94192 .80832 L
.93959 .81566 L
.93824 .82537 L
.9338 .83508 L
.93221 .83925 L
.93043 .84479 L
.92945 .85451 L
.92473 .86422 L
.92249 .86994 L
.9212 .87393 L
.91809 .88364 L
.9156 .89336 L
.91278 .90039 L
.9119 .90307 L
.90876 .91278 L
.90639 .92249 L
.90307 .93059 L
.90253 .93221 L
.89937 .94192 L
.89709 .95163 L
.89336 .96054 L
.89309 .96134 L
.8899 .97106 L
.88769 .98077 L
.98077 .98077 L
F
0 g
.98077 .6823 m
.97867 .68939 L
.97571 .69911 L
.97271 .70882 L
.97106 .71416 L
.96969 .71853 L
.9667 .72824 L
.96438 .73796 L
.96134 .74578 L
.96075 .74767 L
.95772 .75738 L
.95569 .76709 L
.95176 .77681 L
.95163 .77715 L
.94869 .78652 L
.94698 .79623 L
.9428 .80594 L
.94192 .80832 L
.93959 .81566 L
.93824 .82537 L
.9338 .83508 L
.93221 .83925 L
.93043 .84479 L
.92945 .85451 L
.92473 .86422 L
.92249 .86994 L
.9212 .87393 L
.91809 .88364 L
.9156 .89336 L
.91278 .90039 L
.9119 .90307 L
.90876 .91278 L
.90639 .92249 L
.90307 .93059 L
.90253 .93221 L
.89937 .94192 L
.89709 .95163 L
.89336 .96054 L
.89309 .96134 L
.8899 .97106 L
.88769 .98077 L
s
.6 g
.98077 .70667 m
.98013 .70882 L
.97722 .71853 L
.97425 .72824 L
.97119 .73796 L
.97106 .73865 L
.96864 .74767 L
.96555 .75738 L
.9624 .76709 L
.96134 .77042 L
.95969 .77681 L
.95664 .78652 L
.95348 .79623 L
.95163 .80196 L
.95065 .80594 L
.94767 .81566 L
.94449 .82537 L
.94192 .83327 L
.94149 .83508 L
.93862 .84479 L
.93543 .85451 L
.93225 .86422 L
.93221 .86434 L
.9295 .87393 L
.92631 .88364 L
.92309 .89336 L
.92249 .89519 L
.9203 .90307 L
.91712 .91278 L
.91387 .92249 L
.91278 .9258 L
.91102 .93221 L
.90785 .94192 L
.90458 .95163 L
.90307 .95618 L
.90166 .96134 L
.89851 .97106 L
.89522 .98077 L
.98077 .98077 L
F
0 g
.98077 .70667 m
.98013 .70882 L
.97722 .71853 L
.97425 .72824 L
.97119 .73796 L
.97106 .73865 L
.96864 .74767 L
.96555 .75738 L
.9624 .76709 L
.96134 .77042 L
.95969 .77681 L
.95664 .78652 L
.95348 .79623 L
.95163 .80196 L
.95065 .80594 L
.94767 .81566 L
.94449 .82537 L
.94192 .83327 L
.94149 .83508 L
.93862 .84479 L
.93543 .85451 L
.93225 .86422 L
.93221 .86434 L
.9295 .87393 L
.92631 .88364 L
.92309 .89336 L
.92249 .89519 L
.9203 .90307 L
.91712 .91278 L
.91387 .92249 L
.91278 .9258 L
.91102 .93221 L
.90785 .94192 L
.90458 .95163 L
.90307 .95618 L
.90166 .96134 L
.89851 .97106 L
.89522 .98077 L
s
.5 g
.98077 .7269 m
.98037 .72824 L
.97574 .73796 L
.97396 .74767 L
.9715 .75738 L
.97106 .75896 L
.96866 .76709 L
.96567 .77681 L
.96266 .78652 L
.96134 .79081 L
.95975 .79623 L
.95676 .80594 L
.95373 .81566 L
.95163 .82243 L
.95077 .82537 L
.94779 .83508 L
.94474 .84479 L
.94192 .85382 L
.94172 .85451 L
.93875 .86422 L
.93569 .87393 L
.93262 .88364 L
.93221 .88498 L
.92965 .89336 L
.92657 .90307 L
.92348 .91278 L
.92249 .91591 L
.92048 .92249 L
.91739 .93221 L
.91428 .94192 L
.91278 .94661 L
.91124 .95163 L
.90814 .96134 L
.905 .97106 L
.90307 .97707 L
.90193 .98077 L
.98077 .98077 L
F
0 g
.98077 .7269 m
.98037 .72824 L
.97574 .73796 L
.97396 .74767 L
.9715 .75738 L
.97106 .75896 L
.96866 .76709 L
.96567 .77681 L
.96266 .78652 L
.96134 .79081 L
.95975 .79623 L
.95676 .80594 L
.95373 .81566 L
.95163 .82243 L
.95077 .82537 L
.94779 .83508 L
.94474 .84479 L
.94192 .85382 L
.94172 .85451 L
.93875 .86422 L
.93569 .87393 L
.93262 .88364 L
.93221 .88498 L
.92965 .89336 L
.92657 .90307 L
.92348 .91278 L
.92249 .91591 L
.92048 .92249 L
.91739 .93221 L
.91428 .94192 L
.91278 .94661 L
.91124 .95163 L
.90814 .96134 L
.905 .97106 L
.90307 .97707 L
.90193 .98077 L
s
.4 g
.98077 .74617 m
.98015 .74767 L
.97709 .75738 L
.97435 .76709 L
.97151 .77681 L
.97106 .7783 L
.96855 .78652 L
.96556 .79623 L
.9626 .80594 L
.96134 .81021 L
.95968 .81566 L
.95667 .82537 L
.95367 .83508 L
.95163 .8419 L
.95074 .84479 L
.94772 .85451 L
.94469 .86422 L
.94192 .87336 L
.94174 .87393 L
.93871 .88364 L
.93566 .89336 L
.93266 .90307 L
.93221 .9046 L
.92964 .91278 L
.92656 .92249 L
.92352 .93221 L
.92249 .9356 L
.9205 .94192 L
.9174 .95163 L
.91433 .96134 L
.91278 .96638 L
.9113 .97106 L
.90818 .98077 L
.98077 .98077 L
F
0 g
.98077 .74617 m
.98015 .74767 L
.97709 .75738 L
.97435 .76709 L
.97151 .77681 L
.97106 .7783 L
.96855 .78652 L
.96556 .79623 L
.9626 .80594 L
.96134 .81021 L
.95968 .81566 L
.95667 .82537 L
.95367 .83508 L
.95163 .8419 L
.95074 .84479 L
.94772 .85451 L
.94469 .86422 L
.94192 .87336 L
.94174 .87393 L
.93871 .88364 L
.93566 .89336 L
.93266 .90307 L
.93221 .9046 L
.92964 .91278 L
.92656 .92249 L
.92352 .93221 L
.92249 .9356 L
.9205 .94192 L
.9174 .95163 L
.91433 .96134 L
.91278 .96638 L
.9113 .97106 L
.90818 .98077 L
s
.3 g
.98077 .7664 m
.98055 .76709 L
.97763 .77681 L
.97475 .78652 L
.9718 .79623 L
.97106 .79861 L
.96875 .80594 L
.96564 .81566 L
.96267 .82537 L
.96134 .8306 L
.95993 .83508 L
.95681 .84479 L
.95375 .85451 L
.95163 .86237 L
.95105 .86422 L
.94792 .87393 L
.94481 .88364 L
.94205 .89336 L
.94192 .89392 L
.93897 .90307 L
.93582 .91278 L
.93289 .92249 L
.93221 .92523 L
.92995 .93221 L
.92677 .94192 L
.92373 .95163 L
.92249 .95632 L
.92087 .96134 L
.91767 .97106 L
.91455 .98077 L
.98077 .98077 L
F
0 g
.98077 .7664 m
.98055 .76709 L
.97763 .77681 L
.97475 .78652 L
.9718 .79623 L
.97106 .79861 L
.96875 .80594 L
.96564 .81566 L
.96267 .82537 L
.96134 .8306 L
.95993 .83508 L
.95681 .84479 L
.95375 .85451 L
.95163 .86237 L
.95105 .86422 L
.94792 .87393 L
.94481 .88364 L
.94205 .89336 L
.94192 .89392 L
.93897 .90307 L
.93582 .91278 L
.93289 .92249 L
.93221 .92523 L
.92995 .93221 L
.92677 .94192 L
.92373 .95163 L
.92249 .95632 L
.92087 .96134 L
.91767 .97106 L
.91455 .98077 L
s
.2 g
.98077 .79075 m
.97924 .79623 L
.97647 .80594 L
.97353 .81566 L
.97106 .82311 L
.97026 .82537 L
.96636 .83508 L
.96454 .84479 L
.96158 .85451 L
.96134 .85525 L
.95793 .86422 L
.9557 .87393 L
.95272 .88364 L
.95163 .88715 L
.94933 .89336 L
.94492 .90307 L
.94381 .91278 L
.94192 .91885 L
.9406 .92249 L
.93647 .93221 L
.93484 .94192 L
.93221 .95034 L
.93174 .95163 L
.92782 .96134 L
.9258 .97106 L
.92276 .98077 L
.98077 .98077 L
F
0 g
.98077 .79075 m
.97924 .79623 L
.97647 .80594 L
.97353 .81566 L
.97106 .82311 L
.97026 .82537 L
.96636 .83508 L
.96454 .84479 L
.96158 .85451 L
.96134 .85525 L
.95793 .86422 L
.9557 .87393 L
.95272 .88364 L
.95163 .88715 L
.94933 .89336 L
.94492 .90307 L
.94381 .91278 L
.94192 .91885 L
.9406 .92249 L
.93647 .93221 L
.93484 .94192 L
.93221 .95034 L
.93174 .95163 L
.92782 .96134 L
.9258 .97106 L
.92276 .98077 L
s
.3 g
.98077 .88367 m
.97789 .89336 L
.97492 .90307 L
.97191 .91278 L
.97106 .91554 L
.9689 .92249 L
.9678 .93221 L
.96332 .94192 L
.96134 .94717 L
.95994 .95163 L
.95692 .96134 L
.95456 .97106 L
.95163 .97838 L
.95093 .98077 L
.98077 .98077 L
F
0 g
.98077 .88367 m
.97789 .89336 L
.97492 .90307 L
.97191 .91278 L
.97106 .91554 L
.9689 .92249 L
.9678 .93221 L
.96332 .94192 L
.96134 .94717 L
.95994 .95163 L
.95692 .96134 L
.95456 .97106 L
.95163 .97838 L
.95093 .98077 L
s
.4 g
.98077 .90805 m
.97937 .91278 L
.97644 .92249 L
.97147 .93221 L
.97106 .94004 L
.97064 .94192 L
.96784 .95163 L
.96471 .96134 L
.96158 .97106 L
.96134 .9718 L
.95892 .98077 L
.98077 .98077 L
F
0 g
.98077 .90805 m
.97937 .91278 L
.97644 .92249 L
.97147 .93221 L
.97106 .94004 L
.97064 .94192 L
.96784 .95163 L
.96471 .96134 L
.96158 .97106 L
.96134 .9718 L
.95892 .98077 L
s
.5 g
.98077 .92828 m
.97735 .93221 L
.97533 .94192 L
.97337 .95163 L
.97106 .96035 L
.97077 .96134 L
.96787 .97106 L
.96487 .98077 L
.98077 .98077 L
F
0 g
.98077 .92828 m
.97735 .93221 L
.97533 .94192 L
.97337 .95163 L
.97106 .96035 L
.97077 .96134 L
.96787 .97106 L
.96487 .98077 L
s
.6 g
.98077 .94755 m
.97923 .95163 L
.97637 .96134 L
.97361 .97106 L
.97106 .97969 L
.97073 .98077 L
.98077 .98077 L
F
0 g
.98077 .94755 m
.97923 .95163 L
.97637 .96134 L
.97361 .97106 L
.97106 .97969 L
.97073 .98077 L
s
.7 g
.98077 .96778 m
.97975 .97106 L
.97687 .98077 L
.98077 .98077 L
F
0 g
.98077 .96778 m
.97975 .97106 L
.97687 .98077 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00`_ooool2o`0000;ooooo0_l0
002Pooooo`00`_ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgJ3ooooo0033ooooo`04omgMgOl0
003o410@olc<c:7ooooo0033ooooo`04onk^k_lQ8B7o410@onk^kZ7ooooo0033ooooo`04ob4Q8Omg
MgOoMgMgoc8b<Z7ooooo0032ooooo`;o00000_ooool2o`000:3ooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0011oooo
o`;o000000?o410@ooooooooool08oooool5o`00023ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0T
ooooo`Go00009_ooool2o`000003oa0@4?oooooooooo02?ooooo00Gok^k^oc8b<_l0003o410@olc<
c00Tooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`08Oooool4o`000008oa0@4?ooooooooooonk^k_lb
<S;o0000oc8b<_o^k^h3ooooo`00@_ooool00ol0003oooooooooo`0Tooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@08?ooool01OmgMgOoV9RHoooooonHV9SoMgMg02Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A00Wooooo`03o`000?oooooooooo02Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@0Tooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B408oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00oooool003Oooooo1_l00002ooooo`Go00007Oooool6o`0000?ooooo00?oV9RHob4Q
8Oo^k^h08Oooool01Ol@413ooooooooooooooooo410@02Gooooo00?oV9RHob4Q8Oo^k^h09Oooool5
o`0002Gooooo00Go0000ooooooooooooooooo`00000Tooooo`05o`000?ooooooooooooooool00000
8oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool003oooooo
00CoA4A4omgMgOoooooo0000:?ooool00onHV9So8B4Qonk^kP0Pooooo`05o`000?oooooooooooooo
ool000009_ooool00onHV9So8B4Qonk^kP0Tooooo`04odA4A?oMgMgoooooo`0002Kooooo00Go0000
oiRHV?ooooooV9RHob4Q8@0Tooooo`05oc8b<_nHV9SooooooiRHV?lb<S808oooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool003oooooo00CogMgMoeEEEOoooooo
0000:Oooool00omgMgOoIVIVooooo`0Oooooo`05o`000?ooooooooooooooool000009oooool00omg
MgOoIVIVooooo`0Sooooo`04omgMgOmEEEGoooooo`0002Kooooo00Go0000oeEEEOl0003o410@olc<
c00Tooooo`05olc<c?l0003o0000o`000?o<c<`08oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000000oooool0043ooooo00?oMgMgolc<c?l00000:_ooool00ol0003ooooo
ooooo`0Nooooo`05oa0@4?ooooooooooooooool@4100:?ooool00ol0003oooooooooo`0Sooooo`03
ogMgMoo<c<co000002Kooooo00?oEEEEohN7Qoooool09_ooool01Ol@413o^[Zjoooooonj^[[o410@
02?ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo0010oooo
o`03onk^k_m4A4Co000002Kooooo00Go0000okZj^_ooooooV9RHoa0@400Pooooo`05ogMgMonHV9So
oooooiRHV?mgMgL09?ooool01Ol0003o^[ZjoooooonHV9So410@02Gooooo00?ok^k^odA4A?l00000
9_ooool00ooMgMgo410@oiRHV00Vooooo`05o`000?nj^[[ooooookZj^_l000008oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool0047ooooo00?oMgMgo`000?oo
ool09Oooool01OnHV9So410@o`000?lQ8B7oc<c<023ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0T
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`09_ooool00omgMgOo0000ooooo`0Vooooo`04olc<c?m4
A4Co0000oa0@42Cooooo00GoZJVYoa0@4?l0003o410@ojVYZ@0Qooooo`03oeEEEOmVIVKo000000Co
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`009?ooooooo`0004?o00000_ooool002Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`7o00000Oooool1ooooo`009?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo0Ol00001ooooo`7ooooo000T
ooooo`03o`000?oooooooooo0?oooooo?oooool1o`00007ooooo0Oooool002Cooooo00?o0000oooo
ooooool0ooooooloooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`3oooooocoo
oooo0Ol00001ooooo`7ooooo000Tooooo`;o00007?ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Co
oooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool0
0ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooooooo
ool00002ooooo`05o`000?ooooooooooooooool000002?ooool01ol0003ooooooooooooooooo0000
ooooool000000_ooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00Kooooo00Ko0000
oooooooooooo0000ooooool00002ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool0
1_ooool03?l0003oooooooooool0003oooooo`000?oooooo0000ooooool0003oooooo`0000Wooooo
00Wo0000ooooool0003oooooo`000?oooooo0000ooooool000000_ooool00ol0003oooooooooo`05
ooooo`;o00000_ooool002Cooooo00?o0000ooooooooool00ooooolHok>c/`03o`000?nIVIWoVIVI
00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<
01KoC4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmoO`06ogmoO`03o`000?nIVIWoVIVI
00KoVIVI00?o0000ok>c/onc/k<04onc/k<00ol0003oVIVIoiVIV@03oiVIV@03o`000?moOgooOgmo
00;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000006oda<C003o`000?lc<c?o<c<c00?o<c<c00?o0000
oda<C?m<C4`01?m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Go0000oiVIVOnIVIWoVIVI
o`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04
o`000?moOgooOgmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`07o`000?m<C4co
C4a<oda<C?l0003oIVIVo`000002ogmoO`03o`000?nIVIWo000000?o/k>c00?o0000olc<c?o<c<`0
1_o<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0
003o<c<coc<c<`06oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc
/k?o00002Oo<c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003o`00
0?lc<c?o<c<c00Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo5onc
/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02_mV
IVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl01omo
Ogl00ol0003oVIVIoiVIV@05oiVIV@03o`000?nc/k?o/k>c01Co/k>c00?o0000oiVIVOnIVIT00_nI
VIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01?m<
C4`00ol0003o<c<coc<c<`03oc<c<`03o`000?m<C4coC4a<00?oC4a<00Go0000ofIVI_mVIVKoIVIV
o`000002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0003oc<c<olc<c006olc<c005
o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP04o`000?m<C4co
C4a<o`0000Wo<c<c00Co0000oda<C?m<C4co00000_mVIVH01_l0003oOgmoogmoOol0003oVIVIo`00
00?o/k>c00?o0000olc<c?o<c<`01_o<c<`02?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000
0_mVIVH00ol0003oC4a<o`000009oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003o
VIVIo`000?nc/k?o00002Oo<c<`02ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<
C4co000000?o<c<c1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00ooooolF
ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0;
ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`07
ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc/k<04onc/k<00ol0003oVIVIoiVIV@03
oiVIV@03o`000?moOgooOgmo00;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000006oda<C003o`000?lc
<c?o<c<c00?o<c<c00?o0000oda<C?m<C4`01?m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo
00Go0000oiVIVOnIVIWoVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc
/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`00
0008oc<c<`07o`000?m<C4coC4a<oda<C?l0003oIVIVo`000002ogmoO`03o`000?nIVIWo000000?o
/k>c00?o0000olc<c?o<c<`01_o<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00?o0000
ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000
ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003o/k>cok>c/`02o`00
0007ogmoOol0003oIVIVofIVI_l0003oC4a<o`000003oc<c<`Kooooo0Ol00001ooooo`7ooooo000T
ooooo`03o`000?oooooooooo00?ooooo5?nc/k<2o`0000goVIVI00?o0000ogmoOomoOgl02?moOgl2
o`0000coIVIV0_l0000Goda<C0;o00003OmVIVH00ol0003oOgmoogmoO`07ogmoO`03o`000?nIVIWo
VIVI00GoVIVI0_l0000Fok>c/`03o`000?nIVIWoVIVI00;oVIVI00?o0000ogmoOomoOgl00_moOgl0
0ol0003oIVIVofIVIP02ofIVIP03o`000?m<C4coC4a<00CoC4a<00?o0000oc<c<olc<c<00olc<c<0
0ol0003oC4a<oda<C003oda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01?l0003oVIVIoiVI
VOl00004ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04
o`000?moOgooOgmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`04o`000?m<C4co
C4a<o`0000;oIVIV00Ko0000ogmoOomoOgoo0000oiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Ko
c<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`05o`000?mVIVKo0000oda<C?l000002Olc
<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<co
c<c<00Koc<c<00_o0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`000004oc<c
<`Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo4onc/k<00ol0003o
VIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003o
C4a<oda<C00Foda<C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl01omoOgl00ol0003o
VIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c01Co/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003o
OgmoogmoO`02ogmoO`05o`000?mVIVKoIVIVofIVI_l000001om<C4`00ol0003o<c<coc<c<`02oc<c
<`03o`000?m<C4coC4a<00CoC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`04o`000?nIVIWo
VIVIo`0000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nI
VIWoVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`04
o`000?m<C4coC4a<o`0000;oIVIV00Ko0000ogmoOomoOgoo0000oiVIVOl00003ok>c/`03o`000?o<
c<coc<c<00Koc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`05o`000?mVIVKo0000oda<
C?l000002Olc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03
o`000?o<c<coc<c<00Goc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000
oda<C?l00004oc<c<`Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo
4_nc/k<00ol0003oVIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH0
2omVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl0
2?moOgl00ol0003oVIVIoiVIV@05oiVIV@03o`000?nc/k?o/k>c01Co/k>c00?o0000oiVIVOnIVIT0
0onIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`0
1?m<C4`00ol0003o<c<coc<c<`02oc<c<`03o`000?m<C4coC4a<00CoC4a<00Go0000ofIVI_mVIVKo
IVIVo`000003ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0
003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01Ol0003oC4a<oda<
C?m<C4co000000So<c<c00Co0000oda<C?m<C4co00000_mVIVH01_l0003oOgmoogmoOol0003oVIVI
o`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@05o`000?mo
Ogoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0:o`000?m<C4coC4a<o`000?mV
IVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003o/k>cok>c
/`02o`0000;oOgmo0_l00002oda<C003o`000?lc<c?o<c<c00;o<c<c1_ooool1o`00007ooooo0Ooo
ool002Cooooo00?o0000ooooooooool00ooooolAok>c/`;o00003OnIVIT00ol0003oOgmoogmoO`08
ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0;
ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`0D
ok>c/`03o`000?nIVIWoVIVI00;oVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP02
ofIVIP03o`000?m<C4coC4a<00CoC4a<00?o0000oc<c<olc<c<00olc<c<00ol0003oC4a<oda<C004
oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Co/k>c
00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;o
Ogmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<
o`0000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00009olc<c008o`000?nc
/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00[o0000
oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<
c003o`000?nc/k?o/k>c00;o000000CoOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`02
oc<c<`Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo4?nc/k<00ol0
003oVIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0
003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0
003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c01Go/k>c00?o0000oiVIVOnIVIT00_nIVIT00ol0
003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01?m<C4`00ol0
003o<c<coc<c<`03oc<c<`03o`000?m<C4coC4a<00CoC4a<00Go0000ofIVI_mVIVKoIVIVo`000002
ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c003o`000?nc
/k?o/k>c00;o/k>c00Ko0000oiVIVOnIVIWo0000ogmoOol00002ofIVIP03o`000?m<C4coC4a<00;o
C4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo0000
00;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`02?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo
00000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmo
Ool0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003o/k>cok>c/`02o`000004
ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<00_lc<c<6ooooo`7o00000Oooool1oooo
o`009?ooool00ol0003oooooooooo`03ooooo`oo/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003o
OgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003o
IVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o
/k>cok>c/`0Eok>c/`03o`000?nIVIWoVIVI00;oVIVI00?o0000ogmoOomoOgl00omoOgl01Ol0003o
IVIVofIVI_mVIVKo000000KoC4a<00?o0000oc<c<olc<c<00olc<c<00ol0003oC4a<oda<C004oda<
C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Co/k>c00?o
0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo
00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`00
00;oIVIV00Ko0000ogmoOomoOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00So
0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<0
1ol0003oC4a<o`000?mVIVKo0000ogmoOol000000_nIVIT00ol0003o/k>co`000008olc<c005o`00
0?nc/k?o/k>co`000?nIVIT00_l000001OmVIVKo0000oda<C?m<C4co000000Go<c<c1_ooool1o`00
007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool>ok>c/`;o00003OnIVIT00ol0003o
OgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003o
IVIVofIVIP0:ofIVIP;o00002_moOgl00ol0003oVIVIoiVIV@07oiVIV@03o`000?nc/k?o/k>c01Co
/k>c00?o0000oiVIVOnIVIT00_nIVIT2o`0000CoOgmo00Go0000ofIVI_mVIVKoIVIVo`000007oda<
C003o`000?lc<c?o<c<c00;o<c<c00?o0000oda<C?m<C4`01?m<C4`01Ol0003oIVIVofIVI_mVIVKo
000000?oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc
/k?o/k>cok>c/ol000000onIVIT00ol0003oOgmoo`000002ofIVIP05o`000?m<C4coC4a<oda<C?l0
00002?lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0
003o/k>cok>c/ol00008olc<c009o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000?moOgoo000000;o
IVIV00Co0000oda<C?m<C4co00002?lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000
oiVIVOl0003o/k>co`0000Woc<c<00Co0000ok>c/ol0003oVIVI0ol000001OmVIVKo0000oda<C?m<
C4co000000Go<c<c1_ooool1o`00007ooooo0Oooool002Cooooo0_l00004ooooo`go/k>c00?o0000
oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000
oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000
oiVIVOnIVIT01onIVIT00ol0003o/k>cok>c/`0Dok>c/`03o`000?nIVIWoVIVI00?oVIVI00?o0000
ogmoOomoOgl00omoOgl01Ol0003oIVIVofIVI_mVIVKo000000OoC4a<00?o0000oc<c<olc<c<00_lc
<c<00ol0003oC4a<oda<C004oda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01?l0003oVIVI
oiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000003oiVI
V@03o`000?moOgoo000000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`05o`000?m<C4co
C4a<oda<C?l000000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<
00Wo0000ok>c/onc/k?o/k>co`000?nIVIWo0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l0
0008oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00002Oo<
c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c
00?o<c<c1Oooool2o`0000;ooooo000Tooooo`03o`000?oooooooooo00?ooooo3?nc/k<00ol0003o
VIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003o
C4a<oda<C00Goda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003o
VIVIoiVIV@07oiVIV@03o`000?nc/k?o/k>c01Go/k>c00?o0000oiVIVOnIVIT00_nIVIT00ol0003o
OgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01?m<C4`00ol0003o
<c<coc<c<`02oc<c<`03o`000?m<C4coC4a<00CoC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmo
O`05o`000?nIVIWoVIVIoiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o
/k>cok>c/ol000000onIVIT00ol0003oOgmoo`000002ofIVIP05o`000?m<C4coC4a<oda<C?l00000
2?lc<c<00ol0003oC4a<oda<C002oda<C005o`000?mVIVKo0000ogmoOol000000_nIVIT01?l0003o
/k>cok>c/ol00009olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl00ol0003oIVIVo`00
0002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`;o
00000_nc/k<00ol0003oc<c<olc<c006olc<c003o`000?nc/k?o000000;oVIVI0_l00002ofIVIP03
o`000?m<C4co000000Ko<c<c1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool0
0oooool<ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIV
ofIVIP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02_mVIVH2o`0000[oOgmo
00?o0000oiVIVOnIVIT01onIVIT00ol0003o/k>cok>c/`0Eok>c/`03o`000?nIVIWoVIVI00?oVIVI
00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP02ofIVIP03o`000?m<C4coC4a<00GoC4a<
00?o0000oc<c<olc<c<00_lc<c<00ol0003oC4a<oda<C004oda<C005o`000?mVIVKoIVIVofIVI_l0
00000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0
003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo00000om<
C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH00ol0003oOgmo
o`000002oiVIV@04o`000?nc/k?o/k>co`0000Woc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003o
Ogmoo`0000;oIVIV00?o0000oda<C?l000002Olc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?mo
Ogoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o0000ok>c/ol000000_nIVIT2
o`0000;oIVIV00?o0000oda<C?l000001_lc<c<6ooooo`7o00000Oooool1ooooo`009?ooool00ol0
003oooooooooo`03ooooo`_o/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmo
O`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0:ofIV
IP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02?nIVIT00ol0003o/k>cok>c/`0Eok>c
/`03o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP02ofIV
IP03o`000?m<C4coC4a<00CoC4a<00?o0000oc<c<olc<c<00olc<c<00ol0003oC4a<oda<C004oda<
C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Co/k>c00?o
0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo
00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<
C?l000000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Woc<c<00So0000
ok>c/onc/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV00?o0000oda<C?l000002Olc<c<02_l0003o
C4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<
00?o0000ok>c/ol000000_nIVIT2o`0000;oIVIV00?o0000oda<C?l000001_lc<c<6ooooo`7o0000
0Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`[o/k>c00?o0000oiVIVOnIVIT02onI
VIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<
C4`2o`0000coIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@08oiVIV@03o`000?nc
/k?o/k>c01Go/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mV
IVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01Om<C4`00ol0003o<c<coc<c<`02oc<c<`03o`000?m<
C4coC4a<00CoC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVIVOl0
00001?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnI
VIWo00000_moOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000
oda<C?m<C4coC4a<o`000002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o0000
2Oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@;o00000_mVIVH01?l0003oC4a<oda<C?l00008oc<c
<`04o`000?m<C4coC4a<o`0000;oIVIV0_l000001OnIVIWo0000ok>c/onc/k?o000000Soc<c<00co
0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00007oc<c<`Kooooo0Ol0
0001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo2Onc/k<00ol0003oVIVIoiVIV@0;
oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00F
oda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@08
oiVIV@03o`000?nc/k?o/k>c01Go/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`02
ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01Om<C4`00ol0003o<c<coc<c<`02
oc<c<`03o`000?m<C4coC4a<00CoC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`05o`000?nI
VIWoVIVIoiVIVOl000001?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c
00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c
00Ko<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo0000
0_nc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol0
00000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmo
Ool0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01ol0003o/k>cok>c/ol0003oVIVI
o`000?moOgl00_l00002oda<C003o`000?lc<c?o<c<c00Go<c<c1_ooool1o`00007ooooo0Oooool0
02Cooooo00?o0000ooooooooool00oooool8ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmo
OomoOgl02?moOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIV
I_mVIVH02_mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00WoVIVI00?o0000ok>c
/onc/k<05Onc/k<00ol0003oVIVIoiVIV@03oiVIV@03o`000?moOgooOgmo00;oOgmo00?o0000ofIV
I_mVIVH00_mVIVH00ol0003oC4a<oda<C005oda<C003o`000?lc<c?o<c<c00;o<c<c00?o0000oda<
C?m<C4`01?m<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Go0000oiVIVOnIVIWoVIVIo`00
0004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVI
VOl00002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01ol0003o
C4a<oda<C?m<C4co0000ofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00002ok>c/`03o`000?o<
c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`00
0?m<C4coC4a<o`0000Oo<c<c00_o0000oda<C?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVI
o`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Oo0000ok>c/onc/k?o0000oiVIVOl0003oOgmo
00;o00000_m<C4`00ol0003o<c<coc<c<`05oc<c<`Kooooo0Ol00001ooooo`7ooooo000Tooooo`03
o`000?oooooooooo00?ooooo1onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00So
Ogmo00?o0000ofIVI_mVIVH02omVIVH2o`0001OoC4a<0_l0000<ofIVIP03o`000?moOgooOgmo00Wo
Ogmo00?o0000oiVIVOnIVIT02OnIVIT00ol0003o/k>cok>c/`0Eok>c/`03o`000?nIVIWoVIVI00?o
VIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP02ofIVIP03o`000?m<C4coC4a<00Go
C4a<00?o0000oc<c<olc<c<00_lc<c<00ol0003oC4a<oda<C004oda<C005o`000?mVIVKoIVIVofIV
I_l000000omoOgl01Ol0003oVIVIoiVIVOnIVIWo000000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`0
0ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo0000
0om<C4`00ol0003o<c<coc<c<`07oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol0
00000_nIVIT01?l0003o/k>cok>c/ol00008olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000
ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo
0000ogmoOol00002oiVIV@03o`000?nc/k?o000000Soc<c<00Oo0000ok>c/onc/k?o0000oiVIVOl0
003oOgmo00;o00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`Kooooo0Ol00001ooooo`7ooooo000K
ooooo`;o000000?o410@ooooooooool01?ooool00ol0003oooooooooo`03ooooo`Go/k>c0_l0000<
oiVIV@;o00002_moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000
ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`;o00002onIVIT00ol0003o/k>cok>c/`0E
ok>c/`03o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP02
ofIVIP03o`000?m<C4coC4a<00KoC4a<00Go0000oc<c<olc<c?o<c<co`000007oda<C005o`000?mV
IVKoIVIVofIVI_l000000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Co/k>c00?o0000olc<c?o<
c<`01Oo<c<`2o`0000?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`04o`000?mVIVKoIVIV
o`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<00ol0003oC4a<oda<C002o`000005ofIVI_l0003o
OgmoogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00008olc<c004o`000?nc/k?o/k>co`0000;o
VIVI00?o0000ogmoOol000000_mVIVH00ol0003oC4a<o`000009oc<c<`0:o`000?m<C4coC4a<o`00
0?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01ol0003o/k>c
ok>c/ol0003oVIVIo`000?moOgl00_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00?o0000oooo
ooooool00oooool1o`00007ooooo0Oooool001cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`03ooooo`Go/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`09ogmoO`03
o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03
o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Dok>c/`03
o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP02ofIVIP03
o`000?m<C4coC4a<00KoC4a<00Go0000oc<c<olc<c?o<c<co`000006oda<C003o`000?mVIVKoIVIV
00;oIVIV00Co0000ogmoOomoOgoo00000onIVIT00ol0003o/k>cok>c/`02ok>c/`03o`000?o<c<co
c<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Co
0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;o
IVIV00Co0000ogmoOomoOgoo00000_nIVIT01?l0003o/k>cok>c/ol00008olc<c004o`000?nc/k?o
/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH00ol0003oC4a<o`000009oc<c<`0:o`000?m<
C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`0
0ol0003o/k>cok>c/`02o`0000;oOgmo0_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00?o0000
ooooooooool00oooool1o`00007ooooo0Oooool0017ooooo1_l00002ooooo`Go00001_ooool3o`00
00?ooooo1?nc/k<00ol0003oVIVIoiVIV@0:oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIV
I_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmo
OomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Co/k>c00?o0000oiVI
VOnIVIT01?nIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<
C?m<C4`01_m<C4`01Ol0003o<c<coc<c<olc<c?o000000OoC4a<00Go0000ofIVI_mVIVKoIVIVo`00
0002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0003oc<c<olc<c005olc<c003o`00
0?nc/k?o/k>c00;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`00
00?oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP04o`000?moOgoo
Ogmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@08
o`000?moOgooOgmoo`000?mVIVKo0000oda<C?l00009oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo
00000_moOgl2o`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02_l0003o/k>cok>c/ol0003oVIVI
o`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000ooooooooool0
0_ooool3o`0000;ooooo000Iooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool0
0oooool2ok>c/`;o00003?nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV
00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo
00?o0000oiVIVOnIVIT02_nIVIT00ol0003o/k>cok>c/`0Dok>c/`03o`000?nIVIWoVIVI00CoVIVI
00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<00KoC4a<
00Co0000oc<c<olc<c?o00001om<C4`01?l0003oIVIVofIVI_mVIVH2o`0000;oOgmo00Go0000oiVI
VOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<0
1?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<0
1_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP06o`000?moOgooOgmoo`000?nIVIWo00000onc/k<0
0ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Go0000ogmoOol0003oIVIV
o`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmo
o`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c00<o`000?nc/k?o/k>co`000?nIVIWo
0000ogmoOol0003oIVIVo`000?m<C4co00002?lc<c<00ol0003oooooooooo`04ooooo`7o00000Ooo
ool1ooooo`006Oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo00?ooooo0_nc
/k<00ol0003oVIVIoiVIV@0:oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omV
IVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV0_l0000:ogmoO`03o`000?nI
VIWoVIVI00[oVIVI00?o0000ok>c/onc/k<05Onc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?mo
OgooOgmo00;oOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C006oda<C004o`000?lc
<c?o<c<co`0000OoC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`05o`000?nIVIWoVIVIoiVI
VOl000001?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVI
VOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00004oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co
0000oda<C?m<C4co00000_mVIVH01_l0003oOgmoogmoOol0003oVIVIo`0000?o/k>c00?o0000olc<
c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<
C4`00ol0003o<c<coc<c<`07oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVI
o`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003o/k>co`000002oiVIV@07o`000?moOgoo
0000ofIVI_l0003oC4a<o`000008oc<c<`03o`000?oooooooooo00Cooooo0Ol00001ooooo`7ooooo
000Jooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool00oooool00onc/k?o0000oiVI
V@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<
C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVI
V@0:oiVIV@03o`000?nc/k?o/k>c01Go/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmo
O`02ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<C4`01_m<C4`01?l0003o<c<coc<c
<ol00007oda<C005o`000?mVIVKoIVIVofIVI_l000001?moOgl01?l0003oVIVIoiVIVOl00005ok>c
/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00onc/k<01?l0003oVIVIoiVIVOl00002
ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<
C?l00002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01Ol0
003o/k>cok>c/onc/k?o000000;oVIVI0_l000001OmVIVKo0000oda<C?m<C4co000000Wo<c<c00Co
0000oda<C?m<C4co00000_mVIVH2o`000005oiVIVOl0003o/k>cok>c/ol000002?o<c<`02?l0003o
/k>cok>c/ol0003oVIVIo`000?moOgoo00000_mVIVH2o`0000So<c<c00?o0000oda<C?ooool01Ooo
ool1o`00007ooooo0Oooool001[ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`03
ooooo`03o`000?nIVIWoVIVI00[oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0;
ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08
ogmoO`;o00003?nIVIT00ol0003o/k>cok>c/`0Eok>c/`;o00001OnIVIT00ol0003oOgmoogmoO`03
ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01_m<C4`01?l0003o<c<coc<c<ol0
0007oda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgooOgmoo`000002oiVIV@;o0000
1?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo
00000_moOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<
C?m<C4coC4a<o`000002ofIVIP06o`000?moOgooOgmoo`000?nIVIWo00000onc/k<00ol0003oc<c<
olc<c006olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<
C003o`000?lc<c?o<c<c00Oo<c<c00?o0000oda<C?l000000_mVIVH01Ol0003oOgmoo`000?nIVIWo
000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo
0000ofIVI_l0003oC4a<o`0000So<c<c00?o0000oda<C?ooool01Oooool1o`00007ooooo0Oooool0
01_ooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`03ooooo`goVIVI00?o0000ogmo
OomoOgl02OmoOgl00ol0003oIVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIV
I_mVIVH03?mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c
/onc/k<05Onc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00?oOgmo00?o0000ofIV
I_mVIVH00_mVIVH00ol0003oC4a<oda<C007oda<C003o`000?lc<c?o000000OoC4a<00?o0000ofIV
I_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000;oVIVI00?o0000ok>c/onc/k<00onc/k<0
0ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Co0000oiVIVOnIVIWo00000_mo
Ogl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4co
C4a<o`000002ofIVIP06o`000?moOgooOgmoo`000?nIVIWo00000onc/k<00ol0003oc<c<olc<c006
olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`00
0?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nIVIWo0000
00;o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/ol0003oVIVI00;o00000_mVIVH0
0ol0003oC4a<o`000008oc<c<`03o`000?m<C4cooooo00Gooooo0Ol00001ooooo`7ooooo000Toooo
o`03o`000?oooooooooo00?ooooo3?nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV
00[oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?moOgooOgmo
00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Eok>c/`03o`000?nIVIWoVIVI
00GoVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP02ofIVIP03o`000?m<C4coC4a<
00WoC4a<00?o0000oda<C?m<C4`01_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Go0000
oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc
/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o
<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH00ol0003oOgmoo`000002oiVI
V@04o`000?nc/k?o/k>co`0000Woc<c<00Co0000ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`00
0?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP05
o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>c
o`000?nIVIT00_l00002ofIVIP03o`000?m<C4co000000So<c<c00?o0000oda<C?l000001Oooool1
o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool;oiVIV@03o`000?moOgooOgmo
00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV
00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c
01Ko/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`03ogmoO`05o`000?mVIVKoIVIV
ofIVI_l000005?m<C4`01Ol0003oIVIVofIVI_mVIVKo000000CoOgmo00Co0000oiVIVOnIVIWo0000
1Onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Co0000oiVIVOnIVIWo
00000_moOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00?o0000oda<
C?m<C4`00_m<C4`00ol0003oIVIVo`000002ogmoO`03o`000?nIVIWo000000?o/k>c00?o0000olc<
c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000
oda<C?m<C4co00001olc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI
00?o0000ok>c/ol000002?o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0
003oC4a<o`0000So<c<c00Co0000oda<C?m<C4co00001Oooool1o`00007ooooo0Oooool002Cooooo
00?o0000ooooooooool00oooool:oiVIV@03o`000?moOgooOgmo00SoOgmo0_l0000<ofIVIP;o0000
5om<C4`2o`0000goIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`00
0?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`03ogmoO`03o`00
0?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`04_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000?o
Ogmo00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c
/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo00000om<
C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH00ol0003oOgmo
o`000002oiVIV@04o`000?nc/k?o/k>co`0000Woc<c<00Co0000ok>c/onc/k?o00000_nIVIT01Ol0
003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l0
0002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c00<o`00
0?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co00002?lc<c<01?l0003oC4a<
oda<C?l00005ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`WoVIVI
00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<
00?o0000ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI
00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00?oOgmo
00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00Boda<C005o`000?mVIVKoIVIVofIVI_l0
00000omoOgl01Ol0003oVIVIoiVIVOnIVIWo000000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0
003o/k>cok>c/`02ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01?l0003oIVIVofIVI_l0
0003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP03o`00
0?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`01?l0003o/k>cok>c/ol00002oiVI
V@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4co
C4a<o`0000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<
00?o0000ok>c/onc/k<00_l00002ogmoO`05o`000?mVIVKo0000oda<C?l000002?lc<c<01?l0003o
C4a<oda<C?l00005ooooo`7o00000Oooool1ooooo`009?ooool2o`0000Cooooo2?nIVIT00ol0003o
OgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003o
IVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o
/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00GoVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003o
IVIVofIVIP02ofIVIP03o`000?m<C4coC4a<01;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000004ogmo
O`04o`000?nIVIWoVIVIo`0000Go/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`02
ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00003oda<C003o`00
0?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP03o`000?moOgoo000000;o
VIVI00Co0000ok>c/onc/k?o00002Oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@05o`000?moOgoo
0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`03o`000?m<C4co000000;oIVIV00?o
0000ogmoOomoOgl00_l00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00[o0000ok>c/onc/k?o0000
oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`03o`000?m<C4co
000000Gooooo0_l00002ooooo`009?ooool00ol0003oooooooooo`03ooooo`OoVIVI00?o0000ogmo
OomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIV
I_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c
/onc/k<05_nc/k<00ol0003oVIVIoiVIV@05oiVIV@03o`000?moOgooOgmo00?oOgmo00?o0000ofIV
I_mVIVH00omVIVH00ol0003oC4a<oda<C00Aoda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmo
OomoOgooOgmoo`000003oiVIV@03o`000?nc/k?o/k>c00;o/k>c00?o0000olc<c?o<c<`01Oo<c<`0
0ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Go0000ofIVI_mVIVKoIVIV
o`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP03
o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`2o`0000;o/k>c00?o0000oiVI
VOl000000_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00?o0000oda<
C?l000000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`0
3?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000So<c<c00Co0000
oda<C?m<C4co00001_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool6
oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00G
oda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;
oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT01OnIVIT00ol0003oOgmoogmoO`03
ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`04_m<C4`00ol0003oIVIVofIVIP02
ofIVIP05o`000?moOgooOgmoogmoOol000000onIVIT00ol0003o/k>cok>c/`02ok>c/`03o`000?o<
c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00onc/k<01?l0003oVIVIoiVIVOl00002ogmoO`05o`00
0?mVIVKoIVIVofIVI_l000000om<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;o
C4a<00Ko0000ofIVI_mVIVKo0000ogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Co
0000ok>c/onc/k?o00000_nIVIT01_l0003oOgmoogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c
<olc<c<01olc<c<01Ol0003oC4a<o`000?mVIVKo000000;oOgmo00?o0000oiVIVOl000000_nc/k<0
0ol0003oc<c<olc<c006olc<c003o`000?nc/k?o000000;oVIVI00Co0000ogmoOol0003o00000_m<
C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000Kooooo0Ol00001ooooo`7ooooo
000Tooooo`03o`000?oooooooooo00?ooooo1OnIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mV
IVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?mo
OgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nI
VIWoVIVI00GoVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIVIP02ofIVIP03o`000?m<
C4coC4a<01;oC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000?oVIVI
00?o0000ok>c/onc/k<00_nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c
00Co0000oiVIVOnIVIWo00000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000?oC4a<00?o0000oc<c
<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Ko0000ogmoOomoOgoo0000oiVI
VOl00003ok>c/`03o`000?o<c<coc<c<00Goc<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo0000
00;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`03o`000?m<C4co0000
00;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00co0000
ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00009oc<c<`05o`000?m<C4co
0000ofIVI_l000001Oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool4
oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00G
oda<C003o`000?mVIVKoIVIV00[oIVIV0_l0000:ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000
ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@05oiVIV@03o`000?moOgooOgmo00?oOgmo00?o0000
ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00Boda<C005o`000?mVIVKoIVIVofIVI_l000000omo
Ogl01Ol0003oVIVIoiVIVOnIVIWo000000Go/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>c
ok>c/`03ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0
003o<c<coc<c<`05oc<c<`04o`000?m<C4coC4a<oda<C0;o000000GoIVIVo`000?moOgooOgmoo`00
0002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo0000
00;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<
o`0000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00co
0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00009oc<c<`;o000000?o
IVIVo`000?ooool01Oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool3
oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00G
oda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;
oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT01_nIVIT00ol0003oOgmoogmoO`03
ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<C4`04_m<C4`01Ol0003oIVIVofIVI_mV
IVKo000000;oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<
c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00onc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`00
0?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01Olc<c<01Ol0003oC4a<oda<C?m<C4co0000
00;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01?l0003o/k>cok>c/ol00008olc<c007o`000?nc
/k?o/k>cok>c/ol0003oVIVIo`000002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc
<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<0
0ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>co`000?nIVIT00_l00002ofIVIP03o`000?m<
C4co000000Wo<c<c0_l000000omVIVKo0000ooooo`05ooooo`7o00000Oooool1ooooo`009?ooool0
0ol0003oooooooooo`03ooooo`;oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;
ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08
ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@06
oiVIV@03o`000?moOgooOgmo00?oOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00B
oda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01Ol0003oVIVIoiVIVOnIVIWo000000Go/k>c
00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`04o`000?nIVIWoVIVIo`0000;o
Ogmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<
o`0000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01?l0003o/k>cok>c/ol00009olc<c006o`00
0?nc/k?o/k>co`000?nIVIWo00000_moOgl01?l0003oIVIVofIVI_l00002oda<C003o`000?lc<c?o
<c<c00Ko<c<c00?o0000oda<C?l000000_mVIVH00ol0003oOgmoo`000002oiVIV@03o`000?nc/k?o
000000Soc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00009
oc<c<`05o`000?m<C4co0000o`000?moOgl01_ooool1o`00007ooooo0Oooool002Cooooo00?o0000
ooooooooool00oooool00onIVIWo0000ogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000
oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0:ofIVIP;o00002_moOgl00ol0003oVIVIoiVIV@0;
oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT01_nIVIT00ol0003oOgmoogmoO`03
ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<C4`04_m<C4`00ol0003oIVIVofIVIP02
ofIVIP05o`000?moOgooOgmoogmoOol000000onIVIT00ol0003o/k>cok>c/`02ok>c/`03o`000?o<
c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo
00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`07oc<c<`04o`000?m<C4coC4a<o`00
00;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01?l0003o/k>cok>c/ol00009olc<c006o`000?nc
/k?o/k>co`000?nIVIWo00000_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko
<c<c00Co0000oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000
olc<c?o<c<`01_o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<
o`0000So<c<c00?o0000oda<C?m<C4`00_l000000omoOgooooooooooo`04ooooo`7o00000Oooool1
ooooo`009?ooool00ol0003oooooooooo`03ooooo`03o`000?moOgooOgmo00SoOgmo00?o0000ofIV
I_mVIVH02omVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00[oIVIV00?o0000ogmo
OomoOgl02OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVI
VOnIVIT01onIVIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<
C?m<C4`04om<C4`00ol0003oIVIVofIVIP02ofIVIP05o`000?moOgooOgmoogmoOol000000onIVIT0
0ol0003o/k>cok>c/`02ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<0
1?l0003oVIVIoiVIVOl00003ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<0
1_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01?l0
003o/k>cok>c/ol00009olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl00ol0003oIVIV
o`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH2o`0000;o
VIVI00Co0000ok>c/onc/k?o00002?o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000
ofIVI_l0003oC4a<o`0000So<c<c00?o0000oda<C?m<C4`00_l000000omoOgooooooooooo`04oooo
o`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`[oOgmo00?o0000ofIVI_mV
IVH02omVIVH00ol0003oC4a<oda<C00Foda<C0;o00003?mVIVH00ol0003oOgmoogmoO`09ogmoO`03
o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@07oiVIV@03
o`000?moOgooOgmo00?oOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00Boda<C003
o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgooOgmoo`000003oiVIV@03o`000?nc/k?o/k>c
00;o/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`05o`000?nIVIWoVIVI
oiVIVOl000000omoOgl01?l0003oIVIVofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go
0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Co0000ok>c/onc
/k?o00002Oo<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00?o0000ofIVI_l000000_m<
C4`00ol0003o<c<coc<c<`07oc<c<`03o`000?m<C4co000000;oIVIV00Go0000ogmoOol0003oVIVI
o`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmo
o`000?mVIVKo0000oda<C?l00009oc<c<`07o`000?m<C4co0000ofIVI_l0003oOgmoo`000005oooo
o`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`WoOgmo00?o0000ofIVI_mV
IVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomo
Ogl02OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01So/k>c00?o0000oiVIVOnI
VIT01_nIVIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<
C4`04_m<C4`00ol0003oIVIVofIVIP02ofIVIP05o`000?moOgooOgmoogmoOol000000onIVIT00ol0
003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00onc/k<01?l0
003oVIVIoiVIVOl00003ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc
<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Go0000ogmoOomoOgoo0000oiVIV@02o`0000;o
/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo0000
00;oIVIV00?o0000oda<C?l000002_lc<c<00ol0003oC4a<o`000002ofIVIP05o`000?moOgoo0000
oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000
ogmoOol0003oIVIVo`000?m<C4co00002?lc<c<02?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo
00001Oooool1o`00007ooooo0Oooool002Cooooo0_l00004ooooo`SoOgmo00?o0000ofIVI_mVIVH0
3?mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00[oIVIV00?o0000ogmoOomoOgl0
2OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01So/k>c00?o0000oiVIVOnIVIT0
1onIVIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<C4`0
4_m<C4`00ol0003oIVIVofIVIP02ofIVIP04o`000?moOgooOgmoo`0000CoVIVI00?o0000ok>c/onc
/k<00onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Co0000oiVIVOnI
VIWo00000omoOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Oo0000
oda<C?m<C4coC4a<o`000?mVIVKo000000?oOgmo00?o0000oiVIVOl000000onc/k<00ol0003oc<c<
olc<c006olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH00ol0003o
C4a<o`00000:oc<c<`05o`000?m<C4co0000ofIVI_l000000_moOgl00ol0003oVIVIo`000002ok>c
/`03o`000?o<c<coc<c<00Koc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo
0000oda<C?l00008oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol00004ooooo`;o0000
0_ooool002Cooooo00?o0000ooooooooool00oooool7ogmoO`03o`000?mVIVKoIVIV00_oIVIV0_l0
000Goda<C0;o00003?mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o
0000ok>c/onc/k<06?nc/k<00ol0003oVIVIoiVIV@07oiVIV@03o`000?moOgooOgmo00?oOgmo00?o
0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00Boda<C003o`000?mVIVKoIVIV00;oIVIV00Go
0000ogmoOomoOgooOgmoo`000003oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`0
1?o<c<`00ol0003o/k>cok>c/`03ok>c/`04o`000?nIVIWoVIVIo`0000?oOgmo00Co0000ofIVI_mV
IVKo00001?m<C4`00ol0003o<c<coc<c<`05oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH0
1_l0003oOgmoogmoOol0003oVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`02Ol0003o/k>c
ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000Wo<c<c00?o
0000oda<C?l000000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`0
1_o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000So<c<c
00So0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000Kooooo0Ol00001ooooo`7ooooo000Toooo
o`03o`000?oooooooooo00?ooooo1_moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<
01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`;o00003OnIVIT00ol0
003o/k>cok>c/`0Hok>c/`03o`000?nIVIWoVIVI00KoVIVI0_l00005ogmoO`03o`000?mVIVKoIVIV
00?oIVIV00?o0000oda<C?m<C4`04om<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00?o0000
oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000
ok>c/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo0000
1?m<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH00ol0003o
Ogmoo`000002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01?l0003o/k>cok>c/ol00002
oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<01_l0003oC4a<oda<
C?l0003oIVIVo`0000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c00<
o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co00002?lc<c<02?l0003o
C4a<oda<C?l0003oIVIVo`000?moOgoo00001_ooool1o`00007ooooo0Oooool002Cooooo00?o0000
ooooooooool00oooool5ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`0
0ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT03?nIVIT0
0ol0003o/k>cok>c/`0Hok>c/`03o`000?nIVIWoVIVI00OoVIVI00?o0000ogmoOomoOgl01?moOgl0
0ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<01?oC4a<00Go0000ofIVI_mVIVKoIVIVo`00
0003ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001_nc/k<00ol0003oc<c<olc<c004olc<c003o`00
0?nc/k?o/k>c00;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`00
00CoC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o0000
ogmoOol000000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Co0000ok>c/onc/k?o0000
0_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Ko0000oda<C?m<
C4co0000ofIVI_l00002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`0
3?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000So<c<c00So0000
oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`00
0?oooooooooo00?ooooo1?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<
00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00coVIVI
00?o0000ok>c/onc/k<06?nc/k<00ol0003oVIVIoiVIV@07oiVIV@03o`000?moOgooOgmo00CoOgmo
00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00Coda<C005o`000?mVIVKoIVIVofIVI_l0
00000omoOgl00ol0003oVIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<
c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Go0000ofIV
I_mVIVKoIVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`00
0002ofIVIP03o`000?moOgoo000000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c004o`00
0?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol000000omVIVH01?l0003oC4a<oda<C?l00008oc<c
<`05o`000?m<C4co0000ofIVI_l000000_moOgl00ol0003oVIVIo`000003ok>c/`03o`000?o<c<co
c<c<00Goc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00009
oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000Gooooo0Ol00001ooooo`7o
oooo000Tooooo`03o`000?oooooooooo00?ooooo0omoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`00
0?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`00
0?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<2o`0000WoVIVI00?o0000ogmoOomoOgl0
1?moOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH0
0_mVIVH01Ol0003oOgmoogmoOomoOgoo000000?oVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003o
c<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmo
O`03o`000?mVIVKoIVIV00;o00000om<C4`00ol0003o<c<coc<c<`05oc<c<`05o`000?m<C4coC4a<
oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@05o`000?nc/k?o/k>cok>c/ol00000
2?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<
C4co00002?lc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00?o0000oiVIVOl000000_nc
/k<00ol0003oc<c<olc<c006olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIV
o`000?m<C4co00002Olc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000005oooo
o`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`;oOgmo00?o0000ofIVI_mV
IVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV0_l0000:ogmoO`03
o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@08oiVIV@03
o`000?moOgooOgmo00GoOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00Coda<C003
o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgooOgmoo`000003oiVIV@03o`000?nc/k?o/k>c
00?o/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`05o`000?nIVIWoVIVI
oiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00004oda<C003o`000?lc<c?o<c<c00Go<c<c00Go
0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Go0000ok>c/onc
/k?o/k>co`000008olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH0
1?l0003oC4a<oda<C?l00008oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVI
V@04o`000?nc/k?o/k>co`0000Soc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mV
IVKo0000oda<C?l00009oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000Go
oooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo00?oOgmoo`000?mVIVH0
3?mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl0
2OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c0_l0000:oiVIV@03o`00
0?moOgooOgmo00GoOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00Coda<C003o`00
0?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgooOgmoo`000003oiVIV@03o`000?nc/k?o/k>c00?o
/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`05o`000?nIVIWoVIVIoiVI
VOl000000_moOgl01?l0003oIVIVofIVI_l00004oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000
oda<C?m<C4co00000_mVIVH01?l0003oOgmoogmoOol00003oiVIV@04o`000?nc/k?o/k>co`0000So
c<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<
o`0000So<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`03o`000?nIVIWo000000;o/k>c
00?o0000olc<c?o<c<`01_o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0
003oC4a<o`0000Wo<c<c00?o0000oda<C?m<C4`00_l000001?moOgoo0000oiVIVOl00006ooooo`7o
00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`03o`000?mVIVKoIVIV00_oIVIV
00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo
0_l0000=oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02OnIVIT00ol0003oOgmo
ogmoO`05ogmoO`03o`000?mVIVKoIVIV00CoIVIV00?o0000oda<C?m<C4`04_m<C4`00ol0003oIVIV
ofIVIP02ofIVIP05o`000?moOgooOgmoogmoOol000001?nIVIT00ol0003o/k>cok>c/`03ok>c/`03
o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00onc/k<01?l0003oVIVIoiVIVOl00002ogmo
O`05o`000?mVIVKoIVIVofIVI_l000000om<C4`2o`0000Oo<c<c00Go0000oda<C?m<C4coC4a<o`00
0002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c004
o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00008
oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl00ol0003oVIVIo`000002ok>c/`03o`00
0?o<c<coc<c<00Koc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<
C?l00008oc<c<`;o000000SoC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000Kooooo0Ol00001
ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo3OmVIVH00ol0003oC4a<oda<C00Foda<
C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVI
V@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`05ogmo
O`03o`000?mVIVKoIVIV00CoIVIV00?o0000oda<C?m<C4`04_m<C4`00ol0003oIVIVofIVIP02ofIV
IP05o`000?moOgooOgmoogmoOol000000onIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<co
c<c<00Coc<c<00?o0000ok>c/onc/k<00onc/k<01?l0003oVIVIoiVIVOl00002ogmoO`05o`000?mV
IVKoIVIVofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l0
00000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`0
1?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co0000
2?lc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0
003oc<c<olc<c006olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<
C4co00002?lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00006ooooo`7o
00000Oooool1ooooo`009?ooool2o`0000Cooooo3?mVIVH00ol0003oC4a<oda<C00Foda<C003o`00
0?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`00
0?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02OnIVIT00ol0003oOgmoogmoO`05ogmoO`03o`00
0?mVIVKoIVIV00CoIVIV00?o0000oda<C?m<C4`04_m<C4`00ol0003oIVIVofIVIP02ofIVIP03o`00
0?moOgooOgmo00;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000006ok>c/`03o`000?o<c<coc<c<00?o
c<c<00?o0000ok>c/onc/k<00onc/k<01?l0003oVIVIoiVIVOl00002ogmoO`03o`000?mVIVKoIVIV
00;oIVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mV
IVH01?l0003oOgmoogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Go0000ok>c/onc
/k?o/k>co`000002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<0
0ol0003oC4a<o`000002ofIVIP06o`000?moOgooOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<
olc<c006olc<c003o`000?nc/k?o000000;oVIVI00Co0000ogmoOol0003o00000_m<C4`00ol0003o
<c<coc<c<`06oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000Gooooo
0_l00002ooooo`009?ooool00ol0003oooooooooo`03ooooo`coIVIV00?o0000oda<C?m<C4`05_m<
C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onI
VIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00[oVIVI00?o0000ogmoOomoOgl01Omo
Ogl00ol0003oIVIVofIVIP04ofIVIP03o`000?m<C4coC4a<01;oC4a<00?o0000ofIVI_mVIVH00_mV
IVH01Ol0003oOgmoogmoOomoOgoo000000?oVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<
olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01Ol0003o
IVIVofIVI_mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co
000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<
00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`00
00So<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`03o`000?nIVIWo000000;o/k>c00?o
0000olc<c?o<c<`01_o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003o
C4a<o`0000So<c<c00_o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/`06
ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`[oIVIV0_l0000Goda<
C0;o00003OmVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c
/onc/k<05onc/k<00ol0003oVIVIoiVIV@0:oiVIV@03o`000?moOgooOgmo00CoOgmo0_l00006ofIV
IP03o`000?m<C4coC4a<01;oC4a<00?o0000ofIVI_mVIVH00_mVIVH00ol0003oOgmoogmoO`02ogmo
O`05o`000?nIVIWoVIVIoiVIVOl000001_nc/k<00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o
/k>c00?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`03o`000?mVIVKoIVIV00;o00000om<
C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmo
ogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Go0000ok>c/onc/k?o/k>co`000002
oiVIV@04o`000?moOgoo0000ofIVIP;o00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`06o`000?m<
C4coC4a<o`000?mVIVKo00000_moOgl01?l0003oVIVIo`000?nc/k<2o`0000Soc<c<00co0000ok>c
/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00008oc<c<`0<o`000?m<C4coC4a<
o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00001Oooool1o`00007ooooo0Oooool002Co
oooo00?o0000ooooooooool00oooool9ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mV
IVH03?mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc
/k<05onc/k<00ol0003oVIVIoiVIV@0:oiVIV@03o`000?moOgooOgmo00GoOgmo00?o0000ofIVI_mV
IVH01?mVIVH00ol0003oC4a<oda<C00Coda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomo
OgooOgmoo`000004oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0
003o/k>cok>c/`03ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01?l0003oIVIVofIVI_l0
0004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIV
I_l00002ogmoO`04o`000?nIVIWoVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o
/k>cok>c/onc/k?o000000;oVIVI00Go0000ogmoOol0003oIVIVo`000003oda<C003o`000?lc<c?o
<c<c00Ko<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`;o00000_nc/k<00ol0003oc<c<
olc<c007olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co0000
2?lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Gooooo
0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo2?mVIVH00ol0003oC4a<oda<
C00Goda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVI
V@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmo
O`05ogmoO`03o`000?mVIVKoIVIV00GoIVIV00?o0000oda<C?m<C4`04om<C4`01Ol0003oIVIVofIV
I_mVIVKo000000CoOgmo00Go0000oiVIVOnIVIWoVIVIo`000006ok>c/`03o`000?o<c<coc<c<00?o
c<c<00?o0000ok>c/onc/k<00onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Co0000ofIV
I_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mV
IVH01?l0003oOgmoogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Go0000ok>c/onc
/k?o/k>co`000002oiVIV@05o`000?moOgoo0000ofIVI_l000000om<C4`00ol0003o<c<coc<c<`06
oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl01Ol0003oVIVIo`000?nc/k?o000000Wo
c<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00009oc<c<`0;
o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol000001_ooool1o`00007ooooo
0Oooool002Cooooo00?o0000ooooooooool00oooool7ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o
0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o
0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0:oiVIV@03o`000?moOgooOgmo00GoOgmo00?o
0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<C00Coda<C003o`000?mVIVKoIVIV00;oIVIV00Go
0000ogmoOomoOgooOgmoo`000004oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`0
1?o<c<`00ol0003o/k>cok>c/`03ok>c/`04o`000?nIVIWoVIVIo`0000?oOgmo00Co0000ofIVI_mV
IVKo00001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Go0000ofIV
I_mVIVKo0000ogmoO`02o`000003oiVIVOl0003o/k>c00;o/k>c00?o0000olc<c?o<c<`01_o<c<`0
1ol0003o/k>cok>c/onc/k?o0000oiVIVOl000000_moOgl00ol0003oIVIVo`000002oda<C003o`00
0?lc<c?o<c<c00Oo<c<c00So0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000;oVIVI00?o0000
ok>c/ol000002Oo<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<
o`0000Wo<c<c00_o0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`000006oooo
o`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`KoIVIV00?o0000oda<C?m<
C4`05om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnI
VIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`;o00003?nIVIT00ol0003oOgmoogmoO`05ogmoO`03
o`000?mVIVKoIVIV00KoIVIV00?o0000oda<C?m<C4`04om<C4`01Ol0003oIVIVofIVI_mVIVKo0000
00CoOgmo00Go0000oiVIVOnIVIWoVIVIo`000005ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000
ok>c/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Co0000ofIVI_mVIVKo0000
1?m<C4`00ol0003o<c<coc<c<`05oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003o
OgmoogmoOol00002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01ol0003o/k>cok>c/onc
/k?o0000oiVIVOl000000_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c
00So0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000;oVIVI00?o0000ok>c/ol000002Oo<c<`0
3?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000Wo<c<c00_o0000
oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`000006ooooo`7o00000Oooool1oooo
o`009?ooool00ol0003oooooooooo`03ooooo`GoIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003o
IVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o
/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl01_moOgl00ol0003o
IVIVofIVIP05ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003o
OgmoogmoOomoOgoo000000CoVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c004olc<
c003o`000?nc/k?o/k>c00?o/k>c00Co0000oiVIVOnIVIWo00000omoOgl01?l0003oIVIVofIVI_l0
0004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01_l0003oIVIVofIV
I_l0003oOgmoo`0000;oVIVI00?o0000ok>c/onc/k<00_nc/k<00ol0003oc<c<olc<c006olc<c006
o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl00ol0003oIVIVo`000003oda<C003o`000?lc<c?o
<c<c00Ko<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`03o`000?nIVIWo000000;o/k>c
00?o0000olc<c?o<c<`01_o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0
003oC4a<o`0000Wo<c<c00?o0000oda<C?m<C4`00_l000001omoOgoo0000oiVIVOl0003o/k>co`00
0?o<c<`01_ooool1o`00007ooooo0Oooool001Wooooo1Ol00006ooooo`03o`000?oooooooooo00?o
oooo1?mVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00[oIVIV0_l0000:ogmoO`03
o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03
o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<C00Coda<C003
o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgooOgmoo`000004oiVIV@03o`000?nc/k?o/k>c
00Co/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`03ok>c/`05o`000?nIVIWoVIVI
oiVIVOl000000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc
<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01Ol0003o
/k>cok>c/onc/k?o000000Soc<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo00?o
0000ofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo
0000ogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00co0000ok>c/onc/k?o0000oiVI
VOl0003oOgmoo`000?mVIVKo0000oda<C?l00009oc<c<`0<o`000?m<C4co0000ofIVI_l0003oOgmo
o`000?nIVIWo0000ok>c/ol0003oc<c<1_ooool1o`00007ooooo0Oooool001Wooooo00GoV9RHob4Q
8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo00?ooooo0omVIVH00ol0003oC4a<oda<C00G
oda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;
oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`06
ogmoO`03o`000?mVIVKoIVIV00KoIVIV00?o0000oda<C?m<C4`04om<C4`00ol0003oIVIVofIVIP02
ofIVIP05o`000?moOgooOgmoogmoOol000001?nIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<
c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo
00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<
C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<
c<`01ol0003o/k>cok>c/onc/k?o0000oiVIVOl000000_moOgl00ol0003oIVIVo`000003oda<C003
o`000?lc<c?o<c<c00Ko<c<c00So0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000;oVIVI00Co
0000ok>c/onc/k?o00002?o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0
003oC4a<o`0000Wo<c<c00co0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`00
0?o<c<`6ooooo`7o00000Oooool1ooooo`004Oooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h01ooo
ool3o`0000?ooooo0_mVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00_oIVIV00?o
0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o
0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`06ogmoO`03o`000?mVIVKoIVIV00KoIVIV00?o
0000oda<C?m<C4`04om<C4`00ol0003oIVIVofIVIP02ofIVIP03o`000?moOgooOgmo00;oOgmo00Go
0000oiVIVOnIVIWoVIVIo`000006ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<0
0onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000003oda<
C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgoo
Ogmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c007o`000?nc/k?o/k>cok>c/ol0
003oVIVIo`000002ogmoO`03o`000?mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<02?l0
003oC4a<oda<C?l0003oIVIVo`000?moOgoo00000_nIVIT01?l0003o/k>cok>c/ol00008olc<c00:
o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<0
1_lc<c<01Ol0003oC4a<o`000?mVIVKo000000;oOgmo0_l000001?nc/k?o0000olc<c?o<c<`4oooo
o`?o00000_ooool001_ooooo00?oV9RHob4Q8Oo^k^h01_ooool00ol0003oooooooooo`03ooooo`03
ofIVI_l0003oC4a<01SoC4a<00?o0000ofIVI_mVIVH02_mVIVH2o`0000[oOgmo00?o0000oiVIVOnI
VIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomo
Ogl01omoOgl00ol0003oIVIVofIVIP05ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000ofIVI_mV
IVH00_mVIVH00ol0003oOgmoogmoO`02ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001_nc/k<00ol0
003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002
ogmoO`05o`000?mVIVKoIVIVofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<
C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@05o`000?nc/k?o/k>cok>c
/ol000002?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@06o`000?moOgooOgmoo`000?mVIVKo0000
0_m<C4`00ol0003o<c<coc<c<`07oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002
oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`00
0?mVIVKo0000oda<C?l00009oc<c<`0;o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000
ok>c/ol000000_o<c<`6ooooo`7o00000Oooool1ooooo`007?ooool00omgMgOoIVIVooooo`05oooo
o`03o`000?oooooooooo00?ooooo00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0:ofIV
IP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c
/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl01_moOgl00ol0003oIVIVofIVIP06ofIV
IP03o`000?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH00_mVIVH00ol0003oOgmoogmoO`02ogmo
O`05o`000?nIVIWoVIVIoiVIVOl000001_nc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o
/k>c00?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`05o`000?mVIVKoIVIVofIVI_l00000
0om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003o
OgmoogmoOol00002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01?l0003o/k>cok>c/ol0
0002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<02?l0003oC4a<
oda<C?l0003oIVIVo`000?moOgoo00000_nIVIT00ol0003o/k>co`000009olc<c00<o`000?nc/k?o
/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co00002Olc<c<02ol0003oC4a<o`000?mV
IVKo0000ogmoOol0003oVIVIo`000?nc/k?o000000;oc<c<1_ooool1o`00007ooooo0Oooool001go
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooooaSoC4a<0_l0000<ofIVIP03
o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03
o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl01_moOgl00ol0003oIVIVofIVIP06ofIVIP03
o`000?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH00omVIVH01Ol0003oOgmoogmoOomoOgoo0000
00CoVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c
00?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`05o`000?mVIVKoIVIVofIVI_l000000om<
C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmo
ogmoOol00002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01?l0003o/k>cok>c/ol00002
oiVIV@06o`000?moOgooOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`07oc<c<`08o`00
0?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00co
0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00009oc<c<`03o`000?m<
C4co000000;oIVIV0_l000001OnIVIWo0000ok>c/onc/k?o000000;oc<c<1_ooool1o`00007ooooo
0Oooool001Wooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo00?ooooo
5om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT0
2onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI0_l00008ogmoO`03o`00
0?mVIVKoIVIV00KoIVIV00?o0000oda<C?m<C4`04om<C4`00ol0003oIVIVofIVIP03ofIVIP05o`00
0?moOgooOgmoogmoOol000001?nIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00?o
c<c<00?o0000ok>c/onc/k<00onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Co0000ofIV
I_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000
ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<
00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`00
00So<c<c00Wo0000oda<C?m<C4coC4a<o`000?mVIVKo0000ogmoOol000000_nIVIT00ol0003o/k>c
o`000009olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co0000
2Olc<c<02ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o000000?oc<c<1_oo
ool1o`00007ooooo0Oooool001Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oo
oooooooo00?ooooo5om<C4`00ol0003oIVIVofIVIP0:ofIVIP03o`000?moOgooOgmo00WoOgmo00?o
0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00coVIVI00?o
0000ogmoOomoOgl01omoOgl00ol0003oIVIVofIVIP05ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o
0000ofIVI_mVIVH00omVIVH01Ol0003oOgmoogmoOomoOgoo000000CoVIVI00?o0000ok>c/onc/k<0
1?nc/k<00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c00?o/k>c00Go0000oiVIVOnIVIWo
VIVIo`000002ogmoO`05o`000?mVIVKoIVIVofIVI_l000001?m<C4`00ol0003o<c<coc<c<`05oc<c
<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl0
0002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmo
o`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Wo0000oda<C?m<C4coC4a<o`000?mVIVKo
0000ogmoOol000000_nIVIT00ol0003o/k>co`000009olc<c00<o`000?nc/k?o/k>co`000?nIVIWo
0000ogmoOol0003oIVIVo`000?m<C4co00002Olc<c<02ol0003oC4a<o`000?mVIVKo0000ogmoOol0
003oVIVIo`000?nc/k?o000000?oc<c<1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000oooo
ooooool00ooooolEoda<C0;o00003?mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI
00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo
00OoOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<C00Doda<C003o`000?mVIVKoIVIV
00?oIVIV00Go0000ogmoOomoOgooOgmoo`000004oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000
olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`03ok>c/`03o`000?nIVIWoVIVI00;oVIVI00Co0000
ogmoOomoOgoo00000_mVIVH00ol0003oC4a<oda<C002oda<C003o`000?lc<c?o<c<c00Go<c<c00?o
0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000?o
/k>c00?o0000olc<c?o<c<`01_o<c<`02Ol0003o/k>cok>c/onc/k?o0000oiVIVOl0003oOgmoo`00
0002ofIVIP04o`000?m<C4coC4a<o`0000Wo<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmo
O`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02_l0003o/k>cok>c/ol0003o
VIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00?o0000oda<C?m<
C4`00_l000001?moOgoo0000oiVIVOnIVIT2o`0000Coc<c<1_ooool1o`00007ooooo0Oooool002Co
oooo00?o0000ooooooooool00ooooolDoda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomo
Ogl02?moOgl2o`0000goVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@;o
00002OmoOgl00ol0003oIVIVofIVIP05ofIVIP;o00005Om<C4`00ol0003oIVIVofIVIP03ofIVIP05
o`000?moOgooOgmoogmoOol000001?nIVIT00ol0003o/k>cok>c/`05ok>c/`03o`000?o<c<coc<c<
00;oc<c<00?o0000ok>c/onc/k<01?nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Go0000
ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<
C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000;o/k>c00?o0000olc<c?o<
c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0
003oC4a<oda<C?l00009oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVIV@04
o`000?nc/k?o/k>co`0000Soc<c<00?o0000ok>c/ol000000_nIVIT01Ol0003oOgmoo`000?mVIVKo
000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02ol0003oC4a<o`000?mVIVKo0000ogmoOol0003o
VIVIo`000?nc/k?o000000Coc<c<1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000oooooooo
ool00ooooolCoda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003o
VIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003o
OgmoogmoO`07ogmoO`03o`000?mVIVKoIVIV00KoIVIV00?o0000oda<C?m<C4`05?m<C4`00ol0003o
IVIVofIVIP03ofIVIP05o`000?moOgooOgmoogmoOol000001?nIVIT00ol0003o/k>cok>c/`05ok>c
/`03o`000?o<c<coc<c<00;oc<c<00?o0000ok>c/onc/k<01?nc/k<01Ol0003oVIVIoiVIVOnIVIWo
000000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o
0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000;o
/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmo
Ool000000_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000
ogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00?o0000ok>c/ol000000_nIVIT01Ol0
003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01Olc<c<03?l0003oC4a<oda<C?l0
003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Coc<c<1_ooool1o`00007ooooo0Oooool0
02Cooooo00?o0000ooooooooool00ooooolBoda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmo
OomoOgl02?moOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVI
VOnIVIT03?nIVIT00ol0003oOgmoogmoO`07ogmoO`03o`000?mVIVKoIVIV00KoIVIV00?o0000oda<
C?m<C4`05?m<C4`00ol0003oIVIVofIVIP03ofIVIP05o`000?moOgooOgmoogmoOol000001OnIVIT0
0ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o0000ok>c/onc/k<01?nc/k<0
1Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`00
0?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`00
00;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o
0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`08o`000?m<C4coC4a<o`000?mV
IVKo0000ogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00[o0000ok>c/onc/k?o0000
oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4co
0000ofIVI_l000000_moOgl2o`0000;o/k>c00?o0000olc<c?o<c<`00_o<c<`6ooooo`7o00000Ooo
ool1ooooo`009?ooool00ol0003oooooooooo`03oooooa7oC4a<00?o0000ofIVI_mVIVH02omVIVH0
0ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<0
0ol0003oVIVIoiVIV@0;oiVIV@;o00002OmoOgl00ol0003oIVIVofIVIP06ofIVIP03o`000?m<C4co
C4a<01CoC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWo
VIVI00;oVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o
/k>c00?o/k>c0_l00002oiVIV@05o`000?moOgooOgmoogmoOol000000_mVIVH00ol0003oC4a<oda<
C002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`00
0?moOgooOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c005o`000?nc/k?o/k>c
ok>c/ol000000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Co
0000oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<
c<`01oo<c<`03?l0003o/k>co`000?l0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000Wo
<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<
c002olc<c0Kooooo0Ol00001ooooo`7ooooo000Tooooo`;o00001?ooool@oda<C003o`000?mVIVKo
IVIV00_oIVIV0_l0000:ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<0
0ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH01omVIVH0
0ol0003oC4a<oda<C00Doda<C003o`000?mVIVKoIVIV00?oIVIV00?o0000ogmoOomoOgl00_moOgl0
0ol0003oVIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`00oo<c<`0
0ol0003o/k>cok>c/`03ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01?l0003oIVIVofIV
I_l00004oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04
o`000?moOgooOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c005o`000?nc/k?o
/k>cok>c/ol000000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c
00Co0000oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<
c?o<c<`01oo<c<`00ol0003o/k>co`000002oiVIV@07o`000?moOgoo0000ofIVI_l0003oC4a<o`00
0009oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<
c?o<c<`00_o<c<`5ooooo`;o00000_ooool002Cooooo00?o0000ooooooooool00oooool?oda<C003
o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03
o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03
o`000?mVIVKoIVIV00OoIVIV00?o0000oda<C?m<C4`05?m<C4`00ol0003oIVIVofIVIP03ofIVIP03
o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`04ok>c/`03
o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00onc/k<00ol0003oVIVIoiVIV@02oiVIV@04
o`000?moOgooOgmoo`0000;oIVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`05oc<c
<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl0
0002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Co0000ok>c/onc/k?o00000_nIVIT01_l0003oOgmo
ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002
ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`2o`0000;oVIVI00Oo
0000ogmoOol0003oIVIVo`000?m<C4co000000Wo<c<c00?o0000oda<C?l000000_mVIVH2o`000005
oiVIVOl0003o/k>cok>c/ol000001Oo<c<`6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003o
ooooooooo`03ooooo`koC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`;o
00003OnIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomo
Ogl02?moOgl00ol0003oIVIVofIVIP07ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIVI_mV
IVH00omVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc
/k<01Onc/k<00ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c00Co/k>c00Go0000oiVIVOnI
VIWoVIVIo`000002ogmoO`05o`000?mVIVKoIVIVofIVI_l000001?m<C4`00ol0003o<c<coc<c<`06
oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@05o`00
0?nc/k?o/k>cok>c/ol000002?o<c<`01ol0003o/k>cok>c/onc/k?o0000oiVIVOl000000_moOgl0
1?l0003oIVIVofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co0000
0_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`00ol0003o
/k>co`000002oiVIV@07o`000?moOgoo0000ofIVI_l0003oC4a<o`000009oc<c<`04o`000?m<C4co
0000ofIVIP?o000000GoVIVIo`000?nc/k?o/k>co`000005olc<c0Kooooo0Ol00001ooooo`7ooooo
000Tooooo`03o`000?oooooooooo00?ooooo3Om<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?mo
OgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nI
VIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP07ofIVIP03o`000?m<
C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nI
VIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c002olc<c003o`000?nc
/k?o/k>c00Co/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`05o`000?mVIVKoIVIVofIVI_l0
00001?m<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0
003oOgmoogmoOol00002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01ol0003o/k>cok>c
/onc/k?o0000oiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00002oda<C003o`000?lc<c?o<c<c
00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o
0000olc<c?o<c<`01oo<c<`00ol0003o/k>co`000002oiVIV@07o`000?moOgoo0000ofIVI_l0003o
C4a<o`000009oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o
0000olc<c?o<c<`00oo<c<`6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03
ooooo`coC4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWo
VIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0:oiVIV@03o`000?moOgoo
Ogmo00WoOgmo00?o0000ofIVI_mVIVH01omVIVH00ol0003oC4a<oda<C00Eoda<C003o`000?mVIVKo
IVIV00;oIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o
/k>c00Co/k>c00?o0000olc<c?o<c<`00_o<c<`00ol0003o/k>cok>c/`04ok>c/`05o`000?nIVIWo
VIVIoiVIVOl000000omoOgl01Ol0003oIVIVofIVI_mVIVKo000000CoC4a<00?o0000oc<c<olc<c<0
1Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co0000oiVIVOnI
VIWo00000_nc/k<00ol0003oc<c<olc<c007olc<c007o`000?nc/k?o/k>cok>c/ol0003oVIVIo`00
0002ogmoO`04o`000?mVIVKoIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01_l0003oC4a<
oda<C?l0003oIVIVo`0000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<
c005o`000?nc/k?o0000oiVIVOl000000_moOgl01Ol0003oIVIVo`000?m<C4co000000Wo<c<c0_l0
0002ofIVIP07o`000?moOgoo0000oiVIVOl0003o/k>co`000006olc<c0Kooooo0Ol00001ooooo`7o
oooo000Tooooo`03o`000?oooooooooo00?ooooo3?m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`00
0?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`00
0?nIVIWoVIVI00[oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP07ofIVIP03o`00
0?m<C4coC4a<01GoC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`02ogmoO`03o`00
0?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c002olc<c003o`00
0?nc/k?o/k>c00Co/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`05o`000?mVIVKoIVIVofIV
I_l000001?m<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH0
1?l0003oOgmoogmoOol00002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01ol0003o/k>c
ok>c/onc/k?o0000oiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00002oda<C003o`000?lc<c?o
<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c
00?o0000olc<c?o<c<`01oo<c<`00ol0003o/k>co`000002oiVIV@05o`000?moOgoo0000ofIVI_l0
00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`07o`000?m<C4co0000ofIVI_l0003oOgmoo`000002
oiVIV@03o`000?nc/k?o000000Koc<c<1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000oooo
ooooool00oooool:oda<C0;o00003OmVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI
00_oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0:oiVIV@;o00002_moOgl00ol0
003oIVIVofIVIP08ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0
003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01Onc/k<00ol0
003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c00Co/k>c00Go0000oiVIVOnIVIWoVIVIo`000003
ogmoO`05o`000?mVIVKoIVIVofIVI_l000001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<
C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00002ok>c/`03
o`000?o<c<coc<c<00Ooc<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo00Co0000
ofIVI_mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV
00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00?o0000ok>c/ol0
00000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02ol0
003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o000000Ooc<c<1_ooool1o`00007o
oooo0Oooool002Cooooo00?o0000ooooooooool00oooool9oda<C003o`000?mVIVKoIVIV00coIVIV
00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c
00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00WoIVIV
00?o0000oda<C?m<C4`04om<C4`00ol0003oIVIVofIVIP03ofIVIP03o`000?moOgooOgmo00?oOgmo
00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`05ok>c/`03o`000?o<c<coc<c<00;oc<c<
00?o0000ok>c/onc/k<01?nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Go0000ofIVI_mV
IVKoIVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0
003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01oo<
c<`01ol0003o/k>cok>c/onc/k?o0000oiVIVOl000000_moOgl00ol0003oIVIVo`000003oda<C003
o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nIVIWo
000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`00ol0003o/k>co`000002oiVIV@05o`000?moOgoo
0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`05oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo
0000ogmoOol0003oVIVIo`000?nc/k?o00001oo<c<`6ooooo`7o00000Oooool1ooooo`009?ooool0
0ol0003oooooooooo`03ooooo`WoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08
ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0:
oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02OmVIVH00ol0003oC4a<oda<C00D
oda<C003o`000?mVIVKoIVIV00?oIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@02
oiVIV@03o`000?nc/k?o/k>c00Go/k>c00?o0000olc<c?o<c<`00_o<c<`00ol0003o/k>cok>c/`04
ok>c/`03o`000?nIVIWoVIVI00;oVIVI00Co0000ogmoOomoOgoo00000omVIVH00ol0003oC4a<oda<
C002oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIV
I_l00002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01ol0003o
/k>cok>c/onc/k?o0000oiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00002oda<C003o`000?lc
<c?o<c<c00Oo<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<0
0ol0003oc<c<olc<c007olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`00
00;oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<o`000?mVIVKo000000;oOgmo0_l00002
ok>c/`03o`000?o<c<coc<c<00Goc<c<1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000oooo
ooooool00oooool8oda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0
003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02_nIVIT2o`00
00[oOgmo00?o0000ofIVI_mVIVH02?mVIVH2o`0001KoC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0
003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01Onc/k<01Ol0
003oc<c<olc<c?o<c<co000000Oo/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`04o`000?mV
IVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000?o
IVIV00Co0000ogmoOomoOgoo00000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Co0000
ok>c/onc/k?o00000_nIVIT01_l0003oOgmoogmoOol0003oIVIVo`0000?oC4a<00?o0000oc<c<olc
<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<0
0ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Oo0000ogmoOol0003oIVIV
o`000?m<C4co000000Wo<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl000000_nc
/k<00ol0003oc<c<olc<c005olc<c0Kooooo0Ol00001ooooo`7ooooo000Tooooo`;o00001?ooool7
oda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;
oiVIV@03o`000?nc/k?o/k>c01Ko/k>c0_l0000<oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000
ofIVI_mVIVH02OmVIVH00ol0003oC4a<oda<C00Eoda<C003o`000?mVIVKoIVIV00?oIVIV00?o0000
ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c00Go/k>c00Go0000
olc<c?o<c<coc<c<o`000006ok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomoOgooOgmo
o`000002ofIVIP03o`000?m<C4coC4a<00;oC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<
oda<C002oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00002ok>c
/`03o`000?o<c<coc<c<00Ooc<c<00Co0000ok>c/onc/k?o00000_nIVIT01_l0003oOgmoogmoOol0
003oIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP05
o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>c
o`0000;oVIVI00Oo0000ogmoOol0003oIVIVo`000?m<C4co000000Wo<c<c00Wo0000oda<C?l0003o
IVIVo`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c005olc<c0Gooooo0_l00002
ooooo`009?ooool00ol0003oooooooooo`03ooooo`KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0
003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0
003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02OmVIVH00ol0
003oC4a<oda<C00Eoda<C003o`000?mVIVKoIVIV00?oIVIV00?o0000ogmoOomoOgl00_moOgl00ol0
003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c00Go/k>c00Go0000olc<c?o<c<coc<c<o`000006
ok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`000003ofIVIP05o`000?m<
C4coC4a<oda<C?l000001olc<c<00ol0003oC4a<oda<C002oda<C005o`000?mVIVKoIVIVofIVI_l0
00000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c
/onc/k?o/k>co`000002oiVIV@05o`000?moOgoo0000ofIVI_l000000om<C4`00ol0003o<c<coc<c
<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>c
ok>c/ol00007olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Oo0000ogmoOol0003oIVIVo`000?m<
C4co000000Wo<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl000000_nc/k<00ol0
003oc<c<olc<c006olc<c003o`000?oooooooooo00?ooooo0Ol00001ooooo`7ooooo000Tooooo`03
o`000?oooooooooo00?ooooo1Om<C4`00ol0003oIVIVofIVIP0:ofIVIP;o00002_moOgl00ol0003o
VIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003o
OgmoogmoO`08ogmoO`;o00002omVIVH00ol0003oC4a<oda<C00Eoda<C003o`000?mVIVKoIVIV00?o
IVIV0_l00004ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01_nc/k<01?l0003o
c<c<olc<c?l00007ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01Ol0003oIVIVofIVI_mV
IVKo000000CoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mV
IVKoIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c005
o`000?nc/k?o/k>cok>c/ol000000_nIVIT01_l0003oOgmoogmoOol0003oIVIVo`0000;oC4a<00?o
0000oc<c<olc<c<01olc<c<01?l0003oC4a<oda<C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl0
00000_nc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Oo0000ogmo
Ool0003oIVIVo`000?m<C4co000000Wo<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000oiVI
VOl000000_nc/k<00ol0003oc<c<olc<c006olc<c003o`000?oooooooooo00?ooooo0Ol00001oooo
o`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo1?m<C4`00ol0003oIVIVofIVIP0;ofIVIP03
o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03
o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03
o`000?m<C4coC4a<01GoC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`03ogmoO`03
o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01Onc/k<3o`000003olc<c?l0003o/k>c00Ko
/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`05o`000?mVIVKoIVIVofIVI_l000001?m<C4`0
0ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_mo
Ogl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o
/k>co`000002oiVIV@06o`000?moOgooOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`07
oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`00
0?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT01ol0003oOgmoo`000?mVIVKo0000
oda<C?l000002Olc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c/`03
o`000?o<c<coc<c<00Koc<c<00?o0000ooooooooool00oooool1o`00007ooooo0Oooool002Cooooo
00?o0000ooooooooool00oooool3oda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl0
2?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT0
2onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00[oIVIV00?o0000oda<C?m<C4`0
5Om<C4`00ol0003oIVIVofIVIP03ofIVIP03o`000?moOgooOgmo00?oOgmo00?o0000oiVIVOnIVIT0
0_nIVIT00ol0003o/k>cok>c/`06ok>c/`04o`000?o<c<co0000o`0000Oo/k>c00?o0000oiVIVOnI
VIT00_nIVIT01?l0003oOgmoogmoOol00003ofIVIP03o`000?m<C4coC4a<00;oC4a<00?o0000oc<c
<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co0000
oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol00000
0_nIVIT01_l0003oOgmoogmoOol0003oIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0
003oC4a<oda<C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<
c007olc<c003o`000?nc/k?o000000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`00
0?lc<c?o<c<c00Ko<c<c00Oo0000oda<C?l0003oIVIVo`000?moOgoo000000;oVIVI00?o0000ok>c
/ol000002?o<c<`00ol0003oooooooooo`04ooooo`7o00000Oooool1ooooo`009?ooool00ol0003o
ooooooooo`03ooooo`;oC4a<00?o0000ofIVI_mVIVH02_mVIVH2o`0000[oOgmo00?o0000oiVIVOnI
VIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomo
Ogl02?moOgl2o`0000coIVIV00?o0000oda<C?m<C4`05Om<C4`00ol0003oIVIVofIVIP04ofIVIP03
o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00_nIVIT2o`0000Oo/k>c00Go0000olc<c?o<
c<coc<c<o`000007ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01?l0003oIVIVofIVI_l0
0005oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIV
I_l00002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o
/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmoOol000000_mVIVH01Ol0003oC4a<oda<C?m<C4co
000000So<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`03o`000?nIVIWo000000;o/k>c
00?o0000olc<c?o<c<`01oo<c<`01?l0003o/k>co`000?nIVIT2o`000004ogmoOol0003oIVIVo`00
00;oC4a<00?o0000oc<c<olc<c<01_lc<c<02?l0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVI
0_l000000onc/k?o0000olc<c007olc<c003o`000?oooooooooo00Cooooo0Ol00001ooooo`7ooooo
000Tooooo`03o`000?oooooooooo00?ooooo00?oC4a<o`000?mVIVH02omVIVH00ol0003oOgmoogmo
O`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVI
V@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH03?mVIVH00ol0003oC4a<oda<
C00Doda<C003o`000?mVIVKoIVIV00CoIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVI
V@03oiVIV@03o`000?nc/k?o/k>c00Ko/k>c00Co0000olc<c?o<c<co00002?nc/k<01Ol0003oVIVI
oiVIVOnIVIWo000000?oOgmo00Co0000ofIVI_mVIVKo00001Om<C4`00ol0003o<c<coc<c<`05oc<c
<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl0
0003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@03o`00
0?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<01ol0003oC4a<oda<C?m<C4co0000
ofIVI_l000000_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Go0000
ok>c/ol0003oVIVIo`000002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc
<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<
00Koc<c<00?o0000ooooooooool01?ooool1o`00007ooooo0Oooool002Cooooo00?o0000oooooooo
ool00oooool00ol0003oIVIVofIVIP0:ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnI
VIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomo
Ogl02OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01GoC4a<00?o0000ofIVI_mV
IVH00omVIVH00ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc
/k<01_nc/k<01?l0003oc<c<olc<c?l00008ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl0
1Ol0003oIVIVofIVI_mVIVKo000000CoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<
C002oda<C007o`000?mVIVKoIVIVofIVI_l0003oOgmoo`000003oiVIV@04o`000?nc/k?o/k>co`00
00Soc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Co
0000oda<C?m<C4co00002?lc<c<01?l0003oC4a<oda<C?m<C4`2o`0000;oOgmo00?o0000oiVIVOl0
00000_nc/k<00ol0003oc<c<olc<c007olc<c005o`000?nc/k?o0000oiVIVOl000000_moOgl00ol0
003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Wo0000oda<C?l0003oIVIVo`000?mo
Ogoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c003o`000?nc/k?ooooo00Gooooo
0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo3?mVIVH00ol0003oOgmoogmo
O`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVI
V@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<
C00Eoda<C003o`000?mVIVKoIVIV00CoIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVI
V@03oiVIV@03o`000?nc/k?o/k>c00Ko/k>c0ol00008ok>c/`05o`000?nIVIWoVIVIoiVIVOl00000
0omoOgl01Ol0003oIVIVofIVI_mVIVKo000000CoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003o
C4a<oda<C002oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00003
ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@03o`000?mo
Ogoo000000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<01_l0003oC4a<oda<C?l0003oIVIVo`00
00;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c006o`000?nc/k?o/k>c
o`000?nIVIWo00000_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Wo
0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<
c003o`000?nc/k?ooooo00Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?o
oooo2omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc
/k<05_nc/k<00ol0003oVIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mV
IVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00CoIVIV00?o0000ogmoOomo
Ogl00_moOgl00ol0003oVIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c00Wo/k>c00?o0000ok>c/onc
/k<01_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004
oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mV
IVKo000000;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c005o`00
0?nc/k?o/k>cok>c/ol000000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`00
00Wo<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`03o`000?nIVIWo000000;o/k>c00?o
0000olc<c?o<c<`01_o<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00?o0000ofIVI_l0
00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nI
VIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003o/k>co`000005ooooo`7o00000Ooo
ool1ooooo`009?ooool2o`0000Cooooo2_mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWo
VIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0<oiVIV@03o`000?moOgoo
Ogmo00OoOgmo0_l0000=ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH01?mVIVH0
0ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<04_nc/k<0
1Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`00
0?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;o
Ogmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c003o`000?nc/k?o/k>c
00;o/k>c00Go0000oiVIVOl0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000Wo<c<c00Ko
0000oda<C?m<C4co0000ofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000;o/k>c00?o0000olc<
c?o<c<`01Oo<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00Ko0000ofIVI_mVIVKo0000
oda<C?l00008oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o
0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00004ooooo`;o00000_ooool002Cooooo00?o
0000ooooooooool00oooool9ofIVIP03o`000?moOgooOgmo00SoOgmo0_l0000=oiVIV@03o`000?nc
/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT2o`0000WoOgmo00?o0000ofIVI_mVIVH03?mV
IVH00ol0003oC4a<oda<C00Eoda<C0;o00001_mVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nI
VIWoVIVI00?oVIVI00?o0000ok>c/onc/k<04Onc/k<00ol0003oVIVIoiVIV@02oiVIV@05o`000?mo
OgooOgmoogmoOol000000omVIVH00ol0003oC4a<oda<C002oda<C003o`000?lc<c?o<c<c00Go<c<c
00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`05o`000?nIVIWoVIVIoiVI
VOl000000_nc/k<00ol0003oc<c<olc<c007olc<c007o`000?nc/k?o/k>cok>c/ol0003oVIVIo`00
0002ogmoO`04o`000?mVIVKoIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01olc<c<01_l0003oC4a<
oda<C?l0003oIVIVo`0000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<
c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl01Ol0003oIVIVo`000?m<C4co000000Wo<c<c
00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006
olc<c003o`000?nc/k?o000000Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo
00?ooooo2?mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00coVIVI00?o0000ok>c
/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIV
I_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00CoIVIV00?o0000ogmo
OomoOgl00omoOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c017o/k>c00?o0000oiVI
VOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000?oIVIV00?o0000oda<C?m<C4`00_m<C4`0
0ol0003o<c<coc<c<`05oc<c<`05o`000?m<C4coC4a<oda<C?l000000omVIVH01?l0003oOgmoogmo
Ool00003oiVIV@04o`000?nc/k?o/k>co`0000Woc<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo
000000;oOgmo00Co0000ofIVI_mVIVKo00000_m<C4`00ol0003o<c<coc<c<`07oc<c<`06o`000?m<
C4coC4a<o`000?mVIVKo00000_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ko
c<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`05o`000?mVIVKo0000oda<C?l000002Olc
<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<
00Koc<c<00?o0000ok>c/ol000001_ooool1o`00007ooooo0Oooool002Cooooo00?o0000oooooooo
ool00oooool7ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o
/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl01omoOgl2o`0000go
IVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP05ofIVIP03o`000?moOgooOgmo00;o
Ogmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0Aok>c/`03o`000?nIVIWoVIVI00;o
VIVI00Go0000ogmoOomoOgooOgmoo`000003ofIVIP03o`000?m<C4coC4a<00?oC4a<00?o0000oc<c
<olc<c<01?lc<c<00ol0003oC4a<oda<C002oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl0
1?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Oo0000ok>c/onc/k?o/k>c
o`000?nIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo00000_m<C4`00ol0003o<c<coc<c<`07oc<c
<`04o`000?m<C4coC4a<o`0000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<
c<coc<c<00Koc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`03o`000?mVIVKo000000;o
C4a<00?o0000oc<c<olc<c<01_lc<c<00ol0003oC4a<o`000002ofIVIP;o000000?oVIVIo`000?nc
/k<00_nc/k<00ol0003oc<c<olc<c005olc<c004o`000?nc/k?o0000oiVIV@Kooooo0Ol00001oooo
o`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo1_mVIVH00ol0003oOgmoogmoO`09ogmoO`03
o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@;o
00002OmoOgl00ol0003oIVIVofIVIP0;ofIVIP;o00006?m<C4`00ol0003oIVIVofIVIP05ofIVIP03
o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0Bok>c/`05
o`000?nIVIWoVIVIoiVIVOl000000omoOgl01Ol0003oIVIVofIVI_mVIVKo000000GoC4a<00?o0000
oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co
0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c005olc<c005o`000?nc/k?o/k>cok>c/ol0
00000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Wo0000
oda<C?m<C4coC4a<o`000?mVIVKo0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00008olc<
c005o`000?nc/k?o/k>co`000?nIVIT00_l000001?moOgoo0000ofIVI_l00002oda<C003o`000?lc
<c?o<c<c00Ko<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl000000_nc/k<00ol0
003oc<c<olc<c006olc<c004o`000?nc/k?o0000oiVIV@Kooooo0Ol00001ooooo`7ooooo000Toooo
o`03o`000?oooooooooo00?ooooo1OmVIVH2o`0000[oOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0
003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0
003oIVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<01OoC4a<0_l00007ofIVIP03o`000?moOgooOgmo
00;oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0Bok>c/`05o`000?nIVIWoVIVI
oiVIVOl000000omoOgl01Ol0003oIVIVofIVI_mVIVKo000000GoC4a<00?o0000oc<c<olc<c<01?lc
<c<00ol0003oC4a<oda<C003oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo
00001?nc/k<00ol0003oc<c<olc<c005olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0
003oOgmoogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Co0000oda<C?m<C4co0000
0_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Ko0000ok>c/onc
/k?o0000oiVIVOl00002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<0
2Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ko
c<c<00Co0000ok>c/ol0003oVIVI1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000oooooooo
ool00oooool4ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o
/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl2o`0000co
IVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP06ofIVIP03o`000?moOgooOgmo00;o
Ogmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0Bok>c/`05o`000?nIVIWoVIVIoiVI
VOl000000omoOgl01Ol0003oIVIVofIVI_mVIVKo000000GoC4a<00?o0000oc<c<olc<c<01Olc<c<0
0ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo0000
1?nc/k<00ol0003oc<c<olc<c005olc<c005o`000?nc/k?o/k>cok>c/ol000000onIVIT01_l0003o
OgmoogmoOol0003oIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01Olc<c<02Ol0003oC4a<oda<C?m<
C4co0000ofIVI_l0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Ko0000ok>c
/onc/k?o0000oiVIVOl00002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc
<c<00ol0003oC4a<oda<C002o`000007ogmoOol0003oVIVIoiVIVOl0003o/k>co`000008olc<c003
o`000?nc/k?o000000;oVIVI00?o0000ooooooooool00oooool1o`00007ooooo0Oooool002Cooooo
00?o0000ooooooooool00oooool3ofIVIP03o`000?moOgooOgmo00SoOgmo0_l0000=oiVIV@03o`00
0?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`00
0?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP05ofIVIP;o0000
1?moOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c01;o/k>c00?o0000oiVIVOnIVIT0
0_nIVIT01Ol0003oOgmoogmoOomoOgoo000000?oIVIV00?o0000oda<C?m<C4`00_m<C4`00ol0003o
<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmo
O`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc
/k?o000000;oVIVI00Ko0000ogmoOomoOgoo0000ofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko
<c<c00Wo0000oda<C?m<C4coC4a<o`000?mVIVKo0000ogmoOol000000_nIVIT01?l0003o/k>cok>c
/ol00008olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP04o`000?m<C4co
C4a<o`0000So<c<c00_o0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`000009
olc<c005o`000?nc/k?o0000oiVIVOl000001_ooool1o`00007ooooo0Oooool001Wooooo00Gok^k^
oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo00?ooooo0omVIVH00ol0003oOgmoogmo
O`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVI
V@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<oda<
C00Goda<C003o`000?mVIVKoIVIV00KoIVIV00?o0000ogmoOomoOgl00omoOgl00ol0003oVIVIoiVI
V@03oiVIV@03o`000?nc/k?o/k>c01;o/k>c00?o0000oiVIVOnIVIT00_nIVIT01?l0003oOgmoogmo
Ool00004ofIVIP03o`000?m<C4coC4a<00;oC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<
oda<C002oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00003ok>c
/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@06o`000?moOgoo
Ogmoo`000?mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`09o`000?m<C4coC4a<oda<C?l0
003oIVIVo`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`02?l0003o/k>cok>c
/ol0003oVIVIo`000?moOgoo00000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`0;o`000?m<C4co
0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol000002Oo<c<`01Ol0003o/k>co`000?nIVIWo
000000Kooooo0Ol00001ooooo`7ooooo000Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool0
0ol0003oooooooooo`03ooooo`;oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;
oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`09
ogmoO`03o`000?mVIVKoIVIV00[oIVIV00?o0000oda<C?m<C4`06?m<C4`00ol0003oIVIVofIVIP05
ofIVIP03o`000?moOgooOgmo00?oOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`0A
ok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`000003ofIVIP03o`000?m<
C4coC4a<00?oC4a<00?o0000oc<c<olc<c<01Olc<c<01Ol0003oC4a<oda<C?m<C4co000000?oIVIV
00Co0000ogmoOomoOgoo00000onIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Go0000ok>c
/onc/k?o/k>co`000002oiVIV@03o`000?moOgoo000000;oIVIV00Go0000oda<C?m<C4coC4a<o`00
0008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>c
ok>c/ol00008olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP03o`000?m<
C4co000000Wo<c<c00_o0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`000009
olc<c005o`000?nc/k?o0000oiVIVOl000001_ooool1o`00007ooooo0Oooool001Wooooo00Go410@
oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00?ooooo00?oIVIVo`000?moOgl02Omo
Ogl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02_nI
VIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00[oIVIV00?o0000oda<C?m<C4`06?m<
C4`00ol0003oIVIVofIVIP06ofIVIP03o`000?moOgooOgmo00?oOgmo00?o0000oiVIVOnIVIT00onI
VIT00ol0003o/k>cok>c/`0Bok>c/`03o`000?nIVIWoVIVI00;oVIVI00Co0000ogmoOomoOgoo0000
1?mVIVH00ol0003oC4a<oda<C003oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`0
0_m<C4`01?l0003oIVIVofIVI_l00003ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<
c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Ko0000ogmoOomoOgoo0000ofIV
I_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo0000
00;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c008o`000?nc/k?o/k>c
o`000?nIVIWo0000ogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Wo0000oda<C?l0
003oIVIVo`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c003o`000?nc
/k?o/k>c00;o000000?oOgmoooooooooool01?ooool1o`00007ooooo0Oooool001Wooooo00Go0000
ooooooooooooooooo`000006ooooo`?o00000oooool00ol0003oOgmoogmoO`08ogmoO`03o`000?nI
VIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0:oiVIV@;o00002_mo
Ogl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<0_l00007ofIVIP03o`000?mo
OgooOgmo00?oOgmo00?o0000oiVIVOnIVIT00onIVIT2o`0001Co/k>c00Go0000oiVIVOnIVIWoVIVI
o`000003ogmoO`05o`000?mVIVKoIVIVofIVI_l000001Om<C4`00ol0003o<c<coc<c<`05oc<c<`03
o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01Ol0003oVIVIoiVIVOnIVIWo
000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o
0000ogmoOol000000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Co0000oda<C?m<C4co
00000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00So0000ok>c
/onc/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV00?o0000oda<C?l000002Olc<c<02Ol0003oC4a<
o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o0000
ok>c/onc/k<00_l000000omoOgooooooooooo`02ooooo`?o00000_ooool001Wooooo00Go0000oooo
ooooooooooooo`000006ooooo`03o`000?oooooooooo00?ooooo2_moOgl00ol0003oVIVIoiVIV@0;
oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`09
ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP07
ofIVIP03o`000?moOgooOgmo00?oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0C
ok>c/`04o`000?nIVIWoVIVIo`0000CoOgmo00Go0000ofIVI_mVIVKoIVIVo`000005oda<C003o`00
0?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00om<C4`01?l0003oIVIVofIVI_l00002ogmoO`05
o`000?nIVIWoVIVIoiVIVOl000000onc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c
00;o/k>c00Ko0000oiVIVOnIVIWo0000ogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<C?l00000
2?lc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo00000_nc/k<0
0ol0003oc<c<olc<c006olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP03
o`000?m<C4co000000Wo<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl000000_nc
/k<00ol0003oc<c<olc<c006olc<c003o`000?nc/k?o/k>c00;o000000?oOgmoo`000?ooool01?oo
ool1o`00007ooooo0Oooool001Wooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oo
oooooooo00?ooooo2OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o
0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o
0000oda<C?m<C4`06?m<C4`00ol0003oIVIVofIVIP06ofIVIP03o`000?moOgooOgmo00?oOgmo00?o
0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0Cok>c/`05o`000?nIVIWoVIVIoiVIVOl00000
0omoOgl01Ol0003oIVIVofIVI_mVIVKo000000GoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003o
C4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000003
ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?mo
OgooOgmoo`0000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<01?l0003oC4a<oda<C?l00002ofIV
IP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`02?l0003o/k>cok>c/ol0
003oVIVIo`000?moOgoo00000_mVIVH00ol0003oC4a<o`000009oc<c<`09o`000?m<C4co0000ofIV
I_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`01?l0003o/k>co`00
0?l00002ogmoO`03o`000?oooooooooo00?ooooo0Ol00001ooooo`7ooooo000Iooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`03ooooo`SoOgmo00?o0000oiVIVOnIVIT0
2onIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00[oVIVI0_l0000:ogmoO`03o`00
0?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`2o`0000SoIVIV00?o0000ogmoOomoOgl0
0omoOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c01;o/k>c00?o0000oiVIVOnIVIT0
0_nIVIT00ol0003oOgmoogmoO`02o`0000?oIVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o<c<c
oc<c<`04oc<c<`03o`000?m<C4coC4a<00;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`04
o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01_o<c<`01_l0003o/k>cok>c/onc/k?o
0000oiVIV@;o000000GoOgmoo`000?mVIVKoIVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c
00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`00
00Soc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV00?o0000oda<C?l00000
2Olc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<co
c<c<00Koc<c<00?o0000ok>c/onc/k<00_l000000omoOgoo0000ooooo`05ooooo`7o00000Oooool1
ooooo`006Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool00oooool7
ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<2o`0000coVIVI00?o0000
ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000
ofIVI_mVIVH02?mVIVH00ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000
ok>c/onc/k<04_nc/k<00ol0003oVIVIoiVIV@03oiVIV@04o`000?moOgooOgmoo`0000CoIVIV00?o
0000oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00;oC4a<00Go
0000ofIVI_mVIVKoIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<
c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Go0000
oda<C?m<C4coC4a<o`000008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol00000
0_nIVIT01?l0003o/k>cok>c/ol00008olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0
0002ofIVIP03o`000?m<C4co000000Wo<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000oiVI
VOl000000_nc/k<00ol0003oc<c<olc<c006olc<c003o`000?nc/k?o/k>c00;o000000?oOgmoo`00
0?ooool01Oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool6ogmoO`03
o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03
o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Hoda<C003
o`000?mVIVKoIVIV00OoIVIV00?o0000ogmoOomoOgl00omoOgl00ol0003oVIVIoiVIV@03oiVIV@03
o`000?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT00_nIVIT01?l0003oOgmoogmoOol00004ofIV
IP03o`000?m<C4coC4a<00?oC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C002oda<
C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<
c<coc<c<00Koc<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo00Co0000ofIVI_mV
IVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000
ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00008olc<c008o`000?nc/k?o/k>co`000?nIVIWo
0000ogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00?o0000oda<C?m<C4`00_l00000
1omoOgoo0000oiVIVOnIVIWo0000ok>c/ol000002Oo<c<`01?l0003o/k>co`000?nIVIT2o`000003
ofIVI_oooooooooo00Cooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo
1OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT0
2onIVIT00ol0003oOgmoogmoO`08ogmoO`;o00003OmVIVH00ol0003oC4a<oda<C00Goda<C0;o0000
2OmVIVH00ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<0
4_nc/k<00ol0003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol000000omVIVH00ol0003o
C4a<oda<C003oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0003o
IVIVofIVI_mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c007
olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01?l0003oC4a<
oda<C?l00009oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0
003o/k>cok>c/ol00008olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP04
o`000?m<C4co0000o`0000So<c<c00Oo0000oda<C?l0003oIVIVo`000?moOgoo000000;oVIVI00?o
0000ok>c/ol000002Oo<c<`01?l0003o/k>co`000?nIVIT2o`000003ofIVI_oooooooooo00Cooooo
0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo1?moOgl00ol0003oVIVIoiVI
V@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmo
O`08ogmoO`03o`000?mVIVKoIVIV00coIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIV
IP08ofIVIP03o`000?moOgooOgmo00CoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c
/`0Bok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`000003ofIVIP03o`00
0?m<C4coC4a<00?oC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C003oda<C004o`00
0?mVIVKoIVIVo`0000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000003ok>c/`03o`000?o<c<coc<c<
00Ooc<c<00Co0000ok>c/onc/k?o00000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP04o`000?m<
C4coC4a<o`0000Wo<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVIV@04
o`000?nc/k?o/k>co`0000Soc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo
00000_m<C4`00ol0003o<c<coc<c<`07oc<c<`07o`000?m<C4co0000ofIVI_l0003oOgmoo`000002
oiVIV@03o`000?nc/k?o000000Woc<c<00Co0000ok>c/ol0003oVIVI0_l000000omVIVKo0000oooo
o`04ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`?oOgmo00?o0000
oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000
ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000
ofIVI_mVIVH02?mVIVH00ol0003oOgmoogmoO`04ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000
ok>c/onc/k<04_nc/k<00ol0003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol000000omV
IVH00ol0003oC4a<oda<C003oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<
C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000002ok>c/`03
o`000?o<c<coc<c<00Ooc<c<00Co0000ok>c/onc/k?o00000_nIVIT01?l0003oOgmoogmoOol00002
ofIVIP04o`000?m<C4coC4a<o`0000Wo<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmo
o`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003o
Ogmoo`0000;oIVIV00?o0000oda<C?l000002Olc<c<01Ol0003oC4a<o`000?mVIVKo000000;oOgmo
00Go0000oiVIVOl0003o/k>co`000009olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mV
IVKo000000Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo0_moOgl0
0ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT0
0ol0003oOgmoogmoO`08ogmoO`;o00003OmVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKo
IVIV00SoIVIV00?o0000ogmoOomoOgl01?moOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o
/k>c01;o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000CoIVIV00?o
0000oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Co
0000ofIVI_mVIVKo00000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000?o/k>c00?o0000olc<c?o<
c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH0
1?l0003oC4a<oda<C?l00009oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Go0000ogmoOol0003o
VIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003o
Ogmoo`0000;oIVIV00?o0000oda<C?l000002Olc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0
003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Oo0000ok>c/onc/k?o0000oiVIVOl0
003oOgmo00;o00001_ooool1o`00007ooooo0Oooool002Cooooo0_l00004ooooo`03ogmoOol0003o
VIVI00coVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgoo
Ogmo00SoOgmo00?o0000ofIVI_mVIVH03?mVIVH00ol0003oC4a<oda<C00Foda<C0;o00002omVIVH0
0ol0003oOgmoogmoO`04ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<04_nc/k<0
0ol0003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol000001?mVIVH00ol0003oC4a<oda<
C003oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00om<C4`01?l0003oIVIVofIV
I_l00002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c005
o`000?nc/k?o/k>cok>c/ol000000_nIVIT00ol0003oOgmoo`000003ofIVIP04o`000?m<C4coC4a<
o`0000So<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00?o0000oiVIVOl00000
0_nc/k<00ol0003oc<c<olc<c007olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002
ofIVIP03o`000?m<C4co000000Wo<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0
00000_nc/k<00ol0003oc<c<olc<c006olc<c007o`000?nc/k?o/k>co`000?nIVIWo0000ogmoO`02
o`0000Gooooo0_l00002ooooo`009?ooool00ol0003oooooooooo`03ooooo`03o`000?nIVIWoVIVI
00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo
00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV
00[oIVIV00?o0000ogmoOomoOgl01?moOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c
01?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000004ogmoO`05o`000?mVIVKoIVIVofIVI_l000001Om<
C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Co0000ofIVI_mVIVKo0000
0_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`01Ol0003o
/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000omVIVH01?l0003oC4a<oda<C?l0
0008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Go0000ogmoOol0003oVIVIo`000003ok>c/`03
o`000?o<c<coc<c<00Koc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV00?o
0000oda<C?l000002Olc<c<00ol0003oC4a<o`000002ofIVIP;o00000_nIVIT00ol0003o/k>co`00
0009olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000Kooooo0Ol00001oooo
o`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo3OnIVIT00ol0003o/k>cok>c/`0Fok>c/`03
o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03
o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`04ogmoO`03
o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<04onc/k<00ol0003oVIVIoiVIV@02oiVIV@05
o`000?moOgooOgmoogmoOol000000omVIVH00ol0003oC4a<oda<C004oda<C003o`000?lc<c?o<c<c
00?o<c<c00?o0000oda<C?m<C4`00om<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Go0000
oiVIVOnIVIWoVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>c
o`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<01ol0
003oC4a<oda<C?m<C4co0000ofIVI_l000000_moOgl00ol0003oVIVIo`000003ok>c/`03o`000?o<
c<coc<c<00Koc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV00?o0000oda<
C?l000002Olc<c<01ol0003oC4a<o`000?mVIVKo0000ogmoOol000000_nIVIT00ol0003o/k>co`00
0008olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000Kooooo0Ol00001
ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo3?nIVIT00ol0003o/k>cok>c/`0Fok>c
/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIV
IP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`05ogmo
O`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<04onc/k<01Ol0003oVIVIoiVIVOnIVIWo
000000CoOgmo00Go0000ofIVI_mVIVKoIVIVo`000006oda<C003o`000?lc<c?o<c<c00?o<c<c00?o
0000oda<C?m<C4`00om<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Go0000oiVIVOnIVIWo
VIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVI
V@04o`000?moOgooOgmoo`0000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<01ol0003oC4a<oda<
C?m<C4co0000ofIVI_l000000_moOgl00ol0003oVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Ko
c<c<00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV00?o0000oda<C?l000002Olc
<c<01ol0003oC4a<o`000?mVIVKo0000ogmoOol000000_nIVIT00ol0003o/k>co`000008olc<c00:
o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000Kooooo0Ol00001ooooo`7ooooo
000Tooooo`03o`000?oooooooooo00?ooooo2onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nI
VIWoVIVI00coVIVI00?o0000ogmoOomoOgl01omoOgl2o`0000goIVIV00?o0000oda<C?m<C4`05_m<
C4`00ol0003oIVIVofIVIP0:ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT01?nI
VIT00ol0003o/k>cok>c/`0Cok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomoOgooOgmo
o`000003ofIVIP03o`000?m<C4coC4a<00CoC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<
oda<C002oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01Ol0003oVIVIoiVIVOnIVIWo0000
00?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000
ogmoOomoOgoo00000_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`06o`000?m<C4coC4a<o`000?mV
IVKo00000_moOgl00ol0003oVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00So0000ok>c
/onc/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV00?o0000oda<C?l000002Olc<c<00ol0003oC4a<
oda<C002o`000007ogmoOol0003oVIVIoiVIVOl0003o/k>co`000008olc<c00;o`000?nc/k?o/k>c
o`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4`01_ooool1o`00007ooooo0Oooool002Cooooo
00?o0000ooooooooool00oooool:oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT0
2onIVIT2o`0000WoOgmo00?o0000ofIVI_mVIVH03?mVIVH00ol0003oC4a<oda<C00Foda<C003o`00
0?mVIVKoIVIV00[oIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@04oiVIV@03o`00
0?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000Co
IVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?o
C4a<00Co0000ofIVI_mVIVKo00000omoOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<co
c<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01_l0003oVIVIoiVIVOl0003oOgmoo`0000;oIVIV
00Co0000oda<C?m<C4co00002_lc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00?o0000
oiVIVOl000000_nc/k<2o`0000Soc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`0000;o
IVIV00Co0000oda<C?l0003o00002?lc<c<01ol0003oC4a<o`000?mVIVKo0000ogmoOol000000_nI
VIT00ol0003o/k>co`000008olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIV
o`000?m<C4co00001Oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool9
oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`08
ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0:
ofIVIP03o`000?moOgooOgmo00KoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`0C
ok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`000004ofIVIP03o`000?m<
C4coC4a<00?oC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C003oda<C004o`000?mV
IVKoIVIVo`0000?oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c005olc<c003
o`000?nc/k?o/k>c00;o/k>c00Ko0000oiVIVOnIVIWo0000ogmoOol00002ofIVIP04o`000?m<C4co
C4a<o`0000[o<c<c00So0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000;oVIVI00Co0000ok>c
/onc/k?o00002Oo<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<
C003o`000?lc<c?o<c<c00Oo<c<c00Oo0000oda<C?l0003oIVIVo`000?moOgoo000000;oVIVI00?o
0000ok>c/ol000002?o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003o
C4a<o`0000Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo2?nIVIT0
0ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl01omoOgl2
o`0000goIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgoo
Ogmo00GoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`0Cok>c/`03o`000?nIVIWo
VIVI00;oVIVI00?o0000ogmoOomoOgl00_moOgl01Ol0003oIVIVofIVI_mVIVKo000000GoC4a<00?o
0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C003oda<C004o`000?mVIVKoIVIVo`0000?oOgmo
00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c
/ol000000_nIVIT00ol0003oOgmoo`000002ofIVIP05o`000?m<C4coC4a<oda<C?l000002Olc<c<0
1_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<
olc<c007olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP03o`000?m<C4co
000000Wo<c<c00Go0000oda<C?l0003oIVIVo`000002ogmoO`05o`000?nIVIWo0000ok>c/ol00000
2?o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000Kooooo
0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo1onIVIT00ol0003o/k>cok>c
/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI0_l00009ogmoO`03o`000?mVIVKoIVIV00_oIVIV0_l0
000Hoda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVI
V@04oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT00_nIVIT00ol0003oOgmoogmo
O`02ogmoO`05o`000?mVIVKoIVIVofIVI_l000001_m<C4`00ol0003o<c<coc<c<`03oc<c<`03o`00
0?m<C4coC4a<00?oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVI
VOl000001?nc/k<00ol0003oc<c<olc<c005olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT0
1?l0003oOgmoogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01?l0003oC4a<
oda<C?l00002ofIVIP06o`000?moOgooOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006
olc<c00;o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0
003o<c<coc<c<`06oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVIV@03o`00
0?nc/k?o000000Soc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<
C?l00006ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`KoVIVI00?o
0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o
0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00_oIVIV00?o
0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@05oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o
0000oiVIVOnIVIT00_nIVIT00ol0003oOgmoogmoO`02ogmoO`05o`000?mVIVKoIVIVofIVI_l00000
1Om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Go0000ofIVI_mVIVKo
IVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0003oc<c<olc<c005olc<
c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP05o`000?m<
C4coC4a<oda<C?l000002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP06o`000?moOgooOgmoo`00
0?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c00;o`000?nc/k?o/k>cok>c/ol0003oVIVI
o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`08o`000?m<C4coC4a<
o`000?mVIVKo0000ogmoOol00002oiVIV@03o`000?nc/k?o000000Soc<c<00co0000ok>c/onc/k?o
0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00006ooooo`7o00000Oooool1ooooo`009?oo
ool2o`0000Cooooo1OnIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o
0000ogmoOomoOgl02?moOgl2o`0000coIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIV
IP0;ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT01OnIVIT00ol0003o/k>cok>c
/`0Cok>c/`03o`000?nIVIWoVIVI00?oVIVI00Go0000ogmoOomoOgooOgmoo`000003ofIVIP03o`00
0?m<C4coC4a<00CoC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C003oda<C004o`00
0?mVIVKoIVIVo`0000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<
00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01_l0003oVIVIoiVIVOl0003oOgmoo`0000;oIVIV00?o
0000oda<C?m<C4`00_m<C4`00ol0003o<c<coc<c<`05oc<c<`07o`000?m<C4coC4a<oda<C?l0003o
IVIVo`000002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`02_l0003o
/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c
00?o0000oda<C?l000000_mVIVH2o`0000;oVIVI00?o0000ok>c/ol000002Oo<c<`00ol0003o/k>c
ok>c/`02o`000007ogmoOol0003oIVIVo`000?m<C4co0000oc<c<`05ooooo`;o00000_ooool002Co
oooo00?o0000ooooooooool00oooool4oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnI
VIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<
C4`05om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnI
VIT01OnIVIT2o`0001Co/k>c0_l00004oiVIV@05o`000?moOgooOgmoogmoOol000001?mVIVH00ol0
003oC4a<oda<C003oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00om<C4`01Ol0
003oIVIVofIVI_mVIVKo000000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000003ok>c/`03o`000?o<
c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;o
IVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000
ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00009olc<c00:o`000?nc/k?o/k>co`000?nIVIWo
0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01olc<c<01ol0003oC4a<o`000?mV
IVKo0000ogmoOol000000_nIVIT00ol0003o/k>co`000008olc<c0;o000000_o/k>co`000?nIVIWo
0000ogmoOol0003oIVIVo`000?m<C4co0000oc<c<`06ooooo`7o00000Oooool1ooooo`009?ooool0
0ol0003oooooooooo`03ooooo`?oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;
oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<oda<C00G
oda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl01_moOgl00ol0003oVIVIoiVIV@05
oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT00onIVIT01Ol0003oOgmoogmoOomo
Ogoo000000CoIVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<
C4coC4a<00?oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000Co
/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmo
OomoOgoo00000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Co0000oda<C?m<C4co0000
0_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Woc<c<00[o0000ok>c/onc
/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`07oc<c<`07o`00
0?m<C4co0000ofIVI_l0003oOgmoo`000002oiVIV@03o`000?nc/k?o000000Soc<c<00go0000ok>c
/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l0003o<c<c00Kooooo0Ol00001oooo
o`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo0onIVIT00ol0003o/k>cok>c/`0Fok>c/`03
o`000?nIVIWoVIVI00[oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0:ofIVIP03
o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`06ogmoO`03
o`000?nIVIWoVIVI00GoVIVI00?o0000ok>c/onc/k<04onc/k<00ol0003oVIVIoiVIV@03oiVIV@03
o`000?moOgooOgmo00;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000006oda<C003o`000?lc<c?o<c<c
00?o<c<c00?o0000oda<C?m<C4`00om<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Co0000
oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co
0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko
<c<c00Co0000oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000
olc<c?o<c<`01oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l00000
0_m<C4`00ol0003o<c<coc<c<`06oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003o
VIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`03Ol0003o/k>cok>c/ol0003oVIVIo`000?mo
Ogoo0000ofIVI_l0003oC4a<o`000?lc<c<01_ooool1o`00007ooooo0Oooool002Cooooo00?o0000
ooooooooool00oooool2oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02_nIVIT0
0ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00[oIVIV00?o0000oda<C?m<C4`05om<C4`0
0ol0003oIVIVofIVIP0<ofIVIP03o`000?moOgooOgmo00KoOgmo00?o0000oiVIVOnIVIT01OnIVIT0
0ol0003o/k>cok>c/`0Cok>c/`03o`000?nIVIWoVIVI00?oVIVI00Go0000ogmoOomoOgooOgmoo`00
0003ofIVIP;o00001Om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Go
0000ofIVI_mVIVKoIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<
c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH0
1Ol0003oC4a<oda<C?m<C4co000000So<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmo
o`000002oiVIV@04o`000?nc/k?o/k>co`0000Woc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003o
Ogmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`07oc<c<`03o`000?m<C4coC4a<00;o0000
00OoOgmoo`000?nIVIWoVIVIo`000?nc/k?o000000Soc<c<00co0000ok>c/onc/k?o0000oiVIVOl0
003oOgmoo`000?mVIVKo0000oda<C?l00002oc<c<`Kooooo0Ol00001ooooo`7ooooo000Tooooo`03
o`000?oooooooooo00?ooooo0_l0000Hok>c/`03o`000?nIVIWoVIVI00[oVIVI0_l0000:ogmoO`03
o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP;o
00002?moOgl00ol0003oVIVIoiVIV@05oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnI
VIT00onIVIT01Ol0003oOgmoogmoOomoOgoo000000CoIVIV00?o0000oda<C?m<C4`01?m<C4`00ol0
003o<c<coc<c<`03oc<c<`03o`000?m<C4coC4a<00?oC4a<00Go0000ofIVI_mVIVKoIVIVo`000003
ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c
/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o
<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0
003o/k>cok>c/ol00008olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Go0000ogmoOol0003oIVIV
o`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00So0000oda<C?m<C4co0000ofIVI_l0003oOgmo
o`0000;oVIVI00?o0000ok>c/ol000002?o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo
0000ofIVI_l0003oC4a<o`0000;o<c<c1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000oooo
ooooool00ooooolIok>c/`03o`000?nIVIWoVIVI00[oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0
003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0
003oOgmoogmoO`07ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc/k<04_nc/k<00ol0
003oVIVIoiVIV@04oiVIV@05o`000?moOgooOgmoogmoOol000001?mVIVH00ol0003oC4a<oda<C003
oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00om<C4`01Ol0003oIVIVofIVI_mV
IVKo000000?oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c003o`00
0?nc/k?o/k>c00;o/k>c00Ko0000oiVIVOnIVIWo0000ogmoOol00002ofIVIP03o`000?m<C4coC4a<
00;oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo
000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@05o`00
0?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`08o`000?m<C4coC4a<o`00
0?mVIVKo0000ogmoOol00002oiVIV@03o`000?nc/k?o000000Soc<c<00co0000ok>c/onc/k?o0000
oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00002oc<c<`Kooooo0Ol00001ooooo`7ooooo000T
ooooo`03o`000?oooooooooo00?ooooo6?nc/k<00ol0003oVIVIoiVIV@0:oiVIV@03o`000?moOgoo
Ogmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKo
IVIV00_oIVIV00?o0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o
/k>c01?o/k>c00?o0000oiVIVOnIVIT00onIVIT01Ol0003oOgmoogmoOomoOgoo000000CoIVIV00?o
0000oda<C?m<C4`01?m<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Co
0000ofIVI_mVIVKo00000omoOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Go
c<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIV
o`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?mo
Ogoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@05
o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`06o`000?m<C4coC4a<
o`000?mVIVKo00000_moOgl01Ol0003oVIVIo`000?nc/k?o000000Woc<c<00Wo0000ok>c/ol0003o
VIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06ooooo`7o00000Oooool1
ooooo`009?ooool00ol0003oooooooooo`03oooooaOo/k>c00?o0000oiVIVOnIVIT02_nIVIT2o`00
00[oOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV
00_oIVIV00?o0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c
01Co/k>c00?o0000oiVIVOnIVIT00_nIVIT00ol0003oOgmoogmoO`02ogmoO`05o`000?mVIVKoIVIV
ofIVI_l000001om<C4`00ol0003o<c<coc<c<`03oc<c<`03o`000?m<C4coC4a<00?oC4a<00Go0000
ofIVI_mVIVKoIVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000onc/k<00ol0003oc<c<
olc<c006olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl00ol0003o
IVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIV
IP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01?l0003o/k>cok>c/ol0
0002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`08o`00
0?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVIV@03o`000?nc/k?o000000Woc<c<00_o0000
ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`000003oc<c<`Kooooo0Ol00001oooo
o`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo5Onc/k<2o`0000coVIVI00?o0000ogmoOomo
Ogl02OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mV
IVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00GoVIVI00?o0000ok>c/onc
/k<05Onc/k<00ol0003oVIVIoiVIV@02oiVIV@03o`000?moOgooOgmo00;oOgmo00Go0000ofIVI_mV
IVKoIVIVo`000007oda<C003o`000?lc<c?o<c<c00?o<c<c00?o0000oda<C?m<C4`00om<C4`01Ol0
003oIVIVofIVI_mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<
c006olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl00ol0003oIVIV
o`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP03
o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01?l0003o/k>cok>c/ol00002
oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`08o`000?m<
C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVIV@03o`000?nc/k?o000000Woc<c<00_o0000ok>c
/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`000003oc<c<`Kooooo0Ol00001ooooo`7o
oooo000Tooooo`03o`000?oooooooooo00?ooooo5?nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`00
0?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`00
0?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@05oiVIV@03o`00
0?nc/k?o/k>c01Go/k>c00?o0000oiVIVOnIVIT00_nIVIT00ol0003oOgmoogmoO`02ogmoO`05o`00
0?mVIVKoIVIVofIVI_l000001om<C4`00ol0003o<c<coc<c<`03oc<c<`03o`000?m<C4coC4a<00?o
C4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000onc/k<0
0ol0003oc<c<olc<c006olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_mo
Ogl00ol0003oIVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<
o`000002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01?l0003o
/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07
oc<c<`03o`000?m<C4co000000;oIVIV0_l00002oiVIV@03o`000?nc/k?o000000Woc<c<00?o0000
ok>c/onc/k<00_l000001_moOgoo0000ofIVI_l0003oC4a<o`0000Co<c<c1_ooool1o`00007ooooo
0Oooool002Cooooo0_l00004oooooa?o/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmo
O`08ogmoO`;o00003OmVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o
0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c01?o/k>c0_l0
0004oiVIV@03o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<
C004oda<C003o`000?lc<c?o<c<c00?o<c<c00?o0000oda<C?m<C4`00om<C4`01Ol0003oIVIVofIV
I_mVIVKo000000?oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c006olc<c005
o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP05o`000?m<C4co
C4a<oda<C?l000002?lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o0000ogmoOol00000
0_nIVIT01?l0003o/k>cok>c/ol00008olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Go0000ogmo
Ool0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Oo0000oda<C?l0003oIVIVo`00
0?moOgoo000000;oVIVI00?o0000ok>c/ol000002?o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`00
0?moOgoo0000ofIVI_l0003oC4a<o`0000Co<c<c1Oooool2o`0000;ooooo000Tooooo`03o`000?oo
oooooooo00?ooooo4_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o
0000ofIVI_mVIVH03?mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00coIVIV00?o
0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@07oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o
0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o
0000oda<C?m<C4`01?m<C4`00ol0003o<c<coc<c<`02oc<c<`03o`000?m<C4coC4a<00CoC4a<00Go
0000ofIVI_mVIVKoIVIVo`000003ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<
c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH0
1Ol0003oC4a<oda<C?m<C4co000000So<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP05o`00
0?moOgoo0000oiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`00
00;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Oo0000
oda<C?l0003oIVIVo`000?moOgoo000000;oVIVI00?o0000ok>c/ol000002?o<c<`03?l0003o/k>c
ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000Co<c<c1_ooool1o`00007ooooo
0Oooool002Cooooo00?o0000ooooooooool00ooooolAok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o
0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o
0000ofIVI_mVIVH02omVIVH2o`0000WoOgmo00?o0000oiVIVOnIVIT01onIVIT00ol0003o/k>cok>c
/`0Cok>c/`03o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIV
IP02ofIVIP03o`000?m<C4coC4a<00CoC4a<00?o0000oc<c<olc<c<00olc<c<00ol0003oC4a<oda<
C004oda<C004o`000?mVIVKoIVIVo`0000?oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003o
c<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002
ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV
00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00009olc<c00:o`000?nc/k?o/k>co`00
0?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01olc<c<00ol0003oC4a<
oda<C002o`000005ogmoOol0003oVIVIoiVIVOl000000_nc/k<00ol0003oc<c<olc<c005olc<c006
o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl2o`000003oda<C?l0003o<c<c00Co<c<c1_ooool1
o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool@ok>c/`03o`000?nIVIWoVIVI
00_oVIVI00?o0000ogmoOomoOgl02?moOgl2o`0000goIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0
003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT01onIVIT00ol0
003o/k>cok>c/`0Dok>c/`03o`000?nIVIWoVIVI00?oVIVI00Go0000ogmoOomoOgooOgmoo`000004
ofIVIP03o`000?m<C4coC4a<00GoC4a<00?o0000oc<c<olc<c<00_lc<c<00ol0003oC4a<oda<C004
oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Co/k>c
00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;o
Ogmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`07o`000?m<C4coC4a<
oda<C?l0003oIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000;o/k>c00?o0000olc<c?o<c<`0
1_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0
003o<c<coc<c<`06oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVIV@03o`00
0?nc/k?o000000Soc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<
C?l00005oc<c<`Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo3onc
/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH03?mV
IVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?mo
Ogl00ol0003oVIVIoiVIV@07oiVIV@03o`000?nc/k?o/k>c01Co/k>c00?o0000oiVIVOnIVIT00onI
VIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01Om<
C4`00ol0003o<c<coc<c<`02oc<c<`03o`000?m<C4coC4a<00CoC4a<00Go0000ofIVI_mVIVKoIVIV
o`000002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0003oc<c<olc<c005olc<c003
o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00003
oda<C003o`000?lc<c?o<c<c00Ko<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo
00Co0000oiVIVOnIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`00
00;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00So0000
oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000;oVIVI00?o0000ok>c/ol000002?o<c<`03?l0003o
/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000Go<c<c1_ooool1o`00007o
oooo0Oooool002Cooooo00?o0000ooooooooool00oooool>ok>c/`03o`000?nIVIWoVIVI00_oVIVI
00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<
00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00SoVIVI
00?o0000ok>c/onc/k<04onc/k<00ol0003oVIVIoiVIV@03oiVIV@03o`000?moOgooOgmo00;oOgmo
00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C005oda<C003o`000?lc<c?o<c<c00;o<c<c
00?o0000oda<C?m<C4`01?m<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Co0000oiVIVOnI
VIWo00001?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVI
VOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Oo<c<c00Co
0000oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000So
c<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIVIP03o`000?m<C4co0000
00So<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`05o`000?nIVIWo0000ok>c/ol00000
2Oo<c<`00ol0003o/k>co`000002oiVIV@;o000000GoIVIVo`000?m<C4coC4a<o`000005oc<c<`Ko
oooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo3Onc/k<00ol0003oVIVI
oiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo0_l0000=ofIVIP03o`000?m<C4coC4a<01KoC4a<
00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00SoVIVI
00?o0000ok>c/onc/k<05?nc/k<00ol0003oVIVIoiVIV@03oiVIV@03o`000?moOgooOgmo00;oOgmo
00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C004oda<C003o`000?lc<c?o<c<c00;o<c<c
00?o0000oda<C?m<C4`01?m<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Go0000oiVIVOnI
VIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0
003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc
<c<01?l0003oC4a<oda<C?l00002ofIVIP06o`000?moOgooOgmoo`000?nIVIWo00000_nc/k<00ol0
003oc<c<olc<c007olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Go0000ogmoOol0003oIVIVo`00
0002oda<C003o`000?lc<c?o<c<c00Ko<c<c00So0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`00
00;oVIVI00?o0000ok>c/ol000002Oo<c<`02ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIV
o`000?m<C4co000000Ko<c<c1_ooool1o`00007ooooo0Oooool001Wooooo1Ol00006ooooo`03o`00
0?oooooooooo00?ooooo3?nc/k<00ol0003oVIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo00OoOgmo
00?o0000ofIVI_mVIVH03?mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV
00?o0000ogmoOomoOgl02?moOgl2o`0000WoVIVI00?o0000ok>c/onc/k<05Onc/k<00ol0003oVIVI
oiVIV@03oiVIV@03o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<
oda<C004oda<C003o`000?lc<c?o<c<c00;o<c<c00?o0000oda<C?m<C4`01?m<C4`01Ol0003oIVIV
ofIVI_mVIVKo000000?oOgmo00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<
00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKo
IVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP06o`00
0?moOgooOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c007olc<c004o`000?nc/k?o/k>c
o`0000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00So
0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000;oVIVI00?o0000ok>c/ol000002Oo<c<`02ol0
003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co000000Ko<c<c1_ooool1o`00007o
oooo0Oooool001Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo00?o
oooo2onc/k<00ol0003oVIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mV
IVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomo
Ogl02?moOgl00ol0003oVIVIoiVIV@08oiVIV@03o`000?nc/k?o/k>c01Go/k>c00?o0000oiVIVOnI
VIT00onIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<
C4`01?m<C4`00ol0003o<c<coc<c<`02oc<c<`03o`000?m<C4coC4a<00GoC4a<00Co0000ofIVI_mV
IVKo00000omoOgl01Ol0003oVIVIoiVIVOnIVIWo000000Co/k>c00?o0000olc<c?o<c<`01_o<c<`0
1Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01Ol0003oC4a<
oda<C?m<C4co000000So<c<c00Co0000oda<C?m<C4co00000_mVIVH01_l0003oOgmoogmoOol0003o
VIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@05o`00
0?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`00
00;oIVIV0_l00002oiVIV@03o`000?nc/k?o000000Woc<c<00Oo0000ok>c/ol0003oVIVIo`000?mo
Ogoo000000;oIVIV0_l00007oc<c<`Kooooo0Ol00001ooooo`7ooooo000Jooooo`03oiRHV?lQ8B7o
k^k^00Oooooo00?o0000ooooooooool00oooool:ok>c/`03o`000?nIVIWoVIVI00_oVIVI0_l0000:
ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;
ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02?nIVIT00ol0003o/k>cok>c/`0E
ok>c/`03o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP02
ofIVIP03o`000?m<C4coC4a<00GoC4a<00?o0000oc<c<olc<c<00_lc<c<00ol0003oC4a<oda<C004
oda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`00
0?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000003oiVIV@03o`000?moOgoo000000?o
IVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Ko0000
ogmoOomoOgoo0000oiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Ko0000ok>c/onc/k?o
0000oiVIVOl00002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02?l0
003oC4a<oda<C?l0003oIVIVo`000?moOgoo00000_nIVIT00ol0003o/k>co`000008olc<c00<o`00
0?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co00001olc<c<6ooooo`7o0000
0Oooool1ooooo`006oooool00onHV9So8B4Qonk^kP06ooooo`?o00000oooool9ok>c/`03o`000?nI
VIWoVIVI00coVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<
C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`;o00002_nI
VIT00ol0003o/k>cok>c/`0Dok>c/`03o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl00omo
Ogl00ol0003oIVIVofIVIP02ofIVIP03o`000?m<C4coC4a<00GoC4a<00?o0000oc<c<olc<c<00_lc
<c<00ol0003oC4a<oda<C004oda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01?l0003oVIVI
oiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000003oiVI
V@03o`000?moOgoo000000?oIVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`04o`000?m<C4co
C4a<o`0000;oIVIV00Ko0000ogmoOomoOgoo0000oiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Ko
c<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000
oc<c<olc<c<01_lc<c<02?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo00000_nIVIT00ol0003o
/k>co`000008olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co
00001olc<c<4ooooo`?o00000_ooool001cooooo00?oMgMgofIVI_ooool01Oooool00ol0003ooooo
ooooo`03ooooo`So/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`07ogmoO`;o0000
3OmVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl0
2?moOgl00ol0003oVIVIoiVIV@09oiVIV@03o`000?nc/k?o/k>c01Go/k>c00?o0000oiVIVOnIVIT0
0onIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`0
1Om<C4`00ol0003o<c<coc<c<`02oc<c<`03o`000?m<C4coC4a<00CoC4a<00Go0000ofIVI_mVIVKo
IVIVo`000003ogmoO`04o`000?nIVIWoVIVIo`0000Go/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0
003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo00000om<
C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Co0000ogmoOomoOgoo
00000_nIVIT01?l0003o/k>cok>c/ol00009olc<c003o`000?nc/k?o/k>c00;o00000_moOgl00ol0
003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4coC4a<0_l00000
1OmoOgoo0000oiVIVOnIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>co`00
0?nIVIWo000000;oOgmo0_l000000om<C4co0000oc<c<`07oc<c<`Kooooo0Ol00001ooooo`7ooooo
000Mooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool7ok>c/`03o`000?nI
VIWoVIVI00_oVIVI0_l00009ogmoO`03o`000?mVIVKoIVIV00_oIVIV0_l0000Hoda<C003o`000?mV
IVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@09oiVIV@03o`000?nc
/k?o/k>c01Go/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mV
IVKoIVIV00;oIVIV0_l00007oda<C005o`000?lc<c?o<c<coc<c<ol000001_m<C4`01Ol0003oIVIV
ofIVI_mVIVKo000000?oOgmo00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<
00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Go
0000oda<C?m<C4coC4a<o`000008oc<c<`;o00000_m<C4`01_l0003oIVIVofIVI_l0003oOgmoo`00
00;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo
00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`08o`000?m<C4coC4a<o`000?mV
IVKo0000ogmoOol00002oiVIV@03o`000?nc/k?o000000Soc<c<00co0000ok>c/onc/k?o0000oiVI
VOl0003oOgmoo`000?mVIVKo0000oda<C?l00008oc<c<`Kooooo0Ol00001ooooo`7ooooo000Ioooo
o`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`03ooooo`Ko/k>c00?o0000
oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00[oIVIV00?o0000
oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo0_l0000;
oiVIV@03o`000?nc/k?o/k>c01Go/k>c00?o0000oiVIVOnIVIT00onIVIT01Ol0003oOgmoogmoOomo
Ogoo000000GoIVIV00?o0000oda<C?m<C4`01_m<C4`01Ol0003o<c<coc<c<olc<c?o000000KoC4a<
00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0
003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl0
1?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<
o`000002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`01_l0003o
/k>cok>c/ol0003oVIVIo`0000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06
oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVIV@03o`000?nc/k?o000000So
c<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00008oc<c<`Ko
oooo0Ol00001ooooo`7ooooo000;ooooo`?o000000?o410@ooooooooool02?ooool01OnHV9So410@
o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool00oooool5ok>c/`03o`000?nIVIWoVIVI00_o
VIVI00?o0000ogmoOomoOgl02?moOgl2o`0000coIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003o
IVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02_nIVIT00ol0003o
/k>cok>c/`0Eok>c/`03o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003o
IVIVofIVIP02ofIVIP03o`000?m<C4coC4a<00KoC4a<00Go0000oc<c<olc<c?o<c<co`000006oda<
C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01Ol0003oVIVIoiVIVOnIVIWo000000Co/k>c00?o
0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo
00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;o
C4a<00Go0000ofIVI_l0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Woc<c<00Ko0000
ok>c/onc/k?o0000oiVIVOl00002ogmoO`06o`000?mVIVKoIVIVo`000?m<C4co00002?lc<c<01_l0
003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00Go0000oiVIVOl0003o/k>co`000009olc<c009o`00
0?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<0
0ol0003oooooooooo`03ooooo`7o00000Oooool1ooooo`003Oooool00ol@413o^[Zjooooo`0Doooo
o`03o`000?oooooooooo00?ooooo1?nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo
00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV
00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0:oiVIV@03o`000?nc/k?o/k>c
01Co/k>c0_l00005oiVIV@03o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0
003oC4a<oda<C005oda<C0;o00000_lc<c<00ol0003oC4a<oda<C005oda<C005o`000?mVIVKoIVIV
ofIVI_l000000omoOgl01?l0003oVIVIoiVIVOl00005ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o
0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000?o
C4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o0000ogmo
Ool000000_nIVIT01?l0003o/k>cok>c/ol00009olc<c006o`000?nc/k?o/k>co`000?nIVIWo0000
0_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Oo0000oda<C?m<C4co
0000ofIVI_l0003oOgmo00;o000000CoVIVIo`000?nc/k?o00002Oo<c<`02Ol0003o/k>co`000?nI
VIWo0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00?o0000oooooooo
ool00oooool1o`00007ooooo0Oooool000gooooo00?oV9RHoc8b<_ooool05?ooool00ol0003ooooo
ooooo`03ooooo`?o/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`00
0?mVIVKoIVIV00[oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`00
0?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02_nIVIT00ol0003o/k>cok>c/`0Eok>c/`03o`00
0?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP03ofIVIP03o`00
0?m<C4coC4a<00GoC4a<00Go0000oda<C?l0003o<c<co`000007oda<C005o`000?mVIVKoIVIVofIV
I_l000000omoOgl01?l0003oVIVIoiVIVOl00005ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000
ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<
00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o0000ogmoOol0
00000_nIVIT01?l0003o/k>cok>c/ol00009olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_mo
Ogl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00So0000oda<C?m<C4co0000
ofIVI_l0003oOgmoo`0000;oVIVI00?o0000ok>c/ol000002Oo<c<`02Ol0003o/k>co`000?nIVIWo
0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00?o0000ooooooooool0
0oooool1o`00007ooooo0Oooool000gooooo00?ogMgMo`000?nj^[X05?ooool00ol0003ooooooooo
o`03ooooo`?o/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mV
IVKoIVIV00[oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?mo
OgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02_nIVIT00ol0003o/k>cok>c/`0Dok>c/`03o`000?nI
VIWoVIVI00CoVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<
C4coC4a<00KoC4a<00Co0000oda<C?m<C4co00001om<C4`00ol0003oIVIVofIVIP02ofIVIP04o`00
0?moOgooOgmoo`0000?oVIVI00?o0000ok>c/onc/k<00_nc/k<00ol0003oc<c<olc<c005olc<c003
o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00004
oda<C003o`000?lc<c?o<c<c00Ko<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo
00?o0000oiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c009o`000?nc/k?o/k>cok>c/ol0
003oVIVIo`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<02?l0003oC4a<oda<
C?l0003oIVIVo`000?moOgoo00000_nIVIT00ol0003o/k>co`000008olc<c003o`000?nc/k?o0000
00;oVIVI00Oo0000ogmoOol0003oIVIVo`000?m<C4co000000Wo<c<c00?o0000ooooooooool00ooo
ool1o`00007ooooo0Oooool000gooooo00?oEEEEogMgMom4A4@05?ooool00ol0003oooooooooo`03
ooooo`;o/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKo
IVIV00[oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?moOgoo
Ogmo00SoOgmo00?o0000oiVIVOnIVIT02_nIVIT00ol0003o/k>cok>c/`0Eok>c/`03o`000?nIVIWo
VIVI00CoVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4co
C4a<00GoC4a<00?o0000oc<c<ol000002Om<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Co
0000oiVIVOnIVIWo00001Onc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c
00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c
00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000
ok>c/onc/k?o00002?o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Go0000ogmoOol0003o
IVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH2o`00
00;oVIVI00?o0000ok>c/ol000002Oo<c<`01ol0003o/k>co`000?nIVIWo0000ogmoOol000000_mV
IVH00ol0003oC4a<o`000008oc<c<`03o`000?oooooooooo00Cooooo0Ol00001ooooo`7ooooo000<
ooooo`05omgMgOl@413oooooob4Q8OoMgMd04oooool00ol0003oooooooooo`03ooooo`03ok>c/ol0
003oVIVI00_oVIVI0_l0000:ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<
C4`00ol0003oIVIVofIVIP0;ofIVIP;o00002OmoOgl2o`0000coVIVI00?o0000ok>c/onc/k<05Onc
/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH00omV
IVH00ol0003oC4a<oda<C006oda<C004o`000?lc<c?o<c<co`0000OoC4a<00Go0000ofIVI_mVIVKo
IVIVo`000003ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0003oc<c<olc<c005olc<
c003o`000?nc/k?o/k>c00;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`04o`000?mVIVKo
IVIVo`0000?oC4a<00?o0000oc<c<olc<c<01Olc<c<2o`0000?oC4a<00?o0000ofIVI_l000000_mo
Ogl01?l0003oVIVIoiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Wo0000ok>c/onc/k?o
/k>co`000?nIVIWo0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`08o`000?m<
C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVIV@03o`000?nc/k?o000000Soc<c<00co0000ok>c
/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00009oc<c<`03o`000?oooooooooo
00Cooooo0Ol00001ooooo`7ooooo000<ooooo`05ofIVI_n7QhOooooooiRHV?mEEED04oooool2o`00
00Cooooo00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV
00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo
00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Eok>c/`03o`000?nIVIWoVIVI
00?oVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<
00KoC4a<00Co0000oc<c<olc<c?o00001_m<C4`00ol0003oIVIVofIVIP02ofIVIP05o`000?moOgoo
OgmoogmoOol000000onIVIT00ol0003o/k>cok>c/`02ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o
0000ok>c/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo
00000om<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00?o0000ofIVI_l0
00000_moOgl01?l0003oVIVIoiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Wo0000ok>c
/onc/k?o/k>co`000?nIVIWo0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`03
o`000?m<C4co000000;oIVIV00?o0000ogmoOol000000_nIVIT00ol0003o/k>co`000008olc<c00<
o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co00002Olc<c<00ol0003o
ooooooooo`03ooooo`;o00000_ooool000_ooooo00?ok^k^o`000?o^k^h00_ooool00ol0003ogMgM
ooooo`0Aooooo`03o`000?oooooooooo00?ooooo3?nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`00
0?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`00
0?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Eok>c/`03o`00
0?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP03ofIVIP03o`00
0?m<C4coC4a<00SoC4a<0_l00007oda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01Ol0003o
VIVIoiVIVOnIVIWo000000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c
/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc
<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP03o`000?moOgoo000000;oVIVI
00Co0000ok>c/onc/k?o00002?o<c<`02Ol0003o/k>cok>c/onc/k?o0000oiVIVOl0003oOgmoo`00
0002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00So0000oda<C?m<C4co0000ofIVI_l0003oOgmo
o`0000;oVIVI00Co0000ok>c/onc/k?o00001oo<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?mo
Ogoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00?o0000oda<C?ooool01Oooool1
o`00007ooooo0Oooool000_ooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`0@
ooooo`03o`000?oooooooooo00?ooooo2onIVIT2o`0000[oOgmo00?o0000ofIVI_mVIVH02omVIVH0
0ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl2
o`0000goVIVI00?o0000ok>c/onc/k<05Onc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgoo
Ogmo00?oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C009oda<C003o`000?m<C4co
C4a<00KoC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`05o`000?nIVIWoVIVIoiVIVOl00000
1?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo
00000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0
003oC4a<oda<C?l00002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o0000
2?o<c<`02Ol0003o/k>cok>c/onc/k?o0000oiVIVOl0003oOgmoo`000002ofIVIP04o`000?m<C4co
C4a<o`0000So<c<c00So0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000;oVIVI00?o0000ok>c
/ol000002?o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003
o`000?lc<c?o<c<c00Ko<c<c00?o0000oda<C?l000001Oooool1o`00007ooooo0Oooool002Cooooo
00?o0000ooooooooool00oooool:oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH0
2omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl0
2OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Go/k>c00?o0000oiVIVOnIVIT0
1OnIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`0
4om<C4`01?l0003oIVIVofIVI_l00004ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0
003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl0
1Ol0003oIVIVofIVI_mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<
C?l00002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`02Ol0
003o/k>cok>c/onc/k?o0000oiVIVOl0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So
<c<c00So0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000;oVIVI00?o0000ok>c/ol000002?o<
c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o
<c<c00Ko<c<c00?o0000oda<C?l000001Oooool1o`00007ooooo0Oooool002Cooooo00?o0000oooo
ooooool00oooool9oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0
003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0
003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0
003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<C4`04_m<C4`01Ol0
003oIVIVofIVI_mVIVKo000000?oOgmo00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<
c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`05o`00
0?mVIVKoIVIVofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`00
00;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01?l0003o/k>cok>c/ol00008olc<c007o`000?nc
/k?o/k>cok>c/ol0003oVIVIo`000002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc
<c<01_lc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00Go0000oiVIVOl0003o/k>co`00
0009olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c
<olc<c<01_lc<c<00ol0003oC4a<o`000006ooooo`7o00000Oooool1ooooo`009?ooool00ol0003o
ooooooooo`03ooooo`SoVIVI00?o0000ogmoOomoOgl02?moOgl2o`0000goIVIV00?o0000oda<C?m<
C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo0_l0000=oiVIV@03
o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`03ogmoO`03
o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`04_m<C4`01Ol0003oIVIVofIVI_mVIVKo0000
00?oOgmo00Go0000oiVIVOnIVIWoVIVIo`000005ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000
ok>c/onc/k<00_nc/k<2o`0000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH00ol0003oC4a<oda<
C002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH01_l0003oOgmo
ogmoOol0003oVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002
oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<02?l0003oC4a<oda<
C?l0003oIVIVo`000?moOgoo00000_nIVIT00ol0003o/k>co`000009olc<c009o`000?nc/k?o0000
oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<00ol0003oC4a<
o`000006ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`OoVIVI00?o
0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o
0000ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o
0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@05oiVIV@03o`000?moOgooOgmo00?oOgmo00?o
0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C00Aoda<C003o`000?mVIVKoIVIV00;oIVIV00Go
0000ogmoOomoOgooOgmoo`000003oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`0
1?o<c<`00ol0003o/k>cok>c/`02ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01?l0003o
IVIVofIVI_l00004oda<C003o`000?lc<c?o<c<c00Go<c<c00Go0000oda<C?m<C4coC4a<o`000002
ofIVIP06o`000?moOgooOgmoo`000?nIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c004o`00
0?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00008oc<c
<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVIV@03o`000?nc/k?o000000Woc<c<
00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06
oc<c<`03o`000?m<C4co000000Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo
00?ooooo1_nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<
C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP;o00002_moOgl00ol0003oVIVIoiVIV@0;oiVI
V@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT01OnIVIT00ol0003oOgmoogmoO`03ogmo
O`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`04_m<C4`01Ol0003oIVIVofIVI_mVIVKo
000000?oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`02ok>c/`03o`000?o<c<co
c<c<00Coc<c<00?o0000ok>c/onc/k<00_nc/k<00ol0003oVIVIoiVIV@02oiVIV@04o`000?moOgoo
Ogmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`000007oc<c<`05o`000?m<C4coC4a<oda<C?l0
00000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Co0000
ok>c/onc/k?o00000onIVIT2o`0000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<02?l0003oC4a<
oda<C?l0003oIVIVo`000?moOgoo00000_nIVIT00ol0003o/k>co`000009olc<c009o`000?nc/k?o
0000oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003o
C4a<o`000?mVIVH6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`Go
VIVI00?o0000ogmoOomoOgl02?moOgl2o`0000goIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003o
IVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02_nIVIT2o`0001So
/k>c00?o0000oiVIVOnIVIT01OnIVIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00?o
IVIV00?o0000oda<C?m<C4`04Om<C4`00ol0003oIVIVofIVIP02ofIVIP05o`000?moOgooOgmoogmo
Ool000000onIVIT00ol0003o/k>cok>c/`02ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c
/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo00000om<
C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01_l0003oOgmo
ogmoOol0003oVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002
oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<02_l0003oC4a<oda<
C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00co0000
ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00009oc<c<`05o`000?m<C4co
0000ofIVI_l000001Oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool4
oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH03?mVIVH00ol0003oC4a<oda<C00F
oda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl2o`0000coVIVI00?o0000
ok>c/onc/k<06?nc/k<00ol0003oVIVIoiVIV@05oiVIV@03o`000?moOgooOgmo00;oOgmo00?o0000
ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00Boda<C005o`000?mVIVKoIVIVofIVI_l000001?mo
Ogl01Ol0003oVIVIoiVIVOnIVIWo000000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>c
ok>c/`02ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00003oda<
C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000omVIVH01_l0003oOgmoogmoOol0
003oVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@03
o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<02_l0003oC4a<oda<C?l0003o
IVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00co0000ok>c/onc
/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00009oc<c<`05o`000?m<C4co0000ofIV
I_l000001Oooool1o`00007ooooo0Oooool002Cooooo0_l00004ooooo`?oVIVI00?o0000ogmoOomo
Ogl02OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mV
IVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc
/k<06?nc/k<00ol0003oVIVIoiVIV@05oiVIV@03o`000?moOgooOgmo00?oOgmo00?o0000ofIVI_mV
IVH00omVIVH00ol0003oC4a<oda<C00Aoda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomo
OgooOgmoo`000003oiVIV@03o`000?nc/k?o/k>c00;o/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0
003o/k>cok>c/`02ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01?l0003oIVIVofIVI_l0
0004oda<C003o`000?lc<c?o<c<c00Go<c<c00Go0000oda<C?m<C4coC4a<o`000003ofIVIP05o`00
0?moOgoo0000oiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`00
00;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`08o`000?m<C4co
C4a<o`000?mVIVKo0000ogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Wo0000ok>c
/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`05o`00
0?m<C4co0000ofIVI_l000001Oooool2o`0000;ooooo000Tooooo`03o`000?oooooooooo00?ooooo
0_nIVIT00ol0003oOgmoogmoO`08ogmoO`;o00003OmVIVH00ol0003oC4a<oda<C00Foda<C003o`00
0?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`00
0?nc/k?o/k>c01Oo/k>c0_l00007oiVIV@03o`000?moOgooOgmo00?oOgmo00?o0000ofIVI_mVIVH0
0omVIVH00ol0003oC4a<oda<C00Boda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01Ol0003o
VIVIoiVIVOnIVIWo000000Go/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c
/`04o`000?nIVIWoVIVIo`0000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000003oda<C003o`000?lc
<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP03o`000?moOgoo000000;oVIVI
00Co0000ok>c/onc/k?o00002Oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo0000
00;oIVIV00Co0000oda<C?m<C4co00002?lc<c<02Ol0003oC4a<oda<C?l0003oIVIVo`000?moOgoo
0000oiVIV@02o`000003ok>c/ol0003oc<c<00Ooc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003o
Ogmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4co0000ofIVI_l0
00001_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool2oiVIV@03o`00
0?moOgooOgmo00OoOgmo00?o0000ofIVI_mVIVH03?mVIVH00ol0003oC4a<oda<C00Foda<C003o`00
0?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl2o`0000coVIVI00?o0000ok>c/onc/k<0
6?nc/k<00ol0003oVIVIoiVIV@06oiVIV@03o`000?moOgooOgmo00?oOgmo00?o0000ofIVI_mVIVH0
0omVIVH00ol0003oC4a<oda<C00Aoda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgoo
Ogmoo`000003oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`01Oo<c<`01Ol0003o
/k>cok>c/onc/k?o000000?oVIVI00Co0000ogmoOomoOgoo00000omVIVH01Ol0003oC4a<oda<C?m<
C4co000000So<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP03o`000?moOgoo000000;oVIVI
00Co0000ok>c/onc/k?o00002Oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo0000
00;oIVIV00Co0000oda<C?m<C4co00002?lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo
0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0
003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4co0000ofIV
I_l000001_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool00onIVIWo
0000ogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003o
IVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o
/k>cok>c/`0Hok>c/`03o`000?nIVIWoVIVI00KoVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003o
IVIVofIVIP03ofIVIP03o`000?m<C4coC4a<01;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmo
O`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c004olc<
c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000omoOgl01?l0003oIVIVofIVI_l0
0003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP03o`00
0?moOgoo000000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c004o`000?nc/k?o/k>co`00
00;oVIVI00Ko0000ogmoOomoOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00[o
0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c007
olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc
<c<01_lc<c<00ol0003oC4a<oda<C002o`000003ogmoOooooooooooo00Cooooo0Ol00001ooooo`7o
oooo000Tooooo`03o`000?oooooooooo00?ooooo00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIV
ofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmo
ogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<06?nc/k<00ol0003oVIVI
oiVIV@06oiVIV@03o`000?moOgooOgmo00?oOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<
oda<C00Boda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgooOgmoo`000003oiVIV@03
o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`02ok>c/`05
o`000?nIVIWoVIVIoiVIVOl000000_moOgl00ol0003oIVIVofIVIP02o`0000?oC4a<00?o0000oc<c
<olc<c<01_lc<c<01ol0003oC4a<oda<C?m<C4co0000ofIVI_l000000_moOgl01?l0003oVIVIoiVI
VOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT01Ol0003o
Ogmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01olc<c<02_l0003oC4a<oda<C?l0003o
IVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Wo0000ok>c/ol0
003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`06o`000?m<
C4co0000ofIVI_l0003oOgmo1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool0
0oooool:ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIV
ofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo0_l0000<oiVIV@03o`000?nc/k?o/k>c01So/k>c
00?o0000oiVIVOnIVIT01_nIVIT00ol0003oOgmoogmoO`04ogmoO`03o`000?mVIVKoIVIV00?oIVIV
00?o0000oda<C?m<C4`04_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000CoOgmo00Go0000oiVIVOnI
VIWoVIVIo`000005ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00_nc/k<01Ol0
003oVIVIoiVIVOnIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c
<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00?o0000ofIVI_l000000_moOgl01?l0003oVIVIoiVI
VOl00003ok>c/`03o`000?o<c<coc<c<00Goc<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo0000
00;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`0:o`000?m<C4coC4a<
o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01oo<c<`02ol0003o
/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co000000Wo<c<c00Oo0000oda<C?l0003o
IVIVo`000?moOgoo000000Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?o
oooo2?moOgl2o`0000goIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03
o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Hok>c/`03
o`000?nIVIWoVIVI00KoVIVI00?o0000ogmoOomoOgl01?moOgl00ol0003oIVIVofIVIP03ofIVIP03
o`000?m<C4coC4a<01;oC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo0000
00?oVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c
00;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o
0000oc<c<olc<c<01_lc<c<01ol0003oC4a<oda<C?m<C4co0000ofIVI_l000000omoOgl01?l0003o
VIVIoiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT0
1Ol0003oOgmoo`000?mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<02_l0003oC4a<oda<
C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Wo0000
ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`05
o`000?m<C4co0000ofIVI_l000000_moOgl00ol0003oooooooooo`03ooooo`7o00000Oooool1oooo
o`009?ooool00ol0003oooooooooo`03ooooo`OoOgmo00?o0000ofIVI_mVIVH02omVIVH2o`0001So
C4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_o
VIVI00?o0000ok>c/onc/k<06?nc/k<00ol0003oVIVIoiVIV@06oiVIV@03o`000?moOgooOgmo00Co
Ogmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00Boda<C003o`000?mVIVKoIVIV00;o
IVIV00Go0000ogmoOomoOgooOgmoo`000003oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<
c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl0
1?l0003oIVIVofIVI_l00003oda<C0;o00001olc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV
00Co0000ogmoOomoOgoo00000_nIVIT01?l0003o/k>cok>c/ol00008olc<c007o`000?nc/k?o/k>c
ok>c/ol0003oVIVIo`000002ogmoO`03o`000?mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc
<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<co
c<c<00Koc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0
003o<c<coc<c<`06oc<c<`07o`000?m<C4co0000ofIVI_l0003oOgmoo`000006ooooo`7o00000Ooo
ool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`OoOgmo00?o0000ofIVI_mVIVH02_mVIVH0
0ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl2
o`0000coVIVI00?o0000ok>c/onc/k<06?nc/k<00ol0003oVIVIoiVIV@07oiVIV@03o`000?moOgoo
Ogmo00CoOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00Boda<C003o`000?mVIVKo
IVIV00;oIVIV00Go0000ogmoOomoOgooOgmoo`000003oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o
0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`05o`000?nIVIWoVIVIoiVIVOl00000
0_moOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<
C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002?o<
c<`01ol0003o/k>cok>c/onc/k?o0000oiVIVOl000000_moOgl00ol0003oIVIVo`000003oda<C003
o`000?lc<c?o<c<c00Ko<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000
0_nc/k<00ol0003oc<c<olc<c006olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003o
IVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01ol0003oC4a<o`000?mVIVKo0000ogmoOol0
00001_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool5ogmoO`;o0000
3?mVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl0
2?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01So/k>c00?o0000oiVIVOnIVIT0
1onIVIT00ol0003oOgmoogmoO`04ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<C4`0
4om<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Go0000oiVIVOnIVIWoVIVIo`000006ok>c
/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo
000000;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<
C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@04o`000?nc/k?o/k>co`00
00Woc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000;oC4a<
00?o0000oc<c<olc<c<01_lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0
0003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIV
I_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`03o`000?m<C4co000000;oIVIV0_l000000onI
VIWoooooooooo`04ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`Co
Ogmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00_o
IVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01So
/k>c00?o0000oiVIVOnIVIT01onIVIT00ol0003oOgmoogmoO`04ogmoO`03o`000?mVIVKoIVIV00?o
IVIV00?o0000oda<C?m<C4`04om<C4`01Ol0003oIVIVofIVI_mVIVKo000000CoOgmo00Go0000oiVI
VOnIVIWoVIVIo`000005ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00onc/k<0
1?l0003oVIVIoiVIVOl00002ogmoO`05o`000?mVIVKoIVIVofIVI_l000000om<C4`00ol0003o<c<c
oc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVI
V@04o`000?nc/k?o/k>co`0000Woc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`05o`00
0?mVIVKo0000o`000?m<C4`00_l00008oc<c<`09o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0
003oVIVI00;o000000?o/k>co`000?o<c<`01oo<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?mo
Ogoo0000ofIVI_l0003oC4a<o`0000Wo<c<c00So0000oda<C?l0003oIVIVo`000?moOgoo0000oiVI
V@Kooooo0Ol00001ooooo`7ooooo000Tooooo`;o00001?ooool4ogmoO`03o`000?mVIVKoIVIV00[o
IVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00So
Ogmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00So
VIVI00?o0000ogmoOomoOgl01?moOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<01?o
C4a<00Go0000ofIVI_mVIVKoIVIVo`000004ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001Onc/k<0
0ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Co0000oiVIVOnIVIWo00000_mo
Ogl01Ol0003oIVIVofIVI_mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<
oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01?l0003o/k>cok>c/ol00009
olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP04o`000?m<C4coC4a<o`00
00Wo<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003o
c<c<olc<c006olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co
00002Olc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000004ooooo`;o00000_oo
ool002Cooooo00?o0000ooooooooool00oooool3ogmoO`03o`000?mVIVKoIVIV00[oIVIV00?o0000
oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000
oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00SoVIVI00?o0000
ogmoOomoOgl01?moOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000
ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000?oVIVI00?o0000ok>c/onc/k<01?nc
/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00;o/k>c00Go0000oiVIVOnIVIWoVIVI
o`000002ogmoO`05o`000?mVIVKoIVIVofIVI_l000000om<C4`00ol0003o<c<coc<c<`05oc<c<`03
o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl00ol0003oVIVIo`000003ok>c
/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o/k>c0_l00002ogmoO`04o`000?mVIVKo
IVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01_l0003oC4a<oda<C?m<C4co0000ofIVIP;o
00000_nIVIT01?l0003o/k>cok>c/ol00008olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmo
Ool0003oIVIVo`000?m<C4co00002Olc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVI
o`000005ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`;oOgmo00?o
0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00coIVIV00?o
0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o
0000oiVIVOnIVIT02?nIVIT00ol0003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o
0000oda<C?m<C4`04om<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00?o0000oiVIVOnIVIT0
0_nIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<0
0onc/k<01?l0003oVIVIoiVIVOl00002ogmoO`05o`000?mVIVKoIVIVofIVI_l000000om<C4`00ol0
003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol0
0002oiVIV@04o`000?nc/k?o/k>co`0000Woc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmo
O`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01olc<c<02_l0003oC4a<oda<C?l0003o
IVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Wo0000ok>c/ol0
003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`03o`000?m<
C4coC4a<00;o000000CoOgmoo`000?nIVIWo00001_ooool1o`00007ooooo0Oooool002Cooooo00?o
0000ooooooooool00oooool00omoOgoo0000ofIVIP0<ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o
0000ofIVI_mVIVH02omVIVH2o`0000WoOgmo0_l0000=oiVIV@03o`000?nc/k?o/k>c01Ko/k>c0_l0
000:oiVIV@;o00001_moOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o
0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000?oVIVI00?o0000ok>c/onc/k<0
1?nc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00;o/k>c00Go0000oiVIVOnIVIWo
VIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0
003oC4a<oda<C?m<C4co000000;oIVIV00Ko0000ogmoOol0003o0000oiVIVOl00003ok>c/`03o`00
0?o<c<coc<c<00Koc<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo00?o0000ofIV
I_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0;o`000?m<C4coC4a<oda<C?l0003oIVIVo`00
0?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c009o`000?nc/k?o0000oiVI
VOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02Ol0003oC4a<o`00
0?mVIVKo0000ogmoOol0003oVIVIo`000006ooooo`7o00000Oooool1ooooo`009?ooool00ol0003o
ooooooooo`03ooooo`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003o
IVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o
/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00WoVIVI00?o0000ogmoOomoOgl01_moOgl00ol0003o
IVIVofIVIP03ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003o
OgmoogmoOomoOgoo000000?oVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c004olc<
c003o`000?nc/k?o/k>c00;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`04o`000?mVIVKo
IVIVo`0000CoC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP04o`00
0?moOgooOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c004o`000?nc/k?o/k>c
o`0000;oVIVI00Ko0000ogmoOomoOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c
00_o0000oda<C?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<
c<coc<c<00Ooc<c<00_o0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`000009
oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000Kooooo0Ol00001ooooo`7o
oooo000Tooooo`03o`000?oooooooooo00?ooooo3OmVIVH00ol0003oC4a<oda<C00Foda<C003o`00
0?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`00
0?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02OnIVIT00ol0003oOgmoogmoO`06ogmoO`03o`00
0?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<C4`04om<C4`00ol0003oIVIVofIVIP02ofIVIP05o`00
0?moOgooOgmoogmoOol000000onIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00Co
c<c<00?o0000ok>c/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Co0000ofIV
I_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mV
IVH00ol0003oOgmoo`000002oiVIV@03o`000?nc/k?o/k>c00;o/k>c00?o0000olc<c?o<c<`01Oo<
c<`01ol0003o/k>cok>c/onc/k?o0000oiVIVOl000000_moOgl00ol0003oIVIVo`000002oda<C003
o`000?lc<c?o<c<c00Oo<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000
0_nc/k<00ol0003oc<c<olc<c007olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo
000000;oC4a<00?o0000oc<c<olc<c<01olc<c<01?l0003oC4a<o`000?l00002ogmoO`;o000000?o
/k>cooooooooool01?ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool<
ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08
ogmoO`;o00003OnIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00[oVIVI00?o0000
ogmoOomoOgl01OmoOgl00ol0003oIVIVofIVIP04ofIVIP03o`000?m<C4coC4a<01;oC4a<00?o0000
ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000CoVIVI00?o0000ok>c/onc/k<00onc
/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Co0000oiVIVOnIVIWo0000
0omoOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00?o0000oda<C?m<
C4`00_m<C4`01_l0003oIVIVofIVI_l0003oOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`00
0008olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Ko0000ogmoOomoOgoo0000ofIVI_l00002oda<
C003o`000?lc<c?o<c<c00Oo<c<c00?o0000oda<C?l000000_mVIVH01Ol0003oOgmoo`000?nIVIWo
000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo
0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00?o0000oda<C?m<C4`00_l000001Omo
Ogoo0000oiVIVOl0003o/k>c00Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo
00?ooooo2omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmo
OomoOgl02OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVI
VOnIVIT02onIVIT00ol0003oOgmoogmoO`04ogmoO`03o`000?mVIVKoIVIV00CoIVIV00?o0000oda<
C?m<C4`04om<C4`00ol0003oIVIVofIVIP02ofIVIP05o`000?moOgooOgmoogmoOol000001?nIVIT0
0ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00onc/k<0
1?l0003oVIVIoiVIVOl00002ogmoO`05o`000?mVIVKoIVIVofIVI_l000000om<C4`00ol0003o<c<c
oc<c<`06oc<c<`03o`000?m<C4coC4a<00;oC4a<00Ko0000ofIVI_mVIVKo0000ogmoOol00002oiVI
V@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@06o`000?mo
OgooOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`00
00;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00[o0000
ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c
<`03o`000?m<C4coC4a<00;o000000GoOgmoo`000?nIVIWo0000ok>c/`06ooooo`7o00000Oooool1
ooooo`006oooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool00oooool:ofIV
IP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`09ogmo
O`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVI
V@03o`000?moOgooOgmo00CoOgmo00?o0000ofIVI_mVIVH01?mVIVH00ol0003oC4a<oda<C00Coda<
C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgooOgmoo`000004oiVIV@03o`000?nc/k?o
/k>c00?o/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`04o`000?nIVIWo
VIVIo`0000?oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`03o`00
0?m<C4coC4a<00;oC4a<00Ko0000ofIVI_mVIVKo0000ogmoOol00002oiVIV@05o`000?nc/k?o/k>c
ok>c/ol000002?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@06o`000?moOgooOgmoo`000?mVIVKo
00000om<C4`00ol0003o<c<coc<c<`06oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0
003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01oo<c<`02Ol0003o/k>co`000?nIVIWo0000ogmo
Ool0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Co0000oda<C?l0003oIVIV0_l0
00001OnIVIWo0000ok>c/onc/k?o000000Gooooo0Ol00001ooooo`7ooooo000Looooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool00oooool9ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o
0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`;o00003OnIVIT00ol0003o/k>cok>c
/`0Fok>c/`03o`000?nIVIWoVIVI00[oVIVI0_l00006ogmoO`03o`000?mVIVKoIVIV00GoIVIV00?o
0000oda<C?m<C4`04_m<C4`00ol0003oIVIVofIVIP03ofIVIP05o`000?moOgooOgmoogmoOol00000
0onIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<0
0onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000003oda<
C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgoo
Ogmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c004o`000?nc/k?o/k>co`0000;o
VIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`04o`000?m<C4coC4a<
o`0000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00co
0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l0000:oc<c<`;o000000Ko
IVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?oooooooooo00?ooooo0Ol00001ooooo`7o
oooo000Iooooo`Go00001_ooool3o`0000?ooooo2?mVIVH00ol0003oC4a<oda<C00Foda<C003o`00
0?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`00
0?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`04ogmoO`03o`00
0?mVIVKoIVIV00KoIVIV00?o0000oda<C?m<C4`04_m<C4`00ol0003oIVIVofIVIP03ofIVIP05o`00
0?moOgooOgmoogmoOol000000onIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00?o
c<c<00?o0000ok>c/onc/k<00onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Go0000ofIV
I_mVIVKoIVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`00
0002ofIVIP06o`000?moOgooOgmoo`000?nIVIWo00001?nc/k<00ol0003oc<c<olc<c006olc<c004
o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00008
oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`00
0?o<c<coc<c<00Koc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<
C?l0000:oc<c<`;o000000KoIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`04o`000?oooooooooo
ooooo`?o00000_ooool001Wooooo00CoA4A4omgMgOoooooo00001oooool00ol0003oooooooooo`03
ooooo`OoIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP;o00002_moOgl0
0ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT0
0ol0003oOgmoogmoO`04ogmoO`03o`000?mVIVKoIVIV00KoIVIV00?o0000oda<C?m<C4`04_m<C4`0
0ol0003oIVIVofIVIP03ofIVIP05o`000?moOgooOgmoogmoOol000000onIVIT00ol0003o/k>cok>c
/`04ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00onc/k<01Ol0003oVIVIoiVI
VOnIVIWo000000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go
<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Go0000
ok>c/onc/k?o/k>co`000008olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol00000
0_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`03o`000?m<C4co000000;oIVIV00Go0000ogmoOol0
003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Wo0000ok>c/ol0003oVIVIo`000?mo
Ogoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`04o`000?m<C4co0000ofIVIP;o
00000_nIVIT00ol0003o/k>co`000006ooooo`7o00000Oooool1ooooo`006Oooool01?oMgMgoEEEE
ooooool00007ooooo`03o`000?oooooooooo00?ooooo1_mVIVH00ol0003oC4a<oda<C00Foda<C003
o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0:oiVIV@;o
00005onc/k<2o`0000goVIVI00?o0000ogmoOomoOgl01OmoOgl00ol0003oIVIVofIVIP05ofIVIP03
o`000?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo0000
00CoVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c
00?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o
0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo
00000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT0
0ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000Wo<c<c00?o0000oda<C?l000000_mV
IVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`02Ol0003o/k>c
o`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000
oda<C?m<C4co0000ofIVIP02o`000005oiVIVOl0003o/k>cok>c/ol000001_ooool1o`00007ooooo
0Oooool001[ooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`03ooooo`GoIVIV00?o
0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo0_l0
000<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmo
O`06ogmoO`03o`000?mVIVKoIVIV00CoIVIV00?o0000oda<C?m<C4`05?m<C4`00ol0003oIVIVofIV
IP02ofIVIP05o`000?moOgooOgmoogmoOol000001?nIVIT00ol0003o/k>cok>c/`03ok>c/`03o`00
0?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00onc/k<01?l0003oVIVIoiVIVOl00003ogmoO`04
o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co
000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<
00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`00
00Wo<c<c00?o0000oda<C?l000000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000
olc<c?o<c<`01oo<c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003
o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4co0000ofIVIP02o`000005oiVIVOl0003o/k>c
ok>c/ol000001_ooool1o`00007ooooo0Oooool001[ooooo00?ok^k^odA4A?l000001oooool00ol0
003oooooooooo`03ooooo`CoIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIV
IP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c
/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl01_moOgl00ol0003oIVIVofIVIP05ofIV
IP03o`000?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo
000000CoVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o
/k>c00?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<
00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomo
Ogoo00000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Co0000ok>c/onc/k?o00000_nI
VIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000Wo<c<c00?o0000oda<C?l00000
0_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`00ol0003o
/k>co`000002oiVIV@;o000000GoIVIVo`000?m<C4coC4a<o`000009oc<c<`06o`000?m<C4co0000
ofIVI_l0003oOgmo0_l00002ok>c/`03o`000?o<c<cooooo00Gooooo0Ol00001ooooo`7ooooo000K
ooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool00oooool3ofIVIP03o`000?m<C4co
C4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWo
VIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgoo
Ogmo00KoOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<C00Coda<C003o`000?mVIVKo
IVIV00;oIVIV00?o0000ogmoOomoOgl00_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Ko/k>c00?o
0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`04ok>c/`04o`000?nIVIWoVIVIo`0000?oOgmo
00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<
C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Go
0000ok>c/onc/k?o/k>co`000002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co
00002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<0
0ol0003oc<c<olc<c006olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`00
00;oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?l0003oIVIV00;o000000KoVIVI
o`000?nc/k?o/k>co`000?o<c<`6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003ooooooooo
o`03ooooo`;oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?mo
OgooOgmo00SoOgmo0_l0000<oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02onI
VIT00ol0003oOgmoogmoO`06ogmoO`03o`000?mVIVKoIVIV00KoIVIV00?o0000oda<C?m<C4`04om<
C4`00ol0003oIVIVofIVIP02ofIVIP03o`000?moOgooOgmo00;oOgmo00Go0000oiVIVOnIVIWoVIVI
o`000006ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<01?nc/k<01?l0003oVIVI
oiVIVOl00003ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0
003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo00000_nc
/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01Ol0003oOgmo
o`000?mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIV
IP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c00:o`000?nc/k?o
/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0
003oC4a<oda<C?l0003oIVIV00;o000000KoVIVIo`000?nc/k?o/k>co`000?o<c<`6ooooo`7o0000
0Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`03ofIVI_l0003oC4a<01OoC4a<00?o
0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o
0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00KoOgmo00?o
0000ofIVI_mVIVH01_mVIVH00ol0003oC4a<oda<C00Coda<C003o`000?mVIVKoIVIV00;oIVIV00?o
0000ogmoOomoOgl00_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Ko/k>c00?o0000olc<c?o<c<`0
0oo<c<`00ol0003o/k>cok>c/`04ok>c/`04o`000?nIVIWoVIVIo`0000?oOgmo00Co0000ofIVI_mV
IVKo00001?m<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH0
1?l0003oOgmoogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Go0000ok>c/onc/k?o
/k>co`000002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<02_l0
003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Oo
c<c<00?o0000ok>c/onc/k<00_l000001omoOgoo0000ofIVI_mVIVKo0000oda<C?l000002?lc<c<0
1ol0003oC4a<oda<C?l0003oIVIVo`000?moOgl00_l00002ok>c/`03o`000?o<c<coc<c<00Kooooo
0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo00?o0000oda<C?m<C4`05_m<
C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onI
VIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl01_mo
Ogl00ol0003oIVIVofIVIP06ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH00_mV
IVH2o`0000?oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<
c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo
00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go<c<c00Go0000oda<C?m<
C4coC4a<o`000003ofIVIP03o`000?moOgoo000000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008
olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<
C4coC4a<o`0000So<c<c00Co0000oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nIVIWo0000
00;o/k>c00?o0000olc<c?o<c<`01_o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000
ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Oo0000oda<C?m<C4co0000ofIVI_l0003o
Ogmo00;o00000_nc/k<00ol0003oc<c<olc<c006ooooo`7o00000Oooool1ooooo`009?ooool00ol0
003oooooooooo`03oooooaSoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmo
O`;o00003?nIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmo
OomoOgl01omoOgl00ol0003oIVIVofIVIP05ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000ofIV
I_mVIVH00omVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c
/onc/k<00onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Go0000oiVI
VOnIVIWoVIVIo`000002ogmoO`05o`000?mVIVKoIVIVofIVI_l000000om<C4`00ol0003o<c<coc<c
<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000omVIVH00ol0003oOgmoo`000002oiVIV@05o`00
0?nc/k?o/k>cok>c/ol000002?o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmo
Ool000000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Go
0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00[o0000ok>c/onc/k?o
0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`07o`000?m<
C4coC4a<o`000?mVIVKo0000ogmoO`02o`0000;o/k>c00?o0000olc<c?o<c<`01_ooool1o`00007o
oooo0Oooool002Cooooo0_l00004oooooaOoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmo
ogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVI
oiVIV@0;oiVIV@03o`000?moOgooOgmo00OoOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<
oda<C00Doda<C003o`000?mVIVKoIVIV00;oIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVI
oiVIV@02oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>c
ok>c/`04ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<
C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002
ogmoO`04o`000?nIVIWoVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01oo<c<`01?l0003o/k>cok>c
/ol00002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<01?l0003o
C4a<oda<C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006
olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl2o`0000;oC4a<00?o0000oc<c<olc<c<0
1_lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000?oc<c<
1Oooool2o`0000;ooooo000Tooooo`03o`000?oooooooooo00?ooooo5_m<C4`00ol0003oIVIVofIV
IP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c
/`0Gok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl01omoOgl00ol0003oIVIVofIV
IP05ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH00omVIVH01Ol0003oOgmoogmo
OomoOgoo000000CoVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c003olc<c003o`00
0?nc/k?o/k>c00Co/k>c00Co0000oiVIVOnIVIWo00000omoOgl01?l0003oIVIVofIVI_l00004oda<
C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgoo
Ogmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c007o`000?nc/k?o/k>cok>c/ol0
003oVIVIo`000002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01olc<c<01_l0
003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<
c006olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000
oc<c<olc<c<01_lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>c
o`0000?oc<c<1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00ooooolEoda<
C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl2o`0000coVIVI00?o0000ok>c
/onc/k<05onc/k<00ol0003oVIVIoiVIV@0:oiVIV@;o00002OmoOgl00ol0003oIVIVofIVIP06ofIV
IP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH00omVIVH01Ol0003oOgmoogmoOomoOgoo
000000CoVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o
/k>c00Co/k>c00Co0000oiVIVOnIVIWo00000omoOgl01?l0003oIVIVofIVI_l00004oda<C003o`00
0?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`00
00;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c007o`000?nc/k?o/k>cok>c/ol0003oVIVI
o`000002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01olc<c<01_l0003oC4a<
oda<C?l0003oIVIVo`0000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<
c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc
<c<01_lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000?o
c<c<1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00ooooolDoda<C003o`00
0?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`00
0?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`00
0?mVIVKoIVIV00KoIVIV00?o0000oda<C?m<C4`05?m<C4`00ol0003oIVIVofIVIP03ofIVIP05o`00
0?moOgooOgmoogmoOol000001?nIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00?o
c<c<00?o0000ok>c/onc/k<01?nc/k<01?l0003oVIVIoiVIVOl00003ogmoO`05o`000?mVIVKoIVIV
ofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mV
IVH01?l0003oOgmoogmoOol00002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01ol0003o
/k>cok>c/onc/k?o0000oiVIVOl000000_moOgl00ol0003oIVIVo`000003oda<C003o`000?lc<c?o
<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c
00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@;o000000GoIVIVo`000?m<
C4coC4a<o`000008oc<c<`04o`000?m<C4coC4a<oda<C0;o000000KoOgmoo`000?nIVIWo0000ok>c
/ol00004olc<c0Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo4om<
C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onI
VIT00ol0003o/k>cok>c/`0Fok>c/`;o00003?nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mV
IVKoIVIV00KoIVIV00?o0000oda<C?m<C4`05?m<C4`00ol0003oIVIVofIVIP03ofIVIP03o`000?mo
OgooOgmo00;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000007ok>c/`03o`000?o<c<coc<c<00;oc<c<
0_l00005ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01Ol0003oIVIVofIVI_mVIVKo0000
00CoC4a<00?o0000oc<c<olc<c<01Olc<c<2o`0000?oC4a<00Co0000ofIVI_mVIVKo00000_moOgl0
1?l0003oVIVIoiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Oo0000ok>c/onc/k?o/k>c
o`000?nIVIWo000000;oOgmo00?o0000ofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`06
o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<co
c<c<00Koc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0
003o<c<coc<c<`06oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc
/k?o00001?o<c<`6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03oooooa;o
C4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00co
VIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00So
Ogmo00?o0000ofIVI_mVIVH01_mVIVH00ol0003oC4a<oda<C00Doda<C003o`000?mVIVKoIVIV00?o
IVIV00?o0000ogmoOomoOgl00_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Oo/k>c00?o0000olc<
c?o<c<`00_o<c<`00ol0003o/k>cok>c/`04ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl0
1Ol0003oIVIVofIVI_mVIVKo000000CoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<
C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo00000_nc/k<00ol0003o
c<c<olc<c007olc<c007o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000002ogmoO`03o`000?mVIVKo
000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo
00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c00:o`000?nc/k?o/k>co`000?nI
VIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<03?l0003oC4a<oda<
C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Coc<c<1_ooool1o`00007ooooo0Ooo
ool002Cooooo00?o0000ooooooooool00ooooolAoda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000
ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000
oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00KoIVIV00?o0000
oda<C?m<C4`05?m<C4`00ol0003oIVIVofIVIP03ofIVIP03o`000?moOgooOgmo00;oOgmo00?o0000
oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000
ok>c/onc/k<01?nc/k<01?l0003oVIVIoiVIVOl00003ogmoO`05o`000?mVIVKoIVIVofIVI_l00000
0om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003o
OgmoogmoOol00002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01Ol0003o/k>cok>c/onc
/k?o000000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`06o`00
0?m<C4coC4a<o`000?mVIVKo00000_moOgl2o`0000;o/k>c00?o0000olc<c?o<c<`01oo<c<`02_l0
003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko
<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00004olc<c0Ko
oooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo4?m<C4`00ol0003oIVIV
ofIVIP0<ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>c
ok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIV
ofIVIP06ofIVIP03o`000?m<C4coC4a<01GoC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmo
ogmoO`02ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001onc/k<00ol0003oc<c<olc<c002olc<c003
o`000?nc/k?o/k>c00Co/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`05o`000?mVIVKoIVIV
ofIVI_l000001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000
ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<
00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo00?o0000ofIVI_l000000om<C4`00ol0
003o<c<coc<c<`06oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl00ol0003oVIVIo`00
0002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Oo0000ok>c/ol0003oVIVIo`000?moOgoo000000;o
IVIV00?o0000oda<C?l000002?lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVI
VOl0003o/k>co`0000Goc<c<1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool0
0oooool?oda<C003o`000?mVIVKoIVIV00_oIVIV0_l00009ogmoO`;o00003OnIVIT00ol0003o/k>c
ok>c/`0Fok>c/`03o`000?nIVIWoVIVI00[oVIVI0_l0000:ogmoO`03o`000?mVIVKoIVIV00OoIVIV
00?o0000oda<C?m<C4`05?m<C4`00ol0003oIVIVofIVIP03ofIVIP03o`000?moOgooOgmo00;oOgmo
00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00?oc<c<
00?o0000ok>c/onc/k<01?nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Go0000ofIVI_mV
IVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0
003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<
c<`01?l0003o/k>cok>c/ol00002oiVIV@06o`000?moOgooOgmoo`000?mVIVKo00000_m<C4`00ol0
003o<c<coc<c<`07oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl00ol0003oVIVIo`00
0002ok>c/`03o`000?o<c<coc<c<00Koc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`00
0?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000
ogmoOol0003oVIVIo`000?nc/k?o00001Oo<c<`6ooooo`7o00000Oooool1ooooo`009?ooool00ol0
003oooooooooo`03ooooo`koC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`09ogmo
O`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVI
V@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02?mVIVH00ol0003oC4a<oda<C00Coda<
C003o`000?mVIVKoIVIV00?oIVIV00?o0000ogmoOomoOgl00omoOgl01Ol0003oVIVIoiVIVOnIVIWo
000000Oo/k>c00?o0000olc<c?o<c<`00_o<c<`00ol0003o/k>cok>c/`05ok>c/`05o`000?nIVIWo
VIVIoiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00005oda<C003o`000?lc<c?o<c<c00Go<c<c
00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`00
00;o/k>c00?o0000olc<c?o<c<`01oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@06o`000?moOgoo
Ogmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`07oc<c<`06o`000?m<C4coC4a<o`000?mV
IVKo00000_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00[o0000ok>c
/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0<
o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00001Oo<c<`6ooooo`7o
00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`goC4a<00?o0000ofIVI_mVIVH0
2omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<0
5_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH0
2?mVIVH00ol0003oC4a<oda<C00Doda<C003o`000?mVIVKoIVIV00?oIVIV00?o0000ogmoOomoOgl0
0_moOgl00ol0003oVIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`0
0_o<c<`00ol0003o/k>cok>c/`05ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01Ol0003o
IVIVofIVI_mVIVKo000000CoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<
C004o`000?mVIVKoIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<
c006olc<c007o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000002ogmoO`03o`000?mVIVKo000000;o
C4a<00?o0000oc<c<olc<c<01olc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00?o0000
oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c006o`000?nc/k?o/k>co`000?nIVIWo0000
0_moOgl2o`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`00
0?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00?oc<c<1_ooool1o`00007ooooo0Ooo
ool002Cooooo0_l00004ooooo`coC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08
ogmoO`;o00003OnIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000
ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP07ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000
ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000
ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c00Co/k>c00Go0000
oiVIVOnIVIWoVIVIo`000003ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<0
1_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01Ol0
003o/k>cok>c/onc/k?o000000Soc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@03o`000?mo
Ogoo000000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<01_l0003oC4a<oda<C?l0003oIVIVo`00
00;oOgmo00Go0000oiVIVOl0003o/k>co`000009olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000
ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<03?l0003oC4a<oda<C?l0003o
IVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Koc<c<1Oooool2o`0000;ooooo000Tooooo`03
o`000?oooooooooo00?ooooo2om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00Wo
Ogmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_o
VIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP07ofIVIP03o`000?m<C4coC4a<01Go
C4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00;o
VIVI00?o0000ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c00Co
/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000
oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo0000
0_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVI
V@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<01_l0003oC4a<oda<C?l0
003oIVIVo`0000;oOgmo00Go0000oiVIVOl0003o/k>co`000009olc<c00:o`000?nc/k?o/k>co`00
0?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<00ol0003oC4a<
o`000002ofIVIP07o`000?moOgoo0000oiVIVOl0003o/k>co`000006olc<c0Kooooo0Ol00001oooo
o`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo2_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03
o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03
o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP08ofIVIP03
o`000?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`02ogmoO`03
o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c002olc<c003
o`000?nc/k?o/k>c00Go/k>c00Co0000oiVIVOnIVIWo00000omoOgl01?l0003oIVIVofIVI_l00004
oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?mo
OgooOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c005o`000?nc/k?o/k>cok>c
/ol000000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000Wo<c<c00Co0000
oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`0
1_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@;o000000GoIVIVo`000?m<C4coC4a<o`000008oc<c
<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00001oo<c<`6oooo
o`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`WoC4a<00?o0000ofIVI_mV
IVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`;o00003OnIVIT00ol0003o/k>cok>c/`0Fok>c/`03
o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl2o`0000[oIVIV00?o0000oda<C?m<
C4`05?m<C4`00ol0003oIVIVofIVIP03ofIVIP03o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnI
VIT00_nIVIT00ol0003o/k>cok>c/`06ok>c/`05o`000?o<c<coc<c<olc<c?l000001onc/k<01Ol0
003oVIVIoiVIVOnIVIWo000000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc
<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`00
0?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o0000
00;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`;o00000_m<C4`0
1Ol0003oIVIVo`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`02_l0003o/k>c
ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00co
0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00007olc<c0Kooooo0Ol0
0001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo2?m<C4`00ol0003oIVIVofIVIP0<
ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0F
ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP08
ofIVIP03o`000?m<C4coC4a<01GoC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`02
ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01_nc/k<01Ol0003oc<c<olc<c?o<
c<co000000Oo/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`05o`000?mVIVKoIVIVofIVI_l0
00001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mV
IVKo00000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000
ok>c/onc/k?o/k>co`000002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co0000
2?lc<c<02Ol0003oC4a<oda<C?m<C4co0000ofIVI_l0003oOgmoo`000002oiVIV@04o`000?nc/k?o
/k>co`0000Ooc<c<00_o0000ok>c/onc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002
oda<C003o`000?lc<c?o<c<c00Ko<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nI
VIWo0000ok>c/ol00007olc<c0Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo
00?ooooo1om<C4`00ol0003oIVIVofIVIP0;ofIVIP;o00002_moOgl00ol0003oVIVIoiVIV@0;oiVI
V@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmo
O`03o`000?mVIVKoIVIV00SoIVIV00?o0000oda<C?m<C4`05Om<C4`00ol0003oIVIVofIVIP03ofIV
IP03o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`05ok>c
/`05o`000?o<c<coc<c<olc<c?l000001onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Co
0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<
00Oo0000ofIVI_mVIVKoIVIVo`000?moOgoo000000;oVIVI00Go0000ok>c/onc/k?o/k>co`000009
olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Ko0000ogmoOomoOgoo0000ofIVI_l00002oda<C003
o`000?lc<c?o<c<c00Ko<c<c00Wo0000oda<C?m<C4coC4a<o`000?mVIVKo0000ogmoOol000000_nI
VIT01?l0003o/k>cok>c/ol00008olc<c004o`000?nc/k?o/k>cok>c/`;o000000OoOgmoo`000?mV
IVKoIVIVo`000?m<C4co000000So<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nI
VIWo0000ok>c/ol00008olc<c0Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo
00?ooooo1_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVI
VOnIVIT02_nIVIT2o`0001Oo/k>c0_l0000=oiVIV@03o`000?moOgooOgmo00SoOgmo0_l0000:ofIV
IP03o`000?m<C4coC4a<01GoC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`02ogmo
O`;o00001?nIVIT00ol0003o/k>cok>c/`05ok>c/`05o`000?o<c<coc<c<olc<c?l000001onc/k<0
1Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`00
0?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04
o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o
000000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`09o`000?m<
C4coC4a<oda<C?l0003oIVIVo`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`0
2_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c
00Ko<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00008olc<
c0Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo1Om<C4`00ol0003o
IVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo0_l0000<oiVIV@03o`000?nc/k?o/k>c01Ko
/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00[o
IVIV00?o0000oda<C?m<C4`05?m<C4`00ol0003oIVIVofIVIP04ofIVIP03o`000?moOgooOgmo00;o
Ogmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`05ok>c/`05o`000?o<c<coc<c<olc<
c?l000001_nc/k<00ol0003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol000000omVIVH0
0ol0003oC4a<oda<C002oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00om<C4`0
1?l0003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`0
1_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003o
C4a<oda<C?l00008oc<c<`09o`000?m<C4coC4a<oda<C?l0003oIVIVo`000?moOgoo000000;oVIVI
00Co0000ok>c/onc/k?o00002?o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIV
I_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00?o0000oda<C?m<C4`00_l00002ogmoO`05o`00
0?nIVIWo0000ok>c/ol000002?o<c<`00ol0003oooooooooo`03ooooo`7o00000Oooool1ooooo`00
9?ooool00ol0003oooooooooo`03ooooo`CoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmo
ogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVI
oiVIV@0<oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<
oda<C00Eoda<C003o`000?mVIVKoIVIV00?oIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVI
oiVIV@03oiVIV@03o`000?nc/k?o/k>c00Go/k>c00Go0000olc<c?o<c<coc<c<o`000007ok>c/`05
o`000?nIVIWoVIVIoiVIVOl000000omoOgl01Ol0003oIVIVofIVI_mVIVKo000000CoC4a<00?o0000
oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co
0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol0
00000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Oo0000oda<
C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<
c007olc<c005o`000?nc/k?o0000oiVIVOl000000_moOgl2o`0000;oC4a<00?o0000oc<c<olc<c<0
1_lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<
c<coc<c<00Koc<c<00?o0000ooooooooool00oooool1o`00007ooooo0Oooool002Cooooo00?o0000
ooooooooool00oooool3oda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl0
0ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c0_l0000=oiVIV@03o`000?moOgoo
Ogmo00SoOgmo00?o0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<oda<C00Eoda<C003o`000?mVIVKo
IVIV00CoIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@02oiVIV@03o`000?nc/k?o
/k>c00Ko/k>c00Co0000olc<c?o<c<co00001onc/k<00ol0003oVIVIoiVIV@02oiVIV@04o`000?mo
OgooOgmoo`0000?oIVIV00?o0000oda<C?m<C4`00_m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`00
0?m<C4coC4a<00;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`00
00;o/k>c00?o0000olc<c?o<c<`01oo<c<`01ol0003o/k>cok>c/onc/k?o0000oiVIVOl000000_mo
Ogl01?l0003oIVIVofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co
00000_mVIVH00ol0003oOgmoo`000002oiVIV@03o`000?nc/k?o000000[oc<c<00Wo0000ok>c/ol0
003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0<o`000?m<
C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00002?o<c<`00ol0003ooooooooo
o`04ooooo`7o00000Oooool1ooooo`009?ooool2o`0000Cooooo0_m<C4`00ol0003oIVIVofIVIP0;
ofIVIP03o`000?moOgooOgmo00SoOgmo0_l0000<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000
oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000
oda<C?m<C4`05Om<C4`00ol0003oIVIVofIVIP04ofIVIP03o`000?moOgooOgmo00;oOgmo00?o0000
oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`06ok>c/`04o`000?o<c<coc<c<o`0000Oo/k>c00?o
0000oiVIVOnIVIT00_nIVIT01?l0003oOgmoogmoOol00003ofIVIP03o`000?m<C4coC4a<00;oC4a<
00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C005o`000?mVIVKoIVIVofIVI_l0
00000_moOgl01?l0003oVIVIoiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Oo0000ok>c
/onc/k?o/k>co`000?nIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo00000_m<C4`00ol0003o<c<c
oc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT00ol0003o
/k>co`00000:olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o
0000oc<c<olc<c<01_lc<c<00ol0003oC4a<o`000002ofIVIP07o`000?moOgoo0000oiVIVOl0003o
/k>co`000008olc<c003o`000?oooooooooo00?ooooo0_l00002ooooo`009?ooool00ol0003ooooo
ooooo`03ooooo`03oda<C?l0003oIVIV00coIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVI
oiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003oOgmo
ogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05Om<C4`00ol0003oIVIV
ofIVIP04ofIVIP03o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>c
ok>c/`06ok>c/`04o`000?o<c<coc<c<o`0000Oo/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003o
OgmoogmoOomoOgoo000000;oIVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`04oc<c
<`03o`000?m<C4coC4a<00?oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl0
0003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo000000;o
Ogmo00Co0000ofIVI_mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<
oda<C?l000000_mVIVH2o`0000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`00ol0003o/k>co`00
0002oiVIV@;o000000GoIVIVo`000?m<C4coC4a<o`000008oc<c<`08o`000?m<C4coC4a<o`000?mV
IVKo0000ogmoOol00002oiVIV@;o00002?o<c<`00ol0003o/k>cooooo`05ooooo`7o00000Oooool1
ooooo`009?ooool00ol0003oooooooooo`03ooooo`03o`000?mVIVKoIVIV00_oIVIV00?o0000ogmo
OomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVI
VOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<
C?m<C4`05Om<C4`00ol0003oIVIVofIVIP04ofIVIP03o`000?moOgooOgmo00;oOgmo00?o0000oiVI
VOnIVIT00_nIVIT00ol0003o/k>cok>c/`07ok>c/`03o`000?o<c<co000000So/k>c00Go0000oiVI
VOnIVIWoVIVIo`000003ogmoO`05o`000?mVIVKoIVIVofIVI_l000001?m<C4`00ol0003o<c<coc<c
<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVI
oiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Goc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVI
V@04o`000?moOgooOgmoo`0000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<00ol0003oC4a<oda<
C002o`000004ofIVI_l0003oOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`02_l0003o
/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c
00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00008olc<c003o`00
0?nc/k?ooooo00Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo3OmV
IVH00ol0003oOgmoogmoO`08ogmoO`;o00003?nIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nI
VIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<
C4coC4a<01GoC4a<00?o0000ofIVI_mVIVH01?mVIVH00ol0003oOgmoogmoO`03ogmoO`03o`000?nI
VIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01onc/k<00ol0003oc<c<o`000007ok>c/`03o`000?nI
VIWoVIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`000003ofIVIP03o`000?m<C4coC4a<00;oC4a<
00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;o
Ogmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c005olc<c005o`000?nc/k?o/k>c
ok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c
00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`00
00Soc<c<00?o0000ok>c/ol000000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000
oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?l0003oIVIV00;o00000_nIVIT00ol0003o/k>co`00
0008olc<c003o`000?nc/k?ooooo00Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooo
oooo00?ooooo3?mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000
ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000
ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Eoda<C003o`000?mVIVKoIVIV00GoIVIV00?o0000
ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c00Wo/k>c00?o0000
ok>c/onc/k<01_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Go0000ofIVI_mVIVKoIVIV
o`000004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIV
ofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0
003o/k>cok>c/`02ok>c/`06o`000?nIVIWoVIVIo`000?moOgoo00000_mVIVH01?l0003oC4a<oda<
C?l00008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o
/k>cok>c/ol00008olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP04o`00
0?m<C4coC4a<o`0000Oo<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000
ok>c/ol00008olc<c003o`000?nc/k?o/k>c00Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`00
0?oooooooooo00?ooooo2omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI
00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo
00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Eoda<C003o`000?mVIVKoIVIV00GoIVIV
00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c017o/k>c
00?o0000oiVIVOnIVIT00_nIVIT01?l0003oOgmoogmoOol00003ofIVIP03o`000?m<C4coC4a<00?o
C4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`00
00;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o
/k>cok>c/ol000000_nIVIT01_l0003oOgmoogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc
<c<01olc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c
/onc/k?o00002?o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<
C003o`000?lc<c?o<c<c00Ko<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo
0000ok>c/ol00008olc<c004o`000?nc/k?o/k>co`0000Gooooo0Ol00001ooooo`7ooooo000Toooo
o`03o`000?oooooooooo00?ooooo2_mVIVH00ol0003oOgmoogmoO`08ogmoO`;o00003?nIVIT00ol0
003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00[oVIVI0_l0000:ogmoO`03o`000?mVIVKoIVIV
00coIVIV00?o0000oda<C?m<C4`05Om<C4`00ol0003oIVIVofIVIP05ofIVIP03o`000?moOgooOgmo
00;oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`0Bok>c/`05o`000?nIVIWoVIVI
oiVIVOl000000omoOgl01Ol0003oIVIVofIVI_mVIVKo000000GoC4a<00?o0000oc<c<olc<c<01Olc
<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo
00000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01_l0
003oOgmoogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01olc<c<01?l0003oC4a<oda<
C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`02_l0003o
/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c
00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00008olc<c004o`00
0?nc/k?o/k>co`0000Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo
2OmVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<0
5onc/k<00ol0003oVIVIoiVIV@0:oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH0
2omVIVH2o`0001OoC4a<00?o0000ofIVI_mVIVH01OmVIVH00ol0003oOgmoogmoO`02ogmoO`03o`00
0?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<04Onc/k<00ol0003oVIVIoiVIV@02oiVIV@05o`00
0?moOgooOgmoogmoOol000000_mVIVH00ol0003oC4a<oda<C003oda<C003o`000?lc<c?o<c<c00Go
<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVI
o`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Ko
0000ogmoOomoOgoo0000ofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<
C4co00000_mVIVH01_l0003oOgmoogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<
c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo0_l00002oda<C003o`000?lc<c?o<c<c00Ko
<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<
olc<c006olc<c003o`000?nc/k?o000000Kooooo0Ol00001ooooo`7ooooo000Iooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`03ooooo`SoIVIV00?o0000ogmoOomoOgl0
2?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c0_l0000<oiVIV@03o`00
0?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`00
0?mVIVKoIVIV00CoIVIV0_l00004ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<0
4_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<
C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo
000000;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc
/k?o/k>cok>c/ol000000_nIVIT00ol0003oOgmoo`000002ofIVIP05o`000?m<C4coC4a<oda<C?l0
00002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<0
0ol0003oc<c<olc<c007olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`00
00;oC4a<00?o0000oc<c<olc<c<01_lc<c<02ol0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000
oiVIVOl0003o/k>c00;o00001oo<c<`01?l0003o/k>cok>c/ol00006ooooo`7o00000Oooool1oooo
o`006Oooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool00oooool7ofIV
IP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`0Fok>c
/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0<ofIV
IP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH01?mVIVH00ol0003oOgmoogmoO`03ogmo
O`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<04Onc/k<00ol0003oVIVIoiVIV@02oiVI
V@05o`000?moOgooOgmoogmoOol000000omVIVH00ol0003oC4a<oda<C002oda<C003o`000?lc<c?o
<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Co
0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol0
00000_nIVIT00ol0003oOgmoo`000002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01?l0
003oC4a<oda<C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<
c007olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000
oc<c<olc<c<01_lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>c
o`0000Soc<c<00Co0000ok>c/onc/k?o00001_ooool1o`00007ooooo0Oooool001Wooooo00Go0000
ooooooooooooooooo`000006ooooo`?o00000oooool6ofIVIP03o`000?moOgooOgmo00WoOgmo00?o
0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o
0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o
0000ofIVI_mVIVH01?mVIVH00ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o
0000ok>c/onc/k<04_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00?o0000ofIVI_mVIVH0
0_mVIVH00ol0003oC4a<oda<C002oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`0
0om<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0
003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Ko0000oiVIVOnIVIWo0000ogmoOol0
0002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Co0000oda<C?m<C4co00000omVIVH01Ol0003o
Ogmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`00ol0003o/k>cok>c/`02o`00
00;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`03o`000?m<C4co0000
00;oIVIV00Co0000ogmoOol0003o00000_nc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o
/k>co`0000Cooooo0ol00002ooooo`006Oooool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo00?o
0000ooooooooool00oooool6ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onI
VIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?mo
Ogl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH01OmV
IVH00ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<04_nc
/k<00ol0003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol000000omVIVH00ol0003oC4a<
oda<C002oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0003oIVIV
ofIVI_mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<
c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP04o`000?m<
C4coC4a<o`0000So<c<c00Co0000oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nIVIWo0000
00;o/k>c00?o0000olc<c?o<c<`01oo<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000
ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00co0000oda<C?m<C4co0000ofIVI_l0003o
Ogmoo`000?nIVIWo0000ok>c/ol00008olc<c006o`000?nc/k?o/k>co`000?nIVIWo00001Oooool1
o`00007ooooo0Oooool001Wooooo00Go0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooo
oooo00?ooooo1?mVIVH2o`0000WoOgmo0_l0000=oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000
oiVIVOnIVIT02_nIVIT2o`0000[oOgmo0_l0000<ofIVIP;o00006?m<C4`00ol0003oIVIVofIVIP05
ofIVIP03o`000?moOgooOgmo00?oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0B
ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01Ol0003oIVIVofIVI_mVIVKo000000GoC4a<
00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;o
Ogmo00Go0000oiVIVOnIVIWoVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o0000ok>c
/onc/k<00_l00002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<0
1?l0003oC4a<oda<C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<
olc<c007olc<c00:o`000?nc/k?o0000o`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o
0000oc<c<olc<c<01_lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o
/k>co`0000Soc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00005ooooo`7o00000Oooool1ooooo`00
6Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooooooo00?ooooo0omVIVH00ol0003oOgmo
ogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVI
oiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<
oda<C00Goda<C003o`000?mVIVKoIVIV00KoIVIV00?o0000ogmoOomoOgl00omoOgl00ol0003oVIVI
oiVIV@03oiVIV@03o`000?nc/k?o/k>c01;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`03
o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`05oc<c<`03
o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01Ol0003oVIVIoiVIVOnIVIWo
000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00003oiVIV@03o`000?mo
Ogoo000000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<01?l0003oC4a<oda<C?l00002ofIVIP05
o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>c
o`0000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go
0000oda<C?m<C4co0000ofIVIP02o`0000;oVIVI00?o0000ok>c/ol000002?o<c<`01_l0003o/k>c
ok>c/ol0003oVIVIo`0000Gooooo0Ol00001ooooo`7ooooo000Iooooo`03omgMgOl@413oV9RH00So
oooo00?o0000ooooooooool00oooool2ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnI
VIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomo
Ogl02?moOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mV
IVH01_mVIVH00ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc
/k<04_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Go0000ofIVI_mVIVKoIVIVo`000005
oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l0
0002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c004o`00
0?nc/k?o/k>co`0000?oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00009oc<c
<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol0
0008olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP04o`000?m<C4coC4a<
o`0000Oo<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00009
olc<c005o`000?nc/k?o0000oiVIVOl000001_ooool1o`00007ooooo0Oooool001[ooooo00Coc<c<
odA4A?l0003o410@1_ooool00ol0003oooooooooo`03ooooo`03ofIVI_l0003oOgmo00WoOgmo0_l0
000=oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmo
O`09ogmoO`03o`000?mVIVKoIVIV00[oIVIV0_l0000Ioda<C003o`000?mVIVKoIVIV00GoIVIV00?o
0000ogmoOomoOgl00omoOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c01;o/k>c00?o
0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000?oIVIV00?o0000oda<C?m<C4`0
0om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00;oC4a<00Go0000ofIVI_mVIVKo
IVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01oo<c<`01?l0
003o/k>cok>c/ol00002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Co0000oda<C?m<C4co0000
2Olc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0
003oc<c<olc<c007olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;o
C4a<00?o0000oc<c<olc<c<01_lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVI
VOl0003o/k>co`0000Woc<c<00Go0000ok>c/ol0003o0000ogmoO`06ooooo`7o00000Oooool1oooo
o`009?ooool00ol0003oooooooooo`03ooooo`03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnI
VIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomo
Ogl02OmoOgl00ol0003oIVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<01SoC4a<00?o0000ofIVI_mV
IVH01_mVIVH00ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc
/k<04_nc/k<00ol0003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol000000omVIVH00ol0
003oC4a<oda<C003oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0
003oIVIVofIVI_l00003ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01oo<
c<`01?l0003o/k>cok>c/ol00002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Co0000oda<C?m<
C4co00002Olc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00?o0000oiVIVOl000000_nc
/k<00ol0003oc<c<olc<c007olc<c005o`000?nc/k?o/k>co`000?nIVIT00_l00002ofIVIP04o`00
0?m<C4coC4a<o`0000So<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000
ok>c/ol00009olc<c005o`000?nc/k?o0000o`000?moOgl01_ooool1o`00007ooooo0Oooool002Co
oooo00?o0000ooooooooool00oooool;ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc
/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mV
IVH02omVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00KoIVIV00?o0000ogmoOomo
Ogl00omoOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c01;o/k>c00?o0000oiVIVOnI
VIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000?oIVIV00?o0000oda<C?m<C4`00om<C4`00ol0
003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000003
ogmoO`04o`000?nIVIWoVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01oo<c<`01?l0003o/k>cok>c
/ol00002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<01_l0
003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<
c007olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000
oc<c<olc<c<01_lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c
/`03o`000?o<c<coc<c<00Koc<c<00Oo0000ok>c/ol0003oVIVIo`000?moOgoo000000Gooooo0Ol0
0001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo2OmoOgl2o`0000goVIVI00?o0000
ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo0_l0000<
ofIVIP;o00006Om<C4`00ol0003oIVIVofIVIP06ofIVIP03o`000?moOgooOgmo00?oOgmo00?o0000
oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`0Bok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omo
Ogl01Ol0003oIVIVofIVI_mVIVKo000000GoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<
oda<C002oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00003ok>c
/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgoo
Ogmoo`0000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<01ol0003oC4a<oda<C?m<C4co0000ofIV
I_l000000_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00?o0000ok>c
/ol000000_nIVIT01ol0003oOgmoo`000?mVIVKo0000oda<C?l000002Olc<c<02ol0003oC4a<oda<
C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>c00;o00002?o<c<`01ol0003o/k>co`000?nI
VIWo0000ogmoOol000001Oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00ooo
ool9ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVI
V@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<oda<
C00Hoda<C003o`000?mVIVKoIVIV00OoIVIV00?o0000ogmoOomoOgl00omoOgl00ol0003oVIVIoiVI
V@04oiVIV@03o`000?nc/k?o/k>c01;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`05o`00
0?mVIVKoIVIVofIVI_l000001Om<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;o
C4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000
olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo0000
0_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Ko0000ogmo
OomoOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Go0000ok>c/ol0003oVIVI
o`000002ogmoO`05o`000?mVIVKo0000oda<C?l000002Olc<c<03?l0003oC4a<oda<C?l0003oIVIV
o`000?moOgoo0000oiVIVOl0003o/k>co`0000Woc<c<00Oo0000ok>c/ol0003oVIVIo`000?moOgoo
000000Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo2?moOgl00ol0
003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0
003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00[oIVIV00?o0000oda<C?m<C4`06?m<C4`00ol0
003oIVIVofIVIP07ofIVIP03o`000?moOgooOgmo00?oOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0
003o/k>cok>c/`0Bok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01Ol0003oIVIVofIVI_mV
IVKo000000GoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C005o`000?mV
IVKoIVIVofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Go
c<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@07o`000?moOgooOgmoogmoOol0003oIVIVo`00
0003oda<C003o`000?lc<c?o<c<c00Go<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo000000;o
Ogmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c003o`000?nc/k?o000000;o
VIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00co0000oda<
C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00009olc<c007o`000?nc/k?o0000
oiVIVOl0003oOgmoo`000006ooooo`7o00000Oooool1ooooo`009?ooool2o`0000Cooooo1omoOgl0
0ol0003oVIVIoiVIV@0:oiVIV@;o00005onc/k<2o`0000goVIVI00?o0000ogmoOomoOgl02?moOgl2
o`0000coIVIV00?o0000oda<C?m<C4`06?m<C4`00ol0003oIVIVofIVIP07ofIVIP03o`000?moOgoo
Ogmo00?oOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`0Bok>c/`03o`000?nIVIWo
VIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`000003ofIVIP03o`000?m<C4coC4a<00?oC4a<00?o
0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C003oda<C004o`000?mVIVKoIVIVo`0000;oOgmo
00Go0000oiVIVOnIVIWoVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc
/k?o/k>co`000002oiVIV@06o`000?moOgooOgmoo`000?mVIVKo00000om<C4`00ol0003o<c<coc<c
<`06oc<c<`07o`000?m<C4coC4a<oda<C?l0003oIVIVo`000002ogmoO`03o`000?nIVIWo000000;o
/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000
ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000
ogmoOol0003oVIVIo`000?nc/k?o00002Oo<c<`01ol0003o/k>co`000?nIVIWo0000ogmoOol00000
1Oooool2o`0000;ooooo000Tooooo`03o`000?oooooooooo00?ooooo1OmoOgl2o`0000coVIVI00?o
0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo00SoOgmo00?o
0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Hoda<C003o`000?mVIVKoIVIV00OoIVIV00?o
0000ogmoOomoOgl01?moOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o
0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000;oIVIV00?o0000oda<C?m<C4`0
1?m<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00;oC4a<00Go0000ofIVI_mVIVKo
IVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<
c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01_l0003oOgmoogmoOol0003oIVIVo`0000?oC4a<
00?o0000oc<c<olc<c<01_lc<c<01ol0003oC4a<oda<C?m<C4co0000ofIVI_l000000_moOgl00ol0
003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT0
1Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<03?l0003oC4a<oda<
C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Woc<c<00Oo0000ok>c/ol0003oVIVI
o`000?moOgoo000000Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo
1?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT0
3?nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`0
6?m<C4`00ol0003oIVIVofIVIP07ofIVIP03o`000?moOgooOgmo00CoOgmo00?o0000oiVIVOnIVIT0
1?nIVIT00ol0003o/k>cok>c/`0Bok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomoOgoo
Ogmoo`000003ofIVIP03o`000?m<C4coC4a<00?oC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003o
C4a<oda<C003oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000003
ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@06o`000?mo
OgooOgmoo`000?mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`07o`000?m<C4coC4a<oda<
C?l0003oIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<
c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00003oda<C003o`000?lc<c?o
<c<c00Go<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0
003oc<c<olc<c006olc<c008o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVH6ooooo`7o0000
0Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`?oOgmo00?o0000oiVIVOnIVIT02onI
VIT00ol0003o/k>cok>c/`0Fok>c/`;o00003OnIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mV
IVKoIVIV00_oIVIV00?o0000oda<C?m<C4`06?m<C4`00ol0003oIVIVofIVIP07ofIVIP03o`000?mo
OgooOgmo00CoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`0Bok>c/`03o`000?nI
VIWoVIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`000003ofIVIP03o`000?m<C4coC4a<00CoC4a<
00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C002oda<C005o`000?mVIVKoIVIVofIVI_l0
00000_moOgl00ol0003oVIVIoiVIV@02o`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o
/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmoOol000000_mVIVH01Ol0003oC4a<oda<C?m<C4co
000000So<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc
/k?o/k>co`0000Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mVIVKo0000
00;oC4a<00?o0000oc<c<olc<c<01_lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000
oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo
0000ofIVI_l000001Oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool2
ogmoO`;o00003?nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000
ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01SoC4a<00?o0000
ofIVI_mVIVH01omVIVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000
ok>c/onc/k<04_nc/k<00ol0003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol000000omV
IVH00ol0003oC4a<oda<C004oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00_m<
C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003o
c<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Ko0000oiVIVOnIVIWo0000ogmoOol00002
ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`00
0?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01?l0003o/k>cok>c/ol00002oiVI
V@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0:o`000?m<C4co
C4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02Ol0
003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000005ooooo`7o00000Oooool1ooooo`009?oo
ool00ol0003oooooooooo`03ooooo`03ogmoOol0003oVIVI00coVIVI00?o0000ok>c/onc/k<05_nc
/k<00ol0003oVIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omV
IVH00ol0003oC4a<oda<C00Hoda<C003o`000?mVIVKoIVIV00SoIVIV00?o0000ogmoOomoOgl01?mo
Ogl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c01;o/k>c00?o0000oiVIVOnIVIT00_nI
VIT01Ol0003oOgmoogmoOomoOgoo000000?oIVIV00?o0000oda<C?m<C4`01?m<C4`00ol0003o<c<c
oc<c<`04oc<c<`03o`000?m<C4coC4a<00;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`04
o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o
000000;oVIVI00?o0000ogmoOol000000omVIVH01?l0003oC4a<oda<C?l00008oc<c<`04o`000?m<
C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00009olc<c003
o`000?nc/k?o000000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c
00Ko<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003o
c<c<olc<c006olc<c003o`000?nc/k?o/k>c00;o000000CoOgmoo`000?mVIVKo00001_ooool1o`00
007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool00ol0003oVIVIoiVIV@0;oiVIV@03
o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03
o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`2o`0000[oIVIV00?o0000ogmoOomo
Ogl01?moOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c01?o/k>c00Go0000oiVIVOnI
VIWoVIVIo`000004ogmoO`05o`000?mVIVKoIVIVofIVI_l000001Om<C4`00ol0003o<c<coc<c<`04
oc<c<`03o`000?m<C4coC4a<00?oC4a<00Co0000ofIVI_mVIVKo00000omoOgl01?l0003oVIVIoiVI
VOl00004ok>c/`03o`000?o<c<coc<c<00Goc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04
o`000?moOgooOgmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`04o`000?m<C4co
C4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT00ol0003o/k>co`00000:olc<c003o`000?nc
/k?o000000;oVIVI00Oo0000ogmoOol0003oIVIVo`000?m<C4co000000Wo<c<c00[o0000oda<C?m<
C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c009o`00
0?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000Kooooo0Ol00001ooooo`7ooooo000Toooo
o`03o`000?oooooooooo00?ooooo00?o0000oiVIVOnIVIT02_nIVIT00ol0003o/k>cok>c/`0Gok>c
/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIV
IP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02OmVIVH00ol0003oOgmoogmoO`05ogmo
O`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<04onc/k<01Ol0003oVIVIoiVIVOnIVIWo
000000CoOgmo00Go0000ofIVI_mVIVKoIVIVo`000005oda<C003o`000?lc<c?o<c<c00Co<c<c00?o
0000oda<C?m<C4`00om<C4`01?l0003oIVIVofIVI_l00003ogmoO`04o`000?nIVIWoVIVIo`0000Co
/k>c00?o0000olc<c?o<c<`01Oo<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmo
OomoOgoo00000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Co0000oda<C?m<C4co0000
0_mVIVH00ol0003oOgmoo`000002oiVIV@03o`000?nc/k?o000000[oc<c<00Go0000ok>c/ol0003o
VIVIo`000002ogmoO`05o`000?mVIVKo0000oda<C?l000002Olc<c<03?l0003oC4a<oda<C?l0003o
IVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Woc<c<00Wo0000ok>c/ol0003oVIVIo`000?mo
Ogoo0000ofIVI_l000001_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00ooo
ool<oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmo
O`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`2o`0000_oIVIV00?o
0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c01?o/k>c00Go
0000oiVIVOnIVIWoVIVIo`000004ogmoO`05o`000?mVIVKoIVIVofIVI_l000001_m<C4`00ol0003o
<c<coc<c<`03oc<c<`03o`000?m<C4coC4a<00?oC4a<00Co0000ofIVI_mVIVKo00000omoOgl01?l0
003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<0
1_l0003oVIVIoiVIVOl0003oOgmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`09
o`000?m<C4coC4a<oda<C?l0003oIVIVo`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o0000
2Oo<c<`00ol0003o/k>co`000002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o
<c<coc<c<`06oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c
00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>co`000?nIVIWo000000;oOgmo0_l000000om<C4co
ooooooooo`04ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`_oVIVI
00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo
00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00[oIVIV
00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c01?o/k>c
00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000?oIVIV00?o0000oda<C?m<
C4`01?m<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00;oC4a<00Go0000ofIVI_mV
IVKoIVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000onc/k<00ol0003oc<c<olc<c006
olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP04o`00
0?m<C4coC4a<o`0000Wo<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVI
V@04o`000?nc/k?o/k>co`0000Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`00
0?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`00
0?moOgoo0000oiVIVOl0003o/k>co`0000Woc<c<00[o0000ok>c/ol0003oVIVIo`000?moOgoo0000
ofIVI_l0003oC4a<1_ooool1o`00007ooooo0Oooool002Cooooo0_l00004ooooo`[oVIVI00?o0000
ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0:oiVIV@;o00002_moOgl00ol0003oIVIVofIVIP0<
ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`05
ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<04onc/k<00ol0003oVIVIoiVIV@02
oiVIV@05o`000?moOgooOgmoogmoOol000000omVIVH00ol0003oC4a<oda<C004oda<C003o`000?lc
<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo
00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c
/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000Wo<c<c00Co
0000oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000?o/k>c00?o0000olc<c?o<
c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`0
0ol0003o<c<coc<c<`06oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`00
0?nc/k?o00002Oo<c<`02_l0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4`5oooo
o`;o00000_ooool002Cooooo00?o0000ooooooooool00oooool9oiVIV@03o`000?nc/k?o/k>c01Oo
/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00_o
IVIV0_l0000Goda<C0;o00003?mVIVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00Co
VIVI00?o0000ok>c/onc/k<04onc/k<00ol0003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmo
Ool000000omVIVH00ol0003oC4a<oda<C004oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<
C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Co0000oiVIVOnIVIWo00000onc
/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmo
ogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000Wo<c<c00Co0000oda<C?m<C4co00000_mVIVH0
0ol0003oOgmoo`000002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`02_l0003o/k>cok>c
/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c00_o0000
oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`000009olc<c003o`000?nc/k?o0000
00;oVIVI0_l000001OmVIVKo0000oda<C?m<C4co000000Gooooo0Ol00001ooooo`7ooooo000Toooo
o`03o`000?oooooooooo00?ooooo2?nIVIT00ol0003o/k>cok>c/`0Fok>c/`;o00003?nIVIT00ol0
003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0
003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0
003o/k>cok>c/`0Cok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`000004
ofIVIP03o`000?m<C4coC4a<00?oC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C003
oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`00
0?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`00
00;oIVIV00Co0000oda<C?m<C4co00002Olc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?mo
Ogoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01_l0003o/k>cok>c/ol0003oVIVIo`00
00;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0<o`000?m<C4coC4a<
o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00002Oo<c<`02Ol0003o/k>co`000?nIVIWo
0000ogmoOol0003oIVIVo`000002oda<C003o`000?oooooooooo00?ooooo0Ol00001ooooo`7ooooo
000Tooooo`03o`000?oooooooooo00?ooooo2?nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nI
VIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<
C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`04ogmoO`03o`000?nI
VIWoVIVI00GoVIVI00?o0000ok>c/onc/k<04onc/k<00ol0003oVIVIoiVIV@02oiVIV@05o`000?mo
OgooOgmoogmoOol000001?mVIVH00ol0003oC4a<oda<C003oda<C003o`000?lc<c?o<c<c00Co<c<c
00?o0000oda<C?m<C4`00om<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Co0000oiVIVOnI
VIWo00001?nc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT0
1_l0003oOgmoogmoOol0003oIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01olc<c<01?l0003oC4a<
oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01_l0
003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c
<`06oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00002Oo<
c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003o`000?oooooooooo
00?ooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo1onIVIT00ol0003o
/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003o
IVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003o
OgmoogmoO`04ogmoO`03o`000?nIVIWoVIVI00GoVIVI00?o0000ok>c/onc/k<04onc/k<00ol0003o
VIVIoiVIV@02oiVIV@03o`000?moOgooOgmo00;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000005oda<
C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00om<C4`01Ol0003oIVIVofIVI_mVIVKo
000000?oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c005olc<c005o`000?nc
/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<
C?l000002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Co
0000ok>c/onc/k?o00002?o<c<`02?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo00000_mVIVH0
0ol0003oC4a<o`000009oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`00
0?nc/k?o00002Oo<c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003
o`000?oooooooooo00?ooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo
1_nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl0
2?moOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH0
2_mVIVH2o`0000OoOgmo00?o0000oiVIVOnIVIT01OnIVIT00ol0003o/k>cok>c/`0Cok>c/`03o`00
0?nIVIWoVIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`000004ofIVIP03o`000?m<C4coC4a<00?o
C4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C003oda<C005o`000?mVIVKoIVIVofIV
I_l000000_moOgl01?l0003oVIVIoiVIVOl00005ok>c/`03o`000?o<c<coc<c<00Goc<c<00Go0000
ok>c/onc/k?o/k>co`000002oiVIV@06o`000?moOgooOgmoo`000?mVIVKo00001?m<C4`00ol0003o
<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0
003o/k>cok>c/ol00008olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl00ol0003oIVIV
o`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmo
o`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c003o`000?nc/k?o/k>c00;o000000Co
Ogmoo`000?mVIVKo00000_m<C4`00ol0003oooooooooo`04ooooo`7o00000Oooool1ooooo`009?oo
ool00ol0003oooooooooo`03ooooo`GoVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVI
V@0:oiVIV@;o00002_moOgl2o`0000coIVIV0_l0000Goda<C0;o00003OmVIVH00ol0003oOgmoogmo
O`05ogmoO`03o`000?nIVIWoVIVI00GoVIVI00?o0000ok>c/onc/k<04onc/k<00ol0003oVIVIoiVI
V@02oiVIV@03o`000?moOgooOgmo00;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000006oda<C003o`00
0?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00om<C4`01?l0003oIVIVofIVI_l00003ogmoO`04
o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c
/`04o`000?nIVIWoVIVIo`0000;oOgmo00?o0000ofIVI_l000000om<C4`00ol0003o<c<coc<c<`06
oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc
/k?o/k>co`0000Soc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`05o`000?mVIVKo0000
oda<C?l000002Olc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c
/`03o`000?o<c<coc<c<00Koc<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00000
0_m<C4`00ol0003oooooooooo`04ooooo`7o00000Oooool1ooooo`009?ooool00ol0003ooooooooo
o`03ooooo`CoVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?mo
OgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mV
IVKoIVIV00coIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc
/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000CoIVIV
00?o0000oda<C?m<C4`01?m<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<
00Co0000ofIVI_mVIVKo00000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Co/k>c00?o0000olc<
c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00?o0000
ofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mV
IVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Ko0000ok>c/onc/k?o
0000oiVIVOl00002ogmoO`05o`000?mVIVKo0000oda<C?l000002Olc<c<03?l0003oC4a<oda<C?l0
003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Woc<c<00Wo0000ok>c/ol0003oVIVIo`00
0?moOgoo0000ofIVI_l000000_m<C4`00ol0003oooooooooo`04ooooo`7o00000Oooool1ooooo`00
9?ooool00ol0003oooooooooo`03ooooo`?oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVI
oiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH03?mVIVH00ol0003oC4a<
oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVI
oiVIV@06oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT00_nIVIT00ol0003oOgmo
ogmoO`02ogmoO`05o`000?mVIVKoIVIVofIVI_l000001_m<C4`00ol0003o<c<coc<c<`04oc<c<`03
o`000?m<C4coC4a<00?oC4a<00Co0000ofIVI_mVIVKo00000omoOgl01?l0003oVIVIoiVIVOl00004
ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl0
0002ogmoO`03o`000?mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01olc<c<01?l0003oC4a<oda<
C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01?l0003o
/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06
oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<
c?o<c<`01_o<c<`01Ol0003o/k>co`000?nIVIWo000000;oOgmo0_l00002oda<C003o`000?lc<c?o
oooo00Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo0_nIVIT00ol0
003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0
003oIVIVofIVIP0:ofIVIP;o00005om<C4`2o`0000goIVIV00?o0000ogmoOomoOgl01_moOgl00ol0
003oVIVIoiVIV@05oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT00onIVIT01Ol0
003oOgmoogmoOomoOgoo000000CoIVIV00?o0000oda<C?m<C4`01?m<C4`00ol0003o<c<coc<c<`03
oc<c<`03o`000?m<C4coC4a<00?oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`05o`000?nI
VIWoVIVIoiVIVOl000001?nc/k<00ol0003oc<c<olc<c005olc<c005o`000?nc/k?o/k>cok>c/ol0
00000onIVIT00ol0003oOgmoo`000002ofIVIP05o`000?m<C4coC4a<oda<C?l000002Olc<c<01_l0
003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00?o0000oiVIVOl000000onc/k<00ol0003oc<c<olc<
c006olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl00ol0003oIVIVo`000002oda<C003
o`000?lc<c?o<c<c00Ko<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000
0_nc/k<00ol0003oc<c<olc<c006olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo
000000;oC4a<00?o0000oc<c<oooool01Oooool1o`00007ooooo0Oooool002Cooooo0_l00004oooo
o`03oiVIVOl0003o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmo
O`03o`000?mVIVKoIVIV00[oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0<ofIV
IP03o`000?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT01OnIVIT00ol0003o/k>cok>c/`0Cok>c
/`03o`000?nIVIWoVIVI00;oVIVI00?o0000ogmoOomoOgl00_moOgl01Ol0003oIVIVofIVI_mVIVKo
000000OoC4a<00?o0000oc<c<olc<c<00olc<c<00ol0003oC4a<oda<C003oda<C005o`000?mVIVKo
IVIVofIVI_l000000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000?o/k>c00?o0000olc<c?o<c<`0
1_o<c<`01Ol0003o/k>cok>c/onc/k?o000000?oVIVI00?o0000ogmoOol000000_mVIVH01Ol0003o
C4a<oda<C?m<C4co000000Wo<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`03o`000?nI
VIWo000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;o
Ogmo00Go0000ofIVI_l0003oC4a<o`000009oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmo
Ool0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02Ol0003o/k>co`000?nIVIWo0000
ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?ooooo00Cooooo0_l00002ooooo`009?ooool0
0ol0003oooooooooo`03ooooo`03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT0
0ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`0
0ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT01OnIVIT0
0ol0003o/k>cok>c/`0Cok>c/`03o`000?nIVIWoVIVI00?oVIVI00Go0000ogmoOomoOgooOgmoo`00
0004ofIVIP03o`000?m<C4coC4a<00CoC4a<00?o0000oc<c<olc<c<00olc<c<00ol0003oC4a<oda<
C003oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000?o
/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000?oVIVI00?o0000ogmo
Ool000000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000Wo<c<c00Ko0000oda<C?m<C4co0000ofIV
I_l00002ogmoO`03o`000?nIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01_l0003o/k>c
ok>c/ol0003oVIVIo`0000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c
<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`0
1_o<c<`00ol0003o/k>co`000002oiVIV@;o000000GoIVIVo`000?m<C4coC4a<o`000002oc<c<`Ko
oooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo6?nc/k<00ol0003oVIVI
oiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo0_l0000<ofIVIP;o00005om<C4`2o`0000goIVIV
00?o0000ogmoOomoOgl01_moOgl2o`0000OoVIVI00?o0000ok>c/onc/k<04onc/k<00ol0003oVIVI
oiVIV@03oiVIV@03o`000?moOgooOgmo00;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000006oda<C003
o`000?lc<c?o<c<c00?o<c<c00?o0000oda<C?m<C4`01?m<C4`01?l0003oIVIVofIVI_l00003ogmo
O`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc
/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So
<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00?o0000oiVIVOl000000_nc/k<0
0ol0003oc<c<olc<c007olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP04
o`000?m<C4coC4a<o`0000So<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo
0000ok>c/ol00009olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<
00?o0000oc<c<olc<c<01_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00ooo
oolGok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIV
IP0:ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmo
O`07ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc/k<04onc/k<00ol0003oVIVIoiVI
V@03oiVIV@05o`000?moOgooOgmoogmoOol000001?mVIVH00ol0003oC4a<oda<C004oda<C003o`00
0?lc<c?o<c<c00?o<c<c00?o0000oda<C?m<C4`01?m<C4`01?l0003oIVIVofIVI_l00003ogmoO`04
o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o
000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`04o`00
0?m<C4coC4a<o`0000;oIVIV00Ko0000ogmoOomoOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<co
c<c<00Ooc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV00Co0000oda<C?m<
C4co00002?lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`00
00Woc<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<c
oc<c<`06ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03oooooaKo/k>c00?o
0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00[oIVIV00?o
0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00OoOgmo00?o
0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`0Cok>c/`03o`000?nIVIWoVIVI00?oVIVI00?o
0000ogmoOomoOgl00_moOgl01Ol0003oIVIVofIVI_mVIVKo000000KoC4a<00?o0000oc<c<olc<c<0
0olc<c<00ol0003oC4a<oda<C004oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01?l0003o
VIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002
oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`07o`00
0?m<C4coC4a<oda<C?l0003oIVIVo`000002ogmoO`03o`000?nIVIWo000000?o/k>c00?o0000olc<
c?o<c<`01_o<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00?o0000ofIVI_l000000_m<
C4`00ol0003o<c<coc<c<`06oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVI
o`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003o/k>cok>c/`02o`000007ogmoOol0003o
IVIVofIVI_l0003oC4a<o`000003oc<c<`Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oo
oooooooo00?ooooo5?nc/k<2o`0000goVIVI00?o0000ogmoOomoOgl02?moOgl2o`0000coIVIV00?o
0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00OoOgmo00?o
0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`0Dok>c/`03o`000?nIVIWoVIVI00;oVIVI00?o
0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP02ofIVIP03o`000?m<C4coC4a<00CoC4a<00?o
0000oc<c<olc<c<00olc<c<00ol0003oC4a<oda<C003oda<C005o`000?mVIVKoIVIVofIVI_l00000
0omoOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc
/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`00
0008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Ko0000ogmoOomoOgoo0000oiVIVOl00003ok>c
/`03o`000?o<c<coc<c<00Koc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV
00?o0000oda<C?l000002Olc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0
0002ok>c/`03o`000?o<c<coc<c<00Koc<c<00_o0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIV
I_l0003oC4a<o`000004oc<c<`Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo
00?ooooo4onc/k<00ol0003oVIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIV
I_mVIVH02omVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmo
OomoOgl01omoOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c01Co/k>c00?o0000oiVI
VOnIVIT00onIVIT00ol0003oOgmoogmoO`02ogmoO`05o`000?mVIVKoIVIVofIVI_l000001om<C4`0
0ol0003o<c<coc<c<`02oc<c<`03o`000?m<C4coC4a<00CoC4a<00Go0000ofIVI_mVIVKoIVIVo`00
0003ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>c
ok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0
003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Ko0000ogmoOomoOgoo0000oiVI
VOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmo
o`0000;oIVIV00?o0000oda<C?l000002Olc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo
0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Goc<c<00co0000ok>c/onc/k?o0000oiVIVOl0
003oOgmoo`000?mVIVKo0000oda<C?l00004oc<c<`Kooooo0Ol00001ooooo`7ooooo000Tooooo`03
o`000?oooooooooo00?ooooo4_nc/k<00ol0003oVIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo00So
Ogmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00_o
IVIV00?o0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@07oiVIV@03o`000?nc/k?o/k>c01?o
/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00;o
IVIV00?o0000oda<C?m<C4`01?m<C4`00ol0003o<c<coc<c<`02oc<c<`03o`000?m<C4coC4a<00Co
C4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000
olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo0000
0_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Co0000oda<C?m<C4co00000_mVIVH01_l0
003oOgmoogmoOol0003oVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c
/ol00002oiVIV@;o00000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`0:o`000?m<C4coC4a<o`00
0?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>c
o`000?nIVIWo000000;oOgmo0_l00002oda<C003o`000?lc<c?o<c<c00;o<c<c1_ooool1o`00007o
oooo0Oooool001Wooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo00?o
oooo4Onc/k<2o`0000goVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03
o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02_mVIVH2o`0000WoOgmo00?o0000oiVIVOnI
VIT01onIVIT00ol0003o/k>cok>c/`0Dok>c/`03o`000?nIVIWoVIVI00;oVIVI00?o0000ogmoOomo
Ogl00_moOgl00ol0003oIVIVofIVIP02ofIVIP03o`000?m<C4coC4a<00CoC4a<00?o0000oc<c<olc
<c<00olc<c<00ol0003oC4a<oda<C004oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01Ol0
003oVIVIoiVIVOnIVIWo000000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02
ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<c
oc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o
/k>cok>c/ol00008olc<c0;o00000_nc/k<01Ol0003oVIVIo`000?moOgoo000000;oIVIV00Co0000
oda<C?m<C4co00002?lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002
ok>c/`03o`000?o<c<coc<c<00Koc<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0
00000_m<C4`00ol0003o<c<coc<c<`02oc<c<`Kooooo0Ol00001ooooo`7ooooo000Iooooo`05ob4Q
8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`03oooooa3o/k>c00?o0000oiVIVOnI
VIT03?nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<
C4`05om<C4`00ol0003oIVIVofIVIP0:ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnI
VIT01_nIVIT00ol0003o/k>cok>c/`0Eok>c/`03o`000?nIVIWoVIVI00;oVIVI00?o0000ogmoOomo
Ogl00_moOgl00ol0003oIVIVofIVIP02ofIVIP03o`000?m<C4coC4a<00CoC4a<00?o0000oc<c<olc
<c<00olc<c<00ol0003oC4a<oda<C004oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01Ol0
003oVIVIoiVIVOnIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003o/k>cok>c/`02
ok>c/`06o`000?nIVIWoVIVIo`000?moOgoo00000_mVIVH00ol0003oC4a<oda<C002oda<C003o`00
0?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVIV@04
o`000?nc/k?o/k>co`0000Soc<c<00Wo0000ok>c/onc/k?o/k>co`000?nIVIWo0000ogmoOol00000
0_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0
003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02Ol0003o/k>co`000?nIVIWo0000ogmo
Ool0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00;o<c<c1_ooool1o`00007ooooo0Oooool0
01Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00?ooooo3onc/k<0
0ol0003oVIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH0
0ol0003oC4a<oda<C00Foda<C0;o00003?mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWo
VIVI00KoVIVI00?o0000ok>c/onc/k<05Onc/k<00ol0003oVIVIoiVIV@02oiVIV@03o`000?moOgoo
Ogmo00;oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C005oda<C003o`000?lc<c?o
<c<c00;o<c<c00?o0000oda<C?m<C4`01?m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Go
0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<0
0_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c
<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP06o`000?moOgooOgmoo`000?nIVIWo0000
0_nc/k<00ol0003oc<c<olc<c006olc<c009o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000?moOgoo
000000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<01ol0003oC4a<o`000?mVIVKo0000ogmoOol0
00000_nIVIT00ol0003o/k>co`000008olc<c003o`000?nc/k?o000000;oVIVI0_l000001OmVIVKo
0000oda<C?m<C4co000000Go<c<c1_ooool1o`00007ooooo0Oooool001Wooooo00Go<S8boiRHV?oo
ooooV9RHoc8b<P06ooooo`?o00000oooool?ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmo
OomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIV
I_mVIVH02omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00OoVIVI00?o0000ok>c
/onc/k<05?nc/k<00ol0003oVIVIoiVIV@02oiVIV@;o00000omoOgl00ol0003oIVIVofIVIP02ofIV
IP03o`000?m<C4coC4a<00GoC4a<00?o0000oc<c<olc<c<00_lc<c<00ol0003oC4a<oda<C004oda<
C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<
c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;o
IVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH0
0ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Wo0000ok>c/onc/k?o/k>c
o`000?nIVIWo0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`0<o`000?m<C4co
C4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00002Oo<c<`01?l0003o/k>co`000?nI
VIT3o`000005ofIVI_l0003oC4a<oda<C?l000001Olc<c<4ooooo`?o00000_ooool001Wooooo00Go
c<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooooooo00?ooooo3_nc/k<00ol0003oVIVI
oiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<
oda<C00Goda<C003o`000?mVIVKoIVIV00[oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVI
oiVIV@07oiVIV@03o`000?nc/k?o/k>c01Co/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmo
ogmoO`02ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01Om<C4`00ol0003o<c<c
oc<c<`02oc<c<`03o`000?m<C4coC4a<00CoC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`04
o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o
000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c
00Go0000oda<C?m<C4coC4a<o`000002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc
/k?o00002?o<c<`02Ol0003o/k>cok>c/onc/k?o0000oiVIVOl0003oOgmoo`000002ofIVIP04o`00
0?m<C4coC4a<o`0000So<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000
ok>c/ol00009olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o
0000oc<c<olc<c<00olc<c<6ooooo`7o00000Oooool1ooooo`006Oooool01Ol@413o^[Zjoooooonj
^[[o410@00Kooooo00?o0000ooooooooool00oooool=ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o
0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<0_l0
000<ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT01onIVIT00ol0003o/k>cok>c
/`0Eok>c/`03o`000?nIVIWoVIVI00;oVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIV
IP03ofIVIP03o`000?m<C4coC4a<00CoC4a<00?o0000oc<c<olc<c<00_lc<c<00ol0003oC4a<oda<
C004oda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01Ol0003oVIVIoiVIVOnIVIWo000000?o
/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmo
OomoOgoo00000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00?o0000oda<C?m<C4`00_m<
C4`01Ol0003oIVIVo`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01ol0003o
/k>cok>c/onc/k?o0000oiVIVOl000000_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o
<c<c00Ko<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`;o00000_nc/k<00ol0003oc<c<
olc<c006olc<c007o`000?nc/k?o0000oiVIVOl0003oOgmoo`000002ofIVIP03o`000?m<C4co0000
00Ko<c<c1_ooool1o`00007ooooo0Oooool001Wooooo00Go0000okZj^_oooooo^[Zjo`000006oooo
o`03o`000?oooooooooo00?ooooo3?nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo
00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV
00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@07oiVIV@03o`000?nc/k?o/k>c
01Go/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV
00;oIVIV00?o0000oda<C?m<C4`01Om<C4`00ol0003o<c<coc<c<`02oc<c<`03o`000?m<C4coC4a<
00CoC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc
/k<00ol0003oc<c<olc<c005olc<c0;o00000onc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`00
0?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co0000
00;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00008olc<c004o`000?nc/k?o
/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH00ol0003oC4a<o`000009oc<c<`0:o`000?m<
C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`0
2?l0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIV0_l000000om<C4co0000oc<c<`05oc<c<`Ko
oooo0Ol00001ooooo`7ooooo000Iooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0003o
ooooooooo`03ooooo`_o/k>c00?o0000oiVIVOnIVIT02_nIVIT2o`0000[oOgmo00?o0000ofIVI_mV
IVH03?mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00[oIVIV00?o0000ogmoOomo
Ogl02OmoOgl00ol0003oVIVIoiVIV@08oiVIV@03o`000?nc/k?o/k>c01Go/k>c00?o0000oiVIVOnI
VIT00onIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<
C4`01Om<C4`00ol0003o<c<coc<c<`02oc<c<`03o`000?m<C4coC4a<00CoC4a<00Go0000ofIVI_mV
IVKoIVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0003oc<c<olc<c005
olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIV
I_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP03
o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01?l0003o/k>cok>c/ol00002
oiVIV@03o`000?moOgoo000000;oIVIV00?o0000oda<C?l000002Olc<c<02_l0003oC4a<oda<C?l0
003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Wo0000ok>c
/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`04oc<c<`Kooooo
0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo2_nc/k<00ol0003oVIVIoiVI
V@0:oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH2o`0001OoC4a<0_l0
000<ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02?nIVIT00ol0003o/k>cok>c
/`0Eok>c/`03o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIV
IP02ofIVIP03o`000?m<C4coC4a<00GoC4a<00?o0000oc<c<olc<c<00_lc<c<00ol0003oC4a<oda<
C004oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Co
/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`00
00;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4co
C4a<oda<C?l000000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Woc<c<
00Co0000ok>c/onc/k?o00000_nIVIT2o`0000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<01?l0
003oC4a<oda<C?l00002ofIVIP;o000000GoVIVIo`000?nc/k?o/k>co`000008olc<c007o`000?nc
/k?o/k>co`000?nIVIWo0000ogmoO`02o`0000;oC4a<00?o0000oc<c<olc<c<01Olc<c<6ooooo`7o
00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`So/k>c0_l0000<oiVIV@03o`00
0?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`00
0?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@08oiVIV@03o`00
0?nc/k?o/k>c01Go/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`02ogmoO`03o`00
0?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01Om<C4`00ol0003o<c<coc<c<`02oc<c<`03o`00
0?m<C4coC4a<00CoC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`05o`000?nIVIWoVIVIoiVI
VOl000001?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVI
VOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Oo
0000oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo00000_nc/k<00ol0
003oc<c<olc<c006olc<c003o`000?nc/k?o/k>c00;o000000CoVIVIo`000?moOgoo00000_mVIVH0
1?l0003oC4a<oda<C?l00008oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVI
o`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/ol0003oVIVI00Co00000_m<
C4`00ol0003o<c<coc<c<`05oc<c<`Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooo
oooo00?ooooo2?nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000
ofIVI_mVIVH03?mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000
ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@09oiVIV@03o`000?nc/k?o/k>c01Go/k>c00?o0000
oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000
oda<C?m<C4`01Om<C4`00ol0003o<c<coc<c<`02oc<c<`03o`000?m<C4coC4a<00CoC4a<00Go0000
ofIVI_mVIVKoIVIVo`000003ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0003oc<c<
olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0003o
IVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Oo0000oda<C?m<C4coC4a<o`000?mV
IVKo000000;oOgmo00Co0000oiVIVOnIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c004o`00
0?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00007oc<c
<`0;o`000?m<C4coC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003o
c<c<olc<c006olc<c005o`000?nc/k?o/k>co`000?nIVIT00_l000001OmVIVKo0000oda<C?m<C4co
000000Oo<c<c1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool7ok>c
/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0<ofIV
IP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmo
O`03o`000?nIVIWoVIVI00WoVIVI00?o0000ok>c/onc/k<05Onc/k<00ol0003oVIVIoiVIV@03oiVI
V@03o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C005oda<
C005o`000?lc<c?o<c<coc<c<ol000001om<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Go
0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<0
0_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo00000_m<C4`00ol0
003o<c<coc<c<`07oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Ko0000ogmoOomoOgoo0000oiVI
VOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT01Ol0003o
Ogmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<03Ol0003oC4a<oda<C?m<C4co
0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol000002Oo<c<`00ol0003o/k>co`000002oiVI
V@;o000000GoIVIVo`000?m<C4coC4a<o`000007oc<c<`Kooooo0Ol00001ooooo`7ooooo000Toooo
o`03o`000?oooooooooo00?ooooo1_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo
00SoOgmo00?o0000ofIVI_mVIVH03?mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV
00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@09oiVIV@03o`000?nc/k?o/k>c
01Co/k>c00?o0000oiVIVOnIVIT01?nIVIT01Ol0003oOgmoogmoOomoOgoo000000GoIVIV00?o0000
oda<C?m<C4`01Om<C4`00ol0003o<c<coc<c<`02oc<c<`03o`000?m<C4coC4a<00CoC4a<00Go0000
ofIVI_mVIVKoIVIVo`000003ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0003oc<c<
olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0003o
IVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002
ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01?l0003o/k>cok>c
/ol00002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<02_l0003o
C4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<
00Go0000ok>c/onc/k?o0000oiVIV@02o`000005ofIVI_l0003oC4a<oda<C?l000002?lc<c<6oooo
o`7o00000Oooool1ooooo`009?ooool2o`0000Cooooo1Onc/k<00ol0003oVIVIoiVIV@0:oiVIV@;o
00002_moOgl2o`0000coIVIV0_l0000Goda<C0;o00003OmVIVH00ol0003oOgmoogmoO`08ogmoO`;o
00002onIVIT00ol0003o/k>cok>c/`0Dok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomo
Ogl00_moOgl00ol0003oIVIVofIVIP02ofIVIP03o`000?m<C4coC4a<00KoC4a<00Go0000oc<c<olc
<c?o<c<co`000006oda<C0;o00000omVIVH01?l0003oOgmoogmoOol00003oiVIV@03o`000?nc/k?o
/k>c00;o/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`05o`000?nIVIWo
VIVIoiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c
00Co0000oda<C?m<C4co00000_mVIVH01_l0003oOgmoogmoOol0003oVIVIo`0000?o/k>c00?o0000
olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l00000
0_m<C4`00ol0003o<c<coc<c<`07oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003o
VIVIo`000?nc/k?o00002Oo<c<`01?l0003o/k>co`000?nIVIT3o`000005ofIVI_l0003oC4a<oda<
C?l000002?lc<c<00ol0003oooooooooo`02ooooo`;o00000_ooool002Cooooo00?o0000oooooooo
ool00oooool4ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003o
IVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003o
OgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00[oVIVI00?o0000ok>c/onc/k<05Onc/k<00ol0003o
VIVIoiVIV@03oiVIV@03o`000?moOgooOgmo00?oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003o
C4a<oda<C006oda<C005o`000?lc<c?o<c<coc<c<ol000001_m<C4`00ol0003oIVIVofIVIP02ofIV
IP04o`000?moOgooOgmoo`0000?oVIVI00?o0000ok>c/onc/k<00_nc/k<00ol0003oc<c<olc<c005
olc<c003o`000?nc/k?o/k>c00;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`04o`000?mV
IVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP06
o`000?moOgooOgmoo`000?nIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o
/k>co`0000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c
00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00009olc<c009o`00
0?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<0
0ol0003oooooooooo`03ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03oooo
o`?o/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV
00coIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo
00SoOgmo00?o0000oiVIVOnIVIT02_nIVIT00ol0003o/k>cok>c/`0Eok>c/`03o`000?nIVIWoVIVI
00CoVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP02ofIVIP03o`000?m<C4coC4a<
00KoC4a<0ol000000olc<c?o0000oda<C005oda<C003o`000?mVIVKoIVIV00;oIVIV00Co0000ogmo
OomoOgoo00000onIVIT00ol0003o/k>cok>c/`02ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000
ok>c/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo0000
0om<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Ko0000ogmoOomo
Ogoo0000oiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nI
VIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01olc<c<02_l0003oC4a<
oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o
0000ok>c/ol000000_nIVIT2o`0000;oIVIV00Co0000oda<C?m<C4co00001olc<c<00ol0003ooooo
ooooo`04ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`;o/k>c00?o
0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00[oIVIV0_l0
000Goda<C0;o00003OmVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o
0000ok>c/onc/k<05?nc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00;oOgmo00?o
0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C006oda<C004o`000?lc<c?o<c<co`0000OoC4a<
00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0
003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl0
1?l0003oIVIVofIVI_l00004oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co0000
0_mVIVH01_l0003oOgmoogmoOol0003oVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0
003o/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c
<`07oc<c<`03o`000?m<C4co000000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`00
0?o<c<coc<c<00Koc<c<00?o0000ok>c/ol000000_nIVIT2o`0000;oIVIV00?o0000oda<C?l00000
2?lc<c<00ol0003oooooooooo`04ooooo`7o00000Oooool1ooooo`009?ooool00ol0003ooooooooo
o`03ooooo`03ok>c/ol0003oVIVI00coVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIV
IP0:ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmo
O`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05Onc/k<00ol0003oVIVIoiVI
V@04oiVIV@05o`000?moOgooOgmoogmoOol000001_mVIVH00ol0003oC4a<oda<C006oda<C004o`00
0?lc<c?o<c<co`0000OoC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`05o`000?nIVIWoVIVI
oiVIVOl000001?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000
oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00004oda<C003o`000?lc<c?o<c<c00Go<c<c
00Go0000oda<C?m<C4coC4a<o`000002ofIVIP06o`000?moOgooOgmoo`000?nIVIWo00000onc/k<0
0ol0003oc<c<olc<c005olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01Ol0003oOgmoo`00
0?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01olc<c<00ol0003oC4a<o`000002ofIVIP05o`00
0?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c003o`000?nc/k?o000000;o
VIVI0_l00002ofIVIP03o`000?m<C4co000000So<c<c00?o0000ooooooooool01?ooool1o`00007o
oooo0Oooool002Cooooo00?o0000ooooooooool00oooool00ol0003oVIVIoiVIV@0;oiVIV@03o`00
0?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`00
0?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`00
0?nc/k?o/k>c01Go/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`02ogmoO`03o`00
0?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<C4`01_m<C4`01?l0003o<c<coc<c<ol00007oda<C005
o`000?mVIVKoIVIVofIVI_l000000omoOgl01Ol0003oVIVIoiVIVOnIVIWo000000Co/k>c00?o0000
olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`03ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co
0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`05oc<c<`05o`000?m<C4coC4a<oda<C?l0
00000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00_o0000
ok>c/onc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c
00Oo<c<c00?o0000oda<C?l000000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000
olc<c?o<c<`01_o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<
o`0000So<c<c00?o0000oda<C?ooool01Oooool1o`00007ooooo0Oooool002Cooooo00?o0000oooo
ooooool00oooool=oiVIV@03o`000?moOgooOgmo00SoOgmo0_l0000<ofIVIP;o00005om<C4`2o`00
00goIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c
01Go/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV
00?oIVIV00?o0000oda<C?m<C4`01_m<C4`2o`000003oc<c<ol0003oC4a<00KoC4a<00?o0000ofIV
I_mVIVH00_mVIVH01?l0003oOgmoogmoOol00003oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000
olc<c?o<c<`01?o<c<`2o`0000Co/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIV
I_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP03
o`000?moOgoo000000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c004o`000?nc/k?o/k>c
o`0000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c0_l0
00002Om<C4co0000o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<
00Koc<c<00Go0000ok>c/onc/k?o0000oiVIV@03o`000003ofIVI_l0003o000000Wo<c<c00?o0000
oda<C?ooool01Oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool<oiVI
V@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<oda<C00Foda<
C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVI
V@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`02ogmo
O`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<C4`02?m<C4`00ol0003oC4a<oda<C006oda<
C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01Ol0003oVIVIoiVIVOnIVIWo000000Go/k>c00?o
0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo
00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<
C?l000000_mVIVH00ol0003oOgmoo`000002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`0
1?l0003o/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<c
oc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c
/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o0000oiVIV@02o`0000;oIVIV0_l00009
oc<c<`03o`000?m<C4co000000Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo
00?ooooo2onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00[oIVIV00?o0000oda<
C?m<C4`05om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVI
VOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmo
OomoOgl00_moOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<017oC4a<00Go0000ofIV
I_mVIVKoIVIVo`000003ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001Onc/k<00ol0003oc<c<olc<
c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIV
ofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0003o
IVIVo`000?moOgoo000000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c004o`000?nc/k?o
/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00007oc<c<`04o`00
0?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT00ol0003o/k>co`000008olc<c00<
o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co00002?lc<c<01?l0003o
C4a<oda<C?l00005ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`[o
VIVI00?o0000ogmoOomoOgl02?moOgl2o`0000coIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003o
IVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o
/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003o
IVIVofIVIP02ofIVIP03o`000?m<C4coC4a<01;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmo
O`05o`000?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o
/k>c00;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<
00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o0000ogmoOol0
00000_nIVIT01?l0003o/k>cok>c/ol00009olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_mo
Ogl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co0000
0_mVIVH01ol0003oOgmoo`000?nIVIWo0000ok>c/ol000002Oo<c<`03?l0003o/k>cok>c/ol0003o
VIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000So<c<c00Co0000oda<C?m<C4co00001Oooool1
o`00007ooooo0Oooool002Cooooo0_l00004ooooo`WoVIVI00?o0000ogmoOomoOgl02?moOgl00ol0
003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0
003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0
003oVIVIoiVIV@05oiVIV@03o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0
003oC4a<oda<C00Boda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01Ol0003oVIVIoiVIVOnI
VIWo000000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`05o`000?nI
VIWoVIVIoiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko
<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c
/onc/k?o00002Oo<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00?o0000ofIVI_l00000
0_m<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Oo0000ogmoOol0
003oVIVIo`000?nc/k?o000000Woc<c<00?o0000ok>c/onc/k<00_l00002ogmoO`05o`000?mVIVKo
0000oda<C?l000002?lc<c<01?l0003oC4a<oda<C?l00004ooooo`;o00000_ooool002Cooooo00?o
0000ooooooooool00oooool8oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omV
IVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?mo
Ogl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT01OnI
VIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`04_m<
C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Go0000oiVIVOnIVIWoVIVIo`000005ok>c/`03
o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo0000
00;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4co
C4a<oda<C?l000000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Woc<c<
00Co0000ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c
<olc<c<01olc<c<00ol0003oC4a<o`000002ofIVIP03o`000?moOgooOgmo00;o00000_nc/k<00ol0
003oc<c<olc<c006olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;o
C4a<00?o0000oc<c<olc<c<01_lc<c<00ol0003oC4a<o`000006ooooo`7o00000Oooool1ooooo`00
9?ooool00ol0003oooooooooo`03ooooo`OoVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIV
ofIVIP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02_mVIVH2o`0000[oOgmo
00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00GoVIVI
00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIVIP02ofIVIP03o`000?m<C4coC4a<01;oC4a<
00?o0000ofIVI_mVIVH00_mVIVH01?l0003oOgmoogmoOol00003oiVIV@;o00001?nc/k<00ol0003o
c<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01Ol0
003oIVIVofIVI_mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01ol0003oC4a<oda<C?m<
C4co0000ofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Oo
c<c<00Go0000ok>c/onc/k?o0000oiVIV@02o`000004ogmoOol0003oIVIVo`0000;oC4a<00?o0000
oc<c<olc<c<01olc<c<00ol0003oC4a<o`000002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc
/k<00ol0003oc<c<olc<c006olc<c003o`000?nc/k?o000000;oVIVI00Oo0000ogmoOol0003oIVIV
o`000?m<C4co000000So<c<c00Co0000oda<C?m<C4co00001_ooool1o`00007ooooo0Oooool002Co
oooo00?o0000ooooooooool00oooool6oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mV
IVH02omVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00[oIVIV00?o0000ogmoOomo
Ogl02OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@;o00006?nc/k<00ol0003oVIVIoiVIV@05oiVIV@03
o`000?moOgooOgmo00?oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C00Boda<C003
o`000?mVIVKoIVIV00;oIVIV00Co0000ogmoOomoOgoo00000onIVIT00ol0003o/k>cok>c/`03ok>c
/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00onc/k<01?l0003oVIVIoiVIVOl00002
ogmoO`05o`000?mVIVKoIVIVofIVI_l000000om<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<
C4coC4a<00;oC4a<00?o0000ofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00002ok>c/`03o`00
0?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT01_l0003oOgmoogmoOol0003oIVIV
o`0000;oC4a<00?o0000oc<c<olc<c<01olc<c<01Ol0003oC4a<o`000?mVIVKo000000;oOgmo00?o
0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c003o`000?nc/k?o000000;oVIVI00Co
0000ogmoOol0003o00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000Ko
oooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo1OnIVIT00ol0003oOgmo
ogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`2o`0000coIVIV
00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c
00?o0000oiVIVOnIVIT01OnIVIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00;oIVIV
00?o0000oda<C?m<C4`04_m<C4`00ol0003oIVIVofIVIP02ofIVIP04o`000?moOgooOgmoo`0000?o
VIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o
/k>c00Co0000oiVIVOnIVIWo00000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000?oC4a<00?o0000
oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Ko0000ogmoOomoOgoo0000
oiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002
ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01olc<c<00ol0003oC4a<o`000002
ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c00<o`000?nc
/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co00002Olc<c<01Ol0003oC4a<o`00
0?mVIVKo000000Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo1?nI
VIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<
C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onI
VIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00GoVIVI00?o0000ogmoOomoOgl00omo
Ogl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<01;oC4a<00Go0000ofIVI_mVIVKoIVIV
o`000003ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001Onc/k<00ol0003oc<c<olc<c004olc<c003
o`000?nc/k?o/k>c00;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`04o`000?mVIVKoIVIV
o`0000CoC4a<00?o0000oc<c<olc<c<01Olc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co
0000ogmoOomoOgoo00000_nIVIT01?l0003o/k>cok>c/ol00008olc<c007o`000?nc/k?o/k>cok>c
/ol0003oVIVIo`000002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<0
1?l0003oC4a<oda<C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<
olc<c006olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co0000
2Olc<c<2o`000003ofIVI_l0003ooooo00Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oo
oooooooo00?ooooo0onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o
0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0:ofIVIP03o`000?moOgooOgmo00WoOgmo00?o
0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00KoVIVI00?o
0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<01;oC4a<00Go
0000ofIVI_mVIVKoIVIVo`000002ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<0
0onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00;o/k>c00Go0000oiVIVOnIVIWo
VIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01Olc<c<01Ol0
003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01?l0003o/k>cok>c
/ol00008olc<c007o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000002ogmoO`03o`000?mVIVKo0000
00;oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP05o`000?moOgoo
0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>co`000?nIVIT0
0_l00002ofIVIP03o`000?m<C4co000000Wo<c<c0_l000000omVIVKo0000ooooo`05ooooo`7o0000
0Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`;oVIVI00?o0000ogmoOomoOgl02?mo
Ogl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<0_l0000<ofIVIP03o`000?mo
OgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nI
VIWoVIVI00KoVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<
C4coC4a<01;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`05o`000?nIVIWoVIVIoiVIVOl0
00001Onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00;o/k>c00Go0000oiVIVOnI
VIWoVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01Olc<c<0
1Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01?l0003o/k>c
ok>c/ol00008olc<c007o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000002ogmoO`04o`000?mVIVKo
IVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<00ol0003oC4a<o`000002ofIVIP03o`000?mo
Ogoo000000;oVIVI00?o0000ok>c/ol000002?o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?mo
Ogoo0000ofIVI_l0003oC4a<o`0000Wo<c<c00Go0000oda<C?l0003o0000ogmoO`06ooooo`7o0000
0Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`03oiVIVOl0003oOgmo00WoOgmo00?o
0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o
0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o
0000oiVIVOnIVIT01_nIVIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o
0000oda<C?m<C4`04_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00?o0000oiVIVOnIVIT0
0_nIVIT00ol0003o/k>cok>c/`02ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<0
0_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0
003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01_l0003oOgmoogmoOol0
003oVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01ol0003o/k>cok>c/onc/k?o0000oiVI
VOl000000_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<
C?m<C4co00000_mVIVH01ol0003oOgmoo`000?nIVIWo0000ok>c/ol000002Oo<c<`03?l0003o/k>c
ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000So<c<c00?o0000oda<C?m<C4`0
0_l000000omoOgooooooooooo`04ooooo`7o00000Oooool1ooooo`009?ooool00ol0003ooooooooo
o`03ooooo`03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH03?mVIVH00ol0003oC4a<oda<
C00Foda<C003o`000?mVIVKoIVIV00[oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVI
V@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT01onIVIT00ol0003oOgmoogmo
O`03ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<C4`04_m<C4`01Ol0003oIVIVofIV
I_mVIVKo000000?oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`02ok>c/`03o`00
0?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00003ogmoO`04
o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co
000000;oIVIV00Ko0000ogmoOomoOgoo0000oiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<
00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0
003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV0_l00002oiVIV@03o`000?nc/k?o
000000Woc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00008
oc<c<`03o`000?m<C4coC4a<00;o000000?oOgmoooooooooool01?ooool1o`00007ooooo0Oooool0
02Cooooo0_l00004ooooo`[oOgmo00?o0000ofIVI_mVIVH02omVIVH2o`0001OoC4a<0_l0000<ofIV
IP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Gok>c
/`03o`000?nIVIWoVIVI00KoVIVI0_l00005ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<
C?m<C4`04_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00?o0000oiVIVOnIVIT00_nIVIT0
0ol0003o/k>cok>c/`02ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<0
1Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000002oda<C003o`00
0?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`00
00;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01ol0003o/k>cok>c/onc/k?o0000oiVIVOl00000
0_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00?o0000oda<C?l00000
0_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`03?l0003o
/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000Wo<c<c00Oo0000oda<C?l0
003oIVIVo`000?moOgoo000000Cooooo0_l00002ooooo`009?ooool00ol0003oooooooooo`03oooo
o`WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV
00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c
01Oo/k>c00?o0000oiVIVOnIVIT01_nIVIT00ol0003oOgmoogmoO`04ogmoO`03o`000?mVIVKoIVIV
00?oIVIV00?o0000oda<C?m<C4`04_m<C4`00ol0003oIVIVofIVIP02ofIVIP05o`000?moOgooOgmo
ogmoOol000000onIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000
ok>c/onc/k<00onc/k<01?l0003oVIVIoiVIVOl00002ogmoO`05o`000?mVIVKoIVIVofIVI_l00000
0om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01Ol0003o
OgmoogmoOol0003oVIVI00;o00000_nc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>c
o`0000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`05o`000?m<
C4co0000ofIVI_l000000_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<
00?o0000ok>c/ol000000_nIVIT01ol0003oOgmoo`000?mVIVKo0000oda<C?l000002?lc<c<02?l0
003oC4a<oda<C?l0003oIVIVo`000?moOgoo00001Oooool1o`00007ooooo0Oooool002Cooooo00?o
0000ooooooooool00oooool8ogmoO`03o`000?mVIVKoIVIV00coIVIV00?o0000oda<C?m<C4`05_m<
C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onI
VIT00ol0003o/k>cok>c/`0Hok>c/`03o`000?nIVIWoVIVI00KoVIVI00?o0000ogmoOomoOgl01?mo
Ogl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<01;oC4a<00?o0000ofIVI_mVIVH00_mV
IVH01Ol0003oOgmoogmoOomoOgoo000000?oVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<
olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01Ol0003o
IVIVofIVI_mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01ol0003oC4a<oda<C?m<C4co
0000ofIVI_l000000omoOgl00ol0003oVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co
0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000Wo
<c<c00Go0000oda<C?l0003oIVIVo`000002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<
c?o<c<`01_o<c<`00ol0003o/k>co`000002oiVIV@07o`000?moOgoo0000ofIVI_l0003oC4a<o`00
0008oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol00005ooooo`7o00000Oooool1oooo
o`009?ooool00ol0003oooooooooo`03ooooo`OoOgmo00?o0000ofIVI_mVIVH03?mVIVH00ol0003o
C4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003o
VIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT01_nIVIT00ol0003o
OgmoogmoO`04ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<C4`04_m<C4`00ol0003o
IVIVofIVIP02ofIVIP05o`000?moOgooOgmoogmoOol000001?nIVIT00ol0003o/k>cok>c/`02ok>c
/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo
000000;oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`05oc<c<`05o`000?m<
C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@05o`000?nc/k?o/k>cok>c
/ol000002?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000
oda<C?m<C4co00002?lc<c<00ol0003oC4a<o`000002ofIVIP06o`000?moOgooOgmoo`000?nIVIWo
00000_nc/k<00ol0003oc<c<olc<c005olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Co0000ogmo
Ool0003o00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`03o`000?m<C4coC4a<00;o00000_moOgl0
0ol0003oooooooooo`03ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03oooo
o`KoOgmo00?o0000ofIVI_mVIVH03?mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV
00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c
01Oo/k>c00?o0000oiVIVOnIVIT01onIVIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV
00CoIVIV00?o0000oda<C?m<C4`04_m<C4`00ol0003oIVIVofIVIP02ofIVIP05o`000?moOgooOgmo
ogmoOol000000onIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000
ok>c/onc/k<00onc/k<01?l0003oVIVIoiVIVOl00002ogmoO`05o`000?mVIVKoIVIVofIVI_l00000
0om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01_l0003o
OgmoogmoOol0003oVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol0
0002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<01Ol0003oC4a<
o`000?mVIVKo000000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c00<
o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co00002?lc<c<02?l0003o
C4a<oda<C?l0003oIVIVo`000?moOgoo00001_ooool1o`00007ooooo0Oooool002Cooooo00?o0000
ooooooooool00oooool5ogmoO`;o00003?mVIVH2o`0001OoC4a<0_l0000=ofIVIP03o`000?moOgoo
Ogmo00SoOgmo0_l0000<oiVIV@;o00006Onc/k<00ol0003oVIVIoiVIV@07oiVIV@03o`000?moOgoo
Ogmo00CoOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00Coda<C005o`000?mVIVKo
IVIVofIVI_l000000omoOgl01?l0003oVIVIoiVIVOnIVIT2o`0000Go/k>c00?o0000olc<c?o<c<`0
1?o<c<`00ol0003o/k>cok>c/`02ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01?l0003o
IVIVofIVI_l00004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01_l0
003oIVIVofIVI_l0003oOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c004o`00
0?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00008oc<c
<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<
c<coc<c<00Koc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l0
0008oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol00006ooooo`7o00000Oooool1oooo
o`009?ooool00ol0003oooooooooo`03ooooo`CoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003o
C4a<oda<C00Foda<C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003o
VIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01So/k>c00?o0000oiVIVOnIVIT02?nIVIT00ol0003o
OgmoogmoO`04ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<C4`04om<C4`01Ol0003o
IVIVofIVI_mVIVKo000000?oOgmo00Go0000oiVIVOnIVIWoVIVIo`000006ok>c/`03o`000?o<c<co
c<c<00?oc<c<00?o0000ok>c/onc/k<00onc/k<01?l0003oVIVIoiVIVOl00002ogmoO`05o`000?mV
IVKoIVIVofIVI_l000001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<
00Ko0000ofIVI_mVIVKo0000ogmoOol00002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`0
1?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co0000
2?lc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo0_l00003ok>c/`03o`000?o<c<coc<c<
00Koc<c<00Go0000ok>c/onc/k?o0000oiVIV@02o`0000;oIVIV00?o0000oda<C?l000002?lc<c<0
2?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo00001_ooool1o`00007ooooo0Oooool002Cooooo
00?o0000ooooooooool00oooool3ogmoO`03o`000?mVIVKoIVIV00coIVIV00?o0000oda<C?m<C4`0
5_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT0
2onIVIT00ol0003o/k>cok>c/`0Hok>c/`03o`000?nIVIWoVIVI00SoVIVI00?o0000ogmoOomoOgl0
1?moOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<01?oC4a<00Go0000ofIVI_mVIVKo
IVIVo`000003ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001_nc/k<00ol0003oc<c<olc<c004olc<
c003o`000?nc/k?o/k>c00;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`05o`000?mVIVKo
IVIVofIVI_l000000om<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Ko
0000ofIVI_mVIVKo0000ogmoOol00002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01?l0
003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc
<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003o
c<c<olc<c006olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co
00002Olc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000005ooooo`7o00000Ooo
ool1ooooo`004_ooool4o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h6ooooo`03
o`000?oooooooooo00?ooooo0omoOgl00ol0003oIVIVofIVIP0:ofIVIP;o00005om<C4`2o`0000go
IVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo
/k>c0_l00009oiVIV@;o00001_moOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<01?o
C4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000?oVIVI00?o0000ok>c
/onc/k<00onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Go0000oiVI
VOnIVIWoVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01Olc
<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01Ol0003o
/k>cok>c/onc/k?o000000Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002
ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`05
o`000?nIVIWo0000ok>c/ol000002Oo<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000
ofIVI_l0003oC4a<o`0000Wo<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00000
1Oooool1o`00007ooooo0Oooool001Cooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Kooooo00?o0000ooooooooool00oooool2ogmoO`03o`000?mVIVKoIVIV00[oIVIV
00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?moOgooOgmo00SoOgmo
00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00WoVIVI
00?o0000ogmoOomoOgl01?moOgl00ol0003oIVIVofIVIP04ofIVIP03o`000?m<C4coC4a<01;oC4a<
00?o0000ofIVI_mVIVH00omVIVH01?l0003oOgmoogmoOol00004oiVIV@03o`000?nc/k?o/k>c00?o
/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`05o`000?nIVIWoVIVIoiVI
VOl000000_moOgl01?l0003oIVIVofIVI_l00004oda<C003o`000?lc<c?o<c<c00Go<c<c00Go0000
oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o
/k>co`000007olc<c007o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000002ogmoO`04o`000?mVIVKo
IVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02?l0003oC4a<oda<C?l0003oIVIVo`000?mo
Ogoo00000_nIVIT00ol0003o/k>co`000009olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmo
Ool0003oIVIVo`000?m<C4co00002Olc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVI
o`000005ooooo`7o00000Oooool1ooooo`005?ooool00ol0003oooooooooo`02ooooo`05oa0@4?oo
ooooooooooooool@41001_ooool00ol0003oooooooooo`03ooooo`03ogmoOol0003oIVIV00coIVIV
00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo
00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00WoVIVI
00?o0000ogmoOomoOgl01OmoOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<01?oC4a<
00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000?oVIVI00?o0000ok>c/onc
/k<00onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Go0000oiVIVOnI
VIWoVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01Olc<c<0
1Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000onIVIT01?l0003o/k>c
ok>c/ol00008olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0
003oC4a<oda<C?l00008oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl00ol0003oVIVI
o`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmo
o`000?mVIVKo0000oda<C?l00009oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo
000000Kooooo0Ol00001ooooo`7ooooo000Dooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`000006ooooo`?o00000oooool00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4co
C4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWo
VIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@09oiVIV@03o`000?moOgoo
Ogmo00GoOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00Coda<C003o`000?mVIVKo
IVIV00;oIVIV00Go0000ogmoOomoOgooOgmoo`000004oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o
0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`02ok>c/`05o`000?nIVIWoVIVIoiVIVOl00000
0_moOgl01Ol0003oIVIVofIVI_mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003o
C4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01?l0003o/k>cok>c/ol0
0008olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`00
0?m<C4coC4a<o`0000So<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`03o`000?nIVIWo
000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003o/k>co`000002oiVIV@07o`000?moOgoo
0000ofIVI_l0003oC4a<o`000008oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003o
VIVIo`0000Cooooo0ol00002ooooo`005?ooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000001_ooool00ol0003oooooooooo`3oooooocoooooo0Ol00001ooooo`7ooooo000D
ooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oo
oooooooo0?oooooo?oooool1o`00007ooooo0Oooool001Cooooo00?o0000ooooooooool00_ooool0
1OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool0ooooooloooooo`7o00000Ooo
ool1ooooo`004_ooool00omEEEGoIVIVo`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_oo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool09_oo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool09ooo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool00ooo
ool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03
ooooo`7o00000Oooool1ooooo`009?ooooooo`0004?o00000_ooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-7.04757, -6.93977, 0.0606246, \
0.0606246}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.339744 0.0641026 0.339744 0.0641026 [
[.08333 -0.0125 -6 -9 ]
[.08333 -0.0125 6 0 ]
[.21154 -0.0125 -6 -9 ]
[.21154 -0.0125 6 0 ]
[.33974 -0.0125 -3 -9 ]
[.33974 -0.0125 3 0 ]
[.46795 -0.0125 -3 -9 ]
[.46795 -0.0125 3 0 ]
[.59615 -0.0125 -3 -9 ]
[.59615 -0.0125 3 0 ]
[.72436 -0.0125 -3 -9 ]
[.72436 -0.0125 3 0 ]
[.85256 -0.0125 -3 -9 ]
[.85256 -0.0125 3 0 ]
[.98077 -0.0125 -6 -9 ]
[.98077 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5 -21 ]
[.5 -0.0125 5 -9 ]
[-0.0125 .08333 -12 -4.5 ]
[-0.0125 .08333 0 4.5 ]
[-0.0125 .21154 -12 -4.5 ]
[-0.0125 .21154 0 4.5 ]
[-0.0125 .33974 -6 -4.5 ]
[-0.0125 .33974 0 4.5 ]
[-0.0125 .46795 -6 -4.5 ]
[-0.0125 .46795 0 4.5 ]
[-0.0125 .59615 -6 -4.5 ]
[-0.0125 .59615 0 4.5 ]
[-0.0125 .72436 -6 -4.5 ]
[-0.0125 .72436 0 4.5 ]
[-0.0125 .85256 -6 -4.5 ]
[-0.0125 .85256 0 4.5 ]
[-0.0125 .98077 -12 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -24 -5 ]
[-0.01875 .5 -12 5 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08333 0 m
.08333 .00625 L
s
[(-4)] .08333 -0.0125 0 1 Mshowa
.21154 0 m
.21154 .00625 L
s
[(-2)] .21154 -0.0125 0 1 Mshowa
.33974 0 m
.33974 .00625 L
s
[(0)] .33974 -0.0125 0 1 Mshowa
.46795 0 m
.46795 .00625 L
s
[(2)] .46795 -0.0125 0 1 Mshowa
.59615 0 m
.59615 .00625 L
s
[(4)] .59615 -0.0125 0 1 Mshowa
.72436 0 m
.72436 .00625 L
s
[(6)] .72436 -0.0125 0 1 Mshowa
.85256 0 m
.85256 .00625 L
s
[(8)] .85256 -0.0125 0 1 Mshowa
.98077 0 m
.98077 .00625 L
s
[(10)] .98077 -0.0125 0 1 Mshowa
.125 Mabswid
.11538 0 m
.11538 .00375 L
s
.14744 0 m
.14744 .00375 L
s
.17949 0 m
.17949 .00375 L
s
.24359 0 m
.24359 .00375 L
s
.27564 0 m
.27564 .00375 L
s
.30769 0 m
.30769 .00375 L
s
.37179 0 m
.37179 .00375 L
s
.40385 0 m
.40385 .00375 L
s
.4359 0 m
.4359 .00375 L
s
.5 0 m
.5 .00375 L
s
.53205 0 m
.53205 .00375 L
s
.5641 0 m
.5641 .00375 L
s
.62821 0 m
.62821 .00375 L
s
.66026 0 m
.66026 .00375 L
s
.69231 0 m
.69231 .00375 L
s
.75641 0 m
.75641 .00375 L
s
.78846 0 m
.78846 .00375 L
s
.82051 0 m
.82051 .00375 L
s
.88462 0 m
.88462 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.94872 0 m
.94872 .00375 L
s
.05128 0 m
.05128 .00375 L
s
.01923 0 m
.01923 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66 -25 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .08333 m
.00625 .08333 L
s
[(-4)] -0.0125 .08333 1 0 Mshowa
0 .21154 m
.00625 .21154 L
s
[(-2)] -0.0125 .21154 1 0 Mshowa
0 .33974 m
.00625 .33974 L
s
[(0)] -0.0125 .33974 1 0 Mshowa
0 .46795 m
.00625 .46795 L
s
[(2)] -0.0125 .46795 1 0 Mshowa
0 .59615 m
.00625 .59615 L
s
[(4)] -0.0125 .59615 1 0 Mshowa
0 .72436 m
.00625 .72436 L
s
[(6)] -0.0125 .72436 1 0 Mshowa
0 .85256 m
.00625 .85256 L
s
[(8)] -0.0125 .85256 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(10)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .11538 m
.00375 .11538 L
s
0 .14744 m
.00375 .14744 L
s
0 .17949 m
.00375 .17949 L
s
0 .24359 m
.00375 .24359 L
s
0 .27564 m
.00375 .27564 L
s
0 .30769 m
.00375 .30769 L
s
0 .37179 m
.00375 .37179 L
s
0 .40385 m
.00375 .40385 L
s
0 .4359 m
.00375 .4359 L
s
0 .5 m
.00375 .5 L
s
0 .53205 m
.00375 .53205 L
s
0 .5641 m
.00375 .5641 L
s
0 .62821 m
.00375 .62821 L
s
0 .66026 m
.00375 .66026 L
s
0 .69231 m
.00375 .69231 L
s
0 .75641 m
.00375 .75641 L
s
0 .78846 m
.00375 .78846 L
s
0 .82051 m
.00375 .82051 L
s
0 .88462 m
.00375 .88462 L
s
0 .91667 m
.00375 .91667 L
s
0 .94872 m
.00375 .94872 L
s
0 .05128 m
.00375 .05128 L
s
0 .01923 m
.00375 .01923 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
-0.01875 .5 -84 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
66 10 translate
90 rotate
-66 -10 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.08333 .99375 m
.08333 1 L
s
.21154 .99375 m
.21154 1 L
s
.33974 .99375 m
.33974 1 L
s
.46795 .99375 m
.46795 1 L
s
.59615 .99375 m
.59615 1 L
s
.72436 .99375 m
.72436 1 L
s
.85256 .99375 m
.85256 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.11538 .99625 m
.11538 1 L
s
.14744 .99625 m
.14744 1 L
s
.17949 .99625 m
.17949 1 L
s
.24359 .99625 m
.24359 1 L
s
.27564 .99625 m
.27564 1 L
s
.30769 .99625 m
.30769 1 L
s
.37179 .99625 m
.37179 1 L
s
.40385 .99625 m
.40385 1 L
s
.4359 .99625 m
.4359 1 L
s
.5 .99625 m
.5 1 L
s
.53205 .99625 m
.53205 1 L
s
.5641 .99625 m
.5641 1 L
s
.62821 .99625 m
.62821 1 L
s
.66026 .99625 m
.66026 1 L
s
.69231 .99625 m
.69231 1 L
s
.75641 .99625 m
.75641 1 L
s
.78846 .99625 m
.78846 1 L
s
.82051 .99625 m
.82051 1 L
s
.88462 .99625 m
.88462 1 L
s
.91667 .99625 m
.91667 1 L
s
.94872 .99625 m
.94872 1 L
s
.05128 .99625 m
.05128 1 L
s
.01923 .99625 m
.01923 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .08333 m
1 .08333 L
s
.99375 .21154 m
1 .21154 L
s
.99375 .33974 m
1 .33974 L
s
.99375 .46795 m
1 .46795 L
s
.99375 .59615 m
1 .59615 L
s
.99375 .72436 m
1 .72436 L
s
.99375 .85256 m
1 .85256 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .11538 m
1 .11538 L
s
.99625 .14744 m
1 .14744 L
s
.99625 .17949 m
1 .17949 L
s
.99625 .24359 m
1 .24359 L
s
.99625 .27564 m
1 .27564 L
s
.99625 .30769 m
1 .30769 L
s
.99625 .37179 m
1 .37179 L
s
.99625 .40385 m
1 .40385 L
s
.99625 .4359 m
1 .4359 L
s
.99625 .5 m
1 .5 L
s
.99625 .53205 m
1 .53205 L
s
.99625 .5641 m
1 .5641 L
s
.99625 .62821 m
1 .62821 L
s
.99625 .66026 m
1 .66026 L
s
.99625 .69231 m
1 .69231 L
s
.99625 .75641 m
1 .75641 L
s
.99625 .78846 m
1 .78846 L
s
.99625 .82051 m
1 .82051 L
s
.99625 .88462 m
1 .88462 L
s
.99625 .91667 m
1 .91667 L
s
.99625 .94872 m
1 .94872 L
s
.99625 .05128 m
1 .05128 L
s
.99625 .01923 m
1 .01923 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.6 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.7 g
.01923 .9412 m
.0282 .93221 L
.02894 .93149 L
.03794 .92249 L
.03866 .92178 L
.04765 .91278 L
.04837 .91207 L
.05736 .90307 L
.05808 .90235 L
.06708 .89336 L
.06779 .89264 L
.07679 .88364 L
.07751 .88293 L
.0865 .87393 L
.08722 .87322 L
.09621 .86422 L
.09693 .8635 L
.10593 .85451 L
.10664 .85379 L
.11564 .84479 L
.11636 .84408 L
.12535 .83508 L
.12607 .83437 L
.13506 .82537 L
.13578 .82465 L
.14478 .81566 L
.14549 .81494 L
.15449 .80594 L
.15521 .80523 L
.1642 .79623 L
.16492 .79552 L
.17391 .78652 L
.17463 .7858 L
.18363 .77681 L
.18434 .77609 L
.19334 .76709 L
.19406 .76638 L
.20305 .75738 L
.20377 .75666 L
.21276 .74767 L
.21348 .74695 L
.22248 .73796 L
.22319 .73724 L
.23219 .72824 L
.23291 .72753 L
.2419 .71853 L
.24262 .71781 L
.25161 .70882 L
.25233 .7081 L
.26133 .69911 L
.26204 .69839 L
.27104 .68939 L
.27176 .68868 L
.28075 .67968 L
.28147 .67896 L
.29046 .66997 L
.29118 .66925 L
.30018 .66026 L
.30089 .65954 L
.30989 .65054 L
.31061 .64983 L
.3196 .64083 L
.32032 .64011 L
.32931 .63112 L
.33003 .6304 L
.33897 .62141 L
.33974 .62069 L
.34946 .61368 L
.35208 .61169 L
.35917 .60538 L
.36297 .60198 L
.36888 .596 L
.37262 .59227 L
.37859 .58571 L
.3815 .58256 L
.38831 .5746 L
.38982 .57284 L
.39774 .56313 L
.39802 .56276 L
.40542 .55342 L
.40773 .55025 L
.41272 .54371 L
.41744 .5371 L
.41972 .53399 L
.42655 .52428 L
.42716 .52335 L
.43327 .51457 L
.43687 .50905 L
.4397 .50486 L
.44601 .49514 L
.44658 .4942 L
.45227 .48543 L
.45629 .47885 L
.45827 .47572 L
.46427 .46601 L
.46601 .46301 L
.47012 .45629 L
.47572 .44668 L
.47577 .44658 L
.48154 .43687 L
.48543 .4299 L
.48703 .42716 L
.49259 .41744 L
.49514 .41269 L
.49795 .40773 L
.50331 .39802 L
.50486 .39503 L
.50858 .38831 L
.51375 .37859 L
.51457 .37696 L
.51893 .36888 L
.52395 .35917 L
.52428 .35848 L
.52905 .34946 L
.53393 .33974 L
.53399 .3396 L
.53895 .33003 L
.54371 .32033 L
.54371 .32032 L
.54865 .31061 L
.55333 .30089 L
.55342 .30069 L
.55816 .29118 L
.56278 .28147 L
.56313 .28067 L
.56751 .27176 L
.57208 .26204 L
.57284 .26029 L
.57669 .25233 L
.58123 .24262 L
.58256 .23956 L
.58571 .23291 L
.59023 .22319 L
.59227 .21847 L
.5946 .21348 L
.59908 .20377 L
.60198 .19703 L
.60335 .19406 L
.6078 .18434 L
.61169 .17525 L
.61198 .17463 L
.61638 .16492 L
.62059 .15521 L
.62141 .15315 L
.62483 .14549 L
.62908 .13578 L
.63112 .13072 L
.63317 .12607 L
.63742 .11636 L
.64083 .10796 L
.6414 .10664 L
.64562 .09693 L
.64966 .08722 L
.65054 .08489 L
.65371 .07751 L
.65781 .06779 L
.66026 .0615 L
.6617 .05808 L
.66581 .04837 L
.66966 .03866 L
.66997 .0378 L
.67368 .02894 L
.67765 .01923 L
.01923 .01923 L
F
0 g
.01923 .9412 m
.0282 .93221 L
.02894 .93149 L
.03794 .92249 L
.03866 .92178 L
.04765 .91278 L
.04837 .91207 L
.05736 .90307 L
.05808 .90235 L
.06708 .89336 L
.06779 .89264 L
.07679 .88364 L
.07751 .88293 L
.0865 .87393 L
.08722 .87322 L
.09621 .86422 L
.09693 .8635 L
.10593 .85451 L
.10664 .85379 L
.11564 .84479 L
.11636 .84408 L
.12535 .83508 L
.12607 .83437 L
.13506 .82537 L
.13578 .82465 L
.14478 .81566 L
.14549 .81494 L
.15449 .80594 L
.15521 .80523 L
.1642 .79623 L
.16492 .79552 L
.17391 .78652 L
.17463 .7858 L
.18363 .77681 L
.18434 .77609 L
.19334 .76709 L
.19406 .76638 L
.20305 .75738 L
.20377 .75666 L
.21276 .74767 L
.21348 .74695 L
.22248 .73796 L
.22319 .73724 L
.23219 .72824 L
.23291 .72753 L
.2419 .71853 L
.24262 .71781 L
.25161 .70882 L
.25233 .7081 L
.26133 .69911 L
Mistroke
.26204 .69839 L
.27104 .68939 L
.27176 .68868 L
.28075 .67968 L
.28147 .67896 L
.29046 .66997 L
.29118 .66925 L
.30018 .66026 L
.30089 .65954 L
.30989 .65054 L
.31061 .64983 L
.3196 .64083 L
.32032 .64011 L
.32931 .63112 L
.33003 .6304 L
.33897 .62141 L
.33974 .62069 L
.34946 .61368 L
.35208 .61169 L
.35917 .60538 L
.36297 .60198 L
.36888 .596 L
.37262 .59227 L
.37859 .58571 L
.3815 .58256 L
.38831 .5746 L
.38982 .57284 L
.39774 .56313 L
.39802 .56276 L
.40542 .55342 L
.40773 .55025 L
.41272 .54371 L
.41744 .5371 L
.41972 .53399 L
.42655 .52428 L
.42716 .52335 L
.43327 .51457 L
.43687 .50905 L
.4397 .50486 L
.44601 .49514 L
.44658 .4942 L
.45227 .48543 L
.45629 .47885 L
.45827 .47572 L
.46427 .46601 L
.46601 .46301 L
.47012 .45629 L
.47572 .44668 L
.47577 .44658 L
.48154 .43687 L
Mistroke
.48543 .4299 L
.48703 .42716 L
.49259 .41744 L
.49514 .41269 L
.49795 .40773 L
.50331 .39802 L
.50486 .39503 L
.50858 .38831 L
.51375 .37859 L
.51457 .37696 L
.51893 .36888 L
.52395 .35917 L
.52428 .35848 L
.52905 .34946 L
.53393 .33974 L
.53399 .3396 L
.53895 .33003 L
.54371 .32033 L
.54371 .32032 L
.54865 .31061 L
.55333 .30089 L
.55342 .30069 L
.55816 .29118 L
.56278 .28147 L
.56313 .28067 L
.56751 .27176 L
.57208 .26204 L
.57284 .26029 L
.57669 .25233 L
.58123 .24262 L
.58256 .23956 L
.58571 .23291 L
.59023 .22319 L
.59227 .21847 L
.5946 .21348 L
.59908 .20377 L
.60198 .19703 L
.60335 .19406 L
.6078 .18434 L
.61169 .17525 L
.61198 .17463 L
.61638 .16492 L
.62059 .15521 L
.62141 .15315 L
.62483 .14549 L
.62908 .13578 L
.63112 .13072 L
.63317 .12607 L
.63742 .11636 L
.64083 .10796 L
Mistroke
.6414 .10664 L
.64562 .09693 L
.64966 .08722 L
.65054 .08489 L
.65371 .07751 L
.65781 .06779 L
.66026 .0615 L
.6617 .05808 L
.66581 .04837 L
.66966 .03866 L
.66997 .0378 L
.67368 .02894 L
.67765 .01923 L
Mfstroke
.6 g
.01923 .86263 m
.02743 .85451 L
.02894 .85292 L
.03707 .84479 L
.03866 .84321 L
.04678 .83508 L
.04837 .8335 L
.05649 .82537 L
.05808 .82378 L
.06621 .81566 L
.06779 .81407 L
.07592 .80594 L
.07751 .80436 L
.08563 .79623 L
.08722 .79465 L
.09534 .78652 L
.09693 .78493 L
.10506 .77681 L
.10664 .77522 L
.11477 .76709 L
.11636 .76551 L
.12448 .75738 L
.12607 .7558 L
.13419 .74767 L
.13578 .74608 L
.14391 .73796 L
.14549 .73637 L
.15362 .72824 L
.15521 .72666 L
.16333 .71853 L
.16492 .71695 L
.17304 .70882 L
.17463 .70723 L
.18276 .69911 L
.18434 .69752 L
.19247 .68939 L
.19406 .68781 L
.20218 .67968 L
.20377 .6781 L
.21189 .66997 L
.21348 .66838 L
.22161 .66026 L
.22319 .65867 L
.23132 .65054 L
.23291 .64896 L
.24103 .64083 L
.24262 .63925 L
.25074 .63112 L
.25233 .62953 L
.26046 .62141 L
.26204 .61982 L
.27017 .61169 L
.27176 .61011 L
.27988 .60198 L
.28147 .6004 L
.28959 .59227 L
.29118 .59068 L
.29931 .58256 L
.30089 .58097 L
.30902 .57284 L
.31061 .57126 L
.31873 .56313 L
.32032 .56155 L
.32844 .55342 L
.33003 .55183 L
.33832 .54371 L
.33974 .54212 L
.34585 .53399 L
.34946 .52897 L
.35292 .52428 L
.35917 .51578 L
.36005 .51457 L
.36708 .50486 L
.36888 .50235 L
.37399 .49514 L
.37859 .4886 L
.38079 .48543 L
.38749 .47572 L
.38831 .47453 L
.39404 .46601 L
.39802 .46005 L
.40049 .45629 L
.40685 .44658 L
.40773 .44522 L
.41306 .43687 L
.41744 .42997 L
.41919 .42716 L
.42524 .41744 L
.42716 .41434 L
.43115 .40773 L
.43687 .39831 L
.43704 .39802 L
.44278 .38831 L
.44658 .38188 L
.44847 .37859 L
.45409 .36888 L
.45629 .36507 L
.45961 .35917 L
.46512 .34946 L
.46601 .34788 L
.47048 .33974 L
.47572 .3303 L
.47586 .33003 L
.4811 .32032 L
.48543 .31234 L
.48633 .31061 L
.49148 .30089 L
.49514 .29402 L
.49659 .29118 L
.50165 .28147 L
.50486 .27533 L
.50664 .27176 L
.51161 .26204 L
.51457 .25628 L
.5165 .25233 L
.52139 .24262 L
.52428 .23688 L
.52619 .23291 L
.53099 .22319 L
.53399 .21713 L
.53571 .21348 L
.54042 .20377 L
.54371 .19703 L
.54508 .19406 L
.5497 .18434 L
.55342 .1766 L
.5543 .17463 L
.55883 .16492 L
.56313 .15583 L
.56341 .15521 L
.56783 .14549 L
.57236 .13578 L
.57284 .13473 L
.5767 .12607 L
.58116 .11636 L
.58256 .1133 L
.58545 .10664 L
.58984 .09693 L
.59227 .09155 L
.5941 .08722 L
.5984 .07751 L
.60198 .06948 L
.60268 .06779 L
.60686 .05808 L
.61114 .04837 L
.61169 .04711 L
.61522 .03866 L
.61944 .02894 L
.62141 .02444 L
.62351 .01923 L
.01923 .01923 L
F
0 g
.01923 .86263 m
.02743 .85451 L
.02894 .85292 L
.03707 .84479 L
.03866 .84321 L
.04678 .83508 L
.04837 .8335 L
.05649 .82537 L
.05808 .82378 L
.06621 .81566 L
.06779 .81407 L
.07592 .80594 L
.07751 .80436 L
.08563 .79623 L
.08722 .79465 L
.09534 .78652 L
.09693 .78493 L
.10506 .77681 L
.10664 .77522 L
.11477 .76709 L
.11636 .76551 L
.12448 .75738 L
.12607 .7558 L
.13419 .74767 L
.13578 .74608 L
.14391 .73796 L
.14549 .73637 L
.15362 .72824 L
.15521 .72666 L
.16333 .71853 L
.16492 .71695 L
.17304 .70882 L
.17463 .70723 L
.18276 .69911 L
.18434 .69752 L
.19247 .68939 L
.19406 .68781 L
.20218 .67968 L
.20377 .6781 L
.21189 .66997 L
.21348 .66838 L
.22161 .66026 L
.22319 .65867 L
.23132 .65054 L
.23291 .64896 L
.24103 .64083 L
.24262 .63925 L
.25074 .63112 L
.25233 .62953 L
.26046 .62141 L
Mistroke
.26204 .61982 L
.27017 .61169 L
.27176 .61011 L
.27988 .60198 L
.28147 .6004 L
.28959 .59227 L
.29118 .59068 L
.29931 .58256 L
.30089 .58097 L
.30902 .57284 L
.31061 .57126 L
.31873 .56313 L
.32032 .56155 L
.32844 .55342 L
.33003 .55183 L
.33832 .54371 L
.33974 .54212 L
.34585 .53399 L
.34946 .52897 L
.35292 .52428 L
.35917 .51578 L
.36005 .51457 L
.36708 .50486 L
.36888 .50235 L
.37399 .49514 L
.37859 .4886 L
.38079 .48543 L
.38749 .47572 L
.38831 .47453 L
.39404 .46601 L
.39802 .46005 L
.40049 .45629 L
.40685 .44658 L
.40773 .44522 L
.41306 .43687 L
.41744 .42997 L
.41919 .42716 L
.42524 .41744 L
.42716 .41434 L
.43115 .40773 L
.43687 .39831 L
.43704 .39802 L
.44278 .38831 L
.44658 .38188 L
.44847 .37859 L
.45409 .36888 L
.45629 .36507 L
.45961 .35917 L
.46512 .34946 L
.46601 .34788 L
Mistroke
.47048 .33974 L
.47572 .3303 L
.47586 .33003 L
.4811 .32032 L
.48543 .31234 L
.48633 .31061 L
.49148 .30089 L
.49514 .29402 L
.49659 .29118 L
.50165 .28147 L
.50486 .27533 L
.50664 .27176 L
.51161 .26204 L
.51457 .25628 L
.5165 .25233 L
.52139 .24262 L
.52428 .23688 L
.52619 .23291 L
.53099 .22319 L
.53399 .21713 L
.53571 .21348 L
.54042 .20377 L
.54371 .19703 L
.54508 .19406 L
.5497 .18434 L
.55342 .1766 L
.5543 .17463 L
.55883 .16492 L
.56313 .15583 L
.56341 .15521 L
.56783 .14549 L
.57236 .13578 L
.57284 .13473 L
.5767 .12607 L
.58116 .11636 L
.58256 .1133 L
.58545 .10664 L
.58984 .09693 L
.59227 .09155 L
.5941 .08722 L
.5984 .07751 L
.60198 .06948 L
.60268 .06779 L
.60686 .05808 L
.61114 .04837 L
.61169 .04711 L
.61522 .03866 L
.61944 .02894 L
.62141 .02444 L
.62351 .01923 L
Mistroke
Mfstroke
.5 g
.01923 .81893 m
.02251 .81566 L
.02894 .80922 L
.03222 .80594 L
.03866 .7995 L
.04193 .79623 L
.04837 .78979 L
.05164 .78652 L
.05808 .78008 L
.06135 .77681 L
.06779 .77037 L
.07107 .76709 L
.07751 .76065 L
.08078 .75738 L
.08722 .75094 L
.09049 .74767 L
.09693 .74123 L
.1002 .73796 L
.10664 .73152 L
.10992 .72824 L
.11636 .7218 L
.11963 .71853 L
.12607 .71209 L
.12934 .70882 L
.13578 .70238 L
.13905 .69911 L
.14549 .69267 L
.14877 .68939 L
.15521 .68295 L
.15848 .67968 L
.16492 .67324 L
.16819 .66997 L
.17463 .66353 L
.1779 .66026 L
.18434 .65382 L
.18762 .65054 L
.19406 .6441 L
.19733 .64083 L
.20377 .63439 L
.20704 .63112 L
.21348 .62468 L
.21675 .62141 L
.22319 .61497 L
.22647 .61169 L
.23291 .60525 L
.23618 .60198 L
.24262 .59554 L
.24589 .59227 L
.25233 .58583 L
.2556 .58256 L
.26204 .57612 L
.26532 .57284 L
.27176 .5664 L
.27503 .56313 L
.28147 .55669 L
.28474 .55342 L
.29118 .54698 L
.29445 .54371 L
.30089 .53727 L
.30417 .53399 L
.31061 .52755 L
.31388 .52428 L
.32032 .51784 L
.32359 .51457 L
.33003 .50813 L
.33338 .50486 L
.33974 .49842 L
.34277 .49514 L
.34946 .48772 L
.35147 .48543 L
.35917 .47643 L
.35976 .47572 L
.36773 .46601 L
.36888 .46457 L
.3754 .45629 L
.37859 .45215 L
.38282 .44658 L
.38831 .4392 L
.39001 .43687 L
.39701 .42716 L
.39802 .42573 L
.40382 .41744 L
.40773 .41176 L
.41047 .40773 L
.41697 .39802 L
.41744 .3973 L
.42333 .38831 L
.42716 .38237 L
.42956 .37859 L
.43568 .36888 L
.43687 .36698 L
.44169 .35917 L
.44658 .35114 L
.4476 .34946 L
.45341 .33974 L
.45629 .33486 L
.45912 .33003 L
.46477 .32032 L
.46601 .31816 L
.47032 .31061 L
.47572 .30104 L
.4758 .30089 L
.48121 .29118 L
.48543 .28352 L
.48655 .28147 L
.49183 .27176 L
.49514 .2656 L
.49704 .26204 L
.5022 .25233 L
.50486 .24729 L
.50729 .24262 L
.51234 .23291 L
.51457 .22859 L
.51733 .22319 L
.52228 .21348 L
.52428 .20952 L
.52717 .20377 L
.53203 .19406 L
.53399 .19009 L
.53682 .18434 L
.54159 .17463 L
.54371 .17029 L
.5463 .16492 L
.55099 .15521 L
.55342 .15014 L
.55563 .14549 L
.56024 .13578 L
.56313 .12964 L
.5648 .12607 L
.56934 .11636 L
.57284 .1088 L
.57383 .10664 L
.5783 .09693 L
.58256 .08762 L
.58274 .08722 L
.58713 .07751 L
.59151 .06779 L
.59227 .06611 L
.59584 .05808 L
.60017 .04837 L
.60198 .04427 L
.60444 .03866 L
.60871 .02894 L
.61169 .02211 L
.61293 .01923 L
.01923 .01923 L
F
0 g
.01923 .81893 m
.02251 .81566 L
.02894 .80922 L
.03222 .80594 L
.03866 .7995 L
.04193 .79623 L
.04837 .78979 L
.05164 .78652 L
.05808 .78008 L
.06135 .77681 L
.06779 .77037 L
.07107 .76709 L
.07751 .76065 L
.08078 .75738 L
.08722 .75094 L
.09049 .74767 L
.09693 .74123 L
.1002 .73796 L
.10664 .73152 L
.10992 .72824 L
.11636 .7218 L
.11963 .71853 L
.12607 .71209 L
.12934 .70882 L
.13578 .70238 L
.13905 .69911 L
.14549 .69267 L
.14877 .68939 L
.15521 .68295 L
.15848 .67968 L
.16492 .67324 L
.16819 .66997 L
.17463 .66353 L
.1779 .66026 L
.18434 .65382 L
.18762 .65054 L
.19406 .6441 L
.19733 .64083 L
.20377 .63439 L
.20704 .63112 L
.21348 .62468 L
.21675 .62141 L
.22319 .61497 L
.22647 .61169 L
.23291 .60525 L
.23618 .60198 L
.24262 .59554 L
.24589 .59227 L
.25233 .58583 L
.2556 .58256 L
Mistroke
.26204 .57612 L
.26532 .57284 L
.27176 .5664 L
.27503 .56313 L
.28147 .55669 L
.28474 .55342 L
.29118 .54698 L
.29445 .54371 L
.30089 .53727 L
.30417 .53399 L
.31061 .52755 L
.31388 .52428 L
.32032 .51784 L
.32359 .51457 L
.33003 .50813 L
.33338 .50486 L
.33974 .49842 L
.34277 .49514 L
.34946 .48772 L
.35147 .48543 L
.35917 .47643 L
.35976 .47572 L
.36773 .46601 L
.36888 .46457 L
.3754 .45629 L
.37859 .45215 L
.38282 .44658 L
.38831 .4392 L
.39001 .43687 L
.39701 .42716 L
.39802 .42573 L
.40382 .41744 L
.40773 .41176 L
.41047 .40773 L
.41697 .39802 L
.41744 .3973 L
.42333 .38831 L
.42716 .38237 L
.42956 .37859 L
.43568 .36888 L
.43687 .36698 L
.44169 .35917 L
.44658 .35114 L
.4476 .34946 L
.45341 .33974 L
.45629 .33486 L
.45912 .33003 L
.46477 .32032 L
.46601 .31816 L
.47032 .31061 L
Mistroke
.47572 .30104 L
.4758 .30089 L
.48121 .29118 L
.48543 .28352 L
.48655 .28147 L
.49183 .27176 L
.49514 .2656 L
.49704 .26204 L
.5022 .25233 L
.50486 .24729 L
.50729 .24262 L
.51234 .23291 L
.51457 .22859 L
.51733 .22319 L
.52228 .21348 L
.52428 .20952 L
.52717 .20377 L
.53203 .19406 L
.53399 .19009 L
.53682 .18434 L
.54159 .17463 L
.54371 .17029 L
.5463 .16492 L
.55099 .15521 L
.55342 .15014 L
.55563 .14549 L
.56024 .13578 L
.56313 .12964 L
.5648 .12607 L
.56934 .11636 L
.57284 .1088 L
.57383 .10664 L
.5783 .09693 L
.58256 .08762 L
.58274 .08722 L
.58713 .07751 L
.59151 .06779 L
.59227 .06611 L
.59584 .05808 L
.60017 .04837 L
.60198 .04427 L
.60444 .03866 L
.60871 .02894 L
.61169 .02211 L
.61293 .01923 L
Mfstroke
.4 g
.01923 .78352 m
.02594 .77681 L
.02894 .77381 L
.03566 .76709 L
.03866 .7641 L
.04537 .75738 L
.04837 .75438 L
.05508 .74767 L
.05808 .74467 L
.06479 .73796 L
.06779 .73496 L
.07451 .72824 L
.07751 .72525 L
.08422 .71853 L
.08722 .71553 L
.09393 .70882 L
.09693 .70582 L
.10365 .69911 L
.10664 .69611 L
.11336 .68939 L
.11636 .6864 L
.12307 .67968 L
.12607 .67668 L
.13278 .66997 L
.13578 .66697 L
.1425 .66026 L
.14549 .65726 L
.15221 .65054 L
.15521 .64755 L
.16192 .64083 L
.16492 .63783 L
.17163 .63112 L
.17463 .62812 L
.18135 .62141 L
.18434 .61841 L
.19106 .61169 L
.19406 .6087 L
.20077 .60198 L
.20377 .59898 L
.21048 .59227 L
.21348 .58927 L
.2202 .58256 L
.22319 .57956 L
.22991 .57284 L
.23291 .56985 L
.23962 .56313 L
.24262 .56013 L
.24933 .55342 L
.25233 .55042 L
.25905 .54371 L
.26204 .54071 L
.26876 .53399 L
.27176 .531 L
.27847 .52428 L
.28147 .52128 L
.28818 .51457 L
.29118 .51157 L
.2979 .50486 L
.30089 .50186 L
.30761 .49514 L
.31061 .49215 L
.31732 .48543 L
.32032 .48243 L
.32703 .47572 L
.33003 .47272 L
.33676 .46601 L
.33974 .46301 L
.34663 .45629 L
.34946 .45356 L
.35619 .44658 L
.35917 .44334 L
.36501 .43687 L
.36888 .43239 L
.37335 .42716 L
.37859 .42078 L
.3813 .41744 L
.38831 .40854 L
.38894 .40773 L
.39632 .39802 L
.39802 .39571 L
.40346 .38831 L
.40773 .38232 L
.41037 .37859 L
.41711 .36888 L
.41744 .36839 L
.4237 .35917 L
.42716 .35394 L
.43011 .34946 L
.43639 .33974 L
.43687 .33899 L
.44256 .33003 L
.44658 .32357 L
.4486 .32032 L
.45453 .31061 L
.45629 .30767 L
.46037 .30089 L
.46601 .29133 L
.46609 .29118 L
.47176 .28147 L
.47572 .27455 L
.47732 .27176 L
.48282 .26204 L
.48543 .25734 L
.48823 .25233 L
.49357 .24262 L
.49514 .23972 L
.49885 .23291 L
.50406 .22319 L
.50486 .22169 L
.50923 .21348 L
.51431 .20377 L
.51457 .20327 L
.51937 .19406 L
.52428 .18445 L
.52434 .18434 L
.52929 .17463 L
.53399 .16526 L
.53416 .16492 L
.53903 .15521 L
.54371 .14569 L
.54381 .14549 L
.54858 .13578 L
.55327 .12607 L
.55342 .12576 L
.55796 .11636 L
.56258 .10664 L
.56313 .10548 L
.56719 .09693 L
.57174 .08722 L
.57284 .08484 L
.57627 .07751 L
.58076 .06779 L
.58256 .06385 L
.58521 .05808 L
.58965 .04837 L
.59227 .04252 L
.59402 .03866 L
.5984 .02894 L
.60198 .02086 L
.60271 .01923 L
.01923 .01923 L
F
0 g
.01923 .78352 m
.02594 .77681 L
.02894 .77381 L
.03566 .76709 L
.03866 .7641 L
.04537 .75738 L
.04837 .75438 L
.05508 .74767 L
.05808 .74467 L
.06479 .73796 L
.06779 .73496 L
.07451 .72824 L
.07751 .72525 L
.08422 .71853 L
.08722 .71553 L
.09393 .70882 L
.09693 .70582 L
.10365 .69911 L
.10664 .69611 L
.11336 .68939 L
.11636 .6864 L
.12307 .67968 L
.12607 .67668 L
.13278 .66997 L
.13578 .66697 L
.1425 .66026 L
.14549 .65726 L
.15221 .65054 L
.15521 .64755 L
.16192 .64083 L
.16492 .63783 L
.17163 .63112 L
.17463 .62812 L
.18135 .62141 L
.18434 .61841 L
.19106 .61169 L
.19406 .6087 L
.20077 .60198 L
.20377 .59898 L
.21048 .59227 L
.21348 .58927 L
.2202 .58256 L
.22319 .57956 L
.22991 .57284 L
.23291 .56985 L
.23962 .56313 L
.24262 .56013 L
.24933 .55342 L
.25233 .55042 L
.25905 .54371 L
Mistroke
.26204 .54071 L
.26876 .53399 L
.27176 .531 L
.27847 .52428 L
.28147 .52128 L
.28818 .51457 L
.29118 .51157 L
.2979 .50486 L
.30089 .50186 L
.30761 .49514 L
.31061 .49215 L
.31732 .48543 L
.32032 .48243 L
.32703 .47572 L
.33003 .47272 L
.33676 .46601 L
.33974 .46301 L
.34663 .45629 L
.34946 .45356 L
.35619 .44658 L
.35917 .44334 L
.36501 .43687 L
.36888 .43239 L
.37335 .42716 L
.37859 .42078 L
.3813 .41744 L
.38831 .40854 L
.38894 .40773 L
.39632 .39802 L
.39802 .39571 L
.40346 .38831 L
.40773 .38232 L
.41037 .37859 L
.41711 .36888 L
.41744 .36839 L
.4237 .35917 L
.42716 .35394 L
.43011 .34946 L
.43639 .33974 L
.43687 .33899 L
.44256 .33003 L
.44658 .32357 L
.4486 .32032 L
.45453 .31061 L
.45629 .30767 L
.46037 .30089 L
.46601 .29133 L
.46609 .29118 L
.47176 .28147 L
.47572 .27455 L
Mistroke
.47732 .27176 L
.48282 .26204 L
.48543 .25734 L
.48823 .25233 L
.49357 .24262 L
.49514 .23972 L
.49885 .23291 L
.50406 .22319 L
.50486 .22169 L
.50923 .21348 L
.51431 .20377 L
.51457 .20327 L
.51937 .19406 L
.52428 .18445 L
.52434 .18434 L
.52929 .17463 L
.53399 .16526 L
.53416 .16492 L
.53903 .15521 L
.54371 .14569 L
.54381 .14549 L
.54858 .13578 L
.55327 .12607 L
.55342 .12576 L
.55796 .11636 L
.56258 .10664 L
.56313 .10548 L
.56719 .09693 L
.57174 .08722 L
.57284 .08484 L
.57627 .07751 L
.58076 .06779 L
.58256 .06385 L
.58521 .05808 L
.58965 .04837 L
.59227 .04252 L
.59402 .03866 L
.5984 .02894 L
.60198 .02086 L
.60271 .01923 L
Mfstroke
.3 g
.01923 .73982 m
.02105 .73796 L
.02894 .73011 L
.03081 .72824 L
.03866 .7204 L
.04052 .71853 L
.04837 .71068 L
.05023 .70882 L
.05808 .70097 L
.05995 .69911 L
.06779 .69126 L
.06966 .68939 L
.07751 .68155 L
.07937 .67968 L
.08722 .67183 L
.08908 .66997 L
.09693 .66212 L
.0988 .66026 L
.10664 .65241 L
.10851 .65054 L
.11636 .6427 L
.11822 .64083 L
.12607 .63298 L
.12793 .63112 L
.13578 .62327 L
.13765 .62141 L
.14549 .61356 L
.14736 .61169 L
.15521 .60385 L
.15707 .60198 L
.16492 .59413 L
.16678 .59227 L
.17463 .58442 L
.1765 .58256 L
.18434 .57471 L
.18621 .57284 L
.19406 .565 L
.19592 .56313 L
.20377 .55528 L
.20563 .55342 L
.21348 .54557 L
.21535 .54371 L
.22319 .53586 L
.22506 .53399 L
.23291 .52615 L
.23477 .52428 L
.24262 .51643 L
.24448 .51457 L
.25233 .50672 L
.2542 .50486 L
.26204 .49701 L
.26391 .49514 L
.27176 .4873 L
.27362 .48543 L
.28147 .47758 L
.28333 .47572 L
.29118 .46787 L
.29305 .46601 L
.30089 .45816 L
.30276 .45629 L
.31061 .44845 L
.31247 .44658 L
.32032 .43873 L
.32218 .43687 L
.33003 .42902 L
.33186 .42716 L
.33974 .41931 L
.34205 .41744 L
.34946 .41231 L
.35531 .40773 L
.35917 .404 L
.3657 .39802 L
.36888 .39462 L
.37511 .38831 L
.37859 .38433 L
.38383 .37859 L
.38831 .37323 L
.39203 .36888 L
.39802 .36138 L
.39981 .35917 L
.40731 .34946 L
.40773 .34886 L
.41462 .33974 L
.41744 .33572 L
.4216 .33003 L
.42716 .32196 L
.42832 .32032 L
.43499 .31061 L
.43687 .30767 L
.44143 .30089 L
.44658 .29282 L
.44765 .29118 L
.45389 .28147 L
.45629 .27747 L
.4599 .27176 L
.46576 .26204 L
.46601 .26161 L
.47167 .25233 L
.47572 .2453 L
.47732 .24262 L
.48302 .23291 L
.48543 .22852 L
.48853 .22319 L
.49399 .21348 L
.49514 .2113 L
.4994 .20377 L
.50465 .19406 L
.50486 .19364 L
.50999 .18434 L
.51457 .17557 L
.51508 .17463 L
.52031 .16492 L
.52428 .15709 L
.52528 .15521 L
.53039 .14549 L
.53399 .13822 L
.53526 .13578 L
.54026 .12607 L
.54371 .11895 L
.54503 .11636 L
.54994 .10664 L
.55342 .09931 L
.55461 .09693 L
.55943 .08722 L
.56313 .07929 L
.56401 .07751 L
.56876 .06779 L
.57284 .05891 L
.57324 .05808 L
.57792 .04837 L
.58235 .03866 L
.58256 .03817 L
.58693 .02894 L
.59136 .01923 L
.01923 .01923 L
F
0 g
.01923 .73982 m
.02105 .73796 L
.02894 .73011 L
.03081 .72824 L
.03866 .7204 L
.04052 .71853 L
.04837 .71068 L
.05023 .70882 L
.05808 .70097 L
.05995 .69911 L
.06779 .69126 L
.06966 .68939 L
.07751 .68155 L
.07937 .67968 L
.08722 .67183 L
.08908 .66997 L
.09693 .66212 L
.0988 .66026 L
.10664 .65241 L
.10851 .65054 L
.11636 .6427 L
.11822 .64083 L
.12607 .63298 L
.12793 .63112 L
.13578 .62327 L
.13765 .62141 L
.14549 .61356 L
.14736 .61169 L
.15521 .60385 L
.15707 .60198 L
.16492 .59413 L
.16678 .59227 L
.17463 .58442 L
.1765 .58256 L
.18434 .57471 L
.18621 .57284 L
.19406 .565 L
.19592 .56313 L
.20377 .55528 L
.20563 .55342 L
.21348 .54557 L
.21535 .54371 L
.22319 .53586 L
.22506 .53399 L
.23291 .52615 L
.23477 .52428 L
.24262 .51643 L
.24448 .51457 L
.25233 .50672 L
.2542 .50486 L
Mistroke
.26204 .49701 L
.26391 .49514 L
.27176 .4873 L
.27362 .48543 L
.28147 .47758 L
.28333 .47572 L
.29118 .46787 L
.29305 .46601 L
.30089 .45816 L
.30276 .45629 L
.31061 .44845 L
.31247 .44658 L
.32032 .43873 L
.32218 .43687 L
.33003 .42902 L
.33186 .42716 L
.33974 .41931 L
.34205 .41744 L
.34946 .41231 L
.35531 .40773 L
.35917 .404 L
.3657 .39802 L
.36888 .39462 L
.37511 .38831 L
.37859 .38433 L
.38383 .37859 L
.38831 .37323 L
.39203 .36888 L
.39802 .36138 L
.39981 .35917 L
.40731 .34946 L
.40773 .34886 L
.41462 .33974 L
.41744 .33572 L
.4216 .33003 L
.42716 .32196 L
.42832 .32032 L
.43499 .31061 L
.43687 .30767 L
.44143 .30089 L
.44658 .29282 L
.44765 .29118 L
.45389 .28147 L
.45629 .27747 L
.4599 .27176 L
.46576 .26204 L
.46601 .26161 L
.47167 .25233 L
.47572 .2453 L
.47732 .24262 L
Mistroke
.48302 .23291 L
.48543 .22852 L
.48853 .22319 L
.49399 .21348 L
.49514 .2113 L
.4994 .20377 L
.50465 .19406 L
.50486 .19364 L
.50999 .18434 L
.51457 .17557 L
.51508 .17463 L
.52031 .16492 L
.52428 .15709 L
.52528 .15521 L
.53039 .14549 L
.53399 .13822 L
.53526 .13578 L
.54026 .12607 L
.54371 .11895 L
.54503 .11636 L
.54994 .10664 L
.55342 .09931 L
.55461 .09693 L
.55943 .08722 L
.56313 .07929 L
.56401 .07751 L
.56876 .06779 L
.57284 .05891 L
.57324 .05808 L
.57792 .04837 L
.58235 .03866 L
.58256 .03817 L
.58693 .02894 L
.59136 .01923 L
Mfstroke
.4 g
.01923 .66124 m
.02048 .66026 L
.02894 .65153 L
.02993 .65054 L
.03866 .64182 L
.03964 .64083 L
.04837 .6321 L
.04935 .63112 L
.05808 .62239 L
.05907 .62141 L
.06779 .61268 L
.06878 .61169 L
.07751 .60297 L
.07849 .60198 L
.08722 .59325 L
.0882 .59227 L
.09693 .58354 L
.09792 .58256 L
.10664 .57383 L
.10763 .57284 L
.11636 .56412 L
.11734 .56313 L
.12607 .5544 L
.12705 .55342 L
.13578 .54469 L
.13677 .54371 L
.14549 .53498 L
.14648 .53399 L
.15521 .52527 L
.15619 .52428 L
.16492 .51555 L
.1659 .51457 L
.17463 .50584 L
.17562 .50486 L
.18434 .49613 L
.18533 .49514 L
.19406 .48642 L
.19504 .48543 L
.20377 .4767 L
.20475 .47572 L
.21348 .46699 L
.21447 .46601 L
.22319 .45728 L
.22418 .45629 L
.23291 .44757 L
.23389 .44658 L
.24262 .43785 L
.2436 .43687 L
.25233 .42814 L
.25332 .42716 L
.26204 .41843 L
.26303 .41744 L
.27176 .40872 L
.27274 .40773 L
.28147 .399 L
.28245 .39802 L
.29118 .38929 L
.29217 .38831 L
.30089 .37958 L
.30188 .37859 L
.31061 .36987 L
.31159 .36888 L
.32032 .36015 L
.3213 .35917 L
.33003 .35044 L
.33113 .34946 L
.33974 .34073 L
.34054 .33974 L
.34772 .33003 L
.34946 .3276 L
.35482 .32032 L
.35917 .31438 L
.36192 .31061 L
.36888 .30098 L
.36894 .30089 L
.37582 .29118 L
.37859 .28722 L
.38257 .28147 L
.38831 .27314 L
.38924 .27176 L
.39577 .26204 L
.39802 .25867 L
.40218 .25233 L
.40773 .24383 L
.40851 .24262 L
.4147 .23291 L
.41744 .22859 L
.42079 .22319 L
.42684 .21348 L
.42716 .21296 L
.43272 .20377 L
.43687 .19692 L
.43855 .19406 L
.44431 .18434 L
.44658 .1805 L
.44995 .17463 L
.45559 .16492 L
.45629 .16369 L
.46107 .15521 L
.46601 .14649 L
.46655 .14549 L
.47191 .13578 L
.47572 .12891 L
.47723 .12607 L
.4825 .11636 L
.48543 .11095 L
.48768 .10664 L
.49286 .09693 L
.49514 .09263 L
.49792 .08722 L
.503 .07751 L
.50486 .07394 L
.50795 .06779 L
.51294 .05808 L
.51457 .0549 L
.51779 .04837 L
.52269 .03866 L
.52428 .0355 L
.52745 .02894 L
.53227 .01923 L
.01923 .01923 L
F
0 g
.01923 .66124 m
.02048 .66026 L
.02894 .65153 L
.02993 .65054 L
.03866 .64182 L
.03964 .64083 L
.04837 .6321 L
.04935 .63112 L
.05808 .62239 L
.05907 .62141 L
.06779 .61268 L
.06878 .61169 L
.07751 .60297 L
.07849 .60198 L
.08722 .59325 L
.0882 .59227 L
.09693 .58354 L
.09792 .58256 L
.10664 .57383 L
.10763 .57284 L
.11636 .56412 L
.11734 .56313 L
.12607 .5544 L
.12705 .55342 L
.13578 .54469 L
.13677 .54371 L
.14549 .53498 L
.14648 .53399 L
.15521 .52527 L
.15619 .52428 L
.16492 .51555 L
.1659 .51457 L
.17463 .50584 L
.17562 .50486 L
.18434 .49613 L
.18533 .49514 L
.19406 .48642 L
.19504 .48543 L
.20377 .4767 L
.20475 .47572 L
.21348 .46699 L
.21447 .46601 L
.22319 .45728 L
.22418 .45629 L
.23291 .44757 L
.23389 .44658 L
.24262 .43785 L
.2436 .43687 L
.25233 .42814 L
.25332 .42716 L
Mistroke
.26204 .41843 L
.26303 .41744 L
.27176 .40872 L
.27274 .40773 L
.28147 .399 L
.28245 .39802 L
.29118 .38929 L
.29217 .38831 L
.30089 .37958 L
.30188 .37859 L
.31061 .36987 L
.31159 .36888 L
.32032 .36015 L
.3213 .35917 L
.33003 .35044 L
.33113 .34946 L
.33974 .34073 L
.34054 .33974 L
.34772 .33003 L
.34946 .3276 L
.35482 .32032 L
.35917 .31438 L
.36192 .31061 L
.36888 .30098 L
.36894 .30089 L
.37582 .29118 L
.37859 .28722 L
.38257 .28147 L
.38831 .27314 L
.38924 .27176 L
.39577 .26204 L
.39802 .25867 L
.40218 .25233 L
.40773 .24383 L
.40851 .24262 L
.4147 .23291 L
.41744 .22859 L
.42079 .22319 L
.42684 .21348 L
.42716 .21296 L
.43272 .20377 L
.43687 .19692 L
.43855 .19406 L
.44431 .18434 L
.44658 .1805 L
.44995 .17463 L
.45559 .16492 L
.45629 .16369 L
.46107 .15521 L
.46601 .14649 L
Mistroke
.46655 .14549 L
.47191 .13578 L
.47572 .12891 L
.47723 .12607 L
.4825 .11636 L
.48543 .11095 L
.48768 .10664 L
.49286 .09693 L
.49514 .09263 L
.49792 .08722 L
.503 .07751 L
.50486 .07394 L
.50795 .06779 L
.51294 .05808 L
.51457 .0549 L
.51779 .04837 L
.52269 .03866 L
.52428 .0355 L
.52745 .02894 L
.53227 .01923 L
Mfstroke
.5 g
.01923 .61755 m
.02509 .61169 L
.02894 .60783 L
.0348 .60198 L
.03866 .59812 L
.04451 .59227 L
.04837 .58841 L
.05422 .58256 L
.05808 .5787 L
.06393 .57284 L
.06779 .56898 L
.07365 .56313 L
.07751 .55927 L
.08336 .55342 L
.08722 .54956 L
.09307 .54371 L
.09693 .53985 L
.10278 .53399 L
.10664 .53013 L
.1125 .52428 L
.11636 .52042 L
.12221 .51457 L
.12607 .51071 L
.13192 .50486 L
.13578 .501 L
.14163 .49514 L
.14549 .49128 L
.15135 .48543 L
.15521 .48157 L
.16106 .47572 L
.16492 .47186 L
.17077 .46601 L
.17463 .46215 L
.18048 .45629 L
.18434 .45243 L
.1902 .44658 L
.19406 .44272 L
.19991 .43687 L
.20377 .43301 L
.20962 .42716 L
.21348 .4233 L
.21933 .41744 L
.22319 .41358 L
.22905 .40773 L
.23291 .40387 L
.23876 .39802 L
.24262 .39416 L
.24847 .38831 L
.25233 .38445 L
.25818 .37859 L
.26204 .37473 L
.2679 .36888 L
.27176 .36502 L
.27761 .35917 L
.28147 .35531 L
.28732 .34946 L
.29118 .3456 L
.29703 .33974 L
.30089 .33588 L
.30675 .33003 L
.31061 .32617 L
.31646 .32032 L
.32032 .31646 L
.32617 .31061 L
.33003 .30675 L
.33597 .30089 L
.33974 .29703 L
.34511 .29118 L
.34946 .28633 L
.35371 .28147 L
.35917 .27504 L
.36191 .27176 L
.36888 .26318 L
.36979 .26204 L
.3774 .25233 L
.37859 .25077 L
.38475 .24262 L
.38831 .23781 L
.39189 .23291 L
.39802 .22435 L
.39883 .22319 L
.4056 .21348 L
.40773 .21037 L
.41221 .20377 L
.41744 .19592 L
.41867 .19406 L
.425 .18434 L
.42716 .18098 L
.4312 .17463 L
.43687 .16559 L
.43729 .16492 L
.44327 .15521 L
.44658 .14975 L
.44915 .14549 L
.45494 .13578 L
.45629 .13348 L
.46063 .12607 L
.46601 .11678 L
.46625 .11636 L
.47178 .10664 L
.47572 .09966 L
.47724 .09693 L
.48264 .08722 L
.48543 .08213 L
.48795 .07751 L
.49322 .06779 L
.49514 .06421 L
.49841 .05808 L
.50356 .04837 L
.50486 .0459 L
.50864 .03866 L
.51368 .02894 L
.51457 .02721 L
.51865 .01923 L
.01923 .01923 L
F
0 g
.01923 .61755 m
.02509 .61169 L
.02894 .60783 L
.0348 .60198 L
.03866 .59812 L
.04451 .59227 L
.04837 .58841 L
.05422 .58256 L
.05808 .5787 L
.06393 .57284 L
.06779 .56898 L
.07365 .56313 L
.07751 .55927 L
.08336 .55342 L
.08722 .54956 L
.09307 .54371 L
.09693 .53985 L
.10278 .53399 L
.10664 .53013 L
.1125 .52428 L
.11636 .52042 L
.12221 .51457 L
.12607 .51071 L
.13192 .50486 L
.13578 .501 L
.14163 .49514 L
.14549 .49128 L
.15135 .48543 L
.15521 .48157 L
.16106 .47572 L
.16492 .47186 L
.17077 .46601 L
.17463 .46215 L
.18048 .45629 L
.18434 .45243 L
.1902 .44658 L
.19406 .44272 L
.19991 .43687 L
.20377 .43301 L
.20962 .42716 L
.21348 .4233 L
.21933 .41744 L
.22319 .41358 L
.22905 .40773 L
.23291 .40387 L
.23876 .39802 L
.24262 .39416 L
.24847 .38831 L
.25233 .38445 L
.25818 .37859 L
Mistroke
.26204 .37473 L
.2679 .36888 L
.27176 .36502 L
.27761 .35917 L
.28147 .35531 L
.28732 .34946 L
.29118 .3456 L
.29703 .33974 L
.30089 .33588 L
.30675 .33003 L
.31061 .32617 L
.31646 .32032 L
.32032 .31646 L
.32617 .31061 L
.33003 .30675 L
.33597 .30089 L
.33974 .29703 L
.34511 .29118 L
.34946 .28633 L
.35371 .28147 L
.35917 .27504 L
.36191 .27176 L
.36888 .26318 L
.36979 .26204 L
.3774 .25233 L
.37859 .25077 L
.38475 .24262 L
.38831 .23781 L
.39189 .23291 L
.39802 .22435 L
.39883 .22319 L
.4056 .21348 L
.40773 .21037 L
.41221 .20377 L
.41744 .19592 L
.41867 .19406 L
.425 .18434 L
.42716 .18098 L
.4312 .17463 L
.43687 .16559 L
.43729 .16492 L
.44327 .15521 L
.44658 .14975 L
.44915 .14549 L
.45494 .13578 L
.45629 .13348 L
.46063 .12607 L
.46601 .11678 L
.46625 .11636 L
.47178 .10664 L
Mistroke
.47572 .09966 L
.47724 .09693 L
.48264 .08722 L
.48543 .08213 L
.48795 .07751 L
.49322 .06779 L
.49514 .06421 L
.49841 .05808 L
.50356 .04837 L
.50486 .0459 L
.50864 .03866 L
.51368 .02894 L
.51457 .02721 L
.51865 .01923 L
Mfstroke
.6 g
.01923 .58213 m
.02852 .57284 L
.02894 .57242 L
.03823 .56313 L
.03866 .56271 L
.04795 .55342 L
.04837 .553 L
.05766 .54371 L
.05808 .54328 L
.06737 .53399 L
.06779 .53357 L
.07708 .52428 L
.07751 .52386 L
.0868 .51457 L
.08722 .51415 L
.09651 .50486 L
.09693 .50443 L
.10622 .49514 L
.10664 .49472 L
.11593 .48543 L
.11636 .48501 L
.12565 .47572 L
.12607 .4753 L
.13536 .46601 L
.13578 .46558 L
.14507 .45629 L
.14549 .45587 L
.15478 .44658 L
.15521 .44616 L
.1645 .43687 L
.16492 .43645 L
.17421 .42716 L
.17463 .42673 L
.18392 .41744 L
.18434 .41702 L
.19363 .40773 L
.19406 .40731 L
.20335 .39802 L
.20377 .3976 L
.21306 .38831 L
.21348 .38788 L
.22277 .37859 L
.22319 .37817 L
.23248 .36888 L
.23291 .36846 L
.2422 .35917 L
.24262 .35875 L
.25191 .34946 L
.25233 .34903 L
.26162 .33974 L
.26204 .33932 L
.27133 .33003 L
.27176 .32961 L
.28105 .32032 L
.28147 .3199 L
.29076 .31061 L
.29118 .31018 L
.30047 .30089 L
.30089 .30047 L
.31018 .29118 L
.31061 .29076 L
.3199 .28147 L
.32032 .28105 L
.32961 .27176 L
.33003 .27133 L
.33932 .26204 L
.33974 .26162 L
.3493 .25233 L
.34946 .25218 L
.35856 .24262 L
.35917 .24195 L
.36725 .23291 L
.36888 .23101 L
.3755 .22319 L
.37859 .2194 L
.38337 .21348 L
.38831 .20716 L
.39093 .20377 L
.39802 .19433 L
.39822 .19406 L
.40531 .18434 L
.40773 .18094 L
.41219 .17463 L
.41744 .167 L
.41887 .16492 L
.42541 .15521 L
.42716 .15255 L
.4318 .14549 L
.43687 .13761 L
.43804 .13578 L
.44418 .12607 L
.44658 .12218 L
.45019 .11636 L
.45608 .10664 L
.45629 .10629 L
.4619 .09693 L
.46601 .08995 L
.46761 .08722 L
.47325 .07751 L
.47572 .07317 L
.47879 .06779 L
.48426 .05808 L
.48543 .05596 L
.48966 .04837 L
.49497 .03866 L
.49514 .03834 L
.50025 .02894 L
.50486 .02031 L
.50543 .01923 L
.01923 .01923 L
F
0 g
.01923 .58213 m
.02852 .57284 L
.02894 .57242 L
.03823 .56313 L
.03866 .56271 L
.04795 .55342 L
.04837 .553 L
.05766 .54371 L
.05808 .54328 L
.06737 .53399 L
.06779 .53357 L
.07708 .52428 L
.07751 .52386 L
.0868 .51457 L
.08722 .51415 L
.09651 .50486 L
.09693 .50443 L
.10622 .49514 L
.10664 .49472 L
.11593 .48543 L
.11636 .48501 L
.12565 .47572 L
.12607 .4753 L
.13536 .46601 L
.13578 .46558 L
.14507 .45629 L
.14549 .45587 L
.15478 .44658 L
.15521 .44616 L
.1645 .43687 L
.16492 .43645 L
.17421 .42716 L
.17463 .42673 L
.18392 .41744 L
.18434 .41702 L
.19363 .40773 L
.19406 .40731 L
.20335 .39802 L
.20377 .3976 L
.21306 .38831 L
.21348 .38788 L
.22277 .37859 L
.22319 .37817 L
.23248 .36888 L
.23291 .36846 L
.2422 .35917 L
.24262 .35875 L
.25191 .34946 L
.25233 .34903 L
.26162 .33974 L
Mistroke
.26204 .33932 L
.27133 .33003 L
.27176 .32961 L
.28105 .32032 L
.28147 .3199 L
.29076 .31061 L
.29118 .31018 L
.30047 .30089 L
.30089 .30047 L
.31018 .29118 L
.31061 .29076 L
.3199 .28147 L
.32032 .28105 L
.32961 .27176 L
.33003 .27133 L
.33932 .26204 L
.33974 .26162 L
.3493 .25233 L
.34946 .25218 L
.35856 .24262 L
.35917 .24195 L
.36725 .23291 L
.36888 .23101 L
.3755 .22319 L
.37859 .2194 L
.38337 .21348 L
.38831 .20716 L
.39093 .20377 L
.39802 .19433 L
.39822 .19406 L
.40531 .18434 L
.40773 .18094 L
.41219 .17463 L
.41744 .167 L
.41887 .16492 L
.42541 .15521 L
.42716 .15255 L
.4318 .14549 L
.43687 .13761 L
.43804 .13578 L
.44418 .12607 L
.44658 .12218 L
.45019 .11636 L
.45608 .10664 L
.45629 .10629 L
.4619 .09693 L
.46601 .08995 L
.46761 .08722 L
.47325 .07751 L
.47572 .07317 L
Mistroke
.47879 .06779 L
.48426 .05808 L
.48543 .05596 L
.48966 .04837 L
.49497 .03866 L
.49514 .03834 L
.50025 .02894 L
.50486 .02031 L
.50543 .01923 L
Mfstroke
.7 g
.01923 .53846 m
.02362 .53399 L
.02894 .52875 L
.03341 .52428 L
.03866 .51904 L
.04312 .51457 L
.04837 .50932 L
.05284 .50486 L
.05808 .49961 L
.06255 .49514 L
.06779 .4899 L
.07226 .48543 L
.07751 .48019 L
.08197 .47572 L
.08722 .47047 L
.09169 .46601 L
.09693 .46076 L
.1014 .45629 L
.10664 .45105 L
.11111 .44658 L
.11636 .44134 L
.12082 .43687 L
.12607 .43162 L
.13054 .42716 L
.13578 .42191 L
.14025 .41744 L
.14549 .4122 L
.14996 .40773 L
.15521 .40249 L
.15967 .39802 L
.16492 .39277 L
.16939 .38831 L
.17463 .38306 L
.1791 .37859 L
.18434 .37335 L
.18881 .36888 L
.19406 .36364 L
.19852 .35917 L
.20377 .35392 L
.20824 .34946 L
.21348 .34421 L
.21795 .33974 L
.22319 .3345 L
.22766 .33003 L
.23291 .32479 L
.23737 .32032 L
.24262 .31507 L
.24709 .31061 L
.25233 .30536 L
.2568 .30089 L
.26204 .29565 L
.26651 .29118 L
.27176 .28594 L
.27622 .28147 L
.28147 .27622 L
.28594 .27176 L
.29118 .26651 L
.29565 .26204 L
.30089 .2568 L
.30536 .25233 L
.31061 .24709 L
.31507 .24262 L
.32032 .23737 L
.32479 .23291 L
.33003 .22766 L
.3344 .22319 L
.33974 .21795 L
.34557 .21348 L
.34946 .21092 L
.35811 .20377 L
.35917 .2026 L
.36816 .19406 L
.36888 .19322 L
.37742 .18434 L
.37859 .18294 L
.38605 .17463 L
.38831 .17184 L
.39418 .16492 L
.39802 .16 L
.40189 .15521 L
.40773 .14748 L
.40926 .14549 L
.41645 .13578 L
.41744 .13433 L
.42344 .12607 L
.42716 .12059 L
.43013 .11636 L
.43664 .10664 L
.43687 .10627 L
.44313 .09693 L
.44658 .09144 L
.44934 .08722 L
.45545 .07751 L
.45629 .07608 L
.46151 .06779 L
.46601 .06023 L
.46733 .05808 L
.47319 .04837 L
.47572 .04392 L
.47886 .03866 L
.48445 .02894 L
.48543 .02712 L
.49001 .01923 L
.01923 .01923 L
F
0 g
.01923 .53846 m
.02362 .53399 L
.02894 .52875 L
.03341 .52428 L
.03866 .51904 L
.04312 .51457 L
.04837 .50932 L
.05284 .50486 L
.05808 .49961 L
.06255 .49514 L
.06779 .4899 L
.07226 .48543 L
.07751 .48019 L
.08197 .47572 L
.08722 .47047 L
.09169 .46601 L
.09693 .46076 L
.1014 .45629 L
.10664 .45105 L
.11111 .44658 L
.11636 .44134 L
.12082 .43687 L
.12607 .43162 L
.13054 .42716 L
.13578 .42191 L
.14025 .41744 L
.14549 .4122 L
.14996 .40773 L
.15521 .40249 L
.15967 .39802 L
.16492 .39277 L
.16939 .38831 L
.17463 .38306 L
.1791 .37859 L
.18434 .37335 L
.18881 .36888 L
.19406 .36364 L
.19852 .35917 L
.20377 .35392 L
.20824 .34946 L
.21348 .34421 L
.21795 .33974 L
.22319 .3345 L
.22766 .33003 L
.23291 .32479 L
.23737 .32032 L
.24262 .31507 L
.24709 .31061 L
.25233 .30536 L
.2568 .30089 L
Mistroke
.26204 .29565 L
.26651 .29118 L
.27176 .28594 L
.27622 .28147 L
.28147 .27622 L
.28594 .27176 L
.29118 .26651 L
.29565 .26204 L
.30089 .2568 L
.30536 .25233 L
.31061 .24709 L
.31507 .24262 L
.32032 .23737 L
.32479 .23291 L
.33003 .22766 L
.3344 .22319 L
.33974 .21795 L
.34557 .21348 L
.34946 .21092 L
.35811 .20377 L
.35917 .2026 L
.36816 .19406 L
.36888 .19322 L
.37742 .18434 L
.37859 .18294 L
.38605 .17463 L
.38831 .17184 L
.39418 .16492 L
.39802 .16 L
.40189 .15521 L
.40773 .14748 L
.40926 .14549 L
.41645 .13578 L
.41744 .13433 L
.42344 .12607 L
.42716 .12059 L
.43013 .11636 L
.43664 .10664 L
.43687 .10627 L
.44313 .09693 L
.44658 .09144 L
.44934 .08722 L
.45545 .07751 L
.45629 .07608 L
.46151 .06779 L
.46601 .06023 L
.46733 .05808 L
.47319 .04837 L
.47572 .04392 L
.47886 .03866 L
Mistroke
.48445 .02894 L
.48543 .02712 L
.49001 .01923 L
Mfstroke
.6 g
.01923 .45983 m
.02313 .45629 L
.02894 .45012 L
.03248 .44658 L
.03866 .44041 L
.04219 .43687 L
.04837 .4307 L
.05191 .42716 L
.05808 .42098 L
.06162 .41744 L
.06779 .41127 L
.07133 .40773 L
.07751 .40156 L
.08104 .39802 L
.08722 .39184 L
.09076 .38831 L
.09693 .38213 L
.10047 .37859 L
.10664 .37242 L
.11018 .36888 L
.11636 .36271 L
.11989 .35917 L
.12607 .35299 L
.12961 .34946 L
.13578 .34328 L
.13932 .33974 L
.14549 .33357 L
.14903 .33003 L
.15521 .32386 L
.15874 .32032 L
.16492 .31414 L
.16846 .31061 L
.17463 .30443 L
.17817 .30089 L
.18434 .29472 L
.18788 .29118 L
.19406 .28501 L
.19759 .28147 L
.20377 .27529 L
.20731 .27176 L
.21348 .26558 L
.21702 .26204 L
.22319 .25587 L
.22673 .25233 L
.23291 .24616 L
.23644 .24262 L
.24262 .23644 L
.24616 .23291 L
.25233 .22673 L
.25587 .22319 L
.26204 .21702 L
.26558 .21348 L
.27176 .20731 L
.27529 .20377 L
.28147 .19759 L
.28501 .19406 L
.29118 .18788 L
.29472 .18434 L
.30089 .17817 L
.30443 .17463 L
.31061 .16846 L
.31414 .16492 L
.32032 .15874 L
.32386 .15521 L
.33003 .14903 L
.33386 .14549 L
.33974 .13932 L
.34251 .13578 L
.34946 .12624 L
.34958 .12607 L
.35672 .11636 L
.35917 .11301 L
.36379 .10664 L
.36888 .09957 L
.37076 .09693 L
.37763 .08722 L
.37859 .08585 L
.38436 .07751 L
.38831 .07175 L
.39097 .06779 L
.3975 .05808 L
.39802 .0573 L
.40387 .04837 L
.40773 .04244 L
.41015 .03866 L
.41635 .02894 L
.41744 .02723 L
.4224 .01923 L
.01923 .01923 L
F
0 g
.01923 .45983 m
.02313 .45629 L
.02894 .45012 L
.03248 .44658 L
.03866 .44041 L
.04219 .43687 L
.04837 .4307 L
.05191 .42716 L
.05808 .42098 L
.06162 .41744 L
.06779 .41127 L
.07133 .40773 L
.07751 .40156 L
.08104 .39802 L
.08722 .39184 L
.09076 .38831 L
.09693 .38213 L
.10047 .37859 L
.10664 .37242 L
.11018 .36888 L
.11636 .36271 L
.11989 .35917 L
.12607 .35299 L
.12961 .34946 L
.13578 .34328 L
.13932 .33974 L
.14549 .33357 L
.14903 .33003 L
.15521 .32386 L
.15874 .32032 L
.16492 .31414 L
.16846 .31061 L
.17463 .30443 L
.17817 .30089 L
.18434 .29472 L
.18788 .29118 L
.19406 .28501 L
.19759 .28147 L
.20377 .27529 L
.20731 .27176 L
.21348 .26558 L
.21702 .26204 L
.22319 .25587 L
.22673 .25233 L
.23291 .24616 L
.23644 .24262 L
.24262 .23644 L
.24616 .23291 L
.25233 .22673 L
.25587 .22319 L
Mistroke
.26204 .21702 L
.26558 .21348 L
.27176 .20731 L
.27529 .20377 L
.28147 .19759 L
.28501 .19406 L
.29118 .18788 L
.29472 .18434 L
.30089 .17817 L
.30443 .17463 L
.31061 .16846 L
.31414 .16492 L
.32032 .15874 L
.32386 .15521 L
.33003 .14903 L
.33386 .14549 L
.33974 .13932 L
.34251 .13578 L
.34946 .12624 L
.34958 .12607 L
.35672 .11636 L
.35917 .11301 L
.36379 .10664 L
.36888 .09957 L
.37076 .09693 L
.37763 .08722 L
.37859 .08585 L
.38436 .07751 L
.38831 .07175 L
.39097 .06779 L
.3975 .05808 L
.39802 .0573 L
.40387 .04837 L
.40773 .04244 L
.41015 .03866 L
.41635 .02894 L
.41744 .02723 L
.4224 .01923 L
Mfstroke
.5 g
.01923 .41616 m
.02767 .40773 L
.02894 .40645 L
.03738 .39802 L
.03866 .39674 L
.04709 .38831 L
.04837 .38703 L
.0568 .37859 L
.05808 .37731 L
.06651 .36888 L
.06779 .3676 L
.07623 .35917 L
.07751 .35789 L
.08594 .34946 L
.08722 .34818 L
.09565 .33974 L
.09693 .33846 L
.10536 .33003 L
.10664 .32875 L
.11508 .32032 L
.11636 .31904 L
.12479 .31061 L
.12607 .30933 L
.1345 .30089 L
.13578 .29961 L
.14421 .29118 L
.14549 .2899 L
.15393 .28147 L
.15521 .28019 L
.16364 .27176 L
.16492 .27048 L
.17335 .26204 L
.17463 .26076 L
.18306 .25233 L
.18434 .25105 L
.19278 .24262 L
.19406 .24134 L
.20249 .23291 L
.20377 .23163 L
.2122 .22319 L
.21348 .22191 L
.22191 .21348 L
.22319 .2122 L
.23163 .20377 L
.23291 .20249 L
.24134 .19406 L
.24262 .19278 L
.25105 .18434 L
.25233 .18306 L
.26076 .17463 L
.26204 .17335 L
.27048 .16492 L
.27176 .16364 L
.28019 .15521 L
.28147 .15393 L
.2899 .14549 L
.29118 .14421 L
.29961 .13578 L
.30089 .1345 L
.30933 .12607 L
.31061 .12479 L
.31904 .11636 L
.32032 .11508 L
.32875 .10664 L
.33003 .10536 L
.33851 .09693 L
.33974 .09565 L
.34743 .08722 L
.34946 .08495 L
.35592 .07751 L
.35917 .07366 L
.36403 .06779 L
.36888 .0618 L
.37184 .05808 L
.37859 .04938 L
.37937 .04837 L
.38667 .03866 L
.38831 .03643 L
.39375 .02894 L
.39802 .02297 L
.40065 .01923 L
.01923 .01923 L
F
0 g
.01923 .41616 m
.02767 .40773 L
.02894 .40645 L
.03738 .39802 L
.03866 .39674 L
.04709 .38831 L
.04837 .38703 L
.0568 .37859 L
.05808 .37731 L
.06651 .36888 L
.06779 .3676 L
.07623 .35917 L
.07751 .35789 L
.08594 .34946 L
.08722 .34818 L
.09565 .33974 L
.09693 .33846 L
.10536 .33003 L
.10664 .32875 L
.11508 .32032 L
.11636 .31904 L
.12479 .31061 L
.12607 .30933 L
.1345 .30089 L
.13578 .29961 L
.14421 .29118 L
.14549 .2899 L
.15393 .28147 L
.15521 .28019 L
.16364 .27176 L
.16492 .27048 L
.17335 .26204 L
.17463 .26076 L
.18306 .25233 L
.18434 .25105 L
.19278 .24262 L
.19406 .24134 L
.20249 .23291 L
.20377 .23163 L
.2122 .22319 L
.21348 .22191 L
.22191 .21348 L
.22319 .2122 L
.23163 .20377 L
.23291 .20249 L
.24134 .19406 L
.24262 .19278 L
.25105 .18434 L
.25233 .18306 L
.26076 .17463 L
Mistroke
.26204 .17335 L
.27048 .16492 L
.27176 .16364 L
.28019 .15521 L
.28147 .15393 L
.2899 .14549 L
.29118 .14421 L
.29961 .13578 L
.30089 .1345 L
.30933 .12607 L
.31061 .12479 L
.31904 .11636 L
.32032 .11508 L
.32875 .10664 L
.33003 .10536 L
.33851 .09693 L
.33974 .09565 L
.34743 .08722 L
.34946 .08495 L
.35592 .07751 L
.35917 .07366 L
.36403 .06779 L
.36888 .0618 L
.37184 .05808 L
.37859 .04938 L
.37937 .04837 L
.38667 .03866 L
.38831 .03643 L
.39375 .02894 L
.39802 .02297 L
.40065 .01923 L
Mfstroke
.4 g
.01923 .38075 m
.02139 .37859 L
.02894 .37104 L
.0311 .36888 L
.03866 .36133 L
.04081 .35917 L
.04837 .35161 L
.05053 .34946 L
.05808 .3419 L
.06024 .33974 L
.06779 .33219 L
.06995 .33003 L
.07751 .32248 L
.07966 .32032 L
.08722 .31276 L
.08938 .31061 L
.09693 .30305 L
.09909 .30089 L
.10664 .29334 L
.1088 .29118 L
.11636 .28363 L
.11851 .28147 L
.12607 .27391 L
.12823 .27176 L
.13578 .2642 L
.13794 .26204 L
.14549 .25449 L
.14765 .25233 L
.15521 .24478 L
.15736 .24262 L
.16492 .23506 L
.16708 .23291 L
.17463 .22535 L
.17679 .22319 L
.18434 .21564 L
.1865 .21348 L
.19406 .20593 L
.19621 .20377 L
.20377 .19621 L
.20593 .19406 L
.21348 .1865 L
.21564 .18434 L
.22319 .17679 L
.22535 .17463 L
.23291 .16708 L
.23506 .16492 L
.24262 .15736 L
.24478 .15521 L
.25233 .14765 L
.25449 .14549 L
.26204 .13794 L
.2642 .13578 L
.27176 .12823 L
.27391 .12607 L
.28147 .11851 L
.28363 .11636 L
.29118 .1088 L
.29334 .10664 L
.30089 .09909 L
.30305 .09693 L
.31061 .08938 L
.31276 .08722 L
.32032 .07966 L
.32248 .07751 L
.33003 .06995 L
.3322 .06779 L
.33974 .06024 L
.34194 .05808 L
.34946 .0508 L
.35184 .04837 L
.35917 .04057 L
.36092 .03866 L
.36888 .02962 L
.36947 .02894 L
.37761 .01923 L
.01923 .01923 L
F
0 g
.01923 .38075 m
.02139 .37859 L
.02894 .37104 L
.0311 .36888 L
.03866 .36133 L
.04081 .35917 L
.04837 .35161 L
.05053 .34946 L
.05808 .3419 L
.06024 .33974 L
.06779 .33219 L
.06995 .33003 L
.07751 .32248 L
.07966 .32032 L
.08722 .31276 L
.08938 .31061 L
.09693 .30305 L
.09909 .30089 L
.10664 .29334 L
.1088 .29118 L
.11636 .28363 L
.11851 .28147 L
.12607 .27391 L
.12823 .27176 L
.13578 .2642 L
.13794 .26204 L
.14549 .25449 L
.14765 .25233 L
.15521 .24478 L
.15736 .24262 L
.16492 .23506 L
.16708 .23291 L
.17463 .22535 L
.17679 .22319 L
.18434 .21564 L
.1865 .21348 L
.19406 .20593 L
.19621 .20377 L
.20377 .19621 L
.20593 .19406 L
.21348 .1865 L
.21564 .18434 L
.22319 .17679 L
.22535 .17463 L
.23291 .16708 L
.23506 .16492 L
.24262 .15736 L
.24478 .15521 L
.25233 .14765 L
.25449 .14549 L
Mistroke
.26204 .13794 L
.2642 .13578 L
.27176 .12823 L
.27391 .12607 L
.28147 .11851 L
.28363 .11636 L
.29118 .1088 L
.29334 .10664 L
.30089 .09909 L
.30305 .09693 L
.31061 .08938 L
.31276 .08722 L
.32032 .07966 L
.32248 .07751 L
.33003 .06995 L
.3322 .06779 L
.33974 .06024 L
.34194 .05808 L
.34946 .0508 L
.35184 .04837 L
.35917 .04057 L
.36092 .03866 L
.36888 .02962 L
.36947 .02894 L
.37761 .01923 L
Mfstroke
.3 g
.01923 .33708 m
.02621 .33003 L
.02894 .32737 L
.03599 .32032 L
.03866 .31765 L
.0457 .31061 L
.04837 .30794 L
.05542 .30089 L
.05808 .29823 L
.06513 .29118 L
.06779 .28852 L
.07484 .28147 L
.07751 .2788 L
.08455 .27176 L
.08722 .26909 L
.09427 .26204 L
.09693 .25938 L
.10398 .25233 L
.10664 .24967 L
.11369 .24262 L
.11636 .23995 L
.1234 .23291 L
.12607 .23024 L
.13312 .22319 L
.13578 .22053 L
.14283 .21348 L
.14549 .21082 L
.15254 .20377 L
.15521 .2011 L
.16225 .19406 L
.16492 .19139 L
.17197 .18434 L
.17463 .18168 L
.18168 .17463 L
.18434 .17197 L
.19139 .16492 L
.19406 .16225 L
.2011 .15521 L
.20377 .15254 L
.21082 .14549 L
.21348 .14283 L
.22053 .13578 L
.22319 .13312 L
.23024 .12607 L
.23291 .1234 L
.23995 .11636 L
.24262 .11369 L
.24967 .10664 L
.25233 .10398 L
.25938 .09693 L
.26204 .09427 L
.26909 .08722 L
.27176 .08455 L
.2788 .07751 L
.28147 .07484 L
.28852 .06779 L
.29118 .06513 L
.29823 .05808 L
.30089 .05542 L
.30794 .04837 L
.31061 .0457 L
.31765 .03866 L
.32032 .03599 L
.32737 .02894 L
.33003 .02621 L
.33696 .01923 L
.01923 .01923 L
F
0 g
.01923 .33708 m
.02621 .33003 L
.02894 .32737 L
.03599 .32032 L
.03866 .31765 L
.0457 .31061 L
.04837 .30794 L
.05542 .30089 L
.05808 .29823 L
.06513 .29118 L
.06779 .28852 L
.07484 .28147 L
.07751 .2788 L
.08455 .27176 L
.08722 .26909 L
.09427 .26204 L
.09693 .25938 L
.10398 .25233 L
.10664 .24967 L
.11369 .24262 L
.11636 .23995 L
.1234 .23291 L
.12607 .23024 L
.13312 .22319 L
.13578 .22053 L
.14283 .21348 L
.14549 .21082 L
.15254 .20377 L
.15521 .2011 L
.16225 .19406 L
.16492 .19139 L
.17197 .18434 L
.17463 .18168 L
.18168 .17463 L
.18434 .17197 L
.19139 .16492 L
.19406 .16225 L
.2011 .15521 L
.20377 .15254 L
.21082 .14549 L
.21348 .14283 L
.22053 .13578 L
.22319 .13312 L
.23024 .12607 L
.23291 .1234 L
.23995 .11636 L
.24262 .11369 L
.24967 .10664 L
.25233 .10398 L
.25938 .09693 L
Mistroke
.26204 .09427 L
.26909 .08722 L
.27176 .08455 L
.2788 .07751 L
.28147 .07484 L
.28852 .06779 L
.29118 .06513 L
.29823 .05808 L
.30089 .05542 L
.30794 .04837 L
.31061 .0457 L
.31765 .03866 L
.32032 .03599 L
.32737 .02894 L
.33003 .02621 L
.33696 .01923 L
Mfstroke
.4 g
.01923 .25846 m
.02556 .25233 L
.02894 .24875 L
.03507 .24262 L
.03866 .23903 L
.04478 .23291 L
.04837 .22932 L
.0545 .22319 L
.05808 .21961 L
.06421 .21348 L
.06779 .2099 L
.07392 .20377 L
.07751 .20018 L
.08363 .19406 L
.08722 .19047 L
.09335 .18434 L
.09693 .18076 L
.10306 .17463 L
.10664 .17105 L
.11277 .16492 L
.11636 .16133 L
.12248 .15521 L
.12607 .15162 L
.1322 .14549 L
.13578 .14191 L
.14191 .13578 L
.14549 .1322 L
.15162 .12607 L
.15521 .12248 L
.16133 .11636 L
.16492 .11277 L
.17105 .10664 L
.17463 .10306 L
.18076 .09693 L
.18434 .09335 L
.19047 .08722 L
.19406 .08363 L
.20018 .07751 L
.20377 .07392 L
.2099 .06779 L
.21348 .06421 L
.21961 .05808 L
.22319 .0545 L
.22932 .04837 L
.23291 .04478 L
.23903 .03866 L
.24262 .03507 L
.24875 .02894 L
.25233 .02556 L
.25846 .01923 L
.01923 .01923 L
F
0 g
.01923 .25846 m
.02556 .25233 L
.02894 .24875 L
.03507 .24262 L
.03866 .23903 L
.04478 .23291 L
.04837 .22932 L
.0545 .22319 L
.05808 .21961 L
.06421 .21348 L
.06779 .2099 L
.07392 .20377 L
.07751 .20018 L
.08363 .19406 L
.08722 .19047 L
.09335 .18434 L
.09693 .18076 L
.10306 .17463 L
.10664 .17105 L
.11277 .16492 L
.11636 .16133 L
.12248 .15521 L
.12607 .15162 L
.1322 .14549 L
.13578 .14191 L
.14191 .13578 L
.14549 .1322 L
.15162 .12607 L
.15521 .12248 L
.16133 .11636 L
.16492 .11277 L
.17105 .10664 L
.17463 .10306 L
.18076 .09693 L
.18434 .09335 L
.19047 .08722 L
.19406 .08363 L
.20018 .07751 L
.20377 .07392 L
.2099 .06779 L
.21348 .06421 L
.21961 .05808 L
.22319 .0545 L
.22932 .04837 L
.23291 .04478 L
.23903 .03866 L
.24262 .03507 L
.24875 .02894 L
.25233 .02556 L
.25846 .01923 L
Mistroke
Mfstroke
.5 g
.01923 .21478 m
.02054 .21348 L
.02894 .20507 L
.03024 .20377 L
.03866 .19535 L
.03995 .19406 L
.04837 .18564 L
.04967 .18434 L
.05808 .17593 L
.05938 .17463 L
.06779 .16622 L
.06909 .16492 L
.07751 .1565 L
.0788 .15521 L
.08722 .14679 L
.08852 .14549 L
.09693 .13708 L
.09823 .13578 L
.10664 .12737 L
.10794 .12607 L
.11636 .11765 L
.11765 .11636 L
.12607 .10794 L
.12737 .10664 L
.13578 .09823 L
.13708 .09693 L
.14549 .08852 L
.14679 .08722 L
.15521 .0788 L
.1565 .07751 L
.16492 .06909 L
.16622 .06779 L
.17463 .05938 L
.17593 .05808 L
.18434 .04967 L
.18564 .04837 L
.19406 .03995 L
.19535 .03866 L
.20377 .03024 L
.20507 .02894 L
.21348 .02054 L
.21478 .01923 L
.01923 .01923 L
F
0 g
.01923 .21478 m
.02054 .21348 L
.02894 .20507 L
.03024 .20377 L
.03866 .19535 L
.03995 .19406 L
.04837 .18564 L
.04967 .18434 L
.05808 .17593 L
.05938 .17463 L
.06779 .16622 L
.06909 .16492 L
.07751 .1565 L
.0788 .15521 L
.08722 .14679 L
.08852 .14549 L
.09693 .13708 L
.09823 .13578 L
.10664 .12737 L
.10794 .12607 L
.11636 .11765 L
.11765 .11636 L
.12607 .10794 L
.12737 .10664 L
.13578 .09823 L
.13708 .09693 L
.14549 .08852 L
.14679 .08722 L
.15521 .0788 L
.1565 .07751 L
.16492 .06909 L
.16622 .06779 L
.17463 .05938 L
.17593 .05808 L
.18434 .04967 L
.18564 .04837 L
.19406 .03995 L
.19535 .03866 L
.20377 .03024 L
.20507 .02894 L
.21348 .02054 L
.21478 .01923 L
s
.6 g
.01923 .17937 m
.02396 .17463 L
.02894 .16966 L
.03368 .16492 L
.03866 .15994 L
.04339 .15521 L
.04837 .15023 L
.05311 .14549 L
.05808 .14052 L
.06282 .13578 L
.06779 .13081 L
.07253 .12607 L
.07751 .12109 L
.08224 .11636 L
.08722 .11138 L
.09196 .10664 L
.09693 .10167 L
.10167 .09693 L
.10664 .09196 L
.11138 .08722 L
.11636 .08224 L
.12109 .07751 L
.12607 .07253 L
.13081 .06779 L
.13578 .06282 L
.14052 .05808 L
.14549 .05311 L
.15023 .04837 L
.15521 .04339 L
.15994 .03866 L
.16492 .03368 L
.16966 .02894 L
.17463 .02396 L
.17937 .01923 L
.01923 .01923 L
F
0 g
.01923 .17937 m
.02396 .17463 L
.02894 .16966 L
.03368 .16492 L
.03866 .15994 L
.04339 .15521 L
.04837 .15023 L
.05311 .14549 L
.05808 .14052 L
.06282 .13578 L
.06779 .13081 L
.07253 .12607 L
.07751 .12109 L
.08224 .11636 L
.08722 .11138 L
.09196 .10664 L
.09693 .10167 L
.10167 .09693 L
.10664 .09196 L
.11138 .08722 L
.11636 .08224 L
.12109 .07751 L
.12607 .07253 L
.13081 .06779 L
.13578 .06282 L
.14052 .05808 L
.14549 .05311 L
.15023 .04837 L
.15521 .04339 L
.15994 .03866 L
.16492 .03368 L
.16966 .02894 L
.17463 .02396 L
.17937 .01923 L
s
.7 g
.01923 .13565 m
.02881 .12607 L
.02894 .12594 L
.03853 .11636 L
.03866 .11623 L
.04824 .10664 L
.04837 .10651 L
.05795 .09693 L
.05808 .0968 L
.06766 .08722 L
.06779 .08709 L
.07738 .07751 L
.07751 .07738 L
.08709 .06779 L
.08722 .06766 L
.0968 .05808 L
.09693 .05795 L
.10651 .04837 L
.10664 .04824 L
.11623 .03866 L
.11636 .03853 L
.12594 .02894 L
.12607 .02881 L
.13565 .01923 L
.01923 .01923 L
F
0 g
.01923 .13565 m
.02881 .12607 L
.02894 .12594 L
.03853 .11636 L
.03866 .11623 L
.04824 .10664 L
.04837 .10651 L
.05795 .09693 L
.05808 .0968 L
.06766 .08722 L
.06779 .08709 L
.07738 .07751 L
.07751 .07738 L
.08709 .06779 L
.08722 .06766 L
.0968 .05808 L
.09693 .05795 L
.10651 .04837 L
.10664 .04824 L
.11623 .03866 L
.11636 .03853 L
.12594 .02894 L
.12607 .02881 L
.13565 .01923 L
s
.6 g
.01923 .0571 m
.02801 .04837 L
.02894 .04739 L
.03768 .03866 L
.03866 .03768 L
.04739 .02894 L
.04837 .02801 L
.0571 .01923 L
.01923 .01923 L
F
0 g
.01923 .0571 m
.02801 .04837 L
.02894 .04739 L
.03768 .03866 L
.03866 .03768 L
.04739 .02894 L
.04837 .02801 L
.0571 .01923 L
s
.5 g
.02336 .98077 m
.02894 .97518 L
.03308 .97106 L
.03866 .96548 L
.04279 .96134 L
.04837 .95577 L
.0525 .95163 L
.05808 .94605 L
.06222 .94192 L
.06779 .93634 L
.07193 .93221 L
.07751 .92663 L
.08164 .92249 L
.08722 .91692 L
.09135 .91278 L
.09693 .9072 L
.10107 .90307 L
.10664 .89749 L
.11078 .89336 L
.11636 .88778 L
.12049 .88364 L
.12607 .87807 L
.1302 .87393 L
.13578 .86835 L
.13992 .86422 L
.14549 .85864 L
.14963 .85451 L
.15521 .84893 L
.15934 .84479 L
.16492 .83922 L
.16905 .83508 L
.17463 .8295 L
.17877 .82537 L
.18434 .81979 L
.18848 .81566 L
.19406 .81008 L
.19819 .80594 L
.20377 .80037 L
.2079 .79623 L
.21348 .79065 L
.21762 .78652 L
.22319 .78094 L
.22733 .77681 L
.23291 .77123 L
.23704 .76709 L
.24262 .76152 L
.24675 .75738 L
.25233 .7518 L
.25647 .74767 L
.26204 .74209 L
.26618 .73796 L
.27176 .73238 L
.27589 .72824 L
.28147 .72267 L
.2856 .71853 L
.29118 .71295 L
.29532 .70882 L
.30089 .70324 L
.30503 .69911 L
.31061 .69353 L
.31474 .68939 L
.32032 .68382 L
.32445 .67968 L
.33003 .6741 L
.33418 .66997 L
.33974 .66439 L
.34396 .66026 L
.34946 .65495 L
.35375 .65054 L
.35917 .64472 L
.36271 .64083 L
.36888 .63378 L
.37116 .63112 L
.37859 .62216 L
.37921 .62141 L
.38694 .61169 L
.38831 .60993 L
.39439 .60198 L
.39802 .5971 L
.40158 .59227 L
.40773 .5837 L
.40855 .58256 L
.41535 .57284 L
.41744 .56977 L
.42196 .56313 L
.42716 .55532 L
.42842 .55342 L
.43474 .54371 L
.43687 .54038 L
.44094 .53399 L
.44658 .52495 L
.447 .52428 L
.45297 .51457 L
.45629 .50906 L
.45883 .50486 L
.46459 .49514 L
.46601 .49272 L
.47027 .48543 L
.47572 .47593 L
.47584 .47572 L
.48137 .46601 L
.48543 .45873 L
.48679 .45629 L
.49217 .44658 L
.49514 .4411 L
.49745 .43687 L
.50269 .42716 L
.50486 .42308 L
.50786 .41744 L
.51297 .40773 L
.51457 .40465 L
.51803 .39802 L
.52303 .38831 L
.52428 .38584 L
.52798 .37859 L
.53288 .36888 L
.53399 .36664 L
.53774 .35917 L
.54255 .34946 L
.54371 .34708 L
.54732 .33974 L
.55204 .33003 L
.55342 .32715 L
.55672 .32032 L
.56137 .31061 L
.56313 .30686 L
.56597 .30089 L
.57055 .29118 L
.57284 .28622 L
.57507 .28147 L
.57958 .27176 L
.58256 .26523 L
.58402 .26204 L
.58848 .25233 L
.59227 .24391 L
.59285 .24262 L
.59724 .23291 L
.60157 .22319 L
.60198 .22225 L
.60589 .21348 L
.61017 .20377 L
.61169 .20026 L
.61442 .19406 L
.61866 .18434 L
.62141 .17794 L
.62284 .17463 L
.62704 .16492 L
.63112 .15531 L
.63116 .15521 L
.63531 .14549 L
.63941 .13578 L
.64083 .13236 L
.64348 .12607 L
.64756 .11636 L
.65054 .1091 L
.65156 .10664 L
.6556 .09693 L
.65958 .08722 L
.66026 .08553 L
.66355 .07751 L
.66752 .06779 L
.66997 .06166 L
.67142 .05808 L
.67536 .04837 L
.67923 .03866 L
.67968 .03749 L
.68311 .02894 L
.68698 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.02336 .98077 m
.02894 .97518 L
.03308 .97106 L
.03866 .96548 L
.04279 .96134 L
.04837 .95577 L
.0525 .95163 L
.05808 .94605 L
.06222 .94192 L
.06779 .93634 L
.07193 .93221 L
.07751 .92663 L
.08164 .92249 L
.08722 .91692 L
.09135 .91278 L
.09693 .9072 L
.10107 .90307 L
.10664 .89749 L
.11078 .89336 L
.11636 .88778 L
.12049 .88364 L
.12607 .87807 L
.1302 .87393 L
.13578 .86835 L
.13992 .86422 L
.14549 .85864 L
.14963 .85451 L
.15521 .84893 L
.15934 .84479 L
.16492 .83922 L
.16905 .83508 L
.17463 .8295 L
.17877 .82537 L
.18434 .81979 L
.18848 .81566 L
.19406 .81008 L
.19819 .80594 L
.20377 .80037 L
.2079 .79623 L
.21348 .79065 L
.21762 .78652 L
.22319 .78094 L
.22733 .77681 L
.23291 .77123 L
.23704 .76709 L
.24262 .76152 L
.24675 .75738 L
.25233 .7518 L
.25647 .74767 L
.26204 .74209 L
Mistroke
.26618 .73796 L
.27176 .73238 L
.27589 .72824 L
.28147 .72267 L
.2856 .71853 L
.29118 .71295 L
.29532 .70882 L
.30089 .70324 L
.30503 .69911 L
.31061 .69353 L
.31474 .68939 L
.32032 .68382 L
.32445 .67968 L
.33003 .6741 L
.33418 .66997 L
.33974 .66439 L
.34396 .66026 L
.34946 .65495 L
.35375 .65054 L
.35917 .64472 L
.36271 .64083 L
.36888 .63378 L
.37116 .63112 L
.37859 .62216 L
.37921 .62141 L
.38694 .61169 L
.38831 .60993 L
.39439 .60198 L
.39802 .5971 L
.40158 .59227 L
.40773 .5837 L
.40855 .58256 L
.41535 .57284 L
.41744 .56977 L
.42196 .56313 L
.42716 .55532 L
.42842 .55342 L
.43474 .54371 L
.43687 .54038 L
.44094 .53399 L
.44658 .52495 L
.447 .52428 L
.45297 .51457 L
.45629 .50906 L
.45883 .50486 L
.46459 .49514 L
.46601 .49272 L
.47027 .48543 L
.47572 .47593 L
.47584 .47572 L
Mistroke
.48137 .46601 L
.48543 .45873 L
.48679 .45629 L
.49217 .44658 L
.49514 .4411 L
.49745 .43687 L
.50269 .42716 L
.50486 .42308 L
.50786 .41744 L
.51297 .40773 L
.51457 .40465 L
.51803 .39802 L
.52303 .38831 L
.52428 .38584 L
.52798 .37859 L
.53288 .36888 L
.53399 .36664 L
.53774 .35917 L
.54255 .34946 L
.54371 .34708 L
.54732 .33974 L
.55204 .33003 L
.55342 .32715 L
.55672 .32032 L
.56137 .31061 L
.56313 .30686 L
.56597 .30089 L
.57055 .29118 L
.57284 .28622 L
.57507 .28147 L
.57958 .27176 L
.58256 .26523 L
.58402 .26204 L
.58848 .25233 L
.59227 .24391 L
.59285 .24262 L
.59724 .23291 L
.60157 .22319 L
.60198 .22225 L
.60589 .21348 L
.61017 .20377 L
.61169 .20026 L
.61442 .19406 L
.61866 .18434 L
.62141 .17794 L
.62284 .17463 L
.62704 .16492 L
.63112 .15531 L
.63116 .15521 L
.63531 .14549 L
Mistroke
.63941 .13578 L
.64083 .13236 L
.64348 .12607 L
.64756 .11636 L
.65054 .1091 L
.65156 .10664 L
.6556 .09693 L
.65958 .08722 L
.66026 .08553 L
.66355 .07751 L
.66752 .06779 L
.66997 .06166 L
.67142 .05808 L
.67536 .04837 L
.67923 .03866 L
.67968 .03749 L
.68311 .02894 L
.68698 .01923 L
Mfstroke
.4 g
.05878 .98077 m
.06779 .97175 L
.06849 .97106 L
.07751 .96204 L
.0782 .96134 L
.08722 .95233 L
.08791 .95163 L
.09693 .94262 L
.09763 .94192 L
.10664 .9329 L
.10734 .93221 L
.11636 .92319 L
.11705 .92249 L
.12607 .91348 L
.12676 .91278 L
.13578 .90377 L
.13648 .90307 L
.14549 .89405 L
.14619 .89336 L
.15521 .88434 L
.1559 .88364 L
.16492 .87463 L
.16561 .87393 L
.17463 .86492 L
.17533 .86422 L
.18434 .8552 L
.18504 .85451 L
.19406 .84549 L
.19475 .84479 L
.20377 .83578 L
.20446 .83508 L
.21348 .82607 L
.21418 .82537 L
.22319 .81635 L
.22389 .81566 L
.23291 .80664 L
.2336 .80594 L
.24262 .79693 L
.24331 .79623 L
.25233 .78722 L
.25303 .78652 L
.26204 .7775 L
.26274 .77681 L
.27176 .76779 L
.27245 .76709 L
.28147 .75808 L
.28216 .75738 L
.29118 .74837 L
.29188 .74767 L
.30089 .73865 L
.30159 .73796 L
.31061 .72894 L
.3113 .72824 L
.32032 .71923 L
.32101 .71853 L
.33003 .70952 L
.33075 .70882 L
.33974 .6998 L
.34039 .69911 L
.3492 .68939 L
.34946 .6891 L
.3576 .67968 L
.35917 .67781 L
.36565 .66997 L
.36888 .66595 L
.37339 .66026 L
.37859 .65353 L
.38087 .65054 L
.38813 .64083 L
.38831 .64058 L
.39517 .63112 L
.39802 .62711 L
.40203 .62141 L
.40773 .61314 L
.40872 .61169 L
.41526 .60198 L
.41744 .59868 L
.42165 .59227 L
.42716 .58375 L
.42792 .58256 L
.43407 .57284 L
.43687 .56836 L
.4401 .56313 L
.44604 .55342 L
.44658 .55252 L
.45187 .54371 L
.45629 .53625 L
.45762 .53399 L
.46328 .52428 L
.46601 .51954 L
.46885 .51457 L
.47435 .50486 L
.47572 .50243 L
.47978 .49514 L
.48514 .48543 L
.48543 .4849 L
.49043 .47572 L
.49514 .46698 L
.49566 .46601 L
.50083 .45629 L
.50486 .44867 L
.50595 .44658 L
.51101 .43687 L
.51457 .42998 L
.51601 .42716 L
.52097 .41744 L
.52428 .41091 L
.52588 .40773 L
.53074 .39802 L
.53399 .39147 L
.53555 .38831 L
.54033 .37859 L
.54371 .37168 L
.54506 .36888 L
.54975 .35917 L
.55342 .35153 L
.5544 .34946 L
.55901 .33974 L
.56313 .33103 L
.5636 .33003 L
.56813 .32032 L
.57265 .31061 L
.57284 .31019 L
.57711 .30089 L
.58157 .29118 L
.58256 .28901 L
.58596 .28147 L
.59035 .27176 L
.59227 .26749 L
.59469 .26204 L
.59902 .25233 L
.60198 .24565 L
.60331 .24262 L
.60757 .23291 L
.61169 .22349 L
.61182 .22319 L
.61602 .21348 L
.62022 .20377 L
.62141 .20101 L
.62437 .19406 L
.62852 .18434 L
.63112 .17821 L
.63262 .17463 L
.63671 .16492 L
.64079 .15521 L
.64083 .15511 L
.64482 .14549 L
.64886 .13578 L
.65054 .1317 L
.65284 .12607 L
.65683 .11636 L
.66026 .10798 L
.66079 .10664 L
.66472 .09693 L
.66866 .08722 L
.66997 .08397 L
.67254 .07751 L
.67644 .06779 L
.67968 .05967 L
.6803 .05808 L
.68414 .04837 L
.68798 .03866 L
.68939 .03507 L
.69177 .02894 L
.69558 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.05878 .98077 m
.06779 .97175 L
.06849 .97106 L
.07751 .96204 L
.0782 .96134 L
.08722 .95233 L
.08791 .95163 L
.09693 .94262 L
.09763 .94192 L
.10664 .9329 L
.10734 .93221 L
.11636 .92319 L
.11705 .92249 L
.12607 .91348 L
.12676 .91278 L
.13578 .90377 L
.13648 .90307 L
.14549 .89405 L
.14619 .89336 L
.15521 .88434 L
.1559 .88364 L
.16492 .87463 L
.16561 .87393 L
.17463 .86492 L
.17533 .86422 L
.18434 .8552 L
.18504 .85451 L
.19406 .84549 L
.19475 .84479 L
.20377 .83578 L
.20446 .83508 L
.21348 .82607 L
.21418 .82537 L
.22319 .81635 L
.22389 .81566 L
.23291 .80664 L
.2336 .80594 L
.24262 .79693 L
.24331 .79623 L
.25233 .78722 L
.25303 .78652 L
.26204 .7775 L
.26274 .77681 L
.27176 .76779 L
.27245 .76709 L
.28147 .75808 L
.28216 .75738 L
.29118 .74837 L
.29188 .74767 L
.30089 .73865 L
Mistroke
.30159 .73796 L
.31061 .72894 L
.3113 .72824 L
.32032 .71923 L
.32101 .71853 L
.33003 .70952 L
.33075 .70882 L
.33974 .6998 L
.34039 .69911 L
.3492 .68939 L
.34946 .6891 L
.3576 .67968 L
.35917 .67781 L
.36565 .66997 L
.36888 .66595 L
.37339 .66026 L
.37859 .65353 L
.38087 .65054 L
.38813 .64083 L
.38831 .64058 L
.39517 .63112 L
.39802 .62711 L
.40203 .62141 L
.40773 .61314 L
.40872 .61169 L
.41526 .60198 L
.41744 .59868 L
.42165 .59227 L
.42716 .58375 L
.42792 .58256 L
.43407 .57284 L
.43687 .56836 L
.4401 .56313 L
.44604 .55342 L
.44658 .55252 L
.45187 .54371 L
.45629 .53625 L
.45762 .53399 L
.46328 .52428 L
.46601 .51954 L
.46885 .51457 L
.47435 .50486 L
.47572 .50243 L
.47978 .49514 L
.48514 .48543 L
.48543 .4849 L
.49043 .47572 L
.49514 .46698 L
.49566 .46601 L
.50083 .45629 L
Mistroke
.50486 .44867 L
.50595 .44658 L
.51101 .43687 L
.51457 .42998 L
.51601 .42716 L
.52097 .41744 L
.52428 .41091 L
.52588 .40773 L
.53074 .39802 L
.53399 .39147 L
.53555 .38831 L
.54033 .37859 L
.54371 .37168 L
.54506 .36888 L
.54975 .35917 L
.55342 .35153 L
.5544 .34946 L
.55901 .33974 L
.56313 .33103 L
.5636 .33003 L
.56813 .32032 L
.57265 .31061 L
.57284 .31019 L
.57711 .30089 L
.58157 .29118 L
.58256 .28901 L
.58596 .28147 L
.59035 .27176 L
.59227 .26749 L
.59469 .26204 L
.59902 .25233 L
.60198 .24565 L
.60331 .24262 L
.60757 .23291 L
.61169 .22349 L
.61182 .22319 L
.61602 .21348 L
.62022 .20377 L
.62141 .20101 L
.62437 .19406 L
.62852 .18434 L
.63112 .17821 L
.63262 .17463 L
.63671 .16492 L
.64079 .15521 L
.64083 .15511 L
.64482 .14549 L
.64886 .13578 L
.65054 .1317 L
.65284 .12607 L
Mistroke
.65683 .11636 L
.66026 .10798 L
.66079 .10664 L
.66472 .09693 L
.66866 .08722 L
.66997 .08397 L
.67254 .07751 L
.67644 .06779 L
.67968 .05967 L
.6803 .05808 L
.68414 .04837 L
.68798 .03866 L
.68939 .03507 L
.69177 .02894 L
.69558 .01923 L
Mfstroke
.3 g
.10245 .98077 m
.10664 .97666 L
.11217 .97106 L
.11636 .96687 L
.12188 .96134 L
.12607 .95715 L
.13159 .95163 L
.13578 .94744 L
.1413 .94192 L
.14549 .93773 L
.15102 .93221 L
.15521 .92802 L
.16073 .92249 L
.16492 .9183 L
.17044 .91278 L
.17463 .90859 L
.18015 .90307 L
.18434 .89888 L
.18987 .89336 L
.19406 .88917 L
.19958 .88364 L
.20377 .87945 L
.20929 .87393 L
.21348 .86974 L
.219 .86422 L
.22319 .86003 L
.22872 .85451 L
.23291 .85032 L
.23843 .84479 L
.24262 .8406 L
.24814 .83508 L
.25233 .83089 L
.25785 .82537 L
.26204 .82118 L
.26757 .81566 L
.27176 .81147 L
.27728 .80594 L
.28147 .80175 L
.28699 .79623 L
.29118 .79204 L
.2967 .78652 L
.30089 .78233 L
.30642 .77681 L
.31061 .77262 L
.31613 .76709 L
.32032 .7629 L
.32584 .75738 L
.33003 .75319 L
.33585 .74767 L
.33974 .74348 L
.34397 .73796 L
.34946 .73036 L
.35103 .72824 L
.35818 .71853 L
.35917 .71717 L
.36522 .70882 L
.36888 .70372 L
.37216 .69911 L
.37859 .69 L
.37901 .68939 L
.38572 .67968 L
.38831 .6759 L
.3923 .66997 L
.39802 .66145 L
.3988 .66026 L
.40516 .65054 L
.40773 .64659 L
.41141 .64083 L
.41744 .63137 L
.4176 .63112 L
.42363 .62141 L
.42716 .61572 L
.42959 .61169 L
.43549 .60198 L
.43687 .59969 L
.44125 .59227 L
.44658 .58327 L
.44699 .58256 L
.4526 .57284 L
.45629 .56645 L
.45815 .56313 L
.46366 .55342 L
.46601 .54925 L
.46905 .54371 L
.47444 .53399 L
.47572 .53168 L
.47969 .52428 L
.48498 .51457 L
.48543 .51373 L
.4901 .50486 L
.49514 .49541 L
.49528 .49514 L
.5003 .48543 L
.50486 .47672 L
.50535 .47572 L
.51029 .46601 L
.51457 .45767 L
.51524 .45629 L
.52009 .44658 L
.52428 .43827 L
.52495 .43687 L
.52971 .42716 L
.53399 .41852 L
.53449 .41744 L
.53916 .40773 L
.54371 .39842 L
.54389 .39802 L
.54846 .38831 L
.55313 .37859 L
.55342 .37799 L
.55761 .36888 L
.56221 .35917 L
.56313 .35721 L
.56663 .34946 L
.57116 .33974 L
.57284 .33611 L
.57553 .33003 L
.57997 .32032 L
.58256 .31468 L
.58431 .31061 L
.58867 .30089 L
.59227 .29294 L
.593 .29118 L
.59725 .28147 L
.60159 .27176 L
.60198 .27087 L
.60573 .26204 L
.61001 .25233 L
.61169 .24849 L
.61412 .24262 L
.61832 .23291 L
.62141 .2258 L
.62244 .22319 L
.62653 .21348 L
.63071 .20377 L
.63112 .20281 L
.63467 .19406 L
.63878 .18434 L
.64083 .1795 L
.64274 .17463 L
.64677 .16492 L
.65054 .15591 L
.65081 .15521 L
.65468 .14549 L
.6587 .13578 L
.66026 .13201 L
.66253 .12607 L
.66648 .11636 L
.66997 .10783 L
.6704 .10664 L
.67419 .09693 L
.67812 .08722 L
.67968 .08336 L
.68186 .07751 L
.68571 .06779 L
.68939 .0586 L
.68958 .05808 L
.69324 .04837 L
.69709 .03866 L
.69911 .03356 L
.70076 .02894 L
.70451 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.10245 .98077 m
.10664 .97666 L
.11217 .97106 L
.11636 .96687 L
.12188 .96134 L
.12607 .95715 L
.13159 .95163 L
.13578 .94744 L
.1413 .94192 L
.14549 .93773 L
.15102 .93221 L
.15521 .92802 L
.16073 .92249 L
.16492 .9183 L
.17044 .91278 L
.17463 .90859 L
.18015 .90307 L
.18434 .89888 L
.18987 .89336 L
.19406 .88917 L
.19958 .88364 L
.20377 .87945 L
.20929 .87393 L
.21348 .86974 L
.219 .86422 L
.22319 .86003 L
.22872 .85451 L
.23291 .85032 L
.23843 .84479 L
.24262 .8406 L
.24814 .83508 L
.25233 .83089 L
.25785 .82537 L
.26204 .82118 L
.26757 .81566 L
.27176 .81147 L
.27728 .80594 L
.28147 .80175 L
.28699 .79623 L
.29118 .79204 L
.2967 .78652 L
.30089 .78233 L
.30642 .77681 L
.31061 .77262 L
.31613 .76709 L
.32032 .7629 L
.32584 .75738 L
.33003 .75319 L
.33585 .74767 L
.33974 .74348 L
Mistroke
.34397 .73796 L
.34946 .73036 L
.35103 .72824 L
.35818 .71853 L
.35917 .71717 L
.36522 .70882 L
.36888 .70372 L
.37216 .69911 L
.37859 .69 L
.37901 .68939 L
.38572 .67968 L
.38831 .6759 L
.3923 .66997 L
.39802 .66145 L
.3988 .66026 L
.40516 .65054 L
.40773 .64659 L
.41141 .64083 L
.41744 .63137 L
.4176 .63112 L
.42363 .62141 L
.42716 .61572 L
.42959 .61169 L
.43549 .60198 L
.43687 .59969 L
.44125 .59227 L
.44658 .58327 L
.44699 .58256 L
.4526 .57284 L
.45629 .56645 L
.45815 .56313 L
.46366 .55342 L
.46601 .54925 L
.46905 .54371 L
.47444 .53399 L
.47572 .53168 L
.47969 .52428 L
.48498 .51457 L
.48543 .51373 L
.4901 .50486 L
.49514 .49541 L
.49528 .49514 L
.5003 .48543 L
.50486 .47672 L
.50535 .47572 L
.51029 .46601 L
.51457 .45767 L
.51524 .45629 L
.52009 .44658 L
.52428 .43827 L
Mistroke
.52495 .43687 L
.52971 .42716 L
.53399 .41852 L
.53449 .41744 L
.53916 .40773 L
.54371 .39842 L
.54389 .39802 L
.54846 .38831 L
.55313 .37859 L
.55342 .37799 L
.55761 .36888 L
.56221 .35917 L
.56313 .35721 L
.56663 .34946 L
.57116 .33974 L
.57284 .33611 L
.57553 .33003 L
.57997 .32032 L
.58256 .31468 L
.58431 .31061 L
.58867 .30089 L
.59227 .29294 L
.593 .29118 L
.59725 .28147 L
.60159 .27176 L
.60198 .27087 L
.60573 .26204 L
.61001 .25233 L
.61169 .24849 L
.61412 .24262 L
.61832 .23291 L
.62141 .2258 L
.62244 .22319 L
.62653 .21348 L
.63071 .20377 L
.63112 .20281 L
.63467 .19406 L
.63878 .18434 L
.64083 .1795 L
.64274 .17463 L
.64677 .16492 L
.65054 .15591 L
.65081 .15521 L
.65468 .14549 L
.6587 .13578 L
.66026 .13201 L
.66253 .12607 L
.66648 .11636 L
.66997 .10783 L
.6704 .10664 L
Mistroke
.67419 .09693 L
.67812 .08722 L
.67968 .08336 L
.68186 .07751 L
.68571 .06779 L
.68939 .0586 L
.68958 .05808 L
.69324 .04837 L
.69709 .03866 L
.69911 .03356 L
.70076 .02894 L
.70451 .01923 L
Mfstroke
.4 g
.18108 .98077 m
.18434 .97713 L
.19079 .97106 L
.19406 .96779 L
.2005 .96134 L
.20377 .95808 L
.21022 .95163 L
.21348 .94837 L
.21993 .94192 L
.22319 .93865 L
.22964 .93221 L
.23291 .92894 L
.23935 .92249 L
.24262 .91923 L
.24907 .91278 L
.25233 .90952 L
.25878 .90307 L
.26204 .8998 L
.26849 .89336 L
.27176 .89009 L
.2782 .88364 L
.28147 .88038 L
.28792 .87393 L
.29118 .87067 L
.29763 .86422 L
.30089 .86095 L
.30734 .85451 L
.31061 .85124 L
.31705 .84479 L
.32032 .84153 L
.32677 .83508 L
.33003 .83182 L
.33636 .82537 L
.33974 .8221 L
.34851 .81566 L
.34946 .81505 L
.35917 .80674 L
.36008 .80594 L
.36888 .79737 L
.37004 .79623 L
.37859 .78708 L
.37912 .78652 L
.38766 .77681 L
.38831 .77598 L
.39577 .76709 L
.39802 .76416 L
.40345 .75738 L
.40773 .75164 L
.41077 .74767 L
.41744 .73847 L
.41782 .73796 L
.42481 .72824 L
.42716 .72474 L
.4315 .71853 L
.43687 .71043 L
.43796 .70882 L
.4444 .69911 L
.44658 .69559 L
.45062 .68939 L
.45629 .68023 L
.45664 .67968 L
.46272 .66997 L
.46601 .66439 L
.46854 .66026 L
.47433 .65054 L
.47572 .64807 L
.48003 .64083 L
.48543 .63128 L
.48553 .63112 L
.49114 .62141 L
.49514 .61407 L
.49649 .61169 L
.50193 .60198 L
.50486 .59642 L
.50715 .59227 L
.51243 .58256 L
.51457 .57835 L
.51755 .57284 L
.52267 .56313 L
.52428 .55987 L
.5277 .55342 L
.53269 .54371 L
.53399 .54099 L
.53762 .53399 L
.54251 .52428 L
.54371 .52172 L
.54735 .51457 L
.55214 .50486 L
.55342 .50208 L
.55688 .49514 L
.56161 .48543 L
.56313 .48206 L
.56625 .47572 L
.57091 .46601 L
.57284 .46168 L
.57544 .45629 L
.58006 .44658 L
.58256 .44094 L
.58449 .43687 L
.58906 .42716 L
.59227 .41985 L
.59339 .41744 L
.59791 .40773 L
.60198 .39841 L
.60216 .39802 L
.60663 .38831 L
.6109 .37859 L
.61169 .37664 L
.61521 .36888 L
.61951 .35917 L
.62141 .35454 L
.62368 .34946 L
.62798 .33974 L
.63112 .3321 L
.63203 .33003 L
.6363 .32032 L
.64035 .31061 L
.64083 .30934 L
.64451 .30089 L
.64863 .29118 L
.65054 .28627 L
.6526 .28147 L
.65675 .27176 L
.66026 .26288 L
.66061 .26204 L
.66473 .25233 L
.66869 .24262 L
.66997 .23919 L
.6726 .23291 L
.67662 .22319 L
.67968 .21518 L
.68038 .21348 L
.6844 .20377 L
.68826 .19406 L
.68939 .19089 L
.69207 .18434 L
.696 .17463 L
.69911 .16628 L
.69966 .16492 L
.70358 .15521 L
.70738 .14549 L
.70882 .1414 L
.71106 .13578 L
.71493 .12607 L
.71848 .11636 L
.71853 .11621 L
.72232 .10664 L
.72608 .09693 L
.72824 .09075 L
.72962 .08722 L
.73342 .07751 L
.73703 .06779 L
.73796 .065 L
.74063 .05808 L
.74437 .04837 L
.74767 .03897 L
.74779 .03866 L
.75152 .02894 L
.75517 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.18108 .98077 m
.18434 .97713 L
.19079 .97106 L
.19406 .96779 L
.2005 .96134 L
.20377 .95808 L
.21022 .95163 L
.21348 .94837 L
.21993 .94192 L
.22319 .93865 L
.22964 .93221 L
.23291 .92894 L
.23935 .92249 L
.24262 .91923 L
.24907 .91278 L
.25233 .90952 L
.25878 .90307 L
.26204 .8998 L
.26849 .89336 L
.27176 .89009 L
.2782 .88364 L
.28147 .88038 L
.28792 .87393 L
.29118 .87067 L
.29763 .86422 L
.30089 .86095 L
.30734 .85451 L
.31061 .85124 L
.31705 .84479 L
.32032 .84153 L
.32677 .83508 L
.33003 .83182 L
.33636 .82537 L
.33974 .8221 L
.34851 .81566 L
.34946 .81505 L
.35917 .80674 L
.36008 .80594 L
.36888 .79737 L
.37004 .79623 L
.37859 .78708 L
.37912 .78652 L
.38766 .77681 L
.38831 .77598 L
.39577 .76709 L
.39802 .76416 L
.40345 .75738 L
.40773 .75164 L
.41077 .74767 L
.41744 .73847 L
Mistroke
.41782 .73796 L
.42481 .72824 L
.42716 .72474 L
.4315 .71853 L
.43687 .71043 L
.43796 .70882 L
.4444 .69911 L
.44658 .69559 L
.45062 .68939 L
.45629 .68023 L
.45664 .67968 L
.46272 .66997 L
.46601 .66439 L
.46854 .66026 L
.47433 .65054 L
.47572 .64807 L
.48003 .64083 L
.48543 .63128 L
.48553 .63112 L
.49114 .62141 L
.49514 .61407 L
.49649 .61169 L
.50193 .60198 L
.50486 .59642 L
.50715 .59227 L
.51243 .58256 L
.51457 .57835 L
.51755 .57284 L
.52267 .56313 L
.52428 .55987 L
.5277 .55342 L
.53269 .54371 L
.53399 .54099 L
.53762 .53399 L
.54251 .52428 L
.54371 .52172 L
.54735 .51457 L
.55214 .50486 L
.55342 .50208 L
.55688 .49514 L
.56161 .48543 L
.56313 .48206 L
.56625 .47572 L
.57091 .46601 L
.57284 .46168 L
.57544 .45629 L
.58006 .44658 L
.58256 .44094 L
.58449 .43687 L
.58906 .42716 L
Mistroke
.59227 .41985 L
.59339 .41744 L
.59791 .40773 L
.60198 .39841 L
.60216 .39802 L
.60663 .38831 L
.6109 .37859 L
.61169 .37664 L
.61521 .36888 L
.61951 .35917 L
.62141 .35454 L
.62368 .34946 L
.62798 .33974 L
.63112 .3321 L
.63203 .33003 L
.6363 .32032 L
.64035 .31061 L
.64083 .30934 L
.64451 .30089 L
.64863 .29118 L
.65054 .28627 L
.6526 .28147 L
.65675 .27176 L
.66026 .26288 L
.66061 .26204 L
.66473 .25233 L
.66869 .24262 L
.66997 .23919 L
.6726 .23291 L
.67662 .22319 L
.67968 .21518 L
.68038 .21348 L
.6844 .20377 L
.68826 .19406 L
.68939 .19089 L
.69207 .18434 L
.696 .17463 L
.69911 .16628 L
.69966 .16492 L
.70358 .15521 L
.70738 .14549 L
.70882 .1414 L
.71106 .13578 L
.71493 .12607 L
.71848 .11636 L
.71853 .11621 L
.72232 .10664 L
.72608 .09693 L
.72824 .09075 L
.72962 .08722 L
Mistroke
.73342 .07751 L
.73703 .06779 L
.73796 .065 L
.74063 .05808 L
.74437 .04837 L
.74767 .03897 L
.74779 .03866 L
.75152 .02894 L
.75517 .01923 L
Mfstroke
.5 g
.22475 .98077 m
.23291 .97261 L
.23446 .97106 L
.24262 .9629 L
.24417 .96134 L
.25233 .95319 L
.25389 .95163 L
.26204 .94347 L
.2636 .94192 L
.27176 .93376 L
.27331 .93221 L
.28147 .92405 L
.28302 .92249 L
.29118 .91434 L
.29274 .91278 L
.30089 .90462 L
.30245 .90307 L
.31061 .89491 L
.31216 .89336 L
.32032 .8852 L
.32187 .88364 L
.33003 .87549 L
.3316 .87393 L
.33974 .86577 L
.34132 .86422 L
.34946 .85633 L
.35126 .85451 L
.35917 .84611 L
.36037 .84479 L
.36888 .83516 L
.36895 .83508 L
.37712 .82537 L
.37859 .82355 L
.38493 .81566 L
.38831 .81131 L
.39244 .80594 L
.39802 .79848 L
.39968 .79623 L
.40672 .78652 L
.40773 .78509 L
.41356 .77681 L
.41744 .77116 L
.42022 .76709 L
.42671 .75738 L
.42716 .75671 L
.43308 .74767 L
.43687 .74176 L
.4393 .73796 L
.4454 .72824 L
.44658 .72633 L
.4514 .71853 L
.45629 .71044 L
.45727 .70882 L
.46307 .69911 L
.46601 .6941 L
.46877 .68939 L
.47438 .67968 L
.47572 .67732 L
.47991 .66997 L
.48535 .66026 L
.48543 .66011 L
.49075 .65054 L
.49514 .64249 L
.49605 .64083 L
.50131 .63112 L
.50486 .62446 L
.50649 .62141 L
.51163 .61169 L
.51457 .60603 L
.51669 .60198 L
.52171 .59227 L
.52428 .58722 L
.52667 .58256 L
.53159 .57284 L
.53399 .56803 L
.53645 .56313 L
.54128 .55342 L
.54371 .54846 L
.54605 .54371 L
.5508 .53399 L
.55342 .52853 L
.55548 .52428 L
.56014 .51457 L
.56313 .50824 L
.56474 .50486 L
.56934 .49514 L
.57284 .4876 L
.57386 .48543 L
.57839 .47572 L
.58256 .46662 L
.58284 .46601 L
.5873 .45629 L
.59169 .44658 L
.59227 .44529 L
.59608 .43687 L
.60043 .42716 L
.60198 .42363 L
.60474 .41744 L
.60904 .40773 L
.61169 .40164 L
.61329 .39802 L
.61754 .38831 L
.62141 .37933 L
.62172 .37859 L
.62593 .36888 L
.63008 .35917 L
.63112 .35669 L
.63421 .34946 L
.63833 .33974 L
.64083 .33374 L
.6424 .33003 L
.64648 .32032 L
.65049 .31061 L
.65054 .31048 L
.65453 .30089 L
.65853 .29118 L
.66026 .28692 L
.66249 .28147 L
.66647 .27176 L
.66997 .26304 L
.67037 .26204 L
.67431 .25233 L
.67821 .24262 L
.67968 .23888 L
.68207 .23291 L
.68596 .22319 L
.68939 .21441 L
.68976 .21348 L
.69361 .20377 L
.69742 .19406 L
.69911 .18966 L
.70119 .18434 L
.70498 .17463 L
.7087 .16492 L
.70882 .16461 L
.71246 .15521 L
.7162 .14549 L
.71853 .13929 L
.71987 .13578 L
.72359 .12607 L
.72726 .11636 L
.72824 .11368 L
.73091 .10664 L
.73458 .09693 L
.73796 .08779 L
.73817 .08722 L
.74181 .07751 L
.74543 .06779 L
.74767 .06162 L
.74898 .05808 L
.75259 .04837 L
.75614 .03866 L
.75738 .03519 L
.75967 .02894 L
.76324 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.22475 .98077 m
.23291 .97261 L
.23446 .97106 L
.24262 .9629 L
.24417 .96134 L
.25233 .95319 L
.25389 .95163 L
.26204 .94347 L
.2636 .94192 L
.27176 .93376 L
.27331 .93221 L
.28147 .92405 L
.28302 .92249 L
.29118 .91434 L
.29274 .91278 L
.30089 .90462 L
.30245 .90307 L
.31061 .89491 L
.31216 .89336 L
.32032 .8852 L
.32187 .88364 L
.33003 .87549 L
.3316 .87393 L
.33974 .86577 L
.34132 .86422 L
.34946 .85633 L
.35126 .85451 L
.35917 .84611 L
.36037 .84479 L
.36888 .83516 L
.36895 .83508 L
.37712 .82537 L
.37859 .82355 L
.38493 .81566 L
.38831 .81131 L
.39244 .80594 L
.39802 .79848 L
.39968 .79623 L
.40672 .78652 L
.40773 .78509 L
.41356 .77681 L
.41744 .77116 L
.42022 .76709 L
.42671 .75738 L
.42716 .75671 L
.43308 .74767 L
.43687 .74176 L
.4393 .73796 L
.4454 .72824 L
.44658 .72633 L
Mistroke
.4514 .71853 L
.45629 .71044 L
.45727 .70882 L
.46307 .69911 L
.46601 .6941 L
.46877 .68939 L
.47438 .67968 L
.47572 .67732 L
.47991 .66997 L
.48535 .66026 L
.48543 .66011 L
.49075 .65054 L
.49514 .64249 L
.49605 .64083 L
.50131 .63112 L
.50486 .62446 L
.50649 .62141 L
.51163 .61169 L
.51457 .60603 L
.51669 .60198 L
.52171 .59227 L
.52428 .58722 L
.52667 .58256 L
.53159 .57284 L
.53399 .56803 L
.53645 .56313 L
.54128 .55342 L
.54371 .54846 L
.54605 .54371 L
.5508 .53399 L
.55342 .52853 L
.55548 .52428 L
.56014 .51457 L
.56313 .50824 L
.56474 .50486 L
.56934 .49514 L
.57284 .4876 L
.57386 .48543 L
.57839 .47572 L
.58256 .46662 L
.58284 .46601 L
.5873 .45629 L
.59169 .44658 L
.59227 .44529 L
.59608 .43687 L
.60043 .42716 L
.60198 .42363 L
.60474 .41744 L
.60904 .40773 L
.61169 .40164 L
Mistroke
.61329 .39802 L
.61754 .38831 L
.62141 .37933 L
.62172 .37859 L
.62593 .36888 L
.63008 .35917 L
.63112 .35669 L
.63421 .34946 L
.63833 .33974 L
.64083 .33374 L
.6424 .33003 L
.64648 .32032 L
.65049 .31061 L
.65054 .31048 L
.65453 .30089 L
.65853 .29118 L
.66026 .28692 L
.66249 .28147 L
.66647 .27176 L
.66997 .26304 L
.67037 .26204 L
.67431 .25233 L
.67821 .24262 L
.67968 .23888 L
.68207 .23291 L
.68596 .22319 L
.68939 .21441 L
.68976 .21348 L
.69361 .20377 L
.69742 .19406 L
.69911 .18966 L
.70119 .18434 L
.70498 .17463 L
.7087 .16492 L
.70882 .16461 L
.71246 .15521 L
.7162 .14549 L
.71853 .13929 L
.71987 .13578 L
.72359 .12607 L
.72726 .11636 L
.72824 .11368 L
.73091 .10664 L
.73458 .09693 L
.73796 .08779 L
.73817 .08722 L
.74181 .07751 L
.74543 .06779 L
.74767 .06162 L
.74898 .05808 L
Mistroke
.75259 .04837 L
.75614 .03866 L
.75738 .03519 L
.75967 .02894 L
.76324 .01923 L
Mfstroke
.6 g
.26016 .98077 m
.26204 .97889 L
.26987 .97106 L
.27176 .96917 L
.27959 .96134 L
.28147 .95946 L
.2893 .95163 L
.29118 .94975 L
.29901 .94192 L
.30089 .94004 L
.30872 .93221 L
.31061 .93032 L
.31844 .92249 L
.32032 .92061 L
.32815 .91278 L
.33003 .9109 L
.33792 .90307 L
.33974 .90119 L
.34689 .89336 L
.34946 .89049 L
.35541 .88364 L
.35917 .8792 L
.36354 .87393 L
.36888 .86733 L
.37136 .86422 L
.37859 .85492 L
.37891 .85451 L
.38622 .84479 L
.38831 .84197 L
.39332 .83508 L
.39802 .8285 L
.40022 .82537 L
.40696 .81566 L
.40773 .81453 L
.41354 .80594 L
.41744 .80007 L
.41997 .79623 L
.42627 .78652 L
.42716 .78514 L
.43245 .77681 L
.43687 .76974 L
.43851 .76709 L
.44447 .75738 L
.44658 .75391 L
.45033 .74767 L
.4561 .73796 L
.45629 .73763 L
.46178 .72824 L
.46601 .72093 L
.46738 .71853 L
.4729 .70882 L
.47572 .70381 L
.47834 .69911 L
.48373 .68939 L
.48543 .68629 L
.48903 .67968 L
.49428 .66997 L
.49514 .66837 L
.49946 .66026 L
.5046 .65054 L
.50486 .65005 L
.50967 .64083 L
.51457 .63136 L
.51469 .63112 L
.51966 .62141 L
.52428 .61229 L
.52458 .61169 L
.52945 .60198 L
.53399 .59286 L
.53428 .59227 L
.53906 .58256 L
.54371 .57306 L
.54381 .57284 L
.54851 .56313 L
.55318 .55342 L
.55342 .55291 L
.55779 .54371 L
.56239 .53399 L
.56313 .53241 L
.56693 .52428 L
.57146 .51457 L
.57284 .51157 L
.57593 .50486 L
.58039 .49514 L
.58256 .49039 L
.5848 .48543 L
.58919 .47572 L
.59227 .46888 L
.59354 .46601 L
.59787 .45629 L
.60198 .44704 L
.60218 .44658 L
.60644 .43687 L
.6107 .42716 L
.61169 .42487 L
.6149 .41744 L
.61911 .40773 L
.62141 .40239 L
.62327 .39802 L
.62741 .38831 L
.63112 .3796 L
.63154 .37859 L
.63562 .36888 L
.63971 .35917 L
.64083 .35649 L
.64374 .34946 L
.64779 .33974 L
.65054 .33308 L
.65179 .33003 L
.65577 .32032 L
.65975 .31061 L
.66026 .30937 L
.66368 .30089 L
.66762 .29118 L
.66997 .28536 L
.67151 .28147 L
.6754 .27176 L
.67929 .26204 L
.67968 .26105 L
.68312 .25233 L
.68697 .24262 L
.68939 .23646 L
.69077 .23291 L
.69457 .22319 L
.69837 .21348 L
.69911 .21157 L
.7021 .20377 L
.70587 .19406 L
.70882 .1864 L
.7096 .18434 L
.7133 .17463 L
.71702 .16492 L
.71853 .16095 L
.72068 .15521 L
.72437 .14549 L
.72804 .13578 L
.72824 .13523 L
.73165 .12607 L
.73529 .11636 L
.73796 .10922 L
.7389 .10664 L
.74249 .09693 L
.74609 .08722 L
.74767 .08295 L
.74964 .07751 L
.75321 .06779 L
.75677 .05808 L
.75738 .0564 L
.76027 .04837 L
.76381 .03866 L
.76709 .02959 L
.76732 .02894 L
.77079 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.26016 .98077 m
.26204 .97889 L
.26987 .97106 L
.27176 .96917 L
.27959 .96134 L
.28147 .95946 L
.2893 .95163 L
.29118 .94975 L
.29901 .94192 L
.30089 .94004 L
.30872 .93221 L
.31061 .93032 L
.31844 .92249 L
.32032 .92061 L
.32815 .91278 L
.33003 .9109 L
.33792 .90307 L
.33974 .90119 L
.34689 .89336 L
.34946 .89049 L
.35541 .88364 L
.35917 .8792 L
.36354 .87393 L
.36888 .86733 L
.37136 .86422 L
.37859 .85492 L
.37891 .85451 L
.38622 .84479 L
.38831 .84197 L
.39332 .83508 L
.39802 .8285 L
.40022 .82537 L
.40696 .81566 L
.40773 .81453 L
.41354 .80594 L
.41744 .80007 L
.41997 .79623 L
.42627 .78652 L
.42716 .78514 L
.43245 .77681 L
.43687 .76974 L
.43851 .76709 L
.44447 .75738 L
.44658 .75391 L
.45033 .74767 L
.4561 .73796 L
.45629 .73763 L
.46178 .72824 L
.46601 .72093 L
.46738 .71853 L
Mistroke
.4729 .70882 L
.47572 .70381 L
.47834 .69911 L
.48373 .68939 L
.48543 .68629 L
.48903 .67968 L
.49428 .66997 L
.49514 .66837 L
.49946 .66026 L
.5046 .65054 L
.50486 .65005 L
.50967 .64083 L
.51457 .63136 L
.51469 .63112 L
.51966 .62141 L
.52428 .61229 L
.52458 .61169 L
.52945 .60198 L
.53399 .59286 L
.53428 .59227 L
.53906 .58256 L
.54371 .57306 L
.54381 .57284 L
.54851 .56313 L
.55318 .55342 L
.55342 .55291 L
.55779 .54371 L
.56239 .53399 L
.56313 .53241 L
.56693 .52428 L
.57146 .51457 L
.57284 .51157 L
.57593 .50486 L
.58039 .49514 L
.58256 .49039 L
.5848 .48543 L
.58919 .47572 L
.59227 .46888 L
.59354 .46601 L
.59787 .45629 L
.60198 .44704 L
.60218 .44658 L
.60644 .43687 L
.6107 .42716 L
.61169 .42487 L
.6149 .41744 L
.61911 .40773 L
.62141 .40239 L
.62327 .39802 L
.62741 .38831 L
Mistroke
.63112 .3796 L
.63154 .37859 L
.63562 .36888 L
.63971 .35917 L
.64083 .35649 L
.64374 .34946 L
.64779 .33974 L
.65054 .33308 L
.65179 .33003 L
.65577 .32032 L
.65975 .31061 L
.66026 .30937 L
.66368 .30089 L
.66762 .29118 L
.66997 .28536 L
.67151 .28147 L
.6754 .27176 L
.67929 .26204 L
.67968 .26105 L
.68312 .25233 L
.68697 .24262 L
.68939 .23646 L
.69077 .23291 L
.69457 .22319 L
.69837 .21348 L
.69911 .21157 L
.7021 .20377 L
.70587 .19406 L
.70882 .1864 L
.7096 .18434 L
.7133 .17463 L
.71702 .16492 L
.71853 .16095 L
.72068 .15521 L
.72437 .14549 L
.72804 .13578 L
.72824 .13523 L
.73165 .12607 L
.73529 .11636 L
.73796 .10922 L
.7389 .10664 L
.74249 .09693 L
.74609 .08722 L
.74767 .08295 L
.74964 .07751 L
.75321 .06779 L
.75677 .05808 L
.75738 .0564 L
.76027 .04837 L
.76381 .03866 L
Mistroke
.76709 .02959 L
.76732 .02894 L
.77079 .01923 L
Mfstroke
.7 g
.30383 .98077 m
.31061 .97407 L
.31355 .97106 L
.32032 .96428 L
.32326 .96134 L
.33003 .95457 L
.33323 .95163 L
.33974 .94486 L
.34206 .94192 L
.34915 .93221 L
.34946 .93177 L
.35628 .92249 L
.35917 .91854 L
.36335 .91278 L
.36888 .90511 L
.37034 .90307 L
.37721 .89336 L
.37859 .89138 L
.38394 .88364 L
.38831 .87728 L
.39057 .87393 L
.3971 .86422 L
.39802 .86283 L
.40347 .85451 L
.40773 .84798 L
.40976 .84479 L
.41596 .83508 L
.41744 .83274 L
.42202 .82537 L
.42716 .81711 L
.42803 .81566 L
.43392 .80594 L
.43687 .80107 L
.43972 .79623 L
.44548 .78652 L
.44658 .78465 L
.4511 .77681 L
.45629 .76784 L
.45671 .76709 L
.46219 .75738 L
.46601 .75064 L
.46763 .74767 L
.47301 .73796 L
.47572 .73306 L
.4783 .72824 L
.48358 .71853 L
.48543 .71511 L
.48873 .70882 L
.49391 .69911 L
.49514 .69679 L
.49895 .68939 L
.50403 .67968 L
.50486 .6781 L
.50896 .66997 L
.51396 .66026 L
.51457 .65906 L
.51878 .65054 L
.52369 .64083 L
.52428 .63965 L
.52843 .63112 L
.53325 .62141 L
.53399 .6199 L
.5379 .61169 L
.54265 .60198 L
.54371 .5998 L
.54723 .59227 L
.55189 .58256 L
.55342 .57937 L
.5564 .57284 L
.56099 .56313 L
.56313 .55859 L
.56545 .55342 L
.56995 .54371 L
.57284 .53749 L
.57437 .53399 L
.57879 .52428 L
.58256 .51607 L
.58319 .51457 L
.5875 .50486 L
.5919 .49514 L
.59227 .49432 L
.5961 .48543 L
.60044 .47572 L
.60198 .47225 L
.60461 .46601 L
.60887 .45629 L
.61169 .44987 L
.61303 .44658 L
.61719 .43687 L
.62141 .42719 L
.62142 .42716 L
.62543 .41744 L
.6296 .40773 L
.63112 .40419 L
.63359 .39802 L
.63769 .38831 L
.64083 .38089 L
.64172 .37859 L
.64569 .36888 L
.64976 .35917 L
.65054 .35729 L
.65362 .34946 L
.65763 .33974 L
.66026 .3334 L
.66152 .33003 L
.66542 .32032 L
.6694 .31061 L
.66997 .30922 L
.67315 .30089 L
.67708 .29118 L
.67968 .28474 L
.68088 .28147 L
.68468 .27176 L
.68857 .26204 L
.68939 .25998 L
.69223 .25233 L
.69607 .24262 L
.69911 .23494 L
.69982 .23291 L
.70349 .22319 L
.70731 .21348 L
.70882 .20962 L
.71091 .20377 L
.71464 .19406 L
.71841 .18434 L
.71853 .18403 L
.72192 .17463 L
.72565 .16492 L
.72824 .15815 L
.72924 .15521 L
.73282 .14549 L
.73653 .13578 L
.73796 .13201 L
.73999 .12607 L
.74361 .11636 L
.74728 .10664 L
.74767 .1056 L
.75067 .09693 L
.75428 .08722 L
.75738 .07892 L
.75783 .07751 L
.76124 .06779 L
.76484 .05808 L
.76709 .05198 L
.76826 .04837 L
.77171 .03866 L
.77529 .02894 L
.77681 .0248 L
.77861 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.30383 .98077 m
.31061 .97407 L
.31355 .97106 L
.32032 .96428 L
.32326 .96134 L
.33003 .95457 L
.33323 .95163 L
.33974 .94486 L
.34206 .94192 L
.34915 .93221 L
.34946 .93177 L
.35628 .92249 L
.35917 .91854 L
.36335 .91278 L
.36888 .90511 L
.37034 .90307 L
.37721 .89336 L
.37859 .89138 L
.38394 .88364 L
.38831 .87728 L
.39057 .87393 L
.3971 .86422 L
.39802 .86283 L
.40347 .85451 L
.40773 .84798 L
.40976 .84479 L
.41596 .83508 L
.41744 .83274 L
.42202 .82537 L
.42716 .81711 L
.42803 .81566 L
.43392 .80594 L
.43687 .80107 L
.43972 .79623 L
.44548 .78652 L
.44658 .78465 L
.4511 .77681 L
.45629 .76784 L
.45671 .76709 L
.46219 .75738 L
.46601 .75064 L
.46763 .74767 L
.47301 .73796 L
.47572 .73306 L
.4783 .72824 L
.48358 .71853 L
.48543 .71511 L
.48873 .70882 L
.49391 .69911 L
.49514 .69679 L
Mistroke
.49895 .68939 L
.50403 .67968 L
.50486 .6781 L
.50896 .66997 L
.51396 .66026 L
.51457 .65906 L
.51878 .65054 L
.52369 .64083 L
.52428 .63965 L
.52843 .63112 L
.53325 .62141 L
.53399 .6199 L
.5379 .61169 L
.54265 .60198 L
.54371 .5998 L
.54723 .59227 L
.55189 .58256 L
.55342 .57937 L
.5564 .57284 L
.56099 .56313 L
.56313 .55859 L
.56545 .55342 L
.56995 .54371 L
.57284 .53749 L
.57437 .53399 L
.57879 .52428 L
.58256 .51607 L
.58319 .51457 L
.5875 .50486 L
.5919 .49514 L
.59227 .49432 L
.5961 .48543 L
.60044 .47572 L
.60198 .47225 L
.60461 .46601 L
.60887 .45629 L
.61169 .44987 L
.61303 .44658 L
.61719 .43687 L
.62141 .42719 L
.62142 .42716 L
.62543 .41744 L
.6296 .40773 L
.63112 .40419 L
.63359 .39802 L
.63769 .38831 L
.64083 .38089 L
.64172 .37859 L
.64569 .36888 L
.64976 .35917 L
Mistroke
.65054 .35729 L
.65362 .34946 L
.65763 .33974 L
.66026 .3334 L
.66152 .33003 L
.66542 .32032 L
.6694 .31061 L
.66997 .30922 L
.67315 .30089 L
.67708 .29118 L
.67968 .28474 L
.68088 .28147 L
.68468 .27176 L
.68857 .26204 L
.68939 .25998 L
.69223 .25233 L
.69607 .24262 L
.69911 .23494 L
.69982 .23291 L
.70349 .22319 L
.70731 .21348 L
.70882 .20962 L
.71091 .20377 L
.71464 .19406 L
.71841 .18434 L
.71853 .18403 L
.72192 .17463 L
.72565 .16492 L
.72824 .15815 L
.72924 .15521 L
.73282 .14549 L
.73653 .13578 L
.73796 .13201 L
.73999 .12607 L
.74361 .11636 L
.74728 .10664 L
.74767 .1056 L
.75067 .09693 L
.75428 .08722 L
.75738 .07892 L
.75783 .07751 L
.76124 .06779 L
.76484 .05808 L
.76709 .05198 L
.76826 .04837 L
.77171 .03866 L
.77529 .02894 L
.77681 .0248 L
.77861 .01923 L
Mfstroke
.6 g
.38555 .98077 m
.38831 .97726 L
.39368 .97106 L
.39802 .96554 L
.40141 .96134 L
.40773 .95301 L
.40879 .95163 L
.41603 .94192 L
.41744 .93987 L
.42301 .93221 L
.42716 .92612 L
.42971 .92249 L
.43626 .91278 L
.43687 .91181 L
.44274 .90307 L
.44658 .89697 L
.44894 .89336 L
.45509 .88364 L
.45629 .88162 L
.46114 .87393 L
.46601 .86577 L
.46696 .86422 L
.47284 .85451 L
.47572 .84945 L
.4785 .84479 L
.48412 .83508 L
.48543 .83267 L
.48967 .82537 L
.49503 .81566 L
.49514 .81544 L
.50051 .80594 L
.50486 .7978 L
.50572 .79623 L
.51106 .78652 L
.51457 .77973 L
.51615 .77681 L
.52135 .76709 L
.52428 .76125 L
.52633 .75738 L
.5314 .74767 L
.53399 .74237 L
.53629 .73796 L
.54125 .72824 L
.54371 .72311 L
.54604 .71853 L
.55091 .70882 L
.55342 .70346 L
.5556 .69911 L
.56039 .68939 L
.56313 .68345 L
.56498 .67968 L
.5697 .66997 L
.57284 .66306 L
.5742 .66026 L
.57886 .65054 L
.58256 .64232 L
.58326 .64083 L
.58786 .63112 L
.5922 .62141 L
.59227 .62123 L
.59672 .61169 L
.60108 .60198 L
.60198 .5998 L
.60545 .59227 L
.60981 .58256 L
.61169 .57803 L
.61404 .57284 L
.6184 .56313 L
.62141 .55592 L
.62252 .55342 L
.62685 .54371 L
.63092 .53399 L
.63112 .53348 L
.63518 .52428 L
.63933 .51457 L
.64083 .51073 L
.64339 .50486 L
.64756 .49514 L
.65054 .48765 L
.6515 .48543 L
.65566 .47572 L
.65961 .46601 L
.66026 .46427 L
.66364 .45629 L
.66768 .44658 L
.66997 .44057 L
.67152 .43687 L
.67557 .42716 L
.67937 .41744 L
.67968 .41657 L
.68334 .40773 L
.68727 .39802 L
.68939 .39227 L
.69101 .38831 L
.69497 .37859 L
.69869 .36888 L
.69911 .36767 L
.70254 .35917 L
.7064 .34946 L
.70882 .34278 L
.71003 .33974 L
.71391 .33003 L
.7176 .32032 L
.71853 .3176 L
.7213 .31061 L
.72511 .30089 L
.72824 .29213 L
.72861 .29118 L
.73242 .28147 L
.73612 .27176 L
.73796 .26639 L
.73963 .26204 L
.74339 .25233 L
.74694 .24262 L
.74767 .24036 L
.75052 .23291 L
.75422 .22319 L
.75738 .21405 L
.7576 .21348 L
.76129 .20377 L
.7649 .19406 L
.76709 .18747 L
.76827 .18434 L
.77192 .17463 L
.77544 .16492 L
.77681 .16063 L
.77882 .15521 L
.78244 .14549 L
.78583 .13578 L
.78652 .13351 L
.78926 .12607 L
.79283 .11636 L
.79608 .10664 L
.79623 .10612 L
.7996 .09693 L
.80312 .08722 L
.80594 .07848 L
.80629 .07751 L
.80982 .06779 L
.81329 .05808 L
.81566 .05058 L
.81645 .04837 L
.81995 .03866 L
.82336 .02894 L
.82537 .02241 L
.8265 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.38555 .98077 m
.38831 .97726 L
.39368 .97106 L
.39802 .96554 L
.40141 .96134 L
.40773 .95301 L
.40879 .95163 L
.41603 .94192 L
.41744 .93987 L
.42301 .93221 L
.42716 .92612 L
.42971 .92249 L
.43626 .91278 L
.43687 .91181 L
.44274 .90307 L
.44658 .89697 L
.44894 .89336 L
.45509 .88364 L
.45629 .88162 L
.46114 .87393 L
.46601 .86577 L
.46696 .86422 L
.47284 .85451 L
.47572 .84945 L
.4785 .84479 L
.48412 .83508 L
.48543 .83267 L
.48967 .82537 L
.49503 .81566 L
.49514 .81544 L
.50051 .80594 L
.50486 .7978 L
.50572 .79623 L
.51106 .78652 L
.51457 .77973 L
.51615 .77681 L
.52135 .76709 L
.52428 .76125 L
.52633 .75738 L
.5314 .74767 L
.53399 .74237 L
.53629 .73796 L
.54125 .72824 L
.54371 .72311 L
.54604 .71853 L
.55091 .70882 L
.55342 .70346 L
.5556 .69911 L
.56039 .68939 L
.56313 .68345 L
Mistroke
.56498 .67968 L
.5697 .66997 L
.57284 .66306 L
.5742 .66026 L
.57886 .65054 L
.58256 .64232 L
.58326 .64083 L
.58786 .63112 L
.5922 .62141 L
.59227 .62123 L
.59672 .61169 L
.60108 .60198 L
.60198 .5998 L
.60545 .59227 L
.60981 .58256 L
.61169 .57803 L
.61404 .57284 L
.6184 .56313 L
.62141 .55592 L
.62252 .55342 L
.62685 .54371 L
.63092 .53399 L
.63112 .53348 L
.63518 .52428 L
.63933 .51457 L
.64083 .51073 L
.64339 .50486 L
.64756 .49514 L
.65054 .48765 L
.6515 .48543 L
.65566 .47572 L
.65961 .46601 L
.66026 .46427 L
.66364 .45629 L
.66768 .44658 L
.66997 .44057 L
.67152 .43687 L
.67557 .42716 L
.67937 .41744 L
.67968 .41657 L
.68334 .40773 L
.68727 .39802 L
.68939 .39227 L
.69101 .38831 L
.69497 .37859 L
.69869 .36888 L
.69911 .36767 L
.70254 .35917 L
.7064 .34946 L
.70882 .34278 L
Mistroke
.71003 .33974 L
.71391 .33003 L
.7176 .32032 L
.71853 .3176 L
.7213 .31061 L
.72511 .30089 L
.72824 .29213 L
.72861 .29118 L
.73242 .28147 L
.73612 .27176 L
.73796 .26639 L
.73963 .26204 L
.74339 .25233 L
.74694 .24262 L
.74767 .24036 L
.75052 .23291 L
.75422 .22319 L
.75738 .21405 L
.7576 .21348 L
.76129 .20377 L
.7649 .19406 L
.76709 .18747 L
.76827 .18434 L
.77192 .17463 L
.77544 .16492 L
.77681 .16063 L
.77882 .15521 L
.78244 .14549 L
.78583 .13578 L
.78652 .13351 L
.78926 .12607 L
.79283 .11636 L
.79608 .10664 L
.79623 .10612 L
.7996 .09693 L
.80312 .08722 L
.80594 .07848 L
.80629 .07751 L
.80982 .06779 L
.81329 .05808 L
.81566 .05058 L
.81645 .04837 L
.81995 .03866 L
.82336 .02894 L
.82537 .02241 L
.8265 .01923 L
Mfstroke
.5 g
.41177 .98077 m
.41744 .97254 L
.41846 .97106 L
.42501 .96134 L
.42716 .95809 L
.43141 .95163 L
.43687 .94314 L
.43765 .94192 L
.4438 .93221 L
.44658 .92772 L
.44982 .92249 L
.45572 .91278 L
.45629 .91183 L
.46155 .90307 L
.46601 .89548 L
.46726 .89336 L
.4729 .88364 L
.47572 .8787 L
.47845 .87393 L
.48392 .86422 L
.48543 .8615 L
.48932 .85451 L
.49465 .84479 L
.49514 .84387 L
.49992 .83508 L
.50486 .82584 L
.50511 .82537 L
.51027 .81566 L
.51457 .80742 L
.51534 .80594 L
.52039 .79623 L
.52428 .7886 L
.52535 .78652 L
.53029 .77681 L
.53399 .76941 L
.53516 .76709 L
.54001 .75738 L
.54371 .74985 L
.54478 .74767 L
.54954 .73796 L
.55342 .72992 L
.55423 .72824 L
.55891 .71853 L
.56313 .70963 L
.56352 .70882 L
.56812 .69911 L
.57266 .68939 L
.57284 .68899 L
.57719 .67968 L
.58166 .66997 L
.58256 .668 L
.58612 .66026 L
.59054 .65054 L
.59227 .64668 L
.59492 .64083 L
.59928 .63112 L
.60198 .62502 L
.60359 .62141 L
.60791 .61169 L
.61169 .60302 L
.61215 .60198 L
.61642 .59227 L
.62062 .58256 L
.62141 .58071 L
.62481 .57284 L
.62899 .56313 L
.63112 .55808 L
.63311 .55342 L
.63725 .54371 L
.64083 .53513 L
.64131 .53399 L
.6454 .52428 L
.64944 .51457 L
.65054 .51187 L
.65346 .50486 L
.65748 .49514 L
.66026 .4883 L
.66143 .48543 L
.66542 .47572 L
.66934 .46601 L
.66997 .46443 L
.67327 .45629 L
.67719 .44658 L
.67968 .44026 L
.68104 .43687 L
.68493 .42716 L
.68876 .41744 L
.68939 .4158 L
.69259 .40773 L
.69642 .39802 L
.69911 .39104 L
.70018 .38831 L
.70398 .37859 L
.70773 .36888 L
.70882 .366 L
.71146 .35917 L
.71521 .34946 L
.71853 .34067 L
.71889 .33974 L
.72261 .33003 L
.72629 .32032 L
.72824 .31506 L
.72993 .31061 L
.73361 .30089 L
.73722 .29118 L
.73796 .28917 L
.74084 .28147 L
.74447 .27176 L
.74767 .26301 L
.74803 .26204 L
.75163 .25233 L
.75521 .24262 L
.75738 .23657 L
.75873 .23291 L
.76229 .22319 L
.76582 .21348 L
.76709 .20987 L
.76931 .20377 L
.77284 .19406 L
.7763 .18434 L
.77681 .18289 L
.77978 .17463 L
.78327 .16492 L
.78652 .15565 L
.78668 .15521 L
.79014 .14549 L
.79359 .13578 L
.79623 .12816 L
.79697 .12607 L
.8004 .11636 L
.80381 .10664 L
.80594 .1004 L
.80715 .09693 L
.81056 .08722 L
.81393 .07751 L
.81566 .07238 L
.81725 .06779 L
.82062 .05808 L
.82395 .04837 L
.82537 .04411 L
.82724 .03866 L
.83059 .02894 L
.83388 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.41177 .98077 m
.41744 .97254 L
.41846 .97106 L
.42501 .96134 L
.42716 .95809 L
.43141 .95163 L
.43687 .94314 L
.43765 .94192 L
.4438 .93221 L
.44658 .92772 L
.44982 .92249 L
.45572 .91278 L
.45629 .91183 L
.46155 .90307 L
.46601 .89548 L
.46726 .89336 L
.4729 .88364 L
.47572 .8787 L
.47845 .87393 L
.48392 .86422 L
.48543 .8615 L
.48932 .85451 L
.49465 .84479 L
.49514 .84387 L
.49992 .83508 L
.50486 .82584 L
.50511 .82537 L
.51027 .81566 L
.51457 .80742 L
.51534 .80594 L
.52039 .79623 L
.52428 .7886 L
.52535 .78652 L
.53029 .77681 L
.53399 .76941 L
.53516 .76709 L
.54001 .75738 L
.54371 .74985 L
.54478 .74767 L
.54954 .73796 L
.55342 .72992 L
.55423 .72824 L
.55891 .71853 L
.56313 .70963 L
.56352 .70882 L
.56812 .69911 L
.57266 .68939 L
.57284 .68899 L
.57719 .67968 L
.58166 .66997 L
Mistroke
.58256 .668 L
.58612 .66026 L
.59054 .65054 L
.59227 .64668 L
.59492 .64083 L
.59928 .63112 L
.60198 .62502 L
.60359 .62141 L
.60791 .61169 L
.61169 .60302 L
.61215 .60198 L
.61642 .59227 L
.62062 .58256 L
.62141 .58071 L
.62481 .57284 L
.62899 .56313 L
.63112 .55808 L
.63311 .55342 L
.63725 .54371 L
.64083 .53513 L
.64131 .53399 L
.6454 .52428 L
.64944 .51457 L
.65054 .51187 L
.65346 .50486 L
.65748 .49514 L
.66026 .4883 L
.66143 .48543 L
.66542 .47572 L
.66934 .46601 L
.66997 .46443 L
.67327 .45629 L
.67719 .44658 L
.67968 .44026 L
.68104 .43687 L
.68493 .42716 L
.68876 .41744 L
.68939 .4158 L
.69259 .40773 L
.69642 .39802 L
.69911 .39104 L
.70018 .38831 L
.70398 .37859 L
.70773 .36888 L
.70882 .366 L
.71146 .35917 L
.71521 .34946 L
.71853 .34067 L
.71889 .33974 L
.72261 .33003 L
Mistroke
.72629 .32032 L
.72824 .31506 L
.72993 .31061 L
.73361 .30089 L
.73722 .29118 L
.73796 .28917 L
.74084 .28147 L
.74447 .27176 L
.74767 .26301 L
.74803 .26204 L
.75163 .25233 L
.75521 .24262 L
.75738 .23657 L
.75873 .23291 L
.76229 .22319 L
.76582 .21348 L
.76709 .20987 L
.76931 .20377 L
.77284 .19406 L
.7763 .18434 L
.77681 .18289 L
.77978 .17463 L
.78327 .16492 L
.78652 .15565 L
.78668 .15521 L
.79014 .14549 L
.79359 .13578 L
.79623 .12816 L
.79697 .12607 L
.8004 .11636 L
.80381 .10664 L
.80594 .1004 L
.80715 .09693 L
.81056 .08722 L
.81393 .07751 L
.81566 .07238 L
.81725 .06779 L
.82062 .05808 L
.82395 .04837 L
.82537 .04411 L
.82724 .03866 L
.83059 .02894 L
.83388 .01923 L
Mfstroke
.4 g
.43082 .98077 m
.43687 .97113 L
.43691 .97106 L
.4429 .96134 L
.44658 .95529 L
.44878 .95163 L
.45458 .94192 L
.45629 .93901 L
.46028 .93221 L
.4659 .92249 L
.46601 .92231 L
.47144 .91278 L
.47572 .90519 L
.47691 .90307 L
.4823 .89336 L
.48543 .88767 L
.48763 .88364 L
.4929 .87393 L
.49514 .86975 L
.49809 .86422 L
.50324 .85451 L
.50486 .85144 L
.50832 .84479 L
.51337 .83508 L
.51457 .83275 L
.51834 .82537 L
.52328 .81566 L
.52428 .81368 L
.52816 .80594 L
.53301 .79623 L
.53399 .79424 L
.5378 .78652 L
.54256 .77681 L
.54371 .77445 L
.54726 .76709 L
.55194 .75738 L
.55342 .7543 L
.55657 .74767 L
.56117 .73796 L
.56313 .7338 L
.56572 .72824 L
.57026 .71853 L
.57284 .71295 L
.57474 .70882 L
.57921 .69911 L
.58256 .69177 L
.58363 .68939 L
.58802 .67968 L
.59227 .67026 L
.5924 .66997 L
.59672 .66026 L
.60104 .65054 L
.60198 .64842 L
.60531 .64083 L
.60957 .63112 L
.61169 .62626 L
.61379 .62141 L
.61799 .61169 L
.62141 .60378 L
.62217 .60198 L
.62631 .59227 L
.63045 .58256 L
.63112 .58098 L
.63454 .57284 L
.63863 .56313 L
.64083 .55788 L
.64267 .55342 L
.64671 .54371 L
.65054 .53447 L
.65074 .53399 L
.65471 .52428 L
.6587 .51457 L
.66026 .51075 L
.66263 .50486 L
.66657 .49514 L
.66997 .48674 L
.67049 .48543 L
.67437 .47572 L
.67826 .46601 L
.67968 .46244 L
.6821 .45629 L
.68594 .44658 L
.68939 .43784 L
.68977 .43687 L
.69356 .42716 L
.69736 .41744 L
.69911 .41296 L
.70111 .40773 L
.70487 .39802 L
.70862 .38831 L
.70882 .38779 L
.71231 .37859 L
.71604 .36888 L
.71853 .36234 L
.71971 .35917 L
.72339 .34946 L
.72707 .33974 L
.72824 .33661 L
.73068 .33003 L
.73433 .32032 L
.73796 .31061 L
.73796 .31061 L
.74153 .30089 L
.74514 .29118 L
.74767 .28433 L
.7487 .28147 L
.75226 .27176 L
.75583 .26204 L
.75738 .25778 L
.75934 .25233 L
.76287 .24262 L
.7664 .23291 L
.76709 .23097 L
.76986 .22319 L
.77337 .21348 L
.77681 .2039 L
.77685 .20377 L
.78028 .19406 L
.78375 .18434 L
.78652 .17656 L
.78718 .17463 L
.79059 .16492 L
.79404 .15521 L
.79623 .14896 L
.79742 .14549 L
.80081 .13578 L
.80422 .12607 L
.80594 .1211 L
.80756 .11636 L
.81092 .10664 L
.8143 .09693 L
.81566 .09299 L
.8176 .08722 L
.82095 .07751 L
.82429 .06779 L
.82537 .06463 L
.82756 .05808 L
.83088 .04837 L
.83419 .03866 L
.83508 .03602 L
.83743 .02894 L
.84072 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.43082 .98077 m
.43687 .97113 L
.43691 .97106 L
.4429 .96134 L
.44658 .95529 L
.44878 .95163 L
.45458 .94192 L
.45629 .93901 L
.46028 .93221 L
.4659 .92249 L
.46601 .92231 L
.47144 .91278 L
.47572 .90519 L
.47691 .90307 L
.4823 .89336 L
.48543 .88767 L
.48763 .88364 L
.4929 .87393 L
.49514 .86975 L
.49809 .86422 L
.50324 .85451 L
.50486 .85144 L
.50832 .84479 L
.51337 .83508 L
.51457 .83275 L
.51834 .82537 L
.52328 .81566 L
.52428 .81368 L
.52816 .80594 L
.53301 .79623 L
.53399 .79424 L
.5378 .78652 L
.54256 .77681 L
.54371 .77445 L
.54726 .76709 L
.55194 .75738 L
.55342 .7543 L
.55657 .74767 L
.56117 .73796 L
.56313 .7338 L
.56572 .72824 L
.57026 .71853 L
.57284 .71295 L
.57474 .70882 L
.57921 .69911 L
.58256 .69177 L
.58363 .68939 L
.58802 .67968 L
.59227 .67026 L
.5924 .66997 L
Mistroke
.59672 .66026 L
.60104 .65054 L
.60198 .64842 L
.60531 .64083 L
.60957 .63112 L
.61169 .62626 L
.61379 .62141 L
.61799 .61169 L
.62141 .60378 L
.62217 .60198 L
.62631 .59227 L
.63045 .58256 L
.63112 .58098 L
.63454 .57284 L
.63863 .56313 L
.64083 .55788 L
.64267 .55342 L
.64671 .54371 L
.65054 .53447 L
.65074 .53399 L
.65471 .52428 L
.6587 .51457 L
.66026 .51075 L
.66263 .50486 L
.66657 .49514 L
.66997 .48674 L
.67049 .48543 L
.67437 .47572 L
.67826 .46601 L
.67968 .46244 L
.6821 .45629 L
.68594 .44658 L
.68939 .43784 L
.68977 .43687 L
.69356 .42716 L
.69736 .41744 L
.69911 .41296 L
.70111 .40773 L
.70487 .39802 L
.70862 .38831 L
.70882 .38779 L
.71231 .37859 L
.71604 .36888 L
.71853 .36234 L
.71971 .35917 L
.72339 .34946 L
.72707 .33974 L
.72824 .33661 L
.73068 .33003 L
.73433 .32032 L
Mistroke
.73796 .31061 L
.73796 .31061 L
.74153 .30089 L
.74514 .29118 L
.74767 .28433 L
.7487 .28147 L
.75226 .27176 L
.75583 .26204 L
.75738 .25778 L
.75934 .25233 L
.76287 .24262 L
.7664 .23291 L
.76709 .23097 L
.76986 .22319 L
.77337 .21348 L
.77681 .2039 L
.77685 .20377 L
.78028 .19406 L
.78375 .18434 L
.78652 .17656 L
.78718 .17463 L
.79059 .16492 L
.79404 .15521 L
.79623 .14896 L
.79742 .14549 L
.80081 .13578 L
.80422 .12607 L
.80594 .1211 L
.80756 .11636 L
.81092 .10664 L
.8143 .09693 L
.81566 .09299 L
.8176 .08722 L
.82095 .07751 L
.82429 .06779 L
.82537 .06463 L
.82756 .05808 L
.83088 .04837 L
.83419 .03866 L
.83508 .03602 L
.83743 .02894 L
.84072 .01923 L
Mfstroke
.3 g
.44961 .98077 m
.45524 .97106 L
.45629 .96923 L
.46073 .96134 L
.46601 .95203 L
.46622 .95163 L
.47158 .94192 L
.47572 .93445 L
.47691 .93221 L
.48217 .92249 L
.48543 .91649 L
.48737 .91278 L
.49254 .90307 L
.49514 .89817 L
.49761 .89336 L
.50269 .88364 L
.50486 .87948 L
.50764 .87393 L
.51263 .86422 L
.51457 .86043 L
.51749 .85451 L
.52239 .84479 L
.52428 .84103 L
.52716 .83508 L
.53197 .82537 L
.53399 .82128 L
.53666 .81566 L
.54139 .80594 L
.54371 .80118 L
.546 .79623 L
.55065 .78652 L
.55342 .78075 L
.55521 .77681 L
.55977 .76709 L
.56313 .75998 L
.56428 .75738 L
.56875 .74767 L
.57284 .73888 L
.57324 .73796 L
.5776 .72824 L
.58207 .71853 L
.58256 .71746 L
.58634 .70882 L
.59073 .69911 L
.59227 .6957 L
.59496 .68939 L
.59929 .67968 L
.60198 .67363 L
.6035 .66997 L
.60773 .66026 L
.61169 .65126 L
.61198 .65054 L
.61607 .64083 L
.6203 .63112 L
.62141 .62857 L
.62433 .62141 L
.62849 .61169 L
.63112 .60557 L
.63254 .60198 L
.63659 .59227 L
.64071 .58256 L
.64083 .58228 L
.64461 .57284 L
.64868 .56313 L
.65054 .55867 L
.65258 .55342 L
.65656 .54371 L
.66026 .53479 L
.66055 .53399 L
.66437 .52428 L
.66835 .51457 L
.66997 .5106 L
.67213 .50486 L
.67603 .49514 L
.67968 .48613 L
.67993 .48543 L
.68365 .47572 L
.68754 .46601 L
.68939 .46137 L
.69124 .45629 L
.69504 .44658 L
.69889 .43687 L
.69911 .43633 L
.70249 .42716 L
.7063 .41744 L
.70882 .411 L
.70996 .40773 L
.71363 .39802 L
.71741 .38831 L
.71853 .38541 L
.72095 .37859 L
.72465 .36888 L
.72824 .35954 L
.72837 .35917 L
.73184 .34946 L
.73554 .33974 L
.73796 .33339 L
.73908 .33003 L
.74264 .32032 L
.74631 .31061 L
.74767 .30698 L
.74973 .30089 L
.75332 .29118 L
.75695 .28147 L
.75738 .28031 L
.7603 .27176 L
.76388 .26204 L
.76709 .25337 L
.76742 .25233 L
.77077 .24262 L
.77434 .23291 L
.77681 .22616 L
.77774 .22319 L
.78114 .21348 L
.78468 .20377 L
.78652 .1987 L
.78799 .19406 L
.79141 .18434 L
.79493 .17463 L
.79623 .17099 L
.79816 .16492 L
.80158 .15521 L
.80507 .14549 L
.80594 .14302 L
.80824 .13578 L
.81166 .12607 L
.81511 .11636 L
.81566 .1148 L
.81824 .10664 L
.82164 .09693 L
.82506 .08722 L
.82537 .08632 L
.82815 .07751 L
.83152 .06779 L
.83492 .05808 L
.83508 .0576 L
.83797 .04837 L
.84133 .03866 L
.84469 .02894 L
.84479 .02864 L
.84771 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.44961 .98077 m
.45524 .97106 L
.45629 .96923 L
.46073 .96134 L
.46601 .95203 L
.46622 .95163 L
.47158 .94192 L
.47572 .93445 L
.47691 .93221 L
.48217 .92249 L
.48543 .91649 L
.48737 .91278 L
.49254 .90307 L
.49514 .89817 L
.49761 .89336 L
.50269 .88364 L
.50486 .87948 L
.50764 .87393 L
.51263 .86422 L
.51457 .86043 L
.51749 .85451 L
.52239 .84479 L
.52428 .84103 L
.52716 .83508 L
.53197 .82537 L
.53399 .82128 L
.53666 .81566 L
.54139 .80594 L
.54371 .80118 L
.546 .79623 L
.55065 .78652 L
.55342 .78075 L
.55521 .77681 L
.55977 .76709 L
.56313 .75998 L
.56428 .75738 L
.56875 .74767 L
.57284 .73888 L
.57324 .73796 L
.5776 .72824 L
.58207 .71853 L
.58256 .71746 L
.58634 .70882 L
.59073 .69911 L
.59227 .6957 L
.59496 .68939 L
.59929 .67968 L
.60198 .67363 L
.6035 .66997 L
.60773 .66026 L
Mistroke
.61169 .65126 L
.61198 .65054 L
.61607 .64083 L
.6203 .63112 L
.62141 .62857 L
.62433 .62141 L
.62849 .61169 L
.63112 .60557 L
.63254 .60198 L
.63659 .59227 L
.64071 .58256 L
.64083 .58228 L
.64461 .57284 L
.64868 .56313 L
.65054 .55867 L
.65258 .55342 L
.65656 .54371 L
.66026 .53479 L
.66055 .53399 L
.66437 .52428 L
.66835 .51457 L
.66997 .5106 L
.67213 .50486 L
.67603 .49514 L
.67968 .48613 L
.67993 .48543 L
.68365 .47572 L
.68754 .46601 L
.68939 .46137 L
.69124 .45629 L
.69504 .44658 L
.69889 .43687 L
.69911 .43633 L
.70249 .42716 L
.7063 .41744 L
.70882 .411 L
.70996 .40773 L
.71363 .39802 L
.71741 .38831 L
.71853 .38541 L
.72095 .37859 L
.72465 .36888 L
.72824 .35954 L
.72837 .35917 L
.73184 .34946 L
.73554 .33974 L
.73796 .33339 L
.73908 .33003 L
.74264 .32032 L
.74631 .31061 L
Mistroke
.74767 .30698 L
.74973 .30089 L
.75332 .29118 L
.75695 .28147 L
.75738 .28031 L
.7603 .27176 L
.76388 .26204 L
.76709 .25337 L
.76742 .25233 L
.77077 .24262 L
.77434 .23291 L
.77681 .22616 L
.77774 .22319 L
.78114 .21348 L
.78468 .20377 L
.78652 .1987 L
.78799 .19406 L
.79141 .18434 L
.79493 .17463 L
.79623 .17099 L
.79816 .16492 L
.80158 .15521 L
.80507 .14549 L
.80594 .14302 L
.80824 .13578 L
.81166 .12607 L
.81511 .11636 L
.81566 .1148 L
.81824 .10664 L
.82164 .09693 L
.82506 .08722 L
.82537 .08632 L
.82815 .07751 L
.83152 .06779 L
.83492 .05808 L
.83508 .0576 L
.83797 .04837 L
.84133 .03866 L
.84469 .02894 L
.84479 .02864 L
.84771 .01923 L
Mfstroke
.2 g
.50486 .52828 m
.51224 .53399 L
.50568 .54371 L
.50486 .54485 L
.49901 .54371 L
.50257 .53399 L
F
0 g
.50486 .52828 m
.51224 .53399 L
.50568 .54371 L
.50486 .54485 L
.49901 .54371 L
.50257 .53399 L
.50486 .52828 L
s
.8 g
.50486 .32689 m
.51391 .33003 L
.50748 .33974 L
.50486 .34347 L
.49989 .33974 L
.50359 .33003 L
F
0 g
.50486 .32689 m
.51391 .33003 L
.50748 .33974 L
.50486 .34347 L
.49989 .33974 L
.50359 .33003 L
.50486 .32689 L
s
.2 g
.8854 .01923 m
.88364 .02358 L
.88187 .02894 L
.88066 .03866 L
.87584 .04837 L
.87393 .05311 L
.87226 .05808 L
.87108 .06779 L
.86619 .07751 L
.86422 .08233 L
.86256 .08722 L
.86134 .09693 L
.85642 .10664 L
.85451 .11131 L
.85278 .11636 L
.85146 .12607 L
.84654 .13578 L
.84479 .14002 L
.8429 .14549 L
.84142 .15521 L
.83655 .16492 L
.83508 .16848 L
.83294 .17463 L
.83123 .18434 L
.82645 .19406 L
.82537 .19667 L
.82288 .20377 L
.82091 .21348 L
.81624 .22319 L
.81566 .2246 L
.81272 .23291 L
.81045 .24262 L
.80594 .25226 L
.80592 .25233 L
.80246 .26204 L
.79988 .27176 L
.79623 .27969 L
.79558 .28147 L
.79209 .29118 L
.7892 .30089 L
.78652 .30684 L
.78513 .31061 L
.78161 .32032 L
.77843 .33003 L
.77681 .33369 L
.77457 .33974 L
.77254 .34946 L
.76756 .35917 L
.76709 .36024 L
.76389 .36888 L
.76126 .37859 L
.75738 .38657 L
.75671 .38831 L
.75308 .39802 L
.74995 .40773 L
.74767 .41259 L
.74581 .41744 L
.74393 .42716 L
.7386 .43687 L
.73796 .43828 L
.73477 .44658 L
.73202 .45629 L
.72824 .46375 L
.72735 .46601 L
.72359 .47572 L
.72019 .48543 L
.71853 .48888 L
.71605 .49514 L
.71362 .50486 L
.70882 .51369 L
.70846 .51457 L
.7046 .52428 L
.70125 .53399 L
.69911 .53825 L
.69689 .54371 L
.69455 .55342 L
.68939 .56243 L
.68909 .56313 L
.68514 .57284 L
.68165 .58256 L
.67968 .58635 L
.67721 .59227 L
.67462 .60198 L
.66997 .60993 L
.6692 .61169 L
.66514 .62141 L
.66132 .63112 L
.66026 .63314 L
.65697 .64083 L
.65377 .65054 L
.65054 .6561 L
.64871 .66026 L
.64453 .66997 L
.64083 .67863 L
.64034 .67968 L
.63609 .68939 L
.63207 .69911 L
.63112 .70081 L
.62753 .70882 L
.62399 .71853 L
.62141 .72271 L
.61885 .72824 L
.61446 .73796 L
.61169 .74422 L
.61004 .74767 L
.60556 .75738 L
.60198 .7653 L
.60107 .76709 L
.59651 .77681 L
.59227 .78592 L
.59194 .78652 L
.58728 .79623 L
.58265 .80594 L
.58256 .8061 L
.57787 .81566 L
.57324 .82537 L
.57284 .82594 L
.56825 .83508 L
.56351 .84479 L
.56313 .8453 L
.55838 .85451 L
.55342 .86417 L
.55337 .86422 L
.54823 .87393 L
.54371 .88303 L
.54305 .88364 L
.53774 .89336 L
.53399 .90135 L
.53234 .90307 L
.52679 .91278 L
.52428 .9184 L
.52107 .92249 L
.51515 .93221 L
.51457 .93348 L
.50882 .94192 L
.50486 .94762 L
.50061 .94192 L
.50438 .93221 L
.50486 .93104 L
.50847 .92249 L
.51266 .91278 L
.51457 .9084 L
.51693 .90307 L
.52125 .89336 L
.52428 .88654 L
.52559 .88364 L
.52995 .87393 L
.53399 .86489 L
.5343 .86422 L
.53867 .85451 L
.54263 .84479 L
.54371 .84308 L
.54737 .83508 L
.55169 .82537 L
.55342 .82115 L
.55601 .81566 L
.56031 .80594 L
.56313 .79917 L
.5646 .79623 L
.56887 .78652 L
.57284 .77729 L
.57311 .77681 L
.57736 .76709 L
.58123 .75738 L
.58256 .75497 L
.58577 .74767 L
.58895 .73796 L
.59227 .7323 L
.59409 .72824 L
.59824 .71853 L
.60198 .70958 L
.60234 .70882 L
.60646 .69911 L
.6102 .68939 L
.61169 .68651 L
.6146 .67968 L
.6176 .66997 L
.62141 .66313 L
.62266 .66026 L
.62667 .65054 L
.63054 .64083 L
.63112 .63965 L
.63463 .63112 L
.63789 .62141 L
.64083 .61572 L
.64251 .61169 L
.64466 .60198 L
.65028 .59227 L
.65054 .5917 L
.65422 .58256 L
.65747 .57284 L
.66026 .56724 L
.66193 .56313 L
.66406 .55342 L
.6695 .54371 L
.66997 .54267 L
.67339 .53399 L
.67646 .52428 L
.67968 .51771 L
.68094 .51457 L
.68272 .50486 L
.68823 .49514 L
.68939 .49258 L
.69217 .48543 L
.69487 .47572 L
.69911 .46715 L
.69956 .46601 L
.70326 .45629 L
.70646 .44658 L
.70882 .44144 L
.71057 .43687 L
.71264 .42716 L
.7177 .41744 L
.71853 .41553 L
.72146 .40773 L
.72412 .39802 L
.72824 .38933 L
.72863 .38831 L
.73222 .37859 L
.73525 .36888 L
.73796 .36284 L
.73933 .35917 L
.74103 .34946 L
.74612 .33974 L
.74767 .33614 L
.74991 .33003 L
.75211 .32032 L
.75679 .31061 L
.75738 .30919 L
.76038 .30089 L
.76291 .29118 L
.76709 .28198 L
.76728 .28147 L
.77074 .27176 L
.77349 .26204 L
.77681 .25448 L
.77758 .25233 L
.78101 .24262 L
.7839 .23291 L
.78652 .22676 L
.78779 .22319 L
.78921 .21348 L
.79417 .20377 L
.79623 .19879 L
.7979 .19406 L
.79955 .18434 L
.8043 .17463 L
.80594 .17059 L
.80791 .16492 L
.80971 .15521 L
.81431 .14549 L
.81566 .14214 L
.81784 .13578 L
.81973 .12607 L
.82422 .11636 L
.82537 .11345 L
.82769 .10664 L
.8296 .09693 L
.83403 .08722 L
.83508 .08452 L
.83745 .07751 L
.83935 .06779 L
.84373 .05808 L
.84479 .05534 L
.84713 .04837 L
.84897 .03866 L
.85334 .02894 L
.85451 .02605 L
.85673 .01923 L
F
0 g
.8854 .01923 m
.88364 .02358 L
.88187 .02894 L
.88066 .03866 L
.87584 .04837 L
.87393 .05311 L
.87226 .05808 L
.87108 .06779 L
.86619 .07751 L
.86422 .08233 L
.86256 .08722 L
.86134 .09693 L
.85642 .10664 L
.85451 .11131 L
.85278 .11636 L
.85146 .12607 L
.84654 .13578 L
.84479 .14002 L
.8429 .14549 L
.84142 .15521 L
.83655 .16492 L
.83508 .16848 L
.83294 .17463 L
.83123 .18434 L
.82645 .19406 L
.82537 .19667 L
.82288 .20377 L
.82091 .21348 L
.81624 .22319 L
.81566 .2246 L
.81272 .23291 L
.81045 .24262 L
.80594 .25226 L
.80592 .25233 L
.80246 .26204 L
.79988 .27176 L
.79623 .27969 L
.79558 .28147 L
.79209 .29118 L
.7892 .30089 L
.78652 .30684 L
.78513 .31061 L
.78161 .32032 L
.77843 .33003 L
.77681 .33369 L
.77457 .33974 L
.77254 .34946 L
.76756 .35917 L
.76709 .36024 L
.76389 .36888 L
Mistroke
.76126 .37859 L
.75738 .38657 L
.75671 .38831 L
.75308 .39802 L
.74995 .40773 L
.74767 .41259 L
.74581 .41744 L
.74393 .42716 L
.7386 .43687 L
.73796 .43828 L
.73477 .44658 L
.73202 .45629 L
.72824 .46375 L
.72735 .46601 L
.72359 .47572 L
.72019 .48543 L
.71853 .48888 L
.71605 .49514 L
.71362 .50486 L
.70882 .51369 L
.70846 .51457 L
.7046 .52428 L
.70125 .53399 L
.69911 .53825 L
.69689 .54371 L
.69455 .55342 L
.68939 .56243 L
.68909 .56313 L
.68514 .57284 L
.68165 .58256 L
.67968 .58635 L
.67721 .59227 L
.67462 .60198 L
.66997 .60993 L
.6692 .61169 L
.66514 .62141 L
.66132 .63112 L
.66026 .63314 L
.65697 .64083 L
.65377 .65054 L
.65054 .6561 L
.64871 .66026 L
.64453 .66997 L
.64083 .67863 L
.64034 .67968 L
.63609 .68939 L
.63207 .69911 L
.63112 .70081 L
.62753 .70882 L
.62399 .71853 L
Mistroke
.62141 .72271 L
.61885 .72824 L
.61446 .73796 L
.61169 .74422 L
.61004 .74767 L
.60556 .75738 L
.60198 .7653 L
.60107 .76709 L
.59651 .77681 L
.59227 .78592 L
.59194 .78652 L
.58728 .79623 L
.58265 .80594 L
.58256 .8061 L
.57787 .81566 L
.57324 .82537 L
.57284 .82594 L
.56825 .83508 L
.56351 .84479 L
.56313 .8453 L
.55838 .85451 L
.55342 .86417 L
.55337 .86422 L
.54823 .87393 L
.54371 .88303 L
.54305 .88364 L
.53774 .89336 L
.53399 .90135 L
.53234 .90307 L
.52679 .91278 L
.52428 .9184 L
.52107 .92249 L
.51515 .93221 L
.51457 .93348 L
.50882 .94192 L
.50486 .94762 L
.50061 .94192 L
.50438 .93221 L
.50486 .93104 L
.50847 .92249 L
.51266 .91278 L
.51457 .9084 L
.51693 .90307 L
.52125 .89336 L
.52428 .88654 L
.52559 .88364 L
.52995 .87393 L
.53399 .86489 L
.5343 .86422 L
.53867 .85451 L
Mistroke
.54263 .84479 L
.54371 .84308 L
.54737 .83508 L
.55169 .82537 L
.55342 .82115 L
.55601 .81566 L
.56031 .80594 L
.56313 .79917 L
.5646 .79623 L
.56887 .78652 L
.57284 .77729 L
.57311 .77681 L
.57736 .76709 L
.58123 .75738 L
.58256 .75497 L
.58577 .74767 L
.58895 .73796 L
.59227 .7323 L
.59409 .72824 L
.59824 .71853 L
.60198 .70958 L
.60234 .70882 L
.60646 .69911 L
.6102 .68939 L
.61169 .68651 L
.6146 .67968 L
.6176 .66997 L
.62141 .66313 L
.62266 .66026 L
.62667 .65054 L
.63054 .64083 L
.63112 .63965 L
.63463 .63112 L
.63789 .62141 L
.64083 .61572 L
.64251 .61169 L
.64466 .60198 L
.65028 .59227 L
.65054 .5917 L
.65422 .58256 L
.65747 .57284 L
.66026 .56724 L
.66193 .56313 L
.66406 .55342 L
.6695 .54371 L
.66997 .54267 L
.67339 .53399 L
.67646 .52428 L
.67968 .51771 L
.68094 .51457 L
Mistroke
.68272 .50486 L
.68823 .49514 L
.68939 .49258 L
.69217 .48543 L
.69487 .47572 L
.69911 .46715 L
.69956 .46601 L
.70326 .45629 L
.70646 .44658 L
.70882 .44144 L
.71057 .43687 L
.71264 .42716 L
.7177 .41744 L
.71853 .41553 L
.72146 .40773 L
.72412 .39802 L
.72824 .38933 L
.72863 .38831 L
.73222 .37859 L
.73525 .36888 L
.73796 .36284 L
.73933 .35917 L
.74103 .34946 L
.74612 .33974 L
.74767 .33614 L
.74991 .33003 L
.75211 .32032 L
.75679 .31061 L
.75738 .30919 L
.76038 .30089 L
.76291 .29118 L
.76709 .28198 L
.76728 .28147 L
.77074 .27176 L
.77349 .26204 L
.77681 .25448 L
.77758 .25233 L
.78101 .24262 L
.7839 .23291 L
.78652 .22676 L
.78779 .22319 L
.78921 .21348 L
.79417 .20377 L
.79623 .19879 L
.7979 .19406 L
.79955 .18434 L
.8043 .17463 L
.80594 .17059 L
.80791 .16492 L
.80971 .15521 L
Mistroke
.81431 .14549 L
.81566 .14214 L
.81784 .13578 L
.81973 .12607 L
.82422 .11636 L
.82537 .11345 L
.82769 .10664 L
.8296 .09693 L
.83403 .08722 L
.83508 .08452 L
.83745 .07751 L
.83935 .06779 L
.84373 .05808 L
.84479 .05534 L
.84713 .04837 L
.84897 .03866 L
.85334 .02894 L
.85451 .02605 L
.85673 .01923 L
Mfstroke
.2 g
.5737 .01923 m
.57284 .02033 L
.56855 .02894 L
.56367 .03866 L
.56313 .0398 L
.55869 .04837 L
.55368 .05808 L
.55342 .05863 L
.54855 .06779 L
.54371 .07728 L
.54338 .07751 L
.53807 .08722 L
.53399 .09587 L
.53268 .09693 L
.52713 .10664 L
.52428 .11315 L
.52143 .11636 L
.51553 .12607 L
.51457 .12822 L
.50923 .13578 L
.50486 .14208 L
.50083 .13578 L
.50463 .12607 L
.50486 .12551 L
.50873 .11636 L
.51292 .10664 L
.51457 .10286 L
.5172 .09693 L
.52152 .08722 L
.52428 .08101 L
.52586 .07751 L
.53022 .06779 L
.53399 .05935 L
.53457 .05808 L
.53894 .04837 L
.54306 .03866 L
.54371 .03761 L
.54763 .02894 L
.55113 .01923 L
F
0 g
.5737 .01923 m
.57284 .02033 L
.56855 .02894 L
.56367 .03866 L
.56313 .0398 L
.55869 .04837 L
.55368 .05808 L
.55342 .05863 L
.54855 .06779 L
.54371 .07728 L
.54338 .07751 L
.53807 .08722 L
.53399 .09587 L
.53268 .09693 L
.52713 .10664 L
.52428 .11315 L
.52143 .11636 L
.51553 .12607 L
.51457 .12822 L
.50923 .13578 L
.50486 .14208 L
.50083 .13578 L
.50463 .12607 L
.50486 .12551 L
.50873 .11636 L
.51292 .10664 L
.51457 .10286 L
.5172 .09693 L
.52152 .08722 L
.52428 .08101 L
.52586 .07751 L
.53022 .06779 L
.53399 .05935 L
.53457 .05808 L
.53894 .04837 L
.54306 .03866 L
.54371 .03761 L
.54763 .02894 L
.55113 .01923 L
s
.8 g
.50486 .72966 m
.51055 .73796 L
.50486 .74624 L
.50157 .73796 L
F
0 g
.50486 .72966 m
.51055 .73796 L
.50486 .74624 L
.50157 .73796 L
.50486 .72966 L
s
.8 g
.81736 .01923 m
.81566 .02317 L
.81363 .02894 L
.81191 .03866 L
.80701 .04837 L
.80594 .0509 L
.80338 .05808 L
.80127 .06779 L
.79656 .07751 L
.79623 .07828 L
.79302 .08722 L
.79052 .09693 L
.78652 .10544 L
.78607 .10664 L
.78255 .11636 L
.77967 .12607 L
.77681 .13232 L
.77552 .13578 L
.77196 .14549 L
.76874 .15521 L
.76709 .15889 L
.76484 .16492 L
.76276 .17463 L
.75774 .18434 L
.75738 .18515 L
.75404 .19406 L
.75131 .20377 L
.74767 .21121 L
.74679 .21348 L
.74311 .22319 L
.73985 .23291 L
.73796 .23693 L
.73576 .24262 L
.73359 .25233 L
.72837 .26204 L
.72824 .26232 L
.72458 .27176 L
.72156 .28147 L
.71853 .28751 L
.71707 .29118 L
.71326 .30089 L
.70963 .31061 L
.70882 .3123 L
.70563 .32032 L
.70273 .33003 L
.69911 .33687 L
.69792 .33974 L
.69402 .34946 L
.69032 .35917 L
.68939 .36104 L
.68619 .36888 L
.68318 .37859 L
.67968 .38499 L
.67828 .38831 L
.67427 .39802 L
.67035 .40773 L
.66997 .40849 L
.66621 .41744 L
.66282 .42716 L
.66026 .4318 L
.65807 .43687 L
.65564 .44658 L
.65054 .4547 L
.64982 .45629 L
.64564 .46601 L
.64164 .47572 L
.64083 .47721 L
.63722 .48543 L
.63371 .49514 L
.63112 .49948 L
.62868 .50486 L
.62436 .51457 L
.62141 .52136 L
.62002 .52428 L
.61562 .53399 L
.61169 .54277 L
.61122 .54371 L
.60675 .55342 L
.60238 .56313 L
.60198 .56379 L
.59772 .57284 L
.59355 .58256 L
.59227 .58452 L
.58852 .59227 L
.58459 .60198 L
.58256 .60483 L
.57914 .61169 L
.57438 .62141 L
.57284 .62469 L
.56954 .63112 L
.56467 .64083 L
.56313 .64408 L
.55971 .65054 L
.55471 .66026 L
.55342 .66294 L
.5496 .66997 L
.54444 .67968 L
.54371 .68119 L
.53915 .68939 L
.53399 .69876 L
.5338 .69911 L
.52827 .70882 L
.52428 .71574 L
.52262 .71853 L
.51674 .72824 L
.51457 .73177 L
.50545 .72824 L
.50958 .71853 L
.51378 .70882 L
.51457 .70626 L
.51808 .69911 L
.5224 .68939 L
.52428 .68393 L
.52675 .67968 L
.53111 .66997 L
.53399 .66235 L
.53546 .66026 L
.53983 .65054 L
.54371 .64132 L
.54416 .64083 L
.54852 .63112 L
.55258 .62141 L
.55342 .61999 L
.55716 .61169 L
.56059 .60198 L
.56313 .59791 L
.56574 .59227 L
.57 .58256 L
.57284 .57573 L
.57424 .57284 L
.57848 .56313 L
.58256 .55364 L
.58267 .55342 L
.58688 .54371 L
.59064 .53399 L
.59227 .531 L
.5952 .52428 L
.59821 .51457 L
.60198 .50811 L
.60344 .50486 L
.60754 .49514 L
.61158 .48543 L
.61169 .48521 L
.61567 .47572 L
.61919 .46601 L
.62141 .46177 L
.62373 .45629 L
.62635 .44658 L
.63112 .43821 L
.63171 .43687 L
.63568 .42716 L
.63932 .41744 L
.64083 .41437 L
.64356 .40773 L
.6464 .39802 L
.65054 .39024 L
.65136 .38831 L
.65525 .37859 L
.65883 .36888 L
.66026 .36589 L
.66295 .35917 L
.66573 .34946 L
.66997 .34125 L
.67059 .33974 L
.6744 .33003 L
.67781 .32032 L
.67968 .31634 L
.68194 .31061 L
.68441 .30089 L
.68939 .29124 L
.68942 .29118 L
.69316 .28147 L
.69627 .27176 L
.69911 .26574 L
.70055 .26204 L
.70243 .25233 L
.7077 .24262 L
.70882 .24009 L
.71155 .23291 L
.71415 .22319 L
.71853 .21415 L
.71879 .21348 L
.72242 .20377 L
.72545 .19406 L
.72824 .18791 L
.72959 .18434 L
.73131 .17463 L
.73646 .16492 L
.73796 .16147 L
.74027 .15521 L
.74256 .14549 L
.74725 .13578 L
.74767 .13478 L
.75084 .12607 L
.75349 .11636 L
.75738 .1078 L
.75781 .10664 L
.7613 .09693 L
.76418 .08722 L
.76709 .08056 L
.7682 .07751 L
.76959 .06779 L
.77469 .05808 L
.77681 .05309 L
.7785 .04837 L
.78025 .03866 L
.78505 .02894 L
.78652 .02557 L
.78869 .01923 L
F
0 g
.81736 .01923 m
.81566 .02317 L
.81363 .02894 L
.81191 .03866 L
.80701 .04837 L
.80594 .0509 L
.80338 .05808 L
.80127 .06779 L
.79656 .07751 L
.79623 .07828 L
.79302 .08722 L
.79052 .09693 L
.78652 .10544 L
.78607 .10664 L
.78255 .11636 L
.77967 .12607 L
.77681 .13232 L
.77552 .13578 L
.77196 .14549 L
.76874 .15521 L
.76709 .15889 L
.76484 .16492 L
.76276 .17463 L
.75774 .18434 L
.75738 .18515 L
.75404 .19406 L
.75131 .20377 L
.74767 .21121 L
.74679 .21348 L
.74311 .22319 L
.73985 .23291 L
.73796 .23693 L
.73576 .24262 L
.73359 .25233 L
.72837 .26204 L
.72824 .26232 L
.72458 .27176 L
.72156 .28147 L
.71853 .28751 L
.71707 .29118 L
.71326 .30089 L
.70963 .31061 L
.70882 .3123 L
.70563 .32032 L
.70273 .33003 L
.69911 .33687 L
.69792 .33974 L
.69402 .34946 L
.69032 .35917 L
.68939 .36104 L
Mistroke
.68619 .36888 L
.68318 .37859 L
.67968 .38499 L
.67828 .38831 L
.67427 .39802 L
.67035 .40773 L
.66997 .40849 L
.66621 .41744 L
.66282 .42716 L
.66026 .4318 L
.65807 .43687 L
.65564 .44658 L
.65054 .4547 L
.64982 .45629 L
.64564 .46601 L
.64164 .47572 L
.64083 .47721 L
.63722 .48543 L
.63371 .49514 L
.63112 .49948 L
.62868 .50486 L
.62436 .51457 L
.62141 .52136 L
.62002 .52428 L
.61562 .53399 L
.61169 .54277 L
.61122 .54371 L
.60675 .55342 L
.60238 .56313 L
.60198 .56379 L
.59772 .57284 L
.59355 .58256 L
.59227 .58452 L
.58852 .59227 L
.58459 .60198 L
.58256 .60483 L
.57914 .61169 L
.57438 .62141 L
.57284 .62469 L
.56954 .63112 L
.56467 .64083 L
.56313 .64408 L
.55971 .65054 L
.55471 .66026 L
.55342 .66294 L
.5496 .66997 L
.54444 .67968 L
.54371 .68119 L
.53915 .68939 L
.53399 .69876 L
Mistroke
.5338 .69911 L
.52827 .70882 L
.52428 .71574 L
.52262 .71853 L
.51674 .72824 L
.51457 .73177 L
.50545 .72824 L
.50958 .71853 L
.51378 .70882 L
.51457 .70626 L
.51808 .69911 L
.5224 .68939 L
.52428 .68393 L
.52675 .67968 L
.53111 .66997 L
.53399 .66235 L
.53546 .66026 L
.53983 .65054 L
.54371 .64132 L
.54416 .64083 L
.54852 .63112 L
.55258 .62141 L
.55342 .61999 L
.55716 .61169 L
.56059 .60198 L
.56313 .59791 L
.56574 .59227 L
.57 .58256 L
.57284 .57573 L
.57424 .57284 L
.57848 .56313 L
.58256 .55364 L
.58267 .55342 L
.58688 .54371 L
.59064 .53399 L
.59227 .531 L
.5952 .52428 L
.59821 .51457 L
.60198 .50811 L
.60344 .50486 L
.60754 .49514 L
.61158 .48543 L
.61169 .48521 L
.61567 .47572 L
.61919 .46601 L
.62141 .46177 L
.62373 .45629 L
.62635 .44658 L
.63112 .43821 L
.63171 .43687 L
Mistroke
.63568 .42716 L
.63932 .41744 L
.64083 .41437 L
.64356 .40773 L
.6464 .39802 L
.65054 .39024 L
.65136 .38831 L
.65525 .37859 L
.65883 .36888 L
.66026 .36589 L
.66295 .35917 L
.66573 .34946 L
.66997 .34125 L
.67059 .33974 L
.6744 .33003 L
.67781 .32032 L
.67968 .31634 L
.68194 .31061 L
.68441 .30089 L
.68939 .29124 L
.68942 .29118 L
.69316 .28147 L
.69627 .27176 L
.69911 .26574 L
.70055 .26204 L
.70243 .25233 L
.7077 .24262 L
.70882 .24009 L
.71155 .23291 L
.71415 .22319 L
.71853 .21415 L
.71879 .21348 L
.72242 .20377 L
.72545 .19406 L
.72824 .18791 L
.72959 .18434 L
.73131 .17463 L
.73646 .16492 L
.73796 .16147 L
.74027 .15521 L
.74256 .14549 L
.74725 .13578 L
.74767 .13478 L
.75084 .12607 L
.75349 .11636 L
.75738 .1078 L
.75781 .10664 L
.7613 .09693 L
.76418 .08722 L
.76709 .08056 L
Mistroke
.7682 .07751 L
.76959 .06779 L
.77469 .05808 L
.77681 .05309 L
.7785 .04837 L
.78025 .03866 L
.78505 .02894 L
.78652 .02557 L
.78869 .01923 L
Mfstroke
.2 g
.51457 .50563 m
.52416 .51457 L
.51832 .52428 L
.51457 .53038 L
.50653 .52428 L
.51069 .51457 L
F
0 g
.51457 .50563 m
.52416 .51457 L
.51832 .52428 L
.51457 .53038 L
.50653 .52428 L
.51069 .51457 L
.51457 .50563 L
s
.8 g
.66431 .01923 m
.66026 .02894 L
.66026 .02895 L
.65613 .03866 L
.65251 .04837 L
.65054 .05192 L
.64786 .05808 L
.645 .06779 L
.64083 .07452 L
.63947 .07751 L
.63522 .08722 L
.63112 .09664 L
.63098 .09693 L
.62665 .10664 L
.62267 .11636 L
.62141 .11851 L
.61796 .12607 L
.61443 .13578 L
.61169 .14004 L
.60912 .14549 L
.60465 .15521 L
.60198 .16117 L
.60014 .16492 L
.59558 .17463 L
.59227 .18188 L
.59099 .18434 L
.58634 .19406 L
.58256 .20215 L
.58166 .20377 L
.5769 .21348 L
.57284 .22199 L
.57213 .22319 L
.56726 .23291 L
.56313 .24142 L
.56236 .24262 L
.55737 .25233 L
.55342 .26046 L
.55233 .26204 L
.54718 .27176 L
.54371 .27901 L
.54198 .28147 L
.53665 .29118 L
.53399 .29682 L
.53122 .30089 L
.52565 .31061 L
.52428 .3135 L
.51988 .32032 L
.51457 .329 L
.50763 .32032 L
.5118 .31061 L
.51457 .30425 L
.51606 .30089 L
.52037 .29118 L
.52428 .28239 L
.5247 .28147 L
.52907 .27176 L
.53341 .26204 L
.53399 .26057 L
.53778 .25233 L
.54213 .24262 L
.54371 .2387 L
.54648 .23291 L
.55081 .22319 L
.55342 .21684 L
.55513 .21348 L
.55944 .20377 L
.56313 .1951 L
.56372 .19406 L
.56801 .18434 L
.57205 .17463 L
.57284 .17319 L
.5765 .16492 L
.57994 .15521 L
.58256 .15073 L
.58491 .14549 L
.58742 .13578 L
.59227 .12815 L
.59325 .12607 L
.5974 .11636 L
.60138 .10664 L
.60198 .10548 L
.60562 .09693 L
.60903 .08722 L
.61169 .08231 L
.61377 .07751 L
.61619 .06779 L
.62141 .05904 L
.62184 .05808 L
.62586 .04837 L
.62951 .03866 L
.63112 .03545 L
.63382 .02894 L
.63668 .01923 L
F
0 g
.66431 .01923 m
.66026 .02894 L
.66026 .02895 L
.65613 .03866 L
.65251 .04837 L
.65054 .05192 L
.64786 .05808 L
.645 .06779 L
.64083 .07452 L
.63947 .07751 L
.63522 .08722 L
.63112 .09664 L
.63098 .09693 L
.62665 .10664 L
.62267 .11636 L
.62141 .11851 L
.61796 .12607 L
.61443 .13578 L
.61169 .14004 L
.60912 .14549 L
.60465 .15521 L
.60198 .16117 L
.60014 .16492 L
.59558 .17463 L
.59227 .18188 L
.59099 .18434 L
.58634 .19406 L
.58256 .20215 L
.58166 .20377 L
.5769 .21348 L
.57284 .22199 L
.57213 .22319 L
.56726 .23291 L
.56313 .24142 L
.56236 .24262 L
.55737 .25233 L
.55342 .26046 L
.55233 .26204 L
.54718 .27176 L
.54371 .27901 L
.54198 .28147 L
.53665 .29118 L
.53399 .29682 L
.53122 .30089 L
.52565 .31061 L
.52428 .3135 L
.51988 .32032 L
.51457 .329 L
.50763 .32032 L
.5118 .31061 L
Mistroke
.51457 .30425 L
.51606 .30089 L
.52037 .29118 L
.52428 .28239 L
.5247 .28147 L
.52907 .27176 L
.53341 .26204 L
.53399 .26057 L
.53778 .25233 L
.54213 .24262 L
.54371 .2387 L
.54648 .23291 L
.55081 .22319 L
.55342 .21684 L
.55513 .21348 L
.55944 .20377 L
.56313 .1951 L
.56372 .19406 L
.56801 .18434 L
.57205 .17463 L
.57284 .17319 L
.5765 .16492 L
.57994 .15521 L
.58256 .15073 L
.58491 .14549 L
.58742 .13578 L
.59227 .12815 L
.59325 .12607 L
.5974 .11636 L
.60138 .10664 L
.60198 .10548 L
.60562 .09693 L
.60903 .08722 L
.61169 .08231 L
.61377 .07751 L
.61619 .06779 L
.62141 .05904 L
.62184 .05808 L
.62586 .04837 L
.62951 .03866 L
.63112 .03545 L
.63382 .02894 L
.63668 .01923 L
Mfstroke
.4 g
.51475 .98077 m
.51999 .97106 L
.52428 .96263 L
.52496 .96134 L
.53008 .95163 L
.53399 .94375 L
.53495 .94192 L
.53996 .93221 L
.54371 .92449 L
.54472 .92249 L
.54964 .91278 L
.55342 .90484 L
.55431 .90307 L
.55914 .89336 L
.56313 .88483 L
.56371 .88364 L
.56847 .87393 L
.57284 .86444 L
.57295 .86422 L
.57763 .85451 L
.58209 .84479 L
.58256 .84371 L
.58665 .83508 L
.5911 .82537 L
.59227 .82262 L
.59552 .81566 L
.59996 .80594 L
.60198 .80119 L
.60426 .79623 L
.60868 .78652 L
.61169 .77941 L
.61287 .77681 L
.61726 .76709 L
.62137 .75738 L
.62141 .7573 L
.62571 .74767 L
.6299 .73796 L
.63112 .73487 L
.63404 .72824 L
.63826 .71853 L
.64083 .71211 L
.64226 .70882 L
.64647 .69911 L
.65041 .68939 L
.65054 .68904 L
.65456 .67968 L
.65861 .66997 L
.66026 .66565 L
.66254 .66026 L
.66663 .65054 L
.66997 .64195 L
.67044 .64083 L
.6745 .63112 L
.67842 .62141 L
.67968 .61796 L
.68227 .61169 L
.68625 .60198 L
.68939 .59365 L
.68996 .59227 L
.69393 .58256 L
.69776 .57284 L
.69911 .56906 L
.7015 .56313 L
.7054 .55342 L
.70882 .54416 L
.709 .54371 L
.71288 .53399 L
.71667 .52428 L
.71853 .51899 L
.72027 .51457 L
.72411 .50486 L
.72771 .49514 L
.72824 .49352 L
.73141 .48543 L
.73516 .47572 L
.73796 .46777 L
.73864 .46601 L
.7424 .45629 L
.74605 .44658 L
.74767 .44174 L
.74953 .43687 L
.75325 .42716 L
.75674 .41744 L
.75738 .41543 L
.76031 .40773 L
.76397 .39802 L
.76709 .38885 L
.7673 .38831 L
.77095 .37859 L
.77454 .36888 L
.77681 .36201 L
.77786 .35917 L
.78148 .34946 L
.78498 .33974 L
.78652 .33489 L
.78831 .33003 L
.7919 .32032 L
.79529 .31061 L
.79623 .30751 L
.79865 .30089 L
.8022 .29118 L
.80548 .28147 L
.80594 .27987 L
.80888 .27176 L
.81239 .26204 L
.81555 .25233 L
.81566 .25196 L
.81902 .24262 L
.82248 .23291 L
.82537 .2238 L
.82558 .22319 L
.82905 .21348 L
.83247 .20377 L
.83508 .19539 L
.83555 .19406 L
.83899 .18434 L
.84237 .17463 L
.84479 .16672 L
.84542 .16492 L
.84884 .15521 L
.85219 .14549 L
.85451 .1378 L
.8552 .13578 L
.85859 .12607 L
.86192 .11636 L
.86422 .10863 L
.8649 .10664 L
.86826 .09693 L
.87157 .08722 L
.87393 .07922 L
.87451 .07751 L
.87785 .06779 L
.88114 .05808 L
.88364 .04956 L
.88405 .04837 L
.88736 .03866 L
.89063 .02894 L
.89336 .01966 L
.8935 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.51475 .98077 m
.51999 .97106 L
.52428 .96263 L
.52496 .96134 L
.53008 .95163 L
.53399 .94375 L
.53495 .94192 L
.53996 .93221 L
.54371 .92449 L
.54472 .92249 L
.54964 .91278 L
.55342 .90484 L
.55431 .90307 L
.55914 .89336 L
.56313 .88483 L
.56371 .88364 L
.56847 .87393 L
.57284 .86444 L
.57295 .86422 L
.57763 .85451 L
.58209 .84479 L
.58256 .84371 L
.58665 .83508 L
.5911 .82537 L
.59227 .82262 L
.59552 .81566 L
.59996 .80594 L
.60198 .80119 L
.60426 .79623 L
.60868 .78652 L
.61169 .77941 L
.61287 .77681 L
.61726 .76709 L
.62137 .75738 L
.62141 .7573 L
.62571 .74767 L
.6299 .73796 L
.63112 .73487 L
.63404 .72824 L
.63826 .71853 L
.64083 .71211 L
.64226 .70882 L
.64647 .69911 L
.65041 .68939 L
.65054 .68904 L
.65456 .67968 L
.65861 .66997 L
.66026 .66565 L
.66254 .66026 L
.66663 .65054 L
Mistroke
.66997 .64195 L
.67044 .64083 L
.6745 .63112 L
.67842 .62141 L
.67968 .61796 L
.68227 .61169 L
.68625 .60198 L
.68939 .59365 L
.68996 .59227 L
.69393 .58256 L
.69776 .57284 L
.69911 .56906 L
.7015 .56313 L
.7054 .55342 L
.70882 .54416 L
.709 .54371 L
.71288 .53399 L
.71667 .52428 L
.71853 .51899 L
.72027 .51457 L
.72411 .50486 L
.72771 .49514 L
.72824 .49352 L
.73141 .48543 L
.73516 .47572 L
.73796 .46777 L
.73864 .46601 L
.7424 .45629 L
.74605 .44658 L
.74767 .44174 L
.74953 .43687 L
.75325 .42716 L
.75674 .41744 L
.75738 .41543 L
.76031 .40773 L
.76397 .39802 L
.76709 .38885 L
.7673 .38831 L
.77095 .37859 L
.77454 .36888 L
.77681 .36201 L
.77786 .35917 L
.78148 .34946 L
.78498 .33974 L
.78652 .33489 L
.78831 .33003 L
.7919 .32032 L
.79529 .31061 L
.79623 .30751 L
.79865 .30089 L
Mistroke
.8022 .29118 L
.80548 .28147 L
.80594 .27987 L
.80888 .27176 L
.81239 .26204 L
.81555 .25233 L
.81566 .25196 L
.81902 .24262 L
.82248 .23291 L
.82537 .2238 L
.82558 .22319 L
.82905 .21348 L
.83247 .20377 L
.83508 .19539 L
.83555 .19406 L
.83899 .18434 L
.84237 .17463 L
.84479 .16672 L
.84542 .16492 L
.84884 .15521 L
.85219 .14549 L
.85451 .1378 L
.8552 .13578 L
.85859 .12607 L
.86192 .11636 L
.86422 .10863 L
.8649 .10664 L
.86826 .09693 L
.87157 .08722 L
.87393 .07922 L
.87451 .07751 L
.87785 .06779 L
.88114 .05808 L
.88364 .04956 L
.88405 .04837 L
.88736 .03866 L
.89063 .02894 L
.89336 .01966 L
.8935 .01923 L
Mfstroke
.2 g
.74409 .01923 m
.74119 .02894 L
.73796 .03556 L
.73675 .03866 L
.73303 .04837 L
.7296 .05808 L
.72824 .06097 L
.72558 .06779 L
.72307 .07751 L
.71853 .0861 L
.71808 .08722 L
.71427 .09693 L
.71095 .10664 L
.70882 .11095 L
.70665 .11636 L
.70439 .12607 L
.69911 .13543 L
.69896 .13578 L
.69506 .14549 L
.69171 .15521 L
.68939 .1597 L
.68724 .16492 L
.68492 .17463 L
.67968 .18356 L
.67934 .18434 L
.67533 .19406 L
.67175 .20377 L
.66997 .20715 L
.66729 .21348 L
.66452 .22319 L
.66026 .23042 L
.65916 .23291 L
.65504 .24262 L
.65103 .25233 L
.65054 .25325 L
.64675 .26204 L
.64321 .27176 L
.64083 .27588 L
.63835 .28147 L
.63563 .29118 L
.63112 .29812 L
.62983 .30089 L
.62551 .31061 L
.62141 .31988 L
.62119 .32032 L
.61679 .33003 L
.61265 .33974 L
.61169 .34135 L
.60794 .34946 L
.60415 .35917 L
.60198 .36249 L
.59893 .36888 L
.59437 .37859 L
.59227 .38323 L
.58976 .38831 L
.5851 .39802 L
.58256 .40355 L
.5804 .40773 L
.57564 .41744 L
.57284 .42343 L
.57084 .42716 L
.56596 .43687 L
.56313 .44285 L
.56104 .44658 L
.55604 .45629 L
.55342 .46178 L
.55097 .46601 L
.54581 .47572 L
.54371 .48011 L
.54057 .48543 L
.53523 .49514 L
.53399 .49769 L
.52974 .50486 L
.52428 .51436 L
.51491 .50486 L
.51923 .49514 L
.52354 .48543 L
.52428 .48344 L
.52791 .47572 L
.53226 .46601 L
.53399 .4615 L
.53662 .45629 L
.54098 .44658 L
.54371 .43978 L
.54532 .43687 L
.54967 .42716 L
.55342 .41831 L
.55398 .41744 L
.5583 .40773 L
.56238 .39802 L
.56313 .3967 L
.56687 .38831 L
.57036 .37859 L
.57284 .37444 L
.57537 .36888 L
.57959 .35917 L
.58256 .35206 L
.58379 .34946 L
.58799 .33974 L
.5921 .33003 L
.59227 .32971 L
.5963 .32032 L
.59991 .31061 L
.60198 .30678 L
.60453 .30089 L
.6073 .29118 L
.61169 .28368 L
.61269 .28147 L
.61675 .27176 L
.62062 .26204 L
.62141 .26046 L
.6248 .25233 L
.62803 .24262 L
.63112 .23679 L
.63277 .23291 L
.63488 .22319 L
.64063 .21348 L
.64083 .21305 L
.6446 .20377 L
.64792 .19406 L
.65054 .18885 L
.6524 .18434 L
.65467 .17463 L
.66009 .16492 L
.66026 .16456 L
.66397 .15521 L
.6672 .14549 L
.66997 .13984 L
.6716 .13578 L
.67369 .12607 L
.67906 .11636 L
.67968 .115 L
.68294 .10664 L
.6859 .09693 L
.68939 .08978 L
.69041 .08722 L
.69414 .07751 L
.69755 .06779 L
.69911 .06438 L
.70153 .05808 L
.70402 .04837 L
.70882 .03874 L
.70885 .03866 L
.71252 .02894 L
.71552 .01923 L
F
0 g
.74409 .01923 m
.74119 .02894 L
.73796 .03556 L
.73675 .03866 L
.73303 .04837 L
.7296 .05808 L
.72824 .06097 L
.72558 .06779 L
.72307 .07751 L
.71853 .0861 L
.71808 .08722 L
.71427 .09693 L
.71095 .10664 L
.70882 .11095 L
.70665 .11636 L
.70439 .12607 L
.69911 .13543 L
.69896 .13578 L
.69506 .14549 L
.69171 .15521 L
.68939 .1597 L
.68724 .16492 L
.68492 .17463 L
.67968 .18356 L
.67934 .18434 L
.67533 .19406 L
.67175 .20377 L
.66997 .20715 L
.66729 .21348 L
.66452 .22319 L
.66026 .23042 L
.65916 .23291 L
.65504 .24262 L
.65103 .25233 L
.65054 .25325 L
.64675 .26204 L
.64321 .27176 L
.64083 .27588 L
.63835 .28147 L
.63563 .29118 L
.63112 .29812 L
.62983 .30089 L
.62551 .31061 L
.62141 .31988 L
.62119 .32032 L
.61679 .33003 L
.61265 .33974 L
.61169 .34135 L
.60794 .34946 L
.60415 .35917 L
Mistroke
.60198 .36249 L
.59893 .36888 L
.59437 .37859 L
.59227 .38323 L
.58976 .38831 L
.5851 .39802 L
.58256 .40355 L
.5804 .40773 L
.57564 .41744 L
.57284 .42343 L
.57084 .42716 L
.56596 .43687 L
.56313 .44285 L
.56104 .44658 L
.55604 .45629 L
.55342 .46178 L
.55097 .46601 L
.54581 .47572 L
.54371 .48011 L
.54057 .48543 L
.53523 .49514 L
.53399 .49769 L
.52974 .50486 L
.52428 .51436 L
.51491 .50486 L
.51923 .49514 L
.52354 .48543 L
.52428 .48344 L
.52791 .47572 L
.53226 .46601 L
.53399 .4615 L
.53662 .45629 L
.54098 .44658 L
.54371 .43978 L
.54532 .43687 L
.54967 .42716 L
.55342 .41831 L
.55398 .41744 L
.5583 .40773 L
.56238 .39802 L
.56313 .3967 L
.56687 .38831 L
.57036 .37859 L
.57284 .37444 L
.57537 .36888 L
.57959 .35917 L
.58256 .35206 L
.58379 .34946 L
.58799 .33974 L
.5921 .33003 L
Mistroke
.59227 .32971 L
.5963 .32032 L
.59991 .31061 L
.60198 .30678 L
.60453 .30089 L
.6073 .29118 L
.61169 .28368 L
.61269 .28147 L
.61675 .27176 L
.62062 .26204 L
.62141 .26046 L
.6248 .25233 L
.62803 .24262 L
.63112 .23679 L
.63277 .23291 L
.63488 .22319 L
.64063 .21348 L
.64083 .21305 L
.6446 .20377 L
.64792 .19406 L
.65054 .18885 L
.6524 .18434 L
.65467 .17463 L
.66009 .16492 L
.66026 .16456 L
.66397 .15521 L
.6672 .14549 L
.66997 .13984 L
.6716 .13578 L
.67369 .12607 L
.67906 .11636 L
.67968 .115 L
.68294 .10664 L
.6859 .09693 L
.68939 .08978 L
.69041 .08722 L
.69414 .07751 L
.69755 .06779 L
.69911 .06438 L
.70153 .05808 L
.70402 .04837 L
.70882 .03874 L
.70885 .03866 L
.71252 .02894 L
.71552 .01923 L
Mfstroke
.5 g
.52899 .98077 m
.53386 .97106 L
.53399 .9708 L
.53873 .96134 L
.54351 .95163 L
.54371 .95123 L
.54829 .94192 L
.55299 .93221 L
.55342 .9313 L
.55767 .92249 L
.5623 .91278 L
.56313 .91101 L
.56691 .90307 L
.57147 .89336 L
.57284 .89037 L
.57599 .88364 L
.58049 .87393 L
.58256 .86939 L
.58493 .86422 L
.58937 .85451 L
.59227 .84806 L
.59375 .84479 L
.59813 .83508 L
.60198 .8264 L
.60244 .82537 L
.60677 .81566 L
.61103 .80594 L
.61169 .80441 L
.61529 .79623 L
.61951 .78652 L
.62141 .7821 L
.6237 .77681 L
.62789 .76709 L
.63112 .75946 L
.63201 .75738 L
.63615 .74767 L
.64023 .73796 L
.64083 .73651 L
.64432 .72824 L
.64838 .71853 L
.65054 .71325 L
.65239 .70882 L
.65642 .69911 L
.66026 .68968 L
.66037 .68939 L
.66436 .67968 L
.66831 .66997 L
.66997 .66581 L
.67222 .66026 L
.67615 .65054 L
.67968 .64164 L
.68001 .64083 L
.6839 .63112 L
.68775 .62141 L
.68939 .61718 L
.69157 .61169 L
.69541 .60198 L
.69911 .59242 L
.69917 .59227 L
.70297 .58256 L
.70674 .57284 L
.70882 .56738 L
.71046 .56313 L
.71422 .55342 L
.71792 .54371 L
.71853 .54205 L
.72162 .53399 L
.72532 .52428 L
.72824 .51644 L
.72895 .51457 L
.73263 .50486 L
.73628 .49514 L
.73796 .49056 L
.73988 .48543 L
.74351 .47572 L
.74709 .46601 L
.74767 .46439 L
.75067 .45629 L
.75427 .44658 L
.75738 .43796 L
.75778 .43687 L
.76135 .42716 L
.76489 .41744 L
.76709 .41125 L
.76837 .40773 L
.77191 .39802 L
.7754 .38831 L
.77681 .38428 L
.77885 .37859 L
.78235 .36888 L
.78579 .35917 L
.78652 .35704 L
.78922 .34946 L
.79268 .33974 L
.79606 .33003 L
.79623 .32954 L
.79949 .32032 L
.80291 .31061 L
.80594 .30178 L
.80625 .30089 L
.80966 .29118 L
.81304 .28147 L
.81566 .27376 L
.81635 .27176 L
.81973 .26204 L
.82308 .25233 L
.82537 .24549 L
.82636 .24262 L
.8297 .23291 L
.83302 .22319 L
.83508 .21697 L
.83627 .21348 L
.83959 .20377 L
.84287 .19406 L
.84479 .1882 L
.84609 .18434 L
.84939 .17463 L
.85264 .16492 L
.85451 .15918 L
.85583 .15521 L
.8591 .14549 L
.86233 .13578 L
.86422 .12991 L
.86549 .12607 L
.86873 .11636 L
.87194 .10664 L
.87393 .1004 L
.87507 .09693 L
.87828 .08722 L
.88147 .07751 L
.88364 .07065 L
.88457 .06779 L
.88776 .05808 L
.89093 .04837 L
.89336 .04066 L
.894 .03866 L
.89716 .02894 L
.90031 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.52899 .98077 m
.53386 .97106 L
.53399 .9708 L
.53873 .96134 L
.54351 .95163 L
.54371 .95123 L
.54829 .94192 L
.55299 .93221 L
.55342 .9313 L
.55767 .92249 L
.5623 .91278 L
.56313 .91101 L
.56691 .90307 L
.57147 .89336 L
.57284 .89037 L
.57599 .88364 L
.58049 .87393 L
.58256 .86939 L
.58493 .86422 L
.58937 .85451 L
.59227 .84806 L
.59375 .84479 L
.59813 .83508 L
.60198 .8264 L
.60244 .82537 L
.60677 .81566 L
.61103 .80594 L
.61169 .80441 L
.61529 .79623 L
.61951 .78652 L
.62141 .7821 L
.6237 .77681 L
.62789 .76709 L
.63112 .75946 L
.63201 .75738 L
.63615 .74767 L
.64023 .73796 L
.64083 .73651 L
.64432 .72824 L
.64838 .71853 L
.65054 .71325 L
.65239 .70882 L
.65642 .69911 L
.66026 .68968 L
.66037 .68939 L
.66436 .67968 L
.66831 .66997 L
.66997 .66581 L
.67222 .66026 L
.67615 .65054 L
Mistroke
.67968 .64164 L
.68001 .64083 L
.6839 .63112 L
.68775 .62141 L
.68939 .61718 L
.69157 .61169 L
.69541 .60198 L
.69911 .59242 L
.69917 .59227 L
.70297 .58256 L
.70674 .57284 L
.70882 .56738 L
.71046 .56313 L
.71422 .55342 L
.71792 .54371 L
.71853 .54205 L
.72162 .53399 L
.72532 .52428 L
.72824 .51644 L
.72895 .51457 L
.73263 .50486 L
.73628 .49514 L
.73796 .49056 L
.73988 .48543 L
.74351 .47572 L
.74709 .46601 L
.74767 .46439 L
.75067 .45629 L
.75427 .44658 L
.75738 .43796 L
.75778 .43687 L
.76135 .42716 L
.76489 .41744 L
.76709 .41125 L
.76837 .40773 L
.77191 .39802 L
.7754 .38831 L
.77681 .38428 L
.77885 .37859 L
.78235 .36888 L
.78579 .35917 L
.78652 .35704 L
.78922 .34946 L
.79268 .33974 L
.79606 .33003 L
.79623 .32954 L
.79949 .32032 L
.80291 .31061 L
.80594 .30178 L
.80625 .30089 L
Mistroke
.80966 .29118 L
.81304 .28147 L
.81566 .27376 L
.81635 .27176 L
.81973 .26204 L
.82308 .25233 L
.82537 .24549 L
.82636 .24262 L
.8297 .23291 L
.83302 .22319 L
.83508 .21697 L
.83627 .21348 L
.83959 .20377 L
.84287 .19406 L
.84479 .1882 L
.84609 .18434 L
.84939 .17463 L
.85264 .16492 L
.85451 .15918 L
.85583 .15521 L
.8591 .14549 L
.86233 .13578 L
.86422 .12991 L
.86549 .12607 L
.86873 .11636 L
.87194 .10664 L
.87393 .1004 L
.87507 .09693 L
.87828 .08722 L
.88147 .07751 L
.88364 .07065 L
.88457 .06779 L
.88776 .05808 L
.89093 .04837 L
.89336 .04066 L
.894 .03866 L
.89716 .02894 L
.90031 .01923 L
Mfstroke
.6 g
.5413 .98077 m
.54371 .97583 L
.54601 .97106 L
.5507 .96134 L
.55342 .95568 L
.55534 .95163 L
.55995 .94192 L
.56313 .93518 L
.56452 .93221 L
.56906 .92249 L
.57284 .91434 L
.57356 .91278 L
.57802 .90307 L
.58247 .89336 L
.58256 .89316 L
.58686 .88364 L
.59124 .87393 L
.59227 .87165 L
.59557 .86422 L
.5999 .85451 L
.60198 .8498 L
.60418 .84479 L
.60844 .83508 L
.61169 .82764 L
.61267 .82537 L
.61688 .81566 L
.62107 .80594 L
.62141 .80516 L
.62521 .79623 L
.62936 .78652 L
.63112 .78236 L
.63345 .77681 L
.63755 .76709 L
.64083 .75926 L
.64161 .75738 L
.64564 .74767 L
.64967 .73796 L
.65054 .73585 L
.65365 .72824 L
.65764 .71853 L
.66026 .71214 L
.66159 .70882 L
.66553 .69911 L
.66946 .68939 L
.66997 .68813 L
.67333 .67968 L
.67723 .66997 L
.67968 .66382 L
.68108 .66026 L
.68492 .65054 L
.68876 .64083 L
.68939 .63922 L
.69255 .63112 L
.69635 .62141 L
.69911 .61434 L
.70012 .61169 L
.70387 .60198 L
.70763 .59227 L
.70882 .58917 L
.71133 .58256 L
.71505 .57284 L
.71853 .56372 L
.71875 .56313 L
.72241 .55342 L
.72609 .54371 L
.72824 .53799 L
.72972 .53399 L
.73336 .52428 L
.737 .51457 L
.73796 .51199 L
.74057 .50486 L
.74418 .49514 L
.74767 .48572 L
.74777 .48543 L
.75131 .47572 L
.75488 .46601 L
.75738 .45917 L
.75841 .45629 L
.76193 .44658 L
.76546 .43687 L
.76709 .43236 L
.76894 .42716 L
.77243 .41744 L
.77593 .40773 L
.77681 .40528 L
.77936 .39802 L
.78283 .38831 L
.78629 .37859 L
.78652 .37794 L
.78968 .36888 L
.79312 .35917 L
.79623 .35034 L
.79653 .34946 L
.7999 .33974 L
.80331 .33003 L
.80594 .32249 L
.80668 .32032 L
.81003 .31061 L
.81341 .30089 L
.81566 .29438 L
.81673 .29118 L
.82005 .28147 L
.82341 .27176 L
.82537 .26601 L
.82669 .26204 L
.82999 .25233 L
.83331 .24262 L
.83508 .2374 L
.83656 .23291 L
.83984 .22319 L
.84314 .21348 L
.84479 .20854 L
.84635 .20377 L
.8496 .19406 L
.85287 .18434 L
.85451 .17943 L
.85606 .17463 L
.85929 .16492 L
.86253 .15521 L
.86422 .15008 L
.86569 .14549 L
.86889 .13578 L
.8721 .12607 L
.87393 .12049 L
.87524 .11636 L
.87841 .10664 L
.8816 .09693 L
.88364 .09065 L
.88472 .08722 L
.88786 .07751 L
.89103 .06779 L
.89336 .06058 L
.89413 .05808 L
.89723 .04837 L
.90038 .03866 L
.90307 .03028 L
.90348 .02894 L
.90654 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.5413 .98077 m
.54371 .97583 L
.54601 .97106 L
.5507 .96134 L
.55342 .95568 L
.55534 .95163 L
.55995 .94192 L
.56313 .93518 L
.56452 .93221 L
.56906 .92249 L
.57284 .91434 L
.57356 .91278 L
.57802 .90307 L
.58247 .89336 L
.58256 .89316 L
.58686 .88364 L
.59124 .87393 L
.59227 .87165 L
.59557 .86422 L
.5999 .85451 L
.60198 .8498 L
.60418 .84479 L
.60844 .83508 L
.61169 .82764 L
.61267 .82537 L
.61688 .81566 L
.62107 .80594 L
.62141 .80516 L
.62521 .79623 L
.62936 .78652 L
.63112 .78236 L
.63345 .77681 L
.63755 .76709 L
.64083 .75926 L
.64161 .75738 L
.64564 .74767 L
.64967 .73796 L
.65054 .73585 L
.65365 .72824 L
.65764 .71853 L
.66026 .71214 L
.66159 .70882 L
.66553 .69911 L
.66946 .68939 L
.66997 .68813 L
.67333 .67968 L
.67723 .66997 L
.67968 .66382 L
.68108 .66026 L
.68492 .65054 L
Mistroke
.68876 .64083 L
.68939 .63922 L
.69255 .63112 L
.69635 .62141 L
.69911 .61434 L
.70012 .61169 L
.70387 .60198 L
.70763 .59227 L
.70882 .58917 L
.71133 .58256 L
.71505 .57284 L
.71853 .56372 L
.71875 .56313 L
.72241 .55342 L
.72609 .54371 L
.72824 .53799 L
.72972 .53399 L
.73336 .52428 L
.737 .51457 L
.73796 .51199 L
.74057 .50486 L
.74418 .49514 L
.74767 .48572 L
.74777 .48543 L
.75131 .47572 L
.75488 .46601 L
.75738 .45917 L
.75841 .45629 L
.76193 .44658 L
.76546 .43687 L
.76709 .43236 L
.76894 .42716 L
.77243 .41744 L
.77593 .40773 L
.77681 .40528 L
.77936 .39802 L
.78283 .38831 L
.78629 .37859 L
.78652 .37794 L
.78968 .36888 L
.79312 .35917 L
.79623 .35034 L
.79653 .34946 L
.7999 .33974 L
.80331 .33003 L
.80594 .32249 L
.80668 .32032 L
.81003 .31061 L
.81341 .30089 L
.81566 .29438 L
Mistroke
.81673 .29118 L
.82005 .28147 L
.82341 .27176 L
.82537 .26601 L
.82669 .26204 L
.82999 .25233 L
.83331 .24262 L
.83508 .2374 L
.83656 .23291 L
.83984 .22319 L
.84314 .21348 L
.84479 .20854 L
.84635 .20377 L
.8496 .19406 L
.85287 .18434 L
.85451 .17943 L
.85606 .17463 L
.85929 .16492 L
.86253 .15521 L
.86422 .15008 L
.86569 .14549 L
.86889 .13578 L
.8721 .12607 L
.87393 .12049 L
.87524 .11636 L
.87841 .10664 L
.8816 .09693 L
.88364 .09065 L
.88472 .08722 L
.88786 .07751 L
.89103 .06779 L
.89336 .06058 L
.89413 .05808 L
.89723 .04837 L
.90038 .03866 L
.90307 .03028 L
.90348 .02894 L
.90654 .01923 L
Mfstroke
.7 g
.55403 .98077 m
.55855 .97106 L
.56313 .96137 L
.56314 .96134 L
.56755 .95163 L
.57208 .94192 L
.57284 .94027 L
.57642 .93221 L
.58088 .92249 L
.58256 .91883 L
.58518 .91278 L
.58957 .90307 L
.59227 .89708 L
.59384 .89336 L
.59813 .88364 L
.60198 .87502 L
.60243 .87393 L
.60659 .86422 L
.61088 .85451 L
.61169 .85264 L
.61496 .84479 L
.61918 .83508 L
.62141 .82995 L
.62326 .82537 L
.62738 .81566 L
.63112 .80696 L
.63151 .80594 L
.6355 .79623 L
.63962 .78652 L
.64083 .78366 L
.64355 .77681 L
.6476 .76709 L
.65054 .76006 L
.65156 .75738 L
.65549 .74767 L
.65952 .73796 L
.66026 .73617 L
.66332 .72824 L
.66729 .71853 L
.66997 .71198 L
.67114 .70882 L
.67498 .69911 L
.67892 .68939 L
.67968 .68751 L
.68263 .67968 L
.68651 .66997 L
.68939 .66275 L
.69028 .66026 L
.69402 .65054 L
.69788 .64083 L
.69911 .63771 L
.7015 .63112 L
.70528 .62141 L
.70882 .61239 L
.70906 .61169 L
.71264 .60198 L
.71641 .59227 L
.71853 .58679 L
.72 .58256 L
.72366 .57284 L
.7274 .56313 L
.72824 .56092 L
.73088 .55342 L
.73456 .54371 L
.73796 .53478 L
.73821 .53399 L
.74167 .52428 L
.74534 .51457 L
.74767 .50837 L
.74883 .50486 L
.75235 .49514 L
.75599 .48543 L
.75738 .48169 L
.75938 .47572 L
.76292 .46601 L
.76653 .45629 L
.76709 .45475 L
.76984 .44658 L
.77339 .43687 L
.77681 .42755 L
.77693 .42716 L
.78021 .41744 L
.78374 .40773 L
.78652 .40009 L
.78715 .39802 L
.79048 .38831 L
.79399 .37859 L
.79623 .37237 L
.79731 .36888 L
.80066 .35917 L
.80414 .34946 L
.80594 .3444 L
.80738 .33974 L
.81074 .33003 L
.8142 .32032 L
.81566 .31618 L
.81737 .31061 L
.82072 .30089 L
.82415 .29118 L
.82537 .2877 L
.82728 .28147 L
.83062 .27176 L
.83402 .26204 L
.83508 .25898 L
.83711 .25233 L
.84043 .24262 L
.8438 .23291 L
.84479 .23002 L
.84685 .22319 L
.85015 .21348 L
.8535 .20377 L
.85451 .20081 L
.85652 .19406 L
.85978 .18434 L
.86311 .17463 L
.86422 .17136 L
.86611 .16492 L
.86934 .15521 L
.87265 .14549 L
.87393 .14167 L
.87562 .13578 L
.87882 .12607 L
.8821 .11636 L
.88364 .11174 L
.88507 .10664 L
.88822 .09693 L
.89148 .08722 L
.89336 .08157 L
.89446 .07751 L
.89755 .06779 L
.90079 .05808 L
.90307 .05118 L
.9038 .04837 L
.90681 .03866 L
.91002 .02894 L
.91278 .02056 L
.91311 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.55403 .98077 m
.55855 .97106 L
.56313 .96137 L
.56314 .96134 L
.56755 .95163 L
.57208 .94192 L
.57284 .94027 L
.57642 .93221 L
.58088 .92249 L
.58256 .91883 L
.58518 .91278 L
.58957 .90307 L
.59227 .89708 L
.59384 .89336 L
.59813 .88364 L
.60198 .87502 L
.60243 .87393 L
.60659 .86422 L
.61088 .85451 L
.61169 .85264 L
.61496 .84479 L
.61918 .83508 L
.62141 .82995 L
.62326 .82537 L
.62738 .81566 L
.63112 .80696 L
.63151 .80594 L
.6355 .79623 L
.63962 .78652 L
.64083 .78366 L
.64355 .77681 L
.6476 .76709 L
.65054 .76006 L
.65156 .75738 L
.65549 .74767 L
.65952 .73796 L
.66026 .73617 L
.66332 .72824 L
.66729 .71853 L
.66997 .71198 L
.67114 .70882 L
.67498 .69911 L
.67892 .68939 L
.67968 .68751 L
.68263 .67968 L
.68651 .66997 L
.68939 .66275 L
.69028 .66026 L
.69402 .65054 L
.69788 .64083 L
Mistroke
.69911 .63771 L
.7015 .63112 L
.70528 .62141 L
.70882 .61239 L
.70906 .61169 L
.71264 .60198 L
.71641 .59227 L
.71853 .58679 L
.72 .58256 L
.72366 .57284 L
.7274 .56313 L
.72824 .56092 L
.73088 .55342 L
.73456 .54371 L
.73796 .53478 L
.73821 .53399 L
.74167 .52428 L
.74534 .51457 L
.74767 .50837 L
.74883 .50486 L
.75235 .49514 L
.75599 .48543 L
.75738 .48169 L
.75938 .47572 L
.76292 .46601 L
.76653 .45629 L
.76709 .45475 L
.76984 .44658 L
.77339 .43687 L
.77681 .42755 L
.77693 .42716 L
.78021 .41744 L
.78374 .40773 L
.78652 .40009 L
.78715 .39802 L
.79048 .38831 L
.79399 .37859 L
.79623 .37237 L
.79731 .36888 L
.80066 .35917 L
.80414 .34946 L
.80594 .3444 L
.80738 .33974 L
.81074 .33003 L
.8142 .32032 L
.81566 .31618 L
.81737 .31061 L
.82072 .30089 L
.82415 .29118 L
.82537 .2877 L
Mistroke
.82728 .28147 L
.83062 .27176 L
.83402 .26204 L
.83508 .25898 L
.83711 .25233 L
.84043 .24262 L
.8438 .23291 L
.84479 .23002 L
.84685 .22319 L
.85015 .21348 L
.8535 .20377 L
.85451 .20081 L
.85652 .19406 L
.85978 .18434 L
.86311 .17463 L
.86422 .17136 L
.86611 .16492 L
.86934 .15521 L
.87265 .14549 L
.87393 .14167 L
.87562 .13578 L
.87882 .12607 L
.8821 .11636 L
.88364 .11174 L
.88507 .10664 L
.88822 .09693 L
.89148 .08722 L
.89336 .08157 L
.89446 .07751 L
.89755 .06779 L
.90079 .05808 L
.90307 .05118 L
.9038 .04837 L
.90681 .03866 L
.91002 .02894 L
.91278 .02056 L
.91311 .01923 L
Mfstroke
.8 g
.57168 .98077 m
.57284 .97887 L
.57623 .97106 L
.57952 .96134 L
.58256 .95624 L
.58465 .95163 L
.58883 .94192 L
.59227 .93371 L
.59299 .93221 L
.59714 .92249 L
.60105 .91278 L
.60198 .911 L
.60537 .90307 L
.60865 .89336 L
.61169 .88783 L
.61352 .88364 L
.61572 .87393 L
.62141 .86461 L
.62159 .86422 L
.62561 .85451 L
.62918 .84479 L
.63112 .84097 L
.63358 .83508 L
.63628 .82537 L
.64083 .81713 L
.64146 .81566 L
.6454 .80594 L
.64899 .79623 L
.65054 .79303 L
.65319 .78652 L
.65596 .77681 L
.66026 .76865 L
.6609 .76709 L
.66476 .75738 L
.66823 .74767 L
.66997 .74401 L
.67238 .73796 L
.67496 .72824 L
.67968 .71914 L
.67993 .71853 L
.68371 .70882 L
.68695 .69911 L
.68939 .69393 L
.69117 .68939 L
.69332 .67968 L
.69848 .66997 L
.69911 .66856 L
.70228 .66026 L
.70513 .65054 L
.70882 .64284 L
.7096 .64083 L
.71326 .63112 L
.7165 .62141 L
.71853 .61689 L
.7205 .61169 L
.72266 .60198 L
.72758 .59227 L
.72824 .59072 L
.73128 .58256 L
.73394 .57284 L
.73796 .56425 L
.73838 .56313 L
.74194 .55342 L
.74492 .54371 L
.74767 .53751 L
.74897 .53399 L
.75058 .52428 L
.75567 .51457 L
.75738 .51055 L
.75945 .50486 L
.76152 .49514 L
.76623 .48543 L
.76709 .48335 L
.76983 .47572 L
.7722 .46601 L
.77665 .45629 L
.77681 .4559 L
.7801 .44658 L
.78268 .43687 L
.78652 .42816 L
.78688 .42716 L
.79028 .41744 L
.79299 .40773 L
.79623 .40018 L
.797 .39802 L
.80037 .38831 L
.80316 .37859 L
.80594 .37197 L
.80703 .36888 L
.80821 .35917 L
.81321 .34946 L
.81566 .34351 L
.81696 .33974 L
.81827 .33003 L
.82314 .32032 L
.82537 .31482 L
.82681 .31061 L
.82818 .30089 L
.83295 .29118 L
.83508 .28589 L
.83658 .28147 L
.83794 .27176 L
.84267 .26204 L
.84479 .25671 L
.84627 .25233 L
.84757 .24262 L
.85229 .23291 L
.85451 .2273 L
.85588 .22319 L
.85705 .21348 L
.8618 .20377 L
.86422 .19766 L
.86542 .19406 L
.8664 .18434 L
.87122 .17463 L
.87393 .16778 L
.87488 .16492 L
.87803 .15521 L
.88054 .14549 L
.88364 .13767 L
.88427 .13578 L
.8874 .12607 L
.88975 .11636 L
.89336 .10735 L
.89359 .10664 L
.8967 .09693 L
.89884 .08722 L
.9028 .07751 L
.90307 .07678 L
.90593 .06779 L
.90781 .05808 L
.9119 .04837 L
.91278 .04597 L
.9151 .03866 L
.91664 .02894 L
.9209 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.57168 .98077 m
.57284 .97887 L
.57623 .97106 L
.57952 .96134 L
.58256 .95624 L
.58465 .95163 L
.58883 .94192 L
.59227 .93371 L
.59299 .93221 L
.59714 .92249 L
.60105 .91278 L
.60198 .911 L
.60537 .90307 L
.60865 .89336 L
.61169 .88783 L
.61352 .88364 L
.61572 .87393 L
.62141 .86461 L
.62159 .86422 L
.62561 .85451 L
.62918 .84479 L
.63112 .84097 L
.63358 .83508 L
.63628 .82537 L
.64083 .81713 L
.64146 .81566 L
.6454 .80594 L
.64899 .79623 L
.65054 .79303 L
.65319 .78652 L
.65596 .77681 L
.66026 .76865 L
.6609 .76709 L
.66476 .75738 L
.66823 .74767 L
.66997 .74401 L
.67238 .73796 L
.67496 .72824 L
.67968 .71914 L
.67993 .71853 L
.68371 .70882 L
.68695 .69911 L
.68939 .69393 L
.69117 .68939 L
.69332 .67968 L
.69848 .66997 L
.69911 .66856 L
.70228 .66026 L
.70513 .65054 L
.70882 .64284 L
Mistroke
.7096 .64083 L
.71326 .63112 L
.7165 .62141 L
.71853 .61689 L
.7205 .61169 L
.72266 .60198 L
.72758 .59227 L
.72824 .59072 L
.73128 .58256 L
.73394 .57284 L
.73796 .56425 L
.73838 .56313 L
.74194 .55342 L
.74492 .54371 L
.74767 .53751 L
.74897 .53399 L
.75058 .52428 L
.75567 .51457 L
.75738 .51055 L
.75945 .50486 L
.76152 .49514 L
.76623 .48543 L
.76709 .48335 L
.76983 .47572 L
.7722 .46601 L
.77665 .45629 L
.77681 .4559 L
.7801 .44658 L
.78268 .43687 L
.78652 .42816 L
.78688 .42716 L
.79028 .41744 L
.79299 .40773 L
.79623 .40018 L
.797 .39802 L
.80037 .38831 L
.80316 .37859 L
.80594 .37197 L
.80703 .36888 L
.80821 .35917 L
.81321 .34946 L
.81566 .34351 L
.81696 .33974 L
.81827 .33003 L
.82314 .32032 L
.82537 .31482 L
.82681 .31061 L
.82818 .30089 L
.83295 .29118 L
.83508 .28589 L
Mistroke
.83658 .28147 L
.83794 .27176 L
.84267 .26204 L
.84479 .25671 L
.84627 .25233 L
.84757 .24262 L
.85229 .23291 L
.85451 .2273 L
.85588 .22319 L
.85705 .21348 L
.8618 .20377 L
.86422 .19766 L
.86542 .19406 L
.8664 .18434 L
.87122 .17463 L
.87393 .16778 L
.87488 .16492 L
.87803 .15521 L
.88054 .14549 L
.88364 .13767 L
.88427 .13578 L
.8874 .12607 L
.88975 .11636 L
.89336 .10735 L
.89359 .10664 L
.8967 .09693 L
.89884 .08722 L
.9028 .07751 L
.90307 .07678 L
.90593 .06779 L
.90781 .05808 L
.9119 .04837 L
.91278 .04597 L
.9151 .03866 L
.91664 .02894 L
.9209 .01923 L
Mfstroke
.7 g
.5953 .98077 m
.59986 .97106 L
.60198 .9667 L
.60437 .96134 L
.60885 .95163 L
.61169 .94556 L
.61399 .94192 L
.61769 .93221 L
.62141 .92403 L
.62229 .92249 L
.62639 .91278 L
.63071 .90307 L
.63112 .90221 L
.63496 .89336 L
.63921 .88364 L
.64083 .88006 L
.64456 .87393 L
.6476 .86422 L
.65054 .85745 L
.65215 .85451 L
.65588 .84479 L
.66 .83508 L
.66026 .83452 L
.66406 .82537 L
.66812 .81566 L
.66997 .81133 L
.67292 .80594 L
.67615 .79623 L
.67968 .7877 L
.68027 .78652 L
.68409 .77681 L
.68804 .76709 L
.68939 .76386 L
.69287 .75738 L
.69585 .74767 L
.69911 .7396 L
.6999 .73796 L
.70358 .72824 L
.70743 .71853 L
.70882 .71511 L
.71205 .70882 L
.71504 .69911 L
.71853 .69023 L
.71892 .68939 L
.72436 .67968 L
.72635 .66997 L
.72824 .66514 L
.7306 .66026 L
.73378 .65054 L
.7375 .64083 L
.73796 .63968 L
.74231 .63112 L
.74483 .62141 L
.74767 .61395 L
.74869 .61169 L
.75408 .60198 L
.75575 .59227 L
.75738 .58797 L
.7599 .58256 L
.76293 .57284 L
.76653 .56313 L
.76709 .56165 L
.77106 .55342 L
.77362 .54371 L
.77681 .53505 L
.77726 .53399 L
.78215 .52428 L
.7842 .51457 L
.78652 .50821 L
.78798 .50486 L
.79319 .49514 L
.79465 .48543 L
.79623 .48109 L
.7986 .47572 L
.80154 .46601 L
.805 .45629 L
.80594 .45368 L
.80912 .44658 L
.81181 .43687 L
.81524 .42716 L
.81566 .42599 L
.81953 .41744 L
.82198 .40773 L
.82537 .39803 L
.82537 .39802 L
.82981 .38831 L
.83205 .37859 L
.83508 .36984 L
.83547 .36888 L
.83996 .35917 L
.84202 .34946 L
.84479 .34139 L
.84545 .33974 L
.84998 .33003 L
.8519 .32032 L
.85451 .31267 L
.85533 .31061 L
.85986 .30089 L
.86169 .29118 L
.86422 .2837 L
.8651 .28147 L
.86961 .27176 L
.8714 .26204 L
.87393 .25448 L
.87477 .25233 L
.87922 .24262 L
.88102 .23291 L
.88364 .225 L
.88435 .22319 L
.8887 .21348 L
.89056 .20377 L
.89336 .19528 L
.89382 .19406 L
.89807 .18434 L
.90003 .17463 L
.90307 .16531 L
.90322 .16492 L
.90733 .15521 L
.90942 .14549 L
.91256 .13578 L
.91278 .13511 L
.91651 .12607 L
.91874 .11636 L
.92185 .10664 L
.92249 .10468 L
.9256 .09693 L
.92799 .08722 L
.93108 .07751 L
.93221 .074 L
.93462 .06779 L
.93717 .05808 L
.94023 .04837 L
.94192 .04307 L
.94359 .03866 L
.94803 .02894 L
.94932 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.5953 .98077 m
.59986 .97106 L
.60198 .9667 L
.60437 .96134 L
.60885 .95163 L
.61169 .94556 L
.61399 .94192 L
.61769 .93221 L
.62141 .92403 L
.62229 .92249 L
.62639 .91278 L
.63071 .90307 L
.63112 .90221 L
.63496 .89336 L
.63921 .88364 L
.64083 .88006 L
.64456 .87393 L
.6476 .86422 L
.65054 .85745 L
.65215 .85451 L
.65588 .84479 L
.66 .83508 L
.66026 .83452 L
.66406 .82537 L
.66812 .81566 L
.66997 .81133 L
.67292 .80594 L
.67615 .79623 L
.67968 .7877 L
.68027 .78652 L
.68409 .77681 L
.68804 .76709 L
.68939 .76386 L
.69287 .75738 L
.69585 .74767 L
.69911 .7396 L
.6999 .73796 L
.70358 .72824 L
.70743 .71853 L
.70882 .71511 L
.71205 .70882 L
.71504 .69911 L
.71853 .69023 L
.71892 .68939 L
.72436 .67968 L
.72635 .66997 L
.72824 .66514 L
.7306 .66026 L
.73378 .65054 L
.7375 .64083 L
Mistroke
.73796 .63968 L
.74231 .63112 L
.74483 .62141 L
.74767 .61395 L
.74869 .61169 L
.75408 .60198 L
.75575 .59227 L
.75738 .58797 L
.7599 .58256 L
.76293 .57284 L
.76653 .56313 L
.76709 .56165 L
.77106 .55342 L
.77362 .54371 L
.77681 .53505 L
.77726 .53399 L
.78215 .52428 L
.7842 .51457 L
.78652 .50821 L
.78798 .50486 L
.79319 .49514 L
.79465 .48543 L
.79623 .48109 L
.7986 .47572 L
.80154 .46601 L
.805 .45629 L
.80594 .45368 L
.80912 .44658 L
.81181 .43687 L
.81524 .42716 L
.81566 .42599 L
.81953 .41744 L
.82198 .40773 L
.82537 .39803 L
.82537 .39802 L
.82981 .38831 L
.83205 .37859 L
.83508 .36984 L
.83547 .36888 L
.83996 .35917 L
.84202 .34946 L
.84479 .34139 L
.84545 .33974 L
.84998 .33003 L
.8519 .32032 L
.85451 .31267 L
.85533 .31061 L
.85986 .30089 L
.86169 .29118 L
.86422 .2837 L
Mistroke
.8651 .28147 L
.86961 .27176 L
.8714 .26204 L
.87393 .25448 L
.87477 .25233 L
.87922 .24262 L
.88102 .23291 L
.88364 .225 L
.88435 .22319 L
.8887 .21348 L
.89056 .20377 L
.89336 .19528 L
.89382 .19406 L
.89807 .18434 L
.90003 .17463 L
.90307 .16531 L
.90322 .16492 L
.90733 .15521 L
.90942 .14549 L
.91256 .13578 L
.91278 .13511 L
.91651 .12607 L
.91874 .11636 L
.92185 .10664 L
.92249 .10468 L
.9256 .09693 L
.92799 .08722 L
.93108 .07751 L
.93221 .074 L
.93462 .06779 L
.93717 .05808 L
.94023 .04837 L
.94192 .04307 L
.94359 .03866 L
.94803 .02894 L
.94932 .01923 L
Mfstroke
.6 g
.6117 .98077 m
.61611 .97106 L
.62034 .96134 L
.62141 .95869 L
.62456 .95163 L
.62882 .94192 L
.63112 .93626 L
.6329 .93221 L
.63716 .92249 L
.64083 .91349 L
.64114 .91278 L
.64536 .90307 L
.64942 .89336 L
.65054 .89043 L
.65345 .88364 L
.65757 .87393 L
.66026 .86704 L
.66145 .86422 L
.66556 .85451 L
.66944 .84479 L
.66997 .84334 L
.67343 .83508 L
.67742 .82537 L
.67968 .81934 L
.6812 .81566 L
.68521 .80594 L
.68898 .79623 L
.68939 .79504 L
.69288 .78652 L
.69678 .77681 L
.69911 .77044 L
.70046 .76709 L
.70438 .75738 L
.70809 .74767 L
.70882 .74555 L
.71185 .73796 L
.71569 .72824 L
.71853 .72037 L
.71925 .71853 L
.7231 .70882 L
.7268 .69911 L
.72824 .6949 L
.7304 .68939 L
.73418 .67968 L
.73769 .66997 L
.73796 .66915 L
.7414 .66026 L
.74511 .65054 L
.74767 .64312 L
.74854 .64083 L
.75227 .63112 L
.75587 .62141 L
.75738 .61682 L
.75932 .61169 L
.76301 .60198 L
.76646 .59227 L
.76709 .59024 L
.76998 .58256 L
.77361 .57284 L
.77681 .56339 L
.7769 .56313 L
.78052 .55342 L
.78409 .54371 L
.78652 .53627 L
.78736 .53399 L
.79095 .52428 L
.79444 .51457 L
.79623 .5089 L
.7977 .50486 L
.80126 .49514 L
.80467 .48543 L
.80594 .48125 L
.80795 .47572 L
.81147 .46601 L
.81479 .45629 L
.81566 .45335 L
.81809 .44658 L
.82158 .43687 L
.82481 .42716 L
.82537 .42519 L
.82813 .41744 L
.83158 .40773 L
.83474 .39802 L
.83508 .39677 L
.83807 .38831 L
.8415 .37859 L
.84459 .36888 L
.84479 .3681 L
.84793 .35917 L
.85132 .34946 L
.85436 .33974 L
.85451 .33918 L
.85769 .33003 L
.86106 .32032 L
.86407 .31061 L
.86422 .31002 L
.86737 .30089 L
.87071 .29118 L
.87371 .28147 L
.87393 .2806 L
.87696 .27176 L
.88029 .26204 L
.88329 .25233 L
.88364 .25095 L
.88647 .24262 L
.88978 .23291 L
.89281 .22319 L
.89336 .22105 L
.89591 .21348 L
.8992 .20377 L
.90225 .19406 L
.90307 .19092 L
.90526 .18434 L
.90853 .17463 L
.91163 .16492 L
.91278 .16054 L
.91455 .15521 L
.9178 .14549 L
.92092 .13578 L
.92249 .12993 L
.92376 .12607 L
.92699 .11636 L
.93014 .10664 L
.93221 .09908 L
.93291 .09693 L
.9361 .08722 L
.93927 .07751 L
.94192 .068 L
.94199 .06779 L
.94515 .05808 L
.94832 .04837 L
.95118 .03866 L
.95163 .0367 L
.95413 .02894 L
.9573 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.6117 .98077 m
.61611 .97106 L
.62034 .96134 L
.62141 .95869 L
.62456 .95163 L
.62882 .94192 L
.63112 .93626 L
.6329 .93221 L
.63716 .92249 L
.64083 .91349 L
.64114 .91278 L
.64536 .90307 L
.64942 .89336 L
.65054 .89043 L
.65345 .88364 L
.65757 .87393 L
.66026 .86704 L
.66145 .86422 L
.66556 .85451 L
.66944 .84479 L
.66997 .84334 L
.67343 .83508 L
.67742 .82537 L
.67968 .81934 L
.6812 .81566 L
.68521 .80594 L
.68898 .79623 L
.68939 .79504 L
.69288 .78652 L
.69678 .77681 L
.69911 .77044 L
.70046 .76709 L
.70438 .75738 L
.70809 .74767 L
.70882 .74555 L
.71185 .73796 L
.71569 .72824 L
.71853 .72037 L
.71925 .71853 L
.7231 .70882 L
.7268 .69911 L
.72824 .6949 L
.7304 .68939 L
.73418 .67968 L
.73769 .66997 L
.73796 .66915 L
.7414 .66026 L
.74511 .65054 L
.74767 .64312 L
.74854 .64083 L
Mistroke
.75227 .63112 L
.75587 .62141 L
.75738 .61682 L
.75932 .61169 L
.76301 .60198 L
.76646 .59227 L
.76709 .59024 L
.76998 .58256 L
.77361 .57284 L
.77681 .56339 L
.7769 .56313 L
.78052 .55342 L
.78409 .54371 L
.78652 .53627 L
.78736 .53399 L
.79095 .52428 L
.79444 .51457 L
.79623 .5089 L
.7977 .50486 L
.80126 .49514 L
.80467 .48543 L
.80594 .48125 L
.80795 .47572 L
.81147 .46601 L
.81479 .45629 L
.81566 .45335 L
.81809 .44658 L
.82158 .43687 L
.82481 .42716 L
.82537 .42519 L
.82813 .41744 L
.83158 .40773 L
.83474 .39802 L
.83508 .39677 L
.83807 .38831 L
.8415 .37859 L
.84459 .36888 L
.84479 .3681 L
.84793 .35917 L
.85132 .34946 L
.85436 .33974 L
.85451 .33918 L
.85769 .33003 L
.86106 .32032 L
.86407 .31061 L
.86422 .31002 L
.86737 .30089 L
.87071 .29118 L
.87371 .28147 L
.87393 .2806 L
Mistroke
.87696 .27176 L
.88029 .26204 L
.88329 .25233 L
.88364 .25095 L
.88647 .24262 L
.88978 .23291 L
.89281 .22319 L
.89336 .22105 L
.89591 .21348 L
.8992 .20377 L
.90225 .19406 L
.90307 .19092 L
.90526 .18434 L
.90853 .17463 L
.91163 .16492 L
.91278 .16054 L
.91455 .15521 L
.9178 .14549 L
.92092 .13578 L
.92249 .12993 L
.92376 .12607 L
.92699 .11636 L
.93014 .10664 L
.93221 .09908 L
.93291 .09693 L
.9361 .08722 L
.93927 .07751 L
.94192 .068 L
.94199 .06779 L
.94515 .05808 L
.94832 .04837 L
.95118 .03866 L
.95163 .0367 L
.95413 .02894 L
.9573 .01923 L
Mfstroke
.5 g
.62258 .98077 m
.62678 .97106 L
.63091 .96134 L
.63112 .96084 L
.63505 .95163 L
.63916 .94192 L
.64083 .9379 L
.64323 .93221 L
.64731 .92249 L
.65054 .91463 L
.65131 .91278 L
.65535 .90307 L
.65933 .89336 L
.66026 .89107 L
.66331 .88364 L
.66727 .87393 L
.66997 .8672 L
.67118 .86422 L
.67511 .85451 L
.67899 .84479 L
.67968 .84303 L
.68287 .83508 L
.68674 .82537 L
.68939 .81857 L
.69055 .81566 L
.69439 .80594 L
.69818 .79623 L
.69911 .79381 L
.70196 .78652 L
.70575 .77681 L
.70882 .76877 L
.70947 .76709 L
.71323 .75738 L
.71695 .74767 L
.71853 .74344 L
.72063 .73796 L
.72434 .72824 L
.72799 .71853 L
.72824 .71783 L
.73166 .70882 L
.73532 .69911 L
.73796 .69194 L
.73891 .68939 L
.74255 .67968 L
.74615 .66997 L
.74767 .66578 L
.74972 .66026 L
.75332 .65054 L
.75685 .64083 L
.75738 .63934 L
.7604 .63112 L
.76396 .62141 L
.76709 .61263 L
.76743 .61169 L
.77097 .60198 L
.77448 .59227 L
.77681 .58566 L
.77792 .58256 L
.78142 .57284 L
.78489 .56313 L
.78652 .55842 L
.7883 .55342 L
.79177 .54371 L
.79518 .53399 L
.79623 .53092 L
.79858 .52428 L
.80201 .51457 L
.80537 .50486 L
.80594 .50317 L
.80875 .49514 L
.81215 .48543 L
.81547 .47572 L
.81566 .47515 L
.81883 .46601 L
.8222 .45629 L
.82537 .44688 L
.82547 .44658 L
.82881 .43687 L
.83215 .42716 L
.83508 .41836 L
.83539 .41744 L
.83871 .40773 L
.84201 .39802 L
.84479 .38958 L
.84522 .38831 L
.84851 .37859 L
.85179 .36888 L
.85451 .36056 L
.85497 .35917 L
.85823 .34946 L
.86148 .33974 L
.86422 .3313 L
.86464 .33003 L
.86787 .32032 L
.8711 .31061 L
.87393 .30179 L
.87422 .30089 L
.87743 .29118 L
.88063 .28147 L
.88364 .27203 L
.88373 .27176 L
.88691 .26204 L
.89009 .25233 L
.89318 .24262 L
.89336 .24204 L
.89632 .23291 L
.89948 .22319 L
.90256 .21348 L
.90307 .21182 L
.90566 .20377 L
.9088 .19406 L
.91187 .18434 L
.91278 .18135 L
.91492 .17463 L
.91804 .16492 L
.92111 .15521 L
.92249 .15065 L
.92412 .14549 L
.92722 .13578 L
.93028 .12607 L
.93221 .11972 L
.93326 .11636 L
.93633 .10664 L
.93939 .09693 L
.94192 .08856 L
.94233 .08722 L
.94538 .07751 L
.94842 .06779 L
.95137 .05808 L
.95163 .05717 L
.95436 .04837 L
.95739 .03866 L
.96035 .02894 L
.96134 .02555 L
.96328 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.62258 .98077 m
.62678 .97106 L
.63091 .96134 L
.63112 .96084 L
.63505 .95163 L
.63916 .94192 L
.64083 .9379 L
.64323 .93221 L
.64731 .92249 L
.65054 .91463 L
.65131 .91278 L
.65535 .90307 L
.65933 .89336 L
.66026 .89107 L
.66331 .88364 L
.66727 .87393 L
.66997 .8672 L
.67118 .86422 L
.67511 .85451 L
.67899 .84479 L
.67968 .84303 L
.68287 .83508 L
.68674 .82537 L
.68939 .81857 L
.69055 .81566 L
.69439 .80594 L
.69818 .79623 L
.69911 .79381 L
.70196 .78652 L
.70575 .77681 L
.70882 .76877 L
.70947 .76709 L
.71323 .75738 L
.71695 .74767 L
.71853 .74344 L
.72063 .73796 L
.72434 .72824 L
.72799 .71853 L
.72824 .71783 L
.73166 .70882 L
.73532 .69911 L
.73796 .69194 L
.73891 .68939 L
.74255 .67968 L
.74615 .66997 L
.74767 .66578 L
.74972 .66026 L
.75332 .65054 L
.75685 .64083 L
.75738 .63934 L
Mistroke
.7604 .63112 L
.76396 .62141 L
.76709 .61263 L
.76743 .61169 L
.77097 .60198 L
.77448 .59227 L
.77681 .58566 L
.77792 .58256 L
.78142 .57284 L
.78489 .56313 L
.78652 .55842 L
.7883 .55342 L
.79177 .54371 L
.79518 .53399 L
.79623 .53092 L
.79858 .52428 L
.80201 .51457 L
.80537 .50486 L
.80594 .50317 L
.80875 .49514 L
.81215 .48543 L
.81547 .47572 L
.81566 .47515 L
.81883 .46601 L
.8222 .45629 L
.82537 .44688 L
.82547 .44658 L
.82881 .43687 L
.83215 .42716 L
.83508 .41836 L
.83539 .41744 L
.83871 .40773 L
.84201 .39802 L
.84479 .38958 L
.84522 .38831 L
.84851 .37859 L
.85179 .36888 L
.85451 .36056 L
.85497 .35917 L
.85823 .34946 L
.86148 .33974 L
.86422 .3313 L
.86464 .33003 L
.86787 .32032 L
.8711 .31061 L
.87393 .30179 L
.87422 .30089 L
.87743 .29118 L
.88063 .28147 L
.88364 .27203 L
Mistroke
.88373 .27176 L
.88691 .26204 L
.89009 .25233 L
.89318 .24262 L
.89336 .24204 L
.89632 .23291 L
.89948 .22319 L
.90256 .21348 L
.90307 .21182 L
.90566 .20377 L
.9088 .19406 L
.91187 .18434 L
.91278 .18135 L
.91492 .17463 L
.91804 .16492 L
.92111 .15521 L
.92249 .15065 L
.92412 .14549 L
.92722 .13578 L
.93028 .12607 L
.93221 .11972 L
.93326 .11636 L
.93633 .10664 L
.93939 .09693 L
.94192 .08856 L
.94233 .08722 L
.94538 .07751 L
.94842 .06779 L
.95137 .05808 L
.95163 .05717 L
.95436 .04837 L
.95739 .03866 L
.96035 .02894 L
.96134 .02555 L
.96328 .01923 L
Mfstroke
.4 g
.63237 .98077 m
.63646 .97106 L
.64054 .96134 L
.64083 .96064 L
.64457 .95163 L
.64861 .94192 L
.65054 .93723 L
.65259 .93221 L
.65659 .92249 L
.66026 .91352 L
.66055 .91278 L
.66448 .90307 L
.66842 .89336 L
.66997 .88951 L
.6723 .88364 L
.6762 .87393 L
.67968 .8652 L
.68007 .86422 L
.6839 .85451 L
.68775 .84479 L
.68939 .84061 L
.69154 .83508 L
.69534 .82537 L
.69911 .81573 L
.69913 .81566 L
.70287 .80594 L
.70663 .79623 L
.70882 .79056 L
.71035 .78652 L
.71406 .77681 L
.71778 .76709 L
.71853 .76511 L
.72143 .75738 L
.72512 .74767 L
.72824 .73938 L
.72877 .73796 L
.73239 .72824 L
.73604 .71853 L
.73796 .71337 L
.73962 .70882 L
.74322 .69911 L
.74682 .68939 L
.74767 .6871 L
.75036 .67968 L
.75393 .66997 L
.75738 .66055 L
.75749 .66026 L
.76099 .65054 L
.76453 .64083 L
.76709 .63374 L
.76802 .63112 L
.7715 .62141 L
.77501 .61169 L
.77681 .60666 L
.77845 .60198 L
.78191 .59227 L
.78538 .58256 L
.78652 .57932 L
.78877 .57284 L
.79221 .56313 L
.79564 .55342 L
.79623 .55173 L
.799 .54371 L
.80241 .53399 L
.8058 .52428 L
.80594 .52387 L
.80913 .51457 L
.81251 .50486 L
.81566 .49576 L
.81586 .49514 L
.81917 .48543 L
.82252 .47572 L
.82537 .4674 L
.82583 .46601 L
.82911 .45629 L
.83243 .44658 L
.83508 .43878 L
.83571 .43687 L
.83897 .42716 L
.84226 .41744 L
.84479 .40992 L
.84551 .40773 L
.84874 .39802 L
.85201 .38831 L
.85451 .38082 L
.85522 .37859 L
.85842 .36888 L
.86167 .35917 L
.86422 .35146 L
.86486 .34946 L
.86803 .33974 L
.87125 .33003 L
.87393 .32187 L
.87442 .32032 L
.87756 .31061 L
.88076 .30089 L
.88364 .29204 L
.88391 .29118 L
.88702 .28147 L
.89019 .27176 L
.89333 .26204 L
.89336 .26197 L
.8964 .25233 L
.89955 .24262 L
.90267 .23291 L
.90307 .23166 L
.90572 .22319 L
.90883 .21348 L
.91194 .20377 L
.91278 .20112 L
.91496 .19406 L
.91805 .18434 L
.92115 .17463 L
.92249 .17034 L
.92415 .16492 L
.9272 .15521 L
.93028 .14549 L
.93221 .13934 L
.93328 .13578 L
.93629 .12607 L
.93935 .11636 L
.94192 .1081 L
.94235 .10664 L
.94532 .09693 L
.94836 .08722 L
.95137 .07751 L
.95163 .07664 L
.95429 .06779 L
.9573 .05808 L
.9603 .04837 L
.96134 .04495 L
.96321 .03866 L
.96618 .02894 L
.96918 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.63237 .98077 m
.63646 .97106 L
.64054 .96134 L
.64083 .96064 L
.64457 .95163 L
.64861 .94192 L
.65054 .93723 L
.65259 .93221 L
.65659 .92249 L
.66026 .91352 L
.66055 .91278 L
.66448 .90307 L
.66842 .89336 L
.66997 .88951 L
.6723 .88364 L
.6762 .87393 L
.67968 .8652 L
.68007 .86422 L
.6839 .85451 L
.68775 .84479 L
.68939 .84061 L
.69154 .83508 L
.69534 .82537 L
.69911 .81573 L
.69913 .81566 L
.70287 .80594 L
.70663 .79623 L
.70882 .79056 L
.71035 .78652 L
.71406 .77681 L
.71778 .76709 L
.71853 .76511 L
.72143 .75738 L
.72512 .74767 L
.72824 .73938 L
.72877 .73796 L
.73239 .72824 L
.73604 .71853 L
.73796 .71337 L
.73962 .70882 L
.74322 .69911 L
.74682 .68939 L
.74767 .6871 L
.75036 .67968 L
.75393 .66997 L
.75738 .66055 L
.75749 .66026 L
.76099 .65054 L
.76453 .64083 L
.76709 .63374 L
Mistroke
.76802 .63112 L
.7715 .62141 L
.77501 .61169 L
.77681 .60666 L
.77845 .60198 L
.78191 .59227 L
.78538 .58256 L
.78652 .57932 L
.78877 .57284 L
.79221 .56313 L
.79564 .55342 L
.79623 .55173 L
.799 .54371 L
.80241 .53399 L
.8058 .52428 L
.80594 .52387 L
.80913 .51457 L
.81251 .50486 L
.81566 .49576 L
.81586 .49514 L
.81917 .48543 L
.82252 .47572 L
.82537 .4674 L
.82583 .46601 L
.82911 .45629 L
.83243 .44658 L
.83508 .43878 L
.83571 .43687 L
.83897 .42716 L
.84226 .41744 L
.84479 .40992 L
.84551 .40773 L
.84874 .39802 L
.85201 .38831 L
.85451 .38082 L
.85522 .37859 L
.85842 .36888 L
.86167 .35917 L
.86422 .35146 L
.86486 .34946 L
.86803 .33974 L
.87125 .33003 L
.87393 .32187 L
.87442 .32032 L
.87756 .31061 L
.88076 .30089 L
.88364 .29204 L
.88391 .29118 L
.88702 .28147 L
.89019 .27176 L
Mistroke
.89333 .26204 L
.89336 .26197 L
.8964 .25233 L
.89955 .24262 L
.90267 .23291 L
.90307 .23166 L
.90572 .22319 L
.90883 .21348 L
.91194 .20377 L
.91278 .20112 L
.91496 .19406 L
.91805 .18434 L
.92115 .17463 L
.92249 .17034 L
.92415 .16492 L
.9272 .15521 L
.93028 .14549 L
.93221 .13934 L
.93328 .13578 L
.93629 .12607 L
.93935 .11636 L
.94192 .1081 L
.94235 .10664 L
.94532 .09693 L
.94836 .08722 L
.95137 .07751 L
.95163 .07664 L
.95429 .06779 L
.9573 .05808 L
.9603 .04837 L
.96134 .04495 L
.96321 .03866 L
.96618 .02894 L
.96918 .01923 L
Mfstroke
.3 g
.6425 .98077 m
.64652 .97106 L
.65054 .96145 L
.65058 .96134 L
.65443 .95163 L
.65845 .94192 L
.66026 .93755 L
.6623 .93221 L
.66623 .92249 L
.66997 .91337 L
.67018 .91278 L
.67394 .90307 L
.67788 .89336 L
.67968 .88889 L
.68163 .88364 L
.68547 .87393 L
.68936 .86422 L
.68939 .86414 L
.693 .85451 L
.69685 .84479 L
.69911 .83909 L
.70054 .83508 L
.70427 .82537 L
.70809 .81566 L
.70882 .81378 L
.71165 .80594 L
.71541 .79623 L
.71853 .78818 L
.71909 .78652 L
.72267 .77681 L
.72641 .76709 L
.72824 .7623 L
.72994 .75738 L
.73357 .74767 L
.73728 .73796 L
.73796 .73616 L
.74071 .72824 L
.74436 .71853 L
.74767 .70975 L
.74797 .70882 L
.75139 .69911 L
.75503 .68939 L
.75738 .68307 L
.75849 .67968 L
.76197 .66997 L
.76558 .66026 L
.76709 .65613 L
.76893 .65054 L
.77244 .64083 L
.77601 .63112 L
.77681 .62893 L
.77929 .62141 L
.7828 .61169 L
.78634 .60198 L
.78652 .60148 L
.78956 .59227 L
.79306 .58256 L
.79623 .57376 L
.7965 .57284 L
.79974 .56313 L
.80322 .55342 L
.80594 .54578 L
.80656 .54371 L
.80982 .53399 L
.81328 .52428 L
.81566 .51756 L
.81655 .51457 L
.81982 .50486 L
.82325 .49514 L
.82537 .48909 L
.82645 .48543 L
.82972 .47572 L
.83312 .46601 L
.83508 .46037 L
.83628 .45629 L
.83953 .44658 L
.84291 .43687 L
.84479 .4314 L
.84603 .42716 L
.84926 .41744 L
.85261 .40773 L
.85451 .40219 L
.85571 .39802 L
.8589 .38831 L
.86223 .37859 L
.86422 .37274 L
.86531 .36888 L
.86846 .35917 L
.87177 .34946 L
.87393 .34305 L
.87484 .33974 L
.87795 .33003 L
.88123 .32032 L
.88364 .31312 L
.88432 .31061 L
.88736 .30089 L
.89062 .29118 L
.89336 .28296 L
.89374 .28147 L
.8967 .27176 L
.89993 .26204 L
.90307 .25256 L
.90313 .25233 L
.90597 .24262 L
.90917 .23291 L
.91237 .22319 L
.91278 .22193 L
.91518 .21348 L
.91834 .20377 L
.92153 .19406 L
.92249 .19107 L
.92434 .18434 L
.92744 .17463 L
.93061 .16492 L
.93221 .15997 L
.93345 .15521 L
.93647 .14549 L
.93963 .13578 L
.94192 .12865 L
.94255 .12607 L
.94545 .11636 L
.94858 .10664 L
.95163 .09711 L
.95167 .09693 L
.95437 .08722 L
.95747 .07751 L
.96057 .06779 L
.96134 .06534 L
.96326 .05808 L
.96629 .04837 L
.96939 .03866 L
.97106 .03335 L
.97242 .02894 L
.97536 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.6425 .98077 m
.64652 .97106 L
.65054 .96145 L
.65058 .96134 L
.65443 .95163 L
.65845 .94192 L
.66026 .93755 L
.6623 .93221 L
.66623 .92249 L
.66997 .91337 L
.67018 .91278 L
.67394 .90307 L
.67788 .89336 L
.67968 .88889 L
.68163 .88364 L
.68547 .87393 L
.68936 .86422 L
.68939 .86414 L
.693 .85451 L
.69685 .84479 L
.69911 .83909 L
.70054 .83508 L
.70427 .82537 L
.70809 .81566 L
.70882 .81378 L
.71165 .80594 L
.71541 .79623 L
.71853 .78818 L
.71909 .78652 L
.72267 .77681 L
.72641 .76709 L
.72824 .7623 L
.72994 .75738 L
.73357 .74767 L
.73728 .73796 L
.73796 .73616 L
.74071 .72824 L
.74436 .71853 L
.74767 .70975 L
.74797 .70882 L
.75139 .69911 L
.75503 .68939 L
.75738 .68307 L
.75849 .67968 L
.76197 .66997 L
.76558 .66026 L
.76709 .65613 L
.76893 .65054 L
.77244 .64083 L
.77601 .63112 L
Mistroke
.77681 .62893 L
.77929 .62141 L
.7828 .61169 L
.78634 .60198 L
.78652 .60148 L
.78956 .59227 L
.79306 .58256 L
.79623 .57376 L
.7965 .57284 L
.79974 .56313 L
.80322 .55342 L
.80594 .54578 L
.80656 .54371 L
.80982 .53399 L
.81328 .52428 L
.81566 .51756 L
.81655 .51457 L
.81982 .50486 L
.82325 .49514 L
.82537 .48909 L
.82645 .48543 L
.82972 .47572 L
.83312 .46601 L
.83508 .46037 L
.83628 .45629 L
.83953 .44658 L
.84291 .43687 L
.84479 .4314 L
.84603 .42716 L
.84926 .41744 L
.85261 .40773 L
.85451 .40219 L
.85571 .39802 L
.8589 .38831 L
.86223 .37859 L
.86422 .37274 L
.86531 .36888 L
.86846 .35917 L
.87177 .34946 L
.87393 .34305 L
.87484 .33974 L
.87795 .33003 L
.88123 .32032 L
.88364 .31312 L
.88432 .31061 L
.88736 .30089 L
.89062 .29118 L
.89336 .28296 L
.89374 .28147 L
.8967 .27176 L
Mistroke
.89993 .26204 L
.90307 .25256 L
.90313 .25233 L
.90597 .24262 L
.90917 .23291 L
.91237 .22319 L
.91278 .22193 L
.91518 .21348 L
.91834 .20377 L
.92153 .19406 L
.92249 .19107 L
.92434 .18434 L
.92744 .17463 L
.93061 .16492 L
.93221 .15997 L
.93345 .15521 L
.93647 .14549 L
.93963 .13578 L
.94192 .12865 L
.94255 .12607 L
.94545 .11636 L
.94858 .10664 L
.95163 .09711 L
.95167 .09693 L
.95437 .08722 L
.95747 .07751 L
.96057 .06779 L
.96134 .06534 L
.96326 .05808 L
.96629 .04837 L
.96939 .03866 L
.97106 .03335 L
.97242 .02894 L
.97536 .01923 L
Mfstroke
.2 g
.98077 .02559 m
.97981 .02894 L
.97706 .03866 L
.97416 .04837 L
.97106 .05787 L
.97098 .05808 L
.96726 .06779 L
.96516 .07751 L
.9622 .08722 L
.96134 .08998 L
.95876 .09693 L
.95428 .10664 L
.95335 .11636 L
.95163 .1219 L
.95012 .12607 L
.94596 .13578 L
.94444 .14549 L
.94192 .15361 L
.94135 .15521 L
.93743 .16492 L
.93547 .17463 L
.93244 .18434 L
.93221 .18508 L
.92872 .19406 L
.92644 .20377 L
.9234 .21348 L
.92249 .21631 L
.91987 .22319 L
.91526 .23291 L
.91429 .24262 L
.91278 .24734 L
.9109 .25233 L
.90652 .26204 L
.90512 .27176 L
.90307 .27814 L
.90183 .28147 L
.89761 .29118 L
.89588 .30089 L
.89336 .30873 L
.89266 .31061 L
.88856 .32032 L
.88657 .33003 L
.88364 .33908 L
.8834 .33974 L
.87938 .34946 L
.8772 .35917 L
.87404 .36888 L
.87393 .36919 L
.87008 .37859 L
.86775 .38831 L
.86457 .39802 L
.86422 .39906 L
.86068 .40773 L
.85823 .41744 L
.85503 .42716 L
.85451 .4287 L
.85116 .43687 L
.84864 .44658 L
.84541 .45629 L
.84479 .45811 L
.84155 .46601 L
.83897 .47572 L
.83572 .48543 L
.83508 .48728 L
.83182 .49514 L
.82922 .50486 L
.82594 .51457 L
.82537 .51622 L
.82198 .52428 L
.81939 .53399 L
.81608 .54371 L
.81566 .54492 L
.81203 .55342 L
.80948 .56313 L
.80613 .57284 L
.80594 .57338 L
.80195 .58256 L
.79948 .59227 L
.79623 .6016 L
.79608 .60198 L
.79173 .61169 L
.78938 .62141 L
.78652 .62955 L
.78589 .63112 L
.78135 .64083 L
.77919 .65054 L
.77681 .65726 L
.77556 .66026 L
.77078 .66997 L
.76891 .67968 L
.76709 .68471 L
.7651 .68939 L
.75998 .69911 L
.75852 .70882 L
.75738 .71193 L
.75447 .71853 L
.75155 .72824 L
.74803 .73796 L
.74767 .73892 L
.74362 .74767 L
.741 .75738 L
.73796 .76565 L
.73734 .76709 L
.73251 .77681 L
.73032 .78652 L
.72824 .79207 L
.72641 .79623 L
.72102 .80594 L
.71953 .81566 L
.71853 .81827 L
.71521 .82537 L
.71229 .83508 L
.70882 .84427 L
.70859 .84479 L
.70367 .85451 L
.7013 .86422 L
.69911 .86991 L
.69726 .87393 L
.69391 .88364 L
.69018 .89336 L
.68939 .89533 L
.68557 .90307 L
.68271 .91278 L
.67968 .92052 L
.67878 .92249 L
.67327 .93221 L
.67137 .94192 L
.66997 .94537 L
.66687 .95163 L
.66374 .96134 L
.66026 .97008 L
.6598 .97106 L
.65425 .98077 L
.98077 .98077 L
F
0 g
.98077 .02559 m
.97981 .02894 L
.97706 .03866 L
.97416 .04837 L
.97106 .05787 L
.97098 .05808 L
.96726 .06779 L
.96516 .07751 L
.9622 .08722 L
.96134 .08998 L
.95876 .09693 L
.95428 .10664 L
.95335 .11636 L
.95163 .1219 L
.95012 .12607 L
.94596 .13578 L
.94444 .14549 L
.94192 .15361 L
.94135 .15521 L
.93743 .16492 L
.93547 .17463 L
.93244 .18434 L
.93221 .18508 L
.92872 .19406 L
.92644 .20377 L
.9234 .21348 L
.92249 .21631 L
.91987 .22319 L
.91526 .23291 L
.91429 .24262 L
.91278 .24734 L
.9109 .25233 L
.90652 .26204 L
.90512 .27176 L
.90307 .27814 L
.90183 .28147 L
.89761 .29118 L
.89588 .30089 L
.89336 .30873 L
.89266 .31061 L
.88856 .32032 L
.88657 .33003 L
.88364 .33908 L
.8834 .33974 L
.87938 .34946 L
.8772 .35917 L
.87404 .36888 L
.87393 .36919 L
.87008 .37859 L
.86775 .38831 L
Mistroke
.86457 .39802 L
.86422 .39906 L
.86068 .40773 L
.85823 .41744 L
.85503 .42716 L
.85451 .4287 L
.85116 .43687 L
.84864 .44658 L
.84541 .45629 L
.84479 .45811 L
.84155 .46601 L
.83897 .47572 L
.83572 .48543 L
.83508 .48728 L
.83182 .49514 L
.82922 .50486 L
.82594 .51457 L
.82537 .51622 L
.82198 .52428 L
.81939 .53399 L
.81608 .54371 L
.81566 .54492 L
.81203 .55342 L
.80948 .56313 L
.80613 .57284 L
.80594 .57338 L
.80195 .58256 L
.79948 .59227 L
.79623 .6016 L
.79608 .60198 L
.79173 .61169 L
.78938 .62141 L
.78652 .62955 L
.78589 .63112 L
.78135 .64083 L
.77919 .65054 L
.77681 .65726 L
.77556 .66026 L
.77078 .66997 L
.76891 .67968 L
.76709 .68471 L
.7651 .68939 L
.75998 .69911 L
.75852 .70882 L
.75738 .71193 L
.75447 .71853 L
.75155 .72824 L
.74803 .73796 L
.74767 .73892 L
.74362 .74767 L
Mistroke
.741 .75738 L
.73796 .76565 L
.73734 .76709 L
.73251 .77681 L
.73032 .78652 L
.72824 .79207 L
.72641 .79623 L
.72102 .80594 L
.71953 .81566 L
.71853 .81827 L
.71521 .82537 L
.71229 .83508 L
.70882 .84427 L
.70859 .84479 L
.70367 .85451 L
.7013 .86422 L
.69911 .86991 L
.69726 .87393 L
.69391 .88364 L
.69018 .89336 L
.68939 .89533 L
.68557 .90307 L
.68271 .91278 L
.67968 .92052 L
.67878 .92249 L
.67327 .93221 L
.67137 .94192 L
.66997 .94537 L
.66687 .95163 L
.66374 .96134 L
.66026 .97008 L
.6598 .97106 L
.65425 .98077 L
Mfstroke
.3 g
.98077 .11842 m
.9785 .12607 L
.97555 .13578 L
.97254 .14549 L
.97106 .15029 L
.96952 .15521 L
.96653 .16492 L
.96415 .17463 L
.96134 .18191 L
.96057 .18434 L
.95755 .19406 L
.95544 .20377 L
.95163 .21327 L
.95157 .21348 L
.94852 .22319 L
.94671 .23291 L
.94259 .24262 L
.94192 .24444 L
.93942 .25233 L
.93795 .26204 L
.93358 .27176 L
.93221 .27537 L
.93025 .28147 L
.92914 .29118 L
.9245 .30089 L
.92249 .30607 L
.92102 .31061 L
.91791 .32032 L
.91536 .33003 L
.91278 .33651 L
.91172 .33974 L
.90859 .34946 L
.90614 .35917 L
.90307 .36672 L
.90235 .36888 L
.89919 .37859 L
.89683 .38831 L
.89336 .39667 L
.89291 .39802 L
.88972 .40773 L
.88742 .41744 L
.88364 .42639 L
.88338 .42716 L
.88017 .43687 L
.87791 .44658 L
.87393 .45585 L
.87378 .45629 L
.87054 .46601 L
.86828 .47572 L
.86422 .48508 L
.8641 .48543 L
.86082 .49514 L
.85853 .50486 L
.85451 .51405 L
.85433 .51457 L
.85102 .52428 L
.84865 .53399 L
.84479 .54277 L
.84447 .54371 L
.84114 .55342 L
.83865 .56313 L
.83508 .57124 L
.83452 .57284 L
.83116 .58256 L
.82852 .59227 L
.82537 .59945 L
.82447 .60198 L
.82108 .61169 L
.81826 .62141 L
.81566 .62739 L
.81433 .63112 L
.81091 .64083 L
.8079 .65054 L
.80594 .65506 L
.80408 .66026 L
.80244 .66997 L
.79742 .67968 L
.79623 .68246 L
.79373 .68939 L
.79161 .69911 L
.78684 .70882 L
.78652 .70957 L
.78326 .71853 L
.7807 .72824 L
.77681 .73645 L
.77624 .73796 L
.77268 .74767 L
.76971 .75738 L
.76709 .76305 L
.76557 .76709 L
.76198 .77681 L
.75864 .78652 L
.75738 .78933 L
.75478 .79623 L
.75244 .80594 L
.74767 .81532 L
.74754 .81566 L
.74386 .82537 L
.74087 .83508 L
.73796 .84109 L
.73651 .84479 L
.7328 .85451 L
.7293 .86422 L
.72824 .8665 L
.72535 .87393 L
.7227 .88364 L
.71853 .89165 L
.71784 .89336 L
.71403 .90307 L
.71063 .91278 L
.70882 .91648 L
.70641 .92249 L
.70398 .93221 L
.69911 .94099 L
.69872 .94192 L
.69481 .95163 L
.69137 .96134 L
.68939 .96523 L
.68699 .97106 L
.68449 .98077 L
.98077 .98077 L
F
0 g
.98077 .11842 m
.9785 .12607 L
.97555 .13578 L
.97254 .14549 L
.97106 .15029 L
.96952 .15521 L
.96653 .16492 L
.96415 .17463 L
.96134 .18191 L
.96057 .18434 L
.95755 .19406 L
.95544 .20377 L
.95163 .21327 L
.95157 .21348 L
.94852 .22319 L
.94671 .23291 L
.94259 .24262 L
.94192 .24444 L
.93942 .25233 L
.93795 .26204 L
.93358 .27176 L
.93221 .27537 L
.93025 .28147 L
.92914 .29118 L
.9245 .30089 L
.92249 .30607 L
.92102 .31061 L
.91791 .32032 L
.91536 .33003 L
.91278 .33651 L
.91172 .33974 L
.90859 .34946 L
.90614 .35917 L
.90307 .36672 L
.90235 .36888 L
.89919 .37859 L
.89683 .38831 L
.89336 .39667 L
.89291 .39802 L
.88972 .40773 L
.88742 .41744 L
.88364 .42639 L
.88338 .42716 L
.88017 .43687 L
.87791 .44658 L
.87393 .45585 L
.87378 .45629 L
.87054 .46601 L
.86828 .47572 L
.86422 .48508 L
Mistroke
.8641 .48543 L
.86082 .49514 L
.85853 .50486 L
.85451 .51405 L
.85433 .51457 L
.85102 .52428 L
.84865 .53399 L
.84479 .54277 L
.84447 .54371 L
.84114 .55342 L
.83865 .56313 L
.83508 .57124 L
.83452 .57284 L
.83116 .58256 L
.82852 .59227 L
.82537 .59945 L
.82447 .60198 L
.82108 .61169 L
.81826 .62141 L
.81566 .62739 L
.81433 .63112 L
.81091 .64083 L
.8079 .65054 L
.80594 .65506 L
.80408 .66026 L
.80244 .66997 L
.79742 .67968 L
.79623 .68246 L
.79373 .68939 L
.79161 .69911 L
.78684 .70882 L
.78652 .70957 L
.78326 .71853 L
.7807 .72824 L
.77681 .73645 L
.77624 .73796 L
.77268 .74767 L
.76971 .75738 L
.76709 .76305 L
.76557 .76709 L
.76198 .77681 L
.75864 .78652 L
.75738 .78933 L
.75478 .79623 L
.75244 .80594 L
.74767 .81532 L
.74754 .81566 L
.74386 .82537 L
.74087 .83508 L
.73796 .84109 L
Mistroke
.73651 .84479 L
.7328 .85451 L
.7293 .86422 L
.72824 .8665 L
.72535 .87393 L
.7227 .88364 L
.71853 .89165 L
.71784 .89336 L
.71403 .90307 L
.71063 .91278 L
.70882 .91648 L
.70641 .92249 L
.70398 .93221 L
.69911 .94099 L
.69872 .94192 L
.69481 .95163 L
.69137 .96134 L
.68939 .96523 L
.68699 .97106 L
.68449 .98077 L
Mfstroke
.4 g
.98077 .14279 m
.97997 .14549 L
.97705 .15521 L
.97409 .16492 L
.97109 .17463 L
.97106 .17478 L
.96847 .18434 L
.96537 .19406 L
.96223 .20377 L
.96134 .20654 L
.95953 .21348 L
.95646 .22319 L
.9533 .23291 L
.95163 .23808 L
.95049 .24262 L
.94749 .25233 L
.94431 .26204 L
.94192 .26939 L
.94135 .27176 L
.93845 .28147 L
.93525 .29118 L
.93221 .30046 L
.93211 .30089 L
.92933 .31061 L
.92613 .32032 L
.92291 .33003 L
.92249 .33131 L
.92013 .33974 L
.91694 .34946 L
.91369 .35917 L
.91278 .36192 L
.91085 .36888 L
.90767 .37859 L
.9044 .38831 L
.90307 .3923 L
.9015 .39802 L
.89833 .40773 L
.89503 .41744 L
.89336 .42244 L
.89207 .42716 L
.88891 .43687 L
.88559 .44658 L
.88364 .45234 L
.88257 .45629 L
.87941 .46601 L
.87607 .47572 L
.87393 .48199 L
.87299 .48543 L
.86984 .49514 L
.86647 .50486 L
.86422 .5114 L
.86335 .51457 L
.86018 .52428 L
.85679 .53399 L
.85451 .54057 L
.85363 .54371 L
.85043 .55342 L
.84702 .56313 L
.84479 .56949 L
.84384 .57284 L
.8406 .58256 L
.83716 .59227 L
.83508 .59816 L
.83397 .60198 L
.83067 .61169 L
.8272 .62141 L
.82537 .62657 L
.82401 .63112 L
.82066 .64083 L
.81716 .65054 L
.81566 .65473 L
.81396 .66026 L
.81054 .66997 L
.80701 .67968 L
.80594 .68263 L
.8038 .68939 L
.80032 .69911 L
.79676 .70882 L
.79623 .71028 L
.79354 .71853 L
.79 .72824 L
.78652 .73766 L
.78643 .73796 L
.78316 .74767 L
.77956 .75738 L
.77681 .76478 L
.77609 .76709 L
.77266 .77681 L
.76901 .78652 L
.76709 .79163 L
.7656 .79623 L
.76204 .80594 L
.75834 .81566 L
.75738 .8182 L
.75495 .82537 L
.75128 .83508 L
.74767 .8445 L
.74758 .84479 L
.74415 .85451 L
.7404 .86422 L
.73796 .87054 L
.73682 .87393 L
.73319 .88364 L
.72939 .89336 L
.72824 .89629 L
.72586 .90307 L
.72208 .91278 L
.71853 .92175 L
.71829 .92249 L
.71469 .93221 L
.71082 .94192 L
.70882 .94693 L
.70715 .95163 L
.70334 .96134 L
.69941 .97106 L
.69911 .97182 L
.69576 .98077 L
.98077 .98077 L
F
0 g
.98077 .14279 m
.97997 .14549 L
.97705 .15521 L
.97409 .16492 L
.97109 .17463 L
.97106 .17478 L
.96847 .18434 L
.96537 .19406 L
.96223 .20377 L
.96134 .20654 L
.95953 .21348 L
.95646 .22319 L
.9533 .23291 L
.95163 .23808 L
.95049 .24262 L
.94749 .25233 L
.94431 .26204 L
.94192 .26939 L
.94135 .27176 L
.93845 .28147 L
.93525 .29118 L
.93221 .30046 L
.93211 .30089 L
.92933 .31061 L
.92613 .32032 L
.92291 .33003 L
.92249 .33131 L
.92013 .33974 L
.91694 .34946 L
.91369 .35917 L
.91278 .36192 L
.91085 .36888 L
.90767 .37859 L
.9044 .38831 L
.90307 .3923 L
.9015 .39802 L
.89833 .40773 L
.89503 .41744 L
.89336 .42244 L
.89207 .42716 L
.88891 .43687 L
.88559 .44658 L
.88364 .45234 L
.88257 .45629 L
.87941 .46601 L
.87607 .47572 L
.87393 .48199 L
.87299 .48543 L
.86984 .49514 L
.86647 .50486 L
Mistroke
.86422 .5114 L
.86335 .51457 L
.86018 .52428 L
.85679 .53399 L
.85451 .54057 L
.85363 .54371 L
.85043 .55342 L
.84702 .56313 L
.84479 .56949 L
.84384 .57284 L
.8406 .58256 L
.83716 .59227 L
.83508 .59816 L
.83397 .60198 L
.83067 .61169 L
.8272 .62141 L
.82537 .62657 L
.82401 .63112 L
.82066 .64083 L
.81716 .65054 L
.81566 .65473 L
.81396 .66026 L
.81054 .66997 L
.80701 .67968 L
.80594 .68263 L
.8038 .68939 L
.80032 .69911 L
.79676 .70882 L
.79623 .71028 L
.79354 .71853 L
.79 .72824 L
.78652 .73766 L
.78643 .73796 L
.78316 .74767 L
.77956 .75738 L
.77681 .76478 L
.77609 .76709 L
.77266 .77681 L
.76901 .78652 L
.76709 .79163 L
.7656 .79623 L
.76204 .80594 L
.75834 .81566 L
.75738 .8182 L
.75495 .82537 L
.75128 .83508 L
.74767 .8445 L
.74758 .84479 L
.74415 .85451 L
.7404 .86422 L
Mistroke
.73796 .87054 L
.73682 .87393 L
.73319 .88364 L
.72939 .89336 L
.72824 .89629 L
.72586 .90307 L
.72208 .91278 L
.71853 .92175 L
.71829 .92249 L
.71469 .93221 L
.71082 .94192 L
.70882 .94693 L
.70715 .95163 L
.70334 .96134 L
.69941 .97106 L
.69911 .97182 L
.69576 .98077 L
Mfstroke
.5 g
.98077 .16302 m
.98021 .16492 L
.97565 .17463 L
.97384 .18434 L
.97135 .19406 L
.97106 .19509 L
.96849 .20377 L
.9655 .21348 L
.96249 .22319 L
.96134 .22693 L
.95958 .23291 L
.95659 .24262 L
.95356 .25233 L
.95163 .25855 L
.9506 .26204 L
.94762 .27176 L
.94457 .28147 L
.94192 .28994 L
.94155 .29118 L
.93858 .30089 L
.93551 .31061 L
.93245 .32032 L
.93221 .3211 L
.92948 .33003 L
.9264 .33974 L
.92331 .34946 L
.92249 .35203 L
.92031 .35917 L
.91722 .36888 L
.9141 .37859 L
.91278 .38273 L
.91107 .38831 L
.90797 .39802 L
.90483 .40773 L
.90307 .4132 L
.90176 .41744 L
.89865 .42716 L
.89548 .43687 L
.89336 .44343 L
.89238 .44658 L
.88925 .45629 L
.88607 .46601 L
.88364 .47342 L
.88293 .47572 L
.87979 .48543 L
.87658 .49514 L
.87393 .50317 L
.8734 .50486 L
.87025 .51457 L
.86701 .52428 L
.86422 .53268 L
.8638 .53399 L
.86062 .54371 L
.85736 .55342 L
.85451 .56195 L
.85413 .56313 L
.85092 .57284 L
.84764 .58256 L
.84479 .59097 L
.84437 .59227 L
.84114 .60198 L
.83782 .61169 L
.83508 .61974 L
.83454 .62141 L
.83127 .63112 L
.82792 .64083 L
.82537 .64826 L
.82461 .65054 L
.82131 .66026 L
.81793 .66997 L
.81566 .67653 L
.8146 .67968 L
.81125 .68939 L
.80785 .69911 L
.80594 .70455 L
.80449 .70882 L
.8011 .71853 L
.79766 .72824 L
.79623 .73231 L
.79429 .73796 L
.79085 .74767 L
.78738 .75738 L
.78652 .75981 L
.78398 .76709 L
.78049 .77681 L
.77699 .78652 L
.77681 .78704 L
.77355 .79623 L
.77003 .80594 L
.76709 .81402 L
.76652 .81566 L
.76302 .82537 L
.75945 .83508 L
.75738 .84072 L
.75593 .84479 L
.75236 .85451 L
.74876 .86422 L
.74767 .86716 L
.74521 .87393 L
.74159 .88364 L
.73796 .89332 L
.73794 .89336 L
.73435 .90307 L
.73068 .91278 L
.72824 .91921 L
.72703 .92249 L
.72336 .93221 L
.71964 .94192 L
.71853 .94482 L
.71597 .95163 L
.71223 .96134 L
.70882 .97015 L
.70848 .97106 L
.70475 .98077 L
.98077 .98077 L
F
0 g
.98077 .16302 m
.98021 .16492 L
.97565 .17463 L
.97384 .18434 L
.97135 .19406 L
.97106 .19509 L
.96849 .20377 L
.9655 .21348 L
.96249 .22319 L
.96134 .22693 L
.95958 .23291 L
.95659 .24262 L
.95356 .25233 L
.95163 .25855 L
.9506 .26204 L
.94762 .27176 L
.94457 .28147 L
.94192 .28994 L
.94155 .29118 L
.93858 .30089 L
.93551 .31061 L
.93245 .32032 L
.93221 .3211 L
.92948 .33003 L
.9264 .33974 L
.92331 .34946 L
.92249 .35203 L
.92031 .35917 L
.91722 .36888 L
.9141 .37859 L
.91278 .38273 L
.91107 .38831 L
.90797 .39802 L
.90483 .40773 L
.90307 .4132 L
.90176 .41744 L
.89865 .42716 L
.89548 .43687 L
.89336 .44343 L
.89238 .44658 L
.88925 .45629 L
.88607 .46601 L
.88364 .47342 L
.88293 .47572 L
.87979 .48543 L
.87658 .49514 L
.87393 .50317 L
.8734 .50486 L
.87025 .51457 L
.86701 .52428 L
Mistroke
.86422 .53268 L
.8638 .53399 L
.86062 .54371 L
.85736 .55342 L
.85451 .56195 L
.85413 .56313 L
.85092 .57284 L
.84764 .58256 L
.84479 .59097 L
.84437 .59227 L
.84114 .60198 L
.83782 .61169 L
.83508 .61974 L
.83454 .62141 L
.83127 .63112 L
.82792 .64083 L
.82537 .64826 L
.82461 .65054 L
.82131 .66026 L
.81793 .66997 L
.81566 .67653 L
.8146 .67968 L
.81125 .68939 L
.80785 .69911 L
.80594 .70455 L
.80449 .70882 L
.8011 .71853 L
.79766 .72824 L
.79623 .73231 L
.79429 .73796 L
.79085 .74767 L
.78738 .75738 L
.78652 .75981 L
.78398 .76709 L
.78049 .77681 L
.77699 .78652 L
.77681 .78704 L
.77355 .79623 L
.77003 .80594 L
.76709 .81402 L
.76652 .81566 L
.76302 .82537 L
.75945 .83508 L
.75738 .84072 L
.75593 .84479 L
.75236 .85451 L
.74876 .86422 L
.74767 .86716 L
.74521 .87393 L
.74159 .88364 L
Mistroke
.73796 .89332 L
.73794 .89336 L
.73435 .90307 L
.73068 .91278 L
.72824 .91921 L
.72703 .92249 L
.72336 .93221 L
.71964 .94192 L
.71853 .94482 L
.71597 .95163 L
.71223 .96134 L
.70882 .97015 L
.70848 .97106 L
.70475 .98077 L
Mfstroke
.6 g
.98077 .18229 m
.97995 .18434 L
.97694 .19406 L
.97419 .20377 L
.97134 .21348 L
.97106 .21443 L
.96838 .22319 L
.96539 .23291 L
.96243 .24262 L
.96134 .24634 L
.95951 .25233 L
.9565 .26204 L
.9535 .27176 L
.95163 .27803 L
.95057 .28147 L
.94755 .29118 L
.94452 .30089 L
.94192 .30949 L
.94157 .31061 L
.93854 .32032 L
.93548 .33003 L
.9325 .33974 L
.93221 .34072 L
.92947 .34946 L
.92639 .35917 L
.92336 .36888 L
.92249 .37173 L
.92033 .37859 L
.91723 .38831 L
.91416 .39802 L
.91278 .4025 L
.91112 .40773 L
.908 .41744 L
.9049 .42716 L
.90307 .43304 L
.90185 .43687 L
.89871 .44658 L
.89557 .45629 L
.89336 .46335 L
.8925 .46601 L
.88935 .47572 L
.88618 .48543 L
.88364 .49342 L
.88309 .49514 L
.87991 .50486 L
.87672 .51457 L
.87393 .52326 L
.8736 .52428 L
.8704 .53399 L
.86718 .54371 L
.86422 .55285 L
.86403 .55342 L
.86081 .56313 L
.85757 .57284 L
.85451 .5822 L
.85439 .58256 L
.85114 .59227 L
.84787 .60198 L
.84479 .61131 L
.84467 .61169 L
.84139 .62141 L
.83809 .63112 L
.83508 .64017 L
.83486 .64083 L
.83155 .65054 L
.82823 .66026 L
.82537 .66878 L
.82497 .66997 L
.82163 .67968 L
.81828 .68939 L
.81566 .69714 L
.81498 .69911 L
.81161 .70882 L
.80824 .71853 L
.80594 .72525 L
.80491 .72824 L
.8015 .73796 L
.7981 .74767 L
.79623 .75311 L
.79473 .75738 L
.79129 .76709 L
.78787 .77681 L
.78652 .78071 L
.78446 .78652 L
.78099 .79623 L
.77754 .80594 L
.77681 .80805 L
.77408 .81566 L
.77057 .82537 L
.76711 .83508 L
.76709 .83513 L
.76359 .84479 L
.76005 .85451 L
.75738 .86194 L
.75655 .86422 L
.75299 .87393 L
.74942 .88364 L
.74767 .88848 L
.74587 .89336 L
.74226 .90307 L
.73868 .91278 L
.73796 .91476 L
.73507 .92249 L
.73142 .93221 L
.72824 .94076 L
.72781 .94192 L
.72414 .95163 L
.72046 .96134 L
.71853 .96649 L
.71679 .97106 L
.71307 .98077 L
.98077 .98077 L
F
0 g
.98077 .18229 m
.97995 .18434 L
.97694 .19406 L
.97419 .20377 L
.97134 .21348 L
.97106 .21443 L
.96838 .22319 L
.96539 .23291 L
.96243 .24262 L
.96134 .24634 L
.95951 .25233 L
.9565 .26204 L
.9535 .27176 L
.95163 .27803 L
.95057 .28147 L
.94755 .29118 L
.94452 .30089 L
.94192 .30949 L
.94157 .31061 L
.93854 .32032 L
.93548 .33003 L
.9325 .33974 L
.93221 .34072 L
.92947 .34946 L
.92639 .35917 L
.92336 .36888 L
.92249 .37173 L
.92033 .37859 L
.91723 .38831 L
.91416 .39802 L
.91278 .4025 L
.91112 .40773 L
.908 .41744 L
.9049 .42716 L
.90307 .43304 L
.90185 .43687 L
.89871 .44658 L
.89557 .45629 L
.89336 .46335 L
.8925 .46601 L
.88935 .47572 L
.88618 .48543 L
.88364 .49342 L
.88309 .49514 L
.87991 .50486 L
.87672 .51457 L
.87393 .52326 L
.8736 .52428 L
.8704 .53399 L
.86718 .54371 L
Mistroke
.86422 .55285 L
.86403 .55342 L
.86081 .56313 L
.85757 .57284 L
.85451 .5822 L
.85439 .58256 L
.85114 .59227 L
.84787 .60198 L
.84479 .61131 L
.84467 .61169 L
.84139 .62141 L
.83809 .63112 L
.83508 .64017 L
.83486 .64083 L
.83155 .65054 L
.82823 .66026 L
.82537 .66878 L
.82497 .66997 L
.82163 .67968 L
.81828 .68939 L
.81566 .69714 L
.81498 .69911 L
.81161 .70882 L
.80824 .71853 L
.80594 .72525 L
.80491 .72824 L
.8015 .73796 L
.7981 .74767 L
.79623 .75311 L
.79473 .75738 L
.79129 .76709 L
.78787 .77681 L
.78652 .78071 L
.78446 .78652 L
.78099 .79623 L
.77754 .80594 L
.77681 .80805 L
.77408 .81566 L
.77057 .82537 L
.76711 .83508 L
.76709 .83513 L
.76359 .84479 L
.76005 .85451 L
.75738 .86194 L
.75655 .86422 L
.75299 .87393 L
.74942 .88364 L
.74767 .88848 L
.74587 .89336 L
.74226 .90307 L
Mistroke
.73868 .91278 L
.73796 .91476 L
.73507 .92249 L
.73142 .93221 L
.72824 .94076 L
.72781 .94192 L
.72414 .95163 L
.72046 .96134 L
.71853 .96649 L
.71679 .97106 L
.71307 .98077 L
Mfstroke
.7 g
.98077 .20252 m
.98038 .20377 L
.97746 .21348 L
.97459 .22319 L
.97163 .23291 L
.97106 .23473 L
.96857 .24262 L
.96547 .25233 L
.96252 .26204 L
.96134 .26672 L
.95975 .27176 L
.95664 .28147 L
.95358 .29118 L
.95163 .2985 L
.95087 .30089 L
.94775 .31061 L
.94463 .32032 L
.94192 .33003 L
.94192 .33004 L
.93879 .33974 L
.93564 .34946 L
.93274 .35917 L
.93221 .36136 L
.92977 .36888 L
.92659 .37859 L
.92358 .38831 L
.92249 .39245 L
.92069 .39802 L
.91749 .40773 L
.91439 .41744 L
.91278 .42331 L
.91153 .42716 L
.90831 .43687 L
.90515 .44658 L
.90307 .45394 L
.9023 .45629 L
.89907 .46601 L
.89586 .47572 L
.89336 .48435 L
.893 .48543 L
.88975 .49514 L
.88651 .50486 L
.88364 .51451 L
.88363 .51457 L
.88036 .52428 L
.87709 .53399 L
.87412 .54371 L
.87393 .54444 L
.87089 .55342 L
.8676 .56313 L
.86456 .57284 L
.86422 .57413 L
.86135 .58256 L
.85803 .59227 L
.85494 .60198 L
.85451 .60358 L
.85172 .61169 L
.84837 .62141 L
.84526 .63112 L
.84479 .63279 L
.84201 .64083 L
.83864 .65054 L
.8355 .66026 L
.83508 .66175 L
.83222 .66997 L
.82882 .67968 L
.82568 .68939 L
.82537 .69047 L
.82234 .69911 L
.81892 .70882 L
.81578 .71853 L
.81566 .71895 L
.81236 .72824 L
.80892 .73796 L
.80594 .74717 L
.80577 .74767 L
.80229 .75738 L
.79884 .76709 L
.79623 .77514 L
.79564 .77681 L
.79213 .78652 L
.78866 .79623 L
.78652 .80286 L
.7854 .80594 L
.78186 .81566 L
.7784 .82537 L
.77681 .83031 L
.77507 .83508 L
.77149 .84479 L
.76806 .85451 L
.76709 .85752 L
.76462 .86422 L
.76102 .87393 L
.75764 .88364 L
.75738 .88446 L
.75406 .89336 L
.75045 .90307 L
.74767 .91114 L
.74705 .91278 L
.74338 .92249 L
.73978 .93221 L
.73796 .93755 L
.7363 .94192 L
.73259 .95163 L
.72903 .96134 L
.72824 .96369 L
.72542 .97106 L
.72169 .98077 L
.98077 .98077 L
F
0 g
.98077 .20252 m
.98038 .20377 L
.97746 .21348 L
.97459 .22319 L
.97163 .23291 L
.97106 .23473 L
.96857 .24262 L
.96547 .25233 L
.96252 .26204 L
.96134 .26672 L
.95975 .27176 L
.95664 .28147 L
.95358 .29118 L
.95163 .2985 L
.95087 .30089 L
.94775 .31061 L
.94463 .32032 L
.94192 .33003 L
.94192 .33004 L
.93879 .33974 L
.93564 .34946 L
.93274 .35917 L
.93221 .36136 L
.92977 .36888 L
.92659 .37859 L
.92358 .38831 L
.92249 .39245 L
.92069 .39802 L
.91749 .40773 L
.91439 .41744 L
.91278 .42331 L
.91153 .42716 L
.90831 .43687 L
.90515 .44658 L
.90307 .45394 L
.9023 .45629 L
.89907 .46601 L
.89586 .47572 L
.89336 .48435 L
.893 .48543 L
.88975 .49514 L
.88651 .50486 L
.88364 .51451 L
.88363 .51457 L
.88036 .52428 L
.87709 .53399 L
.87412 .54371 L
.87393 .54444 L
.87089 .55342 L
.8676 .56313 L
Mistroke
.86456 .57284 L
.86422 .57413 L
.86135 .58256 L
.85803 .59227 L
.85494 .60198 L
.85451 .60358 L
.85172 .61169 L
.84837 .62141 L
.84526 .63112 L
.84479 .63279 L
.84201 .64083 L
.83864 .65054 L
.8355 .66026 L
.83508 .66175 L
.83222 .66997 L
.82882 .67968 L
.82568 .68939 L
.82537 .69047 L
.82234 .69911 L
.81892 .70882 L
.81578 .71853 L
.81566 .71895 L
.81236 .72824 L
.80892 .73796 L
.80594 .74717 L
.80577 .74767 L
.80229 .75738 L
.79884 .76709 L
.79623 .77514 L
.79564 .77681 L
.79213 .78652 L
.78866 .79623 L
.78652 .80286 L
.7854 .80594 L
.78186 .81566 L
.7784 .82537 L
.77681 .83031 L
.77507 .83508 L
.77149 .84479 L
.76806 .85451 L
.76709 .85752 L
.76462 .86422 L
.76102 .87393 L
.75764 .88364 L
.75738 .88446 L
.75406 .89336 L
.75045 .90307 L
.74767 .91114 L
.74705 .91278 L
.74338 .92249 L
Mistroke
.73978 .93221 L
.73796 .93755 L
.7363 .94192 L
.73259 .95163 L
.72903 .96134 L
.72824 .96369 L
.72542 .97106 L
.72169 .98077 L
Mfstroke
.8 g
.98077 .22687 m
.97909 .23291 L
.97631 .24262 L
.97335 .25233 L
.97106 .25923 L
.97006 .26204 L
.96611 .27176 L
.96438 .28147 L
.96141 .29118 L
.96134 .29139 L
.9577 .30089 L
.95553 .31061 L
.95255 .32032 L
.95163 .32328 L
.94911 .33003 L
.94462 .33974 L
.94364 .34946 L
.94192 .35498 L
.94039 .35917 L
.9362 .36888 L
.93467 .37859 L
.93221 .38646 L
.93154 .38831 L
.92757 .39802 L
.92563 .40773 L
.92258 .41744 L
.92249 .41772 L
.91878 .42716 L
.91654 .43687 L
.91347 .44658 L
.91278 .44873 L
.90985 .45629 L
.90738 .46601 L
.90429 .47572 L
.90307 .47952 L
.90081 .48543 L
.89626 .49514 L
.89505 .50486 L
.89336 .51009 L
.89166 .51457 L
.88727 .52428 L
.88574 .53399 L
.88364 .54044 L
.88241 .54371 L
.87813 .55342 L
.87636 .56313 L
.87393 .57056 L
.87307 .57284 L
.86886 .58256 L
.86691 .59227 L
.86422 .60045 L
.86364 .60198 L
.85947 .61169 L
.85739 .62141 L
.85451 .6301 L
.85412 .63112 L
.84996 .64083 L
.84779 .65054 L
.84479 .65951 L
.84451 .66026 L
.84034 .66997 L
.83811 .67968 L
.83508 .68869 L
.83481 .68939 L
.8306 .69911 L
.82836 .70882 L
.82537 .71762 L
.82502 .71853 L
.82075 .72824 L
.81852 .73796 L
.81566 .74631 L
.81512 .74767 L
.81076 .75738 L
.80859 .76709 L
.80594 .77476 L
.80513 .77681 L
.80064 .78652 L
.79858 .79623 L
.79623 .80296 L
.79502 .80594 L
.79036 .81566 L
.78848 .82537 L
.78652 .83091 L
.78479 .83508 L
.7799 .84479 L
.77828 .85451 L
.77681 .85862 L
.77442 .86422 L
.77144 .87393 L
.76799 .88364 L
.76709 .8861 L
.76389 .89336 L
.76109 .90307 L
.75759 .91278 L
.75738 .91335 L
.75318 .92249 L
.75062 .93221 L
.74767 .94031 L
.74699 .94192 L
.74221 .95163 L
.74005 .96134 L
.73796 .967 L
.73618 .97106 L
.73092 .98077 L
.98077 .98077 L
F
0 g
.98077 .22687 m
.97909 .23291 L
.97631 .24262 L
.97335 .25233 L
.97106 .25923 L
.97006 .26204 L
.96611 .27176 L
.96438 .28147 L
.96141 .29118 L
.96134 .29139 L
.9577 .30089 L
.95553 .31061 L
.95255 .32032 L
.95163 .32328 L
.94911 .33003 L
.94462 .33974 L
.94364 .34946 L
.94192 .35498 L
.94039 .35917 L
.9362 .36888 L
.93467 .37859 L
.93221 .38646 L
.93154 .38831 L
.92757 .39802 L
.92563 .40773 L
.92258 .41744 L
.92249 .41772 L
.91878 .42716 L
.91654 .43687 L
.91347 .44658 L
.91278 .44873 L
.90985 .45629 L
.90738 .46601 L
.90429 .47572 L
.90307 .47952 L
.90081 .48543 L
.89626 .49514 L
.89505 .50486 L
.89336 .51009 L
.89166 .51457 L
.88727 .52428 L
.88574 .53399 L
.88364 .54044 L
.88241 .54371 L
.87813 .55342 L
.87636 .56313 L
.87393 .57056 L
.87307 .57284 L
.86886 .58256 L
.86691 .59227 L
Mistroke
.86422 .60045 L
.86364 .60198 L
.85947 .61169 L
.85739 .62141 L
.85451 .6301 L
.85412 .63112 L
.84996 .64083 L
.84779 .65054 L
.84479 .65951 L
.84451 .66026 L
.84034 .66997 L
.83811 .67968 L
.83508 .68869 L
.83481 .68939 L
.8306 .69911 L
.82836 .70882 L
.82537 .71762 L
.82502 .71853 L
.82075 .72824 L
.81852 .73796 L
.81566 .74631 L
.81512 .74767 L
.81076 .75738 L
.80859 .76709 L
.80594 .77476 L
.80513 .77681 L
.80064 .78652 L
.79858 .79623 L
.79623 .80296 L
.79502 .80594 L
.79036 .81566 L
.78848 .82537 L
.78652 .83091 L
.78479 .83508 L
.7799 .84479 L
.77828 .85451 L
.77681 .85862 L
.77442 .86422 L
.77144 .87393 L
.76799 .88364 L
.76709 .8861 L
.76389 .89336 L
.76109 .90307 L
.75759 .91278 L
.75738 .91335 L
.75318 .92249 L
.75062 .93221 L
.74767 .94031 L
.74699 .94192 L
.74221 .95163 L
Mistroke
.74005 .96134 L
.73796 .967 L
.73618 .97106 L
.73092 .98077 L
Mfstroke
.7 g
.98077 .3198 m
.98062 .32032 L
.97773 .33003 L
.97475 .33974 L
.97174 .34946 L
.97106 .35166 L
.96873 .35917 L
.9675 .36888 L
.9631 .37859 L
.96134 .38329 L
.95977 .38831 L
.95675 .39802 L
.95432 .40773 L
.95163 .41468 L
.95075 .41744 L
.94771 .42716 L
.94551 .43687 L
.94192 .44582 L
.94168 .44658 L
.9386 .45629 L
.93666 .46601 L
.93258 .47572 L
.93221 .47674 L
.92943 .48543 L
.92775 .49514 L
.92347 .50486 L
.92249 .50744 L
.9202 .51457 L
.91878 .52428 L
.91429 .53399 L
.91278 .53789 L
.91089 .54371 L
.90973 .55342 L
.90503 .56313 L
.90307 .56811 L
.90151 .57284 L
.89835 .58256 L
.89568 .59227 L
.89336 .59807 L
.89206 .60198 L
.88887 .61169 L
.88625 .62141 L
.88364 .62779 L
.88253 .63112 L
.87931 .64083 L
.87671 .65054 L
.87393 .65726 L
.87292 .66026 L
.86968 .66997 L
.86706 .67968 L
.86422 .68649 L
.86323 .68939 L
.85996 .69911 L
.8573 .70882 L
.85451 .71546 L
.85345 .71853 L
.85015 .72824 L
.84743 .73796 L
.84479 .74418 L
.84358 .74767 L
.84026 .75738 L
.83743 .76709 L
.83508 .77264 L
.83362 .77681 L
.83027 .78652 L
.82732 .79623 L
.82537 .80084 L
.82357 .80594 L
.82206 .81566 L
.81709 .82537 L
.81566 .82877 L
.81342 .83508 L
.81156 .84479 L
.80675 .85451 L
.80594 .85643 L
.80316 .86422 L
.80093 .87393 L
.7963 .88364 L
.79623 .88381 L
.7928 .89336 L
.7902 .90307 L
.78652 .91098 L
.78585 .91278 L
.78233 .92249 L
.77937 .93221 L
.77681 .93785 L
.77529 .94192 L
.77174 .95163 L
.76846 .96134 L
.76709 .96442 L
.76462 .97106 L
.7624 .98077 L
.98077 .98077 L
F
0 g
.98077 .3198 m
.98062 .32032 L
.97773 .33003 L
.97475 .33974 L
.97174 .34946 L
.97106 .35166 L
.96873 .35917 L
.9675 .36888 L
.9631 .37859 L
.96134 .38329 L
.95977 .38831 L
.95675 .39802 L
.95432 .40773 L
.95163 .41468 L
.95075 .41744 L
.94771 .42716 L
.94551 .43687 L
.94192 .44582 L
.94168 .44658 L
.9386 .45629 L
.93666 .46601 L
.93258 .47572 L
.93221 .47674 L
.92943 .48543 L
.92775 .49514 L
.92347 .50486 L
.92249 .50744 L
.9202 .51457 L
.91878 .52428 L
.91429 .53399 L
.91278 .53789 L
.91089 .54371 L
.90973 .55342 L
.90503 .56313 L
.90307 .56811 L
.90151 .57284 L
.89835 .58256 L
.89568 .59227 L
.89336 .59807 L
.89206 .60198 L
.88887 .61169 L
.88625 .62141 L
.88364 .62779 L
.88253 .63112 L
.87931 .64083 L
.87671 .65054 L
.87393 .65726 L
.87292 .66026 L
.86968 .66997 L
.86706 .67968 L
Mistroke
.86422 .68649 L
.86323 .68939 L
.85996 .69911 L
.8573 .70882 L
.85451 .71546 L
.85345 .71853 L
.85015 .72824 L
.84743 .73796 L
.84479 .74418 L
.84358 .74767 L
.84026 .75738 L
.83743 .76709 L
.83508 .77264 L
.83362 .77681 L
.83027 .78652 L
.82732 .79623 L
.82537 .80084 L
.82357 .80594 L
.82206 .81566 L
.81709 .82537 L
.81566 .82877 L
.81342 .83508 L
.81156 .84479 L
.80675 .85451 L
.80594 .85643 L
.80316 .86422 L
.80093 .87393 L
.7963 .88364 L
.79623 .88381 L
.7928 .89336 L
.7902 .90307 L
.78652 .91098 L
.78585 .91278 L
.78233 .92249 L
.77937 .93221 L
.77681 .93785 L
.77529 .94192 L
.77174 .95163 L
.76846 .96134 L
.76709 .96442 L
.76462 .97106 L
.7624 .98077 L
Mfstroke
.6 g
.98077 .34418 m
.9792 .34946 L
.97627 .35917 L
.97157 .36888 L
.97106 .37617 L
.9705 .37859 L
.96767 .38831 L
.96453 .39802 L
.96141 .40773 L
.96134 .40793 L
.95875 .41744 L
.95562 .42716 L
.95246 .43687 L
.95163 .43947 L
.94974 .44658 L
.94665 .45629 L
.94346 .46601 L
.94192 .47078 L
.94065 .47572 L
.93761 .48543 L
.9344 .49514 L
.93221 .50185 L
.93146 .50486 L
.92849 .51457 L
.92527 .52428 L
.92249 .5327 L
.92219 .53399 L
.9193 .54371 L
.91607 .55342 L
.91284 .56313 L
.91278 .5633 L
.91003 .57284 L
.9068 .58256 L
.90354 .59227 L
.90307 .59368 L
.90069 .60198 L
.89745 .61169 L
.89416 .62141 L
.89336 .62382 L
.89127 .63112 L
.88803 .64083 L
.88472 .65054 L
.88364 .65372 L
.88178 .66026 L
.87853 .66997 L
.87519 .67968 L
.87393 .68338 L
.8722 .68939 L
.86895 .69911 L
.86558 .70882 L
.86422 .71279 L
.86256 .71853 L
.85928 .72824 L
.85589 .73796 L
.85451 .74195 L
.85283 .74767 L
.84953 .75738 L
.84611 .76709 L
.84479 .77087 L
.84303 .77681 L
.83969 .78652 L
.83624 .79623 L
.83508 .79954 L
.83314 .80594 L
.82976 .81566 L
.82629 .82537 L
.82537 .82795 L
.82316 .83508 L
.81973 .84479 L
.81623 .85451 L
.81566 .85611 L
.81308 .86422 L
.8096 .87393 L
.80608 .88364 L
.80594 .88402 L
.8029 .89336 L
.79937 .90307 L
.79623 .91166 L
.7959 .91278 L
.79262 .92249 L
.78904 .93221 L
.78652 .93905 L
.78563 .94192 L
.78222 .95163 L
.7786 .96134 L
.77681 .96616 L
.77523 .97106 L
.7717 .98077 L
.98077 .98077 L
F
0 g
.98077 .34418 m
.9792 .34946 L
.97627 .35917 L
.97157 .36888 L
.97106 .37617 L
.9705 .37859 L
.96767 .38831 L
.96453 .39802 L
.96141 .40773 L
.96134 .40793 L
.95875 .41744 L
.95562 .42716 L
.95246 .43687 L
.95163 .43947 L
.94974 .44658 L
.94665 .45629 L
.94346 .46601 L
.94192 .47078 L
.94065 .47572 L
.93761 .48543 L
.9344 .49514 L
.93221 .50185 L
.93146 .50486 L
.92849 .51457 L
.92527 .52428 L
.92249 .5327 L
.92219 .53399 L
.9193 .54371 L
.91607 .55342 L
.91284 .56313 L
.91278 .5633 L
.91003 .57284 L
.9068 .58256 L
.90354 .59227 L
.90307 .59368 L
.90069 .60198 L
.89745 .61169 L
.89416 .62141 L
.89336 .62382 L
.89127 .63112 L
.88803 .64083 L
.88472 .65054 L
.88364 .65372 L
.88178 .66026 L
.87853 .66997 L
.87519 .67968 L
.87393 .68338 L
.8722 .68939 L
.86895 .69911 L
.86558 .70882 L
Mistroke
.86422 .71279 L
.86256 .71853 L
.85928 .72824 L
.85589 .73796 L
.85451 .74195 L
.85283 .74767 L
.84953 .75738 L
.84611 .76709 L
.84479 .77087 L
.84303 .77681 L
.83969 .78652 L
.83624 .79623 L
.83508 .79954 L
.83314 .80594 L
.82976 .81566 L
.82629 .82537 L
.82537 .82795 L
.82316 .83508 L
.81973 .84479 L
.81623 .85451 L
.81566 .85611 L
.81308 .86422 L
.8096 .87393 L
.80608 .88364 L
.80594 .88402 L
.8029 .89336 L
.79937 .90307 L
.79623 .91166 L
.7959 .91278 L
.79262 .92249 L
.78904 .93221 L
.78652 .93905 L
.78563 .94192 L
.78222 .95163 L
.7786 .96134 L
.77681 .96616 L
.77523 .97106 L
.7717 .98077 L
Mfstroke
.5 g
.98077 .3644 m
.97712 .36888 L
.97524 .37859 L
.97323 .38831 L
.97106 .39647 L
.97061 .39802 L
.9677 .40773 L
.9647 .41744 L
.9617 .42716 L
.96134 .42832 L
.9588 .43687 L
.95578 .44658 L
.95276 .45629 L
.95163 .45993 L
.94982 .46601 L
.94681 .47572 L
.94376 .48543 L
.94192 .49133 L
.94078 .49514 L
.93777 .50486 L
.9347 .51457 L
.93221 .52249 L
.93167 .52428 L
.92867 .53399 L
.92558 .54371 L
.92249 .55342 L
.92249 .55342 L
.9195 .56313 L
.91639 .57284 L
.91328 .58256 L
.91278 .58412 L
.91025 .59227 L
.90713 .60198 L
.90399 .61169 L
.90307 .61458 L
.90094 .62141 L
.89781 .63112 L
.89464 .64083 L
.89336 .64481 L
.89156 .65054 L
.88841 .66026 L
.88522 .66997 L
.88364 .6748 L
.88211 .67968 L
.87894 .68939 L
.87572 .69911 L
.87393 .70456 L
.87258 .70882 L
.86939 .71853 L
.86615 .72824 L
.86422 .73407 L
.86297 .73796 L
.85976 .74767 L
.8565 .75738 L
.85451 .76333 L
.85329 .76709 L
.85005 .77681 L
.84676 .78652 L
.84479 .79235 L
.84353 .79623 L
.84026 .80594 L
.83694 .81566 L
.83508 .82113 L
.83368 .82537 L
.83038 .83508 L
.82703 .84479 L
.82537 .84965 L
.82375 .85451 L
.82041 .86422 L
.81704 .87393 L
.81566 .87792 L
.81372 .88364 L
.81035 .89336 L
.80694 .90307 L
.80594 .90593 L
.8036 .91278 L
.80019 .92249 L
.79675 .93221 L
.79623 .93369 L
.79338 .94192 L
.78993 .95163 L
.78652 .96119 L
.78647 .96134 L
.78306 .97106 L
.77956 .98077 L
.98077 .98077 L
F
0 g
.98077 .3644 m
.97712 .36888 L
.97524 .37859 L
.97323 .38831 L
.97106 .39647 L
.97061 .39802 L
.9677 .40773 L
.9647 .41744 L
.9617 .42716 L
.96134 .42832 L
.9588 .43687 L
.95578 .44658 L
.95276 .45629 L
.95163 .45993 L
.94982 .46601 L
.94681 .47572 L
.94376 .48543 L
.94192 .49133 L
.94078 .49514 L
.93777 .50486 L
.9347 .51457 L
.93221 .52249 L
.93167 .52428 L
.92867 .53399 L
.92558 .54371 L
.92249 .55342 L
.92249 .55342 L
.9195 .56313 L
.91639 .57284 L
.91328 .58256 L
.91278 .58412 L
.91025 .59227 L
.90713 .60198 L
.90399 .61169 L
.90307 .61458 L
.90094 .62141 L
.89781 .63112 L
.89464 .64083 L
.89336 .64481 L
.89156 .65054 L
.88841 .66026 L
.88522 .66997 L
.88364 .6748 L
.88211 .67968 L
.87894 .68939 L
.87572 .69911 L
.87393 .70456 L
.87258 .70882 L
.86939 .71853 L
.86615 .72824 L
Mistroke
.86422 .73407 L
.86297 .73796 L
.85976 .74767 L
.8565 .75738 L
.85451 .76333 L
.85329 .76709 L
.85005 .77681 L
.84676 .78652 L
.84479 .79235 L
.84353 .79623 L
.84026 .80594 L
.83694 .81566 L
.83508 .82113 L
.83368 .82537 L
.83038 .83508 L
.82703 .84479 L
.82537 .84965 L
.82375 .85451 L
.82041 .86422 L
.81704 .87393 L
.81566 .87792 L
.81372 .88364 L
.81035 .89336 L
.80694 .90307 L
.80594 .90593 L
.8036 .91278 L
.80019 .92249 L
.79675 .93221 L
.79623 .93369 L
.79338 .94192 L
.78993 .95163 L
.78652 .96119 L
.78647 .96134 L
.78306 .97106 L
.77956 .98077 L
Mfstroke
.4 g
.98077 .38367 m
.97905 .38831 L
.97621 .39802 L
.97345 .40773 L
.97106 .41581 L
.97056 .41744 L
.96759 .42716 L
.96459 .43687 L
.96168 .44658 L
.96134 .44772 L
.95871 .45629 L
.9557 .46601 L
.95272 .47572 L
.95163 .47941 L
.94978 .48543 L
.94674 .49514 L
.94373 .50486 L
.94192 .51087 L
.94078 .51457 L
.93773 .52428 L
.93468 .53399 L
.93221 .54211 L
.93171 .54371 L
.92865 .55342 L
.92557 .56313 L
.92257 .57284 L
.92249 .57311 L
.91951 .58256 L
.91641 .59227 L
.91336 .60198 L
.91278 .60389 L
.9103 .61169 L
.90717 .62141 L
.90409 .63112 L
.90307 .63443 L
.90102 .64083 L
.89787 .65054 L
.89476 .66026 L
.89336 .66474 L
.89167 .66997 L
.8885 .67968 L
.88535 .68939 L
.88364 .69481 L
.88225 .69911 L
.87906 .70882 L
.87588 .71853 L
.87393 .72464 L
.87275 .72824 L
.86954 .73796 L
.86634 .74767 L
.86422 .75423 L
.86318 .75738 L
.85995 .76709 L
.85671 .77681 L
.85451 .78358 L
.85353 .78652 L
.85027 .79623 L
.84701 .80594 L
.84479 .81269 L
.8438 .81566 L
.84051 .82537 L
.83723 .83508 L
.83508 .84155 L
.83399 .84479 L
.83067 .85451 L
.82736 .86422 L
.82537 .87017 L
.82408 .87393 L
.82074 .88364 L
.8174 .89336 L
.81566 .89853 L
.81409 .90307 L
.81071 .91278 L
.80735 .92249 L
.80594 .92664 L
.80401 .93221 L
.8006 .94192 L
.79721 .95163 L
.79623 .95449 L
.79382 .96134 L
.79038 .97106 L
.78697 .98077 L
.98077 .98077 L
F
0 g
.98077 .38367 m
.97905 .38831 L
.97621 .39802 L
.97345 .40773 L
.97106 .41581 L
.97056 .41744 L
.96759 .42716 L
.96459 .43687 L
.96168 .44658 L
.96134 .44772 L
.95871 .45629 L
.9557 .46601 L
.95272 .47572 L
.95163 .47941 L
.94978 .48543 L
.94674 .49514 L
.94373 .50486 L
.94192 .51087 L
.94078 .51457 L
.93773 .52428 L
.93468 .53399 L
.93221 .54211 L
.93171 .54371 L
.92865 .55342 L
.92557 .56313 L
.92257 .57284 L
.92249 .57311 L
.91951 .58256 L
.91641 .59227 L
.91336 .60198 L
.91278 .60389 L
.9103 .61169 L
.90717 .62141 L
.90409 .63112 L
.90307 .63443 L
.90102 .64083 L
.89787 .65054 L
.89476 .66026 L
.89336 .66474 L
.89167 .66997 L
.8885 .67968 L
.88535 .68939 L
.88364 .69481 L
.88225 .69911 L
.87906 .70882 L
.87588 .71853 L
.87393 .72464 L
.87275 .72824 L
.86954 .73796 L
.86634 .74767 L
Mistroke
.86422 .75423 L
.86318 .75738 L
.85995 .76709 L
.85671 .77681 L
.85451 .78358 L
.85353 .78652 L
.85027 .79623 L
.84701 .80594 L
.84479 .81269 L
.8438 .81566 L
.84051 .82537 L
.83723 .83508 L
.83508 .84155 L
.83399 .84479 L
.83067 .85451 L
.82736 .86422 L
.82537 .87017 L
.82408 .87393 L
.82074 .88364 L
.8174 .89336 L
.81566 .89853 L
.81409 .90307 L
.81071 .91278 L
.80735 .92249 L
.80594 .92664 L
.80401 .93221 L
.8006 .94192 L
.79721 .95163 L
.79623 .95449 L
.79382 .96134 L
.79038 .97106 L
.78697 .98077 L
Mfstroke
.3 g
.98077 .4039 m
.97958 .40773 L
.97671 .41744 L
.97381 .42716 L
.97106 .43612 L
.97082 .43687 L
.96775 .44658 L
.96465 .45629 L
.96184 .46601 L
.96134 .46811 L
.95893 .47572 L
.95581 .48543 L
.95284 .49514 L
.95163 .49988 L
.95005 .50486 L
.94691 .51457 L
.94384 .52428 L
.94192 .53142 L
.9411 .53399 L
.93795 .54371 L
.93483 .55342 L
.93221 .56275 L
.93208 .56313 L
.92893 .57284 L
.92576 .58256 L
.92288 .59227 L
.92249 .59384 L
.91984 .60198 L
.91664 .61169 L
.91364 .62141 L
.91278 .6247 L
.91068 .63112 L
.90746 .64083 L
.90437 .65054 L
.90307 .65533 L
.90145 .66026 L
.89821 .66997 L
.89506 .67968 L
.89336 .68573 L
.89214 .68939 L
.88888 .69911 L
.88569 .70882 L
.88364 .71589 L
.88277 .71853 L
.87949 .72824 L
.87625 .73796 L
.87393 .74582 L
.87331 .74767 L
.87002 .75738 L
.86674 .76709 L
.86422 .77551 L
.86378 .77681 L
.86046 .78652 L
.85716 .79623 L
.85451 .80497 L
.85417 .80594 L
.85083 .81566 L
.84751 .82537 L
.84479 .83417 L
.84448 .83508 L
.84112 .84479 L
.83777 .85451 L
.83508 .86314 L
.83471 .86422 L
.83131 .87393 L
.82794 .88364 L
.82537 .89186 L
.82485 .89336 L
.82142 .90307 L
.81803 .91278 L
.81566 .92033 L
.8149 .92249 L
.81144 .93221 L
.80804 .94192 L
.80594 .94855 L
.80485 .95163 L
.80137 .96134 L
.79796 .97106 L
.79623 .97653 L
.79471 .98077 L
.98077 .98077 L
F
0 g
.98077 .4039 m
.97958 .40773 L
.97671 .41744 L
.97381 .42716 L
.97106 .43612 L
.97082 .43687 L
.96775 .44658 L
.96465 .45629 L
.96184 .46601 L
.96134 .46811 L
.95893 .47572 L
.95581 .48543 L
.95284 .49514 L
.95163 .49988 L
.95005 .50486 L
.94691 .51457 L
.94384 .52428 L
.94192 .53142 L
.9411 .53399 L
.93795 .54371 L
.93483 .55342 L
.93221 .56275 L
.93208 .56313 L
.92893 .57284 L
.92576 .58256 L
.92288 .59227 L
.92249 .59384 L
.91984 .60198 L
.91664 .61169 L
.91364 .62141 L
.91278 .6247 L
.91068 .63112 L
.90746 .64083 L
.90437 .65054 L
.90307 .65533 L
.90145 .66026 L
.89821 .66997 L
.89506 .67968 L
.89336 .68573 L
.89214 .68939 L
.88888 .69911 L
.88569 .70882 L
.88364 .71589 L
.88277 .71853 L
.87949 .72824 L
.87625 .73796 L
.87393 .74582 L
.87331 .74767 L
.87002 .75738 L
.86674 .76709 L
Mistroke
.86422 .77551 L
.86378 .77681 L
.86046 .78652 L
.85716 .79623 L
.85451 .80497 L
.85417 .80594 L
.85083 .81566 L
.84751 .82537 L
.84479 .83417 L
.84448 .83508 L
.84112 .84479 L
.83777 .85451 L
.83508 .86314 L
.83471 .86422 L
.83131 .87393 L
.82794 .88364 L
.82537 .89186 L
.82485 .89336 L
.82142 .90307 L
.81803 .91278 L
.81566 .92033 L
.8149 .92249 L
.81144 .93221 L
.80804 .94192 L
.80594 .94855 L
.80485 .95163 L
.80137 .96134 L
.79796 .97106 L
.79623 .97653 L
.79471 .98077 L
Mfstroke
.2 g
.98077 .42827 m
.97836 .43687 L
.97555 .44658 L
.97252 .45629 L
.97106 .46061 L
.9691 .46601 L
.96486 .47572 L
.96359 .48543 L
.96134 .49276 L
.9605 .49514 L
.95656 .50486 L
.95474 .51457 L
.95176 .52428 L
.95163 .52468 L
.94805 .53399 L
.94584 .54371 L
.94284 .55342 L
.94192 .55636 L
.93938 .56313 L
.93485 .57284 L
.93386 .58256 L
.93221 .58783 L
.93057 .59227 L
.92633 .60198 L
.92483 .61169 L
.92249 .61909 L
.92165 .62141 L
.91761 .63112 L
.91573 .64083 L
.91278 .65013 L
.91263 .65054 L
.90873 .66026 L
.90656 .66997 L
.90347 .67968 L
.90307 .68092 L
.89973 .68939 L
.89733 .69911 L
.89422 .70882 L
.89336 .71148 L
.8906 .71853 L
.88584 .72824 L
.88491 .73796 L
.88364 .74182 L
.88137 .74767 L
.87675 .75738 L
.87552 .76709 L
.87393 .77193 L
.87205 .77681 L
.86752 .78652 L
.86607 .79623 L
.86422 .80181 L
.86262 .80594 L
.85815 .81566 L
.85654 .82537 L
.85451 .83146 L
.8531 .83508 L
.84866 .84479 L
.84693 .85451 L
.84479 .86088 L
.84349 .86422 L
.83903 .87393 L
.83725 .88364 L
.83508 .89005 L
.83378 .89336 L
.82928 .90307 L
.82748 .91278 L
.82537 .91898 L
.82397 .92249 L
.8194 .93221 L
.81764 .94192 L
.81566 .94767 L
.81406 .95163 L
.80938 .96134 L
.80771 .97106 L
.80594 .97619 L
.80404 .98077 L
.98077 .98077 L
F
0 g
.98077 .42827 m
.97836 .43687 L
.97555 .44658 L
.97252 .45629 L
.97106 .46061 L
.9691 .46601 L
.96486 .47572 L
.96359 .48543 L
.96134 .49276 L
.9605 .49514 L
.95656 .50486 L
.95474 .51457 L
.95176 .52428 L
.95163 .52468 L
.94805 .53399 L
.94584 .54371 L
.94284 .55342 L
.94192 .55636 L
.93938 .56313 L
.93485 .57284 L
.93386 .58256 L
.93221 .58783 L
.93057 .59227 L
.92633 .60198 L
.92483 .61169 L
.92249 .61909 L
.92165 .62141 L
.91761 .63112 L
.91573 .64083 L
.91278 .65013 L
.91263 .65054 L
.90873 .66026 L
.90656 .66997 L
.90347 .67968 L
.90307 .68092 L
.89973 .68939 L
.89733 .69911 L
.89422 .70882 L
.89336 .71148 L
.8906 .71853 L
.88584 .72824 L
.88491 .73796 L
.88364 .74182 L
.88137 .74767 L
.87675 .75738 L
.87552 .76709 L
.87393 .77193 L
.87205 .77681 L
.86752 .78652 L
.86607 .79623 L
Mistroke
.86422 .80181 L
.86262 .80594 L
.85815 .81566 L
.85654 .82537 L
.85451 .83146 L
.8531 .83508 L
.84866 .84479 L
.84693 .85451 L
.84479 .86088 L
.84349 .86422 L
.83903 .87393 L
.83725 .88364 L
.83508 .89005 L
.83378 .89336 L
.82928 .90307 L
.82748 .91278 L
.82537 .91898 L
.82397 .92249 L
.8194 .93221 L
.81764 .94192 L
.81566 .94767 L
.81406 .95163 L
.80938 .96134 L
.80771 .97106 L
.80594 .97619 L
.80404 .98077 L
Mfstroke
.3 g
.98077 .52121 m
.97986 .52428 L
.97694 .53399 L
.97395 .54371 L
.97106 .55303 L
.97094 .55342 L
.96793 .56313 L
.9662 .57284 L
.96211 .58256 L
.96134 .58466 L
.95897 .59227 L
.95767 .60198 L
.95327 .61169 L
.95163 .61607 L
.94994 .62141 L
.94691 .63112 L
.9444 .64083 L
.94192 .64723 L
.94086 .65054 L
.93779 .66026 L
.93547 .66997 L
.93221 .67814 L
.93171 .67968 L
.92861 .68939 L
.92649 .69911 L
.92249 .7088 L
.92249 .70882 L
.91937 .71853 L
.91745 .72824 L
.91327 .73796 L
.91278 .73926 L
.91006 .74767 L
.90832 .75738 L
.90398 .76709 L
.90307 .76948 L
.90067 .77681 L
.8991 .78652 L
.89461 .79623 L
.89336 .79945 L
.89121 .80594 L
.88976 .81566 L
.88515 .82537 L
.88364 .82917 L
.88167 .83508 L
.88031 .84479 L
.87559 .85451 L
.87393 .85865 L
.87206 .86422 L
.87072 .87393 L
.86593 .88364 L
.86422 .88787 L
.86236 .89336 L
.86098 .90307 L
.85616 .91278 L
.85451 .91684 L
.85257 .92249 L
.8511 .93221 L
.84628 .94192 L
.84479 .94555 L
.8427 .95163 L
.84106 .96134 L
.83629 .97106 L
.83508 .97389 L
.83273 .98077 L
.98077 .98077 L
F
0 g
.98077 .52121 m
.97986 .52428 L
.97694 .53399 L
.97395 .54371 L
.97106 .55303 L
.97094 .55342 L
.96793 .56313 L
.9662 .57284 L
.96211 .58256 L
.96134 .58466 L
.95897 .59227 L
.95767 .60198 L
.95327 .61169 L
.95163 .61607 L
.94994 .62141 L
.94691 .63112 L
.9444 .64083 L
.94192 .64723 L
.94086 .65054 L
.93779 .66026 L
.93547 .66997 L
.93221 .67814 L
.93171 .67968 L
.92861 .68939 L
.92649 .69911 L
.92249 .7088 L
.92249 .70882 L
.91937 .71853 L
.91745 .72824 L
.91327 .73796 L
.91278 .73926 L
.91006 .74767 L
.90832 .75738 L
.90398 .76709 L
.90307 .76948 L
.90067 .77681 L
.8991 .78652 L
.89461 .79623 L
.89336 .79945 L
.89121 .80594 L
.88976 .81566 L
.88515 .82537 L
.88364 .82917 L
.88167 .83508 L
.88031 .84479 L
.87559 .85451 L
.87393 .85865 L
.87206 .86422 L
.87072 .87393 L
.86593 .88364 L
Mistroke
.86422 .88787 L
.86236 .89336 L
.86098 .90307 L
.85616 .91278 L
.85451 .91684 L
.85257 .92249 L
.8511 .93221 L
.84628 .94192 L
.84479 .94555 L
.8427 .95163 L
.84106 .96134 L
.83629 .97106 L
.83508 .97389 L
.83273 .98077 L
Mfstroke
.4 g
.98077 .54556 m
.97843 .55342 L
.97548 .56313 L
.97168 .57284 L
.97106 .57755 L
.96982 .58256 L
.96684 .59227 L
.96369 .60198 L
.96134 .60931 L
.96079 .61169 L
.95794 .62141 L
.95478 .63112 L
.95164 .64083 L
.95163 .64085 L
.94895 .65054 L
.9458 .66026 L
.94263 .66997 L
.94192 .67216 L
.93988 .67968 L
.93676 .68939 L
.93355 .69911 L
.93221 .70324 L
.93073 .70882 L
.92764 .71853 L
.92441 .72824 L
.92249 .73408 L
.9215 .73796 L
.91845 .74767 L
.91521 .75738 L
.91278 .76469 L
.91218 .76709 L
.90919 .77681 L
.90593 .78652 L
.90307 .79507 L
.90278 .79623 L
.89985 .80594 L
.89658 .81566 L
.89336 .8252 L
.89332 .82537 L
.89044 .83508 L
.88715 .84479 L
.88384 .85451 L
.88364 .8551 L
.88094 .86422 L
.87764 .87393 L
.87431 .88364 L
.87393 .88476 L
.87137 .89336 L
.86805 .90307 L
.86469 .91278 L
.86422 .91417 L
.86172 .92249 L
.85838 .93221 L
.855 .94192 L
.85451 .94334 L
.85199 .95163 L
.84862 .96134 L
.84521 .97106 L
.84479 .97225 L
.84217 .98077 L
.98077 .98077 L
F
0 g
.98077 .54556 m
.97843 .55342 L
.97548 .56313 L
.97168 .57284 L
.97106 .57755 L
.96982 .58256 L
.96684 .59227 L
.96369 .60198 L
.96134 .60931 L
.96079 .61169 L
.95794 .62141 L
.95478 .63112 L
.95164 .64083 L
.95163 .64085 L
.94895 .65054 L
.9458 .66026 L
.94263 .66997 L
.94192 .67216 L
.93988 .67968 L
.93676 .68939 L
.93355 .69911 L
.93221 .70324 L
.93073 .70882 L
.92764 .71853 L
.92441 .72824 L
.92249 .73408 L
.9215 .73796 L
.91845 .74767 L
.91521 .75738 L
.91278 .76469 L
.91218 .76709 L
.90919 .77681 L
.90593 .78652 L
.90307 .79507 L
.90278 .79623 L
.89985 .80594 L
.89658 .81566 L
.89336 .8252 L
.89332 .82537 L
.89044 .83508 L
.88715 .84479 L
.88384 .85451 L
.88364 .8551 L
.88094 .86422 L
.87764 .87393 L
.87431 .88364 L
.87393 .88476 L
.87137 .89336 L
.86805 .90307 L
.86469 .91278 L
Mistroke
.86422 .91417 L
.86172 .92249 L
.85838 .93221 L
.855 .94192 L
.85451 .94334 L
.85199 .95163 L
.84862 .96134 L
.84521 .97106 L
.84479 .97225 L
.84217 .98077 L
Mfstroke
.5 g
.98077 .56579 m
.97641 .57284 L
.97479 .58256 L
.97258 .59227 L
.97106 .59786 L
.96986 .60198 L
.96691 .61169 L
.9639 .62141 L
.96134 .6297 L
.96093 .63112 L
.958 .64083 L
.95498 .65054 L
.95196 .66026 L
.95163 .66132 L
.94903 .66997 L
.946 .67968 L
.94295 .68939 L
.94192 .69271 L
.94 .69911 L
.93696 .70882 L
.93388 .71853 L
.93221 .72387 L
.93089 .72824 L
.92785 .73796 L
.92475 .74767 L
.92249 .7548 L
.92172 .75738 L
.91868 .76709 L
.91556 .77681 L
.91278 .7855 L
.91247 .78652 L
.90943 .79623 L
.9063 .80594 L
.90317 .81566 L
.90307 .81597 L
.90012 .82537 L
.89697 .83508 L
.89381 .84479 L
.89336 .8462 L
.89073 .85451 L
.88756 .86422 L
.88438 .87393 L
.88364 .87619 L
.88128 .88364 L
.87809 .89336 L
.87487 .90307 L
.87393 .90594 L
.87174 .91278 L
.86853 .92249 L
.86529 .93221 L
.86422 .93545 L
.86213 .94192 L
.8589 .95163 L
.85563 .96134 L
.85451 .96472 L
.85244 .97106 L
.84918 .98077 L
.98077 .98077 L
F
0 g
.98077 .56579 m
.97641 .57284 L
.97479 .58256 L
.97258 .59227 L
.97106 .59786 L
.96986 .60198 L
.96691 .61169 L
.9639 .62141 L
.96134 .6297 L
.96093 .63112 L
.958 .64083 L
.95498 .65054 L
.95196 .66026 L
.95163 .66132 L
.94903 .66997 L
.946 .67968 L
.94295 .68939 L
.94192 .69271 L
.94 .69911 L
.93696 .70882 L
.93388 .71853 L
.93221 .72387 L
.93089 .72824 L
.92785 .73796 L
.92475 .74767 L
.92249 .7548 L
.92172 .75738 L
.91868 .76709 L
.91556 .77681 L
.91278 .7855 L
.91247 .78652 L
.90943 .79623 L
.9063 .80594 L
.90317 .81566 L
.90307 .81597 L
.90012 .82537 L
.89697 .83508 L
.89381 .84479 L
.89336 .8462 L
.89073 .85451 L
.88756 .86422 L
.88438 .87393 L
.88364 .87619 L
.88128 .88364 L
.87809 .89336 L
.87487 .90307 L
.87393 .90594 L
.87174 .91278 L
.86853 .92249 L
.86529 .93221 L
Mistroke
.86422 .93545 L
.86213 .94192 L
.8589 .95163 L
.85563 .96134 L
.85451 .96472 L
.85244 .97106 L
.84918 .98077 L
Mfstroke
.6 g
.98077 .58506 m
.97825 .59227 L
.97549 .60198 L
.97269 .61169 L
.97106 .61719 L
.96978 .62141 L
.96679 .63112 L
.96381 .64083 L
.96134 .64911 L
.96091 .65054 L
.95791 .66026 L
.9549 .66997 L
.95196 .67968 L
.95163 .68079 L
.94897 .68939 L
.94594 .69911 L
.94294 .70882 L
.94192 .71226 L
.93997 .71853 L
.93692 .72824 L
.93388 .73796 L
.93221 .74349 L
.9309 .74767 L
.92783 .75738 L
.92476 .76709 L
.92249 .7745 L
.92177 .77681 L
.91868 .78652 L
.91559 .79623 L
.91278 .80527 L
.91257 .80594 L
.90947 .81566 L
.90635 .82537 L
.90329 .83508 L
.90307 .83581 L
.90019 .84479 L
.89704 .85451 L
.89395 .86422 L
.89336 .86612 L
.89083 .87393 L
.88766 .88364 L
.88453 .89336 L
.88364 .89619 L
.88141 .90307 L
.87821 .91278 L
.87505 .92249 L
.87393 .92602 L
.87191 .93221 L
.86869 .94192 L
.8655 .95163 L
.86422 .95562 L
.86233 .96134 L
.85908 .97106 L
.85587 .98077 L
.98077 .98077 L
F
0 g
.98077 .58506 m
.97825 .59227 L
.97549 .60198 L
.97269 .61169 L
.97106 .61719 L
.96978 .62141 L
.96679 .63112 L
.96381 .64083 L
.96134 .64911 L
.96091 .65054 L
.95791 .66026 L
.9549 .66997 L
.95196 .67968 L
.95163 .68079 L
.94897 .68939 L
.94594 .69911 L
.94294 .70882 L
.94192 .71226 L
.93997 .71853 L
.93692 .72824 L
.93388 .73796 L
.93221 .74349 L
.9309 .74767 L
.92783 .75738 L
.92476 .76709 L
.92249 .7745 L
.92177 .77681 L
.91868 .78652 L
.91559 .79623 L
.91278 .80527 L
.91257 .80594 L
.90947 .81566 L
.90635 .82537 L
.90329 .83508 L
.90307 .83581 L
.90019 .84479 L
.89704 .85451 L
.89395 .86422 L
.89336 .86612 L
.89083 .87393 L
.88766 .88364 L
.88453 .89336 L
.88364 .89619 L
.88141 .90307 L
.87821 .91278 L
.87505 .92249 L
.87393 .92602 L
.87191 .93221 L
.86869 .94192 L
.8655 .95163 L
Mistroke
.86422 .95562 L
.86233 .96134 L
.85908 .97106 L
.85587 .98077 L
Mfstroke
.7 g
.98077 .60529 m
.97881 .61169 L
.97594 .62141 L
.97303 .63112 L
.97106 .6375 L
.97001 .64083 L
.96692 .65054 L
.96385 .66026 L
.96134 .6695 L
.9612 .66997 L
.9581 .67968 L
.95499 .68939 L
.95214 .69911 L
.95163 .70126 L
.94922 .70882 L
.94608 .71853 L
.94309 .72824 L
.94192 .73281 L
.94027 .73796 L
.93711 .74767 L
.93403 .75738 L
.93221 .76413 L
.93125 .76709 L
.92808 .77681 L
.92494 .78652 L
.92249 .79522 L
.92217 .79623 L
.91899 .80594 L
.91581 .81566 L
.91295 .82537 L
.91278 .82608 L
.90982 .83508 L
.90661 .84479 L
.90364 .85451 L
.90307 .85671 L
.90059 .86422 L
.89735 .87393 L
.89429 .88364 L
.89336 .88711 L
.89128 .89336 L
.88802 .90307 L
.88489 .91278 L
.88364 .91727 L
.8819 .92249 L
.87862 .93221 L
.87544 .94192 L
.87393 .9472 L
.87244 .95163 L
.86914 .96134 L
.86592 .97106 L
.86422 .97691 L
.86291 .98077 L
.98077 .98077 L
F
0 g
.98077 .60529 m
.97881 .61169 L
.97594 .62141 L
.97303 .63112 L
.97106 .6375 L
.97001 .64083 L
.96692 .65054 L
.96385 .66026 L
.96134 .6695 L
.9612 .66997 L
.9581 .67968 L
.95499 .68939 L
.95214 .69911 L
.95163 .70126 L
.94922 .70882 L
.94608 .71853 L
.94309 .72824 L
.94192 .73281 L
.94027 .73796 L
.93711 .74767 L
.93403 .75738 L
.93221 .76413 L
.93125 .76709 L
.92808 .77681 L
.92494 .78652 L
.92249 .79522 L
.92217 .79623 L
.91899 .80594 L
.91581 .81566 L
.91295 .82537 L
.91278 .82608 L
.90982 .83508 L
.90661 .84479 L
.90364 .85451 L
.90307 .85671 L
.90059 .86422 L
.89735 .87393 L
.89429 .88364 L
.89336 .88711 L
.89128 .89336 L
.88802 .90307 L
.88489 .91278 L
.88364 .91727 L
.8819 .92249 L
.87862 .93221 L
.87544 .94192 L
.87393 .9472 L
.87244 .95163 L
.86914 .96134 L
.86592 .97106 L
Mistroke
.86422 .97691 L
.86291 .98077 L
Mfstroke
.8 g
.98077 .62966 m
.98036 .63112 L
.97763 .64083 L
.97477 .65054 L
.97166 .66026 L
.97106 .662 L
.96808 .66997 L
.96576 .67968 L
.9628 .68939 L
.96134 .69413 L
.95954 .69911 L
.95532 .70882 L
.95395 .71853 L
.95163 .72606 L
.95085 .72824 L
.94691 .73796 L
.94505 .74767 L
.94204 .75738 L
.94192 .75776 L
.9383 .76709 L
.93608 .77681 L
.93306 .78652 L
.93221 .78922 L
.92955 .79623 L
.92495 .80594 L
.92402 .81566 L
.92249 .82047 L
.92067 .82537 L
.91633 .83508 L
.91491 .84479 L
.91278 .8515 L
.91167 .85451 L
.90752 .86422 L
.90574 .87393 L
.90307 .88231 L
.90258 .88364 L
.89857 .89336 L
.89651 .90307 L
.89339 .91278 L
.89336 .91289 L
.88948 .92249 L
.88721 .93221 L
.88407 .94192 L
.88364 .94322 L
.88027 .95163 L
.87784 .96134 L
.87468 .97106 L
.87393 .97337 L
.87096 .98077 L
.98077 .98077 L
F
0 g
.98077 .62966 m
.98036 .63112 L
.97763 .64083 L
.97477 .65054 L
.97166 .66026 L
.97106 .662 L
.96808 .66997 L
.96576 .67968 L
.9628 .68939 L
.96134 .69413 L
.95954 .69911 L
.95532 .70882 L
.95395 .71853 L
.95163 .72606 L
.95085 .72824 L
.94691 .73796 L
.94505 .74767 L
.94204 .75738 L
.94192 .75776 L
.9383 .76709 L
.93608 .77681 L
.93306 .78652 L
.93221 .78922 L
.92955 .79623 L
.92495 .80594 L
.92402 .81566 L
.92249 .82047 L
.92067 .82537 L
.91633 .83508 L
.91491 .84479 L
.91278 .8515 L
.91167 .85451 L
.90752 .86422 L
.90574 .87393 L
.90307 .88231 L
.90258 .88364 L
.89857 .89336 L
.89651 .90307 L
.89339 .91278 L
.89336 .91289 L
.88948 .92249 L
.88721 .93221 L
.88407 .94192 L
.88364 .94322 L
.88027 .95163 L
.87784 .96134 L
.87468 .97106 L
.87393 .97337 L
.87096 .98077 L
s
.7 g
.98077 .72259 m
.9791 .72824 L
.97615 .73796 L
.97315 .74767 L
.97106 .75444 L
.97014 .75738 L
.96714 .76709 L
.965 .77681 L
.96134 .78604 L
.96119 .78652 L
.95817 .79623 L
.95636 .80594 L
.95228 .81566 L
.95163 .81744 L
.94913 .82537 L
.94771 .83508 L
.94335 .84479 L
.94192 .84861 L
.94004 .85451 L
.93903 .86422 L
.93437 .87393 L
.93221 .87953 L
.93088 .88364 L
.9278 .89336 L
.92534 .90307 L
.92249 .91022 L
.92166 .91278 L
.91855 .92249 L
.91623 .93221 L
.91278 .94065 L
.91237 .94192 L
.90922 .95163 L
.90705 .96134 L
.90307 .97085 L
.903 .97106 L
.89983 .98077 L
.98077 .98077 L
F
0 g
.98077 .72259 m
.9791 .72824 L
.97615 .73796 L
.97315 .74767 L
.97106 .75444 L
.97014 .75738 L
.96714 .76709 L
.965 .77681 L
.96134 .78604 L
.96119 .78652 L
.95817 .79623 L
.95636 .80594 L
.95228 .81566 L
.95163 .81744 L
.94913 .82537 L
.94771 .83508 L
.94335 .84479 L
.94192 .84861 L
.94004 .85451 L
.93903 .86422 L
.93437 .87393 L
.93221 .87953 L
.93088 .88364 L
.9278 .89336 L
.92534 .90307 L
.92249 .91022 L
.92166 .91278 L
.91855 .92249 L
.91623 .93221 L
.91278 .94065 L
.91237 .94192 L
.90922 .95163 L
.90705 .96134 L
.90307 .97085 L
.903 .97106 L
.89983 .98077 L
s
.6 g
.98077 .74694 m
.98055 .74767 L
.97765 .75738 L
.97469 .76709 L
.97143 .77681 L
.97106 .77893 L
.96907 .78652 L
.96601 .79623 L
.96286 .80594 L
.96134 .8107 L
.9601 .81566 L
.95711 .82537 L
.95394 .83508 L
.95163 .84223 L
.95103 .84479 L
.94813 .85451 L
.94495 .86422 L
.94192 .87354 L
.94183 .87393 L
.93908 .88364 L
.9359 .89336 L
.93271 .90307 L
.93221 .90462 L
.92995 .91278 L
.92679 .92249 L
.92356 .93221 L
.92249 .93547 L
.92074 .94192 L
.9176 .95163 L
.91435 .96134 L
.91278 .96608 L
.91145 .97106 L
.90833 .98077 L
.98077 .98077 L
F
0 g
.98077 .74694 m
.98055 .74767 L
.97765 .75738 L
.97469 .76709 L
.97143 .77681 L
.97106 .77893 L
.96907 .78652 L
.96601 .79623 L
.96286 .80594 L
.96134 .8107 L
.9601 .81566 L
.95711 .82537 L
.95394 .83508 L
.95163 .84223 L
.95103 .84479 L
.94813 .85451 L
.94495 .86422 L
.94192 .87354 L
.94183 .87393 L
.93908 .88364 L
.9359 .89336 L
.93271 .90307 L
.93221 .90462 L
.92995 .91278 L
.92679 .92249 L
.92356 .93221 L
.92249 .93547 L
.92074 .94192 L
.9176 .95163 L
.91435 .96134 L
.91278 .96608 L
.91145 .97106 L
.90833 .98077 L
s
.5 g
.98077 .76717 m
.97596 .77681 L
.97427 .78652 L
.9719 .79623 L
.97106 .79924 L
.96909 .80594 L
.96611 .81566 L
.9631 .82537 L
.96134 .83108 L
.96017 .83508 L
.9572 .84479 L
.95417 .85451 L
.95163 .8627 L
.95119 .86422 L
.94823 .87393 L
.94519 .88364 L
.94215 .89336 L
.94192 .89409 L
.9392 .90307 L
.93614 .91278 L
.93307 .92249 L
.93221 .92526 L
.9301 .93221 L
.92703 .94192 L
.92393 .95163 L
.92249 .95619 L
.92092 .96134 L
.91785 .97106 L
.91473 .98077 L
.98077 .98077 L
F
0 g
.98077 .76717 m
.97596 .77681 L
.97427 .78652 L
.9719 .79623 L
.97106 .79924 L
.96909 .80594 L
.96611 .81566 L
.9631 .82537 L
.96134 .83108 L
.96017 .83508 L
.9572 .84479 L
.95417 .85451 L
.95163 .8627 L
.95119 .86422 L
.94823 .87393 L
.94519 .88364 L
.94215 .89336 L
.94192 .89409 L
.9392 .90307 L
.93614 .91278 L
.93307 .92249 L
.93221 .92526 L
.9301 .93221 L
.92703 .94192 L
.92393 .95163 L
.92249 .95619 L
.92092 .96134 L
.91785 .97106 L
.91473 .98077 L
s
.4 g
.98077 .78644 m
.98074 .78652 L
.9775 .79623 L
.97476 .80594 L
.97193 .81566 L
.97106 .81858 L
.96899 .82537 L
.966 .83508 L
.96303 .84479 L
.96134 .85049 L
.96012 .85451 L
.95711 .86422 L
.9541 .87393 L
.95163 .88218 L
.95118 .88364 L
.94817 .89336 L
.94513 .90307 L
.94217 .91278 L
.94192 .91364 L
.93916 .92249 L
.9361 .93221 L
.93309 .94192 L
.93221 .94488 L
.93009 .95163 L
.92701 .96134 L
.92396 .97106 L
.92249 .97588 L
.92096 .98077 L
.98077 .98077 L
F
0 g
.98077 .78644 m
.98074 .78652 L
.9775 .79623 L
.97476 .80594 L
.97193 .81566 L
.97106 .81858 L
.96899 .82537 L
.966 .83508 L
.96303 .84479 L
.96134 .85049 L
.96012 .85451 L
.95711 .86422 L
.9541 .87393 L
.95163 .88218 L
.95118 .88364 L
.94817 .89336 L
.94513 .90307 L
.94217 .91278 L
.94192 .91364 L
.93916 .92249 L
.9361 .93221 L
.93309 .94192 L
.93221 .94488 L
.93009 .95163 L
.92701 .96134 L
.92396 .97106 L
.92249 .97588 L
.92096 .98077 L
s
.3 g
.98077 .80667 m
.97805 .81566 L
.97518 .82537 L
.97224 .83508 L
.97106 .83888 L
.9692 .84479 L
.9661 .85451 L
.96308 .86422 L
.96134 .87088 L
.96038 .87393 L
.95727 .88364 L
.95419 .89336 L
.95163 .90265 L
.9515 .90307 L
.94839 .91278 L
.94526 .92249 L
.9424 .93221 L
.94192 .93419 L
.93944 .94192 L
.93628 .95163 L
.93328 .96134 L
.93221 .96551 L
.93042 .97106 L
.92724 .98077 L
.98077 .98077 L
F
0 g
.98077 .80667 m
.97805 .81566 L
.97518 .82537 L
.97224 .83508 L
.97106 .83888 L
.9692 .84479 L
.9661 .85451 L
.96308 .86422 L
.96134 .87088 L
.96038 .87393 L
.95727 .88364 L
.95419 .89336 L
.95163 .90265 L
.9515 .90307 L
.94839 .91278 L
.94526 .92249 L
.9424 .93221 L
.94192 .93419 L
.93944 .94192 L
.93628 .95163 L
.93328 .96134 L
.93221 .96551 L
.93042 .97106 L
.92724 .98077 L
s
.2 g
.98077 .83103 m
.97964 .83508 L
.97689 .84479 L
.97398 .85451 L
.97106 .8634 L
.97077 .86422 L
.967 .87393 L
.96498 .88364 L
.96201 .89336 L
.96134 .89552 L
.95852 .90307 L
.95394 .91278 L
.95316 .92249 L
.95163 .92743 L
.94989 .93221 L
.94566 .94192 L
.94425 .95163 L
.94192 .95914 L
.94113 .96134 L
.93715 .97106 L
.93528 .98077 L
.98077 .98077 L
F
0 g
.98077 .83103 m
.97964 .83508 L
.97689 .84479 L
.97398 .85451 L
.97106 .8634 L
.97077 .86422 L
.967 .87393 L
.96498 .88364 L
.96201 .89336 L
.96134 .89552 L
.95852 .90307 L
.95394 .91278 L
.95316 .92249 L
.95163 .92743 L
.94989 .93221 L
.94566 .94192 L
.94425 .95163 L
.94192 .95914 L
.94113 .96134 L
.93715 .97106 L
.93528 .98077 L
s
.3 g
.98077 .92396 m
.97832 .93221 L
.97536 .94192 L
.97235 .95163 L
.97106 .95582 L
.96934 .96134 L
.96634 .97106 L
.9639 .98077 L
.98077 .98077 L
F
0 g
.98077 .92396 m
.97832 .93221 L
.97536 .94192 L
.97235 .95163 L
.97106 .95582 L
.96934 .96134 L
.96634 .97106 L
.9639 .98077 L
s
.4 g
.98077 .94833 m
.97979 .95163 L
.97687 .96134 L
.9739 .97106 L
.97106 .98031 L
.97096 .98077 L
.98077 .98077 L
F
0 g
.98077 .94833 m
.97979 .95163 L
.97687 .96134 L
.9739 .97106 L
.97106 .98031 L
.97096 .98077 L
s
.5 g
.98077 .96856 m
.98003 .97106 L
.97556 .98077 L
.98077 .98077 L
F
0 g
.98077 .96856 m
.98003 .97106 L
.97556 .98077 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00`_ooool2o`0000;ooooo0_l0
002Pooooo`00`_ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgJ3ooooo0033ooooo`04omgMgOl0
003o410@olc<c:7ooooo0033ooooo`04onk^k_lQ8B7o410@onk^kZ7ooooo0033ooooo`04ob4Q8Omg
MgOoMgMgoc8b<Z7ooooo0032ooooo`;o00000_ooool2o`000:3ooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0011oooo
o`;o000000?o410@ooooooooool08oooool5o`00023ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0T
ooooo`Go00009_ooool2o`000003oa0@4?oooooooooo02?ooooo00Gok^k^oc8b<_l0003o410@olc<
c00Tooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`08Oooool4o`000008oa0@4?ooooooooooonk^k_lb
<S;o0000oc8b<_o^k^h3ooooo`00@_ooool00ol0003oooooooooo`0Tooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@08?ooool01OmgMgOoV9RHoooooonHV9SoMgMg02Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A00Wooooo`03o`000?oooooooooo02Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@0Tooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B408oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00oooool003Oooooo1_l00002ooooo`Go00007Oooool6o`0000?ooooo00?oV9RHob4Q
8Oo^k^h08Oooool01Ol@413ooooooooooooooooo410@02Gooooo00?oV9RHob4Q8Oo^k^h09Oooool5
o`0002Gooooo00Go0000ooooooooooooooooo`00000Tooooo`05o`000?ooooooooooooooool00000
8oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool003oooooo
00CoA4A4omgMgOoooooo0000:?ooool00onHV9So8B4Qonk^kP0Pooooo`05o`000?oooooooooooooo
ool000009_ooool00onHV9So8B4Qonk^kP0Tooooo`04odA4A?oMgMgoooooo`0002Kooooo00Go0000
oiRHV?ooooooV9RHob4Q8@0Tooooo`05oc8b<_nHV9SooooooiRHV?lb<S808oooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool003oooooo00CogMgMoeEEEOoooooo
0000:Oooool00omgMgOoIVIVooooo`0Oooooo`05o`000?ooooooooooooooool000009oooool00omg
MgOoIVIVooooo`0Sooooo`04omgMgOmEEEGoooooo`0002Kooooo00Go0000oeEEEOl0003o410@olc<
c00Tooooo`05olc<c?l0003o0000o`000?o<c<`08oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000000oooool0043ooooo00?oMgMgolc<c?l00000:_ooool00ol0003ooooo
ooooo`0Nooooo`05oa0@4?ooooooooooooooool@4100:?ooool00ol0003oooooooooo`0Sooooo`03
ogMgMoo<c<co000002Kooooo00?oEEEEohN7Qoooool09_ooool01Ol@413o^[Zjoooooonj^[[o410@
02?ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo0010oooo
o`03onk^k_m4A4Co000002Kooooo00Go0000okZj^_ooooooV9RHoa0@400Pooooo`05ogMgMonHV9So
oooooiRHV?mgMgL09?ooool01Ol0003o^[ZjoooooonHV9So410@02Gooooo00?ok^k^odA4A?l00000
9_ooool00ooMgMgo410@oiRHV00Vooooo`05o`000?nj^[[ooooookZj^_l000008oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool0047ooooo00?oMgMgo`000?oo
ool09Oooool01OnHV9So410@o`000?lQ8B7oc<c<023ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0T
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`09_ooool00omgMgOo0000ooooo`0Vooooo`04olc<c?m4
A4Co0000oa0@42Cooooo00GoZJVYoa0@4?l0003o410@ojVYZ@0Qooooo`03oeEEEOmVIVKo000000Co
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`009?ooooooo`0004?o00000_ooool002Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`7o00000Oooool1ooooo`009?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo0Ol00001ooooo`7ooooo000T
ooooo`03o`000?oooooooooo0?oooooo?oooool1o`00007ooooo0Oooool002Cooooo00?o0000oooo
ooooool0ooooooloooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`3oooooocoo
oooo0Ol00001ooooo`7ooooo000Tooooo`;o00004?ooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00oooool01?l0003oooooooooool00003ooooo`04o`000?oooooooooo
o`0000?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`06o`000?oooooo
ooooo`000?oooooo00000_ooool01Ol0003ooooooooooooooooo000000Sooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooo`000002ooooo`04o`000?ooooooooooo`0000Sooooo00Co0000
oooooooooooo00000_ooool01Ol0003oooooo`000?oooooo000000;ooooo00?o0000ooooooooool0
1_ooool02_l0003oooooooooool0003oooooo`000?oooooo0000ooooool00002ooooo`03o`000?oo
oooooooo00Kooooo00Wo0000ooooool0003oooooo`000?oooooo0000ooooool000001_ooool2o`00
00;ooooo000Tooooo`03o`000?oooooooooo00?ooooo2onIVIT00ol0003o/k>cok>c/`0Gok>c/`03
o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0<ofIVIP03
o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`04ogmoO`03
o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<04onc/k<00ol0003oVIVIoiVIV@02oiVIV@05
o`000?moOgooOgmoogmoOol000001?mVIVH00ol0003oC4a<oda<C003oda<C003o`000?lc<c?o<c<c
00Co<c<c00?o0000oda<C?m<C4`00om<C4`01?l0003oIVIVofIVI_l00002ogmoO`05o`000?nIVIWo
VIVIoiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c003o`000?nc/k?o/k>c00;o/k>c00Ko
0000oiVIVOnIVIWo0000ogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01?l0
003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<
c<`01?l0003o/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o
<c<coc<c<`06oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c
00?o0000olc<c?o<c<`01_o<c<`02_l0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<
C4`6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`[oVIVI00?o0000
ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000
ofIVI_mVIVH03?mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00[oIVIV00?o0000
ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o0000
oiVIVOnIVIT00onIVIT01?l0003oOgmoogmoOol00004ofIVIP03o`000?m<C4coC4a<00CoC4a<00?o
0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C002oda<C005o`000?mVIVKoIVIVofIVI_l00000
0_moOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc
/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`00
0008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Go0000ogmoOol0003oVIVIo`000003ok>c/`03
o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT01ol0003oOgmoo`000?mVIVKo
0000oda<C?l000002Olc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o
/k>co`0000Woc<c<00[o0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<1_ooool1
o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool9oiVIV@03o`000?nc/k?o/k>c
01Oo/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV
00coIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0:ofIVIP03o`000?moOgooOgmo
00GoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`0Cok>c/`03o`000?nIVIWoVIVI
00;oVIVI00Go0000ogmoOomoOgooOgmoo`000004ofIVIP03o`000?m<C4coC4a<00?oC4a<00?o0000
oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C003oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Go
0000oiVIVOnIVIWoVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o0000ok>c/onc/k<0
0_nc/k<01_l0003oVIVIoiVIVOl0003oOgmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008
oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT01Ol0003o/k>cok>c
/onc/k?o000000Soc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<
C4`00ol0003o<c<coc<c<`07oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000
00;o/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003o/k>co`000002oiVIV@;o000000GoIVIVo`00
0?m<C4coC4a<o`000005ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03oooo
o`SoVIVI0_l0000Hok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0
003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0
003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<04onc/k<00ol0
003oVIVIoiVIV@02oiVIV@03o`000?moOgooOgmo00;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000006
oda<C003o`000?lc<c?o<c<c00?o<c<c00?o0000oda<C?m<C4`00om<C4`01Ol0003oIVIVofIVI_mV
IVKo000000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<
00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Go0000oda<
C?m<C4coC4a<o`000008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nI
VIT01?l0003o/k>cok>c/ol00008olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Go0000ogmoOol0
003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00co0000oda<C?m<C4co0000ofIVI_l0
003oOgmoo`000?nIVIWo0000ok>c/ol00009olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`00
0?mVIVKo000000;oC4a<00?o0000ooooooooool00oooool1o`00007ooooo0Oooool002Cooooo00?o
0000ooooooooool00oooool7oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02onI
VIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00coIVIV00?o0000oda<C?m<C4`05_m<
C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00CoOgmo00?o0000oiVIVOnIVIT01OnI
VIT00ol0003o/k>cok>c/`0Cok>c/`03o`000?nIVIWoVIVI00;oVIVI00?o0000ogmoOomoOgl00_mo
Ogl01Ol0003oIVIVofIVI_mVIVKo000000GoC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<
oda<C003oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01Ol0003oVIVIoiVIVOnIVIWo0000
00?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Ko0000
ogmoOomoOgoo0000ofIVI_l00004oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co
00000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Co0000ok>c
/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc
<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Woc<c<00Wo
0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003oooooooooo`03oooo
o`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`KoVIVI00?o0000ok>c/onc
/k<05onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mV
IVH02omVIVH2o`0001SoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`04ogmoO`03
o`000?nIVIWoVIVI00GoVIVI00?o0000ok>c/onc/k<04onc/k<00ol0003oVIVIoiVIV@02oiVIV@03
o`000?moOgooOgmo00;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000005oda<C003o`000?lc<c?o<c<c
00Co<c<c00?o0000oda<C?m<C4`00om<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Go0000
oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Goc<c<00Go0000ok>c/onc/k?o/k>c
o`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c
<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol0
0009olc<c003o`000?nc/k?o000000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`00
0?lc<c?o<c<c00Oo<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl000000_nc/k<0
0ol0003oc<c<olc<c006olc<c003o`000?nc/k?o/k>c00;o000000OoOgmoo`000?mVIVKoIVIVo`00
0?m<C4co000000Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo1_nI
VIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00[oVIVI0_l0000:ogmoO`03o`000?mV
IVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`2o`0000coIVIV0_l00007ogmoO`03o`000?nI
VIWoVIVI00CoVIVI00?o0000ok>c/onc/k<05?nc/k<00ol0003oVIVIoiVIV@02oiVIV@05o`000?mo
OgooOgmoogmoOol000001?mVIVH00ol0003oC4a<oda<C003oda<C003o`000?lc<c?o<c<c00Co<c<c
00?o0000oda<C?m<C4`00om<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Co0000oiVIVOnI
VIWo00001?nc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT0
1?l0003oOgmoogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01?l0003oC4a<
oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`00ol0
003o/k>co`000002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07
oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<
c<`01_o<c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003o`000?oo
oooooooo00Cooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo1OnIVIT0
0ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00[oVIVI00?o0000ogmoOomoOgl02OmoOgl0
0ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH03?mVIVH0
0ol0003oOgmoogmoO`06ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<04onc/k<0
0ol0003oVIVIoiVIV@03oiVIV@05o`000?moOgooOgmoogmoOol000001?mVIVH00ol0003oC4a<oda<
C003oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00om<C4`01?l0003oIVIVofIV
I_l00003ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o
/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01Ol0003oC4a<oda<C?m<
C4co000000So<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`00
0?nc/k?o/k>co`0000Woc<c<00Go0000ok>c/ol0003oVIVIo`000002ogmoO`03o`000?mVIVKo0000
00;oC4a<00?o0000oc<c<olc<c<01olc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVI
o`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000
ofIVI_l000000_m<C4`00ol0003oooooooooo`04ooooo`7o00000Oooool1ooooo`009?ooool00ol0
003oooooooooo`03ooooo`CoVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVI
V@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<
C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl01_moOgl00ol0003oVIVIoiVIV@04oiVI
V@03o`000?nc/k?o/k>c01Co/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo
000000CoIVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4co
C4a<00?oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c
00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomo
Ogoo00000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Co0000oda<C?m<C4co00000_mV
IVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Woc<c<00?o0000ok>c/ol00000
0_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01olc<c<02Ol0003o
C4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Ko
0000ok>c/ol0003oVIVIo`000?moOgl2o`0000;oC4a<00?o0000oc<c<oooool01Oooool1o`00007o
oooo0Oooool002Cooooo00?o0000ooooooooool00oooool3oiVIV@03o`000?nc/k?o/k>c01Ko/k>c
00?o0000oiVIVOnIVIT02_nIVIT2o`0000[oOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<
oda<C00Foda<C0;o00003OmVIVH00ol0003oOgmoogmoO`05ogmoO`;o00001_nIVIT00ol0003o/k>c
ok>c/`0Dok>c/`03o`000?nIVIWoVIVI00;oVIVI00?o0000ogmoOomoOgl00_moOgl01Ol0003oIVIV
ofIVI_mVIVKo000000KoC4a<00?o0000oc<c<olc<c<00olc<c<00ol0003oC4a<oda<C003oda<C005
o`000?mVIVKoIVIVofIVI_l000000omoOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<co
c<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mV
IVKoIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;o
IVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00008olc<c004o`000?nc/k?o/k>c
o`0000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00[o
0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006
olc<c005o`000?nc/k?o/k>co`000?nIVIT00_l000001_mVIVKo0000oda<C?m<C4co0000oc<c<`Ko
oooo0Ol00001ooooo`7ooooo000Tooooo`;o00001?ooool2oiVIV@03o`000?nc/k?o/k>c01Ko/k>c
00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV
00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?moOgooOgmo00KoOgmo
00?o0000oiVIVOnIVIT01OnIVIT00ol0003o/k>cok>c/`0Dok>c/`03o`000?nIVIWoVIVI00;oVIVI
00?o0000ogmoOomoOgl00_moOgl01Ol0003oIVIVofIVI_mVIVKo000000KoC4a<00?o0000oc<c<olc
<c<00olc<c<00ol0003oC4a<oda<C003oda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01?l0
003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<0
1?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000;oC4a<00?o0000oc<c<olc<c<0
1_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c
/`03o`000?o<c<coc<c<00Ooc<c<00Co0000ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mV
IVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?mo
Ogoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o0000oiVI
V@02o`000006ofIVI_l0003oC4a<oda<C?l0003o<c<c1Oooool2o`0000;ooooo000Tooooo`03o`00
0?oooooooooo00?ooooo00?oVIVIo`000?nc/k<05onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`00
0?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`00
0?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl01_moOgl00ol0003oVIVIoiVIV@05oiVIV@03o`00
0?nc/k?o/k>c01Co/k>c00?o0000oiVIVOnIVIT00_nIVIT00ol0003oOgmoogmoO`02ogmoO`05o`00
0?mVIVKoIVIVofIVI_l000001_m<C4`00ol0003o<c<coc<c<`03oc<c<`03o`000?m<C4coC4a<00?o
C4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000
olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo0000
0_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH00ol0
003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Woc<c<00[o0000ok>c/onc/k?o0000oiVI
VOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`07oc<c<`07o`000?m<C4co0000
ofIVI_l0003oOgmoo`000002oiVIV@03o`000?nc/k?o000000Soc<c<00Go0000ok>c/onc/k?o0000
oiVIV@02o`000005ofIVI_l0003oC4a<oda<C?l000000_lc<c<6ooooo`7o00000Oooool1ooooo`00
9?ooool00ol0003oooooooooo`03ooooo`03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT0
2onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`0
5_m<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?moOgooOgmo00KoOgmo00?o0000oiVIVOnIVIT0
1OnIVIT2o`0001Go/k>c00?o0000oiVIVOnIVIT00_nIVIT00ol0003oOgmoogmoO`02ogmoO`03o`00
0?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`00
0?m<C4coC4a<00?oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVI
VOl000000onc/k<2o`0000Ooc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgoo
Ogmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`07o`000?m<C4coC4a<oda<C?l0
003oIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`0
1_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<c
oc<c<`06oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o
0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/ol0003oVIVI00;o000000GoIVIVo`000?m<C4co
C4a<o`000002oc<c<`Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo
6?nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH0
2omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV0_l00008ogmoO`03o`00
0?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc/k<04onc/k<00ol0003oVIVIoiVIV@03oiVIV@03o`00
0?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C003oda<C003o`00
0?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00om<C4`01Ol0003oIVIVofIVI_mVIVKo000000;o
Ogmo00Go0000oiVIVOnIVIWoVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c
/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<
o`000008oc<c<`07o`000?m<C4coC4a<oda<C?l0003oIVIVo`000002ogmoO`04o`000?nIVIWoVIVI
o`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo
00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0:o`000?m<C4coC4a<o`000?mV
IVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c
/ol0003oVIVI00;o000000GoIVIVo`000?m<C4coC4a<o`000002oc<c<`Kooooo0Ol00001ooooo`7o
oooo000Tooooo`03o`000?oooooooooo00?ooooo5onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`00
0?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`00
0?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@05oiVIV@03o`00
0?nc/k?o/k>c01Co/k>c00?o0000oiVIVOnIVIT00_nIVIT00ol0003oOgmoogmoO`02ogmoO`03o`00
0?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`00
0?m<C4coC4a<00?oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVI
VOl000000onc/k<00ol0003oc<c<olc<c006olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVI
VOnIVIWo00000_moOgl00ol0003oIVIVo`000003oda<C003o`000?lc<c?o<c<c00Oo<c<c00Co0000
oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<
00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c
<olc<c<01olc<c<01Ol0003oC4a<o`000?mVIVKo000000;oOgmo0_l00002ok>c/`03o`000?o<c<co
c<c<00Koc<c<00Go0000ok>c/onc/k?o0000oiVIV@02o`0000;oIVIV00?o0000oda<C?l000000olc
<c<6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03oooooaGo/k>c0_l0000=
oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00F
oda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@05
oiVIV@03o`000?nc/k?o/k>c01Co/k>c00?o0000oiVIVOnIVIT00onIVIT01Ol0003oOgmoogmoOomo
Ogoo000000CoIVIV00?o0000oda<C?m<C4`01?m<C4`00ol0003o<c<coc<c<`03oc<c<`03o`000?m<
C4coC4a<00?oC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`04o`000?nIVIWoVIVIo`0000Co
/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmo
OomoOgoo00000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Oo0000oda<C?m<C4coC4a<
o`000?mVIVKo000000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c006
o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o
<c<c00Oo<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003o
c<c<olc<c006olc<c005o`000?nc/k?o/k>co`000?nIVIT00_l00002ofIVIP03o`000?m<C4co0000
00?o<c<c1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00ooooolDok>c/`03
o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl02?moOgl2o`0000coIVIV00?o0000oda<C?m<
C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP;o00002OmoOgl00ol0003oVIVIoiVIV@05oiVIV@03
o`000?nc/k?o/k>c01Go/k>c00?o0000oiVIVOnIVIT00onIVIT01Ol0003oOgmoogmoOomoOgoo0000
00CoIVIV00?o0000oda<C?m<C4`01?m<C4`00ol0003o<c<coc<c<`03oc<c<`03o`000?m<C4coC4a<
00?oC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o
0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo
00000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Oo0000oda<C?m<C4coC4a<o`000?mV
IVKo000000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c006o`000?nc
/k?o/k>co`000?nIVIWo00000_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo
<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<
c006olc<c005o`000?nc/k?o/k>co`000?nIVIT00_l00002ofIVIP03o`000?m<C4co000000?o<c<c
1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00ooooolCok>c/`03o`000?nI
VIWoVIVI00_oVIVI0_l0000:ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<
C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT01_nI
VIT00ol0003o/k>cok>c/`0Dok>c/`03o`000?nIVIWoVIVI00?oVIVI00Go0000ogmoOomoOgooOgmo
o`000004ofIVIP03o`000?m<C4coC4a<00CoC4a<00?o0000oc<c<olc<c<00olc<c<00ol0003oC4a<
oda<C003oda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01Ol0003oVIVIoiVIVOnIVIWo0000
00?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000
ogmoOomoOgoo00000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Oo0000oda<C?m<C4co
C4a<o`000?mVIVKo000000;oOgmo00?o0000oiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<
c004o`000?nc/k?o/k>co`0000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc
<c?o<c<c00Oo<c<c00?o0000oda<C?l000000_mVIVH2o`000005oiVIVOl0003o/k>cok>c/ol00000
2?o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000Co<c<c
1_ooool1o`00007ooooo0Oooool001_ooooo0_l000000ol@413oooooooooo`04ooooo`03o`000?oo
oooooooo00?ooooo4_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o
0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o
0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c01Co/k>c00?o
0000oiVIVOnIVIT00onIVIT01Ol0003oOgmoogmoOomoOgoo000000CoIVIV00?o0000oda<C?m<C4`0
1Om<C4`00ol0003o<c<coc<c<`02oc<c<`03o`000?m<C4coC4a<00CoC4a<00Go0000ofIVI_mVIVKo
IVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0003oc<c<olc<c005olc<
c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l0
0003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH01_l0003oOgmo
ogmoOol0003oVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01_l0003o/k>cok>c/ol0003o
VIVIo`0000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0:o`000?m<
C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`0
3?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000Co<c<c1_ooool1
o`00007ooooo0Oooool001cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03oooo
oa7o/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV
00_oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0:ofIVIP;o00002_moOgl00ol0
003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c01Co/k>c00?o0000oiVIVOnIVIT00onIVIT01Ol0
003oOgmoogmoOomoOgoo000000CoIVIV00?o0000oda<C?m<C4`01?m<C4`00ol0003o<c<coc<c<`03
oc<c<`03o`000?m<C4coC4a<00CoC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`05o`000?nI
VIWoVIVIoiVIVOl000001?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c
00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c
00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH01_l0003oOgmoogmoOol0003oVIVIo`0000;o/k>c
00?o0000olc<c?o<c<`01oo<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00?o0000ofIV
I_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmo
Ool0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`03?l0003o/k>cok>c/ol0003oVIVI
o`000?moOgoo0000ofIVI_l0003oC4a<o`0000Co<c<c1_ooool1o`00007ooooo0Oooool0017ooooo
1_l00002ooooo`Go00001_ooool3o`0000?ooooo4?nc/k<00ol0003oVIVIoiVIV@0;oiVIV@;o0000
2_moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH0
2_mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc/k<0
5?nc/k<00ol0003oVIVIoiVIV@03oiVIV@03o`000?moOgooOgmo00;oOgmo00Go0000ofIVI_mVIVKo
IVIVo`000007oda<C003o`000?lc<c?o<c<c00;o<c<c00?o0000oda<C?m<C4`01?m<C4`01Ol0003o
IVIVofIVI_mVIVKo000000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<co
c<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mV
IVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP04
o`000?moOgooOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01?l0003o/k>cok>c/onc
/k<2o`0000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`03o`000?m<
C4coC4a<00;o000000OoOgmoo`000?nIVIWoVIVIo`000?nc/k?o000000Soc<c<00co0000ok>c/onc
/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00005oc<c<`Cooooo0ol00002ooooo`00
6Oooool01?m4A4CogMgMooooool00007ooooo`03o`000?oooooooooo00?ooooo3onc/k<00ol0003o
VIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003o
C4a<oda<C00Foda<C0;o00003?mVIVH00ol0003oOgmoogmoO`08ogmoO`;o00002?nIVIT00ol0003o
/k>cok>c/`0Dok>c/`03o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003o
IVIVofIVIP02ofIVIP03o`000?m<C4coC4a<00CoC4a<00?o0000oc<c<olc<c<00olc<c<00ol0003o
C4a<oda<C003oda<C004o`000?mVIVKoIVIVofIVIP;o00000_moOgl01Ol0003oVIVIoiVIVOnIVIWo
000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/onc/k<2o`0000;oVIVI00Co
0000ogmoOomoOgoo00000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Co0000oda<C?m<
C4co00000_mVIVH01_l0003oOgmoogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01oo<
c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o
<c<coc<c<`06oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c
00?o0000olc<c?o<c<`01_o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0
003oC4a<o`0000Go<c<c1_ooool1o`00007ooooo0Oooool001Wooooo00CogMgMoeEEEOoooooo0000
1oooool00ol0003oooooooooo`03ooooo`ko/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003oOgmo
ogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIV
ofIVIP0:ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT01onIVIT00ol0003o/k>c
ok>c/`0Dok>c/`03o`000?nIVIWoVIVI00;oVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIV
ofIVIP02ofIVIP03o`000?m<C4coC4a<00CoC4a<00?o0000oc<c<olc<c<00olc<c<00ol0003oC4a<
oda<C003oda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01Ol0003oVIVIoiVIVOnIVIWo0000
00?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000?oVIVI00Co0000
ogmoOomoOgoo00000_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`04o`000?m<C4coC4a<o`0000;o
IVIV00Ko0000ogmoOomoOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Ko0000
ok>c/onc/k?o0000oiVIVOl00002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<0
1_lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<
c<coc<c<00Koc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l0
0005oc<c<`Kooooo0Ol00001ooooo`7ooooo000Jooooo`03ogMgMoo<c<co000000Oooooo00?o0000
ooooooooool00oooool=ok>c/`03o`000?nIVIWoVIVI00_oVIVI0_l0000:ogmoO`03o`000?mVIVKo
IVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0:ofIVIP03o`000?moOgoo
Ogmo00WoOgmo00?o0000oiVIVOnIVIT01onIVIT00ol0003o/k>cok>c/`0Dok>c/`03o`000?nIVIWo
VIVI00?oVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP02ofIVIP03o`000?m<C4co
C4a<00CoC4a<00?o0000oc<c<olc<c<00olc<c<00ol0003oC4a<oda<C003oda<C005o`000?mVIVKo
IVIVofIVI_l000000omoOgl01Ol0003oVIVIoiVIVOnIVIWo000000?o/k>c00?o0000olc<c?o<c<`0
1_o<c<`01Ol0003o/k>cok>c/onc/k?o000000?oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01Ol0
003oC4a<oda<C?m<C4co000000So<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP05o`000?mo
Ogoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c006o`000?nc/k?o/k>co`000?nI
VIWo00000_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Go0000oda<
C?l0003oIVIVo`000002ogmoO`;o00000_nc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o
/k>co`0000;oVIVI0_l000001OmVIVKo0000oda<C?m<C4co000000Go<c<c1_ooool1o`00007ooooo
0Oooool001[ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`03ooooo`co/k>c00?o
0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o
0000oda<C?m<C4`05_m<C4`2o`0000coIVIV00?o0000ogmoOomoOgl02?moOgl2o`0000WoVIVI00?o
0000ok>c/onc/k<05?nc/k<00ol0003oVIVIoiVIV@03oiVIV@03o`000?moOgooOgmo00;oOgmo00?o
0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C005oda<C003o`000?lc<c?o<c<c00;o<c<c00?o
0000oda<C?m<C4`01?m<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Co0000oiVIVOnIVIWo
00001?nc/k<00ol0003oc<c<olc<c005olc<c0;o00000onc/k<01?l0003oVIVIoiVIVOl00002ogmo
O`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<
C4co000000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00009olc<c008o`00
0?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP03o`000?m<C4co000000[o<c<c00Wo0000
oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c00<
o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co00001_lc<c<6ooooo`7o
00000Oooool1ooooo`006oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo00?ooooo
3?nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH0
2omVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00[oIVIV00?o0000ogmoOomoOgl0
2OmoOgl00ol0003oVIVIoiVIV@07oiVIV@03o`000?nc/k?o/k>c01Go/k>c00?o0000oiVIVOnIVIT0
0onIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`0
1Om<C4`00ol0003o<c<coc<c<`02oc<c<`03o`000?m<C4coC4a<00CoC4a<00Go0000ofIVI_mVIVKo
IVIVo`000003ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0
003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo00000om<
C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH00ol0003oOgmo
o`000002oiVIV@04o`000?nc/k?o/k>co`0000Woc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003o
Ogmoo`0000;oIVIV00?o0000oda<C?l000002_lc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0
003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o0000ok>c/ol000000_nIVIT01ol0
003oOgmoo`000?mVIVKo0000oda<C?l000001_lc<c<6ooooo`7o00000Oooool1ooooo`009?ooool0
0ol0003oooooooooo`03ooooo`_o/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09
ogmoO`03o`000?mVIVKoIVIV00[oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0;
ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02?nIVIT00ol0003o/k>cok>c/`0D
ok>c/`03o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl00omoOgl01Ol0003oIVIVofIVI_mV
IVKo000000OoC4a<00?o0000oc<c<olc<c<00_lc<c<00ol0003oC4a<oda<C005oda<C004o`000?mV
IVKoIVIVo`0000?oOgmo00Go0000oiVIVOnIVIWoVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Ko
c<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIV
o`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Go
0000ogmoOol0003oVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o
00000_nIVIT00ol0003oOgmoo`000002ofIVIP03o`000?m<C4co000000Wo<c<c00[o0000oda<C?m<
C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c005olc<c004o`00
0?nc/k?o/k>co`0000;oVIVI00Co0000ogmoOol0003oIVIV0_l00007oc<c<`Kooooo0Ol00001oooo
o`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo2_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03
o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003
o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@08oiVIV@03
o`000?nc/k?o/k>c01Co/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`03ogmoO`03
o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01Om<C4`00ol0003o<c<coc<c<`02oc<c<`03
o`000?m<C4coC4a<00CoC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`04o`000?nIVIWoVIVI
o`0000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWo
VIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`00
0?m<C4coC4a<oda<C?l000000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`00
00Woc<c<00Co0000ok>c/onc/k?o00000_nIVIT2o`0000;oIVIV00Co0000oda<C?m<C4co00002Olc
<c<00ol0003oC4a<o`000002ofIVIP;o000000GoVIVIo`000?nc/k?o/k>co`000008olc<c00<o`00
0?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co00001olc<c<6ooooo`7o0000
0Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`Wo/k>c00?o0000oiVIVOnIVIT02onI
VIT00ol0003oOgmoogmoO`08ogmoO`;o00003OmVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mV
IVKoIVIV00[oIVIV0_l0000:ogmoO`03o`000?nIVIWoVIVI00WoVIVI00?o0000ok>c/onc/k<05?nc
/k<00ol0003oVIVIoiVIV@03oiVIV@03o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH00_mV
IVH00ol0003oC4a<oda<C006oda<C005o`000?lc<c?o<c<coc<c<ol000001_m<C4`01Ol0003oIVIV
ofIVI_mVIVKo000000?oOgmo00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<
00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKo
IVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV
00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00008olc<c009o`000?nc/k?o/k>cok>c
/ol0003oVIVIo`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<02_l0003oC4a<
oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Wo
0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVH00_l00008oc<c<`Kooooo0Ol00001oooo
o`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo2?nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03
o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH03?mVIVH00ol0003oC4a<oda<C00Foda<C003
o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@09oiVIV@03
o`000?nc/k?o/k>c01Go/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`02ogmoO`03
o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01_m<C4`01Ol0003o<c<coc<c<olc<c?o0000
00KoC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc
/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo0000
0_moOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<
C4coC4a<o`000002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`0
2Ol0003o/k>cok>c/onc/k?o0000oiVIVOl0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`00
00Oo<c<c00_o0000oda<C?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c/`03
o`000?o<c<coc<c<00Koc<c<00Wo0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVH00_l0
0008oc<c<`Kooooo0Ol00001ooooo`7ooooo000Tooooo`;o00001?ooool7ok>c/`03o`000?nIVIWo
VIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP;o00006?m<C4`0
0ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02OnIVIT0
0ol0003o/k>cok>c/`0Eok>c/`03o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl00_moOgl0
0ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<00GoC4a<00Go0000oc<c<olc<c?o<c<co`00
0006oda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01Ol0003oVIVIoiVIVOnIVIWo000000Co
/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`00
00;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`07oc<c<`04o`000?m<C4co
C4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00008olc<c009o`00
0?nc/k?o/k>cok>c/ol0003oVIVIo`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc
<c<02?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo00000_nIVIT00ol0003o/k>co`000008olc<
c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co00002?lc<c<5oooo
o`;o00000_ooool002Cooooo00?o0000ooooooooool00oooool6ok>c/`03o`000?nIVIWoVIVI00[o
VIVI0_l0000:ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`2o`0000co
IVIV0_l00009ogmoO`;o00002onIVIT00ol0003o/k>cok>c/`0Eok>c/`03o`000?nIVIWoVIVI00?o
VIVI00?o0000ogmoOomoOgl00_moOgl2o`0000CoIVIV00?o0000oda<C?m<C4`01Om<C4`01Ol0003o
<c<coc<c<olc<c?o000000OoC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`04o`000?nIVIWo
VIVIo`0000Go/k>c00?o0000olc<c?o<c<`01?o<c<`2o`0000Co/k>c00Co0000oiVIVOnIVIWo0000
0_moOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Oo0000oda<C?m<
C4coC4a<o`000?mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo00000_nc/k<00ol0003oc<c<olc<
c006olc<c009o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000?moOgoo000000;oIVIV00Co0000oda<
C?m<C4co00002?lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c
/`03o`000?o<c<coc<c<00Koc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo
0000oda<C?l00008oc<c<`03o`000?oooooooooo00?ooooo0Ol00001ooooo`7ooooo000Tooooo`03
o`000?oooooooooo00?ooooo1Onc/k<00ol0003oVIVIoiVIV@0:oiVIV@03o`000?moOgooOgmo00Wo
Ogmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00co
IVIV00?o0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Co
/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00?o
IVIV00?o0000oda<C?m<C4`01Om<C4`01Ol0003o<c<coc<c<olc<c?o000000KoC4a<00?o0000ofIV
I_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000;oVIVI00?o0000ok>c/onc/k<00onc/k<0
0ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Co0000oiVIVOnIVIWo00000_mo
Ogl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Oo0000oda<C?m<C4co
C4a<o`000?mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo00000_nc/k<00ol0003oc<c<olc<c006
olc<c009o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000?moOgoo000000;oIVIV00Co0000oda<C?m<
C4co00002?lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03
o`000?o<c<coc<c<00Koc<c<00?o0000ok>c/onc/k<00_l00002ogmoO`05o`000?mVIVKo0000oda<
C?l000002?lc<c<00ol0003oooooooooo`03ooooo`7o00000Oooool1ooooo`009?ooool00ol0003o
ooooooooo`03ooooo`Co/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03
o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0<ofIVIP03
o`000?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Eok>c/`03
o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP03ofIVIP03
o`000?m<C4coC4a<00GoC4a<00Go0000oc<c<olc<c?o<c<co`000007oda<C005o`000?mVIVKoIVIV
ofIVI_l000000omoOgl01?l0003oVIVIoiVIVOl00005ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o
0000ok>c/onc/k<00onc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000?o
C4a<00?o0000oc<c<olc<c<01_lc<c<01ol0003oC4a<oda<C?m<C4co0000ofIVI_l000000_moOgl0
1?l0003oVIVIoiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Oo0000ok>c/onc/k?o/k>c
o`000?nIVIWo000000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`06
o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl2o`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`0
2_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c
00Go<c<c00?o0000ooooooooool01?ooool1o`00007ooooo0Oooool002Cooooo00?o0000oooooooo
ool00oooool3ok>c/`03o`000?nIVIWoVIVI00[oVIVI0_l0000:ogmoO`03o`000?mVIVKoIVIV00_o
IVIV00?o0000oda<C?m<C4`05_m<C4`2o`0000goIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003o
VIVIoiVIV@0:oiVIV@03o`000?nc/k?o/k>c01Go/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003o
OgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01_m<C4`01?l0003o
<c<coc<c<ol00007oda<C004o`000?mVIVKoIVIVofIVIP;o00000_moOgl01Ol0003oVIVIoiVIVOnI
VIWo000000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`05o`000?nI
VIWoVIVIoiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo
<c<c00Co0000oda<C?m<C4co00000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@04o`000?nc/k?o
/k>co`0000Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIVIP03o`00
0?m<C4co000000Wo<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc
/k<00ol0003oc<c<olc<c006olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIV
o`000?m<C4co00002?lc<c<00ol0003oooooooooo`04ooooo`7o00000Oooool1ooooo`009?ooool0
0ol0003oooooooooo`03ooooo`;o/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`09
ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0<
ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0E
ok>c/`03o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP03
ofIVIP03o`000?m<C4coC4a<00KoC4a<00Co0000oc<c<olc<c?o00001om<C4`01Ol0003oIVIVofIV
I_mVIVKo000000?oOgmo00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Go
c<c<00?o0000ok>c/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Co0000ofIV
I_mVIVKo00000_m<C4`00ol0003o<c<coc<c<`07oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Co
0000ogmoOomoOgoo00000_nIVIT01?l0003o/k>cok>c/ol00008olc<c004o`000?nc/k?o/k>co`00
00;oVIVI00?o0000ogmoOol000000_mVIVH00ol0003oC4a<o`000009oc<c<`0:o`000?m<C4coC4a<
o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003o
/k>co`000002oiVIV@07o`000?moOgoo0000ofIVI_l0003oC4a<o`000008oc<c<`03o`000?oooooo
oooo00Cooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo00?o/k>co`00
0?nIVIT03?nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<
C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVI
VOnIVIT02onIVIT00ol0003o/k>cok>c/`0Eok>c/`03o`000?nIVIWoVIVI00?oVIVI00?o0000ogmo
OomoOgl00_moOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<00KoC4a<00Co0000oc<c
<olc<c?o00001om<C4`01Ol0003oIVIVofIVI_mVIVKo000000CoOgmo00Co0000oiVIVOnIVIWo0000
1?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00?o/k>c00Co0000oiVIVOnIVIWo
00000_moOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<
C?m<C4co00000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<
00Go0000ok>c/onc/k?o/k>co`000002oiVIV@;o00000_mVIVH01?l0003oC4a<oda<C?l00008oc<c
<`04o`000?m<C4coC4a<o`0000;oIVIV0_l000001OnIVIWo0000ok>c/onc/k?o000000Soc<c<00So
0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV0_l00008oc<c<`03o`000?m<C4cooooo
00Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo00?o0000oiVIVOnI
VIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<
C4`05_m<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnI
VIT02onIVIT00ol0003o/k>cok>c/`0Dok>c/`;o00001OnIVIT00ol0003oOgmoogmoO`03ogmoO`03
o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01om<C4`00ol0003o<c<co`000008oda<C005
o`000?mVIVKoIVIVofIVI_l000000omoOgl01Ol0003oVIVIoiVIVOnIVIWo000000?o/k>c00?o0000
olc<c?o<c<`01_o<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co
0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`05oc<c<`05o`000?m<C4coC4a<oda<C?l0
00000_mVIVH01_l0003oOgmoogmoOol0003oVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`0
1?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co0000
2?lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<
c<coc<c<00Koc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l0
0008oc<c<`03o`000?m<C4cooooo00Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooo
oooo00?ooooo3OnIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000
oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP;o00002_moOgl00ol0003oVIVIoiVIV@0;
oiVIV@03o`000?nc/k?o/k>c01Go/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`03
ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01om<C4`00ol0003o<c<co`000007
oda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgooOgmoo`000003oiVIV@05o`000?nc
/k?o/k>cok>c/ol000001oo<c<`00ol0003o/k>cok>c/`03ok>c/`04o`000?nIVIWoVIVIo`0000;o
Ogmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<
oda<C?l000000_mVIVH01_l0003oOgmoogmoOol0003oVIVIo`0000?o/k>c00?o0000olc<c?o<c<`0
1_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<
C4co00001olc<c<01?l0003oC4a<oda<C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc
/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>co`000?nIVIT00_l00002ofIVIP03o`00
0?m<C4co000000So<c<c00?o0000oda<C?ooool01Oooool1o`00007ooooo0Oooool002Cooooo00?o
0000ooooooooool00oooool<oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omV
IVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02Omo
Ogl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Go/k>c00?o0000oiVIVOnIVIT01?nI
VIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`02Om<
C4`00ol0003oC4a<oda<C006oda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01Ol0003oVIVI
oiVIVOnIVIWo000000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04
o`000?nIVIWoVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`05
oc<c<`03o`000?m<C4coC4a<00;oC4a<00So0000ofIVI_mVIVKo0000ogmoOol0003oVIVIo`0000?o
/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo0000
00;oIVIV00Co0000oda<C?m<C4co00002?lc<c<02?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo
00000_nIVIT01?l0003o/k>cok>c/ol00007olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmo
Ool0003oIVIVo`000?m<C4co00002?lc<c<01?l0003oC4a<oda<C?l00005ooooo`7o00000Oooool1
ooooo`009?ooool00ol0003oooooooooo`03ooooo`_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0
003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0
003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05Onc/k<00ol0
003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00?oOgmo00?o0000ofIVI_mVIVH00_mVIVH2o`00
01?oC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001Onc
/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Co0000oiVIVOnIVIWo0000
0_moOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<
C4coC4a<o`000002ofIVIP06o`000?moOgooOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<
c007olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003
o`000?lc<c?o<c<c00Oo<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000
0_nc/k<00ol0003oc<c<olc<c006olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003o
IVIVo`000?m<C4co00002?lc<c<01?l0003oC4a<oda<C?l00005ooooo`7o00000Oooool1ooooo`00
9?ooool2o`0000Cooooo2_nIVIT00ol0003oOgmoogmoO`08ogmoO`;o00003?mVIVH00ol0003oC4a<
oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV0_l0000:ogmoO`03o`000?nIVIWoVIVI00_oVIVI
00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00;oOgmo
00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00Boda<C005o`000?mVIVKoIVIVofIVI_l0
00000omoOgl01Ol0003oVIVIoiVIVOnIVIWo000000Go/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0
003o/k>cok>c/`03ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo00000om<
C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01_l0003oOgmo
ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01oo<c<`01?l0003o/k>cok>c/ol00002
oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`0:o`000?m<
C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`0
3?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000So<c<c00Co0000
oda<C?m<C4co00001?ooool2o`0000;ooooo000Tooooo`03o`000?oooooooooo00?ooooo2?nIVIT2
o`0000[oOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKo
IVIV00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o
/k>c01Ko/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKo
IVIV00;oIVIV00?o0000oda<C?m<C4`04_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000CoOgmo00Co
0000oiVIVOnIVIWo00001Onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c
00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c
00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP06o`000?moOgooOgmoo`000?nIVIWo0000
0onc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOomo
Ogl00_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002
ogmoO`;o00000_nc/k<00ol0003oc<c<olc<c006olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000
ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<00ol0003oC4a<o`000006oooo
o`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`OoVIVI00?o0000ogmoOomo
Ogl02OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mV
IVH02omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc
/k<05_nc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00?oOgmo00?o0000ofIVI_mV
IVH00omVIVH00ol0003oC4a<oda<C00Aoda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomo
OgooOgmoo`000003oiVIV@03o`000?nc/k?o/k>c00;o/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0
003o/k>cok>c/`02ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01?l0003oIVIVofIVI_l0
0003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP03o`00
0?moOgoo000000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c004o`000?nc/k?o/k>co`00
00;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00[o0000
oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<
c00;o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4`00_l00007oc<c<`04
o`000?m<C4coC4a<o`0000Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?o
oooo1onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<
C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP;o00002_moOgl00ol0003oVIVIoiVIV@0;oiVIV@03
o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`03ogmoO`03
o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<C4`04Om<C4`00ol0003oIVIVofIVIP02ofIVIP05
o`000?moOgooOgmoogmoOol000000onIVIT00ol0003o/k>cok>c/`02ok>c/`03o`000?o<c<coc<c<
00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Co0000
ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l00000
0_mVIVH00ol0003oOgmoo`000002oiVIV@05o`000?nc/k?o/k>cok>c/ol000001oo<c<`01Ol0003o
/k>cok>c/onc/k?o000000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o
<c<c00Oo<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0
003oc<c<olc<c006olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<
C4co00002?lc<c<01?l0003oC4a<oda<C?l00006ooooo`7o00000Oooool1ooooo`009?ooool00ol0
003oooooooooo`03ooooo`GoVIVI0_l0000:ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<
C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVI
VOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`;o00001_nIVIT00ol0003oOgmoogmoO`03ogmo
O`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<C4`04_m<C4`01Ol0003oIVIVofIVI_mVIVKo
000000?oOgmo00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o
0000ok>c/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo
00000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0
003oOgmoogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Co0000ok>c/onc/k?o0000
0_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01olc<c<02_l0003o
C4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<
00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00008oc<c<`05o`00
0?m<C4coC4a<o`000?mVIVH01_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool0
0oooool4oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<
oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVI
oiVIV@0:oiVIV@;o00006?nc/k<00ol0003oVIVIoiVIV@05oiVIV@03o`000?moOgooOgmo00?oOgmo
00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00Boda<C005o`000?mVIVKoIVIVofIVI_l0
00000omoOgl01Ol0003oVIVIoiVIVOnIVIWo000000Go/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0
003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`00
0003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Ko0000oda<C?m<C4coC4a<o`000?mVIVH2o`000005
ogmoOol0003oVIVIoiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c006o`000?nc/k?o/k>c
o`000?nIVIWo00000_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00?o
0000oda<C?l000000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`0
1_o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000So<c<c
00Ko0000oda<C?m<C4co0000ofIVI_l00005ooooo`7o00000Oooool1ooooo`009?ooool00ol0003o
ooooooooo`03ooooo`CoVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03
o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`09ogmoO`03
o`000?nIVIWoVIVI00[oVIVI00?o0000ok>c/onc/k<06?nc/k<00ol0003oVIVIoiVIV@05oiVIV@03
o`000?moOgooOgmo00?oOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00Boda<C005
o`000?mVIVKoIVIVofIVI_l000000omoOgl01Ol0003oVIVIoiVIVOnIVIWo000000Go/k>c00?o0000
olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Go
0000ofIVI_mVIVKoIVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co
00000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Woc<c<00Ko0000
ok>c/onc/k?o0000oiVIVOl00002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<0
1_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0
003oc<c<olc<c006olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<
C4co00002?lc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000Gooooo0Ol00001ooooo`7ooooo000T
ooooo`03o`000?oooooooooo00?ooooo0_nIVIT2o`0000[oOgmo00?o0000ofIVI_mVIVH02omVIVH0
0ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00[oIVIV00?o0000ogmoOomoOgl02OmoOgl0
0ol0003oVIVIoiVIV@0:oiVIV@03o`000?nc/k?o/k>c01So/k>c00?o0000oiVIVOnIVIT01OnIVIT0
0ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<C4`04_m<C4`0
1Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Go0000oiVIVOnIVIWoVIVIo`000005ok>c/`03o`00
0?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`05
o`000?mVIVKoIVIVofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`07o`000?m<C4coC4a<
oda<C?l0003oIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000;o/k>c00?o0000olc<c?o<c<`0
1oo<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo00000_m<C4`0
0ol0003o<c<coc<c<`06oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVIV@04
o`000?nc/k?o/k>co`0000Ooc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo
0000oda<C?l00009oc<c<`05o`000?m<C4co0000ofIVI_l000001_ooool1o`00007ooooo0Oooool0
02Cooooo00?o0000ooooooooool00oooool00onIVIWo0000ogmoO`0:ogmoO`03o`000?mVIVKoIVIV
00_oIVIV00?o0000oda<C?m<C4`05_m<C4`2o`0000coIVIV00?o0000ogmoOomoOgl02?moOgl2o`00
00coVIVI00?o0000ok>c/onc/k<06?nc/k<00ol0003oVIVIoiVIV@05oiVIV@03o`000?moOgooOgmo
00?oOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00Boda<C003o`000?mVIVKoIVIV
00;oIVIV00Go0000ogmoOomoOgooOgmoo`000003oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000
olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`02ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_mo
Ogl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Oo<c<c00Co0000oda<C?m<C4co
00000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Woc<c<00Ko0000
ok>c/onc/k?o0000oiVIVOl00002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<0
1_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0
003oc<c<olc<c006olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<
C4co00002Olc<c<01Ol0003oC4a<o`000?l0003oOgmo00Kooooo0Ol00001ooooo`7ooooo000Toooo
o`03o`000?oooooooooo00?ooooo00?oVIVIo`000?moOgl02OmoOgl00ol0003oIVIVofIVIP0;ofIV
IP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`09ogmo
O`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@06oiVI
V@03o`000?moOgooOgmo00?oOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00Boda<
C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgooOgmoo`000003oiVIV@03o`000?nc/k?o
/k>c00?o/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`02ok>c/`05o`000?nIVIWo
VIVIoiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Oo<c<c
00Co0000oda<C?m<C4co00000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@04o`000?nc/k?o/k>c
o`0000Woc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`03o`000?mVIVKo000000;oC4a<
00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP05o`000?moOgoo0000oiVI
VOl000000_nc/k<00ol0003oc<c<olc<c006olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmo
Ool0003oIVIVo`000?m<C4co00002Olc<c<01Ol0003oC4a<o`000?l0003oOgmo00Kooooo0Ol00001
ooooo`7ooooo000Tooooo`;o00001?ooool00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV
00[oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo
00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI
00KoVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<
01?oC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000
ok>c/onc/k<00_nc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Co0000
oiVIVOnIVIWo00000omoOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c
00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Co0000ok>c
/onc/k?o00002?o<c<`01?l0003o/k>cok>c/onc/k<2o`0000?oOgmo00?o0000ofIVI_l000000_m<
C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV0_l00002oiVIV@03o`00
0?nc/k?o000000Woc<c<00?o0000ok>c/onc/k<00_l00002ogmoO`05o`000?mVIVKo0000oda<C?l0
00002?lc<c<00ol0003oC4a<oda<C002o`000003ogmoOooooooooooo00?ooooo0_l00002ooooo`00
9?ooool00ol0003oooooooooo`03ooooo`_oOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<
oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVI
oiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT01onIVIT00ol0003oOgmo
ogmoO`03ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<C4`04_m<C4`00ol0003oIVIV
ofIVIP02ofIVIP05o`000?moOgooOgmoogmoOol000000onIVIT00ol0003o/k>cok>c/`03ok>c/`03
o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo0000
00?oOgmo00Co0000ofIVI_mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4co
C4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Wo
c<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000
oc<c<olc<c<01olc<c<00ol0003oC4a<o`000002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc
/k<00ol0003oc<c<olc<c006olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIV
o`000?m<C4co00002Olc<c<01ol0003oC4a<o`000?mVIVKo0000ogmoOol000001Oooool1o`00007o
oooo0Oooool002Cooooo00?o0000ooooooooool00oooool9ogmoO`;o00003OmVIVH00ol0003oC4a<
oda<C00Foda<C003o`000?mVIVKoIVIV00[oIVIV0_l0000:ogmoO`03o`000?nIVIWoVIVI00_oVIVI
00?o0000ok>c/onc/k<05onc/k<2o`0000SoVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIV
ofIVIP03ofIVIP03o`000?m<C4coC4a<01?oC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`05
o`000?nIVIWoVIVIoiVIVOl000001Onc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c
00;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o
0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo
00000_nIVIT01?l0003o/k>cok>c/ol00008olc<c007o`000?nc/k?o/k>cok>c/ol0003oVIVIo`00
0002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01olc<c<00ol0003oC4a<o`00
0002ofIVIP07o`000?moOgoo0000oiVIVOl0003o/k>co`000009olc<c00<o`000?nc/k?o/k>co`00
0?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co00002Olc<c<01ol0003oC4a<o`000?mVIVKo0000
ogmoOol000001Oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool8ogmo
O`03o`000?mVIVKoIVIV00coIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIV
IP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Gok>c
/`03o`000?nIVIWoVIVI00SoVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIVIP03ofIV
IP03o`000?m<C4coC4a<01?oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`03o`000?nIVIWo
VIVI00;oVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o
/k>c00;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<
00?o0000oc<c<olc<c<01_lc<c<01ol0003oC4a<oda<C?m<C4co0000ofIVI_l000000omoOgl01?l0
003oVIVIoiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nI
VIT01_l0003oOgmoogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01olc<c<01Ol0003o
C4a<o`000?mVIVKo000000;oOgmo00Go0000oiVIVOl0003o/k>co`000009olc<c00<o`000?nc/k?o
/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co00002Olc<c<01ol0003oC4a<o`000?mV
IVKo0000ogmoOol000001Oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00ooo
ool7ogmoO`03o`000?mVIVKoIVIV00_oIVIV0_l0000Hoda<C003o`000?mVIVKoIVIV00_oIVIV00?o
0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o
0000oiVIVOnIVIT02?nIVIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o
0000oda<C?m<C4`04om<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Go0000oiVIVOnIVIWo
VIVIo`000005ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01Ol0003o
VIVIoiVIVOnIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`05
oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@05o`00
0?nc/k?o/k>cok>c/ol000001oo<c<`01ol0003o/k>cok>c/onc/k?o0000oiVIVOl000000_moOgl0
0ol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00?o0000oda<C?l000000_mVIVH0
1Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`03?l0003o/k>cok>c
/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000Wo<c<c00Oo0000oda<C?l0003oIVIV
o`000?moOgoo000000Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo
1_moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<0_l0000<ofIVIP;o0000
2OmoOgl2o`0000goVIVI00?o0000ok>c/onc/k<05onc/k<2o`0000WoVIVI00?o0000ogmoOomoOgl0
0omoOgl00ol0003oIVIVofIVIP04ofIVIP03o`000?m<C4coC4a<01;oC4a<00?o0000ofIVI_mVIVH0
0_mVIVH01Ol0003oOgmoogmoOomoOgoo000000?oVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003o
c<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01Ol0
003oIVIVofIVI_mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<
C4co000000;oIVIV00Ko0000ogmoOomoOgoo0000oiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Ko
c<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo00?o0000ofIVI_l000000_m<C4`0
0ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Go0000ogmoOol0003oVIVI
o`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmo
o`000?mVIVKo0000oda<C?l00009oc<c<`07o`000?m<C4co0000ofIVI_l0003oOgmoo`000006oooo
o`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`GoOgmo00?o0000ofIVI_mV
IVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomo
Ogl01omoOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnI
VIT02?nIVIT00ol0003oOgmoogmoO`04ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<
C4`04om<C4`00ol0003oIVIVofIVIP02ofIVIP05o`000?moOgooOgmoogmoOol000000_nIVIT00ol0
003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00_nc/k<01Ol0
003oVIVIoiVIVOnIVIWo000000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000003oda<C003o`000?lc
<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP06o`000?moOgooOgmoo`000?nI
VIWo00000onc/k<00ol0003oc<c<olc<c006olc<c007o`000?nc/k?o/k>cok>c/ol0003oVIVIo`00
0002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<
C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c00<
o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co00002Olc<c<01ol0003o
C4a<o`000?mVIVKo0000ogmoOol000001_ooool1o`00007ooooo0Oooool002Cooooo00?o0000oooo
ooooool00oooool4ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0
003oIVIVofIVIP0<ofIVIP03o`000?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0
003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00SoVIVI00?o0000ogmoOomoOgl01?moOgl00ol0
003oIVIVofIVIP04ofIVIP03o`000?m<C4coC4a<01;oC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0
003oOgmoogmoOomoOgoo000000?oVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c004
olc<c003o`000?nc/k?o/k>c00?o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01Ol0003oIVIVofIV
I_mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;o
IVIV00Ko0000ogmoOomoOgoo0000oiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Oo0000
ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo00000_m<C4`00ol0003o
<c<coc<c<`06oc<c<`03o`000?m<C4co000000;oIVIV00Go0000ogmoOol0003oVIVIo`000003ok>c
/`03o`000?o<c<coc<c<00Goc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo
00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nI
VIWo000000Gooooo0Ol00001ooooo`7ooooo000Iooooo`Go00001_ooool00ol0003oooooooooo`03
ooooo`?oOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C0;o00003OmVIVH0
0ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<2
o`0000WoVIVI00?o0000ogmoOomoOgl01?moOgl00ol0003oIVIVofIVIP04ofIVIP03o`000?m<C4co
C4a<01;oC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000?oVIVI00?o
0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Go
0000oiVIVOnIVIWoVIVIo`000002ogmoO`03o`000?mVIVKoIVIV00;o00000om<C4`00ol0003o<c<c
oc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH00ol0003oOgmoo`000002oiVIV@05
o`000?nc/k?o/k>cok>c/ol000002?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo
000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP05o`00
0?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c00:o`000?nc/k?o/k>co`00
0?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02Ol0003oC4a<
o`000?mVIVKo0000ogmoOol0003oVIVIo`000005ooooo`7o00000Oooool1ooooo`006Oooool01OnH
V9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool00oooool2ogmoO`03o`000?mVIVKo
IVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?moOgoo
Ogmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWo
VIVI00SoVIVI00?o0000ogmoOomoOgl01OmoOgl00ol0003oIVIVofIVIP04ofIVIP03o`000?m<C4co
C4a<01;oC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000?oVIVI00?o
0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Go
0000oiVIVOnIVIWoVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc
<c<01Olc<c<00ol0003oC4a<oda<C002oda<C006o`000?mVIVKoIVIVo`000?moOgoo00000_nIVIT0
1Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmo
o`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Co0000oda<C?m<C4co00000_mVIVH2o`00
00;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo
0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Wo0000oda<C?l0003oIVIVo`000?mo
Ogoo0000oiVIVOl000001Oooool1o`00007ooooo0Oooool0017ooooo1_l00003ooooo`03oiRHV?lQ
8B7ok^k^00Oooooo0ol00003ooooo`03ogmoOol0003oIVIV00coIVIV00?o0000oda<C?m<C4`05_m<
C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onI
VIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00WoVIVI00?o0000ogmoOomoOgl01?mo
Ogl00ol0003oIVIVofIVIP04ofIVIP03o`000?m<C4coC4a<01;oC4a<00?o0000ofIVI_mVIVH00_mV
IVH01Ol0003oOgmoogmoOomoOgoo000000?oVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<
olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`04
o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co
000000;oIVIV00?o0000ogmoOol000000onIVIT01?l0003o/k>cok>c/ol00008olc<c004o`000?nc
/k?o/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`03
o`000?m<C4co000000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<
00Koc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o
<c<coc<c<`06oc<c<`03o`000?m<C4coC4a<00;o000000CoOgmoo`000?nIVIWo00001?ooool3o`00
00;ooooo000Kooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool00oooool00ol0003o
IVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003o
OgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<2o`0000_o
VIVI00?o0000ogmoOomoOgl01?moOgl00ol0003oIVIVofIVIP04ofIVIP03o`000?m<C4coC4a<01;o
C4a<00?o0000ofIVI_mVIVH00_mVIVH00ol0003oOgmoogmoO`02ogmoO`05o`000?nIVIWoVIVIoiVI
VOl000001Onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Co0000oiVI
VOnIVIWo00000omoOgl01?l0003oIVIVofIVI_l00004oda<C003o`000?lc<c?o<c<c00Go<c<c00Go
0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Go0000ok>c/onc
/k?o/k>co`000008olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH0
0ol0003oC4a<o`00000:oc<c<`03o`000?m<C4co000000;oIVIV00Oo0000ogmoOol0003oVIVIo`00
0?nc/k?o000000Woc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<
C4`00ol0003o<c<coc<c<`06oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000
00Kooooo0Ol00001ooooo`7ooooo000Looooo`03ogMgMomVIVKooooo00Gooooo00?o0000oooooooo
ool00oooool=ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH2o`0000[o
Ogmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00[o
VIVI00?o0000ogmoOomoOgl01OmoOgl00ol0003oIVIVofIVIP04ofIVIP03o`000?m<C4coC4a<01;o
C4a<00?o0000ofIVI_mVIVH00_mVIVH00ol0003oOgmoogmoO`02ogmoO`04o`000?nIVIWoVIVIo`00
00Ko/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`04o`000?nIVIWoVIVI
o`0000?oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`05oc<c<`05o`000?m<
C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@05o`000?nc/k?o/k>cok>c
/ol000002?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV00?o0000
oda<C?l000002_lc<c<01Ol0003oC4a<o`000?mVIVKo000000;oOgmo00Go0000oiVIVOl0003o/k>c
o`000009olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co0000
2Olc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000006ooooo`7o00000Oooool1
ooooo`007Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo3?mVIVH00ol0
003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0
003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0
003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV00CoIVIV00?o0000oda<C?m<C4`04_m<C4`00ol0
003oIVIVofIVIP02ofIVIP03o`000?moOgooOgmo00;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000006
ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00onc/k<01?l0003oVIVIoiVIVOl0
0003ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<
oda<C002oda<C003o`000?mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003o
c<c<olc<c006olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0
003oC4a<oda<C?l00009oc<c<`03o`000?m<C4co000000;oIVIV00Go0000ogmoOol0003oVIVIo`00
0002ok>c/`03o`000?o<c<coc<c<00Koc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`00
0?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0:o`000?m<C4co0000ofIVI_l0003oOgmo
o`000?nIVIWo0000ok>c/`Kooooo0Ol00001ooooo`7ooooo000Iooooo`05o`000?nj^[[ooooooiRH
V?l@41001_ooool00ol0003oooooooooo`03ooooo`_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0
003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0
003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00[oVIVI00?o0000ogmoOomoOgl01OmoOgl00ol0
003oIVIVofIVIP04ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0
003oOgmoogmoOomoOgoo000000?oVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c004
olc<c003o`000?nc/k?o/k>c00;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`05o`000?mV
IVKoIVIVofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l0
00000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Woc<c<00Co0000
ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c
00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<
c?o<c<`01_o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`00
00Wo<c<c00[o0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>c1_ooool1o`00007o
oooo0Oooool001Wooooo00GoV9RHoa0@4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo00?o
oooo2_mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV0_l0000:ogmoO`03
o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0:oiVIV@03
o`000?moOgooOgmo00GoOgmo00?o0000ofIVI_mVIVH01?mVIVH00ol0003oC4a<oda<C00Coda<C003
o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgooOgmoo`000003oiVIV@03o`000?nc/k?o/k>c
00Co/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`02ok>c/`05o`000?nIVIWoVIVI
oiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00004oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go
0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Co0000ok>c/onc
/k?o00002Oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l000000om<
C4`00ol0003o<c<coc<c<`06oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl01Ol0003o
VIVIo`000?nc/k?o000000Woc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo
0000oda<C?l00009oc<c<`0;o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol0
00001Oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool9ofIVIP03o`00
0?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`00
0?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<2o`0000coVIVI00?o0000ogmoOomoOgl0
1OmoOgl00ol0003oIVIVofIVIP04ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH0
0_mVIVH01Ol0003oOgmoogmoOomoOgoo000000?oVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003o
c<c<olc<c004olc<c003o`000?nc/k?o/k>c00;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmo
O`05o`000?mVIVKoIVIVofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4co
C4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Wo
c<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIVIP05o`000?m<C4coC4a<
oda<C?l000002?lc<c<01Ol0003oC4a<o`000?mVIVKo000000;oOgmo00?o0000oiVIVOl000000_nc
/k<00ol0003oc<c<olc<c007olc<c00;o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000
oda<C?l000002Olc<c<00ol0003oC4a<o`000002ofIVIP;o000000GoVIVIo`000?nc/k?o/k>co`00
0005ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`SoIVIV00?o0000
oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000
oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000
ogmoOomoOgl01OmoOgl00ol0003oIVIVofIVIP04ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000
ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000CoVIVI00?o0000ok>c/onc/k<00onc
/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Go0000oiVIVOnIVIWoVIVI
o`000002ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003o
C4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01?l0003o/k>cok>c/ol0
0009olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<
oda<C?l00008oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl00ol0003oVIVIo`000002
ok>c/`03o`000?o<c<coc<c<00Koc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mV
IVKo0000oda<C?l00009oc<c<`0;o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c
/ol000001_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool7ofIVIP03
o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH2o`0000[oOgmo00?o0000oiVIVOnI
VIT02onIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00[oVIVI00?o0000ogmoOomo
Ogl01OmoOgl00ol0003oIVIVofIVIP05ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000ofIVI_mV
IVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000CoVIVI00?o0000ok>c/onc/k<00onc/k<00ol0
003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002
ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<
C?m<C4co000000;oIVIV00?o0000ogmoOol000000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Wo
c<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000;oC4a<00?o
0000oc<c<olc<c<01_lc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00?o0000oiVIVOl0
00000_nc/k<00ol0003oc<c<olc<c006olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0
003oIVIVo`000?m<C4co00002Olc<c<02ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`00
0?nc/k?o000000Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo1_mV
IVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02Omo
Ogl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c0_l0000<oiVIV@03o`000?mo
OgooOgmo00GoOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<C00Coda<C003o`000?mV
IVKoIVIV00;oIVIV00Go0000ogmoOomoOgooOgmoo`000004oiVIV@03o`000?nc/k?o/k>c00?o/k>c
00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`05o`000?nIVIWoVIVIoiVIVOl0
00000_moOgl01?l0003oIVIVofIVI_l00005oda<C003o`000?lc<c?o<c<c00Go<c<c00Go0000oda<
C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>c
o`000008olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003o
C4a<oda<C?l00008oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl00ol0003oVIVIo`00
0002ok>c/`03o`000?o<c<coc<c<00Koc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`00
0?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`03o`000?m<C4coC4a<00;o000000OoOgmo
o`000?nIVIWoVIVIo`000?nc/k?o000000Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oo
oooooooo00?ooooo1OmVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o
0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0:oiVIV@;o00006?nc/k<00ol0003oVIVIoiVI
V@0;oiVIV@03o`000?moOgooOgmo00GoOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<
C00Coda<C003o`000?mVIVKoIVIV00;oIVIV00?o0000ogmoOomoOgl00_moOgl01Ol0003oVIVIoiVI
VOnIVIWo000000Ko/k>c00?o0000olc<c?o<c<`00oo<c<`2o`0000Co/k>c00Go0000oiVIVOnIVIWo
VIVIo`000003ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0
003oC4a<oda<C002oda<C006o`000?mVIVKoIVIVo`000?moOgoo00000_nIVIT01?l0003o/k>cok>c
/onc/k<2o`0000Ooc<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo00?o0000ofIV
I_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_mo
Ogl01Ol0003oVIVIo`000?nc/k?o000000Woc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmo
o`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`09o`000?m<C4co0000ofIVI_l0003o
Ogmoo`000?nIVIWo000000;o/k>c00?o0000ooooooooool01?ooool1o`00007ooooo0Oooool002Co
oooo0_l00004ooooo`CoIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0:ofIVIP03
o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02_nIVIT00ol0003o/k>cok>c/`0Gok>c/`03
o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl01_moOgl00ol0003oIVIVofIVIP05ofIVIP03
o`000?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH00_mVIVH00ol0003oOgmoogmoO`02ogmoO`05
o`000?nIVIWoVIVIoiVIVOl000001_nc/k<00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c
00?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`05o`000?mVIVKoIVIVofIVI_l000001?m<
C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Ko0000ofIVI_mVIVKo0000
ogmoOol00002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01ol0003o/k>cok>c/onc/k?o
0000oiVIVOl000000_moOgl00ol0003oIVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Ko
0000oda<C?m<C4co0000ofIVI_l00002ogmoO`05o`000?nIVIWo0000ok>c/ol000002Oo<c<`02_l0
003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko
<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003ooooooooo
o`03ooooo`;o00000_ooool002Cooooo00?o0000ooooooooool00oooool3ofIVIP03o`000?m<C4co
C4a<01OoC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWo
VIVI00[oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgoo
Ogmo00KoOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<C00Coda<C003o`000?mVIVKo
IVIV00;oIVIV00?o0000ogmoOomoOgl00_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Ko/k>c00?o
0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`03ok>c/`03o`000?nIVIWoVIVI00;oVIVI00Co
0000ogmoOomoOgoo00000_mVIVH00ol0003oC4a<oda<C002oda<C003o`000?lc<c?o<c<c00Go<c<c
00?o0000oda<C?m<C4`00_m<C4`01_l0003oIVIVofIVI_l0003oOgmoo`0000;oVIVI00Go0000ok>c
/onc/k?o/k>co`000008olc<c007o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000002ogmoO`03o`00
0?mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP05
o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c00:o`000?nc/k?o/k>c
o`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01olc<c<2o`000004
ofIVI_l0003oOgmoogmoO`;o00000_nc/k<00ol0003oc<c<ooooo`05ooooo`7o00000Oooool1oooo
o`009?ooool00ol0003oooooooooo`03ooooo`;oIVIV00?o0000oda<C?m<C4`05_m<C4`2o`0000co
IVIV00?o0000ogmoOomoOgl02?moOgl2o`0000coVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003o
VIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0003o
C4a<oda<C00Coda<C003o`000?mVIVKoIVIV00?oIVIV00Go0000ogmoOomoOgooOgmoo`000004oiVI
V@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`03ok>c
/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000CoC4a<00?o
0000oc<c<olc<c<01Olc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo
00000_nIVIT01?l0003o/k>cok>c/ol00009olc<c007o`000?nc/k?o/k>cok>c/ol0003oVIVIo`00
0002ogmoO`03o`000?mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01_l0003oC4a<oda<
C?l0003oIVIVo`0000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c00:
o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<0
1_lc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<co
oooo00Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo00?oIVIVo`00
0?m<C4`06?m<C4`00ol0003oIVIVofIVIP0:ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVI
VOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmo
OomoOgl01omoOgl00ol0003oIVIVofIVIP05ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000ofIV
I_mVIVH00omVIVH01Ol0003oOgmoogmoOomoOgoo000000CoVIVI00?o0000ok>c/onc/k<01?nc/k<0
0ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c00?o/k>c00Go0000oiVIVOnIVIWoVIVIo`00
0002ogmoO`05o`000?mVIVKoIVIVofIVI_l000001?m<C4`00ol0003o<c<coc<c<`05oc<c<`05o`00
0?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@04o`000?nc/k?o/k>c
o`0000Woc<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo00?o0000ofIVI_l00000
0_m<C4`00ol0003o<c<coc<c<`07oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl00ol0
003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0
003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`09o`000?m<C4co0000ofIV
I_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?ooool01Oooool1o`00007ooooo0Ooo
ool002Cooooo00?o0000ooooooooool00oooool00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKo
IVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o
/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`07ogmoO`03o`000?mVIVKo
IVIV00GoIVIV00?o0000oda<C?m<C4`04om<C4`00ol0003oIVIVofIVIP03ofIVIP05o`000?moOgoo
OgmoogmoOol000001?nIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o
0000ok>c/onc/k<00onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Co0000ofIVI_mVIVKo
00001?m<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH00ol0
003oOgmoo`000002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002Oo<c<`01?l0003o/k>cok>c/ol0
0002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<02_l0003oC4a<
oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00co
0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00009oc<c<`0;o`000?m<
C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol000000_o<c<`6ooooo`7o00000Oooool1
ooooo`009?ooool00ol0003oooooooooo`03oooooaWoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0
003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0
003oVIVIoiVIV@0:oiVIV@03o`000?moOgooOgmo00OoOgmo00?o0000ofIVI_mVIVH01_mVIVH00ol0
003oC4a<oda<C00Boda<C003o`000?mVIVKoIVIV00CoIVIV00Go0000ogmoOomoOgooOgmoo`000004
oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03
ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000?oC4a<
00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomo
Ogoo00000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Oo0000ok>c/onc/k?o/k>co`00
0?nIVIWo000000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`06o`00
0?m<C4coC4a<o`000?mVIVKo00000_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<
00Koc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o
<c<coc<c<`06oc<c<`03o`000?m<C4co000000;oIVIV0_l000001OnIVIWo0000ok>c/onc/k?o0000
00;oc<c<1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00ooooolHoda<C003
o`000?mVIVKoIVIV00[oIVIV0_l0000:ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc
/k<05_nc/k<2o`0000goVIVI00?o0000ogmoOomoOgl01_moOgl00ol0003oIVIVofIVIP06ofIVIP03
o`000?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH00omVIVH01Ol0003oOgmoogmoOomoOgoo0000
00CoVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c
00Co/k>c00Co0000oiVIVOnIVIWo00000omoOgl01?l0003oIVIVofIVI_l00004oda<C003o`000?lc
<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;o
VIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Ko0000
ogmoOomoOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c00So0000oda<C?m<C4co
0000ofIVI_l0003oOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`03?l0003o/k>cok>c
/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000Wo<c<c00Wo0000oda<C?l0003oIVIV
o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006ooooo`7o00000Oooool1oooo
o`009?ooool00ol0003oooooooooo`03oooooaOoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003o
OgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003o
VIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo00OoOgmo00?o0000ofIVI_mVIVH01_mVIVH00ol0003o
C4a<oda<C00Coda<C003o`000?mVIVKoIVIV00?oIVIV00Go0000ogmoOomoOgooOgmoo`000004oiVI
V@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`04ok>c
/`04o`000?nIVIWoVIVIo`0000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc
<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;o
VIVI00Co0000ok>c/onc/k?o00002Oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@06o`000?moOgoo
Ogmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`07oc<c<`08o`000?m<C4coC4a<o`000?mV
IVKo0000ogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00co0000ok>c/onc/k?o0000
oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00009oc<c<`09o`000?m<C4co0000ofIVI_l0003o
Ogmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_ooool1o`00007ooooo0Oooool002Co
oooo00?o0000ooooooooool00ooooolFoda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomo
Ogl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnI
VIT02onIVIT00ol0003oOgmoogmoO`07ogmoO`03o`000?mVIVKoIVIV00KoIVIV00?o0000oda<C?m<
C4`04om<C4`00ol0003oIVIVofIVIP03ofIVIP03o`000?moOgooOgmo00;oOgmo00Go0000oiVIVOnI
VIWoVIVIo`000006ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<01?nc/k<01Ol0
003oVIVIoiVIVOnIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c
<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@05
o`000?nc/k?o/k>cok>c/ol000002?o<c<`01ol0003o/k>cok>c/onc/k?o0000oiVIVOl000000_mo
Ogl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Ko0000oda<C?m<C4co0000
ofIVI_l00002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02_l0003o
/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c
00?o0000oda<C?m<C4`00_l000001omoOgoo0000oiVIVOnIVIWo0000ok>c/ol000000oo<c<`6oooo
o`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03oooooaCoC4a<0_l0000<ofIVIP;o
00002OmoOgl2o`0000goVIVI00?o0000ok>c/onc/k<05_nc/k<2o`0000goVIVI00?o0000ogmoOomo
Ogl01omoOgl00ol0003oIVIVofIVIP05ofIVIP;o00005Om<C4`00ol0003oIVIVofIVIP03ofIVIP03
o`000?moOgooOgmo00;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000007ok>c/`03o`000?o<c<coc<c<
00?oc<c<00?o0000ok>c/onc/k<00onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Go0000
ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<
C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000;o/k>c00?o0000olc<c?o<
c<`01oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<
C?m<C4co00002Olc<c<02?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo00000_nIVIT00ol0003o
/k>co`000009olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<
00?o0000oc<c<olc<c<01_lc<c<02ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc
/k?o000000Coc<c<1_ooool1o`00007ooooo0Oooool002Cooooo0_l00004oooooa?oC4a<00?o0000
ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmoO`07ogmoO`03o`000?nIVIWoVIVI00coVIVI00?o0000
ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo00OoOgmo00?o0000
ofIVI_mVIVH01_mVIVH00ol0003oC4a<oda<C00Doda<C003o`000?mVIVKoIVIV00?oIVIV00?o0000
ogmoOomoOgl00_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Oo/k>c00?o0000olc<c?o<c<`00_o<
c<`00ol0003o/k>cok>c/`04ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01Ol0003oIVIV
ofIVI_mVIVKo000000CoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004
o`000?mVIVKoIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo00000_nc/k<00ol0003oc<c<olc<c007
olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<
C?l00009oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVIV@03o`000?nc/k?o
000000Woc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0
003o<c<coc<c<`05oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc
/k?o00001?o<c<`5ooooo`;o00000_ooool002Cooooo00?o0000ooooooooool00ooooolBoda<C003
o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@0<oiVIV@03
o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`07ogmoO`03
o`000?mVIVKoIVIV00KoIVIV00?o0000oda<C?m<C4`05?m<C4`00ol0003oIVIVofIVIP03ofIVIP03
o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`04ok>c/`03
o`000?o<c<coc<c<00;oc<c<00?o0000ok>c/onc/k<01?nc/k<01Ol0003oVIVIoiVIVOnIVIWo0000
00;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000
oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o
00002Oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<
C?m<C4co00002Olc<c<02?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo00000_nIVIT01?l0003o
/k>cok>c/ol00008olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;o
C4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<o`000?mVIVKo000000;oOgmo0_l00002ok>c
/`03o`000?o<c<coc<c<00;oc<c<1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000oooooooo
ool00ooooolAoda<C0;o00003OmVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_o
VIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@;o00002OmoOgl00ol0003o
IVIVofIVIP07ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH00_mVIVH00ol0003o
OgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003o
c<c<olc<c003olc<c003o`000?nc/k?o/k>c00Co/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmo
O`05o`000?mVIVKoIVIVofIVI_l000001?m<C4`00ol0003o<c<coc<c<`05oc<c<`05o`000?m<C4co
C4a<oda<C?l000000omVIVH01?l0003oOgmoogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Wo
c<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<
o`0000So<c<c00Wo0000oda<C?m<C4coC4a<o`000?mVIVKo0000ogmoOol000000_nIVIT01?l0003o
/k>cok>c/ol00008olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;o
C4a<00?o0000oc<c<olc<c<01_lc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`00
0002ok>c/`03o`000?o<c<coc<c<00;oc<c<1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000
ooooooooool00oooool@oda<C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl02?moOgl0
0ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT0
0ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00OoIVIV00?o0000oda<C?m<C4`05Om<C4`0
0ol0003oIVIVofIVIP02ofIVIP03o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00_nIVIT0
0ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<01?nc/k<0
1?l0003oVIVIoiVIVOl00003ogmoO`05o`000?mVIVKoIVIVofIVI_l000000om<C4`00ol0003o<c<c
oc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000omVIVH00ol0003oOgmoo`000002oiVIV@05
o`000?nc/k?o/k>cok>c/ol000002Oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo
000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<02Ol0003oC4a<oda<C?m<C4co0000ofIVI_l0
003oOgmoo`000002oiVIV@03o`000?nc/k?o000000Woc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0
003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`09o`000?m<C4co0000ofIV
I_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`00_o<c<`6ooooo`7o00000Ooo
ool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`ooC4a<00?o0000ofIVI_mVIVH03?mVIVH0
0ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<0
0ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH01_mVIVH0
0ol0003oC4a<oda<C00Eoda<C003o`000?mVIVKoIVIV00;oIVIV00?o0000ogmoOomoOgl00_moOgl0
0ol0003oVIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`00oo<c<`0
0ol0003o/k>cok>c/`04ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01Ol0003oIVIVofIV
I_mVIVKo000000CoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`00
0?mVIVKoIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo00000_nc/k<00ol0003oc<c<olc<c007olc<
c004o`000?nc/k?o/k>co`0000;oVIVI00Ko0000ogmoOomoOgoo0000ofIVI_l00002oda<C003o`00
0?lc<c?o<c<c00Ko<c<c00Wo0000oda<C?m<C4coC4a<o`000?mVIVKo0000ogmoOol000000_nIVIT0
1?l0003o/k>cok>c/ol00009olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000
00;oC4a<00?o0000oc<c<olc<c<01_lc<c<00ol0003oC4a<o`000002ofIVIP;o000000GoVIVIo`00
0?nc/k?o/k>co`000005olc<c0Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo
00?ooooo3_m<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVI
VOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmo
OomoOgl02OmoOgl00ol0003oIVIVofIVIP06ofIVIP03o`000?m<C4coC4a<01CoC4a<0_l00004ofIV
IP03o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`05ok>c
/`03o`000?o<c<coc<c<00;oc<c<00?o0000ok>c/onc/k<01?nc/k<01Ol0003oVIVIoiVIVOnIVIWo
000000?oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<
C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@05o`000?nc/k?o/k>cok>c
/ol000002?o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmoOol000000_mVIVH0
1?l0003oC4a<oda<C?l00008oc<c<`09o`000?m<C4coC4a<oda<C?l0003oIVIVo`000?moOgoo0000
00;oVIVI00?o0000ok>c/ol000002Oo<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000
ofIVI_l0003oC4a<o`0000Wo<c<c00Co0000oda<C?l0003oIVIV0ol000001OnIVIWo0000ok>c/onc
/k?o000000Goc<c<1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool=
oda<C003o`000?mVIVKoIVIV00_oIVIV0_l0000:ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000
ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000
ofIVI_mVIVH01omVIVH00ol0003oC4a<oda<C00Doda<C003o`000?mVIVKoIVIV00?oIVIV00?o0000
ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c00Go/k>c00?o0000
olc<c?o<c<`00_o<c<`00ol0003o/k>cok>c/`04ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omo
Ogl01?l0003oIVIVofIVI_l00004oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4co
C4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008
olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<
C4coC4a<o`0000So<c<c00Wo0000oda<C?m<C4coC4a<o`000?mVIVKo0000ogmoOol000000_nIVIT0
0ol0003o/k>co`000009olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`00
0?m<C4co00002Olc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c/`03
o`000?o<c<coc<c<00?oc<c<1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool0
0oooool<oda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVI
oiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmo
ogmoO`09ogmoO`03o`000?mVIVKoIVIV00OoIVIV00?o0000oda<C?m<C4`05?m<C4`00ol0003oIVIV
ofIVIP03ofIVIP03o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>c
ok>c/`04ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o0000ok>c/onc/k<01?nc/k<01Ol0003oVIVI
oiVIVOnIVIWo000000?oOgmo00Go0000ofIVI_mVIVKoIVIVo`000003oda<C003o`000?lc<c?o<c<c
00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Go
0000ok>c/onc/k?o/k>co`000008olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT00ol0003o
Ogmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Oo0000oda<C?m<C4coC4a<o`000?mV
IVKo000000;oOgmo00Go0000oiVIVOl0003o/k>co`000009olc<c00:o`000?nc/k?o/k>co`000?nI
VIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01ol0003oC4a<o`00
0?mVIVKo0000ogmoOol000000_nIVIT00ol0003o/k>co`000006olc<c0Kooooo0Ol00001ooooo`7o
oooo000Tooooo`03o`000?oooooooooo00?ooooo2om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`00
0?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`00
0?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP07ofIVIP03o`00
0?m<C4coC4a<01GoC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`02ogmoO`03o`00
0?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01Onc/k<01Ol0003oc<c<olc<c?o<c<co000000Oo
/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`05o`000?mVIVKoIVIVofIVI_l000001?m<C4`0
0ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_mo
Ogl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o
/k>co`000002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<01?l0
003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00?o0000ok>c/ol000002Oo<c<`0
2_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c
00Ko<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<
olc<c004olc<c0Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo2_m<
C4`00ol0003oIVIVofIVIP0;ofIVIP;o00002_moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc
/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mV
IVKoIVIV00SoIVIV00?o0000oda<C?m<C4`05?m<C4`00ol0003oIVIVofIVIP03ofIVIP03o`000?mo
OgooOgmo00?oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<
c<coc<c<00;oc<c<00?o0000ok>c/onc/k<01Onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo
00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<
C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000
olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmoOol000000_mV
IVH01?l0003oC4a<oda<C?l00008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol0
00000_nIVIT00ol0003o/k>co`000009olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0
003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmo
Ool0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Coc<c<1_ooool1o`00007ooooo0Oooool0
02Cooooo0_l00004ooooo`WoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`09ogmo
O`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<2o`0000coVIVI00?o0000ogmo
OomoOgl02?moOgl2o`0000[oIVIV00?o0000oda<C?m<C4`05?m<C4`00ol0003oIVIVofIVIP03ofIV
IP03o`000?moOgooOgmo00?oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`05ok>c
/`05o`000?o<c<coc<c<olc<c?l000001onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Go
0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`0
0_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<
c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmoOol000000_mVIVH0
1?l0003oC4a<oda<C?l00009oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVI
V@03o`000?nc/k?o000000Woc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo
00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4co0000ofIVI_l000000_moOgl2o`00
00;o/k>c00?o0000olc<c?o<c<`01Oo<c<`5ooooo`;o00000_ooool002Cooooo00?o0000oooooooo
ool00oooool8oda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003o
VIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003o
OgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00WoIVIV00?o0000oda<C?m<C4`05?m<C4`00ol0003o
IVIVofIVIP04ofIVIP03o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o
/k>cok>c/`05ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o0000ok>c/onc/k<01?nc/k<01Ol0003o
VIVIoiVIVOnIVIWo000000?oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`06
oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVI
VOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo0000
00;oOgmo00Co0000ofIVI_mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4co
C4a<o`0000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<
00[o0000ok>c/ol0003o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c
<`06oc<c<`06o`000?m<C4co0000ofIVI_l0003oOgmo0ol00002ok>c/`03o`000?o<c<coc<c<00Go
c<c<1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool7oda<C003o`00
0?mVIVKoIVIV00_oIVIV0_l0000:ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<0
5onc/k<00ol0003oVIVIoiVIV@0:oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH0
2?mVIVH00ol0003oC4a<oda<C00Eoda<C003o`000?mVIVKoIVIV00CoIVIV00?o0000ogmoOomoOgl0
0_moOgl00ol0003oVIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c00Go/k>c00Go0000olc<c?o<c<co
c<c<o`000007ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01?l0003oIVIVofIVI_l00004
oda<C003o`000?lc<c?o<c<c00Ko<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l0
0002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01ol0003o/k>c
ok>c/onc/k?o0000oiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00002oda<C003o`000?lc<c?o
<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c
00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000ofIV
I_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`00
0?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01Oo<c<`6ooooo`7o00000Oooool1ooooo`009?oo
ool00ol0003oooooooooo`03ooooo`KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmo
O`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<2o`0000coVIVI00?o
0000ogmoOomoOgl02?moOgl2o`0000_oIVIV00?o0000oda<C?m<C4`05?m<C4`00ol0003oIVIVofIV
IP04ofIVIP03o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c
/`05ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o0000ok>c/onc/k<01?nc/k<01Ol0003oVIVIoiVI
VOnIVIWo000000?oOgmo00Go0000ofIVI_mVIVKoIVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko
<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVI
o`0000?o/k>c00?o0000olc<c?o<c<`01oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?mo
Ogoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP03
o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`00ol0003o/k>co`000002oiVI
V@03o`000?moOgoo000000;oIVIV00?o0000oda<C?l000002?lc<c<02Ol0003oC4a<o`000?mVIVKo
0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<1_ooool1o`00007ooooo
0Oooool002Cooooo00?o0000ooooooooool00oooool5oda<C003o`000?mVIVKoIVIV00_oIVIV00?o
0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0:oiVIV@;o00006?nc/k<00ol0003oVIVIoiVI
V@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<oda<
C00Doda<C003o`000?mVIVKoIVIV00CoIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVI
V@02oiVIV@03o`000?nc/k?o/k>c00Ko/k>c00Go0000olc<c?o<c<coc<c<o`000006ok>c/`;o0000
0onIVIT01?l0003oOgmoogmoOol00003ofIVIP03o`000?m<C4coC4a<00;oC4a<00?o0000oc<c<olc
<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Go0000oiVI
VOnIVIWoVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nI
VIT01_l0003oOgmoogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01olc<c<01?l0003o
C4a<oda<C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007
olc<c003o`000?nc/k?o000000;oVIVI00Oo0000ogmoOol0003oIVIVo`000?m<C4co000000Wo<c<c
00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006
olc<c003o`000?oooooooooo00?ooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo
00?ooooo1Om<C4`00ol0003oIVIVofIVIP0:ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVI
VOnIVIT02_nIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmo
OomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIV
I_mVIVH00omVIVH00ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c
/onc/k<01_nc/k<01Ol0003oc<c<olc<c?o<c<co000000Ko/k>c00?o0000oiVIVOnIVIT00_nIVIT0
1?l0003oOgmoogmoOol00003ofIVIP03o`000?m<C4coC4a<00;oC4a<00?o0000oc<c<olc<c<01Olc
<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Go0000oiVIVOnIVIWo
VIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT01_l0
003oOgmoogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01olc<c<01?l0003oC4a<oda<
C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c003
o`000?nc/k?o000000;oVIVI00Oo0000ogmoOol0003oIVIVo`000?m<C4co000000Wo<c<c00Wo0000
oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c003
o`000?oooooooooo00?ooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo
1?m<C4`00ol0003oIVIVofIVIP0:ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT0
2_nIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl0
2?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH0
1?mVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<0
1_nc/k<3o`000003olc<c?l0003o/k>c00Go/k>c00?o0000oiVIVOnIVIT00_nIVIT01?l0003oOgmo
ogmoOol00003ofIVIP03o`000?m<C4coC4a<00;oC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003o
C4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000003
ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT01_l0003oOgmoogmo
Ool0003oIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIV
IP03o`000?moOgooOgmo00;o00000_nc/k<00ol0003oc<c<olc<c007olc<c003o`000?nc/k?o0000
00;oVIVI00?o0000ogmoOomoOgl00_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00?o0000oda<
C?l000000_mVIVH2o`0000;oVIVI00Co0000ok>c/onc/k?o00001oo<c<`00ol0003oooooooooo`04
ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`;oC4a<0_l0000<ofIV
IP03o`000?moOgooOgmo00SoOgmo0_l0000<oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVI
VOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00[oIVIV0_l0000Foda<
C003o`000?mVIVKoIVIV00CoIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@03oiVI
V@03o`000?nc/k?o/k>c00Ko/k>c00Co0000olc<c?o<c<co00001onc/k<01?l0003oVIVIoiVIVOnI
VIT2o`0000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go<c<c
00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`00
00?o/k>c00?o0000olc<c?o<c<`01oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@06o`000?moOgoo
Ogmoo`000?mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;o
IVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00?o0000ok>c
/ol000000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<0
0ol0003oC4a<o`000002ofIVIP;o00000_nIVIT00ol0003o/k>co`000008olc<c003o`000?oooooo
oooo00Cooooo0Ol00001ooooo`7ooooo000Iooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool0
0ol0003oooooooooo`03ooooo`;oC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`09
ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;
oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00E
oda<C003o`000?mVIVKoIVIV00CoIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@03
oiVIV@03o`000?nc/k?o/k>c00Ko/k>c00Co0000olc<c?o<c<co00001onc/k<01Ol0003oVIVIoiVI
VOnIVIWo000000?oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go
<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVI
o`0000?o/k>c00?o0000olc<c?o<c<`01oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@06o`000?mo
OgooOgmoo`000?mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`00
00;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00?o0000
ok>c/ol000000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc
<c<00ol0003oC4a<o`000002ofIVIP;o00000_nIVIT00ol0003o/k>co`000008olc<c003o`000?oo
oooooooo00Cooooo0Ol00001ooooo`7ooooo000Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_oo
ool00ol0003oooooooooo`03ooooo`03oda<C?l0003oIVIV00coIVIV00?o0000ogmoOomoOgl02?mo
Ogl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onI
VIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05Om<
C4`00ol0003oIVIVofIVIP04ofIVIP03o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT01?nI
VIT00ol0003o/k>cok>c/`05ok>c/`04o`000?o<c<coc<c<o`0000Oo/k>c00?o0000oiVIVOnIVIT0
0_nIVIT01Ol0003oOgmoogmoOomoOgoo000000;oIVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o
<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0
003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`00
0002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<01Ol0003oC4a<
oda<C?m<C4co000000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<
00Koc<c<00?o0000ok>c/ol000000onIVIT01ol0003oOgmoo`000?mVIVKo0000oda<C?l000002?lc
<c<01?l0003oC4a<oda<C?l00002ofIVIP;o000000CoVIVIo`000?nc/k?o00002Oo<c<`00ol0003o
ooooooooo`04ooooo`7o00000Oooool1ooooo`006Oooool01Ol@413ooooooooooooooooo410@00Ko
oooo00?o0000ooooooooool00oooool00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00So
Ogmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00[o
VIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01Go
C4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00?o
VIVI00?o0000ok>c/onc/k<01_nc/k<01?l0003oc<c<olc<c?l00007ok>c/`05o`000?nIVIWoVIVI
oiVIVOl000000omoOgl01Ol0003oIVIVofIVI_mVIVKo000000CoC4a<00?o0000oc<c<olc<c<01Olc
<c<00ol0003oC4a<oda<C002oda<C007o`000?mVIVKoIVIVofIVI_l0003oOgmoo`000003oiVIV@04
o`000?nc/k?o/k>co`0000Soc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgoo
Ogmoo`0000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<02ol0003oC4a<oda<C?m<C4co0000ofIV
I_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`00ol0003o/k>co`00
0002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`03o`00
0?m<C4co000000;oIVIV0_l00002oiVIV@03o`000?nc/k?o000000Soc<c<00?o0000ok>c/oooool0
1Oooool1o`00007ooooo0Oooool001Wooooo00Go0000ooooooooooooooooo`000006ooooo`?o0000
0oooool<ofIVIP;o00002_moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c
0_l0000=oiVIV@03o`000?moOgooOgmo00OoOgmo0_l0000=ofIVIP03o`000?m<C4coC4a<01GoC4a<
00?o0000ofIVI_mVIVH01?mVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00?oVIVI
00?o0000ok>c/onc/k<01_nc/k<2o`000003olc<c?l0003o/k>c00Ko/k>c00?o0000oiVIVOnIVIT0
0_nIVIT01?l0003oOgmoogmoOol00003ofIVIP03o`000?m<C4coC4a<00?oC4a<00?o0000oc<c<olc
<c<01?lc<c<2o`0000CoC4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00003
ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@03o`000?mo
Ogoo000000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`04o`000?m<C4coC4a<o`0000;o
IVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c
/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc
<c<00ol0003oC4a<o`000002ofIVIP;o000000CoVIVIo`000?nc/k?o00002Oo<c<`00ol0003o/k>c
ooooo`03ooooo`?o00000_ooool001Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo00?ooooo3?mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI
00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo00OoOgmo
00?o0000ofIVI_mVIVH03?mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00CoIVIV
00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c00Wo/k>c
00?o0000ok>c/onc/k<01_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Go0000ofIVI_mV
IVKoIVIVo`000005oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00om<C4`01?l0
003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<
c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmoOol000000_mVIVH01Ol0003oC4a<
oda<C?m<C4co000000So<c<c00Co0000oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nIVIWo
000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@05o`000?mo
Ogoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`03o`000?m<C4co000000;oIVIV
0_l000001?nIVIWo0000ok>c/ol00009olc<c003o`000?nc/k?o000000Gooooo0Ol00001ooooo`7o
oooo000Iooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`03ooooo`_o
IVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo
/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_o
IVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP04ofIVIP03o`000?moOgooOgmo00;o
Ogmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`0Bok>c/`05o`000?nIVIWoVIVIoiVI
VOl000000omoOgl01Ol0003oIVIVofIVI_mVIVKo000000GoC4a<00?o0000oc<c<olc<c<01?lc<c<0
0ol0003oC4a<oda<C003oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo0000
0onc/k<00ol0003oc<c<olc<c006olc<c003o`000?nc/k?o/k>c00;o/k>c00Go0000oiVIVOl0003o
Ogmoo`000002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01?l0003oC4a<oda<C?l00002
ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00001oo<c<`01?l0003o/k>cok>c
/ol00002oiVIV@03o`000?moOgoo000000;oIVIV00?o0000oda<C?l000002?lc<c<00ol0003oC4a<
o`000002ofIVIP;o000000GoVIVIo`000?nc/k?o/k>co`000008olc<c004o`000?nc/k?o/k>co`00
00Gooooo0Ol00001ooooo`7ooooo000Iooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0
003oooooooooo`03ooooo`WoIVIV0_l00009ogmoO`;o00003OnIVIT00ol0003o/k>cok>c/`0Fok>c
/`;o00003OnIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<
C?m<C4`05_m<C4`00ol0003oIVIVofIVIP04ofIVIP03o`000?moOgooOgmo00;oOgmo0_l00004oiVI
V@03o`000?nc/k?o/k>c01;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`05o`000?mVIVKo
IVIVofIVI_l000001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Go
0000ofIVI_mVIVKoIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<
c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0
003oC4a<oda<C?l00009oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl00ol0003oVIVI
o`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT01ol0003o
Ogmoo`000?mVIVKo0000oda<C?l000002Olc<c<00ol0003oC4a<o`000002ofIVIP;o000000GoVIVI
o`000?nc/k?o/k>co`000008olc<c003o`000?nc/k?o000000Kooooo0Ol00001ooooo`7ooooo000I
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`03ooooo`WoIVIV00?o
0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o
0000oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o
0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP04ofIVIP03o`000?moOgooOgmo00?oOgmo00?o
0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0Bok>c/`05o`000?nIVIWoVIVIoiVIVOl00000
0omoOgl01Ol0003oIVIVofIVI_mVIVKo000000CoC4a<00?o0000oc<c<olc<c<01Olc<c<01Ol0003o
C4a<oda<C?m<C4co000000CoIVIV00Co0000ogmoOomoOgoo00000_nIVIT01Ol0003o/k>cok>c/onc
/k?o000000Soc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@03o`000?moOgoo000000;oIVIV
00Co0000oda<C?m<C4co00002Olc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00?o0000
oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Oo
0000ogmoOol0003oIVIVo`000?m<C4co000000Wo<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo
0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c003o`000?nc/k?o000000Kooooo0Ol0
0001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo2?mVIVH00ol0003oOgmoogmoO`07
ogmoO`03o`000?nIVIWoVIVI00coVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0<
oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00F
oda<C003o`000?mVIVKoIVIV00GoIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@03
oiVIV@03o`000?nc/k?o/k>c01;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`05o`000?mV
IVKoIVIVofIVI_l000001Om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00;oC4a<
00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<
c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmoOol000000_mVIVH0
1?l0003oC4a<oda<C?l00009oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Go0000ogmoOol0003o
VIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00?o0000ok>c/ol000000_nIVIT01Ol0003o
Ogmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<00ol0003oC4a<o`000002ofIV
IP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c005olc<c004o`000?nc/k?o
/k>co`0000Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo1omVIVH0
0ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<0
0ol0003oVIVIoiVIV@0;oiVIV@;o00002_moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4co
C4a<01KoC4a<00?o0000ofIVI_mVIVH01OmVIVH00ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWo
VIVI00;oVIVI00?o0000ok>c/onc/k<04_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Go
0000ofIVI_mVIVKoIVIVo`000005oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`0
0_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000onc/k<00ol0
003oc<c<olc<c005olc<c0;o00000onc/k<00ol0003oVIVIo`000002ogmoO`04o`000?mVIVKoIVIV
o`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01ol0003oC4a<oda<C?m<C4co0000ofIVI_l00000
0_moOgl01Ol0003oVIVIo`000?nc/k?o000000[oc<c<00Co0000ok>c/ol0003oVIVI0_l000001?mo
Ogoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00?o0000oda<C?l000000_mVIVH0
1ol0003oOgmoo`000?nIVIWo0000ok>c/ol000002?o<c<`01?l0003o/k>cok>c/ol00006ooooo`7o
00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`KoIVIV00?o0000ogmoOomoOgl0
2?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT0
2onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`0
5om<C4`00ol0003oIVIVofIVIP05ofIVIP03o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT0
0onIVIT00ol0003o/k>cok>c/`0Bok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01Ol0003o
IVIVofIVI_mVIVKo000000GoC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C003oda<
C004o`000?mVIVKoIVIVo`0000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000003ok>c/`03o`000?o<
c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<00ol0003oVIVIo`000002ogmoO`04o`000?mV
IVKoIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP08
o`000?moOgooOgmoo`000?nIVIWo0000ok>c/ol0000:olc<c005o`000?nc/k?o0000oiVIVOl00000
0_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00?o0000oda<C?l00000
0_mVIVH01?l0003oOgmoo`000?l00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc
/k?o00001_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool5ofIVIP03
o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03
o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03
o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH01OmVIVH00ol0003oOgmoogmoO`02ogmoO`03
o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<04_nc/k<01Ol0003oVIVIoiVIVOnIVIWo0000
00?oOgmo00Go0000ofIVI_mVIVKoIVIVo`000005oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000
oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`05o`000?nIVIWoVIVIoiVIVOl00000
0onc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo
00000_moOgl00ol0003oIVIVo`000003oda<C003o`000?lc<c?o<c<c00Go<c<c00Oo0000oda<C?m<
C4coC4a<o`000?mVIVKo000000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007
olc<c003o`000?nc/k?o000000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc
<c?o<c<c00Ko<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol0
0009olc<c005o`000?nc/k?o0000oiVIVOl000001Oooool1o`00007ooooo0Oooool002Cooooo00?o
0000ooooooooool00oooool4ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onI
VIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02Omo
Ogl00ol0003oIVIVofIVIP0:ofIVIP;o00006?m<C4`2o`0000OoIVIV00?o0000ogmoOomoOgl00omo
Ogl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c017o/k>c00?o0000oiVIVOnIVIT00_nI
VIT01Ol0003oOgmoogmoOomoOgoo000000?oIVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o<c<c
oc<c<`04oc<c<`03o`000?m<C4coC4a<00;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`04
o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o
000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`07o`00
0?m<C4coC4a<oda<C?l0003oIVIVo`000002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<
c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<
C4`00ol0003o<c<coc<c<`06oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVI
o`000?nc/k?o00002Oo<c<`2o`000003oiVIVOl0003ooooo00Gooooo0Ol00001ooooo`7ooooo000T
ooooo`;o00001?ooool2ofIVIP;o00002_moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o
/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKo
IVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP07ofIVIP03o`000?moOgoo
Ogmo00?oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0Aok>c/`03o`000?nIVIWo
VIVI00;oVIVI00Co0000ogmoOomoOgoo00001?mVIVH00ol0003oC4a<oda<C003oda<C003o`000?lc
<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo
00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c
/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Oo
0000oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003o
c<c<olc<c006olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Go0000ogmoOol0003oIVIVo`000002
oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4co0000ofIVIP02o`0000;oVIVI00?o
0000ok>c/ol000002Oo<c<`2o`000003oiVIVOl0003ooooo00Cooooo0_l00002ooooo`009?ooool0
0ol0003oooooooooo`03ooooo`03ofIVI_l0003oOgmo00[oOgmo00?o0000oiVIVOnIVIT02onIVIT0
0ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl0
0ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH01_mVIVH0
0ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<04Onc/k<0
0ol0003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol000000omVIVH00ol0003oC4a<oda<
C003oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIV
I_mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c005
o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP04o`000?m<C4co
C4a<o`0000So<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00Co0000oiVIVOnI
VIWo00000_nc/k<00ol0003oc<c<olc<c005olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000
ogmoOol000000_mVIVH00ol0003oC4a<o`000008oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000
ogmoOol0003oVIVIo`000?nc/k?o00002Oo<c<`01Ol0003o/k>co`000?l0003oOgmo00Kooooo0Ol0
0001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo00?o0000ogmoOomoOgl02OmoOgl0
0ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT0
0ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00[oIVIV0_l0000Ioda<C003o`000?mVIVKo
IVIV00KoIVIV00?o0000ogmoOomoOgl00omoOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o
/k>c01;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`04o`000?mVIVKoIVIVofIVIP;o0000
1?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00?o0000ofIVI_mVIVH0
0_l00002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o
/k>cok>c/onc/k?o000000;oVIVI00Ko0000ogmoOomoOgoo0000ofIVI_l00003oda<C003o`000?lc
<c?o<c<c00Ko<c<c00So0000oda<C?m<C4coC4a<o`000?mVIVKo0000ogmoO`;o000000GoVIVIo`00
0?nc/k?o/k>co`000008olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl01Ol0003oIVIV
o`000?m<C4co000000Wo<c<c00?o0000oda<C?l000000_mVIVH01ol0003oOgmoo`000?nIVIWo0000
ok>c/ol000002?o<c<`00ol0003o/k>cok>c/`02o`000003ogmoOooooooooooo00Cooooo0Ol00001
ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo00?o0000ogmoOomoOgl02?moOgl00ol0
003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0
003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0
003oIVIVofIVIP06ofIVIP03o`000?moOgooOgmo00?oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0
003o/k>cok>c/`0Cok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01Ol0003oIVIVofIVI_mV
IVKo000000GoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mV
IVKoIVIVo`0000?oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c005
o`000?nc/k?o/k>cok>c/ol000000_nIVIT01_l0003oOgmoogmoOol0003oIVIVo`0000?oC4a<00?o
0000oc<c<olc<c<01_lc<c<02Ol0003oC4a<oda<C?m<C4co0000ofIVI_l0003oOgmoo`000002oiVI
V@04o`000?nc/k?o/k>co`0000Soc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`0000;o
IVIV00?o0000oda<C?l000002Olc<c<01Ol0003oC4a<o`000?mVIVKo000000;oOgmo00Go0000oiVI
VOl0003o/k>co`000008olc<c003o`000?nc/k?o/k>c00;o000000?oOgmoooooooooool01?ooool1
o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool:ogmoO`03o`000?nIVIWoVIVI
00_oVIVI00?o0000ok>c/onc/k<05_nc/k<2o`0000coVIVI00?o0000ogmoOomoOgl02?moOgl2o`00
00goIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP06ofIVIP03o`000?moOgooOgmo
00CoOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0Bok>c/`05o`000?nIVIWoVIVI
oiVIVOl000000omoOgl01Ol0003oIVIVofIVI_mVIVKo000000GoC4a<00?o0000oc<c<olc<c<01Olc
<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000?oOgmo00Go0000oiVIVOnIVIWo
VIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVI
V@04o`000?moOgooOgmoo`0000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<02Ol0003oC4a<oda<
C?m<C4co0000ofIVI_l0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Ko0000
ok>c/onc/k?o0000oiVIVOl00002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<0
1_lc<c<00ol0003oC4a<o`000002ofIVIP07o`000?moOgoo0000oiVIVOl0003o/k>co`000009olc<
c007o`000?nc/k?o0000oiVIVOl0003oOgmoo`000005ooooo`7o00000Oooool1ooooo`009?ooool0
0ol0003oooooooooo`03ooooo`WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0F
ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0<
ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0003oOgmoogmoO`04
ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<04_nc/k<00ol0003oVIVIoiVIV@02
oiVIV@05o`000?moOgooOgmoogmoOol000000omVIVH00ol0003oC4a<oda<C003oda<C003o`000?lc
<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00om<C4`01?l0003oIVIVofIVI_l00002ogmoO`05o`00
0?nIVIWoVIVIoiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c
/ol000000_nIVIT01_l0003oOgmoo`000?l0003oIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc
<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o
00002?o<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00?o0000ofIVI_l000000_m<C4`0
0ol0003o<c<coc<c<`06oc<c<`03o`000?m<C4co000000;oIVIV00Oo0000ogmoOol0003oVIVIo`00
0?nc/k?o000000Soc<c<00Go0000ok>c/onc/k?o0000oiVIV@02o`0000Kooooo0Ol00001ooooo`7o
oooo000Tooooo`03o`000?oooooooooo00?ooooo2?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`00
0?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`00
0?mVIVKoIVIV00[oIVIV0_l0000Ioda<C003o`000?mVIVKoIVIV00OoIVIV00?o0000ogmoOomoOgl0
1?moOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c01;o/k>c00?o0000oiVIVOnIVIT0
0_nIVIT01?l0003oOgmoogmoOol00004ofIVIP03o`000?m<C4coC4a<00?oC4a<00?o0000oc<c<olc
<c<01?lc<c<00ol0003oC4a<oda<C003oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Go0000oiVI
VOnIVIWoVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nI
VIT01?l0003oOgmoogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01?l0003o
C4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`0
1_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<c
oc<c<`06oc<c<`03o`000?m<C4co000000;oIVIV00Oo0000ogmoOol0003oVIVIo`000?nc/k?o0000
00Soc<c<00Go0000ok>c/onc/k?o0000oiVIV@02o`0000Kooooo0Ol00001ooooo`7ooooo000Toooo
o`03o`000?oooooooooo00?ooooo1omoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c
01Ko/k>c0_l0000<oiVIV@03o`000?moOgooOgmo00SoOgmo0_l0000<ofIVIP03o`000?m<C4coC4a<
01SoC4a<00?o0000ofIVI_mVIVH01omVIVH00ol0003oOgmoogmoO`04ogmoO`03o`000?nIVIWoVIVI
00?oVIVI00?o0000ok>c/onc/k<04_nc/k<00ol0003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmo
ogmoOol000000omVIVH00ol0003oC4a<oda<C003oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000
oda<C?m<C4`00om<C4`01?l0003oIVIVofIVI_l00002ogmoO`05o`000?nIVIWoVIVIoiVIVOl00000
0onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT00ol0003o
Ogmoo`000002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01?l0003oC4a<oda<C?l00002
ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01?l0003o/k>cok>c
/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0<
o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00002?o<c<`02?l0003o
/k>cok>c/ol0003oVIVIo`000?moOgoo00001_ooool1o`00007ooooo0Oooool002Cooooo00?o0000
ooooooooool00oooool6ogmoO`03o`000?nIVIWoVIVI00[oVIVI0_l0000Hok>c/`03o`000?nIVIWo
VIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4co
C4a<01SoC4a<00?o0000ofIVI_mVIVH01omVIVH2o`0000GoOgmo00?o0000oiVIVOnIVIT00onIVIT0
0ol0003o/k>cok>c/`0Bok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`00
0003ofIVIP03o`000?m<C4coC4a<00?oC4a<0_l00006oc<c<`03o`000?m<C4coC4a<00;oC4a<00Go
0000ofIVI_mVIVKoIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<
c<`01_o<c<`00ol0003o/k>cok>c/`02ok>c/`06o`000?nIVIWoVIVIo`000?moOgoo00000_mVIVH0
1?l0003oC4a<oda<C?l00009oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol00000
0_nIVIT01?l0003o/k>cok>c/ol00008olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl0
0ol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00co0000oda<C?m<C4co0000ofIV
I_l0003oOgmoo`000?nIVIWo0000ok>c/ol00008olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000
ogmoOol00006ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`GoOgmo
00?o0000oiVIVOnIVIT02_nIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00_oVIVI
00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP;o00006Om<C4`00ol0003oIVIV
ofIVIP08ofIVIP03o`000?moOgooOgmo00CoOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>c
ok>c/`0Bok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`000003ofIVIP03
o`000?m<C4coC4a<00?oC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004
o`000?mVIVKoIVIVo`0000?oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006
olc<c003o`000?nc/k?o/k>c00;o/k>c00Ko0000oiVIVOnIVIWo0000ogmoOol00002ofIVIP04o`00
0?m<C4coC4a<o`0000Wo<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVI
V@04o`000?nc/k?o/k>co`0000Soc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`03o`00
0?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`00
0?moOgoo0000oiVIVOl0003o/k>co`0000Soc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmo
o`0000Kooooo0Ol00001ooooo`7ooooo000Tooooo`;o00001?ooool4ogmoO`03o`000?nIVIWoVIVI
00[oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo
00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Hoda<C003o`000?mVIVKoIVIV
00SoIVIV00?o0000ogmoOomoOgl01?moOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c
01;o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000?oIVIV00?o0000
oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Go0000
ofIVI_mVIVKoIVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000onc/k<00ol0003oc<c<
olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Ko0000oiVIVOnIVIWo0000ogmoOol00002ofIV
IP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?mo
Ogoo000000?oVIVI00Co0000ok>c/onc/k?o00001oo<c<`01_l0003o/k>cok>c/ol0003oVIVIo`00
00;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0<o`000?m<C4coC4a<
o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00002?o<c<`02_l0003o/k>cok>c/ol0003o
VIVIo`000?moOgoo0000ofIVI_l00004ooooo`;o00000_ooool002Cooooo00?o0000ooooooooool0
0oooool2ogmoO`;o00003?nIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00_oVIVI
00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01SoC4a<
00?o0000ofIVI_mVIVH02?mVIVH00ol0003oOgmoogmoO`04ogmoO`03o`000?nIVIWoVIVI00?oVIVI
00?o0000ok>c/onc/k<04onc/k<00ol0003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol0
00000omVIVH00ol0003oC4a<oda<C003oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<
C4`00om<C4`01?l0003oIVIVofIVI_l00003ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000
olc<c?o<c<`01Oo<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo0000
0_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0
003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00So0000ok>c/onc/k?o0000oiVI
VOl0003oOgmoo`0000;oIVIV00?o0000oda<C?l000002Olc<c<00ol0003oC4a<o`000002ofIVIP07
o`000?moOgoo0000oiVIVOl0003o/k>co`000008olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000
ogmoOol0003oIVIVo`0000Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?o
oooo0_moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnI
VIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00coIVIV00?o0000oda<C?m<
C4`05om<C4`00ol0003oIVIVofIVIP08ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnI
VIT00onIVIT00ol0003o/k>cok>c/`0Cok>c/`03o`000?nIVIWoVIVI00;oVIVI00Co0000ogmoOomo
Ogoo00001?mVIVH00ol0003oC4a<oda<C003oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<
C?m<C4`00om<C4`01?l0003oIVIVofIVI_l00003ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o
0000olc<c?o<c<`01Oo<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo
00000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Co0000oda<C?m<C4co00000_mVIVH0
0ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00So0000ok>c/onc/k?o0000
oiVIVOl0003oOgmoo`0000;oIVIV00?o0000oda<C?l000002Olc<c<00ol0003oC4a<o`000002ofIV
IP07o`000?moOgoo0000oiVIVOl0003o/k>co`000008olc<c00:o`000?nc/k?o/k>co`000?nIVIWo
0000ogmoOol0003oIVIVo`0000Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo
00?ooooo00?oOgmoo`000?nIVIT03?nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI
00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<
01OoC4a<00?o0000ofIVI_mVIVH02OmVIVH00ol0003oOgmoogmoO`04ogmoO`03o`000?nIVIWoVIVI
00?oVIVI00?o0000ok>c/onc/k<04onc/k<00ol0003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmo
ogmoOol000000omVIVH00ol0003oC4a<oda<C004oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000
oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Go0000oiVIVOnIVIWoVIVI
o`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT01?l0003o
OgmoogmoOol00003ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Co0000oda<C?m<C4co00000_mV
IVH01_l0003oOgmoogmoOol0003oVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`02?l0003o
/k>cok>c/ol0003oVIVIo`000?moOgoo00000_mVIVH00ol0003oC4a<o`000009oc<c<`05o`000?m<
C4co0000ofIVI_l000000_moOgl01Ol0003oVIVIo`000?nc/k?o000000Soc<c<00Go0000ok>c/onc
/k?o0000oiVIV@02o`0000;oIVIV00?o0000ooooooooool00oooool1o`00007ooooo0Oooool002Co
oooo00?o0000ooooooooool00oooool00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo
/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00_o
IVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP09ofIVIP03o`000?moOgooOgmo00Co
Ogmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`0Cok>c/`03o`000?nIVIWoVIVI00;o
VIVI00Co0000ogmoOomoOgoo00001?mVIVH00ol0003oC4a<oda<C003oda<C003o`000?lc<c?o<c<c
00Co<c<c00?o0000oda<C?m<C4`00om<C4`01?l0003oIVIVofIVI_l00003ogmoO`04o`000?nIVIWo
VIVIo`0000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI
00Co0000ogmoOomoOgoo00000omVIVH01?l0003oC4a<oda<C?l00008oc<c<`04o`000?m<C4coC4a<
o`0000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00008olc<c008o`000?nc
/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00?o0000
oda<C?l000000_mVIVH01ol0003oOgmoo`000?nIVIWo0000ok>c/ol000002Oo<c<`02Ol0003o/k>c
o`000?nIVIWo0000ogmoOol0003oIVIVo`000006ooooo`7o00000Oooool1ooooo`009?ooool00ol0
003oooooooooo`03ooooo`goVIVI00?o0000ok>c/onc/k<05_nc/k<2o`0000goVIVI00?o0000ogmo
OomoOgl01omoOgl2o`0000goIVIV00?o0000oda<C?m<C4`05_m<C4`2o`0000_oIVIV00?o0000ogmo
OomoOgl01?moOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o0000oiVI
VOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000?oIVIV00?o0000oda<C?m<C4`01?m<C4`0
0ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00;oC4a<00Go0000ofIVI_mVIVKoIVIVo`00
0002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c005o`00
0?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP04o`000?m<C4coC4a<
o`0000So<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP05o`000?moOgoo0000oiVIVOl00000
0onc/k<00ol0003oc<c<olc<c006olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002
ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00?o0000oda<C?l000000_mVIVH01ol0003oOgmoo`00
0?nIVIWo0000ok>c/ol000002?o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIV
I_l00006ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`coVIVI00?o
0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo00OoOgmo00?o
0000ofIVI_mVIVH03?mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00[oIVIV00?o
0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c01?o/k>c00Go
0000oiVIVOnIVIWoVIVIo`000004ogmoO`05o`000?mVIVKoIVIVofIVI_l000001_m<C4`00ol0003o
<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmo
O`05o`000?nIVIWoVIVIoiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o
/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000So
<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP05o`000?moOgoo0000oiVIVOl000000onc/k<0
0ol0003oc<c<olc<c006olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP04
o`000?m<C4coC4a<o`0000So<c<c00?o0000oda<C?l000000_mVIVH01?l0003oOgmoo`000?l00002
ok>c/`03o`000?o<c<coc<c<00Koc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mV
IVKo00001_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool;oiVIV@03
o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03
o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03
o`000?moOgooOgmo00CoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`0Cok>c/`03
o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`000003ofIVIP03o`000?m<C4coC4a<
00CoC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C002oda<C005o`000?mVIVKoIVIV
ofIVI_l000000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<
c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01?l0003o
C4a<oda<C?l00009oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Go0000ogmoOol0003oVIVIo`00
0003ok>c/`03o`000?o<c<coc<c<00Koc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`00
00;oIVIV00Co0000oda<C?m<C4co00002?lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo
0000oiVIVOl0003o/k>co`0000Soc<c<00_o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mV
IVKo0000oda<C006ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`[o
VIVI00?o0000ok>c/onc/k<05_nc/k<2o`0000goVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003o
IVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02_mVIVH2o`0000Ko
Ogmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`0Cok>c/`03o`000?nIVIWoVIVI00;o
VIVI00?o0000ogmoOomoOgl00_moOgl01Ol0003oIVIVofIVI_mVIVKo000000GoC4a<00?o0000oc<c
<olc<c<01?lc<c<00ol0003oC4a<oda<C003oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl0
0ol0003oVIVIoiVIV@02o`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc
/k?o000000;oVIVI00Ko0000ogmoOomoOgoo0000ofIVI_l00003oda<C003o`000?lc<c?o<c<c00Oo
<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`03o`000?nIVIWo000000?o/k>c00?o0000
olc<c?o<c<`01_o<c<`02?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo00000_mVIVH01?l0003o
C4a<o`000?l00008oc<c<`03o`000?m<C4co000000;oIVIV00Oo0000ogmoOol0003oVIVIo`000?nc
/k?o000000Soc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l0
0005ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`WoVIVI00?o0000
ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000
ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00[oIVIV00?o0000
ogmoOomoOgl01_moOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o0000
oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000CoIVIV00?o0000oda<C?m<C4`00om<
C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Go0000ofIVI_mVIVKoIVIV
o`000002ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o
/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00?o0000ofIVI_l000000om<C4`00ol0
003o<c<coc<c<`07oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVIV@05o`00
0?nc/k?o/k>cok>c/ol000002?o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIV
I_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c00?o0000oda<C?l000000_mVIVH01ol0003oOgmo
o`000?nIVIWo0000ok>c/ol000002?o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000
ofIVI_l0003oC4a<o`0000Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?o
oooo2?nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomo
Ogl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mV
IVH02omVIVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc
/k<04onc/k<00ol0003oVIVIoiVIV@02oiVIV@03o`000?moOgooOgmo00;oOgmo00Go0000ofIVI_mV
IVKoIVIVo`000005oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00om<C4`01Ol0
003oIVIVofIVI_mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<
c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01_l0003oOgmoogmoOol0003oIVIVo`00
00?oC4a<00?o0000oc<c<olc<c<01olc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00?o
0000oiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c008o`000?nc/k?o/k>co`000?nIVIWo
0000ogmoOol00002ofIVIP03o`000?m<C4co000000Wo<c<c00?o0000oda<C?l000000_mVIVH01ol0
003oOgmoo`000?nIVIWo0000ok>c/ol000002Oo<c<`02ol0003o/k>co`000?nIVIWo0000ogmoOol0
003oIVIVo`000?m<C4co000000Kooooo0Ol00001ooooo`7ooooo000Tooooo`;o00001?ooool7oiVI
V@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT2o`0000[oOgmo00?o0000ofIV
I_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmo
OomoOgl01OmoOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o0000oiVI
VOnIVIT00onIVIT01Ol0003oOgmoogmoOomoOgoo000000?oIVIV00?o0000oda<C?m<C4`01?m<C4`0
0ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Co0000ofIVI_mVIVKo00000omo
Ogl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<0
0_nc/k<01_l0003oVIVIoiVIVOl0003oOgmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008
oc<c<`07o`000?m<C4coC4a<oda<C?l0003oIVIVo`000002ogmoO`03o`000?nIVIWo000000;o/k>c
00?o0000olc<c?o<c<`01oo<c<`02?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo00000_mVIVH0
0ol0003oC4a<o`000009oc<c<`03o`000?m<C4co000000;oIVIV00Oo0000ogmoOol0003oVIVIo`00
0?nc/k?o000000Woc<c<00_o0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`00
0005ooooo`;o00000_ooool002Cooooo00?o0000ooooooooool00oooool6oiVIV@03o`000?nc/k?o
/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKo
IVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgoo
Ogmo00GoOgmo00?o0000oiVIVOnIVIT01OnIVIT00ol0003o/k>cok>c/`0Cok>c/`03o`000?nIVIWo
VIVI00;oVIVI00?o0000ogmoOomoOgl00_moOgl01Ol0003oIVIVofIVI_mVIVKo000000GoC4a<00?o
0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C005o`000?mVIVKoIVIVofIVI_l00000
0omoOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Goc<c<00Go0000ok>c/onc
/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`00
0008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Ko0000ogmoOomoOgoo0000oiVIVOl00002ok>c
/`03o`000?o<c<coc<c<00Ooc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV
00?o0000oda<C?l000002Olc<c<00ol0003oC4a<o`000002ofIVIP07o`000?moOgoo0000oiVIVOl0
003o/k>co`000009olc<c00;o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l0
00001_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool5oiVIV@03o`00
0?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`00
0?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`00
0?moOgooOgmo00KoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`0Cok>c/`03o`00
0?nIVIWoVIVI00?oVIVI00Go0000ogmoOomoOgooOgmoo`000003ofIVIP03o`000?m<C4coC4a<00Co
C4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C003oda<C004o`000?mVIVKoIVIVo`00
00?oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o
/k>c00;o/k>c00Ko0000oiVIVOnIVIWo0000ogmoOol00002ofIVIP03o`000?m<C4coC4a<00;oC4a<
00?o0000oc<c<olc<c<01Olc<c<01ol0003oC4a<oda<C?m<C4co0000ofIVI_l000000_moOgl00ol0
003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00So0000ok>c/onc/k?o0000oiVIVOl0
003oOgmoo`0000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<00ol0003oC4a<o`000002ofIVIP07
o`000?moOgoo0000oiVIVOl0003o/k>co`000009olc<c003o`000?nc/k?o/k>c00;o000000OoOgmo
o`000?mVIVKo0000oda<C?l0003o<c<c00Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oo
oooooooo00?ooooo1?nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o
0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0:ofIVIP;o00006?m<C4`00ol0003oIVIVofIV
IP0;ofIVIP03o`000?moOgooOgmo00KoOgmo00?o0000oiVIVOnIVIT01?nIVIT2o`0001Go/k>c00?o
0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000CoIVIV00?o0000oda<C?m<C4`0
1?m<C4`00ol0003o<c<coc<c<`03oc<c<`03o`000?m<C4coC4a<00?oC4a<00Go0000ofIVI_mVIVKo
IVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<
c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP05o`000?m<
C4coC4a<oda<C?l000002?lc<c<01ol0003oC4a<oda<C?m<C4co0000ofIVI_l000000_moOgl00ol0
003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00So0000ok>c/onc/k?o0000oiVIVOl0
003oOgmoo`0000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<00ol0003oC4a<o`000002ofIVIP07
o`000?moOgoo0000oiVIVOl0003o/k>co`000008olc<c0;o000000_o/k>co`000?nIVIWo0000ogmo
Ool0003oIVIVo`000?m<C4co0000oc<c<`06ooooo`7o00000Oooool1ooooo`009?ooool00ol0003o
ooooooooo`03ooooo`?oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03
o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003
o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl01_moOgl00ol0003oVIVIoiVIV@05oiVIV@03
o`000?nc/k?o/k>c01Co/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo0000
00CoIVIV00?o0000oda<C?m<C4`01?m<C4`00ol0003o<c<coc<c<`03oc<c<`03o`000?m<C4coC4a<
00?oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o
0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo
00000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Oo0000oda<C?m<C4coC4a<o`000?mV
IVKo000000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c008o`000?nc
/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00?o0000
oda<C?l000000_mVIVH01ol0003oOgmoo`000?nIVIWo0000ok>c/ol000002?o<c<`03Ol0003o/k>c
ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`000?lc<c<01_ooool1o`00007ooooo
0Oooool002Cooooo00?o0000ooooooooool00oooool2oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o
0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o
0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00KoOgmo00?o
0000oiVIVOnIVIT01OnIVIT00ol0003o/k>cok>c/`0Dok>c/`03o`000?nIVIWoVIVI00;oVIVI00?o
0000ogmoOomoOgl00_moOgl01Ol0003oIVIVofIVI_mVIVKo000000KoC4a<00?o0000oc<c<olc<c<0
0olc<c<00ol0003oC4a<oda<C003oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01Ol0003o
VIVIoiVIVOnIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o
000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c
00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0
003oc<c<olc<c007olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP04o`00
0?m<C4coC4a<o`0000So<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000
0_nc/k<00ol0003oc<c<olc<c005olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003o
IVIVo`000?m<C4co00000_lc<c<6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003ooooooooo
o`03ooooo`03oiVIVOl0003o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmo
O`09ogmoO`03o`000?mVIVKoIVIV00[oIVIV0_l0000Hoda<C003o`000?mVIVKoIVIV00_oIVIV00?o
0000ogmoOomoOgl01_moOgl00ol0003oVIVIoiVIV@05oiVIV@03o`000?nc/k?o/k>c01Co/k>c00?o
0000oiVIVOnIVIT00_nIVIT00ol0003oOgmoogmoO`02ogmoO`05o`000?mVIVKoIVIVofIVI_l00000
1_m<C4`00ol0003o<c<coc<c<`03oc<c<`03o`000?m<C4coC4a<00CoC4a<00Co0000ofIVI_mVIVKo
00000omoOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c
/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<
o`000008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o
/k>cok>c/ol00008olc<c009o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000?moOgoo000000;oIVIV
00?o0000oda<C?l000002Olc<c<00ol0003oC4a<o`000002ofIVIP07o`000?moOgoo0000oiVIVOl0
003o/k>co`000008olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<
C4co00000_lc<c<6ooooo`7o00000Oooool1ooooo`006Oooool5o`0000Kooooo00?o0000oooooooo
ool00oooool00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00[oVIVI00?o0000ogmoOomo
Ogl02OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mV
IVH02omVIVH00ol0003oOgmoogmoO`07ogmoO`03o`000?nIVIWoVIVI00GoVIVI00?o0000ok>c/onc
/k<04onc/k<00ol0003oVIVIoiVIV@03oiVIV@03o`000?moOgooOgmo00;oOgmo00Go0000ofIVI_mV
IVKoIVIVo`000006oda<C003o`000?lc<c?o<c<c00?o<c<c00?o0000oda<C?m<C4`01?m<C4`01?l0
003oIVIVofIVI_l00003ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01_o<
c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01Ol0003o
C4a<oda<C?m<C4co000000So<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002
oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00_o0000ok>c/onc/k?o/k>co`000?nIVIWo0000ogmo
Ool0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00?o0000oda<C?l000000_mVIVH0
1ol0003oOgmoo`000?nIVIWo0000ok>c/ol000002?o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`00
0?moOgoo0000ofIVI_l0003oC4a<o`0000;o<c<c1_ooool1o`00007ooooo0Oooool001Wooooo00Go
V9RHob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo00?ooooo6?nc/k<2o`0000coVIVI
00?o0000ogmoOomoOgl02?moOgl2o`0000goIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIV
ofIVIP0;ofIVIP03o`000?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT01OnIVIT00ol0003o/k>c
ok>c/`0Cok>c/`03o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIV
ofIVIP02ofIVIP03o`000?m<C4coC4a<00?oC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<
oda<C003oda<C004o`000?mVIVKoIVIVo`0000?oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0
003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol0
0002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP06
o`000?moOgooOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c009o`000?nc/k?o
/k>cok>c/ol0003oVIVIo`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<00ol0
003oC4a<o`000002ofIVIP07o`000?moOgoo0000oiVIVOl0003o/k>co`000009olc<c003o`000?nc
/k?o000000;oVIVI0_l000001OmVIVKo0000oda<C?m<C4co000000;o<c<c1_ooool1o`00007ooooo
0Oooool001[ooooo00?oV9RHob4Q8Oo^k^h01oooool00ol0003oooooooooo`03oooooaOo/k>c00?o
0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00coIVIV00?o
0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00OoOgmo00?o
0000oiVIVOnIVIT01OnIVIT00ol0003o/k>cok>c/`0Dok>c/`03o`000?nIVIWoVIVI00;oVIVI00?o
0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP02ofIVIP03o`000?m<C4coC4a<00CoC4a<00?o
0000oc<c<olc<c<00olc<c<00ol0003oC4a<oda<C003oda<C005o`000?mVIVKoIVIVofIVI_l00000
0_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o
/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`0
0ol0003o<c<coc<c<`05oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH00ol0003oOgmoo`00
0002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Wo0000ok>c/onc/k?o/k>co`000?nIVIWo0000
ogmoOol000000_mVIVH00ol0003oC4a<o`000009oc<c<`03o`000?m<C4co000000;oIVIV00Oo0000
ogmoOol0003oVIVIo`000?nc/k?o000000Woc<c<00_o0000ok>c/ol0003oVIVIo`000?moOgoo0000
ofIVI_l0003oC4a<o`000003oc<c<`Kooooo0Ol00001ooooo`7ooooo000Kooooo`03oiRHV?lQ8B7o
k^k^00Kooooo0ol00003oooooaOo/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`09
ogmoO`03o`000?mVIVKoIVIV00[oIVIV0_l0000Hoda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000
ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c01Co/k>c00?o0000
oiVIVOnIVIT00_nIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000
oda<C?m<C4`01?m<C4`00ol0003o<c<coc<c<`03oc<c<`03o`000?m<C4coC4a<00?oC4a<00Go0000
ofIVI_mVIVKoIVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0003oc<c<
olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0003o
IVIVofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002
ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`02Ol0003o/k>cok>c
/onc/k?o0000oiVIVOl0003oOgmoo`000002ofIVIP03o`000?m<C4co000000Wo<c<c00?o0000oda<
C?l000000_mVIVH01ol0003oOgmoo`000?nIVIWo0000ok>c/ol000002Oo<c<`02ol0003o/k>co`00
0?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co000000?o<c<c1?ooool3o`0000;ooooo000Loooo
o`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool00ooooolEok>c/`;o00003?nIVIT00ol0
003oOgmoogmoO`08ogmoO`;o00003?mVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV
00_oIVIV00?o0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c
01Co/k>c00?o0000oiVIVOnIVIT00_nIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV
00;oIVIV00?o0000oda<C?m<C4`01?m<C4`00ol0003o<c<coc<c<`03oc<c<`03o`000?m<C4coC4a<
00?oC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o
0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo
00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;o
C4a<00Go0000ofIVI_l0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Oo0000
ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo00Go0000ofIVI_l0003oC4a<o`000009oc<c<`03
o`000?m<C4co000000;oIVIV00Oo0000ogmoOol0003oVIVIo`000?nc/k?o000000Woc<c<00?o0000
ok>c/onc/k<00_l000001?moOgoo0000ofIVI_mVIVH2o`0000Co<c<c1_ooool1o`00007ooooo0Ooo
ool001gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooooaCo/k>c00?o0000
oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000
oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00OoOgmo00?o0000
oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`0Dok>c/`03o`000?nIVIWoVIVI00?oVIVI00Go0000
ogmoOomoOgooOgmoo`000004ofIVIP03o`000?m<C4coC4a<00CoC4a<00?o0000oc<c<olc<c<00olc
<c<00ol0003oC4a<oda<C004oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01Ol0003oVIVI
oiVIVOnIVIWo000000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`01Ol0003o/k>cok>c/onc/k?o0000
00?oVIVI00?o0000ogmoOol000000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Go0000
oda<C?m<C4coC4a<o`000002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o0000
2?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0
003o<c<coc<c<`07oc<c<`03o`000?m<C4co000000;oIVIV00Oo0000ogmoOol0003oVIVIo`000?nc
/k?o000000Soc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l0
0004oc<c<`Kooooo0Ol00001ooooo`7ooooo000Iooooo`05o`000?nj^[[ooooooiRHV?l@41001_oo
ool00ol0003oooooooooo`03oooooa?o/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmo
O`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV0_l0000Hoda<C003o`000?mVIVKoIVIV00_oIVIV00?o
0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o
0000oiVIVOnIVIT01?nIVIT01Ol0003oOgmoogmoOomoOgoo000000CoIVIV00?o0000oda<C?m<C4`0
1?m<C4`00ol0003o<c<coc<c<`03oc<c<`03o`000?m<C4coC4a<00CoC4a<00Go0000ofIVI_mVIVKo
IVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0003oc<c<olc<c005olc<
c005o`000?nc/k?o/k>cok>c/ol000000onIVIT00ol0003oOgmoo`000002ofIVIP05o`000?m<C4co
C4a<oda<C?l000002?lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o0000ogmoOol00000
0_nIVIT01?l0003o/k>cok>c/ol00008olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Go0000ogmo
Ool0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00?o0000oda<C?l000000_mVIVH0
1ol0003oOgmoo`000?nIVIWo0000ok>c/ol000002?o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`00
0?moOgoo0000ofIVI_l0003oC4a<o`0000Co<c<c1_ooool1o`00007ooooo0Oooool000_ooooo0ol0
00000ol@413oooooooooo`08ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003ooooo
ooooo`03oooooa;o/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`00
0?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`00
0?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`0Dok>c/`03o`00
0?nIVIWoVIVI00?oVIVI00Go0000ogmoOomoOgooOgmoo`000004ofIVIP03o`000?m<C4coC4a<00Co
C4a<00?o0000oc<c<olc<c<00olc<c<00ol0003oC4a<oda<C004oda<C005o`000?mVIVKoIVIVofIV
I_l000000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`0
1Ol0003o/k>cok>c/onc/k?o000000?oVIVI00?o0000ogmoOol000000_mVIVH01Ol0003oC4a<oda<
C?m<C4co000000So<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP03o`000?moOgoo000000;o
VIVI00Co0000ok>c/onc/k?o00002Oo<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000
ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003o
Ogmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o0000oiVIVOl0
00000_moOgl2o`000003oda<C?l0003o<c<c00Co<c<c1_ooool1o`00007ooooo0Oooool000gooooo
00?o410@okZj^_ooool05?ooool00ol0003oooooooooo`03oooooa7o/k>c00?o0000oiVIVOnIVIT0
2onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`0
5om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT0
1_nIVIT00ol0003o/k>cok>c/`0Dok>c/`03o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl0
0_moOgl01Ol0003oIVIVofIVI_mVIVKo000000OoC4a<00?o0000oc<c<olc<c<00_lc<c<00ol0003o
C4a<oda<C004oda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01?l0003oVIVIoiVIVOl00004
ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl0
0002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<
oda<C?m<C4co000000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00008olc<
c004o`000?nc/k?o/k>co`0000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc
<c?o<c<c00Ko<c<c0_l000002om<C4co0000ofIVI_mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o
000000Soc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00005
oc<c<`Kooooo0Ol00001ooooo`7ooooo000=ooooo`03oiRHV?lb<S;ooooo01Cooooo00?o0000oooo
ooooool00oooool@ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0
003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0
003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc/k<05Onc/k<00ol0
003oVIVIoiVIV@03oiVIV@03o`000?moOgooOgmo00;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000007
oda<C003o`000?lc<c?o<c<c00;o<c<c00?o0000oda<C?m<C4`01?m<C4`01Ol0003oIVIVofIVI_mV
IVKo000000?oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c005olc<c003o`00
0?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00003oda<
C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP03o`000?moOgoo
000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@05o`00
0?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`00
00;oIVIV00Oo0000ogmoOol0003oVIVIo`000?nc/k?o000000Soc<c<00co0000ok>c/onc/k?o0000
oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00005oc<c<`Kooooo0Ol00001ooooo`7ooooo000=
ooooo`03omgMgOl0003o^[Zj01Cooooo00?o0000ooooooooool00oooool?ok>c/`03o`000?nIVIWo
VIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4co
C4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWo
VIVI00KoVIVI00?o0000ok>c/onc/k<05?nc/k<00ol0003oVIVIoiVIV@03oiVIV@03o`000?moOgoo
Ogmo00;oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C005oda<C003o`000?lc<c?o
<c<c00;o<c<c00?o0000oda<C?m<C4`01?m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Co
0000oiVIVOnIVIWo00001Onc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c
00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00002oda<C003o`000?lc<c?o<c<c
00Oo<c<c00Co0000oda<C?m<C4co00000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@03o`000?nc
/k?o000000Woc<c<00Co0000ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;o
C4a<00?o0000oc<c<olc<c<01_lc<c<02?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo00000_nI
VIT00ol0003o/k>co`000008olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIV
o`000?m<C4co00001Olc<c<6ooooo`7o00000Oooool1ooooo`003Oooool00omEEEGoMgMgodA4A00D
ooooo`03o`000?oooooooooo00?ooooo3onc/k<00ol0003oVIVIoiVIV@0:oiVIV@03o`000?moOgoo
Ogmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKo
IVIV00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o
/k>c01Co/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`03ogmoO`05o`000?mVIVKo
IVIVofIVI_l000001om<C4`00ol0003o<c<coc<c<`02oc<c<`03o`000?m<C4coC4a<00CoC4a<00Go
0000ofIVI_mVIVKoIVIVo`000003ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<
c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co0000ofIV
I_mVIVKo00000om<C4`00ol0003o<c<coc<c<`07oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o
0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00009olc<c003o`000?nc/k?o000000;oVIVI
00?o0000ogmoOol000000_mVIVH00ol0003oC4a<o`000008oc<c<`04o`000?m<C4coC4a<o`0000;o
IVIV00Oo0000ogmoOol0003oVIVIo`000?nc/k?o000000Woc<c<00?o0000ok>c/ol000000_nIVIT2
o`000005ofIVI_l0003oC4a<oda<C?l000001Olc<c<6ooooo`7o00000Oooool1ooooo`003?ooool0
1OoMgMgo410@oooooolQ8B7ogMgM01?ooooo00?o0000ooooooooool00oooool=ok>c/`;o00003OnI
VIT00ol0003oOgmoogmoO`07ogmoO`;o00003OmVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mV
IVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@07oiVIV@03o`000?nc
/k?o/k>c01Co/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mV
IVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01Om<C4`01?l0003o<c<coc<c<olc<c<2o`0000KoC4a<
00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0
003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl0
1?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Oo0000oda<C?m<C4coC4a<
o`000?mVIVKo000000;oOgmo00Ko0000oiVIVOnIVIWo0000ok>c/ol0000:olc<c003o`000?nc/k?o
000000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Ko
0000oda<C?m<C4co0000ofIVI_l00002ogmoO`05o`000?nIVIWo0000ok>c/ol000002Oo<c<`02ol0
003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co000000Ko<c<c1_ooool1o`00007o
oooo0Oooool000cooooo00GoIVIVohN7QoooooooV9RHoeEEE@0Cooooo`;o00001?ooool<ok>c/`03
o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl01omoOgl00ol0003oIVIVofIVIP0<ofIVIP03
o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`09ogmoO`03
o`000?nIVIWoVIVI00OoVIVI00?o0000ok>c/onc/k<05Onc/k<00ol0003oVIVIoiVIV@03oiVIV@03
o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C005oda<C005
o`000?lc<c?o<c<coc<c<ol000001om<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Go0000
oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc
/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc
<c<01_lc<c<01ol0003oC4a<oda<C?m<C4co0000ofIVI_l000000_moOgl01_l0003oVIVIoiVIVOl0
003o/k>co`0000[oc<c<00?o0000ok>c/ol000000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;o
C4a<00?o0000oc<c<olc<c<01_lc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00Go0000
oiVIVOl0003o/k>co`000009olc<c00;o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000
oda<C?l000001_lc<c<5ooooo`;o00000_ooool000_ooooo00?ok^k^o`000?o^k^h00_ooool00ol0
003ogMgMooooo`0Aooooo`03o`000?oooooooooo00?ooooo3?nc/k<00ol0003oVIVIoiVIV@0;oiVI
V@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<
C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@07oiVI
V@03o`000?nc/k?o/k>c01Go/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`02ogmo
O`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01Om<C4`01Ol0003o<c<coc<c<olc<c?o
000000OoC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVIVOl00000
1?nc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003o
OgmoogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01ol0003oC4a<oda<C?m<
C4co0000ofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Oo
c<c<00?o0000ok>c/ol000000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c
<olc<c<01olc<c<00ol0003oC4a<o`000002ofIVIP07o`000?moOgoo0000oiVIVOl0003o/k>co`00
0009olc<c007o`000?nc/k?o0000oiVIVOl0003oOgmoo`000002ofIVIP;o00001olc<c<6ooooo`7o
00000Oooool1ooooo`002oooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo013o
oooo00?o0000ooooooooool00oooool:ok>c/`;o00003OnIVIT00ol0003oOgmoogmoO`08ogmoO`03
o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03
o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02?nIVIT00ol0003o/k>cok>c/`0Dok>c/`03
o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP02ofIVIP03
o`000?m<C4coC4a<00GoC4a<00?o0000oc<c<olc<c<00_lc<c<00ol0003oC4a<oda<C004oda<C005
o`000?mVIVKoIVIVofIVI_l000000omoOgl01Ol0003oVIVIoiVIVOnIVIWo000000Co/k>c00?o0000
olc<c?o<c<`01Oo<c<`01Ol0003o/k>cok>c/onc/k?o000000?oVIVI00Co0000ogmoOomoOgoo0000
0_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Ko0000ogmo
OomoOgoo0000oiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o0000
0_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01olc<c<01Ol0003o
C4a<o`000?mVIVKo000000;oOgmo00Go0000oiVIVOl0003o/k>co`000009olc<c00;o`000?nc/k?o
0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l000001olc<c<6ooooo`7o00000Oooool1oooo
o`009?ooool00ol0003oooooooooo`03ooooo`Wo/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003o
OgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003o
IVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02?nIVIT00ol0003o
/k>cok>c/`0Dok>c/`03o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003o
IVIVofIVIP02ofIVIP03o`000?m<C4coC4a<00GoC4a<0_l00003oc<c<`03o`000?m<C4coC4a<00Co
C4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000onc/k<0
0ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000onIVIT01?l0003oOgmoogmo
Ool00002ofIVIP04o`000?m<C4coC4a<o`0000Wo<c<c00Co0000oda<C?m<C4co00000_mVIVH01_l0
003oOgmoogmoOol0003oVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c
/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`05
o`000?m<C4co0000ofIVI_l000000_moOgl01Ol0003oVIVIo`000?nc/k?o000000Soc<c<00co0000
ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00007oc<c<`Kooooo0Ol00001
ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo2?nc/k<00ol0003oVIVIoiVIV@0<oiVI
V@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<
C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@08oiVI
V@03o`000?nc/k?o/k>c01Go/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`02ogmo
O`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01Om<C4`01_l0003o<c<coc<c<ol0003o
<c<co`0000KoC4a<00?o0000ofIVI_mVIVH00_mVIVH01?l0003oOgmoogmoOol00003oiVIV@03o`00
0?nc/k?o/k>c00;o/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`00
0?nIVIWoVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c
<`04o`000?m<C4coC4a<o`0000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01?l0003o/k>cok>c
/ol00009olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o
0000oc<c<olc<c<01olc<c<00ol0003oC4a<oda<C002o`0000;oOgmo00?o0000oiVIVOl000000_nc
/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o0000oiVIVOl000000_moOgl2o`0000;oC4a<
00?o0000oc<c<olc<c<01Olc<c<6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003ooooooooo
o`03ooooo`Oo/k>c00?o0000oiVIVOnIVIT02onIVIT2o`0000[oOgmo00?o0000ofIVI_mVIVH02omV
IVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02Omo
Ogl00ol0003oVIVIoiVIV@08oiVIV@03o`000?nc/k?o/k>c01Go/k>c00?o0000oiVIVOnIVIT00onI
VIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<C4`01Om<
C4`01Ol0003o<c<coc<c<olc<c?o000000OoC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`05
o`000?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c
00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000?oC4a<00?o
0000oc<c<olc<c<01Olc<c<2o`0000;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl00ol0003oVIVI
o`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT01Ol0003o
Ogmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01_l0003oC4a<oda<C?l0003o
IVIVo`0000;oOgmo00Go0000oiVIVOl0003o/k>co`000009olc<c009o`000?nc/k?o0000oiVIVOl0
003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01Olc<c<6ooooo`7o00000Oooool1
ooooo`009?ooool00ol0003oooooooooo`03ooooo`Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0
003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0
003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo0_l0000;oiVIV@03o`000?nc/k?o/k>c
01Go/k>c00?o0000oiVIVOnIVIT00onIVIT01Ol0003oOgmoogmoOomoOgoo000000KoIVIV00?o0000
oda<C?m<C4`01Om<C4`01Ol0003o<c<coc<c<olc<c?o000000KoC4a<00?o0000ofIVI_mVIVH00_mV
IVH01?l0003oOgmoogmoOol00003oiVIV@03o`000?nc/k?o/k>c00;o/k>c00?o0000olc<c?o<c<`0
1Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Go0000ofIVI_mV
IVKoIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002
ofIVIP06o`000?moOgooOgmoo`000?nIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c004o`00
0?nc/k?o/k>co`0000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c
00Ko<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`05o`000?nIVIWo0000ok>c/ol00000
2Oo<c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o
<c<c00Go<c<c1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool5ok>c
/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0;ofIV
IP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmo
O`03o`000?nIVIWoVIVI00[oVIVI00?o0000ok>c/onc/k<05Onc/k<00ol0003oVIVIoiVIV@03oiVI
V@03o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C005oda<
C005o`000?lc<c?o<c<coc<c<ol000001_m<C4`00ol0003oIVIVofIVIP02ofIVIP04o`000?moOgoo
Ogmoo`0000?oVIVI00?o0000ok>c/onc/k<00_nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc
/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000?o
C4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C003o`000?mVIVKo000000;o
Ogmo00?o0000oiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`00
00;oVIVI00?o0000ogmoOol000000_mVIVH00ol0003oC4a<o`000008oc<c<`06o`000?m<C4coC4a<
o`000?mVIVKo00000_moOgl01Ol0003oVIVIo`000?nc/k?o000000Woc<c<00Wo0000ok>c/ol0003o
VIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`03o`000?oooooo
oooo00?ooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo1?nc/k<00ol0
003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02_mVIVH2o`00
01SoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI
00[oVIVI00?o0000ok>c/onc/k<05Onc/k<00ol0003oVIVIoiVIV@03oiVIV@03o`000?moOgooOgmo
00?oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C005oda<C0;o00000_lc<c<00ol0
003oC4a<oda<C005oda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01Ol0003oVIVIoiVIVOnI
VIWo000000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nI
VIWoVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`05
o`000?m<C4coC4a<oda<C?l000000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>c
o`0000Woc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`03o`000?mVIVKo000000;oC4a<
00?o0000oc<c<olc<c<01_lc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00Go0000oiVI
VOl0003o/k>co`000009olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000;o
C4a<00?o0000oc<c<olc<c<01_lc<c<00ol0003oooooooooo`03ooooo`7o00000Oooool1ooooo`00
9?ooool00ol0003oooooooooo`03ooooo`?o/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmo
ogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIV
ofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02_nIVIT00ol0003o/k>c
ok>c/`0Fok>c/`03o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIV
ofIVIP02ofIVIP03o`000?m<C4coC4a<00GoC4a<00Go0000oda<C?l0003o<c<co`000007oda<C005
o`000?mVIVKoIVIVofIVI_l000000omoOgl01Ol0003oVIVIoiVIVOnIVIWo000000Co/k>c00?o0000
olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co
0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l0
00000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Woc<c<00Ko0000ok>c
/onc/k?o0000oiVIVOl00002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc
<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00Go0000oiVIVOl0003o/k>co`000009olc<
c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<0
1_lc<c<00ol0003oooooooooo`03ooooo`7o00000Oooool1ooooo`009?ooool2o`0000Cooooo0_nc
/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omV
IVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?mo
Ogl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Go/k>c00?o0000oiVIVOnIVIT00onI
VIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01_m<
C4`2o`000003oda<C?l0003oC4a<00KoC4a<00?o0000ofIVI_mVIVH00_mVIVH01?l0003oOgmoogmo
Ool00003oiVIV@03o`000?nc/k?o/k>c00;o/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>c
ok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0
003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH00ol0003oOgmoo`000002
oiVIV@04o`000?nc/k?o/k>co`0000Woc<c<00Co0000ok>c/onc/k?o00000_nIVIT01Ol0003oOgmo
o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01olc<c<00ol0003oC4a<o`000002ofIVIP07
o`000?moOgoo0000oiVIVOl0003o/k>co`000009olc<c007o`000?nc/k?o0000oiVIVOl0003oOgmo
o`000002ofIVIP03o`000?m<C4co000000So<c<c00?o0000ooooooooool00oooool2o`0000;ooooo
000Tooooo`03o`000?oooooooooo00?ooooo00?o/k>co`000?nIVIT03?nIVIT00ol0003oOgmoogmo
O`09ogmoO`03o`000?mVIVKoIVIV00[oIVIV0_l0000Hoda<C003o`000?mVIVKoIVIV00_oIVIV00?o
0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Go/k>c00?o
0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o
0000oda<C?m<C4`01_m<C4`01?l0003o<c<coc<c<ol00007oda<C003o`000?mVIVKoIVIV00;oIVIV
00?o0000ogmoOomoOgl00_l00002oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`0
1Oo<c<`01?l0003o/k>cok>c/onc/k<2o`0000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01Ol0
003oC4a<oda<C?m<C4co000000So<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP03o`000?mo
Ogoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`2o`0000;o/k>c00?o0000oiVIVOl00000
0_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Co0000oda<C?l0003o
IVIV0ol00002oiVIV@03o`000?nc/k?o000000Woc<c<00_o0000ok>c/ol0003oVIVIo`000?moOgoo
0000ofIVI_l0003oC4a<o`000009oc<c<`03o`000?oooooooooo00Cooooo0Ol00001ooooo`7ooooo
000Tooooo`03o`000?oooooooooo00?ooooo00?o/k>co`000?nIVIT02onIVIT00ol0003oOgmoogmo
O`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIV
IP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c
/`0Dok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIV
IP03ofIVIP03o`000?m<C4coC4a<00KoC4a<00Co0000oc<c<olc<c?o00001om<C4`00ol0003oIVIV
ofIVIP02ofIVIP04o`000?moOgooOgmoo`0000?oVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003o
c<c<olc<c005olc<c005o`000?nc/k?o/k>cok>c/ol000000onIVIT01?l0003oOgmoogmoOol00002
ofIVIP05o`000?m<C4coC4a<oda<C?l000001olc<c<00ol0003oC4a<oda<C002oda<C006o`000?mV
IVKoIVIVo`000?moOgoo00000_nIVIT01?l0003o/k>cok>c/ol00008olc<c007o`000?nc/k?o/k>c
ok>c/ol0003oVIVIo`000002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01olc
<c<01ol0003oC4a<o`000?mVIVKo0000ogmoOol000000_nIVIT00ol0003o/k>co`000008olc<c00<
o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co00002Olc<c<00ol0003o
ooooooooo`04ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`03o`00
0?nIVIWoVIVI00[oVIVI00?o0000ogmoOomoOgl02?moOgl2o`0000goIVIV00?o0000oda<C?m<C4`0
5_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT0
3?nIVIT00ol0003o/k>cok>c/`0Dok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl0
0omoOgl00ol0003oIVIVofIVIP02ofIVIP03o`000?m<C4coC4a<00KoC4a<00Co0000oc<c<olc<c?o
00001om<C4`00ol0003oIVIVofIVIP02ofIVIP04o`000?moOgooOgmoo`0000CoVIVI00?o0000ok>c
/onc/k<00_nc/k<00ol0003oc<c<olc<c005olc<c005o`000?nc/k?o/k>cok>c/ol000000onIVIT0
1?l0003oOgmoogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01Ol0003oC4a<
oda<C?m<C4co000000;oIVIV00Ko0000ogmoOomoOgoo0000oiVIVOl00003ok>c/`03o`000?o<c<co
c<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<2o`0000;oOgmo00?o0000ofIVI_l000000_m<C4`0
0ol0003o<c<coc<c<`07oc<c<`07o`000?m<C4co0000ofIVI_l0003oOgmoo`000002oiVIV@04o`00
0?nc/k?o/k>co`0000Soc<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<
C4`00ol0003o<c<coc<c<`06oc<c<`03o`000?m<C4cooooo00Gooooo0Ol00001ooooo`7ooooo000T
ooooo`03o`000?oooooooooo00?ooooo3?nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKo
IVIV00coIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgoo
Ogmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT2o`0001Ko/k>c00?o0000oiVIVOnIVIT01?nIVIT0
0ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01om<C4`3
o`0000SoC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`05o`000?nIVIWoVIVIoiVIVOl00000
1?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Go0000oiVIVOnIVIWo
VIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01_l0
003oC4a<oda<C?m<C4co0000ofIVIP;o000000GoOgmoo`000?nIVIWoVIVIo`000002ok>c/`03o`00
0?o<c<coc<c<00Koc<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo00?o0000ofIV
I_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmo
Ool00002oiVIV@03o`000?nc/k?o000000Woc<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000
ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`03o`000?m<C4cooooo00Gooooo0Ol00001
ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo2onIVIT00ol0003oOgmoogmoO`09ogmo
O`03o`000?mVIVKoIVIV00[oIVIV0_l0000Hoda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmo
OomoOgl02?moOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Go/k>c00?o0000oiVI
VOnIVIT01?nIVIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<
C?m<C4`02Om<C4`00ol0003oC4a<oda<C006oda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl0
1Ol0003oVIVIoiVIVOnIVIWo000000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c
/`02ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00003oda<C003
o`000?lc<c?o<c<c00Ko<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00Co0000
oiVIVOnIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c007o`000?nc/k?o/k>cok>c/ol0003o
VIVIo`000002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02?l0003o
C4a<oda<C?l0003oIVIVo`000?moOgoo00000_nIVIT00ol0003o/k>co`000009olc<c009o`000?nc
/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<00ol0
003oC4a<o`000005ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`[o
VIVI00?o0000ogmoOomoOgl02?moOgl2o`0000coIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003o
IVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o
/k>cok>c/`0Eok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003o
IVIVofIVIP02ofIVIP03o`000?m<C4coC4a<01;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmo
O`05o`000?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o
/k>c00;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<
00?o0000oc<c<olc<c<01_lc<c<01ol0003oC4a<oda<C?m<C4co0000ofIVI_l000000_moOgl01?l0
003oVIVIoiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Ko0000ok>c/onc/k?o0000oiVI
VOl00002ogmoO`04o`000?mVIVKoIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01Olc<c<01_l0003o
C4a<oda<C?l0003oIVIVo`0000;oOgmo00Go0000oiVIVOl0003o/k>co`000009olc<c009o`000?nc
/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0
003oC4a<oda<C?l00005ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03oooo
o`WoVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<
01OoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI
00_oVIVI0_l0000Gok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl00omoOgl00ol0
003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<017oC4a<00?o0000ofIVI_mVIVH00_mVIVH00ol0
003oOgmoogmoO`02o`0000;oVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c005olc<
c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l0
0003oda<C003o`000?lc<c?o<c<c00Oo<c<c00Co0000oda<C?m<C4co00000_mVIVH01?l0003oOgmo
ogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Woc<c<00Oo0000ok>c/onc/k?o0000oiVIVOl0
003oOgmo00;o000000GoIVIVo`000?m<C4coC4a<o`000008oc<c<`07o`000?m<C4coC4a<o`000?mV
IVKo0000ogmoO`02o`000004oiVIVOl0003o/k>co`0000Woc<c<00Wo0000ok>c/ol0003oVIVIo`00
0?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`03o`000?m<C4co000000Ko
oooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo2?nIVIT00ol0003oOgmo
ogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV0_l0000Hoda<C003o`000?mVIVKoIVIV00_oIVIV
00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c
00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00?oIVIV
00?o0000oda<C?m<C4`04Om<C4`00ol0003oIVIVofIVIP02ofIVIP04o`000?moOgooOgmoo`0000?o
VIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c005olc<c005o`000?nc/k?o/k>cok>c
/ol000000onIVIT01?l0003oOgmoogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<C?l000002Olc
<c<01?l0003oC4a<oda<C?l00002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Co0000ok>c/onc
/k?o00002Oo<c<`02?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo00000_mVIVH01?l0003oC4a<
oda<C?l00008oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVIV@03o`000?nc
/k?o000000Woc<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0
003o<c<coc<c<`06oc<c<`03o`000?m<C4co000000Kooooo0Ol00001ooooo`7ooooo000Tooooo`03
o`000?oooooooooo00?ooooo1onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_o
IVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00So
Ogmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00Co
VIVI00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<017o
C4a<00?o0000ofIVI_mVIVH00_mVIVH01?l0003oOgmoogmoOol00004oiVIV@03o`000?nc/k?o/k>c
00;o/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`05o`000?nIVIWoVIVI
oiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Co
0000oda<C?m<C4co00000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@04o`000?nc/k?o/k>co`00
00Woc<c<00Co0000ok>c/onc/k?o00000_nIVIT2o`0000;oIVIV00Co0000oda<C?m<C4co00002?lc
<c<02?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo00000_nIVIT00ol0003o/k>co`000009olc<
c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000?oC4a<00?o0000oc<c<olc<c<0
1Olc<c<01?l0003oC4a<o`000?mVIVH6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003ooooo
ooooo`03ooooo`KoVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`00
0?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`00
0?nIVIWoVIVI00_oVIVI0_l0000Gok>c/`;o00001_nIVIT00ol0003oOgmoogmoO`03ogmoO`03o`00
0?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<C4`04_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000?o
Ogmo00Go0000oiVIVOnIVIWoVIVIo`000005ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c
/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo00000om<
C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmo
ogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT0
0ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00So0000oda<C?m<C4co0000
ofIVI_l0003oOgmoo`0000;oVIVI00?o0000ok>c/ol000002Oo<c<`02Ol0003o/k>co`000?nIVIWo
0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?l0003o
IVIV1_ooool1o`00007ooooo0Oooool002Cooooo0_l00004ooooo`GoVIVI00?o0000ogmoOomoOgl0
2?moOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH0
2omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<0
5onc/k<00ol0003oVIVIoiVIV@05oiVIV@03o`000?moOgooOgmo00?oOgmo00?o0000ofIVI_mVIVH0
0omVIVH00ol0003oC4a<oda<C00Boda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01Ol0003o
VIVIoiVIVOnIVIWo000000Go/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`02ok>c
/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc
<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;o
VIVI00Co0000ok>c/onc/k?o00002?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo
000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<02?l0003oC4a<oda<C?l0003oIVIVo`000?mo
Ogoo00000_nIVIT00ol0003o/k>co`000009olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`00
0?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<o`000?mVIVKo000000Co
oooo0_l00002ooooo`009?ooool00ol0003oooooooooo`03ooooo`CoVIVI00?o0000ogmoOomoOgl0
2?moOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH0
2omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00[oVIVI00?o0000ok>c/onc/k<0
5onc/k<00ol0003oVIVIoiVIV@05oiVIV@03o`000?moOgooOgmo00?oOgmo00?o0000ofIVI_mVIVH0
0omVIVH00ol0003oC4a<oda<C00Boda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl00ol0003o
VIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c00;o/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o
/k>cok>c/`02ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00003
oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000omVIVH01_l0003oOgmoogmo
Ool0003oVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVI
V@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00001olc<c<01?l0003oC4a<oda<C?l0
0002ofIVIP03o`000?moOgoo000000;oVIVI00?o0000ok>c/ol000002?o<c<`03?l0003o/k>cok>c
/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000Wo<c<c00Go0000oda<C?l0003oIVIV
o`000005ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`?oVIVI00?o
0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o
0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00[oVIVI00?o
0000ok>c/onc/k<06?nc/k<00ol0003oVIVIoiVIV@05oiVIV@03o`000?moOgooOgmo00?oOgmo00?o
0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00Boda<C005o`000?mVIVKoIVIVofIVI_l00000
0omoOgl01Ol0003oVIVIoiVIVOnIVIWo000000Go/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o
/k>cok>c/`02ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00004
oda<C003o`000?lc<c?o<c<c00Go<c<c00Go0000oda<C?m<C4coC4a<o`000003ofIVIP03o`000?mo
Ogoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@03
o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<02?l0003oC4a<oda<C?l0003o
IVIVo`000?moOgoo00000_nIVIT01?l0003o/k>cok>c/ol00008olc<c009o`000?nc/k?o0000oiVI
VOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<o`00
0?mVIVKo000000Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo0onI
VIT00ol0003oOgmoogmoO`07ogmoO`;o00003OmVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mV
IVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0:oiVIV@;o00006?nc
/k<2o`0000OoVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<
C4coC4a<01;oC4a<00?o0000ofIVI_mVIVH00_mVIVH01?l0003oOgmoogmoOol00004oiVIV@03o`00
0?nc/k?o/k>c00;o/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`05o`00
0?nIVIWoVIVIoiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c
00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP06o`000?moOgooOgmoo`000?nIVIWo0000
0onc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol0
00000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmo
Ool00002oiVIV@03o`000?nc/k?o000000Woc<c<00_o0000ok>c/ol0003oVIVIo`000?moOgoo0000
ofIVI_l0003oC4a<o`000009oc<c<`05o`000?m<C4co0000ofIVI_l000001_ooool1o`00007ooooo
0Oooool002Cooooo00?o0000ooooooooool00oooool2oiVIV@03o`000?moOgooOgmo00OoOgmo00?o
0000ofIVI_mVIVH03?mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o
0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0:oiVIV@03o`000?nc/k?o/k>c01So/k>c00?o
0000oiVIVOnIVIT01_nIVIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o
0000oda<C?m<C4`04Om<C4`00ol0003oIVIVofIVIP03ofIVIP04o`000?moOgooOgmoo`0000CoVIVI
00?o0000ok>c/onc/k<00_nc/k<00ol0003oc<c<olc<c005olc<c005o`000?nc/k?o/k>cok>c/ol0
00000onIVIT01Ol0003oOgmoogmoOomoOgoo000000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008
oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01_l0003oOgmoogmoOol0003oVIVIo`0000?o
/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo0000
00;oIVIV00Co0000oda<C?m<C4co00002?lc<c<02?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo
00000_nIVIT00ol0003o/k>co`000009olc<c00;o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mV
IVKo0000oda<C?l000002Olc<c<01Ol0003oC4a<o`000?mVIVKo000000Kooooo0Ol00001ooooo`7o
oooo000Tooooo`03o`000?oooooooooo00?ooooo00?oVIVIo`000?moOgl02OmoOgl00ol0003oIVIV
ofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmo
ogmoO`09ogmoO`03o`000?nIVIWoVIVI00[oVIVI00?o0000ok>c/onc/k<06?nc/k<00ol0003oVIVI
oiVIV@06oiVIV@03o`000?moOgooOgmo00?oOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<
oda<C00Boda<C003o`000?mVIVKoIVIV00;oIVIV00Co0000ogmoOomoOgoo00001?nIVIT00ol0003o
/k>cok>c/`02ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003o
VIVIoiVIVOl00003ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<0
1Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Ko0000ogmoOomoOgoo0000oiVIVOl00003ok>c/`03
o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT01_l0003oOgmoogmoOol0003o
IVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02?l0003oC4a<oda<C?l0003oIVIVo`000?mo
Ogoo00000_nIVIT00ol0003o/k>co`000009olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`00
0?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<00ol0003oC4a<oda<C002o`000003ogmo
Oooooooooooo00Cooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo00?o
0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o
0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00[oVIVI0_l0
000Iok>c/`03o`000?nIVIWoVIVI00KoVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIV
IP03ofIVIP03o`000?m<C4coC4a<01;oC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmo
OomoOgoo000000?oVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c004olc<c003o`00
0?nc/k?o/k>c00?o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01Ol0003oIVIVofIVI_mVIVKo0000
00?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o0000
ogmoOol000000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Co0000ok>c/onc/k?o0000
0_nIVIT00ol0003oOgmoo`000002ofIVIP03o`000?m<C4co000000Wo<c<c00So0000oda<C?m<C4co
0000ofIVI_l0003oOgmoo`0000;oVIVI00?o0000ok>c/ol000002?o<c<`02_l0003o/k>cok>c/ol0
003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Oo0000oda<
C?l0003oIVIVo`000?moOgoo000000Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooo
oooo00?ooooo2_moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000
ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00[oVIVI00?o0000
ok>c/onc/k<06?nc/k<00ol0003oVIVIoiVIV@07oiVIV@03o`000?moOgooOgmo00?oOgmo00?o0000
ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00Boda<C005o`000?mVIVKoIVIVofIVI_l000001?mo
Ogl01Ol0003oVIVIoiVIVOnIVIWo000000Go/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>c
ok>c/`03ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000003oda<
C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01_l0003oIVIVofIVI_l0003o
Ogmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`000007olc<c007o`000?nc/k?o/k>cok>c/ol0
003oVIVIo`000002ogmoO`06o`000?mVIVKoIVIVo`000?m<C4co00002Olc<c<02?l0003oC4a<oda<
C?l0003oIVIVo`000?moOgoo00000_nIVIT00ol0003o/k>co`000008olc<c00<o`000?nc/k?o/k>c
o`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co00002Olc<c<01ol0003oC4a<o`000?mVIVKo
0000ogmoOol000001Oooool1o`00007ooooo0Oooool001_ooooo0_l000000ol@413oooooooooo`04
ooooo`03o`000?oooooooooo00?ooooo2OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4co
C4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWo
VIVI00[oVIVI00?o0000ok>c/onc/k<06?nc/k<00ol0003oVIVIoiVIV@07oiVIV@03o`000?moOgoo
Ogmo00?oOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00Boda<C003o`000?mVIVKo
IVIV00;oIVIV00Go0000ogmoOomoOgooOgmoo`000003oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o
0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo
00Go0000ofIVI_mVIVKoIVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<
C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002?o<
c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co
00002?lc<c<02?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo00000_nIVIT00ol0003o/k>co`00
0009olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c
<olc<c<01_lc<c<00ol0003oC4a<oda<C002o`000003ogmoOol0003ooooo00Gooooo0Ol00001oooo
o`7ooooo000Looooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool8ogmoO`03
o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03
o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02_nIVIT2o`0001Wo/k>c00?o0000oiVIVOnI
VIT01onIVIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<
C4`04om<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0
003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00_nc/k<01Ol0
003oVIVIoiVIVOnIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c
<`05oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@05
o`000?nc/k?o/k>cok>c/ol000002?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@05o`000?moOgoo
0000ofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo
0000ogmoOol00002oiVIV@03o`000?nc/k?o000000Woc<c<00Wo0000ok>c/ol0003oVIVIo`000?mo
Ogoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`03o`000?m<C4coC4a<00;o0000
00?oOgmoo`000?ooool01Oooool1o`00007ooooo0Oooool001Wooooo1Ol00006ooooo`?o00000ooo
ool7ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIV
IP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02_nIVIT00ol0003o/k>cok>c
/`0Hok>c/`03o`000?nIVIWoVIVI00OoVIVI00?o0000ogmoOomoOgl01?moOgl00ol0003oIVIVofIV
IP03ofIVIP03o`000?m<C4coC4a<01;oC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmo
OomoOgoo000000?oVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c004olc<c003o`00
0?nc/k?o/k>c00;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`00
00CoC4a<00?o0000oc<c<olc<c<01Olc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000
ogmoOomoOgoo00000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Co0000ok>c/onc/k?o
00000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<02?l0
003oC4a<oda<C?l0003oIVIVo`000?moOgoo00000_nIVIT00ol0003o/k>co`000009olc<c009o`00
0?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<0
0ol0003oC4a<oda<C002o`000003ogmoOol0003ooooo00?ooooo0ol00002ooooo`006Oooool01?m4
A4CogMgMooooool00007ooooo`03o`000?oooooooooo00?ooooo1_moOgl00ol0003oIVIVofIVIP0;
ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`09
ogmoO`03o`000?nIVIWoVIVI00[oVIVI00?o0000ok>c/onc/k<06?nc/k<00ol0003oVIVIoiVIV@07
oiVIV@03o`000?moOgooOgmo00CoOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00C
oda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01Ol0003oVIVIoiVIVOnIVIWo000000Ko/k>c
00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`02ok>c/`05o`000?nIVIWoVIVIoiVIVOl0
00000_moOgl01?l0003oIVIVofIVI_l00004oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<
C?m<C4co00000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@05o`000?nc/k?o/k>cok>c/ol00000
2?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<
C4co00002?lc<c<02?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo00000_nIVIT01?l0003o/k>c
ok>c/ol00008olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o
0000oc<c<olc<c<01olc<c<01?l0003oC4a<o`000?mVIVH2o`000003oiVIVOoooooooooo00Cooooo
0Ol00001ooooo`7ooooo000Iooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool0
0oooool5ogmoO`03o`000?mVIVKoIVIV00[oIVIV0_l0000Hoda<C003o`000?mVIVKoIVIV00_oIVIV
00?o0000ogmoOomoOgl02?moOgl2o`0000goVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVI
oiVIV@07oiVIV@03o`000?moOgooOgmo00CoOgmo00?o0000ofIVI_mVIVH01?mVIVH00ol0003oC4a<
oda<C00Boda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgooOgmoo`000003oiVIV@03
o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04
o`000?nIVIWoVIVIo`0000?oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`07
oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01?l0003o/k>c
ok>c/ol00009olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Co0000ogmoOol0003oIVIV0_l00002
oda<C003o`000?lc<c?o<c<c00Ko<c<c00Wo0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nI
VIT00_l000000onc/k?o0000olc<c007olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0
003oIVIVo`000?m<C4co00002_lc<c<01ol0003oC4a<o`000?l0003oOgmoo`000?nIVIT01_ooool1
o`00007ooooo0Oooool001[ooooo00?oMgMgolc<c?l000001oooool00ol0003oooooooooo`03oooo
o`CoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV
00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c
01Oo/k>c00?o0000oiVIVOnIVIT01onIVIT00ol0003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV
00CoIVIV00?o0000oda<C?m<C4`04_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000CoOgmo00Go0000
oiVIVOnIVIWoVIVIo`000005ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00onc
/k<01?l0003oVIVIoiVIVOl00002ogmoO`05o`000?mVIVKoIVIVofIVI_l000000om<C4`00ol0003o
<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002
oiVIV@04o`000?nc/k?o/k>co`0000Woc<c<00Co0000ok>c/onc/k?o00000_nIVIT2o`0000;oIVIV
00Go0000oda<C?m<C4coC4a<o`000008oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0
003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`00
0?moOgoo0000ofIVI_l0003oC4a<o`0000[o<c<c00So0000oda<C?l0003o0000ogmoOol0003oVIVI
o`0000Gooooo0Ol00001ooooo`7ooooo000Jooooo`03onk^k_m4A4Co000000Oooooo00?o0000oooo
ooooool00oooool3ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0
003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0
003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00OoVIVI00?o0000ogmoOomoOgl01OmoOgl00ol0
003oIVIVofIVIP04ofIVIP03o`000?m<C4coC4a<01;oC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0
003oOgmoogmoOomoOgoo000000?oVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c005
olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000omoOgl01Ol0003oIVIVofIV
I_mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;o
IVIV00Co0000ogmoOomoOgoo00000_nIVIT01?l0003o/k>cok>c/ol00009olc<c004o`000?nc/k?o
/k>co`0000;oVIVI00Go0000ogmoOol0003oIVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c
00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<
c006olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl2o`0000;oC4a<00?o0000oc<c<olc
<c<01olc<c<01?l0003oC4a<o`000?mVIVH2o`0000;oVIVI00?o0000ooooooooool00oooool1o`00
007ooooo0Oooool001_ooooo00?oMgMgo`000?ooool01_ooool00ol0003oooooooooo`03ooooo`;o
Ogmo00?o0000ofIVI_mVIVH02_mVIVH2o`0001SoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003o
OgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI0_l0000Iok>c/`03o`000?nIVIWoVIVI00So
VIVI00?o0000ogmoOomoOgl01?moOgl00ol0003oIVIVofIVIP04ofIVIP03o`000?m<C4coC4a<01;o
C4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000CoVIVI00?o0000ok>c
/onc/k<00onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00;o/k>c00Go0000oiVI
VOnIVIWoVIVIo`000002ogmoO`05o`000?mVIVKoIVIVofIVI_l000000om<C4`00ol0003o<c<coc<c
<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@04
o`000?nc/k?o/k>co`0000Soc<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo00?o
0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo
0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02_l0003o/k>cok>c/ol0
003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<
C?m<C4co0000ofIVIP02o`000003oiVIVOl0003ooooo00Gooooo0Ol00001ooooo`7ooooo000Toooo
o`03o`000?oooooooooo00?ooooo00?oOgmoo`000?mVIVH03?mVIVH00ol0003oC4a<oda<C00Foda<
C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0<oiVI
V@03o`000?nc/k?o/k>c01Ko/k>c0_l0000;oiVIV@03o`000?moOgooOgmo00CoOgmo00?o0000ofIV
I_mVIVH00omVIVH00ol0003oC4a<oda<C00Coda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmo
OomoOgooOgmoo`000004oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`01?o<c<`0
0ol0003o/k>cok>c/`02ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01Ol0003oIVIVofIV
I_mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;o
IVIV00?o0000ogmoOol000000onIVIT01?l0003o/k>cok>c/ol00008olc<c007o`000?nc/k?o/k>c
ok>c/ol0003oVIVIo`000002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01olc
<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<co
c<c<00Koc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0
003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<o`000?mVIVH00_l000000onIVIWo0000ooooo`05
ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`03o`000?mVIVKoIVIV
00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo
00SoOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI
00[oVIVI00?o0000ogmoOomoOgl01?moOgl00ol0003oIVIVofIVIP04ofIVIP03o`000?m<C4coC4a<
01?oC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000
ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00;o/k>c00Go0000
oiVIVOnIVIWoVIVIo`000002ogmoO`05o`000?mVIVKoIVIVofIVI_l000001?m<C4`00ol0003o<c<c
oc<c<`05oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVI
V@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo
00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`0:o`000?m<C4coC4a<o`000?mV
IVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01oo<c<`00ol0003o/k>co`00
0002oiVIV@;o000000GoIVIVo`000?m<C4coC4a<o`000009oc<c<`06o`000?m<C4co0000ofIVI_l0
003oOgmo0_l000000onc/k?oooooooooo`04ooooo`7o00000Oooool1ooooo`009?ooool00ol0003o
ooooooooo`03ooooo`goIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03
o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT2o`0001So/k>c00?o0000oiVIVOnI
VIT02OnIVIT2o`0000KoOgmo00?o0000ofIVI_mVIVH01?mVIVH00ol0003oC4a<oda<C00Coda<C005
o`000?mVIVKoIVIVofIVI_l000001?moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Go/k>c0_l00005
olc<c003o`000?nc/k?o/k>c00?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`04o`000?mV
IVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`00
0?mVIVKoIVIVo`0000;oOgmo00?o0000oiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c007
o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000
oc<c<olc<c<01olc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c
/`03o`000?o<c<coc<c<00Ooc<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00000
0_m<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<o`000?mVIVH00_l000000onIVIWo
0000ok>c/`06ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`_oIVIV
0_l0000Hoda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVI
oiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmo
ogmoO`05ogmoO`03o`000?mVIVKoIVIV00CoIVIV00?o0000oda<C?m<C4`04om<C4`01Ol0003oIVIV
ofIVI_mVIVKo000000CoOgmo00Go0000oiVIVOnIVIWoVIVIo`000005ok>c/`03o`000?o<c<coc<c<
00Coc<c<00?o0000ok>c/onc/k<00onc/k<01?l0003oVIVIoiVIVOl00003ogmoO`04o`000?mVIVKo
IVIVo`0000CoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mV
IVKoIVIVo`0000;oOgmo00?o0000oiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c007o`00
0?nc/k?o/k>cok>c/ol0003oVIVIo`000002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c
<olc<c<01olc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03
o`000?o<c<coc<c<00Ooc<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<
C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<o`000?mVIVH00_l000000onIVIWo0000
ok>c/`06ooooo`7o00000Oooool1ooooo`009?ooool2o`0000Cooooo2_mVIVH00ol0003oC4a<oda<
C00Goda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVI
V@0<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmo
O`05ogmoO`03o`000?mVIVKoIVIV00CoIVIV00?o0000oda<C?m<C4`04om<C4`00ol0003oIVIVofIV
IP02ofIVIP05o`000?moOgooOgmoogmoOol000000onIVIT00ol0003o/k>cok>c/`03ok>c/`03o`00
0?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;o
Ogmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<
00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl00ol0003oVIVIo`000003ok>c/`03o`000?o<c<co
c<c<00Koc<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo00?o0000ofIVI_l00000
0om<C4`00ol0003o<c<coc<c<`06oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003o
VIVIo`0000;o/k>c00?o0000olc<c?o<c<`01oo<c<`00ol0003o/k>cok>c/`02o`000007ogmoOol0
003oIVIVofIVI_l0003oC4a<o`000008oc<c<`0;o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0
003oVIVIo`000?nc/k<01Oooool2o`0000;ooooo000Tooooo`03o`000?oooooooooo00?ooooo2OmV
IVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?mo
Ogl00ol0003oVIVIoiVIV@0;oiVIV@;o00005onc/k<2o`0000coVIVI00?o0000ogmoOomoOgl01Omo
Ogl00ol0003oIVIVofIVIP04ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH00_mV
IVH01Ol0003oOgmoogmoOomoOgoo000000CoVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<
olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Co0000oiVIVOnIVIWo00000omoOgl01?l0003o
IVIVofIVI_l00004oda<C003o`000?lc<c?o<c<c00Go<c<c00Go0000oda<C?m<C4coC4a<o`000003
ofIVIP03o`000?moOgoo000000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c007o`000?nc
/k?o/k>cok>c/ol0003oVIVIo`000002ogmoO`03o`000?mVIVKo000000;oC4a<0_l00007oc<c<`0;
o`000?m<C4coC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<
olc<c006olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o
0000oc<c<olc<c<01_lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o
/k>co`0000Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo2?mVIVH2
o`0001SoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWo
VIVI00coVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0:oiVIV@03o`000?moOgoo
Ogmo00GoOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<C00Coda<C003o`000?mVIVKo
IVIV00;oIVIV00Go0000ogmoOomoOgooOgmoo`000004oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o
0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`04o`000?nIVIWoVIVIo`0000?oOgmo
00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`05oc<c<`05o`000?m<C4coC4a<oda<
C?l000000omVIVH00ol0003oOgmoo`000002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`0
2Ol0003o/k>cok>c/onc/k?o0000oiVIVOl0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`00
00So<c<c00_o0000oda<C?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c/`03
o`000?o<c<coc<c<00Koc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000
0_m<C4`00ol0003o<c<coc<c<`06oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003o
VIVIo`000?nc/k?o00001Oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00ooo
ool7ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmo
O`08ogmoO`03o`000?nIVIWoVIVI00coVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVI
V@0:oiVIV@03o`000?moOgooOgmo00GoOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<
C00Coda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgooOgmoo`000004oiVIV@03o`00
0?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`04o`00
0?nIVIWoVIVIo`0000?oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`06oc<c
<`04o`000?m<C4coC4a<o`0000?oIVIV00?o0000ogmoOol000000_nIVIT01Ol0003o/k>cok>c/onc
/k?o000000Soc<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo00?o0000ofIVI_l0
00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`09o`000?m<C4coC4a<oda<C?l0003oIVIVo`000?mo
Ogoo000000;oVIVI00?o0000ok>c/ol000002?o<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;o
Ogmo0_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00co0000oda<C?m<C4co0000ofIVI_l0003o
Ogmoo`000?nIVIWo0000ok>c/ol00006ooooo`7o00000Oooool1ooooo`009?ooool00ol0003ooooo
ooooo`03ooooo`KoIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`00
0?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT2o`0001Oo/k>c0_l0000<oiVIV@03o`00
0?moOgooOgmo00GoOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<C00Coda<C003o`00
0?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgooOgmoo`000004oiVIV@03o`000?nc/k?o/k>c00Co
/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`03ok>c/`05o`000?nIVIWoVIVIoiVI
VOl000000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000?oC4a<0_l00007oc<c<`05o`000?m<C4co
C4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@05o`000?nc/k?o/k>cok>c/ol0
00002?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<
C?m<C4co00002?lc<c<02ol0003oC4a<oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000
00;o/k>c00?o0000olc<c?o<c<`01_o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000
ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00co0000oda<C?m<C4co0000ofIVI_l0003o
Ogmoo`000?nIVIWo0000ok>c/ol00006ooooo`7o00000Oooool1ooooo`009?ooool00ol0003ooooo
ooooo`03ooooo`KoIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`00
0?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`00
0?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl01OmoOgl00ol0003oIVIVofIVIP05ofIVIP03o`00
0?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000Co
VIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o
/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`05o`000?mVIVKoIVIVofIVI_l000000om<C4`0
0ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmo
Ool00002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01?l0003o/k>cok>c/ol00002oiVI
V@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<02ol0003oC4a<oda<C?m<
C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02_l0
003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko
<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00006ooooo`7o
00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`GoIVIV00?o0000oda<C?m<C4`0
5_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT0
2_nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl0
1OmoOgl00ol0003oIVIVofIVIP05ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH0
0omVIVH01?l0003oOgmoogmoOol00004oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<
c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Go0000ofIV
I_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`00
0002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c004
o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00008
oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl00ol0003oVIVIo`000002ok>c/`03o`00
0?o<c<coc<c<00Koc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<
C?l00009oc<c<`05o`000?m<C4coC4a<o`000?mVIVH00_l00002oiVIV@03o`000?nc/k?o000000Ko
oooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo1?mVIVH00ol0003oC4a<
oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVI
oiVIV@0:oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003oOgmo
ogmoO`06ogmoO`03o`000?mVIVKoIVIV00GoIVIV00?o0000oda<C?m<C4`04om<C4`00ol0003oIVIV
ofIVIP02ofIVIP05o`000?moOgooOgmoogmoOol000001?nIVIT00ol0003o/k>cok>c/`03ok>c/`03
o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00onc/k<01Ol0003oVIVIoiVIVOnIVIWo0000
00;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000
oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o
/k>co`000008olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0
003oC4a<oda<C?l00008oc<c<`0;o`000?m<C4coC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVI
VOl000000_nc/k<00ol0003oc<c<olc<c007olc<c003o`000?nc/k?o000000;oVIVI0_l000001OmV
IVKo0000oda<C?m<C4co000000Wo<c<c00co0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0
003o/k>co`000?o<c<`6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03oooo
o`?oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo
00WoOgmo00?o0000oiVIVOnIVIT02_nIVIT2o`0001Oo/k>c0_l0000=oiVIV@03o`000?moOgooOgmo
00KoOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<C00Coda<C003o`000?mVIVKoIVIV
00;oIVIV00?o0000ogmoOomoOgl00_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Ko/k>c00?o0000
olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`04o`000?nIVIWoVIVIo`0000?oOgmo00Co
0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l0
00000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Woc<c<00Co0000
ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c
00Co0000oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<
c?o<c<`01oo<c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003o`00
0?lc<c?o<c<c00Ko<c<c00go0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c
/ol0003oc<c<00Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo0_mV
IVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02Omo
Ogl00ol0003oVIVIoiVIV@0:oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT03?nI
VIT00ol0003oOgmoogmoO`06ogmoO`03o`000?mVIVKoIVIV00KoIVIV00?o0000oda<C?m<C4`04om<
C4`00ol0003oIVIVofIVIP02ofIVIP03o`000?moOgooOgmo00;oOgmo00Go0000oiVIVOnIVIWoVIVI
o`000006ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00onc/k<01?l0003oVIVI
oiVIVOl00003ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0
003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo00000_nc
/k<00ol0003oc<c<olc<c007olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Go0000ogmoOol0003o
IVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH01Ol0
003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`02Ol0003o/k>co`000?nI
VIWo0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00go0000oda<C?m<
C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol0003oc<c<00Kooooo0Ol00001ooooo`7o
oooo000Tooooo`03o`000?oooooooooo00?ooooo00?oIVIVo`000?m<C4`05om<C4`00ol0003oIVIV
ofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02_nIVIT00ol0003o/k>c
ok>c/`0Fok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl01omoOgl00ol0003oIVIV
ofIVIP05ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH00_mVIVH00ol0003oOgmo
ogmoO`02ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001_nc/k<00ol0003oc<c<olc<c004olc<c003
o`000?nc/k?o/k>c00?o/k>c00Co0000oiVIVOnIVIWo00000omoOgl01?l0003oIVIVofIVI_l00004
oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?mo
OgooOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`01?l0003o/k>cok>c/ol00002oiVI
V@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<02_l0003oC4a<oda<C?l0
003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00?o0000ok>c
/onc/k<00_l000001omoOgoo0000ofIVI_mVIVKo0000oda<C?l000002?lc<c<03?l0003oC4a<oda<
C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000;oc<c<1_ooool1o`00007ooooo0Ooo
ool002Cooooo0_l00004ooooo`03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH0
0ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00[oVIVI0_l0000Hok>c/`03o`000?nIVIWo
VIVI00_oVIVI00?o0000ogmoOomoOgl01omoOgl00ol0003oIVIVofIVIP05ofIVIP03o`000?m<C4co
C4a<01?oC4a<00?o0000ofIVI_mVIVH00omVIVH01Ol0003oOgmoogmoOomoOgoo000000CoVIVI00?o
0000ok>c/onc/k<00onc/k<2o`0000Goc<c<00?o0000ok>c/onc/k<00onc/k<01Ol0003oVIVIoiVI
VOnIVIWo000000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go
<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWo0000
o`0000;o/k>c00?o0000olc<c?o<c<`01oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?mo
Ogoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP05
o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c00:o`000?nc/k?o/k>c
o`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<03?l0003o
C4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000;oc<c<1Oooool2o`0000;o
oooo000Tooooo`03o`000?oooooooooo00?ooooo6?m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`00
0?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02_nIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`00
0?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl01omoOgl00ol0003oIVIVofIVIP06ofIVIP03o`00
0?m<C4coC4a<01;oC4a<00?o0000ofIVI_mVIVH01?mVIVH01Ol0003oOgmoogmoOomoOgoo000000Co
VIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o
/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`05o`000?mVIVKoIVIVofIVI_l000000om<C4`0
0ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmo
Ool00002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01ol0003o/k>cok>c/onc/k?o0000
oiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co
0000oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<
c<`01_o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`00
0?lc<c?o<c<c00Ko<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c
/ol00002olc<c0Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo5om<
C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02_nI
VIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl01omo
Ogl00ol0003oIVIVofIVIP06ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH00omV
IVH01Ol0003oOgmoogmoOomoOgoo000000CoVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<
olc<c004olc<c003o`000?nc/k?o/k>c00Co/k>c00Co0000oiVIVOnIVIWo00000_moOgl01Ol0003o
IVIVofIVI_mVIVKo000000CoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<
C004o`000?mVIVKoIVIVo`0000;oOgmo00?o0000oiVIVOl000000onc/k<00ol0003oc<c<olc<c007
olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<
C?l00009oc<c<`03o`000?m<C4co000000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03
o`000?o<c<coc<c<00Koc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`;o00000_m<C4`0
0ol0003o<c<coc<c<`06oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`00
0?nc/k?o00000oo<c<`6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03oooo
oaKoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI
00[oVIVI0_l0000Hok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl01omoOgl00ol0
003oIVIVofIVIP06ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0
003oOgmoogmoO`02ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001_nc/k<00ol0003oc<c<olc<c003
olc<c003o`000?nc/k?o/k>c00Co/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`05o`000?mV
IVKoIVIVofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l0
00000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`0
1Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmoOol000000_mVIVH00ol0003oC4a<o`00
000:oc<c<`03o`000?m<C4co000000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`00
0?o<c<coc<c<00Koc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<
C4`00ol0003o<c<coc<c<`06oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVI
o`000?nc/k?o00000oo<c<`6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03
oooooaGoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWo
VIVI00[oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgoo
Ogmo00OoOgmo00?o0000ofIVI_mVIVH01_mVIVH00ol0003oC4a<oda<C00Doda<C003o`000?mVIVKo
IVIV00?oIVIV00?o0000ogmoOomoOgl00_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Ko/k>c00?o
0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`04ok>c/`05o`000?nIVIWoVIVIoiVIVOl00000
0_moOgl01?l0003oIVIVofIVI_l00004oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<
C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`00
0008olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT00ol0003oOgmoo`000002ofIVIP03o`00
0?m<C4co000000[o<c<c00?o0000oda<C?l000000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o
/k>c00?o0000olc<c?o<c<`01_o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIV
I_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmo
o`000?nIVIWo0000ok>c/ol00003olc<c0Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oo
oooooooo00?ooooo5?m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o
0000oiVIVOnIVIT02_nIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o
0000ogmoOomoOgl01omoOgl00ol0003oIVIVofIVIP06ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o
0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`02ogmoO`05o`000?nIVIWoVIVIoiVIVOl00000
1_nc/k<00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c00Co/k>c00Go0000oiVIVOnIVIWo
VIVIo`000002ogmoO`05o`000?mVIVKoIVIVofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c
<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@05o`000?nc
/k?o/k>cok>c/ol000002Oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo000000;o
IVIV00Co0000oda<C?m<C4co00002Olc<c<00ol0003oC4a<o`000002ofIVIP05o`000?moOgoo0000
oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`0000;oVIVI0_l0
00001OmVIVKo0000oda<C?m<C4co000000So<c<c00Co0000oda<C?m<C4coC4a<0_l000001_moOgoo
0000oiVIVOl0003o/k>co`0000Coc<c<1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000oooo
ooooool00ooooolCoda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl2o`00
00goVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo
00SoOgmo00?o0000ofIVI_mVIVH01_mVIVH00ol0003oC4a<oda<C00Coda<C003o`000?mVIVKoIVIV
00?oIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c
00Co/k>c00?o0000olc<c?o<c<`00_o<c<`2o`0000Go/k>c00Go0000oiVIVOnIVIWoVIVIo`000003
ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<
C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01Ol0003o/k>cok>c/onc/k?o0000
00Woc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000;oC4a<
00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP05o`000?moOgoo0000oiVI
VOl000000_nc/k<00ol0003oc<c<olc<c006olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmo
Ool0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<03?l0003oC4a<oda<C?l0003oIVIV
o`000?moOgoo0000oiVIVOl0003o/k>co`0000Coc<c<1_ooool1o`00007ooooo0Oooool002Cooooo
00?o0000ooooooooool00ooooolBoda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl0
2?moOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT0
2onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00KoIVIV00?o0000oda<C?m<C4`0
5?m<C4`00ol0003oIVIVofIVIP03ofIVIP03o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT0
0_nIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<0
1?nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0
003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol0
0002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002Oo<c<`01_l0003o/k>cok>c/ol0003oVIVIo`00
00;oOgmo00?o0000ofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<
o`0000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00[o
0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06
oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00001?o<c<`6
ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03oooooa7oC4a<00?o0000ofIV
I_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00coVIVI00?o0000ok>c
/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIV
I_mVIVH01_mVIVH00ol0003oC4a<oda<C00Doda<C003o`000?mVIVKoIVIV00?oIVIV00?o0000ogmo
OomoOgl00_moOgl00ol0003oVIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<
c?o<c<`00_o<c<`00ol0003o/k>cok>c/`05ok>c/`04o`000?nIVIWoVIVIo`0000?oOgmo00Co0000
ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l00000
0_mVIVH01?l0003oOgmoogmoOol00002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002Oo<c<`01_l0
003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo00000_m<C4`00ol0003o<c<c
oc<c<`07oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o
0000olc<c?o<c<`01oo<c<`00ol0003o/k>cok>c/`02o`000007ogmoOol0003oIVIVofIVI_l0003o
C4a<o`000008oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o
00001Oo<c<`6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03oooooa3oC4a<
00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI
0_l0000Hok>c/`03o`000?nIVIWoVIVI00[oVIVI0_l0000:ogmoO`03o`000?mVIVKoIVIV00KoIVIV
00?o0000oda<C?m<C4`05?m<C4`00ol0003oIVIVofIVIP03ofIVIP03o`000?moOgooOgmo00;oOgmo
00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`05ok>c/`03o`000?o<c<coc<c<00;oc<c<
00?o0000ok>c/onc/k<01?nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Go0000ofIVI_mV
IVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0
003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<
c<`01?l0003o/k>cok>c/ol00002oiVIV@06o`000?moOgooOgmoo`000?mVIVKo00000om<C4`00ol0
003o<c<coc<c<`06oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl00ol0003oVIVIo`00
0002ok>c/`03o`000?o<c<coc<c<00Koc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`00
0?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000
ogmoOol0003oVIVIo`000?nc/k?o00001Oo<c<`6ooooo`7o00000Oooool1ooooo`009?ooool2o`00
00Cooooo3om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVI
VOnIVIT03?nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00[oVIVI00?o0000ogmo
OomoOgl02OmoOgl00ol0003oIVIVofIVIP07ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIV
I_mVIVH00omVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c
/onc/k<01Onc/k<00ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c00Co/k>c00Go0000oiVI
VOnIVIWoVIVIo`000002ogmoO`05o`000?mVIVKoIVIVofIVI_l000001?m<C4`00ol0003o<c<coc<c
<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVI
oiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT01_l0
003oOgmoogmoOol0003oIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01_l0003oC4a<oda<
C?l0003oIVIVo`0000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c00:
o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<0
1_lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Goc<c<
1Oooool2o`0000;ooooo000Tooooo`03o`000?oooooooooo00?ooooo3_m<C4`00ol0003oIVIVofIV
IP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c
/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIV
IP07ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmo
O`02ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<
c002olc<c003o`000?nc/k?o/k>c00Co/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`04o`00
0?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004
o`000?mVIVKoIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006
olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000?oC4a<
00?o0000oc<c<olc<c<01_lc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00?o0000oiVI
VOl000000_nc/k<00ol0003oc<c<olc<c006olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_mo
Ogl2o`0000;oC4a<00?o0000oc<c<olc<c<01olc<c<00ol0003oC4a<o`000002ofIVIP;o000000Go
VIVIo`000?nc/k?o/k>co`000005olc<c0Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oo
oooooooo00?ooooo3Om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o
0000oiVIVOnIVIT02onIVIT2o`0001So/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmo
O`08ogmoO`03o`000?mVIVKoIVIV00OoIVIV00?o0000oda<C?m<C4`05?m<C4`00ol0003oIVIVofIV
IP03ofIVIP03o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c
/`05ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o0000ok>c/onc/k<01?nc/k<01Ol0003oVIVIoiVI
VOnIVIWo000000?oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go
<c<c00Go0000oda<C?m<C4coC4a<o`000003ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Co0000
ok>c/onc/k?o00002Oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@06o`000?moOgooOgmoo`000?mV
IVKo00000_m<C4`00ol0003o<c<coc<c<`07oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_mo
Ogl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00[o0000ok>c/onc/k?o0000
oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`07oc<c<`0;o`000?m<C4co
0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol000001_o<c<`6ooooo`7o00000Oooool1oooo
o`009?ooool00ol0003oooooooooo`03ooooo`coC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003o
OgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00coVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003o
VIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02?mVIVH00ol0003o
C4a<oda<C00Doda<C003o`000?mVIVKoIVIV00?oIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003o
VIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c00Go/k>c00?o0000olc<c?o<c<`00_o<c<`00ol0003o
/k>cok>c/`04ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01Ol0003oIVIVofIVI_mVIVKo
000000CoC4a<00?o0000oc<c<olc<c<01Olc<c<01Ol0003oC4a<oda<C?m<C4co000000?oIVIV00Co
0000ogmoOomoOgoo00000_nIVIT01?l0003o/k>cok>c/ol00009olc<c004o`000?nc/k?o/k>co`00
00;oVIVI00Ko0000ogmoOomoOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Ko
0000oda<C?m<C4co0000ofIVI_l00002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<
c<`01_o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`00
0?lc<c?o<c<c00Oo<c<c00_o0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`00
0006olc<c0Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo2om<C4`0
0ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT03?nIVIT0
0ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl0
0ol0003oIVIVofIVIP08ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH00omVIVH0
0ol0003oOgmoogmoO`03ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001onc/k<00ol0003oc<c<olc<
c002olc<c003o`000?nc/k?o/k>c00Go/k>c00Co0000oiVIVOnIVIWo00000omoOgl01Ol0003oIVIV
ofIVI_mVIVKo000000CoC4a<00?o0000oc<c<olc<c<01Olc<c<01Ol0003oC4a<oda<C?m<C4co0000
00?oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01?l0003o/k>cok>c/ol00009olc<c004o`000?nc
/k?o/k>co`0000;oVIVI00Ko0000ogmoOomoOgoo0000ofIVI_l00003oda<C003o`000?lc<c?o<c<c
00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o
0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@;o000000GoIVIVo`000?m<C4co
C4a<o`000009oc<c<`07o`000?m<C4co0000ofIVI_l0003oOgmoo`000002oiVIV@;o00001oo<c<`6
ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`[oC4a<00?o0000ofIV
I_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI0_l0000Gok>c
/`;o00003OnIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00SoIVIV00?o0000oda<
C?m<C4`05?m<C4`00ol0003oIVIVofIVIP04ofIVIP03o`000?moOgooOgmo00;oOgmo00?o0000oiVI
VOnIVIT00_nIVIT00ol0003o/k>cok>c/`05ok>c/`05o`000?o<c<coc<c<olc<c?l000001onc/k<0
1Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`00
0?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04
o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01oo<c<`01?l0003o/k>cok>c/ol00002
oiVIV@03o`000?moOgoo000000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`06o`000?m<
C4coC4a<o`000?mVIVKo00000_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ko
c<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<c
oc<c<`06oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o0000
1oo<c<`6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`WoC4a<00?o
0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00coVIVI00?o
0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo0_l0
000:ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmo
O`03ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01Onc/k<01Ol0003oc<c<olc<
c?o<c<co000000Oo/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`05o`000?mVIVKoIVIVofIV
I_l000001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIV
I_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Co
0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000Wo
<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000
olc<c?o<c<`01_o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<
C003o`000?lc<c?o<c<c00Ko<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo
0000ok>c/ol00007olc<c0Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?o
oooo2?m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnI
VIT03?nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00[oVIVI0_l0000:ogmoO`03
o`000?mVIVKoIVIV00WoIVIV00?o0000oda<C?m<C4`05?m<C4`00ol0003oIVIVofIVIP04ofIVIP03
o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`05ok>c/`05
o`000?o<c<coc<c<olc<c?l000001onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Co0000
ofIVI_mVIVKo00001Om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Co
0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Oo
c<c<00Co0000ok>c/onc/k?o00000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP04o`000?m<C4co
C4a<o`0000So<c<c00Co0000oda<C?m<C4coC4a<0_l00002ogmoO`03o`000?nIVIWo000000;o/k>c
00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/onc/k<2o`000005ogmoOol0003oIVIVofIV
I_l000000_m<C4`00ol0003o<c<coc<c<`05oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_mo
Ogl2o`000003ok>c/ol0003oc<c<00Ooc<c<1_ooool1o`00007ooooo0Oooool001Wooooo00Gok^k^
oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo00?ooooo1om<C4`00ol0003oIVIVofIV
IP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT2o`0001Oo/k>c0_l0
000<oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02OmVIVH00ol0003oC4a<oda<
C00Doda<C003o`000?mVIVKoIVIV00CoIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVI
V@02oiVIV@03o`000?nc/k?o/k>c00Go/k>c00?o0000olc<c?o<c<`00_o<c<`00ol0003o/k>cok>c
/`04ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01Ol0003oIVIVofIVI_mVIVKo000000Co
C4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`00
00;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o
/k>cok>c/ol000000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c
00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0
003oc<c<olc<c006olc<c009o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIV00;o0000
00?oC4a<o`000?lc<c<01olc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0
003o/k>co`0000Soc<c<1_ooool1o`00007ooooo0Oooool001Wooooo00GoEEEEogMgMoooooooV9RH
ob4Q8@06ooooo`03o`000?oooooooooo00?ooooo1_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`00
0?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`00
0?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP09ofIVIP03o`00
0?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH01?mVIVH01Ol0003oOgmoogmoOomoOgoo000000Go
VIVI00?o0000ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c00Co
/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`05o`000?mVIVKoIVIVofIVI_l000001?m<C4`0
0ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_mo
Ogl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o
/k>co`000002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<01ol0
003oC4a<oda<C?m<C4co0000ofIVI_l000000_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<
c<coc<c<00Koc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`0
0ol0003o<c<coc<c<`06oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`00
0?nc/k?o00002?o<c<`6ooooo`7o00000Oooool1ooooo`006Oooool01Ol0003ooooooooooooooooo
000000Kooooo0ol00003ooooo`GoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`09
ogmoO`03o`000?nIVIWoVIVI00[oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0<
oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02OmVIVH00ol0003oC4a<oda<C00D
oda<C003o`000?mVIVKoIVIV00CoIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@02
oiVIV@03o`000?nc/k?o/k>c00Ko/k>c00Go0000olc<c?o<c<coc<c<o`000006ok>c/`03o`000?nI
VIWoVIVI00;oVIVI00Co0000ogmoOomoOgoo00000omVIVH00ol0003oC4a<oda<C003oda<C003o`00
0?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;o
Ogmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>c
ok>c/ol000000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Wo
0000oda<C?m<C4coC4a<o`000?mVIVKo0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00008
olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co00002Olc<c<0
0ol0003oC4a<oda<C002o`0000;oOgmo00Go0000oiVIVOl0003o/k>co`000008olc<c004o`000?oo
ooooooooooooo`?o00000_ooool001Wooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`03o`00
0?oooooooooo00?ooooo1?m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo
00?o0000oiVIVOnIVIT02_nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00coVIVI
00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP09ofIVIP03o`000?m<C4coC4a<01GoC4a<
00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00?oVIVI
00?o0000ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c00Co/k>c
00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`05o`000?mVIVKoIVIVofIVI_l000001?m<C4`00ol0
003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl0
1?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>c
o`000002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<01_l0003o
C4a<oda<C?l0003oIVIVo`0000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006
olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl2o`0000;oC4a<00?o0000oc<c<olc<c<0
1olc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<co
c<c<00Koc<c<00?o0000ooooooooool00oooool1o`00007ooooo0Oooool001Wooooo00Go0000oeEE
EOl0003o410@olc<c006ooooo`03o`000?oooooooooo00?ooooo0om<C4`00ol0003oIVIVofIVIP0;
ofIVIP;o00002_moOgl00ol0003oVIVIoiVIV@0:oiVIV@;o00005onc/k<2o`0000goVIVI00?o0000
ogmoOomoOgl02?moOgl2o`0000_oIVIV00?o0000oda<C?m<C4`05Om<C4`00ol0003oIVIVofIVIP04
ofIVIP03o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`06
ok>c/`?o000000?oc<c<o`000?nc/k<01_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Go
0000ofIVI_mVIVKoIVIVo`000005oda<C003o`000?lc<c?o<c<c00Go<c<c00Go0000oda<C?m<C4co
C4a<o`000003ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008
olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<
C4coC4a<o`0000Wo<c<c00So0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000;oVIVI00Co0000
ok>c/onc/k?o00002?o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003o
C4a<o`0000[o<c<c00_o0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`000008
olc<c003o`000?oooooooooo00Cooooo0Ol00001ooooo`7ooooo000Iooooo`03oeEEEOn7QhOooooo
00Sooooo00?o0000ooooooooool00oooool2oda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmo
OomoOgl02OmoOgl00ol0003oVIVIoiVIV@0:oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVI
VOnIVIT03?nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00[oIVIV00?o0000oda<
C?m<C4`05Om<C4`00ol0003oIVIVofIVIP04ofIVIP03o`000?moOgooOgmo00;oOgmo00?o0000oiVI
VOnIVIT00_nIVIT00ol0003o/k>cok>c/`06ok>c/`04o`000?nc/k?o/k>co`0000So/k>c00Go0000
oiVIVOnIVIWoVIVIo`000002ogmoO`05o`000?mVIVKoIVIVofIVI_l000001?m<C4`00ol0003o<c<c
oc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000omVIVH01?l0003oOgmoogmoOol00002oiVI
V@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o
0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`09o`000?m<C4coC4a<oda<C?l0
003oIVIVo`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`03?l0003o/k>cok>c
/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000[o<c<c0_l00002ofIVIP07o`000?mo
Ogoo0000oiVIVOl0003o/k>co`000008olc<c003o`000?oooooooooo00Cooooo0Ol00001ooooo`7o
oooo000Iooooo`03omgMgOl@413oV9RH00Sooooo00?o0000ooooooooool00oooool00om<C4co0000
ofIVIP0<ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02_nIVIT00ol0003o/k>c
ok>c/`0Fok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIV
ofIVIP0:ofIVIP03o`000?m<C4coC4a<01GoC4a<00?o0000ofIVI_mVIVH01?mVIVH00ol0003oOgmo
ogmoO`02ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<01Onc/k<00ol0003oc<c<
o`000009ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01?l0003oIVIVofIVI_l00005oda<
C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002
ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c
/onc/k?o000000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`05
o`000?m<C4coC4a<oda<C?l000000_mVIVH2o`0000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`0
1?l0003o/k>cok>c/ol00002oiVIV@;o000000GoIVIVo`000?m<C4coC4a<o`000009oc<c<`07o`00
0?m<C4co0000ofIVI_l0003oOgmoo`000002oiVIV@;o00002Oo<c<`00ol0003oooooooooo`04oooo
o`7o00000Oooool1ooooo`006_ooool01?o<c<coA4A4o`000?l@4106ooooo`03o`000?oooooooooo
00?ooooo00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI
00[oVIVI0_l0000Hok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl2o`00
00coIVIV00?o0000oda<C?m<C4`05Om<C4`00ol0003oIVIVofIVIP04ofIVIP03o`000?moOgooOgmo
00;oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`06ok>c/`04o`000?o<c<coc<c<
o`0000Oo/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`05o`000?mVIVKoIVIVofIVI_l00000
1?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo
00000omoOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Goc<c<0_l00003ok>c
/`03o`000?nIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06
oc<c<`03o`000?m<C4coC4a<00;o000000CoIVIVo`000?moOgoo00000_nIVIT01?l0003o/k>cok>c
/ol00008olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o
0000oc<c<olc<c<01_lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o
/k>co`0000Woc<c<00?o0000ooooooooool01?ooool1o`00007ooooo0Oooool002Cooooo00?o0000
ooooooooool00oooool=ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02_nIVIT0
0ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl0
0ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH00omVIVH0
0ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<01_nc/k<0
0ol0003oc<c<o`000007ok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`00
0003ofIVIP03o`000?m<C4coC4a<00;oC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<
C002oda<C004o`000?mVIVKoIVIVo`0000?oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003o
c<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00?o0000oiVIVOl000000_moOgl01?l0003o
IVIVofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH0
0ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00?o0000ok>c/ol000000_nI
VIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<
oda<C?l0003oIVIV00;o00000_nIVIT00ol0003o/k>co`000009olc<c003o`000?oooooooooo00Co
oooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo3?mVIVH00ol0003oOgmo
ogmoO`09ogmoO`03o`000?nIVIWoVIVI00[oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVI
oiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH03?mVIVH00ol0003oC4a<
oda<C00Eoda<C003o`000?mVIVKoIVIV00CoIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVI
oiVIV@03oiVIV@03o`000?nc/k?o/k>c00So/k>c00?o0000ok>c/onc/k<01_nc/k<01Ol0003oVIVI
oiVIVOnIVIWo000000?oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c
00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00003ogmoO`04o`000?nIVIWo
VIVIo`0000?o/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`06o`000?nI
VIWoVIVIo`000?moOgoo00000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`04o`000?m<C4coC4a<
o`0000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00008olc<c008o`000?nc
/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000Oo<c<c00[o0000
oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<
c003o`000?nc/k?ooooo00Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?o
oooo2omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00[oVIVI0_l0000Hok>c/`03
o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0<ofIVIP03
o`000?m<C4coC4a<01GoC4a<00?o0000ofIVI_mVIVH01?mVIVH00ol0003oOgmoogmoO`02ogmoO`03
o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<04Onc/k<01?l0003oVIVIoiVIVOnIVIT2o`00
00?oOgmo00Co0000ofIVI_mVIVKo00001Om<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4co
C4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`00
0?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@06o`000?moOgooOgmoo`00
0?mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o
0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00008olc<c00:o`000?nc/k?o/k>co`000?nI
VIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02_l0003oC4a<oda<
C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o0000
ok>c/ol000001Oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool:ofIV
IP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02_nIVIT00ol0003o/k>cok>c/`0Gok>c
/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0<ofIV
IP03o`000?m<C4coC4a<01GoC4a<00?o0000ofIVI_mVIVH01OmVIVH00ol0003oOgmoogmoO`02ogmo
O`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<04_nc/k<01Ol0003oVIVIoiVIVOnIVIWo
000000CoOgmo00Co0000ofIVI_mVIVKo00001Om<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<
C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03
o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@06o`000?moOgooOgmo
o`000?mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV
00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00008olc<c00:o`000?nc/k?o/k>co`00
0?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02_l0003oC4a<
oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o
0000ok>c/ol000001Oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool9
ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02_nIVIT00ol0003o/k>cok>c/`0G
ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;
ofIVIP;o00005om<C4`00ol0003oIVIVofIVIP05ofIVIP03o`000?moOgooOgmo00;oOgmo00?o0000
oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0Aok>c/`05o`000?nIVIWoVIVIoiVIVOl000001?mo
Ogl01?l0003oIVIVofIVI_l00005oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`0
0_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<
c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Ko0000ogmoOomoOgoo0000ofIV
I_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH01_l0003o
OgmoogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01_l0003o/k>cok>c/ol0
003oVIVIo`0000;oOgmo0_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Wo0000oda<C?l0003o
IVIVo`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c003o`000?nc/k?o
000000Kooooo0Ol00001ooooo`7ooooo000Tooooo`;o00001?ooool8ofIVIP03o`000?moOgooOgmo
00SoOgmo0_l0000=oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0
003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0
003oIVIVofIVIP05ofIVIP03o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0
003o/k>cok>c/`0Bok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01Ol0003oIVIVofIVI_mV
IVKo000000CoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C0;o00000_mV
IVH01?l0003oOgmoogmoOol00002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01Ol0003o
/k>cok>c/onc/k?o000000;oVIVI00Ko0000ogmoOomoOgoo0000ofIVI_l00003oda<C003o`000?lc
<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVIV@03o`00
0?nc/k?o000000Woc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<
C4`00ol0003o<c<coc<c<`07oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000
00;o/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003o/k>co`000005ooooo`;o00000_ooool002Co
oooo00?o0000ooooooooool00oooool7ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnI
VIT03?nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomo
Ogl02?moOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mV
IVH01OmVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc
/k<04Onc/k<00ol0003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol000000omVIVH00ol0
003oC4a<oda<C002oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0
003oIVIVofIVI_mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<
c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01_l0003oOgmoogmoOol0003oIVIVo`00
00?oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo
000000;oVIVI00?o0000ok>c/ol000002Oo<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo
0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Wo0000oda<C?l0003oIVIVo`000?mo
Ogoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c003o`000?nc/k?o000000Kooooo
0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo1_mVIVH00ol0003oOgmoogmo
O`08ogmoO`03o`000?nIVIWoVIVI00coVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVI
V@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH2o`0001SoC4a<00?o
0000ofIVI_mVIVH01OmVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o
0000ok>c/onc/k<04_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00?o0000ofIVI_mVIVH0
0_mVIVH01Ol0003oC4a<oda<C?m<C4co000000Oo<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0003o
IVIVofIVI_mVIVKo000000?oOgmo00Co0000oiVIVOnIVIWo00000_nc/k<00ol0003oc<c<olc<c006
olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP04o`00
0?m<C4coC4a<o`0000So<c<c00Co0000oda<C?m<C4co00000omVIVH2o`0000;oVIVI00Co0000ok>c
/onc/k?o00002?o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<
C003o`000?lc<c?o<c<c00Oo<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00000
0_nc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o0000oiVIV@Kooooo0Ol00001ooooo`7o
oooo000Tooooo`03o`000?oooooooooo00?ooooo1OmVIVH00ol0003oOgmoogmoO`08ogmoO`03o`00
0?nIVIWoVIVI00_oVIVI0_l0000Hok>c/`03o`000?nIVIWoVIVI00[oVIVI0_l0000:ogmoO`03o`00
0?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP05ofIVIP03o`00
0?moOgooOgmo00?oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`0Bok>c/`03o`00
0?nIVIWoVIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`000003ofIVIP03o`000?m<C4coC4a<00;o
C4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`00
00?oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o
/k>cok>c/ol000000_nIVIT00ol0003oOgmoo`000002ofIVIP05o`000?m<C4coC4a<oda<C?l00000
2?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl000000onc/k<00ol0
003oc<c<olc<c006olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;o
C4a<00?o0000oc<c<olc<c<01_lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVI
VOl0003o/k>co`0000Woc<c<00Go0000ok>c/ol0003oVIVIo`000005ooooo`7o00000Oooool1oooo
o`009?ooool00ol0003oooooooooo`03ooooo`CoIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003o
VIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003o
OgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003o
IVIVofIVIP05ofIVIP03o`000?moOgooOgmo00?oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o
/k>cok>c/`0Bok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl00ol0003oIVIVofIVIP02ofIV
IP03o`000?m<C4coC4a<00;oC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<
C004o`000?mVIVKoIVIVo`0000?oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<
c006olc<c004o`000?nc/k?o/k>co`0000?oVIVI00?o0000ogmoOol000000_mVIVH01Ol0003oC4a<
oda<C?m<C4co000000So<c<c00Co0000oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nIVIWo
000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003o/k>co`000002oiVIV@05o`000?moOgoo
0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo
0000ogmoOol0003oVIVIo`000?nc/k?o00002Oo<c<`01Ol0003o/k>co`000?nIVIWo000000Gooooo
0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo0omVIVH00ol0003oOgmoogmo
O`08ogmoO`03o`000?nIVIWoVIVI00coVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVI
V@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<
C00Goda<C003o`000?mVIVKoIVIV00KoIVIV00?o0000ogmoOomoOgl00omoOgl00ol0003oVIVIoiVI
V@02oiVIV@03o`000?nc/k?o/k>c01;o/k>c00?o0000oiVIVOnIVIT00_nIVIT01?l0003oOgmoogmo
Ool00004ofIVIP03o`000?m<C4coC4a<00;oC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<
oda<C002oda<C004o`000?mVIVKoIVIVo`0000?oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0
003oc<c<olc<c005olc<c005o`000?nc/k?o/k>cok>c/ol000000onIVIT2o`0000;oIVIV00Go0000
oda<C?m<C4coC4a<o`000008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol00000
0_nIVIT01?l0003o/k>cok>c/ol00008olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0
0002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000
oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o0000oiVIVOl000001_oo
ool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool2ofIVIP03o`000?moOgoo
Ogmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT2o`0001So/k>c00?o0000oiVIVOnIVIT02_nIVIT2
o`0000[oOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKo
IVIV00KoIVIV00?o0000ogmoOomoOgl00omoOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o
/k>c01;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`05o`000?mVIVKoIVIVofIVI_l00000
1Om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Co0000ofIVI_mVIVKo
00000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0
003o/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l0
0009oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Co0000ogmoOol0003oVIVI0_l00002ok>c/`03
o`000?o<c<coc<c<00Koc<c<00Wo0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVH00_l0
00000om<C4co0000oc<c<`07oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVI
o`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>co`000?l0003oOgmo00Kooooo0Ol0
0001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo00?oIVIVo`000?moOgl02OmoOgl0
0ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02_nIVIT0
0ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`0
0ol0003oIVIVofIVIP07ofIVIP03o`000?moOgooOgmo00?oOgmo00?o0000oiVIVOnIVIT00onIVIT0
0ol0003o/k>cok>c/`0Aok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`00
0003ofIVIP03o`000?m<C4coC4a<00?oC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<
C002oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000?o
/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmo
Ool000000_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Go
0000ogmoOol0003oVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00[o0000ok>c/onc/k?o
0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0:o`000?m<
C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`0
1Ol0003o/k>co`000?l0003oOgmo00Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooo
oooo00?ooooo00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o
/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKo
IVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP07ofIVIP03o`000?moOgoo
Ogmo00?oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0Bok>c/`05o`000?nIVIWo
VIVIoiVIVOl000000omoOgl00ol0003oIVIVofIVIP02ofIVIP03o`000?m<C4coC4a<00;oC4a<00?o
0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C003oda<C004o`000?mVIVKoIVIVo`0000?oOgmo
00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c
/ol000000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000Wo<c<c00Co0000
oda<C?m<C4co00000_mVIVH00ol0003oOgmoogmoO`02o`0000?o/k>c00?o0000olc<c?o<c<`01_o<
c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o
<c<c00Oo<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003o
c<c<olc<c006olc<c003o`000?nc/k?o/k>c00;o000000?oOgmoooooooooool01?ooool1o`00007o
oooo0Oooool002Cooooo00?o0000ooooooooool00oooool:ogmoO`03o`000?nIVIWoVIVI00_oVIVI
0_l0000Gok>c/`;o00003OnIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV
00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP06ofIVIP;o00001OmoOgl00ol0003oVIVI
oiVIV@03oiVIV@03o`000?nc/k?o/k>c01;o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmo
ogmoOomoOgoo000000?oIVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`04oc<c<`03
o`000?m<C4coC4a<00;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`04o`000?nIVIWoVIVI
o`0000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co
0000ogmoOomoOgoo00000_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`06o`000?m<C4coC4a<o`00
0?mVIVKo00000_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00[o0000
ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`07oc<c
<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`0
1_o<c<`01ol0003o/k>co`000?nIVIWo0000ogmoOol000001Oooool1o`00007ooooo0Oooool002Co
oooo0_l00004ooooo`WoOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`0Fok>c/`03
o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl2o`0000coIVIV00?o0000oda<C?m<
C4`06?m<C4`00ol0003oIVIVofIVIP06ofIVIP03o`000?moOgooOgmo00CoOgmo00?o0000oiVIVOnI
VIT00onIVIT00ol0003o/k>cok>c/`0Bok>c/`05o`000?nIVIWoVIVIoiVIVOl000001?moOgl01Ol0
003oIVIVofIVI_mVIVKo000000GoC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C002
oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`00
0?o<c<coc<c<00Goc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`00
00;oIVIV00Co0000oda<C?m<C4co00002?lc<c<01ol0003oC4a<oda<C?m<C4co0000ofIVI_l00000
0_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00[o0000ok>c/onc/k?o
0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`07oc<c<`0;o`000?m<
C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol000002Oo<c<`01ol0003o/k>co`000?nI
VIWo0000ogmoOol000001?ooool2o`0000;ooooo000Tooooo`03o`000?oooooooooo00?ooooo2?mo
Ogl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02_nI
VIT2o`0000[oOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Hoda<C003o`000?mV
IVKoIVIV00KoIVIV00?o0000ogmoOomoOgl01?moOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc
/k?o/k>c01;o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000?oIVIV
00?o0000oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00;oC4a<
00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<
c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@05o`000?moOgooOgmoogmoOol000000_mV
IVH01?l0003oC4a<oda<C?l00008oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl00ol0
003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0
003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`07oc<c<`09o`000?m<C4co0000ofIV
I_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01ol0003o/k>co`00
0?nIVIWo0000ogmoOol000001_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool0
0oooool7ogmoO`03o`000?nIVIWoVIVI00_oVIVI0_l0000Gok>c/`;o00003?nIVIT00ol0003oOgmo
ogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`06?m<C4`00ol0003oIVIV
ofIVIP06ofIVIP03o`000?moOgooOgmo00CoOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>c
ok>c/`0Bok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`000003ofIVIP03
o`000?m<C4coC4a<00?oC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C003oda<C004
o`000?mVIVKoIVIVo`0000?oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006
olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP04o`00
0?m<C4coC4a<o`0000So<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00?o0000
oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000
ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02_l0003oC4a<oda<C?l0003o
IVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Oo0000ok>c/ol0
003oVIVIo`000?moOgoo000000Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo
00?ooooo1_moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVI
VOnIVIT03?nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00[oIVIV00?o0000oda<
C?m<C4`06?m<C4`00ol0003oIVIVofIVIP07ofIVIP03o`000?moOgooOgmo00CoOgmo00?o0000oiVI
VOnIVIT00onIVIT00ol0003o/k>cok>c/`0Bok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000ogmo
OomoOgooOgmoo`000003ofIVIP03o`000?m<C4coC4a<00?oC4a<00?o0000oc<c<olc<c<01?lc<c<0
0ol0003oC4a<oda<C003oda<C004o`000?mVIVKoIVIVo`0000?oOgmo00Co0000oiVIVOnIVIWo0000
0onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003o
OgmoogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Oo0000oda<C?m<C4coC4a<o`00
0?mVIVKo000000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c003o`00
0?nc/k?o000000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko
<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<
olc<c006olc<c007o`000?nc/k?o0000oiVIVOl0003oOgmoo`000006ooooo`7o00000Oooool1oooo
o`009?ooool00ol0003oooooooooo`03ooooo`KoOgmo00?o0000oiVIVOnIVIT02_nIVIT00ol0003o
/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003o
IVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<01SoC4a<00?o0000ofIVI_mVIVH02?mVIVH00ol0003o
OgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<04onc/k<01Ol0003o
VIVIoiVIVOnIVIWo000000?oOgmo00Go0000ofIVI_mVIVKoIVIVo`000006oda<C003o`000?lc<c?o
<c<c00Co<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00003ogmoO`05o`000?nI
VIWoVIVIoiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol0
00000_nIVIT01_l0003oOgmoogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01olc<c<0
1ol0003oC4a<oda<C?m<C4co0000ofIVI_l000000_moOgl00ol0003oVIVIo`000002ok>c/`03o`00
0?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT01?l0003oOgmoo`000?l00003oda<
C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4co0000ofIVIP02o`0000;oVIVI00?o0000
ok>c/ol000002Oo<c<`01ol0003o/k>co`000?nIVIWo0000ogmoOol000001_ooool1o`00007ooooo
0Oooool002Cooooo00?o0000ooooooooool00oooool5ogmoO`03o`000?nIVIWoVIVI00[oVIVI00?o
0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo00WoOgmo00?o
0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00SoIVIV00?o
0000ogmoOomoOgl01?moOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c01;o/k>c00?o
0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000?oIVIV00?o0000oda<C?m<C4`0
0om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Co0000ofIVI_mVIVKo
00000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0
003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01?l0003oC4a<oda<
C?l00009oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00002
ok>c/`03o`000?o<c<coc<c<00Koc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mV
IVKo00000om<C4`00ol0003o<c<coc<c<`05oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmo
Ool0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02?l0003o/k>co`000?nIVIWo0000
ogmoOol0003oIVIV1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool4
ogmoO`03o`000?nIVIWoVIVI00[oVIVI0_l0000Gok>c/`;o00003OnIVIT00ol0003oOgmoogmoO`08
ogmoO`;o00003?mVIVH2o`0001SoC4a<0_l00009ofIVIP;o00001_moOgl00ol0003oVIVIoiVIV@03
oiVIV@03o`000?nc/k?o/k>c01?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`03o`000?mV
IVKoIVIV00;oIVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<
C4coC4a<00?oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000?o
/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Ko0000ogmo
OomoOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00So<c<c00Oo0000oda<C?m<C4co0000
ofIVI_l0003oOgmo00;o000000GoVIVIo`000?nc/k?o/k>co`000008olc<c00;o`000?nc/k?o/k>c
ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0<
o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00002Oo<c<`02Ol0003o
/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000005ooooo`7o00000Oooool1ooooo`009?ooool0
0ol0003oooooooooo`03ooooo`?oOgmo00?o0000oiVIVOnIVIT02_nIVIT00ol0003o/k>cok>c/`0F
ok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0:
ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02?mVIVH00ol0003oOgmoogmoO`05
ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<04onc/k<01Ol0003oVIVIoiVIVOnI
VIWo000000?oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C003oda<C003o`000?lc
<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00om<C4`01?l0003oIVIVofIVI_l00002ogmoO`05o`00
0?nIVIWoVIVIoiVIVOl000000onc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o
/k>c00Co0000oiVIVOnIVIWo00000_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c
00So<c<c00So0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o
00002?o<c<`02ol0003o/k>cok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<
00?o0000oc<c<olc<c<01_lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0
003o/k>co`0000Woc<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000001Oooool1
o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool2ogmoO`03o`000?nIVIWoVIVI
00[oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo
00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV
00WoIVIV00?o0000ogmoOomoOgl01?moOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c
01?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000
oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Co0000
ofIVI_mVIVKo00000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000?o/k>c00?o0000olc<c?o<c<`0
1_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01?l0
003oC4a<oda<C?l00009oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl00ol0003oVIVI
o`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmo
o`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`07oc<c<`09o`000?m<C4co0000ofIVI_l0003o
Ogmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003o/k>cok>c/`02o`00
0004ogmoOol0003oIVIVo`0000Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo
00?ooooo00?oOgmoo`000?nIVIT02onIVIT2o`0001So/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0
003oOgmoogmoO`08ogmoO`;o00003?mVIVH2o`0001SoC4a<0_l0000:ofIVIP03o`000?moOgooOgmo
00CoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`0Cok>c/`03o`000?nIVIWoVIVI
00;oVIVI00Go0000ogmoOomoOgooOgmoo`000003ofIVIP03o`000?m<C4coC4a<00?oC4a<00?o0000
oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C003oda<C005o`000?mVIVKoIVIVofIVI_l000000_mo
Ogl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<0
0_nc/k<01_l0003oVIVIoiVIVOl0003oOgmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008
oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Ko0000ogmoOomoOgoo0000oiVIVOl00002ok>c/`03
o`000?o<c<coc<c<00Ooc<c<00?o0000ok>c/ol000000_nIVIT01Ol0003oOgmoo`000?mVIVKo0000
00;oC4a<00?o0000oc<c<olc<c<01olc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVI
o`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000
ofIVI_l000001_ooool1o`00007ooooo0Oooool002Cooooo0_l00004ooooo`03o`000?nIVIWoVIVI
00[oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo
00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV
00WoIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c
01?o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000;oIVIV00?o0000
oda<C?m<C4`01?m<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Go0000
ofIVI_mVIVKoIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`0
1Oo<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01Ol0
003oC4a<oda<C?m<C4co000000So<c<c00Co0000oda<C?m<C4co00000_mVIVH01_l0003oOgmoogmo
Ool0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01oo<c<`01Ol0003o/k>co`000?nIVIWo0000
00;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`0;o`000?m<C4co0000
ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol000002Oo<c<`02Ol0003o/k>co`000?nIVIWo0000
ogmoOol0003oIVIVo`000005ooooo`;o00000_ooool002Cooooo00?o0000ooooooooool00oooool<
oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08
ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP09
ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`0C
ok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`000003ofIVIP03o`000?m<
C4coC4a<00CoC4a<00?o0000oc<c<olc<c<00olc<c<00ol0003oC4a<oda<C003oda<C005o`000?mV
IVKoIVIVofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Go
c<c<00?o0000ok>c/onc/k<00_nc/k<01_l0003oVIVIoiVIVOl0003oOgmoo`0000;oIVIV00?o0000
oda<C?m<C4`00_m<C4`00ol0003o<c<coc<c<`05oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Ko
0000ogmoOomoOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00?o0000ok>c/ol0
00000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01olc<c<02Ol0
003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<
00Go0000ok>c/ol0003oVIVIo`000002ogmoO`;o000000?oC4a<ooooooooool01?ooool1o`00007o
oooo0Oooool002Cooooo00?o0000ooooooooool00oooool;oiVIV@;o00006?nc/k<00ol0003oVIVI
oiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<
oda<C00Goda<C003o`000?mVIVKoIVIV00[oIVIV00?o0000ogmoOomoOgl01?moOgl00ol0003oVIVI
oiVIV@04oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmo
ogmoOomoOgoo000000CoIVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`04oc<c<`03
o`000?m<C4coC4a<00?oC4a<00Co0000ofIVI_mVIVKo00000omoOgl01?l0003oVIVIoiVIVOl00003
ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?mo
OgooOgmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`04o`000?m<C4coC4a<o`00
00;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00008olc<c004o`000?nc/k?o
/k>co`0000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c
00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<
c006olc<c00:o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C0Kooooo0Ol00001
ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo2_nIVIT00ol0003o/k>cok>c/`0Gok>c
/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0<ofIV
IP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`05ogmo
O`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<04onc/k<00ol0003oVIVIoiVIV@02oiVI
V@05o`000?moOgooOgmoogmoOol000001?mVIVH00ol0003oC4a<oda<C003oda<C003o`000?lc<c?o
<c<c00Co<c<c00?o0000oda<C?m<C4`00om<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nI
VIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;o
VIVI00Co0000ogmoOomoOgoo00000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Co0000
oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000?o/k>c00?o0000olc<c?o<c<`0
1_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0
003o<c<coc<c<`06oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o
/k>c00?o0000olc<c?o<c<`01_o<c<`02_l0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`00
0?m<C4`6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`WoVIVI00?o
0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o
0000ofIVI_mVIVH02omVIVH2o`0001SoC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmo
O`05ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<04onc/k<00ol0003oVIVIoiVI
V@02oiVIV@05o`000?moOgooOgmoogmoOol000001?mVIVH00ol0003oC4a<oda<C003oda<C003o`00
0?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00om<C4`01?l0003oIVIVofIVI_l00003ogmoO`04
o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o
000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c
00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVIV@05o`000?nc/k?o/k>cok>c
/ol000002?o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003
o`000?lc<c?o<c<c00Oo<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl000000_nc
/k<00ol0003oc<c<olc<c006olc<c003o`000?nc/k?o000000;oVIVI0_l000001OmVIVKo0000oda<
C?m<C4co000000Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo2OnI
VIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?mo
Ogl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02_mV
IVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<04onc
/k<00ol0003oVIVIoiVIV@02oiVIV@03o`000?moOgooOgmo00;oOgmo00Go0000ofIVI_mVIVKoIVIV
o`000006oda<C003o`000?lc<c?o<c<c00?o<c<c00?o0000oda<C?m<C4`00om<C4`01Ol0003oIVIV
ofIVI_mVIVKo000000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000003ok>c/`03o`000?o<c<coc<c<
00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Go
0000oda<C?m<C4coC4a<o`000008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol0
00000_nIVIT01?l0003o/k>cok>c/ol00008olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Go0000
ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00co0000oda<C?m<C4co0000
ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00009olc<c009o`000?nc/k?o0000oiVIVOl0003o
Ogmoo`000?mVIVKo000000;oC4a<00?o0000ooooooooool00oooool1o`00007ooooo0Oooool002Co
oooo00?o0000ooooooooool00oooool8oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnI
VIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00coIVIV00?o0000oda<C?m<
C4`05_m<C4`00ol0003oIVIVofIVIP0:ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnI
VIT01OnIVIT00ol0003o/k>cok>c/`0Cok>c/`03o`000?nIVIWoVIVI00;oVIVI00?o0000ogmoOomo
Ogl00_moOgl01Ol0003oIVIVofIVI_mVIVKo000000GoC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0
003oC4a<oda<C003oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01Ol0003oVIVIoiVIVOnI
VIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI
00Ko0000ogmoOomoOgoo0000ofIVI_l00004oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<
C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Co
0000ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc
<c<01_lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Wo
c<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003ooooooooo
o`03ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`OoVIVI00?o0000
ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000
ofIVI_mVIVH02omVIVH2o`0001SoC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`05
ogmoO`03o`000?nIVIWoVIVI00GoVIVI00?o0000ok>c/onc/k<04onc/k<00ol0003oVIVIoiVIV@02
oiVIV@03o`000?moOgooOgmo00;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000005oda<C003o`000?lc
<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00om<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo
00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Goc<c<00Go0000ok>c/onc
/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`00
0008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>c
ok>c/ol00009olc<c003o`000?nc/k?o000000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<
C003o`000?lc<c?o<c<c00Oo<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00000
0_nc/k<00ol0003oc<c<olc<c006olc<c003o`000?nc/k?o/k>c00;o000000OoOgmoo`000?mVIVKo
IVIVo`000?m<C4co000000Kooooo0Ol00001ooooo`7ooooo000Iooooo`05olc<c?lQ8B7o0000ob4Q
8Oo<c<`01_ooool00ol0003oooooooooo`03ooooo`GoVIVI0_l0000Hok>c/`03o`000?nIVIWoVIVI
00[oVIVI0_l0000:ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`2o`00
00coIVIV00?o0000ogmoOomoOgl01_moOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c
01?o/k>c00?o0000oiVIVOnIVIT00onIVIT01Ol0003oOgmoogmoOomoOgoo000000CoIVIV00?o0000
oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Go0000
ofIVI_mVIVKoIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`0
1Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co0000ofIVI_mV
IVKo00000_m<C4`2o`0000Oo<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP03o`000?moOgoo
000000;oVIVI00?o0000ok>c/ol000002_o<c<`00ol0003o/k>co`000002oiVIV@05o`000?moOgoo
0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`09o`000?m<C4co0000ofIVI_l0003o
Ogmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02Ol0003o/k>co`000?nIVIWo
0000ogmoOol0003oIVIVo`000002oda<C003o`000?oooooooooo00Cooooo0Ol00001ooooo`7ooooo
000Iooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`03ooooo`GoVIVI
00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0:oiVIV@03o`000?moOgooOgmo00WoOgmo
00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00coIVIV
00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@05oiVIV@03o`000?nc/k?o/k>c01?o/k>c
00?o0000oiVIVOnIVIT00onIVIT01Ol0003oOgmoogmoOomoOgoo000000CoIVIV00?o0000oda<C?m<
C4`00om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Co0000ofIVI_mV
IVKo00000omoOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000
ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000;oC4a<
00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o0000ogmoOol0
00000_nIVIT00ol0003o/k>co`00000:olc<c003o`000?nc/k?o000000;oVIVI00Go0000ogmoOol0
003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Wo0000oda<C?l0003oIVIVo`000?mo
Ogoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c009o`000?nc/k?o0000oiVIVOl0
003oOgmoo`000?mVIVKo000000;oC4a<00?o0000ooooooooool01?ooool1o`00007ooooo0Oooool0
01Wooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00?ooooo1?nIVIT0
0ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl0
0ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH03?mVIVH0
0ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00GoVIVI00?o0000ok>c/onc/k<05?nc/k<0
0ol0003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol000001?mVIVH00ol0003oC4a<oda<
C003oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00om<C4`01Ol0003oIVIVofIV
I_mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c005olc<c003
o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00002
oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP03o`000?mo
Ogoo000000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`00ol0003o/k>co`000002oiVIV@05o`00
0?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`09o`000?m<C4co0000ofIV
I_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`01?l0003o/k>co`00
0?l00002ogmoO`;o00000_m<C4`00ol0003o<c<cooooo`05ooooo`7o00000Oooool1ooooo`006Ooo
ool01Olb<S;oV9RHoooooonHV9So<S8b00Kooooo0ol00003ooooo`;oVIVI0_l0000Hok>c/`03o`00
0?nIVIWoVIVI00[oVIVI0_l0000:ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`0
5_m<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT0
1OnIVIT00ol0003o/k>cok>c/`0Dok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomoOgoo
Ogmoo`000004ofIVIP03o`000?m<C4coC4a<00CoC4a<00?o0000oc<c<olc<c<00olc<c<00ol0003o
C4a<oda<C003oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01Ol0003oVIVIoiVIVOnIVIWo
000000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWo
VIVIo`0000;oOgmo00?o0000ofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<
C4coC4a<oda<C?l000000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000So
c<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000
oc<c<olc<c<01_lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c
/`03o`000?o<c<coc<c<00Koc<c<00?o0000ok>c/onc/k<00_l000001?moOgoo0000ofIVI_l00002
oda<C003o`000?lc<c?ooooo00?ooooo0ol00002ooooo`006Oooool01Oo<c<co0000o`000?l0003o
c<c<00Kooooo00?o0000ooooooooool00oooool2oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000
oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000
oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP;o00002?moOgl00ol0003oVIVIoiVIV@05
oiVIV@03o`000?nc/k?o/k>c01Co/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomo
Ogoo000000CoIVIV00?o0000oda<C?m<C4`01?m<C4`00ol0003o<c<coc<c<`03oc<c<`03o`000?m<
C4coC4a<00?oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVIVOl0
00001?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnI
VIWo00000_moOgl00ol0003oIVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<
C?m<C4coC4a<o`000002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<
c007olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl00ol0003oIVIVo`000002oda<C003
o`000?lc<c?o<c<c00Ko<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000
0_nc/k<00ol0003oc<c<olc<c006olc<c003o`000?nc/k?o/k>c00;o000000CoOgmoo`000?mVIVKo
00000_m<C4`00ol0003o<c<cooooo`05ooooo`7o00000Oooool1ooooo`006Oooool01Ol@413o^[Zj
oooooonj^[[o410@00Kooooo00?o0000ooooooooool00oooool00onIVIWo0000ok>c/`0Gok>c/`03
o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03
o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`07ogmoO`03
o`000?nIVIWoVIVI00GoVIVI00?o0000ok>c/onc/k<05?nc/k<00ol0003oVIVIoiVIV@02oiVIV@05
o`000?moOgooOgmoogmoOol000001?mVIVH00ol0003oC4a<oda<C004oda<C003o`000?lc<c?o<c<c
00?o<c<c00?o0000oda<C?m<C4`00om<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Go0000
oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>c
o`000002oiVIV@06o`000?moOgooOgmoo`000?mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c
<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o
/k>co`0000Woc<c<00?o0000ok>c/onc/k<00_l00002ogmoO`03o`000?mVIVKo000000;oC4a<00?o
0000oc<c<olc<c<01olc<c<01ol0003oC4a<o`000?mVIVKo0000ogmoOol000000_nIVIT00ol0003o
/k>co`000009olc<c004o`000?nc/k?o0000oiVIV@;o000000GoIVIVo`000?m<C4coC4a<o`000002
oc<c<`Kooooo0Ol00001ooooo`7ooooo000Iooooo`05o`000?nj^[[ooooookZj^_l000001_ooool0
0ol0003oooooooooo`03ooooo`03o`000?nc/k?o/k>c01Go/k>c0_l0000=oiVIV@03o`000?moOgoo
Ogmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKo
IVIV00_oIVIV00?o0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@05oiVIV@;o00005Onc/k<0
0ol0003oVIVIoiVIV@02oiVIV@03o`000?moOgooOgmo00;oOgmo00Go0000ofIVI_mVIVKoIVIVo`00
0006oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00om<C4`01Ol0003oIVIVofIV
I_mVIVKo000000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Ko
c<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Go0000
oda<C?m<C4coC4a<o`000008oc<c<`07o`000?m<C4coC4a<oda<C?l0003oIVIVo`000002ogmoO`03
o`000?nIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01_l0003o/k>cok>c/ol0003oVIVI
o`0000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0<o`000?m<C4co
C4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00002_o<c<`2o`000006oiVIVOl0003o
0000o`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06ooooo`7o00000Oooool1ooooo`006Ooo
ool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000ooooooooool00ooooolHok>c/`03o`00
0?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl2o`0000coIVIV00?o0000oda<C?m<C4`0
5_m<C4`00ol0003oIVIVofIVIP0;ofIVIP;o00002?moOgl00ol0003oVIVIoiVIV@06oiVIV@03o`00
0?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`02ogmoO`05o`00
0?mVIVKoIVIVofIVI_l000001_m<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?o
C4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000onc/k<0
0ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmo
Ool00002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01ol0003oC4a<oda<C?m<C4co0000
ofIVI_l000000_moOgl00ol0003oVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Ko0000
ok>c/onc/k?o0000oiVIVOl00002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<0
1_lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000[oc<c<
0_l000001_nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_ooool1o`00
007ooooo0Oooool002Cooooo00?o0000ooooooooool00ooooolGok>c/`03o`000?nIVIWoVIVI00[o
VIVI0_l0000:ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003o
IVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o
/k>cok>c/`0Dok>c/`03o`000?nIVIWoVIVI00;oVIVI00?o0000ogmoOomoOgl00_moOgl01Ol0003o
IVIVofIVI_mVIVKo000000OoC4a<00?o0000oc<c<olc<c<00olc<c<00ol0003oC4a<oda<C003oda<
C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000?o/k>c00?o
0000olc<c?o<c<`01_o<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo
00?o0000ofIVI_l000000om<C4`00ol0003o<c<coc<c<`07oc<c<`04o`000?m<C4coC4a<o`0000;o
IVIV00Go0000ogmoOol0003oVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Ko0000ok>c
/onc/k?o0000oiVIVOl00002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01olc
<c<01Ol0003oC4a<o`000?mVIVKo000000;oOgmo0_l00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<
00Co0000ok>c/ol0003oVIVI0_l00002ofIVIP03o`000?m<C4co000000?o<c<c1_ooool1o`00007o
oooo0Oooool002Cooooo00?o0000ooooooooool00ooooolEok>c/`;o00003?nIVIT00ol0003oOgmo
ogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIV
ofIVIP0;ofIVIP03o`000?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>c
ok>c/`0Dok>c/`03o`000?nIVIWoVIVI00;oVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIV
ofIVIP02ofIVIP03o`000?m<C4coC4a<00CoC4a<00?o0000oc<c<olc<c<00olc<c<00ol0003oC4a<
oda<C003oda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01?l0003oVIVIoiVIVOl00004ok>c
/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgoo
Ogmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`07o`000?m<C4coC4a<oda<C?l0
003oIVIVo`000002ogmoO`03o`000?nIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01_l0
003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00Go0000ofIVI_l0003oC4a<o`00000:oc<c<`09o`00
0?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`0
1Ol0003o/k>co`000?l0003oVIVI00;o000000GoIVIVo`000?m<C4coC4a<o`000003oc<c<`Kooooo
0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo5?nc/k<00ol0003oVIVIoiVI
V@0<oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<oda<
C00Foda<C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVI
V@05oiVIV@03o`000?nc/k?o/k>c01Go/k>c00?o0000oiVIVOnIVIT00_nIVIT00ol0003oOgmoogmo
O`02ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01?m<C4`00ol0003o<c<coc<c
<`03oc<c<`03o`000?m<C4coC4a<00?oC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`04o`00
0?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o0000
00;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Oo
0000oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00?o0000oiVIVOl000000onc/k<00ol0003o
c<c<olc<c006olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl01Ol0003oIVIVo`000?m<
C4co000000[o<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl000000_nc/k<00ol0
003oc<c<olc<c006olc<c003o`000?nc/k?o000000;oVIVI0_l000001OmVIVKo0000oda<C?m<C4co
000000?o<c<c1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00ooooolCok>c
/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0:ofIV
IP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmoO`07ogmo
O`03o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc/k<05?nc/k<00ol0003oVIVIoiVIV@03oiVI
V@05o`000?moOgooOgmoogmoOol000001?mVIVH00ol0003oC4a<oda<C005oda<C003o`000?lc<c?o
<c<c00;o<c<c00?o0000oda<C?m<C4`01?m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Go
0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<0
0_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c
<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP06o`000?moOgooOgmoo`000?nIVIWo0000
0onc/k<00ol0003oc<c<olc<c006olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl01Ol0
003oIVIVo`000?m<C4co000000Wo<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nI
VIWo0000ok>c/ol00008olc<c004o`000?nc/k?o/k>co`0000;oVIVI0_l000001OmVIVKo0000oda<
C?m<C4co000000?o<c<c1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00ooo
oolBok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIV
IP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmo
O`08ogmoO`03o`000?nIVIWoVIVI00GoVIVI00?o0000ok>c/onc/k<05?nc/k<00ol0003oVIVIoiVI
V@04oiVIV@05o`000?moOgooOgmoogmoOol000001?mVIVH00ol0003oC4a<oda<C004oda<C003o`00
0?lc<c?o<c<c00;o<c<c00?o0000oda<C?m<C4`01?m<C4`01Ol0003oIVIVofIVI_mVIVKo000000?o
Ogmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>c
ok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<C?l00000
2?lc<c<01ol0003oC4a<oda<C?m<C4co0000ofIVI_l000000_moOgl00ol0003oVIVIo`000003ok>c
/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mV
IVKo000000;oC4a<00?o0000oc<c<olc<c<01olc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0
003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Oo0000ok>c/onc/k?o0000oiVIVOl0
003oOgmo00;o00000_m<C4`00ol0003o<c<coc<c<`02oc<c<`Kooooo0Ol00001ooooo`7ooooo000T
ooooo`;o00001?oooolAok>c/`;o00003OnIVIT00ol0003oOgmoogmoO`08ogmoO`;o00003?mVIVH2
o`0001SoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWo
VIVI00KoVIVI00?o0000ok>c/onc/k<05?nc/k<00ol0003oVIVIoiVIV@03oiVIV@05o`000?moOgoo
OgmoogmoOol000001?mVIVH00ol0003oC4a<oda<C004oda<C0;o00001?lc<c<00ol0003oC4a<oda<
C004oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Co
/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`00
00;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4co
C4a<o`0000;oIVIV00Ko0000ogmoOomoOgoo0000oiVIVOl00002ok>c/`;o00002?o<c<`01_l0003o
/k>cok>c/ol0003oVIVIo`0000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06
oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<
c?o<c<`01_o<c<`01Ol0003o/k>cok>c/ol0003oVIVI00;o000000GoIVIVo`000?m<C4coC4a<o`00
0004oc<c<`Gooooo0_l00002ooooo`009?ooool00ol0003oooooooooo`03oooooa3o/k>c00?o0000
oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00[oIVIV00?o0000
oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000
oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`0Eok>c/`03o`000?nIVIWoVIVI00?oVIVI00Go0000
ogmoOomoOgooOgmoo`000004ofIVIP03o`000?m<C4coC4a<00CoC4a<00?o0000oc<c<olc<c<00olc
<c<00ol0003oC4a<oda<C004oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01Ol0003oVIVI
oiVIVOnIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003o/k>cok>c/`02ok>c/`06
o`000?nIVIWoVIVIo`000?moOgoo00000_mVIVH00ol0003oC4a<oda<C002oda<C003o`000?lc<c?o
<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc
/k?o/k>co`0000Woc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`03o`000?mVIVKo0000
00;oC4a<00?o0000oc<c<olc<c<01_lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000
oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o0000oiVIV@02o`00
0005ofIVI_l0003oC4a<oda<C?l000001?lc<c<6ooooo`7o00000Oooool1ooooo`009?ooool00ol0
003oooooooooo`03ooooo`oo/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`09ogmo
O`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIV
IP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`0Eok>c
/`03o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl00_moOgl01Ol0003oIVIVofIVI_mVIVKo
000000KoC4a<00?o0000oc<c<olc<c<00olc<c<00ol0003oC4a<oda<C004oda<C005o`000?mVIVKo
IVIVofIVI_l000000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Co/k>c00?o0000olc<c?o<c<`0
1Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co0000ofIVI_mV
IVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Ko0000
ogmoOomoOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Ko0000ok>c/onc/k?o
0000oiVIVOl00002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01olc<c<01ol0
003oC4a<o`000?mVIVKo0000ogmoOol000000_nIVIT00ol0003o/k>co`000008olc<c007o`000?nc
/k?o/k>co`000?nIVIWo0000ogmoO`02o`0000;oC4a<00?o0000oc<c<olc<c<00olc<c<6ooooo`7o
00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`oo/k>c00?o0000oiVIVOnIVIT0
2onIVIT00ol0003oOgmoogmoO`08ogmoO`;o00003?mVIVH2o`0001SoC4a<00?o0000ofIVI_mVIVH0
2_mVIVH2o`0000[oOgmo00?o0000oiVIVOnIVIT01onIVIT00ol0003o/k>cok>c/`0Dok>c/`03o`00
0?nIVIWoVIVI00;oVIVI0_l00004ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`0
1?m<C4`00ol0003o<c<coc<c<`02oc<c<`03o`000?m<C4coC4a<00CoC4a<00Go0000ofIVI_mVIVKo
IVIVo`000003ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<
c005o`000?nc/k?o/k>cok>c/ol000000onIVIT01?l0003oOgmoogmoOol00002ofIVIP03o`000?m<
C4coC4a<00;o00001olc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o0000ogmoOol00000
0_nIVIT01?l0003o/k>cok>c/ol00009olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0
0002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmo
o`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c007o`000?nc/k?o/k>co`000?nIVIWo
0000ogmoO`02o`0000;oC4a<00?o0000oc<c<olc<c<00olc<c<6ooooo`7o00000Oooool1ooooo`00
9?ooool00ol0003oooooooooo`03ooooo`ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmo
ogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIV
ofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02?nIVIT00ol0003o/k>c
ok>c/`0Cok>c/`03o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl00omoOgl01Ol0003oIVIV
ofIVI_mVIVKo000000OoC4a<00?o0000oc<c<olc<c<00_lc<c<00ol0003oC4a<oda<C004oda<C005
o`000?mVIVKoIVIVofIVI_l000000omoOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<co
c<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000003oiVIV@04o`000?moOgooOgmoo`0000;oIVIV
00Co0000oda<C?m<C4co00002?lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o0000ogmo
Ool000000_nIVIT01?l0003o/k>cok>c/ol00009olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000
ogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00[o0000oda<C?m<C4co0000ofIVI_l0
003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c007o`000?nc/k?o/k>co`00
0?nIVIWo0000ogmoO`02o`0000;oC4a<00?o0000oc<c<olc<c<00olc<c<6ooooo`7o00000Oooool1
ooooo`009?ooool00ol0003oooooooooo`03ooooo`go/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0
003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0
003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02?nIVIT00ol0
003o/k>cok>c/`0Dok>c/`03o`000?nIVIWoVIVI00;oVIVI00?o0000ogmoOomoOgl00omoOgl00ol0
003oIVIVofIVIP02ofIVIP03o`000?m<C4coC4a<00CoC4a<00?o0000oc<c<olc<c<00_lc<c<00ol0
003oC4a<oda<C004oda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01Ol0003oVIVIoiVIVOnI
VIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000?oVIVI
00Co0000ogmoOomoOgoo00000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`03o`000?m<C4coC4a<
00;oC4a<00Go0000ofIVI_l0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Woc<c<00Ko
0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc
<c<01_lc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo0_l00002ok>c/`03o`000?o<c<co
c<c<00Koc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00006
oc<c<`Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo3?nc/k<00ol0
003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0
003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00[oIVIV0_l0000:ogmoO`03o`000?nIVIWoVIVI
00OoVIVI0_l0000Fok>c/`03o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl00_moOgl00ol0
003oIVIVofIVIP02ofIVIP03o`000?m<C4coC4a<00GoC4a<00?o0000oc<c<olc<c<00_lc<c<00ol0
003oC4a<oda<C004oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01Ol0003oVIVIoiVIVOnI
VIWo000000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`2o`0000?o/k>c00Co0000oiVIVOnIVIWo0000
0_moOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<
C4coC4a<o`000002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`0
2?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo00000_mVIVH00ol0003oC4a<o`000009oc<c<`0:
o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`0
1_o<c<`03?l0003o/k>co`000?l0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000Ko<c<c
1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool;ok>c/`03o`000?nI
VIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<
C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nI
VIWoVIVI00SoVIVI00?o0000ok>c/onc/k<05Onc/k<00ol0003oVIVIoiVIV@03oiVIV@03o`000?mo
OgooOgmo00;oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C004oda<C003o`000?lc
<c?o<c<c00?o<c<c00?o0000oda<C?m<C4`01?m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo
00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc
/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000
oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o0000ogmoOol000000_nI
VIT01?l0003o/k>cok>c/ol00009olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002
ofIVIP03o`000?m<C4co000000Wo<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nI
VIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c003o`000?nc/k?o000000;oVIVI00Oo0000ogmo
Ool0003oIVIVo`000?m<C4co000000Ko<c<c1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000
ooooooooool00oooool:ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl0
0ol0003oIVIVofIVIP0;ofIVIP;o00006?m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgoo
Ogmo00SoOgmo00?o0000oiVIVOnIVIT02?nIVIT00ol0003o/k>cok>c/`0Eok>c/`03o`000?nIVIWo
VIVI00?oVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP02ofIVIP03o`000?m<C4co
C4a<00GoC4a<00?o0000oc<c<olc<c<00_lc<c<00ol0003oC4a<oda<C004oda<C005o`000?mVIVKo
IVIVofIVI_l000000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Co/k>c00?o0000olc<c?o<c<`0
1Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co0000ofIVI_mV
IVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH0
0ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Woc<c<00Co0000ok>c/onc/k?o0000
0_nIVIT2o`0000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<01?l0003oC4a<oda<C?l00002ofIV
IP;o000000GoVIVIo`000?nc/k?o/k>co`000008olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000
ogmoOol0003oIVIVo`000?m<C4co00001olc<c<6ooooo`7o00000Oooool1ooooo`009?ooool00ol0
003oooooooooo`03ooooo`Wo/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmo
O`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0:ofIV
IP;o00002_moOgl00ol0003oVIVIoiVIV@08oiVIV@03o`000?nc/k?o/k>c01Go/k>c00?o0000oiVI
VOnIVIT00onIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<
C?m<C4`01Om<C4`00ol0003o<c<coc<c<`02oc<c<`03o`000?m<C4coC4a<00CoC4a<00Go0000ofIV
I_mVIVKoIVIVo`000003ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0003oc<c<olc<
c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIV
ofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIV
IP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`02Ol0003o/k>cok>c/onc
/k?o0000oiVIVOl0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00[o0000oda<
C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c009
o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIV00;o00002?lc<c<6ooooo`7o00000Ooo
ool1ooooo`009?ooool2o`0000Cooooo2?nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgoo
Ogmo00SoOgmo00?o0000ofIVI_mVIVH03?mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKo
IVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@09oiVIV@03o`000?nc/k?o
/k>c01Go/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKo
IVIV00;oIVIV00?o0000oda<C?m<C4`01Om<C4`00ol0003o<c<coc<c<`02oc<c<`03o`000?m<C4co
C4a<00CoC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`05o`000?nIVIWoVIVIoiVIVOl00000
1?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo
00000_moOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<
C?m<C4coC4a<o`000002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<
c<`02Ol0003o/k>cok>c/onc/k?o0000oiVIVOl0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<
o`0000Oo<c<c00_o0000oda<C?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c
/`03o`000?o<c<coc<c<00Koc<c<00Wo0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVH0
0_l00008oc<c<`Gooooo0_l00002ooooo`009?ooool00ol0003oooooooooo`03ooooo`Oo/k>c00?o
0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV0_l0
000Hoda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVI
V@09oiVIV@03o`000?nc/k?o/k>c01Go/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmo
O`02ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<C4`01?m<C4`00ol0003o<c<coc<c
<`02oc<c<`03o`000?m<C4coC4a<00CoC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`05o`00
0?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o
/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o
<c<c00Oo<c<c00Co0000oda<C?m<C4co00000_mVIVH01_l0003oOgmoogmoOol0003oVIVIo`0000;o
/k>c00?o0000olc<c?o<c<`01_o<c<`02Ol0003o/k>cok>c/onc/k?o0000oiVIVOl0003oOgmoo`00
0002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00So0000oda<C?m<C4co0000ofIVI_l0003oOgmo
o`0000;oVIVI00?o0000ok>c/ol000002?o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo
0000ofIVI_l0003oC4a<o`0000So<c<c1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000oooo
ooooool00oooool6ok>c/`03o`000?nIVIWoVIVI00[oVIVI0_l0000:ogmoO`03o`000?mVIVKoIVIV
00_oIVIV00?o0000oda<C?m<C4`05_m<C4`2o`0000goIVIV00?o0000ogmoOomoOgl02?moOgl00ol0
003oVIVIoiVIV@09oiVIV@03o`000?nc/k?o/k>c01Go/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0
003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<C4`01Om<C4`01Ol0
003o<c<coc<c<olc<c?o000000OoC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`04o`000?nI
VIWoVIVIo`0000Go/k>c00?o0000olc<c?o<c<`01Oo<c<`01Ol0003o/k>cok>c/onc/k?o000000?o
VIVI00Co0000ogmoOomoOgoo00000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Oo0000
oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo00000_nc/k<00ol0003o
c<c<olc<c006olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0
003oC4a<oda<C?l00008oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`00
00;o/k>c00?o0000olc<c?o<c<`01_o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000
ofIVI_l0003oC4a<o`0000So<c<c1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000oooooooo
ool00oooool5ok>c/`03o`000?nIVIWoVIVI00[oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003o
IVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH2o`0000[o
Ogmo00?o0000oiVIVOnIVIT02_nIVIT00ol0003o/k>cok>c/`0Dok>c/`03o`000?nIVIWoVIVI00Co
VIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<00Go
C4a<00Go0000oc<c<olc<c?o<c<co`000006oda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmo
OomoOgooOgmoo`000002oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`01?o<c<`0
0ol0003o/k>cok>c/`02ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01?l0003oIVIVofIV
I_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo0000
00;oOgmo00Co0000oiVIVOnIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o
/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`0:o`00
0?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<
c<`00ol0003o/k>cok>c/`02o`0000;oOgmo00Go0000ofIVI_l0003oC4a<o`000008oc<c<`03o`00
0?oooooooooo00?ooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo1?nc
/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omV
IVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02Omo
Ogl00ol0003oVIVIoiVIV@0:oiVIV@03o`000?nc/k?o/k>c01Go/k>c00?o0000oiVIVOnIVIT00onI
VIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<C4`01Om<
C4`01Ol0003o<c<coc<c<olc<c?o000000OoC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`04
o`000?nIVIWoVIVIo`0000Go/k>c00?o0000olc<c?o<c<`01Oo<c<`01Ol0003o/k>cok>c/onc/k?o
000000?oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c
00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo00000_nc/k<0
0ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Ko0000ogmoOomoOgoo0000
ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002
ogmoO`;o00000_nc/k<00ol0003oc<c<olc<c006olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000
ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<00ol0003oooooooooo`03oooo
o`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`?o/k>c00?o0000oiVIVOnI
VIT02_nIVIT2o`0000[oOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003
o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0:oiVIV@03
o`000?nc/k?o/k>c01Go/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`03ogmoO`03
o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01_m<C4`01?l0003o<c<coc<c<ol00007oda<
C004o`000?mVIVKoIVIVofIVIP;o00000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Co/k>c00?o
0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo
00Go0000ofIVI_mVIVKoIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Co0000oda<C?m<
C4co00000_mVIVH01_l0003oOgmoogmoOol0003oVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<
c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV00?o0000oda<C?l00000
2Olc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<
c<coc<c<00Koc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l0
0008oc<c<`03o`000?oooooooooo00Cooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooo
oooo00?ooooo0_nc/k<00ol0003oVIVIoiVIV@0:oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000
ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV0_l0000:
ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05Onc/k<00ol0003oVIVIoiVIV@03
oiVIV@03o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C006
oda<C004o`000?lc<c?o<c<co`0000OoC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`05o`00
0?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o
/k>c00Co0000oiVIVOnIVIWo00000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000;oC4a<00?o0000
oc<c<olc<c<01olc<c<01?l0003oC4a<oda<C?l00002ofIVIP06o`000?moOgooOgmoo`000?nIVIWo
00000onc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmo
Ool000000_mVIVH00ol0003oC4a<o`000009oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmo
Ool0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003o/k>co`000002oiVIV@07
o`000?moOgoo0000ofIVI_l0003oC4a<o`000008oc<c<`03o`000?oooooooooo00Cooooo0Ol00001
ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo00?o/k>co`000?nIVIT03?nIVIT00ol0
003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0
003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0
003o/k>cok>c/`0Eok>c/`03o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl00_moOgl00ol0
003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<00KoC4a<00Co0000oc<c<olc<c?o00001om<C4`0
1Ol0003oIVIVofIVI_mVIVKo000000CoOgmo00Co0000oiVIVOnIVIWo00001Onc/k<00ol0003oc<c<
olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0003o
IVIVofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Co0000oda<C?m<C4co00000_mVIVH0
1?l0003oOgmoogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Go0000ok>c/onc/k?o
/k>co`000002oiVIV@;o00000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`04o`000?m<C4coC4a<
o`0000;oIVIV0_l000001OnIVIWo0000ok>c/onc/k?o000000Soc<c<00So0000ok>c/onc/k?o0000
oiVIVOl0003oOgmoo`0000;oIVIV0_l00008oc<c<`03o`000?m<C4cooooo00Gooooo0Ol00001oooo
o`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo00?o0000oiVIVOnIVIT02onIVIT00ol0003o
OgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003o
IVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o
/k>cok>c/`0Dok>c/`;o00001OnIVIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00;o
IVIV00?o0000oda<C?m<C4`01om<C4`00ol0003o<c<co`000008oda<C005o`000?mVIVKoIVIVofIV
I_l000000omoOgl01Ol0003oVIVIoiVIVOnIVIWo000000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`0
0ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo0000
0om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01_l0003o
OgmoogmoOol0003oVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol0
0002oiVIV@05o`000?moOgoo0000ofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`0:o`00
0?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<
c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000So<c<c00?o
0000oda<C?ooool01Oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool=
oiVIV@03o`000?moOgooOgmo00SoOgmo0_l0000<ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000
ofIVI_mVIVH02omVIVH2o`0000[oOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0E
ok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIVIP02
ofIVIP03o`000?m<C4coC4a<00OoC4a<00?o0000oc<c<ol000001om<C4`00ol0003oIVIVofIVIP02
ofIVIP05o`000?moOgooOgmoogmoOol000000onIVIT00ol0003o/k>cok>c/`02ok>c/`03o`000?o<
c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00onc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`00
0?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co0000
00;oIVIV00Ko0000ogmoOomoOgoo0000oiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co
0000ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000?oC4a<00?o0000oc<c<olc
<c<01Olc<c<01?l0003oC4a<oda<C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<0
0ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>co`000?nIVIT00_l00002ofIVIP03o`000?m<
C4co000000So<c<c00?o0000oda<C?ooool01Oooool1o`00007ooooo0Oooool002Cooooo0_l00004
ooooo`_oVIVI0_l0000:ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`0
0ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT0
0ol0003o/k>cok>c/`0Eok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl00omoOgl0
0ol0003oIVIVofIVIP02ofIVIP03o`000?m<C4coC4a<00WoC4a<00?o0000oda<C?m<C4`01_m<C4`0
1Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`00
0?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04
o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<
C008o`000?mVIVKoIVIVo`000?moOgoo0000oiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<
00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`00
00So<c<c00So0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o
00001oo<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000So
<c<c00Co0000oda<C?m<C4co00001?ooool2o`0000;ooooo000Tooooo`03o`000?oooooooooo00?o
oooo2_nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<
C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnI
VIT02onIVIT00ol0003o/k>cok>c/`0Eok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomo
Ogl00omoOgl00ol0003oIVIVofIVIP02ofIVIP03o`000?m<C4coC4a<01;oC4a<00Go0000ofIVI_mV
IVKoIVIVo`000003ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001Onc/k<00ol0003oc<c<olc<c004
olc<c003o`000?nc/k?o/k>c00;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`04o`000?mV
IVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;o
IVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00009olc<c004o`000?nc/k?o/k>c
o`0000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00[o
0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006
olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co00002?lc<c<0
1?l0003oC4a<oda<C?l00005ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03
ooooo`[oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0:ofIVIP03o`000?m<C4co
C4a<01KoC4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWo
VIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgoo
Ogmo00?oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C00Boda<C005o`000?mVIVKo
IVIVofIVI_l000000omoOgl01Ol0003oVIVIoiVIVOnIVIWo000000Go/k>c00?o0000olc<c?o<c<`0
1?o<c<`00ol0003o/k>cok>c/`02ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01?l0003o
IVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002
ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`01?l0003o/k>cok>c
/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`0:
o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`0
1_o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000So<c<c
00Co0000oda<C?m<C4co00001Oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool0
0oooool9oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<
oda<C00Foda<C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVI
oiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmo
ogmoO`03ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<C4`04Om<C4`00ol0003oIVIV
ofIVIP02ofIVIP05o`000?moOgooOgmoogmoOol000000onIVIT00ol0003o/k>cok>c/`02ok>c/`03
o`000?o<c<coc<c<00Goc<c<00Go0000ok>c/onc/k?o/k>co`000003oiVIV@04o`000?moOgooOgmo
o`0000?oIVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`05o`000?m<C4coC4a<oda<C?l00000
0_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Woc<c<00Ko0000ok>c/onc
/k?o0000oiVIVOl00002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01olc<c<0
0ol0003oC4a<o`000002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<
c006olc<c003o`000?nc/k?o/k>c00;o00000_moOgl01Ol0003oIVIVo`000?m<C4co000000So<c<c
00Co0000oda<C?m<C4co00001Oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool0
0oooool8oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<
oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVI
oiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmo
ogmoO`03ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`04_m<C4`01Ol0003oIVIV
ofIVI_mVIVKo000000CoOgmo00Co0000oiVIVOnIVIWo00001Onc/k<00ol0003oc<c<olc<c004olc<
c003o`000?nc/k?o/k>c00;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`04o`000?mVIVKo
IVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV
00?o0000ogmoOol000000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Co0000ok>c/onc
/k?o00000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01olc<c<0
1_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo0_l00002ok>c/`03o`000?o<c<coc<c<00Koc<c<
00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c
<`06oc<c<`03o`000?m<C4co000000Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooo
oooo00?ooooo1onIVIT00ol0003oOgmoogmoO`08ogmoO`;o00003?mVIVH2o`0001SoC4a<00?o0000
ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI0_l0000H
ok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIVIP03
ofIVIP03o`000?m<C4coC4a<017oC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomo
Ogoo000000?oVIVI00?o0000ok>c/onc/k<00_nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc
/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000omoOgl01?l0003oIVIVofIVI_l00003oda<C003
o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP03o`000?moOgoo0000
00;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Go
0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00?o0000oda<C?l00000
0_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`03?l0003o
/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000So<c<c00Co0000oda<C?m<
C4co00001_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool6oiVIV@03
o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<oda<C00Goda<C003
o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03
o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT01OnIVIT00ol0003oOgmoogmoO`03ogmoO`03
o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`04_m<C4`00ol0003oIVIVofIVIP02ofIVIP05
o`000?moOgooOgmoogmoOol000000onIVIT00ol0003o/k>cok>c/`02ok>c/`03o`000?o<c<coc<c<
00Coc<c<00?o0000ok>c/onc/k<00onc/k<01?l0003oVIVIoiVIVOl00003ogmoO`04o`000?mVIVKo
IVIVo`0000?oC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C006o`000?mV
IVKoIVIVo`000?moOgoo00000_nIVIT01?l0003o/k>cok>c/ol00008olc<c004o`000?nc/k?o/k>c
o`0000?oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Go
0000oda<C?l0003oIVIVo`000002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`0
1_o<c<`00ol0003o/k>co`000002oiVIV@04o`000?moOgoo0000o`0000;oC4a<00?o0000oc<c<olc
<c<01_lc<c<01?l0003oC4a<oda<C?l00006ooooo`7o00000Oooool1ooooo`009?ooool00ol0003o
ooooooooo`03ooooo`GoVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03
o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03
o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@05oiVIV@03
o`000?moOgooOgmo00?oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C00Boda<C003
o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgooOgmoo`000003oiVIV@03o`000?nc/k?o/k>c
00;o/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVI
o`0000?oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<
C4coC4a<oda<C?l000000_mVIVH01_l0003oOgmoogmoOol0003oVIVIo`0000?o/k>c00?o0000olc<
c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<
C4`00ol0003o<c<coc<c<`07oc<c<`03o`000?m<C4co000000;oIVIV00Go0000ogmoOol0003oVIVI
o`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmo
o`000?mVIVKo0000oda<C?l00008oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00001Oooool1o`00
007ooooo0Oooool001;ooooo1?l000002?l@413oooooooooooo^k^ko<S8bo`000?lb<S;ok^k^1_oo
ool00ol0003oooooooooo`03ooooo`CoVIVI00?o0000ogmoOomoOgl02?moOgl2o`0000coIVIV0_l0
000Hoda<C003o`000?mVIVKoIVIV00[oIVIV0_l0000:ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o
0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@05oiVIV@03o`000?moOgooOgmo00?oOgmo00?o
0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00Boda<C005o`000?mVIVKoIVIVofIVI_l00000
0omoOgl01Ol0003oVIVIoiVIVOnIVIWo000000Go/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o
/k>cok>c/`03ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`0
0ol0003o<c<coc<c<`06oc<c<`03o`000?m<C4coC4a<00;o000000GoIVIVo`000?moOgooOgmoo`00
0002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo0000
00;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`03o`000?m<C4co0000
00;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00co0000
ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00008oc<c<`06o`000?m<C4co
C4a<o`000?mVIVKo00001Oooool1o`00007ooooo0Oooool001Cooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000ooooooooool00oooool3oiVIV@03o`00
0?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Goda<C003o`00
0?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`00
0?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT01_nIVIT00ol0003oOgmoogmoO`03ogmoO`03o`00
0?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<C4`04_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;o
Ogmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00Co
c<c<00?o0000ok>c/onc/k<00onc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIV
o`0000CoC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP04o`000?mo
OgooOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01ol0003o/k>cok>c/onc/k?o0000
oiVIVOl000000_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000
oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`0
1_o<c<`01Ol0003o/k>cok>c/ol0003oVIVI00;o00000_mVIVH00ol0003oC4a<o`000008oc<c<`06
o`000?m<C4coC4a<o`000?mVIVKo00001Oooool1o`00007ooooo0Oooool001Cooooo00?o0000oooo
ooooool00_ooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool00oooool2
oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00G
oda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;
oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT01_nIVIT00ol0003oOgmoogmoO`03
ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<C4`04_m<C4`01Ol0003oIVIVofIVI_mV
IVKo000000?oOgmo00Go0000oiVIVOnIVIWoVIVIo`000005ok>c/`03o`000?o<c<coc<c<00Coc<c<
00?o0000ok>c/onc/k<00onc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`00
00CoC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP04o`000?moOgoo
Ogmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`01_l0003o/k>cok>c/ol0003oVIVIo`00
00;oOgmo00Co0000ofIVI_mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`03o`000?m<C4co
000000;oIVIV00?o0000ogmoOol000000_nIVIT00ol0003o/k>co`000008olc<c00<o`000?nc/k?o
/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co00002Olc<c<01Ol0003oC4a<o`000?mV
IVKo000000Kooooo0Ol00001ooooo`7ooooo000Dooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000006ooooo`?o00000oooool00onIVIWo0000ogmoO`09ogmoO`03o`000?mV
IVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?mo
OgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Hok>c/`03o`000?nI
VIWoVIVI00GoVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<
C4coC4a<01;oC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000?oVIVI
00?o0000ok>c/onc/k<00_nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c
00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c
<olc<c<01olc<c<01?l0003oC4a<oda<C?l00002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Co
0000ok>c/onc/k?o00002Oo<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00?o0000ofIV
I_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Go0000
ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00co0000ok>c/onc/k?o0000
oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00009oc<c<`05o`000?m<C4co0000o`000?moOgl0
1?ooool3o`0000;ooooo000Dooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo0?oooooo?oooool1o`00007ooooo0Oooool001Cooooo00?o
0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool0
ooooooloooooo`7o00000Oooool1ooooo`005?ooool00ol0003oooooooooo`02ooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3oooooocoooooo0Ol00001ooooo`7ooooo
000Booooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Wooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`03ooooo`7o0000
0Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo0Ol0
0001ooooo`7ooooo000Toooooooo0000@ol00002ooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-7.04757, -6.93977, 0.0606246, \
0.0606246}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.339744 0.0641026 0.339744 0.0641026 [
[.08333 -0.0125 -6 -9 ]
[.08333 -0.0125 6 0 ]
[.21154 -0.0125 -6 -9 ]
[.21154 -0.0125 6 0 ]
[.33974 -0.0125 -3 -9 ]
[.33974 -0.0125 3 0 ]
[.46795 -0.0125 -3 -9 ]
[.46795 -0.0125 3 0 ]
[.59615 -0.0125 -3 -9 ]
[.59615 -0.0125 3 0 ]
[.72436 -0.0125 -3 -9 ]
[.72436 -0.0125 3 0 ]
[.85256 -0.0125 -3 -9 ]
[.85256 -0.0125 3 0 ]
[.98077 -0.0125 -6 -9 ]
[.98077 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5 -21 ]
[.5 -0.0125 5 -9 ]
[-0.0125 .08333 -12 -4.5 ]
[-0.0125 .08333 0 4.5 ]
[-0.0125 .21154 -12 -4.5 ]
[-0.0125 .21154 0 4.5 ]
[-0.0125 .33974 -6 -4.5 ]
[-0.0125 .33974 0 4.5 ]
[-0.0125 .46795 -6 -4.5 ]
[-0.0125 .46795 0 4.5 ]
[-0.0125 .59615 -6 -4.5 ]
[-0.0125 .59615 0 4.5 ]
[-0.0125 .72436 -6 -4.5 ]
[-0.0125 .72436 0 4.5 ]
[-0.0125 .85256 -6 -4.5 ]
[-0.0125 .85256 0 4.5 ]
[-0.0125 .98077 -12 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -24 -5 ]
[-0.01875 .5 -12 5 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08333 0 m
.08333 .00625 L
s
[(-4)] .08333 -0.0125 0 1 Mshowa
.21154 0 m
.21154 .00625 L
s
[(-2)] .21154 -0.0125 0 1 Mshowa
.33974 0 m
.33974 .00625 L
s
[(0)] .33974 -0.0125 0 1 Mshowa
.46795 0 m
.46795 .00625 L
s
[(2)] .46795 -0.0125 0 1 Mshowa
.59615 0 m
.59615 .00625 L
s
[(4)] .59615 -0.0125 0 1 Mshowa
.72436 0 m
.72436 .00625 L
s
[(6)] .72436 -0.0125 0 1 Mshowa
.85256 0 m
.85256 .00625 L
s
[(8)] .85256 -0.0125 0 1 Mshowa
.98077 0 m
.98077 .00625 L
s
[(10)] .98077 -0.0125 0 1 Mshowa
.125 Mabswid
.11538 0 m
.11538 .00375 L
s
.14744 0 m
.14744 .00375 L
s
.17949 0 m
.17949 .00375 L
s
.24359 0 m
.24359 .00375 L
s
.27564 0 m
.27564 .00375 L
s
.30769 0 m
.30769 .00375 L
s
.37179 0 m
.37179 .00375 L
s
.40385 0 m
.40385 .00375 L
s
.4359 0 m
.4359 .00375 L
s
.5 0 m
.5 .00375 L
s
.53205 0 m
.53205 .00375 L
s
.5641 0 m
.5641 .00375 L
s
.62821 0 m
.62821 .00375 L
s
.66026 0 m
.66026 .00375 L
s
.69231 0 m
.69231 .00375 L
s
.75641 0 m
.75641 .00375 L
s
.78846 0 m
.78846 .00375 L
s
.82051 0 m
.82051 .00375 L
s
.88462 0 m
.88462 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.94872 0 m
.94872 .00375 L
s
.05128 0 m
.05128 .00375 L
s
.01923 0 m
.01923 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66 -25 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .08333 m
.00625 .08333 L
s
[(-4)] -0.0125 .08333 1 0 Mshowa
0 .21154 m
.00625 .21154 L
s
[(-2)] -0.0125 .21154 1 0 Mshowa
0 .33974 m
.00625 .33974 L
s
[(0)] -0.0125 .33974 1 0 Mshowa
0 .46795 m
.00625 .46795 L
s
[(2)] -0.0125 .46795 1 0 Mshowa
0 .59615 m
.00625 .59615 L
s
[(4)] -0.0125 .59615 1 0 Mshowa
0 .72436 m
.00625 .72436 L
s
[(6)] -0.0125 .72436 1 0 Mshowa
0 .85256 m
.00625 .85256 L
s
[(8)] -0.0125 .85256 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(10)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .11538 m
.00375 .11538 L
s
0 .14744 m
.00375 .14744 L
s
0 .17949 m
.00375 .17949 L
s
0 .24359 m
.00375 .24359 L
s
0 .27564 m
.00375 .27564 L
s
0 .30769 m
.00375 .30769 L
s
0 .37179 m
.00375 .37179 L
s
0 .40385 m
.00375 .40385 L
s
0 .4359 m
.00375 .4359 L
s
0 .5 m
.00375 .5 L
s
0 .53205 m
.00375 .53205 L
s
0 .5641 m
.00375 .5641 L
s
0 .62821 m
.00375 .62821 L
s
0 .66026 m
.00375 .66026 L
s
0 .69231 m
.00375 .69231 L
s
0 .75641 m
.00375 .75641 L
s
0 .78846 m
.00375 .78846 L
s
0 .82051 m
.00375 .82051 L
s
0 .88462 m
.00375 .88462 L
s
0 .91667 m
.00375 .91667 L
s
0 .94872 m
.00375 .94872 L
s
0 .05128 m
.00375 .05128 L
s
0 .01923 m
.00375 .01923 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
-0.01875 .5 -84 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
66 10 translate
90 rotate
-66 -10 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.08333 .99375 m
.08333 1 L
s
.21154 .99375 m
.21154 1 L
s
.33974 .99375 m
.33974 1 L
s
.46795 .99375 m
.46795 1 L
s
.59615 .99375 m
.59615 1 L
s
.72436 .99375 m
.72436 1 L
s
.85256 .99375 m
.85256 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.11538 .99625 m
.11538 1 L
s
.14744 .99625 m
.14744 1 L
s
.17949 .99625 m
.17949 1 L
s
.24359 .99625 m
.24359 1 L
s
.27564 .99625 m
.27564 1 L
s
.30769 .99625 m
.30769 1 L
s
.37179 .99625 m
.37179 1 L
s
.40385 .99625 m
.40385 1 L
s
.4359 .99625 m
.4359 1 L
s
.5 .99625 m
.5 1 L
s
.53205 .99625 m
.53205 1 L
s
.5641 .99625 m
.5641 1 L
s
.62821 .99625 m
.62821 1 L
s
.66026 .99625 m
.66026 1 L
s
.69231 .99625 m
.69231 1 L
s
.75641 .99625 m
.75641 1 L
s
.78846 .99625 m
.78846 1 L
s
.82051 .99625 m
.82051 1 L
s
.88462 .99625 m
.88462 1 L
s
.91667 .99625 m
.91667 1 L
s
.94872 .99625 m
.94872 1 L
s
.05128 .99625 m
.05128 1 L
s
.01923 .99625 m
.01923 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .08333 m
1 .08333 L
s
.99375 .21154 m
1 .21154 L
s
.99375 .33974 m
1 .33974 L
s
.99375 .46795 m
1 .46795 L
s
.99375 .59615 m
1 .59615 L
s
.99375 .72436 m
1 .72436 L
s
.99375 .85256 m
1 .85256 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .11538 m
1 .11538 L
s
.99625 .14744 m
1 .14744 L
s
.99625 .17949 m
1 .17949 L
s
.99625 .24359 m
1 .24359 L
s
.99625 .27564 m
1 .27564 L
s
.99625 .30769 m
1 .30769 L
s
.99625 .37179 m
1 .37179 L
s
.99625 .40385 m
1 .40385 L
s
.99625 .4359 m
1 .4359 L
s
.99625 .5 m
1 .5 L
s
.99625 .53205 m
1 .53205 L
s
.99625 .5641 m
1 .5641 L
s
.99625 .62821 m
1 .62821 L
s
.99625 .66026 m
1 .66026 L
s
.99625 .69231 m
1 .69231 L
s
.99625 .75641 m
1 .75641 L
s
.99625 .78846 m
1 .78846 L
s
.99625 .82051 m
1 .82051 L
s
.99625 .88462 m
1 .88462 L
s
.99625 .91667 m
1 .91667 L
s
.99625 .94872 m
1 .94872 L
s
.99625 .05128 m
1 .05128 L
s
.99625 .01923 m
1 .01923 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.7 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.6 g
.01923 .90293 m
.02881 .89336 L
.02894 .89321 L
.03851 .88364 L
.03866 .8835 L
.04823 .87393 L
.04837 .87379 L
.05794 .86422 L
.05808 .86408 L
.06765 .85451 L
.06779 .85436 L
.07736 .84479 L
.07751 .84465 L
.08708 .83508 L
.08722 .83494 L
.09679 .82537 L
.09693 .82523 L
.1065 .81566 L
.10664 .81551 L
.11621 .80594 L
.11636 .8058 L
.12593 .79623 L
.12607 .79609 L
.13564 .78652 L
.13578 .78638 L
.14535 .77681 L
.14549 .77666 L
.15506 .76709 L
.15521 .76695 L
.16478 .75738 L
.16492 .75724 L
.17449 .74767 L
.17463 .74753 L
.1842 .73796 L
.18434 .73781 L
.19391 .72824 L
.19406 .7281 L
.20363 .71853 L
.20377 .71839 L
.21334 .70882 L
.21348 .70868 L
.22305 .69911 L
.22319 .69896 L
.23276 .68939 L
.23291 .68925 L
.24248 .67968 L
.24262 .67954 L
.25219 .66997 L
.25233 .66983 L
.2619 .66026 L
.26204 .66011 L
.27161 .65054 L
.27176 .6504 L
.28133 .64083 L
.28147 .64069 L
.29104 .63112 L
.29118 .63098 L
.30075 .62141 L
.30089 .62126 L
.31046 .61169 L
.31061 .61155 L
.32018 .60198 L
.32032 .60184 L
.32989 .59227 L
.33003 .59213 L
.33962 .58256 L
.33974 .58241 L
.34689 .57284 L
.34946 .56925 L
.35398 .56313 L
.35917 .55605 L
.36109 .55342 L
.36811 .54371 L
.36888 .54263 L
.375 .53399 L
.37859 .52888 L
.38178 .52428 L
.38831 .51481 L
.38847 .51457 L
.395 .50486 L
.39802 .50033 L
.40142 .49514 L
.40773 .4855 L
.40778 .48543 L
.41397 .47572 L
.41744 .47025 L
.42008 .46601 L
.42612 .45629 L
.42716 .45462 L
.43202 .44658 L
.43687 .43858 L
.43788 .43687 L
.44363 .42716 L
.44658 .42216 L
.44929 .41744 L
.45492 .40773 L
.45629 .40535 L
.46041 .39802 L
.46592 .38831 L
.46601 .38816 L
.47127 .37859 L
.47572 .37057 L
.47662 .36888 L
.48187 .35917 L
.48543 .35262 L
.48708 .34946 L
.49224 .33974 L
.49514 .33429 L
.49732 .33003 L
.5024 .32032 L
.50486 .3156 L
.50736 .31061 L
.51235 .30089 L
.51457 .29656 L
.51721 .29118 L
.52211 .28147 L
.52428 .27716 L
.52689 .27176 L
.5317 .26204 L
.53399 .2574 L
.53639 .25233 L
.54112 .24262 L
.54371 .23731 L
.54574 .23291 L
.55039 .22319 L
.55342 .21687 L
.55495 .21348 L
.55951 .20377 L
.56313 .1961 L
.56404 .19406 L
.56849 .18434 L
.57284 .17501 L
.57301 .17463 L
.57735 .16492 L
.58181 .15521 L
.58256 .15358 L
.58609 .14549 L
.59049 .13578 L
.59227 .13183 L
.59472 .12607 L
.59904 .11636 L
.60198 .10976 L
.60327 .10664 L
.60749 .09693 L
.61169 .08739 L
.61176 .08722 L
.61584 .07751 L
.62006 .06779 L
.62141 .06469 L
.6241 .05808 L
.62826 .04837 L
.63112 .04169 L
.63231 .03866 L
.63636 .02894 L
.64048 .01923 L
.01923 .01923 L
F
0 g
.01923 .90293 m
.02881 .89336 L
.02894 .89321 L
.03851 .88364 L
.03866 .8835 L
.04823 .87393 L
.04837 .87379 L
.05794 .86422 L
.05808 .86408 L
.06765 .85451 L
.06779 .85436 L
.07736 .84479 L
.07751 .84465 L
.08708 .83508 L
.08722 .83494 L
.09679 .82537 L
.09693 .82523 L
.1065 .81566 L
.10664 .81551 L
.11621 .80594 L
.11636 .8058 L
.12593 .79623 L
.12607 .79609 L
.13564 .78652 L
.13578 .78638 L
.14535 .77681 L
.14549 .77666 L
.15506 .76709 L
.15521 .76695 L
.16478 .75738 L
.16492 .75724 L
.17449 .74767 L
.17463 .74753 L
.1842 .73796 L
.18434 .73781 L
.19391 .72824 L
.19406 .7281 L
.20363 .71853 L
.20377 .71839 L
.21334 .70882 L
.21348 .70868 L
.22305 .69911 L
.22319 .69896 L
.23276 .68939 L
.23291 .68925 L
.24248 .67968 L
.24262 .67954 L
.25219 .66997 L
.25233 .66983 L
.2619 .66026 L
Mistroke
.26204 .66011 L
.27161 .65054 L
.27176 .6504 L
.28133 .64083 L
.28147 .64069 L
.29104 .63112 L
.29118 .63098 L
.30075 .62141 L
.30089 .62126 L
.31046 .61169 L
.31061 .61155 L
.32018 .60198 L
.32032 .60184 L
.32989 .59227 L
.33003 .59213 L
.33962 .58256 L
.33974 .58241 L
.34689 .57284 L
.34946 .56925 L
.35398 .56313 L
.35917 .55605 L
.36109 .55342 L
.36811 .54371 L
.36888 .54263 L
.375 .53399 L
.37859 .52888 L
.38178 .52428 L
.38831 .51481 L
.38847 .51457 L
.395 .50486 L
.39802 .50033 L
.40142 .49514 L
.40773 .4855 L
.40778 .48543 L
.41397 .47572 L
.41744 .47025 L
.42008 .46601 L
.42612 .45629 L
.42716 .45462 L
.43202 .44658 L
.43687 .43858 L
.43788 .43687 L
.44363 .42716 L
.44658 .42216 L
.44929 .41744 L
.45492 .40773 L
.45629 .40535 L
.46041 .39802 L
.46592 .38831 L
.46601 .38816 L
Mistroke
.47127 .37859 L
.47572 .37057 L
.47662 .36888 L
.48187 .35917 L
.48543 .35262 L
.48708 .34946 L
.49224 .33974 L
.49514 .33429 L
.49732 .33003 L
.5024 .32032 L
.50486 .3156 L
.50736 .31061 L
.51235 .30089 L
.51457 .29656 L
.51721 .29118 L
.52211 .28147 L
.52428 .27716 L
.52689 .27176 L
.5317 .26204 L
.53399 .2574 L
.53639 .25233 L
.54112 .24262 L
.54371 .23731 L
.54574 .23291 L
.55039 .22319 L
.55342 .21687 L
.55495 .21348 L
.55951 .20377 L
.56313 .1961 L
.56404 .19406 L
.56849 .18434 L
.57284 .17501 L
.57301 .17463 L
.57735 .16492 L
.58181 .15521 L
.58256 .15358 L
.58609 .14549 L
.59049 .13578 L
.59227 .13183 L
.59472 .12607 L
.59904 .11636 L
.60198 .10976 L
.60327 .10664 L
.60749 .09693 L
.61169 .08739 L
.61176 .08722 L
.61584 .07751 L
.62006 .06779 L
.62141 .06469 L
.6241 .05808 L
Mistroke
.62826 .04837 L
.63112 .04169 L
.63231 .03866 L
.63636 .02894 L
.64048 .01923 L
Mfstroke
.5 g
.01923 .85921 m
.02394 .85451 L
.02894 .84949 L
.03364 .84479 L
.03866 .83978 L
.04336 .83508 L
.04837 .83007 L
.05307 .82537 L
.05808 .82036 L
.06278 .81566 L
.06779 .81064 L
.07249 .80594 L
.07751 .80093 L
.08221 .79623 L
.08722 .79122 L
.09192 .78652 L
.09693 .78151 L
.10163 .77681 L
.10664 .77179 L
.11134 .76709 L
.11636 .76208 L
.12106 .75738 L
.12607 .75237 L
.13077 .74767 L
.13578 .74266 L
.14048 .73796 L
.14549 .73294 L
.15019 .72824 L
.15521 .72323 L
.15991 .71853 L
.16492 .71352 L
.16962 .70882 L
.17463 .70381 L
.17933 .69911 L
.18434 .69409 L
.18904 .68939 L
.19406 .68438 L
.19876 .67968 L
.20377 .67467 L
.20847 .66997 L
.21348 .66496 L
.21818 .66026 L
.22319 .65524 L
.22789 .65054 L
.23291 .64553 L
.23761 .64083 L
.24262 .63582 L
.24732 .63112 L
.25233 .62611 L
.25703 .62141 L
.26204 .61639 L
.26674 .61169 L
.27176 .60668 L
.27646 .60198 L
.28147 .59697 L
.28617 .59227 L
.29118 .58726 L
.29588 .58256 L
.30089 .57754 L
.30559 .57284 L
.31061 .56783 L
.31531 .56313 L
.32032 .55812 L
.32502 .55342 L
.33003 .54841 L
.33482 .54371 L
.33974 .53869 L
.34407 .53399 L
.34946 .52799 L
.35271 .52428 L
.35917 .5167 L
.36096 .51457 L
.36887 .50486 L
.36888 .50484 L
.37651 .49514 L
.37859 .49243 L
.38389 .48543 L
.38831 .47948 L
.39105 .47572 L
.39802 .46601 L
.39802 .46601 L
.40481 .45629 L
.40773 .45203 L
.41143 .44658 L
.41744 .43758 L
.41791 .43687 L
.42425 .42716 L
.42716 .42264 L
.43047 .41744 L
.43657 .40773 L
.43687 .40725 L
.44256 .39802 L
.44658 .39141 L
.44845 .38831 L
.45425 .37859 L
.45629 .37514 L
.45996 .36888 L
.46559 .35917 L
.46601 .35844 L
.47113 .34946 L
.47572 .34132 L
.4766 .33974 L
.482 .33003 L
.48543 .32379 L
.48733 .32032 L
.4926 .31061 L
.49514 .30587 L
.4978 .30089 L
.50295 .29118 L
.50486 .28756 L
.50804 .28147 L
.51308 .27176 L
.51457 .26887 L
.51806 .26204 L
.523 .25233 L
.52428 .2498 L
.52788 .24262 L
.53274 .23291 L
.53399 .23037 L
.53752 .22319 L
.54229 .21348 L
.54371 .21057 L
.54699 .20377 L
.55168 .19406 L
.55342 .19042 L
.5563 .18434 L
.56091 .17463 L
.56313 .16992 L
.56547 .16492 L
.57 .15521 L
.57284 .14908 L
.57449 .14549 L
.57895 .13578 L
.58256 .1279 L
.58338 .12607 L
.58778 .11636 L
.59215 .10664 L
.59227 .10639 L
.59648 .09693 L
.6008 .08722 L
.60198 .08455 L
.60507 .07751 L
.60933 .06779 L
.61169 .06238 L
.61355 .05808 L
.61776 .04837 L
.62141 .0399 L
.62193 .03866 L
.62608 .02894 L
.63022 .01923 L
.01923 .01923 L
F
0 g
.01923 .85921 m
.02394 .85451 L
.02894 .84949 L
.03364 .84479 L
.03866 .83978 L
.04336 .83508 L
.04837 .83007 L
.05307 .82537 L
.05808 .82036 L
.06278 .81566 L
.06779 .81064 L
.07249 .80594 L
.07751 .80093 L
.08221 .79623 L
.08722 .79122 L
.09192 .78652 L
.09693 .78151 L
.10163 .77681 L
.10664 .77179 L
.11134 .76709 L
.11636 .76208 L
.12106 .75738 L
.12607 .75237 L
.13077 .74767 L
.13578 .74266 L
.14048 .73796 L
.14549 .73294 L
.15019 .72824 L
.15521 .72323 L
.15991 .71853 L
.16492 .71352 L
.16962 .70882 L
.17463 .70381 L
.17933 .69911 L
.18434 .69409 L
.18904 .68939 L
.19406 .68438 L
.19876 .67968 L
.20377 .67467 L
.20847 .66997 L
.21348 .66496 L
.21818 .66026 L
.22319 .65524 L
.22789 .65054 L
.23291 .64553 L
.23761 .64083 L
.24262 .63582 L
.24732 .63112 L
.25233 .62611 L
.25703 .62141 L
Mistroke
.26204 .61639 L
.26674 .61169 L
.27176 .60668 L
.27646 .60198 L
.28147 .59697 L
.28617 .59227 L
.29118 .58726 L
.29588 .58256 L
.30089 .57754 L
.30559 .57284 L
.31061 .56783 L
.31531 .56313 L
.32032 .55812 L
.32502 .55342 L
.33003 .54841 L
.33482 .54371 L
.33974 .53869 L
.34407 .53399 L
.34946 .52799 L
.35271 .52428 L
.35917 .5167 L
.36096 .51457 L
.36887 .50486 L
.36888 .50484 L
.37651 .49514 L
.37859 .49243 L
.38389 .48543 L
.38831 .47948 L
.39105 .47572 L
.39802 .46601 L
.39802 .46601 L
.40481 .45629 L
.40773 .45203 L
.41143 .44658 L
.41744 .43758 L
.41791 .43687 L
.42425 .42716 L
.42716 .42264 L
.43047 .41744 L
.43657 .40773 L
.43687 .40725 L
.44256 .39802 L
.44658 .39141 L
.44845 .38831 L
.45425 .37859 L
.45629 .37514 L
.45996 .36888 L
.46559 .35917 L
.46601 .35844 L
.47113 .34946 L
Mistroke
.47572 .34132 L
.4766 .33974 L
.482 .33003 L
.48543 .32379 L
.48733 .32032 L
.4926 .31061 L
.49514 .30587 L
.4978 .30089 L
.50295 .29118 L
.50486 .28756 L
.50804 .28147 L
.51308 .27176 L
.51457 .26887 L
.51806 .26204 L
.523 .25233 L
.52428 .2498 L
.52788 .24262 L
.53274 .23291 L
.53399 .23037 L
.53752 .22319 L
.54229 .21348 L
.54371 .21057 L
.54699 .20377 L
.55168 .19406 L
.55342 .19042 L
.5563 .18434 L
.56091 .17463 L
.56313 .16992 L
.56547 .16492 L
.57 .15521 L
.57284 .14908 L
.57449 .14549 L
.57895 .13578 L
.58256 .1279 L
.58338 .12607 L
.58778 .11636 L
.59215 .10664 L
.59227 .10639 L
.59648 .09693 L
.6008 .08722 L
.60198 .08455 L
.60507 .07751 L
.60933 .06779 L
.61169 .06238 L
.61355 .05808 L
.61776 .04837 L
.62141 .0399 L
.62193 .03866 L
.62608 .02894 L
.63022 .01923 L
Mistroke
Mfstroke
.4 g
.01923 .8238 m
.02737 .81566 L
.02894 .81408 L
.03708 .80594 L
.03866 .80437 L
.0468 .79623 L
.04837 .79466 L
.05651 .78652 L
.05808 .78495 L
.06622 .77681 L
.06779 .77523 L
.07593 .76709 L
.07751 .76552 L
.08565 .75738 L
.08722 .75581 L
.09536 .74767 L
.09693 .7461 L
.10507 .73796 L
.10664 .73638 L
.11478 .72824 L
.11636 .72667 L
.1245 .71853 L
.12607 .71696 L
.13421 .70882 L
.13578 .70725 L
.14392 .69911 L
.14549 .69753 L
.15363 .68939 L
.15521 .68782 L
.16335 .67968 L
.16492 .67811 L
.17306 .66997 L
.17463 .6684 L
.18277 .66026 L
.18434 .65868 L
.19248 .65054 L
.19406 .64897 L
.2022 .64083 L
.20377 .63926 L
.21191 .63112 L
.21348 .62955 L
.22162 .62141 L
.22319 .61983 L
.23133 .61169 L
.23291 .61012 L
.24105 .60198 L
.24262 .60041 L
.25076 .59227 L
.25233 .5907 L
.26047 .58256 L
.26204 .58098 L
.27018 .57284 L
.27176 .57127 L
.2799 .56313 L
.28147 .56156 L
.28961 .55342 L
.29118 .55185 L
.29932 .54371 L
.30089 .54213 L
.30903 .53399 L
.31061 .53242 L
.31875 .52428 L
.32032 .52271 L
.32846 .51457 L
.33003 .513 L
.33818 .50486 L
.33974 .50328 L
.34811 .49514 L
.34946 .49384 L
.35751 .48543 L
.35917 .48361 L
.36626 .47572 L
.36888 .47267 L
.37454 .46601 L
.37859 .46106 L
.38245 .45629 L
.38831 .44882 L
.39004 .44658 L
.39737 .43687 L
.39802 .43599 L
.40448 .42716 L
.40773 .4226 L
.41138 .41744 L
.41744 .40866 L
.41808 .40773 L
.42465 .39802 L
.42716 .39422 L
.43105 .38831 L
.43687 .37927 L
.4373 .37859 L
.44346 .36888 L
.44658 .36384 L
.44948 .35917 L
.45539 .34946 L
.45629 .34795 L
.46122 .33974 L
.46601 .33161 L
.46693 .33003 L
.47258 .32032 L
.47572 .31483 L
.47813 .31061 L
.48361 .30089 L
.48543 .29762 L
.48902 .29118 L
.49435 .28147 L
.49514 .28 L
.49963 .27176 L
.50482 .26204 L
.50486 .26197 L
.50998 .25233 L
.51457 .24354 L
.51505 .24262 L
.5201 .23291 L
.52428 .22473 L
.52507 .22319 L
.53002 .21348 L
.53399 .20554 L
.53488 .20377 L
.53974 .19406 L
.54371 .18597 L
.54451 .18434 L
.54928 .17463 L
.55342 .16604 L
.55396 .16492 L
.55865 .15521 L
.56313 .14575 L
.56325 .14549 L
.56786 .13578 L
.5724 .12607 L
.57284 .12511 L
.57693 .11636 L
.58141 .10664 L
.58256 .10413 L
.58587 .09693 L
.59029 .08722 L
.59227 .0828 L
.59467 .07751 L
.59904 .06779 L
.60198 .06114 L
.60335 .05808 L
.60767 .04837 L
.61169 .03915 L
.61191 .03866 L
.61618 .02894 L
.62039 .01923 L
.01923 .01923 L
F
0 g
.01923 .8238 m
.02737 .81566 L
.02894 .81408 L
.03708 .80594 L
.03866 .80437 L
.0468 .79623 L
.04837 .79466 L
.05651 .78652 L
.05808 .78495 L
.06622 .77681 L
.06779 .77523 L
.07593 .76709 L
.07751 .76552 L
.08565 .75738 L
.08722 .75581 L
.09536 .74767 L
.09693 .7461 L
.10507 .73796 L
.10664 .73638 L
.11478 .72824 L
.11636 .72667 L
.1245 .71853 L
.12607 .71696 L
.13421 .70882 L
.13578 .70725 L
.14392 .69911 L
.14549 .69753 L
.15363 .68939 L
.15521 .68782 L
.16335 .67968 L
.16492 .67811 L
.17306 .66997 L
.17463 .6684 L
.18277 .66026 L
.18434 .65868 L
.19248 .65054 L
.19406 .64897 L
.2022 .64083 L
.20377 .63926 L
.21191 .63112 L
.21348 .62955 L
.22162 .62141 L
.22319 .61983 L
.23133 .61169 L
.23291 .61012 L
.24105 .60198 L
.24262 .60041 L
.25076 .59227 L
.25233 .5907 L
.26047 .58256 L
Mistroke
.26204 .58098 L
.27018 .57284 L
.27176 .57127 L
.2799 .56313 L
.28147 .56156 L
.28961 .55342 L
.29118 .55185 L
.29932 .54371 L
.30089 .54213 L
.30903 .53399 L
.31061 .53242 L
.31875 .52428 L
.32032 .52271 L
.32846 .51457 L
.33003 .513 L
.33818 .50486 L
.33974 .50328 L
.34811 .49514 L
.34946 .49384 L
.35751 .48543 L
.35917 .48361 L
.36626 .47572 L
.36888 .47267 L
.37454 .46601 L
.37859 .46106 L
.38245 .45629 L
.38831 .44882 L
.39004 .44658 L
.39737 .43687 L
.39802 .43599 L
.40448 .42716 L
.40773 .4226 L
.41138 .41744 L
.41744 .40866 L
.41808 .40773 L
.42465 .39802 L
.42716 .39422 L
.43105 .38831 L
.43687 .37927 L
.4373 .37859 L
.44346 .36888 L
.44658 .36384 L
.44948 .35917 L
.45539 .34946 L
.45629 .34795 L
.46122 .33974 L
.46601 .33161 L
.46693 .33003 L
.47258 .32032 L
.47572 .31483 L
Mistroke
.47813 .31061 L
.48361 .30089 L
.48543 .29762 L
.48902 .29118 L
.49435 .28147 L
.49514 .28 L
.49963 .27176 L
.50482 .26204 L
.50486 .26197 L
.50998 .25233 L
.51457 .24354 L
.51505 .24262 L
.5201 .23291 L
.52428 .22473 L
.52507 .22319 L
.53002 .21348 L
.53399 .20554 L
.53488 .20377 L
.53974 .19406 L
.54371 .18597 L
.54451 .18434 L
.54928 .17463 L
.55342 .16604 L
.55396 .16492 L
.55865 .15521 L
.56313 .14575 L
.56325 .14549 L
.56786 .13578 L
.5724 .12607 L
.57284 .12511 L
.57693 .11636 L
.58141 .10664 L
.58256 .10413 L
.58587 .09693 L
.59029 .08722 L
.59227 .0828 L
.59467 .07751 L
.59904 .06779 L
.60198 .06114 L
.60335 .05808 L
.60767 .04837 L
.61169 .03915 L
.61191 .03866 L
.61618 .02894 L
.62039 .01923 L
Mfstroke
.3 g
.01923 .78011 m
.02247 .77681 L
.02894 .7704 L
.03225 .76709 L
.03866 .76069 L
.04196 .75738 L
.04837 .75098 L
.05167 .74767 L
.05808 .74126 L
.06139 .73796 L
.06779 .73155 L
.0711 .72824 L
.07751 .72184 L
.08081 .71853 L
.08722 .71213 L
.09052 .70882 L
.09693 .70241 L
.10024 .69911 L
.10664 .6927 L
.10995 .68939 L
.11636 .68299 L
.11966 .67968 L
.12607 .67328 L
.12937 .66997 L
.13578 .66356 L
.13909 .66026 L
.14549 .65385 L
.1488 .65054 L
.15521 .64414 L
.15851 .64083 L
.16492 .63443 L
.16822 .63112 L
.17463 .62471 L
.17794 .62141 L
.18434 .615 L
.18765 .61169 L
.19406 .60529 L
.19736 .60198 L
.20377 .59557 L
.20707 .59227 L
.21348 .58586 L
.21679 .58256 L
.22319 .57615 L
.2265 .57284 L
.23291 .56644 L
.23621 .56313 L
.24262 .55672 L
.24592 .55342 L
.25233 .54701 L
.25564 .54371 L
.26204 .5373 L
.26535 .53399 L
.27176 .52759 L
.27506 .52428 L
.28147 .51787 L
.28477 .51457 L
.29118 .50816 L
.29449 .50486 L
.30089 .49845 L
.3042 .49514 L
.31061 .48874 L
.31391 .48543 L
.32032 .47902 L
.32362 .47572 L
.33003 .46931 L
.33326 .46601 L
.33974 .4596 L
.34395 .45629 L
.34946 .45259 L
.35693 .44658 L
.35917 .44427 L
.3671 .43687 L
.36888 .43489 L
.37641 .42716 L
.37859 .42461 L
.38508 .41744 L
.38831 .41351 L
.39323 .40773 L
.39802 .40166 L
.40096 .39802 L
.40773 .38913 L
.40837 .38831 L
.41564 .37859 L
.41744 .37599 L
.42262 .36888 L
.42716 .36225 L
.42932 .35917 L
.43591 .34946 L
.43687 .34794 L
.44237 .33974 L
.44658 .3331 L
.44858 .33003 L
.45476 .32032 L
.45629 .31774 L
.46079 .31061 L
.46601 .30189 L
.46662 .30089 L
.47252 .29118 L
.47572 .28558 L
.47817 .28147 L
.48382 .27176 L
.48543 .2688 L
.48935 .26204 L
.49475 .25233 L
.49514 .25157 L
.5002 .24262 L
.50486 .23392 L
.50542 .23291 L
.51076 .22319 L
.51457 .21585 L
.51585 .21348 L
.52106 .20377 L
.52428 .19737 L
.52604 .19406 L
.53112 .18434 L
.53399 .1785 L
.536 .17463 L
.54098 .16492 L
.54371 .15923 L
.54576 .15521 L
.55064 .14549 L
.55342 .13959 L
.55532 .13578 L
.56012 .12607 L
.56313 .11957 L
.56471 .11636 L
.56944 .10664 L
.57284 .09919 L
.57393 .09693 L
.5786 .08722 L
.58256 .07844 L
.583 .07751 L
.5876 .06779 L
.59197 .05808 L
.59227 .05735 L
.59647 .04837 L
.60084 .03866 L
.60198 .03593 L
.60519 .02894 L
.60957 .01923 L
.01923 .01923 L
F
0 g
.01923 .78011 m
.02247 .77681 L
.02894 .7704 L
.03225 .76709 L
.03866 .76069 L
.04196 .75738 L
.04837 .75098 L
.05167 .74767 L
.05808 .74126 L
.06139 .73796 L
.06779 .73155 L
.0711 .72824 L
.07751 .72184 L
.08081 .71853 L
.08722 .71213 L
.09052 .70882 L
.09693 .70241 L
.10024 .69911 L
.10664 .6927 L
.10995 .68939 L
.11636 .68299 L
.11966 .67968 L
.12607 .67328 L
.12937 .66997 L
.13578 .66356 L
.13909 .66026 L
.14549 .65385 L
.1488 .65054 L
.15521 .64414 L
.15851 .64083 L
.16492 .63443 L
.16822 .63112 L
.17463 .62471 L
.17794 .62141 L
.18434 .615 L
.18765 .61169 L
.19406 .60529 L
.19736 .60198 L
.20377 .59557 L
.20707 .59227 L
.21348 .58586 L
.21679 .58256 L
.22319 .57615 L
.2265 .57284 L
.23291 .56644 L
.23621 .56313 L
.24262 .55672 L
.24592 .55342 L
.25233 .54701 L
.25564 .54371 L
Mistroke
.26204 .5373 L
.26535 .53399 L
.27176 .52759 L
.27506 .52428 L
.28147 .51787 L
.28477 .51457 L
.29118 .50816 L
.29449 .50486 L
.30089 .49845 L
.3042 .49514 L
.31061 .48874 L
.31391 .48543 L
.32032 .47902 L
.32362 .47572 L
.33003 .46931 L
.33326 .46601 L
.33974 .4596 L
.34395 .45629 L
.34946 .45259 L
.35693 .44658 L
.35917 .44427 L
.3671 .43687 L
.36888 .43489 L
.37641 .42716 L
.37859 .42461 L
.38508 .41744 L
.38831 .41351 L
.39323 .40773 L
.39802 .40166 L
.40096 .39802 L
.40773 .38913 L
.40837 .38831 L
.41564 .37859 L
.41744 .37599 L
.42262 .36888 L
.42716 .36225 L
.42932 .35917 L
.43591 .34946 L
.43687 .34794 L
.44237 .33974 L
.44658 .3331 L
.44858 .33003 L
.45476 .32032 L
.45629 .31774 L
.46079 .31061 L
.46601 .30189 L
.46662 .30089 L
.47252 .29118 L
.47572 .28558 L
.47817 .28147 L
Mistroke
.48382 .27176 L
.48543 .2688 L
.48935 .26204 L
.49475 .25233 L
.49514 .25157 L
.5002 .24262 L
.50486 .23392 L
.50542 .23291 L
.51076 .22319 L
.51457 .21585 L
.51585 .21348 L
.52106 .20377 L
.52428 .19737 L
.52604 .19406 L
.53112 .18434 L
.53399 .1785 L
.536 .17463 L
.54098 .16492 L
.54371 .15923 L
.54576 .15521 L
.55064 .14549 L
.55342 .13959 L
.55532 .13578 L
.56012 .12607 L
.56313 .11957 L
.56471 .11636 L
.56944 .10664 L
.57284 .09919 L
.57393 .09693 L
.5786 .08722 L
.58256 .07844 L
.583 .07751 L
.5876 .06779 L
.59197 .05808 L
.59227 .05735 L
.59647 .04837 L
.60084 .03866 L
.60198 .03593 L
.60519 .02894 L
.60957 .01923 L
Mfstroke
.4 g
.01923 .7015 m
.022 .69911 L
.02894 .69179 L
.03134 .68939 L
.03866 .68207 L
.04105 .67968 L
.04837 .67236 L
.05076 .66997 L
.05808 .66265 L
.06047 .66026 L
.06779 .65294 L
.07019 .65054 L
.07751 .64322 L
.0799 .64083 L
.08722 .63351 L
.08961 .63112 L
.09693 .6238 L
.09932 .62141 L
.10664 .61409 L
.10904 .61169 L
.11636 .60437 L
.11875 .60198 L
.12607 .59466 L
.12846 .59227 L
.13578 .58495 L
.13817 .58256 L
.14549 .57524 L
.14789 .57284 L
.15521 .56552 L
.1576 .56313 L
.16492 .55581 L
.16731 .55342 L
.17463 .5461 L
.17702 .54371 L
.18434 .53639 L
.18674 .53399 L
.19406 .52667 L
.19645 .52428 L
.20377 .51696 L
.20616 .51457 L
.21348 .50725 L
.21587 .50486 L
.22319 .49754 L
.22559 .49514 L
.23291 .48782 L
.2353 .48543 L
.24262 .47811 L
.24501 .47572 L
.25233 .4684 L
.25472 .46601 L
.26204 .45869 L
.26444 .45629 L
.27176 .44897 L
.27415 .44658 L
.28147 .43926 L
.28386 .43687 L
.29118 .42955 L
.29357 .42716 L
.30089 .41984 L
.30329 .41744 L
.31061 .41012 L
.313 .40773 L
.32032 .40041 L
.32271 .39802 L
.33003 .3907 L
.33265 .38831 L
.33974 .38099 L
.34164 .37859 L
.34875 .36888 L
.34946 .36789 L
.35588 .35917 L
.35917 .35466 L
.36295 .34946 L
.36888 .34124 L
.36995 .33974 L
.37682 .33003 L
.37859 .3275 L
.38356 .32032 L
.38831 .31341 L
.3902 .31061 L
.39673 .30089 L
.39802 .29896 L
.40311 .29118 L
.40773 .2841 L
.40941 .28147 L
.41561 .27176 L
.41744 .26887 L
.42168 .26204 L
.42716 .25323 L
.4277 .25233 L
.43359 .24262 L
.43687 .23719 L
.43939 .23291 L
.44516 .22319 L
.44658 .22078 L
.45078 .21348 L
.45629 .20397 L
.45641 .20377 L
.46188 .19406 L
.46601 .18676 L
.46733 .18434 L
.4727 .17463 L
.47572 .16918 L
.478 .16492 L
.48328 .15521 L
.48543 .15123 L
.48844 .14549 L
.49362 .13578 L
.49514 .13291 L
.49866 .12607 L
.50375 .11636 L
.50486 .11422 L
.50868 .10664 L
.51367 .09693 L
.51457 .09518 L
.51851 .08722 L
.52341 .07751 L
.52428 .07578 L
.52816 .06779 L
.53298 .05808 L
.53399 .05602 L
.53764 .04837 L
.54238 .03866 L
.54371 .03593 L
.54696 .02894 L
.55163 .01923 L
.01923 .01923 L
F
0 g
.01923 .7015 m
.022 .69911 L
.02894 .69179 L
.03134 .68939 L
.03866 .68207 L
.04105 .67968 L
.04837 .67236 L
.05076 .66997 L
.05808 .66265 L
.06047 .66026 L
.06779 .65294 L
.07019 .65054 L
.07751 .64322 L
.0799 .64083 L
.08722 .63351 L
.08961 .63112 L
.09693 .6238 L
.09932 .62141 L
.10664 .61409 L
.10904 .61169 L
.11636 .60437 L
.11875 .60198 L
.12607 .59466 L
.12846 .59227 L
.13578 .58495 L
.13817 .58256 L
.14549 .57524 L
.14789 .57284 L
.15521 .56552 L
.1576 .56313 L
.16492 .55581 L
.16731 .55342 L
.17463 .5461 L
.17702 .54371 L
.18434 .53639 L
.18674 .53399 L
.19406 .52667 L
.19645 .52428 L
.20377 .51696 L
.20616 .51457 L
.21348 .50725 L
.21587 .50486 L
.22319 .49754 L
.22559 .49514 L
.23291 .48782 L
.2353 .48543 L
.24262 .47811 L
.24501 .47572 L
.25233 .4684 L
.25472 .46601 L
Mistroke
.26204 .45869 L
.26444 .45629 L
.27176 .44897 L
.27415 .44658 L
.28147 .43926 L
.28386 .43687 L
.29118 .42955 L
.29357 .42716 L
.30089 .41984 L
.30329 .41744 L
.31061 .41012 L
.313 .40773 L
.32032 .40041 L
.32271 .39802 L
.33003 .3907 L
.33265 .38831 L
.33974 .38099 L
.34164 .37859 L
.34875 .36888 L
.34946 .36789 L
.35588 .35917 L
.35917 .35466 L
.36295 .34946 L
.36888 .34124 L
.36995 .33974 L
.37682 .33003 L
.37859 .3275 L
.38356 .32032 L
.38831 .31341 L
.3902 .31061 L
.39673 .30089 L
.39802 .29896 L
.40311 .29118 L
.40773 .2841 L
.40941 .28147 L
.41561 .27176 L
.41744 .26887 L
.42168 .26204 L
.42716 .25323 L
.4277 .25233 L
.43359 .24262 L
.43687 .23719 L
.43939 .23291 L
.44516 .22319 L
.44658 .22078 L
.45078 .21348 L
.45629 .20397 L
.45641 .20377 L
.46188 .19406 L
.46601 .18676 L
Mistroke
.46733 .18434 L
.4727 .17463 L
.47572 .16918 L
.478 .16492 L
.48328 .15521 L
.48543 .15123 L
.48844 .14549 L
.49362 .13578 L
.49514 .13291 L
.49866 .12607 L
.50375 .11636 L
.50486 .11422 L
.50868 .10664 L
.51367 .09693 L
.51457 .09518 L
.51851 .08722 L
.52341 .07751 L
.52428 .07578 L
.52816 .06779 L
.53298 .05808 L
.53399 .05602 L
.53764 .04837 L
.54238 .03866 L
.54371 .03593 L
.54696 .02894 L
.55163 .01923 L
Mfstroke
.5 g
.01923 .65782 m
.02652 .65054 L
.02894 .64811 L
.03622 .64083 L
.03866 .6384 L
.04594 .63112 L
.04837 .62869 L
.05565 .62141 L
.05808 .61897 L
.06536 .61169 L
.06779 .60926 L
.07507 .60198 L
.07751 .59955 L
.08479 .59227 L
.08722 .58984 L
.0945 .58256 L
.09693 .58012 L
.10421 .57284 L
.10664 .57041 L
.11392 .56313 L
.11636 .5607 L
.12364 .55342 L
.12607 .55099 L
.13335 .54371 L
.13578 .54127 L
.14306 .53399 L
.14549 .53156 L
.15277 .52428 L
.15521 .52185 L
.16249 .51457 L
.16492 .51214 L
.1722 .50486 L
.17463 .50242 L
.18191 .49514 L
.18434 .49271 L
.19162 .48543 L
.19406 .483 L
.20134 .47572 L
.20377 .47329 L
.21105 .46601 L
.21348 .46357 L
.22076 .45629 L
.22319 .45386 L
.23047 .44658 L
.23291 .44415 L
.24019 .43687 L
.24262 .43444 L
.2499 .42716 L
.25233 .42472 L
.25961 .41744 L
.26204 .41501 L
.26932 .40773 L
.27176 .4053 L
.27904 .39802 L
.28147 .39559 L
.28875 .38831 L
.29118 .38587 L
.29846 .37859 L
.30089 .37616 L
.30817 .36888 L
.31061 .36645 L
.31789 .35917 L
.32032 .35674 L
.3276 .34946 L
.33003 .34702 L
.33738 .33974 L
.33974 .33731 L
.3464 .33003 L
.34946 .32661 L
.35494 .32032 L
.35917 .31532 L
.36309 .31061 L
.36888 .30346 L
.37093 .30089 L
.37849 .29118 L
.37859 .29104 L
.38581 .28147 L
.38831 .27809 L
.39292 .27176 L
.39802 .26462 L
.39984 .26204 L
.40658 .25233 L
.40773 .25065 L
.41317 .24262 L
.41744 .23619 L
.41961 .23291 L
.42592 .22319 L
.42716 .22126 L
.4321 .21348 L
.43687 .20587 L
.43817 .20377 L
.44414 .19406 L
.44658 .19003 L
.45 .18434 L
.45578 .17463 L
.45629 .17375 L
.46146 .16492 L
.46601 .15705 L
.46706 .15521 L
.47259 .14549 L
.47572 .13993 L
.47804 .13578 L
.48342 .12607 L
.48543 .12241 L
.48873 .11636 L
.49399 .10664 L
.49514 .10449 L
.49917 .09693 L
.50431 .08722 L
.50486 .08618 L
.50938 .07751 L
.51441 .06779 L
.51457 .06749 L
.51938 .05808 L
.52428 .04842 L
.52431 .04837 L
.52918 .03866 L
.53399 .02898 L
.53401 .02894 L
.53879 .01923 L
.01923 .01923 L
F
0 g
.01923 .65782 m
.02652 .65054 L
.02894 .64811 L
.03622 .64083 L
.03866 .6384 L
.04594 .63112 L
.04837 .62869 L
.05565 .62141 L
.05808 .61897 L
.06536 .61169 L
.06779 .60926 L
.07507 .60198 L
.07751 .59955 L
.08479 .59227 L
.08722 .58984 L
.0945 .58256 L
.09693 .58012 L
.10421 .57284 L
.10664 .57041 L
.11392 .56313 L
.11636 .5607 L
.12364 .55342 L
.12607 .55099 L
.13335 .54371 L
.13578 .54127 L
.14306 .53399 L
.14549 .53156 L
.15277 .52428 L
.15521 .52185 L
.16249 .51457 L
.16492 .51214 L
.1722 .50486 L
.17463 .50242 L
.18191 .49514 L
.18434 .49271 L
.19162 .48543 L
.19406 .483 L
.20134 .47572 L
.20377 .47329 L
.21105 .46601 L
.21348 .46357 L
.22076 .45629 L
.22319 .45386 L
.23047 .44658 L
.23291 .44415 L
.24019 .43687 L
.24262 .43444 L
.2499 .42716 L
.25233 .42472 L
.25961 .41744 L
Mistroke
.26204 .41501 L
.26932 .40773 L
.27176 .4053 L
.27904 .39802 L
.28147 .39559 L
.28875 .38831 L
.29118 .38587 L
.29846 .37859 L
.30089 .37616 L
.30817 .36888 L
.31061 .36645 L
.31789 .35917 L
.32032 .35674 L
.3276 .34946 L
.33003 .34702 L
.33738 .33974 L
.33974 .33731 L
.3464 .33003 L
.34946 .32661 L
.35494 .32032 L
.35917 .31532 L
.36309 .31061 L
.36888 .30346 L
.37093 .30089 L
.37849 .29118 L
.37859 .29104 L
.38581 .28147 L
.38831 .27809 L
.39292 .27176 L
.39802 .26462 L
.39984 .26204 L
.40658 .25233 L
.40773 .25065 L
.41317 .24262 L
.41744 .23619 L
.41961 .23291 L
.42592 .22319 L
.42716 .22126 L
.4321 .21348 L
.43687 .20587 L
.43817 .20377 L
.44414 .19406 L
.44658 .19003 L
.45 .18434 L
.45578 .17463 L
.45629 .17375 L
.46146 .16492 L
.46601 .15705 L
.46706 .15521 L
.47259 .14549 L
Mistroke
.47572 .13993 L
.47804 .13578 L
.48342 .12607 L
.48543 .12241 L
.48873 .11636 L
.49399 .10664 L
.49514 .10449 L
.49917 .09693 L
.50431 .08722 L
.50486 .08618 L
.50938 .07751 L
.51441 .06779 L
.51457 .06749 L
.51938 .05808 L
.52428 .04842 L
.52431 .04837 L
.52918 .03866 L
.53399 .02898 L
.53401 .02894 L
.53879 .01923 L
Mfstroke
.6 g
.01923 .62241 m
.02023 .62141 L
.02894 .6127 L
.02995 .61169 L
.03866 .60299 L
.03966 .60198 L
.04837 .59327 L
.04937 .59227 L
.05808 .58356 L
.05909 .58256 L
.06779 .57385 L
.0688 .57284 L
.07751 .56414 L
.07851 .56313 L
.08722 .55442 L
.08822 .55342 L
.09693 .54471 L
.09794 .54371 L
.10664 .535 L
.10765 .53399 L
.11636 .52529 L
.11736 .52428 L
.12607 .51557 L
.12707 .51457 L
.13578 .50586 L
.13679 .50486 L
.14549 .49615 L
.1465 .49514 L
.15521 .48644 L
.15621 .48543 L
.16492 .47672 L
.16592 .47572 L
.17463 .46701 L
.17564 .46601 L
.18434 .4573 L
.18535 .45629 L
.19406 .44759 L
.19506 .44658 L
.20377 .43787 L
.20477 .43687 L
.21348 .42816 L
.21449 .42716 L
.22319 .41845 L
.2242 .41744 L
.23291 .40874 L
.23391 .40773 L
.24262 .39902 L
.24362 .39802 L
.25233 .38931 L
.25334 .38831 L
.26204 .3796 L
.26305 .37859 L
.27176 .36989 L
.27276 .36888 L
.28147 .36017 L
.28247 .35917 L
.29118 .35046 L
.29219 .34946 L
.30089 .34075 L
.3019 .33974 L
.31061 .33104 L
.31161 .33003 L
.32032 .32132 L
.32132 .32032 L
.33003 .31161 L
.33104 .31061 L
.33974 .3019 L
.34076 .30089 L
.34946 .29246 L
.35072 .29118 L
.35917 .28223 L
.35987 .28147 L
.36848 .27176 L
.36888 .27129 L
.37667 .26204 L
.37859 .25967 L
.3845 .25233 L
.38831 .24744 L
.39202 .24262 L
.39802 .23461 L
.39928 .23291 L
.40633 .22319 L
.40773 .22121 L
.41318 .21348 L
.41744 .20728 L
.41984 .20377 L
.42635 .19406 L
.42716 .19283 L
.43273 .18434 L
.43687 .17789 L
.43895 .17463 L
.44506 .16492 L
.44658 .16246 L
.45106 .15521 L
.45629 .14657 L
.45694 .14549 L
.46275 .13578 L
.46601 .13022 L
.46844 .12607 L
.47406 .11636 L
.47572 .11344 L
.4796 .10664 L
.48505 .09693 L
.48543 .09624 L
.49045 .08722 L
.49514 .07861 L
.49575 .07751 L
.50102 .06779 L
.50486 .06058 L
.50619 .05808 L
.51134 .04837 L
.51457 .04216 L
.5164 .03866 L
.52143 .02894 L
.52428 .02334 L
.52639 .01923 L
.01923 .01923 L
F
0 g
.01923 .62241 m
.02023 .62141 L
.02894 .6127 L
.02995 .61169 L
.03866 .60299 L
.03966 .60198 L
.04837 .59327 L
.04937 .59227 L
.05808 .58356 L
.05909 .58256 L
.06779 .57385 L
.0688 .57284 L
.07751 .56414 L
.07851 .56313 L
.08722 .55442 L
.08822 .55342 L
.09693 .54471 L
.09794 .54371 L
.10664 .535 L
.10765 .53399 L
.11636 .52529 L
.11736 .52428 L
.12607 .51557 L
.12707 .51457 L
.13578 .50586 L
.13679 .50486 L
.14549 .49615 L
.1465 .49514 L
.15521 .48644 L
.15621 .48543 L
.16492 .47672 L
.16592 .47572 L
.17463 .46701 L
.17564 .46601 L
.18434 .4573 L
.18535 .45629 L
.19406 .44759 L
.19506 .44658 L
.20377 .43787 L
.20477 .43687 L
.21348 .42816 L
.21449 .42716 L
.22319 .41845 L
.2242 .41744 L
.23291 .40874 L
.23391 .40773 L
.24262 .39902 L
.24362 .39802 L
.25233 .38931 L
.25334 .38831 L
Mistroke
.26204 .3796 L
.26305 .37859 L
.27176 .36989 L
.27276 .36888 L
.28147 .36017 L
.28247 .35917 L
.29118 .35046 L
.29219 .34946 L
.30089 .34075 L
.3019 .33974 L
.31061 .33104 L
.31161 .33003 L
.32032 .32132 L
.32132 .32032 L
.33003 .31161 L
.33104 .31061 L
.33974 .3019 L
.34076 .30089 L
.34946 .29246 L
.35072 .29118 L
.35917 .28223 L
.35987 .28147 L
.36848 .27176 L
.36888 .27129 L
.37667 .26204 L
.37859 .25967 L
.3845 .25233 L
.38831 .24744 L
.39202 .24262 L
.39802 .23461 L
.39928 .23291 L
.40633 .22319 L
.40773 .22121 L
.41318 .21348 L
.41744 .20728 L
.41984 .20377 L
.42635 .19406 L
.42716 .19283 L
.43273 .18434 L
.43687 .17789 L
.43895 .17463 L
.44506 .16492 L
.44658 .16246 L
.45106 .15521 L
.45629 .14657 L
.45694 .14549 L
.46275 .13578 L
.46601 .13022 L
.46844 .12607 L
.47406 .11636 L
Mistroke
.47572 .11344 L
.4796 .10664 L
.48505 .09693 L
.48543 .09624 L
.49045 .08722 L
.49514 .07861 L
.49575 .07751 L
.50102 .06779 L
.50486 .06058 L
.50619 .05808 L
.51134 .04837 L
.51457 .04216 L
.5164 .03866 L
.52143 .02894 L
.52428 .02334 L
.52639 .01923 L
Mfstroke
.7 g
.01923 .57874 m
.02505 .57284 L
.02894 .56903 L
.03484 .56313 L
.03866 .55932 L
.04455 .55342 L
.04837 .54961 L
.05427 .54371 L
.05808 .53989 L
.06398 .53399 L
.06779 .53018 L
.07369 .52428 L
.07751 .52047 L
.0834 .51457 L
.08722 .51076 L
.09312 .50486 L
.09693 .50104 L
.10283 .49514 L
.10664 .49133 L
.11254 .48543 L
.11636 .48162 L
.12225 .47572 L
.12607 .4719 L
.13197 .46601 L
.13578 .46219 L
.14168 .45629 L
.14549 .45248 L
.15139 .44658 L
.15521 .44277 L
.1611 .43687 L
.16492 .43305 L
.17082 .42716 L
.17463 .42334 L
.18053 .41744 L
.18434 .41363 L
.19024 .40773 L
.19406 .40392 L
.19995 .39802 L
.20377 .3942 L
.20967 .38831 L
.21348 .38449 L
.21938 .37859 L
.22319 .37478 L
.22909 .36888 L
.23291 .36507 L
.2388 .35917 L
.24262 .35535 L
.24852 .34946 L
.25233 .34564 L
.25823 .33974 L
.26204 .33593 L
.26794 .33003 L
.27176 .32622 L
.27765 .32032 L
.28147 .3165 L
.28737 .31061 L
.29118 .30679 L
.29708 .30089 L
.30089 .29708 L
.30679 .29118 L
.31061 .28737 L
.3165 .28147 L
.32032 .27765 L
.32622 .27176 L
.33003 .26794 L
.33581 .26204 L
.33974 .25823 L
.34767 .25233 L
.34946 .25119 L
.35917 .24286 L
.35945 .24262 L
.36888 .23349 L
.36948 .23291 L
.37859 .2232 L
.3786 .22319 L
.38723 .21348 L
.38831 .21211 L
.39533 .20377 L
.39802 .20028 L
.40302 .19406 L
.40773 .18776 L
.41035 .18434 L
.41742 .17463 L
.41744 .1746 L
.42443 .16492 L
.42716 .16087 L
.43112 .15521 L
.43687 .14655 L
.43758 .14549 L
.44405 .13578 L
.44658 .13172 L
.45026 .12607 L
.45629 .11636 L
.45629 .11635 L
.46239 .10664 L
.46601 .10051 L
.4682 .09693 L
.47402 .08722 L
.47572 .08419 L
.4797 .07751 L
.48523 .06779 L
.48543 .06741 L
.49083 .05808 L
.49514 .05019 L
.49618 .04837 L
.50163 .03866 L
.50486 .03254 L
.50685 .02894 L
.51214 .01923 L
.01923 .01923 L
F
0 g
.01923 .57874 m
.02505 .57284 L
.02894 .56903 L
.03484 .56313 L
.03866 .55932 L
.04455 .55342 L
.04837 .54961 L
.05427 .54371 L
.05808 .53989 L
.06398 .53399 L
.06779 .53018 L
.07369 .52428 L
.07751 .52047 L
.0834 .51457 L
.08722 .51076 L
.09312 .50486 L
.09693 .50104 L
.10283 .49514 L
.10664 .49133 L
.11254 .48543 L
.11636 .48162 L
.12225 .47572 L
.12607 .4719 L
.13197 .46601 L
.13578 .46219 L
.14168 .45629 L
.14549 .45248 L
.15139 .44658 L
.15521 .44277 L
.1611 .43687 L
.16492 .43305 L
.17082 .42716 L
.17463 .42334 L
.18053 .41744 L
.18434 .41363 L
.19024 .40773 L
.19406 .40392 L
.19995 .39802 L
.20377 .3942 L
.20967 .38831 L
.21348 .38449 L
.21938 .37859 L
.22319 .37478 L
.22909 .36888 L
.23291 .36507 L
.2388 .35917 L
.24262 .35535 L
.24852 .34946 L
.25233 .34564 L
.25823 .33974 L
Mistroke
.26204 .33593 L
.26794 .33003 L
.27176 .32622 L
.27765 .32032 L
.28147 .3165 L
.28737 .31061 L
.29118 .30679 L
.29708 .30089 L
.30089 .29708 L
.30679 .29118 L
.31061 .28737 L
.3165 .28147 L
.32032 .27765 L
.32622 .27176 L
.33003 .26794 L
.33581 .26204 L
.33974 .25823 L
.34767 .25233 L
.34946 .25119 L
.35917 .24286 L
.35945 .24262 L
.36888 .23349 L
.36948 .23291 L
.37859 .2232 L
.3786 .22319 L
.38723 .21348 L
.38831 .21211 L
.39533 .20377 L
.39802 .20028 L
.40302 .19406 L
.40773 .18776 L
.41035 .18434 L
.41742 .17463 L
.41744 .1746 L
.42443 .16492 L
.42716 .16087 L
.43112 .15521 L
.43687 .14655 L
.43758 .14549 L
.44405 .13578 L
.44658 .13172 L
.45026 .12607 L
.45629 .11636 L
.45629 .11635 L
.46239 .10664 L
.46601 .10051 L
.4682 .09693 L
.47402 .08722 L
.47572 .08419 L
.4797 .07751 L
Mistroke
.48523 .06779 L
.48543 .06741 L
.49083 .05808 L
.49514 .05019 L
.49618 .04837 L
.50163 .03866 L
.50486 .03254 L
.50685 .02894 L
.51214 .01923 L
Mfstroke
.6 g
.01923 .50011 m
.02448 .49514 L
.02894 .4904 L
.03391 .48543 L
.03866 .48069 L
.04362 .47572 L
.04837 .47098 L
.05334 .46601 L
.05808 .46126 L
.06305 .45629 L
.06779 .45155 L
.07276 .44658 L
.07751 .44184 L
.08247 .43687 L
.08722 .43212 L
.09219 .42716 L
.09693 .42241 L
.1019 .41744 L
.10664 .4127 L
.11161 .40773 L
.11636 .40299 L
.12132 .39802 L
.12607 .39327 L
.13104 .38831 L
.13578 .38356 L
.14075 .37859 L
.14549 .37385 L
.15046 .36888 L
.15521 .36414 L
.16017 .35917 L
.16492 .35442 L
.16989 .34946 L
.17463 .34471 L
.1796 .33974 L
.18434 .335 L
.18931 .33003 L
.19406 .32529 L
.19902 .32032 L
.20377 .31557 L
.20874 .31061 L
.21348 .30586 L
.21845 .30089 L
.22319 .29615 L
.22816 .29118 L
.23291 .28644 L
.23787 .28147 L
.24262 .27672 L
.24759 .27176 L
.25233 .26701 L
.2573 .26204 L
.26204 .2573 L
.26701 .25233 L
.27176 .24759 L
.27672 .24262 L
.28147 .23787 L
.28644 .23291 L
.29118 .22816 L
.29615 .22319 L
.30089 .21845 L
.30586 .21348 L
.31061 .20874 L
.31557 .20377 L
.32032 .19902 L
.32529 .19406 L
.33003 .18931 L
.33531 .18434 L
.33974 .1796 L
.34357 .17463 L
.34946 .16649 L
.35063 .16492 L
.35777 .15521 L
.35917 .15329 L
.36482 .14549 L
.36888 .13984 L
.37177 .13578 L
.37859 .12613 L
.37864 .12607 L
.38534 .11636 L
.38831 .11202 L
.39193 .10664 L
.39802 .09758 L
.39844 .09693 L
.4048 .08722 L
.40773 .08272 L
.41106 .07751 L
.41725 .06779 L
.41744 .06749 L
.42329 .05808 L
.42716 .05184 L
.42925 .04837 L
.43516 .03866 L
.43687 .03582 L
.44092 .02894 L
.44658 .01941 L
.44668 .01923 L
.01923 .01923 L
F
0 g
.01923 .50011 m
.02448 .49514 L
.02894 .4904 L
.03391 .48543 L
.03866 .48069 L
.04362 .47572 L
.04837 .47098 L
.05334 .46601 L
.05808 .46126 L
.06305 .45629 L
.06779 .45155 L
.07276 .44658 L
.07751 .44184 L
.08247 .43687 L
.08722 .43212 L
.09219 .42716 L
.09693 .42241 L
.1019 .41744 L
.10664 .4127 L
.11161 .40773 L
.11636 .40299 L
.12132 .39802 L
.12607 .39327 L
.13104 .38831 L
.13578 .38356 L
.14075 .37859 L
.14549 .37385 L
.15046 .36888 L
.15521 .36414 L
.16017 .35917 L
.16492 .35442 L
.16989 .34946 L
.17463 .34471 L
.1796 .33974 L
.18434 .335 L
.18931 .33003 L
.19406 .32529 L
.19902 .32032 L
.20377 .31557 L
.20874 .31061 L
.21348 .30586 L
.21845 .30089 L
.22319 .29615 L
.22816 .29118 L
.23291 .28644 L
.23787 .28147 L
.24262 .27672 L
.24759 .27176 L
.25233 .26701 L
.2573 .26204 L
Mistroke
.26204 .2573 L
.26701 .25233 L
.27176 .24759 L
.27672 .24262 L
.28147 .23787 L
.28644 .23291 L
.29118 .22816 L
.29615 .22319 L
.30089 .21845 L
.30586 .21348 L
.31061 .20874 L
.31557 .20377 L
.32032 .19902 L
.32529 .19406 L
.33003 .18931 L
.33531 .18434 L
.33974 .1796 L
.34357 .17463 L
.34946 .16649 L
.35063 .16492 L
.35777 .15521 L
.35917 .15329 L
.36482 .14549 L
.36888 .13984 L
.37177 .13578 L
.37859 .12613 L
.37864 .12607 L
.38534 .11636 L
.38831 .11202 L
.39193 .10664 L
.39802 .09758 L
.39844 .09693 L
.4048 .08722 L
.40773 .08272 L
.41106 .07751 L
.41725 .06779 L
.41744 .06749 L
.42329 .05808 L
.42716 .05184 L
.42925 .04837 L
.43516 .03866 L
.43687 .03582 L
.44092 .02894 L
.44658 .01941 L
.44668 .01923 L
Mfstroke
.5 g
.01923 .45644 m
.01938 .45629 L
.02894 .44673 L
.02909 .44658 L
.03866 .43702 L
.0388 .43687 L
.04837 .4273 L
.04852 .42716 L
.05808 .41759 L
.05823 .41744 L
.06779 .40788 L
.06794 .40773 L
.07751 .39817 L
.07765 .39802 L
.08722 .38845 L
.08737 .38831 L
.09693 .37874 L
.09708 .37859 L
.10664 .36903 L
.10679 .36888 L
.11636 .35932 L
.1165 .35917 L
.12607 .3496 L
.12622 .34946 L
.13578 .33989 L
.13593 .33974 L
.14549 .33018 L
.14564 .33003 L
.15521 .32047 L
.15535 .32032 L
.16492 .31075 L
.16507 .31061 L
.17463 .30104 L
.17478 .30089 L
.18434 .29133 L
.18449 .29118 L
.19406 .28162 L
.1942 .28147 L
.20377 .2719 L
.20392 .27176 L
.21348 .26219 L
.21363 .26204 L
.22319 .25248 L
.22334 .25233 L
.23291 .24277 L
.23305 .24262 L
.24262 .23305 L
.24277 .23291 L
.25233 .22334 L
.25248 .22319 L
.26204 .21363 L
.26219 .21348 L
.27176 .20392 L
.2719 .20377 L
.28147 .1942 L
.28162 .19406 L
.29118 .18449 L
.29133 .18434 L
.30089 .17478 L
.30104 .17463 L
.31061 .16507 L
.31075 .16492 L
.32032 .15535 L
.32047 .15521 L
.33003 .14564 L
.33018 .14549 L
.33974 .13593 L
.33988 .13578 L
.34871 .12607 L
.34946 .12523 L
.35713 .11636 L
.35917 .11394 L
.3652 .10664 L
.36888 .10207 L
.37296 .09693 L
.37859 .08966 L
.38046 .08722 L
.38772 .07751 L
.38831 .07671 L
.39478 .06779 L
.39802 .06324 L
.40165 .05808 L
.40773 .04927 L
.40834 .04837 L
.41489 .03866 L
.41744 .03481 L
.42129 .02894 L
.42716 .01988 L
.42757 .01923 L
.01923 .01923 L
F
0 g
.01923 .45644 m
.01938 .45629 L
.02894 .44673 L
.02909 .44658 L
.03866 .43702 L
.0388 .43687 L
.04837 .4273 L
.04852 .42716 L
.05808 .41759 L
.05823 .41744 L
.06779 .40788 L
.06794 .40773 L
.07751 .39817 L
.07765 .39802 L
.08722 .38845 L
.08737 .38831 L
.09693 .37874 L
.09708 .37859 L
.10664 .36903 L
.10679 .36888 L
.11636 .35932 L
.1165 .35917 L
.12607 .3496 L
.12622 .34946 L
.13578 .33989 L
.13593 .33974 L
.14549 .33018 L
.14564 .33003 L
.15521 .32047 L
.15535 .32032 L
.16492 .31075 L
.16507 .31061 L
.17463 .30104 L
.17478 .30089 L
.18434 .29133 L
.18449 .29118 L
.19406 .28162 L
.1942 .28147 L
.20377 .2719 L
.20392 .27176 L
.21348 .26219 L
.21363 .26204 L
.22319 .25248 L
.22334 .25233 L
.23291 .24277 L
.23305 .24262 L
.24262 .23305 L
.24277 .23291 L
.25233 .22334 L
.25248 .22319 L
Mistroke
.26204 .21363 L
.26219 .21348 L
.27176 .20392 L
.2719 .20377 L
.28147 .1942 L
.28162 .19406 L
.29118 .18449 L
.29133 .18434 L
.30089 .17478 L
.30104 .17463 L
.31061 .16507 L
.31075 .16492 L
.32032 .15535 L
.32047 .15521 L
.33003 .14564 L
.33018 .14549 L
.33974 .13593 L
.33988 .13578 L
.34871 .12607 L
.34946 .12523 L
.35713 .11636 L
.35917 .11394 L
.3652 .10664 L
.36888 .10207 L
.37296 .09693 L
.37859 .08966 L
.38046 .08722 L
.38772 .07751 L
.38831 .07671 L
.39478 .06779 L
.39802 .06324 L
.40165 .05808 L
.40773 .04927 L
.40834 .04837 L
.41489 .03866 L
.41744 .03481 L
.42129 .02894 L
.42716 .01988 L
.42757 .01923 L
Mfstroke
.4 g
.01923 .42103 m
.02281 .41744 L
.02894 .41132 L
.03253 .40773 L
.03866 .4016 L
.04224 .39802 L
.04837 .39189 L
.05195 .38831 L
.05808 .38218 L
.06167 .37859 L
.06779 .37247 L
.07138 .36888 L
.07751 .36275 L
.08109 .35917 L
.08722 .35304 L
.0908 .34946 L
.09693 .34333 L
.10052 .33974 L
.10664 .33362 L
.11023 .33003 L
.11636 .3239 L
.11994 .32032 L
.12607 .31419 L
.12965 .31061 L
.13578 .30448 L
.13937 .30089 L
.14549 .29477 L
.14908 .29118 L
.15521 .28505 L
.15879 .28147 L
.16492 .27534 L
.1685 .27176 L
.17463 .26563 L
.17822 .26204 L
.18434 .25592 L
.18793 .25233 L
.19406 .2462 L
.19764 .24262 L
.20377 .23649 L
.20735 .23291 L
.21348 .22678 L
.21707 .22319 L
.22319 .21707 L
.22678 .21348 L
.23291 .20735 L
.23649 .20377 L
.24262 .19764 L
.2462 .19406 L
.25233 .18793 L
.25592 .18434 L
.26204 .17822 L
.26563 .17463 L
.27176 .1685 L
.27534 .16492 L
.28147 .15879 L
.28505 .15521 L
.29118 .14908 L
.29477 .14549 L
.30089 .13937 L
.30448 .13578 L
.31061 .12965 L
.31419 .12607 L
.32032 .11994 L
.3239 .11636 L
.33003 .11023 L
.33363 .10664 L
.33974 .10052 L
.3434 .09693 L
.34946 .09107 L
.35323 .08722 L
.35917 .08085 L
.36222 .07751 L
.36888 .0699 L
.37069 .06779 L
.37859 .05829 L
.37876 .05808 L
.38652 .04837 L
.38831 .04605 L
.39397 .03866 L
.39802 .03322 L
.40118 .02894 L
.40773 .01983 L
.40816 .01923 L
.01923 .01923 L
F
0 g
.01923 .42103 m
.02281 .41744 L
.02894 .41132 L
.03253 .40773 L
.03866 .4016 L
.04224 .39802 L
.04837 .39189 L
.05195 .38831 L
.05808 .38218 L
.06167 .37859 L
.06779 .37247 L
.07138 .36888 L
.07751 .36275 L
.08109 .35917 L
.08722 .35304 L
.0908 .34946 L
.09693 .34333 L
.10052 .33974 L
.10664 .33362 L
.11023 .33003 L
.11636 .3239 L
.11994 .32032 L
.12607 .31419 L
.12965 .31061 L
.13578 .30448 L
.13937 .30089 L
.14549 .29477 L
.14908 .29118 L
.15521 .28505 L
.15879 .28147 L
.16492 .27534 L
.1685 .27176 L
.17463 .26563 L
.17822 .26204 L
.18434 .25592 L
.18793 .25233 L
.19406 .2462 L
.19764 .24262 L
.20377 .23649 L
.20735 .23291 L
.21348 .22678 L
.21707 .22319 L
.22319 .21707 L
.22678 .21348 L
.23291 .20735 L
.23649 .20377 L
.24262 .19764 L
.2462 .19406 L
.25233 .18793 L
.25592 .18434 L
Mistroke
.26204 .17822 L
.26563 .17463 L
.27176 .1685 L
.27534 .16492 L
.28147 .15879 L
.28505 .15521 L
.29118 .14908 L
.29477 .14549 L
.30089 .13937 L
.30448 .13578 L
.31061 .12965 L
.31419 .12607 L
.32032 .11994 L
.3239 .11636 L
.33003 .11023 L
.33363 .10664 L
.33974 .10052 L
.3434 .09693 L
.34946 .09107 L
.35323 .08722 L
.35917 .08085 L
.36222 .07751 L
.36888 .0699 L
.37069 .06779 L
.37859 .05829 L
.37876 .05808 L
.38652 .04837 L
.38831 .04605 L
.39397 .03866 L
.39802 .03322 L
.40118 .02894 L
.40773 .01983 L
.40816 .01923 L
Mfstroke
.3 g
.01923 .37734 m
.02764 .36888 L
.02894 .36763 L
.0374 .35917 L
.03866 .35791 L
.04711 .34946 L
.04837 .3482 L
.05683 .33974 L
.05808 .33849 L
.06654 .33003 L
.06779 .32878 L
.07625 .32032 L
.07751 .31906 L
.08596 .31061 L
.08722 .30935 L
.09568 .30089 L
.09693 .29964 L
.10539 .29118 L
.10664 .28993 L
.1151 .28147 L
.11636 .28021 L
.12481 .27176 L
.12607 .2705 L
.13453 .26204 L
.13578 .26079 L
.14424 .25233 L
.14549 .25108 L
.15395 .24262 L
.15521 .24136 L
.16366 .23291 L
.16492 .23165 L
.17338 .22319 L
.17463 .22194 L
.18309 .21348 L
.18434 .21223 L
.1928 .20377 L
.19406 .20251 L
.20251 .19406 L
.20377 .1928 L
.21223 .18434 L
.21348 .18309 L
.22194 .17463 L
.22319 .17338 L
.23165 .16492 L
.23291 .16366 L
.24136 .15521 L
.24262 .15395 L
.25108 .14549 L
.25233 .14424 L
.26079 .13578 L
.26204 .13453 L
.2705 .12607 L
.27176 .12481 L
.28021 .11636 L
.28147 .1151 L
.28993 .10664 L
.29118 .10539 L
.29964 .09693 L
.30089 .09568 L
.30935 .08722 L
.31061 .08596 L
.31906 .07751 L
.32032 .07625 L
.32878 .06779 L
.33003 .06654 L
.33841 .05808 L
.33974 .05683 L
.34946 .0498 L
.35135 .04837 L
.35917 .0415 L
.36236 .03866 L
.36888 .03213 L
.37208 .02894 L
.37859 .0218 L
.381 .01923 L
.01923 .01923 L
F
0 g
.01923 .37734 m
.02764 .36888 L
.02894 .36763 L
.0374 .35917 L
.03866 .35791 L
.04711 .34946 L
.04837 .3482 L
.05683 .33974 L
.05808 .33849 L
.06654 .33003 L
.06779 .32878 L
.07625 .32032 L
.07751 .31906 L
.08596 .31061 L
.08722 .30935 L
.09568 .30089 L
.09693 .29964 L
.10539 .29118 L
.10664 .28993 L
.1151 .28147 L
.11636 .28021 L
.12481 .27176 L
.12607 .2705 L
.13453 .26204 L
.13578 .26079 L
.14424 .25233 L
.14549 .25108 L
.15395 .24262 L
.15521 .24136 L
.16366 .23291 L
.16492 .23165 L
.17338 .22319 L
.17463 .22194 L
.18309 .21348 L
.18434 .21223 L
.1928 .20377 L
.19406 .20251 L
.20251 .19406 L
.20377 .1928 L
.21223 .18434 L
.21348 .18309 L
.22194 .17463 L
.22319 .17338 L
.23165 .16492 L
.23291 .16366 L
.24136 .15521 L
.24262 .15395 L
.25108 .14549 L
.25233 .14424 L
.26079 .13578 L
Mistroke
.26204 .13453 L
.2705 .12607 L
.27176 .12481 L
.28021 .11636 L
.28147 .1151 L
.28993 .10664 L
.29118 .10539 L
.29964 .09693 L
.30089 .09568 L
.30935 .08722 L
.31061 .08596 L
.31906 .07751 L
.32032 .07625 L
.32878 .06779 L
.33003 .06654 L
.33841 .05808 L
.33974 .05683 L
.34946 .0498 L
.35135 .04837 L
.35917 .0415 L
.36236 .03866 L
.36888 .03213 L
.37208 .02894 L
.37859 .0218 L
.381 .01923 L
Mfstroke
.4 g
.01923 .29875 m
.02691 .29118 L
.02894 .28904 L
.03651 .28147 L
.03866 .27933 L
.04623 .27176 L
.04837 .26961 L
.05594 .26204 L
.05808 .2599 L
.06565 .25233 L
.06779 .25019 L
.07536 .24262 L
.07751 .24048 L
.08508 .23291 L
.08722 .23076 L
.09479 .22319 L
.09693 .22105 L
.1045 .21348 L
.10664 .21134 L
.11421 .20377 L
.11636 .20163 L
.12393 .19406 L
.12607 .19191 L
.13364 .18434 L
.13578 .1822 L
.14335 .17463 L
.14549 .17249 L
.15306 .16492 L
.15521 .16278 L
.16278 .15521 L
.16492 .15306 L
.17249 .14549 L
.17463 .14335 L
.1822 .13578 L
.18434 .13364 L
.19191 .12607 L
.19406 .12393 L
.20163 .11636 L
.20377 .11421 L
.21134 .10664 L
.21348 .1045 L
.22105 .09693 L
.22319 .09479 L
.23076 .08722 L
.23291 .08508 L
.24048 .07751 L
.24262 .07536 L
.25019 .06779 L
.25233 .06565 L
.2599 .05808 L
.26204 .05594 L
.26961 .04837 L
.27176 .04623 L
.27933 .03866 L
.28147 .03651 L
.28904 .02894 L
.29118 .02691 L
.29875 .01923 L
.01923 .01923 L
F
0 g
.01923 .29875 m
.02691 .29118 L
.02894 .28904 L
.03651 .28147 L
.03866 .27933 L
.04623 .27176 L
.04837 .26961 L
.05594 .26204 L
.05808 .2599 L
.06565 .25233 L
.06779 .25019 L
.07536 .24262 L
.07751 .24048 L
.08508 .23291 L
.08722 .23076 L
.09479 .22319 L
.09693 .22105 L
.1045 .21348 L
.10664 .21134 L
.11421 .20377 L
.11636 .20163 L
.12393 .19406 L
.12607 .19191 L
.13364 .18434 L
.13578 .1822 L
.14335 .17463 L
.14549 .17249 L
.15306 .16492 L
.15521 .16278 L
.16278 .15521 L
.16492 .15306 L
.17249 .14549 L
.17463 .14335 L
.1822 .13578 L
.18434 .13364 L
.19191 .12607 L
.19406 .12393 L
.20163 .11636 L
.20377 .11421 L
.21134 .10664 L
.21348 .1045 L
.22105 .09693 L
.22319 .09479 L
.23076 .08722 L
.23291 .08508 L
.24048 .07751 L
.24262 .07536 L
.25019 .06779 L
.25233 .06565 L
.2599 .05808 L
Mistroke
.26204 .05594 L
.26961 .04837 L
.27176 .04623 L
.27933 .03866 L
.28147 .03651 L
.28904 .02894 L
.29118 .02691 L
.29875 .01923 L
Mfstroke
.5 g
.01923 .25505 m
.02196 .25233 L
.02894 .24534 L
.03167 .24262 L
.03866 .23563 L
.04138 .23291 L
.04837 .22592 L
.05109 .22319 L
.05808 .2162 L
.0608 .21348 L
.06779 .20649 L
.07052 .20377 L
.07751 .19678 L
.08023 .19406 L
.08722 .18707 L
.08994 .18434 L
.09693 .17735 L
.09965 .17463 L
.10664 .16764 L
.10937 .16492 L
.11636 .15793 L
.11908 .15521 L
.12607 .14822 L
.12879 .14549 L
.13578 .1385 L
.1385 .13578 L
.14549 .12879 L
.14822 .12607 L
.15521 .11908 L
.15793 .11636 L
.16492 .10937 L
.16764 .10664 L
.17463 .09965 L
.17735 .09693 L
.18434 .08994 L
.18707 .08722 L
.19406 .08023 L
.19678 .07751 L
.20377 .07052 L
.20649 .06779 L
.21348 .0608 L
.2162 .05808 L
.22319 .05109 L
.22592 .04837 L
.23291 .04138 L
.23563 .03866 L
.24262 .03167 L
.24534 .02894 L
.25233 .02196 L
.25505 .01923 L
.01923 .01923 L
F
0 g
.01923 .25505 m
.02196 .25233 L
.02894 .24534 L
.03167 .24262 L
.03866 .23563 L
.04138 .23291 L
.04837 .22592 L
.05109 .22319 L
.05808 .2162 L
.0608 .21348 L
.06779 .20649 L
.07052 .20377 L
.07751 .19678 L
.08023 .19406 L
.08722 .18707 L
.08994 .18434 L
.09693 .17735 L
.09965 .17463 L
.10664 .16764 L
.10937 .16492 L
.11636 .15793 L
.11908 .15521 L
.12607 .14822 L
.12879 .14549 L
.13578 .1385 L
.1385 .13578 L
.14549 .12879 L
.14822 .12607 L
.15521 .11908 L
.15793 .11636 L
.16492 .10937 L
.16764 .10664 L
.17463 .09965 L
.17735 .09693 L
.18434 .08994 L
.18707 .08722 L
.19406 .08023 L
.19678 .07751 L
.20377 .07052 L
.20649 .06779 L
.21348 .0608 L
.2162 .05808 L
.22319 .05109 L
.22592 .04837 L
.23291 .04138 L
.23563 .03866 L
.24262 .03167 L
.24534 .02894 L
.25233 .02196 L
.25505 .01923 L
Mistroke
Mfstroke
.6 g
.01923 .21965 m
.02539 .21348 L
.02894 .20993 L
.03511 .20377 L
.03866 .20022 L
.04482 .19406 L
.04837 .19051 L
.05453 .18434 L
.05808 .1808 L
.06425 .17463 L
.06779 .17108 L
.07396 .16492 L
.07751 .16137 L
.08367 .15521 L
.08722 .15166 L
.09338 .14549 L
.09693 .14195 L
.1031 .13578 L
.10664 .13223 L
.11281 .12607 L
.11636 .12252 L
.12252 .11636 L
.12607 .11281 L
.13223 .10664 L
.13578 .1031 L
.14195 .09693 L
.14549 .09338 L
.15166 .08722 L
.15521 .08367 L
.16137 .07751 L
.16492 .07396 L
.17108 .06779 L
.17463 .06425 L
.1808 .05808 L
.18434 .05453 L
.19051 .04837 L
.19406 .04482 L
.20022 .03866 L
.20377 .03511 L
.20993 .02894 L
.21348 .02539 L
.21965 .01923 L
.01923 .01923 L
F
0 g
.01923 .21965 m
.02539 .21348 L
.02894 .20993 L
.03511 .20377 L
.03866 .20022 L
.04482 .19406 L
.04837 .19051 L
.05453 .18434 L
.05808 .1808 L
.06425 .17463 L
.06779 .17108 L
.07396 .16492 L
.07751 .16137 L
.08367 .15521 L
.08722 .15166 L
.09338 .14549 L
.09693 .14195 L
.1031 .13578 L
.10664 .13223 L
.11281 .12607 L
.11636 .12252 L
.12252 .11636 L
.12607 .11281 L
.13223 .10664 L
.13578 .1031 L
.14195 .09693 L
.14549 .09338 L
.15166 .08722 L
.15521 .08367 L
.16137 .07751 L
.16492 .07396 L
.17108 .06779 L
.17463 .06425 L
.1808 .05808 L
.18434 .05453 L
.19051 .04837 L
.19406 .04482 L
.20022 .03866 L
.20377 .03511 L
.20993 .02894 L
.21348 .02539 L
.21965 .01923 L
s
.7 g
.01923 .17594 m
.02051 .17463 L
.02894 .16623 L
.03025 .16492 L
.03866 .15651 L
.03996 .15521 L
.04837 .1468 L
.04968 .14549 L
.05808 .13709 L
.05939 .13578 L
.06779 .12738 L
.0691 .12607 L
.07751 .11766 L
.07881 .11636 L
.08722 .10795 L
.08853 .10664 L
.09693 .09824 L
.09824 .09693 L
.10664 .08853 L
.10795 .08722 L
.11636 .07881 L
.11766 .07751 L
.12607 .0691 L
.12738 .06779 L
.13578 .05939 L
.13709 .05808 L
.14549 .04968 L
.1468 .04837 L
.15521 .03996 L
.15651 .03866 L
.16492 .03025 L
.16623 .02894 L
.17463 .02051 L
.17594 .01923 L
.01923 .01923 L
F
0 g
.01923 .17594 m
.02051 .17463 L
.02894 .16623 L
.03025 .16492 L
.03866 .15651 L
.03996 .15521 L
.04837 .1468 L
.04968 .14549 L
.05808 .13709 L
.05939 .13578 L
.06779 .12738 L
.0691 .12607 L
.07751 .11766 L
.07881 .11636 L
.08722 .10795 L
.08853 .10664 L
.09693 .09824 L
.09824 .09693 L
.10664 .08853 L
.10795 .08722 L
.11636 .07881 L
.11766 .07751 L
.12607 .0691 L
.12738 .06779 L
.13578 .05939 L
.13709 .05808 L
.14549 .04968 L
.1468 .04837 L
.15521 .03996 L
.15651 .03866 L
.16492 .03025 L
.16623 .02894 L
.17463 .02051 L
.17594 .01923 L
s
.6 g
.01923 .09738 m
.01982 .09693 L
.02894 .08767 L
.02939 .08722 L
.03866 .07795 L
.0391 .07751 L
.04837 .06824 L
.04882 .06779 L
.05808 .05853 L
.05853 .05808 L
.06779 .04882 L
.06824 .04837 L
.07751 .0391 L
.07795 .03866 L
.08722 .02939 L
.08767 .02894 L
.09693 .01982 L
.09738 .01923 L
.01923 .01923 L
F
0 g
.01923 .09738 m
.01982 .09693 L
.02894 .08767 L
.02939 .08722 L
.03866 .07795 L
.0391 .07751 L
.04837 .06824 L
.04882 .06779 L
.05808 .05853 L
.05853 .05808 L
.06779 .04882 L
.06824 .04837 L
.07751 .0391 L
.07795 .03866 L
.08722 .02939 L
.08767 .02894 L
.09693 .01982 L
.09738 .01923 L
s
.5 g
.01923 .05367 m
.02454 .04837 L
.02894 .04396 L
.03425 .03866 L
.03866 .03425 L
.04396 .02894 L
.04837 .02454 L
.05367 .01923 L
.01923 .01923 L
F
0 g
.01923 .05367 m
.02454 .04837 L
.02894 .04396 L
.03425 .03866 L
.03866 .03425 L
.04396 .02894 L
.04837 .02454 L
.05367 .01923 L
s
.6 g
.01991 .98077 m
.02894 .97173 L
.02964 .97106 L
.03866 .96204 L
.03936 .96134 L
.04837 .95233 L
.04907 .95163 L
.05808 .94262 L
.05878 .94192 L
.06779 .93291 L
.06849 .93221 L
.07751 .92319 L
.07821 .92249 L
.08722 .91348 L
.08792 .91278 L
.09693 .90377 L
.09763 .90307 L
.10664 .89406 L
.10734 .89336 L
.11636 .88434 L
.11706 .88364 L
.12607 .87463 L
.12677 .87393 L
.13578 .86492 L
.13648 .86422 L
.14549 .85521 L
.14619 .85451 L
.15521 .84549 L
.15591 .84479 L
.16492 .83578 L
.16562 .83508 L
.17463 .82607 L
.17533 .82537 L
.18434 .81636 L
.18504 .81566 L
.19406 .80664 L
.19476 .80594 L
.20377 .79693 L
.20447 .79623 L
.21348 .78722 L
.21418 .78652 L
.22319 .77751 L
.22389 .77681 L
.23291 .76779 L
.23361 .76709 L
.24262 .75808 L
.24332 .75738 L
.25233 .74837 L
.25303 .74767 L
.26204 .73866 L
.26274 .73796 L
.27176 .72894 L
.27246 .72824 L
.28147 .71923 L
.28217 .71853 L
.29118 .70952 L
.29188 .70882 L
.30089 .69981 L
.30159 .69911 L
.31061 .69009 L
.31131 .68939 L
.32032 .68038 L
.32102 .67968 L
.33003 .67067 L
.33072 .66997 L
.33974 .66096 L
.34059 .66026 L
.34946 .65396 L
.3539 .65054 L
.35917 .64566 L
.36451 .64083 L
.36888 .63628 L
.37401 .63112 L
.37859 .62599 L
.3828 .62141 L
.38831 .61489 L
.39105 .61169 L
.39802 .60304 L
.39888 .60198 L
.40648 .59227 L
.40773 .59053 L
.41378 .58256 L
.41744 .57738 L
.42076 .57284 L
.42716 .56362 L
.4275 .56313 L
.43423 .55342 L
.43687 .54933 L
.44066 .54371 L
.44658 .53447 L
.44689 .53399 L
.45317 .52428 L
.45629 .51913 L
.45918 .51457 L
.4651 .50486 L
.46601 .50328 L
.47098 .49514 L
.47572 .48696 L
.47663 .48543 L
.48236 .47572 L
.48543 .47018 L
.48786 .46601 L
.49337 .45629 L
.49514 .45296 L
.49876 .44658 L
.50406 .43687 L
.50486 .43531 L
.50936 .42716 L
.51446 .41744 L
.51457 .41723 L
.5197 .40773 L
.52428 .39875 L
.52467 .39802 L
.5298 .38831 L
.53399 .37988 L
.53466 .37859 L
.53968 .36888 L
.54371 .36061 L
.54444 .35917 L
.54936 .34946 L
.55342 .34097 L
.55403 .33974 L
.55887 .33003 L
.56313 .32095 L
.56344 .32032 L
.5682 .31061 L
.5727 .30089 L
.57284 .30057 L
.57737 .29118 L
.58185 .28147 L
.58256 .27983 L
.58639 .27176 L
.59086 .26204 L
.59227 .25874 L
.59527 .25233 L
.59972 .24262 L
.60198 .23731 L
.60401 .23291 L
.60844 .22319 L
.61169 .21553 L
.61262 .21348 L
.61702 .20377 L
.62116 .19406 L
.62141 .19343 L
.62547 .18434 L
.62967 .17463 L
.63112 .171 L
.6338 .16492 L
.63802 .15521 L
.64083 .14824 L
.64202 .14549 L
.64624 .13578 L
.65021 .12607 L
.65054 .12516 L
.65432 .11636 L
.65839 .10664 L
.66026 .10178 L
.66231 .09693 L
.6664 .08722 L
.66997 .07808 L
.67021 .07751 L
.67427 .06779 L
.67821 .05808 L
.67968 .05408 L
.68204 .04837 L
.68603 .03866 L
.68939 .02977 L
.68973 .02894 L
.69371 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.01991 .98077 m
.02894 .97173 L
.02964 .97106 L
.03866 .96204 L
.03936 .96134 L
.04837 .95233 L
.04907 .95163 L
.05808 .94262 L
.05878 .94192 L
.06779 .93291 L
.06849 .93221 L
.07751 .92319 L
.07821 .92249 L
.08722 .91348 L
.08792 .91278 L
.09693 .90377 L
.09763 .90307 L
.10664 .89406 L
.10734 .89336 L
.11636 .88434 L
.11706 .88364 L
.12607 .87463 L
.12677 .87393 L
.13578 .86492 L
.13648 .86422 L
.14549 .85521 L
.14619 .85451 L
.15521 .84549 L
.15591 .84479 L
.16492 .83578 L
.16562 .83508 L
.17463 .82607 L
.17533 .82537 L
.18434 .81636 L
.18504 .81566 L
.19406 .80664 L
.19476 .80594 L
.20377 .79693 L
.20447 .79623 L
.21348 .78722 L
.21418 .78652 L
.22319 .77751 L
.22389 .77681 L
.23291 .76779 L
.23361 .76709 L
.24262 .75808 L
.24332 .75738 L
.25233 .74837 L
.25303 .74767 L
.26204 .73866 L
Mistroke
.26274 .73796 L
.27176 .72894 L
.27246 .72824 L
.28147 .71923 L
.28217 .71853 L
.29118 .70952 L
.29188 .70882 L
.30089 .69981 L
.30159 .69911 L
.31061 .69009 L
.31131 .68939 L
.32032 .68038 L
.32102 .67968 L
.33003 .67067 L
.33072 .66997 L
.33974 .66096 L
.34059 .66026 L
.34946 .65396 L
.3539 .65054 L
.35917 .64566 L
.36451 .64083 L
.36888 .63628 L
.37401 .63112 L
.37859 .62599 L
.3828 .62141 L
.38831 .61489 L
.39105 .61169 L
.39802 .60304 L
.39888 .60198 L
.40648 .59227 L
.40773 .59053 L
.41378 .58256 L
.41744 .57738 L
.42076 .57284 L
.42716 .56362 L
.4275 .56313 L
.43423 .55342 L
.43687 .54933 L
.44066 .54371 L
.44658 .53447 L
.44689 .53399 L
.45317 .52428 L
.45629 .51913 L
.45918 .51457 L
.4651 .50486 L
.46601 .50328 L
.47098 .49514 L
.47572 .48696 L
.47663 .48543 L
.48236 .47572 L
Mistroke
.48543 .47018 L
.48786 .46601 L
.49337 .45629 L
.49514 .45296 L
.49876 .44658 L
.50406 .43687 L
.50486 .43531 L
.50936 .42716 L
.51446 .41744 L
.51457 .41723 L
.5197 .40773 L
.52428 .39875 L
.52467 .39802 L
.5298 .38831 L
.53399 .37988 L
.53466 .37859 L
.53968 .36888 L
.54371 .36061 L
.54444 .35917 L
.54936 .34946 L
.55342 .34097 L
.55403 .33974 L
.55887 .33003 L
.56313 .32095 L
.56344 .32032 L
.5682 .31061 L
.5727 .30089 L
.57284 .30057 L
.57737 .29118 L
.58185 .28147 L
.58256 .27983 L
.58639 .27176 L
.59086 .26204 L
.59227 .25874 L
.59527 .25233 L
.59972 .24262 L
.60198 .23731 L
.60401 .23291 L
.60844 .22319 L
.61169 .21553 L
.61262 .21348 L
.61702 .20377 L
.62116 .19406 L
.62141 .19343 L
.62547 .18434 L
.62967 .17463 L
.63112 .171 L
.6338 .16492 L
.63802 .15521 L
.64083 .14824 L
Mistroke
.64202 .14549 L
.64624 .13578 L
.65021 .12607 L
.65054 .12516 L
.65432 .11636 L
.65839 .10664 L
.66026 .10178 L
.66231 .09693 L
.6664 .08722 L
.66997 .07808 L
.67021 .07751 L
.67427 .06779 L
.67821 .05808 L
.67968 .05408 L
.68204 .04837 L
.68603 .03866 L
.68939 .02977 L
.68973 .02894 L
.69371 .01923 L
Mfstroke
.5 g
.06364 .98077 m
.06779 .97661 L
.07336 .97106 L
.07751 .96691 L
.08307 .96134 L
.08722 .95719 L
.09278 .95163 L
.09693 .94748 L
.10249 .94192 L
.10664 .93777 L
.11221 .93221 L
.11636 .92806 L
.12192 .92249 L
.12607 .91834 L
.13163 .91278 L
.13578 .90863 L
.14134 .90307 L
.14549 .89892 L
.15106 .89336 L
.15521 .88921 L
.16077 .88364 L
.16492 .87949 L
.17048 .87393 L
.17463 .86978 L
.18019 .86422 L
.18434 .86007 L
.18991 .85451 L
.19406 .85036 L
.19962 .84479 L
.20377 .84064 L
.20933 .83508 L
.21348 .83093 L
.21904 .82537 L
.22319 .82122 L
.22876 .81566 L
.23291 .81151 L
.23847 .80594 L
.24262 .80179 L
.24818 .79623 L
.25233 .79208 L
.25789 .78652 L
.26204 .78237 L
.26761 .77681 L
.27176 .77266 L
.27732 .76709 L
.28147 .76294 L
.28703 .75738 L
.29118 .75323 L
.29674 .74767 L
.30089 .74352 L
.30646 .73796 L
.31061 .73381 L
.31617 .72824 L
.32032 .72409 L
.32588 .71853 L
.33003 .71438 L
.33561 .70882 L
.33974 .70467 L
.34544 .69911 L
.34946 .69523 L
.35511 .68939 L
.35917 .685 L
.36399 .67968 L
.36888 .67405 L
.37238 .66997 L
.37859 .66244 L
.38037 .66026 L
.38804 .65054 L
.38831 .6502 L
.39546 .64083 L
.39802 .63737 L
.40262 .63112 L
.40773 .62398 L
.40956 .62141 L
.41632 .61169 L
.41744 .61005 L
.42292 .60198 L
.42716 .5956 L
.42936 .59227 L
.43566 .58256 L
.43687 .58065 L
.44184 .57284 L
.44658 .56523 L
.44788 .56313 L
.45384 .55342 L
.45629 .54934 L
.45968 .54371 L
.46542 .53399 L
.46601 .53299 L
.4711 .52428 L
.47572 .51621 L
.47666 .51457 L
.48217 .50486 L
.48543 .499 L
.48759 .49514 L
.49295 .48543 L
.49514 .48138 L
.49823 .47572 L
.50345 .46601 L
.50486 .46335 L
.50862 .45629 L
.51371 .44658 L
.51457 .44493 L
.51877 .43687 L
.52375 .42716 L
.52428 .42611 L
.52871 .41744 L
.53359 .40773 L
.53399 .40692 L
.53845 .39802 L
.54324 .38831 L
.54371 .38736 L
.54802 .37859 L
.55272 .36888 L
.55342 .36743 L
.55741 .35917 L
.56204 .34946 L
.56313 .34714 L
.56665 .33974 L
.57121 .33003 L
.57284 .3265 L
.57573 .32032 L
.58023 .31061 L
.58256 .30551 L
.58468 .30089 L
.58912 .29118 L
.59227 .28418 L
.5935 .28147 L
.59789 .27176 L
.60198 .26252 L
.6022 .26204 L
.60652 .25233 L
.61079 .24262 L
.61169 .24053 L
.61505 .23291 L
.61928 .22319 L
.62141 .21822 L
.62346 .21348 L
.62765 .20377 L
.63112 .19558 L
.63177 .19406 L
.63592 .18434 L
.64001 .17463 L
.64083 .17264 L
.64408 .16492 L
.64815 .15521 L
.65054 .14937 L
.65216 .14549 L
.65619 .13578 L
.66015 .12607 L
.66026 .12581 L
.66414 .11636 L
.66809 .10664 L
.66997 .10194 L
.672 .09693 L
.67593 .08722 L
.67968 .07777 L
.67979 .07751 L
.68368 .06779 L
.68754 .05808 L
.68939 .05331 L
.69135 .04837 L
.69519 .03866 L
.69896 .02894 L
.69911 .02855 L
.70276 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.06364 .98077 m
.06779 .97661 L
.07336 .97106 L
.07751 .96691 L
.08307 .96134 L
.08722 .95719 L
.09278 .95163 L
.09693 .94748 L
.10249 .94192 L
.10664 .93777 L
.11221 .93221 L
.11636 .92806 L
.12192 .92249 L
.12607 .91834 L
.13163 .91278 L
.13578 .90863 L
.14134 .90307 L
.14549 .89892 L
.15106 .89336 L
.15521 .88921 L
.16077 .88364 L
.16492 .87949 L
.17048 .87393 L
.17463 .86978 L
.18019 .86422 L
.18434 .86007 L
.18991 .85451 L
.19406 .85036 L
.19962 .84479 L
.20377 .84064 L
.20933 .83508 L
.21348 .83093 L
.21904 .82537 L
.22319 .82122 L
.22876 .81566 L
.23291 .81151 L
.23847 .80594 L
.24262 .80179 L
.24818 .79623 L
.25233 .79208 L
.25789 .78652 L
.26204 .78237 L
.26761 .77681 L
.27176 .77266 L
.27732 .76709 L
.28147 .76294 L
.28703 .75738 L
.29118 .75323 L
.29674 .74767 L
.30089 .74352 L
Mistroke
.30646 .73796 L
.31061 .73381 L
.31617 .72824 L
.32032 .72409 L
.32588 .71853 L
.33003 .71438 L
.33561 .70882 L
.33974 .70467 L
.34544 .69911 L
.34946 .69523 L
.35511 .68939 L
.35917 .685 L
.36399 .67968 L
.36888 .67405 L
.37238 .66997 L
.37859 .66244 L
.38037 .66026 L
.38804 .65054 L
.38831 .6502 L
.39546 .64083 L
.39802 .63737 L
.40262 .63112 L
.40773 .62398 L
.40956 .62141 L
.41632 .61169 L
.41744 .61005 L
.42292 .60198 L
.42716 .5956 L
.42936 .59227 L
.43566 .58256 L
.43687 .58065 L
.44184 .57284 L
.44658 .56523 L
.44788 .56313 L
.45384 .55342 L
.45629 .54934 L
.45968 .54371 L
.46542 .53399 L
.46601 .53299 L
.4711 .52428 L
.47572 .51621 L
.47666 .51457 L
.48217 .50486 L
.48543 .499 L
.48759 .49514 L
.49295 .48543 L
.49514 .48138 L
.49823 .47572 L
.50345 .46601 L
.50486 .46335 L
Mistroke
.50862 .45629 L
.51371 .44658 L
.51457 .44493 L
.51877 .43687 L
.52375 .42716 L
.52428 .42611 L
.52871 .41744 L
.53359 .40773 L
.53399 .40692 L
.53845 .39802 L
.54324 .38831 L
.54371 .38736 L
.54802 .37859 L
.55272 .36888 L
.55342 .36743 L
.55741 .35917 L
.56204 .34946 L
.56313 .34714 L
.56665 .33974 L
.57121 .33003 L
.57284 .3265 L
.57573 .32032 L
.58023 .31061 L
.58256 .30551 L
.58468 .30089 L
.58912 .29118 L
.59227 .28418 L
.5935 .28147 L
.59789 .27176 L
.60198 .26252 L
.6022 .26204 L
.60652 .25233 L
.61079 .24262 L
.61169 .24053 L
.61505 .23291 L
.61928 .22319 L
.62141 .21822 L
.62346 .21348 L
.62765 .20377 L
.63112 .19558 L
.63177 .19406 L
.63592 .18434 L
.64001 .17463 L
.64083 .17264 L
.64408 .16492 L
.64815 .15521 L
.65054 .14937 L
.65216 .14549 L
.65619 .13578 L
.66015 .12607 L
Mistroke
.66026 .12581 L
.66414 .11636 L
.66809 .10664 L
.66997 .10194 L
.672 .09693 L
.67593 .08722 L
.67968 .07777 L
.67979 .07751 L
.68368 .06779 L
.68754 .05808 L
.68939 .05331 L
.69135 .04837 L
.69519 .03866 L
.69896 .02894 L
.69911 .02855 L
.70276 .01923 L
Mfstroke
.4 g
.09905 .98077 m
.10664 .97318 L
.10877 .97106 L
.11636 .96347 L
.11848 .96134 L
.12607 .95375 L
.12819 .95163 L
.13578 .94404 L
.1379 .94192 L
.14549 .93433 L
.14762 .93221 L
.15521 .92462 L
.15733 .92249 L
.16492 .9149 L
.16704 .91278 L
.17463 .90519 L
.17675 .90307 L
.18434 .89548 L
.18647 .89336 L
.19406 .88577 L
.19618 .88364 L
.20377 .87605 L
.20589 .87393 L
.21348 .86634 L
.2156 .86422 L
.22319 .85663 L
.22532 .85451 L
.23291 .84692 L
.23503 .84479 L
.24262 .8372 L
.24474 .83508 L
.25233 .82749 L
.25445 .82537 L
.26204 .81778 L
.26417 .81566 L
.27176 .80807 L
.27388 .80594 L
.28147 .79835 L
.28359 .79623 L
.29118 .78864 L
.2933 .78652 L
.30089 .77893 L
.30302 .77681 L
.31061 .76922 L
.31273 .76709 L
.32032 .7595 L
.32244 .75738 L
.33003 .74979 L
.33221 .74767 L
.33974 .74008 L
.34171 .73796 L
.34946 .72938 L
.35046 .72824 L
.3588 .71853 L
.35917 .71809 L
.3668 .70882 L
.36888 .70623 L
.37451 .69911 L
.37859 .69381 L
.38195 .68939 L
.38831 .68086 L
.38917 .67968 L
.39619 .66997 L
.39802 .66739 L
.40302 .66026 L
.40773 .65342 L
.40969 .65054 L
.41621 .64083 L
.41744 .63896 L
.42258 .63112 L
.42716 .62403 L
.42883 .62141 L
.43496 .61169 L
.43687 .60864 L
.44098 .60198 L
.44658 .5928 L
.4469 .59227 L
.45272 .58256 L
.45629 .57652 L
.45845 .57284 L
.4641 .56313 L
.46601 .55982 L
.46966 .55342 L
.47516 .54371 L
.47572 .5427 L
.48057 .53399 L
.48543 .52518 L
.48592 .52428 L
.4912 .51457 L
.49514 .50726 L
.49643 .50486 L
.50159 .49514 L
.50486 .48895 L
.50669 .48543 L
.51175 .47572 L
.51457 .47025 L
.51674 .46601 L
.5217 .45629 L
.52428 .45119 L
.52659 .44658 L
.53145 .43687 L
.53399 .43175 L
.53626 .42716 L
.54103 .41744 L
.54371 .41195 L
.54575 .40773 L
.55044 .39802 L
.55342 .3918 L
.55508 .38831 L
.55969 .37859 L
.56313 .3713 L
.56426 .36888 L
.5688 .35917 L
.57284 .35046 L
.57331 .34946 L
.57777 .33974 L
.58222 .33003 L
.58256 .32928 L
.58661 .32032 L
.591 .31061 L
.59227 .30777 L
.59533 .30089 L
.59966 .29118 L
.60198 .28593 L
.60393 .28147 L
.6082 .27176 L
.61169 .26377 L
.61244 .26204 L
.61664 .25233 L
.62083 .24262 L
.62141 .24129 L
.62498 .23291 L
.62912 .22319 L
.63112 .21849 L
.63322 .21348 L
.63731 .20377 L
.64083 .19538 L
.64138 .19406 L
.64541 .18434 L
.64945 .17463 L
.65054 .17197 L
.65343 .16492 L
.65742 .15521 L
.66026 .14826 L
.66137 .14549 L
.6653 .13578 L
.66924 .12607 L
.66997 .12425 L
.67311 .11636 L
.67701 .10664 L
.67968 .09994 L
.68086 .09693 L
.6847 .08722 L
.68855 .07751 L
.68939 .07535 L
.69233 .06779 L
.69614 .05808 L
.69911 .05046 L
.69991 .04837 L
.70366 .03866 L
.70742 .02894 L
.70882 .0253 L
.71112 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.09905 .98077 m
.10664 .97318 L
.10877 .97106 L
.11636 .96347 L
.11848 .96134 L
.12607 .95375 L
.12819 .95163 L
.13578 .94404 L
.1379 .94192 L
.14549 .93433 L
.14762 .93221 L
.15521 .92462 L
.15733 .92249 L
.16492 .9149 L
.16704 .91278 L
.17463 .90519 L
.17675 .90307 L
.18434 .89548 L
.18647 .89336 L
.19406 .88577 L
.19618 .88364 L
.20377 .87605 L
.20589 .87393 L
.21348 .86634 L
.2156 .86422 L
.22319 .85663 L
.22532 .85451 L
.23291 .84692 L
.23503 .84479 L
.24262 .8372 L
.24474 .83508 L
.25233 .82749 L
.25445 .82537 L
.26204 .81778 L
.26417 .81566 L
.27176 .80807 L
.27388 .80594 L
.28147 .79835 L
.28359 .79623 L
.29118 .78864 L
.2933 .78652 L
.30089 .77893 L
.30302 .77681 L
.31061 .76922 L
.31273 .76709 L
.32032 .7595 L
.32244 .75738 L
.33003 .74979 L
.33221 .74767 L
.33974 .74008 L
Mistroke
.34171 .73796 L
.34946 .72938 L
.35046 .72824 L
.3588 .71853 L
.35917 .71809 L
.3668 .70882 L
.36888 .70623 L
.37451 .69911 L
.37859 .69381 L
.38195 .68939 L
.38831 .68086 L
.38917 .67968 L
.39619 .66997 L
.39802 .66739 L
.40302 .66026 L
.40773 .65342 L
.40969 .65054 L
.41621 .64083 L
.41744 .63896 L
.42258 .63112 L
.42716 .62403 L
.42883 .62141 L
.43496 .61169 L
.43687 .60864 L
.44098 .60198 L
.44658 .5928 L
.4469 .59227 L
.45272 .58256 L
.45629 .57652 L
.45845 .57284 L
.4641 .56313 L
.46601 .55982 L
.46966 .55342 L
.47516 .54371 L
.47572 .5427 L
.48057 .53399 L
.48543 .52518 L
.48592 .52428 L
.4912 .51457 L
.49514 .50726 L
.49643 .50486 L
.50159 .49514 L
.50486 .48895 L
.50669 .48543 L
.51175 .47572 L
.51457 .47025 L
.51674 .46601 L
.5217 .45629 L
.52428 .45119 L
.52659 .44658 L
Mistroke
.53145 .43687 L
.53399 .43175 L
.53626 .42716 L
.54103 .41744 L
.54371 .41195 L
.54575 .40773 L
.55044 .39802 L
.55342 .3918 L
.55508 .38831 L
.55969 .37859 L
.56313 .3713 L
.56426 .36888 L
.5688 .35917 L
.57284 .35046 L
.57331 .34946 L
.57777 .33974 L
.58222 .33003 L
.58256 .32928 L
.58661 .32032 L
.591 .31061 L
.59227 .30777 L
.59533 .30089 L
.59966 .29118 L
.60198 .28593 L
.60393 .28147 L
.6082 .27176 L
.61169 .26377 L
.61244 .26204 L
.61664 .25233 L
.62083 .24262 L
.62141 .24129 L
.62498 .23291 L
.62912 .22319 L
.63112 .21849 L
.63322 .21348 L
.63731 .20377 L
.64083 .19538 L
.64138 .19406 L
.64541 .18434 L
.64945 .17463 L
.65054 .17197 L
.65343 .16492 L
.65742 .15521 L
.66026 .14826 L
.66137 .14549 L
.6653 .13578 L
.66924 .12607 L
.66997 .12425 L
.67311 .11636 L
.67701 .10664 L
Mistroke
.67968 .09994 L
.68086 .09693 L
.6847 .08722 L
.68855 .07751 L
.68939 .07535 L
.69233 .06779 L
.69614 .05808 L
.69911 .05046 L
.69991 .04837 L
.70366 .03866 L
.70742 .02894 L
.70882 .0253 L
.71112 .01923 L
Mfstroke
.3 g
.14274 .98077 m
.14549 .97808 L
.15246 .97106 L
.15521 .96831 L
.16217 .96134 L
.16492 .95859 L
.17188 .95163 L
.17463 .94888 L
.18159 .94192 L
.18434 .93917 L
.19131 .93221 L
.19406 .92946 L
.20102 .92249 L
.20377 .91974 L
.21073 .91278 L
.21348 .91003 L
.22044 .90307 L
.22319 .90032 L
.23016 .89336 L
.23291 .89061 L
.23987 .88364 L
.24262 .88089 L
.24958 .87393 L
.25233 .87118 L
.25929 .86422 L
.26204 .86147 L
.26901 .85451 L
.27176 .85176 L
.27872 .84479 L
.28147 .84204 L
.28843 .83508 L
.29118 .83233 L
.29814 .82537 L
.30089 .82262 L
.30786 .81566 L
.31061 .81291 L
.31757 .80594 L
.32032 .80319 L
.32728 .79623 L
.33003 .79348 L
.33724 .78652 L
.33974 .78377 L
.34502 .77681 L
.34946 .77063 L
.35208 .76709 L
.35917 .75746 L
.35922 .75738 L
.36625 .74767 L
.36888 .744 L
.37317 .73796 L
.37859 .73026 L
.38 .72824 L
.3867 .71853 L
.38831 .71618 L
.39326 .70882 L
.39802 .70172 L
.39973 .69911 L
.4061 .68939 L
.40773 .68688 L
.41232 .67968 L
.41744 .67163 L
.41848 .66997 L
.42452 .66026 L
.42716 .656 L
.43045 .65054 L
.43635 .64083 L
.43687 .63997 L
.4421 .63112 L
.44658 .62354 L
.4478 .62141 L
.45343 .61169 L
.45629 .60673 L
.45895 .60198 L
.46446 .59227 L
.46601 .58953 L
.46984 .58256 L
.47523 .57284 L
.47572 .57196 L
.48047 .56313 L
.48543 .55401 L
.48574 .55342 L
.49087 .54371 L
.49514 .53568 L
.496 .53399 L
.50105 .52428 L
.50486 .51699 L
.50606 .51457 L
.51102 .50486 L
.51457 .49794 L
.51594 .49514 L
.52081 .48543 L
.52428 .47854 L
.52563 .47572 L
.53042 .46601 L
.53399 .45879 L
.53516 .45629 L
.53986 .44658 L
.54371 .43869 L
.54454 .43687 L
.54915 .42716 L
.55342 .41826 L
.55379 .41744 L
.55829 .40773 L
.56288 .39802 L
.56313 .39749 L
.56729 .38831 L
.57182 .37859 L
.57284 .37639 L
.57617 .36888 L
.58063 .35917 L
.58256 .35496 L
.58494 .34946 L
.58932 .33974 L
.59227 .33321 L
.59361 .33003 L
.59789 .32032 L
.60198 .31115 L
.6022 .31061 L
.60635 .30089 L
.61064 .29118 L
.61169 .28877 L
.61472 .28147 L
.61894 .27176 L
.62141 .26607 L
.62303 .26204 L
.62715 .25233 L
.63112 .24308 L
.6313 .24262 L
.63527 .23291 L
.63939 .22319 L
.64083 .21978 L
.64332 .21348 L
.64737 .20377 L
.65054 .19618 L
.65135 .19406 L
.65526 .18434 L
.65929 .17463 L
.66026 .17229 L
.6631 .16492 L
.66707 .15521 L
.66997 .14811 L
.67093 .14549 L
.67476 .13578 L
.6787 .12607 L
.67968 .12364 L
.68241 .11636 L
.68629 .10664 L
.68939 .09888 L
.69008 .09693 L
.6938 .08722 L
.69766 .07751 L
.69911 .07383 L
.70129 .06779 L
.70507 .05808 L
.70882 .04852 L
.70887 .04837 L
.71242 .03866 L
.7162 .02894 L
.71853 .02295 L
.7198 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.14274 .98077 m
.14549 .97808 L
.15246 .97106 L
.15521 .96831 L
.16217 .96134 L
.16492 .95859 L
.17188 .95163 L
.17463 .94888 L
.18159 .94192 L
.18434 .93917 L
.19131 .93221 L
.19406 .92946 L
.20102 .92249 L
.20377 .91974 L
.21073 .91278 L
.21348 .91003 L
.22044 .90307 L
.22319 .90032 L
.23016 .89336 L
.23291 .89061 L
.23987 .88364 L
.24262 .88089 L
.24958 .87393 L
.25233 .87118 L
.25929 .86422 L
.26204 .86147 L
.26901 .85451 L
.27176 .85176 L
.27872 .84479 L
.28147 .84204 L
.28843 .83508 L
.29118 .83233 L
.29814 .82537 L
.30089 .82262 L
.30786 .81566 L
.31061 .81291 L
.31757 .80594 L
.32032 .80319 L
.32728 .79623 L
.33003 .79348 L
.33724 .78652 L
.33974 .78377 L
.34502 .77681 L
.34946 .77063 L
.35208 .76709 L
.35917 .75746 L
.35922 .75738 L
.36625 .74767 L
.36888 .744 L
.37317 .73796 L
Mistroke
.37859 .73026 L
.38 .72824 L
.3867 .71853 L
.38831 .71618 L
.39326 .70882 L
.39802 .70172 L
.39973 .69911 L
.4061 .68939 L
.40773 .68688 L
.41232 .67968 L
.41744 .67163 L
.41848 .66997 L
.42452 .66026 L
.42716 .656 L
.43045 .65054 L
.43635 .64083 L
.43687 .63997 L
.4421 .63112 L
.44658 .62354 L
.4478 .62141 L
.45343 .61169 L
.45629 .60673 L
.45895 .60198 L
.46446 .59227 L
.46601 .58953 L
.46984 .58256 L
.47523 .57284 L
.47572 .57196 L
.48047 .56313 L
.48543 .55401 L
.48574 .55342 L
.49087 .54371 L
.49514 .53568 L
.496 .53399 L
.50105 .52428 L
.50486 .51699 L
.50606 .51457 L
.51102 .50486 L
.51457 .49794 L
.51594 .49514 L
.52081 .48543 L
.52428 .47854 L
.52563 .47572 L
.53042 .46601 L
.53399 .45879 L
.53516 .45629 L
.53986 .44658 L
.54371 .43869 L
.54454 .43687 L
.54915 .42716 L
Mistroke
.55342 .41826 L
.55379 .41744 L
.55829 .40773 L
.56288 .39802 L
.56313 .39749 L
.56729 .38831 L
.57182 .37859 L
.57284 .37639 L
.57617 .36888 L
.58063 .35917 L
.58256 .35496 L
.58494 .34946 L
.58932 .33974 L
.59227 .33321 L
.59361 .33003 L
.59789 .32032 L
.60198 .31115 L
.6022 .31061 L
.60635 .30089 L
.61064 .29118 L
.61169 .28877 L
.61472 .28147 L
.61894 .27176 L
.62141 .26607 L
.62303 .26204 L
.62715 .25233 L
.63112 .24308 L
.6313 .24262 L
.63527 .23291 L
.63939 .22319 L
.64083 .21978 L
.64332 .21348 L
.64737 .20377 L
.65054 .19618 L
.65135 .19406 L
.65526 .18434 L
.65929 .17463 L
.66026 .17229 L
.6631 .16492 L
.66707 .15521 L
.66997 .14811 L
.67093 .14549 L
.67476 .13578 L
.6787 .12607 L
.67968 .12364 L
.68241 .11636 L
.68629 .10664 L
.68939 .09888 L
.69008 .09693 L
.6938 .08722 L
Mistroke
.69766 .07751 L
.69911 .07383 L
.70129 .06779 L
.70507 .05808 L
.70882 .04852 L
.70887 .04837 L
.71242 .03866 L
.7162 .02894 L
.71853 .02295 L
.7198 .01923 L
Mfstroke
.4 g
.22135 .98077 m
.22319 .97856 L
.23106 .97106 L
.23291 .96921 L
.24077 .96134 L
.24262 .9595 L
.25048 .95163 L
.25233 .94978 L
.2602 .94192 L
.26204 .94007 L
.26991 .93221 L
.27176 .93036 L
.27962 .92249 L
.28147 .92065 L
.28933 .91278 L
.29118 .91093 L
.29905 .90307 L
.30089 .90122 L
.30876 .89336 L
.31061 .89151 L
.31847 .88364 L
.32032 .8818 L
.32818 .87393 L
.33003 .87208 L
.33779 .86422 L
.33974 .86237 L
.34946 .85533 L
.35055 .85451 L
.35917 .84703 L
.36169 .84479 L
.36888 .83766 L
.37148 .83508 L
.37859 .82737 L
.38044 .82537 L
.38831 .81626 L
.38883 .81566 L
.39688 .80594 L
.39802 .80443 L
.40455 .79623 L
.40773 .79191 L
.41186 .78652 L
.41744 .77876 L
.41887 .77681 L
.42578 .76709 L
.42716 .76502 L
.43248 .75738 L
.43687 .75071 L
.43893 .74767 L
.4453 .73796 L
.44658 .73587 L
.45154 .72824 L
.45629 .72051 L
.45754 .71853 L
.46358 .70882 L
.46601 .70467 L
.46941 .69911 L
.47514 .68939 L
.47572 .68834 L
.48087 .67968 L
.48543 .67156 L
.48636 .66997 L
.49194 .66026 L
.49514 .65435 L
.4973 .65054 L
.5027 .64083 L
.50486 .63669 L
.50794 .63112 L
.51317 .62141 L
.51457 .61862 L
.51832 .61169 L
.52338 .60198 L
.52428 .60014 L
.52845 .59227 L
.53338 .58256 L
.53399 .58126 L
.53836 .57284 L
.54318 .56313 L
.54371 .562 L
.54807 .55342 L
.5528 .54371 L
.55342 .54235 L
.55759 .53399 L
.56226 .52428 L
.56313 .52234 L
.56694 .51457 L
.57156 .50486 L
.57284 .50196 L
.57613 .49514 L
.58071 .48543 L
.58256 .48122 L
.58517 .47572 L
.58971 .46601 L
.59227 .46013 L
.59406 .45629 L
.59856 .44658 L
.60198 .43869 L
.60282 .43687 L
.60728 .42716 L
.61148 .41744 L
.61169 .41692 L
.61586 .40773 L
.62011 .39802 L
.62141 .39481 L
.62431 .38831 L
.62859 .37859 L
.63112 .37238 L
.63266 .36888 L
.63692 .35917 L
.64083 .34962 L
.6409 .34946 L
.64513 .33974 L
.6492 .33003 L
.65054 .32655 L
.65322 .32032 L
.65734 .31061 L
.66026 .30316 L
.66121 .30089 L
.66533 .29118 L
.66924 .28147 L
.66997 .27946 L
.6732 .27176 L
.6772 .26204 L
.67968 .25546 L
.68097 .25233 L
.68499 .24262 L
.68878 .23291 L
.68939 .23116 L
.69265 .22319 L
.69656 .21348 L
.69911 .20656 L
.70023 .20377 L
.70416 .19406 L
.7079 .18434 L
.70882 .18167 L
.71163 .17463 L
.71548 .16492 L
.71853 .15649 L
.71904 .15521 L
.72288 .14549 L
.72661 .13578 L
.72824 .13103 L
.73018 .12607 L
.73397 .11636 L
.73751 .10664 L
.73796 .10528 L
.74119 .09693 L
.74491 .08722 L
.74767 .07925 L
.74833 .07751 L
.75206 .06779 L
.75568 .05808 L
.75738 .05294 L
.75911 .04837 L
.7628 .03866 L
.76628 .02894 L
.76709 .02636 L
.76978 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.22135 .98077 m
.22319 .97856 L
.23106 .97106 L
.23291 .96921 L
.24077 .96134 L
.24262 .9595 L
.25048 .95163 L
.25233 .94978 L
.2602 .94192 L
.26204 .94007 L
.26991 .93221 L
.27176 .93036 L
.27962 .92249 L
.28147 .92065 L
.28933 .91278 L
.29118 .91093 L
.29905 .90307 L
.30089 .90122 L
.30876 .89336 L
.31061 .89151 L
.31847 .88364 L
.32032 .8818 L
.32818 .87393 L
.33003 .87208 L
.33779 .86422 L
.33974 .86237 L
.34946 .85533 L
.35055 .85451 L
.35917 .84703 L
.36169 .84479 L
.36888 .83766 L
.37148 .83508 L
.37859 .82737 L
.38044 .82537 L
.38831 .81626 L
.38883 .81566 L
.39688 .80594 L
.39802 .80443 L
.40455 .79623 L
.40773 .79191 L
.41186 .78652 L
.41744 .77876 L
.41887 .77681 L
.42578 .76709 L
.42716 .76502 L
.43248 .75738 L
.43687 .75071 L
.43893 .74767 L
.4453 .73796 L
.44658 .73587 L
Mistroke
.45154 .72824 L
.45629 .72051 L
.45754 .71853 L
.46358 .70882 L
.46601 .70467 L
.46941 .69911 L
.47514 .68939 L
.47572 .68834 L
.48087 .67968 L
.48543 .67156 L
.48636 .66997 L
.49194 .66026 L
.49514 .65435 L
.4973 .65054 L
.5027 .64083 L
.50486 .63669 L
.50794 .63112 L
.51317 .62141 L
.51457 .61862 L
.51832 .61169 L
.52338 .60198 L
.52428 .60014 L
.52845 .59227 L
.53338 .58256 L
.53399 .58126 L
.53836 .57284 L
.54318 .56313 L
.54371 .562 L
.54807 .55342 L
.5528 .54371 L
.55342 .54235 L
.55759 .53399 L
.56226 .52428 L
.56313 .52234 L
.56694 .51457 L
.57156 .50486 L
.57284 .50196 L
.57613 .49514 L
.58071 .48543 L
.58256 .48122 L
.58517 .47572 L
.58971 .46601 L
.59227 .46013 L
.59406 .45629 L
.59856 .44658 L
.60198 .43869 L
.60282 .43687 L
.60728 .42716 L
.61148 .41744 L
.61169 .41692 L
Mistroke
.61586 .40773 L
.62011 .39802 L
.62141 .39481 L
.62431 .38831 L
.62859 .37859 L
.63112 .37238 L
.63266 .36888 L
.63692 .35917 L
.64083 .34962 L
.6409 .34946 L
.64513 .33974 L
.6492 .33003 L
.65054 .32655 L
.65322 .32032 L
.65734 .31061 L
.66026 .30316 L
.66121 .30089 L
.66533 .29118 L
.66924 .28147 L
.66997 .27946 L
.6732 .27176 L
.6772 .26204 L
.67968 .25546 L
.68097 .25233 L
.68499 .24262 L
.68878 .23291 L
.68939 .23116 L
.69265 .22319 L
.69656 .21348 L
.69911 .20656 L
.70023 .20377 L
.70416 .19406 L
.7079 .18434 L
.70882 .18167 L
.71163 .17463 L
.71548 .16492 L
.71853 .15649 L
.71904 .15521 L
.72288 .14549 L
.72661 .13578 L
.72824 .13103 L
.73018 .12607 L
.73397 .11636 L
.73751 .10664 L
.73796 .10528 L
.74119 .09693 L
.74491 .08722 L
.74767 .07925 L
.74833 .07751 L
.75206 .06779 L
Mistroke
.75568 .05808 L
.75738 .05294 L
.75911 .04837 L
.7628 .03866 L
.76628 .02894 L
.76709 .02636 L
.76978 .01923 L
Mfstroke
.5 g
.26503 .98077 m
.27176 .97403 L
.27474 .97106 L
.28147 .96433 L
.28445 .96134 L
.29118 .95462 L
.29416 .95163 L
.30089 .9449 L
.30388 .94192 L
.31061 .93519 L
.31359 .93221 L
.32032 .92548 L
.3233 .92249 L
.33003 .91577 L
.33303 .91278 L
.33974 .90605 L
.34278 .90307 L
.34946 .89661 L
.35265 .89336 L
.35917 .88638 L
.36167 .88364 L
.36888 .87544 L
.37018 .87393 L
.37828 .86422 L
.37859 .86383 L
.38605 .85451 L
.38831 .85159 L
.39352 .84479 L
.39802 .83876 L
.40074 .83508 L
.40773 .82537 L
.40773 .82536 L
.41455 .81566 L
.41744 .81143 L
.42119 .80594 L
.42716 .79698 L
.42765 .79623 L
.434 .78652 L
.43687 .78204 L
.44021 .77681 L
.44628 .76709 L
.44658 .76661 L
.45227 .75738 L
.45629 .75072 L
.45813 .74767 L
.46391 .73796 L
.46601 .73438 L
.4696 .72824 L
.47519 .71853 L
.47572 .7176 L
.48072 .70882 L
.48543 .70039 L
.48615 .69911 L
.49154 .68939 L
.49514 .68277 L
.49683 .67968 L
.50208 .66997 L
.50486 .66474 L
.50725 .66026 L
.51237 .65054 L
.51457 .64631 L
.51743 .64083 L
.52244 .63112 L
.52428 .6275 L
.5274 .62141 L
.53231 .61169 L
.53399 .60831 L
.53717 .60198 L
.54198 .59227 L
.54371 .58874 L
.54675 .58256 L
.55148 .57284 L
.55342 .56881 L
.55617 .56313 L
.56082 .55342 L
.56313 .54852 L
.56542 .54371 L
.57001 .53399 L
.57284 .52788 L
.57453 .52428 L
.57905 .51457 L
.58256 .50689 L
.58349 .50486 L
.58795 .49514 L
.59227 .48557 L
.59233 .48543 L
.59673 .47572 L
.60106 .46601 L
.60198 .46391 L
.60538 .45629 L
.60967 .44658 L
.61169 .44192 L
.61391 .43687 L
.61816 .42716 L
.62141 .4196 L
.62234 .41744 L
.62654 .40773 L
.63068 .39802 L
.63112 .39697 L
.63482 .38831 L
.63893 .37859 L
.64083 .37402 L
.643 .36888 L
.64708 .35917 L
.65054 .35076 L
.65109 .34946 L
.65512 .33974 L
.65911 .33003 L
.66026 .32719 L
.66308 .32032 L
.66705 .31061 L
.66997 .30332 L
.67095 .30089 L
.67489 .29118 L
.67877 .28147 L
.67968 .27915 L
.68265 .27176 L
.68652 .26204 L
.68939 .25469 L
.69033 .25233 L
.69417 .24262 L
.69797 .23291 L
.69911 .22993 L
.70175 .22319 L
.70554 .21348 L
.70882 .20489 L
.70925 .20377 L
.71301 .19406 L
.71674 .18434 L
.71853 .17956 L
.72042 .17463 L
.72413 .16492 L
.72778 .15521 L
.72824 .15395 L
.73145 .14549 L
.73511 .13578 L
.73796 .12806 L
.7387 .12607 L
.74235 .11636 L
.74595 .10664 L
.74767 .1019 L
.74951 .09693 L
.75311 .08722 L
.75665 .07751 L
.75738 .07546 L
.7602 .06779 L
.76376 .05808 L
.76709 .04876 L
.76724 .04837 L
.77077 .03866 L
.77428 .02894 L
.77681 .02178 L
.77772 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.26503 .98077 m
.27176 .97403 L
.27474 .97106 L
.28147 .96433 L
.28445 .96134 L
.29118 .95462 L
.29416 .95163 L
.30089 .9449 L
.30388 .94192 L
.31061 .93519 L
.31359 .93221 L
.32032 .92548 L
.3233 .92249 L
.33003 .91577 L
.33303 .91278 L
.33974 .90605 L
.34278 .90307 L
.34946 .89661 L
.35265 .89336 L
.35917 .88638 L
.36167 .88364 L
.36888 .87544 L
.37018 .87393 L
.37828 .86422 L
.37859 .86383 L
.38605 .85451 L
.38831 .85159 L
.39352 .84479 L
.39802 .83876 L
.40074 .83508 L
.40773 .82537 L
.40773 .82536 L
.41455 .81566 L
.41744 .81143 L
.42119 .80594 L
.42716 .79698 L
.42765 .79623 L
.434 .78652 L
.43687 .78204 L
.44021 .77681 L
.44628 .76709 L
.44658 .76661 L
.45227 .75738 L
.45629 .75072 L
.45813 .74767 L
.46391 .73796 L
.46601 .73438 L
.4696 .72824 L
.47519 .71853 L
.47572 .7176 L
Mistroke
.48072 .70882 L
.48543 .70039 L
.48615 .69911 L
.49154 .68939 L
.49514 .68277 L
.49683 .67968 L
.50208 .66997 L
.50486 .66474 L
.50725 .66026 L
.51237 .65054 L
.51457 .64631 L
.51743 .64083 L
.52244 .63112 L
.52428 .6275 L
.5274 .62141 L
.53231 .61169 L
.53399 .60831 L
.53717 .60198 L
.54198 .59227 L
.54371 .58874 L
.54675 .58256 L
.55148 .57284 L
.55342 .56881 L
.55617 .56313 L
.56082 .55342 L
.56313 .54852 L
.56542 .54371 L
.57001 .53399 L
.57284 .52788 L
.57453 .52428 L
.57905 .51457 L
.58256 .50689 L
.58349 .50486 L
.58795 .49514 L
.59227 .48557 L
.59233 .48543 L
.59673 .47572 L
.60106 .46601 L
.60198 .46391 L
.60538 .45629 L
.60967 .44658 L
.61169 .44192 L
.61391 .43687 L
.61816 .42716 L
.62141 .4196 L
.62234 .41744 L
.62654 .40773 L
.63068 .39802 L
.63112 .39697 L
.63482 .38831 L
Mistroke
.63893 .37859 L
.64083 .37402 L
.643 .36888 L
.64708 .35917 L
.65054 .35076 L
.65109 .34946 L
.65512 .33974 L
.65911 .33003 L
.66026 .32719 L
.66308 .32032 L
.66705 .31061 L
.66997 .30332 L
.67095 .30089 L
.67489 .29118 L
.67877 .28147 L
.67968 .27915 L
.68265 .27176 L
.68652 .26204 L
.68939 .25469 L
.69033 .25233 L
.69417 .24262 L
.69797 .23291 L
.69911 .22993 L
.70175 .22319 L
.70554 .21348 L
.70882 .20489 L
.70925 .20377 L
.71301 .19406 L
.71674 .18434 L
.71853 .17956 L
.72042 .17463 L
.72413 .16492 L
.72778 .15521 L
.72824 .15395 L
.73145 .14549 L
.73511 .13578 L
.73796 .12806 L
.7387 .12607 L
.74235 .11636 L
.74595 .10664 L
.74767 .1019 L
.74951 .09693 L
.75311 .08722 L
.75665 .07751 L
.75738 .07546 L
.7602 .06779 L
.76376 .05808 L
.76709 .04876 L
.76724 .04837 L
.77077 .03866 L
Mistroke
.77428 .02894 L
.77681 .02178 L
.77772 .01923 L
Mfstroke
.6 g
.30044 .98077 m
.30089 .98031 L
.31015 .97106 L
.31061 .9706 L
.31986 .96134 L
.32032 .96089 L
.32958 .95163 L
.33003 .95118 L
.33931 .94192 L
.33974 .94146 L
.34817 .93221 L
.34946 .93076 L
.35662 .92249 L
.35917 .91947 L
.36471 .91278 L
.36888 .90761 L
.37249 .90307 L
.37859 .8952 L
.38 .89336 L
.38728 .88364 L
.38831 .88225 L
.39435 .87393 L
.39802 .86877 L
.40122 .86422 L
.40773 .8548 L
.40793 .85451 L
.41449 .84479 L
.41744 .84034 L
.4209 .83508 L
.42716 .82541 L
.42719 .82537 L
.43335 .81566 L
.43687 .81002 L
.43939 .80594 L
.44534 .79623 L
.44658 .79418 L
.45118 .78652 L
.45629 .77791 L
.45694 .77681 L
.46261 .76709 L
.46601 .7612 L
.46819 .75738 L
.47371 .74767 L
.47572 .74409 L
.47914 .73796 L
.48451 .72824 L
.48543 .72656 L
.48981 .71853 L
.49505 .70882 L
.49514 .70864 L
.50022 .69911 L
.50486 .69033 L
.50535 .68939 L
.51041 .67968 L
.51457 .67164 L
.51542 .66997 L
.52038 .66026 L
.52428 .65257 L
.5253 .65054 L
.53016 .64083 L
.53399 .63313 L
.53499 .63112 L
.53976 .62141 L
.54371 .61334 L
.5445 .61169 L
.54919 .60198 L
.55342 .59319 L
.55386 .59227 L
.55847 .58256 L
.56306 .57284 L
.56313 .57269 L
.56759 .56313 L
.57212 .55342 L
.57284 .55185 L
.57658 .54371 L
.58104 .53399 L
.58256 .53067 L
.58544 .52428 L
.58983 .51457 L
.59227 .50915 L
.59418 .50486 L
.59851 .49514 L
.60198 .48731 L
.6028 .48543 L
.60707 .47572 L
.61132 .46601 L
.61169 .46515 L
.61552 .45629 L
.61972 .44658 L
.62141 .44267 L
.62387 .43687 L
.62802 .42716 L
.63112 .41987 L
.63214 .41744 L
.63623 .40773 L
.64031 .39802 L
.64083 .39677 L
.64434 .38831 L
.64838 .37859 L
.65054 .37336 L
.65237 .36888 L
.65636 .35917 L
.66026 .34965 L
.66033 .34946 L
.66426 .33974 L
.6682 .33003 L
.66997 .32563 L
.67208 .32032 L
.67598 .31061 L
.67968 .30133 L
.67985 .30089 L
.68368 .29118 L
.68753 .28147 L
.68939 .27673 L
.69132 .27176 L
.69513 .26204 L
.69892 .25233 L
.69911 .25185 L
.70266 .24262 L
.70642 .23291 L
.70882 .22668 L
.71014 .22319 L
.71385 .21348 L
.71757 .20377 L
.71853 .20123 L
.72122 .19406 L
.72491 .18434 L
.72824 .1755 L
.72856 .17463 L
.73218 .16492 L
.73583 .15521 L
.73796 .1495 L
.73942 .14549 L
.74302 .13578 L
.74662 .12607 L
.74767 .12322 L
.75016 .11636 L
.75373 .10664 L
.75729 .09693 L
.75738 .09668 L
.76079 .08722 L
.76433 .07751 L
.76709 .06986 L
.76782 .06779 L
.7713 .05808 L
.77481 .04837 L
.77681 .04279 L
.77825 .03866 L
.78171 .02894 L
.78518 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.30044 .98077 m
.30089 .98031 L
.31015 .97106 L
.31061 .9706 L
.31986 .96134 L
.32032 .96089 L
.32958 .95163 L
.33003 .95118 L
.33931 .94192 L
.33974 .94146 L
.34817 .93221 L
.34946 .93076 L
.35662 .92249 L
.35917 .91947 L
.36471 .91278 L
.36888 .90761 L
.37249 .90307 L
.37859 .8952 L
.38 .89336 L
.38728 .88364 L
.38831 .88225 L
.39435 .87393 L
.39802 .86877 L
.40122 .86422 L
.40773 .8548 L
.40793 .85451 L
.41449 .84479 L
.41744 .84034 L
.4209 .83508 L
.42716 .82541 L
.42719 .82537 L
.43335 .81566 L
.43687 .81002 L
.43939 .80594 L
.44534 .79623 L
.44658 .79418 L
.45118 .78652 L
.45629 .77791 L
.45694 .77681 L
.46261 .76709 L
.46601 .7612 L
.46819 .75738 L
.47371 .74767 L
.47572 .74409 L
.47914 .73796 L
.48451 .72824 L
.48543 .72656 L
.48981 .71853 L
.49505 .70882 L
.49514 .70864 L
Mistroke
.50022 .69911 L
.50486 .69033 L
.50535 .68939 L
.51041 .67968 L
.51457 .67164 L
.51542 .66997 L
.52038 .66026 L
.52428 .65257 L
.5253 .65054 L
.53016 .64083 L
.53399 .63313 L
.53499 .63112 L
.53976 .62141 L
.54371 .61334 L
.5445 .61169 L
.54919 .60198 L
.55342 .59319 L
.55386 .59227 L
.55847 .58256 L
.56306 .57284 L
.56313 .57269 L
.56759 .56313 L
.57212 .55342 L
.57284 .55185 L
.57658 .54371 L
.58104 .53399 L
.58256 .53067 L
.58544 .52428 L
.58983 .51457 L
.59227 .50915 L
.59418 .50486 L
.59851 .49514 L
.60198 .48731 L
.6028 .48543 L
.60707 .47572 L
.61132 .46601 L
.61169 .46515 L
.61552 .45629 L
.61972 .44658 L
.62141 .44267 L
.62387 .43687 L
.62802 .42716 L
.63112 .41987 L
.63214 .41744 L
.63623 .40773 L
.64031 .39802 L
.64083 .39677 L
.64434 .38831 L
.64838 .37859 L
.65054 .37336 L
Mistroke
.65237 .36888 L
.65636 .35917 L
.66026 .34965 L
.66033 .34946 L
.66426 .33974 L
.6682 .33003 L
.66997 .32563 L
.67208 .32032 L
.67598 .31061 L
.67968 .30133 L
.67985 .30089 L
.68368 .29118 L
.68753 .28147 L
.68939 .27673 L
.69132 .27176 L
.69513 .26204 L
.69892 .25233 L
.69911 .25185 L
.70266 .24262 L
.70642 .23291 L
.70882 .22668 L
.71014 .22319 L
.71385 .21348 L
.71757 .20377 L
.71853 .20123 L
.72122 .19406 L
.72491 .18434 L
.72824 .1755 L
.72856 .17463 L
.73218 .16492 L
.73583 .15521 L
.73796 .1495 L
.73942 .14549 L
.74302 .13578 L
.74662 .12607 L
.74767 .12322 L
.75016 .11636 L
.75373 .10664 L
.75729 .09693 L
.75738 .09668 L
.76079 .08722 L
.76433 .07751 L
.76709 .06986 L
.76782 .06779 L
.7713 .05808 L
.77481 .04837 L
.77681 .04279 L
.77825 .03866 L
.78171 .02894 L
.78518 .01923 L
Mistroke
Mfstroke
.7 g
.34312 .98077 m
.34946 .97206 L
.35018 .97106 L
.35733 .96134 L
.35917 .95882 L
.36439 .95163 L
.36888 .94538 L
.37135 .94192 L
.37821 .93221 L
.37859 .93166 L
.38493 .92249 L
.38831 .91756 L
.39153 .91278 L
.39802 .90312 L
.39805 .90307 L
.40441 .89336 L
.40773 .88825 L
.41067 .88364 L
.41687 .87393 L
.41744 .87303 L
.42291 .86422 L
.42716 .85738 L
.42889 .85451 L
.43479 .84479 L
.43687 .84135 L
.44057 .83508 L
.44633 .82537 L
.44658 .82494 L
.45193 .81566 L
.45629 .80811 L
.45751 .80594 L
.463 .79623 L
.46601 .79091 L
.46841 .78652 L
.4738 .77681 L
.47572 .77334 L
.47907 .76709 L
.48435 .75738 L
.48543 .75539 L
.48949 .74767 L
.49467 .73796 L
.49514 .73707 L
.49969 .72824 L
.50478 .71853 L
.50486 .71838 L
.50969 .70882 L
.51457 .69933 L
.51468 .69911 L
.5195 .68939 L
.52428 .67993 L
.5244 .67968 L
.52914 .66997 L
.53396 .66026 L
.53399 .66018 L
.5386 .65054 L
.54334 .64083 L
.54371 .64008 L
.54791 .63112 L
.55258 .62141 L
.55342 .61965 L
.55707 .61169 L
.56167 .60198 L
.56313 .59887 L
.5661 .59227 L
.57062 .58256 L
.57284 .57777 L
.57501 .57284 L
.57944 .56313 L
.58256 .55634 L
.58381 .55342 L
.58815 .54371 L
.59227 .5346 L
.59252 .53399 L
.59674 .52428 L
.60108 .51457 L
.60198 .51253 L
.60522 .50486 L
.6095 .49514 L
.61169 .49015 L
.61363 .48543 L
.61782 .47572 L
.62141 .46746 L
.62198 .46601 L
.62604 .45629 L
.63021 .44658 L
.63112 .44446 L
.63418 .43687 L
.63829 .42716 L
.64083 .42116 L
.64228 .41744 L
.64628 .40773 L
.65036 .39802 L
.65054 .39757 L
.6542 .38831 L
.65823 .37859 L
.66026 .37367 L
.66208 .36888 L
.66601 .35917 L
.66997 .3495 L
.66998 .34946 L
.67372 .33974 L
.67766 .33003 L
.67968 .32502 L
.68141 .32032 L
.68525 .31061 L
.68914 .30089 L
.68939 .30026 L
.69279 .29118 L
.69663 .28147 L
.69911 .27522 L
.70033 .27176 L
.70405 .26204 L
.70787 .25233 L
.70882 .2499 L
.71144 .24262 L
.71519 .23291 L
.71853 .2243 L
.7189 .22319 L
.72246 .21348 L
.7262 .20377 L
.72824 .19843 L
.72974 .19406 L
.73336 .18434 L
.73707 .17463 L
.73796 .17229 L
.74051 .16492 L
.74415 .15521 L
.74767 .14588 L
.74779 .14549 L
.75119 .13578 L
.75482 .12607 L
.75738 .1192 L
.7583 .11636 L
.76176 .10664 L
.76537 .09693 L
.76709 .09226 L
.76874 .08722 L
.77224 .07751 L
.77581 .06779 L
.77681 .06506 L
.7791 .05808 L
.7826 .04837 L
.78614 .03866 L
.78652 .0376 L
.78937 .02894 L
.79286 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.34312 .98077 m
.34946 .97206 L
.35018 .97106 L
.35733 .96134 L
.35917 .95882 L
.36439 .95163 L
.36888 .94538 L
.37135 .94192 L
.37821 .93221 L
.37859 .93166 L
.38493 .92249 L
.38831 .91756 L
.39153 .91278 L
.39802 .90312 L
.39805 .90307 L
.40441 .89336 L
.40773 .88825 L
.41067 .88364 L
.41687 .87393 L
.41744 .87303 L
.42291 .86422 L
.42716 .85738 L
.42889 .85451 L
.43479 .84479 L
.43687 .84135 L
.44057 .83508 L
.44633 .82537 L
.44658 .82494 L
.45193 .81566 L
.45629 .80811 L
.45751 .80594 L
.463 .79623 L
.46601 .79091 L
.46841 .78652 L
.4738 .77681 L
.47572 .77334 L
.47907 .76709 L
.48435 .75738 L
.48543 .75539 L
.48949 .74767 L
.49467 .73796 L
.49514 .73707 L
.49969 .72824 L
.50478 .71853 L
.50486 .71838 L
.50969 .70882 L
.51457 .69933 L
.51468 .69911 L
.5195 .68939 L
.52428 .67993 L
Mistroke
.5244 .67968 L
.52914 .66997 L
.53396 .66026 L
.53399 .66018 L
.5386 .65054 L
.54334 .64083 L
.54371 .64008 L
.54791 .63112 L
.55258 .62141 L
.55342 .61965 L
.55707 .61169 L
.56167 .60198 L
.56313 .59887 L
.5661 .59227 L
.57062 .58256 L
.57284 .57777 L
.57501 .57284 L
.57944 .56313 L
.58256 .55634 L
.58381 .55342 L
.58815 .54371 L
.59227 .5346 L
.59252 .53399 L
.59674 .52428 L
.60108 .51457 L
.60198 .51253 L
.60522 .50486 L
.6095 .49514 L
.61169 .49015 L
.61363 .48543 L
.61782 .47572 L
.62141 .46746 L
.62198 .46601 L
.62604 .45629 L
.63021 .44658 L
.63112 .44446 L
.63418 .43687 L
.63829 .42716 L
.64083 .42116 L
.64228 .41744 L
.64628 .40773 L
.65036 .39802 L
.65054 .39757 L
.6542 .38831 L
.65823 .37859 L
.66026 .37367 L
.66208 .36888 L
.66601 .35917 L
.66997 .3495 L
.66998 .34946 L
Mistroke
.67372 .33974 L
.67766 .33003 L
.67968 .32502 L
.68141 .32032 L
.68525 .31061 L
.68914 .30089 L
.68939 .30026 L
.69279 .29118 L
.69663 .28147 L
.69911 .27522 L
.70033 .27176 L
.70405 .26204 L
.70787 .25233 L
.70882 .2499 L
.71144 .24262 L
.71519 .23291 L
.71853 .2243 L
.7189 .22319 L
.72246 .21348 L
.7262 .20377 L
.72824 .19843 L
.72974 .19406 L
.73336 .18434 L
.73707 .17463 L
.73796 .17229 L
.74051 .16492 L
.74415 .15521 L
.74767 .14588 L
.74779 .14549 L
.75119 .13578 L
.75482 .12607 L
.75738 .1192 L
.7583 .11636 L
.76176 .10664 L
.76537 .09693 L
.76709 .09226 L
.76874 .08722 L
.77224 .07751 L
.77581 .06779 L
.77681 .06506 L
.7791 .05808 L
.7826 .04837 L
.78614 .03866 L
.78652 .0376 L
.78937 .02894 L
.79286 .01923 L
Mfstroke
.6 g
.41701 .98077 m
.41744 .9801 L
.42402 .97106 L
.42716 .9664 L
.4307 .96134 L
.43687 .95208 L
.43717 .95163 L
.44366 .94192 L
.44658 .93725 L
.44987 .93221 L
.45594 .92249 L
.45629 .92189 L
.46202 .91278 L
.46601 .90605 L
.46784 .90307 L
.47367 .89336 L
.47572 .88973 L
.47935 .88364 L
.4849 .87393 L
.48543 .87295 L
.49049 .86422 L
.49514 .85572 L
.49583 .85451 L
.5013 .84479 L
.50486 .83808 L
.50651 .83508 L
.51182 .82537 L
.51457 .82001 L
.51692 .81566 L
.52208 .80594 L
.52428 .80153 L
.52709 .79623 L
.53212 .78652 L
.53399 .78265 L
.53703 .77681 L
.54195 .76709 L
.54371 .76339 L
.54676 .75738 L
.55159 .74767 L
.55342 .74374 L
.55631 .73796 L
.56107 .72824 L
.56313 .72372 L
.56568 .71853 L
.57037 .70882 L
.57284 .70334 L
.57489 .69911 L
.57952 .68939 L
.58256 .6826 L
.58394 .67968 L
.58853 .66997 L
.59227 .66151 L
.59285 .66026 L
.59738 .65054 L
.60167 .64083 L
.60198 .64007 L
.6061 .63112 L
.61042 .62141 L
.61169 .6183 L
.61469 .61169 L
.61902 .60198 L
.62141 .5962 L
.62316 .59227 L
.62748 .58256 L
.63112 .57376 L
.63152 .57284 L
.6358 .56313 L
.6399 .55342 L
.64083 .55101 L
.64401 .54371 L
.64816 .53399 L
.65054 .52793 L
.65211 .52428 L
.65626 .51457 L
.66014 .50486 L
.66026 .50454 L
.66424 .49514 L
.66824 .48543 L
.66997 .48085 L
.67212 .47572 L
.67616 .46601 L
.67968 .45684 L
.67991 .45629 L
.68393 .44658 L
.68782 .43687 L
.68939 .43255 L
.6916 .42716 L
.69555 .41744 L
.69911 .40794 L
.69919 .40773 L
.70312 .39802 L
.70695 .38831 L
.70882 .38306 L
.7106 .37859 L
.71447 .36888 L
.7181 .35917 L
.71853 .35788 L
.72186 .34946 L
.72565 .33974 L
.72824 .33241 L
.72917 .33003 L
.73297 .32032 L
.73663 .31061 L
.73796 .30666 L
.74019 .30089 L
.74394 .29118 L
.7474 .28147 L
.74767 .28063 L
.75107 .27176 L
.75475 .26204 L
.75738 .25433 L
.75814 .25233 L
.76183 .24262 L
.76541 .23291 L
.76709 .22775 L
.7688 .22319 L
.77246 .21348 L
.77591 .20377 L
.77681 .2009 L
.77935 .19406 L
.78296 .18434 L
.78627 .17463 L
.78652 .17378 L
.78979 .16492 L
.79334 .15521 L
.79623 .1464 L
.79656 .14549 L
.80012 .13578 L
.80361 .12607 L
.80594 .11876 L
.80681 .11636 L
.81034 .10664 L
.81377 .09693 L
.81566 .09086 L
.81696 .08722 L
.82046 .07751 L
.82383 .06779 L
.82537 .0627 L
.82701 .05808 L
.83048 .04837 L
.83379 .03866 L
.83508 .03428 L
.83696 .02894 L
.84041 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.41701 .98077 m
.41744 .9801 L
.42402 .97106 L
.42716 .9664 L
.4307 .96134 L
.43687 .95208 L
.43717 .95163 L
.44366 .94192 L
.44658 .93725 L
.44987 .93221 L
.45594 .92249 L
.45629 .92189 L
.46202 .91278 L
.46601 .90605 L
.46784 .90307 L
.47367 .89336 L
.47572 .88973 L
.47935 .88364 L
.4849 .87393 L
.48543 .87295 L
.49049 .86422 L
.49514 .85572 L
.49583 .85451 L
.5013 .84479 L
.50486 .83808 L
.50651 .83508 L
.51182 .82537 L
.51457 .82001 L
.51692 .81566 L
.52208 .80594 L
.52428 .80153 L
.52709 .79623 L
.53212 .78652 L
.53399 .78265 L
.53703 .77681 L
.54195 .76709 L
.54371 .76339 L
.54676 .75738 L
.55159 .74767 L
.55342 .74374 L
.55631 .73796 L
.56107 .72824 L
.56313 .72372 L
.56568 .71853 L
.57037 .70882 L
.57284 .70334 L
.57489 .69911 L
.57952 .68939 L
.58256 .6826 L
.58394 .67968 L
Mistroke
.58853 .66997 L
.59227 .66151 L
.59285 .66026 L
.59738 .65054 L
.60167 .64083 L
.60198 .64007 L
.6061 .63112 L
.61042 .62141 L
.61169 .6183 L
.61469 .61169 L
.61902 .60198 L
.62141 .5962 L
.62316 .59227 L
.62748 .58256 L
.63112 .57376 L
.63152 .57284 L
.6358 .56313 L
.6399 .55342 L
.64083 .55101 L
.64401 .54371 L
.64816 .53399 L
.65054 .52793 L
.65211 .52428 L
.65626 .51457 L
.66014 .50486 L
.66026 .50454 L
.66424 .49514 L
.66824 .48543 L
.66997 .48085 L
.67212 .47572 L
.67616 .46601 L
.67968 .45684 L
.67991 .45629 L
.68393 .44658 L
.68782 .43687 L
.68939 .43255 L
.6916 .42716 L
.69555 .41744 L
.69911 .40794 L
.69919 .40773 L
.70312 .39802 L
.70695 .38831 L
.70882 .38306 L
.7106 .37859 L
.71447 .36888 L
.7181 .35917 L
.71853 .35788 L
.72186 .34946 L
.72565 .33974 L
.72824 .33241 L
Mistroke
.72917 .33003 L
.73297 .32032 L
.73663 .31061 L
.73796 .30666 L
.74019 .30089 L
.74394 .29118 L
.7474 .28147 L
.74767 .28063 L
.75107 .27176 L
.75475 .26204 L
.75738 .25433 L
.75814 .25233 L
.76183 .24262 L
.76541 .23291 L
.76709 .22775 L
.7688 .22319 L
.77246 .21348 L
.77591 .20377 L
.77681 .2009 L
.77935 .19406 L
.78296 .18434 L
.78627 .17463 L
.78652 .17378 L
.78979 .16492 L
.79334 .15521 L
.79623 .1464 L
.79656 .14549 L
.80012 .13578 L
.80361 .12607 L
.80594 .11876 L
.80681 .11636 L
.81034 .10664 L
.81377 .09693 L
.81566 .09086 L
.81696 .08722 L
.82046 .07751 L
.82383 .06779 L
.82537 .0627 L
.82701 .05808 L
.83048 .04837 L
.83379 .03866 L
.83508 .03428 L
.83696 .02894 L
.84041 .01923 L
Mfstroke
.5 g
.43857 .98077 m
.44469 .97106 L
.44658 .968 L
.45069 .96134 L
.45629 .9521 L
.45658 .95163 L
.46239 .94192 L
.46601 .93576 L
.46809 .93221 L
.47372 .92249 L
.47572 .91898 L
.47926 .91278 L
.48471 .90307 L
.48543 .90177 L
.49011 .89336 L
.49514 .88415 L
.49542 .88364 L
.50069 .87393 L
.50486 .86612 L
.50587 .86422 L
.51102 .85451 L
.51457 .8477 L
.51609 .84479 L
.52112 .83508 L
.52428 .82888 L
.52608 .82537 L
.53101 .81566 L
.53399 .80969 L
.53587 .80594 L
.54071 .79623 L
.54371 .79012 L
.54548 .78652 L
.55024 .77681 L
.55342 .77019 L
.55492 .76709 L
.55959 .75738 L
.56313 .74991 L
.5642 .74767 L
.5688 .73796 L
.57284 .72926 L
.57332 .72824 L
.57785 .71853 L
.58231 .70882 L
.58256 .70828 L
.58677 .69911 L
.59118 .68939 L
.59227 .68695 L
.59556 .67968 L
.59992 .66997 L
.60198 .66529 L
.60423 .66026 L
.60854 .65054 L
.61169 .6433 L
.61278 .64083 L
.61704 .63112 L
.62123 .62141 L
.62141 .62099 L
.62543 .61169 L
.62959 .60198 L
.63112 .59835 L
.63372 .59227 L
.63785 .58256 L
.64083 .5754 L
.64191 .57284 L
.646 .56313 L
.65002 .55342 L
.65054 .55214 L
.65405 .54371 L
.65806 .53399 L
.66026 .52858 L
.66202 .52428 L
.666 .51457 L
.66991 .50486 L
.66997 .50471 L
.67385 .49514 L
.67775 .48543 L
.67968 .48054 L
.68161 .47572 L
.6855 .46601 L
.68931 .45629 L
.68939 .45607 L
.69315 .44658 L
.69697 .43687 L
.69911 .43132 L
.70074 .42716 L
.70453 .41744 L
.70827 .40773 L
.70882 .40627 L
.71202 .39802 L
.71576 .38831 L
.71853 .38095 L
.71943 .37859 L
.72315 .36888 L
.72683 .35917 L
.72824 .35534 L
.73047 .34946 L
.73415 .33974 L
.73775 .33003 L
.73796 .32945 L
.74138 .32032 L
.745 .31061 L
.74767 .30328 L
.74855 .30089 L
.75216 .29118 L
.75573 .28147 L
.75738 .27685 L
.75925 .27176 L
.76282 .26204 L
.76632 .25233 L
.76709 .25014 L
.76983 .24262 L
.77336 .23291 L
.7768 .22319 L
.77681 .22317 L
.7803 .21348 L
.78378 .20377 L
.78652 .19593 L
.78719 .19406 L
.79065 .18434 L
.79409 .17463 L
.79623 .16843 L
.79747 .16492 L
.80091 .15521 L
.8043 .14549 L
.80594 .14067 L
.80765 .13578 L
.81106 .12607 L
.81442 .11636 L
.81566 .11266 L
.81774 .10664 L
.82112 .09693 L
.82443 .08722 L
.82537 .08439 L
.82773 .07751 L
.83108 .06779 L
.83436 .05808 L
.83508 .05587 L
.83764 .04837 L
.84095 .03866 L
.84419 .02894 L
.84479 .02709 L
.84745 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.43857 .98077 m
.44469 .97106 L
.44658 .968 L
.45069 .96134 L
.45629 .9521 L
.45658 .95163 L
.46239 .94192 L
.46601 .93576 L
.46809 .93221 L
.47372 .92249 L
.47572 .91898 L
.47926 .91278 L
.48471 .90307 L
.48543 .90177 L
.49011 .89336 L
.49514 .88415 L
.49542 .88364 L
.50069 .87393 L
.50486 .86612 L
.50587 .86422 L
.51102 .85451 L
.51457 .8477 L
.51609 .84479 L
.52112 .83508 L
.52428 .82888 L
.52608 .82537 L
.53101 .81566 L
.53399 .80969 L
.53587 .80594 L
.54071 .79623 L
.54371 .79012 L
.54548 .78652 L
.55024 .77681 L
.55342 .77019 L
.55492 .76709 L
.55959 .75738 L
.56313 .74991 L
.5642 .74767 L
.5688 .73796 L
.57284 .72926 L
.57332 .72824 L
.57785 .71853 L
.58231 .70882 L
.58256 .70828 L
.58677 .69911 L
.59118 .68939 L
.59227 .68695 L
.59556 .67968 L
.59992 .66997 L
.60198 .66529 L
Mistroke
.60423 .66026 L
.60854 .65054 L
.61169 .6433 L
.61278 .64083 L
.61704 .63112 L
.62123 .62141 L
.62141 .62099 L
.62543 .61169 L
.62959 .60198 L
.63112 .59835 L
.63372 .59227 L
.63785 .58256 L
.64083 .5754 L
.64191 .57284 L
.646 .56313 L
.65002 .55342 L
.65054 .55214 L
.65405 .54371 L
.65806 .53399 L
.66026 .52858 L
.66202 .52428 L
.666 .51457 L
.66991 .50486 L
.66997 .50471 L
.67385 .49514 L
.67775 .48543 L
.67968 .48054 L
.68161 .47572 L
.6855 .46601 L
.68931 .45629 L
.68939 .45607 L
.69315 .44658 L
.69697 .43687 L
.69911 .43132 L
.70074 .42716 L
.70453 .41744 L
.70827 .40773 L
.70882 .40627 L
.71202 .39802 L
.71576 .38831 L
.71853 .38095 L
.71943 .37859 L
.72315 .36888 L
.72683 .35917 L
.72824 .35534 L
.73047 .34946 L
.73415 .33974 L
.73775 .33003 L
.73796 .32945 L
.74138 .32032 L
Mistroke
.745 .31061 L
.74767 .30328 L
.74855 .30089 L
.75216 .29118 L
.75573 .28147 L
.75738 .27685 L
.75925 .27176 L
.76282 .26204 L
.76632 .25233 L
.76709 .25014 L
.76983 .24262 L
.77336 .23291 L
.7768 .22319 L
.77681 .22317 L
.7803 .21348 L
.78378 .20377 L
.78652 .19593 L
.78719 .19406 L
.79065 .18434 L
.79409 .17463 L
.79623 .16843 L
.79747 .16492 L
.80091 .15521 L
.8043 .14549 L
.80594 .14067 L
.80765 .13578 L
.81106 .12607 L
.81442 .11636 L
.81566 .11266 L
.81774 .10664 L
.82112 .09693 L
.82443 .08722 L
.82537 .08439 L
.82773 .07751 L
.83108 .06779 L
.83436 .05808 L
.83508 .05587 L
.83764 .04837 L
.84095 .03866 L
.84419 .02894 L
.84479 .02709 L
.84745 .01923 L
Mfstroke
.4 g
.45542 .98077 m
.45629 .97929 L
.46111 .97106 L
.46601 .96259 L
.46672 .96134 L
.47225 .95163 L
.47572 .94547 L
.4777 .94192 L
.48309 .93221 L
.48543 .92795 L
.4884 .92249 L
.49366 .91278 L
.49514 .91003 L
.49885 .90307 L
.50399 .89336 L
.50486 .89172 L
.50907 .88364 L
.5141 .87393 L
.51457 .87302 L
.51907 .86422 L
.524 .85451 L
.52428 .85396 L
.52887 .84479 L
.53372 .83508 L
.53399 .83452 L
.5385 .82537 L
.54325 .81566 L
.54371 .81472 L
.54795 .80594 L
.55263 .79623 L
.55342 .79457 L
.55724 .78652 L
.56185 .77681 L
.56313 .77407 L
.56639 .76709 L
.57092 .75738 L
.57284 .75323 L
.5754 .74767 L
.57986 .73796 L
.58256 .73205 L
.58427 .72824 L
.58867 .71853 L
.59227 .71054 L
.59303 .70882 L
.59736 .69911 L
.60167 .68939 L
.60198 .6887 L
.60593 .67968 L
.6102 .66997 L
.61169 .66653 L
.6144 .66026 L
.61861 .65054 L
.62141 .64405 L
.62277 .64083 L
.62692 .63112 L
.63106 .62141 L
.63112 .62126 L
.63514 .61169 L
.63923 .60198 L
.64083 .59815 L
.64327 .59227 L
.64731 .58256 L
.65054 .57474 L
.65132 .57284 L
.6553 .56313 L
.65928 .55342 L
.66026 .55103 L
.66321 .54371 L
.66715 .53399 L
.66997 .52702 L
.67105 .52428 L
.67494 .51457 L
.67883 .50486 L
.67968 .50271 L
.68266 .49514 L
.68651 .48543 L
.68939 .47812 L
.69032 .47572 L
.69412 .46601 L
.69792 .45629 L
.69911 .45323 L
.70166 .44658 L
.70542 .43687 L
.70882 .42806 L
.70916 .42716 L
.71286 .41744 L
.71658 .40773 L
.71853 .40261 L
.72025 .39802 L
.72393 .38831 L
.7276 .37859 L
.72824 .37689 L
.73122 .36888 L
.73486 .35917 L
.73796 .35088 L
.73848 .34946 L
.74206 .33974 L
.74567 .33003 L
.74767 .32461 L
.74922 .32032 L
.75278 .31061 L
.75635 .30089 L
.75738 .29806 L
.75985 .29118 L
.76339 .28147 L
.76691 .27176 L
.76709 .27125 L
.77037 .26204 L
.77388 .25233 L
.77681 .24417 L
.77735 .24262 L
.78079 .23291 L
.78426 .22319 L
.78652 .21683 L
.78768 .21348 L
.7911 .20377 L
.79454 .19406 L
.79623 .18923 L
.79791 .18434 L
.80131 .17463 L
.80471 .16492 L
.80594 .16138 L
.80805 .15521 L
.81142 .14549 L
.81479 .13578 L
.81566 .13327 L
.81809 .12607 L
.82144 .11636 L
.82478 .10664 L
.82537 .10491 L
.82804 .09693 L
.83136 .08722 L
.83467 .07751 L
.83508 .07629 L
.83791 .06779 L
.8412 .05808 L
.84448 .04837 L
.84479 .04743 L
.84769 .03866 L
.85095 .02894 L
.85421 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.45542 .98077 m
.45629 .97929 L
.46111 .97106 L
.46601 .96259 L
.46672 .96134 L
.47225 .95163 L
.47572 .94547 L
.4777 .94192 L
.48309 .93221 L
.48543 .92795 L
.4884 .92249 L
.49366 .91278 L
.49514 .91003 L
.49885 .90307 L
.50399 .89336 L
.50486 .89172 L
.50907 .88364 L
.5141 .87393 L
.51457 .87302 L
.51907 .86422 L
.524 .85451 L
.52428 .85396 L
.52887 .84479 L
.53372 .83508 L
.53399 .83452 L
.5385 .82537 L
.54325 .81566 L
.54371 .81472 L
.54795 .80594 L
.55263 .79623 L
.55342 .79457 L
.55724 .78652 L
.56185 .77681 L
.56313 .77407 L
.56639 .76709 L
.57092 .75738 L
.57284 .75323 L
.5754 .74767 L
.57986 .73796 L
.58256 .73205 L
.58427 .72824 L
.58867 .71853 L
.59227 .71054 L
.59303 .70882 L
.59736 .69911 L
.60167 .68939 L
.60198 .6887 L
.60593 .67968 L
.6102 .66997 L
.61169 .66653 L
Mistroke
.6144 .66026 L
.61861 .65054 L
.62141 .64405 L
.62277 .64083 L
.62692 .63112 L
.63106 .62141 L
.63112 .62126 L
.63514 .61169 L
.63923 .60198 L
.64083 .59815 L
.64327 .59227 L
.64731 .58256 L
.65054 .57474 L
.65132 .57284 L
.6553 .56313 L
.65928 .55342 L
.66026 .55103 L
.66321 .54371 L
.66715 .53399 L
.66997 .52702 L
.67105 .52428 L
.67494 .51457 L
.67883 .50486 L
.67968 .50271 L
.68266 .49514 L
.68651 .48543 L
.68939 .47812 L
.69032 .47572 L
.69412 .46601 L
.69792 .45629 L
.69911 .45323 L
.70166 .44658 L
.70542 .43687 L
.70882 .42806 L
.70916 .42716 L
.71286 .41744 L
.71658 .40773 L
.71853 .40261 L
.72025 .39802 L
.72393 .38831 L
.7276 .37859 L
.72824 .37689 L
.73122 .36888 L
.73486 .35917 L
.73796 .35088 L
.73848 .34946 L
.74206 .33974 L
.74567 .33003 L
.74767 .32461 L
.74922 .32032 L
Mistroke
.75278 .31061 L
.75635 .30089 L
.75738 .29806 L
.75985 .29118 L
.76339 .28147 L
.76691 .27176 L
.76709 .27125 L
.77037 .26204 L
.77388 .25233 L
.77681 .24417 L
.77735 .24262 L
.78079 .23291 L
.78426 .22319 L
.78652 .21683 L
.78768 .21348 L
.7911 .20377 L
.79454 .19406 L
.79623 .18923 L
.79791 .18434 L
.80131 .17463 L
.80471 .16492 L
.80594 .16138 L
.80805 .15521 L
.81142 .14549 L
.81479 .13578 L
.81566 .13327 L
.81809 .12607 L
.82144 .11636 L
.82478 .10664 L
.82537 .10491 L
.82804 .09693 L
.83136 .08722 L
.83467 .07751 L
.83508 .07629 L
.83791 .06779 L
.8412 .05808 L
.84448 .04837 L
.84479 .04743 L
.84769 .03866 L
.85095 .02894 L
.85421 .01923 L
Mfstroke
.3 g
.47237 .98077 m
.47572 .97474 L
.47768 .97106 L
.48295 .96134 L
.48543 .95677 L
.48812 .95163 L
.4933 .94192 L
.49514 .93845 L
.49835 .93221 L
.50343 .92249 L
.50486 .91976 L
.50837 .91278 L
.51336 .90307 L
.51457 .90071 L
.5182 .89336 L
.52311 .88364 L
.52428 .88131 L
.52786 .87393 L
.53268 .86422 L
.53399 .86156 L
.53735 .85451 L
.54209 .84479 L
.54371 .84146 L
.54668 .83508 L
.55134 .82537 L
.55342 .82103 L
.55587 .81566 L
.56045 .80594 L
.56313 .80025 L
.56492 .79623 L
.56942 .78652 L
.57284 .77915 L
.57386 .77681 L
.57826 .76709 L
.58256 .75773 L
.5827 .75738 L
.58698 .74767 L
.59138 .73796 L
.59227 .73598 L
.59559 .72824 L
.59992 .71853 L
.60198 .71391 L
.60411 .70882 L
.60836 .69911 L
.61169 .69153 L
.61256 .68939 L
.61669 .67968 L
.62092 .66997 L
.62141 .66885 L
.62494 .66026 L
.62911 .65054 L
.63112 .64585 L
.63312 .64083 L
.6372 .63112 L
.64083 .62255 L
.64127 .62141 L
.6452 .61169 L
.64928 .60198 L
.65054 .59895 L
.65315 .59227 L
.65715 .58256 L
.66026 .57506 L
.66108 .57284 L
.66495 .56313 L
.66893 .55342 L
.66997 .55088 L
.67269 .54371 L
.67661 .53399 L
.67968 .5264 L
.68045 .52428 L
.68422 .51457 L
.68811 .50486 L
.68939 .50164 L
.69179 .49514 L
.69561 .48543 L
.69911 .47661 L
.69941 .47572 L
.70305 .46601 L
.70686 .45629 L
.70882 .45128 L
.71048 .44658 L
.71419 .43687 L
.71797 .42716 L
.71853 .42569 L
.72148 .41744 L
.7252 .40773 L
.72824 .39981 L
.72884 .39802 L
.73238 .38831 L
.73609 .37859 L
.73796 .37367 L
.73958 .36888 L
.74318 .35917 L
.74685 .34946 L
.74767 .34726 L
.75025 .33974 L
.75385 .33003 L
.75738 .32059 L
.75746 .32032 L
.76082 .31061 L
.76441 .30089 L
.76709 .29364 L
.76787 .29118 L
.77129 .28147 L
.77486 .27176 L
.77681 .26644 L
.77821 .26204 L
.78166 .25233 L
.7852 .24262 L
.78652 .23898 L
.78847 .23291 L
.79193 .22319 L
.79544 .21348 L
.79623 .21126 L
.79865 .20377 L
.80209 .19406 L
.80557 .18434 L
.80594 .1833 L
.80873 .17463 L
.81216 .16492 L
.81561 .15521 L
.81566 .15507 L
.81873 .14549 L
.82214 .13578 L
.82537 .1266 L
.82552 .12607 L
.82863 .11636 L
.83203 .10664 L
.83508 .09788 L
.83535 .09693 L
.83845 .08722 L
.84182 .07751 L
.84479 .06891 L
.8451 .06779 L
.84819 .05808 L
.85153 .04837 L
.85451 .0397 L
.85479 .03866 L
.85784 .02894 L
.86116 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.47237 .98077 m
.47572 .97474 L
.47768 .97106 L
.48295 .96134 L
.48543 .95677 L
.48812 .95163 L
.4933 .94192 L
.49514 .93845 L
.49835 .93221 L
.50343 .92249 L
.50486 .91976 L
.50837 .91278 L
.51336 .90307 L
.51457 .90071 L
.5182 .89336 L
.52311 .88364 L
.52428 .88131 L
.52786 .87393 L
.53268 .86422 L
.53399 .86156 L
.53735 .85451 L
.54209 .84479 L
.54371 .84146 L
.54668 .83508 L
.55134 .82537 L
.55342 .82103 L
.55587 .81566 L
.56045 .80594 L
.56313 .80025 L
.56492 .79623 L
.56942 .78652 L
.57284 .77915 L
.57386 .77681 L
.57826 .76709 L
.58256 .75773 L
.5827 .75738 L
.58698 .74767 L
.59138 .73796 L
.59227 .73598 L
.59559 .72824 L
.59992 .71853 L
.60198 .71391 L
.60411 .70882 L
.60836 .69911 L
.61169 .69153 L
.61256 .68939 L
.61669 .67968 L
.62092 .66997 L
.62141 .66885 L
.62494 .66026 L
Mistroke
.62911 .65054 L
.63112 .64585 L
.63312 .64083 L
.6372 .63112 L
.64083 .62255 L
.64127 .62141 L
.6452 .61169 L
.64928 .60198 L
.65054 .59895 L
.65315 .59227 L
.65715 .58256 L
.66026 .57506 L
.66108 .57284 L
.66495 .56313 L
.66893 .55342 L
.66997 .55088 L
.67269 .54371 L
.67661 .53399 L
.67968 .5264 L
.68045 .52428 L
.68422 .51457 L
.68811 .50486 L
.68939 .50164 L
.69179 .49514 L
.69561 .48543 L
.69911 .47661 L
.69941 .47572 L
.70305 .46601 L
.70686 .45629 L
.70882 .45128 L
.71048 .44658 L
.71419 .43687 L
.71797 .42716 L
.71853 .42569 L
.72148 .41744 L
.7252 .40773 L
.72824 .39981 L
.72884 .39802 L
.73238 .38831 L
.73609 .37859 L
.73796 .37367 L
.73958 .36888 L
.74318 .35917 L
.74685 .34946 L
.74767 .34726 L
.75025 .33974 L
.75385 .33003 L
.75738 .32059 L
.75746 .32032 L
.76082 .31061 L
Mistroke
.76441 .30089 L
.76709 .29364 L
.76787 .29118 L
.77129 .28147 L
.77486 .27176 L
.77681 .26644 L
.77821 .26204 L
.78166 .25233 L
.7852 .24262 L
.78652 .23898 L
.78847 .23291 L
.79193 .22319 L
.79544 .21348 L
.79623 .21126 L
.79865 .20377 L
.80209 .19406 L
.80557 .18434 L
.80594 .1833 L
.80873 .17463 L
.81216 .16492 L
.81561 .15521 L
.81566 .15507 L
.81873 .14549 L
.82214 .13578 L
.82537 .1266 L
.82552 .12607 L
.82863 .11636 L
.83203 .10664 L
.83508 .09788 L
.83535 .09693 L
.83845 .08722 L
.84182 .07751 L
.84479 .06891 L
.8451 .06779 L
.84819 .05808 L
.85153 .04837 L
.85451 .0397 L
.85479 .03866 L
.85784 .02894 L
.86116 .01923 L
Mfstroke
.2 g
.50486 .56856 m
.51317 .57284 L
.50668 .58256 L
.50486 .58513 L
.49949 .58256 L
.50313 .57284 L
F
0 g
.50486 .56856 m
.51317 .57284 L
.50668 .58256 L
.50486 .58513 L
.49949 .58256 L
.50313 .57284 L
.50486 .56856 L
s
.8 g
.68135 .01923 m
.67968 .02237 L
.67699 .02894 L
.67424 .03866 L
.66997 .04607 L
.66897 .04837 L
.66491 .05808 L
.66102 .06779 L
.66026 .06925 L
.65674 .07751 L
.65341 .08722 L
.65054 .09222 L
.64847 .09693 L
.64429 .10664 L
.64083 .11477 L
.6401 .11636 L
.63585 .12607 L
.63175 .13578 L
.63112 .13692 L
.62729 .14549 L
.6236 .15521 L
.62141 .15883 L
.6186 .16492 L
.61421 .17463 L
.61169 .18035 L
.60978 .18434 L
.60531 .19406 L
.60198 .20144 L
.60081 .20377 L
.59625 .21348 L
.59227 .22209 L
.59168 .22319 L
.58702 .23291 L
.58256 .24228 L
.58236 .24262 L
.5776 .25233 L
.57284 .26204 L
.57284 .26204 L
.56797 .27176 L
.56313 .28142 L
.56309 .28147 L
.5581 .29118 L
.55342 .3005 L
.55308 .30089 L
.54794 .31061 L
.54371 .31926 L
.54275 .32032 L
.53743 .33003 L
.53399 .33739 L
.53203 .33974 L
.52647 .34946 L
.52428 .35428 L
.52074 .35917 L
.51481 .36888 L
.51457 .3694 L
.50845 .37859 L
.50486 .38374 L
.5004 .37859 L
.50416 .36888 L
.50486 .36717 L
.50824 .35917 L
.51242 .34946 L
.51457 .34452 L
.51669 .33974 L
.52101 .33003 L
.52428 .32267 L
.52534 .32032 L
.52971 .31061 L
.53399 .30101 L
.53405 .30089 L
.53842 .29118 L
.54221 .28147 L
.54371 .27915 L
.54712 .27176 L
.55145 .26204 L
.55342 .25722 L
.55577 .25233 L
.56007 .24262 L
.56313 .23529 L
.56435 .23291 L
.56863 .22319 L
.57284 .21352 L
.57287 .21348 L
.57712 .20377 L
.58088 .19406 L
.58256 .19107 L
.58553 .18434 L
.58855 .17463 L
.59227 .16841 L
.59386 .16492 L
.598 .15521 L
.60198 .14576 L
.60211 .14549 L
.60623 .13578 L
.60988 .12607 L
.61169 .12262 L
.61437 .11636 L
.61723 .10664 L
.62141 .09926 L
.62243 .09693 L
.62645 .08722 L
.63026 .07751 L
.63112 .07576 L
.63441 .06779 L
.63756 .05808 L
.64083 .05184 L
.64229 .04837 L
.64425 .03866 L
.65001 .02894 L
.65054 .02793 L
.654 .01923 L
F
0 g
.68135 .01923 m
.67968 .02237 L
.67699 .02894 L
.67424 .03866 L
.66997 .04607 L
.66897 .04837 L
.66491 .05808 L
.66102 .06779 L
.66026 .06925 L
.65674 .07751 L
.65341 .08722 L
.65054 .09222 L
.64847 .09693 L
.64429 .10664 L
.64083 .11477 L
.6401 .11636 L
.63585 .12607 L
.63175 .13578 L
.63112 .13692 L
.62729 .14549 L
.6236 .15521 L
.62141 .15883 L
.6186 .16492 L
.61421 .17463 L
.61169 .18035 L
.60978 .18434 L
.60531 .19406 L
.60198 .20144 L
.60081 .20377 L
.59625 .21348 L
.59227 .22209 L
.59168 .22319 L
.58702 .23291 L
.58256 .24228 L
.58236 .24262 L
.5776 .25233 L
.57284 .26204 L
.57284 .26204 L
.56797 .27176 L
.56313 .28142 L
.56309 .28147 L
.5581 .29118 L
.55342 .3005 L
.55308 .30089 L
.54794 .31061 L
.54371 .31926 L
.54275 .32032 L
.53743 .33003 L
.53399 .33739 L
.53203 .33974 L
Mistroke
.52647 .34946 L
.52428 .35428 L
.52074 .35917 L
.51481 .36888 L
.51457 .3694 L
.50845 .37859 L
.50486 .38374 L
.5004 .37859 L
.50416 .36888 L
.50486 .36717 L
.50824 .35917 L
.51242 .34946 L
.51457 .34452 L
.51669 .33974 L
.52101 .33003 L
.52428 .32267 L
.52534 .32032 L
.52971 .31061 L
.53399 .30101 L
.53405 .30089 L
.53842 .29118 L
.54221 .28147 L
.54371 .27915 L
.54712 .27176 L
.55145 .26204 L
.55342 .25722 L
.55577 .25233 L
.56007 .24262 L
.56313 .23529 L
.56435 .23291 L
.56863 .22319 L
.57284 .21352 L
.57287 .21348 L
.57712 .20377 L
.58088 .19406 L
.58256 .19107 L
.58553 .18434 L
.58855 .17463 L
.59227 .16841 L
.59386 .16492 L
.598 .15521 L
.60198 .14576 L
.60211 .14549 L
.60623 .13578 L
.60988 .12607 L
.61169 .12262 L
.61437 .11636 L
.61723 .10664 L
.62141 .09926 L
.62243 .09693 L
Mistroke
.62645 .08722 L
.63026 .07751 L
.63112 .07576 L
.63441 .06779 L
.63756 .05808 L
.64083 .05184 L
.64229 .04837 L
.64425 .03866 L
.65001 .02894 L
.65054 .02793 L
.654 .01923 L
Mfstroke
.2 g
.50978 .98077 m
.50486 .97132 L
.50114 .98077 L
F
0 g
.50978 .98077 m
.50486 .97132 L
.50114 .98077 L
s
.2 g
.50486 .16578 m
.51018 .17463 L
.50486 .18236 L
.50136 .17463 L
F
0 g
.50486 .16578 m
.51018 .17463 L
.50486 .18236 L
.50136 .17463 L
.50486 .16578 L
s
.8 g
.50486 .76994 m
.51149 .77681 L
.50486 .78652 L
.50212 .77681 L
F
0 g
.50486 .76994 m
.51149 .77681 L
.50486 .78652 L
.50212 .77681 L
.50486 .76994 L
s
.2 g
.90024 .01923 m
.89545 .02894 L
.89336 .0342 L
.89188 .03866 L
.88869 .04837 L
.88601 .05808 L
.88364 .06392 L
.88235 .06779 L
.87913 .07751 L
.87646 .08722 L
.87393 .09339 L
.87273 .09693 L
.86949 .10664 L
.86681 .11636 L
.86422 .12261 L
.86304 .12607 L
.85977 .13578 L
.85705 .14549 L
.85451 .15159 L
.85326 .15521 L
.84996 .16492 L
.84718 .17463 L
.84479 .1803 L
.84339 .18434 L
.84007 .19406 L
.83718 .20377 L
.83508 .20876 L
.83343 .21348 L
.83209 .22319 L
.82707 .23291 L
.82537 .23696 L
.82338 .24262 L
.82173 .25233 L
.81685 .26204 L
.81566 .26489 L
.81322 .27176 L
.81124 .28147 L
.80651 .29118 L
.80594 .29255 L
.80297 .30089 L
.80063 .31061 L
.79623 .31995 L
.79609 .32032 L
.7926 .33003 L
.78992 .33974 L
.78652 .34711 L
.78565 .34946 L
.78213 .35917 L
.7791 .36888 L
.77681 .37397 L
.77509 .37859 L
.77344 .38831 L
.76821 .39802 L
.76709 .40054 L
.76441 .40773 L
.76207 .41744 L
.75738 .42682 L
.75725 .42716 L
.75361 .43687 L
.75068 .44658 L
.74767 .45287 L
.74635 .45629 L
.74268 .46601 L
.73928 .47572 L
.73796 .47858 L
.73532 .48543 L
.73286 .49514 L
.72824 .504 L
.7279 .50486 L
.72414 .51457 L
.72093 .52428 L
.71853 .52917 L
.71661 .53399 L
.71458 .54371 L
.70907 .55342 L
.70882 .55395 L
.70517 .56313 L
.70205 .57284 L
.69911 .57853 L
.69746 .58256 L
.69356 .59227 L
.68974 .60198 L
.68939 .60269 L
.68572 .61169 L
.68248 .62141 L
.67968 .62665 L
.6778 .63112 L
.6738 .64083 L
.66997 .65016 L
.6698 .65054 L
.66573 .66026 L
.66213 .66997 L
.66026 .67345 L
.65758 .67968 L
.65477 .68939 L
.65054 .69638 L
.64933 .69911 L
.64514 .70882 L
.641 .71853 L
.64083 .71884 L
.63671 .72824 L
.63295 .73796 L
.63112 .74112 L
.62817 .74767 L
.62505 .75738 L
.62141 .76301 L
.6195 .76709 L
.6151 .77681 L
.61169 .78449 L
.61069 .78652 L
.60622 .79623 L
.60198 .80548 L
.60174 .80594 L
.59718 .81566 L
.59275 .82537 L
.59227 .82613 L
.58797 .83508 L
.58368 .84479 L
.58256 .84643 L
.57857 .85451 L
.57381 .86422 L
.57284 .86629 L
.56896 .87393 L
.56409 .88364 L
.56313 .88566 L
.55912 .89336 L
.55411 .90307 L
.55342 .9045 L
.54899 .91278 L
.54383 .92249 L
.54371 .92274 L
.53852 .93221 L
.53399 .94042 L
.53315 .94192 L
.52761 .95163 L
.52428 .9574 L
.52193 .96134 L
.51603 .97106 L
.51457 .97343 L
.50497 .97106 L
.50908 .96134 L
.51328 .95163 L
.51457 .94867 L
.51757 .94192 L
.52189 .93221 L
.52428 .92501 L
.52623 .92249 L
.53059 .91278 L
.53399 .90391 L
.53494 .90307 L
.53931 .89336 L
.54362 .88364 L
.54371 .8835 L
.548 .87393 L
.55177 .86422 L
.55342 .86155 L
.55665 .85451 L
.56094 .84479 L
.56313 .8395 L
.56523 .83508 L
.5695 .82537 L
.57284 .81742 L
.57374 .81566 L
.57798 .80594 L
.58206 .79623 L
.58256 .79531 L
.58638 .78652 L
.58992 .77681 L
.59227 .77261 L
.59471 .76709 L
.59735 .75738 L
.60198 .74978 L
.60295 .74767 L
.60706 .73796 L
.61098 .72824 L
.61169 .72683 L
.61519 .71853 L
.61851 .70882 L
.62141 .70341 L
.62325 .69911 L
.62551 .68939 L
.63112 .67993 L
.63123 .67968 L
.63521 .66997 L
.6387 .66026 L
.64083 .65601 L
.64309 .65054 L
.64566 .64083 L
.65054 .63194 L
.65089 .63112 L
.65479 .62141 L
.65824 .61169 L
.66026 .60753 L
.6625 .60198 L
.66501 .59227 L
.66997 .58295 L
.67013 .58256 L
.67395 .57284 L
.67722 .56313 L
.67968 .55799 L
.68149 .55342 L
.68369 .54371 L
.6889 .53399 L
.68939 .53288 L
.69271 .52428 L
.69566 .51457 L
.69911 .50741 L
.70011 .50486 L
.7038 .49514 L
.70715 .48543 L
.70882 .48173 L
.71111 .47572 L
.7135 .46601 L
.71833 .45629 L
.71853 .45583 L
.72199 .44658 L
.72487 .43687 L
.72824 .42958 L
.72916 .42716 L
.73275 .41744 L
.73593 .40773 L
.73796 .40312 L
.73985 .39802 L
.74189 .38831 L
.74675 .37859 L
.74767 .37643 L
.75042 .36888 L
.75289 .35917 L
.75738 .34949 L
.75739 .34946 L
.76089 .33974 L
.76363 .33003 L
.76709 .32223 L
.76779 .32032 L
.77125 .31061 L
.77417 .30089 L
.77681 .29475 L
.77809 .29118 L
.77956 .28147 L
.78455 .27176 L
.78652 .26704 L
.78829 .26204 L
.79005 .25233 L
.79479 .24262 L
.79623 .23908 L
.79839 .23291 L
.80035 .22319 L
.8049 .21348 L
.80594 .21088 L
.8084 .20377 L
.81048 .19406 L
.8149 .18434 L
.81566 .18243 L
.81833 .17463 L
.82047 .16492 L
.8248 .15521 L
.82537 .15374 L
.82817 .14549 L
.83033 .13578 L
.83459 .12607 L
.83508 .12481 L
.83793 .11636 L
.84007 .10664 L
.8443 .09693 L
.84479 .09563 L
.8476 .08722 L
.84969 .07751 L
.85391 .06779 L
.85451 .06622 L
.85721 .05808 L
.8592 .04837 L
.86343 .03866 L
.86422 .03657 L
.86673 .02894 L
.86858 .01923 L
F
0 g
.90024 .01923 m
.89545 .02894 L
.89336 .0342 L
.89188 .03866 L
.88869 .04837 L
.88601 .05808 L
.88364 .06392 L
.88235 .06779 L
.87913 .07751 L
.87646 .08722 L
.87393 .09339 L
.87273 .09693 L
.86949 .10664 L
.86681 .11636 L
.86422 .12261 L
.86304 .12607 L
.85977 .13578 L
.85705 .14549 L
.85451 .15159 L
.85326 .15521 L
.84996 .16492 L
.84718 .17463 L
.84479 .1803 L
.84339 .18434 L
.84007 .19406 L
.83718 .20377 L
.83508 .20876 L
.83343 .21348 L
.83209 .22319 L
.82707 .23291 L
.82537 .23696 L
.82338 .24262 L
.82173 .25233 L
.81685 .26204 L
.81566 .26489 L
.81322 .27176 L
.81124 .28147 L
.80651 .29118 L
.80594 .29255 L
.80297 .30089 L
.80063 .31061 L
.79623 .31995 L
.79609 .32032 L
.7926 .33003 L
.78992 .33974 L
.78652 .34711 L
.78565 .34946 L
.78213 .35917 L
.7791 .36888 L
.77681 .37397 L
Mistroke
.77509 .37859 L
.77344 .38831 L
.76821 .39802 L
.76709 .40054 L
.76441 .40773 L
.76207 .41744 L
.75738 .42682 L
.75725 .42716 L
.75361 .43687 L
.75068 .44658 L
.74767 .45287 L
.74635 .45629 L
.74268 .46601 L
.73928 .47572 L
.73796 .47858 L
.73532 .48543 L
.73286 .49514 L
.72824 .504 L
.7279 .50486 L
.72414 .51457 L
.72093 .52428 L
.71853 .52917 L
.71661 .53399 L
.71458 .54371 L
.70907 .55342 L
.70882 .55395 L
.70517 .56313 L
.70205 .57284 L
.69911 .57853 L
.69746 .58256 L
.69356 .59227 L
.68974 .60198 L
.68939 .60269 L
.68572 .61169 L
.68248 .62141 L
.67968 .62665 L
.6778 .63112 L
.6738 .64083 L
.66997 .65016 L
.6698 .65054 L
.66573 .66026 L
.66213 .66997 L
.66026 .67345 L
.65758 .67968 L
.65477 .68939 L
.65054 .69638 L
.64933 .69911 L
.64514 .70882 L
.641 .71853 L
.64083 .71884 L
Mistroke
.63671 .72824 L
.63295 .73796 L
.63112 .74112 L
.62817 .74767 L
.62505 .75738 L
.62141 .76301 L
.6195 .76709 L
.6151 .77681 L
.61169 .78449 L
.61069 .78652 L
.60622 .79623 L
.60198 .80548 L
.60174 .80594 L
.59718 .81566 L
.59275 .82537 L
.59227 .82613 L
.58797 .83508 L
.58368 .84479 L
.58256 .84643 L
.57857 .85451 L
.57381 .86422 L
.57284 .86629 L
.56896 .87393 L
.56409 .88364 L
.56313 .88566 L
.55912 .89336 L
.55411 .90307 L
.55342 .9045 L
.54899 .91278 L
.54383 .92249 L
.54371 .92274 L
.53852 .93221 L
.53399 .94042 L
.53315 .94192 L
.52761 .95163 L
.52428 .9574 L
.52193 .96134 L
.51603 .97106 L
.51457 .97343 L
.50497 .97106 L
.50908 .96134 L
.51328 .95163 L
.51457 .94867 L
.51757 .94192 L
.52189 .93221 L
.52428 .92501 L
.52623 .92249 L
.53059 .91278 L
.53399 .90391 L
.53494 .90307 L
Mistroke
.53931 .89336 L
.54362 .88364 L
.54371 .8835 L
.548 .87393 L
.55177 .86422 L
.55342 .86155 L
.55665 .85451 L
.56094 .84479 L
.56313 .8395 L
.56523 .83508 L
.5695 .82537 L
.57284 .81742 L
.57374 .81566 L
.57798 .80594 L
.58206 .79623 L
.58256 .79531 L
.58638 .78652 L
.58992 .77681 L
.59227 .77261 L
.59471 .76709 L
.59735 .75738 L
.60198 .74978 L
.60295 .74767 L
.60706 .73796 L
.61098 .72824 L
.61169 .72683 L
.61519 .71853 L
.61851 .70882 L
.62141 .70341 L
.62325 .69911 L
.62551 .68939 L
.63112 .67993 L
.63123 .67968 L
.63521 .66997 L
.6387 .66026 L
.64083 .65601 L
.64309 .65054 L
.64566 .64083 L
.65054 .63194 L
.65089 .63112 L
.65479 .62141 L
.65824 .61169 L
.66026 .60753 L
.6625 .60198 L
.66501 .59227 L
.66997 .58295 L
.67013 .58256 L
.67395 .57284 L
.67722 .56313 L
.67968 .55799 L
Mistroke
.68149 .55342 L
.68369 .54371 L
.6889 .53399 L
.68939 .53288 L
.69271 .52428 L
.69566 .51457 L
.69911 .50741 L
.70011 .50486 L
.7038 .49514 L
.70715 .48543 L
.70882 .48173 L
.71111 .47572 L
.7135 .46601 L
.71833 .45629 L
.71853 .45583 L
.72199 .44658 L
.72487 .43687 L
.72824 .42958 L
.72916 .42716 L
.73275 .41744 L
.73593 .40773 L
.73796 .40312 L
.73985 .39802 L
.74189 .38831 L
.74675 .37859 L
.74767 .37643 L
.75042 .36888 L
.75289 .35917 L
.75738 .34949 L
.75739 .34946 L
.76089 .33974 L
.76363 .33003 L
.76709 .32223 L
.76779 .32032 L
.77125 .31061 L
.77417 .30089 L
.77681 .29475 L
.77809 .29118 L
.77956 .28147 L
.78455 .27176 L
.78652 .26704 L
.78829 .26204 L
.79005 .25233 L
.79479 .24262 L
.79623 .23908 L
.79839 .23291 L
.80035 .22319 L
.8049 .21348 L
.80594 .21088 L
.8084 .20377 L
Mistroke
.81048 .19406 L
.8149 .18434 L
.81566 .18243 L
.81833 .17463 L
.82047 .16492 L
.8248 .15521 L
.82537 .15374 L
.82817 .14549 L
.83033 .13578 L
.83459 .12607 L
.83508 .12481 L
.83793 .11636 L
.84007 .10664 L
.8443 .09693 L
.84479 .09563 L
.8476 .08722 L
.84969 .07751 L
.85391 .06779 L
.85451 .06622 L
.85721 .05808 L
.8592 .04837 L
.86343 .03866 L
.86422 .03657 L
.86673 .02894 L
.86858 .01923 L
Mfstroke
.2 g
.59316 .01923 m
.59227 .02052 L
.58826 .02894 L
.58414 .03866 L
.58256 .04093 L
.57887 .04837 L
.57411 .05808 L
.57284 .06079 L
.56927 .06779 L
.56439 .07751 L
.56313 .08017 L
.55943 .08722 L
.55442 .09693 L
.55342 .09902 L
.54931 .10664 L
.54415 .11636 L
.54371 .11726 L
.53885 .12607 L
.53399 .13489 L
.53349 .13578 L
.52795 .14549 L
.52428 .15186 L
.52229 .15521 L
.5164 .16492 L
.51457 .16789 L
.50522 .16492 L
.50934 .15521 L
.51354 .14549 L
.51457 .14203 L
.51784 .13578 L
.52215 .12607 L
.52428 .1198 L
.5265 .11636 L
.53086 .10664 L
.53399 .0984 L
.53521 .09693 L
.53958 .08722 L
.54371 .07767 L
.54392 .07751 L
.54827 .06779 L
.5522 .05808 L
.55342 .05607 L
.55691 .04837 L
.56016 .03866 L
.56313 .03399 L
.56549 .02894 L
.56976 .01923 L
F
0 g
.59316 .01923 m
.59227 .02052 L
.58826 .02894 L
.58414 .03866 L
.58256 .04093 L
.57887 .04837 L
.57411 .05808 L
.57284 .06079 L
.56927 .06779 L
.56439 .07751 L
.56313 .08017 L
.55943 .08722 L
.55442 .09693 L
.55342 .09902 L
.54931 .10664 L
.54415 .11636 L
.54371 .11726 L
.53885 .12607 L
.53399 .13489 L
.53349 .13578 L
.52795 .14549 L
.52428 .15186 L
.52229 .15521 L
.5164 .16492 L
.51457 .16789 L
.50522 .16492 L
.50934 .15521 L
.51354 .14549 L
.51457 .14203 L
.51784 .13578 L
.52215 .12607 L
.52428 .1198 L
.5265 .11636 L
.53086 .10664 L
.53399 .0984 L
.53521 .09693 L
.53958 .08722 L
.54371 .07767 L
.54392 .07751 L
.54827 .06779 L
.5522 .05808 L
.55342 .05607 L
.55691 .04837 L
.56016 .03866 L
.56313 .03399 L
.56549 .02894 L
.56976 .01923 L
s
.8 g
.83097 .01923 m
.82825 .02894 L
.82537 .03558 L
.82428 .03866 L
.82089 .04837 L
.81801 .05808 L
.81566 .06352 L
.81413 .06779 L
.8128 .07751 L
.80765 .08722 L
.80594 .09119 L
.80388 .09693 L
.8021 .10664 L
.79718 .11636 L
.79623 .11858 L
.79353 .12607 L
.7913 .13578 L
.7866 .14549 L
.78652 .14569 L
.78306 .15521 L
.78041 .16492 L
.77681 .17258 L
.77604 .17463 L
.77248 .18434 L
.76943 .19406 L
.76709 .19917 L
.76537 .20377 L
.76367 .21348 L
.75839 .22319 L
.75738 .22545 L
.75458 .23291 L
.75212 .24262 L
.74767 .25146 L
.74733 .25233 L
.74365 .26204 L
.74058 .27176 L
.73796 .27722 L
.7363 .28147 L
.73455 .29118 L
.72904 .30089 L
.72824 .30261 L
.72514 .31061 L
.72238 .32032 L
.71853 .32778 L
.71763 .33003 L
.71382 .33974 L
.71035 .34946 L
.70882 .3526 L
.70619 .35917 L
.70362 .36888 L
.69911 .37713 L
.6985 .37859 L
.69459 .38831 L
.69107 .39802 L
.68939 .40134 L
.68677 .40773 L
.68411 .41744 L
.67968 .42525 L
.67887 .42716 L
.67486 .43687 L
.67111 .44658 L
.66997 .44879 L
.66681 .45629 L
.66373 .46601 L
.66026 .47209 L
.65867 .47572 L
.65455 .48543 L
.65054 .49491 L
.65044 .49514 L
.64625 .50486 L
.64249 .51457 L
.64083 .51752 L
.63784 .52428 L
.63473 .53399 L
.63112 .53978 L
.62932 .54371 L
.625 .55342 L
.62141 .5616 L
.62067 .56313 L
.61627 .57284 L
.61194 .58256 L
.61169 .58297 L
.60741 .59227 L
.60332 .60198 L
.60198 .60411 L
.59839 .61169 L
.59464 .62141 L
.59227 .62485 L
.5892 .63112 L
.58455 .64083 L
.58256 .64517 L
.57983 .65054 L
.57508 .66026 L
.57284 .66504 L
.57026 .66997 L
.56538 .67968 L
.56313 .68445 L
.56045 .68939 L
.55544 .69911 L
.55342 .70335 L
.55036 .70882 L
.5452 .71853 L
.54371 .72163 L
.53993 .72824 L
.53459 .73796 L
.53399 .73917 L
.52909 .74767 L
.52428 .75602 L
.52347 .75738 L
.51761 .76709 L
.51457 .77204 L
.50605 .76709 L
.51019 .75738 L
.5144 .74767 L
.51457 .74717 L
.51872 .73796 L
.52303 .72824 L
.52428 .72477 L
.52739 .71853 L
.53174 .70882 L
.53399 .70291 L
.53611 .69911 L
.54046 .68939 L
.54371 .68139 L
.54481 .67968 L
.54915 .66997 L
.55342 .66031 L
.55346 .66026 L
.55779 .65054 L
.56163 .64083 L
.56313 .63828 L
.56637 .63112 L
.56948 .62141 L
.57284 .61604 L
.57487 .61169 L
.5791 .60198 L
.58256 .59376 L
.58329 .59227 L
.58749 .58256 L
.59147 .57284 L
.59227 .57133 L
.59581 .56313 L
.59918 .55342 L
.60198 .5484 L
.60405 .54371 L
.60642 .53399 L
.61169 .52539 L
.6122 .52428 L
.61627 .51457 L
.62 .50486 L
.62141 .50208 L
.62432 .49514 L
.62731 .48543 L
.63112 .47845 L
.63229 .47572 L
.63626 .46601 L
.64005 .45629 L
.64083 .45468 L
.64414 .44658 L
.64727 .43687 L
.65054 .4305 L
.65193 .42716 L
.65384 .41744 L
.65954 .40773 L
.66026 .4062 L
.66352 .39802 L
.66656 .38831 L
.66997 .3815 L
.67115 .37859 L
.67288 .36888 L
.67852 .35917 L
.67968 .35664 L
.6825 .34946 L
.68526 .33974 L
.68939 .33146 L
.68997 .33003 L
.6937 .32032 L
.69699 .31061 L
.69911 .30602 L
.70109 .30089 L
.70333 .29118 L
.70835 .28147 L
.70882 .28039 L
.71208 .27176 L
.71493 .26204 L
.71853 .2544 L
.71933 .25233 L
.72295 .24262 L
.72615 .23291 L
.72824 .22819 L
.73012 .22319 L
.73219 .21348 L
.7371 .20377 L
.73796 .20176 L
.74079 .19406 L
.74333 .18434 L
.74767 .17506 L
.74783 .17463 L
.75136 .16492 L
.7542 .15521 L
.75738 .14806 L
.75832 .14549 L
.76181 .13578 L
.76485 .12607 L
.76709 .12083 L
.76871 .11636 L
.77046 .10664 L
.77533 .09693 L
.77681 .09338 L
.779 .08722 L
.78106 .07751 L
.78566 .06779 L
.78652 .06567 L
.78919 .05808 L
.79145 .04837 L
.79586 .03866 L
.79623 .03772 L
.79929 .02894 L
.80168 .01923 L
F
0 g
.83097 .01923 m
.82825 .02894 L
.82537 .03558 L
.82428 .03866 L
.82089 .04837 L
.81801 .05808 L
.81566 .06352 L
.81413 .06779 L
.8128 .07751 L
.80765 .08722 L
.80594 .09119 L
.80388 .09693 L
.8021 .10664 L
.79718 .11636 L
.79623 .11858 L
.79353 .12607 L
.7913 .13578 L
.7866 .14549 L
.78652 .14569 L
.78306 .15521 L
.78041 .16492 L
.77681 .17258 L
.77604 .17463 L
.77248 .18434 L
.76943 .19406 L
.76709 .19917 L
.76537 .20377 L
.76367 .21348 L
.75839 .22319 L
.75738 .22545 L
.75458 .23291 L
.75212 .24262 L
.74767 .25146 L
.74733 .25233 L
.74365 .26204 L
.74058 .27176 L
.73796 .27722 L
.7363 .28147 L
.73455 .29118 L
.72904 .30089 L
.72824 .30261 L
.72514 .31061 L
.72238 .32032 L
.71853 .32778 L
.71763 .33003 L
.71382 .33974 L
.71035 .34946 L
.70882 .3526 L
.70619 .35917 L
.70362 .36888 L
Mistroke
.69911 .37713 L
.6985 .37859 L
.69459 .38831 L
.69107 .39802 L
.68939 .40134 L
.68677 .40773 L
.68411 .41744 L
.67968 .42525 L
.67887 .42716 L
.67486 .43687 L
.67111 .44658 L
.66997 .44879 L
.66681 .45629 L
.66373 .46601 L
.66026 .47209 L
.65867 .47572 L
.65455 .48543 L
.65054 .49491 L
.65044 .49514 L
.64625 .50486 L
.64249 .51457 L
.64083 .51752 L
.63784 .52428 L
.63473 .53399 L
.63112 .53978 L
.62932 .54371 L
.625 .55342 L
.62141 .5616 L
.62067 .56313 L
.61627 .57284 L
.61194 .58256 L
.61169 .58297 L
.60741 .59227 L
.60332 .60198 L
.60198 .60411 L
.59839 .61169 L
.59464 .62141 L
.59227 .62485 L
.5892 .63112 L
.58455 .64083 L
.58256 .64517 L
.57983 .65054 L
.57508 .66026 L
.57284 .66504 L
.57026 .66997 L
.56538 .67968 L
.56313 .68445 L
.56045 .68939 L
.55544 .69911 L
.55342 .70335 L
Mistroke
.55036 .70882 L
.5452 .71853 L
.54371 .72163 L
.53993 .72824 L
.53459 .73796 L
.53399 .73917 L
.52909 .74767 L
.52428 .75602 L
.52347 .75738 L
.51761 .76709 L
.51457 .77204 L
.50605 .76709 L
.51019 .75738 L
.5144 .74767 L
.51457 .74717 L
.51872 .73796 L
.52303 .72824 L
.52428 .72477 L
.52739 .71853 L
.53174 .70882 L
.53399 .70291 L
.53611 .69911 L
.54046 .68939 L
.54371 .68139 L
.54481 .67968 L
.54915 .66997 L
.55342 .66031 L
.55346 .66026 L
.55779 .65054 L
.56163 .64083 L
.56313 .63828 L
.56637 .63112 L
.56948 .62141 L
.57284 .61604 L
.57487 .61169 L
.5791 .60198 L
.58256 .59376 L
.58329 .59227 L
.58749 .58256 L
.59147 .57284 L
.59227 .57133 L
.59581 .56313 L
.59918 .55342 L
.60198 .5484 L
.60405 .54371 L
.60642 .53399 L
.61169 .52539 L
.6122 .52428 L
.61627 .51457 L
.62 .50486 L
Mistroke
.62141 .50208 L
.62432 .49514 L
.62731 .48543 L
.63112 .47845 L
.63229 .47572 L
.63626 .46601 L
.64005 .45629 L
.64083 .45468 L
.64414 .44658 L
.64727 .43687 L
.65054 .4305 L
.65193 .42716 L
.65384 .41744 L
.65954 .40773 L
.66026 .4062 L
.66352 .39802 L
.66656 .38831 L
.66997 .3815 L
.67115 .37859 L
.67288 .36888 L
.67852 .35917 L
.67968 .35664 L
.6825 .34946 L
.68526 .33974 L
.68939 .33146 L
.68997 .33003 L
.6937 .32032 L
.69699 .31061 L
.69911 .30602 L
.70109 .30089 L
.70333 .29118 L
.70835 .28147 L
.70882 .28039 L
.71208 .27176 L
.71493 .26204 L
.71853 .2544 L
.71933 .25233 L
.72295 .24262 L
.72615 .23291 L
.72824 .22819 L
.73012 .22319 L
.73219 .21348 L
.7371 .20377 L
.73796 .20176 L
.74079 .19406 L
.74333 .18434 L
.74767 .17506 L
.74783 .17463 L
.75136 .16492 L
.7542 .15521 L
Mistroke
.75738 .14806 L
.75832 .14549 L
.76181 .13578 L
.76485 .12607 L
.76709 .12083 L
.76871 .11636 L
.77046 .10664 L
.77533 .09693 L
.77681 .09338 L
.779 .08722 L
.78106 .07751 L
.78566 .06779 L
.78652 .06567 L
.78919 .05808 L
.79145 .04837 L
.79586 .03866 L
.79623 .03772 L
.79929 .02894 L
.80168 .01923 L
Mfstroke
.2 g
.75962 .01923 m
.75738 .024 L
.75554 .02894 L
.75371 .03866 L
.74843 .04837 L
.74767 .05007 L
.74463 .05808 L
.74199 .06779 L
.73796 .07582 L
.73729 .07751 L
.73357 .08722 L
.73032 .09693 L
.72824 .10126 L
.72614 .10664 L
.72399 .11636 L
.71866 .12607 L
.71853 .12634 L
.71483 .13578 L
.71173 .14549 L
.70882 .15124 L
.70722 .15521 L
.70336 .16492 L
.69963 .17463 L
.69911 .17571 L
.69563 .18434 L
.69253 .19406 L
.68939 .19998 L
.68782 .20377 L
.68387 .21348 L
.67999 .22319 L
.67968 .22381 L
.67592 .23291 L
.67259 .24262 L
.66997 .24745 L
.66789 .25233 L
.66558 .26204 L
.66026 .27066 L
.65977 .27176 L
.65565 .28147 L
.65183 .29118 L
.65054 .29356 L
.64736 .30089 L
.64417 .31061 L
.64083 .31618 L
.63897 .32032 L
.63472 .33003 L
.63112 .33836 L
.63046 .33974 L
.62614 .34946 L
.62196 .35917 L
.62141 .36014 L
.61744 .36888 L
.6136 .37859 L
.61169 .38167 L
.60859 .38831 L
.60528 .39802 L
.60198 .40281 L
.5996 .40773 L
.59504 .41744 L
.59227 .42354 L
.59044 .42716 L
.58578 .43687 L
.58256 .44384 L
.5811 .44658 L
.57634 .45629 L
.57284 .46371 L
.57155 .46601 L
.56668 .47572 L
.56313 .48315 L
.56177 .48543 L
.55677 .49514 L
.55342 .50214 L
.55172 .50486 L
.54657 .51457 L
.54371 .52057 L
.54135 .52428 L
.53602 .53399 L
.53399 .53824 L
.53056 .54371 L
.52498 .55342 L
.52428 .55486 L
.51918 .56313 L
.51457 .57066 L
.50714 .56313 L
.5113 .55342 L
.51457 .54591 L
.51554 .54371 L
.51986 .53399 L
.52418 .52428 L
.52428 .52401 L
.52855 .51457 L
.5329 .50486 L
.53399 .50205 L
.53727 .49514 L
.54162 .48543 L
.54371 .48021 L
.54596 .47572 L
.5503 .46601 L
.55342 .45847 L
.55462 .45629 L
.55893 .44658 L
.56313 .43699 L
.56321 .43687 L
.5675 .42716 L
.57133 .41744 L
.57284 .41479 L
.57599 .40773 L
.57911 .39802 L
.58256 .39235 L
.58441 .38831 L
.5886 .37859 L
.59227 .36987 L
.59275 .36888 L
.59691 .35917 L
.60075 .34946 L
.60198 .3471 L
.60514 .33974 L
.60829 .33003 L
.61169 .32395 L
.61329 .32032 L
.61734 .31061 L
.62135 .30089 L
.62141 .30077 L
.62539 .29118 L
.62887 .28147 L
.63112 .27708 L
.63335 .27176 L
.63591 .26204 L
.64083 .25327 L
.64124 .25233 L
.64518 .24262 L
.6487 .23291 L
.65054 .22914 L
.65297 .22319 L
.65562 .21348 L
.66026 .20479 L
.66069 .20377 L
.66454 .19406 L
.66795 .18434 L
.66997 .18013 L
.67216 .17463 L
.67462 .16492 L
.67968 .15529 L
.67972 .15521 L
.68349 .14549 L
.68667 .13578 L
.68939 .13006 L
.69096 .12607 L
.69296 .11636 L
.69823 .10664 L
.69911 .10467 L
.70207 .09693 L
.70483 .08722 L
.70882 .07897 L
.70939 .07751 L
.71305 .06779 L
.71623 .05808 L
.71853 .05301 L
.72029 .04837 L
.72233 .03866 L
.72733 .02894 L
.72824 .02697 L
.73107 .01923 L
F
0 g
.75962 .01923 m
.75738 .024 L
.75554 .02894 L
.75371 .03866 L
.74843 .04837 L
.74767 .05007 L
.74463 .05808 L
.74199 .06779 L
.73796 .07582 L
.73729 .07751 L
.73357 .08722 L
.73032 .09693 L
.72824 .10126 L
.72614 .10664 L
.72399 .11636 L
.71866 .12607 L
.71853 .12634 L
.71483 .13578 L
.71173 .14549 L
.70882 .15124 L
.70722 .15521 L
.70336 .16492 L
.69963 .17463 L
.69911 .17571 L
.69563 .18434 L
.69253 .19406 L
.68939 .19998 L
.68782 .20377 L
.68387 .21348 L
.67999 .22319 L
.67968 .22381 L
.67592 .23291 L
.67259 .24262 L
.66997 .24745 L
.66789 .25233 L
.66558 .26204 L
.66026 .27066 L
.65977 .27176 L
.65565 .28147 L
.65183 .29118 L
.65054 .29356 L
.64736 .30089 L
.64417 .31061 L
.64083 .31618 L
.63897 .32032 L
.63472 .33003 L
.63112 .33836 L
.63046 .33974 L
.62614 .34946 L
.62196 .35917 L
Mistroke
.62141 .36014 L
.61744 .36888 L
.6136 .37859 L
.61169 .38167 L
.60859 .38831 L
.60528 .39802 L
.60198 .40281 L
.5996 .40773 L
.59504 .41744 L
.59227 .42354 L
.59044 .42716 L
.58578 .43687 L
.58256 .44384 L
.5811 .44658 L
.57634 .45629 L
.57284 .46371 L
.57155 .46601 L
.56668 .47572 L
.56313 .48315 L
.56177 .48543 L
.55677 .49514 L
.55342 .50214 L
.55172 .50486 L
.54657 .51457 L
.54371 .52057 L
.54135 .52428 L
.53602 .53399 L
.53399 .53824 L
.53056 .54371 L
.52498 .55342 L
.52428 .55486 L
.51918 .56313 L
.51457 .57066 L
.50714 .56313 L
.5113 .55342 L
.51457 .54591 L
.51554 .54371 L
.51986 .53399 L
.52418 .52428 L
.52428 .52401 L
.52855 .51457 L
.5329 .50486 L
.53399 .50205 L
.53727 .49514 L
.54162 .48543 L
.54371 .48021 L
.54596 .47572 L
.5503 .46601 L
.55342 .45847 L
.55462 .45629 L
Mistroke
.55893 .44658 L
.56313 .43699 L
.56321 .43687 L
.5675 .42716 L
.57133 .41744 L
.57284 .41479 L
.57599 .40773 L
.57911 .39802 L
.58256 .39235 L
.58441 .38831 L
.5886 .37859 L
.59227 .36987 L
.59275 .36888 L
.59691 .35917 L
.60075 .34946 L
.60198 .3471 L
.60514 .33974 L
.60829 .33003 L
.61169 .32395 L
.61329 .32032 L
.61734 .31061 L
.62135 .30089 L
.62141 .30077 L
.62539 .29118 L
.62887 .28147 L
.63112 .27708 L
.63335 .27176 L
.63591 .26204 L
.64083 .25327 L
.64124 .25233 L
.64518 .24262 L
.6487 .23291 L
.65054 .22914 L
.65297 .22319 L
.65562 .21348 L
.66026 .20479 L
.66069 .20377 L
.66454 .19406 L
.66795 .18434 L
.66997 .18013 L
.67216 .17463 L
.67462 .16492 L
.67968 .15529 L
.67972 .15521 L
.68349 .14549 L
.68667 .13578 L
.68939 .13006 L
.69096 .12607 L
.69296 .11636 L
.69823 .10664 L
Mistroke
.69911 .10467 L
.70207 .09693 L
.70483 .08722 L
.70882 .07897 L
.70939 .07751 L
.71305 .06779 L
.71623 .05808 L
.71853 .05301 L
.72029 .04837 L
.72233 .03866 L
.72733 .02894 L
.72824 .02697 L
.73107 .01923 L
Mfstroke
.4 g
.53569 .98077 m
.54068 .97106 L
.54371 .96477 L
.54545 .96134 L
.55034 .95163 L
.55342 .94512 L
.55502 .94192 L
.55983 .93221 L
.56313 .9251 L
.56441 .92249 L
.56915 .91278 L
.57284 .90472 L
.57364 .90307 L
.57831 .89336 L
.58256 .88398 L
.58272 .88364 L
.58732 .87393 L
.59171 .86422 L
.59227 .86289 L
.59619 .85451 L
.60058 .84479 L
.60198 .84146 L
.60492 .83508 L
.60931 .82537 L
.61169 .81969 L
.61352 .81566 L
.61789 .80594 L
.62141 .79758 L
.62201 .79623 L
.62634 .78652 L
.63047 .77681 L
.63112 .77515 L
.63467 .76709 L
.63885 .75738 L
.64083 .75239 L
.64288 .74767 L
.64708 .73796 L
.65054 .72931 L
.651 .72824 L
.65517 .71853 L
.65917 .70882 L
.66026 .70593 L
.66315 .69911 L
.66721 .68939 L
.66997 .68223 L
.67103 .67968 L
.6751 .66997 L
.67895 .66026 L
.67968 .65823 L
.68286 .65054 L
.68682 .64083 L
.68939 .63393 L
.69054 .63112 L
.69451 .62141 L
.69828 .61169 L
.69911 .60933 L
.70208 .60198 L
.70596 .59227 L
.70882 .58444 L
.70957 .58256 L
.71345 .57284 L
.71719 .56313 L
.71853 .55926 L
.72084 .55342 L
.72466 .54371 L
.72818 .53399 L
.72824 .53379 L
.73197 .52428 L
.7357 .51457 L
.73796 .50805 L
.73919 .50486 L
.74295 .49514 L
.74655 .48543 L
.74767 .48202 L
.75008 .47572 L
.75379 .46601 L
.7572 .45629 L
.75738 .45571 L
.76085 .44658 L
.76449 .43687 L
.76709 .42913 L
.76783 .42716 L
.77149 .41744 L
.77504 .40773 L
.77681 .40229 L
.77839 .39802 L
.78201 .38831 L
.78546 .37859 L
.78652 .37517 L
.78884 .36888 L
.79242 .35917 L
.79574 .34946 L
.79623 .34779 L
.79917 .33974 L
.80271 .33003 L
.80589 .32032 L
.80594 .32014 L
.8094 .31061 L
.81289 .30089 L
.81566 .29224 L
.81603 .29118 L
.81953 .28147 L
.82297 .27176 L
.82537 .26408 L
.82609 .26204 L
.82956 .25233 L
.83295 .24262 L
.83508 .23566 L
.83605 .23291 L
.83949 .22319 L
.84285 .21348 L
.84479 .207 L
.84592 .20377 L
.84934 .19406 L
.85266 .18434 L
.85451 .17808 L
.8557 .17463 L
.85909 .16492 L
.86238 .15521 L
.86422 .14891 L
.86539 .14549 L
.86876 .13578 L
.87203 .12607 L
.87393 .1195 L
.875 .11636 L
.87834 .10664 L
.8816 .09693 L
.88364 .08984 L
.88453 .08722 L
.88784 .07751 L
.8911 .06779 L
.89336 .05994 L
.89398 .05808 L
.89727 .04837 L
.90051 .03866 L
.90307 .02981 L
.90335 .02894 L
.90661 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.53569 .98077 m
.54068 .97106 L
.54371 .96477 L
.54545 .96134 L
.55034 .95163 L
.55342 .94512 L
.55502 .94192 L
.55983 .93221 L
.56313 .9251 L
.56441 .92249 L
.56915 .91278 L
.57284 .90472 L
.57364 .90307 L
.57831 .89336 L
.58256 .88398 L
.58272 .88364 L
.58732 .87393 L
.59171 .86422 L
.59227 .86289 L
.59619 .85451 L
.60058 .84479 L
.60198 .84146 L
.60492 .83508 L
.60931 .82537 L
.61169 .81969 L
.61352 .81566 L
.61789 .80594 L
.62141 .79758 L
.62201 .79623 L
.62634 .78652 L
.63047 .77681 L
.63112 .77515 L
.63467 .76709 L
.63885 .75738 L
.64083 .75239 L
.64288 .74767 L
.64708 .73796 L
.65054 .72931 L
.651 .72824 L
.65517 .71853 L
.65917 .70882 L
.66026 .70593 L
.66315 .69911 L
.66721 .68939 L
.66997 .68223 L
.67103 .67968 L
.6751 .66997 L
.67895 .66026 L
.67968 .65823 L
.68286 .65054 L
Mistroke
.68682 .64083 L
.68939 .63393 L
.69054 .63112 L
.69451 .62141 L
.69828 .61169 L
.69911 .60933 L
.70208 .60198 L
.70596 .59227 L
.70882 .58444 L
.70957 .58256 L
.71345 .57284 L
.71719 .56313 L
.71853 .55926 L
.72084 .55342 L
.72466 .54371 L
.72818 .53399 L
.72824 .53379 L
.73197 .52428 L
.7357 .51457 L
.73796 .50805 L
.73919 .50486 L
.74295 .49514 L
.74655 .48543 L
.74767 .48202 L
.75008 .47572 L
.75379 .46601 L
.7572 .45629 L
.75738 .45571 L
.76085 .44658 L
.76449 .43687 L
.76709 .42913 L
.76783 .42716 L
.77149 .41744 L
.77504 .40773 L
.77681 .40229 L
.77839 .39802 L
.78201 .38831 L
.78546 .37859 L
.78652 .37517 L
.78884 .36888 L
.79242 .35917 L
.79574 .34946 L
.79623 .34779 L
.79917 .33974 L
.80271 .33003 L
.80589 .32032 L
.80594 .32014 L
.8094 .31061 L
.81289 .30089 L
.81566 .29224 L
Mistroke
.81603 .29118 L
.81953 .28147 L
.82297 .27176 L
.82537 .26408 L
.82609 .26204 L
.82956 .25233 L
.83295 .24262 L
.83508 .23566 L
.83605 .23291 L
.83949 .22319 L
.84285 .21348 L
.84479 .207 L
.84592 .20377 L
.84934 .19406 L
.85266 .18434 L
.85451 .17808 L
.8557 .17463 L
.85909 .16492 L
.86238 .15521 L
.86422 .14891 L
.86539 .14549 L
.86876 .13578 L
.87203 .12607 L
.87393 .1195 L
.875 .11636 L
.87834 .10664 L
.8816 .09693 L
.88364 .08984 L
.88453 .08722 L
.88784 .07751 L
.8911 .06779 L
.89336 .05994 L
.89398 .05808 L
.89727 .04837 L
.90051 .03866 L
.90307 .02981 L
.90335 .02894 L
.90661 .01923 L
Mfstroke
.5 g
.54898 .98077 m
.55342 .97158 L
.55367 .97106 L
.55836 .96134 L
.56297 .95163 L
.56313 .95129 L
.56758 .94192 L
.57213 .93221 L
.57284 .93065 L
.57665 .92249 L
.58114 .91278 L
.58256 .90966 L
.58559 .90307 L
.59002 .89336 L
.59227 .88834 L
.5944 .88364 L
.59877 .87393 L
.60198 .86668 L
.60308 .86422 L
.6074 .85451 L
.61165 .84479 L
.61169 .84469 L
.61591 .83508 L
.62013 .82537 L
.62141 .82237 L
.62432 .81566 L
.6285 .80594 L
.63112 .79974 L
.63262 .79623 L
.63676 .78652 L
.64082 .77681 L
.64083 .77679 L
.64492 .76709 L
.64897 .75738 L
.65054 .75353 L
.65298 .74767 L
.65701 .73796 L
.66026 .72996 L
.66096 .72824 L
.66495 .71853 L
.66888 .70882 L
.66997 .70609 L
.6728 .69911 L
.67672 .68939 L
.67968 .68192 L
.68058 .67968 L
.68447 .66997 L
.68831 .66026 L
.68939 .65746 L
.69213 .65054 L
.69597 .64083 L
.69911 .6327 L
.69973 .63112 L
.70353 .62141 L
.70729 .61169 L
.70882 .60766 L
.71102 .60198 L
.71477 .59227 L
.71845 .58256 L
.71853 .58233 L
.72216 .57284 L
.72586 .56313 L
.72824 .55672 L
.72949 .55342 L
.73317 .54371 L
.7368 .53399 L
.73796 .53083 L
.74041 .52428 L
.74405 .51457 L
.7476 .50486 L
.74767 .50467 L
.7512 .49514 L
.75479 .48543 L
.75738 .47823 L
.7583 .47572 L
.76187 .46601 L
.7654 .45629 L
.76709 .45153 L
.76889 .44658 L
.77242 .43687 L
.7759 .42716 L
.77681 .42455 L
.77937 .41744 L
.78286 .40773 L
.78628 .39802 L
.78652 .39732 L
.78973 .38831 L
.79319 .37859 L
.79623 .36982 L
.79656 .36888 L
.8 .35917 L
.80341 .34946 L
.80594 .34206 L
.80675 .33974 L
.81016 .33003 L
.81354 .32032 L
.81566 .31404 L
.81685 .31061 L
.82022 .30089 L
.82356 .29118 L
.82537 .28577 L
.82685 .28147 L
.83019 .27176 L
.8335 .26204 L
.83508 .25725 L
.83675 .25233 L
.84007 .24262 L
.84335 .23291 L
.84479 .22848 L
.84658 .22319 L
.84987 .21348 L
.85311 .20377 L
.85451 .19946 L
.85631 .19406 L
.85958 .18434 L
.8628 .17463 L
.86422 .17019 L
.86597 .16492 L
.86921 .15521 L
.8724 .14549 L
.87393 .14068 L
.87554 .13578 L
.87876 .12607 L
.88193 .11636 L
.88364 .11093 L
.88504 .10664 L
.88823 .09693 L
.89139 .08722 L
.89336 .08094 L
.89447 .07751 L
.89763 .06779 L
.90077 .05808 L
.90307 .05071 L
.90382 .04837 L
.90695 .03866 L
.91008 .02894 L
.91278 .02024 L
.9131 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.54898 .98077 m
.55342 .97158 L
.55367 .97106 L
.55836 .96134 L
.56297 .95163 L
.56313 .95129 L
.56758 .94192 L
.57213 .93221 L
.57284 .93065 L
.57665 .92249 L
.58114 .91278 L
.58256 .90966 L
.58559 .90307 L
.59002 .89336 L
.59227 .88834 L
.5944 .88364 L
.59877 .87393 L
.60198 .86668 L
.60308 .86422 L
.6074 .85451 L
.61165 .84479 L
.61169 .84469 L
.61591 .83508 L
.62013 .82537 L
.62141 .82237 L
.62432 .81566 L
.6285 .80594 L
.63112 .79974 L
.63262 .79623 L
.63676 .78652 L
.64082 .77681 L
.64083 .77679 L
.64492 .76709 L
.64897 .75738 L
.65054 .75353 L
.65298 .74767 L
.65701 .73796 L
.66026 .72996 L
.66096 .72824 L
.66495 .71853 L
.66888 .70882 L
.66997 .70609 L
.6728 .69911 L
.67672 .68939 L
.67968 .68192 L
.68058 .67968 L
.68447 .66997 L
.68831 .66026 L
.68939 .65746 L
.69213 .65054 L
Mistroke
.69597 .64083 L
.69911 .6327 L
.69973 .63112 L
.70353 .62141 L
.70729 .61169 L
.70882 .60766 L
.71102 .60198 L
.71477 .59227 L
.71845 .58256 L
.71853 .58233 L
.72216 .57284 L
.72586 .56313 L
.72824 .55672 L
.72949 .55342 L
.73317 .54371 L
.7368 .53399 L
.73796 .53083 L
.74041 .52428 L
.74405 .51457 L
.7476 .50486 L
.74767 .50467 L
.7512 .49514 L
.75479 .48543 L
.75738 .47823 L
.7583 .47572 L
.76187 .46601 L
.7654 .45629 L
.76709 .45153 L
.76889 .44658 L
.77242 .43687 L
.7759 .42716 L
.77681 .42455 L
.77937 .41744 L
.78286 .40773 L
.78628 .39802 L
.78652 .39732 L
.78973 .38831 L
.79319 .37859 L
.79623 .36982 L
.79656 .36888 L
.8 .35917 L
.80341 .34946 L
.80594 .34206 L
.80675 .33974 L
.81016 .33003 L
.81354 .32032 L
.81566 .31404 L
.81685 .31061 L
.82022 .30089 L
.82356 .29118 L
Mistroke
.82537 .28577 L
.82685 .28147 L
.83019 .27176 L
.8335 .26204 L
.83508 .25725 L
.83675 .25233 L
.84007 .24262 L
.84335 .23291 L
.84479 .22848 L
.84658 .22319 L
.84987 .21348 L
.85311 .20377 L
.85451 .19946 L
.85631 .19406 L
.85958 .18434 L
.8628 .17463 L
.86422 .17019 L
.86597 .16492 L
.86921 .15521 L
.8724 .14549 L
.87393 .14068 L
.87554 .13578 L
.87876 .12607 L
.88193 .11636 L
.88364 .11093 L
.88504 .10664 L
.88823 .09693 L
.89139 .08722 L
.89336 .08094 L
.89447 .07751 L
.89763 .06779 L
.90077 .05808 L
.90307 .05071 L
.90382 .04837 L
.90695 .03866 L
.91008 .02894 L
.91278 .02024 L
.9131 .01923 L
Mfstroke
.6 g
.56063 .98077 m
.56313 .97546 L
.56518 .97106 L
.56972 .96134 L
.57284 .95461 L
.57421 .95163 L
.57868 .94192 L
.58256 .93343 L
.58311 .93221 L
.5875 .92249 L
.59188 .91278 L
.59227 .91192 L
.59621 .90307 L
.60053 .89336 L
.60198 .89008 L
.6048 .88364 L
.60907 .87393 L
.61169 .86792 L
.61329 .86422 L
.6175 .85451 L
.62141 .84544 L
.62168 .84479 L
.62582 .83508 L
.62996 .82537 L
.63112 .82264 L
.63405 .81566 L
.63815 .80594 L
.64083 .79954 L
.6422 .79623 L
.64623 .78652 L
.65026 .77681 L
.65054 .77613 L
.65424 .76709 L
.65823 .75738 L
.66026 .75241 L
.66217 .74767 L
.66611 .73796 L
.66997 .7284 L
.67003 .72824 L
.67391 .71853 L
.6778 .70882 L
.67968 .7041 L
.68164 .69911 L
.68549 .68939 L
.68932 .67968 L
.68939 .6795 L
.6931 .66997 L
.69691 .66026 L
.69911 .65462 L
.70067 .65054 L
.70442 .64083 L
.70818 .63112 L
.70882 .62945 L
.71187 .62141 L
.7156 .61169 L
.71853 .604 L
.71928 .60198 L
.72295 .59227 L
.72663 .58256 L
.72824 .57827 L
.73025 .57284 L
.73389 .56313 L
.73753 .55342 L
.73796 .55227 L
.7411 .54371 L
.74471 .53399 L
.74767 .52599 L
.74828 .52428 L
.75183 .51457 L
.75541 .50486 L
.75738 .49945 L
.75892 .49514 L
.76245 .48543 L
.76598 .47572 L
.76709 .47263 L
.76945 .46601 L
.77295 .45629 L
.77644 .44658 L
.77681 .44556 L
.77987 .43687 L
.78334 .42716 L
.78652 .41822 L
.78679 .41744 L
.79019 .40773 L
.79363 .39802 L
.79623 .39062 L
.79702 .38831 L
.8004 .37859 L
.80381 .36888 L
.80594 .36276 L
.80716 .35917 L
.81052 .34946 L
.8139 .33974 L
.81566 .33465 L
.81721 .33003 L
.82055 .32032 L
.8239 .31061 L
.82537 .30629 L
.82717 .30089 L
.83048 .29118 L
.8338 .28147 L
.83508 .27768 L
.83704 .27176 L
.84033 .26204 L
.84362 .25233 L
.84479 .24882 L
.84683 .24262 L
.85009 .23291 L
.85335 .22319 L
.85451 .21971 L
.85653 .21348 L
.85976 .20377 L
.863 .19406 L
.86422 .19036 L
.86616 .18434 L
.86936 .17463 L
.87257 .16492 L
.87393 .16076 L
.8757 .15521 L
.87888 .14549 L
.88207 .13578 L
.88364 .13093 L
.88518 .12607 L
.88832 .11636 L
.89149 .10664 L
.89336 .10086 L
.89458 .09693 L
.8977 .08722 L
.90084 .07751 L
.90307 .07055 L
.90392 .06779 L
.907 .05808 L
.91012 .04837 L
.91278 .04001 L
.91319 .03866 L
.91623 .02894 L
.91933 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.56063 .98077 m
.56313 .97546 L
.56518 .97106 L
.56972 .96134 L
.57284 .95461 L
.57421 .95163 L
.57868 .94192 L
.58256 .93343 L
.58311 .93221 L
.5875 .92249 L
.59188 .91278 L
.59227 .91192 L
.59621 .90307 L
.60053 .89336 L
.60198 .89008 L
.6048 .88364 L
.60907 .87393 L
.61169 .86792 L
.61329 .86422 L
.6175 .85451 L
.62141 .84544 L
.62168 .84479 L
.62582 .83508 L
.62996 .82537 L
.63112 .82264 L
.63405 .81566 L
.63815 .80594 L
.64083 .79954 L
.6422 .79623 L
.64623 .78652 L
.65026 .77681 L
.65054 .77613 L
.65424 .76709 L
.65823 .75738 L
.66026 .75241 L
.66217 .74767 L
.66611 .73796 L
.66997 .7284 L
.67003 .72824 L
.67391 .71853 L
.6778 .70882 L
.67968 .7041 L
.68164 .69911 L
.68549 .68939 L
.68932 .67968 L
.68939 .6795 L
.6931 .66997 L
.69691 .66026 L
.69911 .65462 L
.70067 .65054 L
Mistroke
.70442 .64083 L
.70818 .63112 L
.70882 .62945 L
.71187 .62141 L
.7156 .61169 L
.71853 .604 L
.71928 .60198 L
.72295 .59227 L
.72663 .58256 L
.72824 .57827 L
.73025 .57284 L
.73389 .56313 L
.73753 .55342 L
.73796 .55227 L
.7411 .54371 L
.74471 .53399 L
.74767 .52599 L
.74828 .52428 L
.75183 .51457 L
.75541 .50486 L
.75738 .49945 L
.75892 .49514 L
.76245 .48543 L
.76598 .47572 L
.76709 .47263 L
.76945 .46601 L
.77295 .45629 L
.77644 .44658 L
.77681 .44556 L
.77987 .43687 L
.78334 .42716 L
.78652 .41822 L
.78679 .41744 L
.79019 .40773 L
.79363 .39802 L
.79623 .39062 L
.79702 .38831 L
.8004 .37859 L
.80381 .36888 L
.80594 .36276 L
.80716 .35917 L
.81052 .34946 L
.8139 .33974 L
.81566 .33465 L
.81721 .33003 L
.82055 .32032 L
.8239 .31061 L
.82537 .30629 L
.82717 .30089 L
.83048 .29118 L
Mistroke
.8338 .28147 L
.83508 .27768 L
.83704 .27176 L
.84033 .26204 L
.84362 .25233 L
.84479 .24882 L
.84683 .24262 L
.85009 .23291 L
.85335 .22319 L
.85451 .21971 L
.85653 .21348 L
.85976 .20377 L
.863 .19406 L
.86422 .19036 L
.86616 .18434 L
.86936 .17463 L
.87257 .16492 L
.87393 .16076 L
.8757 .15521 L
.87888 .14549 L
.88207 .13578 L
.88364 .13093 L
.88518 .12607 L
.88832 .11636 L
.89149 .10664 L
.89336 .10086 L
.89458 .09693 L
.8977 .08722 L
.90084 .07751 L
.90307 .07055 L
.90392 .06779 L
.907 .05808 L
.91012 .04837 L
.91278 .04001 L
.91319 .03866 L
.91623 .02894 L
.91933 .01923 L
Mfstroke
.7 g
.57274 .98077 m
.57284 .98055 L
.57707 .97106 L
.58154 .96134 L
.58256 .95911 L
.58582 .95163 L
.59021 .94192 L
.59227 .93736 L
.59446 .93221 L
.59877 .92249 L
.60198 .9153 L
.60302 .91278 L
.60722 .90307 L
.6115 .89336 L
.61169 .89292 L
.61558 .88364 L
.6198 .87393 L
.62141 .87023 L
.62385 .86422 L
.628 .85451 L
.63112 .84723 L
.63207 .84479 L
.6361 .83508 L
.64023 .82537 L
.64083 .82394 L
.64413 .81566 L
.6482 .80594 L
.65054 .80033 L
.65212 .79623 L
.65608 .78652 L
.66011 .77681 L
.66026 .77645 L
.6639 .76709 L
.66788 .75738 L
.66997 .75226 L
.67169 .74767 L
.67556 .73796 L
.6795 .72824 L
.67968 .72779 L
.68319 .71853 L
.68708 .70882 L
.68939 .70303 L
.69081 .69911 L
.69458 .68939 L
.69844 .67968 L
.69911 .67799 L
.70205 .66997 L
.70585 .66026 L
.70882 .65267 L
.70955 .65054 L
.71319 .64083 L
.71697 .63112 L
.71853 .62707 L
.72052 .62141 L
.72421 .61169 L
.72795 .60198 L
.72824 .6012 L
.73141 .59227 L
.7351 .58256 L
.73796 .57505 L
.73869 .57284 L
.7422 .56313 L
.74588 .55342 L
.74767 .54864 L
.74932 .54371 L
.75289 .53399 L
.75652 .52428 L
.75738 .52197 L
.75988 .51457 L
.76346 .50486 L
.76705 .49514 L
.76709 .49503 L
.77035 .48543 L
.77391 .47572 L
.77681 .46782 L
.77737 .46601 L
.78072 .45629 L
.78426 .44658 L
.78652 .44036 L
.78761 .43687 L
.79099 .42716 L
.79451 .41744 L
.79623 .41265 L
.79777 .40773 L
.80117 .39802 L
.80465 .38831 L
.80594 .38468 L
.80785 .37859 L
.81125 .36888 L
.8147 .35917 L
.81566 .35645 L
.81785 .34946 L
.82123 .33974 L
.82466 .33003 L
.82537 .32798 L
.82776 .32032 L
.83112 .31061 L
.83452 .30089 L
.83508 .29926 L
.83758 .29118 L
.84092 .28147 L
.84429 .27176 L
.84479 .2703 L
.84732 .26204 L
.85064 .25233 L
.85399 .24262 L
.85451 .24109 L
.85698 .23291 L
.86027 .22319 L
.8636 .21348 L
.86422 .21164 L
.86657 .20377 L
.86983 .19406 L
.87313 .18434 L
.87393 .18195 L
.87607 .17463 L
.8793 .16492 L
.88258 .15521 L
.88364 .15202 L
.88551 .14549 L
.8887 .13578 L
.89196 .12607 L
.89336 .12185 L
.89489 .11636 L
.89802 .10664 L
.90126 .09693 L
.90307 .09145 L
.90421 .08722 L
.90728 .07751 L
.9105 .06779 L
.91278 .06082 L
.91349 .05808 L
.91646 .04837 L
.91966 .03866 L
.92249 .02996 L
.92274 .02894 L
.92559 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.57274 .98077 m
.57284 .98055 L
.57707 .97106 L
.58154 .96134 L
.58256 .95911 L
.58582 .95163 L
.59021 .94192 L
.59227 .93736 L
.59446 .93221 L
.59877 .92249 L
.60198 .9153 L
.60302 .91278 L
.60722 .90307 L
.6115 .89336 L
.61169 .89292 L
.61558 .88364 L
.6198 .87393 L
.62141 .87023 L
.62385 .86422 L
.628 .85451 L
.63112 .84723 L
.63207 .84479 L
.6361 .83508 L
.64023 .82537 L
.64083 .82394 L
.64413 .81566 L
.6482 .80594 L
.65054 .80033 L
.65212 .79623 L
.65608 .78652 L
.66011 .77681 L
.66026 .77645 L
.6639 .76709 L
.66788 .75738 L
.66997 .75226 L
.67169 .74767 L
.67556 .73796 L
.6795 .72824 L
.67968 .72779 L
.68319 .71853 L
.68708 .70882 L
.68939 .70303 L
.69081 .69911 L
.69458 .68939 L
.69844 .67968 L
.69911 .67799 L
.70205 .66997 L
.70585 .66026 L
.70882 .65267 L
.70955 .65054 L
Mistroke
.71319 .64083 L
.71697 .63112 L
.71853 .62707 L
.72052 .62141 L
.72421 .61169 L
.72795 .60198 L
.72824 .6012 L
.73141 .59227 L
.7351 .58256 L
.73796 .57505 L
.73869 .57284 L
.7422 .56313 L
.74588 .55342 L
.74767 .54864 L
.74932 .54371 L
.75289 .53399 L
.75652 .52428 L
.75738 .52197 L
.75988 .51457 L
.76346 .50486 L
.76705 .49514 L
.76709 .49503 L
.77035 .48543 L
.77391 .47572 L
.77681 .46782 L
.77737 .46601 L
.78072 .45629 L
.78426 .44658 L
.78652 .44036 L
.78761 .43687 L
.79099 .42716 L
.79451 .41744 L
.79623 .41265 L
.79777 .40773 L
.80117 .39802 L
.80465 .38831 L
.80594 .38468 L
.80785 .37859 L
.81125 .36888 L
.8147 .35917 L
.81566 .35645 L
.81785 .34946 L
.82123 .33974 L
.82466 .33003 L
.82537 .32798 L
.82776 .32032 L
.83112 .31061 L
.83452 .30089 L
.83508 .29926 L
.83758 .29118 L
Mistroke
.84092 .28147 L
.84429 .27176 L
.84479 .2703 L
.84732 .26204 L
.85064 .25233 L
.85399 .24262 L
.85451 .24109 L
.85698 .23291 L
.86027 .22319 L
.8636 .21348 L
.86422 .21164 L
.86657 .20377 L
.86983 .19406 L
.87313 .18434 L
.87393 .18195 L
.87607 .17463 L
.8793 .16492 L
.88258 .15521 L
.88364 .15202 L
.88551 .14549 L
.8887 .13578 L
.89196 .12607 L
.89336 .12185 L
.89489 .11636 L
.89802 .10664 L
.90126 .09693 L
.90307 .09145 L
.90421 .08722 L
.90728 .07751 L
.9105 .06779 L
.91278 .06082 L
.91349 .05808 L
.91646 .04837 L
.91966 .03866 L
.92249 .02996 L
.92274 .02894 L
.92559 .01923 L
Mfstroke
.8 g
.58809 .98077 m
.59227 .97423 L
.5936 .97106 L
.59775 .96134 L
.60182 .95163 L
.60198 .95132 L
.60597 .94192 L
.60953 .93221 L
.61169 .92814 L
.61412 .92249 L
.6168 .91278 L
.62141 .90481 L
.62218 .90307 L
.6262 .89336 L
.62995 .88364 L
.63112 .88128 L
.63416 .87393 L
.6372 .86422 L
.64083 .85738 L
.64205 .85451 L
.64597 .84479 L
.64971 .83508 L
.65054 .83334 L
.65376 .82537 L
.65682 .81566 L
.66026 .8089 L
.66147 .80594 L
.66324 .79623 L
.66894 .78652 L
.66997 .78431 L
.67294 .77681 L
.67581 .76709 L
.67968 .75938 L
.68049 .75738 L
.68426 .74767 L
.68767 .73796 L
.68939 .73423 L
.69172 .72824 L
.6942 .71853 L
.69911 .70886 L
.69912 .70882 L
.70282 .69911 L
.70588 .68939 L
.70882 .6831 L
.71014 .67968 L
.7119 .66997 L
.71717 .66026 L
.71853 .65718 L
.72103 .65054 L
.72349 .64083 L
.7282 .63112 L
.72824 .63102 L
.7318 .62141 L
.73468 .61169 L
.73796 .6045 L
.7389 .60198 L
.74245 .59227 L
.74559 .58256 L
.74767 .57779 L
.74949 .57284 L
.75145 .56313 L
.7563 .55342 L
.75738 .55084 L
.75996 .54371 L
.7623 .53399 L
.76683 .52428 L
.76709 .52365 L
.77033 .51457 L
.77293 .50486 L
.77681 .49616 L
.77718 .49514 L
.7806 .48543 L
.78337 .47572 L
.78652 .46842 L
.78738 .46601 L
.79078 .45629 L
.79365 .44658 L
.79623 .44045 L
.7975 .43687 L
.79887 .42716 L
.8038 .41744 L
.80594 .41224 L
.80752 .40773 L
.80906 .39802 L
.81383 .38831 L
.81566 .38379 L
.81745 .37859 L
.8191 .36888 L
.82374 .35917 L
.82537 .3551 L
.8273 .34946 L
.82899 .33974 L
.83355 .33003 L
.83508 .32617 L
.83706 .32032 L
.83874 .31061 L
.84326 .30089 L
.84479 .297 L
.84675 .29118 L
.84836 .28147 L
.85288 .27176 L
.85451 .26758 L
.85635 .26204 L
.85786 .25233 L
.8624 .24262 L
.86422 .23794 L
.86589 .23291 L
.86722 .22319 L
.87182 .21348 L
.87393 .20805 L
.87534 .20377 L
.87644 .19406 L
.88114 .18434 L
.88364 .17794 L
.88473 .17463 L
.88786 .16492 L
.89037 .15521 L
.89336 .14761 L
.89405 .14549 L
.89716 .13578 L
.89948 .12607 L
.90307 .11705 L
.9033 .11636 L
.90639 .10664 L
.90848 .09693 L
.91243 .08722 L
.91278 .08625 L
.91555 .07751 L
.91734 .06779 L
.92145 .05808 L
.92249 .05522 L
.92465 .04837 L
.92604 .03866 L
.93036 .02894 L
.93221 .02411 L
.93369 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.58809 .98077 m
.59227 .97423 L
.5936 .97106 L
.59775 .96134 L
.60182 .95163 L
.60198 .95132 L
.60597 .94192 L
.60953 .93221 L
.61169 .92814 L
.61412 .92249 L
.6168 .91278 L
.62141 .90481 L
.62218 .90307 L
.6262 .89336 L
.62995 .88364 L
.63112 .88128 L
.63416 .87393 L
.6372 .86422 L
.64083 .85738 L
.64205 .85451 L
.64597 .84479 L
.64971 .83508 L
.65054 .83334 L
.65376 .82537 L
.65682 .81566 L
.66026 .8089 L
.66147 .80594 L
.66324 .79623 L
.66894 .78652 L
.66997 .78431 L
.67294 .77681 L
.67581 .76709 L
.67968 .75938 L
.68049 .75738 L
.68426 .74767 L
.68767 .73796 L
.68939 .73423 L
.69172 .72824 L
.6942 .71853 L
.69911 .70886 L
.69912 .70882 L
.70282 .69911 L
.70588 .68939 L
.70882 .6831 L
.71014 .67968 L
.7119 .66997 L
.71717 .66026 L
.71853 .65718 L
.72103 .65054 L
.72349 .64083 L
Mistroke
.7282 .63112 L
.72824 .63102 L
.7318 .62141 L
.73468 .61169 L
.73796 .6045 L
.7389 .60198 L
.74245 .59227 L
.74559 .58256 L
.74767 .57779 L
.74949 .57284 L
.75145 .56313 L
.7563 .55342 L
.75738 .55084 L
.75996 .54371 L
.7623 .53399 L
.76683 .52428 L
.76709 .52365 L
.77033 .51457 L
.77293 .50486 L
.77681 .49616 L
.77718 .49514 L
.7806 .48543 L
.78337 .47572 L
.78652 .46842 L
.78738 .46601 L
.79078 .45629 L
.79365 .44658 L
.79623 .44045 L
.7975 .43687 L
.79887 .42716 L
.8038 .41744 L
.80594 .41224 L
.80752 .40773 L
.80906 .39802 L
.81383 .38831 L
.81566 .38379 L
.81745 .37859 L
.8191 .36888 L
.82374 .35917 L
.82537 .3551 L
.8273 .34946 L
.82899 .33974 L
.83355 .33003 L
.83508 .32617 L
.83706 .32032 L
.83874 .31061 L
.84326 .30089 L
.84479 .297 L
.84675 .29118 L
.84836 .28147 L
Mistroke
.85288 .27176 L
.85451 .26758 L
.85635 .26204 L
.85786 .25233 L
.8624 .24262 L
.86422 .23794 L
.86589 .23291 L
.86722 .22319 L
.87182 .21348 L
.87393 .20805 L
.87534 .20377 L
.87644 .19406 L
.88114 .18434 L
.88364 .17794 L
.88473 .17463 L
.88786 .16492 L
.89037 .15521 L
.89336 .14761 L
.89405 .14549 L
.89716 .13578 L
.89948 .12607 L
.90307 .11705 L
.9033 .11636 L
.90639 .10664 L
.90848 .09693 L
.91243 .08722 L
.91278 .08625 L
.91555 .07751 L
.91734 .06779 L
.92145 .05808 L
.92249 .05522 L
.92465 .04837 L
.92604 .03866 L
.93036 .02894 L
.93221 .02411 L
.93369 .01923 L
Mfstroke
.7 g
.61507 .98077 m
.61833 .97106 L
.62141 .96435 L
.6232 .96134 L
.62702 .95163 L
.63112 .94244 L
.6314 .94192 L
.63558 .93221 L
.63984 .92249 L
.64083 .92032 L
.64565 .91278 L
.64821 .90307 L
.65054 .89775 L
.65302 .89336 L
.65648 .88364 L
.66026 .87478 L
.66069 .87393 L
.66466 .86422 L
.66872 .85451 L
.66997 .85161 L
.67383 .84479 L
.67674 .83508 L
.67968 .828 L
.68102 .82537 L
.68467 .81566 L
.68863 .80594 L
.68939 .80412 L
.69377 .79623 L
.69642 .78652 L
.69911 .77989 L
.70063 .77681 L
.70415 .76709 L
.708 .75738 L
.70882 .75538 L
.71289 .74767 L
.7156 .73796 L
.71853 .73052 L
.71961 .72824 L
.72314 .71853 L
.7269 .70882 L
.72824 .70542 L
.73137 .69911 L
.73433 .68939 L
.73796 .67993 L
.73807 .67968 L
.74318 .66997 L
.74537 .66026 L
.74767 .65425 L
.74938 .65054 L
.75265 .64083 L
.75628 .63112 L
.75738 .62824 L
.76064 .62141 L
.76346 .61169 L
.76706 .60198 L
.76709 .60189 L
.77186 .59227 L
.77415 .58256 L
.77681 .57534 L
.7779 .57284 L
.78303 .56313 L
.78471 .55342 L
.78652 .5485 L
.78865 .54371 L
.79168 .53399 L
.79517 .52428 L
.79623 .52136 L
.7993 .51457 L
.80205 .50486 L
.80551 .49514 L
.80594 .49394 L
.80984 .48543 L
.81232 .47572 L
.81566 .46625 L
.81575 .46601 L
.82027 .45629 L
.82248 .44658 L
.82537 .43832 L
.82596 .43687 L
.83058 .42716 L
.83254 .41744 L
.83508 .41013 L
.83606 .40773 L
.84075 .39802 L
.84251 .38831 L
.84479 .38168 L
.84605 .37859 L
.85078 .36888 L
.85238 .35917 L
.85451 .35296 L
.85593 .34946 L
.86066 .33974 L
.86217 .33003 L
.86422 .32399 L
.8657 .32032 L
.8704 .31061 L
.87187 .30089 L
.87393 .29477 L
.87536 .29118 L
.88 .28147 L
.88149 .27176 L
.88364 .26529 L
.88492 .26204 L
.88946 .25233 L
.89103 .24262 L
.89336 .23557 L
.89439 .23291 L
.8988 .22319 L
.90049 .21348 L
.90307 .2056 L
.90377 .20377 L
.90804 .19406 L
.90988 .18434 L
.91278 .17538 L
.91306 .17463 L
.91718 .16492 L
.91919 .15521 L
.92231 .14549 L
.92249 .14494 L
.92624 .13578 L
.92844 .12607 L
.93153 .11636 L
.93221 .11427 L
.93523 .10664 L
.93762 .09693 L
.94068 .08722 L
.94192 .08335 L
.94417 .07751 L
.94882 .06779 L
.94977 .05808 L
.95163 .05219 L
.95306 .04837 L
.95738 .03866 L
.9588 .02894 L
.96134 .02076 L
.96191 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.61507 .98077 m
.61833 .97106 L
.62141 .96435 L
.6232 .96134 L
.62702 .95163 L
.63112 .94244 L
.6314 .94192 L
.63558 .93221 L
.63984 .92249 L
.64083 .92032 L
.64565 .91278 L
.64821 .90307 L
.65054 .89775 L
.65302 .89336 L
.65648 .88364 L
.66026 .87478 L
.66069 .87393 L
.66466 .86422 L
.66872 .85451 L
.66997 .85161 L
.67383 .84479 L
.67674 .83508 L
.67968 .828 L
.68102 .82537 L
.68467 .81566 L
.68863 .80594 L
.68939 .80412 L
.69377 .79623 L
.69642 .78652 L
.69911 .77989 L
.70063 .77681 L
.70415 .76709 L
.708 .75738 L
.70882 .75538 L
.71289 .74767 L
.7156 .73796 L
.71853 .73052 L
.71961 .72824 L
.72314 .71853 L
.7269 .70882 L
.72824 .70542 L
.73137 .69911 L
.73433 .68939 L
.73796 .67993 L
.73807 .67968 L
.74318 .66997 L
.74537 .66026 L
.74767 .65425 L
.74938 .65054 L
.75265 .64083 L
Mistroke
.75628 .63112 L
.75738 .62824 L
.76064 .62141 L
.76346 .61169 L
.76706 .60198 L
.76709 .60189 L
.77186 .59227 L
.77415 .58256 L
.77681 .57534 L
.7779 .57284 L
.78303 .56313 L
.78471 .55342 L
.78652 .5485 L
.78865 .54371 L
.79168 .53399 L
.79517 .52428 L
.79623 .52136 L
.7993 .51457 L
.80205 .50486 L
.80551 .49514 L
.80594 .49394 L
.80984 .48543 L
.81232 .47572 L
.81566 .46625 L
.81575 .46601 L
.82027 .45629 L
.82248 .44658 L
.82537 .43832 L
.82596 .43687 L
.83058 .42716 L
.83254 .41744 L
.83508 .41013 L
.83606 .40773 L
.84075 .39802 L
.84251 .38831 L
.84479 .38168 L
.84605 .37859 L
.85078 .36888 L
.85238 .35917 L
.85451 .35296 L
.85593 .34946 L
.86066 .33974 L
.86217 .33003 L
.86422 .32399 L
.8657 .32032 L
.8704 .31061 L
.87187 .30089 L
.87393 .29477 L
.87536 .29118 L
.88 .28147 L
Mistroke
.88149 .27176 L
.88364 .26529 L
.88492 .26204 L
.88946 .25233 L
.89103 .24262 L
.89336 .23557 L
.89439 .23291 L
.8988 .22319 L
.90049 .21348 L
.90307 .2056 L
.90377 .20377 L
.90804 .19406 L
.90988 .18434 L
.91278 .17538 L
.91306 .17463 L
.91718 .16492 L
.91919 .15521 L
.92231 .14549 L
.92249 .14494 L
.92624 .13578 L
.92844 .12607 L
.93153 .11636 L
.93221 .11427 L
.93523 .10664 L
.93762 .09693 L
.94068 .08722 L
.94192 .08335 L
.94417 .07751 L
.94882 .06779 L
.94977 .05808 L
.95163 .05219 L
.95306 .04837 L
.95738 .03866 L
.9588 .02894 L
.96134 .02076 L
.96191 .01923 L
Mfstroke
.6 g
.62942 .98077 m
.63112 .9765 L
.63353 .97106 L
.63777 .96134 L
.64083 .95377 L
.64176 .95163 L
.64598 .94192 L
.64998 .93221 L
.65054 .9307 L
.65407 .92249 L
.65815 .91278 L
.66026 .90731 L
.66205 .90307 L
.66615 .89336 L
.66996 .88364 L
.66997 .88361 L
.67402 .87393 L
.67798 .86422 L
.67968 .85962 L
.68179 .85451 L
.68579 .84479 L
.68939 .83531 L
.68949 .83508 L
.69346 .82537 L
.69732 .81566 L
.69911 .81072 L
.70103 .80594 L
.70495 .79623 L
.70859 .78652 L
.70882 .78582 L
.71242 .77681 L
.71624 .76709 L
.71853 .76065 L
.71982 .75738 L
.72366 .74767 L
.72731 .73796 L
.72824 .73518 L
.73096 .72824 L
.73473 .71853 L
.73796 .70943 L
.73819 .70882 L
.74196 .69911 L
.74563 .68939 L
.74767 .6834 L
.74909 .67968 L
.75282 .66997 L
.75636 .66026 L
.75738 .6571 L
.75987 .65054 L
.76354 .64083 L
.76691 .63112 L
.76709 .63051 L
.77052 .62141 L
.77413 .61169 L
.77681 .60367 L
.77743 .60198 L
.78106 .59227 L
.78459 .58256 L
.78652 .57655 L
.78788 .57284 L
.79147 .56313 L
.79491 .55342 L
.79623 .54917 L
.79823 .54371 L
.80178 .53399 L
.80512 .52428 L
.80594 .52153 L
.80846 .51457 L
.81198 .50486 L
.81522 .49514 L
.81566 .49362 L
.8186 .48543 L
.82208 .47572 L
.82522 .46601 L
.82537 .46546 L
.82864 .45629 L
.83208 .44658 L
.83508 .43704 L
.83514 .43687 L
.83858 .42716 L
.84198 .41744 L
.84479 .40838 L
.84502 .40773 L
.84843 .39802 L
.8518 .38831 L
.85451 .37946 L
.85481 .37859 L
.85819 .36888 L
.86154 .35917 L
.86422 .35029 L
.86451 .34946 L
.86786 .33974 L
.87119 .33003 L
.87393 .32088 L
.87412 .32032 L
.87745 .31061 L
.88076 .30089 L
.88364 .29122 L
.88366 .29118 L
.88696 .28147 L
.89025 .27176 L
.89318 .26204 L
.89336 .26133 L
.89639 .25233 L
.89967 .24262 L
.90264 .23291 L
.90307 .23119 L
.90574 .22319 L
.90901 .21348 L
.91203 .20377 L
.91278 .20082 L
.91502 .19406 L
.91827 .18434 L
.92134 .17463 L
.92249 .17021 L
.92423 .16492 L
.92746 .15521 L
.93057 .14549 L
.93221 .13936 L
.93337 .13578 L
.93658 .12607 L
.93972 .11636 L
.94192 .10828 L
.94245 .10664 L
.94562 .09693 L
.94878 .08722 L
.95152 .07751 L
.95163 .07697 L
.9546 .06779 L
.95776 .05808 L
.96065 .04837 L
.96134 .04544 L
.96352 .03866 L
.96666 .02894 L
.96967 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.62942 .98077 m
.63112 .9765 L
.63353 .97106 L
.63777 .96134 L
.64083 .95377 L
.64176 .95163 L
.64598 .94192 L
.64998 .93221 L
.65054 .9307 L
.65407 .92249 L
.65815 .91278 L
.66026 .90731 L
.66205 .90307 L
.66615 .89336 L
.66996 .88364 L
.66997 .88361 L
.67402 .87393 L
.67798 .86422 L
.67968 .85962 L
.68179 .85451 L
.68579 .84479 L
.68939 .83531 L
.68949 .83508 L
.69346 .82537 L
.69732 .81566 L
.69911 .81072 L
.70103 .80594 L
.70495 .79623 L
.70859 .78652 L
.70882 .78582 L
.71242 .77681 L
.71624 .76709 L
.71853 .76065 L
.71982 .75738 L
.72366 .74767 L
.72731 .73796 L
.72824 .73518 L
.73096 .72824 L
.73473 .71853 L
.73796 .70943 L
.73819 .70882 L
.74196 .69911 L
.74563 .68939 L
.74767 .6834 L
.74909 .67968 L
.75282 .66997 L
.75636 .66026 L
.75738 .6571 L
.75987 .65054 L
.76354 .64083 L
Mistroke
.76691 .63112 L
.76709 .63051 L
.77052 .62141 L
.77413 .61169 L
.77681 .60367 L
.77743 .60198 L
.78106 .59227 L
.78459 .58256 L
.78652 .57655 L
.78788 .57284 L
.79147 .56313 L
.79491 .55342 L
.79623 .54917 L
.79823 .54371 L
.80178 .53399 L
.80512 .52428 L
.80594 .52153 L
.80846 .51457 L
.81198 .50486 L
.81522 .49514 L
.81566 .49362 L
.8186 .48543 L
.82208 .47572 L
.82522 .46601 L
.82537 .46546 L
.82864 .45629 L
.83208 .44658 L
.83508 .43704 L
.83514 .43687 L
.83858 .42716 L
.84198 .41744 L
.84479 .40838 L
.84502 .40773 L
.84843 .39802 L
.8518 .38831 L
.85451 .37946 L
.85481 .37859 L
.85819 .36888 L
.86154 .35917 L
.86422 .35029 L
.86451 .34946 L
.86786 .33974 L
.87119 .33003 L
.87393 .32088 L
.87412 .32032 L
.87745 .31061 L
.88076 .30089 L
.88364 .29122 L
.88366 .29118 L
.88696 .28147 L
Mistroke
.89025 .27176 L
.89318 .26204 L
.89336 .26133 L
.89639 .25233 L
.89967 .24262 L
.90264 .23291 L
.90307 .23119 L
.90574 .22319 L
.90901 .21348 L
.91203 .20377 L
.91278 .20082 L
.91502 .19406 L
.91827 .18434 L
.92134 .17463 L
.92249 .17021 L
.92423 .16492 L
.92746 .15521 L
.93057 .14549 L
.93221 .13936 L
.93337 .13578 L
.93658 .12607 L
.93972 .11636 L
.94192 .10828 L
.94245 .10664 L
.94562 .09693 L
.94878 .08722 L
.95152 .07751 L
.95163 .07697 L
.9546 .06779 L
.95776 .05808 L
.96065 .04837 L
.96134 .04544 L
.96352 .03866 L
.96666 .02894 L
.96967 .01923 L
Mfstroke
.5 g
.63976 .98077 m
.64083 .97817 L
.64383 .97106 L
.6479 .96134 L
.65054 .95491 L
.65191 .95163 L
.65594 .94192 L
.65991 .93221 L
.66026 .93134 L
.66389 .92249 L
.66785 .91278 L
.66997 .90747 L
.67176 .90307 L
.67569 .89336 L
.67955 .88364 L
.67968 .88331 L
.68344 .87393 L
.6873 .86422 L
.68939 .85884 L
.69111 .85451 L
.69495 .84479 L
.69873 .83508 L
.69911 .83409 L
.70252 .82537 L
.7063 .81566 L
.70882 .80904 L
.71002 .80594 L
.71378 .79623 L
.71748 .78652 L
.71853 .78372 L
.72118 .77681 L
.72489 .76709 L
.72824 .7581 L
.72852 .75738 L
.7322 .74767 L
.73585 .73796 L
.73796 .73222 L
.73944 .72824 L
.74309 .71853 L
.74667 .70882 L
.74767 .70605 L
.75025 .69911 L
.75384 .68939 L
.75736 .67968 L
.75738 .67962 L
.76093 .66997 L
.76448 .66026 L
.76709 .65291 L
.76795 .65054 L
.77149 .64083 L
.77499 .63112 L
.77681 .62594 L
.77844 .62141 L
.78194 .61169 L
.78538 .60198 L
.78652 .5987 L
.78881 .59227 L
.79228 .58256 L
.79567 .57284 L
.79623 .5712 L
.79908 .56313 L
.80251 .55342 L
.80586 .54371 L
.80594 .54344 L
.80925 .53399 L
.81265 .52428 L
.81566 .51543 L
.81595 .51457 L
.81933 .50486 L
.82268 .49514 L
.82537 .48716 L
.82596 .48543 L
.8293 .47572 L
.83263 .46601 L
.83508 .45863 L
.83588 .45629 L
.83919 .44658 L
.84249 .43687 L
.84479 .42986 L
.8457 .42716 L
.849 .41744 L
.85226 .40773 L
.85451 .40084 L
.85545 .39802 L
.85871 .38831 L
.86195 .37859 L
.86422 .37157 L
.86511 .36888 L
.86835 .35917 L
.87156 .34946 L
.87393 .34206 L
.87469 .33974 L
.8779 .33003 L
.8811 .32032 L
.88364 .31231 L
.8842 .31061 L
.88738 .30089 L
.89056 .29118 L
.89336 .28232 L
.89363 .28147 L
.89679 .27176 L
.89994 .26204 L
.903 .25233 L
.90307 .25209 L
.90612 .24262 L
.90926 .23291 L
.91231 .22319 L
.91278 .22163 L
.91538 .21348 L
.9185 .20377 L
.92155 .19406 L
.92249 .19093 L
.92458 .18434 L
.92767 .17463 L
.93072 .16492 L
.93221 .16 L
.93371 .15521 L
.93678 .14549 L
.93983 .13578 L
.94192 .12883 L
.94278 .12607 L
.94583 .11636 L
.94886 .10664 L
.95163 .09744 L
.95179 .09693 L
.95481 .08722 L
.95783 .07751 L
.96077 .06779 L
.96134 .06582 L
.96373 .05808 L
.96674 .04837 L
.96969 .03866 L
.97106 .03398 L
.97244 .02894 L
.97468 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.63976 .98077 m
.64083 .97817 L
.64383 .97106 L
.6479 .96134 L
.65054 .95491 L
.65191 .95163 L
.65594 .94192 L
.65991 .93221 L
.66026 .93134 L
.66389 .92249 L
.66785 .91278 L
.66997 .90747 L
.67176 .90307 L
.67569 .89336 L
.67955 .88364 L
.67968 .88331 L
.68344 .87393 L
.6873 .86422 L
.68939 .85884 L
.69111 .85451 L
.69495 .84479 L
.69873 .83508 L
.69911 .83409 L
.70252 .82537 L
.7063 .81566 L
.70882 .80904 L
.71002 .80594 L
.71378 .79623 L
.71748 .78652 L
.71853 .78372 L
.72118 .77681 L
.72489 .76709 L
.72824 .7581 L
.72852 .75738 L
.7322 .74767 L
.73585 .73796 L
.73796 .73222 L
.73944 .72824 L
.74309 .71853 L
.74667 .70882 L
.74767 .70605 L
.75025 .69911 L
.75384 .68939 L
.75736 .67968 L
.75738 .67962 L
.76093 .66997 L
.76448 .66026 L
.76709 .65291 L
.76795 .65054 L
.77149 .64083 L
Mistroke
.77499 .63112 L
.77681 .62594 L
.77844 .62141 L
.78194 .61169 L
.78538 .60198 L
.78652 .5987 L
.78881 .59227 L
.79228 .58256 L
.79567 .57284 L
.79623 .5712 L
.79908 .56313 L
.80251 .55342 L
.80586 .54371 L
.80594 .54344 L
.80925 .53399 L
.81265 .52428 L
.81566 .51543 L
.81595 .51457 L
.81933 .50486 L
.82268 .49514 L
.82537 .48716 L
.82596 .48543 L
.8293 .47572 L
.83263 .46601 L
.83508 .45863 L
.83588 .45629 L
.83919 .44658 L
.84249 .43687 L
.84479 .42986 L
.8457 .42716 L
.849 .41744 L
.85226 .40773 L
.85451 .40084 L
.85545 .39802 L
.85871 .38831 L
.86195 .37859 L
.86422 .37157 L
.86511 .36888 L
.86835 .35917 L
.87156 .34946 L
.87393 .34206 L
.87469 .33974 L
.8779 .33003 L
.8811 .32032 L
.88364 .31231 L
.8842 .31061 L
.88738 .30089 L
.89056 .29118 L
.89336 .28232 L
.89363 .28147 L
Mistroke
.89679 .27176 L
.89994 .26204 L
.903 .25233 L
.90307 .25209 L
.90612 .24262 L
.90926 .23291 L
.91231 .22319 L
.91278 .22163 L
.91538 .21348 L
.9185 .20377 L
.92155 .19406 L
.92249 .19093 L
.92458 .18434 L
.92767 .17463 L
.93072 .16492 L
.93221 .16 L
.93371 .15521 L
.93678 .14549 L
.93983 .13578 L
.94192 .12883 L
.94278 .12607 L
.94583 .11636 L
.94886 .10664 L
.95163 .09744 L
.95179 .09693 L
.95481 .08722 L
.95783 .07751 L
.96077 .06779 L
.96134 .06582 L
.96373 .05808 L
.96674 .04837 L
.96969 .03866 L
.97106 .03398 L
.97244 .02894 L
.97468 .01923 L
Mfstroke
.4 g
.98077 .02119 m
.97809 .02894 L
.97533 .03866 L
.97253 .04837 L
.97106 .05332 L
.96961 .05808 L
.96662 .06779 L
.96364 .07751 L
.96134 .08523 L
.96074 .08722 L
.95774 .09693 L
.95473 .10664 L
.9518 .11636 L
.95163 .11692 L
.9488 .12607 L
.94576 .13578 L
.94278 .14549 L
.94192 .14838 L
.9398 .15521 L
.93674 .16492 L
.93371 .17463 L
.93221 .17962 L
.93073 .18434 L
.92766 .19406 L
.92459 .20377 L
.92249 .21062 L
.9216 .21348 L
.91851 .22319 L
.91541 .23291 L
.91278 .2414 L
.9124 .24262 L
.90929 .25233 L
.90617 .26204 L
.90312 .27176 L
.90307 .27194 L
.90001 .28147 L
.89686 .29118 L
.89377 .30089 L
.89336 .30224 L
.89065 .31061 L
.88748 .32032 L
.88436 .33003 L
.88364 .33232 L
.88123 .33974 L
.87803 .34946 L
.87487 .35917 L
.87393 .36215 L
.87172 .36888 L
.86851 .37859 L
.86532 .38831 L
.86422 .39174 L
.86214 .39802 L
.8589 .40773 L
.85569 .41744 L
.85451 .42109 L
.85249 .42716 L
.84922 .43687 L
.84597 .44658 L
.84479 .4502 L
.84275 .45629 L
.83945 .46601 L
.83618 .47572 L
.83508 .47906 L
.83292 .48543 L
.8296 .49514 L
.8263 .50486 L
.82537 .50767 L
.82301 .51457 L
.81966 .52428 L
.81634 .53399 L
.81566 .53604 L
.81301 .54371 L
.80962 .55342 L
.80629 .56313 L
.80594 .56415 L
.80291 .57284 L
.7995 .58256 L
.79623 .592 L
.79614 .59227 L
.79272 .60198 L
.78927 .61169 L
.78652 .6196 L
.78588 .62141 L
.78242 .63112 L
.77895 .64083 L
.77681 .64694 L
.77552 .65054 L
.77202 .66026 L
.76853 .66997 L
.76709 .67402 L
.76505 .67968 L
.76151 .68939 L
.758 .69911 L
.75738 .70083 L
.75446 .70882 L
.75088 .71853 L
.74767 .72738 L
.74735 .72824 L
.74375 .73796 L
.74015 .74767 L
.73796 .75365 L
.73657 .75738 L
.73293 .76709 L
.72929 .77681 L
.72824 .77965 L
.72566 .78652 L
.72197 .79623 L
.71853 .80538 L
.71832 .80594 L
.71461 .81566 L
.71089 .82537 L
.70882 .83083 L
.70719 .83508 L
.70342 .84479 L
.69968 .85451 L
.69911 .856 L
.6959 .86422 L
.6921 .87393 L
.68939 .88089 L
.68831 .88364 L
.68447 .89336 L
.68063 .90307 L
.67968 .90548 L
.67677 .91278 L
.67287 .92249 L
.66997 .92979 L
.669 .93221 L
.66506 .94192 L
.66113 .95163 L
.66026 .9538 L
.65717 .96134 L
.65318 .97106 L
.65054 .97751 L
.6492 .98077 L
.98077 .98077 L
F
0 g
.98077 .02119 m
.97809 .02894 L
.97533 .03866 L
.97253 .04837 L
.97106 .05332 L
.96961 .05808 L
.96662 .06779 L
.96364 .07751 L
.96134 .08523 L
.96074 .08722 L
.95774 .09693 L
.95473 .10664 L
.9518 .11636 L
.95163 .11692 L
.9488 .12607 L
.94576 .13578 L
.94278 .14549 L
.94192 .14838 L
.9398 .15521 L
.93674 .16492 L
.93371 .17463 L
.93221 .17962 L
.93073 .18434 L
.92766 .19406 L
.92459 .20377 L
.92249 .21062 L
.9216 .21348 L
.91851 .22319 L
.91541 .23291 L
.91278 .2414 L
.9124 .24262 L
.90929 .25233 L
.90617 .26204 L
.90312 .27176 L
.90307 .27194 L
.90001 .28147 L
.89686 .29118 L
.89377 .30089 L
.89336 .30224 L
.89065 .31061 L
.88748 .32032 L
.88436 .33003 L
.88364 .33232 L
.88123 .33974 L
.87803 .34946 L
.87487 .35917 L
.87393 .36215 L
.87172 .36888 L
.86851 .37859 L
.86532 .38831 L
Mistroke
.86422 .39174 L
.86214 .39802 L
.8589 .40773 L
.85569 .41744 L
.85451 .42109 L
.85249 .42716 L
.84922 .43687 L
.84597 .44658 L
.84479 .4502 L
.84275 .45629 L
.83945 .46601 L
.83618 .47572 L
.83508 .47906 L
.83292 .48543 L
.8296 .49514 L
.8263 .50486 L
.82537 .50767 L
.82301 .51457 L
.81966 .52428 L
.81634 .53399 L
.81566 .53604 L
.81301 .54371 L
.80962 .55342 L
.80629 .56313 L
.80594 .56415 L
.80291 .57284 L
.7995 .58256 L
.79623 .592 L
.79614 .59227 L
.79272 .60198 L
.78927 .61169 L
.78652 .6196 L
.78588 .62141 L
.78242 .63112 L
.77895 .64083 L
.77681 .64694 L
.77552 .65054 L
.77202 .66026 L
.76853 .66997 L
.76709 .67402 L
.76505 .67968 L
.76151 .68939 L
.758 .69911 L
.75738 .70083 L
.75446 .70882 L
.75088 .71853 L
.74767 .72738 L
.74735 .72824 L
.74375 .73796 L
.74015 .74767 L
Mistroke
.73796 .75365 L
.73657 .75738 L
.73293 .76709 L
.72929 .77681 L
.72824 .77965 L
.72566 .78652 L
.72197 .79623 L
.71853 .80538 L
.71832 .80594 L
.71461 .81566 L
.71089 .82537 L
.70882 .83083 L
.70719 .83508 L
.70342 .84479 L
.69968 .85451 L
.69911 .856 L
.6959 .86422 L
.6921 .87393 L
.68939 .88089 L
.68831 .88364 L
.68447 .89336 L
.68063 .90307 L
.67968 .90548 L
.67677 .91278 L
.67287 .92249 L
.66997 .92979 L
.669 .93221 L
.66506 .94192 L
.66113 .95163 L
.66026 .9538 L
.65717 .96134 L
.65318 .97106 L
.65054 .97751 L
.6492 .98077 L
Mfstroke
.3 g
.98077 .04141 m
.97865 .04837 L
.97578 .05808 L
.97286 .06779 L
.97106 .07362 L
.96984 .07751 L
.96675 .08722 L
.96369 .09693 L
.96134 .10562 L
.96102 .10664 L
.95793 .11636 L
.95482 .12607 L
.95201 .13578 L
.95163 .13739 L
.94904 .14549 L
.9459 .15521 L
.94294 .16492 L
.94192 .16893 L
.94009 .17463 L
.93693 .18434 L
.93387 .19406 L
.93221 .20025 L
.93108 .20377 L
.9279 .21348 L
.92477 .22319 L
.92249 .23134 L
.92199 .23291 L
.91881 .24262 L
.91563 .25233 L
.91282 .26204 L
.91278 .26221 L
.90964 .27176 L
.90643 .28147 L
.90349 .29118 L
.90307 .29284 L
.90041 .30089 L
.89717 .31061 L
.89413 .32032 L
.89336 .32323 L
.8911 .33003 L
.88784 .33974 L
.88473 .34946 L
.88364 .3534 L
.88172 .35917 L
.87843 .36888 L
.87527 .37859 L
.87393 .38333 L
.87226 .38831 L
.86895 .39802 L
.86574 .40773 L
.86422 .41302 L
.86272 .41744 L
.85939 .42716 L
.85615 .43687 L
.85451 .44247 L
.8531 .44658 L
.84975 .45629 L
.84648 .46601 L
.84479 .47168 L
.8434 .47572 L
.84003 .48543 L
.83673 .49514 L
.83508 .50064 L
.83362 .50486 L
.83022 .51457 L
.82691 .52428 L
.82537 .52936 L
.82375 .53399 L
.82032 .54371 L
.817 .55342 L
.81566 .55784 L
.81379 .56313 L
.81033 .57284 L
.80701 .58256 L
.80594 .58606 L
.80373 .59227 L
.80025 .60198 L
.79694 .61169 L
.79623 .61403 L
.79358 .62141 L
.79007 .63112 L
.7868 .64083 L
.78652 .64175 L
.78332 .65054 L
.7798 .66026 L
.77681 .66921 L
.77653 .66997 L
.77296 .67968 L
.76943 .68939 L
.76709 .69641 L
.7661 .69911 L
.7625 .70882 L
.75897 .71853 L
.75738 .72335 L
.75556 .72824 L
.75192 .73796 L
.74844 .74767 L
.74767 .75003 L
.7449 .75738 L
.74124 .76709 L
.73796 .77644 L
.73782 .77681 L
.73412 .78652 L
.73046 .79623 L
.72824 .80258 L
.72696 .80594 L
.72322 .81566 L
.71959 .82537 L
.71853 .82845 L
.71596 .83508 L
.71219 .84479 L
.70882 .85405 L
.70864 .85451 L
.70483 .86422 L
.70107 .87393 L
.69911 .87937 L
.69742 .88364 L
.69356 .89336 L
.68987 .90307 L
.68939 .90441 L
.68604 .91278 L
.68218 .92249 L
.67968 .92917 L
.67846 .93221 L
.67452 .94192 L
.67071 .95163 L
.66997 .95364 L
.66682 .96134 L
.66286 .97106 L
.66026 .97784 L
.65904 .98077 L
.98077 .98077 L
F
0 g
.98077 .04141 m
.97865 .04837 L
.97578 .05808 L
.97286 .06779 L
.97106 .07362 L
.96984 .07751 L
.96675 .08722 L
.96369 .09693 L
.96134 .10562 L
.96102 .10664 L
.95793 .11636 L
.95482 .12607 L
.95201 .13578 L
.95163 .13739 L
.94904 .14549 L
.9459 .15521 L
.94294 .16492 L
.94192 .16893 L
.94009 .17463 L
.93693 .18434 L
.93387 .19406 L
.93221 .20025 L
.93108 .20377 L
.9279 .21348 L
.92477 .22319 L
.92249 .23134 L
.92199 .23291 L
.91881 .24262 L
.91563 .25233 L
.91282 .26204 L
.91278 .26221 L
.90964 .27176 L
.90643 .28147 L
.90349 .29118 L
.90307 .29284 L
.90041 .30089 L
.89717 .31061 L
.89413 .32032 L
.89336 .32323 L
.8911 .33003 L
.88784 .33974 L
.88473 .34946 L
.88364 .3534 L
.88172 .35917 L
.87843 .36888 L
.87527 .37859 L
.87393 .38333 L
.87226 .38831 L
.86895 .39802 L
.86574 .40773 L
Mistroke
.86422 .41302 L
.86272 .41744 L
.85939 .42716 L
.85615 .43687 L
.85451 .44247 L
.8531 .44658 L
.84975 .45629 L
.84648 .46601 L
.84479 .47168 L
.8434 .47572 L
.84003 .48543 L
.83673 .49514 L
.83508 .50064 L
.83362 .50486 L
.83022 .51457 L
.82691 .52428 L
.82537 .52936 L
.82375 .53399 L
.82032 .54371 L
.817 .55342 L
.81566 .55784 L
.81379 .56313 L
.81033 .57284 L
.80701 .58256 L
.80594 .58606 L
.80373 .59227 L
.80025 .60198 L
.79694 .61169 L
.79623 .61403 L
.79358 .62141 L
.79007 .63112 L
.7868 .64083 L
.78652 .64175 L
.78332 .65054 L
.7798 .66026 L
.77681 .66921 L
.77653 .66997 L
.77296 .67968 L
.76943 .68939 L
.76709 .69641 L
.7661 .69911 L
.7625 .70882 L
.75897 .71853 L
.75738 .72335 L
.75556 .72824 L
.75192 .73796 L
.74844 .74767 L
.74767 .75003 L
.7449 .75738 L
.74124 .76709 L
Mistroke
.73796 .77644 L
.73782 .77681 L
.73412 .78652 L
.73046 .79623 L
.72824 .80258 L
.72696 .80594 L
.72322 .81566 L
.71959 .82537 L
.71853 .82845 L
.71596 .83508 L
.71219 .84479 L
.70882 .85405 L
.70864 .85451 L
.70483 .86422 L
.70107 .87393 L
.69911 .87937 L
.69742 .88364 L
.69356 .89336 L
.68987 .90307 L
.68939 .90441 L
.68604 .91278 L
.68218 .92249 L
.67968 .92917 L
.67846 .93221 L
.67452 .94192 L
.67071 .95163 L
.66997 .95364 L
.66682 .96134 L
.66286 .97106 L
.66026 .97784 L
.65904 .98077 L
Mfstroke
.2 g
.98077 .06578 m
.98021 .06779 L
.97747 .07751 L
.9746 .08722 L
.97148 .09693 L
.97106 .09813 L
.96786 .10664 L
.96559 .11636 L
.96264 .12607 L
.96134 .13025 L
.95932 .13578 L
.95504 .14549 L
.95379 .15521 L
.95163 .16218 L
.95065 .16492 L
.94665 .17463 L
.94488 .18434 L
.94192 .19389 L
.94186 .19406 L
.93806 .20377 L
.93591 .21348 L
.93289 .22319 L
.93221 .22534 L
.92932 .23291 L
.92463 .24262 L
.92384 .25233 L
.92249 .25659 L
.92045 .26204 L
.91604 .27176 L
.91474 .28147 L
.91278 .28762 L
.91146 .29118 L
.90725 .30089 L
.90557 .31061 L
.90307 .31843 L
.90238 .32032 L
.89831 .33003 L
.89633 .33974 L
.89336 .34902 L
.8932 .34946 L
.88923 .35917 L
.88703 .36888 L
.88389 .37859 L
.88364 .37935 L
.88003 .38831 L
.87766 .39802 L
.8745 .40773 L
.87393 .40945 L
.87072 .41744 L
.86822 .42716 L
.86504 .43687 L
.86422 .43932 L
.86131 .44658 L
.8587 .45629 L
.8555 .46601 L
.85451 .46897 L
.85179 .47572 L
.84911 .48543 L
.84589 .49514 L
.84479 .49837 L
.84218 .50486 L
.83726 .51457 L
.8362 .52428 L
.83508 .52755 L
.83246 .53399 L
.8297 .54371 L
.82642 .55342 L
.82537 .55648 L
.82263 .56313 L
.81988 .57284 L
.81657 .58256 L
.81566 .58518 L
.81269 .59227 L
.80997 .60198 L
.80663 .61169 L
.80594 .61364 L
.80263 .62141 L
.79997 .63112 L
.7966 .64083 L
.79623 .64186 L
.79244 .65054 L
.78988 .66026 L
.78652 .66985 L
.78647 .66997 L
.7821 .67968 L
.7797 .68939 L
.77681 .69755 L
.77617 .69911 L
.77158 .70882 L
.76942 .71853 L
.76709 .725 L
.76573 .72824 L
.76085 .73796 L
.75904 .74767 L
.75738 .75221 L
.75514 .75738 L
.75207 .76709 L
.74855 .77681 L
.74767 .77918 L
.74435 .78652 L
.74152 .79623 L
.73796 .80594 L
.73796 .80594 L
.73332 .81566 L
.73085 .82537 L
.72824 .83237 L
.72706 .83508 L
.72195 .84479 L
.72007 .85451 L
.71853 .85854 L
.71594 .86422 L
.71283 .87393 L
.70916 .88364 L
.70882 .88452 L
.70449 .89336 L
.70184 .90307 L
.69911 .9102 L
.69795 .91278 L
.69256 .92249 L
.69073 .93221 L
.68939 .93559 L
.68635 .94192 L
.68326 .95163 L
.67968 .96083 L
.67945 .96134 L
.67424 .97106 L
.67193 .98077 L
.98077 .98077 L
F
0 g
.98077 .06578 m
.98021 .06779 L
.97747 .07751 L
.9746 .08722 L
.97148 .09693 L
.97106 .09813 L
.96786 .10664 L
.96559 .11636 L
.96264 .12607 L
.96134 .13025 L
.95932 .13578 L
.95504 .14549 L
.95379 .15521 L
.95163 .16218 L
.95065 .16492 L
.94665 .17463 L
.94488 .18434 L
.94192 .19389 L
.94186 .19406 L
.93806 .20377 L
.93591 .21348 L
.93289 .22319 L
.93221 .22534 L
.92932 .23291 L
.92463 .24262 L
.92384 .25233 L
.92249 .25659 L
.92045 .26204 L
.91604 .27176 L
.91474 .28147 L
.91278 .28762 L
.91146 .29118 L
.90725 .30089 L
.90557 .31061 L
.90307 .31843 L
.90238 .32032 L
.89831 .33003 L
.89633 .33974 L
.89336 .34902 L
.8932 .34946 L
.88923 .35917 L
.88703 .36888 L
.88389 .37859 L
.88364 .37935 L
.88003 .38831 L
.87766 .39802 L
.8745 .40773 L
.87393 .40945 L
.87072 .41744 L
.86822 .42716 L
Mistroke
.86504 .43687 L
.86422 .43932 L
.86131 .44658 L
.8587 .45629 L
.8555 .46601 L
.85451 .46897 L
.85179 .47572 L
.84911 .48543 L
.84589 .49514 L
.84479 .49837 L
.84218 .50486 L
.83726 .51457 L
.8362 .52428 L
.83508 .52755 L
.83246 .53399 L
.8297 .54371 L
.82642 .55342 L
.82537 .55648 L
.82263 .56313 L
.81988 .57284 L
.81657 .58256 L
.81566 .58518 L
.81269 .59227 L
.80997 .60198 L
.80663 .61169 L
.80594 .61364 L
.80263 .62141 L
.79997 .63112 L
.7966 .64083 L
.79623 .64186 L
.79244 .65054 L
.78988 .66026 L
.78652 .66985 L
.78647 .66997 L
.7821 .67968 L
.7797 .68939 L
.77681 .69755 L
.77617 .69911 L
.77158 .70882 L
.76942 .71853 L
.76709 .725 L
.76573 .72824 L
.76085 .73796 L
.75904 .74767 L
.75738 .75221 L
.75514 .75738 L
.75207 .76709 L
.74855 .77681 L
.74767 .77918 L
.74435 .78652 L
Mistroke
.74152 .79623 L
.73796 .80594 L
.73796 .80594 L
.73332 .81566 L
.73085 .82537 L
.72824 .83237 L
.72706 .83508 L
.72195 .84479 L
.72007 .85451 L
.71853 .85854 L
.71594 .86422 L
.71283 .87393 L
.70916 .88364 L
.70882 .88452 L
.70449 .89336 L
.70184 .90307 L
.69911 .9102 L
.69795 .91278 L
.69256 .92249 L
.69073 .93221 L
.68939 .93559 L
.68635 .94192 L
.68326 .95163 L
.67968 .96083 L
.67945 .96134 L
.67424 .97106 L
.67193 .98077 L
Mfstroke
.3 g
.98077 .15871 m
.97893 .16492 L
.97598 .17463 L
.97298 .18434 L
.97106 .19057 L
.96997 .19406 L
.96697 .20377 L
.96476 .21348 L
.96134 .22217 L
.96102 .22319 L
.95799 .23291 L
.9561 .24262 L
.95208 .25233 L
.95163 .25356 L
.94896 .26204 L
.94742 .27176 L
.94314 .28147 L
.94192 .28473 L
.93987 .29118 L
.93872 .30089 L
.93415 .31061 L
.93221 .31566 L
.93071 .32032 L
.92762 .33003 L
.9251 .33974 L
.92249 .34634 L
.92148 .34946 L
.91837 .35917 L
.91598 .36888 L
.91278 .37678 L
.91219 .37859 L
.90905 .38831 L
.90679 .39802 L
.90307 .40698 L
.90282 .40773 L
.89965 .41744 L
.8975 .42716 L
.89338 .43687 L
.89336 .43693 L
.89018 .44658 L
.88812 .45629 L
.88389 .46601 L
.88364 .46666 L
.88064 .47572 L
.87862 .48543 L
.87431 .49514 L
.87393 .49613 L
.87101 .50486 L
.869 .51457 L
.86464 .52428 L
.86422 .52535 L
.8613 .53399 L
.85925 .54371 L
.85486 .55342 L
.85451 .55432 L
.85151 .56313 L
.84937 .57284 L
.84498 .58256 L
.84479 .58304 L
.84162 .59227 L
.83936 .60198 L
.83508 .6115 L
.83501 .61169 L
.83165 .62141 L
.82922 .63112 L
.82537 .63971 L
.82497 .64083 L
.82158 .65054 L
.81895 .66026 L
.81566 .66767 L
.81483 .66997 L
.81141 .67968 L
.80856 .68939 L
.80594 .69535 L
.80459 .69911 L
.80114 .70882 L
.79807 .71853 L
.79623 .72274 L
.79424 .72824 L
.79246 .73796 L
.78746 .74767 L
.78652 .74986 L
.78378 .75738 L
.78149 .76709 L
.77681 .7767 L
.77677 .77681 L
.7732 .78652 L
.77044 .79623 L
.76709 .80332 L
.7661 .80594 L
.76251 .81566 L
.75933 .82537 L
.75738 .82962 L
.75532 .83508 L
.75332 .84479 L
.74816 .85451 L
.74767 .8556 L
.7444 .86422 L
.74165 .87393 L
.73796 .88136 L
.73706 .88364 L
.73334 .89336 L
.73001 .90307 L
.72824 .90679 L
.7259 .91278 L
.7236 .92249 L
.71853 .93189 L
.7184 .93221 L
.71459 .94192 L
.7114 .95163 L
.70882 .95677 L
.70698 .96134 L
.70497 .97106 L
.69933 .98077 L
.98077 .98077 L
F
0 g
.98077 .15871 m
.97893 .16492 L
.97598 .17463 L
.97298 .18434 L
.97106 .19057 L
.96997 .19406 L
.96697 .20377 L
.96476 .21348 L
.96134 .22217 L
.96102 .22319 L
.95799 .23291 L
.9561 .24262 L
.95208 .25233 L
.95163 .25356 L
.94896 .26204 L
.94742 .27176 L
.94314 .28147 L
.94192 .28473 L
.93987 .29118 L
.93872 .30089 L
.93415 .31061 L
.93221 .31566 L
.93071 .32032 L
.92762 .33003 L
.9251 .33974 L
.92249 .34634 L
.92148 .34946 L
.91837 .35917 L
.91598 .36888 L
.91278 .37678 L
.91219 .37859 L
.90905 .38831 L
.90679 .39802 L
.90307 .40698 L
.90282 .40773 L
.89965 .41744 L
.8975 .42716 L
.89338 .43687 L
.89336 .43693 L
.89018 .44658 L
.88812 .45629 L
.88389 .46601 L
.88364 .46666 L
.88064 .47572 L
.87862 .48543 L
.87431 .49514 L
.87393 .49613 L
.87101 .50486 L
.869 .51457 L
.86464 .52428 L
Mistroke
.86422 .52535 L
.8613 .53399 L
.85925 .54371 L
.85486 .55342 L
.85451 .55432 L
.85151 .56313 L
.84937 .57284 L
.84498 .58256 L
.84479 .58304 L
.84162 .59227 L
.83936 .60198 L
.83508 .6115 L
.83501 .61169 L
.83165 .62141 L
.82922 .63112 L
.82537 .63971 L
.82497 .64083 L
.82158 .65054 L
.81895 .66026 L
.81566 .66767 L
.81483 .66997 L
.81141 .67968 L
.80856 .68939 L
.80594 .69535 L
.80459 .69911 L
.80114 .70882 L
.79807 .71853 L
.79623 .72274 L
.79424 .72824 L
.79246 .73796 L
.78746 .74767 L
.78652 .74986 L
.78378 .75738 L
.78149 .76709 L
.77681 .7767 L
.77677 .77681 L
.7732 .78652 L
.77044 .79623 L
.76709 .80332 L
.7661 .80594 L
.76251 .81566 L
.75933 .82537 L
.75738 .82962 L
.75532 .83508 L
.75332 .84479 L
.74816 .85451 L
.74767 .8556 L
.7444 .86422 L
.74165 .87393 L
.73796 .88136 L
Mistroke
.73706 .88364 L
.73334 .89336 L
.73001 .90307 L
.72824 .90679 L
.7259 .91278 L
.7236 .92249 L
.71853 .93189 L
.7184 .93221 L
.71459 .94192 L
.7114 .95163 L
.70882 .95677 L
.70698 .96134 L
.70497 .97106 L
.69933 .98077 L
Mfstroke
.4 g
.98077 .18307 m
.98039 .18434 L
.97749 .19406 L
.97452 .20377 L
.97135 .21348 L
.97106 .21506 L
.96891 .22319 L
.96583 .23291 L
.96269 .24262 L
.96134 .24682 L
.95995 .25233 L
.95693 .26204 L
.95376 .27176 L
.95163 .27836 L
.95088 .28147 L
.94795 .29118 L
.94477 .30089 L
.94192 .30967 L
.94171 .31061 L
.93891 .32032 L
.93572 .33003 L
.93253 .33974 L
.93221 .34074 L
.92978 .34946 L
.9266 .35917 L
.92338 .36888 L
.92249 .37159 L
.92057 .37859 L
.91741 .38831 L
.91416 .39802 L
.91278 .4022 L
.91129 .40773 L
.90815 .41744 L
.90488 .42716 L
.90307 .43258 L
.90192 .43687 L
.89881 .44658 L
.89552 .45629 L
.89336 .46272 L
.89249 .46601 L
.88939 .47572 L
.88608 .48543 L
.88364 .49261 L
.88298 .49514 L
.8799 .50486 L
.87656 .51457 L
.87393 .52227 L
.8734 .52428 L
.87032 .53399 L
.86697 .54371 L
.86422 .55168 L
.86376 .55342 L
.86067 .56313 L
.85729 .57284 L
.85451 .58085 L
.85404 .58256 L
.85092 .59227 L
.84752 .60198 L
.84479 .60976 L
.84426 .61169 L
.8411 .62141 L
.83766 .63112 L
.83508 .63843 L
.8344 .64083 L
.83118 .65054 L
.82771 .66026 L
.82537 .66685 L
.82446 .66997 L
.82117 .67968 L
.81767 .68939 L
.81566 .69501 L
.81442 .69911 L
.81106 .70882 L
.80753 .71853 L
.80594 .72291 L
.80429 .72824 L
.80084 .73796 L
.79728 .74767 L
.79623 .75056 L
.79404 .75738 L
.79052 .76709 L
.78693 .77681 L
.78652 .77793 L
.78368 .78652 L
.78009 .79623 L
.77681 .80505 L
.77654 .80594 L
.77319 .81566 L
.76955 .82537 L
.76709 .8319 L
.76608 .83508 L
.76258 .84479 L
.75889 .85451 L
.75738 .85848 L
.75546 .86422 L
.75183 .87393 L
.7481 .88364 L
.74767 .88478 L
.74468 .89336 L
.74096 .90307 L
.73796 .91081 L
.73731 .91278 L
.73374 .92249 L
.72995 .93221 L
.72824 .93656 L
.72639 .94192 L
.72264 .95163 L
.7188 .96134 L
.71853 .96203 L
.71525 .97106 L
.71139 .98077 L
.98077 .98077 L
F
0 g
.98077 .18307 m
.98039 .18434 L
.97749 .19406 L
.97452 .20377 L
.97135 .21348 L
.97106 .21506 L
.96891 .22319 L
.96583 .23291 L
.96269 .24262 L
.96134 .24682 L
.95995 .25233 L
.95693 .26204 L
.95376 .27176 L
.95163 .27836 L
.95088 .28147 L
.94795 .29118 L
.94477 .30089 L
.94192 .30967 L
.94171 .31061 L
.93891 .32032 L
.93572 .33003 L
.93253 .33974 L
.93221 .34074 L
.92978 .34946 L
.9266 .35917 L
.92338 .36888 L
.92249 .37159 L
.92057 .37859 L
.91741 .38831 L
.91416 .39802 L
.91278 .4022 L
.91129 .40773 L
.90815 .41744 L
.90488 .42716 L
.90307 .43258 L
.90192 .43687 L
.89881 .44658 L
.89552 .45629 L
.89336 .46272 L
.89249 .46601 L
.88939 .47572 L
.88608 .48543 L
.88364 .49261 L
.88298 .49514 L
.8799 .50486 L
.87656 .51457 L
.87393 .52227 L
.8734 .52428 L
.87032 .53399 L
.86697 .54371 L
Mistroke
.86422 .55168 L
.86376 .55342 L
.86067 .56313 L
.85729 .57284 L
.85451 .58085 L
.85404 .58256 L
.85092 .59227 L
.84752 .60198 L
.84479 .60976 L
.84426 .61169 L
.8411 .62141 L
.83766 .63112 L
.83508 .63843 L
.8344 .64083 L
.83118 .65054 L
.82771 .66026 L
.82537 .66685 L
.82446 .66997 L
.82117 .67968 L
.81767 .68939 L
.81566 .69501 L
.81442 .69911 L
.81106 .70882 L
.80753 .71853 L
.80594 .72291 L
.80429 .72824 L
.80084 .73796 L
.79728 .74767 L
.79623 .75056 L
.79404 .75738 L
.79052 .76709 L
.78693 .77681 L
.78652 .77793 L
.78368 .78652 L
.78009 .79623 L
.77681 .80505 L
.77654 .80594 L
.77319 .81566 L
.76955 .82537 L
.76709 .8319 L
.76608 .83508 L
.76258 .84479 L
.75889 .85451 L
.75738 .85848 L
.75546 .86422 L
.75183 .87393 L
.7481 .88364 L
.74767 .88478 L
.74468 .89336 L
.74096 .90307 L
Mistroke
.73796 .91081 L
.73731 .91278 L
.73374 .92249 L
.72995 .93221 L
.72824 .93656 L
.72639 .94192 L
.72264 .95163 L
.7188 .96134 L
.71853 .96203 L
.71525 .97106 L
.71139 .98077 L
Mfstroke
.5 g
.98077 .2033 m
.98063 .20377 L
.97587 .21348 L
.97416 .22319 L
.97174 .23291 L
.97106 .23536 L
.96892 .24262 L
.96594 .25233 L
.96293 .26204 L
.96134 .26721 L
.96001 .27176 L
.95703 .28147 L
.954 .29118 L
.95163 .29883 L
.95103 .30089 L
.94806 .31061 L
.94501 .32032 L
.94198 .33003 L
.94192 .33022 L
.93903 .33974 L
.93597 .34946 L
.9329 .35917 L
.93221 .36138 L
.92992 .36888 L
.92685 .37859 L
.92376 .38831 L
.92249 .39231 L
.92075 .39802 L
.91767 .40773 L
.91456 .41744 L
.91278 .42301 L
.91151 .42716 L
.90843 .43687 L
.90529 .44658 L
.90307 .45348 L
.9022 .45629 L
.89911 .46601 L
.89595 .47572 L
.89336 .48371 L
.89282 .48543 L
.88972 .49514 L
.88654 .50486 L
.88364 .5137 L
.88337 .51457 L
.88026 .52428 L
.87705 .53399 L
.87393 .54345 L
.87385 .54371 L
.87072 .55342 L
.86749 .56313 L
.86426 .57284 L
.86422 .57296 L
.8611 .58256 L
.85784 .59227 L
.85459 .60198 L
.85451 .60222 L
.8514 .61169 L
.84812 .62141 L
.84484 .63112 L
.84479 .63124 L
.84162 .64083 L
.83831 .65054 L
.83508 .66002 L
.835 .66026 L
.83175 .66997 L
.82842 .67968 L
.82537 .68854 L
.82509 .68939 L
.8218 .69911 L
.81843 .70882 L
.81566 .71681 L
.81508 .71853 L
.81175 .72824 L
.80835 .73796 L
.80594 .74483 L
.80498 .74767 L
.8016 .75738 L
.79817 .76709 L
.79623 .77259 L
.79478 .77681 L
.79136 .78652 L
.78789 .79623 L
.78652 .80008 L
.78448 .80594 L
.78101 .81566 L
.77751 .82537 L
.77681 .82732 L
.77407 .83508 L
.77055 .84479 L
.76709 .85429 L
.76702 .85451 L
.76354 .86422 L
.75998 .87393 L
.75738 .881 L
.75644 .88364 L
.75289 .89336 L
.74929 .90307 L
.74767 .90744 L
.74573 .91278 L
.74212 .92249 L
.73848 .93221 L
.73796 .9336 L
.73489 .94192 L
.73122 .95163 L
.72824 .95949 L
.72756 .96134 L
.72391 .97106 L
.72019 .98077 L
.98077 .98077 L
F
0 g
.98077 .2033 m
.98063 .20377 L
.97587 .21348 L
.97416 .22319 L
.97174 .23291 L
.97106 .23536 L
.96892 .24262 L
.96594 .25233 L
.96293 .26204 L
.96134 .26721 L
.96001 .27176 L
.95703 .28147 L
.954 .29118 L
.95163 .29883 L
.95103 .30089 L
.94806 .31061 L
.94501 .32032 L
.94198 .33003 L
.94192 .33022 L
.93903 .33974 L
.93597 .34946 L
.9329 .35917 L
.93221 .36138 L
.92992 .36888 L
.92685 .37859 L
.92376 .38831 L
.92249 .39231 L
.92075 .39802 L
.91767 .40773 L
.91456 .41744 L
.91278 .42301 L
.91151 .42716 L
.90843 .43687 L
.90529 .44658 L
.90307 .45348 L
.9022 .45629 L
.89911 .46601 L
.89595 .47572 L
.89336 .48371 L
.89282 .48543 L
.88972 .49514 L
.88654 .50486 L
.88364 .5137 L
.88337 .51457 L
.88026 .52428 L
.87705 .53399 L
.87393 .54345 L
.87385 .54371 L
.87072 .55342 L
.86749 .56313 L
Mistroke
.86426 .57284 L
.86422 .57296 L
.8611 .58256 L
.85784 .59227 L
.85459 .60198 L
.85451 .60222 L
.8514 .61169 L
.84812 .62141 L
.84484 .63112 L
.84479 .63124 L
.84162 .64083 L
.83831 .65054 L
.83508 .66002 L
.835 .66026 L
.83175 .66997 L
.82842 .67968 L
.82537 .68854 L
.82509 .68939 L
.8218 .69911 L
.81843 .70882 L
.81566 .71681 L
.81508 .71853 L
.81175 .72824 L
.80835 .73796 L
.80594 .74483 L
.80498 .74767 L
.8016 .75738 L
.79817 .76709 L
.79623 .77259 L
.79478 .77681 L
.79136 .78652 L
.78789 .79623 L
.78652 .80008 L
.78448 .80594 L
.78101 .81566 L
.77751 .82537 L
.77681 .82732 L
.77407 .83508 L
.77055 .84479 L
.76709 .85429 L
.76702 .85451 L
.76354 .86422 L
.75998 .87393 L
.75738 .881 L
.75644 .88364 L
.75289 .89336 L
.74929 .90307 L
.74767 .90744 L
.74573 .91278 L
.74212 .92249 L
Mistroke
.73848 .93221 L
.73796 .9336 L
.73489 .94192 L
.73122 .95163 L
.72824 .95949 L
.72756 .96134 L
.72391 .97106 L
.72019 .98077 L
Mfstroke
.6 g
.98077 .22257 m
.9805 .22319 L
.97734 .23291 L
.9746 .24262 L
.97177 .25233 L
.97106 .2547 L
.96882 .26204 L
.96583 .27176 L
.96286 .28147 L
.96134 .28661 L
.95995 .29118 L
.95694 .30089 L
.95394 .31061 L
.95163 .3183 L
.95101 .32032 L
.948 .33003 L
.94496 .33974 L
.94201 .34946 L
.94192 .34977 L
.93899 .35917 L
.93593 .36888 L
.93293 .37859 L
.93221 .381 L
.92992 .38831 L
.92684 .39802 L
.92379 .40773 L
.92249 .412 L
.92078 .41744 L
.91768 .42716 L
.9146 .43687 L
.91278 .44278 L
.91158 .44658 L
.90846 .45629 L
.90535 .46601 L
.90307 .47332 L
.90231 .47572 L
.89917 .48543 L
.89603 .49514 L
.89336 .50363 L
.89296 .50486 L
.88981 .51457 L
.88664 .52428 L
.88364 .5337 L
.88355 .53399 L
.88038 .54371 L
.87719 .55342 L
.87406 .56313 L
.87393 .56353 L
.87087 .57284 L
.86765 .58256 L
.86449 .59227 L
.86422 .59313 L
.86129 .60198 L
.85804 .61169 L
.85485 .62141 L
.85451 .62248 L
.85162 .63112 L
.84835 .64083 L
.84513 .65054 L
.84479 .65158 L
.84187 .66026 L
.83858 .66997 L
.83533 .67968 L
.83508 .68045 L
.83204 .68939 L
.82872 .69911 L
.82545 .70882 L
.82537 .70906 L
.82212 .71853 L
.81877 .72824 L
.81566 .73742 L
.81547 .73796 L
.81211 .74767 L
.80873 .75738 L
.80594 .76553 L
.8054 .76709 L
.802 .77681 L
.7986 .78652 L
.79623 .79339 L
.79523 .79623 L
.7918 .80594 L
.78837 .81566 L
.78652 .82098 L
.78497 .82537 L
.7815 .83508 L
.77804 .84479 L
.77681 .84832 L
.77459 .85451 L
.77109 .86422 L
.76761 .87393 L
.76709 .8754 L
.76411 .88364 L
.76057 .89336 L
.75738 .90221 L
.75707 .90307 L
.75351 .91278 L
.74994 .92249 L
.74767 .92876 L
.7464 .93221 L
.74279 .94192 L
.7392 .95163 L
.73796 .95504 L
.7356 .96134 L
.73196 .97106 L
.72834 .98077 L
.98077 .98077 L
F
0 g
.98077 .22257 m
.9805 .22319 L
.97734 .23291 L
.9746 .24262 L
.97177 .25233 L
.97106 .2547 L
.96882 .26204 L
.96583 .27176 L
.96286 .28147 L
.96134 .28661 L
.95995 .29118 L
.95694 .30089 L
.95394 .31061 L
.95163 .3183 L
.95101 .32032 L
.948 .33003 L
.94496 .33974 L
.94201 .34946 L
.94192 .34977 L
.93899 .35917 L
.93593 .36888 L
.93293 .37859 L
.93221 .381 L
.92992 .38831 L
.92684 .39802 L
.92379 .40773 L
.92249 .412 L
.92078 .41744 L
.91768 .42716 L
.9146 .43687 L
.91278 .44278 L
.91158 .44658 L
.90846 .45629 L
.90535 .46601 L
.90307 .47332 L
.90231 .47572 L
.89917 .48543 L
.89603 .49514 L
.89336 .50363 L
.89296 .50486 L
.88981 .51457 L
.88664 .52428 L
.88364 .5337 L
.88355 .53399 L
.88038 .54371 L
.87719 .55342 L
.87406 .56313 L
.87393 .56353 L
.87087 .57284 L
.86765 .58256 L
Mistroke
.86449 .59227 L
.86422 .59313 L
.86129 .60198 L
.85804 .61169 L
.85485 .62141 L
.85451 .62248 L
.85162 .63112 L
.84835 .64083 L
.84513 .65054 L
.84479 .65158 L
.84187 .66026 L
.83858 .66997 L
.83533 .67968 L
.83508 .68045 L
.83204 .68939 L
.82872 .69911 L
.82545 .70882 L
.82537 .70906 L
.82212 .71853 L
.81877 .72824 L
.81566 .73742 L
.81547 .73796 L
.81211 .74767 L
.80873 .75738 L
.80594 .76553 L
.8054 .76709 L
.802 .77681 L
.7986 .78652 L
.79623 .79339 L
.79523 .79623 L
.7918 .80594 L
.78837 .81566 L
.78652 .82098 L
.78497 .82537 L
.7815 .83508 L
.77804 .84479 L
.77681 .84832 L
.77459 .85451 L
.77109 .86422 L
.76761 .87393 L
.76709 .8754 L
.76411 .88364 L
.76057 .89336 L
.75738 .90221 L
.75707 .90307 L
.75351 .91278 L
.74994 .92249 L
.74767 .92876 L
.7464 .93221 L
.74279 .94192 L
Mistroke
.7392 .95163 L
.73796 .95504 L
.7356 .96134 L
.73196 .97106 L
.72834 .98077 L
Mfstroke
.7 g
.98077 .2428 m
.97789 .25233 L
.97501 .26204 L
.97207 .27176 L
.97106 .27501 L
.96902 .28147 L
.96592 .29118 L
.96292 .30089 L
.96134 .307 L
.96021 .31061 L
.9571 .32032 L
.95402 .33003 L
.95163 .33877 L
.95133 .33974 L
.94821 .34946 L
.94508 .35917 L
.94226 .36888 L
.94192 .37032 L
.93926 .37859 L
.9361 .38831 L
.93313 .39802 L
.93221 .40163 L
.93024 .40773 L
.92706 .41744 L
.92399 .42716 L
.92249 .43273 L
.92115 .43687 L
.91796 .44658 L
.91482 .45629 L
.91278 .46359 L
.912 .46601 L
.90879 .47572 L
.9056 .48543 L
.90307 .49422 L
.90277 .49514 L
.89955 .50486 L
.89632 .51457 L
.89344 .52428 L
.89336 .52462 L
.89023 .53399 L
.88698 .54371 L
.884 .55342 L
.88364 .55479 L
.88084 .56313 L
.87757 .57284 L
.87451 .58256 L
.87393 .58471 L
.87138 .59227 L
.86808 .60198 L
.86497 .61169 L
.86422 .6144 L
.86184 .62141 L
.85851 .63112 L
.85536 .64083 L
.85451 .64385 L
.85222 .65054 L
.84886 .66026 L
.84568 .66997 L
.84479 .67306 L
.84251 .67968 L
.83913 .68939 L
.83593 .69911 L
.83508 .70203 L
.83272 .70882 L
.82932 .71853 L
.8261 .72824 L
.82537 .73075 L
.82284 .73796 L
.81941 .74767 L
.81619 .75738 L
.81566 .75922 L
.81287 .76709 L
.80942 .77681 L
.80621 .78652 L
.80594 .78745 L
.80281 .79623 L
.79934 .80594 L
.79623 .81542 L
.79615 .81566 L
.79264 .82537 L
.78916 .83508 L
.78652 .84313 L
.78592 .84479 L
.78238 .85451 L
.77889 .86422 L
.77681 .87059 L
.77559 .87393 L
.77201 .88364 L
.76854 .89336 L
.76709 .89779 L
.76515 .90307 L
.76154 .91278 L
.7581 .92249 L
.75738 .92473 L
.75459 .93221 L
.75097 .94192 L
.74767 .95142 L
.74759 .95163 L
.74392 .96134 L
.74029 .97106 L
.73796 .97783 L
.73684 .98077 L
.98077 .98077 L
F
0 g
.98077 .2428 m
.97789 .25233 L
.97501 .26204 L
.97207 .27176 L
.97106 .27501 L
.96902 .28147 L
.96592 .29118 L
.96292 .30089 L
.96134 .307 L
.96021 .31061 L
.9571 .32032 L
.95402 .33003 L
.95163 .33877 L
.95133 .33974 L
.94821 .34946 L
.94508 .35917 L
.94226 .36888 L
.94192 .37032 L
.93926 .37859 L
.9361 .38831 L
.93313 .39802 L
.93221 .40163 L
.93024 .40773 L
.92706 .41744 L
.92399 .42716 L
.92249 .43273 L
.92115 .43687 L
.91796 .44658 L
.91482 .45629 L
.91278 .46359 L
.912 .46601 L
.90879 .47572 L
.9056 .48543 L
.90307 .49422 L
.90277 .49514 L
.89955 .50486 L
.89632 .51457 L
.89344 .52428 L
.89336 .52462 L
.89023 .53399 L
.88698 .54371 L
.884 .55342 L
.88364 .55479 L
.88084 .56313 L
.87757 .57284 L
.87451 .58256 L
.87393 .58471 L
.87138 .59227 L
.86808 .60198 L
.86497 .61169 L
Mistroke
.86422 .6144 L
.86184 .62141 L
.85851 .63112 L
.85536 .64083 L
.85451 .64385 L
.85222 .65054 L
.84886 .66026 L
.84568 .66997 L
.84479 .67306 L
.84251 .67968 L
.83913 .68939 L
.83593 .69911 L
.83508 .70203 L
.83272 .70882 L
.82932 .71853 L
.8261 .72824 L
.82537 .73075 L
.82284 .73796 L
.81941 .74767 L
.81619 .75738 L
.81566 .75922 L
.81287 .76709 L
.80942 .77681 L
.80621 .78652 L
.80594 .78745 L
.80281 .79623 L
.79934 .80594 L
.79623 .81542 L
.79615 .81566 L
.79264 .82537 L
.78916 .83508 L
.78652 .84313 L
.78592 .84479 L
.78238 .85451 L
.77889 .86422 L
.77681 .87059 L
.77559 .87393 L
.77201 .88364 L
.76854 .89336 L
.76709 .89779 L
.76515 .90307 L
.76154 .91278 L
.7581 .92249 L
.75738 .92473 L
.75459 .93221 L
.75097 .94192 L
.74767 .95142 L
.74759 .95163 L
.74392 .96134 L
.74029 .97106 L
Mistroke
.73796 .97783 L
.73684 .98077 L
Mfstroke
.8 g
.98077 .26715 m
.97949 .27176 L
.97673 .28147 L
.9738 .29118 L
.97106 .29952 L
.97058 .30089 L
.96676 .31061 L
.96481 .32032 L
.96185 .33003 L
.96134 .33165 L
.9583 .33974 L
.95597 .34946 L
.95299 .35917 L
.95163 .36355 L
.94968 .36888 L
.94538 .37859 L
.94408 .38831 L
.94192 .39526 L
.94092 .39802 L
.93689 .40773 L
.93511 .41744 L
.93221 .42675 L
.93206 .42716 L
.92822 .43687 L
.92608 .44658 L
.92303 .45629 L
.92249 .45798 L
.91939 .46601 L
.91698 .47572 L
.91392 .48543 L
.91278 .489 L
.91044 .49514 L
.9059 .50486 L
.90475 .51457 L
.90307 .5198 L
.90138 .52428 L
.89703 .53399 L
.89551 .54371 L
.89336 .55038 L
.89222 .55342 L
.888 .56313 L
.8862 .57284 L
.88364 .58073 L
.88296 .58256 L
.87883 .59227 L
.87682 .60198 L
.87393 .61085 L
.87362 .61169 L
.86955 .62141 L
.86738 .63112 L
.86422 .64074 L
.86418 .64083 L
.86015 .65054 L
.85786 .66026 L
.85464 .66997 L
.85451 .67038 L
.85064 .67968 L
.84826 .68939 L
.84503 .69911 L
.84479 .69978 L
.84102 .70882 L
.83859 .71853 L
.83533 .72824 L
.83508 .72896 L
.83129 .73796 L
.82884 .74767 L
.82555 .75738 L
.82537 .7579 L
.82144 .76709 L
.819 .77681 L
.81569 .78652 L
.81566 .7866 L
.81148 .79623 L
.80908 .80594 L
.80594 .81505 L
.80571 .81566 L
.80138 .82537 L
.79908 .83508 L
.79623 .84325 L
.79561 .84479 L
.79114 .85451 L
.78898 .86422 L
.78652 .8712 L
.7854 .87393 L
.78072 .88364 L
.77879 .89336 L
.77681 .89891 L
.77506 .90307 L
.7701 .91278 L
.7685 .92249 L
.76709 .92637 L
.76457 .93221 L
.7616 .94192 L
.75811 .95163 L
.75738 .9536 L
.7539 .96134 L
.75114 .97106 L
.74767 .98061 L
.7476 .98077 L
.98077 .98077 L
F
0 g
.98077 .26715 m
.97949 .27176 L
.97673 .28147 L
.9738 .29118 L
.97106 .29952 L
.97058 .30089 L
.96676 .31061 L
.96481 .32032 L
.96185 .33003 L
.96134 .33165 L
.9583 .33974 L
.95597 .34946 L
.95299 .35917 L
.95163 .36355 L
.94968 .36888 L
.94538 .37859 L
.94408 .38831 L
.94192 .39526 L
.94092 .39802 L
.93689 .40773 L
.93511 .41744 L
.93221 .42675 L
.93206 .42716 L
.92822 .43687 L
.92608 .44658 L
.92303 .45629 L
.92249 .45798 L
.91939 .46601 L
.91698 .47572 L
.91392 .48543 L
.91278 .489 L
.91044 .49514 L
.9059 .50486 L
.90475 .51457 L
.90307 .5198 L
.90138 .52428 L
.89703 .53399 L
.89551 .54371 L
.89336 .55038 L
.89222 .55342 L
.888 .56313 L
.8862 .57284 L
.88364 .58073 L
.88296 .58256 L
.87883 .59227 L
.87682 .60198 L
.87393 .61085 L
.87362 .61169 L
.86955 .62141 L
.86738 .63112 L
Mistroke
.86422 .64074 L
.86418 .64083 L
.86015 .65054 L
.85786 .66026 L
.85464 .66997 L
.85451 .67038 L
.85064 .67968 L
.84826 .68939 L
.84503 .69911 L
.84479 .69978 L
.84102 .70882 L
.83859 .71853 L
.83533 .72824 L
.83508 .72896 L
.83129 .73796 L
.82884 .74767 L
.82555 .75738 L
.82537 .7579 L
.82144 .76709 L
.819 .77681 L
.81569 .78652 L
.81566 .7866 L
.81148 .79623 L
.80908 .80594 L
.80594 .81505 L
.80571 .81566 L
.80138 .82537 L
.79908 .83508 L
.79623 .84325 L
.79561 .84479 L
.79114 .85451 L
.78898 .86422 L
.78652 .8712 L
.7854 .87393 L
.78072 .88364 L
.77879 .89336 L
.77681 .89891 L
.77506 .90307 L
.7701 .91278 L
.7685 .92249 L
.76709 .92637 L
.76457 .93221 L
.7616 .94192 L
.75811 .95163 L
.75738 .9536 L
.7539 .96134 L
.75114 .97106 L
.74767 .98061 L
.7476 .98077 L
Mfstroke
.7 g
.98077 .36008 m
.97816 .36888 L
.97519 .37859 L
.97218 .38831 L
.97106 .39194 L
.96917 .39802 L
.96829 .40773 L
.96368 .41744 L
.96134 .42357 L
.96022 .42716 L
.9572 .43687 L
.95493 .44658 L
.95163 .45495 L
.9512 .45629 L
.94816 .46601 L
.94616 .47572 L
.94216 .48543 L
.94192 .48609 L
.93905 .49514 L
.93735 .50486 L
.93313 .51457 L
.93221 .51703 L
.92989 .52428 L
.9285 .53399 L
.92403 .54371 L
.92249 .54772 L
.92065 .55342 L
.91958 .56313 L
.91487 .57284 L
.91278 .57818 L
.91135 .58256 L
.90822 .59227 L
.90563 .60198 L
.90307 .60838 L
.90198 .61169 L
.89882 .62141 L
.89631 .63112 L
.89336 .63835 L
.89253 .64083 L
.88934 .65054 L
.88689 .66026 L
.88364 .66806 L
.883 .66997 L
.87979 .67968 L
.87736 .68939 L
.87393 .69753 L
.8734 .69911 L
.87015 .70882 L
.86772 .71853 L
.86422 .72675 L
.86371 .72824 L
.86044 .73796 L
.85797 .74767 L
.85451 .75573 L
.85393 .75738 L
.85063 .76709 L
.84809 .77681 L
.84479 .78445 L
.84407 .78652 L
.84074 .79623 L
.83809 .80594 L
.83508 .81291 L
.83412 .81566 L
.83076 .82537 L
.82797 .83508 L
.82537 .84112 L
.82407 .84479 L
.82068 .85451 L
.81773 .86422 L
.81566 .86905 L
.81392 .87393 L
.81242 .88364 L
.80738 .89336 L
.80594 .89672 L
.80367 .90307 L
.80174 .91278 L
.79691 .92249 L
.79623 .92411 L
.79331 .93221 L
.79096 .94192 L
.78652 .95123 L
.78637 .95163 L
.78284 .96134 L
.78009 .97106 L
.77681 .97776 L
.77582 .98077 L
.98077 .98077 L
F
0 g
.98077 .36008 m
.97816 .36888 L
.97519 .37859 L
.97218 .38831 L
.97106 .39194 L
.96917 .39802 L
.96829 .40773 L
.96368 .41744 L
.96134 .42357 L
.96022 .42716 L
.9572 .43687 L
.95493 .44658 L
.95163 .45495 L
.9512 .45629 L
.94816 .46601 L
.94616 .47572 L
.94216 .48543 L
.94192 .48609 L
.93905 .49514 L
.93735 .50486 L
.93313 .51457 L
.93221 .51703 L
.92989 .52428 L
.9285 .53399 L
.92403 .54371 L
.92249 .54772 L
.92065 .55342 L
.91958 .56313 L
.91487 .57284 L
.91278 .57818 L
.91135 .58256 L
.90822 .59227 L
.90563 .60198 L
.90307 .60838 L
.90198 .61169 L
.89882 .62141 L
.89631 .63112 L
.89336 .63835 L
.89253 .64083 L
.88934 .65054 L
.88689 .66026 L
.88364 .66806 L
.883 .66997 L
.87979 .67968 L
.87736 .68939 L
.87393 .69753 L
.8734 .69911 L
.87015 .70882 L
.86772 .71853 L
.86422 .72675 L
Mistroke
.86371 .72824 L
.86044 .73796 L
.85797 .74767 L
.85451 .75573 L
.85393 .75738 L
.85063 .76709 L
.84809 .77681 L
.84479 .78445 L
.84407 .78652 L
.84074 .79623 L
.83809 .80594 L
.83508 .81291 L
.83412 .81566 L
.83076 .82537 L
.82797 .83508 L
.82537 .84112 L
.82407 .84479 L
.82068 .85451 L
.81773 .86422 L
.81566 .86905 L
.81392 .87393 L
.81242 .88364 L
.80738 .89336 L
.80594 .89672 L
.80367 .90307 L
.80174 .91278 L
.79691 .92249 L
.79623 .92411 L
.79331 .93221 L
.79096 .94192 L
.78652 .95123 L
.78637 .95163 L
.78284 .96134 L
.78009 .97106 L
.77681 .97776 L
.77582 .98077 L
Mfstroke
.6 g
.98077 .38445 m
.97963 .38831 L
.9767 .39802 L
.97126 .40773 L
.97106 .41644 L
.97084 .41744 L
.96812 .42716 L
.96499 .43687 L
.96186 .44658 L
.96134 .4482 L
.95919 .45629 L
.95609 .46601 L
.95292 .47572 L
.95163 .47974 L
.95017 .48543 L
.94712 .49514 L
.94393 .50486 L
.94192 .51105 L
.94105 .51457 L
.93807 .52428 L
.93487 .53399 L
.93221 .54213 L
.93183 .54371 L
.92896 .55342 L
.92574 .56313 L
.92254 .57284 L
.92249 .57297 L
.91976 .58256 L
.91655 .59227 L
.91331 .60198 L
.91278 .60358 L
.91049 .61169 L
.90728 .62141 L
.90401 .63112 L
.90307 .63396 L
.90114 .64083 L
.89794 .65054 L
.89465 .66026 L
.89336 .6641 L
.89172 .66997 L
.88852 .67968 L
.8852 .68939 L
.88364 .694 L
.88222 .69911 L
.87902 .70882 L
.87568 .71853 L
.87393 .72365 L
.87265 .72824 L
.86944 .73796 L
.86607 .74767 L
.86422 .75307 L
.863 .75738 L
.85978 .76709 L
.85639 .77681 L
.85451 .78223 L
.85328 .78652 L
.85003 .79623 L
.84661 .80594 L
.84479 .81115 L
.84348 .81566 L
.84019 .82537 L
.83675 .83508 L
.83508 .83982 L
.8336 .84479 L
.83027 .85451 L
.82679 .86422 L
.82537 .86823 L
.82363 .87393 L
.82024 .88364 L
.81674 .89336 L
.81566 .89639 L
.81357 .90307 L
.81012 .91278 L
.80659 .92249 L
.80594 .92429 L
.8034 .93221 L
.7999 .94192 L
.79634 .95163 L
.79623 .95194 L
.79313 .96134 L
.78957 .97106 L
.78652 .9793 L
.78609 .98077 L
.98077 .98077 L
F
0 g
.98077 .38445 m
.97963 .38831 L
.9767 .39802 L
.97126 .40773 L
.97106 .41644 L
.97084 .41744 L
.96812 .42716 L
.96499 .43687 L
.96186 .44658 L
.96134 .4482 L
.95919 .45629 L
.95609 .46601 L
.95292 .47572 L
.95163 .47974 L
.95017 .48543 L
.94712 .49514 L
.94393 .50486 L
.94192 .51105 L
.94105 .51457 L
.93807 .52428 L
.93487 .53399 L
.93221 .54213 L
.93183 .54371 L
.92896 .55342 L
.92574 .56313 L
.92254 .57284 L
.92249 .57297 L
.91976 .58256 L
.91655 .59227 L
.91331 .60198 L
.91278 .60358 L
.91049 .61169 L
.90728 .62141 L
.90401 .63112 L
.90307 .63396 L
.90114 .64083 L
.89794 .65054 L
.89465 .66026 L
.89336 .6641 L
.89172 .66997 L
.88852 .67968 L
.8852 .68939 L
.88364 .694 L
.88222 .69911 L
.87902 .70882 L
.87568 .71853 L
.87393 .72365 L
.87265 .72824 L
.86944 .73796 L
.86607 .74767 L
Mistroke
.86422 .75307 L
.863 .75738 L
.85978 .76709 L
.85639 .77681 L
.85451 .78223 L
.85328 .78652 L
.85003 .79623 L
.84661 .80594 L
.84479 .81115 L
.84348 .81566 L
.84019 .82537 L
.83675 .83508 L
.83508 .83982 L
.8336 .84479 L
.83027 .85451 L
.82679 .86422 L
.82537 .86823 L
.82363 .87393 L
.82024 .88364 L
.81674 .89336 L
.81566 .89639 L
.81357 .90307 L
.81012 .91278 L
.80659 .92249 L
.80594 .92429 L
.8034 .93221 L
.7999 .94192 L
.79634 .95163 L
.79623 .95194 L
.79313 .96134 L
.78957 .97106 L
.78652 .9793 L
.78609 .98077 L
Mfstroke
.5 g
.98077 .40468 m
.97778 .40773 L
.97547 .41744 L
.97358 .42716 L
.97106 .43675 L
.97102 .43687 L
.96814 .44658 L
.96514 .45629 L
.96214 .46601 L
.96134 .46859 L
.95923 .47572 L
.95623 .48543 L
.9532 .49514 L
.95163 .50021 L
.95026 .50486 L
.94726 .51457 L
.9442 .52428 L
.94192 .5316 L
.94121 .53399 L
.93822 .54371 L
.93515 .55342 L
.93221 .56276 L
.9321 .56313 L
.92912 .57284 L
.92603 .58256 L
.92294 .59227 L
.92249 .5937 L
.91995 .60198 L
.91685 .61169 L
.91373 .62141 L
.91278 .6244 L
.91071 .63112 L
.90759 .64083 L
.90445 .65054 L
.90307 .65486 L
.9014 .66026 L
.89827 .66997 L
.89511 .67968 L
.89336 .68509 L
.89202 .68939 L
.88888 .69911 L
.88569 .70882 L
.88364 .71508 L
.88256 .71853 L
.87941 .72824 L
.8762 .73796 L
.87393 .74483 L
.87304 .74767 L
.86986 .75738 L
.86663 .76709 L
.86422 .77434 L
.86343 .77681 L
.86024 .78652 L
.85698 .79623 L
.85451 .80361 L
.85376 .80594 L
.85054 .81566 L
.84725 .82537 L
.84479 .83263 L
.844 .83508 L
.84075 .84479 L
.83743 .85451 L
.83508 .8614 L
.83416 .86422 L
.83087 .87393 L
.82753 .88364 L
.82537 .88992 L
.82423 .89336 L
.82091 .90307 L
.81753 .91278 L
.81566 .91819 L
.81421 .92249 L
.81085 .93221 L
.80744 .94192 L
.80594 .94621 L
.8041 .95163 L
.80069 .96134 L
.79726 .97106 L
.79623 .97397 L
.79388 .98077 L
.98077 .98077 L
F
0 g
.98077 .40468 m
.97778 .40773 L
.97547 .41744 L
.97358 .42716 L
.97106 .43675 L
.97102 .43687 L
.96814 .44658 L
.96514 .45629 L
.96214 .46601 L
.96134 .46859 L
.95923 .47572 L
.95623 .48543 L
.9532 .49514 L
.95163 .50021 L
.95026 .50486 L
.94726 .51457 L
.9442 .52428 L
.94192 .5316 L
.94121 .53399 L
.93822 .54371 L
.93515 .55342 L
.93221 .56276 L
.9321 .56313 L
.92912 .57284 L
.92603 .58256 L
.92294 .59227 L
.92249 .5937 L
.91995 .60198 L
.91685 .61169 L
.91373 .62141 L
.91278 .6244 L
.91071 .63112 L
.90759 .64083 L
.90445 .65054 L
.90307 .65486 L
.9014 .66026 L
.89827 .66997 L
.89511 .67968 L
.89336 .68509 L
.89202 .68939 L
.88888 .69911 L
.88569 .70882 L
.88364 .71508 L
.88256 .71853 L
.87941 .72824 L
.8762 .73796 L
.87393 .74483 L
.87304 .74767 L
.86986 .75738 L
.86663 .76709 L
Mistroke
.86422 .77434 L
.86343 .77681 L
.86024 .78652 L
.85698 .79623 L
.85451 .80361 L
.85376 .80594 L
.85054 .81566 L
.84725 .82537 L
.84479 .83263 L
.844 .83508 L
.84075 .84479 L
.83743 .85451 L
.83508 .8614 L
.83416 .86422 L
.83087 .87393 L
.82753 .88364 L
.82537 .88992 L
.82423 .89336 L
.82091 .90307 L
.81753 .91278 L
.81566 .91819 L
.81421 .92249 L
.81085 .93221 L
.80744 .94192 L
.80594 .94621 L
.8041 .95163 L
.80069 .96134 L
.79726 .97106 L
.79623 .97397 L
.79388 .98077 L
Mfstroke
.4 g
.98077 .42395 m
.97953 .42716 L
.97661 .43687 L
.97386 .44658 L
.97106 .45609 L
.97099 .45629 L
.96803 .46601 L
.96503 .47572 L
.96209 .48543 L
.96134 .488 L
.95916 .49514 L
.95614 .50486 L
.95315 .51457 L
.95163 .51969 L
.95022 .52428 L
.94719 .53399 L
.94416 .54371 L
.94192 .55115 L
.94122 .55342 L
.93818 .56313 L
.93512 .57284 L
.93221 .58238 L
.93215 .58256 L
.9291 .59227 L
.92602 .60198 L
.923 .61169 L
.92249 .61339 L
.91996 .62141 L
.91686 .63112 L
.9138 .64083 L
.91278 .64416 L
.91076 .65054 L
.90763 .66026 L
.90454 .66997 L
.90307 .67471 L
.90148 .67968 L
.89834 .68939 L
.89521 .69911 L
.89336 .70501 L
.89213 .70882 L
.88897 .71853 L
.88581 .72824 L
.88364 .73508 L
.88271 .73796 L
.87953 .74767 L
.87634 .75738 L
.87393 .76492 L
.87322 .76709 L
.87002 .77681 L
.8668 .78652 L
.86422 .79451 L
.86365 .79623 L
.86042 .80594 L
.85718 .81566 L
.85451 .82386 L
.85401 .82537 L
.85075 .83508 L
.84749 .84479 L
.84479 .85297 L
.84428 .85451 L
.841 .86422 L
.8377 .87393 L
.83508 .88183 L
.83447 .88364 L
.83116 .89336 L
.82784 .90307 L
.82537 .91044 L
.82457 .91278 L
.82123 .92249 L
.81788 .93221 L
.81566 .9388 L
.81459 .94192 L
.81121 .95163 L
.80784 .96134 L
.80594 .96691 L
.8045 .97106 L
.8011 .98077 L
.98077 .98077 L
F
0 g
.98077 .42395 m
.97953 .42716 L
.97661 .43687 L
.97386 .44658 L
.97106 .45609 L
.97099 .45629 L
.96803 .46601 L
.96503 .47572 L
.96209 .48543 L
.96134 .488 L
.95916 .49514 L
.95614 .50486 L
.95315 .51457 L
.95163 .51969 L
.95022 .52428 L
.94719 .53399 L
.94416 .54371 L
.94192 .55115 L
.94122 .55342 L
.93818 .56313 L
.93512 .57284 L
.93221 .58238 L
.93215 .58256 L
.9291 .59227 L
.92602 .60198 L
.923 .61169 L
.92249 .61339 L
.91996 .62141 L
.91686 .63112 L
.9138 .64083 L
.91278 .64416 L
.91076 .65054 L
.90763 .66026 L
.90454 .66997 L
.90307 .67471 L
.90148 .67968 L
.89834 .68939 L
.89521 .69911 L
.89336 .70501 L
.89213 .70882 L
.88897 .71853 L
.88581 .72824 L
.88364 .73508 L
.88271 .73796 L
.87953 .74767 L
.87634 .75738 L
.87393 .76492 L
.87322 .76709 L
.87002 .77681 L
.8668 .78652 L
Mistroke
.86422 .79451 L
.86365 .79623 L
.86042 .80594 L
.85718 .81566 L
.85451 .82386 L
.85401 .82537 L
.85075 .83508 L
.84749 .84479 L
.84479 .85297 L
.84428 .85451 L
.841 .86422 L
.8377 .87393 L
.83508 .88183 L
.83447 .88364 L
.83116 .89336 L
.82784 .90307 L
.82537 .91044 L
.82457 .91278 L
.82123 .92249 L
.81788 .93221 L
.81566 .9388 L
.81459 .94192 L
.81121 .95163 L
.80784 .96134 L
.80594 .96691 L
.8045 .97106 L
.8011 .98077 L
Mfstroke
.3 g
.98077 .44418 m
.98002 .44658 L
.97713 .45629 L
.97424 .46601 L
.97127 .47572 L
.97106 .4764 L
.9682 .48543 L
.9651 .49514 L
.9622 .50486 L
.96134 .50838 L
.95939 .51457 L
.95627 .52428 L
.95324 .53399 L
.95163 .54016 L
.95051 .54371 L
.94737 .55342 L
.94428 .56313 L
.94192 .5717 L
.94156 .57284 L
.93842 .58256 L
.93527 .59227 L
.93245 .60198 L
.93221 .60302 L
.9294 .61169 L
.92622 .62141 L
.92326 .63112 L
.92249 .63411 L
.92031 .64083 L
.91711 .65054 L
.91405 .66026 L
.91278 .66497 L
.91115 .66997 L
.90793 .67968 L
.9048 .68939 L
.90307 .6956 L
.90192 .69911 L
.89868 .70882 L
.8955 .71853 L
.89336 .72601 L
.89262 .72824 L
.88936 .73796 L
.88614 .74767 L
.88364 .75617 L
.88324 .75738 L
.87997 .76709 L
.87671 .77681 L
.87393 .7861 L
.87379 .78652 L
.8705 .79623 L
.86721 .80594 L
.86425 .81566 L
.86422 .81579 L
.86095 .82537 L
.85764 .83508 L
.85463 .84479 L
.85451 .84524 L
.85132 .85451 L
.84798 .86422 L
.84493 .87393 L
.84479 .87445 L
.84161 .88364 L
.83825 .89336 L
.83518 .90307 L
.83508 .90342 L
.83181 .91278 L
.82843 .92249 L
.82537 .93214 L
.82535 .93221 L
.82193 .94192 L
.81852 .95163 L
.81566 .96061 L
.8154 .96134 L
.81195 .97106 L
.80853 .98077 L
.98077 .98077 L
F
0 g
.98077 .44418 m
.98002 .44658 L
.97713 .45629 L
.97424 .46601 L
.97127 .47572 L
.97106 .4764 L
.9682 .48543 L
.9651 .49514 L
.9622 .50486 L
.96134 .50838 L
.95939 .51457 L
.95627 .52428 L
.95324 .53399 L
.95163 .54016 L
.95051 .54371 L
.94737 .55342 L
.94428 .56313 L
.94192 .5717 L
.94156 .57284 L
.93842 .58256 L
.93527 .59227 L
.93245 .60198 L
.93221 .60302 L
.9294 .61169 L
.92622 .62141 L
.92326 .63112 L
.92249 .63411 L
.92031 .64083 L
.91711 .65054 L
.91405 .66026 L
.91278 .66497 L
.91115 .66997 L
.90793 .67968 L
.9048 .68939 L
.90307 .6956 L
.90192 .69911 L
.89868 .70882 L
.8955 .71853 L
.89336 .72601 L
.89262 .72824 L
.88936 .73796 L
.88614 .74767 L
.88364 .75617 L
.88324 .75738 L
.87997 .76709 L
.87671 .77681 L
.87393 .7861 L
.87379 .78652 L
.8705 .79623 L
.86721 .80594 L
Mistroke
.86425 .81566 L
.86422 .81579 L
.86095 .82537 L
.85764 .83508 L
.85463 .84479 L
.85451 .84524 L
.85132 .85451 L
.84798 .86422 L
.84493 .87393 L
.84479 .87445 L
.84161 .88364 L
.83825 .89336 L
.83518 .90307 L
.83508 .90342 L
.83181 .91278 L
.82843 .92249 L
.82537 .93214 L
.82535 .93221 L
.82193 .94192 L
.81852 .95163 L
.81566 .96061 L
.8154 .96134 L
.81195 .97106 L
.80853 .98077 L
Mfstroke
.2 g
.98077 .46854 m
.97877 .47572 L
.97597 .48543 L
.97298 .49514 L
.97106 .50089 L
.96964 .50486 L
.96557 .51457 L
.96403 .52428 L
.96134 .53304 L
.96101 .53399 L
.9572 .54371 L
.95518 .55342 L
.9522 .56313 L
.95163 .56495 L
.94865 .57284 L
.94628 .58256 L
.94328 .59227 L
.94192 .59663 L
.93994 .60198 L
.93562 .61169 L
.93431 .62141 L
.93221 .62812 L
.93111 .63112 L
.92703 .64083 L
.92527 .65054 L
.92249 .65938 L
.92218 .66026 L
.91827 .66997 L
.91617 .67968 L
.91311 .68939 L
.91278 .6904 L
.90936 .69911 L
.90701 .70882 L
.90393 .71853 L
.90307 .72118 L
.90033 .72824 L
.89561 .73796 L
.89468 .74767 L
.89336 .75175 L
.89119 .75738 L
.88665 .76709 L
.88537 .77681 L
.88364 .7821 L
.88195 .78652 L
.87753 .79623 L
.87599 .80594 L
.87393 .81222 L
.87262 .81566 L
.86828 .82537 L
.86653 .83508 L
.86422 .8421 L
.86319 .84479 L
.8589 .85451 L
.85701 .86422 L
.85451 .87175 L
.85367 .87393 L
.84939 .88364 L
.8474 .89336 L
.84479 .90116 L
.84406 .90307 L
.83977 .91278 L
.83773 .92249 L
.83508 .93034 L
.83436 .93221 L
.83003 .94192 L
.82797 .95163 L
.82537 .95927 L
.82456 .96134 L
.82016 .97106 L
.81812 .98077 L
.98077 .98077 L
F
0 g
.98077 .46854 m
.97877 .47572 L
.97597 .48543 L
.97298 .49514 L
.97106 .50089 L
.96964 .50486 L
.96557 .51457 L
.96403 .52428 L
.96134 .53304 L
.96101 .53399 L
.9572 .54371 L
.95518 .55342 L
.9522 .56313 L
.95163 .56495 L
.94865 .57284 L
.94628 .58256 L
.94328 .59227 L
.94192 .59663 L
.93994 .60198 L
.93562 .61169 L
.93431 .62141 L
.93221 .62812 L
.93111 .63112 L
.92703 .64083 L
.92527 .65054 L
.92249 .65938 L
.92218 .66026 L
.91827 .66997 L
.91617 .67968 L
.91311 .68939 L
.91278 .6904 L
.90936 .69911 L
.90701 .70882 L
.90393 .71853 L
.90307 .72118 L
.90033 .72824 L
.89561 .73796 L
.89468 .74767 L
.89336 .75175 L
.89119 .75738 L
.88665 .76709 L
.88537 .77681 L
.88364 .7821 L
.88195 .78652 L
.87753 .79623 L
.87599 .80594 L
.87393 .81222 L
.87262 .81566 L
.86828 .82537 L
.86653 .83508 L
Mistroke
.86422 .8421 L
.86319 .84479 L
.8589 .85451 L
.85701 .86422 L
.85451 .87175 L
.85367 .87393 L
.84939 .88364 L
.8474 .89336 L
.84479 .90116 L
.84406 .90307 L
.83977 .91278 L
.83773 .92249 L
.83508 .93034 L
.83436 .93221 L
.83003 .94192 L
.82797 .95163 L
.82537 .95927 L
.82456 .96134 L
.82016 .97106 L
.81812 .98077 L
Mfstroke
.3 g
.98077 .56148 m
.98028 .56313 L
.97738 .57284 L
.97439 .58256 L
.97138 .59227 L
.97106 .59331 L
.96837 .60198 L
.9669 .61169 L
.96265 .62141 L
.96134 .62495 L
.95941 .63112 L
.95845 .64083 L
.95385 .65054 L
.95163 .65635 L
.95039 .66026 L
.94735 .66997 L
.945 .67968 L
.94192 .6875 L
.94131 .68939 L
.93824 .69911 L
.93612 .70882 L
.93221 .7184 L
.93216 .71853 L
.92907 .72824 L
.92717 .73796 L
.92303 .74767 L
.92249 .74909 L
.91983 .75738 L
.91817 .76709 L
.91383 .77681 L
.91278 .77955 L
.91052 .78652 L
.90908 .79623 L
.90455 .80594 L
.90307 .80976 L
.90114 .81566 L
.89989 .82537 L
.8952 .83508 L
.89336 .83973 L
.89168 .84479 L
.89059 .85451 L
.88575 .86422 L
.88364 .86945 L
.88215 .87393 L
.87894 .88364 L
.8762 .89336 L
.87393 .89893 L
.87253 .90307 L
.86929 .91278 L
.86655 .92249 L
.86422 .92815 L
.86284 .93221 L
.85957 .94192 L
.85678 .95163 L
.85451 .95712 L
.85306 .96134 L
.84976 .97106 L
.84691 .98077 L
.98077 .98077 L
F
0 g
.98077 .56148 m
.98028 .56313 L
.97738 .57284 L
.97439 .58256 L
.97138 .59227 L
.97106 .59331 L
.96837 .60198 L
.9669 .61169 L
.96265 .62141 L
.96134 .62495 L
.95941 .63112 L
.95845 .64083 L
.95385 .65054 L
.95163 .65635 L
.95039 .66026 L
.94735 .66997 L
.945 .67968 L
.94192 .6875 L
.94131 .68939 L
.93824 .69911 L
.93612 .70882 L
.93221 .7184 L
.93216 .71853 L
.92907 .72824 L
.92717 .73796 L
.92303 .74767 L
.92249 .74909 L
.91983 .75738 L
.91817 .76709 L
.91383 .77681 L
.91278 .77955 L
.91052 .78652 L
.90908 .79623 L
.90455 .80594 L
.90307 .80976 L
.90114 .81566 L
.89989 .82537 L
.8952 .83508 L
.89336 .83973 L
.89168 .84479 L
.89059 .85451 L
.88575 .86422 L
.88364 .86945 L
.88215 .87393 L
.87894 .88364 L
.8762 .89336 L
.87393 .89893 L
.87253 .90307 L
.86929 .91278 L
.86655 .92249 L
Mistroke
.86422 .92815 L
.86284 .93221 L
.85957 .94192 L
.85678 .95163 L
.85451 .95712 L
.85306 .96134 L
.84976 .97106 L
.84691 .98077 L
Mfstroke
.4 g
.98077 .58584 m
.97886 .59227 L
.97592 .60198 L
.97167 .61169 L
.97106 .61783 L
.97021 .62141 L
.9673 .63112 L
.96416 .64083 L
.96134 .64959 L
.96114 .65054 L
.95839 .66026 L
.95525 .66997 L
.95209 .67968 L
.95163 .68113 L
.94939 .68939 L
.94627 .69911 L
.94309 .70882 L
.94192 .71244 L
.94031 .71853 L
.93723 .72824 L
.93402 .73796 L
.93221 .74351 L
.93115 .74767 L
.92811 .75738 L
.92489 .76709 L
.92249 .77436 L
.92189 .77681 L
.91892 .78652 L
.91569 .79623 L
.91278 .80497 L
.91255 .80594 L
.90966 .81566 L
.90641 .82537 L
.90316 .83508 L
.90307 .83534 L
.90032 .84479 L
.89706 .85451 L
.89378 .86422 L
.89336 .86548 L
.8909 .87393 L
.88764 .88364 L
.88433 .89336 L
.88364 .89538 L
.88141 .90307 L
.87813 .91278 L
.8748 .92249 L
.87393 .92504 L
.87184 .93221 L
.86855 .94192 L
.86518 .95163 L
.86422 .95445 L
.86219 .96134 L
.85888 .97106 L
.85549 .98077 L
.98077 .98077 L
F
0 g
.98077 .58584 m
.97886 .59227 L
.97592 .60198 L
.97167 .61169 L
.97106 .61783 L
.97021 .62141 L
.9673 .63112 L
.96416 .64083 L
.96134 .64959 L
.96114 .65054 L
.95839 .66026 L
.95525 .66997 L
.95209 .67968 L
.95163 .68113 L
.94939 .68939 L
.94627 .69911 L
.94309 .70882 L
.94192 .71244 L
.94031 .71853 L
.93723 .72824 L
.93402 .73796 L
.93221 .74351 L
.93115 .74767 L
.92811 .75738 L
.92489 .76709 L
.92249 .77436 L
.92189 .77681 L
.91892 .78652 L
.91569 .79623 L
.91278 .80497 L
.91255 .80594 L
.90966 .81566 L
.90641 .82537 L
.90316 .83508 L
.90307 .83534 L
.90032 .84479 L
.89706 .85451 L
.89378 .86422 L
.89336 .86548 L
.8909 .87393 L
.88764 .88364 L
.88433 .89336 L
.88364 .89538 L
.88141 .90307 L
.87813 .91278 L
.8748 .92249 L
.87393 .92504 L
.87184 .93221 L
.86855 .94192 L
.86518 .95163 L
Mistroke
.86422 .95445 L
.86219 .96134 L
.85888 .97106 L
.85549 .98077 L
Mfstroke
.5 g
.98077 .60607 m
.97675 .61169 L
.97505 .62141 L
.97295 .63112 L
.97106 .63813 L
.97028 .64083 L
.96735 .65054 L
.96434 .66026 L
.96135 .66997 L
.96134 .66998 L
.95844 .67968 L
.95542 .68939 L
.9524 .69911 L
.95163 .7016 L
.94947 .70882 L
.94645 .71853 L
.9434 .72824 L
.94192 .73299 L
.94043 .73796 L
.93741 .74767 L
.93433 .75738 L
.93221 .76415 L
.93133 .76709 L
.9283 .77681 L
.92521 .78652 L
.92249 .79508 L
.92215 .79623 L
.91913 .80594 L
.91602 .81566 L
.91291 .82537 L
.91278 .82578 L
.90989 .83508 L
.90676 .84479 L
.90363 .85451 L
.90307 .85624 L
.90058 .86422 L
.89743 .87393 L
.89427 .88364 L
.89336 .88647 L
.89119 .89336 L
.88803 .90307 L
.88484 .91278 L
.88364 .91647 L
.88174 .92249 L
.87856 .93221 L
.87534 .94192 L
.87393 .94622 L
.87221 .95163 L
.86901 .96134 L
.86577 .97106 L
.86422 .97572 L
.8626 .98077 L
.98077 .98077 L
F
0 g
.98077 .60607 m
.97675 .61169 L
.97505 .62141 L
.97295 .63112 L
.97106 .63813 L
.97028 .64083 L
.96735 .65054 L
.96434 .66026 L
.96135 .66997 L
.96134 .66998 L
.95844 .67968 L
.95542 .68939 L
.9524 .69911 L
.95163 .7016 L
.94947 .70882 L
.94645 .71853 L
.9434 .72824 L
.94192 .73299 L
.94043 .73796 L
.93741 .74767 L
.93433 .75738 L
.93221 .76415 L
.93133 .76709 L
.9283 .77681 L
.92521 .78652 L
.92249 .79508 L
.92215 .79623 L
.91913 .80594 L
.91602 .81566 L
.91291 .82537 L
.91278 .82578 L
.90989 .83508 L
.90676 .84479 L
.90363 .85451 L
.90307 .85624 L
.90058 .86422 L
.89743 .87393 L
.89427 .88364 L
.89336 .88647 L
.89119 .89336 L
.88803 .90307 L
.88484 .91278 L
.88364 .91647 L
.88174 .92249 L
.87856 .93221 L
.87534 .94192 L
.87393 .94622 L
.87221 .95163 L
.86901 .96134 L
.86577 .97106 L
Mistroke
.86422 .97572 L
.8626 .98077 L
Mfstroke
.6 g
.98077 .62534 m
.97869 .63112 L
.97589 .64083 L
.97311 .65054 L
.97106 .65747 L
.97021 .66026 L
.96723 .66997 L
.96424 .67968 L
.96134 .68938 L
.96134 .68939 L
.95836 .69911 L
.95534 .70882 L
.95238 .71853 L
.95163 .72107 L
.94942 .72824 L
.94638 .73796 L
.94338 .74767 L
.94192 .75253 L
.94042 .75738 L
.93736 .76709 L
.93432 .77681 L
.93221 .78377 L
.93135 .78652 L
.92829 .79623 L
.92521 .80594 L
.92249 .81477 L
.92222 .81566 L
.91914 .82537 L
.91604 .83508 L
.91301 .84479 L
.91278 .84555 L
.90993 .85451 L
.9068 .86422 L
.90373 .87393 L
.90307 .87609 L
.90065 .88364 L
.8975 .89336 L
.89439 .90307 L
.89336 .9064 L
.8913 .91278 L
.88813 .92249 L
.88499 .93221 L
.88364 .93647 L
.88187 .94192 L
.87868 .95163 L
.87551 .96134 L
.87393 .9663 L
.87238 .97106 L
.86916 .98077 L
.98077 .98077 L
F
0 g
.98077 .62534 m
.97869 .63112 L
.97589 .64083 L
.97311 .65054 L
.97106 .65747 L
.97021 .66026 L
.96723 .66997 L
.96424 .67968 L
.96134 .68938 L
.96134 .68939 L
.95836 .69911 L
.95534 .70882 L
.95238 .71853 L
.95163 .72107 L
.94942 .72824 L
.94638 .73796 L
.94338 .74767 L
.94192 .75253 L
.94042 .75738 L
.93736 .76709 L
.93432 .77681 L
.93221 .78377 L
.93135 .78652 L
.92829 .79623 L
.92521 .80594 L
.92249 .81477 L
.92222 .81566 L
.91914 .82537 L
.91604 .83508 L
.91301 .84479 L
.91278 .84555 L
.90993 .85451 L
.9068 .86422 L
.90373 .87393 L
.90307 .87609 L
.90065 .88364 L
.8975 .89336 L
.89439 .90307 L
.89336 .9064 L
.8913 .91278 L
.88813 .92249 L
.88499 .93221 L
.88364 .93647 L
.88187 .94192 L
.87868 .95163 L
.87551 .96134 L
.87393 .9663 L
.87238 .97106 L
.86916 .98077 L
s
.7 g
.98077 .64556 m
.97924 .65054 L
.97637 .66026 L
.97346 .66997 L
.97106 .67778 L
.97046 .67968 L
.96738 .68939 L
.96429 .69911 L
.96156 .70882 L
.96134 .70977 L
.95856 .71853 L
.95544 .72824 L
.95252 .73796 L
.95163 .74154 L
.94968 .74767 L
.94654 .75738 L
.9435 .76709 L
.94192 .77308 L
.94073 .77681 L
.93758 .78652 L
.93447 .79623 L
.93221 .80441 L
.93171 .80594 L
.92855 .81566 L
.92539 .82537 L
.92259 .83508 L
.92249 .8355 L
.91946 .84479 L
.91627 .85451 L
.91332 .86422 L
.91278 .86636 L
.9103 .87393 L
.90708 .88364 L
.90403 .89336 L
.90307 .89699 L
.90106 .90307 L
.89782 .91278 L
.89471 .92249 L
.89336 .92739 L
.89176 .93221 L
.8885 .94192 L
.88533 .95163 L
.88364 .95755 L
.88238 .96134 L
.8791 .97106 L
.87588 .98077 L
.98077 .98077 L
F
0 g
.98077 .64556 m
.97924 .65054 L
.97637 .66026 L
.97346 .66997 L
.97106 .67778 L
.97046 .67968 L
.96738 .68939 L
.96429 .69911 L
.96156 .70882 L
.96134 .70977 L
.95856 .71853 L
.95544 .72824 L
.95252 .73796 L
.95163 .74154 L
.94968 .74767 L
.94654 .75738 L
.9435 .76709 L
.94192 .77308 L
.94073 .77681 L
.93758 .78652 L
.93447 .79623 L
.93221 .80441 L
.93171 .80594 L
.92855 .81566 L
.92539 .82537 L
.92259 .83508 L
.92249 .8355 L
.91946 .84479 L
.91627 .85451 L
.91332 .86422 L
.91278 .86636 L
.9103 .87393 L
.90708 .88364 L
.90403 .89336 L
.90307 .89699 L
.90106 .90307 L
.89782 .91278 L
.89471 .92249 L
.89336 .92739 L
.89176 .93221 L
.8885 .94192 L
.88533 .95163 L
.88364 .95755 L
.88238 .96134 L
.8791 .97106 L
.87588 .98077 L
s
.8 g
.98077 .66994 m
.98076 .66997 L
.97804 .67968 L
.9752 .68939 L
.97214 .69911 L
.97106 .70227 L
.96865 .70882 L
.96426 .71853 L
.96324 .72824 L
.96134 .73441 L
.96007 .73796 L
.95602 .74767 L
.95439 .75738 L
.95163 .76635 L
.95137 .76709 L
.94755 .77681 L
.94549 .78652 L
.94248 .79623 L
.94192 .79803 L
.93891 .80594 L
.93652 .81566 L
.93351 .82537 L
.93221 .82949 L
.93012 .83508 L
.92573 .84479 L
.92447 .85451 L
.92249 .86075 L
.92122 .86422 L
.91705 .87393 L
.91536 .88364 L
.91278 .89179 L
.91221 .89336 L
.9082 .90307 L
.9062 .91278 L
.9031 .92249 L
.90307 .9226 L
.89922 .93221 L
.89696 .94192 L
.89385 .95163 L
.89336 .95315 L
.89011 .96134 L
.88767 .97106 L
.88453 .98077 L
.98077 .98077 L
F
0 g
.98077 .66994 m
.98076 .66997 L
.97804 .67968 L
.9752 .68939 L
.97214 .69911 L
.97106 .70227 L
.96865 .70882 L
.96426 .71853 L
.96324 .72824 L
.96134 .73441 L
.96007 .73796 L
.95602 .74767 L
.95439 .75738 L
.95163 .76635 L
.95137 .76709 L
.94755 .77681 L
.94549 .78652 L
.94248 .79623 L
.94192 .79803 L
.93891 .80594 L
.93652 .81566 L
.93351 .82537 L
.93221 .82949 L
.93012 .83508 L
.92573 .84479 L
.92447 .85451 L
.92249 .86075 L
.92122 .86422 L
.91705 .87393 L
.91536 .88364 L
.91278 .89179 L
.91221 .89336 L
.9082 .90307 L
.9062 .91278 L
.9031 .92249 L
.90307 .9226 L
.89922 .93221 L
.89696 .94192 L
.89385 .95163 L
.89336 .95315 L
.89011 .96134 L
.88767 .97106 L
.88453 .98077 L
s
.7 g
.98077 .76287 m
.97952 .76709 L
.97659 .77681 L
.97359 .78652 L
.97106 .79471 L
.97058 .79623 L
.96758 .80594 L
.96565 .81566 L
.96169 .82537 L
.96134 .82632 L
.95861 .83508 L
.95707 .84479 L
.95283 .85451 L
.95163 .85772 L
.94958 .86422 L
.94848 .87393 L
.94392 .88364 L
.94192 .88889 L
.94049 .89336 L
.93743 .90307 L
.93497 .91278 L
.93221 .91981 L
.93134 .92249 L
.92825 .93221 L
.92597 .94192 L
.92249 .95048 L
.92212 .95163 L
.919 .96134 L
.91689 .97106 L
.91284 .98077 L
.98077 .98077 L
F
0 g
.98077 .76287 m
.97952 .76709 L
.97659 .77681 L
.97359 .78652 L
.97106 .79471 L
.97058 .79623 L
.96758 .80594 L
.96565 .81566 L
.96169 .82537 L
.96134 .82632 L
.95861 .83508 L
.95707 .84479 L
.95283 .85451 L
.95163 .85772 L
.94958 .86422 L
.94848 .87393 L
.94392 .88364 L
.94192 .88889 L
.94049 .89336 L
.93743 .90307 L
.93497 .91278 L
.93221 .91981 L
.93134 .92249 L
.92825 .93221 L
.92597 .94192 L
.92249 .95048 L
.92212 .95163 L
.919 .96134 L
.91689 .97106 L
.91284 .98077 L
s
.6 g
.98077 .78722 m
.97808 .79623 L
.97513 .80594 L
.9716 .81566 L
.97106 .81921 L
.96949 .82537 L
.96647 .83508 L
.96332 .84479 L
.96134 .85098 L
.9605 .85451 L
.95757 .86422 L
.9544 .87393 L
.95163 .88251 L
.95138 .88364 L
.94859 .89336 L
.94542 .90307 L
.94225 .91278 L
.94192 .91382 L
.93953 .92249 L
.93638 .93221 L
.93318 .94192 L
.93221 .9449 L
.93039 .95163 L
.92726 .96134 L
.92403 .97106 L
.92249 .97572 L
.92117 .98077 L
.98077 .98077 L
F
0 g
.98077 .78722 m
.97808 .79623 L
.97513 .80594 L
.9716 .81566 L
.97106 .81921 L
.96949 .82537 L
.96647 .83508 L
.96332 .84479 L
.96134 .85098 L
.9605 .85451 L
.95757 .86422 L
.9544 .87393 L
.95163 .88251 L
.95138 .88364 L
.94859 .89336 L
.94542 .90307 L
.94225 .91278 L
.94192 .91382 L
.93953 .92249 L
.93638 .93221 L
.93318 .94192 L
.93221 .9449 L
.93039 .95163 L
.92726 .96134 L
.92403 .97106 L
.92249 .97572 L
.92117 .98077 L
s
.5 g
.98077 .80745 m
.97619 .81566 L
.97456 .82537 L
.97228 .83508 L
.97106 .83952 L
.96952 .84479 L
.96655 .85451 L
.96354 .86422 L
.96134 .87136 L
.9606 .87393 L
.95765 .88364 L
.95462 .89336 L
.95163 .90298 L
.95161 .90307 L
.94868 .91278 L
.94564 .92249 L
.94259 .93221 L
.94192 .93437 L
.93964 .94192 L
.93659 .95163 L
.93352 .96134 L
.93221 .96553 L
.93054 .97106 L
.92748 .98077 L
.98077 .98077 L
F
0 g
.98077 .80745 m
.97619 .81566 L
.97456 .82537 L
.97228 .83508 L
.97106 .83952 L
.96952 .84479 L
.96655 .85451 L
.96354 .86422 L
.96134 .87136 L
.9606 .87393 L
.95765 .88364 L
.95462 .89336 L
.95163 .90298 L
.95161 .90307 L
.94868 .91278 L
.94564 .92249 L
.94259 .93221 L
.94192 .93437 L
.93964 .94192 L
.93659 .95163 L
.93352 .96134 L
.93221 .96553 L
.93054 .97106 L
.92748 .98077 L
s
.4 g
.98077 .82672 m
.97791 .83508 L
.97516 .84479 L
.97235 .85451 L
.97106 .85885 L
.96943 .86422 L
.96644 .87393 L
.96346 .88364 L
.96134 .89077 L
.96056 .89336 L
.95756 .90307 L
.95454 .91278 L
.95163 .92246 L
.95162 .92249 L
.94861 .93221 L
.94558 .94192 L
.9426 .95163 L
.94192 .95392 L
.93961 .96134 L
.93655 .97106 L
.93353 .98077 L
.98077 .98077 L
F
0 g
.98077 .82672 m
.97791 .83508 L
.97516 .84479 L
.97235 .85451 L
.97106 .85885 L
.96943 .86422 L
.96644 .87393 L
.96346 .88364 L
.96134 .89077 L
.96056 .89336 L
.95756 .90307 L
.95454 .91278 L
.95163 .92246 L
.95162 .92249 L
.94861 .93221 L
.94558 .94192 L
.9426 .95163 L
.94192 .95392 L
.93961 .96134 L
.93655 .97106 L
.93353 .98077 L
s
.3 g
.98077 .84695 m
.97847 .85451 L
.9756 .86422 L
.97267 .87393 L
.97106 .87916 L
.96965 .88364 L
.96655 .89336 L
.96351 .90307 L
.96134 .91116 L
.96083 .91278 L
.95773 .92249 L
.95463 .93221 L
.95186 .94192 L
.95163 .94293 L
.94885 .95163 L
.94571 .96134 L
.94277 .97106 L
.94192 .97448 L
.9399 .98077 L
.98077 .98077 L
F
0 g
.98077 .84695 m
.97847 .85451 L
.9756 .86422 L
.97267 .87393 L
.97106 .87916 L
.96965 .88364 L
.96655 .89336 L
.96351 .90307 L
.96134 .91116 L
.96083 .91278 L
.95773 .92249 L
.95463 .93221 L
.95186 .94192 L
.95163 .94293 L
.94885 .95163 L
.94571 .96134 L
.94277 .97106 L
.94192 .97448 L
.9399 .98077 L
s
.2 g
.98077 .87131 m
.98004 .87393 L
.9773 .88364 L
.97442 .89336 L
.97127 .90307 L
.97106 .90367 L
.96761 .91278 L
.96541 .92249 L
.96245 .93221 L
.96134 .93579 L
.95909 .94192 L
.95472 .95163 L
.9536 .96134 L
.95163 .96771 L
.95043 .97106 L
.94637 .98077 L
.98077 .98077 L
F
0 g
.98077 .87131 m
.98004 .87393 L
.9773 .88364 L
.97442 .89336 L
.97127 .90307 L
.97106 .90367 L
.96761 .91278 L
.96541 .92249 L
.96245 .93221 L
.96134 .93579 L
.95909 .94192 L
.95472 .95163 L
.9536 .96134 L
.95163 .96771 L
.95043 .97106 L
.94637 .98077 L
s
.3 g
.98077 .96424 m
.97875 .97106 L
.9758 .98077 L
.98077 .98077 L
F
0 g
.98077 .96424 m
.97875 .97106 L
.9758 .98077 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00`_ooool2o`0000;ooooo0_l0
002Pooooo`00`_ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgJ3ooooo0033ooooo`04omgMgOl0
003o410@olc<c:7ooooo0033ooooo`04onk^k_lQ8B7o410@onk^kZ7ooooo0033ooooo`04ob4Q8Omg
MgOoMgMgoc8b<Z7ooooo0032ooooo`;o00000_ooool2o`000:3ooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0011oooo
o`;o000000?o410@ooooooooool08oooool5o`00023ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0T
ooooo`Go00009_ooool2o`000003oa0@4?oooooooooo02?ooooo00Gok^k^oc8b<_l0003o410@olc<
c00Tooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`08Oooool4o`000008oa0@4?ooooooooooonk^k_lb
<S;o0000oc8b<_o^k^h3ooooo`00@_ooool00ol0003oooooooooo`0Tooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@08?ooool01OmgMgOoV9RHoooooonHV9SoMgMg02Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A00Wooooo`03o`000?oooooooooo02Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@0Tooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B408oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00oooool003Oooooo1_l00002ooooo`Go00007Oooool6o`0000?ooooo00?oV9RHob4Q
8Oo^k^h08Oooool01Ol@413ooooooooooooooooo410@02Gooooo00?oV9RHob4Q8Oo^k^h09Oooool5
o`0002Gooooo00Go0000ooooooooooooooooo`00000Tooooo`05o`000?ooooooooooooooool00000
8oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool003oooooo
00CoA4A4omgMgOoooooo0000:?ooool00onHV9So8B4Qonk^kP0Pooooo`05o`000?oooooooooooooo
ool000009_ooool00onHV9So8B4Qonk^kP0Tooooo`04odA4A?oMgMgoooooo`0002Kooooo00Go0000
oiRHV?ooooooV9RHob4Q8@0Tooooo`05oc8b<_nHV9SooooooiRHV?lb<S808oooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool003oooooo00CogMgMoeEEEOoooooo
0000:Oooool00omgMgOoIVIVooooo`0Oooooo`05o`000?ooooooooooooooool000009oooool00omg
MgOoIVIVooooo`0Sooooo`04omgMgOmEEEGoooooo`0002Kooooo00Go0000oeEEEOl0003o410@olc<
c00Tooooo`05olc<c?l0003o0000o`000?o<c<`08oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000000oooool0043ooooo00?oMgMgolc<c?l00000:_ooool00ol0003ooooo
ooooo`0Nooooo`05oa0@4?ooooooooooooooool@4100:?ooool00ol0003oooooooooo`0Sooooo`03
ogMgMoo<c<co000002Kooooo00?oEEEEohN7Qoooool09_ooool01Ol@413o^[Zjoooooonj^[[o410@
02?ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo0010oooo
o`03onk^k_m4A4Co000002Kooooo00Go0000okZj^_ooooooV9RHoa0@400Pooooo`05ogMgMonHV9So
oooooiRHV?mgMgL09?ooool01Ol0003o^[ZjoooooonHV9So410@02Gooooo00?ok^k^odA4A?l00000
9_ooool00ooMgMgo410@oiRHV00Vooooo`05o`000?nj^[[ooooookZj^_l000008oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool0047ooooo00?oMgMgo`000?oo
ool09Oooool01OnHV9So410@o`000?lQ8B7oc<c<023ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0T
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`09_ooool00omgMgOo0000ooooo`0Vooooo`04olc<c?m4
A4Co0000oa0@42Cooooo00GoZJVYoa0@4?l0003o410@ojVYZ@0Qooooo`03oeEEEOmVIVKo000000Co
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`009?ooooooo`0004?o00000_ooool002Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`7o00000Oooool1ooooo`009?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo0Ol00001ooooo`7ooooo000T
ooooo`03o`000?oooooooooo0?oooooo?oooool1o`00007ooooo0Oooool002Cooooo00?o0000oooo
ooooool0ooooooloooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`3oooooocoo
oooo0Ol00001ooooo`7ooooo000Tooooo`;o00003oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`00
00;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Kooooo00Go0000
ooooooooooooooooo`000002ooooo`03o`000?oooooo000000;ooooo00Go0000oooooooooooooooo
o`000008ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooool000000_ooool00ol0003o
ooooo`000009ooooo`08o`000?ooooooooooo`000?oooooo0000ooooool00002ooooo`03o`000?oo
oooo000000Wooooo00Wo0000ooooool0003oooooo`000?oooooo0000ooooool000000_ooool00ol0
003oooooooooo`06ooooo`05o`000?oooooo0000ooooool000001_ooool2o`0000;ooooo000Toooo
o`03o`000?oooooooooo00?ooooo2_moOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c
01Ko/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV
00_oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP07ofIVIP03o`000?moOgooOgmo
00?oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0Bok>c/`03o`000?nIVIWoVIVI
00;oVIVI00Go0000ogmoOomoOgooOgmoo`000003ofIVIP03o`000?m<C4coC4a<00?oC4a<00?o0000
oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C003oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Go
0000oiVIVOnIVIWoVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o
/k>co`000002oiVIV@03o`000?moOgoo000000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c
<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl01_l0003oVIVIoiVIVOl0003o/k>co`0000Wo
c<c<00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV00?o0000oda<C?l000002Olc
<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<
00Koc<c<00Oo0000ok>c/ol0003oVIVIo`000?moOgoo000000Gooooo0Ol00001ooooo`7ooooo000T
ooooo`03o`000?oooooooooo00?ooooo2OmoOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o
/k>c01Ko/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKo
IVIV00_oIVIV00?o0000oda<C?m<C4`06?m<C4`00ol0003oIVIVofIVIP07ofIVIP03o`000?moOgoo
Ogmo00?oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0Bok>c/`05o`000?nIVIWo
VIVIoiVIVOl000000omoOgl01Ol0003oIVIVofIVI_mVIVKo000000GoC4a<00?o0000oc<c<olc<c<0
1Olc<c<00ol0003oC4a<oda<C002oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01?l0003o
VIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002
oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<01?l0003oC4a<
oda<C?l00002ofIVIP06o`000?moOgooOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c007
olc<c003o`000?nc/k?o/k>c00;o00000_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o
<c<c00Oo<c<c00_o0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`000009olc<
c007o`000?nc/k?o0000oiVIVOl0003oOgmoo`000005ooooo`7o00000Oooool1ooooo`009?ooool0
0ol0003oooooooooo`03ooooo`WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0F
ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;
ofIVIP03o`000?m<C4coC4a<01SoC4a<00?o0000ofIVI_mVIVH01omVIVH00ol0003oOgmoogmoO`03
ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<04_nc/k<00ol0003oVIVIoiVIV@02
oiVIV@05o`000?moOgooOgmoogmoOol000000omVIVH00ol0003oC4a<oda<C003oda<C003o`000?lc
<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00om<C4`01?l0003oIVIVofIVI_l00002ogmoO`05o`00
0?nIVIWoVIVIoiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c007o`000?nc/k?o/k>cok>c
/ol0003oVIVIo`000003ogmoO`04o`000?mVIVKoIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc
<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o
00002?o<c<`02?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo00000_mVIVH00ol0003oC4a<o`00
0009oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<
c?o<c<`01_o<c<`01ol0003o/k>co`000?nIVIWo0000ogmoOol000001_ooool1o`00007ooooo0Ooo
ool002Cooooo00?o0000ooooooooool00oooool7ogmoO`;o00003OnIVIT00ol0003o/k>cok>c/`0F
ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;
ofIVIP;o00006Om<C4`00ol0003oIVIVofIVIP07ofIVIP03o`000?moOgooOgmo00?oOgmo00?o0000
oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0Cok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omo
Ogl01Ol0003oIVIVofIVI_mVIVKo000000GoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<
oda<C002oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00004ok>c
/`03o`000?o<c<coc<c<00Goc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgoo
Ogmoo`0000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<01?l0003oC4a<oda<C?l00002ofIVIP05
o`000?moOgoo0000oiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c00:o`000?nc/k?o/k>c
o`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01olc<c<02Ol0003o
C4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Oo
0000ok>c/ol0003oVIVIo`000?moOgoo000000Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`00
0?oooooooooo00?ooooo1_moOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c
00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV
00?o0000oda<C?m<C4`06?m<C4`00ol0003oIVIVofIVIP07ofIVIP03o`000?moOgooOgmo00CoOgmo
00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0Bok>c/`03o`000?nIVIWoVIVI00;oVIVI
00Go0000ogmoOomoOgooOgmoo`000003ofIVIP03o`000?m<C4coC4a<00?oC4a<00?o0000oc<c<olc
<c<01Olc<c<00ol0003oC4a<oda<C002oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01?l0
003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Goc<c<00Go0000ok>c/onc/k?o/k>co`00
0002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<01?l0003o
C4a<oda<C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl000000onc/k<00ol0003oc<c<olc<c006
olc<c003o`000?nc/k?o000000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc
<c?o<c<c00Ko<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<0
0ol0003oc<c<olc<c006olc<c007o`000?nc/k?o0000oiVIVOl0003oOgmoo`000006ooooo`7o0000
0Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`KoOgmo00?o0000oiVIVOnIVIT02onI
VIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?mo
Ogl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01SoC4a<00?o0000ofIVI_mVIVH01omV
IVH00ol0003oOgmoogmoO`04ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<04onc
/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Go0000ofIVI_mVIVKoIVIVo`000006oda<C003
o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo0000
00;oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c005olc<c005o`000?nc/k?o
/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000Wo
<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>c
o`0000Soc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000om<C4`00ol0
003o<c<coc<c<`06oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c
00?o0000olc<c?o<c<`01_o<c<`00ol0003o/k>co`000002oiVIV@;o000000?oIVIVooooooooool0
1?ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool4ogmoO`;o00003?nI
VIT2o`0001Oo/k>c0_l0000=oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omV
IVH00ol0003oC4a<oda<C00Hoda<C003o`000?mVIVKoIVIV00OoIVIV00?o0000ogmoOomoOgl01?mo
Ogl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c01;o/k>c00?o0000oiVIVOnIVIT00_nI
VIT01Ol0003oOgmoogmoOomoOgoo000000?oIVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o<c<c
oc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Co0000ofIVI_mVIVKo00000_moOgl2o`0000;o
VIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT0
1?l0003oOgmoogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000Wo<c<c00Ko0000oda<C?m<C4co
0000ofIVI_l00002ogmoO`03o`000?nIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`02_l0
003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko
<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00009olc<c008
o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVH6ooooo`7o00000Oooool1ooooo`009?ooool0
0ol0003oooooooooo`03ooooo`?oOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0G
ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;
ofIVIP03o`000?m<C4coC4a<01SoC4a<00?o0000ofIVI_mVIVH01omVIVH00ol0003oOgmoogmoO`05
ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<04_nc/k<01Ol0003oVIVIoiVIVOnI
VIWo000000CoOgmo00Go0000ofIVI_mVIVKoIVIVo`000005oda<C003o`000?lc<c?o<c<c00Co<c<c
00?o0000oda<C?m<C4`00om<C4`01?l0003oIVIVofIVI_l00002ogmoO`05o`000?nIVIWoVIVIoiVI
VOl000000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT0
1?l0003oOgmoogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000Wo<c<c00So0000oda<C?m<C4co
0000ofIVI_l0003oOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c00:o`000?nc
/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<0
3?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Woc<c<00Wo0000
ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000001Oooool1o`00007ooooo0Oooool002Cooooo
00?o0000ooooooooool00oooool2ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<0
5onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH0
2omVIVH00ol0003oC4a<oda<C00Hoda<C003o`000?mVIVKoIVIV00OoIVIV00?o0000ogmoOomoOgl0
1OmoOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c01;o/k>c00?o0000oiVIVOnIVIT0
0_nIVIT01Ol0003oOgmoogmoOomoOgoo000000?oIVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o
<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Co0000ofIVI_mVIVKo00000_moOgl00ol0
003oVIVIoiVIV@02oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Go0000ok>c/onc/k?o/k>co`00
0002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<01_l0003o
C4a<oda<C?l0003oIVIVo`0000;oOgmo00?o0000oiVIVOl000000onc/k<00ol0003oc<c<olc<c006
olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c
<olc<c<01_lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03
o`000?o<c<coc<c<00Koc<c<00?o0000ok>c/onc/k<00_l000001OmoOgoo0000ofIVI_mVIVKo0000
00Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo00?oOgmoo`000?nI
VIT03?nIVIT00ol0003o/k>cok>c/`0Fok>c/`;o00003OnIVIT00ol0003oOgmoogmoO`08ogmoO`03
o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`2o`0000[oIVIV00?o0000ogmoOomo
Ogl01?moOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c01;o/k>c00?o0000oiVIVOnI
VIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000?oIVIV00?o0000oda<C?m<C4`01?m<C4`00ol0
003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002
ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc
/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP04o`000?m<C4coC4a<o`00
00So<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00?o0000oiVIVOl000000_nc
/k<00ol0003oc<c<olc<c007olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIV
o`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo
0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o0000ok>c/onc/k<00_l000001?mo
Ogoo0000ofIVI_l00006ooooo`7o00000Oooool1ooooo`009?ooool2o`0000Cooooo00?oOgmoo`00
0?nIVIT02onIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmo
OomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIV
I_mVIVH02OmVIVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c
/onc/k<04onc/k<00ol0003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol000000omVIVH0
0ol0003oC4a<oda<C004oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00_m<C4`0
1Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000003ok>c/`03o`00
0?o<c<coc<c<00Koc<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo00Go0000ofIV
I_mVIVKoIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mV
IVH01_l0003oOgmoogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01oo<c<`02_l0003o
/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c
00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<
c006olc<c003o`000?nc/k?o/k>c00;o000000CoOgmoo`000?mVIVKo00001Oooool2o`0000;ooooo
000Tooooo`03o`000?oooooooooo00?ooooo00?o0000oiVIVOnIVIT02_nIVIT00ol0003o/k>cok>c
/`0Gok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIV
IP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02OmVIVH00ol0003oOgmoogmo
O`05ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<04_nc/k<00ol0003oVIVIoiVI
V@02oiVIV@05o`000?moOgooOgmoogmoOol000000omVIVH00ol0003oC4a<oda<C004oda<C003o`00
0?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;o
Ogmo00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Goc<c<00Go0000ok>c
/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<
o`000007oc<c<`07o`000?m<C4coC4a<oda<C?l0003oIVIVo`000002ogmoO`03o`000?nIVIWo0000
00;o/k>c00?o0000olc<c?o<c<`01oo<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000
ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c00?o0000oda<C?l000000_mVIVH2o`000005
oiVIVOl0003o/k>cok>c/ol000002Oo<c<`01_l0003o/k>co`000?nIVIWo0000ogmoO`;o000000?o
C4a<ooooooooool01?ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool<
oiVIV@03o`000?nc/k?o/k>c01Ko/k>c0_l0000=oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000
ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C0;o00002omVIVH00ol0003oOgmoogmoO`05
ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<04_nc/k<00ol0003oVIVIoiVIV@02
oiVIV@03o`000?moOgooOgmo00;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000005oda<C003o`000?lc
<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00om<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo
00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o
/k>c00Ko0000oiVIVOnIVIWo0000ogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc
<c<01ol0003oC4a<oda<C?m<C4co0000ofIVI_l000000_moOgl00ol0003oVIVIo`000002ok>c/`03
o`000?o<c<coc<c<00Ooc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000
0_m<C4`00ol0003o<c<coc<c<`07oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo
000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/ol0003oVIVI00;o000000?o
IVIVo`000?m<C4`01_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool;
oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08
ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0:
ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`0B
ok>c/`03o`000?nIVIWoVIVI00;oVIVI00?o0000ogmoOomoOgl00_moOgl01Ol0003oIVIVofIVI_mV
IVKo000000GoC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C003oda<C004o`000?mV
IVKoIVIVo`0000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Go
c<c<00?o0000ok>c/onc/k<00_nc/k<01_l0003oVIVIoiVIVOl0003oOgmoo`0000;oIVIV00Go0000
oda<C?m<C4coC4a<o`000008oc<c<`07o`000?m<C4coC4a<oda<C?l0003oIVIVo`000002ogmoO`03
o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`00ol0003o/k>co`000002oiVIV@05
o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`09o`000?m<C4co0000
ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>c
ok>c/ol0003oVIVI00;o000000?oIVIVo`000?m<C4`01_ooool1o`00007ooooo0Oooool002Cooooo
00?o0000ooooooooool00oooool:oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT0
2onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`0
5om<C4`00ol0003oIVIVofIVIP0:ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT0
1?nIVIT00ol0003o/k>cok>c/`0Bok>c/`03o`000?nIVIWoVIVI00?oVIVI00Go0000ogmoOomoOgoo
Ogmoo`000003ofIVIP03o`000?m<C4coC4a<00?oC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003o
C4a<oda<C002oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00004
ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01_l0003oVIVIoiVIVOl0
003oOgmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`07o`000?m<C4coC4a<oda<
C?l0003oIVIVo`000002ogmoO`03o`000?nIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`0
2_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c
00Oo<c<c00?o0000oda<C?m<C4`00_l000001omoOgoo0000oiVIVOnIVIWo0000ok>c/ol000002Oo<
c<`01?l0003o/k>co`000?nIVIT2o`000005ofIVI_l0003oC4a<oda<C?l000001Oooool1o`00007o
oooo0Oooool002Cooooo00?o0000ooooooooool00oooool9oiVIV@03o`000?nc/k?o/k>c01Oo/k>c
00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV
00?o0000oda<C?m<C4`05_m<C4`2o`0000coIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVI
oiVIV@04oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmo
ogmoOomoOgoo000000?oIVIV00?o0000oda<C?m<C4`01?m<C4`00ol0003o<c<coc<c<`04oc<c<`03
o`000?m<C4coC4a<00?oC4a<00Co0000ofIVI_mVIVKo00000omoOgl01?l0003oVIVIoiVIVOl00004
ok>c/`03o`000?o<c<coc<c<00Goc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?mo
OgooOgmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`04o`000?m<C4coC4a<o`00
00;oIVIV00Ko0000ogmoOomoOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00_o
0000ok>c/onc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o
<c<c00Ko<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0
003oc<c<olc<c007olc<c004o`000?nc/k?o0000oiVIV@;o000000GoIVIVo`000?m<C4coC4a<o`00
0005ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`SoVIVI00?o0000
ok>c/onc/k<05_nc/k<2o`0000goVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0<
ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`05
ogmoO`03o`000?nIVIWoVIVI00GoVIVI00?o0000ok>c/onc/k<04onc/k<00ol0003oVIVIoiVIV@02
oiVIV@05o`000?moOgooOgmoogmoOol000000omVIVH00ol0003oC4a<oda<C004oda<C003o`000?lc
<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00om<C4`01?l0003oIVIVofIVI_l00003ogmoO`04o`00
0?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`01Ol0003o/k>cok>c/onc/k?o0000
00;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Co
0000oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000So
c<c<00_o0000ok>c/onc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003o`00
0?lc<c?o<c<c00Ko<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc
/k<00ol0003oc<c<olc<c007olc<c004o`000?nc/k?o0000oiVIV@;o000000GoIVIVo`000?m<C4co
C4a<o`000005ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`OoVIVI
00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@;o00002_moOgl00ol0003oIVIV
ofIVIP0<ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmo
ogmoO`05ogmoO`03o`000?nIVIWoVIVI00GoVIVI00?o0000ok>c/onc/k<04onc/k<00ol0003oVIVI
oiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol000000omVIVH00ol0003oC4a<oda<C004oda<C003
o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00om<C4`01?l0003oIVIVofIVI_l00003ogmo
O`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol0
0002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`04
o`000?m<C4coC4a<o`0000;oIVIV00Ko0000ogmoOomoOgoo0000oiVIVOl00002ok>c/`03o`000?o<
c<coc<c<00Ooc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`0
0ol0003o<c<coc<c<`06oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl2o`0000;o/k>c
00?o0000olc<c?o<c<`01oo<c<`01?l0003o/k>co`000?nIVIT2o`0000;oIVIV00?o0000oda<C?l0
00001_ooool1o`00007ooooo0Oooool001_ooooo0_l000000ol@413oooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo1_nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI
00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0;ofIVIP;o00005om<C4`2o`0000coIVIV
00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@05oiVIV@03o`000?nc/k?o/k>c01?o/k>c
00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000CoIVIV00?o0000oda<C?m<
C4`00om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Go0000ofIVI_mV
IVKoIVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000onc/k<2o`0000Ooc<c<00Go0000
ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Go0000oda<C?m<C4co
C4a<o`000008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0
003o/k>cok>c/ol00009olc<c003o`000?nc/k?o000000;oVIVI00Go0000ogmoOol0003oIVIVo`00
0002oda<C003o`000?lc<c?o<c<c00Ko<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`00
0?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>co`000?nIVIT00_l0
00001OmVIVKo0000oda<C?m<C4co000000Kooooo0Ol00001ooooo`7ooooo000Looooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool00oooool5oiVIV@03o`000?nc/k?o/k>c01Ko/k>c0_l0
000<oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<
C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl01_moOgl00ol0003oVIVIoiVI
V@05oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmo
OomoOgoo000000CoIVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`00
0?m<C4coC4a<00?oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVI
VOl000000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT0
1?l0003oOgmoogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01?l0003oC4a<
oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`00ol0
003o/k>co`000002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06
oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<
c?o<c<`01_o<c<`01Ol0003o/k>cok>c/ol0003oVIVI00;o000000GoIVIVo`000?m<C4coC4a<o`00
0006ooooo`7o00000Oooool1ooooo`004Oooool6o`0000;ooooo1Ol00006ooooo`?o00000oooool4
oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09
ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;
ofIVIP03o`000?moOgooOgmo00KoOgmo00?o0000oiVIVOnIVIT01OnIVIT00ol0003o/k>cok>c/`0C
ok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`000004ofIVIP03o`000?m<
C4coC4a<00?oC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C004oda<C004o`000?mV
IVKoIVIVo`0000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Ko
c<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Go0000
oda<C?m<C4coC4a<o`000008oc<c<`09o`000?m<C4coC4a<oda<C?l0003oIVIVo`000?moOgoo0000
00;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`00ol0003o/k>co`000002oiVIV@05o`000?moOgoo
0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV
0_l000001OnIVIWo0000ok>c/onc/k?o000000Woc<c<00Ko0000ok>c/ol0003oVIVIo`000?moOgl2
o`0000;oC4a<00?o0000oc<c<oooool00oooool3o`0000;ooooo000Iooooo`04odA4A?oMgMgooooo
o`0000Oooooo00?o0000ooooooooool00oooool3oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000
oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000
oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00KoOgmo00?o0000
oiVIVOnIVIT01OnIVIT00ol0003o/k>cok>c/`0Cok>c/`03o`000?nIVIWoVIVI00;oVIVI00?o0000
ogmoOomoOgl00_moOgl01Ol0003oIVIVofIVI_mVIVKo000000KoC4a<00?o0000oc<c<olc<c<00olc
<c<00ol0003oC4a<oda<C004oda<C004o`000?mVIVKoIVIVo`0000?oOgmo00Co0000oiVIVOnIVIWo
00001?nc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0
003oOgmoogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Go0000oda<C?m<C4coC4a<
o`000002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01?l0003o
/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06
oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<
c?o<c<`01_o<c<`01ol0003o/k>cok>c/ol0003oVIVIo`000?moOgl00_l00002oda<C003o`000?lc
<c?ooooo00Gooooo0Ol00001ooooo`7ooooo000Iooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o
0000ooooooooool00oooool2oiVIV@;o00005onc/k<2o`0000coVIVI00?o0000ogmoOomoOgl02Omo
Ogl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH03?mV
IVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc/k<04onc
/k<00ol0003oVIVIoiVIV@02oiVIV@03o`000?moOgooOgmo00;oOgmo00Go0000ofIVI_mVIVKoIVIV
o`000006oda<C003o`000?lc<c?o<c<c00?o<c<c00?o0000oda<C?m<C4`01?m<C4`01?l0003oIVIV
ofIVI_l00003ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0
003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01?l0003oC4a<oda<
C?l00008oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH00ol0003oOgmoo`000002oiVIV@04
o`000?nc/k?o/k>co`0000Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mV
IVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?mo
Ogoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Oo0000ok>c/onc/k?o0000oiVI
VOl0003oOgmo00;o00000_m<C4`00ol0003o<c<cooooo`05ooooo`7o00000Oooool1ooooo`006_oo
ool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo00?ooooo00?oVIVIo`000?nc/k<05onc
/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omV
IVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV0_l00007ogmoO`03o`000?nI
VIWoVIVI00KoVIVI00?o0000ok>c/onc/k<04onc/k<00ol0003oVIVIoiVIV@02oiVIV@03o`000?mo
OgooOgmo00;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000006oda<C003o`000?lc<c?o<c<c00?o<c<c
00?o0000oda<C?m<C4`01?m<C4`01?l0003oIVIVofIVI_l00003ogmoO`04o`000?nIVIWoVIVIo`00
00Co/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000
ogmoOomoOgoo00000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`05o`000?m<C4coC4a<oda<C?l0
00000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Woc<c<00[o0000ok>c
/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`07oc<c<`03
o`000?m<C4coC4a<00;o000000OoOgmoo`000?nIVIWoVIVIo`000?nc/k?o000000Soc<c<00co0000
ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00002oc<c<`Kooooo0Ol00001
ooooo`7ooooo000Jooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool00oooool00ol0
003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0
003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0
003oOgmoogmoO`06ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc/k<04onc/k<00ol0
003oVIVIoiVIV@03oiVIV@05o`000?moOgooOgmoogmoOol000001?mVIVH00ol0003oC4a<oda<C004
oda<C003o`000?lc<c?o<c<c00?o<c<c00?o0000oda<C?m<C4`00om<C4`01Ol0003oIVIVofIVI_mV
IVKo000000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Goc<c<
00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`03o`000?mVIVKo000000?o
C4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o0000ogmo
Ool000000_nIVIT01?l0003o/k>cok>c/ol00008olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Go
0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00[o0000oda<C?m<C4co
0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c00<o`000?nc
/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co00000_lc<c<6ooooo`7o00000Ooo
ool1ooooo`006oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo00?ooooo00?o0000
ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0:oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000
ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00coIVIV00?o0000
ogmoOomoOgl01_moOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o0000
oiVIVOnIVIT00onIVIT01Ol0003oOgmoogmoOomoOgoo000000CoIVIV00?o0000oda<C?m<C4`00om<
C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Go0000ofIVI_mVIVKoIVIV
o`000002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c003
o`000?nc/k?o/k>c00;o/k>c00Ko0000oiVIVOnIVIWo0000ogmoOol00002ofIVIP05o`000?m<C4co
C4a<oda<C?l000002?lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o0000ogmoOol00000
0_nIVIT01?l0003o/k>cok>c/ol00008olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Go0000ogmo
Ool0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00[o0000oda<C?m<C4co0000ofIV
I_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c00<o`000?nc/k?o/k>c
o`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co00000_lc<c<6ooooo`7o00000Oooool1oooo
o`009?ooool00ol0003oooooooooo`03oooooaSo/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003o
OgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003o
IVIVofIVIP0<ofIVIP03o`000?moOgooOgmo00KoOgmo00?o0000oiVIVOnIVIT01onIVIT00ol0003o
/k>cok>c/`0Bok>c/`03o`000?nIVIWoVIVI00?oVIVI00Go0000ogmoOomoOgooOgmoo`000004ofIV
IP03o`000?m<C4coC4a<00CoC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C003oda<
C004o`000?mVIVKoIVIVo`0000?oOgmo00Go0000oiVIVOnIVIWoVIVIo`000003ok>c/`03o`000?o<
c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;o
IVIV00Co0000oda<C?m<C4co00002Olc<c<01?l0003oC4a<oda<C?l00002ofIVIP04o`000?moOgoo
Ogmoo`0000;oVIVI00?o0000ok>c/ol000002Oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@;o0000
0_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0
003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01ol0003o/k>cok>c/ol0003oVIVIo`00
0?moOgl00_l00002oda<C003o`000?lc<c?o<c<c00Kooooo0Ol00001ooooo`7ooooo000Tooooo`03
o`000?oooooooooo00?ooooo5onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00So
Ogmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00co
IVIV00?o0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c01?o
/k>c00?o0000oiVIVOnIVIT00onIVIT01Ol0003oOgmoogmoOomoOgoo000000CoIVIV00?o0000oda<
C?m<C4`00om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Go0000ofIV
I_mVIVKoIVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000onc/k<00ol0003oc<c<olc<
c006olc<c003o`000?nc/k?o/k>c00;o/k>c00Ko0000oiVIVOnIVIWo0000ogmoOol00002ofIVIP05
o`000?m<C4coC4a<oda<C?l000002Olc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo
000000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`00ol0003o/k>co`000002oiVIV@05o`000?mo
Ogoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`06o`000?m<C4coC4a<o`000?mV
IVKo00000_moOgl2o`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`03?l0003o/k>cok>c/ol0003o
VIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000?o<c<c1_ooool1o`00007ooooo0Oooool002Co
oooo00?o0000ooooooooool00ooooolFok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomo
Ogl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP;o00005om<C4`2o`0000goIVIV00?o0000ogmoOomo
Ogl01omoOgl00ol0003oVIVIoiVIV@05oiVIV@;o00005Onc/k<00ol0003oVIVIoiVIV@03oiVIV@05
o`000?moOgooOgmoogmoOol000001?mVIVH00ol0003oC4a<oda<C004oda<C003o`000?lc<c?o<c<c
00?o<c<c00?o0000oda<C?m<C4`01?m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Go0000
oiVIVOnIVIWoVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>c
o`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c
<`07o`000?m<C4coC4a<oda<C?l0003oIVIVo`000002ogmoO`06o`000?nIVIWoVIVIo`000?nc/k?o
00002_o<c<`00ol0003o/k>co`000002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0
003o<c<coc<c<`06oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o
/k>c00?o0000olc<c?o<c<`01_o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIV
I_l0003oC4a<o`0000?o<c<c1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool0
0ooooolEok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIV
ofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003oOgmo
ogmoO`07ogmoO`03o`000?nIVIWoVIVI00GoVIVI00?o0000ok>c/onc/k<05Onc/k<00ol0003oVIVI
oiVIV@03oiVIV@05o`000?moOgooOgmoogmoOol000001?mVIVH00ol0003oC4a<oda<C004oda<C003
o`000?lc<c?o<c<c00?o<c<c00?o0000oda<C?m<C4`01?m<C4`01Ol0003oIVIVofIVI_mVIVKo0000
00;oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o
/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<C?l0
00002?lc<c<01ol0003oC4a<oda<C?m<C4co0000ofIVI_l000000_moOgl01_l0003oVIVIoiVIVOl0
003o/k>co`0000[oc<c<00?o0000ok>c/ol000000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;o
C4a<00?o0000oc<c<olc<c<01_lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVI
VOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmo
o`000?mVIVKo0000oda<C?l00003oc<c<`Kooooo0Ol00001ooooo`7ooooo000Tooooo`;o00001?oo
oolDok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIV
IP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmo
O`07ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc/k<05?nc/k<00ol0003oVIVIoiVI
V@03oiVIV@05o`000?moOgooOgmoogmoOol000001?mVIVH00ol0003oC4a<oda<C004oda<C003o`00
0?lc<c?o<c<c00?o<c<c00?o0000oda<C?m<C4`01?m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;o
Ogmo00Go0000oiVIVOnIVIWoVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c
/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<
o`000008oc<c<`07o`000?m<C4coC4a<oda<C?l0003oIVIVo`000002ogmoO`04o`000?nIVIWoVIVI
o`0000;o/k>c00?o0000olc<c?o<c<`01oo<c<`00ol0003o/k>co`000002oiVIV@05o`000?moOgoo
0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV
0_l000001OnIVIWo0000ok>c/onc/k?o000000Soc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003o
Ogmoo`000?mVIVKo0000oda<C?l00004oc<c<`Gooooo0_l00002ooooo`009?ooool00ol0003ooooo
ooooo`03oooooa;o/k>c0_l0000=oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH0
2omVIVH00ol0003oC4a<oda<C00Foda<C0;o00003OmVIVH00ol0003oOgmoogmoO`07ogmoO`03o`00
0?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc/k<05?nc/k<00ol0003oVIVIoiVIV@03oiVIV@03o`00
0?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C004oda<C003o`00
0?lc<c?o<c<c00;o<c<c0_l00005oda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01?l0003o
VIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0
003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01olc
<c<01ol0003oC4a<oda<C?m<C4co0000ofIVI_l000000_moOgl00ol0003oVIVIo`000003ok>c/`03
o`000?o<c<coc<c<00Koc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`03o`000?mVIVKo
000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo
0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00co0000ok>c/onc/k?o0000oiVIVOl0
003oOgmoo`000?mVIVKo0000oda<C?l00004oc<c<`Kooooo0Ol00001ooooo`7ooooo000Tooooo`03
o`000?oooooooooo00?ooooo4_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00So
Ogmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00co
IVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c01Co
/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00;o
IVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`03oc<c<`03o`000?m<C4coC4a<00Co
C4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000
olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co
0000ofIVI_mVIVKo00000_m<C4`00ol0003o<c<coc<c<`07oc<c<`07o`000?m<C4coC4a<oda<C?l0
003oIVIVo`000002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`01_l0
003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c
<`06oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000
olc<c?o<c<`01_o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<
o`0000Co<c<c1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00ooooolAok>c
/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIV
IP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmoO`08ogmo
O`03o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc/k<05?nc/k<00ol0003oVIVIoiVIV@03oiVI
V@03o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C004oda<
C003o`000?lc<c?o<c<c00;o<c<c00?o0000oda<C?m<C4`01Om<C4`01?l0003oIVIVofIVI_l00003
ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c
/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o
<c<coc<c<`06oc<c<`07o`000?m<C4coC4a<oda<C?l0003oIVIVo`000002ogmoO`04o`000?nIVIWo
VIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/onc/k<2o`0000;oOgmo
00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`03o`000?m<C4coC4a<00;o0000
00OoOgmoo`000?nIVIWoVIVIo`000?nc/k?o000000Soc<c<00co0000ok>c/onc/k?o0000oiVIVOl0
003oOgmoo`000?mVIVKo0000oda<C?l00005oc<c<`Kooooo0Ol00001ooooo`7ooooo000Tooooo`03
o`000?oooooooooo00?ooooo3onc/k<2o`0000goVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003o
IVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02_mVIVH2o`0000[o
Ogmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`0Dok>c/`03o`000?nIVIWoVIVI00?o
VIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP02ofIVIP03o`000?m<C4coC4a<00Co
C4a<00?o0000oc<c<olc<c<00olc<c<00ol0003oC4a<oda<C004oda<C005o`000?mVIVKoIVIVofIV
I_l000000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`0
0ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo0000
0om<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Ko0000ogmoOomo
Ogoo0000oiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Ko0000ok>c/onc/k?o0000oiVI
VOl00002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02_l0003oC4a<
oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00co
0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00005oc<c<`Kooooo0Ol0
0001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo3onc/k<00ol0003oVIVIoiVIV@0;
oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00G
oda<C003o`000?mVIVKoIVIV00[oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@07
oiVIV@03o`000?nc/k?o/k>c01Co/k>c00?o0000oiVIVOnIVIT00_nIVIT00ol0003oOgmoogmoO`03
ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01?m<C4`00ol0003o<c<coc<c<`03
oc<c<`03o`000?m<C4coC4a<00CoC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`05o`000?nI
VIWoVIVIoiVIVOl000001?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c
00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00002oda<C003o`000?lc<c?o<c<c
00Oo<c<c00Co0000oda<C?m<C4co00000_mVIVH01_l0003oOgmoogmoOol0003oVIVIo`0000?o/k>c
00?o0000olc<c?o<c<`01_o<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00?o0000ofIV
I_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmo
Ool0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`03?l0003o/k>cok>c/ol0003oVIVI
o`000?moOgoo0000ofIVI_l0003oC4a<o`0000Go<c<c1_ooool1o`00007ooooo0Oooool002Cooooo
00?o0000ooooooooool00oooool>ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl0
2?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH0
2_mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00OoVIVI00?o0000ok>c/onc/k<0
5?nc/k<00ol0003oVIVIoiVIV@03oiVIV@03o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH0
0_mVIVH00ol0003oC4a<oda<C004oda<C003o`000?lc<c?o<c<c00?o<c<c00?o0000oda<C?m<C4`0
1?m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000004ok>c
/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002
ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01ol0003oC4a<oda<
C?m<C4co0000ofIVI_l000000_moOgl00ol0003oVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Ko
c<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000
oc<c<olc<c<01_lc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo0_l00002ok>c/`03o`00
0?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT2o`000005ofIVI_l0003oC4a<oda<
C?l000001Olc<c<6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`co
/k>c0_l0000=oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003o
C4a<oda<C00Foda<C0;o00003?mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00Oo
VIVI00?o0000ok>c/onc/k<05?nc/k<00ol0003oVIVIoiVIV@03oiVIV@03o`000?moOgooOgmo00;o
Ogmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C005oda<C003o`000?lc<c?o<c<c00;o
<c<c00?o0000oda<C?m<C4`01?m<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Co0000oiVI
VOnIVIWo00001Onc/k<00ol0003oc<c<olc<c005olc<c005o`000?nc/k?o/k>cok>c/ol000000onI
VIT01?l0003oOgmoogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Go0000oda<C?m<
C4coC4a<o`000002ofIVIP06o`000?moOgooOgmoo`000?nIVIWo00000onc/k<00ol0003oc<c<olc<
c006olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl00ol0003oIVIVo`000002oda<C003
o`000?lc<c?o<c<c00Ko<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000
0_nc/k<00ol0003oc<c<olc<c006olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003o
IVIVo`000?m<C4co00001_lc<c<6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003ooooooooo
o`03ooooo`co/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mV
IVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0:ofIVIP03o`000?mo
OgooOgmo00WoOgmo00?o0000oiVIVOnIVIT01onIVIT00ol0003o/k>cok>c/`0Eok>c/`03o`000?nI
VIWoVIVI00?oVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP02ofIVIP03o`000?m<
C4coC4a<00GoC4a<00?o0000oc<c<olc<c<00_lc<c<00ol0003oC4a<oda<C004oda<C005o`000?mV
IVKoIVIVofIVI_l000000omoOgl01?l0003oVIVIoiVIVOl00005ok>c/`03o`000?o<c<coc<c<00Go
c<c<00Go0000ok>c/onc/k?o/k>co`000003oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Co0000
oda<C?m<C4co00002?lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Ko0000ogmoOomoOgoo
0000oiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl0
0002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02_l0003oC4a<oda<
C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o0000
ok>c/ol000000_nIVIT01ol0003oOgmoo`000?mVIVKo0000oda<C?l000001_lc<c<6ooooo`7o0000
0Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`_o/k>c00?o0000oiVIVOnIVIT02onI
VIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05om<
C4`00ol0003oIVIVofIVIP0:ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02?nI
VIT00ol0003o/k>cok>c/`0Dok>c/`03o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl00omo
Ogl01Ol0003oIVIVofIVI_mVIVKo000000OoC4a<00?o0000oc<c<olc<c<00_lc<c<00ol0003oC4a<
oda<C005oda<C004o`000?mVIVKoIVIVo`0000?oOgmo00Co0000oiVIVOnIVIWo00001Onc/k<00ol0
003oc<c<olc<c005olc<c005o`000?nc/k?o/k>cok>c/ol000000onIVIT01?l0003oOgmoogmoOol0
0002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP06
o`000?moOgooOgmoo`000?nIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o
/k>co`0000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c
00Co0000oda<C?m<C4co00000_mVIVH2o`000005oiVIVOl0003o/k>cok>c/ol000002?o<c<`03?l0
003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000Oo<c<c1_ooool1o`00
007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool:ok>c/`03o`000?nIVIWoVIVI00_o
VIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01Ko
C4a<0_l0000<ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02?nIVIT00ol0003o
/k>cok>c/`0Dok>c/`03o`000?nIVIWoVIVI00?oVIVI0_l00004ogmoO`03o`000?mVIVKoIVIV00;o
IVIV00?o0000oda<C?m<C4`01Om<C4`01Ol0003o<c<coc<c<olc<c?o000000OoC4a<00Go0000ofIV
I_mVIVKoIVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0003oc<c<olc<
c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIV
ofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIV
IP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`01_l0003o/k>cok>c/ol0
003oVIVIo`0000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0:o`00
0?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<
c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000Oo<c<c1_oo
ool1o`00007ooooo0Oooool002Cooooo0_l00004ooooo`So/k>c0_l0000=oiVIV@03o`000?moOgoo
Ogmo00SoOgmo00?o0000ofIVI_mVIVH03?mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKo
IVIV00[oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@09oiVIV@03o`000?nc/k?o
/k>c01Co/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKo
IVIV00;oIVIV00?o0000oda<C?m<C4`01Om<C4`01Ol0003o<c<coc<c<olc<c?o000000OoC4a<00Go
0000ofIVI_mVIVKoIVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0003o
c<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0
003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`00
0002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`01_l0003o/k>c
ok>c/ol0003oVIVIo`0000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c
<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<
c<`01_o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000Oo
<c<c1Oooool2o`0000;ooooo000Tooooo`03o`000?oooooooooo00?ooooo1onc/k<00ol0003oVIVI
oiVIV@0;oiVIV@;o00002_moOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<01KoC4a<
00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00WoVIVI
00?o0000ok>c/onc/k<05?nc/k<00ol0003oVIVIoiVIV@03oiVIV@03o`000?moOgooOgmo00?oOgmo
00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C005oda<C005o`000?lc<c?o<c<coc<c<ol0
00001om<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<0
0ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00?o/k>c00Co0000oiVIVOnIVIWo00000_mo
Ogl01?l0003oIVIVofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Co0000oda<C?m<C4co
00000_mVIVH01_l0003oOgmoogmoOol0003oVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`0
1_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<c
oc<c<`06oc<c<`04o`000?m<C4coC4a<oda<C0;o000000GoOgmoo`000?nIVIWoVIVIo`000002ok>c
/`03o`000?o<c<coc<c<00Goc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`;o000000?o
C4a<o`000?lc<c<01olc<c<6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03
ooooo`Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKo
IVIV00_oIVIV0_l0000Goda<C0;o00003?mVIVH00ol0003oOgmoogmoO`08ogmoO`;o00002onIVIT0
0ol0003o/k>cok>c/`0Dok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl00_moOgl0
0ol0003oIVIVofIVIP02ofIVIP03o`000?m<C4coC4a<00GoC4a<00?o0000oc<c<olc<c<00_lc<c<0
0ol0003oC4a<oda<C004oda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01Ol0003oVIVIoiVI
VOnIVIWo000000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`00
0?nIVIWoVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c
<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o
/k>co`0000Soc<c<00Wo0000ok>c/onc/k?o/k>co`000?nIVIWo0000ogmoOol000000_mVIVH01?l0
003oC4a<oda<C?l00008oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`00
00;o/k>c00?o0000olc<c?o<c<`01_o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000
ofIVI_l0003oC4a<o`0000So<c<c1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000oooooooo
ool00oooool5ok>c/`;o00003?nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00_o
IVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00So
Ogmo00?o0000oiVIVOnIVIT02_nIVIT00ol0003o/k>cok>c/`0Eok>c/`03o`000?nIVIWoVIVI00Co
VIVI00Go0000ogmoOomoOgooOgmoo`000005ofIVIP03o`000?m<C4coC4a<00GoC4a<00?o0000oc<c
<olc<c<00_lc<c<00ol0003oC4a<oda<C004oda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl0
1Ol0003oVIVIoiVIVOnIVIWo000000Co/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c
/`03ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o
<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH00ol0003oOgmoo`000002oiVI
V@04o`000?nc/k?o/k>co`0000Soc<c<00Wo0000ok>c/onc/k?o/k>co`000?nIVIWo0000ogmoOol0
00000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmo
Ool0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`03?l0003o/k>cok>c/ol0003oVIVI
o`000?moOgoo0000ofIVI_l0003oC4a<o`0000So<c<c00?o0000ooooooooool00oooool1o`00007o
oooo0Oooool002Cooooo00?o0000ooooooooool00oooool4ok>c/`03o`000?nIVIWoVIVI00_oVIVI
00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<
00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00[oVIVI
00?o0000ok>c/onc/k<05Onc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00;oOgmo
00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C005oda<C003o`000?lc<c?o<c<c00;o<c<c
00?o0000oda<C?m<C4`01?m<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Go0000oiVIVOnI
VIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0
003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc
<c<00ol0003oC4a<oda<C002oda<C005o`000?mVIVKo0000ogmoOol000000_nIVIT01?l0003o/k>c
ok>c/ol00009olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl00ol0003oIVIVo`000002
oda<C003o`000?lc<c?o<c<c00Ko<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`;o0000
0_nc/k<00ol0003oc<c<olc<c007olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo
000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<00ol0003oooooooooo`03ooooo`7o00000Oooool1
ooooo`009?ooool00ol0003oooooooooo`03ooooo`?o/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0
003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0
003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02_nIVIT00ol0
003o/k>cok>c/`0Eok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl00_moOgl00ol0
003oIVIVofIVIP02ofIVIP03o`000?m<C4coC4a<00KoC4a<0ol000000olc<c?o0000oda<C006oda<
C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Go/k>c00?o
0000olc<c?o<c<`01Oo<c<`01Ol0003o/k>cok>c/onc/k?o000000?oVIVI00Co0000ogmoOomoOgoo
00000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Oo0000oda<C?m<C4coC4a<o`000?mV
IVKo000000;oOgmo00Co0000oiVIVOnIVIWo00000_nc/k<00ol0003oc<c<olc<c007olc<c008o`00
0?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP03o`000?m<C4co000000Wo<c<c00[o0000
oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c007olc<
c00;o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l000002?lc<c<00ol0003o
ooooooooo`04ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`;o/k>c
0_l0000<oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<
oda<C00Foda<C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl01omoOgl00ol0003oVIVI
oiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Go/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmo
ogmoO`02ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01_m<C4`01?l0003oC4a<
oda<C?l00008oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01Ol0003oVIVIoiVIVOnIVIWo
000000Co/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000?oVIVI00Co
0000ogmoOomoOgoo00000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Oo0000oda<C?m<
C4coC4a<o`000?mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo00000_nc/k<00ol0003oc<c<olc<
c007olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP03o`000?m<C4co0000
00Wo<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003o
c<c<olc<c007olc<c00;o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00000
2?lc<c<00ol0003oooooooooo`04ooooo`7o00000Oooool1ooooo`009?ooool00ol0003ooooooooo
o`03ooooo`03ok>c/ol0003oVIVI00coVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIV
IP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH2o`0000WoOgmo00?o
0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Eok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o
0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<00KoC4a<0_l0
0009oda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01?l0003oVIVIoiVIVOl00005ok>c/`03
o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmo
O`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01ol0003oC4a<oda<C?m<
C4co0000ofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Oo
c<c<00Co0000ok>c/onc/k?o00000_nIVIT2o`0000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<0
1?l0003oC4a<oda<C?l00002ofIVIP;o000000GoVIVIo`000?nc/k?o/k>co`000009olc<c007o`00
0?nc/k?o0000oiVIVOl0003oOgmoo`000002ofIVIP;o00002?lc<c<00ol0003oC4a<ooooo`05oooo
o`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`03o`000?nIVIWoVIVI00_o
VIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01Ko
C4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_o
VIVI00?o0000ok>c/onc/k<05Onc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00;o
Ogmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C006oda<C004o`000?lc<c?o<c<co`00
00OoC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc
/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00?o0000oiVIVOnIVIT00_l0
00000omoOgoo0000o`000002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01?l0003oC4a<
oda<C?l00002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`0
0ol0003o/k>cok>c/`02o`000004oiVIVOl0003oOgmoo`0000;oIVIV00Co0000oda<C?m<C4co0000
2?lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<
c<coc<c<00Koc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l0
0008oc<c<`03o`000?m<C4cooooo00Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooo
oooo00?ooooo00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKo
IVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?moOgoo
Ogmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Eok>c/`03o`000?nIVIWo
VIVI00CoVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4co
C4a<00KoC4a<00Co0000oc<c<olc<c?o00001om<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo
00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc
/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`05o`000?mVIVKoIVIVofIVI_l000000om<C4`0
0ol0003o<c<coc<c<`05oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmo
Ool00002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0
003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00[o0000oda<C?m<C4co0000ofIV
I_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c00<o`000?nc/k?o/k>c
o`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co00002?lc<c<00ol0003oC4a<ooooo`05oooo
o`7o00000Oooool1ooooo`009?ooool2o`0000Cooooo3?nIVIT00ol0003oOgmoogmoO`09ogmoO`03
o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0<ofIVIP03
o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Eok>c/`03
o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP03ofIVIP03
o`000?m<C4coC4a<00SoC4a<0_l00007oda<C003o`000?mVIVKoIVIV00;oIVIV00Co0000ogmoOomo
Ogoo00001?nIVIT00ol0003o/k>cok>c/`02ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c
/onc/k<00onc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o
0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Ko0000ogmoOomoOgoo
0000oiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT0
1Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<
C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c005
o`000?nc/k?o/k>co`000?nIVIT00_l00002ofIVIP03o`000?m<C4co000000So<c<c00?o0000oda<
C?ooool01?ooool2o`0000;ooooo000Tooooo`03o`000?oooooooooo00?ooooo3?nIVIT00ol0003o
OgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003o
IVIVofIVIP0<ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o
/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003o
IVIVofIVIP03ofIVIP03o`000?m<C4coC4a<00SoC4a<00?o0000oda<C?m<C4`01_m<C4`01Ol0003o
IVIVofIVI_mVIVKo000000?oOgmo00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<co
c<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`05o`000?mV
IVKoIVIVofIVI_l000000om<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<
00Ko0000ofIVI_mVIVKo0000ogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Co0000
ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c
00So0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o00001oo<
c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000So<c<c00Co
0000oda<C?m<C4co00001Oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00ooo
ool;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH2o`0001OoC4a<0_l0
000=ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c
/`0Fok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIV
IP02ofIVIP;o00004om<C4`01?l0003oIVIVofIVI_mVIVH2o`0000;oOgmo00Go0000oiVIVOnIVIWo
VIVIo`000005ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003o
VIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<0
1Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Ko0000ogmoOomoOgoo0000oiVIVOl00003ok>c/`03
o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIV
IP04o`000?m<C4coC4a<o`0000So<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nI
VIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmo
Ool0003oIVIVo`000?m<C4co00002?lc<c<01?l0003oC4a<oda<C?l00005ooooo`7o00000Oooool1
ooooo`009?ooool00ol0003oooooooooo`03ooooo`[oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0
003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0
003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0
003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0
003oC4a<oda<C00Boda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01Ol0003oVIVIoiVIVOnI
VIWo000000Go/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nI
VIWoVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`05
o`000?m<C4coC4a<oda<C?l000000_mVIVH01_l0003oOgmoogmoOol0003oVIVIo`0000?o/k>c00?o
0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV
00Co0000oda<C?m<C4co00002?lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVI
VOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmo
o`000?mVIVKo0000oda<C?l00008oc<c<`04o`000?m<C4coC4a<o`0000Gooooo0Ol00001ooooo`7o
oooo000Tooooo`03o`000?oooooooooo00?ooooo2OnIVIT00ol0003oOgmoogmoO`08ogmoO`03o`00
0?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`00
0?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`00
0?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIVIP02ofIVIP03o`00
0?m<C4coC4a<01;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000004ogmoO`04o`000?nIVIWoVIVIo`00
00Go/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVI
o`0000;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<
C4coC4a<oda<C?l000000_mVIVH01_l0003oOgmoogmoOol0003oVIVIo`0000?o/k>c00?o0000olc<
c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@06o`000?moOgooOgmoo`000?mVIVKo0000
0_m<C4`00ol0003o<c<coc<c<`06oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl2o`00
00;o/k>c00?o0000olc<c?o<c<`01oo<c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIV
o`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00?o0000oda<C?l000001_ooool1o`00007ooooo
0Oooool002Cooooo00?o0000ooooooooool00oooool8oiVIV@03o`000?moOgooOgmo00SoOgmo00?o
0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C0;o00003OmVIVH00ol0003oOgmoogmo
O`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVI
V@05oiVIV@03o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<
C00Boda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01Ol0003oVIVIoiVIVOnIVIWo000000Co
/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`05o`000?nIVIWoVIVIoiVI
VOl000000_moOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000
oda<C?m<C4coC4a<o`000002ofIVIP06o`000?moOgooOgmoo`000?nIVIWo00000onc/k<00ol0003o
c<c<olc<c006olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH00ol0
003oC4a<o`000009oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc
/k?o00002_o<c<`02_l0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4`2o`0000So
<c<c00?o0000oda<C?l000001_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool0
0oooool7oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<
oda<C00Foda<C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVI
oiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT01OnIVIT00ol0003oOgmo
ogmoO`02ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<C4`04Om<C4`00ol0003oIVIV
ofIVIP02ofIVIP05o`000?moOgooOgmoogmoOol000000onIVIT00ol0003o/k>cok>c/`02ok>c/`03
o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo0000
00;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4co
C4a<oda<C?l000000_mVIVH01_l0003oOgmoogmoOol0003oVIVIo`0000?o/k>c00?o0000olc<c?o<
c<`01Oo<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmoOol000000_mVIVH00ol0
003oC4a<o`000009oc<c<`03o`000?m<C4coC4a<00;o00000_moOgl01Ol0003oVIVIo`000?nc/k?o
000000[oc<c<00_o0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`000009oc<c
<`03o`000?m<C4co000000Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?o
oooo1_nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<
C4`05_m<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnI
VIT02onIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00GoVIVI00?o0000ogmoOomo
Ogl00_moOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<01;oC4a<00Go0000ofIVI_mV
IVKoIVIVo`000003ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0003oc<c<olc<c005
olc<c003o`000?nc/k?o/k>c00;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`04o`000?mV
IVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;o
IVIV00Co0000ogmoOomoOgoo00000_nIVIT01?l0003o/k>cok>c/ol00008olc<c004o`000?nc/k?o
/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`0:o`00
0?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01oo<
c<`02ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co000000Wo<c<c00Co0000
oda<C?l0003oIVIV1_ooool1o`00007ooooo0Oooool001Wooooo1Ol00006ooooo`03o`000?oooooo
oooo00?ooooo1OnIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000
oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0:ofIVIP;o00002_moOgl00ol0003oVIVIoiVIV@0:
oiVIV@;o00006Onc/k<00ol0003oVIVIoiVIV@05oiVIV@03o`000?moOgooOgmo00;oOgmo00?o0000
ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00Boda<C004o`000?mVIVKoIVIVofIVIP;o00000_mo
Ogl00ol0003oVIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c00;o/k>c00?o0000olc<c?o<c<`01Oo<
c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000?oOgmo00Co0000ofIVI_mVIVKo
00000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH00ol0
003oOgmoo`000002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01?l0003o/k>cok>c/ol0
0002oiVIV@05o`000?moOgoo0000ofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`0:o`00
0?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<
c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000Wo<c<c00Go
0000oda<C?l0003oIVIVo`000005ooooo`7o00000Oooool1ooooo`006Oooool01OnHV9So8B4Qonk^
k_ooooooA4A400Kooooo00?o0000ooooooooool00oooool4oiVIV@03o`000?moOgooOgmo00SoOgmo
00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00[oIVIV
00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0:oiVIV@03o`000?nc/k?o/k>c01So/k>c
00?o0000oiVIVOnIVIT01OnIVIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00?oIVIV
00?o0000oda<C?m<C4`04_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00?o0000oiVIVOnI
VIT00_nIVIT00ol0003o/k>cok>c/`02ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc
/k<00_nc/k<01?l0003oVIVIoiVIVOl00003ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000
oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00003ofIVIP03o`000?moOgoo000000;oVIVI00Go
0000ok>c/onc/k?o/k>co`000008olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Go0000ogmoOol0
003oIVIVo`000003oda<C003o`000?lc<c?o<c<c00Go<c<c00Co0000oda<C?m<C4co00000_mVIVH0
1Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`03?l0003o/k>cok>c
/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000Wo<c<c00Go0000oda<C?l0003oIVIV
o`000005ooooo`7o00000Oooool1ooooo`004Oooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h01ooo
ool3o`0000?ooooo0onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o
0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0:ofIVIP03o`000?moOgooOgmo00WoOgmo00?o
0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00GoVIVI00?o
0000ogmoOomoOgl01?moOgl00ol0003oIVIVofIVIP02ofIVIP03o`000?m<C4coC4a<01;oC4a<00Go
0000ofIVI_mVIVKoIVIVo`000003ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<0
0_nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo
00000omoOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<
C?m<C4coC4a<o`000002ofIVIP03o`000?moOgoo000000;oVIVI00Go0000ok>c/onc/k?o/k>co`00
0008olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<
oda<C?l00008oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVIV@04o`000?nc
/k?o/k>co`0000Ooc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<
C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4co0000ofIVI_l000001?ooool3o`0000;ooooo
000Kooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool00oooool2oiVIV@03o`000?mo
OgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C0;o00003?mV
IVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05onc
/k<00ol0003oVIVIoiVIV@05oiVIV@03o`000?moOgooOgmo00CoOgmo00?o0000ofIVI_mVIVH00omV
IVH00ol0003oC4a<oda<C00Aoda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgooOgmo
o`000003oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>c
ok>c/`03ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0
003o<c<coc<c<`07oc<c<`07o`000?m<C4coC4a<oda<C?l0003oIVIVo`000002ogmoO`04o`000?nI
VIWoVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@05
o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`0:o`000?m<C4coC4a<
o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02_l0003o
/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c
00Go0000oda<C?l0003o0000ogmoO`06ooooo`7o00000Oooool1ooooo`007?ooool00omgMgOoIVIV
ooooo`05ooooo`03o`000?oooooooooo00?ooooo00?oVIVIo`000?moOgl02OmoOgl00ol0003oIVIV
ofIVIP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmo
ogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVI
oiVIV@06oiVIV@03o`000?moOgooOgmo00?oOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<
oda<C00Boda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgooOgmoo`000003oiVIV@03
o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`02ok>c/`04
o`000?nIVIWoVIVIo`0000?oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`07
oc<c<`07o`000?m<C4coC4a<oda<C?l0003oIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000;o
/k>c00?o0000olc<c?o<c<`01oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000
ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000
ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02_l0003o/k>cok>c/ol0003o
VIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?l0
003o0000ogmoO`06ooooo`7o00000Oooool1ooooo`007Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00?ooooo00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03
o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`09ogmoO`03
o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@06oiVIV@03
o`000?moOgooOgmo00?oOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00Coda<C005
o`000?mVIVKoIVIVofIVI_l000000omoOgl00ol0003oVIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c
00;o/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`04o`000?nIVIWoVIVI
o`0000?oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`07o`000?m<
C4coC4a<oda<C?l0003oIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000;o/k>c00?o0000olc<
c?o<c<`01oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgooOgmo00;o00000_m<C4`0
0ol0003o<c<coc<c<`07oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`00
00;o/k>c00?o0000olc<c?o<c<`01oo<c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIV
o`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Ko0000oda<C?l0003oIVIVo`000?moOgl6oooo
o`7o00000Oooool1ooooo`006Oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000oooo
ooooool00oooool:ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`2o`00
00coIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c
01Oo/k>c00?o0000oiVIVOnIVIT01_nIVIT00ol0003oOgmoogmoO`04ogmoO`03o`000?mVIVKoIVIV
00?oIVIV00?o0000oda<C?m<C4`04_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00?o0000
oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`02ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000
ok>c/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo0000
1?m<C4`00ol0003o<c<coc<c<`05oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003o
OgmoogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Ko0000ok>c/onc/k?o/k>co`00
0?nIVIT2o`000004ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01olc<c<03?l0003o
C4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000[oc<c<00Wo0000ok>c/ol0
003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`07o`000?m<
C4co0000ofIVI_l0003oOgmoo`000005ooooo`7o00000Oooool1ooooo`006Oooool01OnHV9So410@
o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool00oooool9ogmoO`03o`000?mVIVKoIVIV00co
IVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0:ofIVIP03o`000?moOgooOgmo00Wo
Ogmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00Oo
VIVI00?o0000ogmoOomoOgl01?moOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<01;o
C4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c
/onc/k<00_nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Go0000oiVI
VOnIVIWoVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01Olc
<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01?l0003o
/k>cok>c/ol00008olc<c007o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000002ogmoO`03o`000?mV
IVKo000000;oC4a<00?o0000oc<c<olc<c<01olc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?mo
Ogoo0000oiVIVOl0003o/k>co`0000[oc<c<00_o0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIV
I_l0003oC4a<o`000009oc<c<`07o`000?m<C4co0000ofIVI_l0003oOgmoo`000005ooooo`7o0000
0Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`SoOgmo00?o0000ofIVI_mVIVH03?mV
IVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00[oIVIV00?o0000ogmoOomoOgl02Omo
Ogl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT01onI
VIT00ol0003oOgmoogmoO`04ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<C4`04_m<
C4`00ol0003oIVIVofIVIP02ofIVIP04o`000?moOgooOgmoo`0000CoVIVI00?o0000ok>c/onc/k<0
0_nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Go0000oiVIVOnIVIWo
VIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01Olc<c<01Ol0
003oC4a<oda<C?m<C4co000000;oIVIV00Oo0000ogmoOomoOgooOgmoo`000?nIVIWo000000?o/k>c
00?o0000olc<c?o<c<`01_o<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00?o0000ofIV
I_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmo
Ool0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01oo<c<`02Ol0003o/k>co`000?nIVIWo0000
ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Oo0000oda<C?l0003oIVIV
o`000?moOgoo000000Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo
1omoOgl00ol0003oIVIVofIVIP0;ofIVIP;o00005om<C4`2o`0000coIVIV00?o0000ogmoOomoOgl0
2?moOgl2o`0000goVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@07oiVIV@03o`00
0?moOgooOgmo00CoOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00Boda<C003o`00
0?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgooOgmoo`000003oiVIV@03o`000?nc/k?o/k>c00?o
/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`04o`000?nIVIWoVIVIo`00
00?oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4co
C4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000So
c<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo00?o0000ofIVI_l000000_m<C4`0
0ol0003o<c<coc<c<`07oc<c<`03o`000?m<C4co000000;oIVIV00Go0000ogmoOol0003oVIVIo`00
0002ok>c/`03o`000?o<c<coc<c<00Koc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`00
0?mVIVKo0000oda<C?l00009oc<c<`07o`000?m<C4co0000ofIVI_l0003oOgmoo`000006ooooo`7o
00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`KoOgmo00?o0000ofIVI_mVIVH0
2omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl0
2?moOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT0
2?nIVIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00CoIVIV00?o0000oda<C?m<C4`0
4_m<C4`00ol0003oIVIVofIVIP02ofIVIP05o`000?moOgooOgmoogmoOol000000onIVIT00ol0003o
/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00onc/k<01?l0003o
VIVIoiVIVOl00003ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<0
1Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01?l0003o/k>c
ok>c/ol00008olc<c007o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000002ogmoO`03o`000?mVIVKo
000000;oC4a<00?o0000oc<c<olc<c<01olc<c<00ol0003oC4a<o`000002ofIVIP05o`000?moOgoo
0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c00<o`000?nc/k?o/k>co`000?nIVIWo
0000ogmoOol0003oIVIVo`000?m<C4co00002Olc<c<01ol0003oC4a<o`000?mVIVKo0000ogmoOol0
00001_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool5ogmoO`03o`00
0?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`00
0?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`00
0?nIVIWoVIVI00SoVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIVIP04ofIVIP03o`00
0?m<C4coC4a<01;oC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000?o
VIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c00?o
/k>c00Co0000oiVIVOnIVIWo00000omoOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o
<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI
00Co0000ok>c/onc/k?o00002?o<c<`01ol0003o/k>cok>c/onc/k?o0000oiVIVOl000000_moOgl0
1?l0003oIVIVofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00[o0000oda<C?m<C4co0000
ofIVI_l0003oOgmoo`000?nIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c00;o`000?nc/k?o
0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l000002Olc<c<00ol0003oC4a<o`000002ofIV
IP;o000000?oVIVIooooooooool01?ooool1o`00007ooooo0Oooool002Cooooo00?o0000oooooooo
ool00oooool4ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003o
IVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o
/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00SoVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003o
IVIVofIVIP04ofIVIP03o`000?m<C4coC4a<01;oC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003o
OgmoogmoOomoOgoo000000CoVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c004olc<
c003o`000?nc/k?o/k>c00;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`05o`000?mVIVKo
IVIVofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l00000
0_mVIVH01_l0003oOgmoogmoOol0003oVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01ol0
003o/k>cok>c/onc/k?o0000oiVIVOl000000_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc
<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o
/k>c00?o0000olc<c?o<c<`01_o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIV
I_l0003oC4a<o`0000Wo<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl000001Ooo
ool1o`00007ooooo0Oooool002Cooooo0_l00004ooooo`?oOgmo00?o0000ofIVI_mVIVH02omVIVH0
0ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl0
0ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02?nIVIT0
0ol0003oOgmoogmoO`04ogmoO`03o`000?mVIVKoIVIV00CoIVIV00?o0000oda<C?m<C4`04_m<C4`0
0ol0003oIVIVofIVIP02ofIVIP05o`000?moOgooOgmoogmoOol000001?nIVIT00ol0003o/k>cok>c
/`03ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00_nc/k<01Ol0003oVIVIoiVI
VOnIVIWo000000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko
<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP06o`000?moOgooOgmoo`000?nIVIWo00000onc
/k<00ol0003oc<c<olc<c006olc<c009o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000?moOgoo0000
00;oIVIV00Co0000oda<C?m<C4co00002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP05o`000?mo
Ogoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c00<o`000?nc/k?o/k>co`000?nI
VIWo0000ogmoOol0003oIVIVo`000?m<C4co00002Olc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmo
Ool0003oVIVIo`000004ooooo`;o00000_ooool002Cooooo00?o0000ooooooooool00oooool2ogmo
O`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIV
IP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT2o`0001Wo/k>c00?o0000oiVI
VOnIVIT02?nIVIT00ol0003oOgmoogmoO`04ogmoO`03o`000?mVIVKoIVIV00CoIVIV00?o0000oda<
C?m<C4`04_m<C4`00ol0003oIVIVofIVIP03ofIVIP04o`000?moOgooOgmoo`0000CoVIVI00?o0000
ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00;o/k>c00Go0000
oiVIVOnIVIWoVIVIo`000002ogmoO`05o`000?mVIVKoIVIVofIVI_l000000om<C4`00ol0003o<c<c
oc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVI
V@04o`000?nc/k?o/k>co`0000Soc<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo
00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`03o`000?m<C4co000000;oIVIV
00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Wo0000ok>c/ol0
003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`03o`000?m<
C4coC4a<00;o000000CoOgmoo`000?nIVIWo00001_ooool1o`00007ooooo0Oooool002Cooooo00?o
0000ooooooooool00oooool00omoOgoo0000ofIVIP0<ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o
0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o
0000ok>c/onc/k<05onc/k<2o`0000[oVIVI00?o0000ogmoOomoOgl01?moOgl2o`0000GoIVIV00?o
0000oda<C?m<C4`04om<C4`00ol0003oIVIVofIVIP02ofIVIP05o`000?moOgooOgmoogmoOol00000
0onIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<0
0onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0
003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Ko0000ofIVI_mVIVKo0000ogmoOol0
0002oiVIV@;o00000_nc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`0000;oVIVI
00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`03o`000?m<C4co000000;o
IVIV00Oo0000ogmoOol0003oVIVIo`000?nc/k?o000000[oc<c<00Wo0000ok>c/ol0003oVIVIo`00
0?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`09o`000?m<C4co0000ofIV
I_l0003oOgmoo`000?nIVIWo000000Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooo
oooo00?ooooo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKo
IVIV00coIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o
/k>c01Ko/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`04ogmoO`03o`000?mVIVKo
IVIV00CoIVIV00?o0000oda<C?m<C4`04om<C4`00ol0003oIVIVofIVIP02ofIVIP05o`000?moOgoo
OgmoogmoOol000000onIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o
0000ok>c/onc/k<00onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo
00001?m<C4`00ol0003o<c<coc<c<`05oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0
003oOgmoogmoOol00002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01?l0003o/k>cok>c
/ol00002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<00ol0003o
C4a<o`000002ofIVIP07o`000?moOgoo0000oiVIVOl0003o/k>co`00000:olc<c009o`000?nc/k?o
0000oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02Ol0003o
C4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000006ooooo`7o00000Oooool1ooooo`009?ooool0
0ol0003oooooooooo`03ooooo`goIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0<
ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0F
ok>c/`03o`000?nIVIWoVIVI00[oVIVI00?o0000ogmoOomoOgl01?moOgl00ol0003oIVIVofIVIP05
ofIVIP03o`000?m<C4coC4a<01;oC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomo
Ogoo000000?oVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc
/k?o/k>c00;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`04o`000?mVIVKoIVIVo`0000Co
C4a<00?o0000oc<c<olc<c<01Olc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmo
OomoOgoo00000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Co0000ok>c/onc/k?o0000
0_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Ko0000oda<C?m<
C4co0000ofIVI_l00002ogmoO`05o`000?nIVIWo0000ok>c/ol000002Oo<c<`00ol0003o/k>co`00
0002oiVIV@07o`000?moOgoo0000ofIVI_l0003oC4a<o`000009oc<c<`09o`000?m<C4co0000ofIV
I_l0003oOgmoo`000?nIVIWo000000Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooo
oooo00?ooooo3?mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00coIVIV00?o0000
ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000
oiVIVOnIVIT02OnIVIT00ol0003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV00CoIVIV00?o0000
oda<C?m<C4`04om<C4`01?l0003oIVIVofIVI_mVIVH2o`0000?oOgmo00Go0000oiVIVOnIVIWoVIVI
o`000006ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00onc/k<01Ol0003oVIVI
oiVIVOnIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`06oc<c
<`04o`000?m<C4coC4a<o`0000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01Ol0003o/k>cok>c
/onc/k?o000000Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIVIP04
o`000?m<C4coC4a<o`0000Wo<c<c00?o0000oda<C?l000000_mVIVH01Ol0003oOgmoo`000?nIVIWo
000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0003o
IVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00[o0000oda<C?l0003oIVIVo`000?moOgoo
0000oiVIVOl0003o/k>c1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00ooo
ool;ofIVIP;o00005om<C4`2o`0000goIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVI
V@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c0_l0000<oiVIV@03o`000?moOgooOgmo00CoOgmo00?o
0000ofIVI_mVIVH01?mVIVH00ol0003oC4a<oda<C00Coda<C003o`000?mVIVKoIVIV00;oIVIV00Go
0000ogmoOomoOgooOgmoo`000004oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`0
1?o<c<`00ol0003o/k>cok>c/`03ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo0_l00002ofIVIP05
o`000?m<C4coC4a<oda<C?l000002Olc<c<01?l0003oC4a<oda<C?l00002ofIVIP04o`000?moOgoo
Ogmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@03
o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<01?l0003oC4a<oda<C?l00002
ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c00:o`000?nc
/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<0
2_l0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k<6ooooo`7o00000Oooool1oooo
o`009?ooool00ol0003oooooooooo`03ooooo`[oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003o
IVIVofIVIP0<ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o
/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl01OmoOgl00ol0003o
IVIVofIVIP04ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003o
OgmoogmoOomoOgoo000000CoVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c004olc<
c003o`000?nc/k?o/k>c00?o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l0
0004oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`00
0?moOgooOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`01?l0003o/k>cok>c/ol00002
oiVIV@05o`000?moOgoo0000ofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<
C4coC4a<o`0000;oIVIV00Oo0000ogmoOol0003oVIVIo`000?nc/k?o000000Woc<c<00[o0000ok>c
/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0;
o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol000001Oooool1o`00007ooooo
0Oooool002Cooooo00?o0000ooooooooool00oooool9ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o
0000ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o
0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00GoOgmo00?o
0000ofIVI_mVIVH01?mVIVH00ol0003oC4a<oda<C00Coda<C003o`000?mVIVKoIVIV00;oIVIV00Go
0000ogmoOomoOgooOgmoo`000004oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`0
1?o<c<`00ol0003o/k>cok>c/`03ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Go0000ofIVI_mV
IVKoIVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002
ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c004o`00
0?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH01Ol0003oC4a<oda<C?m<C4co0000
00So<c<c00?o0000oda<C?l000000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000
olc<c?o<c<`01oo<c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003
o`000?lc<c?o<c<c00Ko<c<c00?o0000oda<C?l000000_mVIVH2o`000005oiVIVOl0003o/k>cok>c
/ol000001Oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool8ofIVIP03
o`000?m<C4coC4a<01KoC4a<0_l0000=ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnI
VIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomo
Ogl01OmoOgl00ol0003oIVIVofIVIP04ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000ofIVI_mV
IVH00_mVIVH00ol0003oOgmoogmoO`02ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001_nc/k<00ol0
003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c00?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002
ogmoO`05o`000?mVIVKoIVIVofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<
C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@05o`000?nc/k?o/k>cok>c
/ol000002?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000
oda<C?m<C4co00002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl0
00000_nc/k<00ol0003oc<c<olc<c006olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0
003oIVIVo`000?m<C4co00002Olc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`00
0002ok>c/`03o`000?oooooooooo00?ooooo0Ol00001ooooo`7ooooo000Tooooo`;o00001?ooool7
ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmoO`08
ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0:
oiVIV@03o`000?moOgooOgmo00GoOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<C00C
oda<C003o`000?mVIVKoIVIV00;oIVIV00?o0000ogmoOomoOgl00_moOgl01?l0003oVIVIoiVIVOl0
0006ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00onc/k<01Ol0003oVIVIoiVI
VOnIVIWo000000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko
<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP03o`000?moOgoo000000;oVIVI00?o0000ok>c
/onc/k<00_nc/k<00ol0003oc<c<olc<c005olc<c007o`000?nc/k?o/k>cok>c/ol0003oVIVIo`00
0002ogmoO`04o`000?mVIVKoIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<
oda<C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<
c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co00002Olc<c<02Ol0
003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?oooooooooo00;ooooo
0_l00002ooooo`009?ooool00ol0003oooooooooo`03ooooo`KoIVIV00?o0000oda<C?m<C4`05_m<
C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onI
VIT00ol0003o/k>cok>c/`0Fok>c/`;o00003?nIVIT00ol0003oOgmoogmoO`05ogmoO`03o`000?mV
IVKoIVIV00GoIVIV00?o0000oda<C?m<C4`04om<C4`00ol0003oIVIVofIVIP02ofIVIP03o`000?mo
OgooOgmo00;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000005ok>c/`03o`000?o<c<coc<c<00Coc<c<
00?o0000ok>c/onc/k<00onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Go0000ofIVI_mV
IVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go<c<c00Go0000oda<C?m<C4coC4a<o`000002
ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c004o`00
0?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00008oc<c
<`04o`000?m<C4coC4a<o`0000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<
c<coc<c<00Ooc<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0
003o<c<coc<c<`06oc<c<`03o`000?m<C4coC4a<00;o000000OoOgmoo`000?nIVIWoVIVIo`000?nc
/k?o000000Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo1OmVIVH0
0ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00[oIVIV0_l0000:ogmoO`03o`000?nIVIWo
VIVI00[oVIVI0_l0000Hok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl01_moOgl0
0ol0003oIVIVofIVIP04ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH00omVIVH0
1Ol0003oOgmoogmoOomoOgoo000000?oVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<
c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Co0000oiVIVOnIVIWo00000omoOgl01?l0003oIVIV
ofIVI_l00004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003o
IVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`0
1Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmoOol000000_mVIVH00ol0003oC4a<o`00
0009oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl01Ol0003oVIVIo`000?nc/k?o0000
00[oc<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<c
oc<c<`06oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000
ooooooooool01?ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool4ofIV
IP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`09ogmo
O`03o`000?nIVIWoVIVI00[oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0;oiVI
V@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<C00Coda<
C003o`000?mVIVKoIVIV00?oIVIV00Go0000ogmoOomoOgooOgmoo`000003oiVIV@03o`000?nc/k?o
/k>c00Co/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`04o`000?nIVIWo
VIVIo`0000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go<c<c
00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`00
00;o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000
ogmoOol000000_mVIVH00ol0003oC4a<o`000009oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo0000
0_moOgl01Ol0003oVIVIo`000?nc/k?o000000[oc<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo
0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`09o`000?m<C4co0000ofIVI_l0003o
Ogmoo`000?nIVIWo000000;o/k>c00?o0000ooooooooool01?ooool1o`00007ooooo0Oooool002Co
oooo00?o0000ooooooooool00oooool3ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mV
IVH02_mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc
/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mV
IVH01OmVIVH00ol0003oC4a<oda<C00Doda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomo
OgooOgmoo`000003oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0
003o/k>cok>c/`03ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01?l0003oIVIVofIVI_l0
0004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIV
I_l00002ogmoO`04o`000?nIVIWoVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01oo<c<`01?l0003o
/k>cok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<0
1?l0003oC4a<oda<C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<
olc<c007olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000
oc<c<olc<c<01olc<c<2o`000004ofIVI_l0003oOgmoogmoO`;o00000_nc/k<00ol0003oc<c<oooo
o`05ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`;oIVIV00?o0000
oda<C?m<C4`05_m<C4`2o`0000coIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0;
oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`06
ogmoO`03o`000?mVIVKoIVIV00GoIVIV00?o0000oda<C?m<C4`05?m<C4`00ol0003oIVIVofIVIP02
ofIVIP05o`000?moOgooOgmoogmoOol000001?nIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<
c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo
00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<
C4`00_m<C4`01_l0003oIVIVofIVI_l0003oOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`00
0009olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl01?l0003oIVIVofIVI_l00002oda<
C003o`000?lc<c?o<c<c00Ko<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`03o`000?nI
VIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?mo
Ogoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Wo0000oda<C?l0003oIVIVo`00
0?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<ooooo`05ooooo`7o00000Oooool1ooooo`00
9?ooool00ol0003oooooooooo`03ooooo`03ofIVI_l0003oC4a<01SoC4a<00?o0000ofIVI_mVIVH0
2_mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<0
5_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00OoOgmo00?o0000ofIVI_mVIVH0
1OmVIVH00ol0003oC4a<oda<C00Doda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgoo
Ogmoo`000004oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003o
/k>cok>c/`03ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01Ol0003oIVIVofIVI_mVIVKo
000000CoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C006o`000?mVIVKo
IVIVo`000?moOgoo00000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Woc<c<00Ko0000ok>c/onc
/k?o0000oiVIVOl00002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01olc<c<0
1_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<
olc<c006olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o
0000oc<c<olc<c<01_lc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c
/`03o`000?o<c<cooooo00Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?o
oooo00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0:ofIVIP03o`000?moOgooOgmo00Wo
Ogmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_o
VIVI00?o0000ogmoOomoOgl01omoOgl00ol0003oIVIVofIVIP05ofIVIP03o`000?m<C4coC4a<01Co
C4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000CoVIVI00?o0000ok>c
/onc/k<01?nc/k<00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c00?o/k>c00Go0000oiVI
VOnIVIWoVIVIo`000002ogmoO`05o`000?mVIVKoIVIVofIVI_l000001?m<C4`00ol0003o<c<coc<c
<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH00ol0003oOgmoo`000002oiVIV@05o`00
0?nc/k?o/k>cok>c/ol000002Oo<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00Co0000
ofIVI_mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo
00000_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Oo0000ok>c/ol0
003oVIVIo`000?moOgoo000000;oIVIV00?o0000oda<C?l000002?lc<c<00ol0003oC4a<o`000002
ofIVIP;o000000GoVIVIo`000?nc/k?o/k>co`000002olc<c0Kooooo0Ol00001ooooo`7ooooo000T
ooooo`03o`000?oooooooooo00?ooooo6?m<C4`2o`0000coIVIV00?o0000ogmoOomoOgl02OmoOgl0
0ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT0
0ol0003oOgmoogmoO`07ogmoO`03o`000?mVIVKoIVIV00GoIVIV00?o0000oda<C?m<C4`04om<C4`2
o`0000CoIVIV00?o0000ogmoOomoOgl00_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Ko/k>c00?o
0000olc<c?o<c<`00oo<c<`2o`0000Go/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`05o`00
0?mVIVKoIVIVofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<
C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<
c<`01ol0003o/k>cok>c/onc/k?o0000oiVIVOl000000_moOgl00ol0003oIVIVo`000003oda<C003
o`000?lc<c?o<c<c00Ko<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`03o`000?nIVIWo
000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo
0000ofIVI_l0003oC4a<o`0000Wo<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0
00000_nc/k<00ol0003oc<c<olc<c006ooooo`7o00000Oooool1ooooo`009?ooool00ol0003ooooo
ooooo`03oooooaSoC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`00
0?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`00
0?moOgooOgmo00OoOgmo00?o0000ofIVI_mVIVH01_mVIVH00ol0003oC4a<oda<C00Coda<C003o`00
0?mVIVKoIVIV00?oIVIV00?o0000ogmoOomoOgl00_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Ko
/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`04ok>c/`05o`000?nIVIWoVIVIoiVI
VOl000000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<0
1Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01Ol0003o/k>c
ok>c/onc/k?o000000Soc<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo00?o0000
ofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo0000
0_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00co0000ok>c/onc/k?o
0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00009oc<c<`09o`000?m<C4co0000ofIVI_l0
003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_ooool1o`00007ooooo0Oooool0
02Cooooo0_l00004oooooaOoC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`09ogmo
O`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVI
V@03o`000?moOgooOgmo00OoOgmo00?o0000ofIVI_mVIVH01_mVIVH00ol0003oC4a<oda<C00Coda<
C003o`000?mVIVKoIVIV00?oIVIV00?o0000ogmoOomoOgl00_moOgl01Ol0003oVIVIoiVIVOnIVIWo
000000Ko/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`04ok>c/`05o`000?nIVIWo
VIVIoiVIVOl000000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000?oC4a<00?o0000oc<c<olc<c<0
1_lc<c<00ol0003oC4a<oda<C002oda<C006o`000?mVIVKoIVIVo`000?moOgoo00000_nIVIT01Ol0
003o/k>cok>c/onc/k?o000000Woc<c<00Co0000ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`00
0?mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01_l0003oC4a<oda<C?l0003oIVIVo`00
00;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c006o`000?nc/k?o/k>c
o`000?nIVIWo00000_moOgl2o`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<00ol0003oC4a<oda<
C002o`000007ogmoOol0003oVIVIoiVIVOl0003o/k>co`000003olc<c0Gooooo0_l00002ooooo`00
9?ooool00ol0003oooooooooo`03oooooaGoC4a<0_l0000<ofIVIP03o`000?moOgooOgmo00WoOgmo
00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI
00?o0000ogmoOomoOgl01omoOgl00ol0003oIVIVofIVIP06ofIVIP03o`000?m<C4coC4a<01CoC4a<
00?o0000ofIVI_mVIVH00_mVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00;oVIVI
00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c00?o/k>c
00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c
<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nI
VIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT01_l0003o
OgmoogmoOol0003oIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01_l0003oC4a<oda<C?l0
003oIVIVo`0000;oOgmo00Go0000oiVIVOl0003o/k>co`000009olc<c00:o`000?nc/k?o/k>co`00
0?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<00ol0003oC4a<
o`000002o`000006ogmoOol0003oVIVIo`000?nc/k?o00001?o<c<`6ooooo`7o00000Oooool1oooo
o`009?ooool00ol0003oooooooooo`03oooooaCoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003o
OgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003o
VIVIoiVIV@0;oiVIV@;o00002OmoOgl00ol0003oIVIVofIVIP05ofIVIP03o`000?m<C4coC4a<01Go
C4a<00?o0000ofIVI_mVIVH00_mVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00;o
VIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c00?o
/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000
oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo0000
0_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT01_l0
003oOgmoogmoOol0003oIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01_l0003oC4a<oda<
C?l0003oIVIVo`0000;oOgmo00Go0000oiVIVOl0003o/k>co`000009olc<c00:o`000?nc/k?o/k>c
o`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02ol0003o
C4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o000000Coc<c<1_ooool1o`00007ooooo
0Oooool002Cooooo00?o0000ooooooooool00ooooolCoda<C003o`000?mVIVKoIVIV00_oIVIV00?o
0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o
0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00KoIVIV00?o
0000oda<C?m<C4`05?m<C4`00ol0003oIVIVofIVIP03ofIVIP05o`000?moOgooOgmoogmoOol00000
1?nIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<0
0onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0
003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol0
0002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@06
o`000?moOgooOgmoo`000?mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4co
C4a<o`0000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<
00Co0000ok>c/onc/k?o00000_nIVIT2o`000005ofIVI_l0003oC4a<oda<C?l000002?lc<c<00ol0
003oC4a<oda<C002o`0000;oOgmo0_l00002ok>c/`03o`000?o<c<coc<c<00;oc<c<1_ooool1o`00
007ooooo0Oooool002Cooooo00?o0000ooooooooool00ooooolBoda<C003o`000?mVIVKoIVIV00_o
IVIV00?o0000ogmoOomoOgl02?moOgl2o`0000goVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003o
VIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH01_mVIVH00ol0003o
C4a<oda<C00Doda<C003o`000?mVIVKoIVIV00?oIVIV00Go0000ogmoOomoOgooOgmoo`000004oiVI
V@03o`000?nc/k?o/k>c00Go/k>c00?o0000olc<c?o<c<`00_o<c<`00ol0003o/k>cok>c/`04ok>c
/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000CoC4a<00?o
0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo
00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`00
00;oVIVI00Ko0000ogmoOomoOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c00So
0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`0
2_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c
00Ko<c<c00?o0000oda<C?m<C4`00_l000001?moOgoo0000o`000?l00002ok>c/`03o`000?o<c<co
c<c<00;oc<c<1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00ooooolAoda<
C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0<oiVI
V@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT2o`0000WoOgmo00?o0000ofIV
I_mVIVH01omVIVH00ol0003oC4a<oda<C00Doda<C003o`000?mVIVKoIVIV00?oIVIV00Go0000ogmo
OomoOgooOgmoo`000004oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`00oo<c<`0
0ol0003o/k>cok>c/`04ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01Ol0003oIVIVofIV
I_mVIVKo000000CoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`00
0?mVIVKoIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<
c004o`000?nc/k?o/k>co`0000;oVIVI00Ko0000ogmoOomoOgoo0000ofIVI_l00002oda<C003o`00
0?lc<c?o<c<c00Oo<c<c00So0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000;oVIVI00Co0000
ok>c/onc/k?o00002?o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002
oda<C003o`000?lc<c?o<c<c00Ko<c<c00?o0000oda<C?m<C4`00_l000001?moOgoo0000oiVIVOl0
0002ok>c/`03o`000?o<c<coc<c<00;oc<c<1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000
ooooooooool00oooool@oda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl0
0ol0003oVIVIoiVIV@0;oiVIV@;o00006?nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgoo
Ogmo00SoOgmo00?o0000ofIVI_mVIVH01omVIVH00ol0003oC4a<oda<C00Doda<C003o`000?mVIVKo
IVIV00?oIVIV00?o0000ogmoOomoOgl00_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Oo/k>c00?o
0000olc<c?o<c<`00_o<c<`00ol0003o/k>cok>c/`04ok>c/`05o`000?nIVIWoVIVIoiVIVOl00000
0_moOgl01Ol0003oIVIVofIVI_mVIVKo000000CoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003o
C4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<0
0ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Ko0000ogmoOomoOgoo0000
ofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00So0000oda<C?m<C4co0000ofIVI_l0003o
Ogmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`00ol0003o/k>cok>c/`02o`000007ogmo
Ool0003oIVIVofIVI_l0003oC4a<o`000008oc<c<`05o`000?m<C4coC4a<o`000?mVIVH00_l00000
1OnIVIWo0000ok>c/onc/k?o000000Goc<c<1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000
ooooooooool00oooool?oda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl0
0ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02onIVIT0
0ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00OoIVIV00?o0000oda<C?m<C4`05?m<C4`0
0ol0003oIVIVofIVIP03ofIVIP03o`000?moOgooOgmo00;oOgmo00Go0000oiVIVOnIVIWoVIVIo`00
0007ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o0000ok>c/onc/k<01?nc/k<01Ol0003oVIVIoiVI
VOnIVIWo000000?oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`06oc<c<`05
o`000?m<C4coC4a<oda<C?l000000omVIVH00ol0003oOgmoo`000003oiVIV@04o`000?nc/k?o/k>c
o`0000Soc<c<0_l00002ok>c/`06o`000?nIVIWoVIVIo`000?moOgoo00000_mVIVH01?l0003oC4a<
oda<C?l00008oc<c<`09o`000?m<C4coC4a<oda<C?l0003oIVIVo`000?moOgoo000000;oVIVI00Co
0000ok>c/onc/k?o00002?o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0
003oC4a<o`0000Wo<c<c00Go0000oda<C?m<C4co0000ofIVIP02o`000005oiVIVOl0003o/k>cok>c
/ol000001Oo<c<`6ooooo`7o00000Oooool1ooooo`006Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^
00Kooooo00?o0000ooooooooool00oooool>oda<C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmo
OomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVI
VOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00OoIVIV00?o0000oda<
C?m<C4`04om<C4`00ol0003oIVIVofIVIP03ofIVIP03o`000?moOgooOgmo00?oOgmo00Go0000oiVI
VOnIVIWoVIVIo`000007ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o0000ok>c/onc/k<01?nc/k<0
1Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<c
oc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000omVIVH00ol0003oOgmoo`000003oiVIV@04
o`000?nc/k?o/k>co`0000Soc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@03o`000?moOgoo
000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<02Ol0003oC4a<oda<C?m<C4co0000ofIVI_l0
003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00co0000ok>c/onc/k?o0000oiVI
VOl0003oOgmoo`000?mVIVKo0000oda<C?l00009oc<c<`05o`000?m<C4coC4a<o`000?mVIVH00_l0
00001OnIVIWo0000ok>c/onc/k?o000000Goc<c<1_ooool1o`00007ooooo0Oooool001Wooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00?ooooo3Om<C4`00ol0003oIVIV
ofIVIP0<ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>c
ok>c/`0Fok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIV
ofIVIP07ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmo
ogmoO`02ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01Onc/k<01Ol0003oc<c<
olc<c?o<c<co000000Oo/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`05o`000?mVIVKoIVIV
ofIVI_l000001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000
ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<
00Go0000ok>c/onc/k?o/k>co`000002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<
C4co00002?lc<c<02Ol0003oC4a<oda<C?m<C4co0000ofIVI_l0003oOgmoo`000002oiVIV@03o`00
0?nc/k?o000000Woc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<
C?l00009oc<c<`03o`000?m<C4co000000;oIVIV0_l000001OnIVIWo0000ok>c/onc/k?o000000Go
c<c<1_ooool1o`00007ooooo0Oooool001Wooooo00Go410@oooooooooooooooooa0@4006ooooo`03
o`000?oooooooooo00?ooooo3?m<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?moOgooOgmo00So
Ogmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00_o
VIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP08ofIVIP03o`000?m<C4coC4a<01?o
C4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00;o
VIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c00Co
/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000
oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000?oIVIV00?o0000ogmoOol000000onI
VIT01?l0003o/k>cok>c/ol00008olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT00ol0003o
Ogmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000Wo<c<c00Ko0000oda<C?m<C4co0000ofIVI_l0
0002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02_l0003o/k>cok>c
/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000
oda<C?m<C4co0000ofIVIP02o`0000;oVIVI00?o0000ok>c/ol000001_o<c<`6ooooo`7o00000Ooo
ool1ooooo`006Oooool01Ol0003ooooooooooooooooo000000Kooooo0ol00003ooooo`_oC4a<0_l0
000=ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c
/`0Fok>c/`;o00003?nIVIT2o`0000[oOgmo00?o0000ofIVI_mVIVH01omVIVH2o`0001KoC4a<00?o
0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o
0000ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c00Co/k>c00Go
0000oiVIVOnIVIWoVIVIo`000002ogmoO`05o`000?mVIVKoIVIVofIVI_l000001?m<C4`00ol0003o
<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0
003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`00
0002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<02?l0003oC4a<
oda<C?l0003oIVIVo`000?moOgoo00000_nIVIT00ol0003o/k>co`000009olc<c00:o`000?nc/k?o
/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<00ol0
003oC4a<o`000002ofIVIP;o00000_nIVIT00ol0003o/k>co`000006olc<c0Cooooo0ol00002oooo
o`006Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00oooool:oda<
C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVI
V@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`08ogmo
O`03o`000?mVIVKoIVIV00SoIVIV00?o0000oda<C?m<C4`05?m<C4`00ol0003oIVIVofIVIP03ofIV
IP03o`000?moOgooOgmo00?oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`04ok>c
/`03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<01?nc/k<01Ol0003oVIVIoiVIVOnIVIWo
000000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o
0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000?o
/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmo
Ool000000_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000
ogmoOol00002oiVIV@03o`000?nc/k?o000000Woc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003o
Ogmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`03o`000?m<C4co000000;oIVIV
0_l00002oiVIV@03o`000?nc/k?o000000Koc<c<1_ooool1o`00007ooooo0Oooool001Wooooo00Go
410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00?ooooo2Om<C4`00ol0003oIVIV
ofIVIP0<ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>c
ok>c/`0Fok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIV
ofIVIP08ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmo
ogmoO`03ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01Onc/k<00ol0003oc<c<
olc<c002olc<c003o`000?nc/k?o/k>c00Co/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`05
o`000?mVIVKoIVIVofIVI_l000001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<
00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<
c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@03o`000?moOgoo000000;oIVIV
00Co0000oda<C?m<C4co00002Olc<c<02?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo00000_nI
VIT01?l0003o/k>cok>c/ol00008olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003o
IVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?mo
Ogoo0000oiVIVOl0003o/k>co`0000Ooc<c<1_ooool1o`00007ooooo0Oooool001Wooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00?ooooo2?m<C4`2o`0000goIVIV00?o
0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o
0000oiVIVOnIVIT02onIVIT2o`0000[oOgmo00?o0000ofIVI_mVIVH02?mVIVH00ol0003oC4a<oda<
C00Eoda<C003o`000?mVIVKoIVIV00?oIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVI
V@02oiVIV@03o`000?nc/k?o/k>c00Go/k>c00?o0000olc<c?o<c<`00_o<c<`00ol0003o/k>cok>c
/`04ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01Ol0003oIVIVofIVI_mVIVKo000000Co
C4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`00
00;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c007o`000?nc/k?o
/k>cok>c/ol0003oVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000;oC4a<00?o0000oc<c<olc
<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c
/onc/k?o00002?o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<
C003o`000?lc<c?o<c<c00Ko<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo
0000ok>c/ol00007olc<c0Kooooo0Ol00001ooooo`7ooooo000Iooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01_ooool00ol0003oooooooooo`03ooooo`OoC4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0
003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0
003oVIVIoiVIV@0:oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02?mVIVH00ol0
003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00?oIVIV00?o0000ogmoOomoOgl00_moOgl00ol0
003oVIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c00Go/k>c00Go0000olc<c?o<c<coc<c<o`000007
ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01?l0003oIVIVofIVI_l00005oda<C003o`00
0?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04
o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01ol0003o/k>cok>c/onc/k?o
0000oiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c
00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`00
00Ooc<c<00_o0000ok>c/onc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003
o`000?lc<c?o<c<c00Ko<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000
ok>c/ol00007olc<c0Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo
1_m<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT0
2onIVIT00ol0003o/k>cok>c/`0Fok>c/`;o00003?nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`00
0?mVIVKoIVIV00WoIVIV00?o0000oda<C?m<C4`05Om<C4`00ol0003oIVIVofIVIP03ofIVIP03o`00
0?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`04ok>c/`03o`00
0?o<c<coc<c<00;oc<c<00?o0000ok>c/onc/k<01?nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?o
Ogmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<
C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o
0000olc<c?o<c<`01oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV
00Co0000oda<C?m<C4co00002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo0000
00;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`02?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo
00000_mVIVH00ol0003oC4a<o`000008oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0
003oVIVIo`000?nc/k?o00002?o<c<`6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003ooooo
ooooo`03ooooo`KoC4a<00?o0000ofIVI_mVIVH02_mVIVH2o`0000[oOgmo00?o0000oiVIVOnIVIT0
2_nIVIT2o`0001So/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`;o0000
2omVIVH00ol0003oC4a<oda<C00Eoda<C003o`000?mVIVKoIVIV00?oIVIV00?o0000ogmoOomoOgl0
0_moOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c00Go/k>c00Go0000olc<c?o<c<co
c<c<o`000006ok>c/`;o00000onIVIT01?l0003oOgmoogmoOol00003ofIVIP03o`000?m<C4coC4a<
00?oC4a<00?o0000oc<c<olc<c<01?lc<c<2o`0000?oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002
ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01ol0003o/k>cok>c
/onc/k?o0000oiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00002oda<C003o`000?lc<c?o<c<c
00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVIV@03o`000?nc/k?o
000000Woc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0
003o<c<coc<c<`06oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc
/k?o00002?o<c<`00ol0003oooooooooo`03ooooo`7o00000Oooool1ooooo`009?ooool00ol0003o
ooooooooo`03ooooo`GoC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`09ogmoO`03
o`000?nIVIWoVIVI00[oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03
o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Doda<C003
o`000?mVIVKoIVIV00?oIVIV00?o0000ogmoOomoOgl00omoOgl00ol0003oVIVIoiVIV@03oiVIV@03
o`000?nc/k?o/k>c00Go/k>c00Go0000olc<c?o<c<coc<c<o`000006ok>c/`03o`000?nIVIWoVIVI
00;oVIVI00Co0000ogmoOomoOgoo00000omVIVH00ol0003oC4a<oda<C003oda<C003o`000?lc<c?o
<c<c00Co<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Co
0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c007o`000?nc/k?o/k>cok>c/ol0
003oVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<0
1?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00?o0000ok>c/ol000002Oo<
c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o
<c<c00Ko<c<c00?o0000oda<C?m<C4`00_l00002ogmoO`05o`000?nIVIWo0000ok>c/ol000002?o<
c<`00ol0003oooooooooo`03ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03
ooooo`CoC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWo
VIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgoo
Ogmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Doda<C003o`000?mVIVKo
IVIV00CoIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o
/k>c00Go/k>c00Go0000olc<c?o<c<coc<c<o`000006ok>c/`03o`000?nIVIWoVIVI00;oVIVI00Co
0000ogmoOomoOgoo00000omVIVH00ol0003oC4a<oda<C003oda<C003o`000?lc<c?o<c<c00Co<c<c
00?o0000oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Co0000oiVIVOnI
VIWo00000onc/k<00ol0003oc<c<olc<c006olc<c007o`000?nc/k?o/k>cok>c/ol0003oVIVIo`00
0002ogmoO`04o`000?mVIVKoIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<
oda<C?l00002ofIVIP08o`000?moOgooOgmoo`000?nIVIWo0000ok>c/ol00009olc<c006o`000?nc
/k?o/k>co`000?nIVIWo00000_moOgl2o`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02_l0003o
C4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Goc<c<
00?o0000ooooooooool01?ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00ooo
ool2oda<C0;o00003?mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o
0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo0_l0
000<ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH01?mVIVH00ol0003oOgmoogmo
O`02ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<01_nc/k<01?l0003oc<c<olc<
c?l00007ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01Ol0003oIVIVofIVI_mVIVKo0000
00CoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIV
o`0000;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c007olc<c004o`000?nc
/k?o/k>co`0000;oVIVI00Ko0000ogmoOomoOgoo0000ofIVI_l00003oda<C003o`000?lc<c?o<c<c
00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o
0000olc<c?o<c<`01oo<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002
oda<C003o`000?lc<c?o<c<c00Ko<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nI
VIWo0000ok>c/ol00008olc<c003o`000?oooooooooo00Cooooo0Ol00001ooooo`7ooooo000Toooo
o`;o00001?ooool2oda<C003o`000?mVIVKoIVIV00[oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0
003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0
003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05Om<C4`00ol0
003oIVIVofIVIP04ofIVIP03o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0
003o/k>cok>c/`06ok>c/`04o`000?o<c<coc<c<o`0000Oo/k>c00Go0000oiVIVOnIVIWoVIVIo`00
0003ogmoO`05o`000?mVIVKoIVIVofIVI_l000001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`00
0?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00003ok>c
/`03o`000?o<c<coc<c<00Ooc<c<00Co0000ok>c/onc/k?o00000_nIVIT01_l0003oOgmoogmoOol0
003oIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP05
o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c00:o`000?nc/k?o/k>c
o`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<00ol0003o
C4a<o`000002ofIVIP07o`000?moOgoo0000oiVIVOl0003o/k>co`000008olc<c003o`000?oooooo
oooo00?ooooo0_l00002ooooo`009?ooool00ol0003oooooooooo`03ooooo`03oda<C?l0003oIVIV
00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c
01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV
00_oIVIV00?o0000oda<C?m<C4`05Om<C4`00ol0003oIVIVofIVIP04ofIVIP03o`000?moOgooOgmo
00;oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`06ok>c/`04o`000?o<c<coc<c<
o`0000Oo/k>c00Go0000oiVIVOnIVIWoVIVIo`000004ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<
00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C003oda<C004o`000?mVIVKoIVIVo`0000;o
Ogmo00Co0000oiVIVOnIVIWo00000_nc/k<00ol0003oc<c<olc<c007olc<c004o`000?nc/k?o/k>c
o`0000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`0;o`00
0?m<C4coC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<
c007olc<c004o`000?nc/k?o/k>co`0000;oVIVI0_l000001OmVIVKo0000oda<C?m<C4co000000So
<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00008olc<c003
o`000?nc/k?ooooo00Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo
00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI
00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo
0_l0000<ofIVIP03o`000?m<C4coC4a<01GoC4a<00?o0000ofIVI_mVIVH01?mVIVH00ol0003oOgmo
ogmoO`03ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01_nc/k<01?l0003oc<c<
olc<c?l00007ok>c/`;o00000onIVIT01Ol0003oOgmoogmoOomoOgoo000000;oIVIV00?o0000oda<
C?m<C4`00om<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIV
I_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go
0000ok>c/onc/k?o/k>co`000002oiVIV@06o`000?moOgooOgmoo`000?mVIVKo00000om<C4`00ol0
003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Go0000ogmoOol0003oVIVIo`00
0002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00?o0000ok>c/ol000000_nIVIT01Ol0003oOgmoo`00
0?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`00
0?moOgoo0000oiVIVOl0003o/k>co`0000Soc<c<00?o0000ok>c/oooool01Oooool1o`00007ooooo
0Oooool002Cooooo00?o0000ooooooooool00oooool<ofIVIP03o`000?moOgooOgmo00WoOgmo00?o
0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o
0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<01GoC4a<00?o
0000ofIVI_mVIVH01?mVIVH00ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o
0000ok>c/onc/k<01onc/k<00ol0003oc<c<o`000007ok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go
0000ogmoOomoOgooOgmoo`000002ofIVIP03o`000?m<C4coC4a<00?oC4a<00?o0000oc<c<olc<c<0
1?lc<c<00ol0003oC4a<oda<C003oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co0000oiVIVOnI
VIWo00000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT0
1_l0003oOgmoogmoOol0003oIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<
oda<C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<
c004o`000?nc/k?o/k>co`0000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc
<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4co0000ofIVIP02o`0000;oVIVI00?o0000ok>c/ol00000
2?o<c<`00ol0003o/k>cooooo`05ooooo`7o00000Oooool1ooooo`009?ooool00ol0003ooooooooo
o`03ooooo`_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc
/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mV
IVKoIVIV00coIVIV00?o0000oda<C?m<C4`05Om<C4`00ol0003oIVIVofIVIP04ofIVIP03o`000?mo
OgooOgmo00?oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`09ok>c/`03o`000?nc
/k?o/k>c00Go/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000;oIVIV
00?o0000oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<
00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<
00Goc<c<00?o0000ok>c/onc/k<00_nc/k<02?l0003oVIVIoiVIVOl0003oOgmoo`000?mVIVKo0000
0om<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol0
00000_nIVIT01?l0003o/k>cok>c/ol00008olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmo
Ool00002ofIVIP03o`000?m<C4co000000So<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmo
o`000?nIVIWo0000ok>c/ol00008olc<c004o`000?nc/k?o/k>co`0000Gooooo0Ol00001ooooo`7o
oooo000Tooooo`03o`000?oooooooooo00?ooooo2_mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`00
0?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`00
0?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH03?mVIVH00ol0003oC4a<oda<C00Eoda<C003o`00
0?mVIVKoIVIV00CoIVIV00?o0000ogmoOomoOgl00omoOgl00ol0003oVIVIoiVIV@02oiVIV@03o`00
0?nc/k?o/k>c01;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`05o`000?mVIVKoIVIVofIV
I_l000001Om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00;oC4a<00Go0000ofIV
I_mVIVKoIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<
c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<
oda<C?l00009oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Go0000ogmoOol0003oVIVIo`000002
ok>c/`03o`000?o<c<coc<c<00Ooc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mV
IVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmo
Ool0003oVIVIo`000?nc/k?o00002?o<c<`01?l0003o/k>cok>c/ol00005ooooo`7o00000Oooool1
ooooo`009?ooool00ol0003oooooooooo`03ooooo`WoIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0
003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT2o`00
00[oOgmo00?o0000ofIVI_mVIVH02_mVIVH2o`0001SoC4a<00?o0000ofIVI_mVIVH01?mVIVH00ol0
003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<04_nc/k<01Ol0
003oVIVIoiVIVOnIVIWo000000?oOgmo00Go0000ofIVI_mVIVKoIVIVo`000005oda<C003o`000?lc
<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo
00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c
/ol000000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000Wo<c<c00Co0000
oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`0
1oo<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc
<c?o<c<c00Ko<c<c00?o0000oda<C?m<C4`00_l00002ogmoO`05o`000?nIVIWo0000ok>c/ol00000
2?o<c<`01?l0003o/k>cok>c/ol00005ooooo`7o00000Oooool1ooooo`009?ooool00ol0003ooooo
ooooo`03ooooo`SoIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`00
0?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`00
0?mVIVKoIVIV00[oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP04ofIVIP03o`00
0?moOgooOgmo00?oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`0Bok>c/`05o`00
0?nIVIWoVIVIoiVIVOl000001?moOgl01?l0003oIVIVofIVI_l00005oda<C003o`000?lc<c?o<c<c
00Co<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Co0000
oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol00000
0_nIVIT00ol0003oOgmoo`000002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01?l0003o
C4a<oda<C?l00002ofIVIP03o`000?moOgooOgmo00;o00000_nc/k<00ol0003oc<c<olc<c007olc<
c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl2o`0000;oC4a<00?o0000oc<c<olc<c<01_lc
<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<co
c<c<00Koc<c<00?o0000ok>c/ol000001_ooool1o`00007ooooo0Oooool002Cooooo00?o0000oooo
ooooool00oooool7ofIVIP03o`000?moOgooOgmo00SoOgmo0_l0000=oiVIV@03o`000?nc/k?o/k>c
01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`;o00003?mVIVH00ol0
003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00CoIVIV00?o0000ogmoOomoOgl00omoOgl00ol0
003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c017o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0
003oOgmoogmoOomoOgoo000000?oIVIV00?o0000oda<C?m<C4`00_m<C4`00ol0003o<c<coc<c<`05
oc<c<`03o`000?m<C4coC4a<00;oC4a<00?o0000ofIVI_mVIVH00_l000000omoOgoo0000o`000002
oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI
00?o0000ogmoOol000000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Go0000oda<C?m<
C4co0000ofIVIP02o`000004ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01oo<c<`0
0ol0003o/k>co`000002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c
<`06oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00002?o<
c<`01?l0003o/k>cok>c/ol00006ooooo`7o00000Oooool1ooooo`009?ooool00ol0003ooooooooo
o`03ooooo`KoIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc
/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT2o`0000[oOgmo00?o0000ofIVI_mVIVH02_mV
IVH2o`0001WoC4a<00?o0000ofIVI_mVIVH01?mVIVH00ol0003oOgmoogmoO`03ogmoO`03o`000?nI
VIWoVIVI00?oVIVI00?o0000ok>c/onc/k<04Onc/k<00ol0003oVIVIoiVIV@02oiVIV@05o`000?mo
OgooOgmoogmoOol000000omVIVH00ol0003oC4a<oda<C002oda<C003o`000?lc<c?o<c<c00Go<c<c
00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`05o`000?nIVIWoVIVIoiVI
VOl000000onc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Ko0000oiVI
VOnIVIWo0000ogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<C?l000001olc<c<01ol0003oC4a<
oda<C?m<C4co0000ofIVI_l000000_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<
00Ooc<c<00Go0000ok>c/ol0003oVIVIo`000002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000
oc<c<olc<c<01_lc<c<01ol0003oC4a<oda<C?l0003oIVIVo`000?moOgl00_l00002ok>c/`03o`00
0?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00001_ooool1o`00007ooooo0Oooool002Cooooo
0_l00004ooooo`GoIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@;o0000
6?nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH0
2_mVIVH00ol0003oC4a<oda<C00Goda<C0;o00001_mVIVH00ol0003oOgmoogmoO`03ogmoO`03o`00
0?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<04_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?o
Ogmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<
C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000onc
/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmo
ogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Ko0000oda<C?m<C4co0000ofIVI_l0
0002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`00ol0003o/k>co`00
0002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0<o`00
0?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00002Oo<c<`01Ol0003o/k>c
o`000?nIVIWo000000Cooooo0_l00002ooooo`009?ooool00ol0003oooooooooo`03ooooo`CoIVIV
00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c
00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`;o00003?mVIVH00ol0003oC4a<
oda<C00Goda<C003o`000?mVIVKoIVIV00GoIVIV00?o0000ogmoOomoOgl00omoOgl00ol0003oVIVI
oiVIV@03oiVIV@03o`000?nc/k?o/k>c01;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`05
o`000?mVIVKoIVIVofIVI_l000001Om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<
00?oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<
c<coc<c<00Goc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@;o000000GoOgmoo`000?mVIVKo
IVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo
000000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o
/k>co`0000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c
00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00009olc<c0;o0000
00?oVIVIo`000?ooool01Oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00ooo
ool4ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c
/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIV
IP0:ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0003oOgmoogmo
O`03ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<04_nc/k<01Ol0003oVIVIoiVI
VOnIVIWo000000?oOgmo00Go0000ofIVI_mVIVKoIVIVo`000005oda<C003o`000?lc<c?o<c<c00Co
<c<c00?o0000oda<C?m<C4`00om<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVI
o`0000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co
0000ogmoOomoOgoo00000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`07o`000?m<C4coC4a<oda<
C?l0003oIVIVo`000002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`0
1?l0003o/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<c
oc<c<`06oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o0000
2Oo<c<`2o`000003oiVIVOl0003ooooo00Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oo
oooooooo00?ooooo0omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o
0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo00SoOgmo00?o
0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00OoIVIV00?o
0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c01;o/k>c00?o
0000oiVIVOnIVIT00_nIVIT01?l0003oOgmoogmoOol00004ofIVIP03o`000?m<C4coC4a<00;oC4a<
00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C005o`000?mVIVKoIVIVofIVI_l0
00000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c
/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Co0000oda<C?m<C4co0000
2?lc<c<01ol0003oC4a<oda<C?m<C4co0000ofIVI_l000000_moOgl00ol0003oVIVIo`000002ok>c
/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mV
IVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?l0003oIVIV00;o0000
0_nIVIT00ol0003o/k>co`000009olc<c0;o000000?oVIVIo`000?ooool01Oooool1o`00007ooooo
0Oooool002Cooooo00?o0000ooooooooool00oooool2ofIVIP03o`000?moOgooOgmo00SoOgmo00?o
0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o
0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o
0000ofIVI_mVIVH01_mVIVH00ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o
0000ok>c/onc/k<04_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Go0000ofIVI_mVIVKo
IVIVo`000005oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0003o
IVIVofIVI_mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c006
olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01?l0003oC4a<
oda<C?l00009oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl0
0002ok>c/`03o`000?o<c<coc<c<00Goc<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmo
o`000002ofIVIP03o`000?m<C4co000000So<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmo
o`000?nIVIWo0000ok>c/ol00009olc<c005o`000?nc/k?o0000o`000?moOgl01_ooool1o`00007o
oooo0Oooool002Cooooo00?o0000ooooooooool00oooool00omVIVKo0000ogmoO`09ogmoO`03o`00
0?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<2o`0000coVIVI0_l0000:ogmoO`03o`00
0?mVIVKoIVIV00[oIVIV0_l0000Ioda<C003o`000?mVIVKoIVIV00KoIVIV00?o0000ogmoOomoOgl0
0omoOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c01;o/k>c00?o0000oiVIVOnIVIT0
0_nIVIT01Ol0003oOgmoogmoOomoOgoo000000?oIVIV00?o0000oda<C?m<C4`00_m<C4`00ol0003o
<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00?o0000ofIVI_mVIVH00_l00002ogmoO`04
o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01oo<c<`01?l0003o/k>cok>c/ol00002
oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<01_l0003oC4a<
oda<C?l0003oIVIVo`0000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<
c004o`000?nc/k?o/k>co`0000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc
<c?o<c<c00Ko<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol0
0009olc<c005o`000?nc/k?o0000o`000?moOgl01_ooool1o`00007ooooo0Oooool002Cooooo00?o
0000ooooooooool00oooool00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o
0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo00SoOgmo00?o
0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00KoIVIV00?o
0000ogmoOomoOgl00omoOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c01?o/k>c00Go
0000oiVIVOnIVIWoVIVIo`000004ogmoO`05o`000?mVIVKoIVIVofIVI_l000001?m<C4`00ol0003o
<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000omoOgl01?l0
003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`00
0002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<01_l0003o
C4a<oda<C?l0003oIVIVo`0000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006
olc<c004o`000?nc/k?o/k>co`0000;oVIVI0_l00002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c
00?o0000oda<C?m<C4`00_l00002ogmoO`05o`000?nIVIWo0000ok>c/ol000002Oo<c<`01Ol0003o
/k>co`000?l0003oOgmo00Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?o
oooo2_moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnI
VIT03?nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<
C4`05om<C4`00ol0003oIVIVofIVIP07ofIVIP03o`000?moOgooOgmo00?oOgmo00?o0000oiVIVOnI
VIT00onIVIT00ol0003o/k>cok>c/`0Bok>c/`05o`000?nIVIWoVIVIoiVIVOl000001?moOgl01Ol0
003oIVIVofIVI_mVIVKo000000CoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002
oda<C004o`000?mVIVKoIVIVo`0000?oOgmo00Go0000oiVIVOnIVIWoVIVIo`000002ok>c/`03o`00
0?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`00
00;oIVIV00Co0000oda<C?m<C4co00002Olc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo
00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c003o`000?nc/k?o000000;oVIVI
00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00co0000oda<C?m<
C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00009olc<c007o`000?nc/k?o0000oiVI
VOl0003oOgmoo`000005ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03oooo
o`WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI
00_oVIVI0_l0000:ogmoO`03o`000?mVIVKoIVIV00[oIVIV0_l0000Ioda<C0;o00002?mVIVH00ol0
003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<04_nc/k<00ol0
003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol000000omVIVH00ol0003oC4a<oda<C003
oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00om<C4`01?l0003oIVIVofIVI_l0
0003ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>c
ok>c/onc/k?o000000;oVIVI00Ko0000ogmoOomoOgoo0000ofIVI_l00003oda<C003o`000?lc<c?o
<c<c00Ko<c<c00?o0000oda<C?m<C4`00_l000001?mVIVKo0000ogmoOol00002oiVIV@03o`000?nc
/k?o000000[oc<c<00?o0000ok>c/ol000000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<
00?o0000oc<c<olc<c<01_lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0
003o/k>co`0000Soc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`0000Gooooo0Ol00001
ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo2?moOgl00ol0003oVIVIoiVIV@0;oiVI
V@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`09ogmo
O`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP08ofIV
IP03o`000?moOgooOgmo00?oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0Bok>c
/`03o`000?nIVIWoVIVI00;oVIVI00Co0000ogmoOomoOgoo00001?mVIVH00ol0003oC4a<oda<C003
oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00om<C4`01?l0003oIVIVofIVI_l0
0003ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>c
ok>c/ol00002oiVIV@07o`000?moOgooOgmoogmoOol0003oIVIVo`000003oda<C003o`000?lc<c?o
<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVIV@03o`000?nc
/k?o000000[oc<c<00Go0000ok>c/ol0003oVIVIo`000002ogmoO`03o`000?mVIVKo000000;oC4a<
00?o0000oc<c<olc<c<01_lc<c<00ol0003oC4a<o`000002ofIVIP04o`000?moOgoo0000o`0000;o
/k>c00?o0000olc<c?o<c<`01_o<c<`02?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo00001Ooo
ool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool7ogmoO`03o`000?nIVIWo
VIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<2o`0000coVIVI00?o0000ogmoOomoOgl02OmoOgl0
0ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02?mVIVH0
0ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<04_nc/k<0
0ol0003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol000000omVIVH00ol0003oC4a<oda<
C003oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00om<C4`01?l0003oIVIVofIV
I_l00003ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`01Ol0003o
/k>cok>c/onc/k?o000000;oVIVI00Ko0000ogmoOomoOgoo0000ofIVI_l00003oda<C003o`000?lc
<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`00
0?nc/k?o/k>co`0000Woc<c<00?o0000ok>c/ol000000_nIVIT01Ol0003oOgmoo`000?mVIVKo0000
00;oC4a<00?o0000oc<c<olc<c<01_lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000
oiVIVOl0003o/k>co`0000Soc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`0000Kooooo
0Ol00001ooooo`7ooooo000Tooooo`;o00001?ooool6ogmoO`03o`000?nIVIWoVIVI00[oVIVI0_l0
000Hok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl2o`0000goIVIV00?o
0000oda<C?m<C4`05om<C4`2o`0000SoIVIV0_l00005ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o
0000ok>c/onc/k<04onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Co0000ofIVI_mVIVKo
IVIV0_l00005oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0003o
IVIVofIVI_mVIVKo000000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000003ok>c/`03o`000?o<c<co
c<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@03o`000?moOgoo000000;oIVIV00Go
0000oda<C?m<C4coC4a<o`000008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol0
00000_nIVIT01?l0003o/k>cok>c/ol00008olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Go0000
ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00co0000oda<C?m<C4co0000
ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00008olc<c008o`000?nc/k?o/k>co`000?nIVIWo
0000ogmoOol00005ooooo`;o00000_ooool002Cooooo00?o0000ooooooooool00oooool5ogmoO`03
o`000?nIVIWoVIVI00[oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03
o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH03?mVIVH00ol0003oC4a<oda<C00Goda<C003
o`000?mVIVKoIVIV00SoIVIV00?o0000ogmoOomoOgl01?moOgl00ol0003oVIVIoiVIV@03oiVIV@03
o`000?nc/k?o/k>c01?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`05o`000?mVIVKoIVIV
ofIVI_l000001_m<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000
ofIVI_mVIVKo00000omoOgl01Ol0003oVIVIoiVIVOnIVIWo000000?o/k>c00?o0000olc<c?o<c<`0
1_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmoOol000000_mVIVH01Ol0003o
C4a<oda<C?m<C4co000000So<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002
oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT01Ol0003oOgmo
o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<03?l0003oC4a<oda<C?l0003oIVIV
o`000?moOgoo0000oiVIVOl0003o/k>co`0000Soc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003o
Ogmoo`0000Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo1?moOgl0
0ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT0
0ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00coIVIV00?o0000oda<C?m<C4`05om<C4`0
0ol0003oIVIVofIVIP08ofIVIP03o`000?moOgooOgmo00CoOgmo00?o0000oiVIVOnIVIT00onIVIT0
0ol0003o/k>cok>c/`0Cok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01Ol0003oIVIVofIV
I_mVIVKo000000KoC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C002oda<C005o`00
0?mVIVKoIVIVofIVI_l000000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000?o/k>c00?o0000olc<
c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmoOol000000_mVIVH0
1Ol0003oC4a<oda<C?m<C4co000000So<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmo
o`000003oiVIV@04o`000?nc/k?o/k>co`0000Ooc<c<00Co0000ok>c/onc/k?o00000_nIVIT01Ol0
003oOgmoo`000?mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01Olc<c<03?l0003oC4a<oda<C?l0
003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Woc<c<00Wo0000ok>c/ol0003oVIVIo`00
0?moOgoo0000ofIVI_l000001Oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool0
0oooool3ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVI
oiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo0_l0000=ofIVIP03o`000?m<C4coC4a<01OoC4a<
00?o0000ofIVI_mVIVH02?mVIVH00ol0003oOgmoogmoO`04ogmoO`03o`000?nIVIWoVIVI00?oVIVI
00?o0000ok>c/onc/k<04onc/k<00ol0003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol0
00000omVIVH00ol0003oC4a<oda<C003oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<
C4`00om<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<0
0ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00?o0000oiVIVOl000000_moOgl0
1?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co0000
0_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Ko0000ok>c/onc
/k?o0000oiVIVOl00002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<0
3?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Woc<c<00Wo0000
ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000001Oooool1o`00007ooooo0Oooool002Cooooo
00?o0000ooooooooool00oooool2ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<0
5_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH0
3?mVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00SoIVIV00?o0000ogmoOomoOgl0
1OmoOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT0
0_nIVIT01?l0003oOgmoogmoOol00004ofIVIP03o`000?m<C4coC4a<00?oC4a<00?o0000oc<c<olc
<c<01?lc<c<00ol0003oC4a<oda<C003oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01?l0
003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<0
0ol0003oVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc
<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o
00002?o<c<`02?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo00000_mVIVH01?l0003oC4a<oda<
C?l00008oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o0000
2Oo<c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000005ooooo`7o00000Oooool1
ooooo`009?ooool00ol0003oooooooooo`03ooooo`03ogmoOol0003oVIVI00coVIVI00?o0000ok>c
/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIV
I_mVIVH03?mVIVH00ol0003oC4a<oda<C00Foda<C0;o00002omVIVH00ol0003oOgmoogmoO`04ogmo
O`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<04onc/k<00ol0003oVIVIoiVIV@02oiVI
V@05o`000?moOgooOgmoogmoOol000000omVIVH00ol0003oC4a<oda<C003oda<C003o`000?lc<c?o
<c<c00Co<c<c00?o0000oda<C?m<C4`00om<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Co
0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c006olc<c007o`000?nc/k?o/k>cok>c/ol0
003oVIVIo`000002ogmoO`05o`000?mVIVKoIVIVofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06
oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c
/ol00008olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl00ol0003oIVIVo`000002oda<
C003o`000?lc<c?o<c<c00Ko<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo
0000ok>c/ol00009olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000Kooooo
0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo00?o0000oiVIVOnIVIT02onI
VIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?mo
Ogl2o`0000goIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0:ofIVIP03o`000?mo
OgooOgmo00CoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`0Bok>c/`03o`000?nI
VIWoVIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`000004ofIVIP03o`000?m<C4coC4a<00?oC4a<
00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C003oda<C004o`000?mVIVKoIVIVo`0000?o
Ogmo00Co0000oiVIVOnIVIWo00000onc/k<2o`0000Ooc<c<00Go0000ok>c/onc/k?o/k>co`000002
oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`04o`00
0?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00008olc<
c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc
<c?o<c<c00Ko<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol0
0008olc<c0;o000000So/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000Kooooo0Ol00001oooo
o`7ooooo000Iooooo`Go00001_ooool00ol0003oooooooooo`03ooooo`goVIVI00?o0000ok>c/onc
/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mV
IVH02omVIVH2o`0001SoC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`05ogmoO`03
o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<04_nc/k<00ol0003oVIVIoiVIV@02oiVIV@05
o`000?moOgooOgmoogmoOol000000omVIVH00ol0003oC4a<oda<C004oda<C003o`000?lc<c?o<c<c
00Co<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Co0000
oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol00000
0_nIVIT01?l0003oOgmoogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01?l0
003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<
c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o
<c<coc<c<`06oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o
00002?o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00006ooooo`7o0000
0Oooool1ooooo`006Oooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo00?o0000ooooooooool0
0oooool<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmo
ogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIV
ofIVIP0:ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>c
ok>c/`0Bok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`000004ofIVIP03
o`000?m<C4coC4a<00CoC4a<00?o0000oc<c<olc<c<00olc<c<00ol0003oC4a<oda<C003oda<C004
o`000?mVIVKoIVIVo`0000?oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006
olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP05o`00
0?m<C4coC4a<oda<C?l000002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo0000
00;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@05o`000?mo
Ogoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0:o`000?m<C4coC4a<o`000?mV
IVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02_l0003o/k>co`00
0?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4`6ooooo`7o00000Oooool1ooooo`006_ooool00onH
V9So8B4Qonk^kP07ooooo`03o`000?oooooooooo00?ooooo2onIVIT00ol0003o/k>cok>c/`0Fok>c
/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIV
IP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`05ogmo
O`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<04_nc/k<00ol0003oVIVIoiVIV@02oiVI
V@03o`000?moOgooOgmo00;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000006oda<C003o`000?lc<c?o
<c<c00?o<c<c00?o0000oda<C?m<C4`00om<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Go
0000oiVIVOnIVIWoVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o
/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<0
1Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c
/ol00008olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl00ol0003oIVIVo`000002oda<
C003o`000?lc<c?o<c<c00Ko<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo
0000ok>c/ol00009olc<c00:o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C0Ko
oooo0Ol00001ooooo`7ooooo000Kooooo`03oiRHV?lQ8B7ok^k^00Kooooo0ol00003ooooo`[oVIVI
00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@;o00002_moOgl00ol0003oIVIV
ofIVIP0:ofIVIP;o00006?m<C4`00ol0003oIVIVofIVIP0:ofIVIP03o`000?moOgooOgmo00GoOgmo
00?o0000oiVIVOnIVIT01OnIVIT00ol0003o/k>cok>c/`0Bok>c/`03o`000?nIVIWoVIVI00;oVIVI
00?o0000ogmoOomoOgl00_moOgl01Ol0003oIVIVofIVI_mVIVKo000000KoC4a<00?o0000oc<c<olc
<c<00olc<c<00ol0003oC4a<oda<C003oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01?l0
003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`00
0002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<01Ol0003o
C4a<oda<C?m<C4co000000;oIVIV00Go0000ogmoOol0003oVIVIo`000003ok>c/`03o`000?o<c<co
c<c<00Koc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`05o`000?mVIVKo0000oda<C?l0
00002Olc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Wo
c<c<00_o0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`000003ooooo`?o0000
0_ooool001cooooo00?oMgMgofIVI_ooool01Oooool00ol0003oooooooooo`03ooooo`WoVIVI00?o
0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o
0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00[oIVIV00?o
0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@05oiVIV@03o`000?nc/k?o/k>c01?o/k>c00Go
0000oiVIVOnIVIWoVIVIo`000004ogmoO`05o`000?mVIVKoIVIVofIVI_l000001_m<C4`00ol0003o
<c<coc<c<`03oc<c<`03o`000?m<C4coC4a<00?oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmo
O`05o`000?nIVIWoVIVIoiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o
/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000So
<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP03o`000?moOgoo000000;oVIVI00Go0000ok>c
/onc/k?o/k>co`000007olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl00ol0003oIVIV
o`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmo
o`000?nIVIWo0000ok>c/ol00009olc<c003o`000?nc/k?o000000;oVIVI0_l000001OmVIVKo0000
oda<C?m<C4co000000Gooooo0Ol00001ooooo`7ooooo000Mooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00oooool8oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT0
2onIVIT00ol0003oOgmoogmoO`08ogmoO`;o00003?mVIVH00ol0003oC4a<oda<C00Goda<C003o`00
0?mVIVKoIVIV00[oIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@05oiVIV@03o`00
0?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000Co
IVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?o
C4a<00Co0000ofIVI_mVIVKo00000omoOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<co
c<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mV
IVKoIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01ol0003oC4a<oda<C?m<C4co0000ofIV
I_l000000_moOgl00ol0003oVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00So0000ok>c
/onc/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<03?l0003o
C4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Woc<c<00_o0000ok>c/ol0
003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`000006ooooo`7o00000Oooool1ooooo`006Ooo
ool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool00oooool7oiVIV@03o`00
0?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT2o`0000[oOgmo00?o0000ofIVI_mVIVH0
2_mVIVH2o`0001SoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`05ogmoO`03o`00
0?nIVIWoVIVI00GoVIVI00?o0000ok>c/onc/k<04onc/k<00ol0003oVIVIoiVIV@02oiVIV@05o`00
0?moOgooOgmoogmoOol000000omVIVH00ol0003oC4a<oda<C004oda<C003o`000?lc<c?o<c<c00Co
<c<c00?o0000oda<C?m<C4`00om<C4`01?l0003oIVIVofIVI_l00003ogmoO`04o`000?nIVIWoVIVI
o`0000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`06o`000?nIVIWo
VIVIo`000?moOgoo00000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Oo0000oda<C?m<
C4coC4a<o`000?mVIVKo000000;oOgmo00?o0000oiVIVOl000000onc/k<00ol0003oc<c<olc<c006
olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP04o`000?m<C4coC4a<o`00
00So<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00009olc<
c00;o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l000001_ooool1o`00007o
oooo0Oooool000_ooooo0ol000000ol@413oooooooooo`08ooooo`05oiRHV?l@413o0000ob4Q8Oo<
c<`01_ooool00ol0003oooooooooo`03ooooo`GoVIVI0_l0000Hok>c/`03o`000?nIVIWoVIVI00_o
VIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<01Oo
C4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00Go
VIVI00?o0000ok>c/onc/k<04onc/k<00ol0003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmo
Ool000001?mVIVH00ol0003oC4a<oda<C003oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<
C?m<C4`00om<C4`01?l0003oIVIVofIVI_l00003ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o
0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo
00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`00
00;oIVIV00Go0000ogmoOol0003oVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Ko0000
ok>c/onc/k?o0000oiVIVOl00002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<0
1_lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Woc<c<
00?o0000ok>c/onc/k<00_l000001?moOgoo0000ofIVI_mVIVH2o`000003oc<c<ooooooooooo00Co
oooo0Ol00001ooooo`7ooooo000=ooooo`03oa0@4?nj^[[ooooo01Cooooo00?o0000ooooooooool0
0oooool4oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmo
ogmoO`08ogmoO`;o00003?mVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00_oIVIV
00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@05oiVIV@03o`000?nc/k?o/k>c01?o/k>c
00?o0000oiVIVOnIVIT00_nIVIT00ol0003oOgmoogmoO`02ogmoO`05o`000?mVIVKoIVIVofIVI_l0
00001_m<C4`00ol0003o<c<coc<c<`03oc<c<`;o00001?m<C4`01Ol0003oIVIVofIVI_mVIVKo0000
00;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000
ok>c/onc/k?o/k>co`000003oiVIV@03o`000?moOgoo000000;oIVIV00Go0000oda<C?m<C4coC4a<
o`000008oc<c<`07o`000?m<C4coC4a<oda<C?l0003oIVIVo`000002ogmoO`03o`000?nIVIWo0000
00?o/k>c00?o0000olc<c?o<c<`01_o<c<`02?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000
0_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0
003oVIVIo`000?nc/k?o00002Oo<c<`03?l0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`00
0?m<C4co0000oc<c<`Kooooo0Ol00001ooooo`7ooooo000=ooooo`03oiRHV?lb<S;ooooo01Cooooo
00?o0000ooooooooool00oooool4oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT0
2onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00[oIVIV00?o0000oda<C?m<C4`0
5om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00KoOgmo00?o0000oiVIVOnIVIT0
1OnIVIT00ol0003o/k>cok>c/`0Cok>c/`03o`000?nIVIWoVIVI00;oVIVI00?o0000ogmoOomoOgl0
0_moOgl01Ol0003oIVIVofIVI_mVIVKo000000KoC4a<00?o0000oc<c<olc<c<00olc<c<00ol0003o
C4a<oda<C003oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01Ol0003oVIVIoiVIVOnIVIWo
000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000?oVIVI00?o
0000ogmoOol000000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Oo0000oda<C?m<C4co
C4a<o`000?mVIVKo000000;oOgmo00?o0000oiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<
c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000So
<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00009olc<c00<
o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l0003o<c<c1_ooool1o`00007o
oooo0Oooool000gooooo00?ogMgMo`000?nj^[X05?ooool00ol0003oooooooooo`03ooooo`?oVIVI
00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo00SoOgmo
00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV
00?o0000ogmoOomoOgl01_moOgl00ol0003oVIVIoiVIV@05oiVIV@03o`000?nc/k?o/k>c01Co/k>c
00Go0000oiVIVOnIVIWoVIVIo`000004ogmoO`05o`000?mVIVKoIVIVofIVI_l000001_m<C4`00ol0
003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002
ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c
/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o
<c<coc<c<`06oc<c<`07o`000?m<C4coC4a<oda<C?l0003oIVIVo`000002ogmoO`03o`000?nIVIWo
000000?o/k>c00?o0000olc<c?o<c<`01Oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?mo
Ogoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<00ol0003oC4a<o`000002ofIVIP04o`00
0?moOgoo0000o`0000;o/k>c00?o0000olc<c?o<c<`01oo<c<`03?l0003o/k>co`000?nIVIWo0000
ogmoOol0003oIVIVo`000?m<C4co0000oc<c<`Kooooo0Ol00001ooooo`7ooooo000=ooooo`03oeEE
EOmgMgOoA4A401Cooooo00?o0000ooooooooool00oooool2oiVIV@03o`000?nc/k?o/k>c01Oo/k>c
00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV
00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00KoOgmo
00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`0Cok>c/`03o`000?nIVIWoVIVI00;oVIVI
00?o0000ogmoOomoOgl00_moOgl01Ol0003oIVIVofIVI_mVIVKo000000KoC4a<00?o0000oc<c<olc
<c<00olc<c<00ol0003oC4a<oda<C003oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01Ol0
003oVIVIoiVIVOnIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc
/k?o000000?oVIVI00?o0000ogmoOol000000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c
00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00?o0000oiVIVOl000000onc/k<00ol0
003oc<c<olc<c006olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP04o`00
0?m<C4coC4a<o`0000So<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000
0_nc/k<00ol0003oc<c<olc<c006olc<c00;o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo
0000oda<C?l000000_lc<c<6ooooo`7o00000Oooool1ooooo`003?ooool01OoMgMgo410@oooooolQ
8B7ogMgM01?ooooo00?o0000ooooooooool00oooool00onIVIWo0000ok>c/`0Gok>c/`;o00003?nI
VIT2o`0000[oOgmo00?o0000ofIVI_mVIVH02_mVIVH2o`0001SoC4a<00?o0000ofIVI_mVIVH02omV
IVH2o`0000SoOgmo00?o0000oiVIVOnIVIT01OnIVIT00ol0003o/k>cok>c/`0Cok>c/`03o`000?nI
VIWoVIVI00;oVIVI00?o0000ogmoOomoOgl00_moOgl01Ol0003oIVIVofIVI_mVIVKo000000KoC4a<
00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C003oda<C005o`000?mVIVKoIVIVofIVI_l0
00000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0
003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01Ol0003oC4a<oda<
C?m<C4co000000So<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00?o0000oiVI
VOl000000_nc/k<2o`0000Soc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV
00Co0000oda<C?m<C4co00002?lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVI
VOl0003o/k>co`0000Woc<c<00_o0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<
o`000002oc<c<`Kooooo0Ol00001ooooo`7ooooo000<ooooo`05ofIVI_n7QhOooooooiRHV?mEEED0
4oooool2o`0000Cooooo00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0<oiVIV@03o`00
0?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`00
0?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@05oiVIV@03o`00
0?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`02ogmoO`05o`00
0?mVIVKoIVIVofIVI_l000001_m<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?o
C4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000onc/k<0
0ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmo
Ool00002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<02Ol0003oC4a<oda<C?m<C4co0000
ofIVI_l0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Woc<c<00[o0000ok>c/onc/k?o
0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`07oc<c<`0<o`000?m<
C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00002Oo<c<`02ol0003o/k>co`00
0?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co000000;o<c<c1Oooool2o`0000;ooooo000;oooo
o`03onk^k_l0003ok^k^00;ooooo00?o0000omgMgOooool04Oooool00ol0003oooooooooo`03oooo
oaSo/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV
00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo
00OoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`0Bok>c/`03o`000?nIVIWoVIVI
00CoVIVI00Go0000ogmoOomoOgooOgmoo`000003ofIVIP03o`000?m<C4coC4a<00CoC4a<00?o0000
oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C003oda<C005o`000?mVIVKoIVIVofIVI_l000000_mo
Ogl01Ol0003oVIVIoiVIVOnIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>c
ok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01Ol0003oC4a<oda<C?m<C4co
000000So<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00?o0000oiVIVOl00000
0_nc/k<00ol0003oc<c<olc<c007olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002
ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`00
0?nIVIWo0000ok>c/ol00009olc<c003o`000?nc/k?o000000;oVIVI0_l000001OmVIVKo0000oda<
C?m<C4co000000;o<c<c1_ooool1o`00007ooooo0Oooool000_ooooo00Co410@o`000?l0003ooooo
0_l000000ol@413oooooooooo`0@ooooo`03o`000?oooooooooo00?ooooo5onc/k<00ol0003oVIVI
oiVIV@0;oiVIV@;o00002_moOgl00ol0003oIVIVofIVIP0:ofIVIP;o00006?m<C4`00ol0003oIVIV
ofIVIP0;ofIVIP03o`000?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>c
ok>c/`0Cok>c/`03o`000?nIVIWoVIVI00?oVIVI00Go0000ogmoOomoOgooOgmoo`000004ofIVIP03
o`000?m<C4coC4a<00CoC4a<00?o0000oc<c<olc<c<00olc<c<00ol0003oC4a<oda<C003oda<C005
o`000?mVIVKoIVIVofIVI_l000000omoOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<co
c<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mV
IVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP06
o`000?moOgooOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c007olc<c008o`000?nc/k?o
/k>co`000?nIVIWo0000ogmoOol00002ofIVIP03o`000?m<C4co000000Wo<c<c00co0000oda<C?m<
C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00009olc<c00;o`000?nc/k?o0000oiVI
VOl0003oOgmoo`000?mVIVKo0000oda<C?l000000olc<c<6ooooo`7o00000Oooool1ooooo`009?oo
ool00ol0003oooooooooo`03oooooaOo/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmo
O`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIV
IP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT01OnIVIT00ol0003o/k>cok>c
/`0Dok>c/`03o`000?nIVIWoVIVI00?oVIVI00Go0000ogmoOomoOgooOgmoo`000004ofIVIP03o`00
0?m<C4coC4a<00CoC4a<00?o0000oc<c<olc<c<00olc<c<00ol0003oC4a<oda<C003oda<C005o`00
0?mVIVKoIVIVofIVI_l000000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Co/k>c00?o0000olc<
c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co0000
ofIVI_mVIVKo00000_m<C4`00ol0003o<c<coc<c<`07oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV
00Ko0000ogmoOomoOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00So0000ok>c
/onc/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV00?o0000oda<C?l000002Olc<c<03?l0003oC4a<
oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Woc<c<00_o0000ok>c/ol0003o
VIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`000003oc<c<`Kooooo0Ol00001ooooo`7ooooo000T
ooooo`03o`000?oooooooooo00?ooooo5Onc/k<2o`0000coVIVI00?o0000ogmoOomoOgl02OmoOgl0
0ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH0
0ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00GoVIVI00?o0000ok>c/onc/k<05?nc/k<0
0ol0003oVIVIoiVIV@03oiVIV@05o`000?moOgooOgmoogmoOol000001?mVIVH00ol0003oC4a<oda<
C004oda<C003o`000?lc<c?o<c<c00?o<c<c00?o0000oda<C?m<C4`00om<C4`01Ol0003oIVIVofIV
I_mVIVKo000000?oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c005olc<c003
o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00003
oda<C003o`000?lc<c?o<c<c00Ko<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo
00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c006o`000?nc/k?o/k>co`000?nI
VIWo00000_moOgl01Ol0003oIVIVo`000?m<C4co000000Wo<c<c00[o0000oda<C?m<C4co0000ofIV
I_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c003o`000?nc/k?o/k>c
00;o000000CoOgmoo`000?mVIVKoIVIV0_l00004oc<c<`Kooooo0Ol00001ooooo`7ooooo000Toooo
o`03o`000?oooooooooo00?ooooo5?nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo
00SoOgmo0_l0000=ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0
003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00GoVIVI00?o0000ok>c/onc/k<05?nc/k<00ol0
003oVIVIoiVIV@03oiVIV@03o`000?moOgooOgmo00;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000007
oda<C003o`000?lc<c?o<c<c00;o<c<c00?o0000oda<C?m<C4`01?m<C4`01Ol0003oIVIVofIVI_mV
IVKo000000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Goc<c<
00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`00
00;oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o0000
ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00009olc<c008o`000?nc/k?o/k>co`000?nIVIWo
0000ogmoOol00002ofIVIP03o`000?m<C4co000000Wo<c<c00?o0000oda<C?l000000_mVIVH01Ol0
003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02ol0003o/k>co`000?nI
VIWo0000ogmoOol0003oIVIVo`000?m<C4co000000Co<c<c1_ooool1o`00007ooooo0Oooool002Co
oooo00?o0000ooooooooool00ooooolCok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomo
Ogl02?moOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mV
IVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc
/k<04onc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00;oOgmo00Go0000ofIVI_mV
IVKoIVIVo`000007oda<C003o`000?lc<c?o<c<c00;o<c<c00?o0000oda<C?m<C4`01?m<C4`01Ol0
003oIVIVofIVI_mVIVKo000000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<
c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`00
0?mVIVKoIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co0000
00;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00009olc<c008o`000?nc/k?o
/k>co`000?nIVIWo0000ogmoOol00002ofIVIP03o`000?m<C4co000000Wo<c<c00?o0000oda<C?l0
00000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01Oo<c<`03?l0
003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000Co<c<c1_ooool1o`00
007ooooo0Oooool002Cooooo00?o0000ooooooooool00ooooolBok>c/`03o`000?nIVIWoVIVI00_o
VIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<01Ko
C4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00Ko
VIVI00?o0000ok>c/onc/k<05?nc/k<00ol0003oVIVIoiVIV@03oiVIV@03o`000?moOgooOgmo00;o
Ogmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C004oda<C003o`000?lc<c?o<c<c00;o
<c<c00?o0000oda<C?m<C4`01?m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Go0000oiVI
VOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`00
0002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<01Ol0003o
C4a<oda<C?m<C4co000000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00009
olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP03o`000?m<C4co000000Wo
<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<
olc<c006olc<c005o`000?nc/k?o0000oiVIVOl000000_moOgl2o`0000;oC4a<00?o0000oc<c<olc
<c<00_lc<c<6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03oooooa7o/k>c
00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`;o00003OmVIVH00ol0003oC4a<
oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVI
oiVIV@06oiVIV@03o`000?nc/k?o/k>c01Co/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmo
ogmoO`02ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01?m<C4`00ol0003o<c<c
oc<c<`03oc<c<`03o`000?m<C4coC4a<00?oC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`04
o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o
000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c
00Go0000oda<C?m<C4coC4a<o`000002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc
/k?o00002?o<c<`02Ol0003o/k>cok>c/onc/k?o0000oiVIVOl0003oOgmoo`000002ofIVIP03o`00
0?m<C4co000000Wo<c<c00?o0000oda<C?l000000_mVIVH01ol0003oOgmoo`000?nIVIWo0000ok>c
/ol000002Oo<c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003o`00
0?lc<c?o<c<c00;o<c<c1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00ooo
ool@ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIV
IP0<ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmo
O`08ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc/k<05Onc/k<00ol0003oVIVIoiVI
V@03oiVIV@03o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<
C004oda<C003o`000?lc<c?o<c<c00?o<c<c00?o0000oda<C?m<C4`00om<C4`01Ol0003oIVIVofIV
I_mVIVKo000000?oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c006olc<c005
o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP05o`000?m<C4co
C4a<oda<C?l000002?lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o0000ogmoOol00000
0_nIVIT01?l0003o/k>cok>c/ol00008olc<c009o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000?mo
Ogoo000000;oIVIV00?o0000oda<C?l000002Olc<c<00ol0003oC4a<o`000002ofIVIP07o`000?mo
Ogoo0000oiVIVOl0003o/k>co`000009olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mV
IVKo000000;oC4a<00?o0000oc<c<olc<c<00_lc<c<6ooooo`7o00000Oooool1ooooo`009?ooool2
o`0000Cooooo3onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000
ofIVI_mVIVH03?mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000
ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@07oiVIV@03o`000?nc/k?o/k>c01Co/k>c00?o0000
oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000
oda<C?m<C4`01?m<C4`00ol0003o<c<coc<c<`03oc<c<`03o`000?m<C4coC4a<00?oC4a<00?o0000
ofIVI_mVIVH00_mVIVH01?l0003oOgmoogmoOol00002oiVIV@03o`000?nc/k?o/k>c00;o/k>c00?o
0000olc<c?o<c<`01_o<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo
00Co0000ofIVI_mVIVKo00000_m<C4`00ol0003o<c<coc<c<`07oc<c<`04o`000?m<C4coC4a<o`00
00;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00008olc<c009o`000?nc/k?o
/k>cok>c/ol0003oVIVIo`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<00ol0
003oC4a<o`000002ofIVIP07o`000?moOgoo0000oiVIVOl0003o/k>co`000009olc<c003o`000?nc
/k?o000000;oVIVI0_l000001OmVIVKo0000oda<C?m<C4co000000Go<c<c1Oooool2o`0000;ooooo
000Tooooo`03o`000?oooooooooo00?ooooo3_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?mo
OgooOgmo00SoOgmo0_l0000=ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omV
IVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00OoVIVI00?o0000ok>c/onc/k<05?nc
/k<00ol0003oVIVIoiVIV@03oiVIV@03o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH00_mV
IVH00ol0003oC4a<oda<C005oda<C003o`000?lc<c?o<c<c00;o<c<c00?o0000oda<C?m<C4`01?m<
C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03
o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmo
o`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`05o`000?m<C4coC4a<oda<C?l00000
0_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Co0000ok>c/onc
/k?o00000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01olc<c<0
0ol0003oC4a<o`000002ofIVIP07o`000?moOgoo0000oiVIVOl0003o/k>co`000009olc<c009o`00
0?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<00olc<c<6
ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`go/k>c00?o0000oiVI
VOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV0_l0000Hoda<
C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@07oiVI
V@03o`000?nc/k?o/k>c01Co/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`02ogmo
O`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01Om<C4`01Ol0003o<c<coc<c<olc<c?o
000000OoC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVIVOl00000
1?nc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003o
OgmoogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01Ol0003oC4a<oda<C?m<
C4co000000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00008olc<c004o`00
0?nc/k?o/k>co`0000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c
00Oo<c<c00?o0000oda<C?l000000_mVIVH01ol0003oOgmoo`000?nIVIWo0000ok>c/ol000002Oo<
c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c
00?o<c<c1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool<ok>c/`03
o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03
o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`;o
00002OnIVIT00ol0003o/k>cok>c/`0Dok>c/`03o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomo
Ogl00_moOgl00ol0003oIVIVofIVIP02ofIVIP03o`000?m<C4coC4a<00GoC4a<00?o0000oc<c<olc
<c<00_lc<c<00ol0003oC4a<oda<C004oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01Ol0
003oVIVIoiVIVOnIVIWo000000Co/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc
/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So
<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c
/onc/k?o00002?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgooOgmo00;o00000_m<
C4`00ol0003o<c<coc<c<`07oc<c<`03o`000?m<C4co000000;oIVIV00Go0000ogmoOol0003oVIVI
o`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Oo0000ok>c/ol0003oVIVIo`000?moOgoo0000
00;oIVIV00?o0000oda<C?l000001_lc<c<6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003o
ooooooooo`03ooooo`_o/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03
o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0;ofIVIP03
o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02?nIVIT00ol0003o/k>cok>c/`0Dok>c/`03
o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl00_moOgl2o`0000?oIVIV00?o0000oda<C?m<
C4`01Om<C4`00ol0003o<c<coc<c<`02oc<c<`03o`000?m<C4coC4a<00CoC4a<0_l00002ofIVIP05
o`000?moOgooOgmoogmoOol000000onIVIT00ol0003o/k>cok>c/`02ok>c/`03o`000?o<c<coc<c<
00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKo
IVIVo`0000;oC4a<00?o0000oc<c<olc<c<01olc<c<01ol0003oC4a<oda<C?m<C4co0000ofIVI_l0
00000_moOgl01?l0003oVIVIoiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c
/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01olc
<c<00ol0003oC4a<o`000002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<
olc<c006olc<c00;o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l000001olc
<c<6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`[o/k>c00?o0000
oiVIVOnIVIT02onIVIT2o`0000[oOgmo00?o0000ofIVI_mVIVH02_mVIVH2o`0001SoC4a<00?o0000
ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00SoVIVI00?o0000
ok>c/onc/k<05?nc/k<00ol0003oVIVIoiVIV@03oiVIV@03o`000?moOgooOgmo00;oOgmo00?o0000
ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C005oda<C003o`000?lc<c?o<c<c00;o<c<c00?o0000
oda<C?m<C4`01?m<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Go0000oiVIVOnIVIWoVIVI
o`000004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVI
oiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01olc<c<01ol0
003oC4a<oda<C?m<C4co0000ofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00002ok>c/`03o`00
0?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mVIVKo0000
00;oC4a<00?o0000oc<c<olc<c<01olc<c<00ol0003oC4a<o`000002ofIVIP05o`000?moOgoo0000
oiVIVOl000000_nc/k<00ol0003oc<c<olc<c005olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000
ogmoOol0003oIVIVo`000?m<C4co00001olc<c<6ooooo`7o00000Oooool1ooooo`009?ooool00ol0
003oooooooooo`03ooooo`Wo/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmo
O`03o`000?mVIVKoIVIV00[oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0;ofIV
IP03o`000?moOgooOgmo00SoOgmo0_l0000:oiVIV@03o`000?nc/k?o/k>c01Co/k>c00?o0000oiVI
VOnIVIT00onIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<
C?m<C4`01_m<C4`01Ol0003o<c<coc<c<olc<c?o000000KoC4a<00?o0000ofIVI_mVIVH00_mVIVH0
1?l0003oOgmoogmoOol00003oiVIV@03o`000?nc/k?o/k>c00;o/k>c00?o0000olc<c?o<c<`01Oo<
c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo
00000om<C4`00ol0003o<c<coc<c<`06oc<c<`07o`000?m<C4coC4a<oda<C?l0003oIVIVo`000002
ogmoO`04o`000?nIVIWoVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01oo<c<`02_l0003o/k>cok>c
/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c00[o0000
oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<
c005o`000?nc/k?o0000oiVIVOl000000_moOgl2o`0000;oC4a<00?o0000oc<c<olc<c<01Olc<c<6
ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`So/k>c00?o0000oiVI
VOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`;o00003?mVIVH00ol0003oC4a<oda<C00Goda<
C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@09oiVI
V@03o`000?nc/k?o/k>c01Co/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`02ogmo
O`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01Om<C4`01Ol0003o<c<coc<c<olc<c?o
000000OoC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c
00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/onc/k<2o`0000;oVIVI00Co0000ogmoOomo
Ogoo00000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Co0000oda<C?m<C4co00000_mV
IVH01_l0003oOgmoogmoOol0003oVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o
/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07
oc<c<`0:o`000?m<C4co0000o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<
c?o<c<`01_o<c<`01_l0003o/k>co`000?nIVIWo0000ogmoO`?o00000_m<C4`00ol0003o<c<coc<c
<`05oc<c<`Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo1onc/k<0
0ol0003oVIVIoiVIV@0;oiVIV@;o00002_moOgl00ol0003oIVIVofIVIP0:ofIVIP;o00006?m<C4`0
0ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02?nIVIT0
0ol0003o/k>cok>c/`0Eok>c/`03o`000?nIVIWoVIVI00CoVIVI00Go0000ogmoOomoOgooOgmoo`00
0005ofIVIP03o`000?m<C4coC4a<00GoC4a<00Go0000oc<c<olc<c?o<c<co`000007oda<C005o`00
0?mVIVKoIVIVofIVI_l000000omoOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<
00Koc<c<00Go0000ok>c/onc/k?o/k>co`000003oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Go
0000oda<C?m<C4coC4a<o`000008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Ko0000ogmoOomo
Ogoo0000oiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nI
VIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<
oda<C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<
c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<0
1Olc<c<6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`Ko/k>c00?o
0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00[oIVIV00?o
0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo0_l0
000:oiVIV@03o`000?nc/k?o/k>c01Go/k>c00?o0000oiVIVOnIVIT01?nIVIT01Ol0003oOgmoogmo
OomoOgoo000000GoIVIV00?o0000oda<C?m<C4`01Om<C4`00ol0003o<c<coc<c<`02oc<c<`03o`00
0?m<C4coC4a<00CoC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`05o`000?nIVIWoVIVIoiVI
VOl000000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000onIVIT0
1?l0003oOgmoogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01Ol0003oC4a<
oda<C?m<C4co000000;oIVIV00Go0000ogmoOol0003oVIVIo`000003ok>c/`03o`000?o<c<coc<c<
00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4co
C4a<o`0000So<c<c00?o0000oda<C?l000000_mVIVH00ol0003oOgmoo`000002oiVIV@03o`000?nc
/k?o000000Soc<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0
003o<c<coc<c<`06oc<c<`Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?o
oooo1Onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo0_l0000<ofIVIP03
o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03
o`000?nIVIWoVIVI00WoVIVI00?o0000ok>c/onc/k<05Onc/k<00ol0003oVIVIoiVIV@04oiVIV@03
o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C006oda<C005
o`000?lc<c?o<c<coc<c<ol000001_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Go0000
oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc
/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc
<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Ko0000ogmoOomoOgoo0000oiVIVOl0
0002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Co0000ok>c/onc/k?o00000_nIVIT01Ol0003oOgmo
o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIV
IP07o`000?moOgoo0000oiVIVOl0003o/k>co`000009olc<c009o`000?nc/k?o0000oiVIVOl0003o
Ogmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<00ol0003oooooooooo`03oooo
o`7o00000Oooool1ooooo`009?ooool2o`0000Cooooo1?nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03
o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<oda<C00Goda<C003
o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0:oiVIV@03
o`000?nc/k?o/k>c01Go/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`03ogmoO`03
o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01_m<C4`01Ol0003o<c<coc<c<olc<c?o0000
00KoC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc
/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo0000
0_moOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<
C4coC4a<o`000002ofIVIP06o`000?moOgooOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<
c007olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003
o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH01ol0003oOgmoo`000?nIVIWo
0000ok>c/ol000002Oo<c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<
C003o`000?lc<c?o<c<c00Ko<c<c00?o0000ooooooooool00_ooool2o`0000;ooooo000Tooooo`03
o`000?oooooooooo00?ooooo0onc/k<00ol0003oVIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo00So
Ogmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_o
IVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0:oiVIV@03o`000?nc/k?o/k>c01Ko
/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00;o
IVIV00?o0000oda<C?m<C4`01_m<C4`3o`000003oc<c<ol0003oC4a<00KoC4a<00Go0000ofIVI_mV
IVKoIVIVo`000003ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01_o<c<`0
0ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo0000
0om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH00ol0003o
Ogmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Woc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl0
0002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<
C?l00002ofIVIP07o`000?moOgoo0000oiVIVOl0003o/k>co`000009olc<c009o`000?nc/k?o0000
oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<00ol0003ooooo
ooooo`03ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`?o/k>c00?o
0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o
0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o
0000oiVIVOnIVIT02_nIVIT00ol0003o/k>cok>c/`0Eok>c/`03o`000?nIVIWoVIVI00?oVIVI00?o
0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIVIP02ofIVIP03o`000?m<C4coC4a<00KoC4a<00Co
0000oc<c<ol0003o00001om<C4`00ol0003oIVIVofIVIP02ofIVIP04o`000?moOgooOgmoo`0000?o
VIVI00?o0000ok>c/onc/k<00_nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o
/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o
<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP06o`000?moOgooOgmoo`000?nIVIWo
00000onc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Go0000ogmo
Ool0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00?o0000oda<C?l000000_mVIVH0
1Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01ol0003o/k>co`00
0?nIVIWo0000ogmoOol000000_mVIVH00ol0003oC4a<o`000008oc<c<`03o`000?oooooooooo00Co
oooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo00?o/k>co`000?l00000
3?nIVIT2o`0000[oOgmo00?o0000ofIVI_mVIVH02_mVIVH2o`0001SoC4a<00?o0000ofIVI_mVIVH0
2omVIVH00ol0003oOgmoogmoO`08ogmoO`;o00003?nIVIT00ol0003o/k>cok>c/`0Eok>c/`03o`00
0?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP02ofIVIP03o`00
0?m<C4coC4a<00KoC4a<00Go0000oc<c<olc<c?o<c<co`000007oda<C005o`000?mVIVKoIVIVofIV
I_l000000omoOgl01?l0003oVIVIoiVIVOl00005ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000
ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<
00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o0000ogmoOol0
00000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Ooc<c<0_l00002ok>c/`03o`000?nIVIWo0000
00;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`03o`000?m<C4co0000
00;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Wo0000
ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`03
o`000?oooooooooo00Cooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo
00?o0000oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV
00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo
00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`0Dok>c/`03o`000?nIVIWoVIVI00CoVIVI
00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<00KoC4a<
00Go0000oc<c<olc<c?o<c<co`000006oda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomo
OgooOgmoo`000002oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0
003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo00000om<
C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Ko0000ofIVI_mVIVKo0000
ogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Oo0000ok>c/onc/k?o/k>co`000?nI
VIWo000000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`03o`000?m<
C4co000000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Goc<c<
00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c
<`06oc<c<`03o`000?oooooooooo00Cooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooo
oooo00?ooooo3_nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000
oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000
oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Eok>c/`03o`000?nIVIWoVIVI00?oVIVI00?o0000
ogmoOomoOgl00omoOgl00ol0003oIVIVofIVIP02ofIVIP03o`000?m<C4coC4a<00KoC4a<00Go0000
oc<c<olc<c?o<c<co`000006oda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgooOgmo
o`000003oiVIV@03o`000?nc/k?o/k>c00;o/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>c
ok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0
003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01_l0003oOgmoogmoOol0
003oVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/onc/k<2o`0000;o
Ogmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`03o`000?m<C4co000000;o
IVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Wo0000ok>c
/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`03o`00
0?m<C4cooooo00Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo3?nI
VIT2o`0000[oOgmo00?o0000ofIVI_mVIVH02_mVIVH2o`0001SoC4a<00?o0000ofIVI_mVIVH02omV
IVH00ol0003oOgmoogmoO`08ogmoO`;o00003OnIVIT00ol0003o/k>cok>c/`0Eok>c/`03o`000?nI
VIWoVIVI00CoVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<
C4coC4a<00KoC4a<0_l000000olc<c?o0000oda<C006oda<C005o`000?mVIVKoIVIVofIVI_l00000
0omoOgl01Ol0003oVIVIoiVIVOnIVIWo000000Go/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o
/k>cok>c/`02ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00003
oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP03o`000?mo
Ogoo000000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`01_l0003o/k>cok>c/ol0003oVIVIo`00
00;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<
o`0000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Wo
0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c
<`03o`000?m<C4cooooo00Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?o
oooo2onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<
C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnI
VIT03?nIVIT00ol0003o/k>cok>c/`0Eok>c/`03o`000?nIVIWoVIVI00GoVIVI00?o0000ogmoOomo
Ogl00_moOgl00ol0003oIVIVofIVIP02ofIVIP03o`000?m<C4coC4a<00WoC4a<00?o0000oda<C?m<
C4`01_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Go0000oiVIVOnIVIWoVIVIo`000005
ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnI
VIWo000000;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`00
0?m<C4coC4a<oda<C?l000000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`00
00Woc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`03o`000?mVIVKo000000;oC4a<00?o
0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl0
00000_nc/k<00ol0003oc<c<olc<c006olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mV
IVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<00ol0003oC4a<o`000005ooooo`7o00000Ooo
ool1ooooo`006oooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool00oooool:
oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00F
oda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0;
oiVIV@03o`000?nc/k?o/k>c01Go/k>c00?o0000oiVIVOnIVIT01OnIVIT00ol0003oOgmoogmoO`02
ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`04_m<C4`01Ol0003oIVIVofIVI_mV
IVKo000000?oOgmo00Go0000oiVIVOnIVIWoVIVIo`000005ok>c/`03o`000?o<c<coc<c<00Coc<c<
00?o0000ok>c/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Co0000ofIVI_mV
IVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH0
0ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Woc<c<00Ko0000ok>c/onc/k?o0000
oiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01Olc<c<01?l0
003oC4a<oda<C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<
c006olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c
<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00005ooooo`7o00000Oooool1ooooo`007?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo2OnIVIT00ol0003oOgmoogmoO`08ogmo
O`;o00003OmVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmo
OomoOgl02?moOgl2o`0000goVIVI00?o0000ok>c/onc/k<05Onc/k<00ol0003oVIVIoiVIV@05oiVI
V@03o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00Boda<
C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01Ol0003oVIVIoiVIVOnIVIWo000000Co/k>c00?o
0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo
00Go0000ofIVI_mVIVKoIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Oo0000oda<C?m<
C4coC4a<o`000?mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo00000_nc/k<00ol0003oc<c<olc<
c007olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl00ol0003oIVIVo`000002oda<C003
o`000?lc<c?o<c<c00Ko<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`05o`000?nIVIWo
0000ok>c/ol000002Oo<c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<
C003o`000?lc<c?o<c<c00Ko<c<c00?o0000oda<C?l000001_ooool1o`00007ooooo0Oooool001Wo
oooo1Ol00006ooooo`?o00000oooool8oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mV
IVH03?mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomo
Ogl02?moOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnI
VIT01?nIVIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<
C4`04Om<C4`00ol0003oIVIVofIVIP02ofIVIP05o`000?moOgooOgmoogmoOol000000onIVIT00ol0
003o/k>cok>c/`02ok>c/`03o`000?o<c<coc<c<00Goc<c<00Go0000ok>c/onc/k?o/k>co`000003
oiVIV@04o`000?moOgooOgmoo`0000?oIVIV00Co0000oda<C?m<C4co00002Olc<c<01ol0003oC4a<
oda<C?m<C4co0000ofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00002ok>c/`03o`000?o<c<co
c<c<00Ooc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`03o`000?mVIVKo000000;oC4a<
00?o0000oc<c<olc<c<01_lc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00Go0000oiVI
VOl0003o/k>co`000009olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000;o
C4a<00?o0000oc<c<olc<c<01_lc<c<00ol0003oC4a<o`000004ooooo`?o00000_ooool001Wooooo
00CoA4A4omgMgOoooooo00001oooool00ol0003oooooooooo`03ooooo`OoVIVI00?o0000ogmoOomo
Ogl02?moOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mV
IVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00coVIVI00?o0000ok>c/onc
/k<05_nc/k<00ol0003oVIVIoiVIV@05oiVIV@03o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mV
IVH00omVIVH00ol0003oC4a<oda<C00Aoda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomo
OgooOgmoo`000003oiVIV@03o`000?nc/k?o/k>c00;o/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0
003o/k>cok>c/`02ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01?l0003oIVIVofIVI_l0
0003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo000000;o
Ogmo00Co0000oiVIVOnIVIWo00000_nc/k<00ol0003oc<c<olc<c007olc<c004o`000?nc/k?o/k>c
o`0000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Go
0000oda<C?l0003oIVIVo`000002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`0
1_o<c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000003oda<C003o`000?lc<c?o
<c<c00Go<c<c00Co0000oda<C?l0003oIVIV1_ooool1o`00007ooooo0Oooool001Wooooo00CogMgM
oeEEEOoooooo00001oooool00ol0003oooooooooo`03ooooo`KoVIVI00?o0000ogmoOomoOgl02?mo
Ogl2o`0000goIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?mo
OgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT2o`0001So/k>c00?o0000oiVIVOnIVIT01OnI
VIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<C4`04_m<
C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Go0000oiVIVOnIVIWoVIVIo`000005ok>c/`03
o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmo
O`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01Olc<c<01Ol0003oC4a<oda<C?m<
C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01?l0003o/k>cok>c/ol00008olc<c003
o`000?nc/k?o/k>c00;o000000OoVIVIo`000?moOgooOgmoo`000?mVIVKo000000;oC4a<00?o0000
oc<c<olc<c<01olc<c<01Ol0003oC4a<o`000?mVIVKo000000;oOgmo00?o0000oiVIVOl000000_nc
/k<00ol0003oc<c<olc<c006olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000
00;oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<o`000?mVIVH6ooooo`7o00000Oooool1
ooooo`006_ooool00omgMgOoc<c<o`000007ooooo`03o`000?oooooooooo00?ooooo1OnIVIT00ol0
003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00coIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0
003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0
003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00KoVIVI00?o0000ogmoOomoOgl00_moOgl00ol0
003oIVIVofIVIP02ofIVIP03o`000?m<C4coC4a<01?oC4a<00Go0000ofIVI_mVIVKoIVIVo`000003
ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001Onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc
/k?o/k>c00?o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00004oda<C003
o`000?lc<c?o<c<c00Go<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmo
o`0000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@06o`00
0?moOgooOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`07oc<c<`05o`000?m<C4co0000
ofIVI_l000000_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Wo0000
ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`05
o`000?m<C4co0000ofIVI_l000001Oooool1o`00007ooooo0Oooool001[ooooo00?ok^k^odA4A?l0
00001oooool00ol0003oooooooooo`03ooooo`CoVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003o
IVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003o
OgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003o
VIVIoiVIV@06oiVIV@03o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003o
C4a<oda<C00Boda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01Ol0003oVIVIoiVIVOnIVIWo
000000Go/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWo
VIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`05oc<c<`05o`00
0?m<C4coC4a<oda<C?l000000omVIVH01_l0003oOgmoogmoOol0003oVIVIo`0000?o/k>c00?o0000
olc<c?o<c<`01Oo<c<`01ol0003o/k>cok>c/onc/k?o0000oiVIVOl000000_moOgl00ol0003oIVIV
o`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Go0000oda<C?l0003oIVIVo`000002ogmoO`03
o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02Ol0003o/k>co`000?nIVIWo0000
ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c0_l00002ofIVIP03o`000?oo
oooooooo00?ooooo0Ol00001ooooo`7ooooo000Kooooo`03ogMgMol0003ooooo00Kooooo00?o0000
ooooooooool00oooool3oiVIV@03o`000?moOgooOgmo00SoOgmo0_l0000=ofIVIP03o`000?m<C4co
C4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWo
VIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@05oiVIV@;o00001?moOgl0
0ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<01;oC4a<00?o0000ofIVI_mVIVH00_mVIVH0
1Ol0003oOgmoogmoOomoOgoo000000?oVIVI00?o0000ok>c/onc/k<00_nc/k<00ol0003oc<c<olc<
c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`04o`00
0?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co0000
00;oIVIV00Ko0000ogmoOomoOgoo0000oiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Wo
0000ok>c/onc/k?o/k>co`000?nIVIWo0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00008
oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl00ol0003oVIVIo`000002ok>c/`03o`00
0?o<c<coc<c<00Koc<c<00_o0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`00
000:oc<c<`;o000000?oIVIVo`000?ooool01Oooool1o`00007ooooo0Oooool002Cooooo00?o0000
ooooooooool00oooool2oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH2
o`0001SoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWo
VIVI00[oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@06oiVIV@03o`000?moOgoo
Ogmo00?oOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00Boda<C003o`000?mVIVKo
IVIV00;oIVIV00Co0000ogmoOomoOgoo00001?nIVIT00ol0003o/k>cok>c/`02ok>c/`03o`000?o<
c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo
00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<
C?l000000_mVIVH01_l0003oOgmoogmoOol0003oVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<
c<`02Ol0003o/k>cok>c/onc/k?o0000oiVIVOl0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<
o`0000So<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`03o`000?nIVIWo000000;o/k>c
00?o0000olc<c?o<c<`01_o<c<`02ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<
C4co000000[o<c<c0_l000000omVIVKo0000ooooo`05ooooo`7o00000Oooool1ooooo`009?ooool0
0ol0003oooooooooo`03ooooo`03oiVIVOl0003oOgmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH0
0ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl2
o`0000coVIVI00?o0000ok>c/onc/k<06?nc/k<00ol0003oVIVIoiVIV@05oiVIV@03o`000?moOgoo
Ogmo00?oOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00Boda<C003o`000?mVIVKo
IVIV00;oIVIV00Go0000ogmoOomoOgooOgmoo`000003oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o
0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`02ok>c/`05o`000?nIVIWoVIVIoiVIVOl00000
0_moOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<
C4coC4a<o`000002ofIVIP06o`000?moOgooOgmoo`000?nIVIWo00000onc/k<00ol0003oc<c<olc<
c006olc<c007o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`00
00;oC4a<00?o0000oc<c<olc<c<01Olc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00Ko
0000oiVIVOnIVIWo0000ok>c/ol00008olc<c005o`000?nc/k?o0000oiVIVOl000000_moOgl2o`00
00;oC4a<00?o0000oc<c<olc<c<01olc<c<01Ol0003oC4a<o`000?l0003oOgmo00Kooooo0Ol00001
ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo00?o0000ogmoOomoOgl02?moOgl00ol0
003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0
003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<06?nc/k<00ol0
003oVIVIoiVIV@05oiVIV@03o`000?moOgooOgmo00?oOgmo00?o0000ofIVI_mVIVH01?mVIVH00ol0
003oC4a<oda<C00Boda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01?l0003oVIVIoiVIVOnI
VIT2o`0000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nI
VIWoVIVIo`0000?oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`05
o`000?m<C4coC4a<oda<C?l000000_mVIVH01_l0003oOgmoogmoOol0003oVIVIo`0000?o/k>c00?o
0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@06o`000?moOgoo0000o`000?mV
IVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmo
Ool00002oiVIV@03o`000?nc/k?o000000Woc<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000
ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`03o`000?m<C4coC4a<00;o000000?oOgmo
ooooooooool01?ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool00ol0
003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00[oIVIV0_l0000Hoda<C003o`000?mVIVKoIVIV
00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0:oiVIV@03o`000?nc/k?o/k>c
01So/k>c00?o0000oiVIVOnIVIT01_nIVIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV
00?oIVIV00?o0000oda<C?m<C4`04om<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Go0000
oiVIVOnIVIWoVIVIo`000005ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00onc
/k<01?l0003oVIVIoiVIVOl00003ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc
<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Ko0000ogmoOomoOgoo0000oiVIVOl0
0003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmo
o`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00So0000oda<C?m<C4co0000ofIVI_l0003o
Ogmoo`0000;oVIVI00?o0000ok>c/ol000002Oo<c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0
003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00?o0000oda<C?m<C4`00_l000000omo
Ogoo0000ooooo`04ooooo`7o00000Oooool1ooooo`009?ooool2o`0000Cooooo2_moOgl00ol0003o
IVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003o
OgmoogmoO`08ogmoO`;o00003?nIVIT00ol0003o/k>cok>c/`0Hok>c/`03o`000?nIVIWoVIVI00Ko
VIVI00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIVIP04ofIVIP03o`000?m<C4coC4a<01;o
C4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001Onc/k<0
0ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000omo
Ogl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4co
C4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`0
1?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co0000
2?lc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0
003oc<c<olc<c006olc<c003o`000?nc/k?o000000;oVIVI0_l00002ofIVIP03o`000?m<C4co0000
00Wo<c<c00Co0000oda<C?l0003o00000_moOgl00ol0003oooooooooo`02ooooo`;o00000_ooool0
02Cooooo00?o0000ooooooooool00oooool8ogmoO`;o00003?mVIVH00ol0003oC4a<oda<C00Goda<
C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVI
V@03o`000?nc/k?o/k>c01So/k>c00?o0000oiVIVOnIVIT01_nIVIT00ol0003oOgmoogmoO`03ogmo
O`03o`000?mVIVKoIVIV00CoIVIV00?o0000oda<C?m<C4`04_m<C4`00ol0003oIVIVofIVIP02ofIV
IP05o`000?moOgooOgmoogmoOol000000onIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<co
c<c<00Coc<c<00?o0000ok>c/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Co
0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l0
00000_mVIVH01_l0003oOgmoo`000?l0003oVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`0
1?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co0000
2?lc<c<02?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo00000_nIVIT01?l0003o/k>cok>c/ol0
0008olc<c007o`000?nc/k?o0000oiVIVOl0003oOgmoo`000002ofIVIP03o`000?m<C4co000000So
<c<c00?o0000oda<C?m<C4`00_l000000omoOgoo0000ooooo`05ooooo`7o00000Oooool1ooooo`00
9?ooool00ol0003oooooooooo`03ooooo`SoOgmo00?o0000ofIVI_mVIVH02_mVIVH2o`0001SoC4a<
00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00[oVIVI
00?o0000ok>c/onc/k<06?nc/k<00ol0003oVIVIoiVIV@07oiVIV@03o`000?moOgooOgmo00?oOgmo
00?o0000ofIVI_mVIVH01?mVIVH00ol0003oC4a<oda<C00Boda<C003o`000?mVIVKoIVIV00;oIVIV
00Co0000ogmoOomoOgoo00001?nIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00Co
c<c<00?o0000ok>c/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Co0000ofIV
I_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Co
0000ogmoOomoOgoo00000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Co0000ok>c/onc
/k?o00000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00So0000
oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`02Ol0
003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c
00?o0000oda<C?m<C4`00_l000000omoOgoo0000ooooo`05ooooo`7o00000Oooool1ooooo`009?oo
ool00ol0003oooooooooo`03ooooo`OoOgmo00?o0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<oda<
C00Goda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl2o`0000coVIVI00?o
0000ok>c/onc/k<06?nc/k<00ol0003oVIVIoiVIV@07oiVIV@03o`000?moOgooOgmo00?oOgmo00?o
0000ofIVI_mVIVH01?mVIVH00ol0003oC4a<oda<C00Boda<C003o`000?mVIVKoIVIV00;oIVIV00Go
0000ogmoOomoOgooOgmoo`000003oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`0
1?o<c<`00ol0003o/k>cok>c/`02ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01?l0003o
IVIVofIVI_l00004oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002
ofIVIP03o`000?moOgoo000000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c004o`000?nc
/k?o/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`08
o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<
00?o0000ok>c/onc/k<00_l000001omoOgoo0000ofIVI_mVIVKo0000oda<C?l000002Olc<c<01?l0
003oC4a<o`000?mVIVH2o`000003oiVIVOoooooooooo00Cooooo0Ol00001ooooo`7ooooo000Toooo
o`03o`000?oooooooooo00?ooooo1OmoOgl2o`0000coIVIV00?o0000oda<C?m<C4`05_m<C4`2o`00
00goIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c
01So/k>c00?o0000oiVIVOnIVIT01onIVIT00ol0003oOgmoogmoO`03ogmoO`;o00001OmVIVH00ol0
003oC4a<oda<C00Boda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgooOgmoo`000003
oiVIV@03o`000?nc/k?o/k>c00?o/k>c0_l00006olc<c003o`000?nc/k?o/k>c00;o/k>c00Go0000
oiVIVOnIVIWoVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<0
1_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01?l0
003o/k>cok>c/ol00009olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol000000_mV
IVH01?l0003oC4a<oda<C?l00008oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002
oiVIV@04o`000?nc/k?o0000o`0000Soc<c<00Oo0000ok>c/ol0003oVIVIo`000?moOgoo000000;o
IVIV00?o0000oda<C?l000002Olc<c<01?l0003oC4a<o`000?mVIVH2o`000003oiVIVOoooooooooo
00Cooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo1OmoOgl00ol0003o
IVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003o
OgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00coVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003o
VIVIoiVIV@07oiVIV@03o`000?moOgooOgmo00CoOgmo00?o0000ofIVI_mVIVH01?mVIVH00ol0003o
C4a<oda<C00Boda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgooOgmoo`000003oiVI
V@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c
/`04o`000?nIVIWoVIVIo`0000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000003oda<C003o`000?lc
<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;o
VIVI00Co0000ok>c/onc/k?o00002Oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo
000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?mo
Ogoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Oo0000ok>c/ol0003oVIVIo`00
0?moOgoo000000;oIVIV00?o0000oda<C?l000002Olc<c<01?l0003oC4a<o`000?mVIVH2o`000003
oiVIVOoooooooooo00Cooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo
1?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH0
2omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00coVIVI00?o0000ok>c/onc/k<0
5onc/k<00ol0003oVIVIoiVIV@07oiVIV@03o`000?moOgooOgmo00CoOgmo00?o0000ofIVI_mVIVH0
1?mVIVH00ol0003oC4a<oda<C00Boda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgoo
Ogmoo`000004oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o
/k>cok>c/`03ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000003
oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l0
0002ogmoO`04o`000?nIVIWoVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01oo<c<`01?l0003o/k>c
ok>c/ol00002oiVIV@;o00000omVIVH01?l0003oC4a<oda<C?l00008oc<c<`0:o`000?m<C4coC4a<
o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01oo<c<`01ol0003o
/k>co`000?nIVIWo0000ogmoOol000000_mVIVH00ol0003oC4a<o`000008oc<c<`03o`000?m<C4co
000000;oIVIV0_l000000onIVIWo0000ooooo`04ooooo`7o00000Oooool1ooooo`009?ooool00ol0
003oooooooooo`03ooooo`?oOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<
C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0;oiVI
V@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT01onIVIT00ol0003oOgmoogmoO`05ogmo
O`03o`000?mVIVKoIVIV00CoIVIV00?o0000oda<C?m<C4`04_m<C4`00ol0003oIVIVofIVIP02ofIV
IP05o`000?moOgooOgmoogmoOol000000onIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<co
c<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00003ogmoO`05o`000?mV
IVKoIVIVofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l0
00000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Woc<c<00Co0000
ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c
00So0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000;oVIVI00?o0000ok>c/ol000002Oo<c<`0
1Ol0003o/k>co`000?nIVIWo000000;oOgmo00Go0000ofIVI_l0003oC4a<o`000009oc<c<`09o`00
0?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000Gooooo0Ol00001ooooo`7ooooo000Toooo
o`03o`000?oooooooooo00?ooooo0_moOgl00ol0003oIVIVofIVIP0:ofIVIP;o00006?m<C4`00ol0
003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo0_l0000=oiVIV@03o`000?nc/k?o/k>c
01Oo/k>c00?o0000oiVIVOnIVIT02?nIVIT00ol0003oOgmoogmoO`04ogmoO`03o`000?mVIVKoIVIV
00CoIVIV00?o0000oda<C?m<C4`04_m<C4`00ol0003oIVIVofIVIP02ofIVIP05o`000?moOgooOgmo
ogmoOol000001?nIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000
ok>c/onc/k<00onc/k<01?l0003oVIVIoiVIVOl00003ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<
00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomo
Ogoo00000_nIVIT01?l0003o/k>cok>c/ol00009olc<c005o`000?nc/k?o/k>co`000?nIVIT00_l0
00001?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c00So0000oda<C?m<C4co
0000ofIVI_l0003oOgmoo`0000;oVIVI00?o0000ok>c/ol000002Oo<c<`01ol0003o/k>co`000?nI
VIWo0000ogmoOol000000_mVIVH00ol0003oC4a<o`000008oc<c<`0:o`000?m<C4coC4a<o`000?mV
IVKo0000ogmoOol0003oVIVIo`0000Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooo
oooo00?ooooo00?oOgmoo`000?mVIVH03?mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKo
IVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o
/k>c01Ko/k>c0_l0000;oiVIV@03o`000?moOgooOgmo00CoOgmo00?o0000ofIVI_mVIVH00omVIVH0
0ol0003oC4a<oda<C00Coda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgooOgmoo`00
0004oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c
/`03ok>c/`04o`000?nIVIWoVIVIo`0000?oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o
<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH00ol0003oOgmoo`000003oiVI
V@04o`000?nc/k?o/k>co`0000Soc<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo
00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`08o`000?m<C4coC4a<o`000?mV
IVKo0000ogmoOol00002oiVIV@03o`000?nc/k?o000000Woc<c<00Oo0000ok>c/ol0003oVIVIo`00
0?moOgoo000000;oIVIV00?o0000oda<C?l000002?lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`00
0?moOgoo0000oiVIVOl00005ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03
ooooo`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;
ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0F
ok>c/`03o`000?nIVIWoVIVI00[oVIVI00?o0000ogmoOomoOgl01?moOgl00ol0003oIVIVofIVIP04
ofIVIP03o`000?m<C4coC4a<01?oC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`04o`000?nI
VIWoVIVIoiVIV@;o00001Onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c
00Co0000oiVIVOnIVIWo00000omoOgl01?l0003oIVIVofIVI_l00004oda<C003o`000?lc<c?o<c<c
00Go<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Go
0000ok>c/onc/k?o/k>co`000008olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl00ol0
003oIVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c00So0000oda<C?m<C4co0000ofIVI_l0
003oOgmoo`0000;oVIVI00?o0000ok>c/ol000002Oo<c<`00ol0003o/k>co`000002oiVIV@;o0000
0_mVIVH00ol0003oC4a<o`000009oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo
000000Kooooo0Ol00001ooooo`7ooooo000Tooooo`;o00001?ooool<ofIVIP;o00006?m<C4`00ol0
003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo0_l0000=oiVIV@03o`000?nc/k?o/k>c
01Ko/k>c00?o0000oiVIVOnIVIT02OnIVIT2o`0000KoOgmo00?o0000ofIVI_mVIVH01?mVIVH00ol0
003oC4a<oda<C00Coda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgooOgmoo`000003
oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`02
ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000?oC4a<
00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomo
Ogoo00000_nIVIT01?l0003o/k>cok>c/ol00008olc<c007o`000?nc/k?o/k>cok>c/ol0003oVIVI
o`000002ogmoO`03o`000?mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<02?l0003oC4a<
oda<C?l0003oIVIVo`000?moOgoo00000_nIVIT00ol0003o/k>co`000009olc<c007o`000?nc/k?o
0000oiVIVOl0003oOgmoo`000002ofIVIP03o`000?m<C4co000000So<c<c00[o0000oda<C?m<C4co
0000ofIVI_l0003oOgmoo`000?nIVIWo00001Oooool2o`0000;ooooo000Tooooo`03o`000?oooooo
oooo00?ooooo3?mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000
ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000
oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV00CoIVIV00?o0000
oda<C?m<C4`04om<C4`01Ol0003oIVIVofIVI_mVIVKo000000CoOgmo00Go0000oiVIVOnIVIWoVIVI
o`000006ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00onc/k<01?l0003oVIVI
oiVIVOl00003ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0
003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01?l0003o/k>cok>c
/ol00008olc<c007o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000002ogmoO`03o`000?mVIVKo0000
00?oC4a<00?o0000oc<c<olc<c<01_lc<c<02?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000
0_nIVIT00ol0003o/k>co`000009olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo
000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo
0000oiVIVOl00006ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`_o
IVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00Wo
Ogmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00[o
VIVI00?o0000ogmoOomoOgl01OmoOgl00ol0003oIVIVofIVIP04ofIVIP03o`000?m<C4coC4a<01?o
C4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000?oVIVI00?o0000ok>c
/onc/k<01?nc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00;o/k>c00Go0000oiVI
VOnIVIWoVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01_lc
<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01?l0003o
/k>cok>c/ol00009olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl00ol0003oIVIVo`00
0003oda<C003o`000?lc<c?o<c<c00Ko<c<c00So0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`00
00;oVIVI00?o0000ok>c/ol000002Oo<c<`00ol0003o/k>cok>c/`02o`000007ogmoOol0003oIVIV
ofIVI_l0003oC4a<o`000008oc<c<`0;o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVI
o`000?nc/k<01_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool:ofIV
IP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmo
O`;o00003OnIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00[oVIVI00?o0000ogmo
OomoOgl01OmoOgl00ol0003oIVIVofIVIP04ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000ofIV
I_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000CoVIVI00?o0000ok>c/onc/k<00onc/k<0
0ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Co0000oiVIVOnIVIWo00000omo
Ogl01?l0003oIVIVofIVI_l00004oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4co
C4a<o`000002ofIVIP03o`000?moOgoo000000;oVIVI00Go0000ok>c/onc/k?o/k>co`000009olc<
c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl00ol0003oIVIVo`000003oda<C003o`000?lc
<c?o<c<c00Ko<c<c00So0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000;oVIVI00?o0000ok>c
/ol000002Oo<c<`01ol0003o/k>co`000?nIVIWo0000ogmoOol000000_mVIVH00ol0003oC4a<o`00
0008oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00001Ooo
ool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool9ofIVIP03o`000?m<C4co
C4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWo
VIVI00coVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0:oiVIV@03o`000?moOgoo
Ogmo00KoOgmo00?o0000ofIVI_mVIVH01?mVIVH00ol0003oC4a<oda<C00Coda<C003o`000?mVIVKo
IVIV00;oIVIV00Go0000ogmoOomoOgooOgmoo`000004oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o
0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`04o`000?nIVIWoVIVIo`0000?oOgmo
00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;o
C4a<00Ko0000ofIVI_mVIVKo0000ogmoOol00002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002Oo<
c<`02?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo00000_mVIVH01Ol0003oC4a<oda<C?m<C4co
000000So<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0
003oc<c<olc<c007olc<c007o`000?nc/k?o0000oiVIVOl0003oOgmoo`000002ofIVIP03o`000?m<
C4co000000So<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol0
0005ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`SoIVIV00?o0000
oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000
oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000
ogmoOomoOgl01OmoOgl00ol0003oIVIVofIVIP04ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000
ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000CoVIVI00?o0000ok>c/onc/k<00onc
/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Co0000oiVIVOnIVIWo0000
0omoOgl01?l0003oIVIVofIVI_l00004oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<
C4coC4a<o`000002ofIVIP03o`000?moOgoo000000;oVIVI00Go0000ok>c/onc/k?o/k>co`000009
olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl00ol0003oIVIVo`000003oda<C003o`00
0?lc<c?o<c<c00Ko<c<c00So0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000;oVIVI00?o0000
ok>c/ol000002Oo<c<`01Ol0003o/k>co`000?nIVIWo000000;oOgmo00Go0000ofIVI_l0003oC4a<
o`000008oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o0000
1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool7ofIVIP03o`000?m<
C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nI
VIWoVIVI00_oVIVI0_l0000Hok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl01?mo
Ogl2o`0000KoIVIV00?o0000oda<C?m<C4`04om<C4`00ol0003oIVIVofIVIP02ofIVIP03o`000?mo
OgooOgmo00;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000005ok>c/`;o00001Oo<c<`00ol0003o/k>c
ok>c/`03ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01Ol0003oIVIVofIVI_mVIVKo0000
00CoC4a<00?o0000oc<c<olc<c<01Olc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000
ogmoOomoOgoo00000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Co0000ok>c/onc/k?o
00000_nIVIT01_l0003oOgmoogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01olc<c<0
2?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo00000_nIVIT00ol0003o/k>co`000009olc<c007
o`000?nc/k?o0000oiVIVOl0003oOgmoo`000002ofIVIP03o`000?m<C4co000000So<c<c00co0000
oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00006ooooo`7o00000Oooool1
ooooo`009?ooool00ol0003oooooooooo`03ooooo`KoIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0
003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0
003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl01OmoOgl00ol0
003oIVIVofIVIP05ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH00_mVIVH00ol0
003oOgmoogmoO`02ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001Onc/k<00ol0003oc<c<olc<c004
olc<c003o`000?nc/k?o/k>c00?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`05o`000?mV
IVKoIVIVofIVI_l000001?m<C4`00ol0003o<c<coc<c<`05oc<c<`05o`000?m<C4coC4a<oda<C?l0
00000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`0
1?l0003o/k>cok>c/ol00002oiVIV@06o`000?moOgooOgmoo`000?mVIVKo00000_m<C4`00ol0003o
<c<coc<c<`07oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVIV@03o`000?nc
/k?o000000Woc<c<00Oo0000ok>c/ol0003oVIVIo`000?moOgoo000000;oIVIV00?o0000oda<C?l0
00002?lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Ko
oooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo1OmVIVH00ol0003oC4a<
oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVI
oiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmo
ogmoO`05ogmoO`03o`000?mVIVKoIVIV00GoIVIV00?o0000oda<C?m<C4`04om<C4`00ol0003oIVIV
ofIVIP03ofIVIP05o`000?moOgooOgmoogmoOol000000onIVIT00ol0003o/k>cok>c/`03ok>c/`03
o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00onc/k<01?l0003oVIVIoiVIVOl00002ogmo
O`05o`000?mVIVKoIVIVofIVI_l000001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4co
C4a<00;oC4a<00Ko0000ofIVI_mVIVKo0000ogmoOol00002oiVIV@03o`000?nc/k?o/k>c00;o/k>c
00?o0000olc<c?o<c<`01Oo<c<`01ol0003o/k>cok>c/onc/k?o0000oiVIVOl000000_moOgl00ol0
003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00So0000oda<C?m<C4co0000ofIVI_l0
003oOgmoo`0000;oVIVI00?o0000ok>c/ol000002Oo<c<`00ol0003o/k>co`000002oiVIV@;o0000
0_mVIVH00ol0003oC4a<o`000009oc<c<`0<o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo
0000ok>c/ol0003oc<c<1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00ooo
ool4ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmo
O`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<2o`0000goVIVI00?o
0000ogmoOomoOgl01OmoOgl00ol0003oIVIVofIVIP05ofIVIP03o`000?m<C4coC4a<01?oC4a<0_l0
0004ofIVIP05o`000?moOgooOgmoogmoOol000001?nIVIT00ol0003o/k>cok>c/`03ok>c/`03o`00
0?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;o
Ogmo00Go0000ofIVI_mVIVKoIVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<
C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>c
o`000008olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003o
C4a<oda<C?l00009oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o
/k>c00?o0000olc<c?o<c<`01oo<c<`01ol0003o/k>co`000?nIVIWo0000ogmoOol000000_mVIVH0
0ol0003oC4a<o`000008oc<c<`0=o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`00
0?nc/k?o0000olc<c006ooooo`7o00000Oooool1ooooo`009?ooool2o`0000Cooooo0omVIVH00ol0
003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0
003oVIVIoiVIV@0:oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0
003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV00KoIVIV00?o0000oda<C?m<C4`04om<C4`00ol0
003oIVIVofIVIP03ofIVIP05o`000?moOgooOgmoogmoOol000001?nIVIT00ol0003o/k>cok>c/`03
ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00onc/k<01Ol0003oVIVIoiVIVOnI
VIWo000000;oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`06oc<c<`05o`00
0?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@05o`000?nc/k?o/k>c
ok>c/ol000002?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV00Co
0000oda<C?m<C4co00002Olc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0
0002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Oo0000ok>c/ol0003oVIVIo`000?moOgoo000000;o
IVIV00?o0000oda<C?l000002?lc<c<03Ol0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVI
VOl0003o/k>co`000?o<c<`01Oooool2o`0000;ooooo000Tooooo`03o`000?oooooooooo00?ooooo
0_mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl0
2?moOgl2o`0000coVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`00
0?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<C00Coda<C003o`00
0?mVIVKoIVIV00?oIVIV00Go0000ogmoOomoOgooOgmoo`000004oiVIV@03o`000?nc/k?o/k>c00?o
/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`05o`000?nIVIWoVIVIoiVI
VOl000000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<0
1Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01Ol0003o/k>c
ok>c/onc/k?o000000Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIV
IP04o`000?m<C4coC4a<o`0000Wo<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nI
VIWo00000_nc/k<00ol0003oc<c<olc<c007olc<c003o`000?nc/k?o/k>c00;o000000OoOgmoo`00
0?mVIVKoIVIVo`000?m<C4co000000So<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`00
0?nIVIWo0000ok>c/ol00002olc<c0Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooo
oooo00?ooooo00?oIVIVo`000?m<C4`05om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgoo
Ogmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`;o00003OnIVIT0
0ol0003oOgmoogmoO`06ogmoO`03o`000?mVIVKoIVIV00GoIVIV00?o0000oda<C?m<C4`05?m<C4`0
0ol0003oIVIVofIVIP02ofIVIP05o`000?moOgooOgmoogmoOol000001?nIVIT00ol0003o/k>cok>c
/`04ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00onc/k<01Ol0003oVIVIoiVI
VOnIVIWo000000?oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03
o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00003
ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`00
0002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Co0000oda<C?m<C4co00000_mVIVH01Ol0003o
Ogmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`2o`000006ok>c/ol0003oVIVI
o`000?moOgoo00000_mVIVH00ol0003oC4a<o`000008oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo
0000ogmoOol0003oVIVIo`000?nc/k?o00000_o<c<`6ooooo`7o00000Oooool1ooooo`009?ooool0
0ol0003oooooooooo`03ooooo`03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH0
0ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00[oVIVI00?o0000ok>c/onc/k<05_nc/k<0
0ol0003oVIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH01_mVIVH0
0ol0003oC4a<oda<C00Coda<C003o`000?mVIVKoIVIV00?oIVIV00Go0000ogmoOomoOgooOgmoo`00
0004oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c
/`03ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01?l0003oIVIVofIVI_l00004oda<C003
o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmo
O`03o`000?nIVIWo000000Co/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002
oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<01?l0003oC4a<oda<
C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c008
o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP03o`000?m<C4co000000So<c<c00co
0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00002olc<c0Kooooo0Ol0
0001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo6?m<C4`00ol0003oIVIVofIVIP0;
ofIVIP03o`000?moOgooOgmo00SoOgmo0_l0000<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000
oiVIVOnIVIT02onIVIT2o`0000SoOgmo00?o0000ofIVI_mVIVH01_mVIVH00ol0003oC4a<oda<C00C
oda<C003o`000?mVIVKoIVIV00?oIVIV00Go0000ogmoOomoOgooOgmoo`000004oiVIV@03o`000?nc
/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`04o`000?nI
VIWoVIVIo`0000?oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03
o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00003
ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT01_l0003oOgmoogmo
Ool0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIV
IP03o`000?moOgoo000000;oVIVI00?o0000ok>c/ol000002?o<c<`01_l0003o/k>cok>c/ol0003o
VIVIo`0000;oOgmo00Go0000ofIVI_l0003oC4a<o`000009oc<c<`03o`000?m<C4co000000;oIVIV
0_l000001OnIVIWo0000ok>c/onc/k?o000000;oc<c<1_ooool1o`00007ooooo0Oooool002Cooooo
00?o0000ooooooooool00ooooolGoda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl0
2?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT0
2onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00GoIVIV00?o0000oda<C?m<C4`0
5?m<C4`00ol0003oIVIVofIVIP02ofIVIP03o`000?moOgooOgmo00;oOgmo00Go0000oiVIVOnIVIWo
VIVIo`000007ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00onc/k<01Ol0003o
VIVIoiVIVOnIVIWo000000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000003oda<C003o`000?lc<c?o
<c<c00Ko<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nI
VIWoVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;o
VIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`04o`000?m<C4coC4a<
o`0000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00So
0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV00?o0000oda<C?l000002Olc<c<02ol0
003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o000000?oc<c<1_ooool1o`00007o
oooo0Oooool002Cooooo00?o0000ooooooooool00ooooolFoda<C003o`000?mVIVKoIVIV00_oIVIV
00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0:oiVIV@03o`000?nc/k?o/k>c01Ko/k>c
0_l0000=oiVIV@03o`000?moOgooOgmo00OoOgmo00?o0000ofIVI_mVIVH01_mVIVH00ol0003oC4a<
oda<C00Doda<C003o`000?mVIVKoIVIV00;oIVIV00?o0000ogmoOomoOgl00_moOgl01Ol0003oVIVI
oiVIVOnIVIWo000000Oo/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`03ok>c/`05
o`000?nIVIWoVIVIoiVIVOl000000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000?oC4a<00?o0000
oc<c<olc<c<01_lc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co
0000oiVIVOnIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol0
00000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Co0000oda<
C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<
c<`02?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo00000_mVIVH00ol0003oC4a<o`000009oc<c
<`0;o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol000000oo<c<`6ooooo`7o
00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03oooooaGoC4a<00?o0000ofIVI_mVIVH0
2omVIVH00ol0003oOgmoogmoO`08ogmoO`;o00003?nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`00
0?nIVIWoVIVI00_oVIVI0_l00009ogmoO`03o`000?mVIVKoIVIV00KoIVIV00?o0000oda<C?m<C4`0
5?m<C4`00ol0003oIVIVofIVIP02ofIVIP03o`000?moOgooOgmo00;oOgmo00Go0000oiVIVOnIVIWo
VIVIo`000007ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00onc/k<01Ol0003o
VIVIoiVIVOnIVIWo000000?oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06
oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVI
VOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@03
o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<01?l0003oC4a<oda<C?l00002
ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c003o`000?nc
/k?o000000;oVIVI0_l00002ofIVIP03o`000?m<C4co000000Wo<c<c00?o0000oda<C?m<C4`00_l0
00001?moOgoo0000oiVIVOnIVIT2o`0000Coc<c<1_ooool1o`00007ooooo0Oooool001Wooooo00Go
k^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo00?ooooo4om<C4`2o`0000goIVIV
00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c
00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00KoIVIV
00?o0000oda<C?m<C4`05?m<C4`00ol0003oIVIVofIVIP02ofIVIP;o00000omoOgl00ol0003oVIVI
oiVIV@02oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>c
ok>c/`03ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01?l0003oIVIVofIVI_l00004oda<
C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgoo
Ogmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c005o`000?nc/k?o/k>cok>c/ol0
00000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Co0000oda<
C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01oo<
c<`01ol0003o/k>co`000?nIVIWo0000ogmoOol000000_mVIVH00ol0003oC4a<o`000008oc<c<`0<
o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00001?o<c<`6ooooo`7o
00000Oooool1ooooo`006Oooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000oooooooo
ool00ooooolBoda<C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003o
VIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003o
OgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00KoIVIV00?o0000oda<C?m<C4`04om<C4`00ol0003o
IVIVofIVIP03ofIVIP03o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o
/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o0000ok>c/onc/k<01?nc/k<01Ol0003o
VIVIoiVIVOnIVIWo000000?oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`06
oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@05o`00
0?nc/k?o/k>cok>c/ol000002?o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmo
Ool000000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Go
0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Oo0000ok>c/ol0003o
VIVIo`000?moOgoo000000;oIVIV00?o0000oda<C?l000002?lc<c<03?l0003oC4a<oda<C?l0003o
IVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Coc<c<1_ooool1o`00007ooooo0Oooool001Wo
oooo00Go0000ooooooooooooooooo`000006ooooo`?o00000ooooolBoda<C003o`000?mVIVKoIVIV
00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c
01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV
00KoIVIV00?o0000oda<C?m<C4`05?m<C4`00ol0003oIVIVofIVIP03ofIVIP05o`000?moOgooOgmo
ogmoOol000001?nIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000
ok>c/onc/k<01?nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Go0000ofIVI_mVIVKoIVIV
o`000003oda<C003o`000?lc<c?o<c<c00Oo<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP06
o`000?moOgooOgmoo`000?nIVIWo00001?nc/k<00ol0003oc<c<olc<c006olc<c009o`000?nc/k?o
/k>cok>c/ol0003oVIVIo`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<01?l0
003oC4a<oda<C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<
c006olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000
oc<c<olc<c<01_lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>c
o`0000Coc<c<1?ooool3o`0000;ooooo000Iooooo`05o`000?nHV9SooooooiRHV?lQ8B401_ooool0
0ol0003oooooooooo`03oooooa7oC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`09
ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;
oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH01omVIVH00ol0003oC4a<oda<C00C
oda<C003o`000?mVIVKoIVIV00?oIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@02
oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`00_o<c<`00ol0003o/k>cok>c/`05
ok>c/`04o`000?nIVIWoVIVIo`0000?oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<c
oc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVI
V@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o
0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`0:o`000?m<C4coC4a<o`000?mV
IVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01oo<c<`00ol0003o/k>cok>c
/`02o`000007ogmoOol0003oIVIVofIVI_l0003oC4a<o`000008oc<c<`0<o`000?m<C4coC4a<o`00
0?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00001Oo<c<`6ooooo`7o00000Oooool1ooooo`00
6Oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000ooooooooool00oooool@oda<C003
o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl2o`0000goVIVI00?o0000ok>c/onc
/k<05_nc/k<00ol0003oVIVIoiVIV@0:oiVIV@;o00002_moOgl00ol0003oIVIVofIVIP06ofIVIP;o
00005_m<C4`00ol0003oIVIVofIVIP03ofIVIP05o`000?moOgooOgmoogmoOol000001?nIVIT00ol0
003o/k>cok>c/`05ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o0000ok>c/onc/k<01?nc/k<01Ol0
003oVIVIoiVIVOnIVIWo000000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc
<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`00
0?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01ol0003o/k>cok>c/onc/k?o0000
oiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co
0000oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<
c<`01_o<c<`02?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo00000_mVIVH00ol0003oC4a<o`00
0008oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00001Oo<
c<`6ooooo`7o00000Oooool1ooooo`006Oooool00omEEEGoQhN7ooooo`08ooooo`03o`000?oooooo
oooo00?ooooo3om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000
oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00[oVIVI00?o0000
ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP07ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000
ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000
ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c00Co/k>c00Go0000
oiVIVOnIVIWoVIVIo`000002ogmoO`05o`000?mVIVKoIVIVofIVI_l000001?m<C4`00ol0003o<c<c
oc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003o
VIVIoiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Oo0000ok>c/onc/k?o/k>co`000?nI
VIWo000000;oOgmo00Co0000ofIVI_mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`04o`00
0?m<C4coC4a<o`0000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<
00Koc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV00?o0000oda<C?l00000
2?lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Goc<c<
1_ooool1o`00007ooooo0Oooool001Wooooo00?ogMgMoa0@4?nHV9P02?ooool00ol0003ooooooooo
o`03ooooo`koC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nI
VIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?mo
OgooOgmo00SoOgmo00?o0000ofIVI_mVIVH01omVIVH00ol0003oC4a<oda<C00Doda<C003o`000?mV
IVKoIVIV00?oIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@02oiVIV@03o`000?nc
/k?o/k>c00Go/k>c00?o0000olc<c?o<c<`00_o<c<`00ol0003o/k>cok>c/`04ok>c/`05o`000?nI
VIWoVIVIoiVIVOl000000omoOgl01?l0003oIVIVofIVI_l00004oda<C003o`000?lc<c?o<c<c00Go
<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVI
o`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o
0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`04o`000?m<C4coC4a<o`0000;o
IVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Ko0000ok>c
/onc/k?o0000oiVIVOl00002ogmoO`05o`000?mVIVKo0000oda<C?l000002Olc<c<00ol0003oC4a<
o`000002ofIVIP;o000000GoVIVIo`000?nc/k?o/k>co`000005olc<c0Kooooo0Ol00001ooooo`7o
oooo000Jooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool00oooool=oda<C003
o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl2o`0000goVIVI00?o0000ok>c/onc
/k<05_nc/k<00ol0003oVIVIoiVIV@0:oiVIV@;o00002_moOgl00ol0003oIVIVofIVIP08ofIVIP03
o`000?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`02ogmoO`03
o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c002olc<c003
o`000?nc/k?o/k>c00Co/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`05o`000?mVIVKoIVIV
ofIVI_l000001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000
ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<
00Co0000ok>c/onc/k?o00000_nIVIT01_l0003oOgmoogmoOol0003oIVIVo`0000;oC4a<00?o0000
oc<c<olc<c<01olc<c<01?l0003oC4a<oda<C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl00000
0_nc/k<00ol0003oc<c<olc<c006olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002
ofIVIP03o`000?m<C4co000000Wo<c<c00_o0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0
003o/k>co`000006olc<c0Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?o
oooo3?m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnI
VIT03?nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00[oVIVI00?o0000ogmoOomo
Ogl02OmoOgl00ol0003oIVIVofIVIP08ofIVIP03o`000?m<C4coC4a<01GoC4a<00?o0000ofIVI_mV
IVH00omVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc
/k<01?nc/k<00ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c00Co/k>c00Go0000oiVIVOnI
VIWoVIVIo`000003ogmoO`05o`000?mVIVKoIVIVofIVI_l000001?m<C4`00ol0003o<c<coc<c<`05
oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVI
VOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT01_l0003o
OgmoogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01olc<c<01?l0003oC4a<oda<C?l0
0002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c008o`00
0?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP03o`000?m<C4co000000Wo<c<c0_l00002
ofIVIP07o`000?moOgoo0000oiVIVOl0003o/k>co`000006olc<c0Kooooo0Ol00001ooooo`7ooooo
000Tooooo`03o`000?oooooooooo00?ooooo2om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?mo
OgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nI
VIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP08ofIVIP03o`000?m<
C4coC4a<01GoC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nI
VIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c002olc<c003o`000?nc
/k?o/k>c00Go/k>c00Co0000oiVIVOnIVIWo00000omoOgl01Ol0003oIVIVofIVI_mVIVKo000000Co
C4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmo
OomoOgoo00000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Co0000ok>c/onc/k?o0000
0_nIVIT01_l0003oOgmoogmoOol0003oIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0
003oC4a<oda<C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<
c007olc<c003o`000?nc/k?o000000;oVIVI0_l00002ofIVIP03o`000?m<C4co000000Wo<c<c00Oo
0000oda<C?l0003oIVIVo`000?moOgoo000000;oVIVI0_l00007olc<c0Kooooo0Ol00001ooooo`7o
oooo000Tooooo`03o`000?oooooooooo00?ooooo2_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`00
0?moOgooOgmo00SoOgmo0_l0000=oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT0
2onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00SoIVIV00?o0000oda<C?m<C4`0
5Om<C4`00ol0003oIVIVofIVIP03ofIVIP03o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT0
0_nIVIT00ol0003o/k>cok>c/`05ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o0000ok>c/onc/k<0
1?nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0
003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000omVIVH01?l0003oOgmoogmoOol0
0002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@06
o`000?moOgooOgmoo`000?mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`06o`000?m<C4co
C4a<o`000?mVIVKo00000_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<
00Oo0000ok>c/ol0003oVIVIo`000?moOgoo000000;oIVIV00?o0000oda<C?l000002?lc<c<03?l0
003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Ooc<c<1_ooool1o`00
007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool9oda<C003o`000?mVIVKoIVIV00_o
IVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Ko
/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00Wo
IVIV00?o0000oda<C?m<C4`05?m<C4`00ol0003oIVIVofIVIP03ofIVIP03o`000?moOgooOgmo00?o
Ogmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`05ok>c/`05o`000?o<c<coc<c<olc<
c?l000001onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Co0000ofIVI_mVIVKo00001?m<
C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000omVIVH00ol0003oOgmo
o`000002oiVIV@03o`000?nc/k?o/k>c00;o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>c
ok>c/ol00002oiVIV@06o`000?moOgooOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`07
oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl00ol0003oVIVIo`000002ok>c/`03o`00
0?o<c<coc<c<00Koc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV00?o0000
oda<C?l000002?lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>c
o`0000Ooc<c<1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool8oda<
C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0<oiVI
V@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmo
O`03o`000?mVIVKoIVIV00WoIVIV00?o0000oda<C?m<C4`05Om<C4`00ol0003oIVIVofIVIP03ofIV
IP03o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`05ok>c
/`05o`000?o<c<coc<c<olc<c?l000001onc/k<00ol0003oVIVIoiVIV@02oiVIV@04o`000?moOgoo
Ogmoo`0000;oIVIV00?o0000oda<C?m<C4`00_m<C4`00ol0003o<c<coc<c<`06oc<c<`03o`000?m<
C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03
o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT01?l0003oOgmoogmoOol00002
ofIVIP04o`000?m<C4coC4a<o`0000Wo<c<c00?o0000oda<C?m<C4`00_l00002ogmoO`03o`000?nI
VIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/onc/k<2o`000005ogmo
Ool0003oIVIVofIVI_l000000_m<C4`00ol0003o<c<coc<c<`05oc<c<`06o`000?m<C4coC4a<o`00
0?mVIVKo00000_moOgl2o`0000;o/k>c00?o0000olc<c?o<c<`01Oo<c<`6ooooo`7o00000Oooool1
ooooo`009?ooool2o`0000Cooooo1om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo
00SoOgmo00?o0000oiVIVOnIVIT02onIVIT2o`0001So/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0
003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00WoIVIV00?o0000oda<C?m<C4`05Om<C4`00ol0
003oIVIVofIVIP03ofIVIP03o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0
003o/k>cok>c/`06ok>c/`05o`000?o<c<coc<c<olc<c?l000001_nc/k<00ol0003oVIVIoiVIV@02
oiVIV@04o`000?moOgooOgmoo`0000?oIVIV00?o0000oda<C?m<C4`00_m<C4`00ol0003o<c<coc<c
<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@05
o`000?nc/k?o/k>cok>c/ol000002?o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000
ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo
00000_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00So0000ok>c/onc
/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV00?o0000oda<C?l000002?lc<c<02_l0003oC4a<oda<
C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Goc<c<1Oooool2
o`0000;ooooo000Tooooo`03o`000?oooooooooo00?ooooo1_m<C4`00ol0003oIVIVofIVIP0;ofIV
IP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Gok>c
/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl2o`0000_oIVIV00?o0000oda<
C?m<C4`05?m<C4`00ol0003oIVIVofIVIP04ofIVIP05o`000?moOgooOgmoogmoOol000001OnIVIT0
0ol0003o/k>cok>c/`06ok>c/`05o`000?o<c<coc<c<olc<c?l000001_nc/k<00ol0003oVIVIoiVI
V@02oiVIV@04o`000?moOgooOgmoo`0000?oIVIV00?o0000oda<C?m<C4`00_m<C4`00ol0003o<c<c
oc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003o
VIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002
oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<01_l0003oC4a<oda<
C?l0003oIVIVo`0000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c008
o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP03o`000?m<C4co000000So<c<c00[o
0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c005
olc<c0Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo1Om<C4`00ol0
003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0
003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0
003oIVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH01?mVIVH00ol0
003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01_nc/k<01Ol0
003oc<c<olc<c?o<c<co000000Ko/k>c00?o0000oiVIVOnIVIT00_nIVIT01?l0003oOgmoogmoOol0
0003ofIVIP03o`000?m<C4coC4a<00;oC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<
C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003o
c<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Go0000oiVIVOl0003oOgmoo`000002ofIV
IP04o`000?m<C4coC4a<o`0000Wo<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`06o`00
0?nIVIWoVIVIo`000?nc/k?o00002?o<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00Go
0000ofIVI_l0003oC4a<o`000009oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo
000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003oooooooooo`03ooooo`7o00000Oooool1
ooooo`009?ooool00ol0003oooooooooo`03ooooo`CoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0
003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<2o`00
00goVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<
01CoC4a<00?o0000ofIVI_mVIVH01?mVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI
00?oVIVI00?o0000ok>c/onc/k<01Onc/k<2o`0000;oc<c<00?o0000ok>c/onc/k<01Onc/k<01Ol0
003oVIVIoiVIVOnIVIWo000000?oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc
<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`00
0?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o0000
00;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`06o`000?m<C4co
C4a<o`000?mVIVKo00000_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<
00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV00?o0000oda<C?l000002Olc<c<0
2Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ko
c<c<00?o0000ooooooooool00oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool0
0oooool3oda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVI
oiVIV@0:oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmo
ogmoO`08ogmoO`03o`000?mVIVKoIVIV00[oIVIV00?o0000oda<C?m<C4`05Om<C4`00ol0003oIVIV
ofIVIP04ofIVIP03o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>c
ok>c/`05ok>c/`05o`000?nc/k?o0000olc<c?l000001onc/k<01Ol0003oVIVIoiVIVOnIVIWo0000
00?oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000
oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c
00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmoOol0
00000_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_mo
Ogl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00So0000ok>c/onc/k?o0000
oiVIVOl0003oOgmoo`0000;oIVIV00?o0000oda<C?l000002Olc<c<02Ol0003oC4a<o`000?mVIVKo
0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o0000ooooooooool0
0oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool2oda<C003o`000?mV
IVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl2o`0000coVIVI00?o0000ok>c/onc/k<05onc
/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omV
IVH00ol0003oC4a<oda<C00Doda<C003o`000?mVIVKoIVIV00CoIVIV00?o0000ogmoOomoOgl00_mo
Ogl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c00Ko/k>c0_l000000onc/k?o0000ok>c
/`06ok>c/`03o`000?nIVIWoVIVI00;oVIVI00Co0000ogmoOomoOgoo00000omVIVH00ol0003oC4a<
oda<C002oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIV
ofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0
003o/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l0
0009oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03
o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT2o`0000;oIVIV00?o0000oda<
C?l000002Olc<c<01ol0003oC4a<o`000?mVIVKo0000ogmoOol000000_nIVIT00ol0003o/k>co`00
0008olc<c003o`000?oooooooooo00Cooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooo
oooo00?ooooo00?oC4a<o`000?mVIVH03?mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWo
VIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<2o`0000goVIVI00?o0000ogmoOomoOgl02?moOgl0
0ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH01?mVIVH0
0ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01_nc/k<0
1?l0003oc<c<olc<c?l00007ok>c/`03o`000?nIVIWoVIVI00;oVIVI00Co0000ogmoOomoOgoo0000
0omVIVH00ol0003oC4a<oda<C002oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`0
0_m<C4`2o`0000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01Ol0003o/k>cok>c/onc/k?o0000
00Soc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000
oda<C?m<C4co00002?lc<c<2o`0000;oC4a<00Go0000ofIVI_l0003oOgmoo`000002oiVIV@04o`00
0?nc/k?o/k>co`0000Soc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV00?o
0000oda<C?l000002?lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o
/k>co`0000Woc<c<00?o0000ooooooooool01?ooool1o`00007ooooo0Oooool002Cooooo00?o0000
ooooooooool00oooool00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000
oiVIVOnIVIT02_nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000
ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01GoC4a<00?o0000
ofIVI_mVIVH01?mVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000
ok>c/onc/k<01_nc/k<01?l0003oc<c<olc<c?l00007ok>c/`03o`000?nIVIWoVIVI00;oVIVI00Co
0000ogmoOomoOgoo00000omVIVH00ol0003oC4a<oda<C002oda<C003o`000?lc<c?o<c<c00Go<c<c
00?o0000oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Co0000oiVIVOnI
VIWo00000onc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Ko0000oiVI
VOnIVIWo0000ogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Wo0000oda<C?m<C4co
C4a<o`000?mVIVKo0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00008olc<c008o`000?nc
/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP03o`000?m<C4co000000So<c<c00co0000oda<
C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00009olc<c003o`000?oooooooooo
00Cooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo3OmVIVH00ol0003o
OgmoogmoO`08ogmoO`;o00003?nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_o
VIVI0_l0000:ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05Om<C4`00ol0003o
IVIVofIVIP04ofIVIP03o`000?moOgooOgmo00?oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o
/k>cok>c/`08ok>c/`;o00001onc/k<00ol0003oVIVIoiVIV@02oiVIV@04o`000?moOgooOgmoo`00
00CoIVIV00Go0000oda<C?m<C4coC4a<o`000007oc<c<`03o`000?m<C4coC4a<00;oC4a<00Go0000
ofIVI_mVIVKoIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`0
1_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Ko0000ogmoOomoOgoo0000ofIVI_l00003
oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`2o`000005ogmoOol0003o
VIVIoiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c008o`000?nc/k?o/k>co`000?nIVIWo
0000ogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Wo0000oda<C?l0003oIVIVo`00
0?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c003o`000?nc/k?ooooo00Go
oooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo3?mVIVH00ol0003oOgmo
ogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVI
oiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<
oda<C00Eoda<C003o`000?mVIVKoIVIV00CoIVIV00?o0000ogmoOomoOgl00omoOgl00ol0003oVIVI
oiVIV@02oiVIV@03o`000?nc/k?o/k>c00Wo/k>c00?o0000ok>c/onc/k<01_nc/k<01Ol0003oVIVI
oiVIVOnIVIWo000000?oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c
00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`05o`000?nIVIWo
VIVIoiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c003o`000?nc/k?o/k>c00;o000000Go
VIVIo`000?moOgooOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Wo0000oda<C?m<
C4coC4a<o`000?mVIVKo0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00008olc<c008o`00
0?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP03o`000?m<C4co000000So<c<c00[o0000
oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<
c003o`000?nc/k?ooooo00Gooooo0Ol00001ooooo`7ooooo000Tooooo`;o00001?ooool;ofIVIP03
o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02_nIVIT00ol0003o/k>cok>c/`0Fok>c/`;o
00003OnIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00coIVIV00?o0000oda<C?m<
C4`05Om<C4`00ol0003oIVIVofIVIP04ofIVIP03o`000?moOgooOgmo00?oOgmo00?o0000oiVIVOnI
VIT00_nIVIT00ol0003o/k>cok>c/`0Bok>c/`04o`000?nIVIWoVIVIo`0000CoOgmo00Go0000ofIV
I_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`0
1?l0003oIVIVofIVI_l00002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000onc/k<00ol0003oc<c<
olc<c006olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01?l0
003oC4a<oda<C?l00008oc<c<`09o`000?m<C4coC4a<oda<C?l0003oIVIVo`000?moOgoo000000;o
VIVI00Co0000ok>c/onc/k?o00002?o<c<`02?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000
0_mVIVH00ol0003oC4a<o`000008oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003o
VIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003o/k>co`000004ooooo`;o00000_oo
ool002Cooooo00?o0000ooooooooool00oooool:ofIVIP03o`000?moOgooOgmo00SoOgmo0_l0000<
oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT2o`0000[oOgmo00?o0000
ofIVI_mVIVH03?mVIVH00ol0003oC4a<oda<C00Eoda<C003o`000?mVIVKoIVIV00CoIVIV00?o0000
ogmoOomoOgl00omoOgl00ol0003oVIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c01;o/k>c00Go0000
oiVIVOnIVIWoVIVIo`000003ogmoO`05o`000?mVIVKoIVIVofIVI_l000001?m<C4`00ol0003o<c<c
oc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01Ol0003o
VIVIoiVIVOnIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002
oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<01ol0003oC4a<
oda<C?m<C4co0000ofIVI_l000000_moOgl01_l0003oVIVIoiVIVOl0003o/k>co`0000Soc<c<00Ko
0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`05o`000?mVIVKo0000oda<C?l000002Olc<c<02Ol0
003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<
00Co0000ok>c/onc/k?o00001Oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool0
0oooool9ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>c
ok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIV
ofIVIP0;ofIVIP;o00005om<C4`00ol0003oIVIVofIVIP04ofIVIP03o`000?moOgooOgmo00?oOgmo
00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`0Bok>c/`05o`000?nIVIWoVIVIoiVIVOl0
00000omoOgl2o`0000;oIVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`05oc<c<`03
o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00003
ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Co0000ok>c/onc/k?o00000_nIVIT01_l0003oOgmoogmo
Ool0003oIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIV
IP06o`000?moOgoo0000o`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c007o`000?nc
/k?o/k>co`000?nIVIWo0000ogmoO`02o`000004ofIVI_l0003oC4a<o`0000Wo<c<c00Wo0000oda<
C?l0003oIVIVo`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c003o`00
0?nc/k?o000000Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo2?mV
IVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05onc
/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH03?mV
IVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00CoIVIV00?o0000ogmoOomoOgl00omo
Ogl00ol0003oVIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c01;o/k>c00Go0000oiVIVOnIVIWoVIVI
o`000003ogmoO`05o`000?mVIVKoIVIVofIVI_l000001Om<C4`00ol0003o<c<coc<c<`05oc<c<`05
o`000?m<C4coC4a<oda<C?l000000omVIVH01?l0003oOgmoogmoOol00002oiVIV@05o`000?nc/k?o
/k>cok>c/ol000002Oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@06o`000?moOgooOgmoo`000?mV
IVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000
ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00008olc<c008o`000?nc/k?o/k>co`000?nIVIWo
0000ogmoOol00002ofIVIP03o`000?m<C4co000000Wo<c<c00Wo0000oda<C?l0003oIVIVo`000?mo
Ogoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c003o`000?nc/k?o000000Kooooo
0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo1omVIVH00ol0003oOgmoogmo
O`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVI
V@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<
C00Foda<C003o`000?mVIVKoIVIV00GoIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVI
V@03oiVIV@03o`000?nc/k?o/k>c017o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmo
OomoOgoo000000?oIVIV00?o0000oda<C?m<C4`00_m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`00
0?m<C4coC4a<00;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`00
00?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000
ogmoOol000000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000Oo<c<c00Co0000oda<C?m<C4co0000
0omVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00?o0000ok>c/onc
/k<00_l00002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<00ol0003o
C4a<o`000002ofIVIP04o`000?moOgoo0000o`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0
003o/k>co`000006ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`Ko
IVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0:oiVIV@03o`000?nc/k?o/k>c01Oo
/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00_o
IVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP05ofIVIP03o`000?moOgooOgmo00?o
Ogmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`0Bok>c/`05o`000?nIVIWoVIVIoiVI
VOl000000omoOgl00ol0003oIVIVofIVIP02ofIVIP03o`000?m<C4coC4a<00;oC4a<00?o0000oc<c
<olc<c<01?lc<c<00ol0003oC4a<oda<C002oda<C003o`000?mVIVKoIVIV00;oIVIV00?o0000ogmo
Ool000000onIVIT01?l0003o/k>cok>c/ol00008olc<c005o`000?nc/k?o/k>cok>c/ol000000_nI
VIT01?l0003oOgmoogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Co0000oda<C?m<
C4co00000omVIVH2o`0000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`02?l0003o/k>cok>c/ol0
003oVIVIo`000?moOgoo00000_mVIVH00ol0003oC4a<o`000009oc<c<`09o`000?m<C4co0000ofIV
I_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>co`00
0?nIVIT6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`GoIVIV00?o
0000ogmoOomoOgl02?moOgl2o`0000goVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVI
V@0:oiVIV@;o00002_moOgl2o`0000coIVIV0_l0000Hoda<C003o`000?mVIVKoIVIV00GoIVIV00?o
0000ogmoOomoOgl00omoOgl00ol0003oVIVIoiVIV@02oiVIV@;o00004onc/k<00ol0003oVIVIoiVI
V@02oiVIV@05o`000?moOgooOgmoogmoOol000000omVIVH00ol0003oC4a<oda<C002oda<C003o`00
0?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;o
Ogmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>c
ok>c/ol000000_nIVIT01_l0003oOgmoogmoOol0003oIVIVo`0000?oC4a<00?o0000oc<c<olc<c<0
1_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc
/k?o00002?o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003
o`000?lc<c?o<c<c00Ko<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000
0_nc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o0000oiVIVOl000001Oooool1o`00007o
oooo0Oooool002Cooooo00?o0000ooooooooool00oooool4ofIVIP03o`000?moOgooOgmo00SoOgmo
00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00[oVIVI
00?o0000ogmoOomoOgl02_moOgl00ol0003oIVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<01SoC4a<
00?o0000ofIVI_mVIVH01?mVIVH00ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00?oVIVI
00?o0000ok>c/onc/k<04_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00?o0000ofIVI_mV
IVH00_mVIVH00ol0003oC4a<oda<C002oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<
C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<0
0ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`0000?oVIVI00Ko0000ogmoOomoOgoo0000
ofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0
003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00?o0000ok>c/ol000000_nIVIT0
1Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02_l0003oC4a<oda<
C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000
ok>c/ol0003oVIVIo`000005ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03
ooooo`?oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o
/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKo
IVIV00[oIVIV00?o0000oda<C?m<C4`06?m<C4`00ol0003oIVIVofIVIP05ofIVIP03o`000?moOgoo
Ogmo00?oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`0Bok>c/`03o`000?nIVIWo
VIVI00;oVIVI00Co0000ogmoOomoOgoo00001?mVIVH00ol0003oC4a<oda<C002oda<C003o`000?lc
<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo
00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c
/ol000000onIVIT01Ol0003oOgmoo`000?mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<0
1?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o0000
2?o<c<`02?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo00000_mVIVH01?l0003oC4a<oda<C?l0
0008oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<
c?o<c<`01_o<c<`01Ol0003o/k>co`000?nIVIWo000000Kooooo0Ol00001ooooo`7ooooo000Toooo
o`03o`000?oooooooooo00?ooooo0_mVIVH00ol0003oOgmoogmoO`08ogmoO`;o00003OnIVIT00ol0
003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00[oVIVI0_l0000:ogmoO`;o00003?mVIVH2o`00
01SoC4a<0_l00007ofIVIP03o`000?moOgooOgmo00?oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0
003o/k>cok>c/`0Bok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01Ol0003oIVIVofIVI_mV
IVKo000000GoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mV
IVKoIVIVo`0000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Ko
c<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<
C?m<C4co00002Olc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00Co
0000ok>c/onc/k?o00002?o<c<`02?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo00000_mVIVH0
0ol0003oC4a<o`000008oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`00
00;o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>co`000?nIVIWo000000Kooooo0Ol00001
ooooo`7ooooo000Tooooo`;o00001?ooool00omVIVKo0000ogmoO`09ogmoO`03o`000?nIVIWoVIVI
00coVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0:oiVIV@03o`000?moOgooOgmo
00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Hoda<C003o`000?mVIVKoIVIV
00KoIVIV00?o0000ogmoOomoOgl00omoOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c
017o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000?oIVIV00?o0000
oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`05oc<c<`05o`000?m<C4coC4a<oda<C?l000000omV
IVH01?l0003oOgmoogmoOol00003oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01Ol0003o
/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00009
oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c
/ol00008olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP03o`000?m<C4co
000000So<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0
003oc<c<olc<c006olc<c005o`000?nc/k?o0000oiVIVOl000001Oooool2o`0000;ooooo000Toooo
o`03o`000?oooooooooo00?ooooo00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0;oiVI
V@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmo
O`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`06?m<C4`00ol0003oIVIVofIVIP06ofIV
IP03o`000?moOgooOgmo00?oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0Bok>c
/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl00ol0003oIVIVofIVIP02ofIVIP03o`000?m<C4co
C4a<00;oC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKo
IVIVo`0000?oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c005o`00
0?nc/k?o/k>cok>c/ol000000_nIVIT00ol0003oOgmoo`000002ofIVIP05o`000?m<C4coC4a<oda<
C?l000002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP06o`000?moOgooOgmoo`000?nIVIWo0000
0_nc/k<00ol0003oc<c<olc<c006olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002
ofIVIP03o`000?m<C4co000000Wo<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0
00000_nc/k<00ol0003oc<c<olc<c006olc<c003o`000?nc/k?o/k>c00;o000000?oOgmooooooooo
ool01?ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool:ogmoO`;o0000
3OnIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl0
2?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<0_l00008ofIVIP03o`00
0?moOgooOgmo00?oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0Bok>c/`03o`00
0?nIVIWoVIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`000003ofIVIP03o`000?m<C4coC4a<00?o
C4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C003oda<C004o`000?mVIVKoIVIVo`00
00;oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o
/k>cok>c/ol000000_nIVIT00ol0003oOgmoo`000002ofIVIP05o`000?m<C4coC4a<oda<C?l00000
2?lc<c<01Ol0003oC4a<oda<C?l0003oIVIV00;o000000CoOgmoo`000?nIVIWo00000_nc/k<00ol0
003oc<c<olc<c007olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;o
C4a<00?o0000oc<c<olc<c<01olc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`00
0002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Oo0000ok>c/ol0003oVIVIo`000?moOgoo000000Go
oooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo2OmoOgl00ol0003oVIVI
oiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmo
ogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`06?m<C4`00ol0003oIVIV
ofIVIP06ofIVIP03o`000?moOgooOgmo00CoOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>c
ok>c/`0Bok>c/`05o`000?nIVIWoVIVIoiVIVOl000001?moOgl01Ol0003oIVIVofIVI_mVIVKo0000
00GoC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C003oda<C004o`000?mVIVKoIVIV
o`0000;oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc
/k?o/k>c00;o/k>c00Ko0000oiVIVOnIVIWo0000ogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<
C?l000001olc<c<01ol0003oC4a<oda<C?m<C4co0000ofIVI_l000000_moOgl00ol0003oVIVIo`00
0002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`00
0?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`07oc<c<`0;o`000?m<C4co0000ofIVI_l0003oOgmo
o`000?nIVIWo0000ok>c/ol000002Oo<c<`01ol0003o/k>co`000?nIVIWo0000ogmoOol000001Ooo
ool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool8ogmoO`03o`000?nIVIWo
VIVI00coVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgoo
Ogmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Hoda<C003o`000?mVIVKo
IVIV00KoIVIV00?o0000ogmoOomoOgl01?moOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o
/k>c01;o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000?oIVIV00?o
0000oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Co
0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Ko
c<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Co0000
oda<C?m<C4co00002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl0
00000onc/k<00ol0003oc<c<olc<c006olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0
003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01olc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmo
Ool0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Oo0000ok>c/ol0003oVIVIo`00
0?moOgoo000000Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo1omo
Ogl00ol0003oVIVIoiVIV@0;oiVIV@;o00006?nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?mo
OgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Hoda<C003o`000?mV
IVKoIVIV00KoIVIV00?o0000ogmoOomoOgl01?moOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc
/k?o/k>c01;o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000?oIVIV
00?o0000oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<
00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<
c?o<c<`01Oo<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mV
IVH01?l0003oC4a<oda<C?l00008oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01Ol0003o
Ogmoo`000?nIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`02_l0003o/k>cok>c/ol0003o
VIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00[o0000oda<C?m<
C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c007o`00
0?nc/k?o0000oiVIVOl0003oOgmoo`000006ooooo`7o00000Oooool1ooooo`009?ooool00ol0003o
ooooooooo`03ooooo`KoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Gok>c/`03
o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl2o`0000coIVIV00?o0000oda<C?m<
C4`06?m<C4`00ol0003oIVIVofIVIP07ofIVIP03o`000?moOgooOgmo00CoOgmo00?o0000oiVIVOnI
VIT00onIVIT00ol0003o/k>cok>c/`0Bok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomo
OgooOgmoo`000003ofIVIP03o`000?m<C4coC4a<00?oC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0
003oC4a<oda<C002oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl0
0004ok>c/`03o`000?o<c<coc<c<00Goc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`00
0?moOgooOgmoo`0000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<01Ol0003oC4a<oda<C?m<C4co
000000;oIVIV00Go0000ogmoOol0003oVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o
0000ok>c/ol000000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<0
1_lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<
c<coc<c<00Koc<c<00Oo0000ok>c/ol0003oVIVIo`000?moOgoo000000Kooooo0Ol00001ooooo`7o
oooo000Tooooo`03o`000?oooooooooo00?ooooo1OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`00
0?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`00
0?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`06?m<C4`00ol0003oIVIVofIVIP07ofIVIP03o`00
0?moOgooOgmo00CoOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0Cok>c/`05o`00
0?nIVIWoVIVIoiVIVOl000000omoOgl01Ol0003oIVIVofIVI_mVIVKo000000KoC4a<00?o0000oc<c
<olc<c<01?lc<c<00ol0003oC4a<oda<C002oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl0
1?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Goc<c<00Go0000ok>c/onc/k?o/k>c
o`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<01?l0
003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<
c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00003oda<C003o`000?lc<c?o
<c<c00Ko<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003o
c<c<olc<c006olc<c003o`000?nc/k?o000000;oVIVI0_l000000omVIVKoooooooooo`04ooooo`7o
00000Oooool1ooooo`006Oooool01Oo<c<co8B4Qo`000?lQ8B7oc<c<00Kooooo00?o0000oooooooo
ool00oooool4ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<2o`0000go
VIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01So
C4a<00?o0000ofIVI_mVIVH01omVIVH00ol0003oOgmoogmoO`04ogmoO`03o`000?nIVIWoVIVI00?o
VIVI00?o0000ok>c/onc/k<04onc/k<00ol0003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmo
Ool000000omVIVH00ol0003oC4a<oda<C003oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<
C?m<C4`00om<C4`01?l0003oIVIVofIVI_l00002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000onc
/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmo
ogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000Wo<c<c00Ko0000oda<C?m<C4co0000ofIVI_l0
0002ogmoO`05o`000?nIVIWo0000o`000?nc/k<00_l00008olc<c00:o`000?nc/k?o/k>co`000?nI
VIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<03?l0003oC4a<oda<
C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Woc<c<00So0000ok>c/ol0003oVIVI
o`000?moOgoo0000ofIVIPKooooo0Ol00001ooooo`7ooooo000Iooooo`05ob4Q8OnHV9SooooooiRH
V?lQ8B401_ooool00ol0003oooooooooo`03ooooo`CoOgmo00?o0000oiVIVOnIVIT02_nIVIT00ol0
003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0
003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<0_l00009ofIVIP03o`000?moOgooOgmo
00GoOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0Cok>c/`05o`000?nIVIWoVIVI
oiVIVOl000001?moOgl01Ol0003oIVIVofIVI_mVIVKo000000GoC4a<00?o0000oc<c<olc<c<01?lc
<c<00ol0003oC4a<oda<C003oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Go0000oiVIVOnIVIWo
VIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVI
V@04o`000?moOgooOgmoo`0000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<02?l0003oC4a<oda<
C?l0003oIVIVo`000?moOgoo00000_nIVIT01?l0003o/k>cok>c/ol00009olc<c00:o`000?nc/k?o
/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<03?l0
003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Woc<c<00Wo0000ok>c
/ol0003oVIVIo`000?moOgoo0000ofIVI_l000001Oooool1o`00007ooooo0Oooool001Wooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00?ooooo0_moOgl2o`0000coVIVI
00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo
00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00SoIVIV
00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c01?o/k>c
00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000?oIVIV00?o0000oda<C?m<
C4`00om<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mV
IVKo00000_moOgl00ol0003oVIVIoiVIV@02oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Go0000
ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Co0000oda<C?m<C4co
00002Olc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00?o0000oiVIVOl000000_nc/k<0
0ol0003oc<c<olc<c007olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`00
00;oC4a<00?o0000oc<c<olc<c<01olc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVI
o`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o0000ok>c/onc/k<00_l000001OmoOgoo0000
ofIVI_mVIVKo000000Gooooo0Ol00001ooooo`7ooooo000Iooooo`05oc8b<_nHV9SooooooiRHV?lb
<S801_ooool3o`0000?ooooo00?oOgmoo`000?nIVIT03?nIVIT00ol0003o/k>cok>c/`0Fok>c/`;o
00003OnIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<
C4`05om<C4`00ol0003oIVIVofIVIP09ofIVIP03o`000?moOgooOgmo00CoOgmo00?o0000oiVIVOnI
VIT00onIVIT00ol0003o/k>cok>c/`0Cok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomo
OgooOgmoo`000003ofIVIP03o`000?m<C4coC4a<00CoC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0
003oC4a<oda<C002oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01Ol0003oVIVIoiVIVOnI
VIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI
00Go0000ogmoOomoOgoo0000ofIVIP02o`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01ol0003o
C4a<oda<C?m<C4co0000ofIVI_l000000_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<co
c<c<00Ooc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0
003o<c<coc<c<`07oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c
00?o0000olc<c?o<c<`01_o<c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000004
ooooo`?o00000_ooool001Wooooo00Goc<c<o`000?l0003o0000olc<c006ooooo`03o`000?oooooo
oooo00?ooooo00?oOgmoo`000?nIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWo
VIVI00coVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4co
C4a<01OoC4a<00?o0000ofIVI_mVIVH02OmVIVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWo
VIVI00?oVIVI00?o0000ok>c/onc/k<04onc/k<00ol0003oVIVIoiVIV@02oiVIV@05o`000?moOgoo
OgmoogmoOol000000omVIVH00ol0003oC4a<oda<C004oda<C003o`000?lc<c?o<c<c00Co<c<c00?o
0000oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Go0000oiVIVOnIVIWo
VIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVI
V@03o`000?moOgoo000000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`04o`000?m<C4co
C4a<o`0000;oIVIV00Ko0000ogmoOomoOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Oo
c<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<c
oc<c<`07oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000
olc<c?o<c<`01_o<c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000006ooooo`7o
00000Oooool1ooooo`006Oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000oooooooo
ool00oooool00ol0003oVIVIoiVIV@0:oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnI
VIT02onIVIT2o`0000[oOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Goda<C003
o`000?mVIVKoIVIV00WoIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@04oiVIV@03
o`000?nc/k?o/k>c01;o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo0000
00?oIVIV00?o0000oda<C?m<C4`01?m<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<
00;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000onc
/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01_l0003oOgmo
ogmoOol0003oIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01_lc<c<01_l0003oC4a<oda<C?l0003o
IVIVo`0000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c00:o`000?nc
/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01olc<c<0
0ol0003oC4a<o`000002ofIVIP;o000000GoVIVIo`000?nc/k?o/k>co`000009olc<c004o`000?nc
/k?o0000o`0000;oOgmo0_l000000om<C4coooooooooo`04ooooo`7o00000Oooool1ooooo`006Ooo
ool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool00oooool<oiVIV@03o`00
0?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`00
0?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`2o`0000_oIVIV00?o0000ogmoOomoOgl0
1OmoOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c01;o/k>c00?o0000oiVIVOnIVIT0
0_nIVIT01Ol0003oOgmoogmoOomoOgoo000000CoIVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o
<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmo
O`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003o/k>cok>c/`02
ok>c/`06o`000?nIVIWoVIVIo`000?moOgoo00000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So
<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00?o0000oiVIVOl000000_nc/k<0
0ol0003oc<c<olc<c007olc<c003o`000?nc/k?o000000;oVIVI00Go0000ogmoOol0003oIVIVo`00
0002oda<C003o`000?lc<c?o<c<c00Ko<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`00
0?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c003o`000?nc/k?o/k>c00;o000000GoOgmo
o`000?mVIVKo0000oda<C006ooooo`7o00000Oooool1ooooo`006Oooool01OnYZJWo410@o`000?l@
413oZJVY00Kooooo00?o0000ooooooooool00oooool;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c0_l0
000=oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH03?mVIVH00ol0003oC4a<oda<
C00Foda<C003o`000?mVIVKoIVIV00[oIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVI
V@04oiVIV@03o`000?nc/k?o/k>c01;o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmo
OomoOgoo000000CoIVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`00
0?m<C4coC4a<00?oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01Ol0003oVIVIoiVIVOnIVIWo0000
00?o/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003o/k>cok>c/`02ok>c/`06o`000?nIVIWoVIVI
o`000?moOgoo00000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Oo0000oda<C?m<C4co
C4a<o`000?mVIVKo000000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<
c003o`000?nc/k?o000000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o
<c<c00Ko<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0
003oc<c<olc<c006olc<c003o`000?nc/k?o/k>c00;o000000GoOgmoo`000?mVIVKo0000oda<C006
ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`[oVIVI00?o0000ok>c
/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@;o00002_moOgl00ol0003oIVIVofIVIP0<ofIV
IP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`04ogmo
O`;o00001_nIVIT00ol0003o/k>cok>c/`0Bok>c/`03o`000?nIVIWoVIVI00?oVIVI00Co0000ogmo
OomoOgoo00001?mVIVH00ol0003oC4a<oda<C003oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000
oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo0000
1?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Ko0000oiVIVOnIVIWo
0000ogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01ol0003oC4a<oda<C?m<
C4co0000ofIVI_l000000_moOgl00ol0003oVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<
00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c
<`07oc<c<`03o`000?m<C4coC4a<00;o000000OoOgmoo`000?nIVIWoVIVIo`000?nc/k?o000000Wo
c<c<00Co0000ok>c/ol0003oVIVI0_l000001?mVIVKo0000oda<C?m<C4`6ooooo`7o00000Oooool1
ooooo`009?ooool00ol0003oooooooooo`03ooooo`WoVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0
003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH2o`00
01OoC4a<0_l0000<ofIVIP03o`000?moOgooOgmo00CoOgmo00?o0000oiVIVOnIVIT01OnIVIT00ol0
003o/k>cok>c/`0Cok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`000003
ofIVIP03o`000?m<C4coC4a<00CoC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C002
oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Co/k>c
00?o0000olc<c?o<c<`01Oo<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomo
Ogoo00000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Co0000oda<C?m<C4co00000_mV
IVH00ol0003oOgmoo`000002oiVIV@03o`000?nc/k?o/k>c00;o00001oo<c<`01?l0003o/k>cok>c
/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0:
o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`0
1oo<c<`01?l0003o/k>co`000?nIVIT2o`000005ofIVI_l0003oC4a<oda<C?l000001Oooool1o`00
007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool8oiVIV@03o`000?nc/k?o/k>c01Oo
/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00co
IVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0:ofIVIP03o`000?moOgooOgmo00Go
Ogmo00?o0000oiVIVOnIVIT01OnIVIT00ol0003o/k>cok>c/`0Cok>c/`03o`000?nIVIWoVIVI00;o
VIVI00Go0000ogmoOomoOgooOgmoo`000003ofIVIP03o`000?m<C4coC4a<00CoC4a<00?o0000oc<c
<olc<c<01?lc<c<00ol0003oC4a<oda<C002oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl0
1Ol0003oVIVIoiVIVOnIVIWo000000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`01Ol0003o/k>cok>c
/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01Ol0003oC4a<oda<C?m<C4co0000
00So<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o
/k>co`0000Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;o
C4a<00?o0000oc<c<olc<c<01_lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVI
VOl00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Co0000ok>c/ol0003oVIVI0_l000001OmVIVKo
0000oda<C?m<C4co000000Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?o
oooo1onIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomo
Ogl02OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mV
IVH02omVIVH00ol0003oOgmoogmoO`04ogmoO`03o`000?nIVIWoVIVI00GoVIVI00?o0000ok>c/onc
/k<04onc/k<00ol0003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol000000omVIVH00ol0
003oC4a<oda<C004oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00om<C4`01Ol0
003oIVIVofIVI_mVIVKo000000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000003ok>c/`03o`000?o<
c<coc<c<00Koc<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo00Co0000ofIVI_mV
IVKo00001?m<C4`00ol0003o<c<coc<c<`05oc<c<`07o`000?m<C4coC4a<oda<C?l0003oIVIVo`00
0002ogmoO`04o`000?nIVIWoVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>c
ok>c/ol00002oiVIV@;o00000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`0:o`000?m<C4coC4a<
o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003o
/k>co`000002oiVIV@;o000000GoIVIVo`000?m<C4coC4a<o`000005ooooo`7o00000Oooool1oooo
o`009?ooool00ol0003oooooooooo`03ooooo`KoVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003o
VIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003o
C4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl01?moOgl00ol0003o
VIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003o
OgmoogmoOomoOgoo000000?oIVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`05oc<c
<`03o`000?m<C4coC4a<00;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`05o`000?nIVIWo
VIVIoiVIVOl000001?nc/k<00ol0003oc<c<olc<c005olc<c005o`000?nc/k?o/k>cok>c/ol00000
0_nIVIT01?l0003oOgmoogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01?l0
003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002Oo<
c<`00ol0003o/k>co`000002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<c
oc<c<`06oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o
0000olc<c?o<c<`01oo<c<`01?l0003o/k>co`000?nIVIT2o`0000;oIVIV00?o0000oda<C?l00000
1_ooool1o`00007ooooo0Oooool002Cooooo0_l00004ooooo`KoVIVI00?o0000ok>c/onc/k<05_nc
/k<00ol0003oVIVIoiVIV@0:oiVIV@;o00002_moOgl2o`0000coIVIV0_l0000Goda<C0;o00003?mV
IVH2o`0000OoOgmo00?o0000oiVIVOnIVIT01OnIVIT00ol0003o/k>cok>c/`0Cok>c/`03o`000?nI
VIWoVIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`000004ofIVIP03o`000?m<C4coC4a<00?oC4a<
00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C003oda<C005o`000?mVIVKoIVIVofIVI_l0
00000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0
003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01Ol0003oC4a<oda<
C?m<C4co000000So<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVIV@04
o`000?nc/k?o/k>co`0000Woc<c<00?o0000ok>c/ol000000_nIVIT01Ol0003oOgmoo`000?mVIVKo
000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo
0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o0000oiVIV@02
o`000005ofIVI_l0003oC4a<oda<C?l000001Oooool2o`0000;ooooo000Tooooo`03o`000?oooooo
oooo00?ooooo1OnIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00[oVIVI00?o0000
ogmoOomoOgl02_moOgl00ol0003oIVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000
ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmoO`06ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000
ok>c/onc/k<04onc/k<00ol0003oVIVIoiVIV@03oiVIV@05o`000?moOgooOgmoogmoOol000001?mV
IVH00ol0003oC4a<oda<C003oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00om<
C4`01?l0003oIVIVofIVI_l00003ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000onc/k<00ol0003o
c<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002
ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`00
0?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`00ol0003o/k>co`000002oiVIV@05
o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0:o`000?m<C4coC4a<
o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o
/k>cok>c/ol0003oVIVI00;o000000GoIVIVo`000?m<C4coC4a<o`000006ooooo`7o00000Oooool1
ooooo`009?ooool00ol0003oooooooooo`03ooooo`CoVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0
003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02_mVIVH00ol0
003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl01_moOgl00ol0
003oVIVIoiVIV@05oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0
003oOgmoogmoOomoOgoo000000CoIVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`04
oc<c<`03o`000?m<C4coC4a<00?oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`05o`000?nI
VIWoVIVIoiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol0
00000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<0
1?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o0000
2Oo<c<`00ol0003o/k>co`000002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o
<c<coc<c<`06oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c
00?o0000olc<c?o<c<`01oo<c<`01_l0003o/k>co`000?nIVIWo0000ogmoO`;o00000_m<C4`00ol0
003o<c<cooooo`05ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`?o
VIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0:oiVIV@;o00002_moOgl2o`0000co
IVIV0_l0000Goda<C0;o00003OmVIVH00ol0003oOgmoogmoO`05ogmoO`;o00001onIVIT00ol0003o
/k>cok>c/`0Cok>c/`03o`000?nIVIWoVIVI00;oVIVI00?o0000ogmoOomoOgl00_moOgl01Ol0003o
IVIVofIVI_mVIVKo000000KoC4a<00?o0000oc<c<olc<c<00olc<c<00ol0003oC4a<oda<C004oda<
C004o`000?mVIVKoIVIVo`0000?oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<
c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP04
o`000?m<C4coC4a<o`0000So<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP03o`000?moOgoo
000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@05o`00
0?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0:o`000?m<C4coC4a<o`00
0?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>c
ok>c/ol0003oVIVI00;o000000KoIVIVo`000?m<C4coC4a<o`000?lc<c<6ooooo`7o00000Oooool1
ooooo`009?ooool00ol0003oooooooooo`03ooooo`;oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0
003oVIVIoiVIV@0:oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0
003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl01_moOgl00ol0
003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT00_nIVIT00ol0
003oOgmoogmoO`02ogmoO`05o`000?mVIVKoIVIVofIVI_l000001_m<C4`00ol0003o<c<coc<c<`03
oc<c<`03o`000?m<C4coC4a<00CoC4a<00Co0000ofIVI_mVIVKo00000omoOgl01?l0003oVIVIoiVI
VOl00004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVI
oiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0
003oC4a<oda<C?m<C4co000000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<
c<coc<c<00Ooc<c<00Co0000ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;o
C4a<00?o0000oc<c<olc<c<01_lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVI
VOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o0000oiVIV@02o`000006
ofIVI_l0003oC4a<oda<C?l0003o<c<c1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000oooo
ooooool00oooool00onIVIWo0000ok>c/`0Gok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmo
OomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIV
I_mVIVH03?mVIVH00ol0003oOgmoogmoO`06ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c
/onc/k<04onc/k<00ol0003oVIVIoiVIV@02oiVIV@03o`000?moOgooOgmo00;oOgmo00Go0000ofIV
I_mVIVKoIVIVo`000006oda<C003o`000?lc<c?o<c<c00?o<c<c00?o0000oda<C?m<C4`01?m<C4`0
1?l0003oIVIVofIVI_l00003ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`0
1_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01?l0
003oC4a<oda<C?l00008oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH00ol0003oOgmoo`00
0002oiVIV@04o`000?nc/k?o/k>co`0000Woc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmo
o`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`07oc<c<`07o`000?m<C4co0000ofIVI_l0003o
Ogmoo`000002oiVIV@03o`000?nc/k?o000000Soc<c<00Oo0000ok>c/onc/k?o0000oiVIVOl0003o
Ogmo00;o00000_m<C4`00ol0003o<c<coc<c<`06ooooo`7o00000Oooool1ooooo`009?ooool00ol0
003oooooooooo`03ooooo`03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0
003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`2o`00
00goIVIV00?o0000ogmoOomoOgl01_moOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c
01?o/k>c00?o0000oiVIVOnIVIT00_nIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV
00;oIVIV00?o0000oda<C?m<C4`00om<C4`2o`0000Go<c<c00?o0000oda<C?m<C4`00om<C4`01Ol0
003oIVIVofIVI_mVIVKo000000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000003ok>c/`;o00001oo<
c<`01Ol0003o/k>cok>c/onc/k?o000000?oVIVI00?o0000ogmoOol000000_mVIVH01Ol0003oC4a<
oda<C?m<C4co000000So<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP03o`000?moOgoo0000
00;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@05o`000?mo
Ogoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0:o`000?m<C4coC4a<o`000?mV
IVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01ol0003o/k>cok>c
/ol0003oVIVIo`000?moOgl00_l00002oda<C003o`000?lc<c?o<c<c00Kooooo0Ol00001ooooo`7o
oooo000Tooooo`03o`000?oooooooooo00?ooooo6?nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`00
0?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`00
0?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl01_moOgl00ol0003oVIVIoiVIV@06oiVIV@03o`00
0?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`02ogmoO`03o`00
0?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`00
0?m<C4coC4a<00?oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVI
VOl000000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT0
1?l0003oOgmoogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01ol0003oC4a<
oda<C?m<C4co0000ofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00002ok>c/`03o`000?o<c<co
c<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<
00?o0000oc<c<olc<c<01_lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0
0002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Oo0000ok>c/onc/k?o0000oiVIVOl0003oOgmo00;o
00000_m<C4`00ol0003o<c<coc<c<`06ooooo`7o00000Oooool1ooooo`009?ooool00ol0003ooooo
ooooo`03oooooaOo/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`00
0?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`00
0?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT01OnIVIT00ol0003o/k>cok>c/`0Dok>c/`03o`00
0?nIVIWoVIVI00;oVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP02ofIVIP03o`00
0?m<C4coC4a<00?oC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C003oda<C005o`00
0?mVIVKoIVIVofIVI_l000000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000?o/k>c00?o0000olc<
c?o<c<`01_o<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00?o0000
ofIVI_l000000om<C4`00ol0003o<c<coc<c<`07oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o
0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00008olc<c004o`000?nc/k?o/k>co`0000;o
VIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Ko0000oda<
C?m<C4co0000ofIVI_l00002ogmoO`;o00000_nc/k<00ol0003oc<c<olc<c006olc<c00<o`000?nc
/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co00000olc<c<6ooooo`7o00000Ooo
ool1ooooo`009?ooool00ol0003oooooooooo`03oooooaKo/k>c00?o0000oiVIVOnIVIT02onIVIT0
0ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`2
o`0000goIVIV00?o0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@05oiVIV@03o`000?nc/k?o
/k>c01Co/k>c00?o0000oiVIVOnIVIT00onIVIT01Ol0003oOgmoogmoOomoOgoo000000CoIVIV00?o
0000oda<C?m<C4`01?m<C4`00ol0003o<c<coc<c<`03oc<c<`03o`000?m<C4coC4a<00CoC4a<00Co
0000ofIVI_mVIVKo00000omoOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Ko
c<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Go0000
oda<C?m<C4coC4a<o`000008oc<c<`07o`000?m<C4coC4a<oda<C?l0003oIVIVo`000002ogmoO`03
o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`01_l0003o/k>cok>c/ol0003oVIVI
o`0000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0:o`000?m<C4co
C4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`03?l0
003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000?o<c<c1_ooool1o`00
007ooooo0Oooool002Cooooo0_l00004oooooaGo/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003o
OgmoogmoO`08ogmoO`;o00003?mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00co
IVIV00?o0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@05oiVIV@03o`000?nc/k?o/k>c01Go
/k>c00?o0000oiVIVOnIVIT00onIVIT01Ol0003oOgmoogmoOomoOgoo000000CoIVIV00?o0000oda<
C?m<C4`01?m<C4`00ol0003o<c<coc<c<`03oc<c<`03o`000?m<C4coC4a<00CoC4a<00Co0000ofIV
I_mVIVKo00000omoOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go
0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Go0000oda<C?m<
C4coC4a<o`000008oc<c<`07o`000?m<C4coC4a<oda<C?l0003oIVIVo`000002ogmoO`03o`000?nI
VIWo000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;o
Ogmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0:o`000?m<C4coC4a<o`00
0?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`03?l0003o/k>c
ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000?o<c<c1Oooool2o`0000;ooooo
000Tooooo`03o`000?oooooooooo00?ooooo5?nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?mo
OgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mV
IVKoIVIV00coIVIV00?o0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc
/k?o/k>c01Co/k>c00?o0000oiVIVOnIVIT00onIVIT01Ol0003oOgmoogmoOomoOgoo000000CoIVIV
00?o0000oda<C?m<C4`01?m<C4`00ol0003o<c<coc<c<`03oc<c<`03o`000?m<C4coC4a<00CoC4a<
00Co0000ofIVI_mVIVKo00000omoOgl01Ol0003oVIVIoiVIVOnIVIWo000000?o/k>c00?o0000olc<
c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mV
IVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo0000
00;oOgmo00?o0000oiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>c
o`0000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co
0000oda<C?m<C4co00000_mVIVH2o`000005oiVIVOl0003o/k>cok>c/ol000002?o<c<`03?l0003o
/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000Co<c<c1_ooool1o`00007o
oooo0Oooool002Cooooo00?o0000ooooooooool00ooooolBok>c/`;o00003OnIVIT00ol0003oOgmo
ogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIV
ofIVIP0<ofIVIP03o`000?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>c
ok>c/`0Dok>c/`03o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl00_moOgl01Ol0003oIVIV
ofIVI_mVIVKo000000OoC4a<00?o0000oc<c<olc<c<00_lc<c<00ol0003oC4a<oda<C004oda<C005
o`000?mVIVKoIVIVofIVI_l000000omoOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<co
c<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mV
IVKoIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01olc<c<01ol0003oC4a<oda<C?m<C4co0000ofIV
I_l000000_moOgl00ol0003oVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Ko0000ok>c
/onc/k?o0000oiVIVOl00002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc
<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<co
c<c<00Koc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00004
oc<c<`Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo4_nc/k<00ol0
003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0
003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00[oIVIV0_l0000:ogmoO`03o`000?nIVIWoVIVI
00KoVIVI00?o0000ok>c/onc/k<05?nc/k<00ol0003oVIVIoiVIV@03oiVIV@03o`000?moOgooOgmo
00;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000006oda<C003o`000?lc<c?o<c<c00?o<c<c00?o0000
oda<C?m<C4`01?m<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Co0000oiVIVOnIVIWo0000
1?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo
00000_moOgl01?l0003oIVIVofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Oo0000oda<
C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<
c007olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl00ol0003oIVIVo`000002oda<C003
o`000?lc<c?o<c<c00Ko<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000
0_nc/k<00ol0003oc<c<olc<c006olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003o
IVIVo`000?m<C4co00001?lc<c<6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003ooooooooo
o`03oooooa7o/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mV
IVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0:ofIVIP03o`000?mo
OgooOgmo00WoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`0Dok>c/`03o`000?nI
VIWoVIVI00?oVIVI00?o0000ogmoOomoOgl00_moOgl01Ol0003oIVIVofIVI_mVIVKo000000OoC4a<
00?o0000oc<c<olc<c<00_lc<c<00ol0003oC4a<oda<C005oda<C004o`000?mVIVKoIVIVo`0000?o
Ogmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c
00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc
<c?o<c<c00Ko<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00Co0000oiVIVOnI
VIWo00000_nc/k<00ol0003oc<c<olc<c007olc<c003o`000?nc/k?o/k>c00;o00000_moOgl00ol0
003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00?o0000oda<C?m<C4`00_l000001omo
Ogoo0000oiVIVOnIVIWo0000ok>c/ol000002?o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?mo
Ogoo0000ofIVI_l0003oC4a<o`0000Go<c<c1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000
ooooooooool00oooool?ok>c/`;o00003OnIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKo
IVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`2o`0000coIVIV00?o0000ogmoOomoOgl02OmoOgl0
0ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c01Co/k>c00?o0000oiVIVOnIVIT00onIVIT0
0ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01?m<C4`0
0ol0003o<c<coc<c<`03oc<c<`03o`000?m<C4coC4a<00CoC4a<00Go0000ofIVI_mVIVKoIVIVo`00
0002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0003oc<c<olc<c005olc<c003o`00
0?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00003oda<
C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH01_l0003oOgmoogmoOol0
003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01oo<c<`01_l0003o/k>cok>c/ol0003oVIVIo`00
00;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0:o`000?m<C4coC4a<
o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`03?l0003o
/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000Go<c<c1_ooool1o`00007o
oooo0Oooool002Cooooo00?o0000ooooooooool00oooool>ok>c/`03o`000?nIVIWoVIVI00coVIVI
00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<
00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00OoVIVI
00?o0000ok>c/onc/k<05?nc/k<00ol0003oVIVIoiVIV@02oiVIV@03o`000?moOgooOgmo00?oOgmo
00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C004oda<C003o`000?lc<c?o<c<c00?o<c<c
00?o0000oda<C?m<C4`01?m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Go0000oiVIVOnI
VIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0
003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01olc
<c<01?l0003oC4a<oda<C?l00002ofIVIP06o`000?moOgooOgmoo`000?nIVIWo00000_nc/k<00ol0
003oc<c<olc<c007olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl00ol0003oIVIVo`00
0002oda<C003o`000?lc<c?o<c<c00Ko<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`00
0?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000
ogmoOol0003oIVIVo`000?m<C4co00001Olc<c<6ooooo`7o00000Oooool1ooooo`009?ooool00ol0
003oooooooooo`03ooooo`go/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`08ogmo
O`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0:ofIV
IP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT01onIVIT00ol0003o/k>cok>c/`0Dok>c
/`03o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP02ofIV
IP03o`000?m<C4coC4a<00CoC4a<00?o0000oc<c<olc<c<00olc<c<00ol0003oC4a<oda<C004oda<
C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<
c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`00
0?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co0000
00;oIVIV00Go0000ogmoOol0003oVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Ko0000
ok>c/onc/k?o0000oiVIVOl00002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<0
1_lc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo0_l00002ok>c/`03o`000?o<c<coc<c<
00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT2o`000005ofIVI_l0003oC4a<oda<C?l000001Olc
<c<6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`co/k>c00?o0000
oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000
oda<C?m<C4`05_m<C4`2o`0000coIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@07
oiVIV@03o`000?nc/k?o/k>c01Co/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`02
ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01Om<C4`00ol0003o<c<coc<c<`02
oc<c<`03o`000?m<C4coC4a<00CoC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`04o`000?nI
VIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000?o
VIVI00?o0000ogmoOol000000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Go0000oda<
C?m<C4coC4a<o`000002ofIVIP03o`000?moOgoo000000;oVIVI00Go0000ok>c/onc/k?o/k>co`00
0008olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl00ol0003oIVIVo`000002oda<C003
o`000?lc<c?o<c<c00Ko<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000
0_nc/k<00ol0003oc<c<olc<c006olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003o
IVIVo`000?m<C4co00001_lc<c<6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003ooooooooo
o`03ooooo`_o/k>c0_l0000=oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH03?mV
IVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00[oIVIV00?o0000ogmoOomoOgl02Omo
Ogl00ol0003oVIVIoiVIV@07oiVIV@03o`000?nc/k?o/k>c01Go/k>c00?o0000oiVIVOnIVIT00onI
VIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01Om<
C4`00ol0003o<c<coc<c<`02oc<c<`03o`000?m<C4coC4a<00CoC4a<00Go0000ofIVI_mVIVKoIVIV
o`000003ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o
/k>cok>c/onc/k?o000000?oVIVI00?o0000ogmoOol000000_mVIVH01Ol0003oC4a<oda<C?m<C4co
000000So<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP03o`000?moOgoo000000;oVIVI00Go
0000ok>c/onc/k?o/k>co`000008olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl00ol0
003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00[o0000oda<C?m<C4co0000ofIVI_l0
003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c003o`000?nc/k?o000000;o
VIVI00Oo0000ogmoOol0003oIVIVo`000?m<C4co000000Ko<c<c1_ooool1o`00007ooooo0Oooool0
02Cooooo0_l00004ooooo`[o/k>c00?o0000oiVIVOnIVIT02onIVIT2o`0000[oOgmo00?o0000ofIV
I_mVIVH03?mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00[oIVIV00?o0000ogmo
OomoOgl02OmoOgl00ol0003oVIVIoiVIV@08oiVIV@03o`000?nc/k?o/k>c01Co/k>c00?o0000oiVI
VOnIVIT00onIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<
C?m<C4`01Om<C4`00ol0003o<c<coc<c<`02oc<c<`03o`000?m<C4coC4a<00GoC4a<00Co0000ofIV
I_mVIVKo00000omoOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go
0000ok>c/onc/k?o/k>co`000003oiVIV@03o`000?moOgoo000000;oIVIV00Go0000oda<C?m<C4co
C4a<o`000008oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH00ol0003oOgmoo`000002oiVI
V@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@05o`000?mo
Ogoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;o
IVIV0_l000001OnIVIWo0000ok>c/onc/k?o000000Soc<c<00So0000ok>c/onc/k?o0000oiVIVOl0
003oOgmoo`0000;oIVIV0_l00007oc<c<`Gooooo0_l00002ooooo`009?ooool00ol0003ooooooooo
o`03ooooo`Wo/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mV
IVKoIVIV00_oIVIV0_l0000Goda<C0;o00003?mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nI
VIWoVIVI00SoVIVI00?o0000ok>c/onc/k<05?nc/k<00ol0003oVIVIoiVIV@03oiVIV@03o`000?mo
OgooOgmo00;oOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C005oda<C005o`000?lc
<c?o<c<coc<c<ol000001om<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Go0000oiVIVOnI
VIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0
003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc
<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>c
ok>c/ol00008olc<c0;o00000_nc/k<01Ol0003oVIVIo`000?moOgoo000000;oIVIV00Co0000oda<
C?m<C4co00002?lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c
/`03o`000?o<c<coc<c<00Koc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo
0000oda<C?l00007oc<c<`Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?o
oooo2Onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mV
IVH03?mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00[oIVIV00?o0000ogmoOomo
Ogl02OmoOgl00ol0003oVIVIoiVIV@09oiVIV@03o`000?nc/k?o/k>c01Co/k>c00?o0000oiVIVOnI
VIT00onIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<
C4`01Om<C4`01Ol0003o<c<coc<c<olc<c?o000000OoC4a<00Go0000ofIVI_mVIVKoIVIVo`000002
ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc
/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00003oda<C003
o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP03o`000?moOgoo0000
00;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`02Ol0003o/k>cok>c/onc/k?o0000oiVIVOl0003o
Ogmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00[o0000oda<C?m<C4co0000ofIVI_l0
003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c00<o`000?nc/k?o/k>co`00
0?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co00001olc<c<6ooooo`7o00000Oooool1ooooo`00
9?ooool00ol0003oooooooooo`03ooooo`So/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmo
ogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIV
ofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02OnIVIT00ol0003o/k>c
ok>c/`0Eok>c/`03o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIV
ofIVIP02ofIVIP03o`000?m<C4coC4a<00GoC4a<00Go0000oc<c<olc<c?o<c<co`000007oda<C005
o`000?mVIVKoIVIVofIVI_l000000omoOgl01?l0003oVIVIoiVIVOl00005ok>c/`03o`000?o<c<co
c<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mV
IVKoIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01olc<c<01ol0003oC4a<oda<C?m<C4co0000ofIV
I_l000000_moOgl01?l0003oVIVIoiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00_o0000
ok>c/onc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c
00Ko<c<c00_o0000oda<C?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c/`03
o`000?o<c<coc<c<00Koc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000
oda<C?l00007oc<c<`Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo
1onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH0
2omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl0
2?moOgl00ol0003oVIVIoiVIV@09oiVIV@03o`000?nc/k?o/k>c01Go/k>c00?o0000oiVIVOnIVIT0
0onIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<C4`0
1Om<C4`01Ol0003o<c<coc<c<olc<c?o000000OoC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmo
O`05o`000?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o
/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00003oda<C003o`00
0?lc<c?o<c<c00Oo<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVIV@04
o`000?nc/k?o/k>co`0000Soc<c<00Wo0000ok>c/onc/k?o/k>co`000?nIVIWo0000ogmoOol00000
0_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0
0002oiVIV@03o`000?nc/k?o000000Soc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`00
0?mVIVKo0000oda<C?l00008oc<c<`Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooo
oooo00?ooooo1_nc/k<00ol0003oVIVIoiVIV@0:oiVIV@;o00002_moOgl2o`0000coIVIV0_l0000G
oda<C0;o00003?mVIVH2o`0000[oOgmo00?o0000oiVIVOnIVIT02OnIVIT00ol0003o/k>cok>c/`0E
ok>c/`03o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl00_moOgl2o`0000CoIVIV00?o0000
oda<C?m<C4`01Om<C4`01Ol0003o<c<coc<c<olc<c?o000000OoC4a<00Go0000ofIVI_mVIVKoIVIV
o`000003ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0003oc<c<olc<c004olc<c0;o
00001?nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000
oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o0000ogmoOol000000_nI
VIT01?l0003o/k>cok>c/ol00008olc<c009o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000?moOgoo
000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?mo
Ogoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00co0000ok>c/onc/k?o0000oiVI
VOl0003oOgmoo`000?mVIVKo0000oda<C?l00008oc<c<`03o`000?oooooooooo00?ooooo0Ol00001
ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo1Onc/k<00ol0003oVIVIoiVIV@0:oiVI
V@03o`000?moOgooOgmo00[oOgmo00?o0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<oda<C00Foda<
C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0:oiVI
V@03o`000?nc/k?o/k>c01Co/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`02ogmo
O`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<C4`01Om<C4`01Ol0003o<c<coc<c<olc<c?o
000000KoC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000?oVIVI00?o
0000ok>c/onc/k<00_nc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Co
0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko
<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c
/onc/k?o00002?o<c<`02Ol0003o/k>cok>c/onc/k?o0000oiVIVOl0003oOgmoo`000002ofIVIP04
o`000?m<C4coC4a<o`0000So<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo
00000_nc/k<00ol0003oc<c<olc<c006olc<c003o`000?nc/k?o/k>c00;o00000_moOgl01Ol0003o
IVIVo`000?m<C4co000000So<c<c00?o0000ooooooooool00oooool1o`00007ooooo0Oooool002Co
oooo00?o0000ooooooooool00oooool4ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomo
Ogl02OmoOgl00ol0003oIVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mV
IVH03?mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00[oVIVI00?o0000ok>c/onc
/k<05Onc/k<00ol0003oVIVIoiVIV@03oiVIV@03o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mV
IVH00omVIVH00ol0003oC4a<oda<C005oda<C005o`000?lc<c?o<c<coc<c<ol000001om<C4`01Ol0
003oIVIVofIVI_mVIVKo000000?oOgmo00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<
c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00onc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`00
0?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co0000
00;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00008olc<c007o`000?nc/k?o
/k>cok>c/ol0003oVIVIo`000002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<0
1_lc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo0_l00002ok>c/`03o`000?o<c<coc<c<
00Koc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o
<c<coc<c<`05oc<c<`03o`000?oooooooooo00Cooooo0Ol00001ooooo`7ooooo000Booooo`Co0000
00So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKooooo00?o0000ooooooooool00oooool3
ok>c/`03o`000?nIVIWoVIVI00[oVIVI0_l0000:ogmoO`;o00003?mVIVH2o`0001OoC4a<0_l0000=
ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02_nIVIT00ol0003o/k>cok>c/`0E
ok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP02
ofIVIP03o`000?m<C4coC4a<00KoC4a<1Ol00006oda<C003o`000?mVIVKoIVIV00;oIVIV00Co0000
ogmoOomoOgoo00000onIVIT00ol0003o/k>cok>c/`02ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o
0000ok>c/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo
00000_m<C4`00ol0003o<c<coc<c<`07oc<c<`07o`000?m<C4coC4a<oda<C?l0003oIVIVo`000002
ogmoO`04o`000?nIVIWoVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02Ol0003o/k>cok>c
/onc/k?o0000oiVIVOl0003oOgmoo`000002ofIVIP03o`000?m<C4co000000Wo<c<c00[o0000oda<
C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c00<
o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co00002?lc<c<00ol0003o
ooooooooo`04ooooo`7o00000Oooool1ooooo`005?ooool00ol0003oooooooooo`02ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`03ooooo`;o/k>c00?o0000oiVIVOnI
VIT02_nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<
C4`05_m<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnI
VIT02onIVIT00ol0003o/k>cok>c/`0Eok>c/`03o`000?nIVIWoVIVI00CoVIVI00Go0000ogmoOomo
OgooOgmoo`000005ofIVIP03o`000?m<C4coC4a<00KoC4a<00?o0000oda<C?m<C4`02?m<C4`00ol0
003oIVIVofIVIP02ofIVIP04o`000?moOgooOgmoo`0000?oVIVI00?o0000ok>c/onc/k<00_nc/k<0
0ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Go0000oiVIVOnIVIWoVIVIo`00
0002ogmoO`04o`000?mVIVKoIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01olc<c<01ol0003oC4a<
oda<C?m<C4co0000ofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00002ok>c/`03o`000?o<c<co
c<c<00Koc<c<00Wo0000ok>c/onc/k?o/k>co`000?nIVIWo0000ogmoOol000000_mVIVH00ol0003o
C4a<o`000009oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c
00?o0000olc<c?o<c<`01_o<c<`00ol0003o/k>co`000002oiVIV@07o`000?moOgoo0000ofIVI_l0
003oC4a<o`000008oc<c<`03o`000?oooooooooo00Cooooo0Ol00001ooooo`7ooooo000Dooooo`03
o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo
00?ooooo00?o/k>co`000?nIVIT03?nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV
00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?moOgooOgmo
00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Eok>c/`03o`000?nIVIWoVIVI
00CoVIVI00Go0000ogmoOomoOgooOgmoo`000005ofIVIP03o`000?m<C4coC4a<00KoC4a<00?o0000
oc<c<ol000002?m<C4`00ol0003oIVIVofIVIP02ofIVIP05o`000?moOgooOgmoogmoOol000000_nI
VIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00onc
/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc
<c<01_lc<c<01ol0003oC4a<oda<C?m<C4co0000ofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl0
0002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@;o0000
0_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV0_l000001OnI
VIWo0000ok>c/onc/k?o000000Soc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`0000;o
IVIV0_l00008oc<c<`03o`000?m<C4cooooo00Gooooo0Ol00001ooooo`7ooooo000Dooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000006ooooo`?o00000oooool00ol0003o
VIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003o
C4a<oda<C00Goda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003o
VIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Go/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0003o
OgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01om<C4`01?l0003o
<c<coc<c<ol00007oda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01Ol0003oVIVIoiVIVOnI
VIWo000000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nI
VIWoVIVIo`0000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000003oda<C003o`000?lc<c?o<c<c00Go
<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Co0000
ok>c/onc/k?o00002?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV
00Co0000oda<C?m<C4co00002?lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVI
VOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmo
o`000?mVIVKo0000oda<C?l00008oc<c<`03o`000?m<C4cooooo00?ooooo0ol00002ooooo`005?oo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003ooooo
ooooo`3oooooocoooooo0Ol00001ooooo`7ooooo000Dooooo`03o`000?oooooooooo00;ooooo00Go
410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo0?oooooo?oooool1o`00007ooooo
0Oooool001Cooooo00?o0000ooooooooool00_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo
00?o0000ooooooooool0ooooooloooooo`7o00000Oooool1ooooo`004_ooool00omEEEGoIVIVo`00
0004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool00oooool1o`00007ooooo0Oooool002Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`7o00000Oooool1ooooo`009?oooooo
o`0004?o00000_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-7.04757, -6.93977, 0.0606246, \
0.0606246}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.339744 0.0641026 0.339744 0.0641026 [
[.08333 -0.0125 -6 -9 ]
[.08333 -0.0125 6 0 ]
[.21154 -0.0125 -6 -9 ]
[.21154 -0.0125 6 0 ]
[.33974 -0.0125 -3 -9 ]
[.33974 -0.0125 3 0 ]
[.46795 -0.0125 -3 -9 ]
[.46795 -0.0125 3 0 ]
[.59615 -0.0125 -3 -9 ]
[.59615 -0.0125 3 0 ]
[.72436 -0.0125 -3 -9 ]
[.72436 -0.0125 3 0 ]
[.85256 -0.0125 -3 -9 ]
[.85256 -0.0125 3 0 ]
[.98077 -0.0125 -6 -9 ]
[.98077 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5 -21 ]
[.5 -0.0125 5 -9 ]
[-0.0125 .08333 -12 -4.5 ]
[-0.0125 .08333 0 4.5 ]
[-0.0125 .21154 -12 -4.5 ]
[-0.0125 .21154 0 4.5 ]
[-0.0125 .33974 -6 -4.5 ]
[-0.0125 .33974 0 4.5 ]
[-0.0125 .46795 -6 -4.5 ]
[-0.0125 .46795 0 4.5 ]
[-0.0125 .59615 -6 -4.5 ]
[-0.0125 .59615 0 4.5 ]
[-0.0125 .72436 -6 -4.5 ]
[-0.0125 .72436 0 4.5 ]
[-0.0125 .85256 -6 -4.5 ]
[-0.0125 .85256 0 4.5 ]
[-0.0125 .98077 -12 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -24 -5 ]
[-0.01875 .5 -12 5 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08333 0 m
.08333 .00625 L
s
[(-4)] .08333 -0.0125 0 1 Mshowa
.21154 0 m
.21154 .00625 L
s
[(-2)] .21154 -0.0125 0 1 Mshowa
.33974 0 m
.33974 .00625 L
s
[(0)] .33974 -0.0125 0 1 Mshowa
.46795 0 m
.46795 .00625 L
s
[(2)] .46795 -0.0125 0 1 Mshowa
.59615 0 m
.59615 .00625 L
s
[(4)] .59615 -0.0125 0 1 Mshowa
.72436 0 m
.72436 .00625 L
s
[(6)] .72436 -0.0125 0 1 Mshowa
.85256 0 m
.85256 .00625 L
s
[(8)] .85256 -0.0125 0 1 Mshowa
.98077 0 m
.98077 .00625 L
s
[(10)] .98077 -0.0125 0 1 Mshowa
.125 Mabswid
.11538 0 m
.11538 .00375 L
s
.14744 0 m
.14744 .00375 L
s
.17949 0 m
.17949 .00375 L
s
.24359 0 m
.24359 .00375 L
s
.27564 0 m
.27564 .00375 L
s
.30769 0 m
.30769 .00375 L
s
.37179 0 m
.37179 .00375 L
s
.40385 0 m
.40385 .00375 L
s
.4359 0 m
.4359 .00375 L
s
.5 0 m
.5 .00375 L
s
.53205 0 m
.53205 .00375 L
s
.5641 0 m
.5641 .00375 L
s
.62821 0 m
.62821 .00375 L
s
.66026 0 m
.66026 .00375 L
s
.69231 0 m
.69231 .00375 L
s
.75641 0 m
.75641 .00375 L
s
.78846 0 m
.78846 .00375 L
s
.82051 0 m
.82051 .00375 L
s
.88462 0 m
.88462 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.94872 0 m
.94872 .00375 L
s
.05128 0 m
.05128 .00375 L
s
.01923 0 m
.01923 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66 -25 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .08333 m
.00625 .08333 L
s
[(-4)] -0.0125 .08333 1 0 Mshowa
0 .21154 m
.00625 .21154 L
s
[(-2)] -0.0125 .21154 1 0 Mshowa
0 .33974 m
.00625 .33974 L
s
[(0)] -0.0125 .33974 1 0 Mshowa
0 .46795 m
.00625 .46795 L
s
[(2)] -0.0125 .46795 1 0 Mshowa
0 .59615 m
.00625 .59615 L
s
[(4)] -0.0125 .59615 1 0 Mshowa
0 .72436 m
.00625 .72436 L
s
[(6)] -0.0125 .72436 1 0 Mshowa
0 .85256 m
.00625 .85256 L
s
[(8)] -0.0125 .85256 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(10)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .11538 m
.00375 .11538 L
s
0 .14744 m
.00375 .14744 L
s
0 .17949 m
.00375 .17949 L
s
0 .24359 m
.00375 .24359 L
s
0 .27564 m
.00375 .27564 L
s
0 .30769 m
.00375 .30769 L
s
0 .37179 m
.00375 .37179 L
s
0 .40385 m
.00375 .40385 L
s
0 .4359 m
.00375 .4359 L
s
0 .5 m
.00375 .5 L
s
0 .53205 m
.00375 .53205 L
s
0 .5641 m
.00375 .5641 L
s
0 .62821 m
.00375 .62821 L
s
0 .66026 m
.00375 .66026 L
s
0 .69231 m
.00375 .69231 L
s
0 .75641 m
.00375 .75641 L
s
0 .78846 m
.00375 .78846 L
s
0 .82051 m
.00375 .82051 L
s
0 .88462 m
.00375 .88462 L
s
0 .91667 m
.00375 .91667 L
s
0 .94872 m
.00375 .94872 L
s
0 .05128 m
.00375 .05128 L
s
0 .01923 m
.00375 .01923 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
-0.01875 .5 -84 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
66 10 translate
90 rotate
-66 -10 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.08333 .99375 m
.08333 1 L
s
.21154 .99375 m
.21154 1 L
s
.33974 .99375 m
.33974 1 L
s
.46795 .99375 m
.46795 1 L
s
.59615 .99375 m
.59615 1 L
s
.72436 .99375 m
.72436 1 L
s
.85256 .99375 m
.85256 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.11538 .99625 m
.11538 1 L
s
.14744 .99625 m
.14744 1 L
s
.17949 .99625 m
.17949 1 L
s
.24359 .99625 m
.24359 1 L
s
.27564 .99625 m
.27564 1 L
s
.30769 .99625 m
.30769 1 L
s
.37179 .99625 m
.37179 1 L
s
.40385 .99625 m
.40385 1 L
s
.4359 .99625 m
.4359 1 L
s
.5 .99625 m
.5 1 L
s
.53205 .99625 m
.53205 1 L
s
.5641 .99625 m
.5641 1 L
s
.62821 .99625 m
.62821 1 L
s
.66026 .99625 m
.66026 1 L
s
.69231 .99625 m
.69231 1 L
s
.75641 .99625 m
.75641 1 L
s
.78846 .99625 m
.78846 1 L
s
.82051 .99625 m
.82051 1 L
s
.88462 .99625 m
.88462 1 L
s
.91667 .99625 m
.91667 1 L
s
.94872 .99625 m
.94872 1 L
s
.05128 .99625 m
.05128 1 L
s
.01923 .99625 m
.01923 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .08333 m
1 .08333 L
s
.99375 .21154 m
1 .21154 L
s
.99375 .33974 m
1 .33974 L
s
.99375 .46795 m
1 .46795 L
s
.99375 .59615 m
1 .59615 L
s
.99375 .72436 m
1 .72436 L
s
.99375 .85256 m
1 .85256 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .11538 m
1 .11538 L
s
.99625 .14744 m
1 .14744 L
s
.99625 .17949 m
1 .17949 L
s
.99625 .24359 m
1 .24359 L
s
.99625 .27564 m
1 .27564 L
s
.99625 .30769 m
1 .30769 L
s
.99625 .37179 m
1 .37179 L
s
.99625 .40385 m
1 .40385 L
s
.99625 .4359 m
1 .4359 L
s
.99625 .5 m
1 .5 L
s
.99625 .53205 m
1 .53205 L
s
.99625 .5641 m
1 .5641 L
s
.99625 .62821 m
1 .62821 L
s
.99625 .66026 m
1 .66026 L
s
.99625 .69231 m
1 .69231 L
s
.99625 .75641 m
1 .75641 L
s
.99625 .78846 m
1 .78846 L
s
.99625 .82051 m
1 .82051 L
s
.99625 .88462 m
1 .88462 L
s
.99625 .91667 m
1 .91667 L
s
.99625 .94872 m
1 .94872 L
s
.99625 .05128 m
1 .05128 L
s
.99625 .01923 m
1 .01923 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.7 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.6 g
.01923 .94317 m
.02079 .94192 L
.02894 .93346 L
.0302 .93221 L
.03866 .92375 L
.03991 .92249 L
.04837 .91404 L
.04962 .91278 L
.05808 .90432 L
.05934 .90307 L
.06779 .89461 L
.06905 .89336 L
.07751 .8849 L
.07876 .88364 L
.08722 .87519 L
.08847 .87393 L
.09693 .86547 L
.09819 .86422 L
.10664 .85576 L
.1079 .85451 L
.11636 .84605 L
.11761 .84479 L
.12607 .83634 L
.12732 .83508 L
.13578 .82662 L
.13704 .82537 L
.14549 .81691 L
.14675 .81566 L
.15521 .8072 L
.15646 .80594 L
.16492 .79749 L
.16617 .79623 L
.17463 .78777 L
.17589 .78652 L
.18434 .77806 L
.1856 .77681 L
.19406 .76835 L
.19531 .76709 L
.20377 .75864 L
.20502 .75738 L
.21348 .74892 L
.21474 .74767 L
.22319 .73921 L
.22445 .73796 L
.23291 .7295 L
.23416 .72824 L
.24262 .71979 L
.24387 .71853 L
.25233 .71007 L
.25359 .70882 L
.26204 .70036 L
.2633 .69911 L
.27176 .69065 L
.27301 .68939 L
.28147 .68094 L
.28272 .67968 L
.29118 .67122 L
.29244 .66997 L
.30089 .66151 L
.30215 .66026 L
.31061 .6518 L
.31186 .65054 L
.32032 .64209 L
.32157 .64083 L
.33003 .63237 L
.33143 .63112 L
.33974 .62266 L
.34076 .62141 L
.34792 .61169 L
.34946 .60954 L
.35503 .60198 L
.35917 .59632 L
.36212 .59227 L
.36888 .58291 L
.36913 .58256 L
.37601 .57284 L
.37859 .56916 L
.38276 .56313 L
.38831 .55507 L
.38942 .55342 L
.39596 .54371 L
.39802 .54061 L
.40236 .53399 L
.40773 .52577 L
.40868 .52428 L
.41488 .51457 L
.41744 .51052 L
.42096 .50486 L
.42701 .49514 L
.42716 .4949 L
.43289 .48543 L
.43687 .47886 L
.43871 .47572 L
.44448 .46601 L
.44658 .46243 L
.45011 .45629 L
.45575 .44658 L
.45629 .44563 L
.46122 .43687 L
.46601 .42843 L
.4667 .42716 L
.47206 .41744 L
.47572 .41085 L
.47738 .40773 L
.48265 .39802 L
.48543 .39289 L
.48783 .38831 L
.49301 .37859 L
.49514 .37457 L
.49806 .36888 L
.50314 .35917 L
.50486 .35588 L
.50809 .34946 L
.51308 .33974 L
.51457 .33684 L
.51793 .33003 L
.52283 .32032 L
.52428 .31743 L
.52759 .31061 L
.53241 .30089 L
.53399 .29768 L
.53708 .29118 L
.54182 .28147 L
.54371 .27759 L
.54642 .27176 L
.55107 .26204 L
.55342 .25715 L
.55561 .25233 L
.56019 .24262 L
.56313 .23638 L
.56468 .23291 L
.56916 .22319 L
.57284 .21528 L
.57362 .21348 L
.578 .20377 L
.58247 .19406 L
.58256 .19386 L
.58673 .18434 L
.59113 .17463 L
.59227 .1721 L
.59535 .16492 L
.59968 .15521 L
.60198 .15004 L
.60388 .14549 L
.60812 .13578 L
.61169 .12766 L
.61233 .12607 L
.61645 .11636 L
.62068 .10664 L
.62141 .10497 L
.6247 .09693 L
.62887 .08722 L
.63112 .08197 L
.63289 .07751 L
.63696 .06779 L
.64083 .05868 L
.64106 .05808 L
.64498 .04837 L
.64905 .03866 L
.65054 .03508 L
.65293 .02894 L
.65693 .01923 L
.01923 .01923 L
F
0 g
.01923 .94317 m
.02079 .94192 L
.02894 .93346 L
.0302 .93221 L
.03866 .92375 L
.03991 .92249 L
.04837 .91404 L
.04962 .91278 L
.05808 .90432 L
.05934 .90307 L
.06779 .89461 L
.06905 .89336 L
.07751 .8849 L
.07876 .88364 L
.08722 .87519 L
.08847 .87393 L
.09693 .86547 L
.09819 .86422 L
.10664 .85576 L
.1079 .85451 L
.11636 .84605 L
.11761 .84479 L
.12607 .83634 L
.12732 .83508 L
.13578 .82662 L
.13704 .82537 L
.14549 .81691 L
.14675 .81566 L
.15521 .8072 L
.15646 .80594 L
.16492 .79749 L
.16617 .79623 L
.17463 .78777 L
.17589 .78652 L
.18434 .77806 L
.1856 .77681 L
.19406 .76835 L
.19531 .76709 L
.20377 .75864 L
.20502 .75738 L
.21348 .74892 L
.21474 .74767 L
.22319 .73921 L
.22445 .73796 L
.23291 .7295 L
.23416 .72824 L
.24262 .71979 L
.24387 .71853 L
.25233 .71007 L
.25359 .70882 L
Mistroke
.26204 .70036 L
.2633 .69911 L
.27176 .69065 L
.27301 .68939 L
.28147 .68094 L
.28272 .67968 L
.29118 .67122 L
.29244 .66997 L
.30089 .66151 L
.30215 .66026 L
.31061 .6518 L
.31186 .65054 L
.32032 .64209 L
.32157 .64083 L
.33003 .63237 L
.33143 .63112 L
.33974 .62266 L
.34076 .62141 L
.34792 .61169 L
.34946 .60954 L
.35503 .60198 L
.35917 .59632 L
.36212 .59227 L
.36888 .58291 L
.36913 .58256 L
.37601 .57284 L
.37859 .56916 L
.38276 .56313 L
.38831 .55507 L
.38942 .55342 L
.39596 .54371 L
.39802 .54061 L
.40236 .53399 L
.40773 .52577 L
.40868 .52428 L
.41488 .51457 L
.41744 .51052 L
.42096 .50486 L
.42701 .49514 L
.42716 .4949 L
.43289 .48543 L
.43687 .47886 L
.43871 .47572 L
.44448 .46601 L
.44658 .46243 L
.45011 .45629 L
.45575 .44658 L
.45629 .44563 L
.46122 .43687 L
.46601 .42843 L
Mistroke
.4667 .42716 L
.47206 .41744 L
.47572 .41085 L
.47738 .40773 L
.48265 .39802 L
.48543 .39289 L
.48783 .38831 L
.49301 .37859 L
.49514 .37457 L
.49806 .36888 L
.50314 .35917 L
.50486 .35588 L
.50809 .34946 L
.51308 .33974 L
.51457 .33684 L
.51793 .33003 L
.52283 .32032 L
.52428 .31743 L
.52759 .31061 L
.53241 .30089 L
.53399 .29768 L
.53708 .29118 L
.54182 .28147 L
.54371 .27759 L
.54642 .27176 L
.55107 .26204 L
.55342 .25715 L
.55561 .25233 L
.56019 .24262 L
.56313 .23638 L
.56468 .23291 L
.56916 .22319 L
.57284 .21528 L
.57362 .21348 L
.578 .20377 L
.58247 .19406 L
.58256 .19386 L
.58673 .18434 L
.59113 .17463 L
.59227 .1721 L
.59535 .16492 L
.59968 .15521 L
.60198 .15004 L
.60388 .14549 L
.60812 .13578 L
.61169 .12766 L
.61233 .12607 L
.61645 .11636 L
.62068 .10664 L
.62141 .10497 L
Mistroke
.6247 .09693 L
.62887 .08722 L
.63112 .08197 L
.63289 .07751 L
.63696 .06779 L
.64083 .05868 L
.64106 .05808 L
.64498 .04837 L
.64905 .03866 L
.65054 .03508 L
.65293 .02894 L
.65693 .01923 L
Mfstroke
.5 g
.01923 .89948 m
.02537 .89336 L
.02894 .88977 L
.03507 .88364 L
.03866 .88006 L
.04478 .87393 L
.04837 .87035 L
.0545 .86422 L
.05808 .86063 L
.06421 .85451 L
.06779 .85092 L
.07392 .84479 L
.07751 .84121 L
.08363 .83508 L
.08722 .8315 L
.09335 .82537 L
.09693 .82178 L
.10306 .81566 L
.10664 .81207 L
.11277 .80594 L
.11636 .80236 L
.12248 .79623 L
.12607 .79265 L
.1322 .78652 L
.13578 .78293 L
.14191 .77681 L
.14549 .77322 L
.15162 .76709 L
.15521 .76351 L
.16133 .75738 L
.16492 .7538 L
.17105 .74767 L
.17463 .74408 L
.18076 .73796 L
.18434 .73437 L
.19047 .72824 L
.19406 .72466 L
.20018 .71853 L
.20377 .71495 L
.2099 .70882 L
.21348 .70523 L
.21961 .69911 L
.22319 .69552 L
.22932 .68939 L
.23291 .68581 L
.23903 .67968 L
.24262 .6761 L
.24875 .66997 L
.25233 .66638 L
.25846 .66026 L
.26204 .65667 L
.26817 .65054 L
.27176 .64696 L
.27788 .64083 L
.28147 .63725 L
.2876 .63112 L
.29118 .62753 L
.29731 .62141 L
.30089 .61782 L
.30702 .61169 L
.31061 .60811 L
.31673 .60198 L
.32032 .5984 L
.32645 .59227 L
.33003 .58868 L
.33624 .58256 L
.33974 .57897 L
.34536 .57284 L
.34946 .56827 L
.35395 .56313 L
.35917 .55698 L
.36214 .55342 L
.36888 .54512 L
.37001 .54371 L
.37761 .53399 L
.37859 .5327 L
.38496 .52428 L
.38831 .51975 L
.39209 .51457 L
.39802 .50628 L
.39903 .50486 L
.40579 .49514 L
.40773 .49231 L
.41239 .48543 L
.41744 .47785 L
.41885 .47572 L
.42518 .46601 L
.42716 .46292 L
.43137 .45629 L
.43687 .44753 L
.43746 .44658 L
.44344 .43687 L
.44658 .43169 L
.44931 .42716 L
.4551 .41744 L
.45629 .41542 L
.46079 .40773 L
.46601 .39871 L
.4664 .39802 L
.47194 .38831 L
.47572 .3816 L
.4774 .37859 L
.48279 .36888 L
.48543 .36407 L
.4881 .35917 L
.49337 .34946 L
.49514 .34615 L
.49856 .33974 L
.5037 .33003 L
.50486 .32784 L
.50878 .32032 L
.51382 .31061 L
.51457 .30915 L
.51879 .30089 L
.52373 .29118 L
.52428 .29008 L
.5286 .28147 L
.53344 .27176 L
.53399 .27064 L
.53823 .26204 L
.54298 .25233 L
.54371 .25085 L
.54768 .24262 L
.55236 .23291 L
.55342 .2307 L
.55698 .22319 L
.56159 .21348 L
.56313 .2102 L
.56613 .20377 L
.57066 .19406 L
.57284 .18935 L
.57514 .18434 L
.57961 .17463 L
.58256 .16817 L
.58403 .16492 L
.58842 .15521 L
.59227 .14666 L
.59279 .14549 L
.59711 .13578 L
.60143 .12607 L
.60198 .12482 L
.60569 .11636 L
.60996 .10664 L
.61169 .10266 L
.61417 .09693 L
.61837 .08722 L
.62141 .08018 L
.62254 .07751 L
.62669 .06779 L
.63082 .05808 L
.63112 .05738 L
.63491 .04837 L
.639 .03866 L
.64083 .03428 L
.64304 .02894 L
.64708 .01923 L
.01923 .01923 L
F
0 g
.01923 .89948 m
.02537 .89336 L
.02894 .88977 L
.03507 .88364 L
.03866 .88006 L
.04478 .87393 L
.04837 .87035 L
.0545 .86422 L
.05808 .86063 L
.06421 .85451 L
.06779 .85092 L
.07392 .84479 L
.07751 .84121 L
.08363 .83508 L
.08722 .8315 L
.09335 .82537 L
.09693 .82178 L
.10306 .81566 L
.10664 .81207 L
.11277 .80594 L
.11636 .80236 L
.12248 .79623 L
.12607 .79265 L
.1322 .78652 L
.13578 .78293 L
.14191 .77681 L
.14549 .77322 L
.15162 .76709 L
.15521 .76351 L
.16133 .75738 L
.16492 .7538 L
.17105 .74767 L
.17463 .74408 L
.18076 .73796 L
.18434 .73437 L
.19047 .72824 L
.19406 .72466 L
.20018 .71853 L
.20377 .71495 L
.2099 .70882 L
.21348 .70523 L
.21961 .69911 L
.22319 .69552 L
.22932 .68939 L
.23291 .68581 L
.23903 .67968 L
.24262 .6761 L
.24875 .66997 L
.25233 .66638 L
.25846 .66026 L
Mistroke
.26204 .65667 L
.26817 .65054 L
.27176 .64696 L
.27788 .64083 L
.28147 .63725 L
.2876 .63112 L
.29118 .62753 L
.29731 .62141 L
.30089 .61782 L
.30702 .61169 L
.31061 .60811 L
.31673 .60198 L
.32032 .5984 L
.32645 .59227 L
.33003 .58868 L
.33624 .58256 L
.33974 .57897 L
.34536 .57284 L
.34946 .56827 L
.35395 .56313 L
.35917 .55698 L
.36214 .55342 L
.36888 .54512 L
.37001 .54371 L
.37761 .53399 L
.37859 .5327 L
.38496 .52428 L
.38831 .51975 L
.39209 .51457 L
.39802 .50628 L
.39903 .50486 L
.40579 .49514 L
.40773 .49231 L
.41239 .48543 L
.41744 .47785 L
.41885 .47572 L
.42518 .46601 L
.42716 .46292 L
.43137 .45629 L
.43687 .44753 L
.43746 .44658 L
.44344 .43687 L
.44658 .43169 L
.44931 .42716 L
.4551 .41744 L
.45629 .41542 L
.46079 .40773 L
.46601 .39871 L
.4664 .39802 L
.47194 .38831 L
Mistroke
.47572 .3816 L
.4774 .37859 L
.48279 .36888 L
.48543 .36407 L
.4881 .35917 L
.49337 .34946 L
.49514 .34615 L
.49856 .33974 L
.5037 .33003 L
.50486 .32784 L
.50878 .32032 L
.51382 .31061 L
.51457 .30915 L
.51879 .30089 L
.52373 .29118 L
.52428 .29008 L
.5286 .28147 L
.53344 .27176 L
.53399 .27064 L
.53823 .26204 L
.54298 .25233 L
.54371 .25085 L
.54768 .24262 L
.55236 .23291 L
.55342 .2307 L
.55698 .22319 L
.56159 .21348 L
.56313 .2102 L
.56613 .20377 L
.57066 .19406 L
.57284 .18935 L
.57514 .18434 L
.57961 .17463 L
.58256 .16817 L
.58403 .16492 L
.58842 .15521 L
.59227 .14666 L
.59279 .14549 L
.59711 .13578 L
.60143 .12607 L
.60198 .12482 L
.60569 .11636 L
.60996 .10664 L
.61169 .10266 L
.61417 .09693 L
.61837 .08722 L
.62141 .08018 L
.62254 .07751 L
.62669 .06779 L
.63082 .05808 L
Mistroke
.63112 .05738 L
.63491 .04837 L
.639 .03866 L
.64083 .03428 L
.64304 .02894 L
.64708 .01923 L
Mfstroke
.4 g
.01923 .86407 m
.0288 .85451 L
.02894 .85436 L
.03851 .84479 L
.03866 .84465 L
.04822 .83508 L
.04837 .83493 L
.05793 .82537 L
.05808 .82522 L
.06765 .81566 L
.06779 .81551 L
.07736 .80594 L
.07751 .8058 L
.08707 .79623 L
.08722 .79608 L
.09678 .78652 L
.09693 .78637 L
.1065 .77681 L
.10664 .77666 L
.11621 .76709 L
.11636 .76695 L
.12592 .75738 L
.12607 .75723 L
.13563 .74767 L
.13578 .74752 L
.14535 .73796 L
.14549 .73781 L
.15506 .72824 L
.15521 .7281 L
.16477 .71853 L
.16492 .71838 L
.17448 .70882 L
.17463 .70867 L
.1842 .69911 L
.18434 .69896 L
.19391 .68939 L
.19406 .68925 L
.20362 .67968 L
.20377 .67953 L
.21333 .66997 L
.21348 .66982 L
.22305 .66026 L
.22319 .66011 L
.23276 .65054 L
.23291 .6504 L
.24247 .64083 L
.24262 .64068 L
.25218 .63112 L
.25233 .63097 L
.2619 .62141 L
.26204 .62126 L
.27161 .61169 L
.27176 .61155 L
.28132 .60198 L
.28147 .60183 L
.29103 .59227 L
.29118 .59212 L
.30075 .58256 L
.30089 .58241 L
.31046 .57284 L
.31061 .5727 L
.32017 .56313 L
.32032 .56298 L
.32988 .55342 L
.33003 .55327 L
.3396 .54371 L
.33974 .54356 L
.34946 .53412 L
.34958 .53399 L
.35881 .52428 L
.35917 .52389 L
.36749 .51457 L
.36888 .51295 L
.37572 .50486 L
.37859 .50134 L
.38359 .49514 L
.38831 .4891 L
.39114 .48543 L
.39802 .47627 L
.39842 .47572 L
.40551 .46601 L
.40773 .46287 L
.41238 .45629 L
.41744 .44894 L
.41906 .44658 L
.42559 .43687 L
.42716 .43449 L
.43198 .42716 L
.43687 .41955 L
.43821 .41744 L
.44435 .40773 L
.44658 .40412 L
.45036 .39802 L
.45625 .38831 L
.45629 .38823 L
.46207 .37859 L
.46601 .37189 L
.46777 .36888 L
.4734 .35917 L
.47572 .3551 L
.47895 .34946 L
.48441 .33974 L
.48543 .3379 L
.48981 .33003 L
.49512 .32032 L
.49514 .32027 L
.5004 .31061 L
.50486 .30224 L
.50558 .30089 L
.51073 .29118 L
.51457 .28382 L
.5158 .28147 L
.52084 .27176 L
.52428 .26501 L
.5258 .26204 L
.53074 .25233 L
.53399 .24581 L
.5356 .24262 L
.54044 .23291 L
.54371 .22625 L
.54521 .22319 L
.54997 .21348 L
.55342 .20632 L
.55465 .20377 L
.55933 .19406 L
.56313 .18603 L
.56393 .18434 L
.56854 .17463 L
.57284 .16539 L
.57306 .16492 L
.5776 .15521 L
.58206 .14549 L
.58256 .1444 L
.58652 .13578 L
.59093 .12607 L
.59227 .12308 L
.59531 .11636 L
.59967 .10664 L
.60198 .10142 L
.60398 .09693 L
.6083 .08722 L
.61169 .07943 L
.61254 .07751 L
.6168 .06779 L
.62099 .05808 L
.62141 .05711 L
.62519 .04837 L
.62936 .03866 L
.63112 .03448 L
.63348 .02894 L
.63762 .01923 L
.01923 .01923 L
F
0 g
.01923 .86407 m
.0288 .85451 L
.02894 .85436 L
.03851 .84479 L
.03866 .84465 L
.04822 .83508 L
.04837 .83493 L
.05793 .82537 L
.05808 .82522 L
.06765 .81566 L
.06779 .81551 L
.07736 .80594 L
.07751 .8058 L
.08707 .79623 L
.08722 .79608 L
.09678 .78652 L
.09693 .78637 L
.1065 .77681 L
.10664 .77666 L
.11621 .76709 L
.11636 .76695 L
.12592 .75738 L
.12607 .75723 L
.13563 .74767 L
.13578 .74752 L
.14535 .73796 L
.14549 .73781 L
.15506 .72824 L
.15521 .7281 L
.16477 .71853 L
.16492 .71838 L
.17448 .70882 L
.17463 .70867 L
.1842 .69911 L
.18434 .69896 L
.19391 .68939 L
.19406 .68925 L
.20362 .67968 L
.20377 .67953 L
.21333 .66997 L
.21348 .66982 L
.22305 .66026 L
.22319 .66011 L
.23276 .65054 L
.23291 .6504 L
.24247 .64083 L
.24262 .64068 L
.25218 .63112 L
.25233 .63097 L
.2619 .62141 L
Mistroke
.26204 .62126 L
.27161 .61169 L
.27176 .61155 L
.28132 .60198 L
.28147 .60183 L
.29103 .59227 L
.29118 .59212 L
.30075 .58256 L
.30089 .58241 L
.31046 .57284 L
.31061 .5727 L
.32017 .56313 L
.32032 .56298 L
.32988 .55342 L
.33003 .55327 L
.3396 .54371 L
.33974 .54356 L
.34946 .53412 L
.34958 .53399 L
.35881 .52428 L
.35917 .52389 L
.36749 .51457 L
.36888 .51295 L
.37572 .50486 L
.37859 .50134 L
.38359 .49514 L
.38831 .4891 L
.39114 .48543 L
.39802 .47627 L
.39842 .47572 L
.40551 .46601 L
.40773 .46287 L
.41238 .45629 L
.41744 .44894 L
.41906 .44658 L
.42559 .43687 L
.42716 .43449 L
.43198 .42716 L
.43687 .41955 L
.43821 .41744 L
.44435 .40773 L
.44658 .40412 L
.45036 .39802 L
.45625 .38831 L
.45629 .38823 L
.46207 .37859 L
.46601 .37189 L
.46777 .36888 L
.4734 .35917 L
.47572 .3551 L
Mistroke
.47895 .34946 L
.48441 .33974 L
.48543 .3379 L
.48981 .33003 L
.49512 .32032 L
.49514 .32027 L
.5004 .31061 L
.50486 .30224 L
.50558 .30089 L
.51073 .29118 L
.51457 .28382 L
.5158 .28147 L
.52084 .27176 L
.52428 .26501 L
.5258 .26204 L
.53074 .25233 L
.53399 .24581 L
.5356 .24262 L
.54044 .23291 L
.54371 .22625 L
.54521 .22319 L
.54997 .21348 L
.55342 .20632 L
.55465 .20377 L
.55933 .19406 L
.56313 .18603 L
.56393 .18434 L
.56854 .17463 L
.57284 .16539 L
.57306 .16492 L
.5776 .15521 L
.58206 .14549 L
.58256 .1444 L
.58652 .13578 L
.59093 .12607 L
.59227 .12308 L
.59531 .11636 L
.59967 .10664 L
.60198 .10142 L
.60398 .09693 L
.6083 .08722 L
.61169 .07943 L
.61254 .07751 L
.6168 .06779 L
.62099 .05808 L
.62141 .05711 L
.62519 .04837 L
.62936 .03866 L
.63112 .03448 L
.63348 .02894 L
Mistroke
.63762 .01923 L
Mfstroke
.3 g
.01923 .8204 m
.02389 .81566 L
.02894 .81069 L
.03369 .80594 L
.03866 .80098 L
.0434 .79623 L
.04837 .79126 L
.05311 .78652 L
.05808 .78155 L
.06282 .77681 L
.06779 .77184 L
.07254 .76709 L
.07751 .76213 L
.08225 .75738 L
.08722 .75241 L
.09196 .74767 L
.09693 .7427 L
.10167 .73796 L
.10664 .73299 L
.11139 .72824 L
.11636 .72328 L
.1211 .71853 L
.12607 .71356 L
.13081 .70882 L
.13578 .70385 L
.14052 .69911 L
.14549 .69414 L
.15024 .68939 L
.15521 .68443 L
.15995 .67968 L
.16492 .67471 L
.16966 .66997 L
.17463 .665 L
.17937 .66026 L
.18434 .65529 L
.18909 .65054 L
.19406 .64558 L
.1988 .64083 L
.20377 .63586 L
.20851 .63112 L
.21348 .62615 L
.21822 .62141 L
.22319 .61644 L
.22794 .61169 L
.23291 .60673 L
.23765 .60198 L
.24262 .59701 L
.24736 .59227 L
.25233 .5873 L
.25707 .58256 L
.26204 .57759 L
.26679 .57284 L
.27176 .56788 L
.2765 .56313 L
.28147 .55816 L
.28621 .55342 L
.29118 .54845 L
.29592 .54371 L
.30089 .53874 L
.30564 .53399 L
.31061 .52902 L
.31535 .52428 L
.32032 .51931 L
.32506 .51457 L
.33003 .5096 L
.33467 .50486 L
.33974 .49989 L
.34597 .49514 L
.34946 .49286 L
.35837 .48543 L
.35917 .48454 L
.3684 .47572 L
.36888 .47516 L
.37765 .46601 L
.37859 .46488 L
.38628 .45629 L
.38831 .45378 L
.3944 .44658 L
.39802 .44194 L
.40211 .43687 L
.40773 .42942 L
.40947 .42716 L
.41664 .41744 L
.41744 .41626 L
.42363 .40773 L
.42716 .40253 L
.43032 .39802 L
.43681 .38831 L
.43687 .38821 L
.44331 .37859 L
.44658 .37338 L
.44952 .36888 L
.45562 .35917 L
.45629 .35802 L
.46168 .34946 L
.46601 .34217 L
.4675 .33974 L
.47336 .33003 L
.47572 .32586 L
.47902 .32032 L
.4846 .31061 L
.48543 .30907 L
.49017 .30089 L
.49514 .29185 L
.49552 .29118 L
.50099 .28147 L
.50486 .2742 L
.50621 .27176 L
.51153 .26204 L
.51457 .25613 L
.51663 .25233 L
.5218 .24262 L
.52428 .23765 L
.5268 .23291 L
.53184 .22319 L
.53399 .21878 L
.53674 .21348 L
.54168 .20377 L
.54371 .19951 L
.54648 .19406 L
.55133 .18434 L
.55342 .17987 L
.55604 .17463 L
.56081 .16492 L
.56313 .15985 L
.56541 .15521 L
.57012 .14549 L
.57284 .13947 L
.57462 .13578 L
.57927 .12607 L
.58256 .11872 L
.58368 .11636 L
.58827 .10664 L
.59227 .09763 L
.5926 .09693 L
.59713 .08722 L
.60144 .07751 L
.60198 .0762 L
.60585 .06779 L
.61019 .05808 L
.61169 .05443 L
.61444 .04837 L
.61878 .03866 L
.62141 .03232 L
.62291 .02894 L
.62724 .01923 L
.01923 .01923 L
F
0 g
.01923 .8204 m
.02389 .81566 L
.02894 .81069 L
.03369 .80594 L
.03866 .80098 L
.0434 .79623 L
.04837 .79126 L
.05311 .78652 L
.05808 .78155 L
.06282 .77681 L
.06779 .77184 L
.07254 .76709 L
.07751 .76213 L
.08225 .75738 L
.08722 .75241 L
.09196 .74767 L
.09693 .7427 L
.10167 .73796 L
.10664 .73299 L
.11139 .72824 L
.11636 .72328 L
.1211 .71853 L
.12607 .71356 L
.13081 .70882 L
.13578 .70385 L
.14052 .69911 L
.14549 .69414 L
.15024 .68939 L
.15521 .68443 L
.15995 .67968 L
.16492 .67471 L
.16966 .66997 L
.17463 .665 L
.17937 .66026 L
.18434 .65529 L
.18909 .65054 L
.19406 .64558 L
.1988 .64083 L
.20377 .63586 L
.20851 .63112 L
.21348 .62615 L
.21822 .62141 L
.22319 .61644 L
.22794 .61169 L
.23291 .60673 L
.23765 .60198 L
.24262 .59701 L
.24736 .59227 L
.25233 .5873 L
.25707 .58256 L
Mistroke
.26204 .57759 L
.26679 .57284 L
.27176 .56788 L
.2765 .56313 L
.28147 .55816 L
.28621 .55342 L
.29118 .54845 L
.29592 .54371 L
.30089 .53874 L
.30564 .53399 L
.31061 .52902 L
.31535 .52428 L
.32032 .51931 L
.32506 .51457 L
.33003 .5096 L
.33467 .50486 L
.33974 .49989 L
.34597 .49514 L
.34946 .49286 L
.35837 .48543 L
.35917 .48454 L
.3684 .47572 L
.36888 .47516 L
.37765 .46601 L
.37859 .46488 L
.38628 .45629 L
.38831 .45378 L
.3944 .44658 L
.39802 .44194 L
.40211 .43687 L
.40773 .42942 L
.40947 .42716 L
.41664 .41744 L
.41744 .41626 L
.42363 .40773 L
.42716 .40253 L
.43032 .39802 L
.43681 .38831 L
.43687 .38821 L
.44331 .37859 L
.44658 .37338 L
.44952 .36888 L
.45562 .35917 L
.45629 .35802 L
.46168 .34946 L
.46601 .34217 L
.4675 .33974 L
.47336 .33003 L
.47572 .32586 L
.47902 .32032 L
Mistroke
.4846 .31061 L
.48543 .30907 L
.49017 .30089 L
.49514 .29185 L
.49552 .29118 L
.50099 .28147 L
.50486 .2742 L
.50621 .27176 L
.51153 .26204 L
.51457 .25613 L
.51663 .25233 L
.5218 .24262 L
.52428 .23765 L
.5268 .23291 L
.53184 .22319 L
.53399 .21878 L
.53674 .21348 L
.54168 .20377 L
.54371 .19951 L
.54648 .19406 L
.55133 .18434 L
.55342 .17987 L
.55604 .17463 L
.56081 .16492 L
.56313 .15985 L
.56541 .15521 L
.57012 .14549 L
.57284 .13947 L
.57462 .13578 L
.57927 .12607 L
.58256 .11872 L
.58368 .11636 L
.58827 .10664 L
.59227 .09763 L
.5926 .09693 L
.59713 .08722 L
.60144 .07751 L
.60198 .0762 L
.60585 .06779 L
.61019 .05808 L
.61169 .05443 L
.61444 .04837 L
.61878 .03866 L
.62141 .03232 L
.62291 .02894 L
.62724 .01923 L
Mfstroke
.4 g
.01923 .74177 m
.0234 .73796 L
.02894 .73206 L
.03276 .72824 L
.03866 .72235 L
.04247 .71853 L
.04837 .71263 L
.05218 .70882 L
.05808 .70292 L
.06189 .69911 L
.06779 .69321 L
.07161 .68939 L
.07751 .6835 L
.08132 .67968 L
.08722 .67378 L
.09103 .66997 L
.09693 .66407 L
.10074 .66026 L
.10664 .65436 L
.11046 .65054 L
.11636 .64465 L
.12017 .64083 L
.12607 .63493 L
.12988 .63112 L
.13578 .62522 L
.13959 .62141 L
.14549 .61551 L
.14931 .61169 L
.15521 .6058 L
.15902 .60198 L
.16492 .59608 L
.16873 .59227 L
.17463 .58637 L
.17844 .58256 L
.18434 .57666 L
.18816 .57284 L
.19406 .56695 L
.19787 .56313 L
.20377 .55723 L
.20758 .55342 L
.21348 .54752 L
.21729 .54371 L
.22319 .53781 L
.22701 .53399 L
.23291 .5281 L
.23672 .52428 L
.24262 .51838 L
.24643 .51457 L
.25233 .50867 L
.25614 .50486 L
.26204 .49896 L
.26586 .49514 L
.27176 .48924 L
.27557 .48543 L
.28147 .47953 L
.28528 .47572 L
.29118 .46982 L
.29499 .46601 L
.30089 .46011 L
.30471 .45629 L
.31061 .45039 L
.31442 .44658 L
.32032 .44068 L
.32413 .43687 L
.33003 .43097 L
.33414 .42716 L
.33974 .42126 L
.34272 .41744 L
.34946 .40817 L
.34978 .40773 L
.35693 .39802 L
.35917 .39495 L
.36399 .38831 L
.36888 .38151 L
.37096 .37859 L
.37783 .36888 L
.37859 .36779 L
.38455 .35917 L
.38831 .35368 L
.39116 .34946 L
.39768 .33974 L
.39802 .33924 L
.40405 .33003 L
.40773 .32438 L
.41032 .32032 L
.41652 .31061 L
.41744 .30915 L
.42257 .30089 L
.42716 .2935 L
.42856 .29118 L
.43446 .28147 L
.43687 .27747 L
.44024 .27176 L
.446 .26204 L
.44658 .26106 L
.45161 .25233 L
.45629 .24424 L
.4572 .24262 L
.46269 .23291 L
.46601 .22704 L
.46811 .22319 L
.4735 .21348 L
.47572 .20946 L
.47877 .20377 L
.48405 .19406 L
.48543 .19151 L
.4892 .18434 L
.49438 .17463 L
.49514 .17319 L
.49941 .16492 L
.50449 .15521 L
.50486 .15451 L
.50941 .14549 L
.5144 .13578 L
.51457 .13546 L
.51923 .12607 L
.52413 .11636 L
.52428 .11606 L
.52886 .10664 L
.53368 .09693 L
.53399 .0963 L
.53833 .08722 L
.54308 .07751 L
.54371 .07621 L
.54765 .06779 L
.55231 .05808 L
.55342 .05577 L
.55681 .04837 L
.56141 .03866 L
.56313 .035 L
.56585 .02894 L
.57036 .01923 L
.01923 .01923 L
F
0 g
.01923 .74177 m
.0234 .73796 L
.02894 .73206 L
.03276 .72824 L
.03866 .72235 L
.04247 .71853 L
.04837 .71263 L
.05218 .70882 L
.05808 .70292 L
.06189 .69911 L
.06779 .69321 L
.07161 .68939 L
.07751 .6835 L
.08132 .67968 L
.08722 .67378 L
.09103 .66997 L
.09693 .66407 L
.10074 .66026 L
.10664 .65436 L
.11046 .65054 L
.11636 .64465 L
.12017 .64083 L
.12607 .63493 L
.12988 .63112 L
.13578 .62522 L
.13959 .62141 L
.14549 .61551 L
.14931 .61169 L
.15521 .6058 L
.15902 .60198 L
.16492 .59608 L
.16873 .59227 L
.17463 .58637 L
.17844 .58256 L
.18434 .57666 L
.18816 .57284 L
.19406 .56695 L
.19787 .56313 L
.20377 .55723 L
.20758 .55342 L
.21348 .54752 L
.21729 .54371 L
.22319 .53781 L
.22701 .53399 L
.23291 .5281 L
.23672 .52428 L
.24262 .51838 L
.24643 .51457 L
.25233 .50867 L
.25614 .50486 L
Mistroke
.26204 .49896 L
.26586 .49514 L
.27176 .48924 L
.27557 .48543 L
.28147 .47953 L
.28528 .47572 L
.29118 .46982 L
.29499 .46601 L
.30089 .46011 L
.30471 .45629 L
.31061 .45039 L
.31442 .44658 L
.32032 .44068 L
.32413 .43687 L
.33003 .43097 L
.33414 .42716 L
.33974 .42126 L
.34272 .41744 L
.34946 .40817 L
.34978 .40773 L
.35693 .39802 L
.35917 .39495 L
.36399 .38831 L
.36888 .38151 L
.37096 .37859 L
.37783 .36888 L
.37859 .36779 L
.38455 .35917 L
.38831 .35368 L
.39116 .34946 L
.39768 .33974 L
.39802 .33924 L
.40405 .33003 L
.40773 .32438 L
.41032 .32032 L
.41652 .31061 L
.41744 .30915 L
.42257 .30089 L
.42716 .2935 L
.42856 .29118 L
.43446 .28147 L
.43687 .27747 L
.44024 .27176 L
.446 .26204 L
.44658 .26106 L
.45161 .25233 L
.45629 .24424 L
.4572 .24262 L
.46269 .23291 L
.46601 .22704 L
Mistroke
.46811 .22319 L
.4735 .21348 L
.47572 .20946 L
.47877 .20377 L
.48405 .19406 L
.48543 .19151 L
.4892 .18434 L
.49438 .17463 L
.49514 .17319 L
.49941 .16492 L
.50449 .15521 L
.50486 .15451 L
.50941 .14549 L
.5144 .13578 L
.51457 .13546 L
.51923 .12607 L
.52413 .11636 L
.52428 .11606 L
.52886 .10664 L
.53368 .09693 L
.53399 .0963 L
.53833 .08722 L
.54308 .07751 L
.54371 .07621 L
.54765 .06779 L
.55231 .05808 L
.55342 .05577 L
.55681 .04837 L
.56141 .03866 L
.56313 .035 L
.56585 .02894 L
.57036 .01923 L
Mfstroke
.5 g
.01923 .6981 m
.02794 .68939 L
.02894 .68839 L
.03765 .67968 L
.03866 .67868 L
.04736 .66997 L
.04837 .66896 L
.05708 .66026 L
.05808 .65925 L
.06679 .65054 L
.06779 .64954 L
.0765 .64083 L
.07751 .63983 L
.08621 .63112 L
.08722 .63011 L
.09593 .62141 L
.09693 .6204 L
.10564 .61169 L
.10664 .61069 L
.11535 .60198 L
.11636 .60098 L
.12506 .59227 L
.12607 .59126 L
.13478 .58256 L
.13578 .58155 L
.14449 .57284 L
.14549 .57184 L
.1542 .56313 L
.15521 .56213 L
.16391 .55342 L
.16492 .55241 L
.17363 .54371 L
.17463 .5427 L
.18334 .53399 L
.18434 .53299 L
.19305 .52428 L
.19406 .52328 L
.20276 .51457 L
.20377 .51356 L
.21248 .50486 L
.21348 .50385 L
.22219 .49514 L
.22319 .49414 L
.2319 .48543 L
.23291 .48443 L
.24161 .47572 L
.24262 .47471 L
.25133 .46601 L
.25233 .465 L
.26104 .45629 L
.26204 .45529 L
.27075 .44658 L
.27176 .44558 L
.28046 .43687 L
.28147 .43586 L
.29018 .42716 L
.29118 .42615 L
.29989 .41744 L
.30089 .41644 L
.3096 .40773 L
.31061 .40673 L
.31931 .39802 L
.32032 .39701 L
.32903 .38831 L
.33003 .3873 L
.33877 .37859 L
.33974 .37759 L
.34768 .36888 L
.34946 .36689 L
.35616 .35917 L
.35917 .3556 L
.36426 .34946 L
.36888 .34373 L
.37205 .33974 L
.37859 .33132 L
.37958 .33003 L
.38687 .32032 L
.38831 .31837 L
.39395 .31061 L
.39802 .3049 L
.40084 .30089 L
.40756 .29118 L
.40773 .29093 L
.41412 .28147 L
.41744 .27647 L
.42054 .27176 L
.42683 .26204 L
.42716 .26154 L
.433 .25233 L
.43687 .24615 L
.43905 .24262 L
.44501 .23291 L
.44658 .23031 L
.45086 .22319 L
.45629 .21403 L
.45662 .21348 L
.46229 .20377 L
.46601 .19733 L
.46788 .19406 L
.4734 .18434 L
.47572 .18021 L
.47883 .17463 L
.48421 .16492 L
.48543 .16269 L
.48951 .15521 L
.49475 .14549 L
.49514 .14477 L
.49993 .13578 L
.50486 .12646 L
.50506 .12607 L
.51012 .11636 L
.51457 .10776 L
.51514 .10664 L
.5201 .09693 L
.52428 .08869 L
.52502 .08722 L
.52989 .07751 L
.53399 .06926 L
.53472 .06779 L
.53949 .05808 L
.54371 .04946 L
.54424 .04837 L
.54893 .03866 L
.55342 .02931 L
.55359 .02894 L
.55821 .01923 L
.01923 .01923 L
F
0 g
.01923 .6981 m
.02794 .68939 L
.02894 .68839 L
.03765 .67968 L
.03866 .67868 L
.04736 .66997 L
.04837 .66896 L
.05708 .66026 L
.05808 .65925 L
.06679 .65054 L
.06779 .64954 L
.0765 .64083 L
.07751 .63983 L
.08621 .63112 L
.08722 .63011 L
.09593 .62141 L
.09693 .6204 L
.10564 .61169 L
.10664 .61069 L
.11535 .60198 L
.11636 .60098 L
.12506 .59227 L
.12607 .59126 L
.13478 .58256 L
.13578 .58155 L
.14449 .57284 L
.14549 .57184 L
.1542 .56313 L
.15521 .56213 L
.16391 .55342 L
.16492 .55241 L
.17363 .54371 L
.17463 .5427 L
.18334 .53399 L
.18434 .53299 L
.19305 .52428 L
.19406 .52328 L
.20276 .51457 L
.20377 .51356 L
.21248 .50486 L
.21348 .50385 L
.22219 .49514 L
.22319 .49414 L
.2319 .48543 L
.23291 .48443 L
.24161 .47572 L
.24262 .47471 L
.25133 .46601 L
.25233 .465 L
.26104 .45629 L
Mistroke
.26204 .45529 L
.27075 .44658 L
.27176 .44558 L
.28046 .43687 L
.28147 .43586 L
.29018 .42716 L
.29118 .42615 L
.29989 .41744 L
.30089 .41644 L
.3096 .40773 L
.31061 .40673 L
.31931 .39802 L
.32032 .39701 L
.32903 .38831 L
.33003 .3873 L
.33877 .37859 L
.33974 .37759 L
.34768 .36888 L
.34946 .36689 L
.35616 .35917 L
.35917 .3556 L
.36426 .34946 L
.36888 .34373 L
.37205 .33974 L
.37859 .33132 L
.37958 .33003 L
.38687 .32032 L
.38831 .31837 L
.39395 .31061 L
.39802 .3049 L
.40084 .30089 L
.40756 .29118 L
.40773 .29093 L
.41412 .28147 L
.41744 .27647 L
.42054 .27176 L
.42683 .26204 L
.42716 .26154 L
.433 .25233 L
.43687 .24615 L
.43905 .24262 L
.44501 .23291 L
.44658 .23031 L
.45086 .22319 L
.45629 .21403 L
.45662 .21348 L
.46229 .20377 L
.46601 .19733 L
.46788 .19406 L
.4734 .18434 L
Mistroke
.47572 .18021 L
.47883 .17463 L
.48421 .16492 L
.48543 .16269 L
.48951 .15521 L
.49475 .14549 L
.49514 .14477 L
.49993 .13578 L
.50486 .12646 L
.50506 .12607 L
.51012 .11636 L
.51457 .10776 L
.51514 .10664 L
.5201 .09693 L
.52428 .08869 L
.52502 .08722 L
.52989 .07751 L
.53399 .06926 L
.53472 .06779 L
.53949 .05808 L
.54371 .04946 L
.54424 .04837 L
.54893 .03866 L
.55342 .02931 L
.55359 .02894 L
.55821 .01923 L
Mfstroke
.6 g
.01923 .66269 m
.02166 .66026 L
.02894 .65298 L
.03138 .65054 L
.03866 .64326 L
.04109 .64083 L
.04837 .63355 L
.0508 .63112 L
.05808 .62384 L
.06051 .62141 L
.06779 .61413 L
.07023 .61169 L
.07751 .60441 L
.07994 .60198 L
.08722 .5947 L
.08965 .59227 L
.09693 .58499 L
.09936 .58256 L
.10664 .57528 L
.10908 .57284 L
.11636 .56556 L
.11879 .56313 L
.12607 .55585 L
.1285 .55342 L
.13578 .54614 L
.13821 .54371 L
.14549 .53643 L
.14793 .53399 L
.15521 .52671 L
.15764 .52428 L
.16492 .517 L
.16735 .51457 L
.17463 .50729 L
.17706 .50486 L
.18434 .49758 L
.18678 .49514 L
.19406 .48786 L
.19649 .48543 L
.20377 .47815 L
.2062 .47572 L
.21348 .46844 L
.21591 .46601 L
.22319 .45873 L
.22563 .45629 L
.23291 .44901 L
.23534 .44658 L
.24262 .4393 L
.24505 .43687 L
.25233 .42959 L
.25476 .42716 L
.26204 .41988 L
.26448 .41744 L
.27176 .41016 L
.27419 .40773 L
.28147 .40045 L
.2839 .39802 L
.29118 .39074 L
.29361 .38831 L
.30089 .38103 L
.30333 .37859 L
.31061 .37131 L
.31304 .36888 L
.32032 .3616 L
.32275 .35917 L
.33003 .35189 L
.33248 .34946 L
.33974 .34218 L
.34222 .33974 L
.34946 .33273 L
.35211 .33003 L
.35917 .32251 L
.36117 .32032 L
.36888 .31156 L
.36971 .31061 L
.37783 .30089 L
.37859 .29995 L
.38562 .29118 L
.38831 .28771 L
.3931 .28147 L
.39802 .27488 L
.40033 .27176 L
.40734 .26204 L
.40773 .26149 L
.41417 .25233 L
.41744 .24756 L
.42081 .24262 L
.42716 .23311 L
.42729 .23291 L
.43365 .22319 L
.43687 .21816 L
.43986 .21348 L
.44594 .20377 L
.44658 .20273 L
.45194 .19406 L
.45629 .18684 L
.4578 .18434 L
.46359 .17463 L
.46601 .1705 L
.46928 .16492 L
.47488 .15521 L
.47572 .15372 L
.48041 .14549 L
.48543 .13651 L
.48584 .13578 L
.49123 .12607 L
.49514 .11889 L
.49653 .11636 L
.50178 .10664 L
.50486 .10086 L
.50695 .09693 L
.51208 .08722 L
.51457 .08244 L
.51714 .07751 L
.52216 .06779 L
.52428 .06362 L
.52712 .05808 L
.53203 .04837 L
.53399 .04443 L
.53689 .03866 L
.54171 .02894 L
.54371 .02486 L
.54648 .01923 L
.01923 .01923 L
F
0 g
.01923 .66269 m
.02166 .66026 L
.02894 .65298 L
.03138 .65054 L
.03866 .64326 L
.04109 .64083 L
.04837 .63355 L
.0508 .63112 L
.05808 .62384 L
.06051 .62141 L
.06779 .61413 L
.07023 .61169 L
.07751 .60441 L
.07994 .60198 L
.08722 .5947 L
.08965 .59227 L
.09693 .58499 L
.09936 .58256 L
.10664 .57528 L
.10908 .57284 L
.11636 .56556 L
.11879 .56313 L
.12607 .55585 L
.1285 .55342 L
.13578 .54614 L
.13821 .54371 L
.14549 .53643 L
.14793 .53399 L
.15521 .52671 L
.15764 .52428 L
.16492 .517 L
.16735 .51457 L
.17463 .50729 L
.17706 .50486 L
.18434 .49758 L
.18678 .49514 L
.19406 .48786 L
.19649 .48543 L
.20377 .47815 L
.2062 .47572 L
.21348 .46844 L
.21591 .46601 L
.22319 .45873 L
.22563 .45629 L
.23291 .44901 L
.23534 .44658 L
.24262 .4393 L
.24505 .43687 L
.25233 .42959 L
.25476 .42716 L
Mistroke
.26204 .41988 L
.26448 .41744 L
.27176 .41016 L
.27419 .40773 L
.28147 .40045 L
.2839 .39802 L
.29118 .39074 L
.29361 .38831 L
.30089 .38103 L
.30333 .37859 L
.31061 .37131 L
.31304 .36888 L
.32032 .3616 L
.32275 .35917 L
.33003 .35189 L
.33248 .34946 L
.33974 .34218 L
.34222 .33974 L
.34946 .33273 L
.35211 .33003 L
.35917 .32251 L
.36117 .32032 L
.36888 .31156 L
.36971 .31061 L
.37783 .30089 L
.37859 .29995 L
.38562 .29118 L
.38831 .28771 L
.3931 .28147 L
.39802 .27488 L
.40033 .27176 L
.40734 .26204 L
.40773 .26149 L
.41417 .25233 L
.41744 .24756 L
.42081 .24262 L
.42716 .23311 L
.42729 .23291 L
.43365 .22319 L
.43687 .21816 L
.43986 .21348 L
.44594 .20377 L
.44658 .20273 L
.45194 .19406 L
.45629 .18684 L
.4578 .18434 L
.46359 .17463 L
.46601 .1705 L
.46928 .16492 L
.47488 .15521 L
Mistroke
.47572 .15372 L
.48041 .14549 L
.48543 .13651 L
.48584 .13578 L
.49123 .12607 L
.49514 .11889 L
.49653 .11636 L
.50178 .10664 L
.50486 .10086 L
.50695 .09693 L
.51208 .08722 L
.51457 .08244 L
.51714 .07751 L
.52216 .06779 L
.52428 .06362 L
.52712 .05808 L
.53203 .04837 L
.53399 .04443 L
.53689 .03866 L
.54171 .02894 L
.54371 .02486 L
.54648 .01923 L
Mfstroke
.7 g
.01923 .61901 m
.02648 .61169 L
.02894 .6093 L
.03626 .60198 L
.03866 .59959 L
.04598 .59227 L
.04837 .58988 L
.05569 .58256 L
.05808 .58016 L
.0654 .57284 L
.06779 .57045 L
.07511 .56313 L
.07751 .56074 L
.08483 .55342 L
.08722 .55103 L
.09454 .54371 L
.09693 .54131 L
.10425 .53399 L
.10664 .5316 L
.11396 .52428 L
.11636 .52189 L
.12368 .51457 L
.12607 .51218 L
.13339 .50486 L
.13578 .50246 L
.1431 .49514 L
.14549 .49275 L
.15281 .48543 L
.15521 .48304 L
.16253 .47572 L
.16492 .47333 L
.17224 .46601 L
.17463 .46361 L
.18195 .45629 L
.18434 .4539 L
.19166 .44658 L
.19406 .44419 L
.20138 .43687 L
.20377 .43448 L
.21109 .42716 L
.21348 .42476 L
.2208 .41744 L
.22319 .41505 L
.23051 .40773 L
.23291 .40534 L
.24023 .39802 L
.24262 .39563 L
.24994 .38831 L
.25233 .38591 L
.25965 .37859 L
.26204 .3762 L
.26936 .36888 L
.27176 .36649 L
.27908 .35917 L
.28147 .35678 L
.28879 .34946 L
.29118 .34706 L
.2985 .33974 L
.30089 .33735 L
.30821 .33003 L
.31061 .32764 L
.31793 .32032 L
.32032 .31793 L
.32764 .31061 L
.33003 .30821 L
.33724 .30089 L
.33974 .2985 L
.34946 .29145 L
.34981 .29118 L
.35917 .28315 L
.36107 .28147 L
.36888 .27378 L
.37093 .27176 L
.37859 .26349 L
.37993 .26204 L
.38831 .25238 L
.38835 .25233 L
.39646 .24262 L
.39802 .24055 L
.40413 .23291 L
.40773 .22804 L
.41144 .22319 L
.41744 .21488 L
.41847 .21348 L
.42541 .20377 L
.42716 .20114 L
.43211 .19406 L
.43687 .18683 L
.43855 .18434 L
.44496 .17463 L
.44658 .17199 L
.45118 .16492 L
.45629 .15663 L
.4572 .15521 L
.46325 .14549 L
.46601 .14079 L
.46908 .13578 L
.47483 .12607 L
.47572 .12447 L
.48054 .11636 L
.48543 .10769 L
.48604 .10664 L
.49164 .09693 L
.49514 .09047 L
.49699 .08722 L
.5024 .07751 L
.50486 .07282 L
.50764 .06779 L
.51288 .05808 L
.51457 .05475 L
.51802 .04837 L
.52311 .03866 L
.52428 .03627 L
.52816 .02894 L
.53312 .01923 L
.01923 .01923 L
F
0 g
.01923 .61901 m
.02648 .61169 L
.02894 .6093 L
.03626 .60198 L
.03866 .59959 L
.04598 .59227 L
.04837 .58988 L
.05569 .58256 L
.05808 .58016 L
.0654 .57284 L
.06779 .57045 L
.07511 .56313 L
.07751 .56074 L
.08483 .55342 L
.08722 .55103 L
.09454 .54371 L
.09693 .54131 L
.10425 .53399 L
.10664 .5316 L
.11396 .52428 L
.11636 .52189 L
.12368 .51457 L
.12607 .51218 L
.13339 .50486 L
.13578 .50246 L
.1431 .49514 L
.14549 .49275 L
.15281 .48543 L
.15521 .48304 L
.16253 .47572 L
.16492 .47333 L
.17224 .46601 L
.17463 .46361 L
.18195 .45629 L
.18434 .4539 L
.19166 .44658 L
.19406 .44419 L
.20138 .43687 L
.20377 .43448 L
.21109 .42716 L
.21348 .42476 L
.2208 .41744 L
.22319 .41505 L
.23051 .40773 L
.23291 .40534 L
.24023 .39802 L
.24262 .39563 L
.24994 .38831 L
.25233 .38591 L
.25965 .37859 L
Mistroke
.26204 .3762 L
.26936 .36888 L
.27176 .36649 L
.27908 .35917 L
.28147 .35678 L
.28879 .34946 L
.29118 .34706 L
.2985 .33974 L
.30089 .33735 L
.30821 .33003 L
.31061 .32764 L
.31793 .32032 L
.32032 .31793 L
.32764 .31061 L
.33003 .30821 L
.33724 .30089 L
.33974 .2985 L
.34946 .29145 L
.34981 .29118 L
.35917 .28315 L
.36107 .28147 L
.36888 .27378 L
.37093 .27176 L
.37859 .26349 L
.37993 .26204 L
.38831 .25238 L
.38835 .25233 L
.39646 .24262 L
.39802 .24055 L
.40413 .23291 L
.40773 .22804 L
.41144 .22319 L
.41744 .21488 L
.41847 .21348 L
.42541 .20377 L
.42716 .20114 L
.43211 .19406 L
.43687 .18683 L
.43855 .18434 L
.44496 .17463 L
.44658 .17199 L
.45118 .16492 L
.45629 .15663 L
.4572 .15521 L
.46325 .14549 L
.46601 .14079 L
.46908 .13578 L
.47483 .12607 L
.47572 .12447 L
.48054 .11636 L
Mistroke
.48543 .10769 L
.48604 .10664 L
.49164 .09693 L
.49514 .09047 L
.49699 .08722 L
.5024 .07751 L
.50486 .07282 L
.50764 .06779 L
.51288 .05808 L
.51457 .05475 L
.51802 .04837 L
.52311 .03866 L
.52428 .03627 L
.52816 .02894 L
.53312 .01923 L
Mfstroke
.6 g
.01923 .5404 m
.02582 .53399 L
.02894 .53069 L
.03535 .52428 L
.03866 .52098 L
.04506 .51457 L
.04837 .51126 L
.05477 .50486 L
.05808 .50155 L
.06449 .49514 L
.06779 .49184 L
.0742 .48543 L
.07751 .48213 L
.08391 .47572 L
.08722 .47241 L
.09362 .46601 L
.09693 .4627 L
.10334 .45629 L
.10664 .45299 L
.11305 .44658 L
.11636 .44328 L
.12276 .43687 L
.12607 .43356 L
.13247 .42716 L
.13578 .42385 L
.14219 .41744 L
.14549 .41414 L
.1519 .40773 L
.15521 .40443 L
.16161 .39802 L
.16492 .39471 L
.17132 .38831 L
.17463 .385 L
.18104 .37859 L
.18434 .37529 L
.19075 .36888 L
.19406 .36557 L
.20046 .35917 L
.20377 .35586 L
.21017 .34946 L
.21348 .34615 L
.21989 .33974 L
.22319 .33644 L
.2296 .33003 L
.23291 .32672 L
.23931 .32032 L
.24262 .31701 L
.24902 .31061 L
.25233 .3073 L
.25874 .30089 L
.26204 .29759 L
.26845 .29118 L
.27176 .28787 L
.27816 .28147 L
.28147 .27816 L
.28787 .27176 L
.29118 .26845 L
.29759 .26204 L
.30089 .25874 L
.3073 .25233 L
.31061 .24902 L
.31701 .24262 L
.32032 .23931 L
.32672 .23291 L
.33003 .2296 L
.33671 .22319 L
.33974 .21989 L
.34462 .21348 L
.34946 .20676 L
.35167 .20377 L
.35882 .19406 L
.35917 .19358 L
.36585 .18434 L
.36888 .18012 L
.37278 .17463 L
.37859 .16639 L
.37962 .16492 L
.38632 .15521 L
.38831 .15231 L
.39289 .14549 L
.39802 .13784 L
.39937 .13578 L
.40574 .12607 L
.40773 .123 L
.41197 .11636 L
.41744 .10776 L
.41814 .10664 L
.42418 .09693 L
.42716 .09212 L
.43012 .08722 L
.43602 .07751 L
.43687 .0761 L
.44177 .06779 L
.44658 .05967 L
.44749 .05808 L
.45311 .04837 L
.45629 .04285 L
.45864 .03866 L
.46415 .02894 L
.46601 .02569 L
.46953 .01923 L
.01923 .01923 L
F
0 g
.01923 .5404 m
.02582 .53399 L
.02894 .53069 L
.03535 .52428 L
.03866 .52098 L
.04506 .51457 L
.04837 .51126 L
.05477 .50486 L
.05808 .50155 L
.06449 .49514 L
.06779 .49184 L
.0742 .48543 L
.07751 .48213 L
.08391 .47572 L
.08722 .47241 L
.09362 .46601 L
.09693 .4627 L
.10334 .45629 L
.10664 .45299 L
.11305 .44658 L
.11636 .44328 L
.12276 .43687 L
.12607 .43356 L
.13247 .42716 L
.13578 .42385 L
.14219 .41744 L
.14549 .41414 L
.1519 .40773 L
.15521 .40443 L
.16161 .39802 L
.16492 .39471 L
.17132 .38831 L
.17463 .385 L
.18104 .37859 L
.18434 .37529 L
.19075 .36888 L
.19406 .36557 L
.20046 .35917 L
.20377 .35586 L
.21017 .34946 L
.21348 .34615 L
.21989 .33974 L
.22319 .33644 L
.2296 .33003 L
.23291 .32672 L
.23931 .32032 L
.24262 .31701 L
.24902 .31061 L
.25233 .3073 L
.25874 .30089 L
Mistroke
.26204 .29759 L
.26845 .29118 L
.27176 .28787 L
.27816 .28147 L
.28147 .27816 L
.28787 .27176 L
.29118 .26845 L
.29759 .26204 L
.30089 .25874 L
.3073 .25233 L
.31061 .24902 L
.31701 .24262 L
.32032 .23931 L
.32672 .23291 L
.33003 .2296 L
.33671 .22319 L
.33974 .21989 L
.34462 .21348 L
.34946 .20676 L
.35167 .20377 L
.35882 .19406 L
.35917 .19358 L
.36585 .18434 L
.36888 .18012 L
.37278 .17463 L
.37859 .16639 L
.37962 .16492 L
.38632 .15521 L
.38831 .15231 L
.39289 .14549 L
.39802 .13784 L
.39937 .13578 L
.40574 .12607 L
.40773 .123 L
.41197 .11636 L
.41744 .10776 L
.41814 .10664 L
.42418 .09693 L
.42716 .09212 L
.43012 .08722 L
.43602 .07751 L
.43687 .0761 L
.44177 .06779 L
.44658 .05967 L
.44749 .05808 L
.45311 .04837 L
.45629 .04285 L
.45864 .03866 L
.46415 .02894 L
.46601 .02569 L
Mistroke
.46953 .01923 L
Mfstroke
.5 g
.01923 .49672 m
.02081 .49514 L
.02894 .487 L
.03052 .48543 L
.03866 .47729 L
.04023 .47572 L
.04837 .46758 L
.04994 .46601 L
.05808 .45787 L
.05965 .45629 L
.06779 .44815 L
.06937 .44658 L
.07751 .43844 L
.07908 .43687 L
.08722 .42873 L
.08879 .42716 L
.09693 .41902 L
.0985 .41744 L
.10664 .4093 L
.10822 .40773 L
.11636 .39959 L
.11793 .39802 L
.12607 .38988 L
.12764 .38831 L
.13578 .38017 L
.13735 .37859 L
.14549 .37045 L
.14707 .36888 L
.15521 .36074 L
.15678 .35917 L
.16492 .35103 L
.16649 .34946 L
.17463 .34132 L
.1762 .33974 L
.18434 .3316 L
.18592 .33003 L
.19406 .32189 L
.19563 .32032 L
.20377 .31218 L
.20534 .31061 L
.21348 .30247 L
.21505 .30089 L
.22319 .29275 L
.22477 .29118 L
.23291 .28304 L
.23448 .28147 L
.24262 .27333 L
.24419 .27176 L
.25233 .26362 L
.2539 .26204 L
.26204 .2539 L
.26362 .25233 L
.27176 .24419 L
.27333 .24262 L
.28147 .23448 L
.28304 .23291 L
.29118 .22477 L
.29275 .22319 L
.30089 .21505 L
.30247 .21348 L
.31061 .20534 L
.31218 .20377 L
.32032 .19563 L
.32189 .19406 L
.33003 .18592 L
.33164 .18434 L
.33974 .1762 L
.34121 .17463 L
.34946 .1655 L
.34997 .16492 L
.35834 .15521 L
.35917 .15421 L
.36636 .14549 L
.36888 .14235 L
.37408 .13578 L
.37859 .12994 L
.38154 .12607 L
.38831 .11699 L
.38877 .11636 L
.3958 .10664 L
.39802 .10352 L
.40264 .09693 L
.40773 .08954 L
.40932 .08722 L
.41584 .07751 L
.41744 .07509 L
.42222 .06779 L
.42716 .06015 L
.42848 .05808 L
.43462 .04837 L
.43687 .04476 L
.44064 .03866 L
.44657 .02894 L
.44658 .02892 L
.45239 .01923 L
.01923 .01923 L
F
0 g
.01923 .49672 m
.02081 .49514 L
.02894 .487 L
.03052 .48543 L
.03866 .47729 L
.04023 .47572 L
.04837 .46758 L
.04994 .46601 L
.05808 .45787 L
.05965 .45629 L
.06779 .44815 L
.06937 .44658 L
.07751 .43844 L
.07908 .43687 L
.08722 .42873 L
.08879 .42716 L
.09693 .41902 L
.0985 .41744 L
.10664 .4093 L
.10822 .40773 L
.11636 .39959 L
.11793 .39802 L
.12607 .38988 L
.12764 .38831 L
.13578 .38017 L
.13735 .37859 L
.14549 .37045 L
.14707 .36888 L
.15521 .36074 L
.15678 .35917 L
.16492 .35103 L
.16649 .34946 L
.17463 .34132 L
.1762 .33974 L
.18434 .3316 L
.18592 .33003 L
.19406 .32189 L
.19563 .32032 L
.20377 .31218 L
.20534 .31061 L
.21348 .30247 L
.21505 .30089 L
.22319 .29275 L
.22477 .29118 L
.23291 .28304 L
.23448 .28147 L
.24262 .27333 L
.24419 .27176 L
.25233 .26362 L
.2539 .26204 L
Mistroke
.26204 .2539 L
.26362 .25233 L
.27176 .24419 L
.27333 .24262 L
.28147 .23448 L
.28304 .23291 L
.29118 .22477 L
.29275 .22319 L
.30089 .21505 L
.30247 .21348 L
.31061 .20534 L
.31218 .20377 L
.32032 .19563 L
.32189 .19406 L
.33003 .18592 L
.33164 .18434 L
.33974 .1762 L
.34121 .17463 L
.34946 .1655 L
.34997 .16492 L
.35834 .15521 L
.35917 .15421 L
.36636 .14549 L
.36888 .14235 L
.37408 .13578 L
.37859 .12994 L
.38154 .12607 L
.38831 .11699 L
.38877 .11636 L
.3958 .10664 L
.39802 .10352 L
.40264 .09693 L
.40773 .08954 L
.40932 .08722 L
.41584 .07751 L
.41744 .07509 L
.42222 .06779 L
.42716 .06015 L
.42848 .05808 L
.43462 .04837 L
.43687 .04476 L
.44064 .03866 L
.44657 .02894 L
.44658 .02892 L
.45239 .01923 L
Mfstroke
.4 g
.01923 .46131 m
.02424 .45629 L
.02894 .45159 L
.03396 .44658 L
.03866 .44188 L
.04367 .43687 L
.04837 .43217 L
.05338 .42716 L
.05808 .42246 L
.06309 .41744 L
.06779 .41274 L
.07281 .40773 L
.07751 .40303 L
.08252 .39802 L
.08722 .39332 L
.09223 .38831 L
.09693 .38361 L
.10194 .37859 L
.10664 .37389 L
.11166 .36888 L
.11636 .36418 L
.12137 .35917 L
.12607 .35447 L
.13108 .34946 L
.13578 .34476 L
.14079 .33974 L
.14549 .33504 L
.15051 .33003 L
.15521 .32533 L
.16022 .32032 L
.16492 .31562 L
.16993 .31061 L
.17463 .30591 L
.17964 .30089 L
.18434 .29619 L
.18936 .29118 L
.19406 .28648 L
.19907 .28147 L
.20377 .27677 L
.20878 .27176 L
.21348 .26706 L
.21849 .26204 L
.22319 .25734 L
.22821 .25233 L
.23291 .24763 L
.23792 .24262 L
.24262 .23792 L
.24763 .23291 L
.25233 .22821 L
.25734 .22319 L
.26204 .21849 L
.26706 .21348 L
.27176 .20878 L
.27677 .20377 L
.28147 .19907 L
.28648 .19406 L
.29118 .18936 L
.29619 .18434 L
.30089 .17964 L
.30591 .17463 L
.31061 .16993 L
.31562 .16492 L
.32032 .16022 L
.32533 .15521 L
.33003 .15051 L
.33506 .14549 L
.33974 .14079 L
.34487 .13578 L
.34946 .13135 L
.35459 .12607 L
.35917 .12112 L
.3635 .11636 L
.36888 .11018 L
.37191 .10664 L
.37859 .09857 L
.37993 .09693 L
.38762 .08722 L
.38831 .08633 L
.39505 .07751 L
.39802 .0735 L
.40222 .06779 L
.40773 .0601 L
.40917 .05808 L
.41595 .04837 L
.41744 .04617 L
.42255 .03866 L
.42716 .03172 L
.42899 .02894 L
.43531 .01923 L
.01923 .01923 L
F
0 g
.01923 .46131 m
.02424 .45629 L
.02894 .45159 L
.03396 .44658 L
.03866 .44188 L
.04367 .43687 L
.04837 .43217 L
.05338 .42716 L
.05808 .42246 L
.06309 .41744 L
.06779 .41274 L
.07281 .40773 L
.07751 .40303 L
.08252 .39802 L
.08722 .39332 L
.09223 .38831 L
.09693 .38361 L
.10194 .37859 L
.10664 .37389 L
.11166 .36888 L
.11636 .36418 L
.12137 .35917 L
.12607 .35447 L
.13108 .34946 L
.13578 .34476 L
.14079 .33974 L
.14549 .33504 L
.15051 .33003 L
.15521 .32533 L
.16022 .32032 L
.16492 .31562 L
.16993 .31061 L
.17463 .30591 L
.17964 .30089 L
.18434 .29619 L
.18936 .29118 L
.19406 .28648 L
.19907 .28147 L
.20377 .27677 L
.20878 .27176 L
.21348 .26706 L
.21849 .26204 L
.22319 .25734 L
.22821 .25233 L
.23291 .24763 L
.23792 .24262 L
.24262 .23792 L
.24763 .23291 L
.25233 .22821 L
.25734 .22319 L
Mistroke
.26204 .21849 L
.26706 .21348 L
.27176 .20878 L
.27677 .20377 L
.28147 .19907 L
.28648 .19406 L
.29118 .18936 L
.29619 .18434 L
.30089 .17964 L
.30591 .17463 L
.31061 .16993 L
.31562 .16492 L
.32032 .16022 L
.32533 .15521 L
.33003 .15051 L
.33506 .14549 L
.33974 .14079 L
.34487 .13578 L
.34946 .13135 L
.35459 .12607 L
.35917 .12112 L
.3635 .11636 L
.36888 .11018 L
.37191 .10664 L
.37859 .09857 L
.37993 .09693 L
.38762 .08722 L
.38831 .08633 L
.39505 .07751 L
.39802 .0735 L
.40222 .06779 L
.40773 .0601 L
.40917 .05808 L
.41595 .04837 L
.41744 .04617 L
.42255 .03866 L
.42716 .03172 L
.42899 .02894 L
.43531 .01923 L
Mfstroke
.3 g
.01923 .41759 m
.01937 .41744 L
.02894 .40787 L
.02909 .40773 L
.03866 .39816 L
.0388 .39802 L
.04837 .38845 L
.04851 .38831 L
.05808 .37874 L
.05822 .37859 L
.06779 .36902 L
.06794 .36888 L
.07751 .35931 L
.07765 .35917 L
.08722 .3496 L
.08736 .34946 L
.09693 .33989 L
.09707 .33974 L
.10664 .33017 L
.10679 .33003 L
.11636 .32046 L
.1165 .32032 L
.12607 .31075 L
.12621 .31061 L
.13578 .30104 L
.13592 .30089 L
.14549 .29132 L
.14564 .29118 L
.15521 .28161 L
.15535 .28147 L
.16492 .2719 L
.16506 .27176 L
.17463 .26219 L
.17477 .26204 L
.18434 .25247 L
.18449 .25233 L
.19406 .24276 L
.1942 .24262 L
.20377 .23305 L
.20391 .23291 L
.21348 .22334 L
.21362 .22319 L
.22319 .21362 L
.22334 .21348 L
.23291 .20391 L
.23305 .20377 L
.24262 .1942 L
.24276 .19406 L
.25233 .18449 L
.25247 .18434 L
.26204 .17477 L
.26219 .17463 L
.27176 .16506 L
.2719 .16492 L
.28147 .15535 L
.28161 .15521 L
.29118 .14564 L
.29132 .14549 L
.30089 .13592 L
.30104 .13578 L
.31061 .12621 L
.31075 .12607 L
.32032 .1165 L
.32046 .11636 L
.33003 .10679 L
.33017 .10664 L
.33974 .09707 L
.33991 .09693 L
.34946 .09008 L
.35321 .08722 L
.35917 .08178 L
.36392 .07751 L
.36888 .07241 L
.37348 .06779 L
.37859 .06212 L
.3823 .05808 L
.38831 .05101 L
.39058 .04837 L
.39802 .03916 L
.39843 .03866 L
.40608 .02894 L
.40773 .02663 L
.41337 .01923 L
.01923 .01923 L
F
0 g
.01923 .41759 m
.01937 .41744 L
.02894 .40787 L
.02909 .40773 L
.03866 .39816 L
.0388 .39802 L
.04837 .38845 L
.04851 .38831 L
.05808 .37874 L
.05822 .37859 L
.06779 .36902 L
.06794 .36888 L
.07751 .35931 L
.07765 .35917 L
.08722 .3496 L
.08736 .34946 L
.09693 .33989 L
.09707 .33974 L
.10664 .33017 L
.10679 .33003 L
.11636 .32046 L
.1165 .32032 L
.12607 .31075 L
.12621 .31061 L
.13578 .30104 L
.13592 .30089 L
.14549 .29132 L
.14564 .29118 L
.15521 .28161 L
.15535 .28147 L
.16492 .2719 L
.16506 .27176 L
.17463 .26219 L
.17477 .26204 L
.18434 .25247 L
.18449 .25233 L
.19406 .24276 L
.1942 .24262 L
.20377 .23305 L
.20391 .23291 L
.21348 .22334 L
.21362 .22319 L
.22319 .21362 L
.22334 .21348 L
.23291 .20391 L
.23305 .20377 L
.24262 .1942 L
.24276 .19406 L
.25233 .18449 L
.25247 .18434 L
Mistroke
.26204 .17477 L
.26219 .17463 L
.27176 .16506 L
.2719 .16492 L
.28147 .15535 L
.28161 .15521 L
.29118 .14564 L
.29132 .14549 L
.30089 .13592 L
.30104 .13578 L
.31061 .12621 L
.31075 .12607 L
.32032 .1165 L
.32046 .11636 L
.33003 .10679 L
.33017 .10664 L
.33974 .09707 L
.33991 .09693 L
.34946 .09008 L
.35321 .08722 L
.35917 .08178 L
.36392 .07751 L
.36888 .07241 L
.37348 .06779 L
.37859 .06212 L
.3823 .05808 L
.38831 .05101 L
.39058 .04837 L
.39802 .03916 L
.39843 .03866 L
.40608 .02894 L
.40773 .02663 L
.41337 .01923 L
Mfstroke
.4 g
.01923 .33904 m
.02827 .33003 L
.02894 .32933 L
.03796 .32032 L
.03866 .31962 L
.04767 .31061 L
.04837 .30991 L
.05738 .30089 L
.05808 .30019 L
.06709 .29118 L
.06779 .29048 L
.07681 .28147 L
.07751 .28077 L
.08652 .27176 L
.08722 .27106 L
.09623 .26204 L
.09693 .26134 L
.10594 .25233 L
.10664 .25163 L
.11566 .24262 L
.11636 .24192 L
.12537 .23291 L
.12607 .23221 L
.13508 .22319 L
.13578 .22249 L
.14479 .21348 L
.14549 .21278 L
.15451 .20377 L
.15521 .20307 L
.16422 .19406 L
.16492 .19336 L
.17393 .18434 L
.17463 .18364 L
.18364 .17463 L
.18434 .17393 L
.19336 .16492 L
.19406 .16422 L
.20307 .15521 L
.20377 .15451 L
.21278 .14549 L
.21348 .14479 L
.22249 .13578 L
.22319 .13508 L
.23221 .12607 L
.23291 .12537 L
.24192 .11636 L
.24262 .11566 L
.25163 .10664 L
.25233 .10594 L
.26134 .09693 L
.26204 .09623 L
.27106 .08722 L
.27176 .08652 L
.28077 .07751 L
.28147 .07681 L
.29048 .06779 L
.29118 .06709 L
.30019 .05808 L
.30089 .05738 L
.30991 .04837 L
.31061 .04767 L
.31962 .03866 L
.32032 .03796 L
.32933 .02894 L
.33003 .02827 L
.33912 .01923 L
.01923 .01923 L
F
0 g
.01923 .33904 m
.02827 .33003 L
.02894 .32933 L
.03796 .32032 L
.03866 .31962 L
.04767 .31061 L
.04837 .30991 L
.05738 .30089 L
.05808 .30019 L
.06709 .29118 L
.06779 .29048 L
.07681 .28147 L
.07751 .28077 L
.08652 .27176 L
.08722 .27106 L
.09623 .26204 L
.09693 .26134 L
.10594 .25233 L
.10664 .25163 L
.11566 .24262 L
.11636 .24192 L
.12537 .23291 L
.12607 .23221 L
.13508 .22319 L
.13578 .22249 L
.14479 .21348 L
.14549 .21278 L
.15451 .20377 L
.15521 .20307 L
.16422 .19406 L
.16492 .19336 L
.17393 .18434 L
.17463 .18364 L
.18364 .17463 L
.18434 .17393 L
.19336 .16492 L
.19406 .16422 L
.20307 .15521 L
.20377 .15451 L
.21278 .14549 L
.21348 .14479 L
.22249 .13578 L
.22319 .13508 L
.23221 .12607 L
.23291 .12537 L
.24192 .11636 L
.24262 .11566 L
.25163 .10664 L
.25233 .10594 L
.26134 .09693 L
Mistroke
.26204 .09623 L
.27106 .08722 L
.27176 .08652 L
.28077 .07751 L
.28147 .07681 L
.29048 .06779 L
.29118 .06709 L
.30019 .05808 L
.30089 .05738 L
.30991 .04837 L
.31061 .04767 L
.31962 .03866 L
.32032 .03796 L
.32933 .02894 L
.33003 .02827 L
.33912 .01923 L
Mfstroke
.5 g
.01923 .29533 m
.02339 .29118 L
.02894 .28562 L
.03309 .28147 L
.03866 .27591 L
.04281 .27176 L
.04837 .26619 L
.05252 .26204 L
.05808 .25648 L
.06223 .25233 L
.06779 .24677 L
.07194 .24262 L
.07751 .23706 L
.08166 .23291 L
.08722 .22734 L
.09137 .22319 L
.09693 .21763 L
.10108 .21348 L
.10664 .20792 L
.11079 .20377 L
.11636 .19821 L
.12051 .19406 L
.12607 .18849 L
.13022 .18434 L
.13578 .17878 L
.13993 .17463 L
.14549 .16907 L
.14964 .16492 L
.15521 .15936 L
.15936 .15521 L
.16492 .14964 L
.16907 .14549 L
.17463 .13993 L
.17878 .13578 L
.18434 .13022 L
.18849 .12607 L
.19406 .12051 L
.19821 .11636 L
.20377 .11079 L
.20792 .10664 L
.21348 .10108 L
.21763 .09693 L
.22319 .09137 L
.22734 .08722 L
.23291 .08166 L
.23706 .07751 L
.24262 .07194 L
.24677 .06779 L
.25233 .06223 L
.25648 .05808 L
.26204 .05252 L
.26619 .04837 L
.27176 .04281 L
.27591 .03866 L
.28147 .03309 L
.28562 .02894 L
.29118 .02339 L
.29533 .01923 L
.01923 .01923 L
F
0 g
.01923 .29533 m
.02339 .29118 L
.02894 .28562 L
.03309 .28147 L
.03866 .27591 L
.04281 .27176 L
.04837 .26619 L
.05252 .26204 L
.05808 .25648 L
.06223 .25233 L
.06779 .24677 L
.07194 .24262 L
.07751 .23706 L
.08166 .23291 L
.08722 .22734 L
.09137 .22319 L
.09693 .21763 L
.10108 .21348 L
.10664 .20792 L
.11079 .20377 L
.11636 .19821 L
.12051 .19406 L
.12607 .18849 L
.13022 .18434 L
.13578 .17878 L
.13993 .17463 L
.14549 .16907 L
.14964 .16492 L
.15521 .15936 L
.15936 .15521 L
.16492 .14964 L
.16907 .14549 L
.17463 .13993 L
.17878 .13578 L
.18434 .13022 L
.18849 .12607 L
.19406 .12051 L
.19821 .11636 L
.20377 .11079 L
.20792 .10664 L
.21348 .10108 L
.21763 .09693 L
.22319 .09137 L
.22734 .08722 L
.23291 .08166 L
.23706 .07751 L
.24262 .07194 L
.24677 .06779 L
.25233 .06223 L
.25648 .05808 L
Mistroke
.26204 .05252 L
.26619 .04837 L
.27176 .04281 L
.27591 .03866 L
.28147 .03309 L
.28562 .02894 L
.29118 .02339 L
.29533 .01923 L
Mfstroke
.6 g
.01923 .25992 m
.02682 .25233 L
.02894 .25021 L
.03653 .24262 L
.03866 .2405 L
.04625 .23291 L
.04837 .23078 L
.05596 .22319 L
.05808 .22107 L
.06567 .21348 L
.06779 .21136 L
.07538 .20377 L
.07751 .20165 L
.0851 .19406 L
.08722 .19193 L
.09481 .18434 L
.09693 .18222 L
.10452 .17463 L
.10664 .17251 L
.11423 .16492 L
.11636 .1628 L
.12395 .15521 L
.12607 .15308 L
.13366 .14549 L
.13578 .14337 L
.14337 .13578 L
.14549 .13366 L
.15308 .12607 L
.15521 .12395 L
.1628 .11636 L
.16492 .11423 L
.17251 .10664 L
.17463 .10452 L
.18222 .09693 L
.18434 .09481 L
.19193 .08722 L
.19406 .0851 L
.20165 .07751 L
.20377 .07538 L
.21136 .06779 L
.21348 .06567 L
.22107 .05808 L
.22319 .05596 L
.23078 .04837 L
.23291 .04625 L
.2405 .03866 L
.24262 .03653 L
.25021 .02894 L
.25233 .02682 L
.25992 .01923 L
.01923 .01923 L
F
0 g
.01923 .25992 m
.02682 .25233 L
.02894 .25021 L
.03653 .24262 L
.03866 .2405 L
.04625 .23291 L
.04837 .23078 L
.05596 .22319 L
.05808 .22107 L
.06567 .21348 L
.06779 .21136 L
.07538 .20377 L
.07751 .20165 L
.0851 .19406 L
.08722 .19193 L
.09481 .18434 L
.09693 .18222 L
.10452 .17463 L
.10664 .17251 L
.11423 .16492 L
.11636 .1628 L
.12395 .15521 L
.12607 .15308 L
.13366 .14549 L
.13578 .14337 L
.14337 .13578 L
.14549 .13366 L
.15308 .12607 L
.15521 .12395 L
.1628 .11636 L
.16492 .11423 L
.17251 .10664 L
.17463 .10452 L
.18222 .09693 L
.18434 .09481 L
.19193 .08722 L
.19406 .0851 L
.20165 .07751 L
.20377 .07538 L
.21136 .06779 L
.21348 .06567 L
.22107 .05808 L
.22319 .05596 L
.23078 .04837 L
.23291 .04625 L
.2405 .03866 L
.24262 .03653 L
.25021 .02894 L
.25233 .02682 L
.25992 .01923 L
Mistroke
Mfstroke
.7 g
.01923 .21623 m
.02192 .21348 L
.02894 .20652 L
.03169 .20377 L
.03866 .19681 L
.04141 .19406 L
.04837 .18709 L
.05112 .18434 L
.05808 .17738 L
.06083 .17463 L
.06779 .16767 L
.07054 .16492 L
.07751 .15796 L
.08026 .15521 L
.08722 .14824 L
.08997 .14549 L
.09693 .13853 L
.09968 .13578 L
.10664 .12882 L
.10939 .12607 L
.11636 .11911 L
.11911 .11636 L
.12607 .10939 L
.12882 .10664 L
.13578 .09968 L
.13853 .09693 L
.14549 .08997 L
.14824 .08722 L
.15521 .08026 L
.15796 .07751 L
.16492 .07054 L
.16767 .06779 L
.17463 .06083 L
.17738 .05808 L
.18434 .05112 L
.18709 .04837 L
.19406 .04141 L
.19681 .03866 L
.20377 .03169 L
.20652 .02894 L
.21348 .02192 L
.21623 .01923 L
.01923 .01923 L
F
0 g
.01923 .21623 m
.02192 .21348 L
.02894 .20652 L
.03169 .20377 L
.03866 .19681 L
.04141 .19406 L
.04837 .18709 L
.05112 .18434 L
.05808 .17738 L
.06083 .17463 L
.06779 .16767 L
.07054 .16492 L
.07751 .15796 L
.08026 .15521 L
.08722 .14824 L
.08997 .14549 L
.09693 .13853 L
.09968 .13578 L
.10664 .12882 L
.10939 .12607 L
.11636 .11911 L
.11911 .11636 L
.12607 .10939 L
.12882 .10664 L
.13578 .09968 L
.13853 .09693 L
.14549 .08997 L
.14824 .08722 L
.15521 .08026 L
.15796 .07751 L
.16492 .07054 L
.16767 .06779 L
.17463 .06083 L
.17738 .05808 L
.18434 .05112 L
.18709 .04837 L
.19406 .04141 L
.19681 .03866 L
.20377 .03169 L
.20652 .02894 L
.21348 .02192 L
.21623 .01923 L
s
.6 g
.01923 .13763 m
.02144 .13578 L
.02894 .12792 L
.03079 .12607 L
.03866 .1182 L
.0405 .11636 L
.04837 .10849 L
.05022 .10664 L
.05808 .09878 L
.05993 .09693 L
.06779 .08907 L
.06964 .08722 L
.07751 .07935 L
.07935 .07751 L
.08722 .06964 L
.08907 .06779 L
.09693 .05993 L
.09878 .05808 L
.10664 .05022 L
.10849 .04837 L
.11636 .0405 L
.1182 .03866 L
.12607 .03079 L
.12792 .02894 L
.13578 .02144 L
.13763 .01923 L
.01923 .01923 L
F
0 g
.01923 .13763 m
.02144 .13578 L
.02894 .12792 L
.03079 .12607 L
.03866 .1182 L
.0405 .11636 L
.04837 .10849 L
.05022 .10664 L
.05808 .09878 L
.05993 .09693 L
.06779 .08907 L
.06964 .08722 L
.07751 .07935 L
.07935 .07751 L
.08722 .06964 L
.08907 .06779 L
.09693 .05993 L
.09878 .05808 L
.10664 .05022 L
.10849 .04837 L
.11636 .0405 L
.1182 .03866 L
.12607 .03079 L
.12792 .02894 L
.13578 .02144 L
.13763 .01923 L
s
.5 g
.01923 .09395 m
.02597 .08722 L
.02894 .08423 L
.03567 .07751 L
.03866 .07452 L
.04538 .06779 L
.04837 .06481 L
.0551 .05808 L
.05808 .0551 L
.06481 .04837 L
.06779 .04538 L
.07452 .03866 L
.07751 .03567 L
.08423 .02894 L
.08722 .02597 L
.09395 .01923 L
.01923 .01923 L
F
0 g
.01923 .09395 m
.02597 .08722 L
.02894 .08423 L
.03567 .07751 L
.03866 .07452 L
.04538 .06779 L
.04837 .06481 L
.0551 .05808 L
.05808 .0551 L
.06481 .04837 L
.06779 .04538 L
.07452 .03866 L
.07751 .03567 L
.08423 .02894 L
.08722 .02597 L
.09395 .01923 L
s
.4 g
.01923 .05854 m
.01969 .05808 L
.02894 .04882 L
.0294 .04837 L
.03866 .03911 L
.03911 .03866 L
.04837 .0294 L
.04882 .02894 L
.05808 .01969 L
.05854 .01923 L
.01923 .01923 L
F
0 g
.01923 .05854 m
.01969 .05808 L
.02894 .04882 L
.0294 .04837 L
.03866 .03911 L
.03911 .03866 L
.04837 .0294 L
.04882 .02894 L
.05808 .01969 L
.05854 .01923 L
s
.6 g
.06022 .98077 m
.06779 .97309 L
.06994 .97106 L
.07751 .96349 L
.07965 .96134 L
.08722 .95377 L
.08936 .95163 L
.09693 .94406 L
.09907 .94192 L
.10664 .93435 L
.10879 .93221 L
.11636 .92464 L
.1185 .92249 L
.12607 .91492 L
.12821 .91278 L
.13578 .90521 L
.13792 .90307 L
.14549 .8955 L
.14764 .89336 L
.15521 .88579 L
.15735 .88364 L
.16492 .87607 L
.16706 .87393 L
.17463 .86636 L
.17677 .86422 L
.18434 .85665 L
.18649 .85451 L
.19406 .84694 L
.1962 .84479 L
.20377 .83722 L
.20591 .83508 L
.21348 .82751 L
.21562 .82537 L
.22319 .8178 L
.22534 .81566 L
.23291 .80809 L
.23505 .80594 L
.24262 .79837 L
.24476 .79623 L
.25233 .78866 L
.25447 .78652 L
.26204 .77895 L
.26419 .77681 L
.27176 .76924 L
.2739 .76709 L
.28147 .75952 L
.28361 .75738 L
.29118 .74981 L
.29332 .74767 L
.30089 .7401 L
.30304 .73796 L
.31061 .73039 L
.31275 .72824 L
.32032 .72067 L
.32246 .71853 L
.33003 .71096 L
.33213 .70882 L
.33974 .70125 L
.34241 .69911 L
.34946 .69425 L
.35563 .68939 L
.35917 .68594 L
.36598 .67968 L
.36888 .67656 L
.37536 .66997 L
.37859 .66627 L
.38407 .66026 L
.38831 .65517 L
.39226 .65054 L
.39802 .64332 L
.40003 .64083 L
.4075 .63112 L
.40773 .63079 L
.41482 .62141 L
.41744 .61766 L
.42179 .61169 L
.42716 .6039 L
.42851 .60198 L
.43517 .59227 L
.43687 .5896 L
.44161 .58256 L
.44658 .57475 L
.44783 .57284 L
.45406 .56313 L
.45629 .55941 L
.46007 .55342 L
.46592 .54371 L
.46601 .54355 L
.47183 .53399 L
.47572 .52724 L
.47748 .52428 L
.48317 .51457 L
.48543 .51046 L
.48869 .50486 L
.49414 .49514 L
.49514 .49324 L
.49956 .48543 L
.50479 .47572 L
.50486 .47558 L
.51014 .46601 L
.51457 .45751 L
.51523 .45629 L
.52045 .44658 L
.52428 .43903 L
.52543 .43687 L
.53053 .42716 L
.53399 .42016 L
.5354 .41744 L
.5404 .40773 L
.54371 .40089 L
.54517 .39802 L
.55007 .38831 L
.55342 .38125 L
.55474 .37859 L
.55956 .36888 L
.56313 .36123 L
.56414 .35917 L
.56889 .34946 L
.57284 .34084 L
.57337 .33974 L
.57805 .33003 L
.58247 .32032 L
.58256 .3201 L
.58706 .31061 L
.59148 .30089 L
.59227 .29902 L
.59593 .29118 L
.60035 .28147 L
.60198 .27759 L
.60466 .27176 L
.60907 .26204 L
.61169 .25581 L
.61327 .25233 L
.61765 .24262 L
.62141 .2337 L
.62176 .23291 L
.6261 .22319 L
.63025 .21348 L
.63112 .21127 L
.63443 .20377 L
.63862 .19406 L
.64083 .18852 L
.64264 .18434 L
.64685 .17463 L
.65054 .16544 L
.65077 .16492 L
.65493 .15521 L
.65896 .14549 L
.66026 .14206 L
.66291 .13578 L
.66699 .12607 L
.66997 .11836 L
.6708 .11636 L
.67487 .10664 L
.67875 .09693 L
.67968 .09436 L
.68263 .08722 L
.6866 .07751 L
.68939 .07005 L
.69032 .06779 L
.69429 .05808 L
.69808 .04837 L
.69911 .04546 L
.70185 .03866 L
.70574 .02894 L
.70882 .02056 L
.70935 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.06022 .98077 m
.06779 .97309 L
.06994 .97106 L
.07751 .96349 L
.07965 .96134 L
.08722 .95377 L
.08936 .95163 L
.09693 .94406 L
.09907 .94192 L
.10664 .93435 L
.10879 .93221 L
.11636 .92464 L
.1185 .92249 L
.12607 .91492 L
.12821 .91278 L
.13578 .90521 L
.13792 .90307 L
.14549 .8955 L
.14764 .89336 L
.15521 .88579 L
.15735 .88364 L
.16492 .87607 L
.16706 .87393 L
.17463 .86636 L
.17677 .86422 L
.18434 .85665 L
.18649 .85451 L
.19406 .84694 L
.1962 .84479 L
.20377 .83722 L
.20591 .83508 L
.21348 .82751 L
.21562 .82537 L
.22319 .8178 L
.22534 .81566 L
.23291 .80809 L
.23505 .80594 L
.24262 .79837 L
.24476 .79623 L
.25233 .78866 L
.25447 .78652 L
.26204 .77895 L
.26419 .77681 L
.27176 .76924 L
.2739 .76709 L
.28147 .75952 L
.28361 .75738 L
.29118 .74981 L
.29332 .74767 L
.30089 .7401 L
Mistroke
.30304 .73796 L
.31061 .73039 L
.31275 .72824 L
.32032 .72067 L
.32246 .71853 L
.33003 .71096 L
.33213 .70882 L
.33974 .70125 L
.34241 .69911 L
.34946 .69425 L
.35563 .68939 L
.35917 .68594 L
.36598 .67968 L
.36888 .67656 L
.37536 .66997 L
.37859 .66627 L
.38407 .66026 L
.38831 .65517 L
.39226 .65054 L
.39802 .64332 L
.40003 .64083 L
.4075 .63112 L
.40773 .63079 L
.41482 .62141 L
.41744 .61766 L
.42179 .61169 L
.42716 .6039 L
.42851 .60198 L
.43517 .59227 L
.43687 .5896 L
.44161 .58256 L
.44658 .57475 L
.44783 .57284 L
.45406 .56313 L
.45629 .55941 L
.46007 .55342 L
.46592 .54371 L
.46601 .54355 L
.47183 .53399 L
.47572 .52724 L
.47748 .52428 L
.48317 .51457 L
.48543 .51046 L
.48869 .50486 L
.49414 .49514 L
.49514 .49324 L
.49956 .48543 L
.50479 .47572 L
.50486 .47558 L
.51014 .46601 L
Mistroke
.51457 .45751 L
.51523 .45629 L
.52045 .44658 L
.52428 .43903 L
.52543 .43687 L
.53053 .42716 L
.53399 .42016 L
.5354 .41744 L
.5404 .40773 L
.54371 .40089 L
.54517 .39802 L
.55007 .38831 L
.55342 .38125 L
.55474 .37859 L
.55956 .36888 L
.56313 .36123 L
.56414 .35917 L
.56889 .34946 L
.57284 .34084 L
.57337 .33974 L
.57805 .33003 L
.58247 .32032 L
.58256 .3201 L
.58706 .31061 L
.59148 .30089 L
.59227 .29902 L
.59593 .29118 L
.60035 .28147 L
.60198 .27759 L
.60466 .27176 L
.60907 .26204 L
.61169 .25581 L
.61327 .25233 L
.61765 .24262 L
.62141 .2337 L
.62176 .23291 L
.6261 .22319 L
.63025 .21348 L
.63112 .21127 L
.63443 .20377 L
.63862 .19406 L
.64083 .18852 L
.64264 .18434 L
.64685 .17463 L
.65054 .16544 L
.65077 .16492 L
.65493 .15521 L
.65896 .14549 L
.66026 .14206 L
.66291 .13578 L
Mistroke
.66699 .12607 L
.66997 .11836 L
.6708 .11636 L
.67487 .10664 L
.67875 .09693 L
.67968 .09436 L
.68263 .08722 L
.6866 .07751 L
.68939 .07005 L
.69032 .06779 L
.69429 .05808 L
.69808 .04837 L
.69911 .04546 L
.70185 .03866 L
.70574 .02894 L
.70882 .02056 L
.70935 .01923 L
Mfstroke
.5 g
.10392 .98077 m
.10664 .97804 L
.11363 .97106 L
.11636 .96833 L
.12334 .96134 L
.12607 .95862 L
.13306 .95163 L
.13578 .94891 L
.14277 .94192 L
.14549 .9392 L
.15248 .93221 L
.15521 .92948 L
.16219 .92249 L
.16492 .91977 L
.17191 .91278 L
.17463 .91006 L
.18162 .90307 L
.18434 .90035 L
.19133 .89336 L
.19406 .89063 L
.20105 .88364 L
.20377 .88092 L
.21076 .87393 L
.21348 .87121 L
.22047 .86422 L
.22319 .8615 L
.23018 .85451 L
.23291 .85178 L
.2399 .84479 L
.24262 .84207 L
.24961 .83508 L
.25233 .83236 L
.25932 .82537 L
.26204 .82265 L
.26903 .81566 L
.27176 .81293 L
.27875 .80594 L
.28147 .80322 L
.28846 .79623 L
.29118 .79351 L
.29817 .78652 L
.30089 .7838 L
.30788 .77681 L
.31061 .77408 L
.3176 .76709 L
.32032 .76437 L
.32731 .75738 L
.33003 .75466 L
.33703 .74767 L
.33974 .74495 L
.34691 .73796 L
.34946 .7355 L
.35645 .72824 L
.35917 .72528 L
.36525 .71853 L
.36888 .71433 L
.37358 .70882 L
.37859 .70272 L
.38152 .69911 L
.38831 .69048 L
.38915 .68939 L
.39652 .67968 L
.39802 .67765 L
.40365 .66997 L
.40773 .66426 L
.41057 .66026 L
.41729 .65054 L
.41744 .65032 L
.42388 .64083 L
.42716 .63588 L
.43029 .63112 L
.43657 .62141 L
.43687 .62093 L
.44274 .61169 L
.44658 .6055 L
.44877 .60198 L
.4547 .59227 L
.45629 .58961 L
.46053 .58256 L
.46601 .57327 L
.46626 .57284 L
.47192 .56313 L
.47572 .55649 L
.47748 .55342 L
.48297 .54371 L
.48543 .53928 L
.48838 .53399 L
.49372 .52428 L
.49514 .52166 L
.499 .51457 L
.50421 .50486 L
.50486 .50363 L
.50937 .49514 L
.51445 .48543 L
.51457 .4852 L
.51951 .47572 L
.52428 .46639 L
.52448 .46601 L
.52943 .45629 L
.53399 .4472 L
.5343 .44658 L
.53916 .43687 L
.54371 .42763 L
.54394 .42716 L
.54871 .41744 L
.5534 .40773 L
.55342 .4077 L
.5581 .39802 L
.56271 .38831 L
.56313 .38741 L
.56732 .37859 L
.57187 .36888 L
.57284 .36677 L
.5764 .35917 L
.58089 .34946 L
.58256 .34579 L
.58534 .33974 L
.58977 .33003 L
.59227 .32446 L
.59415 .32032 L
.59852 .31061 L
.60198 .3028 L
.60283 .30089 L
.60716 .29118 L
.61141 .28147 L
.61169 .28081 L
.61567 .27176 L
.61989 .26204 L
.62141 .2585 L
.62408 .25233 L
.62826 .24262 L
.63112 .23586 L
.63238 .23291 L
.63652 .22319 L
.6406 .21348 L
.64083 .21291 L
.64469 .20377 L
.64874 .19406 L
.65054 .18965 L
.65275 .18434 L
.65678 .17463 L
.66026 .16608 L
.66073 .16492 L
.66472 .15521 L
.66866 .14549 L
.66997 .14221 L
.67258 .13578 L
.6765 .12607 L
.67968 .11805 L
.68036 .11636 L
.68425 .10664 L
.6881 .09693 L
.68939 .09358 L
.69191 .08722 L
.69575 .07751 L
.69911 .06883 L
.69951 .06779 L
.70331 .05808 L
.70708 .04837 L
.70882 .04378 L
.7108 .03866 L
.71456 .02894 L
.71824 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.10392 .98077 m
.10664 .97804 L
.11363 .97106 L
.11636 .96833 L
.12334 .96134 L
.12607 .95862 L
.13306 .95163 L
.13578 .94891 L
.14277 .94192 L
.14549 .9392 L
.15248 .93221 L
.15521 .92948 L
.16219 .92249 L
.16492 .91977 L
.17191 .91278 L
.17463 .91006 L
.18162 .90307 L
.18434 .90035 L
.19133 .89336 L
.19406 .89063 L
.20105 .88364 L
.20377 .88092 L
.21076 .87393 L
.21348 .87121 L
.22047 .86422 L
.22319 .8615 L
.23018 .85451 L
.23291 .85178 L
.2399 .84479 L
.24262 .84207 L
.24961 .83508 L
.25233 .83236 L
.25932 .82537 L
.26204 .82265 L
.26903 .81566 L
.27176 .81293 L
.27875 .80594 L
.28147 .80322 L
.28846 .79623 L
.29118 .79351 L
.29817 .78652 L
.30089 .7838 L
.30788 .77681 L
.31061 .77408 L
.3176 .76709 L
.32032 .76437 L
.32731 .75738 L
.33003 .75466 L
.33703 .74767 L
.33974 .74495 L
Mistroke
.34691 .73796 L
.34946 .7355 L
.35645 .72824 L
.35917 .72528 L
.36525 .71853 L
.36888 .71433 L
.37358 .70882 L
.37859 .70272 L
.38152 .69911 L
.38831 .69048 L
.38915 .68939 L
.39652 .67968 L
.39802 .67765 L
.40365 .66997 L
.40773 .66426 L
.41057 .66026 L
.41729 .65054 L
.41744 .65032 L
.42388 .64083 L
.42716 .63588 L
.43029 .63112 L
.43657 .62141 L
.43687 .62093 L
.44274 .61169 L
.44658 .6055 L
.44877 .60198 L
.4547 .59227 L
.45629 .58961 L
.46053 .58256 L
.46601 .57327 L
.46626 .57284 L
.47192 .56313 L
.47572 .55649 L
.47748 .55342 L
.48297 .54371 L
.48543 .53928 L
.48838 .53399 L
.49372 .52428 L
.49514 .52166 L
.499 .51457 L
.50421 .50486 L
.50486 .50363 L
.50937 .49514 L
.51445 .48543 L
.51457 .4852 L
.51951 .47572 L
.52428 .46639 L
.52448 .46601 L
.52943 .45629 L
.53399 .4472 L
Mistroke
.5343 .44658 L
.53916 .43687 L
.54371 .42763 L
.54394 .42716 L
.54871 .41744 L
.5534 .40773 L
.55342 .4077 L
.5581 .39802 L
.56271 .38831 L
.56313 .38741 L
.56732 .37859 L
.57187 .36888 L
.57284 .36677 L
.5764 .35917 L
.58089 .34946 L
.58256 .34579 L
.58534 .33974 L
.58977 .33003 L
.59227 .32446 L
.59415 .32032 L
.59852 .31061 L
.60198 .3028 L
.60283 .30089 L
.60716 .29118 L
.61141 .28147 L
.61169 .28081 L
.61567 .27176 L
.61989 .26204 L
.62141 .2585 L
.62408 .25233 L
.62826 .24262 L
.63112 .23586 L
.63238 .23291 L
.63652 .22319 L
.6406 .21348 L
.64083 .21291 L
.64469 .20377 L
.64874 .19406 L
.65054 .18965 L
.65275 .18434 L
.65678 .17463 L
.66026 .16608 L
.66073 .16492 L
.66472 .15521 L
.66866 .14549 L
.66997 .14221 L
.67258 .13578 L
.6765 .12607 L
.67968 .11805 L
.68036 .11636 L
Mistroke
.68425 .10664 L
.6881 .09693 L
.68939 .09358 L
.69191 .08722 L
.69575 .07751 L
.69911 .06883 L
.69951 .06779 L
.70331 .05808 L
.70708 .04837 L
.70882 .04378 L
.7108 .03866 L
.71456 .02894 L
.71824 .01923 L
Mfstroke
.4 g
.13933 .98077 m
.14549 .97461 L
.14904 .97106 L
.15521 .96489 L
.15875 .96134 L
.16492 .95518 L
.16847 .95163 L
.17463 .94547 L
.17818 .94192 L
.18434 .93575 L
.18789 .93221 L
.19406 .92604 L
.1976 .92249 L
.20377 .91633 L
.20732 .91278 L
.21348 .90662 L
.21703 .90307 L
.22319 .8969 L
.22674 .89336 L
.23291 .88719 L
.23645 .88364 L
.24262 .87748 L
.24617 .87393 L
.25233 .86777 L
.25588 .86422 L
.26204 .85805 L
.26559 .85451 L
.27176 .84834 L
.2753 .84479 L
.28147 .83863 L
.28502 .83508 L
.29118 .82892 L
.29473 .82537 L
.30089 .8192 L
.30444 .81566 L
.31061 .80949 L
.31415 .80594 L
.32032 .79978 L
.32387 .79623 L
.33003 .79007 L
.33366 .78652 L
.33974 .78035 L
.34302 .77681 L
.34946 .76965 L
.35171 .76709 L
.35917 .75837 L
.35999 .75738 L
.36795 .74767 L
.36888 .7465 L
.37562 .73796 L
.37859 .73409 L
.38303 .72824 L
.38831 .72114 L
.39022 .71853 L
.3972 .70882 L
.39802 .70767 L
.40401 .69911 L
.40773 .6937 L
.41065 .68939 L
.41715 .67968 L
.41744 .67924 L
.42351 .66997 L
.42716 .66431 L
.42974 .66026 L
.43585 .65054 L
.43687 .64891 L
.44186 .64083 L
.44658 .63307 L
.44776 .63112 L
.45357 .62141 L
.45629 .6168 L
.45929 .61169 L
.46492 .60198 L
.46601 .6001 L
.47047 .59227 L
.47572 .58298 L
.47596 .58256 L
.48136 .57284 L
.48543 .56546 L
.4867 .56313 L
.49198 .55342 L
.49514 .54753 L
.49719 .54371 L
.50234 .53399 L
.50486 .52922 L
.50744 .52428 L
.51249 .51457 L
.51457 .51053 L
.51747 .50486 L
.52242 .49514 L
.52428 .49146 L
.52731 .48543 L
.53216 .47572 L
.53399 .47203 L
.53696 .46601 L
.54173 .45629 L
.54371 .45223 L
.54644 .44658 L
.55112 .43687 L
.55342 .43208 L
.55576 .42716 L
.56037 .41744 L
.56313 .41158 L
.56493 .40773 L
.56946 .39802 L
.57284 .39074 L
.57396 .38831 L
.57842 .37859 L
.58256 .36956 L
.58286 .36888 L
.58725 .35917 L
.59164 .34946 L
.59227 .34805 L
.59596 .33974 L
.60029 .33003 L
.60198 .32621 L
.60456 .32032 L
.60883 .31061 L
.61169 .30404 L
.61305 .30089 L
.61726 .29118 L
.62141 .28156 L
.62145 .28147 L
.62558 .27176 L
.62973 .26204 L
.63112 .25877 L
.63382 .25233 L
.63791 .24262 L
.64083 .23566 L
.64197 .23291 L
.64601 .22319 L
.65004 .21348 L
.65054 .21225 L
.65401 .20377 L
.658 .19406 L
.66026 .18854 L
.66194 .18434 L
.66588 .17463 L
.66981 .16492 L
.66997 .16453 L
.67369 .15521 L
.67758 .14549 L
.67968 .14022 L
.68142 .13578 L
.68527 .12607 L
.68911 .11636 L
.68939 .11563 L
.69289 .10664 L
.6967 .09693 L
.69911 .09074 L
.70045 .08722 L
.70421 .07751 L
.70797 .06779 L
.70882 .06557 L
.71166 .05808 L
.71539 .04837 L
.71853 .04012 L
.71908 .03866 L
.72274 .02894 L
.72642 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.13933 .98077 m
.14549 .97461 L
.14904 .97106 L
.15521 .96489 L
.15875 .96134 L
.16492 .95518 L
.16847 .95163 L
.17463 .94547 L
.17818 .94192 L
.18434 .93575 L
.18789 .93221 L
.19406 .92604 L
.1976 .92249 L
.20377 .91633 L
.20732 .91278 L
.21348 .90662 L
.21703 .90307 L
.22319 .8969 L
.22674 .89336 L
.23291 .88719 L
.23645 .88364 L
.24262 .87748 L
.24617 .87393 L
.25233 .86777 L
.25588 .86422 L
.26204 .85805 L
.26559 .85451 L
.27176 .84834 L
.2753 .84479 L
.28147 .83863 L
.28502 .83508 L
.29118 .82892 L
.29473 .82537 L
.30089 .8192 L
.30444 .81566 L
.31061 .80949 L
.31415 .80594 L
.32032 .79978 L
.32387 .79623 L
.33003 .79007 L
.33366 .78652 L
.33974 .78035 L
.34302 .77681 L
.34946 .76965 L
.35171 .76709 L
.35917 .75837 L
.35999 .75738 L
.36795 .74767 L
.36888 .7465 L
.37562 .73796 L
Mistroke
.37859 .73409 L
.38303 .72824 L
.38831 .72114 L
.39022 .71853 L
.3972 .70882 L
.39802 .70767 L
.40401 .69911 L
.40773 .6937 L
.41065 .68939 L
.41715 .67968 L
.41744 .67924 L
.42351 .66997 L
.42716 .66431 L
.42974 .66026 L
.43585 .65054 L
.43687 .64891 L
.44186 .64083 L
.44658 .63307 L
.44776 .63112 L
.45357 .62141 L
.45629 .6168 L
.45929 .61169 L
.46492 .60198 L
.46601 .6001 L
.47047 .59227 L
.47572 .58298 L
.47596 .58256 L
.48136 .57284 L
.48543 .56546 L
.4867 .56313 L
.49198 .55342 L
.49514 .54753 L
.49719 .54371 L
.50234 .53399 L
.50486 .52922 L
.50744 .52428 L
.51249 .51457 L
.51457 .51053 L
.51747 .50486 L
.52242 .49514 L
.52428 .49146 L
.52731 .48543 L
.53216 .47572 L
.53399 .47203 L
.53696 .46601 L
.54173 .45629 L
.54371 .45223 L
.54644 .44658 L
.55112 .43687 L
.55342 .43208 L
Mistroke
.55576 .42716 L
.56037 .41744 L
.56313 .41158 L
.56493 .40773 L
.56946 .39802 L
.57284 .39074 L
.57396 .38831 L
.57842 .37859 L
.58256 .36956 L
.58286 .36888 L
.58725 .35917 L
.59164 .34946 L
.59227 .34805 L
.59596 .33974 L
.60029 .33003 L
.60198 .32621 L
.60456 .32032 L
.60883 .31061 L
.61169 .30404 L
.61305 .30089 L
.61726 .29118 L
.62141 .28156 L
.62145 .28147 L
.62558 .27176 L
.62973 .26204 L
.63112 .25877 L
.63382 .25233 L
.63791 .24262 L
.64083 .23566 L
.64197 .23291 L
.64601 .22319 L
.65004 .21348 L
.65054 .21225 L
.65401 .20377 L
.658 .19406 L
.66026 .18854 L
.66194 .18434 L
.66588 .17463 L
.66981 .16492 L
.66997 .16453 L
.67369 .15521 L
.67758 .14549 L
.67968 .14022 L
.68142 .13578 L
.68527 .12607 L
.68911 .11636 L
.68939 .11563 L
.69289 .10664 L
.6967 .09693 L
.69911 .09074 L
Mistroke
.70045 .08722 L
.70421 .07751 L
.70797 .06779 L
.70882 .06557 L
.71166 .05808 L
.71539 .04837 L
.71853 .04012 L
.71908 .03866 L
.72274 .02894 L
.72642 .01923 L
Mfstroke
.3 g
.18304 .98077 m
.18434 .97949 L
.19275 .97106 L
.19406 .96975 L
.20246 .96134 L
.20377 .96004 L
.21217 .95163 L
.21348 .95032 L
.22189 .94192 L
.22319 .94061 L
.2316 .93221 L
.23291 .9309 L
.24131 .92249 L
.24262 .92119 L
.25102 .91278 L
.25233 .91147 L
.26074 .90307 L
.26204 .90176 L
.27045 .89336 L
.27176 .89205 L
.28016 .88364 L
.28147 .88234 L
.28987 .87393 L
.29118 .87262 L
.29959 .86422 L
.30089 .86291 L
.3093 .85451 L
.31061 .8532 L
.31901 .84479 L
.32032 .84349 L
.32872 .83508 L
.33003 .83377 L
.33857 .82537 L
.33974 .82406 L
.34605 .81566 L
.34946 .81091 L
.35313 .80594 L
.35917 .79772 L
.36025 .79623 L
.36728 .78652 L
.36888 .78429 L
.37418 .77681 L
.37859 .77054 L
.38098 .76709 L
.38768 .75738 L
.38831 .75647 L
.39422 .74767 L
.39802 .74199 L
.40067 .73796 L
.40703 .72824 L
.40773 .72716 L
.41323 .71853 L
.41744 .71191 L
.41936 .70882 L
.42541 .69911 L
.42716 .69628 L
.43132 .68939 L
.43687 .68025 L
.4372 .67968 L
.44294 .66997 L
.44658 .66382 L
.44862 .66026 L
.45425 .65054 L
.45629 .64701 L
.45976 .64083 L
.46527 .63112 L
.46601 .62981 L
.47063 .62141 L
.47572 .61224 L
.47601 .61169 L
.48125 .60198 L
.48543 .59428 L
.48648 .59227 L
.49163 .58256 L
.49514 .57595 L
.49673 .57284 L
.50179 .56313 L
.50486 .55727 L
.50678 .55342 L
.51176 .54371 L
.51457 .53822 L
.51664 .53399 L
.52153 .52428 L
.52428 .51882 L
.52632 .51457 L
.53113 .50486 L
.53399 .49906 L
.53584 .49514 L
.54056 .48543 L
.54371 .47897 L
.5452 .47572 L
.54983 .46601 L
.55342 .45854 L
.55443 .45629 L
.55896 .44658 L
.56313 .43777 L
.56353 .43687 L
.56796 .42716 L
.57249 .41744 L
.57284 .41667 L
.57682 .40773 L
.58129 .39802 L
.58256 .39524 L
.58557 .38831 L
.58996 .37859 L
.59227 .37349 L
.59422 .36888 L
.59852 .35917 L
.60198 .35142 L
.60279 .34946 L
.60698 .33974 L
.61126 .33003 L
.61169 .32905 L
.61534 .32032 L
.61956 .31061 L
.62141 .30635 L
.62362 .30089 L
.62776 .29118 L
.63112 .28336 L
.63186 .28147 L
.63587 .27176 L
.63999 .26204 L
.64083 .26006 L
.64391 .25233 L
.64797 .24262 L
.65054 .23646 L
.6519 .23291 L
.65586 .22319 L
.65988 .21348 L
.66026 .21257 L
.66368 .20377 L
.66765 .19406 L
.66997 .18838 L
.67147 .18434 L
.67534 .17463 L
.67928 .16492 L
.67968 .16391 L
.68297 .15521 L
.68686 .14549 L
.68939 .13915 L
.69061 .13578 L
.69437 .12607 L
.69822 .11636 L
.69911 .11411 L
.70184 .10664 L
.70563 .09693 L
.70882 .08879 L
.70936 .08722 L
.71297 .07751 L
.71675 .06779 L
.71853 .06319 L
.72032 .05808 L
.724 .04837 L
.72774 .03866 L
.72824 .03732 L
.73121 .02894 L
.73489 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.18304 .98077 m
.18434 .97949 L
.19275 .97106 L
.19406 .96975 L
.20246 .96134 L
.20377 .96004 L
.21217 .95163 L
.21348 .95032 L
.22189 .94192 L
.22319 .94061 L
.2316 .93221 L
.23291 .9309 L
.24131 .92249 L
.24262 .92119 L
.25102 .91278 L
.25233 .91147 L
.26074 .90307 L
.26204 .90176 L
.27045 .89336 L
.27176 .89205 L
.28016 .88364 L
.28147 .88234 L
.28987 .87393 L
.29118 .87262 L
.29959 .86422 L
.30089 .86291 L
.3093 .85451 L
.31061 .8532 L
.31901 .84479 L
.32032 .84349 L
.32872 .83508 L
.33003 .83377 L
.33857 .82537 L
.33974 .82406 L
.34605 .81566 L
.34946 .81091 L
.35313 .80594 L
.35917 .79772 L
.36025 .79623 L
.36728 .78652 L
.36888 .78429 L
.37418 .77681 L
.37859 .77054 L
.38098 .76709 L
.38768 .75738 L
.38831 .75647 L
.39422 .74767 L
.39802 .74199 L
.40067 .73796 L
.40703 .72824 L
Mistroke
.40773 .72716 L
.41323 .71853 L
.41744 .71191 L
.41936 .70882 L
.42541 .69911 L
.42716 .69628 L
.43132 .68939 L
.43687 .68025 L
.4372 .67968 L
.44294 .66997 L
.44658 .66382 L
.44862 .66026 L
.45425 .65054 L
.45629 .64701 L
.45976 .64083 L
.46527 .63112 L
.46601 .62981 L
.47063 .62141 L
.47572 .61224 L
.47601 .61169 L
.48125 .60198 L
.48543 .59428 L
.48648 .59227 L
.49163 .58256 L
.49514 .57595 L
.49673 .57284 L
.50179 .56313 L
.50486 .55727 L
.50678 .55342 L
.51176 .54371 L
.51457 .53822 L
.51664 .53399 L
.52153 .52428 L
.52428 .51882 L
.52632 .51457 L
.53113 .50486 L
.53399 .49906 L
.53584 .49514 L
.54056 .48543 L
.54371 .47897 L
.5452 .47572 L
.54983 .46601 L
.55342 .45854 L
.55443 .45629 L
.55896 .44658 L
.56313 .43777 L
.56353 .43687 L
.56796 .42716 L
.57249 .41744 L
.57284 .41667 L
Mistroke
.57682 .40773 L
.58129 .39802 L
.58256 .39524 L
.58557 .38831 L
.58996 .37859 L
.59227 .37349 L
.59422 .36888 L
.59852 .35917 L
.60198 .35142 L
.60279 .34946 L
.60698 .33974 L
.61126 .33003 L
.61169 .32905 L
.61534 .32032 L
.61956 .31061 L
.62141 .30635 L
.62362 .30089 L
.62776 .29118 L
.63112 .28336 L
.63186 .28147 L
.63587 .27176 L
.63999 .26204 L
.64083 .26006 L
.64391 .25233 L
.64797 .24262 L
.65054 .23646 L
.6519 .23291 L
.65586 .22319 L
.65988 .21348 L
.66026 .21257 L
.66368 .20377 L
.66765 .19406 L
.66997 .18838 L
.67147 .18434 L
.67534 .17463 L
.67928 .16492 L
.67968 .16391 L
.68297 .15521 L
.68686 .14549 L
.68939 .13915 L
.69061 .13578 L
.69437 .12607 L
.69822 .11636 L
.69911 .11411 L
.70184 .10664 L
.70563 .09693 L
.70882 .08879 L
.70936 .08722 L
.71297 .07751 L
.71675 .06779 L
Mistroke
.71853 .06319 L
.72032 .05808 L
.724 .04837 L
.72774 .03866 L
.72824 .03732 L
.73121 .02894 L
.73489 .01923 L
Mfstroke
.4 g
.2616 .98077 m
.26204 .98018 L
.27131 .97106 L
.27176 .97061 L
.28102 .96134 L
.28147 .9609 L
.29073 .95163 L
.29118 .95118 L
.30045 .94192 L
.30089 .94147 L
.31016 .93221 L
.31061 .93176 L
.31987 .92249 L
.32032 .92205 L
.32958 .91278 L
.33003 .91233 L
.33926 .90307 L
.33974 .90262 L
.34946 .89562 L
.35244 .89336 L
.35917 .88732 L
.36327 .88364 L
.36888 .87794 L
.3729 .87393 L
.37859 .86765 L
.38176 .86422 L
.38831 .85654 L
.39006 .85451 L
.39794 .84479 L
.39802 .84469 L
.40563 .83508 L
.40773 .83219 L
.41293 .82537 L
.41744 .81904 L
.41992 .81566 L
.42673 .80594 L
.42716 .80529 L
.43345 .79623 L
.43687 .79099 L
.43989 .78652 L
.44618 .77681 L
.44658 .77614 L
.45245 .76709 L
.45629 .76079 L
.45845 .75738 L
.46443 .74767 L
.46601 .74494 L
.47028 .73796 L
.47572 .72861 L
.47594 .72824 L
.4817 .71853 L
.48543 .71184 L
.48719 .70882 L
.49274 .69911 L
.49514 .69462 L
.49811 .68939 L
.50346 .67968 L
.50486 .67697 L
.50873 .66997 L
.51389 .66026 L
.51457 .6589 L
.51908 .65054 L
.52408 .64083 L
.52428 .64041 L
.5292 .63112 L
.53399 .62154 L
.53406 .62141 L
.53909 .61169 L
.54371 .60227 L
.54385 .60198 L
.54879 .59227 L
.55342 .58262 L
.55345 .58256 L
.5583 .57284 L
.5629 .56313 L
.56313 .56261 L
.56764 .55342 L
.5722 .54371 L
.57284 .54223 L
.57682 .53399 L
.58135 .52428 L
.58256 .52149 L
.58584 .51457 L
.59035 .50486 L
.59227 .50041 L
.59473 .49514 L
.59921 .48543 L
.60198 .47897 L
.60348 .47572 L
.60792 .46601 L
.61169 .45719 L
.6121 .45629 L
.6165 .44658 L
.6207 .43687 L
.62141 .43509 L
.62495 .42716 L
.62919 .41744 L
.63112 .41266 L
.63329 .40773 L
.63753 .39802 L
.64083 .3899 L
.64152 .38831 L
.64574 .37859 L
.64977 .36888 L
.65054 .36683 L
.65383 .35917 L
.65792 .34946 L
.66026 .34344 L
.66182 .33974 L
.66592 .33003 L
.66976 .32032 L
.66997 .31974 L
.67379 .31061 L
.67776 .30089 L
.67968 .29574 L
.68157 .29118 L
.68557 .28147 L
.68928 .27176 L
.68939 .27144 L
.69324 .26204 L
.69711 .25233 L
.69911 .24684 L
.70081 .24262 L
.70473 .23291 L
.7084 .22319 L
.70882 .22195 L
.7122 .21348 L
.71603 .20377 L
.71853 .19677 L
.7196 .19406 L
.72344 .18434 L
.72712 .17463 L
.72824 .1713 L
.73074 .16492 L
.73452 .15521 L
.73796 .14555 L
.73798 .14549 L
.74174 .13578 L
.74543 .12607 L
.74767 .11953 L
.74888 .11636 L
.75261 .10664 L
.75617 .09693 L
.75738 .09322 L
.75966 .08722 L
.76334 .07751 L
.76674 .06779 L
.76709 .06664 L
.77031 .05808 L
.77393 .04837 L
.77681 .03979 L
.77723 .03866 L
.78085 .02894 L
.78439 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.2616 .98077 m
.26204 .98018 L
.27131 .97106 L
.27176 .97061 L
.28102 .96134 L
.28147 .9609 L
.29073 .95163 L
.29118 .95118 L
.30045 .94192 L
.30089 .94147 L
.31016 .93221 L
.31061 .93176 L
.31987 .92249 L
.32032 .92205 L
.32958 .91278 L
.33003 .91233 L
.33926 .90307 L
.33974 .90262 L
.34946 .89562 L
.35244 .89336 L
.35917 .88732 L
.36327 .88364 L
.36888 .87794 L
.3729 .87393 L
.37859 .86765 L
.38176 .86422 L
.38831 .85654 L
.39006 .85451 L
.39794 .84479 L
.39802 .84469 L
.40563 .83508 L
.40773 .83219 L
.41293 .82537 L
.41744 .81904 L
.41992 .81566 L
.42673 .80594 L
.42716 .80529 L
.43345 .79623 L
.43687 .79099 L
.43989 .78652 L
.44618 .77681 L
.44658 .77614 L
.45245 .76709 L
.45629 .76079 L
.45845 .75738 L
.46443 .74767 L
.46601 .74494 L
.47028 .73796 L
.47572 .72861 L
.47594 .72824 L
Mistroke
.4817 .71853 L
.48543 .71184 L
.48719 .70882 L
.49274 .69911 L
.49514 .69462 L
.49811 .68939 L
.50346 .67968 L
.50486 .67697 L
.50873 .66997 L
.51389 .66026 L
.51457 .6589 L
.51908 .65054 L
.52408 .64083 L
.52428 .64041 L
.5292 .63112 L
.53399 .62154 L
.53406 .62141 L
.53909 .61169 L
.54371 .60227 L
.54385 .60198 L
.54879 .59227 L
.55342 .58262 L
.55345 .58256 L
.5583 .57284 L
.5629 .56313 L
.56313 .56261 L
.56764 .55342 L
.5722 .54371 L
.57284 .54223 L
.57682 .53399 L
.58135 .52428 L
.58256 .52149 L
.58584 .51457 L
.59035 .50486 L
.59227 .50041 L
.59473 .49514 L
.59921 .48543 L
.60198 .47897 L
.60348 .47572 L
.60792 .46601 L
.61169 .45719 L
.6121 .45629 L
.6165 .44658 L
.6207 .43687 L
.62141 .43509 L
.62495 .42716 L
.62919 .41744 L
.63112 .41266 L
.63329 .40773 L
.63753 .39802 L
Mistroke
.64083 .3899 L
.64152 .38831 L
.64574 .37859 L
.64977 .36888 L
.65054 .36683 L
.65383 .35917 L
.65792 .34946 L
.66026 .34344 L
.66182 .33974 L
.66592 .33003 L
.66976 .32032 L
.66997 .31974 L
.67379 .31061 L
.67776 .30089 L
.67968 .29574 L
.68157 .29118 L
.68557 .28147 L
.68928 .27176 L
.68939 .27144 L
.69324 .26204 L
.69711 .25233 L
.69911 .24684 L
.70081 .24262 L
.70473 .23291 L
.7084 .22319 L
.70882 .22195 L
.7122 .21348 L
.71603 .20377 L
.71853 .19677 L
.7196 .19406 L
.72344 .18434 L
.72712 .17463 L
.72824 .1713 L
.73074 .16492 L
.73452 .15521 L
.73796 .14555 L
.73798 .14549 L
.74174 .13578 L
.74543 .12607 L
.74767 .11953 L
.74888 .11636 L
.75261 .10664 L
.75617 .09693 L
.75738 .09322 L
.75966 .08722 L
.76334 .07751 L
.76674 .06779 L
.76709 .06664 L
.77031 .05808 L
.77393 .04837 L
Mistroke
.77681 .03979 L
.77723 .03866 L
.78085 .02894 L
.78439 .01923 L
Mfstroke
.5 g
.3053 .98077 m
.31061 .97546 L
.31502 .97106 L
.32032 .96575 L
.32473 .96134 L
.33003 .95604 L
.33446 .95163 L
.33974 .94633 L
.34425 .94192 L
.34946 .93689 L
.35402 .93221 L
.35917 .92666 L
.36296 .92249 L
.36888 .91572 L
.3714 .91278 L
.37859 .9041 L
.37944 .90307 L
.38716 .89336 L
.38831 .89187 L
.3946 .88364 L
.39802 .87904 L
.40178 .87393 L
.40773 .86564 L
.40874 .86422 L
.41553 .85451 L
.41744 .85171 L
.42215 .84479 L
.42716 .83726 L
.4286 .83508 L
.43492 .82537 L
.43687 .82231 L
.44111 .81566 L
.44658 .80689 L
.44717 .80594 L
.45314 .79623 L
.45629 .791 L
.45899 .78652 L
.46475 .77681 L
.46601 .77465 L
.47043 .76709 L
.47572 .75787 L
.476 .75738 L
.48152 .74767 L
.48543 .74067 L
.48694 .73796 L
.49232 .72824 L
.49514 .72304 L
.4976 .71853 L
.50284 .70882 L
.50486 .70501 L
.508 .69911 L
.51312 .68939 L
.51457 .68659 L
.51817 .67968 L
.52317 .66997 L
.52428 .66777 L
.52812 .66026 L
.53302 .65054 L
.53399 .64858 L
.53788 .64083 L
.54268 .63112 L
.54371 .62902 L
.54745 .62141 L
.55217 .61169 L
.55342 .60909 L
.55685 .60198 L
.5615 .59227 L
.56313 .5888 L
.5661 .58256 L
.57067 .57284 L
.57284 .56816 L
.57519 .56313 L
.57971 .55342 L
.58256 .54717 L
.58415 .54371 L
.5886 .53399 L
.59227 .52585 L
.59298 .52428 L
.59737 .51457 L
.60169 .50486 L
.60198 .50418 L
.60601 .49514 L
.61029 .48543 L
.61169 .4822 L
.61454 .47572 L
.61878 .46601 L
.62141 .45988 L
.62296 .45629 L
.62716 .44658 L
.63112 .43724 L
.63128 .43687 L
.63543 .42716 L
.63953 .41744 L
.64083 .4143 L
.6436 .40773 L
.64767 .39802 L
.65054 .39104 L
.65168 .38831 L
.65572 .37859 L
.65969 .36888 L
.66026 .36747 L
.66367 .35917 L
.66763 .34946 L
.66997 .3436 L
.67153 .33974 L
.67547 .33003 L
.67933 .32032 L
.67968 .31943 L
.68322 .31061 L
.68708 .30089 L
.68939 .29497 L
.69089 .29118 L
.69474 .28147 L
.69852 .27176 L
.69911 .27021 L
.7023 .26204 L
.70609 .25233 L
.70882 .24517 L
.7098 .24262 L
.71357 .23291 L
.71728 .22319 L
.71853 .21984 L
.72097 .21348 L
.72468 .20377 L
.72824 .19423 L
.72831 .19406 L
.73199 .18434 L
.73564 .17463 L
.73796 .16834 L
.73924 .16492 L
.74288 .15521 L
.74647 .14549 L
.74767 .14218 L
.75004 .13578 L
.75364 .12607 L
.75716 .11636 L
.75738 .11574 L
.76072 .10664 L
.76428 .09693 L
.76709 .08903 L
.76775 .08722 L
.77129 .07751 L
.77479 .06779 L
.77681 .06206 L
.77824 .05808 L
.78174 .04837 L
.78519 .03866 L
.78652 .03482 L
.78861 .02894 L
.79208 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.3053 .98077 m
.31061 .97546 L
.31502 .97106 L
.32032 .96575 L
.32473 .96134 L
.33003 .95604 L
.33446 .95163 L
.33974 .94633 L
.34425 .94192 L
.34946 .93689 L
.35402 .93221 L
.35917 .92666 L
.36296 .92249 L
.36888 .91572 L
.3714 .91278 L
.37859 .9041 L
.37944 .90307 L
.38716 .89336 L
.38831 .89187 L
.3946 .88364 L
.39802 .87904 L
.40178 .87393 L
.40773 .86564 L
.40874 .86422 L
.41553 .85451 L
.41744 .85171 L
.42215 .84479 L
.42716 .83726 L
.4286 .83508 L
.43492 .82537 L
.43687 .82231 L
.44111 .81566 L
.44658 .80689 L
.44717 .80594 L
.45314 .79623 L
.45629 .791 L
.45899 .78652 L
.46475 .77681 L
.46601 .77465 L
.47043 .76709 L
.47572 .75787 L
.476 .75738 L
.48152 .74767 L
.48543 .74067 L
.48694 .73796 L
.49232 .72824 L
.49514 .72304 L
.4976 .71853 L
.50284 .70882 L
.50486 .70501 L
Mistroke
.508 .69911 L
.51312 .68939 L
.51457 .68659 L
.51817 .67968 L
.52317 .66997 L
.52428 .66777 L
.52812 .66026 L
.53302 .65054 L
.53399 .64858 L
.53788 .64083 L
.54268 .63112 L
.54371 .62902 L
.54745 .62141 L
.55217 .61169 L
.55342 .60909 L
.55685 .60198 L
.5615 .59227 L
.56313 .5888 L
.5661 .58256 L
.57067 .57284 L
.57284 .56816 L
.57519 .56313 L
.57971 .55342 L
.58256 .54717 L
.58415 .54371 L
.5886 .53399 L
.59227 .52585 L
.59298 .52428 L
.59737 .51457 L
.60169 .50486 L
.60198 .50418 L
.60601 .49514 L
.61029 .48543 L
.61169 .4822 L
.61454 .47572 L
.61878 .46601 L
.62141 .45988 L
.62296 .45629 L
.62716 .44658 L
.63112 .43724 L
.63128 .43687 L
.63543 .42716 L
.63953 .41744 L
.64083 .4143 L
.6436 .40773 L
.64767 .39802 L
.65054 .39104 L
.65168 .38831 L
.65572 .37859 L
.65969 .36888 L
Mistroke
.66026 .36747 L
.66367 .35917 L
.66763 .34946 L
.66997 .3436 L
.67153 .33974 L
.67547 .33003 L
.67933 .32032 L
.67968 .31943 L
.68322 .31061 L
.68708 .30089 L
.68939 .29497 L
.69089 .29118 L
.69474 .28147 L
.69852 .27176 L
.69911 .27021 L
.7023 .26204 L
.70609 .25233 L
.70882 .24517 L
.7098 .24262 L
.71357 .23291 L
.71728 .22319 L
.71853 .21984 L
.72097 .21348 L
.72468 .20377 L
.72824 .19423 L
.72831 .19406 L
.73199 .18434 L
.73564 .17463 L
.73796 .16834 L
.73924 .16492 L
.74288 .15521 L
.74647 .14549 L
.74767 .14218 L
.75004 .13578 L
.75364 .12607 L
.75716 .11636 L
.75738 .11574 L
.76072 .10664 L
.76428 .09693 L
.76709 .08903 L
.76775 .08722 L
.77129 .07751 L
.77479 .06779 L
.77681 .06206 L
.77824 .05808 L
.78174 .04837 L
.78519 .03866 L
.78652 .03482 L
.78861 .02894 L
.79208 .01923 L
Mistroke
Mfstroke
.6 g
.34065 .98077 m
.34944 .97106 L
.34946 .97104 L
.35783 .96134 L
.35917 .95975 L
.36587 .95163 L
.36888 .94789 L
.37361 .94192 L
.37859 .93547 L
.38108 .93221 L
.38831 .92252 L
.38833 .92249 L
.39537 .91278 L
.39802 .90905 L
.40222 .90307 L
.40773 .89508 L
.40891 .89336 L
.41544 .88364 L
.41744 .88062 L
.42183 .87393 L
.42716 .86569 L
.4281 .86422 L
.43424 .85451 L
.43687 .8503 L
.44027 .84479 L
.44621 .83508 L
.44658 .83446 L
.45204 .82537 L
.45629 .81818 L
.45778 .81566 L
.46343 .80594 L
.46601 .80148 L
.46901 .79623 L
.47451 .78652 L
.47572 .78436 L
.47993 .77681 L
.48529 .76709 L
.48543 .76684 L
.49058 .75738 L
.49514 .74892 L
.49581 .74767 L
.50098 .73796 L
.50486 .73061 L
.50609 .72824 L
.51115 .71853 L
.51457 .71191 L
.51615 .70882 L
.52111 .69911 L
.52428 .69285 L
.52601 .68939 L
.53088 .67968 L
.53399 .67341 L
.53569 .66997 L
.54046 .66026 L
.54371 .65362 L
.54519 .65054 L
.54988 .64083 L
.55342 .63346 L
.55453 .63112 L
.55915 .62141 L
.56313 .61297 L
.56372 .61169 L
.56826 .60198 L
.57278 .59227 L
.57284 .59212 L
.57724 .58256 L
.58169 .57284 L
.58256 .57094 L
.58609 .56313 L
.59048 .55342 L
.59227 .54943 L
.59481 .54371 L
.59914 .53399 L
.60198 .52759 L
.60343 .52428 L
.6077 .51457 L
.61169 .50543 L
.61194 .50486 L
.61614 .49514 L
.62034 .48543 L
.62141 .48295 L
.62448 .47572 L
.62863 .46601 L
.63112 .46015 L
.63273 .45629 L
.63683 .44658 L
.64083 .43705 L
.6409 .43687 L
.64493 .42716 L
.64897 .41744 L
.65054 .41363 L
.65295 .40773 L
.65695 .39802 L
.66026 .38992 L
.66091 .38831 L
.66484 .37859 L
.66877 .36888 L
.66997 .36591 L
.67265 .35917 L
.67655 .34946 L
.67968 .34161 L
.68041 .33974 L
.68425 .33003 L
.68809 .32032 L
.68939 .31701 L
.69188 .31061 L
.69569 .30089 L
.69911 .29213 L
.69947 .29118 L
.70321 .28147 L
.70697 .27176 L
.70882 .26696 L
.71068 .26204 L
.7144 .25233 L
.71811 .24262 L
.71853 .24151 L
.72176 .23291 L
.72545 .22319 L
.72824 .21578 L
.72909 .21348 L
.73272 .20377 L
.73636 .19406 L
.73796 .18978 L
.73995 .18434 L
.74355 .17463 L
.74715 .16492 L
.74767 .1635 L
.75068 .15521 L
.75426 .14549 L
.75738 .13695 L
.7578 .13578 L
.76131 .12607 L
.76485 .11636 L
.76709 .11014 L
.76833 .10664 L
.77182 .09693 L
.77532 .08722 L
.77681 .08306 L
.77876 .07751 L
.78222 .06779 L
.78569 .05808 L
.78652 .05573 L
.78908 .04837 L
.79252 .03866 L
.79595 .02894 L
.79623 .02813 L
.79931 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.34065 .98077 m
.34944 .97106 L
.34946 .97104 L
.35783 .96134 L
.35917 .95975 L
.36587 .95163 L
.36888 .94789 L
.37361 .94192 L
.37859 .93547 L
.38108 .93221 L
.38831 .92252 L
.38833 .92249 L
.39537 .91278 L
.39802 .90905 L
.40222 .90307 L
.40773 .89508 L
.40891 .89336 L
.41544 .88364 L
.41744 .88062 L
.42183 .87393 L
.42716 .86569 L
.4281 .86422 L
.43424 .85451 L
.43687 .8503 L
.44027 .84479 L
.44621 .83508 L
.44658 .83446 L
.45204 .82537 L
.45629 .81818 L
.45778 .81566 L
.46343 .80594 L
.46601 .80148 L
.46901 .79623 L
.47451 .78652 L
.47572 .78436 L
.47993 .77681 L
.48529 .76709 L
.48543 .76684 L
.49058 .75738 L
.49514 .74892 L
.49581 .74767 L
.50098 .73796 L
.50486 .73061 L
.50609 .72824 L
.51115 .71853 L
.51457 .71191 L
.51615 .70882 L
.52111 .69911 L
.52428 .69285 L
.52601 .68939 L
Mistroke
.53088 .67968 L
.53399 .67341 L
.53569 .66997 L
.54046 .66026 L
.54371 .65362 L
.54519 .65054 L
.54988 .64083 L
.55342 .63346 L
.55453 .63112 L
.55915 .62141 L
.56313 .61297 L
.56372 .61169 L
.56826 .60198 L
.57278 .59227 L
.57284 .59212 L
.57724 .58256 L
.58169 .57284 L
.58256 .57094 L
.58609 .56313 L
.59048 .55342 L
.59227 .54943 L
.59481 .54371 L
.59914 .53399 L
.60198 .52759 L
.60343 .52428 L
.6077 .51457 L
.61169 .50543 L
.61194 .50486 L
.61614 .49514 L
.62034 .48543 L
.62141 .48295 L
.62448 .47572 L
.62863 .46601 L
.63112 .46015 L
.63273 .45629 L
.63683 .44658 L
.64083 .43705 L
.6409 .43687 L
.64493 .42716 L
.64897 .41744 L
.65054 .41363 L
.65295 .40773 L
.65695 .39802 L
.66026 .38992 L
.66091 .38831 L
.66484 .37859 L
.66877 .36888 L
.66997 .36591 L
.67265 .35917 L
.67655 .34946 L
Mistroke
.67968 .34161 L
.68041 .33974 L
.68425 .33003 L
.68809 .32032 L
.68939 .31701 L
.69188 .31061 L
.69569 .30089 L
.69911 .29213 L
.69947 .29118 L
.70321 .28147 L
.70697 .27176 L
.70882 .26696 L
.71068 .26204 L
.7144 .25233 L
.71811 .24262 L
.71853 .24151 L
.72176 .23291 L
.72545 .22319 L
.72824 .21578 L
.72909 .21348 L
.73272 .20377 L
.73636 .19406 L
.73796 .18978 L
.73995 .18434 L
.74355 .17463 L
.74715 .16492 L
.74767 .1635 L
.75068 .15521 L
.75426 .14549 L
.75738 .13695 L
.7578 .13578 L
.76131 .12607 L
.76485 .11636 L
.76709 .11014 L
.76833 .10664 L
.77182 .09693 L
.77532 .08722 L
.77681 .08306 L
.77876 .07751 L
.78222 .06779 L
.78569 .05808 L
.78652 .05573 L
.78908 .04837 L
.79252 .03866 L
.79595 .02894 L
.79623 .02813 L
.79931 .01923 L
Mfstroke
.7 g
.37236 .98077 m
.37859 .97195 L
.3792 .97106 L
.38591 .96134 L
.38831 .95784 L
.39249 .95163 L
.39802 .94338 L
.39898 .94192 L
.40534 .93221 L
.40773 .92853 L
.41158 .92249 L
.41744 .9133 L
.41777 .91278 L
.4238 .90307 L
.42716 .89765 L
.42975 .89336 L
.43566 .88364 L
.43687 .88163 L
.44141 .87393 L
.44658 .86521 L
.44715 .86422 L
.45276 .85451 L
.45629 .84839 L
.45831 .84479 L
.46381 .83508 L
.46601 .83119 L
.4692 .82537 L
.47459 .81566 L
.47572 .81362 L
.47984 .80594 L
.48513 .79623 L
.48543 .79567 L
.49025 .78652 L
.49514 .77735 L
.49542 .77681 L
.50044 .76709 L
.50486 .75865 L
.50549 .75738 L
.51043 .74767 L
.51457 .73961 L
.51537 .73796 L
.52022 .72824 L
.52428 .7202 L
.52508 .71853 L
.52984 .70882 L
.53399 .70045 L
.53462 .69911 L
.5393 .68939 L
.54371 .68036 L
.54402 .67968 L
.54859 .66997 L
.55326 .66026 L
.55342 .65993 L
.55774 .65054 L
.56234 .64083 L
.56313 .63915 L
.56676 .63112 L
.57129 .62141 L
.57284 .61805 L
.57565 .61169 L
.5801 .60198 L
.58256 .59662 L
.58443 .59227 L
.58879 .58256 L
.59227 .57487 L
.59312 .57284 L
.59737 .56313 L
.60171 .55342 L
.60198 .55281 L
.60585 .54371 L
.61013 .53399 L
.61169 .53042 L
.61423 .52428 L
.61844 .51457 L
.62141 .50773 L
.62256 .50486 L
.62665 .49514 L
.63083 .48543 L
.63112 .48474 L
.63478 .47572 L
.6389 .46601 L
.64083 .46144 L
.64285 .45629 L
.64688 .44658 L
.65054 .43785 L
.65091 .43687 L
.65479 .42716 L
.65882 .41744 L
.66026 .41395 L
.66264 .40773 L
.66659 .39802 L
.66997 .38977 L
.6705 .38831 L
.6743 .37859 L
.67824 .36888 L
.67968 .36529 L
.68196 .35917 L
.68582 .34946 L
.68939 .34054 L
.68967 .33974 L
.69335 .33003 L
.6972 .32032 L
.69911 .31549 L
.70086 .31061 L
.70461 .30089 L
.70843 .29118 L
.70882 .29018 L
.71198 .28147 L
.71575 .27176 L
.71853 .26458 L
.7194 .26204 L
.723 .25233 L
.72675 .24262 L
.72824 .23871 L
.73026 .23291 L
.73391 .22319 L
.73761 .21348 L
.73796 .21257 L
.74104 .20377 L
.74469 .19406 L
.74767 .18615 L
.74825 .18434 L
.75172 .17463 L
.75535 .16492 L
.75738 .15947 L
.75878 .15521 L
.76229 .14549 L
.7659 .13578 L
.76709 .13253 L
.76924 .12607 L
.77276 .11636 L
.77633 .10664 L
.77681 .10534 L
.7796 .09693 L
.78312 .08722 L
.78652 .07788 L
.78663 .07751 L
.78987 .06779 L
.79338 .05808 L
.79623 .05016 L
.79677 .04837 L
.80005 .03866 L
.80353 .02894 L
.80594 .02221 L
.80684 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.37236 .98077 m
.37859 .97195 L
.3792 .97106 L
.38591 .96134 L
.38831 .95784 L
.39249 .95163 L
.39802 .94338 L
.39898 .94192 L
.40534 .93221 L
.40773 .92853 L
.41158 .92249 L
.41744 .9133 L
.41777 .91278 L
.4238 .90307 L
.42716 .89765 L
.42975 .89336 L
.43566 .88364 L
.43687 .88163 L
.44141 .87393 L
.44658 .86521 L
.44715 .86422 L
.45276 .85451 L
.45629 .84839 L
.45831 .84479 L
.46381 .83508 L
.46601 .83119 L
.4692 .82537 L
.47459 .81566 L
.47572 .81362 L
.47984 .80594 L
.48513 .79623 L
.48543 .79567 L
.49025 .78652 L
.49514 .77735 L
.49542 .77681 L
.50044 .76709 L
.50486 .75865 L
.50549 .75738 L
.51043 .74767 L
.51457 .73961 L
.51537 .73796 L
.52022 .72824 L
.52428 .7202 L
.52508 .71853 L
.52984 .70882 L
.53399 .70045 L
.53462 .69911 L
.5393 .68939 L
.54371 .68036 L
.54402 .67968 L
Mistroke
.54859 .66997 L
.55326 .66026 L
.55342 .65993 L
.55774 .65054 L
.56234 .64083 L
.56313 .63915 L
.56676 .63112 L
.57129 .62141 L
.57284 .61805 L
.57565 .61169 L
.5801 .60198 L
.58256 .59662 L
.58443 .59227 L
.58879 .58256 L
.59227 .57487 L
.59312 .57284 L
.59737 .56313 L
.60171 .55342 L
.60198 .55281 L
.60585 .54371 L
.61013 .53399 L
.61169 .53042 L
.61423 .52428 L
.61844 .51457 L
.62141 .50773 L
.62256 .50486 L
.62665 .49514 L
.63083 .48543 L
.63112 .48474 L
.63478 .47572 L
.6389 .46601 L
.64083 .46144 L
.64285 .45629 L
.64688 .44658 L
.65054 .43785 L
.65091 .43687 L
.65479 .42716 L
.65882 .41744 L
.66026 .41395 L
.66264 .40773 L
.66659 .39802 L
.66997 .38977 L
.6705 .38831 L
.6743 .37859 L
.67824 .36888 L
.67968 .36529 L
.68196 .35917 L
.68582 .34946 L
.68939 .34054 L
.68967 .33974 L
Mistroke
.69335 .33003 L
.6972 .32032 L
.69911 .31549 L
.70086 .31061 L
.70461 .30089 L
.70843 .29118 L
.70882 .29018 L
.71198 .28147 L
.71575 .27176 L
.71853 .26458 L
.7194 .26204 L
.723 .25233 L
.72675 .24262 L
.72824 .23871 L
.73026 .23291 L
.73391 .22319 L
.73761 .21348 L
.73796 .21257 L
.74104 .20377 L
.74469 .19406 L
.74767 .18615 L
.74825 .18434 L
.75172 .17463 L
.75535 .16492 L
.75738 .15947 L
.75878 .15521 L
.76229 .14549 L
.7659 .13578 L
.76709 .13253 L
.76924 .12607 L
.77276 .11636 L
.77633 .10664 L
.77681 .10534 L
.7796 .09693 L
.78312 .08722 L
.78652 .07788 L
.78663 .07751 L
.78987 .06779 L
.79338 .05808 L
.79623 .05016 L
.79677 .04837 L
.80005 .03866 L
.80353 .02894 L
.80594 .02221 L
.80684 .01923 L
Mfstroke
.6 g
.44458 .98077 m
.44658 .97746 L
.4508 .97106 L
.45629 .96217 L
.45681 .96134 L
.46289 .95163 L
.46601 .94633 L
.46871 .94192 L
.47449 .93221 L
.47572 .93001 L
.48019 .92249 L
.48543 .91322 L
.48569 .91278 L
.4913 .90307 L
.49514 .896 L
.49664 .89336 L
.50208 .88364 L
.50486 .87836 L
.5073 .87393 L
.51257 .86422 L
.51457 .86028 L
.5177 .85451 L
.52281 .84479 L
.52428 .84181 L
.52784 .83508 L
.53282 .82537 L
.53399 .82293 L
.53777 .81566 L
.54264 .80594 L
.54371 .80366 L
.54749 .79623 L
.55227 .78652 L
.55342 .78402 L
.55702 .77681 L
.56173 .76709 L
.56313 .764 L
.56638 .75738 L
.57104 .74767 L
.57284 .74362 L
.57558 .73796 L
.58018 .72824 L
.58256 .72288 L
.58462 .71853 L
.58918 .70882 L
.59227 .70179 L
.59352 .69911 L
.59804 .68939 L
.60198 .68035 L
.60229 .67968 L
.60675 .66997 L
.61102 .66026 L
.61169 .65858 L
.61534 .65054 L
.61963 .64083 L
.62141 .63648 L
.6238 .63112 L
.62809 .62141 L
.63112 .61404 L
.63215 .61169 L
.63642 .60198 L
.64046 .59227 L
.64083 .59128 L
.64463 .58256 L
.64874 .57284 L
.65054 .56821 L
.65272 .56313 L
.65686 .55342 L
.66026 .54482 L
.66073 .54371 L
.66484 .53399 L
.6688 .52428 L
.66997 .52113 L
.67271 .51457 L
.67674 .50486 L
.67968 .49712 L
.6805 .49514 L
.68451 .48543 L
.68836 .47572 L
.68939 .47282 L
.69218 .46601 L
.69611 .45629 L
.69911 .44822 L
.69977 .44658 L
.7037 .43687 L
.70748 .42716 L
.70882 .42334 L
.71117 .41744 L
.71503 .40773 L
.71853 .39815 L
.71858 .39802 L
.72243 .38831 L
.72618 .37859 L
.72824 .37269 L
.72973 .36888 L
.73353 .35917 L
.73713 .34946 L
.73796 .34694 L
.74074 .33974 L
.74448 .33003 L
.74767 .32091 L
.74789 .32032 L
.75162 .31061 L
.75527 .30089 L
.75738 .2946 L
.75868 .29118 L
.76237 .28147 L
.7659 .27176 L
.76709 .26803 L
.76934 .26204 L
.77299 .25233 L
.77637 .24262 L
.77681 .24118 L
.77989 .23291 L
.78348 .22319 L
.78652 .21406 L
.78673 .21348 L
.79032 .20377 L
.79385 .19406 L
.79623 .18668 L
.79708 .18434 L
.80064 .17463 L
.8041 .16492 L
.80594 .15904 L
.80733 .15521 L
.81086 .14549 L
.81425 .13578 L
.81566 .13113 L
.81747 .12607 L
.82097 .11636 L
.82429 .10664 L
.82537 .10297 L
.82752 .09693 L
.83099 .08722 L
.83424 .07751 L
.83508 .07456 L
.83747 .06779 L
.84091 .05808 L
.8441 .04837 L
.84479 .04589 L
.84733 .03866 L
.85073 .02894 L
.85389 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.44458 .98077 m
.44658 .97746 L
.4508 .97106 L
.45629 .96217 L
.45681 .96134 L
.46289 .95163 L
.46601 .94633 L
.46871 .94192 L
.47449 .93221 L
.47572 .93001 L
.48019 .92249 L
.48543 .91322 L
.48569 .91278 L
.4913 .90307 L
.49514 .896 L
.49664 .89336 L
.50208 .88364 L
.50486 .87836 L
.5073 .87393 L
.51257 .86422 L
.51457 .86028 L
.5177 .85451 L
.52281 .84479 L
.52428 .84181 L
.52784 .83508 L
.53282 .82537 L
.53399 .82293 L
.53777 .81566 L
.54264 .80594 L
.54371 .80366 L
.54749 .79623 L
.55227 .78652 L
.55342 .78402 L
.55702 .77681 L
.56173 .76709 L
.56313 .764 L
.56638 .75738 L
.57104 .74767 L
.57284 .74362 L
.57558 .73796 L
.58018 .72824 L
.58256 .72288 L
.58462 .71853 L
.58918 .70882 L
.59227 .70179 L
.59352 .69911 L
.59804 .68939 L
.60198 .68035 L
.60229 .67968 L
.60675 .66997 L
Mistroke
.61102 .66026 L
.61169 .65858 L
.61534 .65054 L
.61963 .64083 L
.62141 .63648 L
.6238 .63112 L
.62809 .62141 L
.63112 .61404 L
.63215 .61169 L
.63642 .60198 L
.64046 .59227 L
.64083 .59128 L
.64463 .58256 L
.64874 .57284 L
.65054 .56821 L
.65272 .56313 L
.65686 .55342 L
.66026 .54482 L
.66073 .54371 L
.66484 .53399 L
.6688 .52428 L
.66997 .52113 L
.67271 .51457 L
.67674 .50486 L
.67968 .49712 L
.6805 .49514 L
.68451 .48543 L
.68836 .47572 L
.68939 .47282 L
.69218 .46601 L
.69611 .45629 L
.69911 .44822 L
.69977 .44658 L
.7037 .43687 L
.70748 .42716 L
.70882 .42334 L
.71117 .41744 L
.71503 .40773 L
.71853 .39815 L
.71858 .39802 L
.72243 .38831 L
.72618 .37859 L
.72824 .37269 L
.72973 .36888 L
.73353 .35917 L
.73713 .34946 L
.73796 .34694 L
.74074 .33974 L
.74448 .33003 L
.74767 .32091 L
Mistroke
.74789 .32032 L
.75162 .31061 L
.75527 .30089 L
.75738 .2946 L
.75868 .29118 L
.76237 .28147 L
.7659 .27176 L
.76709 .26803 L
.76934 .26204 L
.77299 .25233 L
.77637 .24262 L
.77681 .24118 L
.77989 .23291 L
.78348 .22319 L
.78652 .21406 L
.78673 .21348 L
.79032 .20377 L
.79385 .19406 L
.79623 .18668 L
.79708 .18434 L
.80064 .17463 L
.8041 .16492 L
.80594 .15904 L
.80733 .15521 L
.81086 .14549 L
.81425 .13578 L
.81566 .13113 L
.81747 .12607 L
.82097 .11636 L
.82429 .10664 L
.82537 .10297 L
.82752 .09693 L
.83099 .08722 L
.83424 .07751 L
.83508 .07456 L
.83747 .06779 L
.84091 .05808 L
.8441 .04837 L
.84479 .04589 L
.84733 .03866 L
.85073 .02894 L
.85389 .01923 L
Mfstroke
.5 g
.46324 .98077 m
.46601 .97603 L
.46893 .97106 L
.47453 .96134 L
.47572 .95926 L
.48007 .95163 L
.48543 .94205 L
.4855 .94192 L
.4909 .93221 L
.49514 .92443 L
.4962 .92249 L
.50146 .91278 L
.50486 .9064 L
.50663 .90307 L
.51177 .89336 L
.51457 .88797 L
.51683 .88364 L
.52185 .87393 L
.52428 .86916 L
.52681 .86422 L
.53173 .85451 L
.53399 .84997 L
.53659 .84479 L
.54142 .83508 L
.54371 .8304 L
.54619 .82537 L
.55093 .81566 L
.55342 .81047 L
.55561 .80594 L
.56028 .79623 L
.56313 .79018 L
.56487 .78652 L
.56947 .77681 L
.57284 .76954 L
.57399 .76709 L
.57851 .75738 L
.58256 .74856 L
.58296 .74767 L
.58743 .73796 L
.59182 .72824 L
.59227 .72723 L
.59621 .71853 L
.60055 .70882 L
.60198 .70557 L
.60486 .69911 L
.60916 .68939 L
.61169 .68358 L
.61341 .67968 L
.61766 .66997 L
.62141 .66126 L
.62184 .66026 L
.62605 .65054 L
.63019 .64083 L
.63112 .63863 L
.63433 .63112 L
.63845 .62141 L
.64083 .61568 L
.64251 .61169 L
.6466 .60198 L
.65054 .59242 L
.65061 .59227 L
.65465 .58256 L
.65864 .57284 L
.66026 .56885 L
.66261 .56313 L
.66658 .55342 L
.66997 .54498 L
.67049 .54371 L
.67443 .53399 L
.67832 .52428 L
.67968 .52081 L
.68218 .51457 L
.68606 .50486 L
.68939 .49635 L
.68987 .49514 L
.69372 .48543 L
.69752 .47572 L
.69911 .4716 L
.70129 .46601 L
.70509 .45629 L
.70881 .44658 L
.70882 .44655 L
.71257 .43687 L
.7163 .42716 L
.71853 .42122 L
.71998 .41744 L
.7237 .40773 L
.72736 .39802 L
.72824 .39561 L
.73101 .38831 L
.73468 .37859 L
.73796 .36972 L
.73827 .36888 L
.74191 .35917 L
.74553 .34946 L
.74767 .34356 L
.74908 .33974 L
.75269 .33003 L
.75624 .32032 L
.75738 .31713 L
.75977 .31061 L
.76334 .30089 L
.76683 .29118 L
.76709 .29042 L
.77035 .28147 L
.77387 .27176 L
.77681 .26345 L
.77731 .26204 L
.78081 .25233 L
.78429 .24262 L
.78652 .23621 L
.78769 .23291 L
.79116 .22319 L
.79459 .21348 L
.79623 .20871 L
.79797 .20377 L
.80141 .19406 L
.80479 .18434 L
.80594 .18095 L
.80815 .17463 L
.81156 .16492 L
.8149 .15521 L
.81566 .15293 L
.81824 .14549 L
.82161 .13578 L
.82491 .12607 L
.82537 .12466 L
.82823 .11636 L
.83157 .10664 L
.83482 .09693 L
.83508 .09614 L
.83812 .08722 L
.84144 .07751 L
.84466 .06779 L
.84479 .06737 L
.84793 .05808 L
.85122 .04837 L
.85441 .03866 L
.85451 .03835 L
.85766 .02894 L
.86092 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.46324 .98077 m
.46601 .97603 L
.46893 .97106 L
.47453 .96134 L
.47572 .95926 L
.48007 .95163 L
.48543 .94205 L
.4855 .94192 L
.4909 .93221 L
.49514 .92443 L
.4962 .92249 L
.50146 .91278 L
.50486 .9064 L
.50663 .90307 L
.51177 .89336 L
.51457 .88797 L
.51683 .88364 L
.52185 .87393 L
.52428 .86916 L
.52681 .86422 L
.53173 .85451 L
.53399 .84997 L
.53659 .84479 L
.54142 .83508 L
.54371 .8304 L
.54619 .82537 L
.55093 .81566 L
.55342 .81047 L
.55561 .80594 L
.56028 .79623 L
.56313 .79018 L
.56487 .78652 L
.56947 .77681 L
.57284 .76954 L
.57399 .76709 L
.57851 .75738 L
.58256 .74856 L
.58296 .74767 L
.58743 .73796 L
.59182 .72824 L
.59227 .72723 L
.59621 .71853 L
.60055 .70882 L
.60198 .70557 L
.60486 .69911 L
.60916 .68939 L
.61169 .68358 L
.61341 .67968 L
.61766 .66997 L
.62141 .66126 L
Mistroke
.62184 .66026 L
.62605 .65054 L
.63019 .64083 L
.63112 .63863 L
.63433 .63112 L
.63845 .62141 L
.64083 .61568 L
.64251 .61169 L
.6466 .60198 L
.65054 .59242 L
.65061 .59227 L
.65465 .58256 L
.65864 .57284 L
.66026 .56885 L
.66261 .56313 L
.66658 .55342 L
.66997 .54498 L
.67049 .54371 L
.67443 .53399 L
.67832 .52428 L
.67968 .52081 L
.68218 .51457 L
.68606 .50486 L
.68939 .49635 L
.68987 .49514 L
.69372 .48543 L
.69752 .47572 L
.69911 .4716 L
.70129 .46601 L
.70509 .45629 L
.70881 .44658 L
.70882 .44655 L
.71257 .43687 L
.7163 .42716 L
.71853 .42122 L
.71998 .41744 L
.7237 .40773 L
.72736 .39802 L
.72824 .39561 L
.73101 .38831 L
.73468 .37859 L
.73796 .36972 L
.73827 .36888 L
.74191 .35917 L
.74553 .34946 L
.74767 .34356 L
.74908 .33974 L
.75269 .33003 L
.75624 .32032 L
.75738 .31713 L
Mistroke
.75977 .31061 L
.76334 .30089 L
.76683 .29118 L
.76709 .29042 L
.77035 .28147 L
.77387 .27176 L
.77681 .26345 L
.77731 .26204 L
.78081 .25233 L
.78429 .24262 L
.78652 .23621 L
.78769 .23291 L
.79116 .22319 L
.79459 .21348 L
.79623 .20871 L
.79797 .20377 L
.80141 .19406 L
.80479 .18434 L
.80594 .18095 L
.80815 .17463 L
.81156 .16492 L
.8149 .15521 L
.81566 .15293 L
.81824 .14549 L
.82161 .13578 L
.82491 .12607 L
.82537 .12466 L
.82823 .11636 L
.83157 .10664 L
.83482 .09693 L
.83508 .09614 L
.83812 .08722 L
.84144 .07751 L
.84466 .06779 L
.84479 .06737 L
.84793 .05808 L
.85122 .04837 L
.85441 .03866 L
.85451 .03835 L
.85766 .02894 L
.86092 .01923 L
Mfstroke
.4 g
.4785 .98077 m
.48388 .97106 L
.48543 .96822 L
.48918 .96134 L
.49443 .95163 L
.49514 .9503 L
.49961 .94192 L
.50474 .93221 L
.50486 .93199 L
.50981 .92249 L
.51457 .9133 L
.51483 .91278 L
.5198 .90307 L
.52428 .89423 L
.52472 .89336 L
.52959 .88364 L
.53399 .8748 L
.53442 .87393 L
.5392 .86422 L
.54371 .855 L
.54394 .85451 L
.54864 .84479 L
.55331 .83508 L
.55342 .83485 L
.55792 .82537 L
.56252 .81566 L
.56313 .81435 L
.56706 .80594 L
.57158 .79623 L
.57284 .79351 L
.57605 .78652 L
.58051 .77681 L
.58256 .77233 L
.58492 .76709 L
.58931 .75738 L
.59227 .75081 L
.59367 .74767 L
.598 .73796 L
.60198 .72897 L
.6023 .72824 L
.60656 .71853 L
.61082 .70882 L
.61169 .70681 L
.61502 .69911 L
.61923 .68939 L
.62141 .68433 L
.62338 .67968 L
.62753 .66997 L
.63112 .66153 L
.63165 .66026 L
.63574 .65054 L
.63983 .64083 L
.64083 .63843 L
.64386 .63112 L
.6479 .62141 L
.65054 .61502 L
.6519 .61169 L
.65589 .60198 L
.65986 .59227 L
.66026 .59131 L
.66379 .58256 L
.66773 .57284 L
.66997 .56729 L
.67162 .56313 L
.67551 .55342 L
.6794 .54371 L
.67968 .54299 L
.68322 .53399 L
.68707 .52428 L
.68939 .51839 L
.69088 .51457 L
.69468 .50486 L
.69847 .49514 L
.69911 .49351 L
.70221 .48543 L
.70598 .47572 L
.70882 .46834 L
.7097 .46601 L
.71341 .45629 L
.71713 .44658 L
.71853 .44289 L
.72079 .43687 L
.72447 .42716 L
.72814 .41744 L
.72824 .41716 L
.73175 .40773 L
.7354 .39802 L
.73796 .39116 L
.739 .38831 L
.74259 .37859 L
.7462 .36888 L
.74767 .36488 L
.74974 .35917 L
.75331 .34946 L
.75687 .33974 L
.75738 .33834 L
.76037 .33003 L
.76391 .32032 L
.76709 .31153 L
.76742 .31061 L
.77089 .30089 L
.77439 .29118 L
.77681 .28445 L
.77785 .28147 L
.7813 .27176 L
.78477 .26204 L
.78652 .25711 L
.78818 .25233 L
.79161 .24262 L
.79504 .23291 L
.79623 .22951 L
.79841 .22319 L
.80181 .21348 L
.80521 .20377 L
.80594 .20166 L
.80854 .19406 L
.81192 .18434 L
.81528 .17463 L
.81566 .17355 L
.81858 .16492 L
.82193 .15521 L
.82526 .14549 L
.82537 .14518 L
.82853 .13578 L
.83185 .12607 L
.83508 .11657 L
.83515 .11636 L
.83839 .10664 L
.84169 .09693 L
.84479 .08771 L
.84495 .08722 L
.84816 .07751 L
.85144 .06779 L
.85451 .0586 L
.85467 .05808 L
.85786 .04837 L
.8611 .03866 L
.86422 .02925 L
.86432 .02894 L
.86747 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.4785 .98077 m
.48388 .97106 L
.48543 .96822 L
.48918 .96134 L
.49443 .95163 L
.49514 .9503 L
.49961 .94192 L
.50474 .93221 L
.50486 .93199 L
.50981 .92249 L
.51457 .9133 L
.51483 .91278 L
.5198 .90307 L
.52428 .89423 L
.52472 .89336 L
.52959 .88364 L
.53399 .8748 L
.53442 .87393 L
.5392 .86422 L
.54371 .855 L
.54394 .85451 L
.54864 .84479 L
.55331 .83508 L
.55342 .83485 L
.55792 .82537 L
.56252 .81566 L
.56313 .81435 L
.56706 .80594 L
.57158 .79623 L
.57284 .79351 L
.57605 .78652 L
.58051 .77681 L
.58256 .77233 L
.58492 .76709 L
.58931 .75738 L
.59227 .75081 L
.59367 .74767 L
.598 .73796 L
.60198 .72897 L
.6023 .72824 L
.60656 .71853 L
.61082 .70882 L
.61169 .70681 L
.61502 .69911 L
.61923 .68939 L
.62141 .68433 L
.62338 .67968 L
.62753 .66997 L
.63112 .66153 L
.63165 .66026 L
Mistroke
.63574 .65054 L
.63983 .64083 L
.64083 .63843 L
.64386 .63112 L
.6479 .62141 L
.65054 .61502 L
.6519 .61169 L
.65589 .60198 L
.65986 .59227 L
.66026 .59131 L
.66379 .58256 L
.66773 .57284 L
.66997 .56729 L
.67162 .56313 L
.67551 .55342 L
.6794 .54371 L
.67968 .54299 L
.68322 .53399 L
.68707 .52428 L
.68939 .51839 L
.69088 .51457 L
.69468 .50486 L
.69847 .49514 L
.69911 .49351 L
.70221 .48543 L
.70598 .47572 L
.70882 .46834 L
.7097 .46601 L
.71341 .45629 L
.71713 .44658 L
.71853 .44289 L
.72079 .43687 L
.72447 .42716 L
.72814 .41744 L
.72824 .41716 L
.73175 .40773 L
.7354 .39802 L
.73796 .39116 L
.739 .38831 L
.74259 .37859 L
.7462 .36888 L
.74767 .36488 L
.74974 .35917 L
.75331 .34946 L
.75687 .33974 L
.75738 .33834 L
.76037 .33003 L
.76391 .32032 L
.76709 .31153 L
.76742 .31061 L
Mistroke
.77089 .30089 L
.77439 .29118 L
.77681 .28445 L
.77785 .28147 L
.7813 .27176 L
.78477 .26204 L
.78652 .25711 L
.78818 .25233 L
.79161 .24262 L
.79504 .23291 L
.79623 .22951 L
.79841 .22319 L
.80181 .21348 L
.80521 .20377 L
.80594 .20166 L
.80854 .19406 L
.81192 .18434 L
.81528 .17463 L
.81566 .17355 L
.81858 .16492 L
.82193 .15521 L
.82526 .14549 L
.82537 .14518 L
.82853 .13578 L
.83185 .12607 L
.83508 .11657 L
.83515 .11636 L
.83839 .10664 L
.84169 .09693 L
.84479 .08771 L
.84495 .08722 L
.84816 .07751 L
.85144 .06779 L
.85451 .0586 L
.85467 .05808 L
.85786 .04837 L
.8611 .03866 L
.86422 .02925 L
.86432 .02894 L
.86747 .01923 L
Mfstroke
.3 g
.49406 .98077 m
.49514 .97874 L
.49909 .97106 L
.50418 .96134 L
.50486 .96004 L
.5091 .95163 L
.5141 .94192 L
.51457 .94099 L
.51892 .93221 L
.52383 .92249 L
.52428 .92159 L
.52856 .91278 L
.53339 .90307 L
.53399 .90184 L
.53804 .89336 L
.54278 .88364 L
.54371 .88174 L
.54736 .87393 L
.55203 .86422 L
.55342 .8613 L
.55653 .85451 L
.56112 .84479 L
.56313 .84053 L
.56557 .83508 L
.57008 .82537 L
.57284 .81943 L
.57449 .81566 L
.57891 .80594 L
.58256 .79801 L
.58331 .79623 L
.58762 .78652 L
.59202 .77681 L
.59227 .77626 L
.59622 .76709 L
.60056 .75738 L
.60198 .75419 L
.60472 .74767 L
.60899 .73796 L
.61169 .73181 L
.61315 .72824 L
.61731 .71853 L
.62141 .70912 L
.62153 .70882 L
.62555 .69911 L
.62972 .68939 L
.63112 .68612 L
.6337 .67968 L
.63781 .66997 L
.64083 .66282 L
.64182 .66026 L
.6458 .65054 L
.64988 .64083 L
.65054 .63923 L
.65373 .63112 L
.65775 .62141 L
.66026 .61533 L
.66163 .61169 L
.66553 .60198 L
.66952 .59227 L
.66997 .59116 L
.67326 .58256 L
.67719 .57284 L
.67968 .56668 L
.68098 .56313 L
.68479 .55342 L
.68868 .54371 L
.68939 .54192 L
.69234 .53399 L
.69618 .52428 L
.69911 .51688 L
.69992 .51457 L
.7036 .50486 L
.70742 .49514 L
.70882 .49156 L
.71101 .48543 L
.71474 .47572 L
.71852 .46601 L
.71853 .46597 L
.72202 .45629 L
.72575 .44658 L
.72824 .44009 L
.72934 .43687 L
.73293 .42716 L
.73663 .41744 L
.73796 .41395 L
.74009 .40773 L
.74372 .39802 L
.74738 .38831 L
.74767 .38754 L
.75077 .37859 L
.75439 .36888 L
.75738 .36086 L
.75792 .35917 L
.76134 .34946 L
.76494 .33974 L
.76709 .33392 L
.76835 .33003 L
.77181 .32032 L
.77539 .31061 L
.77681 .30672 L
.7787 .30089 L
.78218 .29118 L
.78572 .28147 L
.78652 .27926 L
.78897 .27176 L
.79244 .26204 L
.79595 .25233 L
.79623 .25154 L
.79914 .24262 L
.80261 .23291 L
.80594 .22357 L
.80605 .22319 L
.80923 .21348 L
.81267 .20377 L
.81566 .19535 L
.81603 .19406 L
.81922 .18434 L
.82265 .17463 L
.82537 .16687 L
.82593 .16492 L
.82913 .15521 L
.83253 .14549 L
.83508 .13815 L
.83576 .13578 L
.83894 .12607 L
.84232 .11636 L
.84479 .10919 L
.84551 .10664 L
.84867 .09693 L
.85203 .08722 L
.85451 .07998 L
.8552 .07751 L
.85832 .06779 L
.86165 .05808 L
.86422 .05053 L
.86481 .04837 L
.86789 .03866 L
.87119 .02894 L
.87393 .02086 L
.87436 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.49406 .98077 m
.49514 .97874 L
.49909 .97106 L
.50418 .96134 L
.50486 .96004 L
.5091 .95163 L
.5141 .94192 L
.51457 .94099 L
.51892 .93221 L
.52383 .92249 L
.52428 .92159 L
.52856 .91278 L
.53339 .90307 L
.53399 .90184 L
.53804 .89336 L
.54278 .88364 L
.54371 .88174 L
.54736 .87393 L
.55203 .86422 L
.55342 .8613 L
.55653 .85451 L
.56112 .84479 L
.56313 .84053 L
.56557 .83508 L
.57008 .82537 L
.57284 .81943 L
.57449 .81566 L
.57891 .80594 L
.58256 .79801 L
.58331 .79623 L
.58762 .78652 L
.59202 .77681 L
.59227 .77626 L
.59622 .76709 L
.60056 .75738 L
.60198 .75419 L
.60472 .74767 L
.60899 .73796 L
.61169 .73181 L
.61315 .72824 L
.61731 .71853 L
.62141 .70912 L
.62153 .70882 L
.62555 .69911 L
.62972 .68939 L
.63112 .68612 L
.6337 .67968 L
.63781 .66997 L
.64083 .66282 L
.64182 .66026 L
Mistroke
.6458 .65054 L
.64988 .64083 L
.65054 .63923 L
.65373 .63112 L
.65775 .62141 L
.66026 .61533 L
.66163 .61169 L
.66553 .60198 L
.66952 .59227 L
.66997 .59116 L
.67326 .58256 L
.67719 .57284 L
.67968 .56668 L
.68098 .56313 L
.68479 .55342 L
.68868 .54371 L
.68939 .54192 L
.69234 .53399 L
.69618 .52428 L
.69911 .51688 L
.69992 .51457 L
.7036 .50486 L
.70742 .49514 L
.70882 .49156 L
.71101 .48543 L
.71474 .47572 L
.71852 .46601 L
.71853 .46597 L
.72202 .45629 L
.72575 .44658 L
.72824 .44009 L
.72934 .43687 L
.73293 .42716 L
.73663 .41744 L
.73796 .41395 L
.74009 .40773 L
.74372 .39802 L
.74738 .38831 L
.74767 .38754 L
.75077 .37859 L
.75439 .36888 L
.75738 .36086 L
.75792 .35917 L
.76134 .34946 L
.76494 .33974 L
.76709 .33392 L
.76835 .33003 L
.77181 .32032 L
.77539 .31061 L
.77681 .30672 L
Mistroke
.7787 .30089 L
.78218 .29118 L
.78572 .28147 L
.78652 .27926 L
.78897 .27176 L
.79244 .26204 L
.79595 .25233 L
.79623 .25154 L
.79914 .24262 L
.80261 .23291 L
.80594 .22357 L
.80605 .22319 L
.80923 .21348 L
.81267 .20377 L
.81566 .19535 L
.81603 .19406 L
.81922 .18434 L
.82265 .17463 L
.82537 .16687 L
.82593 .16492 L
.82913 .15521 L
.83253 .14549 L
.83508 .13815 L
.83576 .13578 L
.83894 .12607 L
.84232 .11636 L
.84479 .10919 L
.84551 .10664 L
.84867 .09693 L
.85203 .08722 L
.85451 .07998 L
.8552 .07751 L
.85832 .06779 L
.86165 .05808 L
.86422 .05053 L
.86481 .04837 L
.86789 .03866 L
.87119 .02894 L
.87393 .02086 L
.87436 .01923 L
Mfstroke
.8 g
.50486 .81022 m
.51242 .81566 L
.50587 .82537 L
.50486 .82679 L
.4991 .82537 L
.50267 .81566 L
F
0 g
.50486 .81022 m
.51242 .81566 L
.50587 .82537 L
.50486 .82679 L
.4991 .82537 L
.50267 .81566 L
.50486 .81022 L
s
.8 g
.5063 .01923 m
.50486 .02082 L
.4993 .01923 L
F
0 g
.5063 .01923 m
.50486 .02082 L
.4993 .01923 L
s
.2 g
.50486 .60883 m
.51409 .61169 L
.50766 .62141 L
.50486 .6254 L
.49999 .62141 L
.5037 .61169 L
F
0 g
.50486 .60883 m
.51409 .61169 L
.50766 .62141 L
.50486 .6254 L
.49999 .62141 L
.5037 .61169 L
.50486 .60883 L
s
.8 g
.69724 .01923 m
.69518 .02894 L
.68946 .03866 L
.68939 .0388 L
.6855 .04837 L
.68216 .05808 L
.67968 .06277 L
.67757 .06779 L
.67527 .07751 L
.66997 .08631 L
.66957 .08722 L
.6655 .09693 L
.66181 .10664 L
.66026 .10956 L
.65734 .11636 L
.65437 .12607 L
.65054 .13251 L
.64909 .13578 L
.6449 .14549 L
.64083 .15498 L
.64072 .15521 L
.63647 .16492 L
.63261 .17463 L
.63112 .17723 L
.62792 .18434 L
.62462 .19406 L
.62141 .19913 L
.61925 .20377 L
.61486 .21348 L
.61169 .22062 L
.61044 .22319 L
.60596 .23291 L
.60198 .24166 L
.60148 .24262 L
.59692 .25233 L
.59239 .26204 L
.59227 .26224 L
.5877 .27176 L
.58327 .28147 L
.58256 .28253 L
.5783 .29118 L
.57392 .30089 L
.57284 .30238 L
.56869 .31061 L
.56381 .32032 L
.56313 .32175 L
.55883 .33003 L
.55383 .33974 L
.55342 .34059 L
.5487 .34946 L
.54371 .35907 L
.54353 .35917 L
.53822 .36888 L
.53399 .37781 L
.53284 .37859 L
.52729 .38831 L
.52428 .39524 L
.5216 .39802 L
.5157 .40773 L
.51457 .41031 L
.50941 .41744 L
.50486 .42402 L
.50093 .41744 L
.50474 .40773 L
.50486 .40744 L
.50885 .39802 L
.51304 .38831 L
.51457 .3848 L
.51732 .37859 L
.52164 .36888 L
.52428 .36295 L
.52598 .35917 L
.53034 .34946 L
.53399 .34129 L
.53469 .33974 L
.53906 .33003 L
.54325 .32032 L
.54371 .31957 L
.54776 .31061 L
.55135 .30089 L
.55342 .29763 L
.5564 .29118 L
.5607 .28147 L
.56313 .27559 L
.56498 .27176 L
.56926 .26204 L
.57284 .25358 L
.5735 .25233 L
.57774 .24262 L
.58175 .23291 L
.58256 .23141 L
.58614 .22319 L
.58956 .21348 L
.59227 .20872 L
.59447 .20377 L
.59691 .19406 L
.60198 .18593 L
.60272 .18434 L
.60683 .17463 L
.61068 .16492 L
.61169 .16294 L
.61496 .15521 L
.61817 .14549 L
.62141 .13953 L
.62302 .13578 L
.62508 .12607 L
.63098 .11636 L
.63112 .11607 L
.63499 .10664 L
.63839 .09693 L
.64083 .09213 L
.64287 .08722 L
.64528 .07751 L
.65054 .06809 L
.65067 .06779 L
.65457 .05808 L
.65794 .04837 L
.66026 .04365 L
.66228 .03866 L
.66466 .02894 L
.66991 .01923 L
F
0 g
.69724 .01923 m
.69518 .02894 L
.68946 .03866 L
.68939 .0388 L
.6855 .04837 L
.68216 .05808 L
.67968 .06277 L
.67757 .06779 L
.67527 .07751 L
.66997 .08631 L
.66957 .08722 L
.6655 .09693 L
.66181 .10664 L
.66026 .10956 L
.65734 .11636 L
.65437 .12607 L
.65054 .13251 L
.64909 .13578 L
.6449 .14549 L
.64083 .15498 L
.64072 .15521 L
.63647 .16492 L
.63261 .17463 L
.63112 .17723 L
.62792 .18434 L
.62462 .19406 L
.62141 .19913 L
.61925 .20377 L
.61486 .21348 L
.61169 .22062 L
.61044 .22319 L
.60596 .23291 L
.60198 .24166 L
.60148 .24262 L
.59692 .25233 L
.59239 .26204 L
.59227 .26224 L
.5877 .27176 L
.58327 .28147 L
.58256 .28253 L
.5783 .29118 L
.57392 .30089 L
.57284 .30238 L
.56869 .31061 L
.56381 .32032 L
.56313 .32175 L
.55883 .33003 L
.55383 .33974 L
.55342 .34059 L
.5487 .34946 L
Mistroke
.54371 .35907 L
.54353 .35917 L
.53822 .36888 L
.53399 .37781 L
.53284 .37859 L
.52729 .38831 L
.52428 .39524 L
.5216 .39802 L
.5157 .40773 L
.51457 .41031 L
.50941 .41744 L
.50486 .42402 L
.50093 .41744 L
.50474 .40773 L
.50486 .40744 L
.50885 .39802 L
.51304 .38831 L
.51457 .3848 L
.51732 .37859 L
.52164 .36888 L
.52428 .36295 L
.52598 .35917 L
.53034 .34946 L
.53399 .34129 L
.53469 .33974 L
.53906 .33003 L
.54325 .32032 L
.54371 .31957 L
.54776 .31061 L
.55135 .30089 L
.55342 .29763 L
.5564 .29118 L
.5607 .28147 L
.56313 .27559 L
.56498 .27176 L
.56926 .26204 L
.57284 .25358 L
.5735 .25233 L
.57774 .24262 L
.58175 .23291 L
.58256 .23141 L
.58614 .22319 L
.58956 .21348 L
.59227 .20872 L
.59447 .20377 L
.59691 .19406 L
.60198 .18593 L
.60272 .18434 L
.60683 .17463 L
.61068 .16492 L
Mistroke
.61169 .16294 L
.61496 .15521 L
.61817 .14549 L
.62141 .13953 L
.62302 .13578 L
.62508 .12607 L
.63098 .11636 L
.63112 .11607 L
.63499 .10664 L
.63839 .09693 L
.64083 .09213 L
.64287 .08722 L
.64528 .07751 L
.65054 .06809 L
.65067 .06779 L
.65457 .05808 L
.65794 .04837 L
.66026 .04365 L
.66228 .03866 L
.66466 .02894 L
.66991 .01923 L
Mfstroke
.2 g
.50486 .20606 m
.51113 .21348 L
.50486 .22264 L
.50191 .21348 L
F
0 g
.50486 .20606 m
.51113 .21348 L
.50486 .22264 L
.50191 .21348 L
.50486 .20606 L
s
.2 g
.61163 .01923 m
.60715 .02894 L
.60295 .03866 L
.60198 .04022 L
.59813 .04837 L
.59421 .05808 L
.59227 .06095 L
.58894 .06779 L
.58428 .07751 L
.58256 .08127 L
.57957 .08722 L
.57481 .09693 L
.57284 .10114 L
.56998 .10664 L
.56511 .11636 L
.56313 .12054 L
.56016 .12607 L
.55516 .13578 L
.55342 .13942 L
.55007 .14549 L
.54491 .15521 L
.54371 .15769 L
.53963 .16492 L
.53429 .17463 L
.53399 .17523 L
.52877 .18434 L
.52428 .19214 L
.52314 .19406 L
.51728 .20377 L
.51457 .20817 L
.50582 .20377 L
.50995 .19406 L
.51416 .18434 L
.51457 .18309 L
.51847 .17463 L
.52279 .16492 L
.52428 .1607 L
.52714 .15521 L
.5315 .14549 L
.53399 .13892 L
.53586 .13578 L
.54022 .12607 L
.54371 .11755 L
.54456 .11636 L
.54891 .10664 L
.55314 .09693 L
.55342 .09645 L
.55755 .08722 L
.56124 .07751 L
.56313 .07437 L
.56612 .06779 L
.56903 .05808 L
.57284 .05215 L
.57463 .04837 L
.57886 .03866 L
.58256 .02993 L
.58305 .02894 L
.58726 .01923 L
F
0 g
.61163 .01923 m
.60715 .02894 L
.60295 .03866 L
.60198 .04022 L
.59813 .04837 L
.59421 .05808 L
.59227 .06095 L
.58894 .06779 L
.58428 .07751 L
.58256 .08127 L
.57957 .08722 L
.57481 .09693 L
.57284 .10114 L
.56998 .10664 L
.56511 .11636 L
.56313 .12054 L
.56016 .12607 L
.55516 .13578 L
.55342 .13942 L
.55007 .14549 L
.54491 .15521 L
.54371 .15769 L
.53963 .16492 L
.53429 .17463 L
.53399 .17523 L
.52877 .18434 L
.52428 .19214 L
.52314 .19406 L
.51728 .20377 L
.51457 .20817 L
.50582 .20377 L
.50995 .19406 L
.51416 .18434 L
.51457 .18309 L
.51847 .17463 L
.52279 .16492 L
.52428 .1607 L
.52714 .15521 L
.5315 .14549 L
.53399 .13892 L
.53586 .13578 L
.54022 .12607 L
.54371 .11755 L
.54456 .11636 L
.54891 .10664 L
.55314 .09693 L
.55342 .09645 L
.55755 .08722 L
.56124 .07751 L
.56313 .07437 L
Mistroke
.56612 .06779 L
.56903 .05808 L
.57284 .05215 L
.57463 .04837 L
.57886 .03866 L
.58256 .02993 L
.58305 .02894 L
.58726 .01923 L
Mfstroke
.8 g
.84477 .01923 m
.84144 .02894 L
.83908 .03866 L
.83508 .04763 L
.83482 .04837 L
.83146 .05808 L
.82894 .06779 L
.82537 .07585 L
.82478 .07751 L
.82139 .08722 L
.81868 .09693 L
.81566 .10379 L
.81464 .10664 L
.81122 .11636 L
.8083 .12607 L
.80594 .13147 L
.80439 .13578 L
.80299 .14549 L
.79781 .15521 L
.79623 .15887 L
.79404 .16492 L
.79213 .17463 L
.78722 .18434 L
.78652 .18598 L
.78358 .19406 L
.78118 .20377 L
.77681 .21284 L
.77656 .21348 L
.773 .22319 L
.77015 .23291 L
.76709 .23945 L
.7659 .24262 L
.7623 .25233 L
.75906 .26204 L
.75738 .26574 L
.75511 .27176 L
.75297 .28147 L
.74791 .29118 L
.74767 .29172 L
.74419 .30089 L
.74134 .31061 L
.73796 .31749 L
.73685 .32032 L
.73313 .33003 L
.72973 .33974 L
.72824 .34291 L
.72569 .34946 L
.72324 .35917 L
.71853 .36803 L
.71819 .36888 L
.71438 .37859 L
.7111 .38831 L
.70882 .39289 L
.70676 .39802 L
.70458 .40773 L
.69911 .41736 L
.69907 .41744 L
.69517 .42716 L
.69186 .43687 L
.68939 .44164 L
.68735 .44658 L
.68512 .45629 L
.67968 .46549 L
.67946 .46601 L
.67545 .47572 L
.67191 .48543 L
.66997 .4891 L
.66741 .49514 L
.66472 .50486 L
.66026 .51236 L
.65928 .51457 L
.65516 .52428 L
.65118 .53399 L
.65054 .5352 L
.64686 .54371 L
.64339 .55342 L
.64083 .55783 L
.63847 .56313 L
.63422 .57284 L
.63112 .58005 L
.62995 .58256 L
.62563 .59227 L
.62141 .60179 L
.62131 .60198 L
.61692 .61169 L
.61283 .62141 L
.61169 .6233 L
.60806 .63112 L
.60436 .64083 L
.60198 .64444 L
.59906 .65054 L
.5945 .66026 L
.59227 .66518 L
.58989 .66997 L
.58523 .67968 L
.58256 .68549 L
.58053 .68939 L
.57577 .69911 L
.57284 .70537 L
.57097 .70882 L
.5661 .71853 L
.56313 .7248 L
.56118 .72824 L
.55618 .73796 L
.55342 .74374 L
.55111 .74767 L
.54596 .75738 L
.54371 .76209 L
.54072 .76709 L
.53538 .77681 L
.53399 .77968 L
.5299 .78652 L
.52432 .79623 L
.52428 .7963 L
.51848 .80594 L
.51457 .81232 L
.50665 .80594 L
.51081 .79623 L
.51457 .78757 L
.51503 .78652 L
.51935 .77681 L
.52367 .76709 L
.52428 .76544 L
.52803 .75738 L
.53238 .74767 L
.53399 .74349 L
.53675 .73796 L
.5411 .72824 L
.54371 .72174 L
.54545 .71853 L
.54979 .70882 L
.55342 .70021 L
.5541 .69911 L
.55842 .68939 L
.56255 .67968 L
.56313 .67865 L
.56699 .66997 L
.57055 .66026 L
.57284 .65639 L
.57549 .65054 L
.57818 .64083 L
.58256 .634 L
.58391 .63112 L
.5881 .62141 L
.59225 .61169 L
.59227 .61166 L
.59642 .60198 L
.60007 .59227 L
.60198 .58872 L
.60465 .58256 L
.6075 .57284 L
.61169 .56562 L
.6128 .56313 L
.61686 .55342 L
.62076 .54371 L
.62141 .5424 L
.62491 .53399 L
.6282 .52428 L
.63112 .51873 L
.63288 .51457 L
.63508 .50486 L
.64076 .49514 L
.64083 .49499 L
.64471 .48543 L
.64808 .47572 L
.65054 .47079 L
.65251 .46601 L
.65486 .45629 L
.66022 .44658 L
.66026 .4465 L
.66408 .43687 L
.66735 .42716 L
.66997 .42178 L
.67171 .41744 L
.67388 .40773 L
.67919 .39802 L
.67968 .39694 L
.68305 .38831 L
.68605 .37859 L
.68939 .37172 L
.69052 .36888 L
.69218 .35917 L
.69769 .34946 L
.69911 .34632 L
.70163 .33974 L
.70418 .33003 L
.70882 .32066 L
.70896 .32032 L
.71262 .31061 L
.71566 .30089 L
.71853 .29467 L
.71986 .29118 L
.7216 .28147 L
.72681 .27176 L
.72824 .26848 L
.73065 .26204 L
.73302 .25233 L
.73772 .24262 L
.73796 .24206 L
.74132 .23291 L
.74408 .22319 L
.74767 .21531 L
.74835 .21348 L
.75187 .20377 L
.75488 .19406 L
.75738 .18833 L
.75884 .18434 L
.76052 .17463 L
.76549 .16492 L
.76709 .16112 L
.76922 .15521 L
.77128 .14549 L
.77594 .13578 L
.77681 .13367 L
.7795 .12607 L
.78182 .11636 L
.78625 .10664 L
.78652 .10596 L
.78969 .09693 L
.79217 .08722 L
.79623 .07799 L
.79641 .07751 L
.79978 .06779 L
.80237 .05808 L
.80594 .04977 L
.80644 .04837 L
.80978 .03866 L
.81244 .02894 L
.81566 .0216 L
.81638 .01923 L
F
0 g
.84477 .01923 m
.84144 .02894 L
.83908 .03866 L
.83508 .04763 L
.83482 .04837 L
.83146 .05808 L
.82894 .06779 L
.82537 .07585 L
.82478 .07751 L
.82139 .08722 L
.81868 .09693 L
.81566 .10379 L
.81464 .10664 L
.81122 .11636 L
.8083 .12607 L
.80594 .13147 L
.80439 .13578 L
.80299 .14549 L
.79781 .15521 L
.79623 .15887 L
.79404 .16492 L
.79213 .17463 L
.78722 .18434 L
.78652 .18598 L
.78358 .19406 L
.78118 .20377 L
.77681 .21284 L
.77656 .21348 L
.773 .22319 L
.77015 .23291 L
.76709 .23945 L
.7659 .24262 L
.7623 .25233 L
.75906 .26204 L
.75738 .26574 L
.75511 .27176 L
.75297 .28147 L
.74791 .29118 L
.74767 .29172 L
.74419 .30089 L
.74134 .31061 L
.73796 .31749 L
.73685 .32032 L
.73313 .33003 L
.72973 .33974 L
.72824 .34291 L
.72569 .34946 L
.72324 .35917 L
.71853 .36803 L
.71819 .36888 L
Mistroke
.71438 .37859 L
.7111 .38831 L
.70882 .39289 L
.70676 .39802 L
.70458 .40773 L
.69911 .41736 L
.69907 .41744 L
.69517 .42716 L
.69186 .43687 L
.68939 .44164 L
.68735 .44658 L
.68512 .45629 L
.67968 .46549 L
.67946 .46601 L
.67545 .47572 L
.67191 .48543 L
.66997 .4891 L
.66741 .49514 L
.66472 .50486 L
.66026 .51236 L
.65928 .51457 L
.65516 .52428 L
.65118 .53399 L
.65054 .5352 L
.64686 .54371 L
.64339 .55342 L
.64083 .55783 L
.63847 .56313 L
.63422 .57284 L
.63112 .58005 L
.62995 .58256 L
.62563 .59227 L
.62141 .60179 L
.62131 .60198 L
.61692 .61169 L
.61283 .62141 L
.61169 .6233 L
.60806 .63112 L
.60436 .64083 L
.60198 .64444 L
.59906 .65054 L
.5945 .66026 L
.59227 .66518 L
.58989 .66997 L
.58523 .67968 L
.58256 .68549 L
.58053 .68939 L
.57577 .69911 L
.57284 .70537 L
.57097 .70882 L
Mistroke
.5661 .71853 L
.56313 .7248 L
.56118 .72824 L
.55618 .73796 L
.55342 .74374 L
.55111 .74767 L
.54596 .75738 L
.54371 .76209 L
.54072 .76709 L
.53538 .77681 L
.53399 .77968 L
.5299 .78652 L
.52432 .79623 L
.52428 .7963 L
.51848 .80594 L
.51457 .81232 L
.50665 .80594 L
.51081 .79623 L
.51457 .78757 L
.51503 .78652 L
.51935 .77681 L
.52367 .76709 L
.52428 .76544 L
.52803 .75738 L
.53238 .74767 L
.53399 .74349 L
.53675 .73796 L
.5411 .72824 L
.54371 .72174 L
.54545 .71853 L
.54979 .70882 L
.55342 .70021 L
.5541 .69911 L
.55842 .68939 L
.56255 .67968 L
.56313 .67865 L
.56699 .66997 L
.57055 .66026 L
.57284 .65639 L
.57549 .65054 L
.57818 .64083 L
.58256 .634 L
.58391 .63112 L
.5881 .62141 L
.59225 .61169 L
.59227 .61166 L
.59642 .60198 L
.60007 .59227 L
.60198 .58872 L
.60465 .58256 L
Mistroke
.6075 .57284 L
.61169 .56562 L
.6128 .56313 L
.61686 .55342 L
.62076 .54371 L
.62141 .5424 L
.62491 .53399 L
.6282 .52428 L
.63112 .51873 L
.63288 .51457 L
.63508 .50486 L
.64076 .49514 L
.64083 .49499 L
.64471 .48543 L
.64808 .47572 L
.65054 .47079 L
.65251 .46601 L
.65486 .45629 L
.66022 .44658 L
.66026 .4465 L
.66408 .43687 L
.66735 .42716 L
.66997 .42178 L
.67171 .41744 L
.67388 .40773 L
.67919 .39802 L
.67968 .39694 L
.68305 .38831 L
.68605 .37859 L
.68939 .37172 L
.69052 .36888 L
.69218 .35917 L
.69769 .34946 L
.69911 .34632 L
.70163 .33974 L
.70418 .33003 L
.70882 .32066 L
.70896 .32032 L
.71262 .31061 L
.71566 .30089 L
.71853 .29467 L
.71986 .29118 L
.7216 .28147 L
.72681 .27176 L
.72824 .26848 L
.73065 .26204 L
.73302 .25233 L
.73772 .24262 L
.73796 .24206 L
.74132 .23291 L
Mistroke
.74408 .22319 L
.74767 .21531 L
.74835 .21348 L
.75187 .20377 L
.75488 .19406 L
.75738 .18833 L
.75884 .18434 L
.76052 .17463 L
.76549 .16492 L
.76709 .16112 L
.76922 .15521 L
.77128 .14549 L
.77594 .13578 L
.77681 .13367 L
.7795 .12607 L
.78182 .11636 L
.78625 .10664 L
.78652 .10596 L
.78969 .09693 L
.79217 .08722 L
.79623 .07799 L
.79641 .07751 L
.79978 .06779 L
.80237 .05808 L
.80594 .04977 L
.80644 .04837 L
.80978 .03866 L
.81244 .02894 L
.81566 .0216 L
.81638 .01923 L
Mfstroke
.2 g
.77395 .01923 m
.77154 .02894 L
.76709 .03803 L
.76686 .03866 L
.76326 .04837 L
.76035 .05808 L
.75738 .06437 L
.75608 .06779 L
.75244 .07751 L
.74911 .08722 L
.74767 .09037 L
.74517 .09693 L
.74284 .10664 L
.73796 .11606 L
.73784 .11636 L
.73412 .12607 L
.73107 .13578 L
.72824 .14154 L
.72669 .14549 L
.72293 .15521 L
.71934 .16492 L
.71853 .16664 L
.71539 .17463 L
.71256 .18434 L
.70882 .19151 L
.70778 .19406 L
.70393 .20377 L
.70035 .21348 L
.69911 .21601 L
.6962 .22319 L
.69341 .23291 L
.68939 .24025 L
.6884 .24262 L
.68445 .25233 L
.68073 .26204 L
.67968 .26411 L
.67651 .27176 L
.67347 .28147 L
.66997 .28773 L
.66849 .29118 L
.66443 .30089 L
.6604 .31061 L
.66026 .31089 L
.65625 .32032 L
.65268 .33003 L
.65054 .33387 L
.64798 .33974 L
.64521 .34946 L
.64083 .35645 L
.6396 .35917 L
.63534 .36888 L
.63112 .37855 L
.6311 .37859 L
.62678 .38831 L
.62284 .39802 L
.62141 .40046 L
.61808 .40773 L
.61464 .41744 L
.61169 .42199 L
.60925 .42716 L
.60478 .43687 L
.60198 .44311 L
.60027 .44658 L
.59571 .45629 L
.59227 .46381 L
.59112 .46601 L
.58647 .47572 L
.58256 .48407 L
.5818 .48543 L
.57704 .49514 L
.57284 .5039 L
.57226 .50486 L
.5674 .51457 L
.56313 .52333 L
.5625 .52428 L
.55751 .53399 L
.55342 .54237 L
.55247 .54371 L
.54733 .55342 L
.54371 .56096 L
.54213 .56313 L
.5368 .57284 L
.53399 .57882 L
.53137 .58256 L
.52581 .59227 L
.52428 .59552 L
.52005 .60198 L
.51457 .61094 L
.50774 .60198 L
.51192 .59227 L
.51457 .58618 L
.51618 .58256 L
.5205 .57284 L
.52428 .56433 L
.52482 .56313 L
.52919 .55342 L
.53353 .54371 L
.53399 .54255 L
.53791 .53399 L
.54225 .52428 L
.54371 .52067 L
.5466 .51457 L
.55093 .50486 L
.55342 .4988 L
.55525 .49514 L
.55956 .48543 L
.56313 .47701 L
.56384 .47572 L
.56813 .46601 L
.57221 .45629 L
.57284 .45515 L
.57662 .44658 L
.58013 .43687 L
.58256 .43268 L
.58503 .42716 L
.58765 .41744 L
.59227 .41008 L
.59336 .40773 L
.59751 .39802 L
.60153 .38831 L
.60198 .38743 L
.60574 .37859 L
.6092 .36888 L
.61169 .36425 L
.61389 .35917 L
.6164 .34946 L
.62141 .34096 L
.62195 .33974 L
.62597 .33003 L
.62965 .32032 L
.63112 .31739 L
.63394 .31061 L
.63685 .30089 L
.64083 .29351 L
.64182 .29118 L
.64575 .28147 L
.64944 .27176 L
.65054 .26945 L
.65354 .26204 L
.65649 .25233 L
.66026 .24503 L
.66125 .24262 L
.6651 .23291 L
.66867 .22319 L
.66997 .22043 L
.67272 .21348 L
.67549 .20377 L
.67968 .19552 L
.68027 .19406 L
.68405 .18434 L
.6874 .17463 L
.68939 .17034 L
.69151 .16492 L
.69387 .15521 L
.69888 .14549 L
.69911 .14497 L
.70261 .13578 L
.70559 .12607 L
.70882 .11923 L
.70993 .11636 L
.71153 .10664 L
.71692 .09693 L
.71853 .0933 L
.72083 .08722 L
.72317 .07751 L
.72796 .06779 L
.72824 .06713 L
.7316 .05808 L
.7344 .04837 L
.73796 .04063 L
.7387 .03866 L
.74225 .02894 L
.74534 .01923 L
F
0 g
.77395 .01923 m
.77154 .02894 L
.76709 .03803 L
.76686 .03866 L
.76326 .04837 L
.76035 .05808 L
.75738 .06437 L
.75608 .06779 L
.75244 .07751 L
.74911 .08722 L
.74767 .09037 L
.74517 .09693 L
.74284 .10664 L
.73796 .11606 L
.73784 .11636 L
.73412 .12607 L
.73107 .13578 L
.72824 .14154 L
.72669 .14549 L
.72293 .15521 L
.71934 .16492 L
.71853 .16664 L
.71539 .17463 L
.71256 .18434 L
.70882 .19151 L
.70778 .19406 L
.70393 .20377 L
.70035 .21348 L
.69911 .21601 L
.6962 .22319 L
.69341 .23291 L
.68939 .24025 L
.6884 .24262 L
.68445 .25233 L
.68073 .26204 L
.67968 .26411 L
.67651 .27176 L
.67347 .28147 L
.66997 .28773 L
.66849 .29118 L
.66443 .30089 L
.6604 .31061 L
.66026 .31089 L
.65625 .32032 L
.65268 .33003 L
.65054 .33387 L
.64798 .33974 L
.64521 .34946 L
.64083 .35645 L
.6396 .35917 L
Mistroke
.63534 .36888 L
.63112 .37855 L
.6311 .37859 L
.62678 .38831 L
.62284 .39802 L
.62141 .40046 L
.61808 .40773 L
.61464 .41744 L
.61169 .42199 L
.60925 .42716 L
.60478 .43687 L
.60198 .44311 L
.60027 .44658 L
.59571 .45629 L
.59227 .46381 L
.59112 .46601 L
.58647 .47572 L
.58256 .48407 L
.5818 .48543 L
.57704 .49514 L
.57284 .5039 L
.57226 .50486 L
.5674 .51457 L
.56313 .52333 L
.5625 .52428 L
.55751 .53399 L
.55342 .54237 L
.55247 .54371 L
.54733 .55342 L
.54371 .56096 L
.54213 .56313 L
.5368 .57284 L
.53399 .57882 L
.53137 .58256 L
.52581 .59227 L
.52428 .59552 L
.52005 .60198 L
.51457 .61094 L
.50774 .60198 L
.51192 .59227 L
.51457 .58618 L
.51618 .58256 L
.5205 .57284 L
.52428 .56433 L
.52482 .56313 L
.52919 .55342 L
.53353 .54371 L
.53399 .54255 L
.53791 .53399 L
.54225 .52428 L
Mistroke
.54371 .52067 L
.5466 .51457 L
.55093 .50486 L
.55342 .4988 L
.55525 .49514 L
.55956 .48543 L
.56313 .47701 L
.56384 .47572 L
.56813 .46601 L
.57221 .45629 L
.57284 .45515 L
.57662 .44658 L
.58013 .43687 L
.58256 .43268 L
.58503 .42716 L
.58765 .41744 L
.59227 .41008 L
.59336 .40773 L
.59751 .39802 L
.60153 .38831 L
.60198 .38743 L
.60574 .37859 L
.6092 .36888 L
.61169 .36425 L
.61389 .35917 L
.6164 .34946 L
.62141 .34096 L
.62195 .33974 L
.62597 .33003 L
.62965 .32032 L
.63112 .31739 L
.63394 .31061 L
.63685 .30089 L
.64083 .29351 L
.64182 .29118 L
.64575 .28147 L
.64944 .27176 L
.65054 .26945 L
.65354 .26204 L
.65649 .25233 L
.66026 .24503 L
.66125 .24262 L
.6651 .23291 L
.66867 .22319 L
.66997 .22043 L
.67272 .21348 L
.67549 .20377 L
.67968 .19552 L
.68027 .19406 L
.68405 .18434 L
Mistroke
.6874 .17463 L
.68939 .17034 L
.69151 .16492 L
.69387 .15521 L
.69888 .14549 L
.69911 .14497 L
.70261 .13578 L
.70559 .12607 L
.70882 .11923 L
.70993 .11636 L
.71153 .10664 L
.71692 .09693 L
.71853 .0933 L
.72083 .08722 L
.72317 .07751 L
.72796 .06779 L
.72824 .06713 L
.7316 .05808 L
.7344 .04837 L
.73796 .04063 L
.7387 .03866 L
.74225 .02894 L
.74534 .01923 L
Mfstroke
.2 g
.5182 .98077 m
.52252 .97106 L
.52428 .96599 L
.52687 .96134 L
.53123 .95163 L
.53399 .94434 L
.53559 .94192 L
.53995 .93221 L
.54371 .92318 L
.54429 .92249 L
.54864 .91278 L
.55276 .90307 L
.55342 .90195 L
.55728 .89336 L
.5608 .88364 L
.56313 .87986 L
.56586 .87393 L
.57012 .86422 L
.57284 .85767 L
.57436 .85451 L
.5786 .84479 L
.58256 .83554 L
.58279 .83508 L
.587 .82537 L
.5908 .81566 L
.59227 .81294 L
.59532 .80594 L
.59841 .79623 L
.60198 .79005 L
.60356 .78652 L
.60766 .77681 L
.61169 .76714 L
.61172 .76709 L
.61579 .75738 L
.61935 .74767 L
.62141 .74372 L
.62384 .73796 L
.62654 .72824 L
.63112 .72013 L
.63182 .71853 L
.6358 .70882 L
.63946 .69911 L
.64083 .69632 L
.64367 .68939 L
.64657 .67968 L
.65054 .67217 L
.65147 .66997 L
.65536 .66026 L
.65897 .65054 L
.66026 .64783 L
.66306 .64083 L
.66589 .63112 L
.66997 .62318 L
.6707 .62141 L
.6745 .61169 L
.67795 .60198 L
.67968 .59828 L
.68205 .59227 L
.68458 .58256 L
.68939 .57316 L
.68952 .57284 L
.69326 .56313 L
.69641 .55342 L
.69911 .54768 L
.70065 .54371 L
.70261 .53399 L
.70782 .52428 L
.70882 .52203 L
.71165 .51457 L
.71431 .50486 L
.71853 .49608 L
.7189 .49514 L
.72252 .48543 L
.72559 .47572 L
.72824 .46985 L
.72969 .46601 L
.73148 .45629 L
.73659 .44658 L
.73796 .44341 L
.74037 .43687 L
.74271 .42716 L
.74737 .41744 L
.74767 .41673 L
.75094 .40773 L
.75363 .39802 L
.75738 .38973 L
.75791 .38831 L
.7614 .37859 L
.76431 .36888 L
.76709 .36249 L
.7683 .35917 L
.76976 .34946 L
.77482 .33974 L
.77681 .33503 L
.77859 .33003 L
.78041 .32032 L
.78517 .31061 L
.78652 .30732 L
.78879 .30089 L
.79084 .29118 L
.79539 .28147 L
.79623 .27937 L
.79889 .27176 L
.8011 .26204 L
.80548 .25233 L
.80594 .25117 L
.80889 .24262 L
.81121 .23291 L
.81547 .22319 L
.81566 .22272 L
.81882 .21348 L
.82118 .20377 L
.82536 .19406 L
.82537 .19403 L
.82865 .18434 L
.83103 .17463 L
.83508 .16509 L
.83514 .16492 L
.8384 .15521 L
.84076 .14549 L
.84479 .13592 L
.84484 .13578 L
.84808 .12607 L
.85038 .11636 L
.85446 .10664 L
.85451 .10651 L
.85768 .09693 L
.85989 .08722 L
.86398 .07751 L
.86422 .07686 L
.8672 .06779 L
.86929 .05808 L
.87341 .04837 L
.87393 .04697 L
.87665 .03866 L
.87857 .02894 L
.88275 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.5182 .98077 m
.52252 .97106 L
.52428 .96599 L
.52687 .96134 L
.53123 .95163 L
.53399 .94434 L
.53559 .94192 L
.53995 .93221 L
.54371 .92318 L
.54429 .92249 L
.54864 .91278 L
.55276 .90307 L
.55342 .90195 L
.55728 .89336 L
.5608 .88364 L
.56313 .87986 L
.56586 .87393 L
.57012 .86422 L
.57284 .85767 L
.57436 .85451 L
.5786 .84479 L
.58256 .83554 L
.58279 .83508 L
.587 .82537 L
.5908 .81566 L
.59227 .81294 L
.59532 .80594 L
.59841 .79623 L
.60198 .79005 L
.60356 .78652 L
.60766 .77681 L
.61169 .76714 L
.61172 .76709 L
.61579 .75738 L
.61935 .74767 L
.62141 .74372 L
.62384 .73796 L
.62654 .72824 L
.63112 .72013 L
.63182 .71853 L
.6358 .70882 L
.63946 .69911 L
.64083 .69632 L
.64367 .68939 L
.64657 .67968 L
.65054 .67217 L
.65147 .66997 L
.65536 .66026 L
.65897 .65054 L
.66026 .64783 L
Mistroke
.66306 .64083 L
.66589 .63112 L
.66997 .62318 L
.6707 .62141 L
.6745 .61169 L
.67795 .60198 L
.67968 .59828 L
.68205 .59227 L
.68458 .58256 L
.68939 .57316 L
.68952 .57284 L
.69326 .56313 L
.69641 .55342 L
.69911 .54768 L
.70065 .54371 L
.70261 .53399 L
.70782 .52428 L
.70882 .52203 L
.71165 .51457 L
.71431 .50486 L
.71853 .49608 L
.7189 .49514 L
.72252 .48543 L
.72559 .47572 L
.72824 .46985 L
.72969 .46601 L
.73148 .45629 L
.73659 .44658 L
.73796 .44341 L
.74037 .43687 L
.74271 .42716 L
.74737 .41744 L
.74767 .41673 L
.75094 .40773 L
.75363 .39802 L
.75738 .38973 L
.75791 .38831 L
.7614 .37859 L
.76431 .36888 L
.76709 .36249 L
.7683 .35917 L
.76976 .34946 L
.77482 .33974 L
.77681 .33503 L
.77859 .33003 L
.78041 .32032 L
.78517 .31061 L
.78652 .30732 L
.78879 .30089 L
.79084 .29118 L
Mistroke
.79539 .28147 L
.79623 .27937 L
.79889 .27176 L
.8011 .26204 L
.80548 .25233 L
.80594 .25117 L
.80889 .24262 L
.81121 .23291 L
.81547 .22319 L
.81566 .22272 L
.81882 .21348 L
.82118 .20377 L
.82536 .19406 L
.82537 .19403 L
.82865 .18434 L
.83103 .17463 L
.83508 .16509 L
.83514 .16492 L
.8384 .15521 L
.84076 .14549 L
.84479 .13592 L
.84484 .13578 L
.84808 .12607 L
.85038 .11636 L
.85446 .10664 L
.85451 .10651 L
.85768 .09693 L
.85989 .08722 L
.86398 .07751 L
.86422 .07686 L
.8672 .06779 L
.86929 .05808 L
.87341 .04837 L
.87393 .04697 L
.87665 .03866 L
.87857 .02894 L
.88275 .01923 L
Mfstroke
.3 g
.53396 .98077 m
.53399 .9807 L
.5393 .97106 L
.54371 .96316 L
.54459 .96134 L
.54975 .95163 L
.55342 .9449 L
.55485 .94192 L
.55985 .93221 L
.56313 .92604 L
.56481 .92249 L
.56968 .91278 L
.57284 .90665 L
.57451 .90307 L
.57927 .89336 L
.58256 .88678 L
.584 .88364 L
.58865 .87393 L
.59227 .86647 L
.59375 .86422 L
.59785 .85451 L
.60198 .84573 L
.60255 .84479 L
.60687 .83508 L
.61135 .82537 L
.61169 .82469 L
.61575 .81566 L
.62015 .80594 L
.62141 .80329 L
.62448 .79623 L
.6288 .78652 L
.63112 .78143 L
.6339 .77681 L
.63734 .76709 L
.64083 .75915 L
.6418 .75738 L
.64575 .74767 L
.64994 .73796 L
.65054 .73663 L
.65406 .72824 L
.65818 .71853 L
.66026 .71374 L
.66299 .70882 L
.66633 .69911 L
.66997 .69043 L
.6705 .68939 L
.67438 .67968 L
.67839 .66997 L
.67968 .66693 L
.68336 .66026 L
.6863 .65054 L
.68939 .64299 L
.69046 .64083 L
.69413 .63112 L
.69803 .62141 L
.69911 .61881 L
.70289 .61169 L
.70573 .60198 L
.70882 .59424 L
.70976 .59227 L
.71337 .58256 L
.71717 .57284 L
.71853 .56945 L
.72171 .56313 L
.72469 .55342 L
.72824 .54426 L
.7285 .54371 L
.73377 .53399 L
.73586 .52428 L
.73796 .51887 L
.73998 .51457 L
.74322 .50486 L
.74689 .49514 L
.74767 .49314 L
.75146 .48543 L
.75414 .47572 L
.75738 .4671 L
.75786 .46601 L
.76293 .45629 L
.76494 .44658 L
.76709 .44083 L
.76888 .43687 L
.77206 .42716 L
.77562 .41744 L
.77681 .41425 L
.77981 .40773 L
.78264 .39802 L
.78617 .38831 L
.78652 .38737 L
.79067 .37859 L
.79311 .36888 L
.79623 .36022 L
.79668 .35917 L
.80143 .34946 L
.80347 .33974 L
.80594 .33284 L
.80713 .33003 L
.81208 .32032 L
.81373 .31061 L
.81566 .30518 L
.81748 .30089 L
.82049 .29118 L
.82388 .28147 L
.82537 .27724 L
.82772 .27176 L
.83057 .26204 L
.83393 .25233 L
.83508 .24904 L
.83783 .24262 L
.84056 .23291 L
.84388 .22319 L
.84479 .22058 L
.84783 .21348 L
.85045 .20377 L
.85375 .19406 L
.85451 .19186 L
.85771 .18434 L
.86025 .17463 L
.86352 .16492 L
.86422 .16288 L
.86747 .15521 L
.86997 .14549 L
.87321 .13578 L
.87393 .13366 L
.87711 .12607 L
.8796 .11636 L
.88282 .10664 L
.88364 .10419 L
.88664 .09693 L
.88916 .08722 L
.89235 .07751 L
.89336 .07447 L
.89607 .06779 L
.89864 .05808 L
.9018 .04837 L
.90307 .04451 L
.9054 .03866 L
.90804 .02894 L
.91117 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.53396 .98077 m
.53399 .9807 L
.5393 .97106 L
.54371 .96316 L
.54459 .96134 L
.54975 .95163 L
.55342 .9449 L
.55485 .94192 L
.55985 .93221 L
.56313 .92604 L
.56481 .92249 L
.56968 .91278 L
.57284 .90665 L
.57451 .90307 L
.57927 .89336 L
.58256 .88678 L
.584 .88364 L
.58865 .87393 L
.59227 .86647 L
.59375 .86422 L
.59785 .85451 L
.60198 .84573 L
.60255 .84479 L
.60687 .83508 L
.61135 .82537 L
.61169 .82469 L
.61575 .81566 L
.62015 .80594 L
.62141 .80329 L
.62448 .79623 L
.6288 .78652 L
.63112 .78143 L
.6339 .77681 L
.63734 .76709 L
.64083 .75915 L
.6418 .75738 L
.64575 .74767 L
.64994 .73796 L
.65054 .73663 L
.65406 .72824 L
.65818 .71853 L
.66026 .71374 L
.66299 .70882 L
.66633 .69911 L
.66997 .69043 L
.6705 .68939 L
.67438 .67968 L
.67839 .66997 L
.67968 .66693 L
.68336 .66026 L
Mistroke
.6863 .65054 L
.68939 .64299 L
.69046 .64083 L
.69413 .63112 L
.69803 .62141 L
.69911 .61881 L
.70289 .61169 L
.70573 .60198 L
.70882 .59424 L
.70976 .59227 L
.71337 .58256 L
.71717 .57284 L
.71853 .56945 L
.72171 .56313 L
.72469 .55342 L
.72824 .54426 L
.7285 .54371 L
.73377 .53399 L
.73586 .52428 L
.73796 .51887 L
.73998 .51457 L
.74322 .50486 L
.74689 .49514 L
.74767 .49314 L
.75146 .48543 L
.75414 .47572 L
.75738 .4671 L
.75786 .46601 L
.76293 .45629 L
.76494 .44658 L
.76709 .44083 L
.76888 .43687 L
.77206 .42716 L
.77562 .41744 L
.77681 .41425 L
.77981 .40773 L
.78264 .39802 L
.78617 .38831 L
.78652 .38737 L
.79067 .37859 L
.79311 .36888 L
.79623 .36022 L
.79668 .35917 L
.80143 .34946 L
.80347 .33974 L
.80594 .33284 L
.80713 .33003 L
.81208 .32032 L
.81373 .31061 L
.81566 .30518 L
Mistroke
.81748 .30089 L
.82049 .29118 L
.82388 .28147 L
.82537 .27724 L
.82772 .27176 L
.83057 .26204 L
.83393 .25233 L
.83508 .24904 L
.83783 .24262 L
.84056 .23291 L
.84388 .22319 L
.84479 .22058 L
.84783 .21348 L
.85045 .20377 L
.85375 .19406 L
.85451 .19186 L
.85771 .18434 L
.86025 .17463 L
.86352 .16492 L
.86422 .16288 L
.86747 .15521 L
.86997 .14549 L
.87321 .13578 L
.87393 .13366 L
.87711 .12607 L
.8796 .11636 L
.88282 .10664 L
.88364 .10419 L
.88664 .09693 L
.88916 .08722 L
.89235 .07751 L
.89336 .07447 L
.89607 .06779 L
.89864 .05808 L
.9018 .04837 L
.90307 .04451 L
.9054 .03866 L
.90804 .02894 L
.91117 .01923 L
Mfstroke
.4 g
.55573 .98077 m
.56052 .97106 L
.56313 .96538 L
.56511 .96134 L
.56983 .95163 L
.57284 .945 L
.57433 .94192 L
.57899 .93221 L
.58256 .92426 L
.58339 .92249 L
.58799 .91278 L
.59227 .90317 L
.59231 .90307 L
.59685 .89336 L
.60119 .88364 L
.60198 .88174 L
.60557 .87393 L
.60993 .86422 L
.61169 .85997 L
.61417 .85451 L
.61852 .84479 L
.62141 .83786 L
.62265 .83508 L
.62697 .82537 L
.63103 .81566 L
.63112 .81542 L
.6353 .80594 L
.63944 .79623 L
.64083 .79267 L
.64351 .78652 L
.64768 .77681 L
.65054 .76959 L
.65161 .76709 L
.65578 .75738 L
.65972 .74767 L
.66026 .74621 L
.66375 .73796 L
.66779 .72824 L
.66997 .72251 L
.67163 .71853 L
.67568 .70882 L
.67947 .69911 L
.67968 .69851 L
.68345 .68939 L
.68738 .67968 L
.68939 .67421 L
.69112 .66997 L
.69508 .66026 L
.69879 .65054 L
.69911 .64961 L
.70265 .64083 L
.70651 .63112 L
.70882 .62472 L
.71014 .62141 L
.71402 .61169 L
.7177 .60198 L
.71853 .59954 L
.72141 .59227 L
.72521 .58256 L
.72824 .57407 L
.72872 .57284 L
.73253 .56313 L
.73622 .55342 L
.73796 .54832 L
.73974 .54371 L
.7435 .53399 L
.74703 .52428 L
.74767 .52229 L
.75063 .51457 L
.75432 .50486 L
.75738 .49599 L
.7577 .49514 L
.76139 .48543 L
.765 .47572 L
.76709 .46941 L
.76837 .46601 L
.77203 .45629 L
.77553 .44658 L
.77681 .44256 L
.77892 .43687 L
.78254 .42716 L
.78591 .41744 L
.78652 .41545 L
.78936 .40773 L
.79293 .39802 L
.79616 .38831 L
.79623 .38806 L
.7997 .37859 L
.80321 .36888 L
.80594 .36042 L
.80639 .35917 L
.80992 .34946 L
.81338 .33974 L
.81566 .33252 L
.81654 .33003 L
.82005 .32032 L
.82345 .31061 L
.82537 .30436 L
.8266 .30089 L
.83007 .29118 L
.83342 .28147 L
.83508 .27594 L
.83655 .27176 L
.84 .26204 L
.84331 .25233 L
.84479 .24727 L
.84642 .24262 L
.84984 .23291 L
.85311 .22319 L
.85451 .21836 L
.8562 .21348 L
.85959 .20377 L
.86283 .19406 L
.86422 .18919 L
.86588 .18434 L
.86925 .17463 L
.87248 .16492 L
.87393 .15978 L
.87549 .15521 L
.87883 .14549 L
.88205 .13578 L
.88364 .13012 L
.88501 .12607 L
.88833 .11636 L
.89155 .10664 L
.89336 .10022 L
.89446 .09693 L
.89775 .08722 L
.90097 .07751 L
.90307 .07008 L
.90383 .06779 L
.9071 .05808 L
.91032 .04837 L
.91278 .03971 L
.91313 .03866 L
.91637 .02894 L
.91958 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.55573 .98077 m
.56052 .97106 L
.56313 .96538 L
.56511 .96134 L
.56983 .95163 L
.57284 .945 L
.57433 .94192 L
.57899 .93221 L
.58256 .92426 L
.58339 .92249 L
.58799 .91278 L
.59227 .90317 L
.59231 .90307 L
.59685 .89336 L
.60119 .88364 L
.60198 .88174 L
.60557 .87393 L
.60993 .86422 L
.61169 .85997 L
.61417 .85451 L
.61852 .84479 L
.62141 .83786 L
.62265 .83508 L
.62697 .82537 L
.63103 .81566 L
.63112 .81542 L
.6353 .80594 L
.63944 .79623 L
.64083 .79267 L
.64351 .78652 L
.64768 .77681 L
.65054 .76959 L
.65161 .76709 L
.65578 .75738 L
.65972 .74767 L
.66026 .74621 L
.66375 .73796 L
.66779 .72824 L
.66997 .72251 L
.67163 .71853 L
.67568 .70882 L
.67947 .69911 L
.67968 .69851 L
.68345 .68939 L
.68738 .67968 L
.68939 .67421 L
.69112 .66997 L
.69508 .66026 L
.69879 .65054 L
.69911 .64961 L
Mistroke
.70265 .64083 L
.70651 .63112 L
.70882 .62472 L
.71014 .62141 L
.71402 .61169 L
.7177 .60198 L
.71853 .59954 L
.72141 .59227 L
.72521 .58256 L
.72824 .57407 L
.72872 .57284 L
.73253 .56313 L
.73622 .55342 L
.73796 .54832 L
.73974 .54371 L
.7435 .53399 L
.74703 .52428 L
.74767 .52229 L
.75063 .51457 L
.75432 .50486 L
.75738 .49599 L
.7577 .49514 L
.76139 .48543 L
.765 .47572 L
.76709 .46941 L
.76837 .46601 L
.77203 .45629 L
.77553 .44658 L
.77681 .44256 L
.77892 .43687 L
.78254 .42716 L
.78591 .41744 L
.78652 .41545 L
.78936 .40773 L
.79293 .39802 L
.79616 .38831 L
.79623 .38806 L
.7997 .37859 L
.80321 .36888 L
.80594 .36042 L
.80639 .35917 L
.80992 .34946 L
.81338 .33974 L
.81566 .33252 L
.81654 .33003 L
.82005 .32032 L
.82345 .31061 L
.82537 .30436 L
.8266 .30089 L
.83007 .29118 L
Mistroke
.83342 .28147 L
.83508 .27594 L
.83655 .27176 L
.84 .26204 L
.84331 .25233 L
.84479 .24727 L
.84642 .24262 L
.84984 .23291 L
.85311 .22319 L
.85451 .21836 L
.8562 .21348 L
.85959 .20377 L
.86283 .19406 L
.86422 .18919 L
.86588 .18434 L
.86925 .17463 L
.87248 .16492 L
.87393 .15978 L
.87549 .15521 L
.87883 .14549 L
.88205 .13578 L
.88364 .13012 L
.88501 .12607 L
.88833 .11636 L
.89155 .10664 L
.89336 .10022 L
.89446 .09693 L
.89775 .08722 L
.90097 .07751 L
.90307 .07008 L
.90383 .06779 L
.9071 .05808 L
.91032 .04837 L
.91278 .03971 L
.91313 .03866 L
.91637 .02894 L
.91958 .01923 L
Mfstroke
.5 g
.56825 .98077 m
.57278 .97106 L
.57284 .97093 L
.57732 .96134 L
.58179 .95163 L
.58256 .94994 L
.58624 .94192 L
.59066 .93221 L
.59227 .92861 L
.59504 .92249 L
.59941 .91278 L
.60198 .90695 L
.60371 .90307 L
.60803 .89336 L
.61169 .88496 L
.61227 .88364 L
.61654 .87393 L
.62074 .86422 L
.62141 .86265 L
.62493 .85451 L
.6291 .84479 L
.63112 .84001 L
.63323 .83508 L
.63736 .82537 L
.64083 .81706 L
.64142 .81566 L
.64552 .80594 L
.64955 .79623 L
.65054 .7938 L
.65358 .78652 L
.65759 .77681 L
.66026 .77024 L
.66155 .76709 L
.66553 .75738 L
.66945 .74767 L
.66997 .74637 L
.67338 .73796 L
.67729 .72824 L
.67968 .7222 L
.68115 .71853 L
.68504 .70882 L
.68886 .69911 L
.68939 .69773 L
.6927 .68939 L
.69652 .67968 L
.69911 .67298 L
.70028 .66997 L
.70409 .66026 L
.70783 .65054 L
.70882 .64794 L
.71157 .64083 L
.71532 .63112 L
.71853 .62261 L
.71899 .62141 L
.72271 .61169 L
.7264 .60198 L
.72824 .597 L
.73003 .59227 L
.73371 .58256 L
.73733 .57284 L
.73796 .57111 L
.74095 .56313 L
.74458 .55342 L
.74767 .54495 L
.74813 .54371 L
.75173 .53399 L
.75531 .52428 L
.75738 .51851 L
.75883 .51457 L
.7624 .50486 L
.76591 .49514 L
.76709 .4918 L
.76941 .48543 L
.77294 .47572 L
.7764 .46601 L
.77681 .46483 L
.77988 .45629 L
.78337 .44658 L
.78652 .43759 L
.78678 .43687 L
.79024 .42716 L
.79369 .41744 L
.79623 .41009 L
.79706 .40773 L
.8005 .39802 L
.80391 .38831 L
.80594 .38233 L
.80725 .37859 L
.81066 .36888 L
.81402 .35917 L
.81566 .35432 L
.81734 .34946 L
.82072 .33974 L
.82404 .33003 L
.82537 .32605 L
.82734 .32032 L
.83068 .31061 L
.83397 .30089 L
.83508 .29753 L
.83724 .29118 L
.84056 .28147 L
.84382 .27176 L
.84479 .26875 L
.84706 .26204 L
.85035 .25233 L
.85358 .24262 L
.85451 .23973 L
.85679 .23291 L
.86006 .22319 L
.86326 .21348 L
.86422 .21047 L
.86644 .20377 L
.86968 .19406 L
.87286 .18434 L
.87393 .18096 L
.87601 .17463 L
.87923 .16492 L
.88239 .15521 L
.88364 .15121 L
.88551 .14549 L
.8887 .13578 L
.89184 .12607 L
.89336 .12121 L
.89493 .11636 L
.89809 .10664 L
.90122 .09693 L
.90307 .09098 L
.90428 .08722 L
.90742 .07751 L
.91053 .06779 L
.91278 .06052 L
.91356 .05808 L
.91667 .04837 L
.91977 .03866 L
.92249 .02982 L
.92277 .02894 L
.92585 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.56825 .98077 m
.57278 .97106 L
.57284 .97093 L
.57732 .96134 L
.58179 .95163 L
.58256 .94994 L
.58624 .94192 L
.59066 .93221 L
.59227 .92861 L
.59504 .92249 L
.59941 .91278 L
.60198 .90695 L
.60371 .90307 L
.60803 .89336 L
.61169 .88496 L
.61227 .88364 L
.61654 .87393 L
.62074 .86422 L
.62141 .86265 L
.62493 .85451 L
.6291 .84479 L
.63112 .84001 L
.63323 .83508 L
.63736 .82537 L
.64083 .81706 L
.64142 .81566 L
.64552 .80594 L
.64955 .79623 L
.65054 .7938 L
.65358 .78652 L
.65759 .77681 L
.66026 .77024 L
.66155 .76709 L
.66553 .75738 L
.66945 .74767 L
.66997 .74637 L
.67338 .73796 L
.67729 .72824 L
.67968 .7222 L
.68115 .71853 L
.68504 .70882 L
.68886 .69911 L
.68939 .69773 L
.6927 .68939 L
.69652 .67968 L
.69911 .67298 L
.70028 .66997 L
.70409 .66026 L
.70783 .65054 L
.70882 .64794 L
Mistroke
.71157 .64083 L
.71532 .63112 L
.71853 .62261 L
.71899 .62141 L
.72271 .61169 L
.7264 .60198 L
.72824 .597 L
.73003 .59227 L
.73371 .58256 L
.73733 .57284 L
.73796 .57111 L
.74095 .56313 L
.74458 .55342 L
.74767 .54495 L
.74813 .54371 L
.75173 .53399 L
.75531 .52428 L
.75738 .51851 L
.75883 .51457 L
.7624 .50486 L
.76591 .49514 L
.76709 .4918 L
.76941 .48543 L
.77294 .47572 L
.7764 .46601 L
.77681 .46483 L
.77988 .45629 L
.78337 .44658 L
.78652 .43759 L
.78678 .43687 L
.79024 .42716 L
.79369 .41744 L
.79623 .41009 L
.79706 .40773 L
.8005 .39802 L
.80391 .38831 L
.80594 .38233 L
.80725 .37859 L
.81066 .36888 L
.81402 .35917 L
.81566 .35432 L
.81734 .34946 L
.82072 .33974 L
.82404 .33003 L
.82537 .32605 L
.82734 .32032 L
.83068 .31061 L
.83397 .30089 L
.83508 .29753 L
.83724 .29118 L
Mistroke
.84056 .28147 L
.84382 .27176 L
.84479 .26875 L
.84706 .26204 L
.85035 .25233 L
.85358 .24262 L
.85451 .23973 L
.85679 .23291 L
.86006 .22319 L
.86326 .21348 L
.86422 .21047 L
.86644 .20377 L
.86968 .19406 L
.87286 .18434 L
.87393 .18096 L
.87601 .17463 L
.87923 .16492 L
.88239 .15521 L
.88364 .15121 L
.88551 .14549 L
.8887 .13578 L
.89184 .12607 L
.89336 .12121 L
.89493 .11636 L
.89809 .10664 L
.90122 .09693 L
.90307 .09098 L
.90428 .08722 L
.90742 .07751 L
.91053 .06779 L
.91278 .06052 L
.91356 .05808 L
.91667 .04837 L
.91977 .03866 L
.92249 .02982 L
.92277 .02894 L
.92585 .01923 L
Mfstroke
.6 g
.57933 .98077 m
.58256 .97371 L
.58375 .97106 L
.58815 .96134 L
.59227 .9522 L
.59252 .95163 L
.59685 .94192 L
.60117 .93221 L
.60198 .93036 L
.60543 .92249 L
.60969 .91278 L
.61169 .90819 L
.61391 .90307 L
.61811 .89336 L
.62141 .88571 L
.62228 .88364 L
.62643 .87393 L
.63057 .86422 L
.63112 .86292 L
.63465 .85451 L
.63875 .84479 L
.64083 .83981 L
.64279 .83508 L
.64683 .82537 L
.65054 .8164 L
.65085 .81566 L
.65483 .80594 L
.65881 .79623 L
.66026 .79269 L
.66274 .78652 L
.66669 .77681 L
.66997 .76868 L
.6706 .76709 L
.67448 .75738 L
.67837 .74767 L
.67968 .74437 L
.6822 .73796 L
.68605 .72824 L
.68939 .71978 L
.68988 .71853 L
.69366 .70882 L
.69747 .69911 L
.69911 .69489 L
.70121 .68939 L
.70498 .67968 L
.70873 .66997 L
.70882 .66973 L
.71242 .66026 L
.71614 .65054 L
.71853 .64428 L
.71982 .64083 L
.72349 .63112 L
.72717 .62141 L
.72824 .61855 L
.73079 .61169 L
.73443 .60198 L
.73796 .59254 L
.73806 .59227 L
.74163 .58256 L
.74524 .57284 L
.74767 .56627 L
.7488 .56313 L
.75236 .55342 L
.75593 .54371 L
.75738 .53972 L
.75943 .53399 L
.76297 .52428 L
.7665 .51457 L
.76709 .51291 L
.76996 .50486 L
.77346 .49514 L
.77681 .48583 L
.77695 .48543 L
.78038 .47572 L
.78385 .46601 L
.78652 .45849 L
.78728 .45629 L
.79069 .44658 L
.79413 .43687 L
.79623 .43089 L
.79751 .42716 L
.8009 .41744 L
.80431 .40773 L
.80594 .40304 L
.80765 .39802 L
.81102 .38831 L
.8144 .37859 L
.81566 .37493 L
.8177 .36888 L
.82104 .35917 L
.82438 .34946 L
.82537 .34657 L
.82765 .33974 L
.83097 .33003 L
.83428 .32032 L
.83508 .31795 L
.83752 .31061 L
.84081 .30089 L
.8441 .29118 L
.84479 .28909 L
.8473 .28147 L
.85057 .27176 L
.85382 .26204 L
.85451 .25999 L
.857 .25233 L
.86024 .24262 L
.86347 .23291 L
.86422 .23063 L
.86662 .22319 L
.86983 .21348 L
.87304 .20377 L
.87393 .20104 L
.87617 .19406 L
.87935 .18434 L
.88253 .17463 L
.88364 .17121 L
.88563 .16492 L
.88879 .15521 L
.89195 .14549 L
.89336 .14114 L
.89503 .13578 L
.89816 .12607 L
.9013 .11636 L
.90307 .11083 L
.90436 .10664 L
.90746 .09693 L
.91058 .08722 L
.91278 .08029 L
.91363 .07751 L
.91669 .06779 L
.91979 .05808 L
.92249 .04951 L
.92284 .04837 L
.92585 .03866 L
.92893 .02894 L
.93198 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.57933 .98077 m
.58256 .97371 L
.58375 .97106 L
.58815 .96134 L
.59227 .9522 L
.59252 .95163 L
.59685 .94192 L
.60117 .93221 L
.60198 .93036 L
.60543 .92249 L
.60969 .91278 L
.61169 .90819 L
.61391 .90307 L
.61811 .89336 L
.62141 .88571 L
.62228 .88364 L
.62643 .87393 L
.63057 .86422 L
.63112 .86292 L
.63465 .85451 L
.63875 .84479 L
.64083 .83981 L
.64279 .83508 L
.64683 .82537 L
.65054 .8164 L
.65085 .81566 L
.65483 .80594 L
.65881 .79623 L
.66026 .79269 L
.66274 .78652 L
.66669 .77681 L
.66997 .76868 L
.6706 .76709 L
.67448 .75738 L
.67837 .74767 L
.67968 .74437 L
.6822 .73796 L
.68605 .72824 L
.68939 .71978 L
.68988 .71853 L
.69366 .70882 L
.69747 .69911 L
.69911 .69489 L
.70121 .68939 L
.70498 .67968 L
.70873 .66997 L
.70882 .66973 L
.71242 .66026 L
.71614 .65054 L
.71853 .64428 L
Mistroke
.71982 .64083 L
.72349 .63112 L
.72717 .62141 L
.72824 .61855 L
.73079 .61169 L
.73443 .60198 L
.73796 .59254 L
.73806 .59227 L
.74163 .58256 L
.74524 .57284 L
.74767 .56627 L
.7488 .56313 L
.75236 .55342 L
.75593 .54371 L
.75738 .53972 L
.75943 .53399 L
.76297 .52428 L
.7665 .51457 L
.76709 .51291 L
.76996 .50486 L
.77346 .49514 L
.77681 .48583 L
.77695 .48543 L
.78038 .47572 L
.78385 .46601 L
.78652 .45849 L
.78728 .45629 L
.79069 .44658 L
.79413 .43687 L
.79623 .43089 L
.79751 .42716 L
.8009 .41744 L
.80431 .40773 L
.80594 .40304 L
.80765 .39802 L
.81102 .38831 L
.8144 .37859 L
.81566 .37493 L
.8177 .36888 L
.82104 .35917 L
.82438 .34946 L
.82537 .34657 L
.82765 .33974 L
.83097 .33003 L
.83428 .32032 L
.83508 .31795 L
.83752 .31061 L
.84081 .30089 L
.8441 .29118 L
.84479 .28909 L
Mistroke
.8473 .28147 L
.85057 .27176 L
.85382 .26204 L
.85451 .25999 L
.857 .25233 L
.86024 .24262 L
.86347 .23291 L
.86422 .23063 L
.86662 .22319 L
.86983 .21348 L
.87304 .20377 L
.87393 .20104 L
.87617 .19406 L
.87935 .18434 L
.88253 .17463 L
.88364 .17121 L
.88563 .16492 L
.88879 .15521 L
.89195 .14549 L
.89336 .14114 L
.89503 .13578 L
.89816 .12607 L
.9013 .11636 L
.90307 .11083 L
.90436 .10664 L
.90746 .09693 L
.91058 .08722 L
.91278 .08029 L
.91363 .07751 L
.91669 .06779 L
.91979 .05808 L
.92249 .04951 L
.92284 .04837 L
.92585 .03866 L
.92893 .02894 L
.93198 .01923 L
Mfstroke
.7 g
.59086 .98077 m
.59227 .97765 L
.59508 .97106 L
.59941 .96134 L
.60198 .95557 L
.60362 .95163 L
.60785 .94192 L
.61169 .9332 L
.61209 .93221 L
.61619 .92249 L
.62042 .91278 L
.62141 .91051 L
.62445 .90307 L
.62861 .89336 L
.63112 .88751 L
.63265 .88364 L
.63671 .87393 L
.64083 .86422 L
.64083 .86422 L
.64472 .85451 L
.6488 .84479 L
.65054 .84061 L
.65269 .83508 L
.65668 .82537 L
.66026 .81672 L
.66065 .81566 L
.66448 .80594 L
.66846 .79623 L
.66997 .79254 L
.67224 .78652 L
.67614 .77681 L
.67968 .76807 L
.68003 .76709 L
.68376 .75738 L
.68765 .74767 L
.68939 .7433 L
.69135 .73796 L
.69515 .72824 L
.699 .71853 L
.69911 .71827 L
.7026 .70882 L
.70641 .69911 L
.70882 .69294 L
.71006 .68939 L
.71374 .67968 L
.71752 .66997 L
.71853 .66735 L
.72105 .66026 L
.72476 .65054 L
.72824 .64148 L
.72846 .64083 L
.73195 .63112 L
.73565 .62141 L
.73796 .61533 L
.73918 .61169 L
.74274 .60198 L
.74641 .59227 L
.74767 .58892 L
.74983 .58256 L
.75342 .57284 L
.75705 .56313 L
.75738 .56225 L
.7604 .55342 L
.76399 .54371 L
.76709 .5353 L
.7675 .53399 L
.77087 .52428 L
.77444 .51457 L
.77681 .5081 L
.77783 .50486 L
.78124 .49514 L
.78478 .48543 L
.78652 .48064 L
.78808 .47572 L
.79151 .46601 L
.79502 .45629 L
.79623 .45292 L
.79825 .44658 L
.80168 .43687 L
.80516 .42716 L
.80594 .42495 L
.80834 .41744 L
.81175 .40773 L
.81521 .39802 L
.81566 .39673 L
.81833 .38831 L
.82173 .37859 L
.82515 .36888 L
.82537 .36826 L
.82824 .35917 L
.83162 .34946 L
.83501 .33974 L
.83508 .33954 L
.83806 .33003 L
.84142 .32032 L
.84478 .31061 L
.84479 .31058 L
.8478 .30089 L
.85113 .29118 L
.85447 .28147 L
.85451 .28137 L
.85745 .27176 L
.86076 .26204 L
.86408 .25233 L
.86422 .25192 L
.86703 .24262 L
.87031 .23291 L
.87361 .22319 L
.87393 .22222 L
.87653 .21348 L
.87979 .20377 L
.88306 .19406 L
.88364 .19229 L
.88596 .18434 L
.88918 .17463 L
.89243 .16492 L
.89336 .16213 L
.89533 .15521 L
.8985 .14549 L
.90174 .13578 L
.90307 .13173 L
.90463 .12607 L
.90775 .11636 L
.91097 .10664 L
.91278 .1011 L
.91389 .09693 L
.91693 .08722 L
.92013 .07751 L
.92249 .07024 L
.92311 .06779 L
.92604 .05808 L
.92922 .04837 L
.93221 .03915 L
.93232 .03866 L
.9351 .02894 L
.93824 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.59086 .98077 m
.59227 .97765 L
.59508 .97106 L
.59941 .96134 L
.60198 .95557 L
.60362 .95163 L
.60785 .94192 L
.61169 .9332 L
.61209 .93221 L
.61619 .92249 L
.62042 .91278 L
.62141 .91051 L
.62445 .90307 L
.62861 .89336 L
.63112 .88751 L
.63265 .88364 L
.63671 .87393 L
.64083 .86422 L
.64083 .86422 L
.64472 .85451 L
.6488 .84479 L
.65054 .84061 L
.65269 .83508 L
.65668 .82537 L
.66026 .81672 L
.66065 .81566 L
.66448 .80594 L
.66846 .79623 L
.66997 .79254 L
.67224 .78652 L
.67614 .77681 L
.67968 .76807 L
.68003 .76709 L
.68376 .75738 L
.68765 .74767 L
.68939 .7433 L
.69135 .73796 L
.69515 .72824 L
.699 .71853 L
.69911 .71827 L
.7026 .70882 L
.70641 .69911 L
.70882 .69294 L
.71006 .68939 L
.71374 .67968 L
.71752 .66997 L
.71853 .66735 L
.72105 .66026 L
.72476 .65054 L
.72824 .64148 L
Mistroke
.72846 .64083 L
.73195 .63112 L
.73565 .62141 L
.73796 .61533 L
.73918 .61169 L
.74274 .60198 L
.74641 .59227 L
.74767 .58892 L
.74983 .58256 L
.75342 .57284 L
.75705 .56313 L
.75738 .56225 L
.7604 .55342 L
.76399 .54371 L
.76709 .5353 L
.7675 .53399 L
.77087 .52428 L
.77444 .51457 L
.77681 .5081 L
.77783 .50486 L
.78124 .49514 L
.78478 .48543 L
.78652 .48064 L
.78808 .47572 L
.79151 .46601 L
.79502 .45629 L
.79623 .45292 L
.79825 .44658 L
.80168 .43687 L
.80516 .42716 L
.80594 .42495 L
.80834 .41744 L
.81175 .40773 L
.81521 .39802 L
.81566 .39673 L
.81833 .38831 L
.82173 .37859 L
.82515 .36888 L
.82537 .36826 L
.82824 .35917 L
.83162 .34946 L
.83501 .33974 L
.83508 .33954 L
.83806 .33003 L
.84142 .32032 L
.84478 .31061 L
.84479 .31058 L
.8478 .30089 L
.85113 .29118 L
.85447 .28147 L
Mistroke
.85451 .28137 L
.85745 .27176 L
.86076 .26204 L
.86408 .25233 L
.86422 .25192 L
.86703 .24262 L
.87031 .23291 L
.87361 .22319 L
.87393 .22222 L
.87653 .21348 L
.87979 .20377 L
.88306 .19406 L
.88364 .19229 L
.88596 .18434 L
.88918 .17463 L
.89243 .16492 L
.89336 .16213 L
.89533 .15521 L
.8985 .14549 L
.90174 .13578 L
.90307 .13173 L
.90463 .12607 L
.90775 .11636 L
.91097 .10664 L
.91278 .1011 L
.91389 .09693 L
.91693 .08722 L
.92013 .07751 L
.92249 .07024 L
.92311 .06779 L
.92604 .05808 L
.92922 .04837 L
.93221 .03915 L
.93232 .03866 L
.9351 .02894 L
.93824 .01923 L
Mfstroke
.8 g
.60657 .98077 m
.61035 .97106 L
.61169 .96846 L
.61471 .96134 L
.61778 .95163 L
.62141 .94507 L
.62277 .94192 L
.62679 .93221 L
.63068 .92249 L
.63112 .92159 L
.63474 .91278 L
.63805 .90307 L
.64083 .89766 L
.64262 .89336 L
.64486 .88364 L
.65041 .87393 L
.65054 .87364 L
.65433 .86422 L
.65762 .85451 L
.66026 .84918 L
.66204 .84479 L
.66425 .83508 L
.66963 .82537 L
.66997 .82462 L
.6735 .81566 L
.67661 .80594 L
.67968 .79965 L
.68105 .79623 L
.68291 .78652 L
.68836 .77681 L
.68939 .77452 L
.69227 .76709 L
.69503 .75738 L
.69911 .74909 L
.69967 .74767 L
.70336 .73796 L
.7066 .72824 L
.70882 .72338 L
.71068 .71853 L
.71281 .70882 L
.71782 .69911 L
.71853 .69748 L
.72156 .68939 L
.72427 .67968 L
.72824 .67126 L
.72874 .66997 L
.73233 .66026 L
.73538 .65054 L
.73796 .64478 L
.73943 .64083 L
.7412 .63112 L
.74624 .62141 L
.74767 .61808 L
.75001 .61169 L
.75226 .60198 L
.75691 .59227 L
.75738 .59114 L
.76048 .58256 L
.76305 .57284 L
.76709 .56391 L
.76738 .56313 L
.77084 .55342 L
.77363 .54371 L
.77681 .53642 L
.77768 .53399 L
.78111 .52428 L
.78403 .51457 L
.78652 .50869 L
.78788 .50486 L
.78937 .49514 L
.79429 .48543 L
.79623 .48073 L
.79799 .47572 L
.79971 .46601 L
.80442 .45629 L
.80594 .45253 L
.80801 .44658 L
.80987 .43687 L
.81443 .42716 L
.81566 .42408 L
.81794 .41744 L
.81987 .40773 L
.82433 .39802 L
.82537 .39539 L
.82778 .38831 L
.82975 .37859 L
.83414 .36888 L
.83508 .36646 L
.83754 .35917 L
.83949 .34946 L
.84384 .33974 L
.84479 .33728 L
.84722 .33003 L
.84911 .32032 L
.85345 .31061 L
.85451 .30787 L
.85683 .30089 L
.85861 .29118 L
.86297 .28147 L
.86422 .27822 L
.86635 .27176 L
.86799 .26204 L
.8724 .25233 L
.87393 .24834 L
.87581 .24262 L
.87724 .23291 L
.88173 .22319 L
.88364 .21822 L
.88519 .21348 L
.88634 .20377 L
.89097 .19406 L
.89336 .18788 L
.89451 .18434 L
.89761 .17463 L
.9001 .16492 L
.90307 .15731 L
.90375 .15521 L
.90684 .14549 L
.90912 .13578 L
.91278 .12653 L
.91293 .12607 L
.916 .11636 L
.91802 .10664 L
.92198 .09693 L
.92249 .0955 L
.9251 .08722 L
.92676 .07751 L
.93091 .06779 L
.93221 .06424 L
.93414 .05808 L
.93533 .04837 L
.93973 .03866 L
.94192 .03276 L
.94311 .02894 L
.94611 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.60657 .98077 m
.61035 .97106 L
.61169 .96846 L
.61471 .96134 L
.61778 .95163 L
.62141 .94507 L
.62277 .94192 L
.62679 .93221 L
.63068 .92249 L
.63112 .92159 L
.63474 .91278 L
.63805 .90307 L
.64083 .89766 L
.64262 .89336 L
.64486 .88364 L
.65041 .87393 L
.65054 .87364 L
.65433 .86422 L
.65762 .85451 L
.66026 .84918 L
.66204 .84479 L
.66425 .83508 L
.66963 .82537 L
.66997 .82462 L
.6735 .81566 L
.67661 .80594 L
.67968 .79965 L
.68105 .79623 L
.68291 .78652 L
.68836 .77681 L
.68939 .77452 L
.69227 .76709 L
.69503 .75738 L
.69911 .74909 L
.69967 .74767 L
.70336 .73796 L
.7066 .72824 L
.70882 .72338 L
.71068 .71853 L
.71281 .70882 L
.71782 .69911 L
.71853 .69748 L
.72156 .68939 L
.72427 .67968 L
.72824 .67126 L
.72874 .66997 L
.73233 .66026 L
.73538 .65054 L
.73796 .64478 L
.73943 .64083 L
Mistroke
.7412 .63112 L
.74624 .62141 L
.74767 .61808 L
.75001 .61169 L
.75226 .60198 L
.75691 .59227 L
.75738 .59114 L
.76048 .58256 L
.76305 .57284 L
.76709 .56391 L
.76738 .56313 L
.77084 .55342 L
.77363 .54371 L
.77681 .53642 L
.77768 .53399 L
.78111 .52428 L
.78403 .51457 L
.78652 .50869 L
.78788 .50486 L
.78937 .49514 L
.79429 .48543 L
.79623 .48073 L
.79799 .47572 L
.79971 .46601 L
.80442 .45629 L
.80594 .45253 L
.80801 .44658 L
.80987 .43687 L
.81443 .42716 L
.81566 .42408 L
.81794 .41744 L
.81987 .40773 L
.82433 .39802 L
.82537 .39539 L
.82778 .38831 L
.82975 .37859 L
.83414 .36888 L
.83508 .36646 L
.83754 .35917 L
.83949 .34946 L
.84384 .33974 L
.84479 .33728 L
.84722 .33003 L
.84911 .32032 L
.85345 .31061 L
.85451 .30787 L
.85683 .30089 L
.85861 .29118 L
.86297 .28147 L
.86422 .27822 L
Mistroke
.86635 .27176 L
.86799 .26204 L
.8724 .25233 L
.87393 .24834 L
.87581 .24262 L
.87724 .23291 L
.88173 .22319 L
.88364 .21822 L
.88519 .21348 L
.88634 .20377 L
.89097 .19406 L
.89336 .18788 L
.89451 .18434 L
.89761 .17463 L
.9001 .16492 L
.90307 .15731 L
.90375 .15521 L
.90684 .14549 L
.90912 .13578 L
.91278 .12653 L
.91293 .12607 L
.916 .11636 L
.91802 .10664 L
.92198 .09693 L
.92249 .0955 L
.9251 .08722 L
.92676 .07751 L
.93091 .06779 L
.93221 .06424 L
.93414 .05808 L
.93533 .04837 L
.93973 .03866 L
.94192 .03276 L
.94311 .02894 L
.94611 .01923 L
Mfstroke
.7 g
.63224 .98077 m
.63621 .97106 L
.64046 .96134 L
.64083 .96055 L
.64464 .95163 L
.64883 .94192 L
.65054 .93804 L
.65396 .93221 L
.65709 .92249 L
.66026 .91508 L
.66147 .91278 L
.66525 .90307 L
.66932 .89336 L
.66997 .89186 L
.67482 .88364 L
.67733 .87393 L
.67968 .8683 L
.68181 .86422 L
.68525 .85451 L
.68921 .84479 L
.68939 .84436 L
.69474 .83508 L
.697 .82537 L
.69911 .82019 L
.7014 .81566 L
.70471 .80594 L
.70857 .79623 L
.70882 .79562 L
.7138 .78652 L
.71616 .77681 L
.71853 .77082 L
.72033 .76709 L
.72369 .75738 L
.72745 .74767 L
.72824 .74568 L
.73218 .73796 L
.73488 .72824 L
.73796 .72023 L
.73873 .71853 L
.74411 .70882 L
.74591 .69911 L
.74767 .69453 L
.75009 .68939 L
.75318 .67968 L
.75682 .66997 L
.75738 .6685 L
.76141 .66026 L
.76399 .65054 L
.76709 .64218 L
.76768 .64083 L
.77271 .63112 L
.77467 .62141 L
.77681 .61563 L
.77855 .61169 L
.78171 .60198 L
.78523 .59227 L
.78652 .58878 L
.78934 .58256 L
.79219 .57284 L
.79568 .56313 L
.79623 .56163 L
.80002 .55342 L
.80256 .54371 L
.80594 .5342 L
.80603 .53399 L
.8106 .52428 L
.81282 .51457 L
.81566 .50654 L
.81635 .50486 L
.82106 .49514 L
.82298 .48543 L
.82537 .47861 L
.82657 .47572 L
.83139 .46601 L
.83303 .45629 L
.83508 .45042 L
.83667 .44658 L
.84158 .43687 L
.843 .42716 L
.84479 .42196 L
.84666 .41744 L
.85163 .40773 L
.85287 .39802 L
.85451 .39324 L
.85654 .38831 L
.86151 .37859 L
.86265 .36888 L
.86422 .36427 L
.86631 .35917 L
.87125 .34946 L
.87235 .33974 L
.87393 .33505 L
.87596 .33003 L
.88083 .32032 L
.88196 .31061 L
.88364 .30558 L
.88551 .30089 L
.89027 .29118 L
.8915 .28147 L
.89336 .27585 L
.89497 .27176 L
.89958 .26204 L
.90096 .25233 L
.90307 .24588 L
.90433 .24262 L
.90878 .23291 L
.91034 .22319 L
.91278 .21567 L
.91361 .21348 L
.91788 .20377 L
.91965 .19406 L
.92249 .18521 L
.92282 .18434 L
.92691 .17463 L
.92889 .16492 L
.93199 .15521 L
.93221 .15453 L
.93586 .14549 L
.93807 .13578 L
.94114 .12607 L
.94192 .12362 L
.94477 .11636 L
.94718 .10664 L
.95022 .09693 L
.95163 .09247 L
.95362 .08722 L
.95814 .07751 L
.95924 .06779 L
.96134 .06107 L
.96244 .05808 L
.96663 .04837 L
.9682 .03866 L
.97106 .02943 L
.97121 .02894 L
.97422 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.63224 .98077 m
.63621 .97106 L
.64046 .96134 L
.64083 .96055 L
.64464 .95163 L
.64883 .94192 L
.65054 .93804 L
.65396 .93221 L
.65709 .92249 L
.66026 .91508 L
.66147 .91278 L
.66525 .90307 L
.66932 .89336 L
.66997 .89186 L
.67482 .88364 L
.67733 .87393 L
.67968 .8683 L
.68181 .86422 L
.68525 .85451 L
.68921 .84479 L
.68939 .84436 L
.69474 .83508 L
.697 .82537 L
.69911 .82019 L
.7014 .81566 L
.70471 .80594 L
.70857 .79623 L
.70882 .79562 L
.7138 .78652 L
.71616 .77681 L
.71853 .77082 L
.72033 .76709 L
.72369 .75738 L
.72745 .74767 L
.72824 .74568 L
.73218 .73796 L
.73488 .72824 L
.73796 .72023 L
.73873 .71853 L
.74411 .70882 L
.74591 .69911 L
.74767 .69453 L
.75009 .68939 L
.75318 .67968 L
.75682 .66997 L
.75738 .6685 L
.76141 .66026 L
.76399 .65054 L
.76709 .64218 L
.76768 .64083 L
Mistroke
.77271 .63112 L
.77467 .62141 L
.77681 .61563 L
.77855 .61169 L
.78171 .60198 L
.78523 .59227 L
.78652 .58878 L
.78934 .58256 L
.79219 .57284 L
.79568 .56313 L
.79623 .56163 L
.80002 .55342 L
.80256 .54371 L
.80594 .5342 L
.80603 .53399 L
.8106 .52428 L
.81282 .51457 L
.81566 .50654 L
.81635 .50486 L
.82106 .49514 L
.82298 .48543 L
.82537 .47861 L
.82657 .47572 L
.83139 .46601 L
.83303 .45629 L
.83508 .45042 L
.83667 .44658 L
.84158 .43687 L
.843 .42716 L
.84479 .42196 L
.84666 .41744 L
.85163 .40773 L
.85287 .39802 L
.85451 .39324 L
.85654 .38831 L
.86151 .37859 L
.86265 .36888 L
.86422 .36427 L
.86631 .35917 L
.87125 .34946 L
.87235 .33974 L
.87393 .33505 L
.87596 .33003 L
.88083 .32032 L
.88196 .31061 L
.88364 .30558 L
.88551 .30089 L
.89027 .29118 L
.8915 .28147 L
.89336 .27585 L
Mistroke
.89497 .27176 L
.89958 .26204 L
.90096 .25233 L
.90307 .24588 L
.90433 .24262 L
.90878 .23291 L
.91034 .22319 L
.91278 .21567 L
.91361 .21348 L
.91788 .20377 L
.91965 .19406 L
.92249 .18521 L
.92282 .18434 L
.92691 .17463 L
.92889 .16492 L
.93199 .15521 L
.93221 .15453 L
.93586 .14549 L
.93807 .13578 L
.94114 .12607 L
.94192 .12362 L
.94477 .11636 L
.94718 .10664 L
.95022 .09693 L
.95163 .09247 L
.95362 .08722 L
.95814 .07751 L
.95924 .06779 L
.96134 .06107 L
.96244 .05808 L
.96663 .04837 L
.9682 .03866 L
.97106 .02943 L
.97121 .02894 L
.97422 .01923 L
Mfstroke
.6 g
.98077 .02195 m
.97869 .02894 L
.97575 .03866 L
.97169 .04837 L
.97106 .05395 L
.97006 .05808 L
.96712 .06779 L
.96398 .07751 L
.96134 .08571 L
.96101 .08722 L
.95821 .09693 L
.95507 .10664 L
.95192 .11636 L
.95163 .11725 L
.94922 .12607 L
.94609 .13578 L
.94291 .14549 L
.94192 .14856 L
.94015 .15521 L
.93705 .16492 L
.93384 .17463 L
.93221 .17964 L
.93099 .18434 L
.92793 .19406 L
.9247 .20377 L
.92249 .21048 L
.92174 .21348 L
.91874 .22319 L
.9155 .23291 L
.91278 .24109 L
.91241 .24262 L
.90948 .25233 L
.90623 .26204 L
.90307 .27147 L
.903 .27176 L
.90014 .28147 L
.89688 .29118 L
.89359 .30089 L
.89336 .3016 L
.89072 .31061 L
.88745 .32032 L
.88414 .33003 L
.88364 .3315 L
.88123 .33974 L
.87795 .34946 L
.87461 .35917 L
.87393 .36116 L
.87166 .36888 L
.86836 .37859 L
.865 .38831 L
.86422 .39057 L
.86201 .39802 L
.85869 .40773 L
.8553 .41744 L
.85451 .41974 L
.85228 .42716 L
.84893 .43687 L
.84552 .44658 L
.84479 .44866 L
.84247 .45629 L
.83909 .46601 L
.83564 .47572 L
.83508 .47732 L
.83257 .48543 L
.82915 .49514 L
.82568 .50486 L
.82537 .50574 L
.82258 .51457 L
.81912 .52428 L
.81566 .5339 L
.81563 .53399 L
.81249 .54371 L
.80898 .55342 L
.80594 .5618 L
.80556 .56313 L
.8023 .57284 L
.79875 .58256 L
.79623 .58945 L
.79538 .59227 L
.792 .60198 L
.78841 .61169 L
.78652 .61683 L
.78507 .62141 L
.78159 .63112 L
.77796 .64083 L
.77681 .64395 L
.77464 .65054 L
.77106 .66026 L
.7674 .66997 L
.76709 .67079 L
.76407 .67968 L
.76041 .68939 L
.75738 .69737 L
.75683 .69911 L
.75336 .70882 L
.74964 .71853 L
.74767 .72368 L
.74614 .72824 L
.74251 .73796 L
.73874 .74767 L
.73796 .7497 L
.73527 .75738 L
.73152 .76709 L
.72824 .77545 L
.7278 .77681 L
.72422 .78652 L
.72038 .79623 L
.71853 .80092 L
.71677 .80594 L
.71299 .81566 L
.70911 .82537 L
.70882 .8261 L
.70551 .83508 L
.70161 .84479 L
.69911 .851 L
.69786 .85451 L
.69404 .86422 L
.69007 .87393 L
.68939 .87559 L
.68636 .88364 L
.68238 .89336 L
.67968 .89989 L
.67852 .90307 L
.67462 .91278 L
.67055 .92249 L
.66997 .92389 L
.66674 .93221 L
.66266 .94192 L
.66026 .94759 L
.65872 .95163 L
.65468 .96134 L
.65054 .97097 L
.65051 .97106 L
.64659 .98077 L
.98077 .98077 L
F
0 g
.98077 .02195 m
.97869 .02894 L
.97575 .03866 L
.97169 .04837 L
.97106 .05395 L
.97006 .05808 L
.96712 .06779 L
.96398 .07751 L
.96134 .08571 L
.96101 .08722 L
.95821 .09693 L
.95507 .10664 L
.95192 .11636 L
.95163 .11725 L
.94922 .12607 L
.94609 .13578 L
.94291 .14549 L
.94192 .14856 L
.94015 .15521 L
.93705 .16492 L
.93384 .17463 L
.93221 .17964 L
.93099 .18434 L
.92793 .19406 L
.9247 .20377 L
.92249 .21048 L
.92174 .21348 L
.91874 .22319 L
.9155 .23291 L
.91278 .24109 L
.91241 .24262 L
.90948 .25233 L
.90623 .26204 L
.90307 .27147 L
.903 .27176 L
.90014 .28147 L
.89688 .29118 L
.89359 .30089 L
.89336 .3016 L
.89072 .31061 L
.88745 .32032 L
.88414 .33003 L
.88364 .3315 L
.88123 .33974 L
.87795 .34946 L
.87461 .35917 L
.87393 .36116 L
.87166 .36888 L
.86836 .37859 L
.865 .38831 L
Mistroke
.86422 .39057 L
.86201 .39802 L
.85869 .40773 L
.8553 .41744 L
.85451 .41974 L
.85228 .42716 L
.84893 .43687 L
.84552 .44658 L
.84479 .44866 L
.84247 .45629 L
.83909 .46601 L
.83564 .47572 L
.83508 .47732 L
.83257 .48543 L
.82915 .49514 L
.82568 .50486 L
.82537 .50574 L
.82258 .51457 L
.81912 .52428 L
.81566 .5339 L
.81563 .53399 L
.81249 .54371 L
.80898 .55342 L
.80594 .5618 L
.80556 .56313 L
.8023 .57284 L
.79875 .58256 L
.79623 .58945 L
.79538 .59227 L
.792 .60198 L
.78841 .61169 L
.78652 .61683 L
.78507 .62141 L
.78159 .63112 L
.77796 .64083 L
.77681 .64395 L
.77464 .65054 L
.77106 .66026 L
.7674 .66997 L
.76709 .67079 L
.76407 .67968 L
.76041 .68939 L
.75738 .69737 L
.75683 .69911 L
.75336 .70882 L
.74964 .71853 L
.74767 .72368 L
.74614 .72824 L
.74251 .73796 L
.73874 .74767 L
Mistroke
.73796 .7497 L
.73527 .75738 L
.73152 .76709 L
.72824 .77545 L
.7278 .77681 L
.72422 .78652 L
.72038 .79623 L
.71853 .80092 L
.71677 .80594 L
.71299 .81566 L
.70911 .82537 L
.70882 .8261 L
.70551 .83508 L
.70161 .84479 L
.69911 .851 L
.69786 .85451 L
.69404 .86422 L
.69007 .87393 L
.68939 .87559 L
.68636 .88364 L
.68238 .89336 L
.67968 .89989 L
.67852 .90307 L
.67462 .91278 L
.67055 .92249 L
.66997 .92389 L
.66674 .93221 L
.66266 .94192 L
.66026 .94759 L
.65872 .95163 L
.65468 .96134 L
.65054 .97097 L
.65051 .97106 L
.64659 .98077 L
Mfstroke
.5 g
.98077 .04219 m
.97661 .04837 L
.97495 .05808 L
.97281 .06779 L
.97106 .07426 L
.97012 .07751 L
.96718 .08722 L
.96417 .09693 L
.96134 .1061 L
.96119 .10664 L
.95827 .11636 L
.95525 .12607 L
.95223 .13578 L
.95163 .13772 L
.9493 .14549 L
.94627 .15521 L
.94322 .16492 L
.94192 .16911 L
.94026 .17463 L
.93723 .18434 L
.93416 .19406 L
.93221 .20027 L
.93116 .20377 L
.92813 .21348 L
.92503 .22319 L
.92249 .2312 L
.92198 .23291 L
.91895 .24262 L
.91584 .25233 L
.91278 .2619 L
.91274 .26204 L
.90971 .27176 L
.90658 .28147 L
.90345 .29118 L
.90307 .29237 L
.9004 .30089 L
.89725 .31061 L
.89409 .32032 L
.89336 .3226 L
.89102 .33003 L
.88785 .33974 L
.88466 .34946 L
.88364 .35259 L
.88156 .35917 L
.87838 .36888 L
.87516 .37859 L
.87393 .38234 L
.87203 .38831 L
.86882 .39802 L
.86558 .40773 L
.86422 .41185 L
.86242 .41744 L
.85919 .42716 L
.85593 .43687 L
.85451 .44112 L
.85273 .44658 L
.84948 .45629 L
.84619 .46601 L
.84479 .47014 L
.84297 .47572 L
.83968 .48543 L
.83636 .49514 L
.83508 .49891 L
.83311 .50486 L
.8298 .51457 L
.82645 .52428 L
.82537 .52743 L
.82317 .53399 L
.81982 .54371 L
.81645 .55342 L
.81566 .5557 L
.81314 .56313 L
.80975 .57284 L
.80635 .58256 L
.80594 .58372 L
.80301 .59227 L
.79959 .60198 L
.79623 .61148 L
.79616 .61169 L
.79278 .62141 L
.78932 .63112 L
.78652 .63898 L
.78588 .64083 L
.78245 .65054 L
.77895 .66026 L
.77681 .66621 L
.77549 .66997 L
.77201 .67968 L
.76847 .68939 L
.76709 .69319 L
.76499 .69911 L
.76145 .70882 L
.75788 .71853 L
.75738 .71989 L
.75437 .72824 L
.75078 .73796 L
.74767 .74633 L
.74719 .74767 L
.74362 .75738 L
.73998 .76709 L
.73796 .77249 L
.73638 .77681 L
.73274 .78652 L
.72906 .79623 L
.72824 .79838 L
.72543 .80594 L
.72172 .81566 L
.71853 .82399 L
.71802 .82537 L
.71433 .83508 L
.71057 .84479 L
.70882 .84932 L
.70685 .85451 L
.70308 .86422 L
.69928 .87393 L
.69911 .87436 L
.69551 .88364 L
.69168 .89336 L
.68939 .89912 L
.68786 .90307 L
.68401 .91278 L
.68012 .92249 L
.67968 .92358 L
.67626 .93221 L
.67234 .94192 L
.66997 .94775 L
.66842 .95163 L
.66448 .96134 L
.66049 .97106 L
.66026 .97162 L
.65653 .98077 L
.98077 .98077 L
F
0 g
.98077 .04219 m
.97661 .04837 L
.97495 .05808 L
.97281 .06779 L
.97106 .07426 L
.97012 .07751 L
.96718 .08722 L
.96417 .09693 L
.96134 .1061 L
.96119 .10664 L
.95827 .11636 L
.95525 .12607 L
.95223 .13578 L
.95163 .13772 L
.9493 .14549 L
.94627 .15521 L
.94322 .16492 L
.94192 .16911 L
.94026 .17463 L
.93723 .18434 L
.93416 .19406 L
.93221 .20027 L
.93116 .20377 L
.92813 .21348 L
.92503 .22319 L
.92249 .2312 L
.92198 .23291 L
.91895 .24262 L
.91584 .25233 L
.91278 .2619 L
.91274 .26204 L
.90971 .27176 L
.90658 .28147 L
.90345 .29118 L
.90307 .29237 L
.9004 .30089 L
.89725 .31061 L
.89409 .32032 L
.89336 .3226 L
.89102 .33003 L
.88785 .33974 L
.88466 .34946 L
.88364 .35259 L
.88156 .35917 L
.87838 .36888 L
.87516 .37859 L
.87393 .38234 L
.87203 .38831 L
.86882 .39802 L
.86558 .40773 L
Mistroke
.86422 .41185 L
.86242 .41744 L
.85919 .42716 L
.85593 .43687 L
.85451 .44112 L
.85273 .44658 L
.84948 .45629 L
.84619 .46601 L
.84479 .47014 L
.84297 .47572 L
.83968 .48543 L
.83636 .49514 L
.83508 .49891 L
.83311 .50486 L
.8298 .51457 L
.82645 .52428 L
.82537 .52743 L
.82317 .53399 L
.81982 .54371 L
.81645 .55342 L
.81566 .5557 L
.81314 .56313 L
.80975 .57284 L
.80635 .58256 L
.80594 .58372 L
.80301 .59227 L
.79959 .60198 L
.79623 .61148 L
.79616 .61169 L
.79278 .62141 L
.78932 .63112 L
.78652 .63898 L
.78588 .64083 L
.78245 .65054 L
.77895 .66026 L
.77681 .66621 L
.77549 .66997 L
.77201 .67968 L
.76847 .68939 L
.76709 .69319 L
.76499 .69911 L
.76145 .70882 L
.75788 .71853 L
.75738 .71989 L
.75437 .72824 L
.75078 .73796 L
.74767 .74633 L
.74719 .74767 L
.74362 .75738 L
.73998 .76709 L
Mistroke
.73796 .77249 L
.73638 .77681 L
.73274 .78652 L
.72906 .79623 L
.72824 .79838 L
.72543 .80594 L
.72172 .81566 L
.71853 .82399 L
.71802 .82537 L
.71433 .83508 L
.71057 .84479 L
.70882 .84932 L
.70685 .85451 L
.70308 .86422 L
.69928 .87393 L
.69911 .87436 L
.69551 .88364 L
.69168 .89336 L
.68939 .89912 L
.68786 .90307 L
.68401 .91278 L
.68012 .92249 L
.67968 .92358 L
.67626 .93221 L
.67234 .94192 L
.66997 .94775 L
.66842 .95163 L
.66448 .96134 L
.66049 .97106 L
.66026 .97162 L
.65653 .98077 L
Mfstroke
.4 g
.98077 .06146 m
.97852 .06779 L
.97574 .07751 L
.97295 .08722 L
.97106 .0936 L
.97005 .09693 L
.96706 .10664 L
.96407 .11636 L
.96134 .12551 L
.96117 .12607 L
.95819 .13578 L
.95517 .14549 L
.95222 .15521 L
.95163 .1572 L
.94925 .16492 L
.94621 .17463 L
.94321 .18434 L
.94192 .18866 L
.94024 .19406 L
.93719 .20377 L
.93415 .21348 L
.93221 .21989 L
.93118 .22319 L
.92811 .23291 L
.92504 .24262 L
.92249 .2509 L
.92205 .25233 L
.91896 .26204 L
.91587 .27176 L
.91284 .28147 L
.91278 .28167 L
.90975 .29118 L
.90663 .30089 L
.90356 .31061 L
.90307 .31221 L
.90047 .32032 L
.89732 .33003 L
.89422 .33974 L
.89336 .34252 L
.89112 .34946 L
.88795 .35917 L
.88481 .36888 L
.88364 .37259 L
.88169 .37859 L
.8785 .38831 L
.87533 .39802 L
.87393 .40243 L
.87219 .40773 L
.86898 .41744 L
.86578 .42716 L
.86422 .43202 L
.86262 .43687 L
.85938 .44658 L
.85615 .45629 L
.85451 .46137 L
.85296 .46601 L
.8497 .47572 L
.84645 .48543 L
.84479 .49048 L
.84323 .49514 L
.83993 .50486 L
.83666 .51457 L
.83508 .51934 L
.83341 .52428 L
.83009 .53399 L
.82678 .54371 L
.82537 .54795 L
.8235 .55342 L
.82015 .56313 L
.81682 .57284 L
.81566 .57631 L
.8135 .58256 L
.81012 .59227 L
.80677 .60198 L
.80594 .60442 L
.80341 .61169 L
.8 .62141 L
.79663 .63112 L
.79623 .63228 L
.79322 .64083 L
.78978 .65054 L
.78652 .65988 L
.78639 .66026 L
.78293 .66997 L
.77946 .67968 L
.77681 .68722 L
.77603 .68939 L
.77253 .69911 L
.76903 .70882 L
.76709 .71429 L
.76556 .71853 L
.76203 .72824 L
.75851 .73796 L
.75738 .74111 L
.75498 .74767 L
.75141 .75738 L
.74787 .76709 L
.74767 .76765 L
.74428 .77681 L
.74068 .78652 L
.73796 .79393 L
.7371 .79623 L
.73346 .80594 L
.72982 .81566 L
.72824 .81993 L
.7262 .82537 L
.72251 .83508 L
.71885 .84479 L
.71853 .84566 L
.71516 .85451 L
.71143 .86422 L
.70882 .87111 L
.70773 .87393 L
.70398 .88364 L
.70022 .89336 L
.69911 .89628 L
.69646 .90307 L
.69265 .91278 L
.68939 .92116 L
.68887 .92249 L
.68503 .93221 L
.68119 .94192 L
.67968 .94576 L
.67734 .95163 L
.67345 .96134 L
.66997 .97006 L
.66957 .97106 L
.66564 .98077 L
.98077 .98077 L
F
0 g
.98077 .06146 m
.97852 .06779 L
.97574 .07751 L
.97295 .08722 L
.97106 .0936 L
.97005 .09693 L
.96706 .10664 L
.96407 .11636 L
.96134 .12551 L
.96117 .12607 L
.95819 .13578 L
.95517 .14549 L
.95222 .15521 L
.95163 .1572 L
.94925 .16492 L
.94621 .17463 L
.94321 .18434 L
.94192 .18866 L
.94024 .19406 L
.93719 .20377 L
.93415 .21348 L
.93221 .21989 L
.93118 .22319 L
.92811 .23291 L
.92504 .24262 L
.92249 .2509 L
.92205 .25233 L
.91896 .26204 L
.91587 .27176 L
.91284 .28147 L
.91278 .28167 L
.90975 .29118 L
.90663 .30089 L
.90356 .31061 L
.90307 .31221 L
.90047 .32032 L
.89732 .33003 L
.89422 .33974 L
.89336 .34252 L
.89112 .34946 L
.88795 .35917 L
.88481 .36888 L
.88364 .37259 L
.88169 .37859 L
.8785 .38831 L
.87533 .39802 L
.87393 .40243 L
.87219 .40773 L
.86898 .41744 L
.86578 .42716 L
Mistroke
.86422 .43202 L
.86262 .43687 L
.85938 .44658 L
.85615 .45629 L
.85451 .46137 L
.85296 .46601 L
.8497 .47572 L
.84645 .48543 L
.84479 .49048 L
.84323 .49514 L
.83993 .50486 L
.83666 .51457 L
.83508 .51934 L
.83341 .52428 L
.83009 .53399 L
.82678 .54371 L
.82537 .54795 L
.8235 .55342 L
.82015 .56313 L
.81682 .57284 L
.81566 .57631 L
.8135 .58256 L
.81012 .59227 L
.80677 .60198 L
.80594 .60442 L
.80341 .61169 L
.8 .62141 L
.79663 .63112 L
.79623 .63228 L
.79322 .64083 L
.78978 .65054 L
.78652 .65988 L
.78639 .66026 L
.78293 .66997 L
.77946 .67968 L
.77681 .68722 L
.77603 .68939 L
.77253 .69911 L
.76903 .70882 L
.76709 .71429 L
.76556 .71853 L
.76203 .72824 L
.75851 .73796 L
.75738 .74111 L
.75498 .74767 L
.75141 .75738 L
.74787 .76709 L
.74767 .76765 L
.74428 .77681 L
.74068 .78652 L
Mistroke
.73796 .79393 L
.7371 .79623 L
.73346 .80594 L
.72982 .81566 L
.72824 .81993 L
.7262 .82537 L
.72251 .83508 L
.71885 .84479 L
.71853 .84566 L
.71516 .85451 L
.71143 .86422 L
.70882 .87111 L
.70773 .87393 L
.70398 .88364 L
.70022 .89336 L
.69911 .89628 L
.69646 .90307 L
.69265 .91278 L
.68939 .92116 L
.68887 .92249 L
.68503 .93221 L
.68119 .94192 L
.67968 .94576 L
.67734 .95163 L
.67345 .96134 L
.66997 .97006 L
.66957 .97106 L
.66564 .98077 L
Mfstroke
.3 g
.98077 .08169 m
.97907 .08722 L
.9762 .09693 L
.97329 .10664 L
.97106 .1139 L
.97029 .11636 L
.9672 .12607 L
.96412 .13578 L
.96143 .14549 L
.96134 .1459 L
.95838 .15521 L
.95527 .16492 L
.95237 .17463 L
.95163 .17766 L
.9495 .18434 L
.94636 .19406 L
.94334 .20377 L
.94192 .20921 L
.94055 .21348 L
.9374 .22319 L
.9343 .23291 L
.93221 .24053 L
.93154 .24262 L
.92837 .25233 L
.92522 .26204 L
.92249 .27162 L
.92245 .27176 L
.91928 .28147 L
.91609 .29118 L
.91318 .30089 L
.91278 .30248 L
.91012 .31061 L
.9069 .32032 L
.90388 .33003 L
.90307 .33311 L
.90088 .33974 L
.89764 .34946 L
.89454 .35917 L
.89336 .36351 L
.89158 .36888 L
.88831 .37859 L
.88516 .38831 L
.88364 .39368 L
.8822 .39802 L
.87891 .40773 L
.87571 .41744 L
.87393 .42361 L
.87274 .42716 L
.86943 .43687 L
.86619 .44658 L
.86422 .4533 L
.86321 .45629 L
.85988 .46601 L
.85661 .47572 L
.85451 .48275 L
.85359 .48543 L
.85024 .49514 L
.84694 .50486 L
.84479 .51196 L
.8439 .51457 L
.84052 .52428 L
.8372 .53399 L
.83508 .54092 L
.83412 .54371 L
.83072 .55342 L
.82737 .56313 L
.82537 .56964 L
.82425 .57284 L
.82082 .58256 L
.81746 .59227 L
.81566 .59811 L
.81429 .60198 L
.81084 .61169 L
.80747 .62141 L
.80594 .62634 L
.80424 .63112 L
.80076 .64083 L
.7974 .65054 L
.79623 .65431 L
.79409 .66026 L
.79058 .66997 L
.78724 .67968 L
.78652 .68202 L
.78384 .68939 L
.78031 .69911 L
.77701 .70882 L
.77681 .70949 L
.77349 .71853 L
.76994 .72824 L
.76709 .73669 L
.76663 .73796 L
.76303 .74767 L
.75947 .75738 L
.75738 .76363 L
.75609 .76709 L
.75245 .77681 L
.74892 .78652 L
.74767 .7903 L
.74544 .79623 L
.74177 .80594 L
.7383 .81566 L
.73796 .81672 L
.73466 .82537 L
.73098 .83508 L
.72824 .84286 L
.72751 .84479 L
.72376 .85451 L
.7201 .86422 L
.71853 .86873 L
.71652 .87393 L
.71274 .88364 L
.70915 .89336 L
.70882 .89433 L
.70539 .90307 L
.70161 .91278 L
.69911 .91965 L
.69798 .92249 L
.69413 .93221 L
.69038 .94192 L
.68939 .94469 L
.68662 .95163 L
.68274 .96134 L
.67968 .96945 L
.67904 .97106 L
.6751 .98077 L
.98077 .98077 L
F
0 g
.98077 .08169 m
.97907 .08722 L
.9762 .09693 L
.97329 .10664 L
.97106 .1139 L
.97029 .11636 L
.9672 .12607 L
.96412 .13578 L
.96143 .14549 L
.96134 .1459 L
.95838 .15521 L
.95527 .16492 L
.95237 .17463 L
.95163 .17766 L
.9495 .18434 L
.94636 .19406 L
.94334 .20377 L
.94192 .20921 L
.94055 .21348 L
.9374 .22319 L
.9343 .23291 L
.93221 .24053 L
.93154 .24262 L
.92837 .25233 L
.92522 .26204 L
.92249 .27162 L
.92245 .27176 L
.91928 .28147 L
.91609 .29118 L
.91318 .30089 L
.91278 .30248 L
.91012 .31061 L
.9069 .32032 L
.90388 .33003 L
.90307 .33311 L
.90088 .33974 L
.89764 .34946 L
.89454 .35917 L
.89336 .36351 L
.89158 .36888 L
.88831 .37859 L
.88516 .38831 L
.88364 .39368 L
.8822 .39802 L
.87891 .40773 L
.87571 .41744 L
.87393 .42361 L
.87274 .42716 L
.86943 .43687 L
.86619 .44658 L
Mistroke
.86422 .4533 L
.86321 .45629 L
.85988 .46601 L
.85661 .47572 L
.85451 .48275 L
.85359 .48543 L
.85024 .49514 L
.84694 .50486 L
.84479 .51196 L
.8439 .51457 L
.84052 .52428 L
.8372 .53399 L
.83508 .54092 L
.83412 .54371 L
.83072 .55342 L
.82737 .56313 L
.82537 .56964 L
.82425 .57284 L
.82082 .58256 L
.81746 .59227 L
.81566 .59811 L
.81429 .60198 L
.81084 .61169 L
.80747 .62141 L
.80594 .62634 L
.80424 .63112 L
.80076 .64083 L
.7974 .65054 L
.79623 .65431 L
.79409 .66026 L
.79058 .66997 L
.78724 .67968 L
.78652 .68202 L
.78384 .68939 L
.78031 .69911 L
.77701 .70882 L
.77681 .70949 L
.77349 .71853 L
.76994 .72824 L
.76709 .73669 L
.76663 .73796 L
.76303 .74767 L
.75947 .75738 L
.75738 .76363 L
.75609 .76709 L
.75245 .77681 L
.74892 .78652 L
.74767 .7903 L
.74544 .79623 L
.74177 .80594 L
Mistroke
.7383 .81566 L
.73796 .81672 L
.73466 .82537 L
.73098 .83508 L
.72824 .84286 L
.72751 .84479 L
.72376 .85451 L
.7201 .86422 L
.71853 .86873 L
.71652 .87393 L
.71274 .88364 L
.70915 .89336 L
.70882 .89433 L
.70539 .90307 L
.70161 .91278 L
.69911 .91965 L
.69798 .92249 L
.69413 .93221 L
.69038 .94192 L
.68939 .94469 L
.68662 .95163 L
.68274 .96134 L
.67968 .96945 L
.67904 .97106 L
.6751 .98077 L
Mfstroke
.2 g
.98077 .10607 m
.98061 .10664 L
.97788 .11636 L
.97504 .12607 L
.97196 .13578 L
.97106 .1384 L
.96844 .14549 L
.96396 .15521 L
.96307 .16492 L
.96134 .17053 L
.95987 .17463 L
.95575 .18434 L
.95422 .19406 L
.95163 .20247 L
.95117 .20377 L
.94731 .21348 L
.94532 .22319 L
.94231 .23291 L
.94192 .23415 L
.93868 .24262 L
.93635 .25233 L
.93333 .26204 L
.93221 .26562 L
.9299 .27176 L
.92543 .28147 L
.92429 .29118 L
.92249 .29687 L
.92101 .30089 L
.91678 .31061 L
.91519 .32032 L
.91278 .32791 L
.912 .33003 L
.90795 .33974 L
.90602 .34946 L
.90307 .35872 L
.90291 .35917 L
.89897 .36888 L
.89679 .37859 L
.89368 .38831 L
.89336 .38928 L
.88987 .39802 L
.88749 .40773 L
.88436 .41744 L
.88364 .41961 L
.88066 .42716 L
.87812 .43687 L
.87497 .44658 L
.87393 .44972 L
.87134 .45629 L
.86656 .46601 L
.86551 .47572 L
.86422 .47959 L
.86192 .48543 L
.85721 .49514 L
.85597 .50486 L
.85451 .50924 L
.8524 .51457 L
.84772 .52428 L
.84636 .53399 L
.84479 .53865 L
.84279 .54371 L
.8381 .55342 L
.83668 .56313 L
.83508 .56782 L
.83307 .57284 L
.82834 .58256 L
.82691 .59227 L
.82537 .59676 L
.82325 .60198 L
.81844 .61169 L
.81706 .62141 L
.81566 .62545 L
.81333 .63112 L
.80838 .64083 L
.80712 .65054 L
.80594 .65391 L
.80329 .66026 L
.80046 .66997 L
.7971 .67968 L
.79623 .68212 L
.79312 .68939 L
.79038 .69911 L
.78698 .70882 L
.78652 .7101 L
.78281 .71853 L
.7802 .72824 L
.77681 .73784 L
.77676 .73796 L
.77234 .74767 L
.76993 .75738 L
.76709 .76529 L
.76635 .76709 L
.76167 .77681 L
.75955 .78652 L
.75738 .79249 L
.75579 .79623 L
.75075 .80594 L
.74907 .81566 L
.74767 .81945 L
.74505 .82537 L
.74204 .83508 L
.73848 .84479 L
.73796 .84618 L
.73409 .85451 L
.73138 .86422 L
.72824 .87266 L
.7277 .87393 L
.72282 .88364 L
.7206 .89336 L
.71853 .89883 L
.71663 .90307 L
.71336 .91278 L
.7097 .92249 L
.70882 .92477 L
.70528 .93221 L
.70239 .94192 L
.69911 .9505 L
.69861 .95163 L
.69349 .96134 L
.69128 .97106 L
.68939 .97599 L
.68709 .98077 L
.98077 .98077 L
F
0 g
.98077 .10607 m
.98061 .10664 L
.97788 .11636 L
.97504 .12607 L
.97196 .13578 L
.97106 .1384 L
.96844 .14549 L
.96396 .15521 L
.96307 .16492 L
.96134 .17053 L
.95987 .17463 L
.95575 .18434 L
.95422 .19406 L
.95163 .20247 L
.95117 .20377 L
.94731 .21348 L
.94532 .22319 L
.94231 .23291 L
.94192 .23415 L
.93868 .24262 L
.93635 .25233 L
.93333 .26204 L
.93221 .26562 L
.9299 .27176 L
.92543 .28147 L
.92429 .29118 L
.92249 .29687 L
.92101 .30089 L
.91678 .31061 L
.91519 .32032 L
.91278 .32791 L
.912 .33003 L
.90795 .33974 L
.90602 .34946 L
.90307 .35872 L
.90291 .35917 L
.89897 .36888 L
.89679 .37859 L
.89368 .38831 L
.89336 .38928 L
.88987 .39802 L
.88749 .40773 L
.88436 .41744 L
.88364 .41961 L
.88066 .42716 L
.87812 .43687 L
.87497 .44658 L
.87393 .44972 L
.87134 .45629 L
.86656 .46601 L
Mistroke
.86551 .47572 L
.86422 .47959 L
.86192 .48543 L
.85721 .49514 L
.85597 .50486 L
.85451 .50924 L
.8524 .51457 L
.84772 .52428 L
.84636 .53399 L
.84479 .53865 L
.84279 .54371 L
.8381 .55342 L
.83668 .56313 L
.83508 .56782 L
.83307 .57284 L
.82834 .58256 L
.82691 .59227 L
.82537 .59676 L
.82325 .60198 L
.81844 .61169 L
.81706 .62141 L
.81566 .62545 L
.81333 .63112 L
.80838 .64083 L
.80712 .65054 L
.80594 .65391 L
.80329 .66026 L
.80046 .66997 L
.7971 .67968 L
.79623 .68212 L
.79312 .68939 L
.79038 .69911 L
.78698 .70882 L
.78652 .7101 L
.78281 .71853 L
.7802 .72824 L
.77681 .73784 L
.77676 .73796 L
.77234 .74767 L
.76993 .75738 L
.76709 .76529 L
.76635 .76709 L
.76167 .77681 L
.75955 .78652 L
.75738 .79249 L
.75579 .79623 L
.75075 .80594 L
.74907 .81566 L
.74767 .81945 L
.74505 .82537 L
Mistroke
.74204 .83508 L
.73848 .84479 L
.73796 .84618 L
.73409 .85451 L
.73138 .86422 L
.72824 .87266 L
.7277 .87393 L
.72282 .88364 L
.7206 .89336 L
.71853 .89883 L
.71663 .90307 L
.71336 .91278 L
.7097 .92249 L
.70882 .92477 L
.70528 .93221 L
.70239 .94192 L
.69911 .9505 L
.69861 .95163 L
.69349 .96134 L
.69128 .97106 L
.68939 .97599 L
.68709 .98077 L
Mfstroke
.3 g
.98077 .19899 m
.97936 .20377 L
.97642 .21348 L
.97342 .22319 L
.97106 .23084 L
.97041 .23291 L
.96741 .24262 L
.9654 .25233 L
.96149 .26204 L
.96134 .26244 L
.95844 .27176 L
.95679 .28147 L
.95261 .29118 L
.95163 .29384 L
.94941 .30089 L
.94818 .31061 L
.9437 .32032 L
.94192 .32501 L
.94032 .33003 L
.93726 .33974 L
.93474 .34946 L
.93221 .35593 L
.93116 .35917 L
.92808 .36888 L
.92572 .37859 L
.92249 .38661 L
.92194 .38831 L
.91883 .39802 L
.91663 .40773 L
.91278 .41704 L
.91265 .41744 L
.90951 .42716 L
.90747 .43687 L
.90332 .44658 L
.90307 .44725 L
.90012 .45629 L
.89821 .46601 L
.89393 .47572 L
.89336 .47722 L
.89065 .48543 L
.88884 .49514 L
.88446 .50486 L
.88364 .50694 L
.88111 .51457 L
.87936 .52428 L
.87489 .53399 L
.87393 .53642 L
.87149 .54371 L
.86976 .55342 L
.86522 .56313 L
.86422 .56564 L
.86178 .57284 L
.86001 .58256 L
.85545 .59227 L
.85451 .59461 L
.85199 .60198 L
.85013 .61169 L
.84557 .62141 L
.84479 .62333 L
.84211 .63112 L
.84011 .64083 L
.83558 .65054 L
.83508 .65178 L
.83214 .66026 L
.82995 .66997 L
.82549 .67968 L
.82537 .67997 L
.82208 .68939 L
.81967 .69911 L
.81566 .70792 L
.81533 .70882 L
.81191 .71853 L
.80926 .72824 L
.80594 .73562 L
.8051 .73796 L
.80164 .74767 L
.79874 .75738 L
.79623 .76303 L
.79475 .76709 L
.79127 .77681 L
.78811 .78652 L
.78652 .79015 L
.7843 .79623 L
.78232 .80594 L
.77738 .81566 L
.77681 .81699 L
.77373 .82537 L
.77121 .83508 L
.76709 .84358 L
.76663 .84479 L
.76303 .85451 L
.76004 .86422 L
.75738 .8699 L
.75585 .87393 L
.75222 .88364 L
.74882 .89336 L
.74767 .8959 L
.74494 .90307 L
.74248 .91278 L
.73796 .92161 L
.73761 .92249 L
.73389 .93221 L
.73075 .94192 L
.72824 .94708 L
.72645 .95163 L
.72456 .96134 L
.71905 .97106 L
.71853 .9721 L
.71515 .98077 L
.98077 .98077 L
F
0 g
.98077 .19899 m
.97936 .20377 L
.97642 .21348 L
.97342 .22319 L
.97106 .23084 L
.97041 .23291 L
.96741 .24262 L
.9654 .25233 L
.96149 .26204 L
.96134 .26244 L
.95844 .27176 L
.95679 .28147 L
.95261 .29118 L
.95163 .29384 L
.94941 .30089 L
.94818 .31061 L
.9437 .32032 L
.94192 .32501 L
.94032 .33003 L
.93726 .33974 L
.93474 .34946 L
.93221 .35593 L
.93116 .35917 L
.92808 .36888 L
.92572 .37859 L
.92249 .38661 L
.92194 .38831 L
.91883 .39802 L
.91663 .40773 L
.91278 .41704 L
.91265 .41744 L
.90951 .42716 L
.90747 .43687 L
.90332 .44658 L
.90307 .44725 L
.90012 .45629 L
.89821 .46601 L
.89393 .47572 L
.89336 .47722 L
.89065 .48543 L
.88884 .49514 L
.88446 .50486 L
.88364 .50694 L
.88111 .51457 L
.87936 .52428 L
.87489 .53399 L
.87393 .53642 L
.87149 .54371 L
.86976 .55342 L
.86522 .56313 L
Mistroke
.86422 .56564 L
.86178 .57284 L
.86001 .58256 L
.85545 .59227 L
.85451 .59461 L
.85199 .60198 L
.85013 .61169 L
.84557 .62141 L
.84479 .62333 L
.84211 .63112 L
.84011 .64083 L
.83558 .65054 L
.83508 .65178 L
.83214 .66026 L
.82995 .66997 L
.82549 .67968 L
.82537 .67997 L
.82208 .68939 L
.81967 .69911 L
.81566 .70792 L
.81533 .70882 L
.81191 .71853 L
.80926 .72824 L
.80594 .73562 L
.8051 .73796 L
.80164 .74767 L
.79874 .75738 L
.79623 .76303 L
.79475 .76709 L
.79127 .77681 L
.78811 .78652 L
.78652 .79015 L
.7843 .79623 L
.78232 .80594 L
.77738 .81566 L
.77681 .81699 L
.77373 .82537 L
.77121 .83508 L
.76709 .84358 L
.76663 .84479 L
.76303 .85451 L
.76004 .86422 L
.75738 .8699 L
.75585 .87393 L
.75222 .88364 L
.74882 .89336 L
.74767 .8959 L
.74494 .90307 L
.74248 .91278 L
.73796 .92161 L
Mistroke
.73761 .92249 L
.73389 .93221 L
.73075 .94192 L
.72824 .94708 L
.72645 .95163 L
.72456 .96134 L
.71905 .97106 L
.71853 .9721 L
.71515 .98077 L
Mfstroke
.4 g
.98077 .22334 m
.97792 .23291 L
.97496 .24262 L
.97155 .25233 L
.97106 .25533 L
.96933 .26204 L
.96629 .27176 L
.96314 .28147 L
.96134 .2871 L
.96035 .29118 L
.95739 .30089 L
.95422 .31061 L
.95163 .31864 L
.95125 .32032 L
.94841 .33003 L
.94524 .33974 L
.94208 .34946 L
.94192 .34994 L
.93936 .35917 L
.93619 .36888 L
.933 .37859 L
.93221 .38102 L
.93022 .38831 L
.92708 .39802 L
.92385 .40773 L
.92249 .41187 L
.921 .41744 L
.91789 .42716 L
.91464 .43687 L
.91278 .44248 L
.91171 .44658 L
.90863 .45629 L
.90536 .46601 L
.90307 .47285 L
.90233 .47572 L
.89929 .48543 L
.896 .49514 L
.89336 .50299 L
.89288 .50486 L
.88987 .51457 L
.88657 .52428 L
.88364 .53289 L
.88336 .53399 L
.88038 .54371 L
.87706 .55342 L
.87393 .56254 L
.87378 .56313 L
.8708 .57284 L
.86746 .58256 L
.86422 .59195 L
.86414 .59227 L
.86115 .60198 L
.85779 .61169 L
.85451 .62112 L
.85443 .62141 L
.85141 .63112 L
.84802 .64083 L
.84479 .65004 L
.84466 .65054 L
.84159 .66026 L
.83817 .66997 L
.83508 .67871 L
.83482 .67968 L
.83168 .68939 L
.82823 .69911 L
.82537 .70712 L
.82489 .70882 L
.82167 .71853 L
.81818 .72824 L
.81566 .73529 L
.81487 .73796 L
.81157 .74767 L
.80805 .75738 L
.80594 .76319 L
.80476 .76709 L
.80136 .77681 L
.7978 .78652 L
.79623 .79083 L
.79453 .79623 L
.79105 .80594 L
.78746 .81566 L
.78652 .81821 L
.78418 .82537 L
.78063 .83508 L
.777 .84479 L
.77681 .84533 L
.77371 .85451 L
.77009 .86422 L
.76709 .87218 L
.76655 .87393 L
.76311 .88364 L
.75943 .89336 L
.75738 .89876 L
.75597 .90307 L
.75238 .91278 L
.74865 .92249 L
.74767 .92506 L
.74521 .93221 L
.74151 .94192 L
.73796 .95109 L
.73778 .95163 L
.73429 .96134 L
.7305 .97106 L
.72824 .97681 L
.7269 .98077 L
.98077 .98077 L
F
0 g
.98077 .22334 m
.97792 .23291 L
.97496 .24262 L
.97155 .25233 L
.97106 .25533 L
.96933 .26204 L
.96629 .27176 L
.96314 .28147 L
.96134 .2871 L
.96035 .29118 L
.95739 .30089 L
.95422 .31061 L
.95163 .31864 L
.95125 .32032 L
.94841 .33003 L
.94524 .33974 L
.94208 .34946 L
.94192 .34994 L
.93936 .35917 L
.93619 .36888 L
.933 .37859 L
.93221 .38102 L
.93022 .38831 L
.92708 .39802 L
.92385 .40773 L
.92249 .41187 L
.921 .41744 L
.91789 .42716 L
.91464 .43687 L
.91278 .44248 L
.91171 .44658 L
.90863 .45629 L
.90536 .46601 L
.90307 .47285 L
.90233 .47572 L
.89929 .48543 L
.896 .49514 L
.89336 .50299 L
.89288 .50486 L
.88987 .51457 L
.88657 .52428 L
.88364 .53289 L
.88336 .53399 L
.88038 .54371 L
.87706 .55342 L
.87393 .56254 L
.87378 .56313 L
.8708 .57284 L
.86746 .58256 L
.86422 .59195 L
Mistroke
.86414 .59227 L
.86115 .60198 L
.85779 .61169 L
.85451 .62112 L
.85443 .62141 L
.85141 .63112 L
.84802 .64083 L
.84479 .65004 L
.84466 .65054 L
.84159 .66026 L
.83817 .66997 L
.83508 .67871 L
.83482 .67968 L
.83168 .68939 L
.82823 .69911 L
.82537 .70712 L
.82489 .70882 L
.82167 .71853 L
.81818 .72824 L
.81566 .73529 L
.81487 .73796 L
.81157 .74767 L
.80805 .75738 L
.80594 .76319 L
.80476 .76709 L
.80136 .77681 L
.7978 .78652 L
.79623 .79083 L
.79453 .79623 L
.79105 .80594 L
.78746 .81566 L
.78652 .81821 L
.78418 .82537 L
.78063 .83508 L
.777 .84479 L
.77681 .84533 L
.77371 .85451 L
.77009 .86422 L
.76709 .87218 L
.76655 .87393 L
.76311 .88364 L
.75943 .89336 L
.75738 .89876 L
.75597 .90307 L
.75238 .91278 L
.74865 .92249 L
.74767 .92506 L
.74521 .93221 L
.74151 .94192 L
.73796 .95109 L
Mistroke
.73778 .95163 L
.73429 .96134 L
.7305 .97106 L
.72824 .97681 L
.7269 .98077 L
Mfstroke
.5 g
.98077 .24357 m
.9761 .25233 L
.97445 .26204 L
.97213 .27176 L
.97106 .27564 L
.96935 .28147 L
.96638 .29118 L
.96337 .30089 L
.96134 .30749 L
.96043 .31061 L
.95748 .32032 L
.95445 .33003 L
.95163 .3391 L
.95145 .33974 L
.94851 .34946 L
.94546 .35917 L
.94242 .36888 L
.94192 .37049 L
.93947 .37859 L
.93642 .38831 L
.93335 .39802 L
.93221 .40166 L
.93037 .40773 L
.92731 .41744 L
.92421 .42716 L
.92249 .43259 L
.9212 .43687 L
.91813 .44658 L
.91501 .45629 L
.91278 .46329 L
.91195 .46601 L
.90889 .47572 L
.90575 .48543 L
.90307 .49375 L
.90264 .49514 L
.89957 .50486 L
.89641 .51457 L
.89336 .52398 L
.89326 .52428 L
.89018 .53399 L
.887 .54371 L
.88382 .55342 L
.88364 .55397 L
.88072 .56313 L
.87752 .57284 L
.87431 .58256 L
.87393 .58372 L
.87119 .59227 L
.86796 .60198 L
.86473 .61169 L
.86422 .61323 L
.86157 .62141 L
.85832 .63112 L
.85506 .64083 L
.85451 .6425 L
.85188 .65054 L
.8486 .66026 L
.84532 .66997 L
.84479 .67152 L
.8421 .67968 L
.8388 .68939 L
.83548 .69911 L
.83508 .70029 L
.83224 .70882 L
.82891 .71853 L
.82556 .72824 L
.82537 .72882 L
.82229 .73796 L
.81892 .74767 L
.81566 .75709 L
.81556 .75738 L
.81225 .76709 L
.80885 .77681 L
.80594 .7851 L
.80547 .78652 L
.80211 .79623 L
.79867 .80594 L
.79623 .81286 L
.79528 .81566 L
.79187 .82537 L
.7884 .83508 L
.78652 .84036 L
.78498 .84479 L
.78152 .85451 L
.77802 .86422 L
.77681 .8676 L
.77458 .87393 L
.77107 .88364 L
.76753 .89336 L
.76709 .89457 L
.76406 .90307 L
.7605 .91278 L
.75738 .92128 L
.75695 .92249 L
.75342 .93221 L
.74982 .94192 L
.74767 .94771 L
.74625 .95163 L
.74265 .96134 L
.73901 .97106 L
.73796 .97387 L
.73542 .98077 L
.98077 .98077 L
F
0 g
.98077 .24357 m
.9761 .25233 L
.97445 .26204 L
.97213 .27176 L
.97106 .27564 L
.96935 .28147 L
.96638 .29118 L
.96337 .30089 L
.96134 .30749 L
.96043 .31061 L
.95748 .32032 L
.95445 .33003 L
.95163 .3391 L
.95145 .33974 L
.94851 .34946 L
.94546 .35917 L
.94242 .36888 L
.94192 .37049 L
.93947 .37859 L
.93642 .38831 L
.93335 .39802 L
.93221 .40166 L
.93037 .40773 L
.92731 .41744 L
.92421 .42716 L
.92249 .43259 L
.9212 .43687 L
.91813 .44658 L
.91501 .45629 L
.91278 .46329 L
.91195 .46601 L
.90889 .47572 L
.90575 .48543 L
.90307 .49375 L
.90264 .49514 L
.89957 .50486 L
.89641 .51457 L
.89336 .52398 L
.89326 .52428 L
.89018 .53399 L
.887 .54371 L
.88382 .55342 L
.88364 .55397 L
.88072 .56313 L
.87752 .57284 L
.87431 .58256 L
.87393 .58372 L
.87119 .59227 L
.86796 .60198 L
.86473 .61169 L
Mistroke
.86422 .61323 L
.86157 .62141 L
.85832 .63112 L
.85506 .64083 L
.85451 .6425 L
.85188 .65054 L
.8486 .66026 L
.84532 .66997 L
.84479 .67152 L
.8421 .67968 L
.8388 .68939 L
.83548 .69911 L
.83508 .70029 L
.83224 .70882 L
.82891 .71853 L
.82556 .72824 L
.82537 .72882 L
.82229 .73796 L
.81892 .74767 L
.81566 .75709 L
.81556 .75738 L
.81225 .76709 L
.80885 .77681 L
.80594 .7851 L
.80547 .78652 L
.80211 .79623 L
.79867 .80594 L
.79623 .81286 L
.79528 .81566 L
.79187 .82537 L
.7884 .83508 L
.78652 .84036 L
.78498 .84479 L
.78152 .85451 L
.77802 .86422 L
.77681 .8676 L
.77458 .87393 L
.77107 .88364 L
.76753 .89336 L
.76709 .89457 L
.76406 .90307 L
.7605 .91278 L
.75738 .92128 L
.75695 .92249 L
.75342 .93221 L
.74982 .94192 L
.74767 .94771 L
.74625 .95163 L
.74265 .96134 L
.73901 .97106 L
Mistroke
.73796 .97387 L
.73542 .98077 L
Mfstroke
.6 g
.98077 .26284 m
.97775 .27176 L
.97501 .28147 L
.97219 .29118 L
.97106 .29498 L
.96926 .30089 L
.96627 .31061 L
.96329 .32032 L
.96134 .32689 L
.96039 .33003 L
.95739 .33974 L
.95437 .34946 L
.95163 .35858 L
.95145 .35917 L
.94844 .36888 L
.94541 .37859 L
.94243 .38831 L
.94192 .39004 L
.93944 .39802 L
.93638 .40773 L
.93336 .41744 L
.93221 .42128 L
.93037 .42716 L
.92729 .43687 L
.92423 .44658 L
.92249 .45228 L
.92123 .45629 L
.91814 .46601 L
.91505 .47572 L
.91278 .48306 L
.91203 .48543 L
.90892 .49514 L
.9058 .50486 L
.90307 .5136 L
.90276 .51457 L
.89964 .52428 L
.89649 .53399 L
.89342 .54371 L
.89336 .54391 L
.89028 .55342 L
.88711 .56313 L
.884 .57284 L
.88364 .57398 L
.88085 .58256 L
.87765 .59227 L
.87451 .60198 L
.87393 .60381 L
.87134 .61169 L
.86812 .62141 L
.86495 .63112 L
.86422 .6334 L
.86176 .64083 L
.85852 .65054 L
.85531 .66026 L
.85451 .66275 L
.8521 .66997 L
.84883 .67968 L
.8456 .68939 L
.84479 .69186 L
.84236 .69911 L
.83906 .70882 L
.8358 .71853 L
.83508 .72072 L
.83253 .72824 L
.8292 .73796 L
.82592 .74767 L
.82537 .74933 L
.82261 .75738 L
.81926 .76709 L
.81595 .77681 L
.81566 .7777 L
.81261 .78652 L
.80922 .79623 L
.80594 .80581 L
.8059 .80594 L
.80251 .81566 L
.7991 .82537 L
.79623 .83366 L
.79574 .83508 L
.79231 .84479 L
.78887 .85451 L
.78652 .86126 L
.78547 .86422 L
.78201 .87393 L
.77854 .88364 L
.77681 .8886 L
.77511 .89336 L
.7716 .90307 L
.76812 .91278 L
.76709 .91568 L
.76463 .92249 L
.76109 .93221 L
.75758 .94192 L
.75738 .94249 L
.75404 .95163 L
.75046 .96134 L
.74767 .96904 L
.74693 .97106 L
.74333 .98077 L
.98077 .98077 L
F
0 g
.98077 .26284 m
.97775 .27176 L
.97501 .28147 L
.97219 .29118 L
.97106 .29498 L
.96926 .30089 L
.96627 .31061 L
.96329 .32032 L
.96134 .32689 L
.96039 .33003 L
.95739 .33974 L
.95437 .34946 L
.95163 .35858 L
.95145 .35917 L
.94844 .36888 L
.94541 .37859 L
.94243 .38831 L
.94192 .39004 L
.93944 .39802 L
.93638 .40773 L
.93336 .41744 L
.93221 .42128 L
.93037 .42716 L
.92729 .43687 L
.92423 .44658 L
.92249 .45228 L
.92123 .45629 L
.91814 .46601 L
.91505 .47572 L
.91278 .48306 L
.91203 .48543 L
.90892 .49514 L
.9058 .50486 L
.90307 .5136 L
.90276 .51457 L
.89964 .52428 L
.89649 .53399 L
.89342 .54371 L
.89336 .54391 L
.89028 .55342 L
.88711 .56313 L
.884 .57284 L
.88364 .57398 L
.88085 .58256 L
.87765 .59227 L
.87451 .60198 L
.87393 .60381 L
.87134 .61169 L
.86812 .62141 L
.86495 .63112 L
Mistroke
.86422 .6334 L
.86176 .64083 L
.85852 .65054 L
.85531 .66026 L
.85451 .66275 L
.8521 .66997 L
.84883 .67968 L
.8456 .68939 L
.84479 .69186 L
.84236 .69911 L
.83906 .70882 L
.8358 .71853 L
.83508 .72072 L
.83253 .72824 L
.8292 .73796 L
.82592 .74767 L
.82537 .74933 L
.82261 .75738 L
.81926 .76709 L
.81595 .77681 L
.81566 .7777 L
.81261 .78652 L
.80922 .79623 L
.80594 .80581 L
.8059 .80594 L
.80251 .81566 L
.7991 .82537 L
.79623 .83366 L
.79574 .83508 L
.79231 .84479 L
.78887 .85451 L
.78652 .86126 L
.78547 .86422 L
.78201 .87393 L
.77854 .88364 L
.77681 .8886 L
.77511 .89336 L
.7716 .90307 L
.76812 .91278 L
.76709 .91568 L
.76463 .92249 L
.76109 .93221 L
.75758 .94192 L
.75738 .94249 L
.75404 .95163 L
.75046 .96134 L
.74767 .96904 L
.74693 .97106 L
.74333 .98077 L
Mfstroke
.7 g
.98077 .28307 m
.97831 .29118 L
.97544 .30089 L
.97251 .31061 L
.97106 .31529 L
.96948 .32032 L
.96638 .33003 L
.96334 .33974 L
.96134 .34728 L
.96066 .34946 L
.95756 .35917 L
.95446 .36888 L
.95173 .37859 L
.95163 .37905 L
.94867 .38831 L
.94553 .39802 L
.94262 .40773 L
.94192 .41059 L
.93972 .41744 L
.93656 .42716 L
.93353 .43687 L
.93221 .44191 L
.9307 .44658 L
.92753 .45629 L
.92442 .46601 L
.92249 .473 L
.92162 .47572 L
.91843 .48543 L
.91527 .49514 L
.91278 .50387 L
.91246 .50486 L
.90926 .51457 L
.90606 .52428 L
.90319 .53399 L
.90307 .5345 L
.90002 .54371 L
.89679 .55342 L
.89381 .56313 L
.89336 .5649 L
.89071 .57284 L
.88745 .58256 L
.88439 .59227 L
.88364 .59506 L
.88133 .60198 L
.87804 .61169 L
.87492 .62141 L
.87393 .62499 L
.87187 .63112 L
.86856 .64083 L
.86539 .65054 L
.86422 .65468 L
.86233 .66026 L
.859 .66997 L
.85579 .67968 L
.85451 .68413 L
.85271 .68939 L
.84935 .69911 L
.84612 .70882 L
.84479 .71334 L
.84301 .71853 L
.83963 .72824 L
.83637 .73796 L
.83508 .74231 L
.83322 .74767 L
.82981 .75738 L
.82654 .76709 L
.82537 .77103 L
.82334 .77681 L
.81991 .78652 L
.81663 .79623 L
.81566 .7995 L
.81338 .80594 L
.80992 .81566 L
.80665 .82537 L
.80594 .82772 L
.80332 .83508 L
.79984 .84479 L
.79658 .85451 L
.79623 .85569 L
.79316 .86422 L
.78966 .87393 L
.78652 .88341 L
.78644 .88364 L
.7829 .89336 L
.77939 .90307 L
.77681 .91087 L
.77611 .91278 L
.77254 .92249 L
.76903 .93221 L
.76709 .93807 L
.76568 .94192 L
.76207 .95163 L
.75858 .96134 L
.75738 .96501 L
.75513 .97106 L
.75149 .98077 L
.98077 .98077 L
F
0 g
.98077 .28307 m
.97831 .29118 L
.97544 .30089 L
.97251 .31061 L
.97106 .31529 L
.96948 .32032 L
.96638 .33003 L
.96334 .33974 L
.96134 .34728 L
.96066 .34946 L
.95756 .35917 L
.95446 .36888 L
.95173 .37859 L
.95163 .37905 L
.94867 .38831 L
.94553 .39802 L
.94262 .40773 L
.94192 .41059 L
.93972 .41744 L
.93656 .42716 L
.93353 .43687 L
.93221 .44191 L
.9307 .44658 L
.92753 .45629 L
.92442 .46601 L
.92249 .473 L
.92162 .47572 L
.91843 .48543 L
.91527 .49514 L
.91278 .50387 L
.91246 .50486 L
.90926 .51457 L
.90606 .52428 L
.90319 .53399 L
.90307 .5345 L
.90002 .54371 L
.89679 .55342 L
.89381 .56313 L
.89336 .5649 L
.89071 .57284 L
.88745 .58256 L
.88439 .59227 L
.88364 .59506 L
.88133 .60198 L
.87804 .61169 L
.87492 .62141 L
.87393 .62499 L
.87187 .63112 L
.86856 .64083 L
.86539 .65054 L
Mistroke
.86422 .65468 L
.86233 .66026 L
.859 .66997 L
.85579 .67968 L
.85451 .68413 L
.85271 .68939 L
.84935 .69911 L
.84612 .70882 L
.84479 .71334 L
.84301 .71853 L
.83963 .72824 L
.83637 .73796 L
.83508 .74231 L
.83322 .74767 L
.82981 .75738 L
.82654 .76709 L
.82537 .77103 L
.82334 .77681 L
.81991 .78652 L
.81663 .79623 L
.81566 .7995 L
.81338 .80594 L
.80992 .81566 L
.80665 .82537 L
.80594 .82772 L
.80332 .83508 L
.79984 .84479 L
.79658 .85451 L
.79623 .85569 L
.79316 .86422 L
.78966 .87393 L
.78652 .88341 L
.78644 .88364 L
.7829 .89336 L
.77939 .90307 L
.77681 .91087 L
.77611 .91278 L
.77254 .92249 L
.76903 .93221 L
.76709 .93807 L
.76568 .94192 L
.76207 .95163 L
.75858 .96134 L
.75738 .96501 L
.75513 .97106 L
.75149 .98077 L
Mfstroke
.8 g
.98077 .30743 m
.97989 .31061 L
.97714 .32032 L
.97425 .33003 L
.97108 .33974 L
.97106 .33981 L
.96738 .34946 L
.96524 .35917 L
.96228 .36888 L
.96134 .37192 L
.95887 .37859 L
.95443 .38831 L
.95343 .39802 L
.95163 .40383 L
.95022 .40773 L
.9461 .41744 L
.94452 .42716 L
.94192 .43555 L
.94145 .43687 L
.93755 .44658 L
.93555 .45629 L
.93253 .46601 L
.93221 .46702 L
.92884 .47572 L
.92652 .48543 L
.92348 .49514 L
.92249 .49825 L
.91998 .50486 L
.91541 .51457 L
.91438 .52428 L
.91278 .52928 L
.91101 .53399 L
.90666 .54371 L
.9052 .55342 L
.90307 .56008 L
.90194 .56313 L
.89775 .57284 L
.89597 .58256 L
.89336 .59067 L
.89276 .59227 L
.88869 .60198 L
.88666 .61169 L
.88364 .62102 L
.8835 .62141 L
.87951 .63112 L
.87729 .64083 L
.87413 .65054 L
.87393 .65112 L
.87021 .66026 L
.86784 .66997 L
.86466 .67968 L
.86422 .68099 L
.8608 .68939 L
.85833 .69911 L
.85512 .70882 L
.85451 .71063 L
.85129 .71853 L
.84873 .72824 L
.8455 .73796 L
.84479 .74004 L
.84167 .74767 L
.83906 .75738 L
.83581 .76709 L
.83508 .76921 L
.83194 .77681 L
.82932 .78652 L
.82603 .79623 L
.82537 .79815 L
.82211 .80594 L
.81949 .81566 L
.81617 .82537 L
.81566 .82685 L
.81216 .83508 L
.80957 .84479 L
.80623 .85451 L
.80594 .85531 L
.80209 .86422 L
.79957 .87393 L
.79623 .88354 L
.79619 .88364 L
.79187 .89336 L
.78948 .90307 L
.78652 .91149 L
.786 .91278 L
.7815 .92249 L
.77929 .93221 L
.77681 .9392 L
.77568 .94192 L
.77094 .95163 L
.76901 .96134 L
.76709 .96665 L
.76522 .97106 L
.76015 .98077 L
.98077 .98077 L
F
0 g
.98077 .30743 m
.97989 .31061 L
.97714 .32032 L
.97425 .33003 L
.97108 .33974 L
.97106 .33981 L
.96738 .34946 L
.96524 .35917 L
.96228 .36888 L
.96134 .37192 L
.95887 .37859 L
.95443 .38831 L
.95343 .39802 L
.95163 .40383 L
.95022 .40773 L
.9461 .41744 L
.94452 .42716 L
.94192 .43555 L
.94145 .43687 L
.93755 .44658 L
.93555 .45629 L
.93253 .46601 L
.93221 .46702 L
.92884 .47572 L
.92652 .48543 L
.92348 .49514 L
.92249 .49825 L
.91998 .50486 L
.91541 .51457 L
.91438 .52428 L
.91278 .52928 L
.91101 .53399 L
.90666 .54371 L
.9052 .55342 L
.90307 .56008 L
.90194 .56313 L
.89775 .57284 L
.89597 .58256 L
.89336 .59067 L
.89276 .59227 L
.88869 .60198 L
.88666 .61169 L
.88364 .62102 L
.8835 .62141 L
.87951 .63112 L
.87729 .64083 L
.87413 .65054 L
.87393 .65112 L
.87021 .66026 L
.86784 .66997 L
Mistroke
.86466 .67968 L
.86422 .68099 L
.8608 .68939 L
.85833 .69911 L
.85512 .70882 L
.85451 .71063 L
.85129 .71853 L
.84873 .72824 L
.8455 .73796 L
.84479 .74004 L
.84167 .74767 L
.83906 .75738 L
.83581 .76709 L
.83508 .76921 L
.83194 .77681 L
.82932 .78652 L
.82603 .79623 L
.82537 .79815 L
.82211 .80594 L
.81949 .81566 L
.81617 .82537 L
.81566 .82685 L
.81216 .83508 L
.80957 .84479 L
.80623 .85451 L
.80594 .85531 L
.80209 .86422 L
.79957 .87393 L
.79623 .88354 L
.79619 .88364 L
.79187 .89336 L
.78948 .90307 L
.78652 .91149 L
.786 .91278 L
.7815 .92249 L
.77929 .93221 L
.77681 .9392 L
.77568 .94192 L
.77094 .95163 L
.76901 .96134 L
.76709 .96665 L
.76522 .97106 L
.76015 .98077 L
Mfstroke
.7 g
.98077 .40036 m
.97859 .40773 L
.97563 .41744 L
.97262 .42716 L
.97106 .43223 L
.96961 .43687 L
.96661 .44658 L
.96427 .45629 L
.96134 .46384 L
.96066 .46601 L
.95764 .47572 L
.95557 .48543 L
.95166 .49514 L
.95163 .49521 L
.9486 .50486 L
.94685 .51457 L
.9427 .52428 L
.94192 .52638 L
.9395 .53399 L
.93809 .54371 L
.93369 .55342 L
.93221 .55731 L
.93034 .56313 L
.92929 .57284 L
.92462 .58256 L
.92249 .58801 L
.92111 .59227 L
.918 .60198 L
.91548 .61169 L
.91278 .61845 L
.91181 .62141 L
.90868 .63112 L
.90626 .64083 L
.90307 .64865 L
.90244 .65054 L
.89928 .66026 L
.89696 .66997 L
.89336 .67861 L
.893 .67968 L
.88981 .68939 L
.88756 .69911 L
.88364 .70832 L
.88348 .70882 L
.88026 .71853 L
.87804 .72824 L
.87393 .73779 L
.87387 .73796 L
.87063 .74767 L
.86842 .75738 L
.86422 .76701 L
.86419 .76709 L
.86092 .77681 L
.85866 .78652 L
.85451 .79598 L
.85442 .79623 L
.85112 .80594 L
.84879 .81566 L
.84479 .82471 L
.84456 .82537 L
.84123 .83508 L
.83878 .84479 L
.83508 .85318 L
.83461 .85451 L
.83125 .86422 L
.82865 .87393 L
.82537 .88139 L
.82457 .88364 L
.82118 .89336 L
.81839 .90307 L
.81566 .90933 L
.81442 .91278 L
.811 .92249 L
.80802 .93221 L
.80594 .937 L
.80418 .94192 L
.80261 .95163 L
.79754 .96134 L
.79623 .9644 L
.79382 .97106 L
.79177 .98077 L
.98077 .98077 L
F
0 g
.98077 .40036 m
.97859 .40773 L
.97563 .41744 L
.97262 .42716 L
.97106 .43223 L
.96961 .43687 L
.96661 .44658 L
.96427 .45629 L
.96134 .46384 L
.96066 .46601 L
.95764 .47572 L
.95557 .48543 L
.95166 .49514 L
.95163 .49521 L
.9486 .50486 L
.94685 .51457 L
.9427 .52428 L
.94192 .52638 L
.9395 .53399 L
.93809 .54371 L
.93369 .55342 L
.93221 .55731 L
.93034 .56313 L
.92929 .57284 L
.92462 .58256 L
.92249 .58801 L
.92111 .59227 L
.918 .60198 L
.91548 .61169 L
.91278 .61845 L
.91181 .62141 L
.90868 .63112 L
.90626 .64083 L
.90307 .64865 L
.90244 .65054 L
.89928 .66026 L
.89696 .66997 L
.89336 .67861 L
.893 .67968 L
.88981 .68939 L
.88756 .69911 L
.88364 .70832 L
.88348 .70882 L
.88026 .71853 L
.87804 .72824 L
.87393 .73779 L
.87387 .73796 L
.87063 .74767 L
.86842 .75738 L
.86422 .76701 L
Mistroke
.86419 .76709 L
.86092 .77681 L
.85866 .78652 L
.85451 .79598 L
.85442 .79623 L
.85112 .80594 L
.84879 .81566 L
.84479 .82471 L
.84456 .82537 L
.84123 .83508 L
.83878 .84479 L
.83508 .85318 L
.83461 .85451 L
.83125 .86422 L
.82865 .87393 L
.82537 .88139 L
.82457 .88364 L
.82118 .89336 L
.81839 .90307 L
.81566 .90933 L
.81442 .91278 L
.811 .92249 L
.80802 .93221 L
.80594 .937 L
.80418 .94192 L
.80261 .95163 L
.79754 .96134 L
.79623 .9644 L
.79382 .97106 L
.79177 .98077 L
Mfstroke
.6 g
.98077 .42473 m
.98005 .42716 L
.97714 .43687 L
.97417 .44658 L
.97114 .45629 L
.97106 .45672 L
.96856 .46601 L
.96546 .47572 L
.96232 .48543 L
.96134 .48848 L
.95961 .49514 L
.95655 .50486 L
.95339 .51457 L
.95163 .52002 L
.95057 .52428 L
.94758 .53399 L
.9444 .54371 L
.94192 .55133 L
.94142 .55342 L
.93854 .56313 L
.93534 .57284 L
.93221 .5824 L
.93217 .58256 L
.92941 .59227 L
.92622 .60198 L
.923 .61169 L
.92249 .61325 L
.92021 .62141 L
.91703 .63112 L
.91378 .64083 L
.91278 .64386 L
.91094 .65054 L
.90776 .66026 L
.90449 .66997 L
.90307 .67424 L
.90158 .67968 L
.89842 .68939 L
.89513 .69911 L
.89336 .70438 L
.89215 .70882 L
.889 .71853 L
.88569 .72824 L
.88364 .73427 L
.88265 .73796 L
.87951 .74767 L
.87617 .75738 L
.87393 .76393 L
.87307 .76709 L
.86993 .77681 L
.86657 .78652 L
.86422 .79334 L
.86343 .79623 L
.86027 .80594 L
.85689 .81566 L
.85451 .82251 L
.85371 .82537 L
.85053 .83508 L
.84711 .84479 L
.84479 .85143 L
.84392 .85451 L
.84069 .86422 L
.83726 .87393 L
.83508 .88009 L
.83405 .88364 L
.83077 .89336 L
.8273 .90307 L
.82537 .90851 L
.8241 .91278 L
.82076 .92249 L
.81726 .93221 L
.81566 .93667 L
.81405 .94192 L
.81064 .95163 L
.80711 .96134 L
.80594 .96457 L
.8039 .97106 L
.80042 .98077 L
.98077 .98077 L
F
0 g
.98077 .42473 m
.98005 .42716 L
.97714 .43687 L
.97417 .44658 L
.97114 .45629 L
.97106 .45672 L
.96856 .46601 L
.96546 .47572 L
.96232 .48543 L
.96134 .48848 L
.95961 .49514 L
.95655 .50486 L
.95339 .51457 L
.95163 .52002 L
.95057 .52428 L
.94758 .53399 L
.9444 .54371 L
.94192 .55133 L
.94142 .55342 L
.93854 .56313 L
.93534 .57284 L
.93221 .5824 L
.93217 .58256 L
.92941 .59227 L
.92622 .60198 L
.923 .61169 L
.92249 .61325 L
.92021 .62141 L
.91703 .63112 L
.91378 .64083 L
.91278 .64386 L
.91094 .65054 L
.90776 .66026 L
.90449 .66997 L
.90307 .67424 L
.90158 .67968 L
.89842 .68939 L
.89513 .69911 L
.89336 .70438 L
.89215 .70882 L
.889 .71853 L
.88569 .72824 L
.88364 .73427 L
.88265 .73796 L
.87951 .74767 L
.87617 .75738 L
.87393 .76393 L
.87307 .76709 L
.86993 .77681 L
.86657 .78652 L
Mistroke
.86422 .79334 L
.86343 .79623 L
.86027 .80594 L
.85689 .81566 L
.85451 .82251 L
.85371 .82537 L
.85053 .83508 L
.84711 .84479 L
.84479 .85143 L
.84392 .85451 L
.84069 .86422 L
.83726 .87393 L
.83508 .88009 L
.83405 .88364 L
.83077 .89336 L
.8273 .90307 L
.82537 .90851 L
.8241 .91278 L
.82076 .92249 L
.81726 .93221 L
.81566 .93667 L
.81405 .94192 L
.81064 .95163 L
.80711 .96134 L
.80594 .96457 L
.8039 .97106 L
.80042 .98077 L
Mfstroke
.5 g
.98077 .44496 m
.98029 .44658 L
.9757 .45629 L
.9739 .46601 L
.97143 .47572 L
.97106 .47703 L
.96857 .48543 L
.96558 .49514 L
.96257 .50486 L
.96134 .50887 L
.95966 .51457 L
.95667 .52428 L
.95364 .53399 L
.95163 .54049 L
.95068 .54371 L
.9477 .55342 L
.94465 .56313 L
.94192 .57188 L
.94164 .57284 L
.93867 .58256 L
.9356 .59227 L
.93254 .60198 L
.93221 .60304 L
.92956 .61169 L
.92649 .62141 L
.92339 .63112 L
.92249 .63397 L
.92039 .64083 L
.9173 .65054 L
.91419 .66026 L
.91278 .66467 L
.91115 .66997 L
.90806 .67968 L
.90491 .68939 L
.90307 .69514 L
.90184 .69911 L
.89874 .70882 L
.89557 .71853 L
.89336 .72537 L
.89246 .72824 L
.88934 .73796 L
.88616 .74767 L
.88364 .75536 L
.88301 .75738 L
.87988 .76709 L
.87667 .77681 L
.87393 .78511 L
.87349 .78652 L
.87034 .79623 L
.8671 .80594 L
.86422 .81462 L
.86389 .81566 L
.86072 .82537 L
.85746 .83508 L
.85451 .84389 L
.85422 .84479 L
.85102 .85451 L
.84773 .86422 L
.84479 .87291 L
.84446 .87393 L
.84123 .88364 L
.83792 .89336 L
.83508 .90168 L
.83463 .90307 L
.83136 .91278 L
.82802 .92249 L
.82537 .9302 L
.82471 .93221 L
.8214 .94192 L
.81803 .95163 L
.81566 .95847 L
.81469 .96134 L
.81135 .97106 L
.80794 .98077 L
.98077 .98077 L
F
0 g
.98077 .44496 m
.98029 .44658 L
.9757 .45629 L
.9739 .46601 L
.97143 .47572 L
.97106 .47703 L
.96857 .48543 L
.96558 .49514 L
.96257 .50486 L
.96134 .50887 L
.95966 .51457 L
.95667 .52428 L
.95364 .53399 L
.95163 .54049 L
.95068 .54371 L
.9477 .55342 L
.94465 .56313 L
.94192 .57188 L
.94164 .57284 L
.93867 .58256 L
.9356 .59227 L
.93254 .60198 L
.93221 .60304 L
.92956 .61169 L
.92649 .62141 L
.92339 .63112 L
.92249 .63397 L
.92039 .64083 L
.9173 .65054 L
.91419 .66026 L
.91278 .66467 L
.91115 .66997 L
.90806 .67968 L
.90491 .68939 L
.90307 .69514 L
.90184 .69911 L
.89874 .70882 L
.89557 .71853 L
.89336 .72537 L
.89246 .72824 L
.88934 .73796 L
.88616 .74767 L
.88364 .75536 L
.88301 .75738 L
.87988 .76709 L
.87667 .77681 L
.87393 .78511 L
.87349 .78652 L
.87034 .79623 L
.8671 .80594 L
Mistroke
.86422 .81462 L
.86389 .81566 L
.86072 .82537 L
.85746 .83508 L
.85451 .84389 L
.85422 .84479 L
.85102 .85451 L
.84773 .86422 L
.84479 .87291 L
.84446 .87393 L
.84123 .88364 L
.83792 .89336 L
.83508 .90168 L
.83463 .90307 L
.83136 .91278 L
.82802 .92249 L
.82537 .9302 L
.82471 .93221 L
.8214 .94192 L
.81803 .95163 L
.81566 .95847 L
.81469 .96134 L
.81135 .97106 L
.80794 .98077 L
Mfstroke
.4 g
.98077 .46423 m
.98005 .46601 L
.97702 .47572 L
.97427 .48543 L
.97142 .49514 L
.97106 .49636 L
.96847 .50486 L
.96547 .51457 L
.96252 .52428 L
.96134 .52828 L
.9596 .53399 L
.95658 .54371 L
.95359 .55342 L
.95163 .55996 L
.95066 .56313 L
.94764 .57284 L
.9446 .58256 L
.94192 .59143 L
.94166 .59227 L
.93863 .60198 L
.93557 .61169 L
.93258 .62141 L
.93221 .62266 L
.92955 .63112 L
.92647 .64083 L
.92344 .65054 L
.92249 .65367 L
.92042 .66026 L
.91732 .66997 L
.91424 .67968 L
.91278 .68444 L
.91121 .68939 L
.90809 .69911 L
.90499 .70882 L
.90307 .71498 L
.90194 .71853 L
.8988 .72824 L
.89566 .73796 L
.89336 .74529 L
.89259 .74767 L
.88944 .75738 L
.88627 .76709 L
.88364 .77536 L
.88318 .77681 L
.88 .78652 L
.87681 .79623 L
.87393 .80519 L
.87369 .80594 L
.87049 .81566 L
.86727 .82537 L
.86422 .83479 L
.86412 .83508 L
.8609 .84479 L
.85766 .85451 L
.85451 .86414 L
.85448 .86422 L
.85123 .87393 L
.84796 .88364 L
.84479 .89325 L
.84476 .89336 L
.84148 .90307 L
.83819 .91278 L
.83508 .92211 L
.83495 .92249 L
.83165 .93221 L
.82832 .94192 L
.82537 .95072 L
.82506 .95163 L
.82172 .96134 L
.81837 .97106 L
.81566 .97908 L
.81508 .98077 L
.98077 .98077 L
F
0 g
.98077 .46423 m
.98005 .46601 L
.97702 .47572 L
.97427 .48543 L
.97142 .49514 L
.97106 .49636 L
.96847 .50486 L
.96547 .51457 L
.96252 .52428 L
.96134 .52828 L
.9596 .53399 L
.95658 .54371 L
.95359 .55342 L
.95163 .55996 L
.95066 .56313 L
.94764 .57284 L
.9446 .58256 L
.94192 .59143 L
.94166 .59227 L
.93863 .60198 L
.93557 .61169 L
.93258 .62141 L
.93221 .62266 L
.92955 .63112 L
.92647 .64083 L
.92344 .65054 L
.92249 .65367 L
.92042 .66026 L
.91732 .66997 L
.91424 .67968 L
.91278 .68444 L
.91121 .68939 L
.90809 .69911 L
.90499 .70882 L
.90307 .71498 L
.90194 .71853 L
.8988 .72824 L
.89566 .73796 L
.89336 .74529 L
.89259 .74767 L
.88944 .75738 L
.88627 .76709 L
.88364 .77536 L
.88318 .77681 L
.88 .78652 L
.87681 .79623 L
.87393 .80519 L
.87369 .80594 L
.87049 .81566 L
.86727 .82537 L
Mistroke
.86422 .83479 L
.86412 .83508 L
.8609 .84479 L
.85766 .85451 L
.85451 .86414 L
.85448 .86422 L
.85123 .87393 L
.84796 .88364 L
.84479 .89325 L
.84476 .89336 L
.84148 .90307 L
.83819 .91278 L
.83508 .92211 L
.83495 .92249 L
.83165 .93221 L
.82832 .94192 L
.82537 .95072 L
.82506 .95163 L
.82172 .96134 L
.81837 .97106 L
.81566 .97908 L
.81508 .98077 L
Mfstroke
.3 g
.98077 .48446 m
.98046 .48543 L
.97755 .49514 L
.97467 .50486 L
.97171 .51457 L
.97106 .51667 L
.96866 .52428 L
.96555 .53399 L
.96259 .54371 L
.96134 .54866 L
.95984 .55342 L
.95672 .56313 L
.95367 .57284 L
.95163 .58043 L
.95096 .58256 L
.94784 .59227 L
.94472 .60198 L
.94198 .61169 L
.94192 .61198 L
.93888 .62141 L
.93573 .63112 L
.93282 .64083 L
.93221 .6433 L
.92986 .65054 L
.92668 .66026 L
.92366 .66997 L
.92249 .67439 L
.92078 .67968 L
.91758 .68939 L
.91447 .69911 L
.91278 .70525 L
.91162 .70882 L
.9084 .71853 L
.90524 .72824 L
.90307 .73588 L
.90239 .73796 L
.89916 .74767 L
.89595 .75738 L
.89336 .76628 L
.89309 .76709 L
.88984 .77681 L
.8866 .78652 L
.8837 .79623 L
.88364 .79645 L
.88045 .80594 L
.87718 .81566 L
.87419 .82537 L
.87393 .82638 L
.87099 .83508 L
.86769 .84479 L
.86464 .85451 L
.86422 .85607 L
.86144 .86422 L
.85812 .87393 L
.85502 .88364 L
.85451 .88552 L
.85182 .89336 L
.84847 .90307 L
.84534 .91278 L
.84479 .91473 L
.84211 .92249 L
.83874 .93221 L
.83558 .94192 L
.83508 .94369 L
.83232 .95163 L
.82892 .96134 L
.82576 .97106 L
.82537 .97242 L
.82243 .98077 L
.98077 .98077 L
F
0 g
.98077 .48446 m
.98046 .48543 L
.97755 .49514 L
.97467 .50486 L
.97171 .51457 L
.97106 .51667 L
.96866 .52428 L
.96555 .53399 L
.96259 .54371 L
.96134 .54866 L
.95984 .55342 L
.95672 .56313 L
.95367 .57284 L
.95163 .58043 L
.95096 .58256 L
.94784 .59227 L
.94472 .60198 L
.94198 .61169 L
.94192 .61198 L
.93888 .62141 L
.93573 .63112 L
.93282 .64083 L
.93221 .6433 L
.92986 .65054 L
.92668 .66026 L
.92366 .66997 L
.92249 .67439 L
.92078 .67968 L
.91758 .68939 L
.91447 .69911 L
.91278 .70525 L
.91162 .70882 L
.9084 .71853 L
.90524 .72824 L
.90307 .73588 L
.90239 .73796 L
.89916 .74767 L
.89595 .75738 L
.89336 .76628 L
.89309 .76709 L
.88984 .77681 L
.8866 .78652 L
.8837 .79623 L
.88364 .79645 L
.88045 .80594 L
.87718 .81566 L
.87419 .82537 L
.87393 .82638 L
.87099 .83508 L
.86769 .84479 L
Mistroke
.86464 .85451 L
.86422 .85607 L
.86144 .86422 L
.85812 .87393 L
.85502 .88364 L
.85451 .88552 L
.85182 .89336 L
.84847 .90307 L
.84534 .91278 L
.84479 .91473 L
.84211 .92249 L
.83874 .93221 L
.83558 .94192 L
.83508 .94369 L
.83232 .95163 L
.82892 .96134 L
.82576 .97106 L
.82537 .97242 L
.82243 .98077 L
Mfstroke
.2 g
.98077 .50881 m
.97917 .51457 L
.97639 .52428 L
.97344 .53399 L
.97106 .54117 L
.97016 .54371 L
.96624 .55342 L
.96446 .56313 L
.96149 .57284 L
.96134 .57332 L
.95782 .58256 L
.95562 .59227 L
.95264 .60198 L
.95163 .60522 L
.94922 .61169 L
.94477 .62141 L
.94373 .63112 L
.94192 .63691 L
.94049 .64083 L
.93634 .65054 L
.93475 .66026 L
.93221 .6684 L
.93164 .66997 L
.9277 .67968 L
.92572 .68939 L
.92267 .69911 L
.92249 .69966 L
.9189 .70882 L
.91662 .71853 L
.91356 .72824 L
.91278 .73066 L
.90997 .73796 L
.90525 .74767 L
.90438 .75738 L
.90307 .76146 L
.90092 .76709 L
.89641 .77681 L
.89514 .78652 L
.89336 .79203 L
.89177 .79623 L
.88741 .80594 L
.88583 .81566 L
.88364 .82238 L
.88252 .82537 L
.87827 .83508 L
.87645 .84479 L
.87393 .8525 L
.87318 .85451 L
.86899 .86422 L
.867 .87393 L
.86422 .88239 L
.86375 .88364 L
.8596 .89336 L
.85748 .90307 L
.85451 .91204 L
.85423 .91278 L
.85009 .92249 L
.84788 .93221 L
.84479 .94145 L
.84462 .94192 L
.84047 .95163 L
.8382 .96134 L
.83508 .97063 L
.83492 .97106 L
.83074 .98077 L
.98077 .98077 L
F
0 g
.98077 .50881 m
.97917 .51457 L
.97639 .52428 L
.97344 .53399 L
.97106 .54117 L
.97016 .54371 L
.96624 .55342 L
.96446 .56313 L
.96149 .57284 L
.96134 .57332 L
.95782 .58256 L
.95562 .59227 L
.95264 .60198 L
.95163 .60522 L
.94922 .61169 L
.94477 .62141 L
.94373 .63112 L
.94192 .63691 L
.94049 .64083 L
.93634 .65054 L
.93475 .66026 L
.93221 .6684 L
.93164 .66997 L
.9277 .67968 L
.92572 .68939 L
.92267 .69911 L
.92249 .69966 L
.9189 .70882 L
.91662 .71853 L
.91356 .72824 L
.91278 .73066 L
.90997 .73796 L
.90525 .74767 L
.90438 .75738 L
.90307 .76146 L
.90092 .76709 L
.89641 .77681 L
.89514 .78652 L
.89336 .79203 L
.89177 .79623 L
.88741 .80594 L
.88583 .81566 L
.88364 .82238 L
.88252 .82537 L
.87827 .83508 L
.87645 .84479 L
.87393 .8525 L
.87318 .85451 L
.86899 .86422 L
.867 .87393 L
Mistroke
.86422 .88239 L
.86375 .88364 L
.8596 .89336 L
.85748 .90307 L
.85451 .91204 L
.85423 .91278 L
.85009 .92249 L
.84788 .93221 L
.84479 .94145 L
.84462 .94192 L
.84047 .95163 L
.8382 .96134 L
.83508 .97063 L
.83492 .97106 L
.83074 .98077 L
Mfstroke
.3 g
.98077 .60174 m
.9807 .60198 L
.97781 .61169 L
.97483 .62141 L
.97182 .63112 L
.97106 .6336 L
.96881 .64083 L
.96765 .65054 L
.96321 .66026 L
.96134 .66523 L
.95986 .66997 L
.95684 .67968 L
.95444 .68939 L
.95163 .69662 L
.95084 .69911 L
.9478 .70882 L
.94563 .71853 L
.94192 .72776 L
.94176 .72824 L
.93869 .73796 L
.93679 .74767 L
.93269 .75738 L
.93221 .75868 L
.92952 .76709 L
.92789 .77681 L
.92358 .78652 L
.92249 .78938 L
.92028 .79623 L
.91893 .80594 L
.9144 .81566 L
.91278 .81983 L
.91098 .82537 L
.90989 .83508 L
.90514 .84479 L
.90307 .85004 L
.9016 .85451 L
.89844 .86422 L
.8958 .87393 L
.89336 .88001 L
.89215 .88364 L
.88896 .89336 L
.88637 .90307 L
.88364 .90973 L
.88262 .91278 L
.87941 .92249 L
.87683 .93221 L
.87393 .9392 L
.87301 .94192 L
.86977 .95163 L
.86719 .96134 L
.86422 .96842 L
.86332 .97106 L
.86005 .98077 L
.98077 .98077 L
F
0 g
.98077 .60174 m
.9807 .60198 L
.97781 .61169 L
.97483 .62141 L
.97182 .63112 L
.97106 .6336 L
.96881 .64083 L
.96765 .65054 L
.96321 .66026 L
.96134 .66523 L
.95986 .66997 L
.95684 .67968 L
.95444 .68939 L
.95163 .69662 L
.95084 .69911 L
.9478 .70882 L
.94563 .71853 L
.94192 .72776 L
.94176 .72824 L
.93869 .73796 L
.93679 .74767 L
.93269 .75738 L
.93221 .75868 L
.92952 .76709 L
.92789 .77681 L
.92358 .78652 L
.92249 .78938 L
.92028 .79623 L
.91893 .80594 L
.9144 .81566 L
.91278 .81983 L
.91098 .82537 L
.90989 .83508 L
.90514 .84479 L
.90307 .85004 L
.9016 .85451 L
.89844 .86422 L
.8958 .87393 L
.89336 .88001 L
.89215 .88364 L
.88896 .89336 L
.88637 .90307 L
.88364 .90973 L
.88262 .91278 L
.87941 .92249 L
.87683 .93221 L
.87393 .9392 L
.87301 .94192 L
.86977 .95163 L
.86719 .96134 L
Mistroke
.86422 .96842 L
.86332 .97106 L
.86005 .98077 L
Mfstroke
.4 g
.98077 .62611 m
.97929 .63112 L
.97635 .64083 L
.97152 .65054 L
.97106 .6581 L
.97057 .66026 L
.96775 .66997 L
.96462 .67968 L
.96149 .68939 L
.96134 .68986 L
.95883 .69911 L
.95571 .70882 L
.95255 .71853 L
.95163 .7214 L
.94983 .72824 L
.94674 .73796 L
.94355 .74767 L
.94192 .75271 L
.94073 .75738 L
.9377 .76709 L
.93449 .77681 L
.93221 .78379 L
.93154 .78652 L
.92858 .79623 L
.92536 .80594 L
.92249 .81463 L
.92225 .81566 L
.91939 .82537 L
.91616 .83508 L
.91293 .84479 L
.91278 .84524 L
.91012 .85451 L
.90689 .86422 L
.90363 .87393 L
.90307 .87562 L
.90078 .88364 L
.89755 .89336 L
.89426 .90307 L
.89336 .90576 L
.89136 .91278 L
.88813 .92249 L
.88481 .93221 L
.88364 .93566 L
.88186 .94192 L
.87863 .95163 L
.87528 .96134 L
.87393 .96531 L
.87229 .97106 L
.86904 .98077 L
.98077 .98077 L
F
0 g
.98077 .62611 m
.97929 .63112 L
.97635 .64083 L
.97152 .65054 L
.97106 .6581 L
.97057 .66026 L
.96775 .66997 L
.96462 .67968 L
.96149 .68939 L
.96134 .68986 L
.95883 .69911 L
.95571 .70882 L
.95255 .71853 L
.95163 .7214 L
.94983 .72824 L
.94674 .73796 L
.94355 .74767 L
.94192 .75271 L
.94073 .75738 L
.9377 .76709 L
.93449 .77681 L
.93221 .78379 L
.93154 .78652 L
.92858 .79623 L
.92536 .80594 L
.92249 .81463 L
.92225 .81566 L
.91939 .82537 L
.91616 .83508 L
.91293 .84479 L
.91278 .84524 L
.91012 .85451 L
.90689 .86422 L
.90363 .87393 L
.90307 .87562 L
.90078 .88364 L
.89755 .89336 L
.89426 .90307 L
.89336 .90576 L
.89136 .91278 L
.88813 .92249 L
.88481 .93221 L
.88364 .93566 L
.88186 .94192 L
.87863 .95163 L
.87528 .96134 L
.87393 .96531 L
.87229 .97106 L
.86904 .98077 L
s
.5 g
.98077 .64634 m
.97723 .65054 L
.97529 .66026 L
.9733 .66997 L
.97106 .67841 L
.97069 .67968 L
.96779 .68939 L
.96478 .69911 L
.96178 .70882 L
.96134 .71025 L
.95888 .71853 L
.95587 .72824 L
.95284 .73796 L
.95163 .74187 L
.94991 .74767 L
.9469 .75738 L
.94384 .76709 L
.94192 .77326 L
.94087 .77681 L
.93786 .78652 L
.93478 .79623 L
.93221 .80443 L
.93176 .80594 L
.92875 .81566 L
.92566 .82537 L
.92258 .83508 L
.92249 .83536 L
.91958 .84479 L
.91648 .85451 L
.91336 .86422 L
.91278 .86606 L
.91034 .87393 L
.90722 .88364 L
.90408 .89336 L
.90307 .89652 L
.90103 .90307 L
.8979 .91278 L
.89473 .92249 L
.89336 .92675 L
.89165 .93221 L
.8885 .94192 L
.88531 .95163 L
.88364 .95674 L
.8822 .96134 L
.87903 .97106 L
.87582 .98077 L
.98077 .98077 L
F
0 g
.98077 .64634 m
.97723 .65054 L
.97529 .66026 L
.9733 .66997 L
.97106 .67841 L
.97069 .67968 L
.96779 .68939 L
.96478 .69911 L
.96178 .70882 L
.96134 .71025 L
.95888 .71853 L
.95587 .72824 L
.95284 .73796 L
.95163 .74187 L
.94991 .74767 L
.9469 .75738 L
.94384 .76709 L
.94192 .77326 L
.94087 .77681 L
.93786 .78652 L
.93478 .79623 L
.93221 .80443 L
.93176 .80594 L
.92875 .81566 L
.92566 .82537 L
.92258 .83508 L
.92249 .83536 L
.91958 .84479 L
.91648 .85451 L
.91336 .86422 L
.91278 .86606 L
.91034 .87393 L
.90722 .88364 L
.90408 .89336 L
.90307 .89652 L
.90103 .90307 L
.8979 .91278 L
.89473 .92249 L
.89336 .92675 L
.89165 .93221 L
.8885 .94192 L
.88531 .95163 L
.88364 .95674 L
.8822 .96134 L
.87903 .97106 L
.87582 .98077 L
s
.6 g
.98077 .66561 m
.97914 .66997 L
.97629 .67968 L
.97353 .68939 L
.97106 .69775 L
.97065 .69911 L
.96767 .70882 L
.96468 .71853 L
.96176 .72824 L
.96134 .72966 L
.9588 .73796 L
.95578 .74767 L
.95281 .75738 L
.95163 .76135 L
.94986 .76709 L
.94683 .77681 L
.94381 .78652 L
.94192 .79281 L
.94086 .79623 L
.93781 .80594 L
.93476 .81566 L
.93221 .82405 L
.9318 .82537 L
.92874 .83508 L
.92566 .84479 L
.92266 .85451 L
.92249 .85505 L
.9196 .86422 L
.91649 .87393 L
.91345 .88364 L
.91278 .88582 L
.91039 .89336 L
.90726 .90307 L
.90418 .91278 L
.90307 .91637 L
.90111 .92249 L
.89796 .93221 L
.89484 .94192 L
.89336 .94667 L
.89176 .95163 L
.88859 .96134 L
.88544 .97106 L
.88364 .97675 L
.88234 .98077 L
.98077 .98077 L
F
0 g
.98077 .66561 m
.97914 .66997 L
.97629 .67968 L
.97353 .68939 L
.97106 .69775 L
.97065 .69911 L
.96767 .70882 L
.96468 .71853 L
.96176 .72824 L
.96134 .72966 L
.9588 .73796 L
.95578 .74767 L
.95281 .75738 L
.95163 .76135 L
.94986 .76709 L
.94683 .77681 L
.94381 .78652 L
.94192 .79281 L
.94086 .79623 L
.93781 .80594 L
.93476 .81566 L
.93221 .82405 L
.9318 .82537 L
.92874 .83508 L
.92566 .84479 L
.92266 .85451 L
.92249 .85505 L
.9196 .86422 L
.91649 .87393 L
.91345 .88364 L
.91278 .88582 L
.91039 .89336 L
.90726 .90307 L
.90418 .91278 L
.90307 .91637 L
.90111 .92249 L
.89796 .93221 L
.89484 .94192 L
.89336 .94667 L
.89176 .95163 L
.88859 .96134 L
.88544 .97106 L
.88364 .97675 L
.88234 .98077 L
s
.7 g
.98077 .68584 m
.97967 .68939 L
.97679 .69911 L
.97389 .70882 L
.97106 .71806 L
.97091 .71853 L
.96784 .72824 L
.96474 .73796 L
.9619 .74767 L
.96134 .75005 L
.95902 .75738 L
.9559 .76709 L
.95291 .77681 L
.95163 .78182 L
.95014 .78652 L
.947 .79623 L
.94393 .80594 L
.94192 .81336 L
.94119 .81566 L
.93804 .82537 L
.93491 .83508 L
.93221 .84468 L
.93217 .84479 L
.92902 .85451 L
.92585 .86422 L
.92295 .87393 L
.92249 .87577 L
.91993 .88364 L
.91673 .89336 L
.91371 .90307 L
.91278 .90663 L
.91077 .91278 L
.90755 .92249 L
.90445 .93221 L
.90307 .93726 L
.90154 .94192 L
.8983 .95163 L
.89514 .96134 L
.89336 .96766 L
.89223 .97106 L
.88898 .98077 L
.98077 .98077 L
F
0 g
.98077 .68584 m
.97967 .68939 L
.97679 .69911 L
.97389 .70882 L
.97106 .71806 L
.97091 .71853 L
.96784 .72824 L
.96474 .73796 L
.9619 .74767 L
.96134 .75005 L
.95902 .75738 L
.9559 .76709 L
.95291 .77681 L
.95163 .78182 L
.95014 .78652 L
.947 .79623 L
.94393 .80594 L
.94192 .81336 L
.94119 .81566 L
.93804 .82537 L
.93491 .83508 L
.93221 .84468 L
.93217 .84479 L
.92902 .85451 L
.92585 .86422 L
.92295 .87393 L
.92249 .87577 L
.91993 .88364 L
.91673 .89336 L
.91371 .90307 L
.91278 .90663 L
.91077 .91278 L
.90755 .92249 L
.90445 .93221 L
.90307 .93726 L
.90154 .94192 L
.8983 .95163 L
.89514 .96134 L
.89336 .96766 L
.89223 .97106 L
.88898 .98077 L
s
.8 g
.98077 .7102 m
.97844 .71853 L
.97563 .72824 L
.97261 .73796 L
.97106 .74255 L
.96921 .74767 L
.965 .75738 L
.96367 .76709 L
.96134 .7747 L
.9606 .77681 L
.95669 .78652 L
.95483 .79623 L
.95184 .80594 L
.95163 .80662 L
.94817 .81566 L
.94592 .82537 L
.94293 .83508 L
.94192 .83829 L
.93949 .84479 L
.935 .85451 L
.93395 .86422 L
.93221 .86977 L
.93068 .87393 L
.92646 .88364 L
.92491 .89336 L
.92249 .90103 L
.92176 .90307 L
.91774 .91278 L
.91581 .92249 L
.91278 .93207 L
.91273 .93221 L
.90886 .94192 L
.90665 .95163 L
.90356 .96134 L
.90307 .96285 L
.89984 .97106 L
.89742 .98077 L
.98077 .98077 L
F
0 g
.98077 .7102 m
.97844 .71853 L
.97563 .72824 L
.97261 .73796 L
.97106 .74255 L
.96921 .74767 L
.965 .75738 L
.96367 .76709 L
.96134 .7747 L
.9606 .77681 L
.95669 .78652 L
.95483 .79623 L
.95184 .80594 L
.95163 .80662 L
.94817 .81566 L
.94592 .82537 L
.94293 .83508 L
.94192 .83829 L
.93949 .84479 L
.935 .85451 L
.93395 .86422 L
.93221 .86977 L
.93068 .87393 L
.92646 .88364 L
.92491 .89336 L
.92249 .90103 L
.92176 .90307 L
.91774 .91278 L
.91581 .92249 L
.91278 .93207 L
.91273 .93221 L
.90886 .94192 L
.90665 .95163 L
.90356 .96134 L
.90307 .96285 L
.89984 .97106 L
.89742 .98077 L
s
.7 g
.98077 .80314 m
.97994 .80594 L
.97703 .81566 L
.97404 .82537 L
.97106 .83497 L
.97102 .83508 L
.96801 .84479 L
.96633 .85451 L
.96222 .86422 L
.96134 .8666 L
.95905 .87393 L
.95781 .88364 L
.95338 .89336 L
.95163 .898 L
.95003 .90307 L
.94699 .91278 L
.94451 .92249 L
.94192 .92916 L
.94095 .93221 L
.93788 .94192 L
.93559 .95163 L
.93221 .96007 L
.9318 .96134 L
.9287 .97106 L
.92662 .98077 L
.98077 .98077 L
F
0 g
.98077 .80314 m
.97994 .80594 L
.97703 .81566 L
.97404 .82537 L
.97106 .83497 L
.97102 .83508 L
.96801 .84479 L
.96633 .85451 L
.96222 .86422 L
.96134 .8666 L
.95905 .87393 L
.95781 .88364 L
.95338 .89336 L
.95163 .898 L
.95003 .90307 L
.94699 .91278 L
.94451 .92249 L
.94192 .92916 L
.94095 .93221 L
.93788 .94192 L
.93559 .95163 L
.93221 .96007 L
.9318 .96134 L
.9287 .97106 L
.92662 .98077 L
s
.6 g
.98077 .8275 m
.97851 .83508 L
.97557 .84479 L
.97169 .85451 L
.97106 .85949 L
.9699 .86422 L
.96693 .87393 L
.96378 .88364 L
.96134 .89125 L
.96086 .89336 L
.95802 .90307 L
.95487 .91278 L
.95172 .92249 L
.95163 .92278 L
.94904 .93221 L
.94589 .94192 L
.94271 .95163 L
.94192 .9541 L
.93997 .96134 L
.93685 .97106 L
.93364 .98077 L
.98077 .98077 L
F
0 g
.98077 .8275 m
.97851 .83508 L
.97557 .84479 L
.97169 .85451 L
.97106 .85949 L
.9699 .86422 L
.96693 .87393 L
.96378 .88364 L
.96134 .89125 L
.96086 .89336 L
.95802 .90307 L
.95487 .91278 L
.95172 .92249 L
.95163 .92278 L
.94904 .93221 L
.94589 .94192 L
.94271 .95163 L
.94192 .9541 L
.93997 .96134 L
.93685 .97106 L
.93364 .98077 L
s
.5 g
.98077 .84773 m
.97647 .85451 L
.97484 .86422 L
.97265 .87393 L
.97106 .87979 L
.96994 .88364 L
.96699 .89336 L
.96398 .90307 L
.96134 .91164 L
.96101 .91278 L
.95809 .92249 L
.95506 .93221 L
.95204 .94192 L
.95163 .94326 L
.94912 .95163 L
.94608 .96134 L
.94304 .97106 L
.94192 .97464 L
.94008 .98077 L
.98077 .98077 L
F
0 g
.98077 .84773 m
.97647 .85451 L
.97484 .86422 L
.97265 .87393 L
.97106 .87979 L
.96994 .88364 L
.96699 .89336 L
.96398 .90307 L
.96134 .91164 L
.96101 .91278 L
.95809 .92249 L
.95506 .93221 L
.95204 .94192 L
.95163 .94326 L
.94912 .95163 L
.94608 .96134 L
.94304 .97106 L
.94192 .97464 L
.94008 .98077 L
s
.4 g
.98077 .867 m
.97833 .87393 L
.97557 .88364 L
.97278 .89336 L
.97106 .89913 L
.96986 .90307 L
.96688 .91278 L
.96389 .92249 L
.96134 .93104 L
.96099 .93221 L
.958 .94192 L
.95498 .95163 L
.95204 .96134 L
.95163 .96273 L
.94906 .97106 L
.94602 .98077 L
.98077 .98077 L
F
0 g
.98077 .867 m
.97833 .87393 L
.97557 .88364 L
.97278 .89336 L
.97106 .89913 L
.96986 .90307 L
.96688 .91278 L
.96389 .92249 L
.96134 .93104 L
.96099 .93221 L
.958 .94192 L
.95498 .95163 L
.95204 .96134 L
.95163 .96273 L
.94906 .97106 L
.94602 .98077 L
s
.3 g
.98077 .88722 m
.97889 .89336 L
.97602 .90307 L
.97311 .91278 L
.97106 .91944 L
.9701 .92249 L
.96701 .93221 L
.96394 .94192 L
.96134 .95143 L
.96128 .95163 L
.95819 .96134 L
.95508 .97106 L
.95221 .98077 L
.98077 .98077 L
F
0 g
.98077 .88722 m
.97889 .89336 L
.97602 .90307 L
.97311 .91278 L
.97106 .91944 L
.9701 .92249 L
.96701 .93221 L
.96394 .94192 L
.96134 .95143 L
.96128 .95163 L
.95819 .96134 L
.95508 .97106 L
.95221 .98077 L
s
.2 g
.98077 .9116 m
.98044 .91278 L
.97771 .92249 L
.97485 .93221 L
.97176 .94192 L
.97106 .94394 L
.9682 .95163 L
.96362 .96134 L
.96289 .97106 L
.96134 .97612 L
.95964 .98077 L
.98077 .98077 L
F
0 g
.98077 .9116 m
.98044 .91278 L
.97771 .92249 L
.97485 .93221 L
.97176 .94192 L
.97106 .94394 L
.9682 .95163 L
.96362 .96134 L
.96289 .97106 L
.96134 .97612 L
.95964 .98077 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00`_ooool2o`0000;ooooo0_l0
002Pooooo`00`_ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgJ3ooooo0033ooooo`04omgMgOl0
003o410@olc<c:7ooooo0033ooooo`04onk^k_lQ8B7o410@onk^kZ7ooooo0033ooooo`04ob4Q8Omg
MgOoMgMgoc8b<Z7ooooo0032ooooo`;o00000_ooool2o`000:3ooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0011oooo
o`;o000000?o410@ooooooooool08oooool5o`00023ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0T
ooooo`Go00009_ooool2o`000003oa0@4?oooooooooo02?ooooo00Gok^k^oc8b<_l0003o410@olc<
c00Tooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`08Oooool4o`000008oa0@4?ooooooooooonk^k_lb
<S;o0000oc8b<_o^k^h3ooooo`00@_ooool00ol0003oooooooooo`0Tooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@08?ooool01OmgMgOoV9RHoooooonHV9SoMgMg02Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A00Wooooo`03o`000?oooooooooo02Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@0Tooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B408oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00oooool003Oooooo1_l00002ooooo`Go00007Oooool6o`0000?ooooo00?oV9RHob4Q
8Oo^k^h08Oooool01Ol@413ooooooooooooooooo410@02Gooooo00?oV9RHob4Q8Oo^k^h09Oooool5
o`0002Gooooo00Go0000ooooooooooooooooo`00000Tooooo`05o`000?ooooooooooooooool00000
8oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool003oooooo
00CoA4A4omgMgOoooooo0000:?ooool00onHV9So8B4Qonk^kP0Pooooo`05o`000?oooooooooooooo
ool000009_ooool00onHV9So8B4Qonk^kP0Tooooo`04odA4A?oMgMgoooooo`0002Kooooo00Go0000
oiRHV?ooooooV9RHob4Q8@0Tooooo`05oc8b<_nHV9SooooooiRHV?lb<S808oooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool003oooooo00CogMgMoeEEEOoooooo
0000:Oooool00omgMgOoIVIVooooo`0Oooooo`05o`000?ooooooooooooooool000009oooool00omg
MgOoIVIVooooo`0Sooooo`04omgMgOmEEEGoooooo`0002Kooooo00Go0000oeEEEOl0003o410@olc<
c00Tooooo`05olc<c?l0003o0000o`000?o<c<`08oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000000oooool0043ooooo00?oMgMgolc<c?l00000:_ooool00ol0003ooooo
ooooo`0Nooooo`05oa0@4?ooooooooooooooool@4100:?ooool00ol0003oooooooooo`0Sooooo`03
ogMgMoo<c<co000002Kooooo00?oEEEEohN7Qoooool09_ooool01Ol@413o^[Zjoooooonj^[[o410@
02?ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo0010oooo
o`03onk^k_m4A4Co000002Kooooo00Go0000okZj^_ooooooV9RHoa0@400Pooooo`05ogMgMonHV9So
oooooiRHV?mgMgL09?ooool01Ol0003o^[ZjoooooonHV9So410@02Gooooo00?ok^k^odA4A?l00000
9_ooool00ooMgMgo410@oiRHV00Vooooo`05o`000?nj^[[ooooookZj^_l000008oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool0047ooooo00?oMgMgo`000?oo
ool09Oooool01OnHV9So410@o`000?lQ8B7oc<c<023ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0T
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`09_ooool00omgMgOo0000ooooo`0Vooooo`04olc<c?m4
A4Co0000oa0@42Cooooo00GoZJVYoa0@4?l0003o410@ojVYZ@0Qooooo`03oeEEEOmVIVKo000000Co
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`009?ooooooo`0004?o00000_ooool002Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`7o00000Oooool1ooooo`009?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo0Ol00001ooooo`7ooooo000T
ooooo`03o`000?oooooooooo0?oooooo?oooool1o`00007ooooo0Oooool002Cooooo00?o0000oooo
ooooool0ooooooloooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`3oooooocoo
oooo0Ol00001ooooo`7ooooo000Tooooo`;o00004?ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Kooooo0ol00008ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00003ooooo`03o`000?oo
oooooooo00Kooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo000000;ooooo
00Co0000oooooooooooo00002?ooool01ol0003ooooooooooooooooo0000ooooool000000_ooool0
0ol0003oooooo`000002ooooo`03o`000?oooooooooo00Kooooo00Ko0000oooooooooooo0000oooo
ool00002ooooo`05o`000?oooooo0000ooooool000002Oooool02Ol0003oooooo`000?oooooo0000
ooooool0003oooooo`000002ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?oo
ool2o`0000;ooooo000Tooooo`03o`000?oooooooooo00?ooooo3?mVIVH00ol0003oOgmoogmoO`09
ogmoO`03o`000?nIVIWoVIVI00[oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0<
oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00E
oda<C003o`000?mVIVKoIVIV00GoIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@03
oiVIV@03o`000?nc/k?o/k>c00So/k>c00?o0000ok>c/onc/k<01_nc/k<01Ol0003oVIVIoiVIVOnI
VIWo000000?oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go<c<c
00?o0000oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Co0000oiVIVOnI
VIWo00000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT0
0ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Oo0000oda<C?m<C4coC4a<
o`000?mVIVKo000000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c006
o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl01Ol0003oIVIVo`000?m<C4co000000Wo<c<c00Wo
0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<
c003o`000?nc/k?o000000Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?o
oooo2omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc
/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mV
IVH02omVIVH00ol0003oC4a<oda<C00Eoda<C003o`000?mVIVKoIVIV00GoIVIV00?o0000ogmoOomo
Ogl00_moOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c017o/k>c00Go0000oiVIVOnI
VIWoVIVIo`000004ogmoO`05o`000?mVIVKoIVIVofIVI_l000001?m<C4`00ol0003o<c<coc<c<`05
oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01Ol0003oVIVIoiVI
VOnIVIWo000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`01ol0003o/k>cok>c/onc/k?o0000oiVI
VOl000000_moOgl01?l0003oIVIVofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Wo0000
oda<C?m<C4coC4a<o`000?mVIVKo0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00008olc<
c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl01Ol0003oIVIVo`000?m<C4co000000Wo<c<c
00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006
olc<c003o`000?nc/k?o000000Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo
00?ooooo2_mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c
/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIV
I_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00GoIVIV00Co0000ogmo
OomoOgooOgmo0_l00004oiVIV@03o`000?nc/k?o/k>c01;o/k>c00Go0000oiVIVOnIVIWoVIVIo`00
0003ogmoO`05o`000?mVIVKoIVIVofIVI_l000001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`00
0?m<C4coC4a<00;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`00
00?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000
ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo
00000_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Ko0000ok>c/onc
/k?o0000oiVIVOl00002ogmoO`05o`000?mVIVKo0000oda<C?l000002Olc<c<02Ol0003oC4a<o`00
0?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o0000ok>c
/ol000001_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool9ofIVIP03
o`000?moOgooOgmo00SoOgmo0_l0000<oiVIV@;o00006?nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03
o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003
o`000?mVIVKoIVIV00GoIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@03oiVIV@03
o`000?nc/k?o/k>c017o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo0000
00?oIVIV00?o0000oda<C?m<C4`00_m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<
00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000;o/k>c00?o
0000olc<c?o<c<`01oo<c<`01ol0003o/k>cok>c/onc/k?o0000oiVIVOl000000_moOgl01?l0003o
IVIVofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Ko0000oda<C?m<C4co0000ofIVI_l0
0002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01_l0003o/k>cok>c
/ol0003oVIVIo`0000;oOgmo00Go0000ofIVI_l0003oC4a<o`000009oc<c<`09o`000?m<C4co0000
ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003o/k>c
o`000006ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`SoIVIV00?o
0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o
0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00coIVIV00?o
0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP04ofIVIP03o`000?moOgooOgmo00?oOgmo00?o
0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0Aok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go
0000ogmoOomoOgooOgmoo`000003ofIVIP03o`000?m<C4coC4a<00;oC4a<00?o0000oc<c<olc<c<0
1Olc<c<01Ol0003oC4a<oda<C?m<C4co000000?oIVIV00Co0000ogmoOomoOgoo00000onIVIT01?l0
003o/k>cok>c/ol00009olc<c007o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000002ogmoO`04o`00
0?mVIVKoIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01olc<c<01_l0003oC4a<oda<C?l0003oIVIV
o`0000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c006o`000?nc/k?o
/k>co`000?nIVIWo00000_moOgl01Ol0003oIVIVo`000?m<C4co000000Wo<c<c00Wo0000oda<C?l0
003oIVIVo`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c003o`000?nc
/k?o000000Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo1omVIVH0
0ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00coVIVI00?o0000ok>c/onc/k<05_nc/k<0
0ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH03?mVIVH0
0ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00CoIVIV00?o0000ogmoOomoOgl00omoOgl0
0ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c017o/k>c00?o0000oiVIVOnIVIT00_nIVIT0
1Ol0003oOgmoogmoOomoOgoo000000?oIVIV00?o0000oda<C?m<C4`00_m<C4`00ol0003o<c<coc<c
<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`04o`00
0?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01ol0003o/k>cok>c/onc/k?o0000
oiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Co
0000oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<
c<`01_o<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00?o0000ofIVI_l000000_m<C4`0
0ol0003o<c<coc<c<`06oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000?o
/k>c00?o0000olc<c?o<c<`01Oo<c<`01?l0003o/k>co`000?nIVIT6ooooo`7o00000Oooool1oooo
o`009?ooool00ol0003oooooooooo`03ooooo`KoIVIV00?o0000ogmoOomoOgl02?moOgl2o`0000co
VIVI0_l0000Hok>c/`03o`000?nIVIWoVIVI00[oVIVI0_l0000:ogmoO`03o`000?mVIVKoIVIV00_o
IVIV0_l0000Hoda<C003o`000?mVIVKoIVIV00CoIVIV00?o0000ogmoOomoOgl00omoOgl00ol0003o
VIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c01;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmo
O`05o`000?mVIVKoIVIVofIVI_l000001Om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4co
C4a<00?oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`00
0?o<c<coc<c<00Goc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`00
00;oIVIV00Co0000oda<C?m<C4co00002?lc<c<00ol0003oC4a<oda<C002o`000004ofIVI_l0003o
Ogmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01_l0003o/k>cok>c/ol0003oVIVIo`00
00;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`09o`000?m<C4co0000
ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>c
o`000?nIVIT6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`GoIVIV
00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c
00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV
00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP05ofIVIP03o`000?moOgooOgmo00?oOgmo
00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`0Cok>c/`05o`000?nIVIWoVIVIoiVIVOl0
00000omoOgl01Ol0003oIVIVofIVI_mVIVKo000000GoC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0
003oC4a<oda<C003oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo00000onc
/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmo
ogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Co0000oda<C?m<C4co00000_mVIVH0
0ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Ko0000ok>c/onc/k?o0000
oiVIVOl00002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02Ol0003o
C4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go
0000ok>c/ol0003oVIVIo`000005ooooo`7o00000Oooool1ooooo`009?ooool00ol0003ooooooooo
o`03ooooo`CoIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc
/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mV
IVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP05ofIVIP03o`000?mo
OgooOgmo00?oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0Bok>c/`05o`000?nI
VIWoVIVIoiVIVOl000000omoOgl01Ol0003oIVIVofIVI_mVIVKo000000GoC4a<00?o0000oc<c<olc
<c<01?lc<c<00ol0003oC4a<oda<C003oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co0000oiVI
VOnIVIWo00001?nc/k<00ol0003oc<c<olc<c005olc<c005o`000?nc/k?o/k>cok>c/ol000000onI
VIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Co0000oda<C?m<C4co
00000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Ko0000ok>c
/onc/k?o0000oiVIVOl00002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc
<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<
00Koc<c<00?o0000ok>c/ol000000_nIVIT00ol0003oooooooooo`03ooooo`7o00000Oooool1oooo
o`009?ooool00ol0003oooooooooo`03ooooo`?oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003o
VIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02_nIVIT2o`0000[o
Ogmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00Go
IVIV00?o0000ogmoOomoOgl00omoOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c01;o
/k>c00?o0000oiVIVOnIVIT00_nIVIT00ol0003oOgmoogmoO`02o`0000?oIVIV00?o0000oda<C?m<
C4`00_m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Go0000ofIVI_mV
IVKoIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`0
1Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Ko0000ogmoOomoOgoo0000ofIVI_l00003oda<C003
o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVI
V@04o`000?nc/k?o/k>co`0000Soc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`0000;o
IVIV00?o0000oda<C?l000002Olc<c<02ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`00
0?nc/k?o000000Woc<c<00Go0000ok>c/ol0003oVIVIo`000006ooooo`7o00000Oooool1ooooo`00
9?ooool2o`0000Cooooo0_mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI
00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0:oiVIV@03o`000?moOgooOgmo00WoOgmo
00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00KoIVIV
00?o0000ogmoOomoOgl00omoOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c01;o/k>c
00?o0000oiVIVOnIVIT00_nIVIT01?l0003oOgmoogmoOol00004ofIVIP03o`000?m<C4coC4a<00;o
C4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C005o`000?mVIVKoIVIVofIV
I_l000000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000
ok>c/onc/k?o/k>co`000002oiVIV@06o`000?moOgooOgmoo`000?mVIVKo00000om<C4`00ol0003o
<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0
003o/k>cok>c/ol00008olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP03
o`000?m<C4co000000Wo<c<c00_o0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>c
o`000009olc<c005o`000?nc/k?o0000oiVIVOl000001Oooool2o`0000;ooooo000Tooooo`03o`00
0?oooooooooo00?ooooo00?oIVIVo`000?moOgl02OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`00
0?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`00
0?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`06?m<C4`00ol0003oIVIVofIVIP05ofIVIP03o`00
0?moOgooOgmo00?oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0Bok>c/`03o`00
0?nIVIWoVIVI00;oVIVI00Co0000ogmoOomoOgoo00001?mVIVH00ol0003oC4a<oda<C003oda<C003
o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo0000
00;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o
/k>cok>c/ol000000_nIVIT01_l0003oOgmoogmoOol0003oIVIVo`0000?oC4a<00?o0000oc<c<olc
<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP06o`000?moOgooOgmoo`000?nIVIWo00000_nc
/k<00ol0003oc<c<olc<c006olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00003ofIV
IP;o00002Olc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c/`03o`00
0?o<c<coc<c<00Koc<c<00?o0000ok>c/onc/k<00_l000000omoOgooooooooooo`04ooooo`7o0000
0Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`03o`000?moOgooOgmo00SoOgmo00?o
0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00[oVIVI0_l0
000:ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`2o`0000OoIVIV00?o
0000ogmoOomoOgl00omoOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c01?o/k>c00Go
0000oiVIVOnIVIWoVIVIo`000003ogmoO`05o`000?mVIVKoIVIVofIVI_l000001Om<C4`00ol0003o
<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl2o`00
00;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c005o`000?nc/k?o/k>cok>c/ol000000_nI
VIT00ol0003oOgmoo`000002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01?l0003oC4a<
oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`02?l0
003o/k>cok>c/ol0003oVIVIo`000?moOgoo00000_mVIVH00ol0003oC4a<o`000009oc<c<`09o`00
0?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`0
0ol0003o/k>cok>c/`02o`000003ogmoOooooooooooo00Cooooo0Ol00001ooooo`7ooooo000Toooo
o`03o`000?oooooooooo00?ooooo2_moOgl00ol0003oVIVIoiVIV@0;oiVIV@;o00005onc/k<2o`00
00coVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<
01OoC4a<00?o0000ofIVI_mVIVH01omVIVH00ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI
00?oVIVI00?o0000ok>c/onc/k<04onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Go0000
ofIVI_mVIVKoIVIVo`000005oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00om<
C4`01?l0003oIVIVofIVI_l00002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000onc/k<00ol0003o
c<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Ko0000oiVIVOnIVIWo0000ogmoOol00002
ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;o
Ogmo00Co0000oiVIVOnIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c008o`000?nc/k?o/k>c
o`000?nIVIWo0000ogmoOol00002ofIVIP03o`000?m<C4co000000Wo<c<c00Wo0000oda<C?l0003o
IVIVo`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c003o`000?nc/k?o
/k>c00;o000000?oOgmoo`000?ooool01?ooool1o`00007ooooo0Oooool002Cooooo00?o0000oooo
ooooool00oooool9ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0
003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0
003oC4a<oda<C00Hoda<C003o`000?mVIVKoIVIV00KoIVIV00?o0000ogmoOomoOgl00omoOgl00ol0
003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c01;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000003
ogmoO`05o`000?mVIVKoIVIVofIVI_l000001Om<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<
C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000?o
/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmo
OomoOgoo00000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV
00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00008olc<c008o`000?nc/k?o/k>co`00
0?nIVIWo0000ogmoOol00002ofIVIP03o`000?m<C4co000000Wo<c<c00?o0000oda<C?l000000_mV
IVH2o`000005oiVIVOl0003o/k>cok>c/ol000002Oo<c<`01?l0003o/k>co`000?l00002ogmoO`03
o`000?oooooooooo00?ooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo
2?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT0
3?nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`0
6?m<C4`00ol0003oIVIVofIVIP06ofIVIP03o`000?moOgooOgmo00?oOgmo00?o0000oiVIVOnIVIT0
1?nIVIT00ol0003o/k>cok>c/`0Bok>c/`05o`000?nIVIWoVIVIoiVIVOl000001?moOgl01Ol0003o
IVIVofIVI_mVIVKo000000GoC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C002oda<
C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<
c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01_l0003oVIVIo`000?l0003oOgmoo`0000;o
IVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000
ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00008olc<c008o`000?nc/k?o/k>co`000?nIVIWo
0000ogmoOol00002ofIVIP03o`000?m<C4co000000Wo<c<c00Wo0000oda<C?l0003oIVIVo`000?mo
Ogoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c003o`000?nc/k?o/k>c00;o0000
00?oOgmoo`000?ooool01Oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00ooo
ool7ogmoO`03o`000?nIVIWoVIVI00_oVIVI0_l0000Gok>c/`;o00003OnIVIT00ol0003oOgmoogmo
O`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`06?m<C4`00ol0003oIVIVofIV
IP07ofIVIP03o`000?moOgooOgmo00?oOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c
/`0Bok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl00ol0003oIVIVofIVIP02ofIVIP03o`00
0?m<C4coC4a<00?oC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C002oda<C005o`00
0?mVIVKoIVIVofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<
00Goc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Go
0000oda<C?m<C4coC4a<o`000008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol0
00000_nIVIT01?l0003o/k>cok>c/ol00008olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmo
Ool00002ofIVIP03o`000?m<C4co000000Wo<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000
oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c003o`000?nc/k?o/k>c00;o000000?oOgmo
o`000?ooool01Oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool6ogmo
O`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0<oiVI
V@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Hoda<
C003o`000?mVIVKoIVIV00OoIVIV00?o0000ogmoOomoOgl00omoOgl00ol0003oVIVIoiVIV@04oiVI
V@03o`000?nc/k?o/k>c01;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000004ogmoO`05o`000?mVIVKo
IVIVofIVI_l000001Om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00;oC4a<00Go
0000ofIVI_mVIVKoIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<
c<`01_o<c<`01ol0003o/k>cok>c/onc/k?o0000oiVIVOl000000_moOgl01?l0003oIVIVofIVI_l0
0003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmo
o`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003o
Ogmoo`0000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<00ol0003oC4a<oda<C002o`000007ogmo
Ool0003oVIVIoiVIVOl0003o/k>co`000009olc<c004o`000?nc/k?o0000oiVIV@;o000000?oIVIV
ooooooooool01?ooool1o`00007ooooo0Oooool001_ooooo0_l000000ol@413oooooooooo`04oooo
o`03o`000?oooooooooo00?ooooo1OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c
01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT2o`0000[oOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0
003oC4a<oda<C00Hoda<C003o`000?mVIVKoIVIV00OoIVIV00?o0000ogmoOomoOgl00omoOgl00ol0
003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c01;o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0
003oOgmoogmoOomoOgoo000000?oIVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`04
oc<c<`03o`000?m<C4coC4a<00?oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`04o`000?nI
VIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@04
o`000?moOgooOgmoo`0000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<01?l0003oC4a<oda<C?l0
0002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`02?l0003o/k>c
ok>c/ol0003oVIVIo`000?moOgoo00000_mVIVH01?l0003oC4a<o`000?l00008oc<c<`09o`000?m<
C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`01?l0
003o/k>co`000?nIVIT2o`000003ofIVI_oooooooooo00Cooooo0Ol00001ooooo`7ooooo000Loooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool4ogmoO`03o`000?nIVIWoVIVI
00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo
00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Hoda<C003o`000?mVIVKoIVIV
00OoIVIV00?o0000ogmoOomoOgl01?moOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c
01;o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000?oIVIV00?o0000
oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Co0000
ofIVI_mVIVKo00000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000?o/k>c00?o0000olc<c?o<c<`0
1oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Co0000oda<
C?m<C4co00002Olc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00Co
0000ok>c/onc/k?o00002?o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0
0002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000oiVI
VOl000000_nc/k<00ol0003oc<c<olc<c007olc<c004o`000?nc/k?o0000oiVIV@;o000000?oIVIV
ooooooooool01?ooool1o`00007ooooo0Oooool0017ooooo1_l00002ooooo`Go00001_ooool3o`00
00?ooooo0omoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVI
VOnIVIT03?nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<
C?m<C4`05om<C4`2o`0000WoIVIV00?o0000ogmoOomoOgl01?moOgl00ol0003oVIVIoiVIV@04oiVI
V@03o`000?nc/k?o/k>c01;o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo
000000?oIVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4co
C4a<00;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVIVOl00000
0_nc/k<00ol0003oc<c<olc<c007olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Co0000ogmoOomo
Ogoo00000_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o
0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00008olc<c008o`000?nc/k?o/k>co`000?nI
VIWo0000ogmoOol00002ofIVIP03o`000?m<C4co000000Wo<c<c00Go0000oda<C?l0003oIVIVo`00
0002ogmoO`;o00000_nc/k<00ol0003oc<c<olc<c007olc<c004o`000?nc/k?o0000oiVIV@;o0000
0_mVIVH01?l0003oooooooooooooool3o`0000;ooooo000Iooooo`04odA4A?oMgMgoooooo`0000Oo
oooo00?o0000ooooooooool00oooool2ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc
/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@;o00002_moOgl00ol0003oIVIVofIVIP0;ofIVIP03
o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02?mVIVH00ol0003oOgmoogmoO`04ogmoO`03
o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<04_nc/k<00ol0003oVIVIoiVIV@02oiVIV@05
o`000?moOgooOgmoogmoOol000001?mVIVH00ol0003oC4a<oda<C003oda<C003o`000?lc<c?o<c<c
00Co<c<c00?o0000oda<C?m<C4`00om<C4`01?l0003oIVIVofIVI_l00002ogmoO`05o`000?nIVIWo
VIVIoiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol00000
0_nIVIT01?l0003oOgmoogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Oo0000oda<
C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<
c007olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP03o`000?m<C4co0000
00Wo<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<
olc<c006olc<c005o`000?nc/k?o/k>co`000?nIVIT00_l000000omVIVKo0000ooooo`05ooooo`7o
00000Oooool1ooooo`006Oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo00?o
oooo0_moOgl00ol0003oVIVIoiVIV@0:oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnI
VIT03?nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<
C4`05_m<C4`2o`0000_oIVIV00?o0000ogmoOomoOgl01?moOgl00ol0003oVIVIoiVIV@04oiVIV@03
o`000?nc/k?o/k>c01;o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo0000
00CoIVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<
00?oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000?o/k>c00?o
0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmoOol00000
0omVIVH01?l0003oC4a<oda<C?l00008oc<c<`07o`000?m<C4coC4a<oda<C?l0003oIVIVo`000002
ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`02?l0003o/k>cok>c/ol0
003oVIVIo`000?moOgoo00000_mVIVH00ol0003oC4a<o`000009oc<c<`09o`000?m<C4co0000ofIV
I_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c
/ol0003oVIVI00;o000000?oIVIVo`000?ooool01Oooool1o`00007ooooo0Oooool001[ooooo00?o
MgMgolc<c?l000001oooool00ol0003oooooooooo`03ooooo`03ogmoOol0003oVIVI00_oVIVI00?o
0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo00SoOgmo00?o
0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00[oIVIV00?o
0000ogmoOomoOgl01?moOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c01?o/k>c00Go
0000oiVIVOnIVIWoVIVIo`000004ogmoO`05o`000?mVIVKoIVIVofIVI_l000001Om<C4`00ol0003o
<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01Ol0
003oVIVIoiVIVOnIVIWo000000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`01Ol0003o/k>cok>c/onc
/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000omVIVH01?l0003oC4a<oda<C?l00008oc<c<`04
o`000?m<C4coC4a<o`0000;oIVIV00Go0000ogmoOol0003oVIVIo`000003ok>c/`03o`000?o<c<co
c<c<00Koc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`05o`000?mVIVKo0000oda<C?l0
00002Olc<c<00ol0003oC4a<o`000002ofIVIP;o000000GoVIVIo`000?nc/k?o/k>co`000009olc<
c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000Kooooo0Ol00001ooooo`7ooooo
000Jooooo`03onk^k_m4A4Co000000Oooooo00?o0000ooooooooool00oooool00ol0003oVIVIoiVI
V@0:oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT2o`0000[oOgmo00?o
0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00[oIVIV00?o
0000ogmoOomoOgl01?moOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o
0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000?oIVIV00?o0000oda<C?m<C4`0
0om<C4`2o`0000Go<c<c00?o0000oda<C?m<C4`00om<C4`01Ol0003oIVIVofIVI_mVIVKo000000;o
Ogmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>c
ok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c
00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00?o0000oiVIVOl000000onc/k<00ol0
003oc<c<olc<c006olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP03o`00
0?m<C4co000000Wo<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl000000_nc/k<0
0ol0003oc<c<olc<c006olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`00
00Kooooo0Ol00001ooooo`7ooooo000Kooooo`03ogMgMol0003ooooo00Kooooo00?o0000oooooooo
ool00oooool<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003o
OgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003o
IVIVofIVIP09ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o
/k>cok>c/`0Cok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`000003ofIV
IP03o`000?m<C4coC4a<00?oC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C003oda<
C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<
c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;o
IVIV00Co0000oda<C?m<C4co00002?lc<c<01ol0003oC4a<oda<C?m<C4co0000ofIVI_l000000_mo
Ogl00ol0003oVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00So0000ok>c/onc/k?o0000
oiVIVOl0003oOgmoo`0000;oIVIV00?o0000oda<C?l000002Olc<c<02Ol0003oC4a<o`000?mVIVKo
0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00[o0000ok>c/onc/k?o
0000oiVIVOl0003oOgmoo`000?mVIVKo00001_ooool1o`00007ooooo0Oooool002Cooooo00?o0000
ooooooooool00oooool<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT0
0ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`0
0ol0003oIVIVofIVIP0:ofIVIP03o`000?moOgooOgmo00CoOgmo00?o0000oiVIVOnIVIT01?nIVIT0
0ol0003o/k>cok>c/`0Cok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`00
0004ofIVIP03o`000?m<C4coC4a<00?oC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<
C003oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo00001Onc/k<00ol0003o
c<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Ko0000oiVIVOnIVIWo0000ogmoOol00002
ofIVIP04o`000?m<C4coC4a<o`0000Wo<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo000000;o
Ogmo0_l00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT01Ol0
003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02_l0003oC4a<oda<C?l0
003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o0000ok>c
/onc/k<00_l00002ogmoO`03o`000?mVIVKo000000Kooooo0Ol00001ooooo`7ooooo000Tooooo`03
o`000?oooooooooo00?ooooo2onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_o
VIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01Oo
C4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00Co
VIVI00?o0000ok>c/onc/k<04onc/k<00ol0003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmo
Ool000000omVIVH00ol0003oC4a<oda<C003oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<
C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo00001?nc
/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmo
ogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Oo0000oda<C?m<C4coC4a<o`000?mV
IVKo000000;oOgmo00?o0000oiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c008o`000?nc
/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP03o`000?m<C4co000000Wo<c<c00?o0000oda<
C?m<C4`00_l000001omoOgoo0000oiVIVOnIVIWo0000ok>c/ol000002?o<c<`03?l0003o/k>cok>c
/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000Gooooo0Ol00001ooooo`7ooooo000T
ooooo`03o`000?oooooooooo00?ooooo2OnIVIT2o`0001Oo/k>c0_l0000=oiVIV@03o`000?moOgoo
Ogmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKo
IVIV00[oIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o
/k>c01?o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000CoIVIV00?o
0000oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Co
0000ofIVI_mVIVKo00000omoOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Go
c<c<00?o0000ok>c/onc/k<00_nc/k<01_l0003oVIVIoiVIVOl0003oOgmoo`0000;oIVIV00Co0000
oda<C?m<C4co00002Olc<c<01ol0003oC4a<oda<C?m<C4co0000ofIVI_l000000_moOgl00ol0003o
VIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003o
Ogmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`08o`000?m<C4coC4a<o`000?mV
IVKo0000ogmoOol00002oiVIV@03o`000?nc/k?o000000Soc<c<00co0000ok>c/onc/k?o0000oiVI
VOl0003oOgmoo`000?mVIVKo0000oda<C?l00005ooooo`7o00000Oooool1ooooo`009?ooool00ol0
003oooooooooo`03ooooo`WoVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVI
V@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH03?mVIVH00ol0003oC4a<oda<C00Foda<
C003o`000?mVIVKoIVIV00[oIVIV00?o0000ogmoOomoOgl01_moOgl00ol0003oVIVIoiVIV@04oiVI
V@03o`000?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo
000000CoIVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4co
C4a<00?oC4a<00Co0000ofIVI_mVIVKo00000omoOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`00
0?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01_l0003oVIVIoiVIVOl0003oOgmoo`00
00;oIVIV00Co0000oda<C?m<C4co00002Olc<c<02Ol0003oC4a<oda<C?m<C4co0000ofIVI_l0003o
Ogmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Woc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0
003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`08o`000?m<C4coC4a<o`00
0?mVIVKo0000ogmoOol00002oiVIV@03o`000?nc/k?o000000Soc<c<00co0000ok>c/onc/k?o0000
oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00005ooooo`7o00000Oooool1ooooo`009?ooool2
o`0000Cooooo2?nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000
ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000
ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`06ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000
ok>c/onc/k<04onc/k<00ol0003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol000001?mV
IVH00ol0003oC4a<oda<C003oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00om<
C4`01?l0003oIVIVofIVI_l00003ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<
c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmoOol000000_mVIVH01Ol0
003oC4a<oda<C?m<C4co000000So<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo
00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c00:o`000?nc/k?o/k>co`000?nI
VIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01_l0003oC4a<oda<
C?l0003oIVIVo`0000;oOgmo00Go0000oiVIVOl0003o/k>co`000008olc<c00<o`000?nc/k?o/k>c
o`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co00001Oooool2o`0000;ooooo000Tooooo`03
o`000?oooooooooo00?ooooo1_nIVIT2o`0001So/k>c00?o0000oiVIVOnIVIT02_nIVIT2o`0000[o
Ogmo00?o0000ofIVI_mVIVH02omVIVH2o`0001OoC4a<0_l0000<ofIVIP03o`000?moOgooOgmo00Go
Ogmo0_l00006oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT00_nIVIT00ol0003o
OgmoogmoO`02ogmoO`05o`000?mVIVKoIVIVofIVI_l000001Om<C4`2o`0000Go<c<c00?o0000oda<
C?m<C4`00om<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`00
0003ok>c/`;o00001oo<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo
00000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Co0000oda<C?m<C4co00000_mVIVH0
1_l0003oOgmoogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02ol0003o/k>c
ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc
<c<02?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo00000_nIVIT00ol0003o/k>co`000008olc<
c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co00001_ooool1o`00
007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool5oiVIV@03o`000?nc/k?o/k>c01Oo
/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00_o
IVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00Ko
Ogmo00?o0000oiVIVOnIVIT01OnIVIT00ol0003o/k>cok>c/`0Cok>c/`03o`000?nIVIWoVIVI00;o
VIVI00?o0000ogmoOomoOgl00_moOgl01Ol0003oIVIVofIVI_mVIVKo000000GoC4a<00?o0000oc<c
<olc<c<01?lc<c<00ol0003oC4a<oda<C003oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl0
1Ol0003oVIVIoiVIVOnIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c
/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01Ol0003oC4a<oda<C?m<C4co0000
00So<c<c00Co0000oda<C?m<C4co00000_mVIVH01_l0003oOgmoogmoOol0003oVIVIo`0000;o/k>c
00?o0000olc<c?o<c<`01_o<c<`02ol0003o/k>cok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mV
IVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02?l0003oC4a<oda<C?l0003oIVIVo`000?mo
Ogoo00000_nIVIT00ol0003o/k>co`000008olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmo
Ool0003oIVIVo`000?m<C4co00001_ooool1o`00007ooooo0Oooool002Cooooo00?o0000oooooooo
ool00oooool4oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003o
OgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003o
IVIVofIVIP0<ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT01OnIVIT00ol0003o
/k>cok>c/`0Cok>c/`03o`000?nIVIWoVIVI00?oVIVI00Go0000ogmoOomoOgooOgmoo`000003ofIV
IP03o`000?m<C4coC4a<00?oC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<
C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000?o/k>c00?o
0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo
00000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Oo0000oda<C?m<C4coC4a<o`000?mV
IVKo000000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c00:o`000?nc
/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01olc<c<0
0ol0003oC4a<o`000002ofIVIP;o00000_nIVIT00ol0003o/k>co`000009olc<c00<o`000?nc/k?o
0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l0003o<c<c1_ooool1o`00007ooooo0Oooool0
02Cooooo00?o0000ooooooooool00oooool3oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVI
VOnIVIT02_nIVIT2o`0000[oOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<
C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@05oiVI
V@03o`000?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT00onIVIT01Ol0003oOgmoogmoOomoOgoo
000000CoIVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4co
C4a<00?oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c
00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomo
Ogoo00000_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o
0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00009olc<c003o`000?nc/k?o000000;oVIVI
00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Oo0000oda<C?l0
003oIVIVo`000?moOgoo000000;oVIVI00?o0000ok>c/ol000002?o<c<`03Ol0003o/k>cok>c/ol0
003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`000?lc<c<01_ooool1o`00007ooooo0Oooool0
02Cooooo00?o0000ooooooooool00oooool2oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVI
VOnIVIT02_nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<
C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVI
VOnIVIT01_nIVIT00ol0003o/k>cok>c/`0Cok>c/`03o`000?nIVIWoVIVI00?oVIVI00Go0000ogmo
OomoOgooOgmoo`000004ofIVIP03o`000?m<C4coC4a<00?oC4a<00?o0000oc<c<olc<c<01?lc<c<0
0ol0003oC4a<oda<C003oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01?l0003oVIVIoiVI
VOl00004ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04
o`000?moOgooOgmoo`0000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<01?l0003oC4a<oda<C?l0
0002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`00ol0003o/k>c
o`000002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`07
o`000?m<C4co0000ofIVI_l0003oOgmoo`000002oiVIV@03o`000?nc/k?o000000Soc<c<00go0000
ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l0003o<c<c00Kooooo0Ol00001
ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo00?oVIVIo`000?nc/k<06?nc/k<00ol0
003oVIVIoiVIV@0:oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0
003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV0_l00008ogmoO`03o`000?nIVIWoVIVI
00GoVIVI00?o0000ok>c/onc/k<04onc/k<00ol0003oVIVIoiVIV@03oiVIV@05o`000?moOgooOgmo
ogmoOol000001?mVIVH00ol0003oC4a<oda<C003oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000
oda<C?m<C4`00om<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo0000
1?nc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003o
OgmoogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01?l0003oC4a<oda<C?l0
0002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`02_l0003o/k>c
ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c00?o
0000oda<C?m<C4`00_l000001omoOgoo0000oiVIVOnIVIWo0000ok>c/ol000002?o<c<`03?l0003o
/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000;o<c<c1_ooool1o`00007o
oooo0Oooool002Cooooo00?o0000ooooooooool00oooool00ol0003o/k>cok>c/`0Gok>c/`03o`00
0?nIVIWoVIVI00[oVIVI0_l0000:ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`0
5_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT0
1OnIVIT00ol0003o/k>cok>c/`0Cok>c/`03o`000?nIVIWoVIVI00?oVIVI00Go0000ogmoOomoOgoo
Ogmoo`000004ofIVIP03o`000?m<C4coC4a<00CoC4a<00?o0000oc<c<olc<c<00olc<c<00ol0003o
C4a<oda<C003oda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01?l0003oVIVIoiVIVOl00004
ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl0
0002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<
oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01?l0
003o/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c
<`06oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVIV@03o`000?nc/k?o0000
00Soc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00002oc<c
<`Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo00?o0000ok>c/onc
/k<05Onc/k<2o`0000coVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03
o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmoO`06ogmoO`03
o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc/k<04onc/k<00ol0003oVIVIoiVIV@03oiVIV@05
o`000?moOgooOgmoogmoOol000001?mVIVH00ol0003oC4a<oda<C003oda<C003o`000?lc<c?o<c<c
00Co<c<c00?o0000oda<C?m<C4`00om<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Co0000
oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c003o`000?nc/k?o/k>c00;o/k>c00Ko
0000oiVIVOnIVIWo0000ogmoOol00002ofIVIP03o`000?m<C4coC4a<00;oC4a<00?o0000oc<c<olc
<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c
/onc/k?o00002?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l00000
0_m<C4`00ol0003o<c<coc<c<`06oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002
oiVIV@03o`000?nc/k?o000000Soc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mV
IVKo0000oda<C?l00002oc<c<`Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo
00?ooooo5onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIV
I_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV0_l00008ogmo
O`03o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc/k<04onc/k<00ol0003oVIVIoiVIV@03oiVI
V@05o`000?moOgooOgmoogmoOol000001?mVIVH00ol0003oC4a<oda<C004oda<C003o`000?lc<c?o
<c<c00?o<c<c00?o0000oda<C?m<C4`01?m<C4`01?l0003oIVIVofIVI_l00003ogmoO`04o`000?nI
VIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`00
0?nIVIWoVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c
<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol0
0009olc<c003o`000?nc/k?o000000;oVIVI00?o0000ogmoOol000000_mVIVH00ol0003oC4a<o`00
0008oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl01Ol0003oVIVIo`000?nc/k?o0000
00Woc<c<00?o0000ok>c/ol000000_nIVIT2o`000005ofIVI_l0003oC4a<oda<C?l000000_lc<c<6
ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03oooooaKo/k>c00?o0000oiVI
VOnIVIT03?nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<
C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00OoOgmo00?o0000oiVI
VOnIVIT01_nIVIT00ol0003o/k>cok>c/`0Dok>c/`03o`000?nIVIWoVIVI00;oVIVI00?o0000ogmo
OomoOgl00_moOgl01Ol0003oIVIVofIVI_mVIVKo000000KoC4a<00?o0000oc<c<olc<c<00olc<c<0
0ol0003oC4a<oda<C004oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01Ol0003oVIVIoiVI
VOnIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000?o
VIVI00?o0000ogmoOol000000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Go0000oda<
C?m<C4coC4a<o`000002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002Oo<
c<`00ol0003o/k>co`000002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<c
oc<c<`06oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVIV@03o`000?nc/k?o
000000Woc<c<00_o0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`000003oc<c
<`Kooooo0Ol00001ooooo`7ooooo000Tooooo`;o00001?oooolEok>c/`;o00003OnIVIT00ol0003o
OgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003o
IVIVofIVIP0<ofIVIP03o`000?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT01OnIVIT00ol0003o
/k>cok>c/`0Eok>c/`03o`000?nIVIWoVIVI00;oVIVI00?o0000ogmoOomoOgl00_moOgl01Ol0003o
IVIVofIVI_mVIVKo000000KoC4a<00?o0000oc<c<olc<c<00olc<c<00ol0003oC4a<oda<C004oda<
C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000?o/k>c00?o
0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000?oVIVI00?o0000ogmoOol00000
0_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIV
IP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`00ol0003o/k>co`000002
oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`08o`000?m<
C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVIV@03o`000?nc/k?o000000Woc<c<00_o0000ok>c
/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`000003oc<c<`Gooooo0_l00002ooooo`00
9?ooool00ol0003oooooooooo`03oooooaCo/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003oOgmo
ogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIV
ofIVIP0;ofIVIP;o00002OmoOgl00ol0003oVIVIoiVIV@05oiVIV@03o`000?nc/k?o/k>c01Go/k>c
00?o0000oiVIVOnIVIT00_nIVIT00ol0003oOgmoogmoO`02ogmoO`05o`000?mVIVKoIVIVofIVI_l0
00001_m<C4`00ol0003o<c<coc<c<`03oc<c<`03o`000?m<C4coC4a<00CoC4a<00Go0000ofIVI_mV
IVKoIVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000onc/k<00ol0003oc<c<olc<c006
olc<c005o`000?nc/k?o/k>cok>c/ol000000onIVIT00ol0003oOgmoo`000002ofIVIP05o`000?m<
C4coC4a<oda<C?l000002?lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o0000ogmoOol0
00000_nIVIT01?l0003o/k>cok>c/ol00009olc<c003o`000?nc/k?o000000;oVIVI00Go0000ogmo
Ool0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00?o0000oda<C?l000000_mVIVH2
o`0000;oVIVI00?o0000ok>c/ol000002Oo<c<`00ol0003o/k>cok>c/`02o`000006ogmoOol0003o
IVIVo`000?m<C4co00001?lc<c<6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003ooooooooo
o`03oooooa?o/k>c00?o0000oiVIVOnIVIT02onIVIT2o`0000[oOgmo00?o0000ofIVI_mVIVH02omV
IVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?mo
Ogl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c01Co/k>c00?o0000oiVIVOnIVIT00_nI
VIT2o`0000?oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C004oda<C003o`000?lc
<c?o<c<c00?o<c<c00?o0000oda<C?m<C4`00om<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo
00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c
/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc
<c<01ol0003oC4a<oda<C?m<C4co0000ofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00002ok>c
/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mV
IVKo000000;oC4a<00?o0000oc<c<olc<c<01olc<c<01ol0003oC4a<o`000?mVIVKo0000ogmoOol0
00000_nIVIT00ol0003o/k>co`000008olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0
003oIVIVo`000?m<C4co00001?lc<c<6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003ooooo
ooooo`03oooooa;o/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`00
0?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`00
0?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT01onIVIT00ol0003o/k>cok>c/`0Cok>c/`03o`00
0?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP02ofIVIP03o`00
0?m<C4coC4a<00CoC4a<00?o0000oc<c<olc<c<00_lc<c<00ol0003oC4a<oda<C004oda<C005o`00
0?mVIVKoIVIVofIVI_l000000omoOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<
00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Go
0000oda<C?m<C4coC4a<o`000008oc<c<`07o`000?m<C4coC4a<oda<C?l0003oIVIVo`000002ogmo
O`04o`000?nIVIWoVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol0
0002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`07o`00
0?m<C4co0000ofIVI_l0003oOgmoo`000002oiVIV@03o`000?nc/k?o000000Soc<c<00co0000ok>c
/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00004oc<c<`Kooooo0Ol00001oooo
o`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo4Onc/k<00ol0003oVIVIoiVIV@0<oiVIV@03
o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003
o`000?mVIVKoIVIV00_oIVIV0_l00009ogmoO`03o`000?nIVIWoVIVI00OoVIVI00?o0000ok>c/onc
/k<05?nc/k<00ol0003oVIVIoiVIV@02oiVIV@03o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mV
IVH00_mVIVH00ol0003oC4a<oda<C004oda<C003o`000?lc<c?o<c<c00?o<c<c00?o0000oda<C?m<
C4`01?m<C4`01?l0003oIVIVofIVI_l00003ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000
olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo0000
0_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo
000000;oOgmo00Co0000oiVIVOnIVIWo00000_nc/k<00ol0003oc<c<olc<c007olc<c00:o`000?nc
/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01olc<c<0
0ol0003oC4a<oda<C002o`000005ogmoOol0003oVIVIoiVIVOl000000_nc/k<00ol0003oc<c<olc<
c005olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl2o`000003oda<C?l0003o<c<c00Co
<c<c1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool@ok>c/`03o`00
0?nIVIWoVIVI00_oVIVI0_l0000:ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`0
5_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT0
1onIVIT00ol0003o/k>cok>c/`0Dok>c/`03o`000?nIVIWoVIVI00;oVIVI00?o0000ogmoOomoOgl0
0_moOgl2o`0000?oIVIV00?o0000oda<C?m<C4`01Om<C4`00ol0003o<c<coc<c<`02oc<c<`03o`00
0?m<C4coC4a<00CoC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVI
VOl000001?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVI
VOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Oo
0000oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00?o0000oiVIVOl000000onc/k<00ol0003o
c<c<olc<c006olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Go0000ogmoOol0003oIVIVo`000002
oda<C003o`000?lc<c?o<c<c00Ko<c<c0_l000001_m<C4co0000ofIVI_l0003oOgmoo`0000;oVIVI
00?o0000ok>c/ol000002?o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0
003oC4a<o`0000Go<c<c1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00ooo
ool?ok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIV
IP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmo
O`08ogmoO`;o00002?nIVIT00ol0003o/k>cok>c/`0Eok>c/`03o`000?nIVIWoVIVI00;oVIVI00?o
0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP02ofIVIP03o`000?m<C4coC4a<00GoC4a<00?o
0000oc<c<olc<c<00_lc<c<00ol0003oC4a<oda<C004oda<C005o`000?mVIVKoIVIVofIVI_l00000
0_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o
/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`0
0ol0003o<c<coc<c<`06oc<c<`07o`000?m<C4coC4a<oda<C?l0003oIVIVo`000002ogmoO`03o`00
0?nIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@05
o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`08o`000?m<C4coC4a<
o`000?mVIVKo0000ogmoOol00002oiVIV@03o`000?nc/k?o000000Soc<c<00co0000ok>c/onc/k?o
0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00005oc<c<`Kooooo0Ol00001ooooo`7ooooo
000Tooooo`03o`000?oooooooooo00?ooooo3_nc/k<00ol0003oVIVIoiVIV@0<oiVIV@03o`000?mo
OgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mV
IVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@07oiVIV@03o`000?nc
/k?o/k>c01Go/k>c00?o0000oiVIVOnIVIT00_nIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mV
IVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01Om<C4`00ol0003o<c<coc<c<`02oc<c<`03o`000?m<
C4coC4a<00CoC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`04o`000?nIVIWoVIVIo`0000Co
/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`03ok>c/`06o`000?nIVIWoVIVIo`00
0?moOgoo00000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000Wo<c<c00Co0000oda<C?m<C4co0000
0_mVIVH01Ol0003oOgmoo`000?nIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o
/k>cok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV00?o0000oda<C?l000002?lc<c<01_l0
003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00Go0000oiVIVOl0003o/k>co`000009olc<c003o`00
0?nc/k?o000000;oVIVI0_l000001OmVIVKo0000oda<C?m<C4co000000Go<c<c1_ooool1o`00007o
oooo0Oooool002Cooooo00?o0000ooooooooool00oooool=ok>c/`03o`000?nIVIWoVIVI00_oVIVI
0_l0000:ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIV
ofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT01onIVIT00ol0003o/k>c
ok>c/`0Eok>c/`03o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIV
ofIVIP02ofIVIP03o`000?m<C4coC4a<00CoC4a<00?o0000oc<c<olc<c<00_lc<c<00ol0003oC4a<
oda<C004oda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01Ol0003oVIVIoiVIVOnIVIWo0000
00Co/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVI
o`0000;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<
C4coC4a<o`0000;oIVIV00Ko0000ogmoOomoOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<
00Ooc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`03o`000?mVIVKo000000;oC4a<00?o
0000oc<c<olc<c<01_lc<c<02?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo00000_nIVIT00ol0
003o/k>co`000009olc<c00;o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l0
00001_lc<c<6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`co/k>c
00?o0000oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV
00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0:ofIVIP03o`000?moOgooOgmo00WoOgmo
00?o0000oiVIVOnIVIT01onIVIT00ol0003o/k>cok>c/`0Eok>c/`03o`000?nIVIWoVIVI00?oVIVI
00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP02ofIVIP03o`000?m<C4coC4a<00CoC4a<
00?o0000oc<c<olc<c<00_lc<c<00ol0003oC4a<oda<C004oda<C005o`000?mVIVKoIVIVofIVI_l0
00000omoOgl01Ol0003oVIVIoiVIVOnIVIWo000000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0
003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo00000om<
C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Ko0000ogmoOomoOgoo
0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl0
0002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02?l0003oC4a<oda<
C?l0003oIVIVo`000?moOgoo00000_nIVIT00ol0003o/k>co`000009olc<c00;o`000?nc/k?o0000
oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l000001_lc<c<6ooooo`7o00000Oooool1ooooo`00
9?ooool2o`0000Cooooo3?nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo
00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00[oIVIV
00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@07oiVIV@03o`000?nc/k?o/k>c01Go/k>c
00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00;oIVIV
00?o0000oda<C?m<C4`01?m<C4`00ol0003o<c<coc<c<`03oc<c<`03o`000?m<C4coC4a<00CoC4a<
00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<
c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000omV
IVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Co0000oda<C?m<C4co00000_mVIVH01_l0003o
OgmoogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01oo<c<`01_l0003o/k>cok>c/ol0
003oVIVIo`0000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`08o`00
0?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVIV@03o`000?nc/k?o000000Soc<c<00?o0000
ok>c/ol000000_nIVIT01ol0003oOgmoo`000?mVIVKo0000oda<C?l000001_lc<c<5ooooo`;o0000
0_ooool002Cooooo00?o0000ooooooooool00oooool;ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o
0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o
0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00SoVIVI00?o
0000ok>c/onc/k<05Onc/k<00ol0003oVIVIoiVIV@03oiVIV@03o`000?moOgooOgmo00;oOgmo00?o
0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C004oda<C003o`000?lc<c?o<c<c00;o<c<c00?o
0000oda<C?m<C4`01Om<C4`01?l0003oIVIVofIVI_l00003ogmoO`05o`000?nIVIWoVIVIoiVIVOl0
00001?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnI
VIWo00000_moOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000
oda<C?m<C4co00000_mVIVH01_l0003oOgmoogmoOol0003oVIVIo`0000?o/k>c00?o0000olc<c?o<
c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`0
0ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV0_l00002oiVIV@03o`000?nc
/k?o000000Woc<c<00_o0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`000007
oc<c<`Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo2Onc/k<2o`00
00goVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<
01OoC4a<00?o0000ofIVI_mVIVH02_mVIVH2o`0000[oOgmo00?o0000oiVIVOnIVIT02?nIVIT00ol0
003o/k>cok>c/`0Dok>c/`;o00001?nIVIT2o`0000CoOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0
003oC4a<oda<C005oda<C003o`000?lc<c?o<c<c00;o<c<c00?o0000oda<C?m<C4`01?m<C4`01Ol0
003oIVIVofIVI_mVIVKo000000?oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<
c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00003ofIVIP05
o`000?m<C4coC4a<oda<C?l000002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP06o`000?moOgoo
Ogmoo`000?nIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c006o`000?nc/k?o/k>co`000?nI
VIWo00000_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00So0000oda<
C?m<C4co0000ofIVI_l0003oOgmoo`0000;oVIVI00?o0000ok>c/ol000002?o<c<`03?l0003o/k>c
ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000Oo<c<c1_ooool1o`00007ooooo
0Oooool002Cooooo00?o0000ooooooooool00oooool9ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o
0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o
0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00WoVIVI00?o
0000ok>c/onc/k<05?nc/k<00ol0003oVIVIoiVIV@03oiVIV@03o`000?moOgooOgmo00?oOgmo00?o
0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C005oda<C005o`000?lc<c?o<c<coc<c<ol00000
1om<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000004ok>c
/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgoo
Ogmoo`0000;oIVIV00?o0000oda<C?m<C4`00_m<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<
C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00009olc<c006
o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o
<c<c00Ko<c<c00So0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000;oVIVI00?o0000ok>c/ol0
00002?o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000Oo
<c<c1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool8ok>c/`03o`00
0?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0<ofIVIP03o`00
0?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`00
0?nIVIWoVIVI00WoVIVI00?o0000ok>c/onc/k<05?nc/k<00ol0003oVIVIoiVIV@03oiVIV@03o`00
0?moOgooOgmo00?oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C005oda<C005o`00
0?lc<c?o<c<coc<c<ol000001om<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Co0000oiVI
VOnIVIWo00001?nc/k<00ol0003oc<c<olc<c006olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000
oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c
00Co0000oda<C?m<C4co00000_mVIVH01_l0003oOgmoogmoOol0003oVIVIo`0000?o/k>c00?o0000
olc<c?o<c<`01_o<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00?o0000ofIVI_l00000
0_m<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<oda<C0;o000000GoOgmoo`000?nI
VIWoVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Goc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl0
0002ogmoO`;o000000?oC4a<o`000?lc<c<01olc<c<6ooooo`7o00000Oooool1ooooo`009?ooool0
0ol0003oooooooooo`03ooooo`Oo/k>c00?o0000oiVIVOnIVIT02_nIVIT2o`0000[oOgmo00?o0000
ofIVI_mVIVH02omVIVH2o`0001OoC4a<0_l0000<ofIVIP;o00002_moOgl00ol0003oVIVIoiVIV@09
oiVIV@03o`000?nc/k?o/k>c01Go/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`02
ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01_m<C4`01Ol0003o<c<coc<c<olc
<c?o000000KoC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`05o`000?nIVIWoVIVIoiVIVOl0
00001?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnI
VIWo00000_moOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000
oda<C?m<C4coC4a<o`000002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o0000
2Oo<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0
003o<c<coc<c<`06oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVIV@03o`00
0?nc/k?o000000Soc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<
C?l00008oc<c<`Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo1_nc
/k<00ol0003oVIVIoiVIV@0:oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omV
IVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02Omo
Ogl00ol0003oVIVIoiVIV@0:oiVIV@03o`000?nc/k?o/k>c01Co/k>c00?o0000oiVIVOnIVIT01?nI
VIT01Ol0003oOgmoogmoOomoOgoo000000GoIVIV00?o0000oda<C?m<C4`01_m<C4`01Ol0003o<c<c
oc<c<olc<c?o000000GoC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo0000
00?oVIVI00?o0000ok>c/onc/k<00_nc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c
00?o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc
<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP03o`000?moOgoo000000;oVIVI
00Co0000ok>c/onc/k?o00002Oo<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00?o0000
ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000
ogmoOol00002oiVIV@03o`000?nc/k?o000000Soc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003o
Ogmoo`000?mVIVKo0000oda<C?l00008oc<c<`03o`000?oooooooooo00?ooooo0Ol00001ooooo`7o
oooo000Tooooo`03o`000?oooooooooo00?ooooo1Onc/k<00ol0003oVIVIoiVIV@0:oiVIV@03o`00
0?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`00
0?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0:oiVIV@03o`00
0?nc/k?o/k>c01Co/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`02ogmoO`03o`00
0?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01_m<C4`01Ol0003o<c<coc<c<olc<c?o000000Ko
C4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc/k<0
0ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_mo
Ogl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00?o0000oda<C?m<C4`0
0_m<C4`01Ol0003oIVIVo`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`01_l0
003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c
<`06oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl01Ol0003oVIVIo`000?nc/k?o0000
00Woc<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<c
oc<c<`06oc<c<`03o`000?oooooooooo00?ooooo0Ol00001ooooo`7ooooo000Iooooo`Go00001_oo
ool00ol0003oooooooooo`03ooooo`Co/k>c00?o0000oiVIVOnIVIT02_nIVIT2o`0000[oOgmo00?o
0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV0_l0
0009ogmoO`;o00003?nIVIT00ol0003o/k>cok>c/`0Dok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o
0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<00GoC4a<0ol0
00000olc<c?o0000oda<C006oda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01?l0003oVIVI
oiVIVOl00005ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003o
VIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<0
1Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c
/ol00009olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl00ol0003oIVIVo`000002oda<
C003o`000?lc<c?o<c<c00Ko<c<c00So0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000;oVIVI
00?o0000ok>c/ol000002Oo<c<`02ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<
C4co000000Wo<c<c00?o0000ooooooooool00oooool1o`00007ooooo0Oooool001Wooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A006ooooo`03o`000?oooooooooo00?ooooo0onc/k<00ol0003oVIVIoiVI
V@0:oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<
C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVI
V@0:oiVIV@03o`000?nc/k?o/k>c01Go/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmo
O`02ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<C4`01Om<C4`01?l0003oC4a<oda<
C?l00008oda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01?l0003oVIVIoiVIVOl00004ok>c
/`03o`000?o<c<coc<c<00Koc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002
ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<
C?m<C4co000000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00009olc<c006
o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o
<c<c00Ko<c<c00So0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000;oVIVI00?o0000ok>c/ol0
00002Oo<c<`02ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co000000Wo<c<c
00?o0000ooooooooool00oooool1o`00007ooooo0Oooool0017ooooo1_l00003ooooo`03oiRHV?lQ
8B7ok^k^00Oooooo0ol00003ooooo`;o/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmo
O`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIV
IP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02_nIVIT00ol0003o/k>cok>c
/`0Eok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIV
IP03ofIVIP03o`000?m<C4coC4a<00KoC4a<0_l00009oda<C005o`000?mVIVKoIVIVofIVI_l00000
0omoOgl01?l0003oVIVIoiVIVOl00005ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc
/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000
oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o0000ogmoOol000000_nI
VIT01?l0003o/k>cok>c/ol00009olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Go0000ogmoOol0
003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH2
o`0000;oVIVI00?o0000ok>c/ol000002Oo<c<`01ol0003o/k>co`000?nIVIWo0000ogmoOol00000
0_mVIVH2o`0000Wo<c<c00?o0000ooooooooool00_ooool3o`0000;ooooo000Kooooo`03oiRHV?lQ
8B7ok^k^00Kooooo00?o0000ooooooooool00oooool00onc/k?o0000oiVIV@0;oiVIV@;o00002_mo
Ogl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omV
IVH00ol0003oOgmoogmoO`08ogmoO`;o00003?nIVIT00ol0003o/k>cok>c/`0Eok>c/`03o`000?nI
VIWoVIVI00CoVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<
C4coC4a<00KoC4a<00Co0000oc<c<olc<c?o00001om<C4`01Ol0003oIVIVofIVI_mVIVKo000000?o
Ogmo00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c
/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo00000om<
C4`00ol0003o<c<coc<c<`06oc<c<`07o`000?m<C4coC4a<oda<C?l0003oIVIVo`000002ogmoO`04
o`000?nIVIWoVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02Ol0003o/k>cok>c/onc/k?o
0000oiVIVOl0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00[o0000oda<C?m<
C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c00<o`00
0?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co00002Olc<c<00ol0003ooooo
ooooo`04ooooo`7o00000Oooool1ooooo`007?ooool00omgMgOoIVIVooooo`05ooooo`03o`000?oo
oooooooo00?ooooo00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mV
IVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?mo
OgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Eok>c/`03o`000?nI
VIWoVIVI00?oVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<
C4coC4a<00KoC4a<00Co0000oc<c<olc<c?o00001om<C4`01Ol0003oIVIVofIVI_mVIVKo000000?o
Ogmo00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c
/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo00000om<
C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00?o0000ofIVI_l000000_mo
Ogl01?l0003oVIVIoiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Wo0000ok>c/onc/k?o
/k>co`000?nIVIWo0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`0:o`000?m<
C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`0
3?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000Wo<c<c00?o0000
ooooooooool01?ooool1o`00007ooooo0Oooool001gooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`03ooooo`coVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0;ofIV
IP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH2o`0000[oOgmo00?o0000oiVI
VOnIVIT02onIVIT00ol0003o/k>cok>c/`0Eok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmo
OomoOgl00_moOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<00SoC4a<0_l00007oda<
C005o`000?mVIVKoIVIVofIVI_l000000omoOgl00ol0003oVIVIoiVIV@02oiVIV@05o`000?nc/k?o
/k>cok>c/ol000001oo<c<`00ol0003o/k>cok>c/`02ok>c/`05o`000?nIVIWoVIVIoiVIVOl00000
0_moOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<
C4coC4a<o`000002ofIVIP06o`000?moOgooOgmoo`000?nIVIWo00000onc/k<00ol0003oc<c<olc<
c005olc<c009o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000?moOgoo000000;oIVIV00Co0000oda<
C?m<C4co00002?lc<c<02?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo00000_nIVIT01?l0003o
/k>cok>c/ol00008olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<
00?o0000oc<c<olc<c<01_lc<c<00ol0003oC4a<ooooo`05ooooo`7o00000Oooool1ooooo`006Ooo
ool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000ooooooooool00oooool<oiVIV@03o`00
0?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`00
0?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`00
0?nc/k?o/k>c01Go/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`03ogmoO`03o`00
0?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`02Om<C4`00ol0003oC4a<oda<C006oda<C005o`00
0?mVIVKoIVIVofIVI_l000000omoOgl01Ol0003oVIVIoiVIVOnIVIWo000000Co/k>c00?o0000olc<
c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co0000
ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`05oc<c<`04o`000?m<C4coC4a<oda<C0;o0000
00GoIVIVo`000?moOgooOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Wo0000ok>c
/onc/k?o/k>co`000?nIVIWo0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`08
o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVIV@03o`000?nc/k?o000000Soc<c<00[o
0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06
oc<c<`03o`000?m<C4co000000Gooooo0Ol00001ooooo`7ooooo000Iooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`03ooooo`_oVIVI00?o0000ogmoOomoOgl02?moOgl0
0ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH03?mVIVH0
0ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<0
0ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH00_mVIVH0
0ol0003oC4a<oda<C00Coda<C004o`000?mVIVKoIVIVo`0000CoOgmo00Go0000oiVIVOnIVIWoVIVI
o`000004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVI
oiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01Olc<c<01Ol0
003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01?l0003o/k>cok>c
/ol00008olc<c009o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000?moOgoo000000;oIVIV00Co0000
oda<C?m<C4co00002?lc<c<02?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo00000_nIVIT00ol0
003o/k>co`000008olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;o
C4a<00?o0000oc<c<olc<c<01_lc<c<00ol0003oC4a<o`000005ooooo`7o00000Oooool1ooooo`00
9?ooool00ol0003oooooooooo`03ooooo`[oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIV
ofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH2o`0000[oOgmo
00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00CoVIVI
00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<01;oC4a<
00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0
003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl0
1?l0003oIVIVofIVI_l00004oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co0000
0_mVIVH01?l0003oOgmoogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Oo0000ok>c
/onc/k?o/k>co`000?nIVIWo000000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c
<`06oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl01Ol0003oVIVIo`000?nc/k?o0000
00Woc<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<c
oc<c<`06oc<c<`03o`000?m<C4co000000Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oo
oooooooo00?ooooo2?nIVIT2o`0000[oOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<
C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVI
V@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmo
O`03ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`04_m<C4`01Ol0003oIVIVofIV
I_mVIVKo000000?oOgmo0_l00002oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`0
1?o<c<`00ol0003o/k>cok>c/`02ok>c/`;o00000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP05
o`000?m<C4coC4a<oda<C?l000002Olc<c<01?l0003oC4a<oda<C?l00002ofIVIP06o`000?moOgoo
Ogmoo`000?nIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`0000;o
VIVI00?o0000ogmoOol000000_mVIVH00ol0003oC4a<o`000009oc<c<`0:o`000?m<C4coC4a<o`00
0?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01oo<c<`02Ol0003o/k>c
o`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00?o0000
oda<C?l000001_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool8oiVI
V@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<
C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl01omoOgl2o`0000goVIVI00?o0000ok>c
/onc/k<05onc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00?oOgmo00?o0000ofIV
I_mVIVH00_mVIVH00ol0003oC4a<oda<C00Boda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl0
1Ol0003oVIVIoiVIVOnIVIWo000000Go/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c
/`02ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00003oda<C003
o`000?lc<c?o<c<c00Oo<c<c00Co0000oda<C?m<C4co00000_mVIVH01_l0003oOgmoogmoOol0003o
VIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`00
0?moOgoo000000;oIVIV00?o0000oda<C?l000002Olc<c<02_l0003oC4a<oda<C?l0003oIVIVo`00
0?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Wo0000ok>c/ol0003oVIVI
o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`03o`000?m<C4co0000
00Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo1onIVIT00ol0003o
OgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003o
IVIVofIVIP0;ofIVIP;o00002OmoOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Oo
/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00;o
IVIV00?o0000oda<C?m<C4`04_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00?o0000oiVI
VOnIVIT00_nIVIT00ol0003o/k>cok>c/`02ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c
/onc/k<00_nc/k<00ol0003oVIVIoiVIV@02oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Co0000
oda<C?m<C4co00002Olc<c<01?l0003oC4a<oda<C?l00002ofIVIP04o`000?moOgooOgmoo`0000;o
VIVI00Co0000ok>c/onc/k?o00002?o<c<`01?l0003o/k>cok>c/ol00003oiVIV@;o00000_mVIVH0
1?l0003oC4a<oda<C?l00008oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVI
o`0000;o/k>c00?o0000olc<c?o<c<`01oo<c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0003o
IVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?l0003oIVIV1_ooool1o`00
007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool5oiVIV@;o00002_moOgl00ol0003o
IVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003o
OgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI0_l0000Hok>c/`;o00001_nIVIT00ol0003o
OgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<C4`04Om<C4`00ol0003o
IVIVofIVIP02ofIVIP05o`000?moOgooOgmoogmoOol000000onIVIT00ol0003o/k>cok>c/`02ok>c
/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo
000000;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<
C4coC4a<oda<C?l000000_mVIVH01_l0003oOgmoogmoOol0003oVIVIo`0000?o/k>c00?o0000olc<
c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000
oda<C?m<C4co00002?lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002
ok>c/`03o`000?o<c<coc<c<00Koc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mV
IVKo0000oda<C?l00009oc<c<`04o`000?m<C4co0000ofIVIPKooooo0Ol00001ooooo`7ooooo000T
ooooo`;o00001?ooool5oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH0
0ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl2
o`0000coVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@06oiVIV@03o`000?moOgoo
Ogmo00;oOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00Boda<C005o`000?mVIVKo
IVIVofIVI_l000001?moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Co/k>c00?o0000olc<c?o<c<`0
1Oo<c<`00ol0003o/k>cok>c/`02ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01?l0003o
IVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002
ofIVIP06o`000?moOgooOgmoo`000?nIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c004o`00
0?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00008oc<c
<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<
c<`01_o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000Wo
<c<c00Go0000oda<C?l0003oIVIVo`000004ooooo`;o00000_ooool002Cooooo00?o0000oooooooo
ool00oooool4oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003o
C4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003o
VIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT01_nIVIT00ol0003o
OgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<C4`04Om<C4`00ol0003o
IVIVofIVIP02ofIVIP05o`000?moOgooOgmoogmoOol000000onIVIT00ol0003o/k>cok>c/`02ok>c
/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo
000000;oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`05oc<c<`05o`000?m<
C4coC4a<oda<C?l000000omVIVH01Ol0003oOgmoo`000?nIVIWo000000?o/k>c00?o0000olc<c?o<
c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<
C?m<C4co00002?lc<c<02?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo00000_nIVIT01?l0003o
/k>cok>c/ol00008olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<
00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<o`000?mVIVKo000000Kooooo0Ol00001ooooo`7o
oooo000Tooooo`03o`000?oooooooooo00?ooooo0_nIVIT2o`0000[oOgmo00?o0000ofIVI_mVIVH0
2omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl0
2?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT0
1_nIVIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<C4`0
4_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Go0000oiVIVOnIVIWoVIVIo`000005ok>c
/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002
ogmoO`05o`000?mVIVKoIVIVofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<
C4coC4a<oda<C?l000000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Wo
c<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<
o`0000So<c<c00Wo0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIT00_l000000onc/k?o
0000olc<c007olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<
00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<o`000?l0003oOgmo00Kooooo0Ol00001ooooo`7o
oooo000Tooooo`03o`000?oooooooooo00?ooooo0_nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`00
0?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0:ofIVIP03o`00
0?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`00
0?nIVIWoVIVI00KoVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIVIP03ofIVIP03o`00
0?m<C4coC4a<01;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`05o`000?nIVIWoVIVIoiVI
VOl000001Onc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVI
VOnIVIWo00000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc
<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>c
ok>c/ol00009olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0
003oC4a<oda<C?l00008oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`00
00;o/k>c00?o0000olc<c?o<c<`01_o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000
ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?l0003o0000ogmoO`06oooo
o`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`03oiVIVOl0003oOgmo00Wo
Ogmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00[o
IVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo
/k>c00?o0000oiVIVOnIVIT01_nIVIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00?o
IVIV00?o0000oda<C?m<C4`04_m<C4`00ol0003oIVIVofIVIP02ofIVIP05o`000?moOgooOgmoogmo
Ool000000onIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c
/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00003ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o
0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C003o`000?mVIVKo000000;oOgmo00Co
0000oiVIVOnIVIWo00000_nc/k<00ol0003oc<c<olc<c007olc<c004o`000?nc/k?o/k>co`0000;o
VIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Go0000oda<
C?m<C4co0000ofIVIP02o`0000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`02_l0003o/k>cok>c
/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000
oda<C?l0003o0000ogmoO`06ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03
ooooo`03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00G
oda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;
oiVIV@03o`000?nc/k?o/k>c01So/k>c00?o0000oiVIVOnIVIT01OnIVIT00ol0003oOgmoogmoO`03
ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<C4`04om<C4`01Ol0003oIVIVofIVI_mV
IVKo000000?oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`02ok>c/`03o`000?o<
c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00003ogmoO`04o`00
0?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co0000
00;oIVIV00?o0000ogmoOol000000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Co0000
ok>c/onc/k?o00000_nIVIT01_l0003oOgmoogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc
<c<01_lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`00
0?o<c<coc<c<00Ooc<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`0
0ol0003o<c<coc<c<`06oc<c<`06o`000?m<C4co0000ofIVI_l0003oOgmo1_ooool1o`00007ooooo
0Oooool002Cooooo00?o0000ooooooooool00oooool:ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o
0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0:ofIVIP;o00002_moOgl00ol0003oVIVIoiVI
V@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c0_l00008oiVIV@03o`000?moOgooOgmo00?oOgmo00?o
0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00Boda<C003o`000?mVIVKoIVIV00;oIVIV00Go
0000ogmoOomoOgooOgmoo`000003oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`0
1?o<c<`00ol0003o/k>cok>c/`02ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01?l0003o
IVIVofIVI_l00004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`00ol0
003oIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`0
1Ol0003o/k>cok>c/ol0003oVIVI00;o000000CoOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<c
oc<c<`07oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o
0000olc<c?o<c<`01oo<c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<
C003o`000?lc<c?o<c<c00Ko<c<c00Oo0000oda<C?l0003oIVIVo`000?moOgoo000000Gooooo0Ol0
0001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo2OmoOgl00ol0003oIVIVofIVIP0;
ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`09
ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<06?nc/k<00ol0003oVIVIoiVIV@06
oiVIV@03o`000?moOgooOgmo00CoOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00B
oda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl00ol0003oVIVIoiVIV@02oiVIV@03o`000?nc
/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`02ok>c/`05o`000?nI
VIWoVIVIoiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00004oda<C003o`000?lc<c?o<c<c00Go
<c<c00?o0000oda<C?m<C4`00_m<C4`00ol0003oIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`00
00?o/k>c00?o0000olc<c?o<c<`01Oo<c<`01ol0003o/k>cok>c/onc/k?o0000oiVIVOl000000_mo
Ogl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00[o0000oda<C?m<C4co0000
ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c007olc<c00;o`000?nc/k?o
0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l000002Olc<c<01ol0003oC4a<o`000?mVIVKo
0000ogmoOol000001Oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool8
ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0;
ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0H
ok>c/`03o`000?nIVIWoVIVI00KoVIVI00?o0000ogmoOomoOgl01?moOgl00ol0003oIVIVofIVIP03
ofIVIP03o`000?m<C4coC4a<01;oC4a<00?o0000ofIVI_mVIVH00_mVIVH01?l0003oOgmoogmoOol0
0004oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c
/`02ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00004oda<C003
o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`00ol0003oIVIVo`000003ogmoO`03
o`000?nIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01_l0003o/k>cok>c/ol0003oVIVI
o`0000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`0:o`000?m<C4co
C4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01oo<c<`02Ol0
003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c
00Oo0000oda<C?l0003oIVIVo`000?moOgoo000000Kooooo0Ol00001ooooo`7ooooo000Tooooo`03
o`000?oooooooooo00?ooooo1omoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01Oo
C4a<00?o0000ofIVI_mVIVH02_mVIVH2o`0000[oOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o
/k>cok>c/`0Gok>c/`;o00002?nIVIT00ol0003oOgmoogmoO`04ogmoO`03o`000?mVIVKoIVIV00?o
IVIV00?o0000oda<C?m<C4`04_m<C4`00ol0003oIVIVofIVIP02ofIVIP05o`000?moOgooOgmoogmo
Ool000000onIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c
/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo00000om<
C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmo
ogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Oo0000ok>c/onc/k?o/k>co`000?nI
VIWo000000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`0:o`000?m<
C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`0
2_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c
00Ko<c<c00Oo0000oda<C?l0003oIVIVo`000?moOgoo000000Kooooo0Ol00001ooooo`7ooooo000T
ooooo`;o00001?ooool6ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`0
0ol0003oIVIVofIVIP0:ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT0
0ol0003o/k>cok>c/`0Hok>c/`03o`000?nIVIWoVIVI00OoVIVI00?o0000ogmoOomoOgl00omoOgl0
0ol0003oIVIVofIVIP04ofIVIP03o`000?m<C4coC4a<01;oC4a<00?o0000ofIVI_mVIVH00_mVIVH0
1Ol0003oOgmoogmoOomoOgoo000000?oVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<
c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`04o`00
0?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co0000
00;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01?l0003o/k>cok>c/ol00008olc<c007o`000?nc
/k?o/k>cok>c/ol0003oVIVIo`000002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc
<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<0
0ol0003oc<c<olc<c006olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`00
00;oC4a<00?o0000oc<c<olc<c<01_lc<c<01ol0003oC4a<o`000?mVIVKo0000ogmoOol000001Ooo
ool2o`0000;ooooo000Tooooo`03o`000?oooooooooo00?ooooo1OmoOgl00ol0003oIVIVofIVIP0;
ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08
ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<06?nc/k<00ol0003oVIVIoiVIV@07
oiVIV@03o`000?moOgooOgmo00CoOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00C
oda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01Ol0003oVIVIoiVIVOnIVIWo000000Ko/k>c
00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`02ok>c/`05o`000?nIVIWoVIVIoiVIVOl0
00000_moOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<
C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o0000
2Oo<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo00000_m<C4`0
0ol0003o<c<coc<c<`06oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`00
00?o/k>c00?o0000olc<c?o<c<`01_o<c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIV
o`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00?o0000oda<C?l000000_mVIVH2o`000003oiVI
VOoooooooooo00Cooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo1?mo
Ogl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<0_l0000<ofIVIP;o00002Omo
Ogl2o`0000goVIVI00?o0000ok>c/onc/k<05onc/k<2o`0000WoVIVI00?o0000ogmoOomoOgl01?mo
Ogl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<01?oC4a<00Go0000ofIVI_mVIVKoIVIV
o`000004ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001Onc/k<00ol0003oc<c<olc<c004olc<c003
o`000?nc/k?o/k>c00?o/k>c00Co0000oiVIVOnIVIWo00000_moOgl2o`0000;oIVIV00Go0000oda<
C?m<C4coC4a<o`000008oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmo
Ool00002oiVIV@04o`000?nc/k?o/k>co`0000Woc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002
ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01olc<c<02_l0003oC4a<oda<C?l0
003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00co0000ok>c
/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00009oc<c<`09o`000?m<C4co0000
ofIVI_l0003oOgmoo`000?nIVIWo000000Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oo
oooooooo00?ooooo0omoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o
0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o
0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@08oiVIV@03o`000?moOgooOgmo00GoOgmo00?o
0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00Coda<C005o`000?mVIVKoIVIVofIVI_l00000
1?moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Go/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o
/k>cok>c/`03ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000003
oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?mo
OgooOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`02?l0003o/k>cok>c/ol0003oVIVI
o`000?moOgoo00000_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`0:o`000?m<C4coC4a<o`000?mV
IVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`03?l0003o/k>cok>c
/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000Wo<c<c00Wo0000oda<C?l0003oIVIV
o`000?moOgoo0000oiVIVOl000001Oooool1o`00007ooooo0Oooool002Cooooo00?o0000oooooooo
ool00oooool2ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003o
IVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o
/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00SoVIVI00?o0000ogmoOomoOgl01OmoOgl00ol0003o
IVIVofIVIP03ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003o
OgmoogmoOomoOgoo000000?oVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c004olc<
c003o`000?nc/k?o/k>c00?o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01Ol0003oIVIVofIVI_mV
IVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV
00Co0000ogmoOomoOgoo00000_nIVIT01?l0003o/k>cok>c/ol00009olc<c006o`000?nc/k?o/k>c
o`000?nIVIWo00000_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00[o
0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c007
olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc
<c<01_lc<c<00ol0003oC4a<oda<C002o`000004ogmoOol0003oVIVIo`0000Kooooo0Ol00001oooo
o`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo00?oOgmoo`000?mVIVH03?mVIVH00ol0003o
C4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl2o`0000go
VIVI00?o0000ok>c/onc/k<05_nc/k<2o`0000_oVIVI00?o0000ogmoOomoOgl01?moOgl00ol0003o
IVIVofIVIP03ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003o
OgmoogmoOomoOgoo000000?oVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c004olc<
c003o`000?nc/k?o/k>c00;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`04o`000?mVIVKo
IVIVo`0000CoC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV
00Go0000ogmoOol0003o0000oiVIV@02o`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01ol0003o
/k>cok>c/onc/k?o0000oiVIVOl000000_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o
<c<c00Ko<c<c00_o0000oda<C?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c
/`03o`000?o<c<coc<c<00Ooc<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00000
0_m<C4`00ol0003o<c<coc<c<`06oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo
000000Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo00?o0000ofIV
I_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmo
OomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVI
VOnIVIT02_nIVIT00ol0003oOgmoogmoO`04ogmoO`03o`000?mVIVKoIVIV00CoIVIV00?o0000oda<
C?m<C4`04om<C4`00ol0003oIVIVofIVIP02ofIVIP05o`000?moOgooOgmoogmoOol000000onIVIT0
0ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00_nc/k<0
1Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<c
oc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01Ol0
003o/k>cok>c/onc/k?o000000Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT01_l0003oOgmoogmo
Ool0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02ol0003oC4a<oda<C?m<C4co0000
ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`02Ol0003o/k>c
o`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Wo0000
oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl000001_ooool1o`00007ooooo0Oooool002Cooooo
00?o0000ooooooooool00oooool=ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH0
2omVIVH2o`0000[oOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`00
0?nIVIWoVIVI00[oVIVI00?o0000ogmoOomoOgl01?moOgl00ol0003oIVIVofIVIP04ofIVIP03o`00
0?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000?o
VIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00;o
/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000
oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o0000ogmoOol000000_nI
VIT00ol0003o/k>cok>c/`02ok>c/`03o`000?o<c<coc<c<00Goc<c<00Oo0000ok>c/onc/k?o/k>c
o`000?nIVIWo000000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0;
o`000?m<C4coC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<
olc<c007olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000
oc<c<olc<c<01olc<c<2o`000004ofIVI_l0003oOgmoogmoO`;o000000?o/k>cooooooooool01?oo
ool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool<ofIVIP03o`000?m<C4co
C4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWo
VIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0:oiVIV@03o`000?moOgoo
Ogmo00CoOgmo00?o0000ofIVI_mVIVH01?mVIVH00ol0003oC4a<oda<C00Coda<C003o`000?mVIVKo
IVIV00;oIVIV00Go0000ogmoOomoOgooOgmoo`000004oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o
0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`04o`000?nIVIWoVIVIo`0000?oOgmo
00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`03o`000?m<C4coC4a<00;o
C4a<00Ko0000ofIVI_mVIVKo0000ogmoOol00002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<
c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co
00002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<0
0ol0003oc<c<olc<c006olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`00
00;oC4a<00?o0000oc<c<olc<c<01_lc<c<02_l0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVI
o`000?nc/k<6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`_oIVIV
00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?moOgooOgmo00SoOgmo
00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00[oVIVI
00?o0000ogmoOomoOgl01OmoOgl00ol0003oIVIVofIVIP04ofIVIP03o`000?m<C4coC4a<01?oC4a<
00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000CoVIVI00?o0000ok>c/onc
/k<00onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Co0000oiVIVOnI
VIWo00000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<0
0ol0003oC4a<oda<C002oda<C006o`000?mVIVKoIVIVo`000?moOgoo00000_nIVIT01Ol0003o/k>c
ok>c/onc/k?o000000Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIV
IP04o`000?m<C4coC4a<o`0000So<c<c00Co0000oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`00
0?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`00
0?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00[o0000oda<C?l0003oIVIV
o`000?moOgoo0000oiVIVOl0003o/k>c1_ooool1o`00007ooooo0Oooool002Cooooo0_l00004oooo
o`[oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP;o00002_moOgl00ol0
003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0
003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV00CoIVIV00?o0000oda<C?m<C4`04om<C4`00ol0
003oIVIVofIVIP02ofIVIP05o`000?moOgooOgmoogmoOol000001?nIVIT00ol0003o/k>cok>c/`03
ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00onc/k<01Ol0003oVIVIoiVIVOnI
VIWo000000;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`03o`00
0?m<C4coC4a<00;oC4a<00Ko0000ofIVI_mVIVKo0000ogmoOol00002oiVIV@05o`000?nc/k?o/k>c
ok>c/ol000002?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV00Go
0000oda<C?m<C4coC4a<o`000008oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003o
VIVIo`0000;o/k>c00?o0000olc<c?o<c<`01oo<c<`01ol0003o/k>co`000?nIVIWo0000ogmoOol0
00000_mVIVH00ol0003oC4a<o`000009oc<c<`;o00000_mVIVH2o`000005oiVIVOl0003o/k>cok>c
/ol000001?ooool2o`0000;ooooo000Tooooo`03o`000?oooooooooo00?ooooo2OmVIVH00ol0003o
C4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003o
VIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003o
OgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV00GoIVIV00?o0000oda<C?m<C4`04_m<C4`2o`0000?o
IVIV00?o0000ogmoOomoOgl00_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Ko/k>c00?o0000olc<
c?o<c<`00oo<c<`00ol0003o/k>cok>c/`03ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl0
1Ol0003oIVIVofIVI_mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<
C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01Ol0003o/k>cok>c/onc/k?o0000
00Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4co
C4a<o`0000So<c<c00Co0000oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o
/k>c00?o0000olc<c?o<c<`01_o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIV
I_l0003oC4a<o`0000[o<c<c0_l000001_mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000
ooooooooool00oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool8ofIV
IP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmoO`07ogmo
O`;o00003OnIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00[oVIVI00?o0000ogmo
OomoOgl01OmoOgl00ol0003oIVIVofIVIP05ofIVIP03o`000?m<C4coC4a<01;oC4a<00?o0000ofIV
I_mVIVH00_mVIVH00ol0003oOgmoogmoO`02ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001_nc/k<0
0ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c00?o/k>c00Go0000oiVIVOnIVIWoVIVIo`00
0002ogmoO`05o`000?mVIVKoIVIVofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`00
0?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@05o`000?nc/k?o/k>c
ok>c/ol000002?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV00Co
0000oda<C?m<C4co00002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP05o`000?moOgoo0000oiVI
VOl000000_nc/k<00ol0003oc<c<olc<c006olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmo
Ool0003oIVIVo`000?m<C4co00002_lc<c<2o`000006ofIVI_l0003oOgmoo`000?nIVIWo00000_nc
/k<00ol0003oooooooooo`03ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03
ooooo`OoIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP;o00002OmoOgl0
0ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02_nIVIT0
0ol0003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV00GoIVIV00?o0000oda<C?m<C4`04_m<C4`0
0ol0003oIVIVofIVIP02ofIVIP03o`000?moOgooOgmo00;oOgmo00Go0000oiVIVOnIVIWoVIVIo`00
0006ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00onc/k<01Ol0003oVIVIoiVI
VOnIVIWo000000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go
<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Go0000
ok>c/onc/k?o/k>co`000008olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Ko0000ogmoOomoOgoo
0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c00?o0000oda<C?l000000_mVIVH01Ol0
003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`01Ol0003o/k>co`000?nI
VIWo000000;oOgmo0_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Co0000oda<C?l0003oIVIV
0_l00002oiVIV@03o`000?nc/k?o000000Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oo
oooooooo00?ooooo1_mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o
0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@;o00006?nc/k<2o`0000coVIVI00?o
0000ogmoOomoOgl01OmoOgl00ol0003oIVIVofIVIP05ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o
0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000CoVIVI00?o0000ok>c/onc/k<0
0onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Go0000oiVIVOnIVIWo
VIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0
003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01Ol0003o/k>cok>c
/onc/k?o000000Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIVIP04
o`000?m<C4coC4a<o`0000Wo<c<c00?o0000oda<C?l000000_mVIVH01Ol0003oOgmoo`000?nIVIWo
000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0003o
IVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4co0000ofIVIP02o`00
0005oiVIVOl0003o/k>cok>c/ol000001_ooool1o`00007ooooo0Oooool002Cooooo00?o0000oooo
ooooool00oooool5ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0
003oOgmoogmoO`08ogmoO`;o00003?nIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI
00_oVIVI00?o0000ogmoOomoOgl01_moOgl00ol0003oIVIVofIVIP05ofIVIP03o`000?m<C4coC4a<
01?oC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000CoVIVI00?o0000
ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Go0000
oiVIVOnIVIWoVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<0
1_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01Ol0
003o/k>cok>c/onc/k?o000000Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`00
0002ofIVIP04o`000?m<C4coC4a<o`0000Wo<c<c00?o0000oda<C?l000000_mVIVH01Ol0003oOgmo
o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`02Ol0003o/k>co`000?nIVIWo0000
ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4co0000
ofIVIP02o`000005oiVIVOl0003o/k>cok>c/ol000001_ooool1o`00007ooooo0Oooool002Cooooo
00?o0000ooooooooool00oooool4ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH0
2omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<0
5onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH0
1?mVIVH2o`0001GoC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000Co
VIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o
/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000
oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo0000
0_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Wo0000ok>c/onc/k?o/k>co`000?nIVIWo
0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`03o`000?m<C4co000000;oIVIV
00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00?o0000ok>c/ol0
00000_nIVIT2o`000005ofIVI_l0003oC4a<oda<C?l000002Olc<c<01_l0003oC4a<o`000?mVIVKo
0000ogmoO`;o00000_nc/k<00ol0003oc<c<ooooo`05ooooo`7o00000Oooool1ooooo`009?ooool0
0ol0003oooooooooo`03ooooo`?oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;
ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0G
ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl01_moOgl00ol0003oIVIVofIVIP04
ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH00_mVIVH00ol0003oOgmoogmoO`02
ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001_nc/k<00ol0003oc<c<olc<c003olc<c003o`000?nc
/k?o/k>c00?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`04o`000?mVIVKoIVIVo`0000Co
C4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`00
00;oOgmo00Co0000oiVIVOnIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o
/k>cok>c/ol000000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c
00Co0000oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<
c?o<c<`01_o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003
o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4co0000ofIVIP02o`000006oiVIVOl0003o/k>c
ok>c/ol0003oc<c<1_ooool1o`00007ooooo0Oooool001Wooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP06ooooo`03o`000?oooooooooo00?ooooo0_mVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mV
IVKoIVIV00[oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc
/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`06ogmoO`03o`000?mV
IVKoIVIV00GoIVIV00?o0000oda<C?m<C4`05?m<C4`00ol0003oIVIVofIVIP02ofIVIP03o`000?mo
OgooOgmo00;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000006ok>c/`03o`000?o<c<coc<c<00?oc<c<
00?o0000ok>c/onc/k<00onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Co0000ofIVI_mV
IVKo00001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIV
I_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go
0000ok>c/onc/k?o/k>co`000002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co
00002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<0
0ol0003oc<c<olc<c006olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`00
00;oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?l0003oIVIV00;o000000KoVIVI
o`000?nc/k?o/k>co`000?o<c<`6ooooo`7o00000Oooool1ooooo`006Oooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Kooooo00?o0000ooooooooool00oooool00omVIVKo0000oda<C00Hoda<C003o`00
0?mVIVKoIVIV00[oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`00
0?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`06ogmoO`03o`00
0?mVIVKoIVIV00CoIVIV00?o0000oda<C?m<C4`05?m<C4`00ol0003oIVIVofIVIP02ofIVIP03o`00
0?moOgooOgmo00;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000007ok>c/`03o`000?o<c<coc<c<00?o
c<c<00?o0000ok>c/onc/k<00onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Go0000ofIV
I_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go<c<c00Go0000oda<C?m<C4coC4a<o`00
0003ofIVIP03o`000?moOgoo000000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c009o`00
0?nc/k?o/k>cok>c/ol0003oVIVIo`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002Olc
<c<01?l0003oC4a<oda<C?l00002ofIVIP07o`000?moOgoo0000oiVIVOl0003o/k>co`000009olc<
c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc
<c<01_lc<c<00ol0003oC4a<oda<C002o`000004ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<
c?ooool01Oooool1o`00007ooooo0Oooool001Wooooo00Go410@oooooooooooooooooa0@4006oooo
o`03o`000?oooooooooo00?ooooo00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0;ofIV
IP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c
/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl01_moOgl00ol0003oIVIVofIVIP05ofIV
IP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH00_mVIVH00ol0003oOgmoogmoO`02ogmo
O`05o`000?nIVIWoVIVIoiVIVOl000001_nc/k<00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o
/k>c00?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<
00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomo
Ogoo00000_nIVIT01?l0003o/k>cok>c/ol00008olc<c005o`000?nc/k?o/k>cok>c/ol000000_nI
VIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Co0000oda<C?m<C4co
00000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`02Ol0
003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c
00Go0000oda<C?m<C4co0000ofIVIP02o`000005oiVIVOl0003o/k>cok>c/ol000000_o<c<`6oooo
o`7o00000Oooool1ooooo`006Oooool01Ol0003ooooooooooooooooo000000Kooooo0ol00003oooo
oaWoC4a<00?o0000ofIVI_mVIVH02_mVIVH2o`0000[oOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0
003o/k>cok>c/`0Fok>c/`;o00003?nIVIT2o`0000SoOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0
003oC4a<oda<C00Coda<C0;o00001?mVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI
00;oVIVI00?o0000ok>c/onc/k<00onc/k<2o`0000Goc<c<00?o0000ok>c/onc/k<00onc/k<01Ol0
003oVIVIoiVIVOnIVIWo000000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000003oda<C0;o00001olc
<c<01Ol0003oC4a<oda<C?m<C4co000000?oIVIV00?o0000ogmoOol000000_nIVIT01Ol0003o/k>c
ok>c/onc/k?o000000Soc<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo00Co0000
ofIVI_mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV
00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00[o0000ok>c/onc
/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`05o`00
0?m<C4coC4a<o`000?mVIVH00_l000001OnIVIWo0000ok>c/onc/k?o000000;oc<c<1?ooool3o`00
00;ooooo000Iooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`03oooo
oaSoC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI
00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo
00OoOgmo00?o0000ofIVI_mVIVH01_mVIVH00ol0003oC4a<oda<C00Coda<C003o`000?mVIVKoIVIV
00?oIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c
00?o/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`05o`000?nIVIWoVIVI
oiVIVOl000000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc
<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01Ol0003o
/k>cok>c/onc/k?o000000Soc<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo00Co
0000ofIVI_mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;o
IVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00[o0000ok>c
/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`05
o`000?m<C4coC4a<o`000?mVIVH00_l000001OnIVIWo0000ok>c/onc/k?o000000;oc<c<1_ooool1
o`00007ooooo0Oooool001Wooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooo
oooo00?ooooo5om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000
oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000
ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP05ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000
ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000
ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Go0000
oiVIVOnIVIWoVIVIo`000002ogmoO`05o`000?mVIVKoIVIVofIVI_l000000om<C4`00ol0003o<c<c
oc<c<`06oc<c<`03o`000?m<C4coC4a<00;oC4a<00Ko0000ofIVI_mVIVKo0000ogmoOol00002oiVI
V@05o`000?nc/k?o/k>cok>c/ol000002Oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?mo
Ogoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP05
o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c009o`000?nc/k?o0000
oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<03?l0003oC4a<
oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000?oc<c<1_ooool1o`00007ooooo
0Oooool001Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00?ooooo
5_m<C4`00ol0003oIVIVofIVIP0:ofIVIP;o00002_moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`00
0?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`00
0?mVIVKoIVIV00GoIVIV00?o0000oda<C?m<C4`05?m<C4`00ol0003oIVIVofIVIP03ofIVIP05o`00
0?moOgooOgmoogmoOol000001?nIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00?o
c<c<00?o0000ok>c/onc/k<01?nc/k<01?l0003oVIVIoiVIVOl00003ogmoO`04o`000?mVIVKoIVIV
o`0000CoC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co
0000ogmoOomoOgoo00000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Oo0000ok>c/onc
/k?o/k>co`000?nIVIWo000000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07
oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl00ol0003oVIVIo`000002ok>c/`03o`00
0?o<c<coc<c<00Ooc<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`0
0ol0003o<c<coc<c<`06oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`00
0?nc/k?o00000oo<c<`6ooooo`7o00000Oooool1ooooo`006Oooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Kooooo00?o0000ooooooooool00ooooolEoda<C003o`000?mVIVKoIVIV00[oIVIV00?o0000
ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000
oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00GoIVIV00?o0000
oda<C?m<C4`05?m<C4`00ol0003oIVIVofIVIP04ofIVIP05o`000?moOgooOgmoogmoOol000001?nI
VIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<01?nc
/k<01?l0003oVIVIoiVIVOl00003ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc
<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT0
1Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo000000;o
Ogmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`06o`000?m<C4coC4a<o`00
0?mVIVKo00000_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Wo0000
ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0<
o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00000oo<c<`6ooooo`7o
00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03oooooaCoC4a<00?o0000ofIVI_mVIVH0
2omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<0
5_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH0
1_mVIVH00ol0003oC4a<oda<C00Coda<C003o`000?mVIVKoIVIV00CoIVIV00Go0000ogmoOomoOgoo
Ogmoo`000004oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003o
/k>cok>c/`04ok>c/`04o`000?nIVIWoVIVIo`0000?oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`0
0ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmo
Ool00002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01ol0003o/k>cok>c/onc/k?o0000
oiVIVOl000000_moOgl00ol0003oIVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000
oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`0
1oo<c<`00ol0003o/k>co`000002oiVIV@;o000000GoIVIVo`000?m<C4coC4a<o`000008oc<c<`0<
o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00001?o<c<`6ooooo`7o
00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03oooooa;oC4a<0_l0000<ofIVIP;o0000
2OmoOgl2o`0000goVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`00
0?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH01_mVIVH00ol0003oC4a<oda<C00Doda<C003o`00
0?mVIVKoIVIV00?oIVIV00?o0000ogmoOomoOgl00_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Oo
/k>c00?o0000olc<c?o<c<`00_o<c<`00ol0003o/k>cok>c/`04ok>c/`05o`000?nIVIWoVIVIoiVI
VOl000000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000CoC4a<00?o0000oc<c<olc<c<01Olc<c<0
0ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo0000
0_nc/k<00ol0003oc<c<olc<c007olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Ko0000ogmoOomo
Ogoo0000ofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Ko0000oda<C?m<C4co0000ofIV
I_l00002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02_l0003o/k>c
ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00co
0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00004olc<c0Kooooo0Ol0
0001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo4Om<C4`00ol0003oIVIVofIVIP0;
ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0F
ok>c/`03o`000?nIVIWoVIVI00_oVIVI0_l00009ogmoO`03o`000?mVIVKoIVIV00OoIVIV00?o0000
oda<C?m<C4`05?m<C4`00ol0003oIVIVofIVIP03ofIVIP05o`000?moOgooOgmoogmoOol000001?nI
VIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<01?nc
/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000003oda<C003
o`000?lc<c?o<c<c00Ko<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmo
O`04o`000?nIVIWoVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01oo<c<`01?l0003o/k>cok>c/ol0
0002oiVIV@06o`000?moOgooOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`07oc<c<`06
o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<co
c<c<00Koc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0
003o<c<coc<c<`06oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc
/k?o00001?o<c<`6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03oooooa3o
C4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00_o
VIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00So
Ogmo00?o0000ofIVI_mVIVH01omVIVH00ol0003oC4a<oda<C00Doda<C003o`000?mVIVKoIVIV00?o
IVIV00?o0000ogmoOomoOgl00_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Oo/k>c00?o0000olc<
c?o<c<`00_o<c<`00ol0003o/k>cok>c/`04ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl0
1Ol0003oIVIVofIVI_mVIVKo000000CoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<
C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003o
c<c<olc<c006olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Ko0000ogmoOomoOgoo0000ofIVI_l0
0003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`03
o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`01ol0003o/k>co`000?nIVIWo0000
ogmoOol000000_mVIVH00ol0003oC4a<o`000008oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000
ogmoOol0003oVIVIo`000?nc/k?o00001Oo<c<`6ooooo`7o00000Oooool1ooooo`009?ooool00ol0
003oooooooooo`03ooooo`ooC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmo
O`;o00003OnIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmo
OomoOgl02?moOgl00ol0003oIVIVofIVIP07ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIV
I_mVIVH00omVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c
/onc/k<01?nc/k<00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c00Co/k>c00Co0000oiVI
VOnIVIWo00000omoOgl01Ol0003oIVIVofIVI_mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc
<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo
00000onc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Ko0000ogmo
OomoOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Ko0000oda<C?m<C4co0000
ofIVI_l00002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02_l0003o
/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c
00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00005olc<c0Kooooo
0Ol00001ooooo`7ooooo000Tooooo`;o00001?ooool>oda<C003o`000?mVIVKoIVIV00coIVIV00?o
0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o
0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00OoIVIV00?o
0000oda<C?m<C4`04om<C4`00ol0003oIVIVofIVIP03ofIVIP03o`000?moOgooOgmo00?oOgmo00?o
0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o
0000ok>c/onc/k<01?nc/k<01?l0003oVIVIoiVIVOl00003ogmoO`04o`000?mVIVKoIVIVo`0000Co
C4a<00?o0000oc<c<olc<c<01_lc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`00
00;oOgmo00Co0000oiVIVOnIVIWo00000_nc/k<00ol0003oc<c<olc<c007olc<c004o`000?nc/k?o
/k>co`0000;oVIVI00Ko0000ogmoOomoOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo
<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000
olc<c?o<c<`01_o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<
C003o`000?lc<c?o<c<c00Ko<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo
0000ok>c/ol00005olc<c0Gooooo0_l00002ooooo`009?ooool00ol0003oooooooooo`03ooooo`go
C4a<00?o0000ofIVI_mVIVH02omVIVH2o`0000[oOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o
/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003o
IVIVofIVIP07ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003o
OgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003o
c<c<olc<c003olc<c003o`000?nc/k?o/k>c00Co/k>c00Co0000oiVIVOnIVIWo00000omoOgl01Ol0
003oIVIVofIVI_mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<00ol0003oC4a<oda<C002
oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<
olc<c006olc<c007o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000002ogmoO`03o`000?mVIVKo0000
00;oC4a<00?o0000oc<c<olc<c<01olc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00?o
0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c005o`000?nc/k?o0000oiVIVOl00000
0_moOgl2o`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`00
0?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00?oc<c<1_ooool1o`00007ooooo0Ooo
ool002Cooooo00?o0000ooooooooool00oooool<oda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000
ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000
oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00OoIVIV00?o0000
oda<C?m<C4`05?m<C4`00ol0003oIVIVofIVIP03ofIVIP03o`000?moOgooOgmo00;oOgmo00?o0000
oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`05ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o0000
ok>c/onc/k<01?nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Co0000ofIVI_mVIVKo0000
1?m<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003o
OgmoogmoOol00002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01Ol0003o/k>cok>c/onc
/k?o000000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`08o`00
0?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVIV@03o`000?nc/k?o000000[oc<c<00Wo0000
ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0<
o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00001_o<c<`6ooooo`7o
00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`_oC4a<00?o0000ofIVI_mVIVH0
3?mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<0
5_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH0
1omVIVH00ol0003oC4a<oda<C00Eoda<C003o`000?mVIVKoIVIV00?oIVIV00?o0000ogmoOomoOgl0
0_moOgl00ol0003oVIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c00Go/k>c00?o0000olc<c?o<c<`0
0_o<c<`00ol0003o/k>cok>c/`04ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01?l0003o
IVIVofIVI_l00004oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002
ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c005o`00
0?nc/k?o/k>cok>c/ol000000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`00
00Wo<c<c00So0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000;oVIVI00?o0000ok>c/ol00000
2_o<c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o
<c<c00Ko<c<c00?o0000oda<C?l000000_mVIVH01ol0003oOgmoo`000?nIVIWo0000ok>c/ol00000
1_o<c<`6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`[oC4a<00?o
0000ofIVI_mVIVH02omVIVH2o`0000[oOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c
/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIV
IP08ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmo
O`02ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<
c002olc<c003o`000?nc/k?o/k>c00Co/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`04o`00
0?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co0000
00;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Go
0000ok>c/onc/k?o/k>co`000002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co
00002Olc<c<01?l0003oC4a<oda<C?l00002ofIVIP;o00000_nIVIT01?l0003o/k>cok>c/ol00009
olc<c003o`000?nc/k?o000000;oVIVI0_l000001OmVIVKo0000oda<C?m<C4co000000So<c<c00co
0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00007olc<c0Kooooo0Ol0
0001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo2Om<C4`00ol0003oIVIVofIVIP0;
ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0F
ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl2o`0000[oIVIV00?o0000
oda<C?m<C4`05?m<C4`00ol0003oIVIVofIVIP03ofIVIP03o`000?moOgooOgmo00;oOgmo00?o0000
oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`06ok>c/`05o`000?o<c<coc<c<olc<c?l000001_nc
/k<00ol0003oVIVIoiVIV@02oiVIV@04o`000?moOgooOgmoo`0000?oIVIV00?o0000oda<C?m<C4`0
0_m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo
00000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c
/onc/k?o/k>co`000002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc
<c<2o`0000;oC4a<00Go0000ofIVI_l0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000So
c<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<c
oc<c<`06oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o0000
1oo<c<`6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`SoC4a<00?o
0000ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmoO`07ogmoO`;o00003OnIVIT00ol0003o/k>cok>c
/`0Gok>c/`03o`000?nIVIWoVIVI00[oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIV
IP08ofIVIP03o`000?m<C4coC4a<01GoC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmo
O`02ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01_nc/k<01Ol0003oc<c<olc<
c?o<c<co000000Ko/k>c00?o0000oiVIVOnIVIT00_nIVIT01?l0003oOgmoogmoOol00003ofIVIP03
o`000?m<C4coC4a<00;oC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004
o`000?mVIVKoIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006
olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<
C4coC4a<o`0000So<c<c00Wo0000oda<C?m<C4coC4a<o`000?mVIVKo0000ogmoOol000000_nIVIT0
1?l0003o/k>cok>c/ol00008olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIV
o`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo
0000oiVIVOl0003o/k>co`0000Ooc<c<1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000oooo
ooooool00oooool7oda<C003o`000?mVIVKoIVIV00_oIVIV0_l00009ogmoO`03o`000?nIVIWoVIVI
00coVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0:oiVIV@03o`000?moOgooOgmo
00WoOgmo00?o0000ofIVI_mVIVH02?mVIVH00ol0003oC4a<oda<C00Eoda<C003o`000?mVIVKoIVIV
00?oIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c
00Go/k>c00Go0000olc<c?o<c<coc<c<o`000006ok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000
ogmoOomoOgooOgmoo`000002ofIVIP03o`000?m<C4coC4a<00;oC4a<00?o0000oc<c<olc<c<01Olc
<c<00ol0003oC4a<oda<C003oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo
00000_nc/k<00ol0003oc<c<olc<c007olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Ko0000ogmo
OomoOgoo0000ofIVI_l00003oda<C003o`000?lc<c?o<c<c00Go<c<c00Wo0000oda<C?m<C4coC4a<
o`000?mVIVKo0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00008olc<c004o`000?nc/k?o
/k>cok>c/`;o000000GoOgmoo`000?mVIVKoIVIVo`000002oda<C003o`000?lc<c?o<c<c00Go<c<c
00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`;o000000?o/k>co`000?o<c<`01oo<c<`6oooo
o`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`KoC4a<00?o0000ofIVI_mV
IVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI0_l0000Hok>c/`;o
00003?nIVIT00ol0003oOgmoogmoO`08ogmoO`;o00002_mVIVH00ol0003oC4a<oda<C00Eoda<C003
o`000?mVIVKoIVIV00?oIVIV00?o0000ogmoOomoOgl00omoOgl00ol0003oVIVIoiVIV@02oiVIV@03
o`000?nc/k?o/k>c00Go/k>c00Go0000olc<c?o<c<coc<c<o`000007ok>c/`05o`000?nIVIWoVIVI
oiVIVOl000000omoOgl01Ol0003oIVIVofIVI_mVIVKo000000CoC4a<00?o0000oc<c<olc<c<01Olc
<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo
00000onc/k<00ol0003oc<c<olc<c006olc<c006o`000?nc/k?o/k>cok>c/ol0003oVIVI0_l00000
1OmoOgoo0000ofIVI_mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02Ol0003oC4a<oda<
C?m<C4co0000ofIVI_l0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00[o0000
ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c
<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00002?o<c<`6oooo
o`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`GoC4a<00?o0000ofIVI_mV
IVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`;o00003?nIVIT00ol0003o/k>cok>c/`0Gok>c/`03
o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0:ofIVIP03
o`000?m<C4coC4a<01GoC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`02ogmoO`03
o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<01Onc/k<01Ol0003oc<c<olc<c?o<c<co0000
00Ko/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000?oIVIV00?o0000
oda<C?m<C4`00_m<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Co0000
ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<
00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo00000_m<C4`0
0ol0003o<c<coc<c<`06oc<c<`09o`000?m<C4coC4a<oda<C?l0003oIVIVo`000?moOgoo000000;o
VIVI00Co0000ok>c/onc/k?o00002?o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000
ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00co0000oda<C?m<C4co0000ofIVI_l0003o
Ogmoo`000?nIVIWo0000ok>c/ol00008olc<c003o`000?oooooooooo00?ooooo0Ol00001ooooo`7o
oooo000Tooooo`;o00001?ooool4oda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl0
2?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT0
2onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00[oIVIV00?o0000oda<C?m<C4`0
5Om<C4`00ol0003oIVIVofIVIP03ofIVIP03o`000?moOgooOgmo00?oOgmo00?o0000oiVIVOnIVIT0
0_nIVIT00ol0003o/k>cok>c/`05ok>c/`05o`000?o<c<coc<c<olc<c?l000001onc/k<01Ol0003o
VIVIoiVIVOnIVIWo000000?oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o
<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nI
VIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01ol0003o/k>cok>c/onc/k?o0000oiVI
VOl000000_moOgl01?l0003oIVIVofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Oo0000
oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<
olc<c006olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl2o`0000;oC4a<00?o0000oc<c
<olc<c<01_lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03
o`000?o<c<coc<c<00Koc<c<00?o0000ooooooooool00_ooool2o`0000;ooooo000Tooooo`03o`00
0?oooooooooo00?ooooo0om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo
00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00_oVIVI
00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<01GoC4a<
00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00;oVIVI
00?o0000ok>c/onc/k<01_nc/k<01?l0003oc<c<olc<c?l00007ok>c/`03o`000?nIVIWoVIVI00;o
VIVI00Co0000ogmoOomoOgoo00000omVIVH00ol0003oC4a<oda<C002oda<C003o`000?lc<c?o<c<c
00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Co0000
oiVIVOnIVIWo00000_nc/k<00ol0003oc<c<olc<c007olc<c007o`000?nc/k?o/k>cok>c/ol0003o
VIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0
003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00?o0000ok>c/ol000002Oo<c<`0
2_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c
00Ko<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00008olc<
c003o`000?oooooooooo00Cooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?o
oooo0om<C4`00ol0003oIVIVofIVIP0:ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnI
VIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomo
Ogl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01GoC4a<00?o0000ofIVI_mV
IVH00omVIVH00ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc
/k<01_nc/k<01?l0003oc<c<olc<c?l00007ok>c/`03o`000?nIVIWoVIVI00;oVIVI00Co0000ogmo
OomoOgoo00000omVIVH00ol0003oC4a<oda<C002oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000
oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo0000
0_nc/k<00ol0003oc<c<olc<c007olc<c007o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000002ogmo
O`04o`000?mVIVKoIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l0
0002ofIVIP03o`000?moOgoo000000;oVIVI00?o0000ok>c/ol000002Oo<c<`02_l0003o/k>cok>c
/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00co0000
oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00008olc<c003o`000?oooooo
oooo00Cooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo0_m<C4`00ol0
003oIVIVofIVIP0:ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0
003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl01omoOgl00ol0
003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0
003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<01_nc/k<01?l0
003oc<c<olc<c?l00007ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01?l0003oIVIVofIV
I_l00005oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIV
ofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0
003o/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l0
0008oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH00ol0003oOgmoo`000002oiVIV@03o`00
0?nc/k?o000000Woc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<
C4`00ol0003o<c<coc<c<`05oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Oo0000ogmoOol0003o
VIVIo`000?nc/k?o000000Soc<c<00?o0000ooooooooool01?ooool1o`00007ooooo0Oooool002Co
oooo00?o0000ooooooooool00oooool00om<C4co0000ofIVIP0<ofIVIP03o`000?moOgooOgmo00So
Ogmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00co
VIVI00?o0000ogmoOomoOgl01omoOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<01Co
C4a<00?o0000ofIVI_mVIVH01?mVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00?o
VIVI00?o0000ok>c/onc/k<01_nc/k<01?l0003oc<c<olc<c?l00007ok>c/`03o`000?nIVIWoVIVI
00;oVIVI00Go0000ogmoOomoOgooOgmoo`000002ofIVIP03o`000?m<C4coC4a<00;oC4a<00?o0000
oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C003oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co
0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c007o`000?nc/k?o/k>cok>c/ol0
003oVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<0
2Ol0003oC4a<oda<C?m<C4co0000ofIVI_l0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`00
00Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT2o`000005ofIVI_l0003oC4a<oda<C?l000002?lc
<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Soc<c<00?o
0000ok>c/oooool01Oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool0
0ol0003oIVIVofIVIP0:ofIVIP;o00002_moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o
/k>c01Ko/k>c0_l0000<oiVIV@;o00002OmoOgl2o`0000goIVIV00?o0000oda<C?m<C4`05Om<C4`0
0ol0003oIVIVofIVIP03ofIVIP03o`000?moOgooOgmo00?oOgmo00?o0000oiVIVOnIVIT00_nIVIT0
0ol0003o/k>cok>c/`07ok>c/`03o`000?o<c<co000000Oo/k>c0_l00003oiVIV@05o`000?moOgoo
OgmoogmoOol000000omVIVH00ol0003oC4a<oda<C002oda<C003o`000?lc<c?o<c<c00Go<c<c00?o
0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000Co
/k>c00?o0000olc<c?o<c<`01Oo<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Ko0000ogmo
OomoOgoo0000ofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co0000
0_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00[o0000ok>c/ol0
003o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0<o`00
0?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00002?o<c<`00ol0003o/k>c
ooooo`05ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`coIVIV00?o
0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o
0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00coIVIV00?o
0000oda<C?m<C4`05Om<C4`00ol0003oIVIVofIVIP04ofIVIP03o`000?moOgooOgmo00?oOgmo00?o
0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`07ok>c/`03o`000?o<c<co000000Oo/k>c00?o
0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000?oIVIV00?o0000oda<C?m<C4`0
0_m<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Co0000ofIVI_mVIVKo
00000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c
/onc/k?o/k>co`000002oiVIV@06o`000?moOgooOgmoo`000?mVIVKo00000om<C4`00ol0003o<c<c
oc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o
/k>cok>c/ol00007olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Go0000ogmoOol0003oIVIVo`00
0002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4co0000ofIVIP02o`0000;oVIVI
00?o0000ok>c/ol000002?o<c<`00ol0003o/k>cooooo`05ooooo`7o00000Oooool1ooooo`009?oo
ool00ol0003oooooooooo`03ooooo`coIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVI
V@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmo
O`08ogmoO`03o`000?mVIVKoIVIV00coIVIV00?o0000oda<C?m<C4`05Om<C4`00ol0003oIVIVofIV
IP04ofIVIP03o`000?moOgooOgmo00?oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c
/`09ok>c/`03o`000?nc/k?o/k>c00Go/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmo
OomoOgoo000000?oIVIV00?o0000oda<C?m<C4`00_m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`00
0?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00004ok>c
/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<02?l0003oVIVIoiVIVOl0003o
Ogmoo`000?mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;o
IVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00008olc<c008o`000?nc/k?o/k>c
o`000?nIVIWo0000ogmoOol00002ofIVIP03o`000?m<C4co000000So<c<c00co0000oda<C?m<C4co
0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00008olc<c004o`000?nc/k?o/k>co`0000Go
oooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo2_mVIVH2o`0000[oOgmo
00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI
00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01GoC4a<
00?o0000ofIVI_mVIVH01?mVIVH00ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00;oVIVI
0_l0000Cok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01Ol0003oIVIVofIVI_mVIVKo0000
00GoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIV
o`0000;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc
/k?o/k>cok>c/ol000000_nIVIT01_l0003oOgmoogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c
<olc<c<01olc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00?o0000
ok>c/ol000002Oo<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<
C003o`000?lc<c?o<c<c00Ko<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo
0000ok>c/ol00008olc<c004o`000?nc/k?o/k>co`0000Gooooo0Ol00001ooooo`7ooooo000Toooo
o`03o`000?oooooooooo00?ooooo2OmVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI
00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo
00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV
00CoIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c
01;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`05o`000?mVIVKoIVIVofIVI_l000001?m<
C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000omVIVH01?l0003oOgmo
ogmoOol00002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01Ol0003o/k>cok>c/onc/k?o
000000;oVIVI00Ko0000ogmoOomoOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c
00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVIV@03o`000?nc/k?o000000Wo
c<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<c
oc<c<`06oc<c<`03o`000?m<C4coC4a<00;o00000_moOgl01Ol0003oVIVIo`000?nc/k?o000000So
c<c<00Co0000ok>c/onc/k?o00001Oooool1o`00007ooooo0Oooool002Cooooo00?o0000oooooooo
ool00oooool9ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o
/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003o
IVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH01?mVIVH00ol0003o
OgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<04_nc/k<01Ol0003o
VIVIoiVIVOnIVIWo000000CoOgmo00Co0000ofIVI_mVIVKo00001Om<C4`00ol0003o<c<coc<c<`05
oc<c<`05o`000?m<C4coC4a<oda<C?l000000omVIVH01?l0003oOgmoogmoOol00002oiVIV@05o`00
0?nc/k?o/k>cok>c/ol000002?o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Ko0000ogmo
OomoOgoo0000ofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co0000
0_mVIVH02?l0003oOgmoogmoOol0003oVIVIo`000?nc/k?o00002Oo<c<`01_l0003o/k>cok>c/ol0
003oVIVIo`0000;oOgmo0_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00[o0000oda<C?m<C4co
0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c003o`000?nc
/k?o000000Kooooo0Ol00001ooooo`7ooooo000Tooooo`;o00001?ooool7ofIVIP;o00002OmoOgl2
o`0000goVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgoo
Ogmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKo
IVIV00CoIVIV00?o0000ogmoOomoOgl00omoOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o
/k>c01;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`05o`000?mVIVKoIVIVofIVI_l00000
1?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Go0000ofIVI_mVIVKo
IVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0
003o/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmoOol000000_mVIVH01Ol0003oC4a<oda<C?m<
C4co000000So<c<c00Co0000oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o
/k>c00?o0000olc<c?o<c<`01oo<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIV
I_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmo
o`000?nIVIWo0000ok>c/ol00008olc<c004o`000?nc/k?o/k>co`0000Gooooo0_l00002ooooo`00
9?ooool00ol0003oooooooooo`03ooooo`KoIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVI
oiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT2o`0000[oOgmo
00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00GoIVIV
00?o0000ogmoOomoOgl00omoOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c017o/k>c
00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000?oIVIV00?o0000oda<C?m<
C4`00_m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Go0000ofIVI_mV
IVKoIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01Oo<c<`0
0ol0003o/k>cok>c/`02ok>c/`06o`000?nIVIWoVIVIo`000?moOgoo00000_mVIVH01Ol0003oC4a<
oda<C?m<C4co000000Oo<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP05o`000?moOgoo0000
oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c003o`000?nc/k?o/k>c00;o00000_moOgl0
0ol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Oo0000oda<C?m<C4co0000ofIV
I_l0003oOgmo00;o00000_nc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`0000Ko
oooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo1OmVIVH00ol0003oOgmo
ogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVI
oiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<
oda<C00Foda<C003o`000?mVIVKoIVIV00GoIVIV00?o0000ogmoOomoOgl00omoOgl00ol0003oVIVI
oiVIV@03oiVIV@03o`000?nc/k?o/k>c01;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`05
o`000?mVIVKoIVIVofIVI_l000001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<
00;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o
0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo
00000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Go0000
ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00[o0000ok>c/onc/k?o0000
oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0<o`000?m<C4co
C4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00002?o<c<`01_l0003o/k>cok>c/ol0
003oVIVIo`0000Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo1?mV
IVH00ol0003oOgmoogmoO`08ogmoO`;o00003OnIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nI
VIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0:ofIVIP;o00006?m<
C4`00ol0003oIVIVofIVIP05ofIVIP03o`000?moOgooOgmo00?oOgmo00?o0000oiVIVOnIVIT00onI
VIT00ol0003o/k>cok>c/`0Bok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01Ol0003oIVIV
ofIVI_mVIVKo000000GoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004
o`000?mVIVKoIVIVo`0000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000003ok>c/`03o`000?o<c<co
c<c<00Koc<c<00?o0000ok>c/onc/k<00_l00002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000
oda<C?m<C4co00002Olc<c<01?l0003oC4a<oda<C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl0
00000_nc/k<00ol0003oc<c<olc<c007olc<c003o`000?nc/k?o000000;oVIVI00Go0000ogmoOol0
003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00co0000oda<C?m<C4co0000ofIVI_l0
003oOgmoo`000?nIVIWo0000ok>c/ol00008olc<c006o`000?nc/k?o/k>co`000?nIVIWo00001Ooo
ool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool4ofIVIP03o`000?moOgoo
Ogmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWo
VIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0:ofIVIP03o`000?m<C4co
C4a<01OoC4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWo
VIVI00?oVIVI00?o0000ok>c/onc/k<04_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Go
0000ofIVI_mVIVKoIVIVo`000005oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`0
0_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000onc/k<00ol0
003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`0000?oVIVI00?o0000ogmoOol000000_mVIVH0
1?l0003oC4a<oda<C?l00009oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Go0000ogmoOol0003o
VIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT01Ol0
003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<03?l0003oC4a<oda<C?l0
003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Soc<c<00Ko0000ok>c/onc/k?o0000oiVI
VOl00005ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`;oIVIV0_l0
000:ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVI
V@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<
C00Foda<C003o`000?mVIVKoIVIV00KoIVIV00?o0000ogmoOomoOgl00omoOgl00ol0003oVIVIoiVI
V@03oiVIV@03o`000?nc/k?o/k>c01;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`05o`00
0?mVIVKoIVIVofIVI_l000001Om<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;o
C4a<00Co0000ofIVI_mVIVKo00000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000?o/k>c00?o0000
olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00003oiVIV@03o`000?moOgoo000000;oIVIV00Co
0000oda<C?m<C4co00002Olc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;o
VIVI00Co0000ok>c/onc/k?o00002?o<c<`02?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000
0_mVIVH01?l0003oC4a<oda<C?l00007oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0
003oVIVIo`000?nc/k?o00002Oo<c<`01Ol0003o/k>co`000?nIVIWo000000Kooooo0Ol00001oooo
o`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo00?oIVIVo`000?moOgl02_moOgl00ol0003o
VIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003o
OgmoogmoO`08ogmoO`;o00003?mVIVH2o`0001WoC4a<00?o0000ofIVI_mVIVH01OmVIVH00ol0003o
OgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<04_nc/k<00ol0003o
VIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol000000omVIVH00ol0003oC4a<oda<C003oda<
C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo
000000;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c007olc<c004o`000?nc
/k?o/k>co`0000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01?l0003oC4a<oda<C?l00009oc<c
<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<
c<coc<c<00Koc<c<00_o0000ok>c/onc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002
oda<C003o`000?lc<c?o<c<c00Ko<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nI
VIWo0000ok>c/ol00009olc<c005o`000?nc/k?o0000o`000?moOgl01_ooool1o`00007ooooo0Ooo
ool001Wooooo1Ol00006ooooo`03o`000?oooooooooo00?ooooo00?oIVIVo`000?moOgl02OmoOgl0
0ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT0
0ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00[oIVIV00?o0000oda<C?m<C4`06?m<C4`0
0ol0003oIVIVofIVIP06ofIVIP03o`000?moOgooOgmo00?oOgmo00?o0000oiVIVOnIVIT00onIVIT0
0ol0003o/k>cok>c/`0Bok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`00
0003ofIVIP03o`000?m<C4coC4a<00?oC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<
C002oda<C004o`000?mVIVKoIVIVo`0000?oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003o
c<c<olc<c007olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH0
1?l0003oC4a<oda<C?l00009oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl00ol0003o
VIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00_o0000ok>c/onc/k?o/k>co`000?nIVIWo
0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00co0000oda<C?m<C4co
0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00009olc<c005o`000?nc/k?o0000o`000?mo
Ogl01_ooool1o`00007ooooo0Oooool001Wooooo00GoV9RHob4Q8Oo^k^koooooodA4A006ooooo`03
o`000?oooooooooo00?ooooo00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03
o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmoO`03
o`000?mVIVKoIVIV00[oIVIV00?o0000oda<C?m<C4`06?m<C4`00ol0003oIVIVofIVIP06ofIVIP03
o`000?moOgooOgmo00?oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0Bok>c/`03
o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`000003ofIVIP03o`000?m<C4coC4a<
00?oC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C002oda<C005o`000?mVIVKoIVIV
ofIVI_l000000omoOgl01?l0003oVIVIoiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Co
0000ok>c/onc/k?o00000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP04o`000?m<C4coC4a<o`00
00Wo<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00003ogmoO`;o00000_nc/k<00ol0003oc<c<olc<
c007olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000
oc<c<olc<c<01_lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>c
o`0000Woc<c<00Ko0000ok>c/ol0003oVIVIo`000?moOgl6ooooo`7o00000Oooool1ooooo`006_oo
ool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo00?ooooo2_moOgl00ol0003oVIVIoiVI
V@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmo
O`08ogmoO`;o00003?mVIVH00ol0003oC4a<oda<C00Hoda<C003o`000?mVIVKoIVIV00KoIVIV00?o
0000ogmoOomoOgl00omoOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c01;o/k>c00Go
0000oiVIVOnIVIWoVIVIo`000003ogmoO`05o`000?mVIVKoIVIVofIVI_l000001Om<C4`00ol0003o
<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmo
O`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc
/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`07
o`000?m<C4coC4a<oda<C?l0003oIVIVo`000002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000
olc<c?o<c<`01oo<c<`00ol0003o/k>co`000002oiVIV@07o`000?moOgoo0000ofIVI_l0003oC4a<
o`000009oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o0000
2Oo<c<`01ol0003o/k>co`000?nIVIWo0000ogmoOol000001Oooool1o`00007ooooo0Oooool001_o
oooo00?oV9RHob4Q8Oo^k^h01_ooool3o`0000?ooooo2?moOgl2o`0000goVIVI00?o0000ok>c/onc
/k<05onc/k<00ol0003oVIVIoiVIV@0:oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mV
IVH02_mVIVH00ol0003oC4a<oda<C00Hoda<C003o`000?mVIVKoIVIV00OoIVIV00?o0000ogmoOomo
Ogl00omoOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c01;o/k>c00Go0000oiVIVOnI
VIWoVIVIo`000003ogmoO`05o`000?mVIVKoIVIVofIVI_l000001Om<C4`00ol0003o<c<coc<c<`05
oc<c<`03o`000?m<C4coC4a<00;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`04o`000?nI
VIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;o
VIVI00Co0000ogmoOomoOgoo00000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`04o`000?m<C4co
C4a<o`0000;oIVIV00Ko0000ogmoOomoOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Oo
c<c<00?o0000ok>c/ol000000_nIVIT01ol0003oOgmoo`000?mVIVKo0000oda<C?l000002Olc<c<0
3?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Woc<c<00Oo0000
ok>c/ol0003oVIVIo`000?moOgoo000000?ooooo0ol00002ooooo`007?ooool00omgMgOoIVIVoooo
o`05ooooo`03o`000?oooooooooo00?ooooo1omoOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc
/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mV
IVKoIVIV00[oIVIV00?o0000oda<C?m<C4`06?m<C4`00ol0003oIVIVofIVIP07ofIVIP03o`000?mo
OgooOgmo00?oOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`0Bok>c/`05o`000?nI
VIWoVIVIoiVIVOl000000omoOgl01Ol0003oIVIVofIVI_mVIVKo000000GoC4a<00?o0000oc<c<olc
<c<01Olc<c<00ol0003oC4a<oda<C002oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01?l0
003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Goc<c<00Go0000ok>c/onc/k?o/k>co`00
0002oiVIV@07o`000?moOgooOgmoogmoOol0003oIVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko
<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000
olc<c?o<c<`01oo<c<`00ol0003o/k>co`000002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<
C4`00ol0003o<c<coc<c<`06oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVI
o`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01ol0003o/k>co`000?nIVIWo0000ogmoOol00000
1_ooool1o`00007ooooo0Oooool001gooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`03ooooo`KoOgmo00?o0000oiVIVOnIVIT02onIVIT2o`0001So/k>c0_l0000<oiVIV@03o`000?mo
OgooOgmo00SoOgmo0_l0000<ofIVIP03o`000?m<C4coC4a<01SoC4a<00?o0000ofIVI_mVIVH01omV
IVH00ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<04_nc
/k<00ol0003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol000000omVIVH00ol0003oC4a<
oda<C003oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00om<C4`01?l0003oIVIV
ofIVI_l00002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<
c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01_l0003oOgmoogmoOol0003oIVIVo`0000?oC4a<
00?o0000oc<c<olc<c<01_lc<c<01ol0003oC4a<oda<C?m<C4co0000ofIVI_l000000_moOgl00ol0
003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT0
1Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<03?l0003oC4a<oda<
C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Woc<c<00Oo0000ok>c/ol0003oVIVI
o`000?moOgoo000000Kooooo0Ol00001ooooo`7ooooo000Iooooo`05o`000?nj^[[ooooooiRHV?l@
41001_ooool00ol0003oooooooooo`03ooooo`GoOgmo0_l0000<oiVIV@03o`000?nc/k?o/k>c01Oo
/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00co
IVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP07ofIVIP;o00001OmoOgl00ol0003o
VIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003o
OgmoogmoOomoOgoo000000;oIVIV00?o0000oda<C?m<C4`01?m<C4`00ol0003o<c<coc<c<`04oc<c
<`03o`000?m<C4coC4a<00;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`05o`000?nIVIWo
VIVIoiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol00000
0_nIVIT01_l0003oOgmoogmoOol0003oIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01ol0
003oC4a<oda<C?m<C4co0000ofIVI_l000000_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<
c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;o
C4a<00?o0000oc<c<olc<c<01_lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVI
VOl0003o/k>co`0000Woc<c<00Oo0000ok>c/ol0003oVIVIo`000?moOgoo000000Kooooo0Ol00001
ooooo`7ooooo000;ooooo`?o000000?o410@ooooooooool02?ooool01OnHV9So410@o`000?lQ8B7o
c<c<00Kooooo00?o0000ooooooooool00oooool4ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000
ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000
ofIVI_mVIVH02omVIVH2o`0001WoC4a<00?o0000ofIVI_mVIVH01omVIVH00ol0003oOgmoogmoO`04
ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<04_nc/k<00ol0003oVIVIoiVIV@02
oiVIV@05o`000?moOgooOgmoogmoOol000000omVIVH00ol0003oC4a<oda<C004oda<C003o`000?lc
<c?o<c<c00?o<c<c00?o0000oda<C?m<C4`00om<C4`01?l0003oIVIVofIVI_l00002ogmoO`05o`00
0?nIVIWoVIVIoiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c
/ol000000_nIVIT01_l0003oOgmoogmoOol0003oIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc
<c<01ol0003oC4a<oda<C?m<C4co0000ofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00002ok>c
/`03o`000?o<c<coc<c<00Koc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo
00000om<C4`00ol0003o<c<coc<c<`06oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nI
VIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003o/k>co`000002oiVIV@;o000000?o
IVIVooooooooool01?ooool1o`00007ooooo0Oooool000gooooo00?o410@okZj^_ooool05?ooool0
0ol0003oooooooooo`03ooooo`?oOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0G
ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;
ofIVIP03o`000?m<C4coC4a<01SoC4a<00?o0000ofIVI_mVIVH01omVIVH00ol0003oOgmoogmoO`04
ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<04_nc/k<00ol0003oVIVIoiVIV@02
oiVIV@05o`000?moOgooOgmoogmoOol000000omVIVH00ol0003oC4a<oda<C004oda<C003o`000?lc
<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo
00?o0000oiVIVOnIVIT00_l00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o
/k>co`000002oiVIV@03o`000?moOgoo000000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c
<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol0
0008olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003
o`000?lc<c?o<c<c00Ko<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000
0_nc/k<00ol0003oc<c<olc<c006olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo
000000Gooooo0Ol00001ooooo`7ooooo000=ooooo`03oiRHV?lb<S;ooooo01Cooooo00?o0000oooo
ooooool00oooool3ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0
003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH03?mVIVH00ol0
003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00SoIVIV00?o0000ogmoOomoOgl01?moOgl00ol0
003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c01;o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0
003oOgmoogmoOomoOgoo000000?oIVIV00?o0000oda<C?m<C4`01?m<C4`00ol0003o<c<coc<c<`04
oc<c<`03o`000?m<C4coC4a<00;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`04o`000?nI
VIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;o
VIVI00?o0000ogmoOol000000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Co0000oda<
C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Co
0000ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc
<c<01_lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`00
0?o<c<coc<c<00Koc<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000001Oooool1
o`00007ooooo0Oooool000gooooo00?ogMgMo`000?nj^[X05?ooool00ol0003oooooooooo`03oooo
o`;oOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI
00coVIVI00?o0000ogmoOomoOgl01omoOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<
01OoC4a<00?o0000ofIVI_mVIVH02?mVIVH00ol0003oOgmoogmoO`04ogmoO`03o`000?nIVIWoVIVI
00CoVIVI00?o0000ok>c/onc/k<04_nc/k<00ol0003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmo
ogmoOol000001?mVIVH00ol0003oC4a<oda<C003oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000
oda<C?m<C4`00om<C4`01?l0003oIVIVofIVI_l00003ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c
00?o0000olc<c?o<c<`01Oo<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmoOol0
00000omVIVH01Ol0003oC4a<oda<C?m<C4co000000Oo<c<c00Oo0000oda<C?m<C4coC4a<o`000?mV
IVKo000000;oOgmo00Ko0000oiVIVOnIVIWo0000ok>c/ol00009olc<c004o`000?nc/k?o/k>co`00
00;oVIVI0_l00002ofIVIP03o`000?m<C4co000000Wo<c<c00?o0000oda<C?m<C4`00_l00002ogmo
O`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02Ol0003o/k>co`000?nIVIWo
0000ogmoOol0003oIVIVo`000005ooooo`7o00000Oooool1ooooo`003Oooool00omEEEGoMgMgodA4
A00Dooooo`03o`000?oooooooooo00?ooooo00?oOgmoo`000?nIVIT03?nIVIT00ol0003o/k>cok>c
/`0Fok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl01omoOgl00ol0003oIVIVofIV
IP0<ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02OmVIVH00ol0003oOgmoogmo
O`04ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<04onc/k<00ol0003oVIVIoiVI
V@02oiVIV@05o`000?moOgooOgmoogmoOol000000omVIVH00ol0003oC4a<oda<C004oda<C003o`00
0?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;o
Ogmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>c
ok>c/ol000000_nIVIT00ol0003oOgmoo`000003ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Co
0000oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Wo
c<c<00?o0000ok>c/ol000000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c
<olc<c<01_lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03
o`000?o<c<coc<c<00Koc<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000001_oo
ool1o`00007ooooo0Oooool000cooooo00GogMgMoa0@4?oooooo8B4QomgMg@0Cooooo`03o`000?oo
oooooooo00?ooooo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`;o00003?nI
VIT2o`0000WoOgmo0_l0000=ofIVIP03o`000?m<C4coC4a<01KoC4a<0_l0000;ofIVIP03o`000?mo
OgooOgmo00CoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`0Bok>c/`03o`000?nI
VIWoVIVI00;oVIVI00?o0000ogmoOomoOgl00_moOgl01Ol0003oIVIVofIVI_mVIVKo000000GoC4a<
00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C003oda<C004o`000?mVIVKoIVIVo`0000?o
Ogmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c005olc<c005o`000?nc/k?o/k>c
ok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<C?l00000
2?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00?o0000ok>c/ol0
00002_o<c<`00ol0003o/k>co`000002oiVIV@07o`000?moOgoo0000ofIVI_l0003oC4a<o`000009
oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<
c?o<c<`01_o<c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000006ooooo`7o0000
0Oooool1ooooo`003?ooool01OmVIVKoQhN7oooooonHV9SoEEEE01?ooooo0_l00004ooooo`goVIVI
00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo
00?o0000ofIVI_mVIVH03?mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00[oIVIV
00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c01;o/k>c
00?o0000oiVIVOnIVIT00_nIVIT00ol0003oOgmoogmoO`02ogmoO`04o`000?mVIVKoIVIVo`0000Ko
C4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C002oda<C005o`000?mVIVKoIVIVofIV
I_l000000omoOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Goc<c<00Go0000
ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Go0000oda<C?m<C4co
C4a<o`000008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT00ol0
003o/k>co`00000:olc<c005o`000?nc/k?o0000oiVIVOl000000_moOgl01Ol0003oIVIVo`000?m<
C4co000000Wo<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol0
0009olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000Gooooo0_l00002oooo
o`002oooool00oo^k^ko0000onk^kP02ooooo`03o`000?oMgMgooooo017ooooo00?o0000oooooooo
ool00oooool<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003o
OgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00coIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003o
IVIVofIVIP0:ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o
/k>cok>c/`0Bok>c/`03o`000?nIVIWoVIVI00;oVIVI00?o0000ogmoOomoOgl00_moOgl01Ol0003o
IVIVofIVI_mVIVKo000000KoC4a<00?o0000oc<c<olc<c<00olc<c<00ol0003oC4a<oda<C003oda<
C004o`000?mVIVKoIVIVo`0000?oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<
c005olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP05
o`000?m<C4coC4a<oda<C?l000002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo
000000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`00ol0003o/k>co`000002oiVIV@05o`000?mo
Ogoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0:o`000?m<C4coC4a<o`000?mV
IVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02_l0003o/k>co`00
0?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4`6ooooo`7o00000Oooool1ooooo`002oooool01?l@
413o0000o`000?ooool2o`000003oa0@4?oooooooooo013ooooo00?o0000ooooooooool00oooool;
oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08
ogmoO`;o00003OmVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00[oIVIV00?o0000
ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o0000
oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000?oIVIV00?o0000oda<C?m<C4`01?m<
C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00;oC4a<00Go0000ofIVI_mVIVKoIVIV
o`000002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c005
o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP04o`000?m<C4co
C4a<o`0000Wo<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`00
0?nc/k?o/k>co`0000Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mVIVKo
000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo
0000oiVIVOl0003o/k>co`0000Woc<c<00[o0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0
003oC4a<1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool:oiVIV@03
o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03
o`000?mVIVKoIVIV00coIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0:ofIVIP03
o`000?moOgooOgmo00KoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`0Bok>c/`03
o`000?nIVIWoVIVI00?oVIVI00Go0000ogmoOomoOgooOgmoo`000003ofIVIP03o`000?m<C4coC4a<
00CoC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C002oda<C005o`000?mVIVKoIVIV
ofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go
0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Co0000oda<C?m<
C4co00002Olc<c<01?l0003oC4a<oda<C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl000000onc
/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Oo0000ogmoOol0003o
IVIVo`000?m<C4co000000Wo<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo
0000ok>c/ol00009olc<c00;o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l0
00001Oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool9oiVIV@03o`00
0?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`00
0?mVIVKoIVIV00coIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0:ofIVIP03o`00
0?moOgooOgmo00KoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`0Cok>c/`03o`00
0?nIVIWoVIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`000003ofIVIP03o`000?m<C4coC4a<00Co
C4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C002oda<C005o`000?mVIVKoIVIVofIV
I_l000000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`0
1Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01?l0003oC4a<
oda<C?l00009oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT01Ol0
003o/k>cok>c/onc/k?o000000Ooc<c<00Co0000ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`00
0?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`00
0?moOgoo0000oiVIVOl0003o/k>co`0000Woc<c<00?o0000ok>c/ol000000_nIVIT2o`000005ofIV
I_l0003oC4a<oda<C?l000001Oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool0
0oooool8oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmo
ogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIV
ofIVIP0;ofIVIP03o`000?moOgooOgmo00CoOgmo0_l00006oiVIV@03o`000?nc/k?o/k>c01?o/k>c
00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000CoIVIV00?o0000oda<C?m<
C4`00om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Go0000ofIVI_mV
IVKoIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01_o<c<`0
1Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01?l0003oC4a<
oda<C?l00009oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0
003o/k>cok>c/ol00008olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl00ol0003oIVIV
o`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmo
o`000?nIVIWo0000ok>c/ol00009olc<c00;o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo
0000oda<C?l000001_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool7
oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT2o`0000[oOgmo00?o0000
ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000
ogmoOomoOgl01?moOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o0000
oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000?oIVIV00?o0000oda<C?m<C4`01?m<
C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Go0000ofIVI_mVIVKoIVIV
o`000002ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o
/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmoOol000000_mVIVH01Ol0003oC4a<oda<C?m<C4co
000000So<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo
00000_nc/k<00ol0003oc<c<olc<c006olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0
0002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmo
o`000?nIVIWo0000ok>c/ol00009olc<c00;o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo
0000oda<C?l000001_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool6
oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09
ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;
ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT01OnIVIT00ol0003o/k>cok>c/`0C
ok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`000004ofIVIP03o`000?m<
C4coC4a<00?oC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C003oda<C005o`000?mV
IVKoIVIVofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00005ok>c/`03o`000?o<c<coc<c<00Go
c<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Go0000
oda<C?m<C4coC4a<o`000008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol00000
0_nIVIT01?l0003o/k>cok>c/ol00008olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl0
0ol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00[o0000oda<C?m<C4co0000ofIV
I_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c003o`000?nc/k?o/k>c
00;o000000CoOgmoo`000?mVIVKo00000_m<C4`00ol0003oooooooooo`04ooooo`7o00000Oooool1
ooooo`009?ooool00ol0003oooooooooo`03ooooo`GoVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0
003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02_mVIVH2o`00
01OoC4a<0_l0000=ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT01OnIVIT00ol0
003o/k>cok>c/`0Cok>c/`03o`000?nIVIWoVIVI00;oVIVI00?o0000ogmoOomoOgl00_moOgl01Ol0
003oIVIVofIVI_mVIVKo000000KoC4a<00?o0000oc<c<olc<c<00olc<c<2o`0000GoC4a<00Co0000
ofIVI_mVIVKo00000omoOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Goc<c<
00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`03o`000?mVIVKo000000?o
C4a<00?o0000oc<c<olc<c<01_lc<c<01ol0003oC4a<oda<C?m<C4co0000ofIVI_l000000_moOgl0
0ol0003oVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Ko0000ok>c/onc/k?o0000oiVI
VOl00002ogmoO`05o`000?mVIVKo0000oda<C?l000002Olc<c<02_l0003oC4a<oda<C?l0003oIVIV
o`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Wo0000ok>c/ol0003o
VIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003oooooooooo`04ooooo`7o00000Oooool1
ooooo`009?ooool00ol0003oooooooooo`03ooooo`CoVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0
003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02_mVIVH00ol0
003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl01_moOgl00ol0
003oVIVIoiVIV@05oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT00_nIVIT00ol0
003oOgmoogmoO`02ogmoO`05o`000?mVIVKoIVIVofIVI_l000001_m<C4`00ol0003o<c<coc<c<`03
oc<c<`03o`000?m<C4coC4a<00CoC4a<00Co0000ofIVI_mVIVKo00000_moOgl01Ol0003oVIVIoiVI
VOnIVIWo000000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`00
0?nIVIWoVIVIo`0000;oOgmo00?o0000ofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`07
o`000?m<C4coC4a<oda<C?l0003oIVIVo`000002ogmoO`03o`000?nIVIWo000000?o/k>c00?o0000
olc<c?o<c<`01_o<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00Go0000ofIVI_l0003o
C4a<o`000009oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c
00?o0000olc<c?o<c<`01_o<c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002
oda<C003o`000?oooooooooo00Cooooo0Ol00001ooooo`7ooooo000Tooooo`;o00001?ooool3oiVI
V@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmo
O`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIV
IP03o`000?moOgooOgmo00KoOgmo00?o0000oiVIVOnIVIT01OnIVIT00ol0003o/k>cok>c/`0Cok>c
/`03o`000?nIVIWoVIVI00;oVIVI00?o0000ogmoOomoOgl00_moOgl01Ol0003oIVIVofIVI_mVIVKo
000000KoC4a<00?o0000oc<c<olc<c<00olc<c<00ol0003oC4a<oda<C004oda<C004o`000?mVIVKo
IVIVo`0000?oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c005olc<c003o`00
0?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl00ol0003oIVIVo`000003oda<C003
o`000?lc<c?o<c<c00Oo<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`03o`000?nIVIWo
000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@05o`000?mo
Ogoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0:o`000?m<C4coC4a<o`000?mV
IVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01oo<c<`2o`000004oiVIVOl0
003oOgmoogmoO`;o00000_m<C4`00ol0003o<c<cooooo`04ooooo`;o00000_ooool002Cooooo00?o
0000ooooooooool00oooool2oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onI
VIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00[oIVIV0_l0000Hoda<C003o`000?mV
IVKoIVIV00_oIVIV00?o0000ogmoOomoOgl01_moOgl00ol0003oVIVIoiVIV@05oiVIV@03o`000?nc
/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT00onIVIT01Ol0003oOgmoogmoOomoOgoo000000CoIVIV
00?o0000oda<C?m<C4`01?m<C4`00ol0003o<c<coc<c<`03oc<c<`03o`000?m<C4coC4a<00?oC4a<
00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0
003oc<c<olc<c005olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol0
0002ofIVIP05o`000?m<C4coC4a<oda<C?l000002Olc<c<01_l0003oC4a<oda<C?l0003oIVIVo`00
00;oOgmo00?o0000oiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c006o`000?nc/k?o/k>c
o`000?nIVIWo00000_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00[o
0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006
olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<ooo
ool01Oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool00onIVIWo0000
ok>c/`0Gok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIV
ofIVIP0:ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmo
ogmoO`07ogmoO`03o`000?nIVIWoVIVI00GoVIVI00?o0000ok>c/onc/k<04onc/k<00ol0003oVIVI
oiVIV@03oiVIV@05o`000?moOgooOgmoogmoOol000000omVIVH00ol0003oC4a<oda<C005oda<C003
o`000?lc<c?o<c<c00?o<c<c00?o0000oda<C?m<C4`00om<C4`01Ol0003oIVIVofIVI_mVIVKo0000
00;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Goc<c<00Go0000
ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Go0000oda<C?m<C4co
C4a<o`000009oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl00ol0003oVIVIo`000002
ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`03o`00
0?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`00
0?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Wo0000ok>c/ol0003oVIVI
o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<cooooo`05ooooo`7o00000Oooool1oooo
o`009?ooool00ol0003oooooooooo`03ooooo`03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnI
VIT02onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00[oIVIV00?o0000oda<C?m<
C4`05om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00OoOgmo00?o0000oiVIVOnI
VIT01OnIVIT00ol0003o/k>cok>c/`0Cok>c/`03o`000?nIVIWoVIVI00?oVIVI00Go0000ogmoOomo
OgooOgmoo`000004ofIVIP03o`000?m<C4coC4a<00CoC4a<00?o0000oc<c<olc<c<00olc<c<00ol0
003oC4a<oda<C003oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01Ol0003oVIVIoiVIVOnI
VIWo000000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI
00Co0000ogmoOomoOgoo00000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000Wo<c<c00Ko0000oda<
C?m<C4co0000ofIVI_l00002ogmoO`03o`000?nIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<
c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o
<c<coc<c<`07oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o
0000olc<c?o<c<`01_o<c<`00ol0003o/k>co`000002oiVIV@;o000000GoIVIVo`000?m<C4coC4a<
o`000002oc<c<`Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo6?nc
/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo0_l0000<ofIVIP03o`000?m<
C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`07ogmoO`03o`000?nI
VIWoVIVI00GoVIVI00?o0000ok>c/onc/k<04onc/k<00ol0003oVIVIoiVIV@03oiVIV@05o`000?mo
OgooOgmoogmoOol000001?mVIVH00ol0003oC4a<oda<C004oda<C003o`000?lc<c?o<c<c00?o<c<c
0_l00005oda<C004o`000?mVIVKoIVIVo`0000?oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0
003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol0
0002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP06
o`000?moOgooOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c007olc<c008o`000?nc/k?o
/k>co`000?nIVIWo0000ogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00co0000oda<
C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00009olc<c009o`000?nc/k?o0000
oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_ooool1o`00007ooooo
0Oooool002Cooooo00?o0000ooooooooool00ooooolHok>c/`03o`000?nIVIWoVIVI00[oVIVI00?o
0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o
0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`07ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o
0000ok>c/onc/k<04onc/k<00ol0003oVIVIoiVIV@03oiVIV@05o`000?moOgooOgmoogmoOol00000
1?mVIVH00ol0003oC4a<oda<C004oda<C003o`000?lc<c?o<c<c00?o<c<c00?o0000oda<C?m<C4`0
1?m<C4`01?l0003oIVIVofIVI_l00003ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<
c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mV
IVH01?l0003oC4a<oda<C?l00009oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Ko0000ogmoOomo
Ogoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00So0000ok>c/onc/k?o0000oiVI
VOl0003oOgmoo`0000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<03?l0003oC4a<oda<C?l0003o
IVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Woc<c<00Wo0000ok>c/ol0003oVIVIo`000?mo
Ogoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06ooooo`7o00000Oooool1ooooo`009?oo
ool00ol0003oooooooooo`03oooooaOo/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmo
O`09ogmoO`03o`000?mVIVKoIVIV00[oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIV
IP0;ofIVIP03o`000?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c
/`0Cok>c/`03o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl00_moOgl01Ol0003oIVIVofIV
I_mVIVKo000000KoC4a<00?o0000oc<c<olc<c<00olc<c<00ol0003oC4a<oda<C004oda<C005o`00
0?mVIVKoIVIVofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<
00Koc<c<00?o0000ok>c/onc/k<00_nc/k<01_l0003oVIVIoiVIVOl0003oOgmoo`0000;oIVIV00Go
0000oda<C?m<C4coC4a<o`000008oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01Ol0003o
Ogmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`01_l0003o/k>cok>c/ol0003o
VIVIo`0000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0:o`000?m<
C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`0
0ol0003o/k>cok>c/`02o`000007ogmoOol0003oIVIVofIVI_l0003oC4a<o`000003oc<c<`Kooooo
0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo5Onc/k<2o`0000coVIVI00?o
0000ogmoOomoOgl02?moOgl2o`0000coIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIV
IP0;ofIVIP03o`000?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c
/`0Dok>c/`03o`000?nIVIWoVIVI00;oVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIV
IP02ofIVIP03o`000?m<C4coC4a<00CoC4a<00?o0000oc<c<olc<c<00olc<c<00ol0003oC4a<oda<
C003oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Co
/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`00
00;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4co
C4a<o`0000;oIVIV00Ko0000ogmoOomoOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Oo
c<c<00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV00?o0000oda<C?l000002Olc
<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<co
c<c<00Koc<c<00?o0000ok>c/ol000000_l000001_moOgoo0000ofIVI_l0003oC4a<o`0000Co<c<c
1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00ooooolDok>c/`03o`000?nI
VIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<
C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`07ogmoO`03o`000?nI
VIWoVIVI00KoVIVI00?o0000ok>c/onc/k<05?nc/k<00ol0003oVIVIoiVIV@03oiVIV@03o`000?mo
OgooOgmo00;oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C004oda<C003o`000?lc
<c?o<c<c00?o<c<c00?o0000oda<C?m<C4`00om<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo
00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc
/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000
oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP06o`000?moOgooOgmoo`000?nIVIWo
00000_nc/k<00ol0003oc<c<olc<c007olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0
0002ofIVIP03o`000?m<C4co000000Wo<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`00
0?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c00;o`000?nc/k?o0000oiVIVOl0003oOgmo
o`000?mVIVKo0000oda<C?l000001?lc<c<6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003o
ooooooooo`03oooooa?o/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03
o`000?mVIVKoIVIV00_oIVIV0_l0000Goda<C0;o00003OmVIVH00ol0003oOgmoogmoO`07ogmoO`03
o`000?nIVIWoVIVI00OoVIVI00?o0000ok>c/onc/k<04onc/k<00ol0003oVIVIoiVIV@03oiVIV@03
o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C004oda<C003
o`000?lc<c?o<c<c00?o<c<c00?o0000oda<C?m<C4`00om<C4`01Ol0003oIVIVofIVI_mVIVKo0000
00;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000
ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Go0000oda<C?m<C4co
C4a<o`000008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Ko0000ogmoOomoOgoo0000oiVIVOl0
0002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Co0000ok>c/onc/k?o00000_nIVIT2o`0000;oIVIV
00Co0000oda<C?m<C4co00002?lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVI
VOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/ol0003oVIVIo`000002ogmoO`;o
00000_m<C4`00ol0003o<c<coc<c<`02oc<c<`Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`00
0?oooooooooo00?ooooo4_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo
00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00coIVIV
00?o0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@07oiVIV@03o`000?nc/k?o/k>c01Co/k>c
00?o0000oiVIVOnIVIT00_nIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00;oIVIV
00?o0000oda<C?m<C4`01?m<C4`00ol0003o<c<coc<c<`03oc<c<`03o`000?m<C4coC4a<00CoC4a<
00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0
003oc<c<olc<c005olc<c005o`000?nc/k?o/k>cok>c/ol000000onIVIT01?l0003oOgmoogmoOol0
0002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP03
o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`2o`0000;o/k>c00Go0000oiVI
VOl0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00[o0000oda<C?m<C4co0000
ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c009o`000?nc/k?o
0000oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<00_lc<c<6ooooo`7o
00000Oooool1ooooo`009?ooool2o`0000Cooooo4Onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`00
0?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH03?mVIVH00ol0003oC4a<oda<C00Foda<C003o`00
0?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@06oiVIV@03o`00
0?nc/k?o/k>c01Go/k>c00?o0000oiVIVOnIVIT00_nIVIT00ol0003oOgmoogmoO`02ogmoO`03o`00
0?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01?m<C4`00ol0003o<c<coc<c<`03oc<c<`03o`00
0?m<C4coC4a<00CoC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVI
VOl000000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000onIVIT0
1?l0003oOgmoogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01?l0003oC4a<
oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`02Ol0
003o/k>cok>c/onc/k?o0000oiVIVOl0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So
<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<
olc<c006olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000
oc<c<olc<c<00_lc<c<5ooooo`;o00000_ooool002Cooooo00?o0000ooooooooool00oooool@ok>c
/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl01omoOgl00ol0003oIVIVofIVIP0<ofIV
IP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmo
O`03o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc/k<05Onc/k<00ol0003oVIVIoiVIV@03oiVI
V@03o`000?moOgooOgmo00;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000007oda<C003o`000?lc<c?o
<c<c00;o<c<c00?o0000oda<C?m<C4`01?m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Go
0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o
/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008
oc<c<`07o`000?m<C4coC4a<oda<C?l0003oIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000;o
/k>c00?o0000olc<c?o<c<`01_o<c<`02ol0003o/k>cok>c/onc/k?o0000oiVIVOl0003oOgmoo`00
0?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01olc<c<03?l0003oC4a<oda<C?l0003oIVIVo`00
0?moOgoo0000oiVIVOl0003o/k>co`0000Woc<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000
ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`02oc<c<`Kooooo0Ol00001ooooo`7ooooo000Toooo
o`03o`000?oooooooooo00?ooooo3onc/k<00ol0003oVIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo
00OoOgmo00?o0000ofIVI_mVIVH03?mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV
00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c
01Go/k>c00?o0000oiVIVOnIVIT00_nIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV
00;oIVIV00?o0000oda<C?m<C4`01?m<C4`00ol0003o<c<coc<c<`03oc<c<`03o`000?m<C4coC4a<
00CoC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000onc
/k<00ol0003oc<c<olc<c006olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo0000
0_moOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<
C4co00000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Wo0000
ok>c/onc/k?o/k>co`000?nIVIWo0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00008oc<c
<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<
c<`01_o<c<`00ol0003o/k>co`000002oiVIV@;o000000GoIVIVo`000?m<C4coC4a<o`000005oc<c
<`Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo3_nc/k<2o`0000co
VIVI0_l00009ogmoO`;o00003OmVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_o
IVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c01Co
/k>c0_l00004oiVIV@;o00000omoOgl00ol0003oIVIVofIVIP02ofIVIP03o`000?m<C4coC4a<00Go
C4a<00?o0000oc<c<olc<c<00_lc<c<00ol0003oC4a<oda<C004oda<C005o`000?mVIVKoIVIVofIV
I_l000000omoOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000
ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Go0000oda<C?m<C4co
C4a<o`000008oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH00ol0003oOgmoo`000002oiVI
V@04o`000?nc/k?o/k>co`0000Soc<c<00Wo0000ok>c/onc/k?o/k>co`000?nIVIWo0000ogmoOol0
00000_mVIVH00ol0003oC4a<o`000009oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0
003oVIVIo`000?nc/k?o00002Oo<c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`00
0002oda<C003o`000?lc<c?o<c<c00?o<c<c1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000
ooooooooool00oooool=ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl0
0ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH0
0ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00OoVIVI00?o0000ok>c/onc/k<05?nc/k<0
0ol0003oVIVIoiVIV@03oiVIV@03o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH00_mVIVH0
0ol0003oC4a<oda<C005oda<C005o`000?lc<c?o<c<coc<c<ol000001om<C4`01Ol0003oIVIVofIV
I_mVIVKo000000?oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c006olc<c005
o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP05o`000?m<C4co
C4a<oda<C?l000002?lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o0000ogmoOol00000
0_nIVIT01?l0003o/k>cok>c/ol00008olc<c009o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000?mo
Ogoo000000;oIVIV00?o0000oda<C?l000002Olc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?mo
Ogoo0000oiVIVOl0003o/k>co`0000Woc<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIV
I_l000000_m<C4`00ol0003o<c<coc<c<`03oc<c<`Kooooo0Ol00001ooooo`7ooooo000Tooooo`03
o`000?oooooooooo00?ooooo3?nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00So
Ogmo00?o0000ofIVI_mVIVH03?mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_o
IVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@07oiVIV@03o`000?nc/k?o/k>c01Co
/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00?o
IVIV00?o0000oda<C?m<C4`01?m<C4`00ol0003o<c<coc<c<`02oc<c<`03o`000?m<C4coC4a<00Co
C4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000
olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo0000
0_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIV
IP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01ol0003o/k>cok>c/onc
/k?o0000oiVIVOl000000_moOgl01Ol0003oIVIVo`000?m<C4co000000Wo<c<c00[o0000oda<C?m<
C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c007o`00
0?nc/k?o0000oiVIVOl0003oOgmoo`000002ofIVIP03o`000?m<C4co000000Ko<c<c1_ooool1o`00
007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool;ok>c/`03o`000?nIVIWoVIVI00_o
VIVI00?o0000ogmoOomoOgl02?moOgl2o`0000goIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003o
IVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT01onIVIT00ol0003o
/k>cok>c/`0Eok>c/`03o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003o
IVIVofIVIP02ofIVIP03o`000?m<C4coC4a<00GoC4a<00Go0000oc<c<olc<c?o<c<co`000007oda<
C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Co/k>c00?o
0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo
00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<
C?l000000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Co0000
ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIVIP03o`000?m<C4co000000Wo<c<c00[o
0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006
olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc
<c<01?lc<c<6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`[o/k>c
00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00coIVIV
00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo
00?o0000oiVIVOnIVIT02?nIVIT00ol0003o/k>cok>c/`0Dok>c/`03o`000?nIVIWoVIVI00?oVIVI
00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIVIP02ofIVIP03o`000?m<C4coC4a<00CoC4a<
00?o0000oc<c<olc<c<00_lc<c<00ol0003oC4a<oda<C005oda<C005o`000?mVIVKoIVIVofIVI_l0
00000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0
003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo00000om<
C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH00ol0003oOgmo
o`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0
003oOgmoo`000002ofIVIP03o`000?m<C4co000000Wo<c<c00[o0000oda<C?m<C4co0000ofIVI_l0
003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c005olc<c00:o`000?nc/k?o/k>co`00
0?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01?lc<c<6ooooo`7o0000
0Oooool1ooooo`006oooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool00ooo
ool9ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIV
IP0<ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmo
O`09ogmoO`03o`000?nIVIWoVIVI00SoVIVI00?o0000ok>c/onc/k<05?nc/k<00ol0003oVIVIoiVI
V@03oiVIV@03o`000?moOgooOgmo00?oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<
C005oda<C005o`000?lc<c?o<c<coc<c<ol000001om<C4`01Ol0003oIVIVofIVI_mVIVKo000000;o
Ogmo00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c
/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o
0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o0000ogmoOol00000
0_nIVIT01?l0003o/k>cok>c/ol00009olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0
0002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmo
o`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o0000oiVIVOl00000
0_moOgl2o`0000;oC4a<00?o0000oc<c<olc<c<01Olc<c<6ooooo`7o00000Oooool1ooooo`007?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo2?nc/k<00ol0003oVIVIoiVI
V@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<
C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVI
V@08oiVIV@03o`000?nc/k?o/k>c01Go/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmo
O`02ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01Om<C4`00ol0003o<c<coc<c
<`02oc<c<`03o`000?m<C4coC4a<00CoC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`05o`00
0?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o
/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o
<c<c00Ko<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo
00000_nc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Go0000ogmo
Ool0003oIVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c00[o0000oda<C?l0003o0000ofIV
I_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c006o`000?nc/k?o0000
oiVIVOl0003oOgmo0ol00002oda<C003o`000?lc<c?o<c<c00Go<c<c1_ooool1o`00007ooooo0Ooo
ool001Wooooo1Ol00006ooooo`?o00000oooool7ok>c/`03o`000?nIVIWoVIVI00_oVIVI0_l0000:
ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;
ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02?nIVIT00ol0003o/k>cok>c/`0E
ok>c/`03o`000?nIVIWoVIVI00CoVIVI00Go0000ogmoOomoOgooOgmoo`000005ofIVIP03o`000?m<
C4coC4a<00GoC4a<00Go0000oc<c<olc<c?o<c<co`000007oda<C005o`000?mVIVKoIVIVofIVI_l0
00000omoOgl01?l0003oVIVIoiVIVOl00005ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c
/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o
0000oc<c<olc<c<01_lc<c<01ol0003oC4a<oda<C?m<C4co0000ofIVI_l000000_moOgl01?l0003o
VIVIoiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT0
1Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<
C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c009
o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01Olc
<c<4ooooo`?o00000_ooool001Wooooo00CoA4A4omgMgOoooooo00001oooool00ol0003ooooooooo
o`03ooooo`Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mV
IVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?mo
OgooOgmo00SoOgmo0_l0000;oiVIV@03o`000?nc/k?o/k>c01Co/k>c00?o0000oiVIVOnIVIT01?nI
VIT01Ol0003oOgmoogmoOomoOgoo000000GoIVIV00?o0000oda<C?m<C4`01Om<C4`00ol0003o<c<c
oc<c<`02oc<c<`03o`000?m<C4coC4a<00CoC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`05
o`000?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c
00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc
<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP03o`000?moOgoo000000;oVIVI
00Co0000ok>c/onc/k?o00002?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo0000
00;oIVIV00Co0000oda<C?m<C4co00002?lc<c<02?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo
00000_nIVIT00ol0003o/k>co`000008olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mV
IVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<6ooooo`7o00000Oooool1ooooo`006Oooool0
1?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo00?ooooo1Onc/k<00ol0003oVIVIoiVI
V@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02_mVIVH2o`0001OoC4a<0_l0
000=ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02_nIVIT00ol0003o/k>cok>c
/`0Dok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIV
IP02ofIVIP03o`000?m<C4coC4a<00KoC4a<00Go0000oc<c<olc<c?o<c<co`000006oda<C003o`00
0?mVIVKoIVIV00;oIVIV00Co0000ogmoOomoOgoo00000onIVIT00ol0003o/k>cok>c/`02ok>c/`03
o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo0000
00;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4co
C4a<o`0000;oIVIV00Ko0000ogmoOomoOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Oo
c<c<00Co0000ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000
oc<c<olc<c<01olc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>c
o`0000Woc<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o
<c<coc<c<`06oc<c<`03o`000?oooooooooo00?ooooo0Ol00001ooooo`7ooooo000Jooooo`03ogMg
Moo<c<co000000Oooooo00?o0000ooooooooool00oooool4ok>c/`03o`000?nIVIWoVIVI00_oVIVI
00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<01KoC4a<
00?o0000ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00[oVIVI
00?o0000ok>c/onc/k<05Onc/k<00ol0003oVIVIoiVIV@03oiVIV@03o`000?moOgooOgmo00?oOgmo
00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C006oda<C005o`000?lc<c?o<c<coc<c<ol0
00001_m<C4`00ol0003oIVIVofIVIP02ofIVIP04o`000?moOgooOgmoo`0000?oVIVI00?o0000ok>c
/onc/k<00_nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Go0000oiVI
VOnIVIWoVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc
<c<01?l0003oC4a<oda<C?l00002ofIVIP06o`000?moOgooOgmoo`000?nIVIWo00000_nc/k<00ol0
003oc<c<olc<c007olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Go0000ogmoOol0003oIVIVo`00
0002oda<C003o`000?lc<c?o<c<c00Oo<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`00
0?nIVIWo0000ok>c/ol00009olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000
00;oC4a<00?o0000oc<c<olc<c<01_lc<c<00ol0003oooooooooo`03ooooo`7o00000Oooool1oooo
o`006_ooool00oo^k^koA4A4o`000007ooooo`03o`000?oooooooooo00?ooooo0onc/k<00ol0003o
VIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003o
C4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003o
VIVIoiVIV@0:oiVIV@03o`000?nc/k?o/k>c01Go/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0003o
OgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01_m<C4`3o`000003
oc<c<ol0003oC4a<00GoC4a<00?o0000ofIVI_mVIVH00_mVIVH01?l0003oOgmoogmoOol00003oiVI
V@03o`000?nc/k?o/k>c00;o/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c
/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc
<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH01_l0003oOgmoogmoOol0003oVIVIo`00
00?o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo
Ogmo00;o00000_m<C4`00ol0003o<c<coc<c<`07oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo0000
0_moOgl2o`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003o/k>co`000002oiVIV@;o0000
0_mVIVH01?l0003oC4a<oda<C?l00007oc<c<`03o`000?oooooooooo00Cooooo0Ol00001ooooo`7o
oooo000Kooooo`03ogMgMol0003ooooo00Kooooo00?o0000ooooooooool00oooool2ok>c/`03o`00
0?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0:ofIVIP;o0000
6?m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT0
2_nIVIT00ol0003o/k>cok>c/`0Eok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl0
0_moOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<00KoC4a<00Co0000oc<c<olc<c?o
00001om<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Go0000oiVIVOnIVIWoVIVIo`000004
ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl0
0002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01olc<c<01?l0003oC4a<
oda<C?l00002ofIVIP06o`000?moOgooOgmoo`000?nIVIWo00000onc/k<00ol0003oc<c<olc<c006
olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`00
0?lc<c?o<c<c00Oo<c<c00?o0000oda<C?l000000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o
/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003o/k>co`000002oiVIV@;o00000_mVIVH00ol0003o
C4a<o`000008oc<c<`03o`000?oooooooooo00Cooooo0Ol00001ooooo`7ooooo000Tooooo`03o`00
0?oooooooooo00?ooooo00?o/k>co`000?nIVIT03?nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`00
0?mVIVKoIVIV00[oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`00
0?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Eok>c/`03o`00
0?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP03ofIVIP03o`00
0?m<C4coC4a<00KoC4a<00Co0000oc<c<olc<c?o00001om<C4`01Ol0003oIVIVofIVI_mVIVKo0000
00?oOgmo00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000
ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<
00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Ko0000ogmoOomo
Ogoo0000oiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Goc<c<00Go0000ok>c/onc/k?o/k>co`00
0002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`03o`00
0?m<C4co000000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ko
c<c<00?o0000ok>c/ol000000_nIVIT2o`0000;oIVIV00?o0000oda<C?l000002?lc<c<00ol0003o
ooooooooo`04ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`03o`00
0?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0:ofIVIP03o`00
0?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`00
0?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05Onc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`00
0?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C006oda<C004o`00
0?lc<c?o<c<co`0000OoC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`05o`000?nIVIWoVIVI
oiVIVOl000001?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00?o/k>c00Co0000
oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c
00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Co0000ok>c
/onc/k?o00002?o<c<`02ol0003o/k>cok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000
00;oC4a<00?o0000oc<c<olc<c<01olc<c<00ol0003oC4a<o`000003ofIVIP;o000000GoVIVIo`00
0?nc/k?o/k>co`000008olc<c005o`000?nc/k?o/k>co`000?nIVIT00_l00002ofIVIP03o`000?m<
C4co000000So<c<c00?o0000oda<C?ooool01Oooool1o`00007ooooo0Oooool002Cooooo00?o0000
ooooooooool00oooool=oiVIV@03o`000?moOgooOgmo00SoOgmo0_l0000<ofIVIP03o`000?m<C4co
C4a<01OoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWo
VIVI00_oVIVI00?o0000ok>c/onc/k<05Onc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgoo
Ogmo00;oOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C006oda<C0;o000000?o<c<c
o`000?m<C4`01_m<C4`00ol0003oIVIVofIVIP02ofIVIP04o`000?moOgooOgmoo`0000?oVIVI00?o
0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co
0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko
<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP03o`000?moOgoo000000;oVIVI00Go0000ok>c
/onc/k?o/k>co`000008olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Go0000ogmoOol0003oIVIV
o`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00?o0000oda<C?l000000_mVIVH01Ol0003oOgmo
o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/ol0003oVIVI
00;o00000_mVIVH2o`0000Wo<c<c00?o0000oda<C?ooool01Oooool1o`00007ooooo0Oooool002Co
oooo00?o0000ooooooooool00oooool<oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mV
IVH02_mVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomo
Ogl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@;o00005onc/k<00ol0003oVIVIoiVIV@04oiVIV@03
o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C008oda<C003
o`000?m<C4coC4a<00KoC4a<00?o0000ofIVI_mVIVH00_mVIVH01?l0003oOgmoogmoOol00003oiVI
V@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c
/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c
<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH00ol0003oOgmoo`000002oiVIV@05o`00
0?nc/k?o/k>cok>c/ol000002?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000
ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Go
0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o
0000oiVIV@02o`0000;oIVIV0_l00009oc<c<`03o`000?m<C4cooooo00Gooooo0Ol00001ooooo`7o
oooo000Tooooo`;o00001?ooool;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH0
2_mVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl0
2?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT0
1?nIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<C4`0
4Om<C4`00ol0003oIVIVofIVIP02ofIVIP04o`000?moOgooOgmoo`0000?oVIVI00?o0000ok>c/onc
/k<00onc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnI
VIWo00000_moOgl01?l0003oIVIVofIVI_l00004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000
oda<C?m<C4`00_m<C4`00ol0003oIVIVofIVIP02o`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`00
0008olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<
oda<C?l00008oc<c<`03o`000?m<C4co000000;oIVIV00?o0000ogmoOol000000_nIVIT00ol0003o
/k>co`000008olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co
00002?lc<c<01?l0003oC4a<oda<C?l00004ooooo`;o00000_ooool002Cooooo00?o0000oooooooo
ool00oooool:oiVIV@03o`000?moOgooOgmo00SoOgmo0_l0000<ofIVIP03o`000?m<C4coC4a<01Oo
C4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_o
VIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00?o
Ogmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C00Boda<C005o`000?mVIVKoIVIVofIV
I_l000000omoOgl01Ol0003oVIVIoiVIVOnIVIWo000000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`0
0ol0003o/k>cok>c/`02ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01?l0003oIVIVofIV
I_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP03
o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`01_l0003o/k>cok>c/ol0003o
VIVIo`0000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<
C4coC4a<o`0000;oIVIV00Oo0000ogmoOol0003oVIVIo`000?nc/k?o000000Woc<c<00?o0000ok>c
/ol000000_nIVIT01ol0003oOgmoo`000?mVIVKo0000oda<C?l000002?lc<c<01?l0003oC4a<oda<
C?l00005ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`WoVIVI00?o
0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o
0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI0_l0
000Gok>c/`03o`000?nIVIWoVIVI00GoVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIV
IP03ofIVIP03o`000?m<C4coC4a<01;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`05o`00
0?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o
/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000
oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o0000ogmoOol000000_nI
VIT01?l0003o/k>cok>c/ol00009olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl00ol0
003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH0
1ol0003oOgmoo`000?nIVIWo0000ok>c/ol000002Oo<c<`01Ol0003o/k>co`000?nIVIWo000000;o
Ogmo00Go0000ofIVI_l0003oC4a<o`000008oc<c<`04o`000?m<C4coC4a<o`0000Gooooo0Ol00001
ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo2?nIVIT00ol0003oOgmoogmoO`08ogmo
O`03o`000?mVIVKoIVIV00_oIVIV0_l0000Goda<C0;o00003OmVIVH00ol0003oOgmoogmoO`08ogmo
O`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@05oiVI
V@03o`000?moOgooOgmo00?oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C00Boda<
C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01Ol0003oVIVIoiVIVOnIVIWo000000Go/k>c00?o
0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`02ok>c/`05o`000?nIVIWoVIVIoiVIVOl00000
0_moOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<
C4coC4a<o`000002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`0
1?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgooOgmo00;o00000_m<C4`00ol0003o<c<coc<c
<`07oc<c<`03o`000?m<C4co000000;oIVIV00?o0000ogmoOomoOgl00_l00002ok>c/`03o`000?o<
c<coc<c<00Koc<c<00?o0000ok>c/ol000000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<
00?o0000oc<c<olc<c<01_lc<c<00ol0003oC4a<o`000006ooooo`7o00000Oooool1ooooo`009?oo
ool00ol0003oooooooooo`03ooooo`OoVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIV
IP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmo
O`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVI
V@05oiVIV@03o`000?moOgooOgmo00?oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<
C00Boda<C003o`000?mVIVKoIVIV00;oIVIV00Co0000ogmoOomoOgoo00000onIVIT2o`0000Co/k>c
00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`03o`000?nIVIWoVIVI00;o0000
00?oOgmoo`000?l000000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Oo0000oda<C?m<
C4coC4a<o`000?mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo00000_nc/k<00ol0003oc<c<olc<
c006olc<c006o`000?nc/k?o/k>cok>c/ol0003oVIVI0_l000001?moOgoo0000ofIVI_l00002oda<
C003o`000?lc<c?o<c<c00Oo<c<c00?o0000oda<C?l000000_mVIVH01Ol0003oOgmoo`000?nIVIWo
000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003o/k>co`000002oiVIV@07o`000?moOgoo
0000ofIVI_l0003oC4a<o`000008oc<c<`04o`000?m<C4coC4a<o`0000Kooooo0Ol00001ooooo`7o
oooo000Tooooo`03o`000?oooooooooo00?ooooo1_nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`00
0?mVIVKoIVIV00coIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`00
0?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`00
0?nIVIWoVIVI00GoVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIVIP02ofIVIP03o`00
0?m<C4coC4a<01;oC4a<00?o0000ofIVI_mVIVH00_mVIVH01?l0003oOgmoogmoOol00003oiVIV@03
o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04
o`000?nIVIWoVIVIo`0000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000003oda<C003o`000?lc<c?o
<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`00ol0003oIVIVo`000002ogmoO`04o`000?nIVIWo
VIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@06o`00
0?moOgooOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`07oc<c<`05o`000?m<C4co0000
ofIVI_l000000_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o0000
ok>c/ol000000_nIVIT01?l0003oOgmoo`000?l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co
0000oda<C?m<C4co00001_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00ooo
ool6oiVIV@03o`000?moOgooOgmo00OoOgmo00?o0000ofIVI_mVIVH03?mVIVH00ol0003oC4a<oda<
C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVI
V@0<oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmo
O`03ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`04_m<C4`00ol0003oIVIVofIV
IP02ofIVIP05o`000?moOgooOgmoogmoOol000000onIVIT00ol0003o/k>cok>c/`03ok>c/`03o`00
0?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;o
Ogmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<
oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<
00Co0000ok>c/onc/k?o00000_nIVIT01_l0003oOgmoogmoOol0003oIVIVo`0000;oC4a<00?o0000
oc<c<olc<c<01_lc<c<00ol0003oC4a<o`000002ofIVIP06o`000?moOgooOgmoo`000?nIVIWo0000
0_nc/k<00ol0003oc<c<olc<c005olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Co0000ogmoOol0
003o00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4co0000ofIVI_l000001Oooool1
o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool5oiVIV@03o`000?moOgooOgmo
00OoOgmo00?o0000ofIVI_mVIVH03?mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV
00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c
01Oo/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV
00?oIVIV00?o0000oda<C?m<C4`04_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Go0000
oiVIVOnIVIWoVIVIo`000005ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc
/k<01?l0003oVIVIoiVIVOl00002ogmoO`05o`000?mVIVKoIVIVofIVI_l000000om<C4`00ol0003o
<c<coc<c<`05oc<c<`05o`000?m<C4coC4a<oda<C?l000000omVIVH01_l0003oOgmoogmoOol0003o
VIVIo`0000?o/k>c00?o0000olc<c?o<c<`01Oo<c<`01ol0003o/k>cok>c/onc/k?o0000oiVIVOl0
00000_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00?o0000oda<C?l0
00000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`03?l0
003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000Wo<c<c00Go0000oda<
C?l0003oIVIVo`000005ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03oooo
o`?oVIVI0_l00009ogmoO`;o00003OmVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV
00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0:oiVIV@;o00006?nc/k<2o`00
00OoVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<
017oC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000?oVIVI00?o0000
ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00;o/k>c00Go0000
oiVIVOnIVIWoVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<0
1_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01?l0
003o/k>cok>c/ol00008olc<c007o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000002ogmoO`03o`00
0?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP05
o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c00<o`000?nc/k?o/k>c
o`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co00002Olc<c<2o`000003ofIVI_l0003ooooo
00Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo0onIVIT00ol0003o
OgmoogmoO`07ogmoO`03o`000?mVIVKoIVIV00coIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003o
IVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o
/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00OoVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003o
IVIVofIVIP03ofIVIP03o`000?m<C4coC4a<017oC4a<00?o0000ofIVI_mVIVH00_mVIVH01?l0003o
OgmoogmoOol00004oiVIV@03o`000?nc/k?o/k>c00;o/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0
003o/k>cok>c/`02ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01?l0003oIVIVofIVI_l0
0003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`00
0?moOgooOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01ol0003o/k>cok>c/onc/k?o
0000oiVIVOl000000_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co
0000oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<
c<`01_o<c<`01Ol0003o/k>cok>c/ol0003oVIVI00;o00000_mVIVH00ol0003oC4a<o`000009oc<c
<`;o000000?oIVIVo`000?ooool01Oooool1o`00007ooooo0Oooool002Cooooo00?o0000oooooooo
ool00oooool2oiVIV@03o`000?moOgooOgmo00OoOgmo00?o0000ofIVI_mVIVH03?mVIVH00ol0003o
C4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003o
VIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT01_nIVIT00ol0003o
OgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<C4`04Om<C4`00ol0003o
IVIVofIVIP02ofIVIP05o`000?moOgooOgmoogmoOol000000onIVIT00ol0003o/k>cok>c/`03ok>c
/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo
000000;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<
C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@04o`000?nc/k?o/k>co`00
00Soc<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo0000
0_m<C4`00ol0003o<c<coc<c<`05oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol0
00000_nIVIT00ol0003o/k>co`000008olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0
003oIVIVo`000?m<C4co00002Olc<c<01Ol0003oC4a<o`000?l0003oOgmo00Kooooo0Ol00001oooo
o`7ooooo000Tooooo`;o00001?ooool2o`0000WoOgmo0_l0000=ofIVIP03o`000?m<C4coC4a<01Ko
C4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00[o
VIVI0_l0000Iok>c/`03o`000?nIVIWoVIVI00KoVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003o
IVIVofIVIP03ofIVIP03o`000?m<C4coC4a<01;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmo
O`04o`000?nIVIWoVIVIoiVIV@;o00001?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o
/k>c00;o/k>c00?o0000oiVIVOnIVIT00_l00002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o
0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Ko0000ogmoOomoOgoo
0000oiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00So0000ok>c/onc/k?o/k>co`000?nI
VIWo0000ogmoO`;o000000GoIVIVo`000?m<C4coC4a<o`000008oc<c<`07o`000?m<C4coC4a<o`00
0?mVIVKo0000ogmoO`02o`000004oiVIVOl0003o/k>co`0000Woc<c<00co0000ok>c/onc/k?o0000
oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00008oc<c<`03o`000?m<C4coC4a<00;o000000?o
Ogmoooooooooool00oooool2o`0000;ooooo000Tooooo`03o`000?oooooooooo00?ooooo2_moOgl0
0ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH0
0ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<0
0ol0003oVIVIoiVIV@06oiVIV@03o`000?moOgooOgmo00?oOgmo00?o0000ofIVI_mVIVH00omVIVH0
0ol0003oC4a<oda<C00Coda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01Ol0003oVIVIoiVI
VOnIVIWo000000Go/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`04o`00
0?nIVIWoVIVIo`0000?oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c
<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01_l0003oOgmoogmoOol0003oVIVIo`0000?o/k>c
00?o0000olc<c?o<c<`01_o<c<`02Ol0003o/k>cok>c/onc/k?o0000oiVIVOl0003oOgmoo`000002
ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00So0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`00
00;oVIVI00?o0000ok>c/ol000002Oo<c<`00ol0003o/k>cok>c/`02o`0000;oOgmo00Go0000ofIV
I_l0003oC4a<o`000008oc<c<`03o`000?m<C4coC4a<00;o000000?oOgmoo`000?ooool01?ooool1
o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool9ogmoO`03o`000?mVIVKoIVIV
00coIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo
00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI
00KoVIVI00?o0000ogmoOomoOgl01?moOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<
01;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001Onc
/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo0000
0omoOgl01Ol0003oIVIVofIVI_mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003o
C4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01?l0003o/k>cok>c/ol0
0008olc<c009o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000?moOgoo000000;oIVIV00Co0000oda<
C?m<C4co00002?lc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00?o0000oiVIVOl00000
0_nc/k<00ol0003oc<c<olc<c006olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003o
IVIVo`000?m<C4co00002Olc<c<01ol0003oC4a<o`000?mVIVKo0000ogmoOol000001Oooool1o`00
007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool9ogmoO`03o`000?mVIVKoIVIV00_o
IVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00Wo
Ogmo00?o0000oiVIVOnIVIT02_nIVIT2o`0001Wo/k>c00?o0000oiVIVOnIVIT01_nIVIT00ol0003o
OgmoogmoO`04ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<C4`04_m<C4`00ol0003o
IVIVofIVIP02ofIVIP05o`000?moOgooOgmoogmoOol000000onIVIT00ol0003o/k>cok>c/`03ok>c
/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00onc/k<01?l0003oVIVIoiVIVOl00002
ogmoO`05o`000?mVIVKoIVIVofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<
C4coC4a<oda<C?l000000_mVIVH01_l0003oOgmoo`000?l0003oVIVIo`0000?o/k>c00?o0000olc<
c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000
oda<C?m<C4co00002?lc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00?o0000oiVIVOl0
00000_nc/k<00ol0003oc<c<olc<c006olc<c003o`000?nc/k?o000000;oVIVI00Oo0000ogmoOol0
003oIVIVo`000?m<C4co000000So<c<c00Go0000oda<C?m<C4co0000ofIVIP02o`0000Kooooo0Ol0
0001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo2?moOgl00ol0003oIVIVofIVIP0;
ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`09
ogmoO`03o`000?nIVIWoVIVI00[oVIVI00?o0000ok>c/onc/k<06?nc/k<00ol0003oVIVIoiVIV@07
oiVIV@03o`000?moOgooOgmo00CoOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00B
oda<C003o`000?mVIVKoIVIV00;oIVIV00Co0000ogmoOomoOgoo00001?nIVIT00ol0003o/k>cok>c
/`03ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00onc/k<01?l0003oVIVIoiVI
VOl00002ogmoO`05o`000?mVIVKoIVIVofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`04
o`000?m<C4coC4a<o`0000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01Ol0003o/k>cok>c/onc
/k?o000000Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`00
0?m<C4coC4a<o`0000So<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`03o`000?nIVIWo
000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003o/k>co`000002oiVIV@04o`000?moOgoo
0000o`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?l0003oIVIV00;o0000
1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool7ogmoO`03o`000?mV
IVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?mo
OgooOgmo00SoOgmo0_l0000<oiVIV@03o`000?nc/k?o/k>c01So/k>c00?o0000oiVIVOnIVIT01onI
VIT00ol0003oOgmoogmoO`04ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<C4`04_m<
C4`00ol0003oIVIVofIVIP02ofIVIP05o`000?moOgooOgmoogmoOol000000onIVIT00ol0003o/k>c
ok>c/`03ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00onc/k<01?l0003oVIVI
oiVIVOl00002ogmoO`05o`000?mVIVKoIVIVofIVI_l000001?m<C4`00ol0003o<c<coc<c<`05oc<c
<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH00ol0003oOgmoo`000002oiVIV@05o`000?nc/k?o
/k>cok>c/ol000002?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV
00Co0000oda<C?m<C4co00002?lc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00?o0000
oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000
ogmoOol0003oIVIVo`000?m<C4co00002?lc<c<02?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo
00001_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool6ogmoO`03o`00
0?mVIVKoIVIV00[oIVIV0_l0000Goda<C0;o00003OmVIVH00ol0003oOgmoogmoO`08ogmoO`03o`00
0?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<06?nc/k<00ol0003oVIVIoiVIV@07oiVIV@03o`00
0?moOgooOgmo00CoOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00Boda<C003o`00
0?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgooOgmoo`000003oiVIV@;o00001?nc/k<2o`0000Ko
c<c<00?o0000ok>c/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Co0000ofIV
I_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Ko0000
ofIVI_mVIVKo0000ogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Woc<c<00Co0000ok>c/onc
/k?o00000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Ko0000
oda<C?m<C4co0000ofIVI_l00002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`0
1_o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000So<c<c
00So0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000Kooooo0Ol00001ooooo`7ooooo000Toooo
o`03o`000?oooooooooo00?ooooo1OmoOgl00ol0003oIVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<
01KoC4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI
00_oVIVI00?o0000ok>c/onc/k<06?nc/k<00ol0003oVIVIoiVIV@08oiVIV@03o`000?moOgooOgmo
00CoOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00Boda<C003o`000?mVIVKoIVIV
00;oIVIV00Go0000ogmoOomoOgooOgmoo`000003oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000
olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Go
0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`0
0_m<C4`01_l0003oIVIVofIVI_l0003oOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`0
1?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co0000
2?lc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo0_l00003ok>c/`03o`000?o<c<coc<c<
00Koc<c<00Go0000ok>c/onc/k?o0000oiVIV@02o`0000;oIVIV00?o0000oda<C?l000002?lc<c<0
2?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo00001_ooool1o`00007ooooo0Oooool002Cooooo
00?o0000ooooooooool00oooool4ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`0
5_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT0
2onIVIT00ol0003o/k>cok>c/`0Hok>c/`03o`000?nIVIWoVIVI00SoVIVI00?o0000ogmoOomoOgl0
1?moOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<01;oC4a<00?o0000ofIVI_mVIVH0
0_mVIVH01Ol0003oOgmoogmoOomoOgoo000000?oVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003o
c<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmo
O`05o`000?mVIVKoIVIVofIVI_l000000om<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4co
C4a<00;oC4a<00Ko0000ofIVI_mVIVKo0000ogmoOol00002oiVIV@05o`000?nc/k?o/k>cok>c/ol0
00002?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo000000?oIVIV00Co0000oda<
C?m<C4co00001olc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00?o0000oiVIVOl00000
0_nc/k<00ol0003oc<c<olc<c006olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003o
IVIVo`000?m<C4co00002Olc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000005
ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`?oOgmo00?o0000ofIV
I_mVIVH02_mVIVH2o`0001SoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmo
O`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<06?nc/k<00ol0003oVIVIoiVIV@07oiVI
V@;o00001_moOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000ofIV
I_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000?oVIVI00?o0000ok>c/onc/k<00onc/k<0
0ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Co0000oiVIVOnIVIWo00000omo
Ogl01?l0003oIVIVofIVI_l00004oda<C003o`000?lc<c?o<c<c00Go<c<c00Go0000oda<C?m<C4co
C4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008
olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<
C?l00008oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl01Ol0003oVIVIo`000?nc/k?o
000000Woc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00009
oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000Gooooo0Ol00001ooooo`7o
oooo000Tooooo`;o00001?ooool2ogmoO`03o`000?mVIVKoIVIV00[oIVIV00?o0000oda<C?m<C4`0
5om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT0
2onIVIT00ol0003o/k>cok>c/`0Hok>c/`03o`000?nIVIWoVIVI00SoVIVI00?o0000ogmoOomoOgl0
1?moOgl00ol0003oIVIVofIVIP04ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH0
0_mVIVH01?l0003oOgmoogmoOol00004oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<
c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`04o`000?nIVIWoVIVIo`0000?oOgmo00Co0000ofIV
I_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`05oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mV
IVH01?l0003oOgmoogmoOol00002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01_l0003o
/k>cok>c/ol0003oVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo00000_m<C4`00ol0003o<c<coc<c
<`06oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVIV@03o`000?nc/k?o0000
00Woc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00009oc<c
<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000Cooooo0_l00002ooooo`009?oo
ool00ol0003oooooooooo`03ooooo`03ogmoOol0003oIVIV00_oIVIV00?o0000oda<C?m<C4`05om<
C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onI
VIT00ol0003o/k>cok>c/`0Gok>c/`;o00002_nIVIT00ol0003oOgmoogmoO`04ogmoO`03o`000?mV
IVKoIVIV00CoIVIV00?o0000oda<C?m<C4`04om<C4`00ol0003oIVIVofIVIP02ofIVIP05o`000?mo
OgooOgmoogmoOol000000onIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00Coc<c<
00?o0000ok>c/onc/k<00onc/k<01?l0003oVIVIoiVIVOl00003ogmoO`04o`000?mVIVKoIVIVo`00
00CoC4a<00?o0000oc<c<olc<c<01Olc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000
ogmoOomoOgoo00000onIVIT01?l0003o/k>cok>c/ol00008olc<c004o`000?nc/k?o/k>co`0000;o
VIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`06o`000?m<C4coC4a<
o`000?mVIVKo00000_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00co
0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00009oc<c<`09o`000?m<
C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000Kooooo0Ol00001ooooo`7ooooo000Tooooo`03
o`000?oooooooooo00?ooooo00?o0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<oda<C00Goda<C003
o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03
o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02OnIVIT00ol0003oOgmoogmoO`04ogmoO`03
o`000?mVIVKoIVIV00CoIVIV00?o0000oda<C?m<C4`04om<C4`00ol0003oIVIVofIVIP02ofIVIP05
o`000?moOgooOgmoogmoOol000000onIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<
00Coc<c<00?o0000ok>c/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Go0000
ofIVI_mVIVKoIVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<
o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00?o0000ok>c/onc/k<00_l00007olc<c005
o`000?nc/k?o/k>cok>c/ol000000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<
o`0000So<c<c00So0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000;oVIVI00Co0000ok>c/onc
/k?o00002?o<c<`00ol0003o/k>co`000002oiVIV@07o`000?moOgoo0000ofIVI_l0003oC4a<o`00
0008oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000Kooooo0Ol00001
ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo3?mVIVH00ol0003oC4a<oda<C00Goda<
C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVI
V@;o00005onc/k<2o`0000_oVIVI00?o0000ogmoOomoOgl01OmoOgl00ol0003oIVIVofIVIP04ofIV
IP03o`000?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo
000000?oVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o
/k>c00;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`05o`000?mVIVKoIVIVofIVI_l00000
0om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003o
OgmoogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Go0000ok>c/onc/k?o/k>co`00
0002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<02?l0003oC4a<
oda<C?l0003oIVIVo`000?moOgoo00000_nIVIT01?l0003o/k>cok>c/ol00008olc<c003o`000?nc
/k?o000000;oVIVI00Oo0000ogmoOol0003oIVIVo`000?m<C4co000000So<c<c00[o0000oda<C?m<
C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00001_ooool1o`00007ooooo0Oooool002Cooooo00?o
0000ooooooooool00oooool;ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02omV
IVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc
/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00CoOgmo00?o0000ofIVI_mVIVH01?mV
IVH00ol0003oC4a<oda<C00Coda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgooOgmo
o`000004oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>c
ok>c/`03ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000003oda<
C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgoo
Ogmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@03
o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<01?l0003oC4a<oda<C?l00002
ofIVIP;o00000_nIVIT01?l0003o/k>cok>c/ol00008olc<c00<o`000?nc/k?o/k>co`000?nIVIWo
0000ogmoOol0003oIVIVo`000?m<C4co00002?lc<c<02ol0003oC4a<oda<C?l0003oIVIVo`000?mo
Ogoo0000oiVIVOl0003o/k>c00Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo
00?ooooo2_mVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmo
OomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVI
VOnIVIT02onIVIT00ol0003oOgmoogmoO`04ogmoO`;o00001OmVIVH00ol0003oC4a<oda<C00Coda<
C003o`000?mVIVKoIVIV00;oIVIV00?o0000ogmoOomoOgl00_moOgl01Ol0003oVIVIoiVIVOnIVIWo
000000Go/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`05o`000?nIVIWo
VIVIoiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00004oda<C003o`000?lc<c?o<c<c00Ko<c<c
00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Co0000ok>c
/onc/k?o00002Oo<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00?o0000ofIVI_l00000
0om<C4`00ol0003o<c<coc<c<`06oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002
oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00?o0000ok>c/ol000000_nIVIT01ol0003oOgmoo`00
0?mVIVKo0000oda<C?l000002?lc<c<02ol0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVI
VOl0003o/k>c00Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo2_mV
IVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?mo
Ogl00ol0003oVIVIoiVIV@0;oiVIV@;o00005onc/k<2o`0000coVIVI00?o0000ogmoOomoOgl01Omo
Ogl00ol0003oIVIVofIVIP04ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH00_mV
IVH01Ol0003oOgmoogmoOomoOgoo000000CoVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<
olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`04
o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co
000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01?l0003o/k>cok>c/ol00009olc<c006o`00
0?nc/k?o/k>co`000?nIVIWo00000_moOgl00ol0003oIVIVo`000003oda<C003o`000?lc<c?o<c<c
00Ko<c<c00So0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000;oVIVI00?o0000ok>c/ol00000
2Oo<c<`00ol0003o/k>co`000002oiVIV@07o`000?moOgoo0000ofIVI_l0003oC4a<o`000008oc<c
<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00001Oooool1o`00
007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool8ofIVIP;o00005om<C4`2o`0000go
IVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko
/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV00Co
IVIV00?o0000oda<C?m<C4`04om<C4`00ol0003oIVIVofIVIP02ofIVIP03o`000?moOgooOgmo00;o
Ogmo00Go0000oiVIVOnIVIWoVIVIo`000005ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c
/onc/k<00onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo00001?m<
C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmo
ogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Woc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl0
0002ogmoO`04o`000?mVIVKoIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02?l0003oC4a<
oda<C?l0003oIVIVo`000?moOgoo00000_nIVIT01?l0003o/k>cok>c/ol00008olc<c003o`000?nc
/k?o000000;oVIVI00Oo0000ogmoOol0003oIVIVo`000?m<C4co000000Wo<c<c00?o0000oda<C?l0
00000_mVIVH2o`000005oiVIVOl0003o/k>cok>c/ol000001Oooool1o`00007ooooo0Oooool001Wo
oooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooooooo00?ooooo1omVIVH00ol0
003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl02?moOgl00ol0
003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0
003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV00CoIVIV00?o0000oda<C?m<C4`04om<C4`00ol0
003oIVIVofIVIP03ofIVIP05o`000?moOgooOgmoogmoOol000000onIVIT00ol0003o/k>cok>c/`04
ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00onc/k<01?l0003oVIVIoiVIVOl0
0003ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<
oda<C002oda<C006o`000?mVIVKoIVIVo`000?moOgoo00000_nIVIT01Ol0003o/k>cok>c/onc/k?o
000000Soc<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo00?o0000ofIVI_l00000
0_m<C4`00ol0003o<c<coc<c<`07oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002
oiVIV@03o`000?nc/k?o000000Woc<c<00?o0000ok>c/ol000000_nIVIT01ol0003oOgmoo`000?mV
IVKo0000oda<C?l000002Olc<c<02ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc
/k?o000000Kooooo0Ol00001ooooo`7ooooo000Iooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_oo
ool00ol0003oooooooooo`03ooooo`OoIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIV
IP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c
/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl01?moOgl00ol0003oIVIVofIV
IP05ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH00omVIVH01Ol0003oOgmoogmo
OomoOgoo000000?oVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c005olc<c003o`00
0?nc/k?o/k>c00?o/k>c00Co0000oiVIVOnIVIWo00000omoOgl01?l0003oIVIVofIVI_l00004oda<
C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01_l0003oIVIVofIVI_l0003o
Ogmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c007o`000?nc/k?o/k>cok>c/ol0
003oVIVIo`000002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01olc<c<02?l0
003oC4a<oda<C?l0003oIVIVo`000?moOgoo00000_nIVIT00ol0003o/k>co`000009olc<c003o`00
0?nc/k?o000000;oVIVI00Oo0000ogmoOol0003oIVIVo`000?m<C4co000000Wo<c<c00_o0000oda<
C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`000006ooooo`7o00000Oooool1ooooo`00
6Oooool01Ol0003ooooooooooooooooo000000Kooooo0ol00003ooooo`KoIVIV00?o0000oda<C?m<
C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnI
VIT03?nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomo
Ogl01OmoOgl00ol0003oIVIVofIVIP04ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIVI_mV
IVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000CoVIVI00?o0000ok>c/onc/k<00onc/k<00ol0
003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Co0000oiVIVOnIVIWo00000omoOgl0
1Ol0003oIVIVofIVI_mVIVKo000000CoC4a<00?o0000oc<c<olc<c<01Olc<c<01Ol0003oC4a<oda<
C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01Ol0003o/k>cok>c/onc/k?o0000
00Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT01_l0003oOgmoogmoOol0003oIVIVo`0000;oC4a<
00?o0000oc<c<olc<c<01olc<c<02?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo00000_nIVIT0
0ol0003o/k>co`000009olc<c005o`000?nc/k?o0000oiVIVOl000000_moOgl01Ol0003oIVIVo`00
0?m<C4co000000So<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c
/ol00004ooooo`?o00000_ooool001Wooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`03o`00
0?oooooooooo00?ooooo1OmVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV
00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c
00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV00GoIVIV
00?o0000oda<C?m<C4`04om<C4`00ol0003oIVIVofIVIP03ofIVIP05o`000?moOgooOgmoogmoOol0
00000onIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc
/k<00onc/k<01?l0003oVIVIoiVIVOl00003ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000
oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C006o`000?mVIVKoIVIVo`000?moOgoo0000
0_nIVIT00ol0003o/k>cok>c/`02ok>c/`03o`000?o<c<coc<c<00Goc<c<00Oo0000ok>c/onc/k?o
/k>co`000?nIVIWo000000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c
<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000So
c<c<00?o0000ok>c/ol000000_nIVIT01ol0003oOgmoo`000?mVIVKo0000oda<C?l000002Olc<c<0
3?l0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o0000olc<c0Kooooo0Ol00001
ooooo`7ooooo000Iooooo`05o`000?mEEEGo0000oa0@4?o<c<`01_ooool00ol0003oooooooooo`03
ooooo`CoIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgoo
Ogmo00WoOgmo00?o0000oiVIVOnIVIT02_nIVIT2o`0001Oo/k>c0_l0000=oiVIV@03o`000?moOgoo
Ogmo00GoOgmo0_l00006ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH00_mVIVH0
1Ol0003oOgmoogmoOomoOgoo000000CoVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<
c003olc<c003o`000?nc/k?o/k>c00?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`05o`00
0?mVIVKoIVIVofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<
C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<
c<`01ol0003o/k>cok>c/onc/k?o0000oiVIVOl000000_moOgl00ol0003oIVIVo`000002oda<C003
o`000?lc<c?o<c<c00Oo<c<c00So0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000;oVIVI00Co
0000ok>c/onc/k?o00002?o<c<`00ol0003o/k>co`000002oiVIV@07o`000?moOgoo0000ofIVI_l0
003oC4a<o`000008oc<c<`0=o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc
/k?o0000olc<c006ooooo`7o00000Oooool1ooooo`006Oooool00omEEEGoQhN7ooooo`08ooooo`03
o`000?oooooooooo00?ooooo0omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_o
IVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko
/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV00Ko
IVIV00?o0000oda<C?m<C4`05?m<C4`00ol0003oIVIVofIVIP02ofIVIP05o`000?moOgooOgmoogmo
Ool000001?nIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c
/onc/k<00onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo00001?m<
C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmo
ogmoOol00002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01ol0003o/k>cok>c/onc/k?o
0000oiVIVOl000000_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00So
0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`0
0ol0003o/k>co`000002oiVIV@07o`000?moOgoo0000ofIVI_l0003oC4a<o`000008oc<c<`0=o`00
0?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o0000olc<c006ooooo`7o0000
0Oooool1ooooo`006Oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo00?ooooo0_mV
IVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02Omo
Ogl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onI
VIT00ol0003oOgmoogmoO`06ogmoO`03o`000?mVIVKoIVIV00GoIVIV00?o0000oda<C?m<C4`05?m<
C4`00ol0003oIVIVofIVIP02ofIVIP05o`000?moOgooOgmoogmoOol000001?nIVIT00ol0003o/k>c
ok>c/`04ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00onc/k<01Ol0003oVIVI
oiVIVOnIVIWo000000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000003oda<C003o`000?lc<c?o<c<c
00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Go
0000ok>c/onc/k?o/k>co`000008olc<c007o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000002ogmo
O`03o`000?mVIVKo000000;oC4a<0_l00008oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmo
Ool00002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003o
Ogmoo`000?mVIVKo0000oda<C?l00008oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0
003oVIVIo`000?nc/k?o00000_o<c<`6ooooo`7o00000Oooool1ooooo`006_ooool01?o<c<coA4A4
o`000?l@4106ooooo`03o`000?oooooooooo00?ooooo00?oIVIVo`000?m<C4`05om<C4`00ol0003o
IVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02_nIVIT2o`0001Oo
/k>c0_l0000=oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0003o
C4a<oda<C00Doda<C003o`000?mVIVKoIVIV00;oIVIV00?o0000ogmoOomoOgl00_moOgl01Ol0003o
VIVIoiVIVOnIVIWo000000Ko/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`04ok>c
/`04o`000?nIVIWoVIVIo`0000?oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c
<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@05
o`000?nc/k?o/k>cok>c/ol000002?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@06o`000?moOgoo
Ogmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`09o`000?m<C4coC4a<oda<C?l0
003oIVIVo`000?moOgoo000000;oVIVI00?o0000ok>c/ol000002Oo<c<`00ol0003o/k>co`000002
oiVIV@07o`000?moOgoo0000ofIVI_l0003oC4a<o`000008oc<c<`0<o`000?m<C4coC4a<o`000?mV
IVKo0000ogmoOol0003oVIVIo`000?nc/k?o00000_o<c<`6ooooo`7o00000Oooool1ooooo`009?oo
ool00ol0003oooooooooo`03ooooo`03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omV
IVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc
/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH01_mV
IVH00ol0003oC4a<oda<C00Coda<C003o`000?mVIVKoIVIV00?oIVIV00?o0000ogmoOomoOgl00_mo
Ogl01Ol0003oVIVIoiVIVOnIVIWo000000Go/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>c
ok>c/`03ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01?l0003oIVIVofIVI_l00004oda<
C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP06o`000?moOgoo
Ogmoo`000?nIVIWo00001?nc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`0000;o
VIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`0;o`000?m<C4coC4a<
oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c003
o`000?nc/k?o000000;oVIVI00Oo0000ogmoOol0003oIVIVo`000?m<C4co000000So<c<c00co0000
oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00002olc<c0Kooooo0Ol00001
ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo6?m<C4`00ol0003oIVIVofIVIP0;ofIV
IP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c
/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl01_moOgl00ol0003oIVIVofIVIP06ofIV
IP03o`000?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`02ogmo
O`05o`000?nIVIWoVIVIoiVIVOl000001_nc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o
/k>c00?o/k>c00Co0000oiVIVOnIVIWo00000omoOgl01?l0003oIVIVofIVI_l00004oda<C003o`00
0?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`00
00;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Ko
0000ogmoOomoOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Wo0000oda<C?m<
C4coC4a<o`000?mVIVKo0000ogmoOol000000_nIVIT00ol0003o/k>co`000009olc<c003o`000?nc
/k?o000000;oVIVI00Oo0000ogmoOol0003oIVIVo`000?m<C4co000000Wo<c<c00?o0000oda<C?l0
00000_mVIVH2o`000005oiVIVOl0003o/k>cok>c/ol000000_o<c<`6ooooo`7o00000Oooool1oooo
o`009?ooool00ol0003oooooooooo`03oooooaOoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003o
OgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00[oVIVI0_l0000Gok>c/`;o00003OnIVIT00ol0003o
OgmoogmoO`07ogmoO`03o`000?mVIVKoIVIV00GoIVIV00?o0000oda<C?m<C4`05?m<C4`00ol0003o
IVIVofIVIP02ofIVIP03o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o
/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00onc/k<01Ol0003o
VIVIoiVIVOnIVIWo000000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o
<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nI
VIWoVIVIo`0000;o/k>c0_l00008olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol0
00000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`09o`000?m<C4coC4a<oda<C?l0003oIVIVo`00
0?moOgoo000000;oVIVI00?o0000ok>c/ol000002Oo<c<`00ol0003o/k>co`000002oiVIV@07o`00
0?moOgoo0000ofIVI_l0003oC4a<o`000009oc<c<`0;o`000?m<C4co0000ofIVI_l0003oOgmoo`00
0?nIVIWo0000ok>c/ol000000oo<c<`6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003ooooo
ooooo`03oooooaKoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`00
0?nIVIWoVIVI00[oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`00
0?moOgooOgmo00OoOgmo00?o0000ofIVI_mVIVH01_mVIVH00ol0003oC4a<oda<C00Doda<C003o`00
0?mVIVKoIVIV00;oIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@02oiVIV@03o`00
0?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`03ok>c/`05o`00
0?nIVIWoVIVIoiVIVOl000000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000CoC4a<00?o0000oc<c
<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co0000
oiVIVOnIVIWo00000_nc/k<00ol0003oc<c<olc<c007olc<c004o`000?nc/k?o/k>co`0000;oVIVI
00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`09o`000?m<C4coC4a<oda<
C?l0003oIVIVo`000?moOgoo000000;oVIVI00?o0000ok>c/ol000002Oo<c<`00ol0003o/k>co`00
0002oiVIV@07o`000?moOgoo0000ofIVI_l0003oC4a<o`000009oc<c<`0;o`000?m<C4co0000ofIV
I_l0003oOgmoo`000?nIVIWo0000ok>c/ol000000oo<c<`6ooooo`7o00000Oooool1ooooo`009?oo
ool00ol0003oooooooooo`03oooooaGoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmo
O`08ogmoO`;o00003?nIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o
0000ogmoOomoOgl01omoOgl00ol0003oIVIVofIVIP06ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o
0000ofIVI_mVIVH00_mVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o
0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c00?o/k>c00Go
0000oiVIVOnIVIWoVIVIo`000003ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc
<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co0000oiVI
VOnIVIWo00000_nc/k<00ol0003oc<c<olc<c007olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o
0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`09o`000?m<C4coC4a<oda<C?l0
003oIVIVo`000?moOgoo000000;oVIVI00?o0000ok>c/ol000002Oo<c<`00ol0003o/k>co`000002
oiVIV@07o`000?moOgoo0000ofIVI_l0003oC4a<o`000009oc<c<`03o`000?m<C4coC4a<00;o0000
00CoOgmoo`000?nIVIWoVIVI0_l00004olc<c0Kooooo0Ol00001ooooo`7ooooo000Tooooo`;o0000
1?oooolCoda<C0;o00003OmVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI
00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00OoOgmo
00?o0000ofIVI_mVIVH01_mVIVH00ol0003oC4a<oda<C00Doda<C003o`000?mVIVKoIVIV00?oIVIV
00Go0000ogmoOomoOgooOgmoo`000004oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<
c<`00oo<c<`00ol0003o/k>cok>c/`04ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01Ol0
003oIVIVofIVI_mVIVKo000000CoC4a<00?o0000oc<c<olc<c<01Olc<c<01Ol0003oC4a<oda<C?m<
C4co000000?oIVIV00?o0000ogmoOol000000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<
00Go0000ok>c/onc/k?o/k>co`000002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<
C4co00002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc
/k<00ol0003oc<c<olc<c007olc<c003o`000?nc/k?o000000;oVIVI00Oo0000ogmoOol0003oIVIV
o`000?m<C4co000000So<c<c0_l000002_m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c
/ol00004olc<c0Gooooo0_l00002ooooo`009?ooool00ol0003oooooooooo`03oooooa;oC4a<00?o
0000ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o
0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o
0000ofIVI_mVIVH01_mVIVH00ol0003oC4a<oda<C00Coda<C003o`000?mVIVKoIVIV00CoIVIV00Go
0000ogmoOomoOgooOgmoo`000004oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`0
0_o<c<`00ol0003o/k>cok>c/`05ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01Ol0003o
IVIVofIVI_mVIVKo000000CoC4a<00?o0000oc<c<olc<c<01Olc<c<01Ol0003oC4a<oda<C?m<C4co
000000?oIVIV00?o0000ogmoOol000000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Go
0000ok>c/onc/k?o/k>co`000002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co
00002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<0
0ol0003oc<c<olc<c007olc<c003o`000?nc/k?o000000;oVIVI00Oo0000ogmoOol0003oIVIVo`00
0?m<C4co000000So<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c
/ol00004olc<c0Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo4_m<
C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onI
VIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?mo
Ogl00ol0003oIVIVofIVIP06ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH00omV
IVH01Ol0003oOgmoogmoOomoOgoo000000CoVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<
olc<c003olc<c003o`000?nc/k?o/k>c00Co/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`05
o`000?mVIVKoIVIVofIVI_l000001?m<C4`00ol0003o<c<coc<c<`05oc<c<`05o`000?m<C4coC4a<
oda<C?l000000omVIVH00ol0003oOgmoo`000002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<
c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<
oda<C?l00009oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c
00?o0000olc<c?o<c<`01oo<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0
0002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?l0003oIVIVo`000002ogmoO`;o0000
0_nc/k<00ol0003oc<c<olc<c002olc<c0Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oo
oooooooo00?ooooo4Om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o
0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00[oVIVI0_l0
000:ogmoO`03o`000?mVIVKoIVIV00KoIVIV00?o0000oda<C?m<C4`05?m<C4`00ol0003oIVIVofIV
IP03ofIVIP03o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c
/`04ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o0000ok>c/onc/k<01?nc/k<01Ol0003oVIVIoiVI
VOnIVIWo000000?oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`06oc<c<`05
o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@05o`000?nc/k?o
/k>cok>c/ol000002?o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmoOol00000
0_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Go0000ogmo
Ool0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00?o0000ok>c/ol000000_nIVIT0
1ol0003oOgmoo`000?mVIVKo0000oda<C?l000002Olc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmo
Ool0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00;oc<c<1_ooool1o`00007ooooo0Oooool0
02Cooooo00?o0000ooooooooool00oooool@oda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmo
OomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVI
VOnIVIT02_nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00KoIVIV00?o0000oda<
C?m<C4`05Om<C4`00ol0003oIVIVofIVIP02ofIVIP03o`000?moOgooOgmo00?oOgmo00?o0000oiVI
VOnIVIT00_nIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o0000ok>c
/onc/k<01?nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Co0000ofIVI_mVIVKo00001?m<
C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmo
ogmoOol00002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01Ol0003o/k>cok>c/onc/k?o
000000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`04o`000?m<
C4coC4a<o`0000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Oo
c<c<00?o0000ok>c/ol000000_nIVIT01ol0003oOgmoo`000?mVIVKo0000oda<C?l000002Olc<c<0
2Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00;o
c<c<1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool?oda<C003o`00
0?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`00
0?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`00
0?mVIVKoIVIV00OoIVIV00?o0000oda<C?m<C4`05?m<C4`00ol0003oIVIVofIVIP02ofIVIP03o`00
0?moOgooOgmo00?oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`04ok>c/`03o`00
0?o<c<coc<c<00;oc<c<00?o0000ok>c/onc/k<01?nc/k<00ol0003oVIVIoiVIV@02oiVIV@04o`00
0?moOgooOgmoo`0000;oIVIV00?o0000oda<C?m<C4`00_m<C4`00ol0003o<c<coc<c<`06oc<c<`03
o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl00ol0003oVIVIo`000003ok>c
/`03o`000?o<c<coc<c<00Ooc<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002
ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmo
o`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00?o0000ok>c/ol000000_nIVIT01ol0003o
Ogmoo`000?mVIVKo0000oda<C?l000002Olc<c<00ol0003oC4a<o`000002ofIVIP;o000000GoVIVI
o`000?nc/k?o/k>co`000005olc<c0Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooo
oooo00?ooooo3_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000
oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00[oVIVI0_l0000:
ogmoO`03o`000?mVIVKoIVIV00OoIVIV00?o0000oda<C?m<C4`05?m<C4`00ol0003oIVIVofIVIP03
ofIVIP03o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`05
ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o0000ok>c/onc/k<01?nc/k<01Ol0003oVIVIoiVIVOnI
VIWo000000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go<c<c
00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`00
00?o/k>c00?o0000olc<c?o<c<`01_o<c<`01ol0003o/k>cok>c/onc/k?o0000oiVIVOl000000_mo
Ogl01?l0003oIVIVofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co
00000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0
003o/k>cok>c/ol00002oiVIV@07o`000?moOgoo0000ofIVI_l0003oC4a<o`000009oc<c<`09o`00
0?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`00oo<c<`6
ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`goC4a<00?o0000ofIV
I_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI0_l0000Gok>c
/`;o00003?nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00SoIVIV00?o0000oda<
C?m<C4`05?m<C4`00ol0003oIVIVofIVIP03ofIVIP03o`000?moOgooOgmo00;oOgmo00?o0000oiVI
VOnIVIT00_nIVIT00ol0003o/k>cok>c/`05ok>c/`05o`000?o<c<coc<c<olc<c?l000001onc/k<0
1Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`00
0?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04
o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01ol0003o/k>cok>c/onc/k?o
0000oiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c
00Co0000oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<
c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@07o`000?moOgoo0000ofIVI_l0003oC4a<
o`000009oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000
olc<c?o<c<`00oo<c<`6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03oooo
o`coC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI
00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo
00WoOgmo00?o0000ofIVI_mVIVH02?mVIVH00ol0003oC4a<oda<C00Doda<C003o`000?mVIVKoIVIV
00?oIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c
00Go/k>c00?o0000olc<c?o<c<`00_o<c<`00ol0003o/k>cok>c/`04ok>c/`05o`000?nIVIWoVIVI
oiVIVOl000000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000CoC4a<00?o0000oc<c<olc<c<01_lc
<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01Ol0003o
/k>cok>c/onc/k?o000000Soc<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo00Co
0000ofIVI_mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;o
IVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00?o0000ok>c
/ol000000_nIVIT01ol0003oOgmoo`000?mVIVKo0000oda<C?l000002Olc<c<01ol0003oC4a<o`00
0?mVIVKo0000ogmoOol000000_nIVIT00ol0003o/k>co`000006olc<c0Kooooo0Ol00001ooooo`7o
oooo000Tooooo`03o`000?oooooooooo00?ooooo2om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`00
0?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`00
0?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP08ofIVIP03o`00
0?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`02ogmoO`;o0000
0onIVIT00ol0003o/k>cok>c/`05ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o0000ok>c/onc/k<0
1?nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<
C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002
ogmoO`04o`000?nIVIWoVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01oo<c<`01?l0003o/k>cok>c
/ol00002oiVIV@06o`000?moOgooOgmoo`000?mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c
<`04o`000?m<C4coC4a<o`0000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<
c<coc<c<00Ooc<c<00Co0000ok>c/ol0003oVIVI0_l000001_moOgoo0000ofIVI_l0003oC4a<o`00
00Wo<c<c00_o0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`000007olc<c0Ko
oooo0Ol00001ooooo`7ooooo000Tooooo`;o00001?ooool:oda<C003o`000?mVIVKoIVIV00_oIVIV
00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@;o00005onc/k<2o`0000goVIVI
00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP08ofIVIP03o`000?m<C4coC4a<01GoC4a<
00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00;oVIVI
00?o0000ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c00Co/k>c
00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`05o`000?mVIVKoIVIVofIVI_l000000om<C4`00ol0
003o<c<coc<c<`06oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl0
1?l0003oVIVIoiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Co0000ok>c/onc/k?o0000
0_nIVIT01_l0003oOgmoogmoOol0003oIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0
003oC4a<oda<C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<
c007olc<c005o`000?nc/k?o0000oiVIVOl000000_moOgl01Ol0003oIVIVo`000?m<C4co000000So
<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00007olc<c0Go
oooo0_l00002ooooo`009?ooool00ol0003oooooooooo`03ooooo`SoC4a<0_l0000=ofIVIP03o`00
0?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`00
0?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP08ofIVIP03o`00
0?m<C4coC4a<01GoC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`02ogmoO`03o`00
0?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01_nc/k<01Ol0003oc<c<olc<c?o<c<co000000Ko
/k>c00?o0000oiVIVOnIVIT00_nIVIT01?l0003oOgmoogmoOol00003ofIVIP03o`000?m<C4coC4a<
00;oC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIV
o`0000;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc
/k?o/k>co`0000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01?l0003oC4a<oda<C?l00009oc<c
<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<
c<`01oo<c<`00ol0003o/k>cok>c/`02o`0000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o
<c<coc<c<`06oc<c<`05o`000?m<C4co0000ofIVI_l000000_moOgl2o`0000;o/k>c00?o0000olc<
c?o<c<`01Oo<c<`6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`Oo
C4a<00?o0000ofIVI_mVIVH02omVIVH2o`0000[oOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o
/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI0_l0000:ogmoO`03o`000?mVIVKoIVIV00So
IVIV00?o0000oda<C?m<C4`05Om<C4`00ol0003oIVIVofIVIP03ofIVIP03o`000?moOgooOgmo00;o
Ogmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`05ok>c/`05o`000?o<c<coc<c<olc<
c?l000001onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo0_l00002ofIVIP03o`000?m<C4co
C4a<00;oC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C003o`000?mVIVKo
IVIV00;o000000?oOgmoo`000?nIVIT00_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Ooc<c<0_l0
0002ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00?o0000ofIVI_l000000om<C4`00ol0003o<c<c
oc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c
/`03o`000?o<c<coc<c<00Koc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`05o`000?mV
IVKo0000oda<C?l000002Olc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002
ok>c/`03o`000?o<c<coc<c<00Goc<c<1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000oooo
ooooool00oooool7oda<C003o`000?mVIVKoIVIV00[oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0
003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0
003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00SoIVIV00?o0000oda<C?m<C4`05Om<C4`00ol0
003oIVIVofIVIP03ofIVIP03o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0
003o/k>cok>c/`05ok>c/`05o`000?o<c<coc<c<olc<c?l000001onc/k<01Ol0003oVIVIoiVIVOnI
VIWo000000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go<c<c
00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`05o`000?nIVIWoVIVIoiVI
VOl000000onc/k<00ol0003oc<c<olc<c005olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT0
1_l0003oOgmoogmoOol0003oIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<
oda<C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<
c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl01Ol0003oIVIVo`000?m<C4co000000Wo<c<c
00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c005
olc<c0Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo1_m<C4`00ol0
003oIVIVofIVIP0:ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0
003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0
003oIVIVofIVIP09ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0
003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<01Onc/k<01Ol0
003oc<c<olc<c?o<c<co000000Oo/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`05o`000?mV
IVKoIVIVofIVI_l000001?m<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<
00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<
00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000
oda<C?m<C4co00002Olc<c<02?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo00000_nIVIT01?l0
003o/k>cok>c/ol00008olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP03
o`000?m<C4co000000Wo<c<c00Co0000oda<C?l0003o00000_moOgl00ol0003oVIVIo`000002ok>c
/`03o`000?o<c<coc<c<00Goc<c<1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000oooooooo
ool00oooool5oda<C003o`000?mVIVKoIVIV00[oIVIV00?o0000ogmoOomoOgl02_moOgl00ol0003o
VIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003o
OgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00WoIVIV00?o0000oda<C?m<C4`05?m<C4`00ol0003o
IVIVofIVIP04ofIVIP03o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o
/k>cok>c/`05ok>c/`05o`000?o<c<coc<c<olc<c?l000001_nc/k<00ol0003oVIVIoiVIV@02oiVI
V@04o`000?moOgooOgmoo`0000?oIVIV00?o0000oda<C?m<C4`00_m<C4`00ol0003o<c<coc<c<`05
oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01Ol0003oVIVIoiVI
VOnIVIWo000000?o/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`03o`00
0?nIVIWo000000;oOgmo00?o0000ofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`04o`00
0?m<C4coC4a<o`0000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<
00Koc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`05o`000?mVIVKo0000oda<C?l00000
2Olc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<co
c<c<00Koc<c<00?o0000ooooooooool00oooool1o`00007ooooo0Oooool002Cooooo00?o0000oooo
ooooool00oooool4oda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0
003oVIVIoiVIV@0:oiVIV@;o00005onc/k<2o`0000goVIVI00?o0000ogmoOomoOgl02?moOgl2o`00
00_oIVIV00?o0000oda<C?m<C4`05Om<C4`00ol0003oIVIVofIVIP03ofIVIP03o`000?moOgooOgmo
00?oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`05ok>c/`;o00000_o<c<`00ol0
003o/k>cok>c/`05ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01Ol0003oIVIVofIVI_mV
IVKo000000CoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mV
IVKoIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c005
o`000?nc/k?o/k>cok>c/ol000000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<
o`0000Wo<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`03o`000?nIVIWo000000;o/k>c
00?o0000olc<c?o<c<`01_o<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00Go0000ofIV
I_l0003oC4a<o`000009oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o
/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003oooooooooo`03ooooo`7o00000Oooool1ooooo`00
9?ooool00ol0003oooooooooo`03ooooo`?oC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmo
ogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVI
oiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<
oda<C00Foda<C003o`000?mVIVKoIVIV00?oIVIV00?o0000ogmoOomoOgl00omoOgl00ol0003oVIVI
oiVIV@02oiVIV@03o`000?nc/k?o/k>c00Go/k>c00Go0000ok>c/ol0003oc<c<o`000007ok>c/`05
o`000?nIVIWoVIVIoiVIVOl000000omoOgl01Ol0003oIVIVofIVI_mVIVKo000000CoC4a<00?o0000
oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co
0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol0
00000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000Wo<c<c00Ko0000oda<
C?m<C4co0000ofIVI_l00002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<
c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00Go0000ofIVI_l0003oC4a<o`000009oc<c
<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`0
1_o<c<`00ol0003oooooooooo`03ooooo`7o00000Oooool1ooooo`009?ooool00ol0003ooooooooo
o`03ooooo`;oC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nI
VIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?mo
OgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Eoda<C003o`000?mV
IVKoIVIV00?oIVIV00?o0000ogmoOomoOgl00omoOgl00ol0003oVIVIoiVIV@02oiVIV@03o`000?nc
/k?o/k>c00Ko/k>c0_l000000onc/k?o0000ok>c/`06ok>c/`03o`000?nIVIWoVIVI00;oVIVI00Co
0000ogmoOomoOgoo00000omVIVH00ol0003oC4a<oda<C002oda<C003o`000?lc<c?o<c<c00Go<c<c
00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`00
00?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000
ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV
00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00?o0000ok>c/ol0
00000_nIVIT01ol0003oOgmoo`000?mVIVKo0000oda<C?l000002Olc<c<01ol0003oC4a<o`000?mV
IVKo0000ogmoOol000000_nIVIT00ol0003o/k>co`000008olc<c003o`000?oooooooooo00Cooooo
0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo00?oC4a<o`000?mVIVH03?mV
IVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00[oVIVI0_l0000Gok>c/`;o00003OnI
VIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05Om<
C4`00ol0003oIVIVofIVIP03ofIVIP03o`000?moOgooOgmo00;oOgmo0_l00004oiVIV@03o`000?nc
/k?o/k>c00Ko/k>c00Co0000olc<c?o<c<co00002?nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;o
Ogmo00Go0000ofIVI_mVIVKoIVIVo`000005oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<
C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o
0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmoOol00000
0_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`;o00000_m<C4`00ol0003oIVIVo`000002ogmoO`03
o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`01Ol0003o/k>co`000?nIVIWo0000
00;oOgmo00Go0000ofIVI_l0003oC4a<o`000009oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmo
o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003oooooooooo`04ooooo`7o
00000Oooool1ooooo`009?ooool2o`0000Cooooo00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmo
ogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVI
oiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<
oda<C00Eoda<C003o`000?mVIVKoIVIV00CoIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVI
oiVIV@03oiVIV@03o`000?nc/k?o/k>c00Ko/k>c00Co0000olc<c?o<c<co00001onc/k<00ol0003o
VIVIoiVIV@02oiVIV@04o`000?moOgooOgmoo`0000?oIVIV00?o0000oda<C?m<C4`00om<C4`00ol0
003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl0
1?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc
/k<01_l0003oVIVIoiVIVOl0003oOgmoo`0000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<01ol0
003oC4a<oda<C?m<C4co0000ofIVI_l000000_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<
c<coc<c<00Ooc<c<00Go0000ok>c/ol0003oVIVIo`000002ogmoO`05o`000?mVIVKo0000oda<C?l0
00002?lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`00
0?o<c<coc<c<00Koc<c<00?o0000ooooooooool00oooool2o`0000;ooooo000Tooooo`03o`000?oo
oooooooo00?ooooo3OmVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o
0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o
0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Eoda<C003o`000?mVIVKoIVIV00CoIVIV00?o
0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c00Ko/k>c00Co
0000olc<c?o<c<co00001onc/k<00ol0003oVIVIoiVIV@02oiVIV@04o`000?moOgooOgmoo`0000Co
IVIV00?o0000oda<C?m<C4`00_m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;o
C4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<co
c<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@06o`000?moOgooOgmoo`000?mVIVKo
00000om<C4`00ol0003o<c<coc<c<`05oc<c<`07o`000?m<C4coC4a<oda<C?l0003oIVIVo`000002
ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`01Ol0003o/k>co`000?nI
VIWo000000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`09o`000?m<
C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0
003o/k>cooooo`05ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`co
IVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0:oiVIV@;o00005onc/k<2o`0000go
VIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01Go
C4a<00?o0000ofIVI_mVIVH01?mVIVH00ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00;o
VIVI00?o0000ok>c/onc/k<01onc/k<3o`0000So/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmo
O`05o`000?mVIVKoIVIVofIVI_l000001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4co
C4a<00;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c
00?o0000olc<c?o<c<`01_o<c<`01ol0003o/k>cok>c/onc/k?o0000oiVIVOl000000_moOgl01?l0
003oIVIVofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Oo0000oda<C?m<C4coC4a<o`00
0?mVIVKo000000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c008o`00
0?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP03o`000?m<C4co000000Wo<c<c00Wo0000
oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c003
o`000?nc/k?o000000Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo
2omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00[oVIVI00?o0000ok>c/onc/k<0
5onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH0
2omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00CoIVIV00?o0000ogmoOomoOgl0
0omoOgl00ol0003oVIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c01;o/k>c00Co0000oiVIVOnIVIWo
00001?moOgl01Ol0003oIVIVofIVI_mVIVKo000000CoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0
003oC4a<oda<C002oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl0
0003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo000000;o
Ogmo00Co0000ofIVI_mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`07o`000?m<C4coC4a<
oda<C?l0003oIVIVo`000002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<
c<`02?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo00000_mVIVH00ol0003oC4a<o`000009oc<c
<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`0
1_o<c<`00ol0003o/k>co`000005ooooo`7o00000Oooool1ooooo`009?ooool00ol0003ooooooooo
o`03ooooo`[oIVIV00?o0000ogmoOomoOgl02?moOgl2o`0000coVIVI00?o0000ok>c/onc/k<05onc
/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omV
IVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00CoIVIV00?o0000ogmoOomoOgl00omo
Ogl00ol0003oVIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c01;o/k>c00Go0000oiVIVOnIVIWoVIVI
o`000003ogmoO`05o`000?mVIVKoIVIVofIVI_l000001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03
o`000?m<C4coC4a<00;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`04o`000?nIVIWoVIVI
o`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01ol0003o/k>cok>c/onc/k?o0000oiVIVOl00000
0_moOgl01?l0003oIVIVofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Ko0000oda<C?m<
C4co0000ofIVI_l00002ogmoO`06o`000?nIVIWoVIVIo`000?nc/k?o00002?o<c<`01_l0003o/k>c
ok>c/ol0003oVIVIo`0000;oOgmo00Go0000ofIVI_l0003oC4a<o`000009oc<c<`09o`000?m<C4co
0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003o
/k>co`000006ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`WoIVIV
00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c
00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV
00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP04ofIVIP03o`000?moOgooOgmo00?oOgmo
00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0Aok>c/`03o`000?nIVIWoVIVI00;oVIVI
00Go0000ogmoOomoOgooOgmoo`000002ofIVIP03o`000?m<C4coC4a<00?oC4a<00?o0000oc<c<olc
<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co0000oiVI
VOnIVIWo00000onc/k<00ol0003oc<c<olc<c007olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Co
0000ogmoOomoOgoo00000_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`08o`000?m<C4coC4a<o`00
0?mVIVKo0000ogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Oo0000ok>c/onc/k?o
0000oiVIVOl0003oOgmo00;o000000CoIVIVo`000?m<C4co00002Olc<c<02Ol0003oC4a<o`000?mV
IVKo0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o0000ok>c/ol0
00001_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool8ofIVIP03o`00
0?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`00
0?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0<ofIVIP03o`00
0?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH01?mVIVH00ol0003oOgmoogmoO`03ogmoO`03o`00
0?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<04Onc/k<00ol0003oVIVIoiVIV@02oiVIV@05o`00
0?moOgooOgmoogmoOol000000_mVIVH00ol0003oC4a<oda<C003oda<C003o`000?lc<c?o<c<c00Go
<c<c00Go0000oda<C?m<C4coC4a<o`000003ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Go0000
ok>c/onc/k?o/k>co`000009olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Co0000ogmoOomoOgoo
00000_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmo
Ool00002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003o
Ogmoo`0000;oIVIV00?o0000oda<C?l000002Olc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0
003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o0000ok>c/ol000001_ooool1o`00
007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool7ofIVIP03o`000?moOgooOgmo00So
Ogmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00_o
VIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<01Ko
C4a<00?o0000ofIVI_mVIVH01?mVIVH00ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00?o
VIVI00?o0000ok>c/onc/k<04Onc/k<00ol0003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmo
Ool000000omVIVH00ol0003oC4a<oda<C002oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<
C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo00000_nc
/k<00ol0003oc<c<olc<c007olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Co0000ogmoOomoOgoo
00000_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV0_l00002
oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`00
00;oIVIV00?o0000oda<C?l000002Olc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVI
o`000003ok>c/`03o`000?o<c<coc<c<00Goc<c<00Co0000ok>c/ol0003oVIVI1_ooool1o`00007o
oooo0Oooool001Wooooo00Goc<c<ob4Q8Ol0003o8B4Qolc<c006ooooo`03o`000?oooooooooo00?o
oooo1_mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc
/k<05onc/k<00ol0003oVIVIoiVIV@0:oiVIV@;o00002_moOgl00ol0003oIVIVofIVIP0;ofIVIP;o
00006?m<C4`00ol0003oIVIVofIVIP04ofIVIP03o`000?moOgooOgmo00?oOgmo00?o0000oiVIVOnI
VIT00onIVIT00ol0003o/k>cok>c/`0Bok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01Ol0
003oIVIVofIVI_mVIVKo000000GoC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C002
oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`00
0?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`00
00;oIVIV00Co0000oda<C?m<C4co00002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?mo
Ogoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`02?l0003o/k>cok>c/ol0003oVIVIo`00
0?moOgoo00000_mVIVH00ol0003oC4a<o`000009oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmo
o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>co`000?nIVIT6oooo
o`7o00000Oooool1ooooo`006Oooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000oooo
ooooool00oooool5ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0
003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00[oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0
003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH01OmVIVH00ol0
003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<04onc/k<01Ol0
003oVIVIoiVIVOnIVIWo000000?oOgmo00Go0000ofIVI_mVIVKoIVIVo`000005oda<C003o`000?lc
<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo
00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c
/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Co
0000oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000So
c<c<00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV00?o0000oda<C?l000002Olc
<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<
00Koc<c<00Go0000ok>c/ol0003oVIVIo`000005ooooo`7o00000Oooool1ooooo`006Oooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00oooool4ofIVIP03o`000?moOgoo
Ogmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWo
VIVI00[oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4co
C4a<01OoC4a<00?o0000ofIVI_mVIVH01OmVIVH00ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWo
VIVI00?oVIVI00?o0000ok>c/onc/k<04_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Go
0000ofIVI_mVIVKoIVIVo`000005oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`0
0_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0
003oc<c<olc<c005olc<c005o`000?nc/k?o/k>cok>c/ol000000onIVIT00ol0003oOgmoo`000002
ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmo
o`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003o
Ogmoo`0000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmo
Ool0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o0000ok>c/ol000000_nIVIT0
0ol0003oooooooooo`03ooooo`7o00000Oooool1ooooo`006Oooool01Olb<S;oV9RHoooooonHV9So
<S8b00Kooooo0ol00003ooooo`?oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;
oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02_nIVIT2o`0000[oOgmo00?o0000
ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00GoIVIV00?o0000
ogmoOomoOgl00omoOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c01;o/k>c00?o0000
oiVIVOnIVIT00_nIVIT01?l0003oOgmoogmoOol00004ofIVIP03o`000?m<C4coC4a<00;oC4a<00?o
0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C005o`000?mVIVKoIVIVofIVI_l00000
0_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc
/k?o/k>co`000002oiVIV@06o`000?moOgooOgmoo`000?mVIVKo00000om<C4`00ol0003o<c<coc<c
<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>c
ok>c/ol00008olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP04o`000?m<
C4co0000o`0000So<c<c00_o0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`00
0009olc<c005o`000?nc/k?o0000oiVIVOl000001?ooool3o`0000;ooooo000Iooooo`05olc<c?l0
003o0000o`000?o<c<`01_ooool00ol0003oooooooooo`03ooooo`;oIVIV00?o0000ogmoOomoOgl0
2?moOgl00ol0003oVIVIoiVIV@0;oiVIV@;o00005onc/k<2o`0000coVIVI00?o0000ogmoOomoOgl0
2OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH0
1_mVIVH00ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<0
4_nc/k<00ol0003oVIVIoiVIV@02oiVIV@04o`000?moOgooOgmoo`0000CoIVIV00?o0000oda<C?m<
C4`00_m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Go0000ofIVI_mV
IVKoIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`0
1Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Ko0000ogmoOomoOgoo0000ofIVI_l00003oda<C003
o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVI
V@04o`000?nc/k?o/k>co`0000Soc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`0000;o
IVIV00?o0000oda<C?l000002Olc<c<02ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`00
0?nc/k?o000000Woc<c<00Go0000ok>c/ol0003oVIVIo`000006ooooo`7o00000Oooool1ooooo`00
6Oooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo00?o0000ooooooooool00oooool00omVIVKo
0000ogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003o
VIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003o
C4a<oda<C00Goda<C003o`000?mVIVKoIVIV00KoIVIV00?o0000ogmoOomoOgl00omoOgl00ol0003o
VIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c01;o/k>c00?o0000oiVIVOnIVIT00_nIVIT01?l0003o
OgmoogmoOol00004ofIVIP03o`000?m<C4coC4a<00?oC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0
003oC4a<oda<C002oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl0
0003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@06o`00
0?moOgooOgmoo`000?mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<
o`0000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT00ol0003o/k>co`000008olc<c008o`000?nc
/k?o/k>co`000?nIVIWo0000ogmoOol00003ofIVIP;o00002Olc<c<02Ol0003oC4a<o`000?mVIVKo
0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o0000ok>c/onc/k<0
0_l000000omoOgooooooooooo`04ooooo`7o00000Oooool1ooooo`006Oooool01Ol0003o^[Zjoooo
oonj^[[o000000Kooooo00?o0000ooooooooool00oooool00ol0003oOgmoogmoO`08ogmoO`03o`00
0?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`00
0?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Goda<C003o`00
0?mVIVKoIVIV00KoIVIV00?o0000ogmoOomoOgl00omoOgl00ol0003oVIVIoiVIV@03oiVIV@03o`00
0?nc/k?o/k>c01;o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000?o
IVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;o
C4a<00Co0000ofIVI_mVIVKo00000_moOgl2o`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008
olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT00ol0003oOgmoo`000002ofIVIP05o`000?m<
C4coC4a<oda<C?l000002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;o
VIVI00Co0000ok>c/onc/k?o00002?o<c<`01ol0003o/k>cok>c/ol0003oVIVIo`000?moOgl00_l0
00001?mVIVKo0000oda<C?l00009oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo
000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003o/k>cok>c/`02o`000003ogmoOooooooo
oooo00Cooooo0Ol00001ooooo`7ooooo000Iooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool0
0ol0003oooooooooo`03ooooo`[oOgmo00?o0000oiVIVOnIVIT02onIVIT2o`0001Oo/k>c0_l0000=
oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00G
oda<C003o`000?mVIVKoIVIV00OoIVIV00?o0000ogmoOomoOgl00omoOgl00ol0003oVIVIoiVIV@03
oiVIV@03o`000?nc/k?o/k>c01;o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomo
Ogoo000000?oIVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<
C4coC4a<00?oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000?o
/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmo
Ool000000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Ko0000oda<C?m<C4co0000ofIV
I_l00002ogmoO`04o`000?nIVIWoVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02?l0003o
/k>cok>c/ol0003oVIVIo`000?moOgoo00000_mVIVH00ol0003oC4a<o`000009oc<c<`09o`000?m<
C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0
003o/k>cok>c/`02o`000003ogmoOol0003ooooo00Cooooo0Ol00001ooooo`7ooooo000Tooooo`03
o`000?oooooooooo00?ooooo2OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko
/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_o
IVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP07ofIVIP03o`000?moOgooOgmo00?o
Ogmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`0Aok>c/`03o`000?nIVIWoVIVI00;o
VIVI00Go0000ogmoOomoOgooOgmoo`000003ofIVIP03o`000?m<C4coC4a<00?oC4a<00?o0000oc<c
<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Go0000
oiVIVOnIVIWoVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>c
o`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<01?l0
003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<
c<`02?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo00000_mVIVH00ol0003oC4a<o`000009oc<c
<`03o`000?m<C4co000000;oIVIV0_l000001OnIVIWo0000ok>c/onc/k?o000000Woc<c<00Co0000
ok>c/ol0003o00000_moOgl00ol0003oooooooooo`03ooooo`7o00000Oooool1ooooo`009?ooool0
0ol0003oooooooooo`03ooooo`SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0F
ok>c/`03o`000?nIVIWoVIVI00_oVIVI0_l0000:ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000
oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP07ofIVIP03o`000?moOgooOgmo00?oOgmo00?o0000
oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`0Bok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omo
Ogl00ol0003oIVIVofIVIP02ofIVIP03o`000?m<C4coC4a<00?oC4a<00?o0000oc<c<olc<c<01?lc
<c<00ol0003oC4a<oda<C002oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01?l0003oVIVI
oiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Goc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVI
V@03o`000?moOgooOgmo00;o000000?oIVIVo`000?m<C4`00_m<C4`00ol0003o<c<coc<c<`06oc<c
<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol0
0008olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP03o`000?m<C4co0000
00Wo<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<
olc<c006olc<c003o`000?nc/k?o/k>c00;o000000?oOgmoo`000?ooool01Oooool1o`00007ooooo
0Oooool002Cooooo00?o0000ooooooooool00oooool7ogmoO`03o`000?nIVIWoVIVI00coVIVI00?o
0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o
0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<oda<C00Hoda<C003o`000?mVIVKoIVIV00OoIVIV00?o
0000ogmoOomoOgl00omoOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c01;o/k>c00Go
0000oiVIVOnIVIWoVIVIo`000003ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`0
0om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00;oC4a<00Go0000ofIVI_mVIVKo
IVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`01Ol0
003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01Ol0003oC4a<oda<
C?m<C4co000000So<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVIV@04
o`000?nc/k?o/k>co`0000Soc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV
00?o0000oda<C?l000002Olc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002
ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o0000ok>c/onc/k<00_l000000omoOgoo0000ooooo`05
ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`KoOgmo00?o0000oiVI
VOnIVIT03?nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmo
OomoOgl02OmoOgl00ol0003oIVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<01SoC4a<00?o0000ofIV
I_mVIVH01omVIVH00ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c
/onc/k<04_nc/k<00ol0003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol000000omVIVH0
0ol0003oC4a<oda<C003oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00_m<C4`0
1Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<
olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIV
IP04o`000?m<C4coC4a<o`0000So<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP05o`000?mo
Ogoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`0000;o
VIVI00?o0000ogmoOol000000_mVIVH00ol0003oC4a<o`000008oc<c<`0:o`000?m<C4coC4a<o`00
0?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003o/k>c
ok>c/`02o`000003ogmoOol0003ooooo00Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oo
oooooooo00?ooooo1_moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o
0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00[oIVIV00?o
0000oda<C?m<C4`06?m<C4`00ol0003oIVIVofIVIP07ofIVIP03o`000?moOgooOgmo00CoOgmo00?o
0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0Cok>c/`05o`000?nIVIWoVIVIoiVIVOl00000
0omoOgl01Ol0003oIVIVofIVI_mVIVKo000000KoC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003o
C4a<oda<C002oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00004
ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT01?l0003oOgmoogmo
Ool00002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01?l0003oC4a<oda<C?l00002ofIV
IP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`02?l0003o/k>cok>c/ol0
003oVIVIo`000?moOgoo00000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`09o`000?m<C4co0000
ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`01?l0003o/k>c
o`000?nIVIT2o`000003ofIVI_oooooooooo00Cooooo0Ol00001ooooo`7ooooo000Tooooo`;o0000
1?ooool5ogmoO`03o`000?nIVIWoVIVI00[oVIVI0_l0000Gok>c/`;o00003OnIVIT00ol0003oOgmo
ogmoO`08ogmoO`;o00003?mVIVH2o`0001WoC4a<00?o0000ofIVI_mVIVH01omVIVH00ol0003oOgmo
ogmoO`04ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<04_nc/k<00ol0003oVIVI
oiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol000000omVIVH00ol0003oC4a<oda<C003oda<C003
o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00om<C4`01?l0003oIVIVofIVI_l00002ogmo
O`;o00000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Woc<c<00Co0000ok>c/onc/k?o00000_nI
VIT01?l0003oOgmoogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Go0000oda<C?m<
C4coC4a<o`000002ofIVIP05o`000?moOgoo0000oiVIVOl000000onc/k<00ol0003oc<c<olc<c006
olc<c009o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIV00;o000000?oC4a<o`000?lc
<c<01olc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`00
0?o<c<coc<c<00Ooc<c<00Co0000ok>c/ol0003oVIVI0_l000000omVIVKoooooooooo`03ooooo`;o
00000_ooool002Cooooo00?o0000ooooooooool00oooool4ogmoO`03o`000?nIVIWoVIVI00_oVIVI
00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo
00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Hoda<C003o`000?mVIVKoIVIV00OoIVIV
00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c01;o/k>c
00Go0000oiVIVOnIVIWoVIVIo`000004ogmoO`05o`000?mVIVKoIVIVofIVI_l000001Om<C4`00ol0
003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Co0000ofIVI_mVIVKo00000_moOgl0
1Ol0003oVIVIoiVIVOnIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c
/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01?l0003oC4a<oda<C?l00008oc<c
<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH2o`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`00
0008olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000
oc<c<olc<c<01_lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c
/`03o`000?o<c<coc<c<00Ooc<c<00Co0000ok>c/ol0003oVIVI0_l000000omVIVKo0000ooooo`04
ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`?oOgmo00?o0000oiVI
VOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmo
OomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01SoC4a<00?o0000ofIV
I_mVIVH01omVIVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c
/onc/k<04_nc/k<00ol0003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol000000omVIVH0
0ol0003oC4a<oda<C003oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`0
1?l0003oIVIVofIVI_l00002ogmoO`03o`000?nIVIWoVIVI00;oVIVI00Co0000ok>c/onc/k?o0000
2?o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01?l0
003oC4a<oda<C?l00008oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01Ol0003oOgmoo`00
0?nIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`02?l0003o/k>cok>c/ol0003oVIVIo`00
0?moOgoo00000_mVIVH00ol0003oC4a<o`000008oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000
ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01oo<c<`01?l0003o/k>co`000?nIVIT2
o`0000;oIVIV00?o0000ooooooooool00oooool1o`00007ooooo0Oooool002Cooooo00?o0000oooo
ooooool00oooool2ogmoO`03o`000?nIVIWoVIVI00[oVIVI0_l0000Gok>c/`;o00003OnIVIT00ol0
003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV0_l0000Hoda<C0;o00002_mVIVH00ol0
003oOgmoogmoO`04ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<04_nc/k<00ol0
003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol000001?mVIVH00ol0003oC4a<oda<C003
oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00om<C4`01?l0003oIVIVofIVI_l0
0002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c005o`00
0?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP04o`000?m<C4coC4a<
o`0000So<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00?o0000oiVIVOl00000
0_nc/k<00ol0003oc<c<olc<c007olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002
ofIVIP03o`000?m<C4co000000So<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nI
VIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>co`000?nIVIT00_l00000
0omVIVKo0000ooooo`05ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03oooo
o`03ogmoOol0003oVIVI00coVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVI
V@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Goda<
C003o`000?mVIVKoIVIV00[oIVIV00?o0000ogmoOomoOgl01?moOgl00ol0003oVIVIoiVIV@03oiVI
V@03o`000?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo
000000?oIVIV00?o0000oda<C?m<C4`01?m<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4co
C4a<00?oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000?o/k>c
00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmoOol0
00000omVIVH01?l0003oC4a<oda<C?l00008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Ko0000
ogmoOomoOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00So0000ok>c/onc/k?o
0000oiVIVOl0003oOgmoo`0000;oIVIV00?o0000oda<C?l000002?lc<c<02_l0003oC4a<oda<C?l0
003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c
/onc/k?o0000oiVIV@02o`000003ofIVI_l0003ooooo00Gooooo0Ol00001ooooo`7ooooo000Toooo
o`03o`000?oooooooooo00?ooooo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c
/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIV
IP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`04ogmo
O`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<04onc/k<01Ol0003oVIVIoiVIVOnIVIWo
000000?oOgmo00Go0000ofIVI_mVIVKoIVIVo`000006oda<C003o`000?lc<c?o<c<c00Co<c<c00?o
0000oda<C?m<C4`00om<C4`01?l0003oIVIVofIVI_l00002ogmoO`05o`000?nIVIWoVIVIoiVIVOl0
00001?nc/k<00ol0003oc<c<olc<c005olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0
003oOgmoogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<C?l000001olc<c<01ol0003oC4a<oda<
C?m<C4co0000ofIVI_l000000_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Oo
c<c<00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV00?o0000oda<C?l000002Olc
<c<00ol0003oC4a<o`000002ofIVIP;o000000GoVIVIo`000?nc/k?o/k>co`000009olc<c006o`00
0?nc/k?o0000oiVIVOl0003oOgmo0_l000000om<C4coooooooooo`04ooooo`7o00000Oooool1oooo
o`009?ooool00ol0003oooooooooo`03ooooo`coVIVI0_l0000Gok>c/`;o00003OnIVIT00ol0003o
OgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003o
IVIVofIVIP09ofIVIP;o00001_moOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c01?o
/k>c00Go0000oiVIVOnIVIWoVIVIo`000004ogmoO`05o`000?mVIVKoIVIVofIVI_l000001Om<C4`0
0ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Go0000ofIVI_mVIVKoIVIVo`00
0002ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>c
ok>c/onc/k?o000000;oVIVI00Ko0000ogmoOomoOgoo0000ofIVI_l00003oda<C003o`000?lc<c?o
<c<c00Ko<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00?o0000oiVIVOl00000
0_nc/k<00ol0003oc<c<olc<c007olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003o
IVIVo`0000;oC4a<00?o0000oc<c<olc<c<01olc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0
003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o0000oiVIV@02
o`000003ofIVI_l0003oC4a<00Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo
00?ooooo2onIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmo
OomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIV
I_mVIVH02_mVIVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c
/onc/k<04onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000CoOgmo00Go0000ofIVI_mVIVKoIVIVo`00
0005oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00om<C4`01?l0003oIVIVofIV
I_l00002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0003oc<c<olc<c006olc<c005
o`000?nc/k?o/k>cok>c/ol000000_nIVIT01_l0003oOgmoogmoOol0003oIVIVo`0000?oC4a<00?o
0000oc<c<olc<c<01_lc<c<01ol0003oC4a<oda<C?m<C4co0000ofIVI_l000000_moOgl00ol0003o
VIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003o
Ogmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`07oc<c<`09o`000?m<C4co0000ofIVI_l0
003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/ol0
003oVIVI00;o000000?oIVIVo`000?m<C4`01_ooool1o`00007ooooo0Oooool002Cooooo00?o0000
ooooooooool00oooool:oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02onIVIT0
0ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`0
0ol0003oIVIVofIVIP0:ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT01?nIVIT0
0ol0003o/k>cok>c/`0Cok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`00
0003ofIVIP03o`000?m<C4coC4a<00?oC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<
C002oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00004ok>c/`03
o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@06o`000?moOgooOgmo
o`000?mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`07o`000?m<C4coC4a<oda<C?l0003o
IVIVo`000002ogmoO`03o`000?nIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`02_l0003o
/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c
00?o0000oda<C?m<C4`00_l000001omoOgoo0000oiVIVOnIVIWo0000ok>c/ol000002?o<c<`02ol0
003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<00Kooooo0Ol00001ooooo`7o
oooo000Tooooo`03o`000?oooooooooo00?ooooo2OnIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`00
0?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`00
0?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`05ogmoO`03o`00
0?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<04onc/k<00ol0003oVIVIoiVIV@02oiVIV@05o`00
0?moOgooOgmoogmoOol000001?mVIVH00ol0003oC4a<oda<C003oda<C003o`000?lc<c?o<c<c00Co
<c<c00?o0000oda<C?m<C4`00om<C4`01?l0003oIVIVofIVI_l00003ogmoO`04o`000?nIVIWoVIVI
o`0000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`06o`000?nIVIWo
VIVIo`000?moOgoo00000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Oo0000oda<C?m<
C4coC4a<o`000?mVIVKo000000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006
olc<c00;o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0
003o<c<coc<c<`06oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o
/k>c00?o0000olc<c?o<c<`01_o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIV
I_l0003oC4a<o`0000Gooooo0Ol00001ooooo`7ooooo000Tooooo`;o00001?ooool8oiVIV@03o`00
0?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`00
0?mVIVKoIVIV00coIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0:ofIVIP03o`00
0?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT01OnIVIT00ol0003o/k>cok>c/`0Cok>c/`03o`00
0?nIVIWoVIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`000004ofIVIP03o`000?m<C4coC4a<00?o
C4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C003oda<C004o`000?mVIVKoIVIVo`00
00?oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o
/k>c00;o/k>c00Ko0000oiVIVOnIVIWo0000ogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<C?l0
00002?lc<c<02Ol0003oC4a<oda<C?m<C4co0000ofIVI_l0003oOgmoo`000002oiVIV@04o`000?nc
/k?o/k>co`0000Soc<c<00_o0000ok>c/onc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`00
0002oda<C003o`000?lc<c?o<c<c00Ko<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`00
0?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000
ogmoOol0003oIVIVo`000?m<C4co00001?ooool2o`0000;ooooo000Tooooo`03o`000?oooooooooo
00?ooooo1onIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmo
OomoOgl02?moOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIV
I_mVIVH02_mVIVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00GoVIVI00?o0000ok>c
/onc/k<04onc/k<00ol0003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol000001?mVIVH0
0ol0003oC4a<oda<C003oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00om<C4`0
1?l0003oIVIVofIVI_l00003ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`0
1_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmoOol000000_mVIVH01Ol0003o
C4a<oda<C?m<C4co000000So<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00?o
0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c009o`000?nc/k?o/k>cok>c/ol0003o
VIVIo`000?moOgoo000000;oIVIV00?o0000oda<C?l000002?lc<c<01_l0003oC4a<oda<C?l0003o
IVIVo`0000;oOgmo0_l00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00co0000ok>c/onc/k?o0000
oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00006ooooo`7o00000Oooool1ooooo`009?ooool0
0ol0003oooooooooo`03ooooo`KoVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0:
oiVIV@;o00002_moOgl00ol0003oIVIVofIVIP0;ofIVIP;o00005om<C4`2o`0000coIVIV00?o0000
ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@05oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o0000
oiVIVOnIVIT00_nIVIT00ol0003oOgmoogmoO`02ogmoO`05o`000?mVIVKoIVIVofIVI_l000001Om<
C4`2o`0000Go<c<c00?o0000oda<C?m<C4`00om<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo
00Go0000oiVIVOnIVIWoVIVIo`000003ok>c/`;o00001oo<c<`01Ol0003o/k>cok>c/onc/k?o0000
00;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Co
0000oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000So
c<c<00_o0000ok>c/onc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003o`00
0?lc<c?o<c<c00Ko<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc
/k<00ol0003oc<c<olc<c006olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIV
o`000?m<C4co00001_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool5
oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`09
ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;
ofIVIP03o`000?moOgooOgmo00KoOgmo00?o0000oiVIVOnIVIT01OnIVIT00ol0003o/k>cok>c/`0C
ok>c/`03o`000?nIVIWoVIVI00;oVIVI00?o0000ogmoOomoOgl00_moOgl01Ol0003oIVIVofIVI_mV
IVKo000000GoC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C003oda<C005o`000?mV
IVKoIVIVofIVI_l000000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000?o/k>c00?o0000olc<c?o<
c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH0
1Ol0003oC4a<oda<C?m<C4co000000So<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmo
o`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00_o0000ok>c/onc/k?o/k>co`000?nIVIWo
0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00[o0000oda<C?m<C4co
0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c00<o`000?nc
/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co00001_ooool1o`00007ooooo0Ooo
ool002Cooooo00?o0000ooooooooool00oooool4oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000
oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000
oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00KoOgmo00?o0000
oiVIVOnIVIT01OnIVIT00ol0003o/k>cok>c/`0Cok>c/`03o`000?nIVIWoVIVI00;oVIVI00?o0000
ogmoOomoOgl00_moOgl01Ol0003oIVIVofIVI_mVIVKo000000GoC4a<00?o0000oc<c<olc<c<01Olc
<c<00ol0003oC4a<oda<C003oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Go0000oiVIVOnIVIWo
VIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVI
V@04o`000?moOgooOgmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`09o`000?m<
C4coC4a<oda<C?l0003oIVIVo`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`0
2ol0003o/k>cok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c
<olc<c<01olc<c<00ol0003oC4a<o`000002ofIVIP;o000000GoVIVIo`000?nc/k?o/k>co`000009
olc<c00<o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l0003o<c<c1_ooool1
o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool3oiVIV@03o`000?nc/k?o/k>c
01Oo/k>c00?o0000oiVIVOnIVIT02_nIVIT2o`0000[oOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0
003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl01_moOgl00ol0
003oVIVIoiVIV@05oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT00_nIVIT00ol0
003oOgmoogmoO`02ogmoO`05o`000?mVIVKoIVIVofIVI_l000001_m<C4`00ol0003o<c<coc<c<`04
oc<c<`03o`000?m<C4coC4a<00?oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`04o`000?nI
VIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;o
VIVI00Co0000ogmoOomoOgoo00000_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`04o`000?m<C4co
C4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00008olc<c004o`00
0?nc/k?o/k>co`0000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c
00Oo<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<
olc<c006olc<c00=o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co0000
oc<c<`06ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`;oVIVI0_l0
000Gok>c/`;o00003?nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o
0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?moOgooOgmo00GoOgmo00?o
0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`0Cok>c/`03o`000?nIVIWoVIVI00;oVIVI00?o
0000ogmoOomoOgl00_moOgl01Ol0003oIVIVofIVI_mVIVKo000000KoC4a<00?o0000oc<c<olc<c<0
1?lc<c<00ol0003oC4a<oda<C003oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01?l0003o
VIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002
oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<01?l0003oC4a<
oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01?l0
003o/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c
<`07oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<
c?o<c<`01_o<c<`03Ol0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`00
0?lc<c<01_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool00onIVIWo
0000ok>c/`0Gok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003o
IVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH2o`0000So
Ogmo00?o0000oiVIVOnIVIT01OnIVIT00ol0003o/k>cok>c/`0Cok>c/`03o`000?nIVIWoVIVI00;o
VIVI00?o0000ogmoOomoOgl00_moOgl01Ol0003oIVIVofIVI_mVIVKo000000KoC4a<00?o0000oc<c
<olc<c<01?lc<c<00ol0003oC4a<oda<C003oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl0
1?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>c
o`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<01?l0
003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002Oo<
c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o
<c<c00Oo<c<c00?o0000oda<C?m<C4`00_l000001omoOgoo0000oiVIVOnIVIWo0000ok>c/ol00000
2?o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000;o<c<c
1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool00ol0003o/k>cok>c
/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIV
IP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmo
O`07ogmoO`03o`000?nIVIWoVIVI00GoVIVI00?o0000ok>c/onc/k<04onc/k<00ol0003oVIVIoiVI
V@03oiVIV@05o`000?moOgooOgmoogmoOol000001?mVIVH00ol0003oC4a<oda<C004oda<C003o`00
0?lc<c?o<c<c00?o<c<c00?o0000oda<C?m<C4`00om<C4`01Ol0003oIVIVofIVI_mVIVKo000000?o
Ogmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c
00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00002oda<C003o`000?lc
<c?o<c<c00Oo<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`00
0?nc/k?o/k>co`0000Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mVIVKo
000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo
00000_nIVIT00ol0003o/k>co`000008olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0
003oIVIVo`000?m<C4co00000_lc<c<6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?nc/k?o/k>c01Go/k>c0_l0000=oiVIV@03o`000?moOgooOgmo00SoOgmo
00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00coIVIV
00?o0000ogmoOomoOgl01_moOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c01?o/k>c
00?o0000oiVIVOnIVIT00onIVIT01Ol0003oOgmoogmoOomoOgoo000000CoIVIV00?o0000oda<C?m<
C4`00om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Go0000ofIVI_mV
IVKoIVIVo`000003ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`0
0ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00?o0000ofIVI_l000000om<
C4`00ol0003o<c<coc<c<`07oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol00000
0_nIVIT01?l0003o/k>cok>c/ol00008olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Go0000ogmo
Ool0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00So0000oda<C?m<C4co0000ofIV
I_l0003oOgmoo`0000;oVIVI00?o0000ok>c/ol000002?o<c<`03?l0003o/k>cok>c/ol0003oVIVI
o`000?moOgoo0000ofIVI_l0003oC4a<o`0000;o<c<c1_ooool1o`00007ooooo0Oooool002Cooooo
0_l00004oooooaOo/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`00
0?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP;o0000
2?moOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT0
0onIVIT01Ol0003oOgmoogmoOomoOgoo000000CoIVIV00?o0000oda<C?m<C4`01?m<C4`00ol0003o
<c<coc<c<`03oc<c<`03o`000?m<C4coC4a<00CoC4a<00Co0000ofIVI_mVIVKo00000omoOgl01?l0
003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<0
1?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000;oC4a<00?o0000oc<c<olc<c<0
1olc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc
/k?o00002Oo<c<`00ol0003o/k>co`000002oiVIV@03o`000?moOgoo000000;oIVIV00?o0000oda<
C?l000002?lc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00Go0000oiVIVOl0003o/k>c
o`000008olc<c004o`000?nc/k?o/k>co`0000;oVIVI0_l000001OmVIVKo0000oda<C?m<C4co0000
00;o<c<c1Oooool2o`0000;ooooo000Tooooo`03o`000?oooooooooo00?ooooo5_nc/k<00ol0003o
VIVIoiVIV@0;oiVIV@;o00002_moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01Ko
C4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`07ogmoO`03o`000?nIVIWoVIVI00Ko
VIVI00?o0000ok>c/onc/k<04onc/k<00ol0003oVIVIoiVIV@03oiVIV@03o`000?moOgooOgmo00;o
Ogmo00Go0000ofIVI_mVIVKoIVIVo`000006oda<C003o`000?lc<c?o<c<c00?o<c<c00?o0000oda<
C?m<C4`01?m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`00
0003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000003oiVIV@03o`00
0?moOgoo000000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`05o`000?m<C4coC4a<oda<
C?l000000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Woc<c<00?o0000
ok>c/ol000000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc
<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<co
c<c<00Koc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00003
oc<c<`Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo5_nc/k<00ol0
003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02_mVIVH00ol0
003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl01omoOgl00ol0
003oVIVIoiVIV@05oiVIV@03o`000?nc/k?o/k>c01Co/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0
003oOgmoogmoO`02ogmoO`05o`000?mVIVKoIVIVofIVI_l000001_m<C4`00ol0003o<c<coc<c<`03
oc<c<`03o`000?m<C4coC4a<00CoC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`05o`000?nI
VIWoVIVIoiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol0
00000onIVIT00ol0003oOgmoo`000002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01Ol0
003oC4a<oda<C?m<C4co000000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol0
0009olc<c003o`000?nc/k?o000000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`00
0?lc<c?o<c<c00Ko<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc
/k<00ol0003oc<c<olc<c006olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIV
o`000?m<C4co00000olc<c<6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03
oooooaGo/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKo
IVIV00[oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?moOgoo
Ogmo00OoOgmo00?o0000oiVIVOnIVIT01OnIVIT00ol0003o/k>cok>c/`0Dok>c/`03o`000?nIVIWo
VIVI00?oVIVI00?o0000ogmoOomoOgl00_moOgl01Ol0003oIVIVofIVI_mVIVKo000000OoC4a<00?o
0000oc<c<olc<c<00olc<c<00ol0003oC4a<oda<C003oda<C005o`000?mVIVKoIVIVofIVI_l00000
0omoOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc
/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000
oc<c<olc<c<01_lc<c<01ol0003oC4a<oda<C?m<C4co0000ofIVI_l000000_moOgl01?l0003oVIVI
oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002
ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02_l0003oC4a<oda<C?l0
003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Goc<c<00[o0000ok>c
/onc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIV0_l00004oc<c<`Kooooo0Ol00001ooooo`7o
oooo000Tooooo`03o`000?oooooooooo00?ooooo5?nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`00
0?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<oda<C00Foda<C003o`00
0?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@06oiVIV@03o`00
0?nc/k?o/k>c01Co/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`02ogmoO`05o`00
0?mVIVKoIVIVofIVI_l000001_m<C4`00ol0003o<c<coc<c<`03oc<c<`03o`000?m<C4coC4a<00Co
C4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000onc/k<0
0ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000onIVIT00ol0003oOgmoo`00
0002ofIVIP05o`000?m<C4coC4a<oda<C?l000002Olc<c<01?l0003oC4a<oda<C?l00002ofIVIP03
o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`00ol0003o/k>co`000002oiVI
V@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4co
C4a<o`0000;oIVIV0_l000001OnIVIWo0000ok>c/onc/k?o000000Soc<c<00co0000ok>c/onc/k?o
0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00004oc<c<`Kooooo0Ol00001ooooo`7ooooo
000Tooooo`03o`000?oooooooooo00?ooooo4_nc/k<2o`0000goVIVI00?o0000ogmoOomoOgl02?mo
Ogl2o`0000coIVIV0_l0000Hoda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?mo
Ogl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT00onI
VIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01?m<
C4`00ol0003o<c<coc<c<`02oc<c<`;o00001Om<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo
00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c
/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<C?l000002Olc
<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo00000_nc/k<00ol0
003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Go0000ogmoOol0003oIVIVo`00
0002oda<C003o`000?lc<c?o<c<c00Ko<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`00
0?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c009o`000?nc/k?o/k>co`000?nIVIWo0000
ogmoOol0003oIVIV00;o00001Olc<c<6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003ooooo
ooooo`03oooooa;o/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`00
0?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`00
0?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT01onIVIT00ol0003o/k>cok>c/`0Cok>c/`03o`00
0?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP02ofIVIP03o`00
0?m<C4coC4a<00?oC4a<00?o0000oc<c<olc<c<00olc<c<00ol0003oC4a<oda<C004oda<C005o`00
0?mVIVKoIVIVofIVI_l000000omoOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<
00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Go
0000oda<C?m<C4coC4a<o`000009oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl00ol0
003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Co0000ok>c/onc/k?o00000_nIVIT0
1Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02_l0003oC4a<oda<
C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Wo0000
ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVH00_l00005oc<c<`Kooooo0Ol00001ooooo`7o
oooo000Tooooo`03o`000?oooooooooo00?ooooo4Onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`00
0?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Goda<C003o`00
0?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@07oiVIV@03o`00
0?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`02ogmoO`03o`00
0?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01?m<C4`00ol0003o<c<coc<c<`02oc<c<`03o`00
0?m<C4coC4a<00GoC4a<00Co0000ofIVI_mVIVKo00000omoOgl01?l0003oVIVIoiVIVOl00004ok>c
/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgoo
Ogmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`000009oc<c<`06o`000?m<C4coC4a<o`000?mV
IVKo00000_moOgl01?l0003oVIVIoiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00[o0000
ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`07oc<c
<`03o`000?m<C4coC4a<00;o000000OoOgmoo`000?nIVIWoVIVIo`000?nc/k?o000000Soc<c<00co
0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00005oc<c<`Kooooo0Ol0
0001ooooo`7ooooo000Booooo`Co000000So410@ooooooooooook^k^oc8b<_l0003o<S8bonk^kPKo
oooo00?o0000ooooooooool00oooool?ok>c/`;o00003OnIVIT00ol0003oOgmoogmoO`08ogmoO`03
o`000?mVIVKoIVIV00_oIVIV0_l0000Hoda<C003o`000?mVIVKoIVIV00[oIVIV0_l0000:ogmoO`03
o`000?nIVIWoVIVI00KoVIVI0_l0000Fok>c/`03o`000?nIVIWoVIVI00;oVIVI00?o0000ogmoOomo
Ogl00_moOgl00ol0003oIVIVofIVIP02ofIVIP03o`000?m<C4coC4a<00GoC4a<00?o0000oc<c<olc
<c<00_lc<c<00ol0003oC4a<oda<C004oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01Ol0
003oVIVIoiVIVOnIVIWo000000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02
ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<c
oc<c<`06oc<c<`07o`000?m<C4coC4a<oda<C?l0003oIVIVo`000002ogmoO`03o`000?nIVIWo0000
00?o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@05o`000?moOgoo
0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo
0000ogmoOol00002oiVIV@03o`000?nc/k?o000000Soc<c<00co0000ok>c/onc/k?o0000oiVIVOl0
003oOgmoo`000?mVIVKo0000oda<C?l00005oc<c<`Kooooo0Ol00001ooooo`7ooooo000Dooooo`03
o`000?oooooooooo00;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo
00?ooooo3onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIV
I_mVIVH02omVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00[oIVIV00?o0000ogmo
OomoOgl02OmoOgl00ol0003oVIVIoiVIV@07oiVIV@03o`000?nc/k?o/k>c01Co/k>c00?o0000oiVI
VOnIVIT00_nIVIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<
C?m<C4`01Om<C4`00ol0003o<c<coc<c<`02oc<c<`03o`000?m<C4coC4a<00CoC4a<00Go0000ofIV
I_mVIVKoIVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0003oc<c<olc<
c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIV
ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Co0000oda<C?m<C4co00000_mVIVH01_l0
003oOgmoogmoOol0003oVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c
/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`08
o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVIV@03o`000?nc/k?o000000Soc<c<00co
0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00005oc<c<`Kooooo0Ol0
0001ooooo`7ooooo000Dooooo`03o`000?oooooooooo00;ooooo00Go410@oooooooooooooooooa0@
4006ooooo`03o`000?oooooooooo00?ooooo3_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?mo
OgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mV
IVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@07oiVIV@03o`000?nc
/k?o/k>c01Co/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mV
IVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01Om<C4`00ol0003o<c<coc<c<`02oc<c<`03o`000?m<
C4coC4a<00CoC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`04o`000?nIVIWoVIVIo`0000Co
/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`00
00;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4co
C4a<oda<C?l000000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000?o/k>c00?o0000olc<c?o<c<`0
1_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0
003o<c<coc<c<`06oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl01Ol0003oVIVIo`00
0?nc/k?o000000Woc<c<00?o0000ok>c/ol000000_nIVIT2o`000005ofIVI_l0003oC4a<oda<C?l0
00001Olc<c<6ooooo`7o00000Oooool1ooooo`005?ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000001_ooool3o`0000?ooooo3Onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03
o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Goda<C003
o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@07oiVIV@03
o`000?nc/k?o/k>c01Go/k>c00?o0000oiVIVOnIVIT00onIVIT01Ol0003oOgmoogmoOomoOgoo0000
00CoIVIV00?o0000oda<C?m<C4`01Om<C4`00ol0003o<c<coc<c<`02oc<c<`03o`000?m<C4coC4a<
00CoC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc
/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo0000
0_moOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<
C4co00000_mVIVH01_l0003oOgmoogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01oo<
c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o
<c<coc<c<`06oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c
00?o0000olc<c?o<c<`01oo<c<`02ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<
C4co000000Ko<c<c1?ooool3o`0000;ooooo000Dooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo?oooool1o`00007ooooo0Ooo
ool001Cooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00Kooooo00?o
0000ooooooooool0ooooooloooooo`7o00000Oooool1ooooo`005?ooool00ol0003oooooooooo`02
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3oooooocoooooo0Ol0
0001ooooo`7ooooo000Booooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP06ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool09oooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`0Wooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`03ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00?ooooo0Ol00001ooooo`7ooooo000Toooooooo0000@ol00002ooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-7.04757, -6.93977, 0.0606246, \
0.0606246}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% ContourGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.339744 0.0641026 0.339744 0.0641026 [
[.08333 -0.0125 -6 -9 ]
[.08333 -0.0125 6 0 ]
[.21154 -0.0125 -6 -9 ]
[.21154 -0.0125 6 0 ]
[.33974 -0.0125 -3 -9 ]
[.33974 -0.0125 3 0 ]
[.46795 -0.0125 -3 -9 ]
[.46795 -0.0125 3 0 ]
[.59615 -0.0125 -3 -9 ]
[.59615 -0.0125 3 0 ]
[.72436 -0.0125 -3 -9 ]
[.72436 -0.0125 3 0 ]
[.85256 -0.0125 -3 -9 ]
[.85256 -0.0125 3 0 ]
[.98077 -0.0125 -6 -9 ]
[.98077 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5 -21 ]
[.5 -0.0125 5 -9 ]
[-0.0125 .08333 -12 -4.5 ]
[-0.0125 .08333 0 4.5 ]
[-0.0125 .21154 -12 -4.5 ]
[-0.0125 .21154 0 4.5 ]
[-0.0125 .33974 -6 -4.5 ]
[-0.0125 .33974 0 4.5 ]
[-0.0125 .46795 -6 -4.5 ]
[-0.0125 .46795 0 4.5 ]
[-0.0125 .59615 -6 -4.5 ]
[-0.0125 .59615 0 4.5 ]
[-0.0125 .72436 -6 -4.5 ]
[-0.0125 .72436 0 4.5 ]
[-0.0125 .85256 -6 -4.5 ]
[-0.0125 .85256 0 4.5 ]
[-0.0125 .98077 -12 -4.5 ]
[-0.0125 .98077 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -24 -5 ]
[-0.01875 .5 -12 5 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.08333 0 m
.08333 .00625 L
s
[(-4)] .08333 -0.0125 0 1 Mshowa
.21154 0 m
.21154 .00625 L
s
[(-2)] .21154 -0.0125 0 1 Mshowa
.33974 0 m
.33974 .00625 L
s
[(0)] .33974 -0.0125 0 1 Mshowa
.46795 0 m
.46795 .00625 L
s
[(2)] .46795 -0.0125 0 1 Mshowa
.59615 0 m
.59615 .00625 L
s
[(4)] .59615 -0.0125 0 1 Mshowa
.72436 0 m
.72436 .00625 L
s
[(6)] .72436 -0.0125 0 1 Mshowa
.85256 0 m
.85256 .00625 L
s
[(8)] .85256 -0.0125 0 1 Mshowa
.98077 0 m
.98077 .00625 L
s
[(10)] .98077 -0.0125 0 1 Mshowa
.125 Mabswid
.11538 0 m
.11538 .00375 L
s
.14744 0 m
.14744 .00375 L
s
.17949 0 m
.17949 .00375 L
s
.24359 0 m
.24359 .00375 L
s
.27564 0 m
.27564 .00375 L
s
.30769 0 m
.30769 .00375 L
s
.37179 0 m
.37179 .00375 L
s
.40385 0 m
.40385 .00375 L
s
.4359 0 m
.4359 .00375 L
s
.5 0 m
.5 .00375 L
s
.53205 0 m
.53205 .00375 L
s
.5641 0 m
.5641 .00375 L
s
.62821 0 m
.62821 .00375 L
s
.66026 0 m
.66026 .00375 L
s
.69231 0 m
.69231 .00375 L
s
.75641 0 m
.75641 .00375 L
s
.78846 0 m
.78846 .00375 L
s
.82051 0 m
.82051 .00375 L
s
.88462 0 m
.88462 .00375 L
s
.91667 0 m
.91667 .00375 L
s
.94872 0 m
.94872 .00375 L
s
.05128 0 m
.05128 .00375 L
s
.01923 0 m
.01923 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66 -25 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .08333 m
.00625 .08333 L
s
[(-4)] -0.0125 .08333 1 0 Mshowa
0 .21154 m
.00625 .21154 L
s
[(-2)] -0.0125 .21154 1 0 Mshowa
0 .33974 m
.00625 .33974 L
s
[(0)] -0.0125 .33974 1 0 Mshowa
0 .46795 m
.00625 .46795 L
s
[(2)] -0.0125 .46795 1 0 Mshowa
0 .59615 m
.00625 .59615 L
s
[(4)] -0.0125 .59615 1 0 Mshowa
0 .72436 m
.00625 .72436 L
s
[(6)] -0.0125 .72436 1 0 Mshowa
0 .85256 m
.00625 .85256 L
s
[(8)] -0.0125 .85256 1 0 Mshowa
0 .98077 m
.00625 .98077 L
s
[(10)] -0.0125 .98077 1 0 Mshowa
.125 Mabswid
0 .11538 m
.00375 .11538 L
s
0 .14744 m
.00375 .14744 L
s
0 .17949 m
.00375 .17949 L
s
0 .24359 m
.00375 .24359 L
s
0 .27564 m
.00375 .27564 L
s
0 .30769 m
.00375 .30769 L
s
0 .37179 m
.00375 .37179 L
s
0 .40385 m
.00375 .40385 L
s
0 .4359 m
.00375 .4359 L
s
0 .5 m
.00375 .5 L
s
0 .53205 m
.00375 .53205 L
s
0 .5641 m
.00375 .5641 L
s
0 .62821 m
.00375 .62821 L
s
0 .66026 m
.00375 .66026 L
s
0 .69231 m
.00375 .69231 L
s
0 .75641 m
.00375 .75641 L
s
0 .78846 m
.00375 .78846 L
s
0 .82051 m
.00375 .82051 L
s
0 .88462 m
.00375 .88462 L
s
0 .91667 m
.00375 .91667 L
s
0 .94872 m
.00375 .94872 L
s
0 .05128 m
.00375 .05128 L
s
0 .01923 m
.00375 .01923 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
-0.01875 .5 -84 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
66 10 translate
90 rotate
-66 -10 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.08333 .99375 m
.08333 1 L
s
.21154 .99375 m
.21154 1 L
s
.33974 .99375 m
.33974 1 L
s
.46795 .99375 m
.46795 1 L
s
.59615 .99375 m
.59615 1 L
s
.72436 .99375 m
.72436 1 L
s
.85256 .99375 m
.85256 1 L
s
.98077 .99375 m
.98077 1 L
s
.125 Mabswid
.11538 .99625 m
.11538 1 L
s
.14744 .99625 m
.14744 1 L
s
.17949 .99625 m
.17949 1 L
s
.24359 .99625 m
.24359 1 L
s
.27564 .99625 m
.27564 1 L
s
.30769 .99625 m
.30769 1 L
s
.37179 .99625 m
.37179 1 L
s
.40385 .99625 m
.40385 1 L
s
.4359 .99625 m
.4359 1 L
s
.5 .99625 m
.5 1 L
s
.53205 .99625 m
.53205 1 L
s
.5641 .99625 m
.5641 1 L
s
.62821 .99625 m
.62821 1 L
s
.66026 .99625 m
.66026 1 L
s
.69231 .99625 m
.69231 1 L
s
.75641 .99625 m
.75641 1 L
s
.78846 .99625 m
.78846 1 L
s
.82051 .99625 m
.82051 1 L
s
.88462 .99625 m
.88462 1 L
s
.91667 .99625 m
.91667 1 L
s
.94872 .99625 m
.94872 1 L
s
.05128 .99625 m
.05128 1 L
s
.01923 .99625 m
.01923 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .08333 m
1 .08333 L
s
.99375 .21154 m
1 .21154 L
s
.99375 .33974 m
1 .33974 L
s
.99375 .46795 m
1 .46795 L
s
.99375 .59615 m
1 .59615 L
s
.99375 .72436 m
1 .72436 L
s
.99375 .85256 m
1 .85256 L
s
.99375 .98077 m
1 .98077 L
s
.125 Mabswid
.99625 .11538 m
1 .11538 L
s
.99625 .14744 m
1 .14744 L
s
.99625 .17949 m
1 .17949 L
s
.99625 .24359 m
1 .24359 L
s
.99625 .27564 m
1 .27564 L
s
.99625 .30769 m
1 .30769 L
s
.99625 .37179 m
1 .37179 L
s
.99625 .40385 m
1 .40385 L
s
.99625 .4359 m
1 .4359 L
s
.99625 .5 m
1 .5 L
s
.99625 .53205 m
1 .53205 L
s
.99625 .5641 m
1 .5641 L
s
.99625 .62821 m
1 .62821 L
s
.99625 .66026 m
1 .66026 L
s
.99625 .69231 m
1 .69231 L
s
.99625 .75641 m
1 .75641 L
s
.99625 .78846 m
1 .78846 L
s
.99625 .82051 m
1 .82051 L
s
.99625 .88462 m
1 .88462 L
s
.99625 .91667 m
1 .91667 L
s
.99625 .94872 m
1 .94872 L
s
.99625 .05128 m
1 .05128 L
s
.99625 .01923 m
1 .01923 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.6 g
.01923 .98077 m
.98077 .98077 L
.98077 .01923 L
.01923 .01923 L
F
0 g
.5 Mabswid
.5 g
.01923 .93976 m
.02679 .93221 L
.02894 .93005 L
.0365 .92249 L
.03866 .92034 L
.04621 .91278 L
.04837 .91062 L
.05592 .90307 L
.05808 .90091 L
.06564 .89336 L
.06779 .8912 L
.07535 .88364 L
.07751 .88149 L
.08506 .87393 L
.08722 .87177 L
.09477 .86422 L
.09693 .86206 L
.10449 .85451 L
.10664 .85235 L
.1142 .84479 L
.11636 .84264 L
.12391 .83508 L
.12607 .83292 L
.13362 .82537 L
.13578 .82321 L
.14334 .81566 L
.14549 .8135 L
.15305 .80594 L
.15521 .80379 L
.16276 .79623 L
.16492 .79407 L
.17247 .78652 L
.17463 .78436 L
.18219 .77681 L
.18434 .77465 L
.1919 .76709 L
.19406 .76494 L
.20161 .75738 L
.20377 .75522 L
.21132 .74767 L
.21348 .74551 L
.22104 .73796 L
.22319 .7358 L
.23075 .72824 L
.23291 .72609 L
.24046 .71853 L
.24262 .71637 L
.25017 .70882 L
.25233 .70666 L
.25989 .69911 L
.26204 .69695 L
.2696 .68939 L
.27176 .68724 L
.27931 .67968 L
.28147 .67752 L
.28902 .66997 L
.29118 .66781 L
.29874 .66026 L
.30089 .6581 L
.30845 .65054 L
.31061 .64839 L
.31816 .64083 L
.32032 .63867 L
.32787 .63112 L
.33003 .62896 L
.33765 .62141 L
.33974 .61925 L
.34664 .61169 L
.34946 .60855 L
.35517 .60198 L
.35917 .59726 L
.36332 .59227 L
.36888 .5854 L
.37114 .58256 L
.37859 .57298 L
.3787 .57284 L
.38602 .56313 L
.38831 .56003 L
.39312 .55342 L
.39802 .54656 L
.40003 .54371 L
.40677 .53399 L
.40773 .53259 L
.41335 .52428 L
.41744 .51813 L
.41979 .51457 L
.42609 .50486 L
.42716 .5032 L
.43227 .49514 L
.43687 .48781 L
.43834 .48543 L
.44431 .47572 L
.44658 .47197 L
.45017 .46601 L
.45594 .45629 L
.45629 .45569 L
.46162 .44658 L
.46601 .43899 L
.46722 .43687 L
.47274 .42716 L
.47572 .42187 L
.47819 .41744 L
.48357 .40773 L
.48543 .40435 L
.48888 .39802 L
.49414 .38831 L
.49514 .38643 L
.49932 .37859 L
.50446 .36888 L
.50486 .36812 L
.50952 .35917 L
.51455 .34946 L
.51457 .34942 L
.51952 .33974 L
.52428 .33036 L
.52444 .33003 L
.52931 .32032 L
.53399 .31092 L
.53415 .31061 L
.53893 .30089 L
.54368 .29118 L
.54371 .29113 L
.54837 .28147 L
.55305 .27176 L
.55342 .27097 L
.55766 .26204 L
.56226 .25233 L
.56313 .25047 L
.5668 .24262 L
.57133 .23291 L
.57284 .22963 L
.5758 .22319 L
.58026 .21348 L
.58256 .20845 L
.58467 .20377 L
.58907 .19406 L
.59227 .18694 L
.59342 .18434 L
.59775 .17463 L
.60198 .1651 L
.60206 .16492 L
.60632 .15521 L
.61058 .14549 L
.61169 .14294 L
.61478 .13578 L
.61899 .12607 L
.62141 .12045 L
.62315 .11636 L
.6273 .10664 L
.63112 .09766 L
.63142 .09693 L
.63551 .08722 L
.6396 .07751 L
.64083 .07455 L
.64363 .06779 L
.64767 .05808 L
.65054 .05114 L
.65167 .04837 L
.65566 .03866 L
.65964 .02894 L
.66026 .02743 L
.66357 .01923 L
.01923 .01923 L
F
0 g
.01923 .93976 m
.02679 .93221 L
.02894 .93005 L
.0365 .92249 L
.03866 .92034 L
.04621 .91278 L
.04837 .91062 L
.05592 .90307 L
.05808 .90091 L
.06564 .89336 L
.06779 .8912 L
.07535 .88364 L
.07751 .88149 L
.08506 .87393 L
.08722 .87177 L
.09477 .86422 L
.09693 .86206 L
.10449 .85451 L
.10664 .85235 L
.1142 .84479 L
.11636 .84264 L
.12391 .83508 L
.12607 .83292 L
.13362 .82537 L
.13578 .82321 L
.14334 .81566 L
.14549 .8135 L
.15305 .80594 L
.15521 .80379 L
.16276 .79623 L
.16492 .79407 L
.17247 .78652 L
.17463 .78436 L
.18219 .77681 L
.18434 .77465 L
.1919 .76709 L
.19406 .76494 L
.20161 .75738 L
.20377 .75522 L
.21132 .74767 L
.21348 .74551 L
.22104 .73796 L
.22319 .7358 L
.23075 .72824 L
.23291 .72609 L
.24046 .71853 L
.24262 .71637 L
.25017 .70882 L
.25233 .70666 L
.25989 .69911 L
Mistroke
.26204 .69695 L
.2696 .68939 L
.27176 .68724 L
.27931 .67968 L
.28147 .67752 L
.28902 .66997 L
.29118 .66781 L
.29874 .66026 L
.30089 .6581 L
.30845 .65054 L
.31061 .64839 L
.31816 .64083 L
.32032 .63867 L
.32787 .63112 L
.33003 .62896 L
.33765 .62141 L
.33974 .61925 L
.34664 .61169 L
.34946 .60855 L
.35517 .60198 L
.35917 .59726 L
.36332 .59227 L
.36888 .5854 L
.37114 .58256 L
.37859 .57298 L
.3787 .57284 L
.38602 .56313 L
.38831 .56003 L
.39312 .55342 L
.39802 .54656 L
.40003 .54371 L
.40677 .53399 L
.40773 .53259 L
.41335 .52428 L
.41744 .51813 L
.41979 .51457 L
.42609 .50486 L
.42716 .5032 L
.43227 .49514 L
.43687 .48781 L
.43834 .48543 L
.44431 .47572 L
.44658 .47197 L
.45017 .46601 L
.45594 .45629 L
.45629 .45569 L
.46162 .44658 L
.46601 .43899 L
.46722 .43687 L
.47274 .42716 L
Mistroke
.47572 .42187 L
.47819 .41744 L
.48357 .40773 L
.48543 .40435 L
.48888 .39802 L
.49414 .38831 L
.49514 .38643 L
.49932 .37859 L
.50446 .36888 L
.50486 .36812 L
.50952 .35917 L
.51455 .34946 L
.51457 .34942 L
.51952 .33974 L
.52428 .33036 L
.52444 .33003 L
.52931 .32032 L
.53399 .31092 L
.53415 .31061 L
.53893 .30089 L
.54368 .29118 L
.54371 .29113 L
.54837 .28147 L
.55305 .27176 L
.55342 .27097 L
.55766 .26204 L
.56226 .25233 L
.56313 .25047 L
.5668 .24262 L
.57133 .23291 L
.57284 .22963 L
.5758 .22319 L
.58026 .21348 L
.58256 .20845 L
.58467 .20377 L
.58907 .19406 L
.59227 .18694 L
.59342 .18434 L
.59775 .17463 L
.60198 .1651 L
.60206 .16492 L
.60632 .15521 L
.61058 .14549 L
.61169 .14294 L
.61478 .13578 L
.61899 .12607 L
.62141 .12045 L
.62315 .11636 L
.6273 .10664 L
.63112 .09766 L
Mistroke
.63142 .09693 L
.63551 .08722 L
.6396 .07751 L
.64083 .07455 L
.64363 .06779 L
.64767 .05808 L
.65054 .05114 L
.65167 .04837 L
.65566 .03866 L
.65964 .02894 L
.66026 .02743 L
.66357 .01923 L
Mfstroke
.4 g
.01923 .90435 m
.02051 .90307 L
.02894 .89464 L
.03022 .89336 L
.03866 .88492 L
.03994 .88364 L
.04837 .87521 L
.04965 .87393 L
.05808 .8655 L
.05936 .86422 L
.06779 .85579 L
.06907 .85451 L
.07751 .84607 L
.07879 .84479 L
.08722 .83636 L
.0885 .83508 L
.09693 .82665 L
.09821 .82537 L
.10664 .81694 L
.10792 .81566 L
.11636 .80722 L
.11764 .80594 L
.12607 .79751 L
.12735 .79623 L
.13578 .7878 L
.13706 .78652 L
.14549 .77809 L
.14677 .77681 L
.15521 .76837 L
.15649 .76709 L
.16492 .75866 L
.1662 .75738 L
.17463 .74895 L
.17591 .74767 L
.18434 .73924 L
.18562 .73796 L
.19406 .72952 L
.19534 .72824 L
.20377 .71981 L
.20505 .71853 L
.21348 .7101 L
.21476 .70882 L
.22319 .70039 L
.22447 .69911 L
.23291 .69067 L
.23419 .68939 L
.24262 .68096 L
.2439 .67968 L
.25233 .67125 L
.25361 .66997 L
.26204 .66154 L
.26332 .66026 L
.27176 .65182 L
.27304 .65054 L
.28147 .64211 L
.28275 .64083 L
.29118 .6324 L
.29246 .63112 L
.30089 .62269 L
.30217 .62141 L
.31061 .61297 L
.31189 .61169 L
.32032 .60326 L
.3216 .60198 L
.33003 .59355 L
.33132 .59227 L
.33974 .58384 L
.34104 .58256 L
.34946 .57439 L
.35099 .57284 L
.35917 .56417 L
.36012 .56313 L
.36871 .55342 L
.36888 .55322 L
.37689 .54371 L
.37859 .54161 L
.38471 .53399 L
.38831 .52937 L
.39223 .52428 L
.39802 .51654 L
.39948 .51457 L
.40652 .50486 L
.40773 .50315 L
.41337 .49514 L
.41744 .48922 L
.42003 .48543 L
.42653 .47572 L
.42716 .47477 L
.4329 .46601 L
.43687 .45982 L
.43913 .45629 L
.44523 .44658 L
.44658 .4444 L
.45123 .43687 L
.45629 .4285 L
.45711 .42716 L
.46291 .41744 L
.46601 .41216 L
.4686 .40773 L
.47422 .39802 L
.47572 .39538 L
.47976 .38831 L
.4852 .37859 L
.48543 .37817 L
.4906 .36888 L
.49514 .36055 L
.4959 .35917 L
.50116 .34946 L
.50486 .34252 L
.50634 .33974 L
.51148 .33003 L
.51457 .3241 L
.51654 .32032 L
.52157 .31061 L
.52428 .30528 L
.52653 .30089 L
.53146 .29118 L
.53399 .28609 L
.53631 .28147 L
.54115 .27176 L
.54371 .26653 L
.54591 .26204 L
.55066 .25233 L
.55342 .2466 L
.55534 .24262 L
.56001 .23291 L
.56313 .22631 L
.56461 .22319 L
.56921 .21348 L
.57284 .20567 L
.57373 .20377 L
.57826 .19406 L
.58256 .18468 L
.58271 .18434 L
.58717 .17463 L
.59157 .16492 L
.59227 .16335 L
.59596 .15521 L
.60031 .14549 L
.60198 .14169 L
.60462 .13578 L
.60892 .12607 L
.61169 .1197 L
.61317 .11636 L
.61742 .10664 L
.62141 .09739 L
.6216 .09693 L
.62581 .08722 L
.62996 .07751 L
.63112 .07475 L
.63409 .06779 L
.63822 .05808 L
.64083 .0518 L
.64228 .04837 L
.64637 .03866 L
.65038 .02894 L
.65054 .02854 L
.65442 .01923 L
.01923 .01923 L
F
0 g
.01923 .90435 m
.02051 .90307 L
.02894 .89464 L
.03022 .89336 L
.03866 .88492 L
.03994 .88364 L
.04837 .87521 L
.04965 .87393 L
.05808 .8655 L
.05936 .86422 L
.06779 .85579 L
.06907 .85451 L
.07751 .84607 L
.07879 .84479 L
.08722 .83636 L
.0885 .83508 L
.09693 .82665 L
.09821 .82537 L
.10664 .81694 L
.10792 .81566 L
.11636 .80722 L
.11764 .80594 L
.12607 .79751 L
.12735 .79623 L
.13578 .7878 L
.13706 .78652 L
.14549 .77809 L
.14677 .77681 L
.15521 .76837 L
.15649 .76709 L
.16492 .75866 L
.1662 .75738 L
.17463 .74895 L
.17591 .74767 L
.18434 .73924 L
.18562 .73796 L
.19406 .72952 L
.19534 .72824 L
.20377 .71981 L
.20505 .71853 L
.21348 .7101 L
.21476 .70882 L
.22319 .70039 L
.22447 .69911 L
.23291 .69067 L
.23419 .68939 L
.24262 .68096 L
.2439 .67968 L
.25233 .67125 L
.25361 .66997 L
Mistroke
.26204 .66154 L
.26332 .66026 L
.27176 .65182 L
.27304 .65054 L
.28147 .64211 L
.28275 .64083 L
.29118 .6324 L
.29246 .63112 L
.30089 .62269 L
.30217 .62141 L
.31061 .61297 L
.31189 .61169 L
.32032 .60326 L
.3216 .60198 L
.33003 .59355 L
.33132 .59227 L
.33974 .58384 L
.34104 .58256 L
.34946 .57439 L
.35099 .57284 L
.35917 .56417 L
.36012 .56313 L
.36871 .55342 L
.36888 .55322 L
.37689 .54371 L
.37859 .54161 L
.38471 .53399 L
.38831 .52937 L
.39223 .52428 L
.39802 .51654 L
.39948 .51457 L
.40652 .50486 L
.40773 .50315 L
.41337 .49514 L
.41744 .48922 L
.42003 .48543 L
.42653 .47572 L
.42716 .47477 L
.4329 .46601 L
.43687 .45982 L
.43913 .45629 L
.44523 .44658 L
.44658 .4444 L
.45123 .43687 L
.45629 .4285 L
.45711 .42716 L
.46291 .41744 L
.46601 .41216 L
.4686 .40773 L
.47422 .39802 L
Mistroke
.47572 .39538 L
.47976 .38831 L
.4852 .37859 L
.48543 .37817 L
.4906 .36888 L
.49514 .36055 L
.4959 .35917 L
.50116 .34946 L
.50486 .34252 L
.50634 .33974 L
.51148 .33003 L
.51457 .3241 L
.51654 .32032 L
.52157 .31061 L
.52428 .30528 L
.52653 .30089 L
.53146 .29118 L
.53399 .28609 L
.53631 .28147 L
.54115 .27176 L
.54371 .26653 L
.54591 .26204 L
.55066 .25233 L
.55342 .2466 L
.55534 .24262 L
.56001 .23291 L
.56313 .22631 L
.56461 .22319 L
.56921 .21348 L
.57284 .20567 L
.57373 .20377 L
.57826 .19406 L
.58256 .18468 L
.58271 .18434 L
.58717 .17463 L
.59157 .16492 L
.59227 .16335 L
.59596 .15521 L
.60031 .14549 L
.60198 .14169 L
.60462 .13578 L
.60892 .12607 L
.61169 .1197 L
.61317 .11636 L
.61742 .10664 L
.62141 .09739 L
.6216 .09693 L
.62581 .08722 L
.62996 .07751 L
.63112 .07475 L
Mistroke
.63409 .06779 L
.63822 .05808 L
.64083 .0518 L
.64228 .04837 L
.64637 .03866 L
.65038 .02894 L
.65054 .02854 L
.65442 .01923 L
Mfstroke
.3 g
.01923 .86068 m
.02532 .85451 L
.02894 .85097 L
.03512 .84479 L
.03866 .84126 L
.04483 .83508 L
.04837 .83154 L
.05454 .82537 L
.05808 .82183 L
.06425 .81566 L
.06779 .81212 L
.07397 .80594 L
.07751 .80241 L
.08368 .79623 L
.08722 .79269 L
.09339 .78652 L
.09693 .78298 L
.1031 .77681 L
.10664 .77327 L
.11282 .76709 L
.11636 .76356 L
.12253 .75738 L
.12607 .75384 L
.13224 .74767 L
.13578 .74413 L
.14195 .73796 L
.14549 .73442 L
.15167 .72824 L
.15521 .72471 L
.16138 .71853 L
.16492 .71499 L
.17109 .70882 L
.17463 .70528 L
.1808 .69911 L
.18434 .69557 L
.19052 .68939 L
.19406 .68586 L
.20023 .67968 L
.20377 .67614 L
.20994 .66997 L
.21348 .66643 L
.21965 .66026 L
.22319 .65672 L
.22937 .65054 L
.23291 .64701 L
.23908 .64083 L
.24262 .63729 L
.24879 .63112 L
.25233 .62758 L
.2585 .62141 L
.26204 .61787 L
.26822 .61169 L
.27176 .60816 L
.27793 .60198 L
.28147 .59844 L
.28764 .59227 L
.29118 .58873 L
.29735 .58256 L
.30089 .57902 L
.30707 .57284 L
.31061 .5693 L
.31678 .56313 L
.32032 .55959 L
.32649 .55342 L
.33003 .54988 L
.33609 .54371 L
.33974 .54017 L
.34809 .53399 L
.34946 .53312 L
.35917 .5248 L
.35976 .52428 L
.36888 .51543 L
.36976 .51457 L
.37859 .50514 L
.37886 .50486 L
.38745 .49514 L
.38831 .49405 L
.39555 .48543 L
.39802 .48222 L
.40323 .47572 L
.40773 .4697 L
.41056 .46601 L
.41744 .45653 L
.41762 .45629 L
.42462 .44658 L
.42716 .4428 L
.43131 .43687 L
.43687 .42849 L
.43777 .42716 L
.44423 .41744 L
.44658 .41365 L
.45044 .40773 L
.45629 .39829 L
.45646 .39802 L
.46255 .38831 L
.46601 .38245 L
.46837 .37859 L
.47418 .36888 L
.47572 .36613 L
.47986 .35917 L
.48537 .34946 L
.48543 .34934 L
.49098 .33974 L
.49514 .33213 L
.49633 .33003 L
.50178 .32032 L
.50486 .31448 L
.507 .31061 L
.51228 .30089 L
.51457 .29641 L
.5174 .29118 L
.52253 .28147 L
.52428 .27793 L
.52755 .27176 L
.53255 .26204 L
.53399 .25905 L
.53748 .25233 L
.54237 .24262 L
.54371 .23979 L
.54721 .23291 L
.55201 .22319 L
.55342 .22014 L
.55675 .21348 L
.56148 .20377 L
.56313 .20013 L
.56611 .19406 L
.57078 .18434 L
.57284 .17974 L
.57531 .17463 L
.57993 .16492 L
.58256 .159 L
.58436 .15521 L
.58893 .14549 L
.59227 .13791 L
.59326 .13578 L
.59779 .12607 L
.60198 .11647 L
.60203 .11636 L
.6065 .10664 L
.61079 .09693 L
.61169 .0947 L
.61509 .08722 L
.6194 .07751 L
.62141 .0726 L
.62355 .06779 L
.62786 .05808 L
.63112 .05016 L
.63191 .04837 L
.63618 .03866 L
.64024 .02894 L
.64083 .0274 L
.64439 .01923 L
.01923 .01923 L
F
0 g
.01923 .86068 m
.02532 .85451 L
.02894 .85097 L
.03512 .84479 L
.03866 .84126 L
.04483 .83508 L
.04837 .83154 L
.05454 .82537 L
.05808 .82183 L
.06425 .81566 L
.06779 .81212 L
.07397 .80594 L
.07751 .80241 L
.08368 .79623 L
.08722 .79269 L
.09339 .78652 L
.09693 .78298 L
.1031 .77681 L
.10664 .77327 L
.11282 .76709 L
.11636 .76356 L
.12253 .75738 L
.12607 .75384 L
.13224 .74767 L
.13578 .74413 L
.14195 .73796 L
.14549 .73442 L
.15167 .72824 L
.15521 .72471 L
.16138 .71853 L
.16492 .71499 L
.17109 .70882 L
.17463 .70528 L
.1808 .69911 L
.18434 .69557 L
.19052 .68939 L
.19406 .68586 L
.20023 .67968 L
.20377 .67614 L
.20994 .66997 L
.21348 .66643 L
.21965 .66026 L
.22319 .65672 L
.22937 .65054 L
.23291 .64701 L
.23908 .64083 L
.24262 .63729 L
.24879 .63112 L
.25233 .62758 L
.2585 .62141 L
Mistroke
.26204 .61787 L
.26822 .61169 L
.27176 .60816 L
.27793 .60198 L
.28147 .59844 L
.28764 .59227 L
.29118 .58873 L
.29735 .58256 L
.30089 .57902 L
.30707 .57284 L
.31061 .5693 L
.31678 .56313 L
.32032 .55959 L
.32649 .55342 L
.33003 .54988 L
.33609 .54371 L
.33974 .54017 L
.34809 .53399 L
.34946 .53312 L
.35917 .5248 L
.35976 .52428 L
.36888 .51543 L
.36976 .51457 L
.37859 .50514 L
.37886 .50486 L
.38745 .49514 L
.38831 .49405 L
.39555 .48543 L
.39802 .48222 L
.40323 .47572 L
.40773 .4697 L
.41056 .46601 L
.41744 .45653 L
.41762 .45629 L
.42462 .44658 L
.42716 .4428 L
.43131 .43687 L
.43687 .42849 L
.43777 .42716 L
.44423 .41744 L
.44658 .41365 L
.45044 .40773 L
.45629 .39829 L
.45646 .39802 L
.46255 .38831 L
.46601 .38245 L
.46837 .37859 L
.47418 .36888 L
.47572 .36613 L
.47986 .35917 L
Mistroke
.48537 .34946 L
.48543 .34934 L
.49098 .33974 L
.49514 .33213 L
.49633 .33003 L
.50178 .32032 L
.50486 .31448 L
.507 .31061 L
.51228 .30089 L
.51457 .29641 L
.5174 .29118 L
.52253 .28147 L
.52428 .27793 L
.52755 .27176 L
.53255 .26204 L
.53399 .25905 L
.53748 .25233 L
.54237 .24262 L
.54371 .23979 L
.54721 .23291 L
.55201 .22319 L
.55342 .22014 L
.55675 .21348 L
.56148 .20377 L
.56313 .20013 L
.56611 .19406 L
.57078 .18434 L
.57284 .17974 L
.57531 .17463 L
.57993 .16492 L
.58256 .159 L
.58436 .15521 L
.58893 .14549 L
.59227 .13791 L
.59326 .13578 L
.59779 .12607 L
.60198 .11647 L
.60203 .11636 L
.6065 .10664 L
.61079 .09693 L
.61169 .0947 L
.61509 .08722 L
.6194 .07751 L
.62141 .0726 L
.62355 .06779 L
.62786 .05808 L
.63112 .05016 L
.63191 .04837 L
.63618 .03866 L
.64024 .02894 L
Mistroke
.64083 .0274 L
.64439 .01923 L
Mfstroke
.4 g
.01923 .78205 m
.02474 .77681 L
.02894 .77234 L
.03419 .76709 L
.03866 .76263 L
.0439 .75738 L
.04837 .75291 L
.05361 .74767 L
.05808 .7432 L
.06333 .73796 L
.06779 .73349 L
.07304 .72824 L
.07751 .72378 L
.08275 .71853 L
.08722 .71406 L
.09246 .70882 L
.09693 .70435 L
.10218 .69911 L
.10664 .69464 L
.11189 .68939 L
.11636 .68493 L
.1216 .67968 L
.12607 .67521 L
.13131 .66997 L
.13578 .6655 L
.14103 .66026 L
.14549 .65579 L
.15074 .65054 L
.15521 .64608 L
.16045 .64083 L
.16492 .63636 L
.17016 .63112 L
.17463 .62665 L
.17988 .62141 L
.18434 .61694 L
.18959 .61169 L
.19406 .60723 L
.1993 .60198 L
.20377 .59751 L
.20901 .59227 L
.21348 .5878 L
.21873 .58256 L
.22319 .57809 L
.22844 .57284 L
.23291 .56838 L
.23815 .56313 L
.24262 .55866 L
.24786 .55342 L
.25233 .54895 L
.25758 .54371 L
.26204 .53924 L
.26729 .53399 L
.27176 .52953 L
.277 .52428 L
.28147 .51981 L
.28671 .51457 L
.29118 .5101 L
.29643 .50486 L
.30089 .50039 L
.30614 .49514 L
.31061 .49068 L
.31585 .48543 L
.32032 .48096 L
.32556 .47572 L
.33003 .47125 L
.33558 .46601 L
.33974 .46154 L
.34377 .45629 L
.34946 .44843 L
.35083 .44658 L
.35798 .43687 L
.35917 .43523 L
.36502 .42716 L
.36888 .42178 L
.37197 .41744 L
.37859 .40806 L
.37883 .40773 L
.38553 .39802 L
.38831 .39396 L
.39212 .38831 L
.39802 .37951 L
.39862 .37859 L
.40498 .36888 L
.40773 .36466 L
.41123 .35917 L
.41743 .34946 L
.41744 .34943 L
.42346 .33974 L
.42716 .33378 L
.42942 .33003 L
.43532 .32032 L
.43687 .31775 L
.44109 .31061 L
.44658 .30134 L
.44683 .30089 L
.45244 .29118 L
.45629 .28451 L
.458 .28147 L
.4635 .27176 L
.46601 .26732 L
.46889 .26204 L
.47429 .25233 L
.47572 .24974 L
.47954 .24262 L
.48483 .23291 L
.48543 .23179 L
.48996 .22319 L
.49514 .21348 L
.49514 .21347 L
.50015 .20377 L
.50486 .19478 L
.50522 .19406 L
.51015 .18434 L
.51457 .17573 L
.5151 .17463 L
.51995 .16492 L
.52428 .15633 L
.52482 .15521 L
.52957 .14549 L
.53399 .13658 L
.53437 .13578 L
.53903 .12607 L
.54371 .11649 L
.54377 .11636 L
.54833 .10664 L
.553 .09693 L
.55342 .09605 L
.55748 .08722 L
.56208 .07751 L
.56313 .07528 L
.56651 .06779 L
.57103 .05808 L
.57284 .05417 L
.5754 .04837 L
.57985 .03866 L
.58256 .03274 L
.58419 .02894 L
.58854 .01923 L
.01923 .01923 L
F
0 g
.01923 .78205 m
.02474 .77681 L
.02894 .77234 L
.03419 .76709 L
.03866 .76263 L
.0439 .75738 L
.04837 .75291 L
.05361 .74767 L
.05808 .7432 L
.06333 .73796 L
.06779 .73349 L
.07304 .72824 L
.07751 .72378 L
.08275 .71853 L
.08722 .71406 L
.09246 .70882 L
.09693 .70435 L
.10218 .69911 L
.10664 .69464 L
.11189 .68939 L
.11636 .68493 L
.1216 .67968 L
.12607 .67521 L
.13131 .66997 L
.13578 .6655 L
.14103 .66026 L
.14549 .65579 L
.15074 .65054 L
.15521 .64608 L
.16045 .64083 L
.16492 .63636 L
.17016 .63112 L
.17463 .62665 L
.17988 .62141 L
.18434 .61694 L
.18959 .61169 L
.19406 .60723 L
.1993 .60198 L
.20377 .59751 L
.20901 .59227 L
.21348 .5878 L
.21873 .58256 L
.22319 .57809 L
.22844 .57284 L
.23291 .56838 L
.23815 .56313 L
.24262 .55866 L
.24786 .55342 L
.25233 .54895 L
.25758 .54371 L
Mistroke
.26204 .53924 L
.26729 .53399 L
.27176 .52953 L
.277 .52428 L
.28147 .51981 L
.28671 .51457 L
.29118 .5101 L
.29643 .50486 L
.30089 .50039 L
.30614 .49514 L
.31061 .49068 L
.31585 .48543 L
.32032 .48096 L
.32556 .47572 L
.33003 .47125 L
.33558 .46601 L
.33974 .46154 L
.34377 .45629 L
.34946 .44843 L
.35083 .44658 L
.35798 .43687 L
.35917 .43523 L
.36502 .42716 L
.36888 .42178 L
.37197 .41744 L
.37859 .40806 L
.37883 .40773 L
.38553 .39802 L
.38831 .39396 L
.39212 .38831 L
.39802 .37951 L
.39862 .37859 L
.40498 .36888 L
.40773 .36466 L
.41123 .35917 L
.41743 .34946 L
.41744 .34943 L
.42346 .33974 L
.42716 .33378 L
.42942 .33003 L
.43532 .32032 L
.43687 .31775 L
.44109 .31061 L
.44658 .30134 L
.44683 .30089 L
.45244 .29118 L
.45629 .28451 L
.458 .28147 L
.4635 .27176 L
.46601 .26732 L
Mistroke
.46889 .26204 L
.47429 .25233 L
.47572 .24974 L
.47954 .24262 L
.48483 .23291 L
.48543 .23179 L
.48996 .22319 L
.49514 .21348 L
.49514 .21347 L
.50015 .20377 L
.50486 .19478 L
.50522 .19406 L
.51015 .18434 L
.51457 .17573 L
.5151 .17463 L
.51995 .16492 L
.52428 .15633 L
.52482 .15521 L
.52957 .14549 L
.53399 .13658 L
.53437 .13578 L
.53903 .12607 L
.54371 .11649 L
.54377 .11636 L
.54833 .10664 L
.553 .09693 L
.55342 .09605 L
.55748 .08722 L
.56208 .07751 L
.56313 .07528 L
.56651 .06779 L
.57103 .05808 L
.57284 .05417 L
.5754 .04837 L
.57985 .03866 L
.58256 .03274 L
.58419 .02894 L
.58854 .01923 L
Mfstroke
.5 g
.01923 .73838 m
.01966 .73796 L
.02894 .72867 L
.02936 .72824 L
.03866 .71895 L
.03908 .71853 L
.04837 .70924 L
.04879 .70882 L
.05808 .69953 L
.0585 .69911 L
.06779 .68982 L
.06821 .68939 L
.07751 .6801 L
.07793 .67968 L
.08722 .67039 L
.08764 .66997 L
.09693 .66068 L
.09735 .66026 L
.10664 .65097 L
.10706 .65054 L
.11636 .64125 L
.11678 .64083 L
.12607 .63154 L
.12649 .63112 L
.13578 .62183 L
.1362 .62141 L
.14549 .61212 L
.14591 .61169 L
.15521 .6024 L
.15563 .60198 L
.16492 .59269 L
.16534 .59227 L
.17463 .58298 L
.17505 .58256 L
.18434 .57327 L
.18476 .57284 L
.19406 .56355 L
.19448 .56313 L
.20377 .55384 L
.20419 .55342 L
.21348 .54413 L
.2139 .54371 L
.22319 .53442 L
.22362 .53399 L
.23291 .5247 L
.23333 .52428 L
.24262 .51499 L
.24304 .51457 L
.25233 .50528 L
.25275 .50486 L
.26204 .49557 L
.26247 .49514 L
.27176 .48585 L
.27218 .48543 L
.28147 .47614 L
.28189 .47572 L
.29118 .46643 L
.2916 .46601 L
.30089 .45672 L
.30132 .45629 L
.31061 .447 L
.31103 .44658 L
.32032 .43729 L
.32074 .43687 L
.33003 .42758 L
.33046 .42716 L
.33974 .41787 L
.34014 .41744 L
.34895 .40773 L
.34946 .40716 L
.35737 .39802 L
.35917 .39587 L
.36542 .38831 L
.36888 .38401 L
.37318 .37859 L
.37859 .3716 L
.38067 .36888 L
.38792 .35917 L
.38831 .35865 L
.39497 .34946 L
.39802 .34518 L
.40184 .33974 L
.40773 .33121 L
.40853 .33003 L
.41508 .32032 L
.41744 .31675 L
.42147 .31061 L
.42716 .30181 L
.42775 .30089 L
.4339 .29118 L
.43687 .28642 L
.43993 .28147 L
.44587 .27176 L
.44658 .27058 L
.45171 .26204 L
.45629 .25431 L
.45745 .25233 L
.46312 .24262 L
.46601 .23761 L
.46869 .23291 L
.4742 .22319 L
.47572 .22049 L
.47963 .21348 L
.48499 .20377 L
.48543 .20297 L
.49028 .19406 L
.49514 .18504 L
.49552 .18434 L
.50069 .17463 L
.50486 .16673 L
.5058 .16492 L
.51086 .15521 L
.51457 .14804 L
.51587 .14549 L
.52083 .13578 L
.52428 .12897 L
.52574 .12607 L
.5306 .11636 L
.53399 .10954 L
.53542 .10664 L
.54019 .09693 L
.54371 .08974 L
.54492 .08722 L
.54962 .07751 L
.55342 .06959 L
.55427 .06779 L
.55888 .05808 L
.56313 .04909 L
.56347 .04837 L
.568 .03866 L
.57252 .02894 L
.57284 .02825 L
.57699 .01923 L
.01923 .01923 L
F
0 g
.01923 .73838 m
.01966 .73796 L
.02894 .72867 L
.02936 .72824 L
.03866 .71895 L
.03908 .71853 L
.04837 .70924 L
.04879 .70882 L
.05808 .69953 L
.0585 .69911 L
.06779 .68982 L
.06821 .68939 L
.07751 .6801 L
.07793 .67968 L
.08722 .67039 L
.08764 .66997 L
.09693 .66068 L
.09735 .66026 L
.10664 .65097 L
.10706 .65054 L
.11636 .64125 L
.11678 .64083 L
.12607 .63154 L
.12649 .63112 L
.13578 .62183 L
.1362 .62141 L
.14549 .61212 L
.14591 .61169 L
.15521 .6024 L
.15563 .60198 L
.16492 .59269 L
.16534 .59227 L
.17463 .58298 L
.17505 .58256 L
.18434 .57327 L
.18476 .57284 L
.19406 .56355 L
.19448 .56313 L
.20377 .55384 L
.20419 .55342 L
.21348 .54413 L
.2139 .54371 L
.22319 .53442 L
.22362 .53399 L
.23291 .5247 L
.23333 .52428 L
.24262 .51499 L
.24304 .51457 L
.25233 .50528 L
.25275 .50486 L
Mistroke
.26204 .49557 L
.26247 .49514 L
.27176 .48585 L
.27218 .48543 L
.28147 .47614 L
.28189 .47572 L
.29118 .46643 L
.2916 .46601 L
.30089 .45672 L
.30132 .45629 L
.31061 .447 L
.31103 .44658 L
.32032 .43729 L
.32074 .43687 L
.33003 .42758 L
.33046 .42716 L
.33974 .41787 L
.34014 .41744 L
.34895 .40773 L
.34946 .40716 L
.35737 .39802 L
.35917 .39587 L
.36542 .38831 L
.36888 .38401 L
.37318 .37859 L
.37859 .3716 L
.38067 .36888 L
.38792 .35917 L
.38831 .35865 L
.39497 .34946 L
.39802 .34518 L
.40184 .33974 L
.40773 .33121 L
.40853 .33003 L
.41508 .32032 L
.41744 .31675 L
.42147 .31061 L
.42716 .30181 L
.42775 .30089 L
.4339 .29118 L
.43687 .28642 L
.43993 .28147 L
.44587 .27176 L
.44658 .27058 L
.45171 .26204 L
.45629 .25431 L
.45745 .25233 L
.46312 .24262 L
.46601 .23761 L
.46869 .23291 L
Mistroke
.4742 .22319 L
.47572 .22049 L
.47963 .21348 L
.48499 .20377 L
.48543 .20297 L
.49028 .19406 L
.49514 .18504 L
.49552 .18434 L
.50069 .17463 L
.50486 .16673 L
.5058 .16492 L
.51086 .15521 L
.51457 .14804 L
.51587 .14549 L
.52083 .13578 L
.52428 .12897 L
.52574 .12607 L
.5306 .11636 L
.53399 .10954 L
.53542 .10664 L
.54019 .09693 L
.54371 .08974 L
.54492 .08722 L
.54962 .07751 L
.55342 .06959 L
.55427 .06779 L
.55888 .05808 L
.56313 .04909 L
.56347 .04837 L
.568 .03866 L
.57252 .02894 L
.57284 .02825 L
.57699 .01923 L
Mfstroke
.6 g
.01923 .70297 m
.02309 .69911 L
.02894 .69325 L
.0328 .68939 L
.03866 .68354 L
.04252 .67968 L
.04837 .67383 L
.05223 .66997 L
.05808 .66412 L
.06194 .66026 L
.06779 .6544 L
.07165 .65054 L
.07751 .64469 L
.08137 .64083 L
.08722 .63498 L
.09108 .63112 L
.09693 .62527 L
.10079 .62141 L
.10664 .61555 L
.1105 .61169 L
.11636 .60584 L
.12022 .60198 L
.12607 .59613 L
.12993 .59227 L
.13578 .58642 L
.13964 .58256 L
.14549 .5767 L
.14935 .57284 L
.15521 .56699 L
.15907 .56313 L
.16492 .55728 L
.16878 .55342 L
.17463 .54757 L
.17849 .54371 L
.18434 .53785 L
.1882 .53399 L
.19406 .52814 L
.19792 .52428 L
.20377 .51843 L
.20763 .51457 L
.21348 .50872 L
.21734 .50486 L
.22319 .499 L
.22705 .49514 L
.23291 .48929 L
.23677 .48543 L
.24262 .47958 L
.24648 .47572 L
.25233 .46987 L
.25619 .46601 L
.26204 .46015 L
.2659 .45629 L
.27176 .45044 L
.27562 .44658 L
.28147 .44073 L
.28533 .43687 L
.29118 .43102 L
.29504 .42716 L
.30089 .4213 L
.30475 .41744 L
.31061 .41159 L
.31447 .40773 L
.32032 .40188 L
.32418 .39802 L
.33003 .39217 L
.33391 .38831 L
.33974 .38245 L
.34368 .37859 L
.34946 .37301 L
.35349 .36888 L
.35917 .36278 L
.36246 .35917 L
.36888 .35184 L
.37093 .34946 L
.37859 .34023 L
.37899 .33974 L
.38673 .33003 L
.38831 .32799 L
.39418 .32032 L
.39802 .31516 L
.40138 .31061 L
.40773 .30176 L
.40835 .30089 L
.41516 .29118 L
.41744 .28783 L
.42178 .28147 L
.42716 .27338 L
.42823 .27176 L
.43457 .26204 L
.43687 .25844 L
.44076 .25233 L
.44658 .24301 L
.44683 .24262 L
.45281 .23291 L
.45629 .22712 L
.45866 .22319 L
.46443 .21348 L
.46601 .21078 L
.47011 .20377 L
.47568 .19406 L
.47572 .194 L
.48121 .18434 L
.48543 .17679 L
.48664 .17463 L
.49202 .16492 L
.49514 .15917 L
.4973 .15521 L
.50255 .14549 L
.50486 .14114 L
.50771 .13578 L
.51283 .12607 L
.51457 .12271 L
.51789 .11636 L
.52289 .10664 L
.52428 .1039 L
.52784 .09693 L
.53275 .08722 L
.53399 .08471 L
.5376 .07751 L
.54241 .06779 L
.54371 .06514 L
.54718 .05808 L
.55191 .04837 L
.55342 .04521 L
.55659 .03866 L
.56124 .02894 L
.56313 .02492 L
.56584 .01923 L
.01923 .01923 L
F
0 g
.01923 .70297 m
.02309 .69911 L
.02894 .69325 L
.0328 .68939 L
.03866 .68354 L
.04252 .67968 L
.04837 .67383 L
.05223 .66997 L
.05808 .66412 L
.06194 .66026 L
.06779 .6544 L
.07165 .65054 L
.07751 .64469 L
.08137 .64083 L
.08722 .63498 L
.09108 .63112 L
.09693 .62527 L
.10079 .62141 L
.10664 .61555 L
.1105 .61169 L
.11636 .60584 L
.12022 .60198 L
.12607 .59613 L
.12993 .59227 L
.13578 .58642 L
.13964 .58256 L
.14549 .5767 L
.14935 .57284 L
.15521 .56699 L
.15907 .56313 L
.16492 .55728 L
.16878 .55342 L
.17463 .54757 L
.17849 .54371 L
.18434 .53785 L
.1882 .53399 L
.19406 .52814 L
.19792 .52428 L
.20377 .51843 L
.20763 .51457 L
.21348 .50872 L
.21734 .50486 L
.22319 .499 L
.22705 .49514 L
.23291 .48929 L
.23677 .48543 L
.24262 .47958 L
.24648 .47572 L
.25233 .46987 L
.25619 .46601 L
Mistroke
.26204 .46015 L
.2659 .45629 L
.27176 .45044 L
.27562 .44658 L
.28147 .44073 L
.28533 .43687 L
.29118 .43102 L
.29504 .42716 L
.30089 .4213 L
.30475 .41744 L
.31061 .41159 L
.31447 .40773 L
.32032 .40188 L
.32418 .39802 L
.33003 .39217 L
.33391 .38831 L
.33974 .38245 L
.34368 .37859 L
.34946 .37301 L
.35349 .36888 L
.35917 .36278 L
.36246 .35917 L
.36888 .35184 L
.37093 .34946 L
.37859 .34023 L
.37899 .33974 L
.38673 .33003 L
.38831 .32799 L
.39418 .32032 L
.39802 .31516 L
.40138 .31061 L
.40773 .30176 L
.40835 .30089 L
.41516 .29118 L
.41744 .28783 L
.42178 .28147 L
.42716 .27338 L
.42823 .27176 L
.43457 .26204 L
.43687 .25844 L
.44076 .25233 L
.44658 .24301 L
.44683 .24262 L
.45281 .23291 L
.45629 .22712 L
.45866 .22319 L
.46443 .21348 L
.46601 .21078 L
.47011 .20377 L
.47568 .19406 L
Mistroke
.47572 .194 L
.48121 .18434 L
.48543 .17679 L
.48664 .17463 L
.49202 .16492 L
.49514 .15917 L
.4973 .15521 L
.50255 .14549 L
.50486 .14114 L
.50771 .13578 L
.51283 .12607 L
.51457 .12271 L
.51789 .11636 L
.52289 .10664 L
.52428 .1039 L
.52784 .09693 L
.53275 .08722 L
.53399 .08471 L
.5376 .07751 L
.54241 .06779 L
.54371 .06514 L
.54718 .05808 L
.55191 .04837 L
.55342 .04521 L
.55659 .03866 L
.56124 .02894 L
.56313 .02492 L
.56584 .01923 L
Mfstroke
.7 g
.01923 .65927 m
.02792 .65054 L
.02894 .64956 L
.03767 .64083 L
.03866 .63985 L
.04738 .63112 L
.04837 .63013 L
.0571 .62141 L
.05808 .62042 L
.06681 .61169 L
.06779 .61071 L
.07652 .60198 L
.07751 .601 L
.08623 .59227 L
.08722 .59128 L
.09595 .58256 L
.09693 .58157 L
.10566 .57284 L
.10664 .57186 L
.11537 .56313 L
.11636 .56215 L
.12508 .55342 L
.12607 .55243 L
.1348 .54371 L
.13578 .54272 L
.14451 .53399 L
.14549 .53301 L
.15422 .52428 L
.15521 .5233 L
.16393 .51457 L
.16492 .51358 L
.17365 .50486 L
.17463 .50387 L
.18336 .49514 L
.18434 .49416 L
.19307 .48543 L
.19406 .48445 L
.20278 .47572 L
.20377 .47473 L
.2125 .46601 L
.21348 .46502 L
.22221 .45629 L
.22319 .45531 L
.23192 .44658 L
.23291 .4456 L
.24163 .43687 L
.24262 .43588 L
.25135 .42716 L
.25233 .42617 L
.26106 .41744 L
.26204 .41646 L
.27077 .40773 L
.27176 .40675 L
.28048 .39802 L
.28147 .39703 L
.2902 .38831 L
.29118 .38732 L
.29991 .37859 L
.30089 .37761 L
.30962 .36888 L
.31061 .3679 L
.31933 .35917 L
.32032 .35818 L
.32905 .34946 L
.33003 .34847 L
.33869 .33974 L
.33974 .33876 L
.34946 .33174 L
.35172 .33003 L
.35917 .32344 L
.36267 .32032 L
.36888 .31406 L
.37235 .31061 L
.37859 .30377 L
.38125 .30089 L
.38831 .29266 L
.38958 .29118 L
.39754 .28147 L
.39802 .28082 L
.40522 .27176 L
.40773 .26832 L
.41252 .26204 L
.41744 .25516 L
.41952 .25233 L
.42637 .24262 L
.42716 .24141 L
.43308 .23291 L
.43687 .22711 L
.43952 .22319 L
.44584 .21348 L
.44658 .21226 L
.4521 .20377 L
.45629 .19691 L
.4581 .19406 L
.46411 .18434 L
.46601 .18107 L
.46995 .17463 L
.47562 .16492 L
.47572 .16474 L
.48138 .15521 L
.48543 .14797 L
.48687 .14549 L
.49243 .13578 L
.49514 .13075 L
.4978 .12607 L
.50317 .11636 L
.50486 .1131 L
.50842 .10664 L
.51361 .09693 L
.51457 .09502 L
.51879 .08722 L
.52381 .07751 L
.52428 .07654 L
.52891 .06779 L
.5338 .05808 L
.53399 .05766 L
.53881 .04837 L
.54359 .03866 L
.54371 .0384 L
.54851 .02894 L
.5532 .01923 L
.01923 .01923 L
F
0 g
.01923 .65927 m
.02792 .65054 L
.02894 .64956 L
.03767 .64083 L
.03866 .63985 L
.04738 .63112 L
.04837 .63013 L
.0571 .62141 L
.05808 .62042 L
.06681 .61169 L
.06779 .61071 L
.07652 .60198 L
.07751 .601 L
.08623 .59227 L
.08722 .59128 L
.09595 .58256 L
.09693 .58157 L
.10566 .57284 L
.10664 .57186 L
.11537 .56313 L
.11636 .56215 L
.12508 .55342 L
.12607 .55243 L
.1348 .54371 L
.13578 .54272 L
.14451 .53399 L
.14549 .53301 L
.15422 .52428 L
.15521 .5233 L
.16393 .51457 L
.16492 .51358 L
.17365 .50486 L
.17463 .50387 L
.18336 .49514 L
.18434 .49416 L
.19307 .48543 L
.19406 .48445 L
.20278 .47572 L
.20377 .47473 L
.2125 .46601 L
.21348 .46502 L
.22221 .45629 L
.22319 .45531 L
.23192 .44658 L
.23291 .4456 L
.24163 .43687 L
.24262 .43588 L
.25135 .42716 L
.25233 .42617 L
.26106 .41744 L
Mistroke
.26204 .41646 L
.27077 .40773 L
.27176 .40675 L
.28048 .39802 L
.28147 .39703 L
.2902 .38831 L
.29118 .38732 L
.29991 .37859 L
.30089 .37761 L
.30962 .36888 L
.31061 .3679 L
.31933 .35917 L
.32032 .35818 L
.32905 .34946 L
.33003 .34847 L
.33869 .33974 L
.33974 .33876 L
.34946 .33174 L
.35172 .33003 L
.35917 .32344 L
.36267 .32032 L
.36888 .31406 L
.37235 .31061 L
.37859 .30377 L
.38125 .30089 L
.38831 .29266 L
.38958 .29118 L
.39754 .28147 L
.39802 .28082 L
.40522 .27176 L
.40773 .26832 L
.41252 .26204 L
.41744 .25516 L
.41952 .25233 L
.42637 .24262 L
.42716 .24141 L
.43308 .23291 L
.43687 .22711 L
.43952 .22319 L
.44584 .21348 L
.44658 .21226 L
.4521 .20377 L
.45629 .19691 L
.4581 .19406 L
.46411 .18434 L
.46601 .18107 L
.46995 .17463 L
.47562 .16492 L
.47572 .16474 L
.48138 .15521 L
Mistroke
.48543 .14797 L
.48687 .14549 L
.49243 .13578 L
.49514 .13075 L
.4978 .12607 L
.50317 .11636 L
.50486 .1131 L
.50842 .10664 L
.51361 .09693 L
.51457 .09502 L
.51879 .08722 L
.52381 .07751 L
.52428 .07654 L
.52891 .06779 L
.5338 .05808 L
.53399 .05766 L
.53881 .04837 L
.54359 .03866 L
.54371 .0384 L
.54851 .02894 L
.5532 .01923 L
Mfstroke
.6 g
.01923 .58069 m
.02717 .57284 L
.02894 .57098 L
.03679 .56313 L
.03866 .56127 L
.0465 .55342 L
.04837 .55155 L
.05622 .54371 L
.05808 .54184 L
.06593 .53399 L
.06779 .53213 L
.07564 .52428 L
.07751 .52242 L
.08535 .51457 L
.08722 .5127 L
.09507 .50486 L
.09693 .50299 L
.10478 .49514 L
.10664 .49328 L
.11449 .48543 L
.11636 .48357 L
.1242 .47572 L
.12607 .47385 L
.13392 .46601 L
.13578 .46414 L
.14363 .45629 L
.14549 .45443 L
.15334 .44658 L
.15521 .44472 L
.16305 .43687 L
.16492 .435 L
.17277 .42716 L
.17463 .42529 L
.18248 .41744 L
.18434 .41558 L
.19219 .40773 L
.19406 .40587 L
.2019 .39802 L
.20377 .39615 L
.21162 .38831 L
.21348 .38644 L
.22133 .37859 L
.22319 .37673 L
.23104 .36888 L
.23291 .36702 L
.24075 .35917 L
.24262 .3573 L
.25047 .34946 L
.25233 .34759 L
.26018 .33974 L
.26204 .33788 L
.26989 .33003 L
.27176 .32817 L
.2796 .32032 L
.28147 .31845 L
.28932 .31061 L
.29118 .30874 L
.29903 .30089 L
.30089 .29903 L
.30874 .29118 L
.31061 .28932 L
.31845 .28147 L
.32032 .2796 L
.32817 .27176 L
.33003 .26989 L
.33806 .26204 L
.33974 .26018 L
.34565 .25233 L
.34946 .24703 L
.35272 .24262 L
.35917 .23385 L
.35986 .23291 L
.36689 .22319 L
.36888 .22041 L
.3738 .21348 L
.37859 .20666 L
.3806 .20377 L
.38731 .19406 L
.38831 .19259 L
.39385 .18434 L
.39802 .17812 L
.40031 .17463 L
.40667 .16492 L
.40773 .16328 L
.41288 .15521 L
.41744 .14803 L
.41902 .14549 L
.42507 .13578 L
.42716 .1324 L
.43099 .12607 L
.43687 .11638 L
.43688 .11636 L
.44262 .10664 L
.44658 .09994 L
.44831 .09693 L
.45394 .08722 L
.45629 .08313 L
.45945 .07751 L
.46496 .06779 L
.46601 .06594 L
.47032 .05808 L
.47572 .04837 L
.47572 .04836 L
.48095 .03866 L
.48543 .0304 L
.48619 .02894 L
.49133 .01923 L
.01923 .01923 L
F
0 g
.01923 .58069 m
.02717 .57284 L
.02894 .57098 L
.03679 .56313 L
.03866 .56127 L
.0465 .55342 L
.04837 .55155 L
.05622 .54371 L
.05808 .54184 L
.06593 .53399 L
.06779 .53213 L
.07564 .52428 L
.07751 .52242 L
.08535 .51457 L
.08722 .5127 L
.09507 .50486 L
.09693 .50299 L
.10478 .49514 L
.10664 .49328 L
.11449 .48543 L
.11636 .48357 L
.1242 .47572 L
.12607 .47385 L
.13392 .46601 L
.13578 .46414 L
.14363 .45629 L
.14549 .45443 L
.15334 .44658 L
.15521 .44472 L
.16305 .43687 L
.16492 .435 L
.17277 .42716 L
.17463 .42529 L
.18248 .41744 L
.18434 .41558 L
.19219 .40773 L
.19406 .40587 L
.2019 .39802 L
.20377 .39615 L
.21162 .38831 L
.21348 .38644 L
.22133 .37859 L
.22319 .37673 L
.23104 .36888 L
.23291 .36702 L
.24075 .35917 L
.24262 .3573 L
.25047 .34946 L
.25233 .34759 L
.26018 .33974 L
Mistroke
.26204 .33788 L
.26989 .33003 L
.27176 .32817 L
.2796 .32032 L
.28147 .31845 L
.28932 .31061 L
.29118 .30874 L
.29903 .30089 L
.30089 .29903 L
.30874 .29118 L
.31061 .28932 L
.31845 .28147 L
.32032 .2796 L
.32817 .27176 L
.33003 .26989 L
.33806 .26204 L
.33974 .26018 L
.34565 .25233 L
.34946 .24703 L
.35272 .24262 L
.35917 .23385 L
.35986 .23291 L
.36689 .22319 L
.36888 .22041 L
.3738 .21348 L
.37859 .20666 L
.3806 .20377 L
.38731 .19406 L
.38831 .19259 L
.39385 .18434 L
.39802 .17812 L
.40031 .17463 L
.40667 .16492 L
.40773 .16328 L
.41288 .15521 L
.41744 .14803 L
.41902 .14549 L
.42507 .13578 L
.42716 .1324 L
.43099 .12607 L
.43687 .11638 L
.43688 .11636 L
.44262 .10664 L
.44658 .09994 L
.44831 .09693 L
.45394 .08722 L
.45629 .08313 L
.45945 .07751 L
.46496 .06779 L
.46601 .06594 L
Mistroke
.47032 .05808 L
.47572 .04837 L
.47572 .04836 L
.48095 .03866 L
.48543 .0304 L
.48619 .02894 L
.49133 .01923 L
Mfstroke
.5 g
.01923 .53699 m
.02224 .53399 L
.02894 .52728 L
.03194 .52428 L
.03866 .51757 L
.04165 .51457 L
.04837 .50785 L
.05137 .50486 L
.05808 .49814 L
.06108 .49514 L
.06779 .48843 L
.07079 .48543 L
.07751 .47872 L
.0805 .47572 L
.08722 .469 L
.09022 .46601 L
.09693 .45929 L
.09993 .45629 L
.10664 .44958 L
.10964 .44658 L
.11636 .43987 L
.11935 .43687 L
.12607 .43015 L
.12907 .42716 L
.13578 .42044 L
.13878 .41744 L
.14549 .41073 L
.14849 .40773 L
.15521 .40102 L
.1582 .39802 L
.16492 .3913 L
.16792 .38831 L
.17463 .38159 L
.17763 .37859 L
.18434 .37188 L
.18734 .36888 L
.19406 .36217 L
.19705 .35917 L
.20377 .35245 L
.20677 .34946 L
.21348 .34274 L
.21648 .33974 L
.22319 .33303 L
.22619 .33003 L
.23291 .32332 L
.2359 .32032 L
.24262 .3136 L
.24562 .31061 L
.25233 .30389 L
.25533 .30089 L
.26204 .29418 L
.26504 .29118 L
.27176 .28447 L
.27475 .28147 L
.28147 .27475 L
.28447 .27176 L
.29118 .26504 L
.29418 .26204 L
.30089 .25533 L
.30389 .25233 L
.31061 .24562 L
.3136 .24262 L
.32032 .2359 L
.32332 .23291 L
.33003 .22619 L
.3331 .22319 L
.33974 .21648 L
.34252 .21348 L
.34946 .20578 L
.35123 .20377 L
.35917 .19449 L
.35953 .19406 L
.36751 .18434 L
.36888 .18263 L
.37519 .17463 L
.37859 .17021 L
.38261 .16492 L
.38831 .15726 L
.38981 .15521 L
.39681 .14549 L
.39802 .14379 L
.40363 .13578 L
.40773 .12982 L
.41028 .12607 L
.41679 .11636 L
.41744 .11536 L
.42315 .10664 L
.42716 .10043 L
.42939 .09693 L
.43551 .08722 L
.43687 .08504 L
.44152 .07751 L
.44658 .0692 L
.44743 .06779 L
.45324 .05808 L
.45629 .05292 L
.45896 .04837 L
.46461 .03866 L
.46601 .03622 L
.47016 .02894 L
.47565 .01923 L
.01923 .01923 L
F
0 g
.01923 .53699 m
.02224 .53399 L
.02894 .52728 L
.03194 .52428 L
.03866 .51757 L
.04165 .51457 L
.04837 .50785 L
.05137 .50486 L
.05808 .49814 L
.06108 .49514 L
.06779 .48843 L
.07079 .48543 L
.07751 .47872 L
.0805 .47572 L
.08722 .469 L
.09022 .46601 L
.09693 .45929 L
.09993 .45629 L
.10664 .44958 L
.10964 .44658 L
.11636 .43987 L
.11935 .43687 L
.12607 .43015 L
.12907 .42716 L
.13578 .42044 L
.13878 .41744 L
.14549 .41073 L
.14849 .40773 L
.15521 .40102 L
.1582 .39802 L
.16492 .3913 L
.16792 .38831 L
.17463 .38159 L
.17763 .37859 L
.18434 .37188 L
.18734 .36888 L
.19406 .36217 L
.19705 .35917 L
.20377 .35245 L
.20677 .34946 L
.21348 .34274 L
.21648 .33974 L
.22319 .33303 L
.22619 .33003 L
.23291 .32332 L
.2359 .32032 L
.24262 .3136 L
.24562 .31061 L
.25233 .30389 L
.25533 .30089 L
Mistroke
.26204 .29418 L
.26504 .29118 L
.27176 .28447 L
.27475 .28147 L
.28147 .27475 L
.28447 .27176 L
.29118 .26504 L
.29418 .26204 L
.30089 .25533 L
.30389 .25233 L
.31061 .24562 L
.3136 .24262 L
.32032 .2359 L
.32332 .23291 L
.33003 .22619 L
.3331 .22319 L
.33974 .21648 L
.34252 .21348 L
.34946 .20578 L
.35123 .20377 L
.35917 .19449 L
.35953 .19406 L
.36751 .18434 L
.36888 .18263 L
.37519 .17463 L
.37859 .17021 L
.38261 .16492 L
.38831 .15726 L
.38981 .15521 L
.39681 .14549 L
.39802 .14379 L
.40363 .13578 L
.40773 .12982 L
.41028 .12607 L
.41679 .11636 L
.41744 .11536 L
.42315 .10664 L
.42716 .10043 L
.42939 .09693 L
.43551 .08722 L
.43687 .08504 L
.44152 .07751 L
.44658 .0692 L
.44743 .06779 L
.45324 .05808 L
.45629 .05292 L
.45896 .04837 L
.46461 .03866 L
.46601 .03622 L
.47016 .02894 L
Mistroke
.47565 .01923 L
Mfstroke
.4 g
.01923 .50158 m
.02567 .49514 L
.02894 .49187 L
.03538 .48543 L
.03866 .48216 L
.0451 .47572 L
.04837 .47245 L
.05481 .46601 L
.05808 .46273 L
.06452 .45629 L
.06779 .45302 L
.07423 .44658 L
.07751 .44331 L
.08395 .43687 L
.08722 .4336 L
.09366 .42716 L
.09693 .42388 L
.10337 .41744 L
.10664 .41417 L
.11308 .40773 L
.11636 .40446 L
.1228 .39802 L
.12607 .39475 L
.13251 .38831 L
.13578 .38503 L
.14222 .37859 L
.14549 .37532 L
.15193 .36888 L
.15521 .36561 L
.16165 .35917 L
.16492 .3559 L
.17136 .34946 L
.17463 .34618 L
.18107 .33974 L
.18434 .33647 L
.19078 .33003 L
.19406 .32676 L
.2005 .32032 L
.20377 .31705 L
.21021 .31061 L
.21348 .30733 L
.21992 .30089 L
.22319 .29762 L
.22963 .29118 L
.23291 .28791 L
.23935 .28147 L
.24262 .2782 L
.24906 .27176 L
.25233 .26848 L
.25877 .26204 L
.26204 .25877 L
.26848 .25233 L
.27176 .24906 L
.2782 .24262 L
.28147 .23935 L
.28791 .23291 L
.29118 .22963 L
.29762 .22319 L
.30089 .21992 L
.30733 .21348 L
.31061 .21021 L
.31705 .20377 L
.32032 .2005 L
.32676 .19406 L
.33003 .19078 L
.33648 .18434 L
.33974 .18107 L
.34634 .17463 L
.34946 .17163 L
.35593 .16492 L
.35917 .1614 L
.36476 .15521 L
.36888 .15046 L
.37312 .14549 L
.37859 .13884 L
.38108 .13578 L
.38831 .1266 L
.38872 .12607 L
.39611 .11636 L
.39802 .11378 L
.40326 .10664 L
.40773 .10038 L
.41018 .09693 L
.41692 .08722 L
.41744 .08645 L
.42351 .07751 L
.42716 .072 L
.42993 .06779 L
.43622 .05808 L
.43687 .05705 L
.44239 .04837 L
.44658 .04163 L
.44843 .03866 L
.45437 .02894 L
.45629 .02573 L
.46021 .01923 L
.01923 .01923 L
F
0 g
.01923 .50158 m
.02567 .49514 L
.02894 .49187 L
.03538 .48543 L
.03866 .48216 L
.0451 .47572 L
.04837 .47245 L
.05481 .46601 L
.05808 .46273 L
.06452 .45629 L
.06779 .45302 L
.07423 .44658 L
.07751 .44331 L
.08395 .43687 L
.08722 .4336 L
.09366 .42716 L
.09693 .42388 L
.10337 .41744 L
.10664 .41417 L
.11308 .40773 L
.11636 .40446 L
.1228 .39802 L
.12607 .39475 L
.13251 .38831 L
.13578 .38503 L
.14222 .37859 L
.14549 .37532 L
.15193 .36888 L
.15521 .36561 L
.16165 .35917 L
.16492 .3559 L
.17136 .34946 L
.17463 .34618 L
.18107 .33974 L
.18434 .33647 L
.19078 .33003 L
.19406 .32676 L
.2005 .32032 L
.20377 .31705 L
.21021 .31061 L
.21348 .30733 L
.21992 .30089 L
.22319 .29762 L
.22963 .29118 L
.23291 .28791 L
.23935 .28147 L
.24262 .2782 L
.24906 .27176 L
.25233 .26848 L
.25877 .26204 L
Mistroke
.26204 .25877 L
.26848 .25233 L
.27176 .24906 L
.2782 .24262 L
.28147 .23935 L
.28791 .23291 L
.29118 .22963 L
.29762 .22319 L
.30089 .21992 L
.30733 .21348 L
.31061 .21021 L
.31705 .20377 L
.32032 .2005 L
.32676 .19406 L
.33003 .19078 L
.33648 .18434 L
.33974 .18107 L
.34634 .17463 L
.34946 .17163 L
.35593 .16492 L
.35917 .1614 L
.36476 .15521 L
.36888 .15046 L
.37312 .14549 L
.37859 .13884 L
.38108 .13578 L
.38831 .1266 L
.38872 .12607 L
.39611 .11636 L
.39802 .11378 L
.40326 .10664 L
.40773 .10038 L
.41018 .09693 L
.41692 .08722 L
.41744 .08645 L
.42351 .07751 L
.42716 .072 L
.42993 .06779 L
.43622 .05808 L
.43687 .05705 L
.44239 .04837 L
.44658 .04163 L
.44843 .03866 L
.45437 .02894 L
.45629 .02573 L
.46021 .01923 L
Mfstroke
.3 g
.01923 .45788 m
.02078 .45629 L
.02894 .44817 L
.03053 .44658 L
.03866 .43845 L
.04024 .43687 L
.04837 .42874 L
.04995 .42716 L
.05808 .41903 L
.05967 .41744 L
.06779 .40932 L
.06938 .40773 L
.07751 .3996 L
.07909 .39802 L
.08722 .38989 L
.0888 .38831 L
.09693 .38018 L
.09852 .37859 L
.10664 .37047 L
.10823 .36888 L
.11636 .36075 L
.11794 .35917 L
.12607 .35104 L
.12765 .34946 L
.13578 .34133 L
.13737 .33974 L
.14549 .33162 L
.14708 .33003 L
.15521 .3219 L
.15679 .32032 L
.16492 .31219 L
.1665 .31061 L
.17463 .30248 L
.17622 .30089 L
.18434 .29277 L
.18593 .29118 L
.19406 .28305 L
.19564 .28147 L
.20377 .27334 L
.20535 .27176 L
.21348 .26363 L
.21507 .26204 L
.22319 .25392 L
.22478 .25233 L
.23291 .2442 L
.23449 .24262 L
.24262 .23449 L
.2442 .23291 L
.25233 .22478 L
.25392 .22319 L
.26204 .21507 L
.26363 .21348 L
.27176 .20535 L
.27334 .20377 L
.28147 .19564 L
.28305 .19406 L
.29118 .18593 L
.29277 .18434 L
.30089 .17622 L
.30248 .17463 L
.31061 .1665 L
.31219 .16492 L
.32032 .15679 L
.3219 .15521 L
.33003 .14708 L
.33158 .14549 L
.33974 .13737 L
.34169 .13578 L
.34946 .13037 L
.35498 .12607 L
.35917 .12206 L
.36542 .11636 L
.36888 .11269 L
.37485 .10664 L
.37859 .1024 L
.38359 .09693 L
.38831 .09129 L
.3918 .08722 L
.39802 .07944 L
.39959 .07751 L
.40711 .06779 L
.40773 .06692 L
.41442 .05808 L
.41744 .05378 L
.4214 .04837 L
.42716 .04003 L
.42812 .03866 L
.43481 .02894 L
.43687 .0257 L
.44125 .01923 L
.01923 .01923 L
F
0 g
.01923 .45788 m
.02078 .45629 L
.02894 .44817 L
.03053 .44658 L
.03866 .43845 L
.04024 .43687 L
.04837 .42874 L
.04995 .42716 L
.05808 .41903 L
.05967 .41744 L
.06779 .40932 L
.06938 .40773 L
.07751 .3996 L
.07909 .39802 L
.08722 .38989 L
.0888 .38831 L
.09693 .38018 L
.09852 .37859 L
.10664 .37047 L
.10823 .36888 L
.11636 .36075 L
.11794 .35917 L
.12607 .35104 L
.12765 .34946 L
.13578 .34133 L
.13737 .33974 L
.14549 .33162 L
.14708 .33003 L
.15521 .3219 L
.15679 .32032 L
.16492 .31219 L
.1665 .31061 L
.17463 .30248 L
.17622 .30089 L
.18434 .29277 L
.18593 .29118 L
.19406 .28305 L
.19564 .28147 L
.20377 .27334 L
.20535 .27176 L
.21348 .26363 L
.21507 .26204 L
.22319 .25392 L
.22478 .25233 L
.23291 .2442 L
.23449 .24262 L
.24262 .23449 L
.2442 .23291 L
.25233 .22478 L
.25392 .22319 L
Mistroke
.26204 .21507 L
.26363 .21348 L
.27176 .20535 L
.27334 .20377 L
.28147 .19564 L
.28305 .19406 L
.29118 .18593 L
.29277 .18434 L
.30089 .17622 L
.30248 .17463 L
.31061 .1665 L
.31219 .16492 L
.32032 .15679 L
.3219 .15521 L
.33003 .14708 L
.33158 .14549 L
.33974 .13737 L
.34169 .13578 L
.34946 .13037 L
.35498 .12607 L
.35917 .12206 L
.36542 .11636 L
.36888 .11269 L
.37485 .10664 L
.37859 .1024 L
.38359 .09693 L
.38831 .09129 L
.3918 .08722 L
.39802 .07944 L
.39959 .07751 L
.40711 .06779 L
.40773 .06692 L
.41442 .05808 L
.41744 .05378 L
.4214 .04837 L
.42716 .04003 L
.42812 .03866 L
.43481 .02894 L
.43687 .0257 L
.44125 .01923 L
Mfstroke
.4 g
.01923 .37931 m
.02016 .37859 L
.02894 .3696 L
.02966 .36888 L
.03866 .35989 L
.03937 .35917 L
.04837 .35017 L
.04908 .34946 L
.05808 .34046 L
.0588 .33974 L
.06779 .33075 L
.06851 .33003 L
.07751 .32104 L
.07822 .32032 L
.08722 .31132 L
.08793 .31061 L
.09693 .30161 L
.09765 .30089 L
.10664 .2919 L
.10736 .29118 L
.11636 .28219 L
.11707 .28147 L
.12607 .27247 L
.12678 .27176 L
.13578 .26276 L
.1365 .26204 L
.14549 .25305 L
.14621 .25233 L
.15521 .24334 L
.15592 .24262 L
.16492 .23362 L
.16563 .23291 L
.17463 .22391 L
.17535 .22319 L
.18434 .2142 L
.18506 .21348 L
.19406 .20448 L
.19477 .20377 L
.20377 .19477 L
.20448 .19406 L
.21348 .18506 L
.2142 .18434 L
.22319 .17535 L
.22391 .17463 L
.23291 .16563 L
.23362 .16492 L
.24262 .15592 L
.24334 .15521 L
.25233 .14621 L
.25305 .14549 L
.26204 .1365 L
.26276 .13578 L
.27176 .12678 L
.27247 .12607 L
.28147 .11707 L
.28219 .11636 L
.29118 .10736 L
.2919 .10664 L
.30089 .09765 L
.30161 .09693 L
.31061 .08793 L
.31132 .08722 L
.32032 .07822 L
.32104 .07751 L
.33003 .06851 L
.33083 .06779 L
.33974 .0588 L
.34033 .05808 L
.34752 .04837 L
.34946 .04566 L
.35462 .03866 L
.35917 .03244 L
.36172 .02894 L
.36874 .01923 L
.01923 .01923 L
F
0 g
.01923 .37931 m
.02016 .37859 L
.02894 .3696 L
.02966 .36888 L
.03866 .35989 L
.03937 .35917 L
.04837 .35017 L
.04908 .34946 L
.05808 .34046 L
.0588 .33974 L
.06779 .33075 L
.06851 .33003 L
.07751 .32104 L
.07822 .32032 L
.08722 .31132 L
.08793 .31061 L
.09693 .30161 L
.09765 .30089 L
.10664 .2919 L
.10736 .29118 L
.11636 .28219 L
.11707 .28147 L
.12607 .27247 L
.12678 .27176 L
.13578 .26276 L
.1365 .26204 L
.14549 .25305 L
.14621 .25233 L
.15521 .24334 L
.15592 .24262 L
.16492 .23362 L
.16563 .23291 L
.17463 .22391 L
.17535 .22319 L
.18434 .2142 L
.18506 .21348 L
.19406 .20448 L
.19477 .20377 L
.20377 .19477 L
.20448 .19406 L
.21348 .18506 L
.2142 .18434 L
.22319 .17535 L
.22391 .17463 L
.23291 .16563 L
.23362 .16492 L
.24262 .15592 L
.24334 .15521 L
.25233 .14621 L
.25305 .14549 L
Mistroke
.26204 .1365 L
.26276 .13578 L
.27176 .12678 L
.27247 .12607 L
.28147 .11707 L
.28219 .11636 L
.29118 .10736 L
.2919 .10664 L
.30089 .09765 L
.30161 .09693 L
.31061 .08793 L
.31132 .08722 L
.32032 .07822 L
.32104 .07751 L
.33003 .06851 L
.33083 .06779 L
.33974 .0588 L
.34033 .05808 L
.34752 .04837 L
.34946 .04566 L
.35462 .03866 L
.35917 .03244 L
.36172 .02894 L
.36874 .01923 L
Mfstroke
.5 g
.01923 .33561 m
.02482 .33003 L
.02894 .3259 L
.03452 .32032 L
.03866 .31618 L
.04423 .31061 L
.04837 .30647 L
.05395 .30089 L
.05808 .29676 L
.06366 .29118 L
.06779 .28705 L
.07337 .28147 L
.07751 .27733 L
.08308 .27176 L
.08722 .26762 L
.0928 .26204 L
.09693 .25791 L
.10251 .25233 L
.10664 .2482 L
.11222 .24262 L
.11636 .23848 L
.12193 .23291 L
.12607 .22877 L
.13165 .22319 L
.13578 .21906 L
.14136 .21348 L
.14549 .20935 L
.15107 .20377 L
.15521 .19963 L
.16078 .19406 L
.16492 .18992 L
.1705 .18434 L
.17463 .18021 L
.18021 .17463 L
.18434 .1705 L
.18992 .16492 L
.19406 .16078 L
.19963 .15521 L
.20377 .15107 L
.20935 .14549 L
.21348 .14136 L
.21906 .13578 L
.22319 .13165 L
.22877 .12607 L
.23291 .12193 L
.23848 .11636 L
.24262 .11222 L
.2482 .10664 L
.25233 .10251 L
.25791 .09693 L
.26204 .0928 L
.26762 .08722 L
.27176 .08308 L
.27733 .07751 L
.28147 .07337 L
.28705 .06779 L
.29118 .06366 L
.29676 .05808 L
.30089 .05395 L
.30647 .04837 L
.31061 .04423 L
.31618 .03866 L
.32032 .03452 L
.3259 .02894 L
.33003 .02482 L
.3357 .01923 L
.01923 .01923 L
F
0 g
.01923 .33561 m
.02482 .33003 L
.02894 .3259 L
.03452 .32032 L
.03866 .31618 L
.04423 .31061 L
.04837 .30647 L
.05395 .30089 L
.05808 .29676 L
.06366 .29118 L
.06779 .28705 L
.07337 .28147 L
.07751 .27733 L
.08308 .27176 L
.08722 .26762 L
.0928 .26204 L
.09693 .25791 L
.10251 .25233 L
.10664 .2482 L
.11222 .24262 L
.11636 .23848 L
.12193 .23291 L
.12607 .22877 L
.13165 .22319 L
.13578 .21906 L
.14136 .21348 L
.14549 .20935 L
.15107 .20377 L
.15521 .19963 L
.16078 .19406 L
.16492 .18992 L
.1705 .18434 L
.17463 .18021 L
.18021 .17463 L
.18434 .1705 L
.18992 .16492 L
.19406 .16078 L
.19963 .15521 L
.20377 .15107 L
.20935 .14549 L
.21348 .14136 L
.21906 .13578 L
.22319 .13165 L
.22877 .12607 L
.23291 .12193 L
.23848 .11636 L
.24262 .11222 L
.2482 .10664 L
.25233 .10251 L
.25791 .09693 L
Mistroke
.26204 .0928 L
.26762 .08722 L
.27176 .08308 L
.27733 .07751 L
.28147 .07337 L
.28705 .06779 L
.29118 .06366 L
.29676 .05808 L
.30089 .05395 L
.30647 .04837 L
.31061 .04423 L
.31618 .03866 L
.32032 .03452 L
.3259 .02894 L
.33003 .02482 L
.3357 .01923 L
Mfstroke
.6 g
.01923 .3002 m
.02825 .29118 L
.02894 .29048 L
.03796 .28147 L
.03866 .28077 L
.04767 .27176 L
.04837 .27106 L
.05738 .26204 L
.05808 .26135 L
.0671 .25233 L
.06779 .25163 L
.07681 .24262 L
.07751 .24192 L
.08652 .23291 L
.08722 .23221 L
.09623 .22319 L
.09693 .2225 L
.10595 .21348 L
.10664 .21278 L
.11566 .20377 L
.11636 .20307 L
.12537 .19406 L
.12607 .19336 L
.13508 .18434 L
.13578 .18365 L
.1448 .17463 L
.14549 .17393 L
.15451 .16492 L
.15521 .16422 L
.16422 .15521 L
.16492 .15451 L
.17393 .14549 L
.17463 .1448 L
.18365 .13578 L
.18434 .13508 L
.19336 .12607 L
.19406 .12537 L
.20307 .11636 L
.20377 .11566 L
.21278 .10664 L
.21348 .10595 L
.2225 .09693 L
.22319 .09623 L
.23221 .08722 L
.23291 .08652 L
.24192 .07751 L
.24262 .07681 L
.25163 .06779 L
.25233 .0671 L
.26135 .05808 L
.26204 .05738 L
.27106 .04837 L
.27176 .04767 L
.28077 .03866 L
.28147 .03796 L
.29048 .02894 L
.29118 .02825 L
.3002 .01923 L
.01923 .01923 L
F
0 g
.01923 .3002 m
.02825 .29118 L
.02894 .29048 L
.03796 .28147 L
.03866 .28077 L
.04767 .27176 L
.04837 .27106 L
.05738 .26204 L
.05808 .26135 L
.0671 .25233 L
.06779 .25163 L
.07681 .24262 L
.07751 .24192 L
.08652 .23291 L
.08722 .23221 L
.09623 .22319 L
.09693 .2225 L
.10595 .21348 L
.10664 .21278 L
.11566 .20377 L
.11636 .20307 L
.12537 .19406 L
.12607 .19336 L
.13508 .18434 L
.13578 .18365 L
.1448 .17463 L
.14549 .17393 L
.15451 .16492 L
.15521 .16422 L
.16422 .15521 L
.16492 .15451 L
.17393 .14549 L
.17463 .1448 L
.18365 .13578 L
.18434 .13508 L
.19336 .12607 L
.19406 .12537 L
.20307 .11636 L
.20377 .11566 L
.21278 .10664 L
.21348 .10595 L
.2225 .09693 L
.22319 .09623 L
.23221 .08722 L
.23291 .08652 L
.24192 .07751 L
.24262 .07681 L
.25163 .06779 L
.25233 .0671 L
.26135 .05808 L
Mistroke
.26204 .05738 L
.27106 .04837 L
.27176 .04767 L
.28077 .03866 L
.28147 .03796 L
.29048 .02894 L
.29118 .02825 L
.3002 .01923 L
Mfstroke
.7 g
.01923 .25652 m
.02334 .25233 L
.02894 .24681 L
.03313 .24262 L
.03866 .2371 L
.04285 .23291 L
.04837 .22738 L
.05256 .22319 L
.05808 .21767 L
.06227 .21348 L
.06779 .20796 L
.07198 .20377 L
.07751 .19825 L
.0817 .19406 L
.08722 .18853 L
.09141 .18434 L
.09693 .17882 L
.10112 .17463 L
.10664 .16911 L
.11083 .16492 L
.11636 .1594 L
.12055 .15521 L
.12607 .14968 L
.13026 .14549 L
.13578 .13997 L
.13997 .13578 L
.14549 .13026 L
.14968 .12607 L
.15521 .12055 L
.1594 .11636 L
.16492 .11083 L
.16911 .10664 L
.17463 .10112 L
.17882 .09693 L
.18434 .09141 L
.18853 .08722 L
.19406 .0817 L
.19825 .07751 L
.20377 .07198 L
.20796 .06779 L
.21348 .06227 L
.21767 .05808 L
.22319 .05256 L
.22738 .04837 L
.23291 .04285 L
.2371 .03866 L
.24262 .03313 L
.24681 .02894 L
.25233 .02334 L
.25652 .01923 L
.01923 .01923 L
F
0 g
.01923 .25652 m
.02334 .25233 L
.02894 .24681 L
.03313 .24262 L
.03866 .2371 L
.04285 .23291 L
.04837 .22738 L
.05256 .22319 L
.05808 .21767 L
.06227 .21348 L
.06779 .20796 L
.07198 .20377 L
.07751 .19825 L
.0817 .19406 L
.08722 .18853 L
.09141 .18434 L
.09693 .17882 L
.10112 .17463 L
.10664 .16911 L
.11083 .16492 L
.11636 .1594 L
.12055 .15521 L
.12607 .14968 L
.13026 .14549 L
.13578 .13997 L
.13997 .13578 L
.14549 .13026 L
.14968 .12607 L
.15521 .12055 L
.1594 .11636 L
.16492 .11083 L
.16911 .10664 L
.17463 .10112 L
.17882 .09693 L
.18434 .09141 L
.18853 .08722 L
.19406 .0817 L
.19825 .07751 L
.20377 .07198 L
.20796 .06779 L
.21348 .06227 L
.21767 .05808 L
.22319 .05256 L
.22738 .04837 L
.23291 .04285 L
.2371 .03866 L
.24262 .03313 L
.24681 .02894 L
.25233 .02334 L
.25652 .01923 L
Mistroke
Mfstroke
.6 g
.01923 .1779 m
.02287 .17463 L
.02894 .16818 L
.03221 .16492 L
.03866 .15847 L
.04192 .15521 L
.04837 .14876 L
.05163 .14549 L
.05808 .13905 L
.06135 .13578 L
.06779 .12933 L
.07106 .12607 L
.07751 .11962 L
.08077 .11636 L
.08722 .10991 L
.09048 .10664 L
.09693 .1002 L
.1002 .09693 L
.10664 .09048 L
.10991 .08722 L
.11636 .08077 L
.11962 .07751 L
.12607 .07106 L
.12933 .06779 L
.13578 .06135 L
.13905 .05808 L
.14549 .05163 L
.14876 .04837 L
.15521 .04192 L
.15847 .03866 L
.16492 .03221 L
.16818 .02894 L
.17463 .02287 L
.1779 .01923 L
.01923 .01923 L
F
0 g
.01923 .1779 m
.02287 .17463 L
.02894 .16818 L
.03221 .16492 L
.03866 .15847 L
.04192 .15521 L
.04837 .14876 L
.05163 .14549 L
.05808 .13905 L
.06135 .13578 L
.06779 .12933 L
.07106 .12607 L
.07751 .11962 L
.08077 .11636 L
.08722 .10991 L
.09048 .10664 L
.09693 .1002 L
.1002 .09693 L
.10664 .09048 L
.10991 .08722 L
.11636 .08077 L
.11962 .07751 L
.12607 .07106 L
.12933 .06779 L
.13578 .06135 L
.13905 .05808 L
.14549 .05163 L
.14876 .04837 L
.15521 .04192 L
.15847 .03866 L
.16492 .03221 L
.16818 .02894 L
.17463 .02287 L
.1779 .01923 L
s
.5 g
.01923 .13423 m
.02739 .12607 L
.02894 .12451 L
.0371 .11636 L
.03866 .1148 L
.04681 .10664 L
.04837 .10509 L
.05653 .09693 L
.05808 .09538 L
.06624 .08722 L
.06779 .08566 L
.07595 .07751 L
.07751 .07595 L
.08566 .06779 L
.08722 .06624 L
.09538 .05808 L
.09693 .05653 L
.10509 .04837 L
.10664 .04681 L
.1148 .03866 L
.11636 .0371 L
.12451 .02894 L
.12607 .02739 L
.13423 .01923 L
.01923 .01923 L
F
0 g
.01923 .13423 m
.02739 .12607 L
.02894 .12451 L
.0371 .11636 L
.03866 .1148 L
.04681 .10664 L
.04837 .10509 L
.05653 .09693 L
.05808 .09538 L
.06624 .08722 L
.06779 .08566 L
.07595 .07751 L
.07751 .07595 L
.08566 .06779 L
.08722 .06624 L
.09538 .05808 L
.09693 .05653 L
.10509 .04837 L
.10664 .04681 L
.1148 .03866 L
.11636 .0371 L
.12451 .02894 L
.12607 .02739 L
.13423 .01923 L
s
.4 g
.01923 .09881 m
.02111 .09693 L
.02894 .0891 L
.03083 .08722 L
.03866 .07939 L
.04054 .07751 L
.04837 .06968 L
.05025 .06779 L
.05808 .05996 L
.05996 .05808 L
.06779 .05025 L
.06968 .04837 L
.07751 .04054 L
.07939 .03866 L
.08722 .03083 L
.0891 .02894 L
.09693 .02111 L
.09881 .01923 L
.01923 .01923 L
F
0 g
.01923 .09881 m
.02111 .09693 L
.02894 .0891 L
.03083 .08722 L
.03866 .07939 L
.04054 .07751 L
.04837 .06968 L
.05025 .06779 L
.05808 .05996 L
.05996 .05808 L
.06779 .05025 L
.06968 .04837 L
.07751 .04054 L
.07939 .03866 L
.08722 .03083 L
.0891 .02894 L
.09693 .02111 L
.09881 .01923 L
s
.3 g
.01923 .05514 m
.02593 .04837 L
.02894 .04543 L
.03572 .03866 L
.03866 .03572 L
.04543 .02894 L
.04837 .02593 L
.05514 .01923 L
.01923 .01923 L
F
0 g
.01923 .05514 m
.02593 .04837 L
.02894 .04543 L
.03572 .03866 L
.03866 .03572 L
.04543 .02894 L
.04837 .02593 L
.05514 .01923 L
s
.7 g
.02228 .98077 m
.02894 .97379 L
.03161 .97106 L
.03866 .96401 L
.04132 .96134 L
.04837 .9543 L
.05103 .95163 L
.05808 .94458 L
.06075 .94192 L
.06779 .93487 L
.07046 .93221 L
.07751 .92516 L
.08017 .92249 L
.08722 .91545 L
.08988 .91278 L
.09693 .90573 L
.0996 .90307 L
.10664 .89602 L
.10931 .89336 L
.11636 .88631 L
.11902 .88364 L
.12607 .8766 L
.12873 .87393 L
.13578 .86688 L
.13845 .86422 L
.14549 .85717 L
.14816 .85451 L
.15521 .84746 L
.15787 .84479 L
.16492 .83775 L
.16758 .83508 L
.17463 .82803 L
.1773 .82537 L
.18434 .81832 L
.18701 .81566 L
.19406 .80861 L
.19672 .80594 L
.20377 .7989 L
.20643 .79623 L
.21348 .78918 L
.21615 .78652 L
.22319 .77947 L
.22586 .77681 L
.23291 .76976 L
.23557 .76709 L
.24262 .76005 L
.24528 .75738 L
.25233 .75033 L
.255 .74767 L
.26204 .74062 L
.26471 .73796 L
.27176 .73091 L
.27442 .72824 L
.28147 .7212 L
.28413 .71853 L
.29118 .71148 L
.29385 .70882 L
.30089 .70177 L
.30356 .69911 L
.31061 .69206 L
.31327 .68939 L
.32032 .68235 L
.32298 .67968 L
.33003 .67263 L
.33294 .66997 L
.33974 .66292 L
.34185 .66026 L
.34895 .65054 L
.34946 .64983 L
.35608 .64083 L
.35917 .6366 L
.36315 .63112 L
.36888 .62317 L
.37014 .62141 L
.37702 .61169 L
.37859 .60944 L
.38375 .60198 L
.38831 .59534 L
.39038 .59227 L
.39691 .58256 L
.39802 .5809 L
.40329 .57284 L
.40773 .56604 L
.40959 .56313 L
.41579 .55342 L
.41744 .5508 L
.42185 .54371 L
.42716 .53517 L
.42787 .53399 L
.43376 .52428 L
.43687 .51913 L
.43956 .51457 L
.44532 .50486 L
.44658 .50272 L
.45094 .49514 L
.45629 .48591 L
.45656 .48543 L
.46203 .47572 L
.46601 .4687 L
.46748 .46601 L
.47286 .45629 L
.47572 .45112 L
.47815 .44658 L
.48343 .43687 L
.48543 .43317 L
.48859 .42716 L
.49377 .41744 L
.49514 .41485 L
.4988 .40773 L
.50389 .39802 L
.50486 .39616 L
.50882 .38831 L
.51381 .37859 L
.51457 .37712 L
.51865 .36888 L
.52355 .35917 L
.52428 .35771 L
.52829 .34946 L
.53311 .33974 L
.53399 .33796 L
.53777 .33003 L
.54251 .32032 L
.54371 .31787 L
.5471 .31061 L
.55176 .30089 L
.55342 .29743 L
.55628 .29118 L
.56086 .28147 L
.56313 .27666 L
.56532 .27176 L
.56983 .26204 L
.57284 .25556 L
.57425 .25233 L
.57866 .24262 L
.58256 .23413 L
.58308 .23291 L
.58737 .22319 L
.59178 .21348 L
.59227 .21238 L
.59598 .20377 L
.60032 .19406 L
.60198 .19031 L
.60449 .18434 L
.60875 .17463 L
.61169 .16793 L
.61292 .16492 L
.61707 .15521 L
.6213 .14549 L
.62141 .14525 L
.62531 .13578 L
.62948 .12607 L
.63112 .12225 L
.63348 .11636 L
.63757 .10664 L
.64083 .09895 L
.64161 .09693 L
.64557 .08722 L
.64965 .07751 L
.65054 .07535 L
.65351 .06779 L
.65752 .05808 L
.66026 .05146 L
.66142 .04837 L
.66531 .03866 L
.66929 .02894 L
.66997 .02729 L
.67304 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.02228 .98077 m
.02894 .97379 L
.03161 .97106 L
.03866 .96401 L
.04132 .96134 L
.04837 .9543 L
.05103 .95163 L
.05808 .94458 L
.06075 .94192 L
.06779 .93487 L
.07046 .93221 L
.07751 .92516 L
.08017 .92249 L
.08722 .91545 L
.08988 .91278 L
.09693 .90573 L
.0996 .90307 L
.10664 .89602 L
.10931 .89336 L
.11636 .88631 L
.11902 .88364 L
.12607 .8766 L
.12873 .87393 L
.13578 .86688 L
.13845 .86422 L
.14549 .85717 L
.14816 .85451 L
.15521 .84746 L
.15787 .84479 L
.16492 .83775 L
.16758 .83508 L
.17463 .82803 L
.1773 .82537 L
.18434 .81832 L
.18701 .81566 L
.19406 .80861 L
.19672 .80594 L
.20377 .7989 L
.20643 .79623 L
.21348 .78918 L
.21615 .78652 L
.22319 .77947 L
.22586 .77681 L
.23291 .76976 L
.23557 .76709 L
.24262 .76005 L
.24528 .75738 L
.25233 .75033 L
.255 .74767 L
.26204 .74062 L
Mistroke
.26471 .73796 L
.27176 .73091 L
.27442 .72824 L
.28147 .7212 L
.28413 .71853 L
.29118 .71148 L
.29385 .70882 L
.30089 .70177 L
.30356 .69911 L
.31061 .69206 L
.31327 .68939 L
.32032 .68235 L
.32298 .67968 L
.33003 .67263 L
.33294 .66997 L
.33974 .66292 L
.34185 .66026 L
.34895 .65054 L
.34946 .64983 L
.35608 .64083 L
.35917 .6366 L
.36315 .63112 L
.36888 .62317 L
.37014 .62141 L
.37702 .61169 L
.37859 .60944 L
.38375 .60198 L
.38831 .59534 L
.39038 .59227 L
.39691 .58256 L
.39802 .5809 L
.40329 .57284 L
.40773 .56604 L
.40959 .56313 L
.41579 .55342 L
.41744 .5508 L
.42185 .54371 L
.42716 .53517 L
.42787 .53399 L
.43376 .52428 L
.43687 .51913 L
.43956 .51457 L
.44532 .50486 L
.44658 .50272 L
.45094 .49514 L
.45629 .48591 L
.45656 .48543 L
.46203 .47572 L
.46601 .4687 L
.46748 .46601 L
Mistroke
.47286 .45629 L
.47572 .45112 L
.47815 .44658 L
.48343 .43687 L
.48543 .43317 L
.48859 .42716 L
.49377 .41744 L
.49514 .41485 L
.4988 .40773 L
.50389 .39802 L
.50486 .39616 L
.50882 .38831 L
.51381 .37859 L
.51457 .37712 L
.51865 .36888 L
.52355 .35917 L
.52428 .35771 L
.52829 .34946 L
.53311 .33974 L
.53399 .33796 L
.53777 .33003 L
.54251 .32032 L
.54371 .31787 L
.5471 .31061 L
.55176 .30089 L
.55342 .29743 L
.55628 .29118 L
.56086 .28147 L
.56313 .27666 L
.56532 .27176 L
.56983 .26204 L
.57284 .25556 L
.57425 .25233 L
.57866 .24262 L
.58256 .23413 L
.58308 .23291 L
.58737 .22319 L
.59178 .21348 L
.59227 .21238 L
.59598 .20377 L
.60032 .19406 L
.60198 .19031 L
.60449 .18434 L
.60875 .17463 L
.61169 .16793 L
.61292 .16492 L
.61707 .15521 L
.6213 .14549 L
.62141 .14525 L
.62531 .13578 L
Mistroke
.62948 .12607 L
.63112 .12225 L
.63348 .11636 L
.63757 .10664 L
.64083 .09895 L
.64161 .09693 L
.64557 .08722 L
.64965 .07751 L
.65054 .07535 L
.65351 .06779 L
.65752 .05808 L
.66026 .05146 L
.66142 .04837 L
.66531 .03866 L
.66929 .02894 L
.66997 .02729 L
.67304 .01923 L
Mfstroke
.6 g
.10051 .98077 m
.10664 .97444 L
.11023 .97106 L
.11636 .96493 L
.11994 .96134 L
.12607 .95522 L
.12965 .95163 L
.13578 .9455 L
.13936 .94192 L
.14549 .93579 L
.14908 .93221 L
.15521 .92608 L
.15879 .92249 L
.16492 .91637 L
.1685 .91278 L
.17463 .90665 L
.17821 .90307 L
.18434 .89694 L
.18793 .89336 L
.19406 .88723 L
.19764 .88364 L
.20377 .87752 L
.20735 .87393 L
.21348 .8678 L
.21706 .86422 L
.22319 .85809 L
.22678 .85451 L
.23291 .84838 L
.23649 .84479 L
.24262 .83867 L
.2462 .83508 L
.25233 .82895 L
.25591 .82537 L
.26204 .81924 L
.26563 .81566 L
.27176 .80953 L
.27534 .80594 L
.28147 .79982 L
.28505 .79623 L
.29118 .7901 L
.29476 .78652 L
.30089 .78039 L
.30448 .77681 L
.31061 .77068 L
.31419 .76709 L
.32032 .76097 L
.3239 .75738 L
.33003 .75125 L
.33354 .74767 L
.33974 .74154 L
.34433 .73796 L
.34946 .73453 L
.35722 .72824 L
.35917 .72621 L
.36736 .71853 L
.36888 .71683 L
.37666 .70882 L
.37859 .70654 L
.38531 .69911 L
.38831 .69544 L
.39346 .68939 L
.39802 .6836 L
.40119 .67968 L
.40773 .67107 L
.40858 .66997 L
.41584 .66026 L
.41744 .65793 L
.42282 .65054 L
.42716 .64419 L
.42951 .64083 L
.43608 .63112 L
.43687 .62987 L
.44256 .62141 L
.44658 .61504 L
.44876 .61169 L
.45493 .60198 L
.45629 .59968 L
.46096 .59227 L
.46601 .58383 L
.46679 .58256 L
.47268 .57284 L
.47572 .56752 L
.47833 .56313 L
.48397 .55342 L
.48543 .55074 L
.48951 .54371 L
.49489 .53399 L
.49514 .53351 L
.50036 .52428 L
.50486 .51586 L
.50557 .51457 L
.51091 .50486 L
.51457 .49779 L
.516 .49514 L
.5212 .48543 L
.52428 .47931 L
.52619 .47572 L
.53126 .46601 L
.53399 .46044 L
.53614 .45629 L
.54111 .44658 L
.54371 .44117 L
.5459 .43687 L
.55077 .42716 L
.55342 .42153 L
.55546 .41744 L
.56025 .40773 L
.56313 .40151 L
.56484 .39802 L
.56957 .38831 L
.57284 .38112 L
.57406 .37859 L
.57873 .36888 L
.58256 .36038 L
.58313 .35917 L
.58773 .34946 L
.59208 .33974 L
.59227 .33929 L
.59659 .33003 L
.60096 .32032 L
.60198 .31786 L
.60532 .31061 L
.60969 .30089 L
.61169 .29609 L
.61392 .29118 L
.61828 .28147 L
.62141 .27398 L
.6224 .27176 L
.62673 .26204 L
.63082 .25233 L
.63112 .25155 L
.63505 .24262 L
.63921 .23291 L
.64083 .22879 L
.64327 .22319 L
.64745 .21348 L
.65054 .20572 L
.65138 .20377 L
.65554 .19406 L
.65951 .18434 L
.66026 .18233 L
.66352 .17463 L
.66757 .16492 L
.66997 .15863 L
.6714 .15521 L
.67546 .14549 L
.67927 .13578 L
.67968 .13463 L
.68322 .12607 L
.68716 .11636 L
.68939 .11033 L
.6909 .10664 L
.69486 .09693 L
.69859 .08722 L
.69911 .08573 L
.70243 .07751 L
.7063 .06779 L
.70882 .06084 L
.70992 .05808 L
.7138 .04837 L
.71751 .03866 L
.71853 .03566 L
.72119 .02894 L
.725 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.10051 .98077 m
.10664 .97444 L
.11023 .97106 L
.11636 .96493 L
.11994 .96134 L
.12607 .95522 L
.12965 .95163 L
.13578 .9455 L
.13936 .94192 L
.14549 .93579 L
.14908 .93221 L
.15521 .92608 L
.15879 .92249 L
.16492 .91637 L
.1685 .91278 L
.17463 .90665 L
.17821 .90307 L
.18434 .89694 L
.18793 .89336 L
.19406 .88723 L
.19764 .88364 L
.20377 .87752 L
.20735 .87393 L
.21348 .8678 L
.21706 .86422 L
.22319 .85809 L
.22678 .85451 L
.23291 .84838 L
.23649 .84479 L
.24262 .83867 L
.2462 .83508 L
.25233 .82895 L
.25591 .82537 L
.26204 .81924 L
.26563 .81566 L
.27176 .80953 L
.27534 .80594 L
.28147 .79982 L
.28505 .79623 L
.29118 .7901 L
.29476 .78652 L
.30089 .78039 L
.30448 .77681 L
.31061 .77068 L
.31419 .76709 L
.32032 .76097 L
.3239 .75738 L
.33003 .75125 L
.33354 .74767 L
.33974 .74154 L
Mistroke
.34433 .73796 L
.34946 .73453 L
.35722 .72824 L
.35917 .72621 L
.36736 .71853 L
.36888 .71683 L
.37666 .70882 L
.37859 .70654 L
.38531 .69911 L
.38831 .69544 L
.39346 .68939 L
.39802 .6836 L
.40119 .67968 L
.40773 .67107 L
.40858 .66997 L
.41584 .66026 L
.41744 .65793 L
.42282 .65054 L
.42716 .64419 L
.42951 .64083 L
.43608 .63112 L
.43687 .62987 L
.44256 .62141 L
.44658 .61504 L
.44876 .61169 L
.45493 .60198 L
.45629 .59968 L
.46096 .59227 L
.46601 .58383 L
.46679 .58256 L
.47268 .57284 L
.47572 .56752 L
.47833 .56313 L
.48397 .55342 L
.48543 .55074 L
.48951 .54371 L
.49489 .53399 L
.49514 .53351 L
.50036 .52428 L
.50486 .51586 L
.50557 .51457 L
.51091 .50486 L
.51457 .49779 L
.516 .49514 L
.5212 .48543 L
.52428 .47931 L
.52619 .47572 L
.53126 .46601 L
.53399 .46044 L
.53614 .45629 L
Mistroke
.54111 .44658 L
.54371 .44117 L
.5459 .43687 L
.55077 .42716 L
.55342 .42153 L
.55546 .41744 L
.56025 .40773 L
.56313 .40151 L
.56484 .39802 L
.56957 .38831 L
.57284 .38112 L
.57406 .37859 L
.57873 .36888 L
.58256 .36038 L
.58313 .35917 L
.58773 .34946 L
.59208 .33974 L
.59227 .33929 L
.59659 .33003 L
.60096 .32032 L
.60198 .31786 L
.60532 .31061 L
.60969 .30089 L
.61169 .29609 L
.61392 .29118 L
.61828 .28147 L
.62141 .27398 L
.6224 .27176 L
.62673 .26204 L
.63082 .25233 L
.63112 .25155 L
.63505 .24262 L
.63921 .23291 L
.64083 .22879 L
.64327 .22319 L
.64745 .21348 L
.65054 .20572 L
.65138 .20377 L
.65554 .19406 L
.65951 .18434 L
.66026 .18233 L
.66352 .17463 L
.66757 .16492 L
.66997 .15863 L
.6714 .15521 L
.67546 .14549 L
.67927 .13578 L
.67968 .13463 L
.68322 .12607 L
.68716 .11636 L
Mistroke
.68939 .11033 L
.6909 .10664 L
.69486 .09693 L
.69859 .08722 L
.69911 .08573 L
.70243 .07751 L
.7063 .06779 L
.70882 .06084 L
.70992 .05808 L
.7138 .04837 L
.71751 .03866 L
.71853 .03566 L
.72119 .02894 L
.725 .01923 L
Mfstroke
.5 g
.1442 .98077 m
.14549 .97946 L
.15391 .97106 L
.15521 .96976 L
.16362 .96134 L
.16492 .96005 L
.17333 .95163 L
.17463 .95033 L
.18305 .94192 L
.18434 .94062 L
.19276 .93221 L
.19406 .93091 L
.20247 .92249 L
.20377 .9212 L
.21218 .91278 L
.21348 .91148 L
.2219 .90307 L
.22319 .90177 L
.23161 .89336 L
.23291 .89206 L
.24132 .88364 L
.24262 .88235 L
.25103 .87393 L
.25233 .87263 L
.26075 .86422 L
.26204 .86292 L
.27046 .85451 L
.27176 .85321 L
.28017 .84479 L
.28147 .8435 L
.28988 .83508 L
.29118 .83378 L
.2996 .82537 L
.30089 .82407 L
.30931 .81566 L
.31061 .81436 L
.31902 .80594 L
.32032 .80465 L
.32873 .79623 L
.33003 .79493 L
.33845 .78652 L
.33974 .78522 L
.34839 .77681 L
.34946 .77578 L
.35776 .76709 L
.35917 .76555 L
.3665 .75738 L
.36888 .75461 L
.37477 .74767 L
.37859 .743 L
.38267 .73796 L
.38831 .73076 L
.39025 .72824 L
.39757 .71853 L
.39802 .71793 L
.40468 .70882 L
.40773 .70453 L
.41157 .69911 L
.41744 .6906 L
.41827 .68939 L
.42483 .67968 L
.42716 .67615 L
.43123 .66997 L
.43687 .66121 L
.43748 .66026 L
.44363 .65054 L
.44658 .64578 L
.44965 .64083 L
.45556 .63112 L
.45629 .62989 L
.46138 .62141 L
.46601 .61355 L
.46709 .61169 L
.47274 .60198 L
.47572 .59677 L
.47829 .59227 L
.48377 .58256 L
.48543 .57956 L
.48917 .57284 L
.4945 .56313 L
.49514 .56193 L
.49978 .55342 L
.50486 .5439 L
.50496 .54371 L
.51013 .53399 L
.51457 .52548 L
.5152 .52428 L
.52025 .51457 L
.52428 .50667 L
.52521 .50486 L
.53016 .49514 L
.53399 .48747 L
.53502 .48543 L
.53987 .47572 L
.54371 .46791 L
.54464 .46601 L
.54941 .45629 L
.55342 .44798 L
.5541 .44658 L
.55878 .43687 L
.56313 .42769 L
.56339 .42716 L
.56799 .41744 L
.57253 .40773 L
.57284 .40705 L
.57706 .39802 L
.58154 .38831 L
.58256 .38606 L
.58599 .37859 L
.59041 .36888 L
.59227 .36474 L
.59479 .35917 L
.59916 .34946 L
.60198 .34308 L
.60347 .33974 L
.60779 .33003 L
.61169 .32109 L
.61203 .32032 L
.6163 .31061 L
.6205 .30089 L
.62141 .29877 L
.6247 .29118 L
.62887 .28147 L
.63112 .27614 L
.63299 .27176 L
.63713 .26204 L
.64083 .25319 L
.64119 .25233 L
.64529 .24262 L
.64933 .23291 L
.65054 .22993 L
.65335 .22319 L
.65737 .21348 L
.66026 .20636 L
.66132 .20377 L
.66531 .19406 L
.66923 .18434 L
.66997 .18249 L
.67316 .17463 L
.67708 .16492 L
.67968 .15832 L
.68093 .15521 L
.68482 .14549 L
.68865 .13578 L
.68939 .13386 L
.69248 .12607 L
.69631 .11636 L
.69911 .1091 L
.70007 .10664 L
.70387 .09693 L
.70762 .08722 L
.70882 .08406 L
.71136 .07751 L
.71511 .06779 L
.71853 .05873 L
.71878 .05808 L
.7225 .04837 L
.72619 .03866 L
.72824 .03312 L
.72983 .02894 L
.7335 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.1442 .98077 m
.14549 .97946 L
.15391 .97106 L
.15521 .96976 L
.16362 .96134 L
.16492 .96005 L
.17333 .95163 L
.17463 .95033 L
.18305 .94192 L
.18434 .94062 L
.19276 .93221 L
.19406 .93091 L
.20247 .92249 L
.20377 .9212 L
.21218 .91278 L
.21348 .91148 L
.2219 .90307 L
.22319 .90177 L
.23161 .89336 L
.23291 .89206 L
.24132 .88364 L
.24262 .88235 L
.25103 .87393 L
.25233 .87263 L
.26075 .86422 L
.26204 .86292 L
.27046 .85451 L
.27176 .85321 L
.28017 .84479 L
.28147 .8435 L
.28988 .83508 L
.29118 .83378 L
.2996 .82537 L
.30089 .82407 L
.30931 .81566 L
.31061 .81436 L
.31902 .80594 L
.32032 .80465 L
.32873 .79623 L
.33003 .79493 L
.33845 .78652 L
.33974 .78522 L
.34839 .77681 L
.34946 .77578 L
.35776 .76709 L
.35917 .76555 L
.3665 .75738 L
.36888 .75461 L
.37477 .74767 L
.37859 .743 L
Mistroke
.38267 .73796 L
.38831 .73076 L
.39025 .72824 L
.39757 .71853 L
.39802 .71793 L
.40468 .70882 L
.40773 .70453 L
.41157 .69911 L
.41744 .6906 L
.41827 .68939 L
.42483 .67968 L
.42716 .67615 L
.43123 .66997 L
.43687 .66121 L
.43748 .66026 L
.44363 .65054 L
.44658 .64578 L
.44965 .64083 L
.45556 .63112 L
.45629 .62989 L
.46138 .62141 L
.46601 .61355 L
.46709 .61169 L
.47274 .60198 L
.47572 .59677 L
.47829 .59227 L
.48377 .58256 L
.48543 .57956 L
.48917 .57284 L
.4945 .56313 L
.49514 .56193 L
.49978 .55342 L
.50486 .5439 L
.50496 .54371 L
.51013 .53399 L
.51457 .52548 L
.5152 .52428 L
.52025 .51457 L
.52428 .50667 L
.52521 .50486 L
.53016 .49514 L
.53399 .48747 L
.53502 .48543 L
.53987 .47572 L
.54371 .46791 L
.54464 .46601 L
.54941 .45629 L
.55342 .44798 L
.5541 .44658 L
.55878 .43687 L
Mistroke
.56313 .42769 L
.56339 .42716 L
.56799 .41744 L
.57253 .40773 L
.57284 .40705 L
.57706 .39802 L
.58154 .38831 L
.58256 .38606 L
.58599 .37859 L
.59041 .36888 L
.59227 .36474 L
.59479 .35917 L
.59916 .34946 L
.60198 .34308 L
.60347 .33974 L
.60779 .33003 L
.61169 .32109 L
.61203 .32032 L
.6163 .31061 L
.6205 .30089 L
.62141 .29877 L
.6247 .29118 L
.62887 .28147 L
.63112 .27614 L
.63299 .27176 L
.63713 .26204 L
.64083 .25319 L
.64119 .25233 L
.64529 .24262 L
.64933 .23291 L
.65054 .22993 L
.65335 .22319 L
.65737 .21348 L
.66026 .20636 L
.66132 .20377 L
.66531 .19406 L
.66923 .18434 L
.66997 .18249 L
.67316 .17463 L
.67708 .16492 L
.67968 .15832 L
.68093 .15521 L
.68482 .14549 L
.68865 .13578 L
.68939 .13386 L
.69248 .12607 L
.69631 .11636 L
.69911 .1091 L
.70007 .10664 L
.70387 .09693 L
Mistroke
.70762 .08722 L
.70882 .08406 L
.71136 .07751 L
.71511 .06779 L
.71853 .05873 L
.71878 .05808 L
.7225 .04837 L
.72619 .03866 L
.72824 .03312 L
.72983 .02894 L
.7335 .01923 L
Mfstroke
.4 g
.17961 .98077 m
.18434 .97604 L
.18932 .97106 L
.19406 .96632 L
.19903 .96134 L
.20377 .95661 L
.20874 .95163 L
.21348 .94689 L
.21846 .94192 L
.22319 .93718 L
.22817 .93221 L
.23291 .92747 L
.23788 .92249 L
.24262 .91776 L
.24759 .91278 L
.25233 .90804 L
.25731 .90307 L
.26204 .89833 L
.26702 .89336 L
.27176 .88862 L
.27673 .88364 L
.28147 .87891 L
.28644 .87393 L
.29118 .86919 L
.29616 .86422 L
.30089 .85948 L
.30587 .85451 L
.31061 .84977 L
.31558 .84479 L
.32032 .84006 L
.32529 .83508 L
.33003 .83034 L
.33509 .82537 L
.33974 .82063 L
.34432 .81566 L
.34946 .80993 L
.35295 .80594 L
.35917 .79864 L
.36118 .79623 L
.36888 .78678 L
.36909 .78652 L
.37672 .77681 L
.37859 .77437 L
.3841 .76709 L
.38831 .76141 L
.39125 .75738 L
.39802 .74795 L
.39821 .74767 L
.405 .73796 L
.40773 .73397 L
.41162 .72824 L
.41744 .71951 L
.41809 .71853 L
.42443 .70882 L
.42716 .70458 L
.43064 .69911 L
.43674 .68939 L
.43687 .68919 L
.44273 .67968 L
.44658 .67335 L
.44862 .66997 L
.45442 .66026 L
.45629 .65708 L
.46012 .65054 L
.46574 .64083 L
.46601 .64038 L
.47128 .63112 L
.47572 .62326 L
.47675 .62141 L
.48215 .61169 L
.48543 .60573 L
.48748 .60198 L
.49275 .59227 L
.49514 .58781 L
.49795 .58256 L
.5031 .57284 L
.50486 .5695 L
.50818 .56313 L
.51322 .55342 L
.51457 .55081 L
.5182 .54371 L
.52314 .53399 L
.52428 .53174 L
.52802 .52428 L
.53287 .51457 L
.53399 .5123 L
.53766 .50486 L
.54242 .49514 L
.54371 .49251 L
.54713 .48543 L
.55181 .47572 L
.55342 .47236 L
.55643 .46601 L
.56104 .45629 L
.56313 .45186 L
.56559 .44658 L
.57013 .43687 L
.57284 .43102 L
.57461 .42716 L
.57908 .41744 L
.58256 .40984 L
.58351 .40773 L
.5879 .39802 L
.59227 .38832 L
.59228 .38831 L
.5966 .37859 L
.60092 .36888 L
.60198 .36648 L
.60519 .35917 L
.60945 .34946 L
.61169 .34432 L
.61367 .33974 L
.61787 .33003 L
.62141 .32184 L
.62205 .32032 L
.6262 .31061 L
.63034 .30089 L
.63112 .29904 L
.63442 .29118 L
.63851 .28147 L
.64083 .27594 L
.64256 .27176 L
.6466 .26204 L
.65054 .25253 L
.65062 .25233 L
.6546 .24262 L
.65859 .23291 L
.66026 .22881 L
.66252 .22319 L
.66646 .21348 L
.66997 .2048 L
.67038 .20377 L
.67426 .19406 L
.67815 .18434 L
.67968 .1805 L
.68199 .17463 L
.68584 .16492 L
.68939 .1559 L
.68966 .15521 L
.69345 .14549 L
.69725 .13578 L
.69911 .13102 L
.701 .12607 L
.70476 .11636 L
.70851 .10664 L
.70882 .10585 L
.71221 .09693 L
.71593 .08722 L
.71853 .0804 L
.71961 .07751 L
.72328 .06779 L
.72696 .05808 L
.72824 .05467 L
.73058 .04837 L
.73422 .03866 L
.73785 .02894 L
.73796 .02867 L
.74143 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.17961 .98077 m
.18434 .97604 L
.18932 .97106 L
.19406 .96632 L
.19903 .96134 L
.20377 .95661 L
.20874 .95163 L
.21348 .94689 L
.21846 .94192 L
.22319 .93718 L
.22817 .93221 L
.23291 .92747 L
.23788 .92249 L
.24262 .91776 L
.24759 .91278 L
.25233 .90804 L
.25731 .90307 L
.26204 .89833 L
.26702 .89336 L
.27176 .88862 L
.27673 .88364 L
.28147 .87891 L
.28644 .87393 L
.29118 .86919 L
.29616 .86422 L
.30089 .85948 L
.30587 .85451 L
.31061 .84977 L
.31558 .84479 L
.32032 .84006 L
.32529 .83508 L
.33003 .83034 L
.33509 .82537 L
.33974 .82063 L
.34432 .81566 L
.34946 .80993 L
.35295 .80594 L
.35917 .79864 L
.36118 .79623 L
.36888 .78678 L
.36909 .78652 L
.37672 .77681 L
.37859 .77437 L
.3841 .76709 L
.38831 .76141 L
.39125 .75738 L
.39802 .74795 L
.39821 .74767 L
.405 .73796 L
.40773 .73397 L
Mistroke
.41162 .72824 L
.41744 .71951 L
.41809 .71853 L
.42443 .70882 L
.42716 .70458 L
.43064 .69911 L
.43674 .68939 L
.43687 .68919 L
.44273 .67968 L
.44658 .67335 L
.44862 .66997 L
.45442 .66026 L
.45629 .65708 L
.46012 .65054 L
.46574 .64083 L
.46601 .64038 L
.47128 .63112 L
.47572 .62326 L
.47675 .62141 L
.48215 .61169 L
.48543 .60573 L
.48748 .60198 L
.49275 .59227 L
.49514 .58781 L
.49795 .58256 L
.5031 .57284 L
.50486 .5695 L
.50818 .56313 L
.51322 .55342 L
.51457 .55081 L
.5182 .54371 L
.52314 .53399 L
.52428 .53174 L
.52802 .52428 L
.53287 .51457 L
.53399 .5123 L
.53766 .50486 L
.54242 .49514 L
.54371 .49251 L
.54713 .48543 L
.55181 .47572 L
.55342 .47236 L
.55643 .46601 L
.56104 .45629 L
.56313 .45186 L
.56559 .44658 L
.57013 .43687 L
.57284 .43102 L
.57461 .42716 L
.57908 .41744 L
Mistroke
.58256 .40984 L
.58351 .40773 L
.5879 .39802 L
.59227 .38832 L
.59228 .38831 L
.5966 .37859 L
.60092 .36888 L
.60198 .36648 L
.60519 .35917 L
.60945 .34946 L
.61169 .34432 L
.61367 .33974 L
.61787 .33003 L
.62141 .32184 L
.62205 .32032 L
.6262 .31061 L
.63034 .30089 L
.63112 .29904 L
.63442 .29118 L
.63851 .28147 L
.64083 .27594 L
.64256 .27176 L
.6466 .26204 L
.65054 .25253 L
.65062 .25233 L
.6546 .24262 L
.65859 .23291 L
.66026 .22881 L
.66252 .22319 L
.66646 .21348 L
.66997 .2048 L
.67038 .20377 L
.67426 .19406 L
.67815 .18434 L
.67968 .1805 L
.68199 .17463 L
.68584 .16492 L
.68939 .1559 L
.68966 .15521 L
.69345 .14549 L
.69725 .13578 L
.69911 .13102 L
.701 .12607 L
.70476 .11636 L
.70851 .10664 L
.70882 .10585 L
.71221 .09693 L
.71593 .08722 L
.71853 .0804 L
.71961 .07751 L
Mistroke
.72328 .06779 L
.72696 .05808 L
.72824 .05467 L
.73058 .04837 L
.73422 .03866 L
.73785 .02894 L
.73796 .02867 L
.74143 .01923 L
Mfstroke
.3 g
.22332 .98077 m
.23291 .97119 L
.23304 .97106 L
.24262 .96147 L
.24275 .96134 L
.25233 .95176 L
.25246 .95163 L
.26204 .94205 L
.26217 .94192 L
.27176 .93234 L
.27189 .93221 L
.28147 .92262 L
.2816 .92249 L
.29118 .91291 L
.29131 .91278 L
.30089 .9032 L
.30102 .90307 L
.31061 .89349 L
.31074 .89336 L
.32032 .88377 L
.32045 .88364 L
.33003 .87406 L
.33018 .87393 L
.33974 .86435 L
.33985 .86422 L
.34709 .85451 L
.34946 .85119 L
.35418 .84479 L
.35917 .83798 L
.36129 .83508 L
.36831 .82537 L
.36888 .82457 L
.3752 .81566 L
.37859 .81081 L
.38197 .80594 L
.38831 .79674 L
.38865 .79623 L
.39518 .78652 L
.39802 .78227 L
.4016 .77681 L
.40773 .76744 L
.40795 .76709 L
.41414 .75738 L
.41744 .75218 L
.42025 .74767 L
.42629 .73796 L
.42716 .73656 L
.43219 .72824 L
.43687 .72052 L
.43804 .71853 L
.44379 .70882 L
.44658 .70409 L
.44945 .69911 L
.45508 .68939 L
.45629 .68729 L
.46057 .67968 L
.46601 .67009 L
.46607 .66997 L
.47142 .66026 L
.47572 .65251 L
.47676 .65054 L
.48202 .64083 L
.48543 .63455 L
.48722 .63112 L
.49239 .62141 L
.49514 .61623 L
.49747 .61169 L
.50254 .60198 L
.50486 .59754 L
.5075 .59227 L
.51249 .58256 L
.51457 .5785 L
.51735 .57284 L
.52225 .56313 L
.52428 .55909 L
.52702 .55342 L
.53184 .54371 L
.53399 .53934 L
.53652 .53399 L
.54126 .52428 L
.54371 .51925 L
.54587 .51457 L
.55052 .50486 L
.55342 .49881 L
.55508 .49514 L
.55964 .48543 L
.56313 .47804 L
.56416 .47572 L
.56862 .46601 L
.57284 .45694 L
.57312 .45629 L
.57748 .44658 L
.58194 .43687 L
.58256 .43552 L
.58621 .42716 L
.59061 .41744 L
.59227 .41376 L
.59484 .40773 L
.59916 .39802 L
.60198 .3917 L
.60339 .38831 L
.60761 .37859 L
.61169 .36932 L
.61187 .36888 L
.61595 .35917 L
.62018 .34946 L
.62141 .34663 L
.62422 .33974 L
.62838 .33003 L
.63112 .32363 L
.63243 .32032 L
.63647 .31061 L
.6406 .30089 L
.64083 .30034 L
.6445 .29118 L
.64857 .28147 L
.65054 .27674 L
.65247 .27176 L
.65645 .26204 L
.66026 .25285 L
.66045 .25233 L
.66426 .24262 L
.66824 .23291 L
.66997 .22866 L
.67203 .22319 L
.67592 .21348 L
.67968 .20419 L
.67983 .20377 L
.68354 .19406 L
.68743 .18434 L
.68939 .17943 L
.69114 .17463 L
.69493 .16492 L
.69879 .15521 L
.69911 .15439 L
.70239 .14549 L
.70619 .13578 L
.70882 .12907 L
.70986 .12607 L
.71353 .11636 L
.71731 .10664 L
.71853 .10347 L
.72084 .09693 L
.72455 .08722 L
.72824 .0776 L
.72828 .07751 L
.73174 .06779 L
.73544 .05808 L
.73796 .05145 L
.73899 .04837 L
.74253 .03866 L
.74621 .02894 L
.74767 .02507 L
.74963 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.22332 .98077 m
.23291 .97119 L
.23304 .97106 L
.24262 .96147 L
.24275 .96134 L
.25233 .95176 L
.25246 .95163 L
.26204 .94205 L
.26217 .94192 L
.27176 .93234 L
.27189 .93221 L
.28147 .92262 L
.2816 .92249 L
.29118 .91291 L
.29131 .91278 L
.30089 .9032 L
.30102 .90307 L
.31061 .89349 L
.31074 .89336 L
.32032 .88377 L
.32045 .88364 L
.33003 .87406 L
.33018 .87393 L
.33974 .86435 L
.33985 .86422 L
.34709 .85451 L
.34946 .85119 L
.35418 .84479 L
.35917 .83798 L
.36129 .83508 L
.36831 .82537 L
.36888 .82457 L
.3752 .81566 L
.37859 .81081 L
.38197 .80594 L
.38831 .79674 L
.38865 .79623 L
.39518 .78652 L
.39802 .78227 L
.4016 .77681 L
.40773 .76744 L
.40795 .76709 L
.41414 .75738 L
.41744 .75218 L
.42025 .74767 L
.42629 .73796 L
.42716 .73656 L
.43219 .72824 L
.43687 .72052 L
.43804 .71853 L
Mistroke
.44379 .70882 L
.44658 .70409 L
.44945 .69911 L
.45508 .68939 L
.45629 .68729 L
.46057 .67968 L
.46601 .67009 L
.46607 .66997 L
.47142 .66026 L
.47572 .65251 L
.47676 .65054 L
.48202 .64083 L
.48543 .63455 L
.48722 .63112 L
.49239 .62141 L
.49514 .61623 L
.49747 .61169 L
.50254 .60198 L
.50486 .59754 L
.5075 .59227 L
.51249 .58256 L
.51457 .5785 L
.51735 .57284 L
.52225 .56313 L
.52428 .55909 L
.52702 .55342 L
.53184 .54371 L
.53399 .53934 L
.53652 .53399 L
.54126 .52428 L
.54371 .51925 L
.54587 .51457 L
.55052 .50486 L
.55342 .49881 L
.55508 .49514 L
.55964 .48543 L
.56313 .47804 L
.56416 .47572 L
.56862 .46601 L
.57284 .45694 L
.57312 .45629 L
.57748 .44658 L
.58194 .43687 L
.58256 .43552 L
.58621 .42716 L
.59061 .41744 L
.59227 .41376 L
.59484 .40773 L
.59916 .39802 L
.60198 .3917 L
Mistroke
.60339 .38831 L
.60761 .37859 L
.61169 .36932 L
.61187 .36888 L
.61595 .35917 L
.62018 .34946 L
.62141 .34663 L
.62422 .33974 L
.62838 .33003 L
.63112 .32363 L
.63243 .32032 L
.63647 .31061 L
.6406 .30089 L
.64083 .30034 L
.6445 .29118 L
.64857 .28147 L
.65054 .27674 L
.65247 .27176 L
.65645 .26204 L
.66026 .25285 L
.66045 .25233 L
.66426 .24262 L
.66824 .23291 L
.66997 .22866 L
.67203 .22319 L
.67592 .21348 L
.67968 .20419 L
.67983 .20377 L
.68354 .19406 L
.68743 .18434 L
.68939 .17943 L
.69114 .17463 L
.69493 .16492 L
.69879 .15521 L
.69911 .15439 L
.70239 .14549 L
.70619 .13578 L
.70882 .12907 L
.70986 .12607 L
.71353 .11636 L
.71731 .10664 L
.71853 .10347 L
.72084 .09693 L
.72455 .08722 L
.72824 .0776 L
.72828 .07751 L
.73174 .06779 L
.73544 .05808 L
.73796 .05145 L
.73899 .04837 L
Mistroke
.74253 .03866 L
.74621 .02894 L
.74767 .02507 L
.74963 .01923 L
Mfstroke
.4 g
.30187 .98077 m
.31061 .97199 L
.31158 .97106 L
.32032 .96232 L
.3213 .96134 L
.33003 .95261 L
.33099 .95163 L
.33974 .9429 L
.34093 .94192 L
.34946 .9359 L
.35425 .93221 L
.35917 .9276 L
.3648 .92249 L
.36888 .91822 L
.37428 .91278 L
.37859 .90793 L
.38305 .90307 L
.38831 .89682 L
.39128 .89336 L
.39802 .88497 L
.3991 .88364 L
.40668 .87393 L
.40773 .87246 L
.41398 .86422 L
.41744 .85932 L
.42096 .85451 L
.42716 .84556 L
.4277 .84479 L
.43441 .83508 L
.43687 .83127 L
.44085 .82537 L
.44658 .81641 L
.44708 .81566 L
.45334 .80594 L
.45629 .80107 L
.45935 .79623 L
.46526 .78652 L
.46601 .78522 L
.47114 .77681 L
.47572 .76889 L
.47679 .76709 L
.48252 .75738 L
.48543 .75212 L
.48802 .74767 L
.49352 .73796 L
.49514 .7349 L
.49891 .72824 L
.5042 .71853 L
.50486 .71724 L
.50951 .70882 L
.51457 .69917 L
.5146 .69911 L
.51984 .68939 L
.52428 .68069 L
.52482 .67968 L
.52994 .66997 L
.53399 .66182 L
.5348 .66026 L
.53982 .65054 L
.54371 .64255 L
.54458 .64083 L
.5495 .63112 L
.55342 .62291 L
.55417 .62141 L
.559 .61169 L
.56313 .60289 L
.56358 .60198 L
.56833 .59227 L
.57282 .58256 L
.57284 .5825 L
.5775 .57284 L
.58197 .56313 L
.58256 .56177 L
.58652 .55342 L
.59098 .54371 L
.59227 .54068 L
.59539 .53399 L
.59984 .52428 L
.60198 .51925 L
.60413 .51457 L
.60856 .50486 L
.61169 .49747 L
.61275 .49514 L
.61714 .48543 L
.62127 .47572 L
.62141 .47536 L
.62559 .46601 L
.62978 .45629 L
.63112 .45293 L
.63392 .44658 L
.63814 .43687 L
.64083 .43018 L
.64214 .42716 L
.64635 .41744 L
.65031 .40773 L
.65054 .4071 L
.65444 .39802 L
.6585 .38831 L
.66026 .38372 L
.66243 .37859 L
.66651 .36888 L
.66997 .36001 L
.67032 .35917 L
.67439 .34946 L
.67831 .33974 L
.67968 .33602 L
.68216 .33003 L
.68614 .32032 L
.68939 .31171 L
.68984 .31061 L
.69382 .30089 L
.69765 .29118 L
.69911 .28712 L
.70139 .28147 L
.70529 .27176 L
.70882 .26222 L
.70889 .26204 L
.71278 .25233 L
.71657 .24262 L
.71853 .23705 L
.72017 .23291 L
.724 .22319 L
.72761 .21348 L
.72824 .21158 L
.7313 .20377 L
.73506 .19406 L
.73796 .18583 L
.73853 .18434 L
.74229 .17463 L
.74595 .16492 L
.74767 .1598 L
.74943 .15521 L
.75315 .14549 L
.75665 .13578 L
.75738 .1335 L
.7602 .12607 L
.76386 .11636 L
.76709 .10691 L
.7672 .10664 L
.77085 .09693 L
.77444 .08722 L
.77681 .08007 L
.77776 .07751 L
.78138 .06779 L
.78489 .05808 L
.78652 .05296 L
.78821 .04837 L
.7918 .03866 L
.7952 .02894 L
.79623 .02556 L
.79855 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.30187 .98077 m
.31061 .97199 L
.31158 .97106 L
.32032 .96232 L
.3213 .96134 L
.33003 .95261 L
.33099 .95163 L
.33974 .9429 L
.34093 .94192 L
.34946 .9359 L
.35425 .93221 L
.35917 .9276 L
.3648 .92249 L
.36888 .91822 L
.37428 .91278 L
.37859 .90793 L
.38305 .90307 L
.38831 .89682 L
.39128 .89336 L
.39802 .88497 L
.3991 .88364 L
.40668 .87393 L
.40773 .87246 L
.41398 .86422 L
.41744 .85932 L
.42096 .85451 L
.42716 .84556 L
.4277 .84479 L
.43441 .83508 L
.43687 .83127 L
.44085 .82537 L
.44658 .81641 L
.44708 .81566 L
.45334 .80594 L
.45629 .80107 L
.45935 .79623 L
.46526 .78652 L
.46601 .78522 L
.47114 .77681 L
.47572 .76889 L
.47679 .76709 L
.48252 .75738 L
.48543 .75212 L
.48802 .74767 L
.49352 .73796 L
.49514 .7349 L
.49891 .72824 L
.5042 .71853 L
.50486 .71724 L
.50951 .70882 L
Mistroke
.51457 .69917 L
.5146 .69911 L
.51984 .68939 L
.52428 .68069 L
.52482 .67968 L
.52994 .66997 L
.53399 .66182 L
.5348 .66026 L
.53982 .65054 L
.54371 .64255 L
.54458 .64083 L
.5495 .63112 L
.55342 .62291 L
.55417 .62141 L
.559 .61169 L
.56313 .60289 L
.56358 .60198 L
.56833 .59227 L
.57282 .58256 L
.57284 .5825 L
.5775 .57284 L
.58197 .56313 L
.58256 .56177 L
.58652 .55342 L
.59098 .54371 L
.59227 .54068 L
.59539 .53399 L
.59984 .52428 L
.60198 .51925 L
.60413 .51457 L
.60856 .50486 L
.61169 .49747 L
.61275 .49514 L
.61714 .48543 L
.62127 .47572 L
.62141 .47536 L
.62559 .46601 L
.62978 .45629 L
.63112 .45293 L
.63392 .44658 L
.63814 .43687 L
.64083 .43018 L
.64214 .42716 L
.64635 .41744 L
.65031 .40773 L
.65054 .4071 L
.65444 .39802 L
.6585 .38831 L
.66026 .38372 L
.66243 .37859 L
Mistroke
.66651 .36888 L
.66997 .36001 L
.67032 .35917 L
.67439 .34946 L
.67831 .33974 L
.67968 .33602 L
.68216 .33003 L
.68614 .32032 L
.68939 .31171 L
.68984 .31061 L
.69382 .30089 L
.69765 .29118 L
.69911 .28712 L
.70139 .28147 L
.70529 .27176 L
.70882 .26222 L
.70889 .26204 L
.71278 .25233 L
.71657 .24262 L
.71853 .23705 L
.72017 .23291 L
.724 .22319 L
.72761 .21348 L
.72824 .21158 L
.7313 .20377 L
.73506 .19406 L
.73796 .18583 L
.73853 .18434 L
.74229 .17463 L
.74595 .16492 L
.74767 .1598 L
.74943 .15521 L
.75315 .14549 L
.75665 .13578 L
.75738 .1335 L
.7602 .12607 L
.76386 .11636 L
.76709 .10691 L
.7672 .10664 L
.77085 .09693 L
.77444 .08722 L
.77681 .08007 L
.77776 .07751 L
.78138 .06779 L
.78489 .05808 L
.78652 .05296 L
.78821 .04837 L
.7918 .03866 L
.7952 .02894 L
.79623 .02556 L
Mistroke
.79855 .01923 L
Mfstroke
.5 g
.34572 .98077 m
.34946 .97715 L
.35537 .97106 L
.35917 .96694 L
.36423 .96134 L
.36888 .95599 L
.37261 .95163 L
.37859 .94438 L
.38059 .94192 L
.38826 .93221 L
.38831 .93214 L
.39566 .92249 L
.39802 .91931 L
.40282 .91278 L
.40773 .90592 L
.40975 .90307 L
.41651 .89336 L
.41744 .89199 L
.42311 .88364 L
.42716 .87754 L
.42954 .87393 L
.43583 .86422 L
.43687 .86259 L
.44201 .85451 L
.44658 .84716 L
.44805 .84479 L
.454 .83508 L
.45629 .83127 L
.45985 .82537 L
.46558 .81566 L
.46601 .81493 L
.47126 .80594 L
.47572 .79815 L
.47682 .79623 L
.48233 .78652 L
.48543 .78094 L
.48774 .77681 L
.4931 .76709 L
.49514 .76332 L
.49838 .75738 L
.5036 .74767 L
.50486 .74529 L
.50876 .73796 L
.51386 .72824 L
.51457 .72686 L
.51891 .71853 L
.52389 .70882 L
.52428 .70805 L
.52885 .69911 L
.53373 .68939 L
.53399 .68886 L
.53859 .67968 L
.54338 .66997 L
.54371 .66929 L
.54815 .66026 L
.55286 .65054 L
.55342 .64936 L
.55754 .64083 L
.56217 .63112 L
.56313 .62907 L
.56678 .62141 L
.57134 .61169 L
.57284 .60844 L
.57586 .60198 L
.58036 .59227 L
.58256 .58745 L
.58481 .58256 L
.58925 .57284 L
.59227 .56612 L
.59362 .56313 L
.59801 .55342 L
.60198 .54446 L
.60232 .54371 L
.60665 .53399 L
.61091 .52428 L
.61169 .52247 L
.61517 .51457 L
.6194 .50486 L
.62141 .50016 L
.62358 .49514 L
.62777 .48543 L
.63112 .47752 L
.63189 .47572 L
.63604 .46601 L
.64012 .45629 L
.64083 .45457 L
.6442 .44658 L
.64826 .43687 L
.65054 .43131 L
.65227 .42716 L
.65631 .41744 L
.66026 .40774 L
.66026 .40773 L
.66425 .39802 L
.6682 .38831 L
.66997 .38388 L
.67211 .37859 L
.67604 .36888 L
.67968 .35971 L
.6799 .35917 L
.68379 .34946 L
.68764 .33974 L
.68939 .33524 L
.69146 .33003 L
.6953 .32032 L
.69906 .31061 L
.69911 .31049 L
.70286 .30089 L
.70664 .29118 L
.70882 .28544 L
.71036 .28147 L
.71412 .27176 L
.71781 .26204 L
.71853 .26012 L
.72151 .25233 L
.72522 .24262 L
.72824 .23451 L
.72885 .23291 L
.73253 .22319 L
.73617 .21348 L
.73796 .20862 L
.73977 .20377 L
.74341 .19406 L
.74699 .18434 L
.74767 .18245 L
.75057 .17463 L
.75416 .16492 L
.75738 .15602 L
.75768 .15521 L
.76125 .14549 L
.76479 .13578 L
.76709 .12931 L
.76827 .12607 L
.77181 .11636 L
.7753 .10664 L
.77681 .10234 L
.77875 .09693 L
.78225 .08722 L
.78569 .07751 L
.78652 .0751 L
.78912 .06779 L
.79259 .05808 L
.79597 .04837 L
.79623 .0476 L
.79939 .03866 L
.80282 .02894 L
.80594 .01984 L
.80616 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.34572 .98077 m
.34946 .97715 L
.35537 .97106 L
.35917 .96694 L
.36423 .96134 L
.36888 .95599 L
.37261 .95163 L
.37859 .94438 L
.38059 .94192 L
.38826 .93221 L
.38831 .93214 L
.39566 .92249 L
.39802 .91931 L
.40282 .91278 L
.40773 .90592 L
.40975 .90307 L
.41651 .89336 L
.41744 .89199 L
.42311 .88364 L
.42716 .87754 L
.42954 .87393 L
.43583 .86422 L
.43687 .86259 L
.44201 .85451 L
.44658 .84716 L
.44805 .84479 L
.454 .83508 L
.45629 .83127 L
.45985 .82537 L
.46558 .81566 L
.46601 .81493 L
.47126 .80594 L
.47572 .79815 L
.47682 .79623 L
.48233 .78652 L
.48543 .78094 L
.48774 .77681 L
.4931 .76709 L
.49514 .76332 L
.49838 .75738 L
.5036 .74767 L
.50486 .74529 L
.50876 .73796 L
.51386 .72824 L
.51457 .72686 L
.51891 .71853 L
.52389 .70882 L
.52428 .70805 L
.52885 .69911 L
.53373 .68939 L
Mistroke
.53399 .68886 L
.53859 .67968 L
.54338 .66997 L
.54371 .66929 L
.54815 .66026 L
.55286 .65054 L
.55342 .64936 L
.55754 .64083 L
.56217 .63112 L
.56313 .62907 L
.56678 .62141 L
.57134 .61169 L
.57284 .60844 L
.57586 .60198 L
.58036 .59227 L
.58256 .58745 L
.58481 .58256 L
.58925 .57284 L
.59227 .56612 L
.59362 .56313 L
.59801 .55342 L
.60198 .54446 L
.60232 .54371 L
.60665 .53399 L
.61091 .52428 L
.61169 .52247 L
.61517 .51457 L
.6194 .50486 L
.62141 .50016 L
.62358 .49514 L
.62777 .48543 L
.63112 .47752 L
.63189 .47572 L
.63604 .46601 L
.64012 .45629 L
.64083 .45457 L
.6442 .44658 L
.64826 .43687 L
.65054 .43131 L
.65227 .42716 L
.65631 .41744 L
.66026 .40774 L
.66026 .40773 L
.66425 .39802 L
.6682 .38831 L
.66997 .38388 L
.67211 .37859 L
.67604 .36888 L
.67968 .35971 L
.6799 .35917 L
Mistroke
.68379 .34946 L
.68764 .33974 L
.68939 .33524 L
.69146 .33003 L
.6953 .32032 L
.69906 .31061 L
.69911 .31049 L
.70286 .30089 L
.70664 .29118 L
.70882 .28544 L
.71036 .28147 L
.71412 .27176 L
.71781 .26204 L
.71853 .26012 L
.72151 .25233 L
.72522 .24262 L
.72824 .23451 L
.72885 .23291 L
.73253 .22319 L
.73617 .21348 L
.73796 .20862 L
.73977 .20377 L
.74341 .19406 L
.74699 .18434 L
.74767 .18245 L
.75057 .17463 L
.75416 .16492 L
.75738 .15602 L
.75768 .15521 L
.76125 .14549 L
.76479 .13578 L
.76709 .12931 L
.76827 .12607 L
.77181 .11636 L
.7753 .10664 L
.77681 .10234 L
.77875 .09693 L
.78225 .08722 L
.78569 .07751 L
.78652 .0751 L
.78912 .06779 L
.79259 .05808 L
.79597 .04837 L
.79623 .0476 L
.79939 .03866 L
.80282 .02894 L
.80594 .01984 L
.80616 .01923 L
Mfstroke
.6 g
.37472 .98077 m
.37859 .97575 L
.38216 .97106 L
.38831 .9628 L
.38937 .96134 L
.39639 .95163 L
.39802 .94933 L
.40321 .94192 L
.40773 .93536 L
.40988 .93221 L
.41639 .92249 L
.41744 .9209 L
.42276 .91278 L
.42716 .90597 L
.42901 .90307 L
.43514 .89336 L
.43687 .89058 L
.44115 .88364 L
.44658 .87474 L
.44707 .87393 L
.45289 .86422 L
.45629 .85846 L
.45861 .85451 L
.46426 .84479 L
.46601 .84176 L
.46982 .83508 L
.47531 .82537 L
.47572 .82464 L
.48072 .81566 L
.48543 .80712 L
.48607 .80594 L
.49135 .79623 L
.49514 .7892 L
.49657 .78652 L
.50174 .77681 L
.50486 .77088 L
.50684 .76709 L
.51189 .75738 L
.51457 .75219 L
.51688 .74767 L
.52184 .73796 L
.52428 .73312 L
.52673 .72824 L
.53159 .71853 L
.53399 .71369 L
.53639 .70882 L
.54116 .69911 L
.54371 .69389 L
.54588 .68939 L
.55057 .67968 L
.55342 .67374 L
.55521 .66997 L
.55982 .66026 L
.56313 .65324 L
.56439 .65054 L
.56893 .64083 L
.57284 .6324 L
.57343 .63112 L
.57789 .62141 L
.58234 .61169 L
.58256 .61122 L
.58673 .60198 L
.59112 .59227 L
.59227 .58971 L
.59545 .58256 L
.59978 .57284 L
.60198 .56787 L
.60405 .56313 L
.60832 .55342 L
.61169 .5457 L
.61255 .54371 L
.61676 .53399 L
.62095 .52428 L
.62141 .52322 L
.62509 .51457 L
.62924 .50486 L
.63112 .50043 L
.63333 .49514 L
.63743 .48543 L
.64083 .47732 L
.64149 .47572 L
.64553 .46601 L
.64956 .45629 L
.65054 .45391 L
.65354 .44658 L
.65753 .43687 L
.66026 .4302 L
.66148 .42716 L
.66542 .41744 L
.66935 .40773 L
.66997 .40619 L
.67322 .39802 L
.67712 .38831 L
.67968 .38188 L
.68097 .37859 L
.68481 .36888 L
.68865 .35917 L
.68939 .35729 L
.69244 .34946 L
.69625 .33974 L
.69911 .3324 L
.70001 .33003 L
.70376 .32032 L
.70752 .31061 L
.70882 .30723 L
.71122 .30089 L
.71495 .29118 L
.71853 .28178 L
.71865 .28147 L
.7223 .27176 L
.72599 .26204 L
.72824 .25606 L
.72962 .25233 L
.73326 .24262 L
.7369 .23291 L
.73796 .23005 L
.74047 .22319 L
.74408 .21348 L
.74767 .20378 L
.74767 .20377 L
.75121 .19406 L
.75478 .18434 L
.75738 .17723 L
.75831 .17463 L
.76183 .16492 L
.76536 .15521 L
.76709 .15042 L
.76884 .14549 L
.77233 .13578 L
.77583 .12607 L
.77681 .12334 L
.77926 .11636 L
.78273 .10664 L
.78619 .09693 L
.78652 .096 L
.78958 .08722 L
.79303 .07751 L
.79623 .0684 L
.79644 .06779 L
.79981 .05808 L
.80322 .04837 L
.80594 .04055 L
.80658 .03866 L
.80993 .02894 L
.81331 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.37472 .98077 m
.37859 .97575 L
.38216 .97106 L
.38831 .9628 L
.38937 .96134 L
.39639 .95163 L
.39802 .94933 L
.40321 .94192 L
.40773 .93536 L
.40988 .93221 L
.41639 .92249 L
.41744 .9209 L
.42276 .91278 L
.42716 .90597 L
.42901 .90307 L
.43514 .89336 L
.43687 .89058 L
.44115 .88364 L
.44658 .87474 L
.44707 .87393 L
.45289 .86422 L
.45629 .85846 L
.45861 .85451 L
.46426 .84479 L
.46601 .84176 L
.46982 .83508 L
.47531 .82537 L
.47572 .82464 L
.48072 .81566 L
.48543 .80712 L
.48607 .80594 L
.49135 .79623 L
.49514 .7892 L
.49657 .78652 L
.50174 .77681 L
.50486 .77088 L
.50684 .76709 L
.51189 .75738 L
.51457 .75219 L
.51688 .74767 L
.52184 .73796 L
.52428 .73312 L
.52673 .72824 L
.53159 .71853 L
.53399 .71369 L
.53639 .70882 L
.54116 .69911 L
.54371 .69389 L
.54588 .68939 L
.55057 .67968 L
Mistroke
.55342 .67374 L
.55521 .66997 L
.55982 .66026 L
.56313 .65324 L
.56439 .65054 L
.56893 .64083 L
.57284 .6324 L
.57343 .63112 L
.57789 .62141 L
.58234 .61169 L
.58256 .61122 L
.58673 .60198 L
.59112 .59227 L
.59227 .58971 L
.59545 .58256 L
.59978 .57284 L
.60198 .56787 L
.60405 .56313 L
.60832 .55342 L
.61169 .5457 L
.61255 .54371 L
.61676 .53399 L
.62095 .52428 L
.62141 .52322 L
.62509 .51457 L
.62924 .50486 L
.63112 .50043 L
.63333 .49514 L
.63743 .48543 L
.64083 .47732 L
.64149 .47572 L
.64553 .46601 L
.64956 .45629 L
.65054 .45391 L
.65354 .44658 L
.65753 .43687 L
.66026 .4302 L
.66148 .42716 L
.66542 .41744 L
.66935 .40773 L
.66997 .40619 L
.67322 .39802 L
.67712 .38831 L
.67968 .38188 L
.68097 .37859 L
.68481 .36888 L
.68865 .35917 L
.68939 .35729 L
.69244 .34946 L
.69625 .33974 L
Mistroke
.69911 .3324 L
.70001 .33003 L
.70376 .32032 L
.70752 .31061 L
.70882 .30723 L
.71122 .30089 L
.71495 .29118 L
.71853 .28178 L
.71865 .28147 L
.7223 .27176 L
.72599 .26204 L
.72824 .25606 L
.72962 .25233 L
.73326 .24262 L
.7369 .23291 L
.73796 .23005 L
.74047 .22319 L
.74408 .21348 L
.74767 .20378 L
.74767 .20377 L
.75121 .19406 L
.75478 .18434 L
.75738 .17723 L
.75831 .17463 L
.76183 .16492 L
.76536 .15521 L
.76709 .15042 L
.76884 .14549 L
.77233 .13578 L
.77583 .12607 L
.77681 .12334 L
.77926 .11636 L
.78273 .10664 L
.78619 .09693 L
.78652 .096 L
.78958 .08722 L
.79303 .07751 L
.79623 .0684 L
.79644 .06779 L
.79981 .05808 L
.80322 .04837 L
.80594 .04055 L
.80658 .03866 L
.80993 .02894 L
.81331 .01923 L
Mfstroke
.7 g
.39991 .98077 m
.40628 .97106 L
.40773 .96881 L
.4125 .96134 L
.41744 .95357 L
.41865 .95163 L
.42469 .94192 L
.42716 .93793 L
.43062 .93221 L
.43652 .92249 L
.43687 .92191 L
.44226 .91278 L
.44658 .90548 L
.44796 .90307 L
.45359 .89336 L
.45629 .88867 L
.45911 .88364 L
.46462 .87393 L
.46601 .87147 L
.46999 .86422 L
.47538 .85451 L
.47572 .8539 L
.48062 .84479 L
.48543 .83594 L
.48588 .83508 L
.49101 .82537 L
.49514 .81762 L
.49614 .81566 L
.50119 .80594 L
.50486 .79893 L
.5062 .79623 L
.51116 .78652 L
.51457 .77988 L
.51607 .77681 L
.52095 .76709 L
.52428 .76048 L
.52576 .75738 L
.53055 .74767 L
.53399 .74073 L
.53529 .73796 L
.53999 .72824 L
.54371 .72063 L
.54467 .71853 L
.54928 .70882 L
.55342 .7002 L
.55391 .69911 L
.55842 .68939 L
.56301 .67968 L
.56313 .67943 L
.56742 .66997 L
.57195 .66026 L
.57284 .65833 L
.5763 .65054 L
.58076 .64083 L
.58256 .6369 L
.58506 .63112 L
.58944 .62141 L
.59227 .61515 L
.59372 .61169 L
.59801 .60198 L
.60198 .59309 L
.60231 .59227 L
.60647 .58256 L
.61076 .57284 L
.61169 .5707 L
.61484 .56313 L
.61906 .55342 L
.62141 .54801 L
.62314 .54371 L
.62727 .53399 L
.63112 .52502 L
.6314 .52428 L
.63538 .51457 L
.63951 .50486 L
.64083 .50172 L
.64343 .49514 L
.64748 .48543 L
.65054 .47812 L
.65146 .47572 L
.65538 .46601 L
.65941 .45629 L
.66026 .45423 L
.66321 .44658 L
.66718 .43687 L
.66997 .43004 L
.67104 .42716 L
.67487 .41744 L
.67881 .40773 L
.67968 .40557 L
.68252 .39802 L
.6864 .38831 L
.68939 .38081 L
.69018 .37859 L
.69391 .36888 L
.69777 .35917 L
.69911 .35577 L
.7014 .34946 L
.70518 .33974 L
.70882 .33046 L
.70896 .33003 L
.71253 .32032 L
.7163 .31061 L
.71853 .30485 L
.7199 .30089 L
.72355 .29118 L
.72729 .28147 L
.72824 .27898 L
.73078 .27176 L
.73445 .26204 L
.73796 .25284 L
.73812 .25233 L
.74157 .24262 L
.74523 .23291 L
.74767 .22643 L
.74873 .22319 L
.75225 .21348 L
.75589 .20377 L
.75738 .19975 L
.75928 .19406 L
.76282 .18434 L
.76643 .17463 L
.76709 .17281 L
.76974 .16492 L
.77329 .15521 L
.77681 .14561 L
.77684 .14549 L
.78011 .13578 L
.78364 .12607 L
.78652 .11815 L
.78707 .11636 L
.79038 .10664 L
.7939 .09693 L
.79623 .09043 L
.79722 .08722 L
.80056 .07751 L
.80405 .06779 L
.80594 .06246 L
.80729 .05808 L
.81064 .04837 L
.8141 .03866 L
.81566 .03424 L
.81728 .02894 L
.82063 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.39991 .98077 m
.40628 .97106 L
.40773 .96881 L
.4125 .96134 L
.41744 .95357 L
.41865 .95163 L
.42469 .94192 L
.42716 .93793 L
.43062 .93221 L
.43652 .92249 L
.43687 .92191 L
.44226 .91278 L
.44658 .90548 L
.44796 .90307 L
.45359 .89336 L
.45629 .88867 L
.45911 .88364 L
.46462 .87393 L
.46601 .87147 L
.46999 .86422 L
.47538 .85451 L
.47572 .8539 L
.48062 .84479 L
.48543 .83594 L
.48588 .83508 L
.49101 .82537 L
.49514 .81762 L
.49614 .81566 L
.50119 .80594 L
.50486 .79893 L
.5062 .79623 L
.51116 .78652 L
.51457 .77988 L
.51607 .77681 L
.52095 .76709 L
.52428 .76048 L
.52576 .75738 L
.53055 .74767 L
.53399 .74073 L
.53529 .73796 L
.53999 .72824 L
.54371 .72063 L
.54467 .71853 L
.54928 .70882 L
.55342 .7002 L
.55391 .69911 L
.55842 .68939 L
.56301 .67968 L
.56313 .67943 L
.56742 .66997 L
Mistroke
.57195 .66026 L
.57284 .65833 L
.5763 .65054 L
.58076 .64083 L
.58256 .6369 L
.58506 .63112 L
.58944 .62141 L
.59227 .61515 L
.59372 .61169 L
.59801 .60198 L
.60198 .59309 L
.60231 .59227 L
.60647 .58256 L
.61076 .57284 L
.61169 .5707 L
.61484 .56313 L
.61906 .55342 L
.62141 .54801 L
.62314 .54371 L
.62727 .53399 L
.63112 .52502 L
.6314 .52428 L
.63538 .51457 L
.63951 .50486 L
.64083 .50172 L
.64343 .49514 L
.64748 .48543 L
.65054 .47812 L
.65146 .47572 L
.65538 .46601 L
.65941 .45629 L
.66026 .45423 L
.66321 .44658 L
.66718 .43687 L
.66997 .43004 L
.67104 .42716 L
.67487 .41744 L
.67881 .40773 L
.67968 .40557 L
.68252 .39802 L
.6864 .38831 L
.68939 .38081 L
.69018 .37859 L
.69391 .36888 L
.69777 .35917 L
.69911 .35577 L
.7014 .34946 L
.70518 .33974 L
.70882 .33046 L
.70896 .33003 L
Mistroke
.71253 .32032 L
.7163 .31061 L
.71853 .30485 L
.7199 .30089 L
.72355 .29118 L
.72729 .28147 L
.72824 .27898 L
.73078 .27176 L
.73445 .26204 L
.73796 .25284 L
.73812 .25233 L
.74157 .24262 L
.74523 .23291 L
.74767 .22643 L
.74873 .22319 L
.75225 .21348 L
.75589 .20377 L
.75738 .19975 L
.75928 .19406 L
.76282 .18434 L
.76643 .17463 L
.76709 .17281 L
.76974 .16492 L
.77329 .15521 L
.77681 .14561 L
.77684 .14549 L
.78011 .13578 L
.78364 .12607 L
.78652 .11815 L
.78707 .11636 L
.79038 .10664 L
.7939 .09693 L
.79623 .09043 L
.79722 .08722 L
.80056 .07751 L
.80405 .06779 L
.80594 .06246 L
.80729 .05808 L
.81064 .04837 L
.8141 .03866 L
.81566 .03424 L
.81728 .02894 L
.82063 .01923 L
Mfstroke
.6 g
.46958 .98077 m
.47529 .97106 L
.47572 .97028 L
.48103 .96134 L
.48543 .9535 L
.48652 .95163 L
.4921 .94192 L
.49514 .93628 L
.49745 .93221 L
.50285 .92249 L
.50486 .91863 L
.50809 .91278 L
.51331 .90307 L
.51457 .90056 L
.51846 .89336 L
.52352 .88364 L
.52428 .88208 L
.52859 .87393 L
.53351 .86422 L
.53399 .8632 L
.5385 .85451 L
.54331 .84479 L
.54371 .84393 L
.54821 .83508 L
.55293 .82537 L
.55342 .82429 L
.55773 .81566 L
.56239 .80594 L
.56313 .80427 L
.56708 .79623 L
.57169 .78652 L
.57284 .78389 L
.57626 .77681 L
.58083 .76709 L
.58256 .76316 L
.5853 .75738 L
.58983 .74767 L
.59227 .74207 L
.59419 .73796 L
.59869 .72824 L
.60198 .72063 L
.60295 .71853 L
.6074 .70882 L
.61159 .69911 L
.61169 .69885 L
.61598 .68939 L
.62023 .67968 L
.62141 .67675 L
.62444 .66997 L
.62871 .66026 L
.63112 .65432 L
.63278 .65054 L
.63704 .64083 L
.64083 .63156 L
.64102 .63112 L
.64524 .62141 L
.64931 .61169 L
.65054 .60849 L
.65334 .60198 L
.65745 .59227 L
.66026 .5851 L
.66133 .58256 L
.66544 .57284 L
.66934 .56313 L
.66997 .5614 L
.67331 .55342 L
.67731 .54371 L
.67968 .5374 L
.68109 .53399 L
.6851 .52428 L
.68888 .51457 L
.68939 .5131 L
.69276 .50486 L
.69667 .49514 L
.69911 .4885 L
.70034 .48543 L
.70427 .47572 L
.70799 .46601 L
.70882 .46361 L
.71174 .45629 L
.71559 .44658 L
.71853 .43843 L
.71915 .43687 L
.72299 .42716 L
.72671 .41744 L
.72824 .41297 L
.73029 .40773 L
.73408 .39802 L
.7376 .38831 L
.73796 .38721 L
.7413 .37859 L
.74501 .36888 L
.74767 .36118 L
.74844 .35917 L
.75217 .34946 L
.75577 .33974 L
.75738 .33488 L
.75922 .33003 L
.76291 .32032 L
.76637 .31061 L
.76709 .3083 L
.76988 .30089 L
.77351 .29118 L
.7768 .28147 L
.77681 .28145 L
.78042 .27176 L
.78399 .26204 L
.78652 .25434 L
.78726 .25233 L
.79085 .24262 L
.79434 .23291 L
.79623 .22696 L
.7976 .22319 L
.80116 .21348 L
.80458 .20377 L
.80594 .19931 L
.80785 .19406 L
.81137 .18434 L
.8147 .17463 L
.81566 .17141 L
.81799 .16492 L
.82148 .15521 L
.82473 .14549 L
.82537 .14325 L
.82803 .13578 L
.83149 .12607 L
.83466 .11636 L
.83508 .11483 L
.83798 .10664 L
.8414 .09693 L
.84451 .08722 L
.84479 .08616 L
.84783 .07751 L
.85123 .06779 L
.85429 .05808 L
.85451 .05725 L
.85759 .04837 L
.86096 .03866 L
.86399 .02894 L
.86422 .02808 L
.86727 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.46958 .98077 m
.47529 .97106 L
.47572 .97028 L
.48103 .96134 L
.48543 .9535 L
.48652 .95163 L
.4921 .94192 L
.49514 .93628 L
.49745 .93221 L
.50285 .92249 L
.50486 .91863 L
.50809 .91278 L
.51331 .90307 L
.51457 .90056 L
.51846 .89336 L
.52352 .88364 L
.52428 .88208 L
.52859 .87393 L
.53351 .86422 L
.53399 .8632 L
.5385 .85451 L
.54331 .84479 L
.54371 .84393 L
.54821 .83508 L
.55293 .82537 L
.55342 .82429 L
.55773 .81566 L
.56239 .80594 L
.56313 .80427 L
.56708 .79623 L
.57169 .78652 L
.57284 .78389 L
.57626 .77681 L
.58083 .76709 L
.58256 .76316 L
.5853 .75738 L
.58983 .74767 L
.59227 .74207 L
.59419 .73796 L
.59869 .72824 L
.60198 .72063 L
.60295 .71853 L
.6074 .70882 L
.61159 .69911 L
.61169 .69885 L
.61598 .68939 L
.62023 .67968 L
.62141 .67675 L
.62444 .66997 L
.62871 .66026 L
Mistroke
.63112 .65432 L
.63278 .65054 L
.63704 .64083 L
.64083 .63156 L
.64102 .63112 L
.64524 .62141 L
.64931 .61169 L
.65054 .60849 L
.65334 .60198 L
.65745 .59227 L
.66026 .5851 L
.66133 .58256 L
.66544 .57284 L
.66934 .56313 L
.66997 .5614 L
.67331 .55342 L
.67731 .54371 L
.67968 .5374 L
.68109 .53399 L
.6851 .52428 L
.68888 .51457 L
.68939 .5131 L
.69276 .50486 L
.69667 .49514 L
.69911 .4885 L
.70034 .48543 L
.70427 .47572 L
.70799 .46601 L
.70882 .46361 L
.71174 .45629 L
.71559 .44658 L
.71853 .43843 L
.71915 .43687 L
.72299 .42716 L
.72671 .41744 L
.72824 .41297 L
.73029 .40773 L
.73408 .39802 L
.7376 .38831 L
.73796 .38721 L
.7413 .37859 L
.74501 .36888 L
.74767 .36118 L
.74844 .35917 L
.75217 .34946 L
.75577 .33974 L
.75738 .33488 L
.75922 .33003 L
.76291 .32032 L
.76637 .31061 L
Mistroke
.76709 .3083 L
.76988 .30089 L
.77351 .29118 L
.7768 .28147 L
.77681 .28145 L
.78042 .27176 L
.78399 .26204 L
.78652 .25434 L
.78726 .25233 L
.79085 .24262 L
.79434 .23291 L
.79623 .22696 L
.7976 .22319 L
.80116 .21348 L
.80458 .20377 L
.80594 .19931 L
.80785 .19406 L
.81137 .18434 L
.8147 .17463 L
.81566 .17141 L
.81799 .16492 L
.82148 .15521 L
.82473 .14549 L
.82537 .14325 L
.82803 .13578 L
.83149 .12607 L
.83466 .11636 L
.83508 .11483 L
.83798 .10664 L
.8414 .09693 L
.84451 .08722 L
.84479 .08616 L
.84783 .07751 L
.85123 .06779 L
.85429 .05808 L
.85451 .05725 L
.85759 .04837 L
.86096 .03866 L
.86399 .02894 L
.86422 .02808 L
.86727 .01923 L
Mfstroke
.5 g
.4863 .98077 m
.49169 .97106 L
.49514 .9647 L
.49698 .96134 L
.50222 .95163 L
.50486 .94667 L
.50739 .94192 L
.51252 .93221 L
.51457 .92825 L
.51757 .92249 L
.52258 .91278 L
.52428 .90944 L
.52754 .90307 L
.53245 .89336 L
.53399 .89024 L
.5373 .88364 L
.54212 .87393 L
.54371 .87068 L
.54689 .86422 L
.55162 .85451 L
.55342 .85075 L
.5563 .84479 L
.56095 .83508 L
.56313 .83046 L
.56555 .82537 L
.57014 .81566 L
.57284 .80982 L
.57466 .80594 L
.57917 .79623 L
.58256 .78883 L
.58362 .78652 L
.58808 .77681 L
.59227 .76751 L
.59246 .76709 L
.59685 .75738 L
.60118 .74767 L
.60198 .74585 L
.6055 .73796 L
.60979 .72824 L
.61169 .72386 L
.61403 .71853 L
.61828 .70882 L
.62141 .70154 L
.62246 .69911 L
.62666 .68939 L
.63079 .67968 L
.63112 .67891 L
.63494 .66997 L
.63905 .66026 L
.64083 .65596 L
.64311 .65054 L
.64719 .64083 L
.65054 .6327 L
.6512 .63112 L
.65524 .62141 L
.65922 .61169 L
.66026 .60913 L
.66319 .60198 L
.66716 .59227 L
.66997 .58526 L
.67107 .58256 L
.675 .57284 L
.67888 .56313 L
.67968 .56109 L
.68276 .55342 L
.68663 .54371 L
.68939 .53663 L
.69044 .53399 L
.69428 .52428 L
.69807 .51457 L
.69911 .51187 L
.70185 .50486 L
.70564 .49514 L
.70882 .48683 L
.70936 .48543 L
.71312 .47572 L
.71684 .46601 L
.71853 .4615 L
.72052 .45629 L
.72424 .44658 L
.72788 .43687 L
.72824 .43589 L
.73155 .42716 L
.73522 .41744 L
.73796 .41 L
.73881 .40773 L
.74245 .39802 L
.74605 .38831 L
.74767 .38384 L
.74961 .37859 L
.75322 .36888 L
.75675 .35917 L
.75738 .3574 L
.7603 .34946 L
.76386 .33974 L
.76709 .3307 L
.76733 .33003 L
.77087 .32032 L
.77438 .31061 L
.77681 .30372 L
.77782 .30089 L
.78132 .29118 L
.78479 .28147 L
.78652 .27649 L
.7882 .27176 L
.79167 .26204 L
.79509 .25233 L
.79623 .24899 L
.79848 .24262 L
.80191 .23291 L
.80528 .22319 L
.80594 .22123 L
.80866 .21348 L
.81206 .20377 L
.81538 .19406 L
.81566 .19321 L
.81873 .18434 L
.8221 .17463 L
.82537 .16494 L
.82538 .16492 L
.82872 .15521 L
.83205 .14549 L
.83508 .13642 L
.8353 .13578 L
.83861 .12607 L
.84192 .11636 L
.84479 .10765 L
.84513 .10664 L
.84842 .09693 L
.85169 .08722 L
.85451 .07863 L
.85488 .07751 L
.85814 .06779 L
.86139 .05808 L
.86422 .04936 L
.86455 .04837 L
.86778 .03866 L
.87101 .02894 L
.87393 .01985 L
.87413 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.4863 .98077 m
.49169 .97106 L
.49514 .9647 L
.49698 .96134 L
.50222 .95163 L
.50486 .94667 L
.50739 .94192 L
.51252 .93221 L
.51457 .92825 L
.51757 .92249 L
.52258 .91278 L
.52428 .90944 L
.52754 .90307 L
.53245 .89336 L
.53399 .89024 L
.5373 .88364 L
.54212 .87393 L
.54371 .87068 L
.54689 .86422 L
.55162 .85451 L
.55342 .85075 L
.5563 .84479 L
.56095 .83508 L
.56313 .83046 L
.56555 .82537 L
.57014 .81566 L
.57284 .80982 L
.57466 .80594 L
.57917 .79623 L
.58256 .78883 L
.58362 .78652 L
.58808 .77681 L
.59227 .76751 L
.59246 .76709 L
.59685 .75738 L
.60118 .74767 L
.60198 .74585 L
.6055 .73796 L
.60979 .72824 L
.61169 .72386 L
.61403 .71853 L
.61828 .70882 L
.62141 .70154 L
.62246 .69911 L
.62666 .68939 L
.63079 .67968 L
.63112 .67891 L
.63494 .66997 L
.63905 .66026 L
.64083 .65596 L
Mistroke
.64311 .65054 L
.64719 .64083 L
.65054 .6327 L
.6512 .63112 L
.65524 .62141 L
.65922 .61169 L
.66026 .60913 L
.66319 .60198 L
.66716 .59227 L
.66997 .58526 L
.67107 .58256 L
.675 .57284 L
.67888 .56313 L
.67968 .56109 L
.68276 .55342 L
.68663 .54371 L
.68939 .53663 L
.69044 .53399 L
.69428 .52428 L
.69807 .51457 L
.69911 .51187 L
.70185 .50486 L
.70564 .49514 L
.70882 .48683 L
.70936 .48543 L
.71312 .47572 L
.71684 .46601 L
.71853 .4615 L
.72052 .45629 L
.72424 .44658 L
.72788 .43687 L
.72824 .43589 L
.73155 .42716 L
.73522 .41744 L
.73796 .41 L
.73881 .40773 L
.74245 .39802 L
.74605 .38831 L
.74767 .38384 L
.74961 .37859 L
.75322 .36888 L
.75675 .35917 L
.75738 .3574 L
.7603 .34946 L
.76386 .33974 L
.76709 .3307 L
.76733 .33003 L
.77087 .32032 L
.77438 .31061 L
.77681 .30372 L
Mistroke
.77782 .30089 L
.78132 .29118 L
.78479 .28147 L
.78652 .27649 L
.7882 .27176 L
.79167 .26204 L
.79509 .25233 L
.79623 .24899 L
.79848 .24262 L
.80191 .23291 L
.80528 .22319 L
.80594 .22123 L
.80866 .21348 L
.81206 .20377 L
.81538 .19406 L
.81566 .19321 L
.81873 .18434 L
.8221 .17463 L
.82537 .16494 L
.82538 .16492 L
.82872 .15521 L
.83205 .14549 L
.83508 .13642 L
.8353 .13578 L
.83861 .12607 L
.84192 .11636 L
.84479 .10765 L
.84513 .10664 L
.84842 .09693 L
.85169 .08722 L
.85451 .07863 L
.85488 .07751 L
.85814 .06779 L
.86139 .05808 L
.86422 .04936 L
.86455 .04837 L
.86778 .03866 L
.87101 .02894 L
.87393 .01985 L
.87413 .01923 L
Mfstroke
.2 g
.50486 .24634 m
.51206 .25233 L
.50548 .26204 L
.50486 .26292 L
.49892 .26204 L
.50246 .25233 L
F
0 g
.50486 .24634 m
.51206 .25233 L
.50548 .26204 L
.50486 .26292 L
.49892 .26204 L
.50246 .25233 L
.50486 .24634 L
s
.8 g
.50486 .85049 m
.51334 .85451 L
.50687 .86422 L
.50486 .86707 L
.49959 .86422 L
.50324 .85451 L
F
0 g
.50486 .85049 m
.51334 .85451 L
.50687 .86422 L
.50486 .86707 L
.49959 .86422 L
.50324 .85451 L
.50486 .85049 L
s
.8 g
.50486 .04496 m
.51373 .04837 L
.50729 .05808 L
.50486 .06153 L
.4998 .05808 L
.50348 .04837 L
F
0 g
.50486 .04496 m
.51373 .04837 L
.50729 .05808 L
.50486 .06153 L
.4998 .05808 L
.50348 .04837 L
.50486 .04496 L
s
.4 g
.50037 .98077 m
.50486 .97227 L
.50549 .97106 L
.51055 .96134 L
.51457 .95358 L
.51556 .95163 L
.52052 .94192 L
.52428 .93451 L
.52544 .93221 L
.5303 .92249 L
.53399 .91507 L
.53512 .91278 L
.5399 .90307 L
.54371 .89528 L
.54463 .89336 L
.54933 .88364 L
.55342 .87513 L
.55399 .87393 L
.5586 .86422 L
.56313 .85463 L
.56319 .85451 L
.56772 .84479 L
.57224 .83508 L
.57284 .83378 L
.57671 .82537 L
.58117 .81566 L
.58256 .8126 L
.58557 .80594 L
.58996 .79623 L
.59227 .79109 L
.5943 .78652 L
.59863 .77681 L
.60198 .76925 L
.60292 .76709 L
.60719 .75738 L
.61144 .74767 L
.61169 .74709 L
.61564 .73796 L
.61984 .72824 L
.62141 .72461 L
.62399 .71853 L
.62814 .70882 L
.63112 .70181 L
.63225 .69911 L
.63634 .68939 L
.64042 .67968 L
.64083 .67871 L
.64445 .66997 L
.64849 .66026 L
.65054 .6553 L
.65248 .65054 L
.65647 .64083 L
.66026 .63158 L
.66044 .63112 L
.66437 .62141 L
.66831 .61169 L
.66997 .60757 L
.67219 .60198 L
.67609 .59227 L
.67968 .58327 L
.67996 .58256 L
.68379 .57284 L
.68764 .56313 L
.68939 .55867 L
.69143 .55342 L
.69523 .54371 L
.69903 .53399 L
.69911 .53379 L
.70276 .52428 L
.70653 .51457 L
.70882 .50862 L
.71024 .50486 L
.71396 .49514 L
.71767 .48543 L
.71853 .48317 L
.72133 .47572 L
.72501 .46601 L
.72824 .45744 L
.72867 .45629 L
.73229 .44658 L
.73593 .43687 L
.73796 .43144 L
.73952 .42716 L
.74312 .41744 L
.74672 .40773 L
.74767 .40516 L
.75026 .39802 L
.75383 .38831 L
.75738 .37862 L
.75739 .37859 L
.76089 .36888 L
.76443 .35917 L
.76709 .3518 L
.76792 .34946 L
.7714 .33974 L
.77491 .33003 L
.77681 .32472 L
.77835 .32032 L
.78181 .31061 L
.78528 .30089 L
.78652 .29739 L
.78868 .29118 L
.79211 .28147 L
.79554 .27176 L
.79623 .26979 L
.7989 .26204 L
.80231 .25233 L
.80571 .24262 L
.80594 .24193 L
.80903 .23291 L
.81241 .22319 L
.81566 .21382 L
.81577 .21348 L
.81907 .20377 L
.82242 .19406 L
.82537 .18546 L
.82574 .18434 L
.82902 .17463 L
.83234 .16492 L
.83508 .15685 L
.83562 .15521 L
.83887 .14549 L
.84217 .13578 L
.84479 .12799 L
.84542 .12607 L
.84864 .11636 L
.85192 .10664 L
.85451 .09888 L
.85513 .09693 L
.85833 .08722 L
.86158 .07751 L
.86422 .06953 L
.86477 .06779 L
.86794 .05808 L
.87116 .04837 L
.87393 .03993 L
.87433 .03866 L
.87747 .02894 L
.88067 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.50037 .98077 m
.50486 .97227 L
.50549 .97106 L
.51055 .96134 L
.51457 .95358 L
.51556 .95163 L
.52052 .94192 L
.52428 .93451 L
.52544 .93221 L
.5303 .92249 L
.53399 .91507 L
.53512 .91278 L
.5399 .90307 L
.54371 .89528 L
.54463 .89336 L
.54933 .88364 L
.55342 .87513 L
.55399 .87393 L
.5586 .86422 L
.56313 .85463 L
.56319 .85451 L
.56772 .84479 L
.57224 .83508 L
.57284 .83378 L
.57671 .82537 L
.58117 .81566 L
.58256 .8126 L
.58557 .80594 L
.58996 .79623 L
.59227 .79109 L
.5943 .78652 L
.59863 .77681 L
.60198 .76925 L
.60292 .76709 L
.60719 .75738 L
.61144 .74767 L
.61169 .74709 L
.61564 .73796 L
.61984 .72824 L
.62141 .72461 L
.62399 .71853 L
.62814 .70882 L
.63112 .70181 L
.63225 .69911 L
.63634 .68939 L
.64042 .67968 L
.64083 .67871 L
.64445 .66997 L
.64849 .66026 L
.65054 .6553 L
Mistroke
.65248 .65054 L
.65647 .64083 L
.66026 .63158 L
.66044 .63112 L
.66437 .62141 L
.66831 .61169 L
.66997 .60757 L
.67219 .60198 L
.67609 .59227 L
.67968 .58327 L
.67996 .58256 L
.68379 .57284 L
.68764 .56313 L
.68939 .55867 L
.69143 .55342 L
.69523 .54371 L
.69903 .53399 L
.69911 .53379 L
.70276 .52428 L
.70653 .51457 L
.70882 .50862 L
.71024 .50486 L
.71396 .49514 L
.71767 .48543 L
.71853 .48317 L
.72133 .47572 L
.72501 .46601 L
.72824 .45744 L
.72867 .45629 L
.73229 .44658 L
.73593 .43687 L
.73796 .43144 L
.73952 .42716 L
.74312 .41744 L
.74672 .40773 L
.74767 .40516 L
.75026 .39802 L
.75383 .38831 L
.75738 .37862 L
.75739 .37859 L
.76089 .36888 L
.76443 .35917 L
.76709 .3518 L
.76792 .34946 L
.7714 .33974 L
.77491 .33003 L
.77681 .32472 L
.77835 .32032 L
.78181 .31061 L
.78528 .30089 L
Mistroke
.78652 .29739 L
.78868 .29118 L
.79211 .28147 L
.79554 .27176 L
.79623 .26979 L
.7989 .26204 L
.80231 .25233 L
.80571 .24262 L
.80594 .24193 L
.80903 .23291 L
.81241 .22319 L
.81566 .21382 L
.81577 .21348 L
.81907 .20377 L
.82242 .19406 L
.82537 .18546 L
.82574 .18434 L
.82902 .17463 L
.83234 .16492 L
.83508 .15685 L
.83562 .15521 L
.83887 .14549 L
.84217 .13578 L
.84479 .12799 L
.84542 .12607 L
.84864 .11636 L
.85192 .10664 L
.85451 .09888 L
.85513 .09693 L
.85833 .08722 L
.86158 .07751 L
.86422 .06953 L
.86477 .06779 L
.86794 .05808 L
.87116 .04837 L
.87393 .03993 L
.87433 .03866 L
.87747 .02894 L
.88067 .01923 L
Mfstroke
.2 g
.78907 .01923 m
.78652 .02482 L
.78503 .02894 L
.78151 .03866 L
.7783 .04837 L
.77681 .05175 L
.77447 .05808 L
.77237 .06779 L
.76744 .07751 L
.76709 .0783 L
.76378 .08722 L
.76111 .09693 L
.75738 .10463 L
.75661 .10664 L
.75298 .11636 L
.74981 .12607 L
.74767 .13066 L
.74571 .13578 L
.74375 .14549 L
.73847 .15521 L
.73796 .15634 L
.73466 .16492 L
.73186 .17463 L
.72824 .18182 L
.72724 .18434 L
.72348 .19406 L
.72005 .20377 L
.71853 .20694 L
.71595 .21348 L
.71344 .22319 L
.70882 .23176 L
.70835 .23291 L
.70449 .24262 L
.7011 .25233 L
.69911 .25631 L
.69677 .26204 L
.69436 .27176 L
.68939 .2805 L
.68898 .28147 L
.68503 .29118 L
.6815 .30089 L
.67968 .30441 L
.6771 .31061 L
.67443 .32032 L
.66997 .328 L
.66909 .33003 L
.66502 .33974 L
.66117 .34946 L
.66026 .3512 L
.65686 .35917 L
.65359 .36888 L
.65054 .37416 L
.64859 .37859 L
.64441 .38831 L
.64083 .3967 L
.64022 .39802 L
.63597 .40773 L
.63191 .41744 L
.63112 .41886 L
.62741 .42716 L
.62379 .43687 L
.62141 .44077 L
.61873 .44658 L
.61433 .45629 L
.61169 .46229 L
.60991 .46601 L
.60543 .47572 L
.60198 .48337 L
.60094 .48543 L
.59638 .49514 L
.59227 .50401 L
.59181 .50486 L
.58715 .51457 L
.58256 .52418 L
.58249 .52428 L
.57774 .53399 L
.57304 .54371 L
.57284 .54399 L
.56811 .55342 L
.56329 .56313 L
.56313 .56334 L
.55824 .57284 L
.55342 .58235 L
.55323 .58256 L
.54809 .59227 L
.54371 .60115 L
.5429 .60198 L
.53759 .61169 L
.53399 .61937 L
.53218 .62141 L
.52663 .63112 L
.52428 .63634 L
.52091 .64083 L
.51498 .65054 L
.51457 .65143 L
.50864 .66026 L
.50486 .66568 L
.5005 .66026 L
.50427 .65054 L
.50486 .64911 L
.50835 .64083 L
.51254 .63112 L
.51457 .62646 L
.51681 .62141 L
.52113 .61169 L
.52428 .60461 L
.52546 .60198 L
.52983 .59227 L
.53399 .58295 L
.53417 .58256 L
.53855 .57284 L
.54243 .56313 L
.54371 .56112 L
.54724 .55342 L
.55157 .54371 L
.55342 .53918 L
.55589 .53399 L
.56019 .52428 L
.56313 .51723 L
.56448 .51457 L
.56875 .50486 L
.57284 .4954 L
.57299 .49514 L
.57724 .48543 L
.58106 .47572 L
.58256 .47302 L
.58565 .46601 L
.58875 .45629 L
.59227 .45035 L
.59398 .44658 L
.59812 .43687 L
.60198 .42767 L
.60223 .42716 L
.60634 .41744 L
.61004 .40773 L
.61169 .40456 L
.61448 .39802 L
.61741 .38831 L
.62141 .3812 L
.62255 .37859 L
.62656 .36888 L
.6304 .35917 L
.63112 .3577 L
.63452 .34946 L
.63773 .33974 L
.64083 .33378 L
.6424 .33003 L
.64446 .32032 L
.65014 .31061 L
.65054 .30976 L
.65411 .30089 L
.65731 .29118 L
.66026 .2853 L
.66182 .28147 L
.66387 .27176 L
.66937 .26204 L
.66997 .26073 L
.67328 .25233 L
.67631 .24262 L
.67968 .23577 L
.68083 .23291 L
.68252 .22319 L
.6881 .21348 L
.68939 .21064 L
.69206 .20377 L
.69471 .19406 L
.69911 .18522 L
.69946 .18434 L
.70315 .17463 L
.70632 .16492 L
.70882 .1595 L
.71047 .15521 L
.71247 .14549 L
.71758 .13578 L
.71853 .13359 L
.72136 .12607 L
.72397 .11636 L
.72824 .10739 L
.72853 .10664 L
.73212 .09693 L
.73511 .08722 L
.73796 .0809 L
.73923 .07751 L
.74085 .06779 L
.746 .05808 L
.74767 .0542 L
.74981 .04837 L
.75195 .03866 L
.75668 .02894 L
.75738 .02734 L
.76028 .01923 L
F
0 g
.78907 .01923 m
.78652 .02482 L
.78503 .02894 L
.78151 .03866 L
.7783 .04837 L
.77681 .05175 L
.77447 .05808 L
.77237 .06779 L
.76744 .07751 L
.76709 .0783 L
.76378 .08722 L
.76111 .09693 L
.75738 .10463 L
.75661 .10664 L
.75298 .11636 L
.74981 .12607 L
.74767 .13066 L
.74571 .13578 L
.74375 .14549 L
.73847 .15521 L
.73796 .15634 L
.73466 .16492 L
.73186 .17463 L
.72824 .18182 L
.72724 .18434 L
.72348 .19406 L
.72005 .20377 L
.71853 .20694 L
.71595 .21348 L
.71344 .22319 L
.70882 .23176 L
.70835 .23291 L
.70449 .24262 L
.7011 .25233 L
.69911 .25631 L
.69677 .26204 L
.69436 .27176 L
.68939 .2805 L
.68898 .28147 L
.68503 .29118 L
.6815 .30089 L
.67968 .30441 L
.6771 .31061 L
.67443 .32032 L
.66997 .328 L
.66909 .33003 L
.66502 .33974 L
.66117 .34946 L
.66026 .3512 L
.65686 .35917 L
Mistroke
.65359 .36888 L
.65054 .37416 L
.64859 .37859 L
.64441 .38831 L
.64083 .3967 L
.64022 .39802 L
.63597 .40773 L
.63191 .41744 L
.63112 .41886 L
.62741 .42716 L
.62379 .43687 L
.62141 .44077 L
.61873 .44658 L
.61433 .45629 L
.61169 .46229 L
.60991 .46601 L
.60543 .47572 L
.60198 .48337 L
.60094 .48543 L
.59638 .49514 L
.59227 .50401 L
.59181 .50486 L
.58715 .51457 L
.58256 .52418 L
.58249 .52428 L
.57774 .53399 L
.57304 .54371 L
.57284 .54399 L
.56811 .55342 L
.56329 .56313 L
.56313 .56334 L
.55824 .57284 L
.55342 .58235 L
.55323 .58256 L
.54809 .59227 L
.54371 .60115 L
.5429 .60198 L
.53759 .61169 L
.53399 .61937 L
.53218 .62141 L
.52663 .63112 L
.52428 .63634 L
.52091 .64083 L
.51498 .65054 L
.51457 .65143 L
.50864 .66026 L
.50486 .66568 L
.5005 .66026 L
.50427 .65054 L
.50486 .64911 L
Mistroke
.50835 .64083 L
.51254 .63112 L
.51457 .62646 L
.51681 .62141 L
.52113 .61169 L
.52428 .60461 L
.52546 .60198 L
.52983 .59227 L
.53399 .58295 L
.53417 .58256 L
.53855 .57284 L
.54243 .56313 L
.54371 .56112 L
.54724 .55342 L
.55157 .54371 L
.55342 .53918 L
.55589 .53399 L
.56019 .52428 L
.56313 .51723 L
.56448 .51457 L
.56875 .50486 L
.57284 .4954 L
.57299 .49514 L
.57724 .48543 L
.58106 .47572 L
.58256 .47302 L
.58565 .46601 L
.58875 .45629 L
.59227 .45035 L
.59398 .44658 L
.59812 .43687 L
.60198 .42767 L
.60223 .42716 L
.60634 .41744 L
.61004 .40773 L
.61169 .40456 L
.61448 .39802 L
.61741 .38831 L
.62141 .3812 L
.62255 .37859 L
.62656 .36888 L
.6304 .35917 L
.63112 .3577 L
.63452 .34946 L
.63773 .33974 L
.64083 .33378 L
.6424 .33003 L
.64446 .32032 L
.65014 .31061 L
.65054 .30976 L
Mistroke
.65411 .30089 L
.65731 .29118 L
.66026 .2853 L
.66182 .28147 L
.66387 .27176 L
.66937 .26204 L
.66997 .26073 L
.67328 .25233 L
.67631 .24262 L
.67968 .23577 L
.68083 .23291 L
.68252 .22319 L
.6881 .21348 L
.68939 .21064 L
.69206 .20377 L
.69471 .19406 L
.69911 .18522 L
.69946 .18434 L
.70315 .17463 L
.70632 .16492 L
.70882 .1595 L
.71047 .15521 L
.71247 .14549 L
.71758 .13578 L
.71853 .13359 L
.72136 .12607 L
.72397 .11636 L
.72824 .10739 L
.72853 .10664 L
.73212 .09693 L
.73511 .08722 L
.73796 .0809 L
.73923 .07751 L
.74085 .06779 L
.746 .05808 L
.74767 .0542 L
.74981 .04837 L
.75195 .03866 L
.75668 .02894 L
.75738 .02734 L
.76028 .01923 L
Mfstroke
.8 g
.50486 .44772 m
.51036 .45629 L
.50486 .4643 L
.50147 .45629 L
F
0 g
.50486 .44772 m
.51036 .45629 L
.50486 .4643 L
.50147 .45629 L
.50486 .44772 L
s
.8 g
.71315 .01923 m
.70949 .02894 L
.70882 .03036 L
.70552 .03866 L
.70256 .04837 L
.69911 .05493 L
.69781 .05808 L
.69391 .06779 L
.69018 .07751 L
.68939 .0791 L
.68608 .08722 L
.68301 .09693 L
.67968 .10305 L
.67816 .10664 L
.67416 .11636 L
.67021 .12607 L
.66997 .12655 L
.6661 .13578 L
.66265 .14549 L
.66026 .14986 L
.65795 .15521 L
.65543 .16492 L
.65054 .17277 L
.6497 .17463 L
.64552 .18434 L
.64149 .19406 L
.64083 .19527 L
.6371 .20377 L
.63353 .21348 L
.63112 .21754 L
.62856 .22319 L
.62424 .23291 L
.62141 .23942 L
.6199 .24262 L
.6155 .25233 L
.61169 .26085 L
.6111 .26204 L
.60662 .27176 L
.6022 .28147 L
.60198 .28184 L
.59759 .29118 L
.59335 .30089 L
.59227 .30257 L
.58839 .31061 L
.58436 .32032 L
.58256 .32288 L
.579 .33003 L
.57424 .33974 L
.57284 .34274 L
.5694 .34946 L
.56453 .35917 L
.56313 .36212 L
.55957 .36888 L
.55456 .37859 L
.55342 .38098 L
.54945 .38831 L
.5443 .39802 L
.54371 .39922 L
.539 .40773 L
.53399 .41683 L
.53365 .41744 L
.52811 .42716 L
.52428 .4338 L
.52245 .43687 L
.51657 .44658 L
.51457 .44983 L
.50533 .44658 L
.50946 .43687 L
.51366 .42716 L
.51457 .42415 L
.51796 .41744 L
.52228 .40773 L
.52428 .40187 L
.52663 .39802 L
.53098 .38831 L
.53399 .38037 L
.53534 .37859 L
.5397 .36888 L
.54371 .35948 L
.54404 .35917 L
.54839 .34946 L
.55239 .33974 L
.55342 .33803 L
.55704 .33003 L
.56038 .32032 L
.56313 .31595 L
.56562 .31061 L
.56988 .30089 L
.57284 .2938 L
.57412 .29118 L
.57836 .28147 L
.58255 .27176 L
.58256 .27175 L
.58676 .26204 L
.59047 .25233 L
.59227 .24905 L
.59508 .24262 L
.59802 .23291 L
.60198 .22617 L
.60332 .22319 L
.60743 .21348 L
.61144 .20377 L
.61169 .20326 L
.61556 .19406 L
.61903 .18434 L
.62141 .17983 L
.62362 .17463 L
.62616 .16492 L
.63112 .15628 L
.63159 .15521 L
.63557 .14549 L
.63917 .13578 L
.64083 .13243 L
.64345 .12607 L
.64623 .11636 L
.65054 .10831 L
.65125 .10664 L
.65514 .09693 L
.65869 .08722 L
.66026 .08395 L
.66285 .07751 L
.66556 .06779 L
.66997 .05932 L
.67048 .05808 L
.67429 .04837 L
.67767 .03866 L
.67968 .0344 L
.68183 .02894 L
.68424 .01923 L
F
0 g
.71315 .01923 m
.70949 .02894 L
.70882 .03036 L
.70552 .03866 L
.70256 .04837 L
.69911 .05493 L
.69781 .05808 L
.69391 .06779 L
.69018 .07751 L
.68939 .0791 L
.68608 .08722 L
.68301 .09693 L
.67968 .10305 L
.67816 .10664 L
.67416 .11636 L
.67021 .12607 L
.66997 .12655 L
.6661 .13578 L
.66265 .14549 L
.66026 .14986 L
.65795 .15521 L
.65543 .16492 L
.65054 .17277 L
.6497 .17463 L
.64552 .18434 L
.64149 .19406 L
.64083 .19527 L
.6371 .20377 L
.63353 .21348 L
.63112 .21754 L
.62856 .22319 L
.62424 .23291 L
.62141 .23942 L
.6199 .24262 L
.6155 .25233 L
.61169 .26085 L
.6111 .26204 L
.60662 .27176 L
.6022 .28147 L
.60198 .28184 L
.59759 .29118 L
.59335 .30089 L
.59227 .30257 L
.58839 .31061 L
.58436 .32032 L
.58256 .32288 L
.579 .33003 L
.57424 .33974 L
.57284 .34274 L
.5694 .34946 L
Mistroke
.56453 .35917 L
.56313 .36212 L
.55957 .36888 L
.55456 .37859 L
.55342 .38098 L
.54945 .38831 L
.5443 .39802 L
.54371 .39922 L
.539 .40773 L
.53399 .41683 L
.53365 .41744 L
.52811 .42716 L
.52428 .4338 L
.52245 .43687 L
.51657 .44658 L
.51457 .44983 L
.50533 .44658 L
.50946 .43687 L
.51366 .42716 L
.51457 .42415 L
.51796 .41744 L
.52228 .40773 L
.52428 .40187 L
.52663 .39802 L
.53098 .38831 L
.53399 .38037 L
.53534 .37859 L
.5397 .36888 L
.54371 .35948 L
.54404 .35917 L
.54839 .34946 L
.55239 .33974 L
.55342 .33803 L
.55704 .33003 L
.56038 .32032 L
.56313 .31595 L
.56562 .31061 L
.56988 .30089 L
.57284 .2938 L
.57412 .29118 L
.57836 .28147 L
.58255 .27176 L
.58256 .27175 L
.58676 .26204 L
.59047 .25233 L
.59227 .24905 L
.59508 .24262 L
.59802 .23291 L
.60198 .22617 L
.60332 .22319 L
Mistroke
.60743 .21348 L
.61144 .20377 L
.61169 .20326 L
.61556 .19406 L
.61903 .18434 L
.62141 .17983 L
.62362 .17463 L
.62616 .16492 L
.63112 .15628 L
.63159 .15521 L
.63557 .14549 L
.63917 .13578 L
.64083 .13243 L
.64345 .12607 L
.64623 .11636 L
.65054 .10831 L
.65125 .10664 L
.65514 .09693 L
.65869 .08722 L
.66026 .08395 L
.66285 .07751 L
.66556 .06779 L
.66997 .05932 L
.67048 .05808 L
.67429 .04837 L
.67767 .03866 L
.67968 .0344 L
.68183 .02894 L
.68424 .01923 L
Mfstroke
.2 g
.51457 .22369 m
.52399 .23291 L
.51815 .24262 L
.51457 .24844 L
.50642 .24262 L
.51057 .23291 L
F
0 g
.51457 .22369 m
.52399 .23291 L
.51815 .24262 L
.51457 .24844 L
.50642 .24262 L
.51057 .23291 L
.51457 .22369 L
s
.8 g
.85971 .01923 m
.85522 .02894 L
.85451 .03073 L
.85181 .03866 L
.84983 .04837 L
.84534 .05808 L
.84479 .05945 L
.84193 .06779 L
.83982 .07751 L
.83536 .08722 L
.83508 .0879 L
.83195 .09693 L
.82967 .10664 L
.82537 .1161 L
.82528 .11636 L
.82188 .12607 L
.81939 .13578 L
.81566 .14406 L
.81514 .14549 L
.81172 .15521 L
.80899 .16492 L
.80594 .17174 L
.8049 .17463 L
.80145 .18434 L
.79847 .19406 L
.79623 .19915 L
.79455 .20377 L
.79301 .21348 L
.78786 .22319 L
.78652 .22627 L
.7841 .23291 L
.78199 .24262 L
.77714 .25233 L
.77681 .25311 L
.77352 .26204 L
.77091 .27176 L
.76709 .27972 L
.76643 .28147 L
.76283 .29118 L
.75976 .30089 L
.75738 .30603 L
.75564 .31061 L
.7539 .32032 L
.74856 .33003 L
.74767 .33201 L
.74473 .33974 L
.74215 .34946 L
.73796 .35775 L
.7374 .35917 L
.73368 .36888 L
.73046 .37859 L
.72824 .3832 L
.72624 .38831 L
.72418 .39802 L
.71879 .40773 L
.71853 .40828 L
.71494 .41744 L
.71189 .42716 L
.70882 .43318 L
.70732 .43687 L
.70347 .44658 L
.69976 .45629 L
.69911 .45765 L
.69574 .46601 L
.6927 .47572 L
.68939 .48192 L
.68793 .48543 L
.68398 .49514 L
.68013 .50486 L
.67968 .50575 L
.67604 .51457 L
.67275 .52428 L
.66997 .52939 L
.66801 .53399 L
.66395 .54371 L
.66026 .55259 L
.65989 .55342 L
.65576 .56313 L
.65199 .57284 L
.65054 .57551 L
.64748 .58256 L
.64436 .59227 L
.64083 .59812 L
.63909 .60198 L
.63484 .61169 L
.63112 .62029 L
.63059 .62141 L
.62626 .63112 L
.62212 .64083 L
.62141 .64208 L
.61756 .65054 L
.6138 .66026 L
.61169 .66362 L
.60872 .66997 L
.60425 .67968 L
.60198 .68476 L
.59973 .68939 L
.59517 .69911 L
.59227 .70548 L
.59057 .70882 L
.58592 .71853 L
.58256 .72577 L
.58123 .72824 L
.57647 .73796 L
.57284 .74564 L
.57169 .74767 L
.56682 .75738 L
.56313 .76508 L
.56191 .76709 L
.55691 .77681 L
.55342 .78408 L
.55187 .78652 L
.54672 .79623 L
.54371 .80253 L
.5415 .80594 L
.53617 .81566 L
.53399 .82023 L
.53072 .82537 L
.52514 .83508 L
.52428 .83686 L
.51935 .84479 L
.51457 .8526 L
.50725 .84479 L
.51142 .83508 L
.51457 .82784 L
.51567 .82537 L
.51998 .81566 L
.52428 .80599 L
.5243 .80594 L
.52867 .79623 L
.53302 .78652 L
.53399 .78404 L
.53739 .77681 L
.54174 .76709 L
.54371 .76218 L
.54609 .75738 L
.55042 .74767 L
.55342 .74041 L
.55474 .73796 L
.55905 .72824 L
.56313 .71886 L
.56333 .71853 L
.56762 .70882 L
.5715 .69911 L
.57284 .69674 L
.57611 .68939 L
.57931 .67968 L
.58256 .6743 L
.58453 .66997 L
.58872 .66026 L
.59227 .65179 L
.59287 .65054 L
.59702 .64083 L
.6009 .63112 L
.60198 .62905 L
.60525 .62141 L
.60847 .61169 L
.61169 .60589 L
.6134 .60198 L
.61746 .59227 L
.62141 .5827 L
.62147 .58256 L
.6255 .57284 L
.62902 .56313 L
.63112 .55903 L
.63346 .55342 L
.6361 .54371 L
.64083 .5352 L
.64135 .53399 L
.64529 .52428 L
.64884 .51457 L
.65054 .51109 L
.65308 .50486 L
.65579 .49514 L
.66026 .48672 L
.66079 .48543 L
.66465 .47572 L
.66809 .46601 L
.66997 .46207 L
.67227 .45629 L
.6748 .44658 L
.67968 .43722 L
.67983 .43687 L
.6836 .42716 L
.68681 .41744 L
.68939 .41199 L
.69107 .40773 L
.69314 .39802 L
.69835 .38831 L
.69911 .38662 L
.70218 .37859 L
.70498 .36888 L
.70882 .3609 L
.7095 .35917 L
.71315 .34946 L
.71637 .33974 L
.71853 .33495 L
.7204 .33003 L
.7225 .32032 L
.72746 .31061 L
.72824 .30878 L
.73117 .30089 L
.7338 .29118 L
.73796 .28232 L
.73828 .28147 L
.74184 .27176 L
.74478 .26204 L
.74767 .25557 L
.74887 .25233 L
.75041 .24262 L
.75554 .23291 L
.75738 .22861 L
.75935 .22319 L
.76136 .21348 L
.76611 .20377 L
.76709 .20141 L
.76973 .19406 L
.77205 .18434 L
.77653 .17463 L
.77681 .17396 L
.78001 .16492 L
.78254 .15521 L
.78652 .14623 L
.78678 .14549 L
.79019 .13578 L
.79286 .12607 L
.79623 .11825 L
.7969 .11636 L
.80027 .10664 L
.80304 .09693 L
.80594 .09003 L
.80693 .08722 L
.81027 .07751 L
.81309 .06779 L
.81566 .06158 L
.81687 .05808 L
.81811 .04837 L
.82302 .03866 L
.82537 .03288 L
.82672 .02894 L
.82802 .01923 L
F
0 g
.85971 .01923 m
.85522 .02894 L
.85451 .03073 L
.85181 .03866 L
.84983 .04837 L
.84534 .05808 L
.84479 .05945 L
.84193 .06779 L
.83982 .07751 L
.83536 .08722 L
.83508 .0879 L
.83195 .09693 L
.82967 .10664 L
.82537 .1161 L
.82528 .11636 L
.82188 .12607 L
.81939 .13578 L
.81566 .14406 L
.81514 .14549 L
.81172 .15521 L
.80899 .16492 L
.80594 .17174 L
.8049 .17463 L
.80145 .18434 L
.79847 .19406 L
.79623 .19915 L
.79455 .20377 L
.79301 .21348 L
.78786 .22319 L
.78652 .22627 L
.7841 .23291 L
.78199 .24262 L
.77714 .25233 L
.77681 .25311 L
.77352 .26204 L
.77091 .27176 L
.76709 .27972 L
.76643 .28147 L
.76283 .29118 L
.75976 .30089 L
.75738 .30603 L
.75564 .31061 L
.7539 .32032 L
.74856 .33003 L
.74767 .33201 L
.74473 .33974 L
.74215 .34946 L
.73796 .35775 L
.7374 .35917 L
.73368 .36888 L
Mistroke
.73046 .37859 L
.72824 .3832 L
.72624 .38831 L
.72418 .39802 L
.71879 .40773 L
.71853 .40828 L
.71494 .41744 L
.71189 .42716 L
.70882 .43318 L
.70732 .43687 L
.70347 .44658 L
.69976 .45629 L
.69911 .45765 L
.69574 .46601 L
.6927 .47572 L
.68939 .48192 L
.68793 .48543 L
.68398 .49514 L
.68013 .50486 L
.67968 .50575 L
.67604 .51457 L
.67275 .52428 L
.66997 .52939 L
.66801 .53399 L
.66395 .54371 L
.66026 .55259 L
.65989 .55342 L
.65576 .56313 L
.65199 .57284 L
.65054 .57551 L
.64748 .58256 L
.64436 .59227 L
.64083 .59812 L
.63909 .60198 L
.63484 .61169 L
.63112 .62029 L
.63059 .62141 L
.62626 .63112 L
.62212 .64083 L
.62141 .64208 L
.61756 .65054 L
.6138 .66026 L
.61169 .66362 L
.60872 .66997 L
.60425 .67968 L
.60198 .68476 L
.59973 .68939 L
.59517 .69911 L
.59227 .70548 L
.59057 .70882 L
Mistroke
.58592 .71853 L
.58256 .72577 L
.58123 .72824 L
.57647 .73796 L
.57284 .74564 L
.57169 .74767 L
.56682 .75738 L
.56313 .76508 L
.56191 .76709 L
.55691 .77681 L
.55342 .78408 L
.55187 .78652 L
.54672 .79623 L
.54371 .80253 L
.5415 .80594 L
.53617 .81566 L
.53399 .82023 L
.53072 .82537 L
.52514 .83508 L
.52428 .83686 L
.51935 .84479 L
.51457 .8526 L
.50725 .84479 L
.51142 .83508 L
.51457 .82784 L
.51567 .82537 L
.51998 .81566 L
.52428 .80599 L
.5243 .80594 L
.52867 .79623 L
.53302 .78652 L
.53399 .78404 L
.53739 .77681 L
.54174 .76709 L
.54371 .76218 L
.54609 .75738 L
.55042 .74767 L
.55342 .74041 L
.55474 .73796 L
.55905 .72824 L
.56313 .71886 L
.56333 .71853 L
.56762 .70882 L
.5715 .69911 L
.57284 .69674 L
.57611 .68939 L
.57931 .67968 L
.58256 .6743 L
.58453 .66997 L
.58872 .66026 L
Mistroke
.59227 .65179 L
.59287 .65054 L
.59702 .64083 L
.6009 .63112 L
.60198 .62905 L
.60525 .62141 L
.60847 .61169 L
.61169 .60589 L
.6134 .60198 L
.61746 .59227 L
.62141 .5827 L
.62147 .58256 L
.6255 .57284 L
.62902 .56313 L
.63112 .55903 L
.63346 .55342 L
.6361 .54371 L
.64083 .5352 L
.64135 .53399 L
.64529 .52428 L
.64884 .51457 L
.65054 .51109 L
.65308 .50486 L
.65579 .49514 L
.66026 .48672 L
.66079 .48543 L
.66465 .47572 L
.66809 .46601 L
.66997 .46207 L
.67227 .45629 L
.6748 .44658 L
.67968 .43722 L
.67983 .43687 L
.6836 .42716 L
.68681 .41744 L
.68939 .41199 L
.69107 .40773 L
.69314 .39802 L
.69835 .38831 L
.69911 .38662 L
.70218 .37859 L
.70498 .36888 L
.70882 .3609 L
.7095 .35917 L
.71315 .34946 L
.71637 .33974 L
.71853 .33495 L
.7204 .33003 L
.7225 .32032 L
.72746 .31061 L
Mistroke
.72824 .30878 L
.73117 .30089 L
.7338 .29118 L
.73796 .28232 L
.73828 .28147 L
.74184 .27176 L
.74478 .26204 L
.74767 .25557 L
.74887 .25233 L
.75041 .24262 L
.75554 .23291 L
.75738 .22861 L
.75935 .22319 L
.76136 .21348 L
.76611 .20377 L
.76709 .20141 L
.76973 .19406 L
.77205 .18434 L
.77653 .17463 L
.77681 .17396 L
.78001 .16492 L
.78254 .15521 L
.78652 .14623 L
.78678 .14549 L
.79019 .13578 L
.79286 .12607 L
.79623 .11825 L
.7969 .11636 L
.80027 .10664 L
.80304 .09693 L
.80594 .09003 L
.80693 .08722 L
.81027 .07751 L
.81309 .06779 L
.81566 .06158 L
.81687 .05808 L
.81811 .04837 L
.82302 .03866 L
.82537 .03288 L
.82672 .02894 L
.82802 .01923 L
Mfstroke
.8 g
.53106 .01923 m
.52549 .02894 L
.52428 .03148 L
.51971 .03866 L
.51457 .04706 L
.50751 .03866 L
.51168 .02894 L
.51457 .0223 L
.51593 .01923 L
F
0 g
.53106 .01923 m
.52549 .02894 L
.52428 .03148 L
.51971 .03866 L
.51457 .04706 L
.50751 .03866 L
.51168 .02894 L
.51457 .0223 L
.51593 .01923 L
s
.2 g
.62971 .01923 m
.62539 .02894 L
.62141 .03796 L
.62106 .03866 L
.61667 .04837 L
.61248 .05808 L
.61169 .0594 L
.60781 .06779 L
.60395 .07751 L
.60198 .08054 L
.5988 .08722 L
.59424 .09693 L
.59227 .10128 L
.58962 .10664 L
.58497 .11636 L
.58256 .1216 L
.58026 .12607 L
.57551 .13578 L
.57284 .14148 L
.5707 .14549 L
.56582 .15521 L
.56313 .1609 L
.5609 .16492 L
.55589 .17463 L
.55342 .17982 L
.55082 .18434 L
.54567 .19406 L
.54371 .19814 L
.54042 .20377 L
.53508 .21348 L
.53399 .21571 L
.52959 .22319 L
.52428 .23242 L
.51479 .22319 L
.51911 .21348 L
.52342 .20377 L
.52428 .20143 L
.52778 .19406 L
.53214 .18434 L
.53399 .1795 L
.5365 .17463 L
.54086 .16492 L
.54371 .15782 L
.5452 .15521 L
.54954 .14549 L
.55342 .13643 L
.55386 .13578 L
.55818 .12607 L
.5622 .11636 L
.56313 .11474 L
.56675 .10664 L
.57016 .09693 L
.57284 .09248 L
.57525 .08722 L
.57948 .07751 L
.58256 .07013 L
.58367 .06779 L
.58787 .05808 L
.59196 .04837 L
.59227 .04777 L
.59618 .03866 L
.59974 .02894 L
.60198 .02614 L
.60442 .01923 L
F
0 g
.62971 .01923 m
.62539 .02894 L
.62141 .03796 L
.62106 .03866 L
.61667 .04837 L
.61248 .05808 L
.61169 .0594 L
.60781 .06779 L
.60395 .07751 L
.60198 .08054 L
.5988 .08722 L
.59424 .09693 L
.59227 .10128 L
.58962 .10664 L
.58497 .11636 L
.58256 .1216 L
.58026 .12607 L
.57551 .13578 L
.57284 .14148 L
.5707 .14549 L
.56582 .15521 L
.56313 .1609 L
.5609 .16492 L
.55589 .17463 L
.55342 .17982 L
.55082 .18434 L
.54567 .19406 L
.54371 .19814 L
.54042 .20377 L
.53508 .21348 L
.53399 .21571 L
.52959 .22319 L
.52428 .23242 L
.51479 .22319 L
.51911 .21348 L
.52342 .20377 L
.52428 .20143 L
.52778 .19406 L
.53214 .18434 L
.53399 .1795 L
.5365 .17463 L
.54086 .16492 L
.54371 .15782 L
.5452 .15521 L
.54954 .14549 L
.55342 .13643 L
.55386 .13578 L
.55818 .12607 L
.5622 .11636 L
.56313 .11474 L
Mistroke
.56675 .10664 L
.57016 .09693 L
.57284 .09248 L
.57525 .08722 L
.57948 .07751 L
.58256 .07013 L
.58367 .06779 L
.58787 .05808 L
.59196 .04837 L
.59227 .04777 L
.59618 .03866 L
.59974 .02894 L
.60198 .02614 L
.60442 .01923 L
Mfstroke
.3 g
.51481 .98077 m
.51964 .97106 L
.52428 .96187 L
.52453 .96134 L
.52927 .95163 L
.53399 .94212 L
.53409 .94192 L
.53873 .93221 L
.54348 .92249 L
.54371 .92202 L
.54804 .91278 L
.55271 .90307 L
.55342 .90158 L
.5572 .89336 L
.5618 .88364 L
.56313 .88081 L
.56623 .87393 L
.57075 .86422 L
.57284 .85971 L
.57513 .85451 L
.57957 .84479 L
.58256 .83828 L
.58393 .83508 L
.58827 .82537 L
.59227 .81654 L
.59263 .81566 L
.59686 .80594 L
.6012 .79623 L
.60198 .79447 L
.60534 .78652 L
.60962 .77681 L
.61169 .77208 L
.61375 .76709 L
.61794 .75738 L
.62141 .7494 L
.62209 .74767 L
.62616 .73796 L
.63033 .72824 L
.63112 .7264 L
.6343 .71853 L
.63841 .70882 L
.64083 .7031 L
.64239 .69911 L
.6464 .68939 L
.65047 .67968 L
.65054 .67951 L
.65431 .66997 L
.65834 .66026 L
.66026 .65561 L
.66219 .65054 L
.66612 .64083 L
.66997 .63143 L
.67008 .63112 L
.67383 .62141 L
.67777 .61169 L
.67968 .60695 L
.68152 .60198 L
.68536 .59227 L
.68925 .58256 L
.68939 .5822 L
.6929 .57284 L
.69674 .56313 L
.69911 .55715 L
.70044 .55342 L
.70416 .54371 L
.70798 .53399 L
.70882 .53184 L
.71155 .52428 L
.7153 .51457 L
.71853 .50624 L
.719 .50486 L
.72256 .49514 L
.7263 .48543 L
.72824 .48037 L
.72984 .47572 L
.73347 .46601 L
.73717 .45629 L
.73796 .45423 L
.74061 .44658 L
.74426 .43687 L
.74767 .42782 L
.74788 .42716 L
.75129 .41744 L
.75492 .40773 L
.75738 .40113 L
.75839 .39802 L
.76187 .38831 L
.76547 .37859 L
.76709 .37419 L
.76884 .36888 L
.77234 .35917 L
.77591 .34946 L
.77681 .34699 L
.7792 .33974 L
.7827 .33003 L
.78624 .32032 L
.78652 .31954 L
.78947 .31061 L
.79296 .30089 L
.79623 .29182 L
.79642 .29118 L
.79964 .28147 L
.80312 .27176 L
.80594 .26385 L
.80648 .26204 L
.80973 .25233 L
.81318 .24262 L
.81566 .23562 L
.81646 .23291 L
.81972 .22319 L
.82315 .21348 L
.82537 .20715 L
.82637 .20377 L
.82962 .19406 L
.83303 .18434 L
.83508 .17843 L
.8362 .17463 L
.83943 .16492 L
.84281 .15521 L
.84479 .14946 L
.84595 .14549 L
.84916 .13578 L
.85252 .12607 L
.85451 .12025 L
.85562 .11636 L
.85881 .10664 L
.86214 .09693 L
.86422 .0908 L
.86523 .08722 L
.86837 .07751 L
.87168 .06779 L
.87393 .06111 L
.87476 .05808 L
.87786 .04837 L
.88114 .03866 L
.88364 .03119 L
.88424 .02894 L
.88727 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.51481 .98077 m
.51964 .97106 L
.52428 .96187 L
.52453 .96134 L
.52927 .95163 L
.53399 .94212 L
.53409 .94192 L
.53873 .93221 L
.54348 .92249 L
.54371 .92202 L
.54804 .91278 L
.55271 .90307 L
.55342 .90158 L
.5572 .89336 L
.5618 .88364 L
.56313 .88081 L
.56623 .87393 L
.57075 .86422 L
.57284 .85971 L
.57513 .85451 L
.57957 .84479 L
.58256 .83828 L
.58393 .83508 L
.58827 .82537 L
.59227 .81654 L
.59263 .81566 L
.59686 .80594 L
.6012 .79623 L
.60198 .79447 L
.60534 .78652 L
.60962 .77681 L
.61169 .77208 L
.61375 .76709 L
.61794 .75738 L
.62141 .7494 L
.62209 .74767 L
.62616 .73796 L
.63033 .72824 L
.63112 .7264 L
.6343 .71853 L
.63841 .70882 L
.64083 .7031 L
.64239 .69911 L
.6464 .68939 L
.65047 .67968 L
.65054 .67951 L
.65431 .66997 L
.65834 .66026 L
.66026 .65561 L
.66219 .65054 L
Mistroke
.66612 .64083 L
.66997 .63143 L
.67008 .63112 L
.67383 .62141 L
.67777 .61169 L
.67968 .60695 L
.68152 .60198 L
.68536 .59227 L
.68925 .58256 L
.68939 .5822 L
.6929 .57284 L
.69674 .56313 L
.69911 .55715 L
.70044 .55342 L
.70416 .54371 L
.70798 .53399 L
.70882 .53184 L
.71155 .52428 L
.7153 .51457 L
.71853 .50624 L
.719 .50486 L
.72256 .49514 L
.7263 .48543 L
.72824 .48037 L
.72984 .47572 L
.73347 .46601 L
.73717 .45629 L
.73796 .45423 L
.74061 .44658 L
.74426 .43687 L
.74767 .42782 L
.74788 .42716 L
.75129 .41744 L
.75492 .40773 L
.75738 .40113 L
.75839 .39802 L
.76187 .38831 L
.76547 .37859 L
.76709 .37419 L
.76884 .36888 L
.77234 .35917 L
.77591 .34946 L
.77681 .34699 L
.7792 .33974 L
.7827 .33003 L
.78624 .32032 L
.78652 .31954 L
.78947 .31061 L
.79296 .30089 L
.79623 .29182 L
Mistroke
.79642 .29118 L
.79964 .28147 L
.80312 .27176 L
.80594 .26385 L
.80648 .26204 L
.80973 .25233 L
.81318 .24262 L
.81566 .23562 L
.81646 .23291 L
.81972 .22319 L
.82315 .21348 L
.82537 .20715 L
.82637 .20377 L
.82962 .19406 L
.83303 .18434 L
.83508 .17843 L
.8362 .17463 L
.83943 .16492 L
.84281 .15521 L
.84479 .14946 L
.84595 .14549 L
.84916 .13578 L
.85252 .12607 L
.85451 .12025 L
.85562 .11636 L
.85881 .10664 L
.86214 .09693 L
.86422 .0908 L
.86523 .08722 L
.86837 .07751 L
.87168 .06779 L
.87393 .06111 L
.87476 .05808 L
.87786 .04837 L
.88114 .03866 L
.88364 .03119 L
.88424 .02894 L
.88727 .01923 L
Mfstroke
.2 g
.53623 .98077 m
.54059 .97106 L
.54371 .96333 L
.54493 .96134 L
.54928 .95163 L
.55342 .94214 L
.55359 .94192 L
.55791 .93221 L
.56181 .92249 L
.56313 .92024 L
.56649 .91278 L
.5697 .90307 L
.57284 .89799 L
.57499 .89336 L
.57921 .88364 L
.58256 .87568 L
.58341 .87393 L
.58761 .86422 L
.59162 .85451 L
.59227 .85328 L
.59593 .84479 L
.59936 .83508 L
.60198 .83035 L
.60416 .82537 L
.60664 .81566 L
.61169 .80731 L
.61232 .80594 L
.61638 .79623 L
.62015 .78652 L
.62141 .78403 L
.62443 .77681 L
.62749 .76709 L
.63112 .76038 L
.63241 .75738 L
.63638 .74767 L
.64019 .73796 L
.64083 .73663 L
.64425 .72824 L
.64743 .71853 L
.65054 .71244 L
.65204 .70882 L
.65405 .69911 L
.65967 .68939 L
.66026 .68814 L
.66363 .67968 L
.66671 .66997 L
.66997 .66344 L
.67126 .66026 L
.67308 .65054 L
.67865 .64083 L
.67968 .63858 L
.6826 .63112 L
.68541 .62141 L
.68939 .6134 L
.69007 .61169 L
.69381 .60198 L
.69713 .59227 L
.69911 .58796 L
.7012 .58256 L
.7035 .57284 L
.70847 .56313 L
.70882 .56233 L
.71219 .55342 L
.71507 .54371 L
.71853 .53633 L
.71943 .53399 L
.72305 .52428 L
.72628 .51457 L
.72824 .51013 L
.73022 .50486 L
.73235 .49514 L
.73722 .48543 L
.73796 .4837 L
.74089 .47572 L
.74348 .46601 L
.74767 .45699 L
.74793 .45629 L
.75146 .44658 L
.75433 .43687 L
.75738 .42999 L
.75842 .42716 L
.7598 .41744 L
.76497 .40773 L
.76709 .40277 L
.76881 .39802 L
.77062 .38831 L
.77545 .37859 L
.77681 .37532 L
.7791 .36888 L
.78121 .35917 L
.78577 .34946 L
.78652 .34761 L
.78929 .33974 L
.79159 .33003 L
.79597 .32032 L
.79623 .31966 L
.79938 .31061 L
.80182 .30089 L
.80594 .29145 L
.80604 .29118 L
.80938 .28147 L
.8119 .27176 L
.81566 .26298 L
.81599 .26204 L
.8193 .25233 L
.82186 .24262 L
.82537 .23428 L
.82585 .23291 L
.82913 .22319 L
.83169 .21348 L
.83508 .20534 L
.83562 .20377 L
.83888 .19406 L
.84142 .18434 L
.84479 .17617 L
.84532 .17463 L
.84855 .16492 L
.85104 .15521 L
.85451 .14676 L
.85494 .14549 L
.85814 .13578 L
.86055 .12607 L
.86422 .11713 L
.86448 .11636 L
.86766 .10664 L
.86996 .09693 L
.87393 .08726 L
.87395 .08722 L
.87711 .07751 L
.87925 .06779 L
.8833 .05808 L
.88364 .05714 L
.88648 .04837 L
.88843 .03866 L
.89256 .02894 L
.89336 .02686 L
.89579 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.53623 .98077 m
.54059 .97106 L
.54371 .96333 L
.54493 .96134 L
.54928 .95163 L
.55342 .94214 L
.55359 .94192 L
.55791 .93221 L
.56181 .92249 L
.56313 .92024 L
.56649 .91278 L
.5697 .90307 L
.57284 .89799 L
.57499 .89336 L
.57921 .88364 L
.58256 .87568 L
.58341 .87393 L
.58761 .86422 L
.59162 .85451 L
.59227 .85328 L
.59593 .84479 L
.59936 .83508 L
.60198 .83035 L
.60416 .82537 L
.60664 .81566 L
.61169 .80731 L
.61232 .80594 L
.61638 .79623 L
.62015 .78652 L
.62141 .78403 L
.62443 .77681 L
.62749 .76709 L
.63112 .76038 L
.63241 .75738 L
.63638 .74767 L
.64019 .73796 L
.64083 .73663 L
.64425 .72824 L
.64743 .71853 L
.65054 .71244 L
.65204 .70882 L
.65405 .69911 L
.65967 .68939 L
.66026 .68814 L
.66363 .67968 L
.66671 .66997 L
.66997 .66344 L
.67126 .66026 L
.67308 .65054 L
.67865 .64083 L
Mistroke
.67968 .63858 L
.6826 .63112 L
.68541 .62141 L
.68939 .6134 L
.69007 .61169 L
.69381 .60198 L
.69713 .59227 L
.69911 .58796 L
.7012 .58256 L
.7035 .57284 L
.70847 .56313 L
.70882 .56233 L
.71219 .55342 L
.71507 .54371 L
.71853 .53633 L
.71943 .53399 L
.72305 .52428 L
.72628 .51457 L
.72824 .51013 L
.73022 .50486 L
.73235 .49514 L
.73722 .48543 L
.73796 .4837 L
.74089 .47572 L
.74348 .46601 L
.74767 .45699 L
.74793 .45629 L
.75146 .44658 L
.75433 .43687 L
.75738 .42999 L
.75842 .42716 L
.7598 .41744 L
.76497 .40773 L
.76709 .40277 L
.76881 .39802 L
.77062 .38831 L
.77545 .37859 L
.77681 .37532 L
.7791 .36888 L
.78121 .35917 L
.78577 .34946 L
.78652 .34761 L
.78929 .33974 L
.79159 .33003 L
.79597 .32032 L
.79623 .31966 L
.79938 .31061 L
.80182 .30089 L
.80594 .29145 L
.80604 .29118 L
Mistroke
.80938 .28147 L
.8119 .27176 L
.81566 .26298 L
.81599 .26204 L
.8193 .25233 L
.82186 .24262 L
.82537 .23428 L
.82585 .23291 L
.82913 .22319 L
.83169 .21348 L
.83508 .20534 L
.83562 .20377 L
.83888 .19406 L
.84142 .18434 L
.84479 .17617 L
.84532 .17463 L
.84855 .16492 L
.85104 .15521 L
.85451 .14676 L
.85494 .14549 L
.85814 .13578 L
.86055 .12607 L
.86422 .11713 L
.86448 .11636 L
.86766 .10664 L
.86996 .09693 L
.87393 .08726 L
.87395 .08722 L
.87711 .07751 L
.87925 .06779 L
.8833 .05808 L
.88364 .05714 L
.88648 .04837 L
.88843 .03866 L
.89256 .02894 L
.89336 .02686 L
.89579 .01923 L
Mfstroke
.3 g
.55558 .98077 m
.56059 .97106 L
.56313 .96641 L
.56552 .96134 L
.5704 .95163 L
.57284 .94699 L
.57521 .94192 L
.57997 .93221 L
.58256 .92712 L
.58468 .92249 L
.58934 .91278 L
.59227 .9068 L
.59487 .90307 L
.59852 .89336 L
.60198 .88606 L
.60351 .88364 L
.60753 .87393 L
.61169 .86492 L
.6121 .86422 L
.61639 .85451 L
.62079 .84479 L
.62141 .84353 L
.62512 .83508 L
.62944 .82537 L
.63112 .82172 L
.63494 .81566 L
.63796 .80594 L
.64083 .79946 L
.64266 .79623 L
.64637 .78652 L
.65054 .77683 L
.65056 .77681 L
.65467 .76709 L
.65879 .75738 L
.66026 .75403 L
.66392 .74767 L
.66693 .73796 L
.66997 .73074 L
.67126 .72824 L
.67497 .71853 L
.67898 .70882 L
.67968 .70718 L
.6843 .69911 L
.68688 .68939 L
.68939 .68329 L
.69122 .67968 L
.6947 .66997 L
.69861 .66026 L
.69911 .65906 L
.7038 .65054 L
.7063 .64083 L
.70882 .63454 L
.71049 .63112 L
.71393 .62141 L
.71773 .61169 L
.71853 .60971 L
.72254 .60198 L
.72524 .59227 L
.72824 .58455 L
.72917 .58256 L
.73269 .57284 L
.73641 .56313 L
.73796 .55915 L
.74072 .55342 L
.74375 .54371 L
.74743 .53399 L
.74767 .53339 L
.75228 .52428 L
.75468 .51457 L
.75738 .50739 L
.75852 .50486 L
.76385 .49514 L
.76547 .48543 L
.76709 .48111 L
.76957 .47572 L
.77258 .46601 L
.77614 .45629 L
.77681 .45452 L
.78055 .44658 L
.78316 .43687 L
.78652 .42763 L
.78672 .42716 L
.79146 .41744 L
.79363 .40773 L
.79623 .40052 L
.7973 .39802 L
.80227 .38831 L
.80398 .37859 L
.80594 .37313 L
.80777 .36888 L
.81081 .35917 L
.81423 .34946 L
.81566 .34546 L
.81813 .33974 L
.82099 .33003 L
.82437 .32032 L
.82537 .31752 L
.82838 .31061 L
.83106 .30089 L
.83442 .29118 L
.83508 .28931 L
.83851 .28147 L
.84104 .27176 L
.84437 .26204 L
.84479 .26084 L
.84851 .25233 L
.85093 .24262 L
.85423 .23291 L
.85451 .23212 L
.85839 .22319 L
.86073 .21348 L
.864 .20377 L
.86422 .20314 L
.86815 .19406 L
.87044 .18434 L
.87369 .17463 L
.87393 .17392 L
.87778 .16492 L
.88007 .15521 L
.88329 .14549 L
.88364 .14445 L
.88729 .13578 L
.88963 .12607 L
.89282 .11636 L
.89336 .11474 L
.8967 .10664 L
.8991 .09693 L
.90226 .08722 L
.90307 .08478 L
.90602 .07751 L
.9085 .06779 L
.91164 .05808 L
.91278 .05458 L
.91524 .04837 L
.91783 .03866 L
.92094 .02894 L
.92249 .02407 L
.92439 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.55558 .98077 m
.56059 .97106 L
.56313 .96641 L
.56552 .96134 L
.5704 .95163 L
.57284 .94699 L
.57521 .94192 L
.57997 .93221 L
.58256 .92712 L
.58468 .92249 L
.58934 .91278 L
.59227 .9068 L
.59487 .90307 L
.59852 .89336 L
.60198 .88606 L
.60351 .88364 L
.60753 .87393 L
.61169 .86492 L
.6121 .86422 L
.61639 .85451 L
.62079 .84479 L
.62141 .84353 L
.62512 .83508 L
.62944 .82537 L
.63112 .82172 L
.63494 .81566 L
.63796 .80594 L
.64083 .79946 L
.64266 .79623 L
.64637 .78652 L
.65054 .77683 L
.65056 .77681 L
.65467 .76709 L
.65879 .75738 L
.66026 .75403 L
.66392 .74767 L
.66693 .73796 L
.66997 .73074 L
.67126 .72824 L
.67497 .71853 L
.67898 .70882 L
.67968 .70718 L
.6843 .69911 L
.68688 .68939 L
.68939 .68329 L
.69122 .67968 L
.6947 .66997 L
.69861 .66026 L
.69911 .65906 L
.7038 .65054 L
Mistroke
.7063 .64083 L
.70882 .63454 L
.71049 .63112 L
.71393 .62141 L
.71773 .61169 L
.71853 .60971 L
.72254 .60198 L
.72524 .59227 L
.72824 .58455 L
.72917 .58256 L
.73269 .57284 L
.73641 .56313 L
.73796 .55915 L
.74072 .55342 L
.74375 .54371 L
.74743 .53399 L
.74767 .53339 L
.75228 .52428 L
.75468 .51457 L
.75738 .50739 L
.75852 .50486 L
.76385 .49514 L
.76547 .48543 L
.76709 .48111 L
.76957 .47572 L
.77258 .46601 L
.77614 .45629 L
.77681 .45452 L
.78055 .44658 L
.78316 .43687 L
.78652 .42763 L
.78672 .42716 L
.79146 .41744 L
.79363 .40773 L
.79623 .40052 L
.7973 .39802 L
.80227 .38831 L
.80398 .37859 L
.80594 .37313 L
.80777 .36888 L
.81081 .35917 L
.81423 .34946 L
.81566 .34546 L
.81813 .33974 L
.82099 .33003 L
.82437 .32032 L
.82537 .31752 L
.82838 .31061 L
.83106 .30089 L
.83442 .29118 L
Mistroke
.83508 .28931 L
.83851 .28147 L
.84104 .27176 L
.84437 .26204 L
.84479 .26084 L
.84851 .25233 L
.85093 .24262 L
.85423 .23291 L
.85451 .23212 L
.85839 .22319 L
.86073 .21348 L
.864 .20377 L
.86422 .20314 L
.86815 .19406 L
.87044 .18434 L
.87369 .17463 L
.87393 .17392 L
.87778 .16492 L
.88007 .15521 L
.88329 .14549 L
.88364 .14445 L
.88729 .13578 L
.88963 .12607 L
.89282 .11636 L
.89336 .11474 L
.8967 .10664 L
.8991 .09693 L
.90226 .08722 L
.90307 .08478 L
.90602 .07751 L
.9085 .06779 L
.91164 .05808 L
.91278 .05458 L
.91524 .04837 L
.91783 .03866 L
.92094 .02894 L
.92249 .02407 L
.92439 .01923 L
Mfstroke
.4 g
.57502 .98077 m
.57965 .97106 L
.58256 .96454 L
.58407 .96134 L
.58865 .95163 L
.59227 .94345 L
.59298 .94192 L
.59751 .93221 L
.60178 .92249 L
.60198 .92201 L
.60623 .91278 L
.61054 .90307 L
.61169 .90024 L
.61482 .89336 L
.61914 .88364 L
.62141 .87814 L
.62328 .87393 L
.6276 .86422 L
.63112 .8557 L
.63164 .85451 L
.63592 .84479 L
.64001 .83508 L
.64083 .83295 L
.64413 .82537 L
.64827 .81566 L
.65054 .80987 L
.65223 .80594 L
.65638 .79623 L
.66024 .78652 L
.66026 .78648 L
.66436 .77681 L
.66835 .76709 L
.66997 .76279 L
.67223 .75738 L
.67627 .74767 L
.67968 .73878 L
.68002 .73796 L
.68404 .72824 L
.68793 .71853 L
.68939 .71449 L
.69171 .70882 L
.69565 .69911 L
.69911 .68988 L
.6993 .68939 L
.70323 .67968 L
.70705 .66997 L
.70882 .665 L
.71071 .66026 L
.71458 .65054 L
.71819 .64083 L
.71853 .63981 L
.72197 .63112 L
.72575 .62141 L
.72824 .61435 L
.72928 .61169 L
.73308 .60198 L
.73673 .59227 L
.73796 .5886 L
.74029 .58256 L
.74404 .57284 L
.74749 .56313 L
.74767 .56257 L
.75118 .55342 L
.75485 .54371 L
.75738 .53626 L
.75824 .53399 L
.76193 .52428 L
.7655 .51457 L
.76709 .50969 L
.76891 .50486 L
.77256 .49514 L
.776 .48543 L
.77681 .48284 L
.77946 .47572 L
.78306 .46601 L
.78635 .45629 L
.78652 .45572 L
.78989 .44658 L
.79344 .43687 L
.79623 .42834 L
.79666 .42716 L
.80022 .41744 L
.80371 .40773 L
.80594 .4007 L
.80691 .39802 L
.81044 .38831 L
.81387 .37859 L
.81566 .37279 L
.81706 .36888 L
.82056 .35917 L
.82392 .34946 L
.82537 .34463 L
.82711 .33974 L
.83058 .33003 L
.83388 .32032 L
.83508 .31622 L
.83706 .31061 L
.8405 .30089 L
.84376 .29118 L
.84479 .28755 L
.84692 .28147 L
.85034 .27176 L
.85355 .26204 L
.85451 .25863 L
.85669 .25233 L
.86008 .24262 L
.86327 .23291 L
.86422 .22947 L
.86638 .22319 L
.86974 .21348 L
.87291 .20377 L
.87393 .20005 L
.87598 .19406 L
.87932 .18434 L
.88248 .17463 L
.88364 .1704 L
.8855 .16492 L
.88882 .15521 L
.89199 .14549 L
.89336 .1405 L
.89494 .13578 L
.89824 .12607 L
.90141 .11636 L
.90307 .11036 L
.90431 .10664 L
.90758 .09693 L
.91077 .08722 L
.91278 .07999 L
.9136 .07751 L
.91684 .06779 L
.92004 .05808 L
.92249 .04937 L
.92282 .04837 L
.92604 .03866 L
.92924 .02894 L
.93205 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.57502 .98077 m
.57965 .97106 L
.58256 .96454 L
.58407 .96134 L
.58865 .95163 L
.59227 .94345 L
.59298 .94192 L
.59751 .93221 L
.60178 .92249 L
.60198 .92201 L
.60623 .91278 L
.61054 .90307 L
.61169 .90024 L
.61482 .89336 L
.61914 .88364 L
.62141 .87814 L
.62328 .87393 L
.6276 .86422 L
.63112 .8557 L
.63164 .85451 L
.63592 .84479 L
.64001 .83508 L
.64083 .83295 L
.64413 .82537 L
.64827 .81566 L
.65054 .80987 L
.65223 .80594 L
.65638 .79623 L
.66024 .78652 L
.66026 .78648 L
.66436 .77681 L
.66835 .76709 L
.66997 .76279 L
.67223 .75738 L
.67627 .74767 L
.67968 .73878 L
.68002 .73796 L
.68404 .72824 L
.68793 .71853 L
.68939 .71449 L
.69171 .70882 L
.69565 .69911 L
.69911 .68988 L
.6993 .68939 L
.70323 .67968 L
.70705 .66997 L
.70882 .665 L
.71071 .66026 L
.71458 .65054 L
.71819 .64083 L
Mistroke
.71853 .63981 L
.72197 .63112 L
.72575 .62141 L
.72824 .61435 L
.72928 .61169 L
.73308 .60198 L
.73673 .59227 L
.73796 .5886 L
.74029 .58256 L
.74404 .57284 L
.74749 .56313 L
.74767 .56257 L
.75118 .55342 L
.75485 .54371 L
.75738 .53626 L
.75824 .53399 L
.76193 .52428 L
.7655 .51457 L
.76709 .50969 L
.76891 .50486 L
.77256 .49514 L
.776 .48543 L
.77681 .48284 L
.77946 .47572 L
.78306 .46601 L
.78635 .45629 L
.78652 .45572 L
.78989 .44658 L
.79344 .43687 L
.79623 .42834 L
.79666 .42716 L
.80022 .41744 L
.80371 .40773 L
.80594 .4007 L
.80691 .39802 L
.81044 .38831 L
.81387 .37859 L
.81566 .37279 L
.81706 .36888 L
.82056 .35917 L
.82392 .34946 L
.82537 .34463 L
.82711 .33974 L
.83058 .33003 L
.83388 .32032 L
.83508 .31622 L
.83706 .31061 L
.8405 .30089 L
.84376 .29118 L
.84479 .28755 L
Mistroke
.84692 .28147 L
.85034 .27176 L
.85355 .26204 L
.85451 .25863 L
.85669 .25233 L
.86008 .24262 L
.86327 .23291 L
.86422 .22947 L
.86638 .22319 L
.86974 .21348 L
.87291 .20377 L
.87393 .20005 L
.87598 .19406 L
.87932 .18434 L
.88248 .17463 L
.88364 .1704 L
.8855 .16492 L
.88882 .15521 L
.89199 .14549 L
.89336 .1405 L
.89494 .13578 L
.89824 .12607 L
.90141 .11636 L
.90307 .11036 L
.90431 .10664 L
.90758 .09693 L
.91077 .08722 L
.91278 .07999 L
.9136 .07751 L
.91684 .06779 L
.92004 .05808 L
.92249 .04937 L
.92282 .04837 L
.92604 .03866 L
.92924 .02894 L
.93205 .01923 L
Mfstroke
.5 g
.5869 .98077 m
.5913 .97106 L
.59227 .96889 L
.59569 .96134 L
.60004 .95163 L
.60198 .94723 L
.60435 .94192 L
.60866 .93221 L
.61169 .92524 L
.6129 .92249 L
.61716 .91278 L
.62134 .90307 L
.62141 .90292 L
.62555 .89336 L
.62971 .88364 L
.63112 .88029 L
.63384 .87393 L
.63796 .86422 L
.64083 .85734 L
.64203 .85451 L
.64611 .84479 L
.65014 .83508 L
.65054 .83408 L
.65417 .82537 L
.65818 .81566 L
.66026 .81051 L
.66213 .80594 L
.66611 .79623 L
.66997 .78664 L
.67002 .78652 L
.67396 .77681 L
.67786 .76709 L
.67968 .76248 L
.68172 .75738 L
.68561 .74767 L
.68939 .73801 L
.68942 .73796 L
.69326 .72824 L
.69708 .71853 L
.69911 .71326 L
.70084 .70882 L
.70464 .69911 L
.70837 .68939 L
.70882 .68821 L
.71212 .67968 L
.71586 .66997 L
.71853 .66288 L
.71954 .66026 L
.72326 .65054 L
.72693 .64083 L
.72824 .63728 L
.73058 .63112 L
.73425 .62141 L
.73784 .61169 L
.73796 .61139 L
.74148 .60198 L
.7451 .59227 L
.74767 .58522 L
.74866 .58256 L
.75226 .57284 L
.75583 .56313 L
.75738 .55879 L
.75935 .55342 L
.76292 .54371 L
.76642 .53399 L
.76709 .53208 L
.76993 .52428 L
.77345 .51457 L
.77681 .50511 L
.7769 .50486 L
.7804 .49514 L
.78388 .48543 L
.78652 .47787 L
.78728 .47572 L
.79075 .46601 L
.79419 .45629 L
.79623 .45037 L
.79757 .44658 L
.801 .43687 L
.8044 .42716 L
.80594 .42261 L
.80775 .41744 L
.81116 .40773 L
.81451 .39802 L
.81566 .3946 L
.81784 .38831 L
.82121 .37859 L
.82452 .36888 L
.82537 .36633 L
.82783 .35917 L
.83117 .34946 L
.83445 .33974 L
.83508 .3378 L
.83773 .33003 L
.84104 .32032 L
.84428 .31061 L
.84479 .30903 L
.84754 .30089 L
.85083 .29118 L
.85404 .28147 L
.85451 .28001 L
.85727 .27176 L
.86053 .26204 L
.86372 .25233 L
.86422 .25074 L
.86692 .24262 L
.87015 .23291 L
.87331 .22319 L
.87393 .22123 L
.87649 .21348 L
.8797 .20377 L
.88284 .19406 L
.88364 .19148 L
.88598 .18434 L
.88916 .17463 L
.89229 .16492 L
.89336 .16149 L
.89539 .15521 L
.89856 .14549 L
.90167 .13578 L
.90307 .13126 L
.90474 .12607 L
.90788 .11636 L
.91098 .10664 L
.91278 .1008 L
.91401 .09693 L
.91713 .08722 L
.92022 .07751 L
.92249 .0701 L
.92322 .06779 L
.92631 .05808 L
.92939 .04837 L
.93221 .03916 L
.93237 .03866 L
.93543 .02894 L
.93849 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.5869 .98077 m
.5913 .97106 L
.59227 .96889 L
.59569 .96134 L
.60004 .95163 L
.60198 .94723 L
.60435 .94192 L
.60866 .93221 L
.61169 .92524 L
.6129 .92249 L
.61716 .91278 L
.62134 .90307 L
.62141 .90292 L
.62555 .89336 L
.62971 .88364 L
.63112 .88029 L
.63384 .87393 L
.63796 .86422 L
.64083 .85734 L
.64203 .85451 L
.64611 .84479 L
.65014 .83508 L
.65054 .83408 L
.65417 .82537 L
.65818 .81566 L
.66026 .81051 L
.66213 .80594 L
.66611 .79623 L
.66997 .78664 L
.67002 .78652 L
.67396 .77681 L
.67786 .76709 L
.67968 .76248 L
.68172 .75738 L
.68561 .74767 L
.68939 .73801 L
.68942 .73796 L
.69326 .72824 L
.69708 .71853 L
.69911 .71326 L
.70084 .70882 L
.70464 .69911 L
.70837 .68939 L
.70882 .68821 L
.71212 .67968 L
.71586 .66997 L
.71853 .66288 L
.71954 .66026 L
.72326 .65054 L
.72693 .64083 L
Mistroke
.72824 .63728 L
.73058 .63112 L
.73425 .62141 L
.73784 .61169 L
.73796 .61139 L
.74148 .60198 L
.7451 .59227 L
.74767 .58522 L
.74866 .58256 L
.75226 .57284 L
.75583 .56313 L
.75738 .55879 L
.75935 .55342 L
.76292 .54371 L
.76642 .53399 L
.76709 .53208 L
.76993 .52428 L
.77345 .51457 L
.77681 .50511 L
.7769 .50486 L
.7804 .49514 L
.78388 .48543 L
.78652 .47787 L
.78728 .47572 L
.79075 .46601 L
.79419 .45629 L
.79623 .45037 L
.79757 .44658 L
.801 .43687 L
.8044 .42716 L
.80594 .42261 L
.80775 .41744 L
.81116 .40773 L
.81451 .39802 L
.81566 .3946 L
.81784 .38831 L
.82121 .37859 L
.82452 .36888 L
.82537 .36633 L
.82783 .35917 L
.83117 .34946 L
.83445 .33974 L
.83508 .3378 L
.83773 .33003 L
.84104 .32032 L
.84428 .31061 L
.84479 .30903 L
.84754 .30089 L
.85083 .29118 L
.85404 .28147 L
Mistroke
.85451 .28001 L
.85727 .27176 L
.86053 .26204 L
.86372 .25233 L
.86422 .25074 L
.86692 .24262 L
.87015 .23291 L
.87331 .22319 L
.87393 .22123 L
.87649 .21348 L
.8797 .20377 L
.88284 .19406 L
.88364 .19148 L
.88598 .18434 L
.88916 .17463 L
.89229 .16492 L
.89336 .16149 L
.89539 .15521 L
.89856 .14549 L
.90167 .13578 L
.90307 .13126 L
.90474 .12607 L
.90788 .11636 L
.91098 .10664 L
.91278 .1008 L
.91401 .09693 L
.91713 .08722 L
.92022 .07751 L
.92249 .0701 L
.92322 .06779 L
.92631 .05808 L
.92939 .04837 L
.93221 .03916 L
.93237 .03866 L
.93543 .02894 L
.93849 .01923 L
Mfstroke
.6 g
.59748 .98077 m
.6018 .97106 L
.60198 .97064 L
.60606 .96134 L
.61032 .95163 L
.61169 .94847 L
.61452 .94192 L
.61873 .93221 L
.62141 .92599 L
.62289 .92249 L
.62704 .91278 L
.63112 .9032 L
.63117 .90307 L
.63525 .89336 L
.63934 .88364 L
.64083 .88009 L
.64338 .87393 L
.64742 .86422 L
.65054 .85668 L
.65143 .85451 L
.65541 .84479 L
.6594 .83508 L
.66026 .83297 L
.66332 .82537 L
.66726 .81566 L
.66997 .80896 L
.67116 .80594 L
.67505 .79623 L
.67894 .78652 L
.67968 .78465 L
.68277 .77681 L
.68662 .76709 L
.68939 .76005 L
.69043 .75738 L
.69422 .74767 L
.69802 .73796 L
.69911 .73517 L
.70177 .72824 L
.70553 .71853 L
.70882 .71 L
.70926 .70882 L
.71297 .69911 L
.71669 .68939 L
.71853 .68455 L
.72035 .67968 L
.72403 .66997 L
.72771 .66026 L
.72824 .65882 L
.73132 .65054 L
.73497 .64083 L
.73796 .63282 L
.73858 .63112 L
.74216 .62141 L
.74577 .61169 L
.74767 .60654 L
.74932 .60198 L
.75288 .59227 L
.75645 .58256 L
.75738 .58 L
.75995 .57284 L
.76349 .56313 L
.76701 .55342 L
.76709 .55319 L
.77047 .54371 L
.77398 .53399 L
.77681 .52611 L
.77744 .52428 L
.78089 .51457 L
.78436 .50486 L
.78652 .49877 L
.78777 .49514 L
.7912 .48543 L
.79464 .47572 L
.79623 .47117 L
.79801 .46601 L
.80141 .45629 L
.80481 .44658 L
.80594 .44332 L
.80814 .43687 L
.81152 .42716 L
.81489 .41744 L
.81566 .41521 L
.81818 .40773 L
.82153 .39802 L
.82487 .38831 L
.82537 .38684 L
.82814 .37859 L
.83146 .36888 L
.83477 .35917 L
.83508 .35823 L
.838 .34946 L
.8413 .33974 L
.84457 .33003 L
.84479 .32937 L
.84778 .32032 L
.85105 .31061 L
.8543 .30089 L
.85451 .30026 L
.85747 .29118 L
.86072 .28147 L
.86394 .27176 L
.86422 .27091 L
.86709 .26204 L
.87031 .25233 L
.87351 .24262 L
.87393 .24132 L
.87663 .23291 L
.87982 .22319 L
.883 .21348 L
.88364 .21149 L
.88609 .20377 L
.88926 .19406 L
.89242 .18434 L
.89336 .18141 L
.89549 .17463 L
.89862 .16492 L
.90176 .15521 L
.90307 .15111 L
.90481 .14549 L
.90792 .13578 L
.91104 .12607 L
.91278 .12056 L
.91407 .11636 L
.91714 .10664 L
.92024 .09693 L
.92249 .08979 L
.92327 .08722 L
.9263 .07751 L
.92938 .06779 L
.93221 .05879 L
.93242 .05808 L
.9354 .04837 L
.93845 .03866 L
.94149 .02894 L
.94192 .02755 L
.94443 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.59748 .98077 m
.6018 .97106 L
.60198 .97064 L
.60606 .96134 L
.61032 .95163 L
.61169 .94847 L
.61452 .94192 L
.61873 .93221 L
.62141 .92599 L
.62289 .92249 L
.62704 .91278 L
.63112 .9032 L
.63117 .90307 L
.63525 .89336 L
.63934 .88364 L
.64083 .88009 L
.64338 .87393 L
.64742 .86422 L
.65054 .85668 L
.65143 .85451 L
.65541 .84479 L
.6594 .83508 L
.66026 .83297 L
.66332 .82537 L
.66726 .81566 L
.66997 .80896 L
.67116 .80594 L
.67505 .79623 L
.67894 .78652 L
.67968 .78465 L
.68277 .77681 L
.68662 .76709 L
.68939 .76005 L
.69043 .75738 L
.69422 .74767 L
.69802 .73796 L
.69911 .73517 L
.70177 .72824 L
.70553 .71853 L
.70882 .71 L
.70926 .70882 L
.71297 .69911 L
.71669 .68939 L
.71853 .68455 L
.72035 .67968 L
.72403 .66997 L
.72771 .66026 L
.72824 .65882 L
.73132 .65054 L
.73497 .64083 L
Mistroke
.73796 .63282 L
.73858 .63112 L
.74216 .62141 L
.74577 .61169 L
.74767 .60654 L
.74932 .60198 L
.75288 .59227 L
.75645 .58256 L
.75738 .58 L
.75995 .57284 L
.76349 .56313 L
.76701 .55342 L
.76709 .55319 L
.77047 .54371 L
.77398 .53399 L
.77681 .52611 L
.77744 .52428 L
.78089 .51457 L
.78436 .50486 L
.78652 .49877 L
.78777 .49514 L
.7912 .48543 L
.79464 .47572 L
.79623 .47117 L
.79801 .46601 L
.80141 .45629 L
.80481 .44658 L
.80594 .44332 L
.80814 .43687 L
.81152 .42716 L
.81489 .41744 L
.81566 .41521 L
.81818 .40773 L
.82153 .39802 L
.82487 .38831 L
.82537 .38684 L
.82814 .37859 L
.83146 .36888 L
.83477 .35917 L
.83508 .35823 L
.838 .34946 L
.8413 .33974 L
.84457 .33003 L
.84479 .32937 L
.84778 .32032 L
.85105 .31061 L
.8543 .30089 L
.85451 .30026 L
.85747 .29118 L
.86072 .28147 L
Mistroke
.86394 .27176 L
.86422 .27091 L
.86709 .26204 L
.87031 .25233 L
.87351 .24262 L
.87393 .24132 L
.87663 .23291 L
.87982 .22319 L
.883 .21348 L
.88364 .21149 L
.88609 .20377 L
.88926 .19406 L
.89242 .18434 L
.89336 .18141 L
.89549 .17463 L
.89862 .16492 L
.90176 .15521 L
.90307 .15111 L
.90481 .14549 L
.90792 .13578 L
.91104 .12607 L
.91278 .12056 L
.91407 .11636 L
.91714 .10664 L
.92024 .09693 L
.92249 .08979 L
.92327 .08722 L
.9263 .07751 L
.92938 .06779 L
.93221 .05879 L
.93242 .05808 L
.9354 .04837 L
.93845 .03866 L
.94149 .02894 L
.94192 .02755 L
.94443 .01923 L
Mfstroke
.7 g
.60848 .98077 m
.61169 .97348 L
.61267 .97106 L
.61681 .96134 L
.62104 .95163 L
.62141 .95078 L
.62506 .94192 L
.62923 .93221 L
.63112 .92778 L
.63323 .92249 L
.63732 .91278 L
.64083 .90449 L
.64137 .90307 L
.64532 .89336 L
.6494 .88364 L
.65054 .88089 L
.65326 .87393 L
.65727 .86422 L
.66026 .857 L
.66119 .85451 L
.66506 .84479 L
.66905 .83508 L
.66997 .83281 L
.6728 .82537 L
.67672 .81566 L
.67968 .80834 L
.68055 .80594 L
.68433 .79623 L
.68822 .78652 L
.68939 .78358 L
.69189 .77681 L
.69572 .76709 L
.69911 .75854 L
.69951 .75738 L
.70315 .74767 L
.70697 .73796 L
.70882 .73322 L
.71058 .72824 L
.71429 .71853 L
.71807 .70882 L
.71853 .70763 L
.72158 .69911 L
.72531 .68939 L
.72824 .68175 L
.72894 .67968 L
.73249 .66997 L
.73619 .66026 L
.73796 .65561 L
.73968 .65054 L
.74328 .64083 L
.74695 .63112 L
.74767 .6292 L
.75035 .62141 L
.75396 .61169 L
.75738 .60252 L
.75755 .60198 L
.76092 .59227 L
.76452 .58256 L
.76709 .57558 L
.76796 .57284 L
.77139 .56313 L
.77496 .55342 L
.77681 .54838 L
.77831 .54371 L
.78176 .53399 L
.7853 .52428 L
.78652 .52092 L
.78857 .51457 L
.79203 .50486 L
.79554 .49514 L
.79623 .4932 L
.79874 .48543 L
.80219 .47572 L
.80567 .46601 L
.80594 .46523 L
.80883 .45629 L
.81226 .44658 L
.81566 .43701 L
.8157 .43687 L
.81882 .42716 L
.82224 .41744 L
.82537 .40854 L
.8256 .40773 L
.82873 .39802 L
.83212 .38831 L
.83508 .37982 L
.83542 .37859 L
.83855 .36888 L
.84192 .35917 L
.84479 .35085 L
.84518 .34946 L
.84828 .33974 L
.85163 .33003 L
.85451 .32164 L
.85487 .32032 L
.85793 .31061 L
.86126 .30089 L
.86422 .29219 L
.86449 .29118 L
.86751 .28147 L
.8708 .27176 L
.87393 .2625 L
.87405 .26204 L
.877 .25233 L
.88027 .24262 L
.88353 .23291 L
.88364 .23257 L
.88642 .22319 L
.88966 .21348 L
.89291 .20377 L
.89336 .20241 L
.89578 .19406 L
.89898 .18434 L
.90221 .17463 L
.90307 .17201 L
.90507 .16492 L
.90822 .15521 L
.91144 .14549 L
.91278 .14137 L
.9143 .13578 L
.9174 .12607 L
.9206 .11636 L
.92249 .11051 L
.9235 .10664 L
.92651 .09693 L
.92968 .08722 L
.93221 .07942 L
.93267 .07751 L
.93555 .06779 L
.9387 .05808 L
.94184 .04837 L
.94192 .04811 L
.94455 .03866 L
.94766 .02894 L
.95078 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.60848 .98077 m
.61169 .97348 L
.61267 .97106 L
.61681 .96134 L
.62104 .95163 L
.62141 .95078 L
.62506 .94192 L
.62923 .93221 L
.63112 .92778 L
.63323 .92249 L
.63732 .91278 L
.64083 .90449 L
.64137 .90307 L
.64532 .89336 L
.6494 .88364 L
.65054 .88089 L
.65326 .87393 L
.65727 .86422 L
.66026 .857 L
.66119 .85451 L
.66506 .84479 L
.66905 .83508 L
.66997 .83281 L
.6728 .82537 L
.67672 .81566 L
.67968 .80834 L
.68055 .80594 L
.68433 .79623 L
.68822 .78652 L
.68939 .78358 L
.69189 .77681 L
.69572 .76709 L
.69911 .75854 L
.69951 .75738 L
.70315 .74767 L
.70697 .73796 L
.70882 .73322 L
.71058 .72824 L
.71429 .71853 L
.71807 .70882 L
.71853 .70763 L
.72158 .69911 L
.72531 .68939 L
.72824 .68175 L
.72894 .67968 L
.73249 .66997 L
.73619 .66026 L
.73796 .65561 L
.73968 .65054 L
.74328 .64083 L
Mistroke
.74695 .63112 L
.74767 .6292 L
.75035 .62141 L
.75396 .61169 L
.75738 .60252 L
.75755 .60198 L
.76092 .59227 L
.76452 .58256 L
.76709 .57558 L
.76796 .57284 L
.77139 .56313 L
.77496 .55342 L
.77681 .54838 L
.77831 .54371 L
.78176 .53399 L
.7853 .52428 L
.78652 .52092 L
.78857 .51457 L
.79203 .50486 L
.79554 .49514 L
.79623 .4932 L
.79874 .48543 L
.80219 .47572 L
.80567 .46601 L
.80594 .46523 L
.80883 .45629 L
.81226 .44658 L
.81566 .43701 L
.8157 .43687 L
.81882 .42716 L
.82224 .41744 L
.82537 .40854 L
.8256 .40773 L
.82873 .39802 L
.83212 .38831 L
.83508 .37982 L
.83542 .37859 L
.83855 .36888 L
.84192 .35917 L
.84479 .35085 L
.84518 .34946 L
.84828 .33974 L
.85163 .33003 L
.85451 .32164 L
.85487 .32032 L
.85793 .31061 L
.86126 .30089 L
.86422 .29219 L
.86449 .29118 L
.86751 .28147 L
Mistroke
.8708 .27176 L
.87393 .2625 L
.87405 .26204 L
.877 .25233 L
.88027 .24262 L
.88353 .23291 L
.88364 .23257 L
.88642 .22319 L
.88966 .21348 L
.89291 .20377 L
.89336 .20241 L
.89578 .19406 L
.89898 .18434 L
.90221 .17463 L
.90307 .17201 L
.90507 .16492 L
.90822 .15521 L
.91144 .14549 L
.91278 .14137 L
.9143 .13578 L
.9174 .12607 L
.9206 .11636 L
.92249 .11051 L
.9235 .10664 L
.92651 .09693 L
.92968 .08722 L
.93221 .07942 L
.93267 .07751 L
.93555 .06779 L
.9387 .05808 L
.94184 .04837 L
.94192 .04811 L
.94455 .03866 L
.94766 .02894 L
.95078 .01923 L
Mfstroke
.8 g
.62337 .98077 m
.62572 .97106 L
.63112 .96185 L
.63134 .96134 L
.63533 .95163 L
.63885 .94192 L
.64083 .93795 L
.6432 .93221 L
.64584 .92249 L
.65054 .91387 L
.65101 .91278 L
.6549 .90307 L
.65838 .89336 L
.66026 .88948 L
.66261 .88364 L
.66519 .87393 L
.66997 .86487 L
.67024 .86422 L
.67406 .85451 L
.67736 .84479 L
.67968 .83993 L
.6816 .83508 L
.68386 .82537 L
.68902 .81566 L
.68939 .81482 L
.69282 .80594 L
.69581 .79623 L
.69911 .78934 L
.70021 .78652 L
.70183 .77681 L
.70728 .76709 L
.70882 .76367 L
.71122 .75738 L
.71366 .74767 L
.71845 .73796 L
.71853 .73777 L
.72209 .72824 L
.72501 .71853 L
.72824 .71151 L
.72927 .70882 L
.73074 .69911 L
.73606 .68939 L
.73796 .68506 L
.73995 .67968 L
.74205 .66997 L
.74687 .66026 L
.74767 .65837 L
.75052 .65054 L
.75303 .64083 L
.75738 .63142 L
.75749 .63112 L
.76099 .62141 L
.76376 .61169 L
.76709 .60416 L
.76789 .60198 L
.77135 .59227 L
.77429 .58256 L
.77681 .57669 L
.77819 .57284 L
.77973 .56313 L
.78467 .55342 L
.78652 .54897 L
.78838 .54371 L
.79021 .53399 L
.7949 .52428 L
.79623 .52102 L
.79849 .51457 L
.80049 .50486 L
.80501 .49514 L
.80594 .49282 L
.8085 .48543 L
.81062 .47572 L
.81501 .46601 L
.81566 .46437 L
.81842 .45629 L
.82061 .44658 L
.82491 .43687 L
.82537 .43568 L
.82826 .42716 L
.83047 .41744 L
.8347 .40773 L
.83508 .40675 L
.83802 .39802 L
.84021 .38831 L
.8444 .37859 L
.84479 .37757 L
.8477 .36888 L
.84983 .35917 L
.85401 .34946 L
.85451 .34816 L
.8573 .33974 L
.85933 .33003 L
.86353 .32032 L
.86422 .31851 L
.86682 .31061 L
.86872 .30089 L
.87296 .29118 L
.87393 .28862 L
.87627 .28147 L
.87799 .27176 L
.8823 .26204 L
.88364 .2585 L
.88565 .25233 L
.88712 .24262 L
.89155 .23291 L
.89336 .22816 L
.89496 .22319 L
.89611 .21348 L
.9007 .20377 L
.90307 .19758 L
.90421 .19406 L
.90729 .18434 L
.90974 .17463 L
.91278 .16679 L
.91338 .16492 L
.91645 .15521 L
.91866 .14549 L
.92249 .13579 L
.9225 .13578 L
.92555 .12607 L
.92744 .11636 L
.93144 .10664 L
.93221 .10452 L
.93458 .09693 L
.93606 .08722 L
.94028 .07751 L
.94192 .07304 L
.94356 .06779 L
.94447 .05808 L
.949 .04837 L
.95163 .04134 L
.95247 .03866 L
.95545 .02894 L
.95758 .01923 L
.98077 .01923 L
.98077 .98077 L
F
0 g
.62337 .98077 m
.62572 .97106 L
.63112 .96185 L
.63134 .96134 L
.63533 .95163 L
.63885 .94192 L
.64083 .93795 L
.6432 .93221 L
.64584 .92249 L
.65054 .91387 L
.65101 .91278 L
.6549 .90307 L
.65838 .89336 L
.66026 .88948 L
.66261 .88364 L
.66519 .87393 L
.66997 .86487 L
.67024 .86422 L
.67406 .85451 L
.67736 .84479 L
.67968 .83993 L
.6816 .83508 L
.68386 .82537 L
.68902 .81566 L
.68939 .81482 L
.69282 .80594 L
.69581 .79623 L
.69911 .78934 L
.70021 .78652 L
.70183 .77681 L
.70728 .76709 L
.70882 .76367 L
.71122 .75738 L
.71366 .74767 L
.71845 .73796 L
.71853 .73777 L
.72209 .72824 L
.72501 .71853 L
.72824 .71151 L
.72927 .70882 L
.73074 .69911 L
.73606 .68939 L
.73796 .68506 L
.73995 .67968 L
.74205 .66997 L
.74687 .66026 L
.74767 .65837 L
.75052 .65054 L
.75303 .64083 L
.75738 .63142 L
Mistroke
.75749 .63112 L
.76099 .62141 L
.76376 .61169 L
.76709 .60416 L
.76789 .60198 L
.77135 .59227 L
.77429 .58256 L
.77681 .57669 L
.77819 .57284 L
.77973 .56313 L
.78467 .55342 L
.78652 .54897 L
.78838 .54371 L
.79021 .53399 L
.7949 .52428 L
.79623 .52102 L
.79849 .51457 L
.80049 .50486 L
.80501 .49514 L
.80594 .49282 L
.8085 .48543 L
.81062 .47572 L
.81501 .46601 L
.81566 .46437 L
.81842 .45629 L
.82061 .44658 L
.82491 .43687 L
.82537 .43568 L
.82826 .42716 L
.83047 .41744 L
.8347 .40773 L
.83508 .40675 L
.83802 .39802 L
.84021 .38831 L
.8444 .37859 L
.84479 .37757 L
.8477 .36888 L
.84983 .35917 L
.85401 .34946 L
.85451 .34816 L
.8573 .33974 L
.85933 .33003 L
.86353 .32032 L
.86422 .31851 L
.86682 .31061 L
.86872 .30089 L
.87296 .29118 L
.87393 .28862 L
.87627 .28147 L
.87799 .27176 L
Mistroke
.8823 .26204 L
.88364 .2585 L
.88565 .25233 L
.88712 .24262 L
.89155 .23291 L
.89336 .22816 L
.89496 .22319 L
.89611 .21348 L
.9007 .20377 L
.90307 .19758 L
.90421 .19406 L
.90729 .18434 L
.90974 .17463 L
.91278 .16679 L
.91338 .16492 L
.91645 .15521 L
.91866 .14549 L
.92249 .13579 L
.9225 .13578 L
.92555 .12607 L
.92744 .11636 L
.93144 .10664 L
.93221 .10452 L
.93458 .09693 L
.93606 .08722 L
.94028 .07751 L
.94192 .07304 L
.94356 .06779 L
.94447 .05808 L
.949 .04837 L
.95163 .04134 L
.95247 .03866 L
.95545 .02894 L
.95758 .01923 L
Mfstroke
.7 g
.98077 .03787 m
.98054 .03866 L
.97764 .04837 L
.97466 .05808 L
.97165 .06779 L
.97106 .06972 L
.96864 .07751 L
.96736 .08722 L
.96299 .09693 L
.96134 .10135 L
.95968 .10664 L
.95667 .11636 L
.95421 .12607 L
.95163 .13275 L
.95067 .13578 L
.94762 .14549 L
.94539 .15521 L
.94192 .16389 L
.94159 .16492 L
.93852 .17463 L
.93652 .18434 L
.93248 .19406 L
.93221 .1948 L
.92935 .20377 L
.92761 .21348 L
.92336 .22319 L
.92249 .2255 L
.92011 .23291 L
.91863 .24262 L
.91418 .25233 L
.91278 .25596 L
.9108 .26204 L
.90957 .27176 L
.90491 .28147 L
.90307 .28617 L
.90142 .29118 L
.90041 .30089 L
.89557 .31061 L
.89336 .31613 L
.89197 .32032 L
.88878 .33003 L
.88613 .33974 L
.88364 .34585 L
.88244 .34946 L
.87922 .35917 L
.87659 .36888 L
.87393 .37533 L
.87283 .37859 L
.86959 .38831 L
.86694 .39802 L
.86422 .40455 L
.86313 .40773 L
.85986 .41744 L
.85718 .42716 L
.85451 .43352 L
.85335 .43687 L
.85006 .44658 L
.8473 .45629 L
.84479 .46224 L
.84349 .46601 L
.84016 .47572 L
.83731 .48543 L
.83508 .4907 L
.83353 .49514 L
.83226 .50486 L
.82719 .51457 L
.82537 .5189 L
.82347 .52428 L
.8219 .53399 L
.81697 .54371 L
.81566 .54683 L
.81332 .55342 L
.8114 .56313 L
.80663 .57284 L
.80594 .57449 L
.80306 .58256 L
.80078 .59227 L
.79623 .60188 L
.79619 .60198 L
.7927 .61169 L
.79006 .62141 L
.78652 .62905 L
.78575 .63112 L
.78223 .64083 L
.77924 .65054 L
.77681 .65591 L
.77519 .66026 L
.77362 .66997 L
.76833 .67968 L
.76709 .68248 L
.76452 .68939 L
.76223 .69911 L
.75738 .70875 L
.75735 .70882 L
.75371 .71853 L
.75083 .72824 L
.74767 .73481 L
.74646 .73796 L
.74278 .74767 L
.73941 .75738 L
.73796 .76052 L
.73542 .76709 L
.73303 .77681 L
.72824 .78593 L
.72801 .78652 L
.72424 .79623 L
.72108 .80594 L
.71853 .81111 L
.71672 .81566 L
.71477 .82537 L
.7092 .83508 L
.70882 .83589 L
.70528 .84479 L
.70221 .85451 L
.69911 .86047 L
.69757 .86422 L
.69367 .87393 L
.68987 .88364 L
.68939 .88463 L
.68583 .89336 L
.68264 .90307 L
.67968 .90859 L
.67792 .91278 L
.67391 .92249 L
.66997 .93208 L
.66991 .93221 L
.66585 .94192 L
.66229 .95163 L
.66026 .95539 L
.6577 .96134 L
.65497 .97106 L
.65054 .97712 L
.64944 .98077 L
.98077 .98077 L
F
0 g
.98077 .03787 m
.98054 .03866 L
.97764 .04837 L
.97466 .05808 L
.97165 .06779 L
.97106 .06972 L
.96864 .07751 L
.96736 .08722 L
.96299 .09693 L
.96134 .10135 L
.95968 .10664 L
.95667 .11636 L
.95421 .12607 L
.95163 .13275 L
.95067 .13578 L
.94762 .14549 L
.94539 .15521 L
.94192 .16389 L
.94159 .16492 L
.93852 .17463 L
.93652 .18434 L
.93248 .19406 L
.93221 .1948 L
.92935 .20377 L
.92761 .21348 L
.92336 .22319 L
.92249 .2255 L
.92011 .23291 L
.91863 .24262 L
.91418 .25233 L
.91278 .25596 L
.9108 .26204 L
.90957 .27176 L
.90491 .28147 L
.90307 .28617 L
.90142 .29118 L
.90041 .30089 L
.89557 .31061 L
.89336 .31613 L
.89197 .32032 L
.88878 .33003 L
.88613 .33974 L
.88364 .34585 L
.88244 .34946 L
.87922 .35917 L
.87659 .36888 L
.87393 .37533 L
.87283 .37859 L
.86959 .38831 L
.86694 .39802 L
Mistroke
.86422 .40455 L
.86313 .40773 L
.85986 .41744 L
.85718 .42716 L
.85451 .43352 L
.85335 .43687 L
.85006 .44658 L
.8473 .45629 L
.84479 .46224 L
.84349 .46601 L
.84016 .47572 L
.83731 .48543 L
.83508 .4907 L
.83353 .49514 L
.83226 .50486 L
.82719 .51457 L
.82537 .5189 L
.82347 .52428 L
.8219 .53399 L
.81697 .54371 L
.81566 .54683 L
.81332 .55342 L
.8114 .56313 L
.80663 .57284 L
.80594 .57449 L
.80306 .58256 L
.80078 .59227 L
.79623 .60188 L
.79619 .60198 L
.7927 .61169 L
.79006 .62141 L
.78652 .62905 L
.78575 .63112 L
.78223 .64083 L
.77924 .65054 L
.77681 .65591 L
.77519 .66026 L
.77362 .66997 L
.76833 .67968 L
.76709 .68248 L
.76452 .68939 L
.76223 .69911 L
.75738 .70875 L
.75735 .70882 L
.75371 .71853 L
.75083 .72824 L
.74767 .73481 L
.74646 .73796 L
.74278 .74767 L
.73941 .75738 L
Mistroke
.73796 .76052 L
.73542 .76709 L
.73303 .77681 L
.72824 .78593 L
.72801 .78652 L
.72424 .79623 L
.72108 .80594 L
.71853 .81111 L
.71672 .81566 L
.71477 .82537 L
.7092 .83508 L
.70882 .83589 L
.70528 .84479 L
.70221 .85451 L
.69911 .86047 L
.69757 .86422 L
.69367 .87393 L
.68987 .88364 L
.68939 .88463 L
.68583 .89336 L
.68264 .90307 L
.67968 .90859 L
.67792 .91278 L
.67391 .92249 L
.66997 .93208 L
.66991 .93221 L
.66585 .94192 L
.66229 .95163 L
.66026 .95539 L
.6577 .96134 L
.65497 .97106 L
.65054 .97712 L
.64944 .98077 L
Mfstroke
.6 g
.98077 .06224 m
.97912 .06779 L
.97618 .07751 L
.9716 .08722 L
.97106 .09423 L
.97043 .09693 L
.96758 .10664 L
.96444 .11636 L
.96134 .12599 L
.96133 .12607 L
.95866 .13578 L
.95553 .14549 L
.95238 .15521 L
.95163 .15753 L
.94966 .16492 L
.94656 .17463 L
.94337 .18434 L
.94192 .18884 L
.94057 .19406 L
.93752 .20377 L
.93431 .21348 L
.93221 .21992 L
.93139 .22319 L
.9284 .23291 L
.92518 .24262 L
.92249 .25076 L
.92212 .25233 L
.91921 .26204 L
.91598 .27176 L
.91278 .28137 L
.91276 .28147 L
.90995 .29118 L
.90671 .30089 L
.90345 .31061 L
.90307 .31174 L
.9006 .32032 L
.89736 .33003 L
.89407 .33974 L
.89336 .34188 L
.89118 .34946 L
.88794 .35917 L
.88462 .36888 L
.88364 .37178 L
.88169 .37859 L
.87844 .38831 L
.8751 .39802 L
.87393 .40144 L
.87212 .40773 L
.86885 .41744 L
.86549 .42716 L
.86422 .43085 L
.86247 .43687 L
.85919 .44658 L
.85579 .45629 L
.85451 .46002 L
.85274 .46601 L
.84943 .47572 L
.84602 .48543 L
.84479 .48893 L
.84294 .49514 L
.83959 .50486 L
.83615 .51457 L
.83508 .5176 L
.83305 .52428 L
.82966 .53399 L
.82619 .54371 L
.82537 .54602 L
.82306 .55342 L
.81963 .56313 L
.81613 .57284 L
.81566 .57418 L
.81299 .58256 L
.8095 .59227 L
.80598 .60198 L
.80594 .60208 L
.80281 .61169 L
.79927 .62141 L
.79623 .62972 L
.79582 .63112 L
.79252 .64083 L
.78894 .65054 L
.78652 .65711 L
.78555 .66026 L
.78211 .66997 L
.77849 .67968 L
.77681 .68422 L
.77514 .68939 L
.77159 .69911 L
.76794 .70882 L
.76709 .71107 L
.76459 .71853 L
.76095 .72824 L
.75738 .73765 L
.75729 .73796 L
.75389 .74767 L
.75019 .75738 L
.74767 .76396 L
.74664 .76709 L
.74306 .77681 L
.73929 .78652 L
.73796 .78998 L
.7358 .79623 L
.73207 .80594 L
.72827 .81566 L
.72824 .81573 L
.72477 .82537 L
.72095 .83508 L
.71853 .8412 L
.71729 .84479 L
.71356 .85451 L
.70968 .86422 L
.70882 .86638 L
.70607 .87393 L
.70219 .88364 L
.69911 .89127 L
.69838 .89336 L
.69462 .90307 L
.69065 .91278 L
.68939 .91587 L
.68693 .92249 L
.68298 .93221 L
.67968 .94017 L
.67905 .94192 L
.67521 .95163 L
.67115 .96134 L
.66997 .96417 L
.66732 .97106 L
.66326 .98077 L
.98077 .98077 L
F
0 g
.98077 .06224 m
.97912 .06779 L
.97618 .07751 L
.9716 .08722 L
.97106 .09423 L
.97043 .09693 L
.96758 .10664 L
.96444 .11636 L
.96134 .12599 L
.96133 .12607 L
.95866 .13578 L
.95553 .14549 L
.95238 .15521 L
.95163 .15753 L
.94966 .16492 L
.94656 .17463 L
.94337 .18434 L
.94192 .18884 L
.94057 .19406 L
.93752 .20377 L
.93431 .21348 L
.93221 .21992 L
.93139 .22319 L
.9284 .23291 L
.92518 .24262 L
.92249 .25076 L
.92212 .25233 L
.91921 .26204 L
.91598 .27176 L
.91278 .28137 L
.91276 .28147 L
.90995 .29118 L
.90671 .30089 L
.90345 .31061 L
.90307 .31174 L
.9006 .32032 L
.89736 .33003 L
.89407 .33974 L
.89336 .34188 L
.89118 .34946 L
.88794 .35917 L
.88462 .36888 L
.88364 .37178 L
.88169 .37859 L
.87844 .38831 L
.8751 .39802 L
.87393 .40144 L
.87212 .40773 L
.86885 .41744 L
.86549 .42716 L
Mistroke
.86422 .43085 L
.86247 .43687 L
.85919 .44658 L
.85579 .45629 L
.85451 .46002 L
.85274 .46601 L
.84943 .47572 L
.84602 .48543 L
.84479 .48893 L
.84294 .49514 L
.83959 .50486 L
.83615 .51457 L
.83508 .5176 L
.83305 .52428 L
.82966 .53399 L
.82619 .54371 L
.82537 .54602 L
.82306 .55342 L
.81963 .56313 L
.81613 .57284 L
.81566 .57418 L
.81299 .58256 L
.8095 .59227 L
.80598 .60198 L
.80594 .60208 L
.80281 .61169 L
.79927 .62141 L
.79623 .62972 L
.79582 .63112 L
.79252 .64083 L
.78894 .65054 L
.78652 .65711 L
.78555 .66026 L
.78211 .66997 L
.77849 .67968 L
.77681 .68422 L
.77514 .68939 L
.77159 .69911 L
.76794 .70882 L
.76709 .71107 L
.76459 .71853 L
.76095 .72824 L
.75738 .73765 L
.75729 .73796 L
.75389 .74767 L
.75019 .75738 L
.74767 .76396 L
.74664 .76709 L
.74306 .77681 L
.73929 .78652 L
Mistroke
.73796 .78998 L
.7358 .79623 L
.73207 .80594 L
.72827 .81566 L
.72824 .81573 L
.72477 .82537 L
.72095 .83508 L
.71853 .8412 L
.71729 .84479 L
.71356 .85451 L
.70968 .86422 L
.70882 .86638 L
.70607 .87393 L
.70219 .88364 L
.69911 .89127 L
.69838 .89336 L
.69462 .90307 L
.69065 .91278 L
.68939 .91587 L
.68693 .92249 L
.68298 .93221 L
.67968 .94017 L
.67905 .94192 L
.67521 .95163 L
.67115 .96134 L
.66997 .96417 L
.66732 .97106 L
.66326 .98077 L
Mfstroke
.5 g
.98077 .08247 m
.97703 .08722 L
.9752 .09693 L
.97317 .10664 L
.97106 .11453 L
.97053 .11636 L
.96762 .12607 L
.96461 .13578 L
.96161 .14549 L
.96134 .14638 L
.95871 .15521 L
.9557 .16492 L
.95267 .17463 L
.95163 .178 L
.94974 .18434 L
.94672 .19406 L
.94367 .20377 L
.94192 .20939 L
.9407 .21348 L
.93768 .22319 L
.93461 .23291 L
.93221 .24055 L
.93159 .24262 L
.92858 .25233 L
.92549 .26204 L
.92249 .27148 L
.92241 .27176 L
.91941 .28147 L
.9163 .29118 L
.91319 .30089 L
.91278 .30218 L
.91017 .31061 L
.90704 .32032 L
.90391 .33003 L
.90307 .33265 L
.90086 .33974 L
.89772 .34946 L
.89455 .35917 L
.89336 .36287 L
.89147 .36888 L
.88832 .37859 L
.88513 .38831 L
.88364 .39287 L
.88202 .39802 L
.87885 .40773 L
.87563 .41744 L
.87393 .42262 L
.87249 .42716 L
.8693 .43687 L
.86606 .44658 L
.86422 .45213 L
.86288 .45629 L
.85967 .46601 L
.85641 .47572 L
.85451 .48139 L
.8532 .48543 L
.84996 .49514 L
.84667 .50486 L
.84479 .51041 L
.84344 .51457 L
.84017 .52428 L
.83685 .53399 L
.83508 .53919 L
.83359 .54371 L
.83029 .55342 L
.82694 .56313 L
.82537 .56771 L
.82366 .57284 L
.82032 .58256 L
.81694 .59227 L
.81566 .59598 L
.81363 .60198 L
.81025 .61169 L
.80685 .62141 L
.80594 .624 L
.80351 .63112 L
.80009 .64083 L
.79666 .65054 L
.79623 .65175 L
.79329 .66026 L
.78983 .66997 L
.78652 .67925 L
.78637 .67968 L
.78296 .68939 L
.77946 .69911 L
.77681 .70649 L
.776 .70882 L
.77252 .71853 L
.76899 .72824 L
.76709 .73346 L
.7655 .73796 L
.76197 .74767 L
.7584 .75738 L
.75738 .76017 L
.75489 .76709 L
.75131 .77681 L
.7477 .78652 L
.74767 .78661 L
.74415 .79623 L
.74051 .80594 L
.73796 .81277 L
.7369 .81566 L
.73328 .82537 L
.7296 .83508 L
.72824 .83866 L
.72596 .84479 L
.72227 .85451 L
.71855 .86422 L
.71853 .86427 L
.71488 .87393 L
.71112 .88364 L
.70882 .8896 L
.7074 .89336 L
.70364 .90307 L
.69983 .91278 L
.69911 .91464 L
.69607 .92249 L
.69224 .93221 L
.68939 .9394 L
.68842 .94192 L
.68458 .95163 L
.68069 .96134 L
.67968 .96386 L
.67683 .97106 L
.67291 .98077 L
.98077 .98077 L
F
0 g
.98077 .08247 m
.97703 .08722 L
.9752 .09693 L
.97317 .10664 L
.97106 .11453 L
.97053 .11636 L
.96762 .12607 L
.96461 .13578 L
.96161 .14549 L
.96134 .14638 L
.95871 .15521 L
.9557 .16492 L
.95267 .17463 L
.95163 .178 L
.94974 .18434 L
.94672 .19406 L
.94367 .20377 L
.94192 .20939 L
.9407 .21348 L
.93768 .22319 L
.93461 .23291 L
.93221 .24055 L
.93159 .24262 L
.92858 .25233 L
.92549 .26204 L
.92249 .27148 L
.92241 .27176 L
.91941 .28147 L
.9163 .29118 L
.91319 .30089 L
.91278 .30218 L
.91017 .31061 L
.90704 .32032 L
.90391 .33003 L
.90307 .33265 L
.90086 .33974 L
.89772 .34946 L
.89455 .35917 L
.89336 .36287 L
.89147 .36888 L
.88832 .37859 L
.88513 .38831 L
.88364 .39287 L
.88202 .39802 L
.87885 .40773 L
.87563 .41744 L
.87393 .42262 L
.87249 .42716 L
.8693 .43687 L
.86606 .44658 L
Mistroke
.86422 .45213 L
.86288 .45629 L
.85967 .46601 L
.85641 .47572 L
.85451 .48139 L
.8532 .48543 L
.84996 .49514 L
.84667 .50486 L
.84479 .51041 L
.84344 .51457 L
.84017 .52428 L
.83685 .53399 L
.83508 .53919 L
.83359 .54371 L
.83029 .55342 L
.82694 .56313 L
.82537 .56771 L
.82366 .57284 L
.82032 .58256 L
.81694 .59227 L
.81566 .59598 L
.81363 .60198 L
.81025 .61169 L
.80685 .62141 L
.80594 .624 L
.80351 .63112 L
.80009 .64083 L
.79666 .65054 L
.79623 .65175 L
.79329 .66026 L
.78983 .66997 L
.78652 .67925 L
.78637 .67968 L
.78296 .68939 L
.77946 .69911 L
.77681 .70649 L
.776 .70882 L
.77252 .71853 L
.76899 .72824 L
.76709 .73346 L
.7655 .73796 L
.76197 .74767 L
.7584 .75738 L
.75738 .76017 L
.75489 .76709 L
.75131 .77681 L
.7477 .78652 L
.74767 .78661 L
.74415 .79623 L
.74051 .80594 L
Mistroke
.73796 .81277 L
.7369 .81566 L
.73328 .82537 L
.7296 .83508 L
.72824 .83866 L
.72596 .84479 L
.72227 .85451 L
.71855 .86422 L
.71853 .86427 L
.71488 .87393 L
.71112 .88364 L
.70882 .8896 L
.7074 .89336 L
.70364 .90307 L
.69983 .91278 L
.69911 .91464 L
.69607 .92249 L
.69224 .93221 L
.68939 .9394 L
.68842 .94192 L
.68458 .95163 L
.68069 .96134 L
.67968 .96386 L
.67683 .97106 L
.67291 .98077 L
Mfstroke
.4 g
.98077 .10174 m
.97896 .10664 L
.97614 .11636 L
.97337 .12607 L
.97106 .13387 L
.97048 .13578 L
.96751 .14549 L
.96451 .15521 L
.9616 .16492 L
.96134 .16578 L
.95863 .17463 L
.95561 .18434 L
.95264 .19406 L
.95163 .19747 L
.94969 .20377 L
.94666 .21348 L
.94364 .22319 L
.94192 .22893 L
.94069 .23291 L
.93764 .24262 L
.93459 .25233 L
.93221 .26017 L
.93162 .26204 L
.92856 .27176 L
.92549 .28147 L
.92249 .29118 L
.92249 .29118 L
.91942 .30089 L
.91632 .31061 L
.91328 .32032 L
.91278 .32195 L
.91021 .33003 L
.90709 .33974 L
.904 .34946 L
.90307 .35249 L
.90093 .35917 L
.89779 .36888 L
.89467 .37859 L
.89336 .3828 L
.89158 .38831 L
.88841 .39802 L
.88527 .40773 L
.88364 .41287 L
.88216 .41744 L
.87897 .42716 L
.87579 .43687 L
.87393 .4427 L
.87266 .44658 L
.86945 .45629 L
.86625 .46601 L
.86422 .4723 L
.86309 .47572 L
.85986 .48543 L
.85662 .49514 L
.85451 .50165 L
.85344 .50486 L
.85018 .51457 L
.84692 .52428 L
.84479 .53075 L
.84371 .53399 L
.84042 .54371 L
.83713 .55342 L
.83508 .55961 L
.83389 .56313 L
.83057 .57284 L
.82726 .58256 L
.82537 .58823 L
.82399 .59227 L
.82064 .60198 L
.8173 .61169 L
.81566 .61659 L
.814 .62141 L
.81062 .63112 L
.80726 .64083 L
.80594 .6447 L
.80391 .65054 L
.8005 .66026 L
.79712 .66997 L
.79623 .67256 L
.79373 .67968 L
.79028 .68939 L
.78688 .69911 L
.78652 .70015 L
.78344 .70882 L
.77997 .71853 L
.77681 .72749 L
.77654 .72824 L
.77305 .73796 L
.76955 .74767 L
.76709 .75457 L
.76608 .75738 L
.76255 .76709 L
.75902 .77681 L
.75738 .78138 L
.75551 .78652 L
.75193 .79623 L
.74838 .80594 L
.74767 .80793 L
.74481 .81566 L
.7412 .82537 L
.73796 .83421 L
.73763 .83508 L
.734 .84479 L
.73036 .85451 L
.72824 .86021 L
.72674 .86422 L
.72305 .87393 L
.71939 .88364 L
.71853 .88594 L
.7157 .89336 L
.71198 .90307 L
.70882 .91139 L
.70828 .91278 L
.70453 .92249 L
.70077 .93221 L
.69911 .93655 L
.69702 .94192 L
.69321 .95163 L
.68943 .96134 L
.68939 .96144 L
.6856 .97106 L
.68175 .98077 L
.98077 .98077 L
F
0 g
.98077 .10174 m
.97896 .10664 L
.97614 .11636 L
.97337 .12607 L
.97106 .13387 L
.97048 .13578 L
.96751 .14549 L
.96451 .15521 L
.9616 .16492 L
.96134 .16578 L
.95863 .17463 L
.95561 .18434 L
.95264 .19406 L
.95163 .19747 L
.94969 .20377 L
.94666 .21348 L
.94364 .22319 L
.94192 .22893 L
.94069 .23291 L
.93764 .24262 L
.93459 .25233 L
.93221 .26017 L
.93162 .26204 L
.92856 .27176 L
.92549 .28147 L
.92249 .29118 L
.92249 .29118 L
.91942 .30089 L
.91632 .31061 L
.91328 .32032 L
.91278 .32195 L
.91021 .33003 L
.90709 .33974 L
.904 .34946 L
.90307 .35249 L
.90093 .35917 L
.89779 .36888 L
.89467 .37859 L
.89336 .3828 L
.89158 .38831 L
.88841 .39802 L
.88527 .40773 L
.88364 .41287 L
.88216 .41744 L
.87897 .42716 L
.87579 .43687 L
.87393 .4427 L
.87266 .44658 L
.86945 .45629 L
.86625 .46601 L
Mistroke
.86422 .4723 L
.86309 .47572 L
.85986 .48543 L
.85662 .49514 L
.85451 .50165 L
.85344 .50486 L
.85018 .51457 L
.84692 .52428 L
.84479 .53075 L
.84371 .53399 L
.84042 .54371 L
.83713 .55342 L
.83508 .55961 L
.83389 .56313 L
.83057 .57284 L
.82726 .58256 L
.82537 .58823 L
.82399 .59227 L
.82064 .60198 L
.8173 .61169 L
.81566 .61659 L
.814 .62141 L
.81062 .63112 L
.80726 .64083 L
.80594 .6447 L
.80391 .65054 L
.8005 .66026 L
.79712 .66997 L
.79623 .67256 L
.79373 .67968 L
.79028 .68939 L
.78688 .69911 L
.78652 .70015 L
.78344 .70882 L
.77997 .71853 L
.77681 .72749 L
.77654 .72824 L
.77305 .73796 L
.76955 .74767 L
.76709 .75457 L
.76608 .75738 L
.76255 .76709 L
.75902 .77681 L
.75738 .78138 L
.75551 .78652 L
.75193 .79623 L
.74838 .80594 L
.74767 .80793 L
.74481 .81566 L
.7412 .82537 L
Mistroke
.73796 .83421 L
.73763 .83508 L
.734 .84479 L
.73036 .85451 L
.72824 .86021 L
.72674 .86422 L
.72305 .87393 L
.71939 .88364 L
.71853 .88594 L
.7157 .89336 L
.71198 .90307 L
.70882 .91139 L
.70828 .91278 L
.70453 .92249 L
.70077 .93221 L
.69911 .93655 L
.69702 .94192 L
.69321 .95163 L
.68943 .96134 L
.68939 .96144 L
.6856 .97106 L
.68175 .98077 L
Mfstroke
.3 g
.98077 .12196 m
.9795 .12607 L
.97662 .13578 L
.97373 .14549 L
.97106 .15418 L
.97074 .15521 L
.96766 .16492 L
.96457 .17463 L
.96177 .18434 L
.96134 .18617 L
.95884 .19406 L
.95572 .20377 L
.95276 .21348 L
.95163 .21794 L
.94996 .22319 L
.94682 .23291 L
.94376 .24262 L
.94192 .24949 L
.94101 .25233 L
.93786 .26204 L
.93474 .27176 L
.93221 .28081 L
.932 .28147 L
.92884 .29118 L
.92567 .30089 L
.92281 .31061 L
.92249 .3119 L
.91975 .32032 L
.91655 .33003 L
.91356 .33974 L
.91278 .34276 L
.91059 .34946 L
.90737 .35917 L
.90429 .36888 L
.90307 .37339 L
.90136 .37859 L
.89812 .38831 L
.89497 .39802 L
.89336 .40379 L
.89205 .40773 L
.88879 .41744 L
.8856 .42716 L
.88364 .43395 L
.88267 .43687 L
.87939 .44658 L
.87616 .45629 L
.87393 .46388 L
.87322 .46601 L
.86992 .47572 L
.86665 .48543 L
.86422 .49358 L
.86369 .49514 L
.86037 .50486 L
.85707 .51457 L
.85451 .52303 L
.85408 .52428 L
.85074 .53399 L
.84741 .54371 L
.84479 .55224 L
.84439 .55342 L
.84102 .56313 L
.83767 .57284 L
.83508 .5812 L
.83461 .58256 L
.83122 .59227 L
.82785 .60198 L
.82537 .60992 L
.82475 .61169 L
.82133 .62141 L
.81794 .63112 L
.81566 .63839 L
.8148 .64083 L
.81134 .65054 L
.80795 .66026 L
.80594 .66661 L
.80475 .66997 L
.80127 .67968 L
.79787 .68939 L
.79623 .69458 L
.79461 .69911 L
.79109 .70882 L
.7877 .71853 L
.78652 .7223 L
.78436 .72824 L
.78082 .73796 L
.77746 .74767 L
.77681 .74976 L
.77402 .75738 L
.77045 .76709 L
.76714 .77681 L
.76709 .77697 L
.76356 .78652 L
.75998 .79623 L
.75738 .80391 L
.75663 .80594 L
.75299 .81566 L
.74942 .82537 L
.74767 .83058 L
.74598 .83508 L
.74231 .84479 L
.73878 .85451 L
.73796 .85699 L
.73521 .86422 L
.73152 .87393 L
.72824 .88314 L
.72805 .88364 L
.72431 .89336 L
.72062 .90307 L
.71853 .90901 L
.71707 .91278 L
.71329 .92249 L
.70965 .93221 L
.70882 .9346 L
.70595 .94192 L
.70215 .95163 L
.69911 .95993 L
.69855 .96134 L
.69469 .97106 L
.69091 .98077 L
.98077 .98077 L
F
0 g
.98077 .12196 m
.9795 .12607 L
.97662 .13578 L
.97373 .14549 L
.97106 .15418 L
.97074 .15521 L
.96766 .16492 L
.96457 .17463 L
.96177 .18434 L
.96134 .18617 L
.95884 .19406 L
.95572 .20377 L
.95276 .21348 L
.95163 .21794 L
.94996 .22319 L
.94682 .23291 L
.94376 .24262 L
.94192 .24949 L
.94101 .25233 L
.93786 .26204 L
.93474 .27176 L
.93221 .28081 L
.932 .28147 L
.92884 .29118 L
.92567 .30089 L
.92281 .31061 L
.92249 .3119 L
.91975 .32032 L
.91655 .33003 L
.91356 .33974 L
.91278 .34276 L
.91059 .34946 L
.90737 .35917 L
.90429 .36888 L
.90307 .37339 L
.90136 .37859 L
.89812 .38831 L
.89497 .39802 L
.89336 .40379 L
.89205 .40773 L
.88879 .41744 L
.8856 .42716 L
.88364 .43395 L
.88267 .43687 L
.87939 .44658 L
.87616 .45629 L
.87393 .46388 L
.87322 .46601 L
.86992 .47572 L
.86665 .48543 L
Mistroke
.86422 .49358 L
.86369 .49514 L
.86037 .50486 L
.85707 .51457 L
.85451 .52303 L
.85408 .52428 L
.85074 .53399 L
.84741 .54371 L
.84479 .55224 L
.84439 .55342 L
.84102 .56313 L
.83767 .57284 L
.83508 .5812 L
.83461 .58256 L
.83122 .59227 L
.82785 .60198 L
.82537 .60992 L
.82475 .61169 L
.82133 .62141 L
.81794 .63112 L
.81566 .63839 L
.8148 .64083 L
.81134 .65054 L
.80795 .66026 L
.80594 .66661 L
.80475 .66997 L
.80127 .67968 L
.79787 .68939 L
.79623 .69458 L
.79461 .69911 L
.79109 .70882 L
.7877 .71853 L
.78652 .7223 L
.78436 .72824 L
.78082 .73796 L
.77746 .74767 L
.77681 .74976 L
.77402 .75738 L
.77045 .76709 L
.76714 .77681 L
.76709 .77697 L
.76356 .78652 L
.75998 .79623 L
.75738 .80391 L
.75663 .80594 L
.75299 .81566 L
.74942 .82537 L
.74767 .83058 L
.74598 .83508 L
.74231 .84479 L
Mistroke
.73878 .85451 L
.73796 .85699 L
.73521 .86422 L
.73152 .87393 L
.72824 .88314 L
.72805 .88364 L
.72431 .89336 L
.72062 .90307 L
.71853 .90901 L
.71707 .91278 L
.71329 .92249 L
.70965 .93221 L
.70882 .9346 L
.70595 .94192 L
.70215 .95163 L
.69911 .95993 L
.69855 .96134 L
.69469 .97106 L
.69091 .98077 L
Mfstroke
.2 g
.98077 .14633 m
.97829 .15521 L
.97547 .16492 L
.97243 .17463 L
.97106 .17867 L
.969 .18434 L
.96472 .19406 L
.96351 .20377 L
.96134 .21082 L
.9604 .21348 L
.95643 .22319 L
.95466 .23291 L
.95167 .24262 L
.95163 .24275 L
.94793 .25233 L
.94576 .26204 L
.94276 .27176 L
.94192 .27442 L
.93927 .28147 L
.9347 .29118 L
.93378 .30089 L
.93221 .30589 L
.93046 .31061 L
.92619 .32032 L
.92474 .33003 L
.92249 .33715 L
.92155 .33974 L
.91748 .34946 L
.91564 .35917 L
.91278 .36819 L
.91253 .36888 L
.90861 .37859 L
.90647 .38831 L
.90338 .39802 L
.90307 .39898 L
.89961 .40773 L
.89724 .41744 L
.89413 .42716 L
.89336 .42954 L
.89049 .43687 L
.88795 .44658 L
.88482 .45629 L
.88364 .45988 L
.88126 .46601 L
.8766 .47572 L
.87543 .48543 L
.87393 .48999 L
.87193 .49514 L
.86737 .50486 L
.86598 .51457 L
.86422 .51988 L
.86251 .52428 L
.85801 .53399 L
.85644 .54371 L
.85451 .54952 L
.85299 .55342 L
.84851 .56313 L
.84684 .57284 L
.84479 .57894 L
.84338 .58256 L
.83889 .59227 L
.83716 .60198 L
.83508 .60811 L
.83367 .61169 L
.82914 .62141 L
.82739 .63112 L
.82537 .63704 L
.82386 .64083 L
.81925 .65054 L
.81754 .66026 L
.81566 .66573 L
.81395 .66997 L
.80922 .67968 L
.80761 .68939 L
.80594 .69418 L
.80392 .69911 L
.79903 .70882 L
.79759 .71853 L
.79623 .72239 L
.79378 .72824 L
.79087 .73796 L
.78748 .74767 L
.78652 .75036 L
.7835 .75738 L
.7807 .76709 L
.77727 .77681 L
.77681 .77809 L
.77306 .78652 L
.77043 .79623 L
.76709 .80559 L
.76695 .80594 L
.76245 .81566 L
.76006 .82537 L
.75738 .83278 L
.75642 .83508 L
.75161 .84479 L
.74959 .85451 L
.74767 .85973 L
.74572 .86422 L
.74046 .87393 L
.73901 .88364 L
.73796 .88644 L
.73482 .89336 L
.7319 .90307 L
.72831 .91278 L
.72824 .91295 L
.72364 .92249 L
.72113 .93221 L
.71853 .93912 L
.7173 .94192 L
.71208 .95163 L
.71024 .96134 L
.70882 .96504 L
.70602 .97106 L
.70293 .98077 L
.98077 .98077 L
F
0 g
.98077 .14633 m
.97829 .15521 L
.97547 .16492 L
.97243 .17463 L
.97106 .17867 L
.969 .18434 L
.96472 .19406 L
.96351 .20377 L
.96134 .21082 L
.9604 .21348 L
.95643 .22319 L
.95466 .23291 L
.95167 .24262 L
.95163 .24275 L
.94793 .25233 L
.94576 .26204 L
.94276 .27176 L
.94192 .27442 L
.93927 .28147 L
.9347 .29118 L
.93378 .30089 L
.93221 .30589 L
.93046 .31061 L
.92619 .32032 L
.92474 .33003 L
.92249 .33715 L
.92155 .33974 L
.91748 .34946 L
.91564 .35917 L
.91278 .36819 L
.91253 .36888 L
.90861 .37859 L
.90647 .38831 L
.90338 .39802 L
.90307 .39898 L
.89961 .40773 L
.89724 .41744 L
.89413 .42716 L
.89336 .42954 L
.89049 .43687 L
.88795 .44658 L
.88482 .45629 L
.88364 .45988 L
.88126 .46601 L
.8766 .47572 L
.87543 .48543 L
.87393 .48999 L
.87193 .49514 L
.86737 .50486 L
.86598 .51457 L
Mistroke
.86422 .51988 L
.86251 .52428 L
.85801 .53399 L
.85644 .54371 L
.85451 .54952 L
.85299 .55342 L
.84851 .56313 L
.84684 .57284 L
.84479 .57894 L
.84338 .58256 L
.83889 .59227 L
.83716 .60198 L
.83508 .60811 L
.83367 .61169 L
.82914 .62141 L
.82739 .63112 L
.82537 .63704 L
.82386 .64083 L
.81925 .65054 L
.81754 .66026 L
.81566 .66573 L
.81395 .66997 L
.80922 .67968 L
.80761 .68939 L
.80594 .69418 L
.80392 .69911 L
.79903 .70882 L
.79759 .71853 L
.79623 .72239 L
.79378 .72824 L
.79087 .73796 L
.78748 .74767 L
.78652 .75036 L
.7835 .75738 L
.7807 .76709 L
.77727 .77681 L
.77681 .77809 L
.77306 .78652 L
.77043 .79623 L
.76709 .80559 L
.76695 .80594 L
.76245 .81566 L
.76006 .82537 L
.75738 .83278 L
.75642 .83508 L
.75161 .84479 L
.74959 .85451 L
.74767 .85973 L
.74572 .86422 L
.74046 .87393 L
Mistroke
.73901 .88364 L
.73796 .88644 L
.73482 .89336 L
.7319 .90307 L
.72831 .91278 L
.72824 .91295 L
.72364 .92249 L
.72113 .93221 L
.71853 .93912 L
.7173 .94192 L
.71208 .95163 L
.71024 .96134 L
.70882 .96504 L
.70602 .97106 L
.70293 .98077 L
Mfstroke
.3 g
.98077 .23927 m
.97978 .24262 L
.97686 .25233 L
.97387 .26204 L
.97106 .2711 L
.97085 .27176 L
.96785 .28147 L
.96606 .29118 L
.96201 .30089 L
.96134 .30272 L
.95888 .31061 L
.95752 .32032 L
.95317 .33003 L
.95163 .33413 L
.94986 .33974 L
.94898 .34946 L
.94428 .35917 L
.94192 .36529 L
.94077 .36888 L
.93771 .37859 L
.93535 .38831 L
.93221 .3962 L
.93162 .39802 L
.92853 .40773 L
.92637 .41744 L
.92249 .42687 L
.9224 .42716 L
.91928 .43687 L
.91731 .44658 L
.91317 .45629 L
.91278 .45732 L
.90997 .46601 L
.90818 .47572 L
.90387 .48543 L
.90307 .48754 L
.90058 .49514 L
.89895 .50486 L
.8945 .51457 L
.89336 .51751 L
.89112 .52428 L
.88961 .53399 L
.88503 .54371 L
.88364 .54723 L
.88158 .55342 L
.88015 .56313 L
.87547 .57284 L
.87393 .57671 L
.87196 .58256 L
.87056 .59227 L
.86581 .60198 L
.86422 .60593 L
.86226 .61169 L
.86082 .62141 L
.85604 .63112 L
.85451 .6349 L
.85248 .64083 L
.85094 .65054 L
.84617 .66026 L
.84479 .66361 L
.8426 .66997 L
.84091 .67968 L
.83618 .68939 L
.83508 .69207 L
.83264 .69911 L
.83073 .70882 L
.82608 .71853 L
.82537 .72026 L
.82257 .72824 L
.82042 .73796 L
.81587 .74767 L
.81566 .74819 L
.81241 .75738 L
.80999 .76709 L
.80594 .77588 L
.8056 .77681 L
.80215 .78652 L
.79943 .79623 L
.79623 .8033 L
.79526 .80594 L
.79178 .81566 L
.78878 .82537 L
.78652 .83044 L
.78481 .83508 L
.78321 .84479 L
.77802 .85451 L
.77681 .85728 L
.77425 .86422 L
.77202 .87393 L
.76717 .88364 L
.76709 .88383 L
.76356 .89336 L
.76078 .90307 L
.75738 .91018 L
.75639 .91278 L
.75275 .92249 L
.74951 .93221 L
.74767 .93619 L
.74548 .94192 L
.74336 .95163 L
.73819 .96134 L
.73796 .96187 L
.73443 .97106 L
.73152 .98077 L
.98077 .98077 L
F
0 g
.98077 .23927 m
.97978 .24262 L
.97686 .25233 L
.97387 .26204 L
.97106 .2711 L
.97085 .27176 L
.96785 .28147 L
.96606 .29118 L
.96201 .30089 L
.96134 .30272 L
.95888 .31061 L
.95752 .32032 L
.95317 .33003 L
.95163 .33413 L
.94986 .33974 L
.94898 .34946 L
.94428 .35917 L
.94192 .36529 L
.94077 .36888 L
.93771 .37859 L
.93535 .38831 L
.93221 .3962 L
.93162 .39802 L
.92853 .40773 L
.92637 .41744 L
.92249 .42687 L
.9224 .42716 L
.91928 .43687 L
.91731 .44658 L
.91317 .45629 L
.91278 .45732 L
.90997 .46601 L
.90818 .47572 L
.90387 .48543 L
.90307 .48754 L
.90058 .49514 L
.89895 .50486 L
.8945 .51457 L
.89336 .51751 L
.89112 .52428 L
.88961 .53399 L
.88503 .54371 L
.88364 .54723 L
.88158 .55342 L
.88015 .56313 L
.87547 .57284 L
.87393 .57671 L
.87196 .58256 L
.87056 .59227 L
.86581 .60198 L
Mistroke
.86422 .60593 L
.86226 .61169 L
.86082 .62141 L
.85604 .63112 L
.85451 .6349 L
.85248 .64083 L
.85094 .65054 L
.84617 .66026 L
.84479 .66361 L
.8426 .66997 L
.84091 .67968 L
.83618 .68939 L
.83508 .69207 L
.83264 .69911 L
.83073 .70882 L
.82608 .71853 L
.82537 .72026 L
.82257 .72824 L
.82042 .73796 L
.81587 .74767 L
.81566 .74819 L
.81241 .75738 L
.80999 .76709 L
.80594 .77588 L
.8056 .77681 L
.80215 .78652 L
.79943 .79623 L
.79623 .8033 L
.79526 .80594 L
.79178 .81566 L
.78878 .82537 L
.78652 .83044 L
.78481 .83508 L
.78321 .84479 L
.77802 .85451 L
.77681 .85728 L
.77425 .86422 L
.77202 .87393 L
.76717 .88364 L
.76709 .88383 L
.76356 .89336 L
.76078 .90307 L
.75738 .91018 L
.75639 .91278 L
.75275 .92249 L
.74951 .93221 L
.74767 .93619 L
.74548 .94192 L
.74336 .95163 L
.73819 .96134 L
Mistroke
.73796 .96187 L
.73443 .97106 L
.73152 .98077 L
Mfstroke
.4 g
.98077 .26362 m
.97835 .27176 L
.9754 .28147 L
.97167 .29118 L
.97106 .29561 L
.96974 .30089 L
.96675 .31061 L
.96361 .32032 L
.96134 .32738 L
.96072 .33003 L
.95785 .33974 L
.95469 .34946 L
.95163 .35891 L
.95158 .35917 L
.94886 .36888 L
.94571 .37859 L
.94254 .38831 L
.94192 .39022 L
.9398 .39802 L
.93667 .40773 L
.93346 .41744 L
.93221 .4213 L
.93065 .42716 L
.92755 .43687 L
.92432 .44658 L
.92249 .45215 L
.92142 .45629 L
.91836 .46601 L
.91512 .47572 L
.91278 .48276 L
.91211 .48543 L
.9091 .49514 L
.90584 .50486 L
.90307 .51313 L
.90271 .51457 L
.89976 .52428 L
.89648 .53399 L
.89336 .54326 L
.89325 .54371 L
.89035 .55342 L
.88706 .56313 L
.88375 .57284 L
.88364 .57316 L
.88085 .58256 L
.87755 .59227 L
.87422 .60198 L
.87393 .60282 L
.87128 .61169 L
.86796 .62141 L
.8646 .63112 L
.86422 .63223 L
.86163 .64083 L
.85829 .65054 L
.8549 .66026 L
.85451 .6614 L
.8519 .66997 L
.84853 .67968 L
.84511 .68939 L
.84479 .69032 L
.84208 .69911 L
.83868 .70882 L
.83524 .71853 L
.83508 .71898 L
.83217 .72824 L
.82874 .73796 L
.82537 .7474 L
.8253 .74767 L
.82217 .75738 L
.8187 .76709 L
.81566 .77556 L
.8153 .77681 L
.81208 .78652 L
.80856 .79623 L
.80594 .80347 L
.80521 .80594 L
.80188 .81566 L
.79833 .82537 L
.79623 .83111 L
.795 .83508 L
.79158 .84479 L
.78798 .85451 L
.78652 .85849 L
.78468 .86422 L
.78116 .87393 L
.77753 .88364 L
.77681 .88561 L
.77423 .89336 L
.77062 .90307 L
.76709 .91245 L
.76699 .91278 L
.76364 .92249 L
.75997 .93221 L
.75738 .93903 L
.75645 .94192 L
.75292 .95163 L
.7492 .96134 L
.74767 .96534 L
.74573 .97106 L
.74206 .98077 L
.98077 .98077 L
F
0 g
.98077 .26362 m
.97835 .27176 L
.9754 .28147 L
.97167 .29118 L
.97106 .29561 L
.96974 .30089 L
.96675 .31061 L
.96361 .32032 L
.96134 .32738 L
.96072 .33003 L
.95785 .33974 L
.95469 .34946 L
.95163 .35891 L
.95158 .35917 L
.94886 .36888 L
.94571 .37859 L
.94254 .38831 L
.94192 .39022 L
.9398 .39802 L
.93667 .40773 L
.93346 .41744 L
.93221 .4213 L
.93065 .42716 L
.92755 .43687 L
.92432 .44658 L
.92249 .45215 L
.92142 .45629 L
.91836 .46601 L
.91512 .47572 L
.91278 .48276 L
.91211 .48543 L
.9091 .49514 L
.90584 .50486 L
.90307 .51313 L
.90271 .51457 L
.89976 .52428 L
.89648 .53399 L
.89336 .54326 L
.89325 .54371 L
.89035 .55342 L
.88706 .56313 L
.88375 .57284 L
.88364 .57316 L
.88085 .58256 L
.87755 .59227 L
.87422 .60198 L
.87393 .60282 L
.87128 .61169 L
.86796 .62141 L
.8646 .63112 L
Mistroke
.86422 .63223 L
.86163 .64083 L
.85829 .65054 L
.8549 .66026 L
.85451 .6614 L
.8519 .66997 L
.84853 .67968 L
.84511 .68939 L
.84479 .69032 L
.84208 .69911 L
.83868 .70882 L
.83524 .71853 L
.83508 .71898 L
.83217 .72824 L
.82874 .73796 L
.82537 .7474 L
.8253 .74767 L
.82217 .75738 L
.8187 .76709 L
.81566 .77556 L
.8153 .77681 L
.81208 .78652 L
.80856 .79623 L
.80594 .80347 L
.80521 .80594 L
.80188 .81566 L
.79833 .82537 L
.79623 .83111 L
.795 .83508 L
.79158 .84479 L
.78798 .85451 L
.78652 .85849 L
.78468 .86422 L
.78116 .87393 L
.77753 .88364 L
.77681 .88561 L
.77423 .89336 L
.77062 .90307 L
.76709 .91245 L
.76699 .91278 L
.76364 .92249 L
.75997 .93221 L
.75738 .93903 L
.75645 .94192 L
.75292 .95163 L
.7492 .96134 L
.74767 .96534 L
.74573 .97106 L
.74206 .98077 L
Mfstroke
.5 g
.98077 .28385 m
.97636 .29118 L
.97473 .30089 L
.97251 .31061 L
.97106 .31592 L
.96978 .32032 L
.96682 .33003 L
.96381 .33974 L
.96134 .34776 L
.96085 .34946 L
.95792 .35917 L
.95489 .36888 L
.95187 .37859 L
.95163 .37938 L
.94895 .38831 L
.94591 .39802 L
.94286 .40773 L
.94192 .41077 L
.93991 .41744 L
.93687 .42716 L
.9338 .43687 L
.93221 .44193 L
.93081 .44658 L
.92776 .45629 L
.92467 .46601 L
.92249 .47287 L
.92163 .47572 L
.91859 .48543 L
.91547 .49514 L
.91278 .50356 L
.91239 .50486 L
.90934 .51457 L
.90621 .52428 L
.90308 .53399 L
.90307 .53403 L
.90003 .54371 L
.89688 .55342 L
.89372 .56313 L
.89336 .56426 L
.89065 .57284 L
.88747 .58256 L
.88429 .59227 L
.88364 .59425 L
.88119 .60198 L
.87799 .61169 L
.87478 .62141 L
.87393 .624 L
.87165 .63112 L
.86844 .64083 L
.8652 .65054 L
.86422 .65351 L
.86204 .66026 L
.8588 .66997 L
.85554 .67968 L
.85451 .68278 L
.85235 .68939 L
.84909 .69911 L
.8458 .70882 L
.84479 .7118 L
.84258 .71853 L
.83929 .72824 L
.83597 .73796 L
.83508 .74057 L
.83272 .74767 L
.8294 .75738 L
.82605 .76709 L
.82537 .76909 L
.82278 .77681 L
.81942 .78652 L
.81605 .79623 L
.81566 .79736 L
.81274 .80594 L
.80935 .81566 L
.80595 .82537 L
.80594 .82538 L
.80261 .83508 L
.79918 .84479 L
.79623 .85314 L
.79577 .85451 L
.79237 .86422 L
.78891 .87393 L
.78652 .88064 L
.78548 .88364 L
.78204 .89336 L
.77854 .90307 L
.77681 .90788 L
.77509 .91278 L
.77159 .92249 L
.76805 .93221 L
.76709 .93485 L
.76457 .94192 L
.76103 .95163 L
.75746 .96134 L
.75738 .96155 L
.75394 .97106 L
.75035 .98077 L
.98077 .98077 L
F
0 g
.98077 .28385 m
.97636 .29118 L
.97473 .30089 L
.97251 .31061 L
.97106 .31592 L
.96978 .32032 L
.96682 .33003 L
.96381 .33974 L
.96134 .34776 L
.96085 .34946 L
.95792 .35917 L
.95489 .36888 L
.95187 .37859 L
.95163 .37938 L
.94895 .38831 L
.94591 .39802 L
.94286 .40773 L
.94192 .41077 L
.93991 .41744 L
.93687 .42716 L
.9338 .43687 L
.93221 .44193 L
.93081 .44658 L
.92776 .45629 L
.92467 .46601 L
.92249 .47287 L
.92163 .47572 L
.91859 .48543 L
.91547 .49514 L
.91278 .50356 L
.91239 .50486 L
.90934 .51457 L
.90621 .52428 L
.90308 .53399 L
.90307 .53403 L
.90003 .54371 L
.89688 .55342 L
.89372 .56313 L
.89336 .56426 L
.89065 .57284 L
.88747 .58256 L
.88429 .59227 L
.88364 .59425 L
.88119 .60198 L
.87799 .61169 L
.87478 .62141 L
.87393 .624 L
.87165 .63112 L
.86844 .64083 L
.8652 .65054 L
Mistroke
.86422 .65351 L
.86204 .66026 L
.8588 .66997 L
.85554 .67968 L
.85451 .68278 L
.85235 .68939 L
.84909 .69911 L
.8458 .70882 L
.84479 .7118 L
.84258 .71853 L
.83929 .72824 L
.83597 .73796 L
.83508 .74057 L
.83272 .74767 L
.8294 .75738 L
.82605 .76709 L
.82537 .76909 L
.82278 .77681 L
.81942 .78652 L
.81605 .79623 L
.81566 .79736 L
.81274 .80594 L
.80935 .81566 L
.80595 .82537 L
.80594 .82538 L
.80261 .83508 L
.79918 .84479 L
.79623 .85314 L
.79577 .85451 L
.79237 .86422 L
.78891 .87393 L
.78652 .88064 L
.78548 .88364 L
.78204 .89336 L
.77854 .90307 L
.77681 .90788 L
.77509 .91278 L
.77159 .92249 L
.76805 .93221 L
.76709 .93485 L
.76457 .94192 L
.76103 .95163 L
.75746 .96134 L
.75738 .96155 L
.75394 .97106 L
.75035 .98077 L
Mfstroke
.6 g
.98077 .30312 m
.97817 .31061 L
.97541 .32032 L
.97261 .33003 L
.97106 .33526 L
.9697 .33974 L
.96671 .34946 L
.96372 .35917 L
.96134 .36717 L
.96082 .36888 L
.95783 .37859 L
.95481 .38831 L
.95188 .39802 L
.95163 .39886 L
.94889 .40773 L
.94585 .41744 L
.94286 .42716 L
.94192 .43032 L
.93988 .43687 L
.93683 .44658 L
.9338 .45629 L
.93221 .46155 L
.93082 .46601 L
.92774 .47572 L
.92468 .48543 L
.92249 .49256 L
.92168 .49514 L
.9186 .50486 L
.9155 .51457 L
.91278 .52333 L
.91248 .52428 L
.90938 .53399 L
.90626 .54371 L
.90321 .55342 L
.90307 .55388 L
.9001 .56313 L
.89695 .57284 L
.89386 .58256 L
.89336 .58418 L
.89074 .59227 L
.88757 .60198 L
.88445 .61169 L
.88364 .61425 L
.88132 .62141 L
.87812 .63112 L
.87496 .64083 L
.87393 .64409 L
.87181 .65054 L
.8686 .66026 L
.86541 .66997 L
.86422 .67368 L
.86224 .67968 L
.85899 .68939 L
.85578 .69911 L
.85451 .70303 L
.85258 .70882 L
.84931 .71853 L
.84606 .72824 L
.84479 .73214 L
.84284 .73796 L
.83954 .74767 L
.83627 .75738 L
.83508 .761 L
.83302 .76709 L
.82969 .77681 L
.8264 .78652 L
.82537 .78961 L
.8231 .79623 L
.81975 .80594 L
.81643 .81566 L
.81566 .81797 L
.8131 .82537 L
.80972 .83508 L
.80638 .84479 L
.80594 .84608 L
.80301 .85451 L
.79959 .86422 L
.79623 .87393 L
.79623 .87394 L
.79281 .88364 L
.78937 .89336 L
.78652 .90154 L
.78598 .90307 L
.78252 .91278 L
.77905 .92249 L
.77681 .92888 L
.77562 .93221 L
.77212 .94192 L
.76862 .95163 L
.76709 .95595 L
.76515 .96134 L
.76161 .97106 L
.75809 .98077 L
.98077 .98077 L
F
0 g
.98077 .30312 m
.97817 .31061 L
.97541 .32032 L
.97261 .33003 L
.97106 .33526 L
.9697 .33974 L
.96671 .34946 L
.96372 .35917 L
.96134 .36717 L
.96082 .36888 L
.95783 .37859 L
.95481 .38831 L
.95188 .39802 L
.95163 .39886 L
.94889 .40773 L
.94585 .41744 L
.94286 .42716 L
.94192 .43032 L
.93988 .43687 L
.93683 .44658 L
.9338 .45629 L
.93221 .46155 L
.93082 .46601 L
.92774 .47572 L
.92468 .48543 L
.92249 .49256 L
.92168 .49514 L
.9186 .50486 L
.9155 .51457 L
.91278 .52333 L
.91248 .52428 L
.90938 .53399 L
.90626 .54371 L
.90321 .55342 L
.90307 .55388 L
.9001 .56313 L
.89695 .57284 L
.89386 .58256 L
.89336 .58418 L
.89074 .59227 L
.88757 .60198 L
.88445 .61169 L
.88364 .61425 L
.88132 .62141 L
.87812 .63112 L
.87496 .64083 L
.87393 .64409 L
.87181 .65054 L
.8686 .66026 L
.86541 .66997 L
Mistroke
.86422 .67368 L
.86224 .67968 L
.85899 .68939 L
.85578 .69911 L
.85451 .70303 L
.85258 .70882 L
.84931 .71853 L
.84606 .72824 L
.84479 .73214 L
.84284 .73796 L
.83954 .74767 L
.83627 .75738 L
.83508 .761 L
.83302 .76709 L
.82969 .77681 L
.8264 .78652 L
.82537 .78961 L
.8231 .79623 L
.81975 .80594 L
.81643 .81566 L
.81566 .81797 L
.8131 .82537 L
.80972 .83508 L
.80638 .84479 L
.80594 .84608 L
.80301 .85451 L
.79959 .86422 L
.79623 .87393 L
.79623 .87394 L
.79281 .88364 L
.78937 .89336 L
.78652 .90154 L
.78598 .90307 L
.78252 .91278 L
.77905 .92249 L
.77681 .92888 L
.77562 .93221 L
.77212 .94192 L
.76862 .95163 L
.76709 .95595 L
.76515 .96134 L
.76161 .97106 L
.75809 .98077 L
Mfstroke
.7 g
.98077 .32335 m
.97873 .33003 L
.97586 .33974 L
.97294 .34946 L
.97106 .35556 L
.96993 .35917 L
.96683 .36888 L
.96377 .37859 L
.96134 .38756 L
.96111 .38831 L
.95801 .39802 L
.9549 .40773 L
.95207 .41744 L
.95163 .41933 L
.94913 .42716 L
.94599 .43687 L
.94301 .44658 L
.94192 .45087 L
.94018 .45629 L
.93702 .46601 L
.93395 .47572 L
.93221 .48219 L
.93116 .48543 L
.92799 .49514 L
.92486 .50486 L
.92249 .51328 L
.92208 .51457 L
.9189 .52428 L
.91572 .53399 L
.91289 .54371 L
.91278 .54415 L
.90973 .55342 L
.90652 .56313 L
.90356 .57284 L
.90307 .57477 L
.9005 .58256 L
.89726 .59227 L
.89421 .60198 L
.89336 .60517 L
.89119 .61169 L
.88793 .62141 L
.88481 .63112 L
.88364 .63534 L
.88181 .64083 L
.87852 .65054 L
.87535 .66026 L
.87393 .66527 L
.87235 .66997 L
.86904 .67968 L
.86583 .68939 L
.86422 .69496 L
.86281 .69911 L
.85948 .70882 L
.85624 .71853 L
.85451 .72441 L
.8532 .72824 L
.84984 .73796 L
.84657 .74767 L
.84479 .75362 L
.8435 .75738 L
.84012 .76709 L
.83682 .77681 L
.83508 .78258 L
.83372 .78652 L
.83031 .79623 L
.827 .80594 L
.82537 .8113 L
.82385 .81566 L
.82041 .82537 L
.81709 .83508 L
.81566 .83977 L
.81389 .84479 L
.81043 .85451 L
.8071 .86422 L
.80594 .868 L
.80383 .87393 L
.80034 .88364 L
.79703 .89336 L
.79623 .89597 L
.79368 .90307 L
.79017 .91278 L
.78688 .92249 L
.78652 .92369 L
.78342 .93221 L
.7799 .94192 L
.77681 .95115 L
.77663 .95163 L
.77306 .96134 L
.76953 .97106 L
.76709 .97836 L
.7662 .98077 L
.98077 .98077 L
F
0 g
.98077 .32335 m
.97873 .33003 L
.97586 .33974 L
.97294 .34946 L
.97106 .35556 L
.96993 .35917 L
.96683 .36888 L
.96377 .37859 L
.96134 .38756 L
.96111 .38831 L
.95801 .39802 L
.9549 .40773 L
.95207 .41744 L
.95163 .41933 L
.94913 .42716 L
.94599 .43687 L
.94301 .44658 L
.94192 .45087 L
.94018 .45629 L
.93702 .46601 L
.93395 .47572 L
.93221 .48219 L
.93116 .48543 L
.92799 .49514 L
.92486 .50486 L
.92249 .51328 L
.92208 .51457 L
.9189 .52428 L
.91572 .53399 L
.91289 .54371 L
.91278 .54415 L
.90973 .55342 L
.90652 .56313 L
.90356 .57284 L
.90307 .57477 L
.9005 .58256 L
.89726 .59227 L
.89421 .60198 L
.89336 .60517 L
.89119 .61169 L
.88793 .62141 L
.88481 .63112 L
.88364 .63534 L
.88181 .64083 L
.87852 .65054 L
.87535 .66026 L
.87393 .66527 L
.87235 .66997 L
.86904 .67968 L
.86583 .68939 L
Mistroke
.86422 .69496 L
.86281 .69911 L
.85948 .70882 L
.85624 .71853 L
.85451 .72441 L
.8532 .72824 L
.84984 .73796 L
.84657 .74767 L
.84479 .75362 L
.8435 .75738 L
.84012 .76709 L
.83682 .77681 L
.83508 .78258 L
.83372 .78652 L
.83031 .79623 L
.827 .80594 L
.82537 .8113 L
.82385 .81566 L
.82041 .82537 L
.81709 .83508 L
.81566 .83977 L
.81389 .84479 L
.81043 .85451 L
.8071 .86422 L
.80594 .868 L
.80383 .87393 L
.80034 .88364 L
.79703 .89336 L
.79623 .89597 L
.79368 .90307 L
.79017 .91278 L
.78688 .92249 L
.78652 .92369 L
.78342 .93221 L
.7799 .94192 L
.77681 .95115 L
.77663 .95163 L
.77306 .96134 L
.76953 .97106 L
.76709 .97836 L
.7662 .98077 L
Mfstroke
.8 g
.98077 .34772 m
.98029 .34946 L
.97755 .35917 L
.97469 .36888 L
.97157 .37859 L
.97106 .38007 L
.96797 .38831 L
.96567 .39802 L
.96272 .40773 L
.96134 .41219 L
.95943 .41744 L
.95518 .42716 L
.95387 .43687 L
.95163 .44412 L
.95075 .44658 L
.94678 .45629 L
.94496 .46601 L
.94195 .47572 L
.94192 .47583 L
.93818 .48543 L
.93599 .49514 L
.93297 .50486 L
.93221 .50728 L
.92943 .51457 L
.92479 .52428 L
.92393 .53399 L
.92249 .53853 L
.92056 .54371 L
.91618 .55342 L
.91483 .56313 L
.91278 .56956 L
.91157 .57284 L
.90739 .58256 L
.90566 .59227 L
.90307 .60037 L
.90248 .60198 L
.89844 .61169 L
.89642 .62141 L
.89336 .63096 L
.8933 .63112 L
.88935 .64083 L
.88712 .65054 L
.88398 .66026 L
.88364 .66128 L
.88015 .66997 L
.87775 .67968 L
.87459 .68939 L
.87393 .69138 L
.87084 .69911 L
.86831 .70882 L
.86513 .71853 L
.86422 .72126 L
.86143 .72824 L
.85879 .73796 L
.85559 .74767 L
.85451 .7509 L
.85191 .75738 L
.84705 .76709 L
.84598 .77681 L
.84479 .78031 L
.8423 .78652 L
.83743 .79623 L
.83629 .80594 L
.83508 .80948 L
.83258 .81566 L
.82766 .82537 L
.82652 .83508 L
.82537 .83842 L
.82275 .84479 L
.81997 .85451 L
.81666 .86422 L
.81566 .86712 L
.81282 .87393 L
.81006 .88364 L
.80672 .89336 L
.80594 .89557 L
.80276 .90307 L
.80006 .91278 L
.79669 .92249 L
.79623 .92379 L
.79258 .93221 L
.78998 .94192 L
.78657 .95163 L
.78652 .95178 L
.78224 .96134 L
.77979 .97106 L
.77681 .97952 L
.77629 .98077 L
.98077 .98077 L
F
0 g
.98077 .34772 m
.98029 .34946 L
.97755 .35917 L
.97469 .36888 L
.97157 .37859 L
.97106 .38007 L
.96797 .38831 L
.96567 .39802 L
.96272 .40773 L
.96134 .41219 L
.95943 .41744 L
.95518 .42716 L
.95387 .43687 L
.95163 .44412 L
.95075 .44658 L
.94678 .45629 L
.94496 .46601 L
.94195 .47572 L
.94192 .47583 L
.93818 .48543 L
.93599 .49514 L
.93297 .50486 L
.93221 .50728 L
.92943 .51457 L
.92479 .52428 L
.92393 .53399 L
.92249 .53853 L
.92056 .54371 L
.91618 .55342 L
.91483 .56313 L
.91278 .56956 L
.91157 .57284 L
.90739 .58256 L
.90566 .59227 L
.90307 .60037 L
.90248 .60198 L
.89844 .61169 L
.89642 .62141 L
.89336 .63096 L
.8933 .63112 L
.88935 .64083 L
.88712 .65054 L
.88398 .66026 L
.88364 .66128 L
.88015 .66997 L
.87775 .67968 L
.87459 .68939 L
.87393 .69138 L
.87084 .69911 L
.86831 .70882 L
Mistroke
.86513 .71853 L
.86422 .72126 L
.86143 .72824 L
.85879 .73796 L
.85559 .74767 L
.85451 .7509 L
.85191 .75738 L
.84705 .76709 L
.84598 .77681 L
.84479 .78031 L
.8423 .78652 L
.83743 .79623 L
.83629 .80594 L
.83508 .80948 L
.83258 .81566 L
.82766 .82537 L
.82652 .83508 L
.82537 .83842 L
.82275 .84479 L
.81997 .85451 L
.81666 .86422 L
.81566 .86712 L
.81282 .87393 L
.81006 .88364 L
.80672 .89336 L
.80594 .89557 L
.80276 .90307 L
.80006 .91278 L
.79669 .92249 L
.79623 .92379 L
.79258 .93221 L
.78998 .94192 L
.78657 .95163 L
.78652 .95178 L
.78224 .96134 L
.77979 .97106 L
.77681 .97952 L
.77629 .98077 L
Mfstroke
.7 g
.98077 .44065 m
.97901 .44658 L
.97607 .45629 L
.97307 .46601 L
.97106 .4725 L
.97005 .47572 L
.96705 .48543 L
.96488 .49514 L
.96134 .50411 L
.96111 .50486 L
.95808 .51457 L
.95623 .52428 L
.95218 .53399 L
.95163 .5355 L
.94905 .54371 L
.94757 .55342 L
.94325 .56313 L
.94192 .56667 L
.93996 .57284 L
.93888 .58256 L
.93426 .59227 L
.93221 .5976 L
.9308 .60198 L
.92771 .61169 L
.92522 .62141 L
.92249 .62828 L
.92157 .63112 L
.91846 .64083 L
.91611 .65054 L
.91278 .65872 L
.91228 .66026 L
.90914 .66997 L
.90692 .67968 L
.90307 .68891 L
.90291 .68939 L
.89974 .69911 L
.89764 .70882 L
.89349 .71853 L
.89336 .71887 L
.89027 .72824 L
.88825 .73796 L
.884 .74767 L
.88364 .7486 L
.88073 .75738 L
.87876 .76709 L
.87442 .77681 L
.87393 .77807 L
.8711 .78652 L
.86914 .79623 L
.86475 .80594 L
.86422 .80729 L
.86139 .81566 L
.85939 .82537 L
.85497 .83508 L
.85451 .83626 L
.8516 .84479 L
.84951 .85451 L
.8451 .86422 L
.84479 .86498 L
.84172 .87393 L
.8395 .88364 L
.83511 .89336 L
.83508 .89343 L
.83174 .90307 L
.82936 .91278 L
.82537 .92165 L
.82507 .92249 L
.82167 .93221 L
.81909 .94192 L
.81566 .9496 L
.81493 .95163 L
.81151 .96134 L
.8087 .97106 L
.80594 .97698 L
.80469 .98077 L
.98077 .98077 L
F
0 g
.98077 .44065 m
.97901 .44658 L
.97607 .45629 L
.97307 .46601 L
.97106 .4725 L
.97005 .47572 L
.96705 .48543 L
.96488 .49514 L
.96134 .50411 L
.96111 .50486 L
.95808 .51457 L
.95623 .52428 L
.95218 .53399 L
.95163 .5355 L
.94905 .54371 L
.94757 .55342 L
.94325 .56313 L
.94192 .56667 L
.93996 .57284 L
.93888 .58256 L
.93426 .59227 L
.93221 .5976 L
.9308 .60198 L
.92771 .61169 L
.92522 .62141 L
.92249 .62828 L
.92157 .63112 L
.91846 .64083 L
.91611 .65054 L
.91278 .65872 L
.91228 .66026 L
.90914 .66997 L
.90692 .67968 L
.90307 .68891 L
.90291 .68939 L
.89974 .69911 L
.89764 .70882 L
.89349 .71853 L
.89336 .71887 L
.89027 .72824 L
.88825 .73796 L
.884 .74767 L
.88364 .7486 L
.88073 .75738 L
.87876 .76709 L
.87442 .77681 L
.87393 .77807 L
.8711 .78652 L
.86914 .79623 L
.86475 .80594 L
Mistroke
.86422 .80729 L
.86139 .81566 L
.85939 .82537 L
.85497 .83508 L
.85451 .83626 L
.8516 .84479 L
.84951 .85451 L
.8451 .86422 L
.84479 .86498 L
.84172 .87393 L
.8395 .88364 L
.83511 .89336 L
.83508 .89343 L
.83174 .90307 L
.82936 .91278 L
.82537 .92165 L
.82507 .92249 L
.82167 .93221 L
.81909 .94192 L
.81566 .9496 L
.81493 .95163 L
.81151 .96134 L
.8087 .97106 L
.80594 .97698 L
.80469 .98077 L
Mfstroke
.6 g
.98077 .465 m
.98047 .46601 L
.97757 .47572 L
.97461 .48543 L
.97139 .49514 L
.97106 .49699 L
.96899 .50486 L
.96592 .51457 L
.96277 .52428 L
.96134 .52876 L
.96003 .53399 L
.95702 .54371 L
.95385 .55342 L
.95163 .5603 L
.95096 .56313 L
.94804 .57284 L
.94486 .58256 L
.94192 .5916 L
.94177 .59227 L
.93899 .60198 L
.93581 .61169 L
.93262 .62141 L
.93221 .62268 L
.92986 .63112 L
.9267 .64083 L
.92347 .65054 L
.92249 .65353 L
.92066 .66026 L
.91751 .66997 L
.91426 .67968 L
.91278 .68414 L
.91137 .68939 L
.90824 .69911 L
.90497 .70882 L
.90307 .71452 L
.902 .71853 L
.8989 .72824 L
.89561 .73796 L
.89336 .74465 L
.89256 .74767 L
.88949 .75738 L
.88617 .76709 L
.88364 .77455 L
.88305 .77681 L
.87999 .78652 L
.87666 .79623 L
.87393 .80421 L
.87348 .80594 L
.87042 .81566 L
.86706 .82537 L
.86422 .83362 L
.86383 .83508 L
.86076 .84479 L
.85738 .85451 L
.85451 .86278 L
.85412 .86422 L
.85102 .87393 L
.84762 .88364 L
.84479 .8917 L
.84434 .89336 L
.84119 .90307 L
.83776 .91278 L
.83508 .92037 L
.83448 .92249 L
.83128 .93221 L
.82781 .94192 L
.82537 .94879 L
.82454 .95163 L
.82126 .96134 L
.81777 .97106 L
.81566 .97692 L
.81451 .98077 L
.98077 .98077 L
F
0 g
.98077 .465 m
.98047 .46601 L
.97757 .47572 L
.97461 .48543 L
.97139 .49514 L
.97106 .49699 L
.96899 .50486 L
.96592 .51457 L
.96277 .52428 L
.96134 .52876 L
.96003 .53399 L
.95702 .54371 L
.95385 .55342 L
.95163 .5603 L
.95096 .56313 L
.94804 .57284 L
.94486 .58256 L
.94192 .5916 L
.94177 .59227 L
.93899 .60198 L
.93581 .61169 L
.93262 .62141 L
.93221 .62268 L
.92986 .63112 L
.9267 .64083 L
.92347 .65054 L
.92249 .65353 L
.92066 .66026 L
.91751 .66997 L
.91426 .67968 L
.91278 .68414 L
.91137 .68939 L
.90824 .69911 L
.90497 .70882 L
.90307 .71452 L
.902 .71853 L
.8989 .72824 L
.89561 .73796 L
.89336 .74465 L
.89256 .74767 L
.88949 .75738 L
.88617 .76709 L
.88364 .77455 L
.88305 .77681 L
.87999 .78652 L
.87666 .79623 L
.87393 .80421 L
.87348 .80594 L
.87042 .81566 L
.86706 .82537 L
Mistroke
.86422 .83362 L
.86383 .83508 L
.86076 .84479 L
.85738 .85451 L
.85451 .86278 L
.85412 .86422 L
.85102 .87393 L
.84762 .88364 L
.84479 .8917 L
.84434 .89336 L
.84119 .90307 L
.83776 .91278 L
.83508 .92037 L
.83448 .92249 L
.83128 .93221 L
.82781 .94192 L
.82537 .94879 L
.82454 .95163 L
.82126 .96134 L
.81777 .97106 L
.81566 .97692 L
.81451 .98077 L
Mfstroke
.5 g
.98077 .48523 m
.98071 .48543 L
.97591 .49514 L
.97421 .50486 L
.97182 .51457 L
.97106 .5173 L
.96901 .52428 L
.96603 .53399 L
.96301 .54371 L
.96134 .54915 L
.96009 .55342 L
.95712 .56313 L
.95409 .57284 L
.95163 .58076 L
.95111 .58256 L
.94815 .59227 L
.9451 .60198 L
.94206 .61169 L
.94192 .61216 L
.93911 .62141 L
.93605 .63112 L
.93298 .64083 L
.93221 .64332 L
.93001 .65054 L
.92694 .66026 L
.92385 .66997 L
.92249 .67425 L
.92084 .67968 L
.91776 .68939 L
.91464 .69911 L
.91278 .70495 L
.9116 .70882 L
.90852 .71853 L
.90537 .72824 L
.90307 .73541 L
.90229 .73796 L
.8992 .74767 L
.89604 .75738 L
.89336 .76564 L
.89291 .76709 L
.88981 .77681 L
.88663 .78652 L
.88364 .79563 L
.88346 .79623 L
.88035 .80594 L
.87714 .81566 L
.87394 .82537 L
.87393 .82539 L
.87081 .83508 L
.86758 .84479 L
.86435 .85451 L
.86422 .8549 L
.86119 .86422 L
.85794 .87393 L
.85468 .88364 L
.85451 .88416 L
.85149 .89336 L
.84821 .90307 L
.84493 .91278 L
.84479 .91318 L
.84171 .92249 L
.83841 .93221 L
.83509 .94192 L
.83508 .94195 L
.83185 .95163 L
.82851 .96134 L
.82537 .97048 L
.82518 .97106 L
.82189 .98077 L
.98077 .98077 L
F
0 g
.98077 .48523 m
.98071 .48543 L
.97591 .49514 L
.97421 .50486 L
.97182 .51457 L
.97106 .5173 L
.96901 .52428 L
.96603 .53399 L
.96301 .54371 L
.96134 .54915 L
.96009 .55342 L
.95712 .56313 L
.95409 .57284 L
.95163 .58076 L
.95111 .58256 L
.94815 .59227 L
.9451 .60198 L
.94206 .61169 L
.94192 .61216 L
.93911 .62141 L
.93605 .63112 L
.93298 .64083 L
.93221 .64332 L
.93001 .65054 L
.92694 .66026 L
.92385 .66997 L
.92249 .67425 L
.92084 .67968 L
.91776 .68939 L
.91464 .69911 L
.91278 .70495 L
.9116 .70882 L
.90852 .71853 L
.90537 .72824 L
.90307 .73541 L
.90229 .73796 L
.8992 .74767 L
.89604 .75738 L
.89336 .76564 L
.89291 .76709 L
.88981 .77681 L
.88663 .78652 L
.88364 .79563 L
.88346 .79623 L
.88035 .80594 L
.87714 .81566 L
.87394 .82537 L
.87393 .82539 L
.87081 .83508 L
.86758 .84479 L
Mistroke
.86435 .85451 L
.86422 .8549 L
.86119 .86422 L
.85794 .87393 L
.85468 .88364 L
.85451 .88416 L
.85149 .89336 L
.84821 .90307 L
.84493 .91278 L
.84479 .91318 L
.84171 .92249 L
.83841 .93221 L
.83509 .94192 L
.83508 .94195 L
.83185 .95163 L
.82851 .96134 L
.82537 .97048 L
.82518 .97106 L
.82189 .98077 L
Mfstroke
.4 g
.98077 .50451 m
.98062 .50486 L
.97742 .51457 L
.97468 .52428 L
.97185 .53399 L
.97106 .53664 L
.96891 .54371 L
.96591 .55342 L
.96294 .56313 L
.96134 .56855 L
.96003 .57284 L
.95703 .58256 L
.95402 .59227 L
.95163 .60024 L
.9511 .60198 L
.94808 .61169 L
.94505 .62141 L
.94209 .63112 L
.94192 .6317 L
.93908 .64083 L
.93602 .65054 L
.93301 .66026 L
.93221 .66294 L
.93001 .66997 L
.92693 .67968 L
.92388 .68939 L
.92249 .69394 L
.92087 .69911 L
.91777 .70882 L
.91469 .71853 L
.91278 .72472 L
.91167 .72824 L
.90855 .73796 L
.90544 .74767 L
.90307 .75526 L
.90239 .75738 L
.89926 .76709 L
.89612 .77681 L
.89336 .78557 L
.89305 .78652 L
.8899 .79623 L
.88673 .80594 L
.88364 .81564 L
.88364 .81566 L
.88047 .82537 L
.87728 .83508 L
.87414 .84479 L
.87393 .84547 L
.87096 .85451 L
.86774 .86422 L
.86458 .87393 L
.86422 .87506 L
.86138 .88364 L
.85813 .89336 L
.85494 .90307 L
.85451 .90441 L
.85171 .91278 L
.84844 .92249 L
.84522 .93221 L
.84479 .93352 L
.84197 .94192 L
.83867 .95163 L
.83542 .96134 L
.83508 .96238 L
.83213 .97106 L
.82881 .98077 L
.98077 .98077 L
F
0 g
.98077 .50451 m
.98062 .50486 L
.97742 .51457 L
.97468 .52428 L
.97185 .53399 L
.97106 .53664 L
.96891 .54371 L
.96591 .55342 L
.96294 .56313 L
.96134 .56855 L
.96003 .57284 L
.95703 .58256 L
.95402 .59227 L
.95163 .60024 L
.9511 .60198 L
.94808 .61169 L
.94505 .62141 L
.94209 .63112 L
.94192 .6317 L
.93908 .64083 L
.93602 .65054 L
.93301 .66026 L
.93221 .66294 L
.93001 .66997 L
.92693 .67968 L
.92388 .68939 L
.92249 .69394 L
.92087 .69911 L
.91777 .70882 L
.91469 .71853 L
.91278 .72472 L
.91167 .72824 L
.90855 .73796 L
.90544 .74767 L
.90307 .75526 L
.90239 .75738 L
.89926 .76709 L
.89612 .77681 L
.89336 .78557 L
.89305 .78652 L
.8899 .79623 L
.88673 .80594 L
.88364 .81564 L
.88364 .81566 L
.88047 .82537 L
.87728 .83508 L
.87414 .84479 L
.87393 .84547 L
.87096 .85451 L
.86774 .86422 L
Mistroke
.86458 .87393 L
.86422 .87506 L
.86138 .88364 L
.85813 .89336 L
.85494 .90307 L
.85451 .90441 L
.85171 .91278 L
.84844 .92249 L
.84522 .93221 L
.84479 .93352 L
.84197 .94192 L
.83867 .95163 L
.83542 .96134 L
.83508 .96238 L
.83213 .97106 L
.82881 .98077 L
Mfstroke
.3 g
.98077 .52474 m
.97797 .53399 L
.97509 .54371 L
.97215 .55342 L
.97106 .55695 L
.96911 .56313 L
.96601 .57284 L
.963 .58256 L
.96134 .58894 L
.9603 .59227 L
.95718 .60198 L
.9541 .61169 L
.95163 .62071 L
.95141 .62141 L
.9483 .63112 L
.94517 .64083 L
.94233 .65054 L
.94192 .65225 L
.93935 .66026 L
.93619 .66997 L
.9332 .67968 L
.93221 .68357 L
.93033 .68939 L
.92715 .69911 L
.92407 .70882 L
.92249 .71466 L
.92124 .71853 L
.91805 .72824 L
.91491 .73796 L
.91278 .74553 L
.91209 .74767 L
.90888 .75738 L
.90569 .76709 L
.90307 .77616 L
.90286 .77681 L
.89964 .78652 L
.89641 .79623 L
.89351 .80594 L
.89336 .80656 L
.89032 .81566 L
.88707 .82537 L
.88407 .83508 L
.88364 .83672 L
.88094 .84479 L
.87766 .85451 L
.87459 .86422 L
.87393 .86665 L
.87147 .87393 L
.86817 .88364 L
.86505 .89336 L
.86422 .89634 L
.86193 .90307 L
.8586 .91278 L
.85544 .92249 L
.85451 .92579 L
.85231 .93221 L
.84896 .94192 L
.84576 .95163 L
.84479 .955 L
.84261 .96134 L
.83923 .97106 L
.83601 .98077 L
.98077 .98077 L
F
0 g
.98077 .52474 m
.97797 .53399 L
.97509 .54371 L
.97215 .55342 L
.97106 .55695 L
.96911 .56313 L
.96601 .57284 L
.963 .58256 L
.96134 .58894 L
.9603 .59227 L
.95718 .60198 L
.9541 .61169 L
.95163 .62071 L
.95141 .62141 L
.9483 .63112 L
.94517 .64083 L
.94233 .65054 L
.94192 .65225 L
.93935 .66026 L
.93619 .66997 L
.9332 .67968 L
.93221 .68357 L
.93033 .68939 L
.92715 .69911 L
.92407 .70882 L
.92249 .71466 L
.92124 .71853 L
.91805 .72824 L
.91491 .73796 L
.91278 .74553 L
.91209 .74767 L
.90888 .75738 L
.90569 .76709 L
.90307 .77616 L
.90286 .77681 L
.89964 .78652 L
.89641 .79623 L
.89351 .80594 L
.89336 .80656 L
.89032 .81566 L
.88707 .82537 L
.88407 .83508 L
.88364 .83672 L
.88094 .84479 L
.87766 .85451 L
.87459 .86422 L
.87393 .86665 L
.87147 .87393 L
.86817 .88364 L
.86505 .89336 L
Mistroke
.86422 .89634 L
.86193 .90307 L
.8586 .91278 L
.85544 .92249 L
.85451 .92579 L
.85231 .93221 L
.84896 .94192 L
.84576 .95163 L
.84479 .955 L
.84261 .96134 L
.83923 .97106 L
.83601 .98077 L
Mfstroke
.2 g
.98077 .54909 m
.97957 .55342 L
.97681 .56313 L
.97389 .57284 L
.97106 .58146 L
.97067 .58256 L
.96688 .59227 L
.96489 .60198 L
.96193 .61169 L
.96134 .61358 L
.95841 .62141 L
.95378 .63112 L
.95308 .64083 L
.95163 .64549 L
.94978 .65054 L
.94552 .66026 L
.94417 .66997 L
.94192 .6772 L
.94103 .67968 L
.93702 .68939 L
.9352 .69911 L
.93221 .70869 L
.93216 .70882 L
.92834 .71853 L
.92616 .72824 L
.92312 .73796 L
.92249 .73992 L
.91951 .74767 L
.91707 .75738 L
.91401 .76709 L
.91278 .77094 L
.91055 .77681 L
.90605 .78652 L
.90484 .79623 L
.90307 .80174 L
.90149 .80594 L
.89717 .81566 L
.8956 .82537 L
.89336 .83232 L
.89233 .83508 L
.88813 .84479 L
.88629 .85451 L
.88364 .86267 L
.88307 .86422 L
.87897 .87393 L
.87691 .88364 L
.87393 .89279 L
.87372 .89336 L
.86968 .90307 L
.86747 .91278 L
.86428 .92249 L
.86422 .92267 L
.86028 .93221 L
.85795 .94192 L
.85474 .95163 L
.85451 .95231 L
.85076 .96134 L
.84835 .97106 L
.84512 .98077 L
.98077 .98077 L
F
0 g
.98077 .54909 m
.97957 .55342 L
.97681 .56313 L
.97389 .57284 L
.97106 .58146 L
.97067 .58256 L
.96688 .59227 L
.96489 .60198 L
.96193 .61169 L
.96134 .61358 L
.95841 .62141 L
.95378 .63112 L
.95308 .64083 L
.95163 .64549 L
.94978 .65054 L
.94552 .66026 L
.94417 .66997 L
.94192 .6772 L
.94103 .67968 L
.93702 .68939 L
.9352 .69911 L
.93221 .70869 L
.93216 .70882 L
.92834 .71853 L
.92616 .72824 L
.92312 .73796 L
.92249 .73992 L
.91951 .74767 L
.91707 .75738 L
.91401 .76709 L
.91278 .77094 L
.91055 .77681 L
.90605 .78652 L
.90484 .79623 L
.90307 .80174 L
.90149 .80594 L
.89717 .81566 L
.8956 .82537 L
.89336 .83232 L
.89233 .83508 L
.88813 .84479 L
.88629 .85451 L
.88364 .86267 L
.88307 .86422 L
.87897 .87393 L
.87691 .88364 L
.87393 .89279 L
.87372 .89336 L
.86968 .90307 L
.86747 .91278 L
Mistroke
.86428 .92249 L
.86422 .92267 L
.86028 .93221 L
.85795 .94192 L
.85474 .95163 L
.85451 .95231 L
.85076 .96134 L
.84835 .97106 L
.84512 .98077 L
Mfstroke
.3 g
.98077 .64202 m
.97824 .65054 L
.97528 .66026 L
.97226 .66997 L
.97106 .67388 L
.96925 .67968 L
.96845 .68939 L
.96379 .69911 L
.96134 .70551 L
.9603 .70882 L
.95728 .71853 L
.95505 .72824 L
.95163 .73688 L
.95129 .73796 L
.94824 .74767 L
.94629 .75738 L
.94226 .76709 L
.94192 .76803 L
.93914 .77681 L
.93749 .78652 L
.93323 .79623 L
.93221 .79897 L
.92998 .80594 L
.92865 .81566 L
.92414 .82537 L
.92249 .82966 L
.92074 .83508 L
.91974 .84479 L
.91499 .85451 L
.91278 .86011 L
.91144 .86422 L
.90831 .87393 L
.90575 .88364 L
.90307 .89032 L
.90207 .89336 L
.8989 .90307 L
.89643 .91278 L
.89336 .92028 L
.89262 .92249 L
.88943 .93221 L
.88701 .94192 L
.88364 .95 L
.88309 .95163 L
.87988 .96134 L
.87749 .97106 L
.87393 .97928 L
.87349 .98077 L
.98077 .98077 L
F
0 g
.98077 .64202 m
.97824 .65054 L
.97528 .66026 L
.97226 .66997 L
.97106 .67388 L
.96925 .67968 L
.96845 .68939 L
.96379 .69911 L
.96134 .70551 L
.9603 .70882 L
.95728 .71853 L
.95505 .72824 L
.95163 .73688 L
.95129 .73796 L
.94824 .74767 L
.94629 .75738 L
.94226 .76709 L
.94192 .76803 L
.93914 .77681 L
.93749 .78652 L
.93323 .79623 L
.93221 .79897 L
.92998 .80594 L
.92865 .81566 L
.92414 .82537 L
.92249 .82966 L
.92074 .83508 L
.91974 .84479 L
.91499 .85451 L
.91278 .86011 L
.91144 .86422 L
.90831 .87393 L
.90575 .88364 L
.90307 .89032 L
.90207 .89336 L
.8989 .90307 L
.89643 .91278 L
.89336 .92028 L
.89262 .92249 L
.88943 .93221 L
.88701 .94192 L
.88364 .95 L
.88309 .95163 L
.87988 .96134 L
.87749 .97106 L
.87393 .97928 L
.87349 .98077 L
s
.4 g
.98077 .66639 m
.97971 .66997 L
.97679 .67968 L
.97118 .68939 L
.97106 .69838 L
.9709 .69911 L
.9682 .70882 L
.96508 .71853 L
.96195 .72824 L
.96134 .73014 L
.95927 .73796 L
.95618 .74767 L
.95301 .75738 L
.95163 .76168 L
.95025 .76709 L
.94721 .77681 L
.94402 .78652 L
.94192 .79299 L
.94112 .79623 L
.93816 .80594 L
.93496 .81566 L
.93221 .82407 L
.9319 .82537 L
.92904 .83508 L
.92584 .84479 L
.92263 .85451 L
.92249 .85491 L
.91985 .86422 L
.91664 .87393 L
.9134 .88364 L
.91278 .88552 L
.91058 .89336 L
.90737 .90307 L
.90411 .91278 L
.90307 .9159 L
.90123 .92249 L
.89803 .93221 L
.89474 .94192 L
.89336 .94604 L
.8918 .95163 L
.88861 .96134 L
.88529 .97106 L
.88364 .97591 L
.8823 .98077 L
.98077 .98077 L
F
0 g
.98077 .66639 m
.97971 .66997 L
.97679 .67968 L
.97118 .68939 L
.97106 .69838 L
.9709 .69911 L
.9682 .70882 L
.96508 .71853 L
.96195 .72824 L
.96134 .73014 L
.95927 .73796 L
.95618 .74767 L
.95301 .75738 L
.95163 .76168 L
.95025 .76709 L
.94721 .77681 L
.94402 .78652 L
.94192 .79299 L
.94112 .79623 L
.93816 .80594 L
.93496 .81566 L
.93221 .82407 L
.9319 .82537 L
.92904 .83508 L
.92584 .84479 L
.92263 .85451 L
.92249 .85491 L
.91985 .86422 L
.91664 .87393 L
.9134 .88364 L
.91278 .88552 L
.91058 .89336 L
.90737 .90307 L
.90411 .91278 L
.90307 .9159 L
.90123 .92249 L
.89803 .93221 L
.89474 .94192 L
.89336 .94604 L
.8918 .95163 L
.88861 .96134 L
.88529 .97106 L
.88364 .97591 L
.8823 .98077 L
s
.5 g
.98077 .68662 m
.97795 .68939 L
.97552 .69911 L
.97364 .70882 L
.9711 .71853 L
.97106 .71869 L
.96822 .72824 L
.96522 .73796 L
.96222 .74767 L
.96134 .75053 L
.95931 .75738 L
.95631 .76709 L
.95328 .77681 L
.95163 .78215 L
.95034 .78652 L
.94734 .79623 L
.94429 .80594 L
.94192 .81354 L
.94129 .81566 L
.93831 .82537 L
.93524 .83508 L
.93221 .8447 L
.93218 .84479 L
.9292 .85451 L
.92612 .86422 L
.92303 .87393 L
.92249 .87563 L
.92003 .88364 L
.91693 .89336 L
.91382 .90307 L
.91278 .90633 L
.91079 .91278 L
.90768 .92249 L
.90454 .93221 L
.90307 .9368 L
.90148 .94192 L
.89836 .95163 L
.8952 .96134 L
.89336 .96703 L
.8921 .97106 L
.88897 .98077 L
.98077 .98077 L
F
0 g
.98077 .68662 m
.97795 .68939 L
.97552 .69911 L
.97364 .70882 L
.9711 .71853 L
.97106 .71869 L
.96822 .72824 L
.96522 .73796 L
.96222 .74767 L
.96134 .75053 L
.95931 .75738 L
.95631 .76709 L
.95328 .77681 L
.95163 .78215 L
.95034 .78652 L
.94734 .79623 L
.94429 .80594 L
.94192 .81354 L
.94129 .81566 L
.93831 .82537 L
.93524 .83508 L
.93221 .8447 L
.93218 .84479 L
.9292 .85451 L
.92612 .86422 L
.92303 .87393 L
.92249 .87563 L
.92003 .88364 L
.91693 .89336 L
.91382 .90307 L
.91278 .90633 L
.91079 .91278 L
.90768 .92249 L
.90454 .93221 L
.90307 .9368 L
.90148 .94192 L
.89836 .95163 L
.8952 .96134 L
.89336 .96703 L
.8921 .97106 L
.88897 .98077 L
s
.6 g
.98077 .70589 m
.97963 .70882 L
.97669 .71853 L
.97394 .72824 L
.97108 .73796 L
.97106 .73803 L
.96811 .74767 L
.96512 .75738 L
.96217 .76709 L
.96134 .76994 L
.95924 .77681 L
.95623 .78652 L
.95324 .79623 L
.95163 .80162 L
.9503 .80594 L
.94728 .81566 L
.94425 .82537 L
.94192 .83309 L
.9413 .83508 L
.93826 .84479 L
.93521 .85451 L
.93224 .86422 L
.93221 .86432 L
.92919 .87393 L
.92611 .88364 L
.92309 .89336 L
.92249 .89533 L
.92005 .90307 L
.91695 .91278 L
.91389 .92249 L
.91278 .9261 L
.91084 .93221 L
.90772 .94192 L
.90462 .95163 L
.90307 .95664 L
.90157 .96134 L
.89843 .97106 L
.8953 .98077 L
.98077 .98077 L
F
0 g
.98077 .70589 m
.97963 .70882 L
.97669 .71853 L
.97394 .72824 L
.97108 .73796 L
.97106 .73803 L
.96811 .74767 L
.96512 .75738 L
.96217 .76709 L
.96134 .76994 L
.95924 .77681 L
.95623 .78652 L
.95324 .79623 L
.95163 .80162 L
.9503 .80594 L
.94728 .81566 L
.94425 .82537 L
.94192 .83309 L
.9413 .83508 L
.93826 .84479 L
.93521 .85451 L
.93224 .86422 L
.93221 .86432 L
.92919 .87393 L
.92611 .88364 L
.92309 .89336 L
.92249 .89533 L
.92005 .90307 L
.91695 .91278 L
.91389 .92249 L
.91278 .9261 L
.91084 .93221 L
.90772 .94192 L
.90462 .95163 L
.90307 .95664 L
.90157 .96134 L
.89843 .97106 L
.8953 .98077 L
s
.7 g
.98077 .72612 m
.9801 .72824 L
.97721 .73796 L
.97432 .74767 L
.97135 .75738 L
.97106 .75833 L
.96829 .76709 L
.96519 .77681 L
.96228 .78652 L
.96134 .79032 L
.95948 .79623 L
.95635 .80594 L
.95333 .81566 L
.95163 .82209 L
.95059 .82537 L
.94746 .83508 L
.94436 .84479 L
.94192 .85364 L
.94164 .85451 L
.93851 .86422 L
.93536 .87393 L
.93252 .88364 L
.93221 .88496 L
.92949 .89336 L
.92631 .90307 L
.92333 .91278 L
.92249 .91605 L
.9204 .92249 L
.9172 .93221 L
.91413 .94192 L
.91278 .94691 L
.91124 .95163 L
.90802 .96134 L
.90488 .97106 L
.90307 .97755 L
.90201 .98077 L
.98077 .98077 L
F
0 g
.98077 .72612 m
.9801 .72824 L
.97721 .73796 L
.97432 .74767 L
.97135 .75738 L
.97106 .75833 L
.96829 .76709 L
.96519 .77681 L
.96228 .78652 L
.96134 .79032 L
.95948 .79623 L
.95635 .80594 L
.95333 .81566 L
.95163 .82209 L
.95059 .82537 L
.94746 .83508 L
.94436 .84479 L
.94192 .85364 L
.94164 .85451 L
.93851 .86422 L
.93536 .87393 L
.93252 .88364 L
.93221 .88496 L
.92949 .89336 L
.92631 .90307 L
.92333 .91278 L
.92249 .91605 L
.9204 .92249 L
.9172 .93221 L
.91413 .94192 L
.91278 .94691 L
.91124 .95163 L
.90802 .96134 L
.90488 .97106 L
.90307 .97755 L
.90201 .98077 L
s
.8 g
.98077 .75047 m
.97884 .75738 L
.97605 .76709 L
.97307 .77681 L
.97106 .78283 L
.96974 .78652 L
.9657 .79623 L
.96411 .80594 L
.96134 .81498 L
.96111 .81566 L
.95732 .82537 L
.95526 .83508 L
.95228 .84479 L
.95163 .84688 L
.94876 .85451 L
.94413 .86422 L
.94337 .87393 L
.94192 .87857 L
.94005 .88364 L
.93576 .89336 L
.93439 .90307 L
.93221 .91006 L
.93122 .91278 L
.92716 .92249 L
.92536 .93221 L
.92249 .94132 L
.92228 .94192 L
.91839 .95163 L
.91626 .96134 L
.91319 .97106 L
.91278 .97236 L
.90948 .98077 L
.98077 .98077 L
F
0 g
.98077 .75047 m
.97884 .75738 L
.97605 .76709 L
.97307 .77681 L
.97106 .78283 L
.96974 .78652 L
.9657 .79623 L
.96411 .80594 L
.96134 .81498 L
.96111 .81566 L
.95732 .82537 L
.95526 .83508 L
.95228 .84479 L
.95163 .84688 L
.94876 .85451 L
.94413 .86422 L
.94337 .87393 L
.94192 .87857 L
.94005 .88364 L
.93576 .89336 L
.93439 .90307 L
.93221 .91006 L
.93122 .91278 L
.92716 .92249 L
.92536 .93221 L
.92249 .94132 L
.92228 .94192 L
.91839 .95163 L
.91626 .96134 L
.91319 .97106 L
.91278 .97236 L
.90948 .98077 L
s
.7 g
.98077 .84341 m
.98036 .84479 L
.97746 .85451 L
.97448 .86422 L
.97146 .87393 L
.97106 .87525 L
.96846 .88364 L
.96704 .89336 L
.96276 .90307 L
.96134 .90689 L
.9595 .91278 L
.95861 .92249 L
.95396 .93221 L
.95163 .93828 L
.95048 .94192 L
.94744 .95163 L
.94512 .96134 L
.94192 .96943 L
.9414 .97106 L
.93833 .98077 L
.98077 .98077 L
F
0 g
.98077 .84341 m
.98036 .84479 L
.97746 .85451 L
.97448 .86422 L
.97146 .87393 L
.97106 .87525 L
.96846 .88364 L
.96704 .89336 L
.96276 .90307 L
.96134 .90689 L
.9595 .91278 L
.95861 .92249 L
.95396 .93221 L
.95163 .93828 L
.95048 .94192 L
.94744 .95163 L
.94512 .96134 L
.94192 .96943 L
.9414 .97106 L
.93833 .98077 L
s
.6 g
.98077 .86777 m
.97894 .87393 L
.976 .88364 L
.97166 .89336 L
.97106 .89976 L
.97028 .90307 L
.96739 .91278 L
.96425 .92249 L
.96134 .93153 L
.9612 .93221 L
.95847 .94192 L
.95534 .95163 L
.95218 .96134 L
.95163 .96306 L
.94948 .97106 L
.94636 .98077 L
.98077 .98077 L
F
0 g
.98077 .86777 m
.97894 .87393 L
.976 .88364 L
.97166 .89336 L
.97106 .89976 L
.97028 .90307 L
.96739 .91278 L
.96425 .92249 L
.96134 .93153 L
.9612 .93221 L
.95847 .94192 L
.95534 .95163 L
.95218 .96134 L
.95163 .96306 L
.94948 .97106 L
.94636 .98077 L
s
.5 g
.98077 .888 m
.97683 .89336 L
.97509 .90307 L
.97302 .91278 L
.97106 .92007 L
.97036 .92249 L
.96743 .93221 L
.96442 .94192 L
.96143 .95163 L
.96134 .95191 L
.95853 .96134 L
.95551 .97106 L
.95248 .98077 L
.98077 .98077 L
F
0 g
.98077 .888 m
.97683 .89336 L
.97509 .90307 L
.97302 .91278 L
.97106 .92007 L
.97036 .92249 L
.96743 .93221 L
.96442 .94192 L
.96143 .95163 L
.96134 .95191 L
.95853 .96134 L
.95551 .97106 L
.95248 .98077 L
s
.4 g
.98077 .90727 m
.97877 .91278 L
.97597 .92249 L
.97319 .93221 L
.97106 .93941 L
.9703 .94192 L
.96732 .95163 L
.96433 .96134 L
.96142 .97106 L
.96134 .97132 L
.95844 .98077 L
.98077 .98077 L
F
0 g
.98077 .90727 m
.97877 .91278 L
.97597 .92249 L
.97319 .93221 L
.97106 .93941 L
.9703 .94192 L
.96732 .95163 L
.96433 .96134 L
.96142 .97106 L
.96134 .97132 L
.95844 .98077 L
s
.3 g
.98077 .9275 m
.97932 .93221 L
.97645 .94192 L
.97354 .95163 L
.97106 .95972 L
.97055 .96134 L
.96747 .97106 L
.96438 .98077 L
.98077 .98077 L
F
0 g
.98077 .9275 m
.97932 .93221 L
.97645 .94192 L
.97354 .95163 L
.97106 .95972 L
.97055 .96134 L
.96747 .97106 L
.96438 .98077 L
s
.2 g
.98077 .95188 m
.97811 .96134 L
.97528 .97106 L
.97223 .98077 L
.98077 .98077 L
F
0 g
.98077 .95188 m
.97811 .96134 L
.97528 .97106 L
.97223 .98077 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00`_ooool2o`0000;ooooo0_l0
002Pooooo`00`_ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgJ3ooooo0033ooooo`04omgMgOl0
003o410@olc<c:7ooooo0033ooooo`04onk^k_lQ8B7o410@onk^kZ7ooooo0033ooooo`04ob4Q8Omg
MgOoMgMgoc8b<Z7ooooo0032ooooo`;o00000_ooool2o`000:3ooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0011oooo
o`;o000000?o410@ooooooooool08oooool5o`00023ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0T
ooooo`Go00009_ooool2o`000003oa0@4?oooooooooo02?ooooo00Gok^k^oc8b<_l0003o410@olc<
c00Tooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`08Oooool4o`000008oa0@4?ooooooooooonk^k_lb
<S;o0000oc8b<_o^k^h3ooooo`00@_ooool00ol0003oooooooooo`0Tooooo`05oiRHV?lQ8B7ok^k^
oooooom4A4@08?ooool01OmgMgOoV9RHoooooonHV9SoMgMg02Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A00Wooooo`03o`000?oooooooooo02Cooooo00GoEEEEogMgMoooooooV9RHob4Q8@0Tooooo`05
ob4Q8OnHV9SooooooiRHV?lQ8B408oooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL00oooool003Oooooo1_l00002ooooo`Go00007Oooool6o`0000?ooooo00?oV9RHob4Q
8Oo^k^h08Oooool01Ol@413ooooooooooooooooo410@02Gooooo00?oV9RHob4Q8Oo^k^h09Oooool5
o`0002Gooooo00Go0000ooooooooooooooooo`00000Tooooo`05o`000?ooooooooooooooool00000
8oooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@41000oooool003oooooo
00CoA4A4omgMgOoooooo0000:?ooool00onHV9So8B4Qonk^kP0Pooooo`05o`000?oooooooooooooo
ool000009_ooool00onHV9So8B4Qonk^kP0Tooooo`04odA4A?oMgMgoooooo`0002Kooooo00Go0000
oiRHV?ooooooV9RHob4Q8@0Tooooo`05oc8b<_nHV9SooooooiRHV?lb<S808oooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool003oooooo00CogMgMoeEEEOoooooo
0000:Oooool00omgMgOoIVIVooooo`0Oooooo`05o`000?ooooooooooooooool000009oooool00omg
MgOoIVIVooooo`0Sooooo`04omgMgOmEEEGoooooo`0002Kooooo00Go0000oeEEEOl0003o410@olc<
c00Tooooo`05olc<c?l0003o0000o`000?o<c<`08oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000000oooool0043ooooo00?oMgMgolc<c?l00000:_ooool00ol0003ooooo
ooooo`0Nooooo`05oa0@4?ooooooooooooooool@4100:?ooool00ol0003oooooooooo`0Sooooo`03
ogMgMoo<c<co000002Kooooo00?oEEEEohN7Qoooool09_ooool01Ol@413o^[Zjoooooonj^[[o410@
02?ooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@00?ooooo0010oooo
o`03onk^k_m4A4Co000002Kooooo00Go0000okZj^_ooooooV9RHoa0@400Pooooo`05ogMgMonHV9So
oooooiRHV?mgMgL09?ooool01Ol0003o^[ZjoooooonHV9So410@02Gooooo00?ok^k^odA4A?l00000
9_ooool00ooMgMgo410@oiRHV00Vooooo`05o`000?nj^[[ooooookZj^_l000008oooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool0047ooooo00?oMgMgo`000?oo
ool09Oooool01OnHV9So410@o`000?lQ8B7oc<c<023ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0T
ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`09_ooool00omgMgOo0000ooooo`0Vooooo`04olc<c?m4
A4Co0000oa0@42Cooooo00GoZJVYoa0@4?l0003o410@ojVYZ@0Qooooo`03oeEEEOmVIVKo000000Co
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`009?ooooooo`0004?o00000_ooool002Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`7o00000Oooool1ooooo`009?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo0Ol00001ooooo`7ooooo000T
ooooo`03o`000?oooooooooo0?oooooo?oooool1o`00007ooooo0Oooool002Cooooo00?o0000oooo
ooooool0ooooooloooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`3oooooocoo
oooo0Ol00001ooooo`7ooooo000Tooooo`;o00003oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`06
ooooo`07o`000?ooooooooooooooool0003oooooo`000002ooooo`04o`000?ooooooooooo`0000;o
oooo00?o0000ooooooooool01_ooool01?l0003oooooooooool00002ooooo`05o`000?oooooo0000
ooooool000000_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo000000;ooooo00Go0000
ooooool0003oooooo`000002ooooo`03o`000?oooooooooo00Kooooo00Wo0000ooooool0003ooooo
o`000?oooooo0000ooooool000000_ooool00ol0003oooooooooo`09ooooo`;o00000_ooool002Co
oooo00?o0000ooooooooool00oooool;oda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomo
Ogl02?moOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnI
VIT02_nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00SoIVIV00?o0000oda<C?m<
C4`05?m<C4`00ol0003oIVIVofIVIP04ofIVIP03o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnI
VIT00_nIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o0000ok>c/onc
/k<01?nc/k<00ol0003oVIVIoiVIV@02oiVIV@04o`000?moOgooOgmoo`0000?oIVIV00?o0000oda<
C?m<C4`00_m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIV
I_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Oo
0000ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo00000_m<C4`00ol0
003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Go0000ogmoOol0003oVIVIo`00
0002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00?o0000ok>c/ol000000_nIVIT01Ol0003oOgmoo`00
0?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmo
Ool0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Coc<c<1_ooool1o`00007ooooo0Oooool0
02Cooooo00?o0000ooooooooool00oooool:oda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmo
OomoOgl02?moOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVI
VOnIVIT02_nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00SoIVIV00?o0000oda<
C?m<C4`05?m<C4`00ol0003oIVIVofIVIP04ofIVIP03o`000?moOgooOgmo00;oOgmo00?o0000oiVI
VOnIVIT00_nIVIT00ol0003o/k>cok>c/`05ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o0000ok>c
/onc/k<01?nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`00
0004oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`00
0?moOgooOgmoo`0000;oVIVI00?o0000ok>c/onc/k<00_nc/k<00ol0003oc<c<olc<c006olc<c007
o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000
oc<c<olc<c<01olc<c<01?l0003oC4a<oda<C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl00000
0_nc/k<00ol0003oc<c<olc<c007olc<c003o`000?nc/k?o000000;oVIVI00Oo0000ogmoOol0003o
IVIVo`000?m<C4co000000So<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo
00000_nc/k<00ol0003oc<c<olc<c004olc<c0Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`00
0?oooooooooo00?ooooo2Om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo
00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00[oVIVI
00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP09ofIVIP03o`000?m<C4coC4a<01CoC4a<
00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00;oVIVI
00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c00Co/k>c
00?o0000oiVIVOnIVIT00_nIVIT01?l0003oOgmoogmoOol00003ofIVIP03o`000?m<C4coC4a<00;o
C4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`00
00;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c007o`000?nc/k?o
/k>cok>c/ol0003oVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000;oC4a<00?o0000oc<c<olc
<c<01olc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`00
0?o<c<coc<c<00Ooc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<
C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4co0000ofIVI_l000000_moOgl2o`0000;o/k>c
00?o0000olc<c?o<c<`01Oo<c<`6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003ooooooooo
o`03ooooo`SoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`;o00003OnI
VIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?mo
Ogl00ol0003oIVIVofIVIP09ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH01?mV
IVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01Onc
/k<01?l0003oc<c<olc<c?o<c<`2o`0000Ko/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`04
o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co
000000?oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<
00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo00000_m<C4`0
0ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Go0000ogmoOol0003oVIVI
o`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<0_l000002Onc/k?o0000oiVIVOnIVIWo0000ogmo
Ool0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Wo0000oda<C?l0003oIVIVo`00
0?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c005olc<c0Kooooo0Ol00001ooooo`7o
oooo000Tooooo`03o`000?oooooooooo00?ooooo1om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`00
0?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`00
0?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP09ofIVIP03o`00
0?m<C4coC4a<01GoC4a<00?o0000ofIVI_mVIVH01?mVIVH01Ol0003oOgmoogmoOomoOgoo000000Go
VIVI00?o0000ok>c/onc/k<01Onc/k<01Ol0003oc<c<olc<c?o<c<co000000Oo/k>c00Go0000oiVI
VOnIVIWoVIVIo`000003ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01_lc
<c<01Ol0003oC4a<oda<C?m<C4co000000?oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01?l0003o
/k>cok>c/ol00009olc<c007o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000002ogmoO`04o`000?mV
IVKoIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP05
o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>c
o`0000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Wo
0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c005olc<
c0Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo1_m<C4`00ol0003o
IVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o
/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003o
IVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH01?mVIVH01Ol0003o
OgmoogmoOomoOgoo000000GoVIVI00?o0000ok>c/onc/k<01Onc/k<01Ol0003oc<c<olc<c?o<c<co
000000Oo/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`05o`000?mVIVKoIVIVofIVI_l00000
0om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000omVIVH01?l0003o
OgmoogmoOol00002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01Ol0003o/k>cok>c/onc
/k?o000000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`04o`00
0?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00008olc<
c003o`000?nc/k?o000000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o
<c<c00Ko<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003o
c<c<olc<c006olc<c003o`000?oooooooooo00?ooooo0Ol00001ooooo`7ooooo000Tooooo`03o`00
0?oooooooooo00?ooooo1Om<C4`00ol0003oIVIVofIVIP0:ofIVIP;o00002_moOgl00ol0003oVIVI
oiVIV@0;oiVIV@;o00005onc/k<2o`0000goVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIV
ofIVIP0:ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH01?mVIVH00ol0003oOgmo
ogmoO`02ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01_nc/k<01Ol0003oc<c<
olc<c?o<c<co000000Ko/k>c00?o0000oiVIVOnIVIT00_nIVIT01?l0003oOgmoogmoOol00003ofIV
IP03o`000?m<C4coC4a<00;oC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<
C004o`000?mVIVKoIVIVo`0000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000003ok>c/`03o`000?o<
c<coc<c<00Goc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@06o`000?moOgooOgmoo`000?mV
IVKo00000_m<C4`00ol0003o<c<coc<c<`07oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Go0000
ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00?o0000ok>c/ol000000_nI
VIT01ol0003oOgmoo`000?mVIVKo0000oda<C?l000002Olc<c<02Ol0003oC4a<o`000?mVIVKo0000
ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o0000ooooooooool00ooo
ool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool4oda<C003o`000?mVIVKo
IVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o
/k>c01Ko/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKo
IVIV00[oIVIV00?o0000oda<C?m<C4`05Om<C4`00ol0003oIVIVofIVIP03ofIVIP03o`000?moOgoo
Ogmo00?oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`07ok>c/`03o`000?o<c<co
000000Oo/k>c00?o0000oiVIVOnIVIT00_nIVIT01?l0003oOgmoogmoOol00003ofIVIP03o`000?m<
C4coC4a<00;oC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mV
IVKoIVIVo`0000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Go
c<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@06o`000?moOgooOgmoo`000?mVIVKo00000_m<
C4`00ol0003o<c<coc<c<`07oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Go0000ogmoOol0003o
VIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00?o0000ok>c/ol000000_nIVIT01ol0003o
Ogmoo`000?mVIVKo0000oda<C?l000002Olc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003o
VIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o0000ooooooooool00oooool1o`00007o
oooo0Oooool002Cooooo00?o0000ooooooooool00oooool3oda<C003o`000?mVIVKoIVIV00_oIVIV
00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c
00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00[oIVIV
00?o0000oda<C?m<C4`05Om<C4`00ol0003oIVIVofIVIP04ofIVIP03o`000?moOgooOgmo00;oOgmo
00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`06ok>c/`Co00001onc/k<00ol0003oVIVI
oiVIV@02oiVIV@04o`000?moOgooOgmoo`0000?oIVIV00?o0000oda<C?m<C4`00_m<C4`00ol0003o
<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01Ol0
003oVIVIoiVIVOnIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol0
0002oiVIV@06o`000?moOgooOgmoo`000?mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`04
o`000?m<C4coC4a<o`0000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<co
c<c<00Ooc<c<00?o0000ok>c/ol000000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o
0000oc<c<olc<c<01_lc<c<01ol0003oC4a<o`000?mVIVKo0000ogmoOol000000_nIVIT01?l0003o
/k>cok>c/ol00007olc<c003o`000?oooooooooo00Cooooo0Ol00001ooooo`7ooooo000Tooooo`03
o`000?oooooooooo00?ooooo0_m<C4`00ol0003oIVIVofIVIP0:ofIVIP;o00002_moOgl00ol0003o
VIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c0_l0000=oiVIV@03o`000?moOgooOgmo00So
Ogmo00?o0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<oda<C00Eoda<C003o`000?mVIVKoIVIV00Co
IVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c00Go
/k>c00Go0000olc<c?o<c<coc<c<o`000007ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl0
1Ol0003oIVIVofIVI_mVIVKo000000CoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<
C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003o
c<c<olc<c007olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Ko0000ogmoOomoOgoo0000ofIVI_l0
0003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH01Ol0003oOgmo
o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`00ol0003o/k>co`000002oiVIV@05
o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`08o`000?m<C4co0000
ofIVI_l0003oOgmoo`000?nIVIT2o`000003ok>c/ol0003oc<c<00Ooc<c<00?o0000ooooooooool0
1?ooool1o`00007ooooo0Oooool002Cooooo0_l00004ooooo`03oda<C?l0003oIVIV00coIVIV00?o
0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o
0000oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o
0000oda<C?m<C4`05Om<C4`00ol0003oIVIVofIVIP04ofIVIP05o`000?moOgooOgmoogmoOol00000
1_nIVIT00ol0003o/k>cok>c/`05ok>c/`05o`000?o<c<coc<c<olc<c?l000001onc/k<01Ol0003o
VIVIoiVIVOnIVIWo000000?oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o
<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nI
VIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;o
VIVI00Ko0000ogmoOomoOgoo0000ofIVI_l00003oda<C003o`000?lc<c?o<c<c00Go<c<c00Go0000
oda<C?m<C4coC4a<o`000002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<
olc<c007olc<c003o`000?nc/k?o000000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003
o`000?lc<c?o<c<c00Ko<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl000000_nc
/k<00ol0003oc<c<olc<c006olc<c003o`000?oooooooooo00?ooooo0_l00002ooooo`009?ooool0
0ol0003oooooooooo`03ooooo`03o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl0
0ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02onIVIT0
0ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05Om<C4`0
0ol0003oIVIVofIVIP04ofIVIP03o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00onIVIT0
0ol0003o/k>cok>c/`05ok>c/`05o`000?o<c<coc<c<olc<c?l000001onc/k<01Ol0003oVIVIoiVI
VOnIVIWo000000?oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go
<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Co0000oiVI
VOnIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nI
VIT01?l0003oOgmoogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00_o0000oda<C?m<
C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<
00?o0000ok>c/ol000000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc
<c<01_lc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<
c<coc<c<00Koc<c<00?o0000ok>c/oooool01Oooool1o`00007ooooo0Oooool002Cooooo00?o0000
ooooooooool00oooool=ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT0
0ol0003o/k>cok>c/`0Fok>c/`;o00003OnIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKo
IVIV00_oIVIV00?o0000oda<C?m<C4`05Om<C4`00ol0003oIVIVofIVIP04ofIVIP03o`000?moOgoo
Ogmo00;oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`06ok>c/`;o000000?oc<c<
o`000?nc/k<01_nc/k<00ol0003oVIVIoiVIV@02oiVIV@04o`000?moOgooOgmoo`0000?oIVIV00?o
0000oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`04oc<c<`;o00000om<C4`01Ol0003oIVIVofIV
I_mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c005
o`000?nc/k?o/k>cok>c/ol000000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<
o`0000Wo<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`03o`000?nIVIWo000000;o/k>c
00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000ofIV
I_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0;o`000?m<C4co0000ofIVI_l0003oOgmoo`00
0?nIVIWo0000ok>c/ol000002Oo<c<`00ol0003o/k>cooooo`05ooooo`7o00000Oooool1ooooo`00
9?ooool00ol0003oooooooooo`03ooooo`coIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVI
oiVIV@0:oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003oOgmo
ogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIV
ofIVIP04ofIVIP03o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>c
ok>c/`08ok>c/`03o`000?nc/k?o/k>c00Ko/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`05
o`000?mVIVKoIVIVofIVI_l000001Om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<
00;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o
0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmoOol00000
0_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl0
0ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nI
VIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02ol0003oC4a<
o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o000000Woc<c<00?o0000ok>c/ol000001Ooo
ool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool;ofIVIP03o`000?moOgoo
Ogmo00WoOgmo00?o0000oiVIVOnIVIT02_nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWo
VIVI00coVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4co
C4a<01KoC4a<00?o0000ofIVI_mVIVH01?mVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWo
VIVI00?oVIVI00?o0000ok>c/onc/k<04Onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Go
0000ofIVI_mVIVKoIVIVo`000005oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`0
0_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0
003oc<c<olc<c006olc<c003o`000?nc/k?o/k>c00;o/k>c00Go0000oiVIVOl0003oOgmoo`000002
ofIVIP04o`000?m<C4coC4a<o`0000Wo<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`04
o`000?nIVIWoVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01Oo<c<`01?l0003o/k>cok>c/ol00002
oiVIV@03o`000?moOgoo000000;oIVIV00?o0000oda<C?l000002?lc<c<02Ol0003oC4a<o`000?mV
IVKo0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc
/k?o00001Oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool:ofIVIP03
o`000?moOgooOgmo00SoOgmo0_l0000<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnI
VIT02onIVIT2o`0000[oOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Eoda<C0;o
00001_mVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc
/k<04_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004
oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l0
0003ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>c
ok>c/onc/k?o000000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00009oc<c
<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<
c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT01ol0003oOgmoo`000?mVIVKo0000oda<
C?l000002Olc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c/`03o`00
0?o<c<coc<c<00Koc<c<00?o0000ok>c/ol000001_ooool1o`00007ooooo0Oooool002Cooooo00?o
0000ooooooooool00oooool9ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onI
VIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl02?mo
Ogl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH01?mV
IVH00ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<04_nc
/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003
o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00003ogmo
O`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc
/k?o000000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`06o`00
0?m<C4coC4a<o`000?mVIVKo00000_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<
00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT01ol0003oOgmoo`000?mVIVKo0000oda<C?l00000
2Olc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<co
c<c<00Koc<c<00?o0000ok>c/ol000001_ooool1o`00007ooooo0Oooool002Cooooo00?o0000oooo
ooooool00oooool8ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0
003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl02?moOgl00ol0
003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH01OmVIVH00ol0
003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<04_nc/k<01Ol0
003oVIVIoiVIVOnIVIWo000000?oOgmo00Go0000ofIVI_mVIVKoIVIVo`000005oda<C003o`000?lc
<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo
00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c
/ol000000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000Wo<c<c00Co0000
oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`0
1oo<c<`00ol0003o/k>co`000002oiVIV@03o`000?moOgooOgmo00;o00000_m<C4`00ol0003o<c<c
oc<c<`06oc<c<`03o`000?m<C4co000000;oIVIV0_l00002oiVIV@04o`000?nc/k?o/k>co`0000So
c<c<00?o0000ok>c/ol000001_ooool1o`00007ooooo0Oooool001_ooooo0_l000000ol@413ooooo
ooooo`04ooooo`03o`000?oooooooooo00?ooooo1omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`00
0?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@;o0000
2_moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH0
1OmVIVH00ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<0
4_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Co0000ofIVI_mVIVKoIVIV0_l00004oda<
C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002
ogmoO`03o`000?nIVIWoVIVI00;o00000onc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o
/k>co`0000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`07
o`000?m<C4coC4a<oda<C?l0003oIVIVo`000002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000
olc<c?o<c<`01oo<c<`00ol0003o/k>co`000002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<
C4`00ol0003o<c<coc<c<`06oc<c<`03o`000?m<C4co000000;oIVIV0_l00002oiVIV@03o`000?nc
/k?o000000Soc<c<00Co0000ok>c/onc/k?o00001_ooool1o`00007ooooo0Oooool001cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`GoIVIV0_l0000:ogmoO`03o`000?nI
VIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0:oiVIV@03o`000?mo
OgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mV
IVKoIVIV00GoIVIV00?o0000ogmoOomoOgl00omoOgl00ol0003oVIVIoiVIV@02oiVIV@03o`000?nc
/k?o/k>c01;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`05o`000?mVIVKoIVIVofIVI_l0
00001Om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Co0000ofIVI_mV
IVKo00000_moOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Goc<c<00Go0000
ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Co0000oda<C?m<C4co
00002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP06o`000?moOgooOgmoo`000?nIVIWo00000_nc
/k<00ol0003oc<c<olc<c007olc<c005o`000?nc/k?o0000oiVIVOl000000_moOgl00ol0003oIVIV
o`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00?o0000oda<C?l000000_mVIVH2o`000005oiVI
VOl0003o/k>cok>c/ol000002?o<c<`01?l0003o/k>cok>c/ol00006ooooo`7o00000Oooool1oooo
o`004Oooool6o`0000;ooooo1Ol00006ooooo`?o00000oooool4ofIVIP03o`000?moOgooOgmo00Wo
Ogmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`;o00003?nIVIT00ol0003o
OgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003o
IVIVofIVIP05ofIVIP03o`000?moOgooOgmo00?oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o
/k>cok>c/`0Bok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01Ol0003oIVIVofIVI_mVIVKo
000000GoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKo
IVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c006olc<c004o`00
0?nc/k?o/k>co`0000?oVIVI00Ko0000ogmoOomoOgoo0000ofIVI_l00003oda<C003o`000?lc<c?o
<c<c00Go<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00?o0000oiVIVOl00000
0_nc/k<00ol0003oc<c<olc<c007olc<c003o`000?nc/k?o000000;oVIVI00Go0000ogmoOol0003o
IVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00co0000oda<C?m<C4co0000ofIVI_l0003o
Ogmoo`000?nIVIWo0000ok>c/ol00009olc<c005o`000?nc/k?o0000oiVIVOl000000oooool3o`00
00;ooooo000Iooooo`04odA4A?oMgMgoooooo`0000Oooooo00?o0000ooooooooool00oooool3ofIV
IP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c
/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0;ofIV
IP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH01OmVIVH00ol0003oOgmoogmoO`03ogmo
O`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<04Onc/k<00ol0003oVIVIoiVIV@02oiVI
V@05o`000?moOgooOgmoogmoOol000000omVIVH00ol0003oC4a<oda<C003oda<C003o`000?lc<c?o
<c<c00Co<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Co
0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol0
00000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Oo0000
oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<
olc<c006olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl00ol0003oIVIVo`000002oda<
C003o`000?lc<c?o<c<c00Ko<c<c00?o0000oda<C?l000000_mVIVH01ol0003oOgmoo`000?nIVIWo
0000ok>c/ol000002Oo<c<`2o`000003oiVIVOl0003ooooo00Gooooo0Ol00001ooooo`7ooooo000I
ooooo`04omgMgOmEEEGoooooo`0000Oooooo00?o0000ooooooooool00oooool2ofIVIP;o00002_mo
Ogl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02_nI
VIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05om<
C4`00ol0003oIVIVofIVIP05ofIVIP03o`000?moOgooOgmo00CoOgmo00?o0000oiVIVOnIVIT00onI
VIT00ol0003o/k>cok>c/`0Aok>c/`03o`000?nIVIWoVIVI00;oVIVI00Co0000ogmoOomoOgoo0000
1?mVIVH00ol0003oC4a<oda<C003oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`0
0_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0
003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol0
0002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo0000
00;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c006o`000?nc/k?o/k>c
o`000?nIVIWo00000_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00?o
0000oda<C?l000000_mVIVH2o`0000;oVIVI00?o0000ok>c/ol000002Oo<c<`2o`000003oiVIVOl0
003ooooo00Gooooo0Ol00001ooooo`7ooooo000Jooooo`03ogMgMoo<c<co000000Oooooo00?o0000
ooooooooool00oooool00omVIVKo0000ogmoO`0:ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000
ok>c/onc/k<05_nc/k<2o`0000coVIVI00?o0000ogmoOomoOgl02?moOgl2o`0000goIVIV00?o0000
oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP05ofIVIP03o`000?moOgooOgmo00CoOgmo00?o0000
oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0Aok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000
ogmoOomoOgooOgmoo`000003ofIVIP03o`000?m<C4coC4a<00?oC4a<00?o0000oc<c<olc<c<01?lc
<c<00ol0003oC4a<oda<C002oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01?l0003oVIVI
oiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVI
V@04o`000?moOgooOgmoo`0000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<01ol0003oC4a<oda<
C?m<C4co0000ofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00002ok>c/`03o`000?o<c<coc<c<
00Koc<c<00Go0000ok>c/ol0003oVIVIo`000002ogmoO`06o`000?mVIVKoIVIVo`000?m<C4co0000
2?lc<c<00ol0003oC4a<o`000002ofIVIP07o`000?moOgoo0000oiVIVOl0003o/k>co`000009olc<
c005o`000?nc/k?o0000o`000?moOgl01_ooool1o`00007ooooo0Oooool001[ooooo00?ok^k^odA4
A?l000001oooool00ol0003oooooooooo`03ooooo`03o`000?moOgooOgmo00WoOgmo00?o0000oiVI
VOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmo
OomoOgl02?moOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIV
I_mVIVH01OmVIVH00ol0003oOgmoogmoO`04ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c
/onc/k<04_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Co0000ofIVI_mVIVKoIVIV0_l0
0004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIV
I_l00003ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o
/k>cok>c/onc/k?o000000;oVIVI00Ko0000ogmoOomoOgoo0000ofIVI_l00003oda<C003o`000?lc
<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH01_l0003oOgmoo`000?l0003oVIVIo`00
00;o/k>c00?o0000olc<c?o<c<`01_o<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00Go
0000ofIVI_l0003oC4a<o`000009oc<c<`03o`000?m<C4co000000;oIVIV00Oo0000ogmoOol0003o
VIVIo`000?nc/k?o000000Soc<c<00?o0000ok>c/onc/k<00_l000000omoOgooooooooooo`04oooo
o`7o00000Oooool1ooooo`006oooool00omgMgOo0000ooooo`06ooooo`03o`000?oooooooooo00?o
oooo00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Ko
/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00_o
IVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP06ofIVIP03o`000?moOgooOgmo00Co
Ogmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`0Cok>c/`05o`000?nIVIWoVIVIoiVI
VOl000000omoOgl01Ol0003oIVIVofIVI_mVIVKo000000GoC4a<00?o0000oc<c<olc<c<01Olc<c<0
0ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000?oOgmo00Co0000oiVIVOnIVIWo0000
0onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01_l0003o
OgmoogmoOol0003oIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l0
0002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`02?l0003o/k>c
ok>c/ol0003oVIVIo`000?moOgoo00000_mVIVH00ol0003oC4a<o`000009oc<c<`03o`000?m<C4co
000000;oIVIV00Oo0000ogmoOol0003oVIVIo`000?nc/k?o000000Soc<c<00?o0000ok>c/onc/k<0
0_l000000omoOgooooooooooo`04ooooo`7o00000Oooool1ooooo`009?ooool00ol0003ooooooooo
o`03ooooo`[oOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nI
VIWoVIVI00[oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<
C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH01omVIVH00ol0003oOgmoogmoO`03ogmoO`03o`000?nI
VIWoVIVI00?oVIVI00?o0000ok>c/onc/k<04_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000CoOgmo
00Go0000ofIVI_mVIVKoIVIVo`000005oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<
C4`00om<C4`01?l0003oIVIVofIVI_l00003ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000
olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`06o`000?nIVIWoVIVIo`000?moOgoo0000
0_mVIVH01Ol0003oC4a<oda<C?m<C4co000000Oo<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo
000000;oOgmo00Co0000oiVIVOnIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c008o`000?nc
/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP03o`000?m<C4co000000Wo<c<c00Go0000oda<
C?l0003oIVIVo`000002ogmoO`04o`000?nIVIWo0000o`0000Woc<c<00?o0000ok>c/onc/k<00_l0
00000omoOgoo0000ooooo`04ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03
ooooo`WoOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWo
VIVI00[oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4co
C4a<01SoC4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0003oOgmoogmoO`04ogmoO`03o`000?nIVIWo
VIVI00;oVIVI00?o0000ok>c/onc/k<04onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Go
0000ofIVI_mVIVKoIVIVo`000005oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`0
0_m<C4`01?l0003oIVIVofIVI_l00003ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<
c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mV
IVH01?l0003oC4a<oda<C?l00008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol0
00000_nIVIT01?l0003o/k>cok>c/ol00008olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_mo
Ogl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00?o0000oda<C?l000000_mV
IVH01ol0003oOgmoo`000?nIVIWo0000ok>c/ol000002Oo<c<`01ol0003o/k>co`000?nIVIWo0000
ogmoOol000001Oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool8ogmo
O`;o00003OnIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmo
OomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01SoC4a<00?o0000ofIV
I_mVIVH01_mVIVH00ol0003oOgmoogmoO`04ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c
/onc/k<04_nc/k<00ol0003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol000000omVIVH0
0ol0003oC4a<oda<C003oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00om<C4`0
1?l0003oIVIVofIVI_l00002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000onc/k<00ol0003oc<c<
olc<c006olc<c006o`000?nc/k?o/k>cok>c/ol0003oVIVI0_l000001OmoOgoo0000ofIVI_mVIVKo
000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?mo
Ogoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01_l0003o/k>cok>c/ol0003oVIVIo`00
00;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`03o`000?m<C4co0000
00;oIVIV00Oo0000ogmoOol0003oVIVIo`000?nc/k?o000000Soc<c<00Go0000ok>c/onc/k?o0000
oiVIV@02o`0000Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo1omo
Ogl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onI
VIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`06?m<
C4`00ol0003oIVIVofIVIP07ofIVIP03o`000?moOgooOgmo00?oOgmo00?o0000oiVIVOnIVIT01?nI
VIT00ol0003o/k>cok>c/`0Bok>c/`03o`000?nIVIWoVIVI00;oVIVI00Co0000ogmoOomoOgoo0000
1?mVIVH00ol0003oC4a<oda<C003oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`0
0om<C4`01?l0003oIVIVofIVI_l00002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000onc/k<00ol0
003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Co0000ogmoOomoOgoo00000_mV
IVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0003o
Ogmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl0
0002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<00ol0003oC4a<o`00
0002ofIVIP04o`000?moOgoo0000o`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>c
ok>c/ol0003oVIVI00;o00001_ooool1o`00007ooooo0Oooool002Cooooo0_l00004ooooo`KoOgmo
00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI
00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01SoC4a<
00?o0000ofIVI_mVIVH01omVIVH00ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00CoVIVI
00?o0000ok>c/onc/k<04_nc/k<00ol0003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol0
00000omVIVH00ol0003oC4a<oda<C003oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<
C4`00om<C4`01?l0003oIVIVofIVI_l00002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000onc/k<0
0ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT00ol0003oOgmoo`00
0002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP03
o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01_l0003o/k>cok>c/ol0003o
VIVIo`0000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0<o`000?m<
C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00002?o<c<`02?l0003o/k>cok>c
/ol0003oVIVIo`000?moOgoo00001Oooool2o`0000;ooooo000Tooooo`03o`000?oooooooooo00?o
oooo1OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@;o00005onc/k<2o`0000goVIVI00?o0000ogmoOomo
Ogl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01SoC4a<00?o0000ofIVI_mV
IVH01omVIVH00ol0003oOgmoogmoO`04ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc
/k<04_nc/k<00ol0003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol000000omVIVH00ol0
003oC4a<oda<C003oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0
003oIVIVofIVI_mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<
c006olc<c003o`000?nc/k?o/k>c00;o/k>c00Ko0000oiVIVOnIVIWo0000ogmoOol00002ofIVIP04
o`000?m<C4coC4a<o`0000Wo<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002
oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`03
o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<00ol0003oC4a<o`000002ofIVIP07
o`000?moOgoo0000oiVIVOl0003o/k>co`000008olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000
ogmoOol00006ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`CoOgmo
00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00coVIVI
00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01SoC4a<
00?o0000ofIVI_mVIVH02?mVIVH00ol0003oOgmoogmoO`04ogmoO`03o`000?nIVIWoVIVI00?oVIVI
00?o0000ok>c/onc/k<04_nc/k<00ol0003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol0
00000omVIVH00ol0003oC4a<oda<C003oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<
C4`00om<C4`01?l0003oIVIVofIVI_l00002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000onc/k<0
0ol0003oc<c<olc<c006olc<c003o`000?nc/k?o/k>c00;o/k>c00Ko0000oiVIVOnIVIWo0000ogmo
Ool00002ofIVIP04o`000?m<C4coC4a<o`0000Wo<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0
003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Ko0000ok>c/onc/k?o0000oiVI
VOl00002ogmoO`;o00000om<C4`00ol0003o<c<coc<c<`06oc<c<`03o`000?m<C4co000000;oIVIV
0_l00002oiVIV@03o`000?nc/k?o000000Soc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmo
o`0000Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo0omoOgl00ol0
003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0
003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`06?m<C4`00ol0
003oIVIVofIVIP08ofIVIP03o`000?moOgooOgmo00CoOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0
003o/k>cok>c/`0Bok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`000003
ofIVIP03o`000?m<C4coC4a<00?oC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002
oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000?o/k>c
00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`06o`000?nIVIWoVIVIo`000?mo
Ogoo00000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Co0000oda<C?m<C4co00000_mV
IVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Ko0000ok>c/onc/k?o
0000oiVIVOl00002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<00ol0
003oC4a<o`000002ofIVIP07o`000?moOgoo0000oiVIVOl0003o/k>co`000008olc<c00:o`000?nc
/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000Gooooo0Ol00001ooooo`7ooooo000Toooo
o`03o`000?oooooooooo00?ooooo0_moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c
01Ko/k>c0_l0000=oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0
003oC4a<oda<C00Goda<C0;o00002OmVIVH2o`0000KoOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0
003o/k>cok>c/`0Cok>c/`05o`000?nIVIWoVIVIoiVIVOl000001?moOgl01Ol0003oIVIVofIVI_mV
IVKo000000GoC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C003oda<C004o`000?mV
IVKoIVIVo`0000?oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c005olc<c005
o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP05o`000?m<C4co
C4a<oda<C?l000002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI
00Co0000ok>c/onc/k?o00002?o<c<`02?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo00000_mV
IVH00ol0003oC4a<o`000009oc<c<`03o`000?m<C4co000000;oIVIV00Oo0000ogmoOol0003oVIVI
o`000?nc/k?o000000Soc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000
1Oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool00omoOgoo0000oiVI
V@0<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmo
O`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`2o`0000_oIVIV00?o
0000ogmoOomoOgl01?moOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c01;o/k>c00?o
0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000CoIVIV00?o0000oda<C?m<C4`0
0om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Co0000ofIVI_mVIVKo
00000omoOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Goc<c<00Go0000ok>c
/onc/k?o/k>co`000002oiVIV@03o`000?moOgoo000000?oIVIV00Go0000oda<C?m<C4coC4a<o`00
0007oc<c<`07o`000?m<C4coC4a<oda<C?l0003oIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`00
00;o/k>c00?o0000olc<c?o<c<`01_o<c<`02?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000
0_mVIVH00ol0003oC4a<o`000009oc<c<`03o`000?m<C4co000000;oIVIV00Oo0000ogmoOol0003o
VIVIo`000?nc/k?o000000Soc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo
00001Oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool00ol0003oVIVI
oiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmo
ogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIV
ofIVIP0:ofIVIP03o`000?moOgooOgmo00CoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>c
ok>c/`0Cok>c/`05o`000?nIVIWoVIVIoiVIVOl000001?moOgl01Ol0003oIVIVofIVI_mVIVKo0000
00GoC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C003oda<C004o`000?mVIVKoIVIV
o`0000?oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c005olc<c005o`000?nc
/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00003ofIVIP04o`000?m<C4coC4a<o`00
00So<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o
/k>co`0000Soc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV00Co0000oda<
C?m<C4co00002?lc<c<00ol0003oC4a<o`000002ofIVIP07o`000?moOgoo0000oiVIVOl0003o/k>c
o`000009olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000Kooooo0Ol00001
ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo3OnIVIT00ol0003o/k>cok>c/`0Fok>c
/`;o00003OnIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<
C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0:ofIVIP03o`000?moOgooOgmo00CoOgmo00?o0000oiVI
VOnIVIT01?nIVIT00ol0003o/k>cok>c/`0Cok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000ogmo
OomoOgooOgmoo`000003ofIVIP03o`000?m<C4coC4a<00CoC4a<00?o0000oc<c<olc<c<01?lc<c<0
0ol0003oC4a<oda<C002oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01Ol0003oVIVIoiVI
VOnIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;o
VIVI00Co0000ogmoOomoOgoo00000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`05o`000?m<C4co
C4a<oda<C?l000000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000?o/k>c00?o0000olc<c?o<c<`0
1_o<c<`02?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo00000_mVIVH01?l0003oC4a<oda<C?l0
0008oc<c<`03o`000?m<C4co000000;oIVIV00Oo0000ogmoOol0003oVIVIo`000?nc/k?o000000So
c<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00001_ooool1o`00007ooooo
0Oooool002Cooooo00?o0000ooooooooool00oooool<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o
0000oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o
0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0:ofIVIP03o`000?moOgooOgmo00GoOgmo00?o
0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`0Cok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go
0000ogmoOomoOgooOgmoo`000003ofIVIP03o`000?m<C4coC4a<00CoC4a<00?o0000oc<c<olc<c<0
1?lc<c<00ol0003oC4a<oda<C002oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01Ol0003o
VIVIoiVIVOnIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o
000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`05o`00
0?m<C4coC4a<oda<C?l000000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000?o/k>c00?o0000olc<
c?o<c<`01_o<c<`02?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo00000_mVIVH01?l0003oC4a<
oda<C?l00008oc<c<`03o`000?m<C4co000000;oIVIV00Oo0000ogmoOol0003oVIVIo`000?nc/k?o
000000Soc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00001_ooool1o`00
007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool;oiVIV@03o`000?nc/k?o/k>c01Ko
/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_o
IVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00Co
Ogmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`0Cok>c/`03o`000?nIVIWoVIVI00;o
VIVI00Go0000ogmoOomoOgooOgmoo`000003ofIVIP03o`000?m<C4coC4a<00CoC4a<00?o0000oc<c
<olc<c<01?lc<c<00ol0003oC4a<oda<C003oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Go0000
oiVIVOnIVIWoVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>c
o`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<01?l0
003oC4a<oda<C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl000000onc/k<00ol0003oc<c<olc<
c006olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP04o`000?m<C4coC4a<
o`0000So<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00008
olc<c00;o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4`01_ooool1o`00
007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool:oiVIV@03o`000?nc/k?o/k>c01Ko
/k>c00?o0000oiVIVOnIVIT02onIVIT2o`0000[oOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003o
C4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl01?moOgl2o`0000Go
VIVI00?o0000ok>c/onc/k<04onc/k<00ol0003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmo
Ool000001?mVIVH00ol0003oC4a<oda<C003oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<
C?m<C4`00om<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo00001?nc
/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01_l0003oOgmo
ogmoOol0003oIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01olc<c<01_l0003oC4a<oda<C?l0003o
IVIVo`0000;oOgmo00?o0000oiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c008o`000?nc
/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00?o0000
oda<C?l000000_mVIVH01ol0003oOgmoo`000?nIVIWo0000ok>c/ol000002?o<c<`03?l0003o/k>c
ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000Gooooo0Ol00001ooooo`7ooooo
000Tooooo`;o00001?ooool9oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT03?nI
VIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<
C4`2o`0000coIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc
/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000CoIVIV
00?o0000oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<
00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<
c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Ko0000ogmoOomoOgoo0000ofIV
I_l00003oda<C003o`000?lc<c?o<c<c00Oo<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmo
O`03o`000?nIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`02_l0003o/k>cok>c/ol0003o
VIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c00?o0000oda<C?l0
00000_mVIVH01ol0003oOgmoo`000?nIVIWo0000ok>c/ol000002?o<c<`03?l0003o/k>cok>c/ol0
003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000Cooooo0_l00002ooooo`009?ooool00ol0
003oooooooooo`03ooooo`SoVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0<oiVI
V@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<
C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@04oiVI
V@03o`000?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT00_nIVIT00ol0003oOgmoogmoO`02ogmo
O`05o`000?mVIVKoIVIVofIVI_l000001Om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4co
C4a<00?oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c
00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Ko0000ogmoOomo
Ogoo0000ofIVI_l00003oda<C003o`000?lc<c?o<c<c00Oo<c<c00Ko0000oda<C?m<C4co0000ofIV
I_l00002ogmoO`03o`000?nIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`02?l0003o/k>c
ok>c/ol0003oVIVIo`000?moOgoo00000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`03o`000?m<
C4co000000;oIVIV00Oo0000ogmoOol0003oVIVIo`000?nc/k?o000000Woc<c<00_o0000ok>c/ol0
003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`000006ooooo`7o00000Oooool1ooooo`009?oo
ool00ol0003oooooooooo`03ooooo`OoVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVI
V@0;oiVIV@;o00002_moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o
0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o
0000ok>c/onc/k<04onc/k<00ol0003oVIVIoiVIV@02oiVIV@03o`000?moOgooOgmo00;oOgmo00Go
0000ofIVI_mVIVKoIVIVo`000006oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`0
0_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0
003oc<c<olc<c005olc<c005o`000?nc/k?o/k>cok>c/ol000000onIVIT00ol0003oOgmoo`000002
ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01ol0003oC4a<oda<C?m<C4co0000ofIVI_l0
00000_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00So0000ok>c/onc
/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV00?o0000oda<C?l000002Olc<c<00ol0003oC4a<o`00
0002ofIVIP07o`000?moOgoo0000oiVIVOl0003o/k>co`000009olc<c00;o`000?nc/k?o0000oiVI
VOl0003oOgmoo`000?mVIVKo0000oda<C?l000001_ooool1o`00007ooooo0Oooool002Cooooo00?o
0000ooooooooool00oooool6oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02_nI
VIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<
C4`2o`0000coIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@05oiVIV@03o`000?nc
/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT00_nIVIT00ol0003oOgmoogmoO`02ogmoO`05o`000?mV
IVKoIVIVofIVI_l000001Om<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<
00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<
c?o<c<`01Oo<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mV
IVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo0000
00;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c008o`000?nc/k?o/k>c
o`000?nIVIWo0000ogmoOol00002ofIVIP03o`000?m<C4co000000Wo<c<c00?o0000oda<C?l00000
0_mVIVH01ol0003oOgmoo`000?nIVIWo0000ok>c/ol000002Oo<c<`02ol0003o/k>co`000?nIVIWo
0000ogmoOol0003oIVIVo`000?m<C4co000000Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`00
0?oooooooooo00?ooooo1OnIVIT00ol0003o/k>cok>c/`0Fok>c/`;o00003?nIVIT00ol0003oOgmo
ogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIV
ofIVIP0;ofIVIP03o`000?moOgooOgmo00KoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>c
ok>c/`0Cok>c/`03o`000?nIVIWoVIVI00?oVIVI00Go0000ogmoOomoOgooOgmoo`000004ofIVIP03
o`000?m<C4coC4a<00?oC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C003oda<C004
o`000?mVIVKoIVIVo`0000?oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c005
olc<c003o`000?nc/k?o/k>c00;o/k>c00Ko0000oiVIVOnIVIWo0000ogmoOol00002ofIVIP03o`00
0?m<C4coC4a<00;oC4a<00?o0000oc<c<olc<c<01_lc<c<01_l0003oC4a<oda<C?l0003oIVIVo`00
00;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c006o`000?nc/k?o/k>c
o`000?nIVIWo00000_moOgl01Ol0003oIVIVo`000?m<C4co000000Wo<c<c00?o0000oda<C?l00000
0_mVIVH01ol0003oOgmoo`000?nIVIWo0000ok>c/ol000002Oo<c<`00ol0003o/k>cok>c/`02o`00
0007ogmoOol0003oIVIVo`000?m<C4co0000oc<c<`06ooooo`7o00000Oooool1ooooo`009?ooool0
0ol0003oooooooooo`03ooooo`CoVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;
oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00F
oda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl01_moOgl00ol0003oVIVIoiVIV@04
oiVIV@;o00005Onc/k<00ol0003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol000001?mV
IVH00ol0003oC4a<oda<C004oda<C003o`000?lc<c?o<c<c00?o<c<c00?o0000oda<C?m<C4`00om<
C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000003ok>c/`03
o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmo
o`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV
00Ko0000ogmoOomoOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00So0000ok>c
/onc/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV00?o0000oda<C?l000002Olc<c<00ol0003oC4a<
o`000002ofIVIP07o`000?moOgoo0000oiVIVOl0003o/k>co`000008olc<c0;o000000_o/k>co`00
0?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co0000oc<c<`06ooooo`7o00000Oooool1ooooo`00
9?ooool00ol0003oooooooooo`03ooooo`?oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVI
oiVIV@0:oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<
oda<C00Foda<C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVI
oiVIV@05oiVIV@03o`000?nc/k?o/k>c01Co/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmo
ogmoOomoOgoo000000CoIVIV00?o0000oda<C?m<C4`01?m<C4`00ol0003o<c<coc<c<`03oc<c<`03
o`000?m<C4coC4a<00?oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`04o`000?nIVIWoVIVI
o`0000Co/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co
0000ogmoOomoOgoo00000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Co0000oda<C?m<
C4co00000_mVIVH01_l0003oOgmoogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01oo<
c<`02?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo00000_mVIVH00ol0003oC4a<o`000009oc<c
<`03o`000?m<C4co000000;oIVIV00Oo0000ogmoOol0003oVIVIo`000?nc/k?o000000Soc<c<00go
0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l0003o<c<c00Kooooo0Ol0
0001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo0_nIVIT00ol0003o/k>cok>c/`0F
ok>c/`;o00003?nIVIT00ol0003oOgmoogmoO`08ogmoO`;o00003OmVIVH00ol0003oC4a<oda<C00F
oda<C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@05
oiVIV@03o`000?nc/k?o/k>c01Co/k>c00?o0000oiVIVOnIVIT00_nIVIT00ol0003oOgmoogmoO`02
ogmoO`05o`000?mVIVKoIVIVofIVI_l000001_m<C4`00ol0003o<c<coc<c<`03oc<c<`03o`000?m<
C4coC4a<00?oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVIVOl0
00000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0
003oOgmoogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01?l0003oC4a<oda<
C?l00002ofIVIP06o`000?moOgooOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c007olc<
c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP03o`000?m<C4co000000Wo<c<c
00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<
c005olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl2o`000004oda<C?l0003o<c<coc<c
<`Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo00?oVIVIo`000?nc
/k<05onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mV
IVH03?mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV0_l00007ogmoO`03
o`000?nIVIWoVIVI00GoVIVI00?o0000ok>c/onc/k<05?nc/k<00ol0003oVIVIoiVIV@02oiVIV@03
o`000?moOgooOgmo00;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000006oda<C003o`000?lc<c?o<c<c
00?o<c<c00?o0000oda<C?m<C4`01?m<C4`01?l0003oIVIVofIVI_l00003ogmoO`04o`000?nIVIWo
VIVIo`0000Co/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI
00Co0000ogmoOomoOgoo00000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Co0000oda<
C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<0_l0
0002ok>c/`07o`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo
<c<c00?o0000oda<C?l000000_mVIVH01ol0003oOgmoo`000?nIVIWo0000ok>c/ol000002?o<c<`0
3?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000;o<c<c1_ooool1
o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool00onIVIWo0000ok>c/`0Gok>c
/`03o`000?nIVIWoVIVI00[oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0;ofIV
IP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmoO`06ogmo
O`03o`000?nIVIWoVIVI00GoVIVI00?o0000ok>c/onc/k<05?nc/k<00ol0003oVIVIoiVIV@02oiVI
V@03o`000?moOgooOgmo00;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000006oda<C003o`000?lc<c?o
<c<c00?o<c<c00?o0000oda<C?m<C4`01?m<C4`01?l0003oIVIVofIVI_l00003ogmoO`04o`000?nI
VIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;o
VIVI00Co0000ogmoOomoOgoo00000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Co0000
oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<
00_o0000ok>c/onc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc
<c?o<c<c00Oo<c<c00?o0000oda<C?l000000_mVIVH01ol0003oOgmoo`000?nIVIWo0000ok>c/ol0
00002?o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000;o
<c<c1_ooool1o`00007ooooo0Oooool002Cooooo0_l00004ooooo`03o`000?nc/k?o/k>c01Ko/k>c
00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV
00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00KoOgmo
00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`0Cok>c/`03o`000?nIVIWoVIVI00?oVIVI
00Go0000ogmoOomoOgooOgmoo`000004ofIVIP03o`000?m<C4coC4a<00?oC4a<00?o0000oc<c<olc
<c<01?lc<c<00ol0003oC4a<oda<C003oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01Ol0
003oVIVIoiVIVOnIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc
/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH00ol0003oC4a<oda<C002oda<C003o`00
0?lc<c?o<c<c00Go<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00Co0000oiVI
VOnIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c00;o`000?nc/k?o/k>cok>c/ol0003oVIVI
o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`03o`000?m<C4co0000
00;oIVIV0_l00002oiVIV@03o`000?nc/k?o000000Soc<c<00co0000ok>c/onc/k?o0000oiVIVOl0
003oOgmoo`000?mVIVKo0000oda<C?l00002oc<c<`Gooooo0_l00002ooooo`009?ooool00ol0003o
ooooooooo`03oooooaSo/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`09ogmoO`03
o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0;ofIVIP03
o`000?moOgooOgmo00KoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`0Cok>c/`03
o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl00_moOgl01Ol0003oIVIVofIVI_mVIVKo0000
00KoC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C003oda<C004o`000?mVIVKoIVIV
o`0000?oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc
/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<
C?l000002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000
ok>c/onc/k?o00002?o<c<`02Ol0003o/k>cok>c/onc/k?o0000oiVIVOl0003oOgmoo`000002ofIV
IP03o`000?m<C4co000000Wo<c<c00?o0000oda<C?l000000_mVIVH01ol0003oOgmoo`000?nIVIWo
0000ok>c/ol000002Oo<c<`00ol0003o/k>co`000002oiVIV@;o000000GoIVIVo`000?m<C4coC4a<
o`000002oc<c<`Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo5onc
/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omV
IVH00ol0003oC4a<oda<C00Foda<C0;o00003OmVIVH00ol0003oOgmoogmoO`07ogmoO`03o`000?nI
VIWoVIVI00GoVIVI00?o0000ok>c/onc/k<05?nc/k<00ol0003oVIVIoiVIV@02oiVIV@03o`000?mo
OgooOgmo00;oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C004oda<C003o`000?lc
<c?o<c<c00?o<c<c00?o0000oda<C?m<C4`00om<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo
00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc
/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000;oC4a<0_l00007
oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc
/k?o/k>co`0000Soc<c<00_o0000ok>c/onc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`00
0002oda<C003o`000?lc<c?o<c<c00Oo<c<c00?o0000oda<C?l000000_mVIVH01ol0003oOgmoo`00
0?nIVIWo0000ok>c/ol000002Oo<c<`02ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`00
0?m<C4co000000?o<c<c1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00ooo
oolFok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIV
IP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmo
O`07ogmoO`03o`000?nIVIWoVIVI00GoVIVI00?o0000ok>c/onc/k<05Onc/k<00ol0003oVIVIoiVI
V@02oiVIV@03o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<
C004oda<C003o`000?lc<c?o<c<c00?o<c<c00?o0000oda<C?m<C4`00om<C4`01Ol0003oIVIVofIV
I_mVIVKo000000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Go
c<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIV
o`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o
0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00008olc<c00;o`000?nc/k?o/k>cok>c/ol0
003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`03o`000?m<
C4co000000;oIVIV00Oo0000ogmoOol0003oVIVIo`000?nc/k?o000000Woc<c<00_o0000ok>c/ol0
003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`000003oc<c<`Kooooo0Ol00001ooooo`7ooooo
000Tooooo`03o`000?oooooooooo00?ooooo5Onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?mo
OgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mV
IVKoIVIV00_oIVIV00?o0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@05oiVIV@03o`000?nc
/k?o/k>c01Go/k>c00?o0000oiVIVOnIVIT00_nIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mV
IVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01?m<C4`00ol0003o<c<coc<c<`03oc<c<`03o`000?m<
C4coC4a<00?oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVIVOl0
00001?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnI
VIWo00000_moOgl01?l0003oIVIVofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000
oda<C?m<C4coC4a<o`000002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o0000
2?o<c<`02ol0003o/k>cok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o
0000oc<c<olc<c<01olc<c<00ol0003oC4a<o`000002ofIVIP07o`000?moOgoo0000oiVIVOl0003o
/k>co`000009olc<c003o`000?nc/k?o/k>c00;o000000KoOgmoo`000?mVIVKo0000oda<C?l00004
oc<c<`Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo4onc/k<2o`00
00goVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<
01KoC4a<0_l0000=ofIVIP03o`000?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0
003o/k>cok>c/`0Dok>c/`03o`000?nIVIWoVIVI00?oVIVI00Go0000ogmoOomoOgooOgmoo`000004
ofIVIP03o`000?m<C4coC4a<00CoC4a<00?o0000oc<c<olc<c<00olc<c<00ol0003oC4a<oda<C004
oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Co/k>c
00?o0000olc<c?o<c<`01Oo<c<`01Ol0003o/k>cok>c/onc/k?o000000?oVIVI00?o0000ogmoOol0
00000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Go0000oda<C?m<C4coC4a<o`000002
ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01?l0003o/k>cok>c
/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`03
o`000?m<C4co000000;oIVIV00Oo0000ogmoOol0003oVIVIo`000?nc/k?o000000Soc<c<00co0000
ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00004oc<c<`Kooooo0Ol00001
ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo4_nc/k<00ol0003oVIVIoiVIV@0<oiVI
V@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<
C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@06oiVI
V@03o`000?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT01?nIVIT01Ol0003oOgmoogmoOomoOgoo
000000CoIVIV00?o0000oda<C?m<C4`01?m<C4`00ol0003o<c<coc<c<`02oc<c<`03o`000?m<C4co
C4a<00GoC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVIVOl00000
1?nc/k<00ol0003oc<c<olc<c005olc<c005o`000?nc/k?o/k>cok>c/ol000000onIVIT00ol0003o
Ogmoo`000002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01Ol0003oC4a<oda<C?m<C4co
000000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00008olc<c004o`000?nc
/k?o/k>co`0000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo
<c<c00?o0000oda<C?l000000_mVIVH01ol0003oOgmoo`000?nIVIWo0000ok>c/ol000002?o<c<`0
3?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000Co<c<c1_ooool1
o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00ooooolBok>c/`03o`000?nIVIWoVIVI
00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<
01KoC4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI
00KoVIVI00?o0000ok>c/onc/k<05?nc/k<00ol0003oVIVIoiVIV@03oiVIV@05o`000?moOgooOgmo
ogmoOol000001?mVIVH00ol0003oC4a<oda<C004oda<C003o`000?lc<c?o<c<c00?o<c<c00?o0000
oda<C?m<C4`01?m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Go0000oiVIVOnIVIWoVIVI
o`000004ok>c/`03o`000?o<c<coc<c<00Goc<c<00Go0000ok>c/onc/k?o/k>co`000003oiVIV@03
o`000?moOgoo000000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`05o`000?m<C4coC4a<
oda<C?l000000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Woc<c<00[o
0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`07
oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<
c?o<c<`01Oo<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo0_l000000om<C4co0000oc<c
<`04oc<c<`Kooooo0Ol00001ooooo`7ooooo000Iooooo`Go00001_ooool00ol0003oooooooooo`03
oooooa3o/k>c0_l0000=oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH0
0ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV0_l00009ogmoO`;o00002?nIVIT0
0ol0003o/k>cok>c/`0Dok>c/`03o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl00_moOgl0
1Ol0003oIVIVofIVI_mVIVKo000000OoC4a<00?o0000oc<c<olc<c<00_lc<c<00ol0003oC4a<oda<
C004oda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01?l0003oVIVIoiVIVOl00004ok>c/`03
o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmo
O`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01ol0003oC4a<oda<C?m<
C4co0000ofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ko
c<c<00Co0000ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000
oc<c<olc<c<01_lc<c<2o`000004oda<C?l0003oIVIVo`0000;oOgmo00Go0000oiVIVOl0003o/k>c
o`000008olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co0000
1Olc<c<6ooooo`7o00000Oooool1ooooo`006Oooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo
00?o0000ooooooooool00oooool?ok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl0
2?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH0
2omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc/k<0
5Onc/k<00ol0003oVIVIoiVIV@02oiVIV@03o`000?moOgooOgmo00?oOgmo00Go0000ofIVI_mVIVKo
IVIVo`000007oda<C003o`000?lc<c?o<c<c00;o<c<c00?o0000oda<C?m<C4`01?m<C4`01Ol0003o
IVIVofIVI_mVIVKo000000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<co
c<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mV
IVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01ol0003oC4a<oda<C?m<C4co0000ofIV
I_l000000_moOgl01?l0003oVIVIoiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000
ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<0
1_lc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00Go0000oiVIVOl0003o/k>co`000008
olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co00001Olc<c<6
ooooo`7o00000Oooool1ooooo`004Oooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h01oooool3o`00
00?ooooo3onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIV
I_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmo
OomoOgl02OmoOgl00ol0003oVIVIoiVIV@07oiVIV@03o`000?nc/k?o/k>c01Co/k>c00?o0000oiVI
VOnIVIT00_nIVIT00ol0003oOgmoogmoO`03ogmoO`05o`000?mVIVKoIVIVofIVI_l000001om<C4`0
0ol0003o<c<coc<c<`02oc<c<`03o`000?m<C4coC4a<00CoC4a<00Go0000ofIVI_mVIVKoIVIVo`00
0003ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>c
ok>c/`02ok>c/`07o`000?nIVIWoVIVIoiVIVOl0003oOgmoo`000002ofIVIP05o`000?m<C4coC4a<
oda<C?l000002Olc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00Co
0000ok>c/onc/k?o00002Oo<c<`00ol0003o/k>co`000002oiVIV@03o`000?moOgoo000000;oIVIV
00?o0000oda<C?l000002?lc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00Go0000oiVI
VOl0003o/k>co`000009olc<c003o`000?nc/k?o000000;oVIVI0_l000001OmVIVKo0000oda<C?m<
C4co000000Go<c<c1?ooool3o`0000;ooooo000Kooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000
ooooooooool00oooool=ok>c/`;o00003OnIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKo
IVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgoo
Ogmo00WoOgmo00?o0000oiVIVOnIVIT01onIVIT00ol0003o/k>cok>c/`0Dok>c/`03o`000?nIVIWo
VIVI00?oVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP02ofIVIP03o`000?m<C4co
C4a<00GoC4a<00?o0000oc<c<olc<c<00_lc<c<00ol0003oC4a<oda<C004oda<C005o`000?mVIVKo
IVIVofIVI_l000000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Co/k>c00?o0000olc<c?o<c<`0
1Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co0000ofIVI_mV
IVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`07o`000?m<C4coC4a<oda<C?l0003oIVIVo`00
0002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`02?o<c<`00ol0003o/k>co`00
0002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`06o`00
0?m<C4coC4a<o`000?mVIVKo00000_moOgl01Ol0003oVIVIo`000?nc/k?o000000Woc<c<00_o0000
ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`000006oc<c<`Kooooo0Ol00001oooo
o`7ooooo000Looooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool00oooool<ok>c/`03
o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03
o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`09ogmoO`03
o`000?nIVIWoVIVI00OoVIVI00?o0000ok>c/onc/k<05Onc/k<00ol0003oVIVIoiVIV@03oiVIV@03
o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C005oda<C005
o`000?lc<c?o<c<coc<c<ol000001om<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Go0000
oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc
/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc
<c<01_lc<c<01ol0003oC4a<oda<C?m<C4co0000ofIVI_l000000_moOgl00ol0003oVIVIo`000002
ok>c/`03o`000?o<c<coc<c<00Soc<c<00?o0000ok>c/ol000000_nIVIT01Ol0003oOgmoo`000?mV
IVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;o
Ogmo00Go0000oiVIVOl0003o/k>co`000009olc<c00;o`000?nc/k?o0000oiVIVOl0003oOgmoo`00
0?mVIVKo0000oda<C?l000001_lc<c<6ooooo`7o00000Oooool1ooooo`007Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00?ooooo2onc/k<00ol0003oVIVIoiVIV@0<oiVIV@03o`00
0?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`00
0?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@07oiVIV@03o`00
0?nc/k?o/k>c01Go/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`02ogmoO`03o`00
0?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01Om<C4`00ol0003o<c<coc<c<`02oc<c<`03o`00
0?m<C4coC4a<00CoC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVI
VOl000001?nc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT0
1?l0003oOgmoogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01ol0003oC4a<
oda<C?m<C4co0000ofIVI_l000000_moOgl00ol0003oVIVIo`000003ok>c/`03o`000?o<c<coc<c<
00Ooc<c<00?o0000ok>c/ol000000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000
oc<c<olc<c<01olc<c<00ol0003oC4a<o`000002ofIVIP07o`000?moOgoo0000oiVIVOl0003o/k>c
o`000009olc<c007o`000?nc/k?o0000oiVIVOl0003oOgmoo`000002ofIVIP;o00001olc<c<6oooo
o`7o00000Oooool1ooooo`006Oooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo00?o0000oooo
ooooool00oooool:ok>c/`03o`000?nIVIWoVIVI00_oVIVI0_l0000:ogmoO`03o`000?mVIVKoIVIV
00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo
00WoOgmo00?o0000oiVIVOnIVIT02?nIVIT00ol0003o/k>cok>c/`0Dok>c/`03o`000?nIVIWoVIVI
00?oVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP02ofIVIP03o`000?m<C4coC4a<
00GoC4a<00?o0000oc<c<olc<c<00_lc<c<00ol0003oC4a<oda<C004oda<C005o`000?mVIVKoIVIV
ofIVI_l000000omoOgl01?l0003oVIVIoiVIVOl00005ok>c/`03o`000?o<c<coc<c<00Goc<c<00Go
0000ok>c/onc/k?o/k>co`000003oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Co0000oda<C?m<
C4co00002Olc<c<01?l0003oC4a<oda<C?l00002ofIVIP06o`000?moOgooOgmoo`000?nIVIWo0000
0onc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Go0000ogmoOol0
003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Go0000oda<C?l0003oIVIVo`000002
ogmoO`05o`000?nIVIWo0000ok>c/ol000002Oo<c<`02ol0003o/k>co`000?nIVIWo0000ogmoOol0
003oIVIVo`000?m<C4co000000Oo<c<c1_ooool1o`00007ooooo0Oooool001Wooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c006ooooo`03o`000?oooooooooo00?ooooo2Onc/k<00ol0003oVIVIoiVIV@0<
oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00F
oda<C0;o00003?mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00SoVIVI00?o0000
ok>c/onc/k<05?nc/k<00ol0003oVIVIoiVIV@03oiVIV@03o`000?moOgooOgmo00?oOgmo00?o0000
ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C005oda<C0;o00000olc<c<00ol0003oC4a<oda<C004
oda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`00
0?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000003oiVIV@04o`000?moOgooOgmoo`00
00;oIVIV00Co0000oda<C?m<C4co00002Olc<c<01?l0003oC4a<oda<C?l00002ofIVIP06o`000?mo
OgooOgmoo`000?nIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`00
00;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Go0000
oda<C?l0003oIVIVo`000002ogmoO`05o`000?nIVIWo0000ok>c/ol000002?o<c<`03?l0003o/k>c
ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000Oo<c<c1_ooool1o`00007ooooo
0Oooool002Cooooo00?o0000ooooooooool00oooool8ok>c/`03o`000?nIVIWoVIVI00coVIVI00?o
0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o
0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00SoVIVI00?o
0000ok>c/onc/k<05Onc/k<00ol0003oVIVIoiVIV@03oiVIV@03o`000?moOgooOgmo00;oOgmo00?o
0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C005oda<C006o`000?lc<c?o<c<co`000?lc<c?o
00001_m<C4`00ol0003oIVIVofIVIP02ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00?o0000ok>c
/onc/k<00onc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVI
VOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co
0000oda<C?m<C4co00000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@04o`000?nc/k?o/k>co`00
00Woc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o
<c<coc<c<`07oc<c<`03o`000?m<C4coC4a<00;o00000_moOgl00ol0003oVIVIo`000002ok>c/`03
o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/ol0003oVIVIo`000002ogmoO`;o00000_m<C4`00ol0
003o<c<coc<c<`05oc<c<`Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?o
oooo1onc/k<00ol0003oVIVIoiVIV@0;oiVIV@;o00002_moOgl00ol0003oIVIVofIVIP0;ofIVIP03
o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`09ogmoO`03
o`000?nIVIWoVIVI00SoVIVI00?o0000ok>c/onc/k<05Onc/k<00ol0003oVIVIoiVIV@03oiVIV@03
o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH00_mVIVH2o`0000OoC4a<00Go0000oc<c<olc
<c?o<c<co`000007oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01Ol0003oVIVIoiVIVOnI
VIWo000000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nI
VIWoVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`05oc<c<`;o
00000_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`03o`000?nIVIWo000000?o/k>c00?o0000olc<
c?o<c<`01_o<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00?o0000ofIVI_l000000_m<
C4`00ol0003o<c<coc<c<`06oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl01Ol0003o
VIVIo`000?nc/k?o000000Soc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo
00000_m<C4`00ol0003o<c<coc<c<`05oc<c<`Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`00
0?oooooooooo00?ooooo1onc/k<00ol0003oVIVIoiVIV@0:oiVIV@03o`000?moOgooOgmo00WoOgmo
00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C0;o00003?mVIVH00ol0003oOgmo
ogmoO`08ogmoO`;o00002onIVIT00ol0003o/k>cok>c/`0Eok>c/`03o`000?nIVIWoVIVI00?oVIVI
00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP02ofIVIP03o`000?m<C4coC4a<00KoC4a<
00Go0000oc<c<olc<c?o<c<co`000006oda<C003o`000?mVIVKoIVIV00;oIVIV00Co0000ogmoOomo
Ogoo00000onIVIT00ol0003o/k>cok>c/`02ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c
/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o
0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Ko0000ogmoOomoOgoo
0000oiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl0
0002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01_l0003oC4a<oda<
C?l0003oIVIVo`0000;oOgmo00Go0000oiVIVOl0003o/k>co`000008olc<c00:o`000?nc/k?o/k>c
o`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01Olc<c<6ooooo`7o
00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`Go/k>c0_l0000<oiVIV@03o`00
0?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`00
0?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0:oiVIV@03o`00
0?nc/k?o/k>c01Go/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`02ogmoO`03o`00
0?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01_m<C4`01Ol0003o<c<coc<c<olc<c?o000000Ko
C4a<00?o0000ofIVI_mVIVH00_mVIVH01?l0003oOgmoogmoOol00004oiVIV@05o`000?nc/k?o/k>c
ok>c/ol000001oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co
0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<
00So0000ofIVI_mVIVKo0000ogmoOol0003oVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`0
1_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo00000_m<C4`00ol0003o
<c<coc<c<`05oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl01Ol0003oVIVIo`000?nc
/k?o000000Woc<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0
003o<c<coc<c<`06oc<c<`03o`000?oooooooooo00?ooooo0Ol00001ooooo`7ooooo000Tooooo`03
o`000?oooooooooo00?ooooo1?nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00Wo
Ogmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_o
IVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0:oiVIV@03o`000?nc/k?o/k>c01Go
/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00?o
IVIV00?o0000oda<C?m<C4`01Om<C4`2o`0000;o<c<c00?o0000oda<C?m<C4`01Om<C4`01Ol0003o
IVIVofIVI_mVIVKo000000?oOgmo00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<co
c<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mV
IVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;o
IVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00009olc<c006o`000?nc/k?o/k>c
o`000?nIVIWo00000_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Ko
0000oda<C?m<C4co0000ofIVI_l00002ogmoO`05o`000?nIVIWo0000ok>c/ol000002Oo<c<`02Ol0
003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c
00?o0000ooooooooool00oooool1o`00007ooooo0Oooool002Cooooo0_l00004ooooo`Co/k>c00?o
0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o
0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o
0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Dok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o
0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<00OoC4a<00?o
0000oc<c<ol000001om<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Go0000oiVIVOnIVIWo
VIVIo`000004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003o
VIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<0
1Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c
/ol00009olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl00ol0003oIVIVo`000002oda<
C003o`000?lc<c?o<c<c00Ko<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`05o`000?nI
VIWo0000ok>c/ol000002Oo<c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002
oda<C003o`000?lc<c?o<c<c00Ko<c<c00?o0000ooooooooool00_ooool2o`0000;ooooo000Toooo
o`03o`000?oooooooooo00?ooooo0_nc/k<2o`0000coVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0
003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0
003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05?nc/k<00ol0
003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0
003oC4a<oda<C006oda<C0;o000000?oC4a<o`000?m<C4`01_m<C4`00ol0003oIVIVofIVIP02ofIV
IP04o`000?moOgooOgmoo`0000?oVIVI00?o0000ok>c/onc/k<00_nc/k<00ol0003oc<c<olc<c005
olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIV
I_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP03
o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`01?l0003o/k>cok>c/ol00002
oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<
C4coC4a<o`0000;oIVIV00Oo0000ogmoOol0003oVIVIo`000?nc/k?o000000Woc<c<00Oo0000ok>c
/ol0003oVIVIo`000?moOgoo000000;oIVIV00?o0000oda<C?l000002?lc<c<00ol0003ooooooooo
o`04ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`03ok>c/ol0003o
VIVI00coVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4co
C4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWo
VIVI00_oVIVI00?o0000ok>c/onc/k<05?nc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgoo
Ogmo00?oOgmo00?o0000ofIVI_mVIVH00_mVIVH2o`0000OoC4a<00Co0000oc<c<olc<c?o00001om<
C4`00ol0003oIVIVofIVIP02ofIVIP03o`000?moOgooOgmo00;o00000_nIVIT00ol0003o/k>cok>c
/`02ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o/k>c0_l00002oiVIV@04o`00
0?moOgooOgmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`05o`000?m<C4coC4a<
oda<C?l000000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Woc<c<00Ko
0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc
<c<01_lc<c<01Ol0003oC4a<oda<C?l0003oIVIV00?o00000_nIVIT00ol0003o/k>co`000009olc<
c008o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVH3o`0000Wo<c<c00?o0000ooooooooool0
1?ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool00onc/k?o0000oiVI
V@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<
C00Foda<C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVI
V@0<oiVIV@03o`000?nc/k?o/k>c01Co/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmo
O`02ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<C4`01_m<C4`01?l0003o<c<coc<c
<ol00007oda<C003o`000?mVIVKoIVIV00;oIVIV00Co0000ogmoOomoOgoo00000onIVIT00ol0003o
/k>cok>c/`02ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000003oiVI
V@04o`000?moOgooOgmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`05o`000?m<
C4coC4a<oda<C?l000000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000So
c<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo00?o0000ofIVI_l000000_m<C4`0
0ol0003o<c<coc<c<`06oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVIV@03
o`000?nc/k?o000000Woc<c<00_o0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<
o`000009oc<c<`03o`000?oooooooooo00Cooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oo
oooooooo00?ooooo00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mV
IVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?mo
OgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Eok>c/`03o`000?nI
VIWoVIVI00?oVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIVIP02ofIVIP03o`000?m<
C4coC4a<00OoC4a<00?o0000oc<c<ol000001om<C4`00ol0003oIVIVofIVIP02ofIVIP05o`000?mo
OgooOgmoogmoOol000000onIVIT00ol0003o/k>cok>c/`02ok>c/`03o`000?o<c<coc<c<00Goc<c<
00?o0000ok>c/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Co0000ofIVI_mV
IVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`03o`000?m<C4coC4a<00;oC4a<00?o0000ofIV
I_l000000_moOgl01?l0003oVIVIoiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Oo0000
ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<c
oc<c<`05oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT00ol0003o
/k>co`000008olc<c005o`000?nc/k?o/k>co`000?nIVIT00_l00002ofIVIP03o`000?m<C4co0000
00Wo<c<c00?o0000ooooooooool01?ooool1o`00007ooooo0Oooool002Cooooo00?o0000oooooooo
ool00oooool<oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003o
C4a<oda<C00Goda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003o
VIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Go/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0003o
OgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<C4`01_m<C4`01?l0003o
<c<coc<c<ol00007oda<C003o`000?mVIVKoIVIV00;oIVIV00Co0000ogmoOomoOgoo00001?nIVIT0
1Ol0003o/k>cok>c/onc/k?o000000Ooc<c<00?o0000ok>c/onc/k<00_nc/k<01Ol0003oVIVIoiVI
VOnIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`05
o`000?m<C4coC4a<oda<C?l000000_mVIVH01_l0003oOgmoogmoOol0003oVIVIo`0000?o/k>c00?o
0000olc<c?o<c<`01Oo<c<`01ol0003o/k>cok>c/onc/k?o0000oiVIVOl000000_moOgl00ol0003o
IVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00So0000oda<C?m<C4co0000ofIVI_l0003o
Ogmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`02Ol0003o/k>co`000?nIVIWo0000ogmo
Ool0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00?o0000oda<C?ooool01Oooool1
o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool;oiVIV@;o00002_moOgl00ol0
003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<0_l0000=ofIVIP03o`000?moOgooOgmo
00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Eok>c/`03o`000?nIVIWoVIVI
00CoVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIVIP02ofIVIP03o`000?m<C4coC4a<
00OoC4a<0ol00008oda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01Ol0003oVIVIoiVIVOnI
VIWo000000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nI
VIWoVIVIo`0000?oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`07
o`000?m<C4coC4a<oda<C?l0003oIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000;o/k>c00?o
0000olc<c?o<c<`01_o<c<`01ol0003o/k>cok>c/onc/k?o0000oiVIVOl000000_moOgl00ol0003o
IVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00So0000oda<C?m<C4co0000ofIVI_l0003o
Ogmoo`0000;oVIVI00?o0000ok>c/ol000002?o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?mo
Ogoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00?o0000oda<C?l000001Oooool1
o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool:oiVIV@03o`000?moOgooOgmo
00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV
00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c
01Ko/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV
00;oIVIV00?o0000oda<C?m<C4`04om<C4`01?l0003oIVIVofIVI_l00004ogmoO`05o`000?nIVIWo
VIVIoiVIVOl000001?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co
0000oiVIVOnIVIWo00000omoOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko
<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo00000_nc
/k<00ol0003oc<c<olc<c006olc<c007o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000002ogmoO`03
o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02?l0003oC4a<oda<C?l0003oIVIV
o`000?moOgoo00000_nIVIT00ol0003o/k>co`000008olc<c00:o`000?nc/k?o/k>co`000?nIVIWo
0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<00ol0003oC4a<o`000005
ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`WoVIVI00?o0000ogmo
OomoOgl02OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIV
I_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c
/onc/k<05_nc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00;oOgmo00?o0000ofIV
I_mVIVH00omVIVH00ol0003oC4a<oda<C00Boda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl0
1Ol0003oVIVIoiVIVOnIVIWo000000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c
/`02ok>c/`04o`000?nIVIWoVIVIo`0000?oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o
<c<coc<c<`06oc<c<`07o`000?m<C4coC4a<oda<C?l0003oIVIVo`000002ogmoO`04o`000?nIVIWo
VIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01ol0003o/k>cok>c/onc/k?o0000oiVIVOl0
00000_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Ko0000oda<C?m<
C4co0000ofIVI_l00002ogmoO`05o`000?nIVIWo0000ok>c/ol000002Oo<c<`02Ol0003o/k>co`00
0?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00?o0000oda<
C?l000001_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool9oiVIV@03
o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C0;o
00003OmVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc
/k<05_nc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00?oOgmo00?o0000ofIVI_mV
IVH00omVIVH00ol0003oC4a<oda<C00Aoda<C003o`000?mVIVKoIVIV00;oIVIV00Co0000ogmoOomo
Ogoo00000onIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00Goc<c<00Co0000ok>c
/onc/k?o/k>c0_l00002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<
o`000009oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01?l0
003o/k>cok>c/ol00008olc<c009o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000?moOgoo000000;o
IVIV00Co0000oda<C?m<C4co00002?lc<c<02?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000
0_nIVIT00ol0003o/k>co`000009olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo
000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<00ol0003oC4a<o`000006ooooo`7o00000Oooool1
ooooo`009?ooool2o`0000Cooooo2?nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV
00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?moOgooOgmo
00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI
00CoVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<
017oC4a<00?o0000ofIVI_mVIVH00_mVIVH01?l0003oOgmoogmoOol00003oiVIV@03o`000?nc/k?o
/k>c00?o/k>c00?o0000olc<c?o<c<`01Oo<c<`01Ol0003o/k>cok>c/onc/k?o000000?oVIVI00Co
0000ogmoOomoOgoo00000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000Wo<c<c00Co0000oda<C?m<
C4co00000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Wo
0000ok>c/onc/k?o/k>co`000?nIVIWo0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00008
oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVIV@03o`000?nc/k?o000000Wo
c<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c
<`06oc<c<`03o`000?m<C4co000000Gooooo0_l00002ooooo`009?ooool00ol0003oooooooooo`03
ooooo`OoVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4co
C4a<01KoC4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWo
VIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgoo
Ogmo00?oOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00Aoda<C003o`000?mVIVKo
IVIV00;oIVIV00Co0000ogmoOomoOgoo00001?nIVIT00ol0003o/k>cok>c/`02ok>c/`03o`000?o<
c<coc<c<00Goc<c<00Go0000ok>c/onc/k?o/k>co`000004oiVIV@04o`000?moOgooOgmoo`0000;o
IVIV00Co0000oda<C?m<C4co00002Olc<c<01?l0003oC4a<oda<C?l00002ofIVIP04o`000?moOgoo
Ogmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01Ol0003o/k>cok>c/onc/k?o000000;o
VIVI0_l00002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00So0000oda<C?m<C4co0000ofIVI_l0
003oOgmoo`0000;oVIVI00?o0000ok>c/ol000002Oo<c<`02Ol0003o/k>co`000?nIVIWo0000ogmo
Ool0003oIVIVo`000003oda<C003o`000?lc<c?o<c<c00Go<c<c00Co0000oda<C?l0003oIVIV1_oo
ool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool6oiVIV@03o`000?moOgoo
Ogmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKo
IVIV00_oIVIV0_l0000:ogmoO`03o`000?nIVIWoVIVI00[oVIVI0_l0000Hok>c/`;o00001_nIVIT0
0ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<C4`04_m<C4`0
1Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Go0000oiVIVOnIVIWoVIVIo`000005ok>c/`03o`00
0?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;o
Ogmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<
oda<C?l000000_mVIVH01_l0003oOgmoogmoOol0003oVIVIo`0000?o/k>c00?o0000olc<c?o<c<`0
1_o<c<`00ol0003o/k>cok>c/`02o`000004oiVIVOl0003oOgmoo`0000;oIVIV00Co0000oda<C?m<
C4co00002?lc<c<02?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo00000_nIVIT00ol0003o/k>c
o`000009olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000
oc<c<olc<c<01_lc<c<01?l0003oC4a<o`000?mVIVH6ooooo`7o00000Oooool1ooooo`009?ooool0
0ol0003oooooooooo`03ooooo`GoVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;
ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`09
ogmoO`03o`000?nIVIWoVIVI00[oVIVI00?o0000ok>c/onc/k<06?nc/k<00ol0003oVIVIoiVIV@05
oiVIV@03o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00C
oda<C004o`000?mVIVKoIVIVo`0000CoOgmo00Go0000oiVIVOnIVIWoVIVIo`000005ok>c/`03o`00
0?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;o
Ogmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<
oda<C?l000000_mVIVH01_l0003oOgmoogmoOol0003oVIVIo`0000?o/k>c00?o0000olc<c?o<c<`0
1_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<
C4co00002?lc<c<02?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo00000_nIVIT00ol0003o/k>c
o`000008olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o
0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<o`000?mVIVKo000000Gooooo0Ol00001ooooo`7ooooo
000Tooooo`03o`000?oooooooooo00?ooooo1?nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mV
IVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?mo
OgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02_nIVIT00ol0003o/k>cok>c/`0Hok>c/`03o`000?nI
VIWoVIVI00GoVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<
C4coC4a<01;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`05o`000?nIVIWoVIVIoiVIVOl0
00001Onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00;o/k>c00Go0000oiVIVOnI
VIWoVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01Olc<c<0
1Ol0003oC4a<oda<C?m<C4co000000?oIVIV00Go0000ogmoOol0003oVIVIo`000003ok>c/`03o`00
0?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIVIP04
o`000?m<C4coC4a<o`0000So<c<c00So0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000;oVIVI
00Co0000ok>c/onc/k?o00002?o<c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`00
0002oda<C003o`000?lc<c?o<c<c00Ko<c<c00?o0000oda<C?l000000_mVIVH00ol0003ooooooooo
o`03ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`?oVIVI00?o0000
ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000
ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00[oVIVI0_l0000H
ok>c/`;o00001onIVIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000
oda<C?m<C4`04_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo0_l00002oiVIV@03o`000?nc
/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nI
VIWoVIVIo`0000?oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`05
o`000?m<C4coC4a<oda<C?l000000_mVIVH00ol0003oOgmoo`000002oiVIV@05o`000?nc/k?o/k>c
ok>c/ol000002?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV00Co
0000oda<C?m<C4co00002?lc<c<02?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo00000_nIVIT0
0ol0003o/k>co`000008olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`00
0?m<C4co00002Olc<c<01Ol0003oC4a<o`000?mVIVKo000000Kooooo0Ol00001ooooo`7ooooo000T
ooooo`03o`000?oooooooooo00?ooooo0_nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKo
IVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgoo
Ogmo00WoOgmo00?o0000oiVIVOnIVIT02_nIVIT00ol0003o/k>cok>c/`0Hok>c/`03o`000?nIVIWo
VIVI00KoVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4co
C4a<01;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`05o`000?nIVIWoVIVIoiVIVOl00000
1Onc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo
00000omoOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<
C?m<C4coC4a<o`000002ofIVIP03o`000?moOgoo000000;oVIVI00Go0000ok>c/onc/k?o/k>co`00
0008olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<
oda<C?l00008oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVIV@03o`000?nc
/k?o000000Soc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l0
0009oc<c<`05o`000?m<C4co0000ofIVI_l000001_ooool1o`00007ooooo0Oooool002Cooooo00?o
0000ooooooooool00oooool00onIVIWo0000ogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o
0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o
0000oiVIVOnIVIT02_nIVIT00ol0003o/k>cok>c/`0Hok>c/`03o`000?nIVIWoVIVI00KoVIVI00?o
0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<01;oC4a<00Go
0000ofIVI_mVIVKoIVIVo`000003ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<0
0onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo
00000omoOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<
C?m<C4coC4a<o`000002ofIVIP03o`000?moOgoo000000;oVIVI00Go0000ok>c/onc/k?o/k>co`00
0008olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Ko0000ogmoOomoOgoo0000ofIVI_l00002oda<
C003o`000?lc<c?o<c<c00Ko<c<c00So0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000;oVIVI
00?o0000ok>c/ol000002Oo<c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002
oda<C003o`000?lc<c?o<c<c00Ko<c<c00?o0000oda<C?m<C4`00_l000000omoOgooooooooooo`04
ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`03o`000?moOgooOgmo
00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV
00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c
01Oo/k>c00?o0000oiVIVOnIVIT01_nIVIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV
00?oIVIV00?o0000oda<C?m<C4`04_m<C4`00ol0003oIVIVofIVIP02ofIVIP05o`000?moOgooOgmo
ogmoOol000000onIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000
ok>c/onc/k<00onc/k<01?l0003oVIVIoiVIVOl00002ogmoO`05o`000?mVIVKoIVIVofIVI_l00000
0om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH00ol0003o
Ogmoo`000002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01?l0003o/k>cok>c/ol00002
oiVIV@03o`000?moOgoo000000;oIVIV00?o0000oda<C?l000002Olc<c<02?l0003oC4a<oda<C?l0
003oIVIVo`000?moOgoo00000_nIVIT00ol0003o/k>co`000009olc<c009o`000?nc/k?o0000oiVI
VOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01_l0003oC4a<o`00
0?mVIVKo0000ogmoO`Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo
2_moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<0_l0000<ofIVIP03o`00
0?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`00
0?nIVIWoVIVI00OoVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIVIP03ofIVIP03o`00
0?m<C4coC4a<01;oC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000?o
VIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o
/k>c00Co0000oiVIVOnIVIWo00000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000?oC4a<00?o0000
oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C006o`000?mVIVKoIVIVo`000?moOgoo0000
0_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002
ogmoO`06o`000?mVIVKoIVIVo`000?m<C4co00002Olc<c<02?l0003oC4a<oda<C?l0003oIVIVo`00
0?moOgoo00000_nIVIT00ol0003o/k>co`000009olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmo
o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01ol0003oC4a<o`000?mVIVKo0000
ogmoOol000001Oooool1o`00007ooooo0Oooool002Cooooo0_l00004ooooo`WoOgmo00?o0000ofIV
I_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmo
OomoOgl02OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVI
VOnIVIT01onIVIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<
C?m<C4`04_m<C4`00ol0003oIVIVofIVIP02ofIVIP05o`000?moOgooOgmoogmoOol000000onIVIT0
0ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<0
1?l0003oVIVIoiVIVOl00002ogmoO`05o`000?mVIVKoIVIVofIVI_l000000om<C4`00ol0003o<c<c
oc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVI
V@04o`000?nc/k?o/k>co`0000Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`00
0002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00So0000oda<C?m<C4co0000ofIVI_l0003oOgmo
o`0000;oVIVI00?o0000ok>c/ol000002Oo<c<`00ol0003o/k>co`000002oiVIV@;o000000GoIVIV
o`000?m<C4coC4a<o`000009oc<c<`;o000000GoIVIVo`000?moOgooOgmoo`000004ooooo`;o0000
0_ooool002Cooooo00?o0000ooooooooool00oooool8ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o
0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o
0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00OoVIVI00?o
0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<01?oC4a<00Go
0000ofIVI_mVIVKoIVIVo`000003ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<0
0_nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Go0000oiVIVOnIVIWo
VIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01Olc<c<01Ol0
003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01Ol0003o/k>cok>c
/onc/k?o000000Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mVIVKo0000
00?oC4a<00?o0000oc<c<olc<c<01_lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000
oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo
0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`07o`000?m<C4co0000ofIVI_l0003o
Ogmoo`000006ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`OoOgmo
00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C0;o00003?mVIVH00ol0003oOgmo
ogmoO`08ogmoO`;o00003OnIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00SoVIVI
00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<01;oC4a<
00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000CoVIVI00?o0000ok>c/onc
/k<00_nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Go0000oiVIVOnI
VIWoVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01Olc<c<0
1Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01Ol0003o/k>c
ok>c/onc/k?o000000Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mVIVKo
000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo
0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Wo0000ok>c/ol0003oVIVIo`000?mo
Ogoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`07o`000?m<C4co0000ofIVI_l0
003oOgmoo`000006ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`Ko
Ogmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_o
IVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Oo
/k>c00?o0000oiVIVOnIVIT01onIVIT2o`0000GoOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003o
C4a<oda<C00Coda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl00ol0003oVIVIoiVIV@02oiVI
V@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`02ok>c
/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00004oda<C003o`000?lc
<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`00ol0003oIVIVo`000002ogmoO`04o`000?nI
VIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@03
o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<02?l0003oC4a<oda<C?l0003o
IVIVo`000?moOgoo00000_nIVIT01?l0003o/k>cok>c/ol00008olc<c003o`000?nc/k?o/k>c00;o
000000OoOgmoo`000?mVIVKoIVIVo`000?m<C4co000000Wo<c<c0_l00002ofIVIP;o000000?oVIVI
ooooooooool01?ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool5ogmo
O`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIV
IP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT2o`0001Wo/k>c00?o0000oiVI
VOnIVIT01onIVIT00ol0003oOgmoogmoO`04ogmoO`03o`000?mVIVKoIVIV00CoIVIV00?o0000oda<
C?m<C4`04_m<C4`00ol0003oIVIVofIVIP02ofIVIP05o`000?moOgooOgmoogmoOol000000onIVIT0
0ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00onc/k<0
1?l0003oVIVIoiVIVOl00003ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<0
1_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01?l0
003o/k>cok>c/ol00009olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl01?l0003oIVIV
o`000?l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00So0000oda<C?m<C4co0000ofIVI_l0003o
Ogmoo`0000;oVIVI00Co0000ok>c/ol0003o00001oo<c<`03?l0003o/k>cok>c/ol0003oVIVIo`00
0?moOgoo0000ofIVI_l0003oC4a<o`0000[o<c<c0_l000001OmVIVKo0000ogmoOol0003oVIVI00Ko
oooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo1?moOgl00ol0003oIVIV
ofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmo
ogmoO`08ogmoO`03o`000?nIVIWoVIVI00coVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVI
oiVIV@08oiVIV@03o`000?moOgooOgmo00CoOgmo00?o0000ofIVI_mVIVH01?mVIVH00ol0003oC4a<
oda<C00Boda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgooOgmoo`000003oiVIV@03
o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`04
o`000?nIVIWoVIVIo`0000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000003oda<C003o`000?lc<c?o
<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI
00Co0000ok>c/onc/k?o00002Oo<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00?o0000
ofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000
ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`03?l0003o/k>cok>c/ol0003o
VIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000[o<c<c0_l000001_mVIVKo0000ogmoOol0003o
VIVIo`0000Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo0omoOgl0
0ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH0
0ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00coVIVI00?o0000ok>c/onc/k<05onc/k<0
0ol0003oVIVIoiVIV@08oiVIV@03o`000?moOgooOgmo00CoOgmo00?o0000ofIVI_mVIVH01?mVIVH0
0ol0003oC4a<oda<C00Boda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgooOgmoo`00
0003oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c
/`02ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000;o
C4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmo
OomoOgoo00000_nIVIT01?l0003o/k>cok>c/ol00009olc<c006o`000?nc/k?o/k>co`000?nIVIWo
00000_moOgl00ol0003oIVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c00So0000oda<C?m<
C4co0000ofIVI_l0003oOgmoo`0000;oVIVI00?o0000ok>c/ol000002?o<c<`01_l0003o/k>cok>c
/ol0003oVIVIo`0000;oOgmo0_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Co0000oda<C?l0
003oIVIV0_l00002oiVIV@03o`000?oooooooooo00?ooooo0Ol00001ooooo`7ooooo000Tooooo`03
o`000?oooooooooo00?ooooo0_moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01Ko
C4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_o
VIVI0_l0000Iok>c/`03o`000?nIVIWoVIVI00SoVIVI00?o0000ogmoOomoOgl01?moOgl00ol0003o
IVIVofIVIP04ofIVIP03o`000?m<C4coC4a<01;oC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003o
OgmoogmoOomoOgoo000000CoVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c004olc<
c003o`000?nc/k?o/k>c00;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`05o`000?mVIVKo
IVIVofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l00000
0_mVIVH01?l0003oOgmoogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Oo0000ok>c
/onc/k?o/k>co`000?nIVIWo000000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c
<`07oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000
olc<c?o<c<`01_o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<
C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4co0000ofIVIP02o`000003oiVIVOl0003o
oooo00Gooooo0Ol00001ooooo`7ooooo000Iooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool0
0ol0003oooooooooo`03ooooo`03ogmoOol0003oIVIV00coIVIV00?o0000oda<C?m<C4`05_m<C4`0
0ol0003oIVIVofIVIP0<ofIVIP03o`000?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT03?nIVIT0
0ol0003o/k>cok>c/`0Fok>c/`;o00002onIVIT00ol0003oOgmoogmoO`04ogmoO`03o`000?mVIVKo
IVIV00CoIVIV00?o0000oda<C?m<C4`04_m<C4`00ol0003oIVIVofIVIP02ofIVIP05o`000?moOgoo
OgmoogmoOol000001?nIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o
0000ok>c/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Go0000ofIVI_mVIVKo
IVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIV
IP03o`000?moOgoo000000?oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01ol0003o/k>cok>c/onc
/k?o0000oiVIVOl000000_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c
00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<
c006olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000
oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?l0003oIVIV00;o000000?oVIVIo`000?ooool01Ooo
ool1o`00007ooooo0Oooool001Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mV
IVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc
/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`05ogmoO`03o`000?mV
IVKoIVIV00?oIVIV00?o0000oda<C?m<C4`04om<C4`01Ol0003oIVIVofIVI_mVIVKo000000CoOgmo
00Go0000oiVIVOnIVIWoVIVIo`000005ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc
/k<00_nc/k<00ol0003oVIVIoiVIV@02oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00?o0000oda<
C?m<C4`00_m<C4`00ol0003o<c<coc<c<`05oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH0
1?l0003oOgmoogmoOol00003oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Co0000ok>c/onc/k?o
00000_nIVIT01_l0003oOgmoogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01olc<c<0
0ol0003oC4a<oda<C002o`0000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006
olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co00002Olc<c<0
1Ol0003oC4a<oda<C?l0003oIVIV00;o000000?oVIVIo`000?ooool01Oooool1o`00007ooooo0Ooo
ool001Wooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo00?ooooo3OmV
IVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?mo
Ogl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02_nI
VIT00ol0003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV00CoIVIV00?o0000oda<C?m<C4`04_m<
C4`00ol0003oIVIVofIVIP02ofIVIP05o`000?moOgooOgmoogmoOol000000onIVIT00ol0003o/k>c
ok>c/`04ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00_nc/k<01Ol0003oVIVI
oiVIVOnIVIWo000000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c
00Go<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP03o`000?moOgoo000000?oVIVI00Go0000
ok>c/onc/k?o/k>co`000007olc<c007o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000002ogmoO`03
o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01olc<c<02_l0003oC4a<oda<C?l0003oIVIV
o`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Wo0000ok>c/ol0003o
VIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`06o`000?m<C4co
0000ofIVI_l0003oOgmo0_l000000onc/k?oooooooooo`04ooooo`7o00000Oooool1ooooo`006Ooo
ool01Ol0003ooooooooooooooooo000000Kooooo0ol00003ooooo`coIVIV00?o0000oda<C?m<C4`0
5_m<C4`2o`0000goIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`00
0?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`05ogmoO`03o`00
0?mVIVKoIVIV00CoIVIV00?o0000oda<C?m<C4`04_m<C4`00ol0003oIVIVofIVIP02ofIVIP03o`00
0?moOgooOgmo00;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000005ok>c/`03o`000?o<c<coc<c<00Co
c<c<00?o0000ok>c/onc/k<00onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Co0000ofIV
I_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Ko0000
ofIVI_mVIVKo0000ogmoOol00002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01ol0003o
/k>cok>c/onc/k?o0000oiVIVOl000000_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o
<c<c00Oo<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0
003oc<c<olc<c007olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<
00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?l0003oIVIV00;o000000?oVIVIo`000?nc
/k<01?ooool3o`0000;ooooo000Iooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`03ooooo`_oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0;ofIVIP03
o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03
o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl01?moOgl00ol0003oIVIVofIVIP05ofIVIP03
o`000?m<C4coC4a<01;oC4a<00?o0000ofIVI_mVIVH00_mVIVH00ol0003oOgmoogmoO`02ogmoO`05
o`000?nIVIWoVIVIoiVIVOl000001Onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c
00?o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000CoC4a<00?o
0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C006o`000?mVIVKoIVIVo`000?moOgoo
00000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Oo0000ok>c/onc/k?o/k>co`000?nI
VIWo000000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<
C4coC4a<o`0000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Oo
c<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c
<`06oc<c<`05o`000?m<C4coC4a<o`000?mVIVH00_l000000onIVIWo0000ok>c/`06ooooo`7o0000
0Oooool1ooooo`006Oooool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool0
0oooool:ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmo
ogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVI
oiVIV@0;oiVIV@03o`000?moOgooOgmo00GoOgmo00?o0000ofIVI_mVIVH01?mVIVH00ol0003oC4a<
oda<C00Boda<C003o`000?mVIVKoIVIV00;oIVIV00?o0000ogmoOomoOgl00_moOgl01Ol0003oVIVI
oiVIVOnIVIWo000000Go/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`05
o`000?nIVIWoVIVIoiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00004oda<C003o`000?lc<c?o
<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01_l0003oIVIVofIVI_l0003oOgmoo`0000;oVIVI
00Go0000ok>c/onc/k?o/k>co`000008olc<c007o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000002
ogmoO`03o`000?mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<02_l0003oC4a<oda<C?l0
003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Oo0000ok>c
/ol0003oVIVIo`000?moOgoo000000;oIVIV00?o0000oda<C?l000002Olc<c<01?l0003oC4a<o`00
0?mVIVH2o`000005oiVIVOl0003o/k>cok>c/ol000001Oooool1o`00007ooooo0Oooool001Wooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo00?ooooo2OmVIVH00ol0003o
C4a<oda<C00Foda<C0;o00003OmVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_o
VIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0:oiVIV@;o00001omoOgl00ol0003o
IVIVofIVIP04ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003o
OgmoogmoOomoOgoo000000?oVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c004olc<
c003o`000?nc/k?o/k>c00?o/k>c00Co0000oiVIVOnIVIWo00000omoOgl01?l0003oIVIVofIVI_l0
0004oda<C003o`000?lc<c?o<c<c00Go<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`00
0?moOgooOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c004o`000?nc/k?o/k>c
o`0000;oVIVI00Ko0000ogmoOol0003o0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c
00_o0000oda<C?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<
c<coc<c<00Koc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`0
0ol0003o<c<coc<c<`07oc<c<`04o`000?m<C4co0000ofIVIP;o000000GoVIVIo`000?nc/k?o/k>c
o`000005ooooo`7o00000Oooool1ooooo`006Oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo
00?o0000ooooooooool00oooool8ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH0
3?mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<0
5onc/k<00ol0003oVIVIoiVIV@0:oiVIV@03o`000?moOgooOgmo00GoOgmo00?o0000ofIVI_mVIVH0
1OmVIVH00ol0003oC4a<oda<C00Coda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgoo
Ogmoo`000003oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o
/k>cok>c/`03ok>c/`04o`000?nIVIWoVIVIo`0000?oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`0
0ol0003o<c<coc<c<`05oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmo
Ool00002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01?l0003o/k>cok>c/ol00002oiVI
V@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<02ol0003oC4a<oda<C?m<
C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02_l0
003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo
<c<c00Co0000oda<C?l0003oIVIV0_l000001OnIVIWo0000ok>c/onc/k?o000000Gooooo0Ol00001
ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo1omVIVH00ol0003oC4a<oda<C00Foda<
C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVI
V@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`05ogmo
O`03o`000?mVIVKoIVIV00GoIVIV00?o0000oda<C?m<C4`04om<C4`00ol0003oIVIVofIVIP02ofIV
IP05o`000?moOgooOgmoogmoOol000000onIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<co
c<c<00Coc<c<00?o0000ok>c/onc/k<00onc/k<01?l0003oVIVIoiVIVOl00003ogmoO`04o`000?mV
IVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01Olc<c<01Ol0003oC4a<oda<C?m<C4co000000;o
IVIV00Co0000ogmoOomoOgoo00000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Co0000
ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c
00_o0000oda<C?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<
c<coc<c<00Koc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`;o00000_m<C4`00ol0003o
<c<coc<c<`07oc<c<`0;o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00000
1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool6ofIVIP03o`000?m<
C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH2o`0000[oOgmo00?o0000oiVIVOnIVIT02_nI
VIT2o`0001So/k>c0_l0000<oiVIV@03o`000?moOgooOgmo00GoOgmo00?o0000ofIVI_mVIVH01OmV
IVH00ol0003oC4a<oda<C00Coda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgooOgmo
o`000004oiVIV@03o`000?nc/k?o/k>c00?o/k>c0_l00005olc<c003o`000?nc/k?o/k>c00?o/k>c
00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`05o`000?mVIVKoIVIVofIVI_l000000om<C4`00ol0
003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol0
0002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@03
o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<01?l0003oC4a<oda<C?l00002
ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c00:o`000?nc
/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<0
3?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Kooooo0Ol00001
ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo1OmVIVH00ol0003oC4a<oda<C00Foda<
C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0:oiVI
V@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`06ogmo
O`03o`000?mVIVKoIVIV00GoIVIV00?o0000oda<C?m<C4`04om<C4`00ol0003oIVIVofIVIP02ofIV
IP05o`000?moOgooOgmoogmoOol000001?nIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<co
c<c<00Coc<c<00?o0000ok>c/onc/k<00onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Go
0000ofIVI_mVIVKoIVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4co
C4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008
olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<
C?l00008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c
/`03o`000?o<c<coc<c<00Koc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo
00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0
003oVIVIo`000?nc/k?o00001_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool0
0oooool4ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmo
ogmoO`09ogmoO`03o`000?nIVIWoVIVI00[oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVI
oiVIV@0;oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<
oda<C00Coda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgooOgmoo`000004oiVIV@03
o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`05
o`000?nIVIWoVIVIoiVIVOl000000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000?oC4a<00?o0000
oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo0000
0_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0
003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Co0000oda<C?m<C4co00000_mV
IVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>c
ok>c/ol00002oiVIV@;o000000GoIVIVo`000?m<C4coC4a<o`000009oc<c<`0<o`000?m<C4co0000
ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol0003oc<c<1_ooool1o`00007ooooo0Oooool002Co
oooo00?o0000ooooooooool00oooool3ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mV
IVH02omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00[oVIVI0_l0000Hok>c/`03
o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl01_moOgl00ol0003oIVIVofIVIP05ofIVIP03
o`000?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH00_mVIVH00ol0003oOgmoogmoO`02ogmoO`05
o`000?nIVIWoVIVIoiVIVOl000001_nc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c
00?o/k>c00Co0000oiVIVOnIVIWo00000omoOgl01?l0003oIVIVofIVI_l00004oda<C003o`000?lc
<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;o
VIVI00Co0000ok>c/onc/k?o00002Oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo
000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP05o`00
0?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c00:o`000?nc/k?o/k>co`00
0?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<03Ol0003oC4a<
oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`000?o<c<`01_ooool1o`00007ooooo
0Oooool002Cooooo0_l00004ooooo`;oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIV
IP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02_nIVIT00ol0003o/k>cok>c
/`0Gok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl01_moOgl00ol0003oIVIVofIV
IP06ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH00_mVIVH00ol0003oOgmoogmo
O`02ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001_nc/k<00ol0003oc<c<olc<c004olc<c003o`00
0?nc/k?o/k>c00?o/k>c00Co0000oiVIVOnIVIWo00000omoOgl01?l0003oIVIVofIVI_l00004oda<
C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgoo
Ogmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@03
o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<01?l0003oC4a<oda<C?l00002
ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c00:o`000?nc
/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<0
3Ol0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`000?o<c<`01Oooool2
o`0000;ooooo000Tooooo`03o`000?oooooooooo00?ooooo00?oIVIVo`000?m<C4`05om<C4`00ol0
003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02_nIVIT00ol0
003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl01omoOgl00ol0
003oIVIVofIVIP05ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH00_mVIVH00ol0
003oOgmoogmoO`02ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001_nc/k<00ol0003oc<c<olc<c004
olc<c003o`000?nc/k?o/k>c00?o/k>c00Co0000oiVIVOnIVIWo00000omoOgl01?l0003oIVIVofIV
I_l00004oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04
o`000?moOgooOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`01?l0003o/k>cok>c/ol0
0002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<02_l0003oC4a<
oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00?o
0000ok>c/onc/k<00_l000001omoOgoo0000ofIVI_mVIVKo0000oda<C?l000002?lc<c<03?l0003o
C4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000;oc<c<1_ooool1o`00007o
oooo0Oooool002Cooooo00?o0000ooooooooool00oooool00ol0003oC4a<oda<C00Foda<C003o`00
0?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`00
0?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`07ogmoO`03o`00
0?mVIVKoIVIV00GoIVIV00?o0000oda<C?m<C4`04om<C4`00ol0003oIVIVofIVIP03ofIVIP05o`00
0?moOgooOgmoogmoOol000001?nIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00?o
c<c<00?o0000ok>c/onc/k<00onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Go0000ofIV
I_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`0
1?l0003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000;o/k>c00?o0000olc<c?o<c<`0
1_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003o
C4a<oda<C?l00008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Go0000ogmoOol0003oVIVIo`00
0002ok>c/`03o`000?o<c<coc<c<00Koc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`00
0?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000
ogmoOol0003oVIVIo`000?nc/k?o00000_o<c<`6ooooo`7o00000Oooool1ooooo`009?ooool00ol0
003oooooooooo`03oooooaSoC4a<0_l0000<ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVI
VOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmo
OomoOgl01omoOgl00ol0003oIVIVofIVIP06ofIVIP03o`000?m<C4coC4a<01;oC4a<00?o0000ofIV
I_mVIVH01?mVIVH01Ol0003oOgmoogmoOomoOgoo000000CoVIVI00?o0000ok>c/onc/k<00onc/k<0
0ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Go0000oiVIVOnIVIWoVIVIo`00
0002ogmoO`05o`000?mVIVKoIVIVofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`03o`00
0?m<C4coC4a<00;oC4a<00Ko0000ofIVI_mVIVKo0000ogmoOol00002oiVIV@05o`000?nc/k?o/k>c
ok>c/ol000002?o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmoOol000000_mV
IVH01?l0003oC4a<oda<C?l00008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Go0000ogmoOol0
003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0
003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0<o`000?m<C4coC4a<o`00
0?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00000_o<c<`6ooooo`7o00000Oooool1ooooo`00
9?ooool00ol0003oooooooooo`03oooooaOoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmo
ogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVI
oiVIV@0;oiVIV@03o`000?moOgooOgmo00OoOgmo00?o0000ofIVI_mVIVH01_mVIVH00ol0003oC4a<
oda<C00Coda<C003o`000?mVIVKoIVIV00?oIVIV00Go0000ogmoOomoOgooOgmoo`000004oiVIV@03
o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`04ok>c/`04
o`000?nIVIWoVIVIo`0000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o
<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nI
VIWoVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@03
o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<00ol0003oC4a<o`000002ofIV
IP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c006o`000?nc/k?o
/k>co`000?nIVIWo00000_moOgl2o`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02_l0003oC4a<
oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Kooooo0Ol0
0001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo5_m<C4`00ol0003oIVIVofIVIP0;
ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0F
ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl01omoOgl00ol0003oIVIVofIVIP06
ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH00omVIVH01?l0003oOgmoogmoOomo
Ogl2o`0000?oVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c003olc<c003o`000?nc
/k?o/k>c00Co/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`05o`000?mVIVKoIVIVofIVI_l0
00000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0
003oOgmoogmoOol00002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01Ol0003o/k>cok>c
/onc/k?o000000;oVIVI00?o0000ogmoOol000000_mVIVH00ol0003oC4a<o`00000:oc<c<`03o`00
0?m<C4co000000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ko
c<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<c
oc<c<`06oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o0000
0oo<c<`6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03oooooaGoC4a<0_l0
000<ofIVIP03o`000?moOgooOgmo00SoOgmo0_l0000=oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o
0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00GoIVIV00?o
0000oda<C?m<C4`05?m<C4`00ol0003oIVIVofIVIP03ofIVIP05o`000?moOgooOgmoogmoOol00000
1?nIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<0
1?nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0
003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol0
0002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01Ol0003o/k>cok>c/onc/k?o000000;o
VIVI00?o0000ogmoOol000000_mVIVH00ol0003oC4a<o`00000:oc<c<`03o`000?m<C4co000000;o
IVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00[o0000ok>c
/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0<
o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00000oo<c<`6ooooo`7o
00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03oooooaCoC4a<00?o0000ofIVI_mVIVH0
2omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00coVIVI00?o0000ok>c/onc/k<0
5_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH0
1OmVIVH00ol0003oC4a<oda<C00Doda<C003o`000?mVIVKoIVIV00?oIVIV00Go0000ogmoOomoOgoo
Ogmoo`000004oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003o
/k>cok>c/`04ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01Ol0003oIVIVofIVI_mVIVKo
000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co
0000ogmoOomoOgoo00000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Go0000ok>c/onc
/k?o/k>co`000002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<0
0ol0003oC4a<o`000002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<
c006olc<c004o`000?nc/k?o/k>co`0000;oVIVI0_l000001OmVIVKo0000oda<C?m<C4co000000So
<c<c00Co0000oda<C?m<C4coC4a<0_l000001_moOgoo0000oiVIVOl0003o/k>co`0000Coc<c<1_oo
ool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00ooooolCoda<C003o`000?mVIVKo
IVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@;o00006?nc/k<0
0ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00OoOgmo0_l00008ofIVIP03o`000?m<C4co
C4a<01?oC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWo
VIVI00;oVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o
/k>c00?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<
00?o0000oc<c<olc<c<01Olc<c<2o`0000?oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003o
VIVIoiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Oo0000ok>c/onc/k?o/k>co`000?nI
VIWo000000;oOgmo00?o0000ofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<
C4coC4a<o`0000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ko
c<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<c
oc<c<`06oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o0000
1?o<c<`6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03oooooa;oC4a<00?o
0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00coVIVI00?o
0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo00OoOgmo00?o
0000ofIVI_mVIVH01_mVIVH00ol0003oC4a<oda<C00Doda<C003o`000?mVIVKoIVIV00?oIVIV00?o
0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o
0000olc<c?o<c<`00_o<c<`00ol0003o/k>cok>c/`04ok>c/`05o`000?nIVIWoVIVIoiVIVOl00000
0omoOgl01?l0003oIVIVofIVI_l00004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<
C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000;o/k>c00?o0000
olc<c?o<c<`01oo<c<`01ol0003o/k>cok>c/onc/k?o0000oiVIVOl000000_moOgl00ol0003oIVIV
o`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH01Ol0003o
Ogmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02_l0003o/k>cok>c/ol0003o
VIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00co0000oda<C?m<
C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00004olc<c0Kooooo0Ol00001ooooo`7o
oooo000Tooooo`;o00001?oooolAoda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl0
2?moOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT0
2onIVIT2o`0000WoOgmo00?o0000ofIVI_mVIVH01_mVIVH00ol0003oC4a<oda<C00Doda<C003o`00
0?mVIVKoIVIV00?oIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@02oiVIV@03o`00
0?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`04ok>c/`04o`00
0?nIVIWoVIVIo`0000?oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`05oc<c
<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl0
0003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo000000;o
Ogmo00Co0000ofIVI_mVIVKo00000_m<C4`00ol0003o<c<coc<c<`07oc<c<`0:o`000?m<C4coC4a<
o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01oo<c<`00ol0003o
/k>cok>c/`02o`000005ogmoOol0003oIVIVofIVI_l000000_m<C4`00ol0003o<c<coc<c<`05oc<c
<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl2o`000003ok>c/ol0003oc<c<00Coc<c<1Ooo
ool2o`0000;ooooo000Tooooo`03o`000?oooooooooo00?ooooo4?m<C4`00ol0003oIVIVofIVIP0;
ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT2o`0001So/k>c00?o0000
oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00KoIVIV00?o0000
oda<C?m<C4`05?m<C4`00ol0003oIVIVofIVIP03ofIVIP03o`000?moOgooOgmo00;oOgmo00?o0000
oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`05ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o0000
ok>c/onc/k<01?nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Go0000ofIVI_mVIVKoIVIV
o`000004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIV
ofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0
003o/k>cok>c/ol00002oiVIV@06o`000?moOgooOgmoo`000?mVIVKo00000om<C4`00ol0003o<c<c
oc<c<`06oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl00ol0003oVIVIo`000002ok>c
/`03o`000?o<c<coc<c<00Koc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo
00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0
003oVIVIo`000?nc/k?o00001Oo<c<`6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003ooooo
ooooo`03ooooo`ooC4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmoO`07ogmoO`03o`00
0?nIVIWoVIVI00coVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`00
0?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH01_mVIVH00ol0003oC4a<oda<C00Doda<C003o`00
0?mVIVKoIVIV00?oIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@02oiVIV@03o`00
0?nc/k?o/k>c00Go/k>c00?o0000olc<c?o<c<`00_o<c<`00ol0003o/k>cok>c/`04ok>c/`05o`00
0?nIVIWoVIVIoiVIVOl000000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000CoC4a<00?o0000oc<c
<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co0000
oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`0000;oVIVI
00Ko0000ogmoOomoOgoo0000ofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Ko0000oda<
C?m<C4co0000ofIVI_l00002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<
c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o
<c<c00Ko<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00005
olc<c0Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo3om<C4`00ol0
003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0
003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0
003oIVIVofIVIP07ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0
003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01Onc/k<00ol0
003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c00Co/k>c00Go0000oiVIVOnIVIWoVIVIo`000003
ogmoO`04o`000?mVIVKoIVIVo`0000GoC4a<00?o0000oc<c<olc<c<01Olc<c<01Ol0003oC4a<oda<
C?m<C4co000000?oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01?l0003o/k>cok>c/ol00009olc<
c004o`000?nc/k?o/k>co`0000;oVIVI00Ko0000ogmoOomoOgoo0000ofIVI_l00002oda<C003o`00
0?lc<c?o<c<c00Oo<c<c00So0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000;oVIVI00Co0000
ok>c/onc/k?o00002?o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002
oda<C003o`000?lc<c?o<c<c00Ko<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nI
VIWo0000ok>c/ol00005olc<c0Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo
00?ooooo3_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVI
VOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmo
OomoOgl02?moOgl00ol0003oIVIVofIVIP07ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIV
I_mVIVH00omVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c
/onc/k<01Onc/k<01Ol0003oc<c<olc<c?o<c<co000000Oo/k>c00Go0000oiVIVOnIVIWoVIVIo`00
0002ogmoO`05o`000?mVIVKoIVIVofIVI_l000001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`00
0?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00003ok>c
/`03o`000?o<c<coc<c<00Koc<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo00?o
0000ofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo
00000_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Ko0000ok>c/onc
/k?o0000oiVIVOl00002ogmoO`;o00000_m<C4`00ol0003o<c<coc<c<`07oc<c<`09o`000?m<C4co
0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`00oo<c<`6ooooo`7o
00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`coC4a<0_l0000=ofIVIP03o`00
0?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`;o0000
3?nIVIT2o`0000[oOgmo00?o0000ofIVI_mVIVH01omVIVH00ol0003oC4a<oda<C00Doda<C003o`00
0?mVIVKoIVIV00?oIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@02oiVIV@03o`00
0?nc/k?o/k>c00Go/k>c00?o0000olc<c?o<c<`00_o<c<`00ol0003o/k>cok>c/`04ok>c/`05o`00
0?nIVIWoVIVIoiVIVOl000000omoOgl01Ol0003oIVIVofIVI_mVIVKo000000CoC4a<00?o0000oc<c
<olc<c<01Olc<c<01Ol0003oC4a<oda<C?m<C4co000000?oIVIV00Co0000ogmoOomoOgoo00000_nI
VIT01?l0003o/k>cok>c/ol00008olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01_l0003o
OgmoogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01olc<c<01_l0003oC4a<oda<C?l0
003oIVIVo`0000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c00:o`00
0?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01olc
<c<02ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o000000Koc<c<1_ooool1
o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool<oda<C003o`000?mVIVKoIVIV
00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c
01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV
00OoIVIV00?o0000oda<C?m<C4`05Om<C4`00ol0003oIVIVofIVIP03ofIVIP03o`000?moOgooOgmo
00;oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`05ok>c/`03o`000?o<c<coc<c<
00;oc<c<00?o0000ok>c/onc/k<01?nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Go0000
ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go<c<c00Go0000oda<C?m<C4coC4a<
o`000003ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01Ol0
003o/k>cok>c/onc/k?o000000;oVIVI00Ko0000ogmoOomoOgoo0000ofIVI_l00002oda<C003o`00
0?lc<c?o<c<c00Oo<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`03o`000?nIVIWo0000
00;o/k>c00?o0000olc<c?o<c<`01_o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000
ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c0_l00002ofIVIP07o`000?moOgoo0000oiVI
VOl0003o/k>co`000006olc<c0Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo
00?ooooo2om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVI
VOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmo
OomoOgl02OmoOgl00ol0003oIVIVofIVIP08ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIV
I_mVIVH00omVIVH00ol0003oOgmoogmoO`03ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001onc/k<0
0ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c00Go/k>c00Co0000oiVIVOnIVIWo00000omo
Ogl01Ol0003oIVIVofIVI_mVIVKo000000CoC4a<00?o0000oc<c<olc<c<01Olc<c<01Ol0003oC4a<
oda<C?m<C4co000000?oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01?l0003o/k>cok>c/ol00009
olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Ko0000ogmoOomoOgoo0000ofIVI_l00002oda<C003
o`000?lc<c?o<c<c00Oo<c<c00Co0000oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nIVIWo
000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@;o000000Go
IVIVo`000?m<C4coC4a<o`000009oc<c<`0;o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo
0000ok>c/ol000001oo<c<`6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03
ooooo`WoC4a<0_l0000=ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT0
0ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl0
0ol0003oIVIVofIVIP08ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH00omVIVH2
o`0000CoOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`05ok>c/`05o`000?o<c<co
c<c<olc<c?l000001onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Go0000ofIVI_mVIVKo
IVIVo`000004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003o
IVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01oo<c<`0
1?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co0000
2Olc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0
003oc<c<olc<c006olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;o
C4a<00?o0000oc<c<olc<c<01_lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVI
VOl0003o/k>co`0000Ooc<c<1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool0
0oooool8oda<C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVI
oiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmo
ogmoO`09ogmoO`03o`000?mVIVKoIVIV00SoIVIV00?o0000oda<C?m<C4`05Om<C4`00ol0003oIVIV
ofIVIP03ofIVIP03o`000?moOgooOgmo00?oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>c
ok>c/`05ok>c/`05o`000?o<c<coc<c<olc<c?l000001onc/k<01Ol0003oVIVIoiVIVOnIVIWo0000
00;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000
oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c
00?o0000olc<c?o<c<`01oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo000000;o
IVIV00Co0000oda<C?m<C4co00002Olc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00?o
0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c00:o`000?nc/k?o/k>co`000?nIVIWo
0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<03?l0003oC4a<oda<C?l0
003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Ooc<c<1_ooool1o`00007ooooo0Oooool0
02Cooooo00?o0000ooooooooool00oooool7oda<C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmo
OomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVI
VOnIVIT02_nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00SoIVIV00?o0000oda<
C?m<C4`05Om<C4`00ol0003oIVIVofIVIP03ofIVIP03o`000?moOgooOgmo00?oOgmo00?o0000oiVI
VOnIVIT00_nIVIT00ol0003o/k>cok>c/`05ok>c/`05o`000?o<c<coc<c<olc<c?l000001onc/k<0
1Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<c
oc<c<`05oc<c<`03o`000?m<C4coC4a<00?oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003o
VIVIoiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Co0000ok>c/onc/k?o00000_nIVIT0
1_l0003oOgmoogmoOol0003oIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01_l0003oC4a<
oda<C?l0003oIVIVo`0000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<
c004o`000?nc/k?o/k>cok>c/`;o000000OoOgmoo`000?mVIVKoIVIVo`000?m<C4co000000So<c<c
00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`;o000000?o/k>co`000?o<c<`01oo<c<`6oooo
o`7o00000Oooool1ooooo`009?ooool2o`0000Cooooo1_m<C4`00ol0003oIVIVofIVIP0;ofIVIP;o
00002_moOgl00ol0003oVIVIoiVIV@0:oiVIV@;o00006?nc/k<2o`0000coVIVI00?o0000ogmoOomo
Ogl02OmoOgl00ol0003oIVIVofIVIP09ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIVI_mV
IVH01?mVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc
/k<01Onc/k<00ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c00Co/k>c00Go0000oiVIVOnI
VIWoVIVIo`000003ogmoO`05o`000?mVIVKoIVIVofIVI_l000001?m<C4`00ol0003o<c<coc<c<`05
oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVI
VOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@03
o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<02Ol0003oC4a<oda<C?m<C4co
0000ofIVI_l0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00[o0000ok>c/onc
/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0<o`00
0?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00002?o<c<`5ooooo`;o0000
0_ooool002Cooooo00?o0000ooooooooool00oooool5oda<C003o`000?mVIVKoIVIV00_oIVIV00?o
0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0:oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o
0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00WoIVIV00?o
0000oda<C?m<C4`05Om<C4`00ol0003oIVIVofIVIP03ofIVIP03o`000?moOgooOgmo00;oOgmo00?o
0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`05ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o
0000ok>c/onc/k<00onc/k<00ol0003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol00000
0omVIVH00ol0003oC4a<oda<C002oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`0
0om<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<
c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmoOol000000_mVIVH0
1?l0003oC4a<oda<C?l00008oc<c<`09o`000?m<C4coC4a<oda<C?l0003oIVIVo`000?moOgoo0000
00;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo
0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00?o0000oda<C?m<C4`00_l00002ogmo
O`05o`000?nIVIWo0000ok>c/ol000002?o<c<`00ol0003oooooooooo`03ooooo`7o00000Oooool1
ooooo`009?ooool00ol0003oooooooooo`03ooooo`CoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0
003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00[oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0
003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02OmVIVH00ol0
003oC4a<oda<C00Eoda<C003o`000?mVIVKoIVIV00?oIVIV00?o0000ogmoOomoOgl00omoOgl00ol0
003oVIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c00Go/k>c00?o0000olc<c?o<c<`00_o<c<`00ol0
003o/k>cok>c/`04ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01Ol0003oIVIVofIVI_mV
IVKo000000CoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mV
IVKoIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c005
o`000?nc/k?o/k>cok>c/ol000000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<
o`0000Wo<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`03o`000?nIVIWo000000;o/k>c
00?o0000olc<c?o<c<`01_o<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo0_l00002oda<
C003o`000?lc<c?o<c<c00Oo<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00000
0_nc/k<00ol0003oc<c<olc<c006olc<c003o`000?oooooooooo00?ooooo0Ol00001ooooo`7ooooo
000Tooooo`03o`000?oooooooooo00?ooooo0om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?mo
OgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02_nIVIT2o`0001So/k>c00?o0000oiVIVOnIVIT02onI
VIT00ol0003oOgmoogmoO`08ogmoO`;o00002omVIVH00ol0003oC4a<oda<C00Eoda<C003o`000?mV
IVKoIVIV00CoIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@02oiVIV@03o`000?nc
/k?o/k>c00Ko/k>c0ol000000oo<c<co0000ok>c/`06ok>c/`05o`000?nIVIWoVIVIoiVIVOl00000
0_moOgl01Ol0003oIVIVofIVI_mVIVKo000000GoC4a<00?o0000oc<c<olc<c<01Olc<c<01Ol0003o
C4a<oda<C?m<C4co000000?oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01Ol0003o/k>cok>c/onc
/k?o000000Soc<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo00Co0000ofIVI_mV
IVKo00000_m<C4`00ol0003o<c<coc<c<`07oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmo
Ool00002oiVIV@03o`000?nc/k?o000000Woc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmo
o`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`07oc<c<`0;o`000?m<C4co0000ofIVI_l0003o
Ogmoo`000?nIVIWo0000ok>c/ol000002?o<c<`00ol0003oooooooooo`04ooooo`7o00000Oooool1
ooooo`009?ooool00ol0003oooooooooo`03ooooo`;oC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0
003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00[oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0
003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0
003oC4a<oda<C00Eoda<C003o`000?mVIVKoIVIV00CoIVIV00?o0000ogmoOomoOgl00_moOgl00ol0
003oVIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c00Ko/k>c00Co0000ok>c/onc/k?o00002?nc/k<0
1Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`00
0?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000003ofIVIP04o`000?moOgooOgmoo`00
00;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c007o`000?nc/k?o/k>cok>c/ol0003oVIVI
o`000002ogmoO`04o`000?mVIVKoIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01olc<c<02?l0003o
C4a<oda<C?l0003oIVIVo`000?moOgoo00000_nIVIT00ol0003o/k>co`000009olc<c00:o`000?nc
/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01olc<c<0
2ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o000000Soc<c<00?o0000oooo
ooooool01?ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool00om<C4co
0000ofIVIP0<ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02_nIVIT00ol0003o
/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003o
IVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01GoC4a<00?o0000ofIVI_mVIVH01?mVIVH00ol0003o
OgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<01Onc/k<00ol0003o
c<c<o`000009ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01?l0003oIVIVofIVI_l00005
oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l0
0002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01ol0003o/k>c
ok>c/onc/k?o0000oiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00002oda<C003o`000?lc<c?o
<c<c00Oo<c<c00Co0000oda<C?m<C4co00000_mVIVH2o`0000;oVIVI00Co0000ok>c/onc/k?o0000
2?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@;o000000GoIVIVo`000?m<C4coC4a<o`000009oc<c
<`07o`000?m<C4co0000ofIVI_l0003oOgmoo`000002oiVIV@;o00002?o<c<`00ol0003o/k>coooo
o`05ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`03o`000?mVIVKo
IVIV00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o
/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKo
IVIV00_oIVIV00?o0000oda<C?m<C4`05Om<C4`00ol0003oIVIVofIVIP04ofIVIP03o`000?moOgoo
Ogmo00;oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`06ok>c/`04o`000?o<c<co
c<c<o`0000Oo/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`05o`000?mVIVKoIVIVofIVI_l0
00001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00?o0000ofIVI_mV
IVH00_l000000omoOgoo0000oiVIV@02oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01?l0
003o/k>cok>c/ol00002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Co0000oda<C?m<C4co0000
2?lc<c<00ol0003oC4a<oda<C002o`000004ofIVI_l0003oOgmoo`0000;oVIVI00Co0000ok>c/onc
/k?o00002?o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003
o`000?lc<c?o<c<c00Ko<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000
ok>c/ol00008olc<c003o`000?nc/k?ooooo00Gooooo0Ol00001ooooo`7ooooo000Iooooo`Go0000
1_ooool00ol0003oooooooooo`03ooooo`03o`000?mVIVKoIVIV00[oIVIV00?o0000ogmoOomoOgl0
2OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT0
2onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00coIVIV00?o0000oda<C?m<C4`0
5Om<C4`00ol0003oIVIVofIVIP03ofIVIP03o`000?moOgooOgmo00?oOgmo00?o0000oiVIVOnIVIT0
0onIVIT00ol0003o/k>cok>c/`06ok>c/`04o`000?o<c<coc<c<o`0000Ko/k>c00?o0000oiVIVOnI
VIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000?oIVIV00?o0000oda<C?m<C4`00_m<C4`00ol0
003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl0
1Ol0003oVIVIoiVIVOnIVIWo000000?o/k>c00?o0000olc<c?o<c<`01Oo<c<`01Ol0003o/k>cok>c
/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01?l0003oC4a<oda<C?l00008oc<c
<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol0
0008olc<c003o`000?nc/k?o000000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`00
0?lc<c?o<c<c00Ko<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c
/ol00008olc<c003o`000?nc/k?ooooo00Gooooo0Ol00001ooooo`7ooooo000Iooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@01_ooool00ol0003oooooooooo`03ooooo`coIVIV00?o0000ogmoOomoOgl0
2OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT0
2onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV0_l0000Goda<C003o`00
0?mVIVKoIVIV00CoIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@03oiVIV@03o`00
0?nc/k?o/k>c00So/k>c0_l00007ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01Ol0003o
IVIVofIVI_mVIVKo000000CoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<
C004o`000?mVIVKoIVIVo`0000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000003ok>c/`03o`000?o<
c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@03o`000?moOgoo000000;oIVIV
00Co0000oda<C?m<C4co00002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo0000
00;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`02?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo
00000_mVIVH01?l0003oC4a<oda<C?l00007oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmo
Ool0003oVIVIo`000?nc/k?o00002Oo<c<`00ol0003o/k>cooooo`05ooooo`7o00000Oooool1oooo
o`006_ooool00onHV9So8B4Qonk^kP07ooooo`03o`000?oooooooooo00?ooooo2omVIVH00ol0003o
OgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003o
VIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003o
C4a<oda<C00Foda<C003o`000?mVIVKoIVIV00CoIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003o
VIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c00Wo/k>c00?o0000ok>c/onc/k<01Onc/k<00ol0003o
VIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol000000_mVIVH00ol0003oC4a<oda<C003oda<
C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002
ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c
/onc/k?o000000;oVIVI00Ko0000ogmoOomoOgoo0000ofIVI_l00003oda<C003o`000?lc<c?o<c<c
00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o
/k>co`0000Soc<c<00Wo0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVH00_l000000om<
C4co0000oc<c<`07oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc
/k?o00002Oo<c<`00ol0003o/k>co`000005ooooo`7o00000Oooool1ooooo`006oooool00onHV9So
8B4Qonk^kP06ooooo`?o00000oooool:ofIVIP03o`000?moOgooOgmo00SoOgmo0_l0000=oiVIV@03
o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03
o`000?mVIVKoIVIV00coIVIV00?o0000oda<C?m<C4`05Om<C4`00ol0003oIVIVofIVIP05ofIVIP03
o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`0Bok>c/`05
o`000?nIVIWoVIVIoiVIVOl000001?moOgl01?l0003oIVIVofIVI_l00005oda<C003o`000?lc<c?o
<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nI
VIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;o
VIVI00Ko0000ogmoOomoOgoo0000ofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000
oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<
00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c
<`06oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00002Oo<
c<`00ol0003o/k>co`000003ooooo`?o00000_ooool001cooooo00?oMgMgofIVI_ooool01Oooool0
0ol0003oooooooooo`03ooooo`WoIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0<
oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08
ogmoO`03o`000?mVIVKoIVIV00_oIVIV0_l0000Goda<C003o`000?mVIVKoIVIV00GoIVIV00?o0000
ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c017o/k>c00?o0000
oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000;oIVIV00?o0000oda<C?m<C4`00om<
C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo0000
0_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc
/k?o/k>co`000002oiVIV@06o`000?moOgooOgmoo`000?mVIVKo00000om<C4`00ol0003o<c<coc<c
<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Ko0000ogmoOomoOgoo0000oiVIVOl00002ok>c
/`03o`000?o<c<coc<c<00Koc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`;o00000_m<
C4`00ol0003o<c<coc<c<`07oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000
00;o/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003o/k>co`000006ooooo`7o00000Oooool1oooo
o`007Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo2?mVIVH00ol0003o
OgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI0_l0000Hok>c/`03o`000?nIVIWoVIVI00_o
VIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01Ko
C4a<00?o0000ofIVI_mVIVH01OmVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00?o
VIVI00?o0000ok>c/onc/k<04_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Go0000ofIV
I_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`0
1Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<
olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01_l0003oOgmoogmoOol0003oIVIV
o`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?mo
Ogoo000000;oVIVI00?o0000ok>c/ol000002Oo<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?mo
Ogoo0000ofIVI_l0003oC4a<o`0000[o<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000oiVI
VOl000000_nc/k<00ol0003oc<c<olc<c006olc<c003o`000?nc/k?o000000Kooooo0Ol00001oooo
o`7ooooo000Iooooo`05o`000?nj^[[ooooooiRHV?l@41001_ooool00ol0003oooooooooo`03oooo
o`OoIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c
01Ko/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`07ogmoO`03o`000?mVIVKoIVIV
00coIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP05ofIVIP03o`000?moOgooOgmo
00;oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0Aok>c/`03o`000?nIVIWoVIVI
00;oVIVI00Go0000ogmoOomoOgooOgmoo`000003ofIVIP03o`000?m<C4coC4a<00;oC4a<00?o0000
oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C005o`000?mVIVKoIVIVofIVI_l000000_mo
Ogl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o
/k>co`000002oiVIV@06o`000?moOgooOgmoo`000?mVIVKo00000om<C4`00ol0003o<c<coc<c<`06
oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT00ol0003o/k>co`00
0009olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co00002_lc
<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<
00Koc<c<00?o0000ok>c/ol000001_ooool1o`00007ooooo0Oooool000_ooooo0ol000000ol@413o
ooooooooo`08ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`03oooo
o`KoIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c
01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT2o`0000WoOgmo00?o0000ofIVI_mVIVH02omVIVH2o`00
01SoC4a<00?o0000ofIVI_mVIVH01OmVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI
00?oVIVI00?o0000ok>c/onc/k<04_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00?o0000
ofIVI_mVIVH00_mVIVH01Ol0003oC4a<oda<C?m<C4co000000Oo<c<c00?o0000oda<C?m<C4`00_m<
C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Co0000oiVIVOnIVIWo00000_nc/k<00ol0003o
c<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002
ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Co0000oda<C?m<C4co00000omVIVH2o`0000;oVIVI
00Co0000ok>c/onc/k?o00002?o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIV
I_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000
oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o0000oiVIV@Kooooo0Ol0
0001ooooo`7ooooo000=ooooo`03oa0@4?nj^[[ooooo01Cooooo00?o0000ooooooooool00oooool5
ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT2o`0001So/k>c00?o0000
oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000
oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP05ofIVIP03o`000?moOgooOgmo00?oOgmo00?o0000
oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`0Bok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000
ogmoOomoOgooOgmoo`000003ofIVIP03o`000?m<C4coC4a<00;oC4a<00?o0000oc<c<olc<c<01Olc
<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000?oOgmo00Co0000oiVIVOnIVIWo
00000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01_l0
003oOgmoo`000?l0003oIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<
C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c00:
o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<0
1_lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Woc<c<
00Go0000ok>c/ol0003oVIVIo`000005ooooo`7o00000Oooool1ooooo`003Oooool00onHV9So<S8b
ooooo`0Dooooo`03o`000?oooooooooo00?ooooo1OmVIVH00ol0003oOgmoogmoO`07ogmoO`03o`00
0?nIVIWoVIVI00coVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`00
0?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<oda<C00Goda<C003o`00
0?mVIVKoIVIV00KoIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@03oiVIV@03o`00
0?nc/k?o/k>c01;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000004ogmoO`05o`000?mVIVKoIVIVofIV
I_l000001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIV
I_mVIVKo00000omoOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co
0000ok>c/onc/k?o00000onIVIT00ol0003oOgmoo`000002ofIVIP05o`000?m<C4coC4a<oda<C?l0
00002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl000000onc/k<0
0ol0003oc<c<olc<c006olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`00
00;oC4a<00?o0000oc<c<olc<c<01_lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000
oiVIVOl0003o/k>co`0000Woc<c<00Go0000ok>c/ol0003oVIVIo`000005ooooo`7o00000Oooool1
ooooo`003Oooool00ooMgMgo0000okZj^P0Dooooo`03o`000?oooooooooo00?ooooo1?mVIVH00ol0
003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0
003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02_mVIVH00ol0
003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00KoIVIV00?o0000ogmoOomoOgl00omoOgl00ol0
003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c01;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000003
ogmoO`05o`000?mVIVKoIVIVofIVI_l000001Om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<
C4coC4a<00?oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00004ok>c/`03
o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000onIVIT00ol0003oOgmoo`000002ofIV
IP04o`000?m<C4coC4a<o`0000Wo<c<c00Co0000oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`00
0?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@05
o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<
o`000?mVIVH00_l00002oiVIV@03o`000?nc/k?o000000Woc<c<00Co0000ok>c/ol0003o00001_oo
ool1o`00007ooooo0Oooool000gooooo00?oEEEEogMgMom4A4@05?ooool00ol0003oooooooooo`03
ooooo`?oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o
/k>c01Ko/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKo
IVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP06ofIVIP03o`000?moOgoo
Ogmo00?oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0Bok>c/`05o`000?nIVIWo
VIVIoiVIVOl000000omoOgl00ol0003oIVIVofIVIP02ofIVIP03o`000?m<C4coC4a<00;oC4a<00?o
0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000?oOgmo
00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c
/ol000000_nIVIT00ol0003oOgmoo`000002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<0
1?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o0000
2?o<c<`02?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo00000_mVIVH01?l0003oC4a<oda<C?l0
0007oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000
olc<c?o<c<`01_o<c<`01Ol0003o/k>co`000?nIVIWo000000Kooooo0Ol00001ooooo`7ooooo000<
ooooo`05omgMgOl@413oooooob4Q8OoMgMd04oooool00ol0003oooooooooo`03ooooo`;oIVIV00?o
0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c0_l0
000<oiVIV@;o00002_moOgl00ol0003oIVIVofIVIP0:ofIVIP;o00006Om<C4`00ol0003oIVIVofIV
IP05ofIVIP03o`000?moOgooOgmo00CoOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c
/`0Aok>c/`;o00000onIVIT01Ol0003oOgmoogmoOomoOgoo000000?oIVIV00?o0000oda<C?m<C4`0
0om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00;oC4a<0_l00002ofIVIP04o`00
0?moOgooOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`000009olc<c005o`000?nc/k?o/k>c
ok>c/ol000000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000Wo<c<c00Co
0000oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<
c<`01oo<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`00
0?lc<c?o<c<c00Ko<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc
/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o0000o`000?moOgl01_ooool1o`00007ooooo
0Oooool000cooooo00GoIVIVohN7QoooooooV9RHoeEEE@0Cooooo`;o00001?ooool00omVIVKo0000
ogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVI
oiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<
oda<C00Hoda<C003o`000?mVIVKoIVIV00KoIVIV00?o0000ogmoOomoOgl00omoOgl00ol0003oVIVI
oiVIV@03oiVIV@03o`000?nc/k?o/k>c01;o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmo
ogmoOomoOgoo000000?oIVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`04oc<c<`03
o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000omoOgl01?l0003oVIVIoiVIVOl00003
ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@03o`000?mo
Ogoo000000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<01?l0003oC4a<oda<C?l00002ofIVIP05
o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c00:o`000?nc/k?o/k>c
o`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02_l0003o
C4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<
00Go0000ok>c/ol0003o0000ogmoO`05ooooo`;o00000_ooool000_ooooo00?ok^k^o`000?o^k^h0
0_ooool00ol0003ogMgMooooo`0Aooooo`03o`000?oooooooooo00?ooooo00?o0000ogmoOomoOgl0
2?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT0
2onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`0
5om<C4`00ol0003oIVIVofIVIP06ofIVIP03o`000?moOgooOgmo00?oOgmo00?o0000oiVIVOnIVIT0
0onIVIT00ol0003o/k>cok>c/`0Bok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomoOgoo
Ogmoo`000004ofIVIP03o`000?m<C4coC4a<00;oC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003o
C4a<oda<C002oda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01?l0003oVIVIoiVIVOl00003
ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@03o`000?mo
Ogoo000000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<01?l0003oC4a<oda<C?l00002ofIVIP03
o`000?moOgooOgmo00;o00000_nc/k<00ol0003oc<c<olc<c007olc<c00:o`000?nc/k?o/k>co`00
0?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01olc<c<02Ol0003oC4a<
o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Ko0000
ok>c/ol0003oVIVIo`000?moOgl6ooooo`7o00000Oooool1ooooo`002oooool01?l@413o0000o`00
0?ooool2o`000003oa0@4?oooooooooo013ooooo00?o0000ooooooooool00oooool:ogmoO`03o`00
0?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`00
0?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02_mVIVH2o`0001WoC4a<00?o0000ofIVI_mVIVH0
1_mVIVH00ol0003oOgmoogmoO`04ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<0
4_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003o
C4a<oda<C002oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0003o
IVIVofIVI_mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c005
olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP04o`00
0?m<C4coC4a<o`0000Wo<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`03o`000?nIVIWo
000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo
0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c00[o0000oda<C?l0003oIVIVo`000?mo
Ogoo0000oiVIVOl0003o/k>c0_l00008olc<c007o`000?nc/k?o0000oiVIVOl0003oOgmoo`000005
ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`WoOgmo00?o0000oiVI
VOnIVIT02onIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00[oVIVI00?o0000ogmo
OomoOgl02OmoOgl00ol0003oIVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<01SoC4a<00?o0000ofIV
I_mVIVH01omVIVH00ol0003oOgmoogmoO`04ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c
/onc/k<04_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00?o0000ofIVI_mVIVH00_mVIVH0
0ol0003oC4a<oda<C002oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`0
1Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<
olc<c005olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIV
IP04o`000?m<C4coC4a<o`0000So<c<c00Co0000oda<C?m<C4co00000_mVIVH01_l0003oOgmoogmo
Ool0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01oo<c<`00ol0003o/k>cok>c/`02o`0000;o
Ogmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`0;o`000?m<C4co0000ofIV
I_l0003oOgmoo`000?nIVIWo0000ok>c/ol000002Oo<c<`01ol0003o/k>co`000?nIVIWo0000ogmo
Ool000001Oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool8ogmoO`03
o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0:oiVIV@03
o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Goda<C003
o`000?mVIVKoIVIV00OoIVIV00?o0000ogmoOomoOgl01?moOgl00ol0003oVIVIoiVIV@03oiVIV@03
o`000?nc/k?o/k>c01;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`03o`000?mVIVKoIVIV
00;oIVIV00?o0000oda<C?m<C4`00_m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<
00;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o
0000olc<c?o<c<`01Oo<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Oo0000ogmoOomoOgoo
Ogmoo`000?mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01_l0003oC4a<oda<C?l0003o
IVIVo`0000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c00:o`000?nc
/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01olc<c<0
2ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o000000Woc<c<00Oo0000ok>c
/ol0003oVIVIo`000?moOgoo000000Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooo
oooo00?ooooo1omoOgl00ol0003oVIVIoiVIV@0:oiVIV@;o00006?nc/k<2o`0000coVIVI00?o0000
ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000
ofIVI_mVIVH01omVIVH00ol0003oOgmoogmoO`04ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000
ok>c/onc/k<04_nc/k<00ol0003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol000000omV
IVH00ol0003oC4a<oda<C003oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00om<
C4`01?l0003oIVIVofIVI_l00003ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<
c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH0
1?l0003oC4a<oda<C?l00008oc<c<`07o`000?m<C4coC4a<oda<C?l0003oIVIVo`000002ogmoO`03
o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`00ol0003o/k>co`000002oiVIV@05
o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0<o`000?m<C4coC4a<
o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00002Oo<c<`01ol0003o/k>co`000?nIVIWo
0000ogmoOol000001_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool6
ogmoO`03o`000?nIVIWoVIVI00[oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0;
oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00G
oda<C003o`000?mVIVKoIVIV00SoIVIV00?o0000ogmoOomoOgl00omoOgl00ol0003oVIVIoiVIV@03
oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomo
Ogoo000000;oIVIV00?o0000oda<C?m<C4`01?m<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<
C4coC4a<00;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`04o`000?nIVIWoVIVIo`0000?o
/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmo
OomoOgoo00000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`07o`000?m<C4coC4a<oda<C?l0003o
IVIVo`000002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o
/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06
oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00002Oo<c<`0
1ol0003o/k>co`000?nIVIWo0000ogmoOol000001_ooool1o`00007ooooo0Oooool002Cooooo00?o
0000ooooooooool00oooool5ogmoO`03o`000?nIVIWoVIVI00[oVIVI00?o0000ok>c/onc/k<05onc
/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omV
IVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00SoIVIV00?o0000ogmoOomoOgl00omo
Ogl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c01;o/k>c00?o0000oiVIVOnIVIT00_nI
VIT01Ol0003oOgmoogmoOomoOgoo000000?oIVIV00?o0000oda<C?m<C4`01?m<C4`00ol0003o<c<c
oc<c<`03oc<c<`03o`000?m<C4coC4a<00?oC4a<00Co0000ofIVI_mVIVKo00000omoOgl01?l0003o
VIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002
oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<01_l0003oC4a<
oda<C?l0003oIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo00000_nc/k<00ol0003oc<c<olc<c006
olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000?oC4a<00?o0000oc<c
<olc<c<01_lc<c<02ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o000000Wo
c<c<00?o0000ok>c/ol000000_nIVIT2o`000003ofIVI_oooooooooo00Cooooo0Ol00001ooooo`7o
oooo000Tooooo`03o`000?oooooooooo00?ooooo1?moOgl00ol0003oVIVIoiVIV@0:oiVIV@;o0000
6?nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo0_l0000=ofIVIP03o`00
0?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02?mVIVH00ol0003oOgmoogmoO`03ogmoO`03o`00
0?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<04_nc/k<00ol0003oVIVIoiVIV@02oiVIV@05o`00
0?moOgooOgmoogmoOol000001?mVIVH00ol0003oC4a<oda<C003oda<C003o`000?lc<c?o<c<c00Co
<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Go0000oiVI
VOnIVIWoVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`00
0002oiVIV@06o`000?moOgooOgmoo`000?mVIVKo00000om<C4`00ol0003o<c<coc<c<`07oc<c<`06
o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<co
c<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<
00?o0000oc<c<olc<c<01_lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0
003o/k>co`0000Woc<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000001Oooool1
o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool3ogmoO`03o`000?nIVIWoVIVI
00[oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo
00SoOgmo00?o0000ofIVI_mVIVH03?mVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV
00SoIVIV00?o0000ogmoOomoOgl01?moOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c
01;o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000CoIVIV00?o0000
oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00;oC4a<00Go0000
ofIVI_mVIVKoIVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000onc/k<00ol0003oc<c<
olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01_l0003oOgmoogmoOol0003oIVIV
o`0000?oC4a<00?o0000oc<c<olc<c<01olc<c<02?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo
00000_nIVIT01?l0003o/k>cok>c/ol00008olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Go0000
ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00co0000oda<C?m<C4co0000
ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00009olc<c009o`000?nc/k?o0000oiVIVOl0003o
Ogmoo`000?mVIVKo000000Gooooo0Ol00001ooooo`7ooooo000Tooooo`;o00001?ooool2ogmoO`03
o`000?nIVIWoVIVI00[oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03
o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH03?mVIVH00ol0003oC4a<oda<C00Goda<C003
o`000?mVIVKoIVIV00SoIVIV00?o0000ogmoOomoOgl01?moOgl00ol0003oVIVIoiVIV@04oiVIV@03
o`000?nc/k?o/k>c01;o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo0000
00CoIVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<
00;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000onc
/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmo
ogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000Wo<c<c00Ko0000oda<C?m<C4co0000ofIVI_l0
0002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`00ol0003o/k>co`00
0002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`09o`00
0?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`0
0ol0003o/k>cok>c/`02o`000004ogmoOol0003oIVIVo`0000Gooooo0_l00002ooooo`009?ooool0
0ol0003oooooooooo`03ooooo`03ogmoOol0003oVIVI00coVIVI00?o0000ok>c/onc/k<05_nc/k<0
0ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH03?mVIVH0
0ol0003oC4a<oda<C00Foda<C0;o00002_mVIVH00ol0003oOgmoogmoO`04ogmoO`;o00001OnIVIT0
0ol0003o/k>cok>c/`0Cok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`00
0003ofIVIP03o`000?m<C4coC4a<00?oC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<
C003oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00004ok>c/`03
o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01_l0003oVIVIoiVIVOl0003oOgmo
o`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV
00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00009olc<c003o`000?nc/k?o000000;o
VIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Wo0000oda<
C?l0003oIVIVo`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c009o`00
0?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000Kooooo0Ol00001ooooo`7ooooo000Toooo
o`03o`000?oooooooooo00?ooooo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c
/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0<ofIV
IP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`04ogmo
O`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<04onc/k<00ol0003oVIVIoiVIV@02oiVI
V@05o`000?moOgooOgmoogmoOol000000omVIVH00ol0003oC4a<oda<C003oda<C003o`000?lc<c?o
<c<c00Co<c<c00?o0000oda<C?m<C4`00om<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Co
0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c005olc<c005o`000?nc/k?o/k>cok>c/ol0
00000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<0
1?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o0000
2Oo<c<`00ol0003o/k>co`000002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o
<c<coc<c<`07oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o
0000olc<c?o<c<`01_o<c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000006oooo
o`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`goVIVI00?o0000ok>c/onc
/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mV
IVH02omVIVH2o`0001SoC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`04ogmoO`03
o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<04onc/k<00ol0003oVIVIoiVIV@02oiVIV@05
o`000?moOgooOgmoogmoOol000000omVIVH00ol0003oC4a<oda<C004oda<C003o`000?lc<c?o<c<c
00?o<c<c00?o0000oda<C?m<C4`00om<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Co0000
oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Ko
0000oiVIVOnIVIWo0000ogmoOol00002ofIVIP03o`000?m<C4coC4a<00;oC4a<00?o0000oc<c<olc
<c<01Olc<c<02Ol0003oC4a<oda<C?m<C4co0000ofIVI_l0003oOgmoo`000002oiVIV@04o`000?nc
/k?o/k>co`0000Woc<c<00?o0000ok>c/ol000000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;o
C4a<00?o0000oc<c<olc<c<01olc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`00
0002ok>c/`03o`000?o<c<coc<c<00Ooc<c<0_l000001?nIVIWo0000ogmoOomoOgl2o`000003oda<
C?oooooooooo00Cooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo3?nI
VIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?mo
Ogl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02_mV
IVH00ol0003oOgmoogmoO`04ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<04onc
/k<00ol0003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol000001?mVIVH00ol0003oC4a<
oda<C003oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00om<C4`01?l0003oIVIV
ofIVI_l00003ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0
003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01Ol0003oC4a<oda<
C?m<C4co000000So<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVIV@04
o`000?nc/k?o/k>co`0000Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mV
IVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?mo
Ogoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00[o0000ok>c/ol0003oVIVIo`00
0?moOgoo0000ofIVI_l0003oC4a<1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000oooooooo
ool00oooool;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003o
OgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00coIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003o
IVIVofIVIP0:ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o
/k>cok>c/`0Cok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`000004ofIV
IP03o`000?m<C4coC4a<00?oC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C003oda<
C004o`000?mVIVKoIVIVo`0000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000003ok>c/`03o`000?o<
c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;o
IVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000
ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00008olc<c004o`000?nc/k?o/k>co`0000;oVIVI
00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00[o0000oda<C?m<
C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c00:o`00
0?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C0Kooooo0Ol00001ooooo`7ooooo000T
ooooo`03o`000?oooooooooo00?ooooo2_nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWo
VIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP;o00006?m<C4`0
0ol0003oIVIVofIVIP0:ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT01?nIVIT0
0ol0003o/k>cok>c/`0Cok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`00
0004ofIVIP03o`000?m<C4coC4a<00?oC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<
C003oda<C004o`000?mVIVKoIVIVo`0000?oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003o
c<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002
ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`00
0?moOgoo000000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c00:o`000?nc/k?o/k>co`00
0?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01olc<c<02Ol0003oC4a<
o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o0000
ok>c/ol000000_nIVIT2o`000005ofIVI_l0003oC4a<oda<C?l000001Oooool1o`00007ooooo0Ooo
ool002Cooooo00?o0000ooooooooool00oooool8oiVIV@;o00006?nc/k<00ol0003oVIVIoiVIV@0;
oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00G
oda<C003o`000?mVIVKoIVIV00[oIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@04
oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT00_nIVIT00ol0003oOgmoogmoO`02
ogmoO`05o`000?mVIVKoIVIVofIVI_l000001_m<C4`00ol0003o<c<coc<c<`03oc<c<`03o`000?m<
C4coC4a<00?oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVIVOl0
00000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0
003oOgmoogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01?l0003oC4a<oda<
C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01?l0003o
/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06
oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00002Oo<c<`0
2Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003o`000?oooooooooo00?o
oooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo2?nIVIT00ol0003o/k>c
ok>c/`0Fok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl01omoOgl00ol0003oIVIV
ofIVIP0<ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmo
ogmoO`05ogmoO`03o`000?nIVIWoVIVI00GoVIVI00?o0000ok>c/onc/k<04onc/k<00ol0003oVIVI
oiVIV@02oiVIV@03o`000?moOgooOgmo00;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000006oda<C003
o`000?lc<c?o<c<c00?o<c<c00?o0000oda<C?m<C4`00om<C4`01Ol0003oIVIVofIVI_mVIVKo0000
00;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000
ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Go0000oda<C?m<C4co
C4a<o`000008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0
003o/k>cok>c/ol00008olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Go0000ogmoOol0003oIVIV
o`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmo
o`000?nIVIWo0000ok>c/ol00009olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo
000000;oC4a<00?o0000ooooooooool00oooool1o`00007ooooo0Oooool002Cooooo00?o0000oooo
ooooool00oooool7oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT2o`00
00WoOgmo00?o0000ofIVI_mVIVH02omVIVH2o`0001OoC4a<0_l0000<ofIVIP03o`000?moOgooOgmo
00GoOgmo00?o0000oiVIVOnIVIT01OnIVIT00ol0003o/k>cok>c/`0Cok>c/`03o`000?nIVIWoVIVI
00;oVIVI00?o0000ogmoOomoOgl00_moOgl01Ol0003oIVIVofIVI_mVIVKo000000KoC4a<00?o0000
oc<c<olc<c<00olc<c<00ol0003oC4a<oda<C003oda<C005o`000?mVIVKoIVIVofIVI_l000000_mo
Ogl01Ol0003oVIVIoiVIVOnIVIWo000000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`01Ol0003o/k>c
ok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01Ol0003oC4a<oda<C?m<C4co
000000So<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc
/k?o/k>co`0000Woc<c<00?o0000ok>c/ol000000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;o
C4a<00?o0000oc<c<olc<c<01olc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`00
0002ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o0000ok>c/onc/k<00_l000001omoOgoo0000ofIV
I_mVIVKo0000oda<C?l000001_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool0
0oooool5oiVIV@;o00006?nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo
00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV
00?o0000ogmoOomoOgl01_moOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c01?o/k>c
00?o0000oiVIVOnIVIT00onIVIT01Ol0003oOgmoogmoOomoOgoo000000CoIVIV00?o0000oda<C?m<
C4`00om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Co0000ofIVI_mV
IVKo00000omoOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000
ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000;oC4a<
0_l00007oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH00ol0003oOgmoo`000002oiVIV@03
o`000?nc/k?o000000[oc<c<00?o0000ok>c/ol000000_nIVIT01ol0003oOgmoo`000?mVIVKo0000
oda<C?l000002_lc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c/`03
o`000?o<c<coc<c<00Koc<c<00?o0000ok>c/ol000000_l000001?moOgoo0000ofIVI_l00002oda<
C003o`000?oooooooooo00Cooooo0Ol00001ooooo`7ooooo000Tooooo`;o00001?ooool5oiVIV@03
o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmoO`03
o`000?mVIVKoIVIV00[oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0<ofIVIP03
o`000?moOgooOgmo00KoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`0Cok>c/`03
o`000?nIVIWoVIVI00?oVIVI00Go0000ogmoOomoOgooOgmoo`000004ofIVIP03o`000?m<C4coC4a<
00?oC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C003oda<C004o`000?mVIVKoIVIV
o`0000?oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc
/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00002oda<C003
o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP03o`000?moOgoo0000
00;oVIVI00?o0000ok>c/ol000002_o<c<`00ol0003o/k>co`000002oiVIV@07o`000?moOgoo0000
ofIVI_l0003oC4a<o`00000:oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000
00;o/k>c00?o0000olc<c?o<c<`01_o<c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIV
o`000002oda<C003o`000?oooooooooo00?ooooo0_l00002ooooo`009?ooool00ol0003ooooooooo
o`03ooooo`CoVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?mo
OgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mV
IVKoIVIV00coIVIV00?o0000ogmoOomoOgl01_moOgl00ol0003oVIVIoiVIV@05oiVIV@03o`000?nc
/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000CoIVIV
00?o0000oda<C?m<C4`01?m<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00;oC4a<
00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000Go/k>c00?o0000olc<
c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`06o`000?nIVIWoVIVIo`000?moOgoo00000_mV
IVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo0000
00;oOgmo00Ko0000oiVIVOnIVIWo0000ok>c/ol00009olc<c006o`000?nc/k?o/k>co`000?nIVIWo
00000_moOgl01Ol0003oIVIVo`000?m<C4co000000Wo<c<c00co0000oda<C?m<C4co0000ofIVI_l0
003oOgmoo`000?nIVIWo0000ok>c/ol00009olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`00
0?mVIVKo000000;oC4a<00?o0000ooooooooool01?ooool1o`00007ooooo0Oooool002Cooooo00?o
0000ooooooooool00oooool3oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT03?nI
VIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<
C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00KoOgmo00?o0000oiVIVOnIVIT01OnI
VIT00ol0003o/k>cok>c/`0Dok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomoOgooOgmo
o`000004ofIVIP03o`000?m<C4coC4a<00?oC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<
oda<C003oda<C004o`000?mVIVKoIVIVo`0000?oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0
003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl0
1?l0003oIVIVofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<
o`000002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`00ol0003o
/k>co`000002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c
<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`0
1oo<c<`2o`000004oiVIVOl0003oOgmoogmoO`;o00000_m<C4`00ol0003o<c<cooooo`05ooooo`7o
00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`;oVIVI00?o0000ok>c/onc/k<0
5_nc/k<2o`0000coVIVI0_l0000:ogmoO`03o`000?mVIVKoIVIV00[oIVIV0_l0000Hoda<C003o`00
0?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl01_moOgl00ol0003oVIVIoiVIV@05oiVIV@03o`00
0?nc/k?o/k>c01Co/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000Co
IVIV00?o0000oda<C?m<C4`01?m<C4`00ol0003o<c<coc<c<`03oc<c<`03o`000?m<C4coC4a<00?o
C4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc/k<0
0ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Ko0000oiVIVOnIVIWo0000ogmo
Ool00002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01ol0003oC4a<oda<C?m<C4co0000
ofIVI_l000000_moOgl01?l0003oVIVIo`000?l00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Ko
0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc
<c<01_lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`00
0?o<c<coc<c<00Koc<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`0
0ol0003o<c<cooooo`05ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03oooo
o`03oiVIVOl0003o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmo
O`03o`000?mVIVKoIVIV00[oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0;ofIV
IP03o`000?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT01OnIVIT00ol0003o/k>cok>c/`0Dok>c
/`03o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`000003ofIVIP03o`000?m<C4co
C4a<00GoC4a<00?o0000oc<c<olc<c<00olc<c<00ol0003oC4a<oda<C003oda<C005o`000?mVIVKo
IVIVofIVI_l000000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Co/k>c00?o0000olc<c?o<c<`0
1Oo<c<`00ol0003o/k>cok>c/`02ok>c/`06o`000?nIVIWoVIVIo`000?moOgoo00000_mVIVH01Ol0
003oC4a<oda<C?m<C4co000000So<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo
00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c006o`000?nc/k?o/k>co`000?nI
VIWo00000_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00[o0000oda<
C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c009
o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<oooool01Ooo
ool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool00ol0003o/k>cok>c/`0F
ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0;
ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`07
ogmoO`03o`000?nIVIWoVIVI00GoVIVI00?o0000ok>c/onc/k<05?nc/k<00ol0003oVIVIoiVIV@02
oiVIV@05o`000?moOgooOgmoogmoOol000001?mVIVH00ol0003oC4a<oda<C004oda<C003o`000?lc
<c?o<c<c00?o<c<c00?o0000oda<C?m<C4`00om<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo
00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc
/k<00_nc/k<01_l0003oVIVIoiVIVOl0003oOgmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`00
0008oc<c<`07o`000?m<C4coC4a<oda<C?l0003oIVIVo`000002ogmoO`03o`000?nIVIWo000000?o
/k>c00?o0000olc<c?o<c<`01_o<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00?o0000
ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmo
o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`2o`0000;oVIVI0_l000001OmVIVKo
0000oda<C?m<C4co000000;o<c<c1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000oooooooo
ool00ooooolHok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003o
IVIVofIVIP0:ofIVIP;o00006?m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00Oo
Ogmo00?o0000oiVIVOnIVIT01OnIVIT00ol0003o/k>cok>c/`0Cok>c/`;o00001?nIVIT00ol0003o
OgmoogmoO`02ogmoO`05o`000?mVIVKoIVIVofIVI_l000001_m<C4`00ol0003o<c<coc<c<`03oc<c
<`;o00001Om<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`00
0003ok>c/`;o00001oo<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo
00000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Oo0000oda<C?m<C4coC4a<o`000?mV
IVKo000000;oOgmo00?o0000oiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c006o`000?nc
/k?o/k>co`000?nIVIWo00000_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko
<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol0000:olc<c0;o
000000KoVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Kooooo0Ol00001
ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo5onc/k<00ol0003oVIVIoiVIV@0;oiVI
V@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<oda<C00Goda<
C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@06oiVI
V@03o`000?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT00onIVIT01Ol0003oOgmoogmoOomoOgoo
000000CoIVIV00?o0000oda<C?m<C4`01?m<C4`00ol0003o<c<coc<c<`03oc<c<`03o`000?m<C4co
C4a<00CoC4a<00Co0000ofIVI_mVIVKo00000omoOgl01Ol0003oVIVIoiVIVOnIVIWo000000?o/k>c
00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomo
Ogoo00000_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`07o`000?m<C4coC4a<oda<C?l0003oIVIV
o`000002ogmoO`03o`000?nIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01_l0003o/k>c
ok>c/ol0003oVIVIo`0000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c
<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00002_o<c<`2o`00
0006oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06ooooo`7o00000Ooo
ool1ooooo`006oooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000ooooooooool00ooooolF
ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0;
ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`07
ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc/k<04onc/k<00ol0003oVIVIoiVIV@03
oiVIV@03o`000?moOgooOgmo00;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000006oda<C003o`000?lc
<c?o<c<c00?o<c<c00?o0000oda<C?m<C4`01?m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo
00Go0000oiVIVOnIVIWoVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o0000ok>c/onc
/k<00_nc/k<01_l0003oVIVIoiVIVOl0003oOgmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`00
0008oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000?o
/k>c00?o0000olc<c?o<c<`01_o<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00?o0000
ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmo
o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`01?l0003o/k>co`000?nIVIT2o`00
00;oIVIV00?o0000oda<C?l000000olc<c<6ooooo`7o00000Oooool1ooooo`007?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00?ooooo5Onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03
o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02_mVIVH2o`0001SoC4a<00?o0000ofIVI_mV
IVH02omVIVH00ol0003oOgmoogmoO`07ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc
/k<05?nc/k<00ol0003oVIVIoiVIV@02oiVIV@03o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mV
IVH00_mVIVH00ol0003oC4a<oda<C004oda<C003o`000?lc<c?o<c<c00?o<c<c00?o0000oda<C?m<
C4`00om<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<0
0ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmo
Ool00002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01ol0003oC4a<oda<C?m<C4co0000
ofIVI_l000000_moOgl00ol0003oVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Ko0000
ok>c/onc/k?o0000oiVIVOl00002ogmoO`05o`000?mVIVKo0000oda<C?l000002_lc<c<02Ol0003o
C4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go
0000ok>c/ol0003o0000oiVIV@02o`000005ofIVI_l0003oC4a<oda<C?l000000olc<c<6ooooo`7o
00000Oooool1ooooo`006Oooool5o`0000Kooooo0ol00003oooooaCo/k>c00?o0000oiVIVOnIVIT0
2onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00[oIVIV00?o0000oda<C?m<C4`0
5om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00OoOgmo00?o0000oiVIVOnIVIT0
1_nIVIT00ol0003o/k>cok>c/`0Dok>c/`03o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl0
0_moOgl00ol0003oIVIVofIVIP02ofIVIP03o`000?m<C4coC4a<00CoC4a<00?o0000oc<c<olc<c<0
0olc<c<00ol0003oC4a<oda<C003oda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01?l0003o
VIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002
oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`07o`00
0?m<C4coC4a<oda<C?l0003oIVIVo`000002ogmoO`03o`000?nIVIWo000000?o/k>c00?o0000olc<
c?o<c<`01_o<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00Go0000ofIVI_l0003oC4a<
o`00000:oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000
olc<c?o<c<`01_o<c<`00ol0003o/k>co`000002oiVIV@;o000000GoIVIVo`000?m<C4coC4a<o`00
0003oc<c<`Cooooo0ol00002ooooo`006Oooool01?m4A4CogMgMooooool00007ooooo`03o`000?oo
oooooooo00?ooooo4onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o
0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o
0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o
0000oiVIVOnIVIT01?nIVIT01Ol0003oOgmoogmoOomoOgoo000000CoIVIV00?o0000oda<C?m<C4`0
1?m<C4`00ol0003o<c<coc<c<`03oc<c<`03o`000?m<C4coC4a<00?oC4a<00Go0000ofIVI_mVIVKo
IVIVo`000003ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0
003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01Ol0003oC4a<oda<
C?m<C4co000000So<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00?o0000oiVI
VOl000000onc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Go0000
ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Wo0000oda<C?l0003oIVIV
o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c007o`000?nc/k?o/k>c
o`000?nIVIWo0000ogmoO`02o`0000;oC4a<00?o0000oc<c<olc<c<00_lc<c<6ooooo`7o00000Ooo
ool1ooooo`006Oooool01?oMgMgoEEEEooooool00007ooooo`03o`000?oooooooooo00?ooooo4_nc
/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo0_l0000=ofIVIP03o`000?m<
C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nI
VIWoVIVI00KoVIVI00?o0000ok>c/onc/k<05?nc/k<00ol0003oVIVIoiVIV@03oiVIV@05o`000?mo
OgooOgmoogmoOol000001?mVIVH00ol0003oC4a<oda<C005oda<C003o`000?lc<c?o<c<c00;o<c<c
00?o0000oda<C?m<C4`01?m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Go0000oiVIVOnI
VIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0
003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc
<c<01?l0003oC4a<oda<C?l00002ofIVIP06o`000?moOgooOgmoo`000?nIVIWo00000onc/k<00ol0
003oc<c<olc<c006olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP04o`00
0?m<C4coC4a<o`0000So<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000
0_nc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>co`000?nIVIT00_l000001OmVIVKo
0000oda<C?m<C4co000000Co<c<c1_ooool1o`00007ooooo0Oooool001[ooooo00?oMgMgolc<c?l0
00001oooool00ol0003oooooooooo`03oooooa7o/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003o
OgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00coIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003o
IVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o
/k>cok>c/`0Eok>c/`03o`000?nIVIWoVIVI00?oVIVI00Go0000ogmoOomoOgooOgmoo`000004ofIV
IP03o`000?m<C4coC4a<00CoC4a<00?o0000oc<c<olc<c<00olc<c<00ol0003oC4a<oda<C004oda<
C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000?o/k>c00?o
0000olc<c?o<c<`01_o<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo
00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`00
00;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00009olc<c008o`000?nc/k?o
/k>co`000?nIVIWo0000ogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00[o0000oda<
C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c005
o`000?nc/k?o/k>co`000?nIVIT00_l000001OmVIVKo0000oda<C?m<C4co000000Co<c<c1_ooool1
o`00007ooooo0Oooool001[ooooo00?ok^k^odA4A?l000001oooool00ol0003oooooooooo`03oooo
oa3o/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV
00coIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo
00SoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`0Eok>c/`03o`000?nIVIWoVIVI
00?oVIVI00?o0000ogmoOomoOgl00_moOgl01Ol0003oIVIVofIVI_mVIVKo000000OoC4a<00?o0000
oc<c<olc<c<00_lc<c<00ol0003oC4a<oda<C004oda<C005o`000?mVIVKoIVIVofIVI_l000000_mo
Ogl01Ol0003oVIVIoiVIVOnIVIWo000000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>c
ok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0
003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Ko0000ogmoOomoOgoo0000oiVI
VOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmo
o`0000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<01ol0003oC4a<o`000?mVIVKo0000ogmoOol0
00000_nIVIT00ol0003o/k>co`000008olc<c005o`000?nc/k?o/k>co`000?nIVIT00_l000001OmV
IVKo0000oda<C?m<C4co000000Go<c<c1_ooool1o`00007ooooo0Oooool001_ooooo00?oMgMgo`00
0?ooool01_ooool00ol0003oooooooooo`03ooooo`oo/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0
003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00coIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0
003oIVIVofIVIP0:ofIVIP;o00002_moOgl00ol0003oVIVIoiVIV@07oiVIV@03o`000?nc/k?o/k>c
01Co/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV
00;oIVIV00?o0000oda<C?m<C4`01?m<C4`00ol0003o<c<coc<c<`02oc<c<`03o`000?m<C4coC4a<
00CoC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000onc
/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000onIVIT00ol0003oOgmo
o`000003ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIV
IP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`02?l0003o/k>cok>c/ol0
003oVIVIo`000?moOgoo00000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`0:o`000?m<C4coC4a<
o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o
/k>cok>c/ol0003oVIVI00;o000000GoIVIVo`000?m<C4coC4a<o`000005oc<c<`Kooooo0Ol00001
ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo3_nc/k<00ol0003oVIVIoiVIV@0;oiVI
V@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH03?mVIVH00ol0003oC4a<oda<C00Foda<
C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@08oiVI
V@03o`000?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`03ogmo
O`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01?m<C4`00ol0003o<c<coc<c<`02oc<c
<`03o`000?m<C4coC4a<00CoC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`04o`000?nIVIWo
VIVIo`0000Co/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000?oVIVI
00?o0000ogmoOol000000omVIVH01?l0003oC4a<oda<C?l00008oc<c<`05o`000?m<C4coC4a<oda<
C?l000000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Woc<c<00So0000
ok>c/onc/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<02_l0
003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ko
c<c<00Go0000ok>c/onc/k?o0000oiVIV@02o`000005ofIVI_l0003oC4a<oda<C?l000001Olc<c<6
ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`go/k>c00?o0000oiVI
VOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV0_l0000Hoda<
C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@08oiVI
V@03o`000?nc/k?o/k>c01Co/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`02ogmo
O`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01?m<C4`00ol0003o<c<coc<c<`02oc<c
<`03o`000?m<C4coC4a<00CoC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`05o`000?nIVIWo
VIVIoiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol00000
0onIVIT00ol0003oOgmoo`000003ofIVIP05o`000?m<C4coC4a<oda<C?l000001olc<c<00ol0003o
C4a<oda<C002oda<C005o`000?mVIVKo0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00009
olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl00ol0003oIVIVo`000002oda<C003o`00
0?lc<c?o<c<c00Ko<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`;o00000_nc/k<00ol0
003oc<c<olc<c006olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;o
C4a<00?o0000oc<c<olc<c<00olc<c<6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003ooooo
ooooo`03ooooo`co/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`00
0?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`00
0?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02?nIVIT00ol0003o/k>cok>c/`0Dok>c/`03o`00
0?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP02ofIVIP03o`00
0?m<C4coC4a<00GoC4a<00?o0000oc<c<olc<c<00_lc<c<00ol0003oC4a<oda<C004oda<C005o`00
0?mVIVKoIVIVofIVI_l000000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Co/k>c00?o0000olc<
c?o<c<`01Oo<c<`2o`0000?o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l0
0003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP03o`00
0?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`02?l0003o/k>cok>c/ol0003oVIVI
o`000?moOgoo00000_mVIVH00ol0003oC4a<o`000009oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo
0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`03?l0003o/k>cok>c/ol0
003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000Ko<c<c1_ooool1o`00007ooooo0Oooool0
02Cooooo00?o0000ooooooooool00oooool;ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmo
OomoOgl02?moOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIV
I_mVIVH02omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00OoVIVI00?o0000ok>c
/onc/k<05Onc/k<00ol0003oVIVIoiVIV@03oiVIV@03o`000?moOgooOgmo00;oOgmo00?o0000ofIV
I_mVIVH00_mVIVH00ol0003oC4a<oda<C005oda<C003o`000?lc<c?o<c<c00;o<c<c00?o0000oda<
C?m<C4`01?m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`00
0004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVI
VOl00002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003o
C4a<oda<C?m<C4co000000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00009
olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP03o`000?m<C4co000000Wo
<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<
olc<c006olc<c003o`000?nc/k?o000000;oVIVI00Oo0000ogmoOol0003oIVIVo`000?m<C4co0000
00Ko<c<c1_ooool1o`00007ooooo0Oooool002Cooooo0_l00004ooooo`[o/k>c00?o0000oiVIVOnI
VIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV0_l0000Hoda<C003
o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@07oiVIV@03
o`000?nc/k?o/k>c01Go/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`02ogmoO`03
o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01Om<C4`00ol0003o<c<coc<c<`02oc<c<`03
o`000?m<C4coC4a<00CoC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`05o`000?nIVIWoVIVI
oiVIVOl000001?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000
oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c
00Go0000oda<C?m<C4coC4a<o`000002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc
/k?o00002Oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@;o00000_mVIVH01?l0003oC4a<oda<C?l0
0008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV0_l000001OnIVIWo0000ok>c/onc/k?o000000So
c<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00007oc<c<`Go
oooo0_l00002ooooo`009?ooool00ol0003oooooooooo`03ooooo`Wo/k>c00?o0000oiVIVOnIVIT0
2onIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`0
5om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo0_l00009oiVIV@03o`00
0?nc/k?o/k>c01Go/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`02ogmoO`03o`00
0?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01Om<C4`00ol0003o<c<coc<c<`02oc<c<`03o`00
0?m<C4coC4a<00CoC4a<00Co0000ofIVI_mVIVKoIVIV0_l00002ogmoO`05o`000?nIVIWoVIVIoiVI
VOl000001?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVI
VOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go
0000oda<C?m<C4coC4a<o`000002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o
00002?o<c<`2o`0000;o/k>c00Go0000oiVIVOl0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<
o`0000So<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0
003oc<c<olc<c006olc<c009o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIV00;o0000
2?lc<c<6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`So/k>c00?o
0000oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`07ogmoO`03o`000?mVIVKoIVIV00coIVIV00?o
0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0:ofIVIP;o00002omoOgl00ol0003oVIVIoiVI
V@08oiVIV@03o`000?nc/k?o/k>c01Go/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmo
O`02ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01Om<C4`00ol0003o<c<coc<c
<`02oc<c<`03o`000?m<C4coC4a<00CoC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`05o`00
0?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o
/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o
<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP03o`000?moOgoo000000;oVIVI00Co
0000ok>c/onc/k?o00002?o<c<`02Ol0003o/k>cok>c/onc/k?o0000oiVIVOl0003oOgmoo`000002
ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`00
0?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c009o`000?nc/k?o/k>co`000?nIVIWo0000
ogmoOol0003oIVIV00;o00002?lc<c<6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003ooooo
ooooo`03ooooo`Oo/k>c00?o0000oiVIVOnIVIT02onIVIT2o`0000WoOgmo00?o0000ofIVI_mVIVH0
2omVIVH2o`0001OoC4a<0_l0000<ofIVIP03o`000?moOgooOgmo00[oOgmo00?o0000oiVIVOnIVIT0
2?nIVIT00ol0003o/k>cok>c/`0Eok>c/`03o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl0
0_moOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<00CoC4a<00?o0000oc<c<olc<c<0
0_lc<c<00ol0003oC4a<oda<C004oda<C005o`000?mVIVKoIVIVofIVI_l000001?moOgl01?l0003o
VIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01ol0
003oVIVIoiVIVOnIVIWo0000ogmoOol000000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000Wo<c<c
00Co0000oda<C?m<C4co00000_mVIVH01_l0003oOgmoogmoOol0003oVIVIo`0000;o/k>c00?o0000
olc<c?o<c<`01_o<c<`02Ol0003o/k>cok>c/onc/k?o0000oiVIVOl0003oOgmoo`000002ofIVIP04
o`000?m<C4coC4a<o`0000So<c<c00Co0000oda<C?m<C4coC4a<0_l000001omoOgoo0000oiVIVOnI
VIWo0000ok>c/ol000002?o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0
003oC4a<o`0000So<c<c1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00ooo
ool6ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIV
IP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmo
O`09ogmoO`;o00002_nIVIT00ol0003o/k>cok>c/`0Eok>c/`03o`000?nIVIWoVIVI00?oVIVI00?o
0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<00GoC4a<00Go
0000oc<c<olc<c?o<c<co`000007oda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01?l0003o
VIVIoiVIVOl00005ok>c/`03o`000?o<c<coc<c<00Goc<c<00Go0000ok>c/onc/k?o/k>co`000003
oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`07o`00
0?m<C4coC4a<oda<C?l0003oIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000;o/k>c00?o0000
olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV00Co
0000oda<C?m<C4co00002?lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0
0002ok>c/`03o`000?o<c<coc<c<00Koc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`00
0?mVIVKo0000oda<C?l00008oc<c<`Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooo
oooo00?ooooo1Onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000
ofIVI_mVIVH02_mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00coIVIV00?o0000
ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0:oiVIV@03o`000?nc/k?o/k>c01Go/k>c00?o0000
oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000
oda<C?m<C4`01Om<C4`01Ol0003o<c<coc<c<olc<c?o000000KoC4a<00?o0000ofIVI_mVIVH00_mV
IVH01Ol0003oOgmoogmoOomoOgoo000000;oVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<
olc<c004olc<c003o`000?nc/k?o/k>c00;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`04
o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01ol0003oC4a<oda<C?m<C4co
0000ofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<
00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`00
00So<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003o
c<c<olc<c006olc<c003o`000?nc/k?o/k>c00;o00000_moOgl01Ol0003oIVIVo`000?m<C4co0000
00So<c<c00?o0000ooooooooool00oooool1o`00007ooooo0Oooool002Cooooo00?o0000oooooooo
ool00oooool4ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003o
IVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003o
OgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00[oVIVI00?o0000ok>c/onc/k<05Onc/k<00ol0003o
VIVIoiVIV@03oiVIV@03o`000?moOgooOgmo00?oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003o
C4a<oda<C005oda<C005o`000?lc<c?o<c<coc<c<ol000001om<C4`01Ol0003oIVIVofIVI_mVIVKo
000000?oOgmo00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o
0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`05o`000?mVIVKoIVIVofIVI_l0
00000_m<C4`00ol0003o<c<coc<c<`07oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Ko0000ogmo
OomoOgoo0000oiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o0000
0_nIVIT00ol0003oOgmoo`000002ofIVIP03o`000?m<C4co000000Wo<c<c00[o0000oda<C?m<C4co
0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c003o`000?nc
/k?o/k>c00;o00000_moOgl01Ol0003oIVIVo`000?m<C4co000000So<c<c00?o0000ooooooooool0
0oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool3ok>c/`03o`000?nI
VIWoVIVI00coVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<
C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nI
VIWoVIVI00[oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@03oiVIV@03o`000?mo
OgooOgmo00;oOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C005oda<C005o`000?lc
<c?o<c<coc<c<ol000001_m<C4`00ol0003oIVIVofIVIP02ofIVIP05o`000?moOgooOgmoogmoOol0
00000_nIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc
/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`0
0ol0003o<c<coc<c<`06oc<c<`07o`000?m<C4coC4a<oda<C?l0003oIVIVo`000002ogmoO`04o`00
0?nIVIWoVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVI
V@06o`000?moOgooOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0:o`000?m<
C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`0
2_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c
00Go<c<c00?o0000ooooooooool01?ooool1o`00007ooooo0Oooool002Cooooo00?o0000oooooooo
ool00oooool2ok>c/`;o00003?nIVIT2o`0000[oOgmo00?o0000ofIVI_mVIVH02_mVIVH2o`0001So
C4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`;o00003?nIVIT00ol0003o
/k>cok>c/`0Eok>c/`03o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003o
IVIVofIVIP02ofIVIP03o`000?m<C4coC4a<00KoC4a<00Co0000oc<c<olc<c?o00001om<C4`01Ol0
003oIVIVofIVI_mVIVKo000000?oOgmo00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<
c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`05o`00
0?mVIVKoIVIVofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`04o`000?m<C4coC4a<o`00
00;oIVIV00Ko0000ogmoOomoOgoo0000oiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co
0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIVIP03o`000?m<C4co000000Wo<c<c
00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<
c006olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co00002?lc
<c<00ol0003oooooooooo`04ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03
ooooo`03ok>c/ol0003oVIVI00coVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0:
ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08
ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05Onc/k<00ol0003oVIVIoiVIV@04
oiVIV@03o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C006
oda<C004o`000?lc<c?o<c<co`0000OoC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`05o`00
0?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o
/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o
<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP06o`000?moOgooOgmoo`000?nIVIWo
00000onc/k<00ol0003oc<c<olc<c005olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT00ol0
003oOgmoo`000002ofIVIP03o`000?m<C4co000000Wo<c<c00[o0000oda<C?m<C4co0000ofIVI_l0
003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c003o`000?nc/k?o000000;o
VIVI00Oo0000ogmoOol0003oIVIVo`000?m<C4co000000So<c<c00?o0000ooooooooool01?ooool1
o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool00ol0003oVIVIoiVIV@0;oiVI
V@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<
C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVI
V@03o`000?nc/k?o/k>c01Go/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`02ogmo
O`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<C4`01_m<C4`01?l0003o<c<coc<c<ol00007
oda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01Ol0003oVIVIoiVIVOnIVIWo000000Co/k>c
00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`03ok>c/`04o`000?nIVIWoVIVIo`0000;o
Ogmo00Co0000ofIVI_mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<
oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<
00Wo0000ok>c/onc/k?o/k>co`000?nIVIWo0000ogmoOol000000_mVIVH00ol0003oC4a<o`000009
oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV0_l000001OnIVIWo0000ok>c/onc/k?o000000Soc<c<
00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00008oc<c<`03o`00
0?m<C4cooooo00Gooooo0Ol00001ooooo`7ooooo000Tooooo`;o00001?ooool=oiVIV@03o`000?mo
OgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02_mVIVH2o`0001SoC4a<00?o0000ofIVI_mVIVH02omV
IVH00ol0003oOgmoogmoO`08ogmoO`;o00003?nIVIT00ol0003o/k>cok>c/`0Eok>c/`03o`000?nI
VIWoVIVI00CoVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIVIP02ofIVIP03o`000?m<
C4coC4a<00OoC4a<00?o0000oc<c<ol000001om<C4`2o`0000?oIVIV00Go0000ogmoOomoOgooOgmo
o`000003oiVIV@03o`000?nc/k?o/k>c00;o/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>c
ok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0
003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01_l0003oOgmoogmoOol0
003oVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@05
o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`0:o`000?m<C4co0000
o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`03?l0003o
/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000So<c<c00?o0000oda<C?oo
ool01?ooool2o`0000;ooooo000Tooooo`03o`000?oooooooooo00?ooooo3?nIVIT00ol0003oOgmo
ogmoO`09ogmoO`03o`000?mVIVKoIVIV00[oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIV
ofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>c
ok>c/`0Eok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIV
ofIVIP02ofIVIP03o`000?m<C4coC4a<00SoC4a<00?o0000oda<C?m<C4`01_m<C4`00ol0003oIVIV
ofIVIP02ofIVIP05o`000?moOgooOgmoogmoOol000000onIVIT00ol0003o/k>cok>c/`02ok>c/`03
o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00onc/k<01?l0003oVIVIoiVIVOl00002ogmo
O`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<
C4co000000;oIVIV00Ko0000ogmoOomoOgoo0000oiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Ko
c<c<00Co0000ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000
oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl00000
0_nc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>co`000?nIVIT00_l00002ofIVIP03
o`000?m<C4co000000So<c<c00?o0000oda<C?ooool01Oooool1o`00007ooooo0Oooool002Cooooo
00?o0000ooooooooool00oooool;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH0
2omVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl0
2?moOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Go/k>c00?o0000oiVIVOnIVIT0
1?nIVIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`0
4Om<C4`00ol0003oIVIVofIVIP02ofIVIP05o`000?moOgooOgmoogmoOol000000onIVIT00ol0003o
/k>cok>c/`02ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003o
VIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01Olc<c<0
0ol0003oC4a<oda<C002oda<C008o`000?mVIVKoIVIVo`000?moOgoo0000oiVIVOl00003ok>c/`03
o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIV
IP04o`000?m<C4coC4a<o`0000So<c<c00So0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000;o
VIVI00?o0000ok>c/ol000002?o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIV
I_l0003oC4a<o`0000So<c<c00Co0000oda<C?m<C4co00001Oooool1o`00007ooooo0Oooool002Co
oooo00?o0000ooooooooool00oooool:oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mV
IVH02_mVIVH2o`0001SoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03
o`000?nIVIWoVIVI00coVIVI00?o0000ok>c/onc/k<05Onc/k<00ol0003oVIVIoiVIV@04oiVIV@03
o`000?moOgooOgmo00?oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C00Boda<C005
o`000?mVIVKoIVIVofIVI_l000000omoOgl01Ol0003oVIVIoiVIVOnIVIWo000000Go/k>c00?o0000
olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`02ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_mo
Ogl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4co
C4a<o`000002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`01?l0
003o/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c
<`07oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000
olc<c?o<c<`01_o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<
o`0000So<c<c00Co0000oda<C?m<C4co00001Oooool1o`00007ooooo0Oooool002Cooooo00?o0000
ooooooooool00oooool9oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02_mVIVH0
0ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl0
0ol0003oVIVIoiVIV@0;oiVIV@;o00006?nc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgoo
Ogmo00;oOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00Boda<C005o`000?mVIVKo
IVIVofIVI_l000000omoOgl01Ol0003oVIVIoiVIVOnIVIWo000000Co/k>c00?o0000olc<c?o<c<`0
1Oo<c<`00ol0003o/k>cok>c/`02ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01?l0003o
IVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002
ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`01?l0003o/k>cok>c
/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`0:
o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`0
1_o<c<`00ol0003o/k>cok>c/`02o`0000;oOgmo00Go0000ofIVI_l0003oC4a<o`000008oc<c<`04
o`000?m<C4coC4a<o`0000Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?o
oooo2?nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<
C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnI
VIT02onIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomo
Ogl00omoOgl00ol0003oIVIVofIVIP02ofIVIP03o`000?m<C4coC4a<01;oC4a<00Go0000ofIVI_mV
IVKoIVIVo`000004ogmoO`04o`000?nIVIWoVIVIo`0000Go/k>c00?o0000olc<c?o<c<`01?o<c<`0
0ol0003o/k>cok>c/`02ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01?l0003oIVIVofIV
I_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP03
o`000?moOgoo000000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c004o`000?nc/k?o/k>c
o`0000;oVIVI00?o0000ogmoOomoOgl00_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Ko0000
oda<C?m<C4co0000ofIVI_l00002ogmoO`;o00000_nc/k<00ol0003oc<c<olc<c006olc<c00:o`00
0?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc
<c<00ol0003oC4a<o`000006ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03
ooooo`OoVIVI00?o0000ogmoOomoOgl02?moOgl2o`0000goIVIV00?o0000oda<C?m<C4`05_m<C4`0
0ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT0
0ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl00omoOgl0
0ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<017oC4a<00?o0000ofIVI_mVIVH00_mVIVH0
1Ol0003oOgmoogmoOomoOgoo000000?oVIVI00?o0000ok>c/onc/k<00_nc/k<00ol0003oc<c<olc<
c005olc<c003o`000?nc/k?o/k>c00;o/k>c00?o0000oiVIVOnIVIT00_l00002ogmoO`04o`000?mV
IVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;o
IVIV00?o0000ogmoOol000000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Go0000ok>c
/onc/k?o0000oiVIV@02o`000004ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01olc
<c<00ol0003oC4a<o`000002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<
olc<c006olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co0000
2?lc<c<01?l0003oC4a<oda<C?l00006ooooo`7o00000Oooool1ooooo`009?ooool00ol0003ooooo
ooooo`03ooooo`KoVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0<ofIVIP03o`00
0?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`00
0?nIVIWoVIVI00_oVIVI0_l0000Hok>c/`03o`000?nIVIWoVIVI00GoVIVI00?o0000ogmoOomoOgl0
0omoOgl00ol0003oIVIVofIVIP02ofIVIP03o`000?m<C4coC4a<01;oC4a<00?o0000ofIVI_mVIVH0
0_mVIVH01Ol0003oOgmoogmoOomoOgoo000000?oVIVI00?o0000ok>c/onc/k<00_nc/k<00ol0003o
c<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000omoOgl01?l0
003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`0
1_l0003oIVIVofIVI_l0003oOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`000007olc<c004
o`000?nc/k?o/k>co`0000;oVIVI00Ko0000ogmoOomoOgoo0000ofIVI_l00002oda<C003o`000?lc
<c?o<c<c00Oo<c<c00Go0000oda<C?l0003oIVIVo`000002ogmoO`03o`000?nIVIWo000000;o/k>c
00?o0000olc<c?o<c<`01_o<c<`00ol0003o/k>co`000002oiVIV@04o`000?moOgoo0000o`0000;o
C4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00006ooooo`7o00000Oooool1oooo
o`009?ooool00ol0003oooooooooo`03ooooo`GoVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003o
IVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003o
OgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003o
VIVIoiVIV@05oiVIV@03o`000?moOgooOgmo00?oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003o
C4a<oda<C00Boda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgooOgmoo`000003oiVI
V@03o`000?nc/k?o/k>c00;o/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c
/`04o`000?nIVIWoVIVIo`0000?oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c
<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@04
o`000?nc/k?o/k>co`0000Soc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`03o`000?mV
IVKo000000;oC4a<00?o0000oc<c<olc<c<01olc<c<00ol0003oC4a<o`000002ofIVIP05o`000?mo
Ogoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c00<o`000?nc/k?o/k>co`000?nI
VIWo0000ogmoOol0003oIVIVo`000?m<C4co00002Olc<c<01Ol0003oC4a<o`000?mVIVKo000000Go
oooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo1?nIVIT00ol0003oOgmo
ogmoO`08ogmoO`03o`000?mVIVKoIVIV00coIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIV
ofIVIP0:ofIVIP;o00002_moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c
00?o0000oiVIVOnIVIT01OnIVIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00?oIVIV
00?o0000oda<C?m<C4`04_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Go0000oiVIVOnI
VIWoVIVIo`000005ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00onc/k<01?l0
003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01Olc
<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV0_l000001OmoOgoo0000oiVIVOnIVIWo000000;o
/k>c00?o0000olc<c?o<c<`01_o<c<`01ol0003o/k>cok>c/onc/k?o0000oiVIVOl000000_moOgl0
0ol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mV
IVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`03?l0003o/k>c
ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000Wo<c<c0_l000000omVIVKo0000
ooooo`05ooooo`7o00000Oooool1ooooo`009?ooool2o`0000Cooooo0onIVIT00ol0003oOgmoogmo
O`08ogmoO`03o`000?mVIVKoIVIV00coIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIV
IP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c
/`0Gok>c/`03o`000?nIVIWoVIVI00KoVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIV
IP03ofIVIP03o`000?m<C4coC4a<01;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`03o`00
0?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c004olc<c003o`00
0?nc/k?o/k>c00?o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00004oda<
C003o`000?lc<c?o<c<c00Go<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgoo
Ogmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01ol0003o/k>cok>c/onc/k?o0000oiVI
VOl000000_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<
C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<
c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000Wo<c<c0_l0
00000omVIVKo0000ooooo`04ooooo`;o00000_ooool002Cooooo00?o0000ooooooooool00oooool2
oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH2o`0001SoC4a<00?o0000
ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000
ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@06oiVIV@03o`000?moOgooOgmo00?oOgmo00?o0000
ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00Boda<C005o`000?mVIVKoIVIVofIVI_l000000omo
Ogl01Ol0003oVIVIoiVIVOnIVIWo000000Go/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>c
ok>c/`03ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0
003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Co0000ogmoOomoOgoo00000_nI
VIT01?l0003o/k>cok>c/ol00009olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl01?l0
003oIVIVofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00?o0000oda<C?l000000_mVIVH0
0ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Ooc<c<00co0000ok>c/onc/k?o0000
oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00009oc<c<`05o`000?m<C4co0000o`000?moOgl0
1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool00onIVIWo0000ogmo
O`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIV
IP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c
/`0Gok>c/`03o`000?nIVIWoVIVI00KoVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIV
IP03ofIVIP03o`000?m<C4coC4a<01;oC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmo
OomoOgoo000000?oVIVI00?o0000ok>c/onc/k<00_nc/k<00ol0003oc<c<olc<c005olc<c003o`00
0?nc/k?o/k>c00;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`00
00?oC4a<00?o0000oc<c<olc<c<01olc<c<01?l0003oC4a<oda<C?l00002ofIVIP04o`000?moOgoo
Ogmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`01_l0003o/k>cok>c/ol0003oVIVIo`00
00;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<
o`0000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00co
0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00009oc<c<`05o`000?m<
C4co0000o`000?moOgl01_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00ooo
ool00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00coIVIV00?o0000oda<C?m<C4`05_m<
C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02_nI
VIT00ol0003o/k>cok>c/`0Hok>c/`03o`000?nIVIWoVIVI00KoVIVI00?o0000ogmoOomoOgl00omo
Ogl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<01;oC4a<00?o0000ofIVI_mVIVH00_mV
IVH01Ol0003oOgmoogmoOomoOgoo000000?oVIVI00?o0000ok>c/onc/k<00_nc/k<00ol0003oc<c<
olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000omoOgl01?l0003o
IVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Oo<c<c00Co0000oda<C?m<C4co00000_mVIVH0
1?l0003oOgmoogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Woc<c<00Ko0000ok>c/onc/k?o
0000oiVIVOl00002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0
003oC4a<oda<C?l00002ofIVIP;o00000_nIVIT01?l0003o/k>cok>c/ol00008olc<c00<o`000?nc
/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co00002Olc<c<01Ol0003oC4a<o`00
0?l0003oOgmo00Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo2_mo
Ogl00ol0003oIVIVofIVIP0;ofIVIP;o00006?m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?mo
OgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02_nIVIT00ol0003o/k>cok>c/`0Hok>c/`03o`000?nI
VIWoVIVI00KoVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<
C4coC4a<01;oC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000?oVIVI
00?o0000ok>c/onc/k<00_nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c
00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`04o`000?mVIVKoIVIVo`0000;oC4a<00?o0000oc<c
<olc<c<01olc<c<01?l0003oC4a<oda<C?l00002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Co
0000ok>c/onc/k?o00002Oo<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000?oOgmo0_l00002oda<
C003o`000?lc<c?o<c<c00Oo<c<c00?o0000oda<C?l000000_mVIVH01Ol0003oOgmoo`000?nIVIWo
000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo
0000ofIVI_l0003oC4a<o`0000Wo<c<c00Oo0000oda<C?l0003oIVIVo`000?moOgoo000000Gooooo
0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo2OmoOgl00ol0003oIVIVofIV
IP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmo
O`08ogmoO`;o00003?nIVIT00ol0003o/k>cok>c/`0Hok>c/`03o`000?nIVIWoVIVI00KoVIVI00?o
0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<01;oC4a<00?o
0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000?oVIVI00?o0000ok>c/onc/k<0
0onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Co0000oiVIVOnIVIWo
00000omoOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<
C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o0000
2?o<c<`01ol0003o/k>cok>c/onc/k?o0000oiVIVOl000000_moOgl00ol0003oIVIVo`000002oda<
C003o`000?lc<c?o<c<c00Oo<c<c00?o0000oda<C?l000000_mVIVH01Ol0003oOgmoo`000?nIVIWo
000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo
0000ofIVI_l0003oC4a<o`0000So<c<c00So0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000Go
oooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo2?moOgl00ol0003oIVIV
ofIVIP0<ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02_mVIVH2o`0000_oOgmo
00?o0000oiVIVOnIVIT02_nIVIT00ol0003o/k>cok>c/`0Hok>c/`03o`000?nIVIWoVIVI00OoVIVI
00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<01;oC4a<
00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000?oVIVI00?o0000ok>c/onc
/k<00onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Co0000oiVIVOnI
VIWo00000omoOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000
oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o
00002?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@06o`000?moOgooOgmoo`000?mVIVKo00000_m<
C4`00ol0003o<c<coc<c<`07oc<c<`05o`000?m<C4co0000ofIVI_l000000_moOgl00ol0003oVIVI
o`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmo
o`000?mVIVKo0000oda<C?l00008oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol00005
ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`OoOgmo00?o0000ofIV
I_mVIVH02omVIVH2o`0001OoC4a<0_l0000<ofIVIP03o`000?moOgooOgmo00[oOgmo00?o0000oiVI
VOnIVIT02_nIVIT00ol0003o/k>cok>c/`0Hok>c/`03o`000?nIVIWoVIVI00OoVIVI00?o0000ogmo
OomoOgl00omoOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<01;oC4a<00?o0000ofIV
I_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000?oVIVI00?o0000ok>c/onc/k<00onc/k<0
0ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Co0000oiVIVOnIVIWo00000omo
Ogl01?l0003oIVIVofIVI_l00004oda<C003o`000?lc<c?o<c<c00Go<c<c00Go0000oda<C?m<C4co
C4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`000007
olc<c007o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000002ogmoO`03o`000?mVIVKo000000;oC4a<
00?o0000oc<c<olc<c<01olc<c<00ol0003oC4a<o`000002ofIVIP05o`000?moOgoo0000oiVIVOl0
00000_nc/k<00ol0003oc<c<olc<c006olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0
003oIVIVo`000?m<C4co00002?lc<c<02?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo00001_oo
ool1o`00007ooooo0Oooool001Wooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oo
oooooooo00?ooooo1_moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o
0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`09ogmoO`;o00003?nIVIT00ol0003o/k>cok>c
/`0Hok>c/`03o`000?nIVIWoVIVI00KoVIVI0_l00005ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o
0000oda<C?m<C4`04om<C4`01Ol0003oIVIVofIVI_mVIVKo000000CoOgmo00Go0000oiVIVOnIVIWo
VIVIo`000005ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00_nc/k<01Ol0003o
VIVIoiVIVOnIVIWo000000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000003oda<C003o`000?lc<c?o
<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP03o`000?moOgoo000000;oVIVI00Go
0000ok>c/onc/k?o/k>co`000008olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol0
00000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Go0000
ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00co0000ok>c/onc/k?o0000
oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00008oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo
0000ogmoOol00006ooooo`7o00000Oooool1ooooo`006Oooool01OmEEEGoMgMgoooooonHV9So8B4Q
00Kooooo00?o0000ooooooooool00oooool6ogmoO`03o`000?mVIVKoIVIV00[oIVIV00?o0000oda<
C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVI
VOnIVIT02onIVIT00ol0003o/k>cok>c/`0Hok>c/`03o`000?nIVIWoVIVI00OoVIVI00?o0000ogmo
OomoOgl01?moOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<01?oC4a<00Go0000ofIV
I_mVIVKoIVIVo`000004ogmoO`04o`000?nIVIWoVIVIo`0000Ko/k>c00?o0000olc<c?o<c<`01?o<
c<`00ol0003o/k>cok>c/`02ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01Ol0003oIVIV
ofIVI_mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co0000
00;oIVIV00?o0000ogmoOol000000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Co0000
ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c
00Co0000oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<
c?o<c<`01_o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`00
00So<c<c00So0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000Kooooo0Ol00001ooooo`7ooooo
000Iooooo`05o`000?ooooooooooooooool000001_ooool3o`0000?ooooo1OmoOgl00ol0003oIVIV
ofIVIP0:ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003oOgmo
ogmoO`08ogmoO`03o`000?nIVIWoVIVI00coVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVI
oiVIV@07oiVIV@03o`000?moOgooOgmo00GoOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<
oda<C00Boda<C005o`000?mVIVKoIVIVofIVI_l000001?moOgl01Ol0003oVIVIoiVIVOnIVIWo0000
00Ko/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`03ok>c/`04o`000?nIVIWoVIVI
o`0000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o
0000oda<C?m<C4`00_m<C4`01_l0003oIVIVofIVI_l0003oOgmoo`0000;oVIVI00Go0000ok>c/onc
/k?o/k>co`000008olc<c004o`000?nc/k?o/k>co`0000;oVIVI0_l00003ofIVIP04o`000?m<C4co
C4a<o`0000So<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`;o00000onc/k<00ol0003o
c<c<olc<c006olc<c005o`000?nc/k?o/k>co`000?nIVIT00_l00002ofIVIP03o`000?m<C4co0000
00So<c<c00So0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000Cooooo0ol00002ooooo`006Ooo
ool01Ol0003oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool00oooool4ogmoO`03o`00
0?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`00
0?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`00
0?nIVIWoVIVI00SoVIVI00?o0000ogmoOomoOgl01?moOgl00ol0003oIVIVofIVIP03ofIVIP03o`00
0?m<C4coC4a<01?oC4a<00Go0000ofIVI_mVIVKoIVIVo`000004ogmoO`04o`000?nIVIWoVIVIo`00
00Ko/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`02ok>c/`05o`000?nIVIWoVIVI
oiVIVOl000000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc
<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o0000ogmoOol000000_nIVIT01Ol0003o/k>c
ok>c/onc/k?o000000Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000003ofIV
IP04o`000?m<C4coC4a<o`0000Oo<c<c00Co0000oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`00
0?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`00
0?moOgoo0000ofIVI_l0003oC4a<o`0000Wo<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000
oiVIVOl000001Oooool1o`00007ooooo0Oooool001Wooooo00Go0000oeEEEOl0003o410@olc<c006
ooooo`03o`000?oooooooooo00?ooooo0omoOgl00ol0003oIVIVofIVIP0:ofIVIP;o00006?m<C4`0
0ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo0_l0000<oiVIV@;o00006Onc/k<0
0ol0003oVIVIoiVIV@07oiVIV@;o00001_moOgl00ol0003oIVIVofIVIP04ofIVIP03o`000?m<C4co
C4a<01;oC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000?oVIVI00?o
0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Go
0000oiVIVOnIVIWoVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc
<c<01Olc<c<00ol0003oC4a<oda<C002oda<C006o`000?mVIVKoIVIVo`000?moOgoo00000_nIVIT0
1Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmo
o`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002
ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`03?l0003o/k>cok>c/ol0
003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000Wo<c<c00Wo0000oda<C?l0003oIVIVo`00
0?moOgoo0000oiVIVOl000001Oooool1o`00007ooooo0Oooool001Wooooo00?oEEEEohN7Qoooool0
2?ooool00ol0003oooooooooo`03ooooo`;oOgmo00?o0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<
oda<C00Goda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVI
oiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02?nIVIT00ol0003oOgmo
ogmoO`04ogmoO`03o`000?mVIVKoIVIV00CoIVIV00?o0000oda<C?m<C4`04om<C4`00ol0003oIVIV
ofIVIP02ofIVIP04o`000?moOgooOgmoo`0000CoVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003o
c<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmo
O`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002
oda<C006o`000?mVIVKoIVIVo`000?moOgoo00000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000So
c<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000;oC4a<00?o
0000oc<c<olc<c<01_lc<c<02?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo00000_nIVIT01?l0
003o/k>cok>c/ol00008olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`00
0?m<C4co00002Olc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000005ooooo`7o
00000Oooool1ooooo`006Oooool00ooMgMgo410@oiRHV008ooooo`03o`000?oooooooooo00?ooooo
00?oOgmoo`000?mVIVH03?mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV
00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c
0_l0000:oiVIV@03o`000?moOgooOgmo00GoOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<
oda<C00Coda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgooOgmoo`000003oiVIV@03
o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`05
o`000?nIVIWoVIVIoiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00004oda<C003o`000?lc<c?o
<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01_l0003oIVIVofIVI_l0003oOgmoo`0000?oVIVI
00Co0000ok>c/onc/k?o00002?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo0000
00;oIVIV00Co0000oda<C?m<C4co00002?lc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo
00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c00<o`000?nc/k?o/k>co`000?nI
VIWo0000ogmoOol0003oIVIVo`000?m<C4co00002Olc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmo
Ool0003oVIVIo`000006ooooo`7o00000Oooool1ooooo`006_ooool01?o<c<coA4A4o`000?l@4106
ooooo`03o`000?oooooooooo00?ooooo00?o0000ofIVI_mVIVH02_mVIVH2o`0001SoC4a<00?o0000
ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`;o00003OnIVIT00ol0003o/k>cok>c/`0F
ok>c/`03o`000?nIVIWoVIVI00WoVIVI0_l00006ogmoO`03o`000?mVIVKoIVIV00CoIVIV00?o0000
oda<C?m<C4`04_m<C4`00ol0003oIVIVofIVIP02ofIVIP05o`000?moOgooOgmoogmoOol000001?nI
VIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00onc
/k<01?l0003oVIVIoiVIVOl00003ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc
<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT0
1Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmo
o`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002
ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`03?l0003o/k>cok>c/ol0
003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000Wo<c<c00Wo0000oda<C?l0003oIVIVo`00
0?moOgoo0000oiVIVOl000001_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool0
0oooool<ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmo
ogmoO`08ogmoO`03o`000?nIVIWoVIVI00coVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVI
oiVIV@09oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH01?mVIVH00ol0003oC4a<
oda<C00Boda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgooOgmoo`000003oiVIV@03
o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`02ok>c/`05
o`000?nIVIWoVIVIoiVIVOl000000omoOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o
<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI
00Go0000ok>c/onc/k?o/k>co`000008olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmo
Ool000000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo0000
0_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00co0000ok>c/onc/k?o
0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00009oc<c<`09o`000?m<C4co0000ofIVI_l0
003oOgmoo`000?nIVIWo000000Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo
00?ooooo3?mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmo
OomoOgl02?moOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVI
VOnIVIT02_nIVIT00ol0003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV00CoIVIV00?o0000oda<
C?m<C4`04_m<C4`00ol0003oIVIVofIVIP02ofIVIP05o`000?moOgooOgmoogmoOol000001?nIVIT0
0ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00onc/k<0
1?l0003oVIVIoiVIVOl00003ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<0
1_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01Ol0
003o/k>cok>c/onc/k?o000000Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`00
0002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Co0000oda<C?m<C4co00000_mVIVH01Ol0003o
Ogmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`03?l0003o/k>cok>c/ol0003o
VIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000Wo<c<c00[o0000oda<C?l0003oIVIVo`000?mo
Ogoo0000oiVIVOl0003o/k>c1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool0
0oooool:ofIVIP;o00006?m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo
0_l0000=oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmo
ogmoO`05ogmoO`03o`000?mVIVKoIVIV00CoIVIV00?o0000oda<C?m<C4`04om<C4`00ol0003oIVIV
ofIVIP02ofIVIP05o`000?moOgooOgmoogmoOol000000onIVIT00ol0003o/k>cok>c/`04ok>c/`03
o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00onc/k<01Ol0003oVIVIoiVIVOnIVIWo0000
00;oOgmo00?o0000ofIVI_mVIVH00_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<
C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o0000
2?o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOol0003oIVIV0_l00002oda<
C003o`000?lc<c?o<c<c00Ko<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`03o`000?nI
VIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?mo
Ogoo0000ofIVI_l0003oC4a<o`0000Wo<c<c00[o0000oda<C?l0003oIVIVo`000?moOgoo0000oiVI
VOl0003o/k>c1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool9ofIV
IP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmo
O`03o`000?nIVIWoVIVI00_oVIVI0_l0000Hok>c/`03o`000?nIVIWoVIVI00[oVIVI00?o0000ogmo
OomoOgl01OmoOgl00ol0003oIVIVofIVIP04ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000ofIV
I_mVIVH00omVIVH01?l0003oOgmoogmoOol00004oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000
olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`03ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_mo
Ogl01?l0003oIVIVofIVI_l00004oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4co
C4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`0
1Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Go0000ogmoOol0003oIVIVo`000003oda<C003o`00
0?lc<c?o<c<c00Ko<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`05o`000?nIVIWo0000
ok>c/ol000002Oo<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<
o`0000Wo<c<c00_o0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`000005oooo
o`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`WoIVIV00?o0000oda<C?m<
C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnI
VIT02onIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00[oVIVI00?o0000ogmoOomo
Ogl01OmoOgl00ol0003oIVIVofIVIP05ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000ofIVI_mV
IVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000?oVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0
003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c00?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002
ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<
C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01?l0003o/k>cok>c/ol00008olc<
c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000CoC4a<00?o
0000oc<c<olc<c<01Olc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00?o0000oiVIVOl0
00000_nc/k<00ol0003oc<c<olc<c006olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0
003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<00ol0003oC4a<o`000002ofIVIP;o0000
00GoVIVIo`000?nc/k?o/k>co`000005ooooo`7o00000Oooool1ooooo`009?ooool2o`0000Cooooo
2?mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl0
2?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT0
2_nIVIT00ol0003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV00GoIVIV00?o0000oda<C?m<C4`0
4om<C4`00ol0003oIVIVofIVIP02ofIVIP05o`000?moOgooOgmoogmoOol000001?nIVIT00ol0003o
/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00onc/k<01Ol0003o
VIVIoiVIVOnIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`05
oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIo`00
0?l00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo0000
00;oOgmo00?o0000ofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`06o`000?m<C4coC4a<
o`000?mVIVKo00000_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00[o
0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06
oc<c<`0;o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol000001Oooool2o`00
00;ooooo000Tooooo`03o`000?oooooooooo00?ooooo1omVIVH00ol0003oC4a<oda<C00Foda<C003
o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@;o
00006?nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00CoOgmo00?o0000ofIVI_mV
IVH01_mVIVH00ol0003oC4a<oda<C00Coda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomo
OgooOgmoo`000003oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0
003o/k>cok>c/`03ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01?l0003oIVIVofIVI_l0
0004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01_l0003oIVIVofIV
I_l0003oOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c007o`000?nc/k?o/k>c
ok>c/ol0003oVIVIo`000002ogmoO`03o`000?mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc
<c<02?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo00000_nIVIT01?l0003o/k>cok>c/ol00008
olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c
<olc<c<01_lc<c<02ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o000000Ko
oooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo1_mVIVH00ol0003oC4a<
oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVI
oiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmo
ogmoO`05ogmoO`03o`000?mVIVKoIVIV00GoIVIV00?o0000oda<C?m<C4`04om<C4`00ol0003oIVIV
ofIVIP02ofIVIP05o`000?moOgooOgmoogmoOol000001?nIVIT00ol0003o/k>cok>c/`03ok>c/`03
o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00onc/k<01Ol0003oVIVIoiVIVOnIVIWo0000
00;oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4co
C4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl00ol0003oVIVIo`000004ok>c/`03o`000?o<
c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000?o
C4a<00?o0000oc<c<olc<c<01_lc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00?o0000
oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000
ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<00ol0003oC4a<oda<C002o`00
0007ogmoOol0003oVIVIo`000?nc/k?o0000olc<c006ooooo`7o00000Oooool1ooooo`009?ooool0
0ol0003oooooooooo`03ooooo`GoIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0:
ofIVIP;o00002_moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c0_l0000=
oiVIV@03o`000?moOgooOgmo00GoOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<C00C
oda<C003o`000?mVIVKoIVIV00;oIVIV00?o0000ogmoOomoOgl00_moOgl01Ol0003oVIVIoiVIVOnI
VIWo000000Ko/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`03ok>c/`05o`000?nI
VIWoVIVIoiVIVOl000000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000?oC4a<00?o0000oc<c<olc
<c<01_lc<c<00ol0003oC4a<oda<C002oda<C006o`000?mVIVKoIVIVo`000?moOgoo00000_nIVIT0
1Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo000000;o
Ogmo00?o0000ofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`08o`000?m<C4coC4a<o`00
0?mVIVKo0000ogmoOol00002oiVIV@03o`000?nc/k?o000000Woc<c<00[o0000ok>c/onc/k?o0000
oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0<o`000?m<C4co
0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol0003oc<c<1_ooool1o`00007ooooo0Oooool0
02Cooooo00?o0000ooooooooool00oooool4ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIV
I_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c
/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo00GoOgmo00?o0000ofIV
I_mVIVH01_mVIVH00ol0003oC4a<oda<C00Coda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmo
OomoOgooOgmoo`000004oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`00oo<c<`0
0ol0003o/k>cok>c/`03ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01Ol0003oIVIVofIV
I_mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<00ol0003oC4a<oda<C002oda<C006o`00
0?mVIVKoIVIVo`000?moOgoo00000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Oo0000
ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo00?o0000ofIVI_l000000om<C4`00ol0003o<c<c
oc<c<`06oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVIV@03o`000?nc/k?o
000000Woc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00009
oc<c<`0<o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol0003oc<c<1_ooool1
o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool2ofIVIP;o00006?m<C4`00ol0
003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0
003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl01OmoOgl00ol0
003oIVIVofIVIP06ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH00_mVIVH00ol0
003oOgmoogmoO`02ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001_nc/k<00ol0003oc<c<olc<c003
olc<c003o`000?nc/k?o/k>c00?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`04o`000?mV
IVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<00ol0003oC4a<oda<C002oda<C006o`00
0?mVIVKoIVIVo`000?moOgoo00000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Oo0000
ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo00?o0000ofIVI_l000000om<C4`00ol0003o<c<c
oc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV0_l00002oiVIV@04o`000?nc/k?o/k>co`00
00Soc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o
<c<coc<c<`06oc<c<`05o`000?m<C4co0000ofIVI_l000000_moOgl2o`0000;o/k>c00?o0000olc<
c?ooool01Oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool00omVIVKo
0000oda<C00Hoda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003o
VIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003o
OgmoogmoO`06ogmoO`03o`000?mVIVKoIVIV00GoIVIV00?o0000oda<C?m<C4`04om<C4`00ol0003o
IVIVofIVIP02ofIVIP03o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o
/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00onc/k<01Ol0003o
VIVIoiVIVOnIVIWo000000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000003oda<C003o`000?lc<c?o
<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI
00Co0000ok>c/onc/k?o00002Oo<c<`01ol0003o/k>cok>c/onc/k?o0000oiVIVOl000000_moOgl0
0ol0003oIVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c00So0000oda<C?m<C4co0000ofIV
I_l0003oOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`03?l0003o/k>cok>c/ol0003o
VIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000Wo<c<c00Wo0000oda<C?l0003oIVIVo`000?mo
Ogoo0000oiVIVOl000000_nc/k<00ol0003oc<c<ooooo`05ooooo`7o00000Oooool1ooooo`009?oo
ool00ol0003oooooooooo`03ooooo`03ofIVI_l0003oC4a<01OoC4a<00?o0000ofIVI_mVIVH02omV
IVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00[oVIVI00?o0000ok>c/onc/k<05_nc
/k<00ol0003oVIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH01_mV
IVH00ol0003oC4a<oda<C00Coda<C003o`000?mVIVKoIVIV00;oIVIV00?o0000ogmoOomoOgl00_mo
Ogl01Ol0003oVIVIoiVIVOnIVIWo000000Ko/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>c
ok>c/`03ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01Ol0003oIVIVofIVI_mVIVKo0000
00?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000
ogmoOomoOgoo00000_nIVIT01?l0003o/k>cok>c/ol00009olc<c007o`000?nc/k?o/k>cok>c/ol0
003oVIVIo`000002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01olc<c<02?l0
003oC4a<oda<C?l0003oIVIVo`000?moOgoo00000_nIVIT00ol0003o/k>co`000009olc<c00<o`00
0?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co00002Olc<c<02Ol0003oC4a<
o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<cooooo00Gooooo0Ol00001
ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo00?o0000oda<C?m<C4`05_m<C4`00ol0
003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02_nIVIT00ol0
003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl01_moOgl00ol0
003oIVIVofIVIP06ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH00omVIVH01Ol0
003oOgmoogmoOomoOgoo000000CoVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c004
olc<c003o`000?nc/k?o/k>c00?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`05o`000?mV
IVKoIVIVofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l0
00000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`0
1ol0003o/k>cok>c/onc/k?o0000oiVIVOl000000_moOgl00ol0003oIVIVo`000003oda<C003o`00
0?lc<c?o<c<c00Ko<c<c00So0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000;oVIVI00Co0000
ok>c/onc/k?o00002Oo<c<`02ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co
000000Wo<c<c00?o0000oda<C?l000000_mVIVH2o`000005oiVIVOl0003o/k>cok>c/ol000000_o<
c<`6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03oooooaSoC4a<00?o0000
ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`;o00003?nIVIT00ol0003o/k>cok>c/`0F
ok>c/`03o`000?nIVIWoVIVI00_oVIVI0_l00008ogmoO`03o`000?mVIVKoIVIV00KoIVIV00?o0000
oda<C?m<C4`04om<C4`00ol0003oIVIVofIVIP03ofIVIP05o`000?moOgooOgmoogmoOol000001?nI
VIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00?oc<c<0_l00004ok>c/`05o`000?nI
VIWoVIVIoiVIVOl000000omoOgl01?l0003oIVIVofIVI_l00004oda<C003o`000?lc<c?o<c<c00Go
<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVI
o`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@06o`000?mo
OgooOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`07oc<c<`08o`000?m<C4coC4a<o`00
0?mVIVKo0000ogmoOol00002oiVIV@03o`000?nc/k?o000000Woc<c<00co0000ok>c/onc/k?o0000
oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00009oc<c<`0;o`000?m<C4co0000ofIVI_l0003o
Ogmoo`000?nIVIWo0000ok>c/ol000000oo<c<`6ooooo`7o00000Oooool1ooooo`009?ooool2o`00
00Cooooo5om<C4`00ol0003oIVIVofIVIP0:ofIVIP;o00002omoOgl00ol0003oVIVIoiVIV@0:oiVI
V@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`07ogmo
O`03o`000?mVIVKoIVIV00KoIVIV00?o0000oda<C?m<C4`04om<C4`00ol0003oIVIVofIVIP03ofIV
IP05o`000?moOgooOgmoogmoOol000001?nIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<co
c<c<00?oc<c<00?o0000ok>c/onc/k<00onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Co
0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<
00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00002ok>c/`03o`000?o<c<coc<c<
00Ooc<c<00Co0000ok>c/onc/k?o00000_nIVIT01_l0003oOgmoogmoOol0003oIVIVo`0000;oC4a<
00?o0000oc<c<olc<c<01olc<c<02?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo00000_nIVIT0
0ol0003o/k>co`000009olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`00
0?m<C4co00002Olc<c<02ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o0000
00?oc<c<1Oooool2o`0000;ooooo000Tooooo`03o`000?oooooooooo00?ooooo5Om<C4`2o`0000co
IVIV00?o0000ogmoOomoOgl02_moOgl00ol0003oVIVIoiVIV@0:oiVIV@03o`000?nc/k?o/k>c01Ko
/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`07ogmoO`03o`000?mVIVKoIVIV00Ko
IVIV00?o0000oda<C?m<C4`04om<C4`00ol0003oIVIVofIVIP03ofIVIP03o`000?moOgooOgmo00;o
Ogmo00Go0000oiVIVOnIVIWoVIVIo`000006ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c
/onc/k<00onc/k<00ol0003oVIVIoiVIV@02oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00?o0000
oda<C?m<C4`00_m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000
ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<
00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0
003o<c<coc<c<`07oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl01Ol0003oVIVIo`00
0?nc/k?o000000Woc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<
C4`00ol0003o<c<coc<c<`06oc<c<`03o`000?m<C4coC4a<00;o000000CoOgmoo`000?nIVIWoVIVI
0_l00004olc<c0Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo5?m<
C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo0_l0000<oiVIV@03o`000?nc
/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT2o`0000WoOgmo00?o0000ofIVI_mVIVH01_mV
IVH00ol0003oC4a<oda<C00Coda<C003o`000?mVIVKoIVIV00?oIVIV00?o0000ogmoOomoOgl00_mo
Ogl01Ol0003oVIVIoiVIVOnIVIWo000000Oo/k>c00?o0000olc<c?o<c<`00_o<c<`00ol0003o/k>c
ok>c/`04ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01Ol0003oIVIVofIVI_mVIVKo0000
00CoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIV
o`0000;oOgmo00Co0000oiVIVOnIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc
/k?o/k>cok>c/ol000000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000Wo
<c<c00So0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000;oVIVI00?o0000ok>c/ol000002Oo<
c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o
<c<c00Ko<c<c00_o0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`000004olc<
c0Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo4om<C4`00ol0003o
IVIVofIVIP0<ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o
/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl01omoOgl00ol0003o
IVIVofIVIP06ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003o
OgmoogmoO`02ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001onc/k<00ol0003oc<c<olc<c002olc<
c003o`000?nc/k?o/k>c00Co/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`05o`000?mVIVKo
IVIVofIVI_l000001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co
0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ko
c<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<
C?m<C4co00002Olc<c<02?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo00000_nIVIT00ol0003o
/k>co`000009olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<
00?o0000oc<c<olc<c<01Olc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0
003o/k>co`0000Coc<c<1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00ooo
oolBoda<C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVI
V@0<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmo
O`08ogmoO`03o`000?mVIVKoIVIV00KoIVIV00?o0000oda<C?m<C4`04om<C4`00ol0003oIVIVofIV
IP04ofIVIP05o`000?moOgooOgmoogmoOol000001?nIVIT00ol0003o/k>cok>c/`04ok>c/`03o`00
0?o<c<coc<c<00;oc<c<00?o0000ok>c/onc/k<01?nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?o
Ogmo00Go0000ofIVI_mVIVKoIVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<
C?m<C4coC4a<o`000003ofIVIP03o`000?moOgoo000000;oVIVI00Go0000ok>c/onc/k?o/k>co`00
0008olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;o
C4a<00?o0000oc<c<olc<c<01olc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo0000
00;oVIVI00?o0000ok>c/ol000002Oo<c<`00ol0003o/k>co`000002oiVIV@07o`000?moOgoo0000
ofIVI_l0003oC4a<o`000008oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVI
o`000?nc/k?o00001?o<c<`6ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03
oooooa;oC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWo
VIVI00coVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgoo
Ogmo00SoOgmo00?o0000ofIVI_mVIVH01_mVIVH00ol0003oC4a<oda<C00Doda<C003o`000?mVIVKo
IVIV00?oIVIV00?o0000ogmoOomoOgl00_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Ko/k>c0_l0
0004olc<c003o`000?nc/k?o/k>c00Co/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`05o`00
0?mVIVKoIVIVofIVI_l000001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;o
C4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00002ok>c/`03o`000?o<c<co
c<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@03o`000?moOgoo000000;oIVIV00Co
0000oda<C?m<C4co00002Olc<c<02?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo00000_nIVIT0
1?l0003o/k>cok>c/ol00008olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIV
o`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<o`000?mVIVKo000000;oOgmo0_l0
0002ok>c/`03o`000?o<c<coc<c<00;oc<c<1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000
ooooooooool00ooooolAoda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl2
o`0000coVIVI0_l0000Hok>c/`03o`000?nIVIWoVIVI00[oVIVI0_l0000:ogmoO`03o`000?mVIVKo
IVIV00KoIVIV00?o0000oda<C?m<C4`05?m<C4`00ol0003oIVIVofIVIP03ofIVIP03o`000?moOgoo
Ogmo00;oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<co
c<c<00?oc<c<00?o0000ok>c/onc/k<00onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Go
0000ofIVI_mVIVKoIVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4co
C4a<o`000003ofIVIP03o`000?moOgoo000000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<
c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4co
C4a<o`0000So<c<c00Wo0000oda<C?m<C4coC4a<o`000?mVIVKo0000ogmoOol000000_nIVIT01?l0
003o/k>cok>c/ol00008olc<c003o`000?nc/k?o000000;oVIVI00Oo0000ogmoOol0003oIVIVo`00
0?m<C4co000000Wo<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl000000_nc/k<0
0ol0003oc<c<olc<c002olc<c0Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo
00?ooooo4?m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVI
VOnIVIT03?nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00[oVIVI00?o0000ogmo
OomoOgl02OmoOgl00ol0003oIVIVofIVIP06ofIVIP03o`000?m<C4coC4a<01GoC4a<00?o0000ofIV
I_mVIVH00_mVIVH00ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c
/onc/k<01?nc/k<00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c00?o/k>c00Go0000oiVI
VOnIVIWoVIVIo`000003ogmoO`05o`000?mVIVKoIVIVofIVI_l000000om<C4`00ol0003o<c<coc<c
<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@05
o`000?nc/k?o/k>cok>c/ol000002?o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000
ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`0;o`000?m<C4coC4a<oda<C?l0003o
IVIVo`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c003o`000?nc/k?o
000000;oVIVI00Oo0000ogmoOol0003oIVIVo`000?m<C4co000000Wo<c<c00Wo0000oda<C?l0003o
IVIVo`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c002olc<c0Kooooo0Ol00001
ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo3om<C4`00ol0003oIVIVofIVIP0;ofIV
IP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`0Fok>c
/`03o`000?nIVIWoVIVI00[oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP07ofIV
IP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH00_mVIVH00ol0003oOgmoogmoO`03ogmo
O`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c003olc<
c003o`000?nc/k?o/k>c00?o/k>c00?o0000oiVIVOnIVIT00_nIVIT01?l0003oOgmoogmoOol00003
ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<00ol0003oC4a<oda<C002oda<C004o`000?mV
IVKoIVIVo`0000;oOgmo00?o0000oiVIVOl000000onc/k<00ol0003oc<c<olc<c007olc<c004o`00
0?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00008oc<c
<`09o`000?m<C4coC4a<oda<C?l0003oIVIVo`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o
00002?o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000Wo
<c<c00?o0000oda<C?l000000_mVIVH2o`000005oiVIVOl0003o/k>cok>c/ol000001Oo<c<`6oooo
o`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`koC4a<00?o0000ofIVI_mV
IVH02omVIVH00ol0003oOgmoogmoO`08ogmoO`;o00003OnIVIT00ol0003o/k>cok>c/`0Fok>c/`03
o`000?nIVIWoVIVI00[oVIVI0_l0000:ogmoO`03o`000?mVIVKoIVIV00OoIVIV00?o0000oda<C?m<
C4`05?m<C4`00ol0003oIVIVofIVIP03ofIVIP03o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnI
VIT00_nIVIT00ol0003o/k>cok>c/`05ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o0000ok>c/onc
/k<01?nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004
oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?mo
OgooOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c005o`000?nc/k?o/k>cok>c
/ol000000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Co0000
oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVIV@03o`000?nc/k?o000000Woc<c<00co
0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00009oc<c<`09o`000?m<
C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`00oo<c<`6oooo
o`7o00000Oooool1ooooo`009?ooool2o`0000Cooooo3Om<C4`00ol0003oIVIVofIVIP0;ofIVIP03
o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`0Fok>c/`03
o`000?nIVIWoVIVI00[oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP08ofIVIP03
o`000?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`02ogmoO`03
o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01Onc/k<01Ol0003oc<c<olc<c?o<c<co0000
00Oo/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`05o`000?mVIVKoIVIVofIVI_l000001?m<
C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmo
ogmoOol00002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01Ol0003o/k>cok>c/onc/k?o
000000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`04o`000?m<
C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT00ol0003o/k>co`000009olc<c00<o`00
0?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co00002Olc<c<02Ol0003oC4a<
o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00?oc<c<1Oooool2
o`0000;ooooo000Tooooo`03o`000?oooooooooo00?ooooo3?m<C4`00ol0003oIVIVofIVIP0;ofIV
IP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`0Fok>c
/`03o`000?nIVIWoVIVI00[oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP08ofIV
IP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`02ogmo
O`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c002olc<
c003o`000?nc/k?o/k>c00Co/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`05o`000?mVIVKo
IVIVofIVI_l000001?m<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l00000
0_mVIVH01?l0003oOgmoogmoOol00002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01Ol0
003o/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l0
0008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT00ol0003o/k>c
o`000009olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o
0000oc<c<olc<c<01_lc<c<01ol0003oC4a<o`000?mVIVKo0000ogmoOol000000_nIVIT00ol0003o
/k>co`000006olc<c0Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo
2om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo0_l0000=oiVIV@03o`00
0?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02_nIVIT2o`0000[oOgmo00?o0000ofIVI_mVIVH0
2?mVIVH00ol0003oC4a<oda<C00Doda<C003o`000?mVIVKoIVIV00?oIVIV00?o0000ogmoOomoOgl0
0_moOgl2o`0000?oVIVI00?o0000ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c002olc<c003o`00
0?nc/k?o/k>c00Co/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`05o`000?mVIVKoIVIVofIV
I_l000001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIV
I_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Oo
0000ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo00000_m<C4`00ol0
003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Go0000ogmoOol0003oVIVIo`00
0002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00?o0000ok>c/ol000000_nIVIT01Ol0003oOgmoo`00
0?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02ol0003oC4a<o`000?mVIVKo0000ogmo
Ool0003oVIVIo`000?nc/k?o000000Ooc<c<1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000
ooooooooool00oooool:oda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl0
0ol0003oVIVIoiVIV@0;oiVIV@;o00006?nc/k<00ol0003oVIVIoiVIV@0:oiVIV@03o`000?moOgoo
Ogmo00WoOgmo00?o0000ofIVI_mVIVH02OmVIVH00ol0003oC4a<oda<C00Doda<C003o`000?mVIVKo
IVIV00?oIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@02oiVIV@03o`000?nc/k?o
/k>c00Go/k>c00?o0000olc<c?o<c<`00_o<c<`00ol0003o/k>cok>c/`04ok>c/`05o`000?nIVIWo
VIVIoiVIVOl000000omoOgl01Ol0003oIVIVofIVI_mVIVKo000000?oC4a<00?o0000oc<c<olc<c<0
1_lc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co0000oiVIVOnI
VIWo00000_nc/k<00ol0003oc<c<olc<c007olc<c007o`000?nc/k?o/k>cok>c/ol0003oVIVIo`00
0002ogmoO`03o`000?mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<
C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c003
o`000?nc/k?o000000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c
00Go<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00007olc<
c0Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo2Om<C4`00ol0003o
IVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o
/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00[oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003o
IVIVofIVIP09ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003o
OgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01_nc/k<01Ol0003o
c<c<olc<c?o<c<co000000Ko/k>c00?o0000oiVIVOnIVIT00_nIVIT01?l0003oOgmoogmoOol00003
ofIVIP03o`000?m<C4coC4a<00;oC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002
oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<
olc<c006olc<c007o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000002ogmoO`04o`000?mVIVKoIVIV
o`0000;oC4a<00?o0000oc<c<olc<c<01olc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo
0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0
003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4co0000ofIV
I_l000000_moOgl2o`0000;o/k>c00?o0000olc<c?o<c<`01Oo<c<`6ooooo`7o00000Oooool1oooo
o`009?ooool00ol0003oooooooooo`03ooooo`SoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003o
OgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003o
VIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02OmVIVH00ol0003o
C4a<oda<C00Doda<C003o`000?mVIVKoIVIV00CoIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003o
VIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c00Go/k>c00Go0000olc<c?o<c<coc<c<o`000007ok>c
/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01?l0003oIVIVofIVI_l00004oda<C003o`000?lc
<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000003ofIVIP04o`000?moOgooOgmoo`0000;o
VIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Ko0000
ogmoOomoOgoo0000ofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co
00000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`2o`00
0009ok>c/ol0003oVIVIoiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<0
1_lc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<co
c<c<00Goc<c<1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool7oda<
C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVI
V@;o00006?nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIV
I_mVIVH02?mVIVH00ol0003oC4a<oda<C00Eoda<C003o`000?mVIVKoIVIV00CoIVIV00Go0000ogmo
OomoOgooOgmoo`000005oiVIV@03o`000?nc/k?o/k>c00Go/k>c00Go0000olc<c?o<c<coc<c<o`00
0007ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01?l0003oIVIVofIVI_l00004oda<C003
o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000003ofIVIP04o`000?moOgooOgmo
o`0000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@06o`00
0?moOgooOgmoo`000?mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<
o`0000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co
0000ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc
<c<01_lc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<
c<coc<c<00Goc<c<1_ooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool6
oda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;
oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08
ogmoO`;o00002_mVIVH00ol0003oC4a<oda<C00Eoda<C003o`000?mVIVKoIVIV00CoIVIV00Go0000
ogmoOomoOgooOgmoo`000005oiVIV@03o`000?nc/k?o/k>c00Go/k>c00Go0000olc<c?o<c<coc<c<
o`000007ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01Ol0003oIVIVofIVI_mVIVKo0000
00?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000?oIVIV00Co0000
ogmoOomoOgoo00000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Go0000ok>c/onc/k?o
/k>co`000002oiVIV@05o`000?moOgoo0000ofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c
<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol0
0007olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003
o`000?lc<c?o<c<c00Ko<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl000000_nc
/k<00ol0003oc<c<olc<c006olc<c0Kooooo0Ol00001ooooo`7ooooo000Iooooo`05olc<c?lQ8B7o
0000ob4Q8Oo<c<`01_ooool00ol0003oooooooooo`03ooooo`GoC4a<00?o0000ofIVI_mVIVH02_mV
IVH2o`0000[oOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`;o00003OnI
VIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00WoIVIV00?o0000oda<C?m<C4`05Om<
C4`00ol0003oIVIVofIVIP04ofIVIP03o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00_nI
VIT00ol0003o/k>cok>c/`06ok>c/`05o`000?o<c<coc<c<olc<c?l000001_nc/k<01Ol0003oVIVI
oiVIVOnIVIWo000000?oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c
00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWo
VIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI
00Ko0000ogmoOomoOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Co0000oda<
C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<
c<`01?l0003o/k>cok>c/ol00002oiVIV@07o`000?moOgoo0000ofIVI_l0003oC4a<o`000009oc<c
<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`0
1_o<c<`00ol0003oooooooooo`03ooooo`7o00000Oooool1ooooo`006Oooool01OlQ8B7oV9RHoooo
oonHV9So8B4Q00Kooooo00?o0000ooooooooool00oooool4oda<C003o`000?mVIVKoIVIV00_oIVIV
00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c
00?o0000oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00[oIVIV
00?o0000oda<C?m<C4`05Om<C4`00ol0003oIVIVofIVIP03ofIVIP03o`000?moOgooOgmo00?oOgmo
00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`06ok>c/`05o`000?o<c<coc<c<olc<c?l0
00001_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004
oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l0
0002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>c
ok>c/onc/k?o000000;oVIVI00Ko0000ogmoOomoOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o
<c<c00Oo<c<c00Co0000oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c
00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@07o`000?moOgoo0000ofIV
I_l0003oC4a<o`000009oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o
/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003oooooooooo`03ooooo`7o00000Oooool1ooooo`00
6Oooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool00oooool3oda<C003
o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03
o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`08ogmoO`03
o`000?mVIVKoIVIV00[oIVIV00?o0000oda<C?m<C4`05Om<C4`00ol0003oIVIVofIVIP04ofIVIP03
o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`06ok>c/`?o
000000?oc<c<o`000?nc/k<01Onc/k<00ol0003oVIVIoiVIV@02oiVIV@04o`000?moOgooOgmoo`00
00?oIVIV00?o0000oda<C?m<C4`00_m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<
00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<
c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@06o`000?moOgooOgmoo`000?mV
IVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Go0000
ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00?o0000ok>c/ol000000_nI
VIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01ol0003oC4a<
o`000?mVIVKo0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00007olc<c003o`000?oooooo
oooo00Cooooo0Ol00001ooooo`7ooooo000Iooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool3
o`0000?ooooo0_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000
oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000
ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<01GoC4a<00?o0000
ofIVI_mVIVH01?mVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00;oVIVI0_l00007
ok>c/`05o`000?o<c<coc<c<olc<c?l000001onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo
00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<
C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000
olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmoOol000000_mV
IVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Go0000oda<C?m<C4co0000ofIVIP02o`000004
ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01oo<c<`00ol0003o/k>co`000002oiVI
V@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`08o`000?m<C4co
0000ofIVI_l0003oOgmoo`000?nIVIT2o`000003ok>c/ol0003oc<c<00Ooc<c<00?o0000oooooooo
ool00_ooool3o`0000;ooooo000Iooooo`05olc<c?l0003o0000o`000?o<c<`01_ooool00ol0003o
ooooooooo`03ooooo`03oda<C?l0003oIVIV00coIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003o
VIVIoiVIV@0:oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003o
OgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05Om<C4`00ol0003o
IVIVofIVIP04ofIVIP05o`000?moOgooOgmoogmoOol000001OnIVIT00ol0003o/k>cok>c/`06ok>c
/`05o`000?o<c<coc<c<olc<c?l000001onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Go
0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`0
0_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<
c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmoOol000000_mVIVH0
1Ol0003oC4a<oda<C?m<C4co000000Oo<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo000000;o
Ogmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c003o`000?nc/k?o000000;o
VIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Wo0000oda<
C?l0003oIVIVo`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c003o`00
0?oooooooooo00Cooooo0Ol00001ooooo`7ooooo000Iooooo`05oa0@4?nj^[[ooooookZj^_l@4100
1_ooool00ol0003oooooooooo`03ooooo`03o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl0
2OmoOgl00ol0003oVIVIoiVIV@0:oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT0
3?nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`0
5Om<C4`00ol0003oIVIVofIVIP04ofIVIP03o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT0
0_nIVIT00ol0003o/k>cok>c/`06ok>c/`05o`000?o<c<coc<c<olc<c?l000001onc/k<01Ol0003o
VIVIoiVIVOnIVIWo000000?oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o
<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Co
0000oiVIVOnIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol0
00000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Co0000
oda<C?m<C4coC4a<0_l00002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01oo<
c<`00ol0003o/k>co`000002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<c
oc<c<`06oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000
olc<c?o<c<`01_o<c<`00ol0003o/k>cooooo`05ooooo`7o00000Oooool1ooooo`006Oooool01Ol0
003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool00oooool=ofIVIP03o`000?moOgoo
Ogmo00SoOgmo0_l0000<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT2
o`0000[oOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Eoda<C003o`000?mVIVKo
IVIV00CoIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o
/k>c00Ko/k>c0_l000000oo<c<co0000ok>c/`06ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omo
Ogl01Ol0003oIVIVofIVI_mVIVKo000000GoC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<
oda<C002oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00003ok>c
/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@03o`000?moOgoo
000000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;o
Ogmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`00
00;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00_o0000
oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`000009olc<c003o`000?nc/k?ooooo
00Gooooo0Ol00001ooooo`7ooooo000Iooooo`05ojVYZOl@413o0000oa0@4?nYZJT01_ooool00ol0
003oooooooooo`03ooooo`coIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0:oiVI
V@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`08ogmo
O`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP04ofIV
IP03o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`08ok>c
/`03o`000?nc/k?o/k>c00Ko/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`05o`000?mVIVKo
IVIVofIVI_l000001Om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00;oC4a<00Go
0000ofIVI_mVIVKoIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<
c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0
003oC4a<oda<C?l00009oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl00ol0003oVIVI
o`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT01Ol0003o
Ogmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02ol0003oC4a<o`000?mVIVKo
0000ogmoOol0003oVIVIo`000?nc/k?o000000Woc<c<00?o0000ok>c/ol000001Oooool1o`00007o
oooo0Oooool002Cooooo00?o0000ooooooooool00oooool;ofIVIP03o`000?moOgooOgmo00WoOgmo
00?o0000oiVIVOnIVIT02_nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00coVIVI
00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<
00?o0000ofIVI_mVIVH01?mVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00?oVIVI
00?o0000ok>c/onc/k<04Onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Go0000ofIVI_mV
IVKoIVIVo`000005oda<C003o`000?lc<c?o<c<c00Go<c<c00Go0000oda<C?m<C4coC4a<o`000003
ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c003o`00
0?nc/k?o/k>c00;o/k>c00Go0000oiVIVOl0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`00
00Wo<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000;o/k>c
00?o0000olc<c?o<c<`01_o<c<`00ol0003o/k>co`000002oiVIV@03o`000?moOgoo000000;oIVIV
00?o0000oda<C?l000002?lc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002
ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00001Oooool1o`00007ooooo0Ooo
ool002Cooooo00?o0000ooooooooool00oooool:ofIVIP03o`000?moOgooOgmo00SoOgmo0_l0000<
oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT2o`0000[oOgmo00?o0000
ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Eoda<C0;o00001_mVIVH00ol0003oOgmoogmoO`02
ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<04_nc/k<01Ol0003oVIVIoiVIVOnI
VIWo000000?oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go<c<c
00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`05o`000?nIVIWoVIVIoiVI
VOl000000_nc/k<00ol0003oc<c<olc<c007olc<c007o`000?nc/k?o/k>cok>c/ol0003oVIVIo`00
0002ogmoO`04o`000?mVIVKoIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01olc<c<01_l0003oC4a<
oda<C?l0003oIVIVo`0000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<
c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl01Ol0003oIVIVo`000?m<C4co000000Wo<c<c
00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006
olc<c003o`000?nc/k?o000000Kooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo
00?ooooo2OmVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c
/onc/k<05onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIV
I_mVIVH03?mVIVH00ol0003oC4a<oda<C00Eoda<C003o`000?mVIVKoIVIV00GoIVIV00?o0000ogmo
OomoOgl00_moOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c01;o/k>c00Go0000oiVI
VOnIVIWoVIVIo`000003ogmoO`05o`000?mVIVKoIVIVofIVI_l000001?m<C4`00ol0003o<c<coc<c
<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01Ol0003oVIVI
oiVIVOnIVIWo000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`01ol0003o/k>cok>c/onc/k?o0000
oiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Ko
0000oda<C?m<C4co0000ofIVI_l00002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<
c<`01_o<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00Go0000ofIVI_l0003oC4a<o`00
0009oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<
c?o<c<`01_o<c<`00ol0003o/k>co`000006ooooo`7o00000Oooool1ooooo`009?ooool00ol0003o
ooooooooo`03ooooo`SoIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0<oiVIV@03
o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`03
o`000?mVIVKoIVIV00coIVIV00?o0000oda<C?m<C4`05Om<C4`00ol0003oIVIVofIVIP05ofIVIP03
o`000?moOgooOgmo00?oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`0Bok>c/`05
o`000?nIVIWoVIVIoiVIVOl000001?moOgl01?l0003oIVIVofIVI_l00005oda<C003o`000?lc<c?o
<c<c00Go<c<c00Go0000oda<C?m<C4coC4a<o`000003ofIVIP04o`000?moOgooOgmoo`0000;oVIVI
00Go0000ok>c/onc/k?o/k>co`000008olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01_l0
003oOgmoogmoOol0003oIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01ol0003oC4a<oda<
C?m<C4co0000ofIVI_l000000_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ko
c<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`05o`000?mVIVKo0000oda<C?l000002Olc
<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<
00Koc<c<00?o0000ok>c/ol000001_ooool1o`00007ooooo0Oooool002Cooooo00?o0000oooooooo
ool00oooool7ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o
/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003o
IVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH01OmVIVH00ol0003o
OgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<04Onc/k<00ol0003o
VIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol000000omVIVH00ol0003oC4a<oda<C002oda<
C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo
000000;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c007o`000?nc
/k?o/k>cok>c/ol0003oVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000;oC4a<00?o0000oc<c
<olc<c<01olc<c<01?l0003oC4a<oda<C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc
/k<00ol0003oc<c<olc<c007olc<c005o`000?nc/k?o0000oiVIVOl000000_moOgl00ol0003oIVIV
o`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000
oiVIVOl000000onc/k<00ol0003oc<c<olc<c005olc<c004o`000?nc/k?o0000oiVIV@Kooooo0Ol0
0001ooooo`7ooooo000Tooooo`;o00001?ooool6ofIVIP03o`000?moOgooOgmo00SoOgmo0_l0000<
oiVIV@;o00006?nc/k<00ol0003oVIVIoiVIV@0:oiVIV@;o00002_moOgl2o`0000coIVIV0_l0000H
oda<C003o`000?mVIVKoIVIV00GoIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@03
oiVIV@03o`000?nc/k?o/k>c01;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`05o`000?mV
IVKoIVIVofIVI_l000001Om<C4`00ol0003o<c<coc<c<`04oc<c<`;o00001?m<C4`01?l0003oIVIV
ofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`01Ol0
003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01?l0003oC4a<oda<
C?l00008oc<c<`03o`000?m<C4coC4a<00;o000000OoIVIVo`000?moOgooOgmoo`000?nIVIWo0000
00;o/k>c00?o0000olc<c?o<c<`01oo<c<`01Ol0003o/k>co`000?nIVIWo000000;oOgmo00?o0000
ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmo
o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>co`000?nIVIT5oooo
o`;o00000_ooool002Cooooo00?o0000ooooooooool00oooool5ofIVIP03o`000?moOgooOgmo00So
Ogmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00[o
VIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01Oo
C4a<00?o0000ofIVI_mVIVH01OmVIVH00ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00;o
VIVI00?o0000ok>c/onc/k<04onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Go0000ofIV
I_mVIVKoIVIVo`000005oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00om<C4`0
1?l0003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`0
1_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01?l0
003oC4a<oda<C?l00008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Ko0000ogmoOomoOgoo0000
oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Go0000ok>c/ol0003oVIVIo`000002ogmo
O`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02Ol0003oC4a<o`000?mVIVKo
0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/ol0003o
VIVIo`000005ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`CoIVIV
00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c
00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV
00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP05ofIVIP03o`000?moOgooOgmo00?oOgmo
00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0Bok>c/`05o`000?nIVIWoVIVIoiVIVOl0
00000omoOgl01Ol0003oIVIVofIVI_mVIVKo000000GoC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0
003oC4a<oda<C003oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo00001?nc
/k<00ol0003oc<c<olc<c005olc<c005o`000?nc/k?o/k>cok>c/ol000000onIVIT00ol0003oOgmo
o`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo
000000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c0;o000000Co/k>c
o`000?nIVIWo00000_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Oo
0000oda<C?l0003oIVIVo`000?moOgoo000000;oVIVI00?o0000ok>c/ol000002Oo<c<`2o`0000;o
VIVI00?o0000ooooooooool00oooool1o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool0
0oooool3ofIVIP03o`000?moOgooOgmo00SoOgmo0_l0000=oiVIV@03o`000?nc/k?o/k>c01Ko/k>c
00?o0000oiVIVOnIVIT02_nIVIT2o`0000[oOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<
oda<C00Goda<C003o`000?mVIVKoIVIV00KoIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVI
oiVIV@03oiVIV@03o`000?nc/k?o/k>c01;o/k>c00?o0000oiVIVOnIVIT00_nIVIT00ol0003oOgmo
ogmoO`02o`0000?oIVIV00?o0000oda<C?m<C4`00_m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`00
0?m<C4coC4a<00;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`00
00?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000
ogmoOomoOgoo00000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`09o`000?m<C4coC4a<oda<C?l0
003oIVIVo`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01_l0003o/k>cok>c
/ol0003oVIVIo`0000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`07
o`000?m<C4co0000ofIVI_l0003oOgmoo`000002oiVIV@03o`000?nc/k?o000000Woc<c<0_l00000
0onIVIWo0000ooooo`05ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03oooo
o`;oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c
01Ko/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV
00_oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP06ofIVIP03o`000?moOgooOgmo
00?oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0Bok>c/`03o`000?nIVIWoVIVI
00;oVIVI00Co0000ogmoOomoOgoo00001?mVIVH00ol0003oC4a<oda<C002oda<C003o`000?lc<c?o
<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Co
0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol0
00000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Wo0000
oda<C?m<C4coC4a<o`000?mVIVKo0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00008olc<
c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc
<c?o<c<c00Ko<c<c00Oo0000oda<C?l0003oIVIVo`000?moOgoo000000;oVIVI00?o0000ok>c/ol0
00002Oo<c<`2o`000003oiVIVOl0003ooooo00Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`00
0?oooooooooo00?ooooo00?oIVIVo`000?moOgl02OmoOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`00
0?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`00
0?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`06?m<C4`00ol0003oIVIVofIVIP05ofIVIP03o`00
0?moOgooOgmo00?oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0Bok>c/`03o`00
0?nIVIWoVIVI00;oVIVI00Co0000ogmoOomoOgoo00001?mVIVH00ol0003oC4a<oda<C003oda<C003
o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo0000
00;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o
/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000So
<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00?o0000oiVIVOl000000_nc/k<0
0ol0003oc<c<olc<c006olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl01_l0003oIVIV
ofIVI_l0003oC4a<o`0000So<c<c00Oo0000oda<C?l0003oIVIVo`000?moOgoo000000;oVIVI00?o
0000ok>c/ol000002Oo<c<`01Ol0003o/k>co`000?l0003oOgmo00Kooooo0Ol00001ooooo`7ooooo
000Tooooo`03o`000?oooooooooo00?ooooo00?o0000ogmoOomoOgl02?moOgl2o`0000goVIVI00?o
0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0:oiVIV@;o00002_moOgl00ol0003oIVIVofIV
IP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<0_l00007ofIVIP03o`000?moOgooOgmo00CoOgmo00?o
0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0Bok>c/`05o`000?nIVIWoVIVIoiVIVOl00000
0omoOgl01Ol0003oIVIVofIVI_mVIVKo000000GoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003o
C4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000?oOgmo00Co0000oiVIVOnIVIWo00000onc/k<0
0ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01_l0003oOgmoogmo
Ool0003oIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIV
IP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01ol0003o/k>cok>c/ol0
003oVIVIo`000?moOgl00_l000001?mVIVKo0000oda<C?l00009oc<c<`09o`000?m<C4co0000ofIV
I_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003o/k>cok>c
/`02o`000003ogmoOooooooooooo00Cooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooo
oooo00?ooooo2_moOgl00ol0003oVIVIoiVIV@0;oiVIV@;o00006?nc/k<00ol0003oVIVIoiVIV@0:
oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00G
oda<C003o`000?mVIVKoIVIV00OoIVIV00?o0000ogmoOomoOgl00omoOgl00ol0003oVIVIoiVIV@03
oiVIV@03o`000?nc/k?o/k>c01?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`05o`000?mV
IVKoIVIVofIVI_l000001Om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<
00Co0000ofIVI_mVIVKo00000omoOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<
00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@06o`000?moOgooOgmoo`000?mVIVKo0000
0om<C4`00ol0003o<c<coc<c<`06oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl01?l0
003oVIVIoiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00So0000ok>c/onc/k?o0000oiVI
VOl0003oOgmoo`0000;oIVIV00?o0000oda<C?l000002Olc<c<02Ol0003oC4a<o`000?mVIVKo0000
ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o0000ok>c/onc/k<00_l0
00000omoOgoo0000ooooo`04ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03
ooooo`WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWo
VIVI00[oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4co
C4a<01SoC4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0003oOgmoogmoO`04ogmoO`03o`000?nIVIWo
VIVI00?oVIVI00?o0000ok>c/onc/k<04_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Go
0000ofIVI_mVIVKoIVIVo`000005oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`0
0_m<C4`01?l0003oIVIVofIVI_l00003ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<
c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mV
IVH01?l0003oC4a<oda<C?l00008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol0
00000_nIVIT01?l0003o/k>cok>c/ol00008olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmo
Ool00002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00?o0000oda<C?l000000_mVIVH2o`0000;o
VIVI00?o0000ok>c/ol000002Oo<c<`01ol0003o/k>co`000?nIVIWo0000ogmoOol000001Oooool1
o`00007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool8ogmoO`03o`000?nIVIWoVIVI
00_oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo
00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Hoda<C003o`000?mVIVKoIVIV
00KoIVIV00?o0000ogmoOomoOgl01?moOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c
01;o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000?oIVIV00?o0000
oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Co0000
ofIVI_mVIVKo00000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000?o/k>c00?o0000olc<c?o<c<`0
1_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmoOol000000_mVIVH01Ol0003o
C4a<oda<C?m<C4co000000So<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002
oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`00
00;oIVIV00Co0000oda<C?m<C4co00002?lc<c<01ol0003oC4a<o`000?mVIVKo0000ogmoOol00000
0_nIVIT00ol0003o/k>co`000008olc<c005o`000?nc/k?o/k>co`000?nIVIT00_l00006ooooo`7o
00000Oooool1ooooo`009?ooool2o`0000Cooooo1omoOgl00ol0003oVIVIoiVIV@0;oiVIV@;o0000
6?nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH0
2_mVIVH00ol0003oC4a<oda<C00Hoda<C003o`000?mVIVKoIVIV00OoIVIV00?o0000ogmoOomoOgl0
1?moOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c01;o/k>c00?o0000oiVIVOnIVIT0
0_nIVIT01?l0003oOgmoogmoOol00004ofIVIP03o`000?m<C4coC4a<00?oC4a<00?o0000oc<c<olc
<c<01?lc<c<00ol0003oC4a<oda<C003oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Go0000oiVI
VOnIVIWoVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nI
VIT01?l0003oOgmoogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01?l0003o
C4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`0
2?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo00000_mVIVH01?l0003oC4a<oda<C?l00008oc<c
<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`0
1_o<c<`01Ol0003o/k>cok>c/ol0003oVIVI00;o00001Oooool2o`0000;ooooo000Tooooo`03o`00
0?oooooooooo00?ooooo1_moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c
00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`08ogmoO`;o00003?mVIVH00ol0003oC4a<
oda<C00Hoda<C003o`000?mVIVKoIVIV00OoIVIV00?o0000ogmoOomoOgl01?moOgl00ol0003oVIVI
oiVIV@03oiVIV@03o`000?nc/k?o/k>c01;o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmo
ogmoOomoOgoo000000?oIVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`04oc<c<`03
o`000?m<C4coC4a<00?oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01Ol0003oVIVIoiVIVOnIVIWo
000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o
0000ogmoOol000000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Co0000oda<C?m<C4co
00000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00So0000ok>c
/onc/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<00ol0003o
C4a<oda<C002o`000007ogmoOol0003oVIVIoiVIVOl0003o/k>co`000009olc<c004o`000?nc/k?o
0000oiVIV@;o000000?oIVIVooooooooool01?ooool1o`00007ooooo0Oooool002Cooooo00?o0000
ooooooooool00oooool5ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<2
o`0000goVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4co
C4a<01SoC4a<00?o0000ofIVI_mVIVH01omVIVH00ol0003oOgmoogmoO`03ogmoO`;o00001OnIVIT0
0ol0003o/k>cok>c/`0Bok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`00
0003ofIVIP03o`000?m<C4coC4a<00?oC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<
C002oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03
o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmo
o`0000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`00
0?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`02?l0003o/k>cok>c/ol0003oVIVI
o`000?moOgoo00000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`07o`000?m<C4co0000ofIVI_l0
003oOgmoo`000002oiVIV@03o`000?nc/k?o000000Woc<c<00Co0000ok>c/ol0003oVIVI0_l00000
0omVIVKoooooooooo`04ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03oooo
o`CoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI
00coVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<
01SoC4a<00?o0000ofIVI_mVIVH01omVIVH00ol0003oOgmoogmoO`04ogmoO`03o`000?nIVIWoVIVI
00CoVIVI00?o0000ok>c/onc/k<04_nc/k<00ol0003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmo
ogmoOol000000omVIVH00ol0003oC4a<oda<C003oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000
oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`05o`000?nIVIWoVIVIoiVIVOl00000
0onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003o
OgmoogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000Wo<c<c00Co0000oda<C?m<C4co00000_mV
IVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00[o0000ok>c/onc/k?o
0000oiVIVOl0003oOgmoo`000?mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`07o`000?m<
C4co0000ofIVI_l0003oOgmoo`000002oiVIV@03o`000?nc/k?o000000Woc<c<00Co0000ok>c/ol0
003oVIVI0_l000000omVIVKoooooooooo`04ooooo`7o00000Oooool1ooooo`009?ooool00ol0003o
ooooooooo`03ooooo`?oOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03
o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03
o`000?m<C4coC4a<01OoC4a<0_l00009ofIVIP03o`000?moOgooOgmo00CoOgmo00?o0000oiVIVOnI
VIT01?nIVIT00ol0003o/k>cok>c/`0Bok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomo
OgooOgmoo`000003ofIVIP03o`000?m<C4coC4a<00?oC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0
003oC4a<oda<C002oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01Ol0003oVIVIoiVIVOnI
VIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI
00Co0000ogmoOomoOgoo00000_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`04o`000?m<C4coC4a<
o`0000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00008olc<c008o`000?nc
/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Go0000
oda<C?l0003oIVIVo`000002ogmoO`05o`000?nIVIWo0000ok>c/ol000002Oo<c<`02Ol0003o/k>c
o`000?nIVIWo0000ogmoOol0003oIVIVo`000005ooooo`7o00000Oooool1ooooo`009?ooool00ol0
003oooooooooo`03ooooo`;oOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c
/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIV
IP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02?mVIVH2o`0000GoOgmo00?o0000oiVI
VOnIVIT01?nIVIT00ol0003o/k>cok>c/`0Cok>c/`05o`000?nIVIWoVIVIoiVIVOl000001?moOgl0
1Ol0003oIVIVofIVI_mVIVKo000000GoC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<
C003oda<C004o`000?mVIVKoIVIVo`0000?oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003o
c<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002
ofIVIP04o`000?m<C4coC4a<o`0000Wo<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmo
o`000002oiVIV@03o`000?nc/k?o000000Woc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmo
o`0000;oIVIV00?o0000oda<C?l000002Olc<c<01Ol0003oC4a<o`000?mVIVKo000000;oOgmo00Go
0000oiVIVOl0003o/k>co`000008olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003o
IVIVo`0000Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo0_moOgl0
0ol0003oVIVIoiVIV@0:oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT03?nIVIT0
0ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`2
o`0000_oIVIV00?o0000ogmoOomoOgl01?moOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o
/k>c01;o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000CoIVIV00?o
0000oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Co
0000ofIVI_mVIVKo00000omoOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Ko
c<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Co0000
oda<C?m<C4co00002?lc<c<01ol0003oC4a<oda<C?m<C4co0000ofIVI_l000000_moOgl01_l0003o
VIVIoiVIVOl0003o/k>co`0000Woc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`0000;o
IVIV00?o0000oda<C?l000002Olc<c<01Ol0003oC4a<o`000?mVIVKo000000;oOgmo00Go0000oiVI
VOl0003o/k>co`000008olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`00
00Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo00?oOgmoo`000?nI
VIT02onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomo
Ogl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mV
IVH02_mVIVH00ol0003oOgmoogmoO`04ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc
/k<04onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000CoOgmo00Go0000ofIVI_mVIVKoIVIVo`000005
oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00om<C4`01?l0003oIVIVofIVI_l0
0003ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`01Ol0003o/k>c
ok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000omVIVH01?l0003oC4a<oda<C?l00008
oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c
/ol00008olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl01Ol0003oIVIVo`000?m<C4co
000000Wo<c<c00?o0000oda<C?l000000_mVIVH01ol0003oOgmoo`000?nIVIWo0000ok>c/ol00000
2Oo<c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000006ooooo`7o00000Oooool1
ooooo`009?ooool00ol0003oooooooooo`03ooooo`03o`000?nIVIWoVIVI00[oVIVI00?o0000ok>c
/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@;o00002_moOgl00ol0003oIVIVofIVIP0;ofIV
IP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`04ogmo
O`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<04onc/k<00ol0003oVIVIoiVIV@02oiVI
V@05o`000?moOgooOgmoogmoOol000000omVIVH00ol0003oC4a<oda<C004oda<C003o`000?lc<c?o
<c<c00Co<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Go
0000oiVIVOnIVIWoVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o
/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<0
1ol0003oC4a<oda<C?m<C4co0000ofIVI_l000000_moOgl00ol0003oVIVIo`000003ok>c/`03o`00
0?o<c<coc<c<00Koc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV00?o0000
oda<C?l000002Olc<c<01Ol0003oC4a<o`000?mVIVKo000000;oOgmo00Go0000oiVIVOl0003o/k>c
o`000008olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000Kooooo0Ol0
0001ooooo`7ooooo000Tooooo`03o`000?oooooooooo00?ooooo3?nIVIT00ol0003o/k>cok>c/`0F
ok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;
ofIVIP03o`000?m<C4coC4a<01KoC4a<0_l0000;ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000
oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`0Cok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000
ogmoOomoOgooOgmoo`000003ofIVIP03o`000?m<C4coC4a<00CoC4a<00?o0000oc<c<olc<c<01?lc
<c<00ol0003oC4a<oda<C002oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01Ol0003oVIVI
oiVIVOnIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o0000
00;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`07o`000?m<
C4coC4a<oda<C?l0003oIVIVo`000002ogmoO`03o`000?nIVIWo000000?o/k>c00?o0000olc<c?o<
c<`01_o<c<`02?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo00000_mVIVH00ol0003oC4a<o`00
0009oc<c<`05o`000?m<C4co0000ofIVI_l000000_moOgl01Ol0003oVIVIo`000?nc/k?o000000So
c<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00001_ooool1o`00007ooooo
0Oooool002Cooooo0_l00004ooooo`_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVI
V@0<oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<
C00Foda<C003o`000?mVIVKoIVIV00[oIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVI
V@04oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmo
OomoOgoo000000?oIVIV00?o0000oda<C?m<C4`01?m<C4`00ol0003o<c<coc<c<`04oc<c<`03o`00
0?m<C4coC4a<00?oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01Ol0003oVIVIoiVIVOnIVIWo0000
00?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000
ogmoOomoOgoo00000_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`06o`000?m<C4coC4a<o`000?mV
IVKo00000_moOgl00ol0003oVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00So0000ok>c
/onc/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV00?o0000oda<C?l000002Olc<c<00ol0003oC4a<
oda<C002o`0000;oOgmo00Go0000oiVIVOl0003o/k>co`000008olc<c00;o`000?nc/k?o/k>co`00
0?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4`01Oooool2o`0000;ooooo000Tooooo`03o`000?oo
oooooooo00?ooooo2_nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI0_l0
000:ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIV
IP0:ofIVIP03o`000?moOgooOgmo00GoOgmo0_l00005oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o
0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000CoIVIV00?o0000oda<C?m<C4`0
0om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Go0000ofIVI_mVIVKo
IVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0
003o/k>cok>c/onc/k?o000000;oVIVI00Ko0000ogmoOomoOgoo0000ofIVI_l00003oda<C003o`00
0?lc<c?o<c<c00Oo<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`03o`000?nIVIWo0000
00?o/k>c00?o0000olc<c?o<c<`01_o<c<`02?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000
0_mVIVH00ol0003oC4a<o`000009oc<c<`05o`000?m<C4co0000ofIVI_l000000_moOgl01Ol0003o
VIVIo`000?nc/k?o000000Soc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo
0000oda<C?l00005ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`Wo
VIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00So
Ogmo00?o0000ofIVI_mVIVH03?mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00[o
IVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c01?o
/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000CoIVIV00?o0000oda<
C?m<C4`00om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Go0000ofIV
I_mVIVKoIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01_o<
c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Ko0000ogmoOomoOgoo0000ofIVI_l00003oda<
C003o`000?lc<c?o<c<c00Oo<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`03o`000?nI
VIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?mo
Ogoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Go0000oda<C?l0003oIVIVo`00
0002ogmoO`05o`000?nIVIWo0000ok>c/ol000002?o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`00
0?moOgoo0000ofIVI_l0003oC4a<o`0000Gooooo0Ol00001ooooo`7ooooo000Tooooo`03o`000?oo
oooooooo00?ooooo2OnIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o
0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o
0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00GoVIVI00?o
0000ok>c/onc/k<04onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000CoOgmo00Go0000ofIVI_mVIVKo
IVIVo`000006oda<C003o`000?lc<c?o<c<c00?o<c<c00?o0000oda<C?m<C4`00om<C4`01Ol0003o
IVIVofIVI_mVIVKo000000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<co
c<c<00Goc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@06o`000?moOgooOgmoo`000?mVIVKo
00001?m<C4`00ol0003o<c<coc<c<`06oc<c<`09o`000?m<C4coC4a<oda<C?l0003oIVIVo`000?mo
Ogoo000000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`02_l0003o/k>cok>c/ol0003oVIVIo`00
0?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Oo0000oda<C?l0003oIVIV
o`000?moOgoo000000;oVIVI00?o0000ok>c/ol000002?o<c<`01ol0003o/k>cok>c/ol0003oVIVI
o`000?moOgl00_l00002oda<C003o`000?oooooooooo00?ooooo0Ol00001ooooo`7ooooo000Toooo
o`03o`000?oooooooooo00?ooooo2?nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI
00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<
01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI
00CoVIVI00?o0000ok>c/onc/k<04onc/k<00ol0003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmo
ogmoOol000001?mVIVH00ol0003oC4a<oda<C003oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000
oda<C?m<C4`00om<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo0000
1?nc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01_l0003o
Ogmoo`000?l0003oIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01olc<c<01_l0003oC4a<oda<C?l0
003oIVIVo`0000;oOgmo00?o0000oiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c008o`00
0?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP03o`000?m<C4co000000Wo<c<c00Go0000
oda<C?l0003oIVIVo`000002ogmoO`05o`000?nIVIWo0000ok>c/ol000002Oo<c<`02ol0003o/k>c
o`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co000000Kooooo0Ol00001ooooo`7ooooo000T
ooooo`03o`000?oooooooooo00?ooooo1_nIVIT2o`0001So/k>c00?o0000oiVIVOnIVIT02_nIVIT2
o`0000[oOgmo0_l0000<ofIVIP;o00006?m<C4`00ol0003oIVIVofIVIP0:ofIVIP;o00001_moOgl2
o`0000KoVIVI00?o0000ok>c/onc/k<04onc/k<00ol0003oVIVIoiVIV@02oiVIV@03o`000?moOgoo
Ogmo00;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000005oda<C0;o00001Olc<c<00ol0003oC4a<oda<
C003oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Co
/k>c00?o0000olc<c?o<c<`01Oo<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmo
OomoOgoo00000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Oo0000oda<C?m<C4coC4a<
o`000?mVIVKo000000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c008
o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP03o`000?m<C4co000000Wo<c<c00Go
0000oda<C?l0003oIVIVo`000002ogmoO`05o`000?nIVIWo0000ok>c/ol000002Oo<c<`02ol0003o
/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co000000Kooooo0Ol00001ooooo`7ooooo
000Tooooo`03o`000?oooooooooo00?ooooo1_nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nI
VIWoVIVI00[oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<
C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`06ogmoO`03o`000?nI
VIWoVIVI00GoVIVI00?o0000ok>c/onc/k<04onc/k<00ol0003oVIVIoiVIV@02oiVIV@03o`000?mo
OgooOgmo00;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000005oda<C003o`000?lc<c?o<c<c00Co<c<c
00?o0000oda<C?m<C4`00om<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Go0000oiVIVOnI
VIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Goc<c<00Go0000ok>c/onc/k?o/k>co`000002
oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`04o`00
0?m<C4coC4a<o`0000;oIVIV00Ko0000ogmoOomoOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<co
c<c<00Ooc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV00?o0000oda<C?l0
00002Olc<c<01Ol0003oC4a<o`000?mVIVKo000000;oOgmo00Go0000oiVIVOl0003o/k>co`000009
olc<c00;o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l000001_ooool1o`00
007ooooo0Oooool002Cooooo00?o0000ooooooooool00oooool5oiVIV@03o`000?nc/k?o/k>c01Ko
/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00_o
IVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00Go
Ogmo00?o0000oiVIVOnIVIT01OnIVIT00ol0003o/k>cok>c/`0Cok>c/`03o`000?nIVIWoVIVI00?o
VIVI00Go0000ogmoOomoOgooOgmoo`000003ofIVIP03o`000?m<C4coC4a<00?oC4a<00?o0000oc<c
<olc<c<01Olc<c<00ol0003oC4a<oda<C003oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Go0000
oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Goc<c<00Go0000ok>c/onc/k?o/k>c
o`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00?o0000oda<C?m<C4`00_m<C4`00ol0003o
<c<coc<c<`05oc<c<`07o`000?m<C4coC4a<oda<C?l0003oIVIVo`000002ogmoO`03o`000?nIVIWo
000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`02?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo
00000_mVIVH00ol0003oC4a<o`000009oc<c<`03o`000?m<C4co000000;oIVIV00Oo0000ogmoOol0
003oVIVIo`000?nc/k?o000000Woc<c<00co0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0
003oC4a<o`000?lc<c<6ooooo`7o00000Oooool1ooooo`004_ooool4o`000008oa0@4?oooooooooo
onk^k_lb<S;o0000oc8b<_o^k^h6ooooo`03o`000?oooooooooo00?ooooo1?nIVIT00ol0003o/k>c
ok>c/`0Fok>c/`03o`000?nIVIWoVIVI00[oVIVI0_l0000:ogmoO`03o`000?mVIVKoIVIV00_oIVIV
00?o0000oda<C?m<C4`05_m<C4`2o`0000goIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVI
oiVIV@05oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT00onIVIT01Ol0003oOgmo
ogmoOomoOgoo000000CoIVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`04oc<c<`03
o`000?m<C4coC4a<00?oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`03o`000?nIVIWoVIVI
00;o00000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT0
1?l0003oOgmoogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01?l0003oC4a<
oda<C?l00002ofIVIP06o`000?moOgooOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c007
olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c
<olc<c<01olc<c<01Ol0003oC4a<o`000?mVIVKo000000;oOgmo00Go0000oiVIVOl0003o/k>co`00
0008olc<c00=o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co0000oc<c
<`06ooooo`7o00000Oooool1ooooo`005?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL01_ooool00ol0003oooooooooo`03ooooo`?oVIVI00?o0000ok>c/onc/k<05_nc
/k<00ol0003oVIVIoiVIV@0:oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omV
IVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl01Omo
Ogl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT00onI
VIT01Ol0003oOgmoogmoOomoOgoo000000CoIVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o<c<c
oc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`04
o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o
000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c
00Co0000oda<C?m<C4co00000_mVIVH01_l0003oOgmoogmoOol0003oVIVIo`0000;o/k>c00?o0000
olc<c?o<c<`01oo<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<
C003o`000?lc<c?o<c<c00Oo<c<c00Go0000oda<C?l0003oIVIVo`000002ogmoO`05o`000?nIVIWo
0000ok>c/ol000002?o<c<`03Ol0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003o
C4a<o`000?lc<c<01_ooool1o`00007ooooo0Oooool001Cooooo00?o0000ooooooooool00_ooool0
1Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool00oooool2oiVIV@03o`000?nc
/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mV
IVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?mo
OgooOgmo00KoOgmo00?o0000oiVIVOnIVIT01OnIVIT00ol0003o/k>cok>c/`0Cok>c/`03o`000?nI
VIWoVIVI00?oVIVI00Go0000ogmoOomoOgooOgmoo`000004ofIVIP03o`000?m<C4coC4a<00?oC4a<
00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C003oda<C005o`000?mVIVKoIVIVofIVI_l0
00000_moOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c
/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<
o`000008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Ko0000ogmoOomoOgoo0000oiVIVOl00002
ok>c/`03o`000?o<c<coc<c<00Ooc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mV
IVKo00000_m<C4`00ol0003o<c<coc<c<`07oc<c<`03o`000?m<C4coC4a<00;o00000_moOgl01Ol0
003oVIVIo`000?nc/k?o000000Soc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mV
IVKo0000oda<C?l00002oc<c<`Kooooo0Ol00001ooooo`7ooooo000Dooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`000006ooooo`?o00000oooool00onIVIWo0000ok>c/`0G
ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;
ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`06
ogmoO`03o`000?nIVIWoVIVI00GoVIVI00?o0000ok>c/onc/k<05?nc/k<00ol0003oVIVIoiVIV@02
oiVIV@05o`000?moOgooOgmoogmoOol000001?mVIVH00ol0003oC4a<oda<C004oda<C003o`000?lc
<c?o<c<c00?o<c<c00?o0000oda<C?m<C4`00om<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo
00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o
/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o
<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc
/k?o/k>co`0000Soc<c<00_o0000ok>c/onc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`00
0002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`05
o`000?nIVIWo0000ok>c/ol000002?o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000
ofIVI_l0003oC4a<o`0000;o<c<c1?ooool3o`0000;ooooo000Dooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo0?oooooo?oooool1o`00
007ooooo0Oooool001Cooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@
00Kooooo00?o0000ooooooooool0ooooooloooooo`7o00000Oooool1ooooo`005?ooool00ol0003o
ooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`3ooooo
ocoooooo0Ol00001ooooo`7ooooo000Booooo`03oeEEEOmVIVKo000000Cooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP06ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool09oooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`03ooooo`7o00000Oooool1ooooo`009?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00?ooooo0Ol00001ooooo`7ooooo000Toooooooo0000@ol00002ooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-7.04757, -6.93977, 0.0606246, \
0.0606246}}]
}, Closed]]
}, Open  ]],

Cell[TextData[{
  "The waves bend toward the shore. This is because the portion of a \
wavefront that is  closer to the beach moves more slowly,  falling behind. \
This behavior is familiar to anyone who has observed  waves at the beach.  \
The bending of the wavefronts is analogous to the refraction of light waves. \
We discuss this connection in Sec. ",
  ButtonBox["5.2.2",
    ButtonData:>"c:27",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text",
  CellTags->"i:76"]
}, Closed]],

Cell[CellGroupData[{

Cell["Ray Trajectories", "Section",
  CellTags->{"i:107", "c:26"}],

Cell[TextData[{
  "For waves propagating in two dimensions in a medium where ",
  Cell[BoxData[
      \(TraditionalForm\`c = c(x)\)]],
  ", we have seen that the wave's phase ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](x, y, t)\)]],
  "  is given in the WKB approximation  by"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](x, y, t)\  = \ 
        k\_y\ y\  + \ \[Integral]\^x\( 
                  k\_x\) \[DifferentialD]x - \[Omega]\ t\)]],
  ","
}], "NE2",
  CellTags->"(5.2.37)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`k\_x = \@\(\[Omega]\^2/\(\(c\^2\)(x)\) - \
k\_y\^2\)\)]],
  ". This phase appears in the exponent of Eq. ",
  ButtonBox["(5.2.35)",
    ButtonData:>"(5.2.35)",
    ButtonStyle->"Hyperlink"],
  ". Curves of constant ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " define the phase fronts that are observed to propagate and bend in the \
previous animation. \n\tConsider a point on a phase front at position ",
  Cell[BoxData[
      \(TraditionalForm\`\((x\_o, \ y\_o)\)\)]],
  " at time ",
  Cell[BoxData[
      \(TraditionalForm\`t = 0\)]],
  ". Let's assume that this point moves with the wave, and  determine the \
path that it follows. One might think of this point as a surfer who is \
allowing the wave to push him/her along at the local wave speed, in a \
direction normal to the local wavefront. \n\tThe equations of motion for this \
point of constant phase can be obtained by taking a differential of Eq. ",
  ButtonBox["(5.2.37)",
    ButtonData:>"(5.2.37)",
    ButtonStyle->"Hyperlink"],
  " and setting ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]\[Phi]\)]],
  " equal to zero:\n\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[DifferentialD]\[Phi]\), "=", 
          RowBox[{"0", "=", 
            
            RowBox[{\(k\_y\ \[DifferentialD]y\), " ", "+", 
              " ", \(\(\(k\_x\)(x, \[Omega], k\_y)\) \[DifferentialD]x\), "-",
               
              RowBox[{"\[Omega]", \(\[DifferentialD]\ t\), Cell[""]}]}]}]}], 
        TraditionalForm]]],
  "  ,\nor in other words, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{"\[DifferentialD]", 
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"]}], 
            StyleBox[" ",
              FontWeight->"Plain"], "\[CenterDot]", 
            StyleBox["k",
              FontWeight->"Bold",
              FontSlant->"Plain"]}], 
          StyleBox[" ",
            FontWeight->"Plain"], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox[" ",
            FontWeight->"Plain"], 
          StyleBox[\(\[Omega]\ \[DifferentialD]t\),
            FontWeight->"Plain"]}], TraditionalForm]]],
  ".  Since the direction of motion is the ",
  Cell[BoxData[
      FormBox[
        StyleBox["k",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  "-direction, we obtain"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{
              StyleBox["\[DifferentialD]",
                FontWeight->"Plain"], 
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"]}], "/", 
            StyleBox[\(\[DifferentialD]t\),
              FontWeight->"Plain"]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{
            RowBox[{\(\[Omega]\/k\), 
              StyleBox[
                OverscriptBox[
                  StyleBox["k",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "^"],
                FontWeight->"Bold"]}], "=", 
            RowBox[{\(c(x)\), " ", 
              StyleBox[
                OverscriptBox[
                  StyleBox["k",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], "^"],
                FontWeight->"Bold"]}]}]}], TraditionalForm]]],
  ","
}], "NE2",
  CellTags->"(5.2.38)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            OverscriptBox[
              StyleBox["k",
                FontWeight->"Bold",
                FontSlant->"Plain"], "^"],
            FontWeight->"Bold"], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{
            StyleBox[
              OverscriptBox[
                StyleBox["k",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "^"],
              FontWeight->"Bold"], 
            StyleBox["(",
              FontWeight->"Plain"], 
            StyleBox["x",
              FontWeight->"Plain"], 
            StyleBox[")",
              FontWeight->"Plain"]}]}], TraditionalForm]]],
  " is a unit vector in the ",
  Cell[BoxData[
      FormBox[
        StyleBox["k",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  "-direction, and where we have used Eq. ",
  ButtonBox["(5.2.34)",
    ButtonData:>"(5.2.34)",
    ButtonStyle->"Hyperlink"],
  " in the second step. "
}], "Text"],

Cell[TextData[{
  "\tThus, the phase point travels with the local phase velocity ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox[
              SubscriptBox["v", 
                StyleBox["\[Phi]",
                  FontWeight->"Plain"]],
              FontWeight->"Bold"], 
            StyleBox["(",
              FontWeight->"Plain"], 
            StyleBox["x",
              FontWeight->"Plain"], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{\(\[Omega]\/k\), 
            StyleBox[
              OverscriptBox[
                StyleBox["k",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "^"],
              FontWeight->"Bold"]}]}], TraditionalForm]]],
  ", which is hardly surprising. This is the same equation for phase velocity \
as for waves in a homogeneous medium, Eq. ",
  ButtonBox["(5.1.41)",
    ButtonData:>"(5.1.41)",
    ButtonStyle->"Hyperlink"],
  ", but now the velocity varies with position. For a given initial \
condition, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox["(",
              FontWeight->"Plain"], 
            StyleBox[\(t = 0\),
              FontWeight->"Plain"], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox[\((x\_o, y\_o)\),
            FontWeight->"Plain"]}], TraditionalForm]]],
  ", the solution to Eq. ",
  ButtonBox["(5.2.38)",
    ButtonData:>"(5.2.38)",
    ButtonStyle->"Hyperlink"],
  " defines a curve ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["(",
            FontWeight->"Plain"], 
          StyleBox["t",
            FontWeight->"Plain"], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  " in the ",
  Cell[BoxData[
      \(TraditionalForm\`x - y\)]],
  " plane, which is the trajectory of the point of constant phase as time \
progresses.  This curve is called a ",
  StyleBox["ray trajectory",
    FontSlant->"Italic"],
  " . \nIn component form, Eq. ",
  ButtonBox["(5.2.38)",
    ButtonData:>"(5.2.38)",
    ButtonStyle->"Hyperlink"],
  " becomes"
}], "Text",
  CellTags->"i:77"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]x/\[DifferentialD]t = \(c(x)\)\ k\_x/
            k\)]],
  ",\n ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]y/\[DifferentialD]t = \(c(x)\)\ k\_y/
            k\)]]
}], "NE2",
  CellTags->"(5.2.39)"],

Cell[TextData[{
  "In Cell ",
  ButtonBox["5.26",
    ButtonData:>"Cell 5.26",
    ButtonStyle->"Hyperlink"],
  ", we solve Eq. ",
  ButtonBox["(5.2.39)",
    ButtonData:>"(5.2.39)",
    ButtonStyle->"Hyperlink"],
  " for three separate initial conditions, and plot them, using our previous \
results for ",
  Cell[BoxData[
      \(TraditionalForm\`\(k\_x\)(x)\)]],
  ".  "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(Do[x0 = \(-5\)\  + \ 2  n; \ y0\  = \ \(-5\)\  + \ 4  n; 
        ray = NDSolve[{\(x'\)[t]\  == \ 
                c[x[t]]\ kx[x[t]]/Sqrt[ky^2\  + \ kx[x[t]]^2], \(y'\)[
                  t]\  == \ c[x[t]]\ ky/Sqrt[ky^2\  + \ kx[x[t]]^2], 
              x[0] \[Equal] x0, y[0] \[Equal] y0}, {x[t], y[t]}, {t, 0, 
              10}]; \[IndentingNewLine]\ xray[t_]\  = \ x[t] /. ray[\([1]\)]; 
        yray[t_]\  = \ y[t] /. ray[\([1]\)]; \ 
        plot[n]\  = \ 
          ParametricPlot[{xray[t], yray[t]}, {t, 0, 10}, 
            DisplayFunction \[Rule] Identity, 
            PlotStyle \[Rule] RGBColor[1, 0, 0]];, {n, 0, 2}];\)\), "\n", 
    \(\(Show[Join[{waves[\([1]\)]}, Table[plot[n], {n, 0, 2}]], 
        PlotRange \[Rule] {{\(-5\), 10}, {\(-5\), 10}}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\)}], "Input",
  ShowCellTags->True,
  CellTags->"Cell 5.26"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.333333 0.0666667 0.333333 0.0666667 [
[.06667 -0.0125 -6 -9 ]
[.06667 -0.0125 6 0 ]
[.2 -0.0125 -6 -9 ]
[.2 -0.0125 6 0 ]
[.33333 -0.0125 -3 -9 ]
[.33333 -0.0125 3 0 ]
[.46667 -0.0125 -3 -9 ]
[.46667 -0.0125 3 0 ]
[.6 -0.0125 -3 -9 ]
[.6 -0.0125 3 0 ]
[.73333 -0.0125 -3 -9 ]
[.73333 -0.0125 3 0 ]
[.86667 -0.0125 -3 -9 ]
[.86667 -0.0125 3 0 ]
[1 -0.0125 -6 -9 ]
[1 -0.0125 6 0 ]
[ 0 0 -0.125 0 ]
[.5 -0.0125 -5 -21 ]
[.5 -0.0125 5 -9 ]
[-0.0125 .06667 -12 -4.5 ]
[-0.0125 .06667 0 4.5 ]
[-0.0125 .2 -12 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .33333 -6 -4.5 ]
[-0.0125 .33333 0 4.5 ]
[-0.0125 .46667 -6 -4.5 ]
[-0.0125 .46667 0 4.5 ]
[-0.0125 .6 -6 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .73333 -6 -4.5 ]
[-0.0125 .73333 0 4.5 ]
[-0.0125 .86667 -6 -4.5 ]
[-0.0125 .86667 0 4.5 ]
[-0.0125 1 -12 -4.5 ]
[-0.0125 1 0 4.5 ]
[ 0 0 -0.125 0 ]
[-0.01875 .5 -24 -5 ]
[-0.01875 .5 -12 5 ]
[ 0 1 .125 0 ]
[ 1 0 .125 0 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.06667 0 m
.06667 .00625 L
s
[(-4)] .06667 -0.0125 0 1 Mshowa
.2 0 m
.2 .00625 L
s
[(-2)] .2 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(0)] .33333 -0.0125 0 1 Mshowa
.46667 0 m
.46667 .00625 L
s
[(2)] .46667 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(4)] .6 -0.0125 0 1 Mshowa
.73333 0 m
.73333 .00625 L
s
[(6)] .73333 -0.0125 0 1 Mshowa
.86667 0 m
.86667 .00625 L
s
[(8)] .86667 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(10)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.1 0 m
.1 .00375 L
s
.13333 0 m
.13333 .00375 L
s
.16667 0 m
.16667 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.3 0 m
.3 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.4 0 m
.4 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.5 0 m
.5 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.66667 0 m
.66667 .00375 L
s
.7 0 m
.7 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.8 0 m
.8 .00375 L
s
.83333 0 m
.83333 .00375 L
s
.9 0 m
.9 .00375 L
s
.93333 0 m
.93333 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.03333 0 m
.03333 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
.5 -0.0125 -66 -25 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .06667 m
.00625 .06667 L
s
[(-4)] -0.0125 .06667 1 0 Mshowa
0 .2 m
.00625 .2 L
s
[(-2)] -0.0125 .2 1 0 Mshowa
0 .33333 m
.00625 .33333 L
s
[(0)] -0.0125 .33333 1 0 Mshowa
0 .46667 m
.00625 .46667 L
s
[(2)] -0.0125 .46667 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(4)] -0.0125 .6 1 0 Mshowa
0 .73333 m
.00625 .73333 L
s
[(6)] -0.0125 .73333 1 0 Mshowa
0 .86667 m
.00625 .86667 L
s
[(8)] -0.0125 .86667 1 0 Mshowa
0 1 m
.00625 1 L
s
[(10)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .1 m
.00375 .1 L
s
0 .13333 m
.00375 .13333 L
s
0 .16667 m
.00375 .16667 L
s
0 .23333 m
.00375 .23333 L
s
0 .26667 m
.00375 .26667 L
s
0 .3 m
.00375 .3 L
s
0 .36667 m
.00375 .36667 L
s
0 .4 m
.00375 .4 L
s
0 .43333 m
.00375 .43333 L
s
0 .5 m
.00375 .5 L
s
0 .53333 m
.00375 .53333 L
s
0 .56667 m
.00375 .56667 L
s
0 .63333 m
.00375 .63333 L
s
0 .66667 m
.00375 .66667 L
s
0 .7 m
.00375 .7 L
s
0 .76667 m
.00375 .76667 L
s
0 .8 m
.00375 .8 L
s
0 .83333 m
.00375 .83333 L
s
0 .9 m
.00375 .9 L
s
0 .93333 m
.00375 .93333 L
s
0 .96667 m
.00375 .96667 L
s
0 .03333 m
.00375 .03333 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
-0.01875 .5 -84 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
66 10 translate
90 rotate
-66 -10 translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.06667 .99375 m
.06667 1 L
s
.2 .99375 m
.2 1 L
s
.33333 .99375 m
.33333 1 L
s
.46667 .99375 m
.46667 1 L
s
.6 .99375 m
.6 1 L
s
.73333 .99375 m
.73333 1 L
s
.86667 .99375 m
.86667 1 L
s
.125 Mabswid
.1 .99625 m
.1 1 L
s
.13333 .99625 m
.13333 1 L
s
.16667 .99625 m
.16667 1 L
s
.23333 .99625 m
.23333 1 L
s
.26667 .99625 m
.26667 1 L
s
.3 .99625 m
.3 1 L
s
.36667 .99625 m
.36667 1 L
s
.4 .99625 m
.4 1 L
s
.43333 .99625 m
.43333 1 L
s
.5 .99625 m
.5 1 L
s
.53333 .99625 m
.53333 1 L
s
.56667 .99625 m
.56667 1 L
s
.63333 .99625 m
.63333 1 L
s
.66667 .99625 m
.66667 1 L
s
.7 .99625 m
.7 1 L
s
.76667 .99625 m
.76667 1 L
s
.8 .99625 m
.8 1 L
s
.83333 .99625 m
.83333 1 L
s
.9 .99625 m
.9 1 L
s
.93333 .99625 m
.93333 1 L
s
.96667 .99625 m
.96667 1 L
s
.03333 .99625 m
.03333 1 L
s
.25 Mabswid
0 1 m
1 1 L
s
.99375 .06667 m
1 .06667 L
s
.99375 .2 m
1 .2 L
s
.99375 .33333 m
1 .33333 L
s
.99375 .46667 m
1 .46667 L
s
.99375 .6 m
1 .6 L
s
.99375 .73333 m
1 .73333 L
s
.99375 .86667 m
1 .86667 L
s
.125 Mabswid
.99625 .1 m
1 .1 L
s
.99625 .13333 m
1 .13333 L
s
.99625 .16667 m
1 .16667 L
s
.99625 .23333 m
1 .23333 L
s
.99625 .26667 m
1 .26667 L
s
.99625 .3 m
1 .3 L
s
.99625 .36667 m
1 .36667 L
s
.99625 .4 m
1 .4 L
s
.99625 .43333 m
1 .43333 L
s
.99625 .5 m
1 .5 L
s
.99625 .53333 m
1 .53333 L
s
.99625 .56667 m
1 .56667 L
s
.99625 .63333 m
1 .63333 L
s
.99625 .66667 m
1 .66667 L
s
.99625 .7 m
1 .7 L
s
.99625 .76667 m
1 .76667 L
s
.99625 .8 m
1 .8 L
s
.99625 .83333 m
1 .83333 L
s
.99625 .9 m
1 .9 L
s
.99625 .93333 m
1 .93333 L
s
.99625 .96667 m
1 .96667 L
s
.99625 .03333 m
1 .03333 L
s
.25 Mabswid
1 0 m
1 1 L
s
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
.6 g
0 1 m
1 1 L
1 0 L
0 0 L
F
.5 g
0 .99924 m
.00934 .9899 L
.0101 .98914 L
.01944 .9798 L
.0202 .97904 L
.02954 .9697 L
.0303 .96894 L
.03964 .9596 L
.0404 .95884 L
.04975 .94949 L
.05051 .94874 L
.05985 .93939 L
.06061 .93863 L
.06995 .92929 L
.07071 .92853 L
.08005 .91919 L
.08081 .91843 L
.09015 .90909 L
.09091 .90833 L
.10025 .89899 L
.10101 .89823 L
.11035 .88889 L
.11111 .88813 L
.12045 .87879 L
.12121 .87803 L
.13055 .86869 L
.13131 .86793 L
.14065 .85859 L
.14141 .85783 L
.15076 .84848 L
.15152 .84773 L
.16086 .83838 L
.16162 .83762 L
.17096 .82828 L
.17172 .82752 L
.18106 .81818 L
.18182 .81742 L
.19116 .80808 L
.19192 .80732 L
.20126 .79798 L
.20202 .79722 L
.21136 .78788 L
.21212 .78712 L
.22146 .77778 L
.22222 .77702 L
.23156 .76768 L
.23232 .76692 L
.24166 .75758 L
.24242 .75682 L
.25177 .74747 L
.25253 .74672 L
.26187 .73737 L
.26263 .73661 L
.27197 .72727 L
.27273 .72651 L
.28207 .71717 L
.28283 .71641 L
.29217 .70707 L
.29293 .70631 L
.30227 .69697 L
.30303 .69621 L
.31237 .68687 L
.31313 .68611 L
.32247 .67677 L
.32323 .67601 L
.3326 .66667 L
.33333 .66591 L
.34184 .65657 L
.34343 .65478 L
.35065 .64646 L
.35354 .64304 L
.35906 .63636 L
.36364 .6307 L
.36716 .62626 L
.37374 .61779 L
.37498 .61616 L
.38256 .60606 L
.38384 .60432 L
.38991 .59596 L
.39394 .59031 L
.39707 .58586 L
.40404 .57578 L
.40406 .57576 L
.41088 .56566 L
.41414 .56074 L
.41755 .55556 L
.42409 .54545 L
.42424 .54522 L
.4305 .53535 L
.43434 .52921 L
.43679 .52525 L
.44298 .51515 L
.44444 .51273 L
.44906 .50505 L
.45455 .49581 L
.45505 .49495 L
.46095 .48485 L
.46465 .47844 L
.46676 .47475 L
.47249 .46465 L
.47475 .46064 L
.47814 .45455 L
.48373 .44444 L
.48485 .44241 L
.48924 .43434 L
.4947 .42424 L
.49495 .42377 L
.50008 .41414 L
.50505 .40473 L
.50541 .40404 L
.51068 .39394 L
.51515 .38529 L
.51589 .38384 L
.52105 .37374 L
.52525 .36546 L
.52617 .36364 L
.53123 .35354 L
.53535 .34525 L
.53624 .34343 L
.54121 .33333 L
.54545 .32466 L
.54614 .32323 L
.55102 .31313 L
.55556 .3037 L
.55587 .30303 L
.56067 .29293 L
.56545 .28283 L
.56566 .28238 L
.57016 .27273 L
.57487 .26263 L
.57576 .26071 L
.57951 .25253 L
.58415 .24242 L
.58586 .23868 L
.58873 .23232 L
.5933 .22222 L
.59596 .2163 L
.59782 .21212 L
.60232 .20202 L
.60606 .19359 L
.60679 .19192 L
.61123 .18182 L
.61565 .17172 L
.61616 .17054 L
.62002 .16162 L
.62439 .15152 L
.62626 .14716 L
.62871 .14141 L
.63302 .13131 L
.63636 .12345 L
.6373 .12121 L
.64155 .11111 L
.6458 .10101 L
.64646 .09942 L
.64999 .09091 L
.6542 .08081 L
.65657 .07508 L
.65835 .07071 L
.6625 .06061 L
.66663 .05051 L
.66667 .05042 L
.67071 .0404 L
.67481 .0303 L
.67677 .02544 L
.67885 .0202 L
.6829 .0101 L
.68687 .00017 L
.68693 0 L
0 0 L
F
0 g
.5 Mabswid
0 .99924 m
.00934 .9899 L
.0101 .98914 L
.01944 .9798 L
.0202 .97904 L
.02954 .9697 L
.0303 .96894 L
.03964 .9596 L
.0404 .95884 L
.04975 .94949 L
.05051 .94874 L
.05985 .93939 L
.06061 .93863 L
.06995 .92929 L
.07071 .92853 L
.08005 .91919 L
.08081 .91843 L
.09015 .90909 L
.09091 .90833 L
.10025 .89899 L
.10101 .89823 L
.11035 .88889 L
.11111 .88813 L
.12045 .87879 L
.12121 .87803 L
.13055 .86869 L
.13131 .86793 L
.14065 .85859 L
.14141 .85783 L
.15076 .84848 L
.15152 .84773 L
.16086 .83838 L
.16162 .83762 L
.17096 .82828 L
.17172 .82752 L
.18106 .81818 L
.18182 .81742 L
.19116 .80808 L
.19192 .80732 L
.20126 .79798 L
.20202 .79722 L
.21136 .78788 L
.21212 .78712 L
.22146 .77778 L
.22222 .77702 L
.23156 .76768 L
.23232 .76692 L
.24166 .75758 L
.24242 .75682 L
.25177 .74747 L
Mistroke
.25253 .74672 L
.26187 .73737 L
.26263 .73661 L
.27197 .72727 L
.27273 .72651 L
.28207 .71717 L
.28283 .71641 L
.29217 .70707 L
.29293 .70631 L
.30227 .69697 L
.30303 .69621 L
.31237 .68687 L
.31313 .68611 L
.32247 .67677 L
.32323 .67601 L
.3326 .66667 L
.33333 .66591 L
.34184 .65657 L
.34343 .65478 L
.35065 .64646 L
.35354 .64304 L
.35906 .63636 L
.36364 .6307 L
.36716 .62626 L
.37374 .61779 L
.37498 .61616 L
.38256 .60606 L
.38384 .60432 L
.38991 .59596 L
.39394 .59031 L
.39707 .58586 L
.40404 .57578 L
.40406 .57576 L
.41088 .56566 L
.41414 .56074 L
.41755 .55556 L
.42409 .54545 L
.42424 .54522 L
.4305 .53535 L
.43434 .52921 L
.43679 .52525 L
.44298 .51515 L
.44444 .51273 L
.44906 .50505 L
.45455 .49581 L
.45505 .49495 L
.46095 .48485 L
.46465 .47844 L
.46676 .47475 L
.47249 .46465 L
Mistroke
.47475 .46064 L
.47814 .45455 L
.48373 .44444 L
.48485 .44241 L
.48924 .43434 L
.4947 .42424 L
.49495 .42377 L
.50008 .41414 L
.50505 .40473 L
.50541 .40404 L
.51068 .39394 L
.51515 .38529 L
.51589 .38384 L
.52105 .37374 L
.52525 .36546 L
.52617 .36364 L
.53123 .35354 L
.53535 .34525 L
.53624 .34343 L
.54121 .33333 L
.54545 .32466 L
.54614 .32323 L
.55102 .31313 L
.55556 .3037 L
.55587 .30303 L
.56067 .29293 L
.56545 .28283 L
.56566 .28238 L
.57016 .27273 L
.57487 .26263 L
.57576 .26071 L
.57951 .25253 L
.58415 .24242 L
.58586 .23868 L
.58873 .23232 L
.5933 .22222 L
.59596 .2163 L
.59782 .21212 L
.60232 .20202 L
.60606 .19359 L
.60679 .19192 L
.61123 .18182 L
.61565 .17172 L
.61616 .17054 L
.62002 .16162 L
.62439 .15152 L
.62626 .14716 L
.62871 .14141 L
.63302 .13131 L
.63636 .12345 L
Mistroke
.6373 .12121 L
.64155 .11111 L
.6458 .10101 L
.64646 .09942 L
.64999 .09091 L
.6542 .08081 L
.65657 .07508 L
.65835 .07071 L
.6625 .06061 L
.66663 .05051 L
.66667 .05042 L
.67071 .0404 L
.67481 .0303 L
.67677 .02544 L
.67885 .0202 L
.6829 .0101 L
.68687 .00017 L
.68693 0 L
Mfstroke
.4 g
0 .96241 m
.00281 .9596 L
.0101 .95231 L
.01292 .94949 L
.0202 .94221 L
.02302 .93939 L
.0303 .93211 L
.03312 .92929 L
.0404 .92201 L
.04322 .91919 L
.05051 .91191 L
.05332 .90909 L
.06061 .90181 L
.06342 .89899 L
.07071 .89171 L
.07352 .88889 L
.08081 .8816 L
.08362 .87879 L
.09091 .8715 L
.09373 .86869 L
.10101 .8614 L
.10383 .85859 L
.11111 .8513 L
.11393 .84848 L
.12121 .8412 L
.12403 .83838 L
.13131 .8311 L
.13413 .82828 L
.14141 .821 L
.14423 .81818 L
.15152 .8109 L
.15433 .80808 L
.16162 .8008 L
.16443 .79798 L
.17172 .7907 L
.17453 .78788 L
.18182 .78059 L
.18463 .77778 L
.19192 .77049 L
.19474 .76768 L
.20202 .76039 L
.20484 .75758 L
.21212 .75029 L
.21494 .74747 L
.22222 .74019 L
.22504 .73737 L
.23232 .73009 L
.23514 .72727 L
.24242 .71999 L
.24524 .71717 L
.25253 .70989 L
.25534 .70707 L
.26263 .69979 L
.26544 .69697 L
.27273 .68969 L
.27554 .68687 L
.28283 .67958 L
.28564 .67677 L
.29293 .66948 L
.29575 .66667 L
.30303 .65938 L
.30585 .65657 L
.31313 .64928 L
.31595 .64646 L
.32323 .63918 L
.32606 .63636 L
.33333 .62908 L
.3362 .62626 L
.34343 .61926 L
.34647 .61616 L
.35354 .60862 L
.35588 .60606 L
.36364 .59724 L
.36474 .59596 L
.37318 .58586 L
.37374 .58516 L
.38127 .57576 L
.38384 .57244 L
.38904 .56566 L
.39394 .55909 L
.39655 .55556 L
.40383 .54545 L
.40404 .54516 L
.41094 .53535 L
.41414 .53068 L
.41784 .52525 L
.42424 .51565 L
.42457 .51515 L
.43118 .50505 L
.43434 .5001 L
.43763 .49495 L
.44396 .48485 L
.44444 .48406 L
.45019 .47475 L
.45455 .46753 L
.45629 .46465 L
.4623 .45455 L
.46465 .45054 L
.46822 .44444 L
.47403 .43434 L
.47475 .43308 L
.47979 .42424 L
.48485 .41519 L
.48543 .41414 L
.49104 .40404 L
.49495 .39686 L
.49654 .39394 L
.50201 .38384 L
.50505 .37811 L
.50738 .37374 L
.51272 .36364 L
.51515 .35895 L
.51798 .35354 L
.52319 .34343 L
.52525 .33938 L
.52835 .33333 L
.53346 .32323 L
.53535 .31942 L
.53851 .31313 L
.54352 .30303 L
.54545 .29907 L
.54848 .29293 L
.55341 .28283 L
.55556 .27835 L
.55827 .27273 L
.56312 .26263 L
.56566 .25725 L
.5679 .25253 L
.57267 .24242 L
.57576 .23578 L
.57738 .23232 L
.58208 .22222 L
.58586 .21395 L
.5867 .21212 L
.59134 .20202 L
.5959 .19192 L
.59596 .19178 L
.60047 .18182 L
.60498 .17172 L
.60606 .16925 L
.60947 .16162 L
.61393 .15152 L
.61616 .14638 L
.61834 .14141 L
.62276 .13131 L
.62626 .12317 L
.62711 .12121 L
.63148 .11111 L
.63579 .10101 L
.63636 .09963 L
.64009 .09091 L
.64437 .08081 L
.64646 .07577 L
.6486 .07071 L
.65284 .06061 L
.65657 .05157 L
.65701 .05051 L
.66121 .0404 L
.66536 .0303 L
.66667 .02706 L
.66949 .0202 L
.67362 .0101 L
.67677 .00224 L
.67768 0 L
0 0 L
F
0 g
0 .96241 m
.00281 .9596 L
.0101 .95231 L
.01292 .94949 L
.0202 .94221 L
.02302 .93939 L
.0303 .93211 L
.03312 .92929 L
.0404 .92201 L
.04322 .91919 L
.05051 .91191 L
.05332 .90909 L
.06061 .90181 L
.06342 .89899 L
.07071 .89171 L
.07352 .88889 L
.08081 .8816 L
.08362 .87879 L
.09091 .8715 L
.09373 .86869 L
.10101 .8614 L
.10383 .85859 L
.11111 .8513 L
.11393 .84848 L
.12121 .8412 L
.12403 .83838 L
.13131 .8311 L
.13413 .82828 L
.14141 .821 L
.14423 .81818 L
.15152 .8109 L
.15433 .80808 L
.16162 .8008 L
.16443 .79798 L
.17172 .7907 L
.17453 .78788 L
.18182 .78059 L
.18463 .77778 L
.19192 .77049 L
.19474 .76768 L
.20202 .76039 L
.20484 .75758 L
.21212 .75029 L
.21494 .74747 L
.22222 .74019 L
.22504 .73737 L
.23232 .73009 L
.23514 .72727 L
.24242 .71999 L
.24524 .71717 L
Mistroke
.25253 .70989 L
.25534 .70707 L
.26263 .69979 L
.26544 .69697 L
.27273 .68969 L
.27554 .68687 L
.28283 .67958 L
.28564 .67677 L
.29293 .66948 L
.29575 .66667 L
.30303 .65938 L
.30585 .65657 L
.31313 .64928 L
.31595 .64646 L
.32323 .63918 L
.32606 .63636 L
.33333 .62908 L
.3362 .62626 L
.34343 .61926 L
.34647 .61616 L
.35354 .60862 L
.35588 .60606 L
.36364 .59724 L
.36474 .59596 L
.37318 .58586 L
.37374 .58516 L
.38127 .57576 L
.38384 .57244 L
.38904 .56566 L
.39394 .55909 L
.39655 .55556 L
.40383 .54545 L
.40404 .54516 L
.41094 .53535 L
.41414 .53068 L
.41784 .52525 L
.42424 .51565 L
.42457 .51515 L
.43118 .50505 L
.43434 .5001 L
.43763 .49495 L
.44396 .48485 L
.44444 .48406 L
.45019 .47475 L
.45455 .46753 L
.45629 .46465 L
.4623 .45455 L
.46465 .45054 L
.46822 .44444 L
.47403 .43434 L
Mistroke
.47475 .43308 L
.47979 .42424 L
.48485 .41519 L
.48543 .41414 L
.49104 .40404 L
.49495 .39686 L
.49654 .39394 L
.50201 .38384 L
.50505 .37811 L
.50738 .37374 L
.51272 .36364 L
.51515 .35895 L
.51798 .35354 L
.52319 .34343 L
.52525 .33938 L
.52835 .33333 L
.53346 .32323 L
.53535 .31942 L
.53851 .31313 L
.54352 .30303 L
.54545 .29907 L
.54848 .29293 L
.55341 .28283 L
.55556 .27835 L
.55827 .27273 L
.56312 .26263 L
.56566 .25725 L
.5679 .25253 L
.57267 .24242 L
.57576 .23578 L
.57738 .23232 L
.58208 .22222 L
.58586 .21395 L
.5867 .21212 L
.59134 .20202 L
.5959 .19192 L
.59596 .19178 L
.60047 .18182 L
.60498 .17172 L
.60606 .16925 L
.60947 .16162 L
.61393 .15152 L
.61616 .14638 L
.61834 .14141 L
.62276 .13131 L
.62626 .12317 L
.62711 .12121 L
.63148 .11111 L
.63579 .10101 L
.63636 .09963 L
Mistroke
.64009 .09091 L
.64437 .08081 L
.64646 .07577 L
.6486 .07071 L
.65284 .06061 L
.65657 .05157 L
.65701 .05051 L
.66121 .0404 L
.66536 .0303 L
.66667 .02706 L
.66949 .0202 L
.67362 .0101 L
.67677 .00224 L
.67768 0 L
Mfstroke
.3 g
0 .91699 m
.00783 .90909 L
.0101 .90689 L
.018 .89899 L
.0202 .89678 L
.0281 .88889 L
.0303 .88668 L
.0382 .87879 L
.0404 .87658 L
.0483 .86869 L
.05051 .86648 L
.0584 .85859 L
.06061 .85638 L
.0685 .84848 L
.07071 .84628 L
.0786 .83838 L
.08081 .83618 L
.0887 .82828 L
.09091 .82608 L
.09881 .81818 L
.10101 .81598 L
.10891 .80808 L
.11111 .80588 L
.11901 .79798 L
.12121 .79577 L
.12911 .78788 L
.13131 .78567 L
.13921 .77778 L
.14141 .77557 L
.14931 .76768 L
.15152 .76547 L
.15941 .75758 L
.16162 .75537 L
.16951 .74747 L
.17172 .74527 L
.17961 .73737 L
.18182 .73517 L
.18971 .72727 L
.19192 .72507 L
.19982 .71717 L
.20202 .71497 L
.20992 .70707 L
.21212 .70487 L
.22002 .69697 L
.22222 .69476 L
.23012 .68687 L
.23232 .68466 L
.24022 .67677 L
.24242 .67456 L
.25032 .66667 L
.25253 .66446 L
.26042 .65657 L
.26263 .65436 L
.27052 .64646 L
.27273 .64426 L
.28062 .63636 L
.28283 .63416 L
.29072 .62626 L
.29293 .62406 L
.30083 .61616 L
.30303 .61396 L
.31093 .60606 L
.31313 .60386 L
.32103 .59596 L
.32323 .59375 L
.33102 .58586 L
.33333 .58365 L
.34343 .57632 L
.34419 .57576 L
.35354 .56769 L
.35584 .56566 L
.36364 .55795 L
.36605 .55556 L
.37374 .54724 L
.3754 .54545 L
.38384 .53569 L
.38413 .53535 L
.39253 .52525 L
.39394 .52339 L
.40051 .51515 L
.40404 .51038 L
.40811 .50505 L
.41414 .49669 L
.41542 .49495 L
.42262 .48485 L
.42424 .4824 L
.42959 .47475 L
.43434 .46752 L
.43629 .46465 L
.44293 .45455 L
.44444 .45209 L
.44941 .44444 L
.45455 .43611 L
.45567 .43434 L
.46196 .42424 L
.46465 .41964 L
.46802 .41414 L
.47398 .40404 L
.47475 .40266 L
.47993 .39394 L
.48485 .38521 L
.48565 .38384 L
.49146 .37374 L
.49495 .3673 L
.49703 .36364 L
.50265 .35354 L
.50505 .34895 L
.5081 .34343 L
.51355 .33333 L
.51515 .33015 L
.51889 .32323 L
.52418 .31313 L
.52525 .31093 L
.52944 .30303 L
.53458 .29293 L
.53535 .2913 L
.53975 .28283 L
.54477 .27273 L
.54545 .27126 L
.54985 .26263 L
.55478 .25253 L
.55556 .25083 L
.55976 .24242 L
.56462 .23232 L
.56566 .23002 L
.56948 .22222 L
.57429 .21212 L
.57576 .20882 L
.57904 .20202 L
.58381 .19192 L
.58586 .18725 L
.58844 .18182 L
.59317 .17172 L
.59596 .16532 L
.59769 .16162 L
.60238 .15152 L
.60606 .14302 L
.6068 .14141 L
.61144 .13131 L
.61583 .12121 L
.61616 .12038 L
.62036 .11111 L
.6248 .10101 L
.62626 .09739 L
.62916 .09091 L
.63361 .08081 L
.63636 .07406 L
.63784 .07071 L
.64227 .06061 L
.64642 .05051 L
.64646 .05039 L
.65081 .0404 L
.65506 .0303 L
.65657 .0264 L
.65922 .0202 L
.66351 .0101 L
.66667 .00206 L
.66754 0 L
0 0 L
F
0 g
0 .91699 m
.00783 .90909 L
.0101 .90689 L
.018 .89899 L
.0202 .89678 L
.0281 .88889 L
.0303 .88668 L
.0382 .87879 L
.0404 .87658 L
.0483 .86869 L
.05051 .86648 L
.0584 .85859 L
.06061 .85638 L
.0685 .84848 L
.07071 .84628 L
.0786 .83838 L
.08081 .83618 L
.0887 .82828 L
.09091 .82608 L
.09881 .81818 L
.10101 .81598 L
.10891 .80808 L
.11111 .80588 L
.11901 .79798 L
.12121 .79577 L
.12911 .78788 L
.13131 .78567 L
.13921 .77778 L
.14141 .77557 L
.14931 .76768 L
.15152 .76547 L
.15941 .75758 L
.16162 .75537 L
.16951 .74747 L
.17172 .74527 L
.17961 .73737 L
.18182 .73517 L
.18971 .72727 L
.19192 .72507 L
.19982 .71717 L
.20202 .71497 L
.20992 .70707 L
.21212 .70487 L
.22002 .69697 L
.22222 .69476 L
.23012 .68687 L
.23232 .68466 L
.24022 .67677 L
.24242 .67456 L
.25032 .66667 L
Mistroke
.25253 .66446 L
.26042 .65657 L
.26263 .65436 L
.27052 .64646 L
.27273 .64426 L
.28062 .63636 L
.28283 .63416 L
.29072 .62626 L
.29293 .62406 L
.30083 .61616 L
.30303 .61396 L
.31093 .60606 L
.31313 .60386 L
.32103 .59596 L
.32323 .59375 L
.33102 .58586 L
.33333 .58365 L
.34343 .57632 L
.34419 .57576 L
.35354 .56769 L
.35584 .56566 L
.36364 .55795 L
.36605 .55556 L
.37374 .54724 L
.3754 .54545 L
.38384 .53569 L
.38413 .53535 L
.39253 .52525 L
.39394 .52339 L
.40051 .51515 L
.40404 .51038 L
.40811 .50505 L
.41414 .49669 L
.41542 .49495 L
.42262 .48485 L
.42424 .4824 L
.42959 .47475 L
.43434 .46752 L
.43629 .46465 L
.44293 .45455 L
.44444 .45209 L
.44941 .44444 L
.45455 .43611 L
.45567 .43434 L
.46196 .42424 L
.46465 .41964 L
.46802 .41414 L
.47398 .40404 L
.47475 .40266 L
.47993 .39394 L
Mistroke
.48485 .38521 L
.48565 .38384 L
.49146 .37374 L
.49495 .3673 L
.49703 .36364 L
.50265 .35354 L
.50505 .34895 L
.5081 .34343 L
.51355 .33333 L
.51515 .33015 L
.51889 .32323 L
.52418 .31313 L
.52525 .31093 L
.52944 .30303 L
.53458 .29293 L
.53535 .2913 L
.53975 .28283 L
.54477 .27273 L
.54545 .27126 L
.54985 .26263 L
.55478 .25253 L
.55556 .25083 L
.55976 .24242 L
.56462 .23232 L
.56566 .23002 L
.56948 .22222 L
.57429 .21212 L
.57576 .20882 L
.57904 .20202 L
.58381 .19192 L
.58586 .18725 L
.58844 .18182 L
.59317 .17172 L
.59596 .16532 L
.59769 .16162 L
.60238 .15152 L
.60606 .14302 L
.6068 .14141 L
.61144 .13131 L
.61583 .12121 L
.61616 .12038 L
.62036 .11111 L
.6248 .10101 L
.62626 .09739 L
.62916 .09091 L
.63361 .08081 L
.63636 .07406 L
.63784 .07071 L
.64227 .06061 L
.64642 .05051 L
Mistroke
.64646 .05039 L
.65081 .0404 L
.65506 .0303 L
.65657 .0264 L
.65922 .0202 L
.66351 .0101 L
.66667 .00206 L
.66754 0 L
Mfstroke
.4 g
0 .83523 m
.00712 .82828 L
.0101 .82513 L
.01705 .81818 L
.0202 .81503 L
.02715 .80808 L
.0303 .80493 L
.03725 .79798 L
.0404 .79483 L
.04736 .78788 L
.05051 .78473 L
.05746 .77778 L
.06061 .77463 L
.06756 .76768 L
.07071 .76453 L
.07766 .75758 L
.08081 .75443 L
.08776 .74747 L
.09091 .74433 L
.09786 .73737 L
.10101 .73422 L
.10796 .72727 L
.11111 .72412 L
.11806 .71717 L
.12121 .71402 L
.12816 .70707 L
.13131 .70392 L
.13826 .69697 L
.14141 .69382 L
.14837 .68687 L
.15152 .68372 L
.15847 .67677 L
.16162 .67362 L
.16857 .66667 L
.17172 .66352 L
.17867 .65657 L
.18182 .65342 L
.18877 .64646 L
.19192 .64332 L
.19887 .63636 L
.20202 .63321 L
.20897 .62626 L
.21212 .62311 L
.21907 .61616 L
.22222 .61301 L
.22917 .60606 L
.23232 .60291 L
.23927 .59596 L
.24242 .59281 L
.24938 .58586 L
.25253 .58271 L
.25948 .57576 L
.26263 .57261 L
.26958 .56566 L
.27273 .56251 L
.27968 .55556 L
.28283 .55241 L
.28978 .54545 L
.29293 .5423 L
.29988 .53535 L
.30303 .5322 L
.30998 .52525 L
.31313 .5221 L
.32008 .51515 L
.32323 .512 L
.33045 .50505 L
.33333 .5019 L
.33861 .49495 L
.34343 .48824 L
.34595 .48485 L
.35338 .47475 L
.35354 .47454 L
.3607 .46465 L
.36364 .46054 L
.3679 .45455 L
.37374 .44626 L
.375 .44444 L
.38197 .43434 L
.38384 .43161 L
.3888 .42424 L
.39394 .41657 L
.39553 .41414 L
.40215 .40404 L
.40404 .40113 L
.40863 .39394 L
.41414 .38529 L
.41504 .38384 L
.42132 .37374 L
.42424 .36902 L
.4275 .36364 L
.43363 .35354 L
.43434 .35236 L
.43961 .34343 L
.44444 .33527 L
.44555 .33333 L
.4514 .32323 L
.45455 .31778 L
.45715 .31313 L
.46288 .30303 L
.46465 .2999 L
.46847 .29293 L
.47408 .28283 L
.47475 .28162 L
.47953 .27273 L
.48485 .26295 L
.48502 .26263 L
.49035 .25253 L
.49495 .24389 L
.49569 .24242 L
.50094 .23232 L
.50505 .22445 L
.50616 .22222 L
.51131 .21212 L
.51515 .20464 L
.51643 .20202 L
.5215 .19192 L
.52525 .18447 L
.52652 .18182 L
.53149 .17172 L
.53535 .16393 L
.53643 .16162 L
.54131 .15152 L
.54545 .14303 L
.54619 .14141 L
.55098 .13131 L
.55556 .12178 L
.55581 .12121 L
.56048 .11111 L
.56527 .10101 L
.56566 .10018 L
.56985 .09091 L
.57456 .08081 L
.57576 .07823 L
.57909 .07071 L
.58372 .06061 L
.58586 .05594 L
.58821 .05051 L
.59276 .0404 L
.59596 .03332 L
.59723 .0303 L
.60167 .0202 L
.60606 .01038 L
.60617 .0101 L
.61048 0 L
0 0 L
F
0 g
0 .83523 m
.00712 .82828 L
.0101 .82513 L
.01705 .81818 L
.0202 .81503 L
.02715 .80808 L
.0303 .80493 L
.03725 .79798 L
.0404 .79483 L
.04736 .78788 L
.05051 .78473 L
.05746 .77778 L
.06061 .77463 L
.06756 .76768 L
.07071 .76453 L
.07766 .75758 L
.08081 .75443 L
.08776 .74747 L
.09091 .74433 L
.09786 .73737 L
.10101 .73422 L
.10796 .72727 L
.11111 .72412 L
.11806 .71717 L
.12121 .71402 L
.12816 .70707 L
.13131 .70392 L
.13826 .69697 L
.14141 .69382 L
.14837 .68687 L
.15152 .68372 L
.15847 .67677 L
.16162 .67362 L
.16857 .66667 L
.17172 .66352 L
.17867 .65657 L
.18182 .65342 L
.18877 .64646 L
.19192 .64332 L
.19887 .63636 L
.20202 .63321 L
.20897 .62626 L
.21212 .62311 L
.21907 .61616 L
.22222 .61301 L
.22917 .60606 L
.23232 .60291 L
.23927 .59596 L
.24242 .59281 L
.24938 .58586 L
Mistroke
.25253 .58271 L
.25948 .57576 L
.26263 .57261 L
.26958 .56566 L
.27273 .56251 L
.27968 .55556 L
.28283 .55241 L
.28978 .54545 L
.29293 .5423 L
.29988 .53535 L
.30303 .5322 L
.30998 .52525 L
.31313 .5221 L
.32008 .51515 L
.32323 .512 L
.33045 .50505 L
.33333 .5019 L
.33861 .49495 L
.34343 .48824 L
.34595 .48485 L
.35338 .47475 L
.35354 .47454 L
.3607 .46465 L
.36364 .46054 L
.3679 .45455 L
.37374 .44626 L
.375 .44444 L
.38197 .43434 L
.38384 .43161 L
.3888 .42424 L
.39394 .41657 L
.39553 .41414 L
.40215 .40404 L
.40404 .40113 L
.40863 .39394 L
.41414 .38529 L
.41504 .38384 L
.42132 .37374 L
.42424 .36902 L
.4275 .36364 L
.43363 .35354 L
.43434 .35236 L
.43961 .34343 L
.44444 .33527 L
.44555 .33333 L
.4514 .32323 L
.45455 .31778 L
.45715 .31313 L
.46288 .30303 L
.46465 .2999 L
Mistroke
.46847 .29293 L
.47408 .28283 L
.47475 .28162 L
.47953 .27273 L
.48485 .26295 L
.48502 .26263 L
.49035 .25253 L
.49495 .24389 L
.49569 .24242 L
.50094 .23232 L
.50505 .22445 L
.50616 .22222 L
.51131 .21212 L
.51515 .20464 L
.51643 .20202 L
.5215 .19192 L
.52525 .18447 L
.52652 .18182 L
.53149 .17172 L
.53535 .16393 L
.53643 .16162 L
.54131 .15152 L
.54545 .14303 L
.54619 .14141 L
.55098 .13131 L
.55556 .12178 L
.55581 .12121 L
.56048 .11111 L
.56527 .10101 L
.56566 .10018 L
.56985 .09091 L
.57456 .08081 L
.57576 .07823 L
.57909 .07071 L
.58372 .06061 L
.58586 .05594 L
.58821 .05051 L
.59276 .0404 L
.59596 .03332 L
.59723 .0303 L
.60167 .0202 L
.60606 .01038 L
.60617 .0101 L
.61048 0 L
Mfstroke
.5 g
0 .7898 m
.00193 .78788 L
.0101 .7797 L
.01202 .77778 L
.0202 .7696 L
.02212 .76768 L
.0303 .7595 L
.03222 .75758 L
.0404 .7494 L
.04233 .74747 L
.05051 .73929 L
.05243 .73737 L
.06061 .72919 L
.06253 .72727 L
.07071 .71909 L
.07263 .71717 L
.08081 .70899 L
.08273 .70707 L
.09091 .69889 L
.09283 .69697 L
.10101 .68879 L
.10293 .68687 L
.11111 .67869 L
.11303 .67677 L
.12121 .66859 L
.12313 .66667 L
.13131 .65849 L
.13323 .65657 L
.14141 .64839 L
.14334 .64646 L
.15152 .63828 L
.15344 .63636 L
.16162 .62818 L
.16354 .62626 L
.17172 .61808 L
.17364 .61616 L
.18182 .60798 L
.18374 .60606 L
.19192 .59788 L
.19384 .59596 L
.20202 .58778 L
.20394 .58586 L
.21212 .57768 L
.21404 .57576 L
.22222 .56758 L
.22414 .56566 L
.23232 .55748 L
.23424 .55556 L
.24242 .54738 L
.24435 .54545 L
.25253 .53727 L
.25445 .53535 L
.26263 .52717 L
.26455 .52525 L
.27273 .51707 L
.27465 .51515 L
.28283 .50697 L
.28475 .50505 L
.29293 .49687 L
.29485 .49495 L
.30303 .48677 L
.30495 .48485 L
.31313 .47667 L
.31505 .47475 L
.32323 .46657 L
.3252 .46465 L
.33333 .45647 L
.33512 .45455 L
.34343 .44534 L
.34422 .44444 L
.35291 .43434 L
.35354 .4336 L
.36124 .42424 L
.36364 .42126 L
.36926 .41414 L
.37374 .40835 L
.37702 .40404 L
.38384 .39488 L
.38453 .39394 L
.39183 .38384 L
.39394 .38087 L
.39894 .37374 L
.40404 .36634 L
.40588 .36364 L
.41266 .35354 L
.41414 .3513 L
.4193 .34343 L
.42424 .33577 L
.4258 .33333 L
.43218 .32323 L
.43434 .31977 L
.43844 .31313 L
.44444 .3033 L
.4446 .30303 L
.45066 .29293 L
.45455 .28637 L
.45662 .28283 L
.4625 .27273 L
.46465 .269 L
.46829 .26263 L
.474 .25253 L
.47475 .2512 L
.47963 .24242 L
.48485 .23297 L
.4852 .23232 L
.4907 .22222 L
.49495 .21433 L
.49613 .21212 L
.5015 .20202 L
.50505 .19529 L
.50681 .19192 L
.51207 .18182 L
.51515 .17585 L
.51726 .17172 L
.52242 .16162 L
.52525 .15602 L
.52751 .15152 L
.53257 .14141 L
.53535 .13581 L
.53756 .13131 L
.54253 .12121 L
.54545 .11522 L
.54744 .11111 L
.55232 .10101 L
.55556 .09426 L
.55715 .09091 L
.56194 .08081 L
.56566 .07294 L
.5667 .07071 L
.57142 .06061 L
.57576 .05127 L
.57611 .05051 L
.58075 .0404 L
.58537 .0303 L
.58586 .02924 L
.58994 .0202 L
.59451 .0101 L
.59596 .00687 L
.59901 0 L
0 0 L
F
0 g
0 .7898 m
.00193 .78788 L
.0101 .7797 L
.01202 .77778 L
.0202 .7696 L
.02212 .76768 L
.0303 .7595 L
.03222 .75758 L
.0404 .7494 L
.04233 .74747 L
.05051 .73929 L
.05243 .73737 L
.06061 .72919 L
.06253 .72727 L
.07071 .71909 L
.07263 .71717 L
.08081 .70899 L
.08273 .70707 L
.09091 .69889 L
.09283 .69697 L
.10101 .68879 L
.10293 .68687 L
.11111 .67869 L
.11303 .67677 L
.12121 .66859 L
.12313 .66667 L
.13131 .65849 L
.13323 .65657 L
.14141 .64839 L
.14334 .64646 L
.15152 .63828 L
.15344 .63636 L
.16162 .62818 L
.16354 .62626 L
.17172 .61808 L
.17364 .61616 L
.18182 .60798 L
.18374 .60606 L
.19192 .59788 L
.19384 .59596 L
.20202 .58778 L
.20394 .58586 L
.21212 .57768 L
.21404 .57576 L
.22222 .56758 L
.22414 .56566 L
.23232 .55748 L
.23424 .55556 L
.24242 .54738 L
.24435 .54545 L
Mistroke
.25253 .53727 L
.25445 .53535 L
.26263 .52717 L
.26455 .52525 L
.27273 .51707 L
.27465 .51515 L
.28283 .50697 L
.28475 .50505 L
.29293 .49687 L
.29485 .49495 L
.30303 .48677 L
.30495 .48485 L
.31313 .47667 L
.31505 .47475 L
.32323 .46657 L
.3252 .46465 L
.33333 .45647 L
.33512 .45455 L
.34343 .44534 L
.34422 .44444 L
.35291 .43434 L
.35354 .4336 L
.36124 .42424 L
.36364 .42126 L
.36926 .41414 L
.37374 .40835 L
.37702 .40404 L
.38384 .39488 L
.38453 .39394 L
.39183 .38384 L
.39394 .38087 L
.39894 .37374 L
.40404 .36634 L
.40588 .36364 L
.41266 .35354 L
.41414 .3513 L
.4193 .34343 L
.42424 .33577 L
.4258 .33333 L
.43218 .32323 L
.43434 .31977 L
.43844 .31313 L
.44444 .3033 L
.4446 .30303 L
.45066 .29293 L
.45455 .28637 L
.45662 .28283 L
.4625 .27273 L
.46465 .269 L
.46829 .26263 L
Mistroke
.474 .25253 L
.47475 .2512 L
.47963 .24242 L
.48485 .23297 L
.4852 .23232 L
.4907 .22222 L
.49495 .21433 L
.49613 .21212 L
.5015 .20202 L
.50505 .19529 L
.50681 .19192 L
.51207 .18182 L
.51515 .17585 L
.51726 .17172 L
.52242 .16162 L
.52525 .15602 L
.52751 .15152 L
.53257 .14141 L
.53535 .13581 L
.53756 .13131 L
.54253 .12121 L
.54545 .11522 L
.54744 .11111 L
.55232 .10101 L
.55556 .09426 L
.55715 .09091 L
.56194 .08081 L
.56566 .07294 L
.5667 .07071 L
.57142 .06061 L
.57576 .05127 L
.57611 .05051 L
.58075 .0404 L
.58537 .0303 L
.58586 .02924 L
.58994 .0202 L
.59451 .0101 L
.59596 .00687 L
.59901 0 L
Mfstroke
.6 g
0 .75297 m
.00549 .74747 L
.0101 .74287 L
.0156 .73737 L
.0202 .73277 L
.0257 .72727 L
.0303 .72267 L
.0358 .71717 L
.0404 .71257 L
.0459 .70707 L
.05051 .70247 L
.056 .69697 L
.06061 .69237 L
.06611 .68687 L
.07071 .68227 L
.07621 .67677 L
.08081 .67217 L
.08631 .66667 L
.09091 .66206 L
.09641 .65657 L
.10101 .65196 L
.10651 .64646 L
.11111 .64186 L
.11661 .63636 L
.12121 .63176 L
.12671 .62626 L
.13131 .62166 L
.13681 .61616 L
.14141 .61156 L
.14691 .60606 L
.15152 .60146 L
.15701 .59596 L
.16162 .59136 L
.16712 .58586 L
.17172 .58126 L
.17722 .57576 L
.18182 .57116 L
.18732 .56566 L
.19192 .56105 L
.19742 .55556 L
.20202 .55095 L
.20752 .54545 L
.21212 .54085 L
.21762 .53535 L
.22222 .53075 L
.22772 .52525 L
.23232 .52065 L
.23782 .51515 L
.24242 .51055 L
.24792 .50505 L
.25253 .50045 L
.25802 .49495 L
.26263 .49035 L
.26813 .48485 L
.27273 .48025 L
.27823 .47475 L
.28283 .47015 L
.28833 .46465 L
.29293 .46004 L
.29843 .45455 L
.30303 .44994 L
.30853 .44444 L
.31313 .43984 L
.31863 .43434 L
.32323 .42974 L
.32875 .42424 L
.33333 .41964 L
.33896 .41414 L
.34343 .40982 L
.34904 .40404 L
.35354 .39918 L
.35829 .39394 L
.36364 .3878 L
.36703 .38384 L
.37374 .37572 L
.37536 .37374 L
.38335 .36364 L
.38384 .363 L
.39106 .35354 L
.39394 .34965 L
.39852 .34343 L
.40404 .33572 L
.40574 .33333 L
.41278 .32323 L
.41414 .32124 L
.41965 .31313 L
.42424 .30621 L
.42634 .30303 L
.4329 .29293 L
.43434 .29066 L
.43933 .28283 L
.44444 .27462 L
.44562 .27273 L
.45182 .26263 L
.45455 .25809 L
.4579 .25253 L
.46387 .24242 L
.46465 .2411 L
.46977 .23232 L
.47475 .22364 L
.47556 .22222 L
.4813 .21212 L
.48485 .20575 L
.48693 .20202 L
.49251 .19192 L
.49495 .18742 L
.498 .18182 L
.50344 .17172 L
.50505 .16867 L
.50881 .16162 L
.51411 .15152 L
.51515 .14951 L
.51937 .14141 L
.52456 .13131 L
.52525 .12994 L
.52971 .12121 L
.53479 .11111 L
.53535 .10998 L
.53985 .10101 L
.54483 .09091 L
.54545 .08963 L
.5498 .08081 L
.5547 .07071 L
.55556 .06891 L
.55957 .06061 L
.56439 .05051 L
.56566 .04781 L
.56918 .0404 L
.57393 .0303 L
.57576 .02634 L
.57863 .0202 L
.58331 .0101 L
.58586 .00451 L
.58794 0 L
0 0 L
F
0 g
0 .75297 m
.00549 .74747 L
.0101 .74287 L
.0156 .73737 L
.0202 .73277 L
.0257 .72727 L
.0303 .72267 L
.0358 .71717 L
.0404 .71257 L
.0459 .70707 L
.05051 .70247 L
.056 .69697 L
.06061 .69237 L
.06611 .68687 L
.07071 .68227 L
.07621 .67677 L
.08081 .67217 L
.08631 .66667 L
.09091 .66206 L
.09641 .65657 L
.10101 .65196 L
.10651 .64646 L
.11111 .64186 L
.11661 .63636 L
.12121 .63176 L
.12671 .62626 L
.13131 .62166 L
.13681 .61616 L
.14141 .61156 L
.14691 .60606 L
.15152 .60146 L
.15701 .59596 L
.16162 .59136 L
.16712 .58586 L
.17172 .58126 L
.17722 .57576 L
.18182 .57116 L
.18732 .56566 L
.19192 .56105 L
.19742 .55556 L
.20202 .55095 L
.20752 .54545 L
.21212 .54085 L
.21762 .53535 L
.22222 .53075 L
.22772 .52525 L
.23232 .52065 L
.23782 .51515 L
.24242 .51055 L
.24792 .50505 L
Mistroke
.25253 .50045 L
.25802 .49495 L
.26263 .49035 L
.26813 .48485 L
.27273 .48025 L
.27823 .47475 L
.28283 .47015 L
.28833 .46465 L
.29293 .46004 L
.29843 .45455 L
.30303 .44994 L
.30853 .44444 L
.31313 .43984 L
.31863 .43434 L
.32323 .42974 L
.32875 .42424 L
.33333 .41964 L
.33896 .41414 L
.34343 .40982 L
.34904 .40404 L
.35354 .39918 L
.35829 .39394 L
.36364 .3878 L
.36703 .38384 L
.37374 .37572 L
.37536 .37374 L
.38335 .36364 L
.38384 .363 L
.39106 .35354 L
.39394 .34965 L
.39852 .34343 L
.40404 .33572 L
.40574 .33333 L
.41278 .32323 L
.41414 .32124 L
.41965 .31313 L
.42424 .30621 L
.42634 .30303 L
.4329 .29293 L
.43434 .29066 L
.43933 .28283 L
.44444 .27462 L
.44562 .27273 L
.45182 .26263 L
.45455 .25809 L
.4579 .25253 L
.46387 .24242 L
.46465 .2411 L
.46977 .23232 L
.47475 .22364 L
Mistroke
.47556 .22222 L
.4813 .21212 L
.48485 .20575 L
.48693 .20202 L
.49251 .19192 L
.49495 .18742 L
.498 .18182 L
.50344 .17172 L
.50505 .16867 L
.50881 .16162 L
.51411 .15152 L
.51515 .14951 L
.51937 .14141 L
.52456 .13131 L
.52525 .12994 L
.52971 .12121 L
.53479 .11111 L
.53535 .10998 L
.53985 .10101 L
.54483 .09091 L
.54545 .08963 L
.5498 .08081 L
.5547 .07071 L
.55556 .06891 L
.55957 .06061 L
.56439 .05051 L
.56566 .04781 L
.56918 .0404 L
.57393 .0303 L
.57576 .02634 L
.57863 .0202 L
.58331 .0101 L
.58586 .00451 L
.58794 0 L
Mfstroke
.7 g
0 .70751 m
.00043 .70707 L
.0101 .69741 L
.01054 .69697 L
.0202 .68731 L
.02064 .68687 L
.0303 .67721 L
.03074 .67677 L
.0404 .6671 L
.04084 .66667 L
.05051 .657 L
.05094 .65657 L
.06061 .6469 L
.06104 .64646 L
.07071 .6368 L
.07114 .63636 L
.08081 .6267 L
.08125 .62626 L
.09091 .6166 L
.09135 .61616 L
.10101 .6065 L
.10145 .60606 L
.11111 .5964 L
.11155 .59596 L
.12121 .5863 L
.12165 .58586 L
.13131 .5762 L
.13175 .57576 L
.14141 .56609 L
.14185 .56566 L
.15152 .55599 L
.15195 .55556 L
.16162 .54589 L
.16205 .54545 L
.17172 .53579 L
.17216 .53535 L
.18182 .52569 L
.18226 .52525 L
.19192 .51559 L
.19236 .51515 L
.20202 .50549 L
.20246 .50505 L
.21212 .49539 L
.21256 .49495 L
.22222 .48529 L
.22266 .48485 L
.23232 .47519 L
.23276 .47475 L
.24242 .46508 L
.24286 .46465 L
.25253 .45498 L
.25296 .45455 L
.26263 .44488 L
.26306 .44444 L
.27273 .43478 L
.27317 .43434 L
.28283 .42468 L
.28327 .42424 L
.29293 .41458 L
.29337 .41414 L
.30303 .40448 L
.30347 .40404 L
.31313 .39438 L
.31357 .39394 L
.32323 .38428 L
.32366 .38384 L
.33333 .37418 L
.33386 .37374 L
.34343 .3669 L
.3477 .36364 L
.35354 .35827 L
.35878 .35354 L
.36364 .34852 L
.3687 .34343 L
.37374 .33782 L
.37785 .33333 L
.38384 .32626 L
.38645 .32323 L
.39394 .31394 L
.3946 .31313 L
.40253 .30303 L
.40404 .30093 L
.41012 .29293 L
.41414 .28726 L
.41738 .28283 L
.42424 .27295 L
.4244 .27273 L
.4314 .26263 L
.43434 .25809 L
.4381 .25253 L
.44444 .24264 L
.44458 .24242 L
.45112 .23232 L
.45455 .22668 L
.45736 .22222 L
.46354 .21212 L
.46465 .2102 L
.46965 .20202 L
.47475 .19322 L
.47552 .19192 L
.48149 .18182 L
.48485 .17578 L
.48721 .17172 L
.49295 .16162 L
.49495 .15787 L
.49855 .15152 L
.50407 .14141 L
.50505 .1395 L
.50958 .13131 L
.5149 .12121 L
.51515 .12071 L
.52033 .11111 L
.52525 .10149 L
.5255 .10101 L
.53084 .09091 L
.53535 .08186 L
.5359 .08081 L
.54112 .07071 L
.54545 .06182 L
.54607 .06061 L
.5512 .05051 L
.55556 .04139 L
.55605 .0404 L
.56108 .0303 L
.56566 .02057 L
.56584 .0202 L
.57079 .0101 L
.57549 0 L
0 0 L
F
0 g
0 .70751 m
.00043 .70707 L
.0101 .69741 L
.01054 .69697 L
.0202 .68731 L
.02064 .68687 L
.0303 .67721 L
.03074 .67677 L
.0404 .6671 L
.04084 .66667 L
.05051 .657 L
.05094 .65657 L
.06061 .6469 L
.06104 .64646 L
.07071 .6368 L
.07114 .63636 L
.08081 .6267 L
.08125 .62626 L
.09091 .6166 L
.09135 .61616 L
.10101 .6065 L
.10145 .60606 L
.11111 .5964 L
.11155 .59596 L
.12121 .5863 L
.12165 .58586 L
.13131 .5762 L
.13175 .57576 L
.14141 .56609 L
.14185 .56566 L
.15152 .55599 L
.15195 .55556 L
.16162 .54589 L
.16205 .54545 L
.17172 .53579 L
.17216 .53535 L
.18182 .52569 L
.18226 .52525 L
.19192 .51559 L
.19236 .51515 L
.20202 .50549 L
.20246 .50505 L
.21212 .49539 L
.21256 .49495 L
.22222 .48529 L
.22266 .48485 L
.23232 .47519 L
.23276 .47475 L
.24242 .46508 L
.24286 .46465 L
Mistroke
.25253 .45498 L
.25296 .45455 L
.26263 .44488 L
.26306 .44444 L
.27273 .43478 L
.27317 .43434 L
.28283 .42468 L
.28327 .42424 L
.29293 .41458 L
.29337 .41414 L
.30303 .40448 L
.30347 .40404 L
.31313 .39438 L
.31357 .39394 L
.32323 .38428 L
.32366 .38384 L
.33333 .37418 L
.33386 .37374 L
.34343 .3669 L
.3477 .36364 L
.35354 .35827 L
.35878 .35354 L
.36364 .34852 L
.3687 .34343 L
.37374 .33782 L
.37785 .33333 L
.38384 .32626 L
.38645 .32323 L
.39394 .31394 L
.3946 .31313 L
.40253 .30303 L
.40404 .30093 L
.41012 .29293 L
.41414 .28726 L
.41738 .28283 L
.42424 .27295 L
.4244 .27273 L
.4314 .26263 L
.43434 .25809 L
.4381 .25253 L
.44444 .24264 L
.44458 .24242 L
.45112 .23232 L
.45455 .22668 L
.45736 .22222 L
.46354 .21212 L
.46465 .2102 L
.46965 .20202 L
.47475 .19322 L
.47552 .19192 L
Mistroke
.48149 .18182 L
.48485 .17578 L
.48721 .17172 L
.49295 .16162 L
.49495 .15787 L
.49855 .15152 L
.50407 .14141 L
.50505 .1395 L
.50958 .13131 L
.5149 .12121 L
.51515 .12071 L
.52033 .11111 L
.52525 .10149 L
.5255 .10101 L
.53084 .09091 L
.53535 .08186 L
.5359 .08081 L
.54112 .07071 L
.54545 .06182 L
.54607 .06061 L
.5512 .05051 L
.55556 .04139 L
.55605 .0404 L
.56108 .0303 L
.56566 .02057 L
.56584 .0202 L
.57079 .0101 L
.57549 0 L
Mfstroke
.6 g
0 .62582 m
.00968 .61616 L
.0101 .61572 L
.01976 .60606 L
.0202 .60562 L
.02987 .59596 L
.0303 .59552 L
.03997 .58586 L
.0404 .58542 L
.05007 .57576 L
.05051 .57532 L
.06017 .56566 L
.06061 .56522 L
.07027 .55556 L
.07071 .55512 L
.08037 .54545 L
.08081 .54502 L
.09047 .53535 L
.09091 .53492 L
.10057 .52525 L
.10101 .52481 L
.11067 .51515 L
.11111 .51471 L
.12077 .50505 L
.12121 .50461 L
.13088 .49495 L
.13131 .49451 L
.14098 .48485 L
.14141 .48441 L
.15108 .47475 L
.15152 .47431 L
.16118 .46465 L
.16162 .46421 L
.17128 .45455 L
.17172 .45411 L
.18138 .44444 L
.18182 .44401 L
.19148 .43434 L
.19192 .43391 L
.20158 .42424 L
.20202 .4238 L
.21168 .41414 L
.21212 .4137 L
.22178 .40404 L
.22222 .4036 L
.23189 .39394 L
.23232 .3935 L
.24199 .38384 L
.24242 .3834 L
.25209 .37374 L
.25253 .3733 L
.26219 .36364 L
.26263 .3632 L
.27229 .35354 L
.27273 .3531 L
.28239 .34343 L
.28283 .343 L
.29249 .33333 L
.29293 .3329 L
.30259 .32323 L
.30303 .32279 L
.31269 .31313 L
.31313 .31269 L
.32279 .30303 L
.32323 .30259 L
.33295 .29293 L
.33333 .29249 L
.34056 .28283 L
.34343 .27881 L
.34792 .27273 L
.35354 .26507 L
.35532 .26263 L
.36263 .25253 L
.36364 .25112 L
.3698 .24242 L
.37374 .23682 L
.37685 .23232 L
.38382 .22222 L
.38384 .22219 L
.39061 .21212 L
.39394 .20713 L
.39729 .20202 L
.4039 .19192 L
.40404 .19171 L
.41034 .18182 L
.41414 .17584 L
.4167 .17172 L
.42299 .16162 L
.42424 .15959 L
.42913 .15152 L
.43434 .14291 L
.43522 .14141 L
.4412 .13131 L
.44444 .12583 L
.44709 .12121 L
.45295 .11111 L
.45455 .10835 L
.45867 .10101 L
.4644 .09091 L
.46465 .09047 L
.46996 .08081 L
.47475 .07218 L
.47553 .07071 L
.48099 .06061 L
.48485 .0535 L
.48641 .05051 L
.49178 .0404 L
.49495 .03445 L
.49707 .0303 L
.50234 .0202 L
.50505 .01501 L
.50751 .0101 L
.5127 0 L
0 0 L
F
0 g
0 .62582 m
.00968 .61616 L
.0101 .61572 L
.01976 .60606 L
.0202 .60562 L
.02987 .59596 L
.0303 .59552 L
.03997 .58586 L
.0404 .58542 L
.05007 .57576 L
.05051 .57532 L
.06017 .56566 L
.06061 .56522 L
.07027 .55556 L
.07071 .55512 L
.08037 .54545 L
.08081 .54502 L
.09047 .53535 L
.09091 .53492 L
.10057 .52525 L
.10101 .52481 L
.11067 .51515 L
.11111 .51471 L
.12077 .50505 L
.12121 .50461 L
.13088 .49495 L
.13131 .49451 L
.14098 .48485 L
.14141 .48441 L
.15108 .47475 L
.15152 .47431 L
.16118 .46465 L
.16162 .46421 L
.17128 .45455 L
.17172 .45411 L
.18138 .44444 L
.18182 .44401 L
.19148 .43434 L
.19192 .43391 L
.20158 .42424 L
.20202 .4238 L
.21168 .41414 L
.21212 .4137 L
.22178 .40404 L
.22222 .4036 L
.23189 .39394 L
.23232 .3935 L
.24199 .38384 L
.24242 .3834 L
.25209 .37374 L
Mistroke
.25253 .3733 L
.26219 .36364 L
.26263 .3632 L
.27229 .35354 L
.27273 .3531 L
.28239 .34343 L
.28283 .343 L
.29249 .33333 L
.29293 .3329 L
.30259 .32323 L
.30303 .32279 L
.31269 .31313 L
.31313 .31269 L
.32279 .30303 L
.32323 .30259 L
.33295 .29293 L
.33333 .29249 L
.34056 .28283 L
.34343 .27881 L
.34792 .27273 L
.35354 .26507 L
.35532 .26263 L
.36263 .25253 L
.36364 .25112 L
.3698 .24242 L
.37374 .23682 L
.37685 .23232 L
.38382 .22222 L
.38384 .22219 L
.39061 .21212 L
.39394 .20713 L
.39729 .20202 L
.4039 .19192 L
.40404 .19171 L
.41034 .18182 L
.41414 .17584 L
.4167 .17172 L
.42299 .16162 L
.42424 .15959 L
.42913 .15152 L
.43434 .14291 L
.43522 .14141 L
.4412 .13131 L
.44444 .12583 L
.44709 .12121 L
.45295 .11111 L
.45455 .10835 L
.45867 .10101 L
.4644 .09091 L
.46465 .09047 L
Mistroke
.46996 .08081 L
.47475 .07218 L
.47553 .07071 L
.48099 .06061 L
.48485 .0535 L
.48641 .05051 L
.49178 .0404 L
.49495 .03445 L
.49707 .0303 L
.50234 .0202 L
.50505 .01501 L
.50751 .0101 L
.5127 0 L
Mfstroke
.5 g
0 .58036 m
.00461 .57576 L
.0101 .57026 L
.0147 .56566 L
.0202 .56016 L
.0248 .55556 L
.0303 .55006 L
.0349 .54545 L
.0404 .53996 L
.04501 .53535 L
.05051 .52985 L
.05511 .52525 L
.06061 .51975 L
.06521 .51515 L
.07071 .50965 L
.07531 .50505 L
.08081 .49955 L
.08541 .49495 L
.09091 .48945 L
.09551 .48485 L
.10101 .47935 L
.10561 .47475 L
.11111 .46925 L
.11571 .46465 L
.12121 .45915 L
.12581 .45455 L
.13131 .44905 L
.13592 .44444 L
.14141 .43895 L
.14602 .43434 L
.15152 .42884 L
.15612 .42424 L
.16162 .41874 L
.16622 .41414 L
.17172 .40864 L
.17632 .40404 L
.18182 .39854 L
.18642 .39394 L
.19192 .38844 L
.19652 .38384 L
.20202 .37834 L
.20662 .37374 L
.21212 .36824 L
.21672 .36364 L
.22222 .35814 L
.22682 .35354 L
.23232 .34804 L
.23693 .34343 L
.24242 .33794 L
.24703 .33333 L
.25253 .32783 L
.25713 .32323 L
.26263 .31773 L
.26723 .31313 L
.27273 .30763 L
.27733 .30303 L
.28283 .29753 L
.28743 .29293 L
.29293 .28743 L
.29753 .28283 L
.30303 .27733 L
.30763 .27273 L
.31313 .26723 L
.31773 .26263 L
.32323 .25713 L
.32792 .25253 L
.33333 .24703 L
.33757 .24242 L
.34343 .2359 L
.34657 .23232 L
.35354 .22416 L
.35516 .22222 L
.3634 .21212 L
.36364 .21182 L
.37135 .20202 L
.37374 .19891 L
.37903 .19192 L
.38384 .18544 L
.38649 .18182 L
.39374 .17172 L
.39394 .17143 L
.4008 .16162 L
.40404 .1569 L
.4077 .15152 L
.41414 .14187 L
.41444 .14141 L
.42104 .13131 L
.42424 .12633 L
.42751 .12121 L
.43386 .11111 L
.43434 .11033 L
.44009 .10101 L
.44444 .09385 L
.44622 .09091 L
.45225 .08081 L
.45455 .07693 L
.45819 .07071 L
.46405 .06061 L
.46465 .05956 L
.46981 .05051 L
.47475 .04176 L
.4755 .0404 L
.48112 .0303 L
.48485 .02353 L
.48666 .0202 L
.49215 .0101 L
.49495 .0049 L
.49756 0 L
0 0 L
F
0 g
0 .58036 m
.00461 .57576 L
.0101 .57026 L
.0147 .56566 L
.0202 .56016 L
.0248 .55556 L
.0303 .55006 L
.0349 .54545 L
.0404 .53996 L
.04501 .53535 L
.05051 .52985 L
.05511 .52525 L
.06061 .51975 L
.06521 .51515 L
.07071 .50965 L
.07531 .50505 L
.08081 .49955 L
.08541 .49495 L
.09091 .48945 L
.09551 .48485 L
.10101 .47935 L
.10561 .47475 L
.11111 .46925 L
.11571 .46465 L
.12121 .45915 L
.12581 .45455 L
.13131 .44905 L
.13592 .44444 L
.14141 .43895 L
.14602 .43434 L
.15152 .42884 L
.15612 .42424 L
.16162 .41874 L
.16622 .41414 L
.17172 .40864 L
.17632 .40404 L
.18182 .39854 L
.18642 .39394 L
.19192 .38844 L
.19652 .38384 L
.20202 .37834 L
.20662 .37374 L
.21212 .36824 L
.21672 .36364 L
.22222 .35814 L
.22682 .35354 L
.23232 .34804 L
.23693 .34343 L
.24242 .33794 L
.24703 .33333 L
Mistroke
.25253 .32783 L
.25713 .32323 L
.26263 .31773 L
.26723 .31313 L
.27273 .30763 L
.27733 .30303 L
.28283 .29753 L
.28743 .29293 L
.29293 .28743 L
.29753 .28283 L
.30303 .27733 L
.30763 .27273 L
.31313 .26723 L
.31773 .26263 L
.32323 .25713 L
.32792 .25253 L
.33333 .24703 L
.33757 .24242 L
.34343 .2359 L
.34657 .23232 L
.35354 .22416 L
.35516 .22222 L
.3634 .21212 L
.36364 .21182 L
.37135 .20202 L
.37374 .19891 L
.37903 .19192 L
.38384 .18544 L
.38649 .18182 L
.39374 .17172 L
.39394 .17143 L
.4008 .16162 L
.40404 .1569 L
.4077 .15152 L
.41414 .14187 L
.41444 .14141 L
.42104 .13131 L
.42424 .12633 L
.42751 .12121 L
.43386 .11111 L
.43434 .11033 L
.44009 .10101 L
.44444 .09385 L
.44622 .09091 L
.45225 .08081 L
.45455 .07693 L
.45819 .07071 L
.46405 .06061 L
.46465 .05956 L
.46981 .05051 L
Mistroke
.47475 .04176 L
.4755 .0404 L
.48112 .0303 L
.48485 .02353 L
.48666 .0202 L
.49215 .0101 L
.49495 .0049 L
.49756 0 L
Mfstroke
.4 g
0 .54353 m
.00818 .53535 L
.0101 .53343 L
.01828 .52525 L
.0202 .52333 L
.02838 .51515 L
.0303 .51323 L
.03848 .50505 L
.0404 .50313 L
.04858 .49495 L
.05051 .49303 L
.05869 .48485 L
.06061 .48293 L
.06879 .47475 L
.07071 .47283 L
.07889 .46465 L
.08081 .46273 L
.08899 .45455 L
.09091 .45262 L
.09909 .44444 L
.10101 .44252 L
.10919 .43434 L
.11111 .43242 L
.11929 .42424 L
.12121 .42232 L
.12939 .41414 L
.13131 .41222 L
.13949 .40404 L
.14141 .40212 L
.14959 .39394 L
.15152 .39202 L
.1597 .38384 L
.16162 .38192 L
.1698 .37374 L
.17172 .37182 L
.1799 .36364 L
.18182 .36172 L
.19 .35354 L
.19192 .35161 L
.2001 .34343 L
.20202 .34151 L
.2102 .33333 L
.21212 .33141 L
.2203 .32323 L
.22222 .32131 L
.2304 .31313 L
.23232 .31121 L
.2405 .30303 L
.24242 .30111 L
.2506 .29293 L
.25253 .29101 L
.26071 .28283 L
.26263 .28091 L
.27081 .27273 L
.27273 .27081 L
.28091 .26263 L
.28283 .26071 L
.29101 .25253 L
.29293 .2506 L
.30111 .24242 L
.30303 .2405 L
.31121 .23232 L
.31313 .2304 L
.32131 .22222 L
.32323 .2203 L
.33142 .21212 L
.33333 .2102 L
.34173 .20202 L
.34343 .20038 L
.35155 .19192 L
.35354 .18974 L
.36066 .18182 L
.36364 .17836 L
.36928 .17172 L
.37374 .16629 L
.37752 .16162 L
.38384 .15356 L
.38542 .15152 L
.39306 .14141 L
.39394 .14021 L
.40046 .13131 L
.40404 .12629 L
.40763 .12121 L
.41414 .11179 L
.41461 .11111 L
.42144 .10101 L
.42424 .09677 L
.4281 .09091 L
.43434 .08122 L
.43461 .08081 L
.44102 .07071 L
.44444 .06518 L
.44728 .06061 L
.45344 .05051 L
.45455 .04865 L
.4595 .0404 L
.46465 .03166 L
.46544 .0303 L
.47132 .0202 L
.47475 .01421 L
.47709 .0101 L
.4828 0 L
0 0 L
F
0 g
0 .54353 m
.00818 .53535 L
.0101 .53343 L
.01828 .52525 L
.0202 .52333 L
.02838 .51515 L
.0303 .51323 L
.03848 .50505 L
.0404 .50313 L
.04858 .49495 L
.05051 .49303 L
.05869 .48485 L
.06061 .48293 L
.06879 .47475 L
.07071 .47283 L
.07889 .46465 L
.08081 .46273 L
.08899 .45455 L
.09091 .45262 L
.09909 .44444 L
.10101 .44252 L
.10919 .43434 L
.11111 .43242 L
.11929 .42424 L
.12121 .42232 L
.12939 .41414 L
.13131 .41222 L
.13949 .40404 L
.14141 .40212 L
.14959 .39394 L
.15152 .39202 L
.1597 .38384 L
.16162 .38192 L
.1698 .37374 L
.17172 .37182 L
.1799 .36364 L
.18182 .36172 L
.19 .35354 L
.19192 .35161 L
.2001 .34343 L
.20202 .34151 L
.2102 .33333 L
.21212 .33141 L
.2203 .32323 L
.22222 .32131 L
.2304 .31313 L
.23232 .31121 L
.2405 .30303 L
.24242 .30111 L
.2506 .29293 L
Mistroke
.25253 .29101 L
.26071 .28283 L
.26263 .28091 L
.27081 .27273 L
.27273 .27081 L
.28091 .26263 L
.28283 .26071 L
.29101 .25253 L
.29293 .2506 L
.30111 .24242 L
.30303 .2405 L
.31121 .23232 L
.31313 .2304 L
.32131 .22222 L
.32323 .2203 L
.33142 .21212 L
.33333 .2102 L
.34173 .20202 L
.34343 .20038 L
.35155 .19192 L
.35354 .18974 L
.36066 .18182 L
.36364 .17836 L
.36928 .17172 L
.37374 .16629 L
.37752 .16162 L
.38384 .15356 L
.38542 .15152 L
.39306 .14141 L
.39394 .14021 L
.40046 .13131 L
.40404 .12629 L
.40763 .12121 L
.41414 .11179 L
.41461 .11111 L
.42144 .10101 L
.42424 .09677 L
.4281 .09091 L
.43434 .08122 L
.43461 .08081 L
.44102 .07071 L
.44444 .06518 L
.44728 .06061 L
.45344 .05051 L
.45455 .04865 L
.4595 .0404 L
.46465 .03166 L
.46544 .0303 L
.47132 .0202 L
.47475 .01421 L
Mistroke
.47709 .0101 L
.4828 0 L
Mfstroke
.3 g
0 .4981 m
.00308 .49495 L
.0101 .488 L
.01325 .48485 L
.0202 .4779 L
.02335 .47475 L
.0303 .4678 L
.03345 .46465 L
.0404 .4577 L
.04355 .45455 L
.05051 .44759 L
.05365 .44444 L
.06061 .43749 L
.06376 .43434 L
.07071 .42739 L
.07386 .42424 L
.08081 .41729 L
.08396 .41414 L
.09091 .40719 L
.09406 .40404 L
.10101 .39709 L
.10416 .39394 L
.11111 .38699 L
.11426 .38384 L
.12121 .37689 L
.12436 .37374 L
.13131 .36679 L
.13446 .36364 L
.14141 .35668 L
.14456 .35354 L
.15152 .34658 L
.15466 .34343 L
.16162 .33648 L
.16477 .33333 L
.17172 .32638 L
.17487 .32323 L
.18182 .31628 L
.18497 .31313 L
.19192 .30618 L
.19507 .30303 L
.20202 .29608 L
.20517 .29293 L
.21212 .28598 L
.21527 .28283 L
.22222 .27588 L
.22537 .27273 L
.23232 .26578 L
.23547 .26263 L
.24242 .25567 L
.24557 .25253 L
.25253 .24557 L
.25567 .24242 L
.26263 .23547 L
.26578 .23232 L
.27273 .22537 L
.27588 .22222 L
.28283 .21527 L
.28598 .21212 L
.29293 .20517 L
.29608 .20202 L
.30303 .19507 L
.30618 .19192 L
.31313 .18497 L
.31628 .18182 L
.32323 .17487 L
.32631 .17172 L
.33333 .16477 L
.33732 .16162 L
.34343 .15748 L
.35089 .15152 L
.35354 .14883 L
.36151 .14141 L
.36364 .13908 L
.37121 .13131 L
.37374 .12838 L
.38023 .12121 L
.38384 .11683 L
.38872 .11111 L
.39394 .10451 L
.39677 .10101 L
.40404 .09148 L
.40448 .09091 L
.41207 .08081 L
.41414 .07782 L
.41932 .07071 L
.42424 .06352 L
.42629 .06061 L
.43316 .05051 L
.43434 .04864 L
.43988 .0404 L
.44444 .03321 L
.44634 .0303 L
.45278 .0202 L
.45455 .01724 L
.45905 .0101 L
.46465 .00074 L
.46511 0 L
0 0 L
F
0 g
0 .4981 m
.00308 .49495 L
.0101 .488 L
.01325 .48485 L
.0202 .4779 L
.02335 .47475 L
.0303 .4678 L
.03345 .46465 L
.0404 .4577 L
.04355 .45455 L
.05051 .44759 L
.05365 .44444 L
.06061 .43749 L
.06376 .43434 L
.07071 .42739 L
.07386 .42424 L
.08081 .41729 L
.08396 .41414 L
.09091 .40719 L
.09406 .40404 L
.10101 .39709 L
.10416 .39394 L
.11111 .38699 L
.11426 .38384 L
.12121 .37689 L
.12436 .37374 L
.13131 .36679 L
.13446 .36364 L
.14141 .35668 L
.14456 .35354 L
.15152 .34658 L
.15466 .34343 L
.16162 .33648 L
.16477 .33333 L
.17172 .32638 L
.17487 .32323 L
.18182 .31628 L
.18497 .31313 L
.19192 .30618 L
.19507 .30303 L
.20202 .29608 L
.20517 .29293 L
.21212 .28598 L
.21527 .28283 L
.22222 .27588 L
.22537 .27273 L
.23232 .26578 L
.23547 .26263 L
.24242 .25567 L
.24557 .25253 L
Mistroke
.25253 .24557 L
.25567 .24242 L
.26263 .23547 L
.26578 .23232 L
.27273 .22537 L
.27588 .22222 L
.28283 .21527 L
.28598 .21212 L
.29293 .20517 L
.29608 .20202 L
.30303 .19507 L
.30618 .19192 L
.31313 .18497 L
.31628 .18182 L
.32323 .17487 L
.32631 .17172 L
.33333 .16477 L
.33732 .16162 L
.34343 .15748 L
.35089 .15152 L
.35354 .14883 L
.36151 .14141 L
.36364 .13908 L
.37121 .13131 L
.37374 .12838 L
.38023 .12121 L
.38384 .11683 L
.38872 .11111 L
.39394 .10451 L
.39677 .10101 L
.40404 .09148 L
.40448 .09091 L
.41207 .08081 L
.41414 .07782 L
.41932 .07071 L
.42424 .06352 L
.42629 .06061 L
.43316 .05051 L
.43434 .04864 L
.43988 .0404 L
.44444 .03321 L
.44634 .0303 L
.45278 .0202 L
.45455 .01724 L
.45905 .0101 L
.46465 .00074 L
.46511 0 L
Mfstroke
.4 g
0 .41635 m
.00259 .41414 L
.0101 .40625 L
.01231 .40404 L
.0202 .39614 L
.02241 .39394 L
.0303 .38604 L
.03251 .38384 L
.0404 .37594 L
.04261 .37374 L
.05051 .36584 L
.05271 .36364 L
.06061 .35574 L
.06281 .35354 L
.07071 .34564 L
.07291 .34343 L
.08081 .33554 L
.08301 .33333 L
.09091 .32544 L
.09311 .32323 L
.10101 .31534 L
.10322 .31313 L
.11111 .30524 L
.11332 .30303 L
.12121 .29513 L
.12342 .29293 L
.13131 .28503 L
.13352 .28283 L
.14141 .27493 L
.14362 .27273 L
.15152 .26483 L
.15372 .26263 L
.16162 .25473 L
.16382 .25253 L
.17172 .24463 L
.17392 .24242 L
.18182 .23453 L
.18402 .23232 L
.19192 .22443 L
.19412 .22222 L
.20202 .21433 L
.20423 .21212 L
.21212 .20423 L
.21433 .20202 L
.22222 .19412 L
.22443 .19192 L
.23232 .18402 L
.23453 .18182 L
.24242 .17392 L
.24463 .17172 L
.25253 .16382 L
.25473 .16162 L
.26263 .15372 L
.26483 .15152 L
.27273 .14362 L
.27493 .14141 L
.28283 .13352 L
.28503 .13131 L
.29293 .12342 L
.29513 .12121 L
.30303 .11332 L
.30524 .11111 L
.31313 .10322 L
.31534 .10101 L
.32323 .09311 L
.32566 .09091 L
.33333 .08301 L
.33509 .08081 L
.34249 .07071 L
.34343 .06939 L
.3499 .06061 L
.35354 .05563 L
.35726 .05051 L
.36364 .04167 L
.36454 .0404 L
.37169 .0303 L
.37374 .02738 L
.37871 .0202 L
.38384 .01273 L
.38561 .0101 L
.39241 0 L
0 0 L
F
0 g
0 .41635 m
.00259 .41414 L
.0101 .40625 L
.01231 .40404 L
.0202 .39614 L
.02241 .39394 L
.0303 .38604 L
.03251 .38384 L
.0404 .37594 L
.04261 .37374 L
.05051 .36584 L
.05271 .36364 L
.06061 .35574 L
.06281 .35354 L
.07071 .34564 L
.07291 .34343 L
.08081 .33554 L
.08301 .33333 L
.09091 .32544 L
.09311 .32323 L
.10101 .31534 L
.10322 .31313 L
.11111 .30524 L
.11332 .30303 L
.12121 .29513 L
.12342 .29293 L
.13131 .28503 L
.13352 .28283 L
.14141 .27493 L
.14362 .27273 L
.15152 .26483 L
.15372 .26263 L
.16162 .25473 L
.16382 .25253 L
.17172 .24463 L
.17392 .24242 L
.18182 .23453 L
.18402 .23232 L
.19192 .22443 L
.19412 .22222 L
.20202 .21433 L
.20423 .21212 L
.21212 .20423 L
.21433 .20202 L
.22222 .19412 L
.22443 .19192 L
.23232 .18402 L
.23453 .18182 L
.24242 .17392 L
.24463 .17172 L
Mistroke
.25253 .16382 L
.25473 .16162 L
.26263 .15372 L
.26483 .15152 L
.27273 .14362 L
.27493 .14141 L
.28283 .13352 L
.28503 .13131 L
.29293 .12342 L
.29513 .12121 L
.30303 .11332 L
.30524 .11111 L
.31313 .10322 L
.31534 .10101 L
.32323 .09311 L
.32566 .09091 L
.33333 .08301 L
.33509 .08081 L
.34249 .07071 L
.34343 .06939 L
.3499 .06061 L
.35354 .05563 L
.35726 .05051 L
.36364 .04167 L
.36454 .0404 L
.37169 .0303 L
.37374 .02738 L
.37871 .0202 L
.38384 .01273 L
.38561 .0101 L
.39241 0 L
Mfstroke
.5 g
0 .37092 m
.00729 .36364 L
.0101 .36082 L
.01739 .35354 L
.0202 .35072 L
.02749 .34343 L
.0303 .34062 L
.03759 .33333 L
.0404 .33052 L
.04769 .32323 L
.05051 .32042 L
.05779 .31313 L
.06061 .31031 L
.06789 .30303 L
.07071 .30021 L
.07799 .29293 L
.08081 .29011 L
.08809 .28283 L
.09091 .28001 L
.09819 .27273 L
.10101 .26991 L
.10829 .26263 L
.11111 .25981 L
.1184 .25253 L
.12121 .24971 L
.1285 .24242 L
.13131 .23961 L
.1386 .23232 L
.14141 .22951 L
.1487 .22222 L
.15152 .21941 L
.1588 .21212 L
.16162 .2093 L
.1689 .20202 L
.17172 .1992 L
.179 .19192 L
.18182 .1891 L
.1891 .18182 L
.19192 .179 L
.1992 .17172 L
.20202 .1689 L
.2093 .16162 L
.21212 .1588 L
.21941 .15152 L
.22222 .1487 L
.22951 .14141 L
.23232 .1386 L
.23961 .13131 L
.24242 .1285 L
.24971 .12121 L
.25253 .1184 L
.25981 .11111 L
.26263 .10829 L
.26991 .10101 L
.27273 .09819 L
.28001 .09091 L
.28283 .08809 L
.29011 .08081 L
.29293 .07799 L
.30021 .07071 L
.30303 .06789 L
.31031 .06061 L
.31313 .05779 L
.32042 .05051 L
.32323 .04769 L
.33059 .0404 L
.33333 .03759 L
.34 .0303 L
.34343 .02646 L
.34889 .0202 L
.35354 .01472 L
.35738 .0101 L
.36364 .00239 L
.36554 0 L
0 0 L
F
0 g
0 .37092 m
.00729 .36364 L
.0101 .36082 L
.01739 .35354 L
.0202 .35072 L
.02749 .34343 L
.0303 .34062 L
.03759 .33333 L
.0404 .33052 L
.04769 .32323 L
.05051 .32042 L
.05779 .31313 L
.06061 .31031 L
.06789 .30303 L
.07071 .30021 L
.07799 .29293 L
.08081 .29011 L
.08809 .28283 L
.09091 .28001 L
.09819 .27273 L
.10101 .26991 L
.10829 .26263 L
.11111 .25981 L
.1184 .25253 L
.12121 .24971 L
.1285 .24242 L
.13131 .23961 L
.1386 .23232 L
.14141 .22951 L
.1487 .22222 L
.15152 .21941 L
.1588 .21212 L
.16162 .2093 L
.1689 .20202 L
.17172 .1992 L
.179 .19192 L
.18182 .1891 L
.1891 .18182 L
.19192 .179 L
.1992 .17172 L
.20202 .1689 L
.2093 .16162 L
.21212 .1588 L
.21941 .15152 L
.22222 .1487 L
.22951 .14141 L
.23232 .1386 L
.23961 .13131 L
.24242 .1285 L
.24971 .12121 L
Mistroke
.25253 .1184 L
.25981 .11111 L
.26263 .10829 L
.26991 .10101 L
.27273 .09819 L
.28001 .09091 L
.28283 .08809 L
.29011 .08081 L
.29293 .07799 L
.30021 .07071 L
.30303 .06789 L
.31031 .06061 L
.31313 .05779 L
.32042 .05051 L
.32323 .04769 L
.33059 .0404 L
.33333 .03759 L
.34 .0303 L
.34343 .02646 L
.34889 .0202 L
.35354 .01472 L
.35738 .0101 L
.36364 .00239 L
.36554 0 L
Mfstroke
.6 g
0 .33409 m
.00076 .33333 L
.0101 .32399 L
.01086 .32323 L
.0202 .31389 L
.02096 .31313 L
.0303 .30379 L
.03106 .30303 L
.0404 .29369 L
.04116 .29293 L
.05051 .28359 L
.05126 .28283 L
.06061 .27349 L
.06137 .27273 L
.07071 .26339 L
.07147 .26263 L
.08081 .25328 L
.08157 .25253 L
.09091 .24318 L
.09167 .24242 L
.10101 .23308 L
.10177 .23232 L
.11111 .22298 L
.11187 .22222 L
.12121 .21288 L
.12197 .21212 L
.13131 .20278 L
.13207 .20202 L
.14141 .19268 L
.14217 .19192 L
.15152 .18258 L
.15227 .18182 L
.16162 .17248 L
.16238 .17172 L
.17172 .16238 L
.17248 .16162 L
.18182 .15227 L
.18258 .15152 L
.19192 .14217 L
.19268 .14141 L
.20202 .13207 L
.20278 .13131 L
.21212 .12197 L
.21288 .12121 L
.22222 .11187 L
.22298 .11111 L
.23232 .10177 L
.23308 .10101 L
.24242 .09167 L
.24318 .09091 L
.25253 .08157 L
.25328 .08081 L
.26263 .07147 L
.26339 .07071 L
.27273 .06137 L
.27349 .06061 L
.28283 .05126 L
.28359 .05051 L
.29293 .04116 L
.29369 .0404 L
.30303 .03106 L
.30379 .0303 L
.31313 .02096 L
.31389 .0202 L
.32323 .01086 L
.324 .0101 L
.33333 .00076 L
.3341 0 L
0 0 L
F
0 g
0 .33409 m
.00076 .33333 L
.0101 .32399 L
.01086 .32323 L
.0202 .31389 L
.02096 .31313 L
.0303 .30379 L
.03106 .30303 L
.0404 .29369 L
.04116 .29293 L
.05051 .28359 L
.05126 .28283 L
.06061 .27349 L
.06137 .27273 L
.07071 .26339 L
.07147 .26263 L
.08081 .25328 L
.08157 .25253 L
.09091 .24318 L
.09167 .24242 L
.10101 .23308 L
.10177 .23232 L
.11111 .22298 L
.11187 .22222 L
.12121 .21288 L
.12197 .21212 L
.13131 .20278 L
.13207 .20202 L
.14141 .19268 L
.14217 .19192 L
.15152 .18258 L
.15227 .18182 L
.16162 .17248 L
.16238 .17172 L
.17172 .16238 L
.17248 .16162 L
.18182 .15227 L
.18258 .15152 L
.19192 .14217 L
.19268 .14141 L
.20202 .13207 L
.20278 .13131 L
.21212 .12197 L
.21288 .12121 L
.22222 .11187 L
.22298 .11111 L
.23232 .10177 L
.23308 .10101 L
.24242 .09167 L
.24318 .09091 L
Mistroke
.25253 .08157 L
.25328 .08081 L
.26263 .07147 L
.26339 .07071 L
.27273 .06137 L
.27349 .06061 L
.28283 .05126 L
.28359 .05051 L
.29293 .04116 L
.29369 .0404 L
.30303 .03106 L
.30379 .0303 L
.31313 .02096 L
.31389 .0202 L
.32323 .01086 L
.324 .0101 L
.33333 .00076 L
.3341 0 L
Mfstroke
.7 g
0 .28868 m
.00576 .28283 L
.0101 .27858 L
.01595 .27273 L
.0202 .26847 L
.02605 .26263 L
.0303 .25837 L
.03615 .25253 L
.0404 .24827 L
.04625 .24242 L
.05051 .23817 L
.05635 .23232 L
.06061 .22807 L
.06645 .22222 L
.07071 .21797 L
.07656 .21212 L
.08081 .20787 L
.08666 .20202 L
.09091 .19777 L
.09676 .19192 L
.10101 .18767 L
.10686 .18182 L
.11111 .17757 L
.11696 .17172 L
.12121 .16746 L
.12706 .16162 L
.13131 .15736 L
.13716 .15152 L
.14141 .14726 L
.14726 .14141 L
.15152 .13716 L
.15736 .13131 L
.16162 .12706 L
.16746 .12121 L
.17172 .11696 L
.17757 .11111 L
.18182 .10686 L
.18767 .10101 L
.19192 .09676 L
.19777 .09091 L
.20202 .08666 L
.20787 .08081 L
.21212 .07656 L
.21797 .07071 L
.22222 .06645 L
.22807 .06061 L
.23232 .05635 L
.23817 .05051 L
.24242 .04625 L
.24827 .0404 L
.25253 .03615 L
.25837 .0303 L
.26263 .02605 L
.26847 .0202 L
.27273 .01595 L
.27858 .0101 L
.28283 .00576 L
.28868 0 L
0 0 L
F
0 g
0 .28868 m
.00576 .28283 L
.0101 .27858 L
.01595 .27273 L
.0202 .26847 L
.02605 .26263 L
.0303 .25837 L
.03615 .25253 L
.0404 .24827 L
.04625 .24242 L
.05051 .23817 L
.05635 .23232 L
.06061 .22807 L
.06645 .22222 L
.07071 .21797 L
.07656 .21212 L
.08081 .20787 L
.08666 .20202 L
.09091 .19777 L
.09676 .19192 L
.10101 .18767 L
.10686 .18182 L
.11111 .17757 L
.11696 .17172 L
.12121 .16746 L
.12706 .16162 L
.13131 .15736 L
.13716 .15152 L
.14141 .14726 L
.14726 .14141 L
.15152 .13716 L
.15736 .13131 L
.16162 .12706 L
.16746 .12121 L
.17172 .11696 L
.17757 .11111 L
.18182 .10686 L
.18767 .10101 L
.19192 .09676 L
.19777 .09091 L
.20202 .08666 L
.20787 .08081 L
.21212 .07656 L
.21797 .07071 L
.22222 .06645 L
.22807 .06061 L
.23232 .05635 L
.23817 .05051 L
.24242 .04625 L
.24827 .0404 L
Mistroke
.25253 .03615 L
.25837 .0303 L
.26263 .02605 L
.26847 .0202 L
.27273 .01595 L
.27858 .0101 L
.28283 .00576 L
.28868 0 L
Mfstroke
.6 g
0 .2069 m
.00519 .20202 L
.0101 .1968 L
.01498 .19192 L
.0202 .1867 L
.02508 .18182 L
.0303 .1766 L
.03518 .17172 L
.0404 .1665 L
.04528 .16162 L
.05051 .1564 L
.05539 .15152 L
.06061 .14629 L
.06549 .14141 L
.07071 .13619 L
.07559 .13131 L
.08081 .12609 L
.08569 .12121 L
.09091 .11599 L
.09579 .11111 L
.10101 .10589 L
.10589 .10101 L
.11111 .09579 L
.11599 .09091 L
.12121 .08569 L
.12609 .08081 L
.13131 .07559 L
.13619 .07071 L
.14141 .06549 L
.14629 .06061 L
.15152 .05539 L
.1564 .05051 L
.16162 .04528 L
.1665 .0404 L
.17172 .03518 L
.1766 .0303 L
.18182 .02508 L
.1867 .0202 L
.19192 .01498 L
.1968 .0101 L
.20202 .00519 L
.2069 0 L
0 0 L
F
0 g
0 .2069 m
.00519 .20202 L
.0101 .1968 L
.01498 .19192 L
.0202 .1867 L
.02508 .18182 L
.0303 .1766 L
.03518 .17172 L
.0404 .1665 L
.04528 .16162 L
.05051 .1564 L
.05539 .15152 L
.06061 .14629 L
.06549 .14141 L
.07071 .13619 L
.07559 .13131 L
.08081 .12609 L
.08569 .12121 L
.09091 .11599 L
.09579 .11111 L
.10101 .10589 L
.10589 .10101 L
.11111 .09579 L
.11599 .09091 L
.12121 .08569 L
.12609 .08081 L
.13131 .07559 L
.13619 .07071 L
.14141 .06549 L
.14629 .06061 L
.15152 .05539 L
.1564 .05051 L
.16162 .04528 L
.1665 .0404 L
.17172 .03518 L
.1766 .0303 L
.18182 .02508 L
.1867 .0202 L
.19192 .01498 L
.1968 .0101 L
.20202 .00519 L
.2069 0 L
s
.5 g
0 .16148 m
.00997 .15152 L
.0101 .15138 L
.02007 .14141 L
.0202 .14128 L
.03017 .13131 L
.0303 .13118 L
.04027 .12121 L
.0404 .12108 L
.05037 .11111 L
.05051 .11098 L
.06047 .10101 L
.06061 .10088 L
.07057 .09091 L
.07071 .09078 L
.08067 .08081 L
.08081 .08067 L
.09078 .07071 L
.09091 .07057 L
.10088 .06061 L
.10101 .06047 L
.11098 .05051 L
.11111 .05037 L
.12108 .0404 L
.12121 .04027 L
.13118 .0303 L
.13131 .03017 L
.14128 .0202 L
.14141 .02007 L
.15138 .0101 L
.15152 .00997 L
.16148 0 L
0 0 L
F
0 g
0 .16148 m
.00997 .15152 L
.0101 .15138 L
.02007 .14141 L
.0202 .14128 L
.03017 .13131 L
.0303 .13118 L
.04027 .12121 L
.0404 .12108 L
.05037 .11111 L
.05051 .11098 L
.06047 .10101 L
.06061 .10088 L
.07057 .09091 L
.07071 .09078 L
.08067 .08081 L
.08081 .08067 L
.09078 .07071 L
.09091 .07057 L
.10088 .06061 L
.10101 .06047 L
.11098 .05051 L
.11111 .05037 L
.12108 .0404 L
.12121 .04027 L
.13118 .0303 L
.13131 .03017 L
.14128 .0202 L
.14141 .02007 L
.15138 .0101 L
.15152 .00997 L
.16148 0 L
s
.4 g
0 .12465 m
.00344 .12121 L
.0101 .11455 L
.01354 .11111 L
.0202 .10445 L
.02364 .10101 L
.0303 .09435 L
.03375 .09091 L
.0404 .08425 L
.04385 .08081 L
.05051 .07415 L
.05395 .07071 L
.06061 .06405 L
.06405 .06061 L
.07071 .05395 L
.07415 .05051 L
.08081 .04385 L
.08425 .0404 L
.09091 .03375 L
.09435 .0303 L
.10101 .02364 L
.10445 .0202 L
.11111 .01354 L
.11455 .0101 L
.12121 .00344 L
.12465 0 L
0 0 L
F
0 g
0 .12465 m
.00344 .12121 L
.0101 .11455 L
.01354 .11111 L
.0202 .10445 L
.02364 .10101 L
.0303 .09435 L
.03375 .09091 L
.0404 .08425 L
.04385 .08081 L
.05051 .07415 L
.05395 .07071 L
.06061 .06405 L
.06405 .06061 L
.07071 .05395 L
.07415 .05051 L
.08081 .04385 L
.08425 .0404 L
.09091 .03375 L
.09435 .0303 L
.10101 .02364 L
.10445 .0202 L
.11111 .01354 L
.11455 .0101 L
.12121 .00344 L
.12465 0 L
s
.3 g
0 .07922 m
.00846 .07071 L
.0101 .06912 L
.01861 .06061 L
.0202 .05902 L
.02872 .05051 L
.0303 .04892 L
.03882 .0404 L
.0404 .03882 L
.04892 .0303 L
.05051 .02872 L
.05902 .0202 L
.06061 .01861 L
.06912 .0101 L
.07071 .00846 L
.07922 0 L
0 0 L
F
0 g
0 .07922 m
.00846 .07071 L
.0101 .06912 L
.01861 .06061 L
.0202 .05902 L
.02872 .05051 L
.0303 .04892 L
.03882 .0404 L
.0404 .03882 L
.04892 .0303 L
.05051 .02872 L
.05902 .0202 L
.06061 .01861 L
.06912 .0101 L
.07071 .00846 L
.07922 0 L
s
.7 g
.04466 1 m
.05051 .99424 L
.05476 .9899 L
.06061 .98405 L
.06486 .9798 L
.07071 .97395 L
.07496 .9697 L
.08081 .96385 L
.08506 .9596 L
.09091 .95375 L
.09516 .94949 L
.10101 .94365 L
.10526 .93939 L
.11111 .93355 L
.11536 .92929 L
.12121 .92344 L
.12546 .91919 L
.13131 .91334 L
.13557 .90909 L
.14141 .90324 L
.14567 .89899 L
.15152 .89314 L
.15577 .88889 L
.16162 .88304 L
.16587 .87879 L
.17172 .87294 L
.17597 .86869 L
.18182 .86284 L
.18607 .85859 L
.19192 .85274 L
.19617 .84848 L
.20202 .84264 L
.20627 .83838 L
.21212 .83254 L
.21637 .82828 L
.22222 .82243 L
.22647 .81818 L
.23232 .81233 L
.23658 .80808 L
.24242 .80223 L
.24668 .79798 L
.25253 .79213 L
.25678 .78788 L
.26263 .78203 L
.26688 .77778 L
.27273 .77193 L
.27698 .76768 L
.28283 .76183 L
.28708 .75758 L
.29293 .75173 L
.29718 .74747 L
.30303 .74163 L
.30728 .73737 L
.31313 .73153 L
.31738 .72727 L
.32323 .72142 L
.3278 .71717 L
.33333 .71132 L
.33664 .70707 L
.34343 .69771 L
.34398 .69697 L
.35141 .68687 L
.35354 .68396 L
.35875 .67677 L
.36364 .66998 L
.366 .66667 L
.37314 .65657 L
.37374 .65571 L
.38013 .64646 L
.38384 .64105 L
.387 .63636 L
.39378 .62626 L
.39394 .62603 L
.4004 .61616 L
.40404 .61057 L
.40692 .60606 L
.41336 .59596 L
.41414 .59473 L
.41965 .58586 L
.42424 .57846 L
.42587 .57576 L
.43201 .56566 L
.43434 .56179 L
.43802 .55556 L
.44401 .54545 L
.44444 .54472 L
.44984 .53535 L
.45455 .52722 L
.45565 .52525 L
.46136 .51515 L
.46465 .50933 L
.46699 .50505 L
.4726 .49495 L
.47475 .49106 L
.47808 .48485 L
.48357 .47475 L
.48485 .47239 L
.48892 .46465 L
.49431 .45455 L
.49495 .45334 L
.49953 .44444 L
.50482 .43434 L
.50505 .4339 L
.50993 .42424 L
.51513 .41414 L
.51515 .41409 L
.52014 .40404 L
.52524 .39394 L
.52525 .39392 L
.53016 .38384 L
.53517 .37374 L
.53535 .37337 L
.54 .36364 L
.54494 .35354 L
.54545 .35247 L
.54969 .34343 L
.55454 .33333 L
.55556 .33122 L
.55922 .32323 L
.564 .31313 L
.56566 .30961 L
.56861 .30303 L
.57331 .29293 L
.57576 .28766 L
.57788 .28283 L
.58249 .27273 L
.58586 .26538 L
.58704 .26263 L
.59154 .25253 L
.59596 .24277 L
.5961 .24242 L
.60048 .23232 L
.60499 .22222 L
.60606 .21982 L
.60931 .21212 L
.61375 .20202 L
.61616 .19654 L
.61805 .19192 L
.6224 .18182 L
.62626 .17294 L
.62675 .17172 L
.63096 .16162 L
.6353 .15152 L
.63636 .14903 L
.63943 .14141 L
.64371 .13131 L
.64646 .12479 L
.64786 .12121 L
.65202 .11111 L
.65625 .10101 L
.65657 .10026 L
.66025 .09091 L
.66444 .08081 L
.66667 .07541 L
.66845 .07071 L
.67253 .06061 L
.67667 .05051 L
.67677 .05026 L
.68056 .0404 L
.68465 .0303 L
.68687 .0248 L
.68856 .0202 L
.69254 .0101 L
.6966 0 L
1 0 L
1 1 L
F
0 g
.04466 1 m
.05051 .99424 L
.05476 .9899 L
.06061 .98405 L
.06486 .9798 L
.07071 .97395 L
.07496 .9697 L
.08081 .96385 L
.08506 .9596 L
.09091 .95375 L
.09516 .94949 L
.10101 .94365 L
.10526 .93939 L
.11111 .93355 L
.11536 .92929 L
.12121 .92344 L
.12546 .91919 L
.13131 .91334 L
.13557 .90909 L
.14141 .90324 L
.14567 .89899 L
.15152 .89314 L
.15577 .88889 L
.16162 .88304 L
.16587 .87879 L
.17172 .87294 L
.17597 .86869 L
.18182 .86284 L
.18607 .85859 L
.19192 .85274 L
.19617 .84848 L
.20202 .84264 L
.20627 .83838 L
.21212 .83254 L
.21637 .82828 L
.22222 .82243 L
.22647 .81818 L
.23232 .81233 L
.23658 .80808 L
.24242 .80223 L
.24668 .79798 L
.25253 .79213 L
.25678 .78788 L
.26263 .78203 L
.26688 .77778 L
.27273 .77193 L
.27698 .76768 L
.28283 .76183 L
.28708 .75758 L
.29293 .75173 L
Mistroke
.29718 .74747 L
.30303 .74163 L
.30728 .73737 L
.31313 .73153 L
.31738 .72727 L
.32323 .72142 L
.3278 .71717 L
.33333 .71132 L
.33664 .70707 L
.34343 .69771 L
.34398 .69697 L
.35141 .68687 L
.35354 .68396 L
.35875 .67677 L
.36364 .66998 L
.366 .66667 L
.37314 .65657 L
.37374 .65571 L
.38013 .64646 L
.38384 .64105 L
.387 .63636 L
.39378 .62626 L
.39394 .62603 L
.4004 .61616 L
.40404 .61057 L
.40692 .60606 L
.41336 .59596 L
.41414 .59473 L
.41965 .58586 L
.42424 .57846 L
.42587 .57576 L
.43201 .56566 L
.43434 .56179 L
.43802 .55556 L
.44401 .54545 L
.44444 .54472 L
.44984 .53535 L
.45455 .52722 L
.45565 .52525 L
.46136 .51515 L
.46465 .50933 L
.46699 .50505 L
.4726 .49495 L
.47475 .49106 L
.47808 .48485 L
.48357 .47475 L
.48485 .47239 L
.48892 .46465 L
.49431 .45455 L
.49495 .45334 L
Mistroke
.49953 .44444 L
.50482 .43434 L
.50505 .4339 L
.50993 .42424 L
.51513 .41414 L
.51515 .41409 L
.52014 .40404 L
.52524 .39394 L
.52525 .39392 L
.53016 .38384 L
.53517 .37374 L
.53535 .37337 L
.54 .36364 L
.54494 .35354 L
.54545 .35247 L
.54969 .34343 L
.55454 .33333 L
.55556 .33122 L
.55922 .32323 L
.564 .31313 L
.56566 .30961 L
.56861 .30303 L
.57331 .29293 L
.57576 .28766 L
.57788 .28283 L
.58249 .27273 L
.58586 .26538 L
.58704 .26263 L
.59154 .25253 L
.59596 .24277 L
.5961 .24242 L
.60048 .23232 L
.60499 .22222 L
.60606 .21982 L
.60931 .21212 L
.61375 .20202 L
.61616 .19654 L
.61805 .19192 L
.6224 .18182 L
.62626 .17294 L
.62675 .17172 L
.63096 .16162 L
.6353 .15152 L
.63636 .14903 L
.63943 .14141 L
.64371 .13131 L
.64646 .12479 L
.64786 .12121 L
.65202 .11111 L
.65625 .10101 L
Mistroke
.65657 .10026 L
.66025 .09091 L
.66444 .08081 L
.66667 .07541 L
.66845 .07071 L
.67253 .06061 L
.67667 .05051 L
.67677 .05026 L
.68056 .0404 L
.68465 .0303 L
.68687 .0248 L
.68856 .0202 L
.69254 .0101 L
.6966 0 L
Mfstroke
.6 g
.12643 1 m
.13131 .99481 L
.13653 .9899 L
.14141 .98502 L
.14663 .9798 L
.15152 .97492 L
.15674 .9697 L
.16162 .96482 L
.16684 .9596 L
.17172 .95472 L
.17694 .94949 L
.18182 .94461 L
.18704 .93939 L
.19192 .93451 L
.19714 .92929 L
.20202 .92441 L
.20724 .91919 L
.21212 .91431 L
.21734 .90909 L
.22222 .90421 L
.22744 .89899 L
.23232 .89411 L
.23754 .88889 L
.24242 .88401 L
.24765 .87879 L
.25253 .87391 L
.25775 .86869 L
.26263 .86381 L
.26785 .85859 L
.27273 .85371 L
.27795 .84848 L
.28283 .8436 L
.28805 .83838 L
.29293 .8335 L
.29815 .82828 L
.30303 .8234 L
.30825 .81818 L
.31313 .8133 L
.31835 .80808 L
.32323 .8032 L
.32834 .79798 L
.33333 .7931 L
.34023 .78788 L
.34343 .78579 L
.35297 .77778 L
.35354 .77713 L
.36338 .76768 L
.36364 .76738 L
.373 .75758 L
.37374 .75668 L
.38197 .74747 L
.38384 .74515 L
.39041 .73737 L
.39394 .73284 L
.39842 .72727 L
.40404 .71981 L
.40607 .71717 L
.4135 .70707 L
.41414 .70613 L
.42078 .69697 L
.42424 .69184 L
.42773 .68687 L
.43434 .67695 L
.43447 .67677 L
.44123 .66667 L
.44444 .66153 L
.44768 .65657 L
.45401 .64646 L
.45455 .64555 L
.46032 .63636 L
.46465 .62907 L
.46637 .62626 L
.47246 .61616 L
.47475 .61211 L
.47835 .60606 L
.48414 .59596 L
.48485 .59465 L
.48994 .58586 L
.49495 .57674 L
.4955 .57576 L
.50119 .56566 L
.50505 .55838 L
.50662 .55556 L
.51214 .54545 L
.51515 .53959 L
.51745 .53535 L
.52282 .52525 L
.52525 .52037 L
.52802 .51515 L
.53326 .50505 L
.53535 .50074 L
.53836 .49495 L
.54349 .48485 L
.54545 .48071 L
.54849 .47475 L
.55352 .46465 L
.55556 .46028 L
.55842 .45455 L
.56337 .44444 L
.56566 .43946 L
.56817 .43434 L
.57305 .42424 L
.57576 .41826 L
.57774 .41414 L
.58257 .40404 L
.58586 .39669 L
.58716 .39394 L
.59193 .38384 L
.59596 .37475 L
.59643 .37374 L
.60115 .36364 L
.60562 .35354 L
.60606 .35246 L
.61021 .34343 L
.61472 .33333 L
.61616 .32982 L
.61915 .32323 L
.62366 .31313 L
.62626 .30683 L
.62796 .30303 L
.63245 .29293 L
.63636 .28349 L
.63666 .28283 L
.64111 .27273 L
.64538 .26263 L
.64646 .25983 L
.64964 .25253 L
.65397 .24242 L
.65657 .23584 L
.65807 .23232 L
.66239 .22222 L
.66644 .21212 L
.66667 .21151 L
.67069 .20202 L
.67486 .19192 L
.67677 .18687 L
.67888 .18182 L
.68309 .17172 L
.68687 .1619 L
.68699 .16162 L
.69117 .15152 L
.69522 .14141 L
.69697 .13663 L
.69914 .13131 L
.70325 .12121 L
.70705 .11111 L
.70707 .11105 L
.71113 .10101 L
.71512 .09091 L
.71717 .08517 L
.71891 .08081 L
.72294 .07071 L
.72673 .06061 L
.72727 .05898 L
.73062 .05051 L
.73457 .0404 L
.73737 .03249 L
.73823 .0303 L
.74218 .0202 L
.74599 .0101 L
.74747 .0057 L
.74968 0 L
1 0 L
1 1 L
F
0 g
.12643 1 m
.13131 .99481 L
.13653 .9899 L
.14141 .98502 L
.14663 .9798 L
.15152 .97492 L
.15674 .9697 L
.16162 .96482 L
.16684 .9596 L
.17172 .95472 L
.17694 .94949 L
.18182 .94461 L
.18704 .93939 L
.19192 .93451 L
.19714 .92929 L
.20202 .92441 L
.20724 .91919 L
.21212 .91431 L
.21734 .90909 L
.22222 .90421 L
.22744 .89899 L
.23232 .89411 L
.23754 .88889 L
.24242 .88401 L
.24765 .87879 L
.25253 .87391 L
.25775 .86869 L
.26263 .86381 L
.26785 .85859 L
.27273 .85371 L
.27795 .84848 L
.28283 .8436 L
.28805 .83838 L
.29293 .8335 L
.29815 .82828 L
.30303 .8234 L
.30825 .81818 L
.31313 .8133 L
.31835 .80808 L
.32323 .8032 L
.32834 .79798 L
.33333 .7931 L
.34023 .78788 L
.34343 .78579 L
.35297 .77778 L
.35354 .77713 L
.36338 .76768 L
.36364 .76738 L
.373 .75758 L
.37374 .75668 L
Mistroke
.38197 .74747 L
.38384 .74515 L
.39041 .73737 L
.39394 .73284 L
.39842 .72727 L
.40404 .71981 L
.40607 .71717 L
.4135 .70707 L
.41414 .70613 L
.42078 .69697 L
.42424 .69184 L
.42773 .68687 L
.43434 .67695 L
.43447 .67677 L
.44123 .66667 L
.44444 .66153 L
.44768 .65657 L
.45401 .64646 L
.45455 .64555 L
.46032 .63636 L
.46465 .62907 L
.46637 .62626 L
.47246 .61616 L
.47475 .61211 L
.47835 .60606 L
.48414 .59596 L
.48485 .59465 L
.48994 .58586 L
.49495 .57674 L
.4955 .57576 L
.50119 .56566 L
.50505 .55838 L
.50662 .55556 L
.51214 .54545 L
.51515 .53959 L
.51745 .53535 L
.52282 .52525 L
.52525 .52037 L
.52802 .51515 L
.53326 .50505 L
.53535 .50074 L
.53836 .49495 L
.54349 .48485 L
.54545 .48071 L
.54849 .47475 L
.55352 .46465 L
.55556 .46028 L
.55842 .45455 L
.56337 .44444 L
.56566 .43946 L
Mistroke
.56817 .43434 L
.57305 .42424 L
.57576 .41826 L
.57774 .41414 L
.58257 .40404 L
.58586 .39669 L
.58716 .39394 L
.59193 .38384 L
.59596 .37475 L
.59643 .37374 L
.60115 .36364 L
.60562 .35354 L
.60606 .35246 L
.61021 .34343 L
.61472 .33333 L
.61616 .32982 L
.61915 .32323 L
.62366 .31313 L
.62626 .30683 L
.62796 .30303 L
.63245 .29293 L
.63636 .28349 L
.63666 .28283 L
.64111 .27273 L
.64538 .26263 L
.64646 .25983 L
.64964 .25253 L
.65397 .24242 L
.65657 .23584 L
.65807 .23232 L
.66239 .22222 L
.66644 .21212 L
.66667 .21151 L
.67069 .20202 L
.67486 .19192 L
.67677 .18687 L
.67888 .18182 L
.68309 .17172 L
.68687 .1619 L
.68699 .16162 L
.69117 .15152 L
.69522 .14141 L
.69697 .13663 L
.69914 .13131 L
.70325 .12121 L
.70705 .11111 L
.70707 .11105 L
.71113 .10101 L
.71512 .09091 L
.71717 .08517 L
Mistroke
.71891 .08081 L
.72294 .07071 L
.72673 .06061 L
.72727 .05898 L
.73062 .05051 L
.73457 .0404 L
.73737 .03249 L
.73823 .0303 L
.74218 .0202 L
.74599 .0101 L
.74747 .0057 L
.74968 0 L
Mfstroke
.5 g
.17185 1 m
.18182 .99003 L
.18195 .9899 L
.19192 .97993 L
.19205 .9798 L
.20202 .96983 L
.20215 .9697 L
.21212 .95973 L
.21225 .9596 L
.22222 .94963 L
.22236 .94949 L
.23232 .93953 L
.23246 .93939 L
.24242 .92943 L
.24256 .92929 L
.25253 .91933 L
.25266 .91919 L
.26263 .90922 L
.26276 .90909 L
.27273 .89912 L
.27286 .89899 L
.28283 .88902 L
.28296 .88889 L
.29293 .87892 L
.29306 .87879 L
.30303 .86882 L
.30316 .86869 L
.31313 .85872 L
.31326 .85859 L
.32323 .84862 L
.32337 .84848 L
.33333 .83852 L
.33347 .83838 L
.34343 .8287 L
.34385 .82828 L
.35343 .81818 L
.35354 .81806 L
.36244 .80808 L
.36364 .80668 L
.37099 .79798 L
.37374 .7946 L
.37916 .78788 L
.38384 .78188 L
.387 .77778 L
.39394 .76853 L
.39457 .76768 L
.40193 .75758 L
.40404 .7546 L
.40907 .74747 L
.41414 .74011 L
.41602 .73737 L
.4228 .72727 L
.42424 .72509 L
.42944 .71717 L
.43434 .70954 L
.43593 .70707 L
.4423 .69697 L
.44444 .6935 L
.44855 .68687 L
.45455 .67697 L
.45467 .67677 L
.46072 .66667 L
.46465 .65998 L
.46665 .65657 L
.4725 .64646 L
.47475 .64252 L
.47827 .63636 L
.48394 .62626 L
.48485 .62463 L
.48956 .61616 L
.49495 .6063 L
.49508 .60606 L
.50057 .59596 L
.50505 .58755 L
.50595 .58586 L
.51131 .57576 L
.51515 .56839 L
.51658 .56566 L
.52182 .55556 L
.52525 .54882 L
.52698 .54545 L
.53211 .53535 L
.53535 .52886 L
.53717 .52525 L
.5422 .51515 L
.54545 .50851 L
.54716 .50505 L
.55211 .49495 L
.55556 .48779 L
.55698 .48485 L
.56184 .47475 L
.56566 .46669 L
.56663 .46465 L
.57141 .45455 L
.57576 .44522 L
.57612 .44444 L
.58083 .43434 L
.58547 .42424 L
.58586 .42339 L
.59011 .41414 L
.5947 .40404 L
.59596 .40122 L
.59925 .39394 L
.60379 .38384 L
.60606 .37869 L
.60827 .37374 L
.61275 .36364 L
.61616 .35582 L
.61717 .35354 L
.6216 .34343 L
.62596 .33333 L
.62626 .33261 L
.63033 .32323 L
.63465 .31313 L
.63636 .30907 L
.63895 .30303 L
.64324 .29293 L
.64646 .2852 L
.64747 .28283 L
.65172 .27273 L
.65591 .26263 L
.65657 .26101 L
.6601 .25253 L
.66427 .24242 L
.66667 .2365 L
.66838 .23232 L
.67253 .22222 L
.67659 .21212 L
.67677 .21168 L
.68069 .20202 L
.68475 .19192 L
.68687 .18654 L
.68876 .18182 L
.6928 .17172 L
.69677 .16162 L
.69697 .1611 L
.70077 .15152 L
.70474 .14141 L
.70707 .13536 L
.70865 .13131 L
.7126 .12121 L
.71649 .11111 L
.71717 .10931 L
.72039 .10101 L
.72428 .09091 L
.72727 .08297 L
.7281 .08081 L
.73197 .07071 L
.73579 .06061 L
.73737 .05634 L
.73958 .05051 L
.7434 .0404 L
.74715 .0303 L
.74747 .02941 L
.75093 .0202 L
.7547 .0101 L
.75758 .0022 L
.75839 0 L
1 0 L
1 1 L
F
0 g
.17185 1 m
.18182 .99003 L
.18195 .9899 L
.19192 .97993 L
.19205 .9798 L
.20202 .96983 L
.20215 .9697 L
.21212 .95973 L
.21225 .9596 L
.22222 .94963 L
.22236 .94949 L
.23232 .93953 L
.23246 .93939 L
.24242 .92943 L
.24256 .92929 L
.25253 .91933 L
.25266 .91919 L
.26263 .90922 L
.26276 .90909 L
.27273 .89912 L
.27286 .89899 L
.28283 .88902 L
.28296 .88889 L
.29293 .87892 L
.29306 .87879 L
.30303 .86882 L
.30316 .86869 L
.31313 .85872 L
.31326 .85859 L
.32323 .84862 L
.32337 .84848 L
.33333 .83852 L
.33347 .83838 L
.34343 .8287 L
.34385 .82828 L
.35343 .81818 L
.35354 .81806 L
.36244 .80808 L
.36364 .80668 L
.37099 .79798 L
.37374 .7946 L
.37916 .78788 L
.38384 .78188 L
.387 .77778 L
.39394 .76853 L
.39457 .76768 L
.40193 .75758 L
.40404 .7546 L
.40907 .74747 L
.41414 .74011 L
Mistroke
.41602 .73737 L
.4228 .72727 L
.42424 .72509 L
.42944 .71717 L
.43434 .70954 L
.43593 .70707 L
.4423 .69697 L
.44444 .6935 L
.44855 .68687 L
.45455 .67697 L
.45467 .67677 L
.46072 .66667 L
.46465 .65998 L
.46665 .65657 L
.4725 .64646 L
.47475 .64252 L
.47827 .63636 L
.48394 .62626 L
.48485 .62463 L
.48956 .61616 L
.49495 .6063 L
.49508 .60606 L
.50057 .59596 L
.50505 .58755 L
.50595 .58586 L
.51131 .57576 L
.51515 .56839 L
.51658 .56566 L
.52182 .55556 L
.52525 .54882 L
.52698 .54545 L
.53211 .53535 L
.53535 .52886 L
.53717 .52525 L
.5422 .51515 L
.54545 .50851 L
.54716 .50505 L
.55211 .49495 L
.55556 .48779 L
.55698 .48485 L
.56184 .47475 L
.56566 .46669 L
.56663 .46465 L
.57141 .45455 L
.57576 .44522 L
.57612 .44444 L
.58083 .43434 L
.58547 .42424 L
.58586 .42339 L
.59011 .41414 L
Mistroke
.5947 .40404 L
.59596 .40122 L
.59925 .39394 L
.60379 .38384 L
.60606 .37869 L
.60827 .37374 L
.61275 .36364 L
.61616 .35582 L
.61717 .35354 L
.6216 .34343 L
.62596 .33333 L
.62626 .33261 L
.63033 .32323 L
.63465 .31313 L
.63636 .30907 L
.63895 .30303 L
.64324 .29293 L
.64646 .2852 L
.64747 .28283 L
.65172 .27273 L
.65591 .26263 L
.65657 .26101 L
.6601 .25253 L
.66427 .24242 L
.66667 .2365 L
.66838 .23232 L
.67253 .22222 L
.67659 .21212 L
.67677 .21168 L
.68069 .20202 L
.68475 .19192 L
.68687 .18654 L
.68876 .18182 L
.6928 .17172 L
.69677 .16162 L
.69697 .1611 L
.70077 .15152 L
.70474 .14141 L
.70707 .13536 L
.70865 .13131 L
.7126 .12121 L
.71649 .11111 L
.71717 .10931 L
.72039 .10101 L
.72428 .09091 L
.72727 .08297 L
.7281 .08081 L
.73197 .07071 L
.73579 .06061 L
.73737 .05634 L
Mistroke
.73958 .05051 L
.7434 .0404 L
.74715 .0303 L
.74747 .02941 L
.75093 .0202 L
.7547 .0101 L
.75758 .0022 L
.75839 0 L
Mfstroke
.4 g
.20868 1 m
.21212 .99656 L
.21878 .9899 L
.22222 .98646 L
.22888 .9798 L
.23232 .97636 L
.23898 .9697 L
.24242 .96625 L
.24908 .9596 L
.25253 .95615 L
.25918 .94949 L
.26263 .94605 L
.26928 .93939 L
.27273 .93595 L
.27939 .92929 L
.28283 .92585 L
.28949 .91919 L
.29293 .91575 L
.29959 .90909 L
.30303 .90565 L
.30969 .89899 L
.31313 .89555 L
.31979 .88889 L
.32323 .88545 L
.32998 .87879 L
.33333 .87535 L
.33943 .86869 L
.34343 .86422 L
.34835 .85859 L
.35354 .85248 L
.35686 .84848 L
.36364 .84014 L
.36504 .83838 L
.37293 .82828 L
.37374 .82723 L
.38057 .81818 L
.38384 .81376 L
.38798 .80808 L
.39394 .79975 L
.39519 .79798 L
.40222 .78788 L
.40404 .78522 L
.40908 .77778 L
.41414 .77018 L
.41579 .76768 L
.42237 .75758 L
.42424 .75465 L
.42881 .74747 L
.43434 .73865 L
.43513 .73737 L
.44135 .72727 L
.44444 .72217 L
.44745 .71717 L
.45347 .70707 L
.45455 .70525 L
.45939 .69697 L
.46465 .68788 L
.46522 .68687 L
.47098 .67677 L
.47475 .67007 L
.47665 .66667 L
.48226 .65657 L
.48485 .65185 L
.48778 .64646 L
.49326 .63636 L
.49495 .63321 L
.49865 .62626 L
.504 .61616 L
.50505 .61417 L
.50928 .60606 L
.51452 .59596 L
.51515 .59473 L
.51969 .58586 L
.52482 .57576 L
.52525 .5749 L
.52989 .56566 L
.53492 .55556 L
.53535 .55469 L
.5399 .54545 L
.54484 .53535 L
.54545 .5341 L
.54973 .52525 L
.55459 .51515 L
.55556 .51314 L
.5594 .50505 L
.56418 .49495 L
.56566 .49182 L
.56891 .48485 L
.57362 .47475 L
.57576 .47014 L
.57828 .46465 L
.58292 .45455 L
.58586 .44812 L
.58752 .44444 L
.59209 .43434 L
.59596 .42574 L
.59663 .42424 L
.60113 .41414 L
.60561 .40404 L
.60606 .40303 L
.61005 .39394 L
.61448 .38384 L
.61616 .37998 L
.61886 .37374 L
.62323 .36364 L
.62626 .3566 L
.62756 .35354 L
.63188 .34343 L
.63618 .33333 L
.63636 .33289 L
.64042 .32323 L
.64468 .31313 L
.64646 .30886 L
.64888 .30303 L
.65308 .29293 L
.65657 .28452 L
.65725 .28283 L
.66139 .27273 L
.66554 .26263 L
.66667 .25986 L
.66962 .25253 L
.67372 .24242 L
.67677 .23488 L
.67778 .23232 L
.68182 .22222 L
.68587 .21212 L
.68687 .20961 L
.68985 .20202 L
.69386 .19192 L
.69697 .18403 L
.69782 .18182 L
.70177 .17172 L
.70572 .16162 L
.70707 .15815 L
.70961 .15152 L
.71353 .14141 L
.71717 .13197 L
.71742 .13131 L
.72127 .12121 L
.72514 .11111 L
.72727 .1055 L
.72895 .10101 L
.73278 .09091 L
.7366 .08081 L
.73737 .07875 L
.74036 .07071 L
.74415 .06061 L
.74747 .0517 L
.74791 .05051 L
.75164 .0404 L
.75539 .0303 L
.75758 .02438 L
.75908 .0202 L
.76279 .0101 L
.7665 0 L
1 0 L
1 1 L
F
0 g
.20868 1 m
.21212 .99656 L
.21878 .9899 L
.22222 .98646 L
.22888 .9798 L
.23232 .97636 L
.23898 .9697 L
.24242 .96625 L
.24908 .9596 L
.25253 .95615 L
.25918 .94949 L
.26263 .94605 L
.26928 .93939 L
.27273 .93595 L
.27939 .92929 L
.28283 .92585 L
.28949 .91919 L
.29293 .91575 L
.29959 .90909 L
.30303 .90565 L
.30969 .89899 L
.31313 .89555 L
.31979 .88889 L
.32323 .88545 L
.32998 .87879 L
.33333 .87535 L
.33943 .86869 L
.34343 .86422 L
.34835 .85859 L
.35354 .85248 L
.35686 .84848 L
.36364 .84014 L
.36504 .83838 L
.37293 .82828 L
.37374 .82723 L
.38057 .81818 L
.38384 .81376 L
.38798 .80808 L
.39394 .79975 L
.39519 .79798 L
.40222 .78788 L
.40404 .78522 L
.40908 .77778 L
.41414 .77018 L
.41579 .76768 L
.42237 .75758 L
.42424 .75465 L
.42881 .74747 L
.43434 .73865 L
.43513 .73737 L
Mistroke
.44135 .72727 L
.44444 .72217 L
.44745 .71717 L
.45347 .70707 L
.45455 .70525 L
.45939 .69697 L
.46465 .68788 L
.46522 .68687 L
.47098 .67677 L
.47475 .67007 L
.47665 .66667 L
.48226 .65657 L
.48485 .65185 L
.48778 .64646 L
.49326 .63636 L
.49495 .63321 L
.49865 .62626 L
.504 .61616 L
.50505 .61417 L
.50928 .60606 L
.51452 .59596 L
.51515 .59473 L
.51969 .58586 L
.52482 .57576 L
.52525 .5749 L
.52989 .56566 L
.53492 .55556 L
.53535 .55469 L
.5399 .54545 L
.54484 .53535 L
.54545 .5341 L
.54973 .52525 L
.55459 .51515 L
.55556 .51314 L
.5594 .50505 L
.56418 .49495 L
.56566 .49182 L
.56891 .48485 L
.57362 .47475 L
.57576 .47014 L
.57828 .46465 L
.58292 .45455 L
.58586 .44812 L
.58752 .44444 L
.59209 .43434 L
.59596 .42574 L
.59663 .42424 L
.60113 .41414 L
.60561 .40404 L
.60606 .40303 L
Mistroke
.61005 .39394 L
.61448 .38384 L
.61616 .37998 L
.61886 .37374 L
.62323 .36364 L
.62626 .3566 L
.62756 .35354 L
.63188 .34343 L
.63618 .33333 L
.63636 .33289 L
.64042 .32323 L
.64468 .31313 L
.64646 .30886 L
.64888 .30303 L
.65308 .29293 L
.65657 .28452 L
.65725 .28283 L
.66139 .27273 L
.66554 .26263 L
.66667 .25986 L
.66962 .25253 L
.67372 .24242 L
.67677 .23488 L
.67778 .23232 L
.68182 .22222 L
.68587 .21212 L
.68687 .20961 L
.68985 .20202 L
.69386 .19192 L
.69697 .18403 L
.69782 .18182 L
.70177 .17172 L
.70572 .16162 L
.70707 .15815 L
.70961 .15152 L
.71353 .14141 L
.71717 .13197 L
.71742 .13131 L
.72127 .12121 L
.72514 .11111 L
.72727 .1055 L
.72895 .10101 L
.73278 .09091 L
.7366 .08081 L
.73737 .07875 L
.74036 .07071 L
.74415 .06061 L
.74747 .0517 L
.74791 .05051 L
.75164 .0404 L
Mistroke
.75539 .0303 L
.75758 .02438 L
.75908 .0202 L
.76279 .0101 L
.7665 0 L
Mfstroke
.3 g
.25411 1 m
.26263 .99154 L
.26421 .9899 L
.27273 .98139 L
.27431 .9798 L
.28283 .97128 L
.28442 .9697 L
.29293 .96118 L
.29452 .9596 L
.30303 .95108 L
.30462 .94949 L
.31313 .94098 L
.31472 .93939 L
.32323 .93088 L
.32499 .92929 L
.33333 .92078 L
.33461 .91919 L
.34204 .90909 L
.34343 .90714 L
.34944 .89899 L
.35354 .89339 L
.35681 .88889 L
.36364 .87944 L
.3641 .87879 L
.37125 .86869 L
.37374 .86514 L
.37827 .85859 L
.38384 .85049 L
.38519 .84848 L
.39199 .83838 L
.39394 .83545 L
.39864 .82828 L
.40404 .82001 L
.40521 .81818 L
.41166 .80808 L
.41414 .80416 L
.41798 .79798 L
.42424 .78791 L
.42426 .78788 L
.43038 .77778 L
.43434 .77123 L
.43643 .76768 L
.44242 .75758 L
.44444 .75415 L
.44828 .74747 L
.45414 .73737 L
.45455 .73667 L
.45983 .72727 L
.46465 .71878 L
.46552 .71717 L
.4711 .70707 L
.47475 .70049 L
.47663 .69697 L
.48211 .68687 L
.48485 .68182 L
.48749 .67677 L
.49288 .66667 L
.49495 .66277 L
.49813 .65657 L
.50342 .64646 L
.50505 .64333 L
.50856 .63636 L
.51375 .62626 L
.51515 .62353 L
.51879 .61616 L
.52389 .60606 L
.52525 .60335 L
.52883 .59596 L
.53385 .58586 L
.53535 .58281 L
.5387 .57576 L
.54363 .56566 L
.54545 .56191 L
.54841 .55556 L
.55326 .54545 L
.55556 .54065 L
.55797 .53535 L
.56273 .52525 L
.56566 .51905 L
.56739 .51515 L
.57206 .50505 L
.57576 .49711 L
.57669 .49495 L
.58126 .48485 L
.58586 .47483 L
.58589 .47475 L
.59033 .46465 L
.59491 .45455 L
.59596 .4522 L
.59929 .44444 L
.60379 .43434 L
.60606 .42925 L
.60815 .42424 L
.61257 .41414 L
.61616 .40598 L
.61694 .40404 L
.62124 .39394 L
.62563 .38384 L
.62626 .38238 L
.62981 .37374 L
.63415 .36364 L
.63636 .35846 L
.63832 .35354 L
.64256 .34343 L
.64646 .33424 L
.64681 .33333 L
.65089 .32323 L
.65513 .31313 L
.65657 .30969 L
.65916 .30303 L
.66332 .29293 L
.66667 .28485 L
.66742 .28283 L
.67143 .27273 L
.67557 .26263 L
.67677 .2597 L
.67949 .25253 L
.68356 .24242 L
.68687 .23424 L
.68756 .23232 L
.69147 .22222 L
.69552 .21212 L
.69697 .20849 L
.69935 .20202 L
.70332 .19192 L
.70707 .18246 L
.70729 .18182 L
.71106 .17172 L
.71502 .16162 L
.71717 .15612 L
.71879 .15152 L
.72264 .14141 L
.72657 .13131 L
.72727 .1295 L
.73023 .12121 L
.7341 .11111 L
.73737 .10259 L
.7379 .10101 L
.74157 .09091 L
.74542 .08081 L
.74747 .0754 L
.74906 .07071 L
.75279 .06061 L
.75661 .05051 L
.75758 .04794 L
.76015 .0404 L
.7639 .0303 L
.76767 .0202 L
.76768 .0202 L
.77115 .0101 L
.77488 0 L
1 0 L
1 1 L
F
0 g
.25411 1 m
.26263 .99154 L
.26421 .9899 L
.27273 .98139 L
.27431 .9798 L
.28283 .97128 L
.28442 .9697 L
.29293 .96118 L
.29452 .9596 L
.30303 .95108 L
.30462 .94949 L
.31313 .94098 L
.31472 .93939 L
.32323 .93088 L
.32499 .92929 L
.33333 .92078 L
.33461 .91919 L
.34204 .90909 L
.34343 .90714 L
.34944 .89899 L
.35354 .89339 L
.35681 .88889 L
.36364 .87944 L
.3641 .87879 L
.37125 .86869 L
.37374 .86514 L
.37827 .85859 L
.38384 .85049 L
.38519 .84848 L
.39199 .83838 L
.39394 .83545 L
.39864 .82828 L
.40404 .82001 L
.40521 .81818 L
.41166 .80808 L
.41414 .80416 L
.41798 .79798 L
.42424 .78791 L
.42426 .78788 L
.43038 .77778 L
.43434 .77123 L
.43643 .76768 L
.44242 .75758 L
.44444 .75415 L
.44828 .74747 L
.45414 .73737 L
.45455 .73667 L
.45983 .72727 L
.46465 .71878 L
.46552 .71717 L
Mistroke
.4711 .70707 L
.47475 .70049 L
.47663 .69697 L
.48211 .68687 L
.48485 .68182 L
.48749 .67677 L
.49288 .66667 L
.49495 .66277 L
.49813 .65657 L
.50342 .64646 L
.50505 .64333 L
.50856 .63636 L
.51375 .62626 L
.51515 .62353 L
.51879 .61616 L
.52389 .60606 L
.52525 .60335 L
.52883 .59596 L
.53385 .58586 L
.53535 .58281 L
.5387 .57576 L
.54363 .56566 L
.54545 .56191 L
.54841 .55556 L
.55326 .54545 L
.55556 .54065 L
.55797 .53535 L
.56273 .52525 L
.56566 .51905 L
.56739 .51515 L
.57206 .50505 L
.57576 .49711 L
.57669 .49495 L
.58126 .48485 L
.58586 .47483 L
.58589 .47475 L
.59033 .46465 L
.59491 .45455 L
.59596 .4522 L
.59929 .44444 L
.60379 .43434 L
.60606 .42925 L
.60815 .42424 L
.61257 .41414 L
.61616 .40598 L
.61694 .40404 L
.62124 .39394 L
.62563 .38384 L
.62626 .38238 L
.62981 .37374 L
Mistroke
.63415 .36364 L
.63636 .35846 L
.63832 .35354 L
.64256 .34343 L
.64646 .33424 L
.64681 .33333 L
.65089 .32323 L
.65513 .31313 L
.65657 .30969 L
.65916 .30303 L
.66332 .29293 L
.66667 .28485 L
.66742 .28283 L
.67143 .27273 L
.67557 .26263 L
.67677 .2597 L
.67949 .25253 L
.68356 .24242 L
.68687 .23424 L
.68756 .23232 L
.69147 .22222 L
.69552 .21212 L
.69697 .20849 L
.69935 .20202 L
.70332 .19192 L
.70707 .18246 L
.70729 .18182 L
.71106 .17172 L
.71502 .16162 L
.71717 .15612 L
.71879 .15152 L
.72264 .14141 L
.72657 .13131 L
.72727 .1295 L
.73023 .12121 L
.7341 .11111 L
.73737 .10259 L
.7379 .10101 L
.74157 .09091 L
.74542 .08081 L
.74747 .0754 L
.74906 .07071 L
.75279 .06061 L
.75661 .05051 L
.75758 .04794 L
.76015 .0404 L
.7639 .0303 L
.76767 .0202 L
.76768 .0202 L
.77115 .0101 L
Mistroke
.77488 0 L
Mfstroke
.4 g
.33648 1 m
.34343 .99501 L
.35019 .9899 L
.35354 .98659 L
.3609 .9798 L
.36364 .97684 L
.37064 .9697 L
.37374 .96614 L
.37969 .9596 L
.38384 .95459 L
.38819 .94949 L
.39394 .94227 L
.39627 .93939 L
.404 .92929 L
.40404 .92924 L
.41162 .91919 L
.41414 .91558 L
.41887 .90909 L
.42424 .90128 L
.42585 .89899 L
.43276 .88889 L
.43434 .8864 L
.43947 .87879 L
.44444 .87096 L
.44593 .86869 L
.4524 .85859 L
.45455 .855 L
.45866 .84848 L
.46465 .83851 L
.46472 .83838 L
.47088 .82828 L
.47475 .82154 L
.47675 .81818 L
.48266 .80808 L
.48485 .8041 L
.4884 .79798 L
.49406 .78788 L
.49495 .78618 L
.4997 .77778 L
.50505 .76782 L
.50513 .76768 L
.5107 .75758 L
.51515 .74903 L
.51599 .74747 L
.52142 .73737 L
.52525 .72981 L
.5266 .72727 L
.5319 .71717 L
.53535 .71018 L
.53697 .70707 L
.54216 .69697 L
.54545 .69014 L
.54712 .68687 L
.55222 .67677 L
.55556 .66971 L
.55708 .66667 L
.56209 .65657 L
.56566 .64889 L
.56685 .64646 L
.57178 .63636 L
.57576 .62769 L
.57645 .62626 L
.58131 .61616 L
.58586 .60612 L
.58589 .60606 L
.59068 .59596 L
.59526 .58586 L
.59596 .58419 L
.5999 .57576 L
.60448 .56566 L
.60606 .56191 L
.60898 .55556 L
.61356 .54545 L
.61616 .53926 L
.61793 .53535 L
.62248 .52525 L
.62626 .51627 L
.62676 .51515 L
.63127 .50505 L
.63558 .49495 L
.63636 .49294 L
.63993 .48485 L
.64429 .47475 L
.64646 .46927 L
.64847 .46465 L
.65284 .45455 L
.65657 .44527 L
.65692 .44444 L
.66125 .43434 L
.66543 .42424 L
.66667 .42095 L
.66955 .41414 L
.67378 .40404 L
.67677 .39631 L
.67776 .39394 L
.68198 .38384 L
.68601 .37374 L
.68687 .37135 L
.69006 .36364 L
.69418 .35354 L
.69697 .34607 L
.69804 .34343 L
.70217 .33333 L
.70611 .32323 L
.70707 .32049 L
.71004 .31313 L
.71409 .30303 L
.71717 .2946 L
.71784 .29293 L
.72188 .28283 L
.72578 .27273 L
.72727 .26842 L
.72956 .26263 L
.73354 .25253 L
.73721 .24242 L
.73737 .24193 L
.74113 .23232 L
.74502 .22222 L
.74747 .21515 L
.74864 .21212 L
.75256 .20202 L
.75631 .19192 L
.75758 .18808 L
.75997 .18182 L
.76384 .17172 L
.7674 .16162 L
.76768 .16072 L
.77117 .15152 L
.77496 .14141 L
.77778 .13308 L
.77844 .13131 L
.78224 .12121 L
.78594 .11111 L
.78788 .10516 L
.78942 .10101 L
.79319 .09091 L
.79678 .08081 L
.79798 .07696 L
.80028 .07071 L
.80401 .06061 L
.80748 .05051 L
.80808 .04848 L
.81103 .0404 L
.81471 .0303 L
.81805 .0202 L
.81818 .01973 L
.82168 .0101 L
.82531 0 L
1 0 L
1 1 L
F
0 g
.33648 1 m
.34343 .99501 L
.35019 .9899 L
.35354 .98659 L
.3609 .9798 L
.36364 .97684 L
.37064 .9697 L
.37374 .96614 L
.37969 .9596 L
.38384 .95459 L
.38819 .94949 L
.39394 .94227 L
.39627 .93939 L
.404 .92929 L
.40404 .92924 L
.41162 .91919 L
.41414 .91558 L
.41887 .90909 L
.42424 .90128 L
.42585 .89899 L
.43276 .88889 L
.43434 .8864 L
.43947 .87879 L
.44444 .87096 L
.44593 .86869 L
.4524 .85859 L
.45455 .855 L
.45866 .84848 L
.46465 .83851 L
.46472 .83838 L
.47088 .82828 L
.47475 .82154 L
.47675 .81818 L
.48266 .80808 L
.48485 .8041 L
.4884 .79798 L
.49406 .78788 L
.49495 .78618 L
.4997 .77778 L
.50505 .76782 L
.50513 .76768 L
.5107 .75758 L
.51515 .74903 L
.51599 .74747 L
.52142 .73737 L
.52525 .72981 L
.5266 .72727 L
.5319 .71717 L
.53535 .71018 L
.53697 .70707 L
Mistroke
.54216 .69697 L
.54545 .69014 L
.54712 .68687 L
.55222 .67677 L
.55556 .66971 L
.55708 .66667 L
.56209 .65657 L
.56566 .64889 L
.56685 .64646 L
.57178 .63636 L
.57576 .62769 L
.57645 .62626 L
.58131 .61616 L
.58586 .60612 L
.58589 .60606 L
.59068 .59596 L
.59526 .58586 L
.59596 .58419 L
.5999 .57576 L
.60448 .56566 L
.60606 .56191 L
.60898 .55556 L
.61356 .54545 L
.61616 .53926 L
.61793 .53535 L
.62248 .52525 L
.62626 .51627 L
.62676 .51515 L
.63127 .50505 L
.63558 .49495 L
.63636 .49294 L
.63993 .48485 L
.64429 .47475 L
.64646 .46927 L
.64847 .46465 L
.65284 .45455 L
.65657 .44527 L
.65692 .44444 L
.66125 .43434 L
.66543 .42424 L
.66667 .42095 L
.66955 .41414 L
.67378 .40404 L
.67677 .39631 L
.67776 .39394 L
.68198 .38384 L
.68601 .37374 L
.68687 .37135 L
.69006 .36364 L
.69418 .35354 L
Mistroke
.69697 .34607 L
.69804 .34343 L
.70217 .33333 L
.70611 .32323 L
.70707 .32049 L
.71004 .31313 L
.71409 .30303 L
.71717 .2946 L
.71784 .29293 L
.72188 .28283 L
.72578 .27273 L
.72727 .26842 L
.72956 .26263 L
.73354 .25253 L
.73721 .24242 L
.73737 .24193 L
.74113 .23232 L
.74502 .22222 L
.74747 .21515 L
.74864 .21212 L
.75256 .20202 L
.75631 .19192 L
.75758 .18808 L
.75997 .18182 L
.76384 .17172 L
.7674 .16162 L
.76768 .16072 L
.77117 .15152 L
.77496 .14141 L
.77778 .13308 L
.77844 .13131 L
.78224 .12121 L
.78594 .11111 L
.78788 .10516 L
.78942 .10101 L
.79319 .09091 L
.79678 .08081 L
.79798 .07696 L
.80028 .07071 L
.80401 .06061 L
.80748 .05051 L
.80808 .04848 L
.81103 .0404 L
.81471 .0303 L
.81805 .0202 L
.81818 .01973 L
.82168 .0101 L
.82531 0 L
Mfstroke
.5 g
.37702 1 m
.38384 .99131 L
.38494 .9899 L
.39259 .9798 L
.39394 .97797 L
.40001 .9697 L
.40404 .96404 L
.40719 .9596 L
.41414 .94955 L
.41418 .94949 L
.42102 .93939 L
.42424 .93453 L
.42769 .92929 L
.43421 .91919 L
.43434 .91898 L
.44062 .90909 L
.44444 .90294 L
.44689 .89899 L
.45306 .88889 L
.45455 .88641 L
.45913 .87879 L
.46465 .86941 L
.46507 .86869 L
.47096 .85859 L
.47475 .85196 L
.47674 .84848 L
.48245 .83838 L
.48485 .83407 L
.48807 .82828 L
.49363 .81818 L
.49495 .81574 L
.49912 .80808 L
.50453 .79798 L
.50505 .79699 L
.5099 .78788 L
.51515 .77783 L
.51518 .77778 L
.52044 .76768 L
.52525 .75826 L
.5256 .75758 L
.53076 .74747 L
.53535 .7383 L
.53582 .73737 L
.54087 .72727 L
.54545 .71795 L
.54584 .71717 L
.5508 .70707 L
.55556 .69722 L
.55568 .69697 L
.56056 .68687 L
.56536 .67677 L
.56566 .67613 L
.57015 .66667 L
.57488 .65657 L
.57576 .65466 L
.57959 .64646 L
.58425 .63636 L
.58586 .63283 L
.58888 .62626 L
.59349 .61616 L
.59596 .61066 L
.59804 .60606 L
.60259 .59596 L
.60606 .58813 L
.60707 .58586 L
.61157 .57576 L
.61599 .56566 L
.61616 .56526 L
.62042 .55556 L
.62481 .54545 L
.62626 .54205 L
.62917 .53535 L
.63351 .52525 L
.63636 .51851 L
.6378 .51515 L
.64211 .50505 L
.64634 .49495 L
.64646 .49464 L
.65059 .48485 L
.65481 .47475 L
.65657 .47045 L
.65898 .46465 L
.66317 .45455 L
.66667 .44594 L
.66728 .44444 L
.67143 .43434 L
.67553 .42424 L
.67677 .42112 L
.6796 .41414 L
.68368 .40404 L
.68687 .39598 L
.68769 .39394 L
.69173 .38384 L
.69573 .37374 L
.69697 .37054 L
.6997 .36364 L
.70369 .35354 L
.70707 .34479 L
.7076 .34343 L
.71156 .33333 L
.71547 .32323 L
.71717 .31875 L
.71935 .31313 L
.72325 .30303 L
.72708 .29293 L
.72727 .29241 L
.73094 .28283 L
.73479 .27273 L
.73737 .26577 L
.73856 .26263 L
.74239 .25253 L
.74617 .24242 L
.74747 .23885 L
.74992 .23232 L
.7537 .22222 L
.7574 .21212 L
.75758 .21164 L
.76115 .20202 L
.76488 .19192 L
.76768 .18415 L
.76853 .18182 L
.77224 .17172 L
.77592 .16162 L
.77778 .15637 L
.77954 .15152 L
.78322 .14141 L
.78683 .13131 L
.78788 .12832 L
.79044 .12121 L
.79407 .11111 L
.79763 .10101 L
.79798 .09999 L
.80122 .09091 L
.80482 .08081 L
.80808 .07139 L
.80832 .07071 L
.81189 .06061 L
.81545 .05051 L
.81818 .04252 L
.81892 .0404 L
.82246 .0303 L
.82598 .0202 L
.82828 .01339 L
.82942 .0101 L
.83293 0 L
1 0 L
1 1 L
F
0 g
.37702 1 m
.38384 .99131 L
.38494 .9899 L
.39259 .9798 L
.39394 .97797 L
.40001 .9697 L
.40404 .96404 L
.40719 .9596 L
.41414 .94955 L
.41418 .94949 L
.42102 .93939 L
.42424 .93453 L
.42769 .92929 L
.43421 .91919 L
.43434 .91898 L
.44062 .90909 L
.44444 .90294 L
.44689 .89899 L
.45306 .88889 L
.45455 .88641 L
.45913 .87879 L
.46465 .86941 L
.46507 .86869 L
.47096 .85859 L
.47475 .85196 L
.47674 .84848 L
.48245 .83838 L
.48485 .83407 L
.48807 .82828 L
.49363 .81818 L
.49495 .81574 L
.49912 .80808 L
.50453 .79798 L
.50505 .79699 L
.5099 .78788 L
.51515 .77783 L
.51518 .77778 L
.52044 .76768 L
.52525 .75826 L
.5256 .75758 L
.53076 .74747 L
.53535 .7383 L
.53582 .73737 L
.54087 .72727 L
.54545 .71795 L
.54584 .71717 L
.5508 .70707 L
.55556 .69722 L
.55568 .69697 L
.56056 .68687 L
Mistroke
.56536 .67677 L
.56566 .67613 L
.57015 .66667 L
.57488 .65657 L
.57576 .65466 L
.57959 .64646 L
.58425 .63636 L
.58586 .63283 L
.58888 .62626 L
.59349 .61616 L
.59596 .61066 L
.59804 .60606 L
.60259 .59596 L
.60606 .58813 L
.60707 .58586 L
.61157 .57576 L
.61599 .56566 L
.61616 .56526 L
.62042 .55556 L
.62481 .54545 L
.62626 .54205 L
.62917 .53535 L
.63351 .52525 L
.63636 .51851 L
.6378 .51515 L
.64211 .50505 L
.64634 .49495 L
.64646 .49464 L
.65059 .48485 L
.65481 .47475 L
.65657 .47045 L
.65898 .46465 L
.66317 .45455 L
.66667 .44594 L
.66728 .44444 L
.67143 .43434 L
.67553 .42424 L
.67677 .42112 L
.6796 .41414 L
.68368 .40404 L
.68687 .39598 L
.68769 .39394 L
.69173 .38384 L
.69573 .37374 L
.69697 .37054 L
.6997 .36364 L
.70369 .35354 L
.70707 .34479 L
.7076 .34343 L
.71156 .33333 L
Mistroke
.71547 .32323 L
.71717 .31875 L
.71935 .31313 L
.72325 .30303 L
.72708 .29293 L
.72727 .29241 L
.73094 .28283 L
.73479 .27273 L
.73737 .26577 L
.73856 .26263 L
.74239 .25253 L
.74617 .24242 L
.74747 .23885 L
.74992 .23232 L
.7537 .22222 L
.7574 .21212 L
.75758 .21164 L
.76115 .20202 L
.76488 .19192 L
.76768 .18415 L
.76853 .18182 L
.77224 .17172 L
.77592 .16162 L
.77778 .15637 L
.77954 .15152 L
.78322 .14141 L
.78683 .13131 L
.78788 .12832 L
.79044 .12121 L
.79407 .11111 L
.79763 .10101 L
.79798 .09999 L
.80122 .09091 L
.80482 .08081 L
.80808 .07139 L
.80832 .07071 L
.81189 .06061 L
.81545 .05051 L
.81818 .04252 L
.81892 .0404 L
.82246 .0303 L
.82598 .0202 L
.82828 .01339 L
.82942 .0101 L
.83293 0 L
Mfstroke
.6 g
.40037 1 m
.40404 .99466 L
.40727 .9899 L
.41403 .9798 L
.41414 .97962 L
.42063 .9697 L
.42424 .96409 L
.42711 .9596 L
.43347 .94949 L
.43434 .94809 L
.43971 .93939 L
.44444 .93161 L
.44584 .92929 L
.45188 .91919 L
.45455 .91469 L
.45782 .90909 L
.46369 .89899 L
.46465 .89732 L
.46946 .88889 L
.47475 .87952 L
.47515 .87879 L
.48077 .86869 L
.48485 .86129 L
.48632 .85859 L
.49181 .84848 L
.49495 .84265 L
.49723 .83838 L
.50259 .82828 L
.50505 .82361 L
.50788 .81818 L
.51313 .80808 L
.51515 .80417 L
.51832 .79798 L
.52346 .78788 L
.52525 .78434 L
.52854 .77778 L
.53359 .76768 L
.53535 .76412 L
.53858 .75758 L
.54354 .74747 L
.54545 .74354 L
.54843 .73737 L
.55331 .72727 L
.55556 .72258 L
.55812 .71717 L
.56292 .70707 L
.56566 .70126 L
.56766 .69697 L
.57238 .68687 L
.57576 .67958 L
.57705 .67677 L
.58169 .66667 L
.58586 .65756 L
.58631 .65657 L
.59087 .64646 L
.59543 .63636 L
.59596 .63518 L
.59993 .62626 L
.60443 .61616 L
.60606 .61247 L
.60887 .60606 L
.61331 .59596 L
.61616 .58942 L
.6177 .58586 L
.62207 .57576 L
.62626 .56604 L
.62643 .56566 L
.63073 .55556 L
.63504 .54545 L
.63636 .54233 L
.63929 .53535 L
.64355 .52525 L
.64646 .5183 L
.64777 .51515 L
.65197 .50505 L
.65616 .49495 L
.65657 .49396 L
.66029 .48485 L
.66444 .47475 L
.66667 .46929 L
.66854 .46465 L
.67264 .45455 L
.67672 .44444 L
.67677 .44432 L
.68075 .43434 L
.6848 .42424 L
.68687 .41905 L
.68879 .41414 L
.69279 .40404 L
.69678 .39394 L
.69697 .39347 L
.70072 .38384 L
.70468 .37374 L
.70707 .36759 L
.70858 .36364 L
.71249 .35354 L
.7164 .34343 L
.71717 .34141 L
.72024 .33333 L
.72411 .32323 L
.72727 .31494 L
.72795 .31313 L
.73176 .30303 L
.73559 .29293 L
.73737 .28819 L
.73936 .28283 L
.74314 .27273 L
.74692 .26263 L
.74747 .26114 L
.75064 .25253 L
.75439 .24242 L
.75758 .23382 L
.75811 .23232 L
.7618 .22222 L
.76552 .21212 L
.76768 .20621 L
.76917 .20202 L
.77284 .19192 L
.77652 .18182 L
.77778 .17832 L
.78012 .17172 L
.78376 .16162 L
.7874 .15152 L
.78788 .15016 L
.79096 .14141 L
.79457 .13131 L
.79798 .12173 L
.79816 .12121 L
.80169 .11111 L
.80527 .10101 L
.80808 .09303 L
.8088 .09091 L
.81232 .08081 L
.81587 .07071 L
.81818 .06406 L
.81935 .06061 L
.82284 .05051 L
.82636 .0404 L
.82828 .03482 L
.8298 .0303 L
.83327 .0202 L
.83675 .0101 L
.83838 .00533 L
.84016 0 L
1 0 L
1 1 L
F
0 g
.40037 1 m
.40404 .99466 L
.40727 .9899 L
.41403 .9798 L
.41414 .97962 L
.42063 .9697 L
.42424 .96409 L
.42711 .9596 L
.43347 .94949 L
.43434 .94809 L
.43971 .93939 L
.44444 .93161 L
.44584 .92929 L
.45188 .91919 L
.45455 .91469 L
.45782 .90909 L
.46369 .89899 L
.46465 .89732 L
.46946 .88889 L
.47475 .87952 L
.47515 .87879 L
.48077 .86869 L
.48485 .86129 L
.48632 .85859 L
.49181 .84848 L
.49495 .84265 L
.49723 .83838 L
.50259 .82828 L
.50505 .82361 L
.50788 .81818 L
.51313 .80808 L
.51515 .80417 L
.51832 .79798 L
.52346 .78788 L
.52525 .78434 L
.52854 .77778 L
.53359 .76768 L
.53535 .76412 L
.53858 .75758 L
.54354 .74747 L
.54545 .74354 L
.54843 .73737 L
.55331 .72727 L
.55556 .72258 L
.55812 .71717 L
.56292 .70707 L
.56566 .70126 L
.56766 .69697 L
.57238 .68687 L
.57576 .67958 L
Mistroke
.57705 .67677 L
.58169 .66667 L
.58586 .65756 L
.58631 .65657 L
.59087 .64646 L
.59543 .63636 L
.59596 .63518 L
.59993 .62626 L
.60443 .61616 L
.60606 .61247 L
.60887 .60606 L
.61331 .59596 L
.61616 .58942 L
.6177 .58586 L
.62207 .57576 L
.62626 .56604 L
.62643 .56566 L
.63073 .55556 L
.63504 .54545 L
.63636 .54233 L
.63929 .53535 L
.64355 .52525 L
.64646 .5183 L
.64777 .51515 L
.65197 .50505 L
.65616 .49495 L
.65657 .49396 L
.66029 .48485 L
.66444 .47475 L
.66667 .46929 L
.66854 .46465 L
.67264 .45455 L
.67672 .44444 L
.67677 .44432 L
.68075 .43434 L
.6848 .42424 L
.68687 .41905 L
.68879 .41414 L
.69279 .40404 L
.69678 .39394 L
.69697 .39347 L
.70072 .38384 L
.70468 .37374 L
.70707 .36759 L
.70858 .36364 L
.71249 .35354 L
.7164 .34343 L
.71717 .34141 L
.72024 .33333 L
.72411 .32323 L
Mistroke
.72727 .31494 L
.72795 .31313 L
.73176 .30303 L
.73559 .29293 L
.73737 .28819 L
.73936 .28283 L
.74314 .27273 L
.74692 .26263 L
.74747 .26114 L
.75064 .25253 L
.75439 .24242 L
.75758 .23382 L
.75811 .23232 L
.7618 .22222 L
.76552 .21212 L
.76768 .20621 L
.76917 .20202 L
.77284 .19192 L
.77652 .18182 L
.77778 .17832 L
.78012 .17172 L
.78376 .16162 L
.7874 .15152 L
.78788 .15016 L
.79096 .14141 L
.79457 .13131 L
.79798 .12173 L
.79816 .12121 L
.80169 .11111 L
.80527 .10101 L
.80808 .09303 L
.8088 .09091 L
.81232 .08081 L
.81587 .07071 L
.81818 .06406 L
.81935 .06061 L
.82284 .05051 L
.82636 .0404 L
.82828 .03482 L
.8298 .0303 L
.83327 .0202 L
.83675 .0101 L
.83838 .00533 L
.84016 0 L
Mfstroke
.7 g
.4226 1 m
.42424 .99736 L
.42875 .9899 L
.43434 .98067 L
.43486 .9798 L
.44083 .9697 L
.44444 .96358 L
.44673 .9596 L
.45259 .94949 L
.45455 .9461 L
.45831 .93939 L
.46404 .92929 L
.46465 .92822 L
.46961 .91919 L
.47475 .90994 L
.4752 .90909 L
.48065 .89899 L
.48485 .89126 L
.48608 .88889 L
.49145 .87879 L
.49495 .87221 L
.49675 .86869 L
.50202 .85859 L
.50505 .85277 L
.5072 .84848 L
.51237 .83838 L
.51515 .83296 L
.51745 .82828 L
.52254 .81818 L
.52525 .81278 L
.52752 .80808 L
.53251 .79798 L
.53535 .79224 L
.53741 .78788 L
.54232 .77778 L
.54545 .77134 L
.54715 .76768 L
.55196 .75758 L
.55556 .75009 L
.55674 .74747 L
.56146 .73737 L
.56566 .72849 L
.56619 .72727 L
.57081 .71717 L
.57552 .70707 L
.57576 .70655 L
.58003 .69697 L
.58467 .68687 L
.58586 .68426 L
.58912 .67677 L
.59369 .66667 L
.59596 .66164 L
.59811 .65657 L
.60259 .64646 L
.60606 .63869 L
.60702 .63636 L
.61138 .62626 L
.61584 .61616 L
.61616 .61542 L
.62007 .60606 L
.62447 .59596 L
.62626 .59182 L
.62868 .58586 L
.63299 .57576 L
.63636 .5679 L
.63724 .56566 L
.64143 .55556 L
.64572 .54545 L
.64646 .54368 L
.64978 .53535 L
.65401 .52525 L
.65657 .51913 L
.65809 .51515 L
.66221 .50505 L
.6664 .49495 L
.66667 .49429 L
.67034 .48485 L
.67448 .47475 L
.67677 .46913 L
.67844 .46465 L
.68247 .45455 L
.68656 .44444 L
.68687 .44369 L
.6904 .43434 L
.69445 .42424 L
.69697 .41793 L
.69834 .41414 L
.70225 .40404 L
.70626 .39394 L
.70707 .39189 L
.71002 .38384 L
.71397 .37374 L
.71717 .36556 L
.71783 .36364 L
.7216 .35354 L
.72553 .34343 L
.72727 .33893 L
.72924 .33333 L
.73307 .32323 L
.73696 .31313 L
.73737 .31203 L
.74056 .30303 L
.7444 .29293 L
.74747 .28484 L
.74814 .28283 L
.75178 .27273 L
.7556 .26263 L
.75758 .25737 L
.7592 .25253 L
.76289 .24242 L
.76668 .23232 L
.76768 .22963 L
.77018 .22222 L
.77389 .21212 L
.77763 .20202 L
.77778 .20162 L
.78106 .19192 L
.78477 .18182 L
.78788 .17332 L
.78837 .17172 L
.79185 .16162 L
.79553 .15152 L
.79798 .14476 L
.79902 .14141 L
.80253 .13131 L
.80619 .12121 L
.80808 .11594 L
.80959 .11111 L
.81311 .10101 L
.81674 .09091 L
.81818 .08685 L
.82007 .08081 L
.82359 .07071 L
.82719 .06061 L
.82828 .0575 L
.83047 .05051 L
.83398 .0404 L
.83754 .0303 L
.83838 .02789 L
.84077 .0202 L
.84426 .0101 L
.8478 0 L
1 0 L
1 1 L
F
0 g
.4226 1 m
.42424 .99736 L
.42875 .9899 L
.43434 .98067 L
.43486 .9798 L
.44083 .9697 L
.44444 .96358 L
.44673 .9596 L
.45259 .94949 L
.45455 .9461 L
.45831 .93939 L
.46404 .92929 L
.46465 .92822 L
.46961 .91919 L
.47475 .90994 L
.4752 .90909 L
.48065 .89899 L
.48485 .89126 L
.48608 .88889 L
.49145 .87879 L
.49495 .87221 L
.49675 .86869 L
.50202 .85859 L
.50505 .85277 L
.5072 .84848 L
.51237 .83838 L
.51515 .83296 L
.51745 .82828 L
.52254 .81818 L
.52525 .81278 L
.52752 .80808 L
.53251 .79798 L
.53535 .79224 L
.53741 .78788 L
.54232 .77778 L
.54545 .77134 L
.54715 .76768 L
.55196 .75758 L
.55556 .75009 L
.55674 .74747 L
.56146 .73737 L
.56566 .72849 L
.56619 .72727 L
.57081 .71717 L
.57552 .70707 L
.57576 .70655 L
.58003 .69697 L
.58467 .68687 L
.58586 .68426 L
.58912 .67677 L
Mistroke
.59369 .66667 L
.59596 .66164 L
.59811 .65657 L
.60259 .64646 L
.60606 .63869 L
.60702 .63636 L
.61138 .62626 L
.61584 .61616 L
.61616 .61542 L
.62007 .60606 L
.62447 .59596 L
.62626 .59182 L
.62868 .58586 L
.63299 .57576 L
.63636 .5679 L
.63724 .56566 L
.64143 .55556 L
.64572 .54545 L
.64646 .54368 L
.64978 .53535 L
.65401 .52525 L
.65657 .51913 L
.65809 .51515 L
.66221 .50505 L
.6664 .49495 L
.66667 .49429 L
.67034 .48485 L
.67448 .47475 L
.67677 .46913 L
.67844 .46465 L
.68247 .45455 L
.68656 .44444 L
.68687 .44369 L
.6904 .43434 L
.69445 .42424 L
.69697 .41793 L
.69834 .41414 L
.70225 .40404 L
.70626 .39394 L
.70707 .39189 L
.71002 .38384 L
.71397 .37374 L
.71717 .36556 L
.71783 .36364 L
.7216 .35354 L
.72553 .34343 L
.72727 .33893 L
.72924 .33333 L
.73307 .32323 L
.73696 .31313 L
Mistroke
.73737 .31203 L
.74056 .30303 L
.7444 .29293 L
.74747 .28484 L
.74814 .28283 L
.75178 .27273 L
.7556 .26263 L
.75758 .25737 L
.7592 .25253 L
.76289 .24242 L
.76668 .23232 L
.76768 .22963 L
.77018 .22222 L
.77389 .21212 L
.77763 .20202 L
.77778 .20162 L
.78106 .19192 L
.78477 .18182 L
.78788 .17332 L
.78837 .17172 L
.79185 .16162 L
.79553 .15152 L
.79798 .14476 L
.79902 .14141 L
.80253 .13131 L
.80619 .12121 L
.80808 .11594 L
.80959 .11111 L
.81311 .10101 L
.81674 .09091 L
.81818 .08685 L
.82007 .08081 L
.82359 .07071 L
.82719 .06061 L
.82828 .0575 L
.83047 .05051 L
.83398 .0404 L
.83754 .0303 L
.83838 .02789 L
.84077 .0202 L
.84426 .0101 L
.8478 0 L
Mfstroke
.6 g
.49261 1 m
.49495 .99557 L
.49819 .9899 L
.50374 .9798 L
.50505 .97726 L
.50923 .9697 L
.51459 .9596 L
.51515 .95847 L
.52 .94949 L
.52518 .93939 L
.52525 .93924 L
.53051 .92929 L
.53535 .91961 L
.53557 .91919 L
.5408 .90909 L
.54545 .89958 L
.54575 .89899 L
.55088 .88889 L
.55556 .87915 L
.55573 .87879 L
.56077 .86869 L
.56554 .85859 L
.56566 .85833 L
.57049 .84848 L
.57521 .83838 L
.57576 .83714 L
.58003 .82828 L
.58473 .81818 L
.58586 .81557 L
.58941 .80808 L
.59409 .79798 L
.59596 .79364 L
.59865 .78788 L
.6033 .77778 L
.60606 .77134 L
.60775 .76768 L
.61237 .75758 L
.61616 .7487 L
.61671 .74747 L
.62129 .73737 L
.62564 .72727 L
.62626 .72571 L
.63008 .71717 L
.63448 .70707 L
.63636 .70238 L
.63875 .69697 L
.64316 .68687 L
.64646 .67871 L
.64731 .67677 L
.65169 .66667 L
.65587 .65657 L
.65657 .65471 L
.66011 .64646 L
.66436 .63636 L
.66667 .63039 L
.66841 .62626 L
.67268 .61616 L
.67665 .60606 L
.67677 .60574 L
.68086 .59596 L
.68498 .58586 L
.68687 .58079 L
.68895 .57576 L
.69311 .56566 L
.69695 .55556 L
.69697 .55551 L
.70108 .54545 L
.70511 .53535 L
.70707 .52993 L
.70896 .52525 L
.71303 .51515 L
.71683 .50505 L
.71717 .50404 L
.72081 .49495 L
.72478 .48485 L
.72727 .47786 L
.7285 .47475 L
.73249 .46465 L
.7363 .45455 L
.73737 .45137 L
.74008 .44444 L
.74401 .43434 L
.74747 .42459 L
.74761 .42424 L
.75152 .41414 L
.75535 .40404 L
.75758 .39752 L
.75894 .39394 L
.76282 .38384 L
.76652 .37374 L
.76768 .37017 L
.77015 .36364 L
.77398 .35354 L
.7775 .34343 L
.77778 .34252 L
.78123 .33333 L
.78499 .32323 L
.78788 .3146 L
.78842 .31313 L
.79219 .30303 L
.79587 .29293 L
.79798 .2864 L
.79929 .28283 L
.80303 .27273 L
.80662 .26263 L
.80808 .25792 L
.81005 .25253 L
.81375 .24242 L
.81724 .23232 L
.81818 .22917 L
.8207 .22222 L
.82436 .21212 L
.82775 .20202 L
.82828 .20015 L
.83124 .19192 L
.83486 .18182 L
.83815 .17172 L
.83838 .17086 L
.84168 .16162 L
.84526 .15152 L
.84846 .14141 L
.84848 .14131 L
.85202 .13131 L
.85557 .12121 L
.85859 .1115 L
.85872 .11111 L
.86227 .10101 L
.86578 .09091 L
.86869 .08142 L
.8689 .08081 L
.87242 .07071 L
.8759 .06061 L
.87879 .05109 L
.87899 .05051 L
.88248 .0404 L
.88594 .0303 L
.88889 .0205 L
.88899 .0202 L
.89245 .0101 L
.8959 0 L
1 0 L
1 1 L
F
0 g
.49261 1 m
.49495 .99557 L
.49819 .9899 L
.50374 .9798 L
.50505 .97726 L
.50923 .9697 L
.51459 .9596 L
.51515 .95847 L
.52 .94949 L
.52518 .93939 L
.52525 .93924 L
.53051 .92929 L
.53535 .91961 L
.53557 .91919 L
.5408 .90909 L
.54545 .89958 L
.54575 .89899 L
.55088 .88889 L
.55556 .87915 L
.55573 .87879 L
.56077 .86869 L
.56554 .85859 L
.56566 .85833 L
.57049 .84848 L
.57521 .83838 L
.57576 .83714 L
.58003 .82828 L
.58473 .81818 L
.58586 .81557 L
.58941 .80808 L
.59409 .79798 L
.59596 .79364 L
.59865 .78788 L
.6033 .77778 L
.60606 .77134 L
.60775 .76768 L
.61237 .75758 L
.61616 .7487 L
.61671 .74747 L
.62129 .73737 L
.62564 .72727 L
.62626 .72571 L
.63008 .71717 L
.63448 .70707 L
.63636 .70238 L
.63875 .69697 L
.64316 .68687 L
.64646 .67871 L
.64731 .67677 L
.65169 .66667 L
Mistroke
.65587 .65657 L
.65657 .65471 L
.66011 .64646 L
.66436 .63636 L
.66667 .63039 L
.66841 .62626 L
.67268 .61616 L
.67665 .60606 L
.67677 .60574 L
.68086 .59596 L
.68498 .58586 L
.68687 .58079 L
.68895 .57576 L
.69311 .56566 L
.69695 .55556 L
.69697 .55551 L
.70108 .54545 L
.70511 .53535 L
.70707 .52993 L
.70896 .52525 L
.71303 .51515 L
.71683 .50505 L
.71717 .50404 L
.72081 .49495 L
.72478 .48485 L
.72727 .47786 L
.7285 .47475 L
.73249 .46465 L
.7363 .45455 L
.73737 .45137 L
.74008 .44444 L
.74401 .43434 L
.74747 .42459 L
.74761 .42424 L
.75152 .41414 L
.75535 .40404 L
.75758 .39752 L
.75894 .39394 L
.76282 .38384 L
.76652 .37374 L
.76768 .37017 L
.77015 .36364 L
.77398 .35354 L
.7775 .34343 L
.77778 .34252 L
.78123 .33333 L
.78499 .32323 L
.78788 .3146 L
.78842 .31313 L
.79219 .30303 L
Mistroke
.79587 .29293 L
.79798 .2864 L
.79929 .28283 L
.80303 .27273 L
.80662 .26263 L
.80808 .25792 L
.81005 .25253 L
.81375 .24242 L
.81724 .23232 L
.81818 .22917 L
.8207 .22222 L
.82436 .21212 L
.82775 .20202 L
.82828 .20015 L
.83124 .19192 L
.83486 .18182 L
.83815 .17172 L
.83838 .17086 L
.84168 .16162 L
.84526 .15152 L
.84846 .14141 L
.84848 .14131 L
.85202 .13131 L
.85557 .12121 L
.85859 .1115 L
.85872 .11111 L
.86227 .10101 L
.86578 .09091 L
.86869 .08142 L
.8689 .08081 L
.87242 .07071 L
.8759 .06061 L
.87879 .05109 L
.87899 .05051 L
.88248 .0404 L
.88594 .0303 L
.88889 .0205 L
.88899 .0202 L
.89245 .0101 L
.8959 0 L
Mfstroke
.2 g
.50505 .27808 m
.51351 .28283 L
.50675 .29293 L
.50505 .29532 L
.49937 .29293 L
.50314 .28283 L
F
0 g
.50505 .27808 m
.51351 .28283 L
.50675 .29293 L
.50505 .29532 L
.49937 .29293 L
.50314 .28283 L
.50505 .27808 L
s
.8 g
.50505 .9064 m
.51483 .90909 L
.50817 .91919 L
.50505 .92364 L
.50009 .91919 L
.50396 .90909 L
F
0 g
.50505 .9064 m
.51483 .90909 L
.50817 .91919 L
.50505 .92364 L
.50009 .91919 L
.50396 .90909 L
.50505 .9064 L
s
.8 g
.55505 0 m
.54971 .0101 L
.54545 .01884 L
.54431 .0202 L
.53877 .0303 L
.53535 .03762 L
.53315 .0404 L
.52737 .05051 L
.52525 .05512 L
.5214 .06061 L
.51523 .07071 L
.51515 .07087 L
.50859 .08081 L
.50505 .08588 L
.50032 .08081 L
.50421 .07071 L
.50505 .06864 L
.50844 .06061 L
.51279 .05051 L
.51515 .04509 L
.51723 .0404 L
.52172 .0303 L
.52525 .02236 L
.52622 .0202 L
.53077 .0101 L
.53524 0 L
F
0 g
.55505 0 m
.54971 .0101 L
.54545 .01884 L
.54431 .0202 L
.53877 .0303 L
.53535 .03762 L
.53315 .0404 L
.52737 .05051 L
.52525 .05512 L
.5214 .06061 L
.51523 .07071 L
.51515 .07087 L
.50859 .08081 L
.50505 .08588 L
.50032 .08081 L
.50421 .07071 L
.50505 .06864 L
.50844 .06061 L
.51279 .05051 L
.51515 .04509 L
.51723 .0404 L
.52172 .0303 L
.52525 .02236 L
.52622 .0202 L
.53077 .0101 L
.53524 0 L
s
.2 g
.81498 0 m
.8125 .0101 L
.80808 .01953 L
.80783 .0202 L
.8042 .0303 L
.80137 .0404 L
.79798 .04778 L
.79697 .05051 L
.79331 .06061 L
.79013 .07071 L
.78788 .07572 L
.78599 .08081 L
.78419 .09091 L
.7788 .10101 L
.77778 .10334 L
.77489 .11111 L
.77239 .12121 L
.76768 .13068 L
.76743 .13131 L
.76365 .14141 L
.76056 .15152 L
.75758 .15777 L
.7561 .16162 L
.75228 .17172 L
.74871 .18182 L
.74747 .1845 L
.74462 .19192 L
.742 .20202 L
.73737 .21095 L
.73691 .21212 L
.73299 .22222 L
.72962 .23232 L
.72727 .23712 L
.72517 .24242 L
.72296 .25253 L
.71729 .26263 L
.71717 .26288 L
.71326 .27273 L
.70996 .28283 L
.70707 .28846 L
.70524 .29293 L
.70119 .30303 L
.69718 .31313 L
.69697 .31357 L
.69303 .32323 L
.68961 .33333 L
.68687 .3385 L
.6848 .34343 L
.68249 .35354 L
.67677 .36296 L
.67647 .36364 L
.67224 .37374 L
.66845 .38384 L
.66667 .38716 L
.66376 .39394 L
.66075 .40404 L
.65657 .41102 L
.65517 .41414 L
.65082 .42424 L
.64648 .43434 L
.64646 .43438 L
.64206 .44444 L
.63809 .45455 L
.63636 .45754 L
.63317 .46465 L
.62983 .47475 L
.62626 .48032 L
.62415 .48485 L
.61958 .49495 L
.61616 .50266 L
.61499 .50505 L
.61033 .51515 L
.60606 .52451 L
.60567 .52525 L
.60093 .53535 L
.59627 .54545 L
.59596 .54595 L
.59135 .55556 L
.58681 .56566 L
.58586 .56706 L
.58157 .57576 L
.57711 .58586 L
.57576 .58771 L
.57158 .59596 L
.56651 .60606 L
.56566 .60786 L
.56134 .61616 L
.55613 .62626 L
.55556 .62745 L
.5508 .63636 L
.54545 .64645 L
.54543 .64646 L
.5399 .65657 L
.53535 .66483 L
.53431 .66667 L
.52855 .67677 L
.52525 .68248 L
.52263 .68687 L
.5165 .69697 L
.51515 .70012 L
.50998 .70707 L
.50505 .7142 L
.50107 .70707 L
.50504 .69697 L
.50505 .69696 L
.50932 .68687 L
.51368 .67677 L
.51515 .67341 L
.51814 .66667 L
.52263 .65657 L
.52525 .65068 L
.52715 .64646 L
.53169 .63636 L
.53535 .62816 L
.53621 .62626 L
.54075 .61616 L
.54518 .60606 L
.54545 .6056 L
.5498 .59596 L
.55363 .58586 L
.55556 .58277 L
.55879 .57576 L
.56325 .56566 L
.56566 .55985 L
.56771 .55556 L
.57215 .54545 L
.57576 .53692 L
.57656 .53535 L
.58097 .52525 L
.58518 .51515 L
.58586 .51389 L
.58971 .50505 L
.59333 .49495 L
.59596 .49029 L
.59837 .48485 L
.60102 .47475 L
.60606 .46657 L
.60695 .46465 L
.61122 .45455 L
.61527 .44444 L
.61616 .44268 L
.61968 .43434 L
.62307 .42424 L
.62626 .41833 L
.62806 .41414 L
.63031 .40404 L
.63636 .39394 L
.63636 .39394 L
.64051 .38384 L
.64409 .37374 L
.64646 .36903 L
.6487 .36364 L
.65129 .35354 L
.65657 .34402 L
.65682 .34343 L
.66087 .33333 L
.66441 .32323 L
.66667 .31862 L
.66888 .31313 L
.67143 .30303 L
.67677 .29307 L
.67682 .29293 L
.68079 .28283 L
.68416 .27273 L
.68687 .26709 L
.68864 .26263 L
.69085 .25253 L
.69632 .24242 L
.69697 .24098 L
.70031 .23232 L
.70333 .22222 L
.70707 .21449 L
.708 .21212 L
.71184 .20202 L
.7153 .19192 L
.71717 .18778 L
.71945 .18182 L
.72187 .17172 L
.72694 .16162 L
.72727 .16085 L
.73076 .15152 L
.73372 .14141 L
.73737 .13355 L
.73822 .13131 L
.74195 .12121 L
.74523 .11111 L
.74747 .10603 L
.74934 .10101 L
.7514 .09091 L
.7565 .08081 L
.75758 .07827 L
.76034 .07071 L
.76285 .06061 L
.76757 .05051 L
.76768 .05025 L
.77122 .0404 L
.77403 .0303 L
.77778 .02191 L
.7784 .0202 L
.782 .0101 L
.785 0 L
F
0 g
.81498 0 m
.8125 .0101 L
.80808 .01953 L
.80783 .0202 L
.8042 .0303 L
.80137 .0404 L
.79798 .04778 L
.79697 .05051 L
.79331 .06061 L
.79013 .07071 L
.78788 .07572 L
.78599 .08081 L
.78419 .09091 L
.7788 .10101 L
.77778 .10334 L
.77489 .11111 L
.77239 .12121 L
.76768 .13068 L
.76743 .13131 L
.76365 .14141 L
.76056 .15152 L
.75758 .15777 L
.7561 .16162 L
.75228 .17172 L
.74871 .18182 L
.74747 .1845 L
.74462 .19192 L
.742 .20202 L
.73737 .21095 L
.73691 .21212 L
.73299 .22222 L
.72962 .23232 L
.72727 .23712 L
.72517 .24242 L
.72296 .25253 L
.71729 .26263 L
.71717 .26288 L
.71326 .27273 L
.70996 .28283 L
.70707 .28846 L
.70524 .29293 L
.70119 .30303 L
.69718 .31313 L
.69697 .31357 L
.69303 .32323 L
.68961 .33333 L
.68687 .3385 L
.6848 .34343 L
.68249 .35354 L
.67677 .36296 L
Mistroke
.67647 .36364 L
.67224 .37374 L
.66845 .38384 L
.66667 .38716 L
.66376 .39394 L
.66075 .40404 L
.65657 .41102 L
.65517 .41414 L
.65082 .42424 L
.64648 .43434 L
.64646 .43438 L
.64206 .44444 L
.63809 .45455 L
.63636 .45754 L
.63317 .46465 L
.62983 .47475 L
.62626 .48032 L
.62415 .48485 L
.61958 .49495 L
.61616 .50266 L
.61499 .50505 L
.61033 .51515 L
.60606 .52451 L
.60567 .52525 L
.60093 .53535 L
.59627 .54545 L
.59596 .54595 L
.59135 .55556 L
.58681 .56566 L
.58586 .56706 L
.58157 .57576 L
.57711 .58586 L
.57576 .58771 L
.57158 .59596 L
.56651 .60606 L
.56566 .60786 L
.56134 .61616 L
.55613 .62626 L
.55556 .62745 L
.5508 .63636 L
.54545 .64645 L
.54543 .64646 L
.5399 .65657 L
.53535 .66483 L
.53431 .66667 L
.52855 .67677 L
.52525 .68248 L
.52263 .68687 L
.5165 .69697 L
.51515 .70012 L
Mistroke
.50998 .70707 L
.50505 .7142 L
.50107 .70707 L
.50504 .69697 L
.50505 .69696 L
.50932 .68687 L
.51368 .67677 L
.51515 .67341 L
.51814 .66667 L
.52263 .65657 L
.52525 .65068 L
.52715 .64646 L
.53169 .63636 L
.53535 .62816 L
.53621 .62626 L
.54075 .61616 L
.54518 .60606 L
.54545 .6056 L
.5498 .59596 L
.55363 .58586 L
.55556 .58277 L
.55879 .57576 L
.56325 .56566 L
.56566 .55985 L
.56771 .55556 L
.57215 .54545 L
.57576 .53692 L
.57656 .53535 L
.58097 .52525 L
.58518 .51515 L
.58586 .51389 L
.58971 .50505 L
.59333 .49495 L
.59596 .49029 L
.59837 .48485 L
.60102 .47475 L
.60606 .46657 L
.60695 .46465 L
.61122 .45455 L
.61527 .44444 L
.61616 .44268 L
.61968 .43434 L
.62307 .42424 L
.62626 .41833 L
.62806 .41414 L
.63031 .40404 L
.63636 .39394 L
.63636 .39394 L
.64051 .38384 L
.64409 .37374 L
Mistroke
.64646 .36903 L
.6487 .36364 L
.65129 .35354 L
.65657 .34402 L
.65682 .34343 L
.66087 .33333 L
.66441 .32323 L
.66667 .31862 L
.66888 .31313 L
.67143 .30303 L
.67677 .29307 L
.67682 .29293 L
.68079 .28283 L
.68416 .27273 L
.68687 .26709 L
.68864 .26263 L
.69085 .25253 L
.69632 .24242 L
.69697 .24098 L
.70031 .23232 L
.70333 .22222 L
.70707 .21449 L
.708 .21212 L
.71184 .20202 L
.7153 .19192 L
.71717 .18778 L
.71945 .18182 L
.72187 .17172 L
.72694 .16162 L
.72727 .16085 L
.73076 .15152 L
.73372 .14141 L
.73737 .13355 L
.73822 .13131 L
.74195 .12121 L
.74523 .11111 L
.74747 .10603 L
.74934 .10101 L
.7514 .09091 L
.7565 .08081 L
.75758 .07827 L
.76034 .07071 L
.76285 .06061 L
.76757 .05051 L
.76768 .05025 L
.77122 .0404 L
.77403 .0303 L
.77778 .02191 L
.7784 .0202 L
.782 .0101 L
Mistroke
.785 0 L
Mfstroke
.8 g
.50505 .48752 m
.51176 .49495 L
.50505 .50476 L
.50209 .49495 L
F
0 g
.50505 .48752 m
.51176 .49495 L
.50505 .50476 L
.50209 .49495 L
.50505 .48752 L
s
.8 g
.73806 0 m
.73737 .00146 L
.73403 .0101 L
.7311 .0202 L
.72727 .02768 L
.72622 .0303 L
.72226 .0404 L
.71861 .05051 L
.71717 .05348 L
.71433 .06061 L
.71158 .07071 L
.70707 .079 L
.70632 .08081 L
.70226 .09091 L
.69856 .10101 L
.69697 .10418 L
.69412 .11111 L
.69128 .12121 L
.68687 .12905 L
.6859 .13131 L
.68174 .14141 L
.6778 .15152 L
.67677 .15353 L
.67336 .16162 L
.6701 .17172 L
.66667 .17776 L
.6649 .18182 L
.66061 .19192 L
.65657 .20151 L
.65633 .20202 L
.65198 .21212 L
.64801 .22222 L
.64646 .225 L
.64323 .23232 L
.63991 .24242 L
.63636 .24815 L
.63436 .25253 L
.62987 .26263 L
.62626 .27086 L
.62536 .27273 L
.62079 .28283 L
.61624 .29293 L
.61616 .29307 L
.61157 .30303 L
.60726 .31313 L
.60606 .31505 L
.60219 .32323 L
.5982 .33333 L
.59596 .33662 L
.59263 .34343 L
.58779 .35354 L
.58586 .35775 L
.58289 .36364 L
.57794 .37374 L
.57576 .37842 L
.57292 .38384 L
.56786 .39394 L
.56566 .3986 L
.56272 .40404 L
.55751 .41414 L
.55556 .41824 L
.55222 .42424 L
.54686 .43434 L
.54545 .43724 L
.54138 .44444 L
.53582 .45455 L
.53535 .45549 L
.53008 .46465 L
.52525 .47304 L
.52424 .47475 L
.51814 .48485 L
.51515 .48971 L
.50617 .48485 L
.51047 .47475 L
.51485 .46465 L
.51515 .46374 L
.51934 .45455 L
.52383 .44444 L
.52525 .44044 L
.52836 .43434 L
.53289 .42424 L
.53535 .41775 L
.53742 .41414 L
.54195 .40404 L
.54545 .39544 L
.54647 .39394 L
.55099 .38384 L
.55545 .37374 L
.55556 .37355 L
.55998 .36364 L
.5639 .35354 L
.56566 .35058 L
.56889 .34343 L
.57203 .33333 L
.57576 .32746 L
.57774 .32323 L
.58214 .31313 L
.58586 .30432 L
.5865 .30303 L
.59087 .29293 L
.59497 .28283 L
.59596 .28096 L
.59952 .27273 L
.60296 .26263 L
.60606 .25712 L
.60809 .25253 L
.61045 .24242 L
.61616 .23321 L
.61657 .23232 L
.6208 .22222 L
.62464 .21212 L
.62626 .20894 L
.62917 .20202 L
.63222 .19192 L
.63636 .18438 L
.63747 .18182 L
.6416 .17172 L
.64551 .16162 L
.64646 .15965 L
.64979 .15152 L
.65299 .14141 L
.65657 .13451 L
.6579 .13131 L
.65978 .12121 L
.66578 .11111 L
.66667 .10922 L
.66995 .10101 L
.67306 .09091 L
.67677 .08355 L
.67788 .08081 L
.68184 .07071 L
.68552 .06061 L
.68687 .05768 L
.68968 .05051 L
.6925 .0404 L
.69697 .03151 L
.69746 .0303 L
.70134 .0202 L
.70473 .0101 L
.70707 .00553 L
.70903 0 L
F
0 g
.73806 0 m
.73737 .00146 L
.73403 .0101 L
.7311 .0202 L
.72727 .02768 L
.72622 .0303 L
.72226 .0404 L
.71861 .05051 L
.71717 .05348 L
.71433 .06061 L
.71158 .07071 L
.70707 .079 L
.70632 .08081 L
.70226 .09091 L
.69856 .10101 L
.69697 .10418 L
.69412 .11111 L
.69128 .12121 L
.68687 .12905 L
.6859 .13131 L
.68174 .14141 L
.6778 .15152 L
.67677 .15353 L
.67336 .16162 L
.6701 .17172 L
.66667 .17776 L
.6649 .18182 L
.66061 .19192 L
.65657 .20151 L
.65633 .20202 L
.65198 .21212 L
.64801 .22222 L
.64646 .225 L
.64323 .23232 L
.63991 .24242 L
.63636 .24815 L
.63436 .25253 L
.62987 .26263 L
.62626 .27086 L
.62536 .27273 L
.62079 .28283 L
.61624 .29293 L
.61616 .29307 L
.61157 .30303 L
.60726 .31313 L
.60606 .31505 L
.60219 .32323 L
.5982 .33333 L
.59596 .33662 L
.59263 .34343 L
Mistroke
.58779 .35354 L
.58586 .35775 L
.58289 .36364 L
.57794 .37374 L
.57576 .37842 L
.57292 .38384 L
.56786 .39394 L
.56566 .3986 L
.56272 .40404 L
.55751 .41414 L
.55556 .41824 L
.55222 .42424 L
.54686 .43434 L
.54545 .43724 L
.54138 .44444 L
.53582 .45455 L
.53535 .45549 L
.53008 .46465 L
.52525 .47304 L
.52424 .47475 L
.51814 .48485 L
.51515 .48971 L
.50617 .48485 L
.51047 .47475 L
.51485 .46465 L
.51515 .46374 L
.51934 .45455 L
.52383 .44444 L
.52525 .44044 L
.52836 .43434 L
.53289 .42424 L
.53535 .41775 L
.53742 .41414 L
.54195 .40404 L
.54545 .39544 L
.54647 .39394 L
.55099 .38384 L
.55545 .37374 L
.55556 .37355 L
.55998 .36364 L
.5639 .35354 L
.56566 .35058 L
.56889 .34343 L
.57203 .33333 L
.57576 .32746 L
.57774 .32323 L
.58214 .31313 L
.58586 .30432 L
.5865 .30303 L
.59087 .29293 L
Mistroke
.59497 .28283 L
.59596 .28096 L
.59952 .27273 L
.60296 .26263 L
.60606 .25712 L
.60809 .25253 L
.61045 .24242 L
.61616 .23321 L
.61657 .23232 L
.6208 .22222 L
.62464 .21212 L
.62626 .20894 L
.62917 .20202 L
.63222 .19192 L
.63636 .18438 L
.63747 .18182 L
.6416 .17172 L
.64551 .16162 L
.64646 .15965 L
.64979 .15152 L
.65299 .14141 L
.65657 .13451 L
.6579 .13131 L
.65978 .12121 L
.66578 .11111 L
.66667 .10922 L
.66995 .10101 L
.67306 .09091 L
.67677 .08355 L
.67788 .08081 L
.68184 .07071 L
.68552 .06061 L
.68687 .05768 L
.68968 .05051 L
.6925 .0404 L
.69697 .03151 L
.69746 .0303 L
.70134 .0202 L
.70473 .0101 L
.70707 .00553 L
.70903 0 L
Mfstroke
.2 g
.65313 0 m
.64974 .0101 L
.64646 .01561 L
.6444 .0202 L
.63998 .0303 L
.63636 .03869 L
.63556 .0404 L
.63106 .05051 L
.62667 .06061 L
.62626 .06132 L
.622 .07071 L
.61795 .08081 L
.61616 .08371 L
.61281 .09091 L
.60925 .10101 L
.60606 .1057 L
.60345 .11111 L
.5987 .12121 L
.59596 .12726 L
.59392 .13131 L
.58908 .14141 L
.58586 .14838 L
.5842 .15152 L
.57925 .16162 L
.57576 .16905 L
.57427 .17172 L
.5692 .18182 L
.56566 .18926 L
.56409 .19192 L
.5589 .20202 L
.55556 .209 L
.55364 .21212 L
.54828 .22222 L
.54545 .22814 L
.54284 .23232 L
.5373 .24242 L
.53535 .24649 L
.53162 .25253 L
.52582 .26263 L
.52525 .26378 L
.51978 .27273 L
.51515 .28027 L
.5073 .27273 L
.51163 .26263 L
.51515 .25453 L
.51604 .25253 L
.52053 .24242 L
.52502 .23232 L
.52525 .23171 L
.52956 .22222 L
.53408 .21212 L
.53535 .20887 L
.53863 .20202 L
.54315 .19192 L
.54545 .18617 L
.54767 .18182 L
.55219 .17172 L
.55556 .1636 L
.55667 .16162 L
.56116 .15152 L
.5656 .14141 L
.56566 .14131 L
.57007 .13131 L
.57399 .12121 L
.57576 .11815 L
.57891 .11111 L
.58205 .10101 L
.58586 .09482 L
.58766 .09091 L
.59202 .08081 L
.59596 .07148 L
.59634 .07071 L
.60066 .06061 L
.60461 .05051 L
.60606 .04776 L
.60922 .0404 L
.61243 .0303 L
.61616 .02369 L
.6177 .0202 L
.62192 .0101 L
.62606 0 L
F
0 g
.65313 0 m
.64974 .0101 L
.64646 .01561 L
.6444 .0202 L
.63998 .0303 L
.63636 .03869 L
.63556 .0404 L
.63106 .05051 L
.62667 .06061 L
.62626 .06132 L
.622 .07071 L
.61795 .08081 L
.61616 .08371 L
.61281 .09091 L
.60925 .10101 L
.60606 .1057 L
.60345 .11111 L
.5987 .12121 L
.59596 .12726 L
.59392 .13131 L
.58908 .14141 L
.58586 .14838 L
.5842 .15152 L
.57925 .16162 L
.57576 .16905 L
.57427 .17172 L
.5692 .18182 L
.56566 .18926 L
.56409 .19192 L
.5589 .20202 L
.55556 .209 L
.55364 .21212 L
.54828 .22222 L
.54545 .22814 L
.54284 .23232 L
.5373 .24242 L
.53535 .24649 L
.53162 .25253 L
.52582 .26263 L
.52525 .26378 L
.51978 .27273 L
.51515 .28027 L
.5073 .27273 L
.51163 .26263 L
.51515 .25453 L
.51604 .25253 L
.52053 .24242 L
.52502 .23232 L
.52525 .23171 L
.52956 .22222 L
Mistroke
.53408 .21212 L
.53535 .20887 L
.53863 .20202 L
.54315 .19192 L
.54545 .18617 L
.54767 .18182 L
.55219 .17172 L
.55556 .1636 L
.55667 .16162 L
.56116 .15152 L
.5656 .14141 L
.56566 .14131 L
.57007 .13131 L
.57399 .12121 L
.57576 .11815 L
.57891 .11111 L
.58205 .10101 L
.58586 .09482 L
.58766 .09091 L
.59202 .08081 L
.59596 .07148 L
.59634 .07071 L
.60066 .06061 L
.60461 .05051 L
.60606 .04776 L
.60922 .0404 L
.61243 .0303 L
.61616 .02369 L
.6177 .0202 L
.62192 .0101 L
.62606 0 L
Mfstroke
.8 g
.88665 0 m
.88505 .0101 L
.8802 .0202 L
.87879 .02373 L
.87656 .0303 L
.87492 .0404 L
.87004 .05051 L
.86869 .05386 L
.86638 .06061 L
.86465 .07071 L
.85977 .08081 L
.85859 .08372 L
.85611 .09091 L
.85422 .10101 L
.84938 .11111 L
.84848 .11332 L
.84574 .12121 L
.84364 .13131 L
.83888 .14141 L
.83838 .14264 L
.83528 .15152 L
.83293 .16162 L
.82828 .17168 L
.82827 .17172 L
.82471 .18182 L
.82209 .19192 L
.81818 .20049 L
.81762 .20202 L
.81403 .21212 L
.81113 .22222 L
.80808 .229 L
.80687 .23232 L
.80324 .24242 L
.80006 .25253 L
.79798 .25722 L
.796 .26263 L
.79417 .27273 L
.78888 .28283 L
.78788 .28513 L
.78501 .29293 L
.78257 .30303 L
.77778 .31276 L
.77764 .31313 L
.77389 .32323 L
.77091 .33333 L
.76768 .34016 L
.76643 .34343 L
.76265 .35354 L
.75921 .36364 L
.75758 .3672 L
.75508 .37374 L
.75273 .38384 L
.74747 .39391 L
.74746 .39394 L
.74359 .40404 L
.74047 .41414 L
.73737 .42042 L
.73587 .42424 L
.73196 .43434 L
.72825 .44444 L
.72727 .44653 L
.72411 .45455 L
.72123 .46465 L
.71717 .47238 L
.71621 .47475 L
.7122 .48485 L
.70851 .49495 L
.70707 .49787 L
.70416 .50505 L
.70133 .51515 L
.69697 .52307 L
.69605 .52525 L
.69194 .53535 L
.68811 .54545 L
.68687 .5479 L
.68369 .55556 L
.6806 .56566 L
.67677 .57246 L
.67535 .57576 L
.67112 .58586 L
.66697 .59596 L
.66667 .59655 L
.66262 .60606 L
.65896 .61616 L
.65657 .62044 L
.65402 .62626 L
.65125 .63636 L
.64646 .64392 L
.6453 .64646 L
.64088 .65657 L
.6365 .66667 L
.63636 .66691 L
.63197 .67677 L
.62794 .68687 L
.62626 .6897 L
.62294 .69697 L
.61945 .70707 L
.61616 .71209 L
.61375 .71717 L
.6091 .72727 L
.60606 .73405 L
.60441 .73737 L
.59967 .74747 L
.59596 .75557 L
.59491 .75758 L
.59006 .76768 L
.58586 .77662 L
.58521 .77778 L
.58026 .78788 L
.57576 .79723 L
.5753 .79798 L
.57023 .80808 L
.56566 .81743 L
.56515 .81818 L
.55995 .82828 L
.55556 .83725 L
.55472 .83838 L
.54938 .84848 L
.54545 .85662 L
.54397 .85859 L
.53843 .86869 L
.53535 .87525 L
.53279 .87879 L
.527 .88889 L
.52525 .89265 L
.52102 .89899 L
.51515 .90859 L
.50818 .89899 L
.51252 .88889 L
.51515 .88285 L
.51695 .87879 L
.52144 .86869 L
.52525 .86012 L
.52594 .85859 L
.53048 .84848 L
.53479 .83838 L
.53535 .8375 L
.53955 .82828 L
.54407 .81818 L
.54545 .81475 L
.5486 .80808 L
.5531 .79798 L
.55556 .79198 L
.55759 .78788 L
.56207 .77778 L
.56566 .76928 L
.56652 .76768 L
.57098 .75758 L
.57527 .74747 L
.57576 .74658 L
.57981 .73737 L
.58353 .72727 L
.58586 .72321 L
.58856 .71717 L
.59139 .70707 L
.59596 .69969 L
.59722 .69697 L
.60154 .68687 L
.60575 .67677 L
.60606 .67615 L
.61009 .66667 L
.61374 .65657 L
.61616 .65204 L
.61856 .64646 L
.62127 .63636 L
.62626 .6278 L
.62695 .62626 L
.63113 .61616 L
.63499 .60606 L
.63636 .60331 L
.63941 .59596 L
.64251 .58586 L
.64646 .57846 L
.64761 .57576 L
.6517 .56566 L
.65556 .55556 L
.65657 .55345 L
.6598 .54545 L
.66292 .53535 L
.66667 .52805 L
.66782 .52525 L
.67182 .51515 L
.67556 .50505 L
.67677 .50247 L
.67974 .49495 L
.68268 .48485 L
.68687 .47655 L
.6876 .47475 L
.69152 .46465 L
.69504 .45455 L
.69697 .45038 L
.69928 .44444 L
.7018 .43434 L
.70696 .42424 L
.70707 .42399 L
.71083 .41414 L
.71397 .40404 L
.71717 .39721 L
.71844 .39394 L
.72019 .38384 L
.72573 .37374 L
.72727 .37025 L
.72977 .36364 L
.73227 .35354 L
.73721 .34343 L
.73737 .34304 L
.74097 .33333 L
.74392 .32323 L
.74747 .31547 L
.74836 .31313 L
.75205 .30303 L
.75528 .29293 L
.75758 .28768 L
.75936 .28283 L
.76134 .27273 L
.76642 .26263 L
.76768 .25966 L
.77026 .25253 L
.77264 .24242 L
.77739 .23232 L
.77778 .23137 L
.78105 .22222 L
.7837 .21212 L
.78788 .20279 L
.78816 .20202 L
.79173 .19192 L
.79457 .18182 L
.79798 .17395 L
.79878 .17172 L
.80231 .16162 L
.80527 .15152 L
.80808 .14486 L
.8093 .14141 L
.81065 .13131 L
.81583 .12121 L
.81818 .11552 L
.81972 .11111 L
.82126 .10101 L
.82626 .09091 L
.82828 .08593 L
.83005 .08081 L
.8317 .07071 L
.83657 .06061 L
.83838 .05609 L
.84029 .05051 L
.84199 .0404 L
.84678 .0303 L
.84848 .026 L
.85045 .0202 L
.85213 .0101 L
.85688 0 L
F
0 g
.88665 0 m
.88505 .0101 L
.8802 .0202 L
.87879 .02373 L
.87656 .0303 L
.87492 .0404 L
.87004 .05051 L
.86869 .05386 L
.86638 .06061 L
.86465 .07071 L
.85977 .08081 L
.85859 .08372 L
.85611 .09091 L
.85422 .10101 L
.84938 .11111 L
.84848 .11332 L
.84574 .12121 L
.84364 .13131 L
.83888 .14141 L
.83838 .14264 L
.83528 .15152 L
.83293 .16162 L
.82828 .17168 L
.82827 .17172 L
.82471 .18182 L
.82209 .19192 L
.81818 .20049 L
.81762 .20202 L
.81403 .21212 L
.81113 .22222 L
.80808 .229 L
.80687 .23232 L
.80324 .24242 L
.80006 .25253 L
.79798 .25722 L
.796 .26263 L
.79417 .27273 L
.78888 .28283 L
.78788 .28513 L
.78501 .29293 L
.78257 .30303 L
.77778 .31276 L
.77764 .31313 L
.77389 .32323 L
.77091 .33333 L
.76768 .34016 L
.76643 .34343 L
.76265 .35354 L
.75921 .36364 L
.75758 .3672 L
Mistroke
.75508 .37374 L
.75273 .38384 L
.74747 .39391 L
.74746 .39394 L
.74359 .40404 L
.74047 .41414 L
.73737 .42042 L
.73587 .42424 L
.73196 .43434 L
.72825 .44444 L
.72727 .44653 L
.72411 .45455 L
.72123 .46465 L
.71717 .47238 L
.71621 .47475 L
.7122 .48485 L
.70851 .49495 L
.70707 .49787 L
.70416 .50505 L
.70133 .51515 L
.69697 .52307 L
.69605 .52525 L
.69194 .53535 L
.68811 .54545 L
.68687 .5479 L
.68369 .55556 L
.6806 .56566 L
.67677 .57246 L
.67535 .57576 L
.67112 .58586 L
.66697 .59596 L
.66667 .59655 L
.66262 .60606 L
.65896 .61616 L
.65657 .62044 L
.65402 .62626 L
.65125 .63636 L
.64646 .64392 L
.6453 .64646 L
.64088 .65657 L
.6365 .66667 L
.63636 .66691 L
.63197 .67677 L
.62794 .68687 L
.62626 .6897 L
.62294 .69697 L
.61945 .70707 L
.61616 .71209 L
.61375 .71717 L
.6091 .72727 L
Mistroke
.60606 .73405 L
.60441 .73737 L
.59967 .74747 L
.59596 .75557 L
.59491 .75758 L
.59006 .76768 L
.58586 .77662 L
.58521 .77778 L
.58026 .78788 L
.57576 .79723 L
.5753 .79798 L
.57023 .80808 L
.56566 .81743 L
.56515 .81818 L
.55995 .82828 L
.55556 .83725 L
.55472 .83838 L
.54938 .84848 L
.54545 .85662 L
.54397 .85859 L
.53843 .86869 L
.53535 .87525 L
.53279 .87879 L
.527 .88889 L
.52525 .89265 L
.52102 .89899 L
.51515 .90859 L
.50818 .89899 L
.51252 .88889 L
.51515 .88285 L
.51695 .87879 L
.52144 .86869 L
.52525 .86012 L
.52594 .85859 L
.53048 .84848 L
.53479 .83838 L
.53535 .8375 L
.53955 .82828 L
.54407 .81818 L
.54545 .81475 L
.5486 .80808 L
.5531 .79798 L
.55556 .79198 L
.55759 .78788 L
.56207 .77778 L
.56566 .76928 L
.56652 .76768 L
.57098 .75758 L
.57527 .74747 L
.57576 .74658 L
Mistroke
.57981 .73737 L
.58353 .72727 L
.58586 .72321 L
.58856 .71717 L
.59139 .70707 L
.59596 .69969 L
.59722 .69697 L
.60154 .68687 L
.60575 .67677 L
.60606 .67615 L
.61009 .66667 L
.61374 .65657 L
.61616 .65204 L
.61856 .64646 L
.62127 .63636 L
.62626 .6278 L
.62695 .62626 L
.63113 .61616 L
.63499 .60606 L
.63636 .60331 L
.63941 .59596 L
.64251 .58586 L
.64646 .57846 L
.64761 .57576 L
.6517 .56566 L
.65556 .55556 L
.65657 .55345 L
.6598 .54545 L
.66292 .53535 L
.66667 .52805 L
.66782 .52525 L
.67182 .51515 L
.67556 .50505 L
.67677 .50247 L
.67974 .49495 L
.68268 .48485 L
.68687 .47655 L
.6876 .47475 L
.69152 .46465 L
.69504 .45455 L
.69697 .45038 L
.69928 .44444 L
.7018 .43434 L
.70696 .42424 L
.70707 .42399 L
.71083 .41414 L
.71397 .40404 L
.71717 .39721 L
.71844 .39394 L
.72019 .38384 L
Mistroke
.72573 .37374 L
.72727 .37025 L
.72977 .36364 L
.73227 .35354 L
.73721 .34343 L
.73737 .34304 L
.74097 .33333 L
.74392 .32323 L
.74747 .31547 L
.74836 .31313 L
.75205 .30303 L
.75528 .29293 L
.75758 .28768 L
.75936 .28283 L
.76134 .27273 L
.76642 .26263 L
.76768 .25966 L
.77026 .25253 L
.77264 .24242 L
.77739 .23232 L
.77778 .23137 L
.78105 .22222 L
.7837 .21212 L
.78788 .20279 L
.78816 .20202 L
.79173 .19192 L
.79457 .18182 L
.79798 .17395 L
.79878 .17172 L
.80231 .16162 L
.80527 .15152 L
.80808 .14486 L
.8093 .14141 L
.81065 .13131 L
.81583 .12121 L
.81818 .11552 L
.81972 .11111 L
.82126 .10101 L
.82626 .09091 L
.82828 .08593 L
.83005 .08081 L
.8317 .07071 L
.83657 .06061 L
.83838 .05609 L
.84029 .05051 L
.84199 .0404 L
.84678 .0303 L
.84848 .026 L
.85045 .0202 L
.85213 .0101 L
Mistroke
.85688 0 L
Mfstroke
.5 g
.50848 1 m
.51379 .9899 L
.51515 .98727 L
.51905 .9798 L
.52424 .9697 L
.52525 .9677 L
.52939 .9596 L
.53448 .94949 L
.53535 .94774 L
.53954 .93939 L
.54453 .92929 L
.54545 .92739 L
.54949 .91919 L
.5544 .90909 L
.55556 .90667 L
.55927 .89899 L
.56409 .88889 L
.56566 .88557 L
.56888 .87879 L
.57363 .86869 L
.57576 .8641 L
.57834 .85859 L
.58303 .84848 L
.58586 .84227 L
.58765 .83838 L
.59228 .82828 L
.59596 .82009 L
.59683 .81818 L
.60139 .80808 L
.60588 .79798 L
.60606 .79757 L
.61038 .78788 L
.61483 .77778 L
.61616 .7747 L
.61925 .76768 L
.62366 .75758 L
.62626 .75149 L
.628 .74747 L
.63237 .73737 L
.63636 .72795 L
.63665 .72727 L
.64097 .71717 L
.64523 .70707 L
.64646 .70408 L
.64946 .69697 L
.6537 .68687 L
.65657 .67989 L
.65787 .67677 L
.66206 .66667 L
.66619 .65657 L
.66667 .65538 L
.67033 .64646 L
.67445 .63636 L
.67677 .63056 L
.67851 .62626 L
.6826 .61616 L
.68662 .60606 L
.68687 .60542 L
.69066 .59596 L
.69468 .58586 L
.69697 .57998 L
.69864 .57576 L
.70264 .56566 L
.70657 .55556 L
.70707 .55423 L
.71051 .54545 L
.71444 .53535 L
.71717 .52819 L
.71831 .52525 L
.72222 .51515 L
.72608 .50505 L
.72727 .50185 L
.72991 .49495 L
.73377 .48485 L
.73737 .47521 L
.73755 .47475 L
.74138 .46465 L
.74518 .45455 L
.74747 .44829 L
.74891 .44444 L
.7527 .43434 L
.75643 .42424 L
.75758 .42108 L
.76015 .41414 L
.76389 .40404 L
.76755 .39394 L
.76768 .39359 L
.77126 .38384 L
.77495 .37374 L
.77778 .36581 L
.77857 .36364 L
.78224 .35354 L
.78589 .34343 L
.78788 .33776 L
.78947 .33333 L
.79311 .32323 L
.7967 .31313 L
.79798 .30943 L
.80026 .30303 L
.80387 .29293 L
.8074 .28283 L
.80808 .28083 L
.81094 .27273 L
.81451 .26263 L
.81799 .25253 L
.81818 .25196 L
.82152 .24242 L
.82505 .23232 L
.82828 .22283 L
.82849 .22222 L
.832 .21212 L
.83549 .20202 L
.83838 .19343 L
.8389 .19192 L
.84238 .18182 L
.84584 .17172 L
.84848 .16376 L
.84921 .16162 L
.85266 .15152 L
.85609 .14141 L
.85859 .13384 L
.85944 .13131 L
.86286 .12121 L
.86626 .11111 L
.86869 .10366 L
.86957 .10101 L
.87296 .09091 L
.87634 .08081 L
.87879 .07322 L
.87962 .07071 L
.88299 .06061 L
.88633 .05051 L
.88889 .04253 L
.88959 .0404 L
.89292 .0303 L
.89625 .0202 L
.89899 .01159 L
.89947 .0101 L
.90278 0 L
1 0 L
1 1 L
F
0 g
.50848 1 m
.51379 .9899 L
.51515 .98727 L
.51905 .9798 L
.52424 .9697 L
.52525 .9677 L
.52939 .9596 L
.53448 .94949 L
.53535 .94774 L
.53954 .93939 L
.54453 .92929 L
.54545 .92739 L
.54949 .91919 L
.5544 .90909 L
.55556 .90667 L
.55927 .89899 L
.56409 .88889 L
.56566 .88557 L
.56888 .87879 L
.57363 .86869 L
.57576 .8641 L
.57834 .85859 L
.58303 .84848 L
.58586 .84227 L
.58765 .83838 L
.59228 .82828 L
.59596 .82009 L
.59683 .81818 L
.60139 .80808 L
.60588 .79798 L
.60606 .79757 L
.61038 .78788 L
.61483 .77778 L
.61616 .7747 L
.61925 .76768 L
.62366 .75758 L
.62626 .75149 L
.628 .74747 L
.63237 .73737 L
.63636 .72795 L
.63665 .72727 L
.64097 .71717 L
.64523 .70707 L
.64646 .70408 L
.64946 .69697 L
.6537 .68687 L
.65657 .67989 L
.65787 .67677 L
.66206 .66667 L
.66619 .65657 L
Mistroke
.66667 .65538 L
.67033 .64646 L
.67445 .63636 L
.67677 .63056 L
.67851 .62626 L
.6826 .61616 L
.68662 .60606 L
.68687 .60542 L
.69066 .59596 L
.69468 .58586 L
.69697 .57998 L
.69864 .57576 L
.70264 .56566 L
.70657 .55556 L
.70707 .55423 L
.71051 .54545 L
.71444 .53535 L
.71717 .52819 L
.71831 .52525 L
.72222 .51515 L
.72608 .50505 L
.72727 .50185 L
.72991 .49495 L
.73377 .48485 L
.73737 .47521 L
.73755 .47475 L
.74138 .46465 L
.74518 .45455 L
.74747 .44829 L
.74891 .44444 L
.7527 .43434 L
.75643 .42424 L
.75758 .42108 L
.76015 .41414 L
.76389 .40404 L
.76755 .39394 L
.76768 .39359 L
.77126 .38384 L
.77495 .37374 L
.77778 .36581 L
.77857 .36364 L
.78224 .35354 L
.78589 .34343 L
.78788 .33776 L
.78947 .33333 L
.79311 .32323 L
.7967 .31313 L
.79798 .30943 L
.80026 .30303 L
.80387 .29293 L
Mistroke
.8074 .28283 L
.80808 .28083 L
.81094 .27273 L
.81451 .26263 L
.81799 .25253 L
.81818 .25196 L
.82152 .24242 L
.82505 .23232 L
.82828 .22283 L
.82849 .22222 L
.832 .21212 L
.83549 .20202 L
.83838 .19343 L
.8389 .19192 L
.84238 .18182 L
.84584 .17172 L
.84848 .16376 L
.84921 .16162 L
.85266 .15152 L
.85609 .14141 L
.85859 .13384 L
.85944 .13131 L
.86286 .12121 L
.86626 .11111 L
.86869 .10366 L
.86957 .10101 L
.87296 .09091 L
.87634 .08081 L
.87879 .07322 L
.87962 .07071 L
.88299 .06061 L
.88633 .05051 L
.88889 .04253 L
.88959 .0404 L
.89292 .0303 L
.89625 .0202 L
.89899 .01159 L
.89947 .0101 L
.90278 0 L
Mfstroke
.4 g
.5221 1 m
.52525 .99378 L
.5272 .9899 L
.53226 .9798 L
.53535 .97356 L
.53726 .9697 L
.54222 .9596 L
.54545 .95298 L
.54714 .94949 L
.55202 .93939 L
.55556 .93202 L
.55685 .92929 L
.56165 .91919 L
.56566 .9107 L
.56641 .90909 L
.57112 .89899 L
.57576 .88902 L
.57582 .88889 L
.58046 .87879 L
.58509 .86869 L
.58586 .867 L
.58966 .85859 L
.59423 .84848 L
.59596 .84462 L
.59873 .83838 L
.60324 .82828 L
.60606 .82191 L
.60769 .81818 L
.61213 .80808 L
.61616 .79886 L
.61654 .79798 L
.62091 .78788 L
.62528 .77778 L
.62626 .77548 L
.62958 .76768 L
.6339 .75758 L
.63636 .75177 L
.63816 .74747 L
.64242 .73737 L
.64646 .72774 L
.64666 .72727 L
.65085 .71717 L
.65505 .70707 L
.65657 .7034 L
.65919 .69697 L
.66334 .68687 L
.66667 .67873 L
.66746 .67677 L
.67155 .66667 L
.67564 .65657 L
.67677 .65376 L
.67967 .64646 L
.68373 .63636 L
.68687 .62849 L
.68774 .62626 L
.69173 .61616 L
.69573 .60606 L
.69697 .60291 L
.69967 .59596 L
.70363 .58586 L
.70707 .57703 L
.70755 .57576 L
.71145 .56566 L
.71536 .55556 L
.71717 .55085 L
.71921 .54545 L
.72308 .53535 L
.72694 .52525 L
.72727 .52438 L
.73074 .51515 L
.73457 .50505 L
.73737 .49763 L
.73836 .49495 L
.74214 .48485 L
.74592 .47475 L
.74747 .47058 L
.74965 .46465 L
.7534 .45455 L
.75714 .44444 L
.75758 .44326 L
.76082 .43434 L
.76453 .42424 L
.76768 .41565 L
.76821 .41414 L
.77186 .40404 L
.77554 .39394 L
.77778 .38776 L
.77916 .38384 L
.78279 .37374 L
.78644 .36364 L
.78788 .3596 L
.79001 .35354 L
.79361 .34343 L
.79722 .33333 L
.79798 .33117 L
.80075 .32323 L
.80432 .31313 L
.80788 .30303 L
.80808 .30247 L
.81138 .29293 L
.81493 .28283 L
.81818 .2735 L
.81844 .27273 L
.82191 .26263 L
.82543 .25253 L
.82828 .24426 L
.8289 .24242 L
.83234 .23232 L
.83583 .22222 L
.83838 .21477 L
.83926 .21212 L
.84268 .20202 L
.84614 .19192 L
.84848 .18501 L
.84953 .18182 L
.85293 .17172 L
.85636 .16162 L
.85859 .15499 L
.85972 .15152 L
.86309 .14141 L
.86649 .13131 L
.86869 .12472 L
.86982 .12121 L
.87316 .11111 L
.87654 .10101 L
.87879 .0942 L
.87984 .09091 L
.88315 .08081 L
.8865 .07071 L
.88889 .06342 L
.88978 .06061 L
.89306 .05051 L
.89638 .0404 L
.89899 .03239 L
.89964 .0303 L
.90289 .0202 L
.90619 .0101 L
.90909 .00112 L
.90944 0 L
1 0 L
1 1 L
F
0 g
.5221 1 m
.52525 .99378 L
.5272 .9899 L
.53226 .9798 L
.53535 .97356 L
.53726 .9697 L
.54222 .9596 L
.54545 .95298 L
.54714 .94949 L
.55202 .93939 L
.55556 .93202 L
.55685 .92929 L
.56165 .91919 L
.56566 .9107 L
.56641 .90909 L
.57112 .89899 L
.57576 .88902 L
.57582 .88889 L
.58046 .87879 L
.58509 .86869 L
.58586 .867 L
.58966 .85859 L
.59423 .84848 L
.59596 .84462 L
.59873 .83838 L
.60324 .82828 L
.60606 .82191 L
.60769 .81818 L
.61213 .80808 L
.61616 .79886 L
.61654 .79798 L
.62091 .78788 L
.62528 .77778 L
.62626 .77548 L
.62958 .76768 L
.6339 .75758 L
.63636 .75177 L
.63816 .74747 L
.64242 .73737 L
.64646 .72774 L
.64666 .72727 L
.65085 .71717 L
.65505 .70707 L
.65657 .7034 L
.65919 .69697 L
.66334 .68687 L
.66667 .67873 L
.66746 .67677 L
.67155 .66667 L
.67564 .65657 L
Mistroke
.67677 .65376 L
.67967 .64646 L
.68373 .63636 L
.68687 .62849 L
.68774 .62626 L
.69173 .61616 L
.69573 .60606 L
.69697 .60291 L
.69967 .59596 L
.70363 .58586 L
.70707 .57703 L
.70755 .57576 L
.71145 .56566 L
.71536 .55556 L
.71717 .55085 L
.71921 .54545 L
.72308 .53535 L
.72694 .52525 L
.72727 .52438 L
.73074 .51515 L
.73457 .50505 L
.73737 .49763 L
.73836 .49495 L
.74214 .48485 L
.74592 .47475 L
.74747 .47058 L
.74965 .46465 L
.7534 .45455 L
.75714 .44444 L
.75758 .44326 L
.76082 .43434 L
.76453 .42424 L
.76768 .41565 L
.76821 .41414 L
.77186 .40404 L
.77554 .39394 L
.77778 .38776 L
.77916 .38384 L
.78279 .37374 L
.78644 .36364 L
.78788 .3596 L
.79001 .35354 L
.79361 .34343 L
.79722 .33333 L
.79798 .33117 L
.80075 .32323 L
.80432 .31313 L
.80788 .30303 L
.80808 .30247 L
.81138 .29293 L
Mistroke
.81493 .28283 L
.81818 .2735 L
.81844 .27273 L
.82191 .26263 L
.82543 .25253 L
.82828 .24426 L
.8289 .24242 L
.83234 .23232 L
.83583 .22222 L
.83838 .21477 L
.83926 .21212 L
.84268 .20202 L
.84614 .19192 L
.84848 .18501 L
.84953 .18182 L
.85293 .17172 L
.85636 .16162 L
.85859 .15499 L
.85972 .15152 L
.86309 .14141 L
.86649 .13131 L
.86869 .12472 L
.86982 .12121 L
.87316 .11111 L
.87654 .10101 L
.87879 .0942 L
.87984 .09091 L
.88315 .08081 L
.8865 .07071 L
.88889 .06342 L
.88978 .06061 L
.89306 .05051 L
.89638 .0404 L
.89899 .03239 L
.89964 .0303 L
.90289 .0202 L
.90619 .0101 L
.90909 .00112 L
.90944 0 L
Mfstroke
.3 g
.53614 1 m
.54101 .9899 L
.54545 .98079 L
.54591 .9798 L
.55067 .9697 L
.55553 .9596 L
.55556 .95954 L
.56019 .94949 L
.56497 .93939 L
.56566 .93793 L
.56956 .92929 L
.57427 .91919 L
.57576 .91599 L
.57881 .90909 L
.58344 .89899 L
.58586 .8937 L
.58793 .88889 L
.59247 .87879 L
.59596 .87108 L
.59696 .86869 L
.60139 .85859 L
.60591 .84848 L
.60606 .84814 L
.61021 .83838 L
.61466 .82828 L
.61616 .82486 L
.61892 .81818 L
.6233 .80808 L
.62626 .80126 L
.62758 .79798 L
.63184 .78788 L
.63618 .77778 L
.63636 .77735 L
.64029 .76768 L
.64458 .75758 L
.64646 .75311 L
.64868 .74747 L
.65288 .73737 L
.65657 .72858 L
.65706 .72727 L
.6611 .71717 L
.66529 .70707 L
.66667 .70373 L
.66926 .69697 L
.67337 .68687 L
.67677 .67857 L
.67743 .67677 L
.68138 .66667 L
.68548 .65657 L
.68687 .65312 L
.68935 .64646 L
.69337 .63636 L
.69697 .62738 L
.69736 .62626 L
.70119 .61616 L
.7052 .60606 L
.70707 .60133 L
.709 .59596 L
.71291 .58586 L
.71688 .57576 L
.71717 .575 L
.72057 .56566 L
.72449 .55556 L
.72727 .54837 L
.72827 .54545 L
.73203 .53535 L
.73593 .52525 L
.73737 .52147 L
.73957 .51515 L
.74337 .50505 L
.74722 .49495 L
.74747 .49429 L
.75078 .48485 L
.75459 .47475 L
.75758 .46681 L
.75828 .46465 L
.76189 .45455 L
.76568 .44444 L
.76768 .43907 L
.76923 .43434 L
.77289 .42424 L
.77664 .41414 L
.77778 .41105 L
.78011 .40404 L
.78378 .39394 L
.78749 .38384 L
.78788 .38276 L
.79089 .37374 L
.79455 .36364 L
.79798 .35421 L
.79818 .35354 L
.80157 .34343 L
.80522 .33333 L
.80808 .32538 L
.80873 .32323 L
.81215 .31313 L
.81578 .30303 L
.81818 .29629 L
.8192 .29293 L
.82264 .28283 L
.82624 .27273 L
.82828 .26693 L
.82959 .26263 L
.83303 .25253 L
.8366 .24242 L
.83838 .23732 L
.83989 .23232 L
.84332 .22222 L
.84687 .21212 L
.84848 .20746 L
.85011 .20202 L
.85353 .19192 L
.85704 .18182 L
.85859 .17733 L
.86025 .17172 L
.86364 .16162 L
.86713 .15152 L
.86869 .14695 L
.87031 .14141 L
.87367 .13131 L
.87713 .12121 L
.87879 .11632 L
.88029 .11111 L
.88361 .10101 L
.88705 .09091 L
.88889 .08545 L
.89019 .08081 L
.89347 .07071 L
.89689 .06061 L
.89899 .05432 L
.90003 .05051 L
.90325 .0404 L
.90665 .0303 L
.90909 .02295 L
.90982 .0202 L
.91296 .0101 L
.91633 0 L
1 0 L
1 1 L
F
0 g
.53614 1 m
.54101 .9899 L
.54545 .98079 L
.54591 .9798 L
.55067 .9697 L
.55553 .9596 L
.55556 .95954 L
.56019 .94949 L
.56497 .93939 L
.56566 .93793 L
.56956 .92929 L
.57427 .91919 L
.57576 .91599 L
.57881 .90909 L
.58344 .89899 L
.58586 .8937 L
.58793 .88889 L
.59247 .87879 L
.59596 .87108 L
.59696 .86869 L
.60139 .85859 L
.60591 .84848 L
.60606 .84814 L
.61021 .83838 L
.61466 .82828 L
.61616 .82486 L
.61892 .81818 L
.6233 .80808 L
.62626 .80126 L
.62758 .79798 L
.63184 .78788 L
.63618 .77778 L
.63636 .77735 L
.64029 .76768 L
.64458 .75758 L
.64646 .75311 L
.64868 .74747 L
.65288 .73737 L
.65657 .72858 L
.65706 .72727 L
.6611 .71717 L
.66529 .70707 L
.66667 .70373 L
.66926 .69697 L
.67337 .68687 L
.67677 .67857 L
.67743 .67677 L
.68138 .66667 L
.68548 .65657 L
.68687 .65312 L
Mistroke
.68935 .64646 L
.69337 .63636 L
.69697 .62738 L
.69736 .62626 L
.70119 .61616 L
.7052 .60606 L
.70707 .60133 L
.709 .59596 L
.71291 .58586 L
.71688 .57576 L
.71717 .575 L
.72057 .56566 L
.72449 .55556 L
.72727 .54837 L
.72827 .54545 L
.73203 .53535 L
.73593 .52525 L
.73737 .52147 L
.73957 .51515 L
.74337 .50505 L
.74722 .49495 L
.74747 .49429 L
.75078 .48485 L
.75459 .47475 L
.75758 .46681 L
.75828 .46465 L
.76189 .45455 L
.76568 .44444 L
.76768 .43907 L
.76923 .43434 L
.77289 .42424 L
.77664 .41414 L
.77778 .41105 L
.78011 .40404 L
.78378 .39394 L
.78749 .38384 L
.78788 .38276 L
.79089 .37374 L
.79455 .36364 L
.79798 .35421 L
.79818 .35354 L
.80157 .34343 L
.80522 .33333 L
.80808 .32538 L
.80873 .32323 L
.81215 .31313 L
.81578 .30303 L
.81818 .29629 L
.8192 .29293 L
.82264 .28283 L
Mistroke
.82624 .27273 L
.82828 .26693 L
.82959 .26263 L
.83303 .25253 L
.8366 .24242 L
.83838 .23732 L
.83989 .23232 L
.84332 .22222 L
.84687 .21212 L
.84848 .20746 L
.85011 .20202 L
.85353 .19192 L
.85704 .18182 L
.85859 .17733 L
.86025 .17172 L
.86364 .16162 L
.86713 .15152 L
.86869 .14695 L
.87031 .14141 L
.87367 .13131 L
.87713 .12121 L
.87879 .11632 L
.88029 .11111 L
.88361 .10101 L
.88705 .09091 L
.88889 .08545 L
.89019 .08081 L
.89347 .07071 L
.89689 .06061 L
.89899 .05432 L
.90003 .05051 L
.90325 .0404 L
.90665 .0303 L
.90909 .02295 L
.90982 .0202 L
.91296 .0101 L
.91633 0 L
Mfstroke
.2 g
.55639 1 m
.56089 .9899 L
.56523 .9798 L
.56566 .97903 L
.5698 .9697 L
.57357 .9596 L
.57576 .95587 L
.57864 .94949 L
.58155 .93939 L
.58586 .93257 L
.58739 .92929 L
.59175 .91919 L
.59596 .90931 L
.59607 .90909 L
.6004 .89899 L
.60425 .88889 L
.60606 .8855 L
.60896 .87879 L
.612 .86869 L
.61616 .86145 L
.61744 .85859 L
.62166 .84848 L
.62574 .83838 L
.62626 .83732 L
.63002 .82828 L
.63349 .81818 L
.63636 .81269 L
.63831 .80808 L
.6407 .79798 L
.64646 .788 L
.64652 .78788 L
.65062 .77778 L
.65416 .76768 L
.65657 .76284 L
.65872 .75758 L
.66125 .74747 L
.66667 .73757 L
.66675 .73737 L
.67076 .72727 L
.67419 .71717 L
.67677 .71187 L
.67869 .70707 L
.68102 .69697 L
.68649 .68687 L
.68687 .68604 L
.69048 .67677 L
.69365 .66667 L
.69697 .6598 L
.69825 .65657 L
.70006 .64646 L
.70573 .63636 L
.70707 .63339 L
.70981 .62626 L
.71251 .61616 L
.71717 .6067 L
.71742 .60606 L
.72123 .59596 L
.72443 .58586 L
.72727 .57967 L
.72876 .57576 L
.73065 .56566 L
.73602 .55556 L
.73737 .55244 L
.73998 .54545 L
.7425 .53535 L
.74735 .52525 L
.74747 .52496 L
.75107 .51515 L
.75398 .50505 L
.75758 .49713 L
.75839 .49495 L
.76205 .48485 L
.76521 .47475 L
.76768 .46908 L
.7693 .46465 L
.77111 .45455 L
.77624 .44444 L
.77778 .44078 L
.78009 .43434 L
.78229 .42424 L
.7871 .41414 L
.78788 .41223 L
.79078 .40404 L
.79324 .39394 L
.79781 .38384 L
.79798 .38342 L
.80138 .37374 L
.804 .36364 L
.80808 .35432 L
.80836 .35354 L
.81187 .34343 L
.8146 .33333 L
.81818 .32497 L
.81879 .32323 L
.82227 .31313 L
.82507 .30303 L
.82828 .29537 L
.82913 .29293 L
.83258 .28283 L
.83541 .27273 L
.83838 .26553 L
.83938 .26263 L
.8428 .25253 L
.84563 .24242 L
.84848 .23544 L
.84955 .23232 L
.85293 .22222 L
.85574 .21212 L
.85859 .2051 L
.85963 .20202 L
.86298 .19192 L
.86574 .18182 L
.86869 .17451 L
.86963 .17172 L
.87296 .16162 L
.87564 .15152 L
.87879 .14368 L
.87955 .14141 L
.88285 .13131 L
.88542 .12121 L
.88889 .11261 L
.88939 .11111 L
.89267 .10101 L
.8951 .09091 L
.89899 .08131 L
.89916 .08081 L
.90242 .07071 L
.90467 .06061 L
.90882 .05051 L
.90909 .04976 L
.9121 .0404 L
.9141 .0303 L
.91836 .0202 L
.91919 .01795 L
.9217 .0101 L
.9234 0 L
1 0 L
1 1 L
F
0 g
.55639 1 m
.56089 .9899 L
.56523 .9798 L
.56566 .97903 L
.5698 .9697 L
.57357 .9596 L
.57576 .95587 L
.57864 .94949 L
.58155 .93939 L
.58586 .93257 L
.58739 .92929 L
.59175 .91919 L
.59596 .90931 L
.59607 .90909 L
.6004 .89899 L
.60425 .88889 L
.60606 .8855 L
.60896 .87879 L
.612 .86869 L
.61616 .86145 L
.61744 .85859 L
.62166 .84848 L
.62574 .83838 L
.62626 .83732 L
.63002 .82828 L
.63349 .81818 L
.63636 .81269 L
.63831 .80808 L
.6407 .79798 L
.64646 .788 L
.64652 .78788 L
.65062 .77778 L
.65416 .76768 L
.65657 .76284 L
.65872 .75758 L
.66125 .74747 L
.66667 .73757 L
.66675 .73737 L
.67076 .72727 L
.67419 .71717 L
.67677 .71187 L
.67869 .70707 L
.68102 .69697 L
.68649 .68687 L
.68687 .68604 L
.69048 .67677 L
.69365 .66667 L
.69697 .6598 L
.69825 .65657 L
.70006 .64646 L
Mistroke
.70573 .63636 L
.70707 .63339 L
.70981 .62626 L
.71251 .61616 L
.71717 .6067 L
.71742 .60606 L
.72123 .59596 L
.72443 .58586 L
.72727 .57967 L
.72876 .57576 L
.73065 .56566 L
.73602 .55556 L
.73737 .55244 L
.73998 .54545 L
.7425 .53535 L
.74735 .52525 L
.74747 .52496 L
.75107 .51515 L
.75398 .50505 L
.75758 .49713 L
.75839 .49495 L
.76205 .48485 L
.76521 .47475 L
.76768 .46908 L
.7693 .46465 L
.77111 .45455 L
.77624 .44444 L
.77778 .44078 L
.78009 .43434 L
.78229 .42424 L
.7871 .41414 L
.78788 .41223 L
.79078 .40404 L
.79324 .39394 L
.79781 .38384 L
.79798 .38342 L
.80138 .37374 L
.804 .36364 L
.80808 .35432 L
.80836 .35354 L
.81187 .34343 L
.8146 .33333 L
.81818 .32497 L
.81879 .32323 L
.82227 .31313 L
.82507 .30303 L
.82828 .29537 L
.82913 .29293 L
.83258 .28283 L
.83541 .27273 L
Mistroke
.83838 .26553 L
.83938 .26263 L
.8428 .25253 L
.84563 .24242 L
.84848 .23544 L
.84955 .23232 L
.85293 .22222 L
.85574 .21212 L
.85859 .2051 L
.85963 .20202 L
.86298 .19192 L
.86574 .18182 L
.86869 .17451 L
.86963 .17172 L
.87296 .16162 L
.87564 .15152 L
.87879 .14368 L
.87955 .14141 L
.88285 .13131 L
.88542 .12121 L
.88889 .11261 L
.88939 .11111 L
.89267 .10101 L
.8951 .09091 L
.89899 .08131 L
.89916 .08081 L
.90242 .07071 L
.90467 .06061 L
.90882 .05051 L
.90909 .04976 L
.9121 .0404 L
.9141 .0303 L
.91836 .0202 L
.91919 .01795 L
.9217 .0101 L
.9234 0 L
Mfstroke
.3 g
.57895 1 m
.58389 .9899 L
.58586 .98613 L
.58878 .9798 L
.59362 .9697 L
.59596 .96501 L
.59841 .9596 L
.60316 .94949 L
.60606 .94344 L
.60875 .93939 L
.61252 .92929 L
.61616 .92145 L
.61753 .91919 L
.62172 .90909 L
.62626 .89906 L
.6263 .89899 L
.63078 .88889 L
.63528 .87879 L
.63636 .87646 L
.63971 .86869 L
.64413 .85859 L
.64646 .85336 L
.64931 .84848 L
.65286 .83838 L
.65657 .82983 L
.65739 .82828 L
.66148 .81818 L
.66577 .80808 L
.66667 .80606 L
.67152 .79798 L
.67423 .78788 L
.67677 .78188 L
.67895 .77778 L
.68258 .76768 L
.68675 .75758 L
.68687 .75731 L
.69274 .74747 L
.69496 .73737 L
.69697 .73252 L
.6997 .72727 L
.70309 .71717 L
.70707 .70727 L
.70716 .70707 L
.71296 .69697 L
.71514 .68687 L
.71717 .68183 L
.7197 .67677 L
.72306 .66667 L
.72703 .65657 L
.72727 .65596 L
.73236 .64646 L
.73483 .63636 L
.73737 .62984 L
.73907 .62626 L
.74257 .61616 L
.74643 .60606 L
.74747 .6034 L
.75116 .59596 L
.75407 .58586 L
.75758 .57661 L
.75795 .57576 L
.76327 .56566 L
.76542 .55556 L
.76768 .54959 L
.76956 .54545 L
.7729 .53535 L
.77664 .52525 L
.77778 .52224 L
.78111 .51515 L
.78403 .50505 L
.78773 .49495 L
.78788 .49456 L
.79258 .48485 L
.79503 .47475 L
.79798 .46664 L
.79883 .46465 L
.80399 .45455 L
.80591 .44444 L
.80808 .43844 L
.80986 .43434 L
.81308 .42424 L
.81667 .41414 L
.81818 .40994 L
.82077 .40404 L
.82377 .39394 L
.82732 .38384 L
.82828 .38116 L
.83157 .37374 L
.83434 .36364 L
.83787 .35354 L
.83838 .35209 L
.84224 .34343 L
.84482 .33333 L
.84831 .32323 L
.84848 .32275 L
.85279 .31313 L
.85519 .30303 L
.85859 .29314 L
.85867 .29293 L
.8632 .28283 L
.86547 .27273 L
.86869 .26328 L
.86894 .26263 L
.87347 .25253 L
.87566 .24242 L
.87879 .23315 L
.87911 .23232 L
.88361 .22222 L
.88576 .21212 L
.88889 .20276 L
.88917 .20202 L
.89362 .19192 L
.89577 .18182 L
.89899 .1721 L
.89914 .17172 L
.9035 .16162 L
.9057 .15152 L
.90902 .14141 L
.90909 .1412 L
.91327 .13131 L
.91555 .12121 L
.91884 .11111 L
.91919 .11005 L
.92293 .10101 L
.92532 .09091 L
.92858 .08081 L
.92929 .07864 L
.9325 .07071 L
.93501 .06061 L
.93825 .05051 L
.93939 .04698 L
.94198 .0404 L
.94464 .0303 L
.94785 .0202 L
.94949 .01507 L
.9514 .0101 L
.95611 0 L
1 0 L
1 1 L
F
0 g
.57895 1 m
.58389 .9899 L
.58586 .98613 L
.58878 .9798 L
.59362 .9697 L
.59596 .96501 L
.59841 .9596 L
.60316 .94949 L
.60606 .94344 L
.60875 .93939 L
.61252 .92929 L
.61616 .92145 L
.61753 .91919 L
.62172 .90909 L
.62626 .89906 L
.6263 .89899 L
.63078 .88889 L
.63528 .87879 L
.63636 .87646 L
.63971 .86869 L
.64413 .85859 L
.64646 .85336 L
.64931 .84848 L
.65286 .83838 L
.65657 .82983 L
.65739 .82828 L
.66148 .81818 L
.66577 .80808 L
.66667 .80606 L
.67152 .79798 L
.67423 .78788 L
.67677 .78188 L
.67895 .77778 L
.68258 .76768 L
.68675 .75758 L
.68687 .75731 L
.69274 .74747 L
.69496 .73737 L
.69697 .73252 L
.6997 .72727 L
.70309 .71717 L
.70707 .70727 L
.70716 .70707 L
.71296 .69697 L
.71514 .68687 L
.71717 .68183 L
.7197 .67677 L
.72306 .66667 L
.72703 .65657 L
.72727 .65596 L
Mistroke
.73236 .64646 L
.73483 .63636 L
.73737 .62984 L
.73907 .62626 L
.74257 .61616 L
.74643 .60606 L
.74747 .6034 L
.75116 .59596 L
.75407 .58586 L
.75758 .57661 L
.75795 .57576 L
.76327 .56566 L
.76542 .55556 L
.76768 .54959 L
.76956 .54545 L
.7729 .53535 L
.77664 .52525 L
.77778 .52224 L
.78111 .51515 L
.78403 .50505 L
.78773 .49495 L
.78788 .49456 L
.79258 .48485 L
.79503 .47475 L
.79798 .46664 L
.79883 .46465 L
.80399 .45455 L
.80591 .44444 L
.80808 .43844 L
.80986 .43434 L
.81308 .42424 L
.81667 .41414 L
.81818 .40994 L
.82077 .40404 L
.82377 .39394 L
.82732 .38384 L
.82828 .38116 L
.83157 .37374 L
.83434 .36364 L
.83787 .35354 L
.83838 .35209 L
.84224 .34343 L
.84482 .33333 L
.84831 .32323 L
.84848 .32275 L
.85279 .31313 L
.85519 .30303 L
.85859 .29314 L
.85867 .29293 L
.8632 .28283 L
Mistroke
.86547 .27273 L
.86869 .26328 L
.86894 .26263 L
.87347 .25253 L
.87566 .24242 L
.87879 .23315 L
.87911 .23232 L
.88361 .22222 L
.88576 .21212 L
.88889 .20276 L
.88917 .20202 L
.89362 .19192 L
.89577 .18182 L
.89899 .1721 L
.89914 .17172 L
.9035 .16162 L
.9057 .15152 L
.90902 .14141 L
.90909 .1412 L
.91327 .13131 L
.91555 .12121 L
.91884 .11111 L
.91919 .11005 L
.92293 .10101 L
.92532 .09091 L
.92858 .08081 L
.92929 .07864 L
.9325 .07071 L
.93501 .06061 L
.93825 .05051 L
.93939 .04698 L
.94198 .0404 L
.94464 .0303 L
.94785 .0202 L
.94949 .01507 L
.9514 .0101 L
.95611 0 L
Mfstroke
.4 g
.59739 1 m
.60209 .9899 L
.60606 .98078 L
.60651 .9798 L
.61115 .9697 L
.61557 .9596 L
.61616 .95814 L
.62008 .94949 L
.62454 .93939 L
.62626 .93515 L
.62888 .92929 L
.63334 .91919 L
.63636 .91182 L
.63756 .90909 L
.642 .89899 L
.64618 .88889 L
.64646 .88815 L
.65054 .87879 L
.65481 .86869 L
.65657 .86416 L
.65895 .85859 L
.66325 .84848 L
.66667 .83983 L
.66728 .83838 L
.67156 .82828 L
.67566 .81818 L
.67677 .81519 L
.67974 .80808 L
.68392 .79798 L
.68687 .79022 L
.68784 .78788 L
.69201 .77778 L
.696 .76768 L
.69697 .76495 L
.69998 .75758 L
.70407 .74747 L
.70707 .73937 L
.70787 .73737 L
.71196 .72727 L
.71588 .71717 L
.71717 .71348 L
.71973 .70707 L
.72375 .69697 L
.72727 .68729 L
.72744 .68687 L
.73144 .67677 L
.73534 .66667 L
.73737 .66081 L
.73903 .65657 L
.74298 .64646 L
.74671 .63636 L
.74747 .63403 L
.75048 .62626 L
.75436 .61616 L
.75758 .60696 L
.75792 .60606 L
.7618 .59596 L
.76558 .58586 L
.76768 .5796 L
.76913 .57576 L
.77297 .56566 L
.77663 .55556 L
.77778 .55196 L
.78022 .54545 L
.78401 .53535 L
.78751 .52525 L
.78788 .52404 L
.79119 .51515 L
.79492 .50505 L
.79798 .49584 L
.7983 .49495 L
.80204 .48485 L
.8057 .47475 L
.80808 .46736 L
.80907 .46465 L
.81277 .45455 L
.81636 .44444 L
.81818 .43861 L
.81972 .43434 L
.8234 .42424 L
.82691 .41414 L
.82828 .4096 L
.83027 .40404 L
.83391 .39394 L
.83735 .38384 L
.83838 .38031 L
.84072 .37374 L
.84433 .36364 L
.84769 .35354 L
.84848 .35076 L
.85107 .34343 L
.85464 .33333 L
.85795 .32323 L
.85859 .32094 L
.86132 .31313 L
.86486 .30303 L
.86813 .29293 L
.86869 .29086 L
.87148 .28283 L
.87499 .27273 L
.87823 .26263 L
.87879 .26053 L
.88155 .25253 L
.88504 .24242 L
.88826 .23232 L
.88889 .22994 L
.89153 .22222 L
.895 .21212 L
.89822 .20202 L
.89899 .1991 L
.90143 .19192 L
.90487 .18182 L
.9081 .17172 L
.90909 .16801 L
.91124 .16162 L
.91467 .15152 L
.91792 .14141 L
.91919 .13667 L
.92098 .13131 L
.92438 .12121 L
.92765 .11111 L
.92929 .10507 L
.93064 .10101 L
.93401 .09091 L
.93731 .08081 L
.93939 .07324 L
.94022 .07071 L
.94357 .06061 L
.94688 .05051 L
.94949 .04116 L
.94974 .0404 L
.95306 .0303 L
.95637 .0202 L
.95931 .0101 L
.9596 .00883 L
.96247 0 L
1 0 L
1 1 L
F
0 g
.59739 1 m
.60209 .9899 L
.60606 .98078 L
.60651 .9798 L
.61115 .9697 L
.61557 .9596 L
.61616 .95814 L
.62008 .94949 L
.62454 .93939 L
.62626 .93515 L
.62888 .92929 L
.63334 .91919 L
.63636 .91182 L
.63756 .90909 L
.642 .89899 L
.64618 .88889 L
.64646 .88815 L
.65054 .87879 L
.65481 .86869 L
.65657 .86416 L
.65895 .85859 L
.66325 .84848 L
.66667 .83983 L
.66728 .83838 L
.67156 .82828 L
.67566 .81818 L
.67677 .81519 L
.67974 .80808 L
.68392 .79798 L
.68687 .79022 L
.68784 .78788 L
.69201 .77778 L
.696 .76768 L
.69697 .76495 L
.69998 .75758 L
.70407 .74747 L
.70707 .73937 L
.70787 .73737 L
.71196 .72727 L
.71588 .71717 L
.71717 .71348 L
.71973 .70707 L
.72375 .69697 L
.72727 .68729 L
.72744 .68687 L
.73144 .67677 L
.73534 .66667 L
.73737 .66081 L
.73903 .65657 L
.74298 .64646 L
Mistroke
.74671 .63636 L
.74747 .63403 L
.75048 .62626 L
.75436 .61616 L
.75758 .60696 L
.75792 .60606 L
.7618 .59596 L
.76558 .58586 L
.76768 .5796 L
.76913 .57576 L
.77297 .56566 L
.77663 .55556 L
.77778 .55196 L
.78022 .54545 L
.78401 .53535 L
.78751 .52525 L
.78788 .52404 L
.79119 .51515 L
.79492 .50505 L
.79798 .49584 L
.7983 .49495 L
.80204 .48485 L
.8057 .47475 L
.80808 .46736 L
.80907 .46465 L
.81277 .45455 L
.81636 .44444 L
.81818 .43861 L
.81972 .43434 L
.8234 .42424 L
.82691 .41414 L
.82828 .4096 L
.83027 .40404 L
.83391 .39394 L
.83735 .38384 L
.83838 .38031 L
.84072 .37374 L
.84433 .36364 L
.84769 .35354 L
.84848 .35076 L
.85107 .34343 L
.85464 .33333 L
.85795 .32323 L
.85859 .32094 L
.86132 .31313 L
.86486 .30303 L
.86813 .29293 L
.86869 .29086 L
.87148 .28283 L
.87499 .27273 L
Mistroke
.87823 .26263 L
.87879 .26053 L
.88155 .25253 L
.88504 .24242 L
.88826 .23232 L
.88889 .22994 L
.89153 .22222 L
.895 .21212 L
.89822 .20202 L
.89899 .1991 L
.90143 .19192 L
.90487 .18182 L
.9081 .17172 L
.90909 .16801 L
.91124 .16162 L
.91467 .15152 L
.91792 .14141 L
.91919 .13667 L
.92098 .13131 L
.92438 .12121 L
.92765 .11111 L
.92929 .10507 L
.93064 .10101 L
.93401 .09091 L
.93731 .08081 L
.93939 .07324 L
.94022 .07071 L
.94357 .06061 L
.94688 .05051 L
.94949 .04116 L
.94974 .0404 L
.95306 .0303 L
.95637 .0202 L
.95931 .0101 L
.9596 .00883 L
.96247 0 L
Mfstroke
.5 g
.60919 1 m
.61366 .9899 L
.61616 .98414 L
.61807 .9798 L
.62249 .9697 L
.62626 .96093 L
.62684 .9596 L
.63121 .94949 L
.63552 .93939 L
.63636 .93739 L
.63982 .92929 L
.64411 .91919 L
.64646 .91352 L
.64833 .90909 L
.65258 .89899 L
.65657 .88933 L
.65675 .88889 L
.66095 .87879 L
.66511 .86869 L
.66667 .86482 L
.66923 .85859 L
.67336 .84848 L
.67677 .84 L
.67742 .83838 L
.68152 .82828 L
.68557 .81818 L
.68687 .81486 L
.68959 .80808 L
.69362 .79798 L
.69697 .78942 L
.69758 .78788 L
.70158 .77778 L
.70554 .76768 L
.70707 .76367 L
.70946 .75758 L
.7134 .74747 L
.71717 .73763 L
.71727 .73737 L
.72118 .72727 L
.72506 .71717 L
.72727 .71129 L
.72889 .70707 L
.73275 .69697 L
.73656 .68687 L
.73737 .68465 L
.74036 .67677 L
.74418 .66667 L
.74747 .65773 L
.74791 .65657 L
.7517 .64646 L
.75545 .63636 L
.75758 .63052 L
.75915 .62626 L
.7629 .61616 L
.76659 .60606 L
.76768 .60303 L
.77027 .59596 L
.77398 .58586 L
.7776 .57576 L
.77778 .57525 L
.78127 .56566 L
.78493 .55556 L
.78788 .5472 L
.78851 .54545 L
.79215 .53535 L
.79576 .52525 L
.79798 .51887 L
.7993 .51515 L
.80291 .50505 L
.80648 .49495 L
.80808 .49027 L
.80999 .48485 L
.81357 .47475 L
.81708 .46465 L
.81818 .4614 L
.82058 .45455 L
.82412 .44444 L
.82759 .43434 L
.82828 .43227 L
.83107 .42424 L
.83457 .41414 L
.838 .40404 L
.83838 .40287 L
.84145 .39394 L
.84493 .38384 L
.84831 .37374 L
.84848 .3732 L
.85175 .36364 L
.85519 .35354 L
.85854 .34343 L
.85859 .34328 L
.86195 .33333 L
.86536 .32323 L
.86868 .31313 L
.86869 .3131 L
.87206 .30303 L
.87545 .29293 L
.87873 .28283 L
.87879 .28266 L
.88209 .27273 L
.88545 .26263 L
.88872 .25253 L
.88889 .25197 L
.89204 .24242 L
.89537 .23232 L
.89862 .22222 L
.89899 .22103 L
.9019 .21212 L
.90522 .20202 L
.90845 .19192 L
.90909 .18984 L
.91169 .18182 L
.91498 .17172 L
.9182 .16162 L
.91919 .1584 L
.9214 .15152 L
.92467 .14141 L
.92788 .13131 L
.92929 .12672 L
.93105 .12121 L
.93429 .11111 L
.93749 .10101 L
.93939 .09479 L
.94062 .09091 L
.94384 .08081 L
.94703 .07071 L
.94949 .06262 L
.95012 .06061 L
.95331 .05051 L
.9565 .0404 L
.95957 .0303 L
.9596 .03021 L
.96272 .0202 L
.9659 .0101 L
.96898 0 L
1 0 L
1 1 L
F
0 g
.60919 1 m
.61366 .9899 L
.61616 .98414 L
.61807 .9798 L
.62249 .9697 L
.62626 .96093 L
.62684 .9596 L
.63121 .94949 L
.63552 .93939 L
.63636 .93739 L
.63982 .92929 L
.64411 .91919 L
.64646 .91352 L
.64833 .90909 L
.65258 .89899 L
.65657 .88933 L
.65675 .88889 L
.66095 .87879 L
.66511 .86869 L
.66667 .86482 L
.66923 .85859 L
.67336 .84848 L
.67677 .84 L
.67742 .83838 L
.68152 .82828 L
.68557 .81818 L
.68687 .81486 L
.68959 .80808 L
.69362 .79798 L
.69697 .78942 L
.69758 .78788 L
.70158 .77778 L
.70554 .76768 L
.70707 .76367 L
.70946 .75758 L
.7134 .74747 L
.71717 .73763 L
.71727 .73737 L
.72118 .72727 L
.72506 .71717 L
.72727 .71129 L
.72889 .70707 L
.73275 .69697 L
.73656 .68687 L
.73737 .68465 L
.74036 .67677 L
.74418 .66667 L
.74747 .65773 L
.74791 .65657 L
.7517 .64646 L
Mistroke
.75545 .63636 L
.75758 .63052 L
.75915 .62626 L
.7629 .61616 L
.76659 .60606 L
.76768 .60303 L
.77027 .59596 L
.77398 .58586 L
.7776 .57576 L
.77778 .57525 L
.78127 .56566 L
.78493 .55556 L
.78788 .5472 L
.78851 .54545 L
.79215 .53535 L
.79576 .52525 L
.79798 .51887 L
.7993 .51515 L
.80291 .50505 L
.80648 .49495 L
.80808 .49027 L
.80999 .48485 L
.81357 .47475 L
.81708 .46465 L
.81818 .4614 L
.82058 .45455 L
.82412 .44444 L
.82759 .43434 L
.82828 .43227 L
.83107 .42424 L
.83457 .41414 L
.838 .40404 L
.83838 .40287 L
.84145 .39394 L
.84493 .38384 L
.84831 .37374 L
.84848 .3732 L
.85175 .36364 L
.85519 .35354 L
.85854 .34343 L
.85859 .34328 L
.86195 .33333 L
.86536 .32323 L
.86868 .31313 L
.86869 .3131 L
.87206 .30303 L
.87545 .29293 L
.87873 .28283 L
.87879 .28266 L
.88209 .27273 L
Mistroke
.88545 .26263 L
.88872 .25253 L
.88889 .25197 L
.89204 .24242 L
.89537 .23232 L
.89862 .22222 L
.89899 .22103 L
.9019 .21212 L
.90522 .20202 L
.90845 .19192 L
.90909 .18984 L
.91169 .18182 L
.91498 .17172 L
.9182 .16162 L
.91919 .1584 L
.9214 .15152 L
.92467 .14141 L
.92788 .13131 L
.92929 .12672 L
.93105 .12121 L
.93429 .11111 L
.93749 .10101 L
.93939 .09479 L
.94062 .09091 L
.94384 .08081 L
.94703 .07071 L
.94949 .06262 L
.95012 .06061 L
.95331 .05051 L
.9565 .0404 L
.95957 .0303 L
.9596 .03021 L
.96272 .0202 L
.9659 .0101 L
.96898 0 L
Mfstroke
.6 g
.61975 1 m
.62412 .9899 L
.62626 .98492 L
.62844 .9798 L
.63276 .9697 L
.63636 .96121 L
.63704 .9596 L
.64129 .94949 L
.64554 .93939 L
.64646 .93718 L
.64973 .92929 L
.65394 .91919 L
.65657 .91283 L
.65809 .90909 L
.66224 .89899 L
.66638 .88889 L
.66667 .88817 L
.67046 .87879 L
.67456 .86869 L
.67677 .8632 L
.6786 .85859 L
.68265 .84848 L
.68669 .83838 L
.68687 .83793 L
.69067 .82828 L
.69467 .81818 L
.69697 .81234 L
.69862 .80808 L
.70257 .79798 L
.70652 .78788 L
.70707 .78647 L
.71041 .77778 L
.71433 .76768 L
.71717 .76029 L
.7182 .75758 L
.72205 .74747 L
.72592 .73737 L
.72727 .73382 L
.72973 .72727 L
.73356 .71717 L
.73737 .70707 L
.73737 .70707 L
.74113 .69697 L
.74492 .68687 L
.74747 .68002 L
.74866 .67677 L
.7524 .66667 L
.75615 .65657 L
.75758 .65269 L
.75983 .64646 L
.76355 .63636 L
.76725 .62626 L
.76768 .62509 L
.77089 .61616 L
.77457 .60606 L
.77778 .5972 L
.77821 .59596 L
.78183 .58586 L
.78547 .57576 L
.78788 .56904 L
.78906 .56566 L
.79265 .55556 L
.79626 .54545 L
.79798 .54061 L
.7998 .53535 L
.80337 .52525 L
.80694 .51515 L
.80808 .51191 L
.81044 .50505 L
.81398 .49495 L
.81752 .48485 L
.81818 .48294 L
.82098 .47475 L
.82449 .46465 L
.82799 .45455 L
.82828 .4537 L
.83142 .44444 L
.83491 .43434 L
.83837 .42424 L
.83838 .42421 L
.84177 .41414 L
.84522 .40404 L
.84848 .39445 L
.84865 .39394 L
.85202 .38384 L
.85545 .37374 L
.85859 .36443 L
.85884 .36364 L
.86219 .35354 L
.86559 .34343 L
.86869 .33416 L
.86895 .33333 L
.87227 .32323 L
.87564 .31313 L
.87879 .30364 L
.87898 .30303 L
.88226 .29293 L
.88561 .28283 L
.88889 .27286 L
.88893 .27273 L
.89218 .26263 L
.8955 .25253 L
.8988 .24242 L
.89899 .24183 L
.90202 .23232 L
.90531 .22222 L
.90859 .21212 L
.90909 .21056 L
.91178 .20202 L
.91505 .19192 L
.91831 .18182 L
.91919 .17904 L
.92147 .17172 L
.92471 .16162 L
.92795 .15152 L
.92929 .14728 L
.9311 .14141 L
.9343 .13131 L
.93752 .12121 L
.93939 .11527 L
.94066 .11111 L
.94382 .10101 L
.94702 .09091 L
.94949 .08302 L
.95016 .08081 L
.95328 .07071 L
.95646 .06061 L
.9596 .05054 L
.95961 .05051 L
.96267 .0404 L
.96583 .0303 L
.96897 .0202 L
.9697 .01782 L
.97201 .0101 L
.97513 0 L
1 0 L
1 1 L
F
0 g
.61975 1 m
.62412 .9899 L
.62626 .98492 L
.62844 .9798 L
.63276 .9697 L
.63636 .96121 L
.63704 .9596 L
.64129 .94949 L
.64554 .93939 L
.64646 .93718 L
.64973 .92929 L
.65394 .91919 L
.65657 .91283 L
.65809 .90909 L
.66224 .89899 L
.66638 .88889 L
.66667 .88817 L
.67046 .87879 L
.67456 .86869 L
.67677 .8632 L
.6786 .85859 L
.68265 .84848 L
.68669 .83838 L
.68687 .83793 L
.69067 .82828 L
.69467 .81818 L
.69697 .81234 L
.69862 .80808 L
.70257 .79798 L
.70652 .78788 L
.70707 .78647 L
.71041 .77778 L
.71433 .76768 L
.71717 .76029 L
.7182 .75758 L
.72205 .74747 L
.72592 .73737 L
.72727 .73382 L
.72973 .72727 L
.73356 .71717 L
.73737 .70707 L
.73737 .70707 L
.74113 .69697 L
.74492 .68687 L
.74747 .68002 L
.74866 .67677 L
.7524 .66667 L
.75615 .65657 L
.75758 .65269 L
.75983 .64646 L
Mistroke
.76355 .63636 L
.76725 .62626 L
.76768 .62509 L
.77089 .61616 L
.77457 .60606 L
.77778 .5972 L
.77821 .59596 L
.78183 .58586 L
.78547 .57576 L
.78788 .56904 L
.78906 .56566 L
.79265 .55556 L
.79626 .54545 L
.79798 .54061 L
.7998 .53535 L
.80337 .52525 L
.80694 .51515 L
.80808 .51191 L
.81044 .50505 L
.81398 .49495 L
.81752 .48485 L
.81818 .48294 L
.82098 .47475 L
.82449 .46465 L
.82799 .45455 L
.82828 .4537 L
.83142 .44444 L
.83491 .43434 L
.83837 .42424 L
.83838 .42421 L
.84177 .41414 L
.84522 .40404 L
.84848 .39445 L
.84865 .39394 L
.85202 .38384 L
.85545 .37374 L
.85859 .36443 L
.85884 .36364 L
.86219 .35354 L
.86559 .34343 L
.86869 .33416 L
.86895 .33333 L
.87227 .32323 L
.87564 .31313 L
.87879 .30364 L
.87898 .30303 L
.88226 .29293 L
.88561 .28283 L
.88889 .27286 L
.88893 .27273 L
Mistroke
.89218 .26263 L
.8955 .25253 L
.8988 .24242 L
.89899 .24183 L
.90202 .23232 L
.90531 .22222 L
.90859 .21212 L
.90909 .21056 L
.91178 .20202 L
.91505 .19192 L
.91831 .18182 L
.91919 .17904 L
.92147 .17172 L
.92471 .16162 L
.92795 .15152 L
.92929 .14728 L
.9311 .14141 L
.9343 .13131 L
.93752 .12121 L
.93939 .11527 L
.94066 .11111 L
.94382 .10101 L
.94702 .09091 L
.94949 .08302 L
.95016 .08081 L
.95328 .07071 L
.95646 .06061 L
.9596 .05054 L
.95961 .05051 L
.96267 .0404 L
.96583 .0303 L
.96897 .0202 L
.9697 .01782 L
.97201 .0101 L
.97513 0 L
Mfstroke
.7 g
.63069 1 m
.63503 .9899 L
.63636 .98678 L
.63917 .9798 L
.64344 .9697 L
.64646 .96255 L
.64761 .9596 L
.65175 .94949 L
.65599 .93939 L
.65657 .93802 L
.66 .92929 L
.66418 .91919 L
.66667 .91316 L
.66821 .90909 L
.67227 .89899 L
.67641 .88889 L
.67677 .88802 L
.68031 .87879 L
.68439 .86869 L
.68687 .86256 L
.68833 .85859 L
.69229 .84848 L
.69635 .83838 L
.69697 .83682 L
.70014 .82828 L
.70414 .81818 L
.70707 .81077 L
.70802 .80808 L
.71186 .79798 L
.71583 .78788 L
.71717 .78444 L
.71956 .77778 L
.72344 .76768 L
.72727 .75782 L
.72735 .75758 L
.73101 .74747 L
.73489 .73737 L
.73737 .73091 L
.73861 .72727 L
.74235 .71717 L
.74621 .70707 L
.74747 .70372 L
.7498 .69697 L
.75357 .68687 L
.75739 .67677 L
.75758 .67626 L
.7609 .66667 L
.76467 .65657 L
.76768 .64851 L
.76833 .64646 L
.7719 .63636 L
.77565 .62626 L
.77778 .62049 L
.77918 .61616 L
.78279 .60606 L
.78651 .59596 L
.78788 .5922 L
.78995 .58586 L
.79357 .57576 L
.79725 .56566 L
.79798 .56364 L
.80063 .55556 L
.80424 .54545 L
.80789 .53535 L
.80808 .53482 L
.81121 .52525 L
.81481 .51515 L
.81818 .50573 L
.81838 .50505 L
.8217 .49495 L
.82528 .48485 L
.82828 .47638 L
.82876 .47475 L
.83209 .46465 L
.83565 .45455 L
.83838 .44676 L
.83906 .44444 L
.84239 .43434 L
.84593 .42424 L
.84848 .4169 L
.84928 .41414 L
.8526 .40404 L
.85611 .39394 L
.85859 .38677 L
.85942 .38384 L
.86272 .37374 L
.86621 .36364 L
.86869 .35639 L
.86949 .35354 L
.87275 .34343 L
.87621 .33333 L
.87879 .32576 L
.87948 .32323 L
.8827 .31313 L
.88614 .30303 L
.88889 .29489 L
.88941 .29293 L
.89257 .28283 L
.89598 .27273 L
.89899 .26376 L
.89928 .26263 L
.90237 .25253 L
.90575 .24242 L
.90909 .23239 L
.90911 .23232 L
.91208 .22222 L
.91543 .21212 L
.91878 .20202 L
.91919 .20078 L
.92174 .19192 L
.92504 .18182 L
.92838 .17172 L
.92929 .16892 L
.93133 .16162 L
.93458 .15152 L
.9379 .14141 L
.93939 .13682 L
.94087 .13131 L
.94405 .12121 L
.94735 .11111 L
.94949 .10448 L
.95037 .10101 L
.95345 .09091 L
.95673 .08081 L
.9596 .07192 L
.95988 .07071 L
.96279 .06061 L
.96604 .05051 L
.96929 .0404 L
.9697 .03911 L
.97209 .0303 L
.97529 .0202 L
.97853 .0101 L
.9798 .00608 L
.98136 0 L
1 0 L
1 1 L
F
0 g
.63069 1 m
.63503 .9899 L
.63636 .98678 L
.63917 .9798 L
.64344 .9697 L
.64646 .96255 L
.64761 .9596 L
.65175 .94949 L
.65599 .93939 L
.65657 .93802 L
.66 .92929 L
.66418 .91919 L
.66667 .91316 L
.66821 .90909 L
.67227 .89899 L
.67641 .88889 L
.67677 .88802 L
.68031 .87879 L
.68439 .86869 L
.68687 .86256 L
.68833 .85859 L
.69229 .84848 L
.69635 .83838 L
.69697 .83682 L
.70014 .82828 L
.70414 .81818 L
.70707 .81077 L
.70802 .80808 L
.71186 .79798 L
.71583 .78788 L
.71717 .78444 L
.71956 .77778 L
.72344 .76768 L
.72727 .75782 L
.72735 .75758 L
.73101 .74747 L
.73489 .73737 L
.73737 .73091 L
.73861 .72727 L
.74235 .71717 L
.74621 .70707 L
.74747 .70372 L
.7498 .69697 L
.75357 .68687 L
.75739 .67677 L
.75758 .67626 L
.7609 .66667 L
.76467 .65657 L
.76768 .64851 L
.76833 .64646 L
Mistroke
.7719 .63636 L
.77565 .62626 L
.77778 .62049 L
.77918 .61616 L
.78279 .60606 L
.78651 .59596 L
.78788 .5922 L
.78995 .58586 L
.79357 .57576 L
.79725 .56566 L
.79798 .56364 L
.80063 .55556 L
.80424 .54545 L
.80789 .53535 L
.80808 .53482 L
.81121 .52525 L
.81481 .51515 L
.81818 .50573 L
.81838 .50505 L
.8217 .49495 L
.82528 .48485 L
.82828 .47638 L
.82876 .47475 L
.83209 .46465 L
.83565 .45455 L
.83838 .44676 L
.83906 .44444 L
.84239 .43434 L
.84593 .42424 L
.84848 .4169 L
.84928 .41414 L
.8526 .40404 L
.85611 .39394 L
.85859 .38677 L
.85942 .38384 L
.86272 .37374 L
.86621 .36364 L
.86869 .35639 L
.86949 .35354 L
.87275 .34343 L
.87621 .33333 L
.87879 .32576 L
.87948 .32323 L
.8827 .31313 L
.88614 .30303 L
.88889 .29489 L
.88941 .29293 L
.89257 .28283 L
.89598 .27273 L
.89899 .26376 L
Mistroke
.89928 .26263 L
.90237 .25253 L
.90575 .24242 L
.90909 .23239 L
.90911 .23232 L
.91208 .22222 L
.91543 .21212 L
.91878 .20202 L
.91919 .20078 L
.92174 .19192 L
.92504 .18182 L
.92838 .17172 L
.92929 .16892 L
.93133 .16162 L
.93458 .15152 L
.9379 .14141 L
.93939 .13682 L
.94087 .13131 L
.94405 .12121 L
.94735 .11111 L
.94949 .10448 L
.95037 .10101 L
.95345 .09091 L
.95673 .08081 L
.9596 .07192 L
.95988 .07071 L
.96279 .06061 L
.96604 .05051 L
.96929 .0404 L
.9697 .03911 L
.97209 .0303 L
.97529 .0202 L
.97853 .0101 L
.9798 .00608 L
.98136 0 L
Mfstroke
.8 g
.64519 1 m
.64646 .9975 L
.64953 .9899 L
.65261 .9798 L
.65657 .97227 L
.65764 .9697 L
.66169 .9596 L
.66547 .94949 L
.66667 .94697 L
.6697 .93939 L
.67269 .92929 L
.67677 .92131 L
.67764 .91919 L
.6816 .90909 L
.68521 .89899 L
.68687 .89543 L
.68944 .88889 L
.69213 .87879 L
.69697 .86929 L
.69721 .86869 L
.7011 .85859 L
.70441 .84848 L
.70707 .8428 L
.70879 .83838 L
.7109 .82828 L
.71627 .81818 L
.71717 .81613 L
.72022 .80808 L
.72303 .79798 L
.72727 .78914 L
.72776 .78788 L
.73153 .77778 L
.73475 .76768 L
.73737 .76186 L
.73899 .75758 L
.74092 .74747 L
.74618 .73737 L
.74747 .73436 L
.75009 .72727 L
.75258 .71717 L
.75739 .70707 L
.75758 .70661 L
.76108 .69697 L
.76391 .68687 L
.76768 .67853 L
.76833 .67677 L
.77196 .66667 L
.77502 .65657 L
.77778 .65021 L
.77914 .64646 L
.78073 .63636 L
.78594 .62626 L
.78788 .62165 L
.78984 .61616 L
.79179 .60606 L
.7967 .59596 L
.79798 .59283 L
.80044 .58586 L
.80263 .57576 L
.80732 .56566 L
.80808 .56376 L
.81094 .55556 L
.81329 .54545 L
.81782 .53535 L
.81818 .53443 L
.82135 .52525 L
.8238 .51515 L
.8282 .50505 L
.82828 .50485 L
.83167 .49495 L
.83416 .48485 L
.83838 .475 L
.83847 .47475 L
.84189 .46465 L
.8444 .45455 L
.84848 .4449 L
.84864 .44444 L
.85204 .43434 L
.85453 .42424 L
.85859 .41456 L
.85873 .41414 L
.8621 .40404 L
.86453 .39394 L
.86869 .38398 L
.86874 .38384 L
.87208 .37374 L
.87442 .36364 L
.87864 .35354 L
.87879 .35315 L
.88198 .34343 L
.88419 .33333 L
.88845 .32323 L
.88889 .32207 L
.8918 .31313 L
.89385 .30303 L
.89817 .29293 L
.89899 .29074 L
.90156 .28283 L
.90337 .27273 L
.9078 .26263 L
.90909 .25918 L
.91124 .25253 L
.91276 .24242 L
.91732 .23232 L
.91919 .22738 L
.92085 .22222 L
.92198 .21212 L
.92674 .20202 L
.92929 .19534 L
.93039 .19192 L
.93357 .18182 L
.93605 .17172 L
.93939 .16309 L
.93986 .16162 L
.94303 .15152 L
.94522 .14141 L
.94924 .13131 L
.94949 .1306 L
.95243 .12121 L
.95423 .11111 L
.95846 .10101 L
.9596 .09785 L
.96176 .09091 L
.96305 .08081 L
.96755 .07071 L
.9697 .06488 L
.97103 .06061 L
.97412 .05051 L
.97651 .0404 L
.9798 .0317 L
.98023 .0303 L
.98331 .0202 L
.9853 .0101 L
.9893 0 L
1 0 L
1 1 L
F
0 g
.64519 1 m
.64646 .9975 L
.64953 .9899 L
.65261 .9798 L
.65657 .97227 L
.65764 .9697 L
.66169 .9596 L
.66547 .94949 L
.66667 .94697 L
.6697 .93939 L
.67269 .92929 L
.67677 .92131 L
.67764 .91919 L
.6816 .90909 L
.68521 .89899 L
.68687 .89543 L
.68944 .88889 L
.69213 .87879 L
.69697 .86929 L
.69721 .86869 L
.7011 .85859 L
.70441 .84848 L
.70707 .8428 L
.70879 .83838 L
.7109 .82828 L
.71627 .81818 L
.71717 .81613 L
.72022 .80808 L
.72303 .79798 L
.72727 .78914 L
.72776 .78788 L
.73153 .77778 L
.73475 .76768 L
.73737 .76186 L
.73899 .75758 L
.74092 .74747 L
.74618 .73737 L
.74747 .73436 L
.75009 .72727 L
.75258 .71717 L
.75739 .70707 L
.75758 .70661 L
.76108 .69697 L
.76391 .68687 L
.76768 .67853 L
.76833 .67677 L
.77196 .66667 L
.77502 .65657 L
.77778 .65021 L
.77914 .64646 L
Mistroke
.78073 .63636 L
.78594 .62626 L
.78788 .62165 L
.78984 .61616 L
.79179 .60606 L
.7967 .59596 L
.79798 .59283 L
.80044 .58586 L
.80263 .57576 L
.80732 .56566 L
.80808 .56376 L
.81094 .55556 L
.81329 .54545 L
.81782 .53535 L
.81818 .53443 L
.82135 .52525 L
.8238 .51515 L
.8282 .50505 L
.82828 .50485 L
.83167 .49495 L
.83416 .48485 L
.83838 .475 L
.83847 .47475 L
.84189 .46465 L
.8444 .45455 L
.84848 .4449 L
.84864 .44444 L
.85204 .43434 L
.85453 .42424 L
.85859 .41456 L
.85873 .41414 L
.8621 .40404 L
.86453 .39394 L
.86869 .38398 L
.86874 .38384 L
.87208 .37374 L
.87442 .36364 L
.87864 .35354 L
.87879 .35315 L
.88198 .34343 L
.88419 .33333 L
.88845 .32323 L
.88889 .32207 L
.8918 .31313 L
.89385 .30303 L
.89817 .29293 L
.89899 .29074 L
.90156 .28283 L
.90337 .27273 L
.9078 .26263 L
Mistroke
.90909 .25918 L
.91124 .25253 L
.91276 .24242 L
.91732 .23232 L
.91919 .22738 L
.92085 .22222 L
.92198 .21212 L
.92674 .20202 L
.92929 .19534 L
.93039 .19192 L
.93357 .18182 L
.93605 .17172 L
.93939 .16309 L
.93986 .16162 L
.94303 .15152 L
.94522 .14141 L
.94924 .13131 L
.94949 .1306 L
.95243 .12121 L
.95423 .11111 L
.95846 .10101 L
.9596 .09785 L
.96176 .09091 L
.96305 .08081 L
.96755 .07071 L
.9697 .06488 L
.97103 .06061 L
.97412 .05051 L
.97651 .0404 L
.9798 .0317 L
.98023 .0303 L
.98331 .0202 L
.9853 .0101 L
.9893 0 L
Mfstroke
.7 g
1 .06126 m
.9972 .07071 L
.99411 .08081 L
.99098 .09091 L
.9899 .09441 L
.98785 .10101 L
.98686 .11111 L
.98211 .12121 L
.9798 .1273 L
.97853 .13131 L
.97539 .14141 L
.97301 .15152 L
.9697 .15993 L
.96916 .16162 L
.96599 .17172 L
.96388 .18182 L
.95974 .19192 L
.9596 .19232 L
.95653 .20202 L
.95471 .21212 L
.95034 .22222 L
.94949 .22449 L
.94699 .23232 L
.94548 .24242 L
.94088 .25253 L
.93939 .25642 L
.93739 .26263 L
.9362 .27273 L
.93135 .28283 L
.92929 .28809 L
.92771 .29293 L
.92445 .30303 L
.92174 .31313 L
.91919 .3195 L
.91796 .32323 L
.91468 .33333 L
.91203 .34343 L
.90909 .35067 L
.90813 .35354 L
.90482 .36364 L
.90223 .37374 L
.89899 .38157 L
.89823 .38384 L
.89488 .39394 L
.89232 .40404 L
.88889 .41222 L
.88824 .41414 L
.88486 .42424 L
.8823 .43434 L
.87879 .44261 L
.87816 .44444 L
.87476 .45455 L
.87215 .46465 L
.86869 .47274 L
.86799 .47475 L
.86456 .48485 L
.86188 .49495 L
.85859 .50261 L
.85774 .50505 L
.85428 .51515 L
.85148 .52525 L
.84848 .53222 L
.84738 .53535 L
.84389 .54545 L
.84096 .55556 L
.83838 .56155 L
.83693 .56566 L
.83341 .57576 L
.83031 .58586 L
.82828 .5906 L
.82638 .59596 L
.82474 .60606 L
.81954 .61616 L
.81818 .61937 L
.81571 .62626 L
.81365 .63636 L
.80867 .64646 L
.80808 .64785 L
.80494 .65657 L
.80245 .66667 L
.79798 .67607 L
.79772 .67677 L
.79405 .68687 L
.79115 .69697 L
.78788 .70404 L
.78675 .70707 L
.78305 .71717 L
.77977 .72727 L
.77778 .73168 L
.77565 .73737 L
.77363 .74747 L
.76831 .75758 L
.76768 .759 L
.76442 .76768 L
.76168 .77778 L
.75758 .78608 L
.75688 .78788 L
.75305 .79798 L
.74973 .80808 L
.74747 .81284 L
.74541 .81818 L
.74331 .82828 L
.73777 .83838 L
.73737 .83925 L
.73379 .84848 L
.73074 .85859 L
.72727 .86544 L
.72597 .86869 L
.72202 .87879 L
.7183 .88889 L
.71717 .89123 L
.71408 .89899 L
.71118 .90909 L
.70707 .91677 L
.70607 .91919 L
.70201 .92929 L
.69823 .93939 L
.69697 .94193 L
.69387 .94949 L
.69087 .9596 L
.68687 .96682 L
.68564 .9697 L
.68148 .9798 L
.67747 .9899 L
.67677 .99115 L
.6731 1 L
1 1 L
F
0 g
1 .06126 m
.9972 .07071 L
.99411 .08081 L
.99098 .09091 L
.9899 .09441 L
.98785 .10101 L
.98686 .11111 L
.98211 .12121 L
.9798 .1273 L
.97853 .13131 L
.97539 .14141 L
.97301 .15152 L
.9697 .15993 L
.96916 .16162 L
.96599 .17172 L
.96388 .18182 L
.95974 .19192 L
.9596 .19232 L
.95653 .20202 L
.95471 .21212 L
.95034 .22222 L
.94949 .22449 L
.94699 .23232 L
.94548 .24242 L
.94088 .25253 L
.93939 .25642 L
.93739 .26263 L
.9362 .27273 L
.93135 .28283 L
.92929 .28809 L
.92771 .29293 L
.92445 .30303 L
.92174 .31313 L
.91919 .3195 L
.91796 .32323 L
.91468 .33333 L
.91203 .34343 L
.90909 .35067 L
.90813 .35354 L
.90482 .36364 L
.90223 .37374 L
.89899 .38157 L
.89823 .38384 L
.89488 .39394 L
.89232 .40404 L
.88889 .41222 L
.88824 .41414 L
.88486 .42424 L
.8823 .43434 L
.87879 .44261 L
Mistroke
.87816 .44444 L
.87476 .45455 L
.87215 .46465 L
.86869 .47274 L
.86799 .47475 L
.86456 .48485 L
.86188 .49495 L
.85859 .50261 L
.85774 .50505 L
.85428 .51515 L
.85148 .52525 L
.84848 .53222 L
.84738 .53535 L
.84389 .54545 L
.84096 .55556 L
.83838 .56155 L
.83693 .56566 L
.83341 .57576 L
.83031 .58586 L
.82828 .5906 L
.82638 .59596 L
.82474 .60606 L
.81954 .61616 L
.81818 .61937 L
.81571 .62626 L
.81365 .63636 L
.80867 .64646 L
.80808 .64785 L
.80494 .65657 L
.80245 .66667 L
.79798 .67607 L
.79772 .67677 L
.79405 .68687 L
.79115 .69697 L
.78788 .70404 L
.78675 .70707 L
.78305 .71717 L
.77977 .72727 L
.77778 .73168 L
.77565 .73737 L
.77363 .74747 L
.76831 .75758 L
.76768 .759 L
.76442 .76768 L
.76168 .77778 L
.75758 .78608 L
.75688 .78788 L
.75305 .79798 L
.74973 .80808 L
.74747 .81284 L
Mistroke
.74541 .81818 L
.74331 .82828 L
.73777 .83838 L
.73737 .83925 L
.73379 .84848 L
.73074 .85859 L
.72727 .86544 L
.72597 .86869 L
.72202 .87879 L
.7183 .88889 L
.71717 .89123 L
.71408 .89899 L
.71118 .90909 L
.70707 .91677 L
.70607 .91919 L
.70201 .92929 L
.69823 .93939 L
.69697 .94193 L
.69387 .94949 L
.69087 .9596 L
.68687 .96682 L
.68564 .9697 L
.68148 .9798 L
.67747 .9899 L
.67677 .99115 L
.6731 1 L
Mfstroke
.6 g
1 .08662 m
.99873 .09091 L
.99568 .10101 L
.99019 .11111 L
.9899 .11988 L
.98961 .12121 L
.98675 .13131 L
.9835 .14141 L
.98024 .15152 L
.9798 .15292 L
.97747 .16162 L
.97424 .17172 L
.97095 .18182 L
.9697 .18572 L
.96809 .19192 L
.96491 .20202 L
.96159 .21212 L
.9596 .21828 L
.95861 .22222 L
.9555 .23232 L
.95217 .24242 L
.94949 .2506 L
.94904 .25253 L
.94602 .26263 L
.94268 .27273 L
.93939 .28267 L
.93936 .28283 L
.93646 .29293 L
.93312 .30303 L
.92975 .31313 L
.92929 .31451 L
.92682 .32323 L
.92348 .33333 L
.92008 .34343 L
.91919 .3461 L
.9171 .35354 L
.91376 .36364 L
.91033 .37374 L
.90909 .37745 L
.9073 .38384 L
.90396 .39394 L
.90051 .40404 L
.89899 .40854 L
.89742 .41414 L
.89408 .42424 L
.89061 .43434 L
.88889 .43938 L
.88747 .44444 L
.88412 .45455 L
.88062 .46465 L
.87879 .46997 L
.87743 .47475 L
.87407 .48485 L
.87054 .49495 L
.86869 .50031 L
.86732 .50505 L
.86393 .51515 L
.86038 .52525 L
.85859 .53038 L
.85713 .53535 L
.8537 .54545 L
.85012 .55556 L
.84848 .5602 L
.84685 .56566 L
.84337 .57576 L
.83976 .58586 L
.83838 .58975 L
.83648 .59596 L
.83295 .60606 L
.82931 .61616 L
.82828 .61903 L
.82602 .62626 L
.82242 .63636 L
.81875 .64646 L
.81818 .64805 L
.81544 .65657 L
.81179 .66667 L
.80809 .67677 L
.80808 .6768 L
.80475 .68687 L
.80105 .69697 L
.79798 .70528 L
.79744 .70707 L
.79395 .71717 L
.79019 .72727 L
.78788 .73348 L
.78665 .73737 L
.78301 .74747 L
.77921 .75758 L
.77778 .7614 L
.7757 .76768 L
.77196 .77778 L
.76812 .78788 L
.76768 .78904 L
.7646 .79798 L
.76077 .80808 L
.75758 .8164 L
.757 .81818 L
.75335 .82828 L
.74944 .83838 L
.74747 .84347 L
.74577 .84848 L
.74194 .85859 L
.73798 .86869 L
.73737 .87025 L
.73433 .87879 L
.73037 .88889 L
.72727 .89673 L
.72651 .89899 L
.72269 .90909 L
.71866 .91919 L
.71717 .92292 L
.71488 .92929 L
.71088 .93939 L
.70707 .94881 L
.70684 .94949 L
.703 .9596 L
.69889 .9697 L
.69697 .97439 L
.69498 .9798 L
.69091 .9899 L
.68687 .99965 L
.68675 1 L
1 1 L
F
0 g
1 .08662 m
.99873 .09091 L
.99568 .10101 L
.99019 .11111 L
.9899 .11988 L
.98961 .12121 L
.98675 .13131 L
.9835 .14141 L
.98024 .15152 L
.9798 .15292 L
.97747 .16162 L
.97424 .17172 L
.97095 .18182 L
.9697 .18572 L
.96809 .19192 L
.96491 .20202 L
.96159 .21212 L
.9596 .21828 L
.95861 .22222 L
.9555 .23232 L
.95217 .24242 L
.94949 .2506 L
.94904 .25253 L
.94602 .26263 L
.94268 .27273 L
.93939 .28267 L
.93936 .28283 L
.93646 .29293 L
.93312 .30303 L
.92975 .31313 L
.92929 .31451 L
.92682 .32323 L
.92348 .33333 L
.92008 .34343 L
.91919 .3461 L
.9171 .35354 L
.91376 .36364 L
.91033 .37374 L
.90909 .37745 L
.9073 .38384 L
.90396 .39394 L
.90051 .40404 L
.89899 .40854 L
.89742 .41414 L
.89408 .42424 L
.89061 .43434 L
.88889 .43938 L
.88747 .44444 L
.88412 .45455 L
.88062 .46465 L
Mistroke
.87879 .46997 L
.87743 .47475 L
.87407 .48485 L
.87054 .49495 L
.86869 .50031 L
.86732 .50505 L
.86393 .51515 L
.86038 .52525 L
.85859 .53038 L
.85713 .53535 L
.8537 .54545 L
.85012 .55556 L
.84848 .5602 L
.84685 .56566 L
.84337 .57576 L
.83976 .58586 L
.83838 .58975 L
.83648 .59596 L
.83295 .60606 L
.82931 .61616 L
.82828 .61903 L
.82602 .62626 L
.82242 .63636 L
.81875 .64646 L
.81818 .64805 L
.81544 .65657 L
.81179 .66667 L
.80809 .67677 L
.80808 .6768 L
.80475 .68687 L
.80105 .69697 L
.79798 .70528 L
.79744 .70707 L
.79395 .71717 L
.79019 .72727 L
.78788 .73348 L
.78665 .73737 L
.78301 .74747 L
.77921 .75758 L
.77778 .7614 L
.7757 .76768 L
.77196 .77778 L
.76812 .78788 L
.76768 .78904 L
.7646 .79798 L
.76077 .80808 L
.75758 .8164 L
.757 .81818 L
.75335 .82828 L
.74944 .83838 L
Mistroke
.74747 .84347 L
.74577 .84848 L
.74194 .85859 L
.73798 .86869 L
.73737 .87025 L
.73433 .87879 L
.73037 .88889 L
.72727 .89673 L
.72651 .89899 L
.72269 .90909 L
.71866 .91919 L
.71717 .92292 L
.71488 .92929 L
.71088 .93939 L
.70707 .94881 L
.70684 .94949 L
.703 .9596 L
.69889 .9697 L
.69697 .97439 L
.69498 .9798 L
.69091 .9899 L
.68687 .99965 L
.68675 1 L
Mfstroke
.5 g
1 .10765 m
.99674 .11111 L
.99445 .12121 L
.99245 .13131 L
.9899 .141 L
.98978 .14141 L
.98678 .15152 L
.98366 .16162 L
.98053 .17172 L
.9798 .17412 L
.97751 .18182 L
.97439 .19192 L
.97124 .20202 L
.9697 .207 L
.96818 .21212 L
.96506 .22222 L
.96188 .23232 L
.9596 .23965 L
.95877 .24242 L
.95566 .25253 L
.95246 .26263 L
.94949 .27206 L
.9493 .27273 L
.94619 .28283 L
.94298 .29293 L
.93977 .30303 L
.93939 .30423 L
.93665 .31313 L
.93343 .32323 L
.93019 .33333 L
.92929 .33616 L
.92704 .34343 L
.92381 .35354 L
.92054 .36364 L
.91919 .36784 L
.91736 .37374 L
.91411 .38384 L
.91082 .39394 L
.90909 .39928 L
.90761 .40404 L
.90434 .41414 L
.90102 .42424 L
.89899 .43047 L
.89777 .43434 L
.89449 .44444 L
.89115 .45455 L
.88889 .46141 L
.88787 .46465 L
.88456 .47475 L
.8812 .48485 L
.87879 .4921 L
.87788 .49495 L
.87455 .50505 L
.87116 .51515 L
.86869 .52254 L
.86781 .52525 L
.86446 .53535 L
.86104 .54545 L
.85859 .55272 L
.85766 .55556 L
.85428 .56566 L
.85083 .57576 L
.84848 .58264 L
.84743 .58586 L
.84401 .59596 L
.84053 .60606 L
.83838 .61231 L
.8371 .61616 L
.83364 .62626 L
.83013 .63636 L
.82828 .64171 L
.82668 .64646 L
.82318 .65657 L
.81964 .66667 L
.81818 .67084 L
.81616 .67677 L
.81262 .68687 L
.80905 .69697 L
.80808 .69971 L
.80554 .70707 L
.80195 .71717 L
.79835 .72727 L
.79798 .72831 L
.79481 .73737 L
.79118 .74747 L
.78788 .75664 L
.78755 .75758 L
.78396 .76768 L
.78029 .77778 L
.77778 .78469 L
.77665 .78788 L
.773 .79798 L
.76928 .80808 L
.76768 .81247 L
.76562 .81818 L
.76191 .82828 L
.75816 .83838 L
.75758 .83996 L
.75446 .84848 L
.75069 .85859 L
.74747 .86717 L
.74692 .86869 L
.74317 .87879 L
.73934 .88889 L
.73737 .89409 L
.73556 .89899 L
.73173 .90909 L
.72786 .91919 L
.72727 .92073 L
.72404 .92929 L
.72014 .93939 L
.71717 .94707 L
.71626 .94949 L
.71236 .9596 L
.70841 .9697 L
.70707 .97311 L
.7045 .9798 L
.70052 .9899 L
.69697 .99885 L
.69653 1 L
1 1 L
F
0 g
1 .10765 m
.99674 .11111 L
.99445 .12121 L
.99245 .13131 L
.9899 .141 L
.98978 .14141 L
.98678 .15152 L
.98366 .16162 L
.98053 .17172 L
.9798 .17412 L
.97751 .18182 L
.97439 .19192 L
.97124 .20202 L
.9697 .207 L
.96818 .21212 L
.96506 .22222 L
.96188 .23232 L
.9596 .23965 L
.95877 .24242 L
.95566 .25253 L
.95246 .26263 L
.94949 .27206 L
.9493 .27273 L
.94619 .28283 L
.94298 .29293 L
.93977 .30303 L
.93939 .30423 L
.93665 .31313 L
.93343 .32323 L
.93019 .33333 L
.92929 .33616 L
.92704 .34343 L
.92381 .35354 L
.92054 .36364 L
.91919 .36784 L
.91736 .37374 L
.91411 .38384 L
.91082 .39394 L
.90909 .39928 L
.90761 .40404 L
.90434 .41414 L
.90102 .42424 L
.89899 .43047 L
.89777 .43434 L
.89449 .44444 L
.89115 .45455 L
.88889 .46141 L
.88787 .46465 L
.88456 .47475 L
.8812 .48485 L
Mistroke
.87879 .4921 L
.87788 .49495 L
.87455 .50505 L
.87116 .51515 L
.86869 .52254 L
.86781 .52525 L
.86446 .53535 L
.86104 .54545 L
.85859 .55272 L
.85766 .55556 L
.85428 .56566 L
.85083 .57576 L
.84848 .58264 L
.84743 .58586 L
.84401 .59596 L
.84053 .60606 L
.83838 .61231 L
.8371 .61616 L
.83364 .62626 L
.83013 .63636 L
.82828 .64171 L
.82668 .64646 L
.82318 .65657 L
.81964 .66667 L
.81818 .67084 L
.81616 .67677 L
.81262 .68687 L
.80905 .69697 L
.80808 .69971 L
.80554 .70707 L
.80195 .71717 L
.79835 .72727 L
.79798 .72831 L
.79481 .73737 L
.79118 .74747 L
.78788 .75664 L
.78755 .75758 L
.78396 .76768 L
.78029 .77778 L
.77778 .78469 L
.77665 .78788 L
.773 .79798 L
.76928 .80808 L
.76768 .81247 L
.76562 .81818 L
.76191 .82828 L
.75816 .83838 L
.75758 .83996 L
.75446 .84848 L
.75069 .85859 L
Mistroke
.74747 .86717 L
.74692 .86869 L
.74317 .87879 L
.73934 .88889 L
.73737 .89409 L
.73556 .89899 L
.73173 .90909 L
.72786 .91919 L
.72727 .92073 L
.72404 .92929 L
.72014 .93939 L
.71717 .94707 L
.71626 .94949 L
.71236 .9596 L
.70841 .9697 L
.70707 .97311 L
.7045 .9798 L
.70052 .9899 L
.69697 .99885 L
.69653 1 L
Mfstroke
.4 g
1 .12769 m
.99861 .13131 L
.9956 .14141 L
.99273 .15152 L
.9899 .16112 L
.98975 .16162 L
.98666 .17172 L
.98355 .18182 L
.98049 .19192 L
.9798 .1943 L
.97743 .20202 L
.9743 .21212 L
.97119 .22222 L
.9697 .22726 L
.96814 .23232 L
.96499 .24242 L
.96184 .25253 L
.9596 .25998 L
.95878 .26263 L
.95561 .27273 L
.95244 .28283 L
.94949 .29246 L
.94935 .29293 L
.94618 .30303 L
.94297 .31313 L
.93984 .32323 L
.93939 .32471 L
.93667 .33333 L
.93344 .34343 L
.93026 .35354 L
.92929 .35671 L
.92709 .36364 L
.92385 .37374 L
.92063 .38384 L
.91919 .38848 L
.91745 .39394 L
.91418 .40404 L
.91093 .41414 L
.90909 .42 L
.90773 .42424 L
.90444 .43434 L
.90115 .44444 L
.89899 .45127 L
.89793 .45455 L
.89462 .46465 L
.8913 .47475 L
.88889 .4823 L
.88806 .48485 L
.88472 .49495 L
.88138 .50505 L
.87879 .51308 L
.87811 .51515 L
.87475 .52525 L
.87138 .53535 L
.86869 .5436 L
.86807 .54545 L
.86469 .55556 L
.86129 .56566 L
.85859 .57387 L
.85796 .57576 L
.85454 .58586 L
.85112 .59596 L
.84848 .60389 L
.84775 .60606 L
.84431 .61616 L
.84086 .62626 L
.83838 .63364 L
.83746 .63636 L
.83398 .64646 L
.8305 .65657 L
.82828 .66314 L
.82707 .66667 L
.82356 .67677 L
.82006 .68687 L
.81818 .69238 L
.81659 .69697 L
.81304 .70707 L
.80951 .71717 L
.80808 .72135 L
.806 .72727 L
.80242 .73737 L
.79887 .74747 L
.79798 .75005 L
.79531 .75758 L
.79169 .76768 L
.78812 .77778 L
.78788 .77848 L
.78451 .78788 L
.78086 .79798 L
.77778 .80664 L
.77726 .80808 L
.77359 .81818 L
.76992 .82828 L
.76768 .83453 L
.76627 .83838 L
.76256 .84848 L
.75886 .85859 L
.75758 .86213 L
.75516 .86869 L
.7514 .87879 L
.74768 .88889 L
.74747 .88946 L
.74392 .89899 L
.74012 .90909 L
.73737 .9165 L
.73636 .91919 L
.73254 .92929 L
.72872 .93939 L
.72727 .94326 L
.7249 .94949 L
.72103 .9596 L
.71718 .9697 L
.71717 .96973 L
.71329 .9798 L
.70937 .9899 L
.70707 .99591 L
.70548 1 L
1 1 L
F
0 g
1 .12769 m
.99861 .13131 L
.9956 .14141 L
.99273 .15152 L
.9899 .16112 L
.98975 .16162 L
.98666 .17172 L
.98355 .18182 L
.98049 .19192 L
.9798 .1943 L
.97743 .20202 L
.9743 .21212 L
.97119 .22222 L
.9697 .22726 L
.96814 .23232 L
.96499 .24242 L
.96184 .25253 L
.9596 .25998 L
.95878 .26263 L
.95561 .27273 L
.95244 .28283 L
.94949 .29246 L
.94935 .29293 L
.94618 .30303 L
.94297 .31313 L
.93984 .32323 L
.93939 .32471 L
.93667 .33333 L
.93344 .34343 L
.93026 .35354 L
.92929 .35671 L
.92709 .36364 L
.92385 .37374 L
.92063 .38384 L
.91919 .38848 L
.91745 .39394 L
.91418 .40404 L
.91093 .41414 L
.90909 .42 L
.90773 .42424 L
.90444 .43434 L
.90115 .44444 L
.89899 .45127 L
.89793 .45455 L
.89462 .46465 L
.8913 .47475 L
.88889 .4823 L
.88806 .48485 L
.88472 .49495 L
.88138 .50505 L
Mistroke
.87879 .51308 L
.87811 .51515 L
.87475 .52525 L
.87138 .53535 L
.86869 .5436 L
.86807 .54545 L
.86469 .55556 L
.86129 .56566 L
.85859 .57387 L
.85796 .57576 L
.85454 .58586 L
.85112 .59596 L
.84848 .60389 L
.84775 .60606 L
.84431 .61616 L
.84086 .62626 L
.83838 .63364 L
.83746 .63636 L
.83398 .64646 L
.8305 .65657 L
.82828 .66314 L
.82707 .66667 L
.82356 .67677 L
.82006 .68687 L
.81818 .69238 L
.81659 .69697 L
.81304 .70707 L
.80951 .71717 L
.80808 .72135 L
.806 .72727 L
.80242 .73737 L
.79887 .74747 L
.79798 .75005 L
.79531 .75758 L
.79169 .76768 L
.78812 .77778 L
.78788 .77848 L
.78451 .78788 L
.78086 .79798 L
.77778 .80664 L
.77726 .80808 L
.77359 .81818 L
.76992 .82828 L
.76768 .83453 L
.76627 .83838 L
.76256 .84848 L
.75886 .85859 L
.75758 .86213 L
.75516 .86869 L
.7514 .87879 L
Mistroke
.74768 .88889 L
.74747 .88946 L
.74392 .89899 L
.74012 .90909 L
.73737 .9165 L
.73636 .91919 L
.73254 .92929 L
.72872 .93939 L
.72727 .94326 L
.7249 .94949 L
.72103 .9596 L
.71718 .9697 L
.71717 .96973 L
.71329 .9798 L
.70937 .9899 L
.70707 .99591 L
.70548 1 L
Mfstroke
.3 g
1 .14873 m
.99913 .15152 L
.99613 .16162 L
.99312 .17172 L
.99003 .18182 L
.9899 .18224 L
.98684 .19192 L
.98362 .20202 L
.98062 .21212 L
.9798 .21551 L
.97767 .22222 L
.97443 .23232 L
.97129 .24242 L
.9697 .24855 L
.96843 .25253 L
.96518 .26263 L
.96196 .27273 L
.9596 .28136 L
.95913 .28283 L
.95586 .29293 L
.95259 .30303 L
.94968 .31313 L
.94949 .31393 L
.94648 .32323 L
.94318 .33333 L
.94011 .34343 L
.93939 .34626 L
.93703 .35354 L
.9337 .36364 L
.93052 .37374 L
.92929 .37836 L
.9275 .38384 L
.92415 .39394 L
.9209 .40404 L
.91919 .41021 L
.9179 .41414 L
.91454 .42424 L
.91123 .43434 L
.90909 .44183 L
.90823 .44444 L
.90484 .45455 L
.90149 .46465 L
.89899 .4732 L
.89848 .47475 L
.89507 .48485 L
.89169 .49495 L
.88889 .50433 L
.88865 .50505 L
.88522 .51515 L
.88181 .52525 L
.87879 .53521 L
.87874 .53535 L
.87529 .54545 L
.87185 .55556 L
.86873 .56566 L
.86869 .56584 L
.86528 .57576 L
.86181 .58586 L
.85865 .59596 L
.85859 .59621 L
.85518 .60606 L
.85168 .61616 L
.84851 .62626 L
.84848 .62634 L
.84499 .63636 L
.84147 .64646 L
.83838 .65621 L
.83826 .65657 L
.8347 .66667 L
.83116 .67677 L
.82828 .68582 L
.82791 .68687 L
.82433 .69697 L
.82077 .70707 L
.81818 .71517 L
.81747 .71717 L
.81385 .72727 L
.81028 .73737 L
.80808 .74426 L
.80693 .74747 L
.80327 .75758 L
.7997 .76768 L
.79798 .77308 L
.79628 .77778 L
.79259 .78788 L
.78904 .79798 L
.78788 .80164 L
.78552 .80808 L
.78181 .81818 L
.77829 .82828 L
.77778 .82993 L
.77465 .83838 L
.77092 .84848 L
.76768 .85795 L
.76744 .85859 L
.76366 .86869 L
.75993 .87879 L
.75758 .88569 L
.75638 .88889 L
.75256 .89899 L
.74884 .90909 L
.74747 .91316 L
.74519 .91919 L
.74133 .92929 L
.73769 .93939 L
.73737 .94035 L
.73386 .94949 L
.73 .9596 L
.72727 .96726 L
.72633 .9697 L
.7224 .9798 L
.71857 .9899 L
.71717 .99389 L
.71478 1 L
1 1 L
F
0 g
1 .14873 m
.99913 .15152 L
.99613 .16162 L
.99312 .17172 L
.99003 .18182 L
.9899 .18224 L
.98684 .19192 L
.98362 .20202 L
.98062 .21212 L
.9798 .21551 L
.97767 .22222 L
.97443 .23232 L
.97129 .24242 L
.9697 .24855 L
.96843 .25253 L
.96518 .26263 L
.96196 .27273 L
.9596 .28136 L
.95913 .28283 L
.95586 .29293 L
.95259 .30303 L
.94968 .31313 L
.94949 .31393 L
.94648 .32323 L
.94318 .33333 L
.94011 .34343 L
.93939 .34626 L
.93703 .35354 L
.9337 .36364 L
.93052 .37374 L
.92929 .37836 L
.9275 .38384 L
.92415 .39394 L
.9209 .40404 L
.91919 .41021 L
.9179 .41414 L
.91454 .42424 L
.91123 .43434 L
.90909 .44183 L
.90823 .44444 L
.90484 .45455 L
.90149 .46465 L
.89899 .4732 L
.89848 .47475 L
.89507 .48485 L
.89169 .49495 L
.88889 .50433 L
.88865 .50505 L
.88522 .51515 L
.88181 .52525 L
Mistroke
.87879 .53521 L
.87874 .53535 L
.87529 .54545 L
.87185 .55556 L
.86873 .56566 L
.86869 .56584 L
.86528 .57576 L
.86181 .58586 L
.85865 .59596 L
.85859 .59621 L
.85518 .60606 L
.85168 .61616 L
.84851 .62626 L
.84848 .62634 L
.84499 .63636 L
.84147 .64646 L
.83838 .65621 L
.83826 .65657 L
.8347 .66667 L
.83116 .67677 L
.82828 .68582 L
.82791 .68687 L
.82433 .69697 L
.82077 .70707 L
.81818 .71517 L
.81747 .71717 L
.81385 .72727 L
.81028 .73737 L
.80808 .74426 L
.80693 .74747 L
.80327 .75758 L
.7997 .76768 L
.79798 .77308 L
.79628 .77778 L
.79259 .78788 L
.78904 .79798 L
.78788 .80164 L
.78552 .80808 L
.78181 .81818 L
.77829 .82828 L
.77778 .82993 L
.77465 .83838 L
.77092 .84848 L
.76768 .85795 L
.76744 .85859 L
.76366 .86869 L
.75993 .87879 L
.75758 .88569 L
.75638 .88889 L
.75256 .89899 L
Mistroke
.74884 .90909 L
.74747 .91316 L
.74519 .91919 L
.74133 .92929 L
.73769 .93939 L
.73737 .94035 L
.73386 .94949 L
.73 .9596 L
.72727 .96726 L
.72633 .9697 L
.7224 .9798 L
.71857 .9899 L
.71717 .99389 L
.71478 1 L
Mfstroke
.2 g
1 .17406 m
.99784 .18182 L
.99493 .19192 L
.99181 .20202 L
.9899 .20771 L
.98832 .21212 L
.98405 .22222 L
.9825 .23232 L
.9798 .24115 L
.97935 .24242 L
.97536 .25253 L
.9733 .26263 L
.9702 .27273 L
.9697 .27433 L
.96648 .28283 L
.96404 .29293 L
.96093 .30303 L
.9596 .30728 L
.95743 .31313 L
.95289 .32323 L
.95159 .33333 L
.94949 .34002 L
.94825 .34343 L
.94397 .35354 L
.94219 .36364 L
.93939 .37254 L
.93896 .37374 L
.93487 .38384 L
.93273 .39394 L
.92954 .40404 L
.92929 .4048 L
.92561 .41414 L
.9232 .42424 L
.91999 .43434 L
.91919 .43682 L
.91623 .44444 L
.91361 .45455 L
.91038 .46465 L
.90909 .46861 L
.90673 .47475 L
.90196 .48485 L
.90069 .49495 L
.89899 .50017 L
.89712 .50505 L
.89248 .51515 L
.89093 .52525 L
.88889 .53149 L
.88741 .53535 L
.88286 .54545 L
.8811 .55556 L
.87879 .56257 L
.87761 .56566 L
.87311 .57576 L
.87119 .58586 L
.86869 .5934 L
.86771 .59596 L
.86322 .60606 L
.86121 .61616 L
.85859 .62399 L
.85771 .62626 L
.85322 .63636 L
.85114 .64646 L
.84848 .65433 L
.84762 .65657 L
.84308 .66667 L
.84099 .67677 L
.83838 .68442 L
.83742 .68687 L
.83282 .69697 L
.83075 .70707 L
.82828 .71426 L
.82712 .71717 L
.82241 .72727 L
.82043 .73737 L
.81818 .74385 L
.81671 .74747 L
.81186 .75758 L
.81001 .76768 L
.80808 .77318 L
.80618 .77778 L
.80112 .78788 L
.7995 .79798 L
.79798 .80226 L
.79552 .80808 L
.79245 .81818 L
.78889 .82828 L
.78788 .83108 L
.78471 .83838 L
.78178 .84848 L
.77818 .85859 L
.77778 .85967 L
.77372 .86869 L
.771 .87879 L
.76768 .888 L
.76731 .88889 L
.76251 .89899 L
.76011 .90909 L
.75758 .91602 L
.75622 .91919 L
.75102 .92929 L
.74911 .93939 L
.74747 .94378 L
.74493 .94949 L
.74172 .9596 L
.73799 .9697 L
.73737 .97132 L
.73339 .9798 L
.73053 .9899 L
.72727 .99864 L
.72666 1 L
1 1 L
F
0 g
1 .17406 m
.99784 .18182 L
.99493 .19192 L
.99181 .20202 L
.9899 .20771 L
.98832 .21212 L
.98405 .22222 L
.9825 .23232 L
.9798 .24115 L
.97935 .24242 L
.97536 .25253 L
.9733 .26263 L
.9702 .27273 L
.9697 .27433 L
.96648 .28283 L
.96404 .29293 L
.96093 .30303 L
.9596 .30728 L
.95743 .31313 L
.95289 .32323 L
.95159 .33333 L
.94949 .34002 L
.94825 .34343 L
.94397 .35354 L
.94219 .36364 L
.93939 .37254 L
.93896 .37374 L
.93487 .38384 L
.93273 .39394 L
.92954 .40404 L
.92929 .4048 L
.92561 .41414 L
.9232 .42424 L
.91999 .43434 L
.91919 .43682 L
.91623 .44444 L
.91361 .45455 L
.91038 .46465 L
.90909 .46861 L
.90673 .47475 L
.90196 .48485 L
.90069 .49495 L
.89899 .50017 L
.89712 .50505 L
.89248 .51515 L
.89093 .52525 L
.88889 .53149 L
.88741 .53535 L
.88286 .54545 L
.8811 .55556 L
Mistroke
.87879 .56257 L
.87761 .56566 L
.87311 .57576 L
.87119 .58586 L
.86869 .5934 L
.86771 .59596 L
.86322 .60606 L
.86121 .61616 L
.85859 .62399 L
.85771 .62626 L
.85322 .63636 L
.85114 .64646 L
.84848 .65433 L
.84762 .65657 L
.84308 .66667 L
.84099 .67677 L
.83838 .68442 L
.83742 .68687 L
.83282 .69697 L
.83075 .70707 L
.82828 .71426 L
.82712 .71717 L
.82241 .72727 L
.82043 .73737 L
.81818 .74385 L
.81671 .74747 L
.81186 .75758 L
.81001 .76768 L
.80808 .77318 L
.80618 .77778 L
.80112 .78788 L
.7995 .79798 L
.79798 .80226 L
.79552 .80808 L
.79245 .81818 L
.78889 .82828 L
.78788 .83108 L
.78471 .83838 L
.78178 .84848 L
.77818 .85859 L
.77778 .85967 L
.77372 .86869 L
.771 .87879 L
.76768 .888 L
.76731 .88889 L
.76251 .89899 L
.76011 .90909 L
.75758 .91602 L
.75622 .91919 L
.75102 .92929 L
Mistroke
.74911 .93939 L
.74747 .94378 L
.74493 .94949 L
.74172 .9596 L
.73799 .9697 L
.73737 .97132 L
.73339 .9798 L
.73053 .9899 L
.72727 .99864 L
.72666 1 L
Mfstroke
.3 g
1 .27072 m
.99941 .27273 L
.99639 .28283 L
.99328 .29293 L
.99014 .30303 L
.9899 .30383 L
.98702 .31313 L
.98543 .32323 L
.98105 .33333 L
.9798 .33673 L
.9777 .34343 L
.97663 .35354 L
.97188 .36364 L
.9697 .36938 L
.96832 .37374 L
.96516 .38384 L
.96268 .39394 L
.9596 .40178 L
.95887 .40404 L
.95568 .41414 L
.95343 .42424 L
.94949 .43392 L
.94936 .43434 L
.94614 .44444 L
.94412 .45455 L
.93984 .46465 L
.93939 .46584 L
.93653 .47475 L
.93475 .48485 L
.93027 .49495 L
.92929 .49751 L
.92685 .50505 L
.92528 .51515 L
.92062 .52525 L
.91919 .52894 L
.91709 .53535 L
.91572 .54545 L
.91089 .55556 L
.90909 .5601 L
.90725 .56566 L
.90605 .57576 L
.90106 .58586 L
.89899 .59102 L
.89734 .59596 L
.89623 .60606 L
.89112 .61616 L
.88889 .62167 L
.88734 .62626 L
.88397 .63636 L
.88108 .64646 L
.87879 .65206 L
.87725 .65657 L
.87386 .66667 L
.87093 .67677 L
.86869 .68219 L
.86708 .68687 L
.86587 .69697 L
.86066 .70707 L
.85859 .71206 L
.85682 .71717 L
.85542 .72727 L
.85026 .73737 L
.84848 .74165 L
.84645 .74747 L
.84482 .75758 L
.83976 .76768 L
.83838 .77097 L
.83599 .77778 L
.83407 .78788 L
.82913 .79798 L
.82828 .80002 L
.82543 .80808 L
.82318 .81818 L
.81839 .82828 L
.81818 .82878 L
.81476 .83838 L
.81217 .84848 L
.80808 .8573 L
.80761 .85859 L
.80398 .86869 L
.80105 .87879 L
.79798 .88554 L
.79675 .88889 L
.79308 .89899 L
.78983 .90909 L
.78788 .91347 L
.78576 .91919 L
.7838 .92929 L
.77852 .93939 L
.77778 .94109 L
.77465 .94949 L
.77203 .9596 L
.76768 .96845 L
.7672 .9697 L
.76342 .9798 L
.76024 .9899 L
.75758 .99515 L
.75586 1 L
1 1 L
F
0 g
1 .27072 m
.99941 .27273 L
.99639 .28283 L
.99328 .29293 L
.99014 .30303 L
.9899 .30383 L
.98702 .31313 L
.98543 .32323 L
.98105 .33333 L
.9798 .33673 L
.9777 .34343 L
.97663 .35354 L
.97188 .36364 L
.9697 .36938 L
.96832 .37374 L
.96516 .38384 L
.96268 .39394 L
.9596 .40178 L
.95887 .40404 L
.95568 .41414 L
.95343 .42424 L
.94949 .43392 L
.94936 .43434 L
.94614 .44444 L
.94412 .45455 L
.93984 .46465 L
.93939 .46584 L
.93653 .47475 L
.93475 .48485 L
.93027 .49495 L
.92929 .49751 L
.92685 .50505 L
.92528 .51515 L
.92062 .52525 L
.91919 .52894 L
.91709 .53535 L
.91572 .54545 L
.91089 .55556 L
.90909 .5601 L
.90725 .56566 L
.90605 .57576 L
.90106 .58586 L
.89899 .59102 L
.89734 .59596 L
.89623 .60606 L
.89112 .61616 L
.88889 .62167 L
.88734 .62626 L
.88397 .63636 L
.88108 .64646 L
Mistroke
.87879 .65206 L
.87725 .65657 L
.87386 .66667 L
.87093 .67677 L
.86869 .68219 L
.86708 .68687 L
.86587 .69697 L
.86066 .70707 L
.85859 .71206 L
.85682 .71717 L
.85542 .72727 L
.85026 .73737 L
.84848 .74165 L
.84645 .74747 L
.84482 .75758 L
.83976 .76768 L
.83838 .77097 L
.83599 .77778 L
.83407 .78788 L
.82913 .79798 L
.82828 .80002 L
.82543 .80808 L
.82318 .81818 L
.81839 .82828 L
.81818 .82878 L
.81476 .83838 L
.81217 .84848 L
.80808 .8573 L
.80761 .85859 L
.80398 .86869 L
.80105 .87879 L
.79798 .88554 L
.79675 .88889 L
.79308 .89899 L
.78983 .90909 L
.78788 .91347 L
.78576 .91919 L
.7838 .92929 L
.77852 .93939 L
.77778 .94109 L
.77465 .94949 L
.77203 .9596 L
.76768 .96845 L
.7672 .9697 L
.76342 .9798 L
.76024 .9899 L
.75758 .99515 L
.75586 1 L
Mfstroke
.4 g
1 .29605 m
.99793 .30303 L
.99487 .31313 L
.99055 .32323 L
.9899 .32933 L
.98894 .33333 L
.9859 .34343 L
.98263 .35354 L
.9798 .36236 L
.97952 .36364 L
.97663 .37374 L
.97336 .38384 L
.97009 .39394 L
.9697 .39515 L
.96728 .40404 L
.96403 .41414 L
.96072 .42424 L
.9596 .42772 L
.95784 .43434 L
.95462 .44444 L
.95129 .45455 L
.94949 .46004 L
.94831 .46465 L
.94514 .47475 L
.94179 .48485 L
.93939 .49212 L
.93869 .49495 L
.93559 .50505 L
.93222 .51515 L
.92929 .52395 L
.92898 .52525 L
.92595 .53535 L
.92257 .54545 L
.91919 .55554 L
.91919 .55556 L
.91624 .56566 L
.91285 .57576 L
.90943 .58586 L
.90909 .58688 L
.90645 .59596 L
.90305 .60606 L
.8996 .61616 L
.89899 .61798 L
.89657 .62626 L
.89316 .63636 L
.88969 .64646 L
.88889 .64882 L
.88662 .65657 L
.88319 .66667 L
.87969 .67677 L
.87879 .67941 L
.87658 .68687 L
.87314 .69697 L
.86961 .70707 L
.86869 .70974 L
.86646 .71717 L
.86299 .72727 L
.85944 .73737 L
.85859 .73982 L
.85626 .74747 L
.85275 .75758 L
.84917 .76768 L
.84848 .76963 L
.84597 .77778 L
.84242 .78788 L
.83881 .79798 L
.83838 .79918 L
.83558 .80808 L
.83198 .81818 L
.82835 .82828 L
.82828 .82847 L
.82509 .83838 L
.82145 .84848 L
.81818 .85749 L
.81787 .85859 L
.81449 .86869 L
.8108 .87879 L
.80808 .88624 L
.80728 .88889 L
.80378 .89899 L
.80005 .90909 L
.79798 .91472 L
.79657 .91919 L
.79296 .92929 L
.78919 .93939 L
.78788 .94292 L
.78572 .94949 L
.78201 .9596 L
.7782 .9697 L
.77778 .97084 L
.77473 .9798 L
.77094 .9899 L
.76768 .99846 L
.7672 1 L
1 1 L
F
0 g
1 .29605 m
.99793 .30303 L
.99487 .31313 L
.99055 .32323 L
.9899 .32933 L
.98894 .33333 L
.9859 .34343 L
.98263 .35354 L
.9798 .36236 L
.97952 .36364 L
.97663 .37374 L
.97336 .38384 L
.97009 .39394 L
.9697 .39515 L
.96728 .40404 L
.96403 .41414 L
.96072 .42424 L
.9596 .42772 L
.95784 .43434 L
.95462 .44444 L
.95129 .45455 L
.94949 .46004 L
.94831 .46465 L
.94514 .47475 L
.94179 .48485 L
.93939 .49212 L
.93869 .49495 L
.93559 .50505 L
.93222 .51515 L
.92929 .52395 L
.92898 .52525 L
.92595 .53535 L
.92257 .54545 L
.91919 .55554 L
.91919 .55556 L
.91624 .56566 L
.91285 .57576 L
.90943 .58586 L
.90909 .58688 L
.90645 .59596 L
.90305 .60606 L
.8996 .61616 L
.89899 .61798 L
.89657 .62626 L
.89316 .63636 L
.88969 .64646 L
.88889 .64882 L
.88662 .65657 L
.88319 .66667 L
.87969 .67677 L
Mistroke
.87879 .67941 L
.87658 .68687 L
.87314 .69697 L
.86961 .70707 L
.86869 .70974 L
.86646 .71717 L
.86299 .72727 L
.85944 .73737 L
.85859 .73982 L
.85626 .74747 L
.85275 .75758 L
.84917 .76768 L
.84848 .76963 L
.84597 .77778 L
.84242 .78788 L
.83881 .79798 L
.83838 .79918 L
.83558 .80808 L
.83198 .81818 L
.82835 .82828 L
.82828 .82847 L
.82509 .83838 L
.82145 .84848 L
.81818 .85749 L
.81787 .85859 L
.81449 .86869 L
.8108 .87879 L
.80808 .88624 L
.80728 .88889 L
.80378 .89899 L
.80005 .90909 L
.79798 .91472 L
.79657 .91919 L
.79296 .92929 L
.78919 .93939 L
.78788 .94292 L
.78572 .94949 L
.78201 .9596 L
.7782 .9697 L
.77778 .97084 L
.77473 .9798 L
.77094 .9899 L
.76768 .99846 L
.7672 1 L
Mfstroke
.5 g
1 .31709 m
.99575 .32323 L
.994 .33333 L
.99179 .34343 L
.9899 .35044 L
.98901 .35354 L
.98595 .36364 L
.98282 .37374 L
.9798 .38356 L
.97972 .38384 L
.97669 .39394 L
.97355 .40404 L
.97041 .41414 L
.9697 .41644 L
.96736 .42424 L
.96421 .43434 L
.96104 .44444 L
.9596 .44909 L
.95796 .45455 L
.95481 .46465 L
.95162 .47475 L
.94949 .4815 L
.94849 .48485 L
.94534 .49495 L
.94212 .50505 L
.93939 .51367 L
.93895 .51515 L
.9358 .52525 L
.93257 .53535 L
.92934 .54545 L
.92929 .54559 L
.92619 .55556 L
.92294 .56566 L
.91968 .57576 L
.91919 .57728 L
.91651 .58586 L
.91324 .59596 L
.90995 .60606 L
.90909 .60872 L
.90675 .61616 L
.90346 .62626 L
.90014 .63636 L
.89899 .63991 L
.89691 .64646 L
.89361 .65657 L
.89026 .66667 L
.88889 .67085 L
.887 .67677 L
.88367 .68687 L
.8803 .69697 L
.87879 .70154 L
.87701 .70707 L
.87366 .71717 L
.87026 .72727 L
.86869 .73198 L
.86694 .73737 L
.86355 .74747 L
.86013 .75758 L
.85859 .76216 L
.85678 .76768 L
.85337 .77778 L
.84991 .78788 L
.84848 .79208 L
.84653 .79798 L
.84309 .80808 L
.83961 .81818 L
.83838 .82175 L
.8362 .82828 L
.83271 .83838 L
.8292 .84848 L
.82828 .85115 L
.82576 .85859 L
.82224 .86869 L
.8187 .87879 L
.81818 .88028 L
.81523 .88889 L
.81167 .89899 L
.8081 .90909 L
.80808 .90915 L
.80459 .91919 L
.801 .92929 L
.79798 .93775 L
.79741 .93939 L
.79385 .94949 L
.79021 .9596 L
.78788 .96608 L
.78661 .9697 L
.78299 .9798 L
.77931 .9899 L
.77778 .99413 L
.77569 1 L
1 1 L
F
0 g
1 .31709 m
.99575 .32323 L
.994 .33333 L
.99179 .34343 L
.9899 .35044 L
.98901 .35354 L
.98595 .36364 L
.98282 .37374 L
.9798 .38356 L
.97972 .38384 L
.97669 .39394 L
.97355 .40404 L
.97041 .41414 L
.9697 .41644 L
.96736 .42424 L
.96421 .43434 L
.96104 .44444 L
.9596 .44909 L
.95796 .45455 L
.95481 .46465 L
.95162 .47475 L
.94949 .4815 L
.94849 .48485 L
.94534 .49495 L
.94212 .50505 L
.93939 .51367 L
.93895 .51515 L
.9358 .52525 L
.93257 .53535 L
.92934 .54545 L
.92929 .54559 L
.92619 .55556 L
.92294 .56566 L
.91968 .57576 L
.91919 .57728 L
.91651 .58586 L
.91324 .59596 L
.90995 .60606 L
.90909 .60872 L
.90675 .61616 L
.90346 .62626 L
.90014 .63636 L
.89899 .63991 L
.89691 .64646 L
.89361 .65657 L
.89026 .66667 L
.88889 .67085 L
.887 .67677 L
.88367 .68687 L
.8803 .69697 L
Mistroke
.87879 .70154 L
.87701 .70707 L
.87366 .71717 L
.87026 .72727 L
.86869 .73198 L
.86694 .73737 L
.86355 .74747 L
.86013 .75758 L
.85859 .76216 L
.85678 .76768 L
.85337 .77778 L
.84991 .78788 L
.84848 .79208 L
.84653 .79798 L
.84309 .80808 L
.83961 .81818 L
.83838 .82175 L
.8362 .82828 L
.83271 .83838 L
.8292 .84848 L
.82828 .85115 L
.82576 .85859 L
.82224 .86869 L
.8187 .87879 L
.81818 .88028 L
.81523 .88889 L
.81167 .89899 L
.8081 .90909 L
.80808 .90915 L
.80459 .91919 L
.801 .92929 L
.79798 .93775 L
.79741 .93939 L
.79385 .94949 L
.79021 .9596 L
.78788 .96608 L
.78661 .9697 L
.78299 .9798 L
.77931 .9899 L
.77778 .99413 L
.77569 1 L
Mfstroke
.6 g
1 .33713 m
.99775 .34343 L
.99485 .35354 L
.99195 .36364 L
.9899 .37055 L
.98894 .37374 L
.98584 .38384 L
.98272 .39394 L
.9798 .40374 L
.97971 .40404 L
.9766 .41414 L
.97346 .42424 L
.97039 .43434 L
.9697 .4367 L
.96731 .44444 L
.96415 .45455 L
.96102 .46465 L
.9596 .46942 L
.95794 .47475 L
.95477 .48485 L
.95161 .49495 L
.94949 .5019 L
.94851 .50505 L
.94533 .51515 L
.94213 .52525 L
.93939 .53415 L
.93902 .53535 L
.93581 .54545 L
.93259 .55556 L
.92944 .56566 L
.92929 .56616 L
.92623 .57576 L
.92298 .58586 L
.91979 .59596 L
.91919 .59792 L
.91658 .60606 L
.91331 .61616 L
.91008 .62626 L
.90909 .62944 L
.90686 .63636 L
.90356 .64646 L
.90029 .65657 L
.89899 .66071 L
.89705 .66667 L
.89373 .67677 L
.89044 .68687 L
.88889 .69174 L
.88718 .69697 L
.88383 .70707 L
.8805 .71717 L
.87879 .72251 L
.87722 .72727 L
.87385 .73737 L
.87049 .74747 L
.86869 .75304 L
.86718 .75758 L
.86378 .76768 L
.8604 .77778 L
.85859 .78331 L
.85705 .78788 L
.85363 .79798 L
.85022 .80808 L
.84848 .81333 L
.84684 .81818 L
.84339 .82828 L
.83995 .83838 L
.83838 .84308 L
.83654 .84848 L
.83305 .85859 L
.82959 .86869 L
.82828 .87258 L
.82614 .87879 L
.82263 .88889 L
.81914 .89899 L
.81818 .90182 L
.81565 .90909 L
.8121 .91919 L
.80859 .92929 L
.80808 .93079 L
.80505 .93939 L
.80147 .94949 L
.79798 .95949 L
.79794 .9596 L
.79435 .9697 L
.79074 .9798 L
.78788 .98792 L
.78717 .9899 L
.78354 1 L
1 1 L
F
0 g
1 .33713 m
.99775 .34343 L
.99485 .35354 L
.99195 .36364 L
.9899 .37055 L
.98894 .37374 L
.98584 .38384 L
.98272 .39394 L
.9798 .40374 L
.97971 .40404 L
.9766 .41414 L
.97346 .42424 L
.97039 .43434 L
.9697 .4367 L
.96731 .44444 L
.96415 .45455 L
.96102 .46465 L
.9596 .46942 L
.95794 .47475 L
.95477 .48485 L
.95161 .49495 L
.94949 .5019 L
.94851 .50505 L
.94533 .51515 L
.94213 .52525 L
.93939 .53415 L
.93902 .53535 L
.93581 .54545 L
.93259 .55556 L
.92944 .56566 L
.92929 .56616 L
.92623 .57576 L
.92298 .58586 L
.91979 .59596 L
.91919 .59792 L
.91658 .60606 L
.91331 .61616 L
.91008 .62626 L
.90909 .62944 L
.90686 .63636 L
.90356 .64646 L
.90029 .65657 L
.89899 .66071 L
.89705 .66667 L
.89373 .67677 L
.89044 .68687 L
.88889 .69174 L
.88718 .69697 L
.88383 .70707 L
.8805 .71717 L
Mistroke
.87879 .72251 L
.87722 .72727 L
.87385 .73737 L
.87049 .74747 L
.86869 .75304 L
.86718 .75758 L
.86378 .76768 L
.8604 .77778 L
.85859 .78331 L
.85705 .78788 L
.85363 .79798 L
.85022 .80808 L
.84848 .81333 L
.84684 .81818 L
.84339 .82828 L
.83995 .83838 L
.83838 .84308 L
.83654 .84848 L
.83305 .85859 L
.82959 .86869 L
.82828 .87258 L
.82614 .87879 L
.82263 .88889 L
.81914 .89899 L
.81818 .90182 L
.81565 .90909 L
.8121 .91919 L
.80859 .92929 L
.80808 .93079 L
.80505 .93939 L
.80147 .94949 L
.79798 .95949 L
.79794 .9596 L
.79435 .9697 L
.79074 .9798 L
.78788 .98792 L
.78717 .9899 L
.78354 1 L
Mfstroke
.7 g
1 .35817 m
.99832 .36364 L
.99534 .37374 L
.99231 .38384 L
.9899 .39167 L
.98919 .39394 L
.98598 .40404 L
.98278 .41414 L
.97995 .42424 L
.9798 .42495 L
.97681 .43434 L
.97357 .44444 L
.97054 .45455 L
.9697 .45798 L
.96757 .46465 L
.96431 .47475 L
.96116 .48485 L
.9596 .49079 L
.95827 .49495 L
.95499 .50505 L
.95176 .51515 L
.94949 .52337 L
.94889 .52525 L
.9456 .53535 L
.94232 .54545 L
.93943 .55556 L
.93939 .5557 L
.93614 .56566 L
.93283 .57576 L
.92978 .58586 L
.92929 .5878 L
.92661 .59596 L
.92327 .60606 L
.92011 .61616 L
.91919 .61965 L
.91701 .62626 L
.91364 .63636 L
.91041 .64646 L
.90909 .65127 L
.90733 .65657 L
.90394 .66667 L
.90065 .67677 L
.89899 .68264 L
.89758 .68687 L
.89417 .69697 L
.89083 .70707 L
.88889 .71377 L
.88775 .71717 L
.88431 .72727 L
.88093 .73737 L
.87879 .74464 L
.87783 .74747 L
.87437 .75758 L
.87096 .76768 L
.86869 .77527 L
.86783 .77778 L
.86435 .78788 L
.86091 .79798 L
.85859 .80565 L
.85775 .80808 L
.85424 .81818 L
.85078 .82828 L
.84848 .83578 L
.84758 .83838 L
.84404 .84848 L
.84056 .85859 L
.83838 .86564 L
.83732 .86869 L
.83376 .87879 L
.83026 .88889 L
.82828 .89525 L
.82697 .89899 L
.82337 .90909 L
.81987 .91919 L
.81818 .92461 L
.81651 .92929 L
.81289 .93939 L
.80939 .94949 L
.80808 .95369 L
.80596 .9596 L
.80231 .9697 L
.79882 .9798 L
.79798 .98252 L
.7953 .9899 L
.79162 1 L
1 1 L
F
0 g
1 .35817 m
.99832 .36364 L
.99534 .37374 L
.99231 .38384 L
.9899 .39167 L
.98919 .39394 L
.98598 .40404 L
.98278 .41414 L
.97995 .42424 L
.9798 .42495 L
.97681 .43434 L
.97357 .44444 L
.97054 .45455 L
.9697 .45798 L
.96757 .46465 L
.96431 .47475 L
.96116 .48485 L
.9596 .49079 L
.95827 .49495 L
.95499 .50505 L
.95176 .51515 L
.94949 .52337 L
.94889 .52525 L
.9456 .53535 L
.94232 .54545 L
.93943 .55556 L
.93939 .5557 L
.93614 .56566 L
.93283 .57576 L
.92978 .58586 L
.92929 .5878 L
.92661 .59596 L
.92327 .60606 L
.92011 .61616 L
.91919 .61965 L
.91701 .62626 L
.91364 .63636 L
.91041 .64646 L
.90909 .65127 L
.90733 .65657 L
.90394 .66667 L
.90065 .67677 L
.89899 .68264 L
.89758 .68687 L
.89417 .69697 L
.89083 .70707 L
.88889 .71377 L
.88775 .71717 L
.88431 .72727 L
.88093 .73737 L
Mistroke
.87879 .74464 L
.87783 .74747 L
.87437 .75758 L
.87096 .76768 L
.86869 .77527 L
.86783 .77778 L
.86435 .78788 L
.86091 .79798 L
.85859 .80565 L
.85775 .80808 L
.85424 .81818 L
.85078 .82828 L
.84848 .83578 L
.84758 .83838 L
.84404 .84848 L
.84056 .85859 L
.83838 .86564 L
.83732 .86869 L
.83376 .87879 L
.83026 .88889 L
.82828 .89525 L
.82697 .89899 L
.82337 .90909 L
.81987 .91919 L
.81818 .92461 L
.81651 .92929 L
.81289 .93939 L
.80939 .94949 L
.80808 .95369 L
.80596 .9596 L
.80231 .9697 L
.79882 .9798 L
.79798 .98252 L
.7953 .9899 L
.79162 1 L
Mfstroke
.8 g
1 .38352 m
.99991 .38384 L
.99708 .39394 L
.99412 .40404 L
.99093 .41414 L
.9899 .41715 L
.98729 .42424 L
.98267 .43434 L
.98168 .44444 L
.9798 .45057 L
.97837 .45455 L
.97412 .46465 L
.97248 .47475 L
.9697 .48378 L
.96932 .48485 L
.96533 .49495 L
.96322 .50505 L
.96009 .51515 L
.9596 .51673 L
.95634 .52525 L
.95389 .53535 L
.95076 .54545 L
.94949 .54946 L
.94721 .55556 L
.9426 .56566 L
.94135 .57576 L
.93939 .58196 L
.93796 .58586 L
.93359 .59596 L
.93189 .60606 L
.92929 .61424 L
.92859 .61616 L
.9244 .62626 L
.92235 .63636 L
.91919 .64629 L
.91913 .64646 L
.91506 .65657 L
.91275 .66667 L
.90951 .67677 L
.90909 .67806 L
.90559 .68687 L
.90308 .69697 L
.89982 .70707 L
.89899 .70961 L
.896 .71717 L
.89334 .72727 L
.89006 .73737 L
.88889 .74092 L
.88631 .74747 L
.88139 .75758 L
.88022 .76768 L
.87879 .77199 L
.87652 .77778 L
.87166 .78788 L
.87031 .79798 L
.86869 .80283 L
.86662 .80808 L
.86179 .81818 L
.86031 .82828 L
.85859 .83341 L
.85662 .83838 L
.85179 .84848 L
.85024 .85859 L
.84848 .86375 L
.84652 .86869 L
.84164 .87879 L
.84008 .88889 L
.83838 .89385 L
.83631 .89899 L
.83134 .90909 L
.82984 .91919 L
.82828 .92369 L
.82599 .92929 L
.82089 .93939 L
.8195 .94949 L
.81818 .95328 L
.81555 .9596 L
.81258 .9697 L
.80908 .9798 L
.80808 .98262 L
.80498 .9899 L
.80209 1 L
1 1 L
F
0 g
1 .38352 m
.99991 .38384 L
.99708 .39394 L
.99412 .40404 L
.99093 .41414 L
.9899 .41715 L
.98729 .42424 L
.98267 .43434 L
.98168 .44444 L
.9798 .45057 L
.97837 .45455 L
.97412 .46465 L
.97248 .47475 L
.9697 .48378 L
.96932 .48485 L
.96533 .49495 L
.96322 .50505 L
.96009 .51515 L
.9596 .51673 L
.95634 .52525 L
.95389 .53535 L
.95076 .54545 L
.94949 .54946 L
.94721 .55556 L
.9426 .56566 L
.94135 .57576 L
.93939 .58196 L
.93796 .58586 L
.93359 .59596 L
.93189 .60606 L
.92929 .61424 L
.92859 .61616 L
.9244 .62626 L
.92235 .63636 L
.91919 .64629 L
.91913 .64646 L
.91506 .65657 L
.91275 .66667 L
.90951 .67677 L
.90909 .67806 L
.90559 .68687 L
.90308 .69697 L
.89982 .70707 L
.89899 .70961 L
.896 .71717 L
.89334 .72727 L
.89006 .73737 L
.88889 .74092 L
.88631 .74747 L
.88139 .75758 L
Mistroke
.88022 .76768 L
.87879 .77199 L
.87652 .77778 L
.87166 .78788 L
.87031 .79798 L
.86869 .80283 L
.86662 .80808 L
.86179 .81818 L
.86031 .82828 L
.85859 .83341 L
.85662 .83838 L
.85179 .84848 L
.85024 .85859 L
.84848 .86375 L
.84652 .86869 L
.84164 .87879 L
.84008 .88889 L
.83838 .89385 L
.83631 .89899 L
.83134 .90909 L
.82984 .91919 L
.82828 .92369 L
.82599 .92929 L
.82089 .93939 L
.8195 .94949 L
.81818 .95328 L
.81555 .9596 L
.81258 .9697 L
.80908 .9798 L
.80808 .98262 L
.80498 .9899 L
.80209 1 L
Mfstroke
.7 g
1 .48017 m
.99862 .48485 L
.99557 .49495 L
.99245 .50505 L
.9899 .51328 L
.98931 .51515 L
.98619 .52525 L
.98414 .53535 L
.98005 .54545 L
.9798 .54615 L
.97686 .55556 L
.97521 .56566 L
.97083 .57576 L
.9697 .57881 L
.96748 .58586 L
.96626 .59596 L
.96156 .60606 L
.9596 .61123 L
.95802 .61616 L
.95484 .62626 L
.95225 .63636 L
.94949 .64339 L
.9485 .64646 L
.94529 .65657 L
.94288 .66667 L
.93939 .67529 L
.93891 .67677 L
.93567 .68687 L
.93343 .69697 L
.92929 .70694 L
.92925 .70707 L
.92598 .71717 L
.9239 .72727 L
.91956 .73737 L
.91919 .73836 L
.91621 .74747 L
.91428 .75758 L
.9098 .76768 L
.90909 .76953 L
.90637 .77778 L
.90455 .78788 L
.89995 .79798 L
.89899 .80044 L
.89645 .80808 L
.89469 .81818 L
.89 .82828 L
.88889 .83109 L
.88644 .83838 L
.8847 .84848 L
.87994 .85859 L
.87879 .86149 L
.87635 .86869 L
.87457 .87879 L
.86978 .88889 L
.86869 .89162 L
.86617 .89899 L
.86429 .90909 L
.85951 .91919 L
.85859 .92148 L
.8559 .92929 L
.85387 .93939 L
.84912 .94949 L
.84848 .95107 L
.84553 .9596 L
.8433 .9697 L
.83862 .9798 L
.83838 .98039 L
.83506 .9899 L
.8326 1 L
1 1 L
F
0 g
1 .48017 m
.99862 .48485 L
.99557 .49495 L
.99245 .50505 L
.9899 .51328 L
.98931 .51515 L
.98619 .52525 L
.98414 .53535 L
.98005 .54545 L
.9798 .54615 L
.97686 .55556 L
.97521 .56566 L
.97083 .57576 L
.9697 .57881 L
.96748 .58586 L
.96626 .59596 L
.96156 .60606 L
.9596 .61123 L
.95802 .61616 L
.95484 .62626 L
.95225 .63636 L
.94949 .64339 L
.9485 .64646 L
.94529 .65657 L
.94288 .66667 L
.93939 .67529 L
.93891 .67677 L
.93567 .68687 L
.93343 .69697 L
.92929 .70694 L
.92925 .70707 L
.92598 .71717 L
.9239 .72727 L
.91956 .73737 L
.91919 .73836 L
.91621 .74747 L
.91428 .75758 L
.9098 .76768 L
.90909 .76953 L
.90637 .77778 L
.90455 .78788 L
.89995 .79798 L
.89899 .80044 L
.89645 .80808 L
.89469 .81818 L
.89 .82828 L
.88889 .83109 L
.88644 .83838 L
.8847 .84848 L
.87994 .85859 L
Mistroke
.87879 .86149 L
.87635 .86869 L
.87457 .87879 L
.86978 .88889 L
.86869 .89162 L
.86617 .89899 L
.86429 .90909 L
.85951 .91919 L
.85859 .92148 L
.8559 .92929 L
.85387 .93939 L
.84912 .94949 L
.84848 .95107 L
.84553 .9596 L
.8433 .9697 L
.83862 .9798 L
.83838 .98039 L
.83506 .9899 L
.8326 1 L
Mfstroke
.6 g
1 .50549 m
.99712 .51515 L
.99405 .52525 L
.99044 .53535 L
.9899 .53876 L
.98819 .54545 L
.98504 .55556 L
.98176 .56566 L
.9798 .5718 L
.97884 .57576 L
.97578 .58586 L
.97249 .59596 L
.9697 .6046 L
.96936 .60606 L
.96644 .61616 L
.96315 .62626 L
.95985 .63636 L
.9596 .63715 L
.95702 .64646 L
.95374 .65657 L
.95041 .66667 L
.94949 .66948 L
.94752 .67677 L
.94426 .68687 L
.9409 .69697 L
.93939 .70156 L
.93793 .70707 L
.9347 .71717 L
.93132 .72727 L
.92929 .73339 L
.92826 .73737 L
.92507 .74747 L
.92167 .75758 L
.91919 .76498 L
.9185 .76768 L
.91535 .77778 L
.91194 .78788 L
.90909 .79633 L
.90867 .79798 L
.90556 .80808 L
.90213 .81818 L
.89899 .82742 L
.89877 .82828 L
.89569 .83838 L
.89224 .84848 L
.88889 .85826 L
.88881 .85859 L
.88573 .86869 L
.88226 .87879 L
.87879 .88885 L
.87878 .88889 L
.87569 .89899 L
.8722 .90909 L
.86869 .91918 L
.86868 .91919 L
.86557 .92929 L
.86205 .93939 L
.85859 .94925 L
.85852 .94949 L
.85535 .9596 L
.8518 .9697 L
.84848 .97907 L
.84829 .9798 L
.84505 .9899 L
.84146 1 L
1 1 L
F
0 g
1 .50549 m
.99712 .51515 L
.99405 .52525 L
.99044 .53535 L
.9899 .53876 L
.98819 .54545 L
.98504 .55556 L
.98176 .56566 L
.9798 .5718 L
.97884 .57576 L
.97578 .58586 L
.97249 .59596 L
.9697 .6046 L
.96936 .60606 L
.96644 .61616 L
.96315 .62626 L
.95985 .63636 L
.9596 .63715 L
.95702 .64646 L
.95374 .65657 L
.95041 .66667 L
.94949 .66948 L
.94752 .67677 L
.94426 .68687 L
.9409 .69697 L
.93939 .70156 L
.93793 .70707 L
.9347 .71717 L
.93132 .72727 L
.92929 .73339 L
.92826 .73737 L
.92507 .74747 L
.92167 .75758 L
.91919 .76498 L
.9185 .76768 L
.91535 .77778 L
.91194 .78788 L
.90909 .79633 L
.90867 .79798 L
.90556 .80808 L
.90213 .81818 L
.89899 .82742 L
.89877 .82828 L
.89569 .83838 L
.89224 .84848 L
.88889 .85826 L
.88881 .85859 L
.88573 .86869 L
.88226 .87879 L
.87879 .88885 L
Mistroke
.87878 .88889 L
.87569 .89899 L
.8722 .90909 L
.86869 .91918 L
.86868 .91919 L
.86557 .92929 L
.86205 .93939 L
.85859 .94925 L
.85852 .94949 L
.85535 .9596 L
.8518 .9697 L
.84848 .97907 L
.84829 .9798 L
.84505 .9899 L
.84146 1 L
Mfstroke
.5 g
1 .52653 m
.99519 .53535 L
.99349 .54545 L
.99109 .55556 L
.9899 .55988 L
.98821 .56566 L
.98513 .57576 L
.98199 .58586 L
.9798 .593 L
.97894 .59596 L
.97586 .60606 L
.97271 .61616 L
.9697 .62588 L
.96959 .62626 L
.96654 .63636 L
.96337 .64646 L
.96021 .65657 L
.9596 .65853 L
.95714 .66667 L
.95396 .67677 L
.95077 .68687 L
.94949 .69094 L
.94767 .69697 L
.94449 .70707 L
.94127 .71717 L
.93939 .72311 L
.93813 .72727 L
.93495 .73737 L
.93171 .74747 L
.92929 .75503 L
.92852 .75758 L
.92533 .76768 L
.92207 .77778 L
.91919 .78672 L
.91884 .78788 L
.91565 .79798 L
.91236 .80808 L
.90909 .81816 L
.90908 .81818 L
.90588 .82828 L
.90258 .83838 L
.89927 .84848 L
.89899 .84935 L
.89604 .85859 L
.89272 .86869 L
.88938 .87879 L
.88889 .88029 L
.88613 .88889 L
.88278 .89899 L
.87941 .90909 L
.87879 .91098 L
.87613 .91919 L
.87275 .92929 L
.86936 .93939 L
.86869 .94142 L
.86605 .94949 L
.86265 .9596 L
.85923 .9697 L
.85859 .9716 L
.85588 .9798 L
.85245 .9899 L
.849 1 L
1 1 L
F
0 g
1 .52653 m
.99519 .53535 L
.99349 .54545 L
.99109 .55556 L
.9899 .55988 L
.98821 .56566 L
.98513 .57576 L
.98199 .58586 L
.9798 .593 L
.97894 .59596 L
.97586 .60606 L
.97271 .61616 L
.9697 .62588 L
.96959 .62626 L
.96654 .63636 L
.96337 .64646 L
.96021 .65657 L
.9596 .65853 L
.95714 .66667 L
.95396 .67677 L
.95077 .68687 L
.94949 .69094 L
.94767 .69697 L
.94449 .70707 L
.94127 .71717 L
.93939 .72311 L
.93813 .72727 L
.93495 .73737 L
.93171 .74747 L
.92929 .75503 L
.92852 .75758 L
.92533 .76768 L
.92207 .77778 L
.91919 .78672 L
.91884 .78788 L
.91565 .79798 L
.91236 .80808 L
.90909 .81816 L
.90908 .81818 L
.90588 .82828 L
.90258 .83838 L
.89927 .84848 L
.89899 .84935 L
.89604 .85859 L
.89272 .86869 L
.88938 .87879 L
.88889 .88029 L
.88613 .88889 L
.88278 .89899 L
.87941 .90909 L
Mistroke
.87879 .91098 L
.87613 .91919 L
.87275 .92929 L
.86936 .93939 L
.86869 .94142 L
.86605 .94949 L
.86265 .9596 L
.85923 .9697 L
.85859 .9716 L
.85588 .9798 L
.85245 .9899 L
.849 1 L
Mfstroke
.4 g
1 .54657 m
.99694 .55556 L
.99409 .56566 L
.99116 .57576 L
.9899 .57999 L
.98812 .58586 L
.98501 .59596 L
.98191 .60606 L
.9798 .61318 L
.97889 .61616 L
.97577 .62626 L
.97264 .63636 L
.9697 .64614 L
.9696 .64646 L
.96647 .65657 L
.96331 .66667 L
.96022 .67677 L
.9596 .67886 L
.9571 .68687 L
.95392 .69697 L
.95078 .70707 L
.94949 .71134 L
.94767 .71717 L
.94447 .72727 L
.94129 .73737 L
.93939 .74359 L
.93817 .74747 L
.93496 .75758 L
.93174 .76768 L
.92929 .77559 L
.9286 .77778 L
.92537 .78788 L
.92213 .79798 L
.91919 .80736 L
.91896 .80808 L
.91571 .81818 L
.91244 .82828 L
.90924 .83838 L
.90909 .83888 L
.90598 .84848 L
.90269 .85859 L
.89945 .86869 L
.89899 .87015 L
.89618 .87879 L
.89285 .88889 L
.88958 .89899 L
.88889 .90118 L
.88629 .90909 L
.88294 .91919 L
.87964 .92929 L
.87879 .93195 L
.87633 .93939 L
.87295 .94949 L
.86962 .9596 L
.86869 .96248 L
.86628 .9697 L
.86288 .9798 L
.85951 .9899 L
.85859 .99275 L
.85615 1 L
1 1 L
F
0 g
1 .54657 m
.99694 .55556 L
.99409 .56566 L
.99116 .57576 L
.9899 .57999 L
.98812 .58586 L
.98501 .59596 L
.98191 .60606 L
.9798 .61318 L
.97889 .61616 L
.97577 .62626 L
.97264 .63636 L
.9697 .64614 L
.9696 .64646 L
.96647 .65657 L
.96331 .66667 L
.96022 .67677 L
.9596 .67886 L
.9571 .68687 L
.95392 .69697 L
.95078 .70707 L
.94949 .71134 L
.94767 .71717 L
.94447 .72727 L
.94129 .73737 L
.93939 .74359 L
.93817 .74747 L
.93496 .75758 L
.93174 .76768 L
.92929 .77559 L
.9286 .77778 L
.92537 .78788 L
.92213 .79798 L
.91919 .80736 L
.91896 .80808 L
.91571 .81818 L
.91244 .82828 L
.90924 .83838 L
.90909 .83888 L
.90598 .84848 L
.90269 .85859 L
.89945 .86869 L
.89899 .87015 L
.89618 .87879 L
.89285 .88889 L
.88958 .89899 L
.88889 .90118 L
.88629 .90909 L
.88294 .91919 L
.87964 .92929 L
Mistroke
.87879 .93195 L
.87633 .93939 L
.87295 .94949 L
.86962 .9596 L
.86869 .96248 L
.86628 .9697 L
.86288 .9798 L
.85951 .9899 L
.85859 .99275 L
.85615 1 L
Mfstroke
.3 g
1 .56761 m
.99752 .57576 L
.99454 .58586 L
.99149 .59596 L
.9899 .60111 L
.98835 .60606 L
.98512 .61616 L
.98196 .62626 L
.9798 .63439 L
.97918 .63636 L
.97595 .64646 L
.97272 .65657 L
.96987 .66667 L
.9697 .66743 L
.96671 .67677 L
.96345 .68687 L
.96041 .69697 L
.9596 .70023 L
.9574 .70707 L
.95412 .71717 L
.95096 .72727 L
.94949 .7328 L
.94802 .73737 L
.94472 .74747 L
.94148 .75758 L
.93939 .76514 L
.93857 .76768 L
.93526 .77778 L
.93197 .78788 L
.92929 .79724 L
.92905 .79798 L
.92573 .80808 L
.92239 .81818 L
.91939 .82828 L
.91919 .8291 L
.91612 .83838 L
.91276 .84848 L
.90964 .85859 L
.90909 .86071 L
.90644 .86869 L
.90305 .87879 L
.89985 .88889 L
.89899 .89208 L
.89668 .89899 L
.89326 .90909 L
.89 .91919 L
.88889 .9232 L
.88684 .92929 L
.8834 .93939 L
.88009 .94949 L
.87879 .95408 L
.87692 .9596 L
.87345 .9697 L
.87011 .9798 L
.86869 .98471 L
.86691 .9899 L
.86342 1 L
1 1 L
F
0 g
1 .56761 m
.99752 .57576 L
.99454 .58586 L
.99149 .59596 L
.9899 .60111 L
.98835 .60606 L
.98512 .61616 L
.98196 .62626 L
.9798 .63439 L
.97918 .63636 L
.97595 .64646 L
.97272 .65657 L
.96987 .66667 L
.9697 .66743 L
.96671 .67677 L
.96345 .68687 L
.96041 .69697 L
.9596 .70023 L
.9574 .70707 L
.95412 .71717 L
.95096 .72727 L
.94949 .7328 L
.94802 .73737 L
.94472 .74747 L
.94148 .75758 L
.93939 .76514 L
.93857 .76768 L
.93526 .77778 L
.93197 .78788 L
.92929 .79724 L
.92905 .79798 L
.92573 .80808 L
.92239 .81818 L
.91939 .82828 L
.91919 .8291 L
.91612 .83838 L
.91276 .84848 L
.90964 .85859 L
.90909 .86071 L
.90644 .86869 L
.90305 .87879 L
.89985 .88889 L
.89899 .89208 L
.89668 .89899 L
.89326 .90909 L
.89 .91919 L
.88889 .9232 L
.88684 .92929 L
.8834 .93939 L
.88009 .94949 L
Mistroke
.87879 .95408 L
.87692 .9596 L
.87345 .9697 L
.87011 .9798 L
.86869 .98471 L
.86691 .9899 L
.86342 1 L
Mfstroke
.2 g
1 .59295 m
.99916 .59596 L
.99631 .60606 L
.99331 .61616 L
.99002 .62626 L
.9899 .62661 L
.98619 .63636 L
.98394 .64646 L
.98086 .65657 L
.9798 .66001 L
.97734 .66667 L
.97276 .67677 L
.97166 .68687 L
.9697 .6932 L
.96834 .69697 L
.96408 .70707 L
.96239 .71717 L
.9596 .72619 L
.95921 .72727 L
.95518 .73737 L
.95306 .74747 L
.94992 .75758 L
.94949 .75891 L
.94611 .76768 L
.94367 .77778 L
.94051 .78788 L
.93939 .7914 L
.9369 .79798 L
.93219 .80808 L
.93104 .81818 L
.92929 .82366 L
.92757 .82828 L
.92308 .83838 L
.9215 .84848 L
.91919 .8557 L
.91812 .85859 L
.9138 .86869 L
.9119 .87879 L
.90909 .88751 L
.90858 .88889 L
.90437 .89899 L
.90222 .90909 L
.89899 .91908 L
.89895 .91919 L
.89482 .92929 L
.89247 .93939 L
.88918 .94949 L
.88889 .95038 L
.88515 .9596 L
.88265 .9697 L
.87934 .9798 L
.87879 .98145 L
.87536 .9899 L
.87275 1 L
1 1 L
F
0 g
1 .59295 m
.99916 .59596 L
.99631 .60606 L
.99331 .61616 L
.99002 .62626 L
.9899 .62661 L
.98619 .63636 L
.98394 .64646 L
.98086 .65657 L
.9798 .66001 L
.97734 .66667 L
.97276 .67677 L
.97166 .68687 L
.9697 .6932 L
.96834 .69697 L
.96408 .70707 L
.96239 .71717 L
.9596 .72619 L
.95921 .72727 L
.95518 .73737 L
.95306 .74747 L
.94992 .75758 L
.94949 .75891 L
.94611 .76768 L
.94367 .77778 L
.94051 .78788 L
.93939 .7914 L
.9369 .79798 L
.93219 .80808 L
.93104 .81818 L
.92929 .82366 L
.92757 .82828 L
.92308 .83838 L
.9215 .84848 L
.91919 .8557 L
.91812 .85859 L
.9138 .86869 L
.9119 .87879 L
.90909 .88751 L
.90858 .88889 L
.90437 .89899 L
.90222 .90909 L
.89899 .91908 L
.89895 .91919 L
.89482 .92929 L
.89247 .93939 L
.88918 .94949 L
.88889 .95038 L
.88515 .9596 L
.88265 .9697 L
Mistroke
.87934 .9798 L
.87879 .98145 L
.87536 .9899 L
.87275 1 L
Mfstroke
.3 g
1 .6896 m
.99782 .69697 L
.99474 .70707 L
.99162 .71717 L
.9899 .72273 L
.98848 .72727 L
.98537 .73737 L
.98296 .74747 L
.9798 .75561 L
.97918 .75758 L
.97603 .76768 L
.97392 .77778 L
.96983 .78788 L
.9697 .78823 L
.96664 .79798 L
.96486 .80808 L
.96051 .81818 L
.9596 .82065 L
.95717 .82828 L
.95577 .83838 L
.95115 .84848 L
.94949 .85282 L
.94765 .85859 L
.94663 .86869 L
.94172 .87879 L
.93939 .88474 L
.93805 .88889 L
.93481 .89899 L
.93222 .90909 L
.92929 .9164 L
.92838 .91919 L
.92512 .92929 L
.92264 .93939 L
.91919 .94781 L
.91863 .94949 L
.91534 .9596 L
.91297 .9697 L
.90909 .97897 L
.90881 .9798 L
.90549 .9899 L
.90319 1 L
1 1 L
F
0 g
1 .6896 m
.99782 .69697 L
.99474 .70707 L
.99162 .71717 L
.9899 .72273 L
.98848 .72727 L
.98537 .73737 L
.98296 .74747 L
.9798 .75561 L
.97918 .75758 L
.97603 .76768 L
.97392 .77778 L
.96983 .78788 L
.9697 .78823 L
.96664 .79798 L
.96486 .80808 L
.96051 .81818 L
.9596 .82065 L
.95717 .82828 L
.95577 .83838 L
.95115 .84848 L
.94949 .85282 L
.94765 .85859 L
.94663 .86869 L
.94172 .87879 L
.93939 .88474 L
.93805 .88889 L
.93481 .89899 L
.93222 .90909 L
.92929 .9164 L
.92838 .91919 L
.92512 .92929 L
.92264 .93939 L
.91919 .94781 L
.91863 .94949 L
.91534 .9596 L
.91297 .9697 L
.90909 .97897 L
.90881 .9798 L
.90549 .9899 L
.90319 1 L
s
.4 g
1 .71493 m
.99934 .71717 L
.99631 .72727 L
.99322 .73737 L
.99004 .74747 L
.9899 .7482 L
.98739 .75758 L
.98417 .76768 L
.9809 .77778 L
.9798 .78124 L
.97808 .78788 L
.97491 .79798 L
.97161 .80808 L
.9697 .81404 L
.96867 .81818 L
.96558 .82828 L
.96227 .83838 L
.9596 .8466 L
.95915 .84848 L
.95617 .85859 L
.95285 .86869 L
.94954 .87879 L
.94949 .87891 L
.94668 .88889 L
.94336 .89899 L
.94002 .90909 L
.93939 .91099 L
.93711 .91919 L
.9338 .92929 L
.93043 .93939 L
.92929 .94283 L
.92746 .94949 L
.92417 .9596 L
.92077 .9697 L
.91919 .97442 L
.91773 .9798 L
.91445 .9899 L
.91103 1 L
1 1 L
F
0 g
1 .71493 m
.99934 .71717 L
.99631 .72727 L
.99322 .73737 L
.99004 .74747 L
.9899 .7482 L
.98739 .75758 L
.98417 .76768 L
.9809 .77778 L
.9798 .78124 L
.97808 .78788 L
.97491 .79798 L
.97161 .80808 L
.9697 .81404 L
.96867 .81818 L
.96558 .82828 L
.96227 .83838 L
.9596 .8466 L
.95915 .84848 L
.95617 .85859 L
.95285 .86869 L
.94954 .87879 L
.94949 .87891 L
.94668 .88889 L
.94336 .89899 L
.94002 .90909 L
.93939 .91099 L
.93711 .91919 L
.9338 .92929 L
.93043 .93939 L
.92929 .94283 L
.92746 .94949 L
.92417 .9596 L
.92077 .9697 L
.91919 .97442 L
.91773 .9798 L
.91445 .9899 L
.91103 1 L
s
.5 g
1 .73597 m
.99959 .73737 L
.99477 .74747 L
.99292 .75758 L
.99036 .76768 L
.9899 .76932 L
.9874 .77778 L
.98429 .78788 L
.98117 .79798 L
.9798 .80244 L
.97814 .80808 L
.97503 .81818 L
.97188 .82828 L
.9697 .83532 L
.9688 .83838 L
.9657 .84848 L
.96253 .85859 L
.9596 .86797 L
.95939 .86869 L
.9563 .87879 L
.95312 .88889 L
.94993 .89899 L
.94949 .90038 L
.94684 .90909 L
.94364 .91919 L
.94042 .92929 L
.93939 .93255 L
.9373 .93939 L
.93409 .94949 L
.93085 .9596 L
.92929 .96447 L
.92769 .9697 L
.92447 .9798 L
.9212 .9899 L
.91919 .99615 L
.91801 1 L
1 1 L
F
0 g
1 .73597 m
.99959 .73737 L
.99477 .74747 L
.99292 .75758 L
.99036 .76768 L
.9899 .76932 L
.9874 .77778 L
.98429 .78788 L
.98117 .79798 L
.9798 .80244 L
.97814 .80808 L
.97503 .81818 L
.97188 .82828 L
.9697 .83532 L
.9688 .83838 L
.9657 .84848 L
.96253 .85859 L
.9596 .86797 L
.95939 .86869 L
.9563 .87879 L
.95312 .88889 L
.94993 .89899 L
.94949 .90038 L
.94684 .90909 L
.94364 .91919 L
.94042 .92929 L
.93939 .93255 L
.9373 .93939 L
.93409 .94949 L
.93085 .9596 L
.92929 .96447 L
.92769 .9697 L
.92447 .9798 L
.9212 .9899 L
.91919 .99615 L
.91801 1 L
s
.6 g
1 .75601 m
.99936 .75758 L
.99618 .76768 L
.99333 .77778 L
.99037 .78788 L
.9899 .78943 L
.9873 .79798 L
.98418 .80808 L
.9811 .81818 L
.9798 .82262 L
.97807 .82828 L
.97494 .83838 L
.97182 .84848 L
.9697 .85558 L
.96877 .85859 L
.96563 .86869 L
.96248 .87879 L
.9596 .8883 L
.95941 .88889 L
.95626 .89899 L
.95308 .90909 L
.94997 .91919 L
.94949 .92078 L
.94683 .92929 L
.94362 .93939 L
.94046 .94949 L
.93939 .95303 L
.93732 .9596 L
.9341 .9697 L
.9309 .9798 L
.92929 .98503 L
.92775 .9899 L
.92451 1 L
1 1 L
F
0 g
1 .75601 m
.99936 .75758 L
.99618 .76768 L
.99333 .77778 L
.99037 .78788 L
.9899 .78943 L
.9873 .79798 L
.98418 .80808 L
.9811 .81818 L
.9798 .82262 L
.97807 .82828 L
.97494 .83838 L
.97182 .84848 L
.9697 .85558 L
.96877 .85859 L
.96563 .86869 L
.96248 .87879 L
.9596 .8883 L
.95941 .88889 L
.95626 .89899 L
.95308 .90909 L
.94997 .91919 L
.94949 .92078 L
.94683 .92929 L
.94362 .93939 L
.94046 .94949 L
.93939 .95303 L
.93732 .9596 L
.9341 .9697 L
.9309 .9798 L
.92929 .98503 L
.92775 .9899 L
.92451 1 L
s
.7 g
1 .77705 m
.99977 .77778 L
.99673 .78788 L
.99374 .79798 L
.99067 .80808 L
.9899 .81055 L
.9875 .81818 L
.98427 .82828 L
.98118 .83838 L
.9798 .84382 L
.97833 .84848 L
.97509 .85859 L
.9719 .86869 L
.9697 .87687 L
.96909 .87879 L
.96584 .88889 L
.9626 .89899 L
.95973 .90909 L
.9596 .90967 L
.95653 .91919 L
.95325 .92929 L
.95021 .93939 L
.94949 .94224 L
.94715 .94949 L
.94384 .9596 L
.94068 .9697 L
.93939 .97458 L
.9377 .9798 L
.93437 .9899 L
.93114 1 L
1 1 L
F
0 g
1 .77705 m
.99977 .77778 L
.99673 .78788 L
.99374 .79798 L
.99067 .80808 L
.9899 .81055 L
.9875 .81818 L
.98427 .82828 L
.98118 .83838 L
.9798 .84382 L
.97833 .84848 L
.97509 .85859 L
.9719 .86869 L
.9697 .87687 L
.96909 .87879 L
.96584 .88889 L
.9626 .89899 L
.95973 .90909 L
.9596 .90967 L
.95653 .91919 L
.95325 .92929 L
.95021 .93939 L
.94949 .94224 L
.94715 .94949 L
.94384 .9596 L
.94068 .9697 L
.93939 .97458 L
.9377 .9798 L
.93437 .9899 L
.93114 1 L
s
.8 g
1 .80238 m
.99841 .80808 L
.99553 .81818 L
.99247 .82828 L
.9899 .83604 L
.98907 .83838 L
.98502 .84848 L
.98312 .85859 L
.98004 .86869 L
.9798 .86946 L
.97625 .87879 L
.97393 .88889 L
.97083 .89899 L
.9697 .90264 L
.96731 .90909 L
.96272 .91919 L
.96156 .92929 L
.9596 .93561 L
.95822 .93939 L
.95393 .94949 L
.95223 .9596 L
.94949 .96836 L
.94901 .9697 L
.94494 .9798 L
.94284 .9899 L
.93967 1 L
1 1 L
F
0 g
1 .80238 m
.99841 .80808 L
.99553 .81818 L
.99247 .82828 L
.9899 .83604 L
.98907 .83838 L
.98502 .84848 L
.98312 .85859 L
.98004 .86869 L
.9798 .86946 L
.97625 .87879 L
.97393 .88889 L
.97083 .89899 L
.9697 .90264 L
.96731 .90909 L
.96272 .91919 L
.96156 .92929 L
.9596 .93561 L
.95822 .93939 L
.95393 .94949 L
.95223 .9596 L
.94949 .96836 L
.94901 .9697 L
.94494 .9798 L
.94284 .9899 L
.93967 1 L
s
.7 g
1 .89902 m
.99701 .90909 L
.99392 .91919 L
.99078 .92929 L
.9899 .93216 L
.98765 .93939 L
.98651 .94949 L
.98185 .9596 L
.9798 .96506 L
.97834 .9697 L
.9752 .9798 L
.97274 .9899 L
.9697 .99752 L
.96896 1 L
1 1 L
F
0 g
1 .89902 m
.99701 .90909 L
.99392 .91919 L
.99078 .92929 L
.9899 .93216 L
.98765 .93939 L
.98651 .94949 L
.98185 .9596 L
.9798 .96506 L
.97834 .9697 L
.9752 .9798 L
.97274 .9899 L
.9697 .99752 L
.96896 1 L
s
.6 g
1 .92437 m
.99854 .92929 L
.99549 .93939 L
.99033 .94949 L
.9899 .95764 L
.98946 .9596 L
.98655 .9697 L
.9833 .9798 L
.98004 .9899 L
.9798 .99067 L
.97727 1 L
1 1 L
F
0 g
1 .92437 m
.99854 .92929 L
.99549 .93939 L
.99033 .94949 L
.9899 .95764 L
.98946 .9596 L
.98655 .9697 L
.9833 .9798 L
.98004 .9899 L
.9798 .99067 L
.97727 1 L
s
.5 g
1 .94541 m
.99644 .94949 L
.99435 .9596 L
.9923 .9697 L
.9899 .97876 L
.9896 .9798 L
.98659 .9899 L
.98346 1 L
1 1 L
F
0 g
1 .94541 m
.99644 .94949 L
.99435 .9596 L
.9923 .9697 L
.9899 .97876 L
.9896 .9798 L
.98659 .9899 L
.98346 1 L
s
.4 g
1 .96545 m
.9984 .9697 L
.99542 .9798 L
.99255 .9899 L
.9899 .99887 L
.98956 1 L
1 1 L
F
0 g
1 .96545 m
.9984 .9697 L
.99542 .9798 L
.99255 .9899 L
.9899 .99887 L
.98956 1 L
s
.3 g
1 .98649 m
.99894 .9899 L
.99594 1 L
1 1 L
F
0 g
1 .98649 m
.99894 .9899 L
.99594 1 L
s
1 0 0 r
0 0 m
.08466 .08466 L
.177 .177 L
.26371 .26371 L
.34708 .34644 L
.43169 .40977 L
.50551 .45237 L
.57752 .48791 L
.64211 .51641 L
.70078 .54024 L
.76016 .56276 L
.81486 .58234 L
.86551 .59961 L
.91762 .61664 L
.96622 .63191 L
s
.96622 .63191 m
1 .64216 L
s
.13333 .26667 m
.218 .35133 L
.31033 .44366 L
.39571 .51884 L
.47103 .56678 L
.54419 .60537 L
.60941 .63566 L
.67443 .66309 L
.73372 .68625 L
.78821 .70626 L
.84385 .72565 L
.89549 .74283 L
.94357 .75819 L
.99327 .77352 L
s
.99327 .77352 m
1 .77552 L
s
.26667 .53333 m
.35128 .61688 L
.43871 .68086 L
.51296 .72294 L
.57876 .75515 L
.64418 .78395 L
.70361 .80801 L
.76367 .83072 L
.81902 .85046 L
.87029 .86787 L
.92298 .88502 L
.97213 .9004 L
s
.97213 .9004 m
1 .90883 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 288},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00__ooool2o`0000;ooooo0_l0
002Tooooo`00__ooool01_o^k^ko8B4QohN7Qonj^[[o0000omgMgJCooooo002oooooo`04omgMgOl0
003o410@olc<c:Gooooo002oooooo`04onk^k_lQ8B7o410@onk^kZGooooo002oooooo`04ob4Q8Omg
MgOoMgMgoc8b<ZGooooo002nooooo`;o00000_ooool2o`000:Cooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo000kooooo`;o000000?o410@ooooooooool09?ooool5o`00027ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0Uooooo`Go00009oooool2o`000003oa0@4?oooooooooo02?ooooo00Gok^k^oc8b
<_l0003o410@olc<c00Uooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`08_ooool4o`000008oa0@4?oo
ooooooooonk^k_lb<S;o0000oc8b<_o^k^h3ooooo`00??ooool00ol0003oooooooooo`0Uooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@08Oooool01OmgMgOoV9RHoooooonHV9SoMgMg02Gooooo00GoV9RH
ob4Q8Oo^k^koooooodA4A00Xooooo`03o`000?oooooooooo02Cooooo00GoEEEEogMgMoooooooV9RH
ob4Q8@0Uooooo`05ob4Q8OnHV9SooooooiRHV?lQ8B409?ooool00ol0003oooooooooo`02ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL00oooool0037ooooo1_l00002ooooo`Go00007_ooool6o`0000?o
oooo00?oV9RHob4Q8Oo^k^h08_ooool01Ol@413ooooooooooooooooo410@02Kooooo00?oV9RHob4Q
8Oo^k^h09_ooool5o`0002Gooooo00Go0000ooooooooooooooooo`00000Uooooo`05o`000?oooooo
ooooooooool000009?ooool00ol0003oooooooooo`02ooooo`05oa0@4?ooooooooooooooool@4100
0oooool003Wooooo00CoA4A4omgMgOoooooo0000:Oooool00onHV9So8B4Qonk^kP0Qooooo`05o`00
0?ooooooooooooooool000009oooool00onHV9So8B4Qonk^kP0Uooooo`04odA4A?oMgMgoooooo`00
02Kooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Uooooo`05oc8b<_nHV9SooooooiRHV?lb<S809?oo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool003Wooooo00Co
gMgMoeEEEOoooooo0000:_ooool00omgMgOoIVIVooooo`0Pooooo`05o`000?ooooooooooooooool0
0000:?ooool00omgMgOoIVIVooooo`0Tooooo`04omgMgOmEEEGoooooo`0002Kooooo00Go0000oeEE
EOl0003o410@olc<c00Uooooo`05olc<c?l0003o0000o`000?o<c<`09?ooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000000oooool003[ooooo00?oMgMgolc<c?l00000:ooo
ool00ol0003oooooooooo`0Oooooo`05oa0@4?ooooooooooooooool@4100:Oooool00ol0003ooooo
ooooo`0Tooooo`03ogMgMoo<c<co000002Kooooo00?oEEEEohN7Qoooool09oooool01Ol@413o^[Zj
oooooonj^[[o410@02Cooooo00?o0000ooooooooool00_ooool01Ol@413ooooooooooooooooo410@
00?ooooo000jooooo`03onk^k_m4A4Co000002Oooooo00Go0000okZj^_ooooooV9RHoa0@400Qoooo
o`05ogMgMonHV9SooooooiRHV?mgMgL09Oooool01Ol0003o^[ZjoooooonHV9So410@02Kooooo00?o
k^k^odA4A?l000009_ooool00ooMgMgo410@oiRHV00Wooooo`05o`000?nj^[[ooooookZj^_l00000
9?ooool00ol0003oooooooooo`02ooooo`05ogMgMonHV9SooooooiRHV?mgMgL00oooool003_ooooo
00?oMgMgo`000?ooool09_ooool01OnHV9So410@o`000?lQ8B7oc<c<027ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0Uooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`09oooool00omgMgOo0000ooooo`0V
ooooo`04olc<c?m4A4Co0000oa0@42Gooooo00GoZJVYoa0@4?l0003o410@ojVYZ@0Rooooo`03oeEE
EOmVIVKo000000Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03ooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`008oooool00ooo003o0000o`00003oo`0003_o
00002?ooool002?ooooo00?oC4a<ool00?m<C4`05_m<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`00
0?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`00
0?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl01_moOgl00ol0003oIVIVofIVIP06ofIVIP03o`00
0?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH00omVIVH01Ol0003oOgmoogmoOomoOgoo000000Co
VIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o
/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`05o`000?mVIVKoIVIVofIVI_l000001?m<C4`0
0ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmo
Ool00002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01ol0003o/k>cok>c/onc/k?o0000
oiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Ko
0000oda<C?m<C4co0000ofIVI_l00002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<
c<`01_o<c<`02?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo00000_mVIVH00ol0003oC4a<o`00
0009oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00Co0000olc<
c?o<c<co00002?ooool002?ooooo0_m<C4`00ooo003oC4a<oda<C00Coda<C003o`000?mVIVKoIVIV
00coIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c
01Oo/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`07ogmoO`03o`000?mVIVKoIVIV
00GoIVIV00?o0000oda<C?m<C4`05Om<C4`00ol0003oIVIVofIVIP02ofIVIP03o`000?moOgooOgmo
00;oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<
00?oc<c<00?o0000ok>c/onc/k<01?nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`03o`000?mVIVKo
IVIV00;oIVIV00?o0000oda<C?m<C4`00_m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4co
C4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`00
0?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT01?l0003oOgmoogmoOol00002ofIV
IP04o`000?m<C4coC4a<o`0000Wo<c<c00So0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000;o
VIVI00?o0000ok>c/ol000002Oo<c<`02?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo00000_mV
IVH00ol0003oC4a<o`000009oc<c<`;o00000_mVIVH01ol0003oOgmoo`000?nIVIWo0000ok>c/ol0
00000oo<c<`00ol0003oooooooooo`06ooooo`008oooool3oda<C003ool00?m<C4coC4a<017oC4a<
00?o0000ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmoO`07ogmoO`;o00003_nIVIT00ol0003o/k>c
ok>c/`0Fok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl01omoOgl00ol0003oIVIV
ofIVIP06ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmo
ogmoO`02ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001_nc/k<00ol0003oc<c<olc<c004olc<c003
o`000?nc/k?o/k>c00?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`05o`000?mVIVKoIVIV
ofIVI_l000001?m<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mV
IVH01?l0003oOgmoogmoOol00002oiVIV@03o`000?nc/k?o/k>c00;o/k>c00?o0000olc<c?o<c<`0
1Oo<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003o
C4a<oda<C?l00009oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl00ol0003oVIVIo`00
0002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Oo0000ok>c/ol0003oVIVIo`000?moOgoo000000;o
IVIV00?o0000oda<C?l000002Olc<c<01ol0003oC4a<o`000?mVIVKo0000ogmoOol000000_nIVIT0
0ol0003o/k>co`000003olc<c003o`000?oooooooooo00Kooooo000Sooooo`CoC4a<00?oo`00oda<
C?m<C4`03om<C4`00ol0003oIVIVofIVIP0;ofIVIP;o00002_moOgl00ol0003oVIVIoiVIV@0;oiVI
V@;o00006?nc/k<00ol0003oVIVIoiVIV@0;oiVIV@;o00002OmoOgl00ol0003oIVIVofIVIP06ofIV
IP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`02ogmo
O`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c003olc<
c003o`000?nc/k?o/k>c00Co/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`05o`000?mVIVKo
IVIVofIVI_l000001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co
0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Ko
c<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<
C?m<C4co00002Olc<c<02?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo00000_nIVIT00ol0003o
/k>co`00000:olc<c007o`000?nc/k?o0000oiVIVOl0003oOgmoo`000002ofIVIP03o`000?m<C4co
000000Wo<c<c00_o0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`000004olc<
c003o`000?oooooooooo00Kooooo000Sooooo`GoC4a<00?oo`00oda<C?m<C4`03Om<C4`00ol0003o
IVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o
/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003o
IVIVofIVIP07ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH00_mVIVH00ol0003o
OgmoogmoO`03ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001onc/k<00ol0003oc<c<olc<c003olc<
c003o`000?nc/k?o/k>c00Co/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`05o`000?mVIVKo
IVIVofIVI_l000001?m<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Co
0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Ko
c<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<
C?m<C4co00002Olc<c<02?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo00000_nIVIT00ol0003o
/k>co`00000:olc<c007o`000?nc/k?o0000oiVIVOl0003oOgmoo`000002ofIVIP03o`000?m<C4co
000000So<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00004
olc<c003o`000?oooooooooo00Kooooo000Sooooo`KoC4a<00?oo`00oda<C?m<C4`02om<C4`00ol0
003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0
003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0
003oIVIVofIVIP06ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0
003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0
003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c00Co/k>c00Go0000oiVIVOnIVIWoVIVIo`000002
ogmoO`05o`000?mVIVKoIVIVofIVI_l000001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<
C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03
o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@03o`000?moOgoo0000
00;oIVIV00Co0000oda<C?m<C4co00002Olc<c<01?l0003oC4a<oda<C?l00002ofIVIP;o00000_nI
VIT01?l0003o/k>cok>c/ol00009olc<c007o`000?nc/k?o0000oiVIVOl0003oOgmoo`000002ofIV
IP03o`000?m<C4co000000Wo<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00000
0_nc/k<00ol0003oc<c<olc<c002olc<c003o`000?oooooooooo00Kooooo000Sooooo`OoC4a<00?o
o`00oda<C?m<C4`02Om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o
0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o
0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP06ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o
0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o
0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c00Co/k>c00Go
0000oiVIVOnIVIWoVIVIo`000003ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc
<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000?oIVIV00Co0000ogmoOomoOgoo00000_nIVIT0
1Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo000000;o
Ogmo00Co0000ofIVI_mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`09o`000?m<C4coC4a<
oda<C?l0003oIVIVo`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`02?l0003o
/k>cok>c/ol0003oVIVIo`000?moOgoo00000_mVIVH00ol0003oC4a<o`000009oc<c<`09o`000?m<
C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`00_o<c<`00ol0
003oooooooooo`06ooooo`008oooool8oda<C003ool00?m<C4coC4a<00OoC4a<00?o0000ofIVI_mV
IVH02omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc
/k<05onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mV
IVH01_mVIVH00ol0003oC4a<oda<C00Eoda<C003o`000?mVIVKoIVIV00?oIVIV00Go0000ogmoOomo
OgooOgmoo`000005oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0
003o/k>cok>c/`04ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01?l0003oIVIVofIVI_l0
0004oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000003ofIVIP06o`00
0?moOgooOgmoo`000?nIVIWo00001?nc/k<00ol0003oc<c<olc<c006olc<c009o`000?nc/k?o/k>c
ok>c/ol0003oVIVIo`000?moOgoo000000?oIVIV00Co0000oda<C?m<C4co00002?lc<c<02Ol0003o
C4a<oda<C?m<C4co0000ofIVI_l0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<
00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c
<`07oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<
c?o<c<`00_o<c<`00ol0003oooooooooo`06ooooo`008oooool9oda<C003ool00?m<C4coC4a<00Go
C4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00_o
VIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00Wo
Ogmo00?o0000ofIVI_mVIVH01_mVIVH00ol0003oC4a<oda<C00Eoda<C003o`000?mVIVKoIVIV00?o
IVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c00Go
/k>c00?o0000olc<c?o<c<`00_o<c<`00ol0003o/k>cok>c/`04ok>c/`05o`000?nIVIWoVIVIoiVI
VOl000000omoOgl01?l0003oIVIVofIVI_l00005oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000
oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c
00?o0000olc<c?o<c<`01_o<c<`01ol0003o/k>cok>c/onc/k?o0000oiVIVOl000000_moOgl01?l0
003oIVIVofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Wo0000oda<C?m<C4coC4a<o`00
0?mVIVKo0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00009olc<c007o`000?nc/k?o0000
oiVIVOl0003oOgmoo`000002ofIVIP03o`000?m<C4co000000Wo<c<c00Wo0000oda<C?l0003oIVIV
o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c003olc<c003o`000?oooooooooo
00Kooooo000Sooooo`[oC4a<00?oo`00oda<C?m<C4`00om<C4`00ol0003oIVIVofIVIP0;ofIVIP03
o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Gok>c/`03
o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP07ofIVIP03
o`000?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`02ogmoO`03
o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c002olc<c003
o`000?nc/k?o/k>c00Co/k>c00?o0000oiVIVOnIVIT00_nIVIT01?l0003oOgmoogmoOol00003ofIV
IP03o`000?m<C4coC4a<00;oC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<
C004o`000?mVIVKoIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<2o`0000Soc<c<00Co
0000ok>c/onc/k?o00000_nIVIT01_l0003oOgmoogmoOol0003oIVIVo`0000?oC4a<00?o0000oc<c
<olc<c<01_lc<c<02Ol0003oC4a<oda<C?m<C4co0000ofIVI_l0003oOgmoo`000002oiVIV@04o`00
0?nc/k?o/k>co`0000Soc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV00?o
0000oda<C?l000002Olc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c
/`03o`000?o<c<coc<c<00?oc<c<00?o0000ooooooooool01_ooool002?ooooo2om<C4`01Ooo003o
C4a<oda<C?m<C4co000000goIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0<oiVI
V@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmo
O`03o`000?mVIVKoIVIV00OoIVIV00?o0000oda<C?m<C4`05Om<C4`00ol0003oIVIVofIVIP03ofIV
IP03o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`05ok>c
/`03o`000?o<c<coc<c<00;oc<c<00?o0000ok>c/onc/k<01?nc/k<00ol0003oVIVIoiVIV@02oiVI
V@04o`000?moOgooOgmoo`0000;oIVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`05
oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVI
VOl00003ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Co0000ok>c/onc/k?o00000_nIVIT01_l0003o
OgmoogmoOol0003oIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<02Ol0003oC4a<oda<C?m<
C4co0000ofIVI_l0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00So0000ok>c
/onc/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV00?o0000oda<C?l000002Olc<c<02Ol0003oC4a<
o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000
ooooooooool01_ooool002?ooooo3?m<C4`00ooo003oC4a<o`00000=ofIVIP03o`000?moOgooOgmo
00WoOgmo00?o0000oiVIVOnIVIT02onIVIT2o`0001So/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0
003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00OoIVIV00?o0000oda<C?m<C4`05Om<C4`00ol0
003oIVIVofIVIP03ofIVIP03o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0
003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o0000ok>c/onc/k<01?nc/k<00ol0
003oVIVIoiVIV@02oiVIV@04o`000?moOgooOgmoo`0000?oIVIV00?o0000oda<C?m<C4`00_m<C4`0
0ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_mo
Ogl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Oo0000ok>c/onc/k?o
/k>co`000?nIVIWo000000;oOgmo00?o0000ofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c
<`07o`000?m<C4coC4a<oda<C?l0003oIVIVo`000002ogmoO`03o`000?nIVIWo000000;o/k>c00?o
0000olc<c?o<c<`01oo<c<`01Ol0003o/k>co`000?nIVIWo000000;oOgmo00Go0000ofIVI_l0003o
C4a<o`000009oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o
0000olc<c?o<c<`01?o<c<`00ol0003oooooooooo`06ooooo`008oooool=oda<C003ool00?mVIVKo
IVIV00_oIVIV00?o0000ogmoOomoOgl02?moOgl2o`0000goVIVI00?o0000ok>c/onc/k<05onc/k<0
0ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH01omVIVH0
0ol0003oC4a<oda<C00Eoda<C003o`000?mVIVKoIVIV00?oIVIV00?o0000ogmoOomoOgl00_moOgl0
0ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c00Go/k>c00?o0000olc<c?o<c<`00_o<c<`0
0ol0003o/k>cok>c/`04ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01?l0003oIVIVofIV
I_l00005oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIV
ofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0
003o/k>cok>c/onc/k?o000000;oVIVI00Ko0000ogmoOomoOgoo0000ofIVI_l00003oda<C003o`00
0?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVIV@03
o`000?nc/k?o000000[oc<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<
C4`00ol0003o<c<coc<c<`07oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000
00;o/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003oooooooooo`06ooooo`008oooool<oda<C003
o`000?mVIVKoo`0000_oIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0<oiVIV@03
o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmoO`03
o`000?mVIVKoIVIV00SoIVIV00?o0000oda<C?m<C4`05Om<C4`00ol0003oIVIVofIVIP03ofIVIP03
o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`05ok>c/`03
o`000?o<c<coc<c<00;oc<c<00?o0000ok>c/onc/k<01?nc/k<01Ol0003oVIVIoiVIVOnIVIWo0000
00?oOgmo00Co0000ofIVI_mVIVKo00001Om<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4co
C4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`00
0?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@06o`000?moOgooOgmoo`00
0?mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o
0000ogmoOol000000_nIVIT00ol0003o/k>co`00000:olc<c009o`000?nc/k?o0000oiVIVOl0003o
Ogmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01olc<c<02Ol0003oC4a<o`000?mVIVKo
0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ooooooooool0
1_ooool002?ooooo2om<C4`01Ol0003oIVIVofIVI_mVIVKoo`0000WoIVIV00?o0000ogmoOomoOgl0
2?moOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT0
2onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00SoIVIV00?o0000oda<C?m<C4`0
5Om<C4`00ol0003oIVIVofIVIP03ofIVIP03o`000?moOgooOgmo00?oOgmo00?o0000oiVIVOnIVIT0
0_nIVIT00ol0003o/k>cok>c/`05ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o0000ok>c/onc/k<0
1?nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Co0000ofIVI_mVIVKo00001Om<C4`00ol0
003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl0
1?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>c
o`000002oiVIV@06o`000?moOgooOgmoo`000?mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c
<`04o`000?m<C4coC4a<o`0000?oIVIV0_l00002oiVIV@04o`000?nc/k?o/k>co`0000Woc<c<00?o
0000ok>c/ol000000_nIVIT2o`000005ofIVI_l0003oC4a<oda<C?l000002Olc<c<02Ol0003oC4a<
o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000
ooooooooool01_ooool002?ooooo2Om<C4`2o`0000GoIVIV00?oo`00ofIVI_mVIVH01OmVIVH00ol0
003oOgmoogmoO`08ogmoO`;o00003OnIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI
00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP08ofIVIP03o`000?m<C4coC4a<
01GoC4a<00?o0000ofIVI_mVIVH01?mVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI
00;oVIVI00?o0000ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c
00Co/k>c00?o0000oiVIVOnIVIT00_nIVIT01?l0003oOgmoogmoOol00003ofIVIP03o`000?m<C4co
C4a<00;oC4a<0_l00007oc<c<`04o`000?m<C4coC4a<oda<C0;o00000_mVIVH01?l0003oOgmoogmo
Ool00002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01Ol0003o/k>cok>c/onc/k?o0000
00;oVIVI00?o0000ogmoOol000000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Co0000
oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<
00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c
<`07oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<
c?o<c<`01Oo<c<`00ol0003oooooooooo`06ooooo`008oooool9oda<C003o`000?mVIVKoIVIV00Go
IVIV00?oo`00ofIVI_mVIVH01?mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_o
VIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo00So
Ogmo00?o0000ofIVI_mVIVH02OmVIVH00ol0003oC4a<oda<C00Eoda<C003o`000?mVIVKoIVIV00Co
IVIV00?o0000ogmoOomoOgl00_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000So/k>c00?o0000olc<
c?o<c<`00_o<c<`00ol0003o/k>cok>c/`04ok>c/`03o`000?nIVIWoVIVI00;oVIVI00Co0000ogmo
OomoOgoo00000omVIVH00ol0003oC4a<oda<C002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000
oda<C?m<C4coC4a<o`000003ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o
/k>co`000008olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT00ol0003oOgmoo`000002ofIV
IP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?mo
Ogoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`00
0?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Wo0000oda<C?l0003oIVIV
o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c005olc<c003o`000?oooooooooo
00Kooooo000Sooooo`SoC4a<00?o0000ofIVI_mVIVH01omVIVH00ooo003oIVIVofIVIP02ofIVIP03
o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Gok>c/`03
o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP09ofIVIP03
o`000?m<C4coC4a<01GoC4a<00?o0000ofIVI_mVIVH01?mVIVH00ol0003oOgmoogmoO`02ogmoO`03
o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01_nc/k<01Ol0003oc<c<olc<c?o<c<co0000
00Oo/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`04o`000?mVIVKoIVIVo`0000GoC4a<00?o
0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C007o`000?mVIVKoIVIVofIVI_l0003o
Ogmoo`000003oiVIV@04o`000?nc/k?o/k>co`0000Woc<c<00Co0000ok>c/onc/k?o00000_nIVIT0
1?l0003oOgmoogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000Wo<c<c00Co0000oda<C?m<C4co
00000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`02_l0
003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko
<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<
olc<c005olc<c003o`000?oooooooooo00Kooooo000Jooooo`;o000000?o410@ooooooooool01?oo
ool7oda<C003o`000?mVIVKoIVIV00WoIVIV00Coo`00ofIVI_mVIVKo00002OmoOgl2o`0000koVIVI
00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo00SoOgmo
00?o0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<oda<C00Eoda<C003o`000?mVIVKoIVIV00CoIVIV
00Go0000ogmoOomoOgooOgmoo`000004oiVIV@03o`000?nc/k?o/k>c00Ko/k>c00?o0000olc<c?o<
c<`00_o<c<`00ol0003o/k>cok>c/`04ok>c/`03o`000?nIVIWoVIVI00;oVIVI00Co0000ogmoOomo
Ogoo00000omVIVH00ol0003oC4a<oda<C002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<
C?m<C4coC4a<o`000003ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>c
o`000008olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT00ol0003oOgmoo`000002ofIVIP05
o`000?m<C4coC4a<oda<C?l000002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo
000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`02?l0003o/k>cok>c/ol0003oVIVIo`000?mo
Ogoo00000_mVIVH00ol0003oC4a<o`000009oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`00
0?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003oooooooooo`06ooooo`006ooo
ool00ol0003oooooooooo`05ooooo`KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ooo003o0000ogmo
O`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI0_l0000Hok>c/`03o`000?nIVIWoVIVI00_oVIVI0_l0
000:ogmoO`03o`000?mVIVKoIVIV00[oIVIV00?o0000oda<C?m<C4`05Om<C4`00ol0003oIVIVofIV
IP04ofIVIP03o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c
/`06ok>c/`05o`000?o<c<coc<c<olc<c?l000001onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?o
Ogmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<
C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000onc
/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT00ol0003oOgmo
o`000002ofIVIP04o`000?m<C4coC4a<o`0000Wo<c<c00Co0000oda<C?m<C4co00000_mVIVH01Ol0
003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`02_l0003o/k>cok>c/ol0
003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00[o0000oda<
C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c003
o`000?oooooooooo00Kooooo000@ooooo`Ko00000_ooool5o`0000Kooooo1Om<C4`00ol0003oIVIV
ofIVIP0;ofIVIP;o000000?oo`00ogmoOomoOgl01omoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`00
0?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`00
0?mVIVKoIVIV00[oIVIV00?o0000oda<C?m<C4`05Om<C4`00ol0003oIVIVofIVIP04ofIVIP03o`00
0?moOgooOgmo00?oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`06ok>c/`05o`00
0?o<c<coc<c<olc<c?l000001onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Go0000ofIV
I_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`0
1?l0003oIVIVofIVI_l00002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000onc/k<00ol0003oc<c<
olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT00ol0003oOgmoo`000002ofIVIP04
o`000?m<C4coC4a<o`0000Wo<c<c00Co0000oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nI
VIWo000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?mo
Ogoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00co0000oda<C?m<C4co0000ofIV
I_l0003oOgmoo`000?nIVIWo0000ok>c/ol00009olc<c003o`000?oooooooooo00Kooooo000Hoooo
o`04odA4A?oMgMgoooooo`0000Oooooo1?m<C4`00ol0003oIVIVofIVIP0;ofIVIP05o`000?moOgoo
OgmoogmoOooo00001omoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o
0000oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00[oIVIV00?o
0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP04ofIVIP03o`000?moOgooOgmo00;oOgmo00?o
0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`06ok>c/`05o`000?o<c<coc<c<olc<c?l00000
1onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<
C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002
ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc
/k?o/k>cok>c/ol000000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000Wo
<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmoogmoO`02o`0000;o/k>c00?o0000olc<
c?o<c<`01oo<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo0_l00002oda<C003o`000?lc
<c?o<c<c00Oo<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl000000_nc/k<00ol0
003oc<c<olc<c006olc<c0;o00002?ooool001Sooooo00CogMgMoeEEEOoooooo00001oooool2oda<
C0;o00003OmVIVH00ol0003oOgmoogmoO`03ogmoO`03ool00?moOgooOgmo00?oOgmo00?o0000oiVI
VOnIVIT02onIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00_oVIVI0_l0000:ogmo
O`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05Om<C4`00ol0003oIVIVofIVIP04ofIV
IP03o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`07ok>c
/`04o`000?o<c<coc<c<o`0000Oo/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`05o`000?mV
IVKoIVIVofIVI_l000001?m<C4`2o`0000Oo<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIV
ofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01_o<c<`01ol0
003o/k>cok>c/onc/k?o0000oiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00002oda<C003o`00
0?lc<c?o<c<c00Oo<c<c00Go0000oda<C?m<C4co0000ofIVIP02o`000004ogmoOol0003oVIVIo`00
00;o/k>c00?o0000olc<c?o<c<`01oo<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000
ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo
0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c0;o00002?ooool001Wooooo00?oMgMg
olc<c?l000001oooool00om<C4co0000ofIVIP0=ofIVIP03o`000?moOgooOgmo00GoOgmo00Goo`00
ogmoOomoOgooOgmoo`00000=oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02onI
VIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05Om<
C4`00ol0003oIVIVofIVIP05ofIVIP03o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00_nI
VIT00ol0003o/k>cok>c/`07ok>c/`04o`000?o<c<coc<c<o`0000Oo/k>c00Go0000oiVIVOnIVIWo
VIVIo`000003ogmoO`05o`000?mVIVKoIVIVofIVI_l000001?m<C4`00ol0003o<c<coc<c<`06oc<c
<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01Ol0003oOgmoogmoOomoOgoo000000;oVIVI00?o
0000ok>c/onc/k<00_nc/k<00ol0003oc<c<olc<c006olc<c007o`000?nc/k?o/k>cok>c/ol0003o
VIVIo`000002ogmoO`03o`000?mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01ol0003o
C4a<oda<C?m<C4co0000ofIVI_l000000_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<co
c<c<00Ooc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0
003o<c<coc<c<`07oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c
00?o0000olc<c?o<c<`01_o<c<`2o`0000Sooooo000Iooooo`03onk^k_m4A4Co000000Oooooo00?o
0000ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmoO`07ogmoO`03ool00?moOgoo000000goVIVI00?o
0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o
0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Eoda<C003o`000?mVIVKoIVIV00GoIVIV00?o
0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c00Oo/k>c00Co
0000olc<c?o<c<co00001onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000CoOgmo00Co0000ofIVI_mV
IVKo00001?m<C4`00ol0003o<c<coc<c<`06oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIV
I_mVIVKo00000omoOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Oo
0000ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo00000_m<C4`00ol0
003o<c<coc<c<`07oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl00ol0003oVIVIo`00
0002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Co0000ok>c/onc/k?o00000_nIVIT2o`000005ofIV
I_l0003oC4a<oda<C?l000002Olc<c<00ol0003oC4a<oda<C002o`000004ogmoOol0003oVIVIo`00
00;o/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003o/k>co`000008ooooo`006_ooool00omgMgOo
0000ooooo`06ooooo`koIVIV00?o0000ogmoOomoOgl02OmoOgl00ooo003oVIVIoiVIV@0;oiVIV@03
o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmoO`03
o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05Om<C4`00ol0003oIVIVofIVIP04ofIVIP;o
00001?moOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c00Ko/k>c00Co0000olc<c?o<
c<co00001onc/k<2o`0000?oVIVI00Go0000ogmoOomoOgooOgmoo`000003ofIVIP03o`000?m<C4co
C4a<00;oC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C005o`000?mVIVKo
IVIVofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<
00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Co0000oda<
C?m<C4co00002?lc<c<01ol0003oC4a<oda<C?m<C4co0000ofIVI_l000000_moOgl00ol0003oVIVI
o`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmo
o`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo
0000ogmoOol0003oVIVIo`000?nc/k?o00002Oo<c<`00ol0003o/k>co`000008ooooo`008oooool=
ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOoo00003?nIVIT00ol0003o/k>cok>c/`0F
ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0;
ofIVIP;o00005om<C4`00ol0003oIVIVofIVIP04ofIVIP03o`000?moOgooOgmo00?oOgmo00?o0000
oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`07ok>c/`03o`000?o<c<co000000Oo/k>c00?o0000
oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000?oIVIV00?o0000oda<C?m<C4`00_m<
C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Go0000ofIVI_mVIVKoIVIV
o`000002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o
/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01?l0003oC4a<oda<C?l0
0008oc<c<`07o`000?m<C4coC4a<oda<C?l0003oIVIVo`000002ogmoO`03o`000?nIVIWo000000;o
/k>c00?o0000olc<c?o<c<`01_o<c<`02ol0003o/k>cok>c/onc/k?o0000oiVIVOl0003oOgmoo`00
0?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`00
0?moOgoo0000oiVIVOl0003o/k>co`0000Woc<c<00?o0000ok>c/ol000002?ooool002?ooooo3?mV
IVH00ol0003oOgmoogmoO`09ogmoO`05o`000?nIVIWoVIVIoiVIVOoo00002OnIVIT2o`0001So/k>c
00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV
00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP04ofIVIP03o`000?moOgooOgmo00?oOgmo
00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`09ok>c/`03o`000?nc/k?o/k>c00Go/k>c
00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000?oIVIV00?o0000oda<C?m<
C4`00_m<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000omVIVH01?l0
003oOgmoogmoOol00002oiVIV@03o`000?nc/k?o/k>c00;o/k>c00?o0000olc<c?o<c<`01Oo<c<`0
0ol0003o/k>cok>c/`02ok>c/`06o`000?nIVIWoVIVIo`000?moOgoo00000_mVIVH01?l0003oC4a<
oda<C?l00009oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl0
0002ok>c/`03o`000?o<c<coc<c<00Koc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`00
00;oIVIV00?o0000oda<C?l000002?lc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo0_l0
0002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00002?ooool002?ooooo2omV
IVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?oo`00oiVIVOnIVIT01OnI
VIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?mo
Ogl2o`0000goIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP05ofIVIP03o`000?mo
OgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0Bok>c/`04o`000?nI
VIWoVIVIoiVIV@;o00000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000GoC4a<00?o0000oc<c<olc
<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000?oOgmo00Co0000oiVI
VOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nI
VIT01_l0003oOgmoogmoOol0003oIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01olc<c<01_l0003o
C4a<oda<C?l0003oIVIVo`0000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007
olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c
<olc<c<01_lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03
o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00002?ooool002?ooooo2_mVIVH00ol0003o
OgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00GoVIVI00?oo`00oiVIVOnIVIT00onIVIT00ol0003o
/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003o
IVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH01?mVIVH00ol0003o
OgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<04_nc/k<01Ol0003o
VIVIoiVIVOnIVIWo000000?oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o
<c<c00Ko<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00003ogmoO`04o`000?nI
VIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;o
VIVI00Ko0000ogmoOomoOgoo0000ofIVI_l00003oda<C003o`000?lc<c?o<c<c00Oo<c<c00So0000
oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`02_l0
003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko
<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<
olc<c006olc<c004o`000?nc/k?o/k>co`0000Sooooo000Sooooo`WoIVIV00?o0000ogmoOomoOgl0
2OmoOgl00ol0003oVIVIoiVIV@07oiVIV@05ool00?nIVIWoVIVIoiVIVOl000006Onc/k<00ol0003o
VIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH03?mVIVH00ol0003o
C4a<oda<C00Goda<C003o`000?mVIVKoIVIV00CoIVIV00?o0000ogmoOomoOgl00omoOgl00ol0003o
VIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c01;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000004ogmo
O`04o`000?mVIVKoIVIVo`0000GoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002
oda<C004o`000?mVIVKoIVIVo`0000?oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<
olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01_l0003oOgmoogmoOol0003oIVIV
o`0000?oC4a<00?o0000oc<c<olc<c<01olc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo
00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c006o`000?nc/k?o/k>co`000?nI
VIWo00000_moOgl2o`0000;oC4a<00?o0000oc<c<olc<c<01olc<c<00ol0003oC4a<o`000002ofIV
IP;o000000GoVIVIo`000?nc/k?o/k>co`000009olc<c004o`000?nc/k?o0000o`0000Sooooo000S
ooooo`SoIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@09oiVIV@03ool00?nIVIWo
000001Wo/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKo
IVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP04ofIVIP03o`000?moOgoo
Ogmo00?oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0Bok>c/`03o`000?nIVIWo
VIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`000003ofIVIP03o`000?m<C4coC4a<00;oC4a<00?o
0000oc<c<olc<c<01_lc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo
00Go0000oiVIVOnIVIWoVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc
/k?o/k>co`000002oiVIV@03o`000?moOgoo000000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008
oc<c<`07o`000?m<C4coC4a<oda<C?l0003oIVIVo`000002ogmoO`03o`000?nIVIWo000000;o/k>c
00?o0000olc<c?o<c<`01oo<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0
0002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000oiVI
VOl000000_nc/k<00ol0003oc<c<olc<c006olc<c003o`000?nc/k?o/k>c00;o00002?ooool002?o
oooo1omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?oo`00ok>c/onc
/k<05onc/k<00ol0003oVIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mV
IVH02omVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00GoIVIV00?o0000ogmoOomo
Ogl00omoOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c01;o/k>c00?o0000oiVIVOnI
VIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000?oIVIV00?o0000oda<C?m<C4`00_m<C4`00ol0
003o<c<coc<c<`06oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl0
1Ol0003oVIVIoiVIVOnIVIWo000000?o/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c
/`02ok>c/`06o`000?nIVIWoVIVIo`000?moOgoo00000_mVIVH01Ol0003oC4a<oda<C?m<C4co0000
00So<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00?o0000oiVIVOl000000_nc
/k<00ol0003oc<c<olc<c007olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIV
o`0000;oC4a<00?o0000oc<c<olc<c<01olc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003o
VIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o0000ok>c/onc/k<00_l00008ooooo`00
8oooool7ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>c
ool0000Gok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIV
ofIVIP0<ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH01?mVIVH00ol0003oOgmo
ogmoO`03ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<04onc/k<01Ol0003oVIVI
oiVIVOnIVIWo000000?oOgmo00Go0000ofIVI_mVIVKoIVIVo`000005oda<C003o`000?lc<c?o<c<c
00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Co0000
oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c003o`000?nc/k?o/k>c00;o/k>c00?o
0000oiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c
00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`00
00Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o
0000oc<c<olc<c<01_lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002
ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/ol0003oVIVIo`000008ooooo`008oooool6
ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT03?nIVIT01?l0003o/k>cok>c/ooo
000Eok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIV
IP0<ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH01OmVIVH00ol0003oOgmoogmo
O`02ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<04_nc/k<01Ol0003oVIVIoiVI
VOnIVIWo000000CoOgmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Ko
<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`05o`000?nIVIWoVIVI
oiVIVOl000000onc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000
oiVIVOnIVIWo00000_moOgl00ol0003oIVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Oo
0000oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003o
c<c<olc<c007olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<
00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?m<C4`2o`000004ogmoOol0003oVIVIo`00
00;o/k>c00?o0000olc<c?o<c<`01oo<c<`01Ol0003o/k>co`000?nIVIWo000000Sooooo000Soooo
o`GoIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@;o00001?nc/k<00ooo
003o/k>cok>c/`0Aok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl02?moOgl00ol0
003oIVIVofIVIP0;ofIVIP;o00006Om<C4`00ol0003oIVIVofIVIP05ofIVIP03o`000?moOgooOgmo
00?oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0Cok>c/`05o`000?nIVIWoVIVI
oiVIVOl000000omoOgl01Ol0003oIVIVofIVI_mVIVKo000000GoC4a<00?o0000oc<c<olc<c<01Olc
<c<00ol0003oC4a<oda<C002oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01?l0003oVIVI
oiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01_l0003o
VIVIoiVIVOl0003oOgmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`04o`000?m<
C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00008olc<c004
o`000?nc/k?o/k>co`0000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o
<c<c00Ko<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0
003oc<c<olc<c007olc<c0;o000000?oVIVIo`000?l000002?ooool002?ooooo1?mVIVH00ol0003o
OgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<01Onc/k<00ooo003o
/k>cok>c/`0?ok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003o
IVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0003o
OgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<04onc/k<01Ol0003o
VIVIoiVIVOnIVIWo000000?oOgmo00Go0000ofIVI_mVIVKoIVIVo`000005oda<C003o`000?lc<c?o
<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Co
0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c
00Ko0000oiVIVOnIVIWo0000ogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<0
1?l0003oC4a<oda<C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl000000onc/k<00ol0003oc<c<
olc<c006olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<
C003o`000?lc<c?o<c<c00Ko<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo
00000_nc/k<00ol0003oc<c<olc<c007olc<c0;o000000?oVIVIo`000?l000002?ooool002?ooooo
0omVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<0
1onc/k<00ooo003o/k>cok>c/`0=ok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl0
2?moOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH0
1_mVIVH00ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<0
4onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000CoOgmo00Co0000ofIVI_mVIVKo00001Om<C4`00ol0
003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002
ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c
/onc/k?o000000;oVIVI00?o0000ogmoOol000000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So
<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVIV@05o`000?nc/k?o/k>c
ok>c/ol000001oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV00?o
0000oda<C?l000002?lc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo0_l00002ok>c/`03
o`000?o<c<coc<c<00Ooc<c<00Ko0000ok>c/ol0003o0000ogmoOol00008ooooo`008oooool00omV
IVKo0000o`00000:ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<02Onc/k<00ooo
003o/k>cok>c/`0;ok>c/`03o`000?nIVIWoVIVI00_oVIVI0_l0000:ogmoO`03o`000?mVIVKoIVIV
00_oIVIV0_l0000Ioda<C003o`000?mVIVKoIVIV00KoIVIV00?o0000ogmoOomoOgl00omoOgl00ol0
003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c01;o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0
003oOgmoogmoOomoOgoo000000?oIVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`04
oc<c<`03o`000?m<C4coC4a<00?oC4a<00Co0000ofIVI_mVIVKo00000_moOgl2o`0000;oVIVI00Go
0000ok>c/onc/k?o/k>co`000009olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Co0000ogmoOomo
Ogoo00000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Co0000oda<C?m<C4co00000_mV
IVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Co0000ok>c/onc/k?o
00000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02_l0
003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ko
c<c<00?o0000ok>c/onc/k<00_l000000omoOgoo0000ooooo`07ooooo`008oooool00ol0003oOgmo
ogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<02onc/k<00ooo003o/k>c
ok>c/`09ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIV
ofIVIP0;ofIVIP03o`000?m<C4coC4a<01SoC4a<00?o0000ofIVI_mVIVH01_mVIVH00ol0003oOgmo
ogmoO`03ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<04onc/k<01Ol0003oVIVI
oiVIVOnIVIWo000000CoOgmo00Go0000ofIVI_mVIVKoIVIVo`000005oda<C003o`000?lc<c?o<c<c
00Co<c<c00?o0000oda<C?m<C4`00om<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWo
VIVIo`0000Co/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI
00Co0000ogmoOomoOgoo00000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Co0000oda<
C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Co
0000ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc
<c<01_lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`00
0?o<c<coc<c<00Koc<c<00?o0000ok>c/onc/k<00_l000000omoOgoo0000ooooo`07ooooo`008ooo
ool;ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<03Onc/k<00ooo003o/k>cok>c
/`07ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIV
IP0;ofIVIP03o`000?m<C4coC4a<01SoC4a<00?o0000ofIVI_mVIVH01omVIVH00ol0003oOgmoogmo
O`03ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<04_nc/k<01Ol0003oVIVIoiVI
VOnIVIWo000000CoOgmo00Go0000ofIVI_mVIVKoIVIVo`000005oda<C003o`000?lc<c?o<c<c00Co
<c<c00?o0000oda<C?m<C4`00om<C4`01?l0003oIVIVofIVI_l00002ogmoO`05o`000?nIVIWoVIVI
oiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nI
VIT01?l0003oOgmoogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01?l0003o
C4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`0
0ol0003o/k>co`000002oiVIV@03o`000?moOgooOgmo00;o00000_m<C4`00ol0003o<c<coc<c<`07
oc<c<`03o`000?m<C4co000000;oIVIV0_l000001OnIVIWo0000ok>c/onc/k?o000000Woc<c<00Oo
0000ok>c/ol0003oVIVIo`000?moOgoo000000Sooooo000Sooooo`[oOgmo00?o0000oiVIVOnIVIT0
2onIVIT00ol0003o/k>cok>c/`0?ok>c/`03ool00?nc/k?o/k>c00Go/k>c00?o0000oiVIVOnIVIT0
2onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`0
6?m<C4`2o`0000SoIVIV00?o0000ogmoOomoOgl00omoOgl00ol0003oVIVIoiVIV@04oiVIV@03o`00
0?nc/k?o/k>c01;o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000?o
IVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;o
C4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000onc/k<0
0ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmo
Ool00002ofIVIP04o`000?m<C4coC4a<o`0000Wo<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0
003oOgmoo`000002oiVIV@03o`000?nc/k?o000000[oc<c<00?o0000ok>c/ol000000_nIVIT01Ol0
003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01olc<c<02Ol0003oC4a<o`000?mV
IVKo0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00So0000ok>c/onc
/k?o0000oiVIVOl0003oOgmoo`0000Sooooo000Sooooo`WoOgmo00?o0000oiVIVOnIVIT02onIVIT0
0ol0003o/k>cok>c/`0Aok>c/`03ool00?nc/k?o/k>c00?o/k>c00?o0000oiVIVOnIVIT02onIVIT0
0ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV0_l0000Ioda<C003o`000?mVIVKo
IVIV00SoIVIV00?o0000ogmoOomoOgl00omoOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o
/k>c01;o/k>c00?o0000oiVIVOnIVIT00_nIVIT01?l0003oOgmoogmoOol00004ofIVIP03o`000?m<
C4coC4a<00?oC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C005o`000?mV
IVKoIVIVofIVI_l000000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000?o/k>c00?o0000olc<c?o<
c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH0
1?l0003oC4a<oda<C?l00009oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol00000
0_nIVIT00ol0003o/k>co`00000:olc<c005o`000?nc/k?o0000oiVIVOl000000_moOgl00ol0003o
IVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo
0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c008o`000?nc/k?o/k>co`000?nIVIWo
0000ogmoOol00008ooooo`008oooool8ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc
/k<04onc/k<01Ooo003o/k>cok>c/onc/k?o000000goVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0
003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01SoC4a<00?o0000ofIVI_mVIVH02?mVIVH00ol0
003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<04_nc/k<00ol0
003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol000000omVIVH00ol0003oC4a<oda<C003
oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mV
IVKo000000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<
00Go0000ok>c/onc/k?o/k>co`000003oiVIV@03o`000?moOgoo000000;oIVIV00Go0000oda<C?m<
C4coC4a<o`000008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT0
1?l0003o/k>cok>c/ol00009olc<c003o`000?nc/k?o000000;oVIVI00Go0000ogmoOol0003oIVIV
o`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Oo0000oda<C?l0003oIVIVo`000?moOgoo0000
00;oVIVI00?o0000ok>c/ol000002?o<c<`01ol0003o/k>cok>c/ol0003oVIVIo`000?moOgl00_l0
0008ooooo`008oooool7ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05Onc/k<0
0ooo003o/k>co`00000=oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH0
0ol0003oC4a<oda<C00Hoda<C0;o00002?mVIVH2o`0000GoOgmo00?o0000oiVIVOnIVIT01?nIVIT0
0ol0003o/k>cok>c/`0Bok>c/`;o00000onIVIT01Ol0003oOgmoogmoOomoOgoo000000CoIVIV00?o
0000oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Go
0000ofIVI_mVIVKoIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<
c<`01oo<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Ko0000ogmoOomoOgoo0000ofIVI_l0
0003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP03o`00
0?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01?l0003o/k>cok>c/ol00002oiVI
V@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0:o`000?m<C4co
C4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01ol0
003o/k>cok>c/ol0003oVIVIo`000?moOgl00_l00008ooooo`008oooool6ogmoO`03o`000?nIVIWo
VIVI00coVIVI00?o0000ok>c/onc/k<05_nc/k<00ooo003oVIVIoiVIV@0;oiVIV@03o`000?moOgoo
Ogmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Hoda<C003o`000?mVIVKo
IVIV00SoIVIV00?o0000ogmoOomoOgl01?moOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o
/k>c01?o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000CoIVIV00?o
0000oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Go
0000ofIVI_mVIVKoIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<
c<`01oo<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Ko0000ogmoOomoOgoo0000ofIVI_l0
0003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP05o`00
0?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c004o`000?nc/k?o/k>co`00
00;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00[o0000
oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<
c007o`000?nc/k?o/k>co`000?nIVIWo0000ogmoO`02o`0000Sooooo000Sooooo`GoOgmo00?o0000
oiVIVOnIVIT02onIVIT2o`0001So/k>c00?o0000oiVIVOoo00002onIVIT00ol0003oOgmoogmoO`09
ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`06?m<C4`00ol0003oIVIVofIVIP08
ofIVIP03o`000?moOgooOgmo00CoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`0B
ok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`000004ofIVIP03o`000?m<
C4coC4a<00?oC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C004oda<C004o`000?mV
IVKoIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c007olc<c005
o`000?nc/k?o/k>cok>c/ol000000_nIVIT01_l0003oOgmoogmoOol0003oIVIVo`0000?oC4a<00?o
0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o0000ogmoOol00000
0_nIVIT01?l0003o/k>cok>c/ol00009olc<c003o`000?nc/k?o000000;oVIVI00?o0000ogmoOol0
00000_mVIVH01?l0003oC4a<oda<C?l00007oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_mo
Ogl2o`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?mo
Ogoo0000ofIVI_l00008ooooo`008oooool3ogmoO`;o00003OnIVIT00ol0003o/k>cok>c/`0Gok>c
/`05o`000?nIVIWoVIVIoiVIVOoo00002OnIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKo
IVIV00_oIVIV00?o0000oda<C?m<C4`06?m<C4`00ol0003oIVIVofIVIP08ofIVIP03o`000?moOgoo
Ogmo00CoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`0Cok>c/`03o`000?nIVIWo
VIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`000003ofIVIP03o`000?m<C4coC4a<00CoC4a<00?o
0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C003oda<C004o`000?mVIVKoIVIVo`0000;oOgmo
00Go0000oiVIVOnIVIWoVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o0000ok>c/onc
/k<00_nc/k<01_l0003oVIVIoiVIVOl0003oOgmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`00
0008oc<c<`07o`000?m<C4coC4a<oda<C?l0003oIVIVo`000002ogmoO`03o`000?nIVIWo000000?o
/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000
ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000
ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02_l0003o/k>cok>c/ol0003o
VIVIo`000?moOgoo0000ofIVI_l00008ooooo`008oooool2ogmoO`03o`000?nIVIWoVIVI00coVIVI
00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@03oiVIV@03ool00?nIVIWoVIVI00GoVIVI
0_l0000:ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`06?m<C4`00ol0003oIVIV
ofIVIP09ofIVIP03o`000?moOgooOgmo00CoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>c
ok>c/`0Cok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`000003ofIVIP03
o`000?m<C4coC4a<00CoC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C003oda<C004
o`000?mVIVKoIVIVo`0000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000003ok>c/`03o`000?o<c<co
c<c<00Koc<c<00?o0000ok>c/onc/k<00_nc/k<01_l0003oVIVIoiVIVOl0003oOgmoo`0000;oIVIV
00Go0000oda<C?m<C4coC4a<o`000008oc<c<`07o`000?m<C4coC4a<oda<C?l0003oIVIVo`000002
ogmoO`03o`000?nIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol0
0002oiVIV@;o00000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`0:o`000?m<C4coC4a<o`000?mV
IVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02_l0003o/k>cok>c
/ol0003oVIVIo`000?moOgoo0000ofIVI_l00008ooooo`008oooool00omoOgoo0000oiVIV@0=oiVI
V@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT01OnIVIT00ooo003oVIVIoiVIV@03oiVI
V@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Goda<
C0;o00002omVIVH00ol0003oOgmoogmoO`04ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c
/onc/k<04onc/k<00ol0003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol000000omVIVH0
0ol0003oC4a<oda<C004oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00om<C4`0
1?l0003oIVIVofIVI_l00002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000onc/k<00ol0003oc<c<
olc<c007olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIV
IP04o`000?m<C4coC4a<o`0000So<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP05o`000?mo
Ogoo0000oiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`0000;o
VIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Wo0000oda<
C?l0003oIVIVo`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c004o`00
0?nc/k?o/k>cok>c/`;o000000?oOgmoo`000?mVIVH00_l00008ooooo`008oooool00ol0003oVIVI
oiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT01onIVIT01Ooo003oVIVI
oiVIVOnIVIWo000000[oOgmo0_l0000=ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mV
IVH02_mVIVH00ol0003oOgmoogmoO`04ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc
/k<04onc/k<00ol0003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol000001?mVIVH00ol0
003oC4a<oda<C003oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00om<C4`01Ol0
003oIVIVofIVI_mVIVKo000000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000003ok>c/`03o`000?o<
c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;o
IVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`07o`000?m<C4coC4a<oda<C?l0003oIVIVo`00
0002ogmoO`03o`000?nIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01_l0003o/k>cok>c
/ol0003oVIVIo`0000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`09
o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<
c<`02Ol0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVIP02o`0000Sooooo000Sooooo`ko
VIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@09oiVIV@04ool00?nIVIWoVIVIo`00
00[oOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV
00[oIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c
01?o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000?oIVIV00?o0000
oda<C?m<C4`01?m<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Go0000
ofIVI_mVIVKoIVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000onc/k<00ol0003oc<c<
olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIV
IP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01ol0003oC4a<oda<C?m<C4co0000ofIVI_l00000
0_moOgl00ol0003oVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Ko0000ok>c/onc/k?o
0000oiVIVOl00002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01olc<c<02Ol0
003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<
00Wo0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVH00_l00008ooooo`008oooool=oiVI
V@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02onIVIT00ooo003o0000ogmoO`09ogmo
O`03o`000?mVIVKoIVIV00coIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0:ofIV
IP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`0Cok>c
/`03o`000?nIVIWoVIVI00;oVIVI00?o0000ogmoOomoOgl00_moOgl01Ol0003oIVIVofIVI_mVIVKo
000000KoC4a<00?o0000oc<c<olc<c<00olc<c<00ol0003oC4a<oda<C003oda<C005o`000?mVIVKo
IVIVofIVI_l000000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Co/k>c00?o0000olc<c?o<c<`0
1_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01?l0
003oC4a<oda<C?l00009oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Ko0000ogmoOomoOgoo0000
oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00?o0000ok>c/ol000000_nIVIT01_l0003o
OgmoogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<00ol0003oC4a<o`000002
ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c009o`000?nc
/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIV00;o00002?ooool002?ooooo3OnIVIT00ol0003o
/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000ool00?moOgl02?moOgl00ol0003o
IVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003o
OgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<04onc/k<00ol0003o
VIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol000000omVIVH00ol0003oC4a<oda<C004oda<
C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00om<C4`01Ol0003oIVIVofIVI_mVIVKo
000000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go
0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Go0000oda<C?m<
C4coC4a<o`000008oc<c<`07o`000?m<C4coC4a<oda<C?l0003oIVIVo`000002ogmoO`03o`000?nI
VIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;o
Ogmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`07o`000?m<C4co0000ofIV
I_l0003oOgmoo`000002oiVIV@03o`000?nc/k?o000000Soc<c<00co0000ok>c/onc/k?o0000oiVI
VOl0003oOgmoo`000?mVIVKo0000oda<C?l00008ooooo`008oooool;oiVIV@;o00006?nc/k<00ol0
003oVIVIoiVIV@0;oiVIV@;o00000_moOgl00ooo003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV
00_oIVIV0_l0000Hoda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0
003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT00_nIVIT00ol0
003oOgmoogmoO`02ogmoO`05o`000?mVIVKoIVIVofIVI_l000001_m<C4`00ol0003o<c<coc<c<`04
oc<c<`03o`000?m<C4coC4a<00?oC4a<00Co0000ofIVI_mVIVKo00000omoOgl01?l0003oVIVIoiVI
VOl00004ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04
o`000?moOgooOgmoo`0000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<01?l0003oC4a<oda<C?l0
0002ofIVIP06o`000?moOgooOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c007olc<c006
o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o
<c<c00Ko<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0
003oc<c<olc<c006olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<
C4co00002?ooool002?ooooo2_nIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00_o
VIVI00?o0000ogmoOomoOgl00omoOgl00ooo003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00_o
IVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00Go
Ogmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`0Cok>c/`03o`000?nIVIWoVIVI00?o
VIVI00Go0000ogmoOomoOgooOgmoo`000004ofIVIP03o`000?m<C4coC4a<00CoC4a<00?o0000oc<c
<olc<c<01?lc<c<00ol0003oC4a<oda<C003oda<C004o`000?mVIVKoIVIVo`0000?oOgmo00Co0000
oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol00000
0_nIVIT01?l0003oOgmoogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000Wo<c<c00Co0000oda<
C?m<C4co00000_mVIVH01_l0003oOgmoogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`0
1oo<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo0_l00003oda<C003o`000?lc<c?o<c<c
00Ko<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003o
c<c<olc<c006olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co
00002?ooool002?ooooo2OnIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00_oVIVI
00?o0000ogmoOomoOgl01OmoOgl01Ooo003oOgmoogmoOomoOgoo000000goIVIV00?o0000oda<C?m<
C4`05om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnI
VIT01OnIVIT00ol0003o/k>cok>c/`0Cok>c/`03o`000?nIVIWoVIVI00;oVIVI00?o0000ogmoOomo
Ogl00_moOgl01Ol0003oIVIVofIVI_mVIVKo000000KoC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0
003oC4a<oda<C003oda<C004o`000?mVIVKoIVIVo`0000?oOgmo00Co0000oiVIVOnIVIWo00001?nc
/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmo
ogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000Wo<c<c00Co0000oda<C?m<C4co00000_mVIVH0
1_l0003oOgmoogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01oo<c<`01_l0003o/k>c
ok>c/ol0003oVIVIo`0000;oOgmo00?o0000ofIVI_l000000om<C4`00ol0003o<c<coc<c<`05oc<c
<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<
c<`01oo<c<`02_l0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4`2o`0000Sooooo
000Sooooo`SoVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?mo
OgooOgmo00OoOgmo00?oo`00ogmoOol000003OmVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mV
IVKoIVIV00_oIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@05oiVIV@03o`000?nc
/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT00onIVIT01Ol0003oOgmoogmoOomoOgoo000000CoIVIV
00?o0000oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<
00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0
003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl0
1?l0003oIVIVofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Co0000oda<C?m<C4co0000
0_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Woc<c<00Ko0000ok>c/onc
/k?o0000oiVIVOl00002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<0
2_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<
00Ooc<c<00[o0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<0_l00008ooooo`00
8oooool7oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmo
ogmoO`09ogmoO`03ool00?mVIVKoIVIV00_oIVIV0_l0000Hoda<C003o`000?mVIVKoIVIV00_oIVIV
00?o0000ogmoOomoOgl01_moOgl00ol0003oVIVIoiVIV@05oiVIV@03o`000?nc/k?o/k>c01?o/k>c
00?o0000oiVIVOnIVIT00onIVIT01Ol0003oOgmoogmoOomoOgoo000000?oIVIV00?o0000oda<C?m<
C4`01?m<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Go0000ofIVI_mV
IVKoIVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000onc/k<00ol0003oc<c<olc<c006
olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00003ofIVIP04o`00
0?m<C4coC4a<o`0000So<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP03o`000?moOgoo0000
00;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`02?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo
00000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmo
Ool0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01oo<c<`2o`0000;oVIVI00Ko0000ogmoOol0
003oIVIVo`000?m<C4`2o`0000Sooooo000Sooooo`KoVIVI00?o0000ok>c/onc/k<05onc/k<00ol0
003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_oo00002omVIVH00ol0
003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl01_moOgl00ol0
003oVIVIoiVIV@05oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT00onIVIT01Ol0
003oOgmoogmoOomoOgoo000000CoIVIV00?o0000oda<C?m<C4`01?m<C4`00ol0003o<c<coc<c<`03
oc<c<`03o`000?m<C4coC4a<00?oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`05o`000?nI
VIWoVIVIoiVIVOl000001?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c
00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c
00Ko<c<c00Co0000oda<C?m<C4co00000omVIVH2o`0000;oVIVI00Co0000ok>c/onc/k?o00002Oo<
c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o
<c<coc<c<`06oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c
00?o0000olc<c?o<c<`01oo<c<`03Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<
C4co0000oc<c<ol000002?ooool001Sooooo1Ol00006ooooo`GoVIVI00?o0000ok>c/onc/k<05onc
/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00Go0000ofIVI_mVIVKoIVIV
ool00009ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmo
ogmoO`06ogmoO`03o`000?nIVIWoVIVI00GoVIVI00?o0000ok>c/onc/k<04onc/k<00ol0003oVIVI
oiVIV@03oiVIV@05o`000?moOgooOgmoogmoOol000001?mVIVH00ol0003oC4a<oda<C004oda<C003
o`000?lc<c?o<c<c00?o<c<c00?o0000oda<C?m<C4`01?m<C4`00ol0003oIVIVofIVIP02o`0000;o
Ogmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>c
ok>c/ol000000onIVIT00ol0003oOgmoo`000002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc
<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>c
ok>c/ol00009olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP04o`000?m<
C4coC4a<o`0000So<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc
/k<00ol0003oc<c<olc<c006olc<c00>o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIV
o`000?m<C4co0000oc<c<ol00008ooooo`006?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo
1OnIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl0
2OmoOgl00ol0003oIVIVofIVIP03ofIVIP03ool00?mVIVKoIVIV00GoIVIV0_l0000Hoda<C003o`00
0?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@06oiVIV@03o`00
0?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT00onIVIT01Ol0003oOgmoogmoOomoOgoo000000Co
IVIV00?o0000oda<C?m<C4`01?m<C4`00ol0003o<c<coc<c<`03oc<c<`03o`000?m<C4coC4a<00Co
C4a<00Co0000ofIVI_mVIVKo00000omoOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<co
c<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000003oiVIV@03o`000?moOgoo000000;oIVIV00Go
0000oda<C?m<C4coC4a<o`000008oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH00ol0003o
Ogmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Woc<c<00So0000ok>c/onc/k?o0000oiVIVOl0
003oOgmoo`0000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<02_l0003oC4a<oda<C?l0003oIVIV
o`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00ko0000ok>c/onc/k?o
0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l0003o<c<co`0000Sooooo000@ooooo`Ko0000
0oooool00onHV9So8B4Qonk^kP07ooooo`?oVIVI0_l0000Hok>c/`03o`000?nIVIWoVIVI00_oVIVI
00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP05ofIVIP03ool00?mVIVKoIVIV00?oIVIV
00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?moOgooOgmo00GoOgmo
00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`0Cok>c/`03o`000?nIVIWoVIVI00?oVIVI
00?o0000ogmoOomoOgl00_moOgl01Ol0003oIVIVofIVI_mVIVKo000000KoC4a<00?o0000oc<c<olc
<c<00olc<c<00ol0003oC4a<oda<C004oda<C004o`000?mVIVKoIVIVo`0000CoOgmo00Co0000oiVI
VOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000onI
VIT00ol0003oOgmoo`000002ofIVIP05o`000?m<C4coC4a<oda<C?l000002Olc<c<01?l0003oC4a<
oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`01?l0
003o/k>cok>c/ol00002oiVIV@;o00000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`0:o`000?m<
C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01Oo<c<`0
1_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo0_l000001Om<C4co0000oc<c<olc<c?o000000So
oooo000Jooooo`03oiRHV?lQ8B7ok^k^00Kooooo0_nIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`00
0?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP07ofIVIP05ool0
0?mVIVKoIVIVofIVI_l000006Om<C4`00ol0003oIVIVofIVIP0;ofIVIP;o00002?moOgl00ol0003o
VIVIoiVIV@05oiVIV@03o`000?nc/k?o/k>c01Co/k>c00?o0000oiVIVOnIVIT00_nIVIT00ol0003o
OgmoogmoO`02ogmoO`05o`000?mVIVKoIVIVofIVI_l000001_m<C4`00ol0003o<c<coc<c<`04oc<c
<`03o`000?m<C4coC4a<00?oC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`04o`000?nIVIWo
VIVIo`0000Co/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI
00Co0000ogmoOomoOgoo00000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000Wo<c<c00Co0000oda<
C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<0_l0
0002ok>c/`05o`000?nIVIWo0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`0:
o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`0
1_o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000;o<c<c
00?o0000ooooooooool01_ooool001_ooooo00?oMgMgofIVI_ooool01Oooool00onIVIWo0000ok>c
/`0Hok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIV
IP09ofIVIP03ool00?mVIVKo000001WoC4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmo
O`06ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc/k<05?nc/k<01Ol0003oVIVIoiVI
VOnIVIWo000000GoOgmo00Go0000ofIVI_mVIVKoIVIVo`000006oda<C003o`000?lc<c?o<c<c00Co
<c<c00?o0000oda<C?m<C4`00om<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Co0000oiVI
VOnIVIWo00001?nc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nI
VIT01?l0003oOgmoogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<C?l000002Olc<c<01?l0003o
C4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`0
2Ol0003o/k>cok>c/onc/k?o0000oiVIVOl0003oOgmoo`000002ofIVIP03o`000?m<C4co000000Wo
<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<
olc<c006olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co0000
0_lc<c<00ol0003oooooooooo`06ooooo`007?ooool00ol0003oooooooooo`04ooooo`03o`000?nc
/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mV
IVKoIVIV00_oIVIV00?oo`00oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?mo
OgooOgmo00KoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`0Dok>c/`03o`000?nI
VIWoVIVI00;oVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP02ofIVIP03o`000?m<
C4coC4a<00?oC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C003oda<C005o`000?mV
IVKoIVIVofIVI_l000000omoOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Ko
c<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Go0000
oda<C?m<C4coC4a<o`000009oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Ko0000ogmoOomoOgoo
0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Wo0000ok>c/onc/k?o/k>co`000?nI
VIWo0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`0:o`000?m<C4coC4a<o`00
0?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01oo<c<`02Ol0003o/k>c
o`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C004o`000?lc<c?o<c<co`0000Sooooo000H
ooooo`05o`000?nj^[[ooooooiRHV?l@41001_oooolIok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o
0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coo`0001OoC4a<00?o
0000ofIVI_mVIVH02omVIVH2o`0000SoOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c
/`0Dok>c/`03o`000?nIVIWoVIVI00;oVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIV
IP02ofIVIP03o`000?m<C4coC4a<00CoC4a<00?o0000oc<c<olc<c<00olc<c<00ol0003oC4a<oda<
C004oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Co
/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`00
00;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`07o`000?m<C4co
C4a<oda<C?l0003oIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000;o/k>c00?o0000olc<c?o<
c<`01_o<c<`02Ol0003o/k>cok>c/onc/k?o0000oiVIVOl0003oOgmoo`000002ofIVIP03o`000?m<
C4co000000Wo<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol0
000:olc<c00;o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l000000olc<c<0
0ol0003oooooooooo`06ooooo`006?ooool01OnHV9So410@o`000?lQ8B7oc<c<00Kooooo6?nc/k<0
0ol0003oVIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH0
1Ol0003oC4a<oda<C?m<C4coo`0001GoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmo
O`08ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc/k<05?nc/k<00ol0003oVIVIoiVI
V@02oiVIV@03o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<
C004oda<C003o`000?lc<c?o<c<c00?o<c<c00?o0000oda<C?m<C4`01?m<C4`01?l0003oIVIVofIV
I_l00003ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0003oc<c<olc<c005olc<c003
o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00003
oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH01?l0003oOgmoogmo
Ool00002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Wo0000ok>c/onc/k?o/k>co`000?nIVIWo
0000ogmoOol000000_mVIVH00ol0003oC4a<o`000009oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo
0000ogmoOol0003oVIVIo`000?nc/k?o00002_o<c<`02ol0003o/k>co`000?nIVIWo0000ogmoOol0
003oIVIVo`000?m<C4co000000?o<c<c00?o0000ooooooooool01_ooool002?ooooo5onc/k<00ol0
003oVIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH03?mVIVH00ol0
003oC4a<oda<C002oda<C003ool00?m<C4coC4a<017oC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0
003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc/k<05?nc/k<00ol0
003oVIVIoiVIV@02oiVIV@03o`000?moOgooOgmo00?oOgmo00Go0000ofIVI_mVIVKoIVIVo`000007
oda<C003o`000?lc<c?o<c<c00;o<c<c00?o0000oda<C?m<C4`01?m<C4`01Ol0003oIVIVofIVI_mV
IVKo000000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Koc<c<
00Go0000ok>c/onc/k?o/k>co`000003oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Go0000oda<
C?m<C4coC4a<o`000008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Ko0000ogmoOomoOgoo0000
oiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0
003oOgmoo`000002ofIVIP03o`000?m<C4co000000Wo<c<c00?o0000oda<C?m<C4`00_l00002ogmo
O`05o`000?nIVIWo0000ok>c/ol000002Oo<c<`00ol0003o/k>co`000002oiVIV@07o`000?moOgoo
0000ofIVI_l0003oC4a<o`000003oc<c<`03o`000?oooooooooo00Kooooo000SoooooaKo/k>c00?o
0000oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00coIVIV00?o
0000oda<C?m<C4`01?m<C4`00ooo003oC4a<oda<C00?oda<C003o`000?mVIVKoIVIV00_oIVIV00?o
0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@05oiVIV@;o00005_nc/k<00ol0003oVIVIoiVI
V@02oiVIV@03o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<
C004oda<C003o`000?lc<c?o<c<c00?o<c<c00?o0000oda<C?m<C4`01?m<C4`01?l0003oIVIVofIV
I_l00003ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0003oc<c<olc<c005olc<c003
o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00003
oda<C003o`000?lc<c?o<c<c00Ko<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo
00Co0000oiVIVOnIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c009o`000?nc/k?o/k>cok>c
/ol0003oVIVIo`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<02_l0003oC4a<
oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Oo
0000ok>c/ol0003oVIVIo`000?moOgoo000000;oIVIV0_l00004oc<c<`03o`000?oooooooooo00Ko
oooo000SoooooaGo/k>c00?o0000oiVIVOnIVIT02onIVIT2o`0000[oOgmo00?o0000ofIVI_mVIVH0
2omVIVH2o`0000SoC4a<00?oo`00oda<C?m<C4`03Om<C4`00ol0003oIVIVofIVIP0;ofIVIP;o0000
2OmoOgl2o`0000SoVIVI00?o0000ok>c/onc/k<05?nc/k<00ol0003oVIVIoiVIV@02oiVIV@03o`00
0?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C005oda<C003o`00
0?lc<c?o<c<c00;o<c<c00?o0000oda<C?m<C4`01?m<C4`01Ol0003oIVIVofIVI_mVIVKo000000?o
Ogmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c005olc<c0;o00000onc/k<01Ol0
003oVIVIoiVIVOnIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo00000_m<C4`00ol0003o<c<coc<c
<`07oc<c<`07o`000?m<C4coC4a<oda<C?l0003oIVIVo`000002ogmoO`03o`000?nIVIWo000000?o
/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo0000
00;oIVIV00Co0000oda<C?m<C4co00002?lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo
0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00co0000ok>c/onc/k?o0000oiVIVOl0
003oOgmoo`000?mVIVKo0000oda<C?l00004oc<c<`03o`000?oooooooooo00Kooooo000SoooooaCo
/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_o
IVIV00?o0000oda<C?m<C4`02Om<C4`00ooo003oC4a<oda<C00;oda<C003o`000?mVIVKoIVIV00_o
IVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c01Co
/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00;o
IVIV00?o0000oda<C?m<C4`01Om<C4`00ol0003o<c<coc<c<`02oc<c<`03o`000?m<C4coC4a<00Co
C4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000
olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_mo
Ogl01?l0003oIVIVofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Oo0000oda<C?m<C4co
C4a<o`000?mVIVKo000000;oOgmo00?o0000oiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<
c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l0
0008oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00002Oo<
c<`01Ol0003o/k>cok>c/ol0003oVIVI00;o00000_mVIVH00ol0003oC4a<o`000004oc<c<`03o`00
0?oooooooooo00Kooooo000Soooooa?o/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmo
O`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`02om<C4`00ooo003oC4a<oda<
C009oda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVI
V@06oiVIV@03o`000?nc/k?o/k>c01Go/k>c00?o0000oiVIVOnIVIT00_nIVIT00ol0003oOgmoogmo
O`02ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01Om<C4`00ol0003o<c<coc<c
<`03oc<c<`03o`000?m<C4coC4a<00?oC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`04o`00
0?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`05
o`000?nIVIWoVIVIoiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00002oda<C003o`000?lc<c?o
<c<c00Oo<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo
00000_nc/k<00ol0003oc<c<olc<c006olc<c009o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000?mo
Ogoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`00
0?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00co0000ok>c/onc/k?o0000
oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00005oc<c<`03o`000?oooooooooo00Kooooo000S
oooooa;o/k>c00?o0000oiVIVOnIVIT02onIVIT2o`0000[oOgmo00?o0000ofIVI_mVIVH02omVIVH0
0ol0003oC4a<oda<C00=oda<C003ool00?m<C4coC4a<00OoC4a<00?o0000ofIVI_mVIVH02omVIVH2
o`0000[oOgmo00?o0000oiVIVOnIVIT01_nIVIT00ol0003o/k>cok>c/`0Eok>c/`03o`000?nIVIWo
VIVI00?oVIVI00Co0000ogmoOomoOgooOgmo0_l00004ofIVIP03o`000?m<C4coC4a<00CoC4a<00?o
0000oc<c<olc<c<00olc<c<00ol0003oC4a<oda<C004oda<C005o`000?mVIVKoIVIVofIVI_l00000
0_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o
/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`0
0ol0003o<c<coc<c<`07oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Ko0000ogmoOol0003o0000
oiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT01Ol0
003oOgmoo`000?mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc<c<02_l0003oC4a<oda<C?l0
003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00co0000ok>c
/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l00005oc<c<`03o`000?oooooooooo
00Kooooo000Soooooa7o/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmoO`03
o`000?mVIVKoIVIV00_oIVIV0_l0000@oda<C003ool00?m<C4coC4a<00GoC4a<00?o0000ofIVI_mV
IVH02omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc
/k<05_nc/k<00ol0003oVIVIoiVIV@03oiVIV@05o`000?moOgooOgmoogmoOol000001OmVIVH00ol0
003oC4a<oda<C004oda<C003o`000?lc<c?o<c<c00?o<c<c00?o0000oda<C?m<C4`01?m<C4`01?l0
003oIVIVofIVI_l00003ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0003oc<c<olc<
c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIV
ofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIV
IP03o`000?moOgoo000000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c004o`000?nc/k?o
/k>co`0000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c
00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<
c006olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co00001Olc
<c<00ol0003oooooooooo`06ooooo`008oooool@ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000
ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<017oC4a<00?oo`00
oda<C?m<C4`00om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000
oiVIVOnIVIT01onIVIT00ol0003o/k>cok>c/`0Eok>c/`03o`000?nIVIWoVIVI00?oVIVI00Go0000
ogmoOomoOgooOgmoo`000005ofIVIP03o`000?m<C4coC4a<00CoC4a<00?o0000oc<c<olc<c<00olc
<c<00ol0003oC4a<oda<C004oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01Ol0003oVIVI
oiVIVOnIVIWo000000Co/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`03ok>c/`04
o`000?nIVIWoVIVIo`0000;oOgmo00?o0000ofIVI_l000000om<C4`00ol0003o<c<coc<c<`07oc<c
<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT01Ol0003o/k>cok>c/onc
/k?o000000Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`00
0?m<C4coC4a<o`0000So<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000
0_nc/k<00ol0003oc<c<olc<c007olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo
000000;oC4a<00?o0000oc<c<olc<c<00olc<c<00ol0003oooooooooo`06ooooo`008oooool?ok>c
/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0;ofIV
IP03o`000?m<C4coC4a<01?oC4a<00Goo`00oda<C?m<C4coC4a<o`00000=ofIVIP03o`000?moOgoo
Ogmo00WoOgmo00?o0000oiVIVOnIVIT01onIVIT00ol0003o/k>cok>c/`0Eok>c/`03o`000?nIVIWo
VIVI00?oVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP02ofIVIP03o`000?m<C4co
C4a<00GoC4a<00?o0000oc<c<olc<c<00_lc<c<00ol0003oC4a<oda<C004oda<C005o`000?mVIVKo
IVIVofIVI_l000000omoOgl00ol0003oVIVIoiVIV@02o`0000?o/k>c00?o0000olc<c?o<c<`01_o<
c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo
00000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH00ol0
003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Woc<c<00Co0000ok>c/onc/k?o00000_nI
VIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01olc<c<03?l0003oC4a<
oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000[oc<c<00[o0000ok>c/ol0003o
VIVIo`000?moOgoo0000ofIVI_l0003oC4a<0_l00005oc<c<`03o`000?oooooooooo00Kooooo000S
ooooo`ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKo
IVIV00_oIVIV0_l0000Foda<C003ool00?m<C4co000000koIVIV00?o0000ogmoOomoOgl02?moOgl0
0ol0003oVIVIoiVIV@08oiVIV@03o`000?nc/k?o/k>c01Go/k>c00?o0000oiVIVOnIVIT00onIVIT0
0ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01Om<C4`0
1Ol0003o<c<coc<c<olc<c?o000000OoC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`04o`00
0?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003o/k>cok>c/`02ok>c/`04
o`000?nIVIWoVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06
oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc
/k?o/k>co`0000Woc<c<00Co0000ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mVIVKo0000
00;oC4a<00?o0000oc<c<olc<c<01olc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000
oiVIVOl0003o/k>co`0000[oc<c<00_o0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003o
C4a<o`000006oc<c<`03o`000?oooooooooo00Kooooo000Sooooo`go/k>c00?o0000oiVIVOnIVIT0
2onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`0
5om<C4`00ooo003oIVIVofIVIP0<ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT0
2?nIVIT00ol0003o/k>cok>c/`0Eok>c/`03o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl0
0_moOgl00ol0003oIVIVofIVIP02ofIVIP03o`000?m<C4coC4a<00GoC4a<00?o0000oc<c<olc<c<0
0_lc<c<00ol0003oC4a<oda<C004oda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01?l0003o
VIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0
003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01olc
<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o
00002Oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgooOgmo00;o00000_m<C4`00ol0
003o<c<coc<c<`07oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o
/k>c00?o0000olc<c?o<c<`01oo<c<`02ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`00
0?m<C4co000000Oo<c<c00?o0000ooooooooool01_ooool002?ooooo3?nc/k<00ol0003oVIVIoiVI
V@0;oiVIV@03o`000?moOgooOgmo00SoOgmo0_l0000=ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o
0000ofIVI_oo00002omVIVH2o`0000[oOgmo00?o0000oiVIVOnIVIT02?nIVIT00ol0003o/k>cok>c
/`0Eok>c/`03o`000?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIV
IP02ofIVIP03o`000?m<C4coC4a<00GoC4a<00?o0000oc<c<olc<c<00_lc<c<00ol0003oC4a<oda<
C004oda<C0;o00000omVIVH01?l0003oOgmoogmoOol00003oiVIV@03o`000?nc/k?o/k>c00;o/k>c
00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000?oVIVI00Co0000ogmoOomo
Ogoo00000_mVIVH01?l0003oC4a<oda<C?l0000:oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o
0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00009olc<c004o`000?nc/k?o/k>co`0000;o
VIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00[o0000oda<
C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c00<
o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co00001olc<c<00ol0003o
ooooooooo`06ooooo`008oooool;ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl0
2?moOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<01OoC4a<00Go0000ofIVI_mVIVKo
IVIVool0000:ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02OnIVIT00ol0003o
/k>cok>c/`0Dok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003o
IVIVofIVIP02ofIVIP03o`000?m<C4coC4a<00GoC4a<00?o0000oc<c<olc<c<00_lc<c<00ol0003o
C4a<oda<C004oda<C003o`000?mVIVKoIVIV00;oIVIV00Co0000ogmoOomoOgoo00000onIVIT00ol0
003o/k>cok>c/`02ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000003
oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Co0000oda<C?m<C4co00002_lc<c<01?l0003oC4a<
oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`01?l0
003o/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c
<`07oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000
olc<c?o<c<`01_o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<
o`0000Oo<c<c00?o0000ooooooooool01_ooool002?ooooo2_nc/k<00ol0003oVIVIoiVIV@0;oiVI
V@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH03?mVIVH00ol0003oC4a<oda<C00Goda<
C003o`000?mVIVKoIVIV00?oIVIV00?oo`00ofIVI_mVIVH01_mVIVH00ol0003oOgmoogmoO`08ogmo
O`03o`000?nIVIWoVIVI00WoVIVI00?o0000ok>c/onc/k<05?nc/k<00ol0003oVIVIoiVIV@04oiVI
V@03o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C006oda<
C005o`000?lc<c?o<c<coc<c<ol000001_m<C4`00ol0003oIVIVofIVIP02ofIVIP04o`000?moOgoo
Ogmoo`0000?oVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c005olc<c005o`000?nc
/k?o/k>cok>c/ol000000onIVIT01?l0003oOgmoogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<
C?l000002Olc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00Go0000
ok>c/onc/k?o/k>co`000008olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Go0000ogmoOol0003o
IVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003o
Ogmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c007olc<c009o`000?nc/k?o0000oiVIVOl0
003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oooooooooo`06
ooooo`008oooool9ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0
003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH01OmVIVH00ooo
003oIVIVofIVIP03ofIVIP;o00002_moOgl00ol0003oVIVIoiVIV@09oiVIV@03o`000?nc/k?o/k>c
01Go/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV
00;oIVIV00?o0000oda<C?m<C4`01_m<C4`01Ol0003o<c<coc<c<olc<c?o000000OoC4a<00Go0000
ofIVI_mVIVKoIVIVo`000003ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0003oc<c<
olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00?o0000oiVIVOnIVIT00_l000000omoOgoo0000
ofIVIP02ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01ol0003oC4a<oda<C?m<C4co0000
ofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Ko
0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc
<c<01olc<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`00
0?o<c<coc<c<00Koc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<
C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?oooooooooo00Kooooo000Sooooo`So/k>c00?o0000
oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000
oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP07ofIVIP05ool00?mVIVKoIVIVofIVI_l000002omo
Ogl00ol0003oVIVIoiVIV@09oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT00onI
VIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01_m<
C4`01Ol0003o<c<coc<c<olc<c?o000000OoC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`04
o`000?nIVIWoVIVIo`0000Go/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c
/`04o`000?nIVIWoVIVIo`0000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000003oda<C003o`000?lc
<c?o<c<c00Ko<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00Co0000oiVIVOnI
VIWo00000_nc/k<00ol0003oc<c<olc<c007olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_mo
Ogl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00[o0000oda<C?m<C4co0000
ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c00:o`000?nc/k?o
/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0
003oooooooooo`06ooooo`008oooool7ok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomo
Ogl02?moOgl00ol0003oIVIVofIVIP06ofIVIP;oo`001?mVIVH00ol0003oC4a<oda<C00Goda<C003
o`000?mVIVKoIVIV00SoIVIV00?oo`00ofIVI_l000002omoOgl00ol0003oVIVIoiVIV@0:oiVIV@03
o`000?nc/k?o/k>c01Go/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`02ogmoO`03
o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<C4`01_m<C4`01Ol0003o<c<coc<c<olc<c?o0000
00KoC4a<00?o0000ofIVI_mVIVH00_mVIVH01?l0003oOgmoogmoOol00003oiVIV@03o`000?nc/k?o
/k>c00?o/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`04o`000?nIVIWo
VIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`07oc<c<`04o`00
0?m<C4coC4a<o`0000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01?l0003o/k>cok>c/ol00009
olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl00ol0003oIVIVo`000002oda<C003o`00
0?lc<c?o<c<c00Oo<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc
/k<00ol0003oc<c<olc<c006olc<c003o`000?nc/k?o/k>c00;o00000_moOgl00ol0003oIVIVo`00
0002oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000ooooooooool01_ooool002?ooooo1_nc/k<0
0ol0003oVIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02OmVIVH0
1?oo003oIVIVofIVI_l0000Ioda<C003o`000?mVIVKoIVIV00[oIVIV00?oo`00ogmoOomoOgl02_mo
Ogl00ol0003oVIVIoiVIV@09oiVIV@03o`000?nc/k?o/k>c01Go/k>c00?o0000oiVIVOnIVIT01?nI
VIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01_m<
C4`01Ol0003o<c<coc<c<olc<c?o000000OoC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`04
o`000?nIVIWoVIVIo`0000Go/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c
/`04o`000?nIVIWoVIVIo`0000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000003oda<C003o`000?lc
<c?o<c<c00Ko<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00Co0000oiVIVOnI
VIWo00000_nc/k<00ol0003oc<c<olc<c007olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_mo
Ogl01_l0003oIVIVofIVI_l0003oC4a<o`0000Wo<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003o
Ogmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c007olc<c009o`000?nc/k?o0000oiVIVOl0
003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<00ol0003oooooooooo`06
ooooo`008oooool5ok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl02?moOgl00ol0
003oIVIVofIVIP0;ofIVIP03ool00?l0003oC4a<01SoC4a<00?o0000ofIVI_mVIVH02_mVIVH2o`00
0003ool00?moOgooOgmo00OoOgmo0_l0000;oiVIV@03o`000?nc/k?o/k>c01Go/k>c00?o0000oiVI
VOnIVIT01?nIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<
C?m<C4`01_m<C4`01?l0003o<c<coc<c<ol00007oda<C003o`000?mVIVKoIVIV00;oIVIV00Co0000
ogmoOomoOgoo00000onIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o
0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000?o
C4a<00?o0000oc<c<olc<c<01olc<c<01?l0003oC4a<oda<C?l00002ofIVIP04o`000?moOgooOgmo
o`0000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;o
Ogmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`0:o`000?m<C4coC4a<o`00
0?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01oo<c<`02_l0003o/k>c
o`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4`2o`0000So<c<c00?o0000ooooooooool01_oo
ool002?ooooo1?nc/k<00ol0003oVIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000
ofIVI_mVIVH03?mVIVH00ol0003oo`00oda<C00Foda<C0;o00003?mVIVH01Ol0003oOgmoogmoOomo
Ogooo`0000OoOgmo00?o0000oiVIVOnIVIT02_nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nI
VIWoVIVI00CoVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP02ofIVIP03o`000?m<
C4coC4a<00KoC4a<00Go0000oda<C?l0003o<c<co`000007oda<C005o`000?mVIVKoIVIVofIVI_l0
00000omoOgl01Ol0003oVIVIoiVIVOnIVIWo000000Co/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0
003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo00000om<
C4`00ol0003o<c<coc<c<`07oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Co0000ogmoOomoOgoo
00000_nIVIT01?l0003o/k>cok>c/ol00009olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_mo
Ogl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00[o0000oda<C?m<C4co0000
ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c007olc<c00;o`000?nc/k?o
0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l000002Olc<c<00ol0003oooooooooo`06oooo
o`008oooool3ok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003o
IVIVofIVIP0<ofIVIP04o`000?m<C4coC4a<ool001GoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0
003oOgmoogmoO`03ogmoO`03ool00?moOgooOgmo00?oOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0
003o/k>cok>c/`0Eok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl00_moOgl00ol0
003oIVIVofIVIP02ofIVIP03o`000?m<C4coC4a<00OoC4a<0_l000000om<C4co0000oda<C006oda<
C003o`000?mVIVKoIVIV00;oIVIV00Co0000ogmoOomoOgoo00000onIVIT00ol0003o/k>cok>c/`02
ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl0
0002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01olc<c<01?l0003oC4a<
oda<C?l00002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`0
1_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<c
oc<c<`07oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o
0000olc<c?o<c<`01oo<c<`02ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co
000000Wo<c<c0_l00008ooooo`008oooool2ok>c/`03o`000?nIVIWoVIVI00_oVIVI0_l0000:ogmo
O`03o`000?mVIVKoIVIV00_oIVIV0_l00004oda<C003ool00?m<C4coC4a<017oC4a<00?o0000ofIV
I_mVIVH02omVIVH2o`0000KoOgmo00Goo`00ogmoOomoOgooOgmoo`00000=oiVIV@03o`000?nc/k?o
/k>c01Go/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKo
IVIV00;oIVIV00?o0000oda<C?m<C4`01_m<C4`01?l0003o<c<coc<c<ol00008oda<C005o`000?mV
IVKoIVIVofIVI_l000000omoOgl01Ol0003oVIVIoiVIVOnIVIWo000000Co/k>c00?o0000olc<c?o<
c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`03o`000?nIVIWoVIVI00;o00000_moOgl01?l0003o
IVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002
ofIVIP05o`000?moOgooOgmoo`000?nIVIT00_l00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Oo
0000ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o
<c<coc<c<`07oc<c<`03o`000?m<C4co000000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c
/`03o`000?o<c<coc<c<00Koc<c<00co0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo
0000oda<C?l00009oc<c<`;o00002?ooool002?ooooo00?o/k>co`000?nIVIT03?nIVIT00ol0003o
OgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`01Om<C4`00ooo003o
C4a<oda<C00?oda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl01omoOgl00ooo003o
Ogmoo`00000>oiVIV@03o`000?nc/k?o/k>c01Co/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0003o
OgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<C4`01_m<C4`01?l0003o
<c<coc<c<ol00007oda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgooOgmoo`000002
oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02
ok>c/`04o`000?nIVIWoVIVIo`0000?oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<c
oc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH00ol0003oOgmoo`000002oiVIV@04
o`000?nc/k?o/k>co`0000Woc<c<00Co0000ok>c/onc/k?o00000_nIVIT01_l0003oOgmoogmoOol0
003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01olc<c<00ol0003oC4a<o`000002ofIVIP05o`00
0?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c00<o`000?nc/k?o/k>co`00
0?nIVIWo0000ogmoOol0003oIVIVo`000?m<C4co00002Olc<c<2o`0000Sooooo000Sooooo`03o`00
0?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`00
0?m<C4coC4a<00OoC4a<00?oo`00oda<C?m<C4`03Om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`00
0?moOgooOgmo00WoOgmo00?oo`00oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`0Eok>c/`03o`00
0?nIVIWoVIVI00?oVIVI00?o0000ogmoOomoOgl01?moOgl00ol0003oIVIVofIVIP02ofIVIP03o`00
0?m<C4coC4a<00KoC4a<00Co0000oc<c<olc<c?o00001om<C4`00ol0003oIVIVofIVIP02ofIVIP05
o`000?moOgooOgmoogmoOol000000onIVIT00ol0003o/k>cok>c/`02ok>c/`03o`000?o<c<coc<c<
00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00003ogmoO`04o`000?mVIVKo
IVIVo`0000?oC4a<00?o0000oc<c<olc<c<01olc<c<01?l0003oC4a<oda<C?l00002ofIVIP06o`00
0?moOgooOgmoo`000?nIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c007o`000?nc/k?o/k>c
ok>c/ol0003oVIVIo`000002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01olc
<c<02_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<co
c<c<00Ooc<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o
<c<coc<c<`06oc<c<`03o`000?m<C4co000000Sooooo000Sooooo`goVIVI00?o0000ogmoOomoOgl0
2OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<00WoC4a<00?oo`00oda<C?m<C4`0
2om<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOoo0000
2onIVIT2o`0001Oo/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`03ogmoO`03o`00
0?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01om<C4`3o`0000SoC4a<00?o0000ofIVI_mVIVH0
0_mVIVH01?l0003oOgmoogmoOol00003oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<
c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000?oOgmo00Co0000ofIV
I_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mV
IVH01_l0003oOgmoogmoOol0003oVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`02Ol0003o
/k>cok>c/onc/k?o0000oiVIVOl0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c
00Co0000oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<
c?o<c<`01_o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003
o`000?lc<c?o<c<c00Ko<c<c00?o0000oda<C?l000002?ooool002?ooooo3?nIVIT00ol0003oOgmo
ogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV0_l0000<oda<C003ool00?m<C4coC4a<00WoC4a<
00?o0000ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmoO`08ogmoO`05o`000?nIVIWoVIVIoiVIVOoo
00002OnIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00GoVIVI00?o0000ogmoOomo
Ogl00omoOgl00ol0003oIVIVofIVIP02ofIVIP03o`000?m<C4coC4a<00WoC4a<00?o0000oda<C?m<
C4`01_m<C4`00ol0003oIVIVofIVIP02ofIVIP04o`000?moOgooOgmoo`0000?oVIVI00?o0000ok>c
/onc/k<00onc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVI
VOnIVIWo00000omoOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go
0000oda<C?m<C4coC4a<o`000002ofIVIP06o`000?moOgooOgmoo`000?nIVIWo00000onc/k<00ol0
003oc<c<olc<c006olc<c009o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000?moOgoo000000;oIVIV
00Co0000oda<C?m<C4co00002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP05o`000?moOgoo0000
oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000
ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<00ol0003oC4a<o`000008oooo
o`008oooool;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003o
C4a<oda<C00=oda<C003ool00?m<C4coC4a<00OoC4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003o
OgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?oo`00oiVIVOnIVIT01OnIVIT00ol0003o
/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00GoVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003o
IVIVofIVIP02ofIVIP03o`000?m<C4coC4a<01;oC4a<00?o0000ofIVI_mVIVH00_mVIVH01?l0003o
OgmoogmoOol00003oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0
003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000?oOgmo00Co0000ofIVI_mVIVKo00000om<
C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01_l0003oOgmo
ogmoOol0003oVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`02Ol0003o/k>cok>c/onc/k?o
0000oiVIVOl0003oOgmoo`000003ofIVIP04o`000?m<C4coC4a<o`0000Oo<c<c00Co0000oda<C?m<
C4co00000_mVIVH00ol0003oOgmoo`000002oiVIV@03o`000?nc/k?o000000Soc<c<00[o0000ok>c
/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`04
o`000?m<C4coC4a<o`0000Sooooo000Sooooo`[oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003o
IVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<00ooC4a<00?oo`00oda<C?m<C4`01Om<C4`00ol0003o
IVIVofIVIP0;ofIVIP;o00002_moOgl00ol0003oVIVIoiVIV@05oiVIV@03ool00?nIVIWoVIVI00?o
VIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@05oiVIV@03o`000?moOgooOgmo00?o
Ogmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C00Coda<C005o`000?mVIVKoIVIVofIV
I_l000000omoOgl01Ol0003oVIVIoiVIVOnIVIWo000000Go/k>c00?o0000olc<c?o<c<`01?o<c<`0
0ol0003o/k>cok>c/`03ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo0000
0om<C4`00ol0003o<c<coc<c<`07oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH00ol0003o
Ogmoo`000002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01?l0003o/k>cok>c/ol00002
oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<01?l0003oC4a<oda<
C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c00:
o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<0
1_lc<c<01?l0003oC4a<o`000?l00008ooooo`008oooool9oiVIV@03o`000?moOgooOgmo00WoOgmo
00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Aoda<C003ool00?m<C4coC4a<00?oC4a<
00?o0000ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00OoVIVI
00Goo`00oiVIVOnIVIWoVIVIo`00000Iok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomo
Ogl01?moOgl00ol0003oIVIVofIVIP02ofIVIP03o`000?m<C4coC4a<01?oC4a<00Go0000ofIVI_mV
IVKoIVIVo`000003ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0003oc<c<olc<c005
olc<c003o`000?nc/k?o/k>c00;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`04o`000?mV
IVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01olc<c<01Ol0003oC4a<oda<C?m<C4co000000;o
IVIV00?o0000ogmoOol000000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Co0000ok>c
/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Co
0000oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<
c<`01_o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000Wo
<c<c00Co0000oda<C?l0003o00002?ooool002?ooooo2?nIVIT00ol0003oOgmoogmoO`09ogmoO`03
o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`04om<C4`01Ooo003oC4a<oda<C?m<C4co0000
00koIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@09oiVIV@03ool00?nIVIWo0000
01Wo/k>c00?o0000oiVIVOnIVIT01OnIVIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV
00;oIVIV00?o0000oda<C?m<C4`04om<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Go0000
oiVIVOnIVIWoVIVIo`000005ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00onc
/k<01?l0003oVIVIoiVIVOl00002ogmoO`05o`000?mVIVKoIVIVofIVI_l000000om<C4`00ol0003o
<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH00ol0003oOgmoo`000002oiVI
V@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?mo
Ogoo000000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<00ol0003oC4a<o`000002ofIVIP05o`00
0?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`00
00;oVIVI0_l000001OmVIVKo0000oda<C?m<C4co000000So<c<c00Go0000oda<C?l0003oIVIVo`00
0008ooooo`008oooool7oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH0
0ol0003oC4a<oda<C00Eoda<C003ool00?m<C4co000000goIVIV0_l0000:ogmoO`03o`000?nIVIWo
VIVI00_oVIVI00?oo`00ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@05oiVIV@03o`000?moOgoo
Ogmo00?oOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00Boda<C005o`000?mVIVKo
IVIVofIVI_l000000omoOgl01Ol0003oVIVIoiVIVOnIVIWo000000Go/k>c00?o0000olc<c?o<c<`0
1Oo<c<`00ol0003o/k>cok>c/`02ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01?l0003o
IVIVofIVI_l00004oda<C003o`000?lc<c?o<c<c00Go<c<c00Go0000oda<C?m<C4coC4a<o`000002
ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c004o`00
0?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00009oc<c
<`03o`000?m<C4co000000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<co
c<c<00Koc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0
003o<c<coc<c<`06oc<c<`05o`000?m<C4co0000ofIVI_l000002?ooool002?ooooo1_nIVIT2o`00
00[oOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Goda<C003ool00?mVIVKoIVIV
00coIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?oo`00
01Oo/k>c0_l00007oiVIV@03o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH01?mVIVH00ol0
003oC4a<oda<C00Boda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01Ol0003oVIVIoiVIVOnI
VIWo000000Go/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`05o`000?nI
VIWoVIVIoiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00004oda<C003o`000?lc<c?o<c<c00Go
<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Co0000
ok>c/onc/k?o00002Oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV
00Co0000oda<C?m<C4co00002Olc<c<00ol0003oC4a<o`000002ofIVIP05o`000?moOgoo0000oiVI
VOl000000_nc/k<00ol0003oc<c<olc<c006olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmo
Ool0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<o`000?mVIVKo0000
00Sooooo000Sooooo`GoVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03
o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_oo00003?mVIVH00ol0003oOgmoogmoO`08ogmoO`03
o`000?nIVIWoVIVI00_oVIVI00Go0000ok>c/onc/k?o/k>cool0000Eok>c/`03o`000?nIVIWoVIVI
00KoVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP04ofIVIP03o`000?m<C4coC4a<
01;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001Onc
/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Go0000oiVIVOnIVIWoVIVI
o`000002ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003o
C4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00?o0000oiVIVOl000000onc/k<00ol0
003oc<c<olc<c006olc<c009o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000?moOgoo000000;oIVIV
00Co0000oda<C?m<C4co00002Olc<c<00ol0003oC4a<o`000002ofIVIP05o`000?moOgoo0000oiVI
VOl000000_nc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>cok>c/`;o000000OoOgmo
o`000?mVIVKoIVIVo`000?m<C4co000000So<c<c00?o0000oda<C?l000000_mVIVH00ol0003ooooo
ooooo`06ooooo`008oooool4oiVIV@03o`000?moOgooOgmo00SoOgmo0_l0000=ofIVIP03o`000?m<
C4coC4a<01OoC4a<00Go0000ofIVI_mVIVKoIVIVool00009ofIVIP;o00002_moOgl00ol0003oVIVI
oiVIV@0;oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?oo`00ok>c/onc/k<04Onc/k<00ol0003oVIVI
oiVIV@06oiVIV@03o`000?moOgooOgmo00?oOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<
oda<C00Boda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgooOgmoo`000003oiVIV@03
o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`04
o`000?nIVIWoVIVIo`0000?oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06
oc<c<`04o`000?m<C4coC4a<oda<C0;o000000GoIVIVo`000?moOgooOgmoo`000002oiVIV@04o`00
0?nc/k?o/k>co`0000Woc<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIV
IP04o`000?m<C4coC4a<o`0000So<c<c00Co0000oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`00
0?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`03?l0003o/k>cok>c/ol0003oVIVIo`00
0?moOgoo0000ofIVI_l0003oC4a<o`0000Wo<c<c00Co0000oda<C?l0003oIVIV0_l00008ooooo`00
6?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo1?nIVIT00ol0003oOgmoogmoO`08ogmoO`03
o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP03ofIVIP03
ool00?mVIVKoIVIV00GoIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0<oiVIV@03
o`000?nc/k?o/k>c00Co/k>c00?oo`00ok>c/onc/k<04?nc/k<00ol0003oVIVIoiVIV@06oiVIV@03
o`000?moOgooOgmo00?oOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00Boda<C003
o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgooOgmoo`000003oiVIV@03o`000?nc/k?o/k>c
00?o/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`04o`000?nIVIWoVIVI
o`0000?oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<
C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@04o`000?nc/k?o/k>co`00
00Woc<c<00Co0000ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000?oC4a<00?o
0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl0
00000_nc/k<00ol0003oc<c<olc<c006olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0
003oIVIVo`000?m<C4co00002Olc<c<01?l0003oC4a<o`000?mVIVH2o`0000Sooooo000Hooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01_ooool3oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIV
I_mVIVH03?mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00GoIVIV00?oo`00ofIV
I_mVIVH00omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00coVIVI00?o0000ok>c
/onc/k<01_nc/k<00ooo003o/k>cok>c/`0?ok>c/`03o`000?nIVIWoVIVI00GoVIVI00?o0000ogmo
OomoOgl00omoOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<01;oC4a<00?o0000ofIV
I_mVIVH00_mVIVH00ol0003oOgmoogmoO`02ogmoO`04o`000?nIVIWoVIVIo`0000Go/k>c00?o0000
olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000?oOgmo00Go
0000ofIVI_mVIVKoIVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4co
C4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`0
1?l0003o/k>cok>c/ol00002oiVIV@;o00000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c
00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`05o`000?nIVIWo0000ok>c/ol000002Oo<c<`0
3?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`0000Wo<c<c00Co0000
oda<C?l0003oIVIV0_l00008ooooo`006?ooool01Ol@413ooooooooooooooooo410@00Kooooo0_nI
VIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00coIVIV00?o0000oda<C?m<C4`05_m<
C4`00ol0003oIVIVofIVIP07ofIVIP05ool00?mVIVKoIVIVofIVI_l000002omoOgl00ol0003oVIVI
oiVIV@0<oiVIV@03o`000?nc/k?o/k>c00So/k>c00?oo`00ok>c/onc/k<03Onc/k<00ol0003oVIVI
oiVIV@05oiVIV@03o`000?moOgooOgmo00CoOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<
oda<C00Boda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgooOgmoo`000003oiVIV@03
o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`04
o`000?nIVIWoVIVIo`0000?oOgmo00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06
oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@04o`00
0?nc/k?o/k>co`0000Woc<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIV
IP04o`000?m<C4coC4a<o`0000So<c<c00Co0000oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`00
0?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`00
0?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00?o0000oda<C?m<C4`00_l0
00000omoOgoo0000ooooo`07ooooo`006?ooool01Ol0003ooooooooooooooooo000000Kooooo0_l0
000:ogmoO`03o`000?mVIVKoIVIV00_oIVIV0_l0000Hoda<C003o`000?mVIVKoIVIV00WoIVIV00Co
o`00ofIVI_l0003o00002_moOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c00[o/k>c
00?oo`00ok>c/onc/k<02_nc/k<2o`0000OoVIVI00?o0000ogmoOomoOgl00omoOgl2o`0000GoIVIV
00?o0000oda<C?m<C4`04_m<C4`00ol0003oIVIVofIVIP02ofIVIP05o`000?moOgooOgmoogmoOol0
00000onIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc
/k<00_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00?o0000ofIVI_mVIVH00_l00003oda<
C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgoo
Ogmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@03
o`000?moOgoo000000;oIVIV00?o0000oda<C?l000002Olc<c<01_l0003oC4a<oda<C?l0003oIVIV
o`0000;oOgmo00Go0000oiVIVOl0003o/k>co`000009olc<c00:o`000?nc/k?o/k>co`000?nIVIWo
0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<00ol0003oC4a<oda<C002
o`000003ogmoOol0003ooooo00Oooooo000Hooooo`05o`000?ooooooooooooooool000001_ooool;
ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0;
ofIVIP03ool00?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`0<
ok>c/`03ool00?nc/k?o/k>c00So/k>c00?o0000oiVIVOnIVIT01onIVIT00ol0003oOgmoogmoO`03
ogmoO`03o`000?mVIVKoIVIV00CoIVIV00?o0000oda<C?m<C4`04_m<C4`00ol0003oIVIVofIVIP02
ofIVIP05o`000?moOgooOgmoogmoOol000000onIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<
c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo
00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;o
C4a<00Co0000ofIVI_mVIVKo00000_moOgl00ol0003oVIVIo`000003ok>c/`03o`000?o<c<coc<c<
00Ooc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`06o`000?mVIVKoIVIVo`000?m<C4co
00002Olc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00Go0000oiVIVOl0003o/k>co`00
0009olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000
oc<c<olc<c<01_lc<c<00ol0003oC4a<oda<C002o`000003ogmoOol0003ooooo00Oooooo000Hoooo
o`05oa0@4?ooooooooooooooool@41001_ooool:ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000
oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooo`0000WoOgmo00?o0000
oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`0>ok>c/`03ool00?nc/k?o/k>c00Oo/k>c00?o0000
oiVIVOnIVIT01_nIVIT00ol0003oOgmoogmoO`03ogmoO`03o`000?mVIVKoIVIV00CoIVIV00?o0000
oda<C?m<C4`04_m<C4`00ol0003oIVIVofIVIP02ofIVIP05o`000?moOgooOgmoogmoOol000000onI
VIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc
/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o
<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002
oiVIV@04o`000?nc/k?o/k>co`0000Woc<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmo
o`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002
ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol0
0002oiVIV@;o000000GoIVIVo`000?m<C4coC4a<o`000009oc<c<`04o`000?m<C4co0000o`0000;o
Ogmo00?o0000ooooooooool01_ooool001Sooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`Wo
Ogmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00_o
IVIV0_l00002ogmoO`03ool00?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT02onIVIT2o`0001;o
/k>c00?oo`00ok>c/onc/k<01?nc/k<2o`0000SoVIVI00?o0000ogmoOomoOgl01?moOgl00ol0003o
IVIVofIVIP03ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH00_mVIVH00ol0003o
OgmoogmoO`02o`0000?oVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c004olc<c003
o`000?nc/k?o/k>c00?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`04o`000?mVIVKoIVIV
o`0000CoC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Ko
0000ogmoOomoOgoo0000oiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Oo0000ok>c/onc
/k?o/k>co`000?nIVIWo000000;oOgmo00?o0000ofIVI_l000000om<C4`00ol0003o<c<coc<c<`06
oc<c<`05o`000?m<C4coC4a<o`000?mVIVH00_l000001?moOgoo0000oiVIVOl00002ok>c/`03o`00
0?o<c<coc<c<00Koc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<
C4`00ol0003o<c<coc<c<`06oc<c<`03o`000?m<C4coC4a<00;o000000?oOgmoo`000?l000002?oo
ool001Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`SoOgmo00?o0000ofIVI_mVIVH02omV
IVH2o`0001SoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`03ogmoO`03ool00?mo
OgooOgmo00?oOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Cok>c/`;oo`000onc
/k<00ol0003oVIVIoiVIV@08oiVIV@03o`000?moOgooOgmo00?oOgmo00?o0000ofIVI_mVIVH01?mV
IVH00ol0003oC4a<oda<C00Coda<C003o`000?mVIVKoIVIV00;oIVIV00Co0000ogmoOomoOgoo0000
1?nIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<0
0onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0
003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000?oIVIV00Ko0000ogmoOomoOgoo0000oiVI
VOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo0000
00;oOgmo00?o0000ofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`06o`000?m<C4coC4a<
o`000?mVIVKo00000_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o
0000ok>c/ol000000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<0
1_lc<c<00ol0003oC4a<oda<C002o`000003ogmoOol0003o000000Sooooo000Sooooo`OoOgmo00?o
0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00_oIVIV00?o
0000ogmoOomoOgl01OmoOgl01Ooo003oOgmoogmoOomoOgoo000000goVIVI00?o0000ok>c/onc/k<0
5_nc/k<01?oo003o/k>cok>c/ol00009oiVIV@03o`000?moOgooOgmo00?oOgmo00?o0000ofIVI_mV
IVH01?mVIVH00ol0003oC4a<oda<C00Coda<C003o`000?mVIVKoIVIV00;oIVIV00Co0000ogmoOomo
Ogoo00001?nIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c
/onc/k<00onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo00001?m<
C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01_l0003oOgmo
ogmoOol0003oVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01ol0003o/k>cok>c/onc/k?o
0000oiVIVOl000000_moOgl00ol0003oIVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Ko
0000oda<C?m<C4co0000ofIVI_l00002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<
c<`01_o<c<`02?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo00000_mVIVH00ol0003oC4a<o`00
0009oc<c<`04o`000?m<C4co0000ofIVIP;o000000?oVIVIo`000?ooool01oooool002?ooooo1_mo
Ogl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02omV
IVH00ol0003oOgmoogmoO`06ogmoO`04ool00?moOgooOgmoo`0000goVIVI00?o0000ok>c/onc/k<0
6?nc/k<00ooo003o0000oiVIV@08oiVIV@03o`000?moOgooOgmo00CoOgmo00?o0000ofIVI_mVIVH0
0omVIVH00ol0003oC4a<oda<C00Coda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgoo
Ogmoo`000003oiVIV@;o00001?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00?o
/k>c00Co0000oiVIVOnIVIWo00000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000?oC4a<00?o0000
oc<c<olc<c<01olc<c<01?l0003oC4a<oda<C?l00002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI
00Go0000ok>c/onc/k?o/k>co`000008olc<c007o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000002
ogmoO`03o`000?mVIVKo000000;oC4a<0_l00008oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo0000
0_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00co0000ok>c/onc/k?o
0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l0000:oc<c<`04o`000?m<C4co0000ofIVIP;o
000000?oVIVIo`000?ooool01oooool002?ooooo1OmoOgl00ol0003oIVIVofIVIP0;ofIVIP;o0000
6?m<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?moOgooOgmo00OoOgmo00?oo`00ogmoOol00000
3?nIVIT00ol0003o/k>cok>c/`0Iok>c/`03o`000?oo003oo`0000SoVIVI00?o0000ogmoOomoOgl0
1?moOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH0
0_mVIVH01Ol0003oOgmoogmoOomoOgoo000000?oVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003o
c<c<olc<c004olc<c003o`000?nc/k?o/k>c00Co/k>c00Co0000oiVIVOnIVIWo00000_moOgl01Ol0
003oIVIVofIVI_mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01olc<c<01?l0003oC4a<oda<C?l0
0002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c007
o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000
oc<c<olc<c<01olc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00?o0000oiVIVOl00000
0_nc/k<00ol0003oc<c<olc<c006olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003o
IVIVo`000?m<C4co00002_lc<c<01?l0003oC4a<o`000?mVIVH2o`000003oiVIVOl0003ooooo00Oo
oooo000Sooooo`CoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Goda<C003o`00
0?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oo`00oiVIV@0;oiVIV@03o`00
0?nc/k?o/k>c01So/k>c0_l00003oiVIV@03ool00?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl0
1?moOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH0
0_mVIVH01Ol0003oOgmoogmoOomoOgoo000000?oVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003o
c<c<olc<c005olc<c003o`000?nc/k?o/k>c00?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmo
O`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01olc<c<01?l0003oC4a<oda<C?l0
0002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c007
o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000
oc<c<olc<c<01olc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00Ko0000oiVIVOnIVIWo
0000ok>c/ol00008olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl2o`0000;oC4a<00?o
0000oc<c<olc<c<01olc<c<01?l0003oC4a<o`000?mVIVH2o`0000;oVIVI00?o0000ooooooooool0
1_ooool002?ooooo0omoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o
0000ofIVI_mVIVH02omVIVH2o`0000[oOgmo00Co0000oiVIVOnIVIWoo`002_nIVIT00ol0003o/k>c
ok>c/`0Hok>c/`03o`000?nIVIWoVIVI00CoVIVI00Coo`00oiVIVOnIVIWoVIVI0_l00006ogmoO`03
o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<C4`04om<C4`00ol0003oIVIVofIVIP02ofIVIP05
o`000?moOgooOgmoogmoOol000001?nIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<
00Coc<c<00?o0000ok>c/onc/k<00onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Go0000
ofIVI_mVIVKoIVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<
o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<
c004o`000?nc/k?o/k>co`0000;oVIVI00Ko0000ogmoOomoOgoo0000ofIVI_l00002oda<C003o`00
0?lc<c?o<c<c00Oo<c<c00So0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000;oVIVI00?o0000
ok>c/ol000002Oo<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<
C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4co0000ofIVIP02o`000003oiVIVOl0003o
000000Sooooo000Sooooo`;oOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Goda<
C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@02oiVI
V@03ool00?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc/k<05onc/k<2o`0000SoVIVI0_oo00000onI
VIWo0000ogmoO`05ogmoO`03o`000?mVIVKoIVIV00CoIVIV00?o0000oda<C?m<C4`04om<C4`00ol0
003oIVIVofIVIP02ofIVIP05o`000?moOgooOgmoogmoOol000001?nIVIT00ol0003o/k>cok>c/`03
ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00onc/k<01Ol0003oVIVIoiVIVOnI
VIWo000000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c
00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Go0000ok>c
/onc/k?o/k>co`000007olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01_l0003oOgmoogmo
Ool0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01olc<c<02?l0003oC4a<oda<C?l0003oIVIV
o`000?moOgoo00000_nIVIT00ol0003o/k>co`000009olc<c00:o`000?nc/k?o/k>co`000?nIVIWo
0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?l0
003oIVIV00;o000000?oVIVIo`000?l000002?ooool002?ooooo00?oOgmoo`000?mVIVH03?mVIVH0
0ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl02?moOgl0
0ol0003oVIVIoiVIV@04oiVIV@03ool00?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<05onc/k<0
0ol0003oVIVIoiVIV@0:oiVIV@03ool00?moOgooOgmo00CoOgmo00?o0000ofIVI_mVIVH01?mVIVH0
0ol0003oC4a<oda<C00Doda<C005o`000?mVIVKoIVIVofIVI_l000001?moOgl01Ol0003oVIVIoiVI
VOnIVIWo000000Go/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`05o`00
0?nIVIWoVIVIoiVIVOl000000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000?oC4a<00?o0000oc<c
<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Go0000ogmoOomoOgooOgmoo`00
0002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@05
o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`08o`000?m<C4coC4a<
o`000?mVIVKo0000ogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00[o0000ok>c/onc
/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`09o`00
0?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVI00;o00002?ooool002?ooooo00?o0000ofIV
I_mVIVH02omVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00_oIVIV0_l0000:ogmo
O`03o`000?nIVIWoVIVI00KoVIVI00?oo`00oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`0Gok>c
/`03o`000?nIVIWoVIVI00[oVIVI00?o0000ogmoOooo00001?moOgl00ol0003oIVIVofIVIP04ofIV
IP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo
000000?oVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o
/k>c00?o/k>c00Co0000oiVIVOnIVIWo00000omoOgl01?l0003oIVIVofIVI_l00004oda<C003o`00
0?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`00
00;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?mo
Ogoo000000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<02?l0003oC4a<oda<C?l0003oIVIVo`00
0?moOgoo00000_nIVIT01?l0003o/k>cok>c/ol00008olc<c00:o`000?nc/k?o/k>co`000?nIVIWo
0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02Ol0003oC4a<oda<C?l0
003oIVIVo`000?moOgoo0000oiVIV@02o`0000Sooooo000Sooooo`goIVIV00?o0000oda<C?m<C4`0
5om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT0
2?nIVIT01?oo003oVIVIoiVIVOl0000Jok>c/`03o`000?nIVIWoVIVI00WoVIVI00Co0000ogmoOomo
OgooOgmo0_oo0002ogmoO`03o`000?mVIVKoIVIV00CoIVIV00?o0000oda<C?m<C4`05?m<C4`00ol0
003oIVIVofIVIP02ofIVIP05o`000?moOgooOgmoogmoOol000000onIVIT00ol0003o/k>cok>c/`04
ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00_nc/k<01Ol0003oVIVIoiVIVOnI
VIWo000000?oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`06oc<c<`05o`00
0?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@04o`000?nc/k?o/k>c
o`0000Woc<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<
C4coC4a<o`0000Wo<c<c00So0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000;oVIVI00Co0000
ok>c/onc/k?o00002?o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002
oda<C003o`000?lc<c?o<c<c00Ko<c<c00Wo0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nI
VIT00_l00008ooooo`008oooool=ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH0
2omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00[oVIVI00?oo`00o`000?nc/k<0
6Onc/k<00ol0003oVIVIoiVIV@0:oiVIV@03o`000?moOgooOgmo00?oOgmo00?oo`00o`000?mVIVH0
1OmVIVH00ol0003oC4a<oda<C00Doda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgoo
Ogmoo`000004oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o
/k>cok>c/`03ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00005
oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l0
0002ogmoO`03o`000?nIVIWo000000?o/k>c00?o0000olc<c?o<c<`01oo<c<`01?l0003o/k>cok>c
/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`04
o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00007
olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Oo0000ogmoOol0003oIVIVo`000?m<C4co000000Wo
<c<c00Wo0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIT00_l00008ooooo`008oooool<
ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`09
ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ool00?nc/k<06?nc/k<00ol0003oVIVIoiVIV@0:
oiVIV@03o`000?moOgooOgmo00GoOgmo0_oo0005ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000
ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000?oVIVI00?o0000ok>c/onc/k<01?nc
/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00;o/k>c00?o0000oiVIVOnIVIT00_nI
VIT01?l0003oOgmoogmoOol00002ofIVIP03o`000?m<C4coC4a<00;oC4a<00?o0000oc<c<olc<c<0
1_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01?l0
003o/k>cok>c/ol00009olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol000000_mV
IVH01?l0003oC4a<oda<C?l00009oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002
oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`00
00;oIVIV00?o0000oda<C?l000002?lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000
oiVIVOl0003o/k>co`0000Sooooo000Sooooo`[oIVIV0_l0000Hoda<C003o`000?mVIVKoIVIV00_o
IVIV0_l0000:ogmoO`03o`000?nIVIWoVIVI00coVIVI00?o0000ok>c/ooo00005_nc/k<2o`0000co
VIVI00?o0000ogmoOomoOgl01OmoOgl01?l0003oIVIVofIVI_oo0003ofIVIP03o`000?m<C4coC4a<
01?oC4a<0_l00004ofIVIP05o`000?moOgooOgmoogmoOol000001?nIVIT00ol0003o/k>cok>c/`03
ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00onc/k<01Ol0003oVIVIoiVIVOnI
VIWo000000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go<c<c
00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`03o`000?nIVIWo000000?o
/k>c00?o0000olc<c?o<c<`01oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo0000
00;oIVIV00Co0000oda<C?m<C4co00002Olc<c<02?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo
00000_nIVIT01?l0003o/k>cok>c/ol00008olc<c00<o`000?nc/k?o/k>co`000?nIVIWo0000ogmo
Ool0003oIVIVo`000?m<C4co00002Olc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000
oiVIVOl0003o/k>co`0000Sooooo000Sooooo`WoIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003o
IVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT03?nIVIT01Ol0003o
/k>cok>c/onc/k?oo`0001Co/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`06ogmo
O`05o`000?mVIVKoIVIVofIVI_oo00000_mVIVH00ol0003oC4a<oda<C00Coda<C003o`000?mVIVKo
IVIV00?oIVIV00Go0000ogmoOomoOgooOgmoo`000004oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o
0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`05o`000?nIVIWoVIVIoiVIVOl00000
0_moOgl01Ol0003oIVIVofIVI_mVIVKo000000CoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003o
C4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00?o0000oiVIVOl000000onc/k<00ol0
003oc<c<olc<c007olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH0
1?l0003oC4a<oda<C?l00009oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVI
o`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/ol0003oVIVI00;o00000_mV
IVH00ol0003oC4a<o`000009oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVI
o`000?nc/k?o00002?ooool002?ooooo2?mVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKo
IVIV00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o
/k>c00?o/k>c00?oo`00ok>c/onc/k<04?nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgoo
Ogmo00KoOgmo00?o0000ofIVI_mVIVH00omVIVH2ool001GoC4a<00?o0000ofIVI_mVIVH00omVIVH0
1Ol0003oOgmoogmoOomoOgoo000000CoVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<
c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`05o`00
0?mVIVKoIVIVofIVI_l000001?m<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<
C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Woc<c<00Co
0000ok>c/onc/k?o00000_nIVIT01_l0003oOgmoogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c
<olc<c<01olc<c<02?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo00000_nIVIT01?l0003o/k>c
ok>c/ol00008olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<
00?o0000oc<c<olc<c<01_lc<c<02ol0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0
003o/k>c00;o00002?ooool002?ooooo1omVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKo
IVIV00_oIVIV0_l0000:ogmoO`03o`000?nIVIWoVIVI00coVIVI00?o0000ok>c/onc/k<01Onc/k<0
0ooo003o/k>cok>c/`0>ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl01_moOgl0
0ol0003oIVIVofIVIP04ofIVIP03o`000?m<C4coo`0001CoC4a<00?o0000ofIVI_mVIVH00_mVIVH0
0ol0003oOgmoogmoO`02ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001_nc/k<00ol0003oc<c<olc<
c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`04o`00
0?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co0000
00;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Go
0000ok>c/onc/k?o/k>co`000002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co
00002?lc<c<02Ol0003oC4a<oda<C?m<C4co0000ofIVI_l0003oOgmoo`000002oiVIV@03o`000?nc
/k?o000000Woc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`0
0ol0003o<c<coc<c<`06oc<c<`0;o`000?m<C4co0000o`000?mVIVKo0000ogmoOol0003oVIVIo`00
0?nc/k<00_l00008ooooo`008oooool6ofIVIP;o00006?m<C4`00ol0003oIVIVofIVIP0;ofIVIP03
o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`07ok>c/`03
ool00?nc/k?o/k>c00co/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`06ogmoO`03
o`000?mVIVKoIVIV00GoIVIV00Co0000oda<C?m<C4coo`004om<C4`00ol0003oIVIVofIVIP02ofIV
IP03o`000?moOgooOgmo00;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000006ok>c/`03o`000?o<c<co
c<c<00?oc<c<00?o0000ok>c/onc/k<00onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Co
0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l0
00000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`0
1?l0003o/k>cok>c/ol00003oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co0000
2?lc<c<02Ol0003oC4a<oda<C?m<C4co0000ofIVI_l0003oOgmoo`000002oiVIV@03o`000?nc/k?o
000000Woc<c<00?o0000ok>c/onc/k<00_l00002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000
oc<c<olc<c<01_lc<c<00ol0003oC4a<o`000002ofIVIP06o`000?moOgoo0000oiVIVOl0003o/k>c
0_l00008ooooo`008oooool5ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02omV
IVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00coVIVI00?o0000ok>c/onc/k<02Onc
/k<00ooo003o/k>cok>c/`0:ok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl01Omo
Ogl00ol0003oIVIVofIVIP05ofIVIP03o`000?m<C4coC4a<00;oC4a<0_oo000@oda<C003o`000?mV
IVKoIVIV00;oIVIV00?o0000ogmoOomoOgl00_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Ko/k>c
00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`04o`000?nIVIWoVIVIo`0000?o
Ogmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`06oc<c<`03o`000?m<C4coC4a<
00;oC4a<00?o0000ofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<co
c<c<00Goc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@03o`000?moOgoo000000;oIVIV00Co
0000oda<C?m<C4co00002?lc<c<02Ol0003oC4a<oda<C?m<C4co0000ofIVI_l0003oOgmoo`000002
oiVIV@03o`000?nc/k?o000000Woc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mV
IVKo00000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0>o`000?m<C4coC4a<o`000?mVIVKo0000ogmo
Ool0003oVIVIo`000?nc/k?o0000olc<c?l00008ooooo`008oooool4ofIVIP03o`000?m<C4coC4a<
01OoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI
00_oVIVI0_l0000=ok>c/`03ool00?nc/k?o/k>c00So/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0
003oOgmoogmoO`05ogmoO`03o`000?mVIVKoIVIV00GoIVIV00?o0000oda<C?m<C4`01Om<C4`00ooo
003oC4a<oda<C00<oda<C003o`000?mVIVKoIVIV00;oIVIV00?o0000ogmoOomoOgl00_moOgl00ol0
003oVIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0
003o/k>cok>c/`03ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01?l0003oIVIVofIVI_l0
0003oda<C003o`000?lc<c?o<c<c00Oo<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`00
0?moOgooOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c007o`000?nc/k?o/k>c
ok>c/ol0003oVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000;oC4a<00?o0000oc<c<olc<c<0
1_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0
003oc<c<olc<c007olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;o
C4a<00?o0000oc<c<olc<c<01_lc<c<03_l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVI
VOl0003o/k>co`000?o<c<co00002?ooool002?ooooo0omVIVH2o`0001SoC4a<00?o0000ofIVI_mV
IVH03?mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc
/k<03_nc/k<00ooo003o/k>cok>c/`06ok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomo
Ogl01OmoOgl00ol0003oIVIVofIVIP06ofIVIP03o`000?m<C4coC4a<00KoC4a<00?oo`00oda<C?m<
C4`02om<C4`00ol0003oIVIVofIVIP02ofIVIP03o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnI
VIT00_nIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc
/k<00onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Co0000ofIVI_mVIVKo00000om<C4`0
0ol0003o<c<coc<c<`07oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmo
Ool00002oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01ol0003o/k>cok>c/onc/k?o0000
oiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co
0000oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<
c<`01oo<c<`00ol0003o/k>co`000002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0
003o<c<coc<c<`06oc<c<`0>o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc
/k?o0000olc<c?l00008ooooo`008oooool2ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIV
I_mVIVH03?mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c
/onc/k<04?nc/k<00ooo003o/k>cok>c/`04ok>c/`03o`000?nIVIWoVIVI00_oVIVI0_l00008ogmo
O`03o`000?mVIVKoIVIV00GoIVIV00?o0000oda<C?m<C4`02?m<C4`2ool000[oC4a<00?o0000ofIV
I_mVIVH00_mVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c
/onc/k<00onc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Go0000oiVI
VOnIVIWoVIVIo`000003ogmoO`05o`000?mVIVKoIVIVofIVI_l000000om<C4`00ol0003o<c<coc<c
<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@05
o`000?nc/k?o/k>cok>c/ol000002?o<c<`01ol0003o/k>cok>c/onc/k?o0000oiVIVOl000000_mo
Ogl01?l0003oIVIVofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c00[o0000oda<C?m<C4co
0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c007olc<c00:o`000?nc
/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<0
3?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000;oc<c<00?o0000
ooooooooool01_ooool002?ooooo00?oIVIVo`000?m<C4`06?m<C4`00ol0003oIVIVofIVIP0;ofIV
IP;o00002_moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01;o/k>c00?oo`00ok>c
/onc/k<00_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00OoOgmo00?o0000ofIV
I_mVIVH01OmVIVH00ol0003oC4a<oda<C00;oda<C0;oo`001om<C4`00ol0003oIVIVofIVIP03ofIV
IP05o`000?moOgooOgmoogmoOol000001?nIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<co
c<c<00?oc<c<00?o0000ok>c/onc/k<01?nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Go
0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`0
0_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<
c?o<c<`01_o<c<`01ol0003o/k>cok>c/onc/k?o0000oiVIVOl000000_moOgl01?l0003oIVIVofIV
I_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH01Ol0003o
Ogmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`02_l0003o/k>cok>c/ol0003o
VIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00co0000oda<C?m<
C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00002olc<c003o`000?oooooooooo00Ko
oooo000Sooooo`03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003oOgmo
ogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05?nc/k<01?oo003o/k>c
ok>c/ol0000>oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH01_mVIVH00ol0003o
C4a<oda<C00=oda<C003ool00?m<C4coC4a<00CoC4a<00?o0000ofIVI_mVIVH00_mVIVH00ol0003o
OgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003o
c<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00?o0000oiVIVOnIVIT00_nIVIT01?l0003o
OgmoogmoOol00003ofIVIP03o`000?m<C4coC4a<00;oC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0
003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00?o0000oiVIVOl000001?nc/k<0
0ol0003oc<c<olc<c006olc<c007o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000002ogmoO`04o`00
0?mVIVKoIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIV
IP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c00:o`000?nc/k?o
/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<00ol0
003oC4a<oda<C002o`0000;oOgmo00Go0000oiVIVOl0003o/k>co`000002olc<c003o`000?oooooo
oooo00Kooooo000SoooooaWoC4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmoO`08ogmo
O`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ooo003o0000oiVIV@0<oiVI
V@;o00002?moOgl00ol0003oIVIVofIVIP06ofIVIP03o`000?m<C4coC4a<00ooC4a<0_oo0003oda<
C003o`000?mVIVKoIVIV00?oIVIV00Go0000ogmoOomoOgooOgmoo`000004oiVIV@03o`000?nc/k?o
/k>c00Co/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`05o`000?nIVIWo
VIVIoiVIVOl000000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000CoC4a<00?o0000oc<c<olc<c<0
1Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co0000oiVIVOnI
VIWo00000onc/k<00ol0003oc<c<olc<c006olc<c007o`000?nc/k?o/k>cok>c/ol0003oVIVIo`00
0003ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<
C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00?o0000ok>c/ol000002Oo<c<`02_l0003o/k>c
ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00[o
0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<01?l0003oc<c<olc<c?l0
0008ooooo`008ooooolHoda<C003o`000?mVIVKoIVIV00_oIVIV0_l0000:ogmoO`03o`000?nIVIWo
VIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oo`00oiVIV@0;oiVIV@03o`000?moOgoo
Ogmo00OoOgmo00?o0000ofIVI_mVIVH01_mVIVH00ol0003oC4a<oda<C00Boda<C0;oo`0000?o0000
ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`02ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001onc
/k<00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c00?o/k>c00Go0000oiVIVOnIVIWoVIVI
o`000003ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003o
C4a<oda<C?m<C4co000000?oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01Ol0003o/k>cok>c/onc
/k?o000000Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT01_l0003oOgmoogmoOol0003oIVIVo`00
00;oC4a<00?o0000oc<c<olc<c<01olc<c<01?l0003oC4a<oda<C?l00002ofIVIP05o`000?moOgoo
0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c00:o`000?nc/k?o/k>co`000?nIVIWo
0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<03?l0003oC4a<oda<C?l0
003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000?oc<c<00?o0000ooooooooool01_ooool0
02?ooooo5om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVI
VOnIVIT02onIVIT00ol0003o/k>cok>c/`0Hok>c/`03o`000?nIVIWoo`0000[oVIVI00?o0000ogmo
OomoOgl02?moOgl00ol0003oIVIVofIVIP06ofIVIP03o`000?m<C4coC4a<01CoC4a<0_oo0004ofIV
IP03o`000?moOgooOgmo00;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000007ok>c/`03o`000?o<c<co
c<c<00?oc<c<00?o0000ok>c/onc/k<00onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Go
0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4co
C4a<o`000003ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008
olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Ko0000ogmoOomoOgoo0000ofIVI_l00002oda<C003
o`000?lc<c?o<c<c00Oo<c<c00Co0000oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nIVIWo
000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo
0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00?o0000oda<C?l000000_mVIVH01ol0
003oOgmoo`000?nIVIWo0000ok>c/ol000000oo<c<`00ol0003oooooooooo`06ooooo`008ooooolG
oda<C003o`000?mVIVKoIVIV00[oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0;
oiVIV@03o`000?nc/k?o/k>c01So/k>c00Go0000oiVIVOnIVIWoVIVIool00008oiVIV@03o`000?mo
OgooOgmo00SoOgmo00?o0000ofIVI_mVIVH01_mVIVH00ol0003oC4a<oda<C00Doda<C003o`000?mV
IVKoIVIV00;oo`0000?oIVIVo`000?moOgl00omoOgl01Ol0003oVIVIoiVIVOnIVIWo000000Oo/k>c
00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`04ok>c/`05o`000?nIVIWoVIVIoiVIVOl0
00000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000CoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0
003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo00000onc
/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01_l0003oOgmo
ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01olc<c<01_l0003oC4a<oda<C?l0003o
IVIVo`0000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c005o`000?nc
/k?o0000oiVIVOl000000_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Go<c<c
00Co0000oda<C?m<C4co00000_mVIVH01ol0003oOgmoo`000?nIVIWo0000ok>c/ol000000oo<c<`0
0ol0003oooooooooo`06ooooo`008ooooolFoda<C003o`000?mVIVKoIVIV00[oIVIV00?o0000ogmo
OomoOgl02_moOgl00ol0003oVIVIoiVIV@0:oiVIV@03o`000?nc/k?o/k>c01So/k>c00?o0000oiVI
VOnIVIT00onIVIT00ooo003oVIVIoiVIV@05oiVIV@03o`000?moOgooOgmo00OoOgmo00?o0000ofIV
I_mVIVH01omVIVH00ol0003oC4a<oda<C00Doda<C003o`000?mVIVKoIVIV00;oIVIV00?oo`00ogmo
OomoOgl00omoOgl01Ol0003oVIVIoiVIVOnIVIWo000000Oo/k>c00?o0000olc<c?o<c<`00oo<c<`0
0ol0003o/k>cok>c/`03ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl00ol0003oIVIVofIV
IP02ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01Ol0003oC4a<oda<C?m<C4co000000?o
IVIV00Co0000ogmoOomoOgoo00000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Co0000
ok>c/onc/k?o00000_nIVIT01_l0003oOgmoogmoOol0003oIVIVo`0000?oC4a<00?o0000oc<c<olc
<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<0
0ol0003oc<c<olc<c007olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`00
00;oC4a<00?o0000oc<c<olc<c<01_lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000
oiVIVOl0003o/k>co`0000Coc<c<00?o0000ooooooooool01_ooool002?ooooo5Om<C4`00ol0003o
IVIVofIVIP0:ofIVIP;o00002_moOgl2o`0000goVIVI00?o0000ok>c/onc/k<05_nc/k<2o`0000Oo
VIVI00?oo`00oiVIVOnIVIT00_nIVIT2o`0000[oOgmo00?o0000ofIVI_mVIVH01_mVIVH00ol0003o
C4a<oda<C00Doda<C003o`000?mVIVKoIVIV00?oIVIV00?o0000ool00?oo00000_moOgl00ol0003o
VIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003o
/k>cok>c/`04ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01Ol0003oIVIVofIVI_mVIVKo
000000CoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKo
IVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c005o`00
0?nc/k?o/k>cok>c/ol000000_nIVIT01_l0003oOgmoogmoOol0003oIVIVo`0000?oC4a<00?o0000
oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl00000
0_nc/k<00ol0003oc<c<olc<c007olc<c003o`000?nc/k?o000000;oVIVI00Ko0000ogmoOol0003o
IVIVo`000?m<C4`2o`0000So<c<c00Go0000oda<C?m<C4co0000ofIVIP03o`000004oiVIVOl0003o
/k>co`0000Coc<c<00?o0000ooooooooool01_ooool002?ooooo4om<C4`2o`0000coIVIV00?o0000
ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000
oiVIVOnIVIT02?nIVIT01?oo003oVIVIoiVIVOl0000;ogmoO`03o`000?mVIVKoIVIV00OoIVIV00?o
0000oda<C?m<C4`05?m<C4`00ol0003oIVIVofIVIP03ofIVIP03o`000?moOgooOgmo00;oo`001OnI
VIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<00onc
/k<00ol0003oVIVIoiVIV@02oiVIV@04o`000?moOgooOgmoo`0000?oIVIV00?o0000oda<C?m<C4`0
0_m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo
00000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c
/onc/k?o/k>co`000002oiVIV@03o`000?moOgoo000000;oIVIV00Go0000oda<C?m<C4coC4a<o`00
0007oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o
/k>c00?o0000olc<c?o<c<`01oo<c<`00ol0003o/k>co`000002oiVIV@07o`000?moOgoo0000ofIV
I_l0003oC4a<o`000009oc<c<`05o`000?m<C4coC4a<o`000?mVIVH00_l00002oiVIV@03o`000?nc
/k?o000000Coc<c<00?o0000ooooooooool01_ooool002?ooooo4_m<C4`00ol0003oIVIVofIVIP0;
ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`0F
ok>c/`03o`000?nIVIWoVIVI00[oVIVI00?oo`00oiVIVOl000002_moOgl00ol0003oIVIVofIVIP07
ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH00omVIVH01_l0003oOgmoogmoOomo
Ogoo0000oiVIV@;oo`000_nIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00?oc<c<
00?o0000ok>c/onc/k<01?nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Go0000ofIVI_mV
IVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0
003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<
c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmoOol000000omVIVH01?l0003oC4a<
oda<C?l00008oc<c<`0;o`000?m<C4coC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00000
0_nc/k<00ol0003oc<c<olc<c007olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003o
IVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?mo
Ogoo0000oiVIVOl0003o/k>co`0000Goc<c<00?o0000ooooooooool01_ooool002?ooooo4Om<C4`0
0ol0003oIVIVofIVIP0;ofIVIP;o00002_moOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o
/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oo`00ool00009ogmoO`03o`000?mVIVKo
IVIV00KoIVIV0_l0000Foda<C003o`000?mVIVKoIVIV00?oIVIV00?o0000ogmoOomoOgl00_moOgl0
1_l0003oVIVIoiVIVOnIVIWoo`00o`0000Oo/k>c00?o0000olc<c?o<c<`00_o<c<`00ol0003o/k>c
ok>c/`04ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01Ol0003oIVIVofIVI_mVIVKo0000
00CoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIV
o`0000;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc
/k?o/k>cok>c/ol000000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000Wo
<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000
olc<c?o<c<`01oo<c<`00ol0003o/k>co`000002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<
C4`00ol0003o<c<coc<c<`06oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVI
o`000?nc/k?o00001Oo<c<`00ol0003oooooooooo`06ooooo`008oooool@oda<C003o`000?mVIVKo
IVIV00_oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o
/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT01Ol0003oOgmoogmoOomoOgooo`0000OoOgmo00?o
0000ofIVI_mVIVH01omVIVH00ol0003oC4a<oda<C00Eoda<C003o`000?mVIVKoIVIV00?oIVIV00?o
0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@02oiVIV@;oo`001_nc/k<00ol0003oc<c<olc<
c002olc<c003o`000?nc/k?o/k>c00Co/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`05o`00
0?mVIVKoIVIVofIVI_l000001Om<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;o
C4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<co
c<c<00Koc<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo
00000_m<C4`00ol0003o<c<coc<c<`07oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl0
0ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00?o0000ok>c/ol000000_nIVIT0
1Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<00ol0003oC4a<oda<
C002o`0000;oOgmo00Go0000oiVIVOl0003o/k>co`000005olc<c003o`000?oooooooooo00Kooooo
000Sooooo`ooC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nI
VIWoVIVI00coVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0<oiVIV@03o`000?mo
OgooOgmo00;oOgmo00?oo`00ogmoOomoOgl00omoOgl00ol0003oIVIVofIVIP07ofIVIP03o`000?m<
C4coC4a<01GoC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nI
VIWoVIVI00;oVIVI00?o0000ok>c/onc/k<00_oo0003ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o
0000ok>c/onc/k<01?nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Co0000ofIVI_mVIVKo
00001Om<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mV
IVKo00000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000
ok>c/onc/k?o/k>co`000002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co0000
2Olc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0
003oc<c<olc<c007olc<c003o`000?nc/k?o000000;oVIVI00Go0000ogmoOol0003oIVIVo`000002
oda<C003o`000?lc<c?o<c<c00Ko<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nI
VIWo00000_nc/k<00ol0003oc<c<olc<c003olc<c003o`000?oooooooooo00Kooooo000Sooooo`ko
C4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_o
VIVI0_l0000Hok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl01?moOgl01Ooo003o
OgmoogmoOomoOgoo000000[oIVIV00?o0000oda<C?m<C4`05?m<C4`00ol0003oIVIVofIVIP03ofIV
IP03o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00_nIVIT2o`0000Co/k>c0_oo00000ol0
003oc<c<olc<c002olc<c0;o00001_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Go0000
ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<
o`000003ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<
c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4co
C4a<o`0000Wo<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`03o`000?nIVIWo000000;o
/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000
ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000
ogmoOol0003oVIVIo`000?nc/k?o00001_o<c<`00ol0003oooooooooo`06ooooo`006?ooool5o`00
00Kooooo3Om<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVI
VOnIVIT02onIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmo
OomoOgl01_moOgl01?oo003oOgmoo`000?l00009ofIVIP03o`000?m<C4coC4a<01GoC4a<00?o0000
ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000
ok>c/onc/k<01Onc/k<2ool000?oc<c<00?o0000ok>c/onc/k<01Onc/k<01Ol0003oVIVIoiVIVOnI
VIWo000000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go<c<c
00?o0000oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Co0000oiVIVOnI
VIWo00000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT0
0ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000Wo<c<c00Ko0000oda<C?m<C4co0000
ofIVI_l00002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o
/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06
oc<c<`07o`000?m<C4coC4a<o`000?mVIVKo0000ogmoO`02o`0000;o/k>c00?o0000olc<c?o<c<`0
1?o<c<`00ol0003oooooooooo`06ooooo`006?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo
3?m<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT0
2onIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00_oVIVI0_l0000:ogmoO`03ool0
0?mVIVKoIVIV00SoIVIV00?o0000oda<C?m<C4`05Om<C4`00ol0003oIVIVofIVIP03ofIVIP03o`00
0?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`05ok>c/`03o`00
0?o<c<coc<c<00;oo`0000?o0000ok>c/onc/k<01Onc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;o
Ogmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<
C?m<C4coC4a<o`000003ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>c
o`000008olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT00ol0003oOgmoo`000002ofIVIP04
o`000?m<C4coC4a<o`0000Wo<c<c00Co0000oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nI
VIWo000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`00ol0003o/k>co`000002oiVIV@05o`000?mo
Ogoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0<o`000?m<C4coC4a<o`000?mV
IVKo0000ogmoOol0003oVIVIo`000?nc/k?o00001oo<c<`00ol0003oooooooooo`06ooooo`006Ooo
ool00onHV9So8B4Qonk^kP07ooooo`_oC4a<00?o0000ofIVI_mVIVH02omVIVH2o`0000[oOgmo00?o
0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o
0000ogmoOomoOgl02OmoOgl01?l0003oIVIVool00?oo0007ofIVIP03o`000?m<C4coC4a<01GoC4a<
00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00;oVIVI
00?o0000ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c002olc<c0;oo`001Onc/k<01Ol0003oVIVI
oiVIVOnIVIWo000000?oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c
00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`05o`000?nIVIWo
VIVIoiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c007o`000?nc/k?o/k>cok>c/ol0003o
VIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01olc<c<01_l0
003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<
c007olc<c003o`000?nc/k?o000000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`00
0?lc<c?o<c<c00Ko<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c
/ol00007olc<c003o`000?oooooooooo00Kooooo000Jooooo`03oiRHV?lQ8B7ok^k^00Kooooo2_m<
C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onI
VIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl02?mo
Ogl00ol0003oIVIVofIVIP02ofIVIP03ool00?mVIVKoIVIV00CoIVIV00?o0000oda<C?m<C4`05?m<
C4`00ol0003oIVIVofIVIP04ofIVIP03o`000?moOgooOgmo00?oOgmo00?o0000oiVIVOnIVIT00_nI
VIT00ol0003o/k>cok>c/`05ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o0000ok>c/ooo00000_oo
0002ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01Ol0003oIVIVofIVI_mVIVKo000000Co
C4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`00
00;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Oo0000
ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo00?o0000ofIVI_l000000om<C4`00ol0003o<c<c
oc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Ko0000ogmoOomoOgoo0000oiVIVOl00002
ok>c/`03o`000?o<c<coc<c<00Ooc<c<00?o0000ok>c/ol000000_nIVIT01ol0003oOgmoo`000?mV
IVKo0000oda<C?l000002Olc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0
003o/k>co`0000Ooc<c<00?o0000ooooooooool01_ooool001_ooooo00?oMgMgofIVI_ooool01Ooo
ool9oda<C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVI
V@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02onIVIT2o`0000[oOgmo00?o
0000ofIVI_mVIVH01?mVIVH00ooo003oIVIVofIVIP02ofIVIP03o`000?m<C4coC4a<01GoC4a<00?o
0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o
0000ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c00?o/k>c0_oo
0004oiVIV@04o`000?moOgooOgmoo`0000?oIVIV00?o0000oda<C?m<C4`00_m<C4`00ol0003o<c<c
oc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`04
o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01ol0003o/k>cok>c/onc/k?o
0000oiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c
00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<
c?o<c<`01oo<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003
o`000?lc<c?o<c<c00Oo<c<c00_o0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>c
o`000008olc<c003o`000?oooooooooo00Kooooo000Looooo`03o`000?oooooooooo00Cooooo2?m<
C4`00ol0003oIVIVofIVIP0;ofIVIP;o00002_moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc
/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mV
IVKoIVIV00KoIVIV00Coo`00ofIVI_mVIVKo00005om<C4`00ol0003oIVIVofIVIP03ofIVIP03o`00
0?moOgooOgmo00?oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`06ok>c/`05o`00
0?o<c<coc<c<olc<c?l000001onc/k<01Ol0003oo`00ool00?nIVIWo000000;oOgmo00Go0000ofIV
I_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Ko<c<c00?o0000oda<C?m<C4`00_m<C4`0
1?l0003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`0
1_o<c<`2o`0000;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00002oda<
C003o`000?lc<c?o<c<c00Ko<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00?o
0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c0;o000000Wo/k>co`000?nIVIWoVIVI
o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0<o`000?m<C4coC4a<
o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00002?o<c<`00ol0003oooooooooo`06oooo
o`006?ooool01Ol0003o^[ZjoooooonHV9So410@00Kooooo1om<C4`00ol0003oIVIVofIVIP0<ofIV
IP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Hok>c
/`03o`000?nIVIWoVIVI00[oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP08ofIV
IP03ool00?mVIVKo000001OoC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`02ogmo
O`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<01_nc/k<01Ol0003oc<c<olc<c?o<c<co
000000Oo/k>c00?o0000oiVIVOnIVIT00_oo0002ogmoO`05o`000?mVIVKoIVIVofIVI_l000001?m<
C4`00ol0003o<c<coc<c<`06oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo0000
0_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc
/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Co0000oda<C?m<C4co00002?lc
<c<01ol0003oC4a<oda<C?m<C4co0000ofIVI_l000000_moOgl00ol0003oVIVIo`000002ok>c/`03
o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mVIVKo
000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo
0000oiVIVOl0003o/k>co`0000Soc<c<00?o0000ooooooooool01_ooool001Sooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c006ooooo`OoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`08
ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<06?nc/k<00ol0003oVIVIoiVIV@0:
oiVIV@03o`000?moOgooOgmo00[oOgmo00?o0000ofIVI_mVIVH02OmVIVH2ool001KoC4a<00?o0000
ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000
ok>c/onc/k<01_nc/k<01Ol0003oc<c<olc<c?o<c<co000000Oo/k>c00Ko0000oiVIVOnIVIWoVIVI
o`000?moOgl2ool00005o`000?mVIVKoIVIVofIVI_l000001?m<C4`00ol0003o<c<coc<c<`05oc<c
<`03o`000?m<C4coC4a<00;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`04o`000?nIVIWo
VIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI
00Ko0000ogmoOomoOgoo0000ofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Wo0000oda<
C?m<C4coC4a<o`000?mVIVKo0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00008olc<c004
o`000?nc/k?o/k>co`0000;oVIVI0_l00002ofIVIP03o`000?m<C4co000000Wo<c<c00?o0000oda<
C?m<C4`00_l00002ogmoO`04o`000?nIVIWo0000o`0000Woc<c<00?o0000ooooooooool01_ooool0
00_ooooo0ol000000ol@413oooooooooo`0Booooo`KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0
003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00[oVIVI00?o0000ok>c/onc/k<06?nc/k<00ol0
003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02_mVIVH00ol0
003oC4a<ool0000Doda<C003o`000?mVIVKoIVIV00CoIVIV00?o0000ogmoOomoOgl00_moOgl00ol0
003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c00Ko/k>c00Go0000olc<c?o<c<coc<c<o`000007
ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01Ol0003oo`00ool00?mVIVKo000000CoC4a<
00?o0000oc<c<olc<c<01_lc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;o
Ogmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>c
ok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000Wo<c<c
00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<
c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<
C4`00ol0003o<c<coc<c<`06oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVI
o`000?nc/k?o00002Oo<c<`00ol0003oooooooooo`06ooooo`003Oooool00ol@413o^[Zjooooo`0C
ooooo`CoC4a<0_l0000<ofIVIP;o00002_moOgl2o`0000goVIVI00?o0000ok>c/onc/k<05onc/k<0
0ol0003oVIVIoiVIV@0:oiVIV@;o00002_moOgl2o`0000coIVIV00Go0000oda<C?m<C4coC4a<ool0
000Coda<C003o`000?mVIVKoIVIV00CoIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVI
V@02oiVIV@03o`000?nc/k?o/k>c00Ko/k>c0ol000000oo<c<co0000ok>c/`06ok>c/`05o`000?nI
VIWoVIVIoiVIVOl000000omoOgl00ol0003oIVIVofIVIP02ool000CoC4a<00?o0000oc<c<olc<c<0
1Olc<c<00ol0003oC4a<oda<C002oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01?l0003o
VIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002
oiVIV@06o`000?moOgooOgmoo`000?mVIVKo00000om<C4`00ol0003o<c<coc<c<`07oc<c<`08o`00
0?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Co
0000ok>c/onc/k?o00000_nIVIT01ol0003oOgmoo`000?mVIVKo0000oda<C?l000002Olc<c<03?l0
003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Woc<c<00?o0000oooo
ooooool01_ooool000gooooo00?oV9RHoc8b<_ooool04oooool3oda<C003o`000?mVIVKoIVIV00_o
IVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Oo
/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00_o
IVIV00?o0000oda<C?m<C4`00om<C4`00ooo003oC4a<oda<C00@oda<C003o`000?mVIVKoIVIV00Co
IVIV00?o0000ogmoOomoOgl00_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Wo/k>c00Co0000ok>c
/onc/k?o00002?nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Go0000ofIVI_mVIVKoIVIV
o`000002ool00003oda<C?l0003o<c<c00Oo<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0003oIVIV
ofIVI_mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<
c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01_l0003oOgmoogmoOol0003oIVIVo`0000?oC4a<
00?o0000oc<c<olc<c<01olc<c<00ol0003oC4a<oda<C002o`0000;oOgmo00Co0000oiVIVOnIVIWo
00000_nc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Oo0000ogmo
Ool0003oIVIVo`000?m<C4co000000Wo<c<c00Oo0000oda<C?m<C4co0000ofIVI_l0003oOgmo00;o
00000_nc/k<00ol0003oc<c<olc<c007olc<c003o`000?oooooooooo00Kooooo000=ooooo`03omgM
gOl0003o^[Zj01?ooooo0_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo
00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00_oVIVI
00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<00GoC4a<
00?oo`00oda<C?m<C4`03_m<C4`00ol0003oIVIVofIVIP04ofIVIP03o`000?moOgooOgmo00;oOgmo
00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`06ok>c/`03o`000?o<c<co000000Wo/k>c
00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`05o`000?mVIVKoIVIVofIVI_l000000om<C4`3ool0
00Ko<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Co0000
oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol00000
0_nIVIT01_l0003oOgmoogmoOol0003oIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01olc<c<02?l0
003oC4a<oda<C?l0003oIVIVo`000?moOgoo00000_nIVIT01?l0003o/k>cok>c/ol00008olc<c004
o`000?nc/k?o/k>co`0000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o
<c<c00Ko<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00009
olc<c0;o00002?ooool000gooooo00?oEEEEogMgMom4A4@04oooool00om<C4co0000ofIVIP0<ofIV
IP;o00002_moOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c0_l0000<oiVI
V@;o00002_moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<00OoC4a<00?oo`00oda<
C?m<C4`02om<C4`2o`0000GoIVIV0_l00004ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c
/onc/k<01_nc/k<01?l0003oc<c<olc<c?l00007ok>c/`03o`000?nIVIWoVIVI00;oVIVI00Co0000
ogmoOomoOgoo00000omVIVH00ol0003oC4a<oda<C003oda<C004o`000?lc<c?oo`00ool000Co<c<c
00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`05o`000?nIVIWoVIVIoiVI
VOl000000onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT0
0ol0003oOgmoo`000002ofIVIP03o`000?m<C4coC4a<00;o00002?lc<c<01?l0003oC4a<oda<C?l0
0002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01_l0003o/k>c
ok>c/ol0003oVIVIo`0000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c
<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00002Oo<c<`2o`00
00Sooooo000<ooooo`05omgMgOl@413oooooob4Q8OoMgMd04_ooool00ol0003oIVIVofIVIP0;ofIV
IP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`0Fok>c
/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0<ofIV
IP03o`000?m<C4coC4a<00SoC4a<0_oo000;oda<C003o`000?mVIVKoIVIV00?oIVIV00?o0000ogmo
OomoOgl01?moOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c00Ko/k>c00Co0000olc<
c?o<c<co00001onc/k<00ol0003oVIVIoiVIV@02oiVIV@04o`000?moOgooOgmoo`0000?oIVIV00?o
0000oda<C?m<C4`00om<C4`01?l0003o<c<coc<c<olc<c<2ool000;o<c<c00?o0000oda<C?m<C4`0
0_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000onc/k<00ol0
003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT00ol0003oOgmoo`000002
ofIVIP04o`000?m<C4coC4a<o`0000Wo<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmo
o`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002
ogmoO`05o`000?mVIVKo0000oda<C?l000002Olc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?mo
Ogoo0000oiVIVOl0003o/k>co`0000Woc<c<0_l00008ooooo`003?ooool01OmVIVKoQhN7oooooonH
V9SoEEEE01;ooooo3OmVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00coVIVI00?o
0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo00SoOgmo00?o
0000ofIVI_mVIVH03?mVIVH00ol0003oC4a<oda<C00;oda<C003ool00?m<C4coC4a<00OoC4a<00?o
0000ofIVI_mVIVH01?mVIVH00ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o
0000ok>c/onc/k<02?nc/k<2o`0000Oo/k>c00?o0000oiVIVOnIVIT00_nIVIT01?l0003oOgmoogmo
Ool00003ofIVIP03o`000?m<C4coC4a<00?oC4a<00?o0000oc<c<olc<c<01?lc<c<2ool000CoC4a<
00Co0000ofIVI_mVIVKo00000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000?o/k>c00?o0000olc<
c?o<c<`01oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@06o`000?moOgooOgmoo`000?mVIVKo0000
0_m<C4`00ol0003o<c<coc<c<`07oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol0
00000_nIVIT01?l0003o/k>cok>c/ol00008olc<c004o`000?nc/k?o/k>cok>c/`;o00000_moOgl0
0ol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00co0000oda<C?m<C4co0000ofIV
I_l0003oOgmoo`000?nIVIWo0000ok>c/ol00009olc<c003o`000?nc/k?o000000Sooooo000;oooo
o`03onk^k_l0003ok^k^00;ooooo00?o0000omgMgOooool04?ooool<ofIVIP;o00002_moOgl00ol0
003oVIVIoiVIV@0;oiVIV@;o00006?nc/k<00ol0003oVIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo
00SoOgmo00?o0000ofIVI_mVIVH02omVIVH2o`0000ooC4a<00?oo`00oda<C?m<C4`01Om<C4`00ol0
003oIVIVofIVIP04ofIVIP03o`000?moOgooOgmo00?oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0
003o/k>cok>c/`09ok>c/`03o`000?nc/k?o/k>c00Ko/k>c00Go0000oiVIVOnIVIWoVIVIo`000003
ogmoO`05o`000?mVIVKoIVIVofIVI_l000001Om<C4`00ol0003o<c<coc<c<`04oc<c<`04o`000?m<
C4coo`00ool000;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00004ok>c
/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@03o`000?moOgoo
000000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`00
0?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01_l0003o/k>cok>c/ol0003oVIVI
o`0000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0<o`000?m<C4co
C4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00002Oo<c<`00ol0003o/k>co`000008
ooooo`002oooool01?l@413o0000o`000?ooool2o`000003oa0@4?oooooooooo00oooooo2omVIVH0
0ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<0
0ol0003oVIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH0
0ol0003oC4a<oda<C00@oda<C003ool00?m<C4coC4a<00CoC4a<00?o0000ofIVI_mVIVH01?mVIVH0
0ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<04onc/k<0
1Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Go0000ofIVI_mVIVKoIVIVo`000005oda<C003o`00
0?lc<c?o<c<c00Co<c<c00Co0000oda<C?m<C4coC4a<0ooo0002ofIVIP04o`000?moOgooOgmoo`00
00;oVIVI00?o0000ok>c/onc/k<00_nc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>c
ok>c/ol000000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000Wo<c<c00Co
0000oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000So
c<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000
oc<c<olc<c<01_lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>c
o`0000Woc<c<00?o0000ok>c/ol000002?ooool002?ooooo2_mVIVH00ol0003oOgmoogmoO`09ogmo
O`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0;oiVI
V@;o00002_moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01;oC4a<00?oo`00oda<
C?m<C4`00_m<C4`00ol0003oIVIVofIVIP04ofIVIP03o`000?moOgooOgmo00?oOgmo00?o0000oiVI
VOnIVIT00onIVIT00ol0003o/k>cok>c/`0Bok>c/`03o`000?nIVIWoVIVI00;oVIVI00Co0000ogmo
OomoOgoo00000omVIVH00ol0003oC4a<oda<C003oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000
oda<C?m<C4`00om<C4`01?l0003oIVIVool00?oo0002ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c
00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmoOol0
00000_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000
ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00008olc<c006o`000?nc/k?o/k>co`000?nIVIWo
00000_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00co0000oda<C?m<
C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00009olc<c004o`000?nc/k?o0000o`00
00Sooooo000Sooooo`WoIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03
o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmoO`03
o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05?m<C4`01?oo003oC4a<oda<C?l00006ofIV
IP03o`000?moOgooOgmo00?oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0Bok>c
/`03o`000?nIVIWoVIVI00;oVIVI00Co0000ogmoOomoOgoo00000omVIVH00ol0003oC4a<oda<C003
oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mV
IVKo000000;oo`0000Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c007olc<c004o`00
0?nc/k?o/k>co`0000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01?l0003oC4a<oda<C?l00009
oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT00ol0003o/k>co`00
0009olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl01Ol0003oIVIVo`000?m<C4co0000
00Wo<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00009olc<
c004o`000?nc/k?o0000o`0000Sooooo000Sooooo`WoIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0
003oVIVIoiVIV@0:oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0
003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`2ool0
0003o`000?mVIVKoIVIV00CoIVIV00?o0000ogmoOomoOgl00omoOgl00ol0003oVIVIoiVIV@03oiVI
V@03o`000?nc/k?o/k>c01;o/k>c00?o0000oiVIVOnIVIT00_nIVIT01?l0003oOgmoogmoOol00003
ofIVIP03o`000?m<C4coC4a<00?oC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002
oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Go0000ool00?oo003oo`00o`000003ok>c/`03o`00
0?o<c<coc<c<00Ooc<c<00Co0000ok>c/onc/k?o00000_nIVIT01?l0003oOgmoogmoOol00002ofIV
IP04o`000?m<C4coC4a<o`0000Wo<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`06o`00
0?nIVIWoVIVIo`000?nc/k?o00002Oo<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00Go
0000ofIVI_l0003oC4a<o`000009oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003o
VIVIo`000?nc/k?o00002Oo<c<`01?l0003o/k>co`000?l00008ooooo`008oooool8ofIVIP03o`00
0?moOgooOgmo00SoOgmo0_l0000<oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT0
2onIVIT2o`0000[oOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Hoda<C003o`00
0?oo003oIVIV00CoIVIV00?o0000ogmoOomoOgl00omoOgl00ol0003oVIVIoiVIV@03oiVIV@03o`00
0?nc/k?o/k>c01;o/k>c00?o0000oiVIVOnIVIT00_nIVIT01?l0003oOgmoogmoOol00004ofIVIP03
o`000?m<C4coC4a<00;oC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C005
o`000?mVIVKoIVIVofIVI_l000000_moOgl01?l0003oVIVIoiVIVOnIVIT2ool00003ok>c/ol0003o
c<c<00Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP04o`00
0?m<C4coC4a<o`0000Wo<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0003oOgmoo`000002oiVI
V@04o`000?nc/k?o/k>co`0000Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`00
0?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02_l0003oC4a<oda<C?l0003oIVIVo`00
0?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/ol0003oVIVI
o`000008ooooo`008oooool6ofIVIP;o00002_moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc
/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mV
IVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`2o`0000;oIVIV0_oo0002ofIVIP03o`000?mo
OgooOgmo00?oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0Bok>c/`03o`000?nI
VIWoVIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`000003ofIVIP03o`000?m<C4coC4a<00?oC4a<
00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000?o
Ogmo00Co0000oiVIVOnIVIWo00000_nc/k<2ool000Soc<c<00Go0000ok>c/onc/k?o/k>co`000002
oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<01?l0003oC4a<
oda<C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<
c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000So
<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00009olc<c005
o`000?nc/k?o0000oiVIVOl000002?ooool002?ooooo1_mVIVH00ol0003oOgmoogmoO`08ogmoO`03
o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0<oiVIV@03
o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Hoda<C003
o`000?mVIVKoIVIV00?oIVIV0_oo00000ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00?o
VIVI00?o0000ok>c/onc/k<04_nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000CoOgmo00Go0000ofIV
I_mVIVKoIVIVo`000005oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`0
1?l0003oIVIVofIVI_l00003ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00Co0000ool00?oo003o
o`001Oo<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH0
1?l0003oC4a<oda<C?l00009oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Go0000ogmoOol0003o
VIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003o
Ogmoo`0000;oIVIV00Co0000oda<C?m<C4co00001olc<c<03Ol0003oC4a<oda<C?m<C4co0000ofIV
I_l0003oOgmoo`000?nIVIWo0000ok>c/ol000002Oo<c<`01Ol0003o/k>co`000?nIVIWo000000So
oooo000Sooooo`GoIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`00
0?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02onIVIT2o`0000[oOgmo00?o0000ofIVI_mVIVH0
2omVIVH00ol0003oC4a<oda<C00Hoda<C003o`000?mVIVKoIVIV00GoIVIV00?o0000ool00?moOgl0
0omoOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c01;o/k>c00?o0000oiVIVOnIVIT0
0_nIVIT01Ol0003oOgmoogmoOomoOgoo000000?oIVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o
<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000omoOgl01?l0
003oVIVIoiVIVOl00004ok>c/`04o`000?o<c<coc<c<olc<c0;oo`000_o<c<`00ol0003o/k>cok>c
/`02ok>c/`06o`000?nIVIWoVIVIo`000?moOgoo00000_mVIVH01?l0003oC4a<oda<C?l00009oc<c
<`04o`000?m<C4coC4a<o`0000;oIVIV00Go0000ogmoOol0003oVIVIo`000003ok>c/`03o`000?o<
c<coc<c<00Koc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV00Co0000oda<
C?m<C4co00002?lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>c
o`0000Woc<c<00Co0000ok>c/ol0003oVIVI0_l00008ooooo`008oooool3ofIVIP;o00002_moOgl0
0ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02onIVIT0
0ol0003oOgmoogmoO`09ogmoO`05o`000?mVIVKoIVIVofIVI_oo00002OmVIVH00ol0003oC4a<oda<
C00Hoda<C003o`000?mVIVKoIVIV00GoIVIV00?o0000ogmoOomoOgl00_oo00000omoOgoo0000oiVI
V@04oiVIV@03o`000?nc/k?o/k>c01?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`;o0000
0omVIVH00ol0003oC4a<oda<C002oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`0
0_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0
003oc<c<olc<c004olc<c0;oo`0000Go0000ok>c/onc/k?o/k>co`000002oiVIV@06o`000?moOgoo
Ogmoo`000?mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`07o`000?m<C4coC4a<oda<C?l0
003oIVIVo`000002ogmoO`03o`000?nIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`02?l0
003o/k>cok>c/ol0003oVIVIo`000?moOgoo00000_mVIVH00ol0003oC4a<o`000009oc<c<`0<o`00
0?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00002Oo<c<`01_l0003o/k>c
o`000?l0003oOgmoo`0000Sooooo000Sooooo`;oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003o
VIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01So/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003o
OgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?oo`00ofIVI_mVIVH01_mVIVH00ol0003o
C4a<oda<C00Hoda<C003o`000?mVIVKoIVIV00GoIVIV00?o0000ogmoOomoOgl00_moOgl00ooo003o
0000oiVIV@04oiVIV@03o`000?nc/k?o/k>c01?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmo
O`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`00_m<C4`00ol0003o<c<coc<c<`05oc<c
<`03o`000?m<C4coC4a<00;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`04o`000?nIVIWo
VIVIo`0000Co/k>c00?o0000olc<c?o<c<`01_o<c<`3ool00005ok>c/ol0003oVIVIoiVIVOl00000
0_moOgl00ol0003oIVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Oo0000oda<C?m<C4co
C4a<o`000?mVIVKo000000;oOgmo00?o0000oiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<
c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP03o`000?m<C4co000000Wo<c<c
00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00009olc<c006o`00
0?nc/k?o0000o`000?moOgoo00002?ooool002?ooooo00?oIVIVo`000?moOgl02_moOgl00ol0003o
VIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01So/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003o
OgmoogmoO`0:ogmoO`03o`000?mVIVKoIVIV00CoIVIV00?oo`00ofIVI_mVIVH01?mVIVH00ol0003o
C4a<oda<C00Hoda<C003o`000?mVIVKoIVIV00GoIVIV00?o0000ogmoOomoOgl00omoOgl00ol0003o
o`00ool00003oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003o
OgmoogmoOomoOgoo000000?oIVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`05oc<c
<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl0
0005ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o0000ok>c/onc/k<00_oo0002oiVIV@03o`000?mo
Ogoo000000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`09o`000?m<C4coC4a<oda<C?l0
003oIVIVo`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`02?l0003o/k>cok>c
/ol0003oVIVIo`000?moOgoo00000_mVIVH00ol0003oC4a<o`000009oc<c<`0<o`000?m<C4coC4a<
o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o00002Oo<c<`01_l0003o/k>co`000?l0003o
Ogmoo`0000Sooooo000Sooooo`03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT0
0ol0003o/k>cok>c/`0Hok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl0
0ol0003oIVIVofIVIP06ofIVIP03ool00?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`06?m<C4`0
0ol0003oIVIVofIVIP06ofIVIP03o`000?moOgooOgmo00?oOgmo00?o0000oiVIVOnIVIT00_oo0000
0onIVIWo0000ok>c/`0Dok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl00ol0003oIVIVofIV
IP02ofIVIP03o`000?m<C4coC4a<00;oC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<
C003oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003o
c<c<olc<c006olc<c006o`000?nc/k?o/k>cok>c/ol0003oVIVI0ooo00001?moOgoo0000ofIVI_l0
0003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo000000;o
Ogmo00?o0000oiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c006o`000?nc/k?o/k>co`00
0?nIVIWo00000_moOgl01Ol0003oIVIVo`000?m<C4co000000Wo<c<c00co0000oda<C?m<C4co0000
ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00009olc<c003o`000?nc/k?o/k>c00;o000000?o
Ogmoo`000?ooool01oooool002?ooooo2omoOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o
/k>c01Ko/k>c0_l0000<oiVIV@;o00002_moOgl2o`0000[oIVIV00Coo`00ofIVI_mVIVKo00006Om<
C4`2o`0000SoIVIV00?o0000ogmoOomoOgl00omoOgl00ol0003oVIVIoiVIV@03oiVIV@03ool00?l0
003o/k>c01?o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000?oIVIV
00?o0000oda<C?m<C4`00om<C4`00ol0003o<c<coc<c<`04oc<c<`;o00001?m<C4`01Ol0003oIVIV
ofIVI_mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c005olc<
c0;o00000onc/k<01Ol0003oVIVIoiVIVOl0003oOgmo00;oo`0000?oIVIVo`000?m<C4`00_m<C4`0
0ol0003o<c<coc<c<`06oc<c<`07o`000?m<C4coC4a<oda<C?l0003oIVIVo`000002ogmoO`03o`00
0?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`02?l0003o/k>cok>c/ol0003oVIVIo`00
0?moOgoo00000_mVIVH00ol0003oC4a<o`000009oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000
ogmoOol0003oVIVIo`000?nc/k?o00002Oo<c<`01ol0003o/k>co`000?nIVIWo0000ogmoOol00000
2?ooool002?ooooo2_moOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o
0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o
o`00o`000?m<C4`06Om<C4`00ol0003oIVIVofIVIP07ofIVIP03o`000?moOgooOgmo00?oOgmo00?o
0000oiVIVOnIVIT01?nIVIT2ool001?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000004ogmoO`05o`00
0?mVIVKoIVIVofIVI_l000001Om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?o
C4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000
olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`07o`000?nIVIWoVIVIo`000?moOgoo0000
ofIVIP03ool000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01ol0003oC4a<oda<C?m<C4co0000ofIV
I_l000000_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00So0000ok>c
/onc/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV00?o0000oda<C?l000002Olc<c<03?l0003oC4a<
oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Woc<c<00Oo0000ok>c/ol0003o
VIVIo`000?moOgoo000000Sooooo000Sooooo`WoOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o
/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003o
IVIVofIVIP0<ofIVIP03o`000?oo003oC4a<01SoC4a<00?o0000ofIVI_mVIVH01omVIVH00ol0003o
OgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00CoVIVI00Co0000ok>c/onc/k?oo`004Onc/k<00ol0
003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol000000omVIVH00ol0003oC4a<oda<C003
oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00om<C4`01Ol0003oIVIVofIVI_mV
IVKo000000;oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c005olc<c003o`00
0?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01Ol0003oIVIVofIVI_l0003oC4a<
00?oo`002?lc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00?o0000oiVIVOl000000_nc
/k<00ol0003oc<c<olc<c007olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIV
IP03o`000?m<C4co000000Wo<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo
00000_nc/k<00ol0003oc<c<olc<c006olc<c006o`000?nc/k?o0000oiVIVOl0003oOgmo0_l00008
ooooo`008oooool8ogmoO`03o`000?nIVIWoVIVI00coVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0
003oVIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH2o`00
00;oC4a<00?oo`00oda<C?m<C4`05Om<C4`00ol0003oIVIVofIVIP07ofIVIP03o`000?moOgooOgmo
00?oOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`02ok>c/`;oo`003_nc/k<00ol0
003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol000000omVIVH00ol0003oC4a<oda<C004
oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00om<C4`01?l0003oIVIVofIVI_l0
0002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c005o`00
0?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP06o`000?m<C4coC4a<
oda<C?l0003o<c<c0_oo0005oc<c<`07o`000?m<C4coC4a<oda<C?l0003oIVIVo`000002ogmoO`03
o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`02?l0003o/k>cok>c/ol0003oVIVI
o`000?moOgoo00000_mVIVH00ol0003oC4a<o`000009oc<c<`03o`000?m<C4co000000;oIVIV00Oo
0000ogmoOol0003oVIVIo`000?nc/k?o000000Woc<c<00Ko0000ok>c/ol0003oVIVIo`000?moOgl2
o`0000Sooooo000Sooooo`OoOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`0Fok>c
/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIV
IP03o`000?m<C4coC4a<00?oC4a<00?oo`00oda<C?m<C4`04om<C4`00ol0003oIVIVofIVIP07ofIV
IP03o`000?moOgooOgmo00?oOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`05ok>c
/`;oo`003?nc/k<00ol0003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol000000omVIVH0
0ol0003oC4a<oda<C003oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00om<C4`0
1?l0003oIVIVofIVI_l00002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000onc/k<00ol0003oc<c<
olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIV
IP05o`000?m<C4coC4a<oda<C?l000000olc<c<3ool000;o<c<c00Oo0000oda<C?m<C4coC4a<o`00
0?mVIVKo000000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c003o`00
0?nc/k?o000000;oVIVI00?o0000ogmoOol000000_mVIVH00ol0003oC4a<o`000008oc<c<`04o`00
0?m<C4coC4a<o`0000;oIVIV00Oo0000ogmoOol0003oVIVIo`000?nc/k?o000000Woc<c<00Ko0000
ok>c/ol0003oVIVIo`000?moOgl2o`0000Sooooo000Sooooo`KoOgmo00?o0000oiVIVOnIVIT03?nI
VIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl02?mo
Ogl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<00GoC4a<00?oo`00oda<C?m<C4`04Om<
C4`00ol0003oIVIVofIVIP07ofIVIP03o`000?moOgooOgmo00CoOgmo00?o0000oiVIVOnIVIT00onI
VIT00ol0003o/k>cok>c/`08ok>c/`03ool00?nc/k?o/k>c00Wo/k>c00Go0000oiVIVOnIVIWoVIVI
o`000003ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o<c<c
oc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01Ol0003o
VIVIoiVIVOnIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o
000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000Oo<c<c
0ooo0002oda<C003o`000?mVIVKo000000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<
olc<c007olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP04o`000?m<C4co
C4a<o`0000So<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol0
0009olc<c003o`000?nc/k?o000000;oVIVI0_l000000omVIVKo0000ooooo`07ooooo`008oooool5
ogmoO`03o`000?nIVIWoVIVI00_oVIVI0_l0000Hok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000
ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<00OoC4a<00?oo`00
oda<C?m<C4`03om<C4`00ol0003oIVIVofIVIP07ofIVIP03o`000?moOgooOgmo00CoOgmo00?o0000
oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`09ok>c/`;oo`002?nc/k<01Ol0003oVIVIoiVIVOnI
VIWo000000CoOgmo00Go0000ofIVI_mVIVKoIVIVo`000005oda<C003o`000?lc<c?o<c<c00Co<c<c
0_l00004oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01Ol0003oVIVIoiVIVOnIVIWo0000
00?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000
ogmoOomoOgoo00000_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`03o`000?m<C4coo`0000;oo`00
00CoIVIVo`000?moOgoo00000_nIVIT01?l0003o/k>cok>c/ol00009olc<c008o`000?nc/k?o/k>c
o`000?nIVIWo0000ogmoOol00002ofIVIP03o`000?m<C4co000000Wo<c<c00co0000oda<C?m<C4co
0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00009olc<c009o`000?nc/k?o0000oiVIVOl0
003oOgmoo`000?mVIVKo000000Sooooo000Sooooo`CoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0
003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl02?moOgl2o`00
00coIVIV00?o0000oda<C?m<C4`02Om<C4`00ooo003oC4a<oda<C00<oda<C0;o00002_mVIVH00ol0
003oOgmoogmoO`04ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<02onc/k<2ool0
00Ko/k>c00Go0000oiVIVOnIVIWoVIVIo`000004ogmoO`05o`000?mVIVKoIVIVofIVI_l000001Om<
C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Go0000ofIVI_mVIVKoIVIV
o`000002ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o
/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01?l0003oC4a<oda<C?l0
0009oc<c<`05o`000?m<C4coC4a<o`000?mVIVH00ooo00001?l0003oVIVIoiVIVOl00002ok>c/`03
o`000?o<c<coc<c<00Ooc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV00?o
0000oda<C?l000002Olc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o
/k>co`0000Woc<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000002?ooool002?o
oooo0omoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnI
VIT02onIVIT2o`0000[oOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00;oda<C003
ool00?m<C4coC4a<00[oC4a<00?o0000ofIVI_mVIVH02OmVIVH00ol0003oOgmoogmoO`04ogmoO`03
o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<03_nc/k<00ooo003o/k>cok>c/`02ok>c/`03
o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`000003ofIVIP03o`000?m<C4coC4a<
00?oC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C003oda<C005o`000?mVIVKoIVIV
ofIVI_l000000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<
c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01?l0003o
C4a<oda<C?l00009oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOomoOgl00ooo0002
ok>c/`03o`000?o<c<coc<c<00Ooc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`0000;o
IVIV00?o0000oda<C?l000002Olc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVI
VOl0003o/k>co`0000Woc<c<00?o0000ok>c/onc/k<00_l000001OmoOgoo0000ofIVI_mVIVKo0000
00Sooooo000Sooooo`;oOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Gok>c/`03
o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03
o`000?m<C4coC4a<00goC4a<00?oo`00oda<C?m<C4`02?m<C4`00ol0003oIVIVofIVIP09ofIVIP03
o`000?moOgooOgmo00CoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`0@ok>c/`;o
o`0000?o/k>co`000?nIVIT00onIVIT01Ol0003oOgmoogmoOomoOgoo000000?oIVIV00?o0000oda<
C?m<C4`01?m<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Co0000ofIV
I_mVIVKo00000omoOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go
0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Co0000oda<C?m<
C4co00002?lc<c<2o`0000;oC4a<00Ko0000ofIVI_mVIVKo0000ogmoOol00002oiVIV@04o`000?oo
003oo`00ool000Soc<c<00_o0000ok>c/onc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`00
0002oda<C003o`000?lc<c?o<c<c00Oo<c<c00?o0000oda<C?l000000_mVIVH01ol0003oOgmoo`00
0?nIVIWo0000ok>c/ol000002Oo<c<`02?l0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIV0_l0
0008ooooo`008oooool00omoOgoo0000oiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000
oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000
oda<C?m<C4`03om<C4`00ooo003oC4a<oda<C006oda<C003o`000?mVIVKoIVIV00WoIVIV00?o0000
ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c01?o/k>c0_oo0004
oiVIV@05o`000?moOgooOgmoogmoOol000000omVIVH00ol0003oC4a<oda<C004oda<C003o`000?lc
<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00om<C4`01?l0003oIVIVofIVI_l00003ogmoO`04o`00
0?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01oo<c<`01Ol0003o/k>cok>c/onc/k?o0000
00;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`05o`000?m<
C4coC4a<oda<C?l000000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000?o
o`001Oo<c<`02ol0003o/k>cok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<
00?o0000oc<c<olc<c<01olc<c<01Ol0003oC4a<o`000?mVIVKo000000;oOgmo00Go0000oiVIVOl0
003o/k>co`000008olc<c009o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIV00;o0000
2?ooool002?ooooo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nI
VIWoVIVI00_oVIVI0_l0000:ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`04Om<
C4`00ooo003oC4a<oda<C004oda<C003o`000?mVIVKoIVIV00WoIVIV00?o0000ogmoOomoOgl01Omo
Ogl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c01?o/k>c00Ko0000oiVIVOoo003oo`00
oiVIVOl00003ogmoO`05o`000?mVIVKoIVIVofIVI_l000001_m<C4`00ol0003o<c<coc<c<`04oc<c
<`03o`000?m<C4coC4a<00?oC4a<00Co0000ofIVI_mVIVKo00000omoOgl01?l0003oVIVIoiVIVOl0
0004ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`00
0?moOgooOgmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`000007oc<c<`03o`000?m<C4coC4a<
00;oC4a<00Go0000ofIVI_l0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Coc<c<0_oo
0002olc<c00;o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`0
0ol0003o<c<coc<c<`07oc<c<`03o`000?m<C4co000000;oIVIV00Go0000ogmoOol0003oVIVIo`00
0002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/ol0003oVIVIo`000002ogmoO`;o0000
00?oC4a<o`000?ooool01oooool002?ooooo3OnIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nI
VIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<
C4coC4a<01?oC4a<00Coo`00oda<C?m<C4coC4a<0_l0000;ofIVIP03o`000?moOgooOgmo00GoOgmo
00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`0Cok>c/`03o`000?nIVIWoVIVI00;oVIVI
0_oo0002ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`00om<C4`00ol0003o<c<c
oc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`05
o`000?nIVIWoVIVIoiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c003o`000?nc/k?o/k>c
00;o/k>c00Ko0000oiVIVOnIVIWo0000ogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<C?l00000
2?lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o
/k>cok>c/ol00006olc<c0?oo`000_nc/k<02?l0003oVIVIoiVIVOl0003oOgmoo`000?mVIVKo0000
0_m<C4`00ol0003o<c<coc<c<`07oc<c<`03o`000?m<C4co000000;oIVIV00Oo0000ogmoOol0003o
VIVIo`000?nc/k?o000000Woc<c<00_o0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003o
C4a<o`000008ooooo`008oooool<oiVIV@03o`000?nc/k?o/k>c01So/k>c00?o0000oiVIVOnIVIT0
2_nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00coIVIV00?o0000oda<C?m<C4`0
5?m<C4`00ooo003oC4a<o`00000=ofIVIP03o`000?moOgooOgmo00GoOgmo00?o0000oiVIVOnIVIT0
1?nIVIT00ol0003o/k>cok>c/`0Cok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOooo003o
Ogmoo`000004ofIVIP03o`000?m<C4coC4a<00?oC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003o
C4a<oda<C003oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01Ol0003oVIVIoiVIVOnIVIWo
000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003o/k>cok>c/`02ok>c/`06o`000?nIVIWo
VIVIo`000?moOgoo00000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Go0000oda<C?m<
C4coC4a<o`000002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`0
1?l0003oo`00ool00?oo0002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<c
oc<c<`07oc<c<`03o`000?m<C4co000000;oIVIV00Oo0000ogmoOol0003oVIVIo`000?nc/k?o0000
00Woc<c<00_o0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`000008ooooo`00
6_ooool2o`000003oa0@4?oooooooooo00Cooooo2onIVIT00ol0003o/k>cok>c/`0Hok>c/`03o`00
0?nIVIWoVIVI00[oVIVI00?o0000ogmoOomoOgl02_moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`00
0?m<C4coC4a<01KoC4a<00?oo`00ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`05ogmoO`03o`00
0?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc/k<04onc/k<00ol0003oVIVIoiVIV@03oiVIV@03o`00
0?moOgooOgmo00;oo`000omVIVH00ol0003oC4a<oda<C004oda<C003o`000?lc<c?o<c<c00Co<c<c
00?o0000oda<C?m<C4`00om<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Co0000oiVIVOnI
VIWo00001?nc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT0
1?l0003oOgmoogmoOol00002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01Ol0003oC4a<
oda<C?m<C4co000000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<
00Ooc<c<00Co0000ok>c/onc/k?o00000_oo00001Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o
0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP07o`000?moOgoo0000oiVIVOl0
003o/k>co`000009olc<c00;o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo0000oda<C?l0
00002?ooool001_ooooo00?o0000ooooooooool01Oooool:oiVIV@03o`000?nc/k?o/k>c01So/k>c
00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV
00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVool0000<ofIVIP03o`000?moOgooOgmo00CoOgmo
00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`0Cok>c/`03o`000?nIVIWoVIVI00?oVIVI
00Ko0000ogmoOomoOgooOgmoo`000?mVIVH2ool00003ofIVI_l0003oC4a<00CoC4a<00?o0000oc<c
<olc<c<01?lc<c<00ol0003oC4a<oda<C003oda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl0
1?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00?o0000ok>c/onc/k<00_nc
/k<01_l0003oVIVIoiVIVOl0003oOgmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c
<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o
/k>co`0000Woc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00003ool00005o`000?m<C4coC4a<oda<
C?l000002?lc<c<00ol0003oC4a<o`000002ofIVIP07o`000?moOgoo0000oiVIVOl0003o/k>co`00
0009olc<c003o`000?nc/k?o000000;oVIVI0_l000001OmVIVKo0000oda<C?m<C4co000000Sooooo
000Hooooo`Go00001_ooool:oiVIV@03o`000?nc/k?o/k>c01Ko/k>c0_l0000<oiVIV@;o00002_mo
Ogl2o`0000goIVIV00?o0000oda<C?m<C4`05_m<C4`2o`0000;oIVIV00?oo`00ofIVI_mVIVH01omV
IVH2o`0000KoOgmo00?o0000oiVIVOnIVIT01OnIVIT00ol0003o/k>cok>c/`0Cok>c/`03o`000?nI
VIWoVIVI00;oVIVI00?o0000ogmoOomoOgl00_moOgl01?l0003oIVIVofIVI_mVIVH2ool000GoC4a<
00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C003oda<C005o`000?mVIVKoIVIVofIVI_l0
00000_moOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c
/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<
o`000008oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH00ol0003oOgmoo`000002oiVIV@04
o`000?nc/k?o/k>co`0000Soc<c<00Co0000ok>c/onc/k?o00000_nIVIT01?l0003oOgmoo`000?mV
IVH3ool00003o`000?lc<c?o<c<c00Oo<c<c00?o0000oda<C?l000000_mVIVH3o`000004oiVIVOl0
003o/k>co`0000Woc<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`0
0ol0003oooooooooo`06ooooo`006?ooool01?m4A4CogMgMooooool00007ooooo`WoVIVI00?o0000
ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000
ofIVI_mVIVH03?mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00?oIVIV00?oo`00
ofIVI_mVIVH01_mVIVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00GoVIVI00?o0000
ok>c/onc/k<04onc/k<00ol0003oVIVIoiVIV@02oiVIV@03o`000?moOgooOgmo00;oOgmo00Oo0000
ofIVI_mVIVKoIVIVo`000?m<C4coo`0000CoC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<
oda<C003oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00004ok>c
/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgoo
Ogmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`05o`000?m<C4coC4a<oda<C?l0
00000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00Co0000ok>c
/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<0ooo0007oc<c<`03o`000?m<
C4co000000;oIVIV0_l00002oiVIV@03o`000?nc/k?o000000Woc<c<00Wo0000ok>c/ol0003oVIVI
o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003oooooooooo`06ooooo`006?ooool01?oMgMgo
EEEEooooool00007ooooo`SoVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0<oiVI
V@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH03?mVIVH00ol0003oC4a<oda<C00Foda<
C003o`000?mVIVKoIVIV00GoIVIV00?oo`00ofIVI_mVIVH01?mVIVH00ol0003oOgmoogmoO`05ogmo
O`03o`000?nIVIWoVIVI00GoVIVI00?o0000ok>c/onc/k<04onc/k<00ol0003oVIVIoiVIV@02oiVI
V@03o`000?moOgooOgmo00;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000003oda<C0;oo`0000?oC4a<
o`000?lc<c<01Olc<c<00ol0003oC4a<oda<C003oda<C005o`000?mVIVKoIVIVofIVI_l000000_mo
Ogl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o
/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000?oIVIV00Co0000oda<C?m<C4co00002?lc<c<0
1Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c
/ol00009olc<c003o`000?nc/k?o000000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C004
o`000?lc<c?o<c<coc<c<`?oo`000olc<c<00ol0003oC4a<o`000002ofIVIP05o`000?moOgoo0000
oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c007o`000?nc/k?o0000oiVIVOl0003oOgmo
o`000002ofIVIP04o`000?m<C4co0000o`0000Sooooo000Iooooo`03ogMgMoo<c<co000000Oooooo
1onIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI0_l0000:ogmoO`03o`00
0?mVIVKoIVIV00coIVIV00?o0000oda<C?m<C4`05_m<C4`2o`0000SoIVIV00?oo`00ofIVI_mVIVH0
0_mVIVH00ol0003oOgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00GoVIVI00?o0000ok>c/onc/k<0
4onc/k<00ol0003oVIVIoiVIV@03oiVIV@05o`000?moOgooOgmoogmoOol000001?mVIVH00ol0003o
C4a<oda<C003oda<C0;oo`001Olc<c<00ol0003oC4a<oda<C003oda<C005o`000?mVIVKoIVIVofIV
I_l000000omoOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000
ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Go0000oda<C?m<C4co
C4a<o`000008oc<c<`03o`000?m<C4coC4a<00;o000000OoIVIVo`000?moOgooOgmoo`000?nIVIWo
000000;o/k>c00?o0000olc<c?o<c<`02?o<c<`00ol0003o/k>co`000002oiVIV@05o`000?moOgoo
0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`04oc<c<`?oo`0000?o0000oda<C?l000000_mV
IVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02Ol0003o/k>c
o`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C0;o00002?ooool001Wooooo00?ok^k^odA4
A?l000001oooool6oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0
003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00coIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0
003oIVIVofIVIP09ofIVIP04ool00?mVIVKoIVIVo`0000SoOgmo00?o0000oiVIVOnIVIT01?nIVIT0
0ol0003o/k>cok>c/`0Dok>c/`03o`000?nIVIWoVIVI00?oVIVI00Go0000ogmoOomoOgooOgmoo`00
0004ofIVIP03o`000?m<C4coC4a<00?oC4a<00?o0000oc<c<ooo00000_oo0002oc<c<`03o`000?m<
C4coC4a<00?oC4a<00Co0000ofIVI_mVIVKo00001?moOgl01?l0003oVIVIoiVIVOl00004ok>c/`03
o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmo
o`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV
00Ko0000ogmoOomoOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Soc<c<00?o0000ok>c
/ol000000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01olc<c<3
ool00007ofIVI_l0003oOgmoogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Goc<c<
00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`2o`0000Sooooo000J
ooooo`03ogMgMol0003ooooo00Kooooo1OnIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWo
VIVI00coVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4co
C4a<01KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ooo003o0000ogmoO`07ogmoO`03o`000?nIVIWo
VIVI00GoVIVI00?o0000ok>c/onc/k<04onc/k<00ol0003oVIVIoiVIV@03oiVIV@05o`000?moOgoo
OgmoogmoOol000001?mVIVH00ol0003oC4a<oda<C003oda<C003o`000?lc<c?o<c<c00?o<c<c0_oo
0005oda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01?l0003oVIVIoiVIVOl00004ok>c/`03
o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmo
o`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV
00Ko0000ogmoOomoOgoo0000oiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Ooc<c<00?o0000ok>c
/ol000000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01olc<c<0
1?l0003oC4a<o`000?mVIVH3ool00003o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<
c<`01Ol0003o/k>co`000?nIVIWo000000;oOgmo0_l00002oda<C003o`000?lc<c?o000000Sooooo
000Sooooo`?oVIVI0_l0000Hok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl02?mo
Ogl00ol0003oIVIVofIVIP0;ofIVIP;o00006?m<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?oo
003oo`0000GoOgmo0_l00007oiVIV@03o`000?nc/k?o/k>c01Co/k>c00?o0000oiVIVOnIVIT00_nI
VIT01Ol0003oOgmoogmoOomoOgoo000000CoIVIV00?o0000oda<C?m<C4`01?m<C4`00ol0003o<c<c
oc<c<`04oc<c<`03o`000?oo003oo`0000?oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`05
o`000?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c
00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00002oda<C003o`000?lc
<c?o<c<c00Oo<c<c00Co0000oda<C?m<C4co00000_mVIVH01_l0003oOgmoogmoOol0003oVIVIo`00
00?o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@05o`000?moOgoo
0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`03o`000?m<C4co000000;oIVIV00?o
0000ogmoOooo00000ooo00000ol0003oc<c<olc<c007olc<c009o`000?nc/k?o0000oiVIVOl0003o
Ogmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<ol000002?ooool002?ooooo0_nIVIT00ol0003o
/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl02?moOgl2o`0000co
IVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0<ofIVIP05o`000?moOgooOgmoogmo
Oooo00001?moOgl00ol0003oVIVIoiVIV@06oiVIV@03o`000?nc/k?o/k>c01Co/k>c00?o0000oiVI
VOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000CoIVIV00?o0000oda<C?m<C4`01?m<C4`0
0ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oo`0000Go0000ofIVI_mVIVKoIVIVo`00
0002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0003oc<c<olc<c005olc<c003o`00
0?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00002oda<
C003o`000?lc<c?o<c<c00Oo<c<c00Co0000oda<C?m<C4co00000_mVIVH01_l0003oOgmoogmoOol0
003oVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@05
o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`03o`000?m<C4co0000
00;oIVIV00Co0000ogmoOol0003o00000_nc/k<3ool000Ooc<c<00Wo0000ok>c/ol0003oVIVIo`00
0?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<co`000008ooooo`008oooool00onIVIWo0000
ok>c/`0Hok>c/`03o`000?nIVIWoVIVI00_oVIVI0_l0000:ogmoO`03o`000?mVIVKoIVIV00_oIVIV
00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?moOgooOgmo00?oOgmo
0_oo00000omoOgoo0000oiVIV@07oiVIV@03o`000?nc/k?o/k>c01Co/k>c00?o0000oiVIVOnIVIT0
0_nIVIT01Ol0003oOgmoogmoOomoOgoo000000CoIVIV00?o0000oda<C?m<C4`01?m<C4`00ol0003o
<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Go0000ool00?oo003oIVIVo`000002ogmo
O`05o`000?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o
/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000Wo
<c<c00Co0000oda<C?m<C4co00000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@04o`000?nc/k?o
/k>co`0000Woc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`0
0ol0003o<c<coc<c<`07oc<c<`0<o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`00
0?nc/k?o00000oo<c<`3ool000?oc<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0
00000_m<C4`01?l0003o<c<coc<c<ol00008ooooo`008oooool00ol0003o/k>cok>c/`0Gok>c/`03
o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03
o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmoO`06ogmoO`03
ool00?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc/k<05?nc/k<00ol0003oVIVIoiVIV@02oiVIV@03
o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C004oda<C003
o`000?lc<c?o<c<c00?o<c<c00?o0000oda<C?m<C4`00om<C4`01?l0003oIVIVofIVI_mVIVH2ool0
00;oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o
/k>cok>c/ol000000onIVIT00ol0003oOgmoo`000002ofIVIP05o`000?m<C4coC4a<oda<C?l00000
2Olc<c<01?l0003oC4a<oda<C?l00002ofIVIP06o`000?moOgooOgmoo`000?nIVIWo00000_nc/k<0
0ol0003oc<c<olc<c007olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Go0000ogmoOol0003oIVIV
o`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH01ol0003o
Ogmoo`000?nIVIWo0000ok>c/ol000001_o<c<`3ool00009o`000?nc/k?o0000oiVIVOl0003oOgmo
o`000?mVIVKo000000;oC4a<00Co0000oc<c<olc<c?o00002?ooool002?ooooo6Onc/k<00ol0003o
VIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003o
C4a<oda<C00Hoda<C003o`000?mVIVKoIVIV00[oIVIV0_l00009ogmoO`03o`000?oo003oVIVI00Ko
VIVI00?o0000ok>c/onc/k<04onc/k<00ol0003oVIVIoiVIV@03oiVIV@03o`000?moOgooOgmo00;o
Ogmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C003oda<C003o`000?lc<c?o<c<c00Co
<c<c00?o0000oda<C?m<C4`00om<C4`01_l0003oIVIVofIVI_mVIVKo0000ogmoO`?oo`000_nIVIT0
0ol0003o/k>cok>c/`02ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`00
0002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`07
o`000?m<C4coC4a<oda<C?l0003oIVIVo`000003ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000
olc<c?o<c<`01oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l00000
0_m<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV0_l00002oiVIV@03
o`000?nc/k?o000000Woc<c<0ooo00001_nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00Co0000
oc<c<olc<c?o00002?ooool002?ooooo6?nc/k<00ol0003oVIVIoiVIV@0;oiVIV@;o00002_moOgl0
0ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01SoC4a<00?o0000ofIVI_mVIVH02_mVIVH0
0ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00;oo`001?nIVIT00ol0003o/k>cok>c/`0D
ok>c/`03o`000?nIVIWoVIVI00;oVIVI00?o0000ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP02
ofIVIP03o`000?m<C4coC4a<00CoC4a<00?o0000oc<c<olc<c<00olc<c<00ol0003oC4a<oda<C004
oda<C004o`000?mVIVKoIVIVo`0000?oOgmo00Co0000oiVIVOoo003oo`001?nc/k<00ol0003oc<c<
olc<c006olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl00ol0003o
IVIVo`000004oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH01_l0
003oOgmoogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01oo<c<`01?l0003o/k>cok>c
/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`04
o`000?m<C4coC4a<o`0000;oIVIV00Oo0000ogmoOol0003oVIVIo`000?nc/k?o000000Woc<c<00Co
0000ok>c/ol0003oVIVI0ooo0002ofIVIP03o`000?m<C4co000000?o<c<c00?o0000ooooooooool0
1_ooool002?ooooo5onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o
0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Goda<C0;o00003?mVIVH00ol0003oOgmoogmo
O`08ogmoO`03o`000?nIVIWoVIVI00?oVIVI00Coo`00oiVIVOnIVIWo00005_nc/k<00ol0003oVIVI
oiVIV@02oiVIV@03o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<
oda<C004oda<C003o`000?lc<c?o<c<c00?o<c<c00?o0000oda<C?m<C4`01?m<C4`01Ol0003oIVIV
ofIVI_mVIVKo000000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000002ool00003ok>c/ol0003oc<c<
00Soc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Go
0000oda<C?m<C4coC4a<o`000008oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH00ol0003o
Ogmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Woc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl0
0002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01_l0003oC4a<oda<
C?l0003oIVIVo`0000;oOgmo00Go0000oiVIVOl0003o/k>co`000009olc<c007o`000?nc/k?o0000
oiVIVOl0003oOgmoo`000004ool00005o`000?lc<c?o<c<coc<c<ol000002?ooool002?ooooo5onc
/k<00ol0003oVIVIoiVIV@0:oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH03?mV
IVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomoOgl02?mo
Ogl00ol0003oVIVIoiVIV@05oiVIV@;oo`0000?o0000ok>c/onc/k<05?nc/k<00ol0003oVIVIoiVI
V@02oiVIV@03o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<
C004oda<C003o`000?lc<c?o<c<c00?o<c<c00?o0000oda<C?m<C4`01?m<C4`01Ol0003oIVIVofIV
I_mVIVKo000000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000002ok>c/`;oo`002Oo<c<`01Ol0003o
/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01Ol0003oC4a<oda<C?m<
C4co000000So<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP03o`000?moOgoo000000;oVIVI
00Co0000ok>c/onc/k?o00002Oo<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00?o0000
ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo0000
0_moOgl01Ol0003oVIVIo`000?nc/k?o000000Woc<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo
0000ofIVI_l000000_m<C4`3ool00003oc<c<ol0003ooooo00Oooooo000SoooooaKo/k>c00?o0000
oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`0:ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000
oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?moOgooOgmo00OoOgmo00?o0000
oiVIVOnIVIT01onIVIT00ol0003oo`00ok>c/`0Dok>c/`03o`000?nIVIWoVIVI00;oVIVI00?o0000
ogmoOomoOgl00_moOgl00ol0003oIVIVofIVIP02ofIVIP03o`000?m<C4coC4a<00GoC4a<00?o0000
oc<c<olc<c<00_lc<c<00ol0003oC4a<oda<C004oda<C005o`000?mVIVKoIVIVofIVI_l000000omo
Ogl01Ol0003oVIVIoiVIVOnIVIWo000000?o/k>c00Co0000ool00?oo003oo`001Oo<c<`00ol0003o
/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co0000ofIVI_mVIVKo00000_m<C4`0
0ol0003o<c<coc<c<`07oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH00ol0003oOgmoo`00
0002oiVIV@04o`000?nc/k?o/k>co`0000Woc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl00002ogmo
O`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01_l0003oC4a<oda<C?l0003o
IVIVo`0000;oOgmo00Co0000oiVIVOl0003o00002Oo<c<`01Ol0003o/k>cok>c/ol0003oVIVI00;o
00000_mVIVH01?l0003oC4a<oda<C?l00002oc<c<`;oo`002?ooool002?ooooo5Onc/k<00ol0003o
VIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003o
C4a<oda<C00Foda<C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003o
VIVIoiVIV@06oiVIV@04o`000?nc/k?o/k>cool001?o/k>c00?o0000oiVIVOnIVIT00onIVIT00ol0
003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<C?m<C4`01?m<C4`00ol0
003o<c<coc<c<`03oc<c<`03o`000?m<C4coC4a<00CoC4a<00Go0000ofIVI_mVIVKoIVIVo`000002
ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc/k<01?l0003oc<c<olc<c?o<c<`2ool000;oc<c<
00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`00
00?oC4a<00?o0000oc<c<olc<c<01olc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo
000000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@05o`00
0?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`06o`000?m<C4coC4a<o`00
0?mVIVKo00000_moOgl01Ol0003oVIVIo`000?nc/k?o000000Woc<c<00Wo0000ok>c/ol0003oVIVI
o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`02oc<c<`03o`000?oooooooooo
00Kooooo000Soooooa?o/k>c0_l0000<oiVIV@;o00002_moOgl2o`0000goIVIV00?o0000oda<C?m<
C4`05_m<C4`2o`0000coIVIV0_l0000:ogmoO`03o`000?nIVIWoVIVI00KoVIVI00?o0000ok>c/onc
/k<00_nc/k<2ool0017o/k>c00?o0000oiVIVOnIVIT00onIVIT01Ol0003oOgmoogmoOomoOgoo0000
00CoIVIV00?o0000oda<C?m<C4`01Om<C4`00ol0003o<c<coc<c<`03oc<c<`03o`000?m<C4coC4a<
00?oC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc
/k<00ol0003oc<c<olc<c003olc<c0;oo`0000?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVI
VOl00002ogmoO`04o`000?mVIVKoIVIVo`0000;oC4a<00?o0000oc<c<olc<c<02?lc<c<01?l0003o
C4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`2
o`0000;o/k>c00?o0000oiVIVOl000000_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o
<c<c00Ko<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`05o`000?nIVIWo0000ok>c/ol0
00002Oo<c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc
<c?o<c<c00;o<c<c00?o0000ooooooooool01_ooool002?ooooo4_nc/k<00ol0003oVIVIoiVIV@0;
oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH03?mVIVH00ol0003oC4a<oda<C00F
oda<C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@06
oiVIV@03o`000?nc/k?o/k>c00Go/k>c00?oo`00ok>c/onc/k<03_nc/k<00ol0003oVIVIoiVIV@03
oiVIV@04o`000?moOgooOgmoo`0000GoIVIV00?o0000oda<C?m<C4`01?m<C4`00ol0003o<c<coc<c
<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`05o`00
0?nIVIWoVIVIoiVIVOl000000onc/k<00ol0003oc<c<olc<c006olc<c0;oo`000onc/k<01?l0003o
VIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000;oC4a<00?o0000oc<c<olc<c<02?lc<c<0
1?l0003oC4a<oda<C?l00002ofIVIP;o00000onIVIT01?l0003o/k>cok>c/ol00008olc<c007o`00
0?nc/k?o/k>cok>c/ol0003oVIVIo`000002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c
<olc<c<01_lc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo0_l00002ok>c/`03o`000?o<
c<coc<c<00Ooc<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0
003o<c<coc<c<`02oc<c<`03o`000?oooooooooo00Kooooo000Soooooa7o/k>c00?o0000oiVIVOnI
VIT03?nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00coIVIV00?o0000oda<C?m<
C4`05_m<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnI
VIT01_nIVIT00ol0003o/k>cok>c/`07ok>c/`;oo`003Onc/k<00ol0003oVIVIoiVIV@03oiVIV@05
o`000?moOgooOgmoogmoOol000001?mVIVH00ol0003oC4a<oda<C005oda<C003o`000?lc<c?o<c<c
00?o<c<c00?o0000oda<C?m<C4`00om<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Go0000
oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_oo
00001?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc
<c<01olc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00Go0000ok>c
/onc/k?o/k>co`000007olc<c007o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000002ogmoO`03o`00
0?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01olc<c<01Ol0003oC4a<o`000?mVIVKo000000;o
Ogmo00Go0000oiVIVOl0003o/k>co`000009olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`00
0?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<00olc<c<00ol0003oooooooooo`06ooooo`008ooo
ool@ok>c/`03o`000?nIVIWoVIVI00_oVIVI0_l0000:ogmoO`03o`000?mVIVKoIVIV00coIVIV00?o
0000oda<C?m<C4`05_m<C4`2o`0000goIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVI
V@07oiVIV@03o`000?nc/k?o/k>c00Wo/k>c00?oo`00ok>c/onc/k<02Onc/k<00ol0003oVIVIoiVI
V@03oiVIV@03o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<
C004oda<C003o`000?lc<c?o<c<c00?o<c<c00?o0000oda<C?m<C4`01?m<C4`01Ol0003oIVIVofIV
I_mVIVKo000000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Ko
c<c<00Go0000ok>c/onc/k?o/k>co`000003ool00004o`000?moOgooOgmoo`0000;oIVIV00Go0000
oda<C?m<C4coC4a<o`000008oc<c<`07o`000?m<C4coC4a<oda<C?l0003oIVIVo`000002ogmoO`04
o`000?nIVIWoVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01ol0003o/k>cok>c/onc/k?o
0000oiVIVOl000000_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00Ko
0000oda<C?m<C4co0000ofIVI_l00002ogmoO`05o`000?nIVIWo0000ok>c/ol000002Oo<c<`02Ol0
003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00?o<c<c
00?o0000ooooooooool01_ooool002?ooooo3onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?mo
OgooOgmo00WoOgmo00?o0000ofIVI_mVIVH03?mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mV
IVKoIVIV00coIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@07oiVIV@03o`000?nc
/k?o/k>c00[o/k>c00?oo`00ok>c/onc/k<01onc/k<00ol0003oVIVIoiVIV@03oiVIV@03o`000?mo
OgooOgmo00?oOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C004oda<C003o`000?lc
<c?o<c<c00;o<c<c00?o0000oda<C?m<C4`01Om<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo
00Co0000oiVIVOnIVIWo00001Onc/k<00ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c
/ol000000onIVIT2ool00005ogmoOol0003oIVIVofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07
oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01?l0003o/k>c
ok>c/ol00008olc<c007o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000002ogmoO`03o`000?mVIVKo
000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo
00000_nIVIT00ol0003o/k>co`000009olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mV
IVKo000000;oC4a<00?o0000oc<c<olc<c<00olc<c<00ol0003oooooooooo`06ooooo`008oooool>
ok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0<
ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmoO`09
ogmoO`03o`000?nIVIWoVIVI00OoVIVI00?o0000ok>c/onc/k<03?nc/k<2ool000Oo/k>c00?o0000
oiVIVOnIVIT00onIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000
oda<C?m<C4`01?m<C4`00ol0003o<c<coc<c<`02oc<c<`03o`000?m<C4coC4a<00GoC4a<00Go0000
ofIVI_mVIVKoIVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0003oc<c<
olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000onIVIT00ol0003oOgmoogmoO`02ool00003
ofIVI_l0003oC4a<00;oC4a<00?o0000oc<c<olc<c<01_lc<c<01ol0003oC4a<oda<C?m<C4co0000
ofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Ko
0000ok>c/onc/k?o0000oiVIVOl00002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc
<c<01_lc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo00Go0000oiVIVOl0003o/k>co`00
0009olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000?oC4a<00?o0000oc<c
<olc<c<00olc<c<00ol0003oooooooooo`06ooooo`008oooool=ok>c/`03o`000?nIVIWoVIVI00co
VIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP;o00006?m<C4`00ol0003o
IVIVofIVIP0<ofIVIP03o`000?moOgooOgmo00SoOgmo0_l00009oiVIV@03o`000?nc/k?o/k>c00oo
/k>c00?oo`00ok>c/onc/k<00onc/k<00ol0003oVIVIoiVIV@03oiVIV@03o`000?moOgooOgmo00;o
Ogmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<C005oda<C003o`000?lc<c?o<c<c00;o
<c<c00?o0000oda<C?m<C4`01?m<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Go0000oiVI
VOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<0
1?l0003oVIVIoiVIVOl00002ogmoO`03o`000?mVIVKoIVIV00?oo`0000?oC4a<o`000?lc<c<02?lc
<c<01?l0003oC4a<oda<C?l00002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Co0000ok>c/onc
/k?o00002Oo<c<`02?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo00000_mVIVH00ol0003oC4a<
o`000009oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl01Ol0003oVIVIo`000?nc/k?o
000000Woc<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o
<c<coc<c<`04oc<c<`03o`000?oooooooooo00Kooooo000Sooooo`co/k>c00?o0000oiVIVOnIVIT0
3?nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`0
5om<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT0
2?nIVIT00ol0003o/k>cok>c/`0Aok>c/`;oo`000onc/k<00ol0003oVIVIoiVIV@03oiVIV@05o`00
0?moOgooOgmoogmoOol000001OmVIVH00ol0003oC4a<oda<C005oda<C003o`000?lc<c?o<c<c00;o
<c<c00?o0000oda<C?m<C4`01?m<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Go0000oiVI
VOnIVIWoVIVIo`000004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<0
1?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKoIVIVo`0000;oC4a<0ooo0008oc<c<`04o`00
0?m<C4coC4a<o`0000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01?l0003o/k>cok>c/ol00009
olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP03o`000?m<C4co000000Wo
<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`05o`000?nIVIWo0000ok>c/ol000002Oo<
c<`02Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c
00Co<c<c00?o0000ooooooooool01_ooool002?ooooo2onc/k<00ol0003oVIVIoiVIV@0;oiVIV@;o
00002_moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mV
IVH03?mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00WoVIVI00?o0000ok>c/onc
/k<04onc/k<00ooo003o/k>co`000005oiVIV@03o`000?moOgooOgmo00;oOgmo00?o0000ofIVI_mV
IVH00_mVIVH00ol0003oC4a<oda<C005oda<C003o`000?lc<c?o<c<c00;o<c<c00?o0000oda<C?m<
C4`01Om<C4`01?l0003oIVIVofIVI_l00003ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc/k<0
0ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_mo
Ogl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00?oo`001?lc<c<01?l0003oC4a<
oda<C?l00002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`0
1?l0003o/k>cok>c/ol00002oiVIV@;o00000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`04o`00
0?m<C4coC4a<o`0000;oIVIV00Oo0000ogmoOol0003oVIVIo`000?nc/k?o000000Woc<c<00?o0000
ok>c/onc/k<00_l000001?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Go<c<c00?o
0000ooooooooool01_ooool002?ooooo2_nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgoo
Ogmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKo
IVIV00coIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@09oiVIV@03o`000?nc/k?o
/k>c01Co/k>c00?o0000ool00?nIVIT01?nIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKo
IVIV00;oIVIV00?o0000oda<C?m<C4`01_m<C4`01Ol0003o<c<coc<c<olc<c?o000000OoC4a<00Go
0000ofIVI_mVIVKoIVIVo`000003ogmoO`04o`000?nIVIWoVIVIo`0000Go/k>c00?o0000olc<c?o<
c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Co0000ofIV
I_mVIVKo00000om<C4`00ol0003o<c<coc<c<`03oc<c<`;oo`000_lc<c<01?l0003oC4a<oda<C?l0
0002ofIVIP06o`000?moOgooOgmoo`000?nIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c003
o`000?nc/k?o/k>c00;o000000CoVIVIo`000?moOgoo00000_mVIVH01?l0003oC4a<oda<C?l00008
oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVIV@03o`000?nc/k?o000000Wo
c<c<00_o0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0003oC4a<o`000008oc<c<`03o`00
0?oooooooooo00Kooooo000Sooooo`Wo/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmo
O`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`06?m<C4`00ol0003oIVIVofIV
IP0:ofIVIP;o00002_moOgl00ol0003oVIVIoiVIV@09oiVIV@03o`000?nc/k?o/k>c01Go/k>c00Co
0000oiVIVOoo003oo`000onIVIT00ol0003oOgmoogmoO`02ogmoO`03o`000?mVIVKoIVIV00;oIVIV
00?o0000oda<C?m<C4`01_m<C4`01Ol0003o<c<coc<c<olc<c?o000000OoC4a<00Go0000ofIVI_mV
IVKoIVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001Onc/k<00ol0003oc<c<olc<c005
olc<c005o`000?nc/k?o/k>cok>c/ol000000onIVIT01?l0003oOgmoogmoOol00002ofIVIP05o`00
0?m<C4coC4a<oda<C?l000001olc<c<3ool000;oC4a<00Ko0000ofIVI_mVIVKo0000ogmoOol00002
oiVIV@05o`000?nc/k?o/k>cok>c/ol000002?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`00
0?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<02?l0003oC4a<oda<C?l0003oIVIV
o`000?moOgoo00000_nIVIT00ol0003o/k>co`000009olc<c00;o`000?nc/k?o0000oiVIVOl0003o
Ogmoo`000?mVIVKo0000oda<C?l000002?lc<c<00ol0003oooooooooo`06ooooo`008oooool8ok>c
/`03o`000?nIVIWoVIVI00_oVIVI0_l0000:ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<
C?m<C4`06?m<C4`00ol0003oIVIVofIVIP0:ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVI
VOnIVIT02OnIVIT00ol0003o/k>cok>c/`0Eok>c/`03o`000?nIVIWoVIVI00;oVIVI00?oo`00oiVI
VOl000001?moOgl00ol0003oIVIVofIVIP02ofIVIP03o`000?m<C4coC4a<00KoC4a<00Go0000oc<c
<olc<c?o<c<co`000007oda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl01?l0003oVIVIoiVI
VOl00005ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01Ol0003oVIVI
oiVIVOnIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo00000_m<C4`00ol0003o<c<coc<c<`07oc<c
<`03o`000?m<C4coo`0000;oo`0000OoIVIVo`000?moOgooOgmoo`000?nIVIWo000000?o/k>c00?o
0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV
00Co0000oda<C?m<C4co00002Olc<c<00ol0003oC4a<oda<C002o`000007ogmoOol0003oVIVIoiVI
VOl0003o/k>co`000009olc<c005o`000?nc/k?o0000oiVIVOl000000_moOgl2o`0000;oC4a<00?o
0000oc<c<olc<c<01_lc<c<00ol0003oooooooooo`06ooooo`008oooool7ok>c/`03o`000?nIVIWo
VIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4co
C4a<01OoC4a<0_l0000<ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02OnIVIT0
0ol0003o/k>cok>c/`0Eok>c/`03o`000?nIVIWoVIVI00CoVIVI0_oo0003ogmoO`03o`000?mVIVKo
IVIV00?oIVIV00?o0000oda<C?m<C4`01Om<C4`01Ol0003o<c<coc<c<olc<c?o000000OoC4a<00Go
0000ofIVI_mVIVKoIVIVo`000003ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0003o
c<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000onIVIT01?l0003oOgmoogmoOol00002
ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01_l0003oC4a<oda<C?m<C4co0000ofIVIP;o
o`000_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Co0000ok>c/onc
/k?o00000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00So0000
oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000;oVIVI00?o0000ok>c/ol000002Oo<c<`02Ol0003o
/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00?o
0000ooooooooool01_ooool002?ooooo1_nc/k<00ol0003oVIVIoiVIV@0<oiVIV@03o`000?moOgoo
Ogmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Hoda<C003o`000?mVIVKo
IVIV00[oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0:oiVIV@03o`000?nc/k?o
/k>c01Go/k>c00?o0000oiVIVOnIVIT01?nIVIT01_l0003oOgmoool00?oo003oOgmoo`0000GoIVIV
00?o0000oda<C?m<C4`01Om<C4`01Ol0003o<c<coc<c<olc<c?o000000OoC4a<00Go0000ofIVI_mV
IVKoIVIVo`000003ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0003oc<c<olc<c005
olc<c003o`000?nc/k?o/k>c00;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`04o`000?mV
IVKoIVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;o
IVIV00Ko0000ool00?oo003oo`00oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Co0000
ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c
00So0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000;oVIVI00?o0000ok>c/ol000002Oo<c<`0
2Ol0003o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko
<c<c00?o0000ooooooooool01_ooool002?ooooo1Onc/k<00ol0003oVIVIoiVIV@0;oiVIV@;o0000
2_moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01SoC4a<00?o0000ofIVI_mVIVH0
2_mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00[oVIVI00?o0000ok>c/onc/k<0
5Onc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgooOgmo00;oOgmo00?oo`00ofIVI_mVIVH0
0omVIVH00ol0003oC4a<oda<C005oda<C005o`000?lc<c?o<c<coc<c<ol000002?m<C4`01?l0003o
IVIVofIVI_l00003ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0003oc<c<olc<c006
olc<c005o`000?nc/k?o/k>cok>c/ol000000onIVIT01?l0003oOgmoogmoOol00002ofIVIP05o`00
0?m<C4coC4a<oda<C?l000002?lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Go0000ogmo
OomoOgoo0000oiVIV@03ool00003ok>c/ol0003oc<c<00Ooc<c<00Co0000ok>c/onc/k?o00000_nI
VIT01_l0003oOgmoogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01olc<c<01Ol0003o
C4a<o`000?mVIVKo000000;oOgmo00Go0000oiVIVOl0003o/k>co`000009olc<c003o`000?nc/k?o
000000;oVIVI0_l00002ofIVIP03o`000?m<C4co000000Wo<c<c00?o0000ooooooooool01_ooool0
02?ooooo1?nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIV
I_mVIVH02omVIVH00ol0003oC4a<oda<C00Goda<C0;o00003?mVIVH00ol0003oOgmoogmoO`09ogmo
O`03o`000?nIVIWoVIVI00[oVIVI00?o0000ok>c/onc/k<05Onc/k<00ol0003oVIVIoiVIV@04oiVI
V@03o`000?moOgooOgmo00;oOgmo00Co0000ofIVI_oo003oo`000_mVIVH00ol0003oC4a<oda<C006
oda<C004o`000?lc<c?o<c<co`0000SoC4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`04o`00
0?nIVIWoVIVIo`0000Go/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`04
o`000?nIVIWoVIVIo`0000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000002oda<C003o`000?lc<c?o
<c<c00Oo<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP03o`000?moOgoo000000;oVIVI00?o
0000ok>c/onc/k<00ooo0007olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol00000
0_mVIVH00ol0003oC4a<o`00000:oc<c<`07o`000?m<C4co0000ofIVI_l0003oOgmoo`000002oiVI
V@03o`000?nc/k?o000000Woc<c<00Oo0000ok>c/ol0003oVIVIo`000?moOgoo000000;oIVIV00?o
0000oda<C?l000002?lc<c<2o`0000Sooooo000Sooooo`Co/k>c00?o0000oiVIVOnIVIT02_nIVIT0
0ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00coIVIV00?o0000oda<C?m<C4`05_m<C4`0
0ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT0
0ol0003o/k>cok>c/`0Eok>c/`03o`000?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl00_moOgl0
1?l0003oIVIVofIVI_mVIVH2ool00003o`000?m<C4coC4a<00KoC4a<00Co0000oc<c<olc<c?o0000
2?m<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Co0000oiVIVOnIVIWo00001?nc/k<00ol0
003oc<c<olc<c006olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl0
1Ol0003oIVIVofIVI_mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01olc<c<01Ol0003oC4a<oda<
C?m<C4co000000;oIVIV00?o0000ogmoOol000000_nIVIT01_l0003o/k>cok>c/onc/k?o0000olc<
c0?oo`001?o<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;oOgmo00Ko0000ofIVI_mVIVKo0000
oda<C?l0000:oc<c<`07o`000?m<C4co0000ofIVI_l0003oOgmoo`000002oiVIV@03o`000?nc/k?o
000000Woc<c<00Wo0000ok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o
<c<coc<c<`06oc<c<`;o00002?ooool002?ooooo0onc/k<00ol0003oVIVIoiVIV@0:oiVIV@03o`00
0?moOgooOgmo00[oOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003o`00
0?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`00
0?nc/k?o/k>c01Co/k>c00?o0000oiVIVOnIVIT01?nIVIT00ol0003oOgmoogmoO`02ogmoO`03o`00
0?mVIVKoIVIV00?oIVIV00?o0000ool00?m<C4`01om<C4`01?l0003o<c<coc<c<ol00007oda<C003
o`000?mVIVKoIVIV00;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT00ol0003o/k>cok>c/`03ok>c
/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@05o`000?moOgoo
OgmoogmoOol000000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000Wo<c<c00Oo0000oda<C?m<C4co
C4a<o`000?mVIVKo000000;oOgmo00?o0000oiVIVOl000000onc/k<00ol0003oc<c<olc<c003olc<
c0?oo`0000Co0000ok>c/onc/k?o00000_nIVIT01_l0003oOgmoogmoOol0003oIVIVo`0000;oC4a<
00?o0000oc<c<olc<c<01olc<c<02?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo00000_nIVIT0
0ol0003o/k>co`000009olc<c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000;o
C4a<00?o0000oc<c<olc<c<01_lc<c<2o`0000Sooooo000Sooooo`;o/k>c00?o0000oiVIVOnIVIT0
2onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`0
5_m<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT0
3?nIVIT00ol0003o/k>cok>c/`0Dok>c/`03o`000?nIVIWoVIVI00GoVIVI00?o0000ogmoOomoOgl0
0_moOgl00ol0003oIVIVofIVIP03ofIVIP04o`000?m<C4coo`00ool000GoC4a<00Co0000oc<c<olc
<c?o00002?m<C4`01Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00Co0000oiVIVOnIVIWo00001?nc
/k<00ol0003oc<c<olc<c006olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo0000
0omoOgl01?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<
C4coC4a<o`000002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`3
ool00006o`000?nIVIWoVIVIo`000?moOgoo00000_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`03
o`000?m<C4co000000;oIVIV0_l00002oiVIV@03o`000?nc/k?o000000Woc<c<00?o0000ok>c/onc
/k<00_l000001omoOgoo0000ofIVI_mVIVKo0000oda<C?l000002?lc<c<00ol0003oC4a<o`000008
ooooo`008oooool2o`0000coVIVI0_l0000:ogmoO`;o00003OmVIVH00ol0003oC4a<oda<C00Foda<
C0;o00003OmVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c
/onc/k<05Onc/k<00ol0003oVIVIoiVIV@03oiVIV@;o00001OmoOgl00ol0003oIVIVofIVIP02ofIV
IP03o`000?m<C4coC4a<00;oC4a<0_oo0003oda<C003o`000?lc<c?o000000SoC4a<00Go0000ofIV
I_mVIVKoIVIVo`000003ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0003oc<c<olc<
c006olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIV
ofIVI_l00004oda<C003o`000?lc<c?o<c<c00Ko<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo
000000;oOgmo00Co0000oiVIVOnIVIWo00000_nc/k<00ol0003oc<c<olc<c007olc<c003o`000?nc
/k?o/k>c00?oo`0000Go0000ogmoOol0003oIVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c
00So0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000;oVIVI00?o0000ok>c/ol000002Oo<c<`0
1ol0003o/k>co`000?nIVIWo0000ogmoOol000000_mVIVH00ol0003oC4a<o`000008oc<c<`03o`00
0?m<C4co000000Sooooo000Sooooo`goVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIV
IP0<ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmo
O`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVI
V@03oiVIV@03o`000?moOgooOgmo00CoOgmo00?o0000ofIVI_mVIVH00_mVIVH00ol0003oC4a<oda<
C004oda<C006ool00?m<C4coC4a<o`000?lc<c?o00001om<C4`00ol0003oIVIVofIVIP02ofIVIP05
o`000?moOgooOgmoogmoOol000000onIVIT00ol0003o/k>cok>c/`02ok>c/`03o`000?o<c<coc<c<
00Goc<c<00?o0000ok>c/onc/k<00onc/k<01?l0003oVIVIoiVIVOl00002ogmoO`04o`000?mVIVKo
IVIVo`0000?oC4a<00?o0000oc<c<olc<c<01olc<c<01ol0003oC4a<oda<C?m<C4co0000ofIVI_l0
00000_moOgl01?l0003oVIVIoiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Co0000ok>c
/onc/k?o00000_nIVIT3ool00003ofIVI_l0003oC4a<00;oC4a<00?o0000oc<c<olc<c<01Olc<c<0
2Ol0003oC4a<oda<C?m<C4co0000ofIVI_l0003oOgmoo`000002oiVIV@03o`000?nc/k?o000000Wo
c<c<00Oo0000ok>c/ol0003oVIVIo`000?moOgoo000000;oIVIV00?o0000oda<C?l000002?lc<c<0
0ol0003oC4a<o`000008ooooo`008oooool=oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIV
I_mVIVH03?mVIVH00ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmo
OomoOgl02OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVI
VOnIVIT00onIVIT00ol0003oOgmoogmoO`04ogmoO`03o`000?mVIVKoIVIV00;oIVIV00?o0000oda<
C?m<C4`01_m<C4`2ool00003oda<C?l0003oC4a<00OoC4a<00Go0000ofIVI_mVIVKoIVIVo`000003
ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001?nc/k<00ol0003oc<c<olc<c006olc<c003o`000?nc
/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl01?l0003oIVIVofIVI_l00004oda<C003
o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP03o`000?moOgoo0000
00;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@04o`000?mo
Ogoo0000ofIVIP?oo`0000?oC4a<o`000?lc<c<01olc<c<02?l0003oC4a<oda<C?l0003oIVIVo`00
0?moOgoo00000_nIVIT00ol0003o/k>co`000009olc<c005o`000?nc/k?o0000oiVIVOl000000_mo
Ogl01Ol0003oIVIVo`000?m<C4co000000So<c<c00Co0000oda<C?m<C4co00002?ooool002?ooooo
3?nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV0_l0000Hoda<C003o`00
0?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl02?moOgl2o`0000coVIVI0_l0000Hok>c/`03o`00
0?nIVIWoVIVI00CoVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIVIP02ofIVIP03o`00
0?m<C4coC4a<00WoC4a<0_oo0007oda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgoo
Ogmoo`000003oiVIV@03o`000?nc/k?o/k>c00;o/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o
/k>cok>c/`02ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00003
oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?mo
OgooOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`01_l0003o/k>cok>c/ol0003oVIVI
o`0000;oOgmo00?o0000ofIVI_l000000_m<C4`3ool000Oo<c<c00So0000oda<C?m<C4co0000ofIV
I_l0003oOgmoo`0000;oVIVI00?o0000ok>c/ol000002Oo<c<`01ol0003o/k>co`000?nIVIWo0000
ogmoOol000000_mVIVH00ol0003oC4a<o`000008oc<c<`04o`000?m<C4coC4a<o`0000Sooooo000S
ooooo`_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4co
C4a<01OoC4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWo
VIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@04oiVIV@03o`000?moOgoo
Ogmo00?oOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00;oda<C003ool00?m<C4co
C4a<00CoC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000?oVIVI00?o
0000ok>c/onc/k<00_nc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Go
0000oiVIVOnIVIWoVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc
<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT0
1?l0003o/k>cok>c/ol00009olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol00002ofIV
IP04o`000?m<C4coC4a<o`0000;o<c<c0ooo0004oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000
ogmoOol00002oiVIV@03o`000?nc/k?o000000Woc<c<00Oo0000ok>c/ol0003oVIVIo`000?moOgoo
000000;oIVIV00?o0000oda<C?l000002?lc<c<01?l0003oC4a<oda<C?l00008ooooo`006?ooool0
1Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo2_nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mV
IVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?mo
OgooOgmo00SoOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nI
VIWoVIVI00CoVIVI00?o0000ogmoOomoOgl01?moOgl00ol0003oIVIVofIVIP02ofIVIP03o`000?m<
C4coC4a<00goC4a<0_oo0003oda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgooOgmo
o`000003oiVIV@03o`000?nc/k?o/k>c00;o/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>c
ok>c/`02ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00003oda<
C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgoo
Ogmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`01_l0003o/k>cok>c/ol0003oVIVIo`00
00;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`04oc<c<`;oo`0000Oo<c<co`00
0?m<C4coC4a<o`000?mVIVKo000000;oOgmo00Go0000oiVIVOl0003o/k>co`000009olc<c003o`00
0?nc/k?o000000;oVIVI0_l00002ofIVIP03o`000?m<C4co000000Wo<c<c00Co0000oda<C?l0003o
00002?ooool001Sooooo00GoEEEEogMgMoooooooV9RHob4Q8@06ooooo`WoVIVI00?o0000ogmoOomo
Ogl02?moOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mV
IVH03?mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI0_l0000Hok>c/`03
o`000?nIVIWoVIVI00GoVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIVIP03ofIVIP03
o`000?m<C4coC4a<00ooC4a<0_oo00000om<C4co0000ofIVIP02ofIVIP05o`000?moOgooOgmoogmo
Ool000000onIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c
/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`05o`000?mVIVKoIVIVofIVI_l000000om<
C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmo
ogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Woc<c<00Ko0000ok>c/onc/k?o0000oiVIVOl0
0002ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<3ool00008oda<C?l0
003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Oo0000ok>c
/ol0003oVIVIo`000?moOgoo000000;oIVIV00?o0000oda<C?l000002?lc<c<00ol0003oC4a<oda<
C002o`0000Sooooo000Hooooo`05o`000?ooooooooooooooool000001_ooool8oiVIV@03o`000?mo
OgooOgmo00SoOgmo0_l0000<ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02omV
IVH2o`0000[oOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Hok>c/`03o`000?nI
VIWoVIVI00GoVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<
C4coC4a<017oC4a<0_oo0003ofIVIP05o`000?moOgooOgmoogmoOol000000onIVIT00ol0003o/k>c
ok>c/`03ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVI
oiVIVOl00002ogmoO`05o`000?mVIVKoIVIVofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c
<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01_l0003oOgmoogmoOol0003oVIVIo`0000?o/k>c
00?o0000olc<c?o<c<`01_o<c<`01ol0003o/k>cok>c/onc/k?o0000oiVIVOl000000_moOgl00ol0
003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00?o0000oda<C?oo00000_oo00001Ol0
003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`01ol0003o/k>co`000?nI
VIWo0000ogmoOol000000_mVIVH00ol0003oC4a<o`000008oc<c<`03o`000?m<C4coC4a<00;o0000
2?ooool001Sooooo00Go0000oiRHV?ooooooV9RHob4Q8@06ooooo`KoVIVI0_l0000:ogmoO`03o`00
0?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`00
0?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Hok>c/`03o`00
0?nIVIWoVIVI00GoVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIVIP03ofIVIP03o`00
0?m<C4coC4a<01;oC4a<00Go0000ofIVI_oo003oo`00o`000003ogmoO`05o`000?nIVIWoVIVIoiVI
VOl000001Onc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVI
VOnIVIWo00000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000?oC4a<00?o0000oc<c<olc<c<01_lc
<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01?l0003o
/k>cok>c/ol00009olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl00ol0003oIVIVo`00
0002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Co0000oda<C?m<C4co00000_mVIVH2ool00005oiVI
VOl0003o/k>cok>c/ol000002Oo<c<`00ol0003o/k>cok>c/`02o`000007ogmoOol0003oIVIVofIV
I_l0003oC4a<o`000008oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00002?ooool001Sooooo00Go
0000oeEEEOl0003o410@olc<c006ooooo`GoVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIV
ofIVIP0;ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmo
ogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<06?nc/k<00ol0003oVIVI
oiVIV@05oiVIV@03o`000?moOgooOgmo00?oOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<
oda<C00Boda<C005o`000?mVIVKoIVIVofIVI_l000000_oo00000omoOgoo0000oiVIV@03oiVIV@03
o`000?nc/k?o/k>c00;o/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`05
o`000?nIVIWoVIVIoiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00004oda<C003o`000?lc<c?o
<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP06o`000?moOgooOgmoo`000?nIVIWo
00000onc/k<00ol0003oc<c<olc<c006olc<c007o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000002
ogmoO`03o`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01olc<c<02?l0003oC4a<oda<C?l0
003oIVIVo`000?moOgoo00000ooo00000onc/k?o0000olc<c008olc<c007o`000?nc/k?o0000oiVI
VOl0003oOgmoo`000002ofIVIP03o`000?m<C4co000000So<c<c00Ko0000oda<C?m<C4co0000ofIV
I_l00008ooooo`006?ooool00omEEEGoQhN7ooooo`08ooooo`GoVIVI00?o0000ogmoOomoOgl02?mo
Ogl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<01SoC4a<00?o0000ofIVI_mVIVH02_mV
IVH2o`0000[oOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`0Hok>c/`03o`000?nI
VIWoVIVI00CoVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIVIP04ofIVIP03o`000?m<
C4coC4a<01;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`?oo`000onIVIT00ol0003o/k>c
ok>c/`02ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c/onc/k<00_nc/k<01Ol0003oVIVI
oiVIVOnIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`06oc<c
<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01_l0003oOgmoogmoOol0003oVIVIo`0000?o/k>c
00?o0000olc<c?o<c<`01_o<c<`01ol0003o/k>cok>c/onc/k?o0000oiVIVOl000000_moOgl00ol0
003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00?o0000oda<C?l000000_mVIVH01_l0
003oOgmoo`000?nIVIWo0000ok>c/`?oo`001oo<c<`02?l0003o/k>cok>c/ol0003oVIVIo`000?mo
Ogoo00000_mVIVH00ol0003oC4a<o`000008oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00002?oo
ool001Sooooo00?ogMgMoa0@4?nHV9P02?ooool3oiVIV@;o00002_moOgl00ol0003oIVIVofIVIP0;
ofIVIP03o`000?m<C4coC4a<01SoC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`09
ogmoO`03o`000?nIVIWoVIVI00_oVIVI0_l0000Jok>c/`03o`000?nIVIWoVIVI00GoVIVI00?o0000
ogmoOomoOgl00omoOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<01;oC4a<00Go0000
ofIVI_mVIVKoIVIVo`000004ogmoO`05o`000?nIVIWoo`00ool00?l000001?nc/k<00ol0003oc<c<
olc<c005olc<c003o`000?nc/k?o/k>c00;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`04
o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01_lc<c<00ol0003oC4a<oda<C002oda<
C003o`000?mVIVKo000000;oOgmo00?o0000oiVIVOl000000onc/k<00ol0003oc<c<olc<c007olc<
c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl00ol0003oIVIVo`000003oda<C003o`000?lc
<c?o<c<c00Ko<c<c00So0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000;oVIVI00Go0000ok>c
/onc/k?o0000olc<c003ool000Coc<c<00Go0000ok>c/ol0003oVIVIo`000002ogmoO`05o`000?mV
IVKo0000oda<C?l000002Olc<c<01?l0003oC4a<o`000?mVIVH2o`0000Sooooo000Iooooo`04olc<
c?m4A4Co0000oa0@40Kooooo0_nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00_o
IVIV00?o0000oda<C?m<C4`05om<C4`2o`0000coIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003o
VIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01So/k>c0_l00007oiVIV@03o`000?moOgooOgmo00?o
Ogmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00Boda<C003o`000?mVIVKoIVIV00;o
IVIV00Go0000ogmoOomoOgooOgmoo`000003oiVIV@03o`000?oo003oo`0000?o/k>c00?o0000olc<
c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl0
1?l0003oIVIVofIVI_l00003oda<C003o`000?lc<c?o<c<c00Oo<c<c00Go0000oda<C?m<C4coC4a<
o`000002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002_o<c<`01_l0003o
/k>cok>c/ol0003oVIVIo`0000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07
oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<
c?o<c<`00oo<c<`3ool00008olc<c?l0003o/k>co`000?nIVIWo0000ogmoOol00002ofIVIP03o`00
0?m<C4co000000Wo<c<c00Ko0000oda<C?l0003o0000ogmoOol00008ooooo`008oooool00onIVIWo
0000ogmoO`0:ogmoO`03o`000?mVIVKoIVIV00coIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003o
IVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o
/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00OoVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003o
IVIVofIVIP03ofIVIP03o`000?m<C4coC4a<01;oC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003o
OgmoogmoOomoOgoo000000?oVIVI00?o0000ok>c/onc/k<00_oo00000onc/k?o0000olc<c006olc<
c003o`000?nc/k?o/k>c00;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`04o`000?mVIVKo
IVIVo`0000?oC4a<00?o0000oc<c<olc<c<01olc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV
00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol0000:olc<c008o`000?nc/k?o/k>co`00
0?nIVIWo0000ogmoOol00002ofIVIP04o`000?m<C4coC4a<o`0000Wo<c<c00[o0000oda<C?m<C4co
0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c0?oo`0000Go
0000oiVIVOl0003oOgmoo`000002ofIVIP03o`000?m<C4co000000Wo<c<c00Ko0000oda<C?l0003o
0000ogmoOol00008ooooo`008oooool00ol0003oOgmoogmoO`0:ogmoO`03o`000?mVIVKoIVIV00_o
IVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?moOgooOgmo00So
Ogmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00Oo
VIVI00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<01?o
C4a<00Go0000ofIVI_mVIVKoIVIVo`000003ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c
/onc/k<00_nc/k<2ool000Koc<c<00?o0000ok>c/onc/k<00onc/k<01?l0003oVIVIoiVIVOl00002
ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<
C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01?l0003o/k>cok>c/ol00009olc<
c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl01?l0003oIVIVofIVI_l00002oda<C003o`00
0?lc<c?o<c<c00Oo<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc
/k<00ol0003oc<c<olc<c007olc<c003o`000?nc/k?oo`0000;oo`0000OoOgmoo`000?mVIVKoIVIV
o`000?m<C4co000000So<c<c00?o0000oda<C?m<C4`00_l000000omoOgoo0000ooooo`07ooooo`00
8oooool<ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIV
ofIVIP0<ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>c
ok>c/`0Gok>c/`03o`000?nIVIWoVIVI00OoVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIV
ofIVIP04ofIVIP03o`000?m<C4coC4a<01;oC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmo
ogmoOomoOgoo000000?oVIVI00?o0000ok>c/onc/k<00onc/k<01?l0003oc<c<ool00?oo0003olc<
c003o`000?nc/k?o/k>c00?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`04o`000?mVIVKo
IVIVo`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<00ol0003oC4a<oda<C002oda<C006o`000?mV
IVKoIVIVo`000?moOgoo00000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Woc<c<00So0000ok>c
/onc/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<01_l0003o
C4a<oda<C?l0003oIVIVo`0000;oOgmo0_l00002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00?o0000
ok>c/ol000000_nIVIT01ol0003oo`00ool00?oo003o0000oda<C?l000002Olc<c<01ol0003oC4a<
o`000?mVIVKo0000ogmoOol000002?ooool002?ooooo2_moOgl2o`0000goIVIV00?o0000oda<C?m<
C4`05_m<C4`2o`0000coIVIV0_l0000;ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc
/k<06?nc/k<00ol0003oVIVIoiVIV@06oiVIV@03o`000?moOgooOgmo00CoOgmo00?o0000ofIVI_mV
IVH00omVIVH00ol0003oC4a<oda<C00Coda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl00ol0
003oVIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c00?o/k>c00Co0000olc<c?o<c<coc<c<0ooo0000
0ol0003o/k>cok>c/`03ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00Go0000ofIVI_mVIVKoIVIV
o`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04
o`000?moOgooOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c004o`000?nc/k?o
/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`0:o`00
0?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01oo<
c<`01ol0003o/k>co`000?nIVIWo0000ogmoOol000000_mVIVH3ool000So<c<c00So0000oda<C?m<
C4co0000ofIVI_l0003oOgmoo`0000Sooooo000Sooooo`WoOgmo00?o0000ofIVI_mVIVH03?mVIVH0
0ol0003oC4a<oda<C00Foda<C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl02OmoOgl0
0ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01So/k>c00?o0000oiVIVOnIVIT01onIVIT0
0ol0003oOgmoogmoO`04ogmoO`03o`000?mVIVKoIVIV00?oIVIV00?o0000oda<C?m<C4`04om<C4`0
1Ol0003oIVIVofIVI_mVIVKo000000?oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c
/`03ok>c/`03o`000?o<c<coc<c<00Coc<c<0_oo0004ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo
00Go0000ofIVI_mVIVKoIVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<
C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002Oo<
c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co
00002Olc<c<00ol0003oC4a<oda<C002o`0000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003o
c<c<olc<c007olc<c007o`000?nc/k?o0000oiVIVOl0003oOgmoo`000002ofIVIP03o`000?m<C4co
000000?oo`001Olc<c<02?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo00002?ooool002?ooooo
2?moOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH0
3?mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<0
6?nc/k<00ol0003oVIVIoiVIV@07oiVIV@03o`000?moOgooOgmo00CoOgmo00?o0000ofIVI_mVIVH0
0omVIVH00ol0003oC4a<oda<C00Coda<C005o`000?mVIVKoIVIVofIVI_l000000omoOgl00ol0003o
VIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o
/k>cok>c/`02ool00005ok>c/ol0003oVIVIoiVIVOl000000_moOgl01Ol0003oIVIVofIVI_mVIVKo
000000CoC4a<00?o0000oc<c<olc<c<01Olc<c<01Ol0003oC4a<oda<C?m<C4co000000?oIVIV00?o
0000ogmoOol000000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Wo0000ok>c/onc/k?o
/k>co`000?nIVIWo0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`0:o`000?m<
C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01oo<c<`0
1ol0003o/k>co`000?nIVIWo0000ogmoOol000000_mVIVH00ol0003oC4a<o`000004oc<c<`?oo`00
00So<c<co`000?m<C4coC4a<o`000?mVIVKo0000ogmoO`;o00002?ooool002?ooooo1omoOgl00ol0
003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<01KoC4a<0_l0000=ofIVIP03o`000?moOgooOgmo
00SoOgmo0_l0000<oiVIV@;o00006_nc/k<00ol0003oVIVIoiVIV@07oiVIV@03o`000?moOgooOgmo
00CoOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00Coda<C003o`000?mVIVKoIVIV
00;oIVIV00Go0000ogmoOomoOgooOgmoo`000003oiVIV@03o`000?nc/k?o/k>c00?o/k>c00?o0000
olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`?oo`0000GoVIVIo`000?moOgooOgmoo`00
0002ofIVIP03o`000?m<C4coC4a<00;oC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<
C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01?l0003o/k>cok>c/ol00009olc<
c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l0
0008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03
o`000?o<c<coc<c<00Koc<c<0_l000001_nc/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV00?o0000
oda<C?l000001olc<c<3ool00005oda<C?l0003oIVIVo`000?moOgl00_l00008ooooo`008oooool6
ogmoO`03o`000?mVIVKoIVIV00coIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0<
ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02_nIVIT00ol0003o/k>cok>c/`0I
ok>c/`03o`000?nIVIWoVIVI00SoVIVI00?o0000ogmoOomoOgl00omoOgl00ol0003oIVIVofIVIP03
ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomo
Ogoo000000?oVIVI00?o0000ok>c/onc/k<00onc/k<00ol0003oc<c<olc<c005olc<c003o`000?nc
/k?o/k>c00;o/k>c00?o0000oiVIVOnIVIT00_oo0002ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<
00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomo
Ogoo00000_nIVIT01?l0003o/k>cok>c/ol00009olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Go
0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Co0000oda<C?m<C4co
00000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02?l0
003o/k>cok>c/ol0003oVIVIo`000?moOgoo00000_mVIVH00ol0003oC4a<o`000008oc<c<`03o`00
0?m<C4coo`0000;oo`0000Co0000ogmoOol0003o00002?ooool002?ooooo1OmoOgl00ol0003oIVIV
ofIVIP0<ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003oOgmo
ogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<06?nc/k<00ol0003oVIVI
oiVIV@08oiVIV@03o`000?moOgooOgmo00CoOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<
oda<C00Coda<C003o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgooOgmoo`000004oiVIV@03
o`000?nc/k?o/k>c00;o/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`03ok>c/`05
o`000?nIVIWoVIVIo`000?moOgl00_oo0002ofIVIP03o`000?m<C4coC4a<00;oC4a<00?o0000oc<c
<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nI
VIT01?l0003o/k>cok>c/ol00009olc<c004o`000?nc/k?o/k>co`0000;oVIVI00?o0000ogmoOol0
00000_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`03o`000?m<C4co000000;oIVIV00?o0000ogmo
Ool000000_nIVIT01?l0003o/k>cok>c/ol00007olc<c006o`000?nc/k?o/k>co`000?nIVIWo0000
0_moOgl01Ol0003oIVIVo`000?m<C4co000000Wo<c<c00Go0000oda<C?l0003oIVIVo`000004ool0
00Sooooo000Sooooo`CoOgmo00?o0000ofIVI_mVIVH02omVIVH2o`0001SoC4a<00?o0000ofIVI_mV
IVH03?mVIVH00ol0003oOgmoogmoO`08ogmoO`;o00003?nIVIT2o`0001Wo/k>c0_l0000:oiVIV@03
o`000?moOgooOgmo00CoOgmo00?o0000ofIVI_mVIVH00omVIVH00ol0003oC4a<oda<C00Coda<C003
o`000?mVIVKoIVIV00;oIVIV00Go0000ogmoOomoOgooOgmoo`000004oiVIV@03o`000?nc/k?o/k>c
00?o/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`04o`000?nIVIWoVIVI
o`0000?oOgmo00Co0000ool00?oo003oo`001?m<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<
C4coC4a<oda<C?l000000_mVIVH01_l0003oOgmoogmoOol0003oVIVIo`0000?o/k>c00?o0000olc<
c?o<c<`01oo<c<`01?l0003o/k>cok>c/ol00002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000
oda<C?m<C4co00002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl0
00000_nc/k<00ol0003oc<c<olc<c006olc<c008o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0
0002ofIVIP03o`000?m<C4co000000Wo<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000oiVI
VOl000002?ooool002?ooooo0omoOgl2o`0000coIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003o
IVIVofIVIP0;ofIVIP;o00002_moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01So
/k>c00?o0000oiVIVOnIVIT02OnIVIT00ol0003oOgmoogmoO`04ogmoO`03o`000?mVIVKoIVIV00Co
IVIV00?o0000oda<C?m<C4`04om<C4`00ol0003oIVIVofIVIP02ofIVIP05o`000?moOgooOgmoogmo
Ool000001?nIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c
/onc/k<00onc/k<01?l0003oVIVIoiVIVOl00003ogmoO`04o`000?mVIVKoIVIVo`0000;oo`000_m<
C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo0000
0_moOgl00ol0003oVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Co0000ok>c/onc/k?o
00000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<o`0000So<c<c00Co0000oda<
C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<
c<`02?l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo00000_mVIVH00ol0003oC4a<o`000009oc<c
<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000Sooooo000Sooooo`;oOgmo00?o
0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00_oIVIV00?o
0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01So/k>c00?o
0000oiVIVOnIVIT02OnIVIT00ol0003oOgmoogmoO`04ogmoO`03o`000?mVIVKoIVIV00CoIVIV00?o
0000oda<C?m<C4`04om<C4`00ol0003oIVIVofIVIP02ofIVIP05o`000?moOgooOgmoogmoOol00000
1?nIVIT00ol0003o/k>cok>c/`03ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ok>c/onc/k<0
0onc/k<01?l0003oVIVIoiVIVOl00003ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<0_oo0008oc<c
<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01?l0003oOgmoogmoOol00002oiVIV@04o`000?nc
/k?o/k>co`0000Woc<c<00Co0000ok>c/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIVIP04
o`000?m<C4coC4a<o`0000Wo<c<c00?o0000oda<C?l000000_mVIVH01Ol0003oOgmoo`000?nIVIWo
000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`01ol0003o/k>co`000?nIVIWo0000ogmoOol00000
0_mVIVH00ol0003oC4a<o`000009oc<c<`03o`000?m<C4coC4a<00;o000000?oOgmoo`000?nIVIT0
0_l00008ooooo`008oooool00omoOgoo0000ofIVIP0<ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o
0000ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o
0000ok>c/onc/k<06?nc/k<00ol0003oVIVIoiVIV@09oiVIV@03o`000?moOgooOgmo00CoOgmo00?o
0000ofIVI_mVIVH01?mVIVH00ol0003oC4a<oda<C00Coda<C0;o00000omVIVH00ol0003oOgmoogmo
O`02ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001Onc/k<00ol0003oc<c<olc<c005olc<c003o`00
0?nc/k?o/k>c00;o/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`05o`000?mVIVKoIVIVofIV
I_l000000om<C4`00ol0003o<c<cool00002ool000Co<c<c00Go0000oda<C?m<C4coC4a<o`000003
ofIVIP06o`000?moOgoo0000o`000?nIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c005o`00
0?nc/k?o/k>cok>c/ol000000_nIVIT00ol0003oOgmoo`000002ofIVIP03o`000?m<C4co000000[o
<c<c00?o0000oda<C?l000000_mVIVH01ol0003oOgmoo`000?nIVIWo0000ok>c/ol000002_o<c<`0
1ol0003o/k>co`000?nIVIWo0000ogmoOol000000_mVIVH00ol0003oC4a<o`000008oc<c<`09o`00
0?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVI00;o00002?ooool002?ooooo00?o0000ofIV
I_mVIVH02omVIVH00ol0003oC4a<oda<C00Hoda<C003o`000?mVIVKoIVIV00[oIVIV0_l0000:ogmo
O`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<06?nc/k<00ol0003oVIVIoiVIV@09oiVI
V@03o`000?moOgooOgmo00GoOgmo00?o0000ofIVI_mVIVH01?mVIVH00ol0003oC4a<oda<C00Coda<
C003o`000?mVIVKoIVIV00;oIVIV00?o0000ogmoOomoOgl00_moOgl01Ol0003oVIVIoiVIVOnIVIWo
000000Go/k>c00?o0000olc<c?o<c<`01Oo<c<`00ol0003o/k>cok>c/`02ok>c/`05o`000?nIVIWo
VIVIoiVIVOl000000_moOgl01Ol0003oIVIVofIVI_mVIVKo000000?oC4a<00?o0000oc<c<olc<c<0
0_lc<c<2ool000;o<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`000?moOgooOgmoo`00
00;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c005o`000?nc/k?o/k>cok>c/ol000000_nI
VIT00ol0003oOgmoo`000002ofIVIP03o`000?m<C4co000000[o<c<c00Go0000oda<C?l0003oIVIV
o`000002ogmoO`05o`000?nIVIWo0000ok>c/ol000002_o<c<`01ol0003o/k>co`000?nIVIWo0000
ogmoOol000000_mVIVH00ol0003oC4a<o`000008oc<c<`09o`000?m<C4coC4a<o`000?mVIVKo0000
ogmoOol0003oVIVI00;o00002?ooool002?ooooo3OmVIVH00ol0003oC4a<oda<C00Hoda<C003o`00
0?mVIVKoIVIV00[oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`00
0?nc/k?o/k>c01Oo/k>c0_l0000;oiVIV@03o`000?moOgooOgmo00GoOgmo00?o0000ofIVI_mVIVH0
1?mVIVH00ol0003oC4a<oda<C00Coda<C003o`000?mVIVKoIVIV00;oIVIV00?o0000ogmoOomoOgl0
0_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Ko/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o
/k>cok>c/`02ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000_moOgl01Ol0003oIVIVofIVI_mVIVKo
000000?oC4a<00?o0000oc<c<olc<c<01Olc<c<3ool000?oC4a<00Ko0000ofIVI_mVIVKo0000ogmo
Ool00002oiVIV@03o`000?nc/k?o/k>c00;o/k>c00?o0000olc<c?o<c<`01Oo<c<`01Ol0003o/k>c
ok>c/onc/k?o000000;oVIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00009oc<c
<`03o`000?m<C4co000000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<co
c<c<00Ooc<c<00Oo0000ok>c/ol0003oVIVIo`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co
00001olc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo0_l000000onc/k?o0000ooooo`07
ooooo`008oooool<ofIVIP03o`000?m<C4coC4a<01OoC4a<0_l0000<ofIVIP03o`000?moOgooOgmo
00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI
00[oVIVI00?o0000ogmoOomoOgl01OmoOgl00ol0003oIVIVofIVIP04ofIVIP03o`000?m<C4coC4a<
01CoC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000?oVIVI00?o0000
ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Go0000
oiVIVOnIVIWoVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<0
1_lc<c<00ol0003oC4a<ool00002ool000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01Ol0003o
/k>cok>c/onc/k?o000000Soc<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo00?o
0000ofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV
00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00So0000ok>c/onc
/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV00?o0000oda<C?l000002?lc<c<03?l0003oC4a<oda<
C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Sooooo000Sooooo`coIVIV00?o0000
oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0;ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000
oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000
ogmoOomoOgl01OmoOgl00ol0003oIVIVofIVIP04ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000
ofIVI_mVIVH00omVIVH01Ol0003oOgmoogmoOomoOgoo000000?oVIVI00?o0000ok>c/onc/k<01?nc
/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00Go0000oiVIVOnIVIWoVIVI
o`000002ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003o
C4a<oda<C?m<C4co000000;oo`0000Co0000ogmoOomoOgoo00000_nIVIT01Ol0003o/k>cok>c/onc
/k?o000000Soc<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo00?o0000ofIVI_l0
00000om<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Go0000ogmo
Ool0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<00So0000ok>c/onc/k?o0000oiVI
VOl0003oOgmoo`0000;oIVIV00?o0000oda<C?l000002?lc<c<03?l0003oC4a<oda<C?l0003oIVIV
o`000?moOgoo0000oiVIVOl0003o/k>co`0000Sooooo000Sooooo`_oIVIV00?o0000oda<C?m<C4`0
5_m<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT0
3?nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl0
1_moOgl00ol0003oIVIVofIVIP03ofIVIP03o`000?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH0
0omVIVH01Ol0003oOgmoogmoOomoOgoo000000CoVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003o
c<c<olc<c003olc<c003o`000?nc/k?o/k>c00?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmo
O`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002
oda<C003o`000?mVIVKoIVIV00?oo`0000Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<
c006olc<c009o`000?nc/k?o/k>cok>c/ol0003oVIVIo`000?moOgoo000000;oIVIV00Co0000oda<
C?m<C4co00002Olc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;oOgmo0_l00003ok>c/`03o`00
0?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o0000oiVIV@02o`0000?oIVIV00?o0000oda<C?l0
00002?lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000So
oooo000Sooooo`[oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`00
0?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`00
0?nIVIWoVIVI00[oVIVI00?o0000ogmoOomoOgl01_moOgl00ol0003oIVIVofIVIP04ofIVIP03o`00
0?m<C4coC4a<01?oC4a<00?o0000ofIVI_mVIVH00omVIVH01Ol0003oOgmoogmoOomoOgoo000000?o
VIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o
/k>c00Go0000oiVIVOnIVIWoVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000
oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo0000
0_oo00001Ol0003o/k>cok>c/onc/k?o000000Soc<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo
000000;oOgmo00?o0000ofIVI_l000000om<C4`00ol0003o<c<coc<c<`06oc<c<`04o`000?m<C4co
C4a<o`0000;oIVIV00Go0000ogmoOol0003oVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Goc<c<
00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV00?o0000oda<C?l000002Olc<c<0
0ol0003oC4a<o`000002ofIVIP;o000000GoVIVIo`000?nc/k?o/k>co`000008ooooo`008oooool9
ofIVIP03o`000?m<C4coC4a<01KoC4a<0_l0000<ofIVIP;o00002_moOgl2o`0000goVIVI00?o0000
ok>c/onc/k<05_nc/k<2o`0000goVIVI00?o0000ogmoOomoOgl01OmoOgl00ol0003oIVIVofIVIP04
ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomo
Ogoo000000CoVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c003olc<c003o`000?nc
/k?o/k>c00?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`04o`000?mVIVKoIVIVo`0000Co
C4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmo
OomoOgoo00000_nIVIT3ool00003ok>c/ol0003oc<c<00Ooc<c<00Oo0000ok>c/onc/k?o/k>co`00
0?nIVIWo000000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`06o`00
0?m<C4coC4a<o`000?mVIVKo00000_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<
00Koc<c<00So0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV00?o0000oda<C?l00000
2Olc<c<02_l0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k<2o`0000Sooooo000S
ooooo`SoIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP0<ofIVIP03o`000?moOgoo
Ogmo00SoOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWo
VIVI00coVIVI00?o0000ogmoOomoOgl01OmoOgl00ol0003oIVIVofIVIP05ofIVIP03o`000?m<C4co
C4a<01CoC4a<00?o0000ofIVI_mVIVH00_mVIVH01Ol0003oOgmoogmoOomoOgoo000000?oVIVI00?o
0000ok>c/onc/k<01Onc/k<00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c00?o/k>c00Go
0000oiVIVOnIVIWoVIVIo`000003ogmoO`04o`000?mVIVKoIVIVo`0000?oC4a<00?o0000oc<c<olc
<c<01olc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00?o0000ogmoOol000000onIVIT00ol0
003o/k>cok>c/`02ool000Ooc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@06o`000?moOgoo
Ogmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`07oc<c<`08o`000?m<C4coC4a<o`000?mV
IVKo0000ogmoOol00002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00So0000ok>c/onc/k?o0000
oiVIVOl0003oOgmoo`0000;oIVIV00?o0000oda<C?l000002Olc<c<2o`0000;oIVIV00Ko0000ogmo
Ool0003oVIVIo`000?nc/k<2o`0000Sooooo000Sooooo`OoIVIV00?o0000oda<C?m<C4`05_m<C4`0
0ol0003oIVIVofIVIP0<ofIVIP03o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT03?nIVIT0
0ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl01_moOgl0
0ol0003oIVIVofIVIP04ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH00_mVIVH0
1Ol0003oOgmoogmoOomoOgoo000000CoVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<
c003olc<c003o`000?nc/k?o/k>c00?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`04o`00
0?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co0000
00;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01_l0003o/k>cok>c/onc/k?o0000olc<c0;oo`00
1Oo<c<`01?l0003o/k>cok>c/ol00003oiVIV@05o`000?moOgoo0000ofIVI_l000000om<C4`00ol0
003o<c<coc<c<`06oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000_moOgl00ol0003oVIVIo`00
0002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Oo0000ok>c/ol0003oVIVIo`000?moOgoo000000;o
IVIV00?o0000oda<C?l000002Olc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`00
0002ok>c/`;o00002?ooool002?ooooo1_mVIVH00ol0003oC4a<oda<C00Foda<C0;o00003OmVIVH0
0ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<2
o`0000goVIVI00?o0000ogmoOomoOgl01_moOgl00ol0003oIVIVofIVIP04ofIVIP03o`000?m<C4co
C4a<01CoC4a<00?o0000ofIVI_mVIVH00_mVIVH00ol0003oOgmoogmoO`02ogmoO`05o`000?nIVIWo
VIVIoiVIVOl000001_nc/k<00ol0003oc<c<olc<c004olc<c003o`000?nc/k?o/k>c00?o/k>c00?o
0000oiVIVOnIVIT00_l00002ogmoO`05o`000?mVIVKoIVIVofIVI_l000000om<C4`00ol0003o<c<c
oc<c<`06oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003o
VIVIoiVIVOl00002ok>c/`03o`000?o<c<coc<c<00;oc<c<0ooo0002olc<c004o`000?nc/k?o/k>c
o`0000;oVIVI00Ko0000ogmoOomoOgoo0000ofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c
00Ko0000oda<C?m<C4co0000ofIVI_l00002ogmoO`05o`000?nIVIWo0000ok>c/ol000002_o<c<`0
1ol0003o/k>co`000?nIVIWo0000ogmoOol000000_mVIVH00ol0003oC4a<o`000008oc<c<`;o0000
00SoC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c0_l00008ooooo`008oooool5ofIV
IP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmoO`09ogmo
O`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0<oiVI
V@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<C00Coda<
C003o`000?mVIVKoIVIV00?oIVIV00Go0000ogmoOomoOgooOgmoo`000004oiVIV@03o`000?nc/k?o
/k>c00Co/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`04o`000?nIVIWo
VIVIo`0000?oOgmo00Go0000ofIVI_mVIVKoIVIVo`000003oda<C003o`000?lc<c?o<c<c00Ko<c<c
00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`00
00;o/k>c00?o0000olc<c?o<c<`01Oo<c<`2ool00004o`000?nc/k?o/k>co`0000;oVIVI00Ko0000
ogmoOomoOgoo0000ofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Ko0000oda<C?m<C4co
0000ofIVI_l00002ogmoO`05o`000?nIVIWo0000ok>c/ol000002_o<c<`01ol0003o/k>co`000?nI
VIWo0000ogmoOol000000_mVIVH00ol0003oC4a<o`000008oc<c<`0:o`000?m<C4coC4a<o`000?mV
IVKo0000ogmoOol0003oVIVIo`0000;o/k>c0_l00008ooooo`008oooool4ofIVIP03o`000?m<C4co
C4a<01KoC4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWo
VIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgoo
Ogmo00KoOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0003oC4a<oda<C00Doda<C003o`000?mVIVKo
IVIV00;oIVIV00?o0000ogmoOomoOgl00_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000Ko/k>c00?o
0000olc<c?o<c<`01?o<c<`00ol0003o/k>cok>c/`03ok>c/`04o`000?nIVIWoVIVIo`0000CoOgmo
00Co0000ofIVI_mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`03o`000?m<C4coC4a<00;o
C4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00002ok>c/`03o`000?o<c<co
c<c<00Ooc<c<00Co0000ool00?oo003o00000_nIVIT01_l0003oOgmoogmoOol0003oIVIVo`0000?o
C4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP05o`000?moOgoo0000
oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c007o`000?nc/k?o0000oiVIVOl0003oOgmo
o`000002ofIVIP04o`000?m<C4coC4a<o`0000Oo<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002
ogmoO`;o00000_nc/k<00ol0003oc<c<o`000008ooooo`008oooool2ofIVIP;o00006?m<C4`00ol0
003oIVIVofIVIP0<ofIVIP03o`000?moOgooOgmo00SoOgmo0_l0000<oiVIV@;o00006Onc/k<00ol0
003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00KoOgmo00?o0000ofIVI_mVIVH01OmVIVH00ol0
003oC4a<oda<C00Doda<C003o`000?mVIVKoIVIV00;oIVIV00?o0000ogmoOomoOgl00_moOgl00ol0
003oVIVIoiVIV@02oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0
003o/k>cok>c/`03ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01?l0003oIVIVofIVI_l0
0004oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP04o`00
0?moOgooOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`000009olc<c003o`000?nc/k?o/k>c
00?oo`0000?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`06o`000?m<C4co
C4a<o`000?mVIVKo00000_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<
00Wo0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVH00_l000000om<C4co0000oc<c<`07
oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<
c?l000002?ooool002?ooooo00?oIVIVo`000?m<C4`06?m<C4`00ol0003oIVIVofIVIP0<ofIVIP03
o`000?moOgooOgmo00SoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Hok>c/`03
o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl01omoOgl00ol0003oIVIVofIVIP05ofIVIP03
o`000?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH00_mVIVH00ol0003oOgmoogmoO`02ogmoO`05
o`000?nIVIWoVIVIoiVIVOl000001onc/k<00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c
00?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o
0000oc<c<olc<c<01_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo
00000_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Woc<c<00Co0000ok>c/onc/k?o00000_nIVIT3
ool000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<01_l0003oC4a<oda<C?l0003oIVIVo`0000;o
Ogmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c006olc<c00:o`000?nc/k?o/k>co`00
0?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02_l0003oC4a<
oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<co000000Sooooo000S
ooooo`03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmoO`08
ogmoO`03o`000?nIVIWoVIVI00coVIVI00?o0000ok>c/onc/k<05_nc/k<2o`0000goVIVI00?o0000
ogmoOomoOgl01omoOgl00ol0003oIVIVofIVIP05ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000
ofIVI_mVIVH00_mVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000
ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c00?o/k>c00Go0000
oiVIVOnIVIWoVIVIo`000003ogmoO`04o`000?mVIVKoIVIVo`0000CoC4a<00?o0000oc<c<olc<c<0
1_lc<c<01Ol0003oC4a<oda<C?m<C4co000000;oIVIV00Co0000ogmoOomoOgoo00000_nIVIT01Ol0
003o/k>cok>c/onc/k?o000000Woc<c<00Co0000ok>c/onc/k?o00000_nIVIT01?l0003oOgmoogmo
Ool00003ool000;oC4a<00?o0000oc<c<olc<c<01_lc<c<01_l0003oC4a<oda<C?l0003oIVIVo`00
00;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c007o`000?nc/k?o0000
oiVIVOl0003oOgmoo`000002ofIVIP03o`000?m<C4co000000Wo<c<c00Wo0000oda<C?l0003oIVIV
o`000?moOgoo0000oiVIVOl000000_nc/k<01?l0003oc<c<olc<c?l00008ooooo`008ooooolIoda<
C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0;oiVI
V@;o00006?nc/k<00ol0003oVIVIoiVIV@0;oiVIV@;o00002OmoOgl00ol0003oIVIVofIVIP05ofIV
IP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH00omVIVH01Ol0003oOgmoogmoOomoOgoo
000000CoVIVI00?o0000ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c003olc<c0;o00001Onc/k<0
1Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`00
0?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04
o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o
000000;oVIVI00?o0000ogmoOol000000_mVIVH00ol0003oC4a<ool00002ool000So<c<c00So0000
oda<C?m<C4co0000ofIVI_l0003oOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`02?l0
003o/k>cok>c/ol0003oVIVIo`000?moOgoo00000_mVIVH00ol0003oC4a<o`000009oc<c<`09o`00
0?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00Co0000olc<c?o<c<co00002?oo
ool002?ooooo6Om<C4`00ol0003oIVIVofIVIP0:ofIVIP;o00002_moOgl00ol0003oVIVIoiVIV@0;
oiVIV@03o`000?nc/k?o/k>c01So/k>c00?o0000oiVIVOnIVIT02_nIVIT00ol0003oOgmoogmoO`08
ogmoO`03o`000?mVIVKoIVIV00KoIVIV00?o0000oda<C?m<C4`05?m<C4`00ol0003oIVIVofIVIP03
ofIVIP05o`000?moOgooOgmoogmoOol000001?nIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<
c<coc<c<00?oc<c<00?o0000ok>c/onc/k<01?nc/k<01?l0003oVIVIoiVIVOl00003ogmoO`05o`00
0?mVIVKoIVIVofIVI_l000001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;o
C4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<co
c<c<00Koc<c<00Oo0000ok>c/onc/k?o/k>co`000?nIVIWo000000;oOgmo00Co0000ofIVI_mVIVKo
00000_m<C4`00ol0003o<c<cool00002ool000Go<c<c00So0000oda<C?m<C4co0000ofIVI_l0003o
Ogmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`02?l0003o/k>cok>c/ol0003oVIVIo`00
0?moOgoo00000_mVIVH00ol0003oC4a<o`000009oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmo
o`000?nIVIWo000000;o/k>c00Co0000olc<c?o<c<co00002?ooool002?ooooo6?m<C4`00ol0003o
IVIVofIVIP0:ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o
/k>cok>c/`0Gok>c/`;o00003?nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00Ko
IVIV00?o0000oda<C?m<C4`05?m<C4`00ol0003oIVIVofIVIP03ofIVIP03o`000?moOgooOgmo00;o
Ogmo00Go0000oiVIVOnIVIWoVIVIo`000006ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c
/onc/k<01?nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`00
0004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00om<C4`01_l0003oIVIVofIV
I_l0003oOgmoo`0000;oVIVI00?o0000ok>c/onc/k<00_nc/k<00ol0003oc<c<olc<c005olc<c005
o`000?nc/k?o/k>cok>c/ol000000_nIVIT00ol0003oOgmoo`000002ofIVIP04o`000?m<C4coC4a<
o`0000Go<c<c0ooo00001olc<c?o0000oda<C?m<C4co0000ofIVI_l000000_moOgl00ol0003oVIVI
o`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Oo0000ok>c/ol0003oVIVIo`000?moOgoo0000
00;oIVIV00?o0000oda<C?l000002Olc<c<01ol0003oC4a<o`000?mVIVKo0000ogmoOol000000_nI
VIT00ol0003o/k>co`000003olc<c003o`000?oooooooooo00Kooooo000SoooooaKoC4a<0_l0000<
ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0G
ok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP06
ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`02
ogmoO`05o`000?nIVIWoVIVIoiVIVOl000001onc/k<00ol0003oc<c<olc<c003olc<c003o`000?nc
/k?o/k>c00?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`05o`000?mVIVKoIVIVofIVI_l0
00001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mV
IVKo00000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000
ok>c/onc/k?o/k>co`000002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co0000
2?lc<c<3ool00006oda<C?l0003oIVIVo`000?moOgoo00000_nIVIT00ol0003o/k>co`00000:olc<
c009o`000?nc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<0
1olc<c<02ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000?nc/k?o000000Coc<c<00?o
0000ooooooooool01_ooool002?ooooo5_m<C4`00ol0003oIVIVofIVIP0:ofIVIP03o`000?moOgoo
Ogmo00WoOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWo
VIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP06ofIVIP03o`000?m<C4co
C4a<01CoC4a<00?o0000ofIVI_mVIVH00_mVIVH00ol0003oOgmoogmoO`03ogmoO`05o`000?nIVIWo
VIVIoiVIVOl000001onc/k<00ol0003oc<c<olc<c003olc<c003o`000?nc/k?o/k>c00?o/k>c00Go
0000oiVIVOnIVIWoVIVIo`000003ogmoO`05o`000?mVIVKoIVIVofIVI_l000001?m<C4`00ol0003o
<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0
003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`00
0002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<00ol0003oC4a<
ool00002ool00003o`000?moOgoo000000;oVIVI00?o0000ok>c/ol000002_o<c<`02Ol0003o/k>c
o`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Oo<c<c00_o0000
oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`000004olc<c003o`000?oooooooooo
00Kooooo000SoooooaGoC4a<00?o0000ofIVI_mVIVH02_mVIVH00ol0003oOgmoogmoO`09ogmoO`03
o`000?nIVIWoVIVI00_oVIVI0_l0000Hok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000ogmoOomo
Ogl02?moOgl2o`0000SoIVIV00?o0000oda<C?m<C4`05?m<C4`00ol0003oIVIVofIVIP03ofIVIP03
o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`04ok>c/`03
o`000?o<c<coc<c<00?oc<c<00?o0000ok>c/onc/k<00onc/k<01Ol0003oVIVIoiVIVOnIVIWo0000
00?oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000
oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c
00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmoOol0
00000_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV0ooo0000
1OnIVIWo0000ok>c/onc/k?o000000Woc<c<00?o0000ok>c/ol000000_nIVIT2o`000005ofIVI_l0
003oC4a<oda<C?l000002Olc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002
ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o0000ooooooooool01_ooool001Sooooo00Goc<c<ob4Q
8Ol0003o8B4Qolc<c006oooooa?oC4a<0_l0000<ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000
oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o0000
ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP07ofIVIP03o`000?m<C4coC4a<01CoC4a<00?o0000
ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000
ok>c/onc/k<01?nc/k<00ol0003oc<c<olc<c003olc<c0;o00001Onc/k<01Ol0003oVIVIoiVIVOnI
VIWo000000?oOgmo00Co0000ofIVI_mVIVKo00001?m<C4`00ol0003o<c<coc<c<`06oc<c<`05o`00
0?m<C4coC4a<oda<C?l000000omVIVH01?l0003oOgmoogmoOol00002oiVIV@05o`000?nc/k?o/k>c
ok>c/ol000002?o<c<`01ol0003o/k>cok>c/onc/k?o0000oiVIVOl000000_moOgl01?l0003oIVIV
ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00[o0000oda<C?m<C4coC4a<o`000?mVIVKo
0000ogmoOol0003oVIVI0ooo00000onc/k?o0000olc<c007olc<c00:o`000?nc/k?o/k>co`000?nI
VIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<02_l0003oC4a<oda<
C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o0000
ooooooooool01_ooool001Sooooo00Go8B4QoiRHV?ooooooV9RHob4Q8@06oooooa;oC4a<00?o0000
ofIVI_mVIVH02omVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00coVIVI00?o0000
ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000
ofIVI_mVIVH01omVIVH00ol0003oC4a<oda<C00Doda<C003o`000?mVIVKoIVIV00?oIVIV00Go0000
ogmoOomoOgooOgmoo`000005oiVIV@03o`000?nc/k?o/k>c00Co/k>c00?o0000olc<c?o<c<`00oo<
c<`00ol0003o/k>cok>c/`04ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01?l0003oIVIV
ofIVI_l00004oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000003ofIV
IP04o`000?moOgooOgmoo`0000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c007o`000?nc
/k?o/k>cok>c/ol0003oVIVIo`000002ogmoO`04o`000?mVIVKoIVIVo`0000;oC4a<00?o0000oc<c
<olc<c<01_lc<c<02Ol0003oC4a<oda<C?m<C4co0000ofIVI_l0003oOgmoo`000002oiVIV@03o`00
0?nc/k?oo`0000;oo`001oo<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l0
0002oda<C003o`000?lc<c?o<c<c00Ko<c<c00[o0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`00
0?nIVIWo00000_nc/k<00ol0003oc<c<olc<c002olc<c003o`000?oooooooooo00Kooooo000Hoooo
o`05o`000?ooooooooooooooool000001_oooolAoda<C003o`000?mVIVKoIVIV00coIVIV00?o0000
ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000
oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00OoIVIV00?o0000
oda<C?m<C4`05?m<C4`00ol0003oIVIVofIVIP03ofIVIP03o`000?moOgooOgmo00;oOgmo00?o0000
oiVIVOnIVIT00_nIVIT00ol0003o/k>cok>c/`05ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o0000
ok>c/onc/k<01?nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Go0000ofIVI_mVIVKoIVIV
o`000004oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIV
ofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01ol0
003o/k>cok>c/onc/k?o0000oiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00003oda<C003o`00
0?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH01Ol0003oOgmoo`000?nIVIWo0000
00;o/k>c00?o0000olc<c?o<c<`00ooo0004olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmo
Ool0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01_lc<c<00ol0003oC4a<oda<C002o`0000;o
Ogmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c002olc<c003o`000?oooooooooo00Ko
oooo000Hooooo`05oc8b<_nHV9SooooooiRHV?lb<S801_ooool@oda<C003o`000?mVIVKoIVIV00co
IVIV00?o0000ogmoOomoOgl02?moOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Oo
/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00Ko
IVIV00?o0000oda<C?m<C4`05Om<C4`00ol0003oIVIVofIVIP03ofIVIP05o`000?moOgooOgmoogmo
Ool000001OnIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00?oc<c<00?o0000ok>c
/onc/k<01?nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000;oOgmo00Go0000ofIVI_mVIVKoIVIVo`00
0004oda<C003o`000?lc<c?o<c<c00Ko<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIV
I_l00002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01ol0003o
/k>cok>c/onc/k?o0000oiVIVOl000000_moOgl01?l0003oIVIVofIVI_l00002oda<C003o`000?lc
<c?o<c<c00Ko<c<c00Wo0000oda<C?m<C4coC4a<o`000?mVIVKo0000ogmoOol000000_nIVIT01?l0
003o/k>cok>c/ol00005olc<c0?oo`0000[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mV
IVKo00000_m<C4`00ol0003o<c<coc<c<`07oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`00
0?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`00oo<c<`00ol0003oooooooooo`06ooooo`006?oo
ool01Oo<c<co0000o`000?l0003oc<c<00Kooooo3om<C4`2o`0000goIVIV00?o0000ogmoOomoOgl0
2OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c0_l0000=oiVIV@03o`00
0?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH01omVIVH00ol0003oC4a<oda<C00Doda<C003o`00
0?mVIVKoIVIV00?oIVIV00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@02oiVIV@03o`00
0?nc/k?o/k>c00Go/k>c00?o0000olc<c?o<c<`00_o<c<`00ol0003o/k>cok>c/`04ok>c/`05o`00
0?nIVIWoVIVIoiVIVOl000000omoOgl00ol0003oIVIVofIVIP02o`0000CoC4a<00?o0000oc<c<olc
<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co0000oiVI
VOnIVIWo00000onc/k<00ol0003oc<c<olc<c007olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Ko
0000ogmoOomoOgoo0000ofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<
C4co00000_mVIVH00ol0003oOgmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<0ooo0000
1ol0003oVIVIo`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`09o`00
0?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`00oo<c<`0
0ol0003oooooooooo`06ooooo`006?ooool01Ol@413o^[Zjoooooonj^[[o410@00Kooooo3_m<C4`0
0ol0003oIVIVofIVIP0<ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT0
0ol0003o/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl02OmoOgl0
0ol0003oIVIVofIVIP07ofIVIP03o`000?m<C4coC4a<01GoC4a<00?o0000ofIVI_mVIVH00omVIVH0
0ol0003oOgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01Onc/k<0
0ol0003oc<c<olc<c002olc<c003o`000?nc/k?o/k>c00Co/k>c00Go0000oiVIVOnIVIWoVIVIo`00
0003ogmoO`04o`000?mVIVKoIVIVo`0000GoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<
oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0
003oc<c<olc<c007olc<c004o`000?nc/k?o/k>co`0000;oVIVI00Ko0000ogmoOomoOgoo0000ofIV
I_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH00ol0003o
Ogmoo`000002oiVIV@04o`000?nc/k?o/k>co`0000Soc<c<00?o0000ok>c/onc/k<00ooo00001?mo
Ogoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c00Wo0000oda<C?l0003oIVIVo`00
0?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c003olc<c003o`000?oooooooooo00Ko
oooo000Hooooo`05o`000?nj^[[ooooookZj^_l000001_ooool=oda<C003o`000?mVIVKoIVIV00co
IVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo
/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00Oo
IVIV00?o0000oda<C?m<C4`05Om<C4`00ol0003oIVIVofIVIP03ofIVIP03o`000?moOgooOgmo00;o
Ogmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`04ok>c/`03o`000?o<c<coc<c<00;o
c<c<00?o0000ok>c/onc/k<01?nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Co0000ofIV
I_mVIVKo00001Om<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000
ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Ooc<c<
00Co0000ok>c/onc/k?o00000_nIVIT01_l0003oOgmoogmoOol0003oIVIVo`0000?oC4a<00?o0000
oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP06o`000?moOgooOgmoo`000?nIVIWo
00000_nc/k<00ol0003oc<c<olc<c006olc<c007o`000?nc/k?o/k>co`000?nIVIWo0000ogmoO`03
ool000;oC4a<00?o0000oc<c<olc<c<01olc<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003o
VIVIo`000002ok>c/`03o`000?o<c<coc<c<00Coc<c<00?o0000ooooooooool01_ooool001Sooooo
00GoZJVYoa0@4?l0003o410@ojVYZ@06ooooo`coC4a<00?o0000ofIVI_mVIVH03?mVIVH00ol0003o
OgmoogmoO`08ogmoO`;o00003?nIVIT2o`0001So/k>c0_l0000=oiVIV@03o`000?moOgooOgmo00So
Ogmo0_l00009ofIVIP03o`000?m<C4coC4a<01GoC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003o
OgmoogmoO`02ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<01Onc/k<00ol0003o
c<c<olc<c002olc<c003o`000?nc/k?o/k>c00Co/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmo
O`04o`000?mVIVKoIVIVo`0000GoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002
oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<
olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01_l0003oOgmoogmoOol0003oIVIV
o`0000?oC4a<00?o0000oc<c<olc<c<01_lc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?mo
Ogoo000000;oVIVI00?o0000ok>c/ol000002Oo<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?mo
Ogoo0000ofIVI_l00003ool000Wo<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0
00000_nc/k<00ol0003oc<c<olc<c004olc<c003o`000?oooooooooo00Kooooo000Sooooo`_oC4a<
00?o0000ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI
00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo00SoOgmo
00?o0000ofIVI_mVIVH02OmVIVH00ol0003oC4a<oda<C00Doda<C003o`000?mVIVKoIVIV00CoIVIV
00?o0000ogmoOomoOgl00_moOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c00Co/k>c
00?o0000olc<c?o<c<`00oo<c<`00ol0003o/k>cok>c/`04ok>c/`05o`000?nIVIWoVIVIoiVIVOl0
00000omoOgl01?l0003oIVIVofIVI_l00005oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<
C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o
0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Ko0000ogmoOomoOgoo
0000ofIVI_l00003oda<C003o`000?lc<c?o<c<c00Ko<c<c00Co0000oda<C?m<C4co00000_mVIVH0
0ol0003oOgmoo`000002oiVIV@03o`000?nc/k?o000000Woc<c<00[o0000ok>c/onc/k?o0000oiVI
VOl0003oOgmoo`000?mVIVKo00000_m<C4`01?l0003oo`00ool00?oo0006oc<c<`09o`000?m<C4co
0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01?o<c<`00ol0003o
ooooooooo`06ooooo`008oooool:oda<C003o`000?mVIVKoIVIV00coIVIV00?o0000ogmoOomoOgl0
2?moOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT0
3?nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00WoIVIV00?o0000oda<C?m<C4`0
5?m<C4`00ol0003oIVIVofIVIP04ofIVIP03o`000?moOgooOgmo00;oOgmo00?o0000oiVIVOnIVIT0
0onIVIT00ol0003o/k>cok>c/`05ok>c/`03o`000?o<c<coc<c<00;oc<c<00?o0000ok>c/onc/k<0
1?nc/k<01Ol0003oVIVIoiVIVOnIVIWo000000?oOgmo00Co0000ofIVI_mVIVKo00001Om<C4`00ol0
003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl0
1?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>c
o`000002oiVIV@06o`000?moOgooOgmoo`000?mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c
<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol0
0008olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000
oc<c<olc<c<00_lc<c<3ool000;o<c<c00Wo0000oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0
00000_nc/k<00ol0003oc<c<olc<c005olc<c003o`000?oooooooooo00Kooooo000Sooooo`WoC4a<
00?o0000ofIVI_mVIVH03?mVIVH00ol0003oOgmoogmoO`08ogmoO`03o`000?nIVIWoVIVI00_oVIVI
0_l0000Hok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIV
ofIVIP09ofIVIP03o`000?m<C4coC4a<01GoC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmo
ogmoO`03ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01Onc/k<00ol0003oc<c<
olc<c002olc<c003o`000?nc/k?o/k>c00Co/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`05
o`000?mVIVKoIVIVofIVI_l000001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<
00;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o
0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmoOol00000
0_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Co0000oda<C?m<C4co00000_mVIVH01Ol0
003oOgmoo`000?nIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`02_l0003o/k>cok>c/ol0
003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Go<c<c0ooo00002?m<
C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c005olc<c003o`00
0?oooooooooo00Kooooo000Sooooo`SoC4a<00?o0000ofIVI_mVIVH02omVIVH2o`0000[oOgmo00?o
0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Hok>c/`03o`000?nIVIWoVIVI00_oVIVI00?o
0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP09ofIVIP03o`000?m<C4coC4a<01KoC4a<00?o
0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`03ogmoO`05o`000?nIVIWoVIVIoiVIVOl00000
2?nc/k<01Ol0003oc<c<olc<c?o<c<co000000Oo/k>c00Go0000oiVIVOnIVIWoVIVIo`000003ogmo
O`05o`000?mVIVKoIVIVofIVI_l000001?m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4co
C4a<00;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c
00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00?o0000ogmoOol0
00000_mVIVH01Ol0003oC4a<oda<C?m<C4co000000So<c<c00Co0000oda<C?m<C4co00000_mVIVH0
1Ol0003oOgmoo`000?nIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`02_l0003o/k>cok>c
/ol0003oVIVIo`000?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00?o0000
oda<C?oo00000_oo00001Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01Oo<
c<`00ol0003oooooooooo`06ooooo`008oooool7oda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000
ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c0_l0000=
oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02_mVIVH00ol0003oC4a<oda<C00E
oda<C003o`000?mVIVKoIVIV00?oIVIV00?o0000ogmoOomoOgl00omoOgl00ol0003oVIVIoiVIV@02
oiVIV@03o`000?nc/k?o/k>c00Go/k>c00?o0000olc<c?o<c<`00_o<c<`00ol0003o/k>cok>c/`04
ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01Ol0003oIVIVofIVI_mVIVKo000000CoC4a<
00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C005o`000?mVIVKoIVIVofIVI_l0
00000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Ooc<c<00Co0000ok>c
/onc/k?o00000_nIVIT00ol0003oOgmoo`000002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc
<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o
00002Oo<c<`01ol0003o/k>co`000?nIVIWo0000ogmoOol000000_mVIVH00ol0003oC4a<o`000008
oc<c<`06o`000?m<C4coC4a<o`000?mVIVKo00000ooo00001?l0003o/k>cok>c/ol00008olc<c003
o`000?oooooooooo00Kooooo000Sooooo`KoC4a<00?o0000ofIVI_mVIVH02omVIVH00ol0003oOgmo
ogmoO`09ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVI
oiVIV@0;oiVIV@;o00002_moOgl00ol0003oIVIVofIVIP0:ofIVIP03o`000?m<C4coC4a<01GoC4a<
00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00;oVIVI
00?o0000ok>c/onc/k<01_nc/k<01Ol0003oc<c<olc<c?o<c<co000000Oo/k>c00Go0000oiVIVOnI
VIWoVIVIo`000003ogmoO`05o`000?mVIVKoIVIVofIVI_l000001?m<C4`00ol0003o<c<coc<c<`05
oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01Ol0003oVIVIoiVI
VOnIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;o
VIVI00?o0000ogmoOol000000_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`04o`000?m<C4coC4a<
o`0000;oIVIV00Go0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00[o
0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c<`06
oc<c<`09o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVI00?oo`0000?o0000olc<c?o<
c<`01_o<c<`00ol0003oooooooooo`06ooooo`008oooool6oda<C003o`000?mVIVKoIVIV00[oIVIV
0_l0000:ogmoO`03o`000?nIVIWoVIVI00coVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVI
oiVIV@0:oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<
oda<C00Doda<C003o`000?mVIVKoIVIV00CoIVIV00?o0000ogmoOomoOgl00omoOgl00ol0003oVIVI
oiVIV@02oiVIV@03o`000?nc/k?o/k>c00Ko/k>c00Go0000olc<c?o<c<coc<c<o`000007ok>c/`05
o`000?nIVIWoVIVIoiVIVOl000000omoOgl01Ol0003oIVIVofIVI_mVIVKo000000CoC4a<00?o0000
oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Go
0000oiVIVOnIVIWoVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o
/k>co`000002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<01?l0
003oC4a<oda<C?l00002ofIVIP05o`000?moOgoo0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<
c007olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000
oc<c<olc<c<01_lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>c
o`0000?oo`001_o<c<`00ol0003oooooooooo`06ooooo`008oooool5oda<C003o`000?mVIVKoIVIV
00[oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@;o00006?nc/k<2o`00
00coVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<C4coC4a<
01GoC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI
00;oVIVI00?o0000ok>c/onc/k<02?nc/k<00ol0003oc<c<o`000007ok>c/`05o`000?nIVIWoVIVI
oiVIVOl000000omoOgl01Ol0003oIVIVofIVI_mVIVKo000000CoC4a<00?o0000oc<c<olc<c<01Olc
<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Go0000oiVIVOnIVIWo
VIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVI
V@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<01?l0003oC4a<oda<C?l0
0002ofIVIP03o`000?moOgooOgmo00;o00000_nc/k<00ol0003oc<c<olc<c007olc<c006o`000?nc
/k?o/k>co`000?nIVIWo00000_moOgl2o`0000;oC4a<00?o0000oc<c<olc<c<01olc<c<00ol0003o
C4a<o`000002ofIVIP;o000000GoVIVIo`000?nc/k?o/k>co`000003olc<c0Goo`000_l00008oooo
o`008oooool3oda<C0;o00003?mVIVH00ol0003oOgmoogmoO`09ogmoO`03o`000?nIVIWoVIVI00_o
VIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00Wo
Ogmo00?o0000ofIVI_mVIVH02_mVIVH2o`0001OoC4a<00?o0000ofIVI_mVIVH00omVIVH00ol0003o
OgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01_nc/k<5o`0000Oo
/k>c00Co0000oiVIVOnIVIWoVIVI0_l00002ogmoO`05o`000?mVIVKoIVIVofIVI_l000001?m<C4`2
o`0000Oo<c<c00?o0000oda<C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nI
VIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00002oiVIV@04
o`000?moOgooOgmoo`0000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<01_l0003oC4a<oda<C?l0
003oIVIVo`0000;oOgmo00?o0000oiVIVOl000000_nc/k<00ol0003oc<c<olc<c007olc<c00:o`00
0?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<00?o0000oc<c<olc<c<01olc
<c<02Ol0003oC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<
00Koc<c<0_oo0008ooooo`008oooool2oda<C003o`000?mVIVKoIVIV00_oIVIV00?o0000ogmoOomo
Ogl02OmoOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnI
VIT03?nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<
C4`05Om<C4`00ol0003oIVIVofIVIP04ofIVIP03o`000?moOgooOgmo00?oOgmo00?o0000oiVIVOnI
VIT00_nIVIT00ol0003o/k>cok>c/`06ok>c/`05o`000?o<c<coc<c<olc<c?l000001onc/k<01Ol0
003oVIVIoiVIVOnIVIWo000000?oOgmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc
<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000003ofIVIP04o`000?moOgooOgmoo`0000;o
VIVI00?o0000ok>c/onc/k<00_nc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`00
00;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`06o`000?m<
C4coC4a<o`000?mVIVKo00000_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Oo
c<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<c
oc<c<`07oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000
olc<c?o<c<`01_o<c<`2o`0000Sooooo000Sooooo`03oda<C?l0003oIVIV00goIVIV00?o0000ogmo
OomoOgl02?moOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVI
VOnIVIT03?nIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<
C?m<C4`05Om<C4`00ol0003oIVIVofIVIP04ofIVIP03o`000?moOgooOgmo00?oOgmo00?o0000oiVI
VOnIVIT00onIVIT00ol0003o/k>cok>c/`06ok>c/`04o`000?o<c<coc<c<o`0000Oo/k>c00?o0000
oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000;oIVIV00?o0000oda<C?m<C4`00om<
C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo0000
0omoOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc
/k?o/k>co`000002oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<0
1?l0003oC4a<oda<C?l00002ofIVIP06o`000?moOgooOgmoo`000?nIVIWo00000_nc/k<00ol0003o
c<c<olc<c007olc<c00:o`000?nc/k?o/k>co`000?nIVIWo0000ogmoOol0003oIVIVo`0000;oC4a<
00?o0000oc<c<olc<c<01_lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0
003o/k>co`0000Woc<c<0_l00008ooooo`008oooool00ol0003oIVIVofIVIP0<ofIVIP03o`000?mo
OgooOgmo00SoOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nI
VIWoVIVI00_oVIVI00?o0000ogmoOomoOgl02OmoOgl00ol0003oIVIVofIVIP0;ofIVIP03o`000?m<
C4coC4a<01GoC4a<00?o0000ofIVI_mVIVH01?mVIVH00ol0003oOgmoogmoO`03ogmoO`03o`000?nI
VIWoVIVI00;oVIVI00?o0000ok>c/onc/k<01_nc/k<01Ol0003oc<c<olc<c?o<c<co000000Oo/k>c
00Go0000oiVIVOnIVIWoVIVIo`000003ogmoO`05o`000?mVIVKoIVIVofIVI_l000001?m<C4`00ol0
003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000omVIVH01Ol0003oOgmoogmoOomo
Ogoo000000;oVIVI00Go0000ok>c/onc/k?o/k>co`000008olc<c004o`000?nc/k?o/k>co`0000;o
VIVI00Co0000ogmoOomoOgoo00000_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`06o`000?m<C4co
C4a<o`000?mVIVKo00000_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<
00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<coc<c
<`07oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<
c?o<c<`01_o<c<`00ol0003o/k>co`000008ooooo`008oooool=ofIVIP;o00002omoOgl00ol0003o
VIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c0_l0000=oiVIV@03o`000?moOgooOgmo00Wo
Ogmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Eoda<C003o`000?mVIVKoIVIV00Co
IVIV00?o0000ogmoOomoOgl00omoOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c00Ko
/k>c0_l000000oo<c<co0000ok>c/`06ok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomo
OgooOgmoo`000003ofIVIP03o`000?m<C4coC4a<00;oC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0
003oC4a<oda<C002oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl0
0003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`00
0?moOgooOgmoo`0000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<01ol0003oC4a<oda<C?m<C4co
0000ofIVI_l000000_moOgl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Koc<c<0_l0
0002ok>c/`07o`000?nIVIWo0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko
<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol00009olc<c003
o`000?nc/k?o000000Sooooo000Sooooo`goIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVI
oiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003oOgmo
ogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIV
ofIVIP04ofIVIP03o`000?moOgooOgmo00?oOgmo00?o0000oiVIVOnIVIT00_nIVIT00ol0003o/k>c
ok>c/`09ok>c/`03o`000?nc/k?o/k>c00Ko/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmo
ogmoOomoOgoo000000?oIVIV00?o0000oda<C?m<C4`00_m<C4`00ol0003o<c<coc<c<`05oc<c<`03
o`000?m<C4coC4a<00;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`04o`000?nIVIWoVIVI
o`0000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co
0000ogmoOomoOgoo00000_mVIVH01?l0003oC4a<oda<C?l00008oc<c<`07o`000?m<C4coC4a<oda<
C?l0003oIVIVo`000002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`0
2ol0003o/k>cok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c
<olc<c<01_lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`00
00Woc<c<00?o0000ok>c/ol000002?ooool002?ooooo3?mVIVH00ol0003oOgmoogmoO`09ogmoO`03
o`000?nIVIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03
o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Foda<C003
o`000?mVIVKoIVIV00CoIVIV00?o0000ogmoOomoOgl00omoOgl00ol0003oVIVIoiVIV@02oiVIV@03
o`000?nc/k?o/k>c01;o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo0000
00?oIVIV00?o0000oda<C?m<C4`00_m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<
00;oC4a<00Go0000ofIVI_mVIVKoIVIVo`000002ogmoO`04o`000?nIVIWoVIVIo`0000?o/k>c00?o
0000olc<c?o<c<`01_o<c<`00ol0003o/k>cok>c/`02ok>c/`03o`000?nIVIWo000000;oOgmo00Co
0000ofIVI_mVIVKo00000_m<C4`00ol0003o<c<coc<c<`07oc<c<`06o`000?m<C4coC4a<o`000?mV
IVKo00000_moOgl01?l0003oVIVIoiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00So0000
ok>c/onc/k?o0000oiVIVOl0003oOgmoo`0000;oIVIV00?o0000oda<C?l000002?lc<c<02_l0003o
C4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<
00Co0000ok>c/onc/k?o00002?ooool002?ooooo2omVIVH00ol0003oOgmoogmoO`08ogmoO`;o0000
3?nIVIT2o`0001So/k>c0_l0000=oiVIV@03o`000?moOgooOgmo00SoOgmo0_l0000<ofIVIP;o0000
6?m<C4`00ol0003oIVIVofIVIP04ofIVIP03o`000?moOgooOgmo00?oOgmo00?o0000oiVIVOnIVIT0
0onIVIT00ol0003o/k>cok>c/`0Bok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01Ol0003o
IVIVofIVI_mVIVKo000000GoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<
C004o`000?mVIVKoIVIVo`0000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000003ok>c/`03o`000?o<
c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@06o`000?moOgooOgmoo`000?mV
IVKo00000_m<C4`00ol0003o<c<coc<c<`08oc<c<`07o`000?m<C4coC4a<o`000?mVIVKo0000ogmo
O`02o`000005oiVIVOl0003o/k>cok>c/ol000002Oo<c<`02_l0003o/k>cok>c/ol0003oVIVIo`00
0?moOgoo0000ofIVI_l00002oda<C003o`000?lc<c?o<c<c00Ko<c<c00[o0000oda<C?m<C4co0000
ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o
/k>co`0000Sooooo000Sooooo`[oIVIV00?o0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0:
oiVIV@03o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0003oOgmoogmoO`08
ogmoO`03o`000?mVIVKoIVIV00coIVIV00?o0000oda<C?m<C4`05_m<C4`00ol0003oIVIVofIVIP04
ofIVIP03o`000?moOgooOgmo00CoOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0B
ok>c/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01Ol0003oIVIVofIVI_mVIVKo000000CoC4a<
00?o0000oc<c<olc<c<01_lc<c<00ol0003oC4a<oda<C002oda<C004o`000?mVIVKoIVIVo`0000;o
Ogmo00Go0000oiVIVOnIVIWoVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c
/onc/k?o/k>co`000002oiVIV@06o`000?moOgooOgmoo`000?mVIVKo00000_m<C4`00ol0003o<c<c
oc<c<`08oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVIV@04o`000?nc/k?o
/k>co`0000Woc<c<00[o0000ok>c/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00000_m<C4`0
0ol0003o<c<coc<c<`06oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`00
00;o/k>c00?o0000olc<c?o<c<`01_o<c<`01?l0003o/k>cok>c/ol00008ooooo`008oooool9ofIV
IP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Fok>c
/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0<ofIV
IP03o`000?m<C4coC4a<01KoC4a<00?o0000ofIVI_mVIVH01OmVIVH00ol0003oOgmoogmoO`03ogmo
O`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<04_nc/k<01Ol0003oVIVIoiVIVOnIVIWo
000000CoOgmo00Co0000ofIVI_mVIVKo00001Om<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<
C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000?o
/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Ko0000ogmo
OomoOgoo0000ofIVI_l00003oda<C003o`000?lc<c?o<c<c00Oo<c<c00So0000oda<C?m<C4co0000
ofIVI_l0003oOgmoo`0000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`01_l0003o/k>cok>c/ol0
003oVIVIo`0000;oOgmo0_l00002oda<C003o`000?lc<c?o<c<c00Oo<c<c00?o0000oda<C?l00000
0_mVIVH2o`000005oiVIVOl0003o/k>cok>c/ol000002Oo<c<`01?l0003o/k>co`000?l00008oooo
o`008oooool8ofIVIP03o`000?moOgooOgmo00SoOgmo0_l0000<oiVIV@;o00006?nc/k<00ol0003o
VIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH02omVIVH2o`0001So
C4a<00?o0000ofIVI_mVIVH01OmVIVH00ol0003oOgmoogmoO`03ogmoO`03o`000?nIVIWoVIVI00?o
VIVI00?o0000ok>c/onc/k<04_nc/k<00ol0003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmo
Ool000000omVIVH00ol0003oC4a<oda<C002oda<C003o`000?lc<c?o<c<c00Ko<c<c00?o0000oda<
C?m<C4`00_m<C4`01?l0003oIVIVofIVI_l00002ogmoO`03o`000?nIVIWoVIVI00;o00000onc/k<0
0ol0003oc<c<olc<c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT00ol0003oOgmoo`00
0002ofIVIP05o`000?m<C4coC4a<oda<C?l000002?lc<c<01?l0003oC4a<oda<C?l00002ofIVIP03
o`000?moOgoo000000;oVIVI00?o0000ok>c/ol000002_o<c<`00ol0003o/k>co`000002oiVIV@05
o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`07oc<c<`09o`000?m<C4co0000
ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`00ol0003o/k>c
ok>c/`02o`0000Sooooo000Sooooo`KoIVIV0_l0000:ogmoO`03o`000?nIVIWoVIVI00_oVIVI00?o
0000ok>c/onc/k<06?nc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00SoOgmo00?o
0000ofIVI_mVIVH03?mVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00GoIVIV00?o
0000ogmoOomoOgl00omoOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c01;o/k>c00?o
0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000?oIVIV00?o0000oda<C?m<C4`0
0_m<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00?oC4a<00Co0000ofIVI_mVIVKo
00000_moOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Goc<c<00?o0000ok>c
/onc/k<00_nc/k<01_l0003oVIVIoiVIVOl0003oOgmoo`0000;oIVIV00Co0000oda<C?m<C4co0000
2Olc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00?o0000ok>c/ol0
00002_o<c<`00ol0003o/k>co`000002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0
003o<c<coc<c<`07oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o/k>c
00?o0000olc<c?o<c<`01_o<c<`00ol0003o/k>cok>c/`02o`0000Sooooo000Sooooo`GoIVIV00?o
0000ogmoOomoOgl02OmoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Oo/k>c0_l0
000=oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000ofIVI_mVIVH03?mVIVH00ol0003oC4a<oda<
C00Goda<C003o`000?mVIVKoIVIV00GoIVIV00?o0000ogmoOomoOgl00omoOgl00ol0003oVIVIoiVI
V@03oiVIV@03o`000?nc/k?o/k>c01;o/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmo
OomoOgoo000000?oIVIV00?o0000oda<C?m<C4`00_m<C4`00ol0003o<c<coc<c<`06oc<c<`03o`00
0?m<C4coC4a<00;oC4a<00Co0000ofIVI_mVIVKo00000_moOgl01?l0003oVIVIoiVIVOl00004ok>c
/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@06o`000?moOgoo
Ogmoo`000?mVIVKo00000om<C4`00ol0003o<c<coc<c<`06oc<c<`09o`000?m<C4coC4a<oda<C?l0
003oIVIVo`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002Oo<c<`00ol0003o/k>co`00
0003oiVIV@;o000000GoIVIVo`000?m<C4coC4a<o`000009oc<c<`03o`000?m<C4coC4a<00;o0000
00OoOgmoo`000?nIVIWoVIVIo`000?nc/k?o000000Woc<c<00Go0000ok>c/ol0003oVIVIo`000008
ooooo`008oooool4ofIVIP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0
003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00_oVIVI0_l0000:ogmoO`03o`000?mVIVKoIVIV
00coIVIV00?o0000oda<C?m<C4`05om<C4`00ol0003oIVIVofIVIP05ofIVIP03o`000?moOgooOgmo
00?oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0Cok>c/`05o`000?nIVIWoVIVI
oiVIVOl000000omoOgl01Ol0003oIVIVofIVI_mVIVKo000000GoC4a<00?o0000oc<c<olc<c<01Olc
<c<00ol0003oC4a<oda<C002oda<C005o`000?mVIVKoIVIVofIVI_l000000_moOgl01?l0003oVIVI
oiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o/k>c0_l000001OnI
VIWo0000ogmoOomoOgoo000000;oIVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`04o`000?m<
C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00008olc<c004
o`000?nc/k?o/k>co`0000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o
<c<c00Ko<c<c00co0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo0000ok>c/ol0000:
olc<c0;o000000?oVIVIo`000?l000002?ooool002?ooooo0omVIVH2o`0000[oOgmo00?o0000oiVI
VOnIVIT02onIVIT00ol0003o/k>cok>c/`0Hok>c/`03o`000?nIVIWoVIVI00[oVIVI00?o0000ogmo
OomoOgl02OmoOgl00ol0003oIVIVofIVIP0;ofIVIP;o00006_m<C4`00ol0003oIVIVofIVIP05ofIV
IP03o`000?moOgooOgmo00?oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0Cok>c
/`05o`000?nIVIWoVIVIoiVIVOl000000omoOgl01Ol0003oIVIVofIVI_mVIVKo000000GoC4a<00?o
0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C005o`000?mVIVKoIVIVofIVI_l00000
0_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc
/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Go0000oda<C?m<C4coC4a<o`00
0008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00Go0000ogmoOol0003oVIVIo`000003ok>c/`03
o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o00000_nIVIT01Ol0003oOgmoo`000?mVIVKo
000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<03?l0003oC4a<oda<C?l0003oIVIVo`000?moOgoo
0000oiVIVOl0003o/k>co`0000[oc<c<0_l000000onIVIWo0000o`000008ooooo`008oooool2ofIV
IP03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT02onIVIT00ol0003o/k>cok>c/`0Gok>c
/`;o00003?nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<
C?m<C4`06?m<C4`2o`0000OoIVIV00?o0000ogmoOomoOgl00omoOgl00ol0003oVIVIoiVIV@03oiVI
V@03o`000?nc/k?o/k>c01?o/k>c00Go0000oiVIVOnIVIWoVIVIo`000004ogmoO`04o`000?mVIVKo
IVIVo`0000GoC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C005o`000?mV
IVKoIVIVofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00003ok>c/`03o`000?o<c<coc<c<00Ko
c<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Go0000
oda<C?m<C4coC4a<o`000008oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol00000
0_nIVIT01Ol0003o/k>cok>c/onc/k?o000000Soc<c<00?o0000ok>c/ol000000_nIVIT00ol0003o
Ogmoo`000002ofIVIP03o`000?m<C4co000000So<c<c00Ko0000oda<C?m<C4co0000ofIVI_l00002
ogmoO`;o00000_nc/k<00ol0003oc<c<olc<c007olc<c006o`000?nc/k?o0000o`000?moOgoo0000
2?ooool002?ooooo00?oIVIVo`000?moOgl02_moOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc
/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mV
IVKoIVIV00_oIVIV00?o0000oda<C?m<C4`06?m<C4`00ol0003oIVIVofIVIP06ofIVIP03o`000?mo
OgooOgmo00?oOgmo00?o0000oiVIVOnIVIT00onIVIT00ol0003o/k>cok>c/`0Cok>c/`05o`000?nI
VIWoVIVIoiVIVOl000001?moOgl01Ol0003oIVIVofIVI_mVIVKo000000CoC4a<00?o0000oc<c<olc
<c<01Olc<c<00ol0003oC4a<oda<C003oda<C004o`000?mVIVKoIVIVo`0000;oOgmo00Go0000oiVI
VOnIVIWoVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`00
0002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<01?l0003o
C4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`0
1?l0003o/k>cok>c/ol00002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<c
oc<c<`06oc<c<`0:o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o
0000olc<c?o<c<`01_o<c<`00ol0003o/k>cok>c/`02o`000003ogmoOol0003ooooo00Oooooo000S
ooooo`03o`000?moOgooOgmo00WoOgmo00?o0000oiVIVOnIVIT03?nIVIT00ol0003o/k>cok>c/`0F
ok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003oIVIVofIVIP0<
ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH01omVIVH00ol0003oOgmoogmoO`03
ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<04onc/k<01Ol0003oVIVIoiVIVOnI
VIWo000000CoOgmo00Go0000ofIVI_mVIVKoIVIVo`000004oda<C003o`000?lc<c?o<c<c00Go<c<c
00?o0000oda<C?m<C4`00om<C4`01?l0003oIVIVofIVI_l00002ogmoO`04o`000?nIVIWoVIVIo`00
00Co/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/onc/k?o000000;oVIVI00Co0000
ogmoOomoOgoo00000_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`04o`000?m<C4coC4a<o`0000;o
IVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00008olc<c004o`000?nc/k?o/k>c
o`0000;oVIVI00Go0000ogmoOol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00[o
0000oda<C?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006
olc<c003o`000?nc/k?o/k>c00;o000000?oOgmoo`000?ooool01oooool002?ooooo2omoOgl00ol0
003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnIVIT03?nIVIT00ol0
003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00coIVIV00?o0000oda<C?m<C4`05om<C4`00ol0
003oIVIVofIVIP07ofIVIP03o`000?moOgooOgmo00?oOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0
003o/k>cok>c/`0Bok>c/`05o`000?nIVIWoVIVIoiVIVOl000001?moOgl01Ol0003oIVIVofIVI_mV
IVKo000000GoC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C003oda<C005o`000?mV
IVKoIVIVofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Go
c<c<00?o0000ok>c/onc/k<00_nc/k<01?l0003oVIVIoiVIVOl00002ogmoO`03o`000?mVIVKo0000
00?oC4a<00?o0000oc<c<olc<c<01_lc<c<01ol0003oC4a<oda<C?m<C4co0000ofIVI_l000000_mo
Ogl01?l0003oVIVIoiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00Co0000ok>c/onc/k?o
00000_nIVIT01Ol0003oOgmoo`000?mVIVKo000000;oC4a<00?o0000oc<c<olc<c<01_lc<c<03?l0
003oC4a<oda<C?l0003oIVIVo`000?moOgoo0000oiVIVOl0003o/k>co`0000Woc<c<00?o0000ok>c
/onc/k<00_l000000omoOgoo0000ooooo`07ooooo`008oooool:ogmoO`03o`000?nIVIWoVIVI00co
VIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?moOgooOgmo00Wo
Ogmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Hoda<C003o`000?mVIVKoIVIV00Oo
IVIV00?o0000ogmoOomoOgl00omoOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c01;o
/k>c00Go0000oiVIVOnIVIWoVIVIo`000004ogmoO`05o`000?mVIVKoIVIVofIVI_l000001?m<C4`0
0ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00?oC4a<00Co0000ofIVI_mVIVKo00000_mo
Ogl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o
/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;oIVIV00Co0000oda<C?m<C4co00002Olc<c<0
1?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c/onc/k?o0000
2Oo<c<`00ol0003o/k>co`000002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o
<c<coc<c<`07oc<c<`03o`000?m<C4co000000;oIVIV0_l000001OnIVIWo0000ok>c/onc/k?o0000
00Woc<c<00Oo0000ok>c/ol0003oVIVIo`000?moOgoo000000Sooooo000Sooooo`WoOgmo0_l0000=
oiVIV@03o`000?nc/k?o/k>c01Ko/k>c0_l0000=oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000
ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Hoda<C003o`000?mVIVKoIVIV00OoIVIV00?o0000
ogmoOomoOgl00omoOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c01;o/k>c00?o0000
oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000?oIVIV00?o0000oda<C?m<C4`00om<
C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Go0000ofIVI_mVIVKoIVIV
o`000002ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o
/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01?l0003oC4a<oda<C?l0
0009oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000ogmoOol000000_nIVIT01?l0003o/k>c
ok>c/ol00009olc<c004o`000?nc/k?o0000oiVIV@;o000000CoOgmoo`000?mVIVKo00000_m<C4`0
0ol0003o<c<coc<c<`07oc<c<`09o`000?m<C4co0000ofIVI_l0003oOgmoo`000?nIVIWo000000;o
/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o/k>cok>c/ol0003oVIVI00?o00002?ooool002?o
oooo2?moOgl00ol0003oVIVIoiVIV@0<oiVIV@03o`000?nc/k?o/k>c01Ko/k>c00?o0000oiVIVOnI
VIT03?nIVIT00ol0003oOgmoogmoO`09ogmoO`03o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<
C4`06?m<C4`00ol0003oIVIVofIVIP07ofIVIP03o`000?moOgooOgmo00CoOgmo00?o0000oiVIVOnI
VIT01?nIVIT00ol0003o/k>cok>c/`0Bok>c/`03o`000?nIVIWoVIVI00;oVIVI00Co0000ogmoOomo
Ogoo00001?mVIVH00ol0003oC4a<oda<C003oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<
C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo00001?nc
/k<00ol0003oc<c<olc<c006olc<c004o`000?nc/k?o/k>co`0000?oVIVI00Co0000ogmoOomoOgoo
00000_mVIVH01?l0003oC4a<oda<C?l00009oc<c<`04o`000?m<C4coC4a<o`0000;oIVIV00?o0000
ogmoOol000000_nIVIT01?l0003o/k>cok>c/ol00009olc<c005o`000?nc/k?o0000oiVIVOl00000
0_moOgl00ol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00?o0000oda<C?l00000
0_mVIVH01Ol0003oOgmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o
/k>cok>c/ol0003oVIVI00?o00002?ooool002?ooooo1omoOgl00ol0003oVIVIoiVIV@0<oiVIV@03
o`000?nc/k?o/k>c01Oo/k>c00?o0000oiVIVOnIVIT02onIVIT00ol0003oOgmoogmoO`09ogmoO`03
o`000?mVIVKoIVIV00_oIVIV00?o0000oda<C?m<C4`06?m<C4`00ol0003oIVIVofIVIP07ofIVIP03
o`000?moOgooOgmo00CoOgmo00?o0000oiVIVOnIVIT01?nIVIT00ol0003o/k>cok>c/`0Bok>c/`03
o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`000003ofIVIP03o`000?m<C4coC4a<
00?oC4a<00?o0000oc<c<olc<c<01Olc<c<00ol0003oC4a<oda<C002oda<C005o`000?mVIVKoIVIV
ofIVI_l000000_moOgl01?l0003oVIVIoiVIVOl00004ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go
0000ok>c/onc/k?o/k>co`000003oiVIV@03o`000?moOgoo000000;oIVIV00Co0000oda<C?m<C4co
00002Olc<c<01?l0003oC4a<oda<C?l00002ofIVIP03o`000?moOgoo000000;oVIVI00Co0000ok>c
/onc/k?o00002Oo<c<`00ol0003o/k>co`000002oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<
C4`00ol0003o<c<coc<c<`06oc<c<`08o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol00002oiVI
V@03o`000?nc/k?o000000Soc<c<00Oo0000ok>c/onc/k?o0000oiVIVOl0003oOgmo00;o00002?oo
ool002?ooooo1omoOgl00ol0003oVIVIoiVIV@0;oiVIV@03o`000?nc/k?o/k>c01Ko/k>c0_l0000=
oiVIV@03o`000?moOgooOgmo00WoOgmo00?o0000ofIVI_mVIVH02_mVIVH2o`0001[oC4a<00?o0000
ofIVI_mVIVH01omVIVH00ol0003oOgmoogmoO`04ogmoO`03o`000?nIVIWoVIVI00?oVIVI0_l0000D
ok>c/`03o`000?nIVIWoVIVI00;oVIVI00Go0000ogmoOomoOgooOgmoo`000004ofIVIP03o`000?m<
C4coC4a<00?oC4a<00?o0000oc<c<olc<c<01?lc<c<00ol0003oC4a<oda<C003oda<C004o`000?mV
IVKoIVIVo`0000?oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<c003
o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl00ol0003oIVIVo`000003oda<
C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP03o`000?moOgoo
000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@05o`00
0?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0:o`000?m<C4coC4a<o`00
0?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`01ol0003o/k>c
ok>c/ol0003oVIVIo`000?moOgl00_l00008ooooo`008oooool6ogmoO`03o`000?nIVIWoVIVI00_o
VIVI00?o0000ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo00Wo
Ogmo00?o0000ofIVI_mVIVH02omVIVH00ol0003oC4a<oda<C00Hoda<C003o`000?mVIVKoIVIV00So
IVIV00?o0000ogmoOomoOgl01?moOgl00ol0003oVIVIoiVIV@03oiVIV@03o`000?nc/k?o/k>c01?o
/k>c00?o0000oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000CoIVIV00?o0000oda<
C?m<C4`00om<C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Co0000ofIV
I_mVIVKo00000_moOgl01Ol0003oVIVIoiVIVOnIVIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<
c<`00ol0003o/k>cok>c/`02ok>c/`04o`000?nIVIWoVIVIo`0000;oOgmo00?o0000ofIVI_l00000
0om<C4`00ol0003o<c<coc<c<`06oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01Ol0003o
Ogmoo`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`01?l0003o/k>cok>c/ol00002
oiVIV@05o`000?moOgoo0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0:o`000?m<
C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`0
1ol0003o/k>cok>c/ol0003oVIVIo`000?moOgl00_l00008ooooo`008oooool5ogmoO`03o`000?nI
VIWoVIVI00_oVIVI00?o0000ok>c/onc/k<05onc/k<00ol0003oVIVIoiVIV@0;oiVIV@03o`000?mo
OgooOgmo00SoOgmo0_l0000=ofIVIP03o`000?m<C4coC4a<01SoC4a<00?o0000ofIVI_mVIVH02?mV
IVH00ol0003oOgmoogmoO`04ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<04onc
/k<00ol0003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol000001?mVIVH00ol0003oC4a<
oda<C003oda<C003o`000?lc<c?o<c<c00Co<c<c00?o0000oda<C?m<C4`00om<C4`01Ol0003oIVIV
ofIVI_mVIVKo000000;oOgmo00Co0000oiVIVOnIVIWo00000onc/k<00ol0003oc<c<olc<c006olc<
c003o`000?nc/k?o/k>c00;o/k>c00Co0000oiVIVOnIVIWo00000_moOgl00ol0003oIVIVo`000003
oda<C003o`000?lc<c?o<c<c00Ko<c<c00Go0000oda<C?m<C4coC4a<o`000002ofIVIP03o`000?mo
Ogoo000000;oVIVI00Co0000ok>c/onc/k?o00002?o<c<`01?l0003o/k>cok>c/ol00002oiVIV@03
o`000?moOgoo000000;oIVIV00?o0000oda<C?l000002?lc<c<01_l0003oC4a<oda<C?l0003oIVIV
o`0000;oOgmo0_l00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00[o0000ok>c/onc/k?o0000oiVI
VOl0003oOgmoo`000?mVIVKo00002?ooool002?ooooo0omoOgl2o`0000coVIVI0_l0000Hok>c/`;o
00003OnIVIT00ol0003oOgmoogmoO`08ogmoO`03o`000?mVIVKoIVIV00_oIVIV0_l0000Ioda<C0;o
00002_mVIVH00ol0003oOgmoogmoO`04ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc
/k<04onc/k<00ol0003oVIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol000000omVIVH00ol0
003oC4a<oda<C003oda<C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0
003oIVIVofIVI_mVIVKo000000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000003ok>c/`03o`000?o<
c<coc<c<00Koc<c<00Go0000ok>c/onc/k?o/k>co`000002oiVIV@04o`000?moOgooOgmoo`0000;o
IVIV00Go0000oda<C?m<C4coC4a<o`000008oc<c<`07o`000?m<C4coC4a<oda<C?l0003oIVIVo`00
0002ogmoO`03o`000?nIVIWo000000;o/k>c00?o0000olc<c?o<c<`01oo<c<`01_l0003o/k>cok>c
/ol0003oVIVIo`0000;oOgmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0:
o`000?m<C4coC4a<o`000?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`0
1_o<c<`02_l0003o/k>cok>c/ol0003oVIVIo`000?moOgoo0000ofIVI_l00008ooooo`004Oooool4
o`000008oa0@4?ooooooooooonk^k_lb<S;o0000oc8b<_o^k^h6ooooo`;oOgmo00?o0000oiVIVOnI
VIT02onIVIT00ol0003o/k>cok>c/`0Gok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomo
Ogl02?moOgl00ol0003oIVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mV
IVH02OmVIVH00ol0003oOgmoogmoO`04ogmoO`03o`000?nIVIWoVIVI00CoVIVI00?o0000ok>c/onc
/k<05?nc/k<00ol0003oVIVIoiVIV@02oiVIV@04o`000?moOgooOgmoo`0000CoIVIV00?o0000oda<
C?m<C4`00om<C4`00ol0003o<c<coc<c<`05oc<c<`03o`000?m<C4coC4a<00;oC4a<00Go0000ofIV
I_mVIVKoIVIVo`000002ogmoO`05o`000?nIVIWoVIVIoiVIVOl000000onc/k<00ol0003oc<c<olc<
c006olc<c005o`000?nc/k?o/k>cok>c/ol000000_nIVIT01?l0003oOgmoogmoOol00002ofIVIP05
o`000?m<C4coC4a<oda<C?l000002?lc<c<01ol0003oC4a<oda<C?m<C4co0000ofIVI_l000000_mo
Ogl00ol0003oVIVIo`000002ok>c/`03o`000?o<c<coc<c<00Ooc<c<00So0000ok>c/onc/k?o0000
oiVIVOl0003oOgmoo`0000;oIVIV00Co0000oda<C?m<C4co00002?lc<c<02_l0003oC4a<oda<C?l0
003oIVIVo`000?moOgoo0000oiVIVOl00002ok>c/`03o`000?o<c<coc<c<00Koc<c<00[o0000ok>c
/onc/k?o0000oiVIVOl0003oOgmoo`000?mVIVKo00002?ooool001?ooooo00?o0000ooooooooool0
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?oOgmoo`000?nIVIT03OnIVIT00ol0003o
/k>cok>c/`0Fok>c/`03o`000?nIVIWoVIVI00coVIVI00?o0000ogmoOomoOgl02?moOgl00ol0003o
IVIVofIVIP0<ofIVIP03o`000?m<C4coC4a<01OoC4a<00?o0000ofIVI_mVIVH02OmVIVH00ol0003o
OgmoogmoO`05ogmoO`03o`000?nIVIWoVIVI00?oVIVI00?o0000ok>c/onc/k<05?nc/k<00ol0003o
VIVIoiVIV@02oiVIV@05o`000?moOgooOgmoogmoOol000000omVIVH00ol0003oC4a<oda<C003oda<
C003o`000?lc<c?o<c<c00Go<c<c00?o0000oda<C?m<C4`00_m<C4`01Ol0003oIVIVofIVI_mVIVKo
000000;oOgmo00Go0000oiVIVOnIVIWoVIVIo`000003ok>c/`03o`000?o<c<coc<c<00Koc<c<00Go
0000ok>c/onc/k?o/k>co`000002oiVIV@05o`000?moOgooOgmoogmoOol000000_mVIVH01?l0003o
C4a<oda<C?l00008oc<c<`05o`000?m<C4coC4a<oda<C?l000000_mVIVH01Ol0003oOgmoo`000?nI
VIWo000000?o/k>c00?o0000olc<c?o<c<`01_o<c<`01_l0003o/k>cok>c/ol0003oVIVIo`0000;o
Ogmo00?o0000ofIVI_l000000_m<C4`00ol0003o<c<coc<c<`06oc<c<`0:o`000?m<C4coC4a<o`00
0?mVIVKo0000ogmoOol0003oVIVIo`0000;o/k>c00?o0000olc<c?o<c<`01_o<c<`02Ol0003o/k>c
ok>c/ol0003oVIVIo`000?moOgoo0000ofIVIP02o`0000Sooooo000Cooooo`03o`000?oooooooooo
00;ooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?nIVIWoVIVI00coVIVI00?o0000
ok>c/onc/k<05_nc/k<00ol0003oVIVIoiVIV@0<oiVIV@03o`000?moOgooOgmo00SoOgmo00?o0000
ofIVI_mVIVH03?mVIVH00ol0003oC4a<oda<C00Goda<C003o`000?mVIVKoIVIV00WoIVIV00?o0000
ogmoOomoOgl01OmoOgl00ol0003oVIVIoiVIV@04oiVIV@03o`000?nc/k?o/k>c01?o/k>c00?o0000
oiVIVOnIVIT00_nIVIT01Ol0003oOgmoogmoOomoOgoo000000CoIVIV00?o0000oda<C?m<C4`00om<
C4`00ol0003o<c<coc<c<`04oc<c<`03o`000?m<C4coC4a<00?oC4a<00Go0000ofIVI_mVIVKoIVIV
o`000002ogmoO`04o`000?nIVIWoVIVIo`0000Co/k>c00?o0000olc<c?o<c<`01_o<c<`01Ol0003o
/k>cok>c/onc/k?o000000;oVIVI00Co0000ogmoOomoOgoo00000_mVIVH01Ol0003oC4a<oda<C?m<
C4co000000So<c<c00Oo0000oda<C?m<C4coC4a<o`000?mVIVKo000000;oOgmo00?o0000oiVIVOl0
00000onc/k<00ol0003oc<c<olc<c006olc<c006o`000?nc/k?o/k>co`000?nIVIWo00000_moOgl0
0ol0003oIVIVo`000002oda<C003o`000?lc<c?o<c<c00Ko<c<c00[o0000oda<C?m<C4co0000ofIV
I_l0003oOgmoo`000?nIVIWo00000_nc/k<00ol0003oc<c<olc<c006olc<c009o`000?nc/k?o/k>c
o`000?nIVIWo0000ogmoOol0003oIVIV00;o00002?ooool001?ooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo00000?ooooooC?ooool001?ooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo00000?ooooooC?ooool001?ooooo00?o0000ooooooooool00_oo
ool01Ol@413ooooooooooooooooo410@0?ooooooC?ooool001?ooooo00?o0000ooooooooool00_oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg0?ooooooC?ooool0017ooooo00?oEEEEofIVI_l000001?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^0?ooooooC?ooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-6.70727, -6.61583, 0.0594144, \
0.0594144}}]
}, Open  ]],

Cell[TextData[{
  "The rays  are curves ",
  Cell[BoxData[
      \(TraditionalForm\`y(x)\)]],
  " that are normal to each surface of constant phase. These surfaces are \
nearly identical to the contours of constant wave height shown in Cell ",
  ButtonBox["5.26",
    ButtonData:>"Cell 5.26",
    ButtonStyle->"Hyperlink"],
  ", since the wave amplitude , ",
  Cell[BoxData[
      \(TraditionalForm\`\@\(\(k\_x\)(x)\)\)]],
  ", is slowly varying compared to ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " [see Eq. ",
  ButtonBox["(5.2.35)",
    ButtonData:>"(5.2.35)",
    ButtonStyle->"Hyperlink"],
  "] .\n\t  The bending of the rays can also be understood by  dividing ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]y/\[DifferentialD]t\)]],
  " by ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]x/\[DifferentialD]t\)]],
  " in Eq. ",
  ButtonBox["(5.2.39)",
    ButtonData:>"(5.2.39)",
    ButtonStyle->"Hyperlink"],
  ":"
}], "Text",
  CellTags->"i:108"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\[DifferentialD]y/\[DifferentialD]t\)\/\(\
\[DifferentialD]x/\[DifferentialD]t\) = \
\(\[DifferentialD]y\/\[DifferentialD]x = 
          k\_y\/\(\(k\_x\)(x, \[Omega], k\_y)\)\)\)]],
  "."
}], "NE2",
  CellTags->"(5.2.40)"],

Cell[TextData[{
  "This equation has a simple physical interpretation. If we define  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta](x)\)]],
  " as the angle the rays make with the horizontal (see Fig. ",
  ButtonBox["5.7",
    ButtonData:>"Fig. 5.7",
    ButtonStyle->"Hyperlink"],
  ") , Eq. ",
  ButtonBox["(5.2.40)",
    ButtonData:>"(5.2.40)",
    ButtonStyle->"Hyperlink"],
  " implies that ",
  Cell[BoxData[
      \(TraditionalForm\`tan\[Theta](x) = k\_y/k\_x\)]],
  ", or equivalently, ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          
          FormBox[\(sin\ \(\[Theta](x)\) = \(k\_y/\(k(x)\) = 
                k\_y\ \(c(x)\)/\[Omega]\)\),
            "TraditionalForm"]}], TraditionalForm]]],
  ", where in the second step we have used Eq. ",
  ButtonBox["(5.2.34)",
    ButtonData:>"(5.2.34)",
    ButtonStyle->"Hyperlink"],
  ". Dividing through by ",
  Cell[BoxData[
      \(TraditionalForm\`c(x)\)]],
  " yields"
}], "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\(sin\ \(\[Theta](x)\)\)\/\(c(x)\) = \
\(k\_y\/\[Omega]\  = constant\)\)]],
  ". "
}], "NE2",
  CellTags->{"i:78", "(5.2.41)"}],

Cell[TextData[{
  "Equation ",
  ButtonBox["(5.2.41)",
    ButtonData:>"(5.2.41)",
    ButtonStyle->"Hyperlink"],
  " is the famous Snell's law for the propagation of waves through an \
inhomogeneous medium. As the phase speed ",
  Cell[BoxData[
      \(TraditionalForm\`c(x)\)]],
  " decreases, Snell's law implies that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta](x)\)]],
  " also decreases. In other words, ",
  StyleBox["rays bend toward regions of lower phase speed",
    FontSlant->"Italic"],
  ". This same equation applies to the refraction of light rays as they \
propagate through an inhomogeneous medium. "
}], "Text"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000=P000332000`400?l00000o`00003oo`3ooooo
0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00
o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS
0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0oooo
o`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?oo
ool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo
003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?oo
of<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3o
oooo0?ooof<0oooo003o0?ooool0oooo9P3oool700000?l0oooo=P3oool00?l0ooooo`3ooolT0?oo
o``00000o`3ooolc0?ooo`00o`3ooooo0?ooob@0oooo3000003o0?oooc<0oooo003o0?ooool0oooo
903oool?00000?l0oooo<03oool00?l0ooooo`3ooolT0?oooa800000o`3oool]0?ooo`00o`3ooooo
0?ooob@0oooo4P00003o0?ooobd0oooo003o0?ooool0oooo8`3ooolI00000?l0oooo9`3oool00?l0
ooooo`3ooolS0?oooal00000o`3ooolQ0?ooo`00o`3ooooo0?ooob<0oooo7`00003o0?ooob40oooo
003o0?ooool0oooo8`3ooolS00000?l0oooo7@3oool00?l0ooooo`3ooolS0?ooobH00000o`3ooolJ
0?ooo`00o`3ooooo0?ooob<0oooo9P00003o0?oooaX0oooo003o0?ooool0oooo8`3oool[00000?l0
oooo5@3oool00?l0ooooo`3ooolQ0?oooc000000o`3ooolB0?ooo`00o`3ooooo0?ooob40oooo<000
003o0?oooa80oooo003o0?ooool0oooo8@3ooold00000?l0oooo3P3oool00?l0ooooo`3ooolQ0?oo
ocL00000o`3oool;0?ooo`00o`3ooooo0?ooob40oooo=`00003o0?ooo`/0oooo003o0?ooool0oooo
8@3ooolm00000?l0oooo1@3oool00?l0ooooo`3ooolQ0?oood400000o`3oool10?ooo`00o`3ooooo
0?ooob40oooo@@00003o0?ooo`40oooo000Y0?ooool00000o`00000l00000?d0oooo000Y0?ooool0
0000o`00000o00000?X0oooo000Y0?ooool00000o`00000o00000?X0oooo000Y0?ooool00000o`00
000l00000?d0oooo000Y0?ooool00000o`00000h00000?l0oooo0P3oool002T0oooo1@0000020?oo
o`H0oadMo`3ooooZ0?oooc/00000o`3oool70?ooo`00:@3oool500000080oooo1P3o7Ago0?ooonX0
oooo>`00003o0?ooo`L0oooo000Y0?ooo`D000002@3o7Ago0?ooonT0oooo>000003o0?ooo`X0oooo
000Y0?ooo`D000002@3o7Ago0?ooonT0oooo=000000L0?ooo`@000003`3oool400000=X0oooo000Y
0?ooo`D000002@3o7Ago0?ooonT0oooo=000000L0?ooo`@000003`3oool400000=X0oooo000Y0?oo
o`D000002`3o7Ago0?ooonL0oooo<000000M0?ooo`T00000303oool700000=P0oooo000Y0?ooo`D0
0000303o7Ago0?ooonH0oooo:`00000R0?ooo`X000002`3oool500000080oooo00<000000?ooo`3o
ool0e@3oool002T0oooo1@00000<0?lM7Ol0ooooiP3oool[00000280oooo2P00000;0?ooo`D00000
0P3oool00`000000oooo0?ooo`3E0?ooo`00:@3oool5000000h0oadMo`3ooooV0?ooobD00000:@3o
ool3000000@0oooo0P0000090?ooo`D000000`3oool200000=D0oooo000Y0?ooo`D000003`3o7Ago
0?ooonD0oooo8000000e0?ooo`<00000203oool4000000@0oooo0P00003E0?ooo`00:@3oool50000
00l0oadMo`3ooooU0?ooob000000=@3oool3000000P0oooo100000040?ooo`800000e@3oool002T0
oooo1@00000A0?lM7Ol0ooooh`3ooolL000003/0oooo00<000000?ooo`3oool0103oool6000000H0
oooo00<000000?ooo`3oool0dP3oool002T0oooo1@0000020?ooo`l0oadMo`3ooooS0?oooaL00000
@@3oool2000000@0oooo1P00003K0?ooo`00:@3oool500000080oooo3`3o7Ago0?ooon<0oooo5`00
00110?ooo`800000103oool600000=/0oooo000Y0?ooo`D000000`3oool?0?lM7Ol0ooooh`3ooolD
000004<0oooo0`0000030?ooo`H00000f`3oool002T0oooo1@0000030?oooa40oadMo`3ooooQ0?oo
o`l00000BP3oool010000000oooo0?ooo`3oool600000=/0oooo000Y0?ooo`D000000`3ooolA0?lM
7Ol0ooooh@3oool?000004X0oooo00@000000?ooo`3oool0oooo1P00003K0?ooo`00:@3oool50000
00D0oooo403o7Ago0?ooon00oooo2`00001?0?ooo`80000000<0oooo0000000000000P00003M0?oo
o`00:@3oool5000000H0oooo4@3o7Ago0?ooon00oooo1000001D0?ooo`L00000g@3oool002T0oooo
1@0000060?oooa40oadMo`3ooooP0?ooo`@00000E03oool700000=d0oooo000Y0?ooo`D00000203o
ool@0?lM7Ol0ooooo`3ooolj0?ooo`D00000g@3oool002T0oooo1@0000090?ooo`l0oadMo`3ooooo
0?ooocX0oooo1@00003M0?ooo`00:@3oool5000000T0oooo403o7Ago0?ooool0oooo>@3oool50000
0=d0oooo000Y0?ooo`D000002@3oool@0?lM7Ol0ooooo`3oooli0?ooo`D00000g@3oool002T0oooo
1@00000;0?oooa00oadMo`3ooooo0?ooocL0oooo1@00003M0?ooo`00:@3oool5000000`0oooo403o
7Ago0?ooool0oooo=03oool700000=d0oooo000Y0?ooo`D00000303oool@0?lM7Ol0ooooo`3ooold
0?ooo`L00000g@3oool002T0oooo1@00000>0?oooa00oadMo`3ooooo0?oooc80oooo2@00003K0?oo
o`00:@3oool5000000h0oooo403o7Ago0?ooool0oooo<P3oool6000000040?ooo`00000000000000
0=X0oooo000Y0?ooo`D000003P3oool@0?lM7Ol0ooooo`3ooolb0?ooo`H0000000@0oooo00000000
00000000fP3oool002T0oooo1@00000?0?oooa00oadMo`3ooooo0?oooc40oooo1P0000030?ooo`03
0000003oool0oooo0=P0oooo000Y0?ooo`D000004@3oool@0?lM7Ol0ooooo`3oool_0?ooo`H00000
0`3oool3000000<0oooo1000003A0?ooo`00:@3oool500000140oooo403o7Ago0?ooool0oooo;`3o
ool6000000<0oooo0`0000030?ooo`@00000d@3oool002T0oooo1@00000B0?oooa00oadMo`3ooooo
0?ooobd0oooo1P0000050?ooo`T00000d@3oool002T0oooo1@00000D0?oooa00oadMo`3ooooo0?oo
obD0oooo0`0000030?ooo`H000001`3oool700000=40oooo000Y0?ooo`D00000503oool@0?lM7Ol0
ooooo`3ooolU0?ooo`<000000`3oool6000000L0oooo1`00003A0?ooo`00:@3oool5000001@0oooo
4@3o7Ago0?ooool0oooo9`3oool7000000X0oooo1@00003B0?ooo`00:@3oool5000001D0oooo403o
7Ago0?ooool0ooooo`3oool@0?ooo`00:@3oool5000001D0oooo403o7Ago0?ooool0ooooo`3oool@
0?ooo`00:@3oool5000001L0oooo403o7Ago0?ooool0ooooo`3oool>0?ooo`00:@3oool5000001P0
oooo403o7Ago0?ooool0ooooo`3oool=0?ooo`00:@3oool5000001P0oooo403o7Ago0?ooool0oooo
o`3oool=0?ooo`00:@3oool5000001T0oooo4@3o7Ago0?ooool0ooooo`3oool;0?ooo`00:@3oool5
000001/0oooo403o7Ago0?ooool0ooooo`3oool:0?ooo`00:@3oool5000001/0oooo403o7Ago0?oo
ool0ooooo`3oool:0?ooo`00:@3oool5000001/0oooo403o7Ago0?ooool0ooooo`3oool:0?ooo`00
:@3oool5000001`0oooo4@3o7Ago0?ooool0ooooo`3oool80?ooo`00:@3oool5000001h0oooo403o
7Ago0?ooool0ooooo`3oool70?ooo`00:@3oool5000001h0oooo403o7Ago0?ooool0ooooo`3oool7
0?ooo`00:@3oool5000001l0oooo4@3o7Ago0?ooool0ooooo`3oool50?ooo`00:@3oool500000240
oooo403o7Ago0?ooool0ooooo`3oool40?ooo`00:@3oool500000240oooo403o7Ago0?ooool0oooo
o`3oool40?ooo`00:@3oool500000240oooo403o7Ago0?ooool0ooooo`3oool40?ooo`00:@3oool5
00000280oooo403o7Ago0?ooool0ooooo`3oool30?ooo`00:@3oool500000280oooo403o7Ago0?oo
ool0ooooo`3oool30?ooo`00:@3oool5000002@0oooo403o7Ago0?ooool0ooooo`3oool10?ooo`00
:@3oool5000002D0oooo403o7Ago0?ooool0ooooo`3oool002T0oooo1@00000U0?oooa00oadMo`3o
oooo0?ooool0oooo000Y0?ooo`D000009`3oool@0?lM7Ol0ooooo`3oooom0?ooo`00:@3oool50000
02L0oooo403o7Ago0?ooool0ooooo@3oool002T0oooo1@00000W0?oooa00oadMo`3ooooo0?ooood0
oooo000Y0?ooo`D00000:03oool@0?lM7Ol0ooooo`3ooool0?ooo`00:@3oool5000002X0oooo403o
7Ago0?ooool0oooonP3oool002T0oooo1@00000Z0?oooa00oadMo`3ooooo0?ooooX0oooo000Y0?oo
o`D00000:`3oool@0?lM7Ol0ooooo`3ooooi0?ooo`00:@3oool5000002d0oooo403o7Ago0?ooool0
oooom`3oool002T0oooo1@00000]0?oooa00oadMo`3ooooo0?ooooL0oooo000Y0?ooo`D00000;@3o
ool@0?lM7Ol0ooooo`3oooog0?ooo`00:@3oool5000002h0oooo403o7Ago0?ooool0oooomP3oool0
02T0oooo1@00000^0?oooa00oadMo`3ooooo0?ooooH0oooo000Y0?ooo`D00000<03oool@0?lM7Ol0
ooooo`3ooood0?ooo`00:@3oool500000340oooo403o7Ago0?ooool0ooool`3oool002T0oooo1@00
000b0?oooa40oadMo`3ooooo0?oooo40oooo000Y0?ooo`D00000<P3ooolA0?lM7Ol0ooooo`3ooooa
0?ooo`00:@3oool500000380oooo4@3o7Ago0?ooool0ooool@3oool002T0oooo1@00000d0?oooa00
oadMo`3ooooo0?oooo00oooo000Y0?ooo`D00000=03oool@0?lM7Ol0ooooo`3oooo`0?ooo`00:@3o
ool5000003D0oooo4@3o7Ago0?ooool0ooookP3oool002T0oooo1@00000g0?oooa00oadMo`3ooooo
0?ooond0oooo000Y0?ooo`D00000=`3oool@0?lM7Ol0ooooo`3oooo]0?ooo`00:@3oool5000003P0
oooo4@3o7Ago0?ooool0ooooj`3oool002T0oooo1@00000h0?oooa40oadMo`3ooooo0?ooon/0oooo
000Y0?ooo`D00000>03ooolA0?lM7Ol0ooooo`3oooo[0?ooo`00:@3oool5000003X0oooo403o7Ago
0?ooool0oooojP3oool002T0oooo1@00000k0?oooa00oadMo`3ooooo0?ooonT0oooo000Y0?ooo`D0
0000>`3oool@0?lM7Ol0ooooo`3ooooY0?ooo`00:@3oool5000003d0oooo403o7Ago0?ooool0oooo
i`3oool002T0oooo1@00000n0?ooo`l0oadMo`3ooooo0?ooonL0oooo000Y0?ooo`D00000?P3oool?
0?lM7Ol0ooooo`3ooooW0?ooo`00:@3oool5000003h0oooo403o7Ago0?ooool0ooooiP3oool002T0
oooo1@0000100?oooa00oadMo`3ooooo0?ooon@0oooo000Y0?ooo`D00000@03oool@0?lM7Ol0oooo
o`3ooooT0?ooo`00:@3oool500000440oooo403o7Ago0?ooool0ooooh`3oool002T0oooo1@000013
0?oooa00oadMo`3ooooo0?ooon40oooo000Y0?ooo`D00000@`3oool@0?lM7Ol0ooooo`3ooooQ0?oo
o`00:@3oool5000004<0oooo403o7Ago0?ooool0ooooh@3oool002T0oooo1@0000140?oooa00oadM
o`3ooooo0?ooon00oooo000Y0?ooo`D00000AP3oool@0?lM7Ol0ooooo`3ooooN0?ooo`00:@3oool5
000004H0oooo403o7Ago0?ooool0oooogP3oool002T0oooo1@0000170?oooa00oadMo`3ooooo0?oo
omd0oooo000Y0?ooo`D00000B@3oool>0?lM7Ol0ooooo`3ooooM0?ooo`00:@3oool5000004T0oooo
3P3o7Ago0?ooool0oooog@3oool002T0oooo1@0000190?oooa00oadMo`3ooooo0?ooom/0oooo000Y
0?ooo`D00000BP3oool@0?lM7Ol0ooooo`3ooooJ0?ooo`00:@3oool5000004X0oooo403o7Ago0?oo
ool0oooofP3oool002T0oooo1@00001;0?oooa40oadMo`3ooooo0?ooomP0oooo000Y0?ooo`D00000
C@3oool?0?lM7Ol0ooooo`3ooooH0?ooo`00:@3oool5000004d0oooo3`3o7Ago0?ooool0oooof03o
ool002T0oooo1@00001=0?oooa00oadMo`3ooooo0?ooomL0oooo000Y0?ooo`D00000CP3ooolA0?lM
7Ol0ooooo`3ooooE0?ooo`00:@3oool5000004h0oooo4@3o7Ago0?ooool0ooooe@3oool002T0oooo
1@00001@0?oooa00oadMo`3ooooo0?ooom@0oooo000Y0?ooo`D00000D@3ooolA0?lM7Ol0ooooo`3o
oooB0?ooo`00:@3oool500000540oooo4@3o7Ago0?ooool0oooodP3oool002T0oooo1@00001A0?oo
oa40oadMo`3ooooo0?ooom80oooo000Y0?ooo`D00000D`3oool@0?lM7Ol0ooooo`3ooooA0?ooo`00
:@3oool5000005<0oooo403o7Ago0?ooool0ooood@3oool002T0oooo1@00001D0?oooa00oadMo`3o
oooo0?ooom00oooo000Y0?ooo`D00000EP3oool@0?lM7Ol0ooooo`3oooo>0?ooo`00:@3oool50000
05L0oooo3`3o7Ago0?ooool0oooocP3oool002T0oooo1@00001G0?ooo`l0oadMo`3ooooo0?ooolh0
oooo000Y0?ooo`D00000E`3oool@0?lM7Ol0ooooo`3oooo=0?ooo`00:@3oool5000005T0oooo403o
7Ago0?ooool0oooob`3oool002T0oooo1@00001I0?oooa00oadMo`3ooooo0?oool/0oooo000Y0?oo
o`D00000FP3oool@0?lM7Ol0ooooo`3oooo:0?ooo`00:@3oool5000005`0oooo3P3o7Ago0?ooool0
oooobP3oool002T0oooo1@00001L0?ooo`h0oadMo`3ooooo0?ooolX0oooo000Y0?ooo`D00000G03o
ool@0?lM7Ol0ooooo`3oooo80?ooo`00:@3oool5000005d0oooo403o7Ago0?ooool0ooooa`3oool0
02T0oooo1@00001M0?oooa00oadMo`3ooooo0?ooolL0oooo000Y0?ooo`D00000G`3oool@0?lM7Ol0
ooooo`3oooo50?ooo`00:@3oool500000600oooo403o7Ago0?ooool0ooooa03oool002T0oooo1@00
001P0?oooa00oadMo`3ooooo0?oool@0oooo000Y0?ooo`D00000H03oool@0?lM7Ol0ooooo`3oooo4
0?ooo`00:@3oool500000680oooo403o7Ago0?ooool0oooo`P3oool002T0oooo1@00001R0?oooa00
oadMo`3ooooo0?oool80oooo000Y0?ooo`D00000H`3oool@0?lM7Ol0ooooo`3oooo10?ooo`00:@3o
ool5000006@0oooo4@3o7Ago0?ooool0oooo_`3oool002T0oooo1@00001T0?oooa40oadMo`3ooooo
0?oookl0oooo000Y0?ooo`D00000IP3oool?0?lM7Ol0ooooo`3ooono0?ooo`00:@3oool5000006L0
oooo3`3o7Ago0?ooool0oooo_P3oool002T0oooo1@00001W0?ooo`l0oadMo`3ooooo0?oookh0oooo
000Y0?ooo`D00000I`3ooolA0?lM7Ol0ooooo`3ooonl0?ooo`00:@3oool5000006T0oooo403o7Ago
0?ooool0oooo^`3oool002T0oooo1@00001Z0?ooo`l0oadMo`3ooooo0?oook/0oooo000Y0?ooo`D0
0000JP3oool?0?lM7Ol0ooooo`3ooonk0?ooo`00:@3oool5000006`0oooo3`3o7Ago0?ooool0oooo
^@3oool002T0oooo1@00001]0?ooo`l0oadMo`3ooooo0?oookP0oooo000Y0?ooo`D00000K@3oool?
0?lM7Ol0ooooo`3ooonh0?ooo`00:@3oool5000006l0oooo3P3o7Ago0?ooool0oooo]`3oool002T0
oooo1@00001_0?oooa00oadMo`3ooooo0?oookD0oooo000Y0?ooo`D00000K`3oool@0?lM7Ol0oooo
o`3ooone0?ooo`00:@3oool500000700oooo403o7Ago0?ooool0oooo]03oool002T0oooo1@00001b
0?oooa00oadMo`3ooooo0?oook80oooo000Y0?ooo`D00000LP3oool@0?lM7Ol0ooooo`3ooonb0?oo
o`00:@3oool5000007<0oooo3`3o7Ago0?ooool0oooo/P3oool002T0oooo1@00001e0?ooo`h0oadM
o`3ooooo0?oook40oooo000Y0?ooo`D00000M@3oool>0?lM7Ol0ooooo`3ooona0?ooo`00:@3oool5
000007D0oooo403o7Ago0?ooool0oooo[`3oool002T0oooo1@00001f0?oooa00oadMo`3ooooo0?oo
ojh0oooo000Y0?ooo`D00000MP3oool@0?lM7Ol0ooooo`3ooon^0?ooo`00:@3oool5000007P0oooo
403o7Ago0?ooool0oooo[03oool002T0oooo1@00001i0?oooa00oadMo`3ooooo0?oooj/0oooo000Y
0?ooo`D00000N@3oool@0?lM7Ol0ooooo`3ooon[0?ooo`00:@3oool5000007T0oooo4P3o7Ago0?oo
ool0ooooZ@3oool002T0oooo1@00001k0?oooa40oadMo`3ooooo0?ooojP0oooo000Y0?ooo`D00000
O03oool@0?lM7Ol0ooooo`3ooonX0?ooo`00:@3oool5000007`0oooo403o7Ago0?ooool0ooooZ03o
ool002T0oooo1@00001m0?oooa40oadMo`3ooooo0?ooojH0oooo000Y0?ooo`D00000O@3ooolB0?lM
7Ol0ooooo`3ooonU0?ooo`00:@3oool5000007d0oooo4P3o7Ago0?ooool0ooooY@3oool002T0oooo
1@00001o0?oooa80oadMo`3ooooo0?oooj<0oooo000Y0?ooo`D00000P03ooolA0?lM7Ol0ooooo`3o
oonS0?ooo`00:@3oool500000800oooo4@3o7Ago0?ooool0ooooX`3oool002T0oooo1@0000220?oo
oa00oadMo`3ooooo0?oooj80oooo000Y0?ooo`D00000P`3ooolA0?lM7Ol0ooooo`3ooonP0?ooo`00
:@3oool5000008<0oooo4@3o7Ago0?ooool0ooooX03oool002T0oooo1@0000250?oooa00oadMo`3o
oooo0?oooil0oooo000Y0?ooo`D00000QP3oool?0?lM7Ol0ooooo`3ooonO0?ooo`00:@3oool50000
08H0oooo3`3o7Ago0?ooool0ooooW`3oool002T0oooo1@0000260?oooa00oadMo`3ooooo0?oooih0
oooo000Y0?ooo`D00000R03oool@0?lM7Ol0ooooo`3ooonL0?ooo`00:@3oool5000008P0oooo403o
7Ago0?ooool0ooooW03oool002T0oooo1@0000290?oooa00oadMo`3ooooo0?oooi/0oooo000Y0?oo
o`D00000R`3oool@0?lM7Ol0ooooo`3ooonI0?ooo`00:@3oool5000008/0oooo403o7Ago0?ooool0
ooooV@3oool002T0oooo1@00002<0?ooo`l0oadMo`3ooooo0?oooiT0oooo000Y0?ooo`D00000SP3o
ool>0?lM7Ol0ooooo`3ooonH0?ooo`00:@3oool5000008h0oooo3P3o7Ago0?ooool0ooooV03oool0
02T0oooo1@00002?0?ooo`l0oadMo`3ooooo0?oooiH0oooo000Y0?ooo`D00000T@3oool>0?lM7Ol0
ooooo`3ooonE0?ooo`00:@3oool500000940oooo403o7Ago0?ooool0ooooT`3oool002T0oooo1@00
002A0?oooa00oadMo`3ooooo0?oooi<0oooo000Y0?ooo`D00000TP3oool@0?lM7Ol0ooooo`3ooonB
0?ooo`00:@3oool5000009@0oooo3P3o7Ago0?ooool0ooooTP3oool002T0oooo1@00002D0?ooo`h0
oadMo`3ooooo0?oooi80oooo000Y0?ooo`D00000U@3oool?0?lM7Ol0ooooo`3ooon@0?ooo`00:@3o
ool5000009D0oooo403o7Ago0?ooool0ooooS`3oool002T0oooo1@00002E0?oooa00oadMo`3ooooo
0?ooohl0oooo000Y0?ooo`D00000UP3ooolA0?lM7Ol0ooooo`3ooon=0?ooo`00:@3oool5000009P0
oooo403o7Ago0?ooool0ooooS03oool002T0oooo1@00002H0?oooa00oadMo`3ooooo0?oooh`0oooo
000Y0?ooo`D00000V@3ooolA0?lM7@<0oooo4`00000O0?oooa4000007`3ooolB000001l0oooo4`00
000O0?oooa400000o`3ooon`0?ooo`00:@3oool5000009T0oooo4@3o7Ad30?oooa<000007`3ooolA
000001l0oooo4P00000O0?oooa<000007`3ooolA00000?l0oooo/03oool002T0oooo1@00002I0?oo
oa40oadM0`3ooolC000001l0oooo4@00000O0?oooa8000007`3ooolC000001l0oooo4@00003o0?oo
ok00oooo000Y0?ooo`D00000V`3oool@0?lM7@80oooo4`00000O0?oooa4000007`3ooolB000001l0
oooo4`00000O0?oooa400000o`3ooon`0?ooo`00:@3oool5000009`0oooo4@3o7AdC000001l0oooo
4@00000O0?oooa8000007`3ooolC000001l0oooo4@00003o0?oook00oooo000Y0?ooo`D00000W03o
oolA0?lM7A<000007`3ooolA000001l0oooo4P00000O0?oooa<000007`3ooolA00000?l0oooo/03o
ool002T0oooo1@00002N0?oooa00oadMo`3ooooo0?ooohH0oooo000Y0?ooo`D00000W`3oool@0?lM
7Ol0ooooo`3ooon50?ooo`00:@3oool5000009l0oooo403o7Ago0?ooool0ooooQ@3oool002T0oooo
1@00002Q0?oooa00oadMo`3ooooo0?oooh<0oooo000Y0?ooo`D00000X@3oool@0?lM7Ol0ooooo`3o
oon30?ooo`00:@3oool500000:80oooo403o7Ago0?ooool0ooooPP3oool002T0oooo1@00002R0?oo
oa00oadMo`3ooooo0?oooh80oooo000Y0?ooo`D00000Y03oool@0?lM7Ol0ooooo`3ooon00?ooo`00
:@3oool500000:D0oooo403o7AeI0?ooo`D00000o`3ooooo0?ooob40oooo000Y0?ooo`D00000Y@3o
ool@0?lM7ET0oooo1@00003o0?ooool0oooo8@3oool002T0oooo1@00002W0?oooa00oadME`3oool5
00000?l0ooooo`3ooolQ0?ooo`00:@3oool500000:P0oooo403o7AeF0?ooo`D00000o`3ooooo0?oo
ob40oooo000Y0?ooo`D00000Z03oool@0?lM7EH0oooo1@00003o0?ooool0oooo8@3oool002T0oooo
1@00002X0?oooa80oadMDP3oool700000?l0ooooo`3ooolQ0?ooo`00:@3oool500000:X0oooo403o
7AeB0?ooo`H00000o`3ooooo0?ooob80oooo000Y0?ooo`D00000ZP3oool@0?lM7E80oooo1P00003o
0?ooool0oooo8P3oool002T0oooo1@00002[0?oooa00oadMD@3oool600000?l0ooooo`3ooolR0?oo
o`00:@3oool500000:d0oooo403o7Ae?0?ooo`H00000o`3ooooo0?ooob80oooo000Y0?ooo`D00000
[@3oool@0?lM7Dl0oooo1P00003o0?ooool0oooo8P3oool002T0oooo1@00002^0?oooa00oadMCP3o
ool600000?l0ooooo`3ooolR0?ooo`00:@3oool500000:l0oooo4@3o7Ae<0?ooo`H00000o`3ooooo
0?ooob80oooo000Y0?ooo`D00000[`3ooolA0?lM7D`0oooo1P00003o0?ooool0oooo8P3oool002T0
oooo1@00002a0?oooa00oadMB`3oool600000?l0ooooo`3ooolR0?ooo`00:@3oool500000;80oooo
3`3o7Ae:0?ooo`L00000o`3ooooo0?ooob80oooo000Y0?ooo`D00000/P3oool?0?lM7DX0oooo1`00
003o0?ooool0oooo8P3oool002T0oooo1@00002d0?ooo`l0oadMB03oool600000?l0ooooo`3ooolS
0?ooo`00:@3oool500000;@0oooo403o7Ae70?ooo`H00000=P3oool00`000000oooo0?ooo`0]0?oo
o`800000o`3ooonj0?ooo`00:@3oool500000;@0oooo403o7Ae70?ooo`H00000=P3oool00`000000
oooo0?ooo`0]0?ooo`800000o`3ooonj0?ooo`00:@3oool500000;D0oooo4@3o7Ae50?ooo`H00000
=03oool300000340oooo00<000000?ooo`3oool0o`3ooong0?ooo`00:@3oool500000;L0oooo403o
7Ae40?ooo`H00000=03oool2000003<0oooo0P00003o0?oookL0oooo000Y0?ooo`D00000^03oool@
0?lM7D40oooo2000000c0?ooo`<00000<`3oool500000?l0oooo]03oool002T0oooo1@00002h0?oo
oa00oadM@@3oool8000003<0oooo0`00000c0?ooo`D00000o`3ooond0?ooo`00:@3oool500000;X0
oooo403o7Ado0?ooo`P00000<`3oool3000003D0oooo0`00003o0?oook@0oooo000Y0?ooo`D00000
^`3oool?0?lM7Cl0oooo1P00000d0?ooo`@00000=P3oool300000?l0oooo/`3oool002T0oooo1@00
002k0?ooo`l0oadM?`3oool6000003@0oooo1000000f0?ooo`<00000o`3ooonc0?ooo`00:@3oool5
00000;d0oooo3P3o7Adn0?ooo`H00000=03oool2000003P0oooo1@00003o0?oook40oooo000Y0?oo
o`D00000_P3oool?0?lM7C/0oooo1`00000d0?ooo`800000>P3oool400000?l0oooo/03oool002T0
oooo1@00002n0?ooo`l0oadM>`3oool7000003@0oooo0P00000j0?ooo`@00000o`3ooon`0?ooo`00
:@3oool500000<00oooo3P3o7Adj0?ooo`L00000<P3oool4000003/0oooo1@00003o0?ooojh0oooo
000Y0?ooo`D00000`@3oool?0?lM7CP0oooo1P00000F0?ooo`X000004`3oool400000140oooo1000
000?0?ooo`@000004`3oool600000?l0oooo[@3oool002T0oooo1@0000310?ooo`l0oadM>03oool6
000001H0oooo2P00000C0?ooo`@000004@3oool4000000l0oooo1000000C0?ooo`H00000o`3ooon]
0?ooo`00:@3oool500000<40oooo403o7Adg0?ooo`H00000503oool5000000D0oooo1@00000@0?oo
o`@000003P3oool9000000/0oooo2000000A0?ooo`H00000o`3ooon]0?ooo`00:@3oool500000<<0
oooo403o7Adc0?ooo`P000004`3oool4000000T0oooo1000000?0?ooo`@000003P3oool:000000X0
oooo1P0000020?ooo`030000003oool0oooo0100oooo1P00003o0?oooj/0oooo000Y0?ooo`D00000
``3oool@0?lM7C<0oooo2000000C0?ooo`@000002@3oool4000000l0oooo1000000>0?ooo`X00000
2P3oool600000080oooo00<000000?ooo`3oool0403oool600000?l0ooooZ`3oool002T0oooo1@00
00340?ooo`l0oadM<`3oool800000140oooo1@00000;0?ooo`D00000303oool500000140oooo0`00
00040?ooo`030000003oool0oooo00L0oooo1P0000030?ooo`800000403oool600000?l0ooooZ`3o
ool002T0oooo1@0000360?ooo`h0oadM<P3oool600000180oooo1P00000=0?ooo`@000002`3oool5
000001P0oooo0`0000070?ooo`D00000103oool200000100oooo1`00003o0?ooojX0oooo000Y0?oo
o`D00000aP3oool>0?lM7C80oooo1P00000B0?ooo`H000003@3oool4000000/0oooo1@00000H0?oo
o`<000001`3oool5000000@0oooo0P00000@0?ooo`L00000o`3ooonZ0?ooo`00:@3oool500000<L0
oooo3`3o7Ad_0?ooo`L000004P3oool6000000d0oooo1P0000090?ooo`D000006@3oool2000000H0
oooo1P0000060?ooo`030000003oool0oooo00h0oooo1P00003o0?ooojX0oooo000Y0?ooo`D00000
b03oool?0?lM7B`0oooo2000000C0?ooo`H000003P3oool6000000P0oooo1@00000K0?ooo`030000
003oool0oooo00<0oooo1P00000G0?ooo`P00000o`3ooonX0?ooo`00:@3oool500000<P0oooo3`3o
7Ad/0?ooo`P000004`3oool6000000h0oooo1P0000080?ooo`D000006`3oool00`000000oooo0?oo
o`030?ooo`H000005`3oool800000?l0ooooZ03oool002T0oooo1@00003:0?ooo`l0oadM:P3oool6
000001D0oooo1P00000>0?ooo`H00000203oool5000001/0oooo0`0000030?ooo`H000005`3oool8
00000?l0ooooZ03oool002T0oooo1@00003:0?oooa00oadM:03oool6000001H0oooo1P00000>0?oo
o`P000001P3oool5000001`0oooo0P0000030?ooo`H000006@3oool600000?l0ooooZ03oool002T0
oooo1@00003:0?oooa00oadM:03oool6000001H0oooo1P00000>0?ooo`P000001P3oool5000001`0
oooo0P0000030?ooo`H000006@3oool600000?l0ooooZ03oool002T0oooo1@00003;0?oooa40oadM
9P3oool6000001H0oooo1P00000@0?ooo`H000001P3oool5000001h0oooo00<000000?ooo`3oool0
1000000K0?ooo`H00000o`3ooonX0?ooo`00:@3oool500000<d0oooo403o7AdS0?ooo`H00000603o
ool600000100oooo1P0000060?ooo`D000007P3oool7000001/0oooo1`00003o0?ooojL0oooo000Y
0?ooo`D00000cP3ooolA0?lM7B40oooo1P00000H0?ooo`H00000403oool7000000D0oooo1`00000M
0?ooo`H000006`3oool700000?l0ooooY`3oool002T0oooo1@00003>0?oooa40oadM8@3oool60000
01P0oooo1P00000@0?ooo`L000001@3oool7000001d0oooo1P00000K0?ooo`L00000o`3ooonW0?oo
o`00:@3oool500000=00oooo403o7AdO0?ooo`H000006@3oool7000000l0oooo1`0000050?ooo`L0
00007@3oool6000001/0oooo1`00003o0?ooojL0oooo000Y0?ooo`D00000d@3oool@0?lM7Ah0oooo
1P00000I0?ooo`L00000403oool8000000<0oooo1`00000M0?ooo`H00000703oool600000?l0oooo
Y`3oool002T0oooo1@00003A0?oooa00oadM7P3oool6000001T0oooo1`00000@0?ooo`P000000`3o
ool7000001d0oooo1P00000L0?ooo`H00000o`3ooonW0?ooo`00:@3oool500000=<0oooo3P3o7AdK
0?ooo`L000006`3oool700000100oooo200000040?ooo`H000007@3oool6000001`0oooo1P00003o
0?ooojL0oooo000Y0?ooo`D00000e03oool?0?lM7AL0oooo2@00000K0?ooo`L00000403oool80000
00@0oooo1P00000L0?ooo`L00000703oool600000?l0ooooY`3oool002T0oooo1@00003D0?ooo`l0
oadM5`3oool9000001/0oooo1`00000@0?ooo`P00000103oool6000001`0oooo1`00000L0?ooo`H0
0000o`3ooonW0?ooo`00:@3oool500000=H0oooo3P3o7AdE0?ooo`T00000703oool700000100oooo
200000040?ooo`L000006`3oool9000001X0oooo1P00003o0?ooojL0oooo000Y0?ooo`D00000e`3o
ool?0?lM7A80oooo2000000O0?oooal000000`3oool7000001/0oooo1P000000103oool000000000
0000000I0?ooo`H00000o`3ooonW0?ooo`00:@3oool500000=L0oooo3`3o7AdB0?ooo`P000007`3o
oolO000000<0oooo1`00000K0?ooo`H0000000@0oooo00000000000000006@3oool600000?l0oooo
Y`3oool002T0oooo1@00003I0?ooo`h0oadM3`3oool900000200oooo7`0000050?ooo`D000006`3o
ool6000000<0oooo00<000000?ooo`3oool05`3oool600000?l0ooooY`3oool002T0oooo1@00003I
0?oooa00oadM303oool800000280oooo2000000@0?ooo`L000001@3oool7000001T0oooo1P000003
0?ooo`<000000`3oool400000100oooo1P00003o0?ooojL0oooo000Y0?ooo`D00000f@3oool@0?lM
7@`0oooo2000000R0?ooo`P00000403oool7000000D0oooo1`00000I0?ooo`H000000`3oool30000
00<0oooo1000000@0?ooo`H00000o`3ooonW0?ooo`00:@3oool500000=X0oooo403o7Ad90?ooo`T0
00008`3oool800000100oooo1`0000060?ooo`H000005`3oool6000000H0oooo2@00000@0?ooo`H0
0000o`3ooonW0?ooo`00:@3oool500000=`0oooo403o7Ad60?ooo`P000009`3oool600000100oooo
1`0000060?ooo`H000004P3oool2000000<0oooo1P0000080?ooo`L00000403oool500000?l0oooo
Z03oool002T0oooo1@00003L0?oooa00oadM1P3oool8000002L0oooo1P00000@0?ooo`L000001P3o
ool600000180oooo0P0000030?ooo`H00000203oool700000100oooo1@00003o0?ooojP0oooo000Y
0?ooo`D00000g@3oool@0?lM7@<0oooo2@00000X0?ooo`L00000403oool6000000L0oooo1P00000C
0?ooo`P000002P3oool500000140oooo1@00003o0?ooojP0oooo000Y0?ooo`D00000g`3oool@0?lM
7@<0oooo1P00000Y0?ooo`L00000403oool6000000T0oooo1000000k0?ooo`D00000o`3ooonX0?oo
o`00:@3oool500000=l0oooo403o7Ad30?ooo`H00000:@3oool700000100oooo1P0000090?ooo`@0
0000>`3oool500000?l0ooooZ03oool002T0oooo1@00003P0?oooa00oadM0`3oool3000002`0oooo
1P00000@0?ooo`H000002@3oool4000003/0oooo1@00003o0?ooojP0oooo000Y0?ooo`D00000h@3o
oolA0?lM7C00oooo1P00000@0?ooo`H000002P3oool5000003T0oooo0`00003o0?ooojX0oooo000Y
0?ooo`D00000h`3oool@0?lM7C40oooo1P00000>0?ooo`H00000303oool4000003P0oooo0`00003o
0?ooojX0oooo000Y0?ooo`D00000h`3oool@0?lM7C40oooo1P00000>0?ooo`H00000303oool40000
03P0oooo0`00003o0?ooojX0oooo000Y0?ooo`D00000i03ooolA0?lM7Bl0oooo1P00000>0?ooo`H0
00003@3oool3000003L0oooo1000003o0?ooojX0oooo000Y0?ooo`D00000iP3oool@0?lM7Bl0oooo
1P00000=0?ooo`H000003`3oool3000003D0oooo0`00003o0?oooj/0oooo000Y0?ooo`D00000iP3o
ool@0?lM7Bl0oooo1P00000=0?ooo`H000003`3oool3000003D0oooo0`00003o0?oooj/0oooo000Y
0?ooo`D00000i`3ooolA0?lM7Bl0oooo1000000=0?ooo`D000004@3oool3000003@0oooo0`00003o
0?oooj/0oooo000Y0?ooo`D00000j@3oool?0?lM7C00oooo1000000<0?ooo`D000004`3oool00`00
0000oooo0?ooo`0b0?ooo`030000003oool0oooo0?l0ooooZ`3oool002T0oooo1@00003Y0?ooo`l0
oadM<03oool4000000`0oooo1@00000C0?ooo`030000003oool0oooo0380oooo00<000000?ooo`3o
ool0o`3ooon[0?ooo`00:@3oool500000>T0oooo403o7Ada0?ooo`@000002@3oool4000001H0oooo
0P00000`0?ooo`<00000o`3ooon]0?ooo`00:@3oool500000>X0oooo403o7Ada0?ooo`@000001P3o
ool5000001T0oooo00<000000?ooo`3oool0;@3oool200000?l0oooo[P3oool002T0oooo1@00003Z
0?oooa00oadM<@3oool4000000H0oooo1@00000I0?ooo`030000003oool0oooo02d0oooo0P00003o
0?ooojh0oooo000Y0?ooo`D00000k03oool@0?lM7C80oooo2@00003o0?oooo`0oooo000Y0?ooo`D0
0000k@3oool@0?lM7Ol0ooooo`3ooolg0?ooo`00:@3oool500000>d0oooo403o7Ago0?ooool0oooo
=`3oool002T0oooo1@00003_0?oooa00oadMo`3ooooo0?ooocD0oooo000Y0?ooo`D00000l03oool@
0?lM7Ol0ooooo`3ooold0?ooo`00:@3oool500000?00oooo403o7Ago0?ooool0oooo=03oool002T0
oooo1@00003b0?oooa00oadMo`3ooooo0?oooc80oooo000Y0?ooo`D00000l`3oool@0?lM7Ol0oooo
o`3ooola0?ooo`00:@3oool500000?<0oooo403o7Ago0?ooool0oooo<@3oool002T0oooo1@00003c
0?oooa80oadMo`3ooooo0?ooobl0oooo000Y0?ooo`D00000m@3ooolA0?lM7Ol0ooooo`3oool^0?oo
o`00:@3oool500000?D0oooo4@3o7Ago0?ooool0oooo;P3oool002T0oooo1@00003f0?oooa80oadM
o`3ooooo0?ooob`0oooo000Y0?ooo`D00000n03ooolA0?lM7Ol0ooooo`3oool[0?ooo`00:@3oool5
00000?T0oooo4P3o7Ago0?ooool0oooo:@3oool002T0oooo1@00003i0?oooa80oadMo`3ooooo0?oo
obT0oooo000Y0?ooo`D00000nP3ooolB0?lM7Ol0ooooo`3ooolX0?ooo`00:@3oool500000?`0oooo
4P3o7Ago0?ooool0oooo9P3oool002T0oooo1@00003l0?oooa80oadMo`3ooooo0?ooobH0oooo000Y
0?ooo`D00000o@3ooolB0?lM7Ol0ooooo`3ooolU0?ooo`00:@3oool500000?l0oooo403o7Ago0?oo
ool0oooo9@3oool002T0oooo1@00003o0?oooa00oadMo`3ooooo0?ooobD0oooo000Y0?ooo`D00000
o`3oool10?oooa40oadMo`3ooooo0?ooob<0oooo000Y0?ooo`D00000o`3oool30?oooa00oadMo`3o
oooo0?ooob80oooo000Y0?ooo`D00000o`3oool30?oooa00oadMo`3ooooo0?ooob80oooo000Y0?oo
o`D00000o`3oool40?oooa00oadMo`3ooooo0?ooob40oooo000Y0?ooo`D00000o`3oool60?oooa00
oadMo`3ooooo0?oooal0oooo000Y0?ooo`D00000o`3oool60?oooa00oadMo`3ooooo0?oooal0oooo
000Y0?ooo`D00000o`3oool70?oooa00oadMo`3ooooo0?oooah0oooo000Y0?ooo`D00000o`3oool7
0?oooa80oadMo`3ooooo0?oooa`0oooo000Y0?ooo`D00000o`3oool70?oooa80oadMo`3ooooo0?oo
oa`0oooo000Y0?ooo`D00000o`3oool90?oooa40oadMo`3ooooo0?oooa/0oooo000Y0?ooo`D00000
o`3oool:0?oooa80oadMo`3ooooo0?oooaT0oooo000Y0?ooo`D00000o`3oool:0?oooa80oadMo`3o
oooo0?oooaT0oooo000Y0?ooo`D00000o`3oool<0?oooa40oadMo`3ooooo0?oooaP0oooo000Y0?oo
o`D00000o`3oool=0?oooa80oadMo`3ooooo0?oooaH0oooo000Y0?ooo`D00000o`3oool=0?oooa80
oadMo`3ooooo0?oooaH0oooo000Y0?ooo`D00000o`3oool?0?oooa40oadMo`3ooooo0?oooaD0oooo
000Y0?ooo`D00000o`3oool@0?oooa80oadMo`3ooooo0?oooa<0oooo000Y0?ooo`D00000o`3ooolB
0?oooa40oadMo`3ooooo0?oooa80oooo000Y0?ooo`D00000o`3ooolB0?oooa40oadMo`3ooooo0?oo
oa80oooo000Y0?ooo`D00000o`3ooolC0?oooa80oadMo`3ooooo0?oooa00oooo000Y0?ooo`D00000
o`3ooolD0?oooa80oadMo`3ooooo0?ooo`l0oooo000Y0?ooo`D00000o`3ooolD0?oooa80oadMo`3o
oooo0?ooo`l0oooo000Y0?ooo`D00000o`3ooolF0?oooa80oadMo`3ooooo0?ooo`d0oooo000Y0?oo
o`D00000o`3ooolG0?oooa80oadMo`3ooooo0?ooo``0oooo000Y0?ooo`D00000o`3ooolG0?oooa80
oadMo`3ooooo0?ooo``0oooo000Y0?ooo`D00000o`3ooolI0?oooa80oadMo`3ooooo0?ooo`X0oooo
000Y0?ooo`D00000o`3ooolJ0?oooa80oadMo`3ooooo0?ooo`T0oooo000Y0?ooo`D00000o`3ooolJ
0?oooa80oadMo`3ooooo0?ooo`T0oooo000Y0?ooo`D00000o`3ooolL0?oooa40oadMo`3ooooo0?oo
o`P0oooo000Y0?ooo`D00000o`3ooolM0?oooa<0oadMo`3ooooo0?ooo`D0oooo000Y0?ooo`D00000
o`3ooolM0?oooa<0oadMo`3ooooo0?ooo`D0oooo000Y0?ooo`D00000o`3ooolO0?oooa<0oadMo`3o
oooo0?ooo`<0oooo000Y0?ooo`D00000o`3ooolR0?oooa40oadMo`3ooooo0?ooo`80oooo000Y0?oo
o`D00000o`3ooolR0?oooa40oadMo`3ooooo0?ooo`80oooo000Y0?ooo`D00000o`3ooolS0?oooa80
oadMo`3ooooo0?ooo`00:@3oool500000?l0oooo9@3ooolA0?lM7Ol0oooooP3oool002T0oooo1@00
003o0?ooobD0oooo4@3o7Ago0?ooooh0oooo000Y0?ooo`D00000o`3ooolV0?oooa80oadMo`3ooool
0?ooo`00:@3oool500000?l0oooo:03ooolA0?lM7Ol0oooon`3oool002T0oooo1@00003o0?ooobT0
oooo4`3o7Ago0?ooooP0oooo000Y0?ooo`D00000o`3ooolY0?oooa<0oadMo`3ooooh0?ooo`00:@3o
ool500000?l0oooo:`3ooolC0?lM7Ol0oooomP3oool002T0oooo1@00003o0?ooob`0oooo4`3o7Ago
0?ooooD0oooo000Y0?ooo`D00000o`3oool/0?oooa<0oadMo`3ooooe0?ooo`00:@3oool500000?l0
oooo;@3ooolD0?lM7Ol0ooool`3oool002T0oooo1@00003o0?ooobl0oooo5@3o7Ago0?oooo00oooo
000Y0?ooo`D00000o`3oool_0?oooaD0oadMo`3oooo`0?ooo`00:@3oool500000?l0oooo<03ooolE
0?lM7Ol0ooook`3oool002T0oooo1@00003o0?oooc<0oooo4`3o7Ago0?ooonh0oooo000Y0?ooo`D0
0000o`3ooolc0?oooa<0oadMo`3oooo^0?ooo`00:@3oool500000?l0oooo=@3ooolC0?lM7Ol0oooo
k03oool002T0oooo1@00003o0?ooocH0oooo4`3o7Ago0?ooon/0oooo000Y0?ooo`D00000o`3ooolf
0?oooa<0oadMo`3oooo[0?ooo`00:@3oool500000?l0oooo>03ooolD0?lM7Ol0ooooj03oool002T0
oooo1@00003o0?oooc/0oooo4`3o7Ago0?ooonH0oooo000Y0?ooo`D00000o`3ooolk0?oooa<0oadM
o`3ooooV0?ooo`00:@3oool500000?l0oooo?03ooolC0?lM7Ol0ooooi@3oool002T0oooo1@00003o
0?oooch0oooo4`3o7Ago0?ooon<0oooo000Y0?ooo`D00000o`3oooln0?oooa<0oadMo`3ooooS0?oo
o`00:@3oool500000?l0oooo@@3ooolA0?lM7Ol0oooohP3oool002T0oooo1@00003o0?oood80oooo
4`3o7Ago0?oooml0oooo000Y0?ooo`D00000o`3ooom20?oooa<0oadMo`3ooooO0?ooo`00:@3oool5
00000?l0ooooA@3ooolB0?lM7Ol0oooog@3oool002T0oooo1@00003o0?ooodH0oooo4P3o7Ago0?oo
om`0oooo000Y0?ooo`D00000o`3ooom80?oooa80oadMo`3ooooJ0?ooo`00:@3oool500000?l0oooo
B03ooolB0?lM7Ol0oooofP3oool002T0oooo1@00003o0?ooodT0oooo503o7Ago0?ooomL0oooo000Y
0?ooo`D00000o`3ooom;0?oooa<0oadMo`3ooooF0?ooo`00:@3oool500000?l0ooooB`3ooolC0?lM
7Ol0ooooeP3oool002T0oooo1@00003o0?ooodh0oooo4`3o7Ago0?ooom<0oooo000Y0?ooo`D00000
o`3ooom?0?oooa<0oadMo`3ooooB0?ooo`00:@3oool500000?l0ooooC`3ooolC0?lM7Ol0oooodP3o
ool002T0oooo1@00003o0?oooe40oooo503o7Ago0?oooll0oooo000Y0?ooo`D00000o`3ooomB0?oo
oaD0oadMo`3oooo=0?ooo`00:@3oool500000?l0ooooDP3ooolE0?lM7Ol0ooooc@3oool002T0oooo
1@00003o0?oooeD0oooo5@3o7Ago0?ooolX0oooo000Y0?ooo`D00000o`3ooomG0?oooa@0oadMo`3o
ooo90?ooo`00:@3oool500000?l0ooooE`3ooolD0?lM7Ol0oooob@3oool002T0oooo1@00003o0?oo
oeP0oooo5@3o7Ago0?ooolL0oooo000Y0?ooo`D00000o`3ooomK0?oooaD0oadMo`3oooo40?ooo`00
:@3oool500000?l0ooooF`3ooolE0?lM7Ol0ooooa03oool002T0oooo1@00003o0?oooed0oooo503o
7Ago0?oool<0oooo000Y0?ooo`D00000o`3ooomN0?oooaH0oadMo`3oooo00?ooo`00:@3oool50000
0?l0ooooGP3ooolF0?lM7Ol0oooo`03oool002T0oooo1@00003o0?oooel0oooo5`3o7Ago0?oookh0
oooo000Y0?ooo`D00000o`3ooomR0?oooaD0oadMo`3ooonm0?ooo`00:@3oool500000?l0ooooHP3o
oolE0?lM7Ol0oooo_@3oool002T0oooo1@00003o0?ooof@0oooo5P3o7Ago0?oookX0oooo000Y0?oo
o`D00000o`3ooomU0?oooaH0oadMo`3oooni0?ooo`00:@3oool500000?l0ooooJ03ooolF0?lM7Ol0
oooo]P3oool002T0oooo1@00003o0?ooofP0oooo5P3o7Ago0?oookH0oooo000Y0?ooo`D00000o`3o
oomZ0?oooaH0oadMo`3ooond0?ooo`00:@3oool500000?l0ooooK@3ooolD0?lM7Ol0oooo/`3oool0
02T0oooo1@00003o0?ooofd0oooo503o7Ago0?oook<0oooo000Y0?ooo`D00000o`3ooom^0?oooaH0
oadMo`3ooon`0?ooo`00:@3oool500000?l0ooooL03ooolF0?lM7Ol0oooo[P3oool002T0oooo1@00
003o0?ooog00oooo5P3o7Ago0?ooojh0oooo000Y0?ooo`D00000o`3ooomc0?oooaH0oadMo`3ooon[
0?ooo`00:@3oool500000?l0ooooM03ooolF0?lM7Ol0ooooZP3oool002T0oooo1@00003o0?ooog@0
oooo5P3o7Ago0?ooojX0oooo000Y0?ooo`D00000o`3ooomg0?oooaD0oadMo`3ooonX0?ooo`00:@3o
ool500000?l0ooooN03ooolF0?lM7Ol0ooooYP3oool002T0oooo1@00003o0?ooogP0oooo5P3o7Ago
0?ooojH0oooo000Y0?ooo`D00000o`3ooomk0?oooaD0oadMo`3ooonT0?ooo`00:@3oool500000?l0
ooooO@3ooolF0?lM7Ol0ooooX@3oool002T0oooo1@00003o0?ooogd0oooo5P3o7Ago0?oooj40oooo
000Y0?ooo`D00000o`3ooon00?oooa@0oadMo`3ooonP0?ooo`00:@3oool500000?l0ooooP@3ooolF
0?lM7Ol0ooooW@3oool002T0oooo1@00003o0?oooh40oooo5P3o7Ago0?oooid0oooo000Y0?ooo`D0
0000o`3ooon40?oooaD0oadMo`3ooonK0?ooo`00:@3oool500000?l0ooooQP3ooolF0?lM7Ol0oooo
V03oool002T0oooo1@00003o0?ooohT0oooo503o7Ago0?oooiL0oooo000Y0?ooo`D00000o`3ooon9
0?oooa@0oadMo`3ooonG0?ooo`00:@3oool500000?l0ooooRP3ooolF0?lM7Ol0ooooU03oool002T0
oooo1@00003o0?ooohd0oooo5@3o7Ago0?oooi80oooo000Y0?ooo`D00000o`3ooon=0?oooaD0oadM
o`3ooonB0?ooo`00:@3oool500000?l0ooooSP3ooolG0?lM7Ol0ooooS`3oool002T0oooo1@00003o
0?oooi40oooo5@3o7Ago0?ooohh0oooo000Y0?ooo`D00000o`3ooonA0?oooaD0oadMo`3ooon>0?oo
o`00:@3oool500000?l0ooooT`3ooolF0?lM7Ol0ooooR`3oool002T0oooo1@00003o0?oooiH0oooo
503o7Ago0?ooohX0oooo000Y0?ooo`D00000o`3ooonF0?oooa@0oadMo`3ooon:0?ooo`00:@3oool5
00000?l0ooooU`3ooolF0?lM7Ol0ooooQ`3oool002T0oooo1@00003o0?oooiX0oooo5@3o7Ago0?oo
ohD0oooo000Y0?ooo`D00000o`3ooonJ0?oooaD0oadMo`3ooon50?ooo`00:@3oool500000?l0oooo
W03ooolF0?lM7Ol0ooooPP3oool002T0oooo1@00003o0?oooil0oooo503o7Ago0?oooh40oooo000Y
0?ooo`D00000o`3ooonO0?oooa@0oadMo`3ooon10?ooo`00:@3oool500000?l0ooooX03ooolF0?lM
7Ol0ooooOP3oool002T0oooo1@00003o0?oooj<0oooo5@3o7Ago0?ooog`0oooo000Y0?ooo`D00000
o`3ooonS0?oooaD0oadMo`3oooml0?ooo`00:@3oool500000?l0ooooY@3ooolF0?lM7Ol0ooooN@3o
ool002T0oooo1@00003o0?ooojL0oooo5@3o7Ago0?ooogP0oooo000Y0?ooo`D00000o`3ooonW0?oo
oaD0oadMo`3ooomh0?ooo`00:@3oool500000?l0ooooZ@3ooolF0?lM7Ol0ooooM@3oool002T0oooo
1@00003o0?oooj`0oooo503o7Ago0?ooog@0oooo000Y0?ooo`D00000o`3ooon]0?oooaH0oadMo`3o
ooma0?ooo`00:@3oool500000?l0oooo[@3ooolF0?lM7Ol0ooooL@3oool002T0oooo1@00003o0?oo
ok00oooo5@3o7Ago0?ooofl0oooo000Y0?ooo`D00000o`3ooonb0?oooaH0oadMo`3ooom/0?ooo`00
:@3oool500000?l0oooo/P3ooolF0?lM7Ol0ooooK03oool002T0oooo1@00003o0?oookD0oooo5P3o
7Ago0?ooofT0oooo000Y0?ooo`D00000o`3ooonf0?oooaH0oadMo`3ooomX0?ooo`00:@3oool50000
0?l0oooo]P3ooolF0?lM7Ol0ooooJ03oool002T0oooo1@00003o0?oookT0oooo5P3o7Ago0?ooofD0
oooo000Y0?ooo`D00000o`3ooonk0?oooaL0oadMo`3ooomR0?ooo`00:@3oool500000?l0oooo^`3o
oolG0?lM7Ol0ooooHP3oool002T0oooo1@00003o0?oookh0oooo5P3o7Ago0?ooof00oooo000Y0?oo
o`D00000o`3ooono0?oooaP0oadMo`3ooomM0?ooo`00:@3oool500000?l0oooo_`3ooolH0?lM7Ol0
ooooG@3oool002T0oooo1@00003o0?oool80oooo5`3o7Ago0?oooe/0oooo000Y0?ooo`D00000o`3o
ooo50?oooaL0oadMo`3ooomH0?ooo`00:@3oool500000?l0ooooa@3ooolG0?lM7Ol0ooooF03oool0
02T0oooo1@00003o0?ooolH0oooo6@3o7Ago0?oooeD0oooo000Y0?ooo`D00000o`3oooo90?oooaT0
oadMo`3ooomB0?ooo`00:@3oool500000?l0oooob@3ooolI0?lM7Ol0ooooDP3oool002T0oooo1@00
003o0?oool`0oooo603o7Ago0?oooe00oooo000Y0?ooo`D00000o`3oooo>0?oooaT0oadMo`3ooom=
0?ooo`00:@3oool500000?l0oooocP3ooolI0?lM7Ol0ooooC@3oool002T0oooo1@00003o0?ooom40
oooo6@3o7Ago0?ooodX0oooo000Y0?ooo`D00000o`3ooooD0?oooaT0oadMo`3ooom70?ooo`00:@3o
ool500000?l0ooooe@3ooolK0?lM7Ol0ooooA03oool002T0oooo1@00003o0?ooomD0oooo6`3o7Ago
0?oood@0oooo000Y0?ooo`D00000o`3ooooH0?oooaX0oadMo`3ooom20?ooo`00:@3oool500000?l0
oooof@3ooolK0?lM7Ol0oooo@03oool002T0oooo1@00003o0?ooomT0oooo6`3o7Ago0?oood00oooo
000Y0?ooo`D00000o`3ooooL0?oooa/0oadMo`3ooolm0?ooo`00:@3oool500000?l0oooogP3ooolL
0?lM7Ol0oooo>P3oool002T0oooo1@00003o0?ooomh0oooo703o7Ago0?ooocX0oooo000Y0?ooo`D0
0000o`3ooooQ0?oooa`0oadMo`3ooolg0?ooo`00:@3oool500000?l0oooohP3ooolL0?lM7Ol0oooo
=P3oool002T0oooo1@00003o0?ooon80oooo703o7Ago0?ooocH0oooo000Y0?ooo`D00000o`3ooooU
0?oooa`0oadMo`3ooolc0?ooo`00:@3oool500000?l0ooooj03ooolL0?lM7Ol0oooo<03oool002T0
oooo1@00003o0?ooonP0oooo703o7Ago0?oooc00oooo000Y0?ooo`D00000o`3oooo[0?oooa`0oadM
o`3oool]0?ooo`00:@3oool500000?l0ooookP3ooolL0?lM7Ol0oooo:P3oool002T0oooo1@00003o
0?ooonh0oooo703o7Ago0?ooobX0oooo000S0?oooa000000o`3oooo/0?oooaX0oadMo`3ooolY0?oo
o`007@3ooolM00000?l0ooooiP3ooolL0?lM7Ol0oooo9P3oool001d0oooo7@00003o0?ooonH0oooo
703o7Ago0?ooobH0oooo000H0?ooobP00000o`3ooooS0?oooa`0oadMo`3ooolS0?ooo`00503ooola
00000?l0ooooh@3ooolL0?lM7Ol0oooo803oool001@0oooo<@00003o0?ooon@0oooo703o7Ago0?oo
oad0oooo000D0?oooc400000o`3ooooT0?oooa`0oadMo`3ooolM0?ooo`005@3oool^00000?l0oooo
j@3ooolL0?lM7Ol0oooo6P3oool001D0oooo;P00000F0?ooo`D00000o`3ooooA0?oooa`0oadMo`3o
oolG0?ooo`005@3oool^000001H0oooo1@00003o0?ooom40oooo703o7Ago0?oooaL0oooo000E0?oo
obh000004`3oool:00000?l0oooodP3ooolK0?lM7Ol0oooo5@3oool001L0oooo:`00000D0?ooo`P0
00000P3oool200000?l0oooodP3ooolL0?lM7Ol0oooo4P3oool001L0oooo:`00000D0?ooo`P00000
0P3oool200000?l0oooodP3ooolL0?lM7Ol0oooo4P3oool001L0oooo:`00000P0?ooo`030000003o
ool0oooo0?l0oooodP3ooolK0?lM7Ol0oooo403oool001L0oooo:@00000S0?ooo`800000o`3ooooD
0?oooal0oadMo`3oool:0?ooo`005`3ooolY000002<0oooo0P00003o0?ooom@0oooo7`3o7Ago0?oo
o`X0oooo000H0?ooobP000009@3oool00`000000oooo0?ooo`3o0?ooom@0oooo7`3o7Ago0?ooo`L0
oooo000H0?ooobP000009@3oool300000?l0oooof@3ooolM0?lM7Ol0oooo103oool001P0oooo:000
000U0?ooo`<00000o`3ooooI0?oooad0oadMo`3oool40?ooo`00603ooolW000002L0oooo0P00003o
0?ooom`0oooo703o7Ago0?ooo`80oooo000J0?ooobD00000:@3oool00`000000oooo0?ooo`3o0?oo
om`0oooo703o7Agn0?ooo`006P3ooolU000002T0oooo00<000000?ooo`3oool0o`3ooooL0?oooa`0
oadMoP3oool001X0oooo9@00000Y0?ooo`<00000o`3ooooO0?oooa`0oadMn`3oool001/0oooo8P00
000[0?ooo`<00000o`3ooooR0?oooad0oadMm`3oool001/0oooo8P00000[0?ooo`<00000o`3ooooR
0?oooad0oadMm`3oool001/0oooo8P00000[0?ooo`@00000o`3ooooT0?oooah0oadMl`3oool001/0
oooo8P00000[0?ooo`H00000o`3ooooT0?oooal0oadMl03oool001/0oooo8P00000[0?ooo`H00000
o`3ooooT0?oooal0oadMl03oool001d0oooo7`00000/0?ooo`H00000o`3ooooY0?oooal0oadMj`3o
ool001d0oooo7`00000/0?ooo`L00000o`3oooo[0?oooa`0oadMj`3oool001d0oooo7@00000/0?oo
o`H000000P3oool00`000000oooo0?ooo`3o0?ooond0oooo5P3o7Ag]0?ooo`007@3ooolM000002`0
oooo1P0000020?ooo`030000003oool0oooo0?l0ooook@3ooolF0?lM7Nd0oooo000N0?oooa`00000
;03oool6000000<0oooo0P00003o0?oooo00oooo4`3o7Ag]0?ooo`007P3ooolL000002`0oooo1P00
00030?ooo`800000o`3ooooe0?ooo`d0oadMkP3oool001h0oooo7000000/0?ooo`H000000`3oool2
00000?l0oooom@3oool=0?lM7Nh0oooo000N0?oooa/00000;@3oool6000000<0oooo0`00003o0?oo
ooP0oooo2@3o7Ag^0?ooo`00803ooolI000002d0oooo1P0000050?ooo`030000003oool0oooo0?l0
oooon@3oool60?lM7Nh0oooo000P0?oooaT00000;@3oool6000000D0oooo00<000000?ooo`3oool0
o`3ooooi0?ooo`H0oadMkP3oool00200oooo6@00000/0?ooo`L000001@3oool300000?l0ooooo`3o
ooo^0?ooo`00803ooolG000002h0oooo1P0000070?ooo`800000o`3ooooo0?ooonh0oooo000P0?oo
oaL00000;P3oool6000000L0oooo0P00003o0?ooool0ooookP3oool00240oooo5P00000^0?ooo`H0
00001`3oool300000?l0ooooo`3oooo]0?ooo`008@3ooolE000002l0oooo1P0000090?ooo`030000
003oool0oooo0?l0ooooo`3oooo[0?ooo`008@3ooolE000002l0oooo1P0000090?ooo`030000003o
ool0oooo0?l0ooooo`3oooo[0?ooo`008@3ooolE000002d0oooo1P00000;0?ooo`030000003oool0
oooo0?l0ooooo`3oooo[0?ooo`008`3ooolC000002d0oooo1P00000;0?ooo`<00000o`3ooooo0?oo
on/0oooo000S0?oooa<00000;@3oool6000000/0oooo0`00003o0?ooool0ooooj`3oool002<0oooo
4@00000_0?ooo`H00000303oool200000?l0ooooo`3oooo[0?ooo`008`3ooolA000002l0oooo1P00
000<0?ooo`800000o`3ooooo0?ooon/0oooo000S0?oooa400000;`3oool6000000`0oooo0P00003o
0?ooool0ooooj`3oool002@0oooo3`00000_0?ooo`H000003@3oool300000?l0ooooo`3ooooZ0?oo
o`00903oool?000002l0oooo1P00000<0?ooo`@00000o`3ooooo0?ooonX0oooo000T0?ooo`l00000
;@3oool8000000X0oooo1P00003o0?ooool0oooojP3oool002@0oooo3`00000]0?ooo`P000002P3o
ool600000?l0ooooo`3ooooZ0?ooo`009P3oool;000002l0oooo1P00000;0?ooo`L00000o`3ooooo
0?ooonX0oooo000V0?ooo`/00000:P3oool;000000/0oooo1`00003o0?ooool0oooojP3oool002H0
oooo2`00000Z0?ooo`/000002`3oool700000?l0ooooo`3ooooZ0?ooo`009`3oool9000002l0oooo
1`00000<0?ooo`D00000o`3ooooo0?ooon/0oooo000W0?ooo`T00000o`3ooooo0?ooool0oooo<`3o
ool002L0oooo2@00003o0?ooool0ooooo`3ooolc0?ooo`009`3oool900000?l0ooooo`3ooooo0?oo
oc<0oooo000Y0?ooo`D00000o`3ooooo0?ooool0oooo=@3oool002T0oooo1@00003o0?ooool0oooo
o`3ooole0?ooo`00:@3oool500000?l0ooooo`3ooooo0?ooocD0oooo000Y0?ooo`D00000o`3ooooo
0?ooool0oooo=@3oool002T0oooo1@00003o0?ooool0ooooo`3ooole0?ooo`00:P3oool400000?l0
ooooo`3ooooo0?ooocD0oooo000Z0?ooo`@00000o`3ooooo0?ooool0oooo=@3oool002X0oooo1000
003o0?ooool0ooooo`3ooole0?ooo`00:P3oool300000?l0ooooo`3ooooo0?ooocH0oooo000/0?oo
o`030000003oool0oooo0?l0ooooo`3ooooo0?oooc@0oooo000/0?ooo`030000003oool0oooo0?l0
ooooo`3ooooo0?oooc@0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3o
ool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0
ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo
0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00
o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS
0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0oooo
o`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?oo
ool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo
003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?oo
of<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3o
oooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0
ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3o
ool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0
ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo
0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00
o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS
0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0oooo
o`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?oo
ool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo
003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?oo
of<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3o
oooo0?ooof<0oooo003o0?ooool0ooooo`3oool80?ooo`@00000E`3oool00?l0ooooo`3ooooo0?oo
o`H0oooo2@00001D0?ooo`00o`3ooooo0?ooool0oooo1P3oool9000005@0oooo003o0?ooool0oooo
o`3oool60?ooo`h00000C`3oool00?l0ooooo`3ooooo0?ooo`H0oooo4P00001;0?ooo`00o`3ooooo
0?ooool0oooo1P3ooolB000004/0oooo003o0?ooool0ooooo`3oool50?oooaL00000A`3oool00?l0
ooooo`3ooooo0?ooo`D0oooo6P0000140?ooo`00o`3ooooo0?ooool0oooo1@3ooolJ000004@0oooo
003o0?ooool0ooooo`3oool50?oooal00000?`3oool00?l0ooooo`3ooooo0?ooo`D0oooo8`00000k
0?ooo`00o`3ooooo0?ooool0oooo1@3ooolS000003/0oooo003o0?ooool0ooooo`3oool50?ooobH0
0000>03oool00?l0ooooo`3ooooo0?ooo`<0oooo;@00000c0?ooo`00o`3ooooo0?ooool0oooo0`3o
ool]000003<0oooo003o0?ooool0ooooo`3oool30?oooc800000;P3oool00?l0ooooo`3ooooo0?oo
o`<0oooo=`00000Y0?ooo`00o`3ooooo0?ooool0oooo0`3ooolg000002T0oooo003o0?ooool0oooo
j`3oool<000000/0oooo>P00000V0?ooo`00o`3ooooo0?ooonL0oooo100000090?ooo`H00000203o
oolm000002<0oooo003o0?ooo`/0ooooo`00003o000003P00000803oool00?l0oooo2`3ooooo0000
0?l00000>000000P0?ooo`00o`3oool;0?ooool00000o`00000o000001T0oooo003o0?ooo`/0oooo
o`00003o0000044000005`3oool00?l0oooo2`3ooooo00000?l00000@@00000G0?ooo`00o`3oool;
0?ooool00000o`00000l000001`0oooo003o0?ooo`/0ooooo`00003o000003P00000803oool00?l0
oooo2`3ooooo00000?l00000>000000P0?ooo`00o`3ooomW0?ooo`D00000=P3oool300000?l0oooo
?`3oool3000001<0oooo1P0000020?oooc/000009@3oool00?l0ooooI`3oool3000003P0oooo1000
003o0?ooocl0oooo0`00000@0?ooo`P000000P3ooolh000002P0oooo003o0?ooofL0oooo0`00000h
0?ooo`@00000o`3ooolo0?ooo`<00000403oool800000080oooo>000000X0?ooo`00o`3ooomW0?oo
o`<00000>P3oool400000?l0oooo?`3oool00`000000oooo0?ooo`0=0?ooo`T000000P3ooold0000
02`0oooo003o0?ooofH0oooo1000000k0?ooo`@00000o`3ooolo0?ooo`<000002@3oool:000000@0
oooo<000000`0?ooo`00o`3ooomV0?ooo`@00000>`3oool400000?l0oooo?`3oool3000000T0oooo
2P0000040?oooc000000<03oool00?l0ooooBP3oool9000001<0oooo1000000?0?ooo`@000003`3o
ool4000001D0oooo1P00000P0?ooo`P00000203oool500000140oooo2@00000I0?ooo`T00000403o
ool6000001h0oooo2000000F0?ooo`H000002`3oool4000000X0oooo0P0000040?ooo`T000004P3o
ool6000000/0oooo1P00000?0?ooo`H000003P3oool3000000D0oooo300000050?ooob/00000=@3o
ool00?l0ooooA`3oool6000000H0oooo0`00000@0?ooo`@00000303oool9000000`0oooo1`00000C
0?ooo`H000007`3oool:000000H0oooo2@00000;0?ooo`l000004`3oool6000000H0oooo0`00000=
0?ooo`H000006`3oool>00000180oooo2P0000060?ooo`T000001`3oool8000000H0oooo1000000=
0?ooo`T000002P3oool8000000/0oooo2@00000@0?ooo`l000002@3ooolU000003T0oooo003o0?oo
odL0oooo1P0000060?ooo`<00000403oool4000000`0oooo2@00000<0?ooo`L000004`3oool60000
01l0oooo2P0000060?ooo`T000002`3oool?000001<0oooo1P0000060?ooo`<000003@3oool60000
01/0oooo3P00000B0?ooo`X000001P3oool9000000L0oooo200000060?ooo`@000003@3oool90000
00X0oooo2000000;0?ooo`T00000403oool?000000T0oooo9@00000i0?ooo`00o`3ooom50?ooo`D0
0000303oool3000000d0oooo1000000<0?ooo`X000002`3oool500000080oooo00<000000?ooo`3o
ool04@3oool6000001`0oooo1P0000060?ooo`030000003oool0oooo00<0oooo1P0000030?ooo`03
0000003oool0oooo00L0oooo2@0000060?ooo`@000003`3oool4000000`0oooo0`00000<0?ooo`H0
00005`3oool9000000H0oooo1000000=0?ooo`H000001P3oool2000000@0oooo1P0000030?ooo`03
0000003oool0oooo00@0oooo1@00000:0?ooo`@00000303oool6000000<0oooo00<000000?ooo`3o
ool02@3oool6000000/0oooo200000000`3oool000000000000=0?ooo`d00000303ooolP000003h0
oooo003o0?oood@0oooo1P00000?0?ooo`030000003oool0oooo00P0oooo1P00000?0?ooo`<00000
103oool2000000T0oooo1@0000030?ooo`8000004@3oool6000001/0oooo1`0000070?ooo`800000
0`3oool6000000@0oooo0P0000070?ooo`H000003@3oool2000000/0oooo1P00000?0?ooo`030000
003oool0oooo00T0oooo1P00000G0?ooo`H000003@3oool2000000X0oooo1P0000090?ooo`040000
003oool0oooo0?ooo`H00000103oool2000000@0oooo1@00000;0?ooo`D000002P3oool6000000@0
oooo0P0000090?ooo`H000002`3oool6000000D0oooo00<000000?ooo`3oool02P3oool:000000l0
oooo700000120?ooo`00o`3ooom40?ooo`H000003`3oool00`000000oooo0?ooo`080?ooo`H00000
3`3oool3000000@0oooo0P0000090?ooo`D000000`3oool200000140oooo1P00000K0?ooo`L00000
1`3oool2000000<0oooo1P0000040?ooo`8000001`3oool6000000d0oooo0P00000;0?ooo`H00000
3`3oool00`000000oooo0?ooo`090?ooo`H000005`3oool6000000d0oooo0P00000:0?ooo`H00000
2@3oool010000000oooo0?ooo`3oool6000000@0oooo0P0000040?ooo`D000002`3oool5000000X0
oooo1P0000040?ooo`8000002@3oool6000000/0oooo1P0000050?ooo`030000003oool0oooo00X0
oooo2P00000?0?oooa`00000@P3oool00?l0ooooA03oool400000180oooo00<000000?ooo`3oool0
1`3oool6000001H0oooo0`0000080?ooo`@00000103oool200000140oooo2000000I0?ooo`H00000
2P3oool00`000000oooo0?ooo`06000000H0oooo00<000000?ooo`3oool00`3oool7000000l0oooo
00<000000?ooo`3oool0203oool500000140oooo0P0000090?ooo`H000005P3oool7000000l0oooo
00<000000?ooo`3oool01`3oool6000000X0oooo0P0000000`3oool0000000000004000000H0oooo
00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0;0?ooo`H000002@3oool6000000H0oooo
00<000000?ooo`3oool01P3oool6000000d0oooo1P0000040?ooo`8000002P3oool700000180oooo
5`0000170?ooo`00o`3ooom20?ooo`H000004P3oool00`000000oooo0?ooo`070?ooo`H00000603o
ool00`000000oooo0?ooo`040?ooo`H000001P3oool00`000000oooo0?ooo`0@0?ooo`H000006@3o
ool6000000/0oooo200000060?ooo`030000003oool0oooo00<0oooo1@00000B0?ooo`8000001`3o
ool600000140oooo0P00000:0?ooo`H000005@3oool600000140oooo0P0000070?ooo`H00000303o
ool8000000H0oooo0P0000030?ooo`030000003oool0oooo00/0oooo1P0000090?ooo`P000001@3o
ool2000000H0oooo1`00000<0?ooo`H000001P3oool00`000000oooo0?ooo`080?ooo`D00000503o
oolD000004T0oooo003o0?oood80oooo1P00000B0?ooo`030000003oool0oooo00L0oooo1P00000H
0?ooo`030000003oool0oooo00@0oooo1P0000060?ooo`030000003oool0oooo0100oooo1P00000I
0?ooo`H000002`3oool8000000H0oooo00<000000?ooo`3oool00`3oool500000180oooo0P000007
0?ooo`H000004@3oool2000000X0oooo1P00000E0?ooo`H000004@3oool2000000L0oooo1P00000<
0?ooo`P000001P3oool2000000<0oooo00<000000?ooo`3oool02`3oool6000000T0oooo20000005
0?ooo`8000001P3oool7000000`0oooo1P0000060?ooo`030000003oool0oooo00P0oooo1@00000D
0?oooa@00000B@3oool00?l0oooo@P3oool6000001`0oooo1P00000I0?ooo`800000103oool60000
01T0oooo1`00000H0?ooo`H000003@3oool7000000/0oooo1@00000K0?ooo`H000007@3oool60000
01D0oooo1P00000J0?ooo`H00000303oool00`000000oooo0?ooo`05000000/0oooo00<000000?oo
o`3oool02`3oool6000000/0oooo1P00000>0?ooo`H00000303oool600000140oooo1@00000D0?oo
o`l00000CP3oool00?l0oooo@P3oool6000001`0oooo1P00000I0?ooo`<000000`3oool6000001T0
oooo1`00000H0?ooo`H000003@3oool7000000/0oooo1@00000K0?ooo`H000007@3oool6000001D0
oooo1P00000J0?ooo`H000003@3oool7000001P0oooo1`00000;0?ooo`H000003P3oool6000000`0
oooo1`00000C0?ooo`800000503oool;00000580oooo003o0?oood80oooo1P00000L0?ooo`H00000
6`3oool010000000oooo0?ooo`3oool6000001X0oooo1P00000H0?ooo`H000003P3oool6000000/0
oooo1@00000K0?ooo`H000007@3oool8000001<0oooo1P00000J0?ooo`H000003@3oool7000001P0
oooo1`00000;0?ooo`H000003P3oool8000000/0oooo1P00000E0?ooo`T000002`3oool6000005L0
oooo003o0?oood80oooo1P00000L0?ooo`H000006`3oool010000000oooo0?ooo`3oool6000001X0
oooo1P00000H0?ooo`H000003P3oool6000000/0oooo1@00000K0?ooo`H000007@3oool8000001<0
oooo1P00000J0?ooo`H000003@3oool7000001P0oooo1`00000;0?ooo`H000003P3oool8000000/0
oooo1P00000E0?ooo`T000002`3oool6000005L0oooo003o0?oood80oooo1P00000L0?ooo`H00000
703oool2000000030?ooo`000000000000800000703oool6000001P0oooo1`00000=0?ooo`P00000
2@3oool5000001/0oooo1P00000O0?ooo`H000004`3oool6000001X0oooo1`00000>0?ooo`D00000
5`3oool7000000d0oooo1P00000?0?ooo`H000002`3oool600000180oooo100000050?ooo`H00000
I@3oool00?l0oooo@P3oool6000001`0oooo1P00000L0?ooo`L00000703oool8000001L0oooo1P00
000?0?ooo`H000002@3oool;000001D0oooo1P00000O0?ooo`L000004P3oool;000001H0oooo1P00
000>0?ooo`L000005@3oool7000000d0oooo1P00000?0?ooo`L000002P3oool600000100oooo1@00
00090?ooo`@00000I03oool00?l0oooo@P3oool6000001`0oooo1P00000L0?ooo`L00000703oool8
000001L0oooo1P00000?0?ooo`H000002@3oool;000001D0oooo1P00000O0?ooo`L000004P3oool;
000001H0oooo1P00000>0?ooo`L000005@3oool7000000d0oooo1P00000?0?ooo`L000002P3oool6
00000100oooo1@0000090?ooo`@00000I03oool00?l0ooooA03oool6000001X0oooo2000000L0?oo
o`D00000703oool8000001L0oooo1P00000?0?ooo`H000002P3oool6000000<0oooo1P00000A0?oo
o`H000007P3oool7000001<0oooo1P0000030?ooo`H000004@3oool6000000l0oooo1P00000C0?oo
o`L000003`3oool6000000l0oooo1`00000<0?ooo`H000003P3oool5000000T0oooo1P00001R0?oo
o`00o`3ooom40?ooo`H000006P3oool8000001`0oooo1@00000L0?ooo`P000006@3oool6000000d0
oooo1P00000:0?ooo`H000001P3oool6000000h0oooo1P00000N0?ooo`P000004P3oool6000000H0
oooo1P00000>0?ooo`H000003`3oool600000180oooo1`00000@0?ooo`H000003`3oool600000003
0?ooo`000000000000X0oooo1P00000=0?ooo`H000002P3oool600000640oooo003o0?oood@0oooo
1P00000J0?ooo`P00000703oool5000001`0oooo2000000I0?ooo`H000003@3oool6000000X0oooo
1P0000060?ooo`H000003P3oool6000001h0oooo2000000B0?ooo`H000001P3oool6000000h0oooo
1P00000?0?ooo`H000004P3oool700000100oooo1P00000?0?ooo`H0000000<0oooo000000000000
2P3oool6000000d0oooo1P00000:0?ooo`H00000H@3oool00?l0ooooA03oool6000001X0oooo2000
000L0?ooo`D000007P3oool6000001T0oooo1P00000>0?ooo`H000002P3oool6000000P0oooo1P00
000;0?ooo`H000007`3oool7000001@0oooo1@0000080?ooo`H000003@3oool6000000d0oooo1`00
000A0?ooo`L000004P3oool5000000l0oooo2@0000090?ooo`H000003@3oool6000000X0oooo1P00
001Q0?ooo`00o`3ooom50?ooo`H000006`3oool6000001`0oooo1@00000N0?ooo`H000006P3oool5
000000h0oooo1P00000:0?ooo`H000002@3oool6000000`0oooo1P00000M0?ooo`T000004P3oool5
000000T0oooo1P00000=0?ooo`D000003`3oool5000000l0oooo1`00000D0?ooo`D000003`3oool6
00000080oooo00<000000?ooo`3oool01`3oool6000000d0oooo1P00000:0?ooo`L00000H03oool0
0?l0ooooA@3oool6000001/0oooo1P00000L0?ooo`D000007P3oool6000001X0oooo1@00000>0?oo
o`H000002P3oool6000000T0oooo1P00000<0?ooo`H000007@3oool900000180oooo1@0000090?oo
o`H000003@3oool5000000l0oooo1@00000?0?ooo`L00000503oool5000000l0oooo1P0000020?oo
o`030000003oool0oooo00L0oooo1P00000=0?ooo`H000002P3oool700000600oooo003o0?ooodD0
oooo1P00000K0?ooo`H000006P3oool7000001h0oooo1P00000J0?ooo`H000003@3oool6000000`0
oooo1P0000090?ooo`H000002P3oool6000001d0oooo1P0000000`3oool000000000000C0?ooo`H0
00002@3oool6000000/0oooo1P00000>0?ooo`D000003P3oool7000001D0oooo1@00000?0?ooo`H0
00000`3oool00`000000oooo0?ooo`070?ooo`H00000303oool6000000`0oooo1@00001P0?ooo`00
o`3ooom70?ooo`H000006@3oool7000001T0oooo2@00000L0?ooo`H00000703oool4000000d0oooo
1P00000=0?ooo`D000002P3oool6000000X0oooo1P00000N0?ooo`P00000503oool4000000X0oooo
1P00000<0?ooo`@000003P3oool5000000h0oooo1`0000090?ooo`030000003oool0oooo00T0oooo
1@00000?0?ooo`P0000000<0oooo0000003oool0203oool6000000`0oooo1`00000;0?ooo`D00000
H03oool00?l0ooooA`3oool6000001T0oooo1`00000I0?ooo`T00000703oool6000001`0oooo1000
000=0?ooo`H000003@3oool5000000X0oooo1P00000:0?ooo`H000007P3oool8000001@0oooo1000
000:0?ooo`H00000303oool4000000h0oooo1@00000>0?ooo`L000002@3oool00`000000oooo0?oo
o`090?ooo`D000003`3oool8000000030?ooo`000000oooo00P0oooo1P00000<0?ooo`L000002`3o
ool500000600oooo003o0?ooodP0oooo1@00000>0?ooo`<00000203oool7000001T0oooo1P000000
103oool0000000000000000K0?ooo`H000007@3oool5000000/0oooo2000000=0?ooo`@000002@3o
ool7000000/0oooo1000000?0?ooo`<00000303oool500000080oooo0`00000C0?ooo`@000002@3o
ool8000000/0oooo1@00000<0?ooo`L00000303oool6000000X0oooo00<000000?ooo`3oool02P3o
ool6000000l0oooo1P0000020?ooo`8000001`3oool6000000d0oooo1P00000;0?ooo`D00000H03o
ool00?l0ooooBP3oool4000000`0oooo1P0000070?ooo`H000006@3oool6000000<0oooo00<00000
0?ooo`3oool06@3oool6000001l0oooo1000000:0?ooo`P000003P3oool5000000T0oooo1@00000<
0?ooo`D000002`3oool6000000/0oooo1@0000030?ooo`<000000P3oool4000000d0oooo1@000009
0?ooo`H000002`3oool6000000/0oooo1`00000<0?ooo`H000002P3oool00`000000oooo0?ooo`0:
0?ooo`H000003`3oool6000000@0oooo00<000000?ooo`3oool0103oool8000000/0oooo1P00000;
0?ooo`D00000H03oool00?l0ooooBP3oool4000000`0oooo1P0000070?ooo`H000006@3oool60000
00<0oooo00<000000?ooo`3oool06@3oool6000001l0oooo1000000:0?ooo`P000003P3oool50000
00T0oooo1@00000<0?ooo`D000002`3oool6000000/0oooo1@0000030?ooo`<000000P3oool40000
00d0oooo1@0000090?ooo`H000002`3oool6000000/0oooo1`00000<0?ooo`H000002P3oool00`00
0000oooo0?ooo`0:0?ooo`H000003`3oool6000000@0oooo00<000000?ooo`3oool0103oool80000
00/0oooo1P00000;0?ooo`D00000H03oool00?l0ooooB`3oool5000000X0oooo1P0000070?ooo`P0
00005`3oool6000000<0oooo0`0000030?ooo`@000004P3oool600000200oooo100000090?ooo`P0
0000403oool3000000T0oooo1@00000>0?ooo`@000002P3oool6000000/0oooo1@0000030?ooo`/0
00003@3oool3000000T0oooo1P00000=0?ooo`@000002`3oool7000000`0oooo1P00000:0?ooo`<0
00002P3oool6000000l0oooo1P0000050?ooo`800000103oool8000000d0oooo1P0000090?ooo`P0
0000G@3oool00?l0ooooC@3oool4000000T0oooo1P0000090?ooo`H000005P3oool6000000D0oooo
2@00000B0?ooo`H000008P3oool4000000L0oooo2000000A0?ooo`<00000203oool5000000l0oooo
1@0000080?ooo`H000002`3oool7000000<0oooo2@00000>0?ooo`<00000203oool6000000h0oooo
1@0000090?ooo`L000003@3oool5000000P0oooo1@00000:0?ooo`L000003P3oool7000000H0oooo
00@000000?ooo`3oool0oooo2000000>0?ooo`H00000203oool8000005d0oooo003o0?ooodd0oooo
100000090?ooo`H000002@3oool6000001H0oooo1P0000050?ooo`T000004P3oool600000280oooo
100000070?ooo`P000004@3oool3000000P0oooo1@00000?0?ooo`D00000203oool6000000/0oooo
1`0000030?ooo`T000003P3oool3000000P0oooo1P00000>0?ooo`D000002@3oool7000000d0oooo
1@0000080?ooo`D000002P3oool7000000h0oooo1`0000060?ooo`040000003oool0oooo0?ooo`P0
00003P3oool6000000P0oooo2000001M0?ooo`00o`3ooom@0?ooo`<000001`3oool4000000/0oooo
1P00000@0?ooo`<000000`3oool6000000L0oooo1`00000B0?ooo`@000009@3oool4000000H0oooo
0P0000000`3oool000000000000400000180oooo100000050?ooo`@000004`3oool3000000L0oooo
1@0000060?ooo`d00000103oool800000100oooo100000050?ooo`@000004`3oool5000000@0oooo
0`0000000`3oool0000000000004000000h0oooo100000060?ooo`H000001P3oool;000000T0oooo
300000070?ooo`T000004P3oool6000000@0oooo1@00001R0?ooo`00o`3ooomC0?ooo`P000003`3o
ool600000180oooo1`00000:0?ooo`D000004`3oool4000002P0oooo1`0000030?ooo`H000005P3o
ool8000001L0oooo2@00000?0?ooo`L000001P3oool4000001H0oooo2000000G0?ooo`P000000P3o
ool6000000l0oooo2@0000040?ooo`8000003@3oool400000140oooo100000090?ooo`H000005P3o
ool:000006@0oooo003o0?ooof`0oooo1000000k0?ooo`@00000<P3oool600000?l0ooooN`3oool0
0?l0ooooK03oool4000003/0oooo1000000b0?ooo`H00000o`3ooomk0?ooo`00o`3ooom/0?ooo`@0
0000>`3oool4000003@0oooo1P00003o0?ooogT0oooo003o0?ooofd0oooo1@00000i0?ooo`<00000
=@3oool600000?l0ooooN@3oool00?l0ooooK@3oool5000003T0oooo0`00000e0?ooo`H00000o`3o
oomi0?ooo`00o`3ooom_0?ooo`@00000>03oool3000003D0oooo1P00003o0?ooogT0oooo003o0?oo
og00oooo0`00000f0?ooo`D00000=@3oool600000?l0ooooN@3oool00?l0ooooL03oool3000003H0
oooo1@00000e0?ooo`H00000o`3ooomi0?ooo`00o`3ooomb0?ooo`800000=@3oool3000003P0oooo
1P00003<0?ooo`D00000YP3oool00?l0ooooL`3oool3000003<0oooo0`00000h0?ooo`H00000b`3o
ool700000:D0oooo003o0?ooog<0oooo0`00000c0?ooo`<00000>03oool600000</0oooo1`00002U
0?ooo`00o`3ooomd0?ooo`800000<`3oool2000003T0oooo1P00003;0?ooo`L00000Y@3oool00?l0
ooooMP3oool00`000000oooo0?ooo`0_0?ooo`<00000>@3oool800000<T0oooo1`00002U0?ooo`00
o`3ooomf0?ooo`030000003oool0oooo02l0oooo0`00000i0?ooo`P00000b@3oool700000:D0oooo
003o0?ooogL0oooo0P00000_0?ooo`030000003oool0oooo03D0oooo3000003:0?ooo`D00000YP3o
ool00?l0ooooiP3oool600000?l0ooooMP3oool00?l0ooooiP3oool600000?l0ooooMP3oool00?l0
ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3o
ool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0
ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo
0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS0?ooo`00
o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0ooooo`3ooomS
0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?ooool0oooo
o`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo003o0?oo
ool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?ooof<0oooo
003o0?ooool0ooooo`3ooomS0?ooo`00o`3ooooo0?ooool0ooooH`3oool00?l0ooooo`3ooooo0?oo
of<0oooo0000\
\>"], "Picture",
  Evaluatable->False,
  ImageSize->{166.625, 150.5},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Fig. 5.7 Ray trajectory in a medium with wave speed ",
  Cell[BoxData[
      \(TraditionalForm\`c = c(x)\)]],
  " that decreases to the right."
}], "Caption",
  CellTags->"Fig. 5.7"],

Cell[TextData[{
  "\tIt is interesting that  Snell's law, derived here for a medium that \
varies slowly compared to the wavelength, also applies even for a medium with \
sharp interfaces, such as occurs for light propagating from air to glass. \
What is missing in the WKB theory of this problem is the ",
  StyleBox["reflected ",
    FontSlant->"Italic"],
  " wave from the sharp interface.  Reflections do not occur in the WKB \
approximation, except at turning points where total internal reflection \
occurs. (Turning points are discussed at the end of the next section.) "
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["5.2.2 WKB with Dispersion: Geometrical Optics", "Subsubtitle",
  CellTags->{"i:79", "c:27"}],

Cell[CellGroupData[{

Cell["Wave-Packet Trajectory", "Section",
  CellTags->{"i:80", "c:28"}],

Cell["\<\
\tWhen light travels through a dispersive medium such as glass, the \
phase velocity is given by \
\>", "Text",
  CellTags->"i:124"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`v\_\[Phi] = \(\[Omega]/k\  = 
          c/\(n(x, \[Omega])\)\)\)]],
  ","
}], "NE2",
  CellTags->"(5.2.42)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  " is the speed of light in vacuum and ",
  Cell[BoxData[
      \(TraditionalForm\`n(x, \[Omega])\)]],
  " is the index of refraction of the medium. The index depends on  the \
frequency of the light; for example, in the visible region, the index of \
window glass is an increasing function of frequency.  We would like to \
describe the behavior of a wave packet traveling through such a medium, \
assuming that the refractive index varies little in space compared over a \
wavelength of the light, so that the WKB method is valid."
}], "Text",
  CellTags->"i:113"],

Cell[TextData[{
  "\tThe previous discussion of WKB theory focused on dispersionless systems \
where the phase velocity ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]/k = c(x)\)]],
  " is independent of  frequency ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\)]],
  ".  On the other hand, the Fourier-transformed wave equation ",
  ButtonBox["(5.2.23)",
    ButtonData:>"(5.2.23)",
    ButtonStyle->"Hyperlink"],
  " could also be applied to dispersive systems where ",
  Cell[BoxData[
      \(TraditionalForm\`k(x, \[Omega])\)]],
  " is a general function of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\)]],
  ", given by ",
  Cell[BoxData[
      \(TraditionalForm\`k(
          x, \[Omega]) = \ \[Omega]\ \(n(x, \[Omega])\)/c\)]],
  ". Therefore,  the WKB solution ",
  ButtonBox["(5.2.26)",
    ButtonData:>"(5.2.26)",
    ButtonStyle->"Hyperlink"],
  " applies to dispersive media. Such media have a general dispersion \
relation,  found by inverting the equation ",
  Cell[BoxData[
      \(TraditionalForm\`k = k(x, \[Omega])\)]],
  " in order to obtain the frequency vs. ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  ":",
  Cell[BoxData[
      FormBox[Cell[""], TraditionalForm]]]
}], "Text",
  CellTags->"i:129"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[Omega]\  = \ \[Omega](x, k)\)]]], "NE2",
  CellTags->"(5.2.43)"],

Cell[TextData[{
  "\tLet us assume for simplicity that we are dealing only with a traveling \
wave packet moving to the right, so that we can take ",
  Cell[BoxData[
      \(TraditionalForm\`B = 0\)]],
  " in Eq. ",
  ButtonBox["(5.2.26)",
    ButtonData:>"(5.2.26)",
    ButtonStyle->"Hyperlink"],
  ".  Then one possible approach is to assume that ",
  Cell[BoxData[
      \(TraditionalForm\`A(\[Omega])\)]],
  " is sharply peaked around some frequency ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_o\)]],
  ". [That is, we assume that we are dealing with a wave packet that is \
nearly a single wave of frequency ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_o\)]],
  ",  with an envelope that varies slowly  in time  compared to ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_o\)]],
  ". This is analogous to the discussion of wave packets for homogeneous \
systems in Sec. ",
  ButtonBox["5.1.2",
    ButtonData:>"c:7",
    ButtonStyle->"Hyperlink"],
  ".]  In this case, we can Taylor-expand ",
  Cell[BoxData[
      \(TraditionalForm\`k(x, \[Omega])\)]],
  " about ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_o\)]],
  ", writing ",
  Cell[BoxData[
      \(TraditionalForm\`k(x, \[Omega]) \[TildeEqual] 
        k(x, \[Omega]\_o) + \((\[Omega] - \[Omega]\_o)\) \[PartialD]\(k(
                  x, \[Omega]\_o)\)/\[PartialD]\[Omega]\_o\)]],
  ".Using this expansion in Eq. ",
  ButtonBox["(5.2.26)",
    ButtonData:>"(5.2.26)",
    ButtonStyle->"Hyperlink"],
  ", we obtain"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`y(x, 
          t) = \(\[ExponentialE]\^\(\[ImaginaryI](\ \[Integral]\^x\( k(x, \
\[Omega]\_o)\) \[DifferentialD]x - \(\[Omega]\_o\) \(\[Integral]\^x\(\
\[PartialD]\(k(x, \[Omega]\_o)\)\/\[PartialD]\[Omega]\_o\) \
\[DifferentialD]x\))\)\/\@\(k(x, \[Omega]\_o)\)\) \(\[Integral]\_\(-\
\[Infinity]\)\%\[Infinity]\(\(\[DifferentialD]\[Omega]\/\(2  \[Pi]\)\) \(A(\
\[Omega])\) \(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Omega][\ 
                      t\  - \ \ \[Integral]\^x\[PartialD]\(k(x, \
\[Omega]\_o)\)\/\[PartialD]\[Omega]\_o\ \[DifferentialD]x\ ]\)\)\(\ \
\)\)\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "If we now introduce the function ",
  Cell[BoxData[
      \(TraditionalForm\`f(
          t)\  = \[Integral]\_\(-\[Infinity]\)\%\[Infinity]\(\(\
\[DifferentialD]\[Omega]\/\(2  \[Pi]\)\) \(A(\[Omega])\) \
\(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Omega]\ t\)\)\(\ \)\)\)]],
  ", this equation becomes "
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(\(y(x, 
        t)\  = \(\[ExponentialE]\^\(\[ImaginaryI](\ \[Integral]\^x\( k(x, \
\[Omega]\_o)\) \[DifferentialD]x - \(\[Omega]\_o\) \(\[Tau](x, \
\[Omega]\_o)\))\)\/\@\(k(x, \[Omega]\_o)\)\) \(f(
          t - \[Tau](x, \[Omega]\_o))\)\)\(\ \)\(,\)\)\)]]], "NE2",
  CellTags->"(5.2.44)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau](
          x, \[Omega]\_o)\  = \[Integral]\^x\[PartialD]\(k(x, \
\[Omega]\_o)\)\/\[PartialD]\[Omega]\_o\ \(\(\[DifferentialD]x\)\(\ \)\)\)]],
  ". The function ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau](x, \[Omega]\_o)\)]],
  " determines the time for the wave packet to propagate to position ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ", or more precisely, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Tau](x\_2, \[Omega]\_o) - \[Tau](
          x\_1, \[Omega]\_o)\)]],
  " is the time required to propagate from position ",
  Cell[BoxData[
      \(TraditionalForm\`x\_1\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`x\_2\)]],
  ". This can be seen by noting that the function ",
  Cell[BoxData[
      \(TraditionalForm\`k = k(x, \[Omega])\)]],
  " can be inverted to obtain the dispersion relation for the waves, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega] = \[Omega](x, k)\)]],
  ". Then the following identity holds:"
}], "Text"],

Cell[TextData[{
  "\t\t ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(\[PartialD]\(k(
                    x, \[Omega]\_o)\)\/\[PartialD]\[Omega]\_o\) \[PartialD]\(\
\[Omega](x, k)\)\/\[PartialD]k\)\( | \_\(k = k(x, \[Omega]\_o)\)\)\) = 1\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "However, this implies that ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\(k(x, \
\[Omega]\_o)\)\/\[PartialD]\[Omega]\_o = 1/\(\(v\_g\)(x, \[Omega]\_o)\)\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`\(v\_g\)(
          x, \[Omega]\_o) = \(\(\[PartialD]\(\[Omega](x, 
                  k)\)\/\[PartialD]k\)\( | \_\(k = 
                k(x, \[Omega]\_o)\)\)\)\)]],
  " is the local group velocity of a wave packet with central frequency ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_o\)]],
  ", given by Eq. ",
  ButtonBox["(5.1.28)",
    ButtonData:>"(5.1.28)",
    ButtonStyle->"Hyperlink"],
  ".  Thus, we can write"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Tau](
          x, \[Omega]\_o)\  = \[Integral]\^x\ \(\(\[DifferentialD]x\)\(\ \)\)\
\/\(\(v\_g\)(x, \[Omega]\_o)\)\)]],
  ", "
}], "NE2",
  CellTags->"(5.2.45)"],

Cell[TextData[{
  "which is clearly the time required to travel to position ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " for a ",
  "wave packet",
  " of constant frequency ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_o\)]],
  " traveling with the given group velocity ",
  Cell[BoxData[
      \(TraditionalForm\`\(v\_g\)(x, \[Omega]\_o)\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\tAlthough the central frequency ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_o\)]],
  " of the wave packet is a constant parameter, determined by ",
  Cell[BoxData[
      \(TraditionalForm\`A(\[Omega])\)]],
  ", the central wavenumber is not; the wavenumber varies slowly in space \
according to  ",
  Cell[BoxData[
      \(TraditionalForm\`k = k(x, \[Omega]\_o)\)]],
  ". It is useful to consider the time variation of ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  " as one follows along with a wave packet with given central frequency ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\)]],
  ". (We drop the subscript on ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_o\)]],
  " to simplify the notation in what follows.)  Taking a time derivative  of \
",
  Cell[BoxData[
      \(TraditionalForm\`k = k(x, \[Omega])\)]],
  " and using the chain rule, we have ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]k/\[DifferentialD]t\  = \((\
\[DifferentialD]x/\[DifferentialD]t)\)\ \[PartialD]\(k(
                x, \[Omega])\)/\[PartialD]x\)]],
  ". However, we have seen that the packet moves at the group velocity, so \
its position satisfies"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\(\(\[DifferentialD]x/\[DifferentialD]t = \
\[PartialD]\(\[Omega](x, k)\)\/\[PartialD]k\)\(,\)\)\)]]], "NE2",
  CellTags->"(5.2.46)"],

Cell[TextData[{
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega](x, k)\)]],
  " is the wave frequency, determined as a function of ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  " by the dispersion relation ",
  ButtonBox["(5.2.43)",
    ButtonData:>"(5.2.43)",
    ButtonStyle->"Hyperlink"],
  ". Therefore, the central wavenumber of the packet satisfies"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]k/\[DifferentialD]t\  = \(\(\
\[PartialD]\(\[Omega](x, 
                    k)\)\/\[PartialD]k\) \[PartialD]\(k(x, \[Omega])\)\/\
\[PartialD]x = \(-\(\[PartialD]\(\[Omega](x, k)\)\/\[PartialD]x\)\)\)\)]],
  ","
}], "NE2",
  CellTags->"(5.2.47)"],

Cell[TextData[{
  "where the second equality follows from a standard identity for \
differentials. Equations ",
  ButtonBox["(5.2.46)",
    ButtonData:>"(5.2.46)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(5.2.47)",
    ButtonData:>"(5.2.47)",
    ButtonStyle->"Hyperlink"],
  " are  coupled first-order ODEs for the evolution of the central wavenumber \
and position of a WKB wave packet. If we know ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  " at some initial time, these ODEs can be used to find  ",
  Cell[BoxData[
      \(TraditionalForm\`x(t)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`k(t)\)]],
  " for all time.  These equations are called the equations of ",
  StyleBox["geometrical optics",
    FontSlant->"Italic"],
  ". We will see later, in Sec. ",
  ButtonBox["5.3",
    ButtonData:>"c:32",
    ButtonStyle->"Hyperlink"],
  ", that the equations can be generalized to wave-packet motion in two or \
more dimensions, according to "
}], "Text",
  CellTags->"i:81"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{
              RowBox[{"\[DifferentialD]", 
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"]}], "/", \(\[DifferentialD]t\)}], "=", 
            RowBox[{
              RowBox[{"\[PartialD]", 
                RowBox[{"\[Omega]", "(", 
                  RowBox[{
                    StyleBox["r",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], ",", 
                    StyleBox["k",
                      FontWeight->"Bold",
                      FontSlant->"Plain"]}], ")"}]}], "/", 
              RowBox[{"\[PartialD]", 
                StyleBox["k",
                  FontWeight->"Bold",
                  FontSlant->"Plain"]}]}]}], ","}], TraditionalForm]]],
  "\n",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{"\[DifferentialD]", 
              StyleBox["k",
                FontWeight->"Bold",
                FontSlant->"Plain"]}], "/", \(\[DifferentialD]t\)}], " ", "=",
           
          RowBox[{
            RowBox[{"-", 
              RowBox[{"\[PartialD]", 
                RowBox[{"\[Omega]", "(", 
                  RowBox[{
                    StyleBox["r",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], ",", 
                    StyleBox["k",
                      FontWeight->"Bold",
                      FontSlant->"Plain"]}], ")"}]}]}], "/", 
            RowBox[{"\[PartialD]", 
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"]}]}]}], TraditionalForm]]],
  ","
}], "NE2",
  CellTags->"(5.2.48)"],

Cell[TextData[{
  "\tIf we compare this with Eqs. ",
  ButtonBox["(1.2.15)",
    ButtonData:>{"Chapter1.nb", "(1.2.15)"},
    ButtonStyle->"Hyperlink"],
  ", we see that  these ODEs have a Hamiltonian form, with ",
  Cell[BoxData[
      FormBox[
        StyleBox["k",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " taking the role of the momentum ",
  Cell[BoxData[
      FormBox[
        StyleBox["p",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " and the frequency ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Omega]", "(", 
          RowBox[{
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], ",", 
            StyleBox["k",
              FontWeight->"Bold",
              FontSlant->"Plain"]}], ")"}], TraditionalForm]]],
  " taking the role of the Hamiltonian ",
  Cell[BoxData[
      FormBox[
        RowBox[{"H", "(", 
          RowBox[{
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], ",", 
            StyleBox["p",
              FontWeight->"Bold",
              FontSlant->"Plain"]}], ")"}], TraditionalForm]]],
  ". Thus, the fact that the central frequency ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\)]],
  " of the wave packet is constant in time during the evolution of the wave \
packet  corresponds to the fact that energy is conserved for time-independent \
Hamiltonians. "
}], "Text",
  CellTags->"i:114"],

Cell[TextData[{
  "\tAlso, for wave packet motion in the ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  "-",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " plane,  if  ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Omega]", "=", 
          RowBox[{"\[Omega]", "(", 
            RowBox[{"x", ",", 
              StyleBox["k",
                FontWeight->"Bold",
                FontSlant->"Plain"]}], 
            StyleBox[")",
              FontWeight->"Plain"]}]}], TraditionalForm]]],
  " , then Eq. ",
  ButtonBox["(5.2.48)",
    ButtonData:>"(5.2.48)",
    ButtonStyle->"Hyperlink"],
  " implies that ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]k\_y/\[DifferentialD]t\  = 0\)]],
  ": the y-component of the central wavenumber for the packet is a constant \
of the motion. This is  equivalent to the conservation of the ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  "-component of momentum when the Hamiltonian is ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  "-independent. "
}], "Text"],

Cell[TextData[{
  "\tThe trajectory of a wave packet moving in the ",
  Cell[BoxData[
      \(TraditionalForm\`x - y\)]],
  " plane is given by dividing the ratio of the ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " components of ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{"\[DifferentialD]", 
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"]}], "/", \(\[DifferentialD]t\)}], "=", 
          RowBox[{\(\[PartialD]\[Omega]\), "/", 
            RowBox[{"\[PartialD]", 
              StyleBox["k",
                FontWeight->"Bold",
                FontSlant->"Plain"]}]}]}], TraditionalForm]]],
  ":"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(\[DifferentialD]y/\[DifferentialD]t\)\/\(\
\[DifferentialD]x/\[DifferentialD]t\) = \
\(\[DifferentialD]y\/\[DifferentialD]x = \(\(k\_y | v\_g | \(\(/\)\(k\)\)\)\/\
\(k\_x | v\_g | \(\(/\)\(k\)\)\) = k\_y\/k\_x\)\)\)]],
  ","
}], "NE2",
  CellTags->"(5.2.49)"],

Cell[TextData[{
  "where in the second step we assumed that the medium is isotropic, and used \
Eq. ",
  ButtonBox["(5.1.43)",
    ButtonData:>"(5.1.43)",
    ButtonStyle->"Hyperlink"],
  " for the group velocity. This ODE is identical to the equation for ray \
trajectories, Eq. ",
  ButtonBox["(5.2.40)",
    ButtonData:>"(5.2.40)",
    ButtonStyle->"Hyperlink"],
  ". (Recall that ray trajectories describe the propagation of phase fronts, \
as opposed to the propagation of the wave packet.) Therefore, in an isotropic \
medium the trajectory of the center of a wave packet with central frequency \
",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\)]],
  " is identical to the trajectory of a ray with the same initial direction \
and the same frequency.",
  StyleBox[" ",
    FontSlant->"Italic"],
  "This is because the phase and group velocities in an isotropic medium are \
in the same direction, along ",
  Cell[BoxData[
      FormBox[
        StyleBox["k",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  ": see Eqs. ",
  ButtonBox["(5.1.41)",
    ButtonData:>"(5.1.41)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(5.1.43)",
    ButtonData:>"(5.1.43)",
    ButtonStyle->"Hyperlink"],
  ". (However, the time required to propagate to a given point along the \
trajectory will generally differ in the two cases, because the magnitude of \
the phase and group velocities need not be the same.) Later in the chapter, \
we will consider anisotropic media where the ray and wave-packet trajectories \
are completely different."
}], "Text"],

Cell[TextData[{
  "Ray trajectories trace out the path followed by points of constant phase \
(points on phase fronts). Wave-packet trajectories trace out the path \
followed by ",
  "wave packet",
  "s.  For a given frequency and initial propagation direction,  in an \
isotropic medium for which ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Omega]", "=", 
          RowBox[{"\[Omega]", "(", 
            RowBox[{
              RowBox[{"|", 
                StyleBox["k",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "|"}], 
              StyleBox[",",
                FontWeight->"Plain"], 
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"]}], 
            StyleBox[")",
              FontWeight->"Plain"]}]}], TraditionalForm]]],
  ", the two trajectories are the same. "
}], "Text",
  CellFrame->True,
  Background->GrayLevel[0.849989],
  CellTags->"i:82"],

Cell[TextData[{
  "\tOf course, a wave packet contains a spread of frequencies, and this \
leads to dispersion: different frequency components travel with different \
phase velocities, in different directions.  We will not consider wave-packet \
dispersion in an inhomogeneous medium in any detail here. For the most part, \
the qualitative features of the dispersion are the same as for a homogeneous \
medium. Around any given wave-packet trajectory [a solution to Eq. ",
  ButtonBox["(5.2.48)",
    ButtonData:>"(5.2.48)",
    ButtonStyle->"Hyperlink"],
  "], the wave packet spreads in both the transverse and longitudinal \
directions.  "
}], "Text"],

Cell[TextData[{
  "\t  However, there is one novel dispersive effect in an inhomogeneous \
medium. Recall that transverse dispersion is weak for a collimated beam that \
is sufficiently broad compared to its wavelength: the Rayleigh length becomes \
very large [Eq. ",
  ButtonBox["(5.1.56)",
    ButtonData:>"(5.1.56)",
    ButtonStyle->"Hyperlink"],
  "]. In such a beam, different frequency components are all traveling in the \
same direction. However, in an inhomogeneous dispersive medium, transverse \
dispersion can occur even if all the rays in a packet are initially \
propagating in the same direction. This transverse dispersion is responsible \
for the rainbow spectrum that occurs when a ray of white light is bent \
through a prism.  "
}], "Text"],

Cell[TextData[{
  "\tOne can see this effect qualitatively by following the ray trajectories \
for different-frequency rays as they propagate through an inhomogeneous  \
medium with a frequency-dependent refractive index ",
  Cell[BoxData[
      \(TraditionalForm\`n(x, \[Omega])\)]],
  ". According to Eq. ",
  ButtonBox["(5.2.49)",
    ButtonData:>"(5.2.49)",
    ButtonStyle->"Hyperlink"],
  ", rays with different frequencies take different paths, even if they start \
in the same direction. This may be seen explicitly by noting that ",
  Cell[BoxData[
      \(TraditionalForm\`k\_y\)]],
  "  is constant in Eq. ",
  ButtonBox["(5.2.49)",
    ButtonData:>"(5.2.49)",
    ButtonStyle->"Hyperlink"],
  "  and ",
  Cell[BoxData[
      \(TraditionalForm\`k\_x\)]],
  " is determined by the equation ",
  Cell[BoxData[
      \(TraditionalForm\`k = \(\@\(k\_x\^2 + k\_y\^2\) = \[Omega]\ \(n(
                x, \[Omega])\)/c\)\)]],
  ".  The second equality follows from the dispersion relation for these \
waves, Eq. ",
  ButtonBox["(5.2.42)",
    ButtonData:>"(5.2.42)",
    ButtonStyle->"Hyperlink"],
  ". Solving this equation for ",
  Cell[BoxData[
      \(TraditionalForm\`k\_x\)]],
  " yields ",
  Cell[BoxData[
      \(TraditionalForm\`k\_x = \@\(\((\[Omega]\ \(n(x, \[Omega])\)/c)\)\^2 - \
k\_y\^2\)\)]],
  ".  Then the ray equation becomes"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]y\/\[DifferentialD]x = 
        1\/\@\(\((\[Omega]\ \(n(x, \[Omega])\)/c\ k\_y)\)\^2 - 1\)\)]],
  ","
}], "Text"],

Cell["which has the solution ", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`y(x)\  = \ 
        y(0)\  + \ \[Integral]\_0\%x\( 
                  1\/\@\(\((\[Omega]\ \(n(x, \[Omega])\)/c\ k\_y)\)\^2 - \
1\)\) \[DifferentialD]x\)]],
  "."
}], "NE2",
  CellTags->"(5.2.50)"],

Cell[TextData[{
  "For example, if the index of refraction is  ",
  Cell[BoxData[
      \(TraditionalForm\`n(x, \[Omega])\  = \ 1\  - \ \[Omega]\ x\^2/a\)]],
  " for some constant ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  ", then we can find the ray trajectory for a given frequency ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\)]],
  " by evaluating the above integral.  Let us  assume that all the rays are \
initially propagating at ",
  Cell[BoxData[
      \(TraditionalForm\`45  \[Degree]\)]],
  "with respect to the horizontal, so that ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]y/\[DifferentialD]x = 1\)]],
  " at ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`n = 1\)]],
  "; then Eq. ",
  ButtonBox["(5.2.50)",
    ButtonData:>"(5.2.50)",
    ButtonStyle->"Hyperlink"],
  " (or Eq. ",
  ButtonBox["(5.2.49)",
    ButtonData:>"(5.2.49)",
    ButtonStyle->"Hyperlink"],
  " ) implies that ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[Omega]/c\ k\_y\ )\)\^2 = \ 2\)]],
  ", and we have "
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(\(Clear["\<Global`*\>"];\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(\(\(n[x_, \[Omega]_]\  = \ 1\  - \ x\^2\ \[Omega]/a;\)\(\n\)
    \)\), "\[IndentingNewLine]", 
    \(y[x_, \[Omega]_]\ \  = \ 
      Integrate[1/Sqrt[2\ n[x1, \[Omega]]^2\  - \ 1], {x1, 0, x}]\)}], "Input",\

  ShowCellTags->True,
  CellTags->"Cell 5.27"],

Cell[BoxData[
    \(\(-\(\(\[ImaginaryI]\ \@\(1 - \(2\ x\^2\ \[Omega]\)\/\(2\ a - \@2\ \
a\)\)\ \@\(1 - \(2\ x\^2\ \[Omega]\)\/\(2\ a + \@2\ a\)\)\ EllipticF[\
\[ImaginaryI]\ ArcSinh[\@2\ x\ \@\(-\(\[Omega]\/\(2\ a - \@2\ a\)\)\)], \(2\ \
a - \@2\ a\)\/\(2\ a + \@2\ a\)]\)\/\(\@2\ \@\(-\(\[Omega]\/\(2\ a - \@2\ a\)\
\)\)\ \@\(\(-1\) + 2\ \((1 - \(x\^2\ \[Omega]\)\/a)\)\^2\)\)\)\)\)], "Output"]
}, Open  ]],

Cell[TextData[{
  " This solution is plotted in Fig. ",
  ButtonBox["5.8",
    ButtonData:>"Fig. 5.8",
    ButtonStyle->"Hyperlink"],
  ", taking ",
  Cell[BoxData[
      \(TraditionalForm\`a = 1\)]],
  "  for three rays with ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega] = 1, 2, \)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`3\)]],
  "."
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0 1 0 1 [
[.2 -0.0125 -9 -9 ]
[.2 -0.0125 9 0 ]
[.4 -0.0125 -9 -9 ]
[.4 -0.0125 9 0 ]
[.6 -0.0125 -9 -9 ]
[.6 -0.0125 9 0 ]
[.8 -0.0125 -9 -9 ]
[.8 -0.0125 9 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[-0.0125 .2 -18 -4.5 ]
[-0.0125 .2 0 4.5 ]
[-0.0125 .4 -18 -4.5 ]
[-0.0125 .4 0 4.5 ]
[-0.0125 .6 -18 -4.5 ]
[-0.0125 .6 0 4.5 ]
[-0.0125 .8 -18 -4.5 ]
[-0.0125 .8 0 4.5 ]
[-0.0125 1 -6 -4.5 ]
[-0.0125 1 0 4.5 ]
[0 1.025 -5 0 ]
[0 1.025 5 12 ]
[ 0 0 0 0 ]
[ 1 1 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 0 m
.2 .00625 L
s
[(0.2)] .2 -0.0125 0 1 Mshowa
.4 0 m
.4 .00625 L
s
[(0.4)] .4 -0.0125 0 1 Mshowa
.6 0 m
.6 .00625 L
s
[(0.6)] .6 -0.0125 0 1 Mshowa
.8 0 m
.8 .00625 L
s
[(0.8)] .8 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(1)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.05 0 m
.05 .00375 L
s
.1 0 m
.1 .00375 L
s
.15 0 m
.15 .00375 L
s
.25 0 m
.25 .00375 L
s
.3 0 m
.3 .00375 L
s
.35 0 m
.35 .00375 L
s
.45 0 m
.45 .00375 L
s
.5 0 m
.5 .00375 L
s
.55 0 m
.55 .00375 L
s
.65 0 m
.65 .00375 L
s
.7 0 m
.7 .00375 L
s
.75 0 m
.75 .00375 L
s
.85 0 m
.85 .00375 L
s
.9 0 m
.9 .00375 L
s
.95 0 m
.95 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .2 m
.00625 .2 L
s
[(0.2)] -0.0125 .2 1 0 Mshowa
0 .4 m
.00625 .4 L
s
[(0.4)] -0.0125 .4 1 0 Mshowa
0 .6 m
.00625 .6 L
s
[(0.6)] -0.0125 .6 1 0 Mshowa
0 .8 m
.00625 .8 L
s
[(0.8)] -0.0125 .8 1 0 Mshowa
0 1 m
.00625 1 L
s
[(1)] -0.0125 1 1 0 Mshowa
.125 Mabswid
0 .05 m
.00375 .05 L
s
0 .1 m
.00375 .1 L
s
0 .15 m
.00375 .15 L
s
0 .25 m
.00375 .25 L
s
0 .3 m
.00375 .3 L
s
0 .35 m
.00375 .35 L
s
0 .45 m
.00375 .45 L
s
0 .5 m
.00375 .5 L
s
0 .55 m
.00375 .55 L
s
0 .65 m
.00375 .65 L
s
0 .7 m
.00375 .7 L
s
0 .75 m
.00375 .75 L
s
0 .85 m
.00375 .85 L
s
0 .9 m
.00375 .9 L
s
0 .95 m
.00375 .95 L
s
.25 Mabswid
0 0 m
0 1 L
s
gsave
0 1.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1 L
0 1 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
0 0 m
.04057 .04059 L
.08481 .08501 L
.12636 .12704 L
.16632 .16788 L
.20885 .21199 L
.2498 .25525 L
.29331 .30232 L
.33524 .34899 L
.37557 .39542 L
.41848 .44683 L
.4598 .49879 L
.49953 .55161 L
.54183 .61182 L
.58254 .67488 L
.62583 .74966 L
.66752 .8332 L
.70762 .93239 L
.72828 .99748 L
s
.72828 .99748 m
.72886 1 L
s
0 1 0 r
0 0 m
.04057 .04061 L
.08481 .08522 L
.12636 .12774 L
.16632 .16952 L
.20885 .21536 L
.2498 .2613 L
.29331 .31278 L
.33524 .36589 L
.37557 .42155 L
.41848 .48801 L
.4598 .56346 L
.49953 .65694 L
.50998 .68842 L
.51991 .7237 L
.52538 .74677 L
.53136 .77716 L
.53399 .7935 L
.53679 .81468 L
.53815 .82749 L
.53943 .84258 L
.54059 .86232 L
.54183 .89058 L
.54313 .89058 L
.54432 .89058 L
.54569 .89058 L
.54699 .89058 L
.54819 .89058 L
.5493 .89058 L
.55051 .89058 L
.55181 .89058 L
.55311 .89058 L
.55434 .89058 L
.55504 .89058 L
.55579 .89058 L
.55712 .89058 L
.5578 .89058 L
.55853 .89058 L
.55985 .89058 L
.56065 .89058 L
.56138 .89058 L
.56277 .89058 L
.56403 .89058 L
.56475 .89058 L
.56542 .89058 L
.56678 .89058 L
.56754 .89058 L
.56824 .89058 L
.56949 .89058 L
.57085 .89058 L
Mistroke
.57214 .89058 L
.57333 .89058 L
.57472 .89058 L
.5755 .89058 L
.57621 .89058 L
.57753 .89058 L
.5782 .89058 L
.57893 .89058 L
.57971 .89058 L
.58054 .89058 L
.58132 .89058 L
.58205 .89058 L
.58276 .89058 L
.58354 .89058 L
.58488 .89058 L
.58608 .89058 L
.58734 .89058 L
.58873 .89058 L
.58999 .89058 L
.59118 .89058 L
.59228 .89058 L
.59349 .89058 L
.59478 .89058 L
.59547 .89058 L
.59619 .89058 L
.59699 .89058 L
.59772 .89058 L
.59905 .89058 L
.5998 .89058 L
.6005 .89058 L
.60181 .89058 L
.603 .89058 L
.60438 .89058 L
.60569 .89058 L
.60695 .89058 L
.60767 .89058 L
.60835 .89058 L
.60971 .89058 L
.61047 .89058 L
.61118 .89058 L
.61236 .89058 L
.61365 .89058 L
.615 .89058 L
.61626 .89058 L
.61697 .89058 L
.61775 .89058 L
.61849 .89058 L
.61917 .89058 L
.62045 .89058 L
.62182 .89058 L
Mistroke
.62252 .89058 L
.62328 .89058 L
.62465 .89058 L
.62776 .89058 L
.62913 .89058 L
.63043 .89058 L
.63114 .89058 L
.63192 .89058 L
.63327 .89058 L
.63456 .89058 L
.63593 .89058 L
.6371 .89058 L
.63838 .89058 L
.63916 .89058 L
.63989 .89058 L
.64127 .89058 L
.64205 .89058 L
.64276 .89058 L
.64354 .89058 L
.64437 .89058 L
.64703 .89058 L
.64776 .89058 L
.64855 .89058 L
.64929 .89058 L
.64997 .89058 L
.6512 .89058 L
.65251 .89058 L
.65375 .89058 L
.65488 .89058 L
.6562 .89058 L
.65695 .89058 L
.65764 .89058 L
.66025 .89058 L
.67107 .89058 L
.71246 .89058 L
.75226 .89058 L
.7577 .89058 L
.75919 .89058 L
.76078 .89058 L
.76155 .89058 L
.76227 .89058 L
.76363 .89058 L
.76494 .89058 L
.76633 .89058 L
.76753 .89058 L
.76881 .89058 L
.7702 .89058 L
.77149 .89058 L
.77227 .89058 L
.77302 .89058 L
Mistroke
.77369 .89058 L
.77441 .89058 L
.77567 .89058 L
.77684 .89058 L
.77813 .89058 L
.77952 .89058 L
.78021 .89058 L
.78097 .89058 L
.78234 .89058 L
.78493 .89058 L
.79464 .89058 L
.79597 .89058 L
.79672 .89058 L
.7974 .89058 L
.79867 .89058 L
.80001 .89058 L
.80121 .89058 L
.80233 .89058 L
.80356 .89058 L
.80488 .89058 L
.8056 .89058 L
.80628 .89058 L
.80702 .89058 L
.80781 .89058 L
.80913 .89058 L
.80988 .89058 L
.81058 .89058 L
.81189 .89058 L
.81309 .89058 L
.8144 .89058 L
.81579 .89058 L
.81702 .89058 L
.81814 .89058 L
.82065 .89058 L
.82517 .89058 L
.8264 .89058 L
.8277 .89058 L
.82838 .89058 L
.82913 .89058 L
.83044 .89058 L
.83543 .89058 L
.85584 .89058 L
.8572 .89058 L
.85796 .89058 L
.85865 .89058 L
.85947 .89058 L
.86024 .89058 L
.86095 .89058 L
.86172 .89058 L
.86239 .89058 L
Mistroke
.86313 .89058 L
.8639 .89058 L
.86462 .89058 L
.86592 .89058 L
.8673 .89058 L
.86865 .89058 L
.86941 .89058 L
.87011 .89058 L
.87141 .89058 L
.87278 .89058 L
.874 .89058 L
.87515 .89058 L
.87641 .89058 L
.87777 .89058 L
.89885 .89058 L
.90944 .89058 L
.91015 .89058 L
.91093 .89058 L
.91166 .89058 L
.91234 .89058 L
.91313 .89058 L
.91396 .89058 L
.91466 .89058 L
.91544 .89058 L
.91616 .89058 L
.91683 .89058 L
.91832 .89058 L
.9197 .89058 L
.92101 .89058 L
.9222 .89058 L
.92349 .89058 L
.9247 .89058 L
.92581 .89058 L
.92705 .89058 L
.9284 .89058 L
.93112 .89058 L
.94188 .89058 L
.96121 .89058 L
1 .89058 L
Mfstroke
0 0 1 r
0 0 m
.04057 .04063 L
.08481 .08543 L
.12636 .12845 L
.16632 .17123 L
.20885 .21899 L
.2498 .2681 L
.29331 .32525 L
.33524 .38787 L
.37557 .46036 L
.39599 .50546 L
.41848 .56901 L
.42377 .58806 L
.42955 .61237 L
.43219 .62539 L
.435 .64142 L
.43765 .65996 L
.44006 .68304 L
.44129 .70194 L
.44244 .72715 L
.44363 .72715 L
.44494 .72715 L
.44627 .72715 L
.44702 .72715 L
.4477 .72715 L
.44899 .72715 L
.45023 .72715 L
.45138 .72715 L
.45261 .72715 L
.45367 .72715 L
.45481 .72715 L
.45604 .72715 L
.45718 .72715 L
.45855 .72715 L
.4598 .72715 L
.46099 .72715 L
.46226 .72715 L
.46346 .72715 L
.46454 .72715 L
.46582 .72715 L
.46721 .72715 L
.46852 .72715 L
.46973 .72715 L
.47098 .72715 L
.47215 .72715 L
.47343 .72715 L
.47481 .72715 L
.4755 .72715 L
.47625 .72715 L
.47762 .72715 L
Mistroke
.47895 .72715 L
.48018 .72715 L
.48156 .72715 L
.48234 .72715 L
.48305 .72715 L
.48437 .72715 L
.48575 .72715 L
.487 .72715 L
.48816 .72715 L
.48944 .72715 L
.4908 .72715 L
.49156 .72715 L
.49226 .72715 L
.49303 .72715 L
.49384 .72715 L
.49521 .72715 L
.49599 .72715 L
.49672 .72715 L
.49807 .72715 L
.49931 .72715 L
.50067 .72715 L
.50136 .72715 L
.5021 .72715 L
.50278 .72715 L
.5035 .72715 L
.50478 .72715 L
.50616 .72715 L
.50694 .72715 L
.50767 .72715 L
.509 .72715 L
.5102 .72715 L
.51087 .72715 L
.5116 .72715 L
.51292 .72715 L
.51419 .72715 L
.51539 .72715 L
.51664 .72715 L
.51802 .72715 L
.5192 .72715 L
.52029 .72715 L
.52148 .72715 L
.52274 .72715 L
.52411 .72715 L
.52537 .72715 L
.52818 .72715 L
.52943 .72715 L
.53078 .72715 L
.53205 .72715 L
.53324 .72715 L
.53463 .72715 L
Mistroke
.53536 .72715 L
.53615 .72715 L
.53697 .72715 L
.53776 .72715 L
.53847 .72715 L
.53923 .72715 L
.5406 .72715 L
.54187 .72715 L
.54265 .72715 L
.54338 .72715 L
.54475 .72715 L
.54597 .72715 L
.54728 .72715 L
.54852 .72715 L
.54964 .72715 L
.55096 .72715 L
.55171 .72715 L
.5524 .72715 L
.55367 .72715 L
.55501 .72715 L
.55629 .72715 L
.55767 .72715 L
.55897 .72715 L
.56016 .72715 L
.56293 .72715 L
.56432 .72715 L
.56511 .72715 L
.56585 .72715 L
.56706 .72715 L
.56838 .72715 L
.56954 .72715 L
.57076 .72715 L
.57187 .72715 L
.57309 .72715 L
.57523 .72715 L
.57651 .72715 L
.57773 .72715 L
.5784 .72715 L
.57913 .72715 L
.58041 .72715 L
.58525 .72715 L
.60769 .72715 L
.60898 .72715 L
.61036 .72715 L
.61166 .72715 L
.61284 .72715 L
.61418 .72715 L
.61544 .72715 L
.6168 .72715 L
.61757 .72715 L
Mistroke
.61828 .72715 L
.623 .72715 L
.62538 .72715 L
.62673 .72715 L
.628 .72715 L
.62932 .72715 L
.63057 .72715 L
.63169 .72715 L
.63291 .72715 L
.63424 .72715 L
.63498 .72715 L
.63566 .72715 L
.63697 .72715 L
.6382 .72715 L
.63954 .72715 L
.64021 .72715 L
.64096 .72715 L
.64227 .72715 L
.64349 .72715 L
.64423 .72715 L
.64494 .72715 L
.64625 .72715 L
.64699 .72715 L
.64767 .72715 L
.64921 .72715 L
.66916 .72715 L
.67414 .72715 L
.67665 .72715 L
.67734 .72715 L
.67807 .72715 L
.67939 .72715 L
.68013 .72715 L
.68094 .72715 L
.6817 .72715 L
.6824 .72715 L
.68373 .72715 L
.6844 .72715 L
.68514 .72715 L
.68646 .72715 L
.68719 .72715 L
.68787 .72715 L
.68918 .72715 L
.69042 .72715 L
.69168 .72715 L
.69282 .72715 L
.69537 .72715 L
.69997 .72715 L
.71038 .72715 L
.71157 .72715 L
.71285 .72715 L
Mistroke
.71405 .72715 L
.71515 .72715 L
.71639 .72715 L
.71756 .72715 L
.71882 .72715 L
.72019 .72715 L
.72085 .72715 L
.72158 .72715 L
.72235 .72715 L
.72306 .72715 L
.72434 .72715 L
.72572 .72715 L
.72701 .72715 L
.72837 .72715 L
.72953 .72715 L
.73079 .72715 L
.73209 .72715 L
.73332 .72715 L
.73442 .72715 L
.73561 .72715 L
.73691 .72715 L
.73829 .72715 L
.74075 .72715 L
.74288 .72715 L
.74405 .72715 L
.74516 .72715 L
.74647 .72715 L
.74766 .72715 L
.74878 .72715 L
.75 .72715 L
.75978 .72715 L
.76245 .72715 L
.7638 .72715 L
.76457 .72715 L
.76528 .72715 L
.76655 .72715 L
.76772 .72715 L
.77032 .72715 L
.77628 .72715 L
.7819 .72715 L
.78443 .72715 L
.78712 .72715 L
.78852 .72715 L
.78931 .72715 L
.79006 .72715 L
.79137 .72715 L
.79211 .72715 L
.79278 .72715 L
.79411 .72715 L
.79531 .72715 L
Mistroke
.79598 .72715 L
.7967 .72715 L
.79802 .72715 L
.79925 .72715 L
.80055 .72715 L
.80288 .72715 L
.81389 .72715 L
.83396 .72715 L
.84392 .72715 L
.85459 .72715 L
.85707 .72715 L
.85774 .72715 L
.85847 .72715 L
.85976 .72715 L
.86096 .72715 L
.86209 .72715 L
.86333 .72715 L
.86466 .72715 L
.86587 .72715 L
.86699 .72715 L
.86817 .72715 L
.86945 .72715 L
.87056 .72715 L
.87157 .72715 L
.87384 .72715 L
.89399 .72715 L
.89537 .72715 L
.89684 .72715 L
.89756 .72715 L
.89824 .72715 L
.89951 .72715 L
.90084 .72715 L
.9016 .72715 L
.90229 .72715 L
.90307 .72715 L
.90378 .72715 L
.90535 .72715 L
.90795 .72715 L
.90866 .72715 L
.90941 .72715 L
.91075 .72715 L
.91201 .72715 L
.91317 .72715 L
.91446 .72715 L
.91583 .72715 L
.91711 .72715 L
.91785 .72715 L
.91853 .72715 L
.91991 .72715 L
.92069 .72715 L
Mistroke
.9214 .72715 L
.92654 .72715 L
.92792 .72715 L
.92869 .72715 L
.92939 .72715 L
.93022 .72715 L
.93101 .72715 L
.93251 .72715 L
.93383 .72715 L
.93523 .72715 L
.93596 .72715 L
.93677 .72715 L
.9375 .72715 L
.93818 .72715 L
.93949 .72715 L
.94023 .72715 L
.94092 .72715 L
.94218 .72715 L
.94351 .72715 L
.94471 .72715 L
.94583 .72715 L
.94705 .72715 L
.94838 .72715 L
.94971 .72715 L
.95046 .72715 L
.95116 .72715 L
.9519 .72715 L
.95257 .72715 L
.95335 .72715 L
.95409 .72715 L
.95539 .72715 L
.9566 .72715 L
.95792 .72715 L
.95859 .72715 L
.95932 .72715 L
.96062 .72715 L
.96183 .72715 L
.96316 .72715 L
.9639 .72715 L
.96457 .72715 L
.96581 .72715 L
.96714 .72715 L
.96956 .72715 L
.97893 .72715 L
1 .72715 L
Mfstroke
0 g
gsave
.37 .6 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(w) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
(3) show
81.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 1.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.48 .8 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 1.000 0.000 setrgbcolor
(w) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 1.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 1.000 0.000 setrgbcolor
(2) show
81.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 1.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.77 .95 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(w) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(1) show
81.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Picture",
  ImageSize->{288, 288},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00COooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44oooo
o`Go0000:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B46ooooo`;o000000?o410@
ooooooooool09oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05onk^k_lb
<S;o0000oa0@4?o<c<`0:_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`05
olc<c?lQ8B7o0000ob4Q8Oo<c<`0<_ooool4o`000003oa0@4?oooooooooo017ooooo001=ooooo`05
ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Z
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Oooooo00?o0000ooooooooool0:?oo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05oeEEEOmgMgOooooooiRHV?lQ
8B40:_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B44ooooo`05ob4Q8OnHV9Sooooo
oiRHV?lQ8B40=?ooool00ol0003oooooooooo`0Cooooo`00COooool01Ol@413ooooooooooooooooo
410@00cooooo00?oV9RHob4Q8Oo^k^h0:oooool01Ol@413ooooooooooooooooo410@00_ooooo1Ol0
000Yooooo`05oa0@4?ooooooooooooooool@41002oooool01Ol0003ooooooooooooooooo000002[o
oooo00Go410@oooooooooooooooooa0@400;ooooo`05o`000?ooooooooooooooool00000=?ooool0
0ol0003oooooooooo`0Cooooo`00COooool01Ol0003ooooooooooooooooo000000gooooo00?oV9RH
ob4Q8Oo^k^h0:_ooool01Ol0003ooooooooooooooooo000000_ooooo00CoA4A4omgMgOoooooo0000
:_ooool01Ol0003ooooooooooooooooo000000_ooooo00Go0000oiRHV?ooooooV9RHob4Q8@0Zoooo
o`05o`000?ooooooooooooooool000002oooool01Olb<S;oV9RHoooooonHV9So<S8b03Cooooo00?o
0000ooooooooool04oooool004gooooo00Go0000ooooooooooooooooo`00000>ooooo`03ogMgMomV
IVKooooo02Wooooo00Go0000ooooooooooooooooo`00000;ooooo`04omgMgOmEEEGoooooo`0002[o
oooo00Go0000ooooooooooooooooo`00000;ooooo`05o`000?mEEEGo0000oa0@4?o<c<`0:_ooool0
1Ol0003ooooooooooooooooo000000_ooooo00Goc<c<o`000?l0003o0000olc<c00dooooo`03o`00
0?oooooooooo01?ooooo001=ooooo`05oa0@4?ooooooooooooooool@41003oooool00ol0003ooooo
ooooo`0Xooooo`05oa0@4?ooooooooooooooool@41003?ooool00omgMgOoc<c<o`00000Zooooo`05
oa0@4?ooooooooooooooool@41002oooool00omEEEGoQhN7ooooo`0/ooooo`05oa0@4?oooooooooo
ooooool@41002oooool01Ol@413o^[Zjoooooonj^[[o410@03Cooooo00?o0000ooooooooool04ooo
ool004gooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0;ooooo`05o`000?nj^[[ooooooiRHV?l@4100
:_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?ok^k^odA4A?l00000:_ooool01OmgMgOo
V9RHoooooonHV9SoMgMg00_ooooo00?ogMgMoa0@4?nHV9P0;?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00_ooooo00Go0000okZj^_oooooo^[Zjo`00000dooooo`03o`000?oooooooooo01?ooooo001=
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<02[ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP0=ooooo`03ogMgMol0003ooooo02Wooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP0<ooooo`04olc<c?m4A4Co0000oa0@42[ooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP0;ooooo`05ojVYZOl@413o0000oa0@4?nYZJT0<_ooool00omEEEGoIVIVo`00000Eooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomOooooo`;o00000_ooool2o`0000Cooooo003ooooooeoo
oooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd4ooooo`00oooooomPooooo`04omgMgOl0003o410@
olc<c0Gooooo000Jooooo`03o`00ool0003o00000?oo0000=ol0000<ooooo`04onk^k_lQ8B7o410@
onk^kPGooooo000Jooooo`03o`000?l00?oooooo00gooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0:ooooo`04ob4Q8OmgMgOoMgMgoc8b<PGooooo000Jooooo`03o`000?oooooo003o
03_ooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
03cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`09ooooo`;o00000_ooool2o`00
00Cooooo000Jooooo`04o`000?ooooooooooo`00ooooooooBoooool001[ooooo00Go0000oooooooo
ooooooooo`00o`3ooooood[ooooo000Jooooo`03o`000?oooooooooo00;ooooo00?o003ooooooooo
ool0oooooom7ooooo`006_ooool00ol0003oooooooooo`03ooooo`03o`00oooooooooooo0?oooooo
A_ooool001[ooooo00?o0000ooooooooool01?ooool00ol00?ooooooooooo`3oooooodGooooo000J
ooooo`03o`000?oooooooooo00Gooooo00?o003oooooooooool0oooooom4ooooo`006_ooool00ol0
003oooooooooo`06ooooo`03o`00oooooooooooo0?oooooo@oooool001[ooooo00?o0000oooooooo
ool01oooool00ol00?ooooooooooo`3ooooood;ooooo000Jooooo`03o`000?oooooooooo00Sooooo
00?o003oooooooooool0oooooom1ooooo`006_ooool00ol0003oooooooooo`09ooooo`03o`00oooo
oooooooo0?oooooo@?ooool001[ooooo00?o0000ooooooooool02_ooool00ol00?ooooooooooo`3o
ooooocoooooo000Jooooo`03o`000?oooooooooo00[ooooo00?o003oooooooooool0oooooolooooo
o`006_ooool00ol0003oooooooooo`0;ooooo`03o`00oooooooooooo0?oooooo?_ooool001[ooooo
0_l0000=ooooo`03o`00oooooooooooo0?oooooo?Oooool001[ooooo00?o0000ooooooooool03Ooo
ool00ol00?ooooooooooo`3ooooooccooooo000Jooooo`03o`000?oooooooooo00kooooo00?o003o
ooooooooool0oooooolkooooo`006_ooool00ol0003oooooooooo`0?ooooo`03o`00oooooooooooo
0?oooooo>_ooool001[ooooo00?o0000ooooooooool04?ooool00ol00?ooooooooooo`3oooooocWo
oooo000Jooooo`03o`000?oooooooooo017ooooo00?o003oooooooooool0oooooolhooooo`006_oo
ool00ol0003oooooooooo`0Booooo`03o`00oooooooooooo0?oooooo=oooool001[ooooo00?o0000
ooooooooool04oooool00ol00?ooooooooooo`3oooooocKooooo000Jooooo`03o`000?oooooooooo
01Cooooo00?o003oooooooooool0ooooooleooooo`006_ooool00ol0003oooooooooo`0Eooooo`03
o`00oooooooooooo0?oooooo=?ooool001[ooooo00?o0000ooooooooool05_ooool00ol00?oooooo
ooooo`3ooooooc?ooooo000Jooooo`03o`000?oooooooooo01Oooooo00?o003oooooooooool0oooo
oolbooooo`006_ooool00ol0003oooooooooo`0Hooooo`03o`00oooooooooooo0?oooooo<Oooool0
01[ooooo00?o0000ooooooooool06Oooool00ol00?ooooooooooo`3ooooooc3ooooo000Jooooo`03
o`000?oooooooooo01[ooooo00?o003oooooooooool0ooooool_ooooo`006_ooool2o`0001cooooo
00?o003oooooooooool0ooooool^ooooo`006_ooool00ol0003oooooooooo`0Looooo`03o`00oooo
oooooooo0?oooooo;Oooool001[ooooo00?o0000ooooooooool07Oooool00ol00?ooooooooooo`3o
ooooobcooooo000Jooooo`03o`000?oooooooooo01kooooo00?o003oooooooooool0ooooool[oooo
o`006_ooool00ol0003oooooooooo`0Oooooo`03o`00oooooooooooo0?oooooo:_ooool001[ooooo
00?o0000ooooooooool08?ooool00ol00?ooooooooooo`3oooooobWooooo000Jooooo`03o`000?oo
oooooooo027ooooo00?o003oooooooooool0oooooolXooooo`006_ooool00ol0003oooooooooo`0R
ooooo`03o`00oooooooooooo0?oooooo9oooool001[ooooo00?o0000ooooooooool08oooool00ol0
0?ooooooooooo`3oooooobKooooo000Jooooo`03o`000?oooooooooo02Cooooo00?o003oool00?oo
ool0oooooolUooooo`006_ooool00ol0003oooooooooo`0Tooooo`03o`00ool0o`3oo`000?oooooo
9Oooool001[ooooo00?o0000ooooooooool09Oooool00ol00?oo0?l0ool0003oooooobCooooo000J
ooooo`03o`000?oooooooooo02Kooooo00?o003oo`3o0?oo0000oooooolSooooo`006_ooool00ol0
003oooooooooo`0Wooooo`03o`00ool0o`3oo`000?oooooo8_ooool001[ooooo00?o0000oooooooo
ool0:?ooool00ol00?oo0?l0ool0003oooooob7ooooo000Jooooo`03o`000?oooooooooo02Wooooo
00?o003oo`3o0?oo0000oooooolPooooo`006_ooool2o`0002_ooooo00?o003oo`3o0?oo0000oooo
oolOooooo`006_ooool00ol0003oooooooooo`0[ooooo`03o`00ool0o`3oo`000?oooooo7_ooool0
01[ooooo00?o0000ooooooooool0;?ooool00ol00?oo0?l0ool0003ooooooagooooo000Jooooo`03
o`000?oooooooooo02gooooo00?o003oo`3o0?oo0000oooooolLooooo`006_ooool00ol0003ooooo
ooooo`0^ooooo`03o`00ool0o`3oo`000?oooooo6oooool001[ooooo00?o0000ooooooooool0;ooo
ool00ol00?oo0?l0ool0003ooooooa[ooooo000Jooooo`03o`000?oooooooooo033ooooo00?o003o
o`3o0?ooool0oooooolIooooo`006_ooool00ol0003oooooooooo`0aooooo`03o`00oooo003ooooo
0?oooooo6?ooool001[ooooo00?o0000ooooooooool0<Oooool00ol00?oo0?l0ool0003ooooooaSo
oooo000Jooooo`03o`000?oooooooooo03;ooooo00?o003oo`3o0?oo0000oooooolGooooo`006_oo
ool00ol0003oooooooooo`0cooooo`03o`00ool0o`3oo`000?oooooo5_ooool001[ooooo00?o0000
ooooooooool0=?ooool00ol00?oo0?l0ool0003ooooooaGooooo000Jooooo`03o`000?oooooooooo
03Gooooo00?o003oo`3o0?oo0000oooooolDooooo`0000Co<S8bo`000?lb<S;ok^k^1Oooool2ob4Q
8@Cooooo1Ol00006ooooo`03o`000?oooooooooo03Kooooo00?o003oo`3o0?oo0000oooooolCoooo
o`0000CoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4A006
ooooo`03o`000?oooooooooo03Oooooo00?o003oo`3o0?oo0000oooooolBooooo`000oooool00ol@
413oooooooooo`0:ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol0000hooooo`03o`00ool0o`3oo`00
0?oooooo4Oooool000?ooooo00?o0000ooooooooool02oooool00onHV9So8B4Qonk^kP06ooooo`03
o`000?oooooooooo03Wooooo00?o003oo`3o0?oo0000ooooool@ooooo`000oooool00ol0003ooooo
ooooo`0<ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool0>_ooool00ol00?oo0?l0
ool0003oooooo`oooooo0003ooooo`03oa0@4?oooooooooo00gooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0kooooo`03o`00ool0o`3oo`000?oooooo3_ooool00004oiRHV?oooooo
V9RHogMgM`_ooooo00Go0000okZj^_ooooooV9RHoa0@4006ooooo`03o`000?oooooooooo03cooooo
00?o003oo`3o0?oo0000ooooool=ooooo`0000Co<S8bo`000?lb<S;ok^k^2oooool01OnHV9So410@
o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0?Oooool00ol00?oo0?l0ooooo`3oooooo`co
oooo000Jooooo`03o`000?oooooooooo03kooooo00?o003oool00?ooool0ooooool;ooooo`006_oo
ool00ol0003oooooooooo`0nooooo`03o`00ool0o`3oo`000?oooooo2oooool001[ooooo00?o0000
ooooooooool0?oooool00ol00?oo0?l0ool0003oooooo`[ooooo000Jooooo`03o`000?oooooooooo
043ooooo00?o003oo`3o0?oo0000ooooool9ooooo`006_ooool00ol0003oooooooooo`11ooooo`03
o`00ool0o`3oo`000?oooooo2?ooool001[ooooo00?o0000ooooooooool0@_ooool00ol00?oo0?l0
ool0003oooooo`Oooooo000Jooooo`03o`000?oooooooooo04;ooooo00Co003oooooool0o`3oo`00
ooooool6ooooo`006_ooool00ol0003oooooooooo`13ooooo`04o`00oooooooo0?l0ool00?oooooo
1Oooool001[ooooo00?o0000ooooooooool0A?ooool01?l00?oo0?l0oooooooo003oooooo`Cooooo
000Jooooo`03o`000?oooooooooo04Gooooo00Co003oo`3o0?ooooooo`00ooooool3ooooo`006_oo
ool2o`0004Oooooo00Co003oo`3o0?ooooooo`00ooooool2ooooo`006_ooool00ol0003ooooooooo
o`17ooooo`04o`00ool0o`3oooooool00?oooooo0Oooool001[ooooo00?o0000ooooooooool0Aooo
ool01Ol00?ooooooo`3o0?ooooooo`000?oooooo000Jooooo`03o`000?oooooooooo04Sooooo00Go
003oooooool0o`3oooooool0003nooooo`006_ooool00ol0003oooooooooo`19ooooo`05o`00oooo
oooo0?l0oooooooo0000oOooool001[ooooo00?o0000ooooooooool0B_ooool01Ol00?oo0?l0oooo
ooooooooo`000?cooooo000Jooooo`03o`000?oooooooooo04_ooooo00Go003oo`3o0?oooooooooo
ool0003kooooo`006_ooool00ol0003oooooooooo`1;ooooo`03o`00oooooooo0?l000;ooooo00?o
o`00ooooooooool0n?ooool001[ooooo00?o0000ooooooooool0C?ooool00ol00?ooooooo`3o0002
ooooo`03ool00?oooooooooo0?Oooooo000Jooooo`03o`000?oooooooooo04gooooo00?o003ooooo
ool0o`000_ooool00ooo003oooooooooo`3fooooo`006_ooool00ol0003oooooooooo`1>ooooo`03
o`00oooooooo0?l000;ooooo00?oo`00ooooooooool0mOooool001[ooooo00?o0000ooooooooool0
Coooool00ol00?ooooooo`3o0002ooooo`03ool00?oooooooooo0?Cooooo000Jooooo`03o`000?oo
oooooooo04oooooo00Co003ooooooooooooo0?l00_ooool00ooo003oooooooooo`3cooooo`006_oo
ool00ol0003oooooooooo`1@ooooo`03o`00oooooooo0?l000?ooooo00?oo`00ooooooooool0l_oo
ool001[ooooo00?o0000ooooooooool0DOooool00ol00?ooooooo`3o0003ooooo`03ool00?oooooo
oooo0?7ooooo000Jooooo`03o`000?oooooooooo05;ooooo00?o003oooooool0o`000oooool00ooo
003oooooooooo`3`ooooo`006_ooool2o`0005?ooooo00Co003ooooooooooooo0?l00oooool00ooo
003oooooooooo`3_ooooo`006_ooool00ol0003oooooooooo`1Cooooo`04o`00ooooooooooooo`3o
00;ooooo00?oo`00ooooooooool0koooool001[ooooo00?o0000ooooooooool0E?ooool01?l00?oo
ooooooooool0o`02ooooo`03ool00?oooooooooo0>kooooo000Jooooo`03o`000?oooooooooo05Go
oooo00Co003ooooooooooooo0?l00_ooool00ooo003oooooooooo`3]ooooo`006_ooool00ol0003o
ooooooooo`1Fooooo`04o`00ooooooooooooo`3o00;ooooo00?oo`00ooooooooool0k?ooool001[o
oooo00?o0000ooooooooool0E_ooool01?l00?ooooooooooool0o`03ooooo`03ool00?oooooooooo
0>_ooooo000Jooooo`03o`000?oooooooooo05Oooooo00Co003ooooooooooooo0?l00oooool00ooo
003oooooooooo`3Zooooo`006_ooool00ol0003oooooooooo`1Hooooo`04o`00ooooooooooooo`3o
00?ooooo00?oo`00ooooooooool0jOooool001[ooooo00?o0000ooooooooool0FOooool01?l00?oo
ooooooooool0o`03ooooo`03ool00?oooooooooo0>Sooooo000Jooooo`03o`000?oooooooooo05Wo
oooo00Go003oooooooooooooooooo`3o0002ooooo`03ool00?oooooooooo0>Sooooo000Jooooo`03
o`000?oooooooooo05[ooooo00Co003ooooooooooooo0?l00oooool00ooo003oooooooooo`3Woooo
o`006_ooool00ol0003oooooooooo`1Kooooo`04o`00ooooooooooooo`3o00?ooooo00?oo`00oooo
ooooool0i_ooool001[ooooo00?o0000ooooooooool0Foooool01Ol00?oooooooooooooooooo0?l0
00?ooooo00?oo`00ooooooooool0iOooool001[ooooo00?o0000ooooooooool0G?ooool01Ol00?oo
oooooooooooooooo0?l000?ooooo00?oo`00ooooooooool0i?ooool001[ooooo00?o0000oooooooo
ool0GOooool01Ol00?oooooooooooooooooo0?l000?ooooo00?oo`00ooooooooool0hoooool001[o
oooo0_l0001Nooooo`03o`00oooooooooooo00;ooooo00Go0?l0ooooooooooooooooool0003Toooo
o`006_ooool00ol0003oooooooooo`1Nooooo`05o`00ooooooooooooooooool0o`000oooool00ooo
003oooooooooo`3Rooooo`006_ooool00ol0003oooooooooo`1Oooooo`05o`00oooooooooooooooo
ool0o`000oooool00ooo003oooooooooo`3Qooooo`006_ooool00ol0003oooooooooo`1Pooooo`05
o`00ooooooooooooooooool0o`000oooool00ooo003oooooooooo`3Pooooo`006_ooool00ol0003o
ooooooooo`1Pooooo`03o`00oooooooooooo00;ooooo00Go0?l0ooooooooooooooooool0003Qoooo
o`006_ooool00ol0003oooooooooo`1Qooooo`03o`00oooooooooooo00;ooooo00Go0?l0oooooooo
ooooooooool0003Pooooo`006_ooool00ol0003oooooooooo`1Rooooo`05o`00oooooooooooooooo
ool0o`000oooool00ooo003oooooooooo`3Nooooo`006_ooool00ol0003oooooooooo`1Rooooo`03
o`00oooooooooooo00;ooooo00Go0?l0ooooooooooooooooool0003Oooooo`006_ooool00ol0003o
ooooooooo`1Sooooo`03o`00oooooooooooo00;ooooo00Go0?l0ooooooooooooooooool0003Noooo
o`006_ooool00ol0003oooooooooo`1Tooooo`05o`00ooooooooooooooooool0o`001?ooool00ooo
003oooooooooo`3Kooooo`006_ooool00ol0003oooooooooo`1Tooooo`03o`00oooooooooooo00;o
oooo00?o0?l0ooooooooool00_ooool00ooo003oooooooooo`3Jooooo`006_ooool00ol0003ooooo
ooooo`1Uooooo`03o`00oooooooooooo00;ooooo00Go0?l0ooooooooooooooooool0003Looooo`00
6_ooool00ol0003oooooooooo`1Vooooo`05o`00ooooooooooooooooool0o`001?ooool00ooo003o
ooooooooo`3Iooooo`0000Co<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Kooooo0_l000000ol@413o
ooooooooo`04ooooo`03o`000?oooooooooo06Kooooo00?o003oooooooooool00_ooool00ol0o`3o
ooooooooo`02ooooo`03ool00?oooooooooo0=Sooooo00001?nHV9SooooooiRHV?mgMgL5ooooo`;o
8B4Q1oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo06Oooooo00?o003ooooooooo
ool00_ooool00ol0o`3oooooooooo`02ooooo`03ool00?oooooooooo0=Oooooo0003ooooo`03oa0@
4?oooooooooo00Wooooo1Ol00006ooooo`03o`000?oooooooooo06Oooooo00?o003oooooooooool0
0_ooool00ol0o`3oooooooooo`03ooooo`03ool00?oooooooooo0=Kooooo0003ooooo`03o`000?oo
oooooooo00Wooooo00CoA4A4omgMgOoooooo00001oooool3o`0006Sooooo00?o003oooooooooool0
0_ooool00ol0o`3oooooooooo`02ooooo`03ool00?oooooooooo0=Kooooo0003ooooo`03o`000?oo
oooooooo00Wooooo00CogMgMoeEEEOoooooo00001oooool00ol0003oooooooooo`1Xooooo`03o`00
oooooooooooo00?ooooo00?o0?l0ooooooooool00_ooool00ooo003oooooooooo`3Eooooo`000ooo
ool00ol@413oooooooooo`0:ooooo`03ogMgMoo<c<co000000Oooooo00?o0000ooooooooool0JOoo
ool00ol00?ooooooooooo`02ooooo`03o`3o0?oooooooooo00?ooooo00?oo`00ooooooooool0e?oo
ool00004oiRHV?ooooooV9RHogMgM`cooooo00?ok^k^odA4A?l000001oooool00ol0003ooooooooo
o`1Yooooo`03o`00oooooooooooo00?ooooo00?o0?l0ooooooooool00oooool00ooo003ooooooooo
o`3Cooooo`0000Co<S8bo`000?lb<S;ok^k^3Oooool00omgMgOo0000ooooo`06ooooo`03o`000?oo
oooooooo06[ooooo00?o003oooooooooool00oooool00ol0o`3oooooooooo`03ooooo`03ool00?oo
oooooooo0=;ooooo000Jooooo`03o`000?oooooooooo06[ooooo00?o003oooooooooool00oooool0
0ol0o`3oooooooooo`04ooooo`03ool00?oooooooooo0=7ooooo000Jooooo`03o`000?oooooooooo
06_ooooo00?o003oooooooooool00oooool00ol0o`3oooooooooo`04ooooo`03ool00?oooooooooo
0=3ooooo000Jooooo`03o`000?oooooooooo06_ooooo00?o003oooooooooool01?ooool00ol0o`3o
ooooooooo`04ooooo`03ool00?oooooooooo0<oooooo000Jooooo`03o`000?oooooooooo06cooooo
00?o003oooooooooool00oooool00ol0o`3oooooooooo`04ooooo`03ool00?oooooooooo0<oooooo
000Jooooo`03o`000?oooooooooo06gooooo00?o003oooooooooool00oooool00ol0o`3ooooooooo
o`04ooooo`03ool00?oooooooooo0<kooooo000Jooooo`03o`000?oooooooooo06gooooo00?o003o
ooooooooool01?ooool00ol0o`3oooooooooo`04ooooo`03ool00?oooooooooo0<gooooo000Joooo
o`03o`000?oooooooooo06kooooo00?o003oooooooooool00oooool00ol0o`3oooooooooo`05oooo
o`03ool00?oooooooooo0<cooooo000Jooooo`03o`000?oooooooooo06kooooo00?o003ooooooooo
ool01?ooool00ol0o`3oooooooooo`05ooooo`03ool00?oooooooooo0<_ooooo000Jooooo`03o`00
0?oooooooooo06oooooo00?o003oooooooooool01?ooool00ol0o`3oooooooooo`05ooooo`03ool0
0?oooooooooo0<[ooooo000Jooooo`03o`000?oooooooooo06oooooo00?o003oooooooooool01Ooo
ool00ol0o`3oooooooooo`05ooooo`03ool00?oooooooooo0<Wooooo000Jooooo`03o`000?oooooo
oooo073ooooo00?o003oooooooooool01?ooool00ol0o`3oooooooooo`06ooooo`03ool00?oooooo
oooo0<Sooooo000Jooooo`;o0000LOooool00ol00?ooooooooooo`05ooooo`03o`3o0?oooooooooo
00Gooooo00?oo`00ooooooooool0b?ooool001[ooooo00?o0000ooooooooool0LOooool00ol00?oo
ooooooooo`05ooooo`03o`3o0?oooooooooo00Gooooo00?oo`00ooooooooool0aoooool001[ooooo
00?o0000ooooooooool0LOooool00ol00?ooooooooooo`05ooooo`03o`3o0?oooooooooo00Kooooo
00?oo`00ooooooooool0a_ooool001[ooooo00?o0000ooooooooool0L_ooool00ol00?oooooooooo
o`05ooooo`03o`3o0?oooooooooo00Kooooo00?oo`00ooooooooool0aOooool001[ooooo00?o0000
ooooooooool0L_ooool00ol00?ooooooooooo`06ooooo`03o`3o0?oooooooooo00Gooooo00?oo`00
ooooooooool0aOooool001[ooooo00?o0000ooooooooool0Loooool00ol00?ooooooooooo`05oooo
o`03o`3o0?oooooooooo00Kooooo00?oo`00ooooooooool0a?ooool001[ooooo00?o0000oooooooo
ool0Loooool00ol00?ooooooooooo`06ooooo`03o`3o0?oooooooooo00Kooooo00?oo`00oooooooo
ool0`oooool001[ooooo00?o0000ooooooooool0M?ooool00ol00?ooooooooooo`06ooooo`03o`3o
0?oooooooooo00Kooooo00?oo`00ooooooooool0`_ooool001[ooooo00?o0000ooooooooool0M?oo
ool00ol00?ooooooooooo`07ooooo`03o`3o0?oooooooooo00Gooooo00?oo`00ooooooooool0`_oo
ool001[ooooo00?o0000ooooooooool0MOooool00ol00?ooooooooooo`06ooooo`03o`3o0?oooooo
oooo00Kooooo00?oo`00ooooooooool0`Oooool001[ooooo00?o0000ooooooooool0MOooool00ol0
0?ooooooooooo`07ooooo`03o`3o0?oooooooooo00Kooooo00?oo`00ooooooooool0`?ooool001[o
oooo00?o0000ooooooooool0M_ooool00ol00?ooooooooooo`07ooooo`03o`3o0?oooooooooo00Ko
oooo00?oo`00ooooooooool0_oooool001[ooooo00?o0000ooooooooool0M_ooool00ol00?oooooo
ooooo`07ooooo`03o`3o0?oooooooooo00Kooooo00?oo`00ooooooooool0_oooool001[ooooo00?o
0000ooooooooool0Moooool00ol00?ooooooooooo`07ooooo`03o`3o0?oooooooooo00Kooooo00?o
o`00ooooooooool0__ooool001[ooooo00?o0000ooooooooool0Moooool00ol00?ooooooooooo`07
ooooo`03o`3o0?oooooooooo00Oooooo00?oo`00ooooooooool0_Oooool001[ooooo0_l0001ioooo
o`03o`00oooooooooooo00Oooooo00?o0?l0ooooooooool01oooool00ooo003oooooooooo`2loooo
o`006_ooool00ol0003oooooooooo`1hooooo`03o`00oooooooooooo00Oooooo00?o0?l0oooooooo
ool01oooool00ooo003oooooooooo`2looooo`006_ooool00ol0003oooooooooo`1iooooo`03o`00
oooooooooooo00Oooooo00?o0?l0ooooooooool01oooool00ooo003oooooooooo`2kooooo`006_oo
ool00ol0003oooooooooo`1iooooo`03o`00oooooooooooo00Oooooo00?o0?l0ooooooooool02?oo
ool00ooo003oooooooooo`2jooooo`006_ooool00ol0003oooooooooo`1jooooo`03o`00oooooooo
oooo00Oooooo00?o0?l0ooooooooool02?ooool00ooo003oooooooooo`2iooooo`006_ooool00ol0
003oooooooooo`1jooooo`03o`00oooooooooooo00Oooooo00?o0?l0ooooooooool02Oooool00ooo
003oooooooooo`2hooooo`006_ooool00ol0003oooooooooo`1jooooo`03o`00oooooooooooo00So
oooo00?o0?l0ooooooooool02?ooool00ooo003oooooooooo`2hooooo`006_ooool00ol0003ooooo
ooooo`1kooooo`03o`00oooooooooooo00Oooooo00?o0?l0ooooooooool02Oooool00ooo003ooooo
ooooo`2gooooo`006_ooool00ol0003oooooooooo`1kooooo`03o`00oooooooooooo00Sooooo00?o
0?l0ooooooooool02Oooool00ooo003oooooooooo`2fooooo`006_ooool00ol0003oooooooooo`1k
ooooo`03o`00oooooooooooo00Sooooo00?o0?l0ooooooooool02_ooool00ooo003oooooooooo`2e
ooooo`006_ooool00ol0003oooooooooo`1looooo`03o`00oooooooooooo00Sooooo00?o0?l0oooo
ooooool02_ooool00ooo003oooooooooo`2dooooo`006_ooool00ol0003oooooooooo`1looooo`03
o`00oooooooooooo00Sooooo00?o0?l0ooooooooool02oooool00ooo003oooooooooo`2cooooo`00
6_ooool00ol0003oooooooooo`1looooo`03o`00oooooooooooo00Wooooo00?o0?l0ooooooooool0
2_ooool00ooo003oooooooooo`2cooooo`006_ooool00ol0003oooooooooo`1mooooo`03o`00oooo
oooooooo00Sooooo00?o0?l0ooooooooool02oooool00ooo003oooooooooo`2booooo`006_ooool0
0ol0003oooooooooo`1mooooo`03o`00oooooooooooo00Wooooo00?o0?l0ooooooooool02oooool0
0ooo003oooooooooo`2aooooo`006_ooool00ol0003oooooooooo`1mooooo`03o`00oooooooooooo
00Wooooo00?o0?l0ooooooooool03?ooool00ooo003oooooooooo`2`ooooo`006_ooool2o`0007oo
oooo00?o003oooooooooool02Oooool00ol0o`3oooooooooo`0<ooooo`03ool00?oooooooooo0:oo
oooo000Jooooo`03o`000?oooooooooo07kooooo00?o003oooooooooool02Oooool00ol0o`3ooooo
ooooo`0<ooooo`03ool00?oooooooooo0:oooooo000Jooooo`03o`000?oooooooooo07kooooo00?o
003oooooooooool02_ooool00ol0o`3oooooooooo`0<ooooo`03ool00?oooooooooo0:kooooo000J
ooooo`03o`000?oooooooooo07oooooo00?o003oooooooooool02Oooool00ol0o`3oooooooooo`0=
ooooo`03ool00?oooooooooo0:gooooo000Jooooo`03o`000?oooooooooo07oooooo00?o003ooooo
ooooool02_ooool00ol0o`3oooooooooo`0<ooooo`03ool00?oooooooooo0:gooooo000Jooooo`03
o`000?oooooooooo07oooooo00?o003oooooooooool02_ooool00ol0o`3oooooooooo`0=ooooo`03
ool00?oooooooooo0:cooooo000Jooooo`03o`000?oooooooooo083ooooo00?o003oooooooooool0
2_ooool00ol0o`3oooooooooo`0=ooooo`03ool00?oooooooooo0:_ooooo000Jooooo`03o`000?oo
oooooooo083ooooo00?o003oooooooooool02_ooool00ol0o`3oooooooooo`0=ooooo`03ool00?oo
oooooooo0:_ooooo000Jooooo`03o`000?oooooooooo083ooooo00?o003oooooooooool02oooool0
0ol0o`3oooooooooo`0=ooooo`03ool00?oooooooooo0:[ooooo000Jooooo`03o`000?oooooooooo
083ooooo00?o003oooooooooool02oooool00ol0o`3oooooooooo`0>ooooo`03ool00?oooooooooo
0:Wooooo000Jooooo`03o`000?oooooooooo087ooooo00?o003oooooooooool02_ooool00ol0o`3o
ooooooooo`0?ooooo`03ool00?oooooooooo0:Sooooo000Jooooo`03o`000?oooooooooo087ooooo
00?o003oooooooooool02oooool00ol0o`3oooooooooo`0>ooooo`03ool00?oooooooooo0:Sooooo
000Jooooo`03o`000?oooooooooo087ooooo00?o003oooooooooool02oooool00ol0o`3ooooooooo
o`0?ooooo`03ool00?oooooooooo0:Oooooo00001?lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1?oo
ool01Oo^k^ko<S8bo`000?l@413oc<c<00Kooooo00?o0000ooooooooool0IOooool01on7Qooo003o
oeEEoomVI_oo003ooc8booo^k_l02Oooool01OnHV?oo413oo`00oolb<_ooc<co00Oooooo00?o003o
ooooooooool03?ooool00ol0o`3oooooooooo`0?ooooo`03ool00?oooooooooo0:Kooooo00001?nH
V9SooooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OmEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o
0000ooooooooool0IOooool01ol@4?oogMgoogMgoolQ8OooooooohN7oomVI_l00_ooool6o`00o`06
ooooool@4?oo^[[ooooooomgMooo<S;o1oooool00ol00?ooooooooooo`0<ooooo`03o`3o0?oooooo
oooo00oooooo00?oo`00ooooooooool0Y_ooool000?ooooo00?o410@ooooooooool02Oooool01Ol0
003ooooooooooooooooo000000Kooooo0ol0001Uooooo`07o`00oooooooogMgooc8booooooook^ko
oa0@o`0=ooooo`03o`00oooooooooooo00Kooooo00?o003oooooooooool03?ooool00ol0o`3ooooo
ooooo`0?ooooo`03ool00?oooooooooo0:Gooooo0003ooooo`03o`000?oooooooooo00Wooooo00Go
0000oiRHV?ooooooV9RHob4Q8@06ooooo`03o`000?oooooooooo06Gooooo00CoEEGoojVYoooooooo
003o0_ooool00ol00?ooooooooooo`06o`00o`Cooooo00?oZJWooa0@ooooool01oooool00ol00?oo
ooooooooo`0<ooooo`03o`3o0?oooooooooo013ooooo00?oo`00ooooooooool0Y?ooool000?ooooo
00?o0000ooooooooool02Oooool01Ol0003oEEEEo`000?l@413oc<c<00Kooooo00?o0000oooooooo
ool0IOooool00ooMgOoo8B7oonk^o`03ooooo`03o`00oooooooooooo00Wooooo00?o413oo`00oonj
^_l02?ooool00ol00?ooooooooooo`0=ooooo`03o`3o0?oooooooooo00oooooo00?oo`00oooooooo
ool0Y?ooool000?ooooo00?o410@ooooooooool02Oooool00omEEEGoQhN7ooooo`08ooooo`03o`00
0?oooooooooo06Kooooo00?oV9SoogMgooooool00_ooool00ol00?ooooooooooo`0:ooooo`03okZj
oolQ8Ooooooo00Sooooo00?o003oooooooooool03?ooool00ol0o`3oooooooooo`0@ooooo`03ool0
0?oooooooooo0:?ooooo00001?nHV9SooooooiRHV?mgMgL;ooooo`03omgMgOl@413oV9RH00Sooooo
00?o0000ooooooooool0MOooool01Ol@4?ooV9Sooooooonj^_oo003o00Wooooo00?o003ooooooooo
ool03Oooool00ol0o`3oooooooooo`0@ooooo`03ool00?oooooooooo0:;ooooo00001?lb<S;o0000
oc8b<_o^k^h<ooooo`04olc<c?m4A4Co0000oa0@40Kooooo00?o0000ooooooooool0MOooool01OnY
ZOoo413oo`00ool@4?ooZJWo00Wooooo00?o003oooooooooool03Oooool00ol0o`3oooooooooo`0@
ooooo`03ool00?oooooooooo0:;ooooo000Jooooo`03o`000?oooooooooo08?ooooo00?o003ooooo
ooooool03Oooool00ol0o`3oooooooooo`0Aooooo`03ool00?oooooooooo0:7ooooo000Jooooo`03
o`000?oooooooooo08Cooooo00?o003oooooooooool03Oooool00ol0o`3oooooooooo`0Aooooo`03
ool00?oooooooooo0:3ooooo000Jooooo`03o`000?oooooooooo08Cooooo00?o003oooooooooool0
3Oooool00ol0o`3oooooooooo`0Aooooo`03ool00?oooooooooo0:3ooooo000Jooooo`03o`000?oo
oooooooo08Cooooo00?o003oooooooooool03_ooool00ol0o`3oooooooooo`0Aooooo`03ool00?oo
oooooooo09oooooo000Jooooo`03o`000?oooooooooo08Cooooo00?o003oooooooooool03_ooool0
0ol0o`3oooooooooo`0Booooo`03ool00?oooooooooo09kooooo000Jooooo`03o`000?oooooooooo
08Gooooo00?o003oooooooooool03_ooool00ol0o`3oooooooooo`0Aooooo`03ool00?oooooooooo
09kooooo000Jooooo`03o`000?oooooooooo08Gooooo00?o003oooooooooool03_ooool00ol0o`3o
ooooooooo`0Booooo`03ool00?oooooooooo09gooooo000Jooooo`03o`000?oooooooooo08Gooooo
00?o003oooooooooool03oooool00ol0o`3oooooooooo`0Booooo`03ool00?oooooooooo09cooooo
000Jooooo`03o`000?oooooooooo08Gooooo00?o003oooooooooool03oooool00ol0o`3ooooooooo
o`0Booooo`03ool00?oooooooooo09cooooo000Jooooo`03o`000?oooooooooo08Gooooo00?o003o
ooooooooool03oooool00ol0o`3oooooooooo`0Cooooo`03ool00?oooooooooo09_ooooo000Joooo
o`;o0000Q_ooool00ol00?ooooooooooo`0@ooooo`03o`3o0?oooooooooo01;ooooo00?oo`00oooo
ooooool0Voooool001[ooooo00?o0000ooooooooool0Q_ooool00ol00?ooooooooooo`0?ooooo`03
o`3o0?oooooooooo01?ooooo00?oo`00ooooooooool0V_ooool001[ooooo00?o0000ooooooooool0
Q_ooool00ol00?ooooooooooo`0@ooooo`03o`3o0?oooooooooo01?ooooo00?oo`00ooooooooool0
VOooool001[ooooo00?o0000ooooooooool0Q_ooool00ol00?ooooooooooo`0@ooooo`03o`3o0?oo
oooooooo01?ooooo00?oo`00ooooooooool0VOooool001[ooooo00?o0000ooooooooool0Q_ooool0
0ol00?ooooooooooo`0@ooooo`03o`3o0?oooooooooo01Cooooo00?oo`00ooooooooool0V?ooool0
01[ooooo00?o0000ooooooooool0Q_ooool00ol00?ooooooooooo`0Aooooo`03o`3o0?oooooooooo
01Cooooo00?oo`00ooooooooool0Uoooool001[ooooo00?o0000ooooooooool0Q_ooool00ol00?oo
ooooooooo`0Aooooo`03o`3o0?oooooooooo01Cooooo00?oo`00ooooooooool0Uoooool001[ooooo
00?o0000ooooooooool0Q_ooool00ol00?ooooooooooo`0Aooooo`03o`3o0?oooooooooo01Gooooo
00?oo`00ooooooooool0U_ooool001[ooooo00?o0000ooooooooool0Q_ooool00ol00?oooooooooo
o`0Booooo`03o`3o0?oooooooooo01Gooooo00?oo`00ooooooooool0UOooool001[ooooo00?o0000
ooooooooool0Q_ooool00ol00?ooooooooooo`0Booooo`03o`3o0?oooooooooo01Gooooo00?oo`00
ooooooooool0UOooool001[ooooo00?o0000ooooooooool0Q_ooool00ol00?ooooooooooo`0Boooo
o`03o`3o0?oooooooooo01Kooooo00?oo`00ooooooooool0U?ooool001[ooooo00?o0000oooooooo
ool0Q_ooool00ol00?ooooooooooo`0Cooooo`03o`3o0?oooooooooo01Gooooo00?oo`00oooooooo
ool0U?ooool001[ooooo00?o0000ooooooooool0Q_ooool00ol00?ooooooooooo`0Cooooo`03o`3o
0?oooooooooo01Kooooo00?oo`00ooooooooool0Toooool001[ooooo00?o0000ooooooooool0Q_oo
ool00ol00?ooooooooooo`0Cooooo`03o`3o0?oooooooooo01Oooooo00?oo`00ooooooooool0T_oo
ool001[ooooo00?o0000ooooooooool0Qoooool00ol00?ooooooooooo`0Booooo`03o`3o0?oooooo
oooo01Oooooo00?oo`00ooooooooool0T_ooool001[ooooo00?o0000ooooooooool0Qoooool00ol0
0?ooooooooooo`0Cooooo`03o`3o0?oooooooooo01Oooooo00?oo`00ooooooooool0TOooool001[o
oooo0_l00028ooooo`03o`00oooooooooooo01?ooooo00?o0?l0ooooooooool05oooool00ooo003o
ooooooooo`2Aooooo`006_ooool00ol0003oooooooooo`27ooooo`03o`00oooooooooooo01?ooooo
00?o0?l0ooooooooool06?ooool00ooo003oooooooooo`2@ooooo`006_ooool00ol0003ooooooooo
o`27ooooo`03o`00oooooooooooo01Cooooo00?o0?l0ooooooooool05oooool00ooo003ooooooooo
o`2@ooooo`006_ooool00ol0003oooooooooo`27ooooo`03o`00oooooooooooo01Cooooo00?o0?l0
ooooooooool06?ooool00ooo003oooooooooo`2?ooooo`006_ooool00ol0003oooooooooo`27oooo
o`03o`00oooooooooooo01Cooooo00?o0?l0ooooooooool06Oooool00ooo003oooooooooo`2>oooo
o`006_ooool00ol0003oooooooooo`27ooooo`03o`00oooooooooooo01Cooooo00?o0?l0oooooooo
ool06Oooool00ooo003oooooooooo`2>ooooo`006_ooool00ol0003oooooooooo`27ooooo`03o`00
oooooooooooo01Gooooo00?o0?l0ooooooooool06Oooool00ooo003oooooooooo`2=ooooo`006_oo
ool00ol0003oooooooooo`27ooooo`03o`00oooooooooooo01Gooooo00?o0?l0ooooooooool06Ooo
ool00ooo003oooooooooo`2=ooooo`006_ooool00ol0003oooooooooo`27ooooojoo003o5Oooool0
01[ooooo00?o0000ooooooooool0Woooool00ol0o`3oooooooooo`0Jooooo`03ool00?oooooooooo
08cooooo000Jooooo`03o`000?oooooooooo0:3ooooo00?o0?l0ooooooooool06_ooool00ooo003o
ooooooooo`2;ooooo`006_ooool00ol0003oooooooooo`2Pooooo`03o`3o0?oooooooooo01[ooooo
00?oo`00ooooooooool0Roooool001[ooooo00?o0000ooooooooool0X?ooool00ol0o`3ooooooooo
o`0Kooooo`03ool00?oooooooooo08[ooooo000Jooooo`03o`000?oooooooooo0:7ooooo00?o0?l0
ooooooooool06oooool00ooo003oooooooooo`29ooooo`006_ooool00ol0003oooooooooo`2Qoooo
o`03o`3o0?oooooooooo01_ooooo00?oo`00ooooooooool0ROooool001[ooooo0_l0002Rooooo`03
o`3o0?oooooooooo01cooooo00?oo`00ooooooooool0R?ooool001[ooooo00?o0000ooooooooool0
XOooool00ol0o`3oooooooooo`0Looooo`03ool00?oooooooooo08Sooooo000Jooooo`03o`000?oo
oooooooo0:;ooooo00?o0?l0ooooooooool07?ooool00ooo003oooooooooo`27ooooo`006_ooool0
0ol0003oooooooooo`2Rooooo`03o`3o0?oooooooooo01cooooo00?oo`00ooooooooool0Qoooool0
01[ooooo00?o0000ooooooooool0X_ooool00ol0o`3oooooooooo`0Mooooo`03ool00?oooooooooo
08Kooooo000Jooooo`03o`000?oooooooooo0:;ooooo00?o0?l0ooooooooool07Oooool00ooo003o
ooooooooo`26ooooo`006_ooool00ol0003oooooooooo`2Rooooo`03o`3o0?oooooooooo01kooooo
00?oo`00ooooooooool0QOooool001[ooooo00?o0000ooooooooool0Xoooool00ol0o`3ooooooooo
o`0Mooooo`03ool00?oooooooooo08Gooooo000Jooooo`03o`000?oooooooooo0:?ooooo00?o0?l0
ooooooooool07_ooool00ooo003oooooooooo`24ooooo`006_ooool00ol0003oooooooooo`2Soooo
o`03o`3o0?oooooooooo01kooooo00?oo`00ooooooooool0Q?ooool001[ooooo00?o0000oooooooo
ool0Xoooool00ol0o`3oooooooooo`0Oooooo`03ool00?oooooooooo08?ooooo000Jooooo`03o`00
0?oooooooooo0:?ooooo00?o0?l0ooooooooool07oooool00ooo003oooooooooo`23ooooo`006_oo
ool00ol0003oooooooooo`2Tooooo`03o`3o0?oooooooooo01oooooo00?oo`00ooooooooool0P_oo
ool00004oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B44ooooo`05olc<c?lQ8B7o0000ob4Q8Oo<c<`0
1_ooool00ol0003oooooooooo`28ooooo`07ohOoQol0o`3oEOmEofKoI_l0o`3o<_lbonkokP09oooo
o`Go0?l01oooool00ol0o`3oooooooooo`0Oooooo`03ool00?oooooooooo08;ooooo00001?nHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q1?ooool01OlQ8B7oV9RHoooooonHV9So8B4Q00Kooooo00?o0000
ooooooooool0R?ooool02?l@oa3ogOoMogOoMolQob7oooooohOoQomVofKooooo1_l0o`02ooooo`05
oiSoV?lQob7ok_o^oooooom4od@01oooool00ol0o`3oooooooooo`0Pooooo`03ool00?oooooooooo
087ooooo0003ooooo`03oa0@4?oooooooooo00Wooooo00Go0000ooooooooooooooooo`000006oooo
o`03o`000?oooooooooo08Sooooo00Oo0?l0oooooooMomgo<_lbooooooo^onko4?l@00[ooooo00?o
V?nHob7o8Oo^onh02?ooool00ol0o`3oooooooooo`0Pooooo`03ool00?oooooooooo087ooooo0003
ooooo`03o`000?oooooooooo00Wooooo00Go<S8boiRHV?ooooooV9RHoc8b<P06ooooo`?o0000R?oo
ool01?mEoeGoZOnYooooool0o`02ooooo`03o`3o0?oooooo0?l000Go0?l01?ooool00onHoiSo8OlQ
onkokP07ooooo`03o`3o0?oooooooooo027ooooo00?oo`00ooooooooool0P?ooool000?ooooo00?o
0000ooooooooool02Oooool01Oo<c<co0000o`000?l0003oc<c<00Kooooo00?o0000ooooooooool0
R?ooool00ooMomgo8OlQonkokP03ooooo`03o`3o0?oooooooooo00[ooooo00?oMomgofKoI_ooool0
1_ooool00ol0o`3oooooooooo`0Qooooo`03ool00?oooooooooo083ooooo0003ooooo`03oa0@4?oo
oooooooo00Wooooo00Go410@okZj^_oooooo^[Zjoa0@4006ooooo`03o`000?oooooooooo08Wooooo
00?oV?nHogOoMoooool00_ooool00ol0o`3oooooooooo`0;ooooo`03o`3o0?oooooooooo00Kooooo
00?o0?l0ooooooooool08Oooool00ooo003oooooooooo`1oooooo`0000CoV9RHoooooonHV9SoMgMg
2oooool01Ol0003o^[Zjoooooonj^[[o000000Kooooo00?o0000ooooooooool0V?ooool01Ol0o`3o
^_njoooooonHoiSo4?l@00Sooooo00?o0?l0ooooooooool08Oooool00ooo003oooooooooo`1ooooo
o`0000Co<S8bo`000?lb<S;ok^k^2oooool01OnYZJWo410@o`000?l@413oZJVY00Kooooo00?o0000
ooooooooool0V?ooool01OnHoiSo4?l@o`3o0?lQob7oc?o<00Sooooo00?o0?l0ooooooooool08_oo
ool00ooo003oooooooooo`1nooooo`006_ooool00ol0003oooooooooo`2Uooooo`03o`3o0?oooooo
oooo02;ooooo00?oo`00ooooooooool0O_ooool001[ooooo00?o0000ooooooooool0YOooool00ol0
o`3oooooooooo`0Sooooo`03ool00?oooooooooo07gooooo000Jooooo`03o`000?oooooooooo0:Go
oooo00?o0?l0ooooooooool08oooool00ooo003oooooooooo`1mooooo`006_ooool00ol0003ooooo
ooooo`2Uooooo`03o`3o0?oooooooooo02Cooooo00?oo`00ooooooooool0O?ooool001[ooooo00?o
0000ooooooooool0YOooool00ol0o`3oooooooooo`0Tooooo`03ool00?oooooooooo07cooooo000J
ooooo`03o`000?oooooooooo0:Gooooo00?o0?l0ooooooooool09Oooool00ooo003oooooooooo`1k
ooooo`006_ooool00ol0003oooooooooo`2Uooooo`03o`3o0?oooooooooo02Gooooo00?oo`00oooo
ooooool0Noooool001[ooooo00?o0000ooooooooool0YOooool00ol0o`3oooooooooo`0Vooooo`03
ool00?oooooooooo07[ooooo000Jooooo`03o`000?oooooooooo0:Gooooo00?o0?l0ooooooooool0
9_ooool00ooo003oooooooooo`1jooooo`006_ooool00ol0003oooooooooo`2Uooooo`03o`3o0?oo
oooooooo02Kooooo00?oo`00ooooooooool0N_ooool001[ooooo0_l0002Vooooo`03o`3o0?oooooo
oooo02Oooooo00?oo`00ooooooooool0NOooool001[ooooo00?o0000ooooooooool0YOooool00ol0
o`3oooooooooo`0Wooooo`03ool00?oooooooooo07Wooooo000Jooooo`03o`000?oooooooooo0:Ko
oooo00?o0?l0ooooooooool09oooool00ooo003oooooooooo`1hooooo`006_ooool00ol0003ooooo
ooooo`2Vooooo`03o`3o0?oooooooooo02Oooooo00?oo`00ooooooooool0N?ooool001[ooooo00?o
0000ooooooooool0Y_ooool00ol0o`3oooooooooo`0Xooooo`03ool00?oooooooooo07Oooooo000J
ooooo`03o`000?oooooooooo0:Kooooo00?o0?l0ooooooooool0:?ooool00ooo003oooooooooo`1g
ooooo`006_ooool00ol0003oooooooooo`2Vooooo`03o`3o0?oooooooooo02Sooooo00?oo`00oooo
ooooool0Moooool001[ooooo00?o0000ooooooooool0Y_ooool00ol0o`3oooooooooo`0Yooooo`03
ool00?oooooooooo07Kooooo000Jooooo`03o`000?oooooooooo0:Kooooo00?o0?l0ooooooooool0
:Oooool00ooo003oooooooooo`1fooooo`006_ooool00ol0003oooooooooo`2Vooooo`03o`3o0?oo
oooooooo02[ooooo00?oo`00ooooooooool0MOooool001[ooooo00?o0000ooooooooool0Y_ooool0
0ol0o`3oooooooooo`0Zooooo`03ool00?oooooooooo07Gooooo000Jooooo`03o`000?oooooooooo
0:Kooooo00?o0?l0ooooooooool0:oooool00ooo003oooooooooo`1dooooo`006_ooool00ol0003o
ooooooooo`2Vooooo`03o`3o0?oooooooooo02_ooooo00?oo`00ooooooooool0M?ooool001[ooooo
00?o0000ooooooooool0Y_oooon@o`3o01Gooooo000Jooooo`03o`000?oooooooooo0=Gooooo00?o
o`00ooooooooool0Loooool001[ooooo00?o0000ooooooooool0eOooool00ooo003oooooooooo`1c
ooooo`006_ooool2o`000=Oooooo00?oo`00ooooooooool0L_ooool001[ooooo00?o0000oooooooo
ool0e_ooool00ooo003oooooooooo`1booooo`006_ooool00ol0003oooooooooo`3Fooooo`03ool0
0?oooooooooo07;ooooo000Jooooo`03o`000?oooooooooo0=Oooooo00?oo`00ooooooooool0LOoo
ool001[ooooo00?o0000ooooooooool0eoooool00ooo003oooooooooo`1aooooo`006_ooool00ol0
003oooooooooo`3Hooooo`03ool00?oooooooooo073ooooo000Jooooo`03o`000?oooooooooo0=So
oooo00?oo`00ooooooooool0L?ooool001[ooooo00?o0000ooooooooool0fOooool00ooo003ooooo
ooooo`1_ooooo`006_ooool00ol0003oooooooooo`3Iooooo`03ool00?oooooooooo06oooooo000J
ooooo`03o`000?oooooooooo0=Wooooo00?oo`00ooooooooool0Koooool001[ooooo00?o0000oooo
ooooool0f_ooool00ooo003oooooooooo`1^ooooo`006_ooool00ol0003oooooooooo`3Jooooo`03
ool00?oooooooooo06kooooo000Jooooo`03o`000?oooooooooo0=[ooooo00?oo`00ooooooooool0
K_ooool001[ooooo00?o0000ooooooooool0foooool00ooo003oooooooooo`04ooooo`07oon7Qooo
003ooeEEoomVI_oo003ooc8booo^kP0:ooooo`Coo`0000?ooa0@ooooooooool0DOooool001[ooooo
00?o0000ooooooooool0foooool00ooo003oooooooooo`04ooooo`07ool@4?oogMgoogMgoolQ8Ooo
ooooohN7oomVIP02ooooo`Koo`001?ooool00ooo003oooooooooo`1Cooooo`006_ooool00ol0003o
ooooooooo`3Kooooo`03ool00?oooooooooo00Cooooo00Ooo`00oooooooogMgooc8booooooook^ko
oa0@00cooooo00?oo`00ooooooooool0Doooool001[ooooo0_l0003Mooooo`03ool00?oooooooooo
00?ooooo00CooeEEoonYZOooooooo`000_ooool00ooo003oooooooooo`06ool000Cooooo00?oo`00
ooooooooool0Doooool001[ooooo00?o0000ooooooooool0g?ooool00ooo003oooooooooo`03oooo
o`03oooMgOoo8B7oonk^00?ooooo00?oo`00ooooooooool02_ooool00ooo003oooooooooo`1Coooo
o`006_ooool00ol0003oooooooooo`3Looooo`03ool00?oooooooooo00Cooooo00?ooiRHoomgMooo
ool00_ooool00ooo003oooooooooo`0:ooooo`03ool00?oooooooooo05?ooooo000Jooooo`03o`00
0?oooooooooo0=cooooo00?oo`00ooooooooool05_ooool00ooo003oooooooooo`1Cooooo`006_oo
ool00ol0003oooooooooo`3Mooooo`03ool00?oooooooooo01?ooooo00?ooeEEoomVI_oo0000EOoo
ool001[ooooo00?o0000ooooooooool0gOooool00ooo003oooooooooo`1[ooooo`006_ooool00ol0
003oooooooooo`3Mooooo`03ool00?oooooooooo06_ooooo000Jooooo`03o`000?oooooooooo0=ko
oooo00?oo`00ooooooooool0J_ooool001[ooooo00?o0000ooooooooool0g_ooool00ooo003ooooo
ooooo`1Zooooo`006_ooool00ol0003oooooooooo`3Nooooo`03ool00?oooooooooo06[ooooo000J
ooooo`03o`000?oooooooooo0=kooooo00?oo`00ooooooooool0J_ooool001[ooooo00?o0000oooo
ooooool0goooool00ooo003oooooooooo`1Yooooo`006_ooool00ol0003oooooooooo`3Oooooo`03
ool00?oooooooooo06Wooooo000@ooooo`Co000000?o410@ooooooooool00oooool00ol0003ooooo
ooooo`3Oooooo`03ool00?oooooooooo06Wooooo000Booooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0h?ooool00ooo003oooooooooo`1Xooooo`004_ooool00ol0003oooooooooo`05
ooooo`?o0000h?ooool2ool006Wooooo000Booooo`03o`000?oooooooooo0?ooooooE?ooool001;o
oooo00?o0000ooooooooool0oooooomDooooo`004_ooool00ol0003oooooooooo`3ooooooeCooooo
000Booooo`03o`000?oooooooooo0?ooooooE?ooool0013ooooo00?oEEEEofIVI_l00000oooooomF
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`005_ooool3
o`000003oa0@4?oooooooooo0?ooooooCOooool001Sooooo00?o410@okZj^_ooool0oooooom>oooo
o`006?ooool00onHV9So<S8booooo`3oooooodkooooo000Hooooo`03omgMgOl0003o^[Zj0?oooooo
C_ooool001Sooooo00?oEEEEogMgMom4A4@0oooooom>ooooo`005oooool01OoMgMgo410@oooooolQ
8B7ogMgM0?ooooooCOooool001Oooooo00GoIVIVohN7QoooooooV9RHoeEEE@3oooooodgooooo000F
ooooo`03onk^k_l0003ok^k^00;ooooo00?o0000omgMgOooool0oooooom;ooooo`005_ooool01?l@
413o0000o`000?ooool2o`000003oa0@4?oooooooooo0?ooooooB_ooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {359, 0}} -> {-0.0845545, -0.0625394, \
0.00400274, 0.00400274}}],

Cell[TextData[{
  "Fig. 5.8 Three ray trajectories in a dispersive medium where ",
  Cell[BoxData[
      \(TraditionalForm\`n(x, \[Omega])\  = \ 1 - \[Omega]\ x\^2\)]],
  "."
}], "Caption",
  CellTags->"Fig. 5.8"],

Cell[TextData[{
  "The rays  bend toward the region of lower wave speed (more negative ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  "), as expected from Snell's law. Although all three rays start out moving \
in the same direction, the refractive index for the blue ray (higher \
frequency)  is larger than for the others, so this ray bends more. A light \
beam made up of these three frequencies would spread accordingly, revealing \
the spectral components of the beam. "
}], "Text"],

Cell[TextData[{
  "\tNote that when ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]y/\[DifferentialD]x = \
\[Infinity]\)]],
  " on a given ray, our analytic solution for ",
  Cell[BoxData[
      \(TraditionalForm\`y(x)\)]],
  " fails. This is the location of a ",
  StyleBox["turning point",
    FontSlant->"Italic"],
  " where the ray trajectory is reflected back toward ",
  Cell[BoxData[
      \(TraditionalForm\`\(-x\&^\)\)]],
  ". At the turning point, ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(k\_x\)\(\[Rule]\)\(0\)\(\ \)\)\)]],
  ",  and we should have switched the sign of the square root in Eq. ",
  ButtonBox["(5.2.50)",
    ButtonData:>"(5.2.50)",
    ButtonStyle->"Hyperlink"],
  ". One can avoid this problem with the analytic form of the ray trajectory \
by simply integrating Eqs. ",
  ButtonBox["(5.2.48)",
    ButtonData:>"(5.2.48)",
    ButtonStyle->"Hyperlink"],
  "  numerically to obtain ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["(",
            FontWeight->"Plain"], 
          StyleBox["t",
            FontWeight->"Plain"], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  ". The appearance of a turning point in the rays is an example of ",
  StyleBox["total internal reflection",
    FontSlant->"Italic"],
  ",  wherein rays are  reflected back toward the region of higher refractive \
index (lower wave speed). "
}], "Text",
  CellTags->"i:83"],

Cell[TextData[{
  "\t At a planar interface between two homogeneous media with refractive \
indices ",
  Cell[BoxData[
      \(TraditionalForm\`n\_1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`n\_2\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`n\_1 > n\_2\)]],
  ",  one can show that total internal reflection will occur for a ray \
propagating in medium ",
  Cell[BoxData[
      \(TraditionalForm\`1\)]],
  " provided that the angle ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\)]],
  " between the interface and the ray is sufficiently small so that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi] < \ \(cos\^\(-1\)\)(n\_2/n\_1)\)]],
  " (see the exercises at the end of the section).  We will have more to say \
about turning points later in the chapter."
}], "Text",
  CellTags->"i:84"],

Cell[TextData[{
  "\tAs the spectral components of this beam spread, the beam amplitude would \
be expected to decrease as the wave energy is distributed over a larger \
volume. In fact, the behavior of the wave-packet amplitude near a turning \
point is rather more complicated than this simple picture suggests.  The \
dynamics of the wave-packet amplitude are considered briefly in the \
sub-subsection entitled ",
  ButtonBox["Wave-Packet Amplitude",
    ButtonData:>"i:88",
    ButtonStyle->"Hyperlink"],
  ", and in ",
  ButtonBox["Sec. 5.3",
    ButtonData:>"i:90",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Hamiltonian Mechanics as the WKB Limit of Quantum Mechanics", "Section",
  CellTags->{"i:85", "c:29"}],

Cell[TextData[{
  "The evolution of the wave function ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi](x, t)\)]],
  " for a particle of mass ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  ", moving in one dimension under the influence of a given potential ",
  Cell[BoxData[
      \(TraditionalForm\`V(x)\)]],
  ",  is determined by Schr\[ODoubleDot]dinger's equation,"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[ImaginaryI]\ \[HBar] \(\[PartialD]\/\[PartialD]t\) \
\(\[Psi](x, 
            t)\) = \(-\(\[HBar]\^2\/\(2\ m\)\)\) \
\(\[PartialD]\^2\/\[PartialD]x\^2\) \(\[Psi](x, t)\)\  + \ \(V(x)\) \(\[Psi](
              x, t)\)\)]],
  "."
}], "NE2",
  CellTags->"(5.2.51)"],

Cell[TextData[{
  "The WKB method is useful for understanding the solution to this equation, \
provided that the wave function varies rapidly in space compared with the \
spatial scale of ",
  Cell[BoxData[
      \(TraditionalForm\`V(x)\)]],
  ", so that the WKB limit, Eq. ",
  ButtonBox["(5.2.7)",
    ButtonData:>"(5.2.7)",
    ButtonStyle->"Hyperlink"],
  ", holds. "
}], "Text"],

Cell[TextData[{
  "\tTo put  Eq. ",
  ButtonBox["(5.2.51)",
    ButtonData:>"(5.2.51)",
    ButtonStyle->"Hyperlink"],
  " into a form amenable to WKB analysis,  we apply a Fourier transform in \
time, defining ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\&~\)(x, \[Omega])\)]],
  " to be the temporal Fourier transform of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi](x, t)\)]],
  ". Then Eq. ",
  ButtonBox["(5.2.51)",
    ButtonData:>"(5.2.51)",
    ButtonStyle->"Hyperlink"],
  " becomes"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\[HBar]\ \[Omega] \(\( \[Psi]\&~\)(
            x, \[Omega])\) = \(-\(\[HBar]\^2\/\(2\ m\)\)\) \(\[PartialD]\^2\/\
\[PartialD]x\^2\) \(\(\[Psi]\&~\)(x, \[Omega])\) + \ \(V(x)\) \(\(\[Psi]\&~\)(
              x, \[Omega])\)\)]],
  "."
}], "Text"],

Cell["This equation can be rearranged to read", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\[PartialD]\^2\/\[PartialD]x\^2\) \(\(\[Psi]\&~\)(
            x, \[Omega])\) = \(-\(\(k\^2\)(x, \[Omega])\)\) \(\(\[Psi]\&~\)(
            x, \[Omega])\)\)]],
  ","
}], "NE2",
  CellTags->"(5.2.52)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`k(x, \[Omega])\)]],
  " is the local wavenumber of the ",
  "wave function",
  ", defined by the equation"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(k\^2\)(
          x, \[Omega]) = \(\(2\ m\)\/\[HBar]\^2\)[\[HBar]\ \[Omega] - 
            V(x)]\)]],
  "."
}], "NE2",
  CellTags->"(5.2.53)"],

Cell[TextData[{
  "Let us assume for the moment that   the energy of the packet, ",
  Cell[BoxData[
      \(TraditionalForm\`\[HBar]\ \[Omega]\_o\)]],
  ", is greater than ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(V(x)\)\)\)]],
  ", so that ",
  Cell[BoxData[
      \(TraditionalForm\`k(x, \[Omega]\_o)\)]],
  " is a real number.  Then  Eq. ",
  ButtonBox["(5.2.52)",
    ButtonData:>"(5.2.52)",
    ButtonStyle->"Hyperlink"],
  " is identical to Eq. ",
  ButtonBox["(5.2.3)",
    ButtonData:>"(5.2.3)",
    ButtonStyle->"Hyperlink"],
  ", and we already know the WKB solution to this problem . WKB wave packets \
propagating to the left or right are described by Eq. ",
  ButtonBox["(5.2.26)",
    ButtonData:>"(5.2.26)",
    ButtonStyle->"Hyperlink"],
  ", and if these packets are narrow in frequency, a packet traveling to the \
right with frequency ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_o\)]],
  " is given by Eq. ",
  ButtonBox["(5.2.44)",
    ButtonData:>"(5.2.44)",
    ButtonStyle->"Hyperlink"],
  ", with an analogous form for a packet traveling to the left."
}], "Text"],

Cell[TextData[{
  "\tThe center of the packet travels according to the equations of \
geometrical optics, given by Eqs. ",
  ButtonBox["(5.2.46)",
    ButtonData:>"(5.2.46)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(5.2.47)",
    ButtonData:>"(5.2.47)",
    ButtonStyle->"Hyperlink"],
  ". These equations can be written in a more recognizable form. The group \
velocity is related to the wavenumber ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  " through ",
  Cell[BoxData[
      \(TraditionalForm\`v\_g = \(\[HBar]\ k/m = p/m\)\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`p = \[HBar]\ k\)]],
  " is the particle momentum.  Also, the energy ",
  Cell[BoxData[
      \(TraditionalForm\`H = \[HBar]\ \[Omega]\)]],
  " of the particle can be written in terms of ",
  Cell[BoxData[
      \(TraditionalForm\`p\)]],
  " via Eq. ",
  ButtonBox["(5.2.53)",
    ButtonData:>"(5.2.53)",
    ButtonStyle->"Hyperlink"],
  ":  ",
  Cell[BoxData[
      \(TraditionalForm\`H = \(\[HBar]\[Omega] = \(\(\[HBar]\^2\) k\^2/2  m + 
              V(x) = p\^2/2  m + V(x)\)\)\)]],
  ". Using these two results, Eqs. ",
  ButtonBox["(5.2.46)",
    ButtonData:>"(5.2.46)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(5.2.47)",
    ButtonData:>"(5.2.47)",
    ButtonStyle->"Hyperlink"],
  " can be written as"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[DifferentialD]x/\[DifferentialD]t = \(\
\[PartialD]\(H(x, p)\)\/\[PartialD]p = p/m\)\)\(,\)\)\)]],
  StyleBox["\n",
    FontSize->9],
  "\n",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]p/\[DifferentialD]t\  = \(\(-\(\
\[PartialD]\(H(x, 
                    p)\)\/\[PartialD]x\)\) = \
\(-\(\[PartialD]V\/\[PartialD]x\)\)\)\)]],
  "."
}], "NE2",
  CellTags->"(5.2.54)"],

Cell[TextData[{
  "\tEquations ",
  ButtonBox["(5.2.54)",
    ButtonData:>"(5.2.54)",
    ButtonStyle->"Hyperlink"],
  " are the Hamiltonian equations of motion for a classical particle moving \
in the potential ",
  Cell[BoxData[
      \(TraditionalForm\`V(x)\)]],
  ". Thus, the equations of geometrical optics for the ",
  "wave packet",
  " of a quantum particle lead directly to the equations of classical \
mechanics."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Turning Points", "Section",
  CellTags->{"i:86", "c:30"}],

Cell[TextData[{
  "\tEquations ",
  ButtonBox["(5.2.53)",
    ButtonData:>"(5.2.53)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(5.2.54)",
    ButtonData:>"(5.2.54)",
    ButtonStyle->"Hyperlink"],
  " exhibit a rather unsettling phenomenon from the point of view of WKB \
theory: there can be positions for which ",
  Cell[BoxData[
      \(TraditionalForm\`k(x, \[Omega])\)]],
  " vanishes. These positions occur where ",
  Cell[BoxData[
      \(TraditionalForm\`E = \(\[HBar]\ \[Omega] = V(x)\)\)]],
  ", which is merely the equation for the classical turning points in the \
motion of the particle. At these points the WKB approximation breaks down. \
One can see this in two ways: (1) the limit  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(k\)\(\[Rule]\)\(0\)\(\ \)\)\)]],
  " implies that ",
  Cell[BoxData[
      \(TraditionalForm\`\((\[DifferentialD]\ ln\ \
k/\[DifferentialD]x)\)\^\(-1\)\)]],
  " is no longer small, and (2) the amplitude of the WKB solution, Eq. ",
  ButtonBox["(5.2.24)",
    ButtonData:>"(5.2.24)",
    ButtonStyle->"Hyperlink"],
  ",  is singular where ",
  Cell[BoxData[
      \(TraditionalForm\`k \[Rule] 0\)]],
  "."
}], "Text"],

Cell[TextData[{
  "\tIn the optics example discussed in relation to Eq. ",
  ButtonBox["(5.2.48)",
    ButtonData:>"(5.2.48)",
    ButtonStyle->"Hyperlink"],
  ", an analogous phenomenon occurred, referred to there as total internal \
reflection. The behavior of a wave packet near a turning point in either \
optics or in quantum theory can be treated with the same approach.  "
}], "Text"],

Cell[TextData[{
  "\tNear the turning point, we cannot use the WKB method. Instead,  we will \
Taylor expand ",
  Cell[BoxData[
      \(TraditionalForm\`k(x, \[Omega])\)]],
  " around the location of the turning point, ",
  Cell[BoxData[
      \(TraditionalForm\`x = x\_o\)]],
  ". At this point, ",
  Cell[BoxData[
      \(TraditionalForm\`k(x\_o\[InvisibleComma]\(\(,\)\(\[Omega]\)\)) = 
        0\)]],
  ".  Then we may write"
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(TraditionalForm\`\(k\^2\)(
          x, \[Omega])\  \[TildeTilde] \ \[Alpha]\ \((x - x\_o)\)\)]],
  ","
}], "NE2",
  CellTags->"(5.2.55)"],

Cell[TextData[{
  "where the constant ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  " is the slope of ",
  Cell[BoxData[
      \(TraditionalForm\`\(k\^2\)(x, \[Omega])\)]],
  " at ",
  Cell[BoxData[
      \(TraditionalForm\`x = x\_o\)]],
  ". This expansion is valid provided that we do not stray too far from ",
  Cell[BoxData[
      \(TraditionalForm\`x\_o\)]],
  ": we need to keep ",
  Cell[BoxData[
      \(TraditionalForm\`x - x\_o\ << \)]],
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " is the scale length for variation in ",
  Cell[BoxData[
      \(TraditionalForm\`k\)]],
  ". Also, we assume here that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\  \[NotEqual] \ 0\)]],
  ". "
}], "Text"],

Cell[TextData[{
  "\tLet us further assume that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] > 0\)]],
  ". This implies that the region ",
  Cell[BoxData[
      \(TraditionalForm\`x < x\_o\)]],
  " is the region of classically allowed orbits, and ",
  Cell[BoxData[
      \(TraditionalForm\`x > x\_o\)]],
  " is classically disallowed.  If we use Eq. ",
  ButtonBox["(5.2.55)",
    ButtonData:>"(5.2.55)",
    ButtonStyle->"Hyperlink"],
  " in Eq. ",
  ButtonBox["(5.2.52)",
    ButtonData:>"(5.2.52)",
    ButtonStyle->"Hyperlink"],
  ", and define ",
  Cell[BoxData[
      \(TraditionalForm\`y = x - x\_o\)]],
  ", we obtain the Airy equation:"
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\^\[DoublePrime]\)(
          y) = \[Alpha]\ y\ \(\[Psi](y)\)\)]],
  "."
}], "NE2",
  CellTags->"(5.2.56)"],

Cell["The general solution is", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Psi](y)\  = \ 
        C\_1\ \(Ai(\[Alpha]\^\(1/3\)\ y)\)\  + \ \(\(C\_2\)\(\ \
\)\(Bi(\[Alpha]\^\(1/3\)\ y)\)\(\ \ \)\)\)]],
  ","
}], "NE2",
  CellTags->"(5.2.57)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`Ai(x)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`Bi(x)\)]],
  " are Airy functions (see the discussion surrounding Eq. ",
  ButtonBox["(1.3.2)",
    ButtonData:>{"Chapter1.nb", "(1.3.2)"},
    ButtonStyle->"Hyperlink"],
  " ).  However,  for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] > 0\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`Bi(\[Alpha]\^\(1/3\)\ y)\)]],
  " blows up as ",
  Cell[BoxData[
      \(TraditionalForm\`y \[Rule] \ \[Infinity]\)]],
  ", so we must take ",
  Cell[BoxData[
      \(TraditionalForm\`C\_2 = 0\)]],
  " in order to obtain a finite wave function. Therefore, the ",
  "wave function",
  " near the turning point has the form"
}], "Text"],

Cell[TextData[Cell[BoxData[
    \(TraditionalForm\`\[Psi](x)\  = \ 
      C\_1\ \(\(Ai(\(\[Alpha]\^\(1/3\)\)(x - x\_o))\)\(.\)\)\)]]], "NE2",
  CellTags->"(5.2.58)"],

Cell[TextData[{
  "[This form also turns out to be correct when ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] < 0\)]],
  " , provided that when ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] < 0\)]],
  " we take the branch of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\^\(\(1/3\)\(\ \)\)\)]],
  " given by ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\^\(\(1/3\)\(\ \)\) = \ \
\(-\((\(|\)\(\[Alpha]\)\(|\))\)\^\(1/3\)\)\)]],
  ".] The solution is plotted in Cell ",
  ButtonBox["5.28",
    ButtonData:>"Cell 5.28",
    ButtonStyle->"Hyperlink"],
  " (for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha] > 0\)]],
  ")."
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot[AiryAi[x], {x, \(-20\), 3}, \ 
        PlotLabel \[Rule] "\<Behavior of the wave function near a turning \
point\>", 
        AxesLabel \[Rule] {\*"\"\<\!\(\[Alpha]\^\(\(1/3\)\(\\\ \)\)\)(x-\!\(x\
\_o\))\>\"", "\<\>"}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 5.28"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.851967 0.0414079 0.273053 0.616563 [
[.02381 .26055 -9 -9 ]
[.02381 .26055 9 0 ]
[.23085 .26055 -9 -9 ]
[.23085 .26055 9 0 ]
[.43789 .26055 -9 -9 ]
[.43789 .26055 9 0 ]
[.64493 .26055 -6 -9 ]
[.64493 .26055 6 0 ]
[1.025 .27305 0 -6.21875 ]
[1.025 .27305 60.6875 6.21875 ]
[.83947 .02643 -24 -4.5 ]
[.83947 .02643 0 4.5 ]
[.83947 .14974 -24 -4.5 ]
[.83947 .14974 0 4.5 ]
[.83947 .39637 -18 -4.5 ]
[.83947 .39637 0 4.5 ]
[.83947 .51968 -18 -4.5 ]
[.83947 .51968 0 4.5 ]
[.5 .63053 -149.062 0 ]
[.5 .63053 149.062 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .27305 m
.02381 .2793 L
s
[(-20)] .02381 .26055 0 1 Mshowa
.23085 .27305 m
.23085 .2793 L
s
[(-15)] .23085 .26055 0 1 Mshowa
.43789 .27305 m
.43789 .2793 L
s
[(-10)] .43789 .26055 0 1 Mshowa
.64493 .27305 m
.64493 .2793 L
s
[(-5)] .64493 .26055 0 1 Mshowa
.125 Mabswid
.06522 .27305 m
.06522 .2768 L
s
.10663 .27305 m
.10663 .2768 L
s
.14803 .27305 m
.14803 .2768 L
s
.18944 .27305 m
.18944 .2768 L
s
.27226 .27305 m
.27226 .2768 L
s
.31366 .27305 m
.31366 .2768 L
s
.35507 .27305 m
.35507 .2768 L
s
.39648 .27305 m
.39648 .2768 L
s
.4793 .27305 m
.4793 .2768 L
s
.5207 .27305 m
.5207 .2768 L
s
.56211 .27305 m
.56211 .2768 L
s
.60352 .27305 m
.60352 .2768 L
s
.68634 .27305 m
.68634 .2768 L
s
.72774 .27305 m
.72774 .2768 L
s
.76915 .27305 m
.76915 .2768 L
s
.81056 .27305 m
.81056 .2768 L
s
.89337 .27305 m
.89337 .2768 L
s
.93478 .27305 m
.93478 .2768 L
s
.97619 .27305 m
.97619 .2768 L
s
.25 Mabswid
0 .27305 m
1 .27305 L
s
gsave
1.025 .27305 -61 -10.2188 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20.4375 translate 1 -1 scale
63.000 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
69.000 9.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
73.188 9.438 moveto
(\\220) show
77.375 9.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(3) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
84.438 13.438 moveto
(H) show
90.438 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
96.438 13.438 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
102.438 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
108.438 15.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(o) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
113.688 13.438 moveto
(L) show
119.688 13.438 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.85197 .02643 m
.85822 .02643 L
s
[(-0.4)] .83947 .02643 1 0 Mshowa
.85197 .14974 m
.85822 .14974 L
s
[(-0.2)] .83947 .14974 1 0 Mshowa
.85197 .39637 m
.85822 .39637 L
s
[(0.2)] .83947 .39637 1 0 Mshowa
.85197 .51968 m
.85822 .51968 L
s
[(0.4)] .83947 .51968 1 0 Mshowa
.125 Mabswid
.85197 .05726 m
.85572 .05726 L
s
.85197 .08808 m
.85572 .08808 L
s
.85197 .11891 m
.85572 .11891 L
s
.85197 .18057 m
.85572 .18057 L
s
.85197 .2114 m
.85572 .2114 L
s
.85197 .24222 m
.85572 .24222 L
s
.85197 .30388 m
.85572 .30388 L
s
.85197 .33471 m
.85572 .33471 L
s
.85197 .36554 m
.85572 .36554 L
s
.85197 .42719 m
.85572 .42719 L
s
.85197 .45802 m
.85572 .45802 L
s
.85197 .48885 m
.85572 .48885 L
s
.85197 .55051 m
.85572 .55051 L
s
.85197 .58133 m
.85572 .58133 L
s
.85197 .61216 m
.85572 .61216 L
s
.25 Mabswid
.85197 0 m
.85197 .61803 L
s
gsave
.5 .63053 -210.062 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def

0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Behavior) show
117.000 13.000 moveto
(of) show
135.000 13.000 moveto
(the) show
159.125 13.000 moveto
(wavefunction) show
237.125 13.000 moveto
(near) show
267.125 13.000 moveto
(a) show
279.125 13.000 moveto
(turning) show
327.125 13.000 moveto
(point) show
357.125 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .16429 m
.03279 .31296 L
.03543 .35628 L
.03793 .39115 L
.04018 .41535 L
.04145 .42547 L
.04262 .43234 L
.04376 .43666 L
.04502 .43859 L
.04634 .43741 L
.04758 .43338 L
.04826 .42994 L
.04891 .42591 L
.05013 .41637 L
.05288 .3864 L
.05745 .31698 L
.06244 .23031 L
.0653 .18447 L
.06799 .14848 L
.06917 .13573 L
.07041 .12453 L
.07106 .11967 L
.07177 .11514 L
.07302 .10934 L
.07378 .10719 L
.07449 .10612 L
.07514 .10595 L
.07583 .10663 L
.07659 .10837 L
.0774 .11135 L
.07809 .11481 L
.07885 .11958 L
.0802 .13041 L
.08166 .14524 L
.08429 .17926 L
.09398 .34016 L
.09664 .37948 L
.0981 .39787 L
.09947 .41266 L
.10076 .42393 L
.10143 .42882 L
.10215 .43318 L
.10341 .43875 L
.10458 .44141 L
.10582 .4416 L
.10696 .43939 L
.10827 .43404 L
.10951 .42629 L
.11066 .41696 L
.11172 .40655 L
Mistroke
.11412 .37739 L
.11963 .29056 L
.12462 .20651 L
.12715 .169 L
.12848 .15186 L
.12989 .13615 L
.13112 .12461 L
.13247 .11459 L
.1337 .10802 L
.13484 .10415 L
.13552 .10291 L
.13625 .10245 L
.13695 .10288 L
.13759 .10401 L
.13881 .10805 L
.14009 .11502 L
.14148 .12539 L
.14277 .13768 L
.14572 .17372 L
.15558 .33367 L
.15797 .36982 L
.16053 .40238 L
.162 .4175 L
.16334 .42862 L
.16398 .43303 L
.16468 .43708 L
.16594 .44245 L
.1671 .44507 L
.16818 .44552 L
.16936 .4438 L
.17063 .4394 L
.17126 .43622 L
.17196 .43203 L
.17322 .42256 L
.17558 .39884 L
.18019 .33489 L
.18446 .26443 L
.18908 .1901 L
.19151 .15676 L
.19407 .12852 L
.19516 .11909 L
.19632 .11087 L
.19759 .10418 L
.19878 .10022 L
.19994 .0985 L
.20104 .09887 L
.20203 .10085 L
.2031 .10473 L
.20438 .11167 L
.20558 .12034 L
Mistroke
.2083 .14728 L
.21096 .18165 L
.21381 .22499 L
.2186 .30376 L
.22369 .38056 L
.22645 .41286 L
.22774 .42499 L
.22894 .43416 L
.23014 .44137 L
.23145 .44675 L
.2326 .44936 L
.23381 .44992 L
.23512 .44798 L
.23586 .44574 L
.23653 .44298 L
.23783 .43575 L
.23907 .4267 L
.24184 .39932 L
.24484 .36026 L
.2544 .20896 L
.25701 .17111 L
.25984 .1369 L
.26113 .12407 L
.2625 .11281 L
.26366 .10516 L
.26494 .09896 L
.26558 .09671 L
.26627 .09496 L
.26754 .09359 L
.26876 .09452 L
.2699 .09733 L
.27112 .10245 L
.27182 .10629 L
.27247 .11049 L
.27519 .13392 L
.27759 .16158 L
.27979 .19142 L
.28473 .26813 L
.28989 .34909 L
.29261 .38644 L
.29551 .4189 L
.29695 .43156 L
.2983 .44114 L
.29951 .4477 L
.30082 .45255 L
.30207 .45494 L
.30338 .45509 L
.30451 .45329 L
.30574 .44931 L
.30705 .4428 L
Mistroke
.30826 .4348 L
.311 .41019 L
.31598 .34679 L
.3253 .20258 L
.33014 .13959 L
.33146 .12591 L
.33289 .11331 L
.33422 .10364 L
.33546 .09663 L
.33613 .09368 L
.33684 .09117 L
.33763 .08916 L
.33835 .08806 L
.33902 .08764 L
.33976 .08789 L
.34045 .08878 L
.34109 .09017 L
.34228 .09419 L
.34359 .10071 L
.34496 .10977 L
.34624 .12021 L
.35527 .23498 L
.36486 .37814 L
.36727 .40702 L
.36987 .43223 L
.37135 .44345 L
.37271 .45151 L
.37402 .45712 L
.37467 .45916 L
.37539 .46077 L
.37667 .46203 L
.37783 .46138 L
.37847 .4603 L
.37917 .45853 L
.38044 .4538 L
.38162 .44762 L
.38288 .43931 L
.38513 .42013 L
.39035 .35827 L
.39524 .28661 L
.40105 .19963 L
.40359 .16545 L
.40636 .13321 L
.40894 .10919 L
.4102 .09991 L
.41134 .09296 L
.41252 .08729 L
.41362 .08341 L
.41479 .08087 L
.41606 .07996 L
Mistroke
.41732 .08093 L
.41804 .08231 L
.4187 .08414 L
.42005 .08938 L
.42149 .09723 L
.4241 .11701 L
.42648 .14062 L
.43654 .27772 L
.44204 .35725 L
.44474 .39166 L
.44721 .41889 L
.4493 .43807 L
.4516 .45432 L
.45279 .46069 L
.4539 .46527 L
.45507 .46866 L
.45632 .47063 L
.45762 .47085 L
.45835 .47015 L
.45903 .46899 L
.46027 .46557 L
.46159 .46017 L
.46276 .45382 L
.46386 .44664 L
.46637 .42614 L
.47579 .31019 L
.48077 .23814 L
.48606 .1666 L
.49067 .11636 L
.49329 .09497 L
.49449 .08721 L
.49576 .08048 L
.49683 .07599 L
.49801 .07237 L
.49908 .07028 L
.50007 .06938 L
.50125 .0696 L
.50233 .07101 L
.50357 .07407 L
.50474 .07834 L
.50591 .08391 L
.5072 .0915 L
.5098 .11125 L
.51448 .15937 L
.52505 .30169 L
.5296 .36287 L
.53456 .41993 L
.53683 .44099 L
.53925 .45921 L
.54042 .46636 L
Mistroke
.54153 .47203 L
.54252 .47618 L
.5436 .47974 L
.54483 .48252 L
.54614 .48396 L
.54734 .48392 L
.54847 .48269 L
.54915 .48139 L
.5498 .47977 L
.55101 .47576 L
.55232 .47003 L
.55374 .46219 L
.55608 .44584 L
.55856 .4242 L
.56301 .37613 L
.57306 .24439 L
.57834 .17627 L
.58389 .11578 L
.58624 .09536 L
.58875 .07759 L
.59019 .06941 L
.5915 .06333 L
.59281 .05855 L
.59406 .05528 L
.59519 .05336 L
.59638 .05244 L
.5974 .05255 L
.59853 .05362 L
.59973 .05587 L
.60103 .05954 L
.60225 .06417 L
.60337 .06936 L
.60786 .09884 L
.6104 .12101 L
.61275 .14454 L
.62165 .25094 L
.63225 .38276 L
.63745 .43627 L
.63973 .45576 L
.64222 .47387 L
.64433 .48627 L
.64658 .49649 L
.64782 .50074 L
.64896 .50373 L
.6501 .50588 L
.65117 .50712 L
.65234 .5076 L
.65358 .50712 L
.65464 .50591 L
.65581 .50375 L
Mistroke
.65706 .50046 L
.65841 .49583 L
.66084 .48468 L
.66337 .46953 L
.66607 .44968 L
.67093 .40581 L
.68196 .28185 L
.69242 .16099 L
.697 .11496 L
.70204 .07279 L
.70704 .04153 L
.70977 .02935 L
.71099 .02507 L
.71232 .02125 L
.71306 .01948 L
.71376 .0181 L
.7144 .01701 L
.71512 .01606 L
.71636 .015 L
.71768 .01472 L
.71842 .01493 L
.71911 .01536 L
.71986 .01609 L
.72065 .01716 L
.72198 .01961 L
.72343 .02325 L
.72608 .03227 L
.72848 .04306 L
.73388 .07544 L
.7436 .15629 L
.76438 .36768 L
.77351 .45173 L
.77835 .49004 L
.78356 .52536 L
.78859 .55329 L
.7932 .57329 L
.79541 .58103 L
.79783 .5881 L
.80009 .59345 L
.80222 .5974 L
.80348 .59923 L
.80483 .60082 L
.80606 .60192 L
.80719 .60265 L
.80842 .60313 L
.80911 .60328 L
.80976 .60332 L
.81108 .60316 L
.81181 .60292 L
.81248 .60262 L
Mistroke
.8137 .60186 L
.81482 .60093 L
.81737 .59802 L
.81962 .5946 L
.822 .59017 L
.83138 .56601 L
.84149 .53168 L
.85978 .46208 L
.87945 .39422 L
.88984 .36514 L
.90094 .33991 L
.91171 .32083 L
.92149 .30756 L
.93132 .29748 L
.9406 .29039 L
.9496 .28531 L
.95912 .28142 L
.96725 .27902 L
.97619 .27712 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{328, 202.562},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006J0000oB000`400?l00000o`00003ooooooonK
ooooo`00oooooonKooooo`00oooooonKooooo`00oooooonKooooo`00oooooonKooooo`00oooooonK
ooooo`00oooooonKooooo`00oooooonKooooo`00oooooonKooooo`00oooooonKooooo`00oooooonK
ooooo`00oooooonKooooo`00oooooonKooooo`00oooooonKooooo`00oooooonKooooo`00oooooonK
ooooo`00oooooonKooooo`00oooooonKooooo`00oooooonKooooo`00oooooonKooooo`00oooooonK
ooooo`00oooooonKooooo`00oooooonKooooo`00oooooonKooooo`00oooooonKooooo`00oooooonK
ooooo`00oooooonKooooo`00oooooonKooooo`00oooooonKooooo`00oooooonKooooo`00oooooonK
ooooo`00oooooolMooooo`03o`000?oooooooooo07_ooooo003ooooooagooooo00?o0000oooooooo
ool0Noooool00?oooooo7Oooool00ol0003oooooooooo`1kooooo`00oooooolMooooo`03o`000?oo
oooooooo07_ooooo003fooooo`;o00009?ooool00ol0003oooooooooo`1kooooo`00mOooool2o`00
0003ooooool0003ooooo00Sooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1_ooool2
o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooooooool0Noooool00?Gooooo00Co0000oooo
oooooooo00002Oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B47ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool0Noooool00?Gooooo00Go0000oooooooooooo0000oooo
o`06o`0000;ooooo00Go410@oooooooooooooooooa0@400;ooooo`Go00001Oooool3o`0007_ooooo
003dooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool01Ol0003ooooooooo
oooooooo000000_ooooo00CoA4A4omgMgOoooooo00001_ooool00ol0003oooooooooo`1kooooo`00
m?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00Go0000oooooooooooo
ooooo`00000;ooooo`04omgMgOmEEEGoooooo`0000Kooooo00?o0000ooooooooool0Noooool00?Co
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06ooooo`05oa0@4?oooooooooooooo
ool@41003?ooool00omgMgOoc<c<o`000006ooooo`03o`000?oooooooooo07_ooooo003dooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?ok^k^odA4A?l000001_ooool00ol0003oooooooooo`1kooooo`00m?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0=oooo
o`03ogMgMol0003ooooo00Gooooo00?o0000ooooooooool0Noooool00?Cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo07_ooooo003Eooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Oooooo`03o`00
0?oooooooooo07_ooooo003Dooooo`?o00007?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo01oooooo00?o0000ooooooooool0Noooool00=Cooooo00?o0000ooooool000007?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo01oooooo0_l0001looooo`00doooool01?l0
003oooooooooool0000Looooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`1kooooo`00doooool01?l0003oooooooooool0000Looooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1kooooo`00^_ooool00ol0
003oooooooooo`0Fooooo`05o`000?ooooooooooooooool000006_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0Noooool00;Wooooo0ol0000Goooo
o`05o`000?ooooooooooooooool000006_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool0Noooool00;Wooooo00?o0000ooooool000005oooool01Ol0
003ooooooooooooooooo000001[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo07_ooooo002Rooooo`;o00005Oooool00ol0003oooooo`00000Goooo
o`05o`000?ooooooooooooooool000006_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool0Noooool00:;ooooo0_l0000Eooooo`03o`000?oooooo0000
01Oooooo00Go0000ooooooooooooooooo`00000Jooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`1kooooo`00SOooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooo000001Cooooo00Co0000oooooooooooo00005_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0N
ooooo`;o0000O?ooool008cooooo0_l0000Cooooo`03o`000?oooooo000001Cooooo00Go0000oooo
ooooooooooooo`00000Eooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0Noooool0
07Sooooo0_l0000Booooo`03o`000?oooooo000001;ooooo00?o0000ooooool000005?ooool01Ol0
003ooooooooooooooooo000001Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1k
ooooo`00I_ooool00ol0003oooooooooo`0?ooooo`;o00004_ooool00ol0003oooooo`00000Boooo
o`04o`000?ooooooooooo`0001?ooooo00Go0000ooooooooooooooooo`00000Eooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool0Noooool005Cooooo00?o0000ooooooooool03oooool2
o`00013ooooo00?o0000ooooool000004Oooool00ol0003oooooo`00000Booooo`04o`000?oooooo
ooooo`0001?ooooo00Go0000ooooooooooooooooo`00000Eooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool0Noooool004?ooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooo0000013ooooo00?o0000ooooool000004?ooool01?l0003ooooooooo
ool0000Booooo`04o`000?ooooooooooo`0001?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0Booooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0Noooool004;ooooo
0_l0000?ooooo`03o`000?oooooo000000oooooo00?o0000ooooool000004?ooool00ol0003ooooo
o`00000@ooooo`04o`000?ooooooooooo`00017ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo07_ooooo0012ooooo`03o`000?oooooo000000kooooo
00?o0000ooooool000003oooool00ol0003oooooo`00000?ooooo`04o`000?ooooooooooo`00013o
oooo00Co0000oooooooooooo00004Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool0Noooool004;ooooo00?o0000ooooool000003_ooool00ol0003o
ooooo`00000?ooooo`03o`000?oooooo000000oooooo00Co0000oooooooooooo00004?ooool01Ol0
003ooooooooooooooooo0000013ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo07_ooooo0012ooooo`03o`000?oooooo000000kooooo00?o0000oooo
ool000003oooool00ol0003oooooo`00000?ooooo`04o`000?ooooooooooo`00013ooooo00Go0000
ooooooooooooooooo`00000@ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool07?oo
ool2o`0007cooooo0012ooooo`03o`000?oooooo000000kooooo00Co0000oooooooooooo00003_oo
ool00ol0003oooooo`00000?ooooo`04o`000?ooooooooooo`00013ooooo00Go0000oooooooooooo
ooooo`00000@ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`1kooooo`00@_ooool00ol0003oooooo`00000>ooooo`04o`000?ooooooooooo`0000go
oooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo000000oooooo00Go0000
ooooooooooooooooo`00000@ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`1kooooo`00@_ooool00ol0003oooooo`00000>ooooo`04o`000?oooooo
ooooo`0000gooooo00Co0000oooooooooooo00003oooool01Ol0003ooooooooooooooooo000000oo
oooo00Go0000ooooooooooooooooo`00000@ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`1kooooo`00@Oooool01?l0003oooooooooool0000=oooo
o`05o`000?ooooooooooooooool000003Oooool01?l0003oooooooooool0000?ooooo`05o`000?oo
ooooooooooooool000003oooool01Ol0003ooooooooooooooooo0000013ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo07_ooooo0011ooooo`04o`00
0?ooooooooooo`0000gooooo00Go0000ooooooooooooooooo`00000=ooooo`05o`000?oooooooooo
ooooool000003_ooool01Ol0003ooooooooooooooooo000000kooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`1kooooo`00@Oooool01Ol0003ooooooooooooooooo000000cooooo00Go
0000ooooooooooooooooo`00000=ooooo`05o`000?ooooooooooooooool000003_ooool01Ol0003o
oooooooooooooooo000000kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B44ooooo`Go00001Oooool00ol0003oooooooooo`1kooooo`00@Oooool01Ol0
003ooooooooooooooooo000000cooooo00Go0000ooooooooooooooooo`00000=ooooo`05o`000?oo
ooooooooooooool000003_ooool01Ol0003ooooooooooooooooo000000kooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00_ooooo00Wo0000oooooooo
ooooooooogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A005ooooo`03o`000?oooooooooo07_ooooo0011ooooo`05o`000?ooooooooooooooool00000
3?ooool01Ol0003ooooooooooooooooo000000gooooo00Go0000ooooooooooooooooo`00000>oooo
o`05o`000?ooooooooooooooool000003_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool01oooool6o`0000;ooooo00Go410@oooooooooooooooooa0@
400<ooooo`03oiRHV?lQ8B7ok^k^00Kooooo00?o0000ooooooooool0Noooool0047ooooo00Go0000
ooooooooooooooooo`00000<ooooo`05o`000?ooooooooooooooool000003Oooool01Ol0003ooooo
oooooooooooo000000kooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0;ooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0;ooooo`03oiRHV?lQ8B7ok^k^
00Gooooo0ol0001kooooo`00@Oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000oooo
ooooooooooooo`00000=ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`00
0?oooooooooo00cooooo00?oMgMgofIVI_ooool01?ooool00ol0003oooooooooo`1kooooo`00@Ooo
ool01Ol0003ooooooooooooooooo000000cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0:ooooo`05o`000?ooooooooooooooool000003Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo00_ooooo00Go0000oooooooooooooooooa0@4003ooooo`03oa0@4?oooooooooo
00gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1kooooo`00@Oooool01Ol0003o
oooooooooooooooo000000cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:oooo
o`05o`000?ooooooooooooooool000003Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo00_ooooo00Wo0000ooooooooooooooooogMgMonHV9SooooooiRHV?mgMgL02oooool01Ol0003o
^[ZjoooooonHV9So410@00Gooooo00?o0000ooooooooool0Noooool003Gooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0:ooooo`05o`000?ooooooooooooooool000003Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo00_ooooo00Wo0000ooooooooooooooooonk^k_lb
<S;o0000oc8b<_o^k^h02oooool01OnHV9So410@o`000?lQ8B7oc<c<00Gooooo00?o0000oooooooo
ool0Noooool003Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1kooooo`00=Ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo07_ooooo000eooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool0Noooool003Gooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool06_ooool2o`00
07cooooo000eooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0Noooool003Gooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`1kooooo`00=Oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo07_ooooo000eooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool0Noooool003Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1koooo
o`00=Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo07_ooooo000fooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool0Noooool003Kooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`1kooooo`00=_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Iooooo`;o0000O?ooool0
03Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1kooooo`00=_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo07_ooooo000fooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo01Wooooo
00?o0000ooooooooool0Noooool003Kooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`1kooooo`00<_ooool5o`0000?ooooo00Kok^k^oc8b<_l0003o<S8bonk^k_l00007ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01?l000001?l@413oooooooooooooool3o`000003
oc8b<_oMgMgooooo00;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool01Oooool4o`000008oa0@4?ooooooooooonk^
k_lb<S;o0000oc8b<_o^k^h2ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00GoA4A4o`000?l0003o<S8b
omgMg@05ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`1kooooo`00<_ooool01OnHV9So8B4Qonk^k_oooooo000000?ooooo00KoMgMgoiRHV?oooooo
V9RHogMgMol00007ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`05o`000?ooooooooooogMgMolb<S800oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`06
ooooo`;o00001?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00;ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Ooo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`1kooooo`00:_ooool6o`0000?ooooo00CoV9RHob4Q8Oo^k^ko00000ooo
ool01_l@413ooooooooooooooooo410@o`0000Oooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooool000001_l00004ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo0000
00[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`09ooooo`Ko00001?ooool2o`00
00Cooooo00Go410@oooooooooooooooooa0@4002ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0:ooooo`Ko00001oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1k
ooooo`00=?ooool00onHV9So8B4Qo`000003ooooo`04o`000?ooooooooooooooo`;o00001oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool0
1_l0003oooooooooooooooooMgMgoc8b<P?ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01_ooool2o`0000Cooooo
00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo00?oMgMgoc8b<_oo
ool01?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo01Wooooo0_l0001looooo`00
=Oooool00omgMgOo0000ooooo`02ooooo`04o`000?ooooooooooooooo`;o00001oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool2o`000004
ob4Q8Ol0003o<S8bolc<c0?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01_ooool2o`0000Cooooo00Go0000oooo
ooooooooooooo`000002ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo00Go0000ob4Q8Ol0003o<S8bolc<
c005ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`1kooooo`00=_ooool01Ol0003ooooooooooooooooo410@00?ooooo00?o410@o`000?ooool01_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_oo
ool2o`0000Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool01oooool2o`0000Cooooo00Go410@oooooooooooooooo
oa0@4002ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0Noooool003;ooooo00Go
0000okZj^_ooooooV9RHo`000003ooooo`06ogMgMonHV9SooooooiRHV?mgMgOo00001oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool2o`00
00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool01oooool2o`0000Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`02
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0Noooool003;ooooo00GoV9RHoa0@
4?l0003o8B4Qo`000003ooooo`06onk^k_lb<S;o0000oc8b<_o^k^ko00001oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`05ooooo`06o`000?oooooooooooeEEEOmVIVKo00001?ooool5o`0000Gooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool01_ooool00omEEEGo0000o`000004ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h00_ooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`05ooooo`Co00001_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool0D?ooool00omgMgOoIVIVooooo`0Gooooo`;o00001?ooool0
0omVIVKoMgMgooooo`08ooooo`00=_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
04oooooo00?ogMgMoa0@4?o^k^h05oooool01?l0003oooooooooool00003ooooo`03onk^k_l@413o
gMgM00Sooooo000fooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0<Oooool01onH
V9So0000o`000?mEEEGok^k^ofIVI_l000005oooool01?mEEEGoV9RHooooooooool2o`0000;ooooo
0_l00009ooooo`;o00000_ooool2o`000005ooooool0003oooooooooool000001?ooool00on7QhOo
IVIVooooo`07ooooo`00=_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo037ooooo
00Ko0000ojVYZOooooooQhN7oc8b<_mVIVHHooooo`0:o`000?ooooooooooooooooo^k^ko8B4QohN7
Qonj^[[o0000omgMg@Wooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd2ooooo`;o00001Oooool0
0oo^k^ko0000ooooo`07ooooo`00=_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
037ooooo00Ko0000ooooooooooooooooohN7Qom4A4@Hooooo`03oc8b<_oooooooooo00;ooooo00Co
gMgMo`000?l@413oc<c<0oooool6o`0000;ooooo00CogMgMo`000?l@413oc<c<2oooool00ol0003o
ooooooooo`06ooooo`00;_ooooooo`0001[o00002Oooool01_lQ8B7oc<c<ooooooooooooV9RHoc8b
<QSooooo00?o<S8booooooooool00_ooool01?o^k^ko8B4Qoa0@4?o^k^h;ooooo`04onk^k_lQ8B7o
410@onk^kP_ooooo00?o0000ooooooooool01_ooool003Gooooo0_l00007ooooo`03o`000?oooooo
000000Kooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00007ooooo`03o`000?oo
oooo000000Sooooo0_l00007ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooo
ooooo`03ooooo`05o`000?ooooooooooooooool000001oooool2o`0000Wooooo0_l0000:ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool2o`0000_ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooo`000009ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`08ooooo`;o00002oooool00ol0003oooooooooo`04ooooo`05
o`000?ooooooooooooooool000002oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`;o00004?ooool01onY
ZJWo8B4QomgMgOo^k^ko<S8boeEEEOnj^[X01_ooool00ol0003oooooooooo`0>ooooo`03o`000?o^
k^kooooo00;ooooo00Co8B4QogMgMomgMgOo<S8b2oooool01?lQ8B7oMgMgogMgMolb<S8:ooooo`03
onk^k_l0003ooooo00Oooooo000eooooo`03o`000?oooooo000000Kooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`06ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo01_ooooo1?l0000Cooooo`07oiRHV?l0003o0000oiRH
V?nj^[[o<S8booooo`03o`0000;ooooo00?o0000ooooooooool00_ooool2o`0000[ooooo00CoEEEE
ogMgMooooooooooo0_l00002ooooo`;o00002Oooool2o`0000;ooooo0_l00009ooooo`03ogMgMomE
EEGooooo00Oooooo000gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_oo
ool00ol0003oooooooooo`07ooooo`03omgMgOl@413ok^k^01kooooo00?ok^k^oa0@4?oMgMd02?oo
ool003Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Hooooo`;o00008?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool0
0omgMgOoIVIVooooo`0Mooooo`03ofIVI_mgMgOooooo00Sooooo000gooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool05Oooool3o`0002;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo03Cooooo000gooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooool000000_ooool00ol0003oooooooooo`0cooooo`00=oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool08oooool2o`0000Gooooo
00?o0000ooooooooool00_l0000fooooo`00=oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool0IOooool003Oooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool05oooool2
o`0001?ooooo00?o0000ooooooooool0I_ooool003Oooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo06Oooooo000gooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`1Xooooo`00=oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0JOooool003Oooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Cooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo06[ooooo000g
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1Z
ooooo`00=oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool0Joooool003Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo06_ooooo000gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Kooooo0_l0000=ooooo`03o`00
0?oooooooooo06cooooo000hooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`1/ooooo`00>?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool0KOooool003Sooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo06gooooo000hooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1^ooooo`00>?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0K_ooool003Sooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo06oooooo000h
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1_
ooooo`00>?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool0Koooool003Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool05Oooool2o`0000Wooooo00?o0000oooooooo
ool0L?ooool003Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo073ooooo000hooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`1aooooo`00>Oooool01Ol0003ooooooooooooooooo000000_ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool0LOooool003Wooooo00Go0000ooooooooooooooooo`00000;ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00_ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo077ooooo000iooooo`05o`000?ooooooooooooooool000002oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`1booooo`00>Oooool01Ol0003ooooooooooooooooo000000_ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`0:ooooo`05o`000?ooooooooooooooool000003Oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0<ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool05Oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B44ooooo`Go00001Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo07;ooooo000iooooo`05o`000?ooooooooooooooool000002oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00[ooooo00Go0000ooooooooooooooooo`00000=oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Eoooo
o`05ogMgMonHV9So0000oiRHV?mgMgL01Oooool2ob4Q8@Cooooo00GoV9RHob4Q8Oo^k^koooooodA4
A005ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0L_ooool003Wooooo00Go0000
ooooooooooooooooo`00000;ooooo`05o`000?ooooooooooooooool000003Oooool01Ol0003ooooo
oooooooooooo000000gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`08ooooo`03
o`000?oooooooooo01Gooooo00Go410@oooooooooooo0000oa0@400<ooooo`03oiRHV?lQ8B7ok^k^
00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`1cooooo`00>Oooool01Ol0003o
oooooooooooooooo000000_ooooo00Go0000ooooooooooooooooo`00000=ooooo`05o`000?oooooo
ooooooooool000003Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`02o`0000gooooo00?oV9RHob4Q8Oo^k^h01Ooo
ool3o`0000Gooooo00?o0000ooooooooool0Loooool003Wooooo00Go0000ooooooooooooooooo`00
000;ooooo`05o`000?ooooooooooooooool000003Oooool01Ol0003ooooooooooooooooo000000go
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool00_l0000>ooooo`03ogMgMomVIVKooooo00Cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`1cooooo`00>Oooool01?l0003oooooooooool0000<ooooo`05
o`000?ooooooooooooooool000003Oooool01Ol0003ooooooooooooooooo000000gooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0<ooooo`05o`000?ooooooooooooooool000003ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01Gooooo00Go410@oooooooooooo0000
oa0@400?ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`1dooooo`00>Oooool01?l0003oooooooooool0000=ooooo`04o`000?ooooooooooo`0000go
oooo00Go0000ooooooooooooooooo`00000=ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool03?ooool01Ol0003ooooooooooooooooo000000oooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`0Eooooo`05ogMgMonHV9Soooooo`000?mgMgL02oooool01Ol0003o^[Zjoooo
oonHV9So410@00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`1dooooo`00>Ooo
ool01?l0003oooooooooool0000=ooooo`04o`000?ooooooooooo`0000gooooo00Co0000oooooooo
oooo00003_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00cooooo00Go0000oooo
ooooooooooooo`00000?ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool05Oooool0
1Oo^k^ko<S8bo`000?l0003ok^k^00_ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c005ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0M?ooool003Wooooo00Co0000oooooooooooo0000
3Oooool01?l0003oooooooooool0000=ooooo`04o`000?ooooooooooo`0000kooooo00Go0000oooo
ooooooooooooo`00000?ooooo`05o`000?ooooooooooooooool000003oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo07Gooooo000iooooo`04o`000?ooooooooooo`0000gooooo00Co
0000oooooooooooo00003Oooool01?l0003oooooooooool0000>ooooo`05o`000?oooooooooooooo
ool000003oooool01Ol0003ooooooooooooooooo000000oooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`1eooooo`00>_ooool00ol0003oooooo`00000=ooooo`04o`000?oooooooooo
o`0000gooooo00Co0000oooooooooooo00003oooool01?l0003oooooooooool0000?ooooo`04o`00
0?ooooooooooo`00013ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`1eooooo`00
>_ooool00ol0003oooooo`00000=ooooo`04o`000?ooooooooooo`0000kooooo00?o0000ooooool0
00003oooool01?l0003oooooooooool0000?ooooo`04o`000?ooooooooooo`00013ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Cooooo0_l00003
ooooo`03o`000?oooooooooo07Kooooo000jooooo`03o`000?oooooo000000gooooo00Co0000oooo
oooooooo00003_ooool00ol0003oooooo`00000?ooooo`04o`000?ooooooooooo`0000oooooo00Co
0000oooooooooooo00004?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00oooooo
00Go0000ooooooooooooooooo`00000Booooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo07Kooooo000jooooo`;o0000
3oooool2o`0000oooooo00?o0000ooooool000003oooool01?l0003oooooooooool0000?ooooo`04
o`000?ooooooooooo`00013ooooo00Go0000ooooooooooooooooo`00000Booooo`05o`000?oooooo
ooooooooool000004oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`1fooooo`00>_ooool2o`0000oooooo0_l0000?
ooooo`03o`000?oooooo000000oooooo00Co0000oooooooooooo00003oooool01?l0003ooooooooo
ool0000@ooooo`05o`000?ooooooooooooooool000004_ooool01Ol0003ooooooooooooooooo0000
01?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Cooooo`05o`000?oooooooooo
ooooool00000NOooool004_ooooo0_l0000?ooooo`03o`000?oooooo000000oooooo00Co0000oooo
oooooooo00003oooool01?l0003oooooooooool0000Aooooo`04o`000?ooooooooooo`0001;ooooo
00Go0000ooooooooooooooooo`00000Cooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool04oooool01Ol0003ooooooooooooooooo000007Wooooo001Mooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooool000004?ooool01?l0003oooooooooool0000Aooooo`04o`000?oooooooooo
o`0001;ooooo00Go0000ooooooooooooooooo`00000Cooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool04oooool01Ol0003ooooooooooooooooo000007Wooooo001_ooooo`;o00004Ooo
ool00ol0003oooooo`00000Aooooo`04o`000?ooooooooooo`0001;ooooo00Go0000oooooooooooo
ooooo`00000Cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool04oooool01?l0003o
ooooooooool0001jooooo`00Koooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo0000017o
oooo00Co0000oooooooooooo00004_ooool01Ol0003ooooooooooooooooo000001Cooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`0Cooooo`04o`000?ooooooooooo`0007[ooooo0022
ooooo`;o00004_ooool00ol0003oooooo`00000Cooooo`04o`000?ooooooooooo`0001Gooooo00Go
0000ooooooooooooooooo`00000Gooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`0Cooooo`04o`000?ooooooooooo`0007[ooooo002Gooooo`;o0000
4oooool01?l0003oooooooooool0000Eooooo`05o`000?ooooooooooooooool000005oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool04oooool3o`00
07_ooooo002Gooooo`;o00005?ooool00ol0003oooooo`00000Eooooo`05o`000?oooooooooooooo
ool000005oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01_ooooo00?o0000oooo
ooooool04oooool00ol0003oooooo`00001kooooo`00[Oooool00ol0003oooooo`00000Eooooo`05
o`000?ooooooooooooooool000006?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool04_ooool00ol0003oooooo`00001kooooo`00[Oooool2o`0001Ko
oooo00Co0000oooooooooooo00006Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool04_ooool00ol0003oooooo`00001kooooo`00aOooool01?l0003o
ooooooooool0000Iooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`0Booooo`;o0000O?ooool00<Kooooo00?o0000ooooool000006Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool04_ooool2o`0007co
oooo0036ooooo`03o`000?oooooo000001Wooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo01;ooooo0_l0001looooo`00a_ooool2o`0001[ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo017ooooo0_l0
001looooo`00h_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01kooooo00?o0000
ooooooooool04Oooool2o`0007cooooo003Rooooo`05o`000?ooooooooooooooool000008Oooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo07_ooooo003Sooooo`04o`000?oooooooooo
o`00027ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1kooooo`00hoooool01?l0
003oooooooooool0000Qooooo`03o`000?oooooooooo013ooooo0_l0001mooooo`00hoooool01?l0
003oooooooooool0000Qooooo`03o`000?oooooooooo013ooooo0_l0001mooooo`00hoooool3o`00
02;ooooo00?o0000ooooooooool04?ooool2o`0007gooooo003Tooooo`;o00008_ooool00ol0003o
ooooooooo`0@ooooo`;o0000OOooool00?oooooo0oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00;o
oooo00?o0000ooooooooool00_lQ8B46ooooo`;o000000Oo410@ooooooooooooooooo`000?oooooo
000007gooooo003oooooo`?ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`02ooooo`03o`000?oooooo
oooo00;o8B4Q1oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000007gooooo003ooooo
o`?ooooo00Go410@oooooooooooooooooa0@4002ooooo`03o`000?oooooooooo00Kooooo1Ol00003
ooooo`03o`000?oooooo000000;o0000Noooool00?oooooo0oooool01Ol0003ooooooooooooooooo
000000;ooooo00?o0000ooooooooool01_ooool01?m4A4CogMgMooooool00004ooooo`03o`000?oo
oooo000007gooooo003oooooo`?ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oo
oooooooo00Kooooo00CogMgMoeEEEOoooooo00000oooool01?l0003oooooooooool0001mooooo`00
ooooool3ooooo`05oa0@4?ooooooooooooooool@41000_ooool00ol0003oooooooooo`07ooooo`03
ogMgMoo<c<co000000?ooooo00Co0000oooooooooooo0000OOooool00?oooooo0oooool01OmgMgOo
V9RHoooooonHV9SoMgMg00;ooooo00?o0000ooooooooool01oooool00oo^k^koA4A4o`000003oooo
o`04o`000?ooooooooooo`0007gooooo003oooooo`?ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP03
ooooo`03o`000?oooooooooo00Oooooo00?oMgMgo`000?ooool00_ooool01?l0003oooooooooool0
001mooooo`00ooooool;ooooo`03o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`00
001mooooo`00ooooool;ooooo`03o`000?oooooooooo00_ooooo00Go0000ooooooooooooooooo`00
001mooooo`00ooooool<ooooo`03o`000?oooooooooo00[ooooo00Go0000ooooooooooooooooo`00
001mooooo`00ooooool<ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool2
o`0007cooooo003oooooo`cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo07_ooooo003oooooo`cooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo07_ooooo003oooooo`cooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07_ooooo003oooooo`gooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07_ooooo003o
ooooo`gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo07_ooooo003oooooo`gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo07_ooooo003oooooo`gooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo07_ooooo003oooooo`gooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`04ooooo`;o0000O?ooool00?oooooo3Oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Noooool00?oooooo3_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Noooool0
0?oooooo3_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0Noooool00?oooooo3oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool0Noooool00?oooooo3oooool2o`0000?ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`1kooooo`00ooooool@ooooo`Co00002Oooool00ol0003ooooooooo
o`1kooooo`00oooooolMooooo`03o`000?oooooooooo07_ooooo003ooooooagooooo00?o0000oooo
ooooool0Noooool00?oooooo7Oooool2o`0007cooooo003ooooooagooooo00?o0000ooooooooool0
Noooool00?oooooo7Oooool00ol0003oooooooooo`1kooooo`00oooooonKooooo`00oooooonKoooo
o`00oooooonKooooo`00oooooonKooooo`00oooooom3ooooo`05ob4Q8Ol0003o0000odA4A?oMgMd0
1_ooool01?l@413o0000o`000?l00019ooooo`00oooooom6ooooo`03ogMgMolb<S;ooooo00Kooooo
00?o0000ooooooooool0BOooool00?ooooooAoooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo04Wooooo0002ooooo`Go000000Ko<S8bonk^k_ooooooooooonk^k_mEEED2o`000005odA4
A?nj^[[oooooooooool@41000_l000001_oooooo0000o`000?l@413ooooooiRHV0;o000000?oMgMg
oa0@4?l000001?ooool00olQ8B7o<S8booooo`04ooooo`Go00000_ooool02?o^k^koEEEEo`000?l0
003oEEEEonk^k_oooooo410@1Ol00007ooooo`06onk^k_mEEEGo0000o`000?mEEEGok^k^0_ooool0
0ol@413o0000o`000002o`000003oa0@4?oooooooooo00Oooooo00GoV9RHo`000?l0003oA4A4okZj
^P02ooooo`04oa0@4?l0003o0000ooooo`;o000000Co410@ooooooo^k^koEEEE0_l000000om4A4Co
^[Zjooooo`08ooooo`05o`000?o<c<cogMgMo`000?o^k^h00_ooool01_nHV9So0000o`000?mgMgOo
410@o`0000Cooooo00?o8B4Qoc8b<_ooool00oooool01_o^k^koEEEEo`000?l0003oA4A4okZj^P;o
oooo00?o410@o`000?l000000_l000001Ol@413oooooooooooooooooV9RH00;o000000GoMgMgo`00
0?l@413ooooooa0@4002o`000004ooooool0003o0000oa0@40;ooooo00GoIVIVo`000?l0003oA4A4
olc<c003ooooo`05oiRHV?l0003o0000odA4A?nj^[X00oooool5o`0000;ooooo00Kok^k^oeEEEOl0
003o0000oeEEEOo^k^h2ooooo`04oa0@4?l0003o0000ooooo`;o000000Go410@oooooooooooooooo
oa0@4002o`000007ooooool0003o0000oa0@4?ooooook^k^oeEEE@02o`000005odA4A?nj^[[ooooo
oooooonHV9P00_l000001OmgMgOo410@o`000?oooooo410@00Go00002?ooool01_nHV9So0000o`00
0?mgMgOo410@o`0000[ooooo00GoV9RHo`000?l0003oA4A4okZj^P03ooooo`05oiRHV?l0003o0000
ogMgMol000000_l@4105o`0000?ooooo00Co410@o`000?l0003ooooo0_l000000ol@413ooooooooo
o`05o`0000;ooooo00Co410@o`000?l0003ooooo0_l000002?l@413oooooonk^k_mEEEGo0000oa0@
4?o<c<co00001oooool02Ol0003oMgMgo`000?l0003oEEEEonk^k_ooooook^k^oeEEE@02o`000003
oeEEEOo^k^kooooo00;ooooo1Ol00002ooooo`04oa0@4?l0003o0000ooooo`;o000000Co410@oooo
ooooooooV9RH0_l000000om4A4Co^[Zjooooo`0Vooooo`000oooool01_l0003oooooooooooo^k^ko
QhN7oc8b<P;ooooo00KoEEEEogMgMoooooook^k^ogMgMol@4103ooooo`05o`000?oooooooooooooo
ool000000_ooool01Ol0003oc<c<onk^k_n7QhOo000000Cooooo00CoV9RHoc8b<_l@413o^[Zj1_oo
ool00ol0003oooooooooo`02ooooo`06oeEEEOmgMgOooooooooooomgMgOoEEEE0oooool00ol0003o
ooooooooo`08ooooo`06oeEEEOmgMgOooooooooooomgMgOoEEEE1?ooool00ol0003oooooooooo`0:
ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000oooool01Ol0003ooooooooooooooooo000000;ooooo
00KoEEEEogMgMoooooook^k^ogMgMol@4108ooooo`06ojVYZOl0003oQhN7oiRHV?l0003oV9RH0_oo
ool01Ol0003oc<c<onk^k_n7QhOo000000Cooooo00CoV9RHoc8b<_l@413o^[Zj0oooool01_mEEEGo
MgMgooooooo^k^koMgMgoa0@40Cooooo00?o0000ooooooooool01?ooool01Ol0003oZJVYoooooon7
QhOo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`06ofIVI_mgMgOooooooooooon7
QhOo410@0oooool01Ol@413o^[Zjonk^k_mgMgOo410@00Gooooo00?o0000ooooooooool00_ooool0
1_mEEEGoMgMgooooooooooooMgMgoeEEE@?ooooo00Go0000ooooooooooooooooo`000005ooooo`05
o`000?ooooooooooooooool000000_ooool01_mEEEGoMgMgooooooo^k^koMgMgoa0@40;ooooo00Go
0000olc<c?o^k^koQhN7o`000004ooooo`03o`000?oooooooooo00Wooooo00Go0000olc<c?o^k^ko
QhN7o`00000;ooooo`05oa0@4?nj^[[ok^k^ogMgMol@41000oooool01Ol0003oZJVYoooooon7QhOo
000000?ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000Gooooo00?o
0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000;ooooo00KoEEEEogMgMooooooo
k^k^oeEEEOl00007ooooo`09o`000?mEEEGok^k^oooooomgMgOoEEEEoooooomEEEGoMgMg00;ooooo
00?oMgMgoeEEEOooool01?ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol@413o^[Zjonk^k_mgMgOo410@02Oooooo0003ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00002?ooool01Ol0003ooooooooooooooooo000000;ooooo00Go410@
ohN7Qoooooook^k^o`000004ooooo`04oa0@4?nj^[[oV9RHoc8b<PKooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000002_ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`05ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`0;oooo
o`06oeEEEOn7QhOoA4A4oeEEEOmgMgOoEEEE0_ooool01Ol@413oQhN7ooooooo^k^ko000000Cooooo
00Co410@okZj^_nHV9So<S8b0oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Co
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`03ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`05ooooo`05oa0@
4?n7QhOoooooonk^k_l000001?ooool00ol0003oooooooooo`09ooooo`05oa0@4?n7QhOoooooonk^
k_l000002oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000000oooool0
0ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003ooooooooo
o`03ooooo`05o`000?ooooooooooooooool000000_ooool01_l0003oooooooooooooooook^k^o`00
00Oooooo00?o0000onk^k_ooool00_ooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooooooool0:Oooool000?ooooo00Ko0000ooooooooooook^k^ohN7Qolb<S82ooooo`Ko00000ooo
ool01Ol0003ooooooooooooooooo000000;ooooo00?o^[Zjoa0@4?l000000_l00003ooooo`06oiRH
V?lb<S;oooooooooool@413o^[Zj1Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`00000:ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Gooooo00Go0000
ooooooooooooooooo`000002ooooo`Ko00002?ooool01_l0003ogMgModA4A?lQ8B7ok^k^o`0000;o
oooo00?o^[Zjoa0@4?l000000_l00003ooooo`06oiRHV?lb<S;oooooooooool@413o^[Zj0_ooool6
o`0000Cooooo00?o0000ooooooooool01?ooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`000003ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000002oooo
o`Ko00000_ooool00onj^[[o410@o`000002o`0000Cooooo00?o0000ooooooooool02Oooool00onj
^[[o410@o`000002o`0000_ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000Gooooo00?o
0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000;ooooo00Ko0000oooooooooooo
ooooonk^k_l00007ooooo`03o`000?o^k^kooooo00;ooooo00?o0000ooooool000001?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooooooo02Wooooo0003ooooo`Co000000[oEEEEonk^k_oooooooooooeEEEOn7
QhOok^k^oooooon7QhOo<S8b0oooool01Ol0003oMgMgoooooonYZJWo000000Gooooo00Ooc<c<o`00
0?ooooooooooonk^k_l0003ogMgM00;ooooo00?oV9RHoc8b<_ooool01?ooool00ol0003ooooooooo
o`02ooooo`06oeEEEOmgMgOooooooooooomgMgOoEEEE0oooool00ol0003o<S8bomgMg@08ooooo`06
oeEEEOmgMgOooooooooooomgMgOoEEEE1?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Gooooo00Go0000ogMgMoooooooZJVYo`000002ooooo`06oeEEEOn7QhOok^k^oooooon7QhOo
<S8b1oooool02?nYZJWo8B4Qoooooon7QhOoEEEEoooooolb<S;oZJVY1?ooool01oo<c<co0000oooo
ooooooook^k^o`000?oMgMd00_ooool02_nHV9So<S8booooooooooooEEEEohN7Qoo^k^koooooohN7
Qolb<S84ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?n7QhOoooooojVYZOl000000_ooool01_mVIVKoMgMgooooooooooooQhN7o`0000?ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`06oeEEEOmgMgOooooooooooomgMgOo
EEEE0oooool01Ol0003oQhN7oooooonYZJWo000000Gooooo00Go0000ohN7QoooooooZJVYo`000002
ooooo`06oeEEEOn7QhOok^k^oooooon7QhOo<S8b1Oooool00oo<c<co0000ooooo`03ooooo`03o`00
0?lb<S;ogMgM00cooooo00?oc<c<o`000?ooool02_ooool00ol0003oooooooooo`05ooooo`05o`00
0?ooooooooooooooool000000oooool00ol0003o<S8bomgMg@05ooooo`05o`000?n7QhOoooooojVY
ZOl000001Oooool00ol0003oooooooooo`03ooooo`05o`000?n7QhOoooooojVYZOl000000_ooool0
1_mEEEGoMgMgooooooo^k^koEEEEo`0000Oooooo00Wo0000oeEEEOo^k^koooooogMgMomVIVKooooo
oeEEEOmgMgL00_ooool00omgMgOoEEEEooooo`04ooooo`03o`000?oooooooooo00?ooooo00Go0000
ohN7QoooooooZJVYo`000003ooooo`03o`000?oooooooooo02Wooooo0003ooooo`05o`000?oooooo
oooookZj^_l@41000oooool01_o^k^koEEEEo`000?l0003oA4A4onk^kP?ooooo00Go0000ogMgMol0
003o0000oiRHV003ooooo`04oc8b<_l0003o0000oiRHV0;ooooo00?o410@o`000?l000000_ooool3
o`0000;ooooo00?o410@o`000?l000001?ooool01_o^k^koEEEEo`000?l0003oEEEEonk^kP;ooooo
0_l000001?nYZJWo8B4Qo`000?lQ8B46ooooo`06onk^k_mEEEGo0000o`000?mEEEGok^k^0_ooool0
0ol@413o0000o`000003o`0000Oooooo00?o410@o`000?l000000ol00004ooooo`05o`000?mgMgOo
0000o`000?nHV9P00_ooool01_o^k^koEEEEo`000?l0003oA4A4onk^kPOooooo0ol00002ooooo`?o
00000_ooool01?lb<S;o0000o`000?nHV9P2ooooo`03oa0@4?l0003o000000;ooooo0ol000000ooo
ooook^k^oeEEE@02o`000005odA4A?o^k^koooooooooool@41001Ol00002ooooo`04oa0@4?l0003o
ooooooooo`;o00000_ooool00ol@413o0000ogMgM`02o`000005oiRHV?ooooooooooonk^k_mVIVH0
0_l000001?m4A4Co0000ooooool@4105o`0000Cooooo00?o410@o`000?l000001?ooool01_o^k^ko
EEEEo`000?l0003oEEEEonk^kP;ooooo00?o410@o`000?mgMgL00_l000000onHV9Soooooooooo`02
ooooo`03oa0@4?l0003oMgMg00;o000000GoV9RHooooooooooook^k^oeEEE@02o`000003odA4A?o^
k^kooooo00;ooooo00Co<S8bo`000?l0003oV9RH0oooool2o`000004ojVYZOlQ8B7o0000ob4Q8@So
oooo00Co<S8bo`000?l0003oV9RH2Oooool00ol@413o0000o`000003o`0000?ooooo00Co410@o`00
0?oooooooooo0_l00002ooooo`;o000000CoZJVYob4Q8Ol0003o8B4Q0_ooool00ol@413o0000ogMg
M`02o`000005oiRHV?ooooooooooooooool@41000_l00004ooooo`03oa0@4?l0003oMgMg00;o0000
00[oV9RHooooooooooook^k^oeEEEOl0003o8B4QojVYZOl0003o410@1Oooool00ol@413o0000ogMg
M`02o`000005ofIVI_o^k^koooooonk^k_mEEED00_l000000omEEEGok^k^ooooo`02ooooo`03oa0@
4?l0003o000000Cooooo00?o410@o`000?mgMgL00_l000000onHV9Sooooooa0@4005o`0002Sooooo
0003ooooo`05o`000?oooooooooookZj^_l000003?ooool00ol0003oooooooooo`0jooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool0Doooool00ol0003oooooooooo`1Iooooo`03o`00
0?oooooooooo02Wooooo0002ooooo`Co000000?o410@ojVYZOooool02oooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo023ooooo00?o410@okZj^_ooool02_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo03Cooooo00?o410@okZj^_ooool07?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0:Oooool001?ooooo00?o410@
o`000?ooool06?ooool00ol@413oooooooooo`0Pooooo`04okZj^_l@413o0000oa0@413ooooo00?o
410@o`000?ooool0=Oooool01?nj^[[o410@o`000?l@410Uooooo`03oa0@4?oooooooooo06_ooooo
00?o410@ooooooooool0:Oooool00ol@413oooooooooo`0gooooo`00oooooonKooooo`00oooooonK
ooooo`00oooooonKooooo`00oooooonKooooo`00oooooonKooooo`00oooooonKooooo`00oooooonK
ooooo`00oooooonKooooo`00oooooonKooooo`00oooooonKooooo`00oooooonKooooo`00oooooonK
ooooo`00oooooonKooooo`00oooooonKooooo`00oooooonKooooo`00oooooonKooooo`00oooooonK
ooooo`00oooooonKooooo`00oooooonKooooo`00oooooonKooooo`00oooooonKooooo`00oooooonK
ooooo`00oooooonKooooo`00oooooonKooooo`00oooooonKooooo`00oooooonKooooo`00oooooonK
ooooo`00oooooonKooooo`00oooooonKooooo`00oooooonKooooo`00oooooonKooooo`00oooooonK
ooooo`00\
\>"],
  ImageRangeCache->{{{0, 409}, {252.188, 0}} -> {-24.5914, -0.61937, \
0.107951, 0.00724989}},
  CellTags->"i:87"]
}, Open  ]],

Cell[TextData[{
  "\tOne can see that the amplitude and wavelength of the wave are increasing \
as one nears the turning point, as expected from WKB analysis as ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(k\)\(\[Rule]\)\(0\)\(\ \)\)\)]],
  ". However, at the turning point the solution is not singular; rather, it \
decays exponentially as one passes through the turning point to the other \
side. The exponential decay of the wave function in the range of ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " that is classically disallowed is the well-known phenomenon of quantum \
tunneling; that is,  quantum particles have a small but finite probability of \
being found in classically disallowed regions. (In optics, the exponential \
decay  of a wave in the forbidden region is referred to as ",
  StyleBox["evanescence",
    FontSlant->"Italic"],
  ".)"
}], "Text",
  CellTags->"i:138"],

Cell[TextData[{
  "\tThe solution shown above corresponds to a single wave component of \
frequency ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\)]],
  ". If a traveling wave of this frequency impinges on the turning point from \
the left, it turns and creates a reflected wave, moving  back to the left \
from whence it came. The interference between these two traveling waves makes \
the pattern of nodes observed in the Airy function  plotted in Cell ",
  ButtonBox["5.28",
    ButtonData:>"Cell 5.28",
    ButtonStyle->"Hyperlink"],
  ". Thus, the classical turning point at ",
  Cell[BoxData[
      \(TraditionalForm\`x = x\_o\)]],
  ", which reflects classical particles, also causes the quantum wave \
function to reflect. "
}], "Text"],

Cell[TextData[{
  "\tIn order to describe the reflection of a wave packet in detail, we would \
need to integrate over a range of frequencies in the packet. The turning \
point location differs for the different frequency components, and causes \
dispersion of the wave packet, as discussed previously in relation to Eq. ",
  ButtonBox["(5.2.50)",
    ButtonData:>"(5.2.50)",
    ButtonStyle->"Hyperlink"],
  ".  If we neglect dispersive spreading, this leads to the equations of \
geometrical optics for the wave packet, equivalent to the equations of motion \
of the classical particle as it is reflected at the turning point. To keep \
dispersive effects requires considerably more work, and will not be discussed \
further here.  In Chapter ",
  ButtonBox["6",
    ButtonData:>{"Chapter6.nb", None},
    ButtonStyle->"Hyperlink"],
  " we will return to the behavior of wave functions near a turning point, \
when we  examine the energy eigenfunctions of the Schr\[ODoubleDot]dinger \
equation in the WKB limit."
}], "Text"]
}, Closed]],

Cell[CellGroupData[{

Cell["Wave-Packet Amplitude", "Section",
  CellTags->{"i:88", "c:31"}],

Cell[TextData[{
  "When a ",
  "wave packet",
  " with frequency ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\)]],
  " propagates through a nonuniform medium, the amplitude of the packet \
varies. We saw several examples of this for one-dimensional systems in \
previous sections, but here we discuss the general case of propagation in two \
or more dimensions.  "
}], "Text"],

Cell[TextData[{
  "\tOne can determine the amplitude variation using the law of energy \
conservation for wave packets, discussed in Sec. ",
  ButtonBox["5.1.3",
    ButtonData:>"c:11",
    ButtonStyle->"Hyperlink"],
  " for classical wave equations with even-order time derivatives. (The \
following does not apply to Schr\[ODoubleDot]dinger's equation, which is \
taken up in the next section. ) Although this energy conservation law was \
derived for uniform systems, it should also be possible to apply it to \
nonuniform systems, provided that the intrinsic parameters in the system \
(wave speed, refractive index, etc.) remain time-independent. Assuming that \
this is the case, we write the energy conservation law ",
  ButtonBox["(5.1.57)",
    ButtonData:>"(5.1.57)",
    ButtonStyle->"Hyperlink"],
  "  as"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{\(\[PartialD]\/\[PartialD]t\), 
              RowBox[{\(\[Epsilon]\&_\), "(", 
                RowBox[{
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], 
                  StyleBox[",",
                    FontWeight->"Plain"], 
                  StyleBox["t",
                    FontWeight->"Plain"]}], 
                StyleBox[")",
                  FontWeight->"Plain"]}]}], 
            StyleBox["+",
              FontWeight->"Plain"], 
            RowBox[{
              StyleBox["\[Del]",
                FontWeight->"Plain"], 
              RowBox[{"\[CenterDot]", 
                RowBox[{"(", 
                  RowBox[{
                    RowBox[{
                      StyleBox[
                        SubscriptBox["v", 
                          StyleBox["g",
                            FontWeight->"Plain"]],
                        FontWeight->"Bold"], "(", 
                      StyleBox["r",
                        FontWeight->"Bold",
                        FontSlant->"Plain"], ")"}], 
                    StyleBox[" ",
                      FontWeight->"Bold"], 
                    RowBox[{\(\[Epsilon]\&_\), "(", 
                      RowBox[{
                        StyleBox["r",
                          FontWeight->"Bold",
                          FontSlant->"Plain"], 
                        StyleBox[",",
                          FontWeight->"Plain"], 
                        StyleBox["t",
                          FontWeight->"Plain"]}], 
                      StyleBox[")",
                        FontWeight->"Plain"]}]}], ")"}]}]}]}], "=", "0"}], 
        TraditionalForm]]],
  ","
}], "NE2",
  CellTags->{"i:119", "(5.2.59)"}],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\&_\)]],
  " is the energy density of a packet with wavenumber ",
  Cell[BoxData[
      FormBox[
        StyleBox["k",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " and frequency ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\)]],
  ", time-averaged over an oscillation period.  Following Eq. ",
  ButtonBox["(5.1.72)",
    ButtonData:>"(5.1.72)",
    ButtonStyle->"Hyperlink"],
  ", the energy density can be expressed in terms of the wave packet \
amplitude ",
  Cell[BoxData[
      FormBox[
        RowBox[{"A", "(", 
          RowBox[{
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[",",
              FontWeight->"Plain"], 
            StyleBox["t",
              FontWeight->"Plain"]}], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  " as"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Epsilon]\&_\), " ", "=", 
          
          RowBox[{\(\[Rho]\/4\), \(A\^2\), 
            "\[Omega]", \(\[PartialD]\/\[PartialD]\[Omega]\), 
            RowBox[{"D", "(", 
              RowBox[{
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], ",", 
                StyleBox["k",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], ",", "\[Omega]"}], ")"}]}]}], 
        TraditionalForm]]],
  ","
}], "NE2",
  CellTags->"(5.2.60)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`D\)]],
  " is the dispersion function. The frequency and wavenumber are related by \
this dispersion function through the equation ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"D", "(", 
            RowBox[{
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], ",", 
              StyleBox["k",
                FontWeight->"Bold",
                FontSlant->"Plain"], ",", "\[Omega]"}], ")"}], "=", "0"}], 
        TraditionalForm]]],
  ", the solution of which provides the dispersion relation ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Omega]", "=", 
          RowBox[{"\[Omega]", "(", 
            RowBox[{
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[",",
                FontWeight->"Plain"], 
              StyleBox["k",
                FontWeight->"Bold",
                FontSlant->"Plain"]}], 
            StyleBox[")",
              FontWeight->"Plain"]}]}], TraditionalForm]]],
  ". The group velocity is ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            SubscriptBox[
              StyleBox["v",
                FontWeight->"Bold",
                FontSlant->"Plain"], "g"], "(", 
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], ")"}], "=", 
          RowBox[{
            RowBox[{"\[PartialD]", 
              RowBox[{"\[Omega]", "(", 
                RowBox[{
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], 
                  StyleBox[",",
                    FontWeight->"Plain"], 
                  StyleBox["k",
                    FontWeight->"Bold",
                    FontSlant->"Plain"]}], 
                StyleBox[")",
                  FontWeight->"Plain"]}]}], "/", 
            RowBox[{"\[PartialD]", 
              StyleBox["k",
                FontWeight->"Bold",
                FontSlant->"Plain"]}]}]}], TraditionalForm]]],
  Cell[BoxData[
      FormBox[
        SubscriptBox["|", 
          RowBox[{
            StyleBox["k",
              FontWeight->"Bold",
              FontSlant->"Plain"], "=", 
            RowBox[{
              StyleBox["k",
                FontWeight->"Bold",
                FontSlant->"Plain"], "(", "r", 
              StyleBox[")",
                FontWeight->"Plain"]}]}]], TraditionalForm]]],
  ", where ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["k",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["(",
            FontWeight->"Plain"], 
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  "is the local wavenumber of the packet, determined by solution of the \
equations of geometrical optics.   For example, for the optics problems \
considered in the previous section, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"D", "(", 
            RowBox[{
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], ",", 
              StyleBox["k",
                FontWeight->"Bold",
                FontSlant->"Plain"], ",", "\[Omega]"}], ")"}], " ", "=", " ", 
          
          RowBox[{
            RowBox[{\(\[Omega]\^2\), 
              RowBox[{\(n\^2\), "(", 
                RowBox[{
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], ",", 
                  StyleBox["\[Omega]",
                    FontWeight->"Plain"]}], 
                StyleBox[")",
                  FontWeight->"Plain"]}]}], 
            StyleBox["-",
              FontWeight->"Plain"], 
            StyleBox[\(\(c\^2\) k\^2\),
              FontWeight->"Plain"]}]}], TraditionalForm]]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " is the refractive index."
}], "Text"],

Cell[TextData[{
  "\tEquation ",
  ButtonBox["(5.2.59)",
    ButtonData:>"(5.2.59)",
    ButtonStyle->"Hyperlink"],
  " is a first-order PDE that is amenable to the method of characteristics, \
to be discussed in Chapter ",
  ButtonBox["7",
    ButtonData:>{"Chapter7.nb", None},
    ButtonStyle->"Hyperlink"],
  ". For a given initial energy density in the wave packet and given initial \
wavenumber and frequency,  the solution for ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Epsilon]\&_\), "(", 
          RowBox[{
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[",",
              FontWeight->"Plain"], 
            StyleBox["t",
              FontWeight->"Plain"]}], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  " can be found and can then be used to determine the wave-packet amplitude \
",
  Cell[BoxData[
      \(TraditionalForm\`A\)]],
  " via Eq. ",
  ButtonBox["(5.2.60)",
    ButtonData:>"(5.2.60)",
    ButtonStyle->"Hyperlink"],
  ". This is somewhat involved, and we will not go into detail here. Some \
examples will be considered in Chapter ",
  ButtonBox["7",
    ButtonData:>{"Chapter7.nb", None},
    ButtonStyle->"Hyperlink"],
  ", and in Sec. ",
  ButtonBox["5.3.1",
    ButtonData:>"c:35",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[TextData[{
  "\tHowever, the method of characteristics is not needed  for the case of a \
time-independent beam in a medium that varies only in the ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " direction. In this case, Eq. ",
  ButtonBox["(5.2.59)",
    ButtonData:>"(5.2.59)",
    ButtonStyle->"Hyperlink"],
  " reduces to "
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(\[PartialD]\/\[PartialD]x\) \((\(\(v\_\(g\ x\)\)(
                x)\)\ \(\(\[Epsilon]\&_\)(x)\)\ )\) = 0\)]],
  ","
}], "Text"],

Cell[TextData[{
  "which has solution ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Epsilon]\&_\)(x) = C/\(\(v\_\(g\ x\)\)(x)\)\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`C\)]],
  " is a constant. Using Eq. ",
  ButtonBox["(5.2.60)",
    ButtonData:>"(5.2.60)",
    ButtonStyle->"Hyperlink"],
  ", we can then obtain the amplitude ",
  Cell[BoxData[
      \(TraditionalForm\`A(x)\)]],
  " of the beam: ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(A(x)\), " ", "\[Proportional]", 
          RowBox[{"1", "/", 
            SqrtBox[
              RowBox[{"|", 
                RowBox[{\(\(v\_\(g\ x\)\)(x)\), " ", 
                  RowBox[{
                    RowBox[{"\[PartialD]", 
                      RowBox[{"D", "(", 
                        RowBox[{"x", ",", 
                          StyleBox["k",
                            FontWeight->"Bold",
                            FontSlant->"Plain"], ",", "\[Omega]"}], ")"}]}], 
                    "/", \(\[PartialD]\[Omega]\)}]}], "|"}]]}]}], 
        TraditionalForm]]],
  ".  However, recalling that ",
  Cell[BoxData[
      \(TraditionalForm\`v\_\(g\ x\)\  = \ \
\[PartialD]\[Omega]/\[PartialD]k\_x\)]],
  ", and applying the identity ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\((\[PartialD]\[Omega]/\[PartialD]k\_x)\) \
\((\[PartialD]D/\[PartialD]\[Omega])\) = \
\(-\[PartialD]D\)/\[PartialD]k\_x\)\)\)]],
  " , we arrive at"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(A(x)\), "  ", "\[Proportional]", 
          RowBox[{"1", "/", 
            SqrtBox[
              RowBox[{"|", 
                RowBox[{
                  RowBox[{"\[PartialD]", 
                    RowBox[{"D", "(", 
                      RowBox[{"x", ",", 
                        StyleBox["k",
                          FontWeight->"Bold",
                          FontSlant->"Plain"], ",", "\[Omega]"}], ")"}]}], 
                  "/", \(\[PartialD]k\_x\)}], "|"}]]}]}], TraditionalForm]]],
  "."
}], "NE2",
  CellTags->"(5.2.61)"],

Cell[TextData[{
  "\tFor the optics example discussed previously, where ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"D", "(", 
            RowBox[{
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], ",", 
              StyleBox["k",
                FontWeight->"Bold",
                FontSlant->"Plain"], ",", "\[Omega]"}], ")"}], "=", 
          RowBox[{
            RowBox[{\(\[Omega]\^2\), 
              RowBox[{\(n\^2\), "(", 
                RowBox[{"x", ",", 
                  StyleBox["\[Omega]",
                    FontWeight->"Plain"]}], 
                StyleBox[")",
                  FontWeight->"Plain"]}]}], 
            StyleBox["-",
              FontWeight->"Plain"], 
            StyleBox[\(\(c\^2\) k\^2\),
              FontWeight->"Plain"]}]}], TraditionalForm]]],
  ", Eq. ",
  ButtonBox["(5.2.61)",
    ButtonData:>"(5.2.61)",
    ButtonStyle->"Hyperlink"],
  " implies that the beam amplitude varies as ",
  Cell[BoxData[
      \(TraditionalForm\`1/\@\(\(k\_x\)(x)\)\)]],
  ", which is typical for WKB problems . In fact, this result could also be \
obtained directly from the WKB solution without consideration of the wave \
energy [see Exercise (9) at the end of the section]. "
}], "Text",
  CellTags->"i:125"],

Cell[TextData[{
  "\tIn this optics example  we assumed that ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          FormBox[\(n(x, \[Omega]) = 1 - \ \(x\^2\) \[Omega]\),
            "TraditionalForm"]}], TraditionalForm]]],
  "  (see Fig. ",
  ButtonBox["5.8",
    ButtonData:>"Fig. 5.8",
    ButtonStyle->"Hyperlink"],
  " and the surrounding discussion). Then Eq. ",
  ButtonBox["(5.2.48)",
    ButtonData:>"(5.2.48)",
    ButtonStyle->"Hyperlink"],
  " implies that ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]k\_x/\[DifferentialD]t < 0\)]],
  " along the wave packet trajectory, which is another way to see why the \
rays bent away from positive ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " in Fig. ",
  ButtonBox["5.8",
    ButtonData:>"Fig. 5.8",
    ButtonStyle->"Hyperlink"],
  ".  In turn,  ",
  Cell[BoxData[
      \(TraditionalForm\`A(x) \[Proportional] 1/\@k\_x\)]],
  " then implies that the electric field ",
  StyleBox["increases",
    FontSlant->"Italic"],
  " as ",
  Cell[BoxData[
      \(TraditionalForm\`k\_x\)]],
  " decreases. However, this result contradicts our previous intuition that \
the spreading of the rays making up the packet should cause the amplitude of \
the packet to ",
  StyleBox["decrease ",
    FontSlant->"Italic"],
  "as the turning point is approached. In fact, both effects occur at once as \
the turning point is approached: the amplitude of a given ray increases \
(because the ",
  StyleBox["x",
    FontSlant->"Italic"],
  "-component of the wave speed is decreasing, so wavefronts pile up), but \
the dispersal of the wave packet of rays works against this effect. "
}], "Text"],

Cell[TextData[{
  "\tHowever, it is important to remember that Eqs. ",
  ButtonBox["(5.2.59)",
    ButtonData:>"(5.2.59)",
    ButtonStyle->"Hyperlink"],
  "-",
  ButtonBox["(5.2.61)",
    ButtonData:>"(5.2.61)",
    ButtonStyle->"Hyperlink"],
  " ",
  StyleBox["neglect dispersion",
    FontSlant->"Italic"],
  ". Recall that Eq. ",
  ButtonBox["(5.2.59)",
    ButtonData:>"(5.2.59)",
    ButtonStyle->"Hyperlink"],
  " is based on Eq. ",
  ButtonBox["(5.1.60)",
    ButtonData:>"(5.1.60)",
    ButtonStyle->"Hyperlink"],
  ", which does not include dispersive spreading of the wave packet. "
}], "Text",
  CellTags->"i:89"],

Cell[TextData[{
  "\tOne can see the limitations of Eq. ",
  ButtonBox["(5.2.59)",
    ButtonData:>"(5.2.59)",
    ButtonStyle->"Hyperlink"],
  " in another way: for a wave packet of plane waves moving in one dimension \
through a uniform medium, Eq. ",
  ButtonBox["(5.2.59)",
    ButtonData:>"(5.2.59)",
    ButtonStyle->"Hyperlink"],
  " implies that ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(\(\[PartialD]\/\[PartialD]t\) \[Epsilon]\&_\), " ", "+", 
            RowBox[{
              StyleBox[
                SubscriptBox["v", 
                  StyleBox["g",
                    FontWeight->"Plain"]],
                FontWeight->"Bold"], "\[CenterDot]", 
              RowBox[{
                StyleBox["\[Del]",
                  FontWeight->"Plain"], 
                StyleBox[" ",
                  FontWeight->"Bold"], \(\[Epsilon]\&_\)}]}]}], "=", "0"}], 
        TraditionalForm]]],
  ". This equation implies that the wave packet is transmitted without change \
in the energy density (see Sec. ",
  ButtonBox["7.1",
    ButtonData:>{"Chapter7.nb", "c:3"},
    ButtonStyle->"Hyperlink"],
  ").  However,  we know that dispersion will cause such a wave packet to \
spread.  Equation ",
  ButtonBox["(5.2.59)",
    ButtonData:>"(5.2.59)",
    ButtonStyle->"Hyperlink"],
  " is valid only for problems where such dispersive effects are negligible. \
"
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["Exercises for Sec. 5.2", "Subsubtitle",
  CellTags->"c:33"],

Cell[TextData[{
  StyleBox["(1)",
    FontWeight->"Bold"],
  " Bessel's equation is  the following ODE:"
}], "Text",
  CellTags->"i:94"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(1\/\(\(r\)\(\ \)\)\) \(\[PartialD]\/\[PartialD]r\) \
\((r \[PartialD]R\/\[PartialD]r)\) - \((m\^2\/r\^2 - 1)\) \(R(r)\) = 0\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Using Eq. ",
  ButtonBox["(5.2.8)",
    ButtonData:>"(5.2.8)",
    ButtonStyle->"Hyperlink"],
  " show that WKB analysis can be applied to  understand the solutions to the \
equation, provided that ",
  Cell[BoxData[
      \(TraditionalForm\`r >> 1\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " The two independent solutions to Bessel's equation are the Bessel \
functions ",
  Cell[BoxData[
      \(TraditionalForm\`\(J\_m\)(r)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\(Y\_m\)(r)\)]],
  ". Show that these functions have the  following form at large ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  " :"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(J\_m\)(
        r), \ \(\(Y\_m\)(r)\)\ ~A\ \ \(r\^\(\(-1\)/2\)\) \(cos(
          r - \[Alpha]\_m)\), \)]],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`A\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\_m\)]],
  " are constants.  "
}], "Text"],

Cell[TextData[{
  "[By other means, it can be shown that ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(A\)\(\ \)\(=\)\(\@\(2/\[Pi]\)\)\(\ \)\)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\_m = \[Pi]\ \((m/2\  + 1/4)\)\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`J\_m\)]],
  ", and ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Alpha]\_m\), "=", 
          RowBox[{"\[Pi]", " ", \((m/2 + 3/4)\), Cell[""], " "}]}], 
        TraditionalForm]]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`Y\_m\)]],
  ".]"
}], "Text"],

Cell[TextData[{
  StyleBox["(2)(a)",
    FontWeight->"Bold"],
  " Using Eq. ",
  ButtonBox["(5.2.8)",
    ButtonData:>"(5.2.8)",
    ButtonStyle->"Hyperlink"],
  ", show that WKB solutions of the Airy equation, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FractionBox[\(\[PartialD]\^2\( y(x)\)\), \(\[PartialD]x\^2\),
            MultilineFunction->None], "=", \(x\ \(y(x)\)\)}], 
        TraditionalForm]]],
  ",  are valid provided that ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(|\)\(x\)\(|\)\) >> 1\)]],
  ". \n",
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Show that these solutions are of the form ",
  Cell[BoxData[
      \(TraditionalForm\`y(x)\  \[Proportional] \ 
        1\/\@x\%4\ \[ExponentialE]\^\(\(\[PlusMinus]\(2\/3\)\)\ \
x\^\(2/3\)\)\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`x >> 1\)]],
  ", ",
  Cell[BoxData[
      FormBox[Cell[""], TraditionalForm]]],
  "and ",
  Cell[BoxData[
      \(TraditionalForm\`y(x)\  \[Proportional] 
        1\/\@\(\(|\)\(x\)\(|\)\)\%4\ \[ExponentialE]\^\(\(\[PlusMinus]\ i\)\ \
2\/3\  | x\( | \^\(2/3\)\)\)\)]],
  "for ",
  Cell[BoxData[
      \(TraditionalForm\`x << -1\)]],
  " ."
}], "Text",
  CellTags->"i:109"],

Cell[TextData[{
  StyleBox["(3)",
    FontWeight->"Bold"],
  " By setting up a recursion relation  analogous to Eq. ",
  ButtonBox["(5.2.17)",
    ButtonData:>"(5.2.17)",
    ButtonStyle->"Hyperlink"],
  ", show that the eikonal ",
  Cell[BoxData[
      \(TraditionalForm\`S\_n\)]],
  " for the ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  "th approximant to the solution of the Airy equation satisfies"
}], "Text",
  CellTags->"i:95"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\(S\_n\)(x)\  = \ 
            B \[PlusMinus] \[Integral]\^x\(\@\( 
                        x\  - \ \[Lambda] \[PartialD]\^2 S\_\(n - 1\)\/\
\[PartialD]x\^2\)\) \[DifferentialD]x\), ",", Cell[""]}], TraditionalForm]]],
  "for ",
  Cell[BoxData[
      \(TraditionalForm\`x >> 1\)]],
  ", "
}], "Text"],

Cell[TextData[{
  "with ",
  Cell[BoxData[
      \(TraditionalForm\`S\_0 = \(\[PlusMinus]2\)\ x\^\(3/2\)/3\)]],
  ". Using ",
  StyleBox["Mathematica",
    FontSlant->"Italic"],
  ", solve this recursion relation and plot ",
  Cell[BoxData[
      \(TraditionalForm\`\(S\_n\)(x)\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`n = 0, 1, 2, 3, 4\)]],
  " , in the range ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0.5 - \ 3\)]],
  ". (Drop the integration constant ",
  Cell[BoxData[
      \(TraditionalForm\`B\)]],
  ".) (Hint: At each order ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  ", Taylor expand the square root to order ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " to simplify the integrals. Write a recursion relation for ",
  Cell[BoxData[
      \(TraditionalForm\`S\_n\)]],
  " that includes this Taylor expansion in the definition.) The solution is \
shown in Fig. ",
  ButtonBox["5.9",
    ButtonData:>"Fig. 5.9",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.166667 0.380952 0.309017 0.103006 [
[.02381 .29652 -9 -9 ]
[.02381 .29652 9 0 ]
[.40476 .29652 -9 -9 ]
[.40476 .29652 9 0 ]
[.59524 .29652 -3 -9 ]
[.59524 .29652 3 0 ]
[.78571 .29652 -9 -9 ]
[.78571 .29652 9 0 ]
[.97619 .29652 -3 -9 ]
[.97619 .29652 3 0 ]
[1.025 .30902 0 -6 ]
[1.025 .30902 10 6 ]
[.20179 0 -12 -4.5 ]
[.20179 0 0 4.5 ]
[.20179 .10301 -12 -4.5 ]
[.20179 .10301 0 4.5 ]
[.20179 .20601 -12 -4.5 ]
[.20179 .20601 0 4.5 ]
[.20179 .41202 -6 -4.5 ]
[.20179 .41202 0 4.5 ]
[.20179 .51503 -6 -4.5 ]
[.20179 .51503 0 4.5 ]
[.20179 .61803 -6 -4.5 ]
[.20179 .61803 0 4.5 ]
[.21429 .64303 -16.625 0 ]
[.21429 .64303 16.625 12 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02381 .30902 m
.02381 .31527 L
s
[(0.5)] .02381 .29652 0 1 Mshowa
.40476 .30902 m
.40476 .31527 L
s
[(1.5)] .40476 .29652 0 1 Mshowa
.59524 .30902 m
.59524 .31527 L
s
[(2)] .59524 .29652 0 1 Mshowa
.78571 .30902 m
.78571 .31527 L
s
[(2.5)] .78571 .29652 0 1 Mshowa
.97619 .30902 m
.97619 .31527 L
s
[(3)] .97619 .29652 0 1 Mshowa
.125 Mabswid
.0619 .30902 m
.0619 .31277 L
s
.1 .30902 m
.1 .31277 L
s
.1381 .30902 m
.1381 .31277 L
s
.17619 .30902 m
.17619 .31277 L
s
.25238 .30902 m
.25238 .31277 L
s
.29048 .30902 m
.29048 .31277 L
s
.32857 .30902 m
.32857 .31277 L
s
.36667 .30902 m
.36667 .31277 L
s
.44286 .30902 m
.44286 .31277 L
s
.48095 .30902 m
.48095 .31277 L
s
.51905 .30902 m
.51905 .31277 L
s
.55714 .30902 m
.55714 .31277 L
s
.63333 .30902 m
.63333 .31277 L
s
.67143 .30902 m
.67143 .31277 L
s
.70952 .30902 m
.70952 .31277 L
s
.74762 .30902 m
.74762 .31277 L
s
.82381 .30902 m
.82381 .31277 L
s
.8619 .30902 m
.8619 .31277 L
s
.9 .30902 m
.9 .31277 L
s
.9381 .30902 m
.9381 .31277 L
s
.25 Mabswid
0 .30902 m
1 .30902 L
s
gsave
1.025 .30902 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.21429 0 m
.22054 0 L
s
[(-3)] .20179 0 1 0 Mshowa
.21429 .10301 m
.22054 .10301 L
s
[(-2)] .20179 .10301 1 0 Mshowa
.21429 .20601 m
.22054 .20601 L
s
[(-1)] .20179 .20601 1 0 Mshowa
.21429 .41202 m
.22054 .41202 L
s
[(1)] .20179 .41202 1 0 Mshowa
.21429 .51503 m
.22054 .51503 L
s
[(2)] .20179 .51503 1 0 Mshowa
.21429 .61803 m
.22054 .61803 L
s
[(3)] .20179 .61803 1 0 Mshowa
.125 Mabswid
.21429 .0206 m
.21804 .0206 L
s
.21429 .0412 m
.21804 .0412 L
s
.21429 .0618 m
.21804 .0618 L
s
.21429 .0824 m
.21804 .0824 L
s
.21429 .12361 m
.21804 .12361 L
s
.21429 .14421 m
.21804 .14421 L
s
.21429 .16481 m
.21804 .16481 L
s
.21429 .18541 m
.21804 .18541 L
s
.21429 .22661 m
.21804 .22661 L
s
.21429 .24721 m
.21804 .24721 L
s
.21429 .26781 m
.21804 .26781 L
s
.21429 .28842 m
.21804 .28842 L
s
.21429 .32962 m
.21804 .32962 L
s
.21429 .35022 m
.21804 .35022 L
s
.21429 .37082 m
.21804 .37082 L
s
.21429 .39142 m
.21804 .39142 L
s
.21429 .43262 m
.21804 .43262 L
s
.21429 .45322 m
.21804 .45322 L
s
.21429 .47383 m
.21804 .47383 L
s
.21429 .49443 m
.21804 .49443 L
s
.21429 .53563 m
.21804 .53563 L
s
.21429 .55623 m
.21804 .55623 L
s
.21429 .57683 m
.21804 .57683 L
s
.21429 .59743 m
.21804 .59743 L
s
.25 Mabswid
.21429 0 m
.21429 .61803 L
s
gsave
.21429 .64303 -77.625 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding MacintoshRomanEncoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(S) show
69.000 14.562 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(n) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
74.250 13.000 moveto
(H) show
80.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
86.250 13.000 moveto
(L) show
92.250 13.000 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
.5 Mabswid
.02381 .3333 m
.06244 .34105 L
.10458 .35028 L
.14415 .35963 L
.18221 .3692 L
.22272 .37998 L
.26171 .3909 L
.30316 .40307 L
.34309 .41531 L
.3815 .42755 L
.42237 .44105 L
.46172 .4545 L
.49955 .46783 L
.53984 .48245 L
.57861 .49692 L
.61984 .51273 L
.65954 .52835 L
.69774 .54373 L
.73838 .56048 L
.77751 .57696 L
.81909 .59486 L
.85916 .61246 L
s
.85916 .61246 m
.87161 .61803 L
s
.02381 .35115 m
.04262 .3524 L
.06244 .35414 L
.10458 .35902 L
.14264 .36462 L
.18314 .37164 L
.22214 .3793 L
.26358 .38831 L
.30351 .39776 L
.34193 .40751 L
.38279 .41854 L
.42214 .42976 L
.45998 .44108 L
.50027 .45367 L
.53904 .46628 L
.58026 .48021 L
.61997 .49411 L
.65817 .50791 L
.69881 .52304 L
.73794 .53802 L
.77952 .55439 L
.81959 .57058 L
.85814 .58652 L
.89914 .60388 L
s
.89914 .60388 m
.93186 .61803 L
s
.02381 .38149 m
.03279 .38002 L
.04262 .37875 L
.04758 .37824 L
.05288 .37778 L
.05785 .37742 L
.06244 .37714 L
.06788 .37689 L
.07075 .37679 L
.07379 .3767 L
.07642 .37664 L
.07889 .3766 L
.0803 .37658 L
.08159 .37657 L
.08231 .37656 L
.08309 .37655 L
.08382 .37655 L
.08451 .37655 L
.08577 .37655 L
.08648 .37655 L
.08713 .37655 L
.08833 .37655 L
.0896 .37656 L
.09074 .37657 L
.0918 .37658 L
.09422 .37662 L
.09684 .37666 L
.09922 .37672 L
.10458 .37688 L
.10939 .37707 L
.11449 .3773 L
.12366 .37783 L
.14443 .37945 L
.1639 .38145 L
.18218 .3837 L
.22086 .38949 L
.262 .39694 L
.30163 .40517 L
.33974 .41393 L
.3803 .42408 L
.41934 .43457 L
.46084 .44642 L
.50082 .45847 L
.53929 .47062 L
.58021 .4841 L
.61961 .4976 L
.6575 .51103 L
.69784 .52581 L
.73666 .54047 L
.77794 .55651 L
Mistroke
.8177 .57239 L
.85594 .58804 L
.89664 .60511 L
Mfstroke
.89664 .60511 m
.92677 .61803 L
s
.02381 .44587 m
.03279 .43609 L
.04262 .42729 L
.06244 .41414 L
.07298 .40904 L
.08426 .40471 L
.09482 .40151 L
.10458 .39917 L
.1148 .39727 L
.12007 .39648 L
.12589 .39574 L
.13566 .3948 L
.14101 .39442 L
.14603 .39415 L
.15099 .39396 L
.1538 .39388 L
.15514 .39385 L
.15641 .39382 L
.15761 .39381 L
.15891 .39379 L
.16009 .39378 L
.16118 .39377 L
.16236 .39377 L
.16366 .39377 L
.16431 .39377 L
.16501 .39377 L
.16627 .39378 L
.16751 .39379 L
.16866 .3938 L
.17125 .39385 L
.17353 .3939 L
.17596 .39396 L
.18016 .3941 L
.1848 .3943 L
.19489 .39487 L
.20414 .39556 L
.225 .39759 L
.26462 .403 L
.30273 .40971 L
.34329 .41815 L
.38234 .4273 L
.42384 .43798 L
.46382 .44907 L
.50229 .46041 L
.5432 .47313 L
.58261 .48596 L
.62049 .49882 L
.66083 .51302 L
.69966 .52717 L
.74093 .5427 L
Mistroke
.7807 .55812 L
.81894 .57335 L
.85964 .58999 L
.89882 .6064 L
Mfstroke
.89882 .6064 m
.92595 .61803 L
s
.04117 .61803 m
.04262 .61022 L
.05288 .56729 L
.06244 .53587 L
.07291 .50864 L
.0828 .4882 L
.09421 .46955 L
.10458 .45612 L
.11428 .44598 L
.12455 .43726 L
.14299 .42568 L
.1524 .42134 L
.16253 .41759 L
.17202 .41483 L
.18083 .41281 L
.19093 .41104 L
.19627 .41033 L
.20196 .4097 L
.20739 .40924 L
.2125 .40891 L
.21709 .40869 L
.21967 .4086 L
.22205 .40854 L
.22332 .40852 L
.22451 .4085 L
.22558 .40848 L
.22675 .40847 L
.22802 .40846 L
.22866 .40846 L
.22937 .40846 L
.23062 .40846 L
.23179 .40847 L
.2329 .40848 L
.23407 .40849 L
.23616 .40853 L
.23841 .40858 L
.24088 .40865 L
.24605 .40885 L
.25158 .40913 L
.26154 .40981 L
.27178 .41072 L
.28289 .41191 L
.30304 .41458 L
.34396 .4216 L
.38336 .42992 L
.42125 .43904 L
.46159 .44973 L
.50041 .46083 L
.54169 .4734 L
.58145 .48617 L
Mistroke
.61969 .49902 L
.66039 .51324 L
.69957 .52744 L
.74121 .54305 L
.78133 .55857 L
.81993 .57392 L
.86099 .59069 L
.90052 .60724 L
Mfstroke
.90052 .60724 m
.92572 .61803 L
s
.02381 .28474 m
.06244 .27699 L
.10458 .26776 L
.14415 .25841 L
.18221 .24883 L
.22272 .23805 L
.26171 .22713 L
.30316 .21497 L
.34309 .20272 L
.3815 .19049 L
.42237 .17699 L
.46172 .16354 L
.49955 .1502 L
.53984 .13558 L
.57861 .12111 L
.61984 .10531 L
.65954 .08969 L
.69774 .0743 L
.73838 .05756 L
.77751 .04107 L
.81909 .02318 L
.85916 .00558 L
s
.85916 .00558 m
.87161 0 L
s
.02381 .30259 m
.06244 .29008 L
.10458 .27651 L
.14415 .26365 L
.18221 .2511 L
.22272 .23749 L
.26171 .22411 L
.30316 .20957 L
.34309 .19522 L
.3815 .18112 L
.42237 .16576 L
.46172 .15065 L
.49955 .13581 L
.53984 .11968 L
.57861 .10383 L
.61984 .08664 L
.65954 .06975 L
.69774 .0532 L
.73838 .03527 L
.77751 .0177 L
s
.77751 .0177 m
.81624 0 L
s
.02381 .27224 m
.04262 .27013 L
.06244 .26708 L
.10458 .25865 L
.14264 .24948 L
.18314 .23859 L
.22214 .22728 L
.26358 .21452 L
.30351 .20161 L
.34193 .18869 L
.38279 .17444 L
.42214 .16026 L
.45998 .14624 L
.50027 .13089 L
.53904 .11574 L
.58026 .09924 L
.61997 .08297 L
.65817 .06697 L
.69881 .0496 L
.73794 .03254 L
.77952 .01405 L
s
.77952 .01405 m
.81052 0 L
s
.02381 .33662 m
.04262 .31866 L
.06244 .30407 L
.10458 .28094 L
.14264 .26451 L
.18314 .24899 L
.22214 .23485 L
.26358 .22011 L
.30351 .20589 L
.34193 .19207 L
.38279 .17712 L
.42214 .16244 L
.45998 .14805 L
.50027 .13239 L
.53904 .11701 L
.58026 .10031 L
.61997 .08388 L
.65817 .06777 L
.69881 .05029 L
.73794 .03314 L
.77952 .01457 L
s
.77952 .01457 m
.81157 0 L
s
.02381 .05716 m
.03279 .10026 L
.04262 .13573 L
.05288 .16321 L
.06244 .18234 L
.0731 .19824 L
.0828 .20895 L
.094 .21797 L
.09903 .2211 L
.10458 .22399 L
.11428 .22787 L
.11958 .22945 L
.12455 .23063 L
.12911 .23149 L
.13344 .23213 L
.13582 .23241 L
.13843 .23267 L
.14081 .23286 L
.14299 .23299 L
.14555 .23311 L
.14689 .23315 L
.14757 .23317 L
.14831 .23319 L
.14954 .23321 L
.15069 .23322 L
.1514 .23322 L
.15206 .23322 L
.15331 .23321 L
.15444 .2332 L
.15564 .23318 L
.15666 .23315 L
.15779 .23312 L
.16031 .23302 L
.16267 .23289 L
.16793 .23253 L
.17276 .23209 L
.18364 .23079 L
.20256 .22767 L
.22326 .22333 L
.26382 .2129 L
.30287 .2013 L
.34437 .18789 L
.38435 .1742 L
.42282 .16046 L
.46373 .14532 L
.50314 .13029 L
.54102 .11545 L
.58136 .09926 L
.62019 .08332 L
.66147 .06599 L
Mistroke
.70123 .04893 L
.73947 .03221 L
.78017 .01408 L
Mfstroke
.78017 .01408 m
.81118 0 L
s
gsave
.59524 .4491 -81 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(+) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sign) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.59524 .15863 -81 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(-) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(sign) show
99.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.10381 .51503 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(n) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(4) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.08476 .42232 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(n) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(3) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.0619 .38627 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(n) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(2) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.05048 .36052 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(n) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(1) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.07714 .32962 -72 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(n) show
69.000 13.000 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(=) show
75.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(0) show
81.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Picture",
  ImageSize->{352.812, 218.062},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40006i000142000`400?l00000o`00003ooooooonj
ooooo`00oooooonjooooo`00oooooonjooooo`00E_ooool01OnHV9So410@o`000?lb<S;oc<c<0?oo
ooooGoooool005Kooooo00Go410@okZj^_ooooooMgMgoc8b<P3ooooooeoooooo001>ooooo`Ko0000
1_ooool00ol0003oooooooooo`3ooooooegooooo001Iooooo`03ojVYZOl@413ooooo00Kooooo0ol0
003Uooooo`Co00004oooool2o`0005Kooooo001Hooooo`03oa0@4?l0003o^[Zj00Oooooo00?o0000
ooooooooool0h_ooool5o`0001?ooooo0_l0001Hooooo`00FOooool00onj^[[o8B4Qooooo`06oooo
o`03o`000?oooooooooo0=oooooo1Ol0000Dooooo`;o0000F_ooool005Kooooo00Go410@oiRHV?oo
oooo^[Zjo`000007ooooo`03o`000?oooooooooo0=gooooo1Ol0000Dooooo`;o0000G?ooool005Ko
oooo00GoZJVYoa0@4?l0003o410@ojVYZ@07ooooo`03o`000?oooooooooo0=[ooooo1Ol0000Doooo
o`?o0000G_ooool006;ooooo00?o0000ooooooooool0f?ooool5o`0001Cooooo0_l0001Qooooo`00
H_ooool00ol0003oooooooooo`3Fooooo`Co00005Oooool2o`0006?ooooo001Rooooo`03o`000?oo
oooooooo0=?ooooo1Ol0000Dooooo`?o0000IOooool006;ooooo0_l0003Booooo`Go00005?ooool2
o`0006Sooooo001Rooooo`03o`000?oooooooooo0<oooooo1?l0000Eooooo`;o0000J_ooool006;o
oooo00?o0000ooooooooool0c?ooool5o`0001Gooooo0_l0001/ooooo`00H_ooool00ol0003ooooo
ooooo`3:ooooo`Go00005?ooool3o`0006kooooo001Rooooo`03o`000?oooooooooo0<Sooooo1?l0
000Eooooo`;o0000LOooool006;ooooo00?o0000ooooooooool0a_ooool4o`0001Gooooo0_l0001c
ooooo`00H_ooool00ol0003oooooooooo`34ooooo`Co00005?ooool3o`0007Gooooo001Rooooo`03
o`000?oooooooooo0<7ooooo1Ol0000Dooooo`;o0000N?ooool006;ooooo0_l00030ooooo`Go0000
5?ooool2o`0007[ooooo001Rooooo`03o`000?oooooooooo0;gooooo1?l0000Dooooo`?o0000O?oo
ool006;ooooo00?o0000ooooooooool0^oooool4o`0001?ooooo0ol0001oooooo`00H_ooool00ol0
003oooooooooo`2iooooo`Co00004oooool2o`0008;ooooo001Rooooo`03o`000?oooooooooo0;Oo
oooo1?l0000Booooo`?o0000Q?ooool006;ooooo00?o0000ooooooooool0]?ooool5o`00017ooooo
0ol00027ooooo`006?ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo0;;ooooo0_l0
00000ooooooo0000o`00000Aooooo`;o0000R_ooool001Sooooo00?o0000ooooooooool0Aoooool0
0ol0003oooooooooo`2_ooooo`Ko00004Oooool2o`0008cooooo000Hooooo`03o`000?oooooooooo
04Oooooo0_l0002]ooooo`Ko00004_ooool2o`0008kooooo000Hooooo`03o`000?oooooooooo04Oo
oooo00?o0000ooooooooool0Z_ooool3o`000003ooooool0003o0000017ooooo0ol0002@ooooo`00
6Oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo0:Sooooo0ol000000ooooooo0000
o`00000Aooooo`;o0000Toooool001Wooooo00?o0000ooooooooool0A_ooool00ol0003ooooooooo
o`2Uooooo`Co000000?oooooo`000?l000004Oooool2o`0009Gooooo000Iooooo`03o`000?oooooo
oooo04Kooooo00?o0000ooooooooool0Xoooool3o`000004ooooool0003o0000o`00017ooooo0_l0
002Gooooo`006Oooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo0:7ooooo1_l0000B
ooooo`;o0000VOooool001Wooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`2Noooo
o`?o000000?oooooo`000?l000004_ooool3o`0009_ooooo000Jooooo`03o`000?oooooooooo04Go
oooo00?o0000ooooooooool0W?ooool6o`0001;ooooo0_l0002Nooooo`006_ooool00ol0003ooooo
ooooo`15ooooo`;o0000Voooool5o`0001;ooooo0ol0002Pooooo`006_ooool00ol0003ooooooooo
o`15ooooo`03o`000?oooooooooo09Oooooo1Ol0000Cooooo`;o0000Xoooool001[ooooo00?o0000
ooooooooool0AOooool00ol0003oooooooooo`2Eooooo`Go00004_ooool3o`000:Gooooo000Joooo
o`03o`000?oooooooooo04Gooooo00?o0000ooooooooool0T_ooool6o`0001;ooooo0_l0002Xoooo
o`006_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo093ooooo1Ol0000Booooo`?o
0000Z_ooool001_ooooo00?o0000ooooooooool0>?ooool5o`0000Oooooo00?o0000ooooooooool0
SOooool6o`00017ooooo0ol0002]ooooo`006oooool00ol0003oooooooooo`0hooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@01oooool00ol0003oooooooooo`2;ooooo`Ko00004Oooool2o`000;3ooooo
000Kooooo`03o`000?oooooooooo033ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^00Sooooo00?o
0000ooooooooool0ROooool5o`00017ooooo0ol0002booooo`006oooool00ol0003oooooooooo`0j
ooooo`03oiRHV?lQ8B7ok^k^00Oooooo0ol00026ooooo`Ko00004?ooool3o`000;Gooooo000Koooo
o`03o`000?oooooooooo03_ooooo00?oMgMgofIVI_ooool01_ooool00ol0003oooooooooo`24oooo
o`Ko00004?ooool2o`000;Sooooo000Looooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`22ooooo`Go00004?ooool3o`000;[ooooo000Looooo`03o`00
0?oooooooooo03Oooooo00Go0000okZj^_ooooooV9RHoa0@4007ooooo`03o`000?oooooooooo07oo
oooo1_l0000?ooooo`?o0000_Oooool001cooooo00?o0000ooooooooool0=oooool01OnHV9So410@
o`000?lQ8B7oc<c<00Oooooo00?o0000ooooooooool0OOooool5o`00013ooooo0_l00030ooooo`00
7Oooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo07_ooooo1Ol0000?ooooo`?o0000
`_ooool001gooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`1hooooo`Go00003ooo
ool3o`000<Gooooo000Mooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0MOooool3
o`000003ooooool0003o000000oooooo0_l00038ooooo`007Oooool00ol0003oooooooooo`12oooo
o`;o0000Loooool3o`000004ooooool0003o0000o`0000kooooo0ol0003:ooooo`007_ooool00ol0
003oooooooooo`11ooooo`03o`000?oooooooooo06oooooo1?l000000ooooooo0000o`00000>oooo
o`?o0000cOooool001kooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`1]ooooo`?o
00000_ooool2o`0000gooooo0ol0003@ooooo`007_ooool00ol0003oooooooooo`11ooooo`03o`00
0?oooooooooo06[ooooo0ol00002ooooo`?o00003?ooool3o`000=?ooooo000Oooooo`03o`000?oo
oooooooo043ooooo00?o0000ooooooooool0Ioooool4o`0000;ooooo0_l0000<ooooo`?o0000e_oo
ool001oooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`1Uooooo`?o00000oooool2
o`0000_ooooo0ol0003Iooooo`007oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo
06;ooooo1?l00002ooooo`?o00002_ooool3o`000=cooooo000Pooooo`03o`000?oooooooooo03oo
oooo00?o0000ooooooooool0Goooool4o`0000;ooooo0ol0000;ooooo`;o0000goooool0023ooooo
00?o0000ooooooooool0?oooool2o`0005kooooo1?l000001?oooooo0000o`000?l0000;ooooo`?o
0000:Oooool01OlQ8B7o0000o`000?m4A4CogMgM0;?ooooo000Pooooo`03o`000?oooooooooo03oo
oooo00?o0000ooooooooool0F_ooool4o`000004ooooool0003o0000o`0000_ooooo0ol0000_oooo
o`03ogMgMolb<S;ooooo0;;ooooo000Qooooo`03o`000?oooooooooo03kooooo00?o0000oooooooo
ool0Eoooool8o`0000cooooo0_l0000cooooo`03o`000?oooooooooo0;7ooooo000Qooooo`03o`00
0?oooooooooo03kooooo00?o0000ooooooooool0EOooool7o`0000cooooo0ol0000Pooooo`06oa0@
4?lb<S;o0000o`000?l@413oZJVY0oooool5o`0000;ooooo00Kok^k^oeEEEOl0003o410@olc<c?l0
0002ooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@ooooooooool0Z?ooool002;ooooo00?o
0000ooooooooool0?Oooool00ol0003oooooooooo`1Booooo`Oo00003?ooool3o`0002?ooooo00Ko
0000ojVYZOoooooooooookZj^_l00005ooooo`03o`000?oooooooooo00;ooooo00KoEEEEogMgMooo
ooook^k^oeEEEOl00003ooooo`05o`000?ooooooooooooooool00000Zoooool002;ooooo00?o0000
ooooooooool0?Oooool00ol0003oooooooooo`1?ooooo`So00002oooool3o`0001Oooooo1_l0000:
ooooo`05okZj^_n7QhOoIVIVofIVI_l@41001Oooool00ol0003oooooooooo`02ooooo`06o`000?oo
ooooooooooooooo^k^ko00000oooool01Ol0003ooooooooooooooooo00000:_ooooo000Rooooo`03
o`000?oooooooooo03gooooo00?o0000ooooooooool0COooool7o`0000_ooooo0ol0000Yooooo`06
oc8b<_lQ8B7oMgMgogMgMon7QhOok^k^1Oooool00ol0003oooooooooo`02ooooo`06o`000?oooooo
ooooooooooo^k^ko00000oooool01Ol0003ooooooooooooooooo00000:_ooooo000Sooooo`03o`00
0?oooooooooo03cooooo00?o0000ooooooooool0B_ooool8o`0000[ooooo0ol0000/ooooo`06o`00
0?nj^[[oooooonk^k_mgMgOo00001Oooool00ol0003oooooooooo`02ooooo`06oeEEEOmgMgOooooo
onk^k_mEEEGo00000oooool01Ol0003oQhN7oooooonYZJWo00000:_ooooo000Sooooo`03o`000?oo
oooooooo03cooooo0_l00019ooooo`Oo00002_ooool3o`0002oooooo00KoZJVYob4Q8Ol0003o0000
oc8b<_l00003ooooo`03oa0@4?l0003o000000Cooooo00_ok^k^oeEEEOl0003o8B4QojVYZOl0003o
410@ooooool@413o0000ogMgM`02o`000003oiRHV?oooooooooo0:Wooooo000Tooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool0AOooool8o`0000[ooooo0_l0003kooooo`009?ooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo04?ooooo1ol0000:ooooo`?o0000?oooool0
0ol0003oooooooooo`2kooooo`009Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo
043ooooo1ol0000;ooooo`;o0000@_ooool00ol@413oooooooooo`2kooooo`009Oooool00ol0003o
ooooooooo`0jooooo`03o`000?oooooooooo03gooooo2?l0000:ooooo`?o0000ooooool3ooooo`00
9_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo03[ooooo2?l0000:ooooo`?o0000
ooooool6ooooo`009_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo03Oooooo2?l0
000:ooooo`?o0000ooooool9ooooo`009oooool00ol0003oooooooooo`0hooooo`03o`000?oooooo
oooo03Cooooo2Ol00009ooooo`?o0000ooooool<ooooo`009oooool00ol0003oooooooooo`0hoooo
o`;o0000<_ooool4o`000003ooooool0003o000000;o00002Oooool3o`000?oooooo3oooool002So
oooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0^ooooo`Co000000?oooooo`000?l0
00000ol00008ooooo`?o0000oooooolBooooo`00:Oooool00ol0003oooooooooo`0fooooo`03o`00
0?oooooooooo02_ooooo0ol00002ooooo`Go00002?ooool3o`000?oooooo5Oooool002Wooooo00?o
0000ooooooooool0=_ooool00ol0003oooooooooo`0Wooooo`Co00000oooool5o`0000Oooooo0ol0
003ooooooaSooooo000Zooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool09?ooool4
o`0000?ooooo1Ol00007ooooo`?o0000oooooolKooooo`00:oooool00ol0003oooooooooo`0Yoooo
o`Co000000?o410@ooooooooool01?ooool00ol0003oooooooooo`0Qooooo`Co00000oooool6o`00
00Kooooo0ol0003ooooooakooooo000/ooooo`03o`000?oooooooooo02[ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0Nooooo`Co00000oooool6o`0000Kooooo0ol0003oooooob7o
oooo000]ooooo`03o`000?oooooooooo01kooooo1_l00005ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool06oooool3o`0000Cooooo1_l00005ooooo`Co0000oooooolTooooo`00;_oo
ool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Kooooo0ol0000Hooooo`?o00000ooo
ool7o`0000Cooooo1?l0003oooooobSooooo000_ooooo`03o`000?oooooooooo02Oooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Eooooo`?o00000oooool3o`000004ooooool0003o
0000o`0000Cooooo0ol0003oooooobcooooo000`ooooo`03o`000?oooooooooo02Kooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Booooo`?o00000oooool3o`000004ooooool0003o
0000o`0000?ooooo1?l0003ooooooboooooo000aooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0>ooooo`Co00000oooool3o`000004ooooool0003o
0000o`0000;ooooo1?l0003ooooooc?ooooo000booooo`03o`000?oooooooooo02;ooooo00?oEEEE
ofIVI_l000002?ooool00ol0003oooooooooo`0:ooooo`Co00001?ooool3o`000004ooooool0003o
0000o`0000;ooooo0ol0003oooooocOooooo000cooooo`;o0000;Oooool00ol0003oooooooooo`06
ooooo`Go00001?ooool3o`000005ooooool0003o0000o`000?ooool01?l0003ooooooc[ooooo000e
ooooo`;o0000:oooool00ol0003oooooooooo`02ooooo`Ko00001?ooool3o`000005ooooool0003o
0000o`000?ooool00ol0003oooooockooooo000gooooo`?o00009oooool9o`0000Cooooo0ol00002
ooooo`;o000000Coooooo`000?l0003o0000oooooom1ooooo`00>_ooool3o`0001kooooo1_l00000
0ooooooo0000o`000003o`0000Gooooo0_l00002ooooo`Ko0000oooooom4ooooo`00?Oooool2o`00
01Wooooo0ol00006ooooo`?o00001Oooool3o`000003ooooool0003o000000?o0000oooooom8oooo
o`00?oooool8o`0000Kooooo2ol00006ooooo`?o000000?oooooo`000?ooool00_ooool3o`000003
ooooool0003o000000;o0000oooooom<ooooo`00Aoooool6o`0000kooooo0ol00004ooooo`05o`00
0?oooooo0000o`000?ooool01?l0003oooooodoooooo001Hooooo`?o00001_ooool6o`000?oooooo
Doooool005Cooooo1?l00007ooooo`Go0000oooooomFooooo`00D?ooool4o`0000Sooooo1Ol00000
0ooooooo0000ooooo`3ooooooeKooooo001<ooooo`Co00002_ooool4o`0000Cooooo00?o0000oooo
ooooool0oooooomEooooo`00B?ooool4o`0000_ooooo1Ol00006ooooo`;o0000oooooomFooooo`00
A?ooool4o`0000_ooooo1_l00009ooooo`03o`000?oooooooooo0?ooooooEOooool003oooooo1Ol0
000:ooooo`So00003?ooool00ol0003oooooooooo`3ooooooeGooooo000jooooo`Go00002_ooool5
o`000003ooooool0003o000000;o00003oooool00ol0003oooooooooo`3ooooooeGooooo000eoooo
o`Go00002_ooool5o`0000?ooooo0ol0000Cooooo`03o`000?oooooooooo0?ooooooEOooool0037o
oooo1?l0000;ooooo`Co00001?ooool5o`0001Gooooo00?o0000ooooooooool0oooooomEooooo`00
;Oooool4o`0000cooooo0ol00005ooooo`Go00006?ooool00ol0003oooooooooo`3ooooooeGooooo
000Yooooo`Co00003?ooool4o`0000Gooooo1Ol0000Kooooo`03o`000?oooooooooo0?ooooooEOoo
ool002?ooooo1_l0000<ooooo`Co00001_ooool6o`0001gooooo0_l0003ooooooeKooooo000Loooo
o`Oo00003_ooool4o`0000Oooooo0ol000000ooooooo0000o`00000Pooooo`03o`000?oooooooooo
0?ooooooEOooool000gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`03ob4Q8Ol0003o0000
00;o00000_ooool01Om4A4Co0000o`000?lb<S;ogMgM00[ooooo1?l00008ooooo`?o000000Cooooo
o`000?l0003o00008_ooool00ol0003oooooooooo`0mooooo`Co000000?o410@ooooooooool00_oo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@0mooooo`Go0000?Oooool5o`0000Gooooo
0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0??ooool01OnHV9So410@o`000?lb<S;oc<c<
02cooooo000=ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b
<_ooool01Oooool4o`0000Wooooo0ol00002ooooo`;o00009Oooool00ol0003oooooooooo`0ooooo
o`03o`000?oooooooooo00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo03cooooo00GoV9RHob4Q
8Oo^k^koooooodA4A00mooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@01Oooool2ob4Q8@Sooooo00?o
MgMgoc8b<_ooool0>oooool01Ol@413o^[ZjoooooomgMgOo<S8b02cooooo000=ooooo`05oa0@4?oo
ooooooooooooool@41004?ooool00ol0003oooooooooo`04o`0000[ooooo0ol00002ooooo`?o0000
9oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0
??ooool00onHV9So8B4Qonk^kP0oooooo`03oiRHV?lQ8B7ok^k^017ooooo00?o0000ooooooooool0
?_ooool00ol0003oooooooooo`0Zooooo`003Oooool01Ol0003ooooooooooooooooo000000kooooo
1Ol0000;ooooo`?o00000oooool2o`0002[ooooo00?o0000ooooooooool0?oooool00ol0003ooooo
ooooo`0>ooooo`03ogMgMolb<S;ooooo03kooooo00?oV9RHob4Q8Oo^k^h0?oooool00onHV9So8B4Q
onk^kP0?ooooo`03ogMgMolb<S;ooooo03kooooo00?oZJVYoa0@4?ooool0:oooool000gooooo00Go
0000ooooooooooooooooo`000009ooooo`Ko000000?o<S8bolc<c?ooool02_ooool2o`0000Cooooo
0_l0000/ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool02oooool01Ol0003o8B4Q
o`000?lb<S;oc<c<043ooooo00?oMgMgofIVI_ooool0?oooool00omgMgOoIVIVooooo`0;ooooo`05
o`000?lQ8B7o0000oc8b<_o<c<`0?_ooool00ol@413o0000okZj^P0/ooooo`003Oooool01Ol@413o
oooooooooooooooo410@00Kooooo0ol00003ooooo`03o`000?oooooooooo00[ooooo0ol00005oooo
o`03o`000?oooooooooo02cooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo047ooooo00?o^[Zjob4Q8Oooool0:oooool000gooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo0ol00006ooooo`;o0000;oooool2o`00
043ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0oooooo`05o`000?nj^[[ooooo
oiRHV?l@4100?Oooool01Ol0003o^[ZjoooooonHV9So410@00cooooo00?o0000ooooooooool0?_oo
ool01Ol@413oV9RHoooooonj^[[o000002cooooo000=ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
3?ooool4o`0000Cooooo0_l00007ooooo`;o0000<Oooool00ol0003oooooooooo`0mooooo`03oeEE
EOmVIVKo000000gooooo1?l0000nooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0?Oooool01OnHV9So
410@o`000?lQ8B7oc<c<00cooooo1?l0000mooooo`05ojVYZOl@413o0000oa0@4?nYZJT0;?ooool0
02?ooooo0ol00007ooooo`;o0000<oooool00ol0003oooooooooo`3ooooooeGooooo000Pooooo`?o
00002?ooool2o`0003Gooooo00?o0000ooooooooool0oooooomEooooo`007Oooool3o`0000[ooooo
00?o0000ooooooooool0=Oooool00ol0003oooooooooo`3ooooooeGooooo000Jooooo`?o00002ooo
ool2o`0003Sooooo00?o0000ooooooooool0oooooolnooooo`;o00000_ooool2o`00017ooooo000H
ooooo`;o00003?ooool2o`0003[ooooo00?o0000ooooooooool0oooooolnooooo`06onk^k_lQ8B7o
QhN7okZj^_l0003ogMgM4Oooool002Gooooo00?o0000ooooooooool0>_ooool00ol0003ooooooooo
o`3oooooocoooooo00CogMgMo`000?l@413oc<c<4_ooool000koooooool00028o`0000kooooo00Co
k^k^ob4Q8Ol@413ok^k^4_ooool001Sooooo00?o0000ooooooooool01oooool2o`0000;ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool05Oooool01?lQ8B7oMgMgogMgMolb<S8Booooo`006?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool05?ooool2o`0000;ooooo0_l0
000Aooooo`006?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03oooooo00?o0000
ooooooooool0Aoooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo04Oooooo00?o0000
ooooooooool0Aoooool00ol0003oooooooooo`0[ooooo`007oooool00ol0003oooooooooo`10oooo
o`03o`000?oooooooooo0?ooooooEOooool001kooooo00Go0000ooooooooooooooooool@4002ool0
0004oooooooo003oo`00ool@40Sooooo00Goonk^oolb<_oo003ooc8booo^kP0/ooooo`03o`000?oo
oooooooo0?ooooooEOooool001gooooo00?o0000ooooooooool00oooool01Ooo003ooooooooooooo
ooooo`0000;ooooo1_oo00001_ooooooogMgoonHV?oooooooiRHoomgMbcooooo00?o0000oooooooo
ool0oooooomEooooo`007?ooool00ol0003oooooooooo`04ooooo`05ool00?oooooooooooooooooo
00002Oooool01Ooo413ooooooooooooooooooa0@02cooooo00?o0000ooooooooool0oooooomEoooo
o`006oooool00ol0003oooooooooo`05ooooo`05ool00?oooooooooooooooooo00000_ooool6ool0
0003oooooooo003ooooo00;ooooo00?oo`00ooooooooool0:_ooool2o`000?ooooooE_ooool001[o
oooo00?o0000ooooooooool01_ooool01Ooo003oohN7ooooooooZJWoo`0000Wooooo00Goo`00oooo
ooooooooooooool0000/ooooo`03o`000?oooooooooo0?ooooooEOooool001Sooooo1?l00006oooo
o`03ool@4?oo003oogMg00;oo`0000?ooiRHooooooooool01oooool01Ooo413ooooooooooooooooo
oa0@02cooooo00?o0000ooooooooool0oooooomEooooo`006?ooool01?l0003oooooooooooooool5
o`00013ooooo00GoogMgoonHV?oooooooiRHoomgM`0/ooooo`03o`000?oooooooooo0?ooooooEOoo
ool0027ooooo1Ol0000;ooooo`05ooo^k_oo<S;oo`00oolb<_ook^h0;?ooool00ol0003ooooooooo
o`3ooooooeGooooo000Vooooo`Go0000=oooool00ol0003oooooooooo`3ooooooeGooooo000[oooo
o`Go0000<_ooool00ol0003oooooooooo`3ooooooeGooooo000`ooooo`Go0000;Oooool00ol0003o
ooooooooo`3ooooooeGooooo000eooooo`Go0000:?ooool2o`000?ooooooE_ooool001Sooooo3?l0
000Fooooo`Co00009?ooool00ol0003oooooooooo`3ooooooeGooooo000Hooooo`04ool@4?oo003o
o`00ooooo`;oo`0000?ooa0@ooooooooool00oooool4o`0000Coo`0000?ooa0@ooooooooool03ooo
ool3o`00027ooooo00?o0000ooooooooool0oooooomEooooo`006Oooool01_oo003ooooooooooooo
ooooo`00ooooo`Koo`001Oooool00ooo003oooooo`000007o`0000gooooo1?l0000Mooooo`03o`00
0?oooooooooo0?ooooooEOooool001Wooooo00Goo`00ooooooooooooooooool0000<ooooo`03ool0
0?oooooooooo00Oooooo2?l00009ooooo`Co00006Oooool00ol0003oooooooooo`3ooooooeGooooo
000Iooooo`06ool00?oooooooooooooooooo003ooooo1_oo0005ooooo`03ool00?oooooooooo00oo
oooo1ol00006ooooo`Co00005Oooool00ol0003oooooooooo`3ooooooeGooooo000Iooooo`05ool0
0?ooQhOooooooonYZOoo00003?ooool00ooo003oooooooooo`0Fooooo`Oo00000oooool3o`0001;o
oooo00?o0000ooooooooool0oooooomEooooo`006?ooool00ooo413oo`00oomgM`02ool00003oonH
V?oooooooooo00[ooooo00?oo`00ooooooooool07Oooool5o`000003ooooool0003o000000;o0000
3_ooool00ol0003oooooooooo`3ooooooeGooooo000Zooooo`03ool00?oooooooooo02;ooooo2Ol0
000:ooooo`;o0000oooooomFooooo`00:?ooool00oooEEGoofIVool0000Yooooo`So00001_ooool0
0ol0003oooooooooo`3ooooooeGooooo001Jooooo`Ko00000_ooool00ol0003oooooooooo`3ooooo
oeGooooo000MooooobOo00006oooool5o`000?ooooooE_ooool001Sooooo1?l000001?o^003oo`00
ool00?ooool2ool00003ool@4?oooooooooo00Kooooo1Ooo000Dooooo`oo00003oooool00ol0003o
ooooo`000004o`000?ooooooDOooool001gooooo00Goo`00ooooooooooooooooool00002ooooo`Ko
o`0000KooooooonHV?oo8B7oonk^ooooooooA4@Sooooo`Ko00002Oooool00ol0003oooooooooo`03
ooooo`Ko0000oooooom<ooooo`007Oooool01Ooo003oooooooooooooooooo`0000[ooooo00?ooiRH
oolQ8Oook^h0:_ooool5o`0000Cooooo00?o0000ooooooooool01oooool7o`000?ooooooAoooool0
01gooooo00Goo`00ooooooooooooooooool00002ooooo`Koo`000oooool00oooV9Soob4Qooo^kP0^
ooooo`Go00003?ooool9o`000?oooooo@_ooool001gooooo00Goo`00oon7QoooooooojVYool0000<
ooooo`03oomgMoooIVKooooo037ooooo1ol0000:ooooo`Co000000?oooooo`000?l000000_l0003o
ooooockooooo000Looooo`03ool@4?oo003oogMg00;oo`0000?ooiRHooooooooool02oooool00ooo
003oooooooooo`0BoooooaGo00002Oooool00ol0003oooooooooo`04ooooo`So00001_ooool3o`00
00;ooooo1?l0003ooooooc[ooooo000[ooooo`05ool00?oo^[[ooooooonHV?oo41003?ooool8o`00
01Gooooo2_l0000>ooooo`Ko00000oooool4o`0000;ooooo1?l0003oooooocKooooo000[ooooo`05
oonHV?oo413oo`00oolQ8Oooc<`01Oooool7o`0002Kooooo2Ol0000<ooooo`Co00000oooool3o`00
00?ooooo1?l0003ooooooc;ooooo000aooooo`Co0000;Oooool00ol0003oooooooooo`06ooooo`Oo
00002Oooool4o`0000;ooooo0ol00004ooooo`Co0000ooooool^ooooo`00;_ooool3o`00037ooooo
00?o0000ooooooooool03Oooool8o`0000Gooooo1?l000000ooooooo0000o`000002o`0000Cooooo
0ol0003oooooob_ooooo000/ooooo`;o0000:Oooool4o`000003oa0@4?oooooooooo00Cooooo00?o
0000ooooooooool05Oooool7o`0000;ooooo2?l00004ooooo`Co0000oooooolWooooo`00:_ooool2
o`0002gooooo00?o0000ooooooooool06ol0000:ooooo`Ko000000?oooooo`000?l000001?l00005
ooooo`Co0000oooooolSooooo`00:?ooool2o`0002gooooo1Ol00006ooooo`?o00004_ooool;o`00
00Gooooo1?l00002ooooo`Go00001Oooool4o`000?oooooo7oooool002Kooooo0_l0000Xooooo`Oo
00000_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01gooooo1_l00003ooooo`Co
00000_ooool5o`0000Gooooo1?l0003ooooooa_ooooo000Uooooo`04onh00?oo003oo`00ooooo`;o
o`0000?ooa0@ooooooooool01_ooool01OooV9Sooa0@ool00?oo<S;oolc<01Kooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02?ooooo1Ol00002oooo
o`Co000000?oooooo`000?l000001?l00005ooooo`Co0000oooooolGooooo`008oooool2o`000003
oooooooo003ooooo00;ooooo00?oo`00ooooooooool01_oo00001_oooooooa0@oonj^_ooooooogMg
oolb<Q?ooooo0ol0000:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0:?ooool5
o`000003ooooool0003o000000Wo00001Oooool4o`000?oooooo4oooool0027ooooo0_l00003oooo
o`05ool00?oooooooooooooooooo00003Oooool00ooo003oooooooooo`0>ooooo`?o00003Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo02gooooo4?l00005ooooo`Co0000ooooool?
ooooo`008?ooool00ol0003oooooooooo`03ooooo`05ool00?oooooooooooooooooo00000_ooool6
ool000Cooooo00?oojVYool@4?ooool03Oooool2o`0000kooooo00?oEEEEofIVI_l000002?ooool0
0ol0003oooooooooo`0cooooo`ko00001Oooool3o`000?oooooo3?ooool001oooooo00?o0000oooo
ooooool01?ooool01Ooo003oohN7ooooooooZJWoo`0000_ooooo00?ooa0@ool00?oo^[X03?ooool2
o`0001_ooooo00?o0000ooooooooool0>?ooool=o`0000Cooooo1?l0003oooooo`Sooooo000Noooo
o`03o`000?oooooooooo00Cooooo00?ooa0@ool00?ooMgL00_oo00000oooV9Soooooooooo`0:oooo
o`03oonj^_oo8B7ooooo00Wooooo0_l0000Mooooo`03o`000?oooooooooo03gooooo2ol00005oooo
o`Co0000ooooool4ooooo`007Oooool00ol0003oooooooooo`0Dooooo`05ool@4?ooV9Sooooooonj
^_oo00002Oooool00ol0003oooooooooo`0Mooooo`;o0000@oooool:o`0000Gooooo0ol0003ooooo
o`7ooooo000Looooo`03o`000?oooooooooo01Gooooo00GoojVYool@4?oo003ooa0@oonYZ@07oooo
o`;o00008?ooool00ol0003oooooooooo`16ooooo`?o000000?oooooo`000?l000001?l00004oooo
o`?o0000AOooool01OlQ8B7o0000o`000?m4A4CogMgM0;?ooooo000Kooooo`03o`000?oooooooooo
027ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`18ooooo`Go000000?oooooo`00
0?l000000ol00004ooooo`?o0000AOooool00omgMgOo<S8booooo`2booooo`006oooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0Boooool6o`000003
ooooool0003o000000;o00001?ooool3o`0004?ooooo00?o0000ooooooooool0/Oooool001[ooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo04kooooo
2ol00004ooooo`?o00007oooool00ol0003oooooooooo`09ooooo`06oa0@4?lb<S;o0000o`000?l@
413oZJVY0oooool5o`0000;ooooo00Kok^k^oeEEEOl0003o410@olc<c?l00002ooooo`04oa0@4?l0
003o0000ooooo`;o000000?o410@ooooooooool0Z?ooool001Wooooo00?o0000ooooooooool08?oo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo057ooooo0ol000000ooooooo0000o`00
0005o`0000Cooooo0ol0000Looooo`03o`000?oooooooooo00Wooooo00Ko0000ojVYZOoooooooooo
okZj^_l00005ooooo`03o`000?oooooooooo00;ooooo00KoEEEEogMgMoooooook^k^oeEEEOl00003
ooooo`05o`000?ooooooooooooooool00000Zoooool001Sooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`0Tooooo`03o`000?oooooooooo05Cooooo0ol000000ooooooo0000o`000006
o`0000?ooooo0ol0000Gooooo`Go00002_ooool01Onj^[[oQhN7ofIVI_mVIVKo410@00Gooooo00?o
0000ooooooooool00_ooool01_l0003oooooooooooooooook^k^o`0000?ooooo00Go0000oooooooo
ooooooooo`00002[ooooo`00>_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo05Oo
oooo0ol00002ooooo`So00000_ooool3o`0001Kooooo00?o0000ooooooooool02Oooool01_lb<S;o
8B4QogMgMomgMgOoQhN7onk^kPGooooo00?o0000ooooooooool00_ooool01_l0003ooooooooooooo
ooook^k^o`0000?ooooo00Go0000ooooooooooooooooo`00002[ooooo`00>Oooool00ol0003ooooo
ooooo`0Vooooo`;o0000Foooool3o`0000?ooooo2?l000001?oooooo0000o`000?l0000Cooooo`03
o`000?oooooooooo00Wooooo00Ko0000okZj^_ooooook^k^ogMgMol00005ooooo`03o`000?oooooo
oooo00;ooooo00KoEEEEogMgMoooooook^k^oeEEEOl00003ooooo`05o`000?n7QhOoooooojVYZOl0
0000Zoooool003Sooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1Mooooo`?o0000
1?ooool;o`0001cooooo00KoZJVYob4Q8Ol0003o0000oc8b<_l00003ooooo`03oa0@4?l0003o0000
00Cooooo00_ok^k^oeEEEOl0003o8B4QojVYZOl0003o410@ooooool@413o0000ogMgM`02o`000003
oiRHV?oooooooooo0:Wooooo000gooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0
H?ooool3o`0000Gooooo2_l0003Rooooo`00=oooool00ol0003oooooooooo`0Xooooo`03o`000?oo
oooooooo06?ooooo0ol00006ooooo`Wo00008Oooool00ol0003oooooooooo`2kooooo`00=_ooool0
0ol0003oooooooooo`0Yooooo`03o`000?oooooooooo06Kooooo0ol00007ooooo`So00007_ooool0
0ol@413oooooooooo`2kooooo`00=Oooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo
06Wooooo0ol00007ooooo`So0000fOooool003Cooooo00?o0000ooooooooool0:oooool00ol0003o
ooooooooo`1/ooooo`;o00002?ooool9o`000=Gooooo000cooooo`03o`000?oooooooooo02cooooo
00?o0000ooooooooool0K_ooool3o`0000Sooooo2Ol0003Booooo`00<oooool00ol0003ooooooooo
o`0/ooooo`;o0000L_ooool3o`0000Sooooo2Ol0003?ooooo`00<_ooool00ol0003oooooooooo`0]
ooooo`03o`000?oooooooooo07Cooooo0_l0000:ooooo`So0000c?ooool003;ooooo00?o0000oooo
ooooool0;Oooool00ol0003oooooooooo`1fooooo`?o00002_ooool8o`000<Wooooo000aooooo`03
o`000?oooooooooo02kooooo00?o0000ooooooooool0NOooool3o`0000[ooooo2Ol00035ooooo`00
<?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo07cooooo0ol0000:ooooo`Go0000
00Coooooo`000?l0003o0000`_ooool0033ooooo00?o0000ooooooooool0;oooool00ol0003ooooo
ooooo`1oooooo`?o00002_ooool5o`000004ooooool0003o0000o`000;oooooo000_ooooo`03o`00
0?oooooooooo033ooooo00?o0000ooooooooool0P_ooool3o`0000[ooooo1?l00002ooooo`?o0000
_?ooool002oooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`25ooooo`?o00002_oo
ool4o`0000;ooooo0ol0002iooooo`00;_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooo
oooo08Sooooo0ol0000:ooooo`?o00000oooool2o`000;Oooooo000^ooooo`03o`000?oooooooooo
037ooooo0_l0002<ooooo`;o00002oooool3o`0000;ooooo0ol0002dooooo`00;Oooool00ol0003o
ooooooooo`0booooo`03o`000?oooooooooo08gooooo0_l0000<ooooo`?o00000_ooool2o`000;;o
oooo000]ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0Soooool3o`0000_ooooo
1?l000001?oooooo0000o`000?l0002_ooooo`00;?ooool00ol0003oooooooooo`0cooooo`03o`00
0?oooooooooo09;ooooo0_l0000<ooooo`Co000000?oooooo`000?l00000[Oooool002cooooo00?o
0000ooooooooool0<oooool00ol0003oooooooooo`2Dooooo`;o00003Oooool7o`000:[ooooo000[
ooooo`03o`000?oooooooa0@00;oo`0000Coooooool00?oo003ooa0@2_ooool2ool00003ool@4?oo
oooooooo01?ooooo1Ol00007ooooo`03o`000?oooooooooo09Kooooo0ol0000<ooooo`Oo0000Z?oo
ool002_ooooo00Co0000ooooooooooooo`000oooool00ooo003oooooool00005ool000Gooooo00?o
o`00ooooooooool05?ooool01OnHV9So8B4Qonk^k_ooooooA4A400Oooooo00?o0000ooooooooool0
VOooool2o`0000gooooo1ol0002Uooooo`00:_ooool01Ol0003oooooooooooooooooo`0000?ooooo
00?oo`00ooooooooool01oooool5ool001Kooooo00?oV9RHob4Q8Oo^k^h02?ooool00ol0003ooooo
ooooo`2Kooooo`;o00003_ooool7o`000:;ooooo000Zooooo`05o`000?oooooooooooooooooo0000
0oooool00ooo003oooooool00005ool000;ooooo00CoodA4oooMgOooooooo`006?ooool00onHV9So
8B4Qonk^kP07ooooo`?o0000WOooool3o`0000kooooo1_l0002Pooooo`00:_ooool02Ol0003ooooo
ooooooooooooo`00oon7QoooooooojVYool00009ooooo`04oooMgOooEEGoooooool001Wooooo00?o
MgMgofIVI_ooool01_ooool00ol0003oooooooooo`2Pooooo`?o00003_ooool6o`0009gooooo000Y
ooooo`07o`000?oooooooooooooooooo413oo`00oomgM`02ool00003oonHV?oooooooooo00Sooooo
00?oogMgooo<c?oo00006_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo0:?ooooo
0_l0000?ooooo`Ko0000V_ooool002Wooooo00?o0000ooooooooool04Oooool00oook^koodA4ool0
000Fooooo`05o`000?nj^[[ooooooiRHV?l@41001oooool00ol0003oooooooooo`2Uooooo`?o0000
3oooool5o`0009Sooooo000Yooooo`03o`000?oooooooooo01;ooooo00?oogMgool00?ooool05Ooo
ool01OnHV9So410@o`000?lQ8B7oc<c<00Oooooo00?o0000ooooooooool0Z?ooool3o`0000oooooo
1Ol0002Eooooo`00:?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo0:_ooooo0_l0
000?ooooo`Go0000Toooool002Sooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`2]
ooooo`?o00003oooool5o`00093ooooo000Xooooo`03o`000?oooooooooo03Oooooo00?o0000oooo
ooooool0/?ooool2o`00013ooooo1?l0002>ooooo`009oooool00ol0003oooooooooo`0hooooo`;o
0000/oooool3o`0000oooooo1Ol0002;ooooo`009oooool00ol0003oooooooooo`0hooooo`03o`00
0?oooooooooo0;Gooooo0_l0000@ooooo`Co0000ROooool002Kooooo00?o0000ooooooooool0>Ooo
ool00ol0003oooooooooo`2gooooo`?o00004?ooool4o`0008Kooooo000Vooooo`03o`000?oooooo
oooo03Wooooo00?o0000ooooooooool0^_ooool2o`00013ooooo1Ol00023ooooo`009_ooool00ol0
003oooooooooo`0iooooo`03o`000?oooooooooo0;cooooo0ol0000?ooooo`Go0000POooool002Go
oooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`2oooooo`;o00004?ooool5o`0007ko
oooo000Uooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0`Oooool3o`0000oooooo
1_l0001kooooo`009Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo0<Cooooo0_l0
000?ooooo`Ko0000NOooool002Cooooo00?o0000ooooooooool0>oooool2o`000<Oooooo0ol0000?
ooooo`Ko0000M_ooool002Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`39oooo
o`;o00003oooool7o`0007?ooooo000Tooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool0boooool2o`0000oooooo1ol0001aooooo`008oooool00ol0003oooooooooo`0looooo`03o`00
0?oooooooooo0<gooooo0ol0000?ooooo`Oo0000K_ooool002?ooooo00?o0000ooooooooool0??oo
ool00ol0003oooooooooo`3@ooooo`;o00003oooool8o`0006_ooooo000Sooooo`03o`000?oooooo
oooo03cooooo00?o0000ooooooooool0d_ooool2o`00013ooooo1ol0001Yooooo`008oooool00ol0
003oooooooooo`0looooo`03o`000?oooooooooo0=Cooooo0ol0000?ooooo`So0000I_ooool002;o
oooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`3Gooooo`;o00004?ooool4o`000003
ooooool0003o000006Cooooo000Rooooo`03o`000?oooooooooo03gooooo0_l0003Jooooo`;o0000
4?ooool8o`00067ooooo000Rooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0fooo
ool2o`00017ooooo1?l000000ooooooo0000o`00001Oooooo`008_ooool00ol0003oooooooooo`0m
ooooo`03o`000?oooooooooo0=gooooo0ol0000Aooooo`?o000000Coooooo`000?l0003o0000G?oo
ool0027ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`3Pooooo`;o00004Oooool4
o`000003ooooool0003o000005[ooooo000Qooooo`03o`000?oooooooooo03kooooo00?o0000oooo
ooooool0h_ooool2o`0001;ooooo0ol000000ooooooo0000o`00001Hooooo`008Oooool00ol0003o
ooooooooo`0nooooo`03o`000?oooooooooo0>Cooooo0ol0000Booooo`;o000000Coooooo`000?l0
003o0000EOooool0027ooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`3Wooooo`;o
00004_ooool3o`000003ooooool0003o000005?ooooo000Qooooo`03o`000?oooooooooo03kooooo
00?o0000ooooooooool0jOooool2o`0001;ooooo0ol000000ooooooo0000o`00001Aooooo`008?oo
ool00ol0003oooooooooo`0oooooo`;o0000k?ooool2o`0001?ooooo1_l0001>ooooo`008?ooool0
0ol0003oooooooooo`0oooooo`03o`000?oooooooooo0>gooooo0ol0000Booooo`?o000000?ooooo
o`000?l00000C?ooool0023ooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`3`oooo
o`;o00004_ooool6o`0004[ooooo000Pooooo`03o`000?oooooooooo03oooooo00?o0000oooooooo
ool0l_ooool2o`0001?ooooo1Ol00018ooooo`007oooool00ol0003oooooooooo`10ooooo`03o`00
0?oooooooooo0?Cooooo0ol0000Booooo`Go0000A_ooool001oooooo00?o0000ooooooooool0=?oo
ool01OnHV9So410@o`000?lb<S;oc<c<00Oooooo00?o0000ooooooooool0moooool2o`0001;ooooo
1_l00013ooooo`007oooool00ol0003oooooooooo`0dooooo`05oa0@4?nj^[[oooooogMgMolb<S80
1oooool00ol0003oooooooooo`3iooooo`;o00004_ooool6o`00047ooooo000Nooooo`03o`000?oo
oooooooo03Wooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`3kooooo`;o00004ooo
ool5o`0003oooooo000Nooooo`03o`000?oooooooooo03Sooooo00?oZJVYoa0@4?ooool01_ooool3
o`000?gooooo00?o0000ooooooooool04_ooool2o`000003ooooool0003ooooo03gooooo001Hoooo
o`03oa0@4?l0003o^[Zj0?ooooooGoooool005Wooooo00?o^[Zjob4Q8Oooool0oooooomNooooo`00
E_ooool01Ol@413oV9RHoooooonj^[[o00000?ooooooGoooool005Kooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@3ooooooeoooooo003ooooook[ooooo003ooooook[ooooo003ooooook[ooooo003ooooo
ok[ooooo003ooooook[ooooo003ooooook[ooooo003ooooook[ooooo001Gooooo`04o`000?oooooo
ooooo`0000Sooooo00?oMgMgofIVI_ooool02?ooool00omVIVKoMgMgooooo`3oooooodWooooo001G
ooooo`04o`000?ooooooooooo`0000Oooooo00?ogMgMoa0@4?o^k^h02Oooool00oo^k^ko410@omgM
g@3oooooodWooooo001Aooooo`07oa0@4?lQ8B7o0000o`000?m4A4CogMgMo`000002ooooo`03o`00
0?oooooooooo00Gooooo00CoEEEEoiRHV?oooooooooo0_l00002ooooo`;o00000oooool00on7QhOo
IVIVooooo`3oooooodSooooo001Aooooo`06o`000?n7QhOooooooooooon7QhOo8B4Q0ol00008oooo
o`0:o`000?ooooooooooooooooo^k^ko8B4QohN7Qonj^[[o0000omgMg@?ooooo00?ok^k^o`000?oo
ool0oooooom8ooooo`00DOooool01_lQ8B7oooooooooooooooook^k^o`0000_ooooo00?o<S8boooo
ooooool00_ooool01?oMgMgo0000oa0@4?o<c<`5ooooo`03o`000?oooooooooo0?ooooooAoooool0
05;ooooo00GogMgMoiRHV?mgMgOo410@ofIVIP0;ooooo`03oc8b<_oooooooooo00;ooooo00Cok^k^
ob4Q8Ol@413ok^k^1Oooool00ol0003oooooooooo`3oooooodOooooo001Aooooo`05ofIVI_l@413o
EEEEohN7Qonj^[X03?ooool00ol0003ok^k^ooooo`02ooooo`04ob4Q8OmgMgOoMgMgoc8b<PCooooo
00?ok^k^o`000?ooool0oooooom8ooooo`00DOooool01_l0003ok^k^ooooooooooooc<c<o`0000_o
oooo00CoEEEEogMgMooooooooooo0_l00002ooooo`;o00000oooool00omgMgOoEEEEooooo`3ooooo
odSooooo001Aooooo`06oc8b<_n7QhOoooooonk^k_mVIVKo00002oooool00ooMgMgo410@onk^kP09
ooooo`03onk^k_l@413ogMgM0?ooooooBOooool0057ooooo00Kok^k^odA4A?l0003o0000oc8b<_l@
410<ooooo`03ogMgMomVIVKooooo00Sooooo00?oIVIVogMgMoooool0oooooom9ooooo`00oooooonj
ooooo`00oooooonjooooo`00oooooonjooooo`00\
\>"],
  ImageRangeCache->{{{0, 440}, {271.562, 0}} -> {0.338404, -3.13996, \
0.00840833, 0.0310969}}],

Cell[TextData[{
  "Fig. 5.9 Approximants to the eikonal for the Airy equation. Order of the \
approximant is shown for the + sign solution. Note the breakdown of \
convergence for ",
  Cell[BoxData[
      \(TraditionalForm\`x \[LessTilde] \ 1\)]],
  " , as expected for an asymptotic expansion that holds only for ",
  Cell[BoxData[
      \(TraditionalForm\`x >> 1\)]],
  ". "
}], "Caption",
  CellTags->"Fig. 5.9"],

Cell[TextData[{
  StyleBox["(4)(a)", "Text",
    FontWeight->"Bold"],
  StyleBox["  Approximants found from recursion relations can also be used to \
solve certain nonlinear equations.  For example, consider the equation ", 
    "Text"],
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\ x\^\(\(3\)\(\ \)\) - x\  + \ 1 = 0\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda] << 1\)]],
  ". A dominant balance exists between ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`1\)]],
  ": if we assume that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\ \(x\^\(\(3\)\(\ \)\)\) << 1\)]],
  " and drop this term, the solution is ",
  Cell[BoxData[
      \(TraditionalForm\`x = 1\)]],
  ". Then ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\ x\^3 = \[Lambda] << 1\)]],
  ", which is consistent with our assumption. Set up a recursion relation of \
the form ",
  Cell[BoxData[
      \(TraditionalForm\`x\_n = \ 1\  + \ \[Lambda]\ x\_\(n - 1\)\^3\)]],
  ", and solve for ",
  Cell[BoxData[
      \(TraditionalForm\`x\_3\)]],
  ", given ",
  Cell[BoxData[
      \(TraditionalForm\`x\_0 = 1\)]],
  ". (No need to Taylor-expand the solution.) Plot the result for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < \[Lambda] < 1\)]],
  "."
}], "Text",
  CellTags->"i:97"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " The  cubic polynomial in part (a) has three roots, but we only found one \
approximate solution in part (a).  Evidently there are two other solutions.  \
Find another dominant balance between two terms in the equation that yields \
approximations to these solutions, set up a recursion relation, and solve it \
up to at least ",
  Cell[BoxData[
      \(TraditionalForm\`x\_3\)]],
  ".  (Again, no Taylor expansion is necessary.)"
}], "Text",
  CellTags->"i:110"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Plot the asymptotic expressions found in parts (a) and (b) together on \
the same graph as a function of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\[Lambda]\)\(\ \)\)\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < \[Lambda] < 1\)]],
  ". Superimpose  these results  on the exact solutions of the cubic equation \
vs. ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\)]],
  ".  "
}], "Text"],

Cell[TextData[{
  StyleBox["(5)",
    FontWeight->"Bold"],
  " The general wave equation for a 1D string with mass density ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho](x)\)]],
  " and tension ",
  Cell[BoxData[
      \(TraditionalForm\`T(x)\)]],
  " is"
}], "Text",
  CellTags->"i:98"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(\[PartialD]\^2\/\[PartialD]t\^2\) \(y(x, 
            t)\) = \(1\/\(\[Rho](x)\)\) \(\[PartialD]\/\[PartialD]x\) \((\(T(
                x)\)\ \(\[PartialD]\/\[PartialD]x\) \(y(x, t)\))\)\)]],
  ","
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Show that the WKB solution for traveling waves on this string is"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`y(x, 
          t) = \(C\/\([\(T(x)\) \(\[Rho](x)\)]\)\^\(1/4\)\) \[ExponentialE]\^\
\(\(-\[ImaginaryI]\)\ \[Omega]\ t\  + \ \[ImaginaryI] \(\[Integral]\_0\%x\( \
k(x)\) \(\(\[DifferentialD]x\)\(\ \)\)\)\) + \(\(D\/\([\(T(x)\) \
\(\[Rho](x)\)]\)\^\(1/4\)\) \(\[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Omega]\
\ t\  + \(-\[ImaginaryI]\) \(\[Integral]\_0\%x\( k(
                          x)\) \(\(\[DifferentialD]x\)\(\ \)\)\)\)\)\(\ \
\)\)\)]],
  ","
}], "NE2",
  CellTags->"(5.2.62)"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`k(
          x)\  = \ \[Omega]/\@\(\(T(x)\)/\(\[Rho](x)\)\)\)]],
  " is the local wavenumber."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Use the result of part (a) to prove that the WKB solution to Eq. ",
  ButtonBox["(5.2.32)",
    ButtonData:>"(5.2.32)",
    ButtonStyle->"Hyperlink"],
  " is  Eq. ",
  ButtonBox["(5.2.35)",
    ButtonData:>"(5.2.35)",
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(6)",
    FontWeight->"Bold"],
  " A simple pendulum with varying length ",
  Cell[BoxData[
      \(TraditionalForm\`l(t)\)]],
  " satisfies the following differential equation:"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(\[DifferentialD]\/\[DifferentialD]t\)[\(\(l\^2\)(
              t)\)\ \(\(\[Theta]\& . \)(t)\)] \[Equal] \(\(-g\)\(\ \)\(l(
            t)\)\(\ \)\(\[Theta](t)\)\(\ \)\)\)]],
  ","
}], "Text"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        RowBox[{"g", "=", 
          RowBox[{"9.8", " ", 
            RowBox[{
              StyleBox["m",
                FontSlant->"Plain"], "/", 
              SuperscriptBox[
                StyleBox["s",
                  FontSlant->"Plain"], "2"]}]}]}], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta] << 1\)]],
  " is assumed."
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Use WKB analysis to determine how ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta](t)\)]],
  " varies in time, assuming that ",
  Cell[BoxData[
      \(TraditionalForm\`l(t)\)]],
  " varies slowly. Plot ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta](t)\)]],
  " assuming that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta](0) = 10\ \[Degree]\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Theta]\& . \)(0) = 0\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`l(t)\  = \ 11\  - \ t\)]],
  ", for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < \)]],
  "10 . Compare with the exact motion, found using ",
  StyleBox["NDSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Find an adiabatic invariant for the pendulum motion. (Hint: The energy of \
the pendulum is ",
  Cell[BoxData[
      \(TraditionalForm\`E(
          t) = \(1\/2\) m\ l\^2\ \[Theta]\& . \^2\  + \ \(1\/2\) 
            m\ g\ l\ \[Theta]\^2\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " is the mass of the bob. )"
}], "Text"],

Cell[TextData[{
  StyleBox["(7)",
    FontWeight->"Bold"],
  " For the hanging string of length ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " described by Eq. ",
  ButtonBox["(4.2.41)",
    ButtonData:>{"Chapter4.nb", "(4.2.41)"},
    ButtonStyle->"Hyperlink"],
  ", use WKB analysis to determine the evolution of  a Gaussian wave packet \
of the initial form"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`y(z, 0)\  = \ Exp[\(-40\) \((z - L/2)\)\^2\ ]\)]],
  ", \nmoving down the string (in the ",
  Cell[BoxData[
      \(TraditionalForm\`\(-z\)\)]],
  "-direction, toward the free end at ",
  Cell[BoxData[
      \(TraditionalForm\`z = 0\)]],
  ").  Make an animation taking ",
  Cell[BoxData[
      \(TraditionalForm\`L = 3\)]],
  ", and compare this evolution with the exact evolution determined in \
Example 2 of Sec. ",
  ButtonBox["4.2.2",
    ButtonData:>{"Chapter4.nb", "c:21"},
    ButtonStyle->"Hyperlink"],
  ", for ",
  Cell[BoxData[
      FormBox[
        RowBox[{"0", "<", "t", "<", 
          RowBox[{"0.6", " ", 
            StyleBox["s",
              FontSlant->"Plain"]}]}], TraditionalForm]]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(8)",
    FontWeight->"Bold"],
  " A rod with varying mass density ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho](x)\)]],
  " supports transverse vibrations that satisfy the inhomogeneous biharmonic \
wave equation"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(\[PartialD]\^2\/\[PartialD]t\^2\) \(y(x, 
            t)\) = \(-\(D\/\(\[Rho](
                  x)\)\)\) \(\[PartialD]\^4\/\[PartialD]x\^4\) \(y(x, 
            t)\)\)\(,\)\)\)]]
}], "Text"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      \(TraditionalForm\`D\)]],
  " is a constant [see Eq. ",
  ButtonBox["(4.2.47)",
    ButtonData:>{"Chapter4.nb", "(4.2.47)"},
    ButtonStyle->"Hyperlink"],
  "]. Using WKB theory, analyze the behavior of traveling waves on this rod, \
and determine the manner in which the wave amplitude varies as ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho](x)\)]],
  " varies."
}], "Text"],

Cell[TextData[{
  StyleBox["(9)(a)",
    FontWeight->"Bold"],
  " A beam of light of frequency \[Omega] has an electric field ",
  Cell[BoxData[
      \(TraditionalForm\`E(x, t)\)]],
  " that varies as ",
  Cell[BoxData[
      \(TraditionalForm\`\(E(
          x)\) \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \[Omega]\ t\)\)]],
  ",  and that propagates in the +",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " direction through a clear medium with varying refractive index  ",
  Cell[BoxData[
      \(TraditionalForm\`n = n(x)\)]],
  " . The electric field in the light wave satisfies "
}], "Text",
  CellTags->"i:127"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FractionBox[\(\[PartialD]\^2\( E(x, t)\)\), \(\[PartialD]t\^2\),
              MultilineFunction->None], "=", 
            RowBox[{\(\(\(c\^2\)\(\ \)\)\/\(n(x)\)\^2\), 
              
              FractionBox[\(\[PartialD]\^2\( E(x, t)\)\), \(\[PartialD]x\^2\),
                
                MultilineFunction->None]}]}], " ", ","}], TraditionalForm]]],
  "\nwhere ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  " is the speed of light in vacuum.  Analyze this equation using WKB theory, \
and determine how  the electric field varies with ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ", assuming that the index varies little over a wavelength of the light. "
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " The average flux of energy (power per unit area) carried by the beam in \
the ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  "-direction is ",
  Cell[BoxData[
      \(TraditionalForm\`1\/2\ \(n(x)\)\  | 
        E[x, t]\( | \^2\)c\ \[Epsilon]\_o\)]],
  " [",
  ButtonBox["Griffiths (1999, p. 83)",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  "]. According to the WKB approach, how does this energy flux vary with ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  "? Comment.    "
}], "Text"],

Cell[TextData[{
  StyleBox["(10)",
    FontWeight->"Bold"],
  " When a light beam of frequency ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\)]],
  " propagates in an ",
  StyleBox["arbitrary",
    FontSlant->"Italic"],
  " direction ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          OverscriptBox[
            StyleBox["k",
              FontWeight->"Bold",
              FontSlant->"Plain"], "^"],
          FontWeight->"Bold"], TraditionalForm]]],
  " through a (non-magnetic) medium with index of refraction ",
  Cell[BoxData[
      FormBox[
        RowBox[{"n", "(", 
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], ")"}], TraditionalForm]]],
  ", ",
  ButtonBox["Maxwell",
    ButtonData:>{
      URL[ 
      "http://www-groups.dcs.st-and.ac.uk/~history/Mathematicians/Maxwell.\
html"], None},
    ButtonStyle->"Hyperlink"],
  "'s equations imply that"
}], "Text",
  CellTags->"i:126"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FractionBox[\(\[PartialD]\^2\), \(\[PartialD]t\^2\),
              MultilineFunction->None], 
            RowBox[{
              StyleBox["E",
                FontWeight->"Bold",
                FontSlant->"Plain"], "(", 
              RowBox[{
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], ",", "t"}], ")"}]}], "=", 
          RowBox[{
            FractionBox[\(\(c\^2\)\(\ \)\), 
              RowBox[{" ", 
                SuperscriptBox[
                  FormBox[
                    RowBox[{"n", "(", 
                      StyleBox["r",
                        FontWeight->"Bold",
                        FontSlant->"Plain"], ")"}],
                    "TraditionalForm"], "2"]}]], "[", 
            RowBox[{
              RowBox[{\(\[Del]\^2\), 
                StyleBox["E",
                  FontWeight->"Bold",
                  FontSlant->"Plain"]}], 
              StyleBox[" ",
                FontWeight->"Plain"], 
              StyleBox["+",
                FontWeight->"Plain"], 
              RowBox[{
                StyleBox["2",
                  FontWeight->"Plain"], 
                RowBox[{
                  StyleBox["\[Del]",
                    FontWeight->"Plain"], 
                  RowBox[{
                    StyleBox["(",
                      FontWeight->"Plain"], 
                    RowBox[{
                      StyleBox["E",
                        FontWeight->"Bold",
                        FontSlant->"Plain"], 
                      StyleBox["\[CenterDot]",
                        FontWeight->"Plain"], \(\[Del]n\/n\)}], 
                    StyleBox[")",
                      FontWeight->"Plain"]}]}]}]}], 
            StyleBox["]",
              FontWeight->"Plain"]}], 
          StyleBox[" ",
            FontWeight->"Plain"]}], TraditionalForm]]],
  "."
}], "NE2",
  CellTags->{"i:118", "(5.2.63)"}],

Cell[TextData[{
  "Assume that ",
  Cell[BoxData[
      \(TraditionalForm\`n = n(x)\)]],
  ", and that the beam propagates in the ",
  Cell[BoxData[
      \(TraditionalForm\`x - y\)]],
  " plane. Take components of the equation, and use WKB theory to analyze the \
wave propagation in two cases:"
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " If ",
  Cell[BoxData[
      \(TraditionalForm\`E\_x = \(E\_y = 0\)\)]],
  " but ",
  Cell[BoxData[
      \(TraditionalForm\`E\_z\  \[NotEqual] \ 0\)]],
  " , show that this remains true everywhere, so that ",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          FormBox[
            RowBox[{
              RowBox[{
                StyleBox[
                  OverscriptBox[
                    StyleBox["k",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], "^"],
                  FontWeight->"Bold"], "\[CenterDot]", 
                StyleBox["E",
                  FontWeight->"Bold",
                  FontSlant->"Plain"]}], 
              StyleBox["=",
                FontWeight->"Plain"], 
              StyleBox["0",
                FontWeight->"Plain"]}],
            "TraditionalForm"]}], TraditionalForm]]],
  "  everywhere, and find the dependence of |",
  Cell[BoxData[
      \(TraditionalForm\`\(\(E\_z\)\(|\)\)\)]],
  " on ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ". "
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " If ",
  Cell[BoxData[
      \(TraditionalForm\`E\_z\  = \ 0\)]],
  " but ",
  Cell[BoxData[
      \(TraditionalForm\`E\_\(\(x\)\(\ \)\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`E\_y\)]],
  " are not equal to zero initially, show that ",
  Cell[BoxData[
      \(TraditionalForm\`E\_z\)]],
  " remains zero.  Although the propagation direction varies with ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ",  the waves must remain transverse, i.e. ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Del]", 
          RowBox[{"\[CenterDot]", 
            RowBox[{"(", 
              StyleBox[
                RowBox[{"\[Epsilon]", 
                  StyleBox["E",
                    FontWeight->"Bold",
                    FontSlant->"Plain"]}]], ")"}]}]}], TraditionalForm]]],
  "=0, where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon] = n\^2\)]],
  " is the dielectric function. Solve Eq. ",
  ButtonBox["(5.2.63)",
    ButtonData:>"(5.2.63)",
    ButtonStyle->"Hyperlink"],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`E\_x\)]],
  " in the WKB limit,  apply ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["k",
              FontWeight->"Bold",
              FontSlant->"Plain"], "\[CenterDot]", 
            StyleBox["E",
              FontWeight->"Bold",
              FontSlant->"Plain"]}], 
          StyleBox["\[TildeEqual]",
            FontWeight->"Plain"], 
          StyleBox["0",
            FontWeight->"Plain"]}], TraditionalForm]]],
  " to find ",
  Cell[BoxData[
      \(TraditionalForm\`E\_y\)]],
  ", and find the dependence of ",
  Cell[BoxData[
      FormBox[
        RowBox[{"|", 
          StyleBox["E",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["|",
            FontWeight->"Plain"]}], TraditionalForm]]],
  " on ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Show that for both cases (a) and (b), the results are compatible with the \
conservation of the ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  "-component of the average Poynting flux: "
}], "Text",
  CellTags->"i:99"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["S",
              FontWeight->"Bold",
              FontSlant->"Plain"], "\[CenterDot]", 
            StyleBox[
              OverscriptBox[
                StyleBox["x",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "^"],
              FontWeight->"Bold"]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox[" ",
            FontWeight->"Plain"], 
          RowBox[{
            RowBox[{\(1\/\(2  \[Mu]\_o\)\), 
              RowBox[{
                RowBox[{
                  StyleBox["(",
                    FontWeight->"Plain"], 
                  RowBox[{
                    StyleBox["E",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], "\[Times]", 
                    StyleBox[\(B\^*\),
                      FontWeight->"Bold"]}], ")"}], "\[CenterDot]", 
                StyleBox[
                  OverscriptBox[
                    StyleBox["x",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], "^"],
                  FontWeight->"Bold"]}]}], 
            StyleBox[" ",
              FontWeight->"Bold"], "=", 
            RowBox[{
              RowBox[{\(1\/2\), 
                SuperscriptBox[
                  RowBox[{"(", 
                    RowBox[{"|", 
                      StyleBox["E",
                        FontWeight->"Bold",
                        FontSlant->"Plain"], 
                      StyleBox["|",
                        FontWeight->"Plain"]}], ")"}], "2"], " ", \(c\^2\), 
                " ", \(\[Epsilon]\_\(\(o\)\(\ \)\)\), \(k\_x/\ \[Omega]\)}], 
              "=", " ", "constant"}]}]}], TraditionalForm]]],
  "."
}], "Text"],

Cell["\<\
(This is the same result as obtained in the previous problem for a \
scalar wave equation.)\
\>", "Text"],

Cell[TextData[{
  StyleBox["(11)",
    FontWeight->"Bold"],
  " An electromagnetic wave of frequency ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega] = 3\)]],
  " and speed ",
  Cell[BoxData[
      \(TraditionalForm\`c = 1\)]],
  " is polarized in the ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  "-direction and propagates in the ",
  Cell[BoxData[
      \(TraditionalForm\`x - y\ plane\)]],
  ". The beam is incident on a medium with index of refraction ",
  Cell[BoxData[
      \(TraditionalForm\`n(x)\)]],
  ". The electric field in these waves is described by Eq. ",
  ButtonBox["(5.2.63)",
    ButtonData:>"(5.2.63)",
    ButtonStyle->"Hyperlink"],
  ". The  angle of incidence is ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\_o = 45  \[Degree]\)]],
  ". The index varies in ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " according to "
}], "Text"],

Cell[TextData[{
  "\t",
  Cell[BoxData[
      FormBox[
        RowBox[{\(n(x)\), "=", 
          TagBox[
            RowBox[{
              StyleBox["{",
                ShowAutoStyles->False,
                FontSize->16], 
              StyleBox[GridBox[{
                    {\(1, \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ x < 0, \)},
                    {\(1\  + \ \(1\/4\) \(sin(x)\), \ \ \ x \[GreaterEqual] \ 
                        0. \)}
                    }],
                ShowAutoStyles->True]}],
            (#&)]}], TraditionalForm]]]
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Plot contours of constant ",
  Cell[BoxData[
      \(TraditionalForm\`Re\ E\_z\)]],
  " at ",
  Cell[BoxData[
      \(TraditionalForm\`t = 0\)]],
  " in the range ",
  Cell[BoxData[
      \(TraditionalForm\`\(-5\) < x < 15\)]],
  ",",
  Cell[BoxData[
      \(TraditionalForm\`\(-5\) < y < 15\)]]
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Plot a ray trajectory ",
  Cell[BoxData[
      \(TraditionalForm\`y(x)\)]],
  " starting at ",
  Cell[BoxData[
      \(TraditionalForm\`x = \(-5\), y = \(-5\), \)]],
  "  for ",
  Cell[BoxData[
      \(TraditionalForm\`\(-5\) < x < 15\)]],
  ", using the previous parameters. Superimpose this ray on the previous \
contour plot."
}], "Text"],

Cell[TextData[{
  StyleBox["(12)",
    FontWeight->"Bold"],
  " A surfer is a distance of 100 m from the shore, which runs north-south. \
Swells with a 17-m wavelength are moving past him with a period of 4 seconds. \
Use the full dispersion relation for water waves, ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Omega]\^2\), "=", 
          RowBox[{"g", " ", "|", 
            StyleBox["k",
              FontWeight->"Bold",
              FontSlant->"Plain"], "|", " ", 
            RowBox[{"tanh", "(", 
              RowBox[{\(h(x)\), " ", "|", 
                StyleBox["k",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "|"}], ")"}]}]}], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " What is the depth of the water at this location? "
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " At the surfer's location, the waves travel in the direction 40 Degrees \
north of due east with period and wavenumber given above. The ocean depth \
varies as  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(h\_o/\((1 + x\^2/10\^3)\)\)\(\ \)\)\)]],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  " is in meters, measured from the surfer's position. The surfer lets the \
swells carry him in, eventually taking him 100 m in the ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  "-direction into shore (where the depth is roughly  one-tenth its previous \
value and the surfer can stand up). Assuming he rides directly transverse to \
the wave face, and that he travels at the same speed as the swells, plot the \
surfer's trajectory. How long does it take him to make this distance? How far \
north of his initial location does he get before he reaches shore?"
}], "Text"],

Cell[TextData[{
  StyleBox["(13)",
    FontWeight->"Bold"],
  " An undersea mountain causes the water depth to vary as ",
  Cell[BoxData[
      \(TraditionalForm\`h(x, y)\  = \ 
        1\  - \ 0.7\ exp[\(-2\) \((x - 1/2)\)\^2 - 5 \((y - 1/2)\)\^2]\)]],
  ". Water waves  have frequency ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"\[Omega]", "(", 
            RowBox[{"k", ",", 
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"]}], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox[" ",
            FontWeight->"Plain"], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox[" ",
            FontWeight->"Plain"], 
          SqrtBox[
            RowBox[{"g", " ", "k", " ", 
              RowBox[{"tanh", "(", 
                RowBox[{"k", " ", 
                  RowBox[{"h", "(", 
                    StyleBox["r",
                      FontWeight->"Bold",
                      FontSlant->"Plain"], ")"}]}], ")"}]}]]}], 
        TraditionalForm]]],
  ", where we will take ",
  Cell[BoxData[
      \(TraditionalForm\`g = 1\)]],
  ", and where  ",
  Cell[BoxData[
      \(TraditionalForm\`k = \@\(k\_x\^2 + k\_y\^2\)\)]],
  " is the magnitude of the wavenumber. Use the equations of geometric optics \
to trace 11 wavepacket trajectories which initially have ",
  Cell[BoxData[
      \(TraditionalForm\`k\_x = 0\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`k\_y = 1\)]],
  ", and start at ",
  Cell[BoxData[
      \(TraditionalForm\`y = 0\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(x = 0.1\ n\)\(,\)\)\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(n = 0, 1, 2, \(\(...\) \(10\)\)\)\)\)]],
  ". Follow the trajectories for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < t < 2\)]],
  " and plot them all on a single parametric plot of ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " vs. ",
  Cell[BoxData[
      \(TraditionalForm\`x\)]],
  ". What happens to the trajectories? (The same principle is at work in any \
lens system.)"
}], "Text",
  CellTags->"i:111"],

Cell[TextData[{
  StyleBox["(14)",
    FontWeight->"Bold"],
  " In shortwave radio communication, the diffuse plasma in the ionosphere \
can be used as a mirror to bounce radio waves to receivers beyond the \
horizon. For  radio waves of frequency ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\)]],
  ", the index of refraction is a function of altitude ",
  Cell[BoxData[
      \(TraditionalForm\`z\)]],
  ", and is approximately ",
  Cell[BoxData[
      \(TraditionalForm\`n(
          z, \[Omega]) = \@\(1 - \(\(\[Omega]\_p\^2\)(z)\)/\[Omega]\^2\)\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_p = \@\(\(e\^\(\(2\)\(\ \)\)\) \(N(z)\)/\
\[Epsilon]\_o\ m\)\)]],
  " is the ",
  StyleBox["electron",
    FontSlant->"Italic"],
  " ",
  StyleBox["plasma frequency",
    FontSlant->"Italic"],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`e\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`m\)]],
  " are the electron charge and mass respectively, and ",
  Cell[BoxData[
      \(TraditionalForm\`N(z)\)]],
  " is the electron density in ",
  Cell[BoxData[
      FormBox[
        SuperscriptBox[
          StyleBox["m",
            FontSlant->"Plain"], \(-3\)], TraditionalForm]]],
  ". At ground level ",
  Cell[BoxData[
      \(TraditionalForm\`z = 0\)]],
  " the electron density is negligible, but at altitudes on the order of \
50-100 km it grows to some maximum value due to the ionizing effect of UV  \
radiation, and then decays again at still higher altitudes as the atmospheric \
density falls off."
}], "Text",
  CellTags->"i:100"],

Cell[TextData[{
  StyleBox["(a) ",
    FontWeight->"Bold"],
  "Show that electromagnetic waves travel through this plasma with the \
dispersion relation"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\^2 = \(c\^2\) k\^2 + \(\[Omega]\_p\^2\)(
            z)\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  "  Show that waves shone directly upward, with ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["k",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{
            StyleBox["k",
              FontWeight->"Plain"], 
            StyleBox[" ",
              FontWeight->"Plain"], 
            StyleBox[
              OverscriptBox[
                StyleBox["z",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "^"],
              FontWeight->"Bold"]}]}], TraditionalForm]]],
  ", will reflect back provided that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega] < \[Omega]\_\(p\ max\)\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_\(p\ max\)\)]],
  " is the maximum plasma frequency. (Hint: Find the turning point for the \
rays.)"
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " More generally, show that for ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega] > \[Omega]\_\(p\ max\)\)]],
  ", there is a maximum angle ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\_max\)]],
  " with respect to the horizontal at which one can direct the waves, and \
still have them bounce back. Find an expression for the angle ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Theta]\_max\)(\[Omega])\)]],
  ". (Answer: ",
  Cell[BoxData[
      \(TraditionalForm\`\(sin\^2\) \[Theta]\_max = \((\[Omega]\_\(p\ max\)/\
\[Omega])\)\^2\)]],
  ")."
}], "Text"],

Cell[TextData[{
  StyleBox["(d)",
    FontWeight->"Bold"],
  " Take the following simple model for the electron density in the \
ionosphere:"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{\(N(z)\), "=", 
          TagBox[
            RowBox[{
              StyleBox["{",
                ShowAutoStyles->False,
                FontSize->16], 
              StyleBox[GridBox[{
                    {\(0, \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \ \
\ \ \ \ \ \ \ \ \ \ \ z < H, \)},
                    {
                      RowBox[{
                        RowBox[{\(5\[Cross]\ 10\^14\), " ", 
                          SuperscriptBox[
                            StyleBox["m",
                              FontSlant->"Plain"], \(-3\)], 
                          " ", \(\((z/H - 
                                  1)\)\^2\), \(\[ExponentialE]\^\(\(-10\) \
\((z/H - 1)\)\(\ \)\)\)}], ",", " ", \(z \[GreaterEqual] \ H\), ","}]}
                    }],
                ShowAutoStyles->True]}],
            (#&)]}], TraditionalForm]]]
}], "Text"],

Cell[TextData[{
  " with ",
  Cell[BoxData[
      \(TraditionalForm\`H = 70\ km\)]],
  ".\nUsing this model and the results of part (c), trace several ray \
trajectories for values of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\)]],
  " in the range  ",
  Cell[BoxData[
      \(TraditionalForm\`0 < \[Theta] \[LessEqual] \ \ \[Theta]\_max\)]],
  " to show that communication with a receiver closer than a certain distance \
",
  Cell[BoxData[
      \(TraditionalForm\`d(\[Omega])\)]],
  "  to the transmitter (but beyond the horizon) is impossible when ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega] > \[Omega]\_\(p\ max\)\)]],
  ". Find ",
  Cell[BoxData[
      \(TraditionalForm\`d(\[Omega])\)]],
  " graphically for\n  (i) ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega] = 2\ \[Pi]\ \(\(c/10\)\(\ \)\)\)]],
  "(10 meter wavelength) and (ii)  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega] = 2\ \[Pi]\ c/5\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(15)",
    FontWeight->"Bold"],
  " A nebula consists of plasma with plasma frequency ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Omega]\_p\)(x, y, z)\)]],
  " that varies in space as  ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Omega]\_p\)(x, y, 
          z) = \ \@\(A\ x\^2 + B\ y\^2\  + \ C\ z\^2\)\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`a, \ b, \)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  " are constants. A radio source at the center of the nebula emits waves of \
frequency ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\)]],
  " in all directions. Using the dispersion relation from the previous \
problem, and the equations of geometrical optics, find the ray trajectories \
for the radio waves analytically, and show that the radio waves are trapped \
within the nebula.   Plot a ray trajectory using ",
  StyleBox["ParametricPlot3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  StyleBox[" ",
    FontWeight->"Bold"],
  "for the following conditions: ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"A", "=", 
            RowBox[{"1", " ", 
              RowBox[{
                SuperscriptBox[
                  StyleBox["s",
                    FontSlant->"Plain"], \(-2\)], "/", \(km\^2\)}]}]}], ",", 
          RowBox[{"B", "=", 
            RowBox[{"4", " ", 
              RowBox[{
                SuperscriptBox[
                  StyleBox["s",
                    FontSlant->"Plain"], \(-2\)], "/", \(km\^2\)}]}]}], ",", 
          RowBox[{"C", "=", 
            RowBox[{"9", " ", 
              RowBox[{
                SuperscriptBox[
                  StyleBox["s",
                    FontSlant->"Plain"], \(-2\)], "/", \(km\^2\)}]}]}], ",", 
          " ", 
          RowBox[{"\[Omega]", " ", "=", " ", 
            RowBox[{\(10\^10\), " ", \(sec\^\(-1\)\), Cell[""]}]}]}], 
        TraditionalForm]]],
  ", and  ",
  Cell[BoxData[
      FormBox[
        StyleBox["k",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " initially in the direction ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"(", 
            RowBox[{
              OverscriptBox[
                StyleBox["x",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "^"], "+", 
              OverscriptBox[
                StyleBox["y",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "^"], "+", 
              OverscriptBox[
                StyleBox["z",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "^"]}], ")"}], "/", \(\@3\)}], 
        TraditionalForm]]],
  " ."
}], "Text"],

Cell[TextData[{
  StyleBox["(16)(a) ",
    FontWeight->"Bold"],
  "At a planar interface between two media with refractive indices ",
  Cell[BoxData[
      \(TraditionalForm\`n\_1\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`n\_2\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`n\_1 > n\_2\)]],
  ", show using Snell's law  that a ray in medium ",
  Cell[BoxData[
      \(TraditionalForm\`1\)]],
  " propagating toward the interface  will be completely reflected provided \
that the angle ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\)]],
  " between the interface and the ray satisfies  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi] < \[Psi]\_\(\(c\)\(\ \)\) = \ 
        arccos(n\_2/n\_1)\)]],
  ". (Hint: Show that no real solution for the refracted-wave angle exists if \
this inequality is satisfied.)"
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " In an optical fiber, the index of refraction ",
  Cell[BoxData[
      \(TraditionalForm\`n = n(r)\)]],
  " is a decreasing function of cylindrical radius ",
  Cell[BoxData[
      \(TraditionalForm\`r\)]],
  ". In typical fibers the index is of the form ",
  Cell[BoxData[
      \(TraditionalForm\`n(r) = n\_1\ \((r < a)\)\)]],
  "; ",
  Cell[BoxData[
      \(TraditionalForm\`n = n\_2\ \((r > a)\)\)]],
  ", with ",
  Cell[BoxData[
      \(TraditionalForm\`a = 4\ \ \[Mu]m\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(n\_1 = 1.451\)\(,\)\)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`n\_2 = 1.444\)]],
  ".  The critical angle is then ",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\_c = 5.63\ \[Degree]\)]],
  ".  The point of an optical fiber is that it guides the rays, even if the \
fiber bends.  Initially, a ray propagates along the axis of the fiber. Then, \
the fiber is bent into a circle of radius ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(R\)\(>>\)\)\)]],
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  ". Given that ",
  Cell[BoxData[
      \(TraditionalForm\`n\_1\)]],
  " is nearly the same as ",
  Cell[BoxData[
      \(TraditionalForm\`n\_2\)]],
  " so that ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[Psi]\_c\) << 1\)]],
  ",  show that the ray will be trapped in the fiber provided that ",
  Cell[BoxData[
      \(TraditionalForm\`R > 2  a/\ \[Psi]\_c\^2 = 830\ \[Mu]m\)]],
  " (",
  Cell[BoxData[
      \(TraditionalForm\`\[Psi]\_c\)]],
  " measured in radians)."
}], "Text",
  CellTags->"i:101"],

Cell[TextData[{
  StyleBox["(17)",
    FontWeight->"Bold"],
  " The speed  ",
  Cell[BoxData[
      \(TraditionalForm\`c\_p\)]],
  " of compressional sound waves in the earth (",
  Cell[BoxData[
      \(TraditionalForm\`P\)]],
  "-waves) is an increasing function of depth ",
  Cell[BoxData[
      \(TraditionalForm\`d\)]],
  " measured from the earth's surface, thanks to the fact that the earth's \
mean density increases with depth.  In accordance with Snell's law, this \
causes  waves that are initially propagating downward to bend back toward the \
surface. A theorist's model for the  dependence  of the wave speed on depth \
",
  Cell[BoxData[
      \(TraditionalForm\`d\)]],
  " into the Earth's  upper crust is "
}], "Text",
  CellTags->"i:102"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(c\_p\)(d) = 
        c\_o\  + \ \((c\_1 - c\_o)\)\ d/d\_o\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`d < d\_o\)]],
  ","
}], "Text"],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(c\_o\), "=", " ", 
          RowBox[{"8", " ", 
            RowBox[{"km", "/", 
              StyleBox["s",
                FontSlant->"Plain"]}]}]}], TraditionalForm]]],
  " is the speed at the surface,  ",
  Cell[BoxData[
      \(TraditionalForm\`d\_o = 2900\ km\)]],
  " is the  depth of the earth's outer core, and ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(c\_1\), "=", 
          RowBox[{"14", " ", 
            RowBox[{"km", "/", 
              StyleBox["s",
                FontSlant->"Plain"]}]}]}], TraditionalForm]]],
  " is the speed at ",
  Cell[BoxData[
      \(TraditionalForm\`d = d\_o\)]],
  ". Assuming that the waves travel along the great circle defined by ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] = 0\)]],
  ", the equations for geometrical optics in spherical coordinates ",
  Cell[BoxData[
      \(TraditionalForm\`\((r, \[Theta], \[Phi])\)\)]],
  " are"
}], "Text"],

Cell[TextData[{
  "\t\t ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]r/\[DifferentialD]t\  = \ \
\[PartialD]\[Omega]/\[PartialD]k\_r, \[IndentingNewLine]\[DifferentialD]k\_r/\
\[DifferentialD]t\  = \(-\ \[PartialD]\[Omega]\)/\[PartialD]r, \)]],
  "   ",
  Cell[BoxData[
      \(TraditionalForm\`r \[DifferentialD]\[Theta]/\[DifferentialD]t\  = \ \
\[PartialD]\[Omega]/\[PartialD]k\_\[Theta], \[IndentingNewLine]\
\[DifferentialD]k\_\[Theta]/\[DifferentialD]t\  = \(-\((1/
                r)\)\)\ \ \[PartialD]\[Omega]/\(\(\[PartialD]\[Theta]\)\(.\)\)\
\)]]
}], "Text"],

Cell[TextData[{
  "where the wave vector ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["k",
            FontWeight->"Bold",
            FontSlant->"Plain"], "=", 
          RowBox[{
            RowBox[{\(k\_r\), " ", 
              OverscriptBox[
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "^"]}], "+", 
            RowBox[{\(k\_\[Theta]\), 
              OverscriptBox[
                StyleBox["\[Theta]",
                  FontWeight->"Bold"], "^"]}]}]}], TraditionalForm]]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega] = \(\(c\_p\)(d = R\_e - r)\)\ k\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`R\_e = 6400\ km\)]],
  " is the earth's radius."
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Use these equations to plot the ray trajectories in the ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, z)\)\)]],
  " plane (where ",
  Cell[BoxData[
      \(TraditionalForm\`x = r\ sin\[Theta], \ z = r\ cos\ \[Theta]\)]],
  ") followed by 10 sound rays until they reach the surface again, starting \
from ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta] = 0, r = R\_e\)]],
  " (i.e. ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0, \ z = R\_e\)]],
  "),  ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(k\_r\), "=", 
            RowBox[{\(-5\), "  ", 
              SuperscriptBox[
                StyleBox["m",
                  FontSlant->"Plain"], \(-1\)]}]}], ","}], 
        TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(k\_\[Theta]\), "=", " ", 
          RowBox[{"n", "  ", 
            SuperscriptBox[
              StyleBox["m",
                FontSlant->"Plain"], \(-1\)]}]}], TraditionalForm]]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(n\)\(=\)\)\)]],
  "5,6,...,15. (This takes up to 1000 seconds for the longest ray \
trajectories.)"
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Let ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\_o\)]],
  " be the value of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\)]],
  " for which a given ray reappears at the Earth's surface, ",
  Cell[BoxData[
      \(TraditionalForm\`r = R\_e\)]],
  ". Using ",
  StyleBox["FindRoot",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ", determine the propagation time ",
  Cell[BoxData[
      \(TraditionalForm\`\(t\_p\)(\[Theta]\_o)\)]],
  " to propagate from ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta] = 0\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta] = \[Theta]\_o\)]],
  ", for the rays found in  part (a). Plot this propagation time vs. ",
  Cell[BoxData[
      \(TraditionalForm\`\[Theta]\_o\)]],
  ". [Given the positions of three or more seismographs and the arrival time \
of the pulse at each, one can fix the location of the epicenter. See, for \
example,  ",
  ButtonBox["Garland (1979)",
    ButtonData:>{"Chapter4.nb", "refs"},
    ButtonStyle->"Hyperlink"],
  " in the reference list for Chapter ",
  ButtonBox["4",
    ButtonData:>{"Chapter4.nb", None},
    ButtonStyle->"Hyperlink"],
  ".]"
}], "Text"],

Cell[TextData[{
  StyleBox["(18)",
    FontWeight->"Bold"],
  " A point source generates sound wave pulses at ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], " ", "=", " ", "0"}], TraditionalForm]]],
  ". The sound speed in still air is ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  ". The pulses initially travel in the ",
  Cell[BoxData[
      \(TraditionalForm\`\(+x\)\)]],
  " (horizontal) direction (i.e. ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(k\_x > 0\), ",", Cell[TextData[Cell[BoxData[
              \(TraditionalForm\`k\_y = 0\)]]]]}], TraditionalForm]]],
  ".  However, a wind of velocity ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["v",
            FontWeight->"Bold",
            FontSlant->"Plain"], " ", "=", " ", \(\(-a\)\ y\ x\&^\)}], 
        TraditionalForm]]],
  " ",
  StyleBox[" ",
    FontWeight->"Bold"],
  " is blowing, where ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  " is altitude and ",
  Cell[BoxData[
      \(TraditionalForm\`a\)]],
  " is a positive constant.  The shear in the wind causes the pulses to \
travel upward. Using the equations of geometrical optics,  find an analytic \
expression for the time ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  " required for the pulses to reach a height ",
  Cell[BoxData[
      \(TraditionalForm\`y\)]],
  ". Plot the shape of the wave-packet trajectory ",
  Cell[BoxData[
      \(TraditionalForm\`y(x)\)]],
  " for ",
  Cell[BoxData[
      \(TraditionalForm\`a = 1, c = 340\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`0 < x < 100\)]],
  " (in MKS units) (The shape of this trajectory explains why it is difficult \
to make someone hear you when they are upwind of your position: your shouts  \
into the wind are refracted up over the person's head.) (Hint: see Eq. ",
  ButtonBox["(5.1.88)",
    ButtonData:>"(5.1.88)",
    ButtonStyle->"Hyperlink"],
  ")."
}], "Text"],

Cell[TextData[{
  StyleBox["(19)",
    FontWeight->"Bold"],
  "  Whistler waves  are electromagnetic waves that travel along the earth's \
magnetic field lines, and are described by the dispersion relation given by \
Eq. ",
  ButtonBox["(5.1.104)",
    ButtonData:>"(5.1.104)",
    ButtonStyle->"Hyperlink"],
  ". The earth's magnetic field can be approximated as the field from a point \
magnetic dipole of order ",
  Cell[BoxData[
      FormBox[
        RowBox[{"M", "=", 
          RowBox[{"8", "\[Times]", \(10\^15\), "  ", 
            StyleBox["T",
              FontSlant->"Plain"], 
            StyleBox[" ",
              FontSlant->"Plain"], 
            SuperscriptBox[
              StyleBox["m",
                FontSlant->"Plain"], "3"]}]}], TraditionalForm]]],
  ". Therefore, in spherical coordinates the magnetic field has the form"
}], "Text",
  CellTags->"i:103"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["B",
            FontWeight->"Bold",
            FontSlant->"Plain"], " ", "=", " ", 
          RowBox[{\(-M\), " ", 
            RowBox[{
              RowBox[{"(", 
                RowBox[{
                  RowBox[{"2", " ", 
                    OverscriptBox[
                      StyleBox["r",
                        FontWeight->"Bold",
                        FontSlant->"Plain"], "^"], "cos", " ", "\[Theta]"}], 
                  " ", "+", " ", 
                  RowBox[{
                    OverscriptBox[
                      StyleBox["\[Theta]",
                        FontWeight->"Bold"], "^"], " ", "sin", " ", 
                    "\[Theta]"}]}], ")"}], "/", \(r\^3\)}]}]}], 
        TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  "The plasma frequency in the earth's magnetosphere varies roughly as ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(\[Omega]\_p\)(
          r) = \[Omega]\_\(p\ o\)\ \((R\ sin\^2\ \
\[Theta]/r)\)\^2\)\(,\)\)\)]],
  "  where ",
  Cell[BoxData[
      \(TraditionalForm\`R = 6400\ km\)]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Omega]\_\(p\ o\)\), "=", 
          RowBox[{"3", "\[Times]", " ", \(10\^7\), " ", 
            SuperscriptBox[
              StyleBox["s",
                FontSlant->"Plain"], \(-1\)]}]}], TraditionalForm]]],
  "[see ",
  ButtonBox["M. Schulz and L. Lanzerotti (1974)",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  "].  Follow the trajectories of four wave packets that begin in the \
northern hemisphere at ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[Phi] = 0\), ",", \(\[Theta] = \[Pi]/4\), ",", \(r = R\), 
          ",", " ", 
          RowBox[{
            RowBox[{"|", 
              StyleBox["k",
                FontWeight->"Bold",
                FontSlant->"Plain"], "|"}], 
            "=", \(3\[Cross]10\^\(-5\)\ m\)}]}], TraditionalForm]]],
  ", but with random initial propagation directions.  Plot the trajectories \
using ",
  StyleBox["ParametricPlot3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " , and plot the earth's surface for reference, to determine visually at \
what location the trajectories return to the earth's surface. (The solution \
for one set of random trajectories is shown in Fig. ",
  ButtonBox["5.10",
    ButtonData:>"Fig. 5.10",
    ButtonStyle->"Hyperlink"],
  ".) "
}], "Text"],

Cell[BoxData[
  Graphics3D[{
    Line[{{459619392.000000, 0.000000, 459619392.000000},{
      513510912.000000, 17908790.000000, 487201312.000000}}],
    Line[{{513510912.000000, 17908790.000000, 487201312.000000},{
      566922496.000000, 36943848.000000, 502858464.000000}}],
    Line[{{566922496.000000, 36943848.000000, 502858464.000000},{
      616761664.000000, 54441824.000000, 508276608.000000}}],
    Line[{{616761664.000000, 54441824.000000, 508276608.000000},{
      661773056.000000, 69781552.000000, 506707584.000000}}],
    Line[{{661773056.000000, 69781552.000000, 506707584.000000},{
      702091456.000000, 83182536.000000, 500618912.000000}}],
    Line[{{702091456.000000, 83182536.000000, 500618912.000000},{
      738275072.000000, 95006968.000000, 491546976.000000}}],
    Line[{{738275072.000000, 95006968.000000, 491546976.000000},{
      770907072.000000, 105568016.000000, 480426880.000000}}],
    Line[{{770907072.000000, 105568016.000000, 480426880.000000},{
      800489472.000000, 115105784.000000, 467844864.000000}}],
    Line[{{800489472.000000, 115105784.000000, 467844864.000000},{
      827432256.000000, 123800328.000000, 454184064.000000}}],
    Line[{{827432256.000000, 123800328.000000, 454184064.000000},{
      852066240.000000, 131787096.000000, 439704928.000000}}],
    Line[{{852066240.000000, 131787096.000000, 439704928.000000},{
      874659136.000000, 139169904.000000, 424591040.000000}}],
    Line[{{874659136.000000, 139169904.000000, 424591040.000000},{
      895429440.000000, 146029648.000000, 408976000.000000}}],
    Line[{{895429440.000000, 146029648.000000, 408976000.000000},{
      914556864.000000, 152429952.000000, 392959104.000000}}],
    Line[{{914556864.000000, 152429952.000000, 392959104.000000},{
      932190720.000000, 158421840.000000, 376616224.000000}}],
    Line[{{932190720.000000, 158421840.000000, 376616224.000000},{
      948456576.000000, 164047408.000000, 360006400.000000}}],
    Line[{{948456576.000000, 164047408.000000, 360006400.000000},{
      963460544.000000, 169341120.000000, 343176192.000000}}],
    Line[{{963460544.000000, 169341120.000000, 343176192.000000},{
      977292928.000000, 174331744.000000, 326162944.000000}}],
    Line[{{977292928.000000, 174331744.000000, 326162944.000000},{
      990031296.000000, 179043488.000000, 308997024.000000}}],
    Line[{{990031296.000000, 179043488.000000, 308997024.000000},{
      1001742400.000000, 183496960.000000, 291703328.000000}}],
    Line[{{1001742400.000000, 183496960.000000, 291703328.000000},{
      1012484160.000000, 187709888.000000, 274302496.000000}}],
    Line[{{1012484160.000000, 187709888.000000, 274302496.000000},{
      1022306880.000000, 191697424.000000, 256811888.000000}}],
    Line[{{1022306880.000000, 191697424.000000, 256811888.000000},{
      1031254272.000000, 195472656.000000, 239246128.000000}}],
    Line[{{1031254272.000000, 195472656.000000, 239246128.000000},{
      1039364800.000000, 199047280.000000, 221617632.000000}}],
    Line[{{1039364800.000000, 199047280.000000, 221617632.000000},{
      1046671744.000000, 202431152.000000, 203937184.000000}}],
    Line[{{1046671744.000000, 202431152.000000, 203937184.000000},{
      1053204288.000000, 205633056.000000, 186214080.000000}}],
    Line[{{1053204288.000000, 205633056.000000, 186214080.000000},{
      1058987904.000000, 208660768.000000, 168456384.000000}}],
    Line[{{1058987904.000000, 208660768.000000, 168456384.000000},{
      1064044416.000000, 211520832.000000, 150671424.000000}}],
    Line[{{1064044416.000000, 211520832.000000, 150671424.000000},{
      1068393088.000000, 214219344.000000, 132865472.000000}}],
    Line[{{1068393088.000000, 214219344.000000, 132865472.000000},{
      1072049984.000000, 216761296.000000, 115044456.000000}}],
    Line[{{1072049984.000000, 216761296.000000, 115044456.000000},{
      1075028992.000000, 219151328.000000, 97213536.000000}}],
    Line[{{1075028992.000000, 219151328.000000, 97213536.000000},{
      1077341312.000000, 221393248.000000, 79377696.000000}}],
    Line[{{1077341312.000000, 221393248.000000, 79377696.000000},{
      1078996224.000000, 223490480.000000, 61541440.000000}}],
    Line[{{1078996224.000000, 223490480.000000, 61541440.000000},{
      1080000768.000000, 225445728.000000, 43709300.000000}}],
    Line[{{1080000768.000000, 225445728.000000, 43709300.000000},{
      1080360320.000000, 227261632.000000, 25885234.000000}}],
    Line[{{1080360320.000000, 227261632.000000, 25885234.000000},{
      1080077952.000000, 228940064.000000, 8073452.500000}}],
    Line[{{1080077952.000000, 228940064.000000, 8073452.500000},{
      1079154816.000000, 230482416.000000, -9721724.000000}}],
    Line[{{1079154816.000000, 230482416.000000, -9721724.000000},{
      1077590784.000000, 231890112.000000, -27496412.000000}}],
    Line[{{1077590784.000000, 231890112.000000, -27496412.000000},{
      1075383168.000000, 233163712.000000, -45246084.000000}}],
    Line[{{1075383168.000000, 233163712.000000, -45246084.000000},{
      1072527680.000000, 234303664.000000, -62966268.000000}}],
    Line[{{1072527680.000000, 234303664.000000, -62966268.000000},{
      1069018368.000000, 235310064.000000, -80652232.000000}}],
    Line[{{1069018368.000000, 235310064.000000, -80652232.000000},{
      1064846464.000000, 236182480.000000, -98298728.000000}}],
    Line[{{1064846464.000000, 236182480.000000, -98298728.000000},{
      1060001984.000000, 236920256.000000, -115900184.000000}}],
    Line[{{1060001984.000000, 236920256.000000, -115900184.000000},{
      1054472256.000000, 237522288.000000, -133450416.000000}}],
    Line[{{1054472256.000000, 237522288.000000, -133450416.000000},{
      1048241984.000000, 237987104.000000, -150942592.000000}}],
    Line[{{1048241984.000000, 237987104.000000, -150942592.000000},{
      1041293888.000000, 238312784.000000, -168368928.000000}}],
    Line[{{1041293888.000000, 238312784.000000, -168368928.000000},{
      1033607040.000000, 238497088.000000, -185720848.000000}}],
    Line[{{1033607040.000000, 238497088.000000, -185720848.000000},{
      1025158016.000000, 238537216.000000, -202988352.000000}}],
    Line[{{1025158016.000000, 238537216.000000, -202988352.000000},{
      1015920064.000000, 238429872.000000, -220160000.000000}}],
    Line[{{1015920064.000000, 238429872.000000, -220160000.000000},{
      1005861120.000000, 238171504.000000, -237222816.000000}}],
    Line[{{1005861120.000000, 238171504.000000, -237222816.000000},{
      994946240.000000, 237757728.000000, -254161328.000000}}],
    Line[{{994946240.000000, 237757728.000000, -254161328.000000},{
      983135488.000000, 237183456.000000, -270957408.000000}}],
    Line[{{983135488.000000, 237183456.000000, -270957408.000000},{
      970381504.000000, 236443568.000000, -287589888.000000}}],
    Line[{{970381504.000000, 236443568.000000, -287589888.000000},{
      956631296.000000, 235531712.000000, -304033248.000000}}],
    Line[{{956631296.000000, 235531712.000000, -304033248.000000},{
      941825216.000000, 234440512.000000, -320256896.000000}}],
    Line[{{941825216.000000, 234440512.000000, -320256896.000000},{
      925891584.000000, 233162896.000000, -336223296.000000}}],
    Line[{{925891584.000000, 233162896.000000, -336223296.000000},{
      908749696.000000, 231690176.000000, -351886592.000000}}],
    Line[{{908749696.000000, 231690176.000000, -351886592.000000},{
      890308800.000000, 230011632.000000, -367190720.000000}}],
    Line[{{890308800.000000, 230011632.000000, -367190720.000000},{
      870457728.000000, 228118048.000000, -382062912.000000}}],
    Line[{{870457728.000000, 228118048.000000, -382062912.000000},{
      849071104.000000, 225997408.000000, -396412480.000000}}],
    Line[{{849071104.000000, 225997408.000000, -396412480.000000},{
      826000704.000000, 223638352.000000, -410119552.000000}}],
    Line[{{826000704.000000, 223638352.000000, -410119552.000000},{
      801075584.000000, 221028112.000000, -423028032.000000}}],
    Line[{{801075584.000000, 221028112.000000, -423028032.000000},{
      774098816.000000, 218153504.000000, -434929664.000000}}],
    Line[{{774098816.000000, 218153504.000000, -434929664.000000},{
      744844992.000000, 215004064.000000, -445537152.000000}}],
    Line[{{744844992.000000, 215004064.000000, -445537152.000000},{
      713075712.000000, 211572416.000000, -454450208.000000}}],
    Line[{{713075712.000000, 211572416.000000, -454450208.000000},{
      678557120.000000, 207852496.000000, -461122816.000000}}],
    Line[{{678557120.000000, 207852496.000000, -461122816.000000},{
      641139264.000000, 203846736.000000, -464787072.000000}}],
    Line[{{641139264.000000, 203846736.000000, -464787072.000000},{
      600894208.000000, 199554448.000000, -464440384.000000}}],
    Line[{{600894208.000000, 199554448.000000, -464440384.000000},{
      558356224.000000, 194943120.000000, -458939936.000000}}],
    Line[{{558356224.000000, 194943120.000000, -458939936.000000},{
      514732736.000000, 189859296.000000, -447423648.000000}}],
    Line[{{514732736.000000, 189859296.000000, -447423648.000000},{
      471591776.000000, 183869520.000000, -430059456.000000}}],
    Line[{{471591776.000000, 183869520.000000, -430059456.000000},{
      429554208.000000, 176098208.000000, -408352512.000000}}],
    Line[{{429554208.000000, 176098208.000000, -408352512.000000},{
      386658016.000000, 165107712.000000, -383959168.000000}}],
    Line[{{386658016.000000, 165107712.000000, -383959168.000000},{
      336865632.000000, 148316128.000000, -356278144.000000}}],
    Line[{{336865632.000000, 148316128.000000, -356278144.000000},{
      262533696.000000, 118145576.000000, -315985728.000000}}],
    Line[{{459619392.000000, 0.000000, 459619392.000000},{
      513349696.000000, 18977294.000000, 477467872.000000}}],
    Line[{{513349696.000000, 18977294.000000, 477467872.000000},{
      563206464.000000, 36247928.000000, 484045056.000000}}],
    Line[{{563206464.000000, 36247928.000000, 484045056.000000},{
      607814848.000000, 51090380.000000, 483230272.000000}}],
    Line[{{607814848.000000, 51090380.000000, 483230272.000000},{
      647440960.000000, 63849316.000000, 477819136.000000}}],
    Line[{{647440960.000000, 63849316.000000, 477819136.000000},{
      682775552.000000, 74980960.000000, 469456032.000000}}],
    Line[{{682775552.000000, 74980960.000000, 469456032.000000},{
      714486592.000000, 84847264.000000, 459101888.000000}}],
    Line[{{714486592.000000, 84847264.000000, 459101888.000000},{
      743125824.000000, 93711104.000000, 447343200.000000}}],
    Line[{{743125824.000000, 93711104.000000, 447343200.000000},{
      769131968.000000, 101762696.000000, 434557152.000000}}],
    Line[{{769131968.000000, 101762696.000000, 434557152.000000},{
      792852544.000000, 109141136.000000, 420996896.000000}}],
    Line[{{792852544.000000, 109141136.000000, 420996896.000000},{
      814565056.000000, 115950760.000000, 406839712.000000}}],
    Line[{{814565056.000000, 115950760.000000, 406839712.000000},{
      834493440.000000, 122271264.000000, 392213536.000000}}],
    Line[{{834493440.000000, 122271264.000000, 392213536.000000},{
      852820544.000000, 128165088.000000, 377213568.000000}}],
    Line[{{852820544.000000, 128165088.000000, 377213568.000000},{
      869697728.000000, 133682032.000000, 361912224.000000}}],
    Line[{{869697728.000000, 133682032.000000, 361912224.000000},{
      885251200.000000, 138862272.000000, 346365568.000000}}],
    Line[{{885251200.000000, 138862272.000000, 346365568.000000},{
      899587264.000000, 143738752.000000, 330617792.000000}}],
    Line[{{899587264.000000, 143738752.000000, 330617792.000000},{
      912796224.000000, 148338832.000000, 314704320.000000}}],
    Line[{{912796224.000000, 148338832.000000, 314704320.000000},{
      924955136.000000, 152685280.000000, 298653856.000000}}],
    Line[{{924955136.000000, 152685280.000000, 298653856.000000},{
      936130816.000000, 156797952.000000, 282489824.000000}}],
    Line[{{936130816.000000, 156797952.000000, 282489824.000000},{
      946380608.000000, 160693216.000000, 266231728.000000}}],
    Line[{{946380608.000000, 160693216.000000, 266231728.000000},{
      955754240.000000, 164385360.000000, 249895904.000000}}],
    Line[{{955754240.000000, 164385360.000000, 249895904.000000},{
      964295488.000000, 167886896.000000, 233496000.000000}}],
    Line[{{964295488.000000, 167886896.000000, 233496000.000000},{
      972041984.000000, 171208448.000000, 217043792.000000}}],
    Line[{{972041984.000000, 171208448.000000, 217043792.000000},{
      979027008.000000, 174359392.000000, 200549296.000000}}],
    Line[{{979027008.000000, 174359392.000000, 200549296.000000},{
      985279488.000000, 177347984.000000, 184021232.000000}}],
    Line[{{985279488.000000, 177347984.000000, 184021232.000000},{
      990824704.000000, 180181376.000000, 167467200.000000}}],
    Line[{{990824704.000000, 180181376.000000, 167467200.000000},{
      995684544.000000, 182865824.000000, 150894000.000000}}],
    Line[{{995684544.000000, 182865824.000000, 150894000.000000},{
      999878080.000000, 185406944.000000, 134307600.000000}}],
    Line[{{999878080.000000, 185406944.000000, 134307600.000000},{
      1003421952.000000, 187809792.000000, 117713232.000000}}],
    Line[{{1003421952.000000, 187809792.000000, 117713232.000000},{
      1006329664.000000, 190078272.000000, 101116168.000000}}],
    Line[{{1006329664.000000, 190078272.000000, 101116168.000000},{
      1008613504.000000, 192216512.000000, 84520600.000000}}],
    Line[{{1008613504.000000, 192216512.000000, 84520600.000000},{
      1010282560.000000, 194227424.000000, 67931128.000000}}],
    Line[{{1010282560.000000, 194227424.000000, 67931128.000000},{
      1011344960.000000, 196114064.000000, 51351580.000000}}],
    Line[{{1011344960.000000, 196114064.000000, 51351580.000000},{
      1011806272.000000, 197878640.000000, 34786060.000000}}],
    Line[{{1011806272.000000, 197878640.000000, 34786060.000000},{
      1011670528.000000, 199523200.000000, 18238366.000000}}],
    Line[{{1011670528.000000, 199523200.000000, 18238366.000000},{
      1010940096.000000, 201049376.000000, 1712383.250000}}],
    Line[{{1010940096.000000, 201049376.000000, 1712383.250000},{
      1009615488.000000, 202458416.000000, -14787922.000000}}],
    Line[{{1009615488.000000, 202458416.000000, -14787922.000000},{
      1007695552.000000, 203751312.000000, -31258550.000000}}],
    Line[{{1007695552.000000, 203751312.000000, -31258550.000000},{
      1005177408.000000, 204928672.000000, -47695208.000000}}],
    Line[{{1005177408.000000, 204928672.000000, -47695208.000000},{
      1002056576.000000, 205990832.000000, -64093440.000000}}],
    Line[{{1002056576.000000, 205990832.000000, -64093440.000000},{
      998326400.000000, 206937808.000000, -80448384.000000}}],
    Line[{{998326400.000000, 206937808.000000, -80448384.000000},{
      993978752.000000, 207769280.000000, -96754784.000000}}],
    Line[{{993978752.000000, 207769280.000000, -96754784.000000},{
      989003456.000000, 208484688.000000, -113006888.000000}}],
    Line[{{989003456.000000, 208484688.000000, -113006888.000000},{
      983388288.000000, 209083120.000000, -129198320.000000}}],
    Line[{{983388288.000000, 209083120.000000, -129198320.000000},{
      977118144.000000, 209563376.000000, -145322016.000000}}],
    Line[{{977118144.000000, 209563376.000000, -145322016.000000},{
      970176448.000000, 209923744.000000, -161369712.000000}}],
    Line[{{970176448.000000, 209923744.000000, -161369712.000000},{
      962543296.000000, 210162272.000000, -177332208.000000}}],
    Line[{{962543296.000000, 210162272.000000, -177332208.000000},{
      954195968.000000, 210277024.000000, -193199488.000000}}],
    Line[{{954195968.000000, 210277024.000000, -193199488.000000},{
      945108672.000000, 210264960.000000, -208959040.000000}}],
    Line[{{945108672.000000, 210264960.000000, -208959040.000000},{
      935252096.000000, 210122944.000000, -224596880.000000}}],
    Line[{{935252096.000000, 210122944.000000, -224596880.000000},{
      924591744.000000, 209847840.000000, -240096880.000000}}],
    Line[{{924591744.000000, 209847840.000000, -240096880.000000},{
      913089664.000000, 209435424.000000, -255439696.000000}}],
    Line[{{913089664.000000, 209435424.000000, -255439696.000000},{
      900702784.000000, 208880896.000000, -270602528.000000}}],
    Line[{{900702784.000000, 208880896.000000, -270602528.000000},{
      887380096.000000, 208179744.000000, -285557952.000000}}],
    Line[{{887380096.000000, 208179744.000000, -285557952.000000},{
      873064064.000000, 207326432.000000, -300272992.000000}}],
    Line[{{873064064.000000, 207326432.000000, -300272992.000000},{
      857691712.000000, 206313888.000000, -314708192.000000}}],
    Line[{{857691712.000000, 206313888.000000, -314708192.000000},{
      841187008.000000, 205135824.000000, -328813760.000000}}],
    Line[{{841187008.000000, 205135824.000000, -328813760.000000},{
      823463360.000000, 203784944.000000, -342528416.000000}}],
    Line[{{823463360.000000, 203784944.000000, -342528416.000000},{
      804422656.000000, 202252720.000000, -355775680.000000}}],
    Line[{{804422656.000000, 202252720.000000, -355775680.000000},{
      783950400.000000, 200531792.000000, -368454784.000000}}],
    Line[{{783950400.000000, 200531792.000000, -368454784.000000},{
      761918592.000000, 198611360.000000, -380442592.000000}}],
    Line[{{761918592.000000, 198611360.000000, -380442592.000000},{
      738179648.000000, 196483984.000000, -391569056.000000}}],
    Line[{{738179648.000000, 196483984.000000, -391569056.000000},{
      712571648.000000, 194140224.000000, -401615552.000000}}],
    Line[{{712571648.000000, 194140224.000000, -401615552.000000},{
      684925696.000000, 191573488.000000, -410282464.000000}}],
    Line[{{684925696.000000, 191573488.000000, -410282464.000000},{
      655079744.000000, 188776288.000000, -417175424.000000}}],
    Line[{{655079744.000000, 188776288.000000, -417175424.000000},{
      622926080.000000, 185744096.000000, -421759648.000000}}],
    Line[{{622926080.000000, 185744096.000000, -421759648.000000},{
      588485184.000000, 182468144.000000, -423353792.000000}}],
    Line[{{588485184.000000, 182468144.000000, -423353792.000000},{
      552037696.000000, 178921120.000000, -421166816.000000}}],
    Line[{{552037696.000000, 178921120.000000, -421166816.000000},{
      514261472.000000, 175019200.000000, -414483168.000000}}],
    Line[{{514261472.000000, 175019200.000000, -414483168.000000},{
      476199296.000000, 170547424.000000, -403052864.000000}}],
    Line[{{476199296.000000, 170547424.000000, -403052864.000000},{
      438757120.000000, 165067008.000000, -387475168.000000}}],
    Line[{{438757120.000000, 165067008.000000, -387475168.000000},{
      401736960.000000, 157837536.000000, -369020448.000000}}],
    Line[{{401736960.000000, 157837536.000000, -369020448.000000},{
      362921504.000000, 147694288.000000, -348612256.000000}}],
    Line[{{362921504.000000, 147694288.000000, -348612256.000000},{
      316798944.000000, 132439016.000000, -325176608.000000}}],
    Line[{{316798944.000000, 132439016.000000, -325176608.000000},{
      247119424.000000, 105368352.000000, -289988960.000000}}],
    Line[{{459619392.000000, 0.000000, 459619392.000000},{
      523880192.000000, 11465825.000000, 467875328.000000}}],
    Line[{{523880192.000000, 11465825.000000, 467875328.000000},{
      575317376.000000, 22157536.000000, 467742336.000000}}],
    Line[{{575317376.000000, 22157536.000000, 467742336.000000},{
      618350080.000000, 32058354.000000, 462850560.000000}}],
    Line[{{618350080.000000, 32058354.000000, 462850560.000000},{
      655318080.000000, 41244776.000000, 454957216.000000}}],
    Line[{{655318080.000000, 41244776.000000, 454957216.000000},{
      687637696.000000, 49803460.000000, 445040352.000000}}],
    Line[{{687637696.000000, 49803460.000000, 445040352.000000},{
      716242560.000000, 57812268.000000, 433695744.000000}}],
    Line[{{716242560.000000, 57812268.000000, 433695744.000000},{
      741785600.000000, 65337216.000000, 421310208.000000}}],
    Line[{{741785600.000000, 65337216.000000, 421310208.000000},{
      764744256.000000, 72433432.000000, 408147264.000000}}],
    Line[{{764744256.000000, 72433432.000000, 408147264.000000},{
      785479936.000000, 79147008.000000, 394393216.000000}}],
    Line[{{785479936.000000, 79147008.000000, 394393216.000000},{
      804272832.000000, 85516320.000000, 380183744.000000}}],
    Line[{{804272832.000000, 85516320.000000, 380183744.000000},{
      821345472.000000, 91573752.000000, 365620256.000000}}],
    Line[{{821345472.000000, 91573752.000000, 365620256.000000},{
      836877824.000000, 97346848.000000, 350780032.000000}}],
    Line[{{836877824.000000, 97346848.000000, 350780032.000000},{
      851017344.000000, 102859064.000000, 335723040.000000}}],
    Line[{{851017344.000000, 102859064.000000, 335723040.000000},{
      863886464.000000, 108130592.000000, 320496640.000000}}],
    Line[{{863886464.000000, 108130592.000000, 320496640.000000},{
      875588032.000000, 113178888.000000, 305138656.000000}}],
    Line[{{875588032.000000, 113178888.000000, 305138656.000000},{
      886209088.000000, 118019144.000000, 289679744.000000}}],
    Line[{{886209088.000000, 118019144.000000, 289679744.000000},{
      895823936.000000, 122664648.000000, 274144960.000000}}],
    Line[{{895823936.000000, 122664648.000000, 274144960.000000},{
      904496128.000000, 127126960.000000, 258555264.000000}}],
    Line[{{904496128.000000, 127126960.000000, 258555264.000000},{
      912281216.000000, 131416624.000000, 242927840.000000}}],
    Line[{{912281216.000000, 131416624.000000, 242927840.000000},{
      919226560.000000, 135542496.000000, 227277648.000000}}],
    Line[{{919226560.000000, 135542496.000000, 227277648.000000},{
      925374016.000000, 139512832.000000, 211617168.000000}}],
    Line[{{925374016.000000, 139512832.000000, 211617168.000000},{
      930759744.000000, 143334816.000000, 195957328.000000}}],
    Line[{{930759744.000000, 143334816.000000, 195957328.000000},{
      935415232.000000, 147014784.000000, 180307792.000000}}],
    Line[{{935415232.000000, 147014784.000000, 180307792.000000},{
      939368320.000000, 150558560.000000, 164676912.000000}}],
    Line[{{939368320.000000, 150558560.000000, 164676912.000000},{
      942642944.000000, 153971216.000000, 149072384.000000}}],
    Line[{{942642944.000000, 153971216.000000, 149072384.000000},{
      945260096.000000, 157257312.000000, 133501128.000000}}],
    Line[{{945260096.000000, 157257312.000000, 133501128.000000},{
      947238016.000000, 160420976.000000, 117969552.000000}}],
    Line[{{947238016.000000, 160420976.000000, 117969552.000000},{
      948592192.000000, 163465696.000000, 102483832.000000}}],
    Line[{{948592192.000000, 163465696.000000, 102483832.000000},{
      949336192.000000, 166394928.000000, 87049520.000000}}],
    Line[{{949336192.000000, 166394928.000000, 87049520.000000},{
      949481152.000000, 169211424.000000, 71672320.000000}}],
    Line[{{949481152.000000, 169211424.000000, 71672320.000000},{
      949036352.000000, 171917664.000000, 56357816.000000}}],
    Line[{{949036352.000000, 171917664.000000, 56357816.000000},{
      948009408.000000, 174515984.000000, 41111356.000000}}],
    Line[{{948009408.000000, 174515984.000000, 41111356.000000},{
      946405888.000000, 177008144.000000, 25938828.000000}}],
    Line[{{946405888.000000, 177008144.000000, 25938828.000000},{
      944230144.000000, 179395888.000000, 10845808.000000}}],
    Line[{{944230144.000000, 179395888.000000, 10845808.000000},{
      941484544.000000, 181680512.000000, -4161461.000000}}],
    Line[{{941484544.000000, 181680512.000000, -4161461.000000},{
      938170240.000000, 183863136.000000, -19076636.000000}}],
    Line[{{938170240.000000, 183863136.000000, -19076636.000000},{
      934286784.000000, 185944640.000000, -33892864.000000}}],
    Line[{{934286784.000000, 185944640.000000, -33892864.000000},{
      929832192.000000, 187925584.000000, -48602676.000000}}],
    Line[{{929832192.000000, 187925584.000000, -48602676.000000},{
      924803264.000000, 189806400.000000, -63198140.000000}}],
    Line[{{924803264.000000, 189806400.000000, -63198140.000000},{
      919194944.000000, 191587168.000000, -77670368.000000}}],
    Line[{{919194944.000000, 191587168.000000, -77670368.000000},{
      913001152.000000, 193267824.000000, -92009760.000000}}],
    Line[{{913001152.000000, 193267824.000000, -92009760.000000},{
      906214080.000000, 194847984.000000, -106205568.000000}}],
    Line[{{906214080.000000, 194847984.000000, -106205568.000000},{
      898824064.000000, 196327120.000000, -120245656.000000}}],
    Line[{{898824064.000000, 196327120.000000, -120245656.000000},{
      890820736.000000, 197704256.000000, -134116936.000000}}],
    Line[{{890820736.000000, 197704256.000000, -134116936.000000},{
      882191616.000000, 198978240.000000, -147804512.000000}}],
    Line[{{882191616.000000, 198978240.000000, -147804512.000000},{
      872922432.000000, 200147792.000000, -161291088.000000}}],
    Line[{{872922432.000000, 200147792.000000, -161291088.000000},{
      862997440.000000, 201211088.000000, -174557600.000000}}],
    Line[{{862997440.000000, 201211088.000000, -174557600.000000},{
      852399232.000000, 202165824.000000, -187582496.000000}}],
    Line[{{852399232.000000, 202165824.000000, -187582496.000000},{
      841108864.000000, 203009616.000000, -200340720.000000}}],
    Line[{{841108864.000000, 203009616.000000, -200340720.000000},{
      829105920.000000, 203739728.000000, -212803600.000000}}],
    Line[{{829105920.000000, 203739728.000000, -212803600.000000},{
      816367872.000000, 204352384.000000, -224939120.000000}}],
    Line[{{816367872.000000, 204352384.000000, -224939120.000000},{
      802871232.000000, 204843488.000000, -236710128.000000}}],
    Line[{{802871232.000000, 204843488.000000, -236710128.000000},{
      788592576.000000, 205208512.000000, -248071952.000000}}],
    Line[{{788592576.000000, 205208512.000000, -248071952.000000},{
      773506432.000000, 205441712.000000, -258976032.000000}}],
    Line[{{773506432.000000, 205441712.000000, -258976032.000000},{
      757587584.000000, 205536384.000000, -269366272.000000}}],
    Line[{{757587584.000000, 205536384.000000, -269366272.000000},{
      740814272.000000, 205484368.000000, -279175904.000000}}],
    Line[{{740814272.000000, 205484368.000000, -279175904.000000},{
      723166080.000000, 205276032.000000, -288330080.000000}}],
    Line[{{723166080.000000, 205276032.000000, -288330080.000000},{
      704629120.000000, 204899056.000000, -296743712.000000}}],
    Line[{{704629120.000000, 204899056.000000, -296743712.000000},{
      685196096.000000, 204338832.000000, -304321696.000000}}],
    Line[{{685196096.000000, 204338832.000000, -304321696.000000},{
      664873856.000000, 203575744.000000, -310959456.000000}}],
    Line[{{664873856.000000, 203575744.000000, -310959456.000000},{
      643681920.000000, 202586144.000000, -316545760.000000}}],
    Line[{{643681920.000000, 202586144.000000, -316545760.000000},{
      621662720.000000, 201337584.000000, -320968736.000000}}],
    Line[{{621662720.000000, 201337584.000000, -320968736.000000},{
      598878080.000000, 199789776.000000, -324121664.000000}}],
    Line[{{598878080.000000, 199789776.000000, -324121664.000000},{
      575411968.000000, 197887808.000000, -325919328.000000}}],
    Line[{{575411968.000000, 197887808.000000, -325919328.000000},{
      551359168.000000, 195560496.000000, -326310112.000000}}],
    Line[{{551359168.000000, 195560496.000000, -326310112.000000},{
      526804512.000000, 192713088.000000, -325294304.000000}}],
    Line[{{526804512.000000, 192713088.000000, -325294304.000000},{
      501786528.000000, 189221248.000000, -322931232.000000}}],
    Line[{{501786528.000000, 189221248.000000, -322931232.000000},{
      476238400.000000, 184917568.000000, -319338304.000000}}],
    Line[{{476238400.000000, 184917568.000000, -319338304.000000},{
      449904832.000000, 179570960.000000, -314662240.000000}}],
    Line[{{449904832.000000, 179570960.000000, -314662240.000000},{
      422223328.000000, 172845872.000000, -309017856.000000}}],
    Line[{{422223328.000000, 172845872.000000, -309017856.000000},{
      392104000.000000, 164210000.000000, -302369920.000000}}],
    Line[{{392104000.000000, 164210000.000000, -302369920.000000},{
      357431072.000000, 152707856.000000, -294267904.000000}}],
    Line[{{357431072.000000, 152707856.000000, -294267904.000000},{
      313498528.000000, 136249568.000000, -283004256.000000}}],
    Line[{{313498528.000000, 136249568.000000, -283004256.000000},{
      245132784.000000, 108069880.000000, -260790320.000000}}],
    Line[{{459619392.000000, 0.000000, 459619392.000000},{
      514804512.000000, -16097511.000000, 477488896.000000}}],
    Line[{{514804512.000000, -16097511.000000, 477488896.000000},{
      565742272.000000, -30289558.000000, 483451168.000000}}],
    Line[{{565742272.000000, -30289558.000000, 483451168.000000},{
      610923648.000000, -42232912.000000, 481969792.000000}}],
    Line[{{610923648.000000, -42232912.000000, 481969792.000000},{
      650821184.000000, -52375424.000000, 476015136.000000}}],
    Line[{{650821184.000000, -52375424.000000, 476015136.000000},{
      686274624.000000, -61161148.000000, 467243872.000000}}],
    Line[{{686274624.000000, -61161148.000000, 467243872.000000},{
      718032064.000000, -68913824.000000, 456593824.000000}}],
    Line[{{718032064.000000, -68913824.000000, 456593824.000000},{
      746686592.000000, -75858728.000000, 444626272.000000}}],
    Line[{{746686592.000000, -75858728.000000, 444626272.000000},{
      772698176.000000, -82154848.000000, 431697984.000000}}],
    Line[{{772698176.000000, -82154848.000000, 431697984.000000},{
      796425344.000000, -87916496.000000, 418046688.000000}}],
    Line[{{796425344.000000, -87916496.000000, 418046688.000000},{
      818150976.000000, -93228304.000000, 403837920.000000}}],
    Line[{{818150976.000000, -93228304.000000, 403837920.000000},{
      838101760.000000, -98154616.000000, 389191072.000000}}],
    Line[{{838101760.000000, -98154616.000000, 389191072.000000},{
      856461760.000000, -102745408.000000, 374194688.000000}}],
    Line[{{856461760.000000, -102745408.000000, 374194688.000000},{
      873382592.000000, -107040336.000000, 358916128.000000}}],
    Line[{{873382592.000000, -107040336.000000, 358916128.000000},{
      888990144.000000, -111071264.000000, 343407520.000000}}],
    Line[{{888990144.000000, -111071264.000000, 343407520.000000},{
      903390464.000000, -114864264.000000, 327709952.000000}}],
    Line[{{903390464.000000, -114864264.000000, 327709952.000000},{
      916673280.000000, -118440936.000000, 311856352.000000}}],
    Line[{{916673280.000000, -118440936.000000, 311856352.000000},{
      928915072.000000, -121819200.000000, 295873440.000000}}],
    Line[{{928915072.000000, -121819200.000000, 295873440.000000},{
      940182016.000000, -125014608.000000, 279783072.000000}}],
    Line[{{940182016.000000, -125014608.000000, 279783072.000000},{
      950531136.000000, -128040192.000000, 263603328.000000}}],
    Line[{{950531136.000000, -128040192.000000, 263603328.000000},{
      960011520.000000, -130906960.000000, 247349488.000000}}],
    Line[{{960011520.000000, -130906960.000000, 247349488.000000},{
      968666368.000000, -133624776.000000, 231034288.000000}}],
    Line[{{968666368.000000, -133624776.000000, 231034288.000000},{
      976533120.000000, -136202016.000000, 214668608.000000}}],
    Line[{{976533120.000000, -136202016.000000, 214668608.000000},{
      983644480.000000, -138645920.000000, 198261904.000000}}],
    Line[{{983644480.000000, -138645920.000000, 198261904.000000},{
      990029184.000000, -140962960.000000, 181822240.000000}}],
    Line[{{990029184.000000, -140962960.000000, 181822240.000000},{
      995712128.000000, -143158768.000000, 165356688.000000}}],
    Line[{{995712128.000000, -143158768.000000, 165356688.000000},{
      1000714816.000000, -145238144.000000, 148871696.000000}}],
    Line[{{1000714816.000000, -145238144.000000, 148871696.000000},{
      1005056384.000000, -147205632.000000, 132372568.000000}}],
    Line[{{1005056384.000000, -147205632.000000, 132372568.000000},{
      1008752896.000000, -149064880.000000, 115864512.000000}}],
    Line[{{1008752896.000000, -149064880.000000, 115864512.000000},{
      1011818048.000000, -150819264.000000, 99352072.000000}}],
    Line[{{1011818048.000000, -150819264.000000, 99352072.000000},{
      1014263552.000000, -152471776.000000, 82839368.000000}}],
    Line[{{1014263552.000000, -152471776.000000, 82839368.000000},{
      1016098688.000000, -154024768.000000, 66330564.000000}}],
    Line[{{1016098688.000000, -154024768.000000, 66330564.000000},{
      1017331328.000000, -155480576.000000, 49829200.000000}}],
    Line[{{1017331328.000000, -155480576.000000, 49829200.000000},{
      1017966848.000000, -156840896.000000, 33339122.000000}}],
    Line[{{1017966848.000000, -156840896.000000, 33339122.000000},{
      1018009408.000000, -158107408.000000, 16863722.000000}}],
    Line[{{1018009408.000000, -158107408.000000, 16863722.000000},{
      1017461056.000000, -159281248.000000, 406682.281250}}],
    Line[{{1017461056.000000, -159281248.000000, 406682.281250},{
      1016322432.000000, -160363488.000000, -16028472.000000}}],
    Line[{{1016322432.000000, -160363488.000000, -16028472.000000},{
      1014592320.000000, -161354816.000000, -32437992.000000}}],
    Line[{{1014592320.000000, -161354816.000000, -32437992.000000},{
      1012267776.000000, -162255744.000000, -48818012.000000}}],
    Line[{{1012267776.000000, -162255744.000000, -48818012.000000},{
      1009344256.000000, -163066496.000000, -65164436.000000}}],
    Line[{{1009344256.000000, -163066496.000000, -65164436.000000},{
      1005815040.000000, -163787040.000000, -81472808.000000}}],
    Line[{{1005815040.000000, -163787040.000000, -81472808.000000},{
      1001672192.000000, -164417168.000000, -97738368.000000}}],
    Line[{{1001672192.000000, -164417168.000000, -97738368.000000},{
      996905536.000000, -164956384.000000, -113955840.000000}}],
    Line[{{996905536.000000, -164956384.000000, -113955840.000000},{
      991502336.000000, -165404000.000000, -130119520.000000}}],
    Line[{{991502336.000000, -165404000.000000, -130119520.000000},{
      985448256.000000, -165758992.000000, -146222784.000000}}],
    Line[{{985448256.000000, -165758992.000000, -146222784.000000},{
      978726080.000000, -166020000.000000, -162258096.000000}}],
    Line[{{978726080.000000, -166020000.000000, -162258096.000000},{
      971316224.000000, -166185664.000000, -178217392.000000}}],
    Line[{{971316224.000000, -166185664.000000, -178217392.000000},{
      963195840.000000, -166254176.000000, -194091168.000000}}],
    Line[{{963195840.000000, -166254176.000000, -194091168.000000},{
      954339136.000000, -166223216.000000, -209868048.000000}}],
    Line[{{954339136.000000, -166223216.000000, -209868048.000000},{
      944716224.000000, -166090464.000000, -225535440.000000}}],
    Line[{{944716224.000000, -166090464.000000, -225535440.000000},{
      934292864.000000, -165853296.000000, -241078608.000000}}],
    Line[{{934292864.000000, -165853296.000000, -241078608.000000},{
      923031168.000000, -165508240.000000, -256479648.000000}}],
    Line[{{923031168.000000, -165508240.000000, -256479648.000000},{
      910886784.000000, -165051776.000000, -271717760.000000}}],
    Line[{{910886784.000000, -165051776.000000, -271717760.000000},{
      897807488.000000, -164480448.000000, -286768000.000000}}],
    Line[{{897807488.000000, -164480448.000000, -286768000.000000},{
      883737408.000000, -163789136.000000, -301600160.000000}}],
    Line[{{883737408.000000, -163789136.000000, -301600160.000000},{
      868610048.000000, -162972896.000000, -316177600.000000}}],
    Line[{{868610048.000000, -162972896.000000, -316177600.000000},{
      852346368.000000, -162027024.000000, -330454464.000000}}],
    Line[{{852346368.000000, -162027024.000000, -330454464.000000},{
      834859264.000000, -160944896.000000, -344374816.000000}}],
    Line[{{834859264.000000, -160944896.000000, -344374816.000000},{
      816043968.000000, -159721008.000000, -357865920.000000}}],
    Line[{{816043968.000000, -159721008.000000, -357865920.000000},{
      795781312.000000, -158348128.000000, -370836832.000000}}],
    Line[{{795781312.000000, -158348128.000000, -370836832.000000},{
      773932864.000000, -156818992.000000, -383168992.000000}}],
    Line[{{773932864.000000, -156818992.000000, -383168992.000000},{
      750335360.000000, -155127744.000000, -394702592.000000}}],
    Line[{{750335360.000000, -155127744.000000, -394702592.000000},{
      724805440.000000, -153268272.000000, -405224672.000000}}],
    Line[{{724805440.000000, -153268272.000000, -405224672.000000},{
      697138688.000000, -151235968.000000, -414444896.000000}}],
    Line[{{697138688.000000, -151235968.000000, -414444896.000000},{
      667123136.000000, -149028848.000000, -421961376.000000}}],
    Line[{{667123136.000000, -149028848.000000, -421961376.000000},{
      634576128.000000, -146649264.000000, -427214176.000000}}],
    Line[{{634576128.000000, -146649264.000000, -427214176.000000},{
      599424128.000000, -144101984.000000, -429445504.000000}}],
    Line[{{599424128.000000, -144101984.000000, -429445504.000000},{
      561860992.000000, -141385600.000000, -427700480.000000}}],
    Line[{{561860992.000000, -141385600.000000, -427700480.000000},{
      522574112.000000, -138461152.000000, -420994176.000000}}],
    Line[{{522574112.000000, -138461152.000000, -420994176.000000},{
      482840704.000000, -135178560.000000, -408801376.000000}}],
    Line[{{482840704.000000, -135178560.000000, -408801376.000000},{
      444012608.000000, -131169296.000000, -391714240.000000}}],
    Line[{{444012608.000000, -131169296.000000, -391714240.000000},{
      406208800.000000, -125774136.000000, -371398560.000000}}],
    Line[{{406208800.000000, -125774136.000000, -371398560.000000},{
      367114208.000000, -117986528.000000, -349269952.000000}}],
    Line[{{367114208.000000, -117986528.000000, -349269952.000000},{
      320845248.000000, -106009736.000000, -324497760.000000}}],
    Line[{{320845248.000000, -106009736.000000, -324497760.000000},{
      250645664.000000, -84465552.000000, -288383776.000000}}],
    Polygon[{{0.000000, 0.000000, 640000000.000000},{
      0.000000, 105340536.000000, 631271232.000000},{
      34204016.000000, 99632896.000000, 631271232.000000},{
      0.000000, 0.000000, 640000000.000000}}],
    Polygon[{{0.000000, 105340536.000000, 631271232.000000},{
      0.000000, 207807664.000000, 605323008.000000},{
      67475040.000000, 196548064.000000, 605323008.000000},{
      34204016.000000, 99632896.000000, 631271232.000000}}],
    Polygon[{{0.000000, 207807664.000000, 605323008.000000},{
      0.000000, 304606336.000000, 562863232.000000},{
      98905512.000000, 288101920.000000, 562863232.000000},{
      67475040.000000, 196548064.000000, 605323008.000000}}],
    Polygon[{{0.000000, 304606336.000000, 562863232.000000},{
      0.000000, 393096128.000000, 505049920.000000},{
      127638104.000000, 371797088.000000, 505049920.000000},{
      98905512.000000, 288101920.000000, 562863232.000000}}],
    Polygon[{{0.000000, 393096128.000000, 505049920.000000},{
      0.000000, 470863296.000000, 433460192.000000},{
      152889072.000000, 445350624.000000, 433460192.000000},{
      127638104.000000, 371797088.000000, 505049920.000000}}],
    Polygon[{{0.000000, 470863296.000000, 433460192.000000},{
      0.000000, 535786560.000000, 350046816.000000},{
      173969600.000000, 506756160.000000, 350046816.000000},{
      152889072.000000, 445350624.000000, 433460192.000000}}],
    Polygon[{{0.000000, 535786560.000000, 350046816.000000},{
      0.000000, 586094912.000000, 257085072.000000},{
      190304720.000000, 554338688.000000, 257085072.000000},{
      173969600.000000, 506756160.000000, 350046816.000000}}],
    Polygon[{{0.000000, 586094912.000000, 257085072.000000},{
      0.000000, 620416192.000000, 157110704.000000},{
      201448800.000000, 586800320.000000, 157110704.000000},{
      190304720.000000, 554338688.000000, 257085072.000000}}],
    Polygon[{{0.000000, 620416192.000000, 157110704.000000},{
      0.000000, 637814080.000000, 52850780.000000},{
      207097888.000000, 603255552.000000, 52850780.000000},{
      201448800.000000, 586800320.000000, 157110704.000000}}],
    Polygon[{{0.000000, 637814080.000000, 52850780.000000},{
      0.000000, 637814080.000000, -52850780.000000},{
      207097888.000000, 603255552.000000, -52850780.000000},{
      207097888.000000, 603255552.000000, 52850780.000000}}],
    Polygon[{{0.000000, 637814080.000000, -52850780.000000},{
      0.000000, 620416192.000000, -157110704.000000},{
      201448800.000000, 586800320.000000, -157110704.000000},{
      207097888.000000, 603255552.000000, -52850780.000000}}],
    Polygon[{{0.000000, 620416192.000000, -157110704.000000},{
      0.000000, 586094912.000000, -257085072.000000},{
      190304720.000000, 554338688.000000, -257085072.000000},{
      201448800.000000, 586800320.000000, -157110704.000000}}],
    Polygon[{{0.000000, 586094912.000000, -257085072.000000},{
      0.000000, 535786560.000000, -350046816.000000},{
      173969600.000000, 506756160.000000, -350046816.000000},{
      190304720.000000, 554338688.000000, -257085072.000000}}],
    Polygon[{{0.000000, 535786560.000000, -350046816.000000},{
      0.000000, 470863296.000000, -433460192.000000},{
      152889072.000000, 445350624.000000, -433460192.000000},{
      173969600.000000, 506756160.000000, -350046816.000000}}],
    Polygon[{{0.000000, 470863296.000000, -433460192.000000},{
      0.000000, 393096128.000000, -505049920.000000},{
      127638104.000000, 371797088.000000, -505049920.000000},{
      152889072.000000, 445350624.000000, -433460192.000000}}],
    Polygon[{{0.000000, 393096128.000000, -505049920.000000},{
      0.000000, 304606336.000000, -562863232.000000},{
      98905512.000000, 288101920.000000, -562863232.000000},{
      127638104.000000, 371797088.000000, -505049920.000000}}],
    Polygon[{{0.000000, 304606336.000000, -562863232.000000},{
      0.000000, 207807664.000000, -605323008.000000},{
      67475040.000000, 196548064.000000, -605323008.000000},{
      98905512.000000, 288101920.000000, -562863232.000000}}],
    Polygon[{{0.000000, 207807664.000000, -605323008.000000},{
      0.000000, 105340536.000000, -631271232.000000},{
      34204016.000000, 99632896.000000, -631271232.000000},{
      67475040.000000, 196548064.000000, -605323008.000000}}],
    Polygon[{{0.000000, 105340536.000000, -631271232.000000},{
      0.000000, 0.000000, -640000000.000000},{
      0.000000, 0.000000, -640000000.000000},{
      34204016.000000, 99632896.000000, -631271232.000000}}],
    Polygon[{{0.000000, 0.000000, 640000000.000000},{
      34204016.000000, 99632896.000000, 631271232.000000},{
      64701496.000000, 83128488.000000, 631271232.000000},{
      0.000000, 0.000000, 640000000.000000}}],
    Polygon[{{34204016.000000, 99632896.000000, 631271232.000000},{
      67475040.000000, 196548064.000000, 605323008.000000},{
      127638104.000000, 163989440.000000, 605323008.000000},{
      64701496.000000, 83128488.000000, 631271232.000000}}],
    Polygon[{{67475040.000000, 196548064.000000, 605323008.000000},{
      98905512.000000, 288101920.000000, 562863232.000000},{
      187093088.000000, 240377200.000000, 562863232.000000},{
      127638104.000000, 163989440.000000, 605323008.000000}}],
    Polygon[{{98905512.000000, 288101920.000000, 562863232.000000},{
      127638104.000000, 371797088.000000, 505049920.000000},{
      241444640.000000, 310208096.000000, 505049920.000000},{
      187093088.000000, 240377200.000000, 562863232.000000}}],
    Polygon[{{127638104.000000, 371797088.000000, 505049920.000000},{
      152889072.000000, 445350624.000000, 433460192.000000},{
      289210240.000000, 371577312.000000, 433460192.000000},{
      241444640.000000, 310208096.000000, 505049920.000000}}],
    Polygon[{{152889072.000000, 445350624.000000, 433460192.000000},{
      173969600.000000, 506756160.000000, 350046816.000000},{
      329086912.000000, 422810880.000000, 350046816.000000},{
      289210240.000000, 371577312.000000, 433460192.000000}}],
    Polygon[{{173969600.000000, 506756160.000000, 350046816.000000},{
      190304720.000000, 554338688.000000, 257085072.000000},{
      359986944.000000, 462511264.000000, 257085072.000000},{
      329086912.000000, 422810880.000000, 350046816.000000}}],
    Polygon[{{190304720.000000, 554338688.000000, 257085072.000000},{
      201448800.000000, 586800320.000000, 157110704.000000},{
      381067488.000000, 489595520.000000, 157110704.000000},{
      359986944.000000, 462511264.000000, 257085072.000000}}],
    Polygon[{{201448800.000000, 586800320.000000, 157110704.000000},{
      207097888.000000, 603255552.000000, 52850780.000000},{
      391753504.000000, 503324928.000000, 52850780.000000},{
      381067488.000000, 489595520.000000, 157110704.000000}}],
    Polygon[{{207097888.000000, 603255552.000000, 52850780.000000},{
      207097888.000000, 603255552.000000, -52850780.000000},{
      391753504.000000, 503324928.000000, -52850780.000000},{
      391753504.000000, 503324928.000000, 52850780.000000}}],
    Polygon[{{207097888.000000, 603255552.000000, -52850780.000000},{
      201448800.000000, 586800320.000000, -157110704.000000},{
      381067488.000000, 489595520.000000, -157110704.000000},{
      391753504.000000, 503324928.000000, -52850780.000000}}],
    Polygon[{{201448800.000000, 586800320.000000, -157110704.000000},{
      190304720.000000, 554338688.000000, -257085072.000000},{
      359986944.000000, 462511264.000000, -257085072.000000},{
      381067488.000000, 489595520.000000, -157110704.000000}}],
    Polygon[{{190304720.000000, 554338688.000000, -257085072.000000},{
      173969600.000000, 506756160.000000, -350046816.000000},{
      329086912.000000, 422810880.000000, -350046816.000000},{
      359986944.000000, 462511264.000000, -257085072.000000}}],
    Polygon[{{173969600.000000, 506756160.000000, -350046816.000000},{
      152889072.000000, 445350624.000000, -433460192.000000},{
      289210240.000000, 371577312.000000, -433460192.000000},{
      329086912.000000, 422810880.000000, -350046816.000000}}],
    Polygon[{{152889072.000000, 445350624.000000, -433460192.000000},{
      127638104.000000, 371797088.000000, -505049920.000000},{
      241444640.000000, 310208096.000000, -505049920.000000},{
      289210240.000000, 371577312.000000, -433460192.000000}}],
    Polygon[{{127638104.000000, 371797088.000000, -505049920.000000},{
      98905512.000000, 288101920.000000, -562863232.000000},{
      187093088.000000, 240377200.000000, -562863232.000000},{
      241444640.000000, 310208096.000000, -505049920.000000}}],
    Polygon[{{98905512.000000, 288101920.000000, -562863232.000000},{
      67475040.000000, 196548064.000000, -605323008.000000},{
      127638104.000000, 163989440.000000, -605323008.000000},{
      187093088.000000, 240377200.000000, -562863232.000000}}],
    Polygon[{{67475040.000000, 196548064.000000, -605323008.000000},{
      34204016.000000, 99632896.000000, -631271232.000000},{
      64701496.000000, 83128488.000000, -631271232.000000},{
      127638104.000000, 163989440.000000, -605323008.000000}}],
    Polygon[{{34204016.000000, 99632896.000000, -631271232.000000},{
      0.000000, 0.000000, -640000000.000000},{
      0.000000, 0.000000, -640000000.000000},{
      64701496.000000, 83128488.000000, -631271232.000000}}],
    Polygon[{{0.000000, 0.000000, 640000000.000000},{
      64701496.000000, 83128488.000000, 631271232.000000},{
      88187568.000000, 57615812.000000, 631271232.000000},{
      0.000000, 0.000000, 640000000.000000}}],
    Polygon[{{64701496.000000, 83128488.000000, 631271232.000000},{
      127638104.000000, 163989440.000000, 605323008.000000},{
      173969600.000000, 113660016.000000, 605323008.000000},{
      88187568.000000, 57615812.000000, 631271232.000000}}],
    Polygon[{{127638104.000000, 163989440.000000, 605323008.000000},{
      187093088.000000, 240377200.000000, 562863232.000000},{
      255006208.000000, 166603872.000000, 562863232.000000},{
      173969600.000000, 113660016.000000, 605323008.000000}}],
    Polygon[{{187093088.000000, 240377200.000000, 562863232.000000},{
      241444640.000000, 310208096.000000, 505049920.000000},{
      329086912.000000, 215003200.000000, 505049920.000000},{
      255006208.000000, 166603872.000000, 562863232.000000}}],
    Polygon[{{241444640.000000, 310208096.000000, 505049920.000000},{
      289210240.000000, 371577312.000000, 433460192.000000},{
      394190976.000000, 257537824.000000, 433460192.000000},{
      329086912.000000, 215003200.000000, 505049920.000000}}],
    Polygon[{{289210240.000000, 371577312.000000, 433460192.000000},{
      329086912.000000, 422810880.000000, 350046816.000000},{
      448542528.000000, 293047456.000000, 350046816.000000},{
      394190976.000000, 257537824.000000, 433460192.000000}}],
    Polygon[{{329086912.000000, 422810880.000000, 350046816.000000},{
      359986944.000000, 462511264.000000, 257085072.000000},{
      490659040.000000, 320563552.000000, 257085072.000000},{
      448542528.000000, 293047456.000000, 350046816.000000}}],
    Polygon[{{359986944.000000, 462511264.000000, 257085072.000000},{
      381067488.000000, 489595520.000000, 157110704.000000},{
      519391616.000000, 339335488.000000, 157110704.000000},{
      490659040.000000, 320563552.000000, 257085072.000000}}],
    Polygon[{{381067488.000000, 489595520.000000, 157110704.000000},{
      391753504.000000, 503324928.000000, 52850780.000000},{
      533956576.000000, 348851232.000000, 52850780.000000},{
      519391616.000000, 339335488.000000, 157110704.000000}}],
    Polygon[{{391753504.000000, 503324928.000000, 52850780.000000},{
      391753504.000000, 503324928.000000, -52850780.000000},{
      533956576.000000, 348851232.000000, -52850780.000000},{
      533956576.000000, 348851232.000000, 52850780.000000}}],
    Polygon[{{391753504.000000, 503324928.000000, -52850780.000000},{
      381067488.000000, 489595520.000000, -157110704.000000},{
      519391616.000000, 339335488.000000, -157110704.000000},{
      533956576.000000, 348851232.000000, -52850780.000000}}],
    Polygon[{{381067488.000000, 489595520.000000, -157110704.000000},{
      359986944.000000, 462511264.000000, -257085072.000000},{
      490659040.000000, 320563552.000000, -257085072.000000},{
      519391616.000000, 339335488.000000, -157110704.000000}}],
    Polygon[{{359986944.000000, 462511264.000000, -257085072.000000},{
      329086912.000000, 422810880.000000, -350046816.000000},{
      448542528.000000, 293047456.000000, -350046816.000000},{
      490659040.000000, 320563552.000000, -257085072.000000}}],
    Polygon[{{329086912.000000, 422810880.000000, -350046816.000000},{
      289210240.000000, 371577312.000000, -433460192.000000},{
      394190976.000000, 257537824.000000, -433460192.000000},{
      448542528.000000, 293047456.000000, -350046816.000000}}],
    Polygon[{{289210240.000000, 371577312.000000, -433460192.000000},{
      241444640.000000, 310208096.000000, -505049920.000000},{
      329086912.000000, 215003200.000000, -505049920.000000},{
      394190976.000000, 257537824.000000, -433460192.000000}}],
    Polygon[{{241444640.000000, 310208096.000000, -505049920.000000},{
      187093088.000000, 240377200.000000, -562863232.000000},{
      255006208.000000, 166603872.000000, -562863232.000000},{
      329086912.000000, 215003200.000000, -505049920.000000}}],
    Polygon[{{187093088.000000, 240377200.000000, -562863232.000000},{
      127638104.000000, 163989440.000000, -605323008.000000},{
      173969600.000000, 113660016.000000, -605323008.000000},{
      255006208.000000, 166603872.000000, -562863232.000000}}],
    Polygon[{{127638104.000000, 163989440.000000, -605323008.000000},{
      64701496.000000, 83128488.000000, -631271232.000000},{
      88187568.000000, 57615812.000000, -631271232.000000},{
      173969600.000000, 113660016.000000, -605323008.000000}}],
    Polygon[{{64701496.000000, 83128488.000000, -631271232.000000},{
      0.000000, 0.000000, -640000000.000000},{
      0.000000, 0.000000, -640000000.000000},{
      88187568.000000, 57615812.000000, -631271232.000000}}],
    Polygon[{{0.000000, 0.000000, 640000000.000000},{
      88187568.000000, 57615812.000000, 631271232.000000},{
      102117144.000000, 25859574.000000, 631271232.000000},{
      0.000000, 0.000000, 640000000.000000}}],
    Polygon[{{88187568.000000, 57615812.000000, 631271232.000000},{
      173969600.000000, 113660016.000000, 605323008.000000},{
      201448800.000000, 51013764.000000, 605323008.000000},{
      102117144.000000, 25859574.000000, 631271232.000000}}],
    Polygon[{{173969600.000000, 113660016.000000, 605323008.000000},{
      255006208.000000, 166603872.000000, 562863232.000000},{
      295285472.000000, 74776432.000000, 562863232.000000},{
      201448800.000000, 51013764.000000, 605323008.000000}}],
    Polygon[{{255006208.000000, 166603872.000000, 562863232.000000},{
      329086912.000000, 215003200.000000, 505049920.000000},{
      381067488.000000, 96499400.000000, 505049920.000000},{
      295285472.000000, 74776432.000000, 562863232.000000}}],
    Polygon[{{329086912.000000, 215003200.000000, 505049920.000000},{
      394190976.000000, 257537824.000000, 433460192.000000},{
      456455008.000000, 115590104.000000, 433460192.000000},{
      381067488.000000, 96499400.000000, 505049920.000000}}],
    Polygon[{{394190976.000000, 257537824.000000, 433460192.000000},{
      448542528.000000, 293047456.000000, 350046816.000000},{
      519391616.000000, 131527824.000000, 350046816.000000},{
      456455008.000000, 115590104.000000, 433460192.000000}}],
    Polygon[{{448542528.000000, 293047456.000000, 350046816.000000},{
      490659040.000000, 320563552.000000, 257085072.000000},{
      568160576.000000, 143877792.000000, 257085072.000000},{
      519391616.000000, 131527824.000000, 350046816.000000}}],
    Polygon[{{490659040.000000, 320563552.000000, 257085072.000000},{
      519391616.000000, 339335488.000000, 157110704.000000},{
      601431616.000000, 152303168.000000, 157110704.000000},{
      568160576.000000, 143877792.000000, 257085072.000000}}],
    Polygon[{{519391616.000000, 339335488.000000, 157110704.000000},{
      533956576.000000, 348851232.000000, 52850780.000000},{
      618297152.000000, 156574096.000000, 52850780.000000},{
      601431616.000000, 152303168.000000, 157110704.000000}}],
    Polygon[{{533956576.000000, 348851232.000000, 52850780.000000},{
      533956576.000000, 348851232.000000, -52850780.000000},{
      618297152.000000, 156574096.000000, -52850780.000000},{
      618297152.000000, 156574096.000000, 52850780.000000}}],
    Polygon[{{533956576.000000, 348851232.000000, -52850780.000000},{
      519391616.000000, 339335488.000000, -157110704.000000},{
      601431616.000000, 152303168.000000, -157110704.000000},{
      618297152.000000, 156574096.000000, -52850780.000000}}],
    Polygon[{{519391616.000000, 339335488.000000, -157110704.000000},{
      490659040.000000, 320563552.000000, -257085072.000000},{
      568160576.000000, 143877792.000000, -257085072.000000},{
      601431616.000000, 152303168.000000, -157110704.000000}}],
    Polygon[{{490659040.000000, 320563552.000000, -257085072.000000},{
      448542528.000000, 293047456.000000, -350046816.000000},{
      519391616.000000, 131527824.000000, -350046816.000000},{
      568160576.000000, 143877792.000000, -257085072.000000}}],
    Polygon[{{448542528.000000, 293047456.000000, -350046816.000000},{
      394190976.000000, 257537824.000000, -433460192.000000},{
      456455008.000000, 115590104.000000, -433460192.000000},{
      519391616.000000, 131527824.000000, -350046816.000000}}],
    Polygon[{{394190976.000000, 257537824.000000, -433460192.000000},{
      329086912.000000, 215003200.000000, -505049920.000000},{
      381067488.000000, 96499400.000000, -505049920.000000},{
      456455008.000000, 115590104.000000, -433460192.000000}}],
    Polygon[{{329086912.000000, 215003200.000000, -505049920.000000},{
      255006208.000000, 166603872.000000, -562863232.000000},{
      295285472.000000, 74776432.000000, -562863232.000000},{
      381067488.000000, 96499400.000000, -505049920.000000}}],
    Polygon[{{255006208.000000, 166603872.000000, -562863232.000000},{
      173969600.000000, 113660016.000000, -605323008.000000},{
      201448800.000000, 51013764.000000, -605323008.000000},{
      295285472.000000, 74776432.000000, -562863232.000000}}],
    Polygon[{{173969600.000000, 113660016.000000, -605323008.000000},{
      88187568.000000, 57615812.000000, -631271232.000000},{
      102117144.000000, 25859574.000000, -631271232.000000},{
      201448800.000000, 51013764.000000, -605323008.000000}}],
    Polygon[{{88187568.000000, 57615812.000000, -631271232.000000},{
      0.000000, 0.000000, -640000000.000000},{
      0.000000, 0.000000, -640000000.000000},{
      102117144.000000, 25859574.000000, -631271232.000000}}],
    Polygon[{{0.000000, 0.000000, 640000000.000000},{
      102117144.000000, 25859574.000000, 631271232.000000},{
      104980744.000000, -8698953.000000, 631271232.000000},{
      0.000000, 0.000000, 640000000.000000}}],
    Polygon[{{102117144.000000, 25859574.000000, 631271232.000000},{
      201448800.000000, 51013764.000000, 605323008.000000},{
      207097888.000000, -17160620.000000, 605323008.000000},{
      104980744.000000, -8698953.000000, 631271232.000000}}],
    Polygon[{{201448800.000000, 51013764.000000, 605323008.000000},{
      295285472.000000, 74776432.000000, 562863232.000000},{
      303565952.000000, -25154192.000000, 562863232.000000},{
      207097888.000000, -17160620.000000, 605323008.000000}}],
    Polygon[{{295285472.000000, 74776432.000000, 562863232.000000},{
      381067488.000000, 96499400.000000, 505049920.000000},{
      391753504.000000, -32461622.000000, 505049920.000000},{
      303565952.000000, -25154192.000000, 562863232.000000}}],
    Polygon[{{381067488.000000, 96499400.000000, 505049920.000000},{
      456455008.000000, 115590104.000000, 433460192.000000},{
      469255072.000000, -38883584.000000, 433460192.000000},{
      391753504.000000, -32461622.000000, 505049920.000000}}],
    Polygon[{{456455008.000000, 115590104.000000, 433460192.000000},{
      519391616.000000, 131527824.000000, 350046816.000000},{
      533956576.000000, -44244904.000000, 350046816.000000},{
      469255072.000000, -38883584.000000, 433460192.000000}}],
    Polygon[{{519391616.000000, 131527824.000000, 350046816.000000},{
      568160576.000000, 143877792.000000, 257085072.000000},{
      584093120.000000, -48399336.000000, 257085072.000000},{
      533956576.000000, -44244904.000000, 350046816.000000}}],
    Polygon[{{568160576.000000, 143877792.000000, 257085072.000000},{
      601431616.000000, 152303168.000000, 157110704.000000},{
      618297152.000000, -51233560.000000, 157110704.000000},{
      584093120.000000, -48399336.000000, 257085072.000000}}],
    Polygon[{{601431616.000000, 152303168.000000, 157110704.000000},{
      618297152.000000, 156574096.000000, 52850780.000000},{
      635635648.000000, -52670268.000000, 52850780.000000},{
      618297152.000000, -51233560.000000, 157110704.000000}}],
    Polygon[{{618297152.000000, 156574096.000000, 52850780.000000},{
      618297152.000000, 156574096.000000, -52850780.000000},{
      635635648.000000, -52670268.000000, -52850780.000000},{
      635635648.000000, -52670268.000000, 52850780.000000}}],
    Polygon[{{618297152.000000, 156574096.000000, -52850780.000000},{
      601431616.000000, 152303168.000000, -157110704.000000},{
      618297152.000000, -51233560.000000, -157110704.000000},{
      635635648.000000, -52670268.000000, -52850780.000000}}],
    Polygon[{{601431616.000000, 152303168.000000, -157110704.000000},{
      568160576.000000, 143877792.000000, -257085072.000000},{
      584093120.000000, -48399336.000000, -257085072.000000},{
      618297152.000000, -51233560.000000, -157110704.000000}}],
    Polygon[{{568160576.000000, 143877792.000000, -257085072.000000},{
      519391616.000000, 131527824.000000, -350046816.000000},{
      533956576.000000, -44244904.000000, -350046816.000000},{
      584093120.000000, -48399336.000000, -257085072.000000}}],
    Polygon[{{519391616.000000, 131527824.000000, -350046816.000000},{
      456455008.000000, 115590104.000000, -433460192.000000},{
      469255072.000000, -38883584.000000, -433460192.000000},{
      533956576.000000, -44244904.000000, -350046816.000000}}],
    Polygon[{{456455008.000000, 115590104.000000, -433460192.000000},{
      381067488.000000, 96499400.000000, -505049920.000000},{
      391753504.000000, -32461622.000000, -505049920.000000},{
      469255072.000000, -38883584.000000, -433460192.000000}}],
    Polygon[{{381067488.000000, 96499400.000000, -505049920.000000},{
      295285472.000000, 74776432.000000, -562863232.000000},{
      303565952.000000, -25154192.000000, -562863232.000000},{
      391753504.000000, -32461622.000000, -505049920.000000}}],
    Polygon[{{295285472.000000, 74776432.000000, -562863232.000000},{
      201448800.000000, 51013764.000000, -605323008.000000},{
      207097888.000000, -17160620.000000, -605323008.000000},{
      303565952.000000, -25154192.000000, -562863232.000000}}],
    Polygon[{{201448800.000000, 51013764.000000, -605323008.000000},{
      102117144.000000, 25859574.000000, -631271232.000000},{
      104980744.000000, -8698953.000000, -631271232.000000},{
      207097888.000000, -17160620.000000, -605323008.000000}}],
    Polygon[{{102117144.000000, 25859574.000000, -631271232.000000},{
      0.000000, 0.000000, -640000000.000000},{
      0.000000, 0.000000, -640000000.000000},{
      104980744.000000, -8698953.000000, -631271232.000000}}],
    Polygon[{{0.000000, 0.000000, 640000000.000000},{
      104980744.000000, -8698953.000000, 631271232.000000},{
      96468056.000000, -42314812.000000, 631271232.000000},{
      0.000000, 0.000000, 640000000.000000}}],
    Polygon[{{104980744.000000, -8698953.000000, 631271232.000000},{
      207097888.000000, -17160620.000000, 605323008.000000},{
      190304720.000000, -83475384.000000, 605323008.000000},{
      96468056.000000, -42314812.000000, 631271232.000000}}],
    Polygon[{{207097888.000000, -17160620.000000, 605323008.000000},{
      303565952.000000, -25154192.000000, 562863232.000000},{
      278950368.000000, -122358968.000000, 562863232.000000},{
      190304720.000000, -83475384.000000, 605323008.000000}}],
    Polygon[{{303565952.000000, -25154192.000000, 562863232.000000},{
      391753504.000000, -32461622.000000, 505049920.000000},{
      359986944.000000, -157904912.000000, 505049920.000000},{
      278950368.000000, -122358968.000000, 562863232.000000}}],
    Polygon[{{391753504.000000, -32461622.000000, 505049920.000000},{
      469255072.000000, -38883584.000000, 433460192.000000},{
      431204064.000000, -189143632.000000, 433460192.000000},{
      359986944.000000, -157904912.000000, 505049920.000000}}],
    Polygon[{{469255072.000000, -38883584.000000, 433460192.000000},{
      533956576.000000, -44244904.000000, 350046816.000000},{
      490659040.000000, -215223008.000000, 350046816.000000},{
      431204064.000000, -189143632.000000, 433460192.000000}}],
    Polygon[{{533956576.000000, -44244904.000000, 350046816.000000},{
      584093120.000000, -48399336.000000, 257085072.000000},{
      536730112.000000, -235431648.000000, 257085072.000000},{
      490659040.000000, -215223008.000000, 350046816.000000}}],
    Polygon[{{584093120.000000, -48399336.000000, 257085072.000000},{
      618297152.000000, -51233560.000000, 157110704.000000},{
      568160576.000000, -249218336.000000, 157110704.000000},{
      536730112.000000, -235431648.000000, 257085072.000000}}],
    Polygon[{{618297152.000000, -51233560.000000, 157110704.000000},{
      635635648.000000, -52670268.000000, 52850780.000000},{
      584093120.000000, -256206992.000000, 52850780.000000},{
      568160576.000000, -249218336.000000, 157110704.000000}}],
    Polygon[{{635635648.000000, -52670268.000000, 52850780.000000},{
      635635648.000000, -52670268.000000, -52850780.000000},{
      584093120.000000, -256206992.000000, -52850780.000000},{
      584093120.000000, -256206992.000000, 52850780.000000}}],
    Polygon[{{635635648.000000, -52670268.000000, -52850780.000000},{
      618297152.000000, -51233560.000000, -157110704.000000},{
      568160576.000000, -249218336.000000, -157110704.000000},{
      584093120.000000, -256206992.000000, -52850780.000000}}],
    Polygon[{{618297152.000000, -51233560.000000, -157110704.000000},{
      584093120.000000, -48399336.000000, -257085072.000000},{
      536730112.000000, -235431648.000000, -257085072.000000},{
      568160576.000000, -249218336.000000, -157110704.000000}}],
    Polygon[{{584093120.000000, -48399336.000000, -257085072.000000},{
      533956576.000000, -44244904.000000, -350046816.000000},{
      490659040.000000, -215223008.000000, -350046816.000000},{
      536730112.000000, -235431648.000000, -257085072.000000}}],
    Polygon[{{533956576.000000, -44244904.000000, -350046816.000000},{
      469255072.000000, -38883584.000000, -433460192.000000},{
      431204064.000000, -189143632.000000, -433460192.000000},{
      490659040.000000, -215223008.000000, -350046816.000000}}],
    Polygon[{{469255072.000000, -38883584.000000, -433460192.000000},{
      391753504.000000, -32461622.000000, -505049920.000000},{
      359986944.000000, -157904912.000000, -505049920.000000},{
      431204064.000000, -189143632.000000, -433460192.000000}}],
    Polygon[{{391753504.000000, -32461622.000000, -505049920.000000},{
      303565952.000000, -25154192.000000, -562863232.000000},{
      278950368.000000, -122358968.000000, -562863232.000000},{
      359986944.000000, -157904912.000000, -505049920.000000}}],
    Polygon[{{303565952.000000, -25154192.000000, -562863232.000000},{
      207097888.000000, -17160620.000000, -605323008.000000},{
      190304720.000000, -83475384.000000, -605323008.000000},{
      278950368.000000, -122358968.000000, -562863232.000000}}],
    Polygon[{{207097888.000000, -17160620.000000, -605323008.000000},{
      104980744.000000, -8698953.000000, -631271232.000000},{
      96468056.000000, -42314812.000000, -631271232.000000},{
      190304720.000000, -83475384.000000, -605323008.000000}}],
    Polygon[{{104980744.000000, -8698953.000000, -631271232.000000},{
      0.000000, 0.000000, -640000000.000000},{
      0.000000, 0.000000, -640000000.000000},{
      96468056.000000, -42314812.000000, -631271232.000000}}],
    Polygon[{{0.000000, 0.000000, 640000000.000000},{
      96468056.000000, -42314812.000000, 631271232.000000},{
      77501552.000000, -71345208.000000, 631271232.000000},{
      0.000000, 0.000000, 640000000.000000}}],
    Polygon[{{96468056.000000, -42314812.000000, 631271232.000000},{
      190304720.000000, -83475384.000000, 605323008.000000},{
      152889072.000000, -140744304.000000, 605323008.000000},{
      77501552.000000, -71345208.000000, 631271232.000000}}],
    Polygon[{{190304720.000000, -83475384.000000, 605323008.000000},{
      278950368.000000, -122358968.000000, 562863232.000000},{
      224106160.000000, -206304256.000000, 562863232.000000},{
      152889072.000000, -140744304.000000, 605323008.000000}}],
    Polygon[{{278950368.000000, -122358968.000000, 562863232.000000},{
      359986944.000000, -157904912.000000, 505049920.000000},{
      289210240.000000, -266236768.000000, 505049920.000000},{
      224106160.000000, -206304256.000000, 562863232.000000}}],
    Polygon[{{359986944.000000, -157904912.000000, 505049920.000000},{
      431204064.000000, -189143632.000000, 433460192.000000},{
      346425376.000000, -318907040.000000, 433460192.000000},{
      289210240.000000, -266236768.000000, 505049920.000000}}],
    Polygon[{{431204064.000000, -189143632.000000, 433460192.000000},{
      490659040.000000, -215223008.000000, 350046816.000000},{
      394190976.000000, -362878368.000000, 350046816.000000},{
      346425376.000000, -318907040.000000, 433460192.000000}}],
    Polygon[{{490659040.000000, -215223008.000000, 350046816.000000},{
      536730112.000000, -235431648.000000, 257085072.000000},{
      431204064.000000, -396951296.000000, 257085072.000000},{
      394190976.000000, -362878368.000000, 350046816.000000}}],
    Polygon[{{536730112.000000, -235431648.000000, 257085072.000000},{
      568160576.000000, -249218336.000000, 157110704.000000},{
      456455008.000000, -420196448.000000, 157110704.000000},{
      431204064.000000, -396951296.000000, 257085072.000000}}],
    Polygon[{{568160576.000000, -249218336.000000, 157110704.000000},{
      584093120.000000, -256206992.000000, 52850780.000000},{
      469255072.000000, -431979712.000000, 52850780.000000},{
      456455008.000000, -420196448.000000, 157110704.000000}}],
    Polygon[{{584093120.000000, -256206992.000000, 52850780.000000},{
      584093120.000000, -256206992.000000, -52850780.000000},{
      469255072.000000, -431979712.000000, -52850780.000000},{
      469255072.000000, -431979712.000000, 52850780.000000}}],
    Polygon[{{584093120.000000, -256206992.000000, -52850780.000000},{
      568160576.000000, -249218336.000000, -157110704.000000},{
      456455008.000000, -420196448.000000, -157110704.000000},{
      469255072.000000, -431979712.000000, -52850780.000000}}],
    Polygon[{{568160576.000000, -249218336.000000, -157110704.000000},{
      536730112.000000, -235431648.000000, -257085072.000000},{
      431204064.000000, -396951296.000000, -257085072.000000},{
      456455008.000000, -420196448.000000, -157110704.000000}}],
    Polygon[{{536730112.000000, -235431648.000000, -257085072.000000},{
      490659040.000000, -215223008.000000, -350046816.000000},{
      394190976.000000, -362878368.000000, -350046816.000000},{
      431204064.000000, -396951296.000000, -257085072.000000}}],
    Polygon[{{490659040.000000, -215223008.000000, -350046816.000000},{
      431204064.000000, -189143632.000000, -433460192.000000},{
      346425376.000000, -318907040.000000, -433460192.000000},{
      394190976.000000, -362878368.000000, -350046816.000000}}],
    Polygon[{{431204064.000000, -189143632.000000, -433460192.000000},{
      359986944.000000, -157904912.000000, -505049920.000000},{
      289210240.000000, -266236768.000000, -505049920.000000},{
      346425376.000000, -318907040.000000, -433460192.000000}}],
    Polygon[{{359986944.000000, -157904912.000000, -505049920.000000},{
      278950368.000000, -122358968.000000, -562863232.000000},{
      224106160.000000, -206304256.000000, -562863232.000000},{
      289210240.000000, -266236768.000000, -505049920.000000}}],
    Polygon[{{278950368.000000, -122358968.000000, -562863232.000000},{
      190304720.000000, -83475384.000000, -605323008.000000},{
      152889072.000000, -140744304.000000, -605323008.000000},{
      224106160.000000, -206304256.000000, -562863232.000000}}],
    Polygon[{{190304720.000000, -83475384.000000, -605323008.000000},{
      96468056.000000, -42314812.000000, -631271232.000000},{
      77501552.000000, -71345208.000000, -631271232.000000},{
      152889072.000000, -140744304.000000, -605323008.000000}}],
    Polygon[{{96468056.000000, -42314812.000000, -631271232.000000},{
      0.000000, 0.000000, -640000000.000000},{
      0.000000, 0.000000, -640000000.000000},{
      77501552.000000, -71345208.000000, -631271232.000000}}],
    Polygon[{{0.000000, 0.000000, 640000000.000000},{
      77501552.000000, -71345208.000000, 631271232.000000},{
      50136556.000000, -92644240.000000, 631271232.000000},{
      0.000000, 0.000000, 640000000.000000}}],
    Polygon[{{77501552.000000, -71345208.000000, 631271232.000000},{
      152889072.000000, -140744304.000000, 605323008.000000},{
      98905512.000000, -182761376.000000, 605323008.000000},{
      50136556.000000, -92644240.000000, 631271232.000000}}],
    Polygon[{{152889072.000000, -140744304.000000, 605323008.000000},{
      224106160.000000, -206304256.000000, 562863232.000000},{
      144976592.000000, -267893280.000000, 562863232.000000},{
      98905512.000000, -182761376.000000, 605323008.000000}}],
    Polygon[{{224106160.000000, -206304256.000000, 562863232.000000},{
      289210240.000000, -266236768.000000, 505049920.000000},{
      187093088.000000, -345717728.000000, 505049920.000000},{
      144976592.000000, -267893280.000000, 562863232.000000}}],
    Polygon[{{289210240.000000, -266236768.000000, 505049920.000000},{
      346425376.000000, -318907040.000000, 433460192.000000},{
      224106160.000000, -414111904.000000, 433460192.000000},{
      187093088.000000, -345717728.000000, 505049920.000000}}],
    Polygon[{{346425376.000000, -318907040.000000, 433460192.000000},{
      394190976.000000, -362878368.000000, 350046816.000000},{
      255006208.000000, -471210208.000000, 350046816.000000},{
      224106160.000000, -414111904.000000, 433460192.000000}}],
    Polygon[{{394190976.000000, -362878368.000000, 350046816.000000},{
      431204064.000000, -396951296.000000, 257085072.000000},{
      278950368.000000, -515455104.000000, 257085072.000000},{
      255006208.000000, -471210208.000000, 350046816.000000}}],
    Polygon[{{431204064.000000, -396951296.000000, 257085072.000000},{
      456455008.000000, -420196448.000000, 157110704.000000},{
      295285472.000000, -545639744.000000, 157110704.000000},{
      278950368.000000, -515455104.000000, 257085072.000000}}],
    Polygon[{{456455008.000000, -420196448.000000, 157110704.000000},{
      469255072.000000, -431979712.000000, 52850780.000000},{
      303565952.000000, -560940736.000000, 52850780.000000},{
      295285472.000000, -545639744.000000, 157110704.000000}}],
    Polygon[{{469255072.000000, -431979712.000000, 52850780.000000},{
      469255072.000000, -431979712.000000, -52850780.000000},{
      303565952.000000, -560940736.000000, -52850780.000000},{
      303565952.000000, -560940736.000000, 52850780.000000}}],
    Polygon[{{469255072.000000, -431979712.000000, -52850780.000000},{
      456455008.000000, -420196448.000000, -157110704.000000},{
      295285472.000000, -545639744.000000, -157110704.000000},{
      303565952.000000, -560940736.000000, -52850780.000000}}],
    Polygon[{{456455008.000000, -420196448.000000, -157110704.000000},{
      431204064.000000, -396951296.000000, -257085072.000000},{
      278950368.000000, -515455104.000000, -257085072.000000},{
      295285472.000000, -545639744.000000, -157110704.000000}}],
    Polygon[{{431204064.000000, -396951296.000000, -257085072.000000},{
      394190976.000000, -362878368.000000, -350046816.000000},{
      255006208.000000, -471210208.000000, -350046816.000000},{
      278950368.000000, -515455104.000000, -257085072.000000}}],
    Polygon[{{394190976.000000, -362878368.000000, -350046816.000000},{
      346425376.000000, -318907040.000000, -433460192.000000},{
      224106160.000000, -414111904.000000, -433460192.000000},{
      255006208.000000, -471210208.000000, -350046816.000000}}],
    Polygon[{{346425376.000000, -318907040.000000, -433460192.000000},{
      289210240.000000, -266236768.000000, -505049920.000000},{
      187093088.000000, -345717728.000000, -505049920.000000},{
      224106160.000000, -414111904.000000, -433460192.000000}}],
    Polygon[{{289210240.000000, -266236768.000000, -505049920.000000},{
      224106160.000000, -206304256.000000, -562863232.000000},{
      144976592.000000, -267893280.000000, -562863232.000000},{
      187093088.000000, -345717728.000000, -505049920.000000}}],
    Polygon[{{224106160.000000, -206304256.000000, -562863232.000000},{
      152889072.000000, -140744304.000000, -605323008.000000},{
      98905512.000000, -182761376.000000, -605323008.000000},{
      144976592.000000, -267893280.000000, -562863232.000000}}],
    Polygon[{{152889072.000000, -140744304.000000, -605323008.000000},{
      77501552.000000, -71345208.000000, -631271232.000000},{
      50136556.000000, -92644240.000000, -631271232.000000},{
      98905512.000000, -182761376.000000, -605323008.000000}}],
    Polygon[{{77501552.000000, -71345208.000000, -631271232.000000},{
      0.000000, 0.000000, -640000000.000000},{
      0.000000, 0.000000, -640000000.000000},{
      50136556.000000, -92644240.000000, -631271232.000000}}],
    Polygon[{{0.000000, 0.000000, 640000000.000000},{
      50136556.000000, -92644240.000000, 631271232.000000},{
      17338482.000000, -103903832.000000, 631271232.000000},{
      0.000000, 0.000000, 640000000.000000}}],
    Polygon[{{50136556.000000, -92644240.000000, 631271232.000000},{
      98905512.000000, -182761376.000000, 605323008.000000},{
      34204016.000000, -204973440.000000, 605323008.000000},{
      17338482.000000, -103903832.000000, 631271232.000000}}],
    Polygon[{{98905512.000000, -182761376.000000, 605323008.000000},{
      144976592.000000, -267893280.000000, 562863232.000000},{
      50136556.000000, -300451904.000000, 562863232.000000},{
      34204016.000000, -204973440.000000, 605323008.000000}}],
    Polygon[{{144976592.000000, -267893280.000000, 562863232.000000},{
      187093088.000000, -345717728.000000, 505049920.000000},{
      64701496.000000, -387734816.000000, 505049920.000000},{
      50136556.000000, -300451904.000000, 562863232.000000}}],
    Polygon[{{187093088.000000, -345717728.000000, 505049920.000000},{
      224106160.000000, -414111904.000000, 433460192.000000},{
      77501552.000000, -464441344.000000, 433460192.000000},{
      64701496.000000, -387734816.000000, 505049920.000000}}],
    Polygon[{{224106160.000000, -414111904.000000, 433460192.000000},{
      255006208.000000, -471210208.000000, 350046816.000000},{
      88187568.000000, -528479104.000000, 350046816.000000},{
      77501552.000000, -464441344.000000, 433460192.000000}}],
    Polygon[{{255006208.000000, -471210208.000000, 350046816.000000},{
      278950368.000000, -515455104.000000, 257085072.000000},{
      96468056.000000, -578101376.000000, 257085072.000000},{
      88187568.000000, -528479104.000000, 350046816.000000}}],
    Polygon[{{278950368.000000, -515455104.000000, 257085072.000000},{
      295285472.000000, -545639744.000000, 157110704.000000},{
      102117144.000000, -611954496.000000, 157110704.000000},{
      96468056.000000, -578101376.000000, 257085072.000000}}],
    Polygon[{{295285472.000000, -545639744.000000, 157110704.000000},{
      303565952.000000, -560940736.000000, 52850780.000000},{
      104980744.000000, -629115136.000000, 52850780.000000},{
      102117144.000000, -611954496.000000, 157110704.000000}}],
    Polygon[{{303565952.000000, -560940736.000000, 52850780.000000},{
      303565952.000000, -560940736.000000, -52850780.000000},{
      104980744.000000, -629115136.000000, -52850780.000000},{
      104980744.000000, -629115136.000000, 52850780.000000}}],
    Polygon[{{303565952.000000, -560940736.000000, -52850780.000000},{
      295285472.000000, -545639744.000000, -157110704.000000},{
      102117144.000000, -611954496.000000, -157110704.000000},{
      104980744.000000, -629115136.000000, -52850780.000000}}],
    Polygon[{{295285472.000000, -545639744.000000, -157110704.000000},{
      278950368.000000, -515455104.000000, -257085072.000000},{
      96468056.000000, -578101376.000000, -257085072.000000},{
      102117144.000000, -611954496.000000, -157110704.000000}}],
    Polygon[{{278950368.000000, -515455104.000000, -257085072.000000},{
      255006208.000000, -471210208.000000, -350046816.000000},{
      88187568.000000, -528479104.000000, -350046816.000000},{
      96468056.000000, -578101376.000000, -257085072.000000}}],
    Polygon[{{255006208.000000, -471210208.000000, -350046816.000000},{
      224106160.000000, -414111904.000000, -433460192.000000},{
      77501552.000000, -464441344.000000, -433460192.000000},{
      88187568.000000, -528479104.000000, -350046816.000000}}],
    Polygon[{{224106160.000000, -414111904.000000, -433460192.000000},{
      187093088.000000, -345717728.000000, -505049920.000000},{
      64701496.000000, -387734816.000000, -505049920.000000},{
      77501552.000000, -464441344.000000, -433460192.000000}}],
    Polygon[{{187093088.000000, -345717728.000000, -505049920.000000},{
      144976592.000000, -267893280.000000, -562863232.000000},{
      50136556.000000, -300451904.000000, -562863232.000000},{
      64701496.000000, -387734816.000000, -505049920.000000}}],
    Polygon[{{144976592.000000, -267893280.000000, -562863232.000000},{
      98905512.000000, -182761376.000000, -605323008.000000},{
      34204016.000000, -204973440.000000, -605323008.000000},{
      50136556.000000, -300451904.000000, -562863232.000000}}],
    Polygon[{{98905512.000000, -182761376.000000, -605323008.000000},{
      50136556.000000, -92644240.000000, -631271232.000000},{
      17338482.000000, -103903832.000000, -631271232.000000},{
      34204016.000000, -204973440.000000, -605323008.000000}}],
    Polygon[{{50136556.000000, -92644240.000000, -631271232.000000},{
      0.000000, 0.000000, -640000000.000000},{
      0.000000, 0.000000, -640000000.000000},{
      17338482.000000, -103903832.000000, -631271232.000000}}],
    Polygon[{{0.000000, 0.000000, 640000000.000000},{
      17338482.000000, -103903832.000000, 
        631271232.000000},{-17338482.000000, -103903832.000000, 
        631271232.000000},{0.000000, 0.000000, 640000000.000000}}],
    Polygon[{{17338482.000000, -103903832.000000, 631271232.000000},{
      34204016.000000, -204973440.000000, 
        605323008.000000},{-34204016.000000, -204973440.000000, 
        605323008.000000},{-17338482.000000, -103903832.000000, 
        631271232.000000}}],
    Polygon[{{34204016.000000, -204973440.000000, 605323008.000000},{
      50136556.000000, -300451904.000000, 
        562863232.000000},{-50136556.000000, -300451904.000000, 
        562863232.000000},{-34204016.000000, -204973440.000000, 
        605323008.000000}}],
    Polygon[{{50136556.000000, -300451904.000000, 562863232.000000},{
      64701496.000000, -387734816.000000, 
        505049920.000000},{-64701496.000000, -387734816.000000, 
        505049920.000000},{-50136556.000000, -300451904.000000, 
        562863232.000000}}],
    Polygon[{{64701496.000000, -387734816.000000, 505049920.000000},{
      77501552.000000, -464441344.000000, 
        433460192.000000},{-77501552.000000, -464441344.000000, 
        433460192.000000},{-64701496.000000, -387734816.000000, 
        505049920.000000}}],
    Polygon[{{77501552.000000, -464441344.000000, 433460192.000000},{
      88187568.000000, -528479104.000000, 
        350046816.000000},{-88187568.000000, -528479104.000000, 
        350046816.000000},{-77501552.000000, -464441344.000000, 
        433460192.000000}}],
    Polygon[{{88187568.000000, -528479104.000000, 350046816.000000},{
      96468056.000000, -578101376.000000, 
        257085072.000000},{-96468056.000000, -578101376.000000, 
        257085072.000000},{-88187568.000000, -528479104.000000, 
        350046816.000000}}],
    Polygon[{{96468056.000000, -578101376.000000, 257085072.000000},{
      102117144.000000, -611954496.000000, 
        157110704.000000},{-102117144.000000, -611954496.000000, 
        157110704.000000},{-96468056.000000, -578101376.000000, 
        257085072.000000}}],
    Polygon[{{102117144.000000, -611954496.000000, 157110704.000000},{
      104980744.000000, -629115136.000000, 
        52850780.000000},{-104980744.000000, -629115136.000000, 
        52850780.000000},{-102117144.000000, -611954496.000000, 
        157110704.000000}}],
    Polygon[{{104980744.000000, -629115136.000000, 52850780.000000},{
      104980744.000000, -629115136.000000, \
-52850780.000000},{-104980744.000000, -629115136.000000, \
-52850780.000000},{-104980744.000000, -629115136.000000, 52850780.000000}}],
    Polygon[{{104980744.000000, -629115136.000000, -52850780.000000},{
      102117144.000000, -611954496.000000, \
-157110704.000000},{-102117144.000000, -611954496.000000, \
-157110704.000000},{-104980744.000000, -629115136.000000, -52850780.000000}}],
    
    Polygon[{{102117144.000000, -611954496.000000, -157110704.000000},{
      96468056.000000, -578101376.000000, \
-257085072.000000},{-96468056.000000, -578101376.000000, \
-257085072.000000},{-102117144.000000, -611954496.000000, \
-157110704.000000}}],
    Polygon[{{96468056.000000, -578101376.000000, -257085072.000000},{
      88187568.000000, -528479104.000000, \
-350046816.000000},{-88187568.000000, -528479104.000000, \
-350046816.000000},{-96468056.000000, -578101376.000000, -257085072.000000}}],
    
    Polygon[{{88187568.000000, -528479104.000000, -350046816.000000},{
      77501552.000000, -464441344.000000, \
-433460192.000000},{-77501552.000000, -464441344.000000, \
-433460192.000000},{-88187568.000000, -528479104.000000, -350046816.000000}}],
    
    Polygon[{{77501552.000000, -464441344.000000, -433460192.000000},{
      64701496.000000, -387734816.000000, \
-505049920.000000},{-64701496.000000, -387734816.000000, \
-505049920.000000},{-77501552.000000, -464441344.000000, -433460192.000000}}],
    
    Polygon[{{64701496.000000, -387734816.000000, -505049920.000000},{
      50136556.000000, -300451904.000000, \
-562863232.000000},{-50136556.000000, -300451904.000000, \
-562863232.000000},{-64701496.000000, -387734816.000000, -505049920.000000}}],
    
    Polygon[{{50136556.000000, -300451904.000000, -562863232.000000},{
      34204016.000000, -204973440.000000, \
-605323008.000000},{-34204016.000000, -204973440.000000, \
-605323008.000000},{-50136556.000000, -300451904.000000, -562863232.000000}}],
    
    Polygon[{{34204016.000000, -204973440.000000, -605323008.000000},{
      17338482.000000, -103903832.000000, \
-631271232.000000},{-17338482.000000, -103903832.000000, \
-631271232.000000},{-34204016.000000, -204973440.000000, -605323008.000000}}],
    
    Polygon[{{17338482.000000, -103903832.000000, -631271232.000000},{
      0.000000, 0.000000, -640000000.000000},{
      0.000000, 
        0.000000, -640000000.000000},{-17338482.000000, -103903832.000000, \
-631271232.000000}}],
    Polygon[{{
      0.000000, 0.000000, 
        640000000.000000},{-17338482.000000, -103903832.000000, 
        631271232.000000},{-50136556.000000, -92644240.000000, 
        631271232.000000},{0.000000, 0.000000, 640000000.000000}}],
    Polygon[{{-17338482.000000, -103903832.000000, 
        631271232.000000},{-34204016.000000, -204973440.000000, 
        605323008.000000},{-98905512.000000, -182761376.000000, 
        605323008.000000},{-50136556.000000, -92644240.000000, 
        631271232.000000}}],
    Polygon[{{-34204016.000000, -204973440.000000, 
        605323008.000000},{-50136556.000000, -300451904.000000, 
        562863232.000000},{-144976592.000000, -267893280.000000, 
        562863232.000000},{-98905512.000000, -182761376.000000, 
        605323008.000000}}],
    Polygon[{{-50136556.000000, -300451904.000000, 
        562863232.000000},{-64701496.000000, -387734816.000000, 
        505049920.000000},{-187093088.000000, -345717728.000000, 
        505049920.000000},{-144976592.000000, -267893280.000000, 
        562863232.000000}}],
    Polygon[{{-64701496.000000, -387734816.000000, 
        505049920.000000},{-77501552.000000, -464441344.000000, 
        433460192.000000},{-224106160.000000, -414111904.000000, 
        433460192.000000},{-187093088.000000, -345717728.000000, 
        505049920.000000}}],
    Polygon[{{-77501552.000000, -464441344.000000, 
        433460192.000000},{-88187568.000000, -528479104.000000, 
        350046816.000000},{-255006208.000000, -471210208.000000, 
        350046816.000000},{-224106160.000000, -414111904.000000, 
        433460192.000000}}],
    Polygon[{{-88187568.000000, -528479104.000000, 
        350046816.000000},{-96468056.000000, -578101376.000000, 
        257085072.000000},{-278950368.000000, -515455104.000000, 
        257085072.000000},{-255006208.000000, -471210208.000000, 
        350046816.000000}}],
    Polygon[{{-96468056.000000, -578101376.000000, 
        257085072.000000},{-102117144.000000, -611954496.000000, 
        157110704.000000},{-295285472.000000, -545639744.000000, 
        157110704.000000},{-278950368.000000, -515455104.000000, 
        257085072.000000}}],
    Polygon[{{-102117144.000000, -611954496.000000, 
        157110704.000000},{-104980744.000000, -629115136.000000, 
        52850780.000000},{-303565952.000000, -560940736.000000, 
        52850780.000000},{-295285472.000000, -545639744.000000, 
        157110704.000000}}],
    Polygon[{{-104980744.000000, -629115136.000000, 
        52850780.000000},{-104980744.000000, -629115136.000000, \
-52850780.000000},{-303565952.000000, -560940736.000000, \
-52850780.000000},{-303565952.000000, -560940736.000000, 52850780.000000}}],
    Polygon[{{-104980744.000000, -629115136.000000, \
-52850780.000000},{-102117144.000000, -611954496.000000, \
-157110704.000000},{-295285472.000000, -545639744.000000, \
-157110704.000000},{-303565952.000000, -560940736.000000, -52850780.000000}}],
    
    Polygon[{{-102117144.000000, -611954496.000000, \
-157110704.000000},{-96468056.000000, -578101376.000000, \
-257085072.000000},{-278950368.000000, -515455104.000000, \
-257085072.000000},{-295285472.000000, -545639744.000000, \
-157110704.000000}}],
    Polygon[{{-96468056.000000, -578101376.000000, \
-257085072.000000},{-88187568.000000, -528479104.000000, \
-350046816.000000},{-255006208.000000, -471210208.000000, \
-350046816.000000},{-278950368.000000, -515455104.000000, \
-257085072.000000}}],
    Polygon[{{-88187568.000000, -528479104.000000, \
-350046816.000000},{-77501552.000000, -464441344.000000, \
-433460192.000000},{-224106160.000000, -414111904.000000, \
-433460192.000000},{-255006208.000000, -471210208.000000, \
-350046816.000000}}],
    Polygon[{{-77501552.000000, -464441344.000000, \
-433460192.000000},{-64701496.000000, -387734816.000000, \
-505049920.000000},{-187093088.000000, -345717728.000000, \
-505049920.000000},{-224106160.000000, -414111904.000000, \
-433460192.000000}}],
    Polygon[{{-64701496.000000, -387734816.000000, \
-505049920.000000},{-50136556.000000, -300451904.000000, \
-562863232.000000},{-144976592.000000, -267893280.000000, \
-562863232.000000},{-187093088.000000, -345717728.000000, \
-505049920.000000}}],
    Polygon[{{-50136556.000000, -300451904.000000, \
-562863232.000000},{-34204016.000000, -204973440.000000, \
-605323008.000000},{-98905512.000000, -182761376.000000, \
-605323008.000000},{-144976592.000000, -267893280.000000, \
-562863232.000000}}],
    Polygon[{{-34204016.000000, -204973440.000000, \
-605323008.000000},{-17338482.000000, -103903832.000000, \
-631271232.000000},{-50136556.000000, -92644240.000000, \
-631271232.000000},{-98905512.000000, -182761376.000000, -605323008.000000}}],
    
    Polygon[{{-17338482.000000, -103903832.000000, -631271232.000000},{
      0.000000, 0.000000, -640000000.000000},{
      0.000000, 
        0.000000, -640000000.000000},{-50136556.000000, -92644240.000000, \
-631271232.000000}}],
    Polygon[{{
      0.000000, 0.000000, 
        640000000.000000},{-50136556.000000, -92644240.000000, 
        631271232.000000},{-77501552.000000, -71345208.000000, 
        631271232.000000},{0.000000, 0.000000, 640000000.000000}}],
    Polygon[{{-50136556.000000, -92644240.000000, 
        631271232.000000},{-98905512.000000, -182761376.000000, 
        605323008.000000},{-152889072.000000, -140744304.000000, 
        605323008.000000},{-77501552.000000, -71345208.000000, 
        631271232.000000}}],
    Polygon[{{-98905512.000000, -182761376.000000, 
        605323008.000000},{-144976592.000000, -267893280.000000, 
        562863232.000000},{-224106160.000000, -206304256.000000, 
        562863232.000000},{-152889072.000000, -140744304.000000, 
        605323008.000000}}],
    Polygon[{{-144976592.000000, -267893280.000000, 
        562863232.000000},{-187093088.000000, -345717728.000000, 
        505049920.000000},{-289210240.000000, -266236768.000000, 
        505049920.000000},{-224106160.000000, -206304256.000000, 
        562863232.000000}}],
    Polygon[{{-187093088.000000, -345717728.000000, 
        505049920.000000},{-224106160.000000, -414111904.000000, 
        433460192.000000},{-346425376.000000, -318907040.000000, 
        433460192.000000},{-289210240.000000, -266236768.000000, 
        505049920.000000}}],
    Polygon[{{-224106160.000000, -414111904.000000, 
        433460192.000000},{-255006208.000000, -471210208.000000, 
        350046816.000000},{-394190976.000000, -362878368.000000, 
        350046816.000000},{-346425376.000000, -318907040.000000, 
        433460192.000000}}],
    Polygon[{{-255006208.000000, -471210208.000000, 
        350046816.000000},{-278950368.000000, -515455104.000000, 
        257085072.000000},{-431204064.000000, -396951296.000000, 
        257085072.000000},{-394190976.000000, -362878368.000000, 
        350046816.000000}}],
    Polygon[{{-278950368.000000, -515455104.000000, 
        257085072.000000},{-295285472.000000, -545639744.000000, 
        157110704.000000},{-456455008.000000, -420196448.000000, 
        157110704.000000},{-431204064.000000, -396951296.000000, 
        257085072.000000}}],
    Polygon[{{-295285472.000000, -545639744.000000, 
        157110704.000000},{-303565952.000000, -560940736.000000, 
        52850780.000000},{-469255072.000000, -431979712.000000, 
        52850780.000000},{-456455008.000000, -420196448.000000, 
        157110704.000000}}],
    Polygon[{{-303565952.000000, -560940736.000000, 
        52850780.000000},{-303565952.000000, -560940736.000000, \
-52850780.000000},{-469255072.000000, -431979712.000000, \
-52850780.000000},{-469255072.000000, -431979712.000000, 52850780.000000}}],
    Polygon[{{-303565952.000000, -560940736.000000, \
-52850780.000000},{-295285472.000000, -545639744.000000, \
-157110704.000000},{-456455008.000000, -420196448.000000, \
-157110704.000000},{-469255072.000000, -431979712.000000, -52850780.000000}}],
    
    Polygon[{{-295285472.000000, -545639744.000000, \
-157110704.000000},{-278950368.000000, -515455104.000000, \
-257085072.000000},{-431204064.000000, -396951296.000000, \
-257085072.000000},{-456455008.000000, -420196448.000000, \
-157110704.000000}}],
    Polygon[{{-278950368.000000, -515455104.000000, \
-257085072.000000},{-255006208.000000, -471210208.000000, \
-350046816.000000},{-394190976.000000, -362878368.000000, \
-350046816.000000},{-431204064.000000, -396951296.000000, \
-257085072.000000}}],
    Polygon[{{-255006208.000000, -471210208.000000, \
-350046816.000000},{-224106160.000000, -414111904.000000, \
-433460192.000000},{-346425376.000000, -318907040.000000, \
-433460192.000000},{-394190976.000000, -362878368.000000, \
-350046816.000000}}],
    Polygon[{{-224106160.000000, -414111904.000000, \
-433460192.000000},{-187093088.000000, -345717728.000000, \
-505049920.000000},{-289210240.000000, -266236768.000000, \
-505049920.000000},{-346425376.000000, -318907040.000000, \
-433460192.000000}}],
    Polygon[{{-187093088.000000, -345717728.000000, \
-505049920.000000},{-144976592.000000, -267893280.000000, \
-562863232.000000},{-224106160.000000, -206304256.000000, \
-562863232.000000},{-289210240.000000, -266236768.000000, \
-505049920.000000}}],
    Polygon[{{-144976592.000000, -267893280.000000, \
-562863232.000000},{-98905512.000000, -182761376.000000, \
-605323008.000000},{-152889072.000000, -140744304.000000, \
-605323008.000000},{-224106160.000000, -206304256.000000, \
-562863232.000000}}],
    Polygon[{{-98905512.000000, -182761376.000000, \
-605323008.000000},{-50136556.000000, -92644240.000000, \
-631271232.000000},{-77501552.000000, -71345208.000000, \
-631271232.000000},{-152889072.000000, -140744304.000000, \
-605323008.000000}}],
    Polygon[{{-50136556.000000, -92644240.000000, -631271232.000000},{
      0.000000, 0.000000, -640000000.000000},{
      0.000000, 
        0.000000, -640000000.000000},{-77501552.000000, -71345208.000000, \
-631271232.000000}}],
    Polygon[{{
      0.000000, 0.000000, 
        640000000.000000},{-77501552.000000, -71345208.000000, 
        631271232.000000},{-96468056.000000, -42314812.000000, 
        631271232.000000},{0.000000, 0.000000, 640000000.000000}}],
    Polygon[{{-77501552.000000, -71345208.000000, 
        631271232.000000},{-152889072.000000, -140744304.000000, 
        605323008.000000},{-190304720.000000, -83475384.000000, 
        605323008.000000},{-96468056.000000, -42314812.000000, 
        631271232.000000}}],
    Polygon[{{-152889072.000000, -140744304.000000, 
        605323008.000000},{-224106160.000000, -206304256.000000, 
        562863232.000000},{-278950368.000000, -122358968.000000, 
        562863232.000000},{-190304720.000000, -83475384.000000, 
        605323008.000000}}],
    Polygon[{{-224106160.000000, -206304256.000000, 
        562863232.000000},{-289210240.000000, -266236768.000000, 
        505049920.000000},{-359986944.000000, -157904912.000000, 
        505049920.000000},{-278950368.000000, -122358968.000000, 
        562863232.000000}}],
    Polygon[{{-289210240.000000, -266236768.000000, 
        505049920.000000},{-346425376.000000, -318907040.000000, 
        433460192.000000},{-431204064.000000, -189143632.000000, 
        433460192.000000},{-359986944.000000, -157904912.000000, 
        505049920.000000}}],
    Polygon[{{-346425376.000000, -318907040.000000, 
        433460192.000000},{-394190976.000000, -362878368.000000, 
        350046816.000000},{-490659040.000000, -215223008.000000, 
        350046816.000000},{-431204064.000000, -189143632.000000, 
        433460192.000000}}],
    Polygon[{{-394190976.000000, -362878368.000000, 
        350046816.000000},{-431204064.000000, -396951296.000000, 
        257085072.000000},{-536730112.000000, -235431648.000000, 
        257085072.000000},{-490659040.000000, -215223008.000000, 
        350046816.000000}}],
    Polygon[{{-431204064.000000, -396951296.000000, 
        257085072.000000},{-456455008.000000, -420196448.000000, 
        157110704.000000},{-568160576.000000, -249218336.000000, 
        157110704.000000},{-536730112.000000, -235431648.000000, 
        257085072.000000}}],
    Polygon[{{-456455008.000000, -420196448.000000, 
        157110704.000000},{-469255072.000000, -431979712.000000, 
        52850780.000000},{-584093120.000000, -256206992.000000, 
        52850780.000000},{-568160576.000000, -249218336.000000, 
        157110704.000000}}],
    Polygon[{{-469255072.000000, -431979712.000000, 
        52850780.000000},{-469255072.000000, -431979712.000000, \
-52850780.000000},{-584093120.000000, -256206992.000000, \
-52850780.000000},{-584093120.000000, -256206992.000000, 52850780.000000}}],
    Polygon[{{-469255072.000000, -431979712.000000, \
-52850780.000000},{-456455008.000000, -420196448.000000, \
-157110704.000000},{-568160576.000000, -249218336.000000, \
-157110704.000000},{-584093120.000000, -256206992.000000, -52850780.000000}}],
    
    Polygon[{{-456455008.000000, -420196448.000000, \
-157110704.000000},{-431204064.000000, -396951296.000000, \
-257085072.000000},{-536730112.000000, -235431648.000000, \
-257085072.000000},{-568160576.000000, -249218336.000000, \
-157110704.000000}}],
    Polygon[{{-431204064.000000, -396951296.000000, \
-257085072.000000},{-394190976.000000, -362878368.000000, \
-350046816.000000},{-490659040.000000, -215223008.000000, \
-350046816.000000},{-536730112.000000, -235431648.000000, \
-257085072.000000}}],
    Polygon[{{-394190976.000000, -362878368.000000, \
-350046816.000000},{-346425376.000000, -318907040.000000, \
-433460192.000000},{-431204064.000000, -189143632.000000, \
-433460192.000000},{-490659040.000000, -215223008.000000, \
-350046816.000000}}],
    Polygon[{{-346425376.000000, -318907040.000000, \
-433460192.000000},{-289210240.000000, -266236768.000000, \
-505049920.000000},{-359986944.000000, -157904912.000000, \
-505049920.000000},{-431204064.000000, -189143632.000000, \
-433460192.000000}}],
    Polygon[{{-289210240.000000, -266236768.000000, \
-505049920.000000},{-224106160.000000, -206304256.000000, \
-562863232.000000},{-278950368.000000, -122358968.000000, \
-562863232.000000},{-359986944.000000, -157904912.000000, \
-505049920.000000}}],
    Polygon[{{-224106160.000000, -206304256.000000, \
-562863232.000000},{-152889072.000000, -140744304.000000, \
-605323008.000000},{-190304720.000000, -83475384.000000, \
-605323008.000000},{-278950368.000000, -122358968.000000, \
-562863232.000000}}],
    Polygon[{{-152889072.000000, -140744304.000000, \
-605323008.000000},{-77501552.000000, -71345208.000000, \
-631271232.000000},{-96468056.000000, -42314812.000000, \
-631271232.000000},{-190304720.000000, -83475384.000000, -605323008.000000}}],
    
    Polygon[{{-77501552.000000, -71345208.000000, -631271232.000000},{
      0.000000, 0.000000, -640000000.000000},{
      0.000000, 
        0.000000, -640000000.000000},{-96468056.000000, -42314812.000000, \
-631271232.000000}}],
    Polygon[{{
      0.000000, 0.000000, 
        640000000.000000},{-96468056.000000, -42314812.000000, 
        631271232.000000},{-104980744.000000, -8698953.000000, 
        631271232.000000},{0.000000, 0.000000, 640000000.000000}}],
    Polygon[{{-96468056.000000, -42314812.000000, 
        631271232.000000},{-190304720.000000, -83475384.000000, 
        605323008.000000},{-207097888.000000, -17160620.000000, 
        605323008.000000},{-104980744.000000, -8698953.000000, 
        631271232.000000}}],
    Polygon[{{-190304720.000000, -83475384.000000, 
        605323008.000000},{-278950368.000000, -122358968.000000, 
        562863232.000000},{-303565952.000000, -25154192.000000, 
        562863232.000000},{-207097888.000000, -17160620.000000, 
        605323008.000000}}],
    Polygon[{{-278950368.000000, -122358968.000000, 
        562863232.000000},{-359986944.000000, -157904912.000000, 
        505049920.000000},{-391753504.000000, -32461622.000000, 
        505049920.000000},{-303565952.000000, -25154192.000000, 
        562863232.000000}}],
    Polygon[{{-359986944.000000, -157904912.000000, 
        505049920.000000},{-431204064.000000, -189143632.000000, 
        433460192.000000},{-469255072.000000, -38883584.000000, 
        433460192.000000},{-391753504.000000, -32461622.000000, 
        505049920.000000}}],
    Polygon[{{-431204064.000000, -189143632.000000, 
        433460192.000000},{-490659040.000000, -215223008.000000, 
        350046816.000000},{-533956576.000000, -44244904.000000, 
        350046816.000000},{-469255072.000000, -38883584.000000, 
        433460192.000000}}],
    Polygon[{{-490659040.000000, -215223008.000000, 
        350046816.000000},{-536730112.000000, -235431648.000000, 
        257085072.000000},{-584093120.000000, -48399336.000000, 
        257085072.000000},{-533956576.000000, -44244904.000000, 
        350046816.000000}}],
    Polygon[{{-536730112.000000, -235431648.000000, 
        257085072.000000},{-568160576.000000, -249218336.000000, 
        157110704.000000},{-618297152.000000, -51233560.000000, 
        157110704.000000},{-584093120.000000, -48399336.000000, 
        257085072.000000}}],
    Polygon[{{-568160576.000000, -249218336.000000, 
        157110704.000000},{-584093120.000000, -256206992.000000, 
        52850780.000000},{-635635648.000000, -52670268.000000, 
        52850780.000000},{-618297152.000000, -51233560.000000, 
        157110704.000000}}],
    Polygon[{{-584093120.000000, -256206992.000000, 
        52850780.000000},{-584093120.000000, -256206992.000000, \
-52850780.000000},{-635635648.000000, -52670268.000000, \
-52850780.000000},{-635635648.000000, -52670268.000000, 52850780.000000}}],
    Polygon[{{-584093120.000000, -256206992.000000, \
-52850780.000000},{-568160576.000000, -249218336.000000, \
-157110704.000000},{-618297152.000000, -51233560.000000, \
-157110704.000000},{-635635648.000000, -52670268.000000, -52850780.000000}}],
    Polygon[{{-568160576.000000, -249218336.000000, \
-157110704.000000},{-536730112.000000, -235431648.000000, \
-257085072.000000},{-584093120.000000, -48399336.000000, \
-257085072.000000},{-618297152.000000, -51233560.000000, -157110704.000000}}],
    
    Polygon[{{-536730112.000000, -235431648.000000, \
-257085072.000000},{-490659040.000000, -215223008.000000, \
-350046816.000000},{-533956576.000000, -44244904.000000, \
-350046816.000000},{-584093120.000000, -48399336.000000, -257085072.000000}}],
    
    Polygon[{{-490659040.000000, -215223008.000000, \
-350046816.000000},{-431204064.000000, -189143632.000000, \
-433460192.000000},{-469255072.000000, -38883584.000000, \
-433460192.000000},{-533956576.000000, -44244904.000000, -350046816.000000}}],
    
    Polygon[{{-431204064.000000, -189143632.000000, \
-433460192.000000},{-359986944.000000, -157904912.000000, \
-505049920.000000},{-391753504.000000, -32461622.000000, \
-505049920.000000},{-469255072.000000, -38883584.000000, -433460192.000000}}],
    
    Polygon[{{-359986944.000000, -157904912.000000, \
-505049920.000000},{-278950368.000000, -122358968.000000, \
-562863232.000000},{-303565952.000000, -25154192.000000, \
-562863232.000000},{-391753504.000000, -32461622.000000, -505049920.000000}}],
    
    Polygon[{{-278950368.000000, -122358968.000000, \
-562863232.000000},{-190304720.000000, -83475384.000000, \
-605323008.000000},{-207097888.000000, -17160620.000000, \
-605323008.000000},{-303565952.000000, -25154192.000000, -562863232.000000}}],
    
    Polygon[{{-190304720.000000, -83475384.000000, \
-605323008.000000},{-96468056.000000, -42314812.000000, \
-631271232.000000},{-104980744.000000, -8698953.000000, \
-631271232.000000},{-207097888.000000, -17160620.000000, -605323008.000000}}],
    
    Polygon[{{-96468056.000000, -42314812.000000, -631271232.000000},{
      0.000000, 0.000000, -640000000.000000},{
      0.000000, 
        0.000000, -640000000.000000},{-104980744.000000, -8698953.000000, \
-631271232.000000}}],
    Polygon[{{
      0.000000, 0.000000, 
        640000000.000000},{-104980744.000000, -8698953.000000, 
        631271232.000000},{-102117144.000000, 25859574.000000, 
        631271232.000000},{0.000000, 0.000000, 640000000.000000}}],
    Polygon[{{-104980744.000000, -8698953.000000, 
        631271232.000000},{-207097888.000000, -17160620.000000, 
        605323008.000000},{-201448800.000000, 51013764.000000, 
        605323008.000000},{-102117144.000000, 25859574.000000, 
        631271232.000000}}],
    Polygon[{{-207097888.000000, -17160620.000000, 
        605323008.000000},{-303565952.000000, -25154192.000000, 
        562863232.000000},{-295285472.000000, 74776432.000000, 
        562863232.000000},{-201448800.000000, 51013764.000000, 
        605323008.000000}}],
    Polygon[{{-303565952.000000, -25154192.000000, 
        562863232.000000},{-391753504.000000, -32461622.000000, 
        505049920.000000},{-381067488.000000, 96499400.000000, 
        505049920.000000},{-295285472.000000, 74776432.000000, 
        562863232.000000}}],
    Polygon[{{-391753504.000000, -32461622.000000, 
        505049920.000000},{-469255072.000000, -38883584.000000, 
        433460192.000000},{-456455008.000000, 115590104.000000, 
        433460192.000000},{-381067488.000000, 96499400.000000, 
        505049920.000000}}],
    Polygon[{{-469255072.000000, -38883584.000000, 
        433460192.000000},{-533956576.000000, -44244904.000000, 
        350046816.000000},{-519391616.000000, 131527824.000000, 
        350046816.000000},{-456455008.000000, 115590104.000000, 
        433460192.000000}}],
    Polygon[{{-533956576.000000, -44244904.000000, 
        350046816.000000},{-584093120.000000, -48399336.000000, 
        257085072.000000},{-568160576.000000, 143877792.000000, 
        257085072.000000},{-519391616.000000, 131527824.000000, 
        350046816.000000}}],
    Polygon[{{-584093120.000000, -48399336.000000, 
        257085072.000000},{-618297152.000000, -51233560.000000, 
        157110704.000000},{-601431616.000000, 152303168.000000, 
        157110704.000000},{-568160576.000000, 143877792.000000, 
        257085072.000000}}],
    Polygon[{{-618297152.000000, -51233560.000000, 
        157110704.000000},{-635635648.000000, -52670268.000000, 
        52850780.000000},{-618297152.000000, 156574096.000000, 
        52850780.000000},{-601431616.000000, 152303168.000000, 
        157110704.000000}}],
    Polygon[{{-635635648.000000, -52670268.000000, 
        52850780.000000},{-635635648.000000, -52670268.000000, \
-52850780.000000},{-618297152.000000, 
        156574096.000000, -52850780.000000},{-618297152.000000, 
        156574096.000000, 52850780.000000}}],
    Polygon[{{-635635648.000000, -52670268.000000, \
-52850780.000000},{-618297152.000000, -51233560.000000, \
-157110704.000000},{-601431616.000000, 
        152303168.000000, -157110704.000000},{-618297152.000000, 
        156574096.000000, -52850780.000000}}],
    Polygon[{{-618297152.000000, -51233560.000000, \
-157110704.000000},{-584093120.000000, -48399336.000000, \
-257085072.000000},{-568160576.000000, 
        143877792.000000, -257085072.000000},{-601431616.000000, 
        152303168.000000, -157110704.000000}}],
    Polygon[{{-584093120.000000, -48399336.000000, \
-257085072.000000},{-533956576.000000, -44244904.000000, \
-350046816.000000},{-519391616.000000, 
        131527824.000000, -350046816.000000},{-568160576.000000, 
        143877792.000000, -257085072.000000}}],
    Polygon[{{-533956576.000000, -44244904.000000, \
-350046816.000000},{-469255072.000000, -38883584.000000, \
-433460192.000000},{-456455008.000000, 
        115590104.000000, -433460192.000000},{-519391616.000000, 
        131527824.000000, -350046816.000000}}],
    Polygon[{{-469255072.000000, -38883584.000000, \
-433460192.000000},{-391753504.000000, -32461622.000000, \
-505049920.000000},{-381067488.000000, 
        96499400.000000, -505049920.000000},{-456455008.000000, 
        115590104.000000, -433460192.000000}}],
    Polygon[{{-391753504.000000, -32461622.000000, \
-505049920.000000},{-303565952.000000, -25154192.000000, \
-562863232.000000},{-295285472.000000, 
        74776432.000000, -562863232.000000},{-381067488.000000, 
        96499400.000000, -505049920.000000}}],
    Polygon[{{-303565952.000000, -25154192.000000, \
-562863232.000000},{-207097888.000000, -17160620.000000, \
-605323008.000000},{-201448800.000000, 
        51013764.000000, -605323008.000000},{-295285472.000000, 
        74776432.000000, -562863232.000000}}],
    Polygon[{{-207097888.000000, -17160620.000000, \
-605323008.000000},{-104980744.000000, -8698953.000000, \
-631271232.000000},{-102117144.000000, 
        25859574.000000, -631271232.000000},{-201448800.000000, 
        51013764.000000, -605323008.000000}}],
    Polygon[{{-104980744.000000, -8698953.000000, -631271232.000000},{
      0.000000, 0.000000, -640000000.000000},{
      0.000000, 0.000000, -640000000.000000},{-102117144.000000, 
        25859574.000000, -631271232.000000}}],
    Polygon[{{
      0.000000, 0.000000, 640000000.000000},{-102117144.000000, 
        25859574.000000, 631271232.000000},{-88187568.000000, 57615812.000000,
         631271232.000000},{0.000000, 0.000000, 640000000.000000}}],
    Polygon[{{-102117144.000000, 25859574.000000, 
        631271232.000000},{-201448800.000000, 51013764.000000, 
        605323008.000000},{-173969600.000000, 113660016.000000, 
        605323008.000000},{-88187568.000000, 57615812.000000, 
        631271232.000000}}],
    Polygon[{{-201448800.000000, 51013764.000000, 
        605323008.000000},{-295285472.000000, 74776432.000000, 
        562863232.000000},{-255006208.000000, 166603872.000000, 
        562863232.000000},{-173969600.000000, 113660016.000000, 
        605323008.000000}}],
    Polygon[{{-295285472.000000, 74776432.000000, 
        562863232.000000},{-381067488.000000, 96499400.000000, 
        505049920.000000},{-329086912.000000, 215003200.000000, 
        505049920.000000},{-255006208.000000, 166603872.000000, 
        562863232.000000}}],
    Polygon[{{-381067488.000000, 96499400.000000, 
        505049920.000000},{-456455008.000000, 115590104.000000, 
        433460192.000000},{-394190976.000000, 257537824.000000, 
        433460192.000000},{-329086912.000000, 215003200.000000, 
        505049920.000000}}],
    Polygon[{{-456455008.000000, 115590104.000000, 
        433460192.000000},{-519391616.000000, 131527824.000000, 
        350046816.000000},{-448542528.000000, 293047456.000000, 
        350046816.000000},{-394190976.000000, 257537824.000000, 
        433460192.000000}}],
    Polygon[{{-519391616.000000, 131527824.000000, 
        350046816.000000},{-568160576.000000, 143877792.000000, 
        257085072.000000},{-490659040.000000, 320563552.000000, 
        257085072.000000},{-448542528.000000, 293047456.000000, 
        350046816.000000}}],
    Polygon[{{-568160576.000000, 143877792.000000, 
        257085072.000000},{-601431616.000000, 152303168.000000, 
        157110704.000000},{-519391616.000000, 339335488.000000, 
        157110704.000000},{-490659040.000000, 320563552.000000, 
        257085072.000000}}],
    Polygon[{{-601431616.000000, 152303168.000000, 
        157110704.000000},{-618297152.000000, 156574096.000000, 
        52850780.000000},{-533956576.000000, 348851232.000000, 
        52850780.000000},{-519391616.000000, 339335488.000000, 
        157110704.000000}}],
    Polygon[{{-618297152.000000, 156574096.000000, 
        52850780.000000},{-618297152.000000, 
        156574096.000000, -52850780.000000},{-533956576.000000, 
        348851232.000000, -52850780.000000},{-533956576.000000, 
        348851232.000000, 52850780.000000}}],
    Polygon[{{-618297152.000000, 
        156574096.000000, -52850780.000000},{-601431616.000000, 
        152303168.000000, -157110704.000000},{-519391616.000000, 
        339335488.000000, -157110704.000000},{-533956576.000000, 
        348851232.000000, -52850780.000000}}],
    Polygon[{{-601431616.000000, 
        152303168.000000, -157110704.000000},{-568160576.000000, 
        143877792.000000, -257085072.000000},{-490659040.000000, 
        320563552.000000, -257085072.000000},{-519391616.000000, 
        339335488.000000, -157110704.000000}}],
    Polygon[{{-568160576.000000, 
        143877792.000000, -257085072.000000},{-519391616.000000, 
        131527824.000000, -350046816.000000},{-448542528.000000, 
        293047456.000000, -350046816.000000},{-490659040.000000, 
        320563552.000000, -257085072.000000}}],
    Polygon[{{-519391616.000000, 
        131527824.000000, -350046816.000000},{-456455008.000000, 
        115590104.000000, -433460192.000000},{-394190976.000000, 
        257537824.000000, -433460192.000000},{-448542528.000000, 
        293047456.000000, -350046816.000000}}],
    Polygon[{{-456455008.000000, 
        115590104.000000, -433460192.000000},{-381067488.000000, 
        96499400.000000, -505049920.000000},{-329086912.000000, 
        215003200.000000, -505049920.000000},{-394190976.000000, 
        257537824.000000, -433460192.000000}}],
    Polygon[{{-381067488.000000, 
        96499400.000000, -505049920.000000},{-295285472.000000, 
        74776432.000000, -562863232.000000},{-255006208.000000, 
        166603872.000000, -562863232.000000},{-329086912.000000, 
        215003200.000000, -505049920.000000}}],
    Polygon[{{-295285472.000000, 
        74776432.000000, -562863232.000000},{-201448800.000000, 
        51013764.000000, -605323008.000000},{-173969600.000000, 
        113660016.000000, -605323008.000000},{-255006208.000000, 
        166603872.000000, -562863232.000000}}],
    Polygon[{{-201448800.000000, 
        51013764.000000, -605323008.000000},{-102117144.000000, 
        25859574.000000, -631271232.000000},{-88187568.000000, 
        57615812.000000, -631271232.000000},{-173969600.000000, 
        113660016.000000, -605323008.000000}}],
    Polygon[{{-102117144.000000, 25859574.000000, -631271232.000000},{
      0.000000, 0.000000, -640000000.000000},{
      0.000000, 0.000000, -640000000.000000},{-88187568.000000, 
        57615812.000000, -631271232.000000}}],
    Polygon[{{
      0.000000, 0.000000, 640000000.000000},{-88187568.000000, 
        57615812.000000, 631271232.000000},{-64701496.000000, 83128488.000000,
         631271232.000000},{0.000000, 0.000000, 640000000.000000}}],
    Polygon[{{-88187568.000000, 57615812.000000, 
        631271232.000000},{-173969600.000000, 113660016.000000, 
        605323008.000000},{-127638104.000000, 163989440.000000, 
        605323008.000000},{-64701496.000000, 83128488.000000, 
        631271232.000000}}],
    Polygon[{{-173969600.000000, 113660016.000000, 
        605323008.000000},{-255006208.000000, 166603872.000000, 
        562863232.000000},{-187093088.000000, 240377200.000000, 
        562863232.000000},{-127638104.000000, 163989440.000000, 
        605323008.000000}}],
    Polygon[{{-255006208.000000, 166603872.000000, 
        562863232.000000},{-329086912.000000, 215003200.000000, 
        505049920.000000},{-241444640.000000, 310208096.000000, 
        505049920.000000},{-187093088.000000, 240377200.000000, 
        562863232.000000}}],
    Polygon[{{-329086912.000000, 215003200.000000, 
        505049920.000000},{-394190976.000000, 257537824.000000, 
        433460192.000000},{-289210240.000000, 371577312.000000, 
        433460192.000000},{-241444640.000000, 310208096.000000, 
        505049920.000000}}],
    Polygon[{{-394190976.000000, 257537824.000000, 
        433460192.000000},{-448542528.000000, 293047456.000000, 
        350046816.000000},{-329086912.000000, 422810880.000000, 
        350046816.000000},{-289210240.000000, 371577312.000000, 
        433460192.000000}}],
    Polygon[{{-448542528.000000, 293047456.000000, 
        350046816.000000},{-490659040.000000, 320563552.000000, 
        257085072.000000},{-359986944.000000, 462511264.000000, 
        257085072.000000},{-329086912.000000, 422810880.000000, 
        350046816.000000}}],
    Polygon[{{-490659040.000000, 320563552.000000, 
        257085072.000000},{-519391616.000000, 339335488.000000, 
        157110704.000000},{-381067488.000000, 489595520.000000, 
        157110704.000000},{-359986944.000000, 462511264.000000, 
        257085072.000000}}],
    Polygon[{{-519391616.000000, 339335488.000000, 
        157110704.000000},{-533956576.000000, 348851232.000000, 
        52850780.000000},{-391753504.000000, 503324928.000000, 
        52850780.000000},{-381067488.000000, 489595520.000000, 
        157110704.000000}}],
    Polygon[{{-533956576.000000, 348851232.000000, 
        52850780.000000},{-533956576.000000, 
        348851232.000000, -52850780.000000},{-391753504.000000, 
        503324928.000000, -52850780.000000},{-391753504.000000, 
        503324928.000000, 52850780.000000}}],
    Polygon[{{-533956576.000000, 
        348851232.000000, -52850780.000000},{-519391616.000000, 
        339335488.000000, -157110704.000000},{-381067488.000000, 
        489595520.000000, -157110704.000000},{-391753504.000000, 
        503324928.000000, -52850780.000000}}],
    Polygon[{{-519391616.000000, 
        339335488.000000, -157110704.000000},{-490659040.000000, 
        320563552.000000, -257085072.000000},{-359986944.000000, 
        462511264.000000, -257085072.000000},{-381067488.000000, 
        489595520.000000, -157110704.000000}}],
    Polygon[{{-490659040.000000, 
        320563552.000000, -257085072.000000},{-448542528.000000, 
        293047456.000000, -350046816.000000},{-329086912.000000, 
        422810880.000000, -350046816.000000},{-359986944.000000, 
        462511264.000000, -257085072.000000}}],
    Polygon[{{-448542528.000000, 
        293047456.000000, -350046816.000000},{-394190976.000000, 
        257537824.000000, -433460192.000000},{-289210240.000000, 
        371577312.000000, -433460192.000000},{-329086912.000000, 
        422810880.000000, -350046816.000000}}],
    Polygon[{{-394190976.000000, 
        257537824.000000, -433460192.000000},{-329086912.000000, 
        215003200.000000, -505049920.000000},{-241444640.000000, 
        310208096.000000, -505049920.000000},{-289210240.000000, 
        371577312.000000, -433460192.000000}}],
    Polygon[{{-329086912.000000, 
        215003200.000000, -505049920.000000},{-255006208.000000, 
        166603872.000000, -562863232.000000},{-187093088.000000, 
        240377200.000000, -562863232.000000},{-241444640.000000, 
        310208096.000000, -505049920.000000}}],
    Polygon[{{-255006208.000000, 
        166603872.000000, -562863232.000000},{-173969600.000000, 
        113660016.000000, -605323008.000000},{-127638104.000000, 
        163989440.000000, -605323008.000000},{-187093088.000000, 
        240377200.000000, -562863232.000000}}],
    Polygon[{{-173969600.000000, 
        113660016.000000, -605323008.000000},{-88187568.000000, 
        57615812.000000, -631271232.000000},{-64701496.000000, 
        83128488.000000, -631271232.000000},{-127638104.000000, 
        163989440.000000, -605323008.000000}}],
    Polygon[{{-88187568.000000, 57615812.000000, -631271232.000000},{
      0.000000, 0.000000, -640000000.000000},{
      0.000000, 0.000000, -640000000.000000},{-64701496.000000, 
        83128488.000000, -631271232.000000}}],
    Polygon[{{
      0.000000, 0.000000, 640000000.000000},{-64701496.000000, 
        83128488.000000, 631271232.000000},{-34204016.000000, 99632896.000000,
         631271232.000000},{0.000000, 0.000000, 640000000.000000}}],
    Polygon[{{-64701496.000000, 83128488.000000, 
        631271232.000000},{-127638104.000000, 163989440.000000, 
        605323008.000000},{-67475040.000000, 196548064.000000, 
        605323008.000000},{-34204016.000000, 99632896.000000, 
        631271232.000000}}],
    Polygon[{{-127638104.000000, 163989440.000000, 
        605323008.000000},{-187093088.000000, 240377200.000000, 
        562863232.000000},{-98905512.000000, 288101920.000000, 
        562863232.000000},{-67475040.000000, 196548064.000000, 
        605323008.000000}}],
    Polygon[{{-187093088.000000, 240377200.000000, 
        562863232.000000},{-241444640.000000, 310208096.000000, 
        505049920.000000},{-127638104.000000, 371797088.000000, 
        505049920.000000},{-98905512.000000, 288101920.000000, 
        562863232.000000}}],
    Polygon[{{-241444640.000000, 310208096.000000, 
        505049920.000000},{-289210240.000000, 371577312.000000, 
        433460192.000000},{-152889072.000000, 445350624.000000, 
        433460192.000000},{-127638104.000000, 371797088.000000, 
        505049920.000000}}],
    Polygon[{{-289210240.000000, 371577312.000000, 
        433460192.000000},{-329086912.000000, 422810880.000000, 
        350046816.000000},{-173969600.000000, 506756160.000000, 
        350046816.000000},{-152889072.000000, 445350624.000000, 
        433460192.000000}}],
    Polygon[{{-329086912.000000, 422810880.000000, 
        350046816.000000},{-359986944.000000, 462511264.000000, 
        257085072.000000},{-190304720.000000, 554338688.000000, 
        257085072.000000},{-173969600.000000, 506756160.000000, 
        350046816.000000}}],
    Polygon[{{-359986944.000000, 462511264.000000, 
        257085072.000000},{-381067488.000000, 489595520.000000, 
        157110704.000000},{-201448800.000000, 586800320.000000, 
        157110704.000000},{-190304720.000000, 554338688.000000, 
        257085072.000000}}],
    Polygon[{{-381067488.000000, 489595520.000000, 
        157110704.000000},{-391753504.000000, 503324928.000000, 
        52850780.000000},{-207097888.000000, 603255552.000000, 
        52850780.000000},{-201448800.000000, 586800320.000000, 
        157110704.000000}}],
    Polygon[{{-391753504.000000, 503324928.000000, 
        52850780.000000},{-391753504.000000, 
        503324928.000000, -52850780.000000},{-207097888.000000, 
        603255552.000000, -52850780.000000},{-207097888.000000, 
        603255552.000000, 52850780.000000}}],
    Polygon[{{-391753504.000000, 
        503324928.000000, -52850780.000000},{-381067488.000000, 
        489595520.000000, -157110704.000000},{-201448800.000000, 
        586800320.000000, -157110704.000000},{-207097888.000000, 
        603255552.000000, -52850780.000000}}],
    Polygon[{{-381067488.000000, 
        489595520.000000, -157110704.000000},{-359986944.000000, 
        462511264.000000, -257085072.000000},{-190304720.000000, 
        554338688.000000, -257085072.000000},{-201448800.000000, 
        586800320.000000, -157110704.000000}}],
    Polygon[{{-359986944.000000, 
        462511264.000000, -257085072.000000},{-329086912.000000, 
        422810880.000000, -350046816.000000},{-173969600.000000, 
        506756160.000000, -350046816.000000},{-190304720.000000, 
        554338688.000000, -257085072.000000}}],
    Polygon[{{-329086912.000000, 
        422810880.000000, -350046816.000000},{-289210240.000000, 
        371577312.000000, -433460192.000000},{-152889072.000000, 
        445350624.000000, -433460192.000000},{-173969600.000000, 
        506756160.000000, -350046816.000000}}],
    Polygon[{{-289210240.000000, 
        371577312.000000, -433460192.000000},{-241444640.000000, 
        310208096.000000, -505049920.000000},{-127638104.000000, 
        371797088.000000, -505049920.000000},{-152889072.000000, 
        445350624.000000, -433460192.000000}}],
    Polygon[{{-241444640.000000, 
        310208096.000000, -505049920.000000},{-187093088.000000, 
        240377200.000000, -562863232.000000},{-98905512.000000, 
        288101920.000000, -562863232.000000},{-127638104.000000, 
        371797088.000000, -505049920.000000}}],
    Polygon[{{-187093088.000000, 
        240377200.000000, -562863232.000000},{-127638104.000000, 
        163989440.000000, -605323008.000000},{-67475040.000000, 
        196548064.000000, -605323008.000000},{-98905512.000000, 
        288101920.000000, -562863232.000000}}],
    Polygon[{{-127638104.000000, 
        163989440.000000, -605323008.000000},{-64701496.000000, 
        83128488.000000, -631271232.000000},{-34204016.000000, 
        99632896.000000, -631271232.000000},{-67475040.000000, 
        196548064.000000, -605323008.000000}}],
    Polygon[{{-64701496.000000, 83128488.000000, -631271232.000000},{
      0.000000, 0.000000, -640000000.000000},{
      0.000000, 0.000000, -640000000.000000},{-34204016.000000, 
        99632896.000000, -631271232.000000}}],
    Polygon[{{
      0.000000, 0.000000, 640000000.000000},{-34204016.000000, 
        99632896.000000, 631271232.000000},{
      0.000000, 105340536.000000, 631271232.000000},{
      0.000000, 0.000000, 640000000.000000}}],
    Polygon[{{-34204016.000000, 99632896.000000, 
        631271232.000000},{-67475040.000000, 196548064.000000, 
        605323008.000000},{0.000000, 207807664.000000, 605323008.000000},{
      0.000000, 105340536.000000, 631271232.000000}}],
    Polygon[{{-67475040.000000, 196548064.000000, 
        605323008.000000},{-98905512.000000, 288101920.000000, 
        562863232.000000},{0.000000, 304606336.000000, 562863232.000000},{
      0.000000, 207807664.000000, 605323008.000000}}],
    Polygon[{{-98905512.000000, 288101920.000000, 
        562863232.000000},{-127638104.000000, 371797088.000000, 
        505049920.000000},{0.000000, 393096128.000000, 505049920.000000},{
      0.000000, 304606336.000000, 562863232.000000}}],
    Polygon[{{-127638104.000000, 371797088.000000, 
        505049920.000000},{-152889072.000000, 445350624.000000, 
        433460192.000000},{0.000000, 470863296.000000, 433460192.000000},{
      0.000000, 393096128.000000, 505049920.000000}}],
    Polygon[{{-152889072.000000, 445350624.000000, 
        433460192.000000},{-173969600.000000, 506756160.000000, 
        350046816.000000},{0.000000, 535786560.000000, 350046816.000000},{
      0.000000, 470863296.000000, 433460192.000000}}],
    Polygon[{{-173969600.000000, 506756160.000000, 
        350046816.000000},{-190304720.000000, 554338688.000000, 
        257085072.000000},{0.000000, 586094912.000000, 257085072.000000},{
      0.000000, 535786560.000000, 350046816.000000}}],
    Polygon[{{-190304720.000000, 554338688.000000, 
        257085072.000000},{-201448800.000000, 586800320.000000, 
        157110704.000000},{0.000000, 620416192.000000, 157110704.000000},{
      0.000000, 586094912.000000, 257085072.000000}}],
    Polygon[{{-201448800.000000, 586800320.000000, 
        157110704.000000},{-207097888.000000, 603255552.000000, 
        52850780.000000},{0.000000, 637814080.000000, 52850780.000000},{
      0.000000, 620416192.000000, 157110704.000000}}],
    Polygon[{{-207097888.000000, 603255552.000000, 
        52850780.000000},{-207097888.000000, 
        603255552.000000, -52850780.000000},{
      0.000000, 637814080.000000, -52850780.000000},{
      0.000000, 637814080.000000, 52850780.000000}}],
    Polygon[{{-207097888.000000, 
        603255552.000000, -52850780.000000},{-201448800.000000, 
        586800320.000000, -157110704.000000},{
      0.000000, 620416192.000000, -157110704.000000},{
      0.000000, 637814080.000000, -52850780.000000}}],
    Polygon[{{-201448800.000000, 
        586800320.000000, -157110704.000000},{-190304720.000000, 
        554338688.000000, -257085072.000000},{
      0.000000, 586094912.000000, -257085072.000000},{
      0.000000, 620416192.000000, -157110704.000000}}],
    Polygon[{{-190304720.000000, 
        554338688.000000, -257085072.000000},{-173969600.000000, 
        506756160.000000, -350046816.000000},{
      0.000000, 535786560.000000, -350046816.000000},{
      0.000000, 586094912.000000, -257085072.000000}}],
    Polygon[{{-173969600.000000, 
        506756160.000000, -350046816.000000},{-152889072.000000, 
        445350624.000000, -433460192.000000},{
      0.000000, 470863296.000000, -433460192.000000},{
      0.000000, 535786560.000000, -350046816.000000}}],
    Polygon[{{-152889072.000000, 
        445350624.000000, -433460192.000000},{-127638104.000000, 
        371797088.000000, -505049920.000000},{
      0.000000, 393096128.000000, -505049920.000000},{
      0.000000, 470863296.000000, -433460192.000000}}],
    Polygon[{{-127638104.000000, 
        371797088.000000, -505049920.000000},{-98905512.000000, 
        288101920.000000, -562863232.000000},{
      0.000000, 304606336.000000, -562863232.000000},{
      0.000000, 393096128.000000, -505049920.000000}}],
    Polygon[{{-98905512.000000, 
        288101920.000000, -562863232.000000},{-67475040.000000, 
        196548064.000000, -605323008.000000},{
      0.000000, 207807664.000000, -605323008.000000},{
      0.000000, 304606336.000000, -562863232.000000}}],
    Polygon[{{-67475040.000000, 
        196548064.000000, -605323008.000000},{-34204016.000000, 
        99632896.000000, -631271232.000000},{
      0.000000, 105340536.000000, -631271232.000000},{
      0.000000, 207807664.000000, -605323008.000000}}],
    Polygon[{{-34204016.000000, 99632896.000000, -631271232.000000},{
      0.000000, 0.000000, -640000000.000000},{
      0.000000, 0.000000, -640000000.000000},{
      0.000000, 105340536.000000, -631271232.000000}}]},
    Boxed -> True,
    Lighting -> True,
    SphericalRegion -> False,
    BoxRatios -> {1.000000, 1.000000, 1.000000},
    ViewPoint -> {1.300000, -2.400000, 2.000000}
  ]
], "Graphics",
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001J2000`400?l00000o`00003oo`3ooomY
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY
0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00m`3oool2
000006l0oooo003d0?ooo`<0000000<0oooo000000000000KP3oool00?80oooo0P0000040?ooo`80
0000KP3oool00>l0oooo0`0000060?ooo`030000003oool0000006d0oooo003/0?ooo`<000002@3o
ool00`000000oooo0000001]0?ooo`00j@3oool3000000`0oooo00@000000?ooo`3oool00000K03o
ool00>L0oooo0P00000@0?ooo`030000003oool0000006`0oooo003T0?ooo`<000004P3oool01000
0000oooo0?ooo`00001[0?ooo`00h@3oool3000001D0oooo00@000000?ooo`3oool00000J`3oool0
0=h0oooo0`00000H0?ooo`050000003oool0oooo0?ooo`000000JP3oool00=`0oooo0P00000K0?oo
o`050000003oool0oooo0?ooo`000000JP3oool00=T0oooo0`00000M0?ooo`030000003oool0oooo
0080oooo00<000000?ooo`3oool0I`3oool00=H0oooo0`00000P0?ooo`030000003oool0oooo0080
oooo00<000000?ooo`3oool0I`3oool00=<0oooo0`00000S0?ooo`030000003oool0oooo00<0oooo
00<000000?ooo`3oool0IP3oool00=40oooo0P00000V0?ooo`030000003oool0oooo00<0oooo00<0
00000?ooo`3oool0IP3oool00<h0oooo0`00000X0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool0I@3oool00</0oooo0`00000[0?ooo`030000003oool0oooo00@0oooo00<000000?oo
o`3oool0I@3oool00<P0oooo0`00000_0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3o
ool0I03oool00<H0oooo0P00000b0?ooo`030000003oool0oooo00@0oooo00<000000?ooo`3oool0
I03oool00<<0oooo0`00000d0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0H`3o
ool00<00oooo0`00000g0?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool0H`3oool0
0;d0oooo0`00000j0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0HP3oool00;/0
oooo0P00000m0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0H@3oool00;P0oooo
0`00000o0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool0H@3oool00;D0oooo0`00
00120?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0H03oool00;80oooo0`000015
0?ooo`030000003oool0oooo00P0oooo00<000000?ooo`3oool0H03oool00;00oooo0P0000180?oo
o`030000003oool0oooo00T0oooo00<000000?ooo`3oool0G`3oool00:d0oooo0`00001:0?ooo`03
0000003oool0oooo00T0oooo00<000000?ooo`3oool0G`3oool00:X0oooo0`00001>0?ooo`030000
003oool0oooo00T0oooo00<000000?ooo`3oool0GP3oool00:L0oooo0`00001A0?ooo`030000003o
ool0oooo00T0oooo00<000000?ooo`3oool0GP3oool00:D0oooo0P00001D0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool0G@3oool00:80oooo0`00001F0?ooo`030000003oool0oooo
00X0oooo00<000000?ooo`3oool0G@3oool009l0oooo0`00001I0?ooo`030000003oool0oooo00/0
oooo00<000000?ooo`3oool0G03oool009`0oooo0`00001L0?ooo`030000003oool0oooo00/0oooo
00<000000?ooo`3oool0G03oool009X0oooo0P00001O0?ooo`030000003oool0oooo00`0oooo00<0
00000?ooo`3oool0F`3oool009L0oooo0`00001Q0?ooo`030000003oool0oooo00`0oooo00<00000
0?ooo`3oool0F`3oool009@0oooo0`00001T0?ooo`030000003oool0oooo00d0oooo00<000000?oo
o`3oool0FP3oool00940oooo0`00001W0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3o
ool0FP3oool008l0oooo0P00001[0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0
F@3oool008`0oooo0`00001]0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool0F@3o
ool008T0oooo0`00001`0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0F03oool0
08H0oooo0`00001c0?ooo`030000003oool0oooo00h0oooo00<000000?ooo`3oool0F03oool008@0
oooo0P00001f0?ooo`030000003oool0oooo00l0oooo00<000000?ooo`3oool0E`3oool00840oooo
0`00001h0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0EP3oool007h0oooo0`00
001k0?ooo`030000003oool0oooo0100oooo00<000000?ooo`3oool0EP3oool007/0oooo0`00001n
0?ooo`030000003oool0oooo0140oooo00<000000?ooo`3oool0E@3oool007T0oooo0P0000210?oo
o`030000003oool0oooo0140oooo00<000000?ooo`3oool0E@3oool007H0oooo0`0000230?ooo`03
0000003oool0oooo0180oooo00<000000?ooo`3oool0E03oool007<0oooo0`0000260?ooo`030000
003oool0oooo0180oooo00<000000?ooo`3oool0E03oool00700oooo0`00002:0?ooo`030000003o
ool0oooo0180oooo00<000000?ooo`3oool0D`3oool006h0oooo0P00002=0?ooo`030000003oool0
oooo0180oooo00<000000?ooo`3oool0D`3oool006/0oooo0`00002?0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool0DP3oool006P0oooo0`00002B0?ooo`030000003oool0oooo01<0
oooo00<000000?ooo`3oool0DP3oool006D0oooo0`00002E0?ooo`030000003oool0oooo01@0oooo
00<000000?ooo`3oool0D@3oool006<0oooo0P00002H0?ooo`030000003oool0oooo01@0oooo00<0
00000?ooo`3oool0D@3oool00600oooo0`00002J0?ooo`030000003oool0oooo01D0oooo00<00000
0?ooo`3oool0D03oool005d0oooo0`00002M0?ooo`030000003oool0oooo01D0oooo00<000000?oo
o`3oool0D03oool005X0oooo0`00002P0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3o
ool0C`3oool005P0oooo0P00002S0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
C`3oool005D0oooo0`00002U0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0CP3o
ool00580oooo0`00002Y0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0CP3oool0
04l0oooo0`00002/0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0C@3oool004d0
oooo0P00002_0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0C03oool004X0oooo
0`00002a0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0C03oool004L0oooo0`00
002d0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0B`3oool004@0oooo0`00002g
0?ooo`030000003oool0oooo01T0oooo00<000000?ooo`3oool0B`3oool00480oooo0P00002j0?oo
o`030000003oool0oooo01X0oooo00<000000?ooo`3oool0BP3oool003l0oooo0`00002l0?ooo`03
0000003oool0oooo01X0oooo00<000000?ooo`3oool0BP3oool003`0oooo0`00002o0?ooo`030000
003oool0oooo01/0oooo00<000000?ooo`3oool0B@3oool003T0oooo0`0000320?ooo`030000003o
ool0oooo01/0oooo00<000000?ooo`3oool0B@3oool003L0oooo0P0000350?ooo`030000003oool0
oooo01`0oooo00<000000?ooo`3oool0B03oool003@0oooo0`0000380?ooo`030000003oool0oooo
01/0oooo00<000000?ooo`3oool0B03oool00380oooo0P00003;0?ooo`030000003oool0oooo01`0
oooo00<000000?ooo`3oool0A`3oool00380oooo0P00003;0?ooo`030000003oool0oooo01`0oooo
00<000000?ooo`3oool0A`3oool00380oooo00<000000?ooo`000000bP3oool00`000000oooo0?oo
o`0M0?ooo`030000003oool0oooo04H0oooo000b0?ooo`040000003oool0oooo00000<T0oooo00<0
00000?ooo`3oool07@3oool00`000000oooo0?ooo`160?ooo`00<@3oool00`000000oooo0?ooo`02
0?ooo`030000003oool0oooo0<H0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`15
0?ooo`00<@3oool00`000000oooo0?ooo`030?ooo`030000003oool0oooo0<D0oooo00<000000?oo
o`3oool07P3oool00`000000oooo0?ooo`150?ooo`00<@3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0oooo0<@0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`140?ooo`00
<@3oool00`000000oooo0?ooo`040?ooo`030000003oool0oooo0<@0oooo00<000000?ooo`3oool0
7`3oool00`000000oooo0?ooo`140?ooo`00<@3oool00`000000oooo0?ooo`050?ooo`030000003o
ool0oooo0<<0oooo00<000000?ooo`3oool0803oool00`000000oooo0?ooo`130?ooo`00<@3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo0<80oooo00<000000?ooo`3oool0803oool0
0`000000oooo0?ooo`130?ooo`00<03oool00`000000oooo0?ooo`080?ooo`030000003oool0oooo
05L0oooo3P00001M0?ooo`030000003oool0oooo0200oooo00<000000?ooo`3oool0@P3oool00300
oooo00<000000?ooo`3oool02@3oool00`000000oooo0?ooo`1<0?ooo`/00000200c<c<00`000000
<c<c03<c<`0203<c<`T00000E03oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0440
oooo000`0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool0B03oool4000000d0<c<c
2@00000:03<c<`H00000CP3oool00`000000oooo0?ooo`0Q0?ooo`030000003oool0oooo0440oooo
000`0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0A@3oool30000000303<c<`00
0000<c<c00<0<c<c2P00000503<c<`040000000m<c<0?C<c03dc<`L00000200c<c<3000002l0oooo
1@00000H0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0@03oool00300oooo00<0
00000?ooo`3oool0303oool00`000000oooo0?ooo`110?ooo`<000000P0c<c<7000000l0<c<c00<0
000003dc<`0m<c<0200m<c<700000080<c<c00@0000003/c<`0000000000903oool9000000D0oooo
1`00000A0?ooo`030000003oool0oooo0280oooo00<000000?ooo`3oool0@03oool00300oooo00<0
00000?ooo`3oool03@3oool00`000000oooo0?ooo`0m0?ooo`<000000P0c<c<4000001D0<c<c00<0
000003dc<`0m<c<03`0m<c<50000000303/c<`000000000001h0oooo1000000E0?ooo`8000003`3o
ool00`000000oooo0?ooo`0S0?ooo`030000003oool0oooo03l0oooo000`0?ooo`030000003oool0
oooo00h0oooo00<000000?ooo`3oool0>P3oool30000000403<c<`0000000000000000<0<c<c00<0
000003<c<`0c<c<03P0c<c<900000140?C<c100000000`0k<c<000000000000J0?ooo`8000006`3o
ool3000000`0oooo00<000000?ooo`3oool08`3oool00`000000oooo0?ooo`0o0?ooo`00;`3oool0
0`000000oooo0?ooo`0@0?ooo`030000003oool0oooo03L0oooo0P000000100c<c<0000000000000
000503<c<`030000000c<c<0<c<c00<0<c<c3000000503<c<`040000001I<c<0FC<c05Tc<`P00000
2P0m<c<00`000000FC<c05Tc<`05000001H0oooo0P00000P0?ooo`8000002P3oool00`000000oooo
0?ooo`0T0?ooo`030000003oool0oooo03h0oooo000_0?ooo`030000003oool0oooo0140oooo00<0
00000?ooo`3oool0=03oool5000000L0<c<c1`00000A03<c<`030000001I<c<0FC<c00T0FC<c2000
000203dc<`800000101I<c<400000180oooo0P00000T0?ooo`030000003oool0oooo00L0oooo00<0
00000?ooo`3oool0903oool00`000000oooo0?ooo`0n0?ooo`00;`3oool00`000000oooo0?ooo`0B
0?ooo`030000003oool0oooo0340oooo1000000703<c<`<0000000<0<c<c0000000c<c<05@0c<c<0
0`000000FC<c05Tc<`0A05Tc<`D000001P1I<c<4000000d0oooo0P00000W0?ooo`8000001`3oool0
0`000000oooo0?ooo`0U0?ooo`030000003oool0oooo03d0oooo000_0?ooo`030000003oool0oooo
01<0oooo00<000000?ooo`3oool0;`3oool2000000L0<c<c0`00000303<c<`030000000c<c<0<c<c
01D0<c<c00<0000005Tc<`1I<c<0501I<c<010000000Mc<c00000000000605Tc<`@000002@3oool2
000002/0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`0U0?ooo`030000003oool0
oooo03d0oooo000_0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0;@3oool20000
00H0<c<c0`00000603<c<`030000000c<c<0<c<c01D0<c<c00<0000005Tc<`1I<c<05@1I<c<00`00
0000Mc<c07Lc<`03000000H0FC<c0`0000060?ooo`030000003oool0oooo02`0oooo00<000000?oo
o`3oool0103oool00`000000oooo0?ooo`0U0?ooo`030000003oool0oooo03`0oooo000_0?ooo`03
0000003oool0oooo01@0oooo00<000000?ooo`3oool0:`3oool2000000@0<c<c0`00000903<c<`03
0000000c<c<0<c<c01D0<c<c00<0000005Tc<`1I<c<05@1I<c<00`000000Mc<c07Lc<`0307Lc<`80
00001P1I<c<2000000<0oooo0P00000`0?ooo`030000003oool0oooo00<0oooo00<000000?ooo`3o
ool09@3oool00`000000oooo0?ooo`0l0?ooo`00;P3oool00`000000oooo0?ooo`0F0?ooo`030000
003oool0oooo02T0oooo0P00000203<c<`<00000300c<c<00`000000<c<c03<c<`0?03<c<`/00000
4`1I<c<00`000000Mc<c07Lc<`0507Lc<`<000001@1I<c<00`000000oooo0000000c0?ooo`030000
003oool0oooo0080oooo00<000000?ooo`3oool09P3oool00`000000oooo0?ooo`0k0?ooo`00;P3o
ool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo02H0oooo1P00000>03<c<`030000000c
<c<0<c<c00@0<c<c3000000604Xc<`030000001c<c<0Lc<c0080Lc<c2000000;05Tc<`030000001g
<c<0Mc<c00P0Mc<c0P00000405Tc<`800000=03oool01@000000oooo0?ooo`3oool0000002P0oooo
00<000000?ooo`3oool0>`3oool002h0oooo00<000000?ooo`3oool0603oool00`000000oooo0?oo
o`0T0?ooo`040000000c<c<0000000000100<c<c2000000B04Xc<`030000001c<c<0Lc<c00X0Lc<c
2000000405Tc<`030000001g<c<0Mc<c00T0Mc<c0`000000101I<c<0000006Y7<`00000c0?ooo`05
0000003oool0oooo0?ooo`000000:@3oool00`000000oooo0?ooo`0j0?ooo`00;P3oool00`000000
oooo0?ooo`0I0?ooo`030000003oool0oooo0240oooo1@00000>03<c<`<0000000<0<c<c0000001:
<c<05`1:<c<00`000000Lc<c07<c<`0B07<c<`H000003@1g<c<30000000306Y7<`000000oooo0380
oooo00@000000?ooo`3oool00000:@3oool00`000000oooo0?ooo`0j0?ooo`00;P3oool00`000000
oooo0?ooo`0J0?ooo`030000003oool0oooo01l0oooo00D0000003<c<`000000<c<c0000000<03<c
<`<000000`0c<c<00`000000BS<c04Xc<`0G04Xc<aT0Lc<c00@0000009=1<`00000000003@1g<c<2
0000000306Y7<`00000000000380oooo00<000000?ooo`000000:P3oool00`000000oooo0?ooo`0i
0?ooo`00;P3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo01d0oooo00<0000003<c
<`0000000P0c<c<00`000000<c<c03<c<`0603<c<`@000001P0c<c<00`000000BS<c04Xc<`0F04Xc
<`030000001c<c<0Lc<c01L0Lc<c00@0000009=1<`2C@C<0Td4c0P00000<07Lc<`80000000<0JTLc
0?ooo`000000<P3oool2000002X0oooo00<000000?ooo`3oool0>@3oool002d0oooo00<000000?oo
o`3oool07@3oool00`000000oooo0?ooo`0J0?ooo`@000000P0c<c<00`000000<c<c03<c<`0403<c
<`@000002@0c<c<00`000000BS<c04Xc<`0F04Xc<`030000001c<c<0Lc<c01L0Lc<c00<0000009=1
<`2C@C<00`2C@C<3000000X0Mc<c0P00000206Y7<`030000003oool0oooo02l0oooo0P00000[0?oo
o`030000003oool0oooo03P0oooo000]0?ooo`030000003oool0oooo01h0oooo00<000000?ooo`3o
ool0603oool00`000000<c<c0000000403<c<`040000000c<c<0<c<c03<c<`<000003@0c<c<00`00
0000BS<c04Xc<`0F04Xc<`030000001c<c<0Lc<c01L0Lc<c00<0000009=1<`2C@C<01P2C@C<20000
00P0Mc<c00D0000008UN<`000000000006Y7<`0200000300oooo00<000000?ooo`3oool0:@3oool0
0`000000oooo0?ooo`0h0?ooo`00;@3oool00`000000oooo0?ooo`0O0?ooo`030000003oool0oooo
01H0oooo00<0000003<c<`000000100c<c<00`000000<c<c00000002000000l0<c<c00<0000004Xc
<`1:<c<04@1:<c<:000001H0Lc<c00<0000009=1<`2C@C<0202C@C<2000000H0Mc<c0P00000208UN
<`040000001ZAc<00000000002l0oooo0P00000Z0?ooo`800000>@3oool002d0oooo00<000000?oo
o`3oool0803oool00`000000oooo0?ooo`0D0?ooo`<000001@0c<c<200000180<c<c00<0000004Xc
<`1:<c<0101:<c<=000000H0HS<c00@0000008`c<`2<<c<0S3<c1P00000@07<c<`030000002C@C<0
Td4c00X0Td4c0`00000407Lc<`0800000029GS<0REhc08UN<`000000JTLc0?ooo`00000_0?ooo`03
0000003oool0oooo02@0oooo100000000`3oool000000?ooo`0h0?ooo`00;@3oool00`000000oooo
0?ooo`0Q0?ooo`030000003oool0oooo0180oooo0P00000503<c<`<000004P0c<c<8000001<0HS<c
00<0000008`c<`2<<c<01`2<<c<7000000T0Lc<c00<0000009=1<`2C@C<03@2C@C<200000080Mc<c
00<0000008UN<`29GS<00P29GS<010000000JTLc00000000000^0?ooo`030000003oool0oooo0240
oooo0`0000050?ooo`030000003oool0oooo03L0oooo000]0?ooo`030000003oool0oooo0280oooo
00<000000?ooo`3oool0403oool2000000D0<c<c00@0000003<c<`0c<c<000003`0c<c<300000003
03<c<`000000HS<c01P0HS<c00<0000008`c<`2<<c<03P2<<c<6000000<0Lc<c00<0000009=1<`2C
@C<03`2C@C<20000000307Lc<`000000REhc00<0REhc00<0000006Y7<`000000;P3oool2000001l0
oooo0`0000080?ooo`030000003oool0oooo03L0oooo000]0?ooo`030000003oool0oooo0280oooo
00<000000?ooo`3oool03`3oool2000000@0<c<c0P00000203<c<`030000000c<c<0<c<c00`0<c<c
0P00000403<c<`030000001R<c<0HS<c01L0HS<c00<0000008`c<`2<<c<0502<<c<500000180Td4c
0P00000508UN<`030000001ZAc<0000001D0oooo4@0000070?ooo`8000006`3oool4000000`0oooo
00<000000?ooo`3oool0=P3oool002`0oooo00<000000?ooo`3oool0903oool00`000000oooo0?oo
o`0=0?ooo`030000000c<c<0<c<c00<0<c<c00<0000003<c<`0c<c<00P0c<c<00`000000<c<c03<c
<`0903<c<`<000001P0c<c<00`000000HS<c068c<`0G068c<`030000002<<c<0S3<c01L0S3<c00<0
00000:aE<`0000000P00000@09=1<`8000001@29GS<300000100oooo1000000A0?ooo`H0000000<0
oooo000000000000603oool300000100oooo00<000000?ooo`3oool0=P3oool002`0oooo00<00000
0?ooo`3oool09@3oool00`000000oooo0?ooo`0;0?ooo`030000000c<c<0<c<c0080<c<c0P000005
03<c<`030000000c<c<0<c<c00H0<c<c0`00000903<c<`030000001R<c<0HS<c01L0HS<c00<00000
08`c<`2<<c<05`2<<c<00`000000[5Dc0:aE<`020:aE<`<000003@2C@C<4000000D0REhc0P00000;
0?ooo`@000006`3oool2000000030?ooo`000000oooo01<0oooo0`00000C0?ooo`030000003oool0
oooo03H0oooo000/0?ooo`030000003oool0oooo02H0oooo00<000000?ooo`3oool02P3oool01000
0000<c<c03<c<`0c<c<2000000H0<c<c00<0000003<c<`0c<c<00`0c<c<3000000`0<c<c00<00000
068c<`1R<c<05`1R<c<00`000000S3<c08`c<`0G08`c<`030000002/EC<0[5Dc00D0[5Dc0`00000;
09=1<`040000002VM3<0YW@c000000D0REhc00<000000?ooo`3oool01@3oool4000000D0oooo3@00
000>0?ooo`<00000403oool4000001H0oooo00<000000?ooo`3oool0=P3oool002`0oooo00<00000
0?ooo`3oool09`3oool00`000000oooo0?ooo`080?ooo`050000000c<c<0<c<c03<c<`0000001`0c
<c<00`000000<c<c03<c<`0203<c<`8000003`0c<c<00`000000HS<c068c<`0G068c<`030000002<
<c<0S3<c01L0S3<c00<000000:aE<`2/EC<0202/EC<2000000T0Td4c00D000000:Id<`2VM3<0YW@c
0000000508UN<`030000003oool0oooo0080oooo0P0000030?ooo`H000003@3oool5000000T0oooo
00<000000?ooo`0000000`00000:0?ooo`<000006P3oool00`000000oooo0?ooo`0f0?ooo`00;03o
ool00`000000oooo0?ooo`0X0?ooo`030000003oool0oooo00L0oooo00@0000003<c<`0000000000
200c<c<00`000000<c<c0000000200000140<c<c00<00000068c<`1R<c<05`1R<c<00`000000S3<c
08`c<`0G08`c<`030000002/EC<0[5Dc00X0[5Dc0`00000609=1<`030000002VM3<0YW@c0080YW@c
00<0000008UN<`29GS<00P29GS<2000000030?ooo`000000000000<0oooo0P00000H0?ooo`@00000
1@3oool010000000oooo0?ooo`0000020?ooo`8000001@3oool3000001d0oooo00<000000?ooo`3o
ool0=P3oool002`0oooo00<000000?ooo`3oool0:@3oool00`000000oooo0?ooo`050?ooo`030000
000c<c<0000000X0<c<c0P00000D03<c<`030000001R<c<0HS<c0140HS<c2P00000F08`c<`030000
002/EC<0[5Dc00d0[5Dc0`00000309=1<`800000102VM3<2000000<0REhc0P0000020?ooo`<00000
7P3oool2000000<0oooo00@000000?ooo`3oool00000103oool500000200oooo00<000000?ooo`3o
ool0=P3oool002/0oooo00<000000?ooo`3oool0:`3oool00`000000oooo0?ooo`030?ooo`<00000
2@0c<c<3000001D0<c<c00<00000068c<`1R<c<0101R<c<=000000H0NC<c00@000000:8c<`2R<c<0
XS<c1P00000@08`c<`030000002/EC<0[5Dc0100[5Dc0`0000000`2C@C<000000:Id<`050:Id<`03
00000029GS<0REhc00@000008`3oool200000080oooo00<000000?ooo`0000000P3oool5000002<0
oooo00<000000?ooo`3oool0=@3oool002/0oooo00<000000?ooo`3oool0;03oool00`000000oooo
0?ooo`020?ooo`030000000c<c<0<c<c00P0<c<c00@0000003<c<`0c<c<00000500c<c<8000001<0
NC<c00<000000:8c<`2R<c<01`2R<c<7000000T0S3<c00<000000:aE<`2/EC<04`2/EC<2000000L0
YW@c00@0000008UN<`29GS<000009`3oool7000000D0oooo0P00000Q0?ooo`030000003oool0oooo
03D0oooo000[0?ooo`030000003oool0oooo02d0oooo00<000000?ooo`3oool00P00000803<c<`80
00000`0c<c<00`000000<c<c03<c<`0?03<c<`<0000000<0BS<c0000001i<c<0601i<c<00`000000
XS<c0:8c<`0>0:8c<`H000000`2<<c<00`000000[5Dc0:aE<`0D0:aE<`8000001`2VM3<010000000
REhc00000000000V0?ooo`D000002@3oool00`000000oooo0?ooo`0N0?ooo`030000003oool0oooo
03D0oooo000[0?ooo`030000003oool0oooo02h0oooo0`00000803<c<`030000000c<c<0<c<c00<0
<c<c00<0000003<c<`0c<c<0300c<c<3000000@0BS<c00<0000007Tc<`1i<c<05`1i<c<00`000000
XS<c0:8c<`0D0:8c<`D000005@2/EC<00`000000`8Tc000000070:Id<`<000008`3oool300000080
oooo00<000000?ooo`0000002P3oool2000001h0oooo00<000000?ooo`3oool0=@3oool002/0oooo
00<000000?ooo`3oool0;`3oool2000000H0<c<c0P00000503<c<`030000000c<c<0<c<c00X0<c<c
0`00000704Xc<`030000001i<c<0NC<c01L0NC<c00<000000:8c<`2R<c<05`2R<c<00`000000`VPc
0000000200000180[5Dc00<000000<29<`30RC<00P0000070:Id<`8000007P3oool4000000D0oooo
00@000000?ooo`00000000002`3oool00`000000oooo0?ooo`0K0?ooo`030000003oool0oooo03D0
oooo000[0?ooo`030000003oool0oooo02h0oooo0`00000403<c<`8000001`0c<c<00`000000<c<c
03<c<`0803<c<`8000002P1:<c<00`000000NC<c07Tc<`0G07Tc<`030000002R<c<0XS<c01L0XS<c
00<000000<9X<`32J3<00P32J3<3000000l0[5Dc00<000000<29<`30RC<00P30RC<00`000000YW@c
0:Id<`050:Id<`030000003oool0oooo01T0oooo0`0000090?ooo`040000003oool000000?ooo`80
00002P3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo03D0oooo000[0?ooo`030000
003oool0oooo02h0oooo0P00000403<c<`030000000c<c<0<c<c00L0<c<c00<0000003<c<`0c<c<0
1@0c<c<3000000`0BS<c00<0000007Tc<`1i<c<05`1i<c<00`000000XS<c0:8c<`0G0:8c<`030000
0032J3<0`VPc00D0`VPc0`00000<0:aE<`0300000030RC<0`8Tc00<0`8Tc00<000000:Id<`2VM3<0
102VM3<2000000/0oooo2`000000103oool0000000000000000<0?ooo`030000003oool0000000<0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo03D0
oooo000Z0?ooo`030000003oool0oooo02h0oooo0`00000203<c<`8000002P0c<c<00`000000<c<c
03<c<`0203<c<`<000003`1:<c<00`000000NC<c07Tc<`0G07Tc<`030000002R<c<0XS<c01L0XS<c
00<000000<9X<`32J3<02032J3<2000000X0[5Dc00<000000<29<`30RC<01030RC<00`000000YW@c
0:Id<`030:Id<`8000000`3oool8000000P0oooo2000000;0?ooo`030000003oool0000000@0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0oooo03@0oooo
000Z0?ooo`030000003oool0oooo02d0oooo0P000000100c<c<0000003<c<`00000<03<c<`030000
000c<c<00000008000004P1:<c<00`000000NC<c07Tc<`0G07Tc<`030000002R<c<0XS<c01L0XS<c
00<000000<9X<`32J3<02P32J3<3000000L0[5Dc00<000000<29<`30RC<01@30RC<00`000000YW@c
0:Id<`030:Id<`@000003@3oool3000000P0oooo100000070?ooo`030000003oool0000000D0oooo
00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo03@0oooo
000Z0?ooo`030000003oool0oooo02d0oooo00<0000003<c<`0000000P00000=03<c<`8000005@1:
<c<00`000000NC<c07Tc<`0G07Tc<`030000002R<c<0XS<c01L0XS<c00<000000<9X<`32J3<03@32
J3<3000000@0[5Dc00<000000<29<`30RC<01P30RC<00`000000YW@c0:Id<`020:Id<`800000303o
ool3000000l0oooo00<000000?ooo`3oool0103oool00`000000oooo000000060?ooo`030000003o
ool0oooo00L0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0d0?ooo`00:P3oool0
0`000000oooo0?ooo`0/0?ooo`80000000<0<c<c0000000c<c<0300c<c<3000001H0BS<c00<00000
07Tc<`1i<c<05`1i<c<00`000000XS<c0:8c<`0G0:8c<`0300000032J3<0`VPc0100`VPc0`000000
0`2/EC<000000<29<`080<29<`070000002VM3<0YW@c0:Id<`000000ZYhc000000070?ooo`@00000
4`3oool3000000<0oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo01P0oooo00<000000?ooo`3oool0=03oool002X0oooo00<000000?ooo`3oool0;03o
ool010000000<c<c00000000000<03<c<`040000000c<c<0<c<c000001H0BS<c00<0000007Tc<`1i
<c<04@1i<c<;000001D0XS<c00<000000<9X<`32J3<04`32J3<2000000X0`8Tc0P0000000`2VM3<0
00000:ZN<`02000000<0oooo0`00000J0?ooo`040000003oool0oooo0?ooo`800000203oool00`00
0000oooo0?ooo`060?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0=03oool002X0
oooo00<000000?ooo`3oool0:`3oool20000000303<c<`000000000000X0<c<c0P00000303<c<`03
0000001:<c<0BS<c01@0BS<c00<0000007Tc<`1i<c<0101i<c<=000000H0SS<c00<000000;I5<`2f
AC<00P2fAC<9000000`0XS<c00<000000<9X<`32J3<05032J3<2000000/0`8Tc00@000000:Id<`00
0000ZYhc1000000N0?ooo`030000003oool0oooo00800000203oool00`000000oooo0?ooo`070?oo
o`030000003oool0oooo01H0oooo00<000000?ooo`3oool0=03oool002T0oooo00<000000?ooo`3o
ool0;03oool01@000000<c<c0000000c<c<0000000T0<c<c00<0000003<c<`0c<c<00`0c<c<00`00
0000BS<c04Xc<`0C04Xc<`P000004`2><c<00`000000]TDc0;I5<`0;0;I5<`P00000102R<c<00`00
0000`VPc0<9X<`0D0<9X<`040000003EVc<00000000000X0`8Tc0P0000020:ZN<`030000003oool0
oooo01l0oooo00@000000?ooo`00000000002@3oool00`000000oooo0?ooo`070?ooo`030000003o
ool0oooo01D0oooo00<000000?ooo`3oool0=03oool002T0oooo00<000000?ooo`3oool0:`3oool2
0000000403<c<`000000<c<c000000L0<c<c0P00000603<c<`030000001:<c<0BS<c0100BS<c0`00
00000`1Q<c<0000008hc<`0H08hc<`030000002fAC<0]TDc01<0]TDc1P00000E0<9X<`050000003E
Vc<0eI/c0=FK<`0000002P30RC<010000000ZYhc0:ZN<`00000R0?ooo`<000002P3oool00`000000
oooo0?ooo`060?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0<`3oool002T0oooo
00<000000?ooo`3oool0:`3oool01@000000<c<c0000000c<c<0000000H0<c<c0P00000803<c<`03
0000001:<c<0BS<c00`0BS<c10000004064c<`030000002><c<0SS<c01L0SS<c00<000000;I5<`2f
AC<05`2fAC<010000000eGXc00000000000C0<9X<`030000003EVc<0eI/c0080eI/c00<000000<29
<`30RC<01`30RC<200000080ZYhc00<000000?ooo`3oool0803oool2000000X0oooo00<000000?oo
o`3oool01P3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo03<0oooo000Y0?ooo`03
0000003oool0oooo02/0oooo00D0000003<c<`000000<c<c0000000503<c<`030000000c<c<0<c<c
00P0<c<c00<0000004Xc<`1:<c<02@1:<c<3000000P0HC<c00<0000008hc<`2><c<05`2><c<00`00
0000]TDc0;I5<`0G0;I5<`040000003ENS<0eGXc0=Ej<`<000004032J3<00`000000eI/c0=FK<`03
0=FK<`0300000030RC<0`8Tc00H0`8Tc0P0000020:ZN<`030000003oool0oooo0200oooo00<00000
0?ooo`0000002@3oool00`000000oooo0?ooo`070?ooo`030000003oool0oooo01D0oooo00<00000
0?ooo`3oool0<`3oool002T0oooo00<000000?ooo`3oool0:P3oool00`000000<c<c0000000203<c
<`040000000c<c<0<c<c03<c<`8000002`0c<c<00`000000BS<c04Xc<`0604Xc<`<000002`1Q<c<0
0`000000SS<c08hc<`0G08hc<`030000002fAC<0]TDc01L0]TDc00<000000=Ej<`3ENS<0103ENS<2
000000h0`VPc00<000000=FK<`3EVc<0103EVc<2000000H0`8Tc00<000000<>c?`0000000P2ZWS<0
0`000000oooo0?ooo`0O0?ooo`040000003oool0oooo000000T0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0E0?ooo`030000003oool0oooo03<0oooo000Y0?ooo`030000003oool0
oooo02X0oooo0P00000303<c<`040000000c<c<0<c<c000000d0<c<c00<0000004Xc<`1:<c<00P1:
<c<4000000h0HC<c00<0000008hc<`2><c<05`2><c<00`000000]TDc0;I5<`0F0;I5<`030000003E
NS<0eGXc00L0eGXc0`00000:0<9X<`030000003EVc<0eI/c00H0eI/c0P0000050<29<`0300000033
/cl000000080ZYhc00<000000?ooo`3oool07`3oool01@000000oooo0?ooo`3oool0000000T0oooo
00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo03<0oooo
000Y0?ooo`030000003oool0oooo02X0oooo0P00000303<c<`<000003P0c<c<00`000000BS<c0000
000200000180HC<c00<0000008hc<`2><c<05`2><c<00`000000]TDc0;I5<`0F0;I5<`030000003E
NS<0eGXc00T0eGXc0`0000080<9X<`030000003EVc<0eI/c00P0eI/c00<000000<29<`30RC<00P30
RC<2000000050<>c?`000000ZYhc0:ZN<`000000803oool01@000000oooo0?ooo`3oool0000000T0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo03<0
oooo000X0?ooo`030000003oool0oooo02X0oooo0P00000403<c<`030000000c<c<0<c<c00h0<c<c
0P00000F064c<`030000002><c<0SS<c01H0SS<c00<000000;I5<`2fAC<05P2fAC<00`000000eGXc
0=Ej<`0<0=Ej<`8000001P32J3<00`000000eI/c0=FK<`090=FK<`0300000030RC<0`8Tc0080`8Tc
00<000000<>c?`0000000P2ZWS<00`000000oooo0?ooo`0M0?ooo`8000000`3oool00`000000oooo
0?ooo`070?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool0503oool00`000000oooo
0?ooo`0c0?ooo`00:03oool00`000000oooo0?ooo`0Z0?ooo`8000000`0c<c<2000000h0<c<c0`00
000G064c<`030000002><c<0SS<c01H0SS<c00<000000;I5<`2fAC<05P2fAC<00`000000eGXc0=Ej
<`0>0=Ej<`<000000`32J3<00`000000eI/c0=FK<`0:0=FK<`0500000030RC<0`8Tc0<29<`000000
0P33/cl00`000000ZYhc0000000O0?ooo`800000103oool00`000000oooo0?ooo`060?ooo`030000
003oool0oooo00L0oooo00<000000?ooo`3oool0503oool00`000000oooo0?ooo`0b0?ooo`00:03o
ool00`000000oooo0?ooo`0Z0?ooo`030000000c<c<0<c<c0080<c<c0P00000=03<c<`040000000e
<c<0=C<c000001L0HC<c00<0000008hc<`2><c<05P2><c<00`000000]TDc0;I5<`0F0;I5<`030000
003ENS<0eGXc0140eGXc0P0000000`32J3<000000=FK<`0<0=FK<`80000000<0`8Tc00000033/cl0
0P33/cl00`000000ZYhc0000000N0?ooo`030000003oool0000000<0oooo00<000000?ooo`3oool0
1`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0
<P3oool002P0oooo00<000000?ooo`3oool0:@3oool2000000<0<c<c00<0000003<c<`0000002`0c
<c<2000000<0=C<c0P00000F064c<`030000002><c<0SS<c01H0SS<c00<000000;I5<`2fAC<05P2f
AC<00`000000eGXc0=Ej<`0C0=Ej<`8000003`3EVc<2000000<0`k<o00<000000:ZN<`0000007P3o
ool00`000000oooo000000040?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool01P3o
ool00`000000oooo0?ooo`0D0?ooo`030000003oool0oooo0380oooo000X0?ooo`030000003oool0
oooo02T0oooo00D0000003<c<`0c<c<0<c<c0000000203<c<`030000000c<c<0<c<c00P0<c<c00<0
000003Dc<`0e<c<0100e<c<00`000000HC<c064c<`0D064c<`030000002><c<0SS<c0100SS<c2`00
000C0;I5<`030000003ENS<0eGXc01D0eGXc0P00000?0=FK<`0300000033/cl0`k<o0080`k<o0P00
000M0?ooo`040000003oool0oooo000000@0oooo00<000000?ooo`3oool01P3oool00`000000oooo
0?ooo`060?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0<P3oool002P0oooo00<0
00000?ooo`3oool0:@3oool01@000000<c<c03<c<`0c<c<000000080<c<c00<0000003<c<`0c<c<0
1P0c<c<2000000L0=C<c00<00000064c<`1Q<c<0501Q<c<00`000000SS<c08hc<`0408hc<``00000
1P2Q<c<00`000000aUTc0<II<`020<II<`P000002`2fAC<00`000000eGXc0=Ej<`0E0=Ej<`040000
003WZT000000000000d0eI/c0P0000030<>c?`8000007@3oool010000000oooo0?ooo`0000050?oo
o`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0D0?oo
o`030000003oool0oooo0380oooo000W0?ooo`030000003oool0oooo02X0oooo00@0000003<c<`0c
<c<00000100c<c<00`000000<c<c03<c<`0403<c<`800000200e<c<00`000000HC<c064c<`0C064c
<`P000004P2Q<c<00`000000aUTc0<II<`0:0<II<`P000000`2fAC<00`000000eGXc0=Ej<`0D0=Ej
<`030000003WZT00ijY00080ijY000<000000=FK<`3EVc<02P3EVc<2000000@0`k<o0P00000L0?oo
o`040000003oool0oooo000000D0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo01@0oooo00<000000?ooo`3oool0<P3oool002L0oooo00<000000?oo
o`3oool0:@3oool010000000<c<c03<c<`00000503<c<`030000000c<c<0<c<c00<0<c<c00<00000
03Dc<`0e<c<0200e<c<00`000000HC<c064c<`0?064c<`@0000000<0Mc<c0000002Q<c<05`2Q<c<0
0`000000aUTc0<II<`0B0<II<`D000005@3ENS<00`000000ijY00>NZ@0030>NZ@0030000003EVc<0
eI/c00P0eI/c00@000000=W4EP3Ia5H000000`33/cl2000001/0oooo00<000000?ooo`3oool00P00
00050?ooo`030000003oool0oooo00D0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?oo
o`0E0?ooo`030000003oool0oooo0340oooo000W0?ooo`030000003oool0oooo02T0oooo00@00000
03<c<`0c<c<000001@0c<c<010000000<c<c03<c<`0c<c<2000000/0=C<c00<00000064c<`1Q<c<0
2`1Q<c<4000000D0Mc<c00<000000:4c<`2Q<c<05P2Q<c<00`000000aUTc0<II<`0E0<II<`040000
003SRC<00000000001<0eGXc00<000000>NZ@03WZT00103WZT000`000000eI/c0=FK<`070=FK<`04
0000003Ia5H0fLAF000000@0`k<o00<000000?ooo`3oool0603oool400000080oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00H0oooo00<000000?oo
o`3oool05@3oool00`000000oooo0?ooo`0a0?ooo`009`3oool00`000000oooo0?ooo`0Y0?ooo`03
0000000c<c<0000000H0<c<c00@0000003<c<`0c<c<000003@0e<c<2000000T0HC<c0`00000907Lc
<`030000002Q<c<0XC<c01H0XC<c00<000000<II<`36FC<05@36FC<010000000hhTc0>>9<`3SRC<3
00000100eGXc00<000000>NZ@03WZT001@3WZT02000000L0eI/c00D000000=W4EP3Ia5H0fLAF0000
00030<>c?`030000003oool0oooo01D0oooo100000050?ooo`030000003oool0oooo0080oooo00<0
00000?ooo`3oool01@3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01D0oooo00<0
00000?ooo`3oool0<@3oool002L0oooo00<000000?ooo`3oool0:@3oool00`000000<c<c00000006
03<c<`<000003`0e<c<00`000000HC<c064c<`03064c<`@000003@1g<c<00`000000XC<c0:4c<`0E
0:4c<`0300000036FC<0aUTc01D0aUTc00<000000>>9<`3SRC<0103SRC<3000000`0eGXc00<00000
0>NZ@03WZT00203WZT000`000000eI/c0=FK<`040=FK<`050000003Ia5H0fLAF0=W4EP0000000`33
/cl00`000000oooo0?ooo`0A0?ooo`@000000`3oool00`000000oooo0?ooo`040?ooo`050000003o
ool0oooo0?ooo`0000001`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01D0oooo
00<000000?ooo`3oool0<@3oool002L0oooo00<000000?ooo`3oool0:@3oool2000000L0<c<c00<0
000003Dc<`0e<c<03`0e<c<00`000000HC<c0000000300000140Mc<c00<000000:4c<`2Q<c<0502Q
<c<2000001H0aUTc00<000000>>9<`3SRC<0203SRC<2000000X0eGXc00<000000>NZ@03WZT002@3W
ZT000`000000eI/c0=FK<`030=FK<`030000003Ia5H0fLAF0080fLAF00@000000<>c?`33/cl00000
403oool3000000H0oooo00<000000?ooo`3oool01P3oool010000000oooo0?ooo`0000070?ooo`03
0000003oool0oooo00H0oooo00<000000?ooo`3oool05@3oool00`000000oooo0?ooo`0a0?ooo`00
9P3oool00`000000oooo0?ooo`0Y0?ooo`8000001`0c<c<200000140=C<c0P00000E07Lc<`030000
002Q<c<0XC<c01@0XC<c00<000000<II<`36FC<05@36FC<00`000000hhTc0>>9<`0:0>>9<`<00000
1`3ENS<00`000000ijY00>NZ@00:0>NZ@0030000003WZT00eI/c0080eI/c00<000000=W4EP3Ia5H0
0`3Ia5H00`000000`k<o0000000<0?ooo`@000002@3oool00`000000oooo0?ooo`060?ooo`040000
003oool0oooo000000L0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`0E0?ooo`03
0000003oool0oooo0340oooo000V0?ooo`030000003oool0oooo02T0oooo0P00000703<c<`<00000
3P0e<c<3000001H0Mc<c00<000000:4c<`2Q<c<0502Q<c<00`000000aUTc0<II<`0E0<II<`030000
003SRC<0hhTc00d0hhTc0`0000040=Ej<`030000003WZT00ijY000/0ijY00P0000000`3EVc<00000
0=W4EP050=W4EP0400000033/cl00000000000P0oooo0`00000<0?ooo`030000003oool0oooo00P0
oooo00<000000?ooo`0000001`3oool00`000000oooo0?ooo`060?ooo`030000003oool0oooo01D0
oooo00<000000?ooo`3oool0<@3oool002H0oooo00<000000?ooo`3oool0:@3oool00`000000<c<c
03<c<`0503<c<`040000000c<c<0<c<c000000d0=C<c00D0000004hc<`1><c<0CS<c0000000E07Lc
<`030000002Q<c<0XC<c01@0XC<c00<000000<II<`36FC<05@36FC<00`000000hhTc0>>9<`0@0>>9
<`80000000<0eGXc0000003WZT003`3WZT02000000L0fLAF00<000000<>c?`000000103oool40000
00l0oooo00<000000?ooo`3oool02@3oool2000000L0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0F0?ooo`030000003oool0oooo0300oooo000V0?ooo`030000003oool0oooo02T0
oooo00<0000003<c<`0c<c<0100c<c<01@000000<c<c03<c<`0c<c<0000000`0=C<c00<0000004hc
<`1><c<00P1><c<00`000000Mc<c07Lc<`0C07Lc<`030000002Q<c<0XC<c01@0XC<c00<000000<II
<`36FC<05@36FC<00`000000hhTc0>>9<`0B0>>9<`8000004@3WZT000`000000fLAF0=W4EP050=W4
EP0400000033/cl000000?ooo`<000004P3oool00`000000oooo0?ooo`0:0?ooo`8000001`3oool0
0`000000oooo0?ooo`060?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0<03oool0
02H0oooo00<000000?ooo`3oool0:@3oool00`000000<c<c03<c<`0403<c<`050000000c<c<0<c<c
03<c<`0000002P0e<c<2000000D0CS<c00<0000007Lc<`1g<c<0501g<c<00`000000XC<c0:4c<`0C
0:4c<`0300000036FC<0aUTc01D0aUTc00<000000>>9<`3SRC<04`3SRC<3000000l0ijY00P000006
0=W4EP@000005@3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool01`3oool00`000000oooo0?ooo`0F0?ooo`030000003oool0oooo0300oooo000V0?oo
o`030000003oool0oooo02T0oooo00<0000003<c<`0c<c<00`0c<c<00`000000<c<c03<c<`0203<c
<`800000200e<c<00`000000CS<c04hc<`0604hc<`030000001g<c<0Mc<c01<0Mc<c00<000000:4c
<`2Q<c<04`2Q<c<00`000000aUTc0<II<`0D0<II<`030000003SRC<0hhTc01<0hhTc00D000000?Bg
F03d]eP0m;MH0000000=0>NZ@0030000003[dVd0000000<0fLAF0`0000000`3Ia5H000000000000F
0?ooo`030000003oool0oooo00/0oooo00<000000?ooo`3oool0103oool00`000000oooo0?ooo`06
0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3oool0<03oool002H0oooo00<000000?oo
o`3oool0:@3oool00`000000<c<c03<c<`0203<c<`030000000c<c<0<c<c00@0<c<c00<0000003Dc
<`0e<c<01@0e<c<00`000000CS<c04hc<`0704hc<`030000001g<c<0Mc<c01<0Mc<c00<000000:4c
<`2Q<c<0202Q<c<A00000140aUTc00<000000>>9<`3SRC<04`3SRC<00`000000m;MH0?BgF0020?Bg
F0030000003WZT00ijY000X0ijY000<000000>_BK@0000000`0000050=W4EP030000003oool0oooo
01<0oooo00<000000?ooo`3oool02`3oool00`000000oooo000000050?ooo`030000003oool0oooo
00H0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0`0?ooo`009@3oool00`000000
oooo0?ooo`0Z0?ooo`030000000c<c<0<c<c0080<c<c00<0000003<c<`0c<c<0100c<c<00`000000
=C<c03Dc<`0303Dc<`8000002P1><c<00`000000Mc<c07Lc<`0B07Lc<`d000002P2a@C<00`000000
dV/c0=9[<`030=9[<``000001@36FC<00`000000hhTc0>>9<`0C0>>9<`030000003d]eP0m;MH00<0
m;MH0P0000090>NZ@0<0000000<0jm9]0000003Ia5H01P3Ia5H00`000000oooo0?ooo`0B0?ooo`03
0000003oool0oooo00`0oooo00@000000?ooo`3oool00000103oool00`000000oooo0?ooo`060?oo
o`030000003oool0oooo01L0oooo00<000000?ooo`3oool0<03oool002D0oooo00<000000?ooo`3o
ool0:P3oool200000080<c<c00<0000003<c<`0c<c<01@0c<c<00`000000=C<c03Dc<`0203Dc<`03
0000001><c<0CS<c00X0CS<c00<0000007Lc<`1g<c<03P1g<c<40000000308`c<`000000/D4c01@0
/D4c00<000000=9[<`3BJc<03`3BJc<7000001<0hhTc00<000000?BgF03d]eP01P3d]eP00`000000
ijY00>NZ@0020>NZ@0@0000000<0ijY00000003[dVd00P3[dVd00`000000fLAF0=W4EP040=W4EP03
0000003oool0oooo0140oooo00<000000?ooo`3oool03@3oool010000000oooo0?ooo`0000030?oo
o`030000003oool0oooo00H0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0`0?oo
o`009@3oool00`000000oooo0?ooo`0Z0?ooo`8000000P0c<c<00`000000<c<c03<c<`0503<c<`80
00000P0e<c<00`000000CS<c04hc<`0<04hc<`030000001g<c<0Mc<c00X0Mc<c1000000408`c<`03
0000002a@C<0/D4c01<0/D4c00<000000=9[<`3BJc<0503BJc<00`000000k9M=0000000200000100
hhTc00<000000?BgF03d]eP01`3d]eP4000000@0ijY000<000000>_BK@3[dVd00`3[dVd00`000000
fLAF0=W4EP020=W4EP8000004`3oool00`000000oooo0?ooo`0<0?ooo`030000003oool0oooo0080
oooo00@000000?ooo`3oool00000203oool00`000000oooo0?ooo`0I0?ooo`030000003oool0oooo
02l0oooo000U0?ooo`030000003oool0oooo02X0oooo0P0000000`0c<c<0000003<c<`0803<c<`<0
00003`1><c<00`000000Mc<c07Lc<`0707Lc<`<00000202<<c<00`000000/D4c0;51<`0C0;51<`03
0000003BJc<0dV/c01@0dV/c00<000000>bGC@3/Udd00P3/Udd2000000h0hhTc00<000000?BgF03d
]eP0103d]eP6000000D0ijY000<000000>_BK@3[dVd00`3[dVd00`000000fLAF0=W4EP020=W4EP80
00004P3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00<0oooo0P0000080?ooo`03
0000003oool0oooo01X0oooo00<000000?ooo`3oool0;`3oool002D0oooo00<000000?ooo`3oool0
:P3oool3000000X0<c<c00<0000004hc<`1><c<03`1><c<00`000000Mc<c07Lc<`0307Lc<`@00000
302<<c<00`000000/D4c0;51<`0B0;51<`030000003BJc<0dV/c01<0dV/c00<000000>bGC@3/Udd0
1@3/Udd3000000X0hhTc00@000000?BgF03d]eP0m;MH100000060?BgF0030000003WZT00ijY00080
ijY000<000000>_BK@3[dVd0103[dVd010000000fLAF0=W4EP3Ia5H200000180oooo00<000000?oo
o`3oool03@3oool00`000000oooo0?ooo`030?ooo`800000203oool00`000000oooo0?ooo`0J0?oo
o`030000003oool0oooo02l0oooo000U0?ooo`030000003oool0oooo02X0oooo0`00000903<c<`80
00004P1><c<00`000000Mc<c00000003000000l0S3<c00<000000;51<`2a@C<04P2a@C<00`000000
dV/c0=9[<`0C0=9[<`030000003/Udd0k9M=00P0k9M=0`0000070>>9<`@000002`3d]eP01@000000
ijY00>NZ@03WZT00000000L0jm9]00<000000=W4EP3Ia5H00P00000A0?ooo`030000003oool0oooo
00d0oooo00<000000?ooo`3oool0103oool2000000P0oooo00<000000?ooo`3oool06P3oool00`00
0000oooo0?ooo`0_0?ooo`00903oool00`000000oooo0?ooo`0[0?ooo`8000002P0c<c<00`000000
<c<c0000000A04hc<`8000004`2<<c<00`000000/D4c0;51<`0B0;51<`030000003BJc<0dV/c01<0
dV/c00<000000>bGC@3/Udd02`3/Udd200000080hhTc1000000?0?BgF0<00000203[dVd00`000000
fLAF0=W4EP0200000100oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`040?ooo`03
0000003oool0000000L0oooo00<000000?ooo`3oool06P3oool00`000000oooo0?ooo`0_0?ooo`00
903oool00`000000oooo0?ooo`0[0?ooo`8000002@0c<c<010000000<c<c03<c<`00000?04hc<`<0
0000502<<c<00`000000/D4c0;51<`0B0;51<`030000003BJc<0dV/c01<0dV/c00<000000>bGC@3/
Udd0303/Udd4000000030>>9<`000000m;MH0140m;MH00<000000>_BK@3[dVd01`3[dVd300000100
oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`050?ooo`030000003oool0000000H0
oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0_0?ooo`00903oool00`000000oooo
0?ooo`0[0?ooo`<000001`0c<c<01@000000<c<c03<c<`0c<c<0000000d0CS<c0P00000306Hc<`03
0000002<<c<0S3<c0140S3<c00<000000;51<`2a@C<04P2a@C<00`000000dV/c0=9[<`0C0=9[<`03
0000003/Udd0k9M=00P0k9M=100000040>bGC@8000004P3d]eP2000000P0jm9]0`00000@0?ooo`03
0000003oool0oooo00d0oooo00<000000?ooo`3oool01@3oool01@000000oooo0?ooo`3oool00000
00@0oooo00<000000?ooo`3oool0703oool00`000000oooo0?ooo`0_0?ooo`00903oool00`000000
oooo0?ooo`0[0?ooo`<000001`0c<c<00`000000<c<c03<c<`0203<c<`030000001><c<0CS<c00T0
CS<c00<0000006Hc<`1V<c<00`1V<c<00`000000S3<c08`c<`0A08`c<`030000002a@C<0/D4c0180
/D4c00<000000=9[<`3BJc<04P3BJc<00`000000k9M=0>bGC@060>bGC@<000002@3/Udd3000000l0
m;MH00<000000?OLPP0000002@3[dVd2000000l0oooo00<000000?ooo`3oool03P3oool00`000000
oooo0?ooo`050?ooo`030000003oool0oooo0080oooo00D000000?ooo`3oool0oooo0000000O0?oo
o`030000003oool0oooo02h0oooo000T0?ooo`030000003oool0oooo02/0oooo0P0000000`0c<c<0
000003<c<`0403<c<`030000000c<c<0<c<c00<0<c<c00<0000004hc<`1><c<01`1><c<2000000L0
IS<c00<0000008`c<`2<<c<0402<<c<00`000000/D4c0;51<`0B0;51<`030000003BJc<0dV/c0180
dV/c00<000000>bGC@3/Udd00P3/Udd4000000/0k9M=00D000000?^oK`3k_fl0nkm_0000000>0?Bg
F0040000003gg880mmb2000000P0jm9]0P00000>0?ooo`030000003oool0oooo00h0oooo00<00000
0?ooo`3oool0103oool2000000D0oooo00@000000?ooo`3oool00000803oool00`000000oooo0?oo
o`0^0?ooo`00903oool00`000000oooo0?ooo`0[0?ooo`80000000<0<c<c0000000c<c<00`0c<c<0
0`000000<c<c03<c<`0503<c<`030000001><c<0CS<c00@0CS<c0P00000906Hc<`030000002<<c<0
S3<c0140S3<c00<000000;51<`2a@C<04@2a@C<00`000000dV/c0=9[<`0B0=9[<`030000003/Udd0
0000008000003`3/Udd00`000000nkm_0?^oK`020?^oK`030000003d]eP0m;MH00X0m;MH00D00000
0?OLPP3gg880mmb2000000070>_BK@<000003@3oool00`000000oooo0?ooo`0>0?ooo`030000003o
ool0oooo00@0oooo00<000000?ooo`3oool01P3oool200000240oooo00<000000?ooo`3oool0;P3o
ool002@0oooo00<000000?ooo`3oool0:`3oool20000000303<c<`000000<c<c00<0<c<c00<00000
03<c<`0c<c<01@0c<c<00`000000CS<c04hc<`0304hc<`030000001V<c<0IS<c00T0IS<c00<00000
08`c<`2<<c<04@2<<c<00`000000/D4c0;51<`0<0;51<`T000003`3BJc<400000140k9M=00<00000
0?^oK`3k_fl0103k_fl2000000X0m;MH00<000000?OLPP3gg8800P3gg8800`000000jm9]0>_BK@04
0>_BK@<00000303oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo00@0oooo00<00000
0?ooo`3oool01P3oool00`000000oooo0?ooo`0P0?ooo`030000003oool0oooo02h0oooo000S0?oo
o`030000003oool0oooo02`0oooo0P00000203<c<`040000000c<c<0<c<c000000P0<c<c00@00000
04hc<`1><c<0CS<c0P00000=06Hc<`030000002<<c<0S3<c0100S3<c00<000000;51<`2a@C<00P2a
@C<;000000@0_UQ000@000000=YlC`3JO4l0fWa?1`0000050=9[<`<0000000<0dV/c0000003/Udd0
4P3/Udd00`000000nkm_0?^oK`060?^oK`030000003d]eP0m;MH00H0m;MH00<000000?OLPP3gg880
0`3gg8800`000000jm9]0>_BK@040>_BK@<00000303oool00`000000oooo0?ooo`0=0?ooo`800000
1P3oool00`000000oooo0?ooo`070?ooo`8000008@3oool00`000000oooo0?ooo`0^0?ooo`008`3o
ool00`000000oooo0?ooo`0/0?ooo`8000000P0c<c<00`000000<c<c0000000:03<c<`<000003`1V
<c<00`000000S3<c08`c<`0?08`c<`L000003P2nF4000`000000fWa?0=YlC`070=YlC`L000000`3B
Jc<00`000000k9M=0>bGC@0A0>bGC@030000003k_fl0nkm_00L0nkm_0P0000060?BgF0030000003g
g880mmb200@0mmb200<000000>_BK@3[dVd00P3[dVd010000000gnfI00000000000;0?ooo`030000
003oool0oooo00d0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`040000
003oool0oooo00000200oooo00<000000?ooo`3oool0;P3oool002<0oooo00<000000?ooo`3oool0
;03oool2000000<0<c<c0P00000:03<c<`030000001V<c<0IS<c00l0IS<c00<0000008`c<`2<<c<0
2`2<<c<40000000309di>P000000_UQ00180_UQ000<000000=YlC`3JO4l01P3JO4l3000000D0fWa?
1@00000A0>bGC@030000003k_fl0nkm_00X0nkm_00<000000?BgF03d]eP00P3d]eP00`000000mmb2
0?OLPP050?OLPP030000003[dVd0jm9]0080jm9]00@000000=o]V@00000000002@3oool2000000l0
oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`050000003oool0oooo0?oo
o`000000803oool00`000000oooo0?ooo`0^0?ooo`008`3oool00`000000oooo0?ooo`0]0?ooo`05
0000000c<c<0<c<c03<c<`0000002P0c<c<00`000000AC<c0000000A06Hc<`030000002<<c<0S3<c
00L0S3<c0`00000509di>P030000002nF400_UQ00140_UQ000<000000=YlC`3JO4l00P3JO4l40000
00/0fWa?00<000000?2QI`0000000P00000>0>bGC@030000003k_fl0nkm_00/0nkm_00D000000?Bg
F03d]eP0m;MH000000080?OLPP040000003[dVd0jm9]00000080gnfI0P0000080?ooo`030000003o
ool0oooo00h0oooo00<000000?ooo`3oool01P3oool00`000000oooo0?ooo`060?ooo`030000003o
ool0oooo00<0oooo00<000000?ooo`3oool07P3oool00`000000oooo0?ooo`0]0?ooo`008`3oool0
0`000000oooo0?ooo`0]0?ooo`040000000c<c<0<c<c03<c<`8000002@0c<c<00`000000AC<c0000
000A06Hc<`030000002<<c<0S3<c00@0S3<c0`00000909di>P030000002nF400_UQ00100_UQ000<0
00000=YlC`0000000P00000>0=YlC`030000003`XFL0l:5W00<0l:5W0`00000;0>bGC@030000003k
_fl0nkm_00`0nkm_0`0000090?OLPP040000003gg880jm9]00000080gnfI0P0000070?ooo`030000
003oool0oooo00l0oooo00<000000?ooo`3oool0103oool2000000T0oooo00<000000?ooo`3oool0
103oool00`000000oooo0?ooo`0M0?ooo`030000003oool0oooo02d0oooo000S0?ooo`030000003o
ool0oooo02d0oooo00@0000003<c<`0c<c<0<c<c0P00000803<c<`0500000015<c<0AC<c04Dc<`00
00004@1V<c<00`000000S3<c00000003000000`0WCTj00<000000;iH@02nF4003P2nF40400000140
fWa?00<000000?2QI`3`XFL01P3`XFL2000000P0k9M=00<000000?^oK`3k_fl03`3k_fl00`000000
mmb20?OLPP080?OLPP030000003[dVd000000080gnfI0P0000070?ooo`030000003oool0oooo00d0
oooo0P0000060?ooo`030000003oool0oooo00L0oooo0P0000070?ooo`030000003oool0oooo01d0
oooo00<000000?ooo`3oool0;@3oool00280oooo00<000000?ooo`3oool0;P3oool010000000<c<c
03<c<`0c<c<3000000H0<c<c00<0000004Dc<`15<c<00P15<c<00`000000IS<c06Hc<`0?06Hc<`80
0000402M>CX00`000000_UQ00;iH@00;0;iH@0<000000P2nF4000`000000fWa?0=YlC`0@0=YlC`03
0000003`XFL0l:5W00P0l:5W0`0000050>bGC@030000003k_fl0nkm_00h0nkm_00<000000?kQU@00
00002@3gg8800`000000mmb20=o]V@020=o]V@030000003oool0oooo00D0oooo00<000000?ooo`3o
ool03@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3o
ool0203oool00`000000oooo0?ooo`0L0?ooo`030000003oool0oooo02d0oooo000R0?ooo`030000
003oool0oooo02h0oooo00L0000003<c<`0c<c<0<c<c0000000c<c<0000000H0<c<c00<0000004Dc
<`15<c<00`15<c<00`000000IS<c06Hc<`0<06Hc<`<000004@2M>CX00`000000_UQ00;iH@0070;iH
@0@000001@2nF4000`000000fWa?0=YlC`0?0=YlC`030000003`XFL0l:5W00`0l:5W0`0000000`3/
Udd000000?^oK`0@0?^oK`030000003nhID0000000X0mmb200D000000=o]V@3OkIT0gnfI00000006
0?ooo`030000003oool0oooo00d0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`07
0?ooo`030000003oool0oooo00X0oooo00<000000?ooo`3oool06`3oool00`000000oooo0?ooo`0]
0?ooo`008P3oool00`000000oooo0?ooo`0^0?ooo`060000000c<c<0<c<c03<c<`000000<c<c0P00
000403<c<`0300000015<c<0AC<c00@0AC<c0P00000;06Hc<`8000000`1m<d000`000000WCTj09di
>P0?09di>P030000002nF400_UQ000<0_UQ00`0000090;iH@0030000003JO4l0fWa?00l0fWa?00<0
00000?2QI`3`XFL03`3`XFL200000100nkm_00D000000?kQU@3nhID0o^6E000000090?OLPP050000
003OkIT0gnfI0=o]V@0000001@3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo00D0
oooo00<000000?ooo`3oool01`3oool00`000000oooo0?ooo`0;0?ooo`030000003oool0oooo01/0
oooo00<000000?ooo`3oool0;@3oool00280oooo00<000000?ooo`3oool0;`3oool010000000<c<c
03<c<`00000203<c<`030000000c<c<0<c<c0080<c<c00<0000004Dc<`15<c<01@15<c<00`000000
IS<c06Hc<`0806Hc<`030000001m<d00OC=000<0OC=000<0000009di>P2M>CX03`2M>CX00`000000
_UQ000000003000000`0_UQ000<000000=YlC`3JO4l03`3JO4l00`000000l:5W0?2QI`0?0?2QI`04
0000003oa8D00000000000d0nkm_00<000000?kQU@3nhID00P3nhID00`000000mmb20?OLPP060?OL
PP8000000`3OkIT010000000oooo0?ooo`3oool2000000h0oooo0P0000070?ooo`030000003oool0
oooo00L0oooo00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0J0?ooo`030000003oool0
oooo02d0oooo000R0?ooo`030000003oool0oooo02l0oooo00<0000003<c<`0000000`0c<c<20000
0080<c<c00<0000004Dc<`15<c<01`15<c<00`000000IS<c06Hc<`0506Hc<`8000001`1m<d000`00
0000WCTj09di>P0=09di>P<00000402nF4000`000000fWa?0=YlC`0?0=YlC`030000003`XFL0l:5W
00l0l:5W00D000000?o4Q@3oa8D0olB50000000<0?^oK`030000003nhID0o^6E00<0o^6E00<00000
0?OLPP3gg8801@3gg882000000<0gnfI00@000000?ooo`00000000003P3oool2000000P0oooo00<0
00000?ooo`3oool01`3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0oooo01X0oooo00<0
00000?ooo`3oool0;03oool00280oooo00<000000?ooo`3oool0;`3oool00`000000<c<c00000004
03<c<`030000000c<c<0000000X0AC<c00<0000006Hc<`1V<c<0101V<c<00`000000OC=007dc@007
07dc@0030000002M>CX0WCTj00T0WCTj100000000`2M>CX000000;iH@00@0;iH@0030000003JO4l0
fWa?00h0fWa?00<000000?2QI`3`XFL03`3`XFL00`000000olB50?o4Q@030?o4Q@8000002@3k_fl0
0`000000o^6E0?kQU@040?kQU@8000001@3gg8800`000000kOF[000000030=o]V@8000003`3oool0
0`000000oooo0?ooo`060?ooo`800000203oool200000180oooo00<000000?ooo`3oool06P3oool0
0`000000oooo0?ooo`0/0?ooo`008P3oool00`000000oooo0?ooo`0`0?ooo`800000100c<c<30000
00/0AC<c00@0000006Hc<`1V<c<0IS<c0P00000:07dc@08000001`2M>CX3000000H0WCTj00<00000
0;iH@02nF4003P2nF4000`000000fWa?0=YlC`0>0=YlC`030000003`XFL0l:5W00h0l:5W00<00000
0?o4Q@3oa8D01P3oa8D00`000000nkm_0?^oK`060?^oK`030000003nhID0o^6E00D0o^6E00<00000
0?OLPP3gg8800`3gg8800`000000kOF[000000020=o]V@8000003P3oool2000000L0oooo0P000009
0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool06@3oool00`000000oooo0?ooo`0/
0?ooo`008@3oool00`000000oooo0?ooo`0a0?ooo`8000001@0c<c<00`000000AC<c04Dc<`0:04Dc
<`040000001V<c<00000000000d0OC=000@0000009di>P2M>CX0WCTj1000000909di>P030000002n
F400_UQ000H0_UQ03@00000<0=YlC`030000003`XFL0l:5W00h0l:5W00<000000?o4Q@3oa8D01`3o
a8D2000000D0nkm_00<000000?kQU@3nhID01`3nhID01@000000mmb20?OLPP3gg88000000080kOF[
00@000000=o]V@3OkIT000003@3oool2000000P0oooo00<000000?ooo`3oool0203oool00`000000
oooo0?ooo`0E0?ooo`030000003oool0oooo01P0oooo00<000000?ooo`3oool0;03oool00240oooo
00<000000?ooo`3oool0<@3oool2000000D0<c<c0P00000<04Dc<`030000001m<d00OC=000d0OC=0
1000000<09di>PX000002036KF0010000000gX]]0=j;K@3NRfd8000000@0fWa?00<000000?2QI`3`
XFL03P3`XFL00`000000olB50?o4Q@0:0?o4Q@050000003k_fl0nkm_0?^oK`0000002P3nhID01@00
0000mmb20?OLPP3gg88000000080kOF[0`00000<0?ooo`8000002@3oool00`000000oooo0?ooo`08
0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0603oool00`000000oooo0?ooo`0/
0?ooo`008@3oool00`000000oooo0?ooo`0b0?ooo`030000000c<c<0<c<c00<0<c<c0P00000;04Dc
<`030000001P<dl0000000/0OC=01@00000:09di>P@0000000<0[5EL00000036KF003`36KF000`00
0000gX]]0=j;K@090=j;K@H000003`3`XFL00`000000olB50?o4Q@0;0?o4Q@80000000<0nkm_0000
003nhID02P3nhID00`000000mmb2000000020>geZ`80000000<0gnfI0000003oool02@3oool20000
00T0oooo0P0000090?ooo`8000006P3oool00`000000oooo0?ooo`0G0?ooo`030000003oool0oooo
02`0oooo000Q0?ooo`030000003oool0oooo0380oooo00<0000003<c<`0c<c<00`0c<c<00`000000
<c==0000000904Dc<`050000001P<dl0H3=?060cC`0000001`1m<d03000000@0OC=000<0000009di
>P2M>CX0102M>CX4000000D0[5EL0P00000?0<I]H0030000003NRfd0gX]]00d0gX]]00<000000?nY
P00000000`00000:0?2QI`030000003oa8D0olB500h0olB500<000000?kQU@3nhID02P3nhID00`00
0000mmb200000002000000030>geZ`000000000000P0oooo0`0000080?ooo`<000002@3oool20000
01`0oooo00<000000?ooo`3oool05`3oool00`000000oooo0?ooo`0/0?ooo`008@3oool00`000000
oooo0?ooo`0c0?ooo`030000000c<c<0<c<c0080<c<c00@0000003<cC@0c<dd000002015<c<01@00
0000H3=?060cC`1P<dl0000000<0OC=01000000807dc@0030000002M>CX0000000<000002P2/EE`0
0`000000aVeP0<I]H00=0<I]H0030000003NRfd0gX]]00`0gX]]00<000000?nYP03oZH00103oZH03
000000H0l:5W00<000000?o4Q@3oa8D03P3oa8D00`000000on6V0000000<0?kQU@8000000`3]mJ/2
000000H0oooo0P0000090?ooo`8000002@3oool3000001l0oooo00<000000?ooo`3oool05`3oool0
0`000000oooo0?ooo`0[0?ooo`008@3oool00`000000oooo0?ooo`0c0?ooo`030000000c<c<0<c<c
0080<c<c00<0000003<cC@0c<dd00P00000604Dc<`030000001P<dl0H3=?00<0H3=?0`00000<07dc
@08000003P2/EE`00`000000aVeP0<I]H00=0<I]H0030000003NRfd0gX]]00`0gX]]00<000000?nY
P03oZH001`3oZH0400000080l:5W00<000000?o4Q@3oa8D03@3oa8D010000000on6V0?oQYP00000;
0?kQU@800000103]mJ/00`000000oooo0?ooo`020?ooo`<000002@3oool2000000T0oooo0P00000S
0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0:`3oool00200oooo00<000000?oo
o`3oool0=@3oool010000000<c<c03<c<`00000403<cC@0300000015<c<0AC<c00<0AC<c00<00000
060cC`1P<dl0100000000`1P<dl0000007dc@00:07dc@080000000<0TT=P0000002/EE`03@2/EE`0
0`000000aVeP0<I]H00<0<I]H08000003P3NRfd00`000000ojV00?nYP00;0?nYP0800000403oa8D0
1@000000on6V0?oQYP3ohJH0000000P0o^6E0P0000000`3emkX000000>geZ`020>geZ`H000002@3o
ool3000000T0oooo0P00000U0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0:`3o
ool00200oooo00<000000?ooo`3oool0=@3oool010000000<c<c03<c<`00000503<cC@0400000015
<c<0AC<c04Dc<`@000001P1P<dl00`000000OC=007dc@00607dc@08000000`2B@f000`000000[5EL
0:aEG00<0:aEG08000003@36KF000`000000gX]]0=j;K@0<0=j;K@030000003oZH00ojV000`0ojV0
00@000000?o6V@00000000003@3oa8D00`000000on6V0?oQYP020?oQYP030000003nhID0o^6E00@0
o^6E2P00000:0?ooo`@000002P3oool2000002P0oooo00<000000?ooo`3oool05@3oool00`000000
oooo0?ooo`0[0?ooo`00803oool00`000000oooo0?ooo`0f0?ooo`030000000c<c<0000000H0<c==
1000000:060cC`030000001m<d00OC=000@0OC=000<000000993H02B@f00102B@f000`000000[5EL
0:aEG00<0:aEG00300000036KF00aVeP00/0aVeP00<000000=j;K@3NRfd0303NRfd00`000000ojV0
0?nYP00<0?nYP0050000003oaYT0olJI0?o6V@0000002`3oa8D00`000000on6V0?oQYP020?oQYP/0
00000P3emkX01@000000kOF[0>geZ`3]mJ/0000000P0oooo0P00000;0?ooo`<00000:`3oool00`00
0000oooo0?ooo`0D0?ooo`030000003oool0oooo02/0oooo000P0?ooo`030000003oool0oooo03H0
oooo00<0000003<c<`0000000`0c<dd40000000304Dc<`000000H3=?00X0H3=?00<0000007dc@01m
<d000P1m<d02000000P0TT=P00<000000:aEG02/EE`02`2/EE`00`000000aVeP0<I]H00;0<I]H003
0000003NRfd0gX]]00`0gX]]00<000000?nYP03oZH002`3oZH000`000000olJI0?o6V@030?o6V@80
0000203oa8D00`000000on6V0?oQYP050?oQYP@000000`3nhID01@000000mONj0?Gg^P3emkX00000
0080kOF[00<000000?ooo`3oool0103oool3000000X0oooo0`00000^0?ooo`030000003oool0oooo
01@0oooo00<000000?ooo`3oool0:`3oool00200oooo00<000000?ooo`3oool0=`3oool5000000@0
<c==00<00000060cC`1P<dl02`1P<dl010000000OC=000000000000:0993H0030000002/EE`0[5EL
00/0[5EL00<000000<I]H036KF002`36KF000`000000gX]]0=j;K@0;0=j;K@030000003oZH00ojV0
00/0ojV000<000000?o6V@3oaYT01P3oaYT2000000D0olB500<000000?oQYP3ohJH01`3ohJHD0000
00/0oooo0P00000b0?ooo`030000003oool0oooo01<0oooo00<000000?ooo`3oool0:`3oool00200
oooo00<000000?ooo`3oool0=03oool5000000L0<c==0P00000=060cC`030000002B@f00TT=P00/0
TT=P00<000000:aEG02/EE`02P2/EE`2000000`0aVeP00<000000=j;K@3NRfd02`3NRfd00`000000
ojV00?nYP00;0?nYP0030000003oaYT0olJI00P0olJI00<000000?o4Q@3oa8D00P3oa8D00`000000
on6V0?oQYP080?oQYP030000003nhID0000000@000000P3emkX00`000000kOF[0000000>0?ooo`@0
0000=@3oool00`000000oooo0?ooo`0C0?ooo`030000003oool0oooo02X0oooo000O0?ooo`030000
003oool0oooo0380oooo0`0000040?ooo`030000000c<dd0<c==00D0<c==00<0000004XcI`000000
2`1P<dl00`000000NcY]0000000<0993H0030000002/EE`0[5EL00/0[5EL00<000000<I]H036KF00
1036KF0:000000X0gX]]00<000000?nYP03oZH002P3oZH000`000000olJI0?o6V@0:0?o6V@800000
00<0olB50000003ohJH02P3ohJH00`000000o^6E000000040?Gg^Q<00000>@3oool00`000000oooo
0?ooo`0C0?ooo`030000003oool0oooo02X0oooo000O0?ooo`030000003oool0oooo02h0oooo1000
00080?ooo`030000000c<dd0<c==00@0<c==00@0000004XcI`1:<fL000002P1P<dl307/jK@030000
002B@f00TT=P00X0TT=P00<000000:aEG02/EE`02@2/EE`8000000H0bh:000@000000>NGR@3WUhT0
iiN91P0000030=j;K@030000003oZH00ojV000/0ojV000<000000?o6V@3oaYT0303oaYT00`000000
on6V0?oQYP0;0?oQYP030000003emkX0mONj00D0mONj0P0000190?ooo`030000003oool0oooo0180
oooo00<000000?ooo`3oool0:P3oool001l0oooo00<000000?ooo`3oool0:`3oool3000000`0oooo
0P00000503<cC@050000001:<fL0BS=W04XcI`000000201P<dl00`000000NcY]07/jK@0207/jK@03
0000002B@f00TT=P00X0TT=P00<000000:aEG02/EE`0102/EE`4000000030;Q_O@000000bh:000/0
bh:000<000000>NGR@3WUhT01`3WUhT5000000/0ojV000<000000?o6V@3oaYT0303oaYT00`000000
onBc0000000;0?oQYP8000001`3emkX2000004X0oooo00<000000?ooo`3oool04@3oool00`000000
oooo0?ooo`0Z0?ooo`007`3oool00`000000oooo0?ooo`0W0?ooo`@00000403oool00`000000<c==
03<cC@0303<cC@030000001:<fL0BS=W0080BS=W00<00000060cC`1P<dl0101P<dl00`000000NcY]
07/jK@0407/jK@030000002B@f00TT=P00T0TT=P00<000000:aEG02/EE`0100000060;Q_O@030000
003;PX00bh:000T0bh:000<000000>NGR@3WUhT02@3WUhT2000000030?n^V0000000000000800000
1P3oZH000`000000olJI0?o6V@0<0?o6V@040000003oi;<0onBc000000X0on6V00<000000?[oa@00
00001`3emkX00`000000oooo0?ooo`190?ooo`030000003oool0oooo0140oooo00<000000?ooo`3o
ool0:P3oool001l0oooo00<000000?ooo`3oool0903oool3000001D0oooo00D0000003<cC@0c<dd0
<c==0000000604XcI`030000001P<dl0H3=?0080H3=?00<0000007/jK@1k>Vd01@1k>Vd2000000/0
TT=P0P00000:0;Q_O@030000003;PX00bh:000T0bh:000<000000>NGR@3WUhT02@3WUhT00`000000
ojjH0?n^V0040?n^V0@000000P3oZH000`000000olJI0?o6V@0;0?o6V@030000003oi;<0onBc0080
onBc00<000000?oQYP3ohJH01P3ohJH010000000n_o50?[oa@0000060?Gg^P030000003oool0oooo
04/0oooo00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0Z0?ooo`007`3oool00`000000
oooo0?ooo`0P0?ooo`@00000603oool200000080<c==00<0000004XcI`1:<fL01@1:<fL010000000
H3=?060cC`1P<dl907/jK@030000002B@f00TT=P00L0TT=P0P0000000`2UHX0000000;Q_O@090;Q_
O@030000003;PX00bh:000T0bh:000<000000>NGR@3WUhT02@3WUhT00`000000ojjH0?n^V0080?n^
V0800000303oaYT2000000D0onBc0P0000050?oQYP8000000`3jolD00`000000mONj0?Gg^P030?Gg
^P800000C@3oool00`000000oooo0?ooo`0@0?ooo`030000003oool0oooo02X0oooo000O0?ooo`03
0000003oool0oooo01d0oooo0`00000M0?ooo`80000000<0<c==0000001:<fL01`1:<fL00`000000
H3=?0000000:07/jK@030000002B@f00TT=P00@0TT=P0P0000040:ERP0030000002hKgd0^6mm00P0
^6mm00<000000<^2P03;PX00203;PX000`000000iiN90>NGR@080>NGR@030000003o[YP0ojjH00T0
ojjH00@000000?o4Z@00000000002@3oaYT2000000L0onBc00<000000?oQYP3ohJH00P3ohJH00`00
0000n_o50?[oa@030?[oa@030000003emkX0mONj0080mONj0P00001?0?ooo`030000003oool0oooo
0100oooo00<000000?ooo`3oool0:@3oool001h0oooo00<000000?ooo`3oool06P3oool400000200
oooo0P0000000`0c<dd0000004XcI`0804XcI`030000001k>Vd0NcY]00X0NcY]00<000000993H02B
@f000P2B@f02000000D0YF:000<000000;Q_O@2hKgd0202hKgd00`000000bh:00<^2P0080<^2P003
0000003WUhT0iiN900P0iiN900<000000?n^V03o[YP0203o[YP00`000000olBY0?o4Z@020?o4Z@03
0000003oaYT0olJI00D0olJI00<000000?oT/`3oi;<0203oi;<010000000on6V0?oQYP0000060?[o
a@040000003emkX0mONj0?Gg^P800000D@3oool00`000000oooo0?ooo`0?0?ooo`030000003oool0
oooo02T0oooo000N0?ooo`030000003oool0oooo01L0oooo0`00000U0?ooo`<000002@1:<fL20000
00`0NcY]00@000000993H00000000000202UHX000`000000^6mm0;Q_O@080;Q_O@030000003;PX00
bh:000L0bh:000<000000>NGR@3WUhT01`3WUhT00`000000ojjH0?n^V0090?n^V0030000003oa:T0
olBY00<0olBY0P0000040?o6V@030000003oi;<0onBc00T0onBc00<000000?oQYP0000001`3jolD0
1P000000mONj0?Gg^P000000h?oJ00000540oooo00<000000?ooo`3oool03`3oool00`000000oooo
0?ooo`0Y0?ooo`007P3oool00`000000oooo0?ooo`0C0?ooo`@00000:@3oool2000000T0BS=W00@0
000006TkP000000000002`1k>Vd00`000000YF:00:ERP0090:ERP0030000002hKgd0^6mm00L0^6mm
00<000000<^2P03;PX001`3;PX000`000000iiN90>NGR@070>NGR@/0ojjH00<000000?o4Z@3oa:T0
1P3oa:T2000000030?o6V@000000onBc00`0onBc00<000000?[oa@3jolD01P3jolD01@000000mONj
0000003PomX0000005<0oooo00<000000?ooo`3oool03P3oool00`000000oooo0?ooo`0Y0?ooo`00
7P3oool00`000000oooo0?ooo`0@0?ooo`<00000;@3oool010000000<c=_0000000m<hD704XcI`05
0000001Y>h00JC^006TkP00000002@1k>Vd00`000000U5b90000000;0:ERP0030000002hKgd0^6mm
00H0^6mm00<000000<^2P03;PX001`3;PX000`000000iiN90>NGR@060>NGR@030000003o[YP0ojjH
00P0ojjH00<000000?o4Z@3oa:T02@3oa:T00`000000onBc0?oT/`0:0?oT/`<00000203jolD20000
0080h?oJ00<000000?ooo`3oool0DP3oool00`000000oooo0?ooo`0=0?ooo`030000003oool0oooo
02T0oooo000N0?ooo`030000003oool0oooo00`0oooo1000000a0?ooo`@000001P1:<fL00`000000
JC^006TkP00206TkP0030000001k>Vd0NcY]00D0NcY]00@0000009ALR@2DG8T0U5b90P00000:0:ER
P0030000002hKgd0^6mm00H0^6mm00<000000<^2P03;PX001P3;PX000`000000iiN90>NGR@060>NG
R@030000003o[YP0ojjH00L0ojjH00<000000?o4Z@3oa:T02@3oa:T00`000000onbm0000000:0?oT
/`040000003oold0ooo=000000P0n_o500@000000>3ofP3PomX00000E@3oool00`000000oooo0?oo
o`0=0?ooo`030000003oool0oooo02T0oooo000N0?ooo`030000003oool0oooo00T0oooo0`00000f
0?ooo`80000000<0?C>50000001:<fL00`1:<fL00`000000JC^006TkP00406TkP0030000001k>Vd0
NcY]00<0NcY]00<0000009ALR@2DG8T0102DG8T00`000000YF:00:ERP0070:ERP0030000002hKgd0
^6mm00D0^6mm500000080?n^V0030000003oa:T0olBY00P0olBY0P0000020?o/_@030000003oi;<0
onBc00L0onBc00D000000?ooc@3oold0ooo=000000070?[oa@040000003PomX0h?oJ000005L0oooo
00<000000?ooo`3oool03@3oool00`000000oooo0?ooo`0X0?ooo`007@3oool00`000000oooo0?oo
o`060?ooo`@00000>P3oool20000000303dcQ@000000BS=W0080BS=W00<0000006TkP01Y>h001@1Y
>h02000000<0NcY]00<0000009ALR@2DG8T01@2DG8T00`000000YF:00:ERP0070:ERP0030000002h
Kgd0^6mm00@0000000<0`8VL0000003@U9h01`3@U9h00`000000kJ6S0>fQX`050>fQX`040000003o
[j`00000000000H0ojjH00<000000?o4Z@3oa:T01`3oa:T00`000000onbm0?o/_@030?o/_@030000
003oi;<0onBc00@0onBc0P0000040?ooc@030000003jolD0n_o500<0n_o50`0000020>3ofP030000
003oool0oooo05H0oooo00<000000?ooo`3oool0303oool00`000000oooo0?ooo`0X0?ooo`007@3o
ool00`000000oooo0?ooo`030?ooo`<00000?P3oool0100c<fl0000003dcQ@0m<hD20000000304Xc
I`000000JC^000P0JC^000<0000007/jK@0000002@2DG8T00`000000YF:00:ERP0060:ERP0<00000
1P30RI`00`000000d9BN0=2DWP050=2DWP030000003]XJ<0kJ6S00@0kJ6S00<000000?n_[03o[j`0
0P3o[j`300000080ojjH00<000000?o4Z@3oa:T01`3oa:T00`000000onbm0?o/_@040?o/_@030000
003oi;<0onBc00<0onBc00<000000?ooc@3oold0103oold00`000000n_o50?[oa@020?[oa@030000
003Von0000000080h?oJ00<000000?ooo`3oool0E`3oool00`000000oooo0?ooo`0<0?ooo`030000
003oool0oooo02P0oooo000M0?ooo`030000003oool0000000<00000@P3oool2000000<0?C>50P00
000:06TkP0030000002DG8T0U5b900T0U5b90P0000040:ERP0<0000000<0]86N00000030RI`01@30
RI`00`000000d9BN0=2DWP050=2DWP030000003]XJ<0kJ6S00@0kJ6S00<000000?n_[03o[j`01@3o
[j`2000000T0olBY00<000000?o/_@3ok;d01P3ok;d01@000000onBc0?oT/`3oi;<0000000L0ooo=
00D000000?[oa@3jolD0n_o5000000020>Koh0030000003PomX0000005/0oooo00<000000?ooo`3o
ool02`3oool00`000000oooo0?ooo`0X0?ooo`007@3oool2000004L0oooo0P00000303dcQ@030000
001Y>h00JC^000P0JC^00`00000;09ALR@030000002UHX00000000800000102dPIh00`000000`8VL
0<29W0040<29W0030000003@U9h0d9BN00@0d9BN00<000000>fQX`3]XJ<00`3]XJ<00`000000ojn/
0?n_[0060?n_[0040000003o_[L00000000000D0olBY0P0000090?o/_@040000003oi;<000000000
00P0ooo=00@000000?[oa@00000000000P3Von000`000000h?oJ0000001M0?ooo`030000003oool0
oooo00X0oooo00<000000?ooo`3oool0:03oool001h0oooo00<000000?ooo`3oool0AP3oool00`00
0000?C>503dcQ@0203dcQ@800000201Y>h000`000000QefH08MMV002000000X0U5b90P0000070;B1
WP0300000030RI`0`8VL00<0`8VL00<000000=2DWP3@U9h0103@U9h00`000000kJ6S0>fQX`030>fQ
X`030000003o[j`0ojn/00D0ojn/00<000000?nn]`3o_[L00P3o_[L200000080olBY00<000000?o/
_@3ok;d02P3ok;d00`000000ooo=0?ooc@080?ooc@8000000`3Von000`000000h?oJ0000001N0?oo
o`030000003oool0oooo00X0oooo00<000000?ooo`3oool0:03oool001l0oooo0P0000170?ooo`06
0000000m<hD0?C>503dcQ@000000GdNI0P00000606TkP00300000027GIP0QefH0080QefH0P000007
09ALR@040000002ZOJ<00000000000L0]86N00<000000<29W030RI`00`30RI`00`000000d9BN0=2D
WP030=2DWP030000003]XJ<0kJ6S00<0kJ6S00<000000?n_[03o[j`0103o[j`00`000000okjg0?nn
]`050?nn]`8000002`3ok;d3000000T0ooo=0P0000040>Koh0800000H03oool00`000000oooo0?oo
o`090?ooo`030000003oool0oooo02P0oooo000Q0?ooo`030000003oool0oooo04D0oooo00D00000
03dcQ@0m<hD0?C>50000000205m7V@030000001Y>h00JC^00080JC^000<0000008MMV027GIP01@27
GIP2000000D0U5b9102ZOJ<00`000000]86N0;B1WP050;B1WP0300000030RI`0`8VL0080`8VL00<0
00000=2DWP3@U9h00`3@U9h00`000000kJ6S0>fQX`020>fQX`030000003o[j`0ojn/00@0ojn/00<0
00000?nn]`3o_[L01@3o_[L2000000030?oFa0000000onbm00L0onbm0P0000020?ood@030000003o
old0ooo=00D0ooo=100000030>Koh0800000HP3oool00`000000oooo0?ooo`090?ooo`030000003o
ool0oooo02L0oooo000R0?ooo`030000003oool0oooo04D0oooo0P0000000`0m<hD0000000000002
05m7V@8000000P1Y>h000`000000QefH08MMV00808MMV0040000002DG8T0U5b9000000D0ZWfS0P00
00060;B1WP0300000030RI`0`8VL0080`8VL00<000000=2DWP3@U9h00P3@U9h00`000000kJ6S0>fQ
X`020>fQX`030000003o[j`0ojn/00<0ojn/00<000000?nn]`3o_[L01@3o_[L01@000000omK40?oF
a03oe/@0000000H0onbm0P0000040?ood@800000103oold3000000030>coi0000000i_oP00<0i_oP
00<000000?ooo`3oool0H@3oool00`000000oooo0?ooo`090?ooo`030000003oool0oooo02L0oooo
000S0?ooo`030000003oool0oooo04H0oooo00<0000003dcQ@000000101OAiT3000000/0QefH0`00
00070:YmX`8000001@2dPIh00`000000`8VL0<29W00800000080kJ6S00<000000?n_[03o[j`00`3o
[j`00`000000okjg0?nn]`040?nn]`8000001@3oe/@010000000onbm0?o/_@3ok;d2000000L0oooA
00<000000?ooc@3oold00`0000030>coi0050000003Von00i_oP0>Koh0000000I@3oool00`000000
oooo0?ooo`080?ooo`030000003oool0oooo02L0oooo000T0?ooo`800000A`3oool00`000000?C>5
0000000505m7V@8000002`27GIP010000000XWf/0000000000070:YmX`030000002dPIh0]86N00<0
]86N0P0000000`0c<c<000000000000303<c<`030000000c<c<0000000<000000`3o[j`00`000000
okjg0?nn]`030?nn]`8000001`3oe/@010000000onbm0000000000090?ood@@00000103/on@00`00
0000i_oP0>Koh002000006H0oooo00<000000?ooo`3oool0203oool00`000000oooo0?ooo`0W0?oo
o`009P3oool00`000000oooo0?ooo`150?ooo`8000001P1OAiT4000000P0QefH00@000000:9m[02R
OJ`0XWf/0P0000060:YmX`80000000D0]86N000000000000<c<c0000000203<c<`050000000c<c<0
<c<c03<c<`0000000P0c<c<00`000000<c<c03<c<`03000000D0okjg00<000000?oFa03oe/@01`3o
e/@2000000X0oooA0`0000050>coi080000000<0i_oP0000003oool0J03oool00`000000oooo0?oo
o`070?ooo`030000003oool0oooo02L0oooo000W0?ooo`030000003oool0oooo04D0oooo0`000004
05m7V@040000001oIJT0OfFY07mUZ@<000001027GIP00`000000XWf/0:9m[0040:9m[0<000001@2Z
OJ<00`000000<c<c03<c<`0203<c<`040000000c<c<0000000000080<c<c00@0000003<c<`0c<c<0
00000P0c<c<20000000403<c<`00000000000?nn]`8000001`3oe/@3000000030?oleP000000oooA
00H0oooA100000070>coi0030000003Von00000006/0oooo00<000000?ooo`3oool01P3oool00`00
0000oooo0?ooo`0W0?ooo`00:03oool2000004L0oooo0`00000305m7V@030000001oIJT0OfFY00<0
OfFY0`0000000`27GIP000000:9m[0080:9m[08000000P2ZOJ<010000000<c<c00000000000303<c
<`030000000c<c<0000000@0<c<c00@0000003<c<`0c<c<00000100c<c<2000000D0omK410000004
0?oleP030000003oom40oooA0080oooA0`0000030?oolP030000003/on@0k?oT00@0k?oT0`00001/
0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool09`3oool002X0oooo00<000000?oo
o`3oool0A@3oool010000000G5Zc00000000000205m7V@030000001oIJT0OfFY00D0OfFY10000009
0:9m[0<000000`0c<c<200000080<c<c100000000`0c<c<0000003<c<`0200000080<c<c0`000000
100c<c<000000000003oe/@3000000P0oocF00<000000?ood@0000000P0000050?oolP030000003/
on@0k?oT00@0k?oT0P00001_0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool09P3o
ool002/0oooo00<000000?ooo`3oool0A@3oool00`000000G5Zc05aJ/`03000000P0OfFY0P000000
0`2MP[L0000000000004000000<0XWf/00<0000003<c<`0c<c<010000000100c<c<000000000000c
<c<40000000303<c<`000000<c<c00<000000P0c<c<5000000P0oocF1@0000070?oolP040000003/
on@0k?oT0>coi0D00000L@3oool00`000000oooo0?ooo`050?ooo`030000003oool0oooo02H0oooo
000/0?ooo`030000003oool0oooo04D0oooo0P00000205aJ/`@000001P1oIJT00`000000WH:g09f2
]`0509f2]aX000000`0c<c<010000000oocF0?oleP3oo=H6000000<0oooh00<000000?oolP3ooo80
1P3ooo87000007<0oooo00<000000?ooo`3oool01@3oool00`000000oooo0?ooo`0V0?ooo`00;@3o
ool2000004H0oooo0P00000305aJ/`L0000000<0OfFY0000000000002P2MP[L00`000000<c<c03<c
<`0303<c<aL00000203oooP00`000000ooob0?oolP040?oolP@000000`3Bool2000007D0oooo00<0
00000?ooo`3oool0103oool00`000000oooo0?ooo`0V0?ooo`00;`3oool00`000000oooo0?ooo`15
0?ooo`030000001LF[<0G5Zc0080G5Zc00<0000007ed_@1mM;d00P1mM;dD0000000303<c<`000000
000000/00000100c<c<00`000000oooh0?oon0090?oon0030000003ooo80000000H000000`3Bool2
000007P0oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0V0?ooo`00<03oool00`00
0000oooo0?ooo`150?ooo`8000000`1LF[<00`000000OGBm07ed_@0407ed_@030000002LRl@0W8_4
00T0W8_400<0000003<c<`0c<c<00`0000001@0c<c<00000000000000000<c<c0080000000@0<c<c
00000000000000000P0c<c<B000000@0eooo00@000000=;oo`3Bool0d_oo0P00001j0?ooo`030000
003oool0oooo00<0oooo00<000000?ooo`3oool09P3oool00340oooo00<000000?ooo`3oool0AP3o
ool6000000D0OGBm0P00000809b;a0@000000`0c<c<20000000503<c<`000000<c<c0000000c<c<0
0P00000203<c<`8000000P0c<c<00`000000g?oo0=coo`080=coo`8000001P3Gool00`000000d_oo
0=;oo`02000007d0oooo00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0V0?ooo`00<P3o
ool2000004L0oooo2@00000307ed_@040000002LRl@0W8_409b;a0@000000`2OUmH20000000303<c
<`000000<c<c0080<c<c00<0000003<c<`0000000`0c<c<00`000000<c<c03<c<`07000000D0g?oo
0P0000060=Ooo`D00000P03oool00`000000oooo0?ooo`020?ooo`030000003oool0oooo02D0oooo
000d0?ooo`030000003oool0oooo04@0oooo00@000000?ooo`3oool0oooo3000000809nGeP<00000
0P0c<c<01P000000<c<c03<c<`0c<c<0000003<c<`D000001P37gol@00000880oooo00<000000?oo
o`3oool00P3oool00`000000oooo0?ooo`0U0?ooo`00=@3oool00`000000oooo0?ooo`130?ooo`03
0000003oool0oooo00@0oooo1000000408:7d@<000000`2OUmH3000000<0YJCh2@0000020;[3o`80
00001`37gol2000000H0`_oo1@0000250?ooo`050000003oool0oooo0?ooo`0000009`3oool003H0
oooo00<000000?ooo`3oool0@P3oool00`000000oooo0?ooo`060?ooo`@000001022Qm44000000L0
YJCh00<000000:nbo`2_/_l00`2_/_l00`000000^/?o0;[3o`030;[3o`8000000`37gol2000000D0
`_oo1@0000280?ooo`050000003oool0oooo0?ooo`0000009`3oool003L0oooo0P0000120?ooo`03
0000003oool0oooo00T0oooo1@00000408fMlP@000000`2UY?P00`000000[k;o0:nbo`030:nbo`03
0000002j`ol0^/?o0080^/?o1`0000040<;oo`D00000R`3oool010000000oooo0?ooo`00000W0?oo
o`00>@3oool00`000000oooo0?ooo`0o0?ooo`030000003oool0oooo00h0oooo1P00000208fMlPl0
00000`2^b_l800000900oooo00<000000?ooo`0000009`3oool003X0oooo00<000000?ooo`3oool0
?P3oool00`000000oooo0?ooo`0D0?oooa@00000V03oool00`000000oooo0000000W0?ooo`00>`3o
ool00`000000oooo0?ooo`0m0?ooo`030000003oool0oooo0<40oooo00<000000?ooo`0000009P3o
ool003`0oooo0P00000m0?ooo`030000003oool0oooo0<80oooo0P00000V0?ooo`00?P3oool00`00
0000oooo0?ooo`0j0?ooo`030000003oool0oooo0<80oooo0P00000V0?ooo`00?`3oool00`000000
oooo0?ooo`0i0?ooo`030000003oool0oooo0<40oooo0`00000V0?ooo`00@03oool2000003P0oooo
00<000000?ooo`3oool0_P3oool4000002T0oooo00120?ooo`030000003oool0oooo03D0oooo00<0
00000?ooo`3oool0^@3oool5000002d0oooo00130?ooo`030000003oool0oooo03@0oooo00<00000
0?ooo`3oool0]@3oool400000380oooo00140?ooo`030000003oool0oooo03<0oooo00<000000?oo
o`3oool0/03oool5000003H0oooo00150?ooo`800000<`3oool00`000000oooo0?ooo`2/0?ooo`@0
0000>`3oool004L0oooo00<000000?ooo`3oool0<03oool00`000000oooo0?ooo`2W0?ooo`D00000
?`3oool004P0oooo00<000000?ooo`3oool0;`3oool00`000000oooo0?ooo`2S0?ooo`@00000A03o
ool004T0oooo00<000000?ooo`3oool0;P3oool00`000000oooo0?ooo`2O0?ooo`@00000B03oool0
04X0oooo0P00000^0?ooo`030000003oool0oooo09X0oooo1@00001<0?ooo`00C03oool00`000000
oooo0?ooo`0[0?ooo`030000003oool0oooo09H0oooo1000001A0?ooo`00C@3oool00`000000oooo
0?ooo`0Z0?ooo`030000003oool0oooo0940oooo1@00001E0?ooo`00CP3oool00`000000oooo0?oo
o`0Y0?ooo`030000003oool0oooo08d0oooo1000001J0?ooo`00C`3oool2000002T0oooo00<00000
0?ooo`3oool0R03oool5000005h0oooo001A0?ooo`030000003oool0oooo02H0oooo00<000000?oo
o`3oool0Q03oool4000006<0oooo001B0?ooo`030000003oool0oooo02D0oooo00<000000?ooo`3o
ool0O`3oool5000006L0oooo001C0?ooo`030000003oool0oooo02@0oooo00<000000?ooo`3oool0
N`3oool4000006`0oooo001D0?ooo`800000903oool00`000000oooo0?ooo`1f0?ooo`D00000L03o
ool005H0oooo00<000000?ooo`3oool08@3oool00`000000oooo0?ooo`1b0?ooo`@00000M@3oool0
05L0oooo00<000000?ooo`3oool07`3oool00`000000oooo0?ooo`1^0?ooo`D00000N@3oool005P0
oooo0P00000O0?ooo`030000003oool0oooo06X0oooo1000001n0?ooo`00FP3oool00`000000oooo
0?ooo`0L0?ooo`030000003oool0oooo06D0oooo1@0000220?ooo`00F`3oool00`000000oooo0?oo
o`0K0?ooo`030000003oool0oooo0640oooo100000270?ooo`00G03oool00`000000oooo0?ooo`0J
0?ooo`030000003oool0oooo05d0oooo1000002;0?ooo`00G@3oool2000001X0oooo00<000000?oo
o`3oool0F03oool5000008l0oooo001O0?ooo`030000003oool0oooo01L0oooo00<000000?ooo`3o
ool0E03oool4000009@0oooo001P0?ooo`030000003oool0oooo01H0oooo00<000000?ooo`3oool0
C`3oool5000009P0oooo001Q0?ooo`030000003oool0oooo01D0oooo00<000000?ooo`3oool0B`3o
ool4000009d0oooo001R0?ooo`8000005@3oool00`000000oooo0?ooo`160?ooo`D00000X@3oool0
06@0oooo00<000000?ooo`3oool04P3oool00`000000oooo0?ooo`120?ooo`@00000YP3oool006D0
oooo00<000000?ooo`3oool04@3oool00`000000oooo0?ooo`0m0?ooo`D00000ZP3oool006H0oooo
00<000000?ooo`3oool0403oool00`000000oooo0?ooo`0i0?ooo`@00000[`3oool006L0oooo0P00
000@0?ooo`030000003oool0oooo03@0oooo1@00002c0?ooo`00J@3oool00`000000oooo0?ooo`0=
0?ooo`030000003oool0oooo0300oooo1000002h0?ooo`00JP3oool00`000000oooo0?ooo`0<0?oo
o`030000003oool0oooo02/0oooo1@00002l0?ooo`00J`3oool00`000000oooo0?ooo`0;0?ooo`03
0000003oool0oooo02L0oooo100000310?ooo`00K03oool2000000/0oooo00<000000?ooo`3oool0
8P3oool500000<D0oooo001^0?ooo`030000003oool0oooo00L0oooo00<000000?ooo`3oool07`3o
ool400000<X0oooo001_0?ooo`030000003oool0oooo00H0oooo00<000000?ooo`3oool06`3oool4
00000<h0oooo001`0?ooo`8000001P3oool00`000000oooo0?ooo`0F0?ooo`D00000dP3oool00780
oooo00<000000?ooo`3oool00`3oool00`000000oooo0?ooo`0B0?ooo`@00000e`3oool007<0oooo
00<000000?ooo`3oool00P3oool00`000000oooo0?ooo`0=0?ooo`D00000f`3oool007@0oooo00D0
00000?ooo`3oool0oooo0000000;0?ooo`@00000h03oool007D0oooo0P0000000`3oool000000?oo
o`050?ooo`D00000i03oool007L0oooo0P0000020?ooo`@00000j@3oool007P0oooo0`00003]0?oo
o`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?oo
o`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?oo
o`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?oo
o`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?oo
o`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?oo
o`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?oo
o`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?oo
o`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?oo
o`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?oo
o`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?ooo`00o`3ooomY0?oo
o`00\
\>"]],

Cell["Fig. 5.10 Four random whistler-wave-packet trajectories. ", "Caption",
  CellTags->"Fig. 5.10"],

Cell[TextData[{
  StyleBox["(20)",
    FontWeight->"Bold"],
  " Moving boundary conditions present special difficulties, but can often be \
put in standard form by means of a coordinate transformation. Consider the \
following example. A plucked uniform string, of initial length ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[\(L\_o\),
            "TraditionalForm"], ","}], TraditionalForm]]],
  " is initially vibrating in its lowest mode with ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(y(x, 
          t)\  = \ \(sin(\[Pi]\ x/L\_o)\)\ cos\ \[Omega]\_o\ t\)\(,\)\)\)]],
  " where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_o\  = \ \[Pi]\ c/L\_o\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  " is the propagation speed for waves on the string. For ",
  Cell[BoxData[
      \(TraditionalForm\`t > 0\)]],
  ", the Dirichlet boundary condition at ",
  Cell[BoxData[
      \(TraditionalForm\`x = L\_o\)]],
  " begins to move according to ",
  Cell[BoxData[
      \(TraditionalForm\`y(L(t), t) = 0\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`L(t) = \ L\_o - \ \(\(v\)\(\ \)\(t\)\(\ \)\)\)]],
  ". This can be accomplished by running one's finger along the string at \
speed ",
  Cell[BoxData[
      \(TraditionalForm\`v\)]],
  ".  Solve this problem by first putting it in standard form through the \
transformation",
  Cell[BoxData[
      FormBox[
        RowBox[{" ", 
          FormBox[\(x\&_ = x/\(L(t)\)\),
            "TraditionalForm"]}], TraditionalForm]]],
  ". In these coordinates the boundary conditions are stationary, ",
  Cell[BoxData[
      \(TraditionalForm\`y(0, t) = \(y(1, t) = 0\)\)]],
  ", but"
}], "Text",
  CellTags->"i:104"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Show that  the wave equation becomes"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(\(D\&^\^2\) \(y(x\&_, t)\)\), "=", 
          RowBox[{\(c\^2\/\(\(L\^2\)(t)\)\), 
            FractionBox[\(\[PartialD]\^2\), \(\[PartialD]x\&_\^2\),
              MultilineFunction->None], \(y(x\&_, t)\)}]}], 
        TraditionalForm]]],
  ","
}], "NE2",
  CellTags->"(5.2.64)"],

Cell[TextData[{
  "where the operator ",
  Cell[BoxData[
      \(TraditionalForm\`D\&^ \[Congruent] \[PartialD]\/\[PartialD]t - \
\(\(x\&_\ \(\(L\& . \)(t)\)\)\/\(L(t)\)\) \[PartialD]\/\[PartialD]x\&_\)]],
  ",  and the time derivative is at fixed ",
  Cell[BoxData[
      \(TraditionalForm\`x\&_\)]],
  ". Hint: Use the following identities:"
}], "Text"],

Cell[TextData[{
  "\t\t ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(\[PartialD]\/\[PartialD]x\) \(y(x\&_, 
              t)\)\)\( | \_t\)\) = \[PartialD]x\&_\/\[PartialD]x\( | \_t\)\(\
\[PartialD]\/\[PartialD]x\&_\) \(y(x\&_, t)\)\( | \_t\)\)]],
  ","
}], "Text"],

Cell[TextData[{
  "\t\t ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(\[PartialD]\/\[PartialD]t\) \(y(x\&_, 
              t)\)\)\( | \_x\)\) = \(\[PartialD]\/\[PartialD]t\) \(y(x\&_, 
              t)\)\( | \_x\&_\)\(+\(\[PartialD]x\&_\/\[PartialD]t\)\)\( | \_x\
\)\ \(\[PartialD]\/\[PartialD]x\&_\) \(y(x\&_, t)\)\( | \_t\) . \)]]
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " This problem is amenable to WKB analysis, provided that ",
  Cell[BoxData[
      \(TraditionalForm\`v << \)]],
  Cell[BoxData[
      \(TraditionalForm\`c\)]],
  ". The solution can be written in the approximate form ",
  Cell[BoxData[
      \(TraditionalForm\`y(x\&_, t) = 
        Re[\(C(x\&_, 
                t)\) \[ExponentialE]\^\(\(-\[ImaginaryI]\)\ \
\(\[Integral]\_0\%t\( \[Omega](t)\) \[DifferentialD]t\)\)] 
          sin\ \[Pi]\ x\&_\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega](t) = \[Pi]\ c/\(L(t)\)\)]],
  ", and ",
  Cell[BoxData[
      \(TraditionalForm\`C(x\&_, t)\)]],
  " is a relatively slowly varying (complex) amplitude. In the limit that ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(v/c\)\(\ \)\)\)]],
  "<<1, show that ",
  Cell[BoxData[
      \(TraditionalForm\`C(x\&_, t)\)]],
  " satisfies the following first-order PDE:"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\ \)\(\((tan\[Pi]\ x\&_)\)\ \[PartialD]\ C\/\
\[PartialD]t - \ \ \[ImaginaryI]\ \(c\/\(L(
                  t)\)\) \[PartialD]\ C\/\[PartialD]x\&_ = \(\((\[Pi]\ x\&_\ \
\  + 1\/2\ tan\ \[Pi]\ x\&_)\)\(\ \)\(L\& . \/L\) \(C\)\(\ \)\)\)\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " First-order PDEs of this type can be solved analytically using the method \
of characteristics. (See Chapter ",
  ButtonBox["7",
    ButtonData:>{"Chapter7.nb", None},
    ButtonStyle->"Hyperlink"],
  ".) ",
  StyleBox["DSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " can also solve this PDE analytically. Show that, for ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(v/c\ << 1\)\(,\)\)\)]],
  " the solution from  ",
  StyleBox["DSolve",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  "  that matches the proper initial conditions is  ",
  Cell[BoxData[
      \(TraditionalForm\`\(C(x, t)\)~1\)]],
  ", so that "
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`y(x, t) \[TildeEqual] 
        Cos\ \(\[Integral]\_0\%t\( \[Omega](
                t)\) \[DifferentialD]t\ \(sin(\[Pi]\ x/\(L(t)\))\)\)\)]],
  "."
}], "NE2",
  CellTags->"(5.2.65)"],

Cell[TextData[{
  StyleBox["(d)",
    FontWeight->"Bold"],
  " Use the ",
  StyleBox["Play",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " function to listen to the sound made by ",
  Cell[BoxData[
      \(TraditionalForm\`cos \(\[Integral]\_0\%t\( \[Omega](
              t)\) \[DifferentialD]t\)\)]],
  " for the case ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[
            RowBox[{\(L\_o\), "=", 
              RowBox[{"1", " ", 
                StyleBox["m",
                  FontSlant->"Plain"]}]}],
            "TraditionalForm"], ",", 
          FormBox[
            RowBox[{"c", "=", 
              RowBox[{"300", " ", 
                RowBox[{
                  StyleBox["m",
                    FontSlant->"Plain"], "/", 
                  StyleBox["s",
                    FontSlant->"Plain"]}]}]}],
            "TraditionalForm"], ",", 
          RowBox[{"and", 
            RowBox[{
              FormBox[
                RowBox[{"v", "=", 
                  RowBox[{"2", " ", 
                    RowBox[{
                      StyleBox["m",
                        FontSlant->"Plain"], "/", 
                      StyleBox["s",
                        FontSlant->"Plain"]}]}]}],
                "TraditionalForm"], "."}]}]}], TraditionalForm]]]
}], "Text"],

Cell[TextData[{
  StyleBox["(e)",
    FontWeight->"Bold"],
  " Find the rate at which the string energy ",
  Cell[BoxData[
      \(TraditionalForm\`E(t)\)]],
  " increases, and using this show that ",
  Cell[BoxData[
      \(TraditionalForm\`\(E(t)\)/\(\[Omega](t)\)\)]],
  " is an adiabatic invariant.  "
}], "Text"],

Cell[TextData[{
  StyleBox["(f)",
    FontWeight->"Bold"],
  " Use the result from part (e) to determine the horizontal force ",
  Cell[BoxData[
      \(TraditionalForm\`F\)]],
  " that the string exerts on the boundary. "
}], "Text"],

Cell[TextData[{
  StyleBox["(21)",
    FontWeight->"Bold"],
  " Consider  the following  wave equation on the interval ",
  Cell[BoxData[
      \(TraditionalForm\`0 < x < L\)]],
  ":"
}], "Text",
  CellTags->"i:105"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\^2 y\/\[PartialD]t\^2 = \(\(c\^2\)(
            t)\) \(\(\[PartialD]\^2 y\/\[PartialD]x\^2\)\(.\)\)\)]]
}], "Text"],

Cell[TextData[{
  "This equation describes waves on a string for which the string tension ",
  Cell[BoxData[
      \(TraditionalForm\`T\)]],
  " and/or the mass density ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\)]],
  " vary in time, but the length ",
  Cell[BoxData[
      \(TraditionalForm\`L\)]],
  " is fixed. (For example,  tightening a guitar string by turning the peg \
both increases the tension and reduces the mass density as more string \
becomes wrapped around the peg. ) Boundary conditions are taken to be ",
  Cell[BoxData[
      \(TraditionalForm\`y = 0\)]],
  "at ",
  Cell[BoxData[
      \(TraditionalForm\`x = 0, L\)]],
  ", with an initial condition ",
  Cell[BoxData[
      \(TraditionalForm\`y(x, 0)\  = \ sin(\ n\ \[Pi]\ x/L)\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`\(y\& . \)(x, 0) = 0\)]],
  ". In other words, like the previous problem, the system starts off in a \
single normal mode. Assume that ",
  Cell[BoxData[
      \(TraditionalForm\`c(t)\)]],
  " varies in time slowly compared to the  frequencies of the  normal modes, \
find the WKB solution for the string motion, and show that"
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " the system remains in mode ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  ";"
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " mode frequency varies in time according to ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega](t) = n\ \[Pi]\ \(c(t)\)/L\)]],
  ";"
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " the adiabatic invariant for ",
  StyleBox["this",
    FontSlant->"Italic"],
  " system is ",
  Cell[BoxData[
      \(TraditionalForm\`\(E(t)\)\ \(\[Omega](t)\)/\(T(t)\)\)]],
  "."
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["5.3 Wave Action", "Subtitle",
  FontColor->RGBColor[1, 0, 0],
  CellTags->{"i:90", "c:32"}],

Cell[TextData[{
  "\tIn the previous discussion the energy conservation law, Eq. ",
  ButtonBox["(5.2.59)",
    ButtonData:>"(5.2.59)",
    ButtonStyle->"Hyperlink"],
  ", for wave-packet solutions to classical wave equations [equations of the \
form of Eq. ",
  ButtonBox["(5.1.63)",
    ButtonData:>"(5.1.63)",
    ButtonStyle->"Hyperlink"],
  "] was simply written down on the basis of intuition. In this section, we \
justify this equation using WKB theory. Also, we derive the equations of \
geometrical optics from first principles, and generalize the analysis to \
allow for time varying media, where energy is no longer conserved, and to \
Schr\[ODoubleDot]dinger-type wave equations with odd-order time derivatives. \
We consider in detail the evolution of the phase and amplitude of the waves, \
and finally,  we obtain a conservation equation for a different quantity, the \
",
  StyleBox["wave action.",
    FontSlant->"Italic"],
  " This quantity is equivalent to the energy for time-independent media, and \
is an adiabatic invariant for time-dependent problems."
}], "Text"],

Cell[CellGroupData[{

Cell["5.3.1 The Eikonal Equation", "Subsubtitle",
  CellTags->"c:35"],

Cell[TextData[{
  "\tConsider a general wave equation for a function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"f", "(", 
          RowBox[{
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[",",
              FontWeight->"Plain"], 
            StyleBox["t",
              FontWeight->"Plain"]}], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  ", of the form"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`D\&^\ f = 0\)]],
  ","
}], "NE3",
  CellTags->"(5.3.1)"],

Cell[TextData[{
  "where the linear differential operator ",
  Cell[BoxData[
      \(TraditionalForm\`D\&^\)]],
  " is a function of position and time, "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\(D\&^\)\(\ \)\)\)]],
  "=",
  Cell[BoxData[
      FormBox[
        RowBox[{"D", "(", 
          RowBox[{
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[",",
              FontWeight->"Plain"], 
            StyleBox["t",
              FontWeight->"Plain"], 
            StyleBox[",",
              FontWeight->"Plain"], 
            RowBox[{
              RowBox[{"-", 
                StyleBox["\[ImaginaryI]",
                  FontWeight->"Plain"]}], 
              StyleBox[" ",
                FontWeight->"Plain"], \(\[PartialD]\/\[PartialD]t\)}], 
            ",", \(\(-\[ImaginaryI]\) \[Del]\)}], ")"}], TraditionalForm]]],
  "."
}], "NE3",
  CellTags->"(5.3.2)"],

Cell[TextData[{
  "The function ",
  Cell[BoxData[
      \(TraditionalForm\`D\)]],
  " can have quite general form, but we assume here that ",
  Cell[BoxData[
      \(TraditionalForm\`D\&^\)]],
  " is ",
  StyleBox["Hermitian",
    FontSlant->"Italic"],
  " with respect to any two functions ",
  Cell[BoxData[
      FormBox[
        RowBox[{"f", "(", 
          RowBox[{
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[",",
              FontWeight->"Plain"], 
            StyleBox["t",
              FontWeight->"Plain"]}], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{"g", "(", 
          RowBox[{
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[",",
              FontWeight->"Plain"], 
            StyleBox["t",
              FontWeight->"Plain"]}], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  " that vanish at infinity sufficiently rapidly so that surface integrals at \
infinity can be neglected, and with respect to the following inner product : \
",
  Cell[BoxData[
      FormBox[
        RowBox[{\((f, g)\), " ", "=", " ", 
          RowBox[{"\[Integral]", 
            RowBox[{
              RowBox[{\(\[DifferentialD]\^3\), 
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"]}], \(\[DifferentialD]t\), 
              " ", \(f\^\(\(\ \)\(*\)\)\), "  ", "g", " "}]}]}], 
        TraditionalForm]]],
  ".  We will also assume that the dispersion relation resulting from this \
equation, ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Omega]", "=", 
          RowBox[{"\[Omega]", "(", 
            RowBox[{
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[",",
                FontWeight->"Plain"], 
              StyleBox["t",
                FontWeight->"Plain"], 
              StyleBox[",",
                FontWeight->"Plain"], 
              StyleBox["k",
                FontWeight->"Bold",
                FontSlant->"Plain"]}], 
            StyleBox[")",
              FontWeight->"Plain"]}]}], TraditionalForm]]],
  ", found by Fourier-transforming Eq. ",
  ButtonBox["(5.3.1)",
    ButtonData:>"(5.3.1)",
    ButtonStyle->"Hyperlink"],
  " and neglecting the time and space dependence in ",
  Cell[BoxData[
      \(TraditionalForm\`D\)]],
  ", provides ",
  StyleBox["real",
    FontSlant->"Italic"],
  " frequencies: the waves are neither damped nor growing in the domain of \
interest. "
}], "Text"],

Cell[TextData[{
  "\tIn what follows, we will sometimes find it useful to combine ",
  Cell[BoxData[
      FormBox[
        StyleBox["r",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  " into a single four-vector ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["z",
            FontWeight->"Bold",
            FontSlant->"Plain"], "=", 
          RowBox[{"(", 
            RowBox[{"t", ",", 
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"]}], ")"}]}], TraditionalForm]]],
  ".  Then ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(D\&^\)\(\ \)\(=\)\)\)]],
  Cell[BoxData[
      FormBox[
        RowBox[{"D", "(", 
          RowBox[{
            StyleBox["z",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[",",
              FontWeight->"Plain"], 
            RowBox[{
              RowBox[{"-", 
                StyleBox["\[ImaginaryI]",
                  FontWeight->"Plain"]}], 
              FractionBox["\[PartialD]", 
                RowBox[{"\[PartialD]", 
                  StyleBox["z",
                    FontWeight->"Bold",
                    FontSlant->"Plain"]}]]}]}], ")"}], TraditionalForm]]],
  ", and ",
  Cell[BoxData[
      FormBox[
        RowBox[{\((f, g)\), " ", "=", " ", 
          RowBox[{"\[Integral]", 
            RowBox[{
              RowBox[{\(\[DifferentialD]\^4\), 
                StyleBox["z",
                  FontWeight->"Bold",
                  FontSlant->"Plain"]}], " ", \(f\^\(\(\ \)\(*\)\)\), "  ", 
              "g"}]}]}], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  "\tWe assume that we are dealing with a wave packet, consisting of a \
localized disturbance with a well-defined central wavenumber and central \
frequency. In the WKB approximation, ",
  Cell[BoxData[
      \(TraditionalForm\`D\)]],
  " is a slowly varying function of position and time compared to this \
wavenumber and frequency. We take account of this by introducing an ordering \
parameter ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\)]],
  " that will be set equal to one at the end of the calculation: ",
  Cell[BoxData[
      FormBox[
        RowBox[{"D", "=", " ", 
          RowBox[{"D", "(", 
            RowBox[{
              StyleBox["z",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[",",
                FontWeight->"Plain"], 
              RowBox[{\(-\[Lambda]\), " ", "\[ImaginaryI]", 
                FractionBox["\[PartialD]", 
                  RowBox[{"\[PartialD]", 
                    StyleBox["z",
                      FontWeight->"Bold",
                      FontSlant->"Plain"]}]]}]}], ")"}], 
          StyleBox[" ",
            FontWeight->"Plain"]}], TraditionalForm]]],
  ". Thus, every time a derivative acts on ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " the result is multiplied by ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\)]],
  ", indicating that such derivatives are small. Also, we write the unknown \
function ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  " in terms of the eikonal ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  " via ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"f", "(", 
            StyleBox["z",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox[" ",
            FontWeight->"Plain"], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox[" ",
            FontWeight->"Plain"], 
          StyleBox[
            SuperscriptBox["\[ExponentialE]", 
              RowBox[{
                RowBox[{"S", "(", 
                  StyleBox["z",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], 
                  StyleBox[")",
                    FontWeight->"Plain"]}], 
                StyleBox["/",
                  FontWeight->"Plain"], 
                StyleBox["\[Lambda]",
                  FontWeight->"Plain"]}]],
            FontWeight->"Plain"]}], TraditionalForm]]],
  ".  The ordering parameter divides ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  ", indicating that ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  " is large: the phase of the wave varies rapidly compared to the length and \
time scales of variation of ",
  Cell[BoxData[
      \(TraditionalForm\`D\)]],
  ". Then to lowest-order in ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\)]],
  ", we keep only first-order derivatives of ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  " in Eq. ",
  ButtonBox["(5.3.1)",
    ButtonData:>"(5.3.1)",
    ButtonStyle->"Hyperlink"],
  " , writing "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(\[Lambda]\^n\) \[PartialD]\^n\ \[ExponentialE]\
\^\(S/\[Lambda]\)/\[PartialD]z\_i\^n\)\(\[TildeEqual]\)\(\(\(\[ExponentialE]\^\
\(S/\[Lambda]\)\)(\[PartialD]S/\[PartialD]z\_i)\)\^n\)\(\ \)\)\)]],
  ","
}], "NE3",
  CellTags->"(5.3.3)"],

Cell[TextData[{
  "where the subscript ",
  Cell[BoxData[
      \(TraditionalForm\`i = 0, 1, 2, 3\)]],
  " refers to the ",
  Cell[BoxData[
      \(TraditionalForm\`\((t, x, y, z)\)\)]],
  " components of ",
  Cell[BoxData[
      FormBox[
        StyleBox["z",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  ". Furthermore, we will expand ",
  Cell[BoxData[
      \(TraditionalForm\`S\)]],
  " in powers of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\)]],
  ", writing ",
  Cell[BoxData[
      FormBox[
        RowBox[{"S", " ", "=", " ", 
          RowBox[{
            RowBox[{\(S\_o\), " ", "+", " ", 
              RowBox[{"\[Lambda]", " ", 
                StyleBox[
                  RowBox[{"\[CapitalDelta]", 
                    StyleBox["S",
                      FontSlant->"Italic"]}]]}], "+"}], "..."}]}], 
        TraditionalForm]]],
  ",. To lowest-order, we drop ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{"\[CapitalDelta]", 
            StyleBox["S",
              FontSlant->"Italic"]}]], TraditionalForm]]],
  " and then, using Eq. ",
  ButtonBox["(5.3.3)",
    ButtonData:>"(5.3.3)",
    ButtonStyle->"Hyperlink"],
  " in  Eq. ",
  ButtonBox["(5.3.1)",
    ButtonData:>"(5.3.1)",
    ButtonStyle->"Hyperlink"],
  ",  we obtain"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          
          RowBox[{\(D\&^\ \[ExponentialE]\^\(S/\[Lambda]\)\), "\[TildeEqual]",
             
            RowBox[{\(\[ExponentialE]\^\(S\_o/\[Lambda]\)\), 
              RowBox[{"D", "(", 
                RowBox[{
                  StyleBox["z",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], 
                  StyleBox[",",
                    FontWeight->"Plain"], 
                  RowBox[{
                    RowBox[{"-", 
                      StyleBox["\[ImaginaryI]",
                        FontWeight->"Plain"]}], 
                    StyleBox[" ",
                      FontWeight->"Plain"], 
                    FractionBox[\(\[PartialD]S\_o\), 
                      RowBox[{"\[PartialD]", 
                        StyleBox["z",
                          FontWeight->"Bold",
                          FontSlant->"Plain"]}]]}]}], ")"}]}]}], "=", "0"}], 
        TraditionalForm]]],
  "."
}], "NE3",
  CellTags->"(5.3.4)"],

Cell[TextData[{
  "Equation ",
  ButtonBox["(5.3.4)",
    ButtonData:>"(5.3.4)",
    ButtonStyle->"Hyperlink"],
  " is often referred to as the ",
  StyleBox["eikonal equation",
    FontSlant->"Italic"],
  ". It is a first-order PDE for the eikonal ",
  Cell[BoxData[
      \(TraditionalForm\`S\_o\)]],
  "."
}], "Text",
  CellTags->"i:121"],

Cell[TextData[{
  "\tThe meaning of this equation becomes clear if we recall that ",
  Cell[BoxData[
      \(TraditionalForm\`S\_o\)]],
  " is related to the phase ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " of the wave by ",
  Cell[BoxData[
      \(TraditionalForm\`S\_o = \[ImaginaryI]\ \[Phi]\)]],
  " [neglecting an \"unimportant\" additive constant, the wave amplitude; see \
Eq. ",
  ButtonBox["(5.2.5)",
    ButtonData:>"(5.2.5)",
    ButtonStyle->"Hyperlink"],
  "]. Thus, we define the frequency and wavenumber of the wave via"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(\[PartialD]S\_o/\[PartialD]t\), "=", 
            RowBox[{\(-\[ImaginaryI]\), " ", 
              RowBox[{"\[Omega]", "(", 
                StyleBox["z",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox[")",
                  FontWeight->"Plain"]}]}]}], 
          StyleBox[",",
            FontWeight->"Plain"]}], TraditionalForm]]],
  " \n",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(\[PartialD]S\_o\), "/", 
            RowBox[{"\[PartialD]", 
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"]}]}], "=", 
          RowBox[{"\[ImaginaryI]", " ", 
            RowBox[{
              StyleBox["k",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox["(",
                FontWeight->"Plain"], 
              StyleBox["z",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[")",
                FontWeight->"Plain"]}]}]}], TraditionalForm]]],
  "."
}], "NE3",
  CellTags->"(5.3.5)"],

Cell[TextData[{
  "Integrating these equations with respect to ",
  Cell[BoxData[
      FormBox[
        StyleBox["r",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  ", we see that phase accumulates according to"
}], "Text"],

Cell[TextData[{
  "  ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"\[Phi]", "(", 
            StyleBox["z",
              FontWeight->"Bold",
              FontSlant->"Plain"], ")"}], "=", 
          RowBox[{
            RowBox[{"\[Integral]", 
              RowBox[{
                StyleBox["k",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], "\[CenterDot]", 
                RowBox[{"\[DifferentialD]", 
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"]}]}]}], 
            StyleBox[" ",
              FontWeight->"Plain"], 
            StyleBox["-",
              FontWeight->"Plain"], 
            StyleBox[" ",
              
              FontWeight->
                "Plain"], \(\[Integral]\[Omega] \[DifferentialD]t\)}]}], 
        TraditionalForm]]],
  ","
}], "NE3",
  CellTags->"(5.3.6)"],

Cell[TextData[{
  " which is the expected form for an inhomogeneous wave.  Also, Eq. ",
  ButtonBox["(5.3.4)",
    ButtonData:>"(5.3.4)",
    ButtonStyle->"Hyperlink"],
  " becomes "
}], "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"D", "(", 
            RowBox[{
              StyleBox["z",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[",",
                FontWeight->"Plain"], \(-\[Omega]\), ",", 
              StyleBox["k",
                FontWeight->"Bold",
                FontSlant->"Plain"]}], ")"}], "=", "0"}], TraditionalForm]]],
  "."
}], "NE3",
  CellTags->{"i:122", "(5.3.7)"}],

Cell[TextData[{
  "We can now see that ",
  Cell[BoxData[
      \(TraditionalForm\`D\)]],
  " is the dispersion function introduced previously. Solving this equation, \
we obtain the dispersion relation"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Omega]", "=", 
          RowBox[{"\[Omega]", "(", 
            RowBox[{
              StyleBox["z",
                FontWeight->"Bold",
                FontSlant->"Plain"], ",", 
              StyleBox["k",
                FontWeight->"Bold",
                FontSlant->"Plain"]}], 
            StyleBox[")",
              FontWeight->"Plain"]}]}], TraditionalForm]]],
  "."
}], "NE3",
  CellTags->"(5.3.8)"],

Cell[TextData[{
  "\tOften there are multiple solutions of Eq. ",
  ButtonBox["(5.3.7)",
    ButtonData:>"(5.3.7)",
    ButtonStyle->"Hyperlink"],
  ", implying that in fact several dispersion relations exist. If ",
  Cell[BoxData[
      \(TraditionalForm\`D\&^\)]],
  " is an ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  "th-order operator in time, then ",
  Cell[BoxData[
      \(TraditionalForm\`D\)]],
  " will be an ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  "th-order polynomial in ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\)]],
  " and there will be ",
  Cell[BoxData[
      \(TraditionalForm\`n\)]],
  " dispersion relations. These dispersion relations describe different \
waves, each of which must be kept in the general solution for ",
  Cell[BoxData[
      \(TraditionalForm\`f\)]],
  ". Remember that in what follows, we assume that all these dispersion \
relations provide real frequencies for given real ",
  Cell[BoxData[
      FormBox[
        StyleBox["k",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        StyleBox["z",
          FontSlant->"Plain"], TraditionalForm]],
    FontWeight->"Bold"],
  "."
}], "Text"],

Cell[TextData[{
  "\tThus, to lowest-order the WKB approximation consists of a nonuniform \
wave (or waves)  with phase fronts given by Eq. ",
  ButtonBox["(5.3.6)",
    ButtonData:>"(5.3.6)",
    ButtonStyle->"Hyperlink"],
  ",  and  with ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\)]],
  " and ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["k",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox[" ",
            FontWeight->"Bold"]}], TraditionalForm]]],
  "related by Eq. ",
  ButtonBox["(5.3.8)",
    ButtonData:>"(5.3.8)",
    ButtonStyle->"Hyperlink"],
  ". As one moves in space or time, the dispersion function ",
  Cell[BoxData[
      \(TraditionalForm\`D\)]],
  " varies slowly and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\)]],
  " and ",
  Cell[BoxData[
      FormBox[
        StyleBox["k",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " change so as to accommodate the variation, always satisfying ",
  Cell[BoxData[
      \(TraditionalForm\`D = 0\)]],
  ", according to the eikonal equation, Eq. ",
  ButtonBox["(5.3.7)",
    ButtonData:>"(5.3.7)",
    ButtonStyle->"Hyperlink"],
  "."
}], "Text",
  CellTags->"i:91"],

Cell[TextData[{
  " \tThe space and time dependence of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\)]],
  " and ",
  Cell[BoxData[
      FormBox[
        StyleBox["k",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " can be determined by noting that ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\^2 S\_o/\[PartialD]t \[PartialD]r\_i = \
\[PartialD]\^2 S\_o/\[PartialD]r\_i \[PartialD]t\)]],
  ", which , when combined with Eq. ",
  ButtonBox["(5.3.5)",
    ButtonData:>"(5.3.5)",
    ButtonStyle->"Hyperlink"],
  ", implies that"
}], "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]k\_i\/\[PartialD]t = \(-\(\[PartialD]\
\[Omega]\/\[PartialD]r\_i\)\)\)]],
  ". "
}], "NE3",
  CellTags->"(5.3.9)"],

Cell[TextData[{
  "Here, ",
  Cell[BoxData[
      \(TraditionalForm\`i = 1, 2, 3\)]],
  " refers to the ",
  Cell[BoxData[
      \(TraditionalForm\`\((x, y, z)\)\)]],
  " components of the vectors. Also, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\)]],
  " and ",
  Cell[BoxData[
      FormBox[
        StyleBox["k",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  "  are regarded here as a functions of only ",
  Cell[BoxData[
      FormBox[
        StyleBox["r",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  ", since ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(S\_o\), "=", 
          RowBox[{\(S\_o\), "(", 
            RowBox[{
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[",",
                FontWeight->"Plain"], 
              StyleBox["t",
                FontWeight->"Plain"]}], 
            StyleBox[")",
              FontWeight->"Plain"]}]}], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\)]],
  " and ",
  Cell[BoxData[
      FormBox[
        StyleBox["k",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " are given by derivatives of ",
  Cell[BoxData[
      \(TraditionalForm\`S\_o\)]],
  " via Eq. ",
  ButtonBox["(5.3.5)",
    ButtonData:>"(5.3.5)",
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text"],

Cell[TextData[{
  "\t Now we rewrite the partial derivative of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\)]],
  " in Eq. ",
  ButtonBox["(5.3.9)",
    ButtonData:>"(5.3.9)",
    ButtonStyle->"Hyperlink"],
  ", regarding ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\)]],
  " as a function of ",
  Cell[BoxData[
      FormBox[
        StyleBox["k",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " as well as ",
  Cell[BoxData[
      FormBox[
        StyleBox["r",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  ", as in Eq. ",
  ButtonBox["(5.3.8)",
    ButtonData:>"(5.3.8)",
    ButtonStyle->"Hyperlink"],
  ". This is allowed because ",
  Cell[BoxData[
      FormBox[
        StyleBox["k",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " is itself a function of ",
  Cell[BoxData[
      FormBox[
        StyleBox["r",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`t\)]],
  ", so that ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"\[Omega]", "(", 
            RowBox[{
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[",",
                FontWeight->"Plain"], 
              StyleBox["t",
                FontWeight->"Plain"]}], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{
            StyleBox["\[Omega]",
              FontWeight->"Plain"], 
            StyleBox["(",
              FontWeight->"Plain"], 
            RowBox[{
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[",",
                FontWeight->"Plain"], 
              StyleBox["t",
                FontWeight->"Plain"], 
              StyleBox[",",
                FontWeight->"Plain"], 
              RowBox[{
                StyleBox["k",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox["(",
                  FontWeight->"Plain"], 
                RowBox[{
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], 
                  StyleBox[",",
                    FontWeight->"Plain"], 
                  StyleBox["t",
                    FontWeight->"Plain"]}], 
                StyleBox[")",
                  FontWeight->"Plain"]}]}], 
            StyleBox[")",
              FontWeight->"Plain"]}]}], TraditionalForm]]],
  ". Then Eq. ",
  ButtonBox["(5.3.9)",
    ButtonData:>"(5.3.9)",
    ButtonStyle->"Hyperlink"],
  " becomes"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[PartialD]k\_i\/\[PartialD]t\), "=", 
          RowBox[{\(-\(\[PartialD]\[Omega]\/\[PartialD]r\_i\)\), 
            SubscriptBox[
              StyleBox["|",
                FontSize->10], 
              StyleBox["k",
                FontWeight->"Bold",
                
                FontSlant->
                  "Plain"]], \
\(-\(\[Sum]\+j\[PartialD]\[Omega]\/\[PartialD]k\_j\)\), 
            SubscriptBox[
              StyleBox["|",
                FontSize->10], 
              StyleBox["r",
                FontWeight->"Bold",
                
                FontSlant->
                  "Plain"]], \(\[PartialD]k\_j\/\[PartialD]r\_i\)}]}], 
        TraditionalForm]]],
  ". "
}], "NE3",
  CellTags->"(5.3.10)"],

Cell[TextData[{
  " However, ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]k\_j/\[PartialD]r\_i = \[PartialD]k\_i/\
\[PartialD]r\_j\)]],
  " because ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]\^2 S\_o/\[PartialD]r\_j \[PartialD]r\_i \
= \[PartialD]\^2 S\_o/\[PartialD]r\_i \[PartialD]r\_j\)]],
  ". This implies that Eq. ",
  ButtonBox["(5.3.10)",
    ButtonData:>"(5.3.10)",
    ButtonStyle->"Hyperlink"],
  " can be written as"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(\[PartialD]k\_i\/\[PartialD]t\), "+", 
            RowBox[{
              FractionBox[\(\[PartialD]\[Omega]\), 
                RowBox[{"\[PartialD]", 
                  StyleBox["k",
                    FontWeight->"Bold",
                    FontSlant->"Plain"]}]], 
              "\[CenterDot]", \(\[Del]k\_i\)}]}], "=", 
          RowBox[{\(-\(\[PartialD]\[Omega]\/\[PartialD]r\_i\)\), 
            SubscriptBox[
              StyleBox["|",
                FontSize->10], 
              StyleBox["k",
                FontWeight->"Bold",
                FontSlant->"Plain"]]}]}], TraditionalForm]]],
  " ."
}], "NE3",
  CellTags->"(5.3.11)"],

Cell[TextData[{
  "Since ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(\[PartialD]\[Omega]\), "/", 
            RowBox[{"\[PartialD]", 
              StyleBox["k",
                FontWeight->"Bold",
                FontSlant->"Plain"]}]}], 
          StyleBox[" ",
            FontWeight->"Plain"], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox[" ",
            FontWeight->"Plain"], 
          StyleBox[
            SubscriptBox["v", 
              StyleBox["g",
                FontWeight->"Plain"]],
            FontWeight->"Bold"]}], TraditionalForm]]],
  ", the ",
  "left-hand",
  " side can be seen to be a total time derivative of ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          SubscriptBox[
            StyleBox["k",
              FontWeight->"Plain"], 
            StyleBox["i",
              FontWeight->"Plain"]],
          FontWeight->"Bold"], TraditionalForm]]],
  " along a trajectory through space, moving with the group velocity (see \
Sec. ",
  ButtonBox["7.1.1",
    ButtonData:>{"Chapter7.nb", "c:4"},
    ButtonStyle->"Hyperlink"],
  " for a discussion of this representation of the total time derivative).  \
Therefore, we may write Eq. ",
  ButtonBox["(5.3.11)",
    ButtonData:>"(5.3.11)",
    ButtonStyle->"Hyperlink"],
  " as "
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          FractionBox[
            RowBox[{"\[DifferentialD]", 
              StyleBox["k",
                FontWeight->"Bold",
                FontSlant->"Plain"]}], \(\[DifferentialD]t\)], "=", 
          RowBox[{"-", 
            RowBox[{"\[Del]", 
              RowBox[{"\[Omega]", "(", 
                RowBox[{
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], 
                  StyleBox[",",
                    FontWeight->"Plain"], 
                  StyleBox["t",
                    FontWeight->"Plain"], 
                  StyleBox[",",
                    FontWeight->"Plain"], 
                  StyleBox["k",
                    FontWeight->"Bold",
                    FontSlant->"Plain"]}], 
                StyleBox[")",
                  FontWeight->"Plain"]}]}]}]}], TraditionalForm]]],
  " "
}], "NE3",
  CellTags->"(5.3.12)"],

Cell["along the trajectory given by ", "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FractionBox[
            RowBox[{"\[DifferentialD]", 
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"]}], \(\[DifferentialD]t\)], "=", 
          RowBox[{
            FractionBox["\[PartialD]", 
              RowBox[{"\[PartialD]", 
                StyleBox["k",
                  FontWeight->"Bold",
                  FontSlant->"Plain"]}]], 
            RowBox[{"\[Omega]", "(", 
              RowBox[{
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"], 
                StyleBox[",",
                  FontWeight->"Plain"], 
                StyleBox["t",
                  FontWeight->"Plain"], 
                StyleBox[",",
                  FontWeight->"Plain"], 
                StyleBox["k",
                  FontWeight->"Bold",
                  FontSlant->"Plain"]}], 
              StyleBox[")",
                FontWeight->"Plain"]}]}]}], TraditionalForm]]],
  "."
}], "NE3",
  CellTags->"(5.3.13)"],

Cell[TextData[{
  "These are the first two equations of geometrical optics.  A third \
equation, for the variation of ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\)]],
  " along this trajectory, can now be found  taking a differential of Eq. ",
  ButtonBox["(5.3.7)",
    ButtonData:>"(5.3.7)",
    ButtonStyle->"Hyperlink"],
  " :"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[DifferentialD]D\), " ", "=", " ", 
          RowBox[{"0", "=", 
            RowBox[{
              RowBox[{
                FractionBox[\(\[PartialD]D\), 
                  RowBox[{"\[PartialD]", 
                    StyleBox["z",
                      FontWeight->"Bold",
                      FontSlant->"Plain"]}]], "\[CenterDot]", 
                RowBox[{"\[DifferentialD]", 
                  StyleBox["z",
                    FontWeight->"Bold",
                    FontSlant->"Plain"]}]}], 
              StyleBox["+",
                
                FontWeight->
                  "Plain"], \(\(\[PartialD]D\/\[PartialD]\[Omega]\) \
\[DifferentialD]\[Omega]\), " ", "+", 
              RowBox[{
                FractionBox[\(\[PartialD]D\), 
                  RowBox[{"\[PartialD]", 
                    StyleBox["k",
                      FontWeight->"Bold",
                      FontSlant->"Plain"]}]], "\[CenterDot]", 
                RowBox[{"\[DifferentialD]", 
                  StyleBox["k",
                    FontWeight->"Bold",
                    FontSlant->"Plain"]}]}]}]}]}], TraditionalForm]]]
}], "Text"],

Cell[TextData[{
  "Dividing by ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]t\)]],
  ", and using Eqs. ",
  ButtonBox["(5.3.12)",
    ButtonData:>"(5.3.12)",
    ButtonStyle->"Hyperlink"],
  " and ",
  ButtonBox["(5.3.13)",
    ButtonData:>"(5.3.13)",
    ButtonStyle->"Hyperlink"],
  " along with the definition of ",
  Cell[BoxData[
      FormBox[
        StyleBox["z",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  ", we have"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{"0", " ", "=", 
          RowBox[{\(\[PartialD]D\/\[PartialD]t\), "+", " ", 
            RowBox[{
              FractionBox[\(\[PartialD]D\), 
                RowBox[{"\[PartialD]", 
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"]}]], "\[CenterDot]", 
              FractionBox[\(\[PartialD]\[Omega]\), 
                RowBox[{"\[PartialD]", 
                  StyleBox["k",
                    FontWeight->"Bold",
                    FontSlant->"Plain"]}]]}], 
            "+", \(\(\[PartialD]D\/\[PartialD]\[Omega]\) \[DifferentialD]\
\[Omega]\/\[DifferentialD]t\), "-", 
            RowBox[{
              FractionBox[\(\[PartialD]D\), 
                RowBox[{"\[PartialD]", 
                  StyleBox["k",
                    FontWeight->"Bold",
                    FontSlant->"Plain"]}]], "\[CenterDot]", 
              FractionBox[\(\[PartialD]\[Omega]\), 
                RowBox[{"\[PartialD]", 
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"]}]]}]}]}], TraditionalForm]]]
}], "Text"],

Cell[TextData[{
  "Dividing this in turn by ",
  Cell[BoxData[
      \(TraditionalForm\`\[PartialD]D/\[PartialD]\[Omega]\)]],
  ", and using the standard identity"
}], "Text"],

Cell[TextData[{
  "\t\t ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          FractionBox[
            RowBox[{\(\[PartialD]D\), "/", 
              RowBox[{"\[PartialD]", 
                StyleBox["z",
                  FontWeight->"Bold",
                  
                  FontSlant->
                    "Plain"]}]}], \(\[PartialD]D/\[PartialD]\[Omega]\)], "=", 
          
          RowBox[{
            RowBox[{"-", 
              FractionBox[\(\[PartialD]\[Omega]\), 
                RowBox[{"\[PartialD]", 
                  StyleBox["z",
                    FontWeight->"Bold",
                    FontSlant->"Plain"]}]]}], \( | \_D\)}]}], 
        TraditionalForm]]],
  ", \nwe obtain"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{"0", " ", "=", 
          RowBox[{\(-\(\[PartialD]\[Omega]\/\[PartialD]t\)\), "-", " ", 
            RowBox[{
              FractionBox[\(\[PartialD]\[Omega]\), 
                RowBox[{"\[PartialD]", 
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"]}]], "\[CenterDot]", 
              FractionBox[\(\[PartialD]\[Omega]\), 
                RowBox[{"\[PartialD]", 
                  StyleBox["k",
                    FontWeight->"Bold",
                    FontSlant->"Plain"]}]]}], 
            "+", \(\[DifferentialD]\[Omega]\/\[DifferentialD]t\), "+", 
            RowBox[{
              FractionBox[\(\[PartialD]\[Omega]\), 
                RowBox[{"\[PartialD]", 
                  StyleBox["k",
                    FontWeight->"Bold",
                    FontSlant->"Plain"]}]], "\[CenterDot]", 
              FractionBox[\(\[PartialD]\[Omega]\), 
                RowBox[{"\[PartialD]", 
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"]}]]}]}]}], TraditionalForm]]],
  ","
}], "Text"],

Cell[" which yields", "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]\[Omega]\/\[DifferentialD]t = \(-\(\
\[PartialD]\[Omega]\/\[PartialD]t\)\)\)]],
  ","
}], "NE3",
  CellTags->"(5.3.14)"],

Cell[TextData[{
  "where the total time derivative is again taken along the trajectory given \
by Eq. ",
  ButtonBox["(5.3.13)",
    ButtonData:>"(5.3.13)",
    ButtonStyle->"Hyperlink"],
  ". This shows that the central frequency of a wave packet is constant, \
unless ",
  Cell[BoxData[
      \(TraditionalForm\`D\)]],
  " has explicit time dependence so that ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Omega]", "(", 
          RowBox[{
            StyleBox["z",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[",",
              FontWeight->"Plain"], 
            StyleBox["k",
              FontWeight->"Bold",
              FontSlant->"Plain"]}], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  " also depends explicitly on time.  Equations ",
  ButtonBox["(5.3.12)",
    ButtonData:>"(5.3.12)",
    ButtonStyle->"Hyperlink"],
  "-",
  ButtonBox["(5.3.14)",
    ButtonData:>"(5.3.14)",
    ButtonStyle->"Hyperlink"],
  " are the equations of geometrical optics,  derived earlier for \
one-dimensional systems without explicit time dependence. "
}], "Text",
  CellTags->"i:115"],

Cell[TextData[{
  "\tThe solution of Eqs. ",
  ButtonBox["(5.3.12)",
    ButtonData:>"(5.3.12)",
    ButtonStyle->"Hyperlink"],
  "-",
  ButtonBox["(5.3.17)",
    ButtonData:>"(5.3.17)",
    ButtonStyle->"Hyperlink"],
  " can be used in Eq. ",
  ButtonBox["(5.3.6)",
    ButtonData:>"(5.3.6)",
    ButtonStyle->"Hyperlink"],
  " in order to determine the phase ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Phi]", "(", 
          RowBox[{
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[",",
              FontWeight->"Plain"], 
            StyleBox["t",
              FontWeight->"Plain"]}], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  " of the solution in the WKB limit.  The approach is as follows. We assume \
that we know the initial phase variation of the wave packet throughout space, \
",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"\[Phi]", "(", 
            RowBox[{
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[",",
                FontWeight->"Plain"], 
              StyleBox[\(t = 0\),
                FontWeight->"Plain"]}], 
            StyleBox[")",
              FontWeight->"Plain"]}], "=", 
          RowBox[{\(\[Phi]\_o\), "(", 
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], ")"}]}], TraditionalForm]]],
  ". Then, taking the spatial gradient  of this initial ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\_o\)]],
  " gives us the initial wavenumber ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox["k",
              FontWeight->"Bold",
              FontSlant->"Plain"], "(", 
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox[\(\[Del]\[Phi]\_o\),
            FontWeight->"Plain"]}], TraditionalForm]]],
  ", throughout space. We now integrate Eqs. ",
  ButtonBox["(5.3.12)",
    ButtonData:>"(5.3.12)",
    ButtonStyle->"Hyperlink"],
  "-",
  ButtonBox["(5.3.13)",
    ButtonData:>"(5.3.13)",
    ButtonStyle->"Hyperlink"],
  " forward in time, starting from all points in space, using these positions \
and their corresponding initial wavenumbers for the initial conditions to the \
ODEs. In principle, this allows us to determine the wavenumbers at all \
positions and times, ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["k",
            FontWeight->"Bold",
            FontSlant->"Plain"], "(", 
          RowBox[{
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[",",
              FontWeight->"Plain"], 
            StyleBox["t",
              FontWeight->"Plain"]}], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  ". We can then either solve the dispersion relation directly to obtain ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Omega]", "(", 
          RowBox[{
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[",",
              FontWeight->"Plain"], 
            StyleBox["t",
              FontWeight->"Plain"]}], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  ", or we can integrate Eq. ",
  ButtonBox["(5.3.14)",
    ButtonData:>"(5.3.14)",
    ButtonStyle->"Hyperlink"],
  " as well.  Since we now know both ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\)]],
  " and ",
  Cell[BoxData[
      FormBox[
        StyleBox["k",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " at all positions and times, we can integrate to determine ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"\[Phi]", "(", 
            RowBox[{
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[",",
                FontWeight->"Plain"], 
              StyleBox["t",
                FontWeight->"Plain"]}], 
            StyleBox[")",
              FontWeight->"Plain"]}], " "}], TraditionalForm]]],
  "using Eq. ",
  ButtonBox["(5.3.6)",
    ButtonData:>"(5.3.6)",
    ButtonStyle->"Hyperlink"],
  ". "
}], "Text",
  CellTags->"i:141"],

Cell[TextData[{
  "\tThis rather complex procedure can be carried out analytically only for a \
few simple cases [see Exercise (1)]. However, as a numerical method it can be \
both useful and enlightening.  As an example,  consider a wavetrain \
travelling in the ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(y\)\(-\)\)\)]],
  "direction toward an inhomogeneous region. Initially the  phase of this \
wavetrain is ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(\[Phi]\_o\), "(", 
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], ")"}], " ", "=", " ", 
          RowBox[{"\[Kappa]", " ", "y", Cell[""]}]}], TraditionalForm]]],
  ":"
}], "Text"],

Cell[BoxData[
    \(\(\[Phi]0[{x_, y_}]\  = \ \[Kappa]\ y;\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 5.29"],

Cell[TextData[{
  "Thus, the initial wavenumber of the wavetrain is ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            SubscriptBox["k", 
              StyleBox["o",
                FontWeight->"Plain"]],
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox[\(\((0, \[Kappa])\)\(.\)\(\ \)\),
            FontWeight->"Plain"]}], TraditionalForm]]]
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(k0[{x_, y_}]\  = {\ D[\[Phi]0[{x, y}], x], 
        D[\[Phi]0[{x, y}], y]}\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 5.30"],

Cell[BoxData[
    \({0, \[Kappa]}\)], "Output"]
}, Open  ]],

Cell[TextData[{
  "Before we integrate forward the geometrical optics equations, it is useful \
to introduce one more ODE that describes the rate of change of phase ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi]\)]],
  " along a wavepacket trajectory. By taking a differential of Eq. ",
  ButtonBox["(5.3.6)",
    ButtonData:>"(5.3.6)",
    ButtonStyle->"Hyperlink"],
  ", we find ",
  Cell[BoxData[
      FormBox[
        RowBox[{\(\[DifferentialD]\[Phi]\), " ", "=", " ", 
          RowBox[{
            RowBox[{
              StyleBox["k",
                FontWeight->"Bold",
                FontSlant->"Plain"], "\[CenterDot]", 
              RowBox[{"\[DifferentialD]", 
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"]}]}], " ", "-", 
            " ", \(\[Omega] \[DifferentialD]t\)}]}], TraditionalForm]]],
  ". Dividing by ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]t\)]],
  " and using Eq. ",
  ButtonBox["(5.3.13)",
    ButtonData:>"(5.3.13)",
    ButtonStyle->"Hyperlink"],
  " yields"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{\(\[DifferentialD]\[Phi]\/\(\(\[DifferentialD]t\)\(\ \)\)\), 
        "=", " ", 
        RowBox[{
          RowBox[{
            StyleBox["k",
              FontWeight->"Bold",
              FontSlant->"Plain"], "\[CenterDot]", 
            SubscriptBox[
              StyleBox["v",
                FontWeight->"Bold",
                FontSlant->"Plain"], "g"]}], "-", "\[Omega]", " "}]}], 
      TraditionalForm]]]], "NE3",
  CellTags->"(5.3.15)"],

Cell[TextData[{
  "We can integrate this ODE at the same time as the  equations for ",
  StyleBox["k",
    FontWeight->"Bold"],
  " and ",
  StyleBox["r",
    FontWeight->"Bold"],
  ", and so  keep track of the accumulation of phase along the trajectories. \
We now integrate forward these trajectories,  starting at a grid of points \
that cover the initial region of the wavetrain, assuming some dispersion \
relation ",
  Cell[BoxData[
      FormBox[
        RowBox[{"\[Omega]", "=", 
          RowBox[{"\[Omega]", "(", 
            RowBox[{
              StyleBox["k",
                FontWeight->"Bold"], 
              StyleBox[",",
                FontWeight->"Plain"], 
              StyleBox["r",
                FontWeight->"Plain"], 
              StyleBox[",",
                FontWeight->"Plain"], 
              StyleBox["t",
                FontWeight->"Plain"]}], 
            StyleBox[")",
              FontWeight->"Plain"]}]}], TraditionalForm]]],
  ":"
}], "Text"],

Cell[BoxData[
    RowBox[{
      StyleBox[\( (*\ define\ the\ group\ velocity*) \),
        FontColor->RGBColor[1, 0, 0]], 
      "\[IndentingNewLine]", \(vg[k_, 
          r_]\  := \ {D[\[Omega][{kx, ky}, r], kx], 
            D[\[Omega][{kx, ky}, r], ky]} /. {kx \[Rule] k[\([1]\)], 
            ky \[Rule] \ k[\([2]\)]}\)}]], "Input",
  ShowCellTags->True,
  CellTags->"Cell 5.31"],

Cell[BoxData[
    RowBox[{
      StyleBox[\( (*\ define\ the\ rate\ of\ change\ of\ k\ *) \),
        FontColor->RGBColor[1, 0, 0]], 
      "\[IndentingNewLine]", \(kp[k_, 
          r_]\  := \ \(-\ {D[\[Omega][k, {x, y}], x], 
              D[\[Omega][k, {x, y}], y]}\) /. {x \[Rule] \ r[\([1]\)], 
            y \[Rule] \ r[\([2]\)]}\)}]], "Input",
  ShowCellTags->True,
  CellTags->"Cell 5.32"],

Cell[BoxData[
    RowBox[{
      StyleBox[\( (*\ 
          integrate\ forward\ the\ equations\ of\ geometrical\ optics\ for\ a\
\ given\ initial\ position\ and\ wavenumber\ *) \),
        FontColor->RGBColor[1, 0, 0]], 
      "\[IndentingNewLine]", \(sol[r0_, k0_]\  := \ 
        NDSolve[{\(x'\)[
                t]\  \[Equal] \ \(vg[{kx[t], ky[t]}, {x[t], 
                    y[t]}]\)[\([1]\)], \[IndentingNewLine]\(y'\)[
                t]\  \[Equal] \ \(vg[{kx[t], ky[t]}, {x[t], 
                    y[t]}]\)[\([2]\)], \[IndentingNewLine]\(kx'\)[
                t]\  \[Equal] \ \(kp[{kx[t], ky[t]}, {x[t], 
                    y[t]}]\)[\([1]\)], \[IndentingNewLine]\(ky'\)[
                t]\  \[Equal] \ \(kp[{kx[t], ky[t]}, {x[t], 
                    y[t]}]\)[\([2]\)], \[IndentingNewLine]\(\[Phi]'\)[
                t]\  \[Equal] \ {kx[t], ky[t]} . 
                  vg[{kx[t], ky[t]}, {x[t], y[t]}] - \[Omega][{kx[t], 
                    ky[t]}, {x[t], y[t]}], \[IndentingNewLine]x[
                0]\  \[Equal] \ r0[\([1]\)], y[0] \[Equal] r0[\([2]\)], 
            kx[0] \[Equal] k0[\([1]\)], 
            ky[0] \[Equal] 
              k0[\([2]\)], \ \[Phi][0]\  \[Equal] \[Phi]0[r0]}, {x, y, kx, 
            ky, \[Phi]}, {t, 0, 10}]\)}]], "Input",
  ShowCellTags->True,
  CellTags->"Cell 5.33"],

Cell["\<\
To actually perform this numerical integration, we must choose some \
specific form for the dispersion relation. We choose the following \
form:\
\>", "Text"],

Cell[BoxData[
    \(\[Omega][k_, 
        r_]\  := \ \(\(Sqrt[k . k]\)\(\ \)\(c[r]\)\(\ \)\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 5.34"],

Cell[TextData[{
  "where the phase speed  ",
  Cell[BoxData[
      FormBox[
        RowBox[{"c", "(", 
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  " is "
}], "Text"],

Cell[BoxData[
    \(c[r_]\  := 
      3 - 2\ Tanh[\((\((y - 2)\)^2\  + \  .2  x^2)\)*3] /. {x \[Rule] 
            r[\([1]\)], y \[Rule] r[\([2]\)]}\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 5.35"],

Cell["This phase speed is plotted below:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot3D[c[{x, y}], {x, \(-2\), 2}, {y, 0, 4}, 
        PlotRange -> {0, 3}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 5.36"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[.02757 .24618 -12 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.17646 .18758 -11.7989 -9 ]
[.17646 .18758 .20112 0 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.50253 .05935 -5.27396 -9 ]
[.50253 .05935 .72604 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.78313 .12104 0 -6.13858 ]
[.78313 .12104 6 2.86142 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.9224 .33431 0 -5.93715 ]
[.9224 .33431 6 3.06285 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.02494 .25992 -6 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.0131 .33416 -6 -2.80073 ]
[.0131 .33416 0 6.19927 ]
[.00067 .41207 -6 -2.86695 ]
[.00067 .41207 0 6.13305 ]
[-0.0124 .49393 -6 -2.93688 ]
[-0.0124 .49393 0 6.06312 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(-2)] .02757 .24618 1 .93395 Mshowa
.18558 .19702 m
.19014 .20174 L
s
[(-1)] .17646 .18758 .96648 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.51046 .06981 m
.51442 .07504 L
s
[(1)] .50253 .05935 .75799 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(2)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.7708 .12553 m
.76464 .12778 L
s
[(1)] .78313 .12104 -1 .36413 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(2)] .8565 .23339 -1 .34028 Mshowa
.9099 .3383 m
.90365 .34029 L
s
[(3)] .9224 .33431 -1 .31937 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(4)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.75514 .10158 m
.75145 .10294 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.81573 .19425 m
.81201 .19555 L
s
.83006 .21617 m
.82633 .21745 L
s
.8578 .2586 m
.85407 .25986 L
s
.87123 .27915 m
.8675 .28039 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.92227 .35722 m
.91851 .3584 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(0)] .02494 .25992 1 -0.39157 Mshowa
.02537 .32952 m
.03151 .3272 L
s
[(1)] .0131 .33416 1 -0.37762 Mshowa
.013 .40759 m
.01917 .40535 L
s
[(2)] .00067 .41207 1 -0.3629 Mshowa
0 .48963 m
.0062 .48748 L
s
[(3)] -0.0124 .49393 1 -0.34736 Mshowa
.125 Mabswid
.03485 .26973 m
.03852 .26831 L
s
.03251 .28447 m
.03618 .28305 L
s
.03016 .29934 m
.03383 .29793 L
s
.02778 .31436 m
.03145 .31296 L
s
.02295 .34483 m
.02663 .34345 L
s
.0205 .36029 m
.02419 .35892 L
s
.01802 .37591 m
.02172 .37454 L
s
.01552 .39167 m
.01922 .39032 L
s
.01045 .42367 m
.01416 .42234 L
s
.00788 .43991 m
.01159 .43859 L
s
.00528 .45632 m
.00899 .45501 L
s
.00265 .47289 m
.00637 .47159 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.659 .748 .916 r
.38048 .64682 .40291 .66687 .44035 .65608 .41824 .63575 Metetra
.659 .748 .916 r
.41824 .63575 .44035 .65608 .47831 .64513 .45654 .62451 Metetra
.659 .748 .916 r
.45654 .62451 .47831 .64513 .5168 .63403 .49539 .61312 Metetra
.659 .748 .916 r
.49539 .61312 .5168 .63403 .55584 .62277 .53479 .60156 Metetra
.659 .748 .916 r
.53479 .60156 .55584 .62277 .59544 .61135 .57477 .58983 Metetra
.659 .748 .916 r
.57477 .58983 .59544 .61135 .63561 .59977 .61533 .57793 Metetra
.659 .748 .916 r
.61533 .57793 .63561 .59977 .67637 .58801 .65649 .56586 Metetra
.659 .748 .916 r
.65649 .56586 .67637 .58801 .71772 .57609 .69826 .55361 Metetra
.659 .748 .916 r
.69826 .55361 .71772 .57609 .75968 .56399 .74066 .54117 Metetra
.659 .748 .916 r
.74066 .54117 .75968 .56399 .80226 .55171 .78369 .52855 Metetra
.659 .748 .916 r
.78369 .52855 .80226 .55171 .84548 .53924 .82737 .51574 Metetra
.659 .748 .916 r
.82737 .51574 .84548 .53924 .88936 .52659 .87173 .50273 Metetra
.659 .748 .916 r
.87173 .50273 .88936 .52659 .9339 .51375 .91676 .48951 Metetra
.659 .748 .916 r
.91676 .48951 .9339 .51375 .97912 .50071 .9625 .4761 Metetra
.659 .748 .916 r
.35746 .62625 .38048 .64682 .41824 .63575 .39555 .61488 Metetra
.659 .748 .916 r
.39555 .61488 .41824 .63575 .45654 .62451 .4342 .60335 Metetra
.659 .748 .916 r
.4342 .60335 .45654 .62451 .49539 .61312 .4734 .59165 Metetra
.659 .748 .916 r
.4734 .59165 .49539 .61312 .53479 .60156 .51318 .57978 Metetra
.659 .748 .916 r
.51318 .57978 .53479 .60156 .57477 .58983 .55354 .56773 Metetra
.659 .748 .916 r
.55354 .56773 .57477 .58983 .61533 .57793 .5945 .55551 Metetra
.659 .748 .916 r
.5945 .55551 .61533 .57793 .65649 .56586 .63607 .5431 Metetra
.659 .748 .916 r
.63607 .5431 .65649 .56586 .69826 .55361 .67826 .53051 Metetra
.659 .748 .916 r
.67826 .53051 .69826 .55361 .74066 .54117 .7211 .51772 Metetra
.659 .748 .916 r
.7211 .51772 .74066 .54117 .78369 .52855 .76459 .50474 Metetra
.659 .748 .916 r
.76459 .50474 .78369 .52855 .82737 .51574 .80875 .49156 Metetra
.659 .748 .916 r
.80875 .49156 .82737 .51574 .87173 .50273 .85359 .47818 Metetra
.659 .748 .916 r
.85359 .47818 .87173 .50273 .91676 .48951 .89914 .46458 Metetra
.659 .748 .916 r
.89914 .46458 .91676 .48951 .9625 .4761 .9454 .45078 Metetra
.659 .748 .916 r
.33382 .60513 .35746 .62625 .39555 .61488 .37225 .59346 Metetra
.659 .748 .916 r
.37225 .59346 .39555 .61488 .4342 .60335 .41125 .58162 Metetra
.659 .748 .916 r
.41125 .58162 .4342 .60335 .4734 .59165 .45082 .56962 Metetra
.658 .748 .916 r
.45082 .56962 .4734 .59165 .51318 .57978 .49097 .55744 Metetra
.658 .748 .916 r
.49097 .55744 .51318 .57978 .55354 .56773 .53172 .5451 Metetra
.658 .748 .916 r
.53172 .5451 .55354 .56773 .5945 .55551 .57309 .53256 Metetra
.659 .749 .917 r
.57309 .53256 .5945 .55551 .63607 .5431 .61508 .51981 Metetra
.659 .749 .917 r
.61508 .51981 .63607 .5431 .67826 .53051 .65771 .50685 Metetra
.659 .749 .916 r
.65771 .50685 .67826 .53051 .7211 .51772 .70099 .49368 Metetra
.659 .749 .916 r
.70099 .49368 .7211 .51772 .76459 .50474 .74495 .4803 Metetra
.659 .748 .916 r
.74495 .4803 .76459 .50474 .80875 .49156 .78959 .46671 Metetra
.659 .748 .916 r
.78959 .46671 .80875 .49156 .85359 .47818 .83493 .45293 Metetra
.659 .748 .916 r
.83493 .45293 .85359 .47818 .89914 .46458 .881 .43893 Metetra
.659 .748 .916 r
.881 .43893 .89914 .46458 .9454 .45078 .9278 .42471 Metetra
.658 .748 .916 r
.30955 .58348 .33382 .60513 .37225 .59346 .34832 .57156 Metetra
.657 .748 .917 r
.34832 .57156 .37225 .59346 .41125 .58162 .38766 .55959 Metetra
.654 .749 .92 r
.38766 .55959 .41125 .58162 .45082 .56962 .42759 .54767 Metetra
.651 .752 .924 r
.42759 .54767 .45082 .56962 .49097 .55744 .46812 .53585 Metetra
.648 .758 .929 r
.46812 .53585 .49097 .55744 .53172 .5451 .50928 .52405 Metetra
.649 .766 .935 r
.50928 .52405 .53172 .5451 .57309 .53256 .5511 .51194 Metetra
.653 .775 .938 r
.5511 .51194 .57309 .53256 .61508 .51981 .59356 .49916 Metetra
.659 .78 .938 r
.59356 .49916 .61508 .51981 .65771 .50685 .63667 .48553 Metetra
.664 .778 .934 r
.63667 .48553 .65771 .50685 .70099 .49368 .68042 .4712 Metetra
.666 .771 .928 r
.68042 .4712 .70099 .49368 .74495 .4803 .72482 .45653 Metetra
.665 .763 .923 r
.72482 .45653 .74495 .4803 .78959 .46671 .76992 .44184 Metetra
.662 .756 .919 r
.76992 .44184 .78959 .46671 .83493 .45293 .81575 .42722 Metetra
.66 .751 .917 r
.81575 .42722 .83493 .45293 .881 .43893 .86233 .41261 Metetra
.659 .749 .916 r
.86233 .41261 .881 .43893 .9278 .42471 .90967 .39789 Metetra
.65 .748 .922 r
.2846 .5615 .30955 .58348 .34832 .57156 .32367 .55004 Metetra
.633 .751 .933 r
.32367 .55004 .34832 .57156 .38766 .55959 .36329 .53982 Metetra
.596 .76 .957 r
.36329 .53982 .38766 .55959 .42759 .54767 .40346 .53196 Metetra
.521 .779 .991 r
.40346 .53196 .42759 .54767 .46812 .53585 .4443 .5269 Metetra
.38 .788 .982 r
.4443 .5269 .46812 .53585 .50928 .52405 .48594 .5233 Metetra
.205 .731 .832 r
.48594 .5233 .50928 .52405 .5511 .51194 .52846 .51798 Metetra
.52846 .51798 .5511 .51194 .59356 .49916 .5718 .50769 Metetra
.5718 .50769 .59356 .49916 .63667 .48553 .61573 .49103 Metetra
.456 .881 .788 r
.61573 .49103 .63667 .48553 .68042 .4712 .66008 .46927 Metetra
.649 .96 .929 r
.66008 .46927 .68042 .4712 .72482 .45653 .70483 .44561 Metetra
.71 .911 .965 r
.70483 .44561 .72482 .45653 .76992 .44184 .75016 .42329 Metetra
.699 .835 .948 r
.75016 .42329 .76992 .44184 .81575 .42722 .79624 .40374 Metetra
.678 .785 .93 r
.79624 .40374 .81575 .42722 .86233 .41261 .8432 .38652 Metetra
.666 .761 .921 r
.8432 .38652 .86233 .41261 .90967 .39789 .89102 .37054 Metetra
.616 .747 .939 r
.25888 .53973 .2846 .5615 .32367 .55004 .29813 .53075 Metetra
.515 .74 .976 r
.29813 .53075 .32367 .55004 .36329 .53982 .33773 .52745 Metetra
.156 .629 .927 r
.33773 .52745 .36329 .53982 .40346 .53196 .37777 .53315 Metetra
.427 0 0 r
.37777 .53315 .40346 .53196 .4443 .5269 .41865 .54689 Metetra
.551 .069 .063 r
.41865 .54689 .4443 .5269 .48594 .5233 .46084 .5615 Metetra
.513 .098 .19 r
.46084 .5615 .48594 .5233 .52846 .51798 .50447 .56833 Metetra
.438 .057 .216 r
.50447 .56833 .52846 .51798 .5718 .50769 .54926 .5621 Metetra
.335 0 .189 r
.54926 .5621 .5718 .50769 .61573 .49103 .59468 .54118 Metetra
.181 0 .101 r
.59468 .54118 .61573 .49103 .66008 .46927 .6402 .50685 Metetra
.6402 .50685 .66008 .46927 .70483 .44561 .68552 .46422 Metetra
.68552 .46422 .70483 .44561 .75016 .42329 .73083 .42204 Metetra
.752 .991 .884 r
.73083 .42204 .75016 .42329 .79624 .40374 .77675 .38777 Metetra
.739 .883 .946 r
.77675 .38777 .79624 .40374 .8432 .38652 .82374 .3626 Metetra
.691 .796 .93 r
.82374 .3626 .8432 .38652 .89102 .37054 .87189 .34319 Metetra
.587 .736 .946 r
.23245 .51712 .25888 .53973 .29813 .53075 .27186 .51008 Metetra
.409 .687 .976 r
.27186 .51008 .29813 .53075 .33773 .52745 .31143 .51197 Metetra
0 .434 .813 r
.31143 .51197 .33773 .52745 .37777 .53315 .35134 .52664 Metetra
.513 0 0 r
.35134 .52664 .37777 .53315 .41865 .54689 .39223 .55023 Metetra
.555 0 0 r
.39223 .55023 .41865 .54689 .46084 .5615 .43481 .57162 Metetra
.421 0 0 r
.43481 .57162 .46084 .5615 .50447 .56833 .47916 .58135 Metetra
.145 0 0 r
.47916 .58135 .50447 .56833 .54926 .5621 .52489 .57564 Metetra
.52489 .57564 .54926 .5621 .59468 .54118 .57139 .55368 Metetra
.6 .927 .705 r
.57139 .55368 .59468 .54118 .6402 .50685 .61802 .51587 Metetra
.802 .993 .755 r
.61802 .51587 .6402 .50685 .68552 .46422 .66427 .46572 Metetra
.879 .991 .803 r
.66427 .46572 .68552 .46422 .73083 .42204 .71013 .41272 Metetra
.863 .947 .869 r
.71013 .41272 .73083 .42204 .77675 .38777 .7563 .36842 Metetra
.783 .865 .91 r
.7563 .36842 .77675 .38777 .82374 .3626 .80356 .33703 Metetra
.71 .796 .918 r
.80356 .33703 .82374 .3626 .87189 .34319 .85212 .31475 Metetra
.619 .73 .925 r
.20543 .49201 .23245 .51712 .27186 .51008 .24532 .48235 Metetra
.55 .687 .929 r
.24532 .48235 .27186 .51008 .31143 .51197 .2855 .47843 Metetra
.438 .594 .908 r
.2855 .47843 .31143 .51197 .35134 .52664 .32601 .48362 Metetra
.37 .496 .856 r
.32601 .48362 .35134 .52664 .39223 .55023 .36726 .49696 Metetra
.41 .47 .812 r
.36726 .49696 .39223 .55023 .43481 .57162 .40987 .51118 Metetra
.5 .499 .787 r
.40987 .51118 .43481 .57162 .47916 .58135 .45411 .5175 Metetra
.588 .541 .769 r
.45411 .5175 .47916 .58135 .52489 .57564 .49975 .51053 Metetra
.657 .577 .753 r
.49975 .51053 .52489 .57564 .57139 .55368 .54629 .48863 Metetra
.707 .604 .739 r
.54629 .48863 .57139 .55368 .61802 .51587 .59313 .4531 Metetra
.737 .625 .735 r
.59313 .4531 .61802 .51587 .66427 .46572 .63988 .40915 Metetra
.748 .647 .749 r
.63988 .40915 .66427 .46572 .71013 .41272 .68663 .36565 Metetra
.741 .677 .789 r
.68663 .36565 .71013 .41272 .7563 .36842 .73389 .33018 Metetra
.717 .712 .844 r
.73389 .33018 .7563 .36842 .80356 .33703 .78214 .3039 Metetra
.687 .735 .888 r
.78214 .3039 .80356 .33703 .85212 .31475 .83152 .28344 Metetra
.65 .737 .913 r
.17767 .46598 .20543 .49201 .24532 .48235 .21815 .45307 Metetra
.636 .711 .901 r
.21815 .45307 .24532 .48235 .2855 .47843 .25917 .44142 Metetra
.612 .653 .866 r
.25917 .44142 .2855 .47843 .32601 .48362 .30073 .43214 Metetra
.586 .573 .806 r
.30073 .43214 .32601 .48362 .36726 .49696 .34292 .42573 Metetra
.572 .508 .745 r
.34292 .42573 .36726 .49696 .40987 .51118 .38595 .42078 Metetra
.575 .477 .705 r
.38595 .42078 .40987 .51118 .45411 .5175 .43 .41403 Metetra
.59 .471 .685 r
.43 .41403 .45411 .5175 .49975 .51053 .47508 .40213 Metetra
.609 .478 .678 r
.47508 .40213 .49975 .51053 .54629 .48863 .52103 .38365 Metetra
.626 .493 .681 r
.52103 .38365 .54629 .48863 .59313 .4531 .56759 .35989 Metetra
.64 .517 .697 r
.56759 .35989 .59313 .4531 .63988 .40915 .61466 .33416 Metetra
.653 .555 .731 r
.61466 .33416 .63988 .40915 .68663 .36565 .66232 .30976 Metetra
.663 .612 .787 r
.66232 .30976 .68663 .36565 .73389 .33018 .71073 .28817 Metetra
.667 .676 .848 r
.71073 .28817 .73389 .33018 .78214 .3039 .76002 .26894 Metetra
.664 .72 .89 r
.76002 .26894 .78214 .3039 .83152 .28344 .81024 .25092 Metetra
.658 .745 .914 r
.14902 .44004 .17767 .46598 .21815 .45307 .18993 .42592 Metetra
.657 .739 .91 r
.18993 .42592 .21815 .45307 .25917 .44142 .2315 .4117 Metetra
.654 .722 .899 r
.2315 .4117 .25917 .44142 .30073 .43214 .27373 .39748 Metetra
.649 .69 .875 r
.27373 .39748 .30073 .43214 .34292 .42573 .31664 .38333 Metetra
.641 .646 .839 r
.31664 .38333 .34292 .42573 .38595 .42078 .36027 .36914 Metetra
.634 .604 .803 r
.36027 .36914 .38595 .42078 .43 .41403 .40466 .35459 Metetra
.63 .577 .777 r
.40466 .35459 .43 .41403 .47508 .40213 .44983 .33928 Metetra
.63 .569 .767 r
.44983 .33928 .47508 .40213 .52103 .38365 .49578 .32303 Metetra
.636 .58 .775 r
.49578 .32303 .52103 .38365 .56759 .35989 .5425 .306 Metetra
.644 .609 .8 r
.5425 .306 .56759 .35989 .61466 .33416 .59 .28857 Metetra
.653 .651 .836 r
.59 .28857 .61466 .33416 .66232 .30976 .6383 .27105 Metetra
.658 .693 .872 r
.6383 .27105 .66232 .30976 .71073 .28817 .68744 .25354 Metetra
.659 .724 .897 r
.68744 .25354 .71073 .28817 .76002 .26894 .73745 .23597 Metetra
.659 .739 .909 r
.73745 .23597 .76002 .26894 .81024 .25092 .78835 .21823 Metetra
.659 .748 .916 r
.11949 .41362 .14902 .44004 .18993 .42592 .16078 .39899 Metetra
.659 .747 .915 r
.16078 .39899 .18993 .42592 .2315 .4117 .20275 .38414 Metetra
.659 .745 .914 r
.20275 .38414 .2315 .4117 .27373 .39748 .24542 .36904 Metetra
.658 .742 .912 r
.24542 .36904 .27373 .39748 .31664 .38333 .28879 .35371 Metetra
.658 .737 .908 r
.28879 .35371 .31664 .38333 .36027 .36914 .33289 .33812 Metetra
.658 .73 .903 r
.33289 .33812 .36027 .36914 .40466 .35459 .37773 .32227 Metetra
.657 .724 .898 r
.37773 .32227 .40466 .35459 .44983 .33928 .42335 .30613 Metetra
.657 .722 .896 r
.42335 .30613 .44983 .33928 .49578 .32303 .46974 .28969 Metetra
.658 .724 .898 r
.46974 .28969 .49578 .32303 .5425 .306 .51694 .27295 Metetra
.658 .73 .902 r
.51694 .27295 .5425 .306 .59 .28857 .56496 .25591 Metetra
.659 .737 .908 r
.56496 .25591 .59 .28857 .6383 .27105 .61384 .23858 Metetra
.659 .742 .912 r
.61384 .23858 .6383 .27105 .68744 .25354 .66358 .22095 Metetra
.659 .745 .914 r
.66358 .22095 .68744 .25354 .73745 .23597 .71421 .20301 Metetra
.659 .747 .915 r
.71421 .20301 .73745 .23597 .78835 .21823 .76576 .18475 Metetra
.659 .748 .916 r
.08906 .38643 .11949 .41362 .16078 .39899 .13073 .37136 Metetra
.659 .748 .916 r
.13073 .37136 .16078 .39899 .20275 .38414 .1731 .35604 Metetra
.659 .748 .916 r
.1731 .35604 .20275 .38414 .24542 .36904 .21618 .34046 Metetra
.659 .748 .916 r
.21618 .34046 .24542 .36904 .28879 .35371 .25998 .32462 Metetra
.659 .747 .916 r
.25998 .32462 .28879 .35371 .33289 .33812 .30453 .30851 Metetra
.659 .747 .915 r
.30453 .30851 .33289 .33812 .37773 .32227 .34984 .29213 Metetra
.659 .747 .915 r
.34984 .29213 .37773 .32227 .42335 .30613 .39594 .27546 Metetra
.659 .747 .915 r
.39594 .27546 .42335 .30613 .46974 .28969 .44284 .25849 Metetra
.659 .747 .915 r
.44284 .25849 .46974 .28969 .51694 .27295 .49057 .24123 Metetra
.659 .747 .915 r
.49057 .24123 .51694 .27295 .56496 .25591 .53914 .22367 Metetra
.659 .747 .916 r
.53914 .22367 .56496 .25591 .61384 .23858 .58859 .20578 Metetra
.659 .748 .916 r
.58859 .20578 .61384 .23858 .66358 .22095 .63894 .18758 Metetra
.659 .748 .916 r
.63894 .18758 .66358 .22095 .71421 .20301 .6902 .16904 Metetra
.659 .748 .916 r
.6902 .16904 .71421 .20301 .76576 .18475 .74241 .15016 Metetra
.659 .748 .916 r
.0577 .35841 .08906 .38643 .13073 .37136 .09976 .34287 Metetra
.659 .748 .916 r
.09976 .34287 .13073 .37136 .1731 .35604 .14252 .32707 Metetra
.659 .748 .916 r
.14252 .32707 .1731 .35604 .21618 .34046 .18601 .31101 Metetra
.659 .748 .916 r
.18601 .31101 .21618 .34046 .25998 .32462 .23025 .29466 Metetra
.659 .748 .916 r
.23025 .29466 .25998 .32462 .30453 .30851 .27525 .27804 Metetra
.659 .748 .916 r
.27525 .27804 .30453 .30851 .34984 .29213 .32104 .26112 Metetra
.659 .748 .916 r
.32104 .26112 .34984 .29213 .39594 .27546 .36763 .24391 Metetra
.659 .748 .916 r
.36763 .24391 .39594 .27546 .44284 .25849 .41505 .22639 Metetra
.659 .748 .916 r
.41505 .22639 .44284 .25849 .49057 .24123 .46332 .20856 Metetra
.659 .748 .916 r
.46332 .20856 .49057 .24123 .53914 .22367 .51246 .1904 Metetra
.659 .748 .916 r
.51246 .1904 .53914 .22367 .58859 .20578 .5625 .17191 Metetra
.659 .748 .916 r
.5625 .17191 .58859 .20578 .63894 .18758 .61346 .15309 Metetra
.659 .748 .916 r
.61346 .15309 .63894 .18758 .6902 .16904 .66536 .13391 Metetra
.659 .748 .916 r
.66536 .13391 .6902 .16904 .74241 .15016 .71824 .11438 Metetra
.659 .748 .916 r
.02537 .32952 .0577 .35841 .09976 .34287 .06781 .3135 Metetra
.659 .748 .916 r
.06781 .3135 .09976 .34287 .14252 .32707 .11098 .2972 Metetra
.659 .748 .916 r
.11098 .2972 .14252 .32707 .18601 .31101 .15489 .28061 Metetra
.659 .748 .916 r
.15489 .28061 .18601 .31101 .23025 .29466 .19957 .26374 Metetra
.659 .748 .916 r
.19957 .26374 .23025 .29466 .27525 .27804 .24503 .24658 Metetra
.659 .748 .916 r
.24503 .24658 .27525 .27804 .32104 .26112 .2913 .2291 Metetra
.659 .748 .916 r
.2913 .2291 .32104 .26112 .36763 .24391 .3384 .21132 Metetra
.659 .748 .916 r
.3384 .21132 .36763 .24391 .41505 .22639 .38634 .19322 Metetra
.659 .748 .916 r
.38634 .19322 .41505 .22639 .46332 .20856 .43516 .17478 Metetra
.659 .748 .916 r
.43516 .17478 .46332 .20856 .51246 .1904 .48488 .15601 Metetra
.659 .748 .916 r
.48488 .15601 .51246 .1904 .5625 .17191 .53551 .13689 Metetra
.659 .748 .916 r
.53551 .13689 .5625 .17191 .61346 .15309 .5871 .11741 Metetra
.659 .748 .916 r
.5871 .11741 .61346 .15309 .66536 .13391 .63966 .09756 Metetra
.659 .748 .916 r
.63966 .09756 .66536 .13391 .71824 .11438 .69323 .07733 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(-2)] .02757 .24618 1 .93395 Mshowa
.18558 .19702 m
.19014 .20174 L
s
[(-1)] .17646 .18758 .96648 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.51046 .06981 m
.51442 .07504 L
s
[(1)] .50253 .05935 .75799 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(2)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00l?ooool5o`0007?ooooo003`ooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@0Loooool00?7ooooo00?oV9RHob4Q8Oo^k^h0M?ooool00?;ooooo00?oV9RHob4Q8Oo^k^h0Looo
ool00??ooooo00?oMgMgofIVI_ooool0L_ooool00?Cooooo00?o0000ooooooooool0LOooool00?3o
oooo00Go0000okZj^_ooooooV9RHoa0@4009ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0IOooool0
0?3ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0IOoo
ool00?kooooo00Go410@oooooooooooooooooa0@401Uooooo`00o_ooool01Ol0003ooooooooooooo
oooo000006Gooooo003nooooo`05o`000?ooooooooooooooool00000IOooool00?kooooo00Go410@
oooooooooooooooooa0@401Uooooo`00o_ooool01OmgMgOoV9RHoooooonHV9SoMgMg06Gooooo003f
ooooo`Co00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^06Gooooo003dooooo`?o000000Cooooo
o`000?oooooo0000KOooool00?;ooooo0_l00004ooooo`;o0000K_ooool00>oooooo0ol00006oooo
o`03o`000?oooooo000006gooooo003/ooooo`?o00002Oooool00ol0003oooooo`00001]ooooo`00
j_ooool3o`0000_ooooo00Co0000oooooooooooo0000K?ooool00>Oooooo0ol00003ooooo`03o`00
0?oooooooooo00Sooooo00Go0000ooooooooooooooooo`00001[ooooo`00iOooool2o`00017ooooo
00Go0000ooooooooooooooooo`00001[ooooo`00h_ooool3o`0001?ooooo00?o0000ooooooooool0
0_ooool2o`0006Wooooo003Pooooo`;o00005oooool01?l0003oooooooooooooool2o`0006Wooooo
003Mooooo`Co00006?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo06Oooooo002d
ooooo`Co000000?o410@ooooooooool07oooool3o`0001cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`1Vooooo`00]_ooool00ol0003oooooooooo`0Oooooo`;o00007oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo06Gooooo002fooooo`03o`000?oooooooooo01co
oooo0ol0000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0IOooool00;Kooooo
00?o0000ooooooooool06_ooool2o`0002Cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`1Tooooo`00]_ooool00ol0003oooooooooo`0Gooooo`?o000000?oooooo`000?ooool08ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06?ooooo002fooooo`03o`000?oooooo
oooo01Gooooo0_l0000Yooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Hoooool0
0;Kooooo00?o0000ooooooooool04_ooool3o`0002_ooooo00?o0000ooooooooool01oooool2o`00
06?ooooo002dooooo`03oeEEEOmVIVKo0000017ooooo0ol0000^ooooo`03o`000?oooooooooo00Oo
oooo0_l0001Sooooo`00a_ooool3o`00033ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`1Qooooo`00`oooool3o`0000;ooooo00?o0000ooooooooool0;_ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo063ooooo0031ooooo`;o0000=_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo063ooooo002nooooo`?o0000>?ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo05oooooo002looooo`;o0000>oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo05kooooo002iooooo`Co0000??ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo05kooooo002fooooo`?o00001?ooool00ol0003oooooooooo`0iooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool0GOooool00;Cooooo0_l00013ooooo`;o00003Oooool3
o`0005gooooo002aooooo`?o0000@_ooool3o`000003ojRoj_l0003ooooo00gooooo00?o0000oooo
ooooool0G?ooool00:oooooo0_l00013ooooo`;o00001?nX_nX2o`0000kooooo00?o0000oooooooo
ool0Foooool00:cooooo0ol00002ooooo`03o`000?oooooooooo03gooooo0ol00006ojRojP03o`00
0?nX_n[o000000kooooo00?o0000ooooooooool0F_ooool00:[ooooo0_l00012ooooo`?o00002OnX
_nX00ol0003oZ;oZo`00000>ooooo`03o`000?oooooooooo05[ooooo002Wooooo`?o0000@_ooool2
o`0000coZ;oZ00Co0000ojRoj_nX_n[o00003_ooool00ol0003oooooooooo`1Iooooo`00Y?ooool3
o`0004;ooooo0ol0000>ojRojP05o`000?nX_n[oZ;oZojRoj_l000003_ooool00ol0003ooooooooo
o`1Hooooo`00NOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Cooooo0_l000000ooooooo0000oooo
o`10ooooo`;o00004OnX_nX01Ol0003oZ;oZojRoj_nX_n[o000000kooooo00?o0000ooooooooool0
F?ooool007Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Qooooo`?o0000@_ooool3o`000003ojRo
j_l0003oZ;oZ013oZ;oZ00?o0000ojRoj_nX_nX00_nX_nX00ol0003oooooooooo`0<ooooo`;o0000
F?ooool007Wooooo00Go410@oooooooooooooooooa0@400Oooooo`;o0000@_ooool3o`0000GoZ;oZ
00?o0000ojRoj_nX_nX03_nX_nX00ol0003oZ;oZojRojP03ojRojP03o`000?oooooooooo00_ooooo
0_l0001Hooooo`00NOooool01Ol0003ooooooooooooooooo000001cooooo0ol00011ooooo`?o0000
2OnX_nX00ol0003oZ;oZojRojP0=ojRojP03o`000?nX_n[oZ;oZ00?oZ;oZ00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`09ooooo`Co000000?o410@ooooooooool0A_ooool007Wooooo00Go
0000ooooooooooooooooo`00000Jooooo`;o0000@Oooool3o`0000coZ;oZ00?o0000ojRoj_nX_nX0
3OnX_nX00ol0003oZ;oZojRojP04ojRojP03o`000?oooooooooo00cooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`18ooooo`00NOooool01Ol@413ooooooooooooooooo410@01Oooooo
0ol00002ooooo`03o`000?oooooooooo03_ooooo0ol0000@ojRojP03o`000?nX_n[oZ;oZ00coZ;oZ
00?o0000ojRoj_nX_nX01?nX_nX2o`0000kooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`18ooooo`00NOooool01OmgMgOoV9RHoooooonHV9SoMgMg01Cooooo0ol00010ooooo`?o0000
5?nX_nX00ol0003oZ;oZojRojP0;ojRojP04o`000?nX_n[oZ;oZojRojP?o000000?oZ;oZo`000?oo
ool03Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo04Sooooo001iooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h04_ooool2o`00043ooooo0ol000000onX_n[o0000ojRojP0DojRojP03
o`000?nX_n[oZ;oZ00_oZ;oZ00Co0000ojRoj_l0003o00001OnX_nX00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0B?ooool008gooooo0ol00010ooooo`;o
00001OnX_nX00ol0003oZ;oZojRojP0CojRojP03o`000?nX_n[oZ;oZ00WoZ;oZ0ol00008ojRojP03
o`000?oooooooooo00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`18ooooo`00
Roooool2o`0000;ooooo00?o0000ooooooooool0>oooool3o`0000SoZ;oZ00?o0000ojRoj_nX_nX0
4onX_nX00ol0003oZ;oZojRojP05ojRojP?o00000_nX_nX00ol0003oZ;oZojRojP06ojRojP03o`00
0?oooooooooo00cooooo0_l00008ooooo`03o`000?oooooooooo04Sooooo0028ooooo`?o0000?ooo
ool3o`0000_oZ;oZ00?o0000ojRoj_nX_nX04onX_nX00ol0003oZ;oZojRojP03ojRojP;o00001OnX
_nX00ol0003oZ;oZojRojP07ojRojP03o`000?oooooooooo00[ooooo00?o0000ooooool000001_oo
ool00omEEEGoIVIVo`00001:ooooo`00Q_ooool2o`00043ooooo0_l0000?ojRojP03o`000?nX_n[o
Z;oZ01?oZ;oZ00?o0000ojRoj_l000000_l00007ojRojP03o`000?nX_n[oZ;oZ00SoZ;oZ00?o0000
ooooooooool03?ooool00ol0003oooooooooo`1@ooooo`00Poooool3o`0003oooooo0ol0000BojRo
jP03o`000?nX_n[oZ;oZ01;oZ;oZ0_l0000:ojRojP03o`000?nX_n[oZ;oZ00WoZ;oZ00?o0000oooo
ooooool02oooool00ol0003oooooooooo`1@ooooo`00POooool3o`0003oooooo0_l0000FojRojP03
o`000?nX_n[oZ;oZ00koZ;oZ0ol000000onX_n[o0000ojRojP09ojRojP03o`000?nX_n[oZ;oZ00Wo
Z;oZ00?o0000ooooooooool03?ooool00ol0003oooooooooo`1?ooooo`00O_ooool3o`0000?ooooo
00?o0000ooooooooool0>Oooool3o`000003ojRoj_l0003oZ;oZ01GoZ;oZ00?o0000ojRoj_nX_nX0
3?nX_nX2o`0000GoZ;oZ00?o0000ojRoj_nX_nX01onX_nX00ol0003oZ;oZojRojP0:ojRojP03o`00
0?oooooooooo00cooooo00?o0000ooooooooool0C_ooool007_ooooo0ol00010ooooo`;o00001OnX
_nX00ol0003oZ;oZojRojP0DojRojP03o`000?nX_n[oZ;oZ00SoZ;oZ0ol00008ojRojP03o`000?nX
_n[oZ;oZ00KoZ;oZ00?o0000ojRoj_nX_nX02onX_nX00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo04kooooo001iooooo`;o0000@?ooool3o`0000SoZ;oZ00?o0000ojRoj_nX_nX05?nX_nX0
0ol0003oZ;oZojRojP05ojRojP;o00003?nX_nX00ol0003oZ;oZojRojP05ojRojP03o`000?nX_n[o
Z;oZ00_oZ;oZ00?o0000ooooooooool03?ooool00ol0003oooooooooo`1=ooooo`00M_ooool3o`00
043ooooo0_l0000<ojRojP03o`000?nX_n[oZ;oZ01?oZ;oZ00?o0000ojRoj_nX_nX00onX_nX2o`00
00koZ;oZ00?o0000ojRoj_nX_nX01OnX_nX00ol0003oZ;oZojRojP0<ojRojP03o`000?oooooooooo
00cooooo0_l0001=ooooo`00M?ooool2o`0000?ooooo00?o0000ooooooooool0>oooool2o`0000ko
Z;oZ00?o0000ojRoj_nX_nX05?nX_nX00ol0003oZ;oZo`000002o`00017oZ;oZ00?o0000ojRoj_nX
_nX01?nX_nX00ol0003oZ;oZojRojP0<ojRojP;o00003?ooool2o`0004kooooo001aooooo`?o0000
@?ooool3o`00017oZ;oZ00?o0000ojRoj_nX_nX04onX_nX2o`0001GoZ;oZ00?o0000ojRoj_nX_nX0
0onX_nX00ol0003oZ;oZojRojP09ojRojP?o000000?oZ;oZo`000?ooool03Oooool00ol0003ooooo
ooooo`1;ooooo`00Koooool2o`00047ooooo0_l0000EojRojP03o`000?nX_n[oZ;oZ00ooZ;oZ0ol0
00000onX_n[o0000ojRojP0EojRojP03o`000?nX_n[oZ;oZ00;oZ;oZ00?o0000ojRoj_nX_nX01_nX
_nX3o`0000GoZ;oZ00?o0000ooooooooool03?ooool00ol0003oooooooooo`1:ooooo`00A?ooool4
o`000003oa0@4?oooooooooo027ooooo0ol00010ooooo`?o000000?oZ;oZo`000?nX_nX05OnX_nX0
0ol0003oZ;oZojRojP0;ojRojP?o00001OnX_nX00ol0003oZ;oZojRojP0CojRojP03o`000?nX_n[o
Z;oZ00;oZ;oZ00?o0000ojRoj_nX_nX00onX_nX3o`0000WoZ;oZ00?o0000ooooooooool02oooool0
0ol0003oooooooooo`1:ooooo`00A_ooool00ol0003oooooooooo`0Pooooo`?o00000_ooool00ol0
003oooooooooo`0kooooo`?o00001OnX_nX00ol0003oZ;oZojRojP0CojRojP03o`000?nX_n[oZ;oZ
00SoZ;oZ0ol00009ojRojP03o`000?nX_n[oZ;oZ01?oZ;oZ00Go0000ojRoj_nX_n[oZ;oZo`000002
ojRojP?o00003OnX_nX00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo04Wooooo000koooo
o`Ko00001Oooool00ol0003oooooooooo`0Nooooo`;o0000@?ooool3o`0000WoZ;oZ00?o0000ojRo
j_nX_nX04onX_nX00ol0003oZ;oZojRojP04ojRojP?o00003OnX_nX00ol0003oZ;oZojRojP0CojRo
jP03o`000?nX_n[oZ;oZ00?o00004?nX_nX00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
04Wooooo0016ooooo`03o`000?oooooooooo01_ooooo0ol0000oooooo`?o00003OnX_nX00ol0003o
Z;oZojRojP0CojRojP03o`000?nX_n[oZ;oZ00?o00004?nX_nX00ol0003oZ;oZojRojP0CojRojPCo
00004onX_nX00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo04Sooooo0016ooooo`03o`00
0?oooooooooo01Wooooo0_l0000oooooo`?o00004OnX_nX00ol0003oZ;oZojRojP0BojRojP?o0000
5?nX_nX00ol0003oZ;oZojRojP0?ojRojP?o000000CoZ;oZo`000?nX_n[o00005?nX_nX00ol0003o
ooooooooo`0:ooooo`?o0000B?ooool004Kooooo00?o0000ooooooooool05_ooool3o`000003oooo
ool0003ooooo03cooooo0_l0000EojRojP03o`000?nX_n[oZ;oZ00koZ;oZ0ol000000onX_n[o0000
ojRojP0EojRojP03o`000?nX_n[oZ;oZ00_oZ;oZ0ol00005ojRojP03o`000?nX_n[o000001?oZ;oZ
00?o0000ooooooooool02oooool00ol0003oooooooooo`17ooooo`00A_ooool00ol0003ooooooooo
o`0Dooooo`;o0000?oooool3o`000003ojRoj_l0003oZ;oZ01CoZ;oZ00?o0000ojRoj_nX_nX02onX
_nX3o`0000GoZ;oZ00?o0000ojRoj_nX_nX04onX_nX00ol0003oZ;oZojRojP08ojRojP?o00002OnX
_nX2o`0001CoZ;oZ00?o0000ooooooooool02oooool00ol0003oooooooooo`16ooooo`00A?ooool0
0omEEEGoIVIVo`00000Cooooo`?o0000?_ooool3o`0000GoZ;oZ00?o0000ojRoj_nX_nX04onX_nX0
0ol0003oZ;oZojRojP07ojRojP?o00002OnX_nX00ol0003oZ;oZojRojP0CojRojP03o`000?nX_n[o
Z;oZ00CoZ;oZ0ol0000<ojRojP;o00005OnX_nX00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo04Gooooo001Gooooo`?o0000?oooool2o`0000WoZ;oZ00?o0000ojRoj_nX_nX04onX_nX00ol0
003oZ;oZojRojP03ojRojP?o00003OnX_nX00ol0003oZ;oZojRojP0CojRojP03o`000?nX_n[oZ;oZ
00?o00004?nX_nX00ol0003oZ;oZojRojP0CojRojP;o00003?ooool00ol0003oooooooooo`15oooo
o`00EOooool2o`0000;ooooo00?o0000ooooooooool0>_ooool3o`0000coZ;oZ00?o0000ojRoj_nX
_nX04onX_nX00ol0003oZ;oZo`000002o`00013oZ;oZ00?o0000ojRoj_nX_nX04onX_nX3o`0001?o
Z;oZ0_l0000AojRojP?o000000?oZ;oZo`000?ooool03?ooool00ol0003oooooooooo`14ooooo`00
D_ooool3o`0003kooooo0ol0000@ojRojP03o`000?nX_n[oZ;oZ01;oZ;oZ0_l0000DojRojP03o`00
0?nX_n[oZ;oZ00ooZ;oZ0ol000000onX_n[o0000ojRojP0CojRojP;o00003onX_nX2o`0000GoZ;oZ
00?o0000ooooooooool02oooool00ol0003oooooooooo`13ooooo`00D?ooool2o`0003oooooo0_l0
000DojRojP03o`000?nX_n[oZ;oZ00koZ;oZ0ol000000onX_n[o0000ojRojP0DojRojP03o`000?nX
_n[oZ;oZ00coZ;oZ0_l00005ojRojP03o`000?nX_n[oZ;oZ017oZ;oZ00?o0000ojRoj_l000002onX
_nX3o`0000OoZ;oZ00?o0000ooooooooool02oooool00ol0003oooooooooo`13ooooo`00COooool3
o`0003kooooo0ol000000onX_n[o0000ojRojP0DojRojP03o`000?nX_n[oZ;oZ00[oZ;oZ0ol00005
ojRojP03o`000?nX_n[oZ;oZ01?oZ;oZ00?o0000ojRoj_nX_nX02?nX_nX3o`0000SoZ;oZ00?o0000
ojRoj_nX_nX04?nX_nX01?l0003oZ;oZojRoj_l00007ojRojP?o00002onX_nX00ol0003ooooooooo
o`0:ooooo`?o0000@oooool004_ooooo1?l0000looooo`?o00001OnX_nX00ol0003oZ;oZojRojP0C
ojRojP03o`000?nX_n[oZ;oZ00OoZ;oZ0_l00009ojRojP03o`000?nX_n[oZ;oZ01;oZ;oZ00?o0000
ojRoj_nX_nX01_nX_nX2o`0000coZ;oZ00?o0000ojRoj_nX_nX03onX_nX01?l0003oZ;oZojRoj_l0
0005ojRojP;o00003onX_nX00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo047ooooo0018
ooooo`?o00001?ooool00ol0003oooooooooo`0fooooo`?o00002OnX_nX00ol0003oZ;oZojRojP0C
ojRojP03o`000?nX_n[oZ;oZ00?oZ;oZ0ol0000<ojRojP03o`000?nX_n[oZ;oZ01;oZ;oZ00?o0000
ojRoj_nX_nX00onX_nX2o`0000koZ;oZ00?o0000ojRoj_nX_nX03onX_nX01_l0003oZ;oZojRoj_nX
_n[o0000ojRojP?o00004OnX_nX00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo047ooooo
0015ooooo`?o0000?Oooool3o`0000goZ;oZ00?o0000ojRoj_nX_nX04onX_nX00ol0003oZ;oZo`00
0002o`00013oZ;oZ00?o0000ojRoj_nX_nX04_nX_nX00ol0003oZ;oZo`000002o`00017oZ;oZ00?o
0000ojRoj_nX_nX03_nX_nX01?l0003oZ;oZojRoj_nX_nX2o`0001GoZ;oZ00?o0000ooooooooool0
2oooool00ol0003oooooooooo`10ooooo`00@oooool2o`0003gooooo0ol0000@ojRojP03o`000?nX
_n[oZ;oZ01?oZ;oZ0_l0000DojRojP03o`000?nX_n[oZ;oZ017oZ;oZ0_l0000EojRojP03o`000?nX
_n[oZ;oZ00goZ;oZ1?l000000onX_^Wo0000ojRojP0DojRojP03o`000?oooooooooo00cooooo00?o
0000ooooooooool0?oooool0043ooooo1?l0000looooo`;o00005?nX_nX00ol0003oZ;oZojRojP0?
ojRojP?o000000?oZ;oZo`000?nX_nX04onX_nX00ol0003oZ;oZojRojP0>ojRojP?o000000?oZ;oZ
o`000?nX_nX05OnX_nX00ol0003oZ;oZojRojP0:ojRojP?o00001OnX_^T00ol0003oZ;oZojRojP0C
ojRojP03o`000?oooooooooo00_ooooo00?o0000ooooooooool0?oooool003kooooo0_l00004oooo
o`03o`000?oooooooooo03Kooooo0ol000000onX_n[o0000ojRojP0DojRojP03o`000?nX_n[oZ;oZ
00coZ;oZ0_l00005ojRojP03o`000?nX_n[oZ;oZ01;oZ;oZ00?o0000ojRoj_nX_nX02_nX_nX3o`00
00GoZ;oZ00?o0000ojRoj_nX_nX04onX_nX00ol0003oZ;oZojRojP07ojRojP?o00000_nX_^T00ol0
003oZ;kYojRnj@04ojRnj@03o`000?nX_n[oZ;oZ01?oZ;oZ00?o0000ooooooooool02oooool00ol0
003oooooooooo`0nooooo`00>oooool3o`0003cooooo0ol00005ojRojP03o`000?nX_n[oZ;oZ01?o
Z;oZ00?o0000ojRoj_nX_nX02?nX_nX3o`0000SoZ;oZ00?o0000ojRoj_nX_nX04_nX_nX00ol0003o
Z;oZojRojP07ojRojP;o00002OnX_nX00ol0003oZ;oZojRojP0CojRojP03o`000?nX_n[oZ;oZ00?o
Z;oZ0ol00005ojRnj@03o`000?nX_^WoZ;kY00GoZ;kY00?o0000ojRoj_nX_nX04_nX_nX00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo03gooooo000iooooo`;o0000?Oooool2o`0000WoZ;oZ
00?o0000ojRoj_nX_nX04_nX_nX00ol0003oZ;oZojRojP06ojRojP;o00003?nX_nX00ol0003oZ;oZ
ojRojP0BojRojP03o`000?nX_n[oZ;oZ00?oZ;oZ0ol0000<ojRojP03o`000?nX_n[oZ;oZ01?oZ;oZ
00?o0000ojRoj_l000000_l00008ojRnj@03o`000?nX_^WoZ;kY00GoZ;kY00?o0000ojRoj_nX_nX0
4_nX_nX2o`0000cooooo0_l00009ooooo`Go0000<Oooool0013ooooo1Ol0000Qooooo`Co0000>ooo
ool3o`0000coZ;oZ00?o0000ojRoj_nX_nX04_nX_nX00ol0003oZ;oZojRojP03ojRojP;o00003_nX
_nX00ol0003oZ;oZojRojP0CojRojP03o`000?nX_n[o000000;o00004?nX_nX00ol0003oZ;oZojRo
jP0BojRojP;o00002onX_^T00ol0003oZ;kYojRnj@06ojRnj@03o`000?nX_n[oZ;oZ00koZ;oZ0ol0
00000onX_NSo0000ooooo`0=ooooo`03o`000?oooooooooo00Kooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A00aooooo`004?ooool01OnHV9So8B4Qonk^k_ooooooA4A401kooooo0ol00004ooooo`03o`00
0?oooooooooo03Gooooo0ol0000@ojRojP03o`000?nX_n[oZ;oZ01;oZ;oZ00?o0000ojRoj_l00000
0_l0000AojRojP03o`000?nX_n[oZ;oZ01;oZ;oZ0_l0000DojRojP03o`000?nX_n[oZ;oZ00koZ;oZ
0ol000000onX_NWo0000ojRnj@0;ojRnj@03o`000?nX_^WoZ;kY00KoZ;kY00?o0000ojRoj_nX_nX0
2_nX_nX3o`0000GoZ;gX00?o0000ooooooooool03?ooool00ol0003oooooooooo`06ooooo`03oiRH
V?lQ8B7ok^k^03;ooooo0008ooooo`Ko00000oooool00onHV9So8B4Qonk^kP0Mooooo`;o0000?Ooo
ool2o`0001CoZ;oZ00?o0000ojRoj_nX_nX04OnX_nX2o`0001GoZ;oZ00?o0000ojRoj_nX_nX03_nX
_nX3o`000003ojRoj_l0003oZ;oZ01?oZ;oZ00?o0000ojRoj_nX_nX02onX_nX3o`0000GoZ;gY00?o
0000ojRnjOnX_^T02OnX_^T00ol0003oZ;kYojRnj@06ojRnj@03o`000?nX_n[oZ;oZ00OoZ;oZ0ol0
0009ojRmj003o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool00onHV9So8B4Qonk^
kP0aooooo`004_ooool00onHV9So8B4Qonk^kP0Iooooo`?o0000??ooool3o`000003ojRoj_l0003o
Z;oZ01?oZ;oZ00?o0000ojRoj_nX_nX03_nX_nX3o`0000;oZ;oZ00?o0000ojRoj_nX_nX04onX_nX0
0ol0003oZ;oZojRojP0:ojRojP?o00001OnX_nX00ol0003oZ;oZojRojP0BojRojP03o`000?nX_n[o
Z;oZ00OoZ;oZ0ol00009ojRmj@03o`000?nX_^WoZ;kY00SoZ;kY00?o0000ojRnjOnX_^T01onX_^T0
0ol0003oZ;oZojRojP03ojRojP?o00003OnX_NP00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00Oooooo00?oMgMgofIVI_ooool0<?ooool001?ooooo00?oMgMgofIVI_ooool05_ooool2o`00
0003ooooool0003ooooo03Wooooo0ol00005ojRojP03o`000?nX_n[oZ;oZ01;oZ;oZ00?o0000ojRo
j_nX_nX02_nX_nX3o`0000KoZ;oZ00?o0000ojRoj_nX_nX04_nX_nX00ol0003oZ;oZojRojP07ojRo
jP?o00002OnX_nX00ol0003oZ;oZojRojP0BojRojP03o`000?nX_n[oZ;oZ00?oZ;oZ0ol0000=ojRm
j@03o`000?nX_^WoZ;kY00OoZ;kY00?o0000ojRnjOnX_^T02?nX_^T00ol0003oZ;oZo`000002o`00
013oZ;gX00?o0000ooooooooool03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
02oooooo000Dooooo`03o`000?oooooooooo01;ooooo0ol00004ooooo`03o`000?oooooooooo03Go
oooo0_l00009ojRojP03o`000?nX_n[oZ;oZ01;oZ;oZ00?o0000ojRoj_nX_nX01onX_nX2o`0000[o
Z;oZ00?o0000ojRoj_nX_nX04_nX_nX00ol0003oZ;oZojRojP03ojRojP?o00003OnX_nX00ol0003o
Z;oZojRojP0BojRojP03o`000?nX_n[o000000;o00004?nX_NT00ol0003oZ;kYojRnj@07ojRnj@03
o`000?nX_^WoZ;kY00SoZ;kY0_l0000DojRmj003o`000?oooooooooo00_ooooo0_l00004ooooo`05
o`000?nj^[[ooooooiRHV?l@4100<Oooool0013ooooo00Go0000okZj^_ooooooV9RHoa0@400Boooo
o`;o0000??ooool3o`0000coZ;oZ00?o0000ojRoj_nX_nX04_nX_nX00ol0003oZ;oZojRojP03ojRo
jP?o00003OnX_nX00ol0003oZ;oZojRojP0BojRojP03o`000?nX_n[o000000;o00004?nX_nX00ol0
003oZ;oZojRojP0BojRojP;o00005?nX_NT00ol0003oZ;kYojRnj@06ojRnj@03o`000?nX_^WoZ;kY
00GoZ;kY0ol000000onX^NGo0000ojRmj00DojRmj003o`000?oooooooooo00Wooooo00?o0000oooo
ool000001?ooool01OnHV9So410@o`000?lQ8B7oc<c<037ooooo000@ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`03oooool3o`0003_ooooo0ol0000@ojRojP03o`000?nX_n[oZ;oZ01;oZ;oZ00?o0000
ojRoj_l000000_l0000AojRojP03o`000?nX_n[oZ;oZ013oZ;oZ0ol0000DojRojP03o`000?nX_n[o
Z;oZ00koZ;oZ0ol000000onX_>So0000ojRmj@0DojRmj@03o`000?nX_^WoZ;kY00GoZ;kY00?o0000
ojRnjOnX_^T00_nX_^T3o`0000GoZ;WU00?o0000ojRmj?nX_NP04_nX_NP00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo03Oooooo000Qooooo`?o00000_ooool00ol0003oooooooooo`0goooo
o`;o00005?nX_nX00ol0003oZ;oZojRojP0@ojRojP?o00005OnX_nX00ol0003oZ;oZojRojP0<ojRo
jP?o00000_nX_nX00ol0003oZ;oZojRojP0CojRojP03o`000?nX_n[oZ;oZ00[oZ;oZ0ol00005ojRl
j003o`000?nX_NWoZ;gY01;oZ;gY00?o0000ojRnjOnX_^T01?nX_^T2o`000004ojRnjOl0003o0000
o`0000WoZ;WU00?o0000ojRmj?nX_NP04_nX_NP00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo03Oooooo000Oooooo`;o0000??ooool3o`0000;oZ;oZ00?o0000ojRoj_nX_nX04_nX_nX00ol0
003oZ;oZojRojP0<ojRojP?o00000onX_nX00ol0003oZ;oZojRojP0CojRojP03o`000?nX_n[oZ;oZ
00SoZ;oZ0ol00006ojRojP03o`000?nX_n[oZ;oZ01;oZ;oZ00?o0000ojRoj_nX_nX01onX_nX3o`00
00WoZ;cX00?o0000ojRmjOnX_NT04_nX_NT00ol0003oZ;kYojRnj@06o`0000goZ;WU00?o0000ojRm
j?nX_NP04_nX_NP00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03Kooooo000Looooo`?o
0000??ooool2o`0000KoZ;oZ00?o0000ojRoj_nX_nX04_nX_nX00ol0003oZ;oZojRojP08ojRojP?o
00001onX_nX00ol0003oZ;oZojRojP0CojRojP03o`000?nX_n[oZ;oZ00CoZ;oZ0ol0000:ojRojP03
o`000?nX_n[oZ;oZ01;oZ;oZ00?o0000ojRoj_nX_nX00onX_nX3o`0000goZ;cX00?o0000ojRmjOnX
_NT04OnX_NT6o`0000;oZ;WU00?o0000ojRiiOnX^ND02onX^ND00ol0003oZ;gXojRmj00BojRmj0;o
00003Oooool00ol0003oooooooooo`0eooooo`006oooool3o`0003[ooooo0ol00009ojRojP03o`00
0?nX_n[oZ;oZ01;oZ;oZ00?o0000ojRoj_nX_nX01?nX_nX3o`0000_oZ;oZ00?o0000ojRoj_nX_nX0
4onX_nX00ol0003oZ;oZojRojP03o`0000koZ;oZ00?o0000ojRoj_nX_nX04_nX_nX00ol0003oZ;oZ
o`000002o`00013oZ;cX00?o0000ojRmjOnX_NT03_nX_NT3o`000003ojRmjOl0003o000000KoZ;WU
00?o0000ojRiiOnX^ND02onX^ND00ol0003oZ;gXojRmj00>ojRmj0?o000000?oZKSSo`000?ooool0
3?ooool00ol0003oooooooooo`0eooooo`006oooool00ol0003oooooo`00000hooooo`;o00003OnX
_nX00ol0003oZ;oZojRojP0BojRojP03o`000?nX_n[oZ;oZ00?o00003onX_nX00ol0003oZ;oZojRo
jP0BojRojP?o00004_nX_nX00ol0003oZ;oZojRojP0@ojRojP?o00005?nX_>P00ol0003oZ;gYojRm
j@0:ojRmj@?o000000KoZ;gYo`000?l0003o0000ojRagol00007ojRii@03o`000?nX^NGoZ;WU00_o
Z;WU00?o0000ojRmj?nX_NP02_nX_NP3o`0000GoZKSS00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0dooooo`004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo0_l000000ooooooo
0000ooooo`0cooooo`?o00004?nX_nX00ol0003oZ;oZojRojP0AojRojP?o00004onX_nX00ol0003o
Z;oZojRojP0>ojRojP?o000000?oZ;oZo`000?nX_nX04onX_nX00ol0003oZ;oZojRojP0<ojRojP?o
00000_nX^^H00ol0003oZ;cXojRlj00CojRlj003o`000?nX_NWoZ;gY00KoZ;gY0ol000001?nX_NWo
0000o`000?l00005ojRag`03o`000?nX^NGoZ;WU00CoZ;WU00?o0000ojRiiOnX^ND02onX^ND00ol0
003oZ;gXojRmj007ojRmj0?o00002OnY^><00ol0003oooooooooo`0:ooooo`;o0000=Oooool0013o
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`05o`000?ooooooooooooooool00000<Oooool2
o`0001CoZ;oZ00?o0000ojRoj_nX_nX03OnX_nX3o`000003ojRoj_l0003oZ;oZ01CoZ;oZ00?o0000
ojRoj_nX_nX02_nX_nX3o`0000GoZ;oZ00?o0000ojRoj_nX_nX04_nX_nX00ol0003oZ;oZojRojP08
ojRojP?o00001_nX^^H00ol0003oZ;cXojRlj00BojRlj003o`000?nX_NWoZ;gY00?oZ;gY0ol00000
1?nX_NWo0000o`000?l00009ojRag`03o`000?nX^NGoZ;WU00CoZ;WU00?o0000ojRiiOnX^ND02onX
^ND00ol0003oZ;gXojRmj003ojRmj0?o00003?nY^><00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo03?ooooo000@ooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo02_ooooo0ol000000onX_n[o0000ojRojP0DojRojP03o`000?nX
_n[oZ;oZ00[oZ;oZ0_l00005ojRojP03o`000?nX_n[oZ;oZ01?oZ;oZ00?o0000ojRoj_nX_nX01onX
_nX2o`0000WoZ;oZ00?o0000ojRoj_nX_nX04_nX_nX00ol0003oZ;oZojRojP04ojRojP?o00002_nX
^^H00ol0003oZ;cXojRlj00BojRlj003o`000?nX_NWo000000;o000000CoZ;gYo`000?l0003o0000
3?nX/Ml00ol0003oZ;WUojRii@05ojRii@03o`000?nX^NGoZ;WU00_oZ;WU00?o0000ojRmj?l00000
0_l0000@ojVhh`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0<_ooool0013ooooo00Go
0000ooooooooooooooooo`000005ooooo`;o00001Oooool00ol0003oooooooooo`0Xooooo`;o0000
1OnX_nX00ol0003oZ;oZojRojP0CojRojP03o`000?nX_n[oZ;oZ00KoZ;oZ0ol00008ojRojP03o`00
0?nX_n[oZ;oZ01?oZ;oZ00?o0000ojRoj_nX_nX00onX_nX3o`0000coZ;oZ00?o0000ojRoj_nX_nX0
4_nX_nX00ol0003oZ;oZojRojP03o`0000koZ;[V00?o0000ojRlj?nX_>P04OnX_>P2o`000004ojRm
jOl0003o0000o`00013oZ;7O00?o0000ojRiiOnX^ND01?nX^ND00ol0003oZ;WUojRii@0;ojRii@;o
00005?nY^><00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo037ooooo000@ooooo`05o`00
0?ooooooooooooooool000001Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo02Co
oooo0ol00008ojRojP03o`000?nX_n[oZ;oZ01?oZ;oZ00?o0000ojRoj_nX_nX00onX_nX2o`0000co
Z;oZ00?o0000ojRoj_nX_nX04onX_nX00ol0003oZ;oZo`000002o`00013oZ;oZ00?o0000ojRoj_nX
_nX04OnX_nX3o`0001;oZ;[V00?o0000ojRlj?nX_>P03OnX_>P3o`000003ojRlj?l0003o000001Co
Z;7O00?o0000ojRiiOnX^ND01?nX^ND00ol0003oZ;WUojRii@07ojRii@?o000000?oZZgIo`000?nY
^><04onY^><00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo037ooooo000@ooooo`05oa0@
4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo027o
oooo0_l0000<ojRojP03o`000?nX_n[oZ;oZ01?oZ;oZ00?o0000ojRoj_l000000_l0000?ojRojP03
o`000?nX_n[oZ;oZ01;oZ;oZ0_l0000DojRojP03o`000?nX_n[oZ;oZ00goZ;oZ0ol000000onX^NGo
0000ojRjiP0CojRjiP03o`000?nX_>SoZ;cX00WoZ;cX0ol000001_nX_>So0000o`000?l0003oYjKF
o`0001CoZ;7O00?o0000ojRiiOnX^ND01OnX^ND00ol0003oZ;WUojRii@04ojRii@;o00001OnZ[MT0
0ol0003oZKSSojVhh`0BojVhh`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0<?ooool0
013ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool07Oooool3o`0000ooZ;oZ00?o0000ojRoj_nX_nX04_nX_nX2o`0001?oZ;oZ00?o0000
ojRoj_nX_nX03_nX_nX3o`000003ojRoj_l0003oZ;oZ01?oZ;oZ00?o0000ojRoj_nX_nX02_nX_nX3
o`0000GoZ;WU00?o0000ojRji_nX^^H04OnX^^H00ol0003oZ;cXojRlj006ojRlj0?o000000CoZ;cX
o`000?l0003o00001OnWY]H00ol0003oZ;7OojRag`0BojRag`03o`000?nX^NGoZ;WU00GoZ;WU00?o
0000ojRiiOnX^ND00ol00007ojZ]f@03o`000?nY^>?oZKSS01;oZKSS00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0`ooooo`004?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`0Jooooo`;o00004onX_nX00ol0003oZ;oZojRo
jP0>ojRojP?o000000?oZ;oZo`000?nX_nX04onX_nX00ol0003oZ;oZojRojP0:ojRojP?o00001OnX
_nX00ol0003oZ;oZojRojP0BojRojP03o`000?nX_n[oZ;oZ00OoZ;oZ0_l00009ojRii@03o`000?nX
^^KoZ;[V017oZ;[V00?o0000ojRlj?nX_>P00_nX_>P3o`0000;oZ;cX0_l00009ojNVeP03o`000?nX
/MooZ;7O01;oZ;7O00?o0000ojRiiOnX^ND01?nX^ND3o`0000_oZZgI00?o0000ojVhhonY^><04_nY
^><00ol0003oooooooooo`0:ooooo`;o0000<Oooool001Wooooo0_l0000;ooooo`03o`000?oooooo
oooo01Kooooo0ol00002ojRojP03o`000?nX_n[oZ;oZ017oZ;oZ00?o0000ojRoj_nX_nX02_nX_nX3
o`0000GoZ;oZ00?o0000ojRoj_nX_nX04_nX_nX00ol0003oZ;oZojRojP07ojRojP;o00002OnX_nX0
0ol0003oZ;oZojRojP0BojRojP03o`000?nX_n[oZ;oZ00?oZ;oZ0ol0000<ojRii@03o`000?nX^^Ko
Z;[V017oZ;[V1?l00002ojRlj0?o00002onWY]H00ol0003oZ;7OojRag`0BojRag`03o`000?nX^NGo
Z;WU00?oZ;WU0ol0000=ojZ]f@03o`000?nY^>?oZKSS017oZKSS0_l0000=ooooo`03o`000?oooooo
oooo02kooooo000Iooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool04oooool2o`00
00KoZ;oZ00?o0000ojRoj_nX_nX04OnX_nX00ol0003oZ;oZojRojP07ojRojP;o00002OnX_nX00ol0
003oZ;oZojRojP0BojRojP03o`000?nX_n[oZ;oZ00?oZ;oZ0ol0000<ojRojP03o`000?nX_n[oZ;oZ
01;oZ;oZ00?o0000ojRoj_l000000_l0000?ojRii@03o`000?nX^^KoZ;[V00ooZ;[V1?l000001?nX
_>So0000o`000?l0000?ojNVeP03o`000?nX/MooZ;7O01;oZ;7O00?o0000ojRiiOl000000_l00003
ojZ]f@03o`000?nZ[MWoZZgI00[oZZgI00?o0000ojVhhonY^><03_nY^><3o`000003ojnlhol0003o
oooo00cooooo00?o0000ooooooooool0;_ooool001Wooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0?ooooo`?o00002OnX_nX00ol0003oZ;oZojRojP0AojRojP03o`000?nX_n[oZ;oZ
00?oZ;oZ0ol0000<ojRojP03o`000?nX_n[oZ;oZ01;oZ;oZ00?o0000ojRoj_l000000_l0000@ojRo
jP03o`000?nX_n[oZ;oZ017oZ;oZ0_l0000CojRii@03o`000?nX^^KoZ;[V00_oZ;[V0ol00003ojRj
iP;o00004_nWY]H00ol0003oZ;7OojRag`0BojRag`;o00001onZ[MT00ol0003oZZgIojZ]f@0:ojZ]
f@03o`000?nY^>?oZKSS00_oZKSS0_l00005ojnlh`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool0;Oooool001Wooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`;o
00003OnX_nX00ol0003oZ;oZojRojP0AojRojP03o`000?nX_n[o000000;o00004?nX_nX00ol0003o
Z;oZojRojP0AojRojP;o00005?nX_nX00ol0003oZ;oZojRojP0=ojRojP?o000000?oZ;SUo`000?nX
^ND04onX^ND00ol0003oZ;[VojRjiP07ojRjiP?o00000onX^^H3o`000003ojBKc?l0003oYjKF01;o
YjKF00?o0000ojRagonX/Ml03_nX/Ml3o`000003ojVLbOl0003oZZgI00KoZZgI00?o0000ojZ]fOnZ
[MT02_nZ[MT00ol0003oZKSSojVhh`08ojVhh`?o00002?n__><00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo02cooooo000Iooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
2?ooool3o`00013oZ;oZ00?o0000ojRoj_nX_nX04?nX_nX3o`0001?oZ;oZ00?o0000ojRoj_nX_nX0
3OnX_nX3o`0000;oZ;oZ00?o0000ojRoj_nX_nX04OnX_nX00ol0003oZ;oZojRojP0:ojRojP?o0000
1OnX^>D00ol0003oZ;WUojRii@0BojRii@03o`000?nX^^KoZ;[V00CoZ;[V0_l00003ojRjiP?o0000
1OnTVl`00ol0003oYjKFojNVeP0AojNVeP03o`000?nX/MooZ;7O00_oZ;7O0_l00005ojVLb@03o`00
0?nZ[MWoZZgI00GoZZgI00?o0000ojZ]fOnZ[MT02_nZ[MT00ol0003oZKSSojVhh`05ojVhh`;o0000
2on__><00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02cooooo000Hooooo`?o00004?oo
ool2o`0000Kooooo0ol0000CojRojP03o`000?nX_n[oZ;oZ00coZ;oZ0ol00003ojRojP03o`000?nX
_n[oZ;oZ017oZ;oZ00?o0000ojRoj_nX_nX02_nX_nX2o`0000KoZ;oZ00?o0000ojRoj_nX_nX04OnX
_nX00ol0003oZ;oZojRojP07ojRojP;o00002OnX^>D00ol0003oZ;WUojRii@0AojRii@04o`000?nX
^^KoZ;[VojRjiP?o00000onX^^H2o`0000SoY9_<00?o0000ojNVe_nWY]H04OnWY]H00ol0003oZ;7O
ojRag`08ojRag`?o00001onYW<T00ol0003oZZgIojZ]f@06ojZ]f@03o`000?nZ[MWoZZgI00[oZZgI
00?o0000ojVhhonY^><00_nY^><2o`0000ko[kcS00?o0000ooooooooool02oooool2o`0002cooooo
000Hooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00ol00003ojRojP03o`000?nX
_n[oZ;oZ017oZ;oZ00?o0000ojRoj_nX_nX02?nX_nX3o`0000OoZ;oZ00?o0000ojRoj_nX_nX04OnX
_nX00ol0003oZ;oZojRojP06ojRojP?o00002OnX_nX00ol0003oZ;oZojRojP0AojRojP03o`000?nX
_n[oZ;oZ00?oZ;oZ0ol0000<ojRhi@03o`000?nX^NGoZ;WU017oZ;WU0ol00003ojRjiP?o00002onT
Vl`00ol0003oYjKFojNVeP0AojNVeP03o`000?nX/MooZ;7O00GoZ;7O0_l0000;ojVLb@03o`000?nZ
[MWoZZgI00GoZZgI00?o0000ojZ]fOnZ[MT02_nZ[MT00ol0003oZKSSo`000002o`00017o[kcS00?o
0000ooooooooool02_ooool2o`0002cooooo000Hooooo`03o`000?oooooooooo01;ooooo0ol00007
ojRojP03o`000?nX_n[oZ;oZ017oZ;oZ00?o0000ojRoj_nX_nX01?nX_nX3o`0000_oZ;oZ00?o0000
ojRoj_nX_nX04OnX_nX00ol0003oZ;oZojRojP03ojRojP;o00003OnX_nX00ol0003oZ;oZojRojP0A
ojRojP03o`000?nX_n[o000000;o00004?nX^>D00ol0003oZ;WUojRii@0=ojRii@?o000000?oZ;WU
o`000?nX^^H00ol0000>ojBKc003o`000?nWY]KoYjKF017oYjKF00?o0000ojRagonX/Ml00onX/Ml2
o`0000koZIc900?o0000ojZ]fOnZ[MT01OnZ[MT00ol0003oZZgIojZ]f@09ojZ]f@;o00005?n__><0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02[ooooo000Hooooo`03o`000?oooooooooo
00oooooo0ol0000;ojRojP03o`000?nX_n[oZ;oZ017oZ;oZ00?o0000ojRoj_nX_nX00ol0000?ojRo
jP03o`000?nX_n[oZ;oZ017oZ;oZ00?o0000ojRoj_l000000_l0000@ojRojP03o`000?nX_n[oZ;oZ
013oZ;oZ0_l0000DojRhi@03o`000?nX^NGoZ;WU00WoZ;WU0ol00003ojRii@?o00004_nTVl`00ol0
003oYjKFojNVeP0AojNVeP03o`000?nX/Moo000000;o00004?nYW<T00ol0003oZZgIojZ]f@06ojZ]
f@03o`000?nZ[MWoZZgI00KoZZgI0_l000000ong]]So0000ojnlh`0Dojnlh`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool0:Oooool001Sooooo00?o0000ooooooooool03?ooool3o`0000oo
Z;oZ00?o0000ojRoj_nX_nX04?nX_nX3o`0001?oZ;oZ00?o0000ojRoj_nX_nX04?nX_nX2o`0001Co
Z;oZ00?o0000ojRoj_nX_nX03?nX_nX3o`000003ojRiiOl0003oZ;SU01?oZ;SU00?o0000ojRiiOnX
^ND01_nX^ND3o`0000?oZ;WU0ol00002oj:DaP03o`000?nTVlcoY9_<013oY9_<00?o0000ojNVe_nW
Y]H04OnWY]H2o`0001CoZIc900?o0000ojZ]fOnZ[MT01_nZ[MT00ol0003oZZgIojZ]f@04ojZ]f@03
o`000?ng]]So]kKH00;o]kKH00?o0000ojnlhon__><04_n__><00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo02Sooooo000Hooooo`;o00002_ooool3o`0001?oZ;oZ00?o0000ojRoj_nX_nX0
3?nX_nX3o`0000?oZ;oZ00?o0000ojRoj_nX_nX04OnX_nX00ol0003oZ;oZojRojP0<ojRojP?o0000
00?oZ;oZo`000?nX_nX05?nX_nX00ol0003oZ;oZojRojP08ojRojP?o00001OnX^ND00ol0003oZ;SU
ojRhi@0BojRhi@03o`000?nX^NGoZ;WU00;oZ;WU0ol00003ojRii@?o00001_nRU<H00ol0003oY9_<
ojBKc00@ojBKc003o`000?nWY]KoYjKF00koYjKF0_l000000onWS[_o0000ojVLb@0CojVLb@03o`00
0?nZ[MWoZZgI00KoZZgI00?o0000ojZ]fOnZ[MT00_nZ[MT2o`0000Ko]kKH00?o0000ojnlhon__><0
4_n__><00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02Sooooo000Hooooo`03o`000?oo
oooooooo00Kooooo0ol00003ojRojP03o`000?nX_n[oZ;oZ017oZ;oZ00?o0000ojRoj_nX_nX02OnX
_nX2o`0000OoZ;oZ00?o0000ojRoj_nX_nX04OnX_nX00ol0003oZ;oZojRojP08ojRojP?o00001OnX
_nX00ol0003oZ;oZojRojP0CojRojP03o`000?nX_n[oZ;oZ00CoZ;oZ0ol00009ojRii@03o`000?nX
^>GoZ;SU01;oZ;SU1?l00003ojRii@?o00002OnRU<H00ol0003oY9_<ojBKc00AojBKc003o`000?nW
Y]KoYjKF00_oYjKF0_l00004ojN>^`03o`000?nYW<WoZIc901;oZIc900?o0000ojZ]fOnZ[MT01_nZ
[MT01?l0003oZZgIo`000?l00008okNff003o`000?n__>?o[kcS01;o[kcS0_l0000=ooooo`03o`00
0?oooooooooo02Oooooo000Hooooo`03o`000?oooooooooo00Cooooo0_l00007ojRojP03o`000?nX
_n[oZ;oZ017oZ;oZ00?o0000ojRoj_nX_nX01_nX_nX2o`0000[oZ;oZ00?o0000ojRoj_nX_nX04OnX
_nX00ol0003oZ;oZojRojP04ojRojP?o00002OnX_nX00ol0003oZ;oZojRojP0CojRojP03o`000?nX
_n[oZ;oZ00?o00003OnX^ND00ol0003oZ;SUojRhi@0@ojRhi@?o00000_nX^ND3o`0000goXYC600?o
0000ojBKc?nTVl`04?nTVl`00ol0003oYjKFojNVeP09ojNVeP;o00001_nWS[/00ol0003oZIc9ojVL
b@0BojVLb@03o`000?nZ[MWoZZgI00KoZZgI0_l0000;okNff003o`000?n__>?o[kcS00ko[kcS0ol0
00000onebn_o0000ooooo`0<ooooo`;o0000:?ooool001Oooooo00?o0000ooooooooool00oooool2
o`0000[oZ;oZ00?o0000ojRoj_nX_nX04OnX_nX00ol0003oZ;oZojRojP02ojRojP?o00003OnX_nX0
0ol0003oZ;oZojRojP0AojRojP03o`000?nX_n[oZ;oZ00?o00003OnX_nX00ol0003oZ;oZojRojP0B
ojRojP?o00004OnX^ND00ol0003oZ;SUojRhi@0<ojRhi@?o00000_nX^>D3o`00013oXYC600?o0000
ojBKc?nTVl`04OnTVl`00ol0003oYjKFojNVeP06ojNVeP;o00002OnWS[/00ol0003oZIc9ojVLb@0B
ojVLb@03o`000?nZ[MWoZZgI00?oZZgI0_l00002okNff003o`000?ng]]So]kKH00Wo]kKH00?o0000
ojnlhon__><02on__><2o`0000Go]L_[00?o0000ooooooooool02oooool00ol0003oooooooooo`07
ooooo`05oiRHV?l@413o0000oc8b<_o<c<`06_ooool001Oooooo00?o0000ooooooooool00ol0000=
ojRojP03o`000?nX_n[oZ;oZ017oZ;oZ00Co0000ojRoj_l0003o00004OnX_nX00ol0003oZ;oZojRo
jP0@ojRojP?o00004OnX_nX00ol0003oZ;oZojRojP0>ojRojP?o000000?oZ;[Wo`000?nX^ND04_nX
^ND00ol0003oZ;SUojRhi@08ojRhi@?o00000_nX^>D3o`000003oj6Aa?l0003oXYC6013oXYC600?o
0000ojBKc?nTVl`04OnTVl`00ol0003oYjKFojNVeP04ojNVeP;o00002onWS[/00ol0003oZIc9ojVL
b@0CojVLb@05o`000?nZ[MWoZZgIojZ]fOl000001?ng]]P00ol0003o]kKHokNff009okNff003o`00
0?n__>?o[kcS00So[kcS0ol00008okG;j`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
1_ooool01Ol@413o^[ZjoooooomgMgOo<S8b01[ooooo000Gooooo`?o00004OnX_nX00ol0003oZ;oZ
ojRojP0@ojRojP;o00005?nX_nX00ol0003oZ;oZojRojP0<ojRojP?o000000?oZ;oZo`000?nX_nX0
4_nX_nX00ol0003oZ;oZojRojP0:ojRojP?o00001OnX^^L00ol0003oZ;WUojRii@0@ojRii@03o`00
0?nX^>GoZ;SU00GoZ;SU0ol00002ojRhi@?o00001OnQTL@00ol0003oXYC6oj:DaP0?oj:DaP03o`00
0?nTVlcoY9_<017oY9_<00Co0000ojNVe_nWY]KoYjKF0_l0000>ojN>^`03o`000?nYW<WoZIc901;o
ZIc900Co0000ojZ]fOl0003o00001_ng]]P00ol0003o]kKHokNff009okNff003o`000?n__>?o[kcS
00Go[kcS0_l0000<okG;j`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0Hooooo`005oooool2o`0001?oZ;oZ00?o0000ojRoj_nX_nX03?nX_nX3o`0000;o
Z;oZ00?o0000ojRoj_nX_nX04_nX_nX00ol0003oZ;oZojRojP08ojRojP?o00001OnX_nX00ol0003o
Z;oZojRojP0AojRojP03o`000?nX_n[oZ;oZ00OoZ;oZ0_l00009ojRji`03o`000?nX^NGoZ;WU013o
Z;WU00Co0000ojRhiOnX^>GoZ;SU0ol00003ojRhi@;o00002?nQTL@00ol0003oXYC6oj:DaP0?oj:D
aP03o`000?nTVlcoY9_<017oY9_<00Co0000ojNVe_l0003o00004?nWS[/00ol0003oZIc9ojVLb@0B
ojVLb@;o00002Ong]]P00ol0003o]kKHokNff008okNff003o`000?n__>?o[kcS00?o[kcS0_l0000?
okG;j`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02?ooool00onYZJWo410@ooooo`0I
ooooo`003Oooool4o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooool000004onX_nX00ol0
003oZ;oZojRojP08ojRojP?o00001_nX_nX00ol0003oZ;oZojRojP0BojRojP03o`000?nX_n[oZ;oZ
00CoZ;oZ0ol00009ojRojP03o`000?nX_n[oZ;oZ017oZ;oZ00?o0000ojRoj_nX_nX00onX_nX3o`00
00coZ;[W00?o0000ojRiiOnX^ND04?nX^ND3o`0000?oZ;SU0ol0000:oj6Aa003o`000?nRU<KoXYC6
013oXYC600?o0000ojBKc?nTVl`04?nTVl`2o`0001?oYhjk00?o0000ojVLbOnYW<T04?nYW<T00ol0
003o_Jg9o`000009okNff003o`000?ng]]So]kKH00Wo]kKH00?o0000ojnlhol000000_l0000AokG;
j`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool00ol@413o0000okZj^P0Joooo
o`003oooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0001?oZ;oZ00?o0000ojRo
j_nX_nX01?nX_nX3o`0000[oZ;oZ00?o0000ojRoj_nX_nX04_nX_nX00ol0003oZ;oZojRojP03o`00
00goZ;oZ00?o0000ojRoj_nX_nX04OnX_nX00ol0003oZ;oZo`000002o`00013oZ;[W00?o0000ojRi
iOnX^ND03?nX^ND3o`000003ojRiiOl0003oZ;SU00?o00003_nQTL@00ol0003oXYC6oj:DaP0?oj:D
aP03o`000?nTVlcoY9_<00koY9_<0_l000000onSQ;;o0000ojN>^`0BojN>^`03o`000?nYW<WoZIc9
00ooZIc900Go0000okf]bOnm[LWo_Jg9o`000009okNff003o`000?ng]]So]kKH00So]kKH0_l0000E
okG;j`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool00onj^[[o8B4Qooooo`0I
ooooo`003oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ojRo
j_nX_nX04OnX_nX00ol0003oZ;oZojRojP03o`0000koZ;oZ00?o0000ojRoj_nX_nX04OnX_nX3o`00
017oZ;oZ00?o0000ojRoj_nX_nX04?nX_nX2o`0001CoZ;[W00?o0000ojRiiOnX^ND02?nX^ND3o`00
00CoZ;WU0_l0000Aoj6Aa003o`000?nRU<KoXYC6013oXYC600?o0000ojBKc?nTVl`03?nTVl`00ol0
003oXhBboj>4/P02oj>4/P03o`000?nWS[_oYhjk017oYhjk00?o0000ojVLbOnYW<T03?nYW<T2o`00
00Co_Jg900?o0000okNff?ng]]P02?ng]]P00ol0003o]kKHokNff006okNff003o`000?o8gNSo0000
01Ko]L_[00?o0000ooooooooool02Oooool3o`0000Cooooo00Go410@oiRHV?oooooo^[Zjo`00000J
ooooo`003oooool00ol0003oooooooooo`04ooooo`;o00001?ooool2o`00017oZ;oZ0ol0000BojRo
jP03o`000?nX_n[oZ;oZ00goZ;oZ0ol00002ojRojP03o`000?nX_n[oZ;oZ013oZ;oZ00?o0000ojRo
j_nX_nX03?nX_nX3o`0000;oZ;cX00?o0000ojRjionX^^L04OnX^^L00ol0003oZ;WUojRii@06ojRi
i@;o00001?nX^ND3o`000003oj6Ca_l0003oXI74013oXI7400?o0000oj:Da_nRU<H04?nRU<H00ol0
003oY9_<ojBKc00:ojBKc0;o00001OnSQ;800ol0003oYhjkojN>^`0AojN>^`03o`000?nYW<WoZIc9
00_oZIc900?o0000okf]bOnm[LT01Onm[LT00ol0003o]kKHokNff008okNff003o`000?ng]]So]kKH
00?o]kKH0_l00003olSMj003o`000?nebn_o]L_[01?o]L_[0_l0000<ooooo`03o`000?oooooooooo
00;ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@0Jooooo`003oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Gooooo00?o0000ojRoj_nX_nX02onX_nX3o`0000?oZ;oZ00?o0000ojRo
j_nX_nX04?nX_nX00ol0003oZ;oZojRojP0:ojRojP;o00001_nX_nX00ol0003oZ;oZojRojP0@ojRo
jP03o`000?nX_n[oZ;oZ00SoZ;oZ0ol00006ojRlj003o`000?nX^^OoZ;[W017oZ;[W00?o0000ojRi
iOnX^ND00_nX^ND3o`0000?oZ;WU0ol00005oj6CaP03o`000?nQTLCoXI7400ooXI7400?o0000oj:D
a_nRU<H04?nRU<H00ol0003oY9_<ojBKc007ojBKc0;o00001onSQ;800ol0003oYhjkojN>^`0AojN>
^`03o`000?nYW<WoZIc900[oZIc900?o0000okf]bOnm[LT01_nm[LT00ol0003o]kKHokNff008okNf
f003o`000?ng]]So]kKH00;o]kKH00?o0000olSMj?o8gNP01?o8gNP00ol0003o]L_[okG;j`0?okG;
j`?o000000?o/<_^o`000?ooool03?ooool00ol0003oooooooooo`0Pooooo`003oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o0000ojRoj_nX_nX01onX_nX3o`0000Oo
Z;oZ00?o0000ojRoj_nX_nX04?nX_nX00ol0003oZ;oZojRojP06ojRojP?o00002OnX_nX00ol0003o
Z;oZojRojP0@ojRojP03o`000?nX_n[oZ;oZ00CoZ;oZ0ol0000:ojRlj003o`000?nX^^OoZ;[W017o
Z;[W1?l00003ojRii@?o00002?nQTlH00ol0003oXI74oj6Aa00?oj6Aa003o`000?nRU<KoXYC6013o
XYC600?o0000ojBKc?nTVl`01OnTVl`2o`0000[oXhBb00?o0000ojN>^onWS[/04OnWS[/00ol0003o
ZIc9ojVLb@07ojVLb@;o00002_nm[LT00ol0003o]kKHokNff008okNff004o`000?ng]]So0000o`00
00Sob=gX00?o0000okG;jonebn/03?nebn/2o`0000Go/<_^00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0Pooooo`003oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ojRoj_nX_nX00onX_nX3o`0000_oZ;oZ00?o0000ojRoj_nX_nX04?nX_nX00ol0003o
Z;oZojRojP03ojRojP;o00003OnX_nX00ol0003oZ;oZojRojP0@ojRojP03o`000?nX_n[oZ;oZ00?o
00003_nX_>P00ol0003oZ;[WojRji`0>ojRji`Co00000_nX^ND3o`0000coXI?600?o0000oj6Aa?nQ
TL@03onQTL@00ol0003oXYC6oj:DaP0?oj:DaP03o`000?nTVlcoY9_<00?oY9_<0_l0000<oj>4/P03
o`000?nWS[_oYhjk017oYhjk00?o0000ojVLbOnYW<T01_nYW<T00ol0003o_Jg9okf]b@0;okf]b@03
o`000?ng]]So]kKH00So]kKH00?o0000olSMj?o8gNP02Oo8gNP00ol0003o]L_[okG;j`08okG;j`?o
00002?n`bnh00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01oooooo000=ooooo`03oeEE
EOmVIVKo000000Kooooo00?o0000ooooooooool02?ooool00ol0003oZ;oZo`000002o`0000ooZ;oZ
00?o0000ojRoj_nX_nX04?nX_nX00ol0003oZ;oZo`000002o`00013oZ;oZ00?o0000ojRoj_nX_nX0
3onX_nX3o`0001;oZ;cX00?o0000ojRjionX^^L02_nX^^L3o`0000?oZ;[W0ol0000?oj6CaP03o`00
0?nQTLCoXI7400ooXI7400?o0000oj:Da_nRU<H04?nRU<H01Ol0003oY9_<ojBKc?nTVlco000000ko
XhBb00?o0000ojN>^onWS[/04_nWS[/00ol0003oZIc9ojVLb@04ojVLb@03o`000?nm[LWo_Jg900co
_Jg900?o0000okNff?ng]]P01ong]]P00ol0003ob=gXo`00000:olSMj003o`000?nebn_o]L_[00Ko
]L_[0_l0000;ok3;kP03o`000?oooooooooo00_ooooo00?o0000ooooooooool07_ooool001Gooooo
00?o0000ooooooooool02_ooool00ol0003oZ;oZojRojP0AojRojP03o`000?nX_n[oZ;oZ00ooZ;oZ
0ol0000CojRojP03o`000?nX_n[oZ;oZ00_oZ;oZ0ol00002ojRmj@03o`000?nX_>SoZ;cX017oZ;cX
00?o0000ojRjionX^^L01_nX^^L3o`0000?oZ;[W0ol000000onRV/go0000oj6CaP0?oj6CaP03o`00
0?nQTLCoXI7400ooXI7400?o0000oj:Da_nRU<H04?nRU<H01?l0003oY9_<o`000?l0000@oj>4/P03
o`000?nWS[_oYhjk017oYhjk00?o0000ojVLbOnYW<T00_nYW<T2o`00013o_Jg900?o0000okNff?ng
]]P01?ng]]P2o`0000;ob=gX00?o0000olSMj?o8gNP02Oo8gNP00ol0003o]L_[okG;j`03okG;j`;o
00003_n`bnh00ol0003oooooooooo`0:ooooo`;o00007oooool001Gooooo0_l0000<ooooo`03o`00
0?nX_n[oZ;oZ017oZ;oZ00?o0000ojRoj_nX_nX02onX_nX3o`0000?oZ;oZ00?o0000ojRoj_nX_nX0
4OnX_nX00ol0003oZ;oZojRojP07ojRojP?o00001_nX_NT00ol0003oZ;cXojRlj00AojRlj003o`00
0?nX^^OoZ;[W00;oZ;[W0ol00003ojRji`?o00001OnRV/d00ol0003oXI?6oj6CaP0>oj6CaP03o`00
0?nQTLCoXI7400ooXI7400?o0000oj:Da_nRU<H03onRU<H2o`0001;oXhBb00?o0000ojN>^onWS[/0
4_nWS[/01?l0003oZIc9ojVLbOl0000Bokf]b@03o`000?ng]]So]kKH00?o]kKH00?o0000olSMj?o8
gNP00oo8gNP00ol0003ob=gXolSMj009olSMj003o`000?nebn_o000000;o00004?n`bnh00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo01gooooo000Eooooo`03o`000?oooooooooo00cooooo
00?o0000ojRoj_nX_nX04OnX_nX00ol0003oZ;oZojRojP07ojRojP?o00001onX_nX00ol0003oZ;oZ
ojRojP0AojRojP03o`000?nX_n[oZ;oZ00?oZ;oZ0ol0000:ojRmj@03o`000?nX_>SoZ;cX017oZ;cX
1?l00003ojRji`?o00002?nRV/d00ol0003oXI?6oj6CaP0>oj6CaP03o`000?nQTLCoXI7400ooXI74
00?o0000oj:Da_nRU<H03OnRU<H2o`000003oj1n[_l0003oXhBb017oXhBb00?o0000ojN>^onWS[/0
4_nWS[/00ol0003oZIc9o`00000Dokf]b@03o`000?ng]]So]kKH00;o00001oo8gNP00ol0003ob=gX
olSMj008olSMj0;o00005?n`bnh00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01cooooo
000Eooooo`03o`000?oooooooooo00gooooo00?o0000ojRoj_nX_nX04OnX_nX00ol0003oZ;oZojRo
jP03ojRojP?o00002onX_nX00ol0003oZ;oZojRojP0AojRojP03o`000?nX_n[o000000;o00003_nX
_NT00ol0003oZ;cXojRlj00>ojRlj0Co00000_nX^^L3o`0000_oXY[=00?o0000oj6Ca_nQTlH03onQ
TlH00ol0003oXI74oj6Aa00?oj6Aa003o`000?nRU<KoXYC600[oXYC60_l00003oj1n[P03o`000?nS
Q;;oXhBb017oXhBb00?o0000ojN>^onWS[/04OnWS[/2o`0001Go_Jg900?o0000okNff?l000002Oo8
gNP00ol0003ob=gXolSMj006olSMj0;o000000?o_N;bo`000?n`bnh05?n`bnh00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo01cooooo000Eooooo`03o`000?oooooooooo00kooooo00?o0000
ojRoj_nX_nX04OnX_nX00ol0003oZ;oZo`000002o`0000ooZ;oZ00?o0000ojRoj_nX_nX04?nX_nX2
o`0001;oZ;gY00?o0000ojRlj?nX_>P02onX_>P2o`0000?oZ;cX0ol0000?oj:Jc@03o`000?nQTlKo
XI?600koXI?600?o0000oj6Aa?nQTL@03onQTL@00ol0003oXYC6oj:DaP08oj:DaP;o00001_nPOZh0
0ol0003oXhBboj>4/P0@oj>4/P03o`000?nWS[_oYhjk013oYhjk00?o0000oknU_ol000005_nm[LT2
o`0000[ob=gX00?o0000olSMj?o8gNP00oo8gNP2o`0000Co_N;b00?o0000ok3;k_n`bnh04_n`bnh0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01_ooooo000Eooooo`03o`000?oooooooooo
00oooooo00?o0000ojRoj_nX_nX04?nX_nX3o`0001;oZ;oZ00?o0000ojRoj_nX_nX03?nX_nX3o`00
0003ojRnjOl0003oZ;gY01;oZ;gY00?o0000ojRlj?nX_>P01onX_>P3o`0000;oZ;cX0ol000000onT
YMKo0000oj:Jc@0?oj:Jc@03o`000?nQTlKoXI?600ooXI?600?o0000oj6Aa?nQTL@03_nQTL@00ol0
003oXYC6oj:DaP06oj:DaP;o00002?nPOZh00ol0003oXhBboj>4/P0@oj>4/P03o`000?nWS[_oYhjk
00ooYhjk00Go0000oknU_onoYKoo_jFoo`00000Dokf]b@04o`000?oLl]kog?;No`0000[ob=gX00?o
0000olSMj?o8gNP00_l00007okgRlP03o`000?n`bnko/<_^013o/<_^0ol0000=ooooo`03o`000?oo
oooooooo01[ooooo000Dooooo`;o00004_ooool00ol0003oZ;oZojRojP0<ojRojP?o00000onX_nX0
0ol0003oZ;oZojRojP0@ojRojP03o`000?nX_n[oZ;oZ00SoZ;oZ0ol00005ojRnj@03o`000?nX_NWo
Z;gY017oZ;gY00?o0000ojRlj?nX_>P00onX_>P3o`0000;oZ;cX0ol00005ojBUeP03o`000?nRV/go
XY[=00koXY[=00?o0000oj6Ca_nQTlH03_nQTlH00ol0003oXI74oj6Aa00?oj6Aa003o`000?nRU<Ko
XYC600?oXYC60_l0000:oj1n[P03o`000?nSQ;;oXhBb017oXhBb00?o0000ojN>^onWS[/03OnWS[/0
0ol0003o_jFooknU_`02oknU_`03o`000?nm[LWo_Jg9017o_Jg900?o0000omcbg_oLl]h00_oLl]h0
0ol0003ob=gXolSMj008olSMj0;o00002_nmh_800ol0003o/<_^ok3;kP0<ok3;kP?o00000_nZ`^/0
0ol0003oooooooooo`0;ooooo`;o00006oooool001Cooooo00?o0000ooooooooool04_ooool00ol0
003oZ;oZojRojP08ojRojP?o00001onX_nX00ol0003oZ;oZojRojP0@ojRojP03o`000?nX_n[oZ;oZ
00CoZ;oZ0ol00009ojRnj@03o`000?nX_NWoZ;gY017oZ;gY00?o0000ojRlj?l000000_l00002ojRl
j0?o00002?nTYMH00ol0003oXY[=oj:Jc@0>oj:Jc@03o`000?nQTlKoXI?600koXI?600?o0000oj6A
a?nQTL@03onQTL@01?l0003oXYC6oj:Da_nRU<H2o`0000goX7j^00?o0000oj>4/_nSQ;804?nSQ;80
0ol0003oYhjkojN>^`0<ojN>^`03o`000?noYKoo_jFo00Co_jFo00?o0000okf]bOnm[LT03onm[LT0
0ol0003og?;NomcbgP04omcbgP03o`000?o8gNSob=gX00Gob=gX0ol0000<okgRlP03o`000?n`bnko
/<_^00So/<_^0ol00006oj[2j`03o`000?oooooooooo00[ooooo0_l0000Kooooo`005?ooool00ol0
003oooooooooo`0Cooooo`03o`000?nX_n[oZ;oZ00CoZ;oZ0ol0000;ojRojP03o`000?nX_n[oZ;oZ
013oZ;oZ00?o0000ojRoj_nX_nX00ol0000=ojRnj@03o`000?nX_NWoZ;gY00ooZ;gY0ol00002ojRl
j0?o00003?nTYMH00ol0003oXY[=oj:Jc@0=oj:Jc@03o`000?nQTlKoXI?600ooXI?600?o0000oj6A
a?nQTL@03_nQTL@01?l0003oXYC6o`000?l0000?oj1n[P03o`000?nSQ;;oXhBb013oXhBb00?o0000
ojN>^onWS[/02onWS[/00ol0003o_jFooknU_`05oknU_`03o`000?nm[LWo_Jg900ko_Jg900?o0000
omcbg_oLl]h01_oLl]h00ol0003ob=gXolSMj002olSMj0;o00000onmh_800ol0003o_N;bokgRlP0:
okgRlP03o`000?n`bnko/<_^00Co/<_^0ol0000:oj[2j`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool06Oooool001Cooooo00?o0000ooooooooool05?ooool00ol0003oZ;oZojRojP03o`00
00ooZ;oZ00?o0000ojRoj_nX_nX03onX_nX3o`00017oZ;kY00?o0000ojRmjOnX_NT02onX_NT3o`00
00;oZ;gY0ol0000?ojBUeP03o`000?nRV/goXY[=00koXY[=00?o0000oj6Ca_nQTlH03_nQTlH00ol0
003oXI74oj6Aa00>oj6Aa0;o00004OnPOZh00ol0003oXhBboj>4/P0Aoj>4/P03o`000?nWS[_oYhjk
00WoYhjk00?o0000oknU_onoYKl01onoYKl00ol0003o_Jg9okf]b@0<okf]b@03o`000?oLl]kog?;N
00Sog?;N00Co0000olSMj?l0003o00001_nmh_800ol0003o_N;bokgRlP0:okgRlP03o`000?n`bnko
/<_^00?o00003_nZ`^/00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Sooooo000Doooo
o`03o`000?oooooooooo01Gooooo0_l0000CojRojP03o`000?nX_n[oZ;oZ00_oZ;oZ0ol00002ojRo
jP03o`000?nX_^WoZ;kY013oZ;kY00?o0000ojRmjOnX_NT01onX_NT3o`0000;oZ;gY0ol000000onV
/=oo0000ojBUeP0?ojBUeP03o`000?nRV/goXY[=00koXY[=00?o0000oj6Ca_nQTlH03onQTlH00ol0
003oXI74oj6Aa00:oj6Aa0?o000000?oVgZ]o`000?nPOZh04?nPOZh00ol0003oXhBboj>4/P0Aoj>4
/P03o`000?nWS[_oYhjk00SoYhjk00?o0000oknU_onoYKl02?noYKl00ol0003o_Jg9okf]b@0;okf]
b@03o`000?oLl]kog?;N00Wog?;N0ol00008okgRlP03o`000?nmh_;o_N;b00Wo_N;b0ol0000Boj[2
j`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05oooool001Cooooo0_l0000Hooooo`03
o`000?nX_n[oZ;oZ017oZ;oZ00?o0000ojRoj_nX_nX01onX_nX3o`0000KoZ;oZ00?o0000ojRnjOnX
_^T04?nX_^T00ol0003oZ;gYojRmj@03ojRmj@?o00000_nX_NT3o`0000GoY[3O00?o0000ojBUe_nT
YMH03_nTYMH00ol0003oXY[=oj:Jc@0>oj:Jc@03o`000?nQTlKoXI?600koXI?600?o0000oj6Aa?nQ
TL@02?nQTL@2o`0000CoVgZ]00?o0000oj1n[_nPOZh04?nPOZh00ol0003oXhBboj>4/P0@oj>4/P03
o`000?nWS[_oYhjk00OoYhjk00?o0000oknU_onoYKl02_noYKl00ol0003o_Jg9okf]b@09okf]b@03
o`000?oLl]kog?;N00Wog?;N00Go0000ol3mh_o0oN;o`?gRo`000007okgRlP03o`000?nmh_;o_N;b
00Ko_N;b0ol000000on]b>ko0000oj[2j`0Boj[2j`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool05oooool001?ooooo00?o0000ooooooooool06Oooool00ol0003oZ;oZojRojP0AojRojP03
o`000?nX_n[oZ;oZ00?oZ;oZ0ol0000:ojRojP03o`000?nX_^WoZ;kY013oZ;kY00?o0000ojRmjOnX
_NT00_l00002ojRmj@?o00002OnV/=l00ol0003oY:GFojBUeP0=ojBUeP03o`000?nRV/goXY[=00ko
XY[=00?o0000oj6Ca_nQTlH03onQTlH00ol0003oXI74oj6Aa004oj6Aa0?o00001onKNZd00ol0003o
X7j^oj1n[P0?oj1n[P03o`000?nSQ;;oXhBb017oXhBb00?o0000ojN>^onWS[/01OnWS[/00ol0003o
_jFooknU_`0;oknU_`03o`000?nm[LWo_Jg900So_Jg900?o0000omcbg_oLl]h02OoLl]h00ol0003o
`?gRol3mhP03ol3mhP03o`000?nmh_;o_N;b00Go_N;b00?o0000okgRl_nmh_800_nmh_83o`0000Go
[LS^00?o0000oj[2jonZ`^/04OnZ`^/00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Ko
oooo000Cooooo`03o`000?oooooooooo01[ooooo00?o0000ojRoj_nX_nX04OnX_nX00ol0003oZ;oZ
o`000002o`0000koZ;oZ00?o0000ojRnjOnX_^T03onX_^T3o`000004ojRmjOl0003o0000o`0000co
Y[3O00?o0000ojBUe_nTYMH03_nTYMH00ol0003oXY[=oj:Jc@0=oj:Jc@03o`000?nQTlKoXI?600oo
XI?600?o0000oj6Aa?nQTL@00_nQTL@2o`0000[oVgZ]00?o0000oj1n[_nPOZh03onPOZh00ol0003o
XhBboj>4/P0Aoj>4/P03o`000?nWS[_oYhjk00CoYhjk00?o0000oknU_onoYKl03OnoYKl00ol0003o
_Jg9okf]b@06okf]b@03o`000?oLl]kog?;N00Wog?;N00?o0000ol3mh_o0oN801Oo0oN800ol0003o
_N;bokgRlP05okgRlP04o`000?nmh_;o0000o`0000Wo[LS^00?o0000oj[2jonZ`^/04OnZ`^/00ol0
003oooooooooo`09ooooo`;o00005oooool001?ooooo00?o0000ooooooooool06oooool2o`00017o
Z;oZ0ol0000AojRojP03o`000?nX_^WoZ;kY00_oZ;kY0ol000001?nX_^Wo0000o`000?l0000@ojJ`
g`03o`000?nTYMKoY:GF00goY:GF00?o0000oj:JcOnRV/d03_nRV/d00ol0003oXI?6oj6CaP0>oj6C
aP03o`000?nQTLCo000000;o00003?nKNZd00ol0003oX7j^oj1n[P0@oj1n[P03o`000?nSQ;;oXhBb
013oXhBb00?o0000ojN>^onWS[/00onWS[/00ol0003o_jFooknU_`0>oknU_`03o`000?nm[LWo_Jg9
00Go_Jg900?o0000omcbg_oLl]h02?oLl]h2o`0000Wo`?gR00?o0000okgRl_nmh_800onmh_83o`00
00_o[LS^00?o0000oj[2jonZ`^/04?nZ`^/3o`0000_ooooo00?o0000ooooooooool05Oooool001?o
oooo00?o0000ooooooooool07Oooool00ol0003oZ;oZojRojP0;ojRojP?o00000onX_nX00ol0003o
Z;oZojRojP0?ojRojP03o`000?nX_^WoZ;kY00OoZ;kY0ol000001_nX_^Wo0000o`000?l0003oYkSV
o`0001;oY[3O00?o0000ojBUe_nTYMH03OnTYMH00ol0003oXY[=oj:Jc@0=oj:Jc@03o`000?nQTlKo
XI?600goXI?60ol0000?oi]j[@03o`000?nPOZkoX7j^013oX7j^00?o0000oj>4/_nSQ;804OnSQ;80
1Ol0003oYhjkojN>^onWS[_o000001;o_jFo00?o0000okf]bOnm[LT00onm[LT00ol0003og?;Nomcb
gP08omcbgP03o`000?o0oN;o`?gR00[o`?gR00?o0000okgRl_l000000_l00002ojg8kP03o`000?n]
b>ko[LS^00[o[LS^00?o0000oj[2jonZ`^/03?nZ`^/3o`0000;oZ;oZ00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0Dooooo`004oooool3o`0001kooooo00?o0000ojRoj_nX_nX01onX_nX3
o`0000OoZ;oZ00?o0000ojRoj_nX_nX03onX_nX00ol0003oZ;kYojRnj@03ojRnj@?o000000CoZ;kY
o`000?l0003o00001OnW^>H00ol0003oY[3OojJ`g`0?ojJ`g`03o`000?nTYMKoY:GF00goY:GF00?o
0000oj:JcOnRV/d03_nRV/d00ol0003oXI?6oj6CaP08oj6CaPCo00000_nGN:l00ol0003oVgZ]oi]j
[@0>oi]j[@03o`000?nPOZkoX7j^00ooX7j^00?o0000oj>4/_nSQ;804OnSQ;801?l0003oYhjkojN>
^ol0000CoknU_`03o`000?nm[LWo_Jg900;o_Jg900?o0000omcbg_oLl]h02?oLl]h00ol0003o`?gR
ol3mhP0;ol3mhP;o00001_n]b>h00ol0003o[LS^ojg8kP0:ojg8kP03o`000?nZ`^_oZ/;[00OoZ/;[
1?l00006ojRojP03o`000?oooooooooo00[ooooo00?o0000ooooooooool04oooool001?ooooo00?o
0000ooooooooool07oooool00ol0003oZ;oZojRojP03ojRojP?o00002onX_nX00ol0003oZ;oZojRo
jP0?ojRojP03o`000?nX_^Wo000000;o000000CoZ;kYo`000?l0003o00002OnW^>H00ol0003oY[3O
ojJ`g`0?ojJ`g`03o`000?nTYMKoY:GF00goY:GF00?o0000oj:JcOnRV/d03OnRV/d00ol0003oXI?6
oj6CaP04oj6CaPCo00001_nGN:l00ol0003oVgZ]oi]j[@0>oi]j[@03o`000?nPOZkoX7j^00ooX7j^
00?o0000oj>4/_nSQ;804OnSQ;800ol0003oYhjko`00000EoknU_`04o`000?nm[LWo_Jg9o`0000[o
g?;N00?o0000ol3mh_o0oN802_o0oN82o`000003ok;El_l0003o[LS^00Ko[LS^00?o0000ojg8k_n]
b>h02On]b>h00ol0003oZ/;[oj[2j`04oj[2j`?o00002onX_nX00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo01?ooooo000Booooo`03o`000?oooooooooo027ooooo00?o0000ojRoj_l00000
0_l0000?ojRojP03o`000?nX_n[oZ;oZ00goZ;oZ0ol000001?nX_^Wo0000o`000?l0000=ojNhiP03
o`000?nV/=ooY[3O00koY[3O00?o0000ojBUe_nTYMH03OnTYMH00ol0003oXY[=oj:Jc@0=oj:Jc@03
o`000?nQTlKoXI?600Co00002onGN:l00ol0003oVgZ]oi]j[@0=oi]j[@03o`000?nPOZkoX7j^013o
X7j^00?o0000oj>4/_nSQ;804?nSQ;82o`0001Ko_jFo00?o0000okf]bOl000002OoLl]h2o`0000[o
`?gR0ol00004ok;ElP03o`000?n]b>ko[LS^00Co[LS^00?o0000ojg8k_n]b>h02_n]b>h00ol0003o
Z/;[oj[2j`03o`0000koZ;oZ00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Booooo`00
1oooool5o`0000Kooooo00?o0000ooooooooool08_ooool2o`0001;oZ;oZ00?o0000ojRoj_nX_nX0
2OnX_nX3o`000004ojRoj_l0003o0000o`00013oYkSV00?o0000ojJ`gonV/=l03onV/=l00ol0003o
Y:GFojBUeP0<ojBUeP03o`000?nRV/goXY[=00coXY[=1?l0000?oiMh[`03o`000?nKNZgoVgZ]00go
VgZ]00?o0000oj1n[_nPOZh04?nPOZh00ol0003oXhBboj>4/P0?oj>4/P03o`000?nlWkco000001Oo
_jFo0_l00008omcbgP03o`000?o0oN;o`?gR00So`?gR0_l00008ok;ElP03o`000?n]b>ko[LS^00Co
[LS^00?o0000ojg8k_n]b>h02On]b>h3o`0001;oZ;oZ00?o0000ooooooooool02Oooool2o`0000[o
oooo0_l000000ol@413oooooooooo`04ooooo`001oooool01OnHV9So8B4Qonk^k_ooooooA4A400Ko
oooo00?o0000ooooooooool09?ooool00ol0003oZ;oZojRojP0@ojRojP03o`000?nX_n[oZ;oZ00Ko
Z;oZ0_l000001?nX_n[o0000o`000?l00002ojRmj003o`000?nW^>KoYkSV00ooYkSV00?o0000ojJ`
gonV/=l03onV/=l00ol0003oY:GFojBUeP0<ojBUeP03o`000?nRV/goXY[=00KoXY[=1Ol00002oi=j
]003o`000?nGN:ooUgR_00koUgR_00?o0000oi]j[OnKNZd03_nKNZd00ol0003oX7j^oj1n[P0?oj1n
[P03o`000?nSQ;;oXhBb00koXhBb00Go0000okbO_?nlWkco_9nlo`00000FoknU_`03o`000?oQoLgo
000000;o00001?oLl]h00ol0003o`?gRol3mhP07ol3mhP;o00002onbeO800ol0003o[LS^ojg8kP04
ojg8kP03o`000?n]b>ko[LS^00Go[LS^0ol000000onX`>[o0000ojRojP0CojRojP03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`05ooooo`002?ooool00onH
V9So8B4Qonk^kP07ooooo`03o`000?oooooooooo02Gooooo00?o0000ojRoj_nX_nX04?nX_nX00ol0
003oZ;oZojRojP02ojRojPKo00001_nX_NP00ol0003oYkSVojNhiP0?ojNhiP03o`000?nV/=ooY[3O
00koY[3O00?o0000ojBUe_nTYMH03?nTYMH01?l0003oXY[=oj:JcOnRV/d5o`0000OoTgZd00?o0000
oiMh[onGN:l03_nGN:l00ol0003oVgZ]oi]j[@0>oi]j[@03o`000?nPOZkoX7j^00ooX7j^00?o0000
oj>4/_nSQ;803OnSQ;800ol0003o_9nlokbO_002okbO_003o`000?noYKoo_jFo01?o_jFo00?o0000
on7mcOoQoLd00ooQoLd2o`000003omcbg_l0003o`?gR00Ko`?gR0ol0000>ok;ElP03o`000?n]b>ko
[LS^00Co[LS^00Co0000ojg8k_n]b>ko[LS^0ol00005ojS0jP03o`000?nX_n[oZ;oZ017oZ;oZ00?o
0000ooooooooool02_ooool00ol0003oooooooooo`05ooooo`Go00001_ooool000Wooooo00?oV9RH
ob4Q8Oo^k^h01_ooool2o`0002Oooooo00?o0000ojRoj_nX_nX04?nX_nX6o`0000_oZ;gX00?o0000
ojNhi_nW^>H03onW^>H00ol0003oY[3OojJ`g`0>ojJ`g`03o`000?nTYMKoY:GF00GoY:GF2_l0000=
oi=j]003o`000?nGN:ooUgR_00goUgR_00?o0000oi]j[OnKNZd03_nKNZd00ol0003oX7j^oj1n[P0@
oj1n[P03o`000?nSQ;;oXhBb00_oXhBb00?o0000okbO_?nlWk`00onlWk`00ol0003o_jFooknU_`0B
oknU_`03o`000?oQoLgohOg=00GohOg=1Ol00003ol3mhP;o00004_nbeO800ol0003o[LS^ojg8kP03
ojg8kPCo00002OnX`>X00ol0003oZ;oZojRojP0AojRojP03o`000?oooooooooo00[ooooo00?o0000
ooooooooool01?ooool01?m4A4CogMgMooooool00007ooooo`002_ooool00omgMgOoIVIVooooo`05
ooooo`03o`000?oooooooooo02Oooooo00?o0000ojRoj_nX_nX03OnX_nX5o`0000ooZ;gX00?o0000
ojNhi_nW^>H03_nW^>H00ol0003oY[3OojJ`g`0=ojJ`g`Wo00001onBP[h00ol0003oTgZdoi=j]00=
oi=j]003o`000?nGN:ooUgR_00koUgR_00?o0000oi]j[OnKNZd03OnKNZd00ol0003oX7j^oj1n[P0@
oj1n[P03o`000?nSQ;;oXhBb00[oXhBb00?o0000okbO_?nlWk`01OnlWk`00ol0003o_jFooknU_`0@
oknU_`03o`000?oQoLgohOg=00GohOg=2_l0000Dok;ElP03o`000?n]b>ko[LS^00Co00003?nX`>X0
0ol0003oZ;oZojRojP0?ojRojP?o00002oooool00ol0003oooooooooo`04ooooo`04omgMgOmEEEGo
ooooo`0000Oooooo000;ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:Oooool0
0ol0003oZ;oZojRojP09ojRojPGo000000?oZ;kYo`000?nX_NP04?nX_NP00ol0003oYkSVojNhiP0>
ojNhiP03o`000?nV/=ooY[3O00OoY[3O1Ol00002oiJBcP03o`000?nBP[koTX:n00_oTX:n00?o0000
oi=j]?nCN[@03OnCN[@00ol0003oUgR_oiMh[`0>oiMh[`03o`000?nKNZgoVgZ]00koVgZ]00?o0000
oj1n[_nPOZh03onPOZh00ol0003oXhBboj>4/P09oj>4/P03o`000?nlWkco_9nl00Ko_9nl00?o0000
oknU_onoYKl03onoYKl00ol0003ohOg=on7mc@05on7mc@So00000onejOL00ol0003o/]Gbok;ElP0@
ok;ElPCo00001?nX`>X00ol0003oZ<3ZojS0jP0:ojS0jP03o`000?nX_n[oZ;oZ00_oZ;oZ0ol00002
ojRojP03o`000?oooooooooo00[ooooo00?o0000ooooooooool01?ooool00omgMgOoc<c<o`000007
ooooo`001oooool01Ol0003o^[ZjoooooonHV9So410@00Gooooo00?o0000ooooooooool0:_ooool0
0ol0003oZ;oZojRojP05ojRojPGo00001OnX_^T00ol0003oZ;gXojRmj00?ojRmj003o`000?nW^>Ko
YkSV00koYkSV00Co0000ojJ`gonV/=ooY[3O1Ol00007oiJBcP03o`000?nBP[koTX:n00coTX:n00?o
0000oi=j]?nCN[@03?nCN[@00ol0003oUgR_oiMh[`0>oiMh[`03o`000?nKNZgoVgZ]00koVgZ]00?o
0000oj1n[_nPOZh04?nPOZh00ol0003oXhBboj>4/P07oj>4/P03o`000?nlWkco_9nl00So_9nl00?o
0000oknU_onoYKl03OnoYKl00ol0003ohOg=on7mc@05on7mc@Oo00001_nejOL00ol0003o/]Gbok;E
lP0<ok;ElP?o00000_nY`N/00ol0003oZ<3ZojS0jP03ojS0jP03o`000?nX`>[oZ<3Z00[oZ<3Z00?o
0000ojRoj_nX_nX02?nX_nX3o`0000KoZ;oZ00?o0000ooooooooool02?ooool3o`0000Gooooo00?o
k^k^odA4A?l000001oooool000Oooooo00GoV9RHoa0@4?l0003o8B4Qolc<c005ooooo`03o`000?oo
oooooooo02_ooooo00Co0000ojRoj_nX_n[oZ;oZ1Ol00009ojRnj@03o`000?nX_NSoZ;gX00ooZ;gX
00?o0000ojNhi_nW^>H03?nW^>H5o`0000goUY;>00?o0000oi:2__nBP[h02onBP[h00ol0003oTgZd
oi=j]00=oi=j]003o`000?nGN:ooUgR_00goUgR_00?o0000oi]j[OnKNZd03_nKNZd00ol0003oX7j^
oj1n[P0@oj1n[P03o`000?nSQ;;oXhBb00KoXhBb00?o0000okbO_?nlWk`02OnlWk`00ol0003o_jFo
oknU_`0<oknU_`03o`000?oQoLgohOg=00GohOg=1_l00009okGYm`03o`000?nbeO;o/]Gb00So/]Gb
0ol00006ojW1j`03o`000?nX`>[oZ<3Z00?oZ<3Z00?o0000ojS0j_nX`>X02_nX`>X00ol0003oZ;oZ
ojRojP04ojRojP?o00002_nX_nX00ol0003oooooooooo`04ooooo`?o00000_ooool00ol0003ooooo
ooooo`04ooooo`03ogMgMol0003ooooo00Kooooo000Aooooo`03o`000?oooooooooo02cooooo1Ol0
000=ojRnj@03o`000?nX_NSoZ;gX00ooZ;gX00?o0000ojNhi_nW^>H01_nW^>H5o`0000;oW:OM00?o
0000oiJBc_nFT/h03OnFT/h00ol0003oTX:noi:2_P0;oi:2_P03o`000?nCN[CoTgZd00goTgZd00?o
0000oiMh[onGN:l03OnGN:l00ol0003oVgZ]oi]j[@0>oi]j[@03o`000?nPOZkoX7j^013oX7j^00?o
0000oj>4/_nSQ;801OnSQ;800ol0003o_9nlokbO_00;okbO_003o`000?noYKoo_jFo00[o_jFo00?o
0000on7mcOoQoLd01OoQoLd4o`0000go]NWg00?o0000ok;El_nbeO801?nbeO83o`0000[oZL7[00?o
0000ojS0j_nX`>X00onX`>X00ol0003oZ<3ZojS0jP0:ojS0jP03o`000?nX_n[oZ;oZ00?o00003OnX
_nX01?l0003oooooooooooooool3o`0000Gooooo00?o0000ooooooooool03Oooool0017ooooo0_l0
000[ooooo`;o000000?oooooo`000?l000004?nX_^T00ol0003oZ;gXojRmj00?ojRmj003o`000?nW
^>KoYkSV00Go00002?nLYmd00ol0003oUY;>oiJBcP0<oiJBcP03o`000?nBP[koTX:n00coTX:n00?o
0000oi=j]?nCN[@03?nCN[@00ol0003oUgR_oiMh[`0>oiMh[`03o`000?nKNZgoVgZ]00koVgZ]00?o
0000oj1n[_nPOZh03onPOZh00ol0003oXhBboj>4/P04oj>4/P03o`000?nlWkco_9nl00co_9nl00?o
0000oknU_onoYKl02OnoYKl00ol0003ohOg=on7mc@05on7mc@?o00004?nejOL00ol0003o/]Gbok;E
lP03o`0000goZL7[00?o0000ojS0j_nX`>X01?nX`>X00ol0003oZ<3ZojS0jP08ojS0jPCo00004OnX
_nX3o`0000Sooooo00?o0000ooooooooool03Oooool0017ooooo00?o0000ooooooooool09oooool3
o`0000Gooooo00?o0000ojRnjOnX_^T03_nX_^T00ol0003oZ;gXojRmj00=ojRmj0Co00003OnLYmd0
0ol0003oUY;>oiJBcP0=oiJBcP03o`000?nBP[koTX:n00_oTX:n00?o0000oi=j]?nCN[@03?nCN[@0
0ol0003oUgR_oiMh[`0>oiMh[`03o`000?nKNZgoVgZ]00koVgZ]00?o0000oj1n[_nPOZh04?nPOZh0
0ol0003oXhBboj>4/P02oj>4/P03o`000?nlWkco_9nl00go_9nl00?o0000oknU_onoYKl02OnoYKl0
0ol0003ohOg=on7mc@03on7mc@?o00004_nejOL3o`00017oZL7[00?o0000ojS0j_nX`>X00onX`>X0
0ol0003oZ<3ZojS0jP05ojS0jP?o00000_nX_nX00ol0003oZ;oZojRojP0AojRojP03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool03Oooool0017ooooo00?o0000ooooooooool09?ooool3o`00
00Wooooo00?o0000ojRnjOnX_^T03_nX_^T00ol0003oZ;gXojRmj009ojRmj0?o00000_nR]^H00ol0
003oW:OMoibWg@0=oibWg@03o`000?nFT/koUY;>00coUY;>00?o0000oi:2__nBP[h02onBP[h00ol0
003oTgZdoi=j]00=oi=j]003o`000?nGN:ooUgR_00goUgR_00?o0000oi]j[OnKNZd03_nKNZd00ol0
003oX7j^oj1n[P0@oj1n[P05o`000?nSQ;;oXhBboj>4/_l000004OnlWk`00ol0003o_jFooknU_`07
oknU_`03o`000?oQoLgohOg=00?ohOg=0ol0000@okGYm`?o000000?oZ/?/o`000?nY`N/04_nY`N/0
0ol0003oZ<3ZojS0jP03ojS0jP04o`000?nX`>[oZ<3ZojS0jP?o00001_nX_nX00ol0003oZ;oZojRo
jP0@ojRojP03o`000?oooooooooo00Sooooo00?o0000ooooooooool03?ooool0013ooooo00?o0000
ooooooooool08_ooool3o`0000gooooo00?o0000ojRnjOnX_^T03_nX_^T00ol0003oZ;gXojRmj004
ojRmj0Co00001_nR]^H00ol0003oW:OMoibWg@0<oibWg@03o`000?nFT/koUY;>00coUY;>00?o0000
oi:2__nBP[h03?nBP[h00ol0003oTgZdoi=j]00<oi=j]003o`000?nGN:ooUgR_00goUgR_00?o0000
oi]j[OnKNZd03_nKNZd00ol0003oX7j^oj1n[P0@oj1n[P04o`000?nSQ;;oXhBbo`0001;o_9nl00?o
0000oknU_onoYKl01_noYKl00ol0003ohOg=on7mc@03on7mc@04o`000?nVmNgoY_G]ojKek@;o0000
2onejOL3o`0000GoZ/?/00?o0000ojW1jonY`N/04?nY`N/00ol0003oZ<3ZojS0jP04ojS0jP?o0000
2_nX_nX00ol0003oZ;oZojRojP0@ojRojP03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
3?ooool0013ooooo00?o0000ooooooooool07oooool3o`00017ooooo00?o0000ojRnjOnX_^T03_nX
_^T00ol0003oZ;gXojRmj003o`0000_oX[KV00?o0000oibWgOnLYmd03?nLYmd00ol0003oUY;>oiJB
cP0<oiJBcP03o`000?nBP[koTX:n00_oTX:n00?o0000oi=j]?nCN[@03?nCN[@00ol0003oUgR_oiMh
[`0>oiMh[`03o`000?nKNZgoVgZ]00koVgZ]00?o0000oj1n[_nPOZh04?nPOZh2o`0001Co_9nl00?o
0000oknU_onoYKl01?noYKl00ol0003ohOg=on7mc@03on7mc@03o`000?nVmNgoY_G]00CoY_G]00?o
0000okGYmonejOL01OnejOL3o`0000WoZ/?/00?o0000ojW1jonY`N/04?nY`N/00ol0003oZ<3ZojS0
jP03o`000003ojRoj_l0003oZ;oZ00[oZ;oZ00?o0000ojRoj_nX_nX03onX_nX3o`0000Sooooo00?o
0000ooooooooool03?ooool0013ooooo0_l0000Mooooo`?o00005Oooool00ol0003oZ;kYojRnj@0<
ojRnj@Co00003onR]^H00ol0003oW:OMoibWg@0;oibWg@03o`000?nFT/koUY;>00coUY;>00?o0000
oi:2__nBP[h02onBP[h00ol0003oTgZdoi=j]00<oi=j]003o`000?nGN:ooUgR_00koUgR_00?o0000
oi]j[OnKNZd03_nKNZd00ol0003oX7j^oj1n[P0?oj1n[P;o00005OnlWk`00ol0003o_jFooknU_`03
oknU_`03o`000?oQoLgohOg=00?ohOg=00?o0000ojKekOnVmNd01_nVmNd2o`0000;o]NWg0ol0000=
oj[3k003o`000?nY`N_oZL7[00koZL7[1?l00004ojRojP03o`000?nX_n[oZ;oZ00[oZ;oZ00?o0000
ojRoj_nX_nX02onX_nX3o`0000;oZ;oZ00?o0000ooooooooool01_ooool00ol0003oooooooooo`0<
ooooo`004?ooool00ol0003oooooooooo`0Iooooo`?o00006Oooool00ol0003oZ;kYojRnj@08ojRn
j@?o00000onV_>T00ol0003oX[KVoj:fiP0=oj:fiP03o`000?nLYmgoW:OM00coW:OM00?o0000oiJB
c_nFT/h02onFT/h00ol0003oTX:noi:2_P0;oi:2_P03o`000?nCN[CoTgZd00goTgZd00?o0000oiMh
[onGN:l03OnGN:l00ol0003oVgZ]oi]j[@0>oi]j[@03o`000?nPOZkoX7j^00koX7j^00?o0000okBJ
_Ol000005_nlWk`01Ol0003o_jFooknU_onoYKoo000000GohOg=00?o0000ojKekOnVmNd02?nVmNd3
o`00017oZ/?/00?o0000ojW1jonY`N/02OnY`N/4o`0000;oZ;oZ00?o0000ojRoj_nX_nX01?nX_nX0
0ol0003oZ;oZojRojP0:ojRojP03o`000?nX_n[oZ;oZ00OoZ;oZ0ol00006ojRojP03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool03?ooool0013ooooo00?o0000ooooooooool05_ooool3o`00
01gooooo00?o0000ojRnjOnX_^T01?nX_^T3o`0000OoY[cY00?o0000oj:fi_nR]^H03OnR]^H00ol0
003oW:OMoibWg@0<oibWg@03o`000?nFT/koUY;>00_oUY;>00?o0000oi:2__nBP[h02onBP[h00ol0
003oTgZdoi=j]00<oi=j]003o`000?nGN:ooUgR_00goUgR_00?o0000oi]j[OnKNZd03_nKNZd00ol0
003oX7j^oj1n[P0=oj1n[P05o`000?ndV[go]9ZmokBJ_Ol000005OnlWk`01?l0003o_jFooknU_ol0
0005on7mc@03o`000?nVmNgoY_G]00KoY_G]0ol000000onZaNgo0000oj[3k00Boj[3k003o`000?nY
`N_oZL7[00GoZL7[0ol00007ojRojP03o`000?nX_n[oZ;oZ00CoZ;oZ00?o0000ojRoj_nX_nX02OnX
_nX00ol0003oZ;oZojRojP04ojRojP?o00002_nX_nX00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00cooooo000@ooooo`03o`000?oooooooooo01?ooooo0ol0000Qooooo`03o`000?nX_^Wo
Z;kY00?o00002onV_>T00ol0003oX[KVoj:fiP0=oj:fiP03o`000?nLYmgoW:OM00_oW:OM00?o0000
oiJBc_nFT/h02onFT/h00ol0003oTX:noi:2_P0;oi:2_P03o`000?nCN[CoTgZd00coTgZd00?o0000
oiMh[onGN:l03OnGN:l00ol0003oVgZ]oi]j[@0?oi]j[@03o`000?nPOZkoX7j^00[oX7j^0_l00004
okBJ_@03o`000?nlWkco_9nl01?o_9nl00?o0000oknU_ol000000_oQoLd4o`0000KoY_G]0ol00005
oj[5k@03o`000?nZ`ncoZ/?/017oZ/?/00?o0000ojW1jonY`N/01?l0000;ojRojP03o`000?nX_n[o
Z;oZ00?oZ;oZ00?o0000ojRoj_nX_nX02_nX_nX00ol0003oZ;oZojRojP03o`0000goZ;oZ00?o0000
ooooooooool01?ooool00ol0003oooooooooo`0<ooooo`003oooool00ol0003oooooooooo`0Boooo
o`;o00009Oooool2o`0000ooY[cY00?o0000oj:fi_nR]^H03OnR]^H00ol0003oW:OMoibWg@0;oibW
g@03o`000?nFT/koUY;>00[oUY;>00?o0000oi:2__nBP[h02onBP[h00ol0003oTgZdoi=j]00<oi=j
]003o`000?nGN:ooUgR_00koUgR_00?o0000oi]j[OnKNZd03_nKNZd00ol0003oX7j^oj1n[P09oj1n
[P03o`000?ndV[go]9Zm00Co]9Zm00?o0000okbO_?nlWk`05?nlWk`4o`0000;ocOk100?o0000ojKe
kOnVmNd00_nVmNd3o`0000WoZ/G]00?o0000oj[3k?nZ`n`04?nZ`n`3o`00013oZ;oZ00?o0000ojRo
j_nX_nX00onX_nX00ol0003oZ;oZojRojP08ojRojPCo00004OnX_nX00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00_ooooo000?ooooo`03o`000?oooooooooo00oooooo0ol0000Xooooo`03
o`000?nV_>WoY[cY00koY[cY00?o0000oj:fi_nR]^H03?nR]^H00ol0003oW:OMoibWg@0;oibWg@03
o`000?nFT/koUY;>00_oUY;>00?o0000oi:2__nBP[h02onBP[h00ol0003oTgZdoi=j]00<oi=j]003
o`000?nGN:ooUgR_00goUgR_00?o0000oi]j[OnKNZd03_nKNZd00ol0003oX7j^oj1n[P08oj1n[P03
o`000?ndV[go]9Zm00Ko]9Zm00?o0000okbO_?nlWk`04onlWk`00ol0003ocOk1olgn`@02olgn`@03
o`000?nVmNgoY_G]00?o00003OnZaNd00ol0003oZ/?/oj[3k00<oj[3k0?o000000?oZ;oZo`000?nX
_nX04?nX_nX00ol0003oZ;oZojRojP04ojRojP03o`000?nX_n[oZ;oZ00?oZ;oZ1?l00002ojRojP03
o`000?nX_n[oZ;oZ017oZ;oZ00?o0000ooooooooool00oooool00ol0003oooooooooo`0;ooooo`00
3oooool2o`0000gooooo0ol0000/ooooo`03o`000?nV_>WoY[cY00koY[cY00?o0000oj:fi_nR]^H0
3?nR]^H00ol0003oW:OMoibWg@0;oibWg@03o`000?nFT/koUY;>00[oUY;>00?o0000oi:2__nBP[h0
2onBP[h00ol0003oTgZdoi=j]00<oi=j]003o`000?nGN:ooUgR_00goUgR_00?o0000oi]j[OnKNZd0
3_nKNZd00ol0003oX7j^oj1n[P06oj1n[P;o00002OndV[d00ol0003o_9nlokbO_00BokbO_003o`00
0?o=o/7ocOk100;ocOk11?l0000Aoj[5k@03o`000?nZ`ncoZ/?/00SoZ/?/0ol00005ojRojP03o`00
0?nX_n[oZ;oZ00ooZ;oZ00?o0000ojRoj_nX_nX01?nX_nX5o`0000OoZ;oZ00?o0000ojRoj_nX_nX0
4?nX_nX00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00_ooooo000?ooooo`03o`000?oo
oooooooo00Wooooo0ol0000`ooooo`03o`000?nV_>WoY[cY00koY[cY00?o0000oj:fi_nR]^H03?nR
]^H00ol0003oW:OMoibWg@0:oibWg@03o`000?nFT/koUY;>00[oUY;>00?o0000oi:2__nBP[h02onB
P[h00ol0003oTgZdoi=j]00<oi=j]003o`000?nGN:ooUgR_00goUgR_00?o0000oi]j[OnKNZd03onK
NZd00ol0003oX7j^oj1n[P04oj1n[P03o`000?ndV[go]9Zm00Wo]9Zm00?o0000okbO_?nlWk`04Onl
Wk`00ol0003ocOk1olgn`@02olgn`@;o00000_nYanl00ol0003oZ/G]oj[5k@0@oj[5k@03o`000?nZ
`ncoZ/?/00CoZ/?/0ol00009ojRojP03o`000?nX_n[oZ;oZ00ooZ;oZ00?o0000ojRoj_nX_nX01?l0
000<ojRojP03o`000?nX_n[oZ;oZ013oZ;oZ00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0;ooooo`003oooool00ol0003oooooooooo`06ooooo`?o0000=?ooool00ol0003oY[cYojJlj@0>
ojJlj@03o`000?nR]^KoX[KV00WoX[KV2?l00008oibWg@03o`000?nFT/koUY;>00[oUY;>00?o0000
oi:2__nBP[h02onBP[h00ol0003oTgZdoi=j]00;oi=j]003o`000?nGN:ooUgR_00koUgR_00?o0000
oi]j[OnKNZd03_nKNZd00ol0003oX7j^oj1n[P03oj1n[P03o`000?ndV[go]9Zm00_o]9Zm00?o0000
okbO_?nlWk`03onlWk`00ol0003ocOk1olgn`@02olgn`@03o`000?nYanooZLO_00?oZLO_00?o0000
oj[5kOnZaNd04?nZaNd00ol0003oZ/?/oj[3k003o`0000coZ;oZ00?o0000ojRoj_nX_nX03onX_nX3
o`0000CoZ;oZ00?o0000ojRoj_nX_nX02_nX_nX00ol0003oZ;oZojRojP0>ojRojP?o00000oooool0
0ol0003oooooooooo`0;ooooo`003oooool00ol0003oooooooooo`03ooooo`?o0000>?ooool00ol0
003oY[cYojJlj@0>ojJlj@04o`000?nR]^KoX[KVoj:fiPOo00000on<[nd00ol0003oL9SXog2Hj002
og2Hj0Oo000000?oW:OMo`000?nFT/h02onFT/h00ol0003oTX:noi:2_P0;oi:2_P03o`000?nCN[Co
TgZd00coTgZd00?o0000oiMh[onGN:l03OnGN:l00ol0003oVgZ]oi]j[@0>oi]j[@04o`000?nPOZko
X7j^oj1n[P;o00003_ndV[d00ol0003o_9nlokbO_00>okbO_003o`000?o=o/7ocOk100;ocOk100?o
0000ojW7konYanl01OnYanl00ol0003oZ/G]oj[5k@0>oj[5k@Co00004?nX_nX00ol0003oZ;oZojRo
jP0;ojRojP?o000000?oZ;oZo`000?nX_nX01OnX_nX00ol0003oZ;oZojRojP09ojRojP03o`000?nX
_n[oZ;oZ00[oZ;oZ1?l00002ojRojP05o`000?ooooooooooooooool000003Oooool000kooooo00Co
0000oooooooooooooooo0ol0000looooo`03o`000?nV_>WoY[cY00coY[cY1Ol0000;ohb_k@03o`00
0?m`V>SoL9SX00SoL9SX1?l0000:oiJBcP03o`000?nBP[koTX:n00_oTX:n00?o0000oi=j]?nCN[@0
3?nCN[@00ol0003oUgR_oiMh[`0=oiMh[`03o`000?nKNZgoVgZ]00koVgZ]00Co0000oj1n[_nPOZko
00004OndV[d00ol0003o_9nlokbO_00<okbO_003o`000?o=o/7ocOk100;ocOk100?o0000ojW7konY
anl01onYanl00ol0003oZ/G]oj[5k@09oj[5k@Co00000_nX_nX00ol0003oZ;oZojRojP0@ojRojP03
o`000?nX_n[oZ;oZ00OoZ;oZ0ol00005ojRojP03o`000?nX_n[oZ;oZ00?oZ;oZ00?o0000ojRoj_nX
_nX02_nX_nX00ol0003oZ;oZojRojP05ojRojPCo00001onX_nX01?l0003oooooooooool0000=oooo
o`003_ooool4o`00043ooooo00?o0000ojJljOnV_>T01_nV_>T5o`0000?oW[[/00?o0000ohb_kOn<
[nd02on<[nd00ol0003oL9SXog2Hj009og2Hj003o`000?mNO]_o000000;o00002?nFT/h00ol0003o
TX:noi:2_P0:oi:2_P03o`000?nCN[CoTgZd00coTgZd00?o0000oiMh[onGN:l03OnGN:l00ol0003o
VgZ]oi]j[@0?oi]j[@;o00004_ndV[d00ol0003o_9nlokbO_00;okbO_003o`000?o=o/7ocOk100;o
cOk100?o0000ojW7konYanl02OnYanl00ol0003oZ/G]oj[5k@05oj[5k@?o00001onX_nX00ol0003o
Z;oZojRojP0?ojRojP03o`000?nX_n[oZ;oZ00CoZ;oZ0ol00009ojRojP03o`000?nX_n[oZ;oZ00?o
Z;oZ00?o0000ojRoj_nX_nX02_nX_nX00ol0003oZ;oZojRojP04o`0000coZ;oZ00?o0000ooooool0
00003Oooool000kooooo0_l00013ooooo`03o`000?nV_>WoY[cY00Go00002OnN^^`00ol0003oS:o]
ohb_k@0;ohb_k@03o`000?m`V>SoL9SX00WoL9SX00Co0000oeinfomNO]_oGWkK0ol00005oiJBcP03
o`000?nBP[koTX:n00_oTX:n00?o0000oi=j]?nCN[@02onCN[@00ol0003oUgR_oiMh[`0=oiMh[`03
o`000?nKNZgoVgZ]00koVgZ]0_l0000CokBJ_@03o`000?nlWkco_9nl00[o_9nl00?o0000olgn`Oo=
o/400_o=o/400ol0003oZLO_ojW7k`0;ojW7k`03o`000?nZaNgoZ/G]00Co00002onX_nX00ol0003o
Z;oZojRojP0?ojRojP03o`000?nX_n[oZ;oZ00?o00003OnX_nX00ol0003oZ;oZojRojP03ojRojP03
o`000?nX_n[oZ;oZ00WoZ;oZ0ol0000@ojRojP04o`000?ooooooooooo`0000cooooo0003ooooo`05
oiRHV?l@413o0000oc8b<_o<c<`02?ooool00ol0003oooooooooo`11ooooo`;o00003onN^^`00ol0
003oS:o]ohb_k@0:ohb_k@03o`000?m`V>SoL9SX00[oL9SX00?o0000oeinfomNO]/00omNO]/3o`00
00;oUY;>00?o0000oi:2__nBP[h02onBP[h00ol0003oTgZdoi=j]00<oi=j]003o`000?nGN:ooUgR_
00goUgR_00?o0000oi]j[OnKNZd02onKNZd2o`000003ojRC`?l0003o]9Zm01?o]9Zm00?o0000okbO
_?nlWk`02?nlWk`00ol0003ocOk1olgn`@02olgn`@03o`000?nYanooZLO_00coZLO_0ol0000@ojRo
jP03o`000?nX_n[oZ;oZ00goZ;oZ1?l0000AojRojP03o`000?nX_n[oZ;oZ00?oZ;oZ00?o0000ojRo
j_nX_nX01OnX_nX3o`000003ojRoj_l0003oZ;oZ017oZ;oZ00?o0000ooooool000003?ooool000?o
oooo00Go410@okZj^_ooooooMgMgoc8b<P09ooooo`03o`000?oooooooooo04;ooooo00?o0000oijj
k?nN^^`03OnN^^`00ol0003oS:o]ohb_k@0:ohb_k@03o`000?m`V>SoL9SX00WoL9SX00?o0000oein
fomNO]/01_mNO]/4o`0000coTX:n00?o0000oi=j]?nCN[@03?nCN[@00ol0003oUgR_oiMh[`0=oiMh
[`03o`000?nKNZgoVgZ]00SoVgZ]0ol00004ojRC`003o`000?ndV[go]9Zm017o]9Zm00?o0000okbO
_?nlWk`01onlWk`00ol0003ocOk1olgn`@02olgn`@03o`000?nYanooZLO_00[oZLO_0ol000000onX
_n[o0000ojRojP0@ojRojP03o`000?nX_n[oZ;oZ00WoZ;oZ1?l00002ojRojP03o`000?nX_n[oZ;oZ
013oZ;oZ00?o0000ojRoj_nX_nX00onX_nX00ol0003oZ;oZojRojP02ojRojP?o00001OnX_nX00ol0
003oZ;oZojRojP0?ojRojP03o`000?oooooo000000cooooo0007ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool0@_ooool00ol0003oW[[/oijjk00=oijjk003o`000?n<[ngoS:o]00[o
S:o]00?o0000og2Hj?m`V>P02Om`V>P00ol0003oGWkKoeinf`08oeinf`?o00002onBP[h00ol0003o
TgZdoi=j]00;oi=j]003o`000?nGN:ooUgR_00goUgR_00?o0000oi]j[OnKNZd01_nKNZd2o`0000Oo
Z9?000?o0000okBJ_OndV[d04_ndV[d00ol0003o_9nlokbO_005okbO_003o`000?o=o/7ocOk100;o
cOk100?o0000ojW7konYanl02?nYanl3o`0000GoZ;oZ00?o0000ojRoj_nX_nX03onX_nX00ol0003o
Z;oZojRojP05ojRojP?o00001onX_nX00ol0003oZ;oZojRojP0@ojRojP03o`000?nX_n[oZ;oZ00?o
Z;oZ1?l00009ojRojP03o`000?nX_n[oZ;oZ00ooZ;oZ0_l0000<ooooo`001_ooool00onYZJWo410@
ooooo`0:ooooo`;o0000@oooool00ol0003oW[[/oijjk00=oijjk003o`000?n<[ngoS:o]00[oS:o]
00?o0000og2Hj?m`V>P02?m`V>P00ol0003oGWkKoeinf`08oeinf`03o`000?mXN<ooJ7S?00Co0000
1onBP[h00ol0003oTgZdoi=j]00;oi=j]003o`000?nGN:ooUgR_00goUgR_00?o0000oi]j[OnKNZd0
1?nKNZd2o`0000WoZ9?000?o0000okBJ_OndV[d04_ndV[d00ol0003o_9nlokbO_004okbO_003o`00
0?o=o/7ocOk100;ocOk100?o0000ojS7l?l000001_nYanl3o`0000WoZ;oZ00?o0000ojRoj_nX_nX0
3onX_nX00ol0003oZ;oZojRojP04o`0000_oZ;oZ00?o0000ojRoj_nX_nX04?nX_nX00ol0003oZ;oZ
ojRojP04o`0000coZ;oZ00?o0000ojRoj_nX_nX03OnX_nX3o`0000cooooo0005ooooo`03oa0@4?l0
003o^[Zj00gooooo00?o0000ooooooooool0@Oooool00ol0003oW[[/oijjk00=oijjk003o`000?n<
[ngoS:o]00WoS:o]00?o0000og2Hj?m`V>P02Om`V>P00ol0003oGWkKoeinf`08oeinf`03o`000?mX
N<ooJ7S?00?oJ7S?0ol00004oi:2_P03o`000?nCN[CoTgZd00coTgZd00?o0000oiMh[onGN:l03?nG
N:l01?l0003oVgZ]oi]j[OnKNZd3o`0000coZ9?000?o0000okBJ_OndV[d04OndV[d00ol0003o_9nl
okbO_003okbO_003o`000?o=o/7ocOk100;ocOk100Go0000ojS7l?nXao3oZ<O`o`000002ojW7k`?o
00003?nX_nX00ol0003oZ;oZojRojP0?ojRojP?o00004?nX_nX00ol0003oZ;oZojRojP0>ojRojPCo
00001?nX_nX00ol0003oZ;oZojRojP09ojRojP03o`000?nX_n[oZ;oZ00WoZ;oZ1?l00002ooooo`03
o`000?oooooooooo00[ooooo0006ooooo`03okZj^_lQ8B7ooooo00gooooo00?o0000ooooooooool0
@Oooool00ol0003oW[[/oijjk00=oijjk003o`000?n<[ngoS:o]00WoS:o]00?o0000og2Hj?m`V>P0
2Om`V>P00ol0003oGWkKoeinf`07oeinf`03o`000?mXN<ooJ7S?00KoJ7S?1?l000000onBP[ko0000
oi=j]00<oi=j]003o`000?nGN:ooUgR_00goUgR_0ol0000?ojRC`003o`000?ndV[go]9Zm01;o]9Zm
00Go0000okbO_?nlWkco_9nlo`000003olgn`@;o00000onXao04o`00013oZ;oZ00?o0000ojRoj_nX
_nX02onX_nX3o`000003ojRoj_l0003oZ;oZ017oZ;oZ00?o0000ojRoj_nX_nX02OnX_nX4o`0000;o
Z;oZ00?o0000ojRoj_nX_nX00onX_nX00ol0003oZ;oZojRojP0:ojRojP03o`000?nX_n[oZ;oZ00Go
Z;oZ0ol00006ooooo`03o`000?oooooooooo00[ooooo0003ooooo`05oa0@4?nHV9SooooookZj^_l0
00003oooool00ol0003oooooooooo`11ooooo`03o`000?nN^^coW[[/00[oW[[/2ol00004ohb_k@03
o`000?m`V>SoL9SX00SoL9SX00?o0000oeinfomNO]/02?mNO]/00ol0003oJ7S?ofQhc`09ofQhc`Go
00002_nCN[@00ol0003oUgR_oiMh[`0;oiMh[`?o00004OnXTl000ol0003o]9ZmokBJ_@0BokBJ_@05
o`000?nlWkco_9nlo`000?o=o/400ol000000onXao3o0000o`000002o`0000;oZ;oZ00?o0000ojRo
j_nX_nX04?nX_nX00ol0003oZ;oZojRojP07ojRojP?o00001OnX_nX00ol0003oZ;oZojRojP0@ojRo
jP03o`000?nX_n[oZ;oZ00GoZ;oZ0ol00007ojRojP03o`000?nX_n[oZ;oZ00?oZ;oZ00?o0000ojRo
j_nX_nX02_nX_nX00ol0003oZ;oZojRojP04o`0000Wooooo00?o0000ooooooooool02_ooool000?o
oooo00GoZJVYoa0@4?l0003o410@ojVYZ@0@ooooo`;o0000@_ooool00ol0003oW[[/oijjk002oijj
k0Oo00001OnF_?800ol0003oJ:oiofR_n@03ofR_n@Oo00002Om`V>P00ol0003oGWkKoeinf`07oein
f`03o`000?mXN<ooJ7S?00[oJ7S?00Co0000ogmobOmoOlWoOgo91Ol00005oi=j]003o`000?nGN:oo
UgR_00KoUgR_1Ol00002oiJ:a003o`000?nXTl3oZ9?0013oZ9?000?o0000okBJ_OndV[d04OndV[d0
0ol0003o_9nlo`000002o`000004oiW]]?l0003o0000o`0000OoZ;oZ00?o0000ojRoj_nX_nX03onX
_nX00ol0003oZ;oZojRojP04ojRojP?o00002OnX_nX00ol0003oZ;oZojRojP0@ojRojP03o`000?nX
_n[oZ;oZ00Co00002onX_nX00ol0003oZ;oZojRojP03ojRojP03o`000?nX_n[oZ;oZ00WoZ;oZ0ol0
000>ooooo`03o`000?oooooooooo00Wooooo000Jooooo`03o`000?oooooooooo043ooooo1?l0000=
oiJllP03o`000?mX[oWoJ:oi00WoJ:oi0ol00006og2Hj003o`000?mNO]_oGWkK00SoGWkK00?o0000
ofQhcomXN<l02_mXN<l00ol0003oOgo9ogmob@05ogmob@Go000000CoTgZdo`000?nGN:ooUgR_1Ol0
0008oiJ:a003o`000?nXTl3oZ9?000ooZ9?000?o0000okBJ_OndV[d04OndV[d2o`0000;oVNfd0_l0
000;ojRojP03o`000?nX_n[oZ;oZ00ooZ;oZ00?o0000ojRoj_nX_nX00ol0000=ojRojP03o`000?nX
_n[oZ;oZ00koZ;oZ1?l0000@ojRojP03o`000?nX_n[oZ;oZ00;oZ;oZ00?o0000ojRoj_nX_nX01_nX
_nX3o`00017ooooo00?o0000ooooooooool02Oooool001_ooooo00?o0000ooooooooool0@Oooool0
0ol0003oU[cboiJllP0=oiJllP;o00002omX[oT4o`0000CoL9SX00?o0000oeinfomNO]/01omNO]/0
0ol0003oJ7S?ofQhc`0:ofQhc`03o`000?moOlWoOgo900[oOgo91?l0000=oiJ:a003o`000?nXTl3o
Z9?000ooZ9?000?o0000okBJ_OndV[d04?ndV[d01Ol0003oVNfdoiW]]?nIkKCo000000koZ;oZ00?o
0000ojRoj_nX_nX03OnX_nX4o`00017oZ;oZ00?o0000ojRoj_nX_nX02OnX_nX4o`0000;oZ;oZ00?o
0000ojRoj_nX_nX03onX_nX00ol0003oZ;oZojRojP03ojRojP03o`000?nX_n[oZ;oZ00;oZ;oZ0ol0
000Dooooo`03o`000?oooooooooo00Wooooo000Looooo`03o`000?oooooooooo047ooooo00?o0000
oiJll_nF_?803_nF_?800ol0003oJ:oiofR_n@0:ofR_n@03o`000?l0Km3o000000;o00000_m`V>P0
0ol0003oGWkKoeinf`07oeinf`03o`000?mXN<ooJ7S?00WoJ7S?00?o0000ogmobOmoOlT02omoOlT0
0ol0003oUX[4oiJ:a00=oiJ:a003o`000?nXTl3oZ9?0013oZ9?000?o0000okBJ_OndV[d03_ndV[d0
1Ol0003oVNfdoiW]]?nIkKCo0000013oZ;oZ00?o0000ojRoj_nX_nX02OnX_nX3o`0000;oZ;oZ00?o
0000ojRoj_nX_nX04OnX_nX00ol0003oZ;oZojRojP05ojRojP?o00001onX_nX00ol0003oZ;oZojRo
jP0?ojRojP03o`000?nX_n[oZ;oZ00?oZ;oZ1?l0000Gooooo`03o`000?oooooooooo00Wooooo000M
ooooo`03o`000?oooooooooo047ooooo00?o0000oiJll_nF_?803_nF_?800ol0003oJ:oiofR_n@0:
ofR_n@;o00000_l0Km03o`0000WoGWkK00?o0000ofQhcomXN<l02_mXN<l00ol0003oOgo9ogmob@0;
ogmob@03o`000?nFR/CoUX[400goUX[400?o0000ojRC`?nXTl003onXTl000ol0003o]9ZmokBJ_@0=
okBJ_@03o`000?nIkKCoVNfd00;o00004_nX_nX00ol0003oZ;oZojRojP04ojRojPCo00001_nX_nX0
0ol0003oZ;oZojRojP0AojRojP03o`000?nX_n[oZ;oZ00Co00002onX_nX00ol0003oZ;oZojRojP0?
ojRojP03o`000?nX_n[oZ;oZ00Co00006Oooool00ol0003oooooooooo`09ooooo`007_ooool2o`00
04;ooooo00?o0000oiJll_nF_?803_nF_?800ol0003oJ:oiofR_n@05ofR_n@go00002?mNO]/00ol0
003oJ7S?ofQhc`09ofQhc`03o`000?moOlWoOgo900_oOgo900?o0000oiJ:a?nFR/@03OnFR/@00ol0
003oZ9?0ojRC`00@ojRC`003o`000?ndV[go]9Zm00[o]9Zm0_l00002oiW]]004o`000?nX_n[oZ;oZ
o`0001;oZ;oZ00?o0000ojRoj_nX_nX00ol0000;ojRojP03o`000?nX_n[oZ;oZ013oZ;oZ0ol0000@
ojRojP03o`000?nX_n[oZ;oZ00goZ;oZ1?l00003ooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool02Oooool0023ooooo00?o0000ooooooooool0@?ooool00ol0003oU[cboiJllP0<oiJl
lPWo00002?n3_OT2o`000003obNQkOl0003o000000;o00001_mNO]/00ol0003oJ7S?ofQhc`09ofQh
c`03o`000?moOlWoOgo900_oOgo900?o0000oiJ:a?nFR/@03_nFR/@00ol0003oZ9?0ojRC`00?ojRC
`003o`000?ndV[go]9Zm00Wo]9Zm00Go0000oiW]]?nIkKCoVNfdo`000004ojRojP03o`000?nX_n[o
Z;oZ00koZ;oZ1?l0000?ojRojP03o`000?nX_n[oZ;oZ00coZ;oZ0ol000000onX_n[o0000ojRojP0@
ojRojP03o`000?nX_n[oZ;oZ00WoZ;oZ1?l00008ooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool02Oooool0027ooooo00?o0000ooooooooool0@?ooool00ol0003oU[cboiJllP06oiJl
lPGo00001?nM_o000ol0003oPkgioh>mn@0<oh>mn@?o00000_lWXNd00ol0003oGWkKoeinf`04oein
f`03o`000?mXN<ooJ7S?00WoJ7S?00?o0000ogmobOmoOlT02omoOlT00ol0003oUX[4oiJ:a00=oiJ:
a003o`000?nXTl3oZ9?000ooZ9?000?o0000okBJ_OndV[d02?ndV[d00ol0003oVNfdoiW]]002o`00
00KoZ;oZ00?o0000ojRoj_nX_nX02OnX_nX4o`0000;oZ;oZ00?o0000ojRoj_nX_nX03onX_nX00ol0
003oZ;oZojRojP08ojRojP?o00001OnX_nX00ol0003oZ;oZojRojP0?ojRojP03o`000?nX_n[oZ;oZ
00GoZ;oZ0ol0000=ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02?ooool002;o
oooo00?o0000ooooooooool0@?ooool00ol0003oU[cboiJllP05o`0000[oWKo`00?o0000oh>mnOn3
_OT03_n3_OT2o`000003obNQkOl0003o000000CoGWkK00?o0000ofQhcomXN<l02OmXN<l00ol0003o
Ogo9ogmob@0;ogmob@03o`000?nFR/CoUX[400goUX[400?o0000ojRC`?nXTl004?nXTl000ol0003o
]9ZmokBJ_@06okBJ_@04o`000?nIkKCoVNfdo`0000WoZ;oZ00?o0000ojRoj_nX_nX01OnX_nX3o`00
00OoZ;oZ00?o0000ojRoj_nX_nX03onX_nX00ol0003oZ;oZojRojP04ojRojP?o00002OnX_nX00ol0
003oZ;oZojRojP0?ojRojP03o`000?nX_n[oZ;oZ00Co00004Oooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo00Sooooo000Sooooo`;o0000@Oooool2o`00013oWKo`00?o0000oh>mnOn3
_OT03On3_OT7o`0000?oGWkK00?o0000ofQhcomXN<l02OmXN<l00ol0003oOgo9ogmob@0:ogmob@03
o`000?nFR/CoUX[400koUX[400?o0000ojRC`?nXTl003onXTl000ol0003o]9ZmokBJ_@05okBJ_@04
o`000?nIkKCoVNfdo`0000_oZ;oZ00?o0000ojRoj_nX_nX01?l0000;ojRojP03o`000?nX_n[oZ;oZ
00ooZ;oZ00?o0000ojRoj_nX_nX00ol0000=ojRojP03o`000?nX_n[oZ;oZ00goZ;oZ1?l0000Eoooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02?ooool002Gooooo00?o0000oooooooo
ool0@?ooool00ol0003oWKo`oifol00>oifol003o`000?n3_OWoPkgi00WoPkgi0ol00004oj;0kP03
o`000?nH`_CoV<;d00;o000000?oGWkKo`000?mXN<l02_mXN<l00ol0003oOgo9ogmob@0;ogmob@03
o`000?nFR/CoUX[400goUX[400?o0000ojRC`?nXTl003onXTl000ol0003o]9ZmokBJ_@03okBJ_@;o
000000?oVNfdo`000?l000003?nX_nX3o`00013oZ;oZ00?o0000ojRoj_nX_nX03OnX_nX4o`00013o
Z;oZ00?o0000ojRoj_nX_nX02OnX_nX4o`0001[ooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`08ooooo`009_ooool00ol0003oooooooooo`10ooooo`03o`000?nM_o3oWKo`00koWKo`
00?o0000oh>mnOn3_OT01?n3_OT4o`0000SoX/3^00Oo0000oiS2m?nH`_CoV<;do`000?mNO]_o0000
00[oJ7S?00?o0000ogmobOmoOlT02omoOlT00ol0003oUX[4oiJ:a00>oiJ:a003o`000?nXTl3oZ9?0
00ooZ9?000Ko0000okBJ_OndV[go]9Zmo`000?nIkK@2o`0000_oZ;oZ0ol000000onX_n[o0000ojRo
jP0AojRojP03o`000?nX_n[oZ;oZ00WoZ;oZ0ol00003ojRojP03o`000?nX_n[oZ;oZ00ooZ;oZ00?o
0000ojRoj_nX_nX01OnX_nX3o`0001oooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`08ooooo`009oooool00ol0003oooooooooo`10ooooo`03o`000?nM_o3oWKo`00koWKo`00?o0000
oh>mnOn3_OT00ol0000=oj;0kP04o`000?nH`_CoV<;doiS2m0;o00002omXN<l00ol0003oOgo9ogmo
b@0;ogmob@03o`000?nFR/CoUX[400goUX[400?o0000ojRC`?nXTl003onXTl000ol0003o]9ZmokBJ
_@04o`0000WoZ;oZ0ol00005ojRojP03o`000?nX_n[oZ;oZ013oZ;oZ00?o0000ojRoj_nX_nX01?nX
_nX4o`0000OoZ;oZ00?o0000ojRoj_nX_nX03onX_nX00ol0003oZ;oZojRojP04o`0002;ooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`08ooooo`00:?ooool2o`00047ooooo00?o0000
oifol?nM_o003?nM_o04o`00017oX/3^00?o0000oiS2m?nH`_@00_nH`_@2o`0000WoJ7S?00?o0000
ogmobOmoOlT02omoOlT00ol0003oUX[4oiJ:a00>oiJ:a003o`000?nXTl3oZ9?000koZ9?000Co0000
okBJ_Ol0003o00000onX_nX00ol0003oZ;oZojRojP03ojRojP?o00002OnX_nX00ol0003oZ;oZojRo
jP0@ojRojP03o`000?nX_n[oZ;oZ00?o00003?nX_nX00ol0003oZ;oZojRojP0=ojRojPCo00009ooo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Sooooo000Zooooo`03o`000?oooooo
oooo03oooooo00?o0000oifol?nM_o002?nM_o03o`0000CoY[o/00?o0000oj;0k_nR`>h03onR`>h0
0ol0003oV<;doiS2m003oiS2m0;o00002?mXN<l00ol0003oOgo9ogmob@0:ogmob@03o`000?nFR/Co
UX[400koUX[400?o0000ojRC`?nXTl003_nXTl02o`0000KoZ;oZ00?o0000ojRoj_l000000_l0000=
ojRojP03o`000?nX_n[oZ;oZ00koZ;oZ1?l0000@ojRojP03o`000?nX_n[oZ;oZ00WoZ;oZ0ol0000/
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool02?ooool002_ooooo00?o0000oooo
ooooool0?oooool00ol0003oWKo`oifol004oifol0?o00002?nV_n`00ol0003oX/3^oj;0kP0?oj;0
kP03o`000?nH`_CoV<;d00?o000000?oYko[o`000?l000001_mXN<l00ol0003oOgo9ogmob@0;ogmo
b@03o`000?nFR/CoUX[400goUX[400?o0000ojRC`?nXTl003?nXTl02o`0000OoZ;oZ0ol0000AojRo
jP03o`000?nX_n[oZ;oZ00WoZ;oZ1?l00002ojRojP03o`000?nX_n[oZ;oZ013oZ;oZ00?o0000ojRo
j_nX_nX01?nX_nX4o`00033ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`07oooo
o`00;?ooool00ol0003oooooooooo`0oooooo`03o`000?nM_o3oWKo`00?o00003?nV_n`2o`0000ko
X/3^1?l00006ojNoj`;o00001?mXN<l00ol0003oOgo9ogmob@0;ogmob@03o`000?nFR/CoUX[400ko
UX[400?o0000ojRC`?nXTl002OnXTl02o`0000KoZ;oZ0ol00003ojRojP03o`000?nX_n[oZ;oZ00oo
Z;oZ00?o0000ojRoj_nX_nX01OnX_nX3o`0000OoZ;oZ00?o0000ojRoj_nX_nX04?nX_nX00ol0003o
Z;oZojRojP03o`0003Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`07ooooo`00
;Oooool2o`00043ooooo0_l0000AojJok003o`000?nR`>koX/3^00SoX/3^0ol00004ojRojP03o`00
0?nW_n_oYko[00GoYko[0_l00003ofQhc`03o`000?moOlWoOgo900_oOgo900?o0000oiJ:a?nFR/@0
3OnFR/@00ol0003oZ9?0ojRC`006ojRC`0?o00001?nX_nX4o`0000OoZ;oZ00?o0000ojRoj_nX_nX0
3onX_nX00ol0003oZ;oZojRojP04o`0000_oZ;oZ00?o0000ojRoj_nX_nX03onX_nX3o`0003Sooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`07ooooo`00;oooool00ol0003ooooooooo
o`0oooooo`03o`000?nV_ncoY[o/00ooY[o/00?o0000oj;0k_nR`>h01?nR`>h3o`0000SoZ;oZ00?o
0000ojNojonW_n/01_nW_n/2o`000003ofQhcol0003oOgo900coOgo900?o0000oiJ:a?nFR/@03_nF
R/@00ol0003oZ9?0ojRC`003ojRC`0;o000000CoZ;oZo`000?nX_n[oZ;oZ0ol0000<ojRojP03o`00
0?nX_n[oZ;oZ00goZ;oZ1?l0000@ojRojP03o`000?nX_n[oZ;oZ00_oZ;oZ0ol0000looooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool01oooool0033ooooo00?o0000ooooooooool0?ooo
ool00ol0003oY[o/ojJok00?ojJok003o`000?nR`>koX/3^00?o00003?nX_nX00ol0003oYko[ojNo
j`07ojNoj`;o00003OmoOlT00ol0003oUX[4oiJ:a00>oiJ:a004o`000?nXTl3oZ9?0ojRC`0;o0000
0_nX_nX4o`00013oZ;oZ00?o0000ojRoj_nX_nX02OnX_nX3o`0000;oZ;oZ00?o0000ojRoj_nX_nX0
3onX_nX00ol0003oZ;oZojRojP08ojRojP?o0000@?ooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo00Oooooo000aooooo`03o`000?oooooooooo03oooooo00?o0000ojJok?nV_n`03OnV
_n`4o`00013oZ;oZ00?o0000ojNojonW_n/02?nW_n/4o`0000[oOgo900?o0000oiJ:a?nFR/@03OnF
R/@01Ol0003oZ9?0o`000?l0003oZ;oZ00?o00001?nX_nX00ol0003oZ;oZojRojP0>ojRojP03o`00
0?nX_n[oZ;oZ00CoZ;oZ1?l00006ojRojP03o`000?nX_n[oZ;oZ00ooZ;oZ00?o0000ojRoj_nX_nX0
1?nX_nX3o`0004?ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`07ooooo`00<_oo
ool2o`00043ooooo00?o0000ojJok?nV_n`02OnV_n`3o`0000CoZ;oZ00?o0000ojRoj_nX_nX03_nX
_nX00ol0003oYko[ojNoj`04ojNoj`?o00001?nX_nX5o`0000GoOgo900?o0000oiJ:a?nFR/@02_nF
R/@8o`0000SoZ;oZ00?o0000ojRoj_nX_nX03_nX_nX00ol0003oZ;oZojRojP03o`0000_oZ;oZ00?o
0000ojRoj_nX_nX03onX_nX00ol0003oZ;oZojRojP03o`0004Oooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`07ooooo`00=?ooool00ol0003oooooooooo`0nooooo`03o`000?nV_nco
Y[o/00CoY[o/1?l00008ojRojP03o`000?nX_n[oZ;oZ00koZ;oZ00?o0000ojNojonW_n/00ol0000;
ojRojPOo00001?nFR/@8o`0000;oZ;oZ0ol0000<ojRojP03o`000?nX_n[oZ;oZ00coZ;oZ1?l0000?
ojRojP03o`000?nX_n[oZ;oZ00goZ;oZ1?l0001;ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool01_ooool003Gooooo00?o0000ooooooooool0?_ooool00ol0003oY[o/ojJok003o`00
00goZ;oZ00?o0000ojRoj_nX_nX03?nX_nX4o`0000ooZ;oZ00?o0000ojRoj_nX_nX00_nX_nX5o`00
00KoZ;oZ1?l0000@ojRojP03o`000?nX_n[oZ;oZ00SoZ;oZ0ol00002ojRojP03o`000?nX_n[oZ;oZ
00ooZ;oZ00?o0000ojRoj_nX_nX02OnX_nX3o`0004oooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`06ooooo`00=_ooool00ol0003oooooooooo`0nooooo`;o00004OnX_nX00ol0003o
Z;oZojRojP08ojRojP?o00000onX_nX00ol0003oZ;oZojRojP0>ojRojP03o`000?nX_n[oZ;oZ00Wo
Z;oZ0ol00003ojRojP03o`000?nX_n[oZ;oZ00ooZ;oZ00?o0000ojRoj_nX_nX01?nX_nX3o`0000Ko
Z;oZ00?o0000ojRoj_nX_nX03onX_nX00ol0003oZ;oZojRojP04ojRojPCo0000Doooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo00Kooooo000gooooo`03o`000?oooooooooo03oooooo
00?o0000ojRoj_nX_nX03onX_nX00ol0003oZ;oZojRojP04ojRojP?o00001onX_nX00ol0003oZ;oZ
ojRojP0>ojRojP03o`000?nX_n[oZ;oZ00CoZ;oZ1?l00007ojRojP03o`000?nX_n[oZ;oZ00ooZ;oZ
00?o0000ojRoj_nX_nX00ol0000:ojRojP03o`000?nX_n[oZ;oZ00ooZ;oZ00?o0000ojRoj_nX_nX0
0ol0001Hooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01_ooool003Sooooo0_l0
0010ooooo`03o`000?nX_n[oZ;oZ00ooZ;oZ00?o0000ojRoj_nX_nX00ol0000;ojRojP03o`000?nX
_n[oZ;oZ00koZ;oZ00?o0000ojRoj_nX_nX00ol0000<ojRojP03o`000?nX_n[oZ;oZ00goZ;oZ1?l0
000>ojRojP03o`000?nX_n[oZ;oZ00goZ;oZ1?l0001Looooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool01_ooool003[ooooo00?o0000ooooooooool0?_ooool2o`0000koZ;oZ1?l0000?
ojRojP03o`000?nX_n[oZ;oZ00coZ;oZ1?l0000@ojRojP03o`000?nX_n[oZ;oZ00WoZ;oZ0ol00002
ojRojP03o`000?nX_n[oZ;oZ00koZ;oZ00?o0000ojRoj_nX_nX02OnX_nX3o`00063ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`06ooooo`00>oooool00ol0003oooooooooo`0ooooo
o`03o`000?nX_n[oZ;oZ00SoZ;oZ0ol00003ojRojP03o`000?nX_n[oZ;oZ00koZ;oZ00?o0000ojRo
j_nX_nX02?nX_nX3o`0000CoZ;oZ00?o0000ojRoj_nX_nX03_nX_nX00ol0003oZ;oZojRojP04ojRo
jPCo00001_nX_nX00ol0003oZ;oZojRojP0>ojRojP03o`000?nX_n[oZ;oZ00CoZ;oZ1?l0001Toooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01_ooool003cooooo00?o0000oooooooo
ool0?oooool00ol0003oZ;oZojRojP04ojRojP?o00001onX_nX00ol0003oZ;oZojRojP0>ojRojP03
o`000?nX_n[oZ;oZ00CoZ;oZ0ol00008ojRojP03o`000?nX_n[oZ;oZ00koZ;oZ00?o0000ojRoj_nX
_nX00ol0000;ojRojP03o`000?nX_n[oZ;oZ00koZ;oZ00?o0000ojRoj_nX_nX00ol0001Yooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool003gooooo0_l00010ooooo`03o`00
0?nX_n[oZ;oZ00?o00002onX_nX00ol0003oZ;oZojRojP0>ojRojP03o`000?nX_n[oZ;oZ00?o0000
3?nX_nX00ol0003oZ;oZojRojP0<ojRojPCo00003onX_nX00ol0003oZ;oZojRojP0<ojRojPCo0000
KOooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo000oooooo`03o`000?oo
oooooooo03kooooo0_l0000?ojRojP03o`000?nX_n[oZ;oZ00coZ;oZ1?l0000@ojRojP03o`000?nX
_n[oZ;oZ00SoZ;oZ0ol00003ojRojP03o`000?nX_n[oZ;oZ00koZ;oZ00?o0000ojRoj_nX_nX02?nX
_nX3o`00077ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`05ooooo`00@?ooool0
0ol0003oooooooooo`0nooooo`03o`000?nX_n[oZ;oZ00koZ;oZ00?o0000ojRoj_nX_nX02?nX_nX3
o`0000?oZ;oZ00?o0000ojRoj_nX_nX03onX_nX00ol0003oZ;oZojRojP04ojRojP?o00001onX_nX0
0ol0003oZ;oZojRojP0>ojRojP03o`000?nX_n[oZ;oZ00CoZ;oZ0ol0001eooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01Oooool0047ooooo00?o0000ooooooooool0?_ooool00ol0
003oZ;oZojRojP0>ojRojP03o`000?nX_n[oZ;oZ00CoZ;oZ0ol00007ojRojP03o`000?nX_n[oZ;oZ
00ooZ;oZ00?o0000ojRoj_nX_nX00ol0000;ojRojP03o`000?nX_n[oZ;oZ00koZ;oZ00?o0000ojRo
j_nX_nX00ol0001iooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool004;o
oooo0_l0000oooooo`03o`000?nX_n[oZ;oZ00koZ;oZ00?o0000ojRoj_nX_nX00ol0000;ojRojP03
o`000?nX_n[oZ;oZ00goZ;oZ1?l0000?ojRojP03o`000?nX_n[oZ;oZ00coZ;oZ1?l0001looooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool004Cooooo00?o0000ooooooooool0
?Oooool00ol0003oZ;oZojRojP0<ojRojPCo00003onX_nX00ol0003oZ;oZojRojP09ojRojP?o0000
0onX_nX00ol0003oZ;oZojRojP0>ojRojP03o`000?nX_n[oZ;oZ00KoZ;oZ1Ol00021ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool004Gooooo00?o0000ooooooooool0?Ooo
ool00ol0003oZ;oZojRojP08ojRojP?o00000onX_nX00ol0003oZ;oZojRojP0>ojRojP03o`000?nX
_n[oZ;oZ00CoZ;oZ1?l00007ojRojP03o`000?nX_n[oZ;oZ00koZ;oZ00?o0000ojRoj_nX_nX01Ol0
0027ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool004Kooooo00?o0000
ooooooooool0?Oooool00ol0003oZ;oZojRojP04ojRojP?o00001onX_nX00ol0003oZ;oZojRojP0>
ojRojP03o`000?nX_n[oZ;oZ00?o00003?nX_nX00ol0003oZ;oZojRojP0<ojRojPCo0000SOooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo0017ooooo`;o0000?_ooool00ol0
003oZ;oZojRojP03o`0000_oZ;oZ00?o0000ojRoj_nX_nX03?nX_nX4o`00013oZ;oZ00?o0000ojRo
j_nX_nX02?nX_nX3o`00097ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`00BOooool00ol0003oooooooooo`0looooo`;o00003onX_nX00ol0003oZ;oZojRojP08ojRojP?o
00001?nX_nX00ol0003oZ;oZojRojP0>ojRojP03o`000?nX_n[oZ;oZ00CoZ;oZ0ol0002Eooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool004[ooooo00?o0000ooooooooool0
?Oooool00ol0003oZ;oZojRojP0=ojRojP03o`000?nX_n[oZ;oZ00CoZ;oZ0ol00008ojRojP03o`00
0?nX_n[oZ;oZ00koZ;oZ00?o0000ojRoj_nX_nX00ol0002Iooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool004_ooooo00?o0000ooooooooool0?Oooool00ol0003oZ;oZojRo
jP0=ojRojP03o`000?nX_n[oZ;oZ00?o00003?nX_nX00ol0003oZ;oZojRojP0<ojRojPCo0000WOoo
ool01Ol0003ooooooooooooooooo000000Kooooo001<ooooo`;o0000?_ooool00ol0003oZ;oZojRo
jP0<ojRojP?o00004?nX_nX00ol0003oZ;oZojRojP08ojRojP?o0000XOooool01Ol0003ooooooooo
oooooooo000000Kooooo001>ooooo`03o`000?oooooooooo03cooooo00?o0000ojRoj_nX_nX02?nX
_nX3o`0000?oZ;oZ00?o0000ojRoj_nX_nX03_nX_nX00ol0003oZ;oZojRojP04ojRojP?o0000YOoo
ool01?l0003oooooooooool00006ooooo`00Coooool00ol0003oooooooooo`0looooo`03o`000?nX
_n[oZ;oZ00CoZ;oZ0ol00007ojRojP03o`000?nX_n[oZ;oZ00koZ;oZ00?o0000ojRoj_nX_nX00ol0
002Yooooo`03o`000?oooooo000000Kooooo001@ooooo`03o`000?oooooooooo03cooooo00?o0000
ojRoj_nX_nX00ol0000;ojRojP03o`000?nX_n[oZ;oZ00coZ;oZ1?l0002/ooooo`04o`000?oooooo
ooooo`0000Gooooo001Aooooo`;o0000?Oooool2o`0000ooZ;oZ00?o0000ojRoj_nX_nX02?nX_nX3
o`000;7ooooo00?o0000ooooool000001Oooool005?ooooo00?o0000ooooooooool0??ooool00ol0
003oZ;oZojRojP0=ojRojP03o`000?nX_n[oZ;oZ00CoZ;oZ0ol0002eooooo`;o00001Oooool005Co
oooo00?o0000ooooooooool0??ooool00ol0003oZ;oZojRojP0=ojRojP03o`000?nX_n[oZ;oZ00?o
0000]oooool3o`0000Gooooo001Eooooo`03o`000?oooooooooo03cooooo00?o0000ojRoj_nX_nX0
2onX_nX4o`000;Kooooo1?l00008ooooo`00E_ooool00ol0003oooooooooo`0looooo`03o`000?nX
_n[oZ;oZ00GoZ;oZ1Ol0002fooooo`Co00003?ooool005Oooooo0_l0000mooooo`03o`000?nX_n[o
Z;oZ00Co0000]oooool4o`00013ooooo001Iooooo`03o`000?oooooooooo03_ooooo0_l0002hoooo
o`?o00005?ooool005[ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`2cooooo`Co
00005oooool005_ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`2_ooooo`Co0000
6oooool005cooooo0_l0000iooooo`03o`000?oooooooooo0:_ooooo1?l0000Oooooo`00G_ooool0
0ol0003oooooooooo`0fooooo`03o`000?oooooooooo0:Oooooo1?l0000Sooooo`00Goooool00ol0
003oooooooooo`0eooooo`03o`000?oooooooooo0:?ooooo1?l0000Wooooo`00H?ooool00ol0003o
ooooooooo`0dooooo`03o`000?oooooooooo09oooooo1?l0000[ooooo`00HOooool2o`0003Cooooo
00?o0000ooooooooool0W?ooool3o`0002oooooo001Sooooo`03o`000?oooooooooo037ooooo00?o
0000ooooooooool0V?ooool4o`0003;ooooo001Tooooo`03o`000?oooooooooo033ooooo00?o0000
ooooooooool0U?ooool4o`0003Kooooo001Uooooo`03o`000?oooooooooo02oooooo00?o0000oooo
ooooool0T?ooool4o`0003[ooooo001Vooooo`;o0000;oooool00ol0003oooooooooo`2<ooooo`Co
0000?_ooool006Sooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`28ooooo`Co0000
@_ooool006Wooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`24ooooo`Co0000A_oo
ool006[ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`21ooooo`Co0000B_ooool0
06_ooooo0_l0000Yooooo`03o`000?oooooooooo07kooooo0ol0001>ooooo`00KOooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo07[ooooo1?l0001Aooooo`00K_ooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo07Kooooo1?l0001Eooooo`00Koooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo07;ooooo1?l0001Iooooo`00L?ooool00ol0003oooooooooo`0S
ooooo`03o`000?oooooooooo06kooooo1?l0001Mooooo`00LOooool2o`0002?ooooo00?o0000oooo
ooooool0J_ooool4o`00067ooooo001cooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool0I_ooool4o`0006Gooooo001dooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0
H_ooool4o`0006Wooooo001eooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0Gooo
ool3o`0006gooooo001fooooo`;o00007_ooool00ol0003oooooooooo`1Kooooo`Co0000L?ooool0
07Sooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Gooooo`Co0000M?ooool007Wo
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1Cooooo`Co0000N?ooool007[ooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`1?ooooo`Co0000O?ooool007_ooooo0_l0
000Iooooo`03o`000?oooooooooo04_ooooo1?l00020ooooo`00OOooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo04Oooooo1?l00024ooooo`00O_ooool00ol0003oooooooooo`0Eoooo
o`03o`000?oooooooooo04Cooooo0ol00028ooooo`00Ooooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo043ooooo1?l0002;ooooo`00P?ooool2o`0001Cooooo00?o0000ooooooooool0
??ooool4o`0008oooooo0022ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0>?oo
ool4o`0009?ooooo0023ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0=?ooool4
o`0009Oooooo0024ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0<?ooool4o`00
09_ooooo0025ooooo`;o00003oooool00ol0003oooooooooo`0/ooooo`Co0000Woooool008Oooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Xooooo`Co0000Xoooool008Sooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0Vooooo`?o0000Yoooool008Wooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0Rooooo`Co0000Z_ooool008[ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`0Nooooo`Co0000[_ooool008_ooooo0_l00008ooooo`03
o`000?oooooooooo01[ooooo1?l0002booooo`00SOooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo01Kooooo1?l0002fooooo`00S_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo01;ooooo1?l0002jooooo`00Soooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00kooooo1?l0002nooooo`00T?ooool2o`0000?ooooo00?o0000ooooooooool02oooool3o`00
0<;ooooo002Booooo`04o`000?ooooooooooo`0000Wooooo1?l00035ooooo`00Toooool00ol0003o
ooooo`000005ooooo`Co0000bOooool009Cooooo0_l000000ooooooo0000o`000002o`000<gooooo
002Eooooo`;o0000dOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.040844, 0.0227724, \
0.00350012, 0.00350012}}]
}, Open  ]],

Cell[TextData[{
  "For this disperion relation, Eq. ",
  ButtonBox["(5.3.15)",
    ButtonData:>"(5.3.15)",
    ButtonStyle->"Hyperlink"],
  " implies that ",
  Cell[BoxData[
      \(TraditionalForm\`\[DifferentialD]\[Phi]/\[DifferentialD]t = 0\)]],
  ", so that phase is constant along the wavepacket trajectories:  \
wavepackets move at the same velocity as phase fronts because these waves are \
dispersionless. "
}], "Text"],

Cell["\<\
After choosing a value for the initial wavenumber, we integrate \
forward in time  starting from a grid of points below the \
inhomogeneity:\
\>", "Text"],

Cell[BoxData[
    \(\(\[Kappa] = 1;\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 5.37"],

Cell[BoxData[
    \(\(phasedata\  = \ 
        Table[{x[t], 
              y[t], \[Phi][t]} /. \(sol[{x0, y0}, 
                k0[{x0, 
                    y0}]]\)[\([1]\)], {y0, \(- .45\),  .45,  .1}, {x0, \(- \
.45\),  .45,  .1}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 5.38"],

Cell[TextData[{
  "We then plot the phase of the points versus ",
  Cell[BoxData[
      \(TraditionalForm\`x - y\)]],
  " position for several times using ",
  StyleBox["ScatterPlot3D",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  ":"
}], "Text"],

Cell[BoxData[
    \(<< Graphics`\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 5.39"],

Cell[BoxData[
    \(\(Table[
        Table[ScatterPlot3D[phasedata[\([n]\)], PlotJoined \[Rule] True, 
            PlotStyle \[Rule] Hue[n/Length[phasedata]], 
            DisplayFunction \[Rule] Identity], {n, 1, 
            Length[phasedata]}], {t, 0, 4,  .2}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 5.40"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Table[
        Show[%[\([n]\)], DisplayFunction \[Rule] $DisplayFunction, 
          PlotRange \[Rule] {{\(-2\), 2}, {\(- .5\), 5}, {\(-1\), 1}}], {n, 
          1, Length[%]}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 5.41"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .89104 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-16 1.0656 -0.0363427 1.0656 [
[.02544 .21571 -12 -8.9133 ]
[.02544 .21571 0 .0867 ]
[.16074 .16277 -11.6592 -9 ]
[.16074 .16277 .34081 0 ]
[.3021 .10747 -5.60025 -9 ]
[.3021 .10747 .39975 0 ]
[.44992 .04965 -5.37091 -9 ]
[.44992 .04965 .62909 0 ]
[.60467 -0.01084 -5.14157 -9 ]
[.60467 -0.01084 .85843 0 ]
[.66454 .05085 0 -6.20675 ]
[.66454 .05085 6 2.79325 ]
[.80797 .25198 0 -6.0417 ]
[.80797 .25198 6 2.9583 ]
[.93071 .4241 0 -5.90576 ]
[.93071 .4241 6 3.09424 ]
[.02254 .22988 -12 -2.74631 ]
[.02254 .22988 0 6.25369 ]
[.0142 .29178 -24 -2.78907 ]
[.0142 .29178 0 6.21093 ]
[.00558 .35578 -6 -2.83339 ]
[.00558 .35578 0 6.16661 ]
[-0.00334 .42198 -18 -2.87938 ]
[-0.00334 .42198 0 6.12062 ]
[-0.01257 .49051 -6 -2.92712 ]
[-0.01257 .49051 0 6.07288 ]
[ 0 0 0 0 ]
[ 1 .89104 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03495 .22504 m
.61241 0 L
s
.03495 .22504 m
.03971 .2297 L
s
[(-2)] .02544 .21571 1 .98073 Mshowa
.16988 .17246 m
.17445 .1773 L
s
[(-1)] .16074 .16277 .9432 1 Mshowa
.31082 .11753 m
.31518 .12256 L
s
[(0)] .3021 .10747 .86675 1 Mshowa
.45818 .0601 m
.46231 .06533 L
s
[(1)] .44992 .04965 .7903 1 Mshowa
.61241 0 m
.61628 .00542 L
s
[(2)] .60467 -0.01084 .71386 1 Mshowa
.125 Mabswid
.06148 .2147 m
.06431 .21752 L
s
.08823 .20428 m
.09104 .20712 L
s
.11521 .19376 m
.118 .19663 L
s
.14243 .18316 m
.14519 .18604 L
s
.19758 .16166 m
.20029 .16459 L
s
.22551 .15078 m
.22821 .15373 L
s
.2537 .13979 m
.25637 .14277 L
s
.28213 .12871 m
.28478 .13171 L
s
.33977 .10625 m
.34236 .10929 L
s
.36897 .09487 m
.37153 .09794 L
s
.39844 .08339 m
.40097 .08648 L
s
.42817 .0718 m
.43068 .07491 L
s
.48846 .0483 m
.49091 .05146 L
s
.51902 .03639 m
.52144 .03958 L
s
.54986 .02437 m
.55225 .02758 L
s
.58099 .01224 m
.58335 .01547 L
s
.25 Mabswid
.61241 0 m
.97291 .505 L
s
.65208 .05558 m
.64586 .05794 L
s
[(0)] .66454 .05085 -1 .37928 Mshowa
.79537 .2563 m
.78907 .25846 L
s
[(2)] .80797 .25198 -1 .3426 Mshowa
.91799 .42808 m
.91164 .43006 L
s
[(4)] .93071 .4241 -1 .31239 Mshowa
.125 Mabswid
.69012 .10886 m
.68637 .11025 L
s
.72662 .16 m
.72286 .16135 L
s
.76168 .2091 m
.75791 .21042 L
s
.82778 .3017 m
.82399 .30297 L
s
.85897 .3454 m
.85518 .34664 L
s
.88903 .3875 m
.88522 .38871 L
s
.94594 .46722 m
.94211 .46839 L
s
.25 Mabswid
.03495 .22504 m
0 .48612 L
s
.03495 .22504 m
.04116 .22262 L
s
[(-1)] .02254 .22988 1 -0.38971 Mshowa
.02665 .28704 m
.03288 .28468 L
s
[(-0.5)] .0142 .29178 1 -0.38021 Mshowa
.01807 .35115 m
.02431 .34884 L
s
[(0)] .00558 .35578 1 -0.37036 Mshowa
.00919 .41747 m
.01546 .41521 L
s
[(0.5)] -0.00334 .42198 1 -0.36014 Mshowa
0 .48612 m
.00629 .48392 L
s
[(1)] -0.01257 .49051 1 -0.34953 Mshowa
.125 Mabswid
.03331 .23728 m
.03704 .23583 L
s
.03166 .2496 m
.03539 .24816 L
s
.03 .262 m
.03373 .26056 L
s
.02833 .27448 m
.03207 .27305 L
s
.02496 .29969 m
.0287 .29828 L
s
.02325 .31243 m
.02699 .31102 L
s
.02154 .32525 m
.02528 .32385 L
s
.01981 .33816 m
.02355 .33676 L
s
.01632 .36423 m
.02007 .36285 L
s
.01455 .37741 m
.01831 .37603 L
s
.01278 .39067 m
.01653 .3893 L
s
.01099 .40402 m
.01475 .40266 L
s
.00738 .43101 m
.01114 .42966 L
s
.00555 .44464 m
.00932 .4433 L
s
.00371 .45837 m
.00748 .45704 L
s
.00186 .4722 m
.00563 .47087 L
s
.25 Mabswid
.03495 .22504 m
0 .48612 L
s
0 .48612 m
.46953 .89104 L
s
.46953 .89104 m
.47294 .65459 L
s
.47294 .65459 m
.03495 .22504 L
s
.61241 0 m
.97291 .505 L
s
.97291 .505 m
1 .75117 L
s
1 .75117 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.03495 .22504 m
0 .48612 L
s
0 .48612 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.61241 0 m
.03495 .22504 L
s
.47294 .65459 m
.97291 .505 L
s
.97291 .505 m
1 .75117 L
s
1 .75117 m
.46953 .89104 L
s
.46953 .89104 m
.47294 .65459 L
s
0 0 m
1 0 L
1 .89104 L
0 .89104 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.32032 .42086 m
.33479 .4159 L
s
1 0 .6 r
.31209 .3983 m
.32655 .39329 L
s
.8 0 1 r
.30385 .37571 m
.3183 .37065 L
s
.2 0 1 r
.2956 .35309 m
.31004 .34797 L
s
1 0 0 r
.33479 .4159 m
.34932 .41093 L
s
0 .4 1 r
.28734 .33043 m
.30177 .32526 L
s
1 0 .6 r
.32655 .39329 m
.34108 .38826 L
s
0 1 1 r
.27906 .30775 m
.29349 .30252 L
s
.8 0 1 r
.3183 .37065 m
.33282 .36556 L
s
0 1 .4 r
.27078 .28503 m
.2852 .27976 L
s
.2 0 1 r
.31004 .34797 m
.32455 .34283 L
s
1 0 0 r
.34932 .41093 m
.36392 .40593 L
s
.2 1 0 r
.26248 .26229 m
.27689 .25695 L
s
0 .4 1 r
.30177 .32526 m
.31627 .32007 L
s
1 0 .6 r
.34108 .38826 m
.35567 .38321 L
s
.8 1 0 r
.25417 .23951 m
.26858 .23412 L
s
0 1 1 r
.29349 .30252 m
.30798 .29728 L
s
.8 0 1 r
.33282 .36556 m
.3474 .36046 L
s
1 .6 0 r
.24586 .2167 m
.26025 .21126 L
s
0 1 .4 r
.2852 .27976 m
.29968 .27445 L
s
.2 0 1 r
.32455 .34283 m
.33913 .33767 L
s
1 0 0 r
.36392 .40593 m
.37859 .40091 L
s
.2 1 0 r
.27689 .25695 m
.29137 .2516 L
s
0 .4 1 r
.31627 .32007 m
.33084 .31485 L
s
1 0 .6 r
.35567 .38321 m
.37033 .37813 L
s
.8 1 0 r
.26858 .23412 m
.28304 .22871 L
s
0 1 1 r
.30798 .29728 m
.32254 .29201 L
s
.8 0 1 r
.3474 .36046 m
.36205 .35533 L
s
1 .6 0 r
.26025 .21126 m
.27471 .20579 L
s
0 1 .4 r
.29968 .27445 m
.31423 .26913 L
s
.2 0 1 r
.33913 .33767 m
.35377 .33249 L
s
1 0 0 r
.37859 .40091 m
.39332 .39587 L
s
.2 1 0 r
.29137 .2516 m
.30591 .24622 L
s
0 .4 1 r
.33084 .31485 m
.34547 .30961 L
s
1 0 .6 r
.37033 .37813 m
.38505 .37304 L
s
.8 1 0 r
.28304 .22871 m
.29757 .22327 L
s
0 1 1 r
.32254 .29201 m
.33716 .28671 L
s
.8 0 1 r
.36205 .35533 m
.37677 .35017 L
s
1 .6 0 r
.27471 .20579 m
.28923 .2003 L
s
0 1 .4 r
.31423 .26913 m
.32884 .26378 L
s
.2 0 1 r
.35377 .33249 m
.36847 .32728 L
s
1 0 0 r
.39332 .39587 m
.40812 .3908 L
s
.2 1 0 r
.30591 .24622 m
.32051 .24081 L
s
0 .4 1 r
.34547 .30961 m
.36017 .30435 L
s
1 0 .6 r
.38505 .37304 m
.39984 .36791 L
s
.8 1 0 r
.29757 .22327 m
.31217 .21781 L
s
0 1 1 r
.33716 .28671 m
.35185 .28139 L
s
.8 0 1 r
.37677 .35017 m
.39155 .345 L
s
1 .6 0 r
.28923 .2003 m
.30382 .19478 L
s
0 1 .4 r
.32884 .26378 m
.34352 .2584 L
s
.2 0 1 r
.36847 .32728 m
.38325 .32205 L
s
1 0 0 r
.40812 .3908 m
.42298 .38571 L
s
.2 1 0 r
.32051 .24081 m
.33518 .23538 L
s
0 .4 1 r
.36017 .30435 m
.37493 .29906 L
s
1 0 .6 r
.39984 .36791 m
.4147 .36277 L
s
.8 1 0 r
.31217 .21781 m
.32683 .21233 L
s
0 1 1 r
.35185 .28139 m
.36661 .27605 L
s
.8 0 1 r
.39155 .345 m
.4064 .3398 L
s
1 .6 0 r
.30382 .19478 m
.31847 .18924 L
s
0 1 .4 r
.34352 .2584 m
.35827 .253 L
s
.2 0 1 r
.38325 .32205 m
.39809 .31679 L
s
1 0 0 r
.42298 .38571 m
.43791 .3806 L
s
.2 1 0 r
.33518 .23538 m
.34992 .22993 L
s
0 .4 1 r
.37493 .29906 m
.38976 .29375 L
s
1 0 .6 r
.4147 .36277 m
.42962 .3576 L
s
.8 1 0 r
.32683 .21233 m
.34156 .20682 L
s
0 1 1 r
.36661 .27605 m
.38143 .27068 L
s
.8 0 1 r
.4064 .3398 m
.42131 .33457 L
s
1 .6 0 r
.31847 .18924 m
.33319 .18367 L
s
0 1 .4 r
.35827 .253 m
.37309 .24758 L
s
.2 0 1 r
.39809 .31679 m
.41299 .31151 L
s
1 0 0 r
.43791 .3806 m
.45292 .37547 L
s
.2 1 0 r
.34992 .22993 m
.36473 .22445 L
s
0 .4 1 r
.38976 .29375 m
.40466 .28842 L
s
1 0 .6 r
.42962 .3576 m
.44461 .35241 L
s
.8 1 0 r
.34156 .20682 m
.35636 .20128 L
s
0 1 1 r
.38143 .27068 m
.39632 .26529 L
s
.8 0 1 r
.42131 .33457 m
.4363 .32933 L
s
1 .6 0 r
.33319 .18367 m
.34798 .17808 L
s
0 1 .4 r
.37309 .24758 m
.38797 .24213 L
s
.2 0 1 r
.41299 .31151 m
.42797 .30621 L
s
.2 1 0 r
.36473 .22445 m
.3796 .21894 L
s
0 .4 1 r
.40466 .28842 m
.41963 .28306 L
s
.8 1 0 r
.35636 .20128 m
.37122 .19572 L
s
0 1 1 r
.39632 .26529 m
.41128 .25988 L
s
1 .6 0 r
.34798 .17808 m
.36284 .17246 L
s
0 1 .4 r
.38797 .24213 m
.40292 .23666 L
s
.2 1 0 r
.3796 .21894 m
.39454 .21341 L
s
.8 1 0 r
.37122 .19572 m
.38616 .19013 L
s
1 .6 0 r
.36284 .17246 m
.37776 .16682 L
s
0 g
.25 Mabswid
.61241 0 m
.97291 .505 L
s
.97291 .505 m
1 .75117 L
s
1 .75117 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.03495 .22504 m
0 .48612 L
s
0 .48612 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.61241 0 m
.03495 .22504 L
s
.03495 .22504 m
.61241 0 L
s
.03495 .22504 m
.03971 .2297 L
s
[(-2)] .02544 .21571 1 .98073 Mshowa
.16988 .17246 m
.17445 .1773 L
s
[(-1)] .16074 .16277 .9432 1 Mshowa
.31082 .11753 m
.31518 .12256 L
s
[(0)] .3021 .10747 .86675 1 Mshowa
.45818 .0601 m
.46231 .06533 L
s
[(1)] .44992 .04965 .7903 1 Mshowa
.61241 0 m
.61628 .00542 L
s
[(2)] .60467 -0.01084 .71386 1 Mshowa
.125 Mabswid
.06148 .2147 m
.06431 .21752 L
s
.08823 .20428 m
.09104 .20712 L
s
.11521 .19376 m
.118 .19663 L
s
.14243 .18316 m
.14519 .18604 L
s
.19758 .16166 m
.20029 .16459 L
s
.22551 .15078 m
.22821 .15373 L
s
.2537 .13979 m
.25637 .14277 L
s
.28213 .12871 m
.28478 .13171 L
s
.33977 .10625 m
.34236 .10929 L
s
.36897 .09487 m
.37153 .09794 L
s
.39844 .08339 m
.40097 .08648 L
s
.42817 .0718 m
.43068 .07491 L
s
.48846 .0483 m
.49091 .05146 L
s
.51902 .03639 m
.52144 .03958 L
s
.54986 .02437 m
.55225 .02758 L
s
.58099 .01224 m
.58335 .01547 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 256.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001@2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00gOooool5o`0008Kooooo003Mooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0Q_ooool00=ko
oooo00?oV9RHob4Q8Oo^k^h0Qoooool00=oooooo00?oV9RHob4Q8Oo^k^h0Q_ooool00>3ooooo00?o
MgMgofIVI_ooool0QOooool00>7ooooo00?o0000ooooooooool0Q?ooool00=gooooo00Go0000okZj
^_ooooooV9RHoa0@4026ooooo`00gOooool01OnHV9So410@o`000?lQ8B7oc<c<08Kooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003Tooooo`;o0000P_ooool0
0>7ooooo0ol000000ooooooo0000ooooo`21ooooo`00goooool2o`0000Cooooo0_l00021ooooo`00
g?ooool3o`0000Kooooo00?o0000ooooool00000P?ooool00=[ooooo0_l00009ooooo`03o`000?oo
oooo0000083ooooo003Gooooo`?o000000?oooooo`000?ooool02?ooool01?l0003oooooooooool0
001oooooo`00e?ooool3o`0000Cooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooo
oooo000007kooooo003Booooo`;o00004Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo07_ooooo002Zooooo`Co000000?o410@ooooooooool07_ooool3o`0001?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1kooooo`00[?ooool00ol0003oooooooooo`0Nooooo`;o
000000?oooooo`000?ooool04oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07[o
oooo002/ooooo`03o`000?oooooooooo01_ooooo0ol00004ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`1iooooo`00[?ooool00ol0003ooooooooo
o`0Iooooo`;o00006oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo07Wooooo002/
ooooo`03o`000?oooooooooo01Kooooo0ol0000Mooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool02?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^06_ooooo002/ooooo`03o`000?oooooo
oooo01Cooooo0_l000000ooooooo0000ooooo`0Mooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01oooool01OmgMgOoV9RHoooooonHV9SoMgMg06_ooooo002/ooooo`03o`000?oooooo
oooo017ooooo0ol00004ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`06ooooo`05oa0@4?ooooooooooooooool@4100Joooool00:[ooooo00?oEEEE
ofIVI_l000004Oooool2o`0002Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06
ooooo`05o`000?ooooooooooooooool00000Joooool00;_ooooo0ol0000Wooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000006_ooooo002i
ooooo`;o000000?oooooo`000?ooool09oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Cooooo00Go410@oooooooooooooooooa0@401[ooooo`00]_ooool3o`0000Cooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`1[ooooo`00/oooool3o`0002oooooo00?o0000ooooooooool02Oooool2
o`0000Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1[ooooo`00/Oooool2o`0003;ooooo00?o0000
ooooooooool02?ooool01?l0003oooooooooool0001dooooo`00[_ooool3o`000003ooooool0003o
oooo037ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1aooooo`00[?ooool2o`00
00Gooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
077ooooo002Yooooo`?o0000>_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo073o
oooo002Wooooo`;o0000?Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo06oooooo
002Tooooo`?o000000?oooooo`000?ooool0??ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo06oooooo002Rooooo`;o0000@_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo06kooooo001gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08oooool3o`0004Cooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1]ooooo`00Moooool01OmgMgOoV9RHoooooonHV9So
MgMg027ooooo0_l00017ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0K?ooool0
07Oooooo00Go410@oooooooooooooooooa0@400Nooooo`?o00000_ooool00ol0003oooooooooo`14
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0K?ooool007Oooooo00Go0000oooo
ooooooooooooo`00000Looooo`;o0000C?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo06_ooooo001gooooo`05o`000?ooooooooooooooool000006Oooool3o`0004kooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`1Zooooo`00Moooool01Ol@413ooooooooooooooooo
410@01Kooooo0ol0001Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0J_ooool0
07Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Dooooo`;o00000oooool00ol0003oooooooooo`1>
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0JOooool007Oooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Aooooo`?o0000E_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo06Sooooo002;ooooo`;o0000FOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
06Sooooo0028ooooo`?o0000Foooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo06Oo
oooo0026ooooo`;o00000oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo01Gooooo
0_l0001Xooooo`00Poooool3o`00063ooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`1Uooooo`00POooool2o`0006?ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1U
ooooo`00O_ooool4o`0006Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`1Toooo
o`00O?ooool2o`0000Cooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo06?ooooo001iooooo`?o0000J_ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo06?ooooo001gooooo`;o0000KOooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo06;ooooo001dooooo`?o000000?oooooo`000?ooool0K?ooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo067ooooo001aooooo`?o0000L_ooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo063ooooo0019ooooo`Co000000?o410@ooooooooool07oooool2o`0007Go
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1Pooooo`00Boooool00ol0003ooooo
ooooo`0Nooooo`?o0000Moooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo05oooooo
0010ooooo`Ko00001Oooool00ol0003oooooooooo`0Looooo`;o00000_ooool00ol0003ooooooooo
o`1eooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0G_ooool004_ooooo00?o0000
ooooooooool06Oooool3o`0007cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1N
ooooo`00Boooool00ol0003oooooooooo`0Gooooo`;o0000Ooooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo05gooooo001;ooooo`03o`000?oooooooooo01Cooooo0ol00021ooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0G?ooool004_ooooo00?o0000ooooooooool0
4_ooool2o`0000?ooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo05_ooooo0019ooooo`03oeEEEOmVIVKo0000017ooooo0ol00026ooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool0Foooool005_ooooo0_l00029ooooo`03o`000?oooooo
oooo027ooooo0_l0001Looooo`00F?ooool3o`000003ooooool0003ooooo08Sooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`1Iooooo`00E_ooool2o`0003kooooo0_ooV@1>ooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool0FOooool005?ooooo0ol0000mooooo`?ooiT0
D?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo05Sooooo001@ooooo`?o0000?_oo
ool2oonI05?ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1Gooooo`00C_ooool2
o`0000;ooooo00?o0000ooooooooool0>Oooool3oonI05Gooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`1Fooooo`00Boooool3o`0000Gooooo00?o0000ooooooooool0=_ooool2oonI
05Sooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1Fooooo`00BOooool2o`0003ko
oooo0oooV@1Jooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0EOooool004Kooooo
1?l0000mooooo`;ooiT0GOooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo05Cooooo
0014ooooo`;o0000?_ooool3oonI05oooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`1Dooooo`006_ooool5o`0002;ooooo0ol0000mooooo`?ooiT05Oooool2olco04_ooooo00?o0000
ooooooooool0:Oooool00ol0003oooooooooo`1Cooooo`006_ooool01OnHV9So8B4Qonk^k_oooooo
A4A4023ooooo0_l0000looooo`CooiT05Oooool3olco04gooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`1Booooo`004_ooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h07_ooool3o`00
0003ooooool0003ooooo03Sooooo0oooV@0Gooooo`;oc?l0D?ooool00ol0003oooooooooo`0[oooo
o`03o`000?oooooooooo057ooooo000Looooo`03oiRHV?lQ8B7ok^k^01_ooooo0_l0000looooo`;o
oiT05oooool3olco05;ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`1Aooooo`00
7Oooool00omgMgOoIVIVooooo`0Gooooo`?o0000>oooool3oonI01Kooooo0oo<o`1Fooooo`03o`00
0?oooooooooo02_ooooo00?o0000ooooooooool0D?ooool001kooooo00?o0000ooooooooool05?oo
ool2o`0003cooooo0_ooV@0Eooooo`Coc?l0FOooool00ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo04oooooo000Jooooo`05o`000?nj^[[ooooooiRHV?l@41004oooool3o`0000;ooooo00?o
0000ooooooooool0=oooool2oonI01Cooooo0oo<o`1Mooooo`03o`000?oooooooooo02cooooo0_l0
001@ooooo`006_ooool01OnHV9So410@o`000?lQ8B7oc<c<013ooooo0ol0000mooooo`;ooiT05?oo
ool2olco063ooooo00?o0000ooooooooool0;?ooool2o`00053ooooo000]ooooo`;o0000?Oooool3
oonI01?ooooo0oo<o`0Eooooo`?o<ol0B_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooo
oooo04gooooo000Zooooo`?o000000?oooooo`000?ooool0>oooool00oooV@3oooooooooo`0Boooo
o`;oc?l05?ooool4oc?o04gooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1=oooo
o`00:?ooool2o`0005?ooooo0oo<o`0Cooooo`?o<ol0DOooool00ol0003oooooooooo`0_ooooo`03
o`000?oooooooooo04cooooo000Uooooo`?o0000Doooool2olco01Cooooo0_lco`1Dooooo`03o`00
0?oooooooooo033ooooo00?o0000ooooooooool0Boooool002Cooooo0_l0001Booooo`?oc?l05?oo
ool2oc?o05Kooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`1:ooooo`006_ooool4
o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooool00000Coooool2olco01Gooooo0_lco`1H
ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0B_ooool001cooooo00?o0000oooo
ooooool01Oooool01?l0003oooooooooool0001;ooooo`?oc?l05?ooool3oc?o05[ooooo00?o0000
ooooooooool0<_ooool00ol0003oooooooooo`19ooooo`004Oooool6o`0000Gooooo00?o0000oooo
ooooool01Oooool2o`0000;ooooo00?o0000ooooooooool0AOooool3olco01Gooooo0_lco`0Doooo
o`;o0?mVAoooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo04Sooooo000Looooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`12ooooo`;o
c?l05Oooool3oc?o01?ooooo0ol0ofI9ooooo`03o`000?oooooooooo03?ooooo00?o0000oooooooo
ool01oooool5o`0003cooooo000Looooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`1Fooooo`;o<ol05?ooool2o`3oITcooooo00?o0000ooooooooool0
=?ooool00ol0003oooooooooo`06ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0??ooool001cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo05;ooooo
0olco`0Cooooo`?o0?mVC_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00Kooooo
00?oV9RHob4Q8Oo^k^h0?Oooool001cooooo00?o0000ooooooooool01?ooool3o`0000Kooooo00?o
0000ooooooooool0C_ooool3oc?o01Cooooo0_l0ofIAooooo`03o`000?oooooooooo03Kooooo00?o
0000ooooooooool01_ooool00onHV9So8B4Qonk^kP0looooo`006_ooool00omEEEGoIVIVo`000006
ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0BOooool4oc?o01Cooooo0ol0ofIC
ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool01oooool00omgMgOoIVIVooooo`0k
ooooo`008oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo04Gooooo0olco`0Foooo
o`;o0?mVE_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0>_ooool002?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`12ooooo`;o
<ol05_ooool3o`3oIUSooooo00?o0000ooooooooool0=oooool2o`0000Cooooo00Go0000okZj^_oo
ooooV9RHoa0@400looooo`008oooool2o`0000_ooooo00?o0000ooooooooool0?_ooool3oc?o01Go
oooo0ol0ofHEooooo`;o0?ooA?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooo000000Co
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c00looooo`008oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo03cooooo00?o<ol0ooooooooool04oooool3o`3oIQGooooo0ol0oom6ooooo`03
o`000?oooooooooo03Wooooo00?o0000ooooooooool0@_ooool002;ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`1>ooooo`?o0?mV5_ooool2o`3oodWooooo00?o0000ooooooooool0
>_ooool00ol0003oooooooooo`11ooooo`008_ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo04_ooooo0_l0ofHFooooo`?o0?ooB_ooool2o`0003gooooo00?o0000ooooooooool0@?oo
ool002;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`17ooooo`?o0?mV5_ooool2
o`3ood[ooooo0ol000000ooooooo0000ooooo`0looooo`03o`000?oooooooooo043ooooo000Roooo
o`;o00004Oooool00ol0003oooooooooo`14ooooo`;o0?mV5_ooool3o`3oodWooooo0ol00005oooo
o`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0?oooool002;ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`10ooooo`?o0?mV5Oooool3o`3oodWooooo0ol00009ooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0?_ooool002;ooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0mooooo`;o0?mV5?ooool4o`3oodWooooo0ol0000=ooooo`03o`00
0?oooooooooo03[ooooo00?o0000ooooooooool0?_ooool002;ooooo0ol0000Cooooo`03o`000?oo
oooooooo03Wooooo0ol0ofHCooooo`?o0?oo5oooool2o`1Voc7ooooo0ol0000Aooooo`03o`000?oo
oooooooo03[ooooo00?o0000ooooooooool0?Oooool002;ooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`0gooooo`03o`3oI_oooooooooo01;ooooo0_l0oolGooooo`?o06Ko<Oooool2
o`0001Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0looooo`008Oooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo04Sooooo0ol0oolFooooo`?o06Ko<Oooool3o`00
01Oooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0kooooo`001oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Gooooo0_l0oolEooooo`Co06Ko<Oooool3
o`0001_ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0kooooo`001oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`12ooooo`;o0?oo5?ooool3o`1Voc;ooooo0ol0000O
ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0>_ooool000Go00000_ooool01Ol@
413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00_ooool2o`0001[ooooo00?o0000
ooooooooool0?_ooool3o`3ooaCooooo0_l0I_lbooooo`?o00008oooool00ol0003oooooooooo`0j
ooooo`03o`000?oooooooooo03Wooooo0007ooooo`05o`000?ooooooooooooooool000003oooool0
0omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0>Oooool4
o`3ooaCooooo0ol0I_lbooooo`;o00009_ooool00ol0003oooooooooo`0jooooo`;o0000>_ooool0
00Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?oo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo03Gooooo0ol0oolFooooo`;o06Ko<_oo
ool3o`0002Wooooo00?o0000ooooooooool0>Oooool2o`0003[ooooo0007ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool0<oooool00ol0ooooooooooooo`0Dooooo`?o06Ko5_ooool3oc<0oaSooooo0ol0
000]ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0=oooool000Oooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Kooooo0_l0000Nooooo`03o`000?oo
oooooooo04Kooooo0ol0I_lEooooo`Co<`3o6?ooool3o`00037ooooo00?o0000ooooooooool0>Ooo
ool00ol0003oooooooooo`0gooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0
0004ooooo`;o00008?ooool00ol0003oooooooooo`11ooooo`Co06Ko5Oooool3oc<0oaWooooo0ol0
000eooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0=_ooool0023ooooo00?o0000
ooooooooool08?ooool00ol0003oooooooooo`0mooooo`?o06Ko5oooool2oc<0oaWooooo0ol0000h
ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0=Oooool0023ooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`0jooooo`;o06Ko5oooool3oc<0oaWooooo0_l0000loooo
o`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0=?ooool0023ooooo0_l0000Sooooo`03
o`000?oooooooooo03Kooooo0ol0I_lGooooo`;o<`3o6Oooool3o`0003oooooo00?o0000oooooooo
ool0>Oooool00ol0003oooooooooo`0dooooo`008?ooool00ol0003oooooooooo`0Sooooo`03o`00
0?oooooooooo03?ooooo0_l0I_lGooooo`?o<`3o6?ooool3o`0004?ooooo00?o0000ooooooooool0
>Oooool00ol0003oooooooooo`0cooooo`008?ooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo033ooooo0_l0I_lFooooo`?o<`3o5?ooool2ol`0o`;ooooo0ol00017ooooo`03o`000?oo
oooooooo03Wooooo00?o0000ooooooooool0<_ooool0023ooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0^ooooo`03o`1Voooooooooooo01;ooooo1?lc0?lDooooo`?oc03o00Cooooo
o`000?l0003o0000B_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo03;ooooo000P
ooooo`03o`000?oooooooooo02Kooooo0_l00010ooooo`?o<`3o5_ooool2ol`0o`;ooooo0_l0001>
ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0<Oooool001oooooo0ol0000Yoooo
o`03o`000?oooooooooo03_ooooo0_lc0?lFooooo`?oc03o00Coooooo`000?l0003o0000DOooool0
0ol0003oooooooooo`0iooooo`03o`000?oooooooooo033ooooo000Oooooo`03o`000?oooooooooo
02[ooooo00?o0000ooooooooool0=oooool3oc<0oaKooooo0_o<0?l01?oooooo0000o`000?l0001E
ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0;oooool001oooooo00?o0000oooo
ooooool0:oooool00ol0003oooooooooo`0dooooo`;o<`3o5_ooool3ol`0o`?o0000F?ooool00ol0
003oooooooooo`0iooooo`03o`000?oooooooooo02oooooo000Oooooo`03o`000?oooooooooo02co
oooo00?o0000ooooooooool0<?ooool3oc<0oaGooooo0oo<0?l3o`0005cooooo00?o0000oooooooo
ool0>?ooool2o`00033ooooo000Oooooo`?o0000;Oooool00ol0003oooooooooo`0/ooooo`?o<`3o
5Oooool3ol`0o`?o0000H?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02gooooo
000Oooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0:?ooool3oc<0oaGooooo0oo<
0?l00ooooooo0000o`00000Cooooo`;oo`2ICoooool00ol0003oooooooooo`0hooooo`03o`000?oo
oooooooo02gooooo000Dooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003ooooooooo
o`0_ooooo`03o`000?oooooooooo03gooooo0_o<0?l01?oooooo0000o`000?l0000Booooo`?oo`2I
D_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02cooooo000Dooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo03Wooooo
0oo<0?l3o`0001;ooooo0ooo09UEooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0
:oooool001Cooooo00Go410@oooooooooooooooooa0@4005ooooo`;o0000<oooool00ol0003ooooo
ooooo`0eooooo`?oc03o0ol0000Aooooo`Coo`2IFOooool00ol0003oooooooooo`0iooooo`03o`00
0?oooooooooo02[ooooo000Dooooo`05o`000?ooooooooooooooool000001Oooool00ol0003ooooo
ooooo`0cooooo`03o`000?oooooooooo033ooooo1?o<0?l3o`00017ooooo0ooo09UNooooo`03o`00
0?oooooooooo03Sooooo00?o0000ooooooooool0:_ooool001Cooooo00Go0000oooooooooooooooo
o`000005ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0;?ooool3ol`0o`04oooo
ool0003o0000o`0001;ooooo0_oo09URooooo`03o`000?oooooooooo03Sooooo00?o0000oooooooo
ool0:Oooool001Cooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo03Go
oooo00?o0000ooooooooool0:Oooool2ol`0o`;ooooo0_l0000Booooo`?oo`2IIOooool00ol0003o
ooooooooo`0hooooo`03o`000?oooooooooo02Sooooo000Dooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo02Gooooo0oo<0?l01?oooooo
0000o`000?l0000Booooo`;oo`2IJ?ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo
02Sooooo000Dooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2o`0003Sooooo00?o0000oooo
ooooool08oooool00oo<0?ooooooo`000002o`0001;ooooo0ooo09TFooooo`?oo`00D_ooool00ol0
003oooooooooo`0hooooo`03o`000?oooooooooo02Oooooo000Nooooo`03o`000?oooooooooo03So
oooo00?o0000ooooooooool08Oooool3o`0001;ooooo0ooo09TEooooo`Coo`00E_ooool00ol0003o
ooooooooo`0hooooo`03o`000?oooooooooo02Kooooo000Mooooo`03o`000?oooooooooo03[ooooo
00?o0000ooooooooool07Oooool3o`00017ooooo1?oo09TEooooo`?oo`00Foooool00ol0003ooooo
ooooo`0hooooo`03o`000?oooooooooo02Gooooo000Mooooo`03o`000?oooooooooo03_ooooo00?o
0000ooooooooool06_ooool2o`0001;ooooo0_oo09TGooooo`;oo`00Goooool00ol0003ooooooooo
o`0gooooo`03o`000?oooooooooo02Gooooo000Mooooo`;o0000?Oooool00ol0003oooooooooo`0F
ooooo`?o00004_ooool2ool0VAKooooo0ooo001Qooooo`03o`000?oooooooooo03Oooooo0_l0000V
ooooo`007Oooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo01;ooooo0ol0000Boooo
o`?oo`2I5_ooool2ool006Gooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Soooo
o`007Oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00kooooo0ol0000Booooo`?o
o`2I5_ooool3ool006Sooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Sooooo`00
7Oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00[ooooo0ol0000Booooo`?oo`2I
5_ooool3ool006cooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Rooooo`007Ooo
ool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo00Kooooo0ol0000Zooooo`Coo`00L?oo
ool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo027ooooo000Looooo`?o0000@_ooool0
0ol0003oooooooooo`03ooooo`;o0000:_ooool3ool007Cooooo00?o0000ooooooooool0>?ooool0
0ol0003oooooooooo`0Pooooo`007?ooool00ol0003oooooooooo`13ooooo`03o`000?oooooo0000
00;o0000:_ooool2ool007Sooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Poooo
o`007?ooool00ol0003oooooooooo`12ooooo`?o0000:_ooool3ool007_ooooo00?o0000oooooooo
ool0=oooool00ol0003oooooooooo`09ooooo`;o000000?o410@ooooooooool04Oooool001cooooo
00?o0000ooooooooool0?oooool3o`0000?ooooo00?o0000ooooooooool09?ooool3ool007oooooo
00?o0000ooooooooool0=oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01;ooooo
000Looooo`?o0000??ooool3o`0000Oooooo00?o0000ooooooooool07oooool4ool008?ooooo00?o
0000ooooooooool0=_ooool00ol0003oooooooooo`06ooooo`Go00004oooool001cooooo00?o0000
ooooooooool0>Oooool3o`0000_ooooo00?o0000ooooooooool07?ooool2ool008Oooooo00?o0000
ooooooooool0=oooool00ol0003oooooooooo`05ooooo`04odA4A?oMgMgoooooo`0001Cooooo0000
1_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oM
gMd01Oooool00ol0003oooooooooo`0gooooo`;o00003oooool00ol0003oooooooooo`0Jooooo`03
ool00?oooooooooo08Sooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`04ooooo`04
omgMgOmEEEGoooooo`0001Cooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B48
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0=?ooool3o`0001;ooooo00?o0000
ooooooooool0YOooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Gooooo00?oMgMg
olc<c?l000005?ooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool03_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo037ooooo0ol0000Fooooo`03o`000?oooooooooo
0:Gooooo00?o0000ooooooooool0=_ooool2o`0000Gooooo00?ok^k^odA4A?l000005?ooool00003
ooooool0003ooooo00;ooooo00?o0000ooooooooool03Oooool00omgMgOo<S8booooo`03ooooo`;o
0000<?ooool3o`0001[ooooo00?o0000ooooooooool0YOooool00ol0003oooooooooo`0dooooo`03
o`000?oooooo000000Kooooo00?oMgMgo`000?ooool04oooool00003ooooool0003ooooo00;ooooo
00?o0000ooooooooool02_ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000oooooooo
ool0;?ooool3o`0001kooooo00?o0000ooooooooool0Y?ooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo01Wooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Zooooo`;o00008_ooool00ol0003ooooo
ooooo`2Tooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool06Oooool00006oooooomg
MgOoV9RHoooooonHV9SoMgMg3?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Oo
oooo0ol0000Uooooo`;o0000YOooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo01So
oooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPcooooo1?l00005ooooo`;o00009Oooool3o`00
02[ooooo00?o0000ooooooooool0Xoooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo
01Oooooo000Kooooo`03o`000?oooooooooo027ooooo0ol0000^ooooo`03o`000?oooooooooo0:?o
oooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Gooooo`006oooool00ol0003ooooo
ooooo`0Nooooo`?o0000<_ooool00ol0003oooooooooo`2Rooooo`03o`000?oooooooooo03Kooooo
00?o0000ooooooooool05_ooool001_ooooo00?o0000ooooooooool06oooool3o`0003Kooooo00?o
0000ooooooooool0X_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo01Gooooo000J
ooooo`03o`000?oooooooooo01[ooooo0_l0000jooooo`03o`000?oooooooooo0:;ooooo00?o0000
ooooooooool0=_ooool00ol0003oooooooooo`0Dooooo`006_ooool2o`0001Sooooo0ol0000moooo
o`03o`000?oooooooooo0:;ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Doooo
o`006_ooool00ol0003oooooooooo`0Dooooo`?o0000@Oooool00ol0003oooooooooo`2Qooooo`03
o`000?oooooooooo03Kooooo00?o0000ooooooooool04oooool001[ooooo00?o0000ooooooooool0
4Oooool3o`0004Gooooo00?o0000ooooooooool0XOooool00ol0003oooooooooo`0fooooo`03o`00
0?oooooooooo01;ooooo000Jooooo`03o`000?oooooooooo00kooooo0ol00019ooooo`03o`000?oo
oooooooo0:7ooooo00?o0000ooooooooool0=Oooool2o`0001?ooooo000Jooooo`03o`000?oooooo
oooo00cooooo0_l0001=ooooo`03o`000?oooooooooo0:7ooooo00?o0000ooooooooool0=?ooool2
o`0001?ooooo000Iooooo`?o00002_ooool3o`00053ooooo00?o0000ooooooooool0XOooool00ol0
003oooooooooo`0eooooo`03o`000?oooooooooo013ooooo000Jooooo`03o`000?oooooooooo00Ko
oooo0ol0001Dooooo`03o`000?oooooooooo0:3ooooo00?o0000ooooooooool0=_ooool00ol0003o
ooooooooo`0?ooooo`006Oooool00ol0003oooooooooo`04ooooo`?o0000F?ooool00ol0003ooooo
ooooo`2Pooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool03oooool001Wooooo00Co
0000oooooooooooooooo0ol0001Looooo`03o`000?oooooooooo0:3ooooo00?o0000ooooooooool0
=Oooool00ol0003oooooooooo`0>ooooo`006Oooool4o`00063ooooo00?o0000ooooooooool0X?oo
ool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00gooooo000Iooooo`;o0000Hoooool0
0ol0003oooooooooo`2Pooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool03Oooool0
00oooooo1?l000000ol@413oooooooooo`05ooooo`03o`000?oooooooooo067ooooo00?o0000oooo
ooooool0Woooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00cooooo000Aooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`2Oooooo`03
o`000?oooooooooo03Gooooo00?o0000ooooooooool02oooool0017ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo09oooooo00?o0000ooooooooool0
=Oooool00ol0003oooooooooo`0:ooooo`004Oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo067ooooo00?o0000ooooooooool0Woooool00ol0003oooooooooo`0dooooo`03o`000?oo
oooooooo00[ooooo000Aooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0HOooool0
0ol0003oooooooooo`2Oooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool02Oooool0
017ooooo00?o0000ooooooooool03?ooool2o`0006;ooooo00?o0000ooooooooool0W_ooool00ol0
003oooooooooo`0cooooo`?o00002_ooool0017ooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`1Pooooo`03o`000?oooooooooo09kooooo00?o0000ooooooooool0;oooool3o`0000;o
oooo00?o0000ooooooooool02?ooool000oooooo00?oEEEEofIVI_l000004Oooool00ol0003ooooo
ooooo`1Pooooo`03o`000?oooooooooo09kooooo00?o0000ooooooooool0:oooool3o`0000Gooooo
00?o0000ooooooooool02?ooool002Cooooo00?o0000ooooooooool0H?ooool00ol0003ooooooooo
o`2Nooooo`03o`000?oooooooooo02Kooooo1?l00008ooooo`03o`000?oooooooooo00Sooooo000U
ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`0R
ooooo`?o00003?ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`1Poooo
o`03o`000?oooooooooo09gooooo00?o0000ooooooooool07oooool3o`00013ooooo00?o0000oooo
ooooool01oooool002Oooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`2Mooooo`03
o`000?oooooooooo01[ooooo1?l0000Cooooo`03o`000?oooooooooo00Oooooo000Xooooo`;o0000
HOooool00ol0003oooooooooo`2Mooooo`03o`000?oooooooooo01Kooooo0ol0000Gooooo`03o`00
0?oooooooooo00Oooooo000Zooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool0WOoo
ool00ol0003oooooooooo`0Booooo`?o00006_ooool00ol0003oooooooooo`07ooooo`00:oooool0
0ol0003oooooooooo`1Oooooo`03o`000?oooooooooo09gooooo00?o0000ooooooooool03Oooool4
o`0001gooooo00?o0000ooooooooool01oooool002cooooo00?o0000ooooooooool0Goooool00ol0
003oooooooooo`2Looooo`03o`000?oooooooooo00[ooooo0ol0000Qooooo`03o`000?oooooooooo
00Oooooo000]ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool0W?ooool00ol0003o
ooooooooo`06ooooo`?o00009?ooool00ol0003oooooooooo`07ooooo`00;_ooool00ol0003ooooo
ooooo`1Oooooo`03o`000?oooooooooo09cooooo00Co0000oooooooooooooooo1?l0000Wooooo`03
o`000?oooooooooo00Oooooo000_ooooo`;o0000H?ooool00ol0003oooooooooo`2Looooo`?o0000
;?ooool00ol0003oooooooooo`06ooooo`00<Oooool00ol0003oooooooooo`1Nooooo`;o0000VOoo
ool3o`000003ooooool0003ooooo02cooooo00?o0000ooooooooool01_ooool003;ooooo00?o0000
ooooooooool0Goooool00ol0003oooooooooo`2Cooooo`?o00001?ooool00ol0003oooooooooo`0[
ooooo`03o`000?oooooooooo00Kooooo000cooooo`03o`000?oooooooooo05oooooo00?o0000oooo
ooooool0S_ooool4o`0000Sooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`06oooo
o`00=?ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo08[ooooo0ol0000=ooooo`03
o`000?oooooooooo02Wooooo00?o0000ooooooooool01_ooool003Gooooo00?o0000ooooooooool0
Goooool00ol0003oooooooooo`26ooooo`?o00004Oooool00ol0003oooooooooo`0Xooooo`03o`00
0?oooooooooo00Kooooo000fooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool0POoo
ool4o`0001Gooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`06ooooo`00=oooool2
o`00063ooooo00?o0000ooooooooool0OOooool3o`0001Wooooo00?o0000ooooooooool09oooool0
0ol0003oooooooooo`06ooooo`00>Oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo
07Wooooo0ol0000Mooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool01Oooool003[o
oooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`1dooooo`Co00008Oooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo00Gooooo000kooooo`03o`000?oooooooooo05kooooo
00?o0000ooooooooool0L?ooool3o`0002Kooooo00?o0000ooooooooool09Oooool00ol0003ooooo
ooooo`05ooooo`00??ooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo06cooooo0ol0
000Yooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool01Oooool003gooooo00?o0000
ooooooooool0G_ooool00ol0003oooooooooo`1Wooooo`Co0000;Oooool00ol0003oooooooooo`0T
ooooo`03o`000?oooooooooo00Gooooo000nooooo`;o0000Goooool00ol0003oooooooooo`1Soooo
o`?o0000<_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Gooooo0010ooooo`03
o`000?oooooooooo05gooooo00?o0000ooooooooool0Goooool3o`0003Kooooo00?o0000oooooooo
ool08_ooool00ol0003oooooooooo`05ooooo`00@Oooool00ol0003oooooooooo`1Mooooo`03o`00
0?oooooooooo05[ooooo1?l0000jooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
1Oooool004;ooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`1Fooooo`?o0000?_oo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Gooooo0013ooooo`03o`000?oooooo
oooo05gooooo00?o0000ooooooooool0D_ooool3o`0004;ooooo00?o0000ooooooooool08Oooool0
0ol0003oooooooooo`04ooooo`00A?ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo
04gooooo1?l00016ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01?ooool004Go
oooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`19ooooo`?o0000Boooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo00Cooooo0016ooooo`;o0000G_ooool00ol0003ooooo
ooooo`15ooooo`?o0000Coooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Cooooo
0018ooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool0@?ooool4o`0005;ooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`04ooooo`00BOooool00ol0003oooooooooo`1L
ooooo`03o`000?oooooooooo03cooooo0ol0001Gooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool01?ooool004[ooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`0hoooo
o`?o0000Foooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Cooooo001;ooooo`03
o`000?oooooooooo05cooooo00?o0000ooooooooool0<oooool4o`0005oooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`04ooooo`00C?ooool00ol0003oooooooooo`1Looooo`03o`00
0?oooooooooo02oooooo0ol0001Tooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
0oooool004gooooo0_l0001Mooooo`03o`000?oooooooooo02_ooooo0ol0001Wooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool00oooool004oooooo00?o0000ooooooooool0Foooool0
0ol0003oooooooooo`0Wooooo`?o0000Joooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo00?ooooo001@ooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool08_ooool4o`00
06oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`03ooooo`00DOooool00ol0003o
ooooooooo`1Kooooo`03o`000?oooooooooo01kooooo0ol0001dooooo`03o`000?oooooooooo01So
oooo00?o0000ooooooooool00oooool005;ooooo00?o0000ooooooooool0Foooool00ol0003ooooo
ooooo`0Jooooo`?o0000N?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00?ooooo
001Cooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool05Oooool4o`0007_ooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`03ooooo`00E?ooool2o`0005cooooo00?o0000
ooooooooool04Oooool3o`00083ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`03
ooooo`00E_ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00gooooo0ol00024oooo
o`03o`000?oooooooooo01Kooooo00?o0000ooooooooool00_ooool005Oooooo00?o0000oooooooo
ool0F_ooool00ol0003oooooooooo`08ooooo`Co0000R?ooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo00;ooooo001Hooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool0
1?ooool3o`0008gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`02ooooo`00FOoo
ool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00?o0000T?ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo00;ooooo001Jooooo`03o`000?oooooooooo05[ooooo0_l0002D
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00_ooool005_ooooo00?o0000oooo
ooooool0FOooool00ol0003oooooooooo`2Dooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool00_ooool005cooooo0_l0001Iooooo`03o`000?oooooooooo09Gooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`02ooooo`00G_ooool00ol0003oooooooooo`1Fooooo`03o`00
0?oooooooooo09Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`02ooooo`00Gooo
ool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo09Kooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`01ooooo`00H?ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooo
oooo09Oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`01ooooo`00HOooool00ol0
003oooooooooo`1Cooooo`03o`000?oooooooooo09Sooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`01ooooo`00H_ooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo09Wo
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`01ooooo`00Hoooool2o`0005;ooooo
00?o0000ooooooooool0V_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo007ooooo
001Uooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool0V_ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo007ooooo001Vooooo`03o`000?oooooooooo04kooooo00?o0000
ooooooooool0Voooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo007ooooo001Woooo
o`03o`000?oooooooooo04gooooo00?o0000ooooooooool0W?ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo007ooooo001Xooooo`03o`000?oooooooooo04cooooo00?o0000oooooooo
ool0WOooool00ol0003oooooooooo`0;ooooo`7o00000Oooool1ooooo`00JOooool00ol0003ooooo
ooooo`1;ooooo`03o`000?oooooooooo09gooooo00?o0000ooooooooool02oooool1o`00007ooooo
0Oooool006[ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`2Nooooo`03o`000?oo
oooooooo00[ooooo0Ol00001ooooo`7ooooo001[ooooo`;o0000B_ooool00ol0003oooooooooo`2O
ooooo`03o`000?oooooooooo00Wooooo0Ol00001ooooo`7ooooo001]ooooo`03o`000?oooooooooo
04Oooooo00?o0000ooooooooool0X?ooool00ol0003oooooooooo`08ooooo`7o00000Oooool1oooo
o`00K_ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo0:7ooooo00?o0000oooooooo
ool01oooool1o`00007ooooo0Oooool006oooooo00?o0000ooooooooool0AOooool00ol0003ooooo
ooooo`2Qooooo`03o`000?oooooooooo00Oooooo0Ol00001ooooo`7ooooo001`ooooo`03o`000?oo
oooooooo04Cooooo00?o0000ooooooooool0X_ooool00ol0003oooooooooo`06ooooo`7o00000Ooo
ool1ooooo`00LOooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo0:?ooooo00?o0000
ooooooooool01Oooool1o`00007ooooo0Oooool007;ooooo0_l00012ooooo`03o`000?oooooooooo
0:Gooooo00?o0000ooooooooool01Oooool1o`00007ooooo001dooooo`03o`000?oooooooooo03oo
oooo00?o0000ooooooooool0Y_ooool00ol0003oooooooooo`04ooooo`7o00000Oooool007Gooooo
00?o0000ooooooooool0?_ooool00ol0003oooooooooo`2Vooooo`03o`000?oooooooooo00Cooooo
0Ol00001ooooo`00M_ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo0:Oooooo00?o
0000ooooooooool00oooool1o`00007ooooo001gooooo`03o`000?oooooooooo03cooooo00?o0000
ooooooooool0Z?ooool00ol0003oooooooooo`02ooooo`7o00000Oooool007Sooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`2Yooooo`05o`000?ooooooooooooooool000000Oooool0
07Wooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`2Zooooo`04o`000?oooooooooo
o`00007ooooo001jooooo`;o0000>_ooool00ol0003oooooooooo`2Zooooo`04o`000?oooooooooo
o`00007ooooo001looooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0Zoooool00ol0
003oooooooooo`01o`000000OOooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo0:co
oooo0Ol00001ooooo`7o0000001nooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0
[Oooool2o`000000Ooooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo0:cooooo0ol0
0000083ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`2Xooooo`Co00000oooool0
087ooooo0_l0000cooooo`03o`000?oooooooooo0:Gooooo0ol00007ooooo`00Poooool00ol0003o
ooooooooo`0`ooooo`03o`000?oooooooooo0:7ooooo1?l0000:ooooo`00Q?ooool00ol0003ooooo
ooooo`0_ooooo`03o`000?oooooooooo09gooooo1?l0000>ooooo`00QOooool00ol0003ooooooooo
o`0^ooooo`03o`000?oooooooooo09Wooooo1?l0000Booooo`00Q_ooool00ol0003oooooooooo`0]
ooooo`03o`000?oooooooooo09Gooooo1?l0000Fooooo`00Qoooool00ol0003oooooooooo`0/oooo
o`03o`000?oooooooooo09;ooooo0ol0000Jooooo`00R?ooool2o`0002cooooo00?o0000oooooooo
ool0S_ooool4o`0001gooooo002:ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0
R_ooool4o`00027ooooo002;ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0Q_oo
ool4o`0002Gooooo002<ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0P_ooool4
o`0002Wooooo002=ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0Ooooool3o`00
02gooooo002>ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0Noooool4o`00033o
oooo002?ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0Moooool4o`0003Cooooo
002@ooooo`;o00009?ooool00ol0003oooooooooo`1cooooo`Co0000>?ooool009;ooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`1`ooooo`?o0000??ooool009?ooooo00?o0000oooo
ooooool08?ooool00ol0003oooooooooo`1/ooooo`Co0000?oooool009Cooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`1Xooooo`Co0000@oooool009Gooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`1Tooooo`Co0000Aoooool009Kooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`1Pooooo`Co0000Boooool009Oooooo0_l0000Mooooo`03o`000?oooooo
oooo05gooooo0ol0001?ooooo`00VOooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
05Wooooo1?l0001Booooo`00V_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo05Go
oooo1?l0001Fooooo`00Voooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo057ooooo
1?l0001Jooooo`00W?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04gooooo1?l0
001Nooooo`00WOooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04[ooooo0ol0001R
ooooo`00W_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04Kooooo1?l0001Uoooo
o`00Woooool2o`0001Cooooo00?o0000ooooooooool0@oooool4o`0006Wooooo002Qooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool0?oooool4o`0006gooooo002Rooooo`03o`000?oo
oooooooo013ooooo00?o0000ooooooooool0>oooool4o`00077ooooo002Sooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0>?ooool3o`0007Gooooo002Tooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool0=?ooool4o`0007Sooooo002Uooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool0<?ooool4o`0007cooooo002Vooooo`;o00003Oooool00ol0003ooooo
ooooo`0/ooooo`Co0000P?ooool00:Sooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0Yooooo`?o0000Q?ooool00:Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0U
ooooo`Co0000Qoooool00:[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Qoooo
o`Co0000Roooool00:_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Mooooo`Co
0000Soooool00:cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Iooooo`Co0000
Toooool00:gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Fooooo`?o0000Uooo
ool00:kooooo0_l00005ooooo`03o`000?oooooooooo01;ooooo1?l0002Jooooo`00/?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00kooooo1?l0002Nooooo`00/Oooool01Ol0003o
oooooooooooooooo000000cooooo1?l0002Rooooo`00/_ooool01?l0003oooooooooool00008oooo
o`Co0000Y_ooool00;?ooooo00?o0000ooooool000001Oooool3o`000:[ooooo002dooooo`;o0000
00?oooooo`000?l000000_l0002]ooooo`00]Oooool2o`000;7ooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {319.688, 0}} -> {-0.0710364, -0.0181728, \
0.0035149, 0.0035149}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .89104 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-16 1.0656 -0.0363427 1.0656 [
[.02544 .21571 -12 -8.9133 ]
[.02544 .21571 0 .0867 ]
[.16074 .16277 -11.6592 -9 ]
[.16074 .16277 .34081 0 ]
[.3021 .10747 -5.60025 -9 ]
[.3021 .10747 .39975 0 ]
[.44992 .04965 -5.37091 -9 ]
[.44992 .04965 .62909 0 ]
[.60467 -0.01084 -5.14157 -9 ]
[.60467 -0.01084 .85843 0 ]
[.66454 .05085 0 -6.20675 ]
[.66454 .05085 6 2.79325 ]
[.80797 .25198 0 -6.0417 ]
[.80797 .25198 6 2.9583 ]
[.93071 .4241 0 -5.90576 ]
[.93071 .4241 6 3.09424 ]
[.02254 .22988 -12 -2.74631 ]
[.02254 .22988 0 6.25369 ]
[.0142 .29178 -24 -2.78907 ]
[.0142 .29178 0 6.21093 ]
[.00558 .35578 -6 -2.83339 ]
[.00558 .35578 0 6.16661 ]
[-0.00334 .42198 -18 -2.87938 ]
[-0.00334 .42198 0 6.12062 ]
[-0.01257 .49051 -6 -2.92712 ]
[-0.01257 .49051 0 6.07288 ]
[ 0 0 0 0 ]
[ 1 .89104 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03495 .22504 m
.61241 0 L
s
.03495 .22504 m
.03971 .2297 L
s
[(-2)] .02544 .21571 1 .98073 Mshowa
.16988 .17246 m
.17445 .1773 L
s
[(-1)] .16074 .16277 .9432 1 Mshowa
.31082 .11753 m
.31518 .12256 L
s
[(0)] .3021 .10747 .86675 1 Mshowa
.45818 .0601 m
.46231 .06533 L
s
[(1)] .44992 .04965 .7903 1 Mshowa
.61241 0 m
.61628 .00542 L
s
[(2)] .60467 -0.01084 .71386 1 Mshowa
.125 Mabswid
.06148 .2147 m
.06431 .21752 L
s
.08823 .20428 m
.09104 .20712 L
s
.11521 .19376 m
.118 .19663 L
s
.14243 .18316 m
.14519 .18604 L
s
.19758 .16166 m
.20029 .16459 L
s
.22551 .15078 m
.22821 .15373 L
s
.2537 .13979 m
.25637 .14277 L
s
.28213 .12871 m
.28478 .13171 L
s
.33977 .10625 m
.34236 .10929 L
s
.36897 .09487 m
.37153 .09794 L
s
.39844 .08339 m
.40097 .08648 L
s
.42817 .0718 m
.43068 .07491 L
s
.48846 .0483 m
.49091 .05146 L
s
.51902 .03639 m
.52144 .03958 L
s
.54986 .02437 m
.55225 .02758 L
s
.58099 .01224 m
.58335 .01547 L
s
.25 Mabswid
.61241 0 m
.97291 .505 L
s
.65208 .05558 m
.64586 .05794 L
s
[(0)] .66454 .05085 -1 .37928 Mshowa
.79537 .2563 m
.78907 .25846 L
s
[(2)] .80797 .25198 -1 .3426 Mshowa
.91799 .42808 m
.91164 .43006 L
s
[(4)] .93071 .4241 -1 .31239 Mshowa
.125 Mabswid
.69012 .10886 m
.68637 .11025 L
s
.72662 .16 m
.72286 .16135 L
s
.76168 .2091 m
.75791 .21042 L
s
.82778 .3017 m
.82399 .30297 L
s
.85897 .3454 m
.85518 .34664 L
s
.88903 .3875 m
.88522 .38871 L
s
.94594 .46722 m
.94211 .46839 L
s
.25 Mabswid
.03495 .22504 m
0 .48612 L
s
.03495 .22504 m
.04116 .22262 L
s
[(-1)] .02254 .22988 1 -0.38971 Mshowa
.02665 .28704 m
.03288 .28468 L
s
[(-0.5)] .0142 .29178 1 -0.38021 Mshowa
.01807 .35115 m
.02431 .34884 L
s
[(0)] .00558 .35578 1 -0.37036 Mshowa
.00919 .41747 m
.01546 .41521 L
s
[(0.5)] -0.00334 .42198 1 -0.36014 Mshowa
0 .48612 m
.00629 .48392 L
s
[(1)] -0.01257 .49051 1 -0.34953 Mshowa
.125 Mabswid
.03331 .23728 m
.03704 .23583 L
s
.03166 .2496 m
.03539 .24816 L
s
.03 .262 m
.03373 .26056 L
s
.02833 .27448 m
.03207 .27305 L
s
.02496 .29969 m
.0287 .29828 L
s
.02325 .31243 m
.02699 .31102 L
s
.02154 .32525 m
.02528 .32385 L
s
.01981 .33816 m
.02355 .33676 L
s
.01632 .36423 m
.02007 .36285 L
s
.01455 .37741 m
.01831 .37603 L
s
.01278 .39067 m
.01653 .3893 L
s
.01099 .40402 m
.01475 .40266 L
s
.00738 .43101 m
.01114 .42966 L
s
.00555 .44464 m
.00932 .4433 L
s
.00371 .45837 m
.00748 .45704 L
s
.00186 .4722 m
.00563 .47087 L
s
.25 Mabswid
.03495 .22504 m
0 .48612 L
s
0 .48612 m
.46953 .89104 L
s
.46953 .89104 m
.47294 .65459 L
s
.47294 .65459 m
.03495 .22504 L
s
.61241 0 m
.97291 .505 L
s
.97291 .505 m
1 .75117 L
s
1 .75117 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.03495 .22504 m
0 .48612 L
s
0 .48612 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.61241 0 m
.03495 .22504 L
s
.47294 .65459 m
.97291 .505 L
s
.97291 .505 m
1 .75117 L
s
1 .75117 m
.46953 .89104 L
s
.46953 .89104 m
.47294 .65459 L
s
0 0 m
1 0 L
1 .89104 L
0 .89104 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.33807 .43896 m
.35246 .43408 L
s
1 0 .6 r
.32992 .41659 m
.34431 .41167 L
s
.8 0 1 r
.32176 .3942 m
.33614 .38922 L
s
.2 0 1 r
.31359 .37178 m
.32796 .36674 L
s
1 0 0 r
.35246 .43408 m
.36692 .42919 L
s
0 .4 1 r
.30541 .34932 m
.31977 .34424 L
s
1 0 .6 r
.34431 .41167 m
.35875 .40672 L
s
0 1 1 r
.29722 .32684 m
.31157 .3217 L
s
.8 0 1 r
.33614 .38922 m
.35058 .38422 L
s
0 1 .4 r
.28901 .30432 m
.30335 .29913 L
s
.2 0 1 r
.32796 .36674 m
.34239 .36169 L
s
1 0 0 r
.36692 .42919 m
.38144 .42427 L
s
.2 1 0 r
.2808 .28177 m
.29513 .27653 L
s
0 .4 1 r
.31977 .34424 m
.33419 .33913 L
s
1 0 .6 r
.35875 .40672 m
.37326 .40175 L
s
.8 1 0 r
.27257 .2592 m
.28689 .2539 L
s
0 1 1 r
.31157 .3217 m
.32598 .31654 L
s
.8 0 1 r
.35058 .38422 m
.36508 .3792 L
s
1 .6 0 r
.26433 .23659 m
.27865 .23123 L
s
0 1 .4 r
.30335 .29913 m
.31776 .29391 L
s
.2 0 1 r
.34239 .36169 m
.35688 .35661 L
s
1 0 0 r
.38144 .42427 m
.39602 .41934 L
s
.2 1 0 r
.29513 .27653 m
.30953 .27126 L
s
0 .4 1 r
.33419 .33913 m
.34868 .334 L
s
1 0 .6 r
.37326 .40175 m
.38784 .39676 L
s
.8 1 0 r
.28689 .2539 m
.30128 .24857 L
s
0 1 1 r
.32598 .31654 m
.34046 .31135 L
s
.8 0 1 r
.36508 .3792 m
.37965 .37415 L
s
1 .6 0 r
.27865 .23123 m
.29303 .22586 L
s
0 1 .4 r
.31776 .29391 m
.33223 .28867 L
s
.2 0 1 r
.35688 .35661 m
.37144 .35151 L
s
1 0 0 r
.39602 .41934 m
.41067 .41438 L
s
.2 1 0 r
.30953 .27126 m
.32399 .26597 L
s
0 .4 1 r
.34868 .334 m
.36323 .32884 L
s
1 0 .6 r
.38784 .39676 m
.40248 .39174 L
s
.8 1 0 r
.30128 .24857 m
.31573 .24323 L
s
0 1 1 r
.34046 .31135 m
.355 .30614 L
s
.8 0 1 r
.37965 .37415 m
.39428 .36908 L
s
1 .6 0 r
.29303 .22586 m
.30747 .22045 L
s
0 1 .4 r
.33223 .28867 m
.34676 .28341 L
s
.2 0 1 r
.37144 .35151 m
.38607 .34639 L
s
1 0 0 r
.41067 .41438 m
.42539 .40939 L
s
.2 1 0 r
.32399 .26597 m
.33851 .26065 L
s
0 .4 1 r
.36323 .32884 m
.37784 .32367 L
s
1 0 .6 r
.40248 .39174 m
.41719 .38671 L
s
.8 1 0 r
.31573 .24323 m
.33025 .23785 L
s
0 1 1 r
.355 .30614 m
.36961 .30091 L
s
.8 0 1 r
.39428 .36908 m
.40898 .36399 L
s
1 .6 0 r
.30747 .22045 m
.32198 .21503 L
s
0 1 .4 r
.34676 .28341 m
.36136 .27813 L
s
.2 0 1 r
.38607 .34639 m
.40076 .34125 L
s
1 0 0 r
.42539 .40939 m
.44017 .40439 L
s
.2 1 0 r
.33851 .26065 m
.3531 .25531 L
s
0 .4 1 r
.37784 .32367 m
.39252 .31847 L
s
1 0 .6 r
.41719 .38671 m
.43196 .38165 L
s
.8 1 0 r
.33025 .23785 m
.34483 .23246 L
s
0 1 1 r
.36961 .30091 m
.38428 .29566 L
s
.8 0 1 r
.40898 .36399 m
.42374 .35888 L
s
1 .6 0 r
.32198 .21503 m
.33655 .20958 L
s
0 1 .4 r
.36136 .27813 m
.37603 .27282 L
s
.2 0 1 r
.40076 .34125 m
.41551 .33608 L
s
1 0 0 r
.44017 .40439 m
.45501 .39936 L
s
.2 1 0 r
.3531 .25531 m
.36776 .24994 L
s
0 .4 1 r
.39252 .31847 m
.40727 .31324 L
s
1 0 .6 r
.43196 .38165 m
.4468 .37657 L
s
.8 1 0 r
.34483 .23246 m
.35948 .22704 L
s
0 1 1 r
.38428 .29566 m
.39902 .29038 L
s
.8 0 1 r
.42374 .35888 m
.43857 .35374 L
s
1 .6 0 r
.33655 .20958 m
.35119 .2041 L
s
0 1 .4 r
.37603 .27282 m
.39076 .26748 L
s
.2 0 1 r
.41551 .33608 m
.43034 .33089 L
s
1 0 0 r
.45501 .39936 m
.46993 .39431 L
s
.2 1 0 r
.36776 .24994 m
.38248 .24456 L
s
0 .4 1 r
.40727 .31324 m
.42209 .308 L
s
1 0 .6 r
.4468 .37657 m
.4617 .37146 L
s
.8 1 0 r
.35948 .22704 m
.3742 .2216 L
s
0 1 1 r
.39902 .29038 m
.41383 .28508 L
s
.8 0 1 r
.43857 .35374 m
.45347 .34858 L
s
1 .6 0 r
.35119 .2041 m
.3659 .1986 L
s
0 1 .4 r
.39076 .26748 m
.40555 .26213 L
s
.2 0 1 r
.43034 .33089 m
.44522 .32567 L
s
.2 1 0 r
.38248 .24456 m
.39727 .23914 L
s
0 .4 1 r
.42209 .308 m
.43697 .30273 L
s
.8 1 0 r
.3742 .2216 m
.38898 .21613 L
s
0 1 1 r
.41383 .28508 m
.4287 .27975 L
s
1 .6 0 r
.3659 .1986 m
.38067 .19308 L
s
0 1 .4 r
.40555 .26213 m
.42042 .25674 L
s
.2 1 0 r
.39727 .23914 m
.41213 .2337 L
s
.8 1 0 r
.38898 .21613 m
.40382 .21063 L
s
1 .6 0 r
.38067 .19308 m
.39551 .18753 L
s
0 g
.25 Mabswid
.61241 0 m
.97291 .505 L
s
.97291 .505 m
1 .75117 L
s
1 .75117 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.03495 .22504 m
0 .48612 L
s
0 .48612 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.61241 0 m
.03495 .22504 L
s
.03495 .22504 m
.61241 0 L
s
.03495 .22504 m
.03971 .2297 L
s
[(-2)] .02544 .21571 1 .98073 Mshowa
.16988 .17246 m
.17445 .1773 L
s
[(-1)] .16074 .16277 .9432 1 Mshowa
.31082 .11753 m
.31518 .12256 L
s
[(0)] .3021 .10747 .86675 1 Mshowa
.45818 .0601 m
.46231 .06533 L
s
[(1)] .44992 .04965 .7903 1 Mshowa
.61241 0 m
.61628 .00542 L
s
[(2)] .60467 -0.01084 .71386 1 Mshowa
.125 Mabswid
.06148 .2147 m
.06431 .21752 L
s
.08823 .20428 m
.09104 .20712 L
s
.11521 .19376 m
.118 .19663 L
s
.14243 .18316 m
.14519 .18604 L
s
.19758 .16166 m
.20029 .16459 L
s
.22551 .15078 m
.22821 .15373 L
s
.2537 .13979 m
.25637 .14277 L
s
.28213 .12871 m
.28478 .13171 L
s
.33977 .10625 m
.34236 .10929 L
s
.36897 .09487 m
.37153 .09794 L
s
.39844 .08339 m
.40097 .08648 L
s
.42817 .0718 m
.43068 .07491 L
s
.48846 .0483 m
.49091 .05146 L
s
.51902 .03639 m
.52144 .03958 L
s
.54986 .02437 m
.55225 .02758 L
s
.58099 .01224 m
.58335 .01547 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 256.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001@2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00gOooool5o`0008Kooooo003Mooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0Q_ooool00=ko
oooo00?oV9RHob4Q8Oo^k^h0Qoooool00=oooooo00?oV9RHob4Q8Oo^k^h0Q_ooool00>3ooooo00?o
MgMgofIVI_ooool0QOooool00>7ooooo00?o0000ooooooooool0Q?ooool00=gooooo00Go0000okZj
^_ooooooV9RHoa0@4026ooooo`00gOooool01OnHV9So410@o`000?lQ8B7oc<c<08Kooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003Tooooo`;o0000P_ooool0
0>7ooooo0ol000000ooooooo0000ooooo`21ooooo`00goooool2o`0000Cooooo0_l00021ooooo`00
g?ooool3o`0000Kooooo00?o0000ooooool00000P?ooool00=[ooooo0_l00009ooooo`03o`000?oo
oooo0000083ooooo003Gooooo`?o000000?oooooo`000?ooool02?ooool01?l0003oooooooooool0
001oooooo`00e?ooool3o`0000Cooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooo
oooo000007kooooo003Booooo`;o00004Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo07_ooooo002Zooooo`Co000000?o410@ooooooooool07_ooool3o`0001?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1kooooo`00[?ooool00ol0003oooooooooo`0Nooooo`;o
000000?oooooo`000?ooool04oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07[o
oooo002/ooooo`03o`000?oooooooooo01_ooooo0ol00004ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`1iooooo`00[?ooool00ol0003ooooooooo
o`0Iooooo`;o00006oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo07Wooooo002/
ooooo`03o`000?oooooooooo01Kooooo0ol0000Mooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool02?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^06_ooooo002/ooooo`03o`000?oooooo
oooo01Cooooo0_l000000ooooooo0000ooooo`0Mooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01oooool01OmgMgOoV9RHoooooonHV9SoMgMg06_ooooo002/ooooo`03o`000?oooooo
oooo017ooooo0ol00004ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`06ooooo`05oa0@4?ooooooooooooooool@4100Joooool00:[ooooo00?oEEEE
ofIVI_l000004Oooool2o`0002Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06
ooooo`05o`000?ooooooooooooooool00000Joooool00;_ooooo0ol0000Wooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000006_ooooo002i
ooooo`;o000000?oooooo`000?ooool09oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Cooooo00Go410@oooooooooooooooooa0@401[ooooo`00]_ooool3o`0000Cooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`1[ooooo`00/oooool3o`0002oooooo00?o0000ooooooooool02Oooool2
o`0000Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1[ooooo`00/Oooool2o`0003;ooooo00?o0000
ooooooooool02?ooool01?l0003oooooooooool0001dooooo`00[_ooool3o`000003ooooool0003o
oooo037ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1aooooo`00[?ooool2o`00
00Gooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
077ooooo002Yooooo`?o0000>_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo073o
oooo002Wooooo`;o0000?Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo06oooooo
002Tooooo`?o000000?oooooo`000?ooool0??ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo06oooooo002Rooooo`;o0000@_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo06kooooo001gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08oooool3o`0004Cooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1]ooooo`00Moooool01OmgMgOoV9RHoooooonHV9So
MgMg027ooooo0_l00017ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0K?ooool0
07Oooooo00Go410@oooooooooooooooooa0@400Nooooo`?o00000_ooool00ol0003oooooooooo`14
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0K?ooool007Oooooo00Go0000oooo
ooooooooooooo`00000Looooo`;o0000C?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo06_ooooo001gooooo`05o`000?ooooooooooooooool000006Oooool3o`0004kooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`1Zooooo`00Moooool01Ol@413ooooooooooooooooo
410@01Kooooo0ol0001Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0J_ooool0
07Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Dooooo`;o00000oooool00ol0003oooooooooo`1>
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0JOooool007Oooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Aooooo`?o0000E_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo06Sooooo002;ooooo`;o0000FOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
06Sooooo0028ooooo`?o0000Foooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo06Oo
oooo0026ooooo`;o00000oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo01Gooooo
0_l0001Xooooo`00Poooool3o`00063ooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`1Uooooo`00POooool2o`0006?ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1U
ooooo`00O_ooool4o`0006Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`1Toooo
o`00O?ooool2o`0000Cooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo06?ooooo001iooooo`?o0000J_ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo06?ooooo001gooooo`;o0000KOooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo06;ooooo001dooooo`?o000000?oooooo`000?ooool0K?ooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo067ooooo001aooooo`?o0000L_ooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo063ooooo0019ooooo`Co000000?o410@ooooooooool07oooool2o`0007Go
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1Pooooo`00Boooool00ol0003ooooo
ooooo`0Nooooo`?o0000Moooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo05oooooo
0010ooooo`Ko00001Oooool00ol0003oooooooooo`0Looooo`;o00000_ooool00ol0003ooooooooo
o`1eooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0G_ooool004_ooooo00?o0000
ooooooooool06Oooool3o`0007cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1N
ooooo`00Boooool00ol0003oooooooooo`0Gooooo`;o0000Ooooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo05gooooo001;ooooo`03o`000?oooooooooo01Cooooo0ol00021ooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0G?ooool004_ooooo00?o0000ooooooooool0
4_ooool2o`0000?ooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo05_ooooo0019ooooo`03oeEEEOmVIVKo0000017ooooo0ol00026ooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool0Foooool005_ooooo0_l00029ooooo`03o`000?oooooo
oooo027ooooo0_l0001Looooo`00F?ooool3o`000003ooooool0003ooooo08Sooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`1Iooooo`00E_ooool2o`0008kooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`1Iooooo`00Doooool3o`00093ooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`1Hooooo`00D?ooool3o`0009?ooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1Gooooo`00C_ooool2o`0000;ooooo00?o0000ooooooooool0TOooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo05Kooooo001;ooooo`?o00001Oooool00ol0
003oooooooooo`2@ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0E_ooool004Wo
oooo0_l0002Kooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0EOooool004Kooooo
1?l0002Looooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0E?ooool004Cooooo0_l0
001Fooooo`;ooiT0B?ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo05Cooooo000J
ooooo`Go00008_ooool3o`0005Gooooo0oooV@1:ooooo`03o`000?oooooooooo02Wooooo00?o0000
ooooooooool0Doooool001[ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00Pooooo`;o0000E_ooool2
oonI04gooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`1Booooo`004_ooool6o`00
00?ooooo00?oV9RHob4Q8Oo^k^h07_ooool3o`000003ooooool0003ooooo05;ooooo0oooV@1?oooo
o`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0DOooool001cooooo00?oV9RHob4Q8Oo^
k^h06oooool2o`0005Kooooo0_ooV@1Booooo`03o`000?oooooooooo02_ooooo00?o0000oooooooo
ool0DOooool001gooooo00?oMgMgofIVI_ooool05oooool3o`0005Gooooo0oooV@1Eooooo`03o`00
0?oooooooooo02_ooooo00?o0000ooooooooool0D?ooool001kooooo00?o0000ooooooooool05?oo
ool2o`0005Gooooo0oooV@1Hooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0Cooo
ool001[ooooo00Go0000okZj^_ooooooV9RHoa0@400Cooooo`?o00000_ooool00ol0003ooooooooo
o`1>ooooo`CooiT0Foooool00ol0003oooooooooo`0/ooooo`;o0000D?ooool001[ooooo00GoV9RH
oa0@4?l0003o8B4Qolc<c00@ooooo`?o0000Doooool3oonI01Oooooo0_o<o`16ooooo`03o`000?oo
oooooooo02cooooo0_l0001@ooooo`00;Oooool2o`0005Cooooo0_ooV@0Gooooo`?oc?l0B?ooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo04gooooo000Zooooo`?o000000?oooooo`00
0?ooool0D?ooool3oonI01Kooooo0oo<o`1;ooooo`03o`000?oooooooooo02kooooo00?o0000oooo
ooooool0COooool002Sooooo0_l0001Dooooo`;ooiT05Oooool4olco04kooooo00?o0000oooooooo
ool0;oooool00ol0003oooooooooo`1<ooooo`009Oooool3o`0005Cooooo0_ooV@0Dooooo`?oc?l0
D_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo04_ooooo000Tooooo`;o0000E?oo
ool2oonI01Cooooo0_o<o`1Eooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0B_oo
ool001[ooooo1?l000000ol@413oooooooooo`03ooooo`03o`000?oooooo0000053ooooo0oooV@0C
ooooo`?oc?l0Eoooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo04[ooooo000Loooo
o`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo0000C?ooool3oonI01Cooooo0_o<o`0D
ooooo`;o<ol0A?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo04Wooooo000Aoooo
o`Ko00001Oooool00ol0003oooooooooo`05ooooo`;o00000_ooool00ol0003oooooooooo`16oooo
o`?ooiT05?ooool3olco01?ooooo0olco`16ooooo`03o`000?oooooooooo03?ooooo00?o0000oooo
ooooool0B?ooool001cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo05[ooooo0_o<o`0Dooooo`;o<ol0BOooool00ol0003oooooooooo`0cooooo`03
o`000?oooooooooo00Oooooo1Ol0000looooo`007?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0E_ooool3olco01?ooooo0olco`1;ooooo`03o`00
0?oooooooooo03Cooooo00?o0000ooooooooool01_ooool01OnHV9So8B4Qonk^k_ooooooA4A403co
oooo000Looooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`1Booooo`?oc?l05?ooool2oc?o04kooooo00?o0000ooooooooool0=Oooool00ol0003ooooo
ooooo`06ooooo`03oiRHV?lQ8B7ok^k^03gooooo000Looooo`03o`000?oooooooooo00Cooooo0ol0
0006ooooo`03o`000?oooooooooo04gooooo1?o<o`0Dooooo`?o<ol0D?ooool00ol0003ooooooooo
o`0fooooo`03o`000?oooooooooo00Kooooo00?oV9RHob4Q8Oo^k^h0??ooool001[ooooo00?oEEEE
ofIVI_l000001_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo04[ooooo0_o<o`0F
ooooo`;o<ol0Doooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Oooooo00?oMgMg
ofIVI_ooool0>oooool002?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`17oooo
o`;oc?l05_ooool2oc?o05Gooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo03[ooooo000Sooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool0@oooool3olco01Gooooo0olco`0Dooooo`;o0?mV@Oooool00ol0003oooooooooo`0gooooo`;o
00001?ooool01Ol0003o^[ZjoooooonHV9So410@03cooooo000Sooooo`;o00002oooool00ol0003o
ooooooooo`11ooooo`03olco0?oooooooooo01;ooooo1?lco`0Dooooo`?o0?mV@oooool00ol0003o
ooooooooo`0fooooo`03o`000?oooooo000000Cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00loooo
o`008oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05;ooooo0olco`0Fooooo`;o
0?mVA_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo04;ooooo000Rooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool0Coooool2oc?o01Kooooo0ol0ofI8ooooo`03o`00
0?oooooooooo03[ooooo00?o0000ooooooooool0@Oooool002;ooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`1;ooooo`?o<ol05Oooool3o`3oIT[ooooo0_l0000mooooo`03o`000?oo
oooooooo043ooooo000Rooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0B?ooool2
oc?o01Cooooo1?l0ofI:ooooo`?o000000?oooooo`000?ooool0??ooool00ol0003oooooooooo`10
ooooo`008_ooool2o`00017ooooo00?o0000ooooooooool0A?ooool3oc?o01?ooooo0ol0ofI;oooo
o`?o00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo03oooooo000Rooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool0@?ooool3oc?o01Cooooo0_l0ofI;ooooo`?o
00002Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo03kooooo000Rooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool0??ooool3oc?o01Cooooo0ol0ofHGooooo`;o0?oo
<Oooool3o`0000gooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0nooooo`008_oo
ool3o`0001?ooooo00?o0000ooooooooool0D?ooool2o`3oIQOooooo0ol0ool`ooooo`?o00004Ooo
ool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03gooooo000Rooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool0COooool2o`3oIQKooooo0ol0oolaooooo`;o00005?ooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo03cooooo000Qooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool0BOooool3o`3oIQCooooo1?l0oolaooooo`?o00005oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo03_ooooo0007ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool0A?ooool4o`3oIQCooooo0ol0oolbooooo`?o00006oooool0
0ol0003oooooooooo`0jooooo`03o`000?oooooooooo03_ooooo0007ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo043ooooo0ol0ofHFooooo`;o0?oo<_ooool3o`0001oooooo00?o0000
ooooooooool0>_ooool00ol0003oooooooooo`0jooooo`001Ol00002ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`02ooooo`;o00006_ooool00ol0003oooooooooo`0m
ooooo`;o0?mV5_ooool3o`3ooc7ooooo0ol0000Sooooo`03o`000?oooooooooo03[ooooo00?o0000
ooooooooool0>Oooool000Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;o
oooo00?ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0iooooo`?o0?mV5_ooool2
o`3ooaGooooo0_l0I_lKooooo`;o00009_ooool00ol0003oooooooooo`0jooooo`;o0000>_ooool0
00Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?oo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo03Oooooo00?o0?mVooooooooool05?oo
ool3o`3ooaCooooo0ol0I_lJooooo`?o0000:Oooool00ol0003oooooooooo`0iooooo`;o0000>_oo
ool000Oooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool07?ooool00ol0003oooooooooo`1:ooooo`?o0?oo5Oooool2o`1Voa[ooooo0ol0
000]ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0=oooool000Oooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Kooooo0_l0000Nooooo`03o`000?oo
oooooooo04Gooooo1?l0oolEooooo`?o06Ko6Oooool3o`00037ooooo00?o0000ooooooooool0>Ooo
ool00ol0003oooooooooo`0gooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0
0004ooooo`;o00008?ooool00ol0003oooooooooo`12ooooo`;o0?oo5oooool2o`1VoaWooooo0ol0
000eooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0=_ooool0023ooooo00?o0000
ooooooooool08?ooool00ol0003oooooooooo`0oooooo`;o0?oo5_ooool3o`1VoaSooooo0ol0000h
ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0=Oooool0023ooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`0kooooo`?o0?oo5Oooool3o`1VoaWooooo0_l0000loooo
o`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0=?ooool0023ooooo0_l0000Sooooo`03
o`000?oooooooooo03Oooooo0ol0oolDooooo`Co06Ko6Oooool3o`0003oooooo00?o0000oooooooo
ool0>Oooool00ol0003oooooooooo`0dooooo`008?ooool00ol0003oooooooooo`0Sooooo`03o`00
0?oooooooooo03?ooooo0ol0oolDooooo`?o06Ko5_ooool2oc<0o`;ooooo0ol00013ooooo`03o`00
0?oooooooooo03Wooooo00?o0000ooooooooool0<oooool0023ooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`17ooooo`;o06Ko5_ooool3oc<0o`04ooooool0003o0000o`0004Oooooo
00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0booooo`008?ooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo04?ooooo0ol0I_lFooooo`;o<`3o00Coooooo`000?l0003o0000
B_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo03;ooooo000Pooooo`03o`000?oo
oooooooo02Kooooo0_l00011ooooo`;o06Ko5_ooool3oc<0o`03ooooool0003o000004kooooo00?o
0000ooooooooool0>Oooool00ol0003oooooooooo`0aooooo`007oooool3o`0002Wooooo00?o0000
ooooooooool0>oooool3o`1VoaGooooo0olc0?l01?oooooo0000o`000?l0001Aooooo`03o`000?oo
oooooooo03Wooooo00?o0000ooooooooool0<?ooool001oooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`0gooooo`?o06Ko5Oooool3oc<0o`04ooooool0003o0000o`0005Gooooo00?o
0000ooooooooool0>Oooool00ol0003oooooooooo`0_ooooo`007oooool00ol0003oooooooooo`0[
ooooo`03o`000?oooooooooo03;ooooo1?l0I_lEooooo`?o<`3o00Coooooo`000?l0003o0000F?oo
ool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02oooooo000Oooooo`03o`000?oooooo
oooo02cooooo00?o0000ooooooooool0;oooool2o`1VoaOooooo0_lc0?l01?oooooo0000o`000?l0
001Looooo`03o`000?oooooooooo03Sooooo0_l0000`ooooo`007oooool3o`0002gooooo00?o0000
ooooooooool0;Oooool00ol0I_ooooooooooo`0Dooooo`?o<`3o0ol0000Booooo`?oc03oBoooool0
0ol0003oooooooooo`0iooooo`03o`000?oooooooooo02gooooo000Oooooo`03o`000?oooooooooo
02kooooo00?o0000ooooooooool0@?ooool3oc<0o`03ooooool0003o0000017ooooo1?o<0?m?oooo
o`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0;Oooool001Cooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP06ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0>oooool4oc<0
o`04ooooool0003o0000o`00013ooooo0oo<0?mDooooo`03o`000?oooooooooo03Sooooo00?o0000
ooooooooool0;?ooool001Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooo
oooo037ooooo00?o0000ooooooooool0=oooool3oc<0o`;ooooo0ol0000Aooooo`;oc03oEoooool0
0ol0003oooooooooo`0iooooo`03o`000?oooooooooo02_ooooo000Dooooo`05oa0@4?oooooooooo
ooooool@41001Oooool2o`0003?ooooo00?o0000ooooooooool0=?ooool2oc<0o`;ooooo0ol0000A
ooooo`?oc03oF_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02[ooooo000Doooo
o`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooo
oooo033ooooo0olc0?l01?oooooo0000o`000?l0000Booooo`;oc03oG_ooool00ol0003ooooooooo
o`0hooooo`03o`000?oooooooooo02[ooooo000Dooooo`05o`000?ooooooooooooooool000001Ooo
ool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02cooooo0olc0?l01?oooooo0000o`00
0?l0000Booooo`?oc03oHOooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02Wooooo
000Dooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003oooooooooo`0eooooo`03o`00
0?oooooooooo02Sooooo0olc0?l2ooooo`;o00004_ooool3ol`0oaGooooo0_oo09U>ooooo`03o`00
0?oooooooooo03Sooooo00?o0000ooooooooool0:?ooool001Cooooo00GoMgMgoiRHV?ooooooV9RH
ogMgM`05ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0:Oooool3o`00013ooooo
1?o<0?lEooooo`?oo`2ID?ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02Sooooo
000Dooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2o`0003Sooooo00?o0000ooooooooool0
9Oooool3o`00017ooooo0_o<0?lGooooo`;oo`2IE?ooool00ol0003oooooooooo`0hooooo`03o`00
0?oooooooooo02Oooooo000Nooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool08Ooo
ool3o`0001;ooooo0_o<0?lFooooo`?oo`2IEoooool00ol0003oooooooooo`0hooooo`03o`000?oo
oooooooo02Kooooo000Mooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool07Oooool3
o`0001;ooooo0oo<0?lEooooo`?oo`2IFoooool00ol0003oooooooooo`0hooooo`03o`000?oooooo
oooo02Gooooo000Mooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool06_ooool2o`00
01;ooooo0oo<0?lDooooo`Coo`2IGoooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo
02Gooooo000Mooooo`;o0000?Oooool00ol0003oooooooooo`0Fooooo`?o00004?ooool4ol`0oaCo
oooo0ooo09USooooo`03o`000?oooooooooo03Oooooo0_l0000Vooooo`007Oooool00ol0003ooooo
ooooo`0mooooo`03o`000?oooooooooo01;ooooo0ol0000@ooooo`?oc03o5_ooool2ool0VFOooooo
00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Sooooo`007Oooool00ol0003ooooooooo
o`0nooooo`03o`000?oooooooooo00kooooo0ol0000Booooo`03ol`0oooooooooooo01Cooooo0ooo
09TGooooo`;oo`00DOooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02?ooooo000M
ooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool02_ooool3o`0002Wooooo0ooo09TG
ooooo`?oo`00E?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02;ooooo000Moooo
o`03o`000?oooooooooo043ooooo00?o0000ooooooooool01_ooool3o`0002Sooooo1?oo09TGoooo
o`?oo`00F?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo027ooooo000Looooo`?o
0000@_ooool00ol0003oooooooooo`03ooooo`;o0000:?ooool3ool0VAOooooo1?oo001Kooooo`03
o`000?oooooooooo03Sooooo00?o0000ooooooooool08?ooool001cooooo00?o0000ooooooooool0
@oooool00ol0003oooooo`000002o`0002Sooooo0_oo09TGooooo`?oo`00H?ooool00ol0003ooooo
ooooo`0gooooo`03o`000?oooooooooo023ooooo000Looooo`03o`000?oooooooooo04;ooooo0ol0
000Yooooo`;oo`2I5oooool2ool006Cooooo00?o0000ooooooooool0=oooool00ol0003ooooooooo
o`09ooooo`;o000000?o410@ooooooooool04Oooool001cooooo00?o0000ooooooooool0?oooool3
o`0000?ooooo00?o0000ooooooooool08oooool3ool0VAKooooo0ooo001Wooooo`03o`000?oooooo
oooo03Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Booooo`007?ooool3o`00
03cooooo0ol00007ooooo`03o`000?oooooooooo01oooooo0ooo09TFooooo`?oo`00Joooool00ol0
003oooooooooo`0fooooo`03o`000?oooooooooo00Kooooo1Ol0000Cooooo`007?ooool00ol0003o
ooooooooo`0iooooo`?o00002oooool00ol0003oooooooooo`0cooooo`Coo`00K_ooool00ol0003o
ooooooooo`0gooooo`03o`000?oooooooooo00Gooooo00CoA4A4omgMgOoooooo00005?ooool00006
ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgM
g@05ooooo`03o`000?oooooooooo03Oooooo0_l0000?ooooo`03o`000?oooooooooo02oooooo0ooo
001cooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool01?ooool01?oMgMgoEEEEoooo
ool0000Dooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q2?ooool00omgMgOo
<S8booooo`04ooooo`03o`000?oooooooooo03Cooooo0ol0000Booooo`03o`000?oooooooooo02co
oooo0_oo001gooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool01Oooool00omgMgOo
c<c<o`00000Dooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0>ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0<Oooool3o`0001Kooooo00?o0000ooooooooool0
:?ooool3ool007[ooooo00?o0000ooooooooool0=_ooool2o`0000Gooooo00?ok^k^odA4A?l00000
5?ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool03Oooool00omgMgOo<S8boooo
o`03ooooo`;o0000<?ooool3o`0001[ooooo00?o0000ooooooooool09?ooool3ool007kooooo00?o
0000ooooooooool0=?ooool00ol0003oooooo`000006ooooo`03ogMgMol0003ooooo01?ooooo0000
0ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00[ooooo00Go0000ob4Q8Ol0003o<S8bolc<
c004ooooo`03o`000?oooooooooo02cooooo0ol0000Nooooo`03o`000?oooooooooo01oooooo1?oo
0021ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool06Oooool00003ooooool@413o
oooo00;ooooo00?o410@ooooooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo02[ooooo0_l0000Rooooo`03o`000?oooooooooo01cooooo0_oo0026ooooo`03o`000?oooooo
oooo03Kooooo00?o0000ooooooooool06Oooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg3?oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Oooooo0ol0000Uooooo`;o00006ooo
ool00ooo003oooooooooo`27ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool06?oo
ool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3?ooool4o`0000Gooooo0_l0000Uooooo`?o0000
:_ooool00ol0003oooooooooo`2Sooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0
5oooool001_ooooo00?o0000ooooooooool08Oooool3o`0002kooooo00?o0000ooooooooool0Xooo
ool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo01Oooooo000Kooooo`03o`000?oooooo
oooo01kooooo0ol0000booooo`03o`000?oooooooooo0:;ooooo00?o0000ooooooooool0=_ooool0
0ol0003oooooooooo`0Fooooo`006oooool00ol0003oooooooooo`0Kooooo`?o0000=_ooool00ol0
003oooooooooo`2Rooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool05Oooool001[o
oooo00?o0000ooooooooool06_ooool2o`0003[ooooo00?o0000ooooooooool0X_ooool00ol0003o
ooooooooo`0fooooo`03o`000?oooooooooo01Cooooo000Jooooo`;o00006?ooool3o`0003gooooo
00?o0000ooooooooool0X_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo01Cooooo
000Jooooo`03o`000?oooooooooo01Cooooo0ol00011ooooo`03o`000?oooooooooo0:7ooooo00?o
0000ooooooooool0=_ooool00ol0003oooooooooo`0Cooooo`006_ooool00ol0003oooooooooo`0A
ooooo`?o0000AOooool00ol0003oooooooooo`2Qooooo`03o`000?oooooooooo03Kooooo00?o0000
ooooooooool04_ooool001[ooooo00?o0000ooooooooool03_ooool3o`0004Wooooo00?o0000oooo
ooooool0XOooool00ol0003oooooooooo`0eooooo`;o00004oooool001[ooooo00?o0000oooooooo
ool03?ooool2o`0004gooooo00?o0000ooooooooool0XOooool00ol0003oooooooooo`0dooooo`;o
00004oooool001Wooooo0ol0000:ooooo`?o0000D?ooool00ol0003oooooooooo`2Qooooo`03o`00
0?oooooooooo03Gooooo00?o0000ooooooooool04?ooool001[ooooo00?o0000ooooooooool01_oo
ool3o`0005Cooooo00?o0000ooooooooool0X?ooool00ol0003oooooooooo`0fooooo`03o`000?oo
oooooooo00oooooo000Iooooo`03o`000?oooooooooo00Cooooo0ol0001Hooooo`03o`000?oooooo
oooo0:3ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0?ooooo`006Oooool01?l0
003oooooooooooooool3o`0005cooooo00?o0000ooooooooool0X?ooool00ol0003oooooooooo`0e
ooooo`03o`000?oooooooooo00kooooo000Iooooo`Co0000H?ooool00ol0003oooooooooo`2Poooo
o`03o`000?oooooooooo03Gooooo00?o0000ooooooooool03Oooool001Wooooo0_l0001Sooooo`03
o`000?oooooooooo0:3ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0=ooooo`00
3oooool4o`000003oa0@4?oooooooooo00Gooooo00?o0000ooooooooool0HOooool00ol0003ooooo
ooooo`2Oooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool03?ooool0017ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo09oooooo00?o
0000ooooooooool0=Oooool00ol0003oooooooooo`0;ooooo`004Oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0Woooool00ol0003oooooooooo`0e
ooooo`03o`000?oooooooooo00[ooooo000Aooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool0HOooool00ol0003oooooooooo`2Oooooo`03o`000?oooooooooo03Cooooo00?o0000oooo
ooooool02_ooool0017ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Qooooo`03
o`000?oooooooooo09oooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`09ooooo`00
4Oooool00ol0003oooooooooo`0<ooooo`;o0000H_ooool00ol0003oooooooooo`2Nooooo`03o`00
0?oooooooooo03?ooooo0ol0000:ooooo`004Oooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo063ooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`0_ooooo`?o00000_oo
ool00ol0003oooooooooo`08ooooo`003oooool00omEEEGoIVIVo`00000Aooooo`03o`000?oooooo
oooo063ooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`0[ooooo`?o00001Oooool0
0ol0003oooooooooo`08ooooo`009?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo
09kooooo00?o0000ooooooooool09_ooool4o`0000Sooooo00?o0000ooooooooool02?ooool002Go
oooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`2Nooooo`03o`000?oooooooooo02;o
oooo0ol0000<ooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo063ooooo
00?o0000ooooooooool0WOooool00ol0003oooooooooo`0Oooooo`?o00004?ooool00ol0003ooooo
ooooo`07ooooo`009oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo09gooooo00?o
0000ooooooooool06_ooool4o`0001?ooooo00?o0000ooooooooool01oooool002Sooooo0_l0001Q
ooooo`03o`000?oooooooooo09gooooo00?o0000ooooooooool05_ooool3o`0001Oooooo00?o0000
ooooooooool01oooool002[ooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`2Moooo
o`03o`000?oooooooooo01;ooooo0ol0000Jooooo`03o`000?oooooooooo00Oooooo000[ooooo`03
o`000?oooooooooo05oooooo00?o0000ooooooooool0WOooool00ol0003oooooooooo`0=ooooo`Co
00007Oooool00ol0003oooooooooo`07ooooo`00;?ooool00ol0003oooooooooo`1Oooooo`03o`00
0?oooooooooo09cooooo00?o0000ooooooooool02_ooool3o`00027ooooo00?o0000ooooooooool0
1oooool002gooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`2Looooo`03o`000?oo
oooooooo00Kooooo0ol0000Tooooo`03o`000?oooooooooo00Oooooo000^ooooo`03o`000?oooooo
oooo05oooooo00?o0000ooooooooool0W?ooool01?l0003oooooooooooooool4o`0002Oooooo00?o
0000ooooooooool01oooool002oooooo0_l0001Pooooo`03o`000?oooooooooo09cooooo0ol0000/
ooooo`03o`000?oooooooooo00Kooooo000aooooo`03o`000?oooooooooo05kooooo0_l0002Ioooo
o`?o000000?oooooo`000?ooool0;?ooool00ol0003oooooooooo`06ooooo`00<_ooool00ol0003o
ooooooooo`1Oooooo`03o`000?oooooooooo09?ooooo0ol00004ooooo`03o`000?oooooooooo02_o
oooo00?o0000ooooooooool01_ooool003?ooooo00?o0000ooooooooool0Goooool00ol0003ooooo
ooooo`2>ooooo`Co00002?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00Kooooo
000dooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool0R_ooool3o`0000gooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`06ooooo`00=Oooool00ol0003oooooooooo`1O
ooooo`03o`000?oooooooooo08Kooooo0ol0000Aooooo`03o`000?oooooooooo02Sooooo00?o0000
ooooooooool01_ooool003Kooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`21oooo
o`Co00005Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Kooooo000gooooo`;o
0000H?ooool00ol0003oooooooooo`1mooooo`?o00006Oooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo00Kooooo000iooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0
NOooool3o`0001gooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`05ooooo`00>_oo
ool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo07Cooooo1?l0000Qooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool01Oooool003_ooooo00?o0000ooooooooool0G_ooool0
0ol0003oooooooooo`1`ooooo`?o00009_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo00Gooooo000looooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0K?ooool3o`00
02Wooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`05ooooo`00?Oooool00ol0003o
ooooooooo`1Nooooo`03o`000?oooooooooo06Oooooo1?l0000]ooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool01Oooool003kooooo0_l0001Oooooo`03o`000?oooooooooo06?ooooo
0ol0000booooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool01Oooool0043ooooo00?o
0000ooooooooool0GOooool00ol0003oooooooooo`1Oooooo`?o0000=_ooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo00Gooooo0011ooooo`03o`000?oooooooooo05gooooo00?o0000
ooooooooool0F_ooool4o`0003[ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`05
ooooo`00@_ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo05Kooooo0ol0000noooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool01Oooool004?ooooo00?o0000oooooooo
ool0GOooool00ol0003oooooooooo`1Booooo`?o0000@_ooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo00Cooooo0014ooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool0
COooool4o`0004Kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`04ooooo`00AOoo
ool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo04Wooooo0ol0001;ooooo`03o`000?oo
oooooooo01oooooo00?o0000ooooooooool01?ooool004Kooooo0_l0001Nooooo`03o`000?oooooo
oooo04Gooooo0ol0001?ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool01?ooool0
04Sooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`10ooooo`Co0000D_ooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo00Cooooo0019ooooo`03o`000?oooooooooo05co
oooo00?o0000ooooooooool0??ooool3o`0005Oooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`04ooooo`00B_ooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo03Sooooo
0ol0001Kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool01?ooool004_ooooo00?o
0000ooooooooool0G?ooool00ol0003oooooooooo`0cooooo`Co0000Goooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00Cooooo001<ooooo`03o`000?oooooooooo05cooooo00?o0000
ooooooooool0;oooool3o`0006Cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`03
ooooo`00COooool2o`0005gooooo00?o0000ooooooooool0:oooool3o`0006Oooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`03ooooo`00Coooool00ol0003oooooooooo`1Kooooo`03
o`000?oooooooooo02Oooooo0ol0001[ooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool00oooool0053ooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`0Rooooo`Co0000
Koooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00?ooooo001Aooooo`03o`000?oo
oooooooo05_ooooo00?o0000ooooooooool07_ooool3o`0007Cooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`03ooooo`00D_ooool00ol0003oooooooooo`1Kooooo`03o`000?oooooo
oooo01[ooooo0ol0001hooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool00oooool0
05?ooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`0Eooooo`Co0000Noooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo00?ooooo001Dooooo`;o0000G?ooool00ol0003o
ooooooooo`0Aooooo`?o0000P?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00?o
oooo001Fooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool03Oooool3o`0008Cooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`02ooooo`00Eoooool00ol0003ooooooooo
o`1Jooooo`03o`000?oooooooooo00Sooooo1?l00028ooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool00_ooool005Sooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`04
ooooo`?o0000SOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00;ooooo001Ioooo
o`03o`000?oooooooooo05[ooooo00?o0000ooooooooool00ol0002@ooooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool00_ooool005[ooooo00?o0000ooooooooool0F_ooool2o`0009Co
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`02ooooo`00Foooool00ol0003ooooo
ooooo`1Iooooo`03o`000?oooooooooo09Cooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`02ooooo`00G?ooool2o`0005Wooooo00?o0000ooooooooool0UOooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo00;ooooo001Nooooo`03o`000?oooooooooo05Kooooo00?o0000
ooooooooool0U_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo001Ooooo
o`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0U_ooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo007ooooo001Pooooo`03o`000?oooooooooo05Cooooo00?o0000oooooooo
ool0Uoooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo007ooooo001Qooooo`03o`00
0?oooooooooo05?ooooo00?o0000ooooooooool0V?ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo007ooooo001Rooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0VOoo
ool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo007ooooo001Sooooo`;o0000D_ooool0
0ol0003oooooooooo`2Jooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00Oooool0
06Gooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`2Jooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool00Oooool006Kooooo00?o0000ooooooooool0C_ooool00ol0003o
ooooooooo`2Kooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00Oooool006Oooooo
00?o0000ooooooooool0COooool00ol0003oooooooooo`2Looooo`03o`000?oooooooooo00_ooooo
00?o0000ooooooooool00Oooool006Sooooo00?o0000ooooooooool0C?ooool00ol0003ooooooooo
o`2Mooooo`03o`000?oooooooooo00_ooooo0Ol00001ooooo`7ooooo001Yooooo`03o`000?oooooo
oooo04_ooooo00?o0000ooooooooool0WOooool00ol0003oooooooooo`0;ooooo`7o00000Oooool1
ooooo`00J_ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo09kooooo00?o0000oooo
ooooool02_ooool1o`00007ooooo0Oooool006_ooooo0_l0001:ooooo`03o`000?oooooooooo09oo
oooo00?o0000ooooooooool02Oooool1o`00007ooooo0Oooool006gooooo00?o0000ooooooooool0
Aoooool00ol0003oooooooooo`2Pooooo`03o`000?oooooooooo00Sooooo0Ol00001ooooo`7ooooo
001^ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0XOooool00ol0003ooooooooo
o`07ooooo`7o00000Oooool1ooooo`00Koooool00ol0003oooooooooo`15ooooo`03o`000?oooooo
oooo0:7ooooo00?o0000ooooooooool01oooool1o`00007ooooo0Oooool0073ooooo00?o0000oooo
ooooool0A?ooool00ol0003oooooooooo`2Rooooo`03o`000?oooooooooo00Kooooo0Ol00001oooo
o`7ooooo001aooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0Xoooool00ol0003o
ooooooooo`05ooooo`7o00000Oooool1ooooo`00L_ooool2o`0004;ooooo00?o0000ooooooooool0
YOooool00ol0003oooooooooo`05ooooo`7o00000Oooool007Cooooo00?o0000ooooooooool0?ooo
ool00ol0003oooooooooo`2Vooooo`03o`000?oooooooooo00Cooooo0Ol00001ooooo`00MOooool0
0ol0003oooooooooo`0nooooo`03o`000?oooooooooo0:Kooooo00?o0000ooooooooool01?ooool1
o`00007ooooo001fooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0Yoooool00ol0
003oooooooooo`03ooooo`7o00000Oooool007Oooooo00?o0000ooooooooool0??ooool00ol0003o
ooooooooo`2Xooooo`03o`000?oooooooooo00;ooooo0Ol00001ooooo`00N?ooool00ol0003ooooo
ooooo`0kooooo`03o`000?oooooooooo0:Wooooo00Go0000ooooooooooooooooo`000001ooooo`00
NOooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo0:[ooooo00Co0000oooooooooooo
00000Oooool007[ooooo0_l0000jooooo`03o`000?oooooooooo0:[ooooo00Co0000oooooooooooo
00000Oooool007cooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`2[ooooo`03o`00
0?oooooooooo007o0000001mooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0[?oo
ool1o`00007ooooo0Ol0000007kooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`2]
ooooo`;o0000001oooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0[?ooool3o`00
0000P?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo0:Sooooo1?l00003ooooo`00
POooool2o`0003?ooooo00?o0000ooooooooool0YOooool3o`0000Oooooo0023ooooo`03o`000?oo
oooooooo033ooooo00?o0000ooooooooool0XOooool4o`0000[ooooo0024ooooo`03o`000?oooooo
oooo02oooooo00?o0000ooooooooool0WOooool4o`0000kooooo0025ooooo`03o`000?oooooooooo
02kooooo00?o0000ooooooooool0VOooool4o`0001;ooooo0026ooooo`03o`000?oooooooooo02go
oooo00?o0000ooooooooool0UOooool4o`0001Kooooo0027ooooo`03o`000?oooooooooo02cooooo
00?o0000ooooooooool0T_ooool3o`0001[ooooo0028ooooo`;o0000;?ooool00ol0003ooooooooo
o`2>ooooo`Co00007Oooool008[ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`2:
ooooo`Co00008Oooool008_ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`26oooo
o`Co00009Oooool008cooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`22ooooo`Co
0000:Oooool008gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1oooooo`?o0000
;Oooool008kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1kooooo`Co0000<?oo
ool008oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1gooooo`Co0000=?ooool0
093ooooo0_l0000Tooooo`03o`000?oooooooooo07?ooooo1?l0000hooooo`00T_ooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo073ooooo0ol0000looooo`00Toooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo06cooooo1?l0000oooooo`00U?ooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo06Sooooo1?l00013ooooo`00UOooool00ol0003oooooooooo`0N
ooooo`03o`000?oooooooooo06Cooooo1?l00017ooooo`00U_ooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo063ooooo1?l0001;ooooo`00Uoooool2o`0001gooooo00?o0000oooooooo
ool0GOooool3o`0004oooooo002Iooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
FOooool4o`0005;ooooo002Jooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0EOoo
ool4o`0005Kooooo002Kooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0DOooool4
o`0005[ooooo002Looooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0COooool4o`00
05kooooo002Mooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0B_ooool3o`0006;o
oooo002Nooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0A_ooool4o`0006Gooooo
002Oooooo`;o00005?ooool00ol0003oooooooooo`13ooooo`Co0000JOooool00:7ooooo00?o0000
ooooooooool04Oooool00ol0003oooooooooo`0oooooo`Co0000KOooool00:;ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`0kooooo`Co0000LOooool00:?ooooo00?o0000oooooooo
ool03oooool00ol0003oooooooooo`0hooooo`?o0000MOooool00:Cooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0dooooo`Co0000N?ooool00:Gooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`0`ooooo`Co0000O?ooool00:Kooooo0_l0000=ooooo`03o`000?oooooo
oooo02cooooo1?l00020ooooo`00Z?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
02Wooooo0ol00024ooooo`00ZOooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02Go
oooo1?l00027ooooo`00Z_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo027ooooo
1?l0002;ooooo`00Zoooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01gooooo1?l0
002?ooooo`00[?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Wooooo1?l0002C
ooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Kooooo0ol0002Goooo
o`00[_ooool2o`0000Gooooo00?o0000ooooooooool04_ooool4o`0009[ooooo002`ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool03_ooool4o`0009kooooo002aooooo`05o`000?oo
ooooooooooooool000003?ooool4o`000:;ooooo002booooo`04o`000?ooooooooooo`0000Sooooo
1?l0002Vooooo`00/oooool00ol0003oooooo`000005ooooo`?o0000Z_ooool00;Cooooo0_l00000
0ooooooo0000o`000002o`000:gooooo002eooooo`;o0000/Oooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {319.688, 0}} -> {-0.0710364, -0.0181728, \
0.0035149, 0.0035149}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .89104 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-16 1.0656 -0.0363427 1.0656 [
[.02544 .21571 -12 -8.9133 ]
[.02544 .21571 0 .0867 ]
[.16074 .16277 -11.6592 -9 ]
[.16074 .16277 .34081 0 ]
[.3021 .10747 -5.60025 -9 ]
[.3021 .10747 .39975 0 ]
[.44992 .04965 -5.37091 -9 ]
[.44992 .04965 .62909 0 ]
[.60467 -0.01084 -5.14157 -9 ]
[.60467 -0.01084 .85843 0 ]
[.66454 .05085 0 -6.20675 ]
[.66454 .05085 6 2.79325 ]
[.80797 .25198 0 -6.0417 ]
[.80797 .25198 6 2.9583 ]
[.93071 .4241 0 -5.90576 ]
[.93071 .4241 6 3.09424 ]
[.02254 .22988 -12 -2.74631 ]
[.02254 .22988 0 6.25369 ]
[.0142 .29178 -24 -2.78907 ]
[.0142 .29178 0 6.21093 ]
[.00558 .35578 -6 -2.83339 ]
[.00558 .35578 0 6.16661 ]
[-0.00334 .42198 -18 -2.87938 ]
[-0.00334 .42198 0 6.12062 ]
[-0.01257 .49051 -6 -2.92712 ]
[-0.01257 .49051 0 6.07288 ]
[ 0 0 0 0 ]
[ 1 .89104 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03495 .22504 m
.61241 0 L
s
.03495 .22504 m
.03971 .2297 L
s
[(-2)] .02544 .21571 1 .98073 Mshowa
.16988 .17246 m
.17445 .1773 L
s
[(-1)] .16074 .16277 .9432 1 Mshowa
.31082 .11753 m
.31518 .12256 L
s
[(0)] .3021 .10747 .86675 1 Mshowa
.45818 .0601 m
.46231 .06533 L
s
[(1)] .44992 .04965 .7903 1 Mshowa
.61241 0 m
.61628 .00542 L
s
[(2)] .60467 -0.01084 .71386 1 Mshowa
.125 Mabswid
.06148 .2147 m
.06431 .21752 L
s
.08823 .20428 m
.09104 .20712 L
s
.11521 .19376 m
.118 .19663 L
s
.14243 .18316 m
.14519 .18604 L
s
.19758 .16166 m
.20029 .16459 L
s
.22551 .15078 m
.22821 .15373 L
s
.2537 .13979 m
.25637 .14277 L
s
.28213 .12871 m
.28478 .13171 L
s
.33977 .10625 m
.34236 .10929 L
s
.36897 .09487 m
.37153 .09794 L
s
.39844 .08339 m
.40097 .08648 L
s
.42817 .0718 m
.43068 .07491 L
s
.48846 .0483 m
.49091 .05146 L
s
.51902 .03639 m
.52144 .03958 L
s
.54986 .02437 m
.55225 .02758 L
s
.58099 .01224 m
.58335 .01547 L
s
.25 Mabswid
.61241 0 m
.97291 .505 L
s
.65208 .05558 m
.64586 .05794 L
s
[(0)] .66454 .05085 -1 .37928 Mshowa
.79537 .2563 m
.78907 .25846 L
s
[(2)] .80797 .25198 -1 .3426 Mshowa
.91799 .42808 m
.91164 .43006 L
s
[(4)] .93071 .4241 -1 .31239 Mshowa
.125 Mabswid
.69012 .10886 m
.68637 .11025 L
s
.72662 .16 m
.72286 .16135 L
s
.76168 .2091 m
.75791 .21042 L
s
.82778 .3017 m
.82399 .30297 L
s
.85897 .3454 m
.85518 .34664 L
s
.88903 .3875 m
.88522 .38871 L
s
.94594 .46722 m
.94211 .46839 L
s
.25 Mabswid
.03495 .22504 m
0 .48612 L
s
.03495 .22504 m
.04116 .22262 L
s
[(-1)] .02254 .22988 1 -0.38971 Mshowa
.02665 .28704 m
.03288 .28468 L
s
[(-0.5)] .0142 .29178 1 -0.38021 Mshowa
.01807 .35115 m
.02431 .34884 L
s
[(0)] .00558 .35578 1 -0.37036 Mshowa
.00919 .41747 m
.01546 .41521 L
s
[(0.5)] -0.00334 .42198 1 -0.36014 Mshowa
0 .48612 m
.00629 .48392 L
s
[(1)] -0.01257 .49051 1 -0.34953 Mshowa
.125 Mabswid
.03331 .23728 m
.03704 .23583 L
s
.03166 .2496 m
.03539 .24816 L
s
.03 .262 m
.03373 .26056 L
s
.02833 .27448 m
.03207 .27305 L
s
.02496 .29969 m
.0287 .29828 L
s
.02325 .31243 m
.02699 .31102 L
s
.02154 .32525 m
.02528 .32385 L
s
.01981 .33816 m
.02355 .33676 L
s
.01632 .36423 m
.02007 .36285 L
s
.01455 .37741 m
.01831 .37603 L
s
.01278 .39067 m
.01653 .3893 L
s
.01099 .40402 m
.01475 .40266 L
s
.00738 .43101 m
.01114 .42966 L
s
.00555 .44464 m
.00932 .4433 L
s
.00371 .45837 m
.00748 .45704 L
s
.00186 .4722 m
.00563 .47087 L
s
.25 Mabswid
.03495 .22504 m
0 .48612 L
s
0 .48612 m
.46953 .89104 L
s
.46953 .89104 m
.47294 .65459 L
s
.47294 .65459 m
.03495 .22504 L
s
.61241 0 m
.97291 .505 L
s
.97291 .505 m
1 .75117 L
s
1 .75117 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.03495 .22504 m
0 .48612 L
s
0 .48612 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.61241 0 m
.03495 .22504 L
s
.47294 .65459 m
.97291 .505 L
s
.97291 .505 m
1 .75117 L
s
1 .75117 m
.46953 .89104 L
s
.46953 .89104 m
.47294 .65459 L
s
0 0 m
1 0 L
1 .89104 L
0 .89104 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.35555 .45677 m
.36986 .45198 L
s
1 0 .6 r
.34747 .43459 m
.36178 .42975 L
s
.8 0 1 r
.33939 .41239 m
.35369 .4075 L
s
.2 0 1 r
.3313 .39016 m
.34558 .38521 L
s
1 0 0 r
.36986 .45198 m
.38424 .44716 L
s
0 .4 1 r
.32319 .3679 m
.33747 .3629 L
s
1 0 .6 r
.36178 .42975 m
.37614 .42488 L
s
0 1 1 r
.31508 .34561 m
.32935 .34056 L
s
.8 0 1 r
.35369 .4075 m
.36804 .40258 L
s
0 1 .4 r
.30695 .32329 m
.32121 .31819 L
s
.2 0 1 r
.34558 .38521 m
.35994 .38024 L
s
1 0 0 r
.38424 .44716 m
.39868 .44233 L
s
.2 1 0 r
.29881 .30094 m
.31307 .29578 L
s
0 .4 1 r
.33747 .3629 m
.35181 .35788 L
s
1 0 .6 r
.37614 .42488 m
.39058 .41999 L
s
.8 1 0 r
.29067 .27856 m
.30491 .27335 L
s
0 1 1 r
.32935 .34056 m
.34368 .33548 L
s
.8 0 1 r
.36804 .40258 m
.38247 .39763 L
s
1 .6 0 r
.28251 .25615 m
.29675 .25088 L
s
0 1 .4 r
.32121 .31819 m
.33554 .31306 L
s
.2 0 1 r
.35994 .38024 m
.37435 .37525 L
s
1 0 0 r
.39868 .44233 m
.41318 .43747 L
s
.2 1 0 r
.31307 .29578 m
.32739 .2906 L
s
0 .4 1 r
.35181 .35788 m
.36622 .35283 L
s
1 0 .6 r
.39058 .41999 m
.40507 .41508 L
s
.8 1 0 r
.30491 .27335 m
.31922 .26811 L
s
0 1 1 r
.34368 .33548 m
.35808 .33038 L
s
.8 0 1 r
.38247 .39763 m
.39695 .39267 L
s
1 .6 0 r
.29675 .25088 m
.31105 .24559 L
s
0 1 .4 r
.33554 .31306 m
.34993 .3079 L
s
.2 0 1 r
.37435 .37525 m
.38883 .37023 L
s
1 0 0 r
.41318 .43747 m
.42775 .43259 L
s
.2 1 0 r
.32739 .2906 m
.34177 .28539 L
s
0 .4 1 r
.36622 .35283 m
.38069 .34776 L
s
1 0 .6 r
.40507 .41508 m
.41963 .41015 L
s
.8 1 0 r
.31922 .26811 m
.3336 .26285 L
s
0 1 1 r
.35808 .33038 m
.37254 .32526 L
s
.8 0 1 r
.39695 .39267 m
.41151 .38769 L
s
1 .6 0 r
.31105 .24559 m
.32541 .24028 L
s
0 1 .4 r
.34993 .3079 m
.36439 .30273 L
s
.2 0 1 r
.38883 .37023 m
.40337 .36519 L
s
1 0 0 r
.42775 .43259 m
.44238 .42769 L
s
.2 1 0 r
.34177 .28539 m
.35622 .28016 L
s
0 .4 1 r
.38069 .34776 m
.39523 .34267 L
s
1 0 .6 r
.41963 .41015 m
.43425 .4052 L
s
.8 1 0 r
.3336 .26285 m
.34803 .25757 L
s
0 1 1 r
.37254 .32526 m
.38707 .32011 L
s
.8 0 1 r
.41151 .38769 m
.42612 .38268 L
s
1 .6 0 r
.32541 .24028 m
.33984 .23494 L
s
0 1 .4 r
.36439 .30273 m
.3789 .29753 L
s
.2 0 1 r
.40337 .36519 m
.41798 .36013 L
s
1 0 0 r
.44238 .42769 m
.45708 .42276 L
s
.2 1 0 r
.35622 .28016 m
.37073 .27491 L
s
0 .4 1 r
.39523 .34267 m
.40983 .33755 L
s
1 0 .6 r
.43425 .4052 m
.44894 .40022 L
s
.8 1 0 r
.34803 .25757 m
.36254 .25226 L
s
0 1 1 r
.38707 .32011 m
.40166 .31494 L
s
.8 0 1 r
.42612 .38268 m
.4408 .37765 L
s
1 .6 0 r
.33984 .23494 m
.35434 .22958 L
s
0 1 .4 r
.3789 .29753 m
.39349 .2923 L
s
.2 0 1 r
.41798 .36013 m
.43265 .35505 L
s
1 0 0 r
.45708 .42276 m
.47184 .41782 L
s
.2 1 0 r
.37073 .27491 m
.3853 .26963 L
s
0 .4 1 r
.40983 .33755 m
.42449 .33241 L
s
1 0 .6 r
.44894 .40022 m
.4637 .39522 L
s
.8 1 0 r
.36254 .25226 m
.3771 .24693 L
s
0 1 1 r
.40166 .31494 m
.41632 .30975 L
s
.8 0 1 r
.4408 .37765 m
.45555 .3726 L
s
1 .6 0 r
.35434 .22958 m
.36889 .2242 L
s
0 1 .4 r
.39349 .2923 m
.40814 .28706 L
s
.2 0 1 r
.43265 .35505 m
.44739 .34994 L
s
1 0 0 r
.47184 .41782 m
.48667 .41285 L
s
.2 1 0 r
.3853 .26963 m
.39994 .26433 L
s
0 .4 1 r
.42449 .33241 m
.43922 .32725 L
s
1 0 .6 r
.4637 .39522 m
.47852 .3902 L
s
.8 1 0 r
.3771 .24693 m
.39173 .24158 L
s
0 1 1 r
.41632 .30975 m
.43104 .30454 L
s
.8 0 1 r
.45555 .3726 m
.47036 .36752 L
s
1 .6 0 r
.36889 .2242 m
.38352 .21879 L
s
0 1 .4 r
.40814 .28706 m
.42285 .28179 L
s
.2 0 1 r
.44739 .34994 m
.46219 .34481 L
s
.2 1 0 r
.39994 .26433 m
.41465 .25901 L
s
0 .4 1 r
.43922 .32725 m
.45402 .32207 L
s
.8 1 0 r
.39173 .24158 m
.40643 .2362 L
s
0 1 1 r
.43104 .30454 m
.44583 .2993 L
s
1 .6 0 r
.38352 .21879 m
.39821 .21335 L
s
0 1 .4 r
.42285 .28179 m
.43763 .2765 L
s
.2 1 0 r
.41465 .25901 m
.42942 .25366 L
s
.8 1 0 r
.40643 .2362 m
.4212 .23079 L
s
1 .6 0 r
.39821 .21335 m
.41296 .2079 L
s
0 g
.25 Mabswid
.61241 0 m
.97291 .505 L
s
.97291 .505 m
1 .75117 L
s
1 .75117 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.03495 .22504 m
0 .48612 L
s
0 .48612 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.61241 0 m
.03495 .22504 L
s
.03495 .22504 m
.61241 0 L
s
.03495 .22504 m
.03971 .2297 L
s
[(-2)] .02544 .21571 1 .98073 Mshowa
.16988 .17246 m
.17445 .1773 L
s
[(-1)] .16074 .16277 .9432 1 Mshowa
.31082 .11753 m
.31518 .12256 L
s
[(0)] .3021 .10747 .86675 1 Mshowa
.45818 .0601 m
.46231 .06533 L
s
[(1)] .44992 .04965 .7903 1 Mshowa
.61241 0 m
.61628 .00542 L
s
[(2)] .60467 -0.01084 .71386 1 Mshowa
.125 Mabswid
.06148 .2147 m
.06431 .21752 L
s
.08823 .20428 m
.09104 .20712 L
s
.11521 .19376 m
.118 .19663 L
s
.14243 .18316 m
.14519 .18604 L
s
.19758 .16166 m
.20029 .16459 L
s
.22551 .15078 m
.22821 .15373 L
s
.2537 .13979 m
.25637 .14277 L
s
.28213 .12871 m
.28478 .13171 L
s
.33977 .10625 m
.34236 .10929 L
s
.36897 .09487 m
.37153 .09794 L
s
.39844 .08339 m
.40097 .08648 L
s
.42817 .0718 m
.43068 .07491 L
s
.48846 .0483 m
.49091 .05146 L
s
.51902 .03639 m
.52144 .03958 L
s
.54986 .02437 m
.55225 .02758 L
s
.58099 .01224 m
.58335 .01547 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 256.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001@2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00gOooool5o`0008Kooooo003Mooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0Q_ooool00=ko
oooo00?oV9RHob4Q8Oo^k^h0Qoooool00=oooooo00?oV9RHob4Q8Oo^k^h0Q_ooool00>3ooooo00?o
MgMgofIVI_ooool0QOooool00>7ooooo00?o0000ooooooooool0Q?ooool00=gooooo00Go0000okZj
^_ooooooV9RHoa0@4026ooooo`00gOooool01OnHV9So410@o`000?lQ8B7oc<c<08Kooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003Tooooo`;o0000P_ooool0
0>7ooooo0ol000000ooooooo0000ooooo`21ooooo`00goooool2o`0000Cooooo0_l00021ooooo`00
g?ooool3o`0000Kooooo00?o0000ooooool00000P?ooool00=[ooooo0_l00009ooooo`03o`000?oo
oooo0000083ooooo003Gooooo`?o000000?oooooo`000?ooool02?ooool01?l0003oooooooooool0
001oooooo`00e?ooool3o`0000Cooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooo
oooo000007kooooo003Booooo`;o00004Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo07_ooooo002Zooooo`Co000000?o410@ooooooooool07_ooool3o`0001?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1kooooo`00[?ooool00ol0003oooooooooo`0Nooooo`;o
000000?oooooo`000?ooool04oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07[o
oooo002/ooooo`03o`000?oooooooooo01_ooooo0ol00004ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`1iooooo`00[?ooool00ol0003ooooooooo
o`0Iooooo`;o00006oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo07Wooooo002/
ooooo`03o`000?oooooooooo01Kooooo0ol0000Mooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool02?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^06_ooooo002/ooooo`03o`000?oooooo
oooo01Cooooo0_l000000ooooooo0000ooooo`0Mooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01oooool01OmgMgOoV9RHoooooonHV9SoMgMg06_ooooo002/ooooo`03o`000?oooooo
oooo017ooooo0ol00004ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`06ooooo`05oa0@4?ooooooooooooooool@4100Joooool00:[ooooo00?oEEEE
ofIVI_l000004Oooool2o`0002Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06
ooooo`05o`000?ooooooooooooooool00000Joooool00;_ooooo0ol0000Wooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000006_ooooo002i
ooooo`;o000000?oooooo`000?ooool09oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Cooooo00Go410@oooooooooooooooooa0@401[ooooo`00]_ooool3o`0000Cooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`1[ooooo`00/oooool3o`0002oooooo00?o0000ooooooooool02Oooool2
o`0000Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1[ooooo`00/Oooool2o`0003;ooooo00?o0000
ooooooooool02?ooool01?l0003oooooooooool0001dooooo`00[_ooool3o`000003ooooool0003o
oooo037ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1aooooo`00[?ooool2o`00
00Gooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
077ooooo002Yooooo`?o0000>_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo073o
oooo002Wooooo`;o0000?Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo06oooooo
002Tooooo`?o000000?oooooo`000?ooool0??ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo06oooooo002Rooooo`;o0000@_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo06kooooo001gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08oooool3o`0004Cooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1]ooooo`00Moooool01OmgMgOoV9RHoooooonHV9So
MgMg027ooooo0_l00017ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0K?ooool0
07Oooooo00Go410@oooooooooooooooooa0@400Nooooo`?o00000_ooool00ol0003oooooooooo`14
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0K?ooool007Oooooo00Go0000oooo
ooooooooooooo`00000Looooo`;o0000C?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo06_ooooo001gooooo`05o`000?ooooooooooooooool000006Oooool3o`0004kooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`1Zooooo`00Moooool01Ol@413ooooooooooooooooo
410@01Kooooo0ol0001Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0J_ooool0
07Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Dooooo`;o00000oooool00ol0003oooooooooo`1>
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0JOooool007Oooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Aooooo`?o0000E_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo06Sooooo002;ooooo`;o0000FOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
06Sooooo0028ooooo`?o0000Foooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo06Oo
oooo0026ooooo`;o00000oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo01Gooooo
0_l0001Xooooo`00Poooool3o`00063ooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`1Uooooo`00POooool2o`0006?ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1U
ooooo`00O_ooool4o`0006Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`1Toooo
o`00O?ooool2o`0000Cooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo06?ooooo001iooooo`?o0000J_ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo06?ooooo001gooooo`;o0000KOooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo06;ooooo001dooooo`?o000000?oooooo`000?ooool0K?ooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo067ooooo001aooooo`?o0000L_ooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo063ooooo0019ooooo`Co000000?o410@ooooooooool07oooool2o`0007Go
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1Pooooo`00Boooool00ol0003ooooo
ooooo`0Nooooo`?o0000Moooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo05oooooo
0010ooooo`Ko00001Oooool00ol0003oooooooooo`0Looooo`;o00000_ooool00ol0003ooooooooo
o`1eooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0G_ooool004_ooooo00?o0000
ooooooooool06Oooool3o`0007cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1N
ooooo`00Boooool00ol0003oooooooooo`0Gooooo`;o0000Ooooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo05gooooo001;ooooo`03o`000?oooooooooo01Cooooo0ol00021ooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0G?ooool004_ooooo00?o0000ooooooooool0
4_ooool2o`0000?ooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo05_ooooo0019ooooo`03oeEEEOmVIVKo0000017ooooo0ol00026ooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool0Foooool005_ooooo0_l00029ooooo`03o`000?oooooo
oooo027ooooo0_l0001Looooo`00F?ooool3o`000003ooooool0003ooooo08Sooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`1Iooooo`00E_ooool2o`0008kooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`1Iooooo`00Doooool3o`00093ooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`1Hooooo`00D?ooool3o`0009?ooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1Gooooo`00C_ooool2o`0000;ooooo00?o0000ooooooooool0TOooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo05Kooooo001;ooooo`?o00001Oooool00ol0
003oooooooooo`2@ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0E_ooool004Wo
oooo0_l0002Kooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0EOooool004Kooooo
1?l0002Looooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0E?ooool004Cooooo0_l0
002Pooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0E?ooool001[ooooo1Ol0000R
ooooo`?o0000X_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo05?ooooo000Joooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@08?ooool2o`000:Gooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`1Booooo`004_ooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h07_ooool3o`00
0003ooooool0003ooooo0:Cooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`1Aoooo
o`007?ooool00onHV9So8B4Qonk^kP0Kooooo`;o0000Z_ooool00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo057ooooo000Mooooo`03ogMgMomVIVKooooo01Oooooo0ol0002]ooooo`03o`00
0?oooooooooo02_ooooo00?o0000ooooooooool0D?ooool001kooooo00?o0000ooooooooool05?oo
ool2o`000;3ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`1?ooooo`006_ooool0
1Ol0003o^[ZjoooooonHV9So410@01?ooooo0ol00002ooooo`03o`000?oooooooooo06Sooooo0_oo
V@13ooooo`03o`000?oooooooooo02cooooo0_l0001@ooooo`006_ooool01OnHV9So410@o`000?lQ
8B7oc<c<013ooooo0ol0001]ooooo`?ooiT0AOooool00ol0003oooooooooo`0/ooooo`;o0000D?oo
ool002gooooo0_l0001]ooooo`?ooiT0B?ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooo
oooo04gooooo000Zooooo`?o000000?oooooo`000?ooool0J?ooool4oonI04_ooooo00?o0000oooo
ooooool0;_ooool00ol0003oooooooooo`1=ooooo`00:?ooool2o`0006_ooooo0oooV@1?ooooo`03
o`000?oooooooooo02oooooo00?o0000ooooooooool0C?ooool002Gooooo0ol0001[ooooo`;ooiT0
D_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo04_ooooo000Tooooo`;o0000J_oo
ool3oonI05Cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`1:ooooo`006_ooool4
o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooool00000Ioooool2oonI01Cooooo0_o<o`11
ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0B_ooool001cooooo00?o0000oooo
ooooool01Oooool01?l0003oooooooooool0001Sooooo`?ooiT04oooool3olco04?ooooo00?o0000
ooooooooool0<_ooool00ol0003oooooooooo`19ooooo`004Oooool6o`0000Gooooo00?o0000oooo
ooooool01Oooool2o`0000;ooooo00?o0000ooooooooool0G_ooool2oonI01Cooooo0_o<o`16oooo
o`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0B?ooool001cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo05[ooooo0oooV@0Cooooo`?o
c?l0B?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Oooooo1Ol0000looooo`00
7?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
E_ooool3oonI01Cooooo0_o<o`1;ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0
1_ooool01OnHV9So8B4Qonk^k_ooooooA4A403cooooo000Looooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`1Booooo`?ooiT05Oooool2olco04gooooo
00?o0000ooooooooool0=Oooool00ol0003oooooooooo`06ooooo`03oiRHV?lQ8B7ok^k^03gooooo
000Looooo`03o`000?oooooooooo00Cooooo0ol00006ooooo`03o`000?oooooooooo04kooooo0ooo
V@0Fooooo`;oc?l0Coooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Kooooo00?o
V9RHob4Q8Oo^k^h0??ooool001[ooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`07
ooooo`03o`000?oooooooooo04_ooooo0_ooV@0Fooooo`?oc?l0DOooool00ol0003oooooooooo`0f
ooooo`03o`000?oooooooooo00Oooooo00?oMgMgofIVI_ooool0>oooool002?ooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`17ooooo`?ooiT05Oooool3olco01Cooooo0_lco`0noooo
o`03o`000?oooooooooo03Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0joooo
o`008oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo04Gooooo00?ooiT0oooooooo
ool04_ooool4olco01Cooooo0olco`10ooooo`03o`000?oooooooooo03Oooooo0_l00004ooooo`05
o`000?nj^[[ooooooiRHV?l@4100??ooool002?ooooo0_l0000;ooooo`03o`000?oooooooooo05Ko
oooo0oo<o`0Fooooo`;o<ol0@oooool00ol0003oooooooooo`0fooooo`03o`000?oooooo000000Co
oooo00GoV9RHoa0@4?l0003o8B4Qolc<c00looooo`008oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo05?ooooo0_o<o`0Fooooo`?o<ol0AOooool00ol0003oooooooooo`0iooooo`03
o`000?oooooooooo04;ooooo000Rooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
Coooool3olco01Gooooo0olco`18ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0
@Oooool002;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1<ooooo`;oc?l05?oo
ool4oc?o04[ooooo0_l0000mooooo`03o`000?oooooooooo043ooooo000Rooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0BOooool2olco01?ooooo0olco`1;ooooo`?o000000?ooooo
o`000?ooool0??ooool00ol0003oooooooooo`10ooooo`008_ooool2o`00017ooooo00?o0000oooo
ooooool0AOooool3olco01?ooooo0_lco`1;ooooo`?o00001Oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo03oooooo000Rooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool0@Oooool3olco01Cooooo0_lco`0Fooooo`?o0?mV<Oooool3o`0000Wooooo00?o0000oooooooo
ool0>oooool00ol0003oooooooooo`0nooooo`008_ooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo05Gooooo0_lco`0Dooooo`Co0?mV<Oooool3o`0000gooooo00?o0000ooooooooool0
>_ooool00ol0003oooooooooo`0nooooo`008_ooool3o`0001?ooooo00?o0000ooooooooool0DOoo
ool3oc?o01?ooooo0ol0ofHbooooo`?o00004Oooool00ol0003oooooooooo`0jooooo`03o`000?oo
oooooooo03gooooo000Rooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0COooool3
oc?o01Cooooo0_l0ofHcooooo`;o00005?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo03cooooo000Qooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0B?ooool4oc?o
01Cooooo0ol0ofHbooooo`?o00005oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
03_ooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`00
0?l0003o<S8bomgMg@04ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0A?ooool3
oc?o01Kooooo0_l0ofHbooooo`?o00006oooool00ol0003oooooooooo`0jooooo`03o`000?oooooo
oooo03_ooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo047ooooo0_lco`0F
ooooo`?o0?mV<Oooool3o`0001oooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0j
ooooo`001Ol00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`02
ooooo`;o00006_ooool00ol0003oooooooooo`0mooooo`?o<ol05Oooool3o`3oIQGooooo0_l0oolJ
ooooo`?o00008oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03Wooooo0007oooo
o`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool0>oooool00olco`3oooooooooo`0Booooo`Co0?mV5Oooool3
o`3ooa[ooooo0_l0000Vooooo`03o`000?oooooooooo03[ooooo0_l0000jooooo`001oooool01Ol0
003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool0COooool2o`3oIQOooooo0_l0oolJooooo`?o0000:Ooo
ool00ol0003oooooooooo`0iooooo`;o0000>_ooool000Oooooo00Go410@oooooooooooooooooa0@
400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`1:ooooo`;o0?mV5_ooool3o`3ooaWooooo0ol0000]ooooo`03o`000?oooooooooo03[ooooo00?o
0000ooooooooool0=oooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oo
oooooooo00Kooooo0_l0000Nooooo`03o`000?oooooooooo04Kooooo0ol0ofHFooooo`;o0?oo6Ooo
ool3o`00037ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0gooooo`001oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00004ooooo`;o00008?ooool00ol0003ooooooooo
o`13ooooo`;o0?mV5_ooool3o`3ooaSooooo0ol0000eooooo`03o`000?oooooooooo03Wooooo00?o
0000ooooooooool0=_ooool0023ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0o
ooooo`?o0?mV5Oooool3o`3ooaSooooo0ol0000hooooo`03o`000?oooooooooo03[ooooo00?o0000
ooooooooool0=Oooool0023ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0koooo
o`?o0?mV5?ooool4o`3ooaWooooo0_l0000looooo`03o`000?oooooooooo03[ooooo00?o0000oooo
ooooool0=?ooool0023ooooo0_l0000Sooooo`03o`000?oooooooooo03Oooooo0ol0ofHDooooo`?o
0?oo5_ooool2o`1Vo`;ooooo0ol0000oooooo`03o`000?oooooooooo03Wooooo00?o0000oooooooo
ool0=?ooool0023ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1;ooooo`;o0?oo
5_ooool3o`1Vo`04ooooool0003o0000o`0004?ooooo00?o0000ooooooooool0>Oooool00ol0003o
ooooooooo`0cooooo`008?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo04Oooooo
0ol0oolEooooo`?o06Ko00Coooooo`000?l0003o0000Aoooool00ol0003oooooooooo`0iooooo`03
o`000?oooooooooo03;ooooo000Pooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
@oooool3o`3ooaCooooo1?l0I_l01?oooooo0000o`000?l0001:ooooo`03o`000?oooooooooo03Wo
oooo00?o0000ooooooooool0<_ooool0023ooooo00?o0000ooooooooool09_ooool2o`0003oooooo
1?l0oolEooooo`;o06Ko0oooool2o`0004kooooo00?o0000ooooooooool0>Oooool00ol0003ooooo
ooooo`0aooooo`007oooool3o`0002Wooooo00?o0000ooooooooool0>_ooool2o`3ooaOooooo0_l0
I_l2ooooo`?o0000DOooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo033ooooo000O
ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0=oooool2o`3ooaKooooo0ol0I_l0
1?oooooo0000o`000?l0001Eooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0;ooo
ool001oooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0cooooo`?o0?oo5Oooool3
o`1Vo`04ooooool0003o0000o`00013ooooo0_lc0?m6ooooo`03o`000?oooooooooo03Wooooo00?o
0000ooooooooool0;oooool001oooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0a
ooooo`03o`3ooooooooooooo01;ooooo1?l0I_l01?oooooo0000o`000?l0000@ooooo`?o<`3oBOoo
ool00ol0003oooooooooo`0hooooo`;o0000<?ooool001oooooo0ol0000]ooooo`03o`000?oooooo
oooo04;ooooo0ol0I_l2ooooo`?o00004Oooool2oc<0odgooooo00?o0000ooooooooool0>Oooool0
0ol0003oooooooooo`0]ooooo`007oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo
03oooooo0_l0I_l3ooooo`;o00004Oooool3oc<0oe3ooooo00?o0000ooooooooool0>?ooool00ol0
003oooooooooo`0]ooooo`005?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooo
ooooool0;oooool00ol0003oooooooooo`0kooooo`?o06Ko0_ooool3o`00017ooooo0_lc0?mDoooo
o`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0;?ooool001Cooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0>?ooool2o`1V
o`;ooooo0ol0000Aooooo`?o<`3oE_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo
02_ooooo000Dooooo`05oa0@4?ooooooooooooooool@41001Oooool2o`0003?ooooo00?o0000oooo
ooooool0=?ooool3o`1Vo`04ooooool0003o0000o`00017ooooo0olc0?mJooooo`03o`000?oooooo
oooo03Wooooo00?o0000ooooooooool0:_ooool001Cooooo00Go0000ooooooooooooooooo`000005
ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0<?ooool3o`1Vo`04ooooool0003o
0000o`00013ooooo1?lc0?mNooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0:_oo
ool001Cooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo03Cooooo00?o
0000ooooooooool0;Oooool2o`1Vo`04ooooool0003o0000o`00017ooooo0_lc0?lGooooo`;oc03o
B_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02Wooooo000Dooooo`05oa0@4?oo
ooooooooooooool@41001Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02gooooo
0_l0000Booooo`;o<`3o5_ooool3ol`0odgooooo00?o0000ooooooooool0>?ooool00ol0003ooooo
ooooo`0Xooooo`005?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0
=_ooool00ol0003oooooooooo`0Yooooo`?o00004Oooool3oc<0oaGooooo0oo<0?m@ooooo`03o`00
0?oooooooooo03Sooooo00?o0000ooooooooool0:?ooool001Cooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o0000>?ooool00ol0003oooooooooo`0Uooooo`?o00004Oooool3oc<0oaCooooo
1?o<0?mDooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool09oooool001kooooo00?o
0000ooooooooool0>?ooool00ol0003oooooooooo`0Qooooo`?o00004?ooool4oc<0oaCooooo0oo<
0?mIooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool09_ooool001gooooo00?o0000
ooooooooool0>_ooool00ol0003oooooooooo`0Mooooo`?o00004?ooool3oc<0oaKooooo0_o<0?mM
ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool09Oooool001gooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`0Jooooo`;o00004Oooool2oc<0oaKooooo0oo<0?mPoooo
o`03o`000?oooooooooo03Oooooo00?o0000ooooooooool09Oooool001gooooo0_l0000mooooo`03
o`000?oooooooooo01Kooooo0ol0000@ooooo`?o<`3o5Oooool3ol`0of?ooooo00?o0000oooooooo
ool0=oooool2o`0002Kooooo000Mooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0
4_ooool3o`0001;ooooo00?o<`3oooooooooool04_ooool4ol`0oaKooooo0ooo09U>ooooo`03o`00
0?oooooooooo03Sooooo00?o0000ooooooooool08oooool001gooooo00?o0000ooooooooool0?_oo
ool00ol0003oooooooooo`0>ooooo`?o00009oooool3ol`0oaOooooo0ooo09UBooooo`03o`000?oo
oooooooo03Oooooo00?o0000ooooooooool08oooool001gooooo00?o0000ooooooooool0?oooool0
0ol0003oooooooooo`0:ooooo`?o0000:?ooool2ol`0oaOooooo0ooo09UFooooo`03o`000?oooooo
oooo03Oooooo00?o0000ooooooooool08_ooool001gooooo00?o0000ooooooooool0@?ooool00ol0
003oooooooooo`06ooooo`?o0000:Oooool2ol`0oaOooooo0_oo09UJooooo`03o`000?oooooooooo
03Oooooo00?o0000ooooooooool08Oooool001cooooo0ol00012ooooo`03o`000?oooooooooo00?o
oooo0_l0000Yooooo`?oc03o5_ooool3ool0VEcooooo00?o0000ooooooooool0>?ooool00ol0003o
ooooooooo`0Pooooo`007?ooool00ol0003oooooooooo`13ooooo`03o`000?oooooo000000;o0000
9oooool4ol`0oaKooooo0ooo09UPooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0
8?ooool001cooooo00?o0000ooooooooool0@_ooool3o`0002Oooooo0oo<0?lFooooo`Coo`2II?oo
ool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00Wooooo0_l000000ol@413ooooooooo
o`0Aooooo`007?ooool00ol0003oooooooooo`0oooooo`?o00000oooool00ol0003oooooooooo`0S
ooooo`03ol`0oooooooooooo01Cooooo0ooo09TFooooo`;oo`00DOooool00ol0003oooooooooo`0g
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04_ooool001cooooo0ol0000loooo
o`?o00001oooool00ol0003oooooooooo`0gooooo`;oo`2I5_ooool3ool005Cooooo00?o0000oooo
ooooool0=_ooool00ol0003oooooooooo`06ooooo`Go00004oooool001cooooo00?o0000oooooooo
ool0>Oooool3o`0000_ooooo00?o0000ooooooooool0<oooool3ool0VAGooooo0ooo001Gooooo`03
o`000?oooooooooo03Oooooo00?o0000ooooooooool01Oooool01?m4A4CogMgMooooool0000Doooo
o`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb
<S;ogMgM00Gooooo00?o0000ooooooooool0=oooool2o`0000oooooo00?o0000ooooooooool0;ooo
ool3ool0VACooooo1?oo001Kooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool01?oo
ool01?oMgMgoEEEEooooool0000Dooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o
8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo03Cooooo0ol0000Booooo`03
o`000?oooooooooo02[ooooo1?oo09TDooooo`?oo`00H?ooool00ol0003oooooooooo`0fooooo`03
o`000?oooooooooo00Gooooo00?oMgMgolc<c?l000005?ooool00003ooooool@413ooooo00;ooooo
00?o410@ooooooooool03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo037ooooo
0ol0000Fooooo`03o`000?oooooooooo02Oooooo0_oo09TFooooo`;oo`00I?ooool00ol0003ooooo
ooooo`0fooooo`;o00001Oooool00oo^k^koA4A4o`00000Dooooo`0000?oooooo`000?ooool00_oo
ool00ol0003oooooooooo`0=ooooo`03ogMgMolb<S;ooooo00?ooooo0_l0000`ooooo`?o00006_oo
ool00ol0003oooooooooo`0Sooooo`?oo`2I5_ooool2ool006Oooooo00?o0000ooooooooool0=?oo
ool00ol0003oooooo`000006ooooo`03ogMgMol0003ooooo01?ooooo00000ooooooo0000ooooo`02
ooooo`03o`000?oooooooooo00[ooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oo
oooooooo02cooooo0ol0000Nooooo`03o`000?oooooooooo01oooooo0ooo09TFooooo`?oo`00JOoo
ool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo01Wooooo00000ooooooo410@ooooo`02
ooooo`03oa0@4?oooooooooo00[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Z
ooooo`;o00008_ooool00ol0003oooooooooo`0cooooo`Coo`00KOooool00ol0003oooooooooo`0f
ooooo`03o`000?oooooooooo01Wooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`cooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Wooooo`?o00009Oooool2o`00033ooooo0ooo
001booooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool06?ooool00006ooooooo^k^ko
<S8bo`000?lb<S;ok^k^3?ooool4o`0000Gooooo0_l0000Uooooo`?o0000:_ooool00ol0003ooooo
ooooo`0[ooooo`;oo`00M_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo01Oooooo
000Kooooo`03o`000?oooooooooo027ooooo0ol0000^ooooo`03o`000?oooooooooo02Oooooo0ooo
001iooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool05oooool001_ooooo00?o0000
ooooooooool07_ooool3o`0003;ooooo00?o0000ooooooooool08oooool3ool007cooooo00?o0000
ooooooooool0=_ooool00ol0003oooooooooo`0Fooooo`006oooool00ol0003oooooooooo`0Koooo
o`?o0000=_ooool00ol0003oooooooooo`0Nooooo`Coo`00P?ooool00ol0003oooooooooo`0foooo
o`03o`000?oooooooooo01Gooooo000Jooooo`03o`000?oooooooooo01[ooooo0_l0000jooooo`03
o`000?oooooooooo01[ooooo0ooo0025ooooo`03o`000?oooooooooo03Kooooo00?o0000oooooooo
ool05?ooool001[ooooo0_l0000Hooooo`?o0000?Oooool00ol0003oooooooooo`0Hooooo`03ool0
0?oooooooooo08Oooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Dooooo`006_oo
ool00ol0003oooooooooo`0Dooooo`?o0000@Oooool00ol0003oooooooooo`2Qooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool04oooool001[ooooo00?o0000ooooooooool04Oooool3
o`0004Gooooo00?o0000ooooooooool0XOooool00ol0003oooooooooo`0fooooo`03o`000?oooooo
oooo01;ooooo000Jooooo`03o`000?oooooooooo00kooooo0ol00019ooooo`03o`000?oooooooooo
0:7ooooo00?o0000ooooooooool0=Oooool2o`0001?ooooo000Jooooo`03o`000?oooooooooo00co
oooo0_l0001=ooooo`03o`000?oooooooooo0:7ooooo00?o0000ooooooooool0=?ooool2o`0001?o
oooo000Iooooo`?o00002_ooool3o`00053ooooo00?o0000ooooooooool0XOooool00ol0003ooooo
ooooo`0eooooo`03o`000?oooooooooo013ooooo000Jooooo`03o`000?oooooooooo00Kooooo0ol0
001Dooooo`03o`000?oooooooooo0:3ooooo00?o0000ooooooooool0=_ooool00ol0003ooooooooo
o`0?ooooo`006Oooool00ol0003oooooooooo`04ooooo`?o0000F?ooool00ol0003oooooooooo`2P
ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool03oooool001Wooooo00Co0000oooo
oooooooooooo0ol0001Looooo`03o`000?oooooooooo0:3ooooo00?o0000ooooooooool0=Oooool0
0ol0003oooooooooo`0>ooooo`006Oooool4o`00063ooooo00?o0000ooooooooool0X?ooool00ol0
003oooooooooo`0eooooo`03o`000?oooooooooo00gooooo000Iooooo`;o0000Hoooool00ol0003o
ooooooooo`2Pooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool03Oooool000oooooo
1?l000000ol@413oooooooooo`05ooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0
Woooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00cooooo000Aooooo`03o`000?oo
oooooooo00Sooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`2Oooooo`03o`000?oo
oooooooo03Gooooo00?o0000ooooooooool02oooool0017ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`1Qooooo`03o`000?oooooooooo09oooooo00?o0000ooooooooool0=Oooool0
0ol0003oooooooooo`0:ooooo`004Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
067ooooo00?o0000ooooooooool0Woooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo
00[ooooo000Aooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0HOooool00ol0003o
ooooooooo`2Oooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool02Oooool0017ooooo
00?o0000ooooooooool03?ooool2o`0006;ooooo00?o0000ooooooooool0W_ooool00ol0003ooooo
ooooo`0cooooo`?o00002_ooool0017ooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`1Pooooo`03o`000?oooooooooo09kooooo00?o0000ooooooooool0;oooool3o`0000;ooooo00?o
0000ooooooooool02?ooool000oooooo00?oEEEEofIVI_l000004Oooool00ol0003oooooooooo`1P
ooooo`03o`000?oooooooooo09kooooo00?o0000ooooooooool0:oooool3o`0000Gooooo00?o0000
ooooooooool02?ooool002Cooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`2Noooo
o`03o`000?oooooooooo02Kooooo1?l00008ooooo`03o`000?oooooooooo00Sooooo000Uooooo`03
o`000?oooooooooo063ooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`0Rooooo`?o
00003?ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`1Pooooo`03o`00
0?oooooooooo09gooooo00?o0000ooooooooool07oooool3o`00013ooooo00?o0000ooooooooool0
1oooool002Oooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`2Mooooo`03o`000?oo
oooooooo01[ooooo1?l0000Cooooo`03o`000?oooooooooo00Oooooo000Xooooo`;o0000HOooool0
0ol0003oooooooooo`2Mooooo`03o`000?oooooooooo01Kooooo0ol0000Gooooo`03o`000?oooooo
oooo00Oooooo000Zooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool0WOooool00ol0
003oooooooooo`0Booooo`?o00006_ooool00ol0003oooooooooo`07ooooo`00:oooool00ol0003o
ooooooooo`1Oooooo`03o`000?oooooooooo09gooooo00?o0000ooooooooool03Oooool4o`0001go
oooo00?o0000ooooooooool01oooool002cooooo00?o0000ooooooooool0Goooool00ol0003ooooo
ooooo`2Looooo`03o`000?oooooooooo00[ooooo0ol0000Qooooo`03o`000?oooooooooo00Oooooo
000]ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool0W?ooool00ol0003ooooooooo
o`06ooooo`?o00009?ooool00ol0003oooooooooo`07ooooo`00;_ooool00ol0003oooooooooo`1O
ooooo`03o`000?oooooooooo09cooooo00Co0000oooooooooooooooo1?l0000Wooooo`03o`000?oo
oooooooo00Oooooo000_ooooo`;o0000H?ooool00ol0003oooooooooo`2Looooo`?o0000;?ooool0
0ol0003oooooooooo`06ooooo`00<Oooool00ol0003oooooooooo`1Nooooo`;o0000VOooool3o`00
0003ooooool0003ooooo02cooooo00?o0000ooooooooool01_ooool003;ooooo00?o0000oooooooo
ool0Goooool00ol0003oooooooooo`2Cooooo`?o00001?ooool00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo00Kooooo000cooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool0
S_ooool4o`0000Sooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`06ooooo`00=?oo
ool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo08[ooooo0ol0000=ooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool01_ooool003Gooooo00?o0000ooooooooool0Goooool0
0ol0003oooooooooo`26ooooo`?o00004Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooo
oooo00Kooooo000fooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool0POooool4o`00
01Gooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`06ooooo`00=oooool2o`00063o
oooo00?o0000ooooooooool0OOooool3o`0001Wooooo00?o0000ooooooooool09oooool00ol0003o
ooooooooo`06ooooo`00>Oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo07Wooooo
0ol0000Mooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool01Oooool003[ooooo00?o
0000ooooooooool0G_ooool00ol0003oooooooooo`1dooooo`Co00008Oooool00ol0003ooooooooo
o`0Vooooo`03o`000?oooooooooo00Gooooo000kooooo`03o`000?oooooooooo05kooooo00?o0000
ooooooooool0L?ooool3o`0002Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`05
ooooo`00??ooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo06cooooo0ol0000Yoooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool01Oooool003gooooo00?o0000oooooooo
ool0G_ooool00ol0003oooooooooo`1Wooooo`Co0000;Oooool00ol0003oooooooooo`0Tooooo`03
o`000?oooooooooo00Gooooo000nooooo`;o0000Goooool00ol0003oooooooooo`1Sooooo`?o0000
<_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Gooooo0010ooooo`03o`000?oo
oooooooo05gooooo00?o0000ooooooooool0Goooool3o`0003Kooooo00?o0000ooooooooool08_oo
ool00ol0003oooooooooo`05ooooo`00@Oooool00ol0003oooooooooo`1Mooooo`03o`000?oooooo
oooo05[ooooo1?l0000jooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool01Oooool0
04;ooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`1Fooooo`?o0000?_ooool00ol0
003oooooooooo`0Qooooo`03o`000?oooooooooo00Gooooo0013ooooo`03o`000?oooooooooo05go
oooo00?o0000ooooooooool0D_ooool3o`0004;ooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`04ooooo`00A?ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo04gooooo
1?l00016ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01?ooool004Gooooo00?o
0000ooooooooool0GOooool00ol0003oooooooooo`19ooooo`?o0000Boooool00ol0003ooooooooo
o`0Oooooo`03o`000?oooooooooo00Cooooo0016ooooo`;o0000G_ooool00ol0003oooooooooo`15
ooooo`?o0000Coooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Cooooo0018oooo
o`03o`000?oooooooooo05cooooo00?o0000ooooooooool0@?ooool4o`0005;ooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`04ooooo`00BOooool00ol0003oooooooooo`1Looooo`03
o`000?oooooooooo03cooooo0ol0001Gooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool01?ooool004[ooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`0hooooo`?o0000
Foooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Cooooo001;ooooo`03o`000?oo
oooooooo05cooooo00?o0000ooooooooool0<oooool4o`0005oooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`04ooooo`00C?ooool00ol0003oooooooooo`1Looooo`03o`000?oooooo
oooo02oooooo0ol0001Tooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool00oooool0
04gooooo0_l0001Mooooo`03o`000?oooooooooo02_ooooo0ol0001Wooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool00oooool004oooooo00?o0000ooooooooool0Foooool00ol0003o
ooooooooo`0Wooooo`?o0000Joooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00?o
oooo001@ooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool08_ooool4o`0006oooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`03ooooo`00DOooool00ol0003ooooooooo
o`1Kooooo`03o`000?oooooooooo01kooooo0ol0001dooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool00oooool005;ooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`0J
ooooo`?o0000N?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00?ooooo001Coooo
o`03o`000?oooooooooo05_ooooo00?o0000ooooooooool05Oooool4o`0007_ooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`03ooooo`00E?ooool2o`0005cooooo00?o0000oooooooo
ool04Oooool3o`00083ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`03ooooo`00
E_ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00gooooo0ol00024ooooo`03o`00
0?oooooooooo01Kooooo00?o0000ooooooooool00_ooool005Oooooo00?o0000ooooooooool0F_oo
ool00ol0003oooooooooo`08ooooo`Co0000R?ooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo00;ooooo001Hooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool01?ooool3
o`0008gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`02ooooo`00FOooool00ol0
003oooooooooo`1Jooooo`03o`000?oooooooooo00?o0000T?ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo00;ooooo001Jooooo`03o`000?oooooooooo05[ooooo0_l0002Dooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool00_ooool005_ooooo00?o0000ooooooooool0
FOooool00ol0003oooooooooo`2Dooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
0_ooool005cooooo0_l0001Iooooo`03o`000?oooooooooo09Gooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`02ooooo`00G_ooool00ol0003oooooooooo`1Fooooo`03o`000?oooooo
oooo09Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`02ooooo`00Goooool00ol0
003oooooooooo`1Eooooo`03o`000?oooooooooo09Kooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`01ooooo`00H?ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo09Oo
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`01ooooo`00HOooool00ol0003ooooo
ooooo`1Cooooo`03o`000?oooooooooo09Sooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`01ooooo`00H_ooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo09Wooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`01ooooo`00Hoooool2o`0005;ooooo00?o0000
ooooooooool0V_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo007ooooo001Uoooo
o`03o`000?oooooooooo04oooooo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo007ooooo001Vooooo`03o`000?oooooooooo04kooooo00?o0000oooooooo
ool0Voooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo007ooooo001Wooooo`03o`00
0?oooooooooo04gooooo00?o0000ooooooooool0W?ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo007ooooo001Xooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0WOoo
ool00ol0003oooooooooo`0;ooooo`7o00000Oooool1ooooo`00JOooool00ol0003oooooooooo`1;
ooooo`03o`000?oooooooooo09gooooo00?o0000ooooooooool02oooool1o`00007ooooo0Oooool0
06[ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`2Nooooo`03o`000?oooooooooo
00[ooooo0Ol00001ooooo`7ooooo001[ooooo`;o0000B_ooool00ol0003oooooooooo`2Oooooo`03
o`000?oooooooooo00Wooooo0Ol00001ooooo`7ooooo001]ooooo`03o`000?oooooooooo04Oooooo
00?o0000ooooooooool0X?ooool00ol0003oooooooooo`08ooooo`7o00000Oooool1ooooo`00K_oo
ool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo0:7ooooo00?o0000ooooooooool01ooo
ool1o`00007ooooo0Oooool006oooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`2Q
ooooo`03o`000?oooooooooo00Oooooo0Ol00001ooooo`7ooooo001`ooooo`03o`000?oooooooooo
04Cooooo00?o0000ooooooooool0X_ooool00ol0003oooooooooo`06ooooo`7o00000Oooool1oooo
o`00LOooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo0:?ooooo00?o0000oooooooo
ool01Oooool1o`00007ooooo0Oooool007;ooooo0_l00012ooooo`03o`000?oooooooooo0:Gooooo
00?o0000ooooooooool01Oooool1o`00007ooooo001dooooo`03o`000?oooooooooo03oooooo00?o
0000ooooooooool0Y_ooool00ol0003oooooooooo`04ooooo`7o00000Oooool007Gooooo00?o0000
ooooooooool0?_ooool00ol0003oooooooooo`2Vooooo`03o`000?oooooooooo00Cooooo0Ol00001
ooooo`00M_ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo0:Oooooo00?o0000oooo
ooooool00oooool1o`00007ooooo001gooooo`03o`000?oooooooooo03cooooo00?o0000oooooooo
ool0Z?ooool00ol0003oooooooooo`02ooooo`7o00000Oooool007Sooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`2Yooooo`05o`000?ooooooooooooooool000000Oooool007Wooooo
00?o0000ooooooooool0>_ooool00ol0003oooooooooo`2Zooooo`04o`000?ooooooooooo`00007o
oooo001jooooo`;o0000>_ooool00ol0003oooooooooo`2Zooooo`04o`000?ooooooooooo`00007o
oooo001looooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0Zoooool00ol0003ooooo
ooooo`01o`000000OOooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo0:cooooo0Ol0
0001ooooo`7o0000001nooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0[Oooool2
o`000000Ooooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo0:cooooo0ol00000083o
oooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`2Xooooo`Co00000oooool0087ooooo
0_l0000cooooo`03o`000?oooooooooo0:Gooooo0ol00007ooooo`00Poooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo0:7ooooo1?l0000:ooooo`00Q?ooool00ol0003oooooooooo`0_
ooooo`03o`000?oooooooooo09gooooo1?l0000>ooooo`00QOooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooooooo09Wooooo1?l0000Booooo`00Q_ooool00ol0003oooooooooo`0]ooooo`03
o`000?oooooooooo09Gooooo1?l0000Fooooo`00Qoooool00ol0003oooooooooo`0/ooooo`03o`00
0?oooooooooo09;ooooo0ol0000Jooooo`00R?ooool2o`0002cooooo00?o0000ooooooooool0S_oo
ool4o`0001gooooo002:ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0R_ooool4
o`00027ooooo002;ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0Q_ooool4o`00
02Gooooo002<ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0P_ooool4o`0002Wo
oooo002=ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0Ooooool3o`0002gooooo
002>ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0Noooool4o`00033ooooo002?
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0Moooool4o`0003Cooooo002@oooo
o`;o00009?ooool00ol0003oooooooooo`1cooooo`Co0000>?ooool009;ooooo00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`1`ooooo`?o0000??ooool009?ooooo00?o0000ooooooooool0
8?ooool00ol0003oooooooooo`1/ooooo`Co0000?oooool009Cooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`1Xooooo`Co0000@oooool009Gooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`1Tooooo`Co0000Aoooool009Kooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`1Pooooo`Co0000Boooool009Oooooo0_l0000Mooooo`03o`000?oooooooooo05go
oooo0ol0001?ooooo`00VOooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo05Wooooo
1?l0001Booooo`00V_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo05Gooooo1?l0
001Fooooo`00Voooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo057ooooo1?l0001J
ooooo`00W?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04gooooo1?l0001Noooo
o`00WOooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04[ooooo0ol0001Rooooo`00
W_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04Kooooo1?l0001Uooooo`00Wooo
ool2o`0001Cooooo00?o0000ooooooooool0@oooool4o`0006Wooooo002Qooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool0?oooool4o`0006gooooo002Rooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool0>oooool4o`00077ooooo002Sooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0>?ooool3o`0007Gooooo002Tooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool0=?ooool4o`0007Sooooo002Uooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool0<?ooool4o`0007cooooo002Vooooo`;o00003Oooool00ol0003oooooooooo`0/
ooooo`Co0000P?ooool00:Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Yoooo
o`?o0000Q?ooool00:Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Uooooo`Co
0000Qoooool00:[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Qooooo`Co0000
Roooool00:_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Mooooo`Co0000Sooo
ool00:cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Iooooo`Co0000Toooool0
0:gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Fooooo`?o0000Uoooool00:ko
oooo0_l00005ooooo`03o`000?oooooooooo01;ooooo1?l0002Jooooo`00/?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00kooooo1?l0002Nooooo`00/Oooool01Ol0003ooooooooo
oooooooo000000cooooo1?l0002Rooooo`00/_ooool01?l0003oooooooooool00008ooooo`Co0000
Y_ooool00;?ooooo00?o0000ooooool000001Oooool3o`000:[ooooo002dooooo`;o000000?ooooo
o`000?l000000_l0002]ooooo`00]Oooool2o`000;7ooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {319.688, 0}} -> {-0.0710364, -0.0181728, \
0.0035149, 0.0035149}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .89104 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-16 1.0656 -0.0363427 1.0656 [
[.02544 .21571 -12 -8.9133 ]
[.02544 .21571 0 .0867 ]
[.16074 .16277 -11.6592 -9 ]
[.16074 .16277 .34081 0 ]
[.3021 .10747 -5.60025 -9 ]
[.3021 .10747 .39975 0 ]
[.44992 .04965 -5.37091 -9 ]
[.44992 .04965 .62909 0 ]
[.60467 -0.01084 -5.14157 -9 ]
[.60467 -0.01084 .85843 0 ]
[.66454 .05085 0 -6.20675 ]
[.66454 .05085 6 2.79325 ]
[.80797 .25198 0 -6.0417 ]
[.80797 .25198 6 2.9583 ]
[.93071 .4241 0 -5.90576 ]
[.93071 .4241 6 3.09424 ]
[.02254 .22988 -12 -2.74631 ]
[.02254 .22988 0 6.25369 ]
[.0142 .29178 -24 -2.78907 ]
[.0142 .29178 0 6.21093 ]
[.00558 .35578 -6 -2.83339 ]
[.00558 .35578 0 6.16661 ]
[-0.00334 .42198 -18 -2.87938 ]
[-0.00334 .42198 0 6.12062 ]
[-0.01257 .49051 -6 -2.92712 ]
[-0.01257 .49051 0 6.07288 ]
[ 0 0 0 0 ]
[ 1 .89104 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03495 .22504 m
.61241 0 L
s
.03495 .22504 m
.03971 .2297 L
s
[(-2)] .02544 .21571 1 .98073 Mshowa
.16988 .17246 m
.17445 .1773 L
s
[(-1)] .16074 .16277 .9432 1 Mshowa
.31082 .11753 m
.31518 .12256 L
s
[(0)] .3021 .10747 .86675 1 Mshowa
.45818 .0601 m
.46231 .06533 L
s
[(1)] .44992 .04965 .7903 1 Mshowa
.61241 0 m
.61628 .00542 L
s
[(2)] .60467 -0.01084 .71386 1 Mshowa
.125 Mabswid
.06148 .2147 m
.06431 .21752 L
s
.08823 .20428 m
.09104 .20712 L
s
.11521 .19376 m
.118 .19663 L
s
.14243 .18316 m
.14519 .18604 L
s
.19758 .16166 m
.20029 .16459 L
s
.22551 .15078 m
.22821 .15373 L
s
.2537 .13979 m
.25637 .14277 L
s
.28213 .12871 m
.28478 .13171 L
s
.33977 .10625 m
.34236 .10929 L
s
.36897 .09487 m
.37153 .09794 L
s
.39844 .08339 m
.40097 .08648 L
s
.42817 .0718 m
.43068 .07491 L
s
.48846 .0483 m
.49091 .05146 L
s
.51902 .03639 m
.52144 .03958 L
s
.54986 .02437 m
.55225 .02758 L
s
.58099 .01224 m
.58335 .01547 L
s
.25 Mabswid
.61241 0 m
.97291 .505 L
s
.65208 .05558 m
.64586 .05794 L
s
[(0)] .66454 .05085 -1 .37928 Mshowa
.79537 .2563 m
.78907 .25846 L
s
[(2)] .80797 .25198 -1 .3426 Mshowa
.91799 .42808 m
.91164 .43006 L
s
[(4)] .93071 .4241 -1 .31239 Mshowa
.125 Mabswid
.69012 .10886 m
.68637 .11025 L
s
.72662 .16 m
.72286 .16135 L
s
.76168 .2091 m
.75791 .21042 L
s
.82778 .3017 m
.82399 .30297 L
s
.85897 .3454 m
.85518 .34664 L
s
.88903 .3875 m
.88522 .38871 L
s
.94594 .46722 m
.94211 .46839 L
s
.25 Mabswid
.03495 .22504 m
0 .48612 L
s
.03495 .22504 m
.04116 .22262 L
s
[(-1)] .02254 .22988 1 -0.38971 Mshowa
.02665 .28704 m
.03288 .28468 L
s
[(-0.5)] .0142 .29178 1 -0.38021 Mshowa
.01807 .35115 m
.02431 .34884 L
s
[(0)] .00558 .35578 1 -0.37036 Mshowa
.00919 .41747 m
.01546 .41521 L
s
[(0.5)] -0.00334 .42198 1 -0.36014 Mshowa
0 .48612 m
.00629 .48392 L
s
[(1)] -0.01257 .49051 1 -0.34953 Mshowa
.125 Mabswid
.03331 .23728 m
.03704 .23583 L
s
.03166 .2496 m
.03539 .24816 L
s
.03 .262 m
.03373 .26056 L
s
.02833 .27448 m
.03207 .27305 L
s
.02496 .29969 m
.0287 .29828 L
s
.02325 .31243 m
.02699 .31102 L
s
.02154 .32525 m
.02528 .32385 L
s
.01981 .33816 m
.02355 .33676 L
s
.01632 .36423 m
.02007 .36285 L
s
.01455 .37741 m
.01831 .37603 L
s
.01278 .39067 m
.01653 .3893 L
s
.01099 .40402 m
.01475 .40266 L
s
.00738 .43101 m
.01114 .42966 L
s
.00555 .44464 m
.00932 .4433 L
s
.00371 .45837 m
.00748 .45704 L
s
.00186 .4722 m
.00563 .47087 L
s
.25 Mabswid
.03495 .22504 m
0 .48612 L
s
0 .48612 m
.46953 .89104 L
s
.46953 .89104 m
.47294 .65459 L
s
.47294 .65459 m
.03495 .22504 L
s
.61241 0 m
.97291 .505 L
s
.97291 .505 m
1 .75117 L
s
1 .75117 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.03495 .22504 m
0 .48612 L
s
0 .48612 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.61241 0 m
.03495 .22504 L
s
.47294 .65459 m
.97291 .505 L
s
.97291 .505 m
1 .75117 L
s
1 .75117 m
.46953 .89104 L
s
.46953 .89104 m
.47294 .65459 L
s
0 0 m
1 0 L
1 .89104 L
0 .89104 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.37281 .47439 m
.38706 .46968 L
s
1 0 .6 r
.36476 .45233 m
.37899 .44757 L
s
.8 0 1 r
.35674 .4303 m
.37096 .42548 L
s
.2 0 1 r
.34871 .40826 m
.36293 .40339 L
s
1 0 0 r
.38706 .46968 m
.40137 .46495 L
s
0 .4 1 r
.34069 .38619 m
.35489 .38126 L
s
1 0 .6 r
.37899 .44757 m
.39328 .44278 L
s
0 1 1 r
.33265 .36409 m
.34684 .35911 L
s
.8 0 1 r
.37096 .42548 m
.38524 .42064 L
s
0 1 .4 r
.3246 .34196 m
.33879 .33694 L
s
.2 0 1 r
.36293 .40339 m
.3772 .39849 L
s
1 0 0 r
.40137 .46495 m
.41573 .4602 L
s
.2 1 0 r
.31654 .3198 m
.33072 .31473 L
s
0 .4 1 r
.35489 .38126 m
.36915 .37632 L
s
1 0 .6 r
.39328 .44278 m
.40763 .43797 L
s
.8 1 0 r
.30847 .29762 m
.32264 .29249 L
s
0 1 1 r
.34684 .35911 m
.3611 .35412 L
s
.8 0 1 r
.38524 .42064 m
.39958 .41578 L
s
1 .6 0 r
.30039 .2754 m
.31455 .27022 L
s
0 1 .4 r
.33879 .33694 m
.35304 .33189 L
s
.2 0 1 r
.3772 .39849 m
.39153 .39358 L
s
1 0 0 r
.41573 .4602 m
.43016 .45542 L
s
.2 1 0 r
.33072 .31473 m
.34496 .30963 L
s
0 .4 1 r
.36915 .37632 m
.38348 .37135 L
s
1 0 .6 r
.40763 .43797 m
.42205 .43314 L
s
.8 1 0 r
.32264 .29249 m
.33687 .28733 L
s
0 1 1 r
.3611 .35412 m
.37542 .3491 L
s
.8 0 1 r
.39958 .41578 m
.41399 .4109 L
s
1 .6 0 r
.31455 .27022 m
.32878 .26501 L
s
0 1 .4 r
.35304 .33189 m
.36735 .32682 L
s
.2 0 1 r
.39153 .39358 m
.40593 .38864 L
s
1 0 0 r
.43016 .45542 m
.44465 .45062 L
s
.2 1 0 r
.34496 .30963 m
.35926 .3045 L
s
0 .4 1 r
.38348 .37135 m
.39787 .36637 L
s
1 0 .6 r
.42205 .43314 m
.43653 .42829 L
s
.8 1 0 r
.33687 .28733 m
.35117 .28216 L
s
0 1 1 r
.37542 .3491 m
.3898 .34406 L
s
.8 0 1 r
.41399 .4109 m
.42846 .40599 L
s
1 .6 0 r
.32878 .26501 m
.34306 .25978 L
s
0 1 .4 r
.36735 .32682 m
.38172 .32172 L
s
.2 0 1 r
.40593 .38864 m
.4204 .38369 L
s
1 0 0 r
.44465 .45062 m
.4592 .44579 L
s
.2 1 0 r
.35926 .3045 m
.37363 .29936 L
s
0 .4 1 r
.39787 .36637 m
.41233 .36136 L
s
1 0 .6 r
.43653 .42829 m
.45107 .42341 L
s
.8 1 0 r
.35117 .28216 m
.36553 .27696 L
s
0 1 1 r
.3898 .34406 m
.40425 .339 L
s
.8 0 1 r
.42846 .40599 m
.44299 .40107 L
s
1 .6 0 r
.34306 .25978 m
.35741 .25453 L
s
0 1 .4 r
.38172 .32172 m
.39616 .31661 L
s
.2 0 1 r
.4204 .38369 m
.43492 .37871 L
s
1 0 0 r
.4592 .44579 m
.47381 .44094 L
s
.2 1 0 r
.37363 .29936 m
.38806 .29419 L
s
0 .4 1 r
.41233 .36136 m
.42685 .35633 L
s
1 0 .6 r
.45107 .42341 m
.46568 .41851 L
s
.8 1 0 r
.36553 .27696 m
.37995 .27174 L
s
0 1 1 r
.40425 .339 m
.41876 .33391 L
s
.8 0 1 r
.44299 .40107 m
.45759 .39612 L
s
1 .6 0 r
.35741 .25453 m
.37183 .24926 L
s
0 1 .4 r
.39616 .31661 m
.41066 .31147 L
s
.2 0 1 r
.43492 .37871 m
.44951 .37371 L
s
1 0 0 r
.47381 .44094 m
.48849 .43607 L
s
.2 1 0 r
.38806 .29419 m
.40256 .289 L
s
0 .4 1 r
.42685 .35633 m
.44143 .35127 L
s
1 0 .6 r
.46568 .41851 m
.48035 .4136 L
s
.8 1 0 r
.37995 .27174 m
.39444 .2665 L
s
0 1 1 r
.41876 .33391 m
.43333 .32881 L
s
.8 0 1 r
.45759 .39612 m
.47225 .39115 L
s
1 .6 0 r
.37183 .24926 m
.38631 .24396 L
s
0 1 .4 r
.41066 .31147 m
.42523 .30631 L
s
.2 0 1 r
.44951 .37371 m
.46417 .36868 L
s
1 0 0 r
.48849 .43607 m
.50322 .43117 L
s
.2 1 0 r
.40256 .289 m
.41711 .28379 L
s
0 .4 1 r
.44143 .35127 m
.45608 .3462 L
s
1 0 .6 r
.48035 .4136 m
.49508 .40865 L
s
.8 1 0 r
.39444 .2665 m
.40899 .26123 L
s
0 1 1 r
.43333 .32881 m
.44797 .32368 L
s
.8 0 1 r
.47225 .39115 m
.48698 .38615 L
s
1 .6 0 r
.38631 .24396 m
.40085 .23864 L
s
0 1 .4 r
.42523 .30631 m
.43986 .30113 L
s
.2 0 1 r
.46417 .36868 m
.47889 .36364 L
s
.2 1 0 r
.41711 .28379 m
.43174 .27855 L
s
0 .4 1 r
.45608 .3462 m
.47079 .3411 L
s
.8 1 0 r
.40899 .26123 m
.4236 .25594 L
s
0 1 1 r
.44797 .32368 m
.46268 .31852 L
s
1 .6 0 r
.40085 .23864 m
.41546 .2333 L
s
0 1 .4 r
.43986 .30113 m
.45456 .29592 L
s
.2 1 0 r
.43174 .27855 m
.44643 .27329 L
s
.8 1 0 r
.4236 .25594 m
.43828 .25062 L
s
1 .6 0 r
.41546 .2333 m
.43013 .22793 L
s
0 g
.25 Mabswid
.61241 0 m
.97291 .505 L
s
.97291 .505 m
1 .75117 L
s
1 .75117 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.03495 .22504 m
0 .48612 L
s
0 .48612 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.61241 0 m
.03495 .22504 L
s
.03495 .22504 m
.61241 0 L
s
.03495 .22504 m
.03971 .2297 L
s
[(-2)] .02544 .21571 1 .98073 Mshowa
.16988 .17246 m
.17445 .1773 L
s
[(-1)] .16074 .16277 .9432 1 Mshowa
.31082 .11753 m
.31518 .12256 L
s
[(0)] .3021 .10747 .86675 1 Mshowa
.45818 .0601 m
.46231 .06533 L
s
[(1)] .44992 .04965 .7903 1 Mshowa
.61241 0 m
.61628 .00542 L
s
[(2)] .60467 -0.01084 .71386 1 Mshowa
.125 Mabswid
.06148 .2147 m
.06431 .21752 L
s
.08823 .20428 m
.09104 .20712 L
s
.11521 .19376 m
.118 .19663 L
s
.14243 .18316 m
.14519 .18604 L
s
.19758 .16166 m
.20029 .16459 L
s
.22551 .15078 m
.22821 .15373 L
s
.2537 .13979 m
.25637 .14277 L
s
.28213 .12871 m
.28478 .13171 L
s
.33977 .10625 m
.34236 .10929 L
s
.36897 .09487 m
.37153 .09794 L
s
.39844 .08339 m
.40097 .08648 L
s
.42817 .0718 m
.43068 .07491 L
s
.48846 .0483 m
.49091 .05146 L
s
.51902 .03639 m
.52144 .03958 L
s
.54986 .02437 m
.55225 .02758 L
s
.58099 .01224 m
.58335 .01547 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 256.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001@2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00gOooool5o`0008Kooooo003Mooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0Q_ooool00=ko
oooo00?oV9RHob4Q8Oo^k^h0Qoooool00=oooooo00?oV9RHob4Q8Oo^k^h0Q_ooool00>3ooooo00?o
MgMgofIVI_ooool0QOooool00>7ooooo00?o0000ooooooooool0Q?ooool00=gooooo00Go0000okZj
^_ooooooV9RHoa0@4026ooooo`00gOooool01OnHV9So410@o`000?lQ8B7oc<c<08Kooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003Tooooo`;o0000P_ooool0
0>7ooooo0ol000000ooooooo0000ooooo`21ooooo`00goooool2o`0000Cooooo0_l00021ooooo`00
g?ooool3o`0000Kooooo00?o0000ooooool00000P?ooool00=[ooooo0_l00009ooooo`03o`000?oo
oooo0000083ooooo003Gooooo`?o000000?oooooo`000?ooool02?ooool01?l0003oooooooooool0
001oooooo`00e?ooool3o`0000Cooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooo
oooo000007kooooo003Booooo`;o00004Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo07_ooooo002Zooooo`Co000000?o410@ooooooooool07_ooool3o`0001?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1kooooo`00[?ooool00ol0003oooooooooo`0Nooooo`;o
000000?oooooo`000?ooool04oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07[o
oooo002/ooooo`03o`000?oooooooooo01_ooooo0ol00004ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`1iooooo`00[?ooool00ol0003ooooooooo
o`0Iooooo`;o00006oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo07Wooooo002/
ooooo`03o`000?oooooooooo01Kooooo0ol0000Mooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool02?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^06_ooooo002/ooooo`03o`000?oooooo
oooo01Cooooo0_l000000ooooooo0000ooooo`0Mooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01oooool01OmgMgOoV9RHoooooonHV9SoMgMg06_ooooo002/ooooo`03o`000?oooooo
oooo017ooooo0ol00004ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`06ooooo`05oa0@4?ooooooooooooooool@4100Joooool00:[ooooo00?oEEEE
ofIVI_l000004Oooool2o`0002Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06
ooooo`05o`000?ooooooooooooooool00000Joooool00;_ooooo0ol0000Wooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000006_ooooo002i
ooooo`;o000000?oooooo`000?ooool09oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Cooooo00Go410@oooooooooooooooooa0@401[ooooo`00]_ooool3o`0000Cooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`1[ooooo`00/oooool3o`0002oooooo00?o0000ooooooooool02Oooool2
o`0000Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1[ooooo`00/Oooool2o`0003;ooooo00?o0000
ooooooooool02?ooool01?l0003oooooooooool0001dooooo`00[_ooool3o`000003ooooool0003o
oooo037ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1aooooo`00[?ooool2o`00
00Gooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
077ooooo002Yooooo`?o0000>_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo073o
oooo002Wooooo`;o0000?Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo06oooooo
002Tooooo`?o000000?oooooo`000?ooool0??ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo06oooooo002Rooooo`;o0000@_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo06kooooo001gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08oooool3o`0004Cooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1]ooooo`00Moooool01OmgMgOoV9RHoooooonHV9So
MgMg027ooooo0_l00017ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0K?ooool0
07Oooooo00Go410@oooooooooooooooooa0@400Nooooo`?o00000_ooool00ol0003oooooooooo`14
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0K?ooool007Oooooo00Go0000oooo
ooooooooooooo`00000Looooo`;o0000C?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo06_ooooo001gooooo`05o`000?ooooooooooooooool000006Oooool3o`0004kooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`1Zooooo`00Moooool01Ol@413ooooooooooooooooo
410@01Kooooo0ol0001Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0J_ooool0
07Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Dooooo`;o00000oooool00ol0003oooooooooo`1>
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0JOooool007Oooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Aooooo`?o0000E_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo06Sooooo002;ooooo`;o0000FOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
06Sooooo0028ooooo`?o0000Foooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo06Oo
oooo0026ooooo`;o00000oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo01Gooooo
0_l0001Xooooo`00Poooool3o`00063ooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`1Uooooo`00POooool2o`0006?ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1U
ooooo`00O_ooool4o`0006Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`1Toooo
o`00O?ooool2o`0000Cooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo06?ooooo001iooooo`?o0000J_ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo06?ooooo001gooooo`;o0000KOooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo06;ooooo001dooooo`?o000000?oooooo`000?ooool0K?ooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo067ooooo001aooooo`?o0000L_ooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo063ooooo0019ooooo`Co000000?o410@ooooooooool07oooool2o`0007Go
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1Pooooo`00Boooool00ol0003ooooo
ooooo`0Nooooo`?o0000Moooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo05oooooo
0010ooooo`Ko00001Oooool00ol0003oooooooooo`0Looooo`;o00000_ooool00ol0003ooooooooo
o`1eooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0G_ooool004_ooooo00?o0000
ooooooooool06Oooool3o`0007cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1N
ooooo`00Boooool00ol0003oooooooooo`0Gooooo`;o0000Ooooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo05gooooo001;ooooo`03o`000?oooooooooo01Cooooo0ol00021ooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0G?ooool004_ooooo00?o0000ooooooooool0
4_ooool2o`0000?ooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo05_ooooo0019ooooo`03oeEEEOmVIVKo0000017ooooo0ol00026ooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool0Foooool005_ooooo0_l00029ooooo`03o`000?oooooo
oooo027ooooo0_l0001Looooo`00F?ooool3o`000003ooooool0003ooooo08Sooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`1Iooooo`00E_ooool2o`0008kooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`1Iooooo`00Doooool3o`00093ooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`1Hooooo`00D?ooool3o`0009?ooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1Gooooo`00C_ooool2o`0000;ooooo00?o0000ooooooooool0TOooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo05Kooooo001;ooooo`?o00001Oooool00ol0
003oooooooooo`2@ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0E_ooool004Wo
oooo0_l0002Kooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0EOooool004Kooooo
1?l0002Looooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0E?ooool004Cooooo0_l0
002Pooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0E?ooool001[ooooo1Ol0000R
ooooo`?o0000X_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo05?ooooo000Joooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@08?ooool2o`000:Gooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`1Booooo`004_ooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h07_ooool3o`00
0003ooooool0003ooooo0:Cooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`1Aoooo
o`007?ooool00onHV9So8B4Qonk^kP0Kooooo`;o0000Z_ooool00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo057ooooo000Mooooo`03ogMgMomVIVKooooo01Oooooo0ol0002]ooooo`03o`00
0?oooooooooo02_ooooo00?o0000ooooooooool0D?ooool001kooooo00?o0000ooooooooool05?oo
ool2o`000;3ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`1?ooooo`006_ooool0
1Ol0003o^[ZjoooooonHV9So410@01?ooooo0ol00002ooooo`03o`000?oooooooooo0:gooooo00?o
0000ooooooooool0;?ooool2o`00053ooooo000Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`04?oo
ool3o`000;Gooooo00?o0000ooooooooool0;?ooool2o`00053ooooo000]ooooo`;o0000^?ooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo04gooooo000Zooooo`?o000000?oooooo`00
0?ooool0]oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo04gooooo000Xooooo`;o
0000_Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo04cooooo000Uooooo`?o0000
_oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo04_ooooo000Tooooo`;o0000POoo
ool2oonI03kooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`1:ooooo`006_ooool4
o`000003oa0@4?oooooooooo00?ooooo00?o0000ooooool00000OOooool3oonI043ooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`1:ooooo`007?ooool00ol0003oooooooooo`05oooo
o`04o`000?ooooooooooo`0007[ooooo0_ooV@13ooooo`03o`000?oooooooooo03;ooooo00?o0000
ooooooooool0BOooool0017ooooo1_l00005ooooo`03o`000?oooooooooo00Gooooo0_l00002oooo
o`03o`000?oooooooooo07Gooooo0_ooV@15ooooo`03o`000?oooooooooo03?ooooo00?o0000oooo
ooooool0B?ooool001cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo07;ooooo0_ooV@17ooooo`03o`000?oooooooooo03?ooooo00?o0000oooooooo
ool01oooool5o`0003cooooo000Looooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`1^ooooo`?ooiT0BOooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo00Kooooo00GoV9RHob4Q8Oo^k^koooooodA4A00looooo`007?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Joooool2oonI04cooooo
00?o0000ooooooooool0=Oooool00ol0003oooooooooo`06ooooo`03oiRHV?lQ8B7ok^k^03gooooo
000Looooo`03o`000?oooooooooo00Cooooo0ol00006ooooo`03o`000?oooooooooo06Oooooo0ooo
V@1>ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool01_ooool00onHV9So8B4Qonk^
kP0looooo`006_ooool00omEEEGoIVIVo`000006ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool0Hoooool3oonI01Cooooo0_o<o`0kooooo`03o`000?oooooooooo03Kooooo00?o0000
ooooooooool01oooool00omgMgOoIVIVooooo`0kooooo`008oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo05kooooo1?ooV@0Dooooo`?oc?l0?Oooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0>_ooool002?ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`1Jooooo`?ooiT05_ooool2olco043ooooo00?o0000oooooooo
ool0=oooool2o`0000Cooooo00Go0000okZj^_ooooooV9RHoa0@400looooo`008oooool2o`0000_o
oooo00?o0000ooooooooool0Eoooool2oonI01Kooooo0oo<o`12ooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooool000001?ooool01OnHV9So410@o`000?lQ8B7oc<c<03cooooo000Sooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0Doooool3oonI01Gooooo0oo<o`15ooooo`03
o`000?oooooooooo03Wooooo00?o0000ooooooooool0@_ooool002;ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`1@ooooo`;ooiT05?ooool4olco04Sooooo00?o0000ooooooooool0
>_ooool00ol0003oooooooooo`11ooooo`008_ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo04gooooo0_ooV@0Dooooo`;oc?l0Boooool2o`0003gooooo00?o0000ooooooooool0@?oo
ool002;ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`19ooooo`?ooiT05?ooool2
olco04[ooooo0ol000000ooooooo0000ooooo`0looooo`03o`000?oooooooooo043ooooo000Roooo
o`;o00004Oooool00ol0003oooooooooo`15ooooo`?ooiT05?ooool3olco01Gooooo0olco`0aoooo
o`?o00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo03oooooo000Rooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool0FOooool2olco01Cooooo1?lco`0aooooo`?o
00002Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo03kooooo000Rooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool0EOooool3olco01?ooooo0olco`0booooo`?o0000
3Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03kooooo000Rooooo`?o00004ooo
ool00ol0003oooooooooo`1Aooooo`?oc?l05?ooool2oc?o03;ooooo0ol0000Aooooo`03o`000?oo
oooooooo03[ooooo00?o0000ooooooooool0?Oooool002;ooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`1<ooooo`Coc?l05?ooool3oc?o03;ooooo0_l0000Dooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool0??ooool0027ooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`18ooooo`?oc?l05_ooool2oc?o03;ooooo0ol0000Gooooo`03o`000?oooooooooo
03_ooooo00?o0000ooooooooool0>oooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Cooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`15ooooo`;oc?l05_ooool3oc?o037ooooo0ol0000Kooooo`03o`000?oooooo
oooo03[ooooo00?o0000ooooooooool0>oooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool0@_ooool2olco01Gooooo0olco`0Dooooo`;o0?mV6oooool3o`0001oooooo00?o0000
ooooooooool0>_ooool00ol0003oooooooooo`0jooooo`001Ol00002ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`02ooooo`;o00006_ooool00ol0003oooooooooo`10
ooooo`03olco0?oooooooooo017ooooo1?lco`0Eooooo`;o0?mV6_ooool3o`0002?ooooo00?o0000
ooooooooool0>_ooool00ol0003oooooooooo`0iooooo`001oooool01Ol0003ooooooooooooooooo
000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo057ooooo0_lco`0Gooooo`;o0?mV6_ooool2o`0002Kooooo00?o0000ooooooooool0>_ooool2
o`0003[ooooo0007ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1>ooooo`;o<ol05_oo
ool3o`3oIQWooooo0ol0000Yooooo`03o`000?oooooooooo03Wooooo0_l0000jooooo`001oooool0
1Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo04[ooooo0olco`0Eooooo`?o0?mV6Oooool3o`0002gooooo00?o
0000ooooooooool0>_ooool00ol0003oooooooooo`0gooooo`001oooool01OmgMgOoV9RHoooooonH
V9SoMgMg00cooooo00?o0000ooooooooool01_ooool2o`0001kooooo00?o0000ooooooooool0A_oo
ool3oc?o01Cooooo1?l0ofHIooooo`?o0000<Oooool00ol0003oooooooooo`0iooooo`03o`000?oo
oooooooo03Oooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Cooooo0_l0
000Pooooo`03o`000?oooooooooo047ooooo1?lco`0Dooooo`?o0?mV6_ooool3o`0003Gooooo00?o
0000ooooooooool0>Oooool00ol0003oooooooooo`0fooooo`008?ooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo03gooooo0olco`0Fooooo`;o0?mV6_ooool3o`0003Sooooo00?o0000
ooooooooool0>_ooool00ol0003oooooooooo`0eooooo`008?ooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo03_ooooo00?o<ol0ooooooooool05?ooool3o`3oIQGooooo0ol0ool2oooo
o`;o0000??ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03Cooooo000Pooooo`;o
00008oooool00ol0003oooooooooo`1>ooooo`?o0?mV5?ooool4o`3oo`;ooooo0ol0000oooooo`03
o`000?oooooooooo03Wooooo00?o0000ooooooooool0=?ooool0023ooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`19ooooo`Co0?mV5?ooool3o`3oo`?ooooo0ol00013ooooo`03o`00
0?oooooooooo03Wooooo00?o0000ooooooooool0<oooool0023ooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`16ooooo`;o0?mV5_ooool2o`3oo`?ooooo0ol00017ooooo`03o`000?oo
oooooooo03Wooooo00?o0000ooooooooool0<_ooool0023ooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`13ooooo`;o0?mV5_ooool2o`3oo`;ooooo0ol0001:ooooo`03o`000?oooooo
oooo03Wooooo00?o0000ooooooooool0<_ooool0023ooooo00?o0000ooooooooool09_ooool2o`00
043ooooo0ol0ofHFooooo`;o0?oo0_ooool2o`0004kooooo00?o0000ooooooooool0>Oooool00ol0
003oooooooooo`0aooooo`007oooool3o`0002Wooooo00?o0000ooooooooool0>oooool2o`3oIQKo
oooo0ol0ool01?oooooo0000o`000?l0001Aooooo`03o`000?oooooooooo03Wooooo00?o0000oooo
ooooool0<?ooool001oooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0gooooo`?o
0?mV5Oooool3o`3oo`04ooooool0003o0000o`00013ooooo0_l0I_m3ooooo`03o`000?oooooooooo
03Wooooo00?o0000ooooooooool0;oooool001oooooo00?o0000ooooooooool0:oooool00ol0003o
ooooooooo`0eooooo`03o`3oI_oooooooooo01;ooooo1?l0ool01?oooooo0000o`000?l0000@oooo
o`?o06KoAOooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02oooooo000Oooooo`03
o`000?oooooooooo02cooooo00?o0000ooooooooool0A_ooool3o`3oo`;ooooo0ol0000Aooooo`;o
06KoBOooool00ol0003oooooooooo`0hooooo`;o0000<?ooool001oooooo0ol0000]ooooo`03o`00
0?oooooooooo04?ooooo0_l0ool2ooooo`?o00004Oooool3o`1Vodcooooo00?o0000ooooooooool0
>Oooool00ol0003oooooooooo`0]ooooo`007oooool00ol0003oooooooooo`0^ooooo`03o`000?oo
oooooooo03oooooo0ol0ool2ooooo`;o00004Oooool3o`1Voe3ooooo00?o0000ooooooooool0>?oo
ool00ol0003oooooooooo`0]ooooo`005?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o
0000ooooooooool0;oooool00ol0003oooooooooo`0kooooo`?o0?oo0_ooool3o`0000oooooo1?l0
I_mDooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0;?ooool001Cooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0=ooo
ool3o`3oo`;ooooo0ol0000?ooooo`?o06KoF?ooool00ol0003oooooooooo`0iooooo`03o`000?oo
oooooooo02_ooooo000Dooooo`05oa0@4?ooooooooooooooool@41001Oooool2o`0003?ooooo00?o
0000ooooooooool0<oooool3o`3oo`;ooooo0ol0000@ooooo`;o06KoG?ooool00ol0003ooooooooo
o`0iooooo`03o`000?oooooooooo02[ooooo000Dooooo`05o`000?ooooooooooooooool000001Ooo
ool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo037ooooo00?o0?ooooooooooool00ol0
000Aooooo`;o06Ko5_ooool3oc<0odKooooo00?o0000ooooooooool0>?ooool00ol0003ooooooooo
o`0Zooooo`005?ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0=?oo
ool00ol0003oooooooooo`0`ooooo`?o00004Oooool3o`1VoaCooooo1?lc0?m:ooooo`03o`000?oo
oooooooo03Sooooo00?o0000ooooooooool0:Oooool001Cooooo00Go410@oooooooooooooooooa0@
4005ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0;Oooool2o`00013ooooo1?l0
I_lDooooo`?o<`3oCoooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02Sooooo000D
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`0fooooo`03o`000?oo
oooooooo02Wooooo0ol0000?ooooo`?o06Ko5_ooool2oc<0oe;ooooo00?o0000ooooooooool0>?oo
ool00ol0003oooooooooo`0Xooooo`005?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_l0
000hooooo`03o`000?oooooooooo02Gooooo0ol0000@ooooo`;o06Ko5_ooool3oc<0oeGooooo00?o
0000ooooooooool0>?ooool00ol0003oooooooooo`0Wooooo`007_ooool00ol0003oooooooooo`0h
ooooo`03o`000?oooooooooo027ooooo0ol0000@ooooo`?o06Ko5Oooool3oc<0oeWooooo00?o0000
ooooooooool0>?ooool00ol0003oooooooooo`0Vooooo`007Oooool00ol0003oooooooooo`0joooo
o`03o`000?oooooooooo01gooooo0ol0000@ooooo`?o06Ko5?ooool4oc<0oegooooo00?o0000oooo
ooooool0>?ooool00ol0003oooooooooo`0Uooooo`007Oooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo01[ooooo0_l0000@ooooo`?o06Ko5?ooool3oc<0oaKooooo0_o<0?m:ooooo`03
o`000?oooooooooo03Oooooo00?o0000ooooooooool09Oooool001gooooo0_l0000mooooo`03o`00
0?oooooooooo01Kooooo0ol0000Wooooo`;o<`3o5_ooool3ol`0odcooooo00?o0000ooooooooool0
=oooool2o`0002Kooooo000Mooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool04_oo
ool3o`0002Oooooo0olc0?lFooooo`;oc03oD?ooool00ol0003oooooooooo`0hooooo`03o`000?oo
oooooooo02?ooooo000Mooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool03_ooool3
o`0002Oooooo0olc0?lFooooo`?oc03oDoooool00ol0003oooooooooo`0gooooo`03o`000?oooooo
oooo02?ooooo000Mooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool02_ooool3o`00
02Oooooo0olc0?lFooooo`?oc03oEoooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo
02;ooooo000Mooooo`03o`000?oooooooooo043ooooo00?o0000ooooooooool01_ooool3o`0002Oo
oooo0olc0?lFooooo`?oc03oFoooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo027o
oooo000Looooo`?o0000@_ooool00ol0003oooooooooo`03ooooo`;o0000:?ooool2oc<0oaKooooo
0oo<0?mNooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool08?ooool001cooooo00?o
0000ooooooooool0@oooool00ol0003oooooo`000002o`0002Oooooo0olc0?lFooooo`;oc03oH_oo
ool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo023ooooo000Looooo`03o`000?oooooo
oooo04;ooooo0ol0000Yooooo`03oc<0oooooooooooo01Cooooo0oo<0?lEooooo`?oo`2ICOooool0
0ol0003oooooooooo`0gooooo`03o`000?oooooooooo00Wooooo0_l000000ol@413oooooooooo`0A
ooooo`007?ooool00ol0003oooooooooo`0oooooo`?o00000oooool00ol0003oooooooooo`0joooo
o`?oc03o5?ooool4ool0VE7ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo01;ooooo000Looooo`?o0000??ooool3o`0000Oooooo00?o0000oooooooo
ool0=Oooool4ol`0oaCooooo0ooo09UFooooo`03o`000?oooooooooo03Kooooo00?o0000oooooooo
ool01_ooool5o`0001?ooooo000Looooo`03o`000?oooooooooo03Wooooo0ol0000;ooooo`03o`00
0?oooooooooo037ooooo0oo<0?lFooooo`;oo`2IFOooool00ol0003oooooooooo`0gooooo`03o`00
0?oooooooooo00Gooooo00CoA4A4omgMgOoooooo00005?ooool00006ooooooo^k^ko<S8bo`000?lb
<S;ok^k^1Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo03Oooooo0_l0000?ooooo`03o`000?oooooooooo02gooooo0oo<0?lFooooo`?oo`2IG?ooool0
0ol0003oooooooooo`0gooooo`03o`000?oooooooooo00Cooooo00CogMgMoeEEEOoooooo00005?oo
ool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool0
1?ooool00ol0003oooooooooo`0dooooo`?o00004_ooool00ol0003oooooooooo`0Yooooo`?oc03o
5_ooool3ool0VF3ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`05ooooo`03ogMg
Moo<c<co000001Cooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00kooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0aooooo`?o00005_ooool00ol0003ooooooooo
o`0Uooooo`?oc03o5Oooool4ool0VFCooooo00?o0000ooooooooool0=_ooool2o`0000Gooooo00?o
k^k^odA4A?l000005?ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool03Oooool0
0omgMgOo<S8booooo`03ooooo`;o0000<?ooool3o`0001[ooooo00?o0000ooooooooool08oooool0
0oo<0?ooooooooooo`0Dooooo`;oo`2I5oooool2ool0053ooooo00?o0000ooooooooool0=?ooool0
0ol0003oooooo`000006ooooo`03ogMgMol0003ooooo01?ooooo00000ooooooo0000ooooo`02oooo
o`03o`000?oooooooooo00[ooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooo
oooo02cooooo0ol0000Nooooo`03o`000?oooooooooo03Oooooo0_oo09TFooooo`?oo`00D_ooool0
0ol0003oooooooooo`0gooooo`03o`000?oooooooooo01Wooooo00000ooooooo410@ooooo`02oooo
o`03oa0@4?oooooooooo00[ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Zoooo
o`;o00008_ooool00ol0003oooooooooo`0cooooo`?oo`2I5_ooool2ool005Kooooo00?o0000oooo
ooooool0=_ooool00ol0003oooooooooo`0Iooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL<
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool09oooool3o`0002Gooooo0_l0000`
ooooo`?oo`2I5_ooool3ool005Wooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0H
ooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h<ooooo`Co00001Oooool2o`0002Gooooo0ol0
000Zooooo`03o`000?oooooooooo02Wooooo1?oo09TFooooo`?oo`00GOooool00ol0003ooooooooo
o`0fooooo`03o`000?oooooooooo01Oooooo000Kooooo`03o`000?oooooooooo027ooooo0ol0000^
ooooo`03o`000?oooooooooo02Gooooo0ooo09TFooooo`Coo`00HOooool00ol0003oooooooooo`0e
ooooo`03o`000?oooooooooo01Oooooo000Kooooo`03o`000?oooooooooo01kooooo0ol0000boooo
o`03o`000?oooooooooo027ooooo0ooo09TFooooo`?oo`00IOooool00ol0003oooooooooo`0foooo
o`03o`000?oooooooooo01Kooooo000Kooooo`03o`000?oooooooooo01_ooooo0ol0000fooooo`03
o`000?oooooooooo01gooooo0ooo09TFooooo`?oo`00JOooool00ol0003oooooooooo`0fooooo`03
o`000?oooooooooo01Gooooo000Jooooo`03o`000?oooooooooo01[ooooo0_l0000jooooo`03o`00
0?oooooooooo037ooooo1?oo001]ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0
5?ooool001[ooooo0_l0000Hooooo`?o0000?Oooool00ol0003oooooooooo`0^ooooo`;oo`00L_oo
ool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo01Cooooo000Jooooo`03o`000?oooooo
oooo01Cooooo0ol00011ooooo`03o`000?oooooooooo02_ooooo0_oo001dooooo`03o`000?oooooo
oooo03Kooooo00?o0000ooooooooool04oooool001[ooooo00?o0000ooooooooool04Oooool3o`00
04Gooooo00?o0000ooooooooool09oooool3ool007Oooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`0Booooo`006_ooool00ol0003oooooooooo`0>ooooo`?o0000BOooool00ol0003o
ooooooooo`0Sooooo`?oo`00Noooool00ol0003oooooooooo`0eooooo`;o00004oooool001[ooooo
00?o0000ooooooooool03?ooool2o`0004gooooo00?o0000ooooooooool07_ooool4ool007oooooo
00?o0000ooooooooool0=?ooool2o`0001?ooooo000Iooooo`?o00002_ooool3o`00053ooooo00?o
0000ooooooooool06_ooool3ool008Cooooo00?o0000ooooooooool0=Oooool00ol0003ooooooooo
o`0@ooooo`006_ooool00ol0003oooooooooo`06ooooo`?o0000E?ooool00ol0003oooooooooo`0H
ooooo`03ool00?oooooooooo08Gooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0?
ooooo`006Oooool00ol0003oooooooooo`04ooooo`?o0000F?ooool00ol0003oooooooooo`2Poooo
o`03o`000?oooooooooo03Gooooo00?o0000ooooooooool03oooool001Wooooo00Co0000oooooooo
oooooooo0ol0001Looooo`03o`000?oooooooooo0:3ooooo00?o0000ooooooooool0=Oooool00ol0
003oooooooooo`0>ooooo`006Oooool4o`00063ooooo00?o0000ooooooooool0X?ooool00ol0003o
ooooooooo`0eooooo`03o`000?oooooooooo00gooooo000Iooooo`;o0000Hoooool00ol0003ooooo
ooooo`2Pooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool03Oooool000oooooo1?l0
00000ol@413oooooooooo`05ooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0Wooo
ool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00cooooo000Aooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`2Oooooo`03o`000?oooooo
oooo03Gooooo00?o0000ooooooooool02oooool0017ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`1Qooooo`03o`000?oooooooooo09oooooo00?o0000ooooooooool0=Oooool00ol0
003oooooooooo`0:ooooo`004Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo067o
oooo00?o0000ooooooooool0Woooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00[o
oooo000Aooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0HOooool00ol0003ooooo
ooooo`2Oooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool02Oooool0017ooooo00?o
0000ooooooooool03?ooool2o`0006;ooooo00?o0000ooooooooool0W_ooool00ol0003ooooooooo
o`0cooooo`?o00002_ooool0017ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1P
ooooo`03o`000?oooooooooo09kooooo00?o0000ooooooooool0;oooool3o`0000;ooooo00?o0000
ooooooooool02?ooool000oooooo00?oEEEEofIVI_l000004Oooool00ol0003oooooooooo`1Poooo
o`03o`000?oooooooooo09kooooo00?o0000ooooooooool0:oooool3o`0000Gooooo00?o0000oooo
ooooool02?ooool002Cooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`2Nooooo`03
o`000?oooooooooo02Kooooo1?l00008ooooo`03o`000?oooooooooo00Sooooo000Uooooo`03o`00
0?oooooooooo063ooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`0Rooooo`?o0000
3?ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`1Pooooo`03o`000?oo
oooooooo09gooooo00?o0000ooooooooool07oooool3o`00013ooooo00?o0000ooooooooool01ooo
ool002Oooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`2Mooooo`03o`000?oooooo
oooo01[ooooo1?l0000Cooooo`03o`000?oooooooooo00Oooooo000Xooooo`;o0000HOooool00ol0
003oooooooooo`2Mooooo`03o`000?oooooooooo01Kooooo0ol0000Gooooo`03o`000?oooooooooo
00Oooooo000Zooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool0WOooool00ol0003o
ooooooooo`0Booooo`?o00006_ooool00ol0003oooooooooo`07ooooo`00:oooool00ol0003ooooo
ooooo`1Oooooo`03o`000?oooooooooo09gooooo00?o0000ooooooooool03Oooool4o`0001gooooo
00?o0000ooooooooool01oooool002cooooo00?o0000ooooooooool0Goooool00ol0003ooooooooo
o`2Looooo`03o`000?oooooooooo00[ooooo0ol0000Qooooo`03o`000?oooooooooo00Oooooo000]
ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool0W?ooool00ol0003oooooooooo`06
ooooo`?o00009?ooool00ol0003oooooooooo`07ooooo`00;_ooool00ol0003oooooooooo`1Ooooo
o`03o`000?oooooooooo09cooooo00Co0000oooooooooooooooo1?l0000Wooooo`03o`000?oooooo
oooo00Oooooo000_ooooo`;o0000H?ooool00ol0003oooooooooo`2Looooo`?o0000;?ooool00ol0
003oooooooooo`06ooooo`00<Oooool00ol0003oooooooooo`1Nooooo`;o0000VOooool3o`000003
ooooool0003ooooo02cooooo00?o0000ooooooooool01_ooool003;ooooo00?o0000ooooooooool0
Goooool00ol0003oooooooooo`2Cooooo`?o00001?ooool00ol0003oooooooooo`0[ooooo`03o`00
0?oooooooooo00Kooooo000cooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool0S_oo
ool4o`0000Sooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`06ooooo`00=?ooool0
0ol0003oooooooooo`1Oooooo`03o`000?oooooooooo08[ooooo0ol0000=ooooo`03o`000?oooooo
oooo02Wooooo00?o0000ooooooooool01_ooool003Gooooo00?o0000ooooooooool0Goooool00ol0
003oooooooooo`26ooooo`?o00004Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo
00Kooooo000fooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool0POooool4o`0001Go
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`06ooooo`00=oooool2o`00063ooooo
00?o0000ooooooooool0OOooool3o`0001Wooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`06ooooo`00>Oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo07Wooooo0ol0
000Mooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool01Oooool003[ooooo00?o0000
ooooooooool0G_ooool00ol0003oooooooooo`1dooooo`Co00008Oooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo00Gooooo000kooooo`03o`000?oooooooooo05kooooo00?o0000oooo
ooooool0L?ooool3o`0002Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`05oooo
o`00??ooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo06cooooo0ol0000Yooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool01Oooool003gooooo00?o0000ooooooooool0
G_ooool00ol0003oooooooooo`1Wooooo`Co0000;Oooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo00Gooooo000nooooo`;o0000Goooool00ol0003oooooooooo`1Sooooo`?o0000<_oo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Gooooo0010ooooo`03o`000?oooooo
oooo05gooooo00?o0000ooooooooool0Goooool3o`0003Kooooo00?o0000ooooooooool08_ooool0
0ol0003oooooooooo`05ooooo`00@Oooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo
05[ooooo1?l0000jooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool01Oooool004;o
oooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`1Fooooo`?o0000?_ooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo00Gooooo0013ooooo`03o`000?oooooooooo05gooooo
00?o0000ooooooooool0D_ooool3o`0004;ooooo00?o0000ooooooooool08Oooool00ol0003ooooo
ooooo`04ooooo`00A?ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo04gooooo1?l0
0016ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool01?ooool004Gooooo00?o0000
ooooooooool0GOooool00ol0003oooooooooo`19ooooo`?o0000Boooool00ol0003oooooooooo`0O
ooooo`03o`000?oooooooooo00Cooooo0016ooooo`;o0000G_ooool00ol0003oooooooooo`15oooo
o`?o0000Coooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Cooooo0018ooooo`03
o`000?oooooooooo05cooooo00?o0000ooooooooool0@?ooool4o`0005;ooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`04ooooo`00BOooool00ol0003oooooooooo`1Looooo`03o`00
0?oooooooooo03cooooo0ol0001Gooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
1?ooool004[ooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`0hooooo`?o0000Fooo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Cooooo001;ooooo`03o`000?oooooo
oooo05cooooo00?o0000ooooooooool0<oooool4o`0005oooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`04ooooo`00C?ooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo
02oooooo0ol0001Tooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool00oooool004go
oooo0_l0001Mooooo`03o`000?oooooooooo02_ooooo0ol0001Wooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool00oooool004oooooo00?o0000ooooooooool0Foooool00ol0003ooooo
ooooo`0Wooooo`?o0000Joooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00?ooooo
001@ooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool08_ooool4o`0006oooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`03ooooo`00DOooool00ol0003oooooooooo`1K
ooooo`03o`000?oooooooooo01kooooo0ol0001dooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool00oooool005;ooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`0Joooo
o`?o0000N?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00?ooooo001Cooooo`03
o`000?oooooooooo05_ooooo00?o0000ooooooooool05Oooool4o`0007_ooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`03ooooo`00E?ooool2o`0005cooooo00?o0000ooooooooool0
4Oooool3o`00083ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`03ooooo`00E_oo
ool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00gooooo0ol00024ooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool00_ooool005Oooooo00?o0000ooooooooool0F_ooool0
0ol0003oooooooooo`08ooooo`Co0000R?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo00;ooooo001Hooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool01?ooool3o`00
08gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`02ooooo`00FOooool00ol0003o
ooooooooo`1Jooooo`03o`000?oooooooooo00?o0000T?ooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo00;ooooo001Jooooo`03o`000?oooooooooo05[ooooo0_l0002Dooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool00_ooool005_ooooo00?o0000ooooooooool0FOoo
ool00ol0003oooooooooo`2Dooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00_oo
ool005cooooo0_l0001Iooooo`03o`000?oooooooooo09Gooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`02ooooo`00G_ooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo
09Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`02ooooo`00Goooool00ol0003o
ooooooooo`1Eooooo`03o`000?oooooooooo09Kooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`01ooooo`00H?ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo09Oooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`01ooooo`00HOooool00ol0003ooooooooo
o`1Cooooo`03o`000?oooooooooo09Sooooo00?o0000ooooooooool03oooool00ol0003ooooooooo
o`01ooooo`00H_ooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo09Wooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`01ooooo`00Hoooool2o`0005;ooooo00?o0000oooo
ooooool0V_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo007ooooo001Uooooo`03
o`000?oooooooooo04oooooo00?o0000ooooooooool0V_ooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo007ooooo001Vooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0
Voooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo007ooooo001Wooooo`03o`000?oo
oooooooo04gooooo00?o0000ooooooooool0W?ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo007ooooo001Xooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0WOooool0
0ol0003oooooooooo`0;ooooo`7o00000Oooool1ooooo`00JOooool00ol0003oooooooooo`1;oooo
o`03o`000?oooooooooo09gooooo00?o0000ooooooooool02oooool1o`00007ooooo0Oooool006[o
oooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`2Nooooo`03o`000?oooooooooo00[o
oooo0Ol00001ooooo`7ooooo001[ooooo`;o0000B_ooool00ol0003oooooooooo`2Oooooo`03o`00
0?oooooooooo00Wooooo0Ol00001ooooo`7ooooo001]ooooo`03o`000?oooooooooo04Oooooo00?o
0000ooooooooool0X?ooool00ol0003oooooooooo`08ooooo`7o00000Oooool1ooooo`00K_ooool0
0ol0003oooooooooo`16ooooo`03o`000?oooooooooo0:7ooooo00?o0000ooooooooool01oooool1
o`00007ooooo0Oooool006oooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`2Qoooo
o`03o`000?oooooooooo00Oooooo0Ol00001ooooo`7ooooo001`ooooo`03o`000?oooooooooo04Co
oooo00?o0000ooooooooool0X_ooool00ol0003oooooooooo`06ooooo`7o00000Oooool1ooooo`00
LOooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo0:?ooooo00?o0000ooooooooool0
1Oooool1o`00007ooooo0Oooool007;ooooo0_l00012ooooo`03o`000?oooooooooo0:Gooooo00?o
0000ooooooooool01Oooool1o`00007ooooo001dooooo`03o`000?oooooooooo03oooooo00?o0000
ooooooooool0Y_ooool00ol0003oooooooooo`04ooooo`7o00000Oooool007Gooooo00?o0000oooo
ooooool0?_ooool00ol0003oooooooooo`2Vooooo`03o`000?oooooooooo00Cooooo0Ol00001oooo
o`00M_ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo0:Oooooo00?o0000oooooooo
ool00oooool1o`00007ooooo001gooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0
Z?ooool00ol0003oooooooooo`02ooooo`7o00000Oooool007Sooooo00?o0000ooooooooool0>ooo
ool00ol0003oooooooooo`2Yooooo`05o`000?ooooooooooooooool000000Oooool007Wooooo00?o
0000ooooooooool0>_ooool00ol0003oooooooooo`2Zooooo`04o`000?ooooooooooo`00007ooooo
001jooooo`;o0000>_ooool00ol0003oooooooooo`2Zooooo`04o`000?ooooooooooo`00007ooooo
001looooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0Zoooool00ol0003ooooooooo
o`01o`000000OOooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo0:cooooo0Ol00001
ooooo`7o0000001nooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0[Oooool2o`00
0000Ooooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo0:cooooo0ol00000083ooooo
00?o0000ooooooooool0<oooool00ol0003oooooooooo`2Xooooo`Co00000oooool0087ooooo0_l0
000cooooo`03o`000?oooooooooo0:Gooooo0ol00007ooooo`00Poooool00ol0003oooooooooo`0`
ooooo`03o`000?oooooooooo0:7ooooo1?l0000:ooooo`00Q?ooool00ol0003oooooooooo`0_oooo
o`03o`000?oooooooooo09gooooo1?l0000>ooooo`00QOooool00ol0003oooooooooo`0^ooooo`03
o`000?oooooooooo09Wooooo1?l0000Booooo`00Q_ooool00ol0003oooooooooo`0]ooooo`03o`00
0?oooooooooo09Gooooo1?l0000Fooooo`00Qoooool00ol0003oooooooooo`0/ooooo`03o`000?oo
oooooooo09;ooooo0ol0000Jooooo`00R?ooool2o`0002cooooo00?o0000ooooooooool0S_ooool4
o`0001gooooo002:ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0R_ooool4o`00
027ooooo002;ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0Q_ooool4o`0002Go
oooo002<ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0P_ooool4o`0002Wooooo
002=ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0Ooooool3o`0002gooooo002>
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0Noooool4o`00033ooooo002?oooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0Moooool4o`0003Cooooo002@ooooo`;o
00009?ooool00ol0003oooooooooo`1cooooo`Co0000>?ooool009;ooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`1`ooooo`?o0000??ooool009?ooooo00?o0000ooooooooool08?oo
ool00ol0003oooooooooo`1/ooooo`Co0000?oooool009Cooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`1Xooooo`Co0000@oooool009Gooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`1Tooooo`Co0000Aoooool009Kooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`1Pooooo`Co0000Boooool009Oooooo0_l0000Mooooo`03o`000?oooooooooo05gooooo
0ol0001?ooooo`00VOooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo05Wooooo1?l0
001Booooo`00V_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo05Gooooo1?l0001F
ooooo`00Voooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo057ooooo1?l0001Joooo
o`00W?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04gooooo1?l0001Nooooo`00
WOooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04[ooooo0ol0001Rooooo`00W_oo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04Kooooo1?l0001Uooooo`00Woooool2
o`0001Cooooo00?o0000ooooooooool0@oooool4o`0006Wooooo002Qooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool0?oooool4o`0006gooooo002Rooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool0>oooool4o`00077ooooo002Sooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool0>?ooool3o`0007Gooooo002Tooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool0=?ooool4o`0007Sooooo002Uooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0<?ooool4o`0007cooooo002Vooooo`;o00003Oooool00ol0003oooooooooo`0/oooo
o`Co0000P?ooool00:Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Yooooo`?o
0000Q?ooool00:Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Uooooo`Co0000
Qoooool00:[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Qooooo`Co0000Rooo
ool00:_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Mooooo`Co0000Soooool0
0:cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Iooooo`Co0000Toooool00:go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Fooooo`?o0000Uoooool00:kooooo
0_l00005ooooo`03o`000?oooooooooo01;ooooo1?l0002Jooooo`00/?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00kooooo1?l0002Nooooo`00/Oooool01Ol0003ooooooooooooo
oooo000000cooooo1?l0002Rooooo`00/_ooool01?l0003oooooooooool00008ooooo`Co0000Y_oo
ool00;?ooooo00?o0000ooooool000001Oooool3o`000:[ooooo002dooooo`;o000000?oooooo`00
0?l000000_l0002]ooooo`00]Oooool2o`000;7ooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {319.688, 0}} -> {-0.0710364, -0.0181728, \
0.0035149, 0.0035149}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .89104 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-16 1.0656 -0.0363427 1.0656 [
[.02544 .21571 -12 -8.9133 ]
[.02544 .21571 0 .0867 ]
[.16074 .16277 -11.6592 -9 ]
[.16074 .16277 .34081 0 ]
[.3021 .10747 -5.60025 -9 ]
[.3021 .10747 .39975 0 ]
[.44992 .04965 -5.37091 -9 ]
[.44992 .04965 .62909 0 ]
[.60467 -0.01084 -5.14157 -9 ]
[.60467 -0.01084 .85843 0 ]
[.66454 .05085 0 -6.20675 ]
[.66454 .05085 6 2.79325 ]
[.80797 .25198 0 -6.0417 ]
[.80797 .25198 6 2.9583 ]
[.93071 .4241 0 -5.90576 ]
[.93071 .4241 6 3.09424 ]
[.02254 .22988 -12 -2.74631 ]
[.02254 .22988 0 6.25369 ]
[.0142 .29178 -24 -2.78907 ]
[.0142 .29178 0 6.21093 ]
[.00558 .35578 -6 -2.83339 ]
[.00558 .35578 0 6.16661 ]
[-0.00334 .42198 -18 -2.87938 ]
[-0.00334 .42198 0 6.12062 ]
[-0.01257 .49051 -6 -2.92712 ]
[-0.01257 .49051 0 6.07288 ]
[ 0 0 0 0 ]
[ 1 .89104 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03495 .22504 m
.61241 0 L
s
.03495 .22504 m
.03971 .2297 L
s
[(-2)] .02544 .21571 1 .98073 Mshowa
.16988 .17246 m
.17445 .1773 L
s
[(-1)] .16074 .16277 .9432 1 Mshowa
.31082 .11753 m
.31518 .12256 L
s
[(0)] .3021 .10747 .86675 1 Mshowa
.45818 .0601 m
.46231 .06533 L
s
[(1)] .44992 .04965 .7903 1 Mshowa
.61241 0 m
.61628 .00542 L
s
[(2)] .60467 -0.01084 .71386 1 Mshowa
.125 Mabswid
.06148 .2147 m
.06431 .21752 L
s
.08823 .20428 m
.09104 .20712 L
s
.11521 .19376 m
.118 .19663 L
s
.14243 .18316 m
.14519 .18604 L
s
.19758 .16166 m
.20029 .16459 L
s
.22551 .15078 m
.22821 .15373 L
s
.2537 .13979 m
.25637 .14277 L
s
.28213 .12871 m
.28478 .13171 L
s
.33977 .10625 m
.34236 .10929 L
s
.36897 .09487 m
.37153 .09794 L
s
.39844 .08339 m
.40097 .08648 L
s
.42817 .0718 m
.43068 .07491 L
s
.48846 .0483 m
.49091 .05146 L
s
.51902 .03639 m
.52144 .03958 L
s
.54986 .02437 m
.55225 .02758 L
s
.58099 .01224 m
.58335 .01547 L
s
.25 Mabswid
.61241 0 m
.97291 .505 L
s
.65208 .05558 m
.64586 .05794 L
s
[(0)] .66454 .05085 -1 .37928 Mshowa
.79537 .2563 m
.78907 .25846 L
s
[(2)] .80797 .25198 -1 .3426 Mshowa
.91799 .42808 m
.91164 .43006 L
s
[(4)] .93071 .4241 -1 .31239 Mshowa
.125 Mabswid
.69012 .10886 m
.68637 .11025 L
s
.72662 .16 m
.72286 .16135 L
s
.76168 .2091 m
.75791 .21042 L
s
.82778 .3017 m
.82399 .30297 L
s
.85897 .3454 m
.85518 .34664 L
s
.88903 .3875 m
.88522 .38871 L
s
.94594 .46722 m
.94211 .46839 L
s
.25 Mabswid
.03495 .22504 m
0 .48612 L
s
.03495 .22504 m
.04116 .22262 L
s
[(-1)] .02254 .22988 1 -0.38971 Mshowa
.02665 .28704 m
.03288 .28468 L
s
[(-0.5)] .0142 .29178 1 -0.38021 Mshowa
.01807 .35115 m
.02431 .34884 L
s
[(0)] .00558 .35578 1 -0.37036 Mshowa
.00919 .41747 m
.01546 .41521 L
s
[(0.5)] -0.00334 .42198 1 -0.36014 Mshowa
0 .48612 m
.00629 .48392 L
s
[(1)] -0.01257 .49051 1 -0.34953 Mshowa
.125 Mabswid
.03331 .23728 m
.03704 .23583 L
s
.03166 .2496 m
.03539 .24816 L
s
.03 .262 m
.03373 .26056 L
s
.02833 .27448 m
.03207 .27305 L
s
.02496 .29969 m
.0287 .29828 L
s
.02325 .31243 m
.02699 .31102 L
s
.02154 .32525 m
.02528 .32385 L
s
.01981 .33816 m
.02355 .33676 L
s
.01632 .36423 m
.02007 .36285 L
s
.01455 .37741 m
.01831 .37603 L
s
.01278 .39067 m
.01653 .3893 L
s
.01099 .40402 m
.01475 .40266 L
s
.00738 .43101 m
.01114 .42966 L
s
.00555 .44464 m
.00932 .4433 L
s
.00371 .45837 m
.00748 .45704 L
s
.00186 .4722 m
.00563 .47087 L
s
.25 Mabswid
.03495 .22504 m
0 .48612 L
s
0 .48612 m
.46953 .89104 L
s
.46953 .89104 m
.47294 .65459 L
s
.47294 .65459 m
.03495 .22504 L
s
.61241 0 m
.97291 .505 L
s
.97291 .505 m
1 .75117 L
s
1 .75117 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.03495 .22504 m
0 .48612 L
s
0 .48612 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.61241 0 m
.03495 .22504 L
s
.47294 .65459 m
.97291 .505 L
s
.97291 .505 m
1 .75117 L
s
1 .75117 m
.46953 .89104 L
s
.46953 .89104 m
.47294 .65459 L
s
0 0 m
1 0 L
1 .89104 L
0 .89104 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.39041 .49252 m
.40468 .48798 L
s
1 0 .6 r
.38199 .47007 m
.39618 .46541 L
s
.8 0 1 r
.37388 .44801 m
.38803 .44328 L
s
1 0 0 r
.40468 .48798 m
.419 .48339 L
s
.2 0 1 r
.36588 .42609 m
.38001 .4213 L
s
1 0 .6 r
.39618 .46541 m
.41042 .46072 L
s
0 .4 1 r
.35791 .40419 m
.37203 .39934 L
s
0 1 1 r
.34994 .38227 m
.36406 .37738 L
s
.8 0 1 r
.38803 .44328 m
.40224 .43852 L
s
1 0 0 r
.419 .48339 m
.43337 .47876 L
s
0 1 .4 r
.34197 .36033 m
.35608 .35538 L
s
.2 0 1 r
.38001 .4213 m
.39421 .41648 L
s
.2 1 0 r
.33398 .33836 m
.34809 .33336 L
s
1 0 .6 r
.41042 .46072 m
.42472 .45601 L
s
0 .4 1 r
.37203 .39934 m
.38622 .39448 L
s
.8 1 0 r
.32599 .31636 m
.34008 .31132 L
s
0 1 1 r
.36406 .37738 m
.37824 .37246 L
s
.8 0 1 r
.40224 .43852 m
.41652 .43375 L
s
1 0 0 r
.43337 .47876 m
.44779 .47408 L
s
1 .6 0 r
.31798 .29434 m
.33207 .28924 L
s
0 1 .4 r
.35608 .35538 m
.37025 .35042 L
s
.2 0 1 r
.39421 .41648 m
.40847 .41165 L
s
.2 1 0 r
.34809 .33336 m
.36225 .32835 L
s
1 0 .6 r
.42472 .45601 m
.43908 .45126 L
s
0 .4 1 r
.38622 .39448 m
.40047 .38959 L
s
.8 1 0 r
.34008 .31132 m
.35424 .30625 L
s
0 1 1 r
.37824 .37246 m
.39248 .36752 L
s
.8 0 1 r
.41652 .43375 m
.43085 .42894 L
s
1 0 0 r
.44779 .47408 m
.46224 .46934 L
s
1 .6 0 r
.33207 .28924 m
.34622 .28412 L
s
0 1 .4 r
.37025 .35042 m
.38448 .34543 L
s
.2 0 1 r
.40847 .41165 m
.42279 .40679 L
s
.2 1 0 r
.36225 .32835 m
.37648 .32331 L
s
1 0 .6 r
.43908 .45126 m
.45349 .44648 L
s
0 .4 1 r
.40047 .38959 m
.41479 .38468 L
s
.8 1 0 r
.35424 .30625 m
.36846 .30115 L
s
0 1 1 r
.39248 .36752 m
.40679 .36256 L
s
.8 0 1 r
.43085 .42894 m
.44524 .42412 L
s
1 0 0 r
.46224 .46934 m
.47672 .46456 L
s
1 .6 0 r
.34622 .28412 m
.36043 .27897 L
s
0 1 .4 r
.38448 .34543 m
.39878 .34042 L
s
.2 0 1 r
.42279 .40679 m
.43718 .40192 L
s
.2 1 0 r
.37648 .32331 m
.39077 .31824 L
s
1 0 .6 r
.45349 .44648 m
.46795 .44167 L
s
0 .4 1 r
.41479 .38468 m
.42916 .37975 L
s
.8 1 0 r
.36846 .30115 m
.38274 .29604 L
s
0 1 1 r
.40679 .36256 m
.42115 .35758 L
s
.8 0 1 r
.44524 .42412 m
.4597 .41927 L
s
1 0 0 r
.47672 .46456 m
.49123 .45972 L
s
1 .6 0 r
.36043 .27897 m
.3747 .27381 L
s
0 1 .4 r
.39878 .34042 m
.41314 .33538 L
s
.2 0 1 r
.43718 .40192 m
.45162 .39702 L
s
.2 1 0 r
.39077 .31824 m
.40512 .31316 L
s
1 0 .6 r
.46795 .44167 m
.48247 .43683 L
s
0 .4 1 r
.42916 .37975 m
.4436 .3748 L
s
.8 1 0 r
.38274 .29604 m
.39708 .2909 L
s
0 1 1 r
.42115 .35758 m
.43558 .35258 L
s
.8 0 1 r
.4597 .41927 m
.47421 .41439 L
s
1 0 0 r
.49123 .45972 m
.50578 .45485 L
s
1 .6 0 r
.3747 .27381 m
.38904 .26862 L
s
0 1 .4 r
.41314 .33538 m
.42756 .33033 L
s
.2 0 1 r
.45162 .39702 m
.46613 .39209 L
s
.2 1 0 r
.40512 .31316 m
.41953 .30805 L
s
1 0 .6 r
.48247 .43683 m
.49704 .43197 L
s
0 .4 1 r
.4436 .3748 m
.4581 .36983 L
s
.8 1 0 r
.39708 .2909 m
.41149 .28574 L
s
0 1 1 r
.43558 .35258 m
.45008 .34755 L
s
.8 0 1 r
.47421 .41439 m
.48879 .40949 L
s
1 .6 0 r
.38904 .26862 m
.40344 .26341 L
s
1 0 0 r
.50578 .45485 m
.52036 .44993 L
s
0 1 .4 r
.42756 .33033 m
.44205 .32525 L
s
.2 0 1 r
.46613 .39209 m
.4807 .38715 L
s
.2 1 0 r
.41953 .30805 m
.43401 .30292 L
s
0 .4 1 r
.4581 .36983 m
.47266 .36484 L
s
1 0 .6 r
.49704 .43197 m
.51167 .42707 L
s
.8 1 0 r
.41149 .28574 m
.42596 .28056 L
s
0 1 1 r
.45008 .34755 m
.46463 .34251 L
s
.8 0 1 r
.48879 .40949 m
.50342 .40457 L
s
1 .6 0 r
.40344 .26341 m
.4179 .25817 L
s
0 1 .4 r
.44205 .32525 m
.4566 .32015 L
s
.2 0 1 r
.4807 .38715 m
.49534 .38218 L
s
.2 1 0 r
.43401 .30292 m
.44855 .29777 L
s
0 .4 1 r
.47266 .36484 m
.48729 .35982 L
s
.8 1 0 r
.42596 .28056 m
.44049 .27536 L
s
0 1 1 r
.46463 .34251 m
.47925 .33744 L
s
1 .6 0 r
.4179 .25817 m
.43242 .25291 L
s
0 1 .4 r
.4566 .32015 m
.47121 .31503 L
s
.2 1 0 r
.44855 .29777 m
.46316 .2926 L
s
.8 1 0 r
.44049 .27536 m
.45509 .27013 L
s
1 .6 0 r
.43242 .25291 m
.44701 .24763 L
s
0 g
.25 Mabswid
.61241 0 m
.97291 .505 L
s
.97291 .505 m
1 .75117 L
s
1 .75117 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.03495 .22504 m
0 .48612 L
s
0 .48612 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.61241 0 m
.03495 .22504 L
s
.03495 .22504 m
.61241 0 L
s
.03495 .22504 m
.03971 .2297 L
s
[(-2)] .02544 .21571 1 .98073 Mshowa
.16988 .17246 m
.17445 .1773 L
s
[(-1)] .16074 .16277 .9432 1 Mshowa
.31082 .11753 m
.31518 .12256 L
s
[(0)] .3021 .10747 .86675 1 Mshowa
.45818 .0601 m
.46231 .06533 L
s
[(1)] .44992 .04965 .7903 1 Mshowa
.61241 0 m
.61628 .00542 L
s
[(2)] .60467 -0.01084 .71386 1 Mshowa
.125 Mabswid
.06148 .2147 m
.06431 .21752 L
s
.08823 .20428 m
.09104 .20712 L
s
.11521 .19376 m
.118 .19663 L
s
.14243 .18316 m
.14519 .18604 L
s
.19758 .16166 m
.20029 .16459 L
s
.22551 .15078 m
.22821 .15373 L
s
.2537 .13979 m
.25637 .14277 L
s
.28213 .12871 m
.28478 .13171 L
s
.33977 .10625 m
.34236 .10929 L
s
.36897 .09487 m
.37153 .09794 L
s
.39844 .08339 m
.40097 .08648 L
s
.42817 .0718 m
.43068 .07491 L
s
.48846 .0483 m
.49091 .05146 L
s
.51902 .03639 m
.52144 .03958 L
s
.54986 .02437 m
.55225 .02758 L
s
.58099 .01224 m
.58335 .01547 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 256.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001@2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00gOooool5o`0008Kooooo003Mooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0Q_ooool00=ko
oooo00?oV9RHob4Q8Oo^k^h0Qoooool00=oooooo00?oV9RHob4Q8Oo^k^h0Q_ooool00>3ooooo00?o
MgMgofIVI_ooool0QOooool00>7ooooo00?o0000ooooooooool0Q?ooool00=gooooo00Go0000okZj
^_ooooooV9RHoa0@4026ooooo`00gOooool01OnHV9So410@o`000?lQ8B7oc<c<08Kooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003Tooooo`;o0000P_ooool0
0>7ooooo0ol000000ooooooo0000ooooo`21ooooo`00goooool2o`0000Cooooo0_l00021ooooo`00
g?ooool3o`0000Kooooo00?o0000ooooool00000P?ooool00=[ooooo0_l00009ooooo`03o`000?oo
oooo0000083ooooo003Gooooo`?o000000?oooooo`000?ooool02?ooool01?l0003oooooooooool0
001oooooo`00e?ooool3o`0000Cooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooo
oooo000007kooooo003Booooo`;o00004Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo07_ooooo002Zooooo`Co000000?o410@ooooooooool07_ooool3o`0001?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1kooooo`00[?ooool00ol0003oooooooooo`0Nooooo`;o
000000?oooooo`000?ooool04oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07[o
oooo002/ooooo`03o`000?oooooooooo01_ooooo0ol00004ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`1iooooo`00[?ooool00ol0003ooooooooo
o`0Iooooo`;o00006oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo07Wooooo002/
ooooo`03o`000?oooooooooo01Kooooo0ol0000Mooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool02?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^06_ooooo002/ooooo`03o`000?oooooo
oooo01Cooooo0_l000000ooooooo0000ooooo`0Mooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01oooool01OmgMgOoV9RHoooooonHV9SoMgMg06_ooooo002/ooooo`03o`000?oooooo
oooo017ooooo0ol00004ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`06ooooo`05oa0@4?ooooooooooooooool@4100Joooool00:[ooooo00?oEEEE
ofIVI_l000004Oooool2o`0002Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06
ooooo`05o`000?ooooooooooooooool00000Joooool00;_ooooo0ol0000Wooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000006_ooooo002i
ooooo`;o000000?oooooo`000?ooool09oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Cooooo00Go410@oooooooooooooooooa0@401[ooooo`00]_ooool3o`0000Cooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`1[ooooo`00/oooool3o`0002oooooo00?o0000ooooooooool02Oooool2
o`0000Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1[ooooo`00/Oooool2o`0003;ooooo00?o0000
ooooooooool02?ooool01?l0003oooooooooool0001dooooo`00[_ooool3o`000003ooooool0003o
oooo037ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1aooooo`00[?ooool2o`00
00Gooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
077ooooo002Yooooo`?o0000>_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo073o
oooo002Wooooo`;o0000?Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo06oooooo
002Tooooo`?o000000?oooooo`000?ooool0??ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo06oooooo002Rooooo`;o0000@_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo06kooooo001gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08oooool3o`0004Cooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1]ooooo`00Moooool01OmgMgOoV9RHoooooonHV9So
MgMg027ooooo0_l00017ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0K?ooool0
07Oooooo00Go410@oooooooooooooooooa0@400Nooooo`?o00000_ooool00ol0003oooooooooo`14
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0K?ooool007Oooooo00Go0000oooo
ooooooooooooo`00000Looooo`;o0000C?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo06_ooooo001gooooo`05o`000?ooooooooooooooool000006Oooool3o`0004kooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`1Zooooo`00Moooool01Ol@413ooooooooooooooooo
410@01Kooooo0ol0001Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0J_ooool0
07Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Dooooo`;o00000oooool00ol0003oooooooooo`1>
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0JOooool007Oooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Aooooo`?o0000E_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo06Sooooo002;ooooo`;o0000FOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
06Sooooo0028ooooo`?o0000Foooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo06Oo
oooo0026ooooo`;o00000oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo01Gooooo
0_l0001Xooooo`00Poooool3o`00063ooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`1Uooooo`00POooool2o`0006?ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1U
ooooo`00O_ooool4o`0006Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`1Toooo
o`00O?ooool2o`0000Cooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo06?ooooo001iooooo`?o0000J_ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo06?ooooo001gooooo`;o0000KOooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo06;ooooo001dooooo`?o000000?oooooo`000?ooool0K?ooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo067ooooo001aooooo`?o0000L_ooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo063ooooo0019ooooo`Co000000?o410@ooooooooool07oooool2o`0007Go
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1Pooooo`00Boooool00ol0003ooooo
ooooo`0Nooooo`?o0000Moooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo05oooooo
0010ooooo`Ko00001Oooool00ol0003oooooooooo`0Looooo`;o00000_ooool00ol0003ooooooooo
o`1eooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0G_ooool004_ooooo00?o0000
ooooooooool06Oooool3o`0007cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1N
ooooo`00Boooool00ol0003oooooooooo`0Gooooo`;o0000Ooooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo05gooooo001;ooooo`03o`000?oooooooooo01Cooooo0ol00021ooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0G?ooool004_ooooo00?o0000ooooooooool0
4_ooool2o`0000?ooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo05_ooooo0019ooooo`03oeEEEOmVIVKo0000017ooooo0ol00026ooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool0Foooool005_ooooo0_l00029ooooo`03o`000?oooooo
oooo027ooooo0_l0001Looooo`00F?ooool3o`000003ooooool0003ooooo08Sooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`1Iooooo`00E_ooool2o`0008kooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`1Iooooo`00Doooool3o`00093ooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`1Hooooo`00D?ooool3o`0009?ooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1Gooooo`00C_ooool2o`0000;ooooo00?o0000ooooooooool0TOooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo05Kooooo001;ooooo`?o00001Oooool00ol0
003oooooooooo`2@ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0E_ooool004Wo
oooo0_l0002Kooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0EOooool004Kooooo
1?l0002Looooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0E?ooool004Cooooo0_l0
002Pooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0E?ooool001[ooooo1Ol0000R
ooooo`?o0000X_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo05?ooooo000Joooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@08?ooool2o`000:Gooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`1Booooo`004_ooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h07_ooool3o`00
0003ooooool0003ooooo0:Cooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`1Aoooo
o`007?ooool00onHV9So8B4Qonk^kP0Kooooo`;o0000Z_ooool00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo057ooooo000Mooooo`03ogMgMomVIVKooooo01Oooooo0ol0002]ooooo`03o`00
0?oooooooooo02_ooooo00?o0000ooooooooool0D?ooool001kooooo00?o0000ooooooooool05?oo
ool2o`000;3ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`1?ooooo`006_ooool0
1Ol0003o^[ZjoooooonHV9So410@01?ooooo0ol00002ooooo`03o`000?oooooooooo0:gooooo00?o
0000ooooooooool0;?ooool2o`00053ooooo000Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`04?oo
ool3o`000;Gooooo00?o0000ooooooooool0;?ooool2o`00053ooooo000]ooooo`;o0000^?ooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo04gooooo000Zooooo`?o000000?oooooo`00
0?ooool0]oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo04gooooo000Xooooo`;o
0000_Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo04cooooo000Uooooo`?o0000
_oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo04_ooooo000Tooooo`;o0000`Ooo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo04[ooooo000Jooooo`Co000000?o410@
ooooooooool00oooool00ol0003oooooo`000030ooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool0B_ooool001cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0002o
ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0BOooool0017ooooo1_l00005oooo
o`03o`000?oooooooooo00Gooooo0_l00002ooooo`03o`000?oooooooooo0;cooooo00?o0000oooo
ooooool0<oooool00ol0003oooooooooo`18ooooo`007?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0^oooool00ol0003oooooooooo`0cooooo`03
o`000?oooooooooo00Oooooo1Ol0000looooo`007?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo00Kooooo00GoV9RHob4Q8Oo^k^koooooodA4A00looooo`007?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00ol0003ooooo
ooooo`0eooooo`03o`000?oooooooooo00Kooooo00?oV9RHob4Q8Oo^k^h0?Oooool001cooooo00?o
0000ooooooooool01?ooool3o`0000Kooooo00?o0000ooooooooool0O_ooool2oonI03Sooooo00?o
0000ooooooooool0=_ooool00ol0003oooooooooo`06ooooo`03oiRHV?lQ8B7ok^k^03cooooo000J
ooooo`03oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`1j
ooooo`?ooiT0>_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Oooooo00?oMgMg
ofIVI_ooool0>oooool002?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1goooo
o`;ooiT0?Oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ooooool0>_ooool002?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1cooooo`?o
oiT0?oooool00ol0003oooooooooo`0gooooo`;o00001?ooool01Ol0003o^[ZjoooooonHV9So410@
03cooooo000Sooooo`;o00002oooool00ol0003oooooooooo`1_ooooo`?ooiT0@_ooool00ol0003o
ooooooooo`0fooooo`03o`000?oooooo000000Cooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00loooo
o`008oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo06[ooooo1?ooV@15ooooo`03
o`000?oooooooooo03Wooooo00?o0000ooooooooool0@_ooool002;ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`1Wooooo`;ooiT0BOooool00ol0003oooooooooo`0jooooo`03o`00
0?oooooooooo047ooooo000Rooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0I?oo
ool2oonI04[ooooo0_l0000mooooo`03o`000?oooooooooo043ooooo000Rooooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0H?ooool3oonI01Gooooo0oo<o`0aooooo`?o000000?ooooo
o`000?ooool0??ooool00ol0003oooooooooo`10ooooo`008_ooool2o`00017ooooo00?o0000oooo
ooooool0GOooool2oonI01Cooooo1?o<o`0aooooo`?o00001Oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo03oooooo000Rooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool0FOooool3oonI01?ooooo0oo<o`0booooo`?o00002Oooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo03kooooo000Rooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0
EOooool3oonI01Cooooo0_o<o`0booooo`?o00003Oooool00ol0003oooooooooo`0jooooo`03o`00
0?oooooooooo03kooooo000Rooooo`?o00004oooool00ol0003oooooooooo`1@ooooo`CooiT05?oo
ool3olco037ooooo0ol0000Aooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0?Ooo
ool002;ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1=ooooo`;ooiT05Oooool3
olco03;ooooo0_l0000Dooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0??ooool0
027ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1:ooooo`;ooiT04oooool4olco
03;ooooo0ol0000Gooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0>oooool000Oo
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;o
gMgM00Cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`16ooooo`?ooiT04_ooool3
olco01Kooooo0_lco`0Kooooo`?o00006oooool00ol0003oooooooooo`0jooooo`03o`000?oooooo
oooo03_ooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMg
oc8b<_ooool00oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04Cooooo00?ooiT0
ooooooooool04Oooool2olco01Kooooo0olco`0Jooooo`?o00007oooool00ol0003oooooooooo`0j
ooooo`03o`000?oooooooooo03[ooooo0005o`0000;ooooo00Go410@oooooooooooooooooa0@400@
ooooo`03o`000?oooooooooo00;ooooo0_l0000Jooooo`03o`000?oooooooooo05Gooooo0_o<o`0E
ooooo`?o<ol06_ooool3o`0002?ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0i
ooooo`001oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo05;ooooo0_o<o`0Dooooo`?o<ol06oooool2
o`0002Kooooo00?o0000ooooooooool0>_ooool2o`0003[ooooo0007ooooo`05o`000?oooooooooo
ooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`1>ooooo`?oc?l04oooool3oc?o01_ooooo0ol0000Yooooo`03o`000?oo
oooooooo03Wooooo0_l0000jooooo`001oooool01Ol@413ooooooooooooooooo410@00cooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo04[ooooo0oo<
o`0Dooooo`;o<ol06oooool3o`0002gooooo00?o0000ooooooooool0>_ooool00ol0003ooooooooo
o`0gooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01_oo
ool2o`0001kooooo00?o0000ooooooooool0AOooool4olco01Cooooo0olco`0Jooooo`?o0000<Ooo
ool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo03Oooooo0007ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool4o`0000Cooooo0_l0000Pooooo`03o`000?oooooooooo04;ooooo0_o<
o`0Fooooo`;o<ol06_ooool3o`0003Gooooo00?o0000ooooooooool0>Oooool00ol0003ooooooooo
o`0fooooo`008?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo043ooooo00?oc?l0
ooooooooool04oooool3oc?o01Gooooo0ol0ofH01?oooooo0000o`000?l0000hooooo`03o`000?oo
oooooooo03[ooooo00?o0000ooooooooool0=Oooool0023ooooo00?o0000ooooooooool08Oooool0
0ol0003oooooooooo`1Booooo`?o<ol05?ooool4o`3oIP;ooooo0_l0000looooo`03o`000?oooooo
oooo03[ooooo00?o0000ooooooooool0=?ooool0023ooooo0_l0000Sooooo`03o`000?oooooooooo
04gooooo1?lco`0Dooooo`?o0?mV0oooool3o`0003oooooo00?o0000ooooooooool0>Oooool00ol0
003oooooooooo`0dooooo`008?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo04[o
oooo0_lco`0Fooooo`;o0?mV0oooool3o`0004?ooooo00?o0000ooooooooool0>Oooool00ol0003o
ooooooooo`0cooooo`008?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo04Oooooo
0_lco`0Eooooo`?o0?mV0_ooool3o`0004Oooooo00?o0000ooooooooool0>Oooool00ol0003ooooo
ooooo`0booooo`008?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo04?ooooo0olc
o`0Dooooo`?o0?mV0_ooool3o`0004[ooooo00?o0000ooooooooool0>Oooool00ol0003ooooooooo
o`0booooo`008?ooool00ol0003oooooooooo`0Vooooo`;o0000@?ooool3oc?o01Cooooo0ol0ofH3
ooooo`;o0000C_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo037ooooo000Ooooo
o`?o0000:Oooool00ol0003oooooooooo`0jooooo`?o<ol05?ooool3o`3oIP?ooooo0ol0000@oooo
o`;o0?oo?oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo033ooooo000Oooooo`03
o`000?oooooooooo02[ooooo00?o0000ooooooooool0C_ooool2o`3oIP?ooooo0ol0000@ooooo`?o
0?oo@_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02oooooo000Oooooo`03o`00
0?oooooooooo02_ooooo00?o0000ooooooooool0B_ooool3o`3oIP;ooooo0ol0000@ooooo`?o0?oo
AOooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02oooooo000Oooooo`03o`000?oo
oooooooo02cooooo00?o0000ooooooooool0A_ooool3o`3oIP;ooooo0ol0000?ooooo`Co0?ooBOoo
ool00ol0003oooooooooo`0hooooo`;o0000<?ooool001oooooo0ol0000]ooooo`03o`000?oooooo
oooo047ooooo1?l0ofH2ooooo`?o00003oooool3o`3oodkooooo00?o0000ooooooooool0>Oooool0
0ol0003oooooooooo`0]ooooo`007oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo
03kooooo0_l0ofH4ooooo`;o00004?ooool2o`3ooe;ooooo00?o0000ooooooooool0>?ooool00ol0
003oooooooooo`0]ooooo`005?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooo
ooooool0;oooool00ol0003oooooooooo`0kooooo`;o0?mV0oooool3o`0000oooooo0ol0oomEoooo
o`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0;?ooool001Cooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0=oooool3o`3o
IP;ooooo0ol0000?ooooo`?o0?oo5?ooool2o`1Vod;ooooo00?o0000ooooooooool0>Oooool00ol0
003oooooooooo`0[ooooo`005?ooool01Ol@413ooooooooooooooooo410@00Gooooo0_l0000coooo
o`03o`000?oooooooooo03Gooooo00?o0?mVooooooooool00ol0000?ooooo`?o0?oo5Oooool2o`1V
odGooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Zooooo`005?ooool01Ol0003o
oooooooooooooooo000000Gooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0doooo
o`?o00003oooool3o`3ooaKooooo0_l0I_m8ooooo`03o`000?oooooooooo03Sooooo00?o0000oooo
ooooool0:_ooool001Cooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo
03Cooooo00?o0000ooooooooool0<?ooool3o`00013ooooo0_l0oolFooooo`?o06KoBoooool00ol0
003oooooooooo`0hooooo`03o`000?oooooooooo02Wooooo000Dooooo`05oa0@4?oooooooooooooo
ool@41001Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02gooooo0_l0000@oooo
o`?o0?oo5Oooool3o`1Vodoooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Xoooo
o`005?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`0Yooooo`?o00003oooool3o`3ooaCooooo1?l0I_mBooooo`03o`000?oooooooooo
03Sooooo00?o0000ooooooooool0:?ooool001Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05oooo
o`;o0000>?ooool00ol0003oooooooooo`0Uooooo`?o00003_ooool4o`3ooaCooooo0ol0I_mGoooo
o`03o`000?oooooooooo03Sooooo00?o0000ooooooooool09oooool001kooooo00?o0000oooooooo
ool0>?ooool00ol0003oooooooooo`0Qooooo`?o00003oooool2o`3ooaKooooo0_l0I_mKooooo`03
o`000?oooooooooo03Sooooo00?o0000ooooooooool09_ooool001gooooo00?o0000ooooooooool0
>_ooool00ol0003oooooooooo`0Mooooo`?o00004Oooool00ol0ooooooooooooo`0Cooooo`?o06Ko
5_ooool2oc<0odKooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Uooooo`007Ooo
ool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo01[ooooo0_l0000Wooooo`?o06Ko5_oo
ool3oc<0odWooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Uooooo`007Oooool2
o`0003gooooo00?o0000ooooooooool05_ooool3o`0002Gooooo1?l0I_lFooooo`?o<`3oC?ooool0
0ol0003oooooooooo`0gooooo`;o00009_ooool001gooooo00?o0000ooooooooool0?Oooool00ol0
003oooooooooo`0Booooo`?o00009_ooool2o`1VoaKooooo1?lc0?m@ooooo`03o`000?oooooooooo
03Sooooo00?o0000ooooooooool08oooool001gooooo00?o0000ooooooooool0?_ooool00ol0003o
ooooooooo`0>ooooo`?o00009oooool2o`1VoaGooooo0olc0?mEooooo`03o`000?oooooooooo03Oo
oooo00?o0000ooooooooool08oooool001gooooo00?o0000ooooooooool0?oooool00ol0003ooooo
ooooo`0:ooooo`?o00009oooool3o`1VoaGooooo0_lc0?mIooooo`03o`000?oooooooooo03Oooooo
00?o0000ooooooooool08_ooool001gooooo00?o0000ooooooooool0@?ooool00ol0003ooooooooo
o`06ooooo`?o00009oooool3o`1VoaKooooo0_lc0?mLooooo`03o`000?oooooooooo03Oooooo00?o
0000ooooooooool08Oooool001cooooo0ol00012ooooo`03o`000?oooooooooo00?ooooo0_l0000W
ooooo`?o06Ko5_ooool3oc<0oaCooooo0_o<0?m8ooooo`03o`000?oooooooooo03Sooooo00?o0000
ooooooooool08?ooool001cooooo00?o0000ooooooooool0@oooool00ol0003oooooo`000002o`00
03kooooo1?lc0?lDooooo`?oc03oBoooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo
023ooooo000Looooo`03o`000?oooooooooo04;ooooo0ol0000nooooo`?o<`3o5_ooool2ol`0odoo
oooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`09ooooo`;o000000?o410@oooooooo
ool04Oooool001cooooo00?o0000ooooooooool0?oooool3o`0000?ooooo00?o0000ooooooooool0
>?ooool3oc<0oaKooooo0oo<0?mBooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0Booooo`007?ooool3o`0003cooooo0ol00007ooooo`03o`000?oo
oooooooo03?ooooo1?lc0?lFooooo`?oc03oE_ooool00ol0003oooooooooo`0fooooo`03o`000?oo
oooooooo00Kooooo1Ol0000Cooooo`007?ooool00ol0003oooooooooo`0iooooo`?o00002oooool0
0ol0003oooooooooo`0`ooooo`;o<`3o5_ooool4ol`0oeWooooo00?o0000ooooooooool0=oooool0
0ol0003oooooooooo`05ooooo`04odA4A?oMgMgoooooo`0001Cooooo00001_ooooook^k^oc8b<_l0
003o<S8bonk^kPGooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003o
ooooooooo`0gooooo`;o00003oooool00ol0003oooooooooo`0]ooooo`;o<`3o5Oooool3ol`0oeko
oooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`04ooooo`04omgMgOmEEEGoooooo`00
01Cooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool0=?ooool3o`0001;ooooo00?o0000ooooooooool0:Oooool3
oc<0oaGooooo0_o<0?mRooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool01Oooool0
0omgMgOoc<c<o`00000Dooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0>oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0<Oooool3o`0001Kooooo00?o0000oooo
ooooool09oooool00olc0?ooooooooooo`0Dooooo`;oc03o5oooool2ool0VDcooooo00?o0000oooo
ooooool0=_ooool2o`0000Gooooo00?ok^k^odA4A?l000005?ooool00003ooooool0003ooooo00;o
oooo00?o0000ooooooooool03Oooool00omgMgOo<S8booooo`03ooooo`;o0000<?ooool3o`0001[o
oooo00?o0000ooooooooool0>_ooool3ol`0oaKooooo0ooo09U?ooooo`03o`000?oooooooooo03Co
oooo00?o0000ooooool000001_ooool00omgMgOo0000ooooo`0Cooooo`0000?oooooo`000?ooool0
0_ooool00ol0003oooooooooo`0:ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003o
ooooooooo`0/ooooo`?o00007_ooool00ol0003oooooooooo`0eooooo`Coc03o5_ooool3ool0VE;o
oooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Iooooo`0000?ooooooa0@4?ooool0
0_ooool00ol@413oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
:_ooool2o`0002;ooooo00?o0000ooooooooool0<Oooool3ol`0oaKooooo1?oo09UFooooo`03o`00
0?oooooooooo03Kooooo00?o0000ooooooooool06Oooool00006oooooomgMgOoV9RHoooooonHV9So
MgMg3?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Oooooo0ol0000Uooooo`;o
0000;_ooool3ol`0oaKooooo0ooo09UKooooo`03o`000?oooooooooo03Kooooo00?o0000oooooooo
ool06?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^3?ooool4o`0000Gooooo0_l0000Uoooo
o`?o0000:_ooool00ol0003oooooooooo`0Wooooo`Coc03o5_ooool3ool0VEoooooo00?o0000oooo
ooooool0=_ooool00ol0003oooooooooo`0Gooooo`006oooool00ol0003oooooooooo`0Qooooo`?o
0000;_ooool00ol0003oooooooooo`0Tooooo`;oc03o5_ooool4ool0VF?ooooo00?o0000oooooooo
ool0=Oooool00ol0003oooooooooo`0Gooooo`006oooool00ol0003oooooooooo`0Nooooo`?o0000
<_ooool00ol0003oooooooooo`0Rooooo`03ol`0oooooooooooo01?ooooo0ooo09UWooooo`03o`00
0?oooooooooo03Kooooo00?o0000ooooooooool05_ooool001_ooooo00?o0000ooooooooool06ooo
ool3o`0003Kooooo00?o0000ooooooooool0=Oooool2ool0VASooooo0ooo001@ooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool05Oooool001[ooooo00?o0000ooooooooool06_ooool2
o`0003[ooooo00?o0000ooooooooool0<_ooool2ool0VAOooooo0ooo001Dooooo`03o`000?oooooo
oooo03Kooooo00?o0000ooooooooool05?ooool001[ooooo0_l0000Hooooo`?o0000?Oooool00ol0
003oooooooooo`0^ooooo`?oo`2I5_ooool3ool005Sooooo00?o0000ooooooooool0=Oooool00ol0
003oooooooooo`0Dooooo`006_ooool00ol0003oooooooooo`0Dooooo`?o0000@Oooool00ol0003o
ooooooooo`0Yooooo`Coo`2I5_ooool3ool005_ooooo00?o0000ooooooooool0=_ooool00ol0003o
ooooooooo`0Cooooo`006_ooool00ol0003oooooooooo`0Aooooo`?o0000AOooool00ol0003ooooo
ooooo`0Uooooo`?oo`2I5_ooool4ool005oooooo00?o0000ooooooooool0=_ooool00ol0003ooooo
ooooo`0Booooo`006_ooool00ol0003oooooooooo`0>ooooo`?o0000BOooool00ol0003ooooooooo
o`0Qooooo`?oo`2I5_ooool3ool006Cooooo00?o0000ooooooooool0=Oooool2o`0001?ooooo000J
ooooo`03o`000?oooooooooo00cooooo0_l0001=ooooo`03o`000?oooooooooo01gooooo0ooo09TG
ooooo`;oo`00J?ooool00ol0003oooooooooo`0dooooo`;o00004oooool001Wooooo0ol0000:oooo
o`?o0000D?ooool00ol0003oooooooooo`0cooooo`?oo`00Joooool00ol0003oooooooooo`0eoooo
o`03o`000?oooooooooo013ooooo000Jooooo`03o`000?oooooooooo00Kooooo0ol0001Dooooo`03
o`000?oooooooooo02oooooo0ooo001^ooooo`03o`000?oooooooooo03Kooooo00?o0000oooooooo
ool03oooool001Wooooo00?o0000ooooooooool01?ooool3o`0005Sooooo00?o0000ooooooooool0
:_ooool4ool007;ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0?ooooo`006Ooo
ool01?l0003oooooooooooooool3o`0005cooooo00?o0000ooooooooool09oooool2ool007Oooooo
00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0>ooooo`006Oooool4o`00063ooooo00?o
0000ooooooooool08oooool3ool007[ooooo00?o0000ooooooooool0=Oooool00ol0003ooooooooo
o`0=ooooo`006Oooool2o`0006?ooooo00?o0000ooooooooool07_ooool4ool007kooooo00?o0000
ooooooooool0=?ooool00ol0003oooooooooo`0=ooooo`003oooool4o`000003oa0@4?oooooooooo
00Gooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Jooooo`?oo`00P_ooool00ol0
003oooooooooo`0eooooo`03o`000?oooooooooo00cooooo000Aooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Hooooo`03ool00?oooooooooo08Co
oooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0;ooooo`004Oooool00ol0003ooooo
ooooo`09ooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0Woooool00ol0003ooooo
ooooo`0eooooo`03o`000?oooooooooo00[ooooo000Aooooo`03o`000?oooooooooo00[ooooo00?o
0000ooooooooool0HOooool00ol0003oooooooooo`2Oooooo`03o`000?oooooooooo03Cooooo00?o
0000ooooooooool02_ooool0017ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Q
ooooo`03o`000?oooooooooo09oooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`09
ooooo`004Oooool00ol0003oooooooooo`0<ooooo`;o0000H_ooool00ol0003oooooooooo`2Noooo
o`03o`000?oooooooooo03?ooooo0ol0000:ooooo`004Oooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo063ooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`0_ooooo`?o
00000_ooool00ol0003oooooooooo`08ooooo`003oooool00omEEEGoIVIVo`00000Aooooo`03o`00
0?oooooooooo063ooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`0[ooooo`?o0000
1Oooool00ol0003oooooooooo`08ooooo`009?ooool00ol0003oooooooooo`1Pooooo`03o`000?oo
oooooooo09kooooo00?o0000ooooooooool09_ooool4o`0000Sooooo00?o0000ooooooooool02?oo
ool002Gooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`2Nooooo`03o`000?oooooo
oooo02;ooooo0ol0000<ooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo
063ooooo00?o0000ooooooooool0WOooool00ol0003oooooooooo`0Oooooo`?o00004?ooool00ol0
003oooooooooo`07ooooo`009oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo09go
oooo00?o0000ooooooooool06_ooool4o`0001?ooooo00?o0000ooooooooool01oooool002Sooooo
0_l0001Qooooo`03o`000?oooooooooo09gooooo00?o0000ooooooooool05_ooool3o`0001Oooooo
00?o0000ooooooooool01oooool002[ooooo00?o0000ooooooooool0Goooool00ol0003ooooooooo
o`2Mooooo`03o`000?oooooooooo01;ooooo0ol0000Jooooo`03o`000?oooooooooo00Oooooo000[
ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool0WOooool00ol0003oooooooooo`0=
ooooo`Co00007Oooool00ol0003oooooooooo`07ooooo`00;?ooool00ol0003oooooooooo`1Ooooo
o`03o`000?oooooooooo09cooooo00?o0000ooooooooool02_ooool3o`00027ooooo00?o0000oooo
ooooool01oooool002gooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`2Looooo`03
o`000?oooooooooo00Kooooo0ol0000Tooooo`03o`000?oooooooooo00Oooooo000^ooooo`03o`00
0?oooooooooo05oooooo00?o0000ooooooooool0W?ooool01?l0003oooooooooooooool4o`0002Oo
oooo00?o0000ooooooooool01oooool002oooooo0_l0001Pooooo`03o`000?oooooooooo09cooooo
0ol0000/ooooo`03o`000?oooooooooo00Kooooo000aooooo`03o`000?oooooooooo05kooooo0_l0
002Iooooo`?o000000?oooooo`000?ooool0;?ooool00ol0003oooooooooo`06ooooo`00<_ooool0
0ol0003oooooooooo`1Oooooo`03o`000?oooooooooo09?ooooo0ol00004ooooo`03o`000?oooooo
oooo02_ooooo00?o0000ooooooooool01_ooool003?ooooo00?o0000ooooooooool0Goooool00ol0
003oooooooooo`2>ooooo`Co00002?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo
00Kooooo000dooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool0R_ooool3o`0000go
oooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`06ooooo`00=Oooool00ol0003ooooo
ooooo`1Oooooo`03o`000?oooooooooo08Kooooo0ol0000Aooooo`03o`000?oooooooooo02Sooooo
00?o0000ooooooooool01_ooool003Kooooo00?o0000ooooooooool0Goooool00ol0003ooooooooo
o`21ooooo`Co00005Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Kooooo000g
ooooo`;o0000H?ooool00ol0003oooooooooo`1mooooo`?o00006Oooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo00Kooooo000iooooo`03o`000?oooooooooo05kooooo00?o0000oooo
ooooool0NOooool3o`0001gooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`05oooo
o`00>_ooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo07Cooooo1?l0000Qooooo`03
o`000?oooooooooo02Kooooo00?o0000ooooooooool01Oooool003_ooooo00?o0000ooooooooool0
G_ooool00ol0003oooooooooo`1`ooooo`?o00009_ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo00Gooooo000looooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0K?oo
ool3o`0002Wooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`05ooooo`00?Oooool0
0ol0003oooooooooo`1Nooooo`03o`000?oooooooooo06Oooooo1?l0000]ooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool01Oooool003kooooo0_l0001Oooooo`03o`000?oooooooooo
06?ooooo0ol0000booooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool01Oooool0043o
oooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`1Oooooo`?o0000=_ooool00ol0003o
ooooooooo`0Rooooo`03o`000?oooooooooo00Gooooo0011ooooo`03o`000?oooooooooo05gooooo
00?o0000ooooooooool0F_ooool4o`0003[ooooo00?o0000ooooooooool08Oooool00ol0003ooooo
ooooo`05ooooo`00@_ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo05Kooooo0ol0
000nooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool01Oooool004?ooooo00?o0000
ooooooooool0GOooool00ol0003oooooooooo`1Booooo`?o0000@_ooool00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo00Cooooo0014ooooo`03o`000?oooooooooo05gooooo00?o0000oooo
ooooool0COooool4o`0004Kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`04oooo
o`00AOooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo04Wooooo0ol0001;ooooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool01?ooool004Kooooo0_l0001Nooooo`03o`00
0?oooooooooo04Gooooo0ol0001?ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
1?ooool004Sooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`10ooooo`Co0000D_oo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Cooooo0019ooooo`03o`000?oooooo
oooo05cooooo00?o0000ooooooooool0??ooool3o`0005Oooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`04ooooo`00B_ooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo
03Sooooo0ol0001Kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool01?ooool004_o
oooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`0cooooo`Co0000Goooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo001<ooooo`03o`000?oooooooooo05cooooo
00?o0000ooooooooool0;oooool3o`0006Cooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`03ooooo`00COooool2o`0005gooooo00?o0000ooooooooool0:oooool3o`0006Oooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`03ooooo`00Coooool00ol0003oooooooooo`1K
ooooo`03o`000?oooooooooo02Oooooo0ol0001[ooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool00oooool0053ooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`0Roooo
o`Co0000Koooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00?ooooo001Aooooo`03
o`000?oooooooooo05_ooooo00?o0000ooooooooool07_ooool3o`0007Cooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`03ooooo`00D_ooool00ol0003oooooooooo`1Kooooo`03o`00
0?oooooooooo01[ooooo0ol0001hooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
0oooool005?ooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`0Eooooo`Co0000Nooo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00?ooooo001Dooooo`;o0000G?ooool0
0ol0003oooooooooo`0Aooooo`?o0000P?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo00?ooooo001Fooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool03Oooool3o`00
08Cooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`02ooooo`00Eoooool00ol0003o
ooooooooo`1Jooooo`03o`000?oooooooooo00Sooooo1?l00028ooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool00_ooool005Sooooo00?o0000ooooooooool0F_ooool00ol0003ooooo
ooooo`04ooooo`?o0000SOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00;ooooo
001Iooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool00ol0002@ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool00_ooool005[ooooo00?o0000ooooooooool0F_ooool2
o`0009Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`02ooooo`00Foooool00ol0
003oooooooooo`1Iooooo`03o`000?oooooooooo09Cooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`02ooooo`00G?ooool2o`0005Wooooo00?o0000ooooooooool0UOooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo001Nooooo`03o`000?oooooooooo05Kooooo
00?o0000ooooooooool0U_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo
001Oooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0U_ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo007ooooo001Pooooo`03o`000?oooooooooo05Cooooo00?o0000
ooooooooool0Uoooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo007ooooo001Qoooo
o`03o`000?oooooooooo05?ooooo00?o0000ooooooooool0V?ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo007ooooo001Rooooo`03o`000?oooooooooo05;ooooo00?o0000oooooooo
ool0VOooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo007ooooo001Sooooo`;o0000
D_ooool00ol0003oooooooooo`2Jooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
0Oooool006Gooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`2Jooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool00Oooool006Kooooo00?o0000ooooooooool0C_ooool0
0ol0003oooooooooo`2Kooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00Oooool0
06Oooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`2Looooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool00Oooool006Sooooo00?o0000ooooooooool0C?ooool00ol0003o
ooooooooo`2Mooooo`03o`000?oooooooooo00_ooooo0Ol00001ooooo`7ooooo001Yooooo`03o`00
0?oooooooooo04_ooooo00?o0000ooooooooool0WOooool00ol0003oooooooooo`0;ooooo`7o0000
0Oooool1ooooo`00J_ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo09kooooo00?o
0000ooooooooool02_ooool1o`00007ooooo0Oooool006_ooooo0_l0001:ooooo`03o`000?oooooo
oooo09oooooo00?o0000ooooooooool02Oooool1o`00007ooooo0Oooool006gooooo00?o0000oooo
ooooool0Aoooool00ol0003oooooooooo`2Pooooo`03o`000?oooooooooo00Sooooo0Ol00001oooo
o`7ooooo001^ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0XOooool00ol0003o
ooooooooo`07ooooo`7o00000Oooool1ooooo`00Koooool00ol0003oooooooooo`15ooooo`03o`00
0?oooooooooo0:7ooooo00?o0000ooooooooool01oooool1o`00007ooooo0Oooool0073ooooo00?o
0000ooooooooool0A?ooool00ol0003oooooooooo`2Rooooo`03o`000?oooooooooo00Kooooo0Ol0
0001ooooo`7ooooo001aooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0Xoooool0
0ol0003oooooooooo`05ooooo`7o00000Oooool1ooooo`00L_ooool2o`0004;ooooo00?o0000oooo
ooooool0YOooool00ol0003oooooooooo`05ooooo`7o00000Oooool007Cooooo00?o0000oooooooo
ool0?oooool00ol0003oooooooooo`2Vooooo`03o`000?oooooooooo00Cooooo0Ol00001ooooo`00
MOooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo0:Kooooo00?o0000ooooooooool0
1?ooool1o`00007ooooo001fooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0Yooo
ool00ol0003oooooooooo`03ooooo`7o00000Oooool007Oooooo00?o0000ooooooooool0??ooool0
0ol0003oooooooooo`2Xooooo`03o`000?oooooooooo00;ooooo0Ol00001ooooo`00N?ooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo0:Wooooo00Go0000ooooooooooooooooo`000001
ooooo`00NOooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo0:[ooooo00Co0000oooo
oooooooo00000Oooool007[ooooo0_l0000jooooo`03o`000?oooooooooo0:[ooooo00Co0000oooo
oooooooo00000Oooool007cooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`2[oooo
o`03o`000?oooooooooo007o0000001mooooo`03o`000?oooooooooo03Kooooo00?o0000oooooooo
ool0[?ooool1o`00007ooooo0Ol0000007kooooo00?o0000ooooooooool0=Oooool00ol0003ooooo
ooooo`2]ooooo`;o0000001oooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0[?oo
ool3o`000000P?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo0:Sooooo1?l00003
ooooo`00POooool2o`0003?ooooo00?o0000ooooooooool0YOooool3o`0000Oooooo0023ooooo`03
o`000?oooooooooo033ooooo00?o0000ooooooooool0XOooool4o`0000[ooooo0024ooooo`03o`00
0?oooooooooo02oooooo00?o0000ooooooooool0WOooool4o`0000kooooo0025ooooo`03o`000?oo
oooooooo02kooooo00?o0000ooooooooool0VOooool4o`0001;ooooo0026ooooo`03o`000?oooooo
oooo02gooooo00?o0000ooooooooool0UOooool4o`0001Kooooo0027ooooo`03o`000?oooooooooo
02cooooo00?o0000ooooooooool0T_ooool3o`0001[ooooo0028ooooo`;o0000;?ooool00ol0003o
ooooooooo`2>ooooo`Co00007Oooool008[ooooo00?o0000ooooooooool0:Oooool00ol0003ooooo
ooooo`2:ooooo`Co00008Oooool008_ooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`26ooooo`Co00009Oooool008cooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`22
ooooo`Co0000:Oooool008gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1ooooo
o`?o0000;Oooool008kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1kooooo`Co
0000<?ooool008oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1gooooo`Co0000
=?ooool0093ooooo0_l0000Tooooo`03o`000?oooooooooo07?ooooo1?l0000hooooo`00T_ooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo073ooooo0ol0000looooo`00Toooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo06cooooo1?l0000oooooo`00U?ooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo06Sooooo1?l00013ooooo`00UOooool00ol0003ooooo
ooooo`0Nooooo`03o`000?oooooooooo06Cooooo1?l00017ooooo`00U_ooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo063ooooo1?l0001;ooooo`00Uoooool2o`0001gooooo00?o0000
ooooooooool0GOooool3o`0004oooooo002Iooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool0FOooool4o`0005;ooooo002Jooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool0EOooool4o`0005Kooooo002Kooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
DOooool4o`0005[ooooo002Looooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0COoo
ool4o`0005kooooo002Mooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0B_ooool3
o`0006;ooooo002Nooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0A_ooool4o`00
06Gooooo002Oooooo`;o00005?ooool00ol0003oooooooooo`13ooooo`Co0000JOooool00:7ooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0oooooo`Co0000KOooool00:;ooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`0kooooo`Co0000LOooool00:?ooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`0hooooo`?o0000MOooool00:Cooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0dooooo`Co0000N?ooool00:Gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0`ooooo`Co0000O?ooool00:Kooooo0_l0000=ooooo`03o`00
0?oooooooooo02cooooo1?l00020ooooo`00Z?ooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo02Wooooo0ol00024ooooo`00ZOooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo02Gooooo1?l00027ooooo`00Z_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
027ooooo1?l0002;ooooo`00Zoooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01go
oooo1?l0002?ooooo`00[?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Wooooo
1?l0002Cooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Kooooo0ol0
002Gooooo`00[_ooool2o`0000Gooooo00?o0000ooooooooool04_ooool4o`0009[ooooo002`oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03_ooool4o`0009kooooo002aooooo`05
o`000?ooooooooooooooool000003?ooool4o`000:;ooooo002booooo`04o`000?ooooooooooo`00
00Sooooo1?l0002Vooooo`00/oooool00ol0003oooooo`000005ooooo`?o0000Z_ooool00;Cooooo
0_l000000ooooooo0000o`000002o`000:gooooo002eooooo`;o0000/Oooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {319.688, 0}} -> {-0.0710364, -0.0181728, \
0.0035149, 0.0035149}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .89104 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-16 1.0656 -0.0363427 1.0656 [
[.02544 .21571 -12 -8.9133 ]
[.02544 .21571 0 .0867 ]
[.16074 .16277 -11.6592 -9 ]
[.16074 .16277 .34081 0 ]
[.3021 .10747 -5.60025 -9 ]
[.3021 .10747 .39975 0 ]
[.44992 .04965 -5.37091 -9 ]
[.44992 .04965 .62909 0 ]
[.60467 -0.01084 -5.14157 -9 ]
[.60467 -0.01084 .85843 0 ]
[.66454 .05085 0 -6.20675 ]
[.66454 .05085 6 2.79325 ]
[.80797 .25198 0 -6.0417 ]
[.80797 .25198 6 2.9583 ]
[.93071 .4241 0 -5.90576 ]
[.93071 .4241 6 3.09424 ]
[.02254 .22988 -12 -2.74631 ]
[.02254 .22988 0 6.25369 ]
[.0142 .29178 -24 -2.78907 ]
[.0142 .29178 0 6.21093 ]
[.00558 .35578 -6 -2.83339 ]
[.00558 .35578 0 6.16661 ]
[-0.00334 .42198 -18 -2.87938 ]
[-0.00334 .42198 0 6.12062 ]
[-0.01257 .49051 -6 -2.92712 ]
[-0.01257 .49051 0 6.07288 ]
[ 0 0 0 0 ]
[ 1 .89104 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03495 .22504 m
.61241 0 L
s
.03495 .22504 m
.03971 .2297 L
s
[(-2)] .02544 .21571 1 .98073 Mshowa
.16988 .17246 m
.17445 .1773 L
s
[(-1)] .16074 .16277 .9432 1 Mshowa
.31082 .11753 m
.31518 .12256 L
s
[(0)] .3021 .10747 .86675 1 Mshowa
.45818 .0601 m
.46231 .06533 L
s
[(1)] .44992 .04965 .7903 1 Mshowa
.61241 0 m
.61628 .00542 L
s
[(2)] .60467 -0.01084 .71386 1 Mshowa
.125 Mabswid
.06148 .2147 m
.06431 .21752 L
s
.08823 .20428 m
.09104 .20712 L
s
.11521 .19376 m
.118 .19663 L
s
.14243 .18316 m
.14519 .18604 L
s
.19758 .16166 m
.20029 .16459 L
s
.22551 .15078 m
.22821 .15373 L
s
.2537 .13979 m
.25637 .14277 L
s
.28213 .12871 m
.28478 .13171 L
s
.33977 .10625 m
.34236 .10929 L
s
.36897 .09487 m
.37153 .09794 L
s
.39844 .08339 m
.40097 .08648 L
s
.42817 .0718 m
.43068 .07491 L
s
.48846 .0483 m
.49091 .05146 L
s
.51902 .03639 m
.52144 .03958 L
s
.54986 .02437 m
.55225 .02758 L
s
.58099 .01224 m
.58335 .01547 L
s
.25 Mabswid
.61241 0 m
.97291 .505 L
s
.65208 .05558 m
.64586 .05794 L
s
[(0)] .66454 .05085 -1 .37928 Mshowa
.79537 .2563 m
.78907 .25846 L
s
[(2)] .80797 .25198 -1 .3426 Mshowa
.91799 .42808 m
.91164 .43006 L
s
[(4)] .93071 .4241 -1 .31239 Mshowa
.125 Mabswid
.69012 .10886 m
.68637 .11025 L
s
.72662 .16 m
.72286 .16135 L
s
.76168 .2091 m
.75791 .21042 L
s
.82778 .3017 m
.82399 .30297 L
s
.85897 .3454 m
.85518 .34664 L
s
.88903 .3875 m
.88522 .38871 L
s
.94594 .46722 m
.94211 .46839 L
s
.25 Mabswid
.03495 .22504 m
0 .48612 L
s
.03495 .22504 m
.04116 .22262 L
s
[(-1)] .02254 .22988 1 -0.38971 Mshowa
.02665 .28704 m
.03288 .28468 L
s
[(-0.5)] .0142 .29178 1 -0.38021 Mshowa
.01807 .35115 m
.02431 .34884 L
s
[(0)] .00558 .35578 1 -0.37036 Mshowa
.00919 .41747 m
.01546 .41521 L
s
[(0.5)] -0.00334 .42198 1 -0.36014 Mshowa
0 .48612 m
.00629 .48392 L
s
[(1)] -0.01257 .49051 1 -0.34953 Mshowa
.125 Mabswid
.03331 .23728 m
.03704 .23583 L
s
.03166 .2496 m
.03539 .24816 L
s
.03 .262 m
.03373 .26056 L
s
.02833 .27448 m
.03207 .27305 L
s
.02496 .29969 m
.0287 .29828 L
s
.02325 .31243 m
.02699 .31102 L
s
.02154 .32525 m
.02528 .32385 L
s
.01981 .33816 m
.02355 .33676 L
s
.01632 .36423 m
.02007 .36285 L
s
.01455 .37741 m
.01831 .37603 L
s
.01278 .39067 m
.01653 .3893 L
s
.01099 .40402 m
.01475 .40266 L
s
.00738 .43101 m
.01114 .42966 L
s
.00555 .44464 m
.00932 .4433 L
s
.00371 .45837 m
.00748 .45704 L
s
.00186 .4722 m
.00563 .47087 L
s
.25 Mabswid
.03495 .22504 m
0 .48612 L
s
0 .48612 m
.46953 .89104 L
s
.46953 .89104 m
.47294 .65459 L
s
.47294 .65459 m
.03495 .22504 L
s
.61241 0 m
.97291 .505 L
s
.97291 .505 m
1 .75117 L
s
1 .75117 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.03495 .22504 m
0 .48612 L
s
0 .48612 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.61241 0 m
.03495 .22504 L
s
.47294 .65459 m
.97291 .505 L
s
.97291 .505 m
1 .75117 L
s
1 .75117 m
.46953 .89104 L
s
.46953 .89104 m
.47294 .65459 L
s
0 0 m
1 0 L
1 .89104 L
0 .89104 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.41068 .51539 m
.42565 .51157 L
s
.42565 .51157 m
.44071 .50757 L
s
1 0 .6 r
.40039 .48961 m
.41479 .48526 L
s
1 0 0 r
.44071 .50757 m
.4558 .50333 L
s
.8 0 1 r
.39134 .46625 m
.40552 .46168 L
s
1 0 .6 r
.41479 .48526 m
.42924 .48084 L
s
.2 0 1 r
.38298 .44392 m
.39708 .43923 L
s
1 0 0 r
.4558 .50333 m
.47083 .49881 L
s
0 .4 1 r
.37493 .42199 m
.38899 .41723 L
s
.8 0 1 r
.40552 .46168 m
.41976 .45707 L
s
0 1 1 r
.36698 .40019 m
.38103 .39537 L
s
1 0 .6 r
.42924 .48084 m
.44372 .47633 L
s
.2 0 1 r
.39708 .43923 m
.41123 .43452 L
s
0 1 .4 r
.35906 .37841 m
.3731 .37355 L
s
1 0 0 r
.47083 .49881 m
.48572 .494 L
s
.2 1 0 r
.35115 .35663 m
.36518 .35171 L
s
0 .4 1 r
.38899 .41723 m
.40311 .41245 L
s
.8 0 1 r
.41976 .45707 m
.43403 .45241 L
s
.8 1 0 r
.34323 .33482 m
.35725 .32985 L
s
0 1 1 r
.38103 .39537 m
.39513 .39054 L
s
1 0 .6 r
.44372 .47633 m
.4582 .4717 L
s
1 .6 0 r
.3353 .31298 m
.34931 .30796 L
s
.2 0 1 r
.41123 .43452 m
.42544 .42978 L
s
0 1 .4 r
.3731 .37355 m
.3872 .36866 L
s
.2 1 0 r
.36518 .35171 m
.37927 .34677 L
s
1 0 0 r
.48572 .494 m
.5004 .48893 L
s
0 .4 1 r
.40311 .41245 m
.41729 .40765 L
s
.8 0 1 r
.43403 .45241 m
.44835 .4477 L
s
.8 1 0 r
.35725 .32985 m
.37133 .32486 L
s
0 1 1 r
.39513 .39054 m
.4093 .38568 L
s
1 0 .6 r
.4582 .4717 m
.47267 .46696 L
s
1 .6 0 r
.34931 .30796 m
.36339 .30292 L
s
.2 0 1 r
.42544 .42978 m
.4397 .42501 L
s
0 1 .4 r
.3872 .36866 m
.40135 .36375 L
s
.2 1 0 r
.37927 .34677 m
.39342 .34181 L
s
0 .4 1 r
.41729 .40765 m
.43153 .40282 L
s
1 0 0 r
.5004 .48893 m
.51483 .48363 L
s
.8 0 1 r
.44835 .4477 m
.46271 .44294 L
s
.8 1 0 r
.37133 .32486 m
.38547 .31985 L
s
0 1 1 r
.4093 .38568 m
.42353 .3808 L
s
1 0 .6 r
.47267 .46696 m
.48711 .46211 L
s
1 .6 0 r
.36339 .30292 m
.37752 .29786 L
s
.2 0 1 r
.4397 .42501 m
.45402 .42021 L
s
0 1 .4 r
.40135 .36375 m
.41557 .35882 L
s
.2 1 0 r
.39342 .34181 m
.40763 .33683 L
s
0 .4 1 r
.43153 .40282 m
.44583 .39797 L
s
.8 0 1 r
.46271 .44294 m
.47709 .43813 L
s
1 0 0 r
.51483 .48363 m
.52903 .47817 L
s
.8 1 0 r
.38547 .31985 m
.39968 .31481 L
s
0 1 1 r
.42353 .3808 m
.43782 .3759 L
s
1 0 .6 r
.48711 .46211 m
.50152 .45717 L
s
1 .6 0 r
.37752 .29786 m
.39171 .29277 L
s
.2 0 1 r
.45402 .42021 m
.46839 .41537 L
s
0 1 .4 r
.41557 .35882 m
.42985 .35387 L
s
.2 1 0 r
.40763 .33683 m
.4219 .33183 L
s
0 .4 1 r
.44583 .39797 m
.46019 .39309 L
s
.8 0 1 r
.47709 .43813 m
.49151 .43327 L
s
.8 1 0 r
.39968 .31481 m
.41394 .30976 L
s
0 1 1 r
.43782 .3759 m
.45217 .37098 L
s
1 0 0 r
.52903 .47817 m
.54304 .47261 L
s
1 0 .6 r
.50152 .45717 m
.51589 .45214 L
s
1 .6 0 r
.39171 .29277 m
.40597 .28767 L
s
.2 0 1 r
.46839 .41537 m
.48281 .41051 L
s
0 1 .4 r
.42985 .35387 m
.4442 .34889 L
s
.2 1 0 r
.4219 .33183 m
.43623 .3268 L
s
0 .4 1 r
.46019 .39309 m
.4746 .38819 L
s
.8 0 1 r
.49151 .43327 m
.50596 .42837 L
s
.8 1 0 r
.41394 .30976 m
.42827 .30468 L
s
0 1 1 r
.45217 .37098 m
.46658 .36603 L
s
1 0 .6 r
.51589 .45214 m
.53025 .44706 L
s
1 .6 0 r
.40597 .28767 m
.42029 .28254 L
s
.2 0 1 r
.48281 .41051 m
.49728 .40562 L
s
0 1 .4 r
.4442 .34889 m
.4586 .3439 L
s
.2 1 0 r
.43623 .3268 m
.45063 .32175 L
s
0 .4 1 r
.4746 .38819 m
.48908 .38327 L
s
.8 0 1 r
.50596 .42837 m
.52044 .42343 L
s
.8 1 0 r
.42827 .30468 m
.44266 .29958 L
s
0 1 1 r
.46658 .36603 m
.48105 .36106 L
s
1 .6 0 r
.42029 .28254 m
.43467 .27739 L
s
0 1 .4 r
.4586 .3439 m
.47307 .33888 L
s
.2 0 1 r
.49728 .40562 m
.51181 .4007 L
s
.2 1 0 r
.45063 .32175 m
.46509 .31668 L
s
0 .4 1 r
.48908 .38327 m
.50362 .37832 L
s
.8 1 0 r
.44266 .29958 m
.45711 .29446 L
s
0 1 1 r
.48105 .36106 m
.49559 .35607 L
s
1 .6 0 r
.43467 .27739 m
.44912 .27221 L
s
0 1 .4 r
.47307 .33888 m
.4876 .33384 L
s
.2 1 0 r
.46509 .31668 m
.47962 .31159 L
s
.8 1 0 r
.45711 .29446 m
.47163 .28932 L
s
1 .6 0 r
.44912 .27221 m
.46363 .26702 L
s
0 g
.25 Mabswid
.61241 0 m
.97291 .505 L
s
.97291 .505 m
1 .75117 L
s
1 .75117 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.03495 .22504 m
0 .48612 L
s
0 .48612 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.61241 0 m
.03495 .22504 L
s
.03495 .22504 m
.61241 0 L
s
.03495 .22504 m
.03971 .2297 L
s
[(-2)] .02544 .21571 1 .98073 Mshowa
.16988 .17246 m
.17445 .1773 L
s
[(-1)] .16074 .16277 .9432 1 Mshowa
.31082 .11753 m
.31518 .12256 L
s
[(0)] .3021 .10747 .86675 1 Mshowa
.45818 .0601 m
.46231 .06533 L
s
[(1)] .44992 .04965 .7903 1 Mshowa
.61241 0 m
.61628 .00542 L
s
[(2)] .60467 -0.01084 .71386 1 Mshowa
.125 Mabswid
.06148 .2147 m
.06431 .21752 L
s
.08823 .20428 m
.09104 .20712 L
s
.11521 .19376 m
.118 .19663 L
s
.14243 .18316 m
.14519 .18604 L
s
.19758 .16166 m
.20029 .16459 L
s
.22551 .15078 m
.22821 .15373 L
s
.2537 .13979 m
.25637 .14277 L
s
.28213 .12871 m
.28478 .13171 L
s
.33977 .10625 m
.34236 .10929 L
s
.36897 .09487 m
.37153 .09794 L
s
.39844 .08339 m
.40097 .08648 L
s
.42817 .0718 m
.43068 .07491 L
s
.48846 .0483 m
.49091 .05146 L
s
.51902 .03639 m
.52144 .03958 L
s
.54986 .02437 m
.55225 .02758 L
s
.58099 .01224 m
.58335 .01547 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 256.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001@2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00gOooool5o`0008Kooooo003Mooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0Q_ooool00=ko
oooo00?oV9RHob4Q8Oo^k^h0Qoooool00=oooooo00?oV9RHob4Q8Oo^k^h0Q_ooool00>3ooooo00?o
MgMgofIVI_ooool0QOooool00>7ooooo00?o0000ooooooooool0Q?ooool00=gooooo00Go0000okZj
^_ooooooV9RHoa0@4026ooooo`00gOooool01OnHV9So410@o`000?lQ8B7oc<c<08Kooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003Tooooo`;o0000P_ooool0
0>7ooooo0ol000000ooooooo0000ooooo`21ooooo`00goooool2o`0000Cooooo0_l00021ooooo`00
g?ooool3o`0000Kooooo00?o0000ooooool00000P?ooool00=[ooooo0_l00009ooooo`03o`000?oo
oooo0000083ooooo003Gooooo`?o000000?oooooo`000?ooool02?ooool01?l0003oooooooooool0
001oooooo`00e?ooool3o`0000Cooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooo
oooo000007kooooo003Booooo`;o00004Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo07_ooooo002Zooooo`Co000000?o410@ooooooooool07_ooool3o`0001?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1kooooo`00[?ooool00ol0003oooooooooo`0Nooooo`;o
000000?oooooo`000?ooool04oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07[o
oooo002/ooooo`03o`000?oooooooooo01_ooooo0ol00004ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`1iooooo`00[?ooool00ol0003ooooooooo
o`0Iooooo`;o00006oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo07Wooooo002/
ooooo`03o`000?oooooooooo01Kooooo0ol0000Mooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool02?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^06_ooooo002/ooooo`03o`000?oooooo
oooo01Cooooo0_l000000ooooooo0000ooooo`0Mooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01oooool01OmgMgOoV9RHoooooonHV9SoMgMg06_ooooo002/ooooo`03o`000?oooooo
oooo017ooooo0ol00004ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`06ooooo`05oa0@4?ooooooooooooooool@4100Joooool00:[ooooo00?oEEEE
ofIVI_l000004Oooool2o`0002Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06
ooooo`05o`000?ooooooooooooooool00000Joooool00;_ooooo0ol0000Wooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000006_ooooo002i
ooooo`;o000000?oooooo`000?ooool09oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Cooooo00Go410@oooooooooooooooooa0@401[ooooo`00]_ooool3o`0000Cooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`1[ooooo`00/oooool3o`0002oooooo00?o0000ooooooooool02Oooool2
o`0000Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1[ooooo`00/Oooool2o`0003;ooooo00?o0000
ooooooooool02?ooool01?l0003oooooooooool0001dooooo`00[_ooool3o`000003ooooool0003o
oooo037ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1aooooo`00[?ooool2o`00
00Gooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
077ooooo002Yooooo`?o0000>_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo073o
oooo002Wooooo`;o0000?Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo06oooooo
002Tooooo`?o000000?oooooo`000?ooool0??ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo06oooooo002Rooooo`;o0000@_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo06kooooo001gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08oooool3o`0004Cooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1]ooooo`00Moooool01OmgMgOoV9RHoooooonHV9So
MgMg027ooooo0_l00017ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0K?ooool0
07Oooooo00Go410@oooooooooooooooooa0@400Nooooo`?o00000_ooool00ol0003oooooooooo`14
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0K?ooool007Oooooo00Go0000oooo
ooooooooooooo`00000Looooo`;o0000C?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo06_ooooo001gooooo`05o`000?ooooooooooooooool000006Oooool3o`0004kooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`1Zooooo`00Moooool01Ol@413ooooooooooooooooo
410@01Kooooo0ol0001Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0J_ooool0
07Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Dooooo`;o00000oooool00ol0003oooooooooo`1>
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0JOooool007Oooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Aooooo`?o0000E_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo06Sooooo002;ooooo`;o0000FOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
06Sooooo0028ooooo`?o0000Foooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo06Oo
oooo0026ooooo`;o00000oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo01Gooooo
0_l0001Xooooo`00Poooool3o`00063ooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`1Uooooo`00POooool2o`0006?ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1U
ooooo`00O_ooool4o`0006Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`1Toooo
o`00O?ooool2o`0000Cooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo06?ooooo001iooooo`?o0000J_ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo06?ooooo001gooooo`;o0000KOooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo06;ooooo001dooooo`?o000000?oooooo`000?ooool0K?ooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo067ooooo001aooooo`?o0000L_ooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo063ooooo0019ooooo`Co000000?o410@ooooooooool07oooool2o`0007Go
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1Pooooo`00Boooool00ol0003ooooo
ooooo`0Nooooo`?o0000Moooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo05oooooo
0010ooooo`Ko00001Oooool00ol0003oooooooooo`0Looooo`;o00000_ooool00ol0003ooooooooo
o`1eooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0G_ooool004_ooooo00?o0000
ooooooooool06Oooool3o`0007cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1N
ooooo`00Boooool00ol0003oooooooooo`0Gooooo`;o0000Ooooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo05gooooo001;ooooo`03o`000?oooooooooo01Cooooo0ol00021ooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0G?ooool004_ooooo00?o0000ooooooooool0
4_ooool2o`0000?ooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo05_ooooo0019ooooo`03oeEEEOmVIVKo0000017ooooo0ol00026ooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool0Foooool005_ooooo0_l00029ooooo`03o`000?oooooo
oooo027ooooo0_l0001Looooo`00F?ooool3o`000003ooooool0003ooooo08Sooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`1Iooooo`00E_ooool2o`0008kooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`1Iooooo`00Doooool3o`00093ooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`1Hooooo`00D?ooool3o`0009?ooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1Gooooo`00C_ooool2o`0000;ooooo00?o0000ooooooooool0TOooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo05Kooooo001;ooooo`?o00001Oooool00ol0
003oooooooooo`2@ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0E_ooool004Wo
oooo0_l0002Kooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0EOooool004Kooooo
1?l0002Looooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0E?ooool004Cooooo0_l0
002Pooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0E?ooool001[ooooo1Ol0000R
ooooo`?o0000X_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo05?ooooo000Joooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@08?ooool2o`000:Gooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`1Booooo`004_ooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h07_ooool3o`00
0003ooooool0003ooooo0:Cooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`1Aoooo
o`007?ooool00onHV9So8B4Qonk^kP0Kooooo`;o0000Z_ooool00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo057ooooo000Mooooo`03ogMgMomVIVKooooo01Oooooo0ol0002]ooooo`03o`00
0?oooooooooo02_ooooo00?o0000ooooooooool0D?ooool001kooooo00?o0000ooooooooool05?oo
ool2o`000;3ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`1?ooooo`006_ooool0
1Ol0003o^[ZjoooooonHV9So410@01?ooooo0ol00002ooooo`03o`000?oooooooooo0:gooooo00?o
0000ooooooooool0;?ooool2o`00053ooooo000Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`04?oo
ool3o`000;Gooooo00?o0000ooooooooool0;?ooool2o`00053ooooo000]ooooo`;o0000^?ooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo04gooooo000Zooooo`?o000000?oooooo`00
0?ooool0]oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo04gooooo000Xooooo`;o
0000_Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo04cooooo000Uooooo`?o0000
_oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo04_ooooo000Tooooo`;o0000`Ooo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo04[ooooo000Jooooo`Co000000?o410@
ooooooooool00oooool00ol0003oooooo`000030ooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool0B_ooool001cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0002o
ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0BOooool0017ooooo1_l00005oooo
o`03o`000?oooooooooo00Gooooo0_l00002ooooo`03o`000?oooooooooo0;cooooo00?o0000oooo
ooooool0<oooool00ol0003oooooooooo`18ooooo`007?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0^oooool00ol0003oooooooooo`0cooooo`03
o`000?oooooooooo00Oooooo1Ol0000looooo`007?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo00Kooooo00GoV9RHob4Q8Oo^k^koooooodA4A00looooo`007?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00ol0003ooooo
ooooo`0eooooo`03o`000?oooooooooo00Kooooo00?oV9RHob4Q8Oo^k^h0?Oooool001cooooo00?o
0000ooooooooool01?ooool3o`0000Kooooo00?o0000ooooooooool0^?ooool00ol0003ooooooooo
o`0fooooo`03o`000?oooooooooo00Kooooo00?oV9RHob4Q8Oo^k^h0??ooool001[ooooo00?oEEEE
ofIVI_l000001_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;Oooooo00?o0000
ooooooooool0=_ooool00ol0003oooooooooo`07ooooo`03ogMgMomVIVKooooo03_ooooo000Soooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0]_ooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0>_ooool002?ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`2eooooo`03o`000?oooooooooo03Oooooo0_l00004ooooo`05
o`000?nj^[[ooooooiRHV?l@4100??ooool002?ooooo0_l0000;ooooo`03o`000?oooooooooo0;Co
oooo00?o0000ooooooooool0=_ooool00ol0003oooooo`000004ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`0??ooool002?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`2cooooo`03
o`000?oooooooooo03Wooooo00?o0000ooooooooool0@_ooool002;ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0
@Oooool002;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1kooooo`?ooiT0<_oo
ool2o`0003gooooo00?o0000ooooooooool0@?ooool002;ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`1gooooo`?ooiT0<_ooool3o`000003ooooool0003ooooo03cooooo00?o0000
ooooooooool0@?ooool002;ooooo0_l0000Aooooo`03o`000?oooooooooo07?ooooo0oooV@0boooo
o`?o00001Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo03oooooo000Rooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool0L?ooool2oonI03;ooooo0ol00009ooooo`03
o`000?oooooooooo03_ooooo00?o0000ooooooooool0?_ooool002;ooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`1/ooooo`?ooiT0<Oooool3o`0000gooooo00?o0000ooooooooool0
>_ooool00ol0003oooooooooo`0nooooo`008_ooool3o`0001?ooooo00?o0000ooooooooool0J?oo
ool3oonI037ooooo0ol0000Aooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0?Ooo
ool002;ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Sooooo`CooiT0<_ooool2
o`0001Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0looooo`008Oooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo05oooooo0oooV@0Fooooo`;oc?l06oooool3o`00
01Oooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0kooooo`001oooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01?ooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo05cooooo0_ooV@0Fooooo`?oc?l06_ooool3
o`0001_ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0kooooo`001oooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`1Iooooo`;ooiT05Oooool3olco01[ooooo0ol0000O
ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0>_ooool000Go00000_ooool01Ol@
413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00_ooool2o`0001[ooooo00?o0000
ooooooooool0EOooool3oonI01?ooooo1?o<o`0Jooooo`?o00008oooool00ol0003oooooooooo`0j
ooooo`03o`000?oooooooooo03Wooooo0007ooooo`05o`000?ooooooooooooooool000003oooool0
0omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0D?ooool4
oonI01Cooooo0_o<o`0Looooo`;o00009_ooool00ol0003oooooooooo`0jooooo`;o0000>_ooool0
00Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?oo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo04cooooo0oooV@0Fooooo`;oc?l06ooo
ool3o`0002Wooooo00?o0000ooooooooool0>Oooool2o`0003[ooooo0007ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool0BOooool2oonI01Kooooo0oo<o`0Jooooo`?o0000;Oooool00ol0003ooooooooo
o`0jooooo`03o`000?oooooooooo03Oooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?oo
ool00ol0003oooooooooo`06ooooo`;o00007_ooool00ol0003oooooooooo`16ooooo`;ooiT05Ooo
ool3olco01Cooooo0_lco`04ooooo`?o0000<Oooool00ol0003oooooooooo`0iooooo`03o`000?oo
oooooooo03Oooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Cooooo0_l0
000Pooooo`03o`000?oooooooooo04Cooooo00?ooiT0ooooooooool04Oooool4olco01Cooooo0olc
o`03ooooo`?o0000=Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo03Kooooo000P
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0E?ooool3olco01Kooooo0_lco`03
ooooo`?o0000>?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03Gooooo000Poooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool0DOooool2olco01Kooooo0olco`03oooo
o`;o0000??ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03Cooooo000Pooooo`;o
00008oooool00ol0003oooooooooo`1>ooooo`;oc?l05Oooool3oc?o00?ooooo0ol0000oooooo`03
o`000?oooooooooo03Wooooo00?o0000ooooooooool0=?ooool0023ooooo00?o0000ooooooooool0
8oooool00ol0003oooooooooo`1:ooooo`?oc?l04oooool4oc?o00?ooooo0ol00013ooooo`03o`00
0?oooooooooo03Wooooo00?o0000ooooooooool0<oooool0023ooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`15ooooo`Coc?l05?ooool2oc?o00Cooooo0ol00017ooooo`03o`000?oo
oooooooo03Wooooo00?o0000ooooooooool0<_ooool0023ooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`11ooooo`?oc?l05_ooool2oc?o00?ooooo0ol0001:ooooo`03o`000?oooooo
oooo03Wooooo00?o0000ooooooooool0<_ooool0023ooooo00?o0000ooooooooool09_ooool2o`00
043ooooo00?oc?l0ooooooooool05?ooool3oc?o00?ooooo0_l0000?ooooo`?o0?mV??ooool00ol0
003oooooooooo`0iooooo`03o`000?oooooooooo037ooooo000Oooooo`?o0000:Oooool00ol0003o
ooooooooo`1Aooooo`?o<ol00oooool3o`0000kooooo0ol0ofI0ooooo`03o`000?oooooooooo03Wo
oooo00?o0000ooooooooool0<?ooool001oooooo00?o0000ooooooooool0:_ooool00ol0003ooooo
ooooo`1<ooooo`Co<ol00oooool3o`0000kooooo0ol0ofI4ooooo`03o`000?oooooooooo03Wooooo
00?o0000ooooooooool0;oooool001oooooo00?o0000ooooooooool0:oooool00ol0003ooooooooo
o`18ooooo`?o<ol01?ooool3o`0000oooooo0_l0ofI7ooooo`03o`000?oooooooooo03Wooooo00?o
0000ooooooooool0;oooool001oooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`15
ooooo`;o<ol01?ooool3o`0000oooooo0ol0ofI:ooooo`03o`000?oooooooooo03Sooooo0_l0000`
ooooo`007oooool3o`0002gooooo00?o0000ooooooooool0@_ooool2oc?o00?ooooo0ol0000@oooo
o`;o0?mVC_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02gooooo000Oooooo`03
o`000?oooooooooo02kooooo00?o0000ooooooooool0?_ooool3oc?o00?ooooo0_l0000@ooooo`?o
0?mVDOooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02gooooo000Dooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo03[o
oooo0olco`03ooooo`?o00003oooool3o`3oIQCooooo0_l0ooloooooo`03o`000?oooooooooo03So
oooo00?o0000ooooooooool0;?ooool001Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool0??ooool3o`0000kooooo1?l0ofHDooooo`?o
0?oo@Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02_ooooo000Dooooo`05oa0@
4?ooooooooooooooool@41001Oooool2o`0003?ooooo00?o0000ooooooooool0>?ooool3o`0000oo
oooo0_l0ofHFooooo`;o0?ooAOooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02[o
oooo000Dooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`0cooooo`03
o`000?oooooooooo03Cooooo0ol0000?ooooo`?o0?mV5Oooool3o`3oodSooooo00?o0000oooooooo
ool0>?ooool00ol0003oooooooooo`0Zooooo`005?ooool01Ol0003ooooooooooooooooo000000Go
oooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0`ooooo`?o00003_ooool4o`3oIQGo
oooo0ol0oom<ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0:Oooool001Cooooo
00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo03Gooooo00?o0000oooooooo
ool0;Oooool2o`0000kooooo0ol0ofHFooooo`?o0?ooD?ooool00ol0003oooooooooo`0hooooo`03
o`000?oooooooooo02Sooooo000Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003o
ooooooooo`0fooooo`03o`000?oooooooooo02Wooooo0ol0000>ooooo`;o0?mV5_ooool3o`3ooe?o
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Xooooo`005?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_l0000hooooo`03o`000?oooooooooo02Gooooo0ol0000?ooooo`;o
0?mV5Oooool3o`3ooeOooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Wooooo`00
7_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo027ooooo0ol0000Aooooo`03o`3o
I_oooooooooo017ooooo1?l0oolFooooo`?o06Ko@_ooool00ol0003oooooooooo`0hooooo`03o`00
0?oooooooooo02Kooooo000Mooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool07Ooo
ool3o`0002Gooooo0ol0oolFooooo`Co06KoA_ooool00ol0003oooooooooo`0hooooo`03o`000?oo
oooooooo02Gooooo000Mooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool06_ooool2
o`0002Kooooo0_l0oolFooooo`?o06KoBoooool00ol0003oooooooooo`0gooooo`03o`000?oooooo
oooo02Gooooo000Mooooo`;o0000?Oooool00ol0003oooooooooo`0Fooooo`?o00009_ooool2o`3o
oaKooooo0_l0I_m>ooooo`03o`000?oooooooooo03Oooooo0_l0000Vooooo`007Oooool00ol0003o
ooooooooo`0mooooo`03o`000?oooooooooo01;ooooo0ol0000Vooooo`?o0?oo5Oooool3o`1Voe7o
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Sooooo`007Oooool00ol0003ooooo
ooooo`0nooooo`03o`000?oooooooooo00kooooo0ol0000Uooooo`Co0?oo5Oooool3o`1VoeGooooo
00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Sooooo`007Oooool00ol0003ooooooooo
o`0oooooo`03o`000?oooooooooo00[ooooo0ol0000Uooooo`?o0?oo5_ooool3o`1VoeWooooo00?o
0000ooooooooool0=oooool00ol0003oooooooooo`0Rooooo`007Oooool00ol0003oooooooooo`10
ooooo`03o`000?oooooooooo00Kooooo0ol0000Wooooo`03o`3ooooooooooooo01Cooooo0ol0I_lF
ooooo`;o<`3oAOooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo027ooooo000Loooo
o`?o0000@_ooool00ol0003oooooooooo`03ooooo`;o0000?_ooool3o`1VoaKooooo0olc0?m7oooo
o`03o`000?oooooooooo03Sooooo00?o0000ooooooooool08?ooool001cooooo00?o0000oooooooo
ool0@oooool00ol0003oooooo`000002o`0003cooooo1?l0I_lFooooo`?o<`3oBoooool00ol0003o
ooooooooo`0gooooo`03o`000?oooooooooo023ooooo000Looooo`03o`000?oooooooooo04;ooooo
0ol0000looooo`?o06Ko5_ooool4oc<0odoooooo00?o0000ooooooooool0=oooool00ol0003ooooo
ooooo`09ooooo`;o000000?o410@ooooooooool04Oooool001cooooo00?o0000ooooooooool0?ooo
ool3o`0000?ooooo00?o0000ooooooooool0=oooool2o`1VoaKooooo0olc0?mDooooo`03o`000?oo
oooooooo03Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Booooo`007?ooool3
o`0003cooooo0ol00007ooooo`03o`000?oooooooooo03Cooooo0_l0I_lFooooo`;o<`3oF?ooool0
0ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Kooooo1Ol0000Cooooo`007?ooool00ol0
003oooooooooo`0iooooo`?o00002oooool00ol0003oooooooooo`0`ooooo`?o06Ko5Oooool3oc<0
oe[ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`05ooooo`04odA4A?oMgMgooooo
o`0001Cooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPGooooo0_lQ8B45ooooo`05odA4A?l0
003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0gooooo`;o00003oooool00ol0003ooooo
ooooo`0/ooooo`?o06Ko5Oooool3oc<0oekooooo00?o0000ooooooooool0=oooool00ol0003ooooo
ooooo`04ooooo`04omgMgOmEEEGoooooo`0001Cooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMg
M`Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0=?ooool3o`00
01;ooooo00?o0000ooooooooool0@?ooool3oc<0oaKooooo0oo<0?m9ooooo`03o`000?oooooooooo
03Kooooo00?o0000ooooooooool01Oooool00omgMgOoc<c<o`00000Dooooo`0000?ooooooa0@4?oo
ool00_ooool00ol@413oooooooooo`0>ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0<Oooool3o`0001Kooooo00?o0000ooooooooool0??ooool3oc<0oaKooooo0oo<0?m=ooooo`03
o`000?oooooooooo03Kooooo0_l00005ooooo`03onk^k_m4A4Co000001Cooooo00000ooooooo0000
ooooo`02ooooo`03o`000?oooooooooo00gooooo00?oMgMgoc8b<_ooool00oooool2o`00033ooooo
0ol0000Jooooo`03o`000?oooooooooo03Sooooo0olc0?lFooooo`?oc03oDOooool00ol0003ooooo
ooooo`0dooooo`03o`000?oooooo000000Kooooo00?oMgMgo`000?ooool04oooool00003ooooool0
003ooooo00;ooooo00?o0000ooooooooool02_ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo
00?o0000ooooooooool0;?ooool3o`0001kooooo00?o0000ooooooooool0<oooool4oc<0oaOooooo
0_o<0?mDooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool06Oooool00003ooooool@
413ooooo00;ooooo00?o410@ooooooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo02[ooooo0_l0000Rooooo`03o`000?oooooooooo02oooooo0olc0?lHooooo`?oc03oEooo
ool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo01Wooooo00001_ooooooMgMgoiRHV?oo
ooooV9RHogMgM`cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Wooooo`?o0000
9Oooool2o`0002gooooo0_lc0?lHooooo`?oc03oFoooool00ol0003oooooooooo`0fooooo`03o`00
0?oooooooooo01Sooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPcooooo1?l00005ooooo`;o
00009Oooool3o`0002[ooooo00?o0000ooooooooool0:?ooool2oc<0oaKooooo1?o<0?mOooooo`03
o`000?oooooooooo03Kooooo00?o0000ooooooooool05oooool001_ooooo00?o0000ooooooooool0
8Oooool3o`0002kooooo00?o0000ooooooooool09_ooool00olc0?ooooooooooo`0Cooooo`?oc03o
I?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo01Oooooo000Kooooo`03o`000?oo
oooooooo01kooooo0ol0000booooo`03o`000?oooooooooo03Sooooo0oo<0?lIooooo`?oo`2IBooo
ool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo01Kooooo000Kooooo`03o`000?oooooo
oooo01_ooooo0ol0000fooooo`03o`000?oooooooooo03Cooooo0oo<0?lHooooo`Coo`2ICoooool0
0ol0003oooooooooo`0fooooo`03o`000?oooooooooo01Gooooo000Jooooo`03o`000?oooooooooo
01[ooooo0_l0000jooooo`03o`000?oooooooooo033ooooo0oo<0?lHooooo`?oo`2IE?ooool00ol0
003oooooooooo`0fooooo`03o`000?oooooooooo01Cooooo000Jooooo`;o00006?ooool3o`0003go
oooo00?o0000ooooooooool0;?ooool3ol`0oaWooooo0_oo09UHooooo`03o`000?oooooooooo03Go
oooo00?o0000ooooooooool05?ooool001[ooooo00?o0000ooooooooool05?ooool3o`00047ooooo
00?o0000ooooooooool09oooool4ol`0oaWooooo0ooo09UJooooo`03o`000?oooooooooo03Kooooo
00?o0000ooooooooool04oooool001[ooooo00?o0000ooooooooool04Oooool3o`0004Gooooo00?o
0000ooooooooool08oooool3ol`0oa[ooooo0ooo09UNooooo`03o`000?oooooooooo03Kooooo00?o
0000ooooooooool04_ooool001[ooooo00?o0000ooooooooool03_ooool3o`0004Wooooo00?o0000
ooooooooool08Oooool00oo<0?ooooooooooo`0Hooooo`?oo`2IH_ooool00ol0003oooooooooo`0e
ooooo`;o00004oooool001[ooooo00?o0000ooooooooool03?ooool2o`0004gooooo00?o0000oooo
ooooool0>?ooool3ool0VFKooooo00?o0000ooooooooool0=?ooool2o`0001?ooooo000Iooooo`?o
00002_ooool3o`00053ooooo00?o0000ooooooooool0=?ooool3ool0VA[ooooo0_oo001>ooooo`03
o`000?oooooooooo03Gooooo00?o0000ooooooooool04?ooool001[ooooo00?o0000ooooooooool0
1_ooool3o`0005Cooooo00?o0000ooooooooool0;oooool4ool0VA[ooooo0ooo001@ooooo`03o`00
0?oooooooooo03Kooooo00?o0000ooooooooool03oooool001Wooooo00?o0000ooooooooool01?oo
ool3o`0005Sooooo00?o0000ooooooooool0:oooool3ool0VAcooooo0_oo001Dooooo`03o`000?oo
oooooooo03Gooooo00?o0000ooooooooool03oooool001Wooooo00Co0000oooooooooooooooo0ol0
001Looooo`03o`000?oooooooooo02Oooooo0ooo09TMooooo`;oo`00Eoooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo00kooooo000Iooooo`Co0000H?ooool00ol0003oooooooooo`0R
ooooo`Coo`2I7_ooool2ool005[ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0=
ooooo`006Oooool2o`0006?ooooo00?o0000ooooooooool07_ooool3ool0VAoooooo0ooo001Moooo
o`03o`000?oooooooooo03Cooooo00?o0000ooooooooool03Oooool000oooooo1?l000000ol@413o
ooooooooo`05ooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool07?ooool00ooo09Wo
ooooooooo`0Mooooo`?oo`00H?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00co
oooo000Aooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0HOooool00ol0003ooooo
ooooo`0gooooo`Coo`00I?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00_ooooo
000Aooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0HOooool00ol0003ooooooooo
o`0cooooo`?oo`00JOooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00[ooooo000A
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0_
ooooo`?oo`00KOooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00[ooooo000Aoooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Zoooo
o`Coo`00LOooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Wooooo000Aooooo`03
o`000?oooooooooo00cooooo0_l0001Rooooo`03o`000?oooooooooo02Kooooo0ooo001eooooo`03
o`000?oooooooooo03?ooooo0ol0000:ooooo`004Oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo063ooooo00?o0000ooooooooool08_ooool3ool007Wooooo00?o0000ooooooooool0
;oooool3o`0000;ooooo00?o0000ooooooooool02?ooool000oooooo00?oEEEEofIVI_l000004Ooo
ool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo01cooooo1Ooo001mooooo`03o`000?oo
oooooooo02_ooooo0ol00005ooooo`03o`000?oooooooooo00Sooooo000Tooooo`03o`000?oooooo
oooo063ooooo00?o0000ooooooooool06?ooool3ool008?ooooo00?o0000ooooooooool09_ooool4
o`0000Sooooo00?o0000ooooooooool02?ooool002Gooooo00?o0000ooooooooool0H?ooool00ol0
003oooooooooo`2Nooooo`03o`000?oooooooooo02;ooooo0ol0000<ooooo`03o`000?oooooooooo
00Sooooo000Vooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0WOooool00ol0003o
ooooooooo`0Oooooo`?o00004?ooool00ol0003oooooooooo`07ooooo`009oooool00ol0003ooooo
ooooo`1Pooooo`03o`000?oooooooooo09gooooo00?o0000ooooooooool06_ooool4o`0001?ooooo
00?o0000ooooooooool01oooool002Sooooo0_l0001Qooooo`03o`000?oooooooooo09gooooo00?o
0000ooooooooool05_ooool3o`0001Oooooo00?o0000ooooooooool01oooool002[ooooo00?o0000
ooooooooool0Goooool00ol0003oooooooooo`2Mooooo`03o`000?oooooooooo01;ooooo0ol0000J
ooooo`03o`000?oooooooooo00Oooooo000[ooooo`03o`000?oooooooooo05oooooo00?o0000oooo
ooooool0WOooool00ol0003oooooooooo`0=ooooo`Co00007Oooool00ol0003oooooooooo`07oooo
o`00;?ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo09cooooo00?o0000oooooooo
ool02_ooool3o`00027ooooo00?o0000ooooooooool01oooool002gooooo00?o0000ooooooooool0
Goooool00ol0003oooooooooo`2Looooo`03o`000?oooooooooo00Kooooo0ol0000Tooooo`03o`00
0?oooooooooo00Oooooo000^ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool0W?oo
ool01?l0003oooooooooooooool4o`0002Oooooo00?o0000ooooooooool01oooool002oooooo0_l0
001Pooooo`03o`000?oooooooooo09cooooo0ol0000/ooooo`03o`000?oooooooooo00Kooooo000a
ooooo`03o`000?oooooooooo05kooooo0_l0002Iooooo`?o000000?oooooo`000?ooool0;?ooool0
0ol0003oooooooooo`06ooooo`00<_ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo
09?ooooo0ol00004ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool01_ooool003?o
oooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`2>ooooo`Co00002?ooool00ol0003o
ooooooooo`0Zooooo`03o`000?oooooooooo00Kooooo000dooooo`03o`000?oooooooooo05oooooo
00?o0000ooooooooool0R_ooool3o`0000gooooo00?o0000ooooooooool0:Oooool00ol0003ooooo
ooooo`06ooooo`00=Oooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo08Kooooo0ol0
000Aooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool01_ooool003Kooooo00?o0000
ooooooooool0Goooool00ol0003oooooooooo`21ooooo`Co00005Oooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo00Kooooo000gooooo`;o0000H?ooool00ol0003oooooooooo`1moooo
o`?o00006Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Kooooo000iooooo`03
o`000?oooooooooo05kooooo00?o0000ooooooooool0NOooool3o`0001gooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`05ooooo`00>_ooool00ol0003oooooooooo`1Nooooo`03o`00
0?oooooooooo07Cooooo1?l0000Qooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0
1Oooool003_ooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`1`ooooo`?o00009_oo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Gooooo000looooo`03o`000?oooooo
oooo05kooooo00?o0000ooooooooool0K?ooool3o`0002Wooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`05ooooo`00?Oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo
06Oooooo1?l0000]ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01Oooool003ko
oooo0_l0001Oooooo`03o`000?oooooooooo06?ooooo0ol0000booooo`03o`000?oooooooooo02?o
oooo00?o0000ooooooooool01Oooool0043ooooo00?o0000ooooooooool0GOooool00ol0003ooooo
ooooo`1Oooooo`?o0000=_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Gooooo
0011ooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool0F_ooool4o`0003[ooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`05ooooo`00@_ooool00ol0003oooooooooo`1M
ooooo`03o`000?oooooooooo05Kooooo0ol0000nooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool01Oooool004?ooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`1Boooo
o`?o0000@_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Cooooo0014ooooo`03
o`000?oooooooooo05gooooo00?o0000ooooooooool0COooool4o`0004Kooooo00?o0000oooooooo
ool08?ooool00ol0003oooooooooo`04ooooo`00AOooool00ol0003oooooooooo`1Mooooo`03o`00
0?oooooooooo04Wooooo0ol0001;ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0
1?ooool004Kooooo0_l0001Nooooo`03o`000?oooooooooo04Gooooo0ol0001?ooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool01?ooool004Sooooo00?o0000ooooooooool0G?ooool0
0ol0003oooooooooo`10ooooo`Co0000D_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo00Cooooo0019ooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool0??ooool3o`00
05Oooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`04ooooo`00B_ooool00ol0003o
ooooooooo`1Looooo`03o`000?oooooooooo03Sooooo0ol0001Kooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool01?ooool004_ooooo00?o0000ooooooooool0G?ooool00ol0003ooooo
ooooo`0cooooo`Co0000Goooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo
001<ooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool0;oooool3o`0006Cooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`03ooooo`00COooool2o`0005gooooo00?o0000
ooooooooool0:oooool3o`0006Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`03
ooooo`00Coooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo02Oooooo0ol0001[oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool00oooool0053ooooo00?o0000oooooooo
ool0Foooool00ol0003oooooooooo`0Rooooo`Co0000Koooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo00?ooooo001Aooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool0
7_ooool3o`0007Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`03ooooo`00D_oo
ool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo01[ooooo0ol0001hooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool00oooool005?ooooo00?o0000ooooooooool0Foooool0
0ol0003oooooooooo`0Eooooo`Co0000Noooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo00?ooooo001Dooooo`;o0000G?ooool00ol0003oooooooooo`0Aooooo`?o0000P?ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo00?ooooo001Fooooo`03o`000?oooooooooo05[o
oooo00?o0000ooooooooool03Oooool3o`0008Cooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`02ooooo`00Eoooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00Sooooo
1?l00028ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool00_ooool005Sooooo00?o
0000ooooooooool0F_ooool00ol0003oooooooooo`04ooooo`?o0000SOooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo00;ooooo001Iooooo`03o`000?oooooooooo05[ooooo00?o0000
ooooooooool00ol0002@ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00_ooool0
05[ooooo00?o0000ooooooooool0F_ooool2o`0009Cooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`02ooooo`00Foooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo09Co
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`02ooooo`00G?ooool2o`0005Wooooo
00?o0000ooooooooool0UOooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo
001Nooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool0U_ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo00;ooooo001Oooooo`03o`000?oooooooooo05Gooooo00?o0000
ooooooooool0U_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo007ooooo001Poooo
o`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0Uoooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo007ooooo001Qooooo`03o`000?oooooooooo05?ooooo00?o0000oooooooo
ool0V?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo007ooooo001Rooooo`03o`00
0?oooooooooo05;ooooo00?o0000ooooooooool0VOooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo007ooooo001Sooooo`;o0000D_ooool00ol0003oooooooooo`2Jooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool00Oooool006Gooooo00?o0000ooooooooool0Coooool0
0ol0003oooooooooo`2Jooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00Oooool0
06Kooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`2Kooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool00Oooool006Oooooo00?o0000ooooooooool0COooool00ol0003o
ooooooooo`2Looooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00Oooool006Sooooo
00?o0000ooooooooool0C?ooool00ol0003oooooooooo`2Mooooo`03o`000?oooooooooo00_ooooo
0Ol00001ooooo`7ooooo001Yooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0WOoo
ool00ol0003oooooooooo`0;ooooo`7o00000Oooool1ooooo`00J_ooool00ol0003oooooooooo`1:
ooooo`03o`000?oooooooooo09kooooo00?o0000ooooooooool02_ooool1o`00007ooooo0Oooool0
06_ooooo0_l0001:ooooo`03o`000?oooooooooo09oooooo00?o0000ooooooooool02Oooool1o`00
007ooooo0Oooool006gooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`2Pooooo`03
o`000?oooooooooo00Sooooo0Ol00001ooooo`7ooooo001^ooooo`03o`000?oooooooooo04Kooooo
00?o0000ooooooooool0XOooool00ol0003oooooooooo`07ooooo`7o00000Oooool1ooooo`00Kooo
ool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo0:7ooooo00?o0000ooooooooool01ooo
ool1o`00007ooooo0Oooool0073ooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`2R
ooooo`03o`000?oooooooooo00Kooooo0Ol00001ooooo`7ooooo001aooooo`03o`000?oooooooooo
04?ooooo00?o0000ooooooooool0Xoooool00ol0003oooooooooo`05ooooo`7o00000Oooool1oooo
o`00L_ooool2o`0004;ooooo00?o0000ooooooooool0YOooool00ol0003oooooooooo`05ooooo`7o
00000Oooool007Cooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`2Vooooo`03o`00
0?oooooooooo00Cooooo0Ol00001ooooo`00MOooool00ol0003oooooooooo`0nooooo`03o`000?oo
oooooooo0:Kooooo00?o0000ooooooooool01?ooool1o`00007ooooo001fooooo`03o`000?oooooo
oooo03gooooo00?o0000ooooooooool0Yoooool00ol0003oooooooooo`03ooooo`7o00000Oooool0
07Oooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`2Xooooo`03o`000?oooooooooo
00;ooooo0Ol00001ooooo`00N?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0:Wo
oooo00Go0000ooooooooooooooooo`000001ooooo`00NOooool00ol0003oooooooooo`0jooooo`03
o`000?oooooooooo0:[ooooo00Co0000oooooooooooo00000Oooool007[ooooo0_l0000jooooo`03
o`000?oooooooooo0:[ooooo00Co0000oooooooooooo00000Oooool007cooooo00?o0000oooooooo
ool0=oooool00ol0003oooooooooo`2[ooooo`03o`000?oooooooooo007o0000001mooooo`03o`00
0?oooooooooo03Kooooo00?o0000ooooooooool0[?ooool1o`00007ooooo0Ol0000007kooooo00?o
0000ooooooooool0=Oooool00ol0003oooooooooo`2]ooooo`;o0000001oooooo`03o`000?oooooo
oooo03Cooooo00?o0000ooooooooool0[?ooool3o`000000P?ooool00ol0003oooooooooo`0coooo
o`03o`000?oooooooooo0:Sooooo1?l00003ooooo`00POooool2o`0003?ooooo00?o0000oooooooo
ool0YOooool3o`0000Oooooo0023ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
XOooool4o`0000[ooooo0024ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0WOoo
ool4o`0000kooooo0025ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0VOooool4
o`0001;ooooo0026ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0UOooool4o`00
01Kooooo0027ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0T_ooool3o`0001[o
oooo0028ooooo`;o0000;?ooool00ol0003oooooooooo`2>ooooo`Co00007Oooool008[ooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`2:ooooo`Co00008Oooool008_ooooo00?o0000
ooooooooool0:?ooool00ol0003oooooooooo`26ooooo`Co00009Oooool008cooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`22ooooo`Co0000:Oooool008gooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`1oooooo`?o0000;Oooool008kooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`1kooooo`Co0000<?ooool008oooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`1gooooo`Co0000=?ooool0093ooooo0_l0000Tooooo`03o`000?oooooo
oooo07?ooooo1?l0000hooooo`00T_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
073ooooo0ol0000looooo`00Toooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo06co
oooo1?l0000oooooo`00U?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo06Sooooo
1?l00013ooooo`00UOooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo06Cooooo1?l0
0017ooooo`00U_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo063ooooo1?l0001;
ooooo`00Uoooool2o`0001gooooo00?o0000ooooooooool0GOooool3o`0004oooooo002Iooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool0FOooool4o`0005;ooooo002Jooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool0EOooool4o`0005Kooooo002Kooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool0DOooool4o`0005[ooooo002Looooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool0COooool4o`0005kooooo002Mooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool0B_ooool3o`0006;ooooo002Nooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool0A_ooool4o`0006Gooooo002Oooooo`;o00005?ooool00ol0003ooooo
ooooo`13ooooo`Co0000JOooool00:7ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0oooooo`Co0000KOooool00:;ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0k
ooooo`Co0000LOooool00:?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0hoooo
o`?o0000MOooool00:Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0dooooo`Co
0000N?ooool00:Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0`ooooo`Co0000
O?ooool00:Kooooo0_l0000=ooooo`03o`000?oooooooooo02cooooo1?l00020ooooo`00Z?ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Wooooo0ol00024ooooo`00ZOooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo02Gooooo1?l00027ooooo`00Z_ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo027ooooo1?l0002;ooooo`00Zoooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo01gooooo1?l0002?ooooo`00[?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo01Wooooo1?l0002Cooooo`00[Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo01Kooooo0ol0002Gooooo`00[_ooool2o`0000Gooooo00?o0000oooo
ooooool04_ooool4o`0009[ooooo002`ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool03_ooool4o`0009kooooo002aooooo`05o`000?ooooooooooooooool000003?ooool4o`000:;o
oooo002booooo`04o`000?ooooooooooo`0000Sooooo1?l0002Vooooo`00/oooool00ol0003ooooo
o`000005ooooo`?o0000Z_ooool00;Cooooo0_l000000ooooooo0000o`000002o`000:gooooo002e
ooooo`;o0000/Oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {319.688, 0}} -> {-0.0710364, -0.0181728, \
0.0035149, 0.0035149}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .89104 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-16 1.0656 -0.0363427 1.0656 [
[.02544 .21571 -12 -8.9133 ]
[.02544 .21571 0 .0867 ]
[.16074 .16277 -11.6592 -9 ]
[.16074 .16277 .34081 0 ]
[.3021 .10747 -5.60025 -9 ]
[.3021 .10747 .39975 0 ]
[.44992 .04965 -5.37091 -9 ]
[.44992 .04965 .62909 0 ]
[.60467 -0.01084 -5.14157 -9 ]
[.60467 -0.01084 .85843 0 ]
[.66454 .05085 0 -6.20675 ]
[.66454 .05085 6 2.79325 ]
[.80797 .25198 0 -6.0417 ]
[.80797 .25198 6 2.9583 ]
[.93071 .4241 0 -5.90576 ]
[.93071 .4241 6 3.09424 ]
[.02254 .22988 -12 -2.74631 ]
[.02254 .22988 0 6.25369 ]
[.0142 .29178 -24 -2.78907 ]
[.0142 .29178 0 6.21093 ]
[.00558 .35578 -6 -2.83339 ]
[.00558 .35578 0 6.16661 ]
[-0.00334 .42198 -18 -2.87938 ]
[-0.00334 .42198 0 6.12062 ]
[-0.01257 .49051 -6 -2.92712 ]
[-0.01257 .49051 0 6.07288 ]
[ 0 0 0 0 ]
[ 1 .89104 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03495 .22504 m
.61241 0 L
s
.03495 .22504 m
.03971 .2297 L
s
[(-2)] .02544 .21571 1 .98073 Mshowa
.16988 .17246 m
.17445 .1773 L
s
[(-1)] .16074 .16277 .9432 1 Mshowa
.31082 .11753 m
.31518 .12256 L
s
[(0)] .3021 .10747 .86675 1 Mshowa
.45818 .0601 m
.46231 .06533 L
s
[(1)] .44992 .04965 .7903 1 Mshowa
.61241 0 m
.61628 .00542 L
s
[(2)] .60467 -0.01084 .71386 1 Mshowa
.125 Mabswid
.06148 .2147 m
.06431 .21752 L
s
.08823 .20428 m
.09104 .20712 L
s
.11521 .19376 m
.118 .19663 L
s
.14243 .18316 m
.14519 .18604 L
s
.19758 .16166 m
.20029 .16459 L
s
.22551 .15078 m
.22821 .15373 L
s
.2537 .13979 m
.25637 .14277 L
s
.28213 .12871 m
.28478 .13171 L
s
.33977 .10625 m
.34236 .10929 L
s
.36897 .09487 m
.37153 .09794 L
s
.39844 .08339 m
.40097 .08648 L
s
.42817 .0718 m
.43068 .07491 L
s
.48846 .0483 m
.49091 .05146 L
s
.51902 .03639 m
.52144 .03958 L
s
.54986 .02437 m
.55225 .02758 L
s
.58099 .01224 m
.58335 .01547 L
s
.25 Mabswid
.61241 0 m
.97291 .505 L
s
.65208 .05558 m
.64586 .05794 L
s
[(0)] .66454 .05085 -1 .37928 Mshowa
.79537 .2563 m
.78907 .25846 L
s
[(2)] .80797 .25198 -1 .3426 Mshowa
.91799 .42808 m
.91164 .43006 L
s
[(4)] .93071 .4241 -1 .31239 Mshowa
.125 Mabswid
.69012 .10886 m
.68637 .11025 L
s
.72662 .16 m
.72286 .16135 L
s
.76168 .2091 m
.75791 .21042 L
s
.82778 .3017 m
.82399 .30297 L
s
.85897 .3454 m
.85518 .34664 L
s
.88903 .3875 m
.88522 .38871 L
s
.94594 .46722 m
.94211 .46839 L
s
.25 Mabswid
.03495 .22504 m
0 .48612 L
s
.03495 .22504 m
.04116 .22262 L
s
[(-1)] .02254 .22988 1 -0.38971 Mshowa
.02665 .28704 m
.03288 .28468 L
s
[(-0.5)] .0142 .29178 1 -0.38021 Mshowa
.01807 .35115 m
.02431 .34884 L
s
[(0)] .00558 .35578 1 -0.37036 Mshowa
.00919 .41747 m
.01546 .41521 L
s
[(0.5)] -0.00334 .42198 1 -0.36014 Mshowa
0 .48612 m
.00629 .48392 L
s
[(1)] -0.01257 .49051 1 -0.34953 Mshowa
.125 Mabswid
.03331 .23728 m
.03704 .23583 L
s
.03166 .2496 m
.03539 .24816 L
s
.03 .262 m
.03373 .26056 L
s
.02833 .27448 m
.03207 .27305 L
s
.02496 .29969 m
.0287 .29828 L
s
.02325 .31243 m
.02699 .31102 L
s
.02154 .32525 m
.02528 .32385 L
s
.01981 .33816 m
.02355 .33676 L
s
.01632 .36423 m
.02007 .36285 L
s
.01455 .37741 m
.01831 .37603 L
s
.01278 .39067 m
.01653 .3893 L
s
.01099 .40402 m
.01475 .40266 L
s
.00738 .43101 m
.01114 .42966 L
s
.00555 .44464 m
.00932 .4433 L
s
.00371 .45837 m
.00748 .45704 L
s
.00186 .4722 m
.00563 .47087 L
s
.25 Mabswid
.03495 .22504 m
0 .48612 L
s
0 .48612 m
.46953 .89104 L
s
.46953 .89104 m
.47294 .65459 L
s
.47294 .65459 m
.03495 .22504 L
s
.61241 0 m
.97291 .505 L
s
.97291 .505 m
1 .75117 L
s
1 .75117 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.03495 .22504 m
0 .48612 L
s
0 .48612 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.61241 0 m
.03495 .22504 L
s
.47294 .65459 m
.97291 .505 L
s
.97291 .505 m
1 .75117 L
s
1 .75117 m
.46953 .89104 L
s
.46953 .89104 m
.47294 .65459 L
s
0 0 m
1 0 L
1 .89104 L
0 .89104 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.43053 .55543 m
.44885 .55401 L
s
.44885 .55401 m
.46845 .55167 L
s
.46845 .55167 m
.48887 .5481 L
s
.48887 .5481 m
.50943 .54318 L
s
.50943 .54318 m
.52934 .53692 L
s
1 0 .6 r
.4225 .51975 m
.43862 .517 L
s
.43862 .517 m
.45515 .5138 L
s
1 0 0 r
.52934 .53692 m
.54789 .52954 L
s
1 0 .6 r
.45515 .5138 m
.47191 .50998 L
s
.47191 .50998 m
.48863 .50545 L
s
1 0 0 r
.54789 .52954 m
.56456 .5214 L
s
.8 0 1 r
.41148 .48925 m
.42635 .4854 L
s
1 0 .6 r
.48863 .50545 m
.50497 .50021 L
s
.8 0 1 r
.42635 .4854 m
.44132 .48138 L
s
.2 0 1 r
.40126 .46356 m
.41557 .4592 L
s
.8 0 1 r
.44132 .48138 m
.4563 .47711 L
s
1 0 0 r
.56456 .5214 m
.57912 .51291 L
s
0 .4 1 r
.39227 .44032 m
.40636 .43572 L
s
1 0 .6 r
.50497 .50021 m
.52063 .49434 L
s
.2 0 1 r
.41557 .4592 m
.42992 .45475 L
s
0 1 1 r
.38397 .41811 m
.39797 .4134 L
s
.8 0 1 r
.4563 .47711 m
.47124 .47257 L
s
0 1 .4 r
.37596 .3963 m
.38993 .39152 L
s
0 .4 1 r
.40636 .43572 m
.4205 .43109 L
s
.2 1 0 r
.36807 .37463 m
.38202 .36979 L
s
.2 0 1 r
.42992 .45475 m
.44431 .45021 L
s
1 0 .6 r
.52063 .49434 m
.53543 .488 L
s
0 1 1 r
.39797 .4134 m
.41203 .40867 L
s
.8 1 0 r
.3602 .35298 m
.37415 .34809 L
s
1 0 0 r
.57912 .51291 m
.5917 .50447 L
s
.8 0 1 r
.47124 .47257 m
.48603 .46774 L
s
1 .6 0 r
.35234 .33132 m
.36628 .32638 L
s
0 1 .4 r
.38993 .39152 m
.40396 .38672 L
s
0 .4 1 r
.4205 .43109 m
.43469 .42641 L
s
.2 1 0 r
.38202 .36979 m
.39604 .36493 L
s
.2 0 1 r
.44431 .45021 m
.45869 .44556 L
s
0 1 1 r
.41203 .40867 m
.42615 .4039 L
s
.8 1 0 r
.37415 .34809 m
.38816 .34318 L
s
1 0 .6 r
.53543 .488 m
.54934 .48139 L
s
1 .6 0 r
.36628 .32638 m
.38028 .32142 L
s
.8 0 1 r
.48603 .46774 m
.50061 .46263 L
s
0 1 .4 r
.40396 .38672 m
.41805 .38189 L
s
0 .4 1 r
.43469 .42641 m
.44891 .42167 L
s
.2 1 0 r
.39604 .36493 m
.41011 .36005 L
s
.2 0 1 r
.45869 .44556 m
.47307 .44079 L
s
0 1 1 r
.42615 .4039 m
.44032 .3991 L
s
.8 1 0 r
.38816 .34318 m
.40222 .33825 L
s
1 .6 0 r
.38028 .32142 m
.39434 .31644 L
s
0 1 .4 r
.41805 .38189 m
.4322 .37704 L
s
.8 0 1 r
.50061 .46263 m
.51495 .45731 L
s
0 .4 1 r
.44891 .42167 m
.46317 .41689 L
s
.2 1 0 r
.41011 .36005 m
.42425 .35515 L
s
1 0 .6 r
.54934 .48139 m
.56248 .47468 L
s
.2 0 1 r
.47307 .44079 m
.48741 .43592 L
s
0 1 1 r
.44032 .3991 m
.45454 .39428 L
s
.8 1 0 r
.40222 .33825 m
.41635 .3333 L
s
1 .6 0 r
.39434 .31644 m
.40846 .31144 L
s
0 1 .4 r
.4322 .37704 m
.44641 .37217 L
s
0 .4 1 r
.46317 .41689 m
.47746 .41205 L
s
.8 0 1 r
.51495 .45731 m
.52906 .45182 L
s
.2 1 0 r
.42425 .35515 m
.43845 .35023 L
s
.2 0 1 r
.48741 .43592 m
.50172 .43095 L
s
0 1 1 r
.45454 .39428 m
.46881 .38942 L
s
.8 1 0 r
.41635 .3333 m
.43054 .32832 L
s
1 .6 0 r
.40846 .31144 m
.42264 .30641 L
s
0 1 .4 r
.44641 .37217 m
.46067 .36727 L
s
0 .4 1 r
.47746 .41205 m
.49178 .40717 L
s
.2 1 0 r
.43845 .35023 m
.4527 .34528 L
s
.8 0 1 r
.52906 .45182 m
.54297 .44623 L
s
.2 0 1 r
.50172 .43095 m
.516 .4259 L
s
0 1 1 r
.46881 .38942 m
.48314 .38453 L
s
.8 1 0 r
.43054 .32832 m
.44479 .32333 L
s
1 .6 0 r
.42264 .30641 m
.43688 .30136 L
s
0 1 .4 r
.46067 .36727 m
.47499 .36235 L
s
0 .4 1 r
.49178 .40717 m
.50614 .40224 L
s
.2 1 0 r
.4527 .34528 m
.46702 .34031 L
s
.2 0 1 r
.516 .4259 m
.53027 .42079 L
s
0 1 1 r
.48314 .38453 m
.49752 .37962 L
s
.8 1 0 r
.44479 .32333 m
.4591 .31831 L
s
1 .6 0 r
.43688 .30136 m
.45118 .2963 L
s
0 1 .4 r
.47499 .36235 m
.48937 .3574 L
s
0 .4 1 r
.50614 .40224 m
.52053 .39728 L
s
.2 1 0 r
.46702 .34031 m
.4814 .33532 L
s
.8 1 0 r
.4591 .31831 m
.47347 .31327 L
s
0 1 1 r
.49752 .37962 m
.51195 .37467 L
s
1 .6 0 r
.45118 .2963 m
.46554 .2912 L
s
0 1 .4 r
.48937 .3574 m
.50382 .35243 L
s
.2 1 0 r
.4814 .33532 m
.49584 .33031 L
s
.8 1 0 r
.47347 .31327 m
.4879 .30821 L
s
1 .6 0 r
.46554 .2912 m
.47997 .28609 L
s
0 g
.25 Mabswid
.61241 0 m
.97291 .505 L
s
.97291 .505 m
1 .75117 L
s
1 .75117 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.03495 .22504 m
0 .48612 L
s
0 .48612 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.61241 0 m
.03495 .22504 L
s
.03495 .22504 m
.61241 0 L
s
.03495 .22504 m
.03971 .2297 L
s
[(-2)] .02544 .21571 1 .98073 Mshowa
.16988 .17246 m
.17445 .1773 L
s
[(-1)] .16074 .16277 .9432 1 Mshowa
.31082 .11753 m
.31518 .12256 L
s
[(0)] .3021 .10747 .86675 1 Mshowa
.45818 .0601 m
.46231 .06533 L
s
[(1)] .44992 .04965 .7903 1 Mshowa
.61241 0 m
.61628 .00542 L
s
[(2)] .60467 -0.01084 .71386 1 Mshowa
.125 Mabswid
.06148 .2147 m
.06431 .21752 L
s
.08823 .20428 m
.09104 .20712 L
s
.11521 .19376 m
.118 .19663 L
s
.14243 .18316 m
.14519 .18604 L
s
.19758 .16166 m
.20029 .16459 L
s
.22551 .15078 m
.22821 .15373 L
s
.2537 .13979 m
.25637 .14277 L
s
.28213 .12871 m
.28478 .13171 L
s
.33977 .10625 m
.34236 .10929 L
s
.36897 .09487 m
.37153 .09794 L
s
.39844 .08339 m
.40097 .08648 L
s
.42817 .0718 m
.43068 .07491 L
s
.48846 .0483 m
.49091 .05146 L
s
.51902 .03639 m
.52144 .03958 L
s
.54986 .02437 m
.55225 .02758 L
s
.58099 .01224 m
.58335 .01547 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 256.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001@2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00gOooool5o`0008Kooooo003Mooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0Q_ooool00=ko
oooo00?oV9RHob4Q8Oo^k^h0Qoooool00=oooooo00?oV9RHob4Q8Oo^k^h0Q_ooool00>3ooooo00?o
MgMgofIVI_ooool0QOooool00>7ooooo00?o0000ooooooooool0Q?ooool00=gooooo00Go0000okZj
^_ooooooV9RHoa0@4026ooooo`00gOooool01OnHV9So410@o`000?lQ8B7oc<c<08Kooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003Tooooo`;o0000P_ooool0
0>7ooooo0ol000000ooooooo0000ooooo`21ooooo`00goooool2o`0000Cooooo0_l00021ooooo`00
g?ooool3o`0000Kooooo00?o0000ooooool00000P?ooool00=[ooooo0_l00009ooooo`03o`000?oo
oooo0000083ooooo003Gooooo`?o000000?oooooo`000?ooool02?ooool01?l0003oooooooooool0
001oooooo`00e?ooool3o`0000Cooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooo
oooo000007kooooo003Booooo`;o00004Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo07_ooooo002Zooooo`Co000000?o410@ooooooooool07_ooool3o`0001?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1kooooo`00[?ooool00ol0003oooooooooo`0Nooooo`;o
000000?oooooo`000?ooool04oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07[o
oooo002/ooooo`03o`000?oooooooooo01_ooooo0ol00004ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`1iooooo`00[?ooool00ol0003ooooooooo
o`0Iooooo`;o00006oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo07Wooooo002/
ooooo`03o`000?oooooooooo01Kooooo0ol0000Mooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool02?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^06_ooooo002/ooooo`03o`000?oooooo
oooo01Cooooo0_l000000ooooooo0000ooooo`0Mooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01oooool01OmgMgOoV9RHoooooonHV9SoMgMg06_ooooo002/ooooo`03o`000?oooooo
oooo017ooooo0ol00004ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`06ooooo`05oa0@4?ooooooooooooooool@4100Joooool00:[ooooo00?oEEEE
ofIVI_l000004Oooool2o`0002Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06
ooooo`05o`000?ooooooooooooooool00000Joooool00;_ooooo0ol0000Wooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000006_ooooo002i
ooooo`;o000000?oooooo`000?ooool09oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Cooooo00Go410@oooooooooooooooooa0@401[ooooo`00]_ooool3o`0000Cooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`1[ooooo`00/oooool3o`0002oooooo00?o0000ooooooooool02Oooool2
o`0000Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1[ooooo`00/Oooool2o`0003;ooooo00?o0000
ooooooooool02?ooool01?l0003oooooooooool0001dooooo`00[_ooool3o`000003ooooool0003o
oooo037ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1aooooo`00[?ooool2o`00
00Gooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
077ooooo002Yooooo`?o0000>_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo073o
oooo002Wooooo`;o0000?Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo06oooooo
002Tooooo`?o000000?oooooo`000?ooool0??ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo06oooooo002Rooooo`;o0000@_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo06kooooo001gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08oooool3o`0004Cooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1]ooooo`00Moooool01OmgMgOoV9RHoooooonHV9So
MgMg027ooooo0_l00017ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0K?ooool0
07Oooooo00Go410@oooooooooooooooooa0@400Nooooo`?o00000_ooool00ol0003oooooooooo`14
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0K?ooool007Oooooo00Go0000oooo
ooooooooooooo`00000Looooo`;o0000C?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo06_ooooo001gooooo`05o`000?ooooooooooooooool000006Oooool3o`0004kooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`1Zooooo`00Moooool01Ol@413ooooooooooooooooo
410@01Kooooo0ol0001Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0J_ooool0
07Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Dooooo`;o00000oooool00ol0003oooooooooo`1>
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0JOooool007Oooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Aooooo`?o0000E_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo06Sooooo002;ooooo`;o0000FOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
06Sooooo0028ooooo`?o0000Foooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo06Oo
oooo0026ooooo`;o00000oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo01Gooooo
0_l0001Xooooo`00Poooool3o`00063ooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`1Uooooo`00POooool2o`0006?ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1U
ooooo`00O_ooool4o`0006Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`1Toooo
o`00O?ooool2o`0000Cooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo06?ooooo001iooooo`?o0000J_ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo06?ooooo001gooooo`;o0000KOooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo06;ooooo001dooooo`?o000000?oooooo`000?ooool0K?ooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo067ooooo001aooooo`?o0000L_ooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo063ooooo0019ooooo`Co000000?o410@ooooooooool07oooool2o`0007Go
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1Pooooo`00Boooool00ol0003ooooo
ooooo`0Nooooo`?o0000Moooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo05oooooo
0010ooooo`Ko00001Oooool00ol0003oooooooooo`0Looooo`;o00000_ooool00ol0003ooooooooo
o`1eooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0G_ooool004_ooooo00?o0000
ooooooooool06Oooool3o`0007cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1N
ooooo`00Boooool00ol0003oooooooooo`0Gooooo`;o0000Ooooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo05gooooo001;ooooo`03o`000?oooooooooo01Cooooo0ol00021ooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0G?ooool004_ooooo00?o0000ooooooooool0
4_ooool2o`0000?ooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo05_ooooo0019ooooo`03oeEEEOmVIVKo0000017ooooo0ol00026ooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool0Foooool005_ooooo0_l00029ooooo`03o`000?oooooo
oooo027ooooo0_l0001Looooo`00F?ooool3o`000003ooooool0003ooooo08Sooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`1Iooooo`00E_ooool2o`0008kooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`1Iooooo`00Doooool3o`00093ooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`1Hooooo`00D?ooool3o`0009?ooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1Gooooo`00C_ooool2o`0000;ooooo00?o0000ooooooooool0TOooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo05Kooooo001;ooooo`?o00001Oooool00ol0
003oooooooooo`2@ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0E_ooool004Wo
oooo0_l0002Kooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0EOooool004Kooooo
1?l0002Looooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0E?ooool004Cooooo0_l0
002Pooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0E?ooool001[ooooo1Ol0000R
ooooo`?o0000X_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo05?ooooo000Joooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@08?ooool2o`000:Gooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`1Booooo`004_ooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h07_ooool3o`00
0003ooooool0003ooooo0:Cooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`1Aoooo
o`007?ooool00onHV9So8B4Qonk^kP0Kooooo`;o0000Z_ooool00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo057ooooo000Mooooo`03ogMgMomVIVKooooo01Oooooo0ol0002]ooooo`03o`00
0?oooooooooo02_ooooo00?o0000ooooooooool0D?ooool001kooooo00?o0000ooooooooool05?oo
ool2o`000;3ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`1?ooooo`006_ooool0
1Ol0003o^[ZjoooooonHV9So410@01?ooooo0ol00002ooooo`03o`000?oooooooooo0:gooooo00?o
0000ooooooooool0;?ooool2o`00053ooooo000Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`04?oo
ool3o`000;Gooooo00?o0000ooooooooool0;?ooool2o`00053ooooo000]ooooo`;o0000^?ooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo04gooooo000Zooooo`?o000000?oooooo`00
0?ooool0]oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo04gooooo000Xooooo`;o
0000_Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo04cooooo000Uooooo`?o0000
_oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo04_ooooo000Tooooo`;o0000`Ooo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo04[ooooo000Jooooo`Co000000?o410@
ooooooooool00oooool00ol0003oooooo`000030ooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool0B_ooool001cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0002o
ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0BOooool0017ooooo1_l00005oooo
o`03o`000?oooooooooo00Gooooo0_l00002ooooo`03o`000?oooooooooo0;cooooo00?o0000oooo
ooooool0<oooool00ol0003oooooooooo`18ooooo`007?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0^oooool00ol0003oooooooooo`0cooooo`03
o`000?oooooooooo00Oooooo1Ol0000looooo`007?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo00Kooooo00GoV9RHob4Q8Oo^k^koooooodA4A00looooo`007?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00ol0003ooooo
ooooo`0eooooo`03o`000?oooooooooo00Kooooo00?oV9RHob4Q8Oo^k^h0?Oooool001cooooo00?o
0000ooooooooool01?ooool3o`0000Kooooo00?o0000ooooooooool0^?ooool00ol0003ooooooooo
o`0fooooo`03o`000?oooooooooo00Kooooo00?oV9RHob4Q8Oo^k^h0??ooool001[ooooo00?oEEEE
ofIVI_l000001_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;Oooooo00?o0000
ooooooooool0=_ooool00ol0003oooooooooo`07ooooo`03ogMgMomVIVKooooo03_ooooo000Soooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0]_ooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0>_ooool002?ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`2eooooo`03o`000?oooooooooo03Oooooo0_l00004ooooo`05
o`000?nj^[[ooooooiRHV?l@4100??ooool002?ooooo0_l0000;ooooo`03o`000?oooooooooo0;Co
oooo00?o0000ooooooooool0=_ooool00ol0003oooooo`000004ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`0??ooool002?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`2cooooo`03
o`000?oooooooooo03Wooooo00?o0000ooooooooool0@_ooool002;ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0
@Oooool002;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`2`ooooo`;o0000?Ooo
ool00ol0003oooooooooo`10ooooo`008_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo0:cooooo0ol000000ooooooo0000ooooo`0looooo`03o`000?oooooooooo043ooooo000Roooo
o`;o00004Oooool00ol0003oooooooooo`2Xooooo`?o00001Oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo03oooooo000Rooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool0Y?ooool3o`0000Wooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0nooooo`00
8_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo0:3ooooo0ol0000=ooooo`03o`00
0?oooooooooo03[ooooo00?o0000ooooooooool0?_ooool002;ooooo0ol0000Cooooo`03o`000?oo
oooooooo09cooooo0ol0000Aooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0?Ooo
ool002;ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1looooo`;ooiT06oooool2
o`0001Cooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0looooo`008Oooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo07Sooooo0oooV@0Jooooo`?o00005oooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo03_ooooo0007ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@04ooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool0M?ooool3oonI01[ooooo0ol0000Kooooo`03o`000?oooooo
oooo03[ooooo00?o0000ooooooooool0>oooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05
ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool0Koooool4oonI01[ooooo0ol0000Oooooo`03o`000?oooooooooo03[ooooo00?o0000
ooooooooool0>_ooool000Go00000_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000
ooooooooool00_ooool2o`0001[ooooo00?o0000ooooooooool0K?ooool2oonI01_ooooo0ol0000S
ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0>Oooool000Oooooo00Go0000oooo
ooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`1Yooooo`;ooiT06oooool2o`0002Kooooo00?o0000ooooooooool0>_ooool2
o`0003[ooooo0007ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Uooooo`?ooiT06_oo
ool3o`0002Wooooo00?o0000ooooooooool0>Oooool2o`0003[ooooo0007ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool0HOooool3oonI01Cooooo0_o<o`04ooooo`?o0000;Oooool00ol0003ooooooooo
o`0jooooo`03o`000?oooooooooo03Oooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?oo
ool00ol0003oooooooooo`06ooooo`;o00007_ooool00ol0003oooooooooo`1Looooo`CooiT05?oo
ool3olco00?ooooo0ol0000aooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0=ooo
ool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001?ooool2o`00023ooooo00?o
0000ooooooooool0F?ooool3oonI01Kooooo0_o<o`03ooooo`?o0000=Oooool00ol0003ooooooooo
o`0iooooo`03o`000?oooooooooo03Kooooo000Pooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool0EOooool2oonI01Kooooo0oo<o`02ooooo`?o0000>?ooool00ol0003oooooooooo`0j
ooooo`03o`000?oooooooooo03Gooooo000Pooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool0D_ooool2oonI01Gooooo0oo<o`03ooooo`;o0000??ooool00ol0003oooooooooo`0joooo
o`03o`000?oooooooooo03Cooooo000Pooooo`;o00008oooool00ol0003oooooooooo`1>ooooo`?o
oiT04oooool4olco00?ooooo0ol0000oooooo`03o`000?oooooooooo03Wooooo00?o0000oooooooo
ool0=?ooool0023ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`19ooooo`CooiT0
4oooool3olco00Cooooo0ol00013ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0
<oooool0023ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`15ooooo`?ooiT05Ooo
ool2olco00Cooooo0ol00017ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0<_oo
ool0023ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`13ooooo`03oonI0?oooooo
oooo01Cooooo0_o<o`03ooooo`?o00003oooool3oc?o03Sooooo00?o0000ooooooooool0>Oooool0
0ol0003oooooooooo`0booooo`008?ooool00ol0003oooooooooo`0Vooooo`;o0000Eoooool3olco
00?ooooo0_l0000>ooooo`Co<ol0??ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo
037ooooo000Oooooo`?o0000:Oooool00ol0003oooooooooo`1@ooooo`Coc?l00oooool3o`0000ko
oooo0_lco`11ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0<?ooool001oooooo
00?o0000ooooooooool0:_ooool00ol0003oooooooooo`1<ooooo`?oc?l01?ooool3o`0000oooooo
0_lco`14ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0;oooool001oooooo00?o
0000ooooooooool0:oooool00ol0003oooooooooo`19ooooo`;oc?l01?ooool3o`0000oooooo0olc
o`16ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0;oooool001oooooo00?o0000
ooooooooool0;?ooool00ol0003oooooooooo`16ooooo`;oc?l00oooool3o`0000oooooo0olco`1:
ooooo`03o`000?oooooooooo03Sooooo0_l0000`ooooo`007oooool3o`0002gooooo00?o0000oooo
ooooool0@_ooool3olco00;ooooo0ol0000>ooooo`Co<ol0C_ooool00ol0003oooooooooo`0ioooo
o`03o`000?oooooooooo02gooooo000Oooooo`03o`000?oooooooooo02kooooo00?o0000oooooooo
ool0?_ooool3olco00?ooooo0_l0000>ooooo`?o<ol05_ooool2o`3oIS_ooooo00?o0000oooooooo
ool0>?ooool00ol0003oooooooooo`0]ooooo`005?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Ko
oooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`10ooooo`?o00003_ooool2oc?o01Ko
oooo0ol0ofHnooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0;?ooool001Cooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo037ooooo00?o0000oooooooo
ool0??ooool3o`0000oooooo0_lco`0Eooooo`?o0?mV@Oooool00ol0003oooooooooo`0iooooo`03
o`000?oooooooooo02_ooooo000Dooooo`05oa0@4?ooooooooooooooool@41001Oooool2o`0003?o
oooo00?o0000ooooooooool0>?ooool3o`0000oooooo0olco`0Cooooo`Co0?mVAOooool00ol0003o
ooooooooo`0iooooo`03o`000?oooooooooo02[ooooo000Dooooo`05o`000?ooooooooooooooool0
00001Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo03Cooooo0ol0000>ooooo`Co
<ol05?ooool2o`3oIT[ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Zooooo`00
5?ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0=?ooool00ol0003o
ooooooooo`0`ooooo`?o00003_ooool3oc?o01Kooooo0_l0ofI=ooooo`03o`000?oooooooooo03So
oooo00?o0000ooooooooool0:Oooool001Cooooo00Go410@oooooooooooooooooa0@4005ooooo`03
o`000?oooooooooo03Gooooo00?o0000ooooooooool0;Oooool2o`0000kooooo0olco`0Fooooo`?o
0?mVD?ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02Sooooo000Dooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo02Wo
oooo0ol0000>ooooo`;o<ol05_ooool3o`3oIQCooooo0_l0oolmooooo`03o`000?oooooooooo03So
oooo00?o0000ooooooooool0:?ooool001Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
0000>?ooool00ol0003oooooooooo`0Uooooo`?o00009Oooool4o`3oIQCooooo0ol0oom0ooooo`03
o`000?oooooooooo03Sooooo00?o0000ooooooooool09oooool001kooooo00?o0000ooooooooool0
>?ooool00ol0003oooooooooo`0Qooooo`?o00009Oooool3o`3oIQKooooo0_l0oom4ooooo`03o`00
0?oooooooooo03Sooooo00?o0000ooooooooool09_ooool001gooooo00?o0000ooooooooool0>_oo
ool00ol0003oooooooooo`0Mooooo`?o00009Oooool3o`3oIQKooooo0ol0oom7ooooo`03o`000?oo
oooooooo03Sooooo00?o0000ooooooooool09Oooool001gooooo00?o0000ooooooooool0>oooool0
0ol0003oooooooooo`0Jooooo`;o00009Oooool3o`3oIQKooooo0ol0oom;ooooo`03o`000?oooooo
oooo03Oooooo00?o0000ooooooooool09Oooool001gooooo0_l0000mooooo`03o`000?oooooooooo
01Kooooo0ol0000Tooooo`?o0?mV5Oooool4o`3oodkooooo00?o0000ooooooooool0=oooool2o`00
02Kooooo000Mooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool04_ooool3o`0002Go
oooo0_l0ofHEooooo`?o0?ooDoooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02?o
oooo000Mooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool03_ooool3o`0002Gooooo
0ol0ofHEooooo`;o0?ooEoooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02?ooooo
000Mooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool02_ooool3o`0002Oooooo00?o
0?mVooooooooool05?ooool2o`3ooaKooooo0_l0I_m2ooooo`03o`000?oooooooooo03Oooooo00?o
0000ooooooooool08_ooool001gooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`06
ooooo`?o0000?_ooool3o`3ooaKooooo0_l0I_m5ooooo`03o`000?oooooooooo03Oooooo00?o0000
ooooooooool08Oooool001cooooo0ol00012ooooo`03o`000?oooooooooo00?ooooo0_l0000moooo
o`Co0?oo5_ooool3o`1VodOooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Poooo
o`007?ooool00ol0003oooooooooo`13ooooo`03o`000?oooooo000000;o0000??ooool3o`3ooaKo
oooo1?l0I_m;ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool08?ooool001cooooo
00?o0000ooooooooool0@_ooool3o`0003cooooo0ol0oolFooooo`?o06KoD?ooool00ol0003ooooo
ooooo`0gooooo`03o`000?oooooooooo00Wooooo0_l000000ol@413oooooooooo`0Aooooo`007?oo
ool00ol0003oooooooooo`0oooooo`?o00000oooool00ol0003oooooooooo`0fooooo`?o0?oo5ooo
ool2o`1VoeCooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo01;ooooo000Looooo`?o0000??ooool3o`0000Oooooo00?o0000ooooooooool0<_ooool3
o`3ooaOooooo0ol0I_mGooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool01_ooool5
o`0001?ooooo000Looooo`03o`000?oooooooooo03Wooooo0ol0000;ooooo`03o`000?oooooooooo
033ooooo00?o0?ooooooooooool05Oooool3o`1Voe[ooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`05ooooo`04odA4A?oMgMgoooooo`0001Cooooo00001_ooooook^k^oc8b<_l0003o
<S8bonk^kPGooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooo
ooooo`0gooooo`;o00003oooool00ol0003oooooooooo`14ooooo`?o06Ko6?ooool2oc<0odCooooo
00?o0000ooooooooool0=oooool00ol0003oooooooooo`04ooooo`04omgMgOmEEEGoooooo`0001Co
oooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0=?ooool3o`0001;ooooo00?o0000ooooooooool0@?ooool3o`1V
oaSooooo0olc0?m7ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool01Oooool00omg
MgOoc<c<o`00000Dooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0>ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0<Oooool3o`0001Kooooo00?o0000oooooooo
ool0??ooool3o`1VoaSooooo0olc0?m;ooooo`03o`000?oooooooooo03Kooooo0_l00005ooooo`03
onk^k_m4A4Co000001Cooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00gooooo
00?oMgMgoc8b<_ooool00oooool2o`00033ooooo0ol0000Jooooo`03o`000?oooooooooo03Oooooo
1?l0I_lGooooo`Co<`3oCoooool00ol0003oooooooooo`0dooooo`03o`000?oooooo000000Kooooo
00?oMgMgo`000?ooool04oooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool02_oo
ool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool0;?ooool3o`0001kooooo
00?o0000ooooooooool0<oooool3o`1VoaSooooo0olc0?mCooooo`03o`000?oooooooooo03Oooooo
00?o0000ooooooooool06Oooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02[ooooo0_l0000Rooooo`03o`000?oo
oooooooo02oooooo0ol0I_lIooooo`;o<`3oEoooool00ol0003oooooooooo`0fooooo`03o`000?oo
oooooooo01Wooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`cooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Wooooo`?o00009Oooool2o`0002gooooo0_l0I_lJooooo`;o<`3o
F_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo01Sooooo00001_ooooook^k^oc8b
<_l0003o<S8bonk^kPcooooo1?l00005ooooo`;o00009Oooool3o`0002[ooooo00?o0000oooooooo
ool0@oooool3oc<0oegooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Gooooo`00
6oooool00ol0003oooooooooo`0Qooooo`?o0000;_ooool00ol0003oooooooooo`0nooooo`Co<`3o
6?ooool2ol`0odOooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Gooooo`006ooo
ool00ol0003oooooooooo`0Nooooo`?o0000<_ooool00ol0003oooooooooo`0jooooo`?o<`3o6Ooo
ool3ol`0odWooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Fooooo`006oooool0
0ol0003oooooooooo`0Kooooo`?o0000=_ooool00ol0003oooooooooo`0fooooo`?o<`3o6_ooool2
ol`0odgooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Eooooo`006_ooool00ol0
003oooooooooo`0Jooooo`;o0000>_ooool00ol0003oooooooooo`0aooooo`Co<`3o6oooool2ol`0
oe3ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Dooooo`006_ooool2o`0001So
oooo0ol0000mooooo`03o`000?oooooooooo02gooooo0olc0?lMooooo`;oc03oDoooool00ol0003o
ooooooooo`0eooooo`03o`000?oooooooooo01Cooooo000Jooooo`03o`000?oooooooooo01Cooooo
0ol00011ooooo`03o`000?oooooooooo02Wooooo0olc0?lMooooo`?oc03oEOooool00ol0003ooooo
ooooo`0fooooo`03o`000?oooooooooo01?ooooo000Jooooo`03o`000?oooooooooo017ooooo0ol0
0015ooooo`03o`000?oooooooooo02Kooooo0_lc0?lNooooo`;oc03oFOooool00ol0003ooooooooo
o`0fooooo`03o`000?oooooooooo01;ooooo000Jooooo`03o`000?oooooooooo00kooooo0ol00019
ooooo`03o`000?oooooooooo04;ooooo0oo<0?mLooooo`03o`000?oooooooooo03Gooooo0_l0000C
ooooo`006_ooool00ol0003oooooooooo`0<ooooo`;o0000COooool00ol0003oooooooooo`0noooo
o`?oc03oH?ooool00ol0003oooooooooo`0dooooo`;o00004oooool001Wooooo0ol0000:ooooo`?o
0000D?ooool00ol0003oooooooooo`0iooooo`Coc03oI?ooool00ol0003oooooooooo`0eooooo`03
o`000?oooooooooo013ooooo000Jooooo`03o`000?oooooooooo00Kooooo0ol0001Dooooo`03o`00
0?oooooooooo03Gooooo0oo<0?lNooooo`;oo`2IB?ooool00ol0003oooooooooo`0fooooo`03o`00
0?oooooooooo00oooooo000Iooooo`03o`000?oooooooooo00Cooooo0ol0001Hooooo`03o`000?oo
oooooooo037ooooo0oo<0?lOooooo`;oo`2IBoooool00ol0003oooooooooo`0eooooo`03o`000?oo
oooooooo00oooooo000Iooooo`04o`000?ooooooooooooooo`?o0000G?ooool00ol0003ooooooooo
o`0[ooooo`Goc03o8?ooool2ool0VDkooooo00?o0000ooooooooool0=Oooool00ol0003ooooooooo
o`0>ooooo`006Oooool4o`00063ooooo00?o0000ooooooooool09_ooool4ol`0ob;ooooo0ooo09UA
ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool03Oooool001Wooooo0_l0001Soooo
o`03o`000?oooooooooo02;ooooo0oo<0?lTooooo`;oo`2IEOooool00ol0003oooooooooo`0doooo
o`03o`000?oooooooooo00gooooo000?ooooo`Co000000?o410@ooooooooool01Oooool00ol0003o
ooooooooo`1Qooooo`03o`000?oooooooooo023ooooo00?oc03oooooooooool08oooool2ool0VEOo
oooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0<ooooo`004Oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0@oooool2ool0VE[ooooo
00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0;ooooo`004Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0?oooool3ool0VEgooooo00?o
0000ooooooooool0=Oooool00ol0003oooooooooo`0:ooooo`004Oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0>oooool3ool0VF7ooooo00?o0000
ooooooooool0=?ooool00ol0003oooooooooo`0:ooooo`004Oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo067ooooo00?o0000ooooooooool0=oooool3ool0VFGooooo00?o0000oooo
ooooool0=?ooool00ol0003oooooooooo`09ooooo`004Oooool00ol0003oooooooooo`0<ooooo`;o
0000H_ooool00ol0003oooooooooo`0dooooo`;oo`2I8?ooool2ool004Kooooo00?o0000oooooooo
ool0<oooool3o`0000[ooooo000Aooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
H?ooool00ol0003oooooooooo`0`ooooo`?oo`2I8Oooool00ooo003oooooooooo`17ooooo`03o`00
0?oooooooooo02oooooo0ol00002ooooo`03o`000?oooooooooo00Sooooo000?ooooo`03oeEEEOmV
IVKo0000017ooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0[ooooo`Coo`2I8ooo
ool00ooo003oooooooooo`19ooooo`03o`000?oooooooooo02_ooooo0ol00005ooooo`03o`000?oo
oooooooo00Sooooo000Tooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool09?ooool6
ool0VBGooooo0_oo001=ooooo`03o`000?oooooooooo02Kooooo1?l00008ooooo`03o`000?oooooo
oooo00Sooooo000Uooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool07_ooool5ool0
VBSooooo0ooo001@ooooo`03o`000?oooooooooo02;ooooo0ol0000<ooooo`03o`000?oooooooooo
00Sooooo000Vooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool06_ooool3ool0VB_o
oooo0_oo001Cooooo`03o`000?oooooooooo01oooooo0ol0000@ooooo`03o`000?oooooooooo00Oo
oooo000Wooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0AOooool2ool005Kooooo
00?o0000ooooooooool06_ooool4o`0001?ooooo00?o0000ooooooooool01oooool002Sooooo0_l0
001Qooooo`03o`000?oooooooooo04?ooooo00?oo`00ooooooooool0Eoooool00ol0003ooooooooo
o`0Fooooo`?o00005oooool00ol0003oooooooooo`07ooooo`00:_ooool00ol0003oooooooooo`1O
ooooo`03o`000?oooooooooo043ooooo0_oo001Kooooo`03o`000?oooooooooo01;ooooo0ol0000J
ooooo`03o`000?oooooooooo00Oooooo000[ooooo`03o`000?oooooooooo05oooooo00?o0000oooo
ooooool0??ooool3ool005kooooo00?o0000ooooooooool03Oooool4o`0001gooooo00?o0000oooo
ooooool01oooool002cooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0iooooo`;o
o`00HOooool00ol0003oooooooooo`0:ooooo`?o00008Oooool00ol0003oooooooooo`07ooooo`00
;Oooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo03Kooooo0_oo001Tooooo`03o`00
0?oooooooooo00Kooooo0ol0000Tooooo`03o`000?oooooooooo00Oooooo000^ooooo`03o`000?oo
oooooooo05oooooo00?o0000ooooooooool0<_ooool3ool006Oooooo00Co0000oooooooooooooooo
1?l0000Wooooo`03o`000?oooooooooo00Oooooo000_ooooo`;o0000H?ooool00ol0003ooooooooo
o`0/ooooo`Goo`00Joooool3o`0002cooooo00?o0000ooooooooool01_ooool0037ooooo00?o0000
ooooooooool0G_ooool2o`0002Kooooo1_oo001]ooooo`?o000000?oooooo`000?ooool0;?ooool0
0ol0003oooooooooo`06ooooo`00<_ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo
023ooooo0ooo001`ooooo`?o00001?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
00Kooooo000cooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool05?ooool;ool006oo
oooo1?l00008ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool01_ooool003Cooooo
00?o0000ooooooooool0Goooool00ol0003oooooooooo`0?ooooo`Coo`00Moooool3o`0000gooooo
00?o0000ooooooooool0:Oooool00ol0003oooooooooo`06ooooo`00=Oooool00ol0003ooooooooo
o`1Oooooo`03o`000?oooooooooo08Kooooo0ol0000Aooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool01_ooool003Kooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`21
ooooo`Co00005Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Kooooo000goooo
o`;o0000H?ooool00ol0003oooooooooo`1mooooo`?o00006Oooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo00Kooooo000iooooo`03o`000?oooooooooo05kooooo00?o0000oooooooo
ool0NOooool3o`0001gooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`05ooooo`00
>_ooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo07Cooooo1?l0000Qooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool01Oooool003_ooooo00?o0000ooooooooool0G_oo
ool00ol0003oooooooooo`1`ooooo`?o00009_ooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo00Gooooo000looooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0K?ooool3
o`0002Wooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`05ooooo`00?Oooool00ol0
003oooooooooo`1Nooooo`03o`000?oooooooooo06Oooooo1?l0000]ooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool01Oooool003kooooo0_l0001Oooooo`03o`000?oooooooooo06?o
oooo0ol0000booooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool01Oooool0043ooooo
00?o0000ooooooooool0GOooool00ol0003oooooooooo`1Oooooo`?o0000=_ooool00ol0003ooooo
ooooo`0Rooooo`03o`000?oooooooooo00Gooooo0011ooooo`03o`000?oooooooooo05gooooo00?o
0000ooooooooool0F_ooool4o`0003[ooooo00?o0000ooooooooool08Oooool00ol0003ooooooooo
o`05ooooo`00@_ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo05Kooooo0ol0000n
ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool01Oooool004?ooooo00?o0000oooo
ooooool0GOooool00ol0003oooooooooo`1Booooo`?o0000@_ooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo00Cooooo0014ooooo`03o`000?oooooooooo05gooooo00?o0000oooooooo
ool0COooool4o`0004Kooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`04ooooo`00
AOooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo04Wooooo0ol0001;ooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool01?ooool004Kooooo0_l0001Nooooo`03o`000?oo
oooooooo04Gooooo0ol0001?ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool01?oo
ool004Sooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`10ooooo`Co0000D_ooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Cooooo0019ooooo`03o`000?oooooooooo
05cooooo00?o0000ooooooooool0??ooool3o`0005Oooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`04ooooo`00B_ooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo03So
oooo0ol0001Kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool01?ooool004_ooooo
00?o0000ooooooooool0G?ooool00ol0003oooooooooo`0cooooo`Co0000Goooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo00Cooooo001<ooooo`03o`000?oooooooooo05cooooo00?o
0000ooooooooool0;oooool3o`0006Cooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`03ooooo`00COooool2o`0005gooooo00?o0000ooooooooool0:oooool3o`0006Oooooo00?o0000
ooooooooool06oooool00ol0003oooooooooo`03ooooo`00Coooool00ol0003oooooooooo`1Koooo
o`03o`000?oooooooooo02Oooooo0ol0001[ooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool00oooool0053ooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`0Rooooo`Co
0000Koooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00?ooooo001Aooooo`03o`00
0?oooooooooo05_ooooo00?o0000ooooooooool07_ooool3o`0007Cooooo00?o0000ooooooooool0
6?ooool00ol0003oooooooooo`03ooooo`00D_ooool00ol0003oooooooooo`1Kooooo`03o`000?oo
oooooooo01[ooooo0ol0001hooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool00ooo
ool005?ooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`0Eooooo`Co0000Noooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00?ooooo001Dooooo`;o0000G?ooool00ol0
003oooooooooo`0Aooooo`?o0000P?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
00?ooooo001Fooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool03Oooool3o`0008Co
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`02ooooo`00Eoooool00ol0003ooooo
ooooo`1Jooooo`03o`000?oooooooooo00Sooooo1?l00028ooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool00_ooool005Sooooo00?o0000ooooooooool0F_ooool00ol0003ooooooooo
o`04ooooo`?o0000SOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00;ooooo001I
ooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool00ol0002@ooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool00_ooool005[ooooo00?o0000ooooooooool0F_ooool2o`00
09Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`02ooooo`00Foooool00ol0003o
ooooooooo`1Iooooo`03o`000?oooooooooo09Cooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`02ooooo`00G?ooool2o`0005Wooooo00?o0000ooooooooool0UOooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo00;ooooo001Nooooo`03o`000?oooooooooo05Kooooo00?o
0000ooooooooool0U_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo001O
ooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool0U_ooool00ol0003oooooooooo`0A
ooooo`03o`000?oooooooooo007ooooo001Pooooo`03o`000?oooooooooo05Cooooo00?o0000oooo
ooooool0Uoooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo007ooooo001Qooooo`03
o`000?oooooooooo05?ooooo00?o0000ooooooooool0V?ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo007ooooo001Rooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0
VOooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo007ooooo001Sooooo`;o0000D_oo
ool00ol0003oooooooooo`2Jooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00Ooo
ool006Gooooo00?o0000ooooooooool0Coooool00ol0003oooooooooo`2Jooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool00Oooool006Kooooo00?o0000ooooooooool0C_ooool00ol0
003oooooooooo`2Kooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool00Oooool006Oo
oooo00?o0000ooooooooool0COooool00ol0003oooooooooo`2Looooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool00Oooool006Sooooo00?o0000ooooooooool0C?ooool00ol0003ooooo
ooooo`2Mooooo`03o`000?oooooooooo00_ooooo0Ol00001ooooo`7ooooo001Yooooo`03o`000?oo
oooooooo04_ooooo00?o0000ooooooooool0WOooool00ol0003oooooooooo`0;ooooo`7o00000Ooo
ool1ooooo`00J_ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo09kooooo00?o0000
ooooooooool02_ooool1o`00007ooooo0Oooool006_ooooo0_l0001:ooooo`03o`000?oooooooooo
09oooooo00?o0000ooooooooool02Oooool1o`00007ooooo0Oooool006gooooo00?o0000oooooooo
ool0Aoooool00ol0003oooooooooo`2Pooooo`03o`000?oooooooooo00Sooooo0Ol00001ooooo`7o
oooo001^ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0XOooool00ol0003ooooo
ooooo`07ooooo`7o00000Oooool1ooooo`00Koooool00ol0003oooooooooo`15ooooo`03o`000?oo
oooooooo0:7ooooo00?o0000ooooooooool01oooool1o`00007ooooo0Oooool0073ooooo00?o0000
ooooooooool0A?ooool00ol0003oooooooooo`2Rooooo`03o`000?oooooooooo00Kooooo0Ol00001
ooooo`7ooooo001aooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool0Xoooool00ol0
003oooooooooo`05ooooo`7o00000Oooool1ooooo`00L_ooool2o`0004;ooooo00?o0000oooooooo
ool0YOooool00ol0003oooooooooo`05ooooo`7o00000Oooool007Cooooo00?o0000ooooooooool0
?oooool00ol0003oooooooooo`2Vooooo`03o`000?oooooooooo00Cooooo0Ol00001ooooo`00MOoo
ool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo0:Kooooo00?o0000ooooooooool01?oo
ool1o`00007ooooo001fooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0Yoooool0
0ol0003oooooooooo`03ooooo`7o00000Oooool007Oooooo00?o0000ooooooooool0??ooool00ol0
003oooooooooo`2Xooooo`03o`000?oooooooooo00;ooooo0Ol00001ooooo`00N?ooool00ol0003o
ooooooooo`0kooooo`03o`000?oooooooooo0:Wooooo00Go0000ooooooooooooooooo`000001oooo
o`00NOooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo0:[ooooo00Co0000oooooooo
oooo00000Oooool007[ooooo0_l0000jooooo`03o`000?oooooooooo0:[ooooo00Co0000oooooooo
oooo00000Oooool007cooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`2[ooooo`03
o`000?oooooooooo007o0000001mooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0
[?ooool1o`00007ooooo0Ol0000007kooooo00?o0000ooooooooool0=Oooool00ol0003ooooooooo
o`2]ooooo`;o0000001oooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0[?ooool3
o`000000P?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo0:Sooooo1?l00003oooo
o`00POooool2o`0003?ooooo00?o0000ooooooooool0YOooool3o`0000Oooooo0023ooooo`03o`00
0?oooooooooo033ooooo00?o0000ooooooooool0XOooool4o`0000[ooooo0024ooooo`03o`000?oo
oooooooo02oooooo00?o0000ooooooooool0WOooool4o`0000kooooo0025ooooo`03o`000?oooooo
oooo02kooooo00?o0000ooooooooool0VOooool4o`0001;ooooo0026ooooo`03o`000?oooooooooo
02gooooo00?o0000ooooooooool0UOooool4o`0001Kooooo0027ooooo`03o`000?oooooooooo02co
oooo00?o0000ooooooooool0T_ooool3o`0001[ooooo0028ooooo`;o0000;?ooool00ol0003ooooo
ooooo`2>ooooo`Co00007Oooool008[ooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`2:ooooo`Co00008Oooool008_ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`26
ooooo`Co00009Oooool008cooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`22oooo
o`Co0000:Oooool008gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1oooooo`?o
0000;Oooool008kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1kooooo`Co0000
<?ooool008oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1gooooo`Co0000=?oo
ool0093ooooo0_l0000Tooooo`03o`000?oooooooooo07?ooooo1?l0000hooooo`00T_ooool00ol0
003oooooooooo`0Qooooo`03o`000?oooooooooo073ooooo0ol0000looooo`00Toooool00ol0003o
ooooooooo`0Pooooo`03o`000?oooooooooo06cooooo1?l0000oooooo`00U?ooool00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo06Sooooo1?l00013ooooo`00UOooool00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo06Cooooo1?l00017ooooo`00U_ooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo063ooooo1?l0001;ooooo`00Uoooool2o`0001gooooo00?o0000oooo
ooooool0GOooool3o`0004oooooo002Iooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool0FOooool4o`0005;ooooo002Jooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
EOooool4o`0005Kooooo002Kooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0DOoo
ool4o`0005[ooooo002Looooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0COooool4
o`0005kooooo002Mooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0B_ooool3o`00
06;ooooo002Nooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0A_ooool4o`0006Go
oooo002Oooooo`;o00005?ooool00ol0003oooooooooo`13ooooo`Co0000JOooool00:7ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`0oooooo`Co0000KOooool00:;ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0kooooo`Co0000LOooool00:?ooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0hooooo`?o0000MOooool00:Cooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0dooooo`Co0000N?ooool00:Gooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0`ooooo`Co0000O?ooool00:Kooooo0_l0000=ooooo`03o`000?oo
oooooooo02cooooo1?l00020ooooo`00Z?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo02Wooooo0ol00024ooooo`00ZOooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
02Gooooo1?l00027ooooo`00Z_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo027o
oooo1?l0002;ooooo`00Zoooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01gooooo
1?l0002?ooooo`00[?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Wooooo1?l0
002Cooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Kooooo0ol0002G
ooooo`00[_ooool2o`0000Gooooo00?o0000ooooooooool04_ooool4o`0009[ooooo002`ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool03_ooool4o`0009kooooo002aooooo`05o`00
0?ooooooooooooooool000003?ooool4o`000:;ooooo002booooo`04o`000?ooooooooooo`0000So
oooo1?l0002Vooooo`00/oooool00ol0003oooooo`000005ooooo`?o0000Z_ooool00;Cooooo0_l0
00000ooooooo0000o`000002o`000:gooooo002eooooo`;o0000/Oooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {319.688, 0}} -> {-0.0710364, -0.0181728, \
0.0035149, 0.0035149}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .89104 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-16 1.0656 -0.0363427 1.0656 [
[.02544 .21571 -12 -8.9133 ]
[.02544 .21571 0 .0867 ]
[.16074 .16277 -11.6592 -9 ]
[.16074 .16277 .34081 0 ]
[.3021 .10747 -5.60025 -9 ]
[.3021 .10747 .39975 0 ]
[.44992 .04965 -5.37091 -9 ]
[.44992 .04965 .62909 0 ]
[.60467 -0.01084 -5.14157 -9 ]
[.60467 -0.01084 .85843 0 ]
[.66454 .05085 0 -6.20675 ]
[.66454 .05085 6 2.79325 ]
[.80797 .25198 0 -6.0417 ]
[.80797 .25198 6 2.9583 ]
[.93071 .4241 0 -5.90576 ]
[.93071 .4241 6 3.09424 ]
[.02254 .22988 -12 -2.74631 ]
[.02254 .22988 0 6.25369 ]
[.0142 .29178 -24 -2.78907 ]
[.0142 .29178 0 6.21093 ]
[.00558 .35578 -6 -2.83339 ]
[.00558 .35578 0 6.16661 ]
[-0.00334 .42198 -18 -2.87938 ]
[-0.00334 .42198 0 6.12062 ]
[-0.01257 .49051 -6 -2.92712 ]
[-0.01257 .49051 0 6.07288 ]
[ 0 0 0 0 ]
[ 1 .89104 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03495 .22504 m
.61241 0 L
s
.03495 .22504 m
.03971 .2297 L
s
[(-2)] .02544 .21571 1 .98073 Mshowa
.16988 .17246 m
.17445 .1773 L
s
[(-1)] .16074 .16277 .9432 1 Mshowa
.31082 .11753 m
.31518 .12256 L
s
[(0)] .3021 .10747 .86675 1 Mshowa
.45818 .0601 m
.46231 .06533 L
s
[(1)] .44992 .04965 .7903 1 Mshowa
.61241 0 m
.61628 .00542 L
s
[(2)] .60467 -0.01084 .71386 1 Mshowa
.125 Mabswid
.06148 .2147 m
.06431 .21752 L
s
.08823 .20428 m
.09104 .20712 L
s
.11521 .19376 m
.118 .19663 L
s
.14243 .18316 m
.14519 .18604 L
s
.19758 .16166 m
.20029 .16459 L
s
.22551 .15078 m
.22821 .15373 L
s
.2537 .13979 m
.25637 .14277 L
s
.28213 .12871 m
.28478 .13171 L
s
.33977 .10625 m
.34236 .10929 L
s
.36897 .09487 m
.37153 .09794 L
s
.39844 .08339 m
.40097 .08648 L
s
.42817 .0718 m
.43068 .07491 L
s
.48846 .0483 m
.49091 .05146 L
s
.51902 .03639 m
.52144 .03958 L
s
.54986 .02437 m
.55225 .02758 L
s
.58099 .01224 m
.58335 .01547 L
s
.25 Mabswid
.61241 0 m
.97291 .505 L
s
.65208 .05558 m
.64586 .05794 L
s
[(0)] .66454 .05085 -1 .37928 Mshowa
.79537 .2563 m
.78907 .25846 L
s
[(2)] .80797 .25198 -1 .3426 Mshowa
.91799 .42808 m
.91164 .43006 L
s
[(4)] .93071 .4241 -1 .31239 Mshowa
.125 Mabswid
.69012 .10886 m
.68637 .11025 L
s
.72662 .16 m
.72286 .16135 L
s
.76168 .2091 m
.75791 .21042 L
s
.82778 .3017 m
.82399 .30297 L
s
.85897 .3454 m
.85518 .34664 L
s
.88903 .3875 m
.88522 .38871 L
s
.94594 .46722 m
.94211 .46839 L
s
.25 Mabswid
.03495 .22504 m
0 .48612 L
s
.03495 .22504 m
.04116 .22262 L
s
[(-1)] .02254 .22988 1 -0.38971 Mshowa
.02665 .28704 m
.03288 .28468 L
s
[(-0.5)] .0142 .29178 1 -0.38021 Mshowa
.01807 .35115 m
.02431 .34884 L
s
[(0)] .00558 .35578 1 -0.37036 Mshowa
.00919 .41747 m
.01546 .41521 L
s
[(0.5)] -0.00334 .42198 1 -0.36014 Mshowa
0 .48612 m
.00629 .48392 L
s
[(1)] -0.01257 .49051 1 -0.34953 Mshowa
.125 Mabswid
.03331 .23728 m
.03704 .23583 L
s
.03166 .2496 m
.03539 .24816 L
s
.03 .262 m
.03373 .26056 L
s
.02833 .27448 m
.03207 .27305 L
s
.02496 .29969 m
.0287 .29828 L
s
.02325 .31243 m
.02699 .31102 L
s
.02154 .32525 m
.02528 .32385 L
s
.01981 .33816 m
.02355 .33676 L
s
.01632 .36423 m
.02007 .36285 L
s
.01455 .37741 m
.01831 .37603 L
s
.01278 .39067 m
.01653 .3893 L
s
.01099 .40402 m
.01475 .40266 L
s
.00738 .43101 m
.01114 .42966 L
s
.00555 .44464 m
.00932 .4433 L
s
.00371 .45837 m
.00748 .45704 L
s
.00186 .4722 m
.00563 .47087 L
s
.25 Mabswid
.03495 .22504 m
0 .48612 L
s
0 .48612 m
.46953 .89104 L
s
.46953 .89104 m
.47294 .65459 L
s
.47294 .65459 m
.03495 .22504 L
s
.61241 0 m
.97291 .505 L
s
.97291 .505 m
1 .75117 L
s
1 .75117 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.03495 .22504 m
0 .48612 L
s
0 .48612 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.61241 0 m
.03495 .22504 L
s
.47294 .65459 m
.97291 .505 L
s
.97291 .505 m
1 .75117 L
s
1 .75117 m
.46953 .89104 L
s
.46953 .89104 m
.47294 .65459 L
s
0 0 m
1 0 L
1 .89104 L
0 .89104 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.43475 .5958 m
.45907 .59489 L
s
.45907 .59489 m
.4856 .59223 L
s
.4856 .59223 m
.51321 .58765 L
s
.51321 .58765 m
.54086 .58116 L
s
1 0 .6 r
.43396 .56501 m
.45525 .56429 L
s
.45525 .56429 m
.4786 .56212 L
s
.4786 .56212 m
.50314 .55822 L
s
1 0 0 r
.54086 .58116 m
.56765 .57294 L
s
1 0 .6 r
.50314 .55822 m
.52786 .55249 L
s
1 0 0 r
.56765 .57294 m
.59276 .56319 L
s
1 0 .6 r
.52786 .55249 m
.55175 .54503 L
s
.8 0 1 r
.43118 .52951 m
.44939 .52809 L
s
.44939 .52809 m
.46886 .52573 L
s
.46886 .52573 m
.48916 .52215 L
s
1 0 .6 r
.55175 .54503 m
.57392 .53612 L
s
1 0 0 r
.59276 .56319 m
.6154 .55225 L
s
.8 0 1 r
.48916 .52215 m
.50958 .51719 L
s
.50958 .51719 m
.52936 .5109 L
s
1 0 .6 r
.57392 .53612 m
.59358 .52615 L
s
.2 0 1 r
.42321 .49388 m
.43923 .49111 L
s
1 0 0 r
.6154 .55225 m
.63482 .54061 L
s
.2 0 1 r
.43923 .49111 m
.45565 .48789 L
s
.8 0 1 r
.52936 .5109 m
.54779 .50348 L
s
.2 0 1 r
.45565 .48789 m
.47231 .48405 L
s
1 0 .6 r
.59358 .52615 m
.6102 .51569 L
s
.2 0 1 r
.47231 .48405 m
.48891 .4795 L
s
.8 0 1 r
.54779 .50348 m
.56435 .49529 L
s
0 .4 1 r
.41227 .46344 m
.42704 .45958 L
s
1 0 0 r
.63482 .54061 m
.65052 .52894 L
s
.2 0 1 r
.48891 .4795 m
.50515 .47422 L
s
0 .4 1 r
.42704 .45958 m
.44191 .45553 L
s
0 1 1 r
.40211 .43786 m
.41633 .43347 L
s
1 0 .6 r
.6102 .51569 m
.62365 .50535 L
s
0 .4 1 r
.44191 .45553 m
.4568 .45124 L
s
.8 0 1 r
.56435 .49529 m
.57882 .48675 L
s
0 1 .4 r
.39318 .41473 m
.40718 .41011 L
s
.2 0 1 r
.50515 .47422 m
.52071 .46832 L
s
0 1 1 r
.41633 .43347 m
.43059 .429 L
s
.2 1 0 r
.38494 .39264 m
.39885 .38791 L
s
0 .4 1 r
.4568 .45124 m
.47164 .44667 L
s
.8 1 0 r
.37698 .37096 m
.39087 .36615 L
s
0 1 .4 r
.40718 .41011 m
.42123 .40545 L
s
1 .6 0 r
.36914 .34941 m
.38301 .34455 L
s
0 1 1 r
.43059 .429 m
.44489 .42443 L
s
.2 0 1 r
.52071 .46832 m
.53541 .46195 L
s
.2 1 0 r
.39885 .38791 m
.41282 .38315 L
s
.8 0 1 r
.57882 .48675 m
.59132 .47826 L
s
0 .4 1 r
.47164 .44667 m
.48633 .44181 L
s
.8 1 0 r
.39087 .36615 m
.40481 .36133 L
s
0 1 .4 r
.42123 .40545 m
.43533 .40074 L
s
1 .6 0 r
.38301 .34455 m
.39693 .33966 L
s
0 1 1 r
.44489 .42443 m
.45918 .41976 L
s
.2 1 0 r
.41282 .38315 m
.42685 .37836 L
s
.2 0 1 r
.53541 .46195 m
.54923 .4553 L
s
0 .4 1 r
.48633 .44181 m
.50082 .43669 L
s
.8 1 0 r
.40481 .36133 m
.41881 .35648 L
s
0 1 .4 r
.43533 .40074 m
.44946 .39599 L
s
1 .6 0 r
.39693 .33966 m
.41092 .33476 L
s
0 1 1 r
.45918 .41976 m
.47346 .41497 L
s
.2 1 0 r
.42685 .37836 m
.44093 .37354 L
s
.8 1 0 r
.41881 .35648 m
.43286 .3516 L
s
0 .4 1 r
.50082 .43669 m
.51507 .43133 L
s
0 1 .4 r
.44946 .39599 m
.46363 .39118 L
s
1 .6 0 r
.41092 .33476 m
.42496 .32984 L
s
.2 0 1 r
.54923 .4553 m
.56228 .44856 L
s
0 1 1 r
.47346 .41497 m
.48771 .41007 L
s
.2 1 0 r
.44093 .37354 m
.45506 .36869 L
s
.8 1 0 r
.43286 .3516 m
.44697 .34671 L
s
0 1 .4 r
.46363 .39118 m
.47782 .38632 L
s
0 .4 1 r
.51507 .43133 m
.52908 .42581 L
s
1 .6 0 r
.42496 .32984 m
.43907 .32489 L
s
0 1 1 r
.48771 .41007 m
.50193 .40508 L
s
.2 1 0 r
.45506 .36869 m
.46924 .36381 L
s
.8 1 0 r
.44697 .34671 m
.46115 .34179 L
s
0 1 .4 r
.47782 .38632 m
.49205 .38141 L
s
1 .6 0 r
.43907 .32489 m
.45323 .31992 L
s
0 .4 1 r
.52908 .42581 m
.5429 .4202 L
s
0 1 1 r
.50193 .40508 m
.51612 .4 L
s
.2 1 0 r
.46924 .36381 m
.48347 .3589 L
s
.8 1 0 r
.46115 .34179 m
.47537 .33684 L
s
0 1 .4 r
.49205 .38141 m
.50631 .37646 L
s
1 .6 0 r
.45323 .31992 m
.46745 .31493 L
s
0 1 1 r
.51612 .4 m
.53029 .39486 L
s
.2 1 0 r
.48347 .3589 m
.49775 .35396 L
s
.8 1 0 r
.47537 .33684 m
.48966 .33187 L
s
0 1 .4 r
.50631 .37646 m
.52061 .37147 L
s
1 .6 0 r
.46745 .31493 m
.48174 .30992 L
s
.2 1 0 r
.49775 .35396 m
.51209 .34899 L
s
.8 1 0 r
.48966 .33187 m
.50401 .32688 L
s
1 .6 0 r
.48174 .30992 m
.49608 .30489 L
s
0 g
.25 Mabswid
.61241 0 m
.97291 .505 L
s
.97291 .505 m
1 .75117 L
s
1 .75117 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.03495 .22504 m
0 .48612 L
s
0 .48612 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.61241 0 m
.03495 .22504 L
s
.03495 .22504 m
.61241 0 L
s
.03495 .22504 m
.03971 .2297 L
s
[(-2)] .02544 .21571 1 .98073 Mshowa
.16988 .17246 m
.17445 .1773 L
s
[(-1)] .16074 .16277 .9432 1 Mshowa
.31082 .11753 m
.31518 .12256 L
s
[(0)] .3021 .10747 .86675 1 Mshowa
.45818 .0601 m
.46231 .06533 L
s
[(1)] .44992 .04965 .7903 1 Mshowa
.61241 0 m
.61628 .00542 L
s
[(2)] .60467 -0.01084 .71386 1 Mshowa
.125 Mabswid
.06148 .2147 m
.06431 .21752 L
s
.08823 .20428 m
.09104 .20712 L
s
.11521 .19376 m
.118 .19663 L
s
.14243 .18316 m
.14519 .18604 L
s
.19758 .16166 m
.20029 .16459 L
s
.22551 .15078 m
.22821 .15373 L
s
.2537 .13979 m
.25637 .14277 L
s
.28213 .12871 m
.28478 .13171 L
s
.33977 .10625 m
.34236 .10929 L
s
.36897 .09487 m
.37153 .09794 L
s
.39844 .08339 m
.40097 .08648 L
s
.42817 .0718 m
.43068 .07491 L
s
.48846 .0483 m
.49091 .05146 L
s
.51902 .03639 m
.52144 .03958 L
s
.54986 .02437 m
.55225 .02758 L
s
.58099 .01224 m
.58335 .01547 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 256.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001@2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00gOooool5o`0008Kooooo003Mooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0Q_ooool00=ko
oooo00?oV9RHob4Q8Oo^k^h0Qoooool00=oooooo00?oV9RHob4Q8Oo^k^h0Q_ooool00>3ooooo00?o
MgMgofIVI_ooool0QOooool00>7ooooo00?o0000ooooooooool0Q?ooool00=gooooo00Go0000okZj
^_ooooooV9RHoa0@4026ooooo`00gOooool01OnHV9So410@o`000?lQ8B7oc<c<08Kooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003Tooooo`;o0000P_ooool0
0>7ooooo0ol000000ooooooo0000ooooo`21ooooo`00goooool2o`0000Cooooo0_l00021ooooo`00
g?ooool3o`0000Kooooo00?o0000ooooool00000P?ooool00=[ooooo0_l00009ooooo`03o`000?oo
oooo0000083ooooo003Gooooo`?o000000?oooooo`000?ooool02?ooool01?l0003oooooooooool0
001oooooo`00e?ooool3o`0000Cooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooo
oooo000007kooooo003Booooo`;o00004Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo07_ooooo002Zooooo`Co000000?o410@ooooooooool07_ooool3o`0001?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1kooooo`00[?ooool00ol0003oooooooooo`0Nooooo`;o
000000?oooooo`000?ooool04oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07[o
oooo002/ooooo`03o`000?oooooooooo01_ooooo0ol00004ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`1iooooo`00[?ooool00ol0003ooooooooo
o`0Iooooo`;o00006oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo07Wooooo002/
ooooo`03o`000?oooooooooo01Kooooo0ol0000Mooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool02?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^06_ooooo002/ooooo`03o`000?oooooo
oooo01Cooooo0_l000000ooooooo0000ooooo`0Mooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01oooool01OmgMgOoV9RHoooooonHV9SoMgMg06_ooooo002/ooooo`03o`000?oooooo
oooo017ooooo0ol00004ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`06ooooo`05oa0@4?ooooooooooooooool@4100Joooool00:[ooooo00?oEEEE
ofIVI_l000004Oooool2o`0002Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06
ooooo`05o`000?ooooooooooooooool00000Joooool00;_ooooo0ol0000Wooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000006_ooooo002i
ooooo`;o000000?oooooo`000?ooool09oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Cooooo00Go410@oooooooooooooooooa0@401[ooooo`00]_ooool3o`0000Cooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`1[ooooo`00/oooool3o`0002oooooo00?o0000ooooooooool02Oooool2
o`0000Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1[ooooo`00/Oooool2o`0003;ooooo00?o0000
ooooooooool02?ooool01?l0003oooooooooool0001dooooo`00[_ooool3o`000003ooooool0003o
oooo037ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1aooooo`00[?ooool2o`00
00Gooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
077ooooo002Yooooo`?o0000>_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo073o
oooo002Wooooo`;o0000?Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo06oooooo
002Tooooo`?o000000?oooooo`000?ooool0??ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo06oooooo002Rooooo`;o0000@_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo06kooooo001gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08oooool3o`0004Cooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1]ooooo`00Moooool01OmgMgOoV9RHoooooonHV9So
MgMg027ooooo0_l00017ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0K?ooool0
07Oooooo00Go410@oooooooooooooooooa0@400Nooooo`?o00000_ooool00ol0003oooooooooo`14
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0K?ooool007Oooooo00Go0000oooo
ooooooooooooo`00000Looooo`;o0000C?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo06_ooooo001gooooo`05o`000?ooooooooooooooool000006Oooool3o`0004kooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`1Zooooo`00Moooool01Ol@413ooooooooooooooooo
410@01Kooooo0ol0001Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0J_ooool0
07Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Dooooo`;o00000oooool00ol0003oooooooooo`1>
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0JOooool007Oooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Aooooo`?o0000E_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo06Sooooo002;ooooo`;o0000FOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
06Sooooo0028ooooo`?o0000Foooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo06Oo
oooo0026ooooo`;o00000oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo01Gooooo
0_l0001Xooooo`00Poooool3o`00063ooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`1Uooooo`00POooool2o`0006?ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1U
ooooo`00O_ooool4o`0006Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`1Toooo
o`00O?ooool2o`0000Cooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo06?ooooo001iooooo`?o0000J_ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo06?ooooo001gooooo`;o0000KOooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo06;ooooo001dooooo`?o000000?oooooo`000?ooool0K?ooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo067ooooo001aooooo`?o0000L_ooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo063ooooo0019ooooo`Co000000?o410@ooooooooool07oooool2o`0007Go
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1Pooooo`00Boooool00ol0003ooooo
ooooo`0Nooooo`?o0000Moooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo05oooooo
0010ooooo`Ko00001Oooool00ol0003oooooooooo`0Looooo`;o00000_ooool00ol0003ooooooooo
o`1eooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0G_ooool004_ooooo00?o0000
ooooooooool06Oooool3o`0007cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1N
ooooo`00Boooool00ol0003oooooooooo`0Gooooo`;o0000Ooooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo05gooooo001;ooooo`03o`000?oooooooooo01Cooooo0ol00021ooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0G?ooool004_ooooo00?o0000ooooooooool0
4_ooool2o`0000?ooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo05_ooooo0019ooooo`03oeEEEOmVIVKo0000017ooooo0ol00026ooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool0Foooool005_ooooo0_l00029ooooo`03o`000?oooooo
oooo027ooooo0_l0001Looooo`00F?ooool3o`000003ooooool0003ooooo08Sooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`1Iooooo`00E_ooool2o`0008kooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`1Iooooo`00Doooool3o`00093ooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`1Hooooo`00D?ooool3o`0009?ooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1Gooooo`00C_ooool2o`0000;ooooo00?o0000ooooooooool0TOooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo05Kooooo001;ooooo`?o00001Oooool00ol0
003oooooooooo`2@ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0E_ooool004Wo
oooo0_l0002Kooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0EOooool004Kooooo
1?l0002Looooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0E?ooool004Cooooo0_l0
002Pooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0E?ooool001[ooooo1Ol0000R
ooooo`?o0000X_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo05?ooooo000Joooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@08?ooool2o`000:Gooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`1Booooo`004_ooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h07_ooool3o`00
0003ooooool0003ooooo0:Cooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`1Aoooo
o`007?ooool00onHV9So8B4Qonk^kP0Kooooo`;o0000Z_ooool00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo057ooooo000Mooooo`03ogMgMomVIVKooooo01Oooooo0ol0002]ooooo`03o`00
0?oooooooooo02_ooooo00?o0000ooooooooool0D?ooool001kooooo00?o0000ooooooooool05?oo
ool2o`000;3ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`1?ooooo`006_ooool0
1Ol0003o^[ZjoooooonHV9So410@01?ooooo0ol00002ooooo`03o`000?oooooooooo0:gooooo00?o
0000ooooooooool0;?ooool2o`00053ooooo000Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`04?oo
ool3o`000;Gooooo00?o0000ooooooooool0;?ooool2o`00053ooooo000]ooooo`;o0000^?ooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo04gooooo000Zooooo`?o000000?oooooo`00
0?ooool0]oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo04gooooo000Xooooo`;o
0000_Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo04cooooo000Uooooo`?o0000
_oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo04_ooooo000Tooooo`;o0000`Ooo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo04[ooooo000Jooooo`Co000000?o410@
ooooooooool00oooool00ol0003oooooo`000030ooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool0B_ooool001cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0002o
ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0BOooool0017ooooo1_l00005oooo
o`03o`000?oooooooooo00Gooooo0_l00002ooooo`03o`000?oooooooooo0;cooooo00?o0000oooo
ooooool0<oooool00ol0003oooooooooo`18ooooo`007?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0^oooool00ol0003oooooooooo`0cooooo`03
o`000?oooooooooo00Oooooo1Ol0000looooo`007?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo00Kooooo00GoV9RHob4Q8Oo^k^koooooodA4A00looooo`007?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00ol0003ooooo
ooooo`0eooooo`03o`000?oooooooooo00Kooooo00?oV9RHob4Q8Oo^k^h0?Oooool001cooooo00?o
0000ooooooooool01?ooool3o`0000Kooooo00?o0000ooooooooool0^?ooool00ol0003ooooooooo
o`0fooooo`03o`000?oooooooooo00Kooooo00?oV9RHob4Q8Oo^k^h0??ooool001[ooooo00?oEEEE
ofIVI_l000001_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;Oooooo00?o0000
ooooooooool0=_ooool00ol0003oooooooooo`07ooooo`03ogMgMomVIVKooooo03_ooooo000Soooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0]_ooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0>_ooool002?ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`2eooooo`03o`000?oooooooooo03Oooooo0_l00004ooooo`05
o`000?nj^[[ooooooiRHV?l@4100??ooool002?ooooo0_l0000;ooooo`03o`000?oooooooooo0;Co
oooo00?o0000ooooooooool0=_ooool00ol0003oooooo`000004ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`0??ooool002?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`2cooooo`03
o`000?oooooooooo03Wooooo00?o0000ooooooooool0@_ooool002;ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0
@Oooool002;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`2`ooooo`;o0000?Ooo
ool00ol0003oooooooooo`10ooooo`008_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo0:cooooo0ol000000ooooooo0000ooooo`0looooo`03o`000?oooooooooo043ooooo000Roooo
o`;o00004Oooool00ol0003oooooooooo`2Xooooo`?o00001Oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo03oooooo000Rooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool0Y?ooool3o`0000Wooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0nooooo`00
8_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo0:3ooooo0ol0000=ooooo`03o`00
0?oooooooooo03[ooooo00?o0000ooooooooool0?_ooool002;ooooo0ol0000Cooooo`03o`000?oo
oooooooo09cooooo0ol0000Aooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0?Ooo
ool002;ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`2Iooooo`;o00005?ooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo03cooooo000Qooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool0UOooool3o`0001Oooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`0kooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo097ooooo0ol0000Kooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0>oooool0
00Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0SOooool3o`0001oooooo00?o0000
ooooooooool0>_ooool00ol0003oooooooooo`0jooooo`001Ol00002ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`02ooooo`;o00006_ooool00ol0003oooooooooo`29
ooooo`?o00008oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03Wooooo0007oooo
o`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool0Q_ooool2o`0002Kooooo00?o0000ooooooooool0>_ooool2
o`0003[ooooo0007ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1kooooo`;ooiT01Ooo
ool3o`0002Wooooo00?o0000ooooooooool0>Oooool2o`0003[ooooo0007ooooo`05oa0@4?oooooo
ooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool0N?ooool2oonI00Cooooo0ol0000]ooooo`03o`000?oooooooooo03[ooooo00?o
0000ooooooooool0=oooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oo
oooooooo00Kooooo0_l0000Nooooo`03o`000?oooooooooo07Gooooo0_ooV@03ooooo`?o0000<Ooo
ool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo03Oooooo0007ooooo`05onk^k_lb<S;o
0000oc8b<_o^k^h03?ooool4o`0000Cooooo0_l0000Pooooo`03o`000?oooooooooo077ooooo0ooo
V@02ooooo`?o0000=Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo03Kooooo000P
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0KOooool3oonI00;ooooo0ol0000h
ooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0=Oooool0023ooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`1Xooooo`CooiT00oooool2o`0003cooooo00?o0000oooo
ooooool0>_ooool00ol0003oooooooooo`0dooooo`008?ooool2o`0002?ooooo00?o0000oooooooo
ool0I?ooool3oonI00Cooooo0ol0000oooooo`03o`000?oooooooooo03Wooooo00?o0000oooooooo
ool0=?ooool0023ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Pooooo`?ooiT0
1?ooool3o`0000gooooo0_o<o`0dooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0
<oooool0023ooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1Looooo`?ooiT01?oo
ool3o`0000gooooo0oo<o`0gooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0<_oo
ool0023ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1Hooooo`?ooiT01?ooool3
o`0000kooooo0_o<o`0jooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0<_ooool0
023ooooo00?o0000ooooooooool09_ooool2o`0005Kooooo0_ooV@05ooooo`;o00003_ooool3olco
03gooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0aooooo`007oooool3o`0002Wo
oooo00?o0000ooooooooool0D?ooool3oonI00Cooooo0ol0000=ooooo`?oc?l0@Oooool00ol0003o
ooooooooo`0iooooo`03o`000?oooooooooo033ooooo000Oooooo`03o`000?oooooooooo02[ooooo
00?o0000ooooooooool0C?ooool3oonI00Cooooo0ol0000=ooooo`?oc?l0AOooool00ol0003ooooo
ooooo`0iooooo`03o`000?oooooooooo02oooooo000Oooooo`03o`000?oooooooooo02_ooooo00?o
0000ooooooooool0B?ooool3oonI00Cooooo0ol0000=ooooo`?oc?l0B?ooool00ol0003ooooooooo
o`0iooooo`03o`000?oooooooooo02oooooo000Oooooo`03o`000?oooooooooo02cooooo00?o0000
ooooooooool0A?ooool3oonI00Cooooo0ol0000>ooooo`;oc?l0C?ooool00ol0003oooooooooo`0h
ooooo`;o0000<?ooool001oooooo0ol0000]ooooo`03o`000?oooooooooo04;ooooo00?ooiT0oooo
ooooool00_ooool3o`0000kooooo0oo<o`0Fooooo`;o<ol0=oooool00ol0003oooooooooo`0ioooo
o`03o`000?oooooooooo02gooooo000Oooooo`03o`000?oooooooooo02kooooo00?o0000oooooooo
ool0A?ooool2o`0000kooooo0oo<o`0Fooooo`?o<ol0>_ooool00ol0003oooooooooo`0hooooo`03
o`000?oooooooooo02gooooo000Dooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003o
ooooooooo`0_ooooo`03o`000?oooooooooo043ooooo0ol0000=ooooo`?oc?l05_ooool3oc?o03ko
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0/ooooo`005?ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0looooo`?o
00003Oooool3olco01Gooooo1?lco`11ooooo`03o`000?oooooooooo03Wooooo00?o0000oooooooo
ool0:oooool001Cooooo00Go410@oooooooooooooooooa0@4005ooooo`;o0000<oooool00ol0003o
ooooooooo`0hooooo`?o00003_ooool2olco01Gooooo0olco`16ooooo`03o`000?oooooooooo03Wo
oooo00?o0000ooooooooool0:_ooool001Cooooo00Go0000ooooooooooooooooo`000005ooooo`03
o`000?oooooooooo03?ooooo00?o0000ooooooooool0=?ooool3o`0000kooooo0oo<o`0Dooooo`?o
<ol0B_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02[ooooo000Dooooo`05o`00
0?ooooooooooooooool000001Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo033o
oooo0ol0000>ooooo`?oc?l05?ooool3oc?o04kooooo00?o0000ooooooooool0>?ooool00ol0003o
ooooooooo`0Yooooo`005?ooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000oooooooo
ool0=Oooool00ol0003oooooooooo`0]ooooo`;o00003oooool2olco01Cooooo0olco`0Fooooo`;o
0?mV>_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02Sooooo000Dooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo02Wo
oooo0ol0000Uooooo`;o<ol05_ooool3o`3oIScooooo00?o0000ooooooooool0>?ooool00ol0003o
ooooooooo`0Xooooo`005?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_l0000hooooo`03
o`000?oooooooooo02Gooooo0ol0000Uooooo`?o<ol05_ooool2o`3oIT3ooooo00?o0000oooooooo
ool0>?ooool00ol0003oooooooooo`0Wooooo`007_ooool00ol0003oooooooooo`0hooooo`03o`00
0?oooooooooo027ooooo0ol0000Uooooo`?o<ol05_ooool3o`3oIT?ooooo00?o0000ooooooooool0
>?ooool00ol0003oooooooooo`0Vooooo`007Oooool00ol0003oooooooooo`0jooooo`03o`000?oo
oooooooo01gooooo0ol0000Uooooo`?o<ol05_ooool3o`3oITOooooo00?o0000ooooooooool0>?oo
ool00ol0003oooooooooo`0Uooooo`007Oooool00ol0003oooooooooo`0kooooo`03o`000?oooooo
oooo01[ooooo0_l0000Uooooo`?o<ol05Oooool4o`3oIT_ooooo00?o0000ooooooooool0=oooool0
0ol0003oooooooooo`0Uooooo`007Oooool2o`0003gooooo00?o0000ooooooooool05_ooool3o`00
02Cooooo0olco`0Eooooo`?o0?mVCoooool00ol0003oooooooooo`0gooooo`;o00009_ooool001go
oooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Booooo`?o00009?ooool3oc?o01Ko
oooo0_l0ofICooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool08oooool001gooooo
00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0>ooooo`?o0000?_ooool2o`3oIQOooooo
0_l0oolmooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool08oooool001gooooo00?o
0000ooooooooool0?oooool00ol0003oooooooooo`0:ooooo`?o0000?_ooool3o`3oIQKooooo0ol0
oom0ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool08_ooool001gooooo00?o0000
ooooooooool0@?ooool00ol0003oooooooooo`06ooooo`?o0000?Oooool4o`3oIQOooooo0_l0oom4
ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool08Oooool001cooooo0ol00012oooo
o`03o`000?oooooooooo00?ooooo0_l0000mooooo`?o0?mV6?ooool3o`3oodKooooo00?o0000oooo
ooooool0>?ooool00ol0003oooooooooo`0Pooooo`007?ooool00ol0003oooooooooo`13ooooo`03
o`000?oooooo000000;o0000??ooool3o`3oIQSooooo0ol0oom:ooooo`03o`000?oooooooooo03Oo
oooo00?o0000ooooooooool08?ooool001cooooo00?o0000ooooooooool0@_ooool3o`0003cooooo
0ol0ofHHooooo`?o0?ooC_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00Wooooo
0_l000000ol@413oooooooooo`0Aooooo`007?ooool00ol0003oooooooooo`0oooooo`?o00000ooo
ool00ol0003oooooooooo`0fooooo`?o0?mV6?ooool3o`3ooe;ooooo00?o0000ooooooooool0=ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01;ooooo000Looooo`?o0000??ooool3
o`0000Oooooo00?o0000ooooooooool0=?ooool00ol0ofKoooooooooo`0Fooooo`?o0?ooE_ooool0
0ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Kooooo1Ol0000Cooooo`007?ooool00ol0
003oooooooooo`0iooooo`?o00002oooool00ol0003oooooooooo`18ooooo`Co0?ooFOooool00ol0
003oooooooooo`0gooooo`03o`000?oooooooooo00Gooooo00CoA4A4omgMgOoooooo00005?ooool0
0006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8b
omgMg@05ooooo`03o`000?oooooooooo03Oooooo0_l0000?ooooo`03o`000?oooooooooo04Cooooo
0ol0oolLooooo`;o06Ko@?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00Cooooo
00CogMgMoeEEEOoooooo00005?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q
8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0dooooo`?o00004_ooool00ol0
003oooooooooo`11ooooo`;o0?oo7?ooool3o`1Vod?ooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`05ooooo`03ogMgMoo<c<co000001Cooooo00000ooooooo410@ooooo`02ooooo`03
oa0@4?oooooooooo00kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0aooooo`?o
00005_ooool00ol0003oooooooooo`0mooooo`?o0?oo6oooool3o`1VodOooooo00?o0000oooooooo
ool0=_ooool2o`0000Gooooo00?ok^k^odA4A?l000005?ooool00003ooooool0003ooooo00;ooooo
00?o0000ooooooooool03Oooool00omgMgOo<S8booooo`03ooooo`;o0000<?ooool3o`0001[ooooo
00?o0000ooooooooool0>Oooool3o`3ooa_ooooo0ol0I_m;ooooo`03o`000?oooooooooo03Cooooo
00?o0000ooooool000001_ooool00omgMgOo0000ooooo`0Cooooo`0000?oooooo`000?ooool00_oo
ool00ol0003oooooooooo`0:ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooo
ooooo`0/ooooo`?o00007_ooool00ol0003oooooooooo`0eooooo`?o0?oo6oooool3o`1Vodkooooo
00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Iooooo`0000?ooooooa0@4?ooool00_oo
ool00ol@413oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0:_oo
ool2o`0002;ooooo00?o0000ooooooooool0<Oooool3o`3ooacooooo0_l0I_mBooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool06Oooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg
3?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02Oooooo0ol0000Uooooo`;o0000
<?ooool00ol0ooooooooooooo`0Jooooo`?o06KoEOooool00ol0003oooooooooo`0fooooo`03o`00
0?oooooooooo01Sooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPcooooo1?l00005ooooo`;o
00009Oooool3o`0002[ooooo00?o0000ooooooooool0Aoooool3o`1VoeWooooo00?o0000oooooooo
ool0=_ooool00ol0003oooooooooo`0Gooooo`006oooool00ol0003oooooooooo`0Qooooo`?o0000
;_ooool00ol0003oooooooooo`12ooooo`Co06KoGOooool00ol0003oooooooooo`0eooooo`03o`00
0?oooooooooo01Oooooo000Kooooo`03o`000?oooooooooo01kooooo0ol0000booooo`03o`000?oo
oooooooo03kooooo0ol0I_lNooooo`;o<`3o@Oooool00ol0003oooooooooo`0fooooo`03o`000?oo
oooooooo01Kooooo000Kooooo`03o`000?oooooooooo01_ooooo0ol0000fooooo`03o`000?oooooo
oooo03[ooooo0ol0I_lOooooo`;o<`3oA?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooo
oooo01Gooooo000Jooooo`03o`000?oooooooooo01[ooooo0_l0000jooooo`03o`000?oooooooooo
03Gooooo1?l0I_lPooooo`;o<`3oAoooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo
01Cooooo000Jooooo`;o00006?ooool3o`0003gooooo00?o0000ooooooooool0<Oooool3o`1Vob;o
oooo0_lc0?m:ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool05?ooool001[ooooo
00?o0000ooooooooool05?ooool3o`00047ooooo00?o0000ooooooooool0;Oooool3o`1VobCooooo
00?o<`3oooooooooool0B_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo01?ooooo
000Jooooo`03o`000?oooooooooo017ooooo0ol00015ooooo`03o`000?oooooooooo02Wooooo0ol0
I_lUooooo`;o<`3oC_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo01;ooooo000J
ooooo`03o`000?oooooooooo00kooooo0ol00019ooooo`03o`000?oooooooooo04kooooo0_lc0?mA
ooooo`03o`000?oooooooooo03Gooooo0_l0000Cooooo`006_ooool00ol0003oooooooooo`0<oooo
o`;o0000COooool00ol0003oooooooooo`1;ooooo`;o<`3oE?ooool00ol0003oooooooooo`0doooo
o`;o00004oooool001Wooooo0ol0000:ooooo`?o0000D?ooool00ol0003oooooooooo`17ooooo`?o
<`3oEoooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo013ooooo000Jooooo`03o`00
0?oooooooooo00Kooooo0ol0001Dooooo`03o`000?oooooooooo04;ooooo1?lc0?mJooooo`03o`00
0?oooooooooo03Kooooo00?o0000ooooooooool03oooool001Wooooo00?o0000ooooooooool01?oo
ool3o`0005Sooooo00?o0000ooooooooool0?Oooool4oc<0oakooooo0_o<0?loooooo`03o`000?oo
oooooooo03Gooooo00?o0000ooooooooool03oooool001Wooooo00Co0000oooooooooooooooo0ol0
001Looooo`03o`000?oooooooooo03Wooooo0olc0?lQooooo`03ol`0oooooooooooo043ooooo00?o
0000ooooooooool0=Oooool00ol0003oooooooooo`0>ooooo`006Oooool4o`00063ooooo00?o0000
ooooooooool0=?ooool4oc<0ob?ooooo00?oc03oooooooooool0@_ooool00ol0003oooooooooo`0e
ooooo`03o`000?oooooooooo00gooooo000Iooooo`;o0000Hoooool00ol0003oooooooooo`0]oooo
o`Ko<`3o9Oooool2ol`0odKooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0=oooo
o`003oooool4o`000003oa0@4?oooooooooo00Gooooo00?o0000ooooooooool0HOooool00ol0003o
ooooooooo`0Wooooo`Go<`3o:Oooool2ol`0odSooooo00?o0000ooooooooool0=Oooool00ol0003o
ooooooooo`0<ooooo`004Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo067ooooo
00?o0000ooooooooool08oooool3oc<0obgooooo00?oc03oooooooooool0BOooool00ol0003ooooo
ooooo`0eooooo`03o`000?oooooooooo00_ooooo000Aooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool0HOooool00ol0003oooooooooo`1@ooooo`;oc03oCOooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo00[ooooo000Aooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool0HOooool00ol0003oooooooooo`1<ooooo`?oc03oD?ooool00ol0003oooooooooo`0d
ooooo`03o`000?oooooooooo00[ooooo000Aooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool0HOooool00ol0003oooooooooo`19ooooo`;oc03oE?ooool00ol0003oooooooooo`0doooo
o`03o`000?oooooooooo00Wooooo000Aooooo`03o`000?oooooooooo00cooooo0_l0001Rooooo`03
o`000?oooooooooo04Gooooo0oo<0?lIooooo`;oo`2I>oooool00ol0003oooooooooo`0cooooo`?o
00002_ooool0017ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1Pooooo`03o`00
0?oooooooooo04;ooooo0_o<0?lKooooo`03ool0VOoooooooooo03cooooo00?o0000ooooooooool0
;oooool3o`0000;ooooo00?o0000ooooooooool02?ooool000oooooo00?oEEEEofIVI_l000004Ooo
ool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo03oooooo0_o<0?lLooooo`03ool0VOoo
oooooooo03kooooo00?o0000ooooooooool0:oooool3o`0000Gooooo00?o0000ooooooooool02?oo
ool002Cooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0kooooo`?oc03o7Oooool0
0ooo09Woooooooooo`10ooooo`03o`000?oooooooooo02Kooooo1?l00008ooooo`03o`000?oooooo
oooo00Sooooo000Uooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0=_ooool4ol`0
oakooooo0_oo09U4ooooo`03o`000?oooooooooo02;ooooo0ol0000<ooooo`03o`000?oooooooooo
00Sooooo000Vooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0<_ooool3ol`0ob3o
oooo0_oo09U6ooooo`03o`000?oooooooooo01oooooo0ol0000@ooooo`03o`000?oooooooooo00Oo
oooo000Wooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0;?ooool5ol`0ob;ooooo
00?oo`2Iooooooooool0Aoooool00ol0003oooooooooo`0Jooooo`Co00004oooool00ol0003ooooo
ooooo`07ooooo`00:?ooool2o`00067ooooo00?o0000ooooooooool09?ooool7ol`0obGooooo0_oo
09U;ooooo`03o`000?oooooooooo01Kooooo0ol0000Gooooo`03o`000?oooooooooo00Oooooo000Z
ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool06_ooool9ol`0obWooooo0ooo09TC
ooooo`;oo`00>Oooool00ol0003oooooooooo`0Booooo`?o00006_ooool00ol0003oooooooooo`07
ooooo`00:oooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo04Wooooo0_oo09TEoooo
o`03ool00?oooooooooo03[ooooo00?o0000ooooooooool03Oooool4o`0001gooooo00?o0000oooo
ooooool01oooool002cooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`16ooooo`;o
o`2I5_ooool00ooo003oooooooooo`0kooooo`03o`000?oooooooooo00[ooooo0ol0000Qooooo`03
o`000?oooooooooo00Oooooo000]ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool0
@_ooool3ool0VAOooooo00?oo`00ooooooooool0?Oooool00ol0003oooooooooo`06ooooo`?o0000
9?ooool00ol0003oooooooooo`07ooooo`00;_ooool00ol0003oooooooooo`1Oooooo`03o`000?oo
oooooooo03oooooo0_oo09THooooo`;oo`00@Oooool01?l0003oooooooooooooool4o`0002Oooooo
00?o0000ooooooooool01oooool002oooooo0_l0001Pooooo`03o`000?oooooooooo03cooooo0_oo
09THooooo`;oo`00A?ooool3o`0002cooooo00?o0000ooooooooool01_ooool0037ooooo00?o0000
ooooooooool0G_ooool2o`0003Wooooo0ooo09TIooooo`03ool00?oooooooooo047ooooo0ol00000
0ooooooo0000ooooo`0/ooooo`03o`000?oooooooooo00Kooooo000booooo`03o`000?oooooooooo
05oooooo00?o0000ooooooooool0<oooool3ool0VA[ooooo0_oo0011ooooo`?o00001?ooool00ol0
003oooooooooo`0[ooooo`03o`000?oooooooooo00Kooooo000cooooo`03o`000?oooooooooo05oo
oooo00?o0000ooooooooool0;oooool3ool0VA_ooooo0_oo000oooooo`Co00002?ooool00ol0003o
ooooooooo`0Zooooo`03o`000?oooooooooo00Kooooo000dooooo`03o`000?oooooooooo05oooooo
00?o0000ooooooooool0:_ooool4ool0VA_ooooo0ooo000nooooo`?o00003Oooool00ol0003ooooo
ooooo`0Yooooo`03o`000?oooooooooo00Kooooo000eooooo`03o`000?oooooooooo05oooooo00?o
0000ooooooooool08oooool6ool0VAgooooo0_oo000nooooo`?o00004Oooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo00Kooooo000fooooo`03o`000?oooooooooo05oooooo00?o0000
ooooooooool06_ooool8ool0VB7ooooo0_oo000looooo`Co00005Oooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo00Kooooo000gooooo`;o0000H?ooool00ol0003oooooooooo`0>oooo
o`_oo`2I9oooool2ool003_ooooo0ol0000Iooooo`03o`000?oooooooooo02Oooooo00?o0000oooo
ooooool01_ooool003Wooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0looooo`?o
o`00>_ooool3o`0001gooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`05ooooo`00
>_ooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo03Wooooo0_oo000iooooo`Co0000
8Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Gooooo000kooooo`03o`000?oo
oooooooo05kooooo00?o0000ooooooooool0=Oooool3ool003Sooooo0ol0000Vooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool01Oooool003cooooo00?o0000ooooooooool0G_ooool0
0ol0003oooooooooo`0_ooooo`Goo`00>?ooool3o`0002Wooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`05ooooo`00?Oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo
02_ooooo0ooo000iooooo`Co0000;Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
00Gooooo000nooooo`;o0000Goooool00ol0003oooooooooo`0Wooooo`?oo`00>Oooool3o`0003;o
oooo00?o0000ooooooooool08oooool00ol0003oooooooooo`05ooooo`00@?ooool00ol0003ooooo
ooooo`1Mooooo`03o`000?oooooooooo02?ooooo0ooo000iooooo`?o0000=_ooool00ol0003ooooo
ooooo`0Rooooo`03o`000?oooooooooo00Gooooo0011ooooo`03o`000?oooooooooo05gooooo00?o
0000ooooooooool07?ooool6ool003Sooooo1?l0000jooooo`03o`000?oooooooooo027ooooo00?o
0000ooooooooool01Oooool004;ooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`0B
ooooo`Woo`00>oooool3o`0003kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`05
ooooo`00@oooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo00Cooooo3Ooo0011oooo
o`?o0000@_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Cooooo0014ooooo`03
o`000?oooooooooo05gooooo00?o0000ooooooooool0COooool4o`0004Kooooo00?o0000oooooooo
ool08?ooool00ol0003oooooooooo`04ooooo`00AOooool00ol0003oooooooooo`1Mooooo`03o`00
0?oooooooooo04Wooooo0ol0001;ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0
1?ooool004Kooooo0_l0001Nooooo`03o`000?oooooooooo04Gooooo0ol0001?ooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool01?ooool004Sooooo00?o0000ooooooooool0G?ooool0
0ol0003oooooooooo`10ooooo`Co0000D_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo00Cooooo0019ooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool0??ooool3o`00
05Oooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`04ooooo`00B_ooool00ol0003o
ooooooooo`1Looooo`03o`000?oooooooooo03Sooooo0ol0001Kooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool01?ooool004_ooooo00?o0000ooooooooool0G?ooool00ol0003ooooo
ooooo`0cooooo`Co0000Goooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo
001<ooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool0;oooool3o`0006Cooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`03ooooo`00COooool2o`0005gooooo00?o0000
ooooooooool0:oooool3o`0006Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`03
ooooo`00Coooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo02Oooooo0ol0001[oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool00oooool0053ooooo00?o0000oooooooo
ool0Foooool00ol0003oooooooooo`0Rooooo`Co0000Koooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo00?ooooo001Aooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool0
7_ooool3o`0007Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`03ooooo`00D_oo
ool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo01[ooooo0ol0001hooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool00oooool005?ooooo00?o0000ooooooooool0Foooool0
0ol0003oooooooooo`0Eooooo`Co0000Noooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo00?ooooo001Dooooo`;o0000G?ooool00ol0003oooooooooo`0Aooooo`?o0000P?ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo00?ooooo001Fooooo`03o`000?oooooooooo05[o
oooo00?o0000ooooooooool03Oooool3o`0008Cooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`02ooooo`00Eoooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00Sooooo
1?l00028ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool00_ooool005Sooooo00?o
0000ooooooooool0F_ooool00ol0003oooooooooo`04ooooo`?o0000SOooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo00;ooooo001Iooooo`03o`000?oooooooooo05[ooooo00?o0000
ooooooooool00ol0002@ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00_ooool0
05[ooooo00?o0000ooooooooool0F_ooool2o`0009Cooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`02ooooo`00Foooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo09Co
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`02ooooo`00G?ooool2o`0005Wooooo
00?o0000ooooooooool0UOooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo
001Nooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool0U_ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo00;ooooo001Oooooo`03o`000?oooooooooo05Gooooo00?o0000
ooooooooool0U_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo007ooooo001Poooo
o`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0Uoooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo007ooooo001Qooooo`03o`000?oooooooooo05?ooooo00?o0000oooooooo
ool0V?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo007ooooo001Rooooo`03o`00
0?oooooooooo05;ooooo00?o0000ooooooooool0VOooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo007ooooo001Sooooo`;o0000D_ooool00ol0003oooooooooo`2Jooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool00Oooool006Gooooo00?o0000ooooooooool0Coooool0
0ol0003oooooooooo`2Jooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00Oooool0
06Kooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`2Kooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool00Oooool006Oooooo00?o0000ooooooooool0COooool00ol0003o
ooooooooo`2Looooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00Oooool006Sooooo
00?o0000ooooooooool0C?ooool00ol0003oooooooooo`2Mooooo`03o`000?oooooooooo00_ooooo
0Ol00001ooooo`7ooooo001Yooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0WOoo
ool00ol0003oooooooooo`0;ooooo`7o00000Oooool1ooooo`00J_ooool00ol0003oooooooooo`1:
ooooo`03o`000?oooooooooo09kooooo00?o0000ooooooooool02_ooool1o`00007ooooo0Oooool0
06_ooooo0_l0001:ooooo`03o`000?oooooooooo09oooooo00?o0000ooooooooool02Oooool1o`00
007ooooo0Oooool006gooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`2Pooooo`03
o`000?oooooooooo00Sooooo0Ol00001ooooo`7ooooo001^ooooo`03o`000?oooooooooo04Kooooo
00?o0000ooooooooool0XOooool00ol0003oooooooooo`07ooooo`7o00000Oooool1ooooo`00Kooo
ool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo0:7ooooo00?o0000ooooooooool01ooo
ool1o`00007ooooo0Oooool0073ooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`2R
ooooo`03o`000?oooooooooo00Kooooo0Ol00001ooooo`7ooooo001aooooo`03o`000?oooooooooo
04?ooooo00?o0000ooooooooool0Xoooool00ol0003oooooooooo`05ooooo`7o00000Oooool1oooo
o`00L_ooool2o`0004;ooooo00?o0000ooooooooool0YOooool00ol0003oooooooooo`05ooooo`7o
00000Oooool007Cooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`2Vooooo`03o`00
0?oooooooooo00Cooooo0Ol00001ooooo`00MOooool00ol0003oooooooooo`0nooooo`03o`000?oo
oooooooo0:Kooooo00?o0000ooooooooool01?ooool1o`00007ooooo001fooooo`03o`000?oooooo
oooo03gooooo00?o0000ooooooooool0Yoooool00ol0003oooooooooo`03ooooo`7o00000Oooool0
07Oooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`2Xooooo`03o`000?oooooooooo
00;ooooo0Ol00001ooooo`00N?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0:Wo
oooo00Go0000ooooooooooooooooo`000001ooooo`00NOooool00ol0003oooooooooo`0jooooo`03
o`000?oooooooooo0:[ooooo00Co0000oooooooooooo00000Oooool007[ooooo0_l0000jooooo`03
o`000?oooooooooo0:[ooooo00Co0000oooooooooooo00000Oooool007cooooo00?o0000oooooooo
ool0=oooool00ol0003oooooooooo`2[ooooo`03o`000?oooooooooo007o0000001mooooo`03o`00
0?oooooooooo03Kooooo00?o0000ooooooooool0[?ooool1o`00007ooooo0Ol0000007kooooo00?o
0000ooooooooool0=Oooool00ol0003oooooooooo`2]ooooo`;o0000001oooooo`03o`000?oooooo
oooo03Cooooo00?o0000ooooooooool0[?ooool3o`000000P?ooool00ol0003oooooooooo`0coooo
o`03o`000?oooooooooo0:Sooooo1?l00003ooooo`00POooool2o`0003?ooooo00?o0000oooooooo
ool0YOooool3o`0000Oooooo0023ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
XOooool4o`0000[ooooo0024ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0WOoo
ool4o`0000kooooo0025ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0VOooool4
o`0001;ooooo0026ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0UOooool4o`00
01Kooooo0027ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0T_ooool3o`0001[o
oooo0028ooooo`;o0000;?ooool00ol0003oooooooooo`2>ooooo`Co00007Oooool008[ooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`2:ooooo`Co00008Oooool008_ooooo00?o0000
ooooooooool0:?ooool00ol0003oooooooooo`26ooooo`Co00009Oooool008cooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`22ooooo`Co0000:Oooool008gooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`1oooooo`?o0000;Oooool008kooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`1kooooo`Co0000<?ooool008oooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`1gooooo`Co0000=?ooool0093ooooo0_l0000Tooooo`03o`000?oooooo
oooo07?ooooo1?l0000hooooo`00T_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
073ooooo0ol0000looooo`00Toooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo06co
oooo1?l0000oooooo`00U?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo06Sooooo
1?l00013ooooo`00UOooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo06Cooooo1?l0
0017ooooo`00U_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo063ooooo1?l0001;
ooooo`00Uoooool2o`0001gooooo00?o0000ooooooooool0GOooool3o`0004oooooo002Iooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool0FOooool4o`0005;ooooo002Jooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool0EOooool4o`0005Kooooo002Kooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool0DOooool4o`0005[ooooo002Looooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool0COooool4o`0005kooooo002Mooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool0B_ooool3o`0006;ooooo002Nooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool0A_ooool4o`0006Gooooo002Oooooo`;o00005?ooool00ol0003ooooo
ooooo`13ooooo`Co0000JOooool00:7ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0oooooo`Co0000KOooool00:;ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0k
ooooo`Co0000LOooool00:?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0hoooo
o`?o0000MOooool00:Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0dooooo`Co
0000N?ooool00:Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0`ooooo`Co0000
O?ooool00:Kooooo0_l0000=ooooo`03o`000?oooooooooo02cooooo1?l00020ooooo`00Z?ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Wooooo0ol00024ooooo`00ZOooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo02Gooooo1?l00027ooooo`00Z_ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo027ooooo1?l0002;ooooo`00Zoooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo01gooooo1?l0002?ooooo`00[?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo01Wooooo1?l0002Cooooo`00[Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo01Kooooo0ol0002Gooooo`00[_ooool2o`0000Gooooo00?o0000oooo
ooooool04_ooool4o`0009[ooooo002`ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool03_ooool4o`0009kooooo002aooooo`05o`000?ooooooooooooooool000003?ooool4o`000:;o
oooo002booooo`04o`000?ooooooooooo`0000Sooooo1?l0002Vooooo`00/oooool00ol0003ooooo
o`000005ooooo`?o0000Z_ooool00;Cooooo0_l000000ooooooo0000o`000002o`000:gooooo002e
ooooo`;o0000/Oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {319.688, 0}} -> {-0.0710364, -0.0181728, \
0.0035149, 0.0035149}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .89104 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-16 1.0656 -0.0363427 1.0656 [
[.02544 .21571 -12 -8.9133 ]
[.02544 .21571 0 .0867 ]
[.16074 .16277 -11.6592 -9 ]
[.16074 .16277 .34081 0 ]
[.3021 .10747 -5.60025 -9 ]
[.3021 .10747 .39975 0 ]
[.44992 .04965 -5.37091 -9 ]
[.44992 .04965 .62909 0 ]
[.60467 -0.01084 -5.14157 -9 ]
[.60467 -0.01084 .85843 0 ]
[.66454 .05085 0 -6.20675 ]
[.66454 .05085 6 2.79325 ]
[.80797 .25198 0 -6.0417 ]
[.80797 .25198 6 2.9583 ]
[.93071 .4241 0 -5.90576 ]
[.93071 .4241 6 3.09424 ]
[.02254 .22988 -12 -2.74631 ]
[.02254 .22988 0 6.25369 ]
[.0142 .29178 -24 -2.78907 ]
[.0142 .29178 0 6.21093 ]
[.00558 .35578 -6 -2.83339 ]
[.00558 .35578 0 6.16661 ]
[-0.00334 .42198 -18 -2.87938 ]
[-0.00334 .42198 0 6.12062 ]
[-0.01257 .49051 -6 -2.92712 ]
[-0.01257 .49051 0 6.07288 ]
[ 0 0 0 0 ]
[ 1 .89104 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03495 .22504 m
.61241 0 L
s
.03495 .22504 m
.03971 .2297 L
s
[(-2)] .02544 .21571 1 .98073 Mshowa
.16988 .17246 m
.17445 .1773 L
s
[(-1)] .16074 .16277 .9432 1 Mshowa
.31082 .11753 m
.31518 .12256 L
s
[(0)] .3021 .10747 .86675 1 Mshowa
.45818 .0601 m
.46231 .06533 L
s
[(1)] .44992 .04965 .7903 1 Mshowa
.61241 0 m
.61628 .00542 L
s
[(2)] .60467 -0.01084 .71386 1 Mshowa
.125 Mabswid
.06148 .2147 m
.06431 .21752 L
s
.08823 .20428 m
.09104 .20712 L
s
.11521 .19376 m
.118 .19663 L
s
.14243 .18316 m
.14519 .18604 L
s
.19758 .16166 m
.20029 .16459 L
s
.22551 .15078 m
.22821 .15373 L
s
.2537 .13979 m
.25637 .14277 L
s
.28213 .12871 m
.28478 .13171 L
s
.33977 .10625 m
.34236 .10929 L
s
.36897 .09487 m
.37153 .09794 L
s
.39844 .08339 m
.40097 .08648 L
s
.42817 .0718 m
.43068 .07491 L
s
.48846 .0483 m
.49091 .05146 L
s
.51902 .03639 m
.52144 .03958 L
s
.54986 .02437 m
.55225 .02758 L
s
.58099 .01224 m
.58335 .01547 L
s
.25 Mabswid
.61241 0 m
.97291 .505 L
s
.65208 .05558 m
.64586 .05794 L
s
[(0)] .66454 .05085 -1 .37928 Mshowa
.79537 .2563 m
.78907 .25846 L
s
[(2)] .80797 .25198 -1 .3426 Mshowa
.91799 .42808 m
.91164 .43006 L
s
[(4)] .93071 .4241 -1 .31239 Mshowa
.125 Mabswid
.69012 .10886 m
.68637 .11025 L
s
.72662 .16 m
.72286 .16135 L
s
.76168 .2091 m
.75791 .21042 L
s
.82778 .3017 m
.82399 .30297 L
s
.85897 .3454 m
.85518 .34664 L
s
.88903 .3875 m
.88522 .38871 L
s
.94594 .46722 m
.94211 .46839 L
s
.25 Mabswid
.03495 .22504 m
0 .48612 L
s
.03495 .22504 m
.04116 .22262 L
s
[(-1)] .02254 .22988 1 -0.38971 Mshowa
.02665 .28704 m
.03288 .28468 L
s
[(-0.5)] .0142 .29178 1 -0.38021 Mshowa
.01807 .35115 m
.02431 .34884 L
s
[(0)] .00558 .35578 1 -0.37036 Mshowa
.00919 .41747 m
.01546 .41521 L
s
[(0.5)] -0.00334 .42198 1 -0.36014 Mshowa
0 .48612 m
.00629 .48392 L
s
[(1)] -0.01257 .49051 1 -0.34953 Mshowa
.125 Mabswid
.03331 .23728 m
.03704 .23583 L
s
.03166 .2496 m
.03539 .24816 L
s
.03 .262 m
.03373 .26056 L
s
.02833 .27448 m
.03207 .27305 L
s
.02496 .29969 m
.0287 .29828 L
s
.02325 .31243 m
.02699 .31102 L
s
.02154 .32525 m
.02528 .32385 L
s
.01981 .33816 m
.02355 .33676 L
s
.01632 .36423 m
.02007 .36285 L
s
.01455 .37741 m
.01831 .37603 L
s
.01278 .39067 m
.01653 .3893 L
s
.01099 .40402 m
.01475 .40266 L
s
.00738 .43101 m
.01114 .42966 L
s
.00555 .44464 m
.00932 .4433 L
s
.00371 .45837 m
.00748 .45704 L
s
.00186 .4722 m
.00563 .47087 L
s
.25 Mabswid
.03495 .22504 m
0 .48612 L
s
0 .48612 m
.46953 .89104 L
s
.46953 .89104 m
.47294 .65459 L
s
.47294 .65459 m
.03495 .22504 L
s
.61241 0 m
.97291 .505 L
s
.97291 .505 m
1 .75117 L
s
1 .75117 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.03495 .22504 m
0 .48612 L
s
0 .48612 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.61241 0 m
.03495 .22504 L
s
.47294 .65459 m
.97291 .505 L
s
.97291 .505 m
1 .75117 L
s
1 .75117 m
.46953 .89104 L
s
.46953 .89104 m
.47294 .65459 L
s
0 0 m
1 0 L
1 .89104 L
0 .89104 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.43744 .61998 m
.46583 .61819 L
s
.46583 .61819 m
.4961 .61451 L
s
1 0 .6 r
.43627 .59637 m
.4628 .59498 L
s
1 0 0 r
.4961 .61451 m
.52712 .60892 L
s
1 0 .6 r
.4628 .59498 m
.49137 .59172 L
s
.49137 .59172 m
.52082 .58652 L
s
1 0 0 r
.52712 .60892 m
.558 .6015 L
s
.8 0 1 r
.43537 .57013 m
.45954 .56922 L
s
.45954 .56922 m
.48589 .56654 L
s
1 0 .6 r
.52082 .58652 m
.5502 .57947 L
s
.8 0 1 r
.48589 .56654 m
.51333 .56193 L
s
1 0 0 r
.558 .6015 m
.58801 .5924 L
s
.8 0 1 r
.51333 .56193 m
.54081 .55541 L
s
1 0 .6 r
.5502 .57947 m
.57873 .57071 L
s
.2 0 1 r
.43459 .5394 m
.45574 .53867 L
s
.45574 .53867 m
.47894 .53649 L
s
.47894 .53649 m
.50333 .53257 L
s
.8 0 1 r
.54081 .55541 m
.56743 .54713 L
s
1 0 0 r
.58801 .5924 m
.61654 .58177 L
s
.2 0 1 r
.50333 .53257 m
.52789 .5268 L
s
1 0 .6 r
.57873 .57071 m
.6057 .56044 L
s
.8 0 1 r
.56743 .54713 m
.59238 .53732 L
s
.2 0 1 r
.52789 .5268 m
.55163 .5193 L
s
0 .4 1 r
.43183 .50393 m
.44992 .5025 L
s
1 0 0 r
.61654 .58177 m
.6429 .56986 L
s
0 .4 1 r
.44992 .5025 m
.46927 .50013 L
s
1 0 .6 r
.6057 .56044 m
.6304 .54892 L
s
0 .4 1 r
.46927 .50013 m
.48943 .49653 L
s
.2 0 1 r
.55163 .5193 m
.57365 .51034 L
s
.8 0 1 r
.59238 .53732 m
.61487 .52632 L
s
0 .4 1 r
.48943 .49653 m
.50973 .49154 L
s
.50973 .49154 m
.52939 .48521 L
s
1 0 0 r
.6429 .56986 m
.66635 .55703 L
s
.2 0 1 r
.57365 .51034 m
.59319 .50031 L
s
1 0 .6 r
.6304 .54892 m
.65203 .53657 L
s
0 1 1 r
.42391 .46833 m
.43983 .46555 L
s
.8 0 1 r
.61487 .52632 m
.63417 .51461 L
s
0 1 1 r
.43983 .46555 m
.45615 .46231 L
s
0 .4 1 r
.52939 .48521 m
.5477 .47775 L
s
0 1 1 r
.45615 .46231 m
.4727 .45845 L
s
.2 0 1 r
.59319 .50031 m
.6097 .48979 L
s
0 1 1 r
.4727 .45845 m
.4892 .45387 L
s
1 0 0 r
.66635 .55703 m
.68612 .54388 L
s
0 .4 1 r
.5477 .47775 m
.56415 .46952 L
s
0 1 .4 r
.41304 .43797 m
.42773 .43408 L
s
1 0 .6 r
.65203 .53657 m
.66992 .52401 L
s
.8 0 1 r
.63417 .51461 m
.64976 .50287 L
s
0 1 1 r
.4892 .45387 m
.50533 .44857 L
s
0 1 .4 r
.42773 .43408 m
.4425 .43002 L
s
.2 1 0 r
.40296 .41248 m
.41708 .40807 L
s
.2 0 1 r
.6097 .48979 m
.62306 .47939 L
s
0 1 .4 r
.4425 .43002 m
.45729 .42571 L
s
0 .4 1 r
.56415 .46952 m
.57852 .46093 L
s
.8 1 0 r
.39409 .38947 m
.408 .38483 L
s
0 1 1 r
.50533 .44857 m
.52079 .44264 L
s
.2 1 0 r
.41708 .40807 m
.43126 .40358 L
s
1 .6 0 r
.38589 .3675 m
.39972 .36274 L
s
0 1 .4 r
.45729 .42571 m
.47203 .42111 L
s
.8 1 0 r
.408 .38483 m
.42196 .38014 L
s
.2 1 0 r
.43126 .40358 m
.44546 .39899 L
s
0 1 1 r
.52079 .44264 m
.5354 .43624 L
s
1 .6 0 r
.39972 .36274 m
.4136 .35796 L
s
0 .4 1 r
.57852 .46093 m
.59094 .45239 L
s
0 1 .4 r
.47203 .42111 m
.48664 .41623 L
s
.8 1 0 r
.42196 .38014 m
.43596 .37542 L
s
.2 1 0 r
.44546 .39899 m
.45966 .39429 L
s
1 .6 0 r
.4136 .35796 m
.42754 .35315 L
s
0 1 1 r
.5354 .43624 m
.54913 .42956 L
s
0 1 .4 r
.48664 .41623 m
.50103 .41108 L
s
.8 1 0 r
.43596 .37542 m
.45 .37064 L
s
.2 1 0 r
.45966 .39429 m
.47385 .38948 L
s
1 .6 0 r
.42754 .35315 m
.44153 .34831 L
s
0 1 .4 r
.50103 .41108 m
.51519 .4057 L
s
.8 1 0 r
.45 .37064 m
.46408 .36581 L
s
0 1 1 r
.54913 .42956 m
.56209 .42277 L
s
.2 1 0 r
.47385 .38948 m
.48801 .38456 L
s
1 .6 0 r
.44153 .34831 m
.45556 .34344 L
s
.8 1 0 r
.46408 .36581 m
.47818 .36093 L
s
0 1 .4 r
.51519 .4057 m
.52911 .40015 L
s
.2 1 0 r
.48801 .38456 m
.50213 .37954 L
s
1 .6 0 r
.45556 .34344 m
.46965 .33854 L
s
.8 1 0 r
.47818 .36093 m
.49232 .35599 L
s
0 1 .4 r
.52911 .40015 m
.54283 .3945 L
s
.2 1 0 r
.50213 .37954 m
.51623 .37444 L
s
1 .6 0 r
.46965 .33854 m
.48379 .3336 L
s
.8 1 0 r
.49232 .35599 m
.50649 .35102 L
s
.2 1 0 r
.51623 .37444 m
.5303 .36928 L
s
1 .6 0 r
.48379 .3336 m
.49798 .32864 L
s
.8 1 0 r
.50649 .35102 m
.52069 .34601 L
s
1 .6 0 r
.49798 .32864 m
.51222 .32365 L
s
0 g
.25 Mabswid
.61241 0 m
.97291 .505 L
s
.97291 .505 m
1 .75117 L
s
1 .75117 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.03495 .22504 m
0 .48612 L
s
0 .48612 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.61241 0 m
.03495 .22504 L
s
.03495 .22504 m
.61241 0 L
s
.03495 .22504 m
.03971 .2297 L
s
[(-2)] .02544 .21571 1 .98073 Mshowa
.16988 .17246 m
.17445 .1773 L
s
[(-1)] .16074 .16277 .9432 1 Mshowa
.31082 .11753 m
.31518 .12256 L
s
[(0)] .3021 .10747 .86675 1 Mshowa
.45818 .0601 m
.46231 .06533 L
s
[(1)] .44992 .04965 .7903 1 Mshowa
.61241 0 m
.61628 .00542 L
s
[(2)] .60467 -0.01084 .71386 1 Mshowa
.125 Mabswid
.06148 .2147 m
.06431 .21752 L
s
.08823 .20428 m
.09104 .20712 L
s
.11521 .19376 m
.118 .19663 L
s
.14243 .18316 m
.14519 .18604 L
s
.19758 .16166 m
.20029 .16459 L
s
.22551 .15078 m
.22821 .15373 L
s
.2537 .13979 m
.25637 .14277 L
s
.28213 .12871 m
.28478 .13171 L
s
.33977 .10625 m
.34236 .10929 L
s
.36897 .09487 m
.37153 .09794 L
s
.39844 .08339 m
.40097 .08648 L
s
.42817 .0718 m
.43068 .07491 L
s
.48846 .0483 m
.49091 .05146 L
s
.51902 .03639 m
.52144 .03958 L
s
.54986 .02437 m
.55225 .02758 L
s
.58099 .01224 m
.58335 .01547 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 256.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001@2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00gOooool5o`0008Kooooo003Mooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0Q_ooool00=ko
oooo00?oV9RHob4Q8Oo^k^h0Qoooool00=oooooo00?oV9RHob4Q8Oo^k^h0Q_ooool00>3ooooo00?o
MgMgofIVI_ooool0QOooool00>7ooooo00?o0000ooooooooool0Q?ooool00=gooooo00Go0000okZj
^_ooooooV9RHoa0@4026ooooo`00gOooool01OnHV9So410@o`000?lQ8B7oc<c<08Kooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003Tooooo`;o0000P_ooool0
0>7ooooo0ol000000ooooooo0000ooooo`21ooooo`00goooool2o`0000Cooooo0_l00021ooooo`00
g?ooool3o`0000Kooooo00?o0000ooooool00000P?ooool00=[ooooo0_l00009ooooo`03o`000?oo
oooo0000083ooooo003Gooooo`?o000000?oooooo`000?ooool02?ooool01?l0003oooooooooool0
001oooooo`00e?ooool3o`0000Cooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooo
oooo000007kooooo003Booooo`;o00004Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo07_ooooo002Zooooo`Co000000?o410@ooooooooool07_ooool3o`0001?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1kooooo`00[?ooool00ol0003oooooooooo`0Nooooo`;o
000000?oooooo`000?ooool04oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07[o
oooo002/ooooo`03o`000?oooooooooo01_ooooo0ol00004ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`1iooooo`00[?ooool00ol0003ooooooooo
o`0Iooooo`;o00006oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo07Wooooo002/
ooooo`03o`000?oooooooooo01Kooooo0ol0000Mooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool02?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^06_ooooo002/ooooo`03o`000?oooooo
oooo01Cooooo0_l000000ooooooo0000ooooo`0Mooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01oooool01OmgMgOoV9RHoooooonHV9SoMgMg06_ooooo002/ooooo`03o`000?oooooo
oooo017ooooo0ol00004ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`06ooooo`05oa0@4?ooooooooooooooool@4100Joooool00:[ooooo00?oEEEE
ofIVI_l000004Oooool2o`0002Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06
ooooo`05o`000?ooooooooooooooool00000Joooool00;_ooooo0ol0000Wooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000006_ooooo002i
ooooo`;o000000?oooooo`000?ooool09oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Cooooo00Go410@oooooooooooooooooa0@401[ooooo`00]_ooool3o`0000Cooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`1[ooooo`00/oooool3o`0002oooooo00?o0000ooooooooool02Oooool2
o`0000Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1[ooooo`00/Oooool2o`0003;ooooo00?o0000
ooooooooool02?ooool01?l0003oooooooooool0001dooooo`00[_ooool3o`000003ooooool0003o
oooo037ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1aooooo`00[?ooool2o`00
00Gooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
077ooooo002Yooooo`?o0000>_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo073o
oooo002Wooooo`;o0000?Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo06oooooo
002Tooooo`?o000000?oooooo`000?ooool0??ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo06oooooo002Rooooo`;o0000@_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo06kooooo001gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08oooool3o`0004Cooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1]ooooo`00Moooool01OmgMgOoV9RHoooooonHV9So
MgMg027ooooo0_l00017ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0K?ooool0
07Oooooo00Go410@oooooooooooooooooa0@400Nooooo`?o00000_ooool00ol0003oooooooooo`14
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0K?ooool007Oooooo00Go0000oooo
ooooooooooooo`00000Looooo`;o0000C?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo06_ooooo001gooooo`05o`000?ooooooooooooooool000006Oooool3o`0004kooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`1Zooooo`00Moooool01Ol@413ooooooooooooooooo
410@01Kooooo0ol0001Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0J_ooool0
07Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Dooooo`;o00000oooool00ol0003oooooooooo`1>
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0JOooool007Oooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Aooooo`?o0000E_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo06Sooooo002;ooooo`;o0000FOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
06Sooooo0028ooooo`?o0000Foooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo06Oo
oooo0026ooooo`;o00000oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo01Gooooo
0_l0001Xooooo`00Poooool3o`00063ooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`1Uooooo`00POooool2o`0006?ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1U
ooooo`00O_ooool4o`0006Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`1Toooo
o`00O?ooool2o`0000Cooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo06?ooooo001iooooo`?o0000J_ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo06?ooooo001gooooo`;o0000KOooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo06;ooooo001dooooo`?o000000?oooooo`000?ooool0K?ooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo067ooooo001aooooo`?o0000L_ooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo063ooooo0019ooooo`Co000000?o410@ooooooooool07oooool2o`0007Go
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1Pooooo`00Boooool00ol0003ooooo
ooooo`0Nooooo`?o0000Moooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo05oooooo
0010ooooo`Ko00001Oooool00ol0003oooooooooo`0Looooo`;o00000_ooool00ol0003ooooooooo
o`1eooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0G_ooool004_ooooo00?o0000
ooooooooool06Oooool3o`0007cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1N
ooooo`00Boooool00ol0003oooooooooo`0Gooooo`;o0000Ooooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo05gooooo001;ooooo`03o`000?oooooooooo01Cooooo0ol00021ooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0G?ooool004_ooooo00?o0000ooooooooool0
4_ooool2o`0000?ooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo05_ooooo0019ooooo`03oeEEEOmVIVKo0000017ooooo0ol00026ooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool0Foooool005_ooooo0_l00029ooooo`03o`000?oooooo
oooo027ooooo0_l0001Looooo`00F?ooool3o`000003ooooool0003ooooo08Sooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`1Iooooo`00E_ooool2o`0008kooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`1Iooooo`00Doooool3o`00093ooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`1Hooooo`00D?ooool3o`0009?ooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1Gooooo`00C_ooool2o`0000;ooooo00?o0000ooooooooool0TOooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo05Kooooo001;ooooo`?o00001Oooool00ol0
003oooooooooo`2@ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0E_ooool004Wo
oooo0_l0002Kooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0EOooool004Kooooo
1?l0002Looooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0E?ooool004Cooooo0_l0
002Pooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0E?ooool001[ooooo1Ol0000R
ooooo`?o0000X_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo05?ooooo000Joooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@08?ooool2o`000:Gooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`1Booooo`004_ooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h07_ooool3o`00
0003ooooool0003ooooo0:Cooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`1Aoooo
o`007?ooool00onHV9So8B4Qonk^kP0Kooooo`;o0000Z_ooool00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo057ooooo000Mooooo`03ogMgMomVIVKooooo01Oooooo0ol0002]ooooo`03o`00
0?oooooooooo02_ooooo00?o0000ooooooooool0D?ooool001kooooo00?o0000ooooooooool05?oo
ool2o`000;3ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`1?ooooo`006_ooool0
1Ol0003o^[ZjoooooonHV9So410@01?ooooo0ol00002ooooo`03o`000?oooooooooo0:gooooo00?o
0000ooooooooool0;?ooool2o`00053ooooo000Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`04?oo
ool3o`000;Gooooo00?o0000ooooooooool0;?ooool2o`00053ooooo000]ooooo`;o0000^?ooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo04gooooo000Zooooo`?o000000?oooooo`00
0?ooool0]oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo04gooooo000Xooooo`;o
0000_Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo04cooooo000Uooooo`?o0000
_oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo04_ooooo000Tooooo`;o0000`Ooo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo04[ooooo000Jooooo`Co000000?o410@
ooooooooool00oooool00ol0003oooooo`000030ooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool0B_ooool001cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0002o
ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0BOooool0017ooooo1_l00005oooo
o`03o`000?oooooooooo00Gooooo0_l00002ooooo`03o`000?oooooooooo0;cooooo00?o0000oooo
ooooool0<oooool00ol0003oooooooooo`18ooooo`007?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0^oooool00ol0003oooooooooo`0cooooo`03
o`000?oooooooooo00Oooooo1Ol0000looooo`007?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo00Kooooo00GoV9RHob4Q8Oo^k^koooooodA4A00looooo`007?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00ol0003ooooo
ooooo`0eooooo`03o`000?oooooooooo00Kooooo00?oV9RHob4Q8Oo^k^h0?Oooool001cooooo00?o
0000ooooooooool01?ooool3o`0000Kooooo00?o0000ooooooooool0^?ooool00ol0003ooooooooo
o`0fooooo`03o`000?oooooooooo00Kooooo00?oV9RHob4Q8Oo^k^h0??ooool001[ooooo00?oEEEE
ofIVI_l000001_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;Oooooo00?o0000
ooooooooool0=_ooool00ol0003oooooooooo`07ooooo`03ogMgMomVIVKooooo03_ooooo000Soooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0]_ooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0>_ooool002?ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`2eooooo`03o`000?oooooooooo03Oooooo0_l00004ooooo`05
o`000?nj^[[ooooooiRHV?l@4100??ooool002?ooooo0_l0000;ooooo`03o`000?oooooooooo0;Co
oooo00?o0000ooooooooool0=_ooool00ol0003oooooo`000004ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`0??ooool002?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`2cooooo`03
o`000?oooooooooo03Wooooo00?o0000ooooooooool0@_ooool002;ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0
@Oooool002;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`2`ooooo`;o0000?Ooo
ool00ol0003oooooooooo`10ooooo`008_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo0:cooooo0ol000000ooooooo0000ooooo`0looooo`03o`000?oooooooooo043ooooo000Roooo
o`;o00004Oooool00ol0003oooooooooo`2Xooooo`?o00001Oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo03oooooo000Rooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool0Y?ooool3o`0000Wooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0nooooo`00
8_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo0:3ooooo0ol0000=ooooo`03o`00
0?oooooooooo03[ooooo00?o0000ooooooooool0?_ooool002;ooooo0ol0000Cooooo`03o`000?oo
oooooooo09cooooo0ol0000Aooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0?Ooo
ool002;ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`2Iooooo`;o00005?ooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo03cooooo000Qooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool0UOooool3o`0001Oooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`0kooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo097ooooo0ol0000Kooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0>oooool0
00Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0SOooool3o`0001oooooo00?o0000
ooooooooool0>_ooool00ol0003oooooooooo`0jooooo`001Ol00002ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`02ooooo`;o00006_ooool00ol0003oooooooooo`29
ooooo`?o00008oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03Wooooo0007oooo
o`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool0Q_ooool2o`0002Kooooo00?o0000ooooooooool0>_ooool2
o`0003[ooooo0007ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`22ooooo`?o0000:Ooo
ool00ol0003oooooooooo`0iooooo`;o0000>_ooool000Oooooo00Go410@oooooooooooooooooa0@
400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`1nooooo`?o0000;Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03Oooooo0007
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`;o00007_oo
ool00ol0003oooooooooo`1jooooo`?o0000<Oooool00ol0003oooooooooo`0iooooo`03o`000?oo
oooooooo03Oooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Cooooo0_l0
000Pooooo`03o`000?oooooooooo07Kooooo0ol0000eooooo`03o`000?oooooooooo03Wooooo00?o
0000ooooooooool0=_ooool0023ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1b
ooooo`?o0000>?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03Gooooo000Poooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool0Koooool2o`0003cooooo00?o0000oooo
ooooool0>_ooool00ol0003oooooooooo`0dooooo`008?ooool2o`0002?ooooo00?o0000oooooooo
ool0Joooool3o`0000gooooo0_ooV@0`ooooo`03o`000?oooooooooo03Wooooo00?o0000oooooooo
ool0=?ooool0023ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`1Wooooo`?o0000
3Oooool3oonI03?ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0cooooo`008?oo
ool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo06?ooooo0ol0000>ooooo`;ooiT0=ooo
ool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo03;ooooo000Pooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0Goooool3o`0000kooooo0oooV@0iooooo`03o`000?oooooo
oooo03Wooooo00?o0000ooooooooool0<_ooool0023ooooo00?o0000ooooooooool09_ooool2o`00
05gooooo0_l0000>ooooo`?ooiT0?Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo
037ooooo000Oooooo`?o0000:Oooool00ol0003oooooooooo`1Gooooo`?o00003Oooool3oonI047o
oooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0`ooooo`007oooool00ol0003ooooo
ooooo`0Zooooo`03o`000?oooooooooo05?ooooo0ol0000=ooooo`?ooiT0AOooool00ol0003ooooo
ooooo`0iooooo`03o`000?oooooooooo02oooooo000Oooooo`03o`000?oooooooooo02_ooooo00?o
0000ooooooooool0Coooool3o`0000kooooo0_ooV@18ooooo`03o`000?oooooooooo03Wooooo00?o
0000ooooooooool0;oooool001oooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`1;
ooooo`?o00003_ooool3oonI01Kooooo0_o<o`0cooooo`03o`000?oooooooooo03Sooooo0_l0000`
ooooo`007oooool3o`0002gooooo00?o0000ooooooooool0Aoooool3o`0000kooooo0oooV@0Foooo
o`?oc?l0=_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02gooooo000Oooooo`03
o`000?oooooooooo02kooooo00?o0000ooooooooool0A?ooool2o`0000gooooo1?ooV@0Fooooo`?o
c?l0>_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02gooooo000Dooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo043o
oooo0ol0000=ooooo`;ooiT05_ooool4olco03kooooo00?o0000ooooooooool0>?ooool00ol0003o
ooooooooo`0/ooooo`005?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo00?o0000oooooooo
ool0<Oooool00ol0003oooooooooo`0looooo`?o00003Oooool3oonI01Gooooo0oo<o`12ooooo`03
o`000?oooooooooo03Wooooo00?o0000ooooooooool0:oooool001Cooooo00Go410@oooooooooooo
oooooa0@4005ooooo`;o0000<oooool00ol0003oooooooooo`0hooooo`?o00003?ooool4oonI01Go
oooo0oo<o`16ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0:_ooool001Cooooo
00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo03?ooooo00?o0000oooooooo
ool0=?ooool3o`0000gooooo0_ooV@0Fooooo`?oc?l0B_ooool00ol0003oooooooooo`0hooooo`03
o`000?oooooooooo02[ooooo000Dooooo`05o`000?ooooooooooooooool000001Oooool00ol0003o
ooooooooo`0dooooo`03o`000?oooooooooo033ooooo0ol0000?ooooo`03oonI0?oooooooooo01?o
oooo0oo<o`1>ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0:Oooool001Cooooo
00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo03Gooooo00?o0000oooooooo
ool0;Oooool2o`0002Kooooo0_o<o`0Hooooo`?o<ol0=oooool00ol0003oooooooooo`0hooooo`03
o`000?oooooooooo02Sooooo000Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool00ol0003o
ooooooooo`0fooooo`03o`000?oooooooooo02Wooooo0ol0000Uooooo`?oc?l05_ooool4oc?o03[o
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Xooooo`005?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_l0000hooooo`03o`000?oooooooooo02Gooooo0ol0000Uooooo`?o
c?l05_ooool3oc?o03oooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Wooooo`00
7_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo027ooooo0ol0000Uooooo`?oc?l0
5oooool2oc?o04?ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Vooooo`007Ooo
ool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo01gooooo0ol0000Uooooo`?oc?l06?oo
ool2oc?o04Kooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Uooooo`007Oooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo01[ooooo0_l0000Uooooo`?oc?l06?ooool3
oc?o04Wooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Uooooo`007Oooool2o`00
03gooooo00?o0000ooooooooool05_ooool3o`0002Cooooo0oo<o`0Gooooo`Co<ol0C?ooool00ol0
003oooooooooo`0gooooo`;o00009_ooool001gooooo00?o0000ooooooooool0?Oooool00ol0003o
ooooooooo`0Booooo`?o0000?_ooool3oc?o057ooooo00?o0000ooooooooool0>?ooool00ol0003o
ooooooooo`0Sooooo`007Oooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo00kooooo
0ol0000oooooo`;o<ol06_ooool2o`3oISWooooo00?o0000ooooooooool0=oooool00ol0003ooooo
ooooo`0Sooooo`007Oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00[ooooo0ol0
000oooooo`?o<ol06Oooool3o`3oIScooooo00?o0000ooooooooool0=oooool00ol0003ooooooooo
o`0Rooooo`007Oooool00ol0003oooooooooo`10ooooo`03o`000?oooooooooo00Kooooo0ol0000o
ooooo`?o<ol06_ooool2o`3oIT3ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Q
ooooo`007?ooool3o`0004;ooooo00?o0000ooooooooool00oooool2o`0003oooooo0olco`0Koooo
o`;o0?mV@_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo023ooooo000Looooo`03
o`000?oooooooooo04?ooooo00?o0000ooooool000000_l0000nooooo`?o<ol07?ooool2o`3oITGo
oooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Pooooo`007?ooool00ol0003ooooo
ooooo`12ooooo`?o0000?_ooool3oc?o01cooooo0ol0ofI8ooooo`03o`000?oooooooooo03Oooooo
00?o0000ooooooooool02Oooool2o`000003oa0@4?oooooooooo017ooooo000Looooo`03o`000?oo
oooooooo03oooooo0ol00003ooooo`03o`000?oooooooooo03Sooooo0olco`0Looooo`?o0?mVC?oo
ool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04_oo
ool001cooooo0ol0000looooo`?o00001oooool00ol0003oooooooooo`1Booooo`Co0?mVD?ooool0
0ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Kooooo1Ol0000Cooooo`007?ooool00ol0
003oooooooooo`0iooooo`?o00002oooool00ol0003oooooooooo`1>ooooo`?o0?mVE?ooool00ol0
003oooooooooo`0gooooo`03o`000?oooooooooo00Gooooo00CoA4A4omgMgOoooooo00005?ooool0
0006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8b
omgMg@05ooooo`03o`000?oooooooooo03Oooooo0_l0000?ooooo`03o`000?oooooooooo04[ooooo
0ol0ofHLooooo`;o0?oo>_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00Cooooo
00CogMgMoeEEEOoooooo00005?ooool00006oooooomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q
8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0dooooo`?o00004_ooool00ol0
003oooooooooo`15ooooo`Co0?mV7_ooool00ol0ooooooooooooo`0kooooo`03o`000?oooooooooo
03Kooooo00?o0000ooooooooool01Oooool00omgMgOoc<c<o`00000Dooooo`0000?ooooooa0@4?oo
ool00_ooool00ol@413oooooooooo`0>ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0<Oooool3o`0001Kooooo00?o0000ooooooooool0@Oooool3o`3oIR7ooooo00?o0?oooooooooo
ool0?Oooool00ol0003oooooooooo`0fooooo`;o00001Oooool00oo^k^koA4A4o`00000Dooooo`00
00?oooooo`000?ooool00_ooool00ol0003oooooooooo`0=ooooo`03ogMgMolb<S;ooooo00?ooooo
0_l0000`ooooo`?o00006_ooool00ol0003oooooooooo`0mooooo`?o0?mV8_ooool2o`3ood7ooooo
00?o0000ooooooooool0=?ooool00ol0003oooooo`000006ooooo`03ogMgMol0003ooooo01?ooooo
00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00[ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c004ooooo`03o`000?oooooooooo02cooooo0ol0000Nooooo`03o`000?oooooooooo03Wooooo
0ol0ofHRooooo`?o0?oo@oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo01Wooooo
00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00[ooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0Zooooo`;o00008_ooool00ol0003oooooooooo`0eooooo`?o0?mV8ooo
ool2o`3oodOooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Iooooo`0000Kooooo
ogMgMonHV9SooooooiRHV?mgMgL<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
9oooool3o`0002Gooooo0_l0000dooooo`03o`3oI_oooooooooo02;ooooo0_l0oom:ooooo`03o`00
0?oooooooooo03Kooooo00?o0000ooooooooool06?ooool00006ooooooo^k^ko<S8bo`000?lb<S;o
k^k^3?ooool4o`0000Gooooo0_l0000Uooooo`?o0000:_ooool00ol0003oooooooooo`1Dooooo`;o
0?ooCOooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo01Oooooo000Kooooo`03o`00
0?oooooooooo027ooooo0ol0000^ooooo`03o`000?oooooooooo053ooooo0ol0oom@ooooo`03o`00
0?oooooooooo03Gooooo00?o0000ooooooooool05oooool001_ooooo00?o0000ooooooooool07_oo
ool3o`0003;ooooo00?o0000ooooooooool0C?ooool3o`3ooe?ooooo00?o0000ooooooooool0=_oo
ool00ol0003oooooooooo`0Fooooo`006oooool00ol0003oooooooooo`0Kooooo`?o0000=_ooool0
0ol0003oooooooooo`18ooooo`?o0?oo7Oooool2o`1VocSooooo00?o0000ooooooooool0=_ooool0
0ol0003oooooooooo`0Eooooo`006_ooool00ol0003oooooooooo`0Jooooo`;o0000>_ooool00ol0
003oooooooooo`14ooooo`?o0?oo7oooool00ol0I_ooooooooooo`0iooooo`03o`000?oooooooooo
03Kooooo00?o0000ooooooooool05?ooool001[ooooo0_l0000Hooooo`?o0000?Oooool00ol0003o
ooooooooo`0oooooo`Co0?oo8Oooool00ol0I_ooooooooooo`0kooooo`03o`000?oooooooooo03Go
oooo00?o0000ooooooooool05?ooool001[ooooo00?o0000ooooooooool05?ooool3o`00047ooooo
00?o0000ooooooooool0>oooool3o`3oob?ooooo0_l0I_lnooooo`03o`000?oooooooooo03Kooooo
00?o0000ooooooooool04oooool001[ooooo00?o0000ooooooooool04Oooool3o`0004Gooooo00?o
0000ooooooooool0=_ooool4o`3oobCooooo0_l0I_m1ooooo`03o`000?oooooooooo03Kooooo00?o
0000ooooooooool04_ooool001[ooooo00?o0000ooooooooool03_ooool3o`0004Wooooo00?o0000
ooooooooool0;oooool6o`3oobOooooo00?o06Koooooooooool0@_ooool00ol0003oooooooooo`0e
ooooo`;o00004oooool001[ooooo00?o0000ooooooooool03?ooool2o`0004gooooo00?o0000oooo
ooooool0:oooool3o`3oob_ooooo0_l0I_m6ooooo`03o`000?oooooooooo03Cooooo0_l0000Coooo
o`006Oooool3o`0000[ooooo0ol0001@ooooo`03o`000?oooooooooo05Kooooo0_l0I_m9ooooo`03
o`000?oooooooooo03Gooooo00?o0000ooooooooool04?ooool001[ooooo00?o0000ooooooooool0
1_ooool3o`0005Cooooo00?o0000ooooooooool0E?ooool00ol0I_ooooooooooo`19ooooo`03o`00
0?oooooooooo03Kooooo00?o0000ooooooooool03oooool001Wooooo00?o0000ooooooooool01?oo
ool3o`0005Sooooo00?o0000ooooooooool0D?ooool3o`1VoaOooooo0_lc0?ldooooo`03o`000?oo
oooooooo03Gooooo00?o0000ooooooooool03oooool001Wooooo00Co0000oooooooooooooooo0ol0
001Looooo`03o`000?oooooooooo04cooooo0ol0I_lIooooo`03oc<0oooooooooooo03Gooooo00?o
0000ooooooooool0=Oooool00ol0003oooooooooo`0>ooooo`006Oooool4o`00063ooooo00?o0000
ooooooooool0B?ooool3o`1Voa_ooooo00?o<`3oooooooooool0=oooool00ol0003oooooooooo`0e
ooooo`03o`000?oooooooooo00gooooo000Iooooo`;o0000Hoooool00ol0003oooooooooo`14oooo
o`?o06Ko7Oooool00olc0?ooooooooooo`0iooooo`03o`000?oooooooooo03Cooooo00?o0000oooo
ooooool03Oooool000oooooo1?l000000ol@413oooooooooo`05ooooo`03o`000?oooooooooo067o
oooo00?o0000ooooooooool0?oooool4o`1Voakooooo0_lc0?llooooo`03o`000?oooooooooo03Go
oooo00?o0000ooooooooool03?ooool0017ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`1Qooooo`03o`000?oooooooooo03_ooooo0ol0I_lPooooo`;o<`3o?oooool00ol0003ooooo
ooooo`0eooooo`03o`000?oooooooooo00_ooooo000Aooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool0HOooool00ol0003oooooooooo`0eooooo`Go06Ko8_ooool00olc0?oooooooooo
o`10ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool02_ooool0017ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo02gooooo1ol0I_lU
ooooo`;o<`3oA?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00[ooooo000Aoooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Voooo
o`Ko06Ko:_ooool2oc<0oa?ooooo0_o<0?lbooooo`03o`000?oooooooooo03Cooooo00?o0000oooo
ooooool02Oooool0017ooooo00?o0000ooooooooool03?ooool2o`0006;ooooo00?o0000oooooooo
ool08_ooool3o`1Voboooooo00?o<`3oooooooooool04_ooool00oo<0?ooooooooooo`0booooo`03
o`000?oooooooooo03?ooooo0ol0000:ooooo`004Oooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo063ooooo00?o0000ooooooooool0DOooool2oc<0oa?ooooo0_o<0?lfooooo`03o`00
0?oooooooooo02oooooo0ol00002ooooo`03o`000?oooooooooo00Sooooo000?ooooo`03oeEEEOmV
IVKo0000017ooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1>ooooo`;o<`3o5?oo
ool00oo<0?ooooooooooo`0gooooo`03o`000?oooooooooo02_ooooo0ol00005ooooo`03o`000?oo
oooooooo00Sooooo000Tooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0B_ooool3
oc<0oaCooooo0_o<0?lkooooo`03o`000?oooooooooo02Kooooo1?l00008ooooo`03o`000?oooooo
oooo00Sooooo000Uooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0Aoooool2oc<0
oaKooooo00?oc03oooooooooool0??ooool00ol0003oooooooooo`0Rooooo`?o00003?ooool00ol0
003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo04?o
oooo0olc0?lFooooo`;oc03o?oooool00ol0003oooooooooo`0Oooooo`?o00004?ooool00ol0003o
ooooooooo`07ooooo`009oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo03kooooo
1?lc0?lHooooo`03ol`0oooooooooooo00gooooo0_oo09Taooooo`03o`000?oooooooooo01[ooooo
1?l0000Cooooo`03o`000?oooooooooo00Oooooo000Xooooo`;o0000HOooool00ol0003ooooooooo
o`0iooooo`Co<`3o6_ooool2ol`0o`oooooo00?oo`2Iooooooooool0<_ooool00ol0003ooooooooo
o`0Fooooo`?o00005oooool00ol0003oooooooooo`07ooooo`00:_ooool00ol0003oooooooooo`1O
ooooo`03o`000?oooooooooo03Cooooo1?lc0?lLooooo`;oc03o3oooool2ool0VCKooooo00?o0000
ooooooooool04_ooool3o`0001[ooooo00?o0000ooooooooool01oooool002_ooooo00?o0000oooo
ooooool0Goooool00ol0003oooooooooo`0]ooooo`Ko<`3o7_ooool2ol`0oa3ooooo00?oo`2Ioooo
ooooool0=oooool00ol0003oooooooooo`0=ooooo`Co00007Oooool00ol0003oooooooooo`07oooo
o`00;?ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo02Cooooo2?lc0?lRooooo`;o
c03o4?ooool2ool0VC[ooooo00?o0000ooooooooool02_ooool3o`00027ooooo00?o0000oooooooo
ool01oooool002gooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0Hooooo`_o<`3o
:?ooool2ol`0oa7ooooo00?oo`2Iooooooooool0>oooool00ol0003oooooooooo`06ooooo`?o0000
9?ooool00ol0003oooooooooo`07ooooo`00;_ooool00ol0003oooooooooo`1Oooooo`03o`000?oo
oooooooo04Oooooo0oo<0?lAooooo`;oo`2I?oooool01?l0003oooooooooooooool4o`0002Oooooo
00?o0000ooooooooool01oooool002oooooo0_l0001Pooooo`03o`000?oooooooooo04?ooooo0oo<
0?lCooooo`03ool0VOoooooooooo00gooooo0_oo000aooooo`?o0000;?ooool00ol0003ooooooooo
o`06ooooo`00<Oooool00ol0003oooooooooo`1Nooooo`;o0000@Oooool2ol`0oaGooooo00?oo`2I
ooooooooool03?ooool2ool0033ooooo0ol000000ooooooo0000ooooo`0/ooooo`03o`000?oooooo
oooo00Kooooo000booooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool0>oooool3ol`0
oaGooooo0_oo09T>ooooo`03ool00?oooooooooo02gooooo0ol00004ooooo`03o`000?oooooooooo
02_ooooo00?o0000ooooooooool01_ooool003?ooooo00?o0000ooooooooool0Goooool00ol0003o
ooooooooo`0gooooo`?oc03o5Oooool3ool0V@kooooo0_oo000/ooooo`Co00002?ooool00ol0003o
ooooooooo`0Zooooo`03o`000?oooooooooo00Kooooo000dooooo`03o`000?oooooooooo05oooooo
00?o0000ooooooooool0<_ooool4ol`0oaGooooo0ooo09T?ooooo`;oo`00:oooool3o`0000gooooo
00?o0000ooooooooool0:Oooool00ol0003oooooooooo`06ooooo`00=Oooool00ol0003ooooooooo
o`1Oooooo`03o`000?oooooooooo02cooooo1Oo<0?lGooooo`;oo`2I4Oooool00ooo003ooooooooo
o`0Xooooo`?o00004Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Kooooo000f
ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool09Oooool6ol`0oa[ooooo0_oo09TA
ooooo`;oo`009oooool4o`0001Gooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`06
ooooo`00=oooool2o`00063ooooo00?o0000ooooooooool06oooool9ol`0oagooooo0ooo09TAoooo
o`;oo`009_ooool3o`0001Wooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`06oooo
o`00>Oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo017ooooo2Oo<0?lTooooo`;o
o`2I4oooool00ooo003oooooooooo`0Sooooo`?o00007Oooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo00Gooooo000jooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0
3?ooool4ol`0ob[ooooo0ooo09TCooooo`;oo`008_ooool4o`00027ooooo00?o0000ooooooooool0
9_ooool00ol0003oooooooooo`05ooooo`00>oooool00ol0003oooooooooo`1Nooooo`03o`000?oo
oooooooo03Kooooo0ooo09TDooooo`;oo`008Oooool3o`0002Kooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`05ooooo`00??ooool00ol0003oooooooooo`1Nooooo`03o`000?oooooo
oooo03;ooooo0ooo09TEooooo`;oo`008?ooool3o`0002Wooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`05ooooo`00?Oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo
02gooooo1?oo09TFooooo`;oo`007_ooool4o`0002gooooo00?o0000ooooooooool09?ooool00ol0
003oooooooooo`05ooooo`00?_ooool2o`0005oooooo00?o0000ooooooooool09oooool5ool0VAOo
oooo0ooo000Mooooo`?o0000<_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Go
oooo0010ooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool08_ooool4ool0VAWooooo
0ooo000Mooooo`?o0000=_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00Gooooo
0011ooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool07?ooool5ool0VA[ooooo0ooo
000Looooo`Co0000>_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Gooooo0012
ooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool04oooool8ool0VA_ooooo1?oo000L
ooooo`?o0000?_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Gooooo0013oooo
o`03o`000?oooooooooo05gooooo00?o0000ooooooooool01?ooool>ool0VB3ooooo0ooo000Moooo
o`?o0000@_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Cooooo0014ooooo`03
o`000?oooooooooo05gooooo00?o0000ooooooooool0;_ooool3ool001cooooo1?l00016ooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool01?ooool004Gooooo00?o0000ooooooooool0
GOooool00ol0003oooooooooo`0Yooooo`Coo`007?ooool3o`0004_ooooo00?o0000ooooooooool0
7oooool00ol0003oooooooooo`04ooooo`00A_ooool2o`0005kooooo00?o0000ooooooooool09Ooo
ool3ool001gooooo0ol0001?ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool01?oo
ool004Sooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`0Qooooo`?oo`007?ooool4
o`0005;ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`04ooooo`00BOooool00ol0
003oooooooooo`1Looooo`03o`000?oooooooooo01Wooooo1ooo000Looooo`?o0000Eoooool00ol0
003oooooooooo`0Mooooo`03o`000?oooooooooo00Cooooo001:ooooo`03o`000?oooooooooo05co
oooo00?o0000ooooooooool04?ooool8ool0023ooooo0ol0001Kooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool01?ooool004_ooooo00?o0000ooooooooool0G?ooool00ol0003ooooo
ooooo`0:ooooo`Goo`009?ooool4o`0005oooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`04ooooo`00C?ooool00ol0003oooooooooo`1Looooo`coo`009_ooool3o`0006Cooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`03ooooo`00COooool2o`0005gooooo00?o0000
ooooooooool0:oooool3o`0006Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`03
ooooo`00Coooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo02Oooooo0ol0001[oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool00oooool0053ooooo00?o0000oooooooo
ool0Foooool00ol0003oooooooooo`0Rooooo`Co0000Koooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo00?ooooo001Aooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool0
7_ooool3o`0007Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`03ooooo`00D_oo
ool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo01[ooooo0ol0001hooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool00oooool005?ooooo00?o0000ooooooooool0Foooool0
0ol0003oooooooooo`0Eooooo`Co0000Noooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo00?ooooo001Dooooo`;o0000G?ooool00ol0003oooooooooo`0Aooooo`?o0000P?ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo00?ooooo001Fooooo`03o`000?oooooooooo05[o
oooo00?o0000ooooooooool03Oooool3o`0008Cooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`02ooooo`00Eoooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00Sooooo
1?l00028ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool00_ooool005Sooooo00?o
0000ooooooooool0F_ooool00ol0003oooooooooo`04ooooo`?o0000SOooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo00;ooooo001Iooooo`03o`000?oooooooooo05[ooooo00?o0000
ooooooooool00ol0002@ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00_ooool0
05[ooooo00?o0000ooooooooool0F_ooool2o`0009Cooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`02ooooo`00Foooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo09Co
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`02ooooo`00G?ooool2o`0005Wooooo
00?o0000ooooooooool0UOooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo
001Nooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool0U_ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo00;ooooo001Oooooo`03o`000?oooooooooo05Gooooo00?o0000
ooooooooool0U_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo007ooooo001Poooo
o`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0Uoooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo007ooooo001Qooooo`03o`000?oooooooooo05?ooooo00?o0000oooooooo
ool0V?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo007ooooo001Rooooo`03o`00
0?oooooooooo05;ooooo00?o0000ooooooooool0VOooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo007ooooo001Sooooo`;o0000D_ooool00ol0003oooooooooo`2Jooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool00Oooool006Gooooo00?o0000ooooooooool0Coooool0
0ol0003oooooooooo`2Jooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00Oooool0
06Kooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`2Kooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool00Oooool006Oooooo00?o0000ooooooooool0COooool00ol0003o
ooooooooo`2Looooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00Oooool006Sooooo
00?o0000ooooooooool0C?ooool00ol0003oooooooooo`2Mooooo`03o`000?oooooooooo00_ooooo
0Ol00001ooooo`7ooooo001Yooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0WOoo
ool00ol0003oooooooooo`0;ooooo`7o00000Oooool1ooooo`00J_ooool00ol0003oooooooooo`1:
ooooo`03o`000?oooooooooo09kooooo00?o0000ooooooooool02_ooool1o`00007ooooo0Oooool0
06_ooooo0_l0001:ooooo`03o`000?oooooooooo09oooooo00?o0000ooooooooool02Oooool1o`00
007ooooo0Oooool006gooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`2Pooooo`03
o`000?oooooooooo00Sooooo0Ol00001ooooo`7ooooo001^ooooo`03o`000?oooooooooo04Kooooo
00?o0000ooooooooool0XOooool00ol0003oooooooooo`07ooooo`7o00000Oooool1ooooo`00Kooo
ool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo0:7ooooo00?o0000ooooooooool01ooo
ool1o`00007ooooo0Oooool0073ooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`2R
ooooo`03o`000?oooooooooo00Kooooo0Ol00001ooooo`7ooooo001aooooo`03o`000?oooooooooo
04?ooooo00?o0000ooooooooool0Xoooool00ol0003oooooooooo`05ooooo`7o00000Oooool1oooo
o`00L_ooool2o`0004;ooooo00?o0000ooooooooool0YOooool00ol0003oooooooooo`05ooooo`7o
00000Oooool007Cooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`2Vooooo`03o`00
0?oooooooooo00Cooooo0Ol00001ooooo`00MOooool00ol0003oooooooooo`0nooooo`03o`000?oo
oooooooo0:Kooooo00?o0000ooooooooool01?ooool1o`00007ooooo001fooooo`03o`000?oooooo
oooo03gooooo00?o0000ooooooooool0Yoooool00ol0003oooooooooo`03ooooo`7o00000Oooool0
07Oooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`2Xooooo`03o`000?oooooooooo
00;ooooo0Ol00001ooooo`00N?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0:Wo
oooo00Go0000ooooooooooooooooo`000001ooooo`00NOooool00ol0003oooooooooo`0jooooo`03
o`000?oooooooooo0:[ooooo00Co0000oooooooooooo00000Oooool007[ooooo0_l0000jooooo`03
o`000?oooooooooo0:[ooooo00Co0000oooooooooooo00000Oooool007cooooo00?o0000oooooooo
ool0=oooool00ol0003oooooooooo`2[ooooo`03o`000?oooooooooo007o0000001mooooo`03o`00
0?oooooooooo03Kooooo00?o0000ooooooooool0[?ooool1o`00007ooooo0Ol0000007kooooo00?o
0000ooooooooool0=Oooool00ol0003oooooooooo`2]ooooo`;o0000001oooooo`03o`000?oooooo
oooo03Cooooo00?o0000ooooooooool0[?ooool3o`000000P?ooool00ol0003oooooooooo`0coooo
o`03o`000?oooooooooo0:Sooooo1?l00003ooooo`00POooool2o`0003?ooooo00?o0000oooooooo
ool0YOooool3o`0000Oooooo0023ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
XOooool4o`0000[ooooo0024ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0WOoo
ool4o`0000kooooo0025ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0VOooool4
o`0001;ooooo0026ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0UOooool4o`00
01Kooooo0027ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0T_ooool3o`0001[o
oooo0028ooooo`;o0000;?ooool00ol0003oooooooooo`2>ooooo`Co00007Oooool008[ooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`2:ooooo`Co00008Oooool008_ooooo00?o0000
ooooooooool0:?ooool00ol0003oooooooooo`26ooooo`Co00009Oooool008cooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`22ooooo`Co0000:Oooool008gooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`1oooooo`?o0000;Oooool008kooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`1kooooo`Co0000<?ooool008oooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`1gooooo`Co0000=?ooool0093ooooo0_l0000Tooooo`03o`000?oooooo
oooo07?ooooo1?l0000hooooo`00T_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
073ooooo0ol0000looooo`00Toooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo06co
oooo1?l0000oooooo`00U?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo06Sooooo
1?l00013ooooo`00UOooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo06Cooooo1?l0
0017ooooo`00U_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo063ooooo1?l0001;
ooooo`00Uoooool2o`0001gooooo00?o0000ooooooooool0GOooool3o`0004oooooo002Iooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool0FOooool4o`0005;ooooo002Jooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool0EOooool4o`0005Kooooo002Kooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool0DOooool4o`0005[ooooo002Looooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool0COooool4o`0005kooooo002Mooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool0B_ooool3o`0006;ooooo002Nooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool0A_ooool4o`0006Gooooo002Oooooo`;o00005?ooool00ol0003ooooo
ooooo`13ooooo`Co0000JOooool00:7ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0oooooo`Co0000KOooool00:;ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0k
ooooo`Co0000LOooool00:?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0hoooo
o`?o0000MOooool00:Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0dooooo`Co
0000N?ooool00:Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0`ooooo`Co0000
O?ooool00:Kooooo0_l0000=ooooo`03o`000?oooooooooo02cooooo1?l00020ooooo`00Z?ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Wooooo0ol00024ooooo`00ZOooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo02Gooooo1?l00027ooooo`00Z_ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo027ooooo1?l0002;ooooo`00Zoooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo01gooooo1?l0002?ooooo`00[?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo01Wooooo1?l0002Cooooo`00[Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo01Kooooo0ol0002Gooooo`00[_ooool2o`0000Gooooo00?o0000oooo
ooooool04_ooool4o`0009[ooooo002`ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool03_ooool4o`0009kooooo002aooooo`05o`000?ooooooooooooooool000003?ooool4o`000:;o
oooo002booooo`04o`000?ooooooooooo`0000Sooooo1?l0002Vooooo`00/oooool00ol0003ooooo
o`000005ooooo`?o0000Z_ooool00;Cooooo0_l000000ooooooo0000o`000002o`000:gooooo002e
ooooo`;o0000/Oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {319.688, 0}} -> {-0.0710364, -0.0181728, \
0.0035149, 0.0035149}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .89104 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-16 1.0656 -0.0363427 1.0656 [
[.02544 .21571 -12 -8.9133 ]
[.02544 .21571 0 .0867 ]
[.16074 .16277 -11.6592 -9 ]
[.16074 .16277 .34081 0 ]
[.3021 .10747 -5.60025 -9 ]
[.3021 .10747 .39975 0 ]
[.44992 .04965 -5.37091 -9 ]
[.44992 .04965 .62909 0 ]
[.60467 -0.01084 -5.14157 -9 ]
[.60467 -0.01084 .85843 0 ]
[.66454 .05085 0 -6.20675 ]
[.66454 .05085 6 2.79325 ]
[.80797 .25198 0 -6.0417 ]
[.80797 .25198 6 2.9583 ]
[.93071 .4241 0 -5.90576 ]
[.93071 .4241 6 3.09424 ]
[.02254 .22988 -12 -2.74631 ]
[.02254 .22988 0 6.25369 ]
[.0142 .29178 -24 -2.78907 ]
[.0142 .29178 0 6.21093 ]
[.00558 .35578 -6 -2.83339 ]
[.00558 .35578 0 6.16661 ]
[-0.00334 .42198 -18 -2.87938 ]
[-0.00334 .42198 0 6.12062 ]
[-0.01257 .49051 -6 -2.92712 ]
[-0.01257 .49051 0 6.07288 ]
[ 0 0 0 0 ]
[ 1 .89104 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03495 .22504 m
.61241 0 L
s
.03495 .22504 m
.03971 .2297 L
s
[(-2)] .02544 .21571 1 .98073 Mshowa
.16988 .17246 m
.17445 .1773 L
s
[(-1)] .16074 .16277 .9432 1 Mshowa
.31082 .11753 m
.31518 .12256 L
s
[(0)] .3021 .10747 .86675 1 Mshowa
.45818 .0601 m
.46231 .06533 L
s
[(1)] .44992 .04965 .7903 1 Mshowa
.61241 0 m
.61628 .00542 L
s
[(2)] .60467 -0.01084 .71386 1 Mshowa
.125 Mabswid
.06148 .2147 m
.06431 .21752 L
s
.08823 .20428 m
.09104 .20712 L
s
.11521 .19376 m
.118 .19663 L
s
.14243 .18316 m
.14519 .18604 L
s
.19758 .16166 m
.20029 .16459 L
s
.22551 .15078 m
.22821 .15373 L
s
.2537 .13979 m
.25637 .14277 L
s
.28213 .12871 m
.28478 .13171 L
s
.33977 .10625 m
.34236 .10929 L
s
.36897 .09487 m
.37153 .09794 L
s
.39844 .08339 m
.40097 .08648 L
s
.42817 .0718 m
.43068 .07491 L
s
.48846 .0483 m
.49091 .05146 L
s
.51902 .03639 m
.52144 .03958 L
s
.54986 .02437 m
.55225 .02758 L
s
.58099 .01224 m
.58335 .01547 L
s
.25 Mabswid
.61241 0 m
.97291 .505 L
s
.65208 .05558 m
.64586 .05794 L
s
[(0)] .66454 .05085 -1 .37928 Mshowa
.79537 .2563 m
.78907 .25846 L
s
[(2)] .80797 .25198 -1 .3426 Mshowa
.91799 .42808 m
.91164 .43006 L
s
[(4)] .93071 .4241 -1 .31239 Mshowa
.125 Mabswid
.69012 .10886 m
.68637 .11025 L
s
.72662 .16 m
.72286 .16135 L
s
.76168 .2091 m
.75791 .21042 L
s
.82778 .3017 m
.82399 .30297 L
s
.85897 .3454 m
.85518 .34664 L
s
.88903 .3875 m
.88522 .38871 L
s
.94594 .46722 m
.94211 .46839 L
s
.25 Mabswid
.03495 .22504 m
0 .48612 L
s
.03495 .22504 m
.04116 .22262 L
s
[(-1)] .02254 .22988 1 -0.38971 Mshowa
.02665 .28704 m
.03288 .28468 L
s
[(-0.5)] .0142 .29178 1 -0.38021 Mshowa
.01807 .35115 m
.02431 .34884 L
s
[(0)] .00558 .35578 1 -0.37036 Mshowa
.00919 .41747 m
.01546 .41521 L
s
[(0.5)] -0.00334 .42198 1 -0.36014 Mshowa
0 .48612 m
.00629 .48392 L
s
[(1)] -0.01257 .49051 1 -0.34953 Mshowa
.125 Mabswid
.03331 .23728 m
.03704 .23583 L
s
.03166 .2496 m
.03539 .24816 L
s
.03 .262 m
.03373 .26056 L
s
.02833 .27448 m
.03207 .27305 L
s
.02496 .29969 m
.0287 .29828 L
s
.02325 .31243 m
.02699 .31102 L
s
.02154 .32525 m
.02528 .32385 L
s
.01981 .33816 m
.02355 .33676 L
s
.01632 .36423 m
.02007 .36285 L
s
.01455 .37741 m
.01831 .37603 L
s
.01278 .39067 m
.01653 .3893 L
s
.01099 .40402 m
.01475 .40266 L
s
.00738 .43101 m
.01114 .42966 L
s
.00555 .44464 m
.00932 .4433 L
s
.00371 .45837 m
.00748 .45704 L
s
.00186 .4722 m
.00563 .47087 L
s
.25 Mabswid
.03495 .22504 m
0 .48612 L
s
0 .48612 m
.46953 .89104 L
s
.46953 .89104 m
.47294 .65459 L
s
.47294 .65459 m
.03495 .22504 L
s
.61241 0 m
.97291 .505 L
s
.97291 .505 m
1 .75117 L
s
1 .75117 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.03495 .22504 m
0 .48612 L
s
0 .48612 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.61241 0 m
.03495 .22504 L
s
.47294 .65459 m
.97291 .505 L
s
.97291 .505 m
1 .75117 L
s
1 .75117 m
.46953 .89104 L
s
.46953 .89104 m
.47294 .65459 L
s
0 0 m
1 0 L
1 .89104 L
0 .89104 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.44068 .63827 m
.47196 .63602 L
s
.47196 .63602 m
.50495 .63183 L
s
1 0 .6 r
.43933 .61668 m
.46913 .6146 L
s
.46913 .6146 m
.50071 .61062 L
s
.8 0 1 r
.43803 .59447 m
.46625 .59267 L
s
1 0 0 r
.50495 .63183 m
.5385 .62571 L
s
.8 0 1 r
.46625 .59267 m
.49633 .58896 L
s
1 0 .6 r
.50071 .61062 m
.53293 .60471 L
s
.2 0 1 r
.43687 .57095 m
.46324 .56955 L
s
.8 0 1 r
.49633 .58896 m
.52716 .58333 L
s
.2 0 1 r
.46324 .56955 m
.49163 .56627 L
s
1 0 0 r
.5385 .62571 m
.5718 .61772 L
s
1 0 .6 r
.53293 .60471 m
.56494 .59696 L
s
.2 0 1 r
.49163 .56627 m
.52089 .56104 L
s
.8 0 1 r
.52716 .58333 m
.55784 .57587 L
s
0 .4 1 r
.43597 .54479 m
.45999 .54387 L
s
.45999 .54387 m
.48619 .54118 L
s
.2 0 1 r
.52089 .56104 m
.55009 .55395 L
s
0 .4 1 r
.48619 .54118 m
.51345 .53654 L
s
1 0 0 r
.5718 .61772 m
.60419 .60799 L
s
1 0 .6 r
.56494 .59696 m
.59609 .58751 L
s
.8 0 1 r
.55784 .57587 m
.58767 .56671 L
s
0 .4 1 r
.51345 .53654 m
.54076 .52998 L
s
.2 0 1 r
.55009 .55395 m
.57844 .54513 L
s
0 1 1 r
.4352 .51411 m
.45622 .51337 L
s
.45622 .51337 m
.47928 .51119 L
s
1 0 0 r
.60419 .60799 m
.63512 .59666 L
s
0 1 1 r
.47928 .51119 m
.50351 .50724 L
s
0 .4 1 r
.54076 .52998 m
.56721 .52165 L
s
1 0 .6 r
.59609 .58751 m
.62577 .57649 L
s
.8 0 1 r
.58767 .56671 m
.61601 .55602 L
s
0 1 1 r
.50351 .50724 m
.52792 .50144 L
s
.2 0 1 r
.57844 .54513 m
.60524 .5348 L
s
0 .4 1 r
.56721 .52165 m
.592 .51179 L
s
0 1 1 r
.52792 .50144 m
.55151 .4939 L
s
1 0 0 r
.63512 .59666 m
.66398 .58394 L
s
1 0 .6 r
.62577 .57649 m
.65335 .56413 L
s
0 1 .4 r
.43247 .47868 m
.45045 .47724 L
s
.8 0 1 r
.61601 .55602 m
.6422 .54403 L
s
0 1 .4 r
.45045 .47724 m
.46967 .47485 L
s
.2 0 1 r
.60524 .5348 m
.62977 .52321 L
s
0 1 .4 r
.46967 .47485 m
.48971 .47123 L
s
0 1 1 r
.55151 .4939 m
.57339 .48488 L
s
0 .4 1 r
.592 .51179 m
.61435 .50072 L
s
0 1 .4 r
.48971 .47123 m
.50988 .46622 L
s
1 0 0 r
.66398 .58394 m
.69005 .57015 L
s
1 0 .6 r
.65335 .56413 m
.67811 .55078 L
s
0 1 .4 r
.50988 .46622 m
.52941 .45985 L
s
.8 0 1 r
.6422 .54403 m
.66549 .53113 L
s
0 1 1 r
.57339 .48488 m
.5928 .4748 L
s
.2 0 1 r
.62977 .52321 m
.65127 .51079 L
s
.2 1 0 r
.42461 .44311 m
.44042 .44032 L
s
0 .4 1 r
.61435 .50072 m
.63352 .48895 L
s
.2 1 0 r
.44042 .44032 m
.45664 .43706 L
s
0 1 .4 r
.52941 .45985 m
.5476 .45235 L
s
.2 1 0 r
.45664 .43706 m
.47308 .43318 L
s
0 1 1 r
.5928 .4748 m
.6092 .46422 L
s
.2 1 0 r
.47308 .43318 m
.48948 .42858 L
s
1 0 .6 r
.67811 .55078 m
.69927 .53702 L
s
.8 0 1 r
.66549 .53113 m
.68513 .5179 L
s
1 0 0 r
.69005 .57015 m
.71252 .55587 L
s
0 1 .4 r
.5476 .45235 m
.56395 .44407 L
s
.8 1 0 r
.41381 .41282 m
.4284 .40892 L
s
.2 0 1 r
.65127 .51079 m
.66904 .49816 L
s
0 .4 1 r
.63352 .48895 m
.649 .47714 L
s
.2 1 0 r
.48948 .42858 m
.5055 .42325 L
s
.8 1 0 r
.4284 .40892 m
.44308 .40483 L
s
1 .6 0 r
.40379 .38743 m
.41783 .383 L
s
0 1 1 r
.6092 .46422 m
.62247 .45377 L
s
.8 1 0 r
.44308 .40483 m
.45778 .4005 L
s
0 1 .4 r
.56395 .44407 m
.57823 .43545 L
s
.2 1 0 r
.5055 .42325 m
.52087 .41729 L
s
1 .6 0 r
.41783 .383 m
.43191 .37849 L
s
.8 1 0 r
.45778 .4005 m
.47243 .39588 L
s
1 .6 0 r
.43191 .37849 m
.44602 .37388 L
s
.2 1 0 r
.52087 .41729 m
.53538 .41085 L
s
0 1 .4 r
.57823 .43545 m
.59056 .42686 L
s
.8 1 0 r
.47243 .39588 m
.48693 .39098 L
s
1 .6 0 r
.44602 .37388 m
.46013 .36916 L
s
.2 1 0 r
.53538 .41085 m
.54902 .40414 L
s
.8 1 0 r
.48693 .39098 m
.50124 .3858 L
s
1 .6 0 r
.46013 .36916 m
.47423 .36433 L
s
.8 1 0 r
.50124 .3858 m
.5153 .38039 L
s
.2 1 0 r
.54902 .40414 m
.5619 .39733 L
s
1 .6 0 r
.47423 .36433 m
.4883 .35938 L
s
.8 1 0 r
.5153 .38039 m
.52913 .37482 L
s
1 .6 0 r
.4883 .35938 m
.50233 .35434 L
s
.8 1 0 r
.52913 .37482 m
.54277 .36915 L
s
1 .6 0 r
.50233 .35434 m
.51633 .34921 L
s
.51633 .34921 m
.53032 .34403 L
s
0 g
.25 Mabswid
.61241 0 m
.97291 .505 L
s
.97291 .505 m
1 .75117 L
s
1 .75117 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.03495 .22504 m
0 .48612 L
s
0 .48612 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.61241 0 m
.03495 .22504 L
s
.03495 .22504 m
.61241 0 L
s
.03495 .22504 m
.03971 .2297 L
s
[(-2)] .02544 .21571 1 .98073 Mshowa
.16988 .17246 m
.17445 .1773 L
s
[(-1)] .16074 .16277 .9432 1 Mshowa
.31082 .11753 m
.31518 .12256 L
s
[(0)] .3021 .10747 .86675 1 Mshowa
.45818 .0601 m
.46231 .06533 L
s
[(1)] .44992 .04965 .7903 1 Mshowa
.61241 0 m
.61628 .00542 L
s
[(2)] .60467 -0.01084 .71386 1 Mshowa
.125 Mabswid
.06148 .2147 m
.06431 .21752 L
s
.08823 .20428 m
.09104 .20712 L
s
.11521 .19376 m
.118 .19663 L
s
.14243 .18316 m
.14519 .18604 L
s
.19758 .16166 m
.20029 .16459 L
s
.22551 .15078 m
.22821 .15373 L
s
.2537 .13979 m
.25637 .14277 L
s
.28213 .12871 m
.28478 .13171 L
s
.33977 .10625 m
.34236 .10929 L
s
.36897 .09487 m
.37153 .09794 L
s
.39844 .08339 m
.40097 .08648 L
s
.42817 .0718 m
.43068 .07491 L
s
.48846 .0483 m
.49091 .05146 L
s
.51902 .03639 m
.52144 .03958 L
s
.54986 .02437 m
.55225 .02758 L
s
.58099 .01224 m
.58335 .01547 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 256.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001@2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00gOooool5o`0008Kooooo003Mooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0Q_ooool00=ko
oooo00?oV9RHob4Q8Oo^k^h0Qoooool00=oooooo00?oV9RHob4Q8Oo^k^h0Q_ooool00>3ooooo00?o
MgMgofIVI_ooool0QOooool00>7ooooo00?o0000ooooooooool0Q?ooool00=gooooo00Go0000okZj
^_ooooooV9RHoa0@4026ooooo`00gOooool01OnHV9So410@o`000?lQ8B7oc<c<08Kooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003Tooooo`;o0000P_ooool0
0>7ooooo0ol000000ooooooo0000ooooo`21ooooo`00goooool2o`0000Cooooo0_l00021ooooo`00
g?ooool3o`0000Kooooo00?o0000ooooool00000P?ooool00=[ooooo0_l00009ooooo`03o`000?oo
oooo0000083ooooo003Gooooo`?o000000?oooooo`000?ooool02?ooool01?l0003oooooooooool0
001oooooo`00e?ooool3o`0000Cooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooo
oooo000007kooooo003Booooo`;o00004Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo07_ooooo002Zooooo`Co000000?o410@ooooooooool07_ooool3o`0001?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1kooooo`00[?ooool00ol0003oooooooooo`0Nooooo`;o
000000?oooooo`000?ooool04oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07[o
oooo002/ooooo`03o`000?oooooooooo01_ooooo0ol00004ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`1iooooo`00[?ooool00ol0003ooooooooo
o`0Iooooo`;o00006oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo07Wooooo002/
ooooo`03o`000?oooooooooo01Kooooo0ol0000Mooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool02?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^06_ooooo002/ooooo`03o`000?oooooo
oooo01Cooooo0_l000000ooooooo0000ooooo`0Mooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01oooool01OmgMgOoV9RHoooooonHV9SoMgMg06_ooooo002/ooooo`03o`000?oooooo
oooo017ooooo0ol00004ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`06ooooo`05oa0@4?ooooooooooooooool@4100Joooool00:[ooooo00?oEEEE
ofIVI_l000004Oooool2o`0002Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06
ooooo`05o`000?ooooooooooooooool00000Joooool00;_ooooo0ol0000Wooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000006_ooooo002i
ooooo`;o000000?oooooo`000?ooool09oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Cooooo00Go410@oooooooooooooooooa0@401[ooooo`00]_ooool3o`0000Cooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`1[ooooo`00/oooool3o`0002oooooo00?o0000ooooooooool02Oooool2
o`0000Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1[ooooo`00/Oooool2o`0003;ooooo00?o0000
ooooooooool02?ooool01?l0003oooooooooool0001dooooo`00[_ooool3o`000003ooooool0003o
oooo037ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1aooooo`00[?ooool2o`00
00Gooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
077ooooo002Yooooo`?o0000>_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo073o
oooo002Wooooo`;o0000?Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo06oooooo
002Tooooo`?o000000?oooooo`000?ooool0??ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo06oooooo002Rooooo`;o0000@_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo06kooooo001gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08oooool3o`0004Cooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1]ooooo`00Moooool01OmgMgOoV9RHoooooonHV9So
MgMg027ooooo0_l00017ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0K?ooool0
07Oooooo00Go410@oooooooooooooooooa0@400Nooooo`?o00000_ooool00ol0003oooooooooo`14
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0K?ooool007Oooooo00Go0000oooo
ooooooooooooo`00000Looooo`;o0000C?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo06_ooooo001gooooo`05o`000?ooooooooooooooool000006Oooool3o`0004kooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`1Zooooo`00Moooool01Ol@413ooooooooooooooooo
410@01Kooooo0ol0001Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0J_ooool0
07Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Dooooo`;o00000oooool00ol0003oooooooooo`1>
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0JOooool007Oooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Aooooo`?o0000E_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo06Sooooo002;ooooo`;o0000FOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
06Sooooo0028ooooo`?o0000Foooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo06Oo
oooo0026ooooo`;o00000oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo01Gooooo
0_l0001Xooooo`00Poooool3o`00063ooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`1Uooooo`00POooool2o`0006?ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1U
ooooo`00O_ooool4o`0006Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`1Toooo
o`00O?ooool2o`0000Cooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo06?ooooo001iooooo`?o0000J_ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo06?ooooo001gooooo`;o0000KOooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo06;ooooo001dooooo`?o000000?oooooo`000?ooool0K?ooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo067ooooo001aooooo`?o0000L_ooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo063ooooo0019ooooo`Co000000?o410@ooooooooool07oooool2o`0007Go
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1Pooooo`00Boooool00ol0003ooooo
ooooo`0Nooooo`?o0000Moooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo05oooooo
0010ooooo`Ko00001Oooool00ol0003oooooooooo`0Looooo`;o00000_ooool00ol0003ooooooooo
o`1eooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0G_ooool004_ooooo00?o0000
ooooooooool06Oooool3o`0007cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1N
ooooo`00Boooool00ol0003oooooooooo`0Gooooo`;o0000Ooooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo05gooooo001;ooooo`03o`000?oooooooooo01Cooooo0ol00021ooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0G?ooool004_ooooo00?o0000ooooooooool0
4_ooool2o`0000?ooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo05_ooooo0019ooooo`03oeEEEOmVIVKo0000017ooooo0ol00026ooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool0Foooool005_ooooo0_l00029ooooo`03o`000?oooooo
oooo027ooooo0_l0001Looooo`00F?ooool3o`000003ooooool0003ooooo08Sooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`1Iooooo`00E_ooool2o`0008kooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`1Iooooo`00Doooool3o`00093ooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`1Hooooo`00D?ooool3o`0009?ooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1Gooooo`00C_ooool2o`0000;ooooo00?o0000ooooooooool0TOooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo05Kooooo001;ooooo`?o00001Oooool00ol0
003oooooooooo`2@ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0E_ooool004Wo
oooo0_l0002Kooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0EOooool004Kooooo
1?l0002Looooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0E?ooool004Cooooo0_l0
002Pooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0E?ooool001[ooooo1Ol0000R
ooooo`?o0000X_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo05?ooooo000Joooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@08?ooool2o`000:Gooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`1Booooo`004_ooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h07_ooool3o`00
0003ooooool0003ooooo0:Cooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`1Aoooo
o`007?ooool00onHV9So8B4Qonk^kP0Kooooo`;o0000Z_ooool00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo057ooooo000Mooooo`03ogMgMomVIVKooooo01Oooooo0ol0002]ooooo`03o`00
0?oooooooooo02_ooooo00?o0000ooooooooool0D?ooool001kooooo00?o0000ooooooooool05?oo
ool2o`000;3ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`1?ooooo`006_ooool0
1Ol0003o^[ZjoooooonHV9So410@01?ooooo0ol00002ooooo`03o`000?oooooooooo0:gooooo00?o
0000ooooooooool0;?ooool2o`00053ooooo000Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`04?oo
ool3o`000;Gooooo00?o0000ooooooooool0;?ooool2o`00053ooooo000]ooooo`;o0000^?ooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo04gooooo000Zooooo`?o000000?oooooo`00
0?ooool0]oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo04gooooo000Xooooo`;o
0000_Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo04cooooo000Uooooo`?o0000
_oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo04_ooooo000Tooooo`;o0000`Ooo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo04[ooooo000Jooooo`Co000000?o410@
ooooooooool00oooool00ol0003oooooo`000030ooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool0B_ooool001cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0002o
ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0BOooool0017ooooo1_l00005oooo
o`03o`000?oooooooooo00Gooooo0_l00002ooooo`03o`000?oooooooooo0;cooooo00?o0000oooo
ooooool0<oooool00ol0003oooooooooo`18ooooo`007?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0^oooool00ol0003oooooooooo`0cooooo`03
o`000?oooooooooo00Oooooo1Ol0000looooo`007?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo00Kooooo00GoV9RHob4Q8Oo^k^koooooodA4A00looooo`007?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00ol0003ooooo
ooooo`0eooooo`03o`000?oooooooooo00Kooooo00?oV9RHob4Q8Oo^k^h0?Oooool001cooooo00?o
0000ooooooooool01?ooool3o`0000Kooooo00?o0000ooooooooool0^?ooool00ol0003ooooooooo
o`0fooooo`03o`000?oooooooooo00Kooooo00?oV9RHob4Q8Oo^k^h0??ooool001[ooooo00?oEEEE
ofIVI_l000001_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;Oooooo00?o0000
ooooooooool0=_ooool00ol0003oooooooooo`07ooooo`03ogMgMomVIVKooooo03_ooooo000Soooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0]_ooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0>_ooool002?ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`2eooooo`03o`000?oooooooooo03Oooooo0_l00004ooooo`05
o`000?nj^[[ooooooiRHV?l@4100??ooool002?ooooo0_l0000;ooooo`03o`000?oooooooooo0;Co
oooo00?o0000ooooooooool0=_ooool00ol0003oooooo`000004ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`0??ooool002?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`2cooooo`03
o`000?oooooooooo03Wooooo00?o0000ooooooooool0@_ooool002;ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0
@Oooool002;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`2`ooooo`;o0000?Ooo
ool00ol0003oooooooooo`10ooooo`008_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo0:cooooo0ol000000ooooooo0000ooooo`0looooo`03o`000?oooooooooo043ooooo000Roooo
o`;o00004Oooool00ol0003oooooooooo`2Xooooo`?o00001Oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo03oooooo000Rooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool0Y?ooool3o`0000Wooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0nooooo`00
8_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo0:3ooooo0ol0000=ooooo`03o`00
0?oooooooooo03[ooooo00?o0000ooooooooool0?_ooool002;ooooo0ol0000Cooooo`03o`000?oo
oooooooo09cooooo0ol0000Aooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0?Ooo
ool002;ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`2Iooooo`;o00005?ooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo03cooooo000Qooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool0UOooool3o`0001Oooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`0kooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo097ooooo0ol0000Kooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0>oooool0
00Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0SOooool3o`0001oooooo00?o0000
ooooooooool0>_ooool00ol0003oooooooooo`0jooooo`001Ol00002ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`02ooooo`;o00006_ooool00ol0003oooooooooo`29
ooooo`?o00008oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03Wooooo0007oooo
o`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool0Q_ooool2o`0002Kooooo00?o0000ooooooooool0>_ooool2
o`0003[ooooo0007ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`22ooooo`?o0000:Ooo
ool00ol0003oooooooooo`0iooooo`;o0000>_ooool000Oooooo00Go410@oooooooooooooooooa0@
400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`1nooooo`?o0000;Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03Oooooo0007
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`;o00007_oo
ool00ol0003oooooooooo`1jooooo`?o0000<Oooool00ol0003oooooooooo`0iooooo`03o`000?oo
oooooooo03Oooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Cooooo0_l0
000Pooooo`03o`000?oooooooooo07Kooooo0ol0000eooooo`03o`000?oooooooooo03Wooooo00?o
0000ooooooooool0=_ooool0023ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1b
ooooo`?o0000>?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03Gooooo000Poooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool0Koooool2o`0003cooooo00?o0000oooo
ooooool0>_ooool00ol0003oooooooooo`0dooooo`008?ooool2o`0002?ooooo00?o0000oooooooo
ool0Joooool3o`0003oooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0dooooo`00
8?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo06Oooooo0ol00013ooooo`03o`00
0?oooooooooo03Wooooo00?o0000ooooooooool0<oooool0023ooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`1Sooooo`?o0000Aoooool00ol0003oooooooooo`0iooooo`03o`000?oo
oooooooo03;ooooo000Pooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0Goooool3
o`0004[ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0booooo`008?ooool00ol0
003oooooooooo`0Vooooo`;o0000GOooool2o`0004kooooo00?o0000ooooooooool0>Oooool00ol0
003oooooooooo`0aooooo`007oooool3o`0002Wooooo00?o0000ooooooooool0Eoooool3o`00057o
oooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0`ooooo`007oooool00ol0003ooooo
ooooo`0Zooooo`03o`000?oooooooooo05?ooooo0ol0001Eooooo`03o`000?oooooooooo03Wooooo
00?o0000ooooooooool0;oooool001oooooo00?o0000ooooooooool0:oooool00ol0003ooooooooo
o`1?ooooo`?o00009oooool2oonI02oooooo00?o0000ooooooooool0>Oooool00ol0003ooooooooo
o`0_ooooo`007oooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo04_ooooo0ol0000W
ooooo`?ooiT0<_ooool00ol0003oooooooooo`0hooooo`;o0000<?ooool001oooooo0ol0000]oooo
o`03o`000?oooooooooo04Oooooo0ol0000Xooooo`;ooiT0=_ooool00ol0003oooooooooo`0ioooo
o`03o`000?oooooooooo02gooooo000Oooooo`03o`000?oooooooooo02kooooo00?o0000oooooooo
ool0A?ooool2o`0002Sooooo0oooV@0iooooo`03o`000?oooooooooo03Sooooo00?o0000oooooooo
ool0;Oooool001Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo02oo
oooo00?o0000ooooooooool0@?ooool3o`0002Oooooo0oooV@0mooooo`03o`000?oooooooooo03So
oooo00?o0000ooooooooool0;?ooool001Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool0??ooool3o`0002Oooooo0oooV@10ooooo`03
o`000?oooooooooo03Wooooo00?o0000ooooooooool0:oooool001Cooooo00Go410@oooooooooooo
oooooa0@4005ooooo`;o0000<oooool00ol0003oooooooooo`0hooooo`?o00009oooool3oonI04Co
oooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0Zooooo`005?ooool01Ol0003ooooo
oooooooooooo000000Gooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0dooooo`?o
0000:?ooool2oonI04Sooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Zooooo`00
5?ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool0=?ooool00ol0003o
ooooooooo`0`ooooo`?o0000:?ooool3oonI04_ooooo00?o0000ooooooooool0>?ooool00ol0003o
ooooooooo`0Yooooo`005?ooool01Ol@413ooooooooooooooooo410@00Gooooo00?o0000oooooooo
ool0=Oooool00ol0003oooooooooo`0]ooooo`;o0000:?ooool3oonI01Wooooo0oo<o`0cooooo`03
o`000?oooooooooo03Sooooo00?o0000ooooooooool0:?ooool001Cooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`05ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0:Oooool3o`0002Oo
oooo0oooV@0Hooooo`Coc?l0=_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02So
oooo000Dooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2o`0003Sooooo00?o0000oooooooo
ool09Oooool3o`0002Oooooo0oooV@0Iooooo`;oc?l0>oooool00ol0003oooooooooo`0hooooo`03
o`000?oooooooooo02Oooooo000Nooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0
8Oooool3o`0002Oooooo0oooV@0Jooooo`;oc?l0?_ooool00ol0003oooooooooo`0hooooo`03o`00
0?oooooooooo02Kooooo000Mooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool07Ooo
ool3o`0002Kooooo1?ooV@0Jooooo`?oc?l0@Oooool00ol0003oooooooooo`0hooooo`03o`000?oo
oooooooo02Gooooo000Mooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool06_ooool2
o`0002Oooooo0_ooV@0Looooo`;oc?l0AOooool00ol0003oooooooooo`0gooooo`03o`000?oooooo
oooo02Gooooo000Mooooo`;o0000?Oooool00ol0003oooooooooo`0Fooooo`?o0000:?ooool00ooo
V@3oooooooooo`0Iooooo`?oc?l0Aoooool00ol0003oooooooooo`0gooooo`;o00009_ooool001go
oooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Booooo`?o0000AOooool2olco04_o
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Sooooo`007Oooool00ol0003ooooo
ooooo`0nooooo`03o`000?oooooooooo00kooooo0ol00015ooooo`?oc?l0C_ooool00ol0003ooooo
ooooo`0gooooo`03o`000?oooooooooo02?ooooo000Mooooo`03o`000?oooooooooo03oooooo00?o
0000ooooooooool02_ooool3o`0004Gooooo0oo<o`0Looooo`;o<ol0=?ooool00ol0003ooooooooo
o`0gooooo`03o`000?oooooooooo02;ooooo000Mooooo`03o`000?oooooooooo043ooooo00?o0000
ooooooooool01_ooool3o`0004Gooooo0oo<o`0Mooooo`;o<ol0=oooool00ol0003oooooooooo`0g
ooooo`03o`000?oooooooooo027ooooo000Looooo`?o0000@_ooool00ol0003oooooooooo`03oooo
o`;o0000AOooool3olco01kooooo0_lco`0iooooo`03o`000?oooooooooo03Sooooo00?o0000oooo
ooooool08?ooool001cooooo00?o0000ooooooooool0@oooool00ol0003oooooo`000002o`0004Co
oooo0oo<o`0Oooooo`;o<ol0??ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo023o
oooo000Looooo`03o`000?oooooooooo04;ooooo0ol00012ooooo`Goc?l08Oooool00olco`3ooooo
ooooo`0mooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool02Oooool2o`000003oa0@
4?oooooooooo017ooooo000Looooo`03o`000?oooooooooo03oooooo0ol00003ooooo`03o`000?oo
oooooooo03cooooo0oo<o`0Tooooo`;o<ol0@Oooool00ol0003oooooooooo`0gooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool04_ooool001cooooo0ol0000looooo`?o00001oooool0
0ol0003oooooooooo`1Pooooo`;o<ol0A?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooo
oooo00Kooooo1Ol0000Cooooo`007?ooool00ol0003oooooooooo`0iooooo`?o00002oooool00ol0
003oooooooooo`1Mooooo`;o<ol0A_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo
00Gooooo00CoA4A4omgMgOoooooo00005?ooool00006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Ooo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo03Oooooo
0_l0000?ooooo`03o`000?oooooooooo05Wooooo0olco`19ooooo`03o`000?oooooooooo03Oooooo
00?o0000ooooooooool01?ooool01?oMgMgoEEEEooooool0000Dooooo`0000KoooooogMgMonHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
03Cooooo0ol0000Booooo`03o`000?oooooooooo05Cooooo1?lco`1=ooooo`03o`000?oooooooooo
03Kooooo00?o0000ooooooooool01Oooool00omgMgOoc<c<o`00000Dooooo`0000?ooooooa0@4?oo
ool00_ooool00ol@413oooooooooo`0>ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0<Oooool3o`0001Kooooo00?o0000ooooooooool0Coooool4oc?o01kooooo0_l0ofHbooooo`03
o`000?oooooooooo03Kooooo0_l00005ooooo`03onk^k_m4A4Co000001Cooooo00000ooooooo0000
ooooo`02ooooo`03o`000?oooooooooo00gooooo00?oMgMgoc8b<_ooool00oooool2o`00033ooooo
0ol0000Jooooo`03o`000?oooooooooo04_ooooo0olco`0Qooooo`03o`3oI_oooooooooo03?ooooo
00?o0000ooooooooool0=?ooool00ol0003oooooo`000006ooooo`03ogMgMol0003ooooo01?ooooo
00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00[ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c004ooooo`03o`000?oooooooooo02cooooo0ol0000Nooooo`03o`000?oooooooooo04Kooooo
1?lco`0Sooooo`03o`3oI_oooooooooo03Cooooo00?o0000ooooooooool0=oooool00ol0003ooooo
ooooo`0Iooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0:_ooool2o`0002;ooooo00?o0000ooooooooool0@?oo
ool5oc?o02Gooooo0_l0ofHhooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool06Ooo
ool00006oooooomgMgOoV9RHoooooonHV9SoMgMg3?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo02Oooooo0ol0000Uooooo`;o0000>_ooool6oc?o02Sooooo0_l0ofHkooooo`03o`00
0?oooooooooo03Kooooo00?o0000ooooooooool06?ooool00006ooooooo^k^ko<S8bo`000?lb<S;o
k^k^3?ooool4o`0000Gooooo0_l0000Uooooo`?o0000:_ooool00ol0003oooooooooo`0dooooo`?o
<ol0;Oooool00ol0ofKoooooooooo`0looooo`03o`000?oooooooooo03Kooooo00?o0000oooooooo
ool05oooool001_ooooo00?o0000ooooooooool08Oooool3o`0002kooooo00?o0000ooooooooool0
HOooool2o`3oIT3ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Gooooo`006ooo
ool00ol0003oooooooooo`0Nooooo`?o0000<_ooool00ol0003oooooooooo`1Mooooo`?o0?mV@_oo
ool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo01Kooooo000Kooooo`03o`000?oooooo
oooo01_ooooo0ol0000fooooo`03o`000?oooooooooo05[ooooo0_l0ofI6ooooo`03o`000?oooooo
oooo03Kooooo00?o0000ooooooooool05Oooool001[ooooo00?o0000ooooooooool06_ooool2o`00
03[ooooo00?o0000ooooooooool0E_ooool3o`3oIQWooooo0_l0ool^ooooo`03o`000?oooooooooo
03Kooooo00?o0000ooooooooool05?ooool001[ooooo0_l0000Hooooo`?o0000?Oooool00ol0003o
ooooooooo`1Cooooo`;o0?mV6_ooool2o`3ooc7ooooo00?o0000ooooooooool0=Oooool00ol0003o
ooooooooo`0Dooooo`006_ooool00ol0003oooooooooo`0Dooooo`?o0000@Oooool00ol0003ooooo
ooooo`1@ooooo`;o0?mV6oooool00ol0ooooooooooooo`0aooooo`03o`000?oooooooooo03Kooooo
00?o0000ooooooooool04oooool001[ooooo00?o0000ooooooooool04Oooool3o`0004Gooooo00?o
0000ooooooooool0C?ooool3o`3oIQ_ooooo0_l0ooleooooo`03o`000?oooooooooo03Kooooo00?o
0000ooooooooool04_ooool001[ooooo00?o0000ooooooooool03_ooool3o`0004Wooooo00?o0000
ooooooooool0Aoooool4o`3oIQgooooo00?o0?ooooooooooool0=_ooool00ol0003oooooooooo`0e
ooooo`;o00004oooool001[ooooo00?o0000ooooooooool03?ooool2o`0004gooooo00?o0000oooo
ooooool0@oooool3o`3oIR3ooooo00?o0?ooooooooooool0>?ooool00ol0003oooooooooo`0doooo
o`;o00004oooool001Wooooo0ol0000:ooooo`?o0000D?ooool00ol0003oooooooooo`0mooooo`Go
0?mV8_ooool00ol0ooooooooooooo`0jooooo`03o`000?oooooooooo03Gooooo00?o0000oooooooo
ool04?ooool001[ooooo00?o0000ooooooooool01_ooool3o`0005Cooooo00?o0000ooooooooool0
=_ooool6o`3oIRGooooo0_l0oolmooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0
3oooool001Wooooo00?o0000ooooooooool01?ooool3o`0005Sooooo00?o0000ooooooooool0:ooo
ool:o`3oIRSooooo0ol0oolBooooo`;o06Ko;?ooool00ol0003oooooooooo`0eooooo`03o`000?oo
oooooooo00oooooo000Iooooo`04o`000?ooooooooooooooo`?o0000G?ooool00ol0003ooooooooo
o`1Jooooo`;o0?oo5?ooool00ol0I_ooooooooooo`0]ooooo`03o`000?oooooooooo03Gooooo00?o
0000ooooooooool03_ooool001Wooooo1?l0001Pooooo`03o`000?oooooooooo05Oooooo0_l0oolE
ooooo`03o`1Voooooooooooo02oooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0=
ooooo`006Oooool2o`0006?ooooo00?o0000ooooooooool0Doooool3o`3ooaKooooo00?o06Kooooo
ooooool0<Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00gooooo000?ooooo`Co
000000?o410@ooooooooool01Oooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo053o
oooo0_l0oolGooooo`;o06Ko=?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00co
oooo000Aooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0HOooool00ol0003ooooo
ooooo`1=ooooo`;o0?oo6?ooool00ol0I_ooooooooooo`0eooooo`03o`000?oooooooooo03Gooooo
00?o0000ooooooooool02oooool0017ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`1Qooooo`03o`000?oooooooooo04Wooooo0ol0oolHooooo`;o06Ko>Oooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo00[ooooo000Aooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool0HOooool00ol0003oooooooooo`15ooooo`?o0?oo6_ooool00ol0I_ooooooooooo`0=
ooooo`;o<`3o:oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00[ooooo000Aoooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`11oooo
o`?o0?oo6oooool2o`1Vo`oooooo00?o<`3oooooooooool0;?ooool00ol0003oooooooooo`0doooo
o`03o`000?oooooooooo00Wooooo000Aooooo`03o`000?oooooooooo00cooooo0_l0001Rooooo`03
o`000?oooooooooo03cooooo1?l0oolKooooo`?o06Ko3oooool2oc<0oboooooo00?o0000oooooooo
ool0<oooool3o`0000[ooooo000Aooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
H?ooool00ol0003oooooooooo`0eooooo`Ko0?oo7?ooool3o`1Voa7ooooo00?o<`3oooooooooool0
<?ooool00ol0003oooooooooo`0_ooooo`?o00000_ooool00ol0003oooooooooo`08ooooo`003ooo
ool00omEEEGoIVIVo`00000Aooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0;?oo
ool8o`3oob3ooooo0_l0I_lBooooo`;o<`3o=?ooool00ol0003oooooooooo`0[ooooo`?o00001Ooo
ool00ol0003oooooooooo`08ooooo`009?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo023ooooo2ol0oolUooooo`?o06Ko4_ooool2oc<0ocOooooo00?o0000ooooooooool09_ooool4
o`0000Sooooo00?o0000ooooooooool02?ooool002Gooooo00?o0000ooooooooool0H?ooool00ol0
003oooooooooo`1<ooooo`?o06Ko5?ooool00olc0?ooooooooooo`0;ooooo`;oc03o:oooool00ol0
003oooooooooo`0Rooooo`?o00003?ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003o
ooooooooo`1Pooooo`03o`000?oooooooooo04Wooooo0_l0I_lEooooo`;o<`3o3Oooool00oo<0?oo
ooooooooo`0[ooooo`03o`000?oooooooooo01oooooo0ol0000@ooooo`03o`000?oooooooooo00Oo
oooo000Wooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0AOooool3o`1VoaGooooo
0_lc0?l>ooooo`03ol`0oooooooooooo02gooooo00?o0000ooooooooool06_ooool4o`0001?ooooo
00?o0000ooooooooool01oooool002Sooooo0_l0001Qooooo`03o`000?oooooooooo047ooooo0ol0
I_lFooooo`;o<`3o3oooool00oo<0?ooooooooooo`0_ooooo`03o`000?oooooooooo01Kooooo0ol0
000Gooooo`03o`000?oooooooooo00Oooooo000Zooooo`03o`000?oooooooooo05oooooo00?o0000
ooooooooool0??ooool4o`1VoaOooooo0_lc0?l@ooooo`03ol`0oooooooooooo037ooooo00?o0000
ooooooooool04_ooool3o`0001[ooooo00?o0000ooooooooool01oooool002_ooooo00?o0000oooo
ooooool0Goooool00ol0003oooooooooo`0fooooo`Go06Ko6Oooool2oc<0oa3ooooo0_o<0?leoooo
o`03o`000?oooooooooo00gooooo1?l0000Mooooo`03o`000?oooooooooo00Oooooo000/ooooo`03
o`000?oooooooooo05oooooo00?o0000ooooooooool0<Oooool4o`1Voacooooo0_lc0?l@ooooo`;o
c03o=oooool00ol0003oooooooooo`0:ooooo`?o00008Oooool00ol0003oooooooooo`07ooooo`00
;Oooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo02_ooooo1Ol0I_lMooooo`?o<`3o
4?ooool2ol`0o`gooooo0_oo09T[ooooo`03o`000?oooooooooo00Kooooo0ol0000Tooooo`03o`00
0?oooooooooo00Oooooo000^ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool09?oo
ool6o`1Voaoooooo0olc0?lAooooo`;oc03o3Oooool2ool0VBkooooo00Co0000oooooooooooooooo
1?l0000Wooooo`03o`000?oooooooooo00Oooooo000_ooooo`;o0000H?ooool00ol0003ooooooooo
o`0Fooooo`go06Ko8Oooool4oc<0oa;ooooo0_o<0?l>ooooo`03ool0VOoooooooooo02oooooo0ol0
000/ooooo`03o`000?oooooooooo00Kooooo000aooooo`03o`000?oooooooooo05kooooo0_l00011
ooooo`?o<`3o5?ooool2ol`0o`kooooo0_oo09T_ooooo`?o000000?oooooo`000?ooool0;?ooool0
0ol0003oooooooooo`06ooooo`00<_ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo
03_ooooo0olc0?lDooooo`?oc03o3_ooool2ool0VBkooooo0ol00004ooooo`03o`000?oooooooooo
02_ooooo00?o0000ooooooooool01_ooool003?ooooo00?o0000ooooooooool0Goooool00ol0003o
ooooooooo`0gooooo`?o<`3o5Oooool2ol`0oa3ooooo00?oo`2Iooooooooool0:_ooool4o`0000So
oooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`06ooooo`00=?ooool00ol0003ooooo
ooooo`1Oooooo`03o`000?oooooooooo03?ooooo0olc0?lFooooo`;oc03o4?ooool2ool0V@gooooo
0_oo000Kooooo`?o00003Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00Kooooo
000eooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool0;oooool3oc<0oaOooooo0_o<
0?l@ooooo`;oo`2I3_ooool00ooo003oooooooooo`0Hooooo`?o00004Oooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo00Kooooo000fooooo`03o`000?oooooooooo05oooooo00?o0000
ooooooooool09oooool7oc<0oaOooooo0oo<0?lAooooo`03ool0VOoooooooooo00cooooo0_oo000G
ooooo`Co00005Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Kooooo000goooo
o`;o0000H?ooool00ol0003oooooooooo`0Looooo`[o<`3o7?ooool2ol`0oa;ooooo0_oo09T=oooo
o`;oo`005_ooool3o`0001Wooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`06oooo
o`00>Oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo01;ooooo2Olc0?lSooooo`?o
c03o4_ooool2ool0V@kooooo00?oo`00ooooooooool04oooool3o`0001gooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`05ooooo`00>_ooool00ol0003oooooooooo`1Nooooo`03o`00
0?oooooooooo00gooooo1?lc0?lYooooo`?oc03o4_ooool3ool0V@kooooo0_oo000Booooo`Co0000
8Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Gooooo000kooooo`03o`000?oo
oooooooo05kooooo00?o0000ooooooooool0=_ooool3ol`0oa?ooooo0_oo09T?ooooo`;oo`004Ooo
ool3o`0002Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`05ooooo`00??ooool0
0ol0003oooooooooo`1Nooooo`03o`000?oooooooooo037ooooo1?o<0?lCooooo`?oo`2I3_ooool3
ool0013ooooo0ol0000Yooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool01Oooool0
03gooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0[ooooo`Goc03o5?ooool3ool0
V@oooooo0_oo000?ooooo`Co0000;Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
00Gooooo000nooooo`;o0000Goooool00ol0003oooooooooo`0Tooooo`Koc03o5_ooool3ool0VA3o
oooo0_oo000>ooooo`?o0000<_ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00Go
oooo0010ooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool07_ooool5ol`0oaWooooo
0ooo09TAooooo`;oo`003Oooool3o`0003Kooooo00?o0000ooooooooool08_ooool00ol0003ooooo
ooooo`05ooooo`00@Oooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo01Gooooo2?o<
0?lKooooo`?oo`2I4_ooool2ool000_ooooo1?l0000jooooo`03o`000?oooooooooo027ooooo00?o
0000ooooooooool01Oooool004;ooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`0;
ooooo`Woc03o8?ooool3ool0VACooooo00?oo`00ooooooooool02?ooool3o`0003kooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`05ooooo`00@oooool00ol0003oooooooooo`1Moooo
o`03o`000?oooooooooo00Gooooo1Oo<0?lVooooo`?oo`2I5Oooool2ool000Sooooo0ol00012oooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool01?ooool004Cooooo00?o0000oooooooo
ool0GOooool00ol0003oooooooooo`0/ooooo`?oo`2I5Oooool3ool000Kooooo1?l00016ooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool01?ooool004Gooooo00?o0000ooooooooool0
GOooool00ol0003oooooooooo`0Vooooo`Goo`2I5?ooool4ool000Kooooo0ol0001;ooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool01?ooool004Kooooo0_l0001Nooooo`03o`000?oo
oooooooo01oooooo1_oo09TFooooo`?oo`001oooool3o`0004oooooo00?o0000ooooooooool07_oo
ool00ol0003oooooooooo`04ooooo`00B?ooool00ol0003oooooooooo`1Looooo`03o`000?oooooo
oooo01Wooooo1Ooo09TIooooo`?oo`001_ooool4o`0005;ooooo00?o0000ooooooooool07_ooool0
0ol0003oooooooooo`04ooooo`00BOooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo
01;ooooo1_oo09TKooooo`?oo`001_ooool3o`0005Oooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`04ooooo`00B_ooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo00co
oooo1Ooo09TOooooo`;oo`001_ooool3o`0005_ooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`04ooooo`00Boooool00ol0003oooooooooo`1Looooo`03o`000?oo09Woo`2I00_oo`2I
8Oooool3ool000Cooooo1?l0001Oooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
1?ooool004cooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`0Wooooo`Coo`001?oo
ool3o`0006Cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`03ooooo`00COooool2
o`0005gooooo00?o0000ooooooooool08?ooool6ool000Gooooo0ol0001Wooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool00oooool004oooooo00?o0000ooooooooool0Foooool00ol0
003oooooooooo`0Iooooo`Koo`002?ooool3o`0006_ooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`03ooooo`00D?ooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo01?o
oooo1Ooo000:ooooo`Co0000Koooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00?o
oooo001Aooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool03?ooool6ool000cooooo
0ol0001dooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool00oooool005;ooooo00?o
0000ooooooooool0Foooool00ol0003oooooooooo`06ooooo`Goo`003oooool3o`0007Sooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`03ooooo`00Doooool00ol0003oooooooooo`1F
ooooo`goo`004?ooool4o`0007_ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`03
ooooo`00E?ooool2o`0005cooooo00?o0000ooooooooool04Oooool3o`00083ooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`03ooooo`00E_ooool00ol0003oooooooooo`1Jooooo`03
o`000?oooooooooo00gooooo0ol00024ooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool00_ooool005Oooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`08ooooo`Co0000
R?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00;ooooo001Hooooo`03o`000?oo
oooooooo05[ooooo00?o0000ooooooooool01?ooool3o`0008gooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`02ooooo`00FOooool00ol0003oooooooooo`1Jooooo`03o`000?oooooo
oooo00?o0000T?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00;ooooo001Joooo
o`03o`000?oooooooooo05[ooooo0_l0002Dooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool00_ooool005_ooooo00?o0000ooooooooool0FOooool00ol0003oooooooooo`2Dooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool00_ooool005cooooo0_l0001Iooooo`03o`00
0?oooooooooo09Gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`02ooooo`00G_oo
ool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo09Kooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`02ooooo`00Goooool00ol0003oooooooooo`1Eooooo`03o`000?oooooo
oooo09Kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`01ooooo`00H?ooool00ol0
003oooooooooo`1Dooooo`03o`000?oooooooooo09Oooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`01ooooo`00HOooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo09So
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`01ooooo`00H_ooool00ol0003ooooo
ooooo`1Booooo`03o`000?oooooooooo09Wooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`01ooooo`00Hoooool2o`0005;ooooo00?o0000ooooooooool0V_ooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo007ooooo001Uooooo`03o`000?oooooooooo04oooooo00?o0000
ooooooooool0V_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo007ooooo001Voooo
o`03o`000?oooooooooo04kooooo00?o0000ooooooooool0Voooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo007ooooo001Wooooo`03o`000?oooooooooo04gooooo00?o0000oooooooo
ool0W?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo007ooooo001Xooooo`03o`00
0?oooooooooo04cooooo00?o0000ooooooooool0WOooool00ol0003oooooooooo`0;ooooo`7o0000
0Oooool1ooooo`00JOooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo09gooooo00?o
0000ooooooooool02oooool1o`00007ooooo0Oooool006[ooooo00?o0000ooooooooool0B_ooool0
0ol0003oooooooooo`2Nooooo`03o`000?oooooooooo00[ooooo0Ol00001ooooo`7ooooo001[oooo
o`;o0000B_ooool00ol0003oooooooooo`2Oooooo`03o`000?oooooooooo00Wooooo0Ol00001oooo
o`7ooooo001]ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0X?ooool00ol0003o
ooooooooo`08ooooo`7o00000Oooool1ooooo`00K_ooool00ol0003oooooooooo`16ooooo`03o`00
0?oooooooooo0:7ooooo00?o0000ooooooooool01oooool1o`00007ooooo0Oooool006oooooo00?o
0000ooooooooool0AOooool00ol0003oooooooooo`2Qooooo`03o`000?oooooooooo00Oooooo0Ol0
0001ooooo`7ooooo001`ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0X_ooool0
0ol0003oooooooooo`06ooooo`7o00000Oooool1ooooo`00LOooool00ol0003oooooooooo`13oooo
o`03o`000?oooooooooo0:?ooooo00?o0000ooooooooool01Oooool1o`00007ooooo0Oooool007;o
oooo0_l00012ooooo`03o`000?oooooooooo0:Gooooo00?o0000ooooooooool01Oooool1o`00007o
oooo001dooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0Y_ooool00ol0003ooooo
ooooo`04ooooo`7o00000Oooool007Gooooo00?o0000ooooooooool0?_ooool00ol0003ooooooooo
o`2Vooooo`03o`000?oooooooooo00Cooooo0Ol00001ooooo`00M_ooool00ol0003oooooooooo`0m
ooooo`03o`000?oooooooooo0:Oooooo00?o0000ooooooooool00oooool1o`00007ooooo001goooo
o`03o`000?oooooooooo03cooooo00?o0000ooooooooool0Z?ooool00ol0003oooooooooo`02oooo
o`7o00000Oooool007Sooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`2Yooooo`05
o`000?ooooooooooooooool000000Oooool007Wooooo00?o0000ooooooooool0>_ooool00ol0003o
ooooooooo`2Zooooo`04o`000?ooooooooooo`00007ooooo001jooooo`;o0000>_ooool00ol0003o
ooooooooo`2Zooooo`04o`000?ooooooooooo`00007ooooo001looooo`03o`000?oooooooooo03Oo
oooo00?o0000ooooooooool0Zoooool00ol0003oooooooooo`01o`000000OOooool00ol0003ooooo
ooooo`0fooooo`03o`000?oooooooooo0:cooooo0Ol00001ooooo`7o0000001nooooo`03o`000?oo
oooooooo03Gooooo00?o0000ooooooooool0[Oooool2o`000000Ooooool00ol0003oooooooooo`0d
ooooo`03o`000?oooooooooo0:cooooo0ol00000083ooooo00?o0000ooooooooool0<oooool00ol0
003oooooooooo`2Xooooo`Co00000oooool0087ooooo0_l0000cooooo`03o`000?oooooooooo0:Go
oooo0ol00007ooooo`00Poooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo0:7ooooo
1?l0000:ooooo`00Q?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo09gooooo1?l0
000>ooooo`00QOooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo09Wooooo1?l0000B
ooooo`00Q_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo09Gooooo1?l0000Foooo
o`00Qoooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo09;ooooo0ol0000Jooooo`00
R?ooool2o`0002cooooo00?o0000ooooooooool0S_ooool4o`0001gooooo002:ooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool0R_ooool4o`00027ooooo002;ooooo`03o`000?oooooo
oooo02Sooooo00?o0000ooooooooool0Q_ooool4o`0002Gooooo002<ooooo`03o`000?oooooooooo
02Oooooo00?o0000ooooooooool0P_ooool4o`0002Wooooo002=ooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool0Ooooool3o`0002gooooo002>ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool0Noooool4o`00033ooooo002?ooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool0Moooool4o`0003Cooooo002@ooooo`;o00009?ooool00ol0003oooooooooo`1c
ooooo`Co0000>?ooool009;ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`1`oooo
o`?o0000??ooool009?ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1/ooooo`Co
0000?oooool009Cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`1Xooooo`Co0000
@oooool009Gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1Tooooo`Co0000Aooo
ool009Kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1Pooooo`Co0000Boooool0
09Oooooo0_l0000Mooooo`03o`000?oooooooooo05gooooo0ol0001?ooooo`00VOooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo05Wooooo1?l0001Booooo`00V_ooool00ol0003ooooo
ooooo`0Iooooo`03o`000?oooooooooo05Gooooo1?l0001Fooooo`00Voooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo057ooooo1?l0001Jooooo`00W?ooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo04gooooo1?l0001Nooooo`00WOooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo04[ooooo0ol0001Rooooo`00W_ooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo04Kooooo1?l0001Uooooo`00Woooool2o`0001Cooooo00?o0000ooooooooool0
@oooool4o`0006Wooooo002Qooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0?ooo
ool4o`0006gooooo002Rooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0>oooool4
o`00077ooooo002Sooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0>?ooool3o`00
07Gooooo002Tooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0=?ooool4o`0007So
oooo002Uooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0<?ooool4o`0007cooooo
002Vooooo`;o00003Oooool00ol0003oooooooooo`0/ooooo`Co0000P?ooool00:Sooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0Yooooo`?o0000Q?ooool00:Wooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0Uooooo`Co0000Qoooool00:[ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`0Qooooo`Co0000Roooool00:_ooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`0Mooooo`Co0000Soooool00:cooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`0Iooooo`Co0000Toooool00:gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Fooooo`?o0000Uoooool00:kooooo0_l00005ooooo`03o`000?oooooooooo
01;ooooo1?l0002Jooooo`00/?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00ko
oooo1?l0002Nooooo`00/Oooool01Ol0003ooooooooooooooooo000000cooooo1?l0002Rooooo`00
/_ooool01?l0003oooooooooool00008ooooo`Co0000Y_ooool00;?ooooo00?o0000ooooool00000
1Oooool3o`000:[ooooo002dooooo`;o000000?oooooo`000?l000000_l0002]ooooo`00]Oooool2
o`000;7ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {319.688, 0}} -> {-0.0710364, -0.0181728, \
0.0035149, 0.0035149}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .89104 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-16 1.0656 -0.0363427 1.0656 [
[.02544 .21571 -12 -8.9133 ]
[.02544 .21571 0 .0867 ]
[.16074 .16277 -11.6592 -9 ]
[.16074 .16277 .34081 0 ]
[.3021 .10747 -5.60025 -9 ]
[.3021 .10747 .39975 0 ]
[.44992 .04965 -5.37091 -9 ]
[.44992 .04965 .62909 0 ]
[.60467 -0.01084 -5.14157 -9 ]
[.60467 -0.01084 .85843 0 ]
[.66454 .05085 0 -6.20675 ]
[.66454 .05085 6 2.79325 ]
[.80797 .25198 0 -6.0417 ]
[.80797 .25198 6 2.9583 ]
[.93071 .4241 0 -5.90576 ]
[.93071 .4241 6 3.09424 ]
[.02254 .22988 -12 -2.74631 ]
[.02254 .22988 0 6.25369 ]
[.0142 .29178 -24 -2.78907 ]
[.0142 .29178 0 6.21093 ]
[.00558 .35578 -6 -2.83339 ]
[.00558 .35578 0 6.16661 ]
[-0.00334 .42198 -18 -2.87938 ]
[-0.00334 .42198 0 6.12062 ]
[-0.01257 .49051 -6 -2.92712 ]
[-0.01257 .49051 0 6.07288 ]
[ 0 0 0 0 ]
[ 1 .89104 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03495 .22504 m
.61241 0 L
s
.03495 .22504 m
.03971 .2297 L
s
[(-2)] .02544 .21571 1 .98073 Mshowa
.16988 .17246 m
.17445 .1773 L
s
[(-1)] .16074 .16277 .9432 1 Mshowa
.31082 .11753 m
.31518 .12256 L
s
[(0)] .3021 .10747 .86675 1 Mshowa
.45818 .0601 m
.46231 .06533 L
s
[(1)] .44992 .04965 .7903 1 Mshowa
.61241 0 m
.61628 .00542 L
s
[(2)] .60467 -0.01084 .71386 1 Mshowa
.125 Mabswid
.06148 .2147 m
.06431 .21752 L
s
.08823 .20428 m
.09104 .20712 L
s
.11521 .19376 m
.118 .19663 L
s
.14243 .18316 m
.14519 .18604 L
s
.19758 .16166 m
.20029 .16459 L
s
.22551 .15078 m
.22821 .15373 L
s
.2537 .13979 m
.25637 .14277 L
s
.28213 .12871 m
.28478 .13171 L
s
.33977 .10625 m
.34236 .10929 L
s
.36897 .09487 m
.37153 .09794 L
s
.39844 .08339 m
.40097 .08648 L
s
.42817 .0718 m
.43068 .07491 L
s
.48846 .0483 m
.49091 .05146 L
s
.51902 .03639 m
.52144 .03958 L
s
.54986 .02437 m
.55225 .02758 L
s
.58099 .01224 m
.58335 .01547 L
s
.25 Mabswid
.61241 0 m
.97291 .505 L
s
.65208 .05558 m
.64586 .05794 L
s
[(0)] .66454 .05085 -1 .37928 Mshowa
.79537 .2563 m
.78907 .25846 L
s
[(2)] .80797 .25198 -1 .3426 Mshowa
.91799 .42808 m
.91164 .43006 L
s
[(4)] .93071 .4241 -1 .31239 Mshowa
.125 Mabswid
.69012 .10886 m
.68637 .11025 L
s
.72662 .16 m
.72286 .16135 L
s
.76168 .2091 m
.75791 .21042 L
s
.82778 .3017 m
.82399 .30297 L
s
.85897 .3454 m
.85518 .34664 L
s
.88903 .3875 m
.88522 .38871 L
s
.94594 .46722 m
.94211 .46839 L
s
.25 Mabswid
.03495 .22504 m
0 .48612 L
s
.03495 .22504 m
.04116 .22262 L
s
[(-1)] .02254 .22988 1 -0.38971 Mshowa
.02665 .28704 m
.03288 .28468 L
s
[(-0.5)] .0142 .29178 1 -0.38021 Mshowa
.01807 .35115 m
.02431 .34884 L
s
[(0)] .00558 .35578 1 -0.37036 Mshowa
.00919 .41747 m
.01546 .41521 L
s
[(0.5)] -0.00334 .42198 1 -0.36014 Mshowa
0 .48612 m
.00629 .48392 L
s
[(1)] -0.01257 .49051 1 -0.34953 Mshowa
.125 Mabswid
.03331 .23728 m
.03704 .23583 L
s
.03166 .2496 m
.03539 .24816 L
s
.03 .262 m
.03373 .26056 L
s
.02833 .27448 m
.03207 .27305 L
s
.02496 .29969 m
.0287 .29828 L
s
.02325 .31243 m
.02699 .31102 L
s
.02154 .32525 m
.02528 .32385 L
s
.01981 .33816 m
.02355 .33676 L
s
.01632 .36423 m
.02007 .36285 L
s
.01455 .37741 m
.01831 .37603 L
s
.01278 .39067 m
.01653 .3893 L
s
.01099 .40402 m
.01475 .40266 L
s
.00738 .43101 m
.01114 .42966 L
s
.00555 .44464 m
.00932 .4433 L
s
.00371 .45837 m
.00748 .45704 L
s
.00186 .4722 m
.00563 .47087 L
s
.25 Mabswid
.03495 .22504 m
0 .48612 L
s
0 .48612 m
.46953 .89104 L
s
.46953 .89104 m
.47294 .65459 L
s
.47294 .65459 m
.03495 .22504 L
s
.61241 0 m
.97291 .505 L
s
.97291 .505 m
1 .75117 L
s
1 .75117 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.03495 .22504 m
0 .48612 L
s
0 .48612 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.61241 0 m
.03495 .22504 L
s
.47294 .65459 m
.97291 .505 L
s
.97291 .505 m
1 .75117 L
s
1 .75117 m
.46953 .89104 L
s
.46953 .89104 m
.47294 .65459 L
s
0 0 m
1 0 L
1 .89104 L
0 .89104 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.44401 .65514 m
.4779 .65266 L
s
1 0 .6 r
.44262 .63408 m
.47513 .63169 L
s
1 0 0 r
.4779 .65266 m
.51341 .64815 L
s
.8 0 1 r
.44125 .61288 m
.47234 .61061 L
s
1 0 .6 r
.47513 .63169 m
.50928 .62732 L
s
.8 0 1 r
.47234 .61061 m
.50512 .6064 L
s
1 0 0 r
.51341 .64815 m
.54937 .64163 L
s
.2 0 1 r
.4399 .59139 m
.46953 .5893 L
s
1 0 .6 r
.50928 .62732 m
.54393 .62096 L
s
.2 0 1 r
.46953 .5893 m
.50091 .58528 L
s
0 .4 1 r
.43862 .56927 m
.46666 .56746 L
s
.8 0 1 r
.50512 .6064 m
.53847 .60023 L
s
0 .4 1 r
.46666 .56746 m
.49656 .56373 L
s
.2 0 1 r
.50091 .58528 m
.53293 .57934 L
s
1 0 0 r
.54937 .64163 m
.58496 .63316 L
s
0 1 1 r
.43746 .54584 m
.46367 .54443 L
s
1 0 .6 r
.54393 .62096 m
.57827 .61271 L
s
0 .4 1 r
.49656 .56373 m
.52719 .55807 L
s
0 1 1 r
.46367 .54443 m
.49188 .54113 L
s
.8 0 1 r
.53847 .60023 m
.57155 .59219 L
s
.2 0 1 r
.53293 .57934 m
.56474 .57154 L
s
0 1 1 r
.49188 .54113 m
.52097 .53587 L
s
0 .4 1 r
.52719 .55807 m
.55768 .55056 L
s
0 1 .4 r
.43657 .51976 m
.46045 .51883 L
s
1 0 0 r
.58496 .63316 m
.61959 .62286 L
s
0 1 .4 r
.46045 .51883 m
.48648 .51613 L
s
1 0 .6 r
.57827 .61271 m
.61169 .60266 L
s
0 1 1 r
.52097 .53587 m
.54998 .52874 L
s
0 1 .4 r
.48648 .51613 m
.51357 .51146 L
s
.8 0 1 r
.57155 .59219 m
.60375 .5824 L
s
.2 0 1 r
.56474 .57154 m
.59569 .56203 L
s
0 .4 1 r
.55768 .55056 m
.58732 .54134 L
s
0 1 .4 r
.51357 .51146 m
.54071 .50486 L
s
0 1 1 r
.54998 .52874 m
.57815 .51988 L
s
.2 1 0 r
.43581 .48913 m
.4567 .48839 L
s
1 0 0 r
.61959 .62286 m
.65274 .61085 L
s
.2 1 0 r
.4567 .48839 m
.47961 .4862 L
s
1 0 .6 r
.61169 .60266 m
.64364 .59095 L
s
.8 0 1 r
.60375 .5824 m
.63448 .571 L
s
.2 1 0 r
.47961 .4862 m
.5037 .48223 L
s
0 1 .4 r
.54071 .50486 m
.56699 .49649 L
s
.2 0 1 r
.59569 .56203 m
.62518 .55095 L
s
0 .4 1 r
.58732 .54134 m
.61549 .53059 L
s
.2 1 0 r
.5037 .48223 m
.52795 .4764 L
s
0 1 1 r
.57815 .51988 m
.60479 .50948 L
s
0 1 .4 r
.56699 .49649 m
.59163 .48657 L
s
.2 1 0 r
.52795 .4764 m
.55139 .46882 L
s
1 0 0 r
.65274 .61085 m
.68383 .59731 L
s
1 0 .6 r
.64364 .59095 m
.67353 .57777 L
s
.8 0 1 r
.63448 .571 m
.66316 .5582 L
s
.2 0 1 r
.62518 .55095 m
.65259 .53851 L
s
.8 1 0 r
.4331 .45373 m
.45096 .45229 L
s
0 .4 1 r
.61549 .53059 m
.64151 .51854 L
s
.8 1 0 r
.45096 .45229 m
.47007 .44989 L
s
0 1 1 r
.60479 .50948 m
.62916 .49783 L
s
.8 1 0 r
.47007 .44989 m
.48998 .44625 L
s
.2 1 0 r
.55139 .46882 m
.57314 .45975 L
s
0 1 .4 r
.59163 .48657 m
.61384 .47545 L
s
.8 1 0 r
.48998 .44625 m
.51002 .44121 L
s
1 0 0 r
.68383 .59731 m
.71214 .58256 L
s
1 0 .6 r
.67353 .57777 m
.70064 .56346 L
s
.8 0 1 r
.66316 .5582 m
.68905 .54433 L
s
.2 0 1 r
.65259 .53851 m
.67719 .52509 L
s
.8 1 0 r
.51002 .44121 m
.52943 .43482 L
s
0 .4 1 r
.64151 .51854 m
.66465 .50556 L
s
.2 1 0 r
.57314 .45975 m
.59242 .44962 L
s
0 1 1 r
.62916 .49783 m
.65052 .48534 L
s
1 .6 0 r
.42529 .41821 m
.44101 .4154 L
s
0 1 .4 r
.61384 .47545 m
.63288 .46361 L
s
1 .6 0 r
.44101 .4154 m
.45712 .41213 L
s
.8 1 0 r
.52943 .43482 m
.54751 .42728 L
s
1 .6 0 r
.45712 .41213 m
.47346 .40823 L
s
.2 1 0 r
.59242 .44962 m
.60872 .43898 L
s
1 .6 0 r
.47346 .40823 m
.48975 .40361 L
s
.2 0 1 r
.67719 .52509 m
.69821 .51124 L
s
0 .4 1 r
.66465 .50556 m
.68416 .49225 L
s
.8 0 1 r
.68905 .54433 m
.71137 .52996 L
s
.8 1 0 r
.54751 .42728 m
.56375 .41896 L
s
1 0 .6 r
.70064 .56346 m
.72417 .54858 L
s
0 1 1 r
.65052 .48534 m
.66817 .47264 L
s
1 0 0 r
.71214 .58256 m
.73683 .56717 L
s
0 1 .4 r
.63288 .46361 m
.64826 .45174 L
s
1 .6 0 r
.48975 .40361 m
.50568 .39826 L
s
.2 1 0 r
.60872 .43898 m
.6219 .42847 L
s
.8 1 0 r
.56375 .41896 m
.57794 .41029 L
s
1 .6 0 r
.50568 .39826 m
.52094 .39226 L
s
.52094 .39226 m
.53536 .3858 L
s
.8 1 0 r
.57794 .41029 m
.59019 .40166 L
s
1 .6 0 r
.53536 .3858 m
.54891 .37905 L
s
.54891 .37905 m
.56171 .37221 L
s
0 g
.25 Mabswid
.61241 0 m
.97291 .505 L
s
.97291 .505 m
1 .75117 L
s
1 .75117 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.03495 .22504 m
0 .48612 L
s
0 .48612 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.61241 0 m
.03495 .22504 L
s
.03495 .22504 m
.61241 0 L
s
.03495 .22504 m
.03971 .2297 L
s
[(-2)] .02544 .21571 1 .98073 Mshowa
.16988 .17246 m
.17445 .1773 L
s
[(-1)] .16074 .16277 .9432 1 Mshowa
.31082 .11753 m
.31518 .12256 L
s
[(0)] .3021 .10747 .86675 1 Mshowa
.45818 .0601 m
.46231 .06533 L
s
[(1)] .44992 .04965 .7903 1 Mshowa
.61241 0 m
.61628 .00542 L
s
[(2)] .60467 -0.01084 .71386 1 Mshowa
.125 Mabswid
.06148 .2147 m
.06431 .21752 L
s
.08823 .20428 m
.09104 .20712 L
s
.11521 .19376 m
.118 .19663 L
s
.14243 .18316 m
.14519 .18604 L
s
.19758 .16166 m
.20029 .16459 L
s
.22551 .15078 m
.22821 .15373 L
s
.2537 .13979 m
.25637 .14277 L
s
.28213 .12871 m
.28478 .13171 L
s
.33977 .10625 m
.34236 .10929 L
s
.36897 .09487 m
.37153 .09794 L
s
.39844 .08339 m
.40097 .08648 L
s
.42817 .0718 m
.43068 .07491 L
s
.48846 .0483 m
.49091 .05146 L
s
.51902 .03639 m
.52144 .03958 L
s
.54986 .02437 m
.55225 .02758 L
s
.58099 .01224 m
.58335 .01547 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 256.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001@2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00gOooool5o`0008Kooooo003Mooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0Q_ooool00=ko
oooo00?oV9RHob4Q8Oo^k^h0Qoooool00=oooooo00?oV9RHob4Q8Oo^k^h0Q_ooool00>3ooooo00?o
MgMgofIVI_ooool0QOooool00>7ooooo00?o0000ooooooooool0Q?ooool00=gooooo00Go0000okZj
^_ooooooV9RHoa0@4026ooooo`00gOooool01OnHV9So410@o`000?lQ8B7oc<c<08Kooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003Tooooo`;o0000P_ooool0
0>7ooooo0ol000000ooooooo0000ooooo`21ooooo`00goooool2o`0000Cooooo0_l00021ooooo`00
g?ooool3o`0000Kooooo00?o0000ooooool00000P?ooool00=[ooooo0_l00009ooooo`03o`000?oo
oooo0000083ooooo003Gooooo`?o000000?oooooo`000?ooool02?ooool01?l0003oooooooooool0
001oooooo`00e?ooool3o`0000Cooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooo
oooo000007kooooo003Booooo`;o00004Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo07_ooooo002Zooooo`Co000000?o410@ooooooooool07_ooool3o`0001?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1kooooo`00[?ooool00ol0003oooooooooo`0Nooooo`;o
000000?oooooo`000?ooool04oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07[o
oooo002/ooooo`03o`000?oooooooooo01_ooooo0ol00004ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`1iooooo`00[?ooool00ol0003ooooooooo
o`0Iooooo`;o00006oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo07Wooooo002/
ooooo`03o`000?oooooooooo01Kooooo0ol0000Mooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool02?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^06_ooooo002/ooooo`03o`000?oooooo
oooo01Cooooo0_l000000ooooooo0000ooooo`0Mooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01oooool01OmgMgOoV9RHoooooonHV9SoMgMg06_ooooo002/ooooo`03o`000?oooooo
oooo017ooooo0ol00004ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`06ooooo`05oa0@4?ooooooooooooooool@4100Joooool00:[ooooo00?oEEEE
ofIVI_l000004Oooool2o`0002Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06
ooooo`05o`000?ooooooooooooooool00000Joooool00;_ooooo0ol0000Wooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000006_ooooo002i
ooooo`;o000000?oooooo`000?ooool09oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Cooooo00Go410@oooooooooooooooooa0@401[ooooo`00]_ooool3o`0000Cooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`1[ooooo`00/oooool3o`0002oooooo00?o0000ooooooooool02Oooool2
o`0000Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1[ooooo`00/Oooool2o`0003;ooooo00?o0000
ooooooooool02?ooool01?l0003oooooooooool0001dooooo`00[_ooool3o`000003ooooool0003o
oooo037ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1aooooo`00[?ooool2o`00
00Gooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
077ooooo002Yooooo`?o0000>_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo073o
oooo002Wooooo`;o0000?Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo06oooooo
002Tooooo`?o000000?oooooo`000?ooool0??ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo06oooooo002Rooooo`;o0000@_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo06kooooo001gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08oooool3o`0004Cooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1]ooooo`00Moooool01OmgMgOoV9RHoooooonHV9So
MgMg027ooooo0_l00017ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0K?ooool0
07Oooooo00Go410@oooooooooooooooooa0@400Nooooo`?o00000_ooool00ol0003oooooooooo`14
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0K?ooool007Oooooo00Go0000oooo
ooooooooooooo`00000Looooo`;o0000C?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo06_ooooo001gooooo`05o`000?ooooooooooooooool000006Oooool3o`0004kooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`1Zooooo`00Moooool01Ol@413ooooooooooooooooo
410@01Kooooo0ol0001Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0J_ooool0
07Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Dooooo`;o00000oooool00ol0003oooooooooo`1>
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0JOooool007Oooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Aooooo`?o0000E_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo06Sooooo002;ooooo`;o0000FOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
06Sooooo0028ooooo`?o0000Foooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo06Oo
oooo0026ooooo`;o00000oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo01Gooooo
0_l0001Xooooo`00Poooool3o`00063ooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`1Uooooo`00POooool2o`0006?ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1U
ooooo`00O_ooool4o`0006Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`1Toooo
o`00O?ooool2o`0000Cooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo06?ooooo001iooooo`?o0000J_ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo06?ooooo001gooooo`;o0000KOooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo06;ooooo001dooooo`?o000000?oooooo`000?ooool0K?ooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo067ooooo001aooooo`?o0000L_ooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo063ooooo0019ooooo`Co000000?o410@ooooooooool07oooool2o`0007Go
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1Pooooo`00Boooool00ol0003ooooo
ooooo`0Nooooo`?o0000Moooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo05oooooo
0010ooooo`Ko00001Oooool00ol0003oooooooooo`0Looooo`;o00000_ooool00ol0003ooooooooo
o`1eooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0G_ooool004_ooooo00?o0000
ooooooooool06Oooool3o`0007cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1N
ooooo`00Boooool00ol0003oooooooooo`0Gooooo`;o0000Ooooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo05gooooo001;ooooo`03o`000?oooooooooo01Cooooo0ol00021ooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0G?ooool004_ooooo00?o0000ooooooooool0
4_ooool2o`0000?ooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo05_ooooo0019ooooo`03oeEEEOmVIVKo0000017ooooo0ol00026ooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool0Foooool005_ooooo0_l00029ooooo`03o`000?oooooo
oooo027ooooo0_l0001Looooo`00F?ooool3o`000003ooooool0003ooooo08Sooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`1Iooooo`00E_ooool2o`0008kooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`1Iooooo`00Doooool3o`00093ooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`1Hooooo`00D?ooool3o`0009?ooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1Gooooo`00C_ooool2o`0000;ooooo00?o0000ooooooooool0TOooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo05Kooooo001;ooooo`?o00001Oooool00ol0
003oooooooooo`2@ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0E_ooool004Wo
oooo0_l0002Kooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0EOooool004Kooooo
1?l0002Looooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0E?ooool004Cooooo0_l0
002Pooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0E?ooool001[ooooo1Ol0000R
ooooo`?o0000X_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo05?ooooo000Joooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@08?ooool2o`000:Gooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`1Booooo`004_ooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h07_ooool3o`00
0003ooooool0003ooooo0:Cooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`1Aoooo
o`007?ooool00onHV9So8B4Qonk^kP0Kooooo`;o0000Z_ooool00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo057ooooo000Mooooo`03ogMgMomVIVKooooo01Oooooo0ol0002]ooooo`03o`00
0?oooooooooo02_ooooo00?o0000ooooooooool0D?ooool001kooooo00?o0000ooooooooool05?oo
ool2o`000;3ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`1?ooooo`006_ooool0
1Ol0003o^[ZjoooooonHV9So410@01?ooooo0ol00002ooooo`03o`000?oooooooooo0:gooooo00?o
0000ooooooooool0;?ooool2o`00053ooooo000Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`04?oo
ool3o`000;Gooooo00?o0000ooooooooool0;?ooool2o`00053ooooo000]ooooo`;o0000^?ooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo04gooooo000Zooooo`?o000000?oooooo`00
0?ooool0]oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo04gooooo000Xooooo`;o
0000_Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo04cooooo000Uooooo`?o0000
_oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo04_ooooo000Tooooo`;o0000`Ooo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo04[ooooo000Jooooo`Co000000?o410@
ooooooooool00oooool00ol0003oooooo`000030ooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool0B_ooool001cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0002o
ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0BOooool0017ooooo1_l00005oooo
o`03o`000?oooooooooo00Gooooo0_l00002ooooo`03o`000?oooooooooo0;cooooo00?o0000oooo
ooooool0<oooool00ol0003oooooooooo`18ooooo`007?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0^oooool00ol0003oooooooooo`0cooooo`03
o`000?oooooooooo00Oooooo1Ol0000looooo`007?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo00Kooooo00GoV9RHob4Q8Oo^k^koooooodA4A00looooo`007?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00ol0003ooooo
ooooo`0eooooo`03o`000?oooooooooo00Kooooo00?oV9RHob4Q8Oo^k^h0?Oooool001cooooo00?o
0000ooooooooool01?ooool3o`0000Kooooo00?o0000ooooooooool0^?ooool00ol0003ooooooooo
o`0fooooo`03o`000?oooooooooo00Kooooo00?oV9RHob4Q8Oo^k^h0??ooool001[ooooo00?oEEEE
ofIVI_l000001_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;Oooooo00?o0000
ooooooooool0=_ooool00ol0003oooooooooo`07ooooo`03ogMgMomVIVKooooo03_ooooo000Soooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0]_ooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0>_ooool002?ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`2eooooo`03o`000?oooooooooo03Oooooo0_l00004ooooo`05
o`000?nj^[[ooooooiRHV?l@4100??ooool002?ooooo0_l0000;ooooo`03o`000?oooooooooo0;Co
oooo00?o0000ooooooooool0=_ooool00ol0003oooooo`000004ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`0??ooool002?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`2cooooo`03
o`000?oooooooooo03Wooooo00?o0000ooooooooool0@_ooool002;ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0
@Oooool002;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`2`ooooo`;o0000?Ooo
ool00ol0003oooooooooo`10ooooo`008_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo0:cooooo0ol000000ooooooo0000ooooo`0looooo`03o`000?oooooooooo043ooooo000Roooo
o`;o00004Oooool00ol0003oooooooooo`2Xooooo`?o00001Oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo03oooooo000Rooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool0Y?ooool3o`0000Wooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0nooooo`00
8_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo0:3ooooo0ol0000=ooooo`03o`00
0?oooooooooo03[ooooo00?o0000ooooooooool0?_ooool002;ooooo0ol0000Cooooo`03o`000?oo
oooooooo09cooooo0ol0000Aooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0?Ooo
ool002;ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`2Iooooo`;o00005?ooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo03cooooo000Qooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool0UOooool3o`0001Oooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`0kooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo097ooooo0ol0000Kooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0>oooool0
00Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0SOooool3o`0001oooooo00?o0000
ooooooooool0>_ooool00ol0003oooooooooo`0jooooo`001Ol00002ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`02ooooo`;o00006_ooool00ol0003oooooooooo`29
ooooo`?o00008oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03Wooooo0007oooo
o`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool0Q_ooool2o`0002Kooooo00?o0000ooooooooool0>_ooool2
o`0003[ooooo0007ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`22ooooo`?o0000:Ooo
ool00ol0003oooooooooo`0iooooo`;o0000>_ooool000Oooooo00Go410@oooooooooooooooooa0@
400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`1nooooo`?o0000;Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03Oooooo0007
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`;o00007_oo
ool00ol0003oooooooooo`1jooooo`?o0000<Oooool00ol0003oooooooooo`0iooooo`03o`000?oo
oooooooo03Oooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Cooooo0_l0
000Pooooo`03o`000?oooooooooo07Kooooo0ol0000eooooo`03o`000?oooooooooo03Wooooo00?o
0000ooooooooool0=_ooool0023ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1b
ooooo`?o0000>?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03Gooooo000Poooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool0Koooool2o`0003cooooo00?o0000oooo
ooooool0>_ooool00ol0003oooooooooo`0dooooo`008?ooool2o`0002?ooooo00?o0000oooooooo
ool0Joooool3o`0003oooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0dooooo`00
8?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo06Oooooo0ol00013ooooo`03o`00
0?oooooooooo03Wooooo00?o0000ooooooooool0<oooool0023ooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`1Sooooo`?o0000Aoooool00ol0003oooooooooo`0iooooo`03o`000?oo
oooooooo03;ooooo000Pooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0Goooool3
o`0004[ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0booooo`008?ooool00ol0
003oooooooooo`0Vooooo`;o0000GOooool2o`0004kooooo00?o0000ooooooooool0>Oooool00ol0
003oooooooooo`0aooooo`007oooool3o`0002Wooooo00?o0000ooooooooool0Eoooool3o`00057o
oooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0`ooooo`007oooool00ol0003ooooo
ooooo`0Zooooo`03o`000?oooooooooo05?ooooo0ol0001Eooooo`03o`000?oooooooooo03Wooooo
00?o0000ooooooooool0;oooool001oooooo00?o0000ooooooooool0:oooool00ol0003ooooooooo
o`1?ooooo`?o0000F?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02oooooo000O
ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0Boooool3o`0005cooooo00?o0000
ooooooooool0>?ooool2o`00033ooooo000Oooooo`?o0000;Oooool00ol0003oooooooooo`17oooo
o`?o0000H?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02gooooo000Oooooo`03
o`000?oooooooooo02kooooo00?o0000ooooooooool0A?ooool2o`0006Cooooo00?o0000oooooooo
ool0>?ooool00ol0003oooooooooo`0]ooooo`005?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Ko
oooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`10ooooo`?o0000Ioooool00ol0003o
ooooooooo`0hooooo`03o`000?oooooooooo02cooooo000Dooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo03cooooo0ol0001Zooooo`03
o`000?oooooooooo03Wooooo00?o0000ooooooooool0:oooool001Cooooo00Go410@oooooooooooo
oooooa0@4005ooooo`;o0000<oooool00ol0003oooooooooo`0hooooo`?o0000K_ooool00ol0003o
ooooooooo`0iooooo`03o`000?oooooooooo02[ooooo000Dooooo`05o`000?ooooooooooooooool0
00001Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo03Cooooo0ol0001booooo`03
o`000?oooooooooo03Sooooo00?o0000ooooooooool0:_ooool001Cooooo00Go0000oooooooooooo
ooooo`000005ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0<?ooool3o`0007Ko
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Yooooo`005?ooool01Ol@413ooooo
oooooooooooo410@00Gooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0]ooooo`;o
0000N_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02Sooooo000Dooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo02Wo
oooo0ol0001=ooooo`;ooiT0;Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02So
oooo000Dooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2o`0003Sooooo00?o0000oooooooo
ool09Oooool3o`0004kooooo0_ooV@0`ooooo`03o`000?oooooooooo03Sooooo00?o0000oooooooo
ool09oooool001kooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Qooooo`?o0000
Coooool2oonI03?ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Vooooo`007Ooo
ool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo01gooooo0ol0001?ooooo`?ooiT0=_oo
ool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02Gooooo000Mooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool06_ooool2o`00053ooooo0_ooV@0jooooo`03o`000?oooooo
oooo03Oooooo00?o0000ooooooooool09Oooool001gooooo0_l0000mooooo`03o`000?oooooooooo
01Kooooo0ol0001@ooooo`;ooiT0??ooool00ol0003oooooooooo`0gooooo`;o00009_ooool001go
oooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Booooo`?o0000DOooool2oonI03oo
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Sooooo`007Oooool00ol0003ooooo
ooooo`0nooooo`03o`000?oooooooooo00kooooo0ol0001Aooooo`?ooiT0@_ooool00ol0003ooooo
ooooo`0gooooo`03o`000?oooooooooo02?ooooo000Mooooo`03o`000?oooooooooo03oooooo00?o
0000ooooooooool02_ooool3o`0005;ooooo0_ooV@16ooooo`03o`000?oooooooooo03Oooooo00?o
0000ooooooooool08_ooool001gooooo00?o0000ooooooooool0@?ooool00ol0003oooooooooo`06
ooooo`?o0000D_ooool3oonI01cooooo0_o<o`0[ooooo`03o`000?oooooooooo03Oooooo00?o0000
ooooooooool08Oooool001cooooo0ol00012ooooo`03o`000?oooooooooo00?ooooo0_l0001Boooo
o`?ooiT07_ooool00oo<o`3oooooooooo`0[ooooo`03o`000?oooooooooo03Sooooo00?o0000oooo
ooooool08?ooool001cooooo00?o0000ooooooooool0@oooool00ol0003oooooo`000002o`00057o
oooo0oooV@0Pooooo`03olco0?oooooooooo02gooooo00?o0000ooooooooool0=oooool00ol0003o
ooooooooo`0Pooooo`007?ooool00ol0003oooooooooo`12ooooo`?o0000D?ooool4oonI027ooooo
0_o<o`0aooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool02Oooool2o`000003oa0@
4?oooooooooo017ooooo000Looooo`03o`000?oooooooooo03oooooo0ol00003ooooo`03o`000?oo
oooooooo04Sooooo1OooV@0Sooooo`;oc?l0=?ooool00ol0003oooooooooo`0gooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool04_ooool001cooooo0ol0000looooo`?o00001oooool0
0ol0003oooooooooo`12ooooo`GooiT09oooool00oo<o`3oooooooooo`0eooooo`03o`000?oooooo
oooo03Kooooo00?o0000ooooooooool01_ooool5o`0001?ooooo000Looooo`03o`000?oooooooooo
03Wooooo0ol0000;ooooo`03o`000?oooooooooo03kooooo0oooV@0Zooooo`;oc?l0>?ooool00ol0
003oooooooooo`0gooooo`03o`000?oooooooooo00Gooooo00CoA4A4omgMgOoooooo00005?ooool0
0006ooooooo^k^ko<S8bo`000?lb<S;ok^k^1Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8b
omgMg@05ooooo`03o`000?oooooooooo03Oooooo0_l0000?ooooo`03o`000?oooooooooo06Sooooo
0_o<o`0kooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool01?ooool01?oMgMgoEEEE
ooooool0000Dooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL5ooooo`;o8B4Q2?ooool00omg
MgOo<S8booooo`04ooooo`03o`000?oooooooooo03Cooooo0ol0000Booooo`03o`000?oooooooooo
06Gooooo0_o<o`0nooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool01Oooool00omg
MgOoc<c<o`00000Dooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0>ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool0<Oooool3o`0001Kooooo00?o0000oooooooo
ool0H_ooool2olco01Sooooo00?o<ol0ooooooooool09_ooool00ol0003oooooooooo`0fooooo`;o
00001Oooool00oo^k^koA4A4o`00000Dooooo`0000?oooooo`000?ooool00_ooool00ol0003ooooo
ooooo`0=ooooo`03ogMgMolb<S;ooooo00?ooooo0_l0000`ooooo`?o00006_ooool00ol0003ooooo
ooooo`1Oooooo`;oc?l06Oooool00olco`3oooooooooo`0Xooooo`03o`000?oooooooooo03Cooooo
00?o0000ooooool000001_ooool00omgMgOo0000ooooo`0Cooooo`0000?oooooo`000?ooool00_oo
ool00ol0003oooooooooo`0:ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003ooooo
ooooo`0/ooooo`?o00007_ooool00ol0003oooooooooo`1Looooo`;oc?l06_ooool00olco`3ooooo
ooooo`0Yooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool06Oooool00003ooooool@
413ooooo00;ooooo00?o410@ooooooooool02_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo02[ooooo0_l0000Rooooo`03o`000?oooooooooo05Wooooo0_o<o`0Kooooo`03oc?o0?oo
oooooooo02_ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Iooooo`0000Kooooo
ogMgMonHV9SooooooiRHV?mgMgL<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
9oooool3o`0002Gooooo0_l0001Fooooo`?oc?l06oooool2oc?o02oooooo00?o0000ooooooooool0
=_ooool00ol0003oooooooooo`0Hooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h<ooooo`Co
00001Oooool2o`0002Gooooo0ol0000Zooooo`03o`000?oooooooooo04kooooo1Oo<o`0Looooo`;o
<ol0<_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo01Oooooo000Kooooo`03o`00
0?oooooooooo027ooooo0ol0000^ooooo`03o`000?oooooooooo04Sooooo1Oo<o`0Oooooo`;o<ol0
=Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo01Oooooo000Kooooo`03o`000?oo
oooooooo01kooooo0ol0000booooo`03o`000?oooooooooo04Cooooo0oo<o`0Rooooo`;o<ol0=ooo
ool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo01Kooooo000Kooooo`03o`000?oooooo
oooo01_ooooo0ol0000fooooo`03o`000?oooooooooo03Oooooo3?o<o`0Tooooo`03oc?o0?oooooo
oooo017ooooo0_l0ofHUooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool05Oooool0
01[ooooo00?o0000ooooooooool06_ooool2o`0003[ooooo00?o0000ooooooooool0<oooool3olco
02kooooo0_lco`0Cooooo`03o`3oI_oooooooooo02Kooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`0Dooooo`006_ooool2o`0001Sooooo0ol0000mooooo`03o`000?oooooooooo06;o
oooo00?o<ol0ooooooooool04_ooool00ol0ofKoooooooooo`0Xooooo`03o`000?oooooooooo03Go
oooo00?o0000ooooooooool05?ooool001[ooooo00?o0000ooooooooool05?ooool3o`00047ooooo
00?o0000ooooooooool0Goooool2oc?o01Cooooo00?o0?mVooooooooool0:Oooool00ol0003ooooo
ooooo`0fooooo`03o`000?oooooooooo01?ooooo000Jooooo`03o`000?oooooooooo017ooooo0ol0
0015ooooo`03o`000?oooooooooo05_ooooo0olco`0Dooooo`;o0?mV;Oooool00ol0003ooooooooo
o`0fooooo`03o`000?oooooooooo01;ooooo000Jooooo`03o`000?oooooooooo00kooooo0ol00019
ooooo`03o`000?oooooooooo05Sooooo0_lco`0Fooooo`03o`3oI_oooooooooo02kooooo00?o0000
ooooooooool0=Oooool2o`0001?ooooo000Jooooo`03o`000?oooooooooo00cooooo0_l0001=oooo
o`03o`000?oooooooooo05Cooooo0olco`0Fooooo`;o0?mV<_ooool00ol0003oooooooooo`0doooo
o`;o00004oooool001Wooooo0ol0000:ooooo`?o0000D?ooool00ol0003oooooooooo`1?ooooo`Co
<ol06?ooool00ol0ofKoooooooooo`0=ooooo`;o0?oo9?ooool00ol0003oooooooooo`0eooooo`03
o`000?oooooooooo013ooooo000Jooooo`03o`000?oooooooooo00Kooooo0ol0001Dooooo`03o`00
0?oooooooooo04[ooooo1?lco`0Jooooo`;o0?mV3oooool00ol0ooooooooooooo`0Tooooo`03o`00
0?oooooooooo03Kooooo00?o0000ooooooooool03oooool001Wooooo00?o0000ooooooooool01?oo
ool3o`0005Sooooo00?o0000ooooooooool0AOooool4oc?o01cooooo0_l0ofH?ooooo`;o0?oo:?oo
ool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00oooooo000Iooooo`04o`000?oooooo
ooooooooo`?o0000G?ooool00ol0003oooooooooo`10ooooo`Co<ol07_ooool2o`3oIQ3ooooo00?o
0?ooooooooooool0:Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00kooooo000I
ooooo`Co0000H?ooool00ol0003oooooooooo`0kooooo`Co<ol08?ooool2o`3oIQ3ooooo0_l0ool]
ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool03Oooool001Wooooo0_l0001Soooo
o`03o`000?oooooooooo02gooooo3Olco`0Rooooo`;o0?mV4Oooool00ol0ooooooooooooo`0^oooo
o`03o`000?oooooooooo03Cooooo00?o0000ooooooooool03Oooool000oooooo1?l000000ol@413o
ooooooooo`05ooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0:?ooool4oc?o02co
oooo0ol0ofHAooooo`;o0?oo<Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00co
oooo000Aooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0HOooool00ol0003ooooo
ooooo`1Dooooo`?o0?mV4oooool00ol0ooooooooooooo`0<ooooo`;o06Ko9?ooool00ol0003ooooo
ooooo`0eooooo`03o`000?oooooooooo00_ooooo000Aooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool0HOooool00ol0003oooooooooo`1Aooooo`;o0?mV5Oooool00ol0oooooooooooo
o`0<ooooo`03o`1Voooooooooooo02Gooooo00?o0000ooooooooool0=Oooool00ol0003ooooooooo
o`0:ooooo`004Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo067ooooo00?o0000
ooooooooool0COooool3o`3oIQGooooo0_l0ool=ooooo`;o06Ko:Oooool00ol0003oooooooooo`0d
ooooo`03o`000?oooooooooo00[ooooo000Aooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool0HOooool00ol0003oooooooooo`19ooooo`?o0?mV5Oooool3o`3oo`kooooo00?o06Kooooo
ooooool0:_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Wooooo000Aooooo`03
o`000?oooooooooo00cooooo0_l0001Rooooo`03o`000?oooooooooo04Cooooo1?l0ofHEooooo`?o
0?oo3oooool2o`1Vobgooooo00?o0000ooooooooool0<oooool3o`0000[ooooo000Aooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0nooooo`Go0?mV
5oooool2o`3ooa3ooooo0_l0I_l`ooooo`03o`000?oooooooooo02oooooo0ol00002ooooo`03o`00
0?oooooooooo00Sooooo000?ooooo`03oeEEEOmVIVKo0000017ooooo00?o0000ooooooooool0H?oo
ool00ol0003oooooooooo`0iooooo`Co0?mV6_ooool2o`3ooa3ooooo0_l0I_l=ooooo`;o<`3o9?oo
ool00ol0003oooooooooo`0[ooooo`?o00001Oooool00ol0003oooooooooo`08ooooo`009?ooool0
0ol0003oooooooooo`1Pooooo`03o`000?oooooooooo03?ooooo1Ol0ofHKooooo`?o0?oo4?ooool2
o`1Vo`kooooo00?o<`3oooooooooool09Oooool00ol0003oooooooooo`0Vooooo`Co00002?ooool0
0ol0003oooooooooo`08ooooo`009Oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo
02cooooo1_l0ofHNooooo`;o0?oo4Oooool2o`1Vo`kooooo0_lc0?lYooooo`03o`000?oooooooooo
02;ooooo0ol0000<ooooo`03o`000?oooooooooo00Sooooo000Vooooo`03o`000?oooooooooo063o
oooo00?o0000ooooooooool07_ooool=o`3oIR7ooooo0ol0oolAooooo`;o06Ko3oooool00olc0?oo
ooooooooo`0Yooooo`03o`000?oooooooooo01oooooo0ol0000@ooooo`03o`000?oooooooooo00Oo
oooo000Wooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0B?ooool3o`3ooa7ooooo
0ol0I_l@ooooo`03oc<0oooooooooooo02_ooooo00?o0000ooooooooool06_ooool4o`0001?ooooo
00?o0000ooooooooool01oooool002Sooooo0_l0001Qooooo`03o`000?oooooooooo04Cooooo0ol0
oolBooooo`;o06Ko4Oooool2oc<0oboooooo00?o0000ooooooooool05_ooool3o`0001Oooooo00?o
0000ooooooooool01oooool002[ooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0o
ooooo`Co0?oo4oooool2o`1Voa7ooooo0_lc0?l;ooooo`;oc03o9Oooool00ol0003oooooooooo`0B
ooooo`?o00006_ooool00ol0003oooooooooo`07ooooo`00:oooool00ol0003oooooooooo`1Ooooo
o`03o`000?oooooooooo03Wooooo1Ol0oolEooooo`;o06Ko4Oooool2oc<0o`cooooo00?oc03ooooo
ooooool09_ooool00ol0003oooooooooo`0=ooooo`Co00007Oooool00ol0003oooooooooo`07oooo
o`00;?ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo03Cooooo1?l0oolGooooo`?o
06Ko4Oooool2oc<0o`cooooo0_o<0?lYooooo`03o`000?oooooooooo00[ooooo0ol0000Qooooo`03
o`000?oooooooooo00Oooooo000]ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool0
;_ooool5o`3ooaWooooo0_l0I_lBooooo`;o<`3o3Oooool00oo<0?ooooooooooo`0Zooooo`03o`00
0?oooooooooo00Kooooo0ol0000Tooooo`03o`000?oooooooooo00Oooooo000^ooooo`03o`000?oo
oooooooo05oooooo00?o0000ooooooooool09_ooool7o`3ooa_ooooo0ol0I_lAooooo`?o<`3o3_oo
ool00oo<0?ooooooooooo`0/ooooo`04o`000?ooooooooooooooo`Co00009oooool00ol0003ooooo
ooooo`07ooooo`00;oooool2o`00063ooooo00?o0000ooooooooool07?ooool9o`3ooaoooooo0ol0
I_lBooooo`;o<`3o3oooool2ol`0oc3ooooo0ol0000/ooooo`03o`000?oooooooooo00Kooooo000a
ooooo`03o`000?oooooooooo05kooooo0_l0000Gooooo`Go0?oo9Oooool3o`1Voa;ooooo0olc0?l?
ooooo`;oc03o2oooool2ool0VB;ooooo0ol000000ooooooo0000ooooo`0/ooooo`03o`000?oooooo
oooo00Kooooo000booooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool0>_ooool4o`1V
oa?ooooo0_lc0?l@ooooo`;oc03o3?ooool00ooo09Woooooooooo`0Oooooo`?o00001?ooool00ol0
003oooooooooo`0[ooooo`03o`000?oooooooooo00Kooooo000cooooo`03o`000?oooooooooo05oo
oooo00?o0000ooooooooool0=_ooool3o`1VoaGooooo0_lc0?lAooooo`03ol`0oooooooooooo00[o
oooo0_oo09TNooooo`Co00002?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00Ko
oooo000dooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool0<_ooool3o`1VoaGooooo
0olc0?lAooooo`;oc03o3?ooool00ooo09Woooooooooo`0Kooooo`?o00003Oooool00ol0003ooooo
ooooo`0Yooooo`03o`000?oooooooooo00Kooooo000eooooo`03o`000?oooooooooo05oooooo00?o
0000ooooooooool0;?ooool5o`1VoaKooooo0_lc0?lBooooo`;oc03o3Oooool00ooo09Wooooooooo
o`0Iooooo`?o00004Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Kooooo000f
ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool09_ooool5o`1VoaSooooo0olc0?lB
ooooo`;oc03o3Oooool2ool0VASooooo1?l0000Eooooo`03o`000?oooooooooo02Oooooo00?o0000
ooooooooool01_ooool003Oooooo0_l0001Pooooo`03o`000?oooooooooo01kooooo1ol0I_lIoooo
o`Co<`3o4_ooool3ol`0o`gooooo0_oo09TGooooo`?o00006Oooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo00Kooooo000iooooo`03o`000?oooooooooo05kooooo00?o0000oooooooo
ool03_ooool?o`1Voagooooo0olc0?lDooooo`;oc03o3_ooool2ool0V@kooooo0_oo0006ooooo`?o
00007Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Gooooo000jooooo`03o`00
0?oooooooooo05kooooo00?o0000ooooooooool0=Oooool4oc<0oaGooooo0_o<0?l?ooooo`03ool0
VOoooooooooo00cooooo0_oo0004ooooo`Co00008Oooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo00Gooooo000kooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0<Ooo
ool3oc<0oaKooooo0oo<0?l?ooooo`;oo`2I3Oooool2ool000?ooooo0ol0000Vooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool01Oooool003cooooo00?o0000ooooooooool0G_ooool0
0ol0003oooooooooo`0]ooooo`?o<`3o5_ooool3ol`0oa3ooooo0_oo09T>ooooo`03ool00?oooooo
oooo00?o0000:Oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Gooooo000moooo
o`03o`000?oooooooooo05kooooo00?o0000ooooooooool09oooool5oc<0oaKooooo0oo<0?lAoooo
o`;oo`2I3_ooool2ool000?o0000;Oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
00Gooooo000nooooo`;o0000Goooool00ol0003oooooooooo`0Qooooo`Go<`3o6?ooool3ol`0oa;o
oooo0_oo09T>ooooo`;oo`0000?o0000ooooooooool0<?ooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo00Gooooo0010ooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool0
6?ooool8oc<0oa[ooooo0oo<0?lCooooo`;oo`2I3Oooool00ol0003oo`00ool0000fooooo`03o`00
0?oooooooooo02;ooooo00?o0000ooooooooool01Oooool0047ooooo00?o0000ooooooooool0GOoo
ool00ol0003oooooooooo`0=ooooo`[o<`3o7oooool3ol`0oaCooooo0_oo09T;ooooo`?o00000_oo
000iooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool01Oooool004;ooooo00?o0000
ooooooooool0GOooool00ol0003oooooooooo`07ooooo`Go<`3o9Oooool4ol`0oaGooooo0_oo09T:
ooooo`?o00000_ooool00ooo003oooooooooo`0iooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool01Oooool004?ooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`0/oooo
o`Coc03o5_ooool3ool0V@Wooooo0ol00003ooooo`;oo`00?Oooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo00Cooooo0014ooooo`03o`000?oooooooooo05gooooo00?o0000oooooooo
ool09oooool4ol`0oaOooooo0ooo09T8ooooo`Co00001?ooool2ool0043ooooo00?o0000oooooooo
ool08?ooool00ol0003oooooooooo`04ooooo`00AOooool00ol0003oooooooooo`1Mooooo`03o`00
0?oooooooooo027ooooo1Oo<0?lHooooo`?oo`2I2?ooool3o`0000Gooooo0ooo0013ooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool01?ooool004Kooooo0_l0001Nooooo`03o`000?oo
oooooooo01_ooooo1Oo<0?lJooooo`?oo`2I2?ooool3o`0000Kooooo0_oo0017ooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool01?ooool004Sooooo00?o0000ooooooooool0G?ooool0
0ol0003oooooooooo`0Booooo`Soc03o6oooool4ool0V@Oooooo1?l00006ooooo`?oo`00BOooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Cooooo0019ooooo`03o`000?oooooooooo
05cooooo00?o0000ooooooooool01_ooool;ol`0ob3ooooo0ooo09T8ooooo`?o00002?ooool2ool0
04gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`04ooooo`00B_ooool00ol0003o
ooooooooo`1Looooo`03o`000?oooooooooo00Goc03o9oooool4ool0V@Sooooo0ol00008ooooo`?o
o`00D?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Cooooo001;ooooo`03o`00
0?oooooooooo05cooooo00?o0000ooooooooool09oooool4ool0V@Sooooo1?l00008ooooo`?oo`00
E?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo001<ooooo`03o`000?oo
oooooooo05cooooo00?o0000ooooooooool08_ooool4ool0V@Wooooo0ol00009ooooo`?oo`00F?oo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00?ooooo001=ooooo`;o0000GOooool0
0ol0003oooooooooo`0Looooo`Goo`2I2_ooool3o`0000[ooooo0_oo001Kooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool00oooool004oooooo00?o0000ooooooooool0Foooool00ol0
003oooooooooo`0Fooooo`Goo`2I3?ooool3o`0000[ooooo0ooo001Nooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool00oooool0053ooooo00?o0000ooooooooool0Foooool00ol0003o
ooooooooo`0<ooooo`Woo`2I3Oooool4o`0000[ooooo0ooo001Rooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool00oooool0057ooooo00?o0000ooooooooool0Foooool00ol0003ooooo
ooooo`0;ool0VA?ooooo0ol0000;ooooo`?oo`00I_ooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo00?ooooo001Booooo`03o`000?oooooooooo05Oooooo1_oo09TKooooo`?o00002_oo
ool4ool006[ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`03ooooo`00Doooool0
0ol0003oooooooooo`1Kooooo`03o`000?oooooooooo01Gooooo1?l00009ooooo`Coo`00K_ooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00?ooooo001Dooooo`;o0000G?ooool00ol0
003oooooooooo`0Aooooo`?o00002Oooool4ool007?ooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`03ooooo`00E_ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00go
oooo0ol00007ooooo`Goo`00N?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00;o
oooo001Gooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool02?ooool4o`0000Cooooo
1_oo001nooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool00_ooool005Sooooo00?o
0000ooooooooool0F_ooool00ol0003oooooooooo`04ooooo`;o00002Ooo0025ooooo`03o`000?oo
oooooooo01Cooooo00?o0000ooooooooool00_ooool005Wooooo00?o0000ooooooooool0Eoooool;
ool008kooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`02ooooo`00F_ooool00ol0
003oooooooooo`1@ooooo`Koo`001?ooool2o`0009Cooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`02ooooo`00Foooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo09Co
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`02ooooo`00G?ooool2o`0005Wooooo
00?o0000ooooooooool0UOooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo
001Nooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool0U_ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo00;ooooo001Oooooo`03o`000?oooooooooo05Gooooo00?o0000
ooooooooool0U_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo007ooooo001Poooo
o`03o`000?oooooooooo05Cooooo00?o0000ooooooooool0Uoooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo007ooooo001Qooooo`03o`000?oooooooooo05?ooooo00?o0000oooooooo
ool0V?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo007ooooo001Rooooo`03o`00
0?oooooooooo05;ooooo00?o0000ooooooooool0VOooool00ol0003oooooooooo`0>ooooo`03o`00
0?oooooooooo007ooooo001Sooooo`;o0000D_ooool00ol0003oooooooooo`2Jooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool00Oooool006Gooooo00?o0000ooooooooool0Coooool0
0ol0003oooooooooo`2Jooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00Oooool0
06Kooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`2Kooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool00Oooool006Oooooo00?o0000ooooooooool0COooool00ol0003o
ooooooooo`2Looooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00Oooool006Sooooo
00?o0000ooooooooool0C?ooool00ol0003oooooooooo`2Mooooo`03o`000?oooooooooo00_ooooo
0Ol00001ooooo`7ooooo001Yooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0WOoo
ool00ol0003oooooooooo`0;ooooo`7o00000Oooool1ooooo`00J_ooool00ol0003oooooooooo`1:
ooooo`03o`000?oooooooooo09kooooo00?o0000ooooooooool02_ooool1o`00007ooooo0Oooool0
06_ooooo0_l0001:ooooo`03o`000?oooooooooo09oooooo00?o0000ooooooooool02Oooool1o`00
007ooooo0Oooool006gooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`2Pooooo`03
o`000?oooooooooo00Sooooo0Ol00001ooooo`7ooooo001^ooooo`03o`000?oooooooooo04Kooooo
00?o0000ooooooooool0XOooool00ol0003oooooooooo`07ooooo`7o00000Oooool1ooooo`00Kooo
ool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo0:7ooooo00?o0000ooooooooool01ooo
ool1o`00007ooooo0Oooool0073ooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`2R
ooooo`03o`000?oooooooooo00Kooooo0Ol00001ooooo`7ooooo001aooooo`03o`000?oooooooooo
04?ooooo00?o0000ooooooooool0Xoooool00ol0003oooooooooo`05ooooo`7o00000Oooool1oooo
o`00L_ooool2o`0004;ooooo00?o0000ooooooooool0YOooool00ol0003oooooooooo`05ooooo`7o
00000Oooool007Cooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`2Vooooo`03o`00
0?oooooooooo00Cooooo0Ol00001ooooo`00MOooool00ol0003oooooooooo`0nooooo`03o`000?oo
oooooooo0:Kooooo00?o0000ooooooooool01?ooool1o`00007ooooo001fooooo`03o`000?oooooo
oooo03gooooo00?o0000ooooooooool0Yoooool00ol0003oooooooooo`03ooooo`7o00000Oooool0
07Oooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`2Xooooo`03o`000?oooooooooo
00;ooooo0Ol00001ooooo`00N?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0:Wo
oooo00Go0000ooooooooooooooooo`000001ooooo`00NOooool00ol0003oooooooooo`0jooooo`03
o`000?oooooooooo0:[ooooo00Co0000oooooooooooo00000Oooool007[ooooo0_l0000jooooo`03
o`000?oooooooooo0:[ooooo00Co0000oooooooooooo00000Oooool007cooooo00?o0000oooooooo
ool0=oooool00ol0003oooooooooo`2[ooooo`03o`000?oooooooooo007o0000001mooooo`03o`00
0?oooooooooo03Kooooo00?o0000ooooooooool0[?ooool1o`00007ooooo0Ol0000007kooooo00?o
0000ooooooooool0=Oooool00ol0003oooooooooo`2]ooooo`;o0000001oooooo`03o`000?oooooo
oooo03Cooooo00?o0000ooooooooool0[?ooool3o`000000P?ooool00ol0003oooooooooo`0coooo
o`03o`000?oooooooooo0:Sooooo1?l00003ooooo`00POooool2o`0003?ooooo00?o0000oooooooo
ool0YOooool3o`0000Oooooo0023ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
XOooool4o`0000[ooooo0024ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0WOoo
ool4o`0000kooooo0025ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0VOooool4
o`0001;ooooo0026ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0UOooool4o`00
01Kooooo0027ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0T_ooool3o`0001[o
oooo0028ooooo`;o0000;?ooool00ol0003oooooooooo`2>ooooo`Co00007Oooool008[ooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`2:ooooo`Co00008Oooool008_ooooo00?o0000
ooooooooool0:?ooool00ol0003oooooooooo`26ooooo`Co00009Oooool008cooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`22ooooo`Co0000:Oooool008gooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`1oooooo`?o0000;Oooool008kooooo00?o0000ooooooooool0
9Oooool00ol0003oooooooooo`1kooooo`Co0000<?ooool008oooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`1gooooo`Co0000=?ooool0093ooooo0_l0000Tooooo`03o`000?oooooo
oooo07?ooooo1?l0000hooooo`00T_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
073ooooo0ol0000looooo`00Toooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo06co
oooo1?l0000oooooo`00U?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo06Sooooo
1?l00013ooooo`00UOooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo06Cooooo1?l0
0017ooooo`00U_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo063ooooo1?l0001;
ooooo`00Uoooool2o`0001gooooo00?o0000ooooooooool0GOooool3o`0004oooooo002Iooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool0FOooool4o`0005;ooooo002Jooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool0EOooool4o`0005Kooooo002Kooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool0DOooool4o`0005[ooooo002Looooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool0COooool4o`0005kooooo002Mooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool0B_ooool3o`0006;ooooo002Nooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool0A_ooool4o`0006Gooooo002Oooooo`;o00005?ooool00ol0003ooooo
ooooo`13ooooo`Co0000JOooool00:7ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0oooooo`Co0000KOooool00:;ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0k
ooooo`Co0000LOooool00:?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0hoooo
o`?o0000MOooool00:Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0dooooo`Co
0000N?ooool00:Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0`ooooo`Co0000
O?ooool00:Kooooo0_l0000=ooooo`03o`000?oooooooooo02cooooo1?l00020ooooo`00Z?ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Wooooo0ol00024ooooo`00ZOooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo02Gooooo1?l00027ooooo`00Z_ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo027ooooo1?l0002;ooooo`00Zoooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo01gooooo1?l0002?ooooo`00[?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo01Wooooo1?l0002Cooooo`00[Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo01Kooooo0ol0002Gooooo`00[_ooool2o`0000Gooooo00?o0000oooo
ooooool04_ooool4o`0009[ooooo002`ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool03_ooool4o`0009kooooo002aooooo`05o`000?ooooooooooooooool000003?ooool4o`000:;o
oooo002booooo`04o`000?ooooooooooo`0000Sooooo1?l0002Vooooo`00/oooool00ol0003ooooo
o`000005ooooo`?o0000Z_ooool00;Cooooo0_l000000ooooooo0000o`000002o`000:gooooo002e
ooooo`;o0000/Oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {319.688, 0}} -> {-0.0710364, -0.0181728, \
0.0035149, 0.0035149}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .89104 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-16 1.0656 -0.0363427 1.0656 [
[.02544 .21571 -12 -8.9133 ]
[.02544 .21571 0 .0867 ]
[.16074 .16277 -11.6592 -9 ]
[.16074 .16277 .34081 0 ]
[.3021 .10747 -5.60025 -9 ]
[.3021 .10747 .39975 0 ]
[.44992 .04965 -5.37091 -9 ]
[.44992 .04965 .62909 0 ]
[.60467 -0.01084 -5.14157 -9 ]
[.60467 -0.01084 .85843 0 ]
[.66454 .05085 0 -6.20675 ]
[.66454 .05085 6 2.79325 ]
[.80797 .25198 0 -6.0417 ]
[.80797 .25198 6 2.9583 ]
[.93071 .4241 0 -5.90576 ]
[.93071 .4241 6 3.09424 ]
[.02254 .22988 -12 -2.74631 ]
[.02254 .22988 0 6.25369 ]
[.0142 .29178 -24 -2.78907 ]
[.0142 .29178 0 6.21093 ]
[.00558 .35578 -6 -2.83339 ]
[.00558 .35578 0 6.16661 ]
[-0.00334 .42198 -18 -2.87938 ]
[-0.00334 .42198 0 6.12062 ]
[-0.01257 .49051 -6 -2.92712 ]
[-0.01257 .49051 0 6.07288 ]
[ 0 0 0 0 ]
[ 1 .89104 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03495 .22504 m
.61241 0 L
s
.03495 .22504 m
.03971 .2297 L
s
[(-2)] .02544 .21571 1 .98073 Mshowa
.16988 .17246 m
.17445 .1773 L
s
[(-1)] .16074 .16277 .9432 1 Mshowa
.31082 .11753 m
.31518 .12256 L
s
[(0)] .3021 .10747 .86675 1 Mshowa
.45818 .0601 m
.46231 .06533 L
s
[(1)] .44992 .04965 .7903 1 Mshowa
.61241 0 m
.61628 .00542 L
s
[(2)] .60467 -0.01084 .71386 1 Mshowa
.125 Mabswid
.06148 .2147 m
.06431 .21752 L
s
.08823 .20428 m
.09104 .20712 L
s
.11521 .19376 m
.118 .19663 L
s
.14243 .18316 m
.14519 .18604 L
s
.19758 .16166 m
.20029 .16459 L
s
.22551 .15078 m
.22821 .15373 L
s
.2537 .13979 m
.25637 .14277 L
s
.28213 .12871 m
.28478 .13171 L
s
.33977 .10625 m
.34236 .10929 L
s
.36897 .09487 m
.37153 .09794 L
s
.39844 .08339 m
.40097 .08648 L
s
.42817 .0718 m
.43068 .07491 L
s
.48846 .0483 m
.49091 .05146 L
s
.51902 .03639 m
.52144 .03958 L
s
.54986 .02437 m
.55225 .02758 L
s
.58099 .01224 m
.58335 .01547 L
s
.25 Mabswid
.61241 0 m
.97291 .505 L
s
.65208 .05558 m
.64586 .05794 L
s
[(0)] .66454 .05085 -1 .37928 Mshowa
.79537 .2563 m
.78907 .25846 L
s
[(2)] .80797 .25198 -1 .3426 Mshowa
.91799 .42808 m
.91164 .43006 L
s
[(4)] .93071 .4241 -1 .31239 Mshowa
.125 Mabswid
.69012 .10886 m
.68637 .11025 L
s
.72662 .16 m
.72286 .16135 L
s
.76168 .2091 m
.75791 .21042 L
s
.82778 .3017 m
.82399 .30297 L
s
.85897 .3454 m
.85518 .34664 L
s
.88903 .3875 m
.88522 .38871 L
s
.94594 .46722 m
.94211 .46839 L
s
.25 Mabswid
.03495 .22504 m
0 .48612 L
s
.03495 .22504 m
.04116 .22262 L
s
[(-1)] .02254 .22988 1 -0.38971 Mshowa
.02665 .28704 m
.03288 .28468 L
s
[(-0.5)] .0142 .29178 1 -0.38021 Mshowa
.01807 .35115 m
.02431 .34884 L
s
[(0)] .00558 .35578 1 -0.37036 Mshowa
.00919 .41747 m
.01546 .41521 L
s
[(0.5)] -0.00334 .42198 1 -0.36014 Mshowa
0 .48612 m
.00629 .48392 L
s
[(1)] -0.01257 .49051 1 -0.34953 Mshowa
.125 Mabswid
.03331 .23728 m
.03704 .23583 L
s
.03166 .2496 m
.03539 .24816 L
s
.03 .262 m
.03373 .26056 L
s
.02833 .27448 m
.03207 .27305 L
s
.02496 .29969 m
.0287 .29828 L
s
.02325 .31243 m
.02699 .31102 L
s
.02154 .32525 m
.02528 .32385 L
s
.01981 .33816 m
.02355 .33676 L
s
.01632 .36423 m
.02007 .36285 L
s
.01455 .37741 m
.01831 .37603 L
s
.01278 .39067 m
.01653 .3893 L
s
.01099 .40402 m
.01475 .40266 L
s
.00738 .43101 m
.01114 .42966 L
s
.00555 .44464 m
.00932 .4433 L
s
.00371 .45837 m
.00748 .45704 L
s
.00186 .4722 m
.00563 .47087 L
s
.25 Mabswid
.03495 .22504 m
0 .48612 L
s
0 .48612 m
.46953 .89104 L
s
.46953 .89104 m
.47294 .65459 L
s
.47294 .65459 m
.03495 .22504 L
s
.61241 0 m
.97291 .505 L
s
.97291 .505 m
1 .75117 L
s
1 .75117 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.03495 .22504 m
0 .48612 L
s
0 .48612 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.61241 0 m
.03495 .22504 L
s
.47294 .65459 m
.97291 .505 L
s
.97291 .505 m
1 .75117 L
s
1 .75117 m
.46953 .89104 L
s
.46953 .89104 m
.47294 .65459 L
s
0 0 m
1 0 L
1 .89104 L
0 .89104 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.4473 .67156 m
.48374 .66891 L
s
1 0 .6 r
.44592 .65074 m
.48099 .64816 L
s
1 0 0 r
.48374 .66891 m
.52171 .66413 L
s
.8 0 1 r
.44455 .62985 m
.47824 .62736 L
s
1 0 .6 r
.48099 .64816 m
.51762 .6435 L
s
.2 0 1 r
.44317 .60889 m
.47548 .60649 L
s
.8 0 1 r
.47824 .62736 m
.51353 .62282 L
s
1 0 0 r
.52171 .66413 m
.56002 .65723 L
s
0 .4 1 r
.44181 .58779 m
.47271 .58551 L
s
.2 0 1 r
.47548 .60649 m
.50942 .60209 L
s
1 0 .6 r
.51762 .6435 m
.55465 .63676 L
s
0 .4 1 r
.47271 .58551 m
.50529 .58127 L
s
.8 0 1 r
.51353 .62282 m
.54926 .61625 L
s
0 1 1 r
.44047 .5664 m
.46991 .5643 L
s
.2 0 1 r
.50942 .60209 m
.54386 .5957 L
s
0 1 1 r
.46991 .5643 m
.5011 .56026 L
s
1 0 0 r
.56002 .65723 m
.59787 .64831 L
s
0 1 .4 r
.43919 .54438 m
.46706 .54256 L
s
0 .4 1 r
.50529 .58127 m
.53843 .57507 L
s
1 0 .6 r
.55465 .63676 m
.59126 .62803 L
s
0 1 .4 r
.46706 .54256 m
.49678 .53881 L
s
0 1 1 r
.5011 .56026 m
.53293 .55428 L
s
.8 0 1 r
.54926 .61625 m
.58463 .60773 L
s
.2 1 0 r
.43805 .52104 m
.46409 .51962 L
s
.2 0 1 r
.54386 .5957 m
.57799 .58738 L
s
0 1 .4 r
.49678 .53881 m
.52723 .53311 L
s
.2 1 0 r
.46409 .51962 m
.49213 .5163 L
s
0 .4 1 r
.53843 .57507 m
.57132 .56698 L
s
0 1 1 r
.53293 .55428 m
.56455 .54644 L
s
.2 1 0 r
.49213 .5163 m
.52104 .51102 L
s
1 0 0 r
.59787 .64831 m
.63471 .63746 L
s
1 0 .6 r
.59126 .62803 m
.62688 .61742 L
s
0 1 .4 r
.52723 .53311 m
.55753 .52556 L
s
.8 1 0 r
.43717 .49503 m
.46089 .49411 L
s
.8 0 1 r
.58463 .60773 m
.61905 .59736 L
s
.8 1 0 r
.46089 .49411 m
.48676 .49138 L
s
.2 0 1 r
.57799 .58738 m
.6112 .57727 L
s
.2 1 0 r
.52104 .51102 m
.54987 .50384 L
s
.8 1 0 r
.48676 .49138 m
.51369 .48669 L
s
0 .4 1 r
.57132 .56698 m
.60331 .55713 L
s
0 1 1 r
.56455 .54644 m
.5953 .53687 L
s
0 1 .4 r
.55753 .52556 m
.58699 .51629 L
s
.8 1 0 r
.51369 .48669 m
.54066 .48006 L
s
1 0 0 r
.63471 .63746 m
.67004 .62479 L
s
.2 1 0 r
.54987 .50384 m
.57787 .49493 L
s
1 0 .6 r
.62688 .61742 m
.66102 .60504 L
s
1 .6 0 r
.43641 .46447 m
.45717 .46372 L
s
.8 0 1 r
.61905 .59736 m
.65199 .58528 L
s
1 .6 0 r
.45717 .46372 m
.47994 .46151 L
s
.2 0 1 r
.6112 .57727 m
.64295 .56549 L
s
0 .4 1 r
.60331 .55713 m
.63385 .54566 L
s
1 .6 0 r
.47994 .46151 m
.50388 .45752 L
s
.8 1 0 r
.54066 .48006 m
.56678 .47164 L
s
0 1 1 r
.5953 .53687 m
.62461 .52572 L
s
0 1 .4 r
.58699 .51629 m
.61497 .50548 L
s
1 .6 0 r
.50388 .45752 m
.52798 .45166 L
s
.2 1 0 r
.57787 .49493 m
.60434 .48448 L
s
1 0 0 r
.67004 .62479 m
.70332 .61045 L
s
.8 1 0 r
.56678 .47164 m
.59126 .46167 L
s
1 0 .6 r
.66102 .60504 m
.69311 .59105 L
s
1 .6 0 r
.52798 .45166 m
.55128 .44404 L
s
.8 0 1 r
.65199 .58528 m
.68289 .57165 L
s
.2 0 1 r
.64295 .56549 m
.67265 .55224 L
s
0 .4 1 r
.63385 .54566 m
.66234 .53278 L
s
0 1 1 r
.62461 .52572 m
.65184 .51322 L
s
0 1 .4 r
.61497 .50548 m
.64083 .49336 L
s
.2 1 0 r
.60434 .48448 m
.62856 .47277 L
s
1 .6 0 r
.55128 .44404 m
.57288 .43493 L
s
.8 1 0 r
.59126 .46167 m
.61333 .45049 L
s
1 0 0 r
.70332 .61045 m
.7338 .59475 L
s
1 0 .6 r
.69311 .59105 m
.72241 .57578 L
s
.8 0 1 r
.68289 .57165 m
.71101 .55681 L
s
.2 0 1 r
.67265 .55224 m
.69958 .53784 L
s
0 .4 1 r
.66234 .53278 m
.68806 .51883 L
s
0 1 1 r
.65184 .51322 m
.67628 .49971 L
s
0 1 .4 r
.64083 .49336 m
.66382 .48031 L
s
1 .6 0 r
.57288 .43493 m
.59204 .42475 L
s
.2 1 0 r
.62856 .47277 m
.64977 .46021 L
s
.8 1 0 r
.61333 .45049 m
.63224 .43859 L
s
1 .6 0 r
.59204 .42475 m
.60823 .41406 L
s
0 1 1 r
.67628 .49971 m
.69715 .48579 L
s
0 1 .4 r
.66382 .48031 m
.6832 .46693 L
s
0 .4 1 r
.68806 .51883 m
.71024 .50438 L
s
.2 0 1 r
.69958 .53784 m
.72295 .52287 L
s
.2 1 0 r
.64977 .46021 m
.66731 .44744 L
s
.8 0 1 r
.71101 .55681 m
.73553 .54133 L
s
1 0 .6 r
.72241 .57578 m
.74807 .55979 L
s
1 0 0 r
.7338 .59475 m
.7606 .57826 L
s
.8 1 0 r
.63224 .43859 m
.64753 .42666 L
s
1 .6 0 r
.60823 .41406 m
.62133 .4035 L
s
0 g
.25 Mabswid
.61241 0 m
.97291 .505 L
s
.97291 .505 m
1 .75117 L
s
1 .75117 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.03495 .22504 m
0 .48612 L
s
0 .48612 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.61241 0 m
.03495 .22504 L
s
.03495 .22504 m
.61241 0 L
s
.03495 .22504 m
.03971 .2297 L
s
[(-2)] .02544 .21571 1 .98073 Mshowa
.16988 .17246 m
.17445 .1773 L
s
[(-1)] .16074 .16277 .9432 1 Mshowa
.31082 .11753 m
.31518 .12256 L
s
[(0)] .3021 .10747 .86675 1 Mshowa
.45818 .0601 m
.46231 .06533 L
s
[(1)] .44992 .04965 .7903 1 Mshowa
.61241 0 m
.61628 .00542 L
s
[(2)] .60467 -0.01084 .71386 1 Mshowa
.125 Mabswid
.06148 .2147 m
.06431 .21752 L
s
.08823 .20428 m
.09104 .20712 L
s
.11521 .19376 m
.118 .19663 L
s
.14243 .18316 m
.14519 .18604 L
s
.19758 .16166 m
.20029 .16459 L
s
.22551 .15078 m
.22821 .15373 L
s
.2537 .13979 m
.25637 .14277 L
s
.28213 .12871 m
.28478 .13171 L
s
.33977 .10625 m
.34236 .10929 L
s
.36897 .09487 m
.37153 .09794 L
s
.39844 .08339 m
.40097 .08648 L
s
.42817 .0718 m
.43068 .07491 L
s
.48846 .0483 m
.49091 .05146 L
s
.51902 .03639 m
.52144 .03958 L
s
.54986 .02437 m
.55225 .02758 L
s
.58099 .01224 m
.58335 .01547 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 256.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001@2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00gOooool5o`0008Kooooo003Mooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0Q_ooool00=ko
oooo00?oV9RHob4Q8Oo^k^h0Qoooool00=oooooo00?oV9RHob4Q8Oo^k^h0Q_ooool00>3ooooo00?o
MgMgofIVI_ooool0QOooool00>7ooooo00?o0000ooooooooool0Q?ooool00=gooooo00Go0000okZj
^_ooooooV9RHoa0@4026ooooo`00gOooool01OnHV9So410@o`000?lQ8B7oc<c<08Kooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003Tooooo`;o0000P_ooool0
0>7ooooo0ol000000ooooooo0000ooooo`21ooooo`00goooool2o`0000Cooooo0_l00021ooooo`00
g?ooool3o`0000Kooooo00?o0000ooooool00000P?ooool00=[ooooo0_l00009ooooo`03o`000?oo
oooo0000083ooooo003Gooooo`?o000000?oooooo`000?ooool02?ooool01?l0003oooooooooool0
001oooooo`00e?ooool3o`0000Cooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooo
oooo000007kooooo003Booooo`;o00004Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo07_ooooo002Zooooo`Co000000?o410@ooooooooool07_ooool3o`0001?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1kooooo`00[?ooool00ol0003oooooooooo`0Nooooo`;o
000000?oooooo`000?ooool04oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07[o
oooo002/ooooo`03o`000?oooooooooo01_ooooo0ol00004ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`1iooooo`00[?ooool00ol0003ooooooooo
o`0Iooooo`;o00006oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo07Wooooo002/
ooooo`03o`000?oooooooooo01Kooooo0ol0000Mooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool02?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^06_ooooo002/ooooo`03o`000?oooooo
oooo01Cooooo0_l000000ooooooo0000ooooo`0Mooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01oooool01OmgMgOoV9RHoooooonHV9SoMgMg06_ooooo002/ooooo`03o`000?oooooo
oooo017ooooo0ol00004ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`06ooooo`05oa0@4?ooooooooooooooool@4100Joooool00:[ooooo00?oEEEE
ofIVI_l000004Oooool2o`0002Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06
ooooo`05o`000?ooooooooooooooool00000Joooool00;_ooooo0ol0000Wooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000006_ooooo002i
ooooo`;o000000?oooooo`000?ooool09oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Cooooo00Go410@oooooooooooooooooa0@401[ooooo`00]_ooool3o`0000Cooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`1[ooooo`00/oooool3o`0002oooooo00?o0000ooooooooool02Oooool2
o`0000Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1[ooooo`00/Oooool2o`0003;ooooo00?o0000
ooooooooool02?ooool01?l0003oooooooooool0001dooooo`00[_ooool3o`000003ooooool0003o
oooo037ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1aooooo`00[?ooool2o`00
00Gooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
077ooooo002Yooooo`?o0000>_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo073o
oooo002Wooooo`;o0000?Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo06oooooo
002Tooooo`?o000000?oooooo`000?ooool0??ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo06oooooo002Rooooo`;o0000@_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo06kooooo001gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08oooool3o`0004Cooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1]ooooo`00Moooool01OmgMgOoV9RHoooooonHV9So
MgMg027ooooo0_l00017ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0K?ooool0
07Oooooo00Go410@oooooooooooooooooa0@400Nooooo`?o00000_ooool00ol0003oooooooooo`14
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0K?ooool007Oooooo00Go0000oooo
ooooooooooooo`00000Looooo`;o0000C?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo06_ooooo001gooooo`05o`000?ooooooooooooooool000006Oooool3o`0004kooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`1Zooooo`00Moooool01Ol@413ooooooooooooooooo
410@01Kooooo0ol0001Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0J_ooool0
07Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Dooooo`;o00000oooool00ol0003oooooooooo`1>
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0JOooool007Oooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Aooooo`?o0000E_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo06Sooooo002;ooooo`;o0000FOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
06Sooooo0028ooooo`?o0000Foooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo06Oo
oooo0026ooooo`;o00000oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo01Gooooo
0_l0001Xooooo`00Poooool3o`00063ooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`1Uooooo`00POooool2o`0006?ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1U
ooooo`00O_ooool4o`0006Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`1Toooo
o`00O?ooool2o`0000Cooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo06?ooooo001iooooo`?o0000J_ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo06?ooooo001gooooo`;o0000KOooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo06;ooooo001dooooo`?o000000?oooooo`000?ooool0K?ooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo067ooooo001aooooo`?o0000L_ooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo063ooooo0019ooooo`Co000000?o410@ooooooooool07oooool2o`0007Go
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1Pooooo`00Boooool00ol0003ooooo
ooooo`0Nooooo`?o0000Moooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo05oooooo
0010ooooo`Ko00001Oooool00ol0003oooooooooo`0Looooo`;o00000_ooool00ol0003ooooooooo
o`1eooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0G_ooool004_ooooo00?o0000
ooooooooool06Oooool3o`0007cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1N
ooooo`00Boooool00ol0003oooooooooo`0Gooooo`;o0000Ooooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo05gooooo001;ooooo`03o`000?oooooooooo01Cooooo0ol00021ooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0G?ooool004_ooooo00?o0000ooooooooool0
4_ooool2o`0000?ooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo05_ooooo0019ooooo`03oeEEEOmVIVKo0000017ooooo0ol00026ooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool0Foooool005_ooooo0_l00029ooooo`03o`000?oooooo
oooo027ooooo0_l0001Looooo`00F?ooool3o`000003ooooool0003ooooo08Sooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`1Iooooo`00E_ooool2o`0008kooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`1Iooooo`00Doooool3o`00093ooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`1Hooooo`00D?ooool3o`0009?ooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1Gooooo`00C_ooool2o`0000;ooooo00?o0000ooooooooool0TOooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo05Kooooo001;ooooo`?o00001Oooool00ol0
003oooooooooo`2@ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0E_ooool004Wo
oooo0_l0002Kooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0EOooool004Kooooo
1?l0002Looooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0E?ooool004Cooooo0_l0
002Pooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0E?ooool001[ooooo1Ol0000R
ooooo`?o0000X_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo05?ooooo000Joooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@08?ooool2o`000:Gooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`1Booooo`004_ooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h07_ooool3o`00
0003ooooool0003ooooo0:Cooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`1Aoooo
o`007?ooool00onHV9So8B4Qonk^kP0Kooooo`;o0000Z_ooool00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo057ooooo000Mooooo`03ogMgMomVIVKooooo01Oooooo0ol0002]ooooo`03o`00
0?oooooooooo02_ooooo00?o0000ooooooooool0D?ooool001kooooo00?o0000ooooooooool05?oo
ool2o`000;3ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`1?ooooo`006_ooool0
1Ol0003o^[ZjoooooonHV9So410@01?ooooo0ol00002ooooo`03o`000?oooooooooo0:gooooo00?o
0000ooooooooool0;?ooool2o`00053ooooo000Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`04?oo
ool3o`000;Gooooo00?o0000ooooooooool0;?ooool2o`00053ooooo000]ooooo`;o0000^?ooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo04gooooo000Zooooo`?o000000?oooooo`00
0?ooool0]oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo04gooooo000Xooooo`;o
0000_Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo04cooooo000Uooooo`?o0000
_oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo04_ooooo000Tooooo`;o0000`Ooo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo04[ooooo000Jooooo`Co000000?o410@
ooooooooool00oooool00ol0003oooooo`000030ooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool0B_ooool001cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0002o
ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0BOooool0017ooooo1_l00005oooo
o`03o`000?oooooooooo00Gooooo0_l00002ooooo`03o`000?oooooooooo0;cooooo00?o0000oooo
ooooool0<oooool00ol0003oooooooooo`18ooooo`007?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0^oooool00ol0003oooooooooo`0cooooo`03
o`000?oooooooooo00Oooooo1Ol0000looooo`007?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo00Kooooo00GoV9RHob4Q8Oo^k^koooooodA4A00looooo`007?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00ol0003ooooo
ooooo`0eooooo`03o`000?oooooooooo00Kooooo00?oV9RHob4Q8Oo^k^h0?Oooool001cooooo00?o
0000ooooooooool01?ooool3o`0000Kooooo00?o0000ooooooooool0^?ooool00ol0003ooooooooo
o`0fooooo`03o`000?oooooooooo00Kooooo00?oV9RHob4Q8Oo^k^h0??ooool001[ooooo00?oEEEE
ofIVI_l000001_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;Oooooo00?o0000
ooooooooool0=_ooool00ol0003oooooooooo`07ooooo`03ogMgMomVIVKooooo03_ooooo000Soooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0]_ooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0>_ooool002?ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`2eooooo`03o`000?oooooooooo03Oooooo0_l00004ooooo`05
o`000?nj^[[ooooooiRHV?l@4100??ooool002?ooooo0_l0000;ooooo`03o`000?oooooooooo0;Co
oooo00?o0000ooooooooool0=_ooool00ol0003oooooo`000004ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`0??ooool002?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`2cooooo`03
o`000?oooooooooo03Wooooo00?o0000ooooooooool0@_ooool002;ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0
@Oooool002;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`2`ooooo`;o0000?Ooo
ool00ol0003oooooooooo`10ooooo`008_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo0:cooooo0ol000000ooooooo0000ooooo`0looooo`03o`000?oooooooooo043ooooo000Roooo
o`;o00004Oooool00ol0003oooooooooo`2Xooooo`?o00001Oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo03oooooo000Rooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool0Y?ooool3o`0000Wooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0nooooo`00
8_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo0:3ooooo0ol0000=ooooo`03o`00
0?oooooooooo03[ooooo00?o0000ooooooooool0?_ooool002;ooooo0ol0000Cooooo`03o`000?oo
oooooooo09cooooo0ol0000Aooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0?Ooo
ool002;ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`2Iooooo`;o00005?ooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo03cooooo000Qooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool0UOooool3o`0001Oooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`0kooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo097ooooo0ol0000Kooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0>oooool0
00Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0SOooool3o`0001oooooo00?o0000
ooooooooool0>_ooool00ol0003oooooooooo`0jooooo`001Ol00002ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`02ooooo`;o00006_ooool00ol0003oooooooooo`29
ooooo`?o00008oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03Wooooo0007oooo
o`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool0Q_ooool2o`0002Kooooo00?o0000ooooooooool0>_ooool2
o`0003[ooooo0007ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`22ooooo`?o0000:Ooo
ool00ol0003oooooooooo`0iooooo`;o0000>_ooool000Oooooo00Go410@oooooooooooooooooa0@
400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`1nooooo`?o0000;Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03Oooooo0007
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`;o00007_oo
ool00ol0003oooooooooo`1jooooo`?o0000<Oooool00ol0003oooooooooo`0iooooo`03o`000?oo
oooooooo03Oooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Cooooo0_l0
000Pooooo`03o`000?oooooooooo07Kooooo0ol0000eooooo`03o`000?oooooooooo03Wooooo00?o
0000ooooooooool0=_ooool0023ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1b
ooooo`?o0000>?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03Gooooo000Poooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool0Koooool2o`0003cooooo00?o0000oooo
ooooool0>_ooool00ol0003oooooooooo`0dooooo`008?ooool2o`0002?ooooo00?o0000oooooooo
ool0Joooool3o`0003oooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0dooooo`00
8?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo06Oooooo0ol00013ooooo`03o`00
0?oooooooooo03Wooooo00?o0000ooooooooool0<oooool0023ooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`1Sooooo`?o0000Aoooool00ol0003oooooooooo`0iooooo`03o`000?oo
oooooooo03;ooooo000Pooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0Goooool3
o`0004[ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0booooo`008?ooool00ol0
003oooooooooo`0Vooooo`;o0000GOooool2o`0004kooooo00?o0000ooooooooool0>Oooool00ol0
003oooooooooo`0aooooo`007oooool3o`0002Wooooo00?o0000ooooooooool0Eoooool3o`00057o
oooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0`ooooo`007oooool00ol0003ooooo
ooooo`0Zooooo`03o`000?oooooooooo05?ooooo0ol0001Eooooo`03o`000?oooooooooo03Wooooo
00?o0000ooooooooool0;oooool001oooooo00?o0000ooooooooool0:oooool00ol0003ooooooooo
o`1?ooooo`?o0000F?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02oooooo000O
ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0Boooool3o`0005cooooo00?o0000
ooooooooool0>?ooool2o`00033ooooo000Oooooo`?o0000;Oooool00ol0003oooooooooo`17oooo
o`?o0000H?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02gooooo000Oooooo`03
o`000?oooooooooo02kooooo00?o0000ooooooooool0A?ooool2o`0006Cooooo00?o0000oooooooo
ool0>?ooool00ol0003oooooooooo`0]ooooo`005?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Ko
oooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`10ooooo`?o0000Ioooool00ol0003o
ooooooooo`0hooooo`03o`000?oooooooooo02cooooo000Dooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo03cooooo0ol0001Zooooo`03
o`000?oooooooooo03Wooooo00?o0000ooooooooool0:oooool001Cooooo00Go410@oooooooooooo
oooooa0@4005ooooo`;o0000<oooool00ol0003oooooooooo`0hooooo`?o0000K_ooool00ol0003o
ooooooooo`0iooooo`03o`000?oooooooooo02[ooooo000Dooooo`05o`000?ooooooooooooooool0
00001Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo03Cooooo0ol0001booooo`03
o`000?oooooooooo03Sooooo00?o0000ooooooooool0:_ooool001Cooooo00Go0000oooooooooooo
ooooo`000005ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0<?ooool3o`0007Ko
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Yooooo`005?ooool01Ol@413ooooo
oooooooooooo410@00Gooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0]ooooo`;o
0000N_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02Sooooo000Dooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo02Wo
oooo0ol0001looooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0:?ooool001Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o0000>?ooool00ol0003oooooooooo`0Uooooo`?o
0000P?ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02Oooooo000Nooooo`03o`00
0?oooooooooo03Sooooo00?o0000ooooooooool08Oooool3o`0008Cooooo00?o0000ooooooooool0
>?ooool00ol0003oooooooooo`0Vooooo`007Oooool00ol0003oooooooooo`0jooooo`03o`000?oo
oooooooo01gooooo0ol00028ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool09Ooo
ool001gooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Jooooo`;o0000S?ooool0
0ol0003oooooooooo`0gooooo`03o`000?oooooooooo02Gooooo000Mooooo`;o0000?Oooool00ol0
003oooooooooo`0Fooooo`?o0000S_ooool00ol0003oooooooooo`0gooooo`;o00009_ooool001go
oooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Booooo`?o0000T_ooool00ol0003o
ooooooooo`0hooooo`03o`000?oooooooooo02?ooooo000Mooooo`03o`000?oooooooooo03kooooo
00?o0000ooooooooool03_ooool3o`0009Kooooo00?o0000ooooooooool0=oooool00ol0003ooooo
ooooo`0Sooooo`007Oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00[ooooo0ol0
002Jooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool08_ooool001gooooo00?o0000
ooooooooool0@?ooool00ol0003oooooooooo`06ooooo`?o0000W_ooool00ol0003oooooooooo`0g
ooooo`03o`000?oooooooooo027ooooo000Looooo`?o0000@_ooool00ol0003oooooooooo`03oooo
o`;o0000Ooooool00oooV@3oooooooooo`0Oooooo`03o`000?oooooooooo03Sooooo00?o0000oooo
ooooool08?ooool001cooooo00?o0000ooooooooool0@oooool00ol0003oooooo`000002o`00083o
oooo00?ooiT0ooooooooool08Oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo023o
oooo000Looooo`03o`000?oooooooooo04;ooooo0ol00022ooooo`03oonI0?oooooooooo02?ooooo
00?o0000ooooooooool0=oooool00ol0003oooooooooo`09ooooo`;o000000?o410@ooooooooool0
4Oooool001cooooo00?o0000ooooooooool0?oooool3o`0000?ooooo00?o0000ooooooooool0O_oo
ool00oooV@3oooooooooo`0Uooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0Booooo`007?ooool3o`0003cooooo0ol00007ooooo`03o`000?oooooo
oooo07_ooooo0_ooV@0Yooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool01_ooool5
o`0001?ooooo000Looooo`03o`000?oooooooooo03Wooooo0ol0000;ooooo`03o`000?oooooooooo
07Sooooo0_ooV@0[ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool01Oooool01?m4
A4CogMgMooooool0000Dooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h5ooooo`;o8B4Q1Ooo
ool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0=oooool2o`0000oooooo
00?o0000ooooooooool0MOooool2oonI02kooooo00?o0000ooooooooool0=oooool00ol0003ooooo
ooooo`04ooooo`04omgMgOmEEEGoooooo`0001Cooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMg
M`Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0=?ooool3o`00
01;ooooo00?o0000ooooooooool0L_ooool2oonI037ooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`05ooooo`03ogMgMoo<c<co000001Cooooo00000ooooooo410@ooooo`02ooooo`03
oa0@4?oooooooooo00kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0aooooo`?o
00005_ooool00ol0003oooooooooo`1`ooooo`03oonI0?oooooooooo017ooooo0_o<o`0Oooooo`03
o`000?oooooooooo03Kooooo0_l00005ooooo`03onk^k_m4A4Co000001Cooooo00000ooooooo0000
ooooo`02ooooo`03o`000?oooooooooo00gooooo00?oMgMgoc8b<_ooool00oooool2o`00033ooooo
0ol0000Jooooo`03o`000?oooooooooo06gooooo0_ooV@0Cooooo`03olco0?oooooooooo023ooooo
00?o0000ooooooooool0=?ooool00ol0003oooooo`000006ooooo`03ogMgMol0003ooooo01?ooooo
00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00[ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c004ooooo`03o`000?oooooooooo02cooooo0ol0000Nooooo`03o`000?oooooooooo06_ooooo
00?ooiT0ooooooooool04_ooool00oo<o`3oooooooooo`0Qooooo`03o`000?oooooooooo03Oooooo
00?o0000ooooooooool06Oooool00003ooooool@413ooooo00;ooooo00?o410@ooooooooool02_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo02[ooooo0_l0000Rooooo`03o`000?oo
oooooooo06Sooooo0_ooV@0Dooooo`03olco0?oooooooooo02?ooooo00?o0000ooooooooool0=_oo
ool00ol0003oooooooooo`0Iooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL<ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool09oooool3o`0002Gooooo0_l0001Uooooo`?ooiT0
5?ooool2olco02Oooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Hooooo`0000Ko
ooooonk^k_lb<S;o0000oc8b<_o^k^h<ooooo`Co00001Oooool2o`0002Gooooo0ol0000Zooooo`03
o`000?oooooooooo063ooooo0_ooV@0Eooooo`;oc?l0:_ooool00ol0003oooooooooo`0fooooo`03
o`000?oooooooooo01Oooooo000Kooooo`03o`000?oooooooooo027ooooo0ol0000^ooooo`03o`00
0?oooooooooo05cooooo0oooV@0Fooooo`03olco0?oooooooooo02_ooooo00?o0000ooooooooool0
=Oooool00ol0003oooooooooo`0Gooooo`006oooool00ol0003oooooooooo`0Nooooo`?o0000<_oo
ool00ol0003oooooooooo`1Gooooo`CooiT05oooool2olco00kooooo0_lco`0Nooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool05_ooool001_ooooo00?o0000ooooooooool06oooool3
o`0003Kooooo00?o0000ooooooooool0D_ooool4oonI01Wooooo0_o<o`0?ooooo`03oc?o0?oooooo
oooo01oooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Eooooo`006_ooool00ol0
003oooooooooo`0Jooooo`;o0000>_ooool00ol0003oooooooooo`1=ooooo`CooiT06_ooool3olco
013ooooo00?o<ol0ooooooooool08Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo
01Cooooo000Jooooo`;o00006?ooool3o`0003gooooo00?o0000ooooooooool0A_ooool6oonI01co
oooo0_o<o`0Booooo`03oc?o0?oooooooooo02?ooooo00?o0000ooooooooool0=Oooool00ol0003o
ooooooooo`0Dooooo`006_ooool00ol0003oooooooooo`0Dooooo`?o0000@Oooool00ol0003ooooo
ooooo`0mooooo`SooiT08?ooool2olco01;ooooo0_lco`0Vooooo`03o`000?oooooooooo03Kooooo
00?o0000ooooooooool04oooool001[ooooo00?o0000ooooooooool04Oooool3o`0004Gooooo00?o
0000ooooooooool0<Oooool;oonI02Kooooo0_o<o`0Booooo`;o<ol0:Oooool00ol0003ooooooooo
o`0fooooo`03o`000?oooooooooo01;ooooo000Jooooo`03o`000?oooooooooo00kooooo0ol00019
ooooo`03o`000?oooooooooo05oooooo0_o<o`0Cooooo`03oc?o0?oooooooooo00_ooooo0_l0ofHM
ooooo`03o`000?oooooooooo03Gooooo0_l0000Cooooo`006_ooool00ol0003oooooooooo`0<oooo
o`;o0000COooool00ol0003oooooooooo`1Looooo`;oc?l04oooool2oc?o00gooooo00?o0?mVoooo
ooooool07_ooool00ol0003oooooooooo`0dooooo`;o00004oooool001Wooooo0ol0000:ooooo`?o
0000D?ooool00ol0003oooooooooo`1Iooooo`;oc?l04oooool2oc?o00gooooo0_l0ofHRooooo`03
o`000?oooooooooo03Gooooo00?o0000ooooooooool04?ooool001[ooooo00?o0000ooooooooool0
1_ooool3o`0005Cooooo00?o0000ooooooooool0EOooool3olco01?ooooo0_lco`0>ooooo`03o`3o
I_oooooooooo02;ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0?ooooo`006Ooo
ool00ol0003oooooooooo`04ooooo`?o0000F?ooool00ol0003oooooooooo`1Aooooo`?oc?l04ooo
ool3oc?o00oooooo00?o0?mVooooooooool09?ooool00ol0003oooooooooo`0eooooo`03o`000?oo
oooooooo00oooooo000Iooooo`04o`000?ooooooooooooooo`?o0000G?ooool00ol0003ooooooooo
o`1<ooooo`Coc?l05?ooool2oc?o013ooooo0_l0ofHXooooo`03o`000?oooooooooo03Gooooo00?o
0000ooooooooool03_ooool001Wooooo1?l0001Pooooo`03o`000?oooooooooo04Kooooo1Oo<o`0F
ooooo`;o<ol04?ooool2o`3oIR_ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0=
ooooo`006Oooool2o`0006?ooooo00?o0000ooooooooool0?oooool6olco01Wooooo0_lco`0Aoooo
o`03o`3oI_oooooooooo00_ooooo0_l0oolOooooo`03o`000?oooooooooo03Cooooo00?o0000oooo
ooooool03Oooool000oooooo1?l000000ol@413oooooooooo`05ooooo`03o`000?oooooooooo067o
oooo00?o0000ooooooooool0=Oooool9olco01gooooo0_lco`0Aooooo`;o0?mV3?ooool2o`3oob7o
oooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0<ooooo`004Oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0;?ooool8olco02Cooooo
0_lco`0Aooooo`;o0?mV3Oooool00ol0ooooooooooooo`0Rooooo`03o`000?oooooooooo03Gooooo
00?o0000ooooooooool02oooool0017ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`1Qooooo`03o`000?oooooooooo02Oooooo1?o<o`0Yooooo`?o<ol04Oooool2o`3oIPgooooo0_l0
oolVooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool02_ooool0017ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo053ooooo0olco`0A
ooooo`?o0?mV3Oooool2o`3oobWooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0:
ooooo`004Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo067ooooo00?o0000oooo
ooooool0C?ooool3oc?o01;ooooo0_l0ofH?ooooo`03o`3ooooooooooooo02[ooooo00?o0000oooo
ooooool0=?ooool00ol0003oooooooooo`09ooooo`004Oooool00ol0003oooooooooo`0<ooooo`;o
0000H_ooool00ol0003oooooooooo`17ooooo`Co<ol04oooool2o`3oIPoooooo0_l0ool=ooooo`;o
06Ko7_ooool00ol0003oooooooooo`0cooooo`?o00002_ooool0017ooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo047ooooo1Olco`0Eooooo`;o0?mV
3oooool2o`3oo`kooooo00?o06Koooooooooool07oooool00ol0003oooooooooo`0_ooooo`?o0000
0_ooool00ol0003oooooooooo`08ooooo`003oooool00omEEEGoIVIVo`00000Aooooo`03o`000?oo
oooooooo063ooooo00?o0000ooooooooool0??ooool4oc?o01Oooooo0ol0ofH@ooooo`03o`3ooooo
oooooooo00cooooo0_l0I_lSooooo`03o`000?oooooooooo02_ooooo0ol00005ooooo`03o`000?oo
oooooooo00Sooooo000Tooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0=_ooool5
oc?o01Wooooo0_l0ofHAooooo`;o0?oo3Oooool2o`1VobKooooo00?o0000ooooooooool09_ooool4
o`0000Sooooo00?o0000ooooooooool02?ooool002Gooooo00?o0000ooooooooool0H?ooool00ol0
003oooooooooo`0^ooooo`Oo<ol06oooool3o`3oIQ7ooooo0_l0ool>ooooo`03o`1Voooooooooooo
02Oooooo00?o0000ooooooooool08_ooool3o`0000cooooo00?o0000ooooooooool02?ooool002Ko
oooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0Oooooo`ko<ol07oooool3o`3oIQ7o
oooo0ol0ool>ooooo`;o06Ko:_ooool00ol0003oooooooooo`0Oooooo`?o00004?ooool00ol0003o
ooooooooo`07ooooo`009oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo04Sooooo
0ol0ofHBooooo`;o0?oo3oooool2o`1Vo`cooooo0_lc0?lOooooo`03o`000?oooooooooo01[ooooo
1?l0000Cooooo`03o`000?oooooooooo00Oooooo000Xooooo`;o0000HOooool00ol0003ooooooooo
o`13ooooo`Co0?mV4oooool2o`3oo`oooooo0_l0I_l=ooooo`03oc<0oooooooooooo023ooooo00?o
0000ooooooooool05_ooool3o`0001Oooooo00?o0000ooooooooool01oooool002[ooooo00?o0000
ooooooooool0Goooool00ol0003oooooooooo`0mooooo`Go0?mV5?ooool3o`3oo`oooooo0_l0I_l=
ooooo`;o<`3o9?ooool00ol0003oooooooooo`0Booooo`?o00006_ooool00ol0003oooooooooo`07
ooooo`00:oooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo03Oooooo1Ol0ofHGoooo
o`;o0?oo4?ooool2o`1Vo`gooooo0_lc0?lWooooo`03o`000?oooooooooo00gooooo1?l0000Moooo
o`03o`000?oooooooooo00Oooooo000/ooooo`03o`000?oooooooooo05oooooo00?o0000oooooooo
ool0<Oooool5o`3oIQWooooo0ol0ool@ooooo`;o06Ko3_ooool00olc0?ooooooooooo`0Wooooo`03
o`000?oooooooooo00[ooooo0ol0000Qooooo`03o`000?oooooooooo00Oooooo000]ooooo`03o`00
0?oooooooooo05oooooo00?o0000ooooooooool0:?ooool8o`3oIQ_ooooo0ol0oolAooooo`;o06Ko
3_ooool2oc<0ob_ooooo00?o0000ooooooooool01_ooool3o`0002Cooooo00?o0000ooooooooool0
1oooool002kooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0Mooooo`[o0?mV8?oo
ool3o`3ooa;ooooo0_l0I_l>ooooo`;o<`3o3?ooool2ol`0ob3ooooo00Co0000oooooooooooooooo
1?l0000Wooooo`03o`000?oooooooooo00Oooooo000_ooooo`;o0000H?ooool00ol0003ooooooooo
o`0Gooooo`Go0?mV9oooool3o`3ooa?ooooo0_l0I_l>ooooo`;o<`3o3Oooool00oo<0?oooooooooo
o`0Qooooo`?o0000;?ooool00ol0003oooooooooo`06ooooo`00<Oooool00ol0003oooooooooo`1N
ooooo`;o0000?oooool4o`3ooa?ooooo0ol0I_l?ooooo`03oc<0oooooooooooo00_ooooo0_o<0?lQ
ooooo`?o000000?oooooo`000?ooool0;?ooool00ol0003oooooooooo`06ooooo`00<_ooool00ol0
003oooooooooo`1Oooooo`03o`000?oooooooooo03Oooooo1Ol0oolDooooo`?o06Ko4?ooool2oc<0
o`cooooo0_o<0?lPooooo`?o00001?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo
00Kooooo000cooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool0<?ooool6o`3ooaKo
oooo0ol0I_lAooooo`;o<`3o3Oooool00oo<0?ooooooooooo`0Looooo`Co00002?ooool00ol0003o
ooooooooo`0Zooooo`03o`000?oooooooooo00Kooooo000dooooo`03o`000?oooooooooo05oooooo
00?o0000ooooooooool0:_ooool5o`3ooaWooooo0ol0I_lAooooo`?o<`3o3Oooool2ol`0oacooooo
0ol0000=ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool01_ooool003Gooooo00?o
0000ooooooooool0Goooool00ol0003oooooooooo`0Tooooo`Go0?oo6oooool3o`1Voa;ooooo0_lc
0?l>ooooo`;oc03o3?ooool2ool0V@gooooo0ol0000Aooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool01_ooool003Kooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0N
ooooo`Go0?oo7Oooool3o`1Voa;ooooo0olc0?l>ooooo`;oc03o3Oooool00ooo09Woooooooooo`09
ooooo`Co00005Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Kooooo000goooo
o`;o0000H?ooool00ol0003oooooooooo`0@ooooo`go0?oo7oooool3o`1Voa?ooooo0_lc0?l@oooo
o`03ol`0oooooooooooo00cooooo00?oo`2Iooooooooool01oooool3o`0001Wooooo00?o0000oooo
ooooool09oooool00ol0003oooooooooo`06ooooo`00>Oooool00ol0003oooooooooo`1Nooooo`03
o`000?oooooooooo03Oooooo1?l0I_lCooooo`?o<`3o4?ooool2ol`0o`gooooo0_oo09T7ooooo`?o
00007Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Gooooo000jooooo`03o`00
0?oooooooooo05kooooo00?o0000ooooooooool0<Oooool5o`1VoaGooooo0_lc0?lAooooo`;oc03o
3_ooool00ooo09Woooooooooo`03ooooo`Co00008Oooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo00Gooooo000kooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0:_oo
ool6o`1VoaOooooo0olc0?lAooooo`;oc03o3oooool01?oo09Woooooooooooooool3o`0002Kooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`05ooooo`00??ooool00ol0003ooooooooo
o`1Nooooo`03o`000?oooooooooo02Cooooo1Ol0I_lJooooo`?o<`3o4Oooool3ol`0o`oooooo0_oo
09T01?oooooo0000o`000?l00007ooooo`;oo`008?ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo00Gooooo000mooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool07_oo
ool5o`1Voa_ooooo1?lc0?lBooooo`;oc03o4?ooool2ool0V@?o00002Oooool00ooo003ooooooooo
o`0Qooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool01Oooool003kooooo0_l0001O
ooooo`03o`000?oooooooooo01Sooooo1Ol0I_lMooooo`?o<`3o5?ooool2ol`0oa3ooooo0_oo09T0
0ol0003oooooooooo`09ooooo`;oo`009Oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo00Gooooo0010ooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool03oooool8o`1V
oakooooo1?lc0?lEooooo`;oc03o3oooool00ol0003oo`2Iool0V@0=ooooo`03ool00?oooooooooo
02Kooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`05ooooo`00@Oooool00ol0003o
ooooooooo`1Mooooo`03o`000?oooooooooo00Sooooo1_l0I_lRooooo`Co<`3o5_ooool3ol`0o`go
oooo0ol00002ool0V@gooooo0_oo000Zooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool01Oooool004;ooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`0[ooooo`Co<`3o
5oooool3ol`0o`gooooo0ol000000oooooooo`2Iool0V@0>ooooo`03ool00?oooooooooo02[ooooo
00?o0000ooooooooool08Oooool00ol0003oooooooooo`05ooooo`00@oooool00ol0003ooooooooo
o`1Mooooo`03o`000?oooooooooo02Gooooo1Olc0?lHooooo`?oc03o3Oooool3o`000004oooooooo
09Woo`2Iool0V@kooooo0_oo000^ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0
1?ooool004Cooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`0Oooooo`Go<`3o6_oo
ool3ol`0o`cooooo1?l000001?ooooooo`2Iool0VOoo09T?ooooo`;oo`00<Oooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo00Cooooo0015ooooo`03o`000?oooooooooo05gooooo00?o
0000ooooooooool06?ooool6oc<0oa_ooooo1?o<0?l<ooooo`?o00000_ooool3ool0V@oooooo0ooo
000dooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool01?ooool004Kooooo0_l0001N
ooooo`03o`000?oooooooooo017ooooo1_lc0?lNooooo`?oc03o3Oooool3o`0000?ooooo0_oo09T@
ooooo`;oo`00>?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Cooooo0018oooo
o`03o`000?oooooooooo05cooooo00?o0000ooooooooool02?ooool8oc<0ob3ooooo1?o<0?l<oooo
o`Co00000oooool3ool0VA3ooooo0_oo000jooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool01?ooool004Wooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`02ooooo`Go
<`3o9?ooool4ol`0o`gooooo0ol00004ooooo`?oo`2I4Oooool2ool003gooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`04ooooo`00B_ooool00ol0003oooooooooo`1Looooo`03o`00
0?oooooooooo02Kooooo1?o<0?l>ooooo`?o00001?ooool3ool0VA;ooooo0_oo0010ooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool01?ooool004_ooooo00?o0000ooooooooool0G?oo
ool00ol0003oooooooooo`0Pooooo`Goc03o3_ooool4o`0000Gooooo0_oo09TBooooo`?oo`00@ooo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo001<ooooo`03o`000?oooooo
oooo05cooooo00?o0000ooooooooool06Oooool6ol`0oa3ooooo0ol00006ooooo`?oo`2I4_ooool2
ool004Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`03ooooo`00COooool2o`00
05gooooo00?o0000ooooooooool04_ooool6ol`0oa?ooooo0ol00006ooooo`?oo`2I4oooool2ool0
04Wooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`03ooooo`00Coooool00ol0003o
ooooooooo`1Kooooo`03o`000?oooooooooo00_ooooo1_o<0?lFooooo`?o00001_ooool3ool0VACo
oooo0_oo001<ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool00oooool0053ooooo
00?o0000ooooooooool0Foooool00ol0003oooooooooo`02ooooo`Soc03o6?ooool4o`0000Gooooo
1?oo09TDooooo`?oo`00Coooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00?ooooo
001Aooooo`03o`000?oooooooooo05Wooooo1_o<0?lMooooo`?o00001Oooool4ool0VAGooooo0ooo
001Cooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool00oooool005;ooooo00?o0000
ooooooooool0Foooool00ol0003oooooooooo`0Jooooo`?o00001?ooool4ool0VAKooooo0ooo001G
ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool00oooool005?ooooo00?o0000oooo
ooooool0Foooool00ol0003oooooooooo`0Eooooo`Co00000_ooool5ool0VAOooooo0ooo001Joooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool00oooool005Cooooo0_l0001Looooo`03
o`000?oooooooooo017ooooo0ol00006ool0VAWooooo0ooo001Nooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool00oooool005Kooooo00?o0000ooooooooool0F_ooool00ol0003ooooo
ooooo`0=ooooo`Koo`2I7?ooool3ool006;ooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`02ooooo`00Eoooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00Gooooo1ooo
09TOooooo`?oo`00I_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00;ooooo001H
ooooo`03o`000?oooooooooo05Wooooo2?oo09T3o`0001oooooo1?oo001Zooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool00_ooool005Wooooo00?o0000ooooooooool0D_ooool6ool0
V@;ooooo00?o0000ooooooooool00ol0000Nooooo`Coo`00K_ooool00ol0003oooooooooo`0Doooo
o`03o`000?oooooooooo00;ooooo001Jooooo`03o`000?oooooooooo05[ooooo0_l0000Mooooo`Co
o`00Loooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00;ooooo001Kooooo`03o`00
0?oooooooooo05Wooooo00?o0000ooooooooool05oooool5ool007Sooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`02ooooo`00G?ooool2o`0005Wooooo00?o0000ooooooooool04?oo
ool7ool007kooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`02ooooo`00G_ooool0
0ol0003oooooooooo`1Fooooo`03o`000?oooooooooo00[ooooo1_oo0026ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool00_ooool005oooooo00?o0000ooooooooool0EOooool00ol0
003oooooooooo`03ooooo`Ooo`00S?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
007ooooo001Pooooo`03o`000?oooooooooo057ooooo2Ooo002Dooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool00Oooool0067ooooo00?o0000ooooooooool0B_ooool6ool000?ooooo
00?o0000ooooooooool0V?ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo007ooooo
001Rooooo`03o`000?oooooooooo05;ooooo00?o0000ooooooooool0VOooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo007ooooo001Sooooo`;o0000D_ooool00ol0003oooooooooo`2J
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00Oooool006Gooooo00?o0000oooo
ooooool0Coooool00ol0003oooooooooo`2Jooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool00Oooool006Kooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`2Kooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool00Oooool006Oooooo00?o0000ooooooooool0
COooool00ol0003oooooooooo`2Looooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
0Oooool006Sooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`2Mooooo`03o`000?oo
oooooooo00_ooooo0Ol00001ooooo`7ooooo001Yooooo`03o`000?oooooooooo04_ooooo00?o0000
ooooooooool0WOooool00ol0003oooooooooo`0;ooooo`7o00000Oooool1ooooo`00J_ooool00ol0
003oooooooooo`1:ooooo`03o`000?oooooooooo09kooooo00?o0000ooooooooool02_ooool1o`00
007ooooo0Oooool006_ooooo0_l0001:ooooo`03o`000?oooooooooo09oooooo00?o0000oooooooo
ool02Oooool1o`00007ooooo0Oooool006gooooo00?o0000ooooooooool0Aoooool00ol0003ooooo
ooooo`2Pooooo`03o`000?oooooooooo00Sooooo0Ol00001ooooo`7ooooo001^ooooo`03o`000?oo
oooooooo04Kooooo00?o0000ooooooooool0XOooool00ol0003oooooooooo`07ooooo`7o00000Ooo
ool1ooooo`00Koooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo0:7ooooo00?o0000
ooooooooool01oooool1o`00007ooooo0Oooool0073ooooo00?o0000ooooooooool0A?ooool00ol0
003oooooooooo`2Rooooo`03o`000?oooooooooo00Kooooo0Ol00001ooooo`7ooooo001aooooo`03
o`000?oooooooooo04?ooooo00?o0000ooooooooool0Xoooool00ol0003oooooooooo`05ooooo`7o
00000Oooool1ooooo`00L_ooool2o`0004;ooooo00?o0000ooooooooool0YOooool00ol0003ooooo
ooooo`05ooooo`7o00000Oooool007Cooooo00?o0000ooooooooool0?oooool00ol0003ooooooooo
o`2Vooooo`03o`000?oooooooooo00Cooooo0Ol00001ooooo`00MOooool00ol0003oooooooooo`0n
ooooo`03o`000?oooooooooo0:Kooooo00?o0000ooooooooool01?ooool1o`00007ooooo001foooo
o`03o`000?oooooooooo03gooooo00?o0000ooooooooool0Yoooool00ol0003oooooooooo`03oooo
o`7o00000Oooool007Oooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`2Xooooo`03
o`000?oooooooooo00;ooooo0Ol00001ooooo`00N?ooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo0:Wooooo00Go0000ooooooooooooooooo`000001ooooo`00NOooool00ol0003ooooo
ooooo`0jooooo`03o`000?oooooooooo0:[ooooo00Co0000oooooooooooo00000Oooool007[ooooo
0_l0000jooooo`03o`000?oooooooooo0:[ooooo00Co0000oooooooooooo00000Oooool007cooooo
00?o0000ooooooooool0=oooool00ol0003oooooooooo`2[ooooo`03o`000?oooooooooo007o0000
001mooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0[?ooool1o`00007ooooo0Ol0
000007kooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`2]ooooo`;o0000001ooooo
o`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0[?ooool3o`000000P?ooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo0:Sooooo1?l00003ooooo`00POooool2o`0003?ooooo
00?o0000ooooooooool0YOooool3o`0000Oooooo0023ooooo`03o`000?oooooooooo033ooooo00?o
0000ooooooooool0XOooool4o`0000[ooooo0024ooooo`03o`000?oooooooooo02oooooo00?o0000
ooooooooool0WOooool4o`0000kooooo0025ooooo`03o`000?oooooooooo02kooooo00?o0000oooo
ooooool0VOooool4o`0001;ooooo0026ooooo`03o`000?oooooooooo02gooooo00?o0000oooooooo
ool0UOooool4o`0001Kooooo0027ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0
T_ooool3o`0001[ooooo0028ooooo`;o0000;?ooool00ol0003oooooooooo`2>ooooo`Co00007Ooo
ool008[ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`2:ooooo`Co00008Oooool0
08_ooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`26ooooo`Co00009Oooool008co
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`22ooooo`Co0000:Oooool008gooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`1oooooo`?o0000;Oooool008kooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`1kooooo`Co0000<?ooool008oooooo00?o0000
ooooooooool09?ooool00ol0003oooooooooo`1gooooo`Co0000=?ooool0093ooooo0_l0000Toooo
o`03o`000?oooooooooo07?ooooo1?l0000hooooo`00T_ooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo073ooooo0ol0000looooo`00Toooool00ol0003oooooooooo`0Pooooo`03o`00
0?oooooooooo06cooooo1?l0000oooooo`00U?ooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo06Sooooo1?l00013ooooo`00UOooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo06Cooooo1?l00017ooooo`00U_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
063ooooo1?l0001;ooooo`00Uoooool2o`0001gooooo00?o0000ooooooooool0GOooool3o`0004oo
oooo002Iooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0FOooool4o`0005;ooooo
002Jooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0EOooool4o`0005Kooooo002K
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0DOooool4o`0005[ooooo002Loooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0COooool4o`0005kooooo002Mooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool0B_ooool3o`0006;ooooo002Nooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool0A_ooool4o`0006Gooooo002Oooooo`;o00005?oo
ool00ol0003oooooooooo`13ooooo`Co0000JOooool00:7ooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`0oooooo`Co0000KOooool00:;ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`0kooooo`Co0000LOooool00:?ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0hooooo`?o0000MOooool00:Cooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0dooooo`Co0000N?ooool00:Gooooo00?o0000ooooooooool03Oooool00ol0003ooooooooo
o`0`ooooo`Co0000O?ooool00:Kooooo0_l0000=ooooo`03o`000?oooooooooo02cooooo1?l00020
ooooo`00Z?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Wooooo0ol00024oooo
o`00ZOooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02Gooooo1?l00027ooooo`00
Z_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo027ooooo1?l0002;ooooo`00Zooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo01gooooo1?l0002?ooooo`00[?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Wooooo1?l0002Cooooo`00[Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo01Kooooo0ol0002Gooooo`00[_ooool2o`0000Go
oooo00?o0000ooooooooool04_ooool4o`0009[ooooo002`ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool03_ooool4o`0009kooooo002aooooo`05o`000?ooooooooooooooool00000
3?ooool4o`000:;ooooo002booooo`04o`000?ooooooooooo`0000Sooooo1?l0002Vooooo`00/ooo
ool00ol0003oooooo`000005ooooo`?o0000Z_ooool00;Cooooo0_l000000ooooooo0000o`000002
o`000:gooooo002eooooo`;o0000/Oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {319.688, 0}} -> {-0.0710364, -0.0181728, \
0.0035149, 0.0035149}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .89104 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-16 1.0656 -0.0363427 1.0656 [
[.02544 .21571 -12 -8.9133 ]
[.02544 .21571 0 .0867 ]
[.16074 .16277 -11.6592 -9 ]
[.16074 .16277 .34081 0 ]
[.3021 .10747 -5.60025 -9 ]
[.3021 .10747 .39975 0 ]
[.44992 .04965 -5.37091 -9 ]
[.44992 .04965 .62909 0 ]
[.60467 -0.01084 -5.14157 -9 ]
[.60467 -0.01084 .85843 0 ]
[.66454 .05085 0 -6.20675 ]
[.66454 .05085 6 2.79325 ]
[.80797 .25198 0 -6.0417 ]
[.80797 .25198 6 2.9583 ]
[.93071 .4241 0 -5.90576 ]
[.93071 .4241 6 3.09424 ]
[.02254 .22988 -12 -2.74631 ]
[.02254 .22988 0 6.25369 ]
[.0142 .29178 -24 -2.78907 ]
[.0142 .29178 0 6.21093 ]
[.00558 .35578 -6 -2.83339 ]
[.00558 .35578 0 6.16661 ]
[-0.00334 .42198 -18 -2.87938 ]
[-0.00334 .42198 0 6.12062 ]
[-0.01257 .49051 -6 -2.92712 ]
[-0.01257 .49051 0 6.07288 ]
[ 0 0 0 0 ]
[ 1 .89104 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03495 .22504 m
.61241 0 L
s
.03495 .22504 m
.03971 .2297 L
s
[(-2)] .02544 .21571 1 .98073 Mshowa
.16988 .17246 m
.17445 .1773 L
s
[(-1)] .16074 .16277 .9432 1 Mshowa
.31082 .11753 m
.31518 .12256 L
s
[(0)] .3021 .10747 .86675 1 Mshowa
.45818 .0601 m
.46231 .06533 L
s
[(1)] .44992 .04965 .7903 1 Mshowa
.61241 0 m
.61628 .00542 L
s
[(2)] .60467 -0.01084 .71386 1 Mshowa
.125 Mabswid
.06148 .2147 m
.06431 .21752 L
s
.08823 .20428 m
.09104 .20712 L
s
.11521 .19376 m
.118 .19663 L
s
.14243 .18316 m
.14519 .18604 L
s
.19758 .16166 m
.20029 .16459 L
s
.22551 .15078 m
.22821 .15373 L
s
.2537 .13979 m
.25637 .14277 L
s
.28213 .12871 m
.28478 .13171 L
s
.33977 .10625 m
.34236 .10929 L
s
.36897 .09487 m
.37153 .09794 L
s
.39844 .08339 m
.40097 .08648 L
s
.42817 .0718 m
.43068 .07491 L
s
.48846 .0483 m
.49091 .05146 L
s
.51902 .03639 m
.52144 .03958 L
s
.54986 .02437 m
.55225 .02758 L
s
.58099 .01224 m
.58335 .01547 L
s
.25 Mabswid
.61241 0 m
.97291 .505 L
s
.65208 .05558 m
.64586 .05794 L
s
[(0)] .66454 .05085 -1 .37928 Mshowa
.79537 .2563 m
.78907 .25846 L
s
[(2)] .80797 .25198 -1 .3426 Mshowa
.91799 .42808 m
.91164 .43006 L
s
[(4)] .93071 .4241 -1 .31239 Mshowa
.125 Mabswid
.69012 .10886 m
.68637 .11025 L
s
.72662 .16 m
.72286 .16135 L
s
.76168 .2091 m
.75791 .21042 L
s
.82778 .3017 m
.82399 .30297 L
s
.85897 .3454 m
.85518 .34664 L
s
.88903 .3875 m
.88522 .38871 L
s
.94594 .46722 m
.94211 .46839 L
s
.25 Mabswid
.03495 .22504 m
0 .48612 L
s
.03495 .22504 m
.04116 .22262 L
s
[(-1)] .02254 .22988 1 -0.38971 Mshowa
.02665 .28704 m
.03288 .28468 L
s
[(-0.5)] .0142 .29178 1 -0.38021 Mshowa
.01807 .35115 m
.02431 .34884 L
s
[(0)] .00558 .35578 1 -0.37036 Mshowa
.00919 .41747 m
.01546 .41521 L
s
[(0.5)] -0.00334 .42198 1 -0.36014 Mshowa
0 .48612 m
.00629 .48392 L
s
[(1)] -0.01257 .49051 1 -0.34953 Mshowa
.125 Mabswid
.03331 .23728 m
.03704 .23583 L
s
.03166 .2496 m
.03539 .24816 L
s
.03 .262 m
.03373 .26056 L
s
.02833 .27448 m
.03207 .27305 L
s
.02496 .29969 m
.0287 .29828 L
s
.02325 .31243 m
.02699 .31102 L
s
.02154 .32525 m
.02528 .32385 L
s
.01981 .33816 m
.02355 .33676 L
s
.01632 .36423 m
.02007 .36285 L
s
.01455 .37741 m
.01831 .37603 L
s
.01278 .39067 m
.01653 .3893 L
s
.01099 .40402 m
.01475 .40266 L
s
.00738 .43101 m
.01114 .42966 L
s
.00555 .44464 m
.00932 .4433 L
s
.00371 .45837 m
.00748 .45704 L
s
.00186 .4722 m
.00563 .47087 L
s
.25 Mabswid
.03495 .22504 m
0 .48612 L
s
0 .48612 m
.46953 .89104 L
s
.46953 .89104 m
.47294 .65459 L
s
.47294 .65459 m
.03495 .22504 L
s
.61241 0 m
.97291 .505 L
s
.97291 .505 m
1 .75117 L
s
1 .75117 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.03495 .22504 m
0 .48612 L
s
0 .48612 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.61241 0 m
.03495 .22504 L
s
.47294 .65459 m
.97291 .505 L
s
.97291 .505 m
1 .75117 L
s
1 .75117 m
.46953 .89104 L
s
.46953 .89104 m
.47294 .65459 L
s
0 0 m
1 0 L
1 .89104 L
0 .89104 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.45054 .6877 m
.48947 .68489 L
s
1 0 .6 r
.44917 .66706 m
.48676 .66432 L
s
1 0 0 r
.48947 .68489 m
.52988 .67984 L
s
.8 0 1 r
.44781 .64638 m
.48403 .64371 L
s
1 0 .6 r
.48676 .66432 m
.52583 .65939 L
s
.2 0 1 r
.44645 .62566 m
.4813 .62306 L
s
.8 0 1 r
.48403 .64371 m
.52178 .6389 L
s
1 0 0 r
.52988 .67984 m
.57051 .67259 L
s
0 .4 1 r
.44508 .60487 m
.47857 .60236 L
s
.2 0 1 r
.4813 .62306 m
.51772 .61837 L
s
1 0 .6 r
.52583 .65939 m
.56519 .65229 L
s
0 1 1 r
.44372 .58401 m
.47583 .58159 L
s
0 .4 1 r
.47857 .60236 m
.51365 .5978 L
s
.8 0 1 r
.52178 .6389 m
.55986 .63196 L
s
0 1 .4 r
.44236 .56301 m
.47307 .56071 L
s
0 1 1 r
.47583 .58159 m
.50956 .57717 L
s
.2 0 1 r
.51772 .61837 m
.55452 .61159 L
s
1 0 0 r
.57051 .67259 m
.61059 .66323 L
s
0 1 .4 r
.47307 .56071 m
.50546 .55645 L
s
0 .4 1 r
.51365 .5978 m
.54916 .59119 L
s
.2 1 0 r
.44103 .54172 m
.4703 .5396 L
s
1 0 .6 r
.56519 .65229 m
.60404 .64312 L
s
0 1 1 r
.50956 .57717 m
.5438 .57073 L
s
.2 1 0 r
.4703 .5396 m
.5013 .53554 L
s
.8 0 1 r
.55986 .63196 m
.59747 .62298 L
s
.8 1 0 r
.43976 .5198 m
.46746 .51796 L
s
0 1 .4 r
.50546 .55645 m
.5384 .55021 L
s
.2 0 1 r
.55452 .61159 m
.5909 .60281 L
s
.8 1 0 r
.46746 .51796 m
.497 .51419 L
s
.2 1 0 r
.5013 .53554 m
.53293 .52953 L
s
0 .4 1 r
.54916 .59119 m
.58432 .58261 L
s
1 .6 0 r
.43863 .49654 m
.46451 .49512 L
s
0 1 1 r
.5438 .57073 m
.57772 .56237 L
s
.8 1 0 r
.497 .51419 m
.52726 .50846 L
s
1 .6 0 r
.46451 .49512 m
.49238 .49178 L
s
1 0 0 r
.61059 .66323 m
.6496 .65184 L
s
0 1 .4 r
.5384 .55021 m
.57108 .54208 L
s
1 0 .6 r
.60404 .64312 m
.64185 .63196 L
s
.2 1 0 r
.53293 .52953 m
.56435 .52164 L
s
1 .6 0 r
.49238 .49178 m
.52111 .48647 L
s
.8 0 1 r
.59747 .62298 m
.63408 .61206 L
s
.2 0 1 r
.5909 .60281 m
.6263 .59213 L
s
.8 1 0 r
.52726 .50846 m
.55738 .50087 L
s
0 .4 1 r
.58432 .58261 m
.61852 .57218 L
s
0 1 1 r
.57772 .56237 m
.61072 .5522 L
s
1 .6 0 r
.52111 .48647 m
.54977 .47925 L
s
0 1 .4 r
.57108 .54208 m
.60287 .53217 L
s
.2 1 0 r
.56435 .52164 m
.59492 .51202 L
s
1 0 0 r
.6496 .65184 m
.6871 .63853 L
s
.8 1 0 r
.55738 .50087 m
.58665 .49155 L
s
1 0 .6 r
.64185 .63196 m
.67815 .61892 L
s
.8 0 1 r
.63408 .61206 m
.66919 .5993 L
s
1 .6 0 r
.54977 .47925 m
.57759 .4703 L
s
.2 0 1 r
.6263 .59213 m
.66023 .57967 L
s
0 .4 1 r
.61852 .57218 m
.65126 .56002 L
s
0 1 1 r
.61072 .5522 m
.64226 .54035 L
s
0 1 .4 r
.60287 .53217 m
.63322 .52064 L
s
.2 1 0 r
.59492 .51202 m
.62404 .50081 L
s
.8 1 0 r
.58665 .49155 m
.61446 .48068 L
s
1 .6 0 r
.57759 .4703 m
.60389 .45979 L
s
1 0 0 r
.6871 .63853 m
.72254 .62342 L
s
1 0 .6 r
.67815 .61892 m
.7124 .60415 L
s
.8 0 1 r
.66919 .5993 m
.70225 .58488 L
s
.2 0 1 r
.66023 .57967 m
.69211 .5656 L
s
0 .4 1 r
.65126 .56002 m
.68195 .54632 L
s
0 1 1 r
.64226 .54035 m
.67177 .52702 L
s
0 1 .4 r
.63322 .52064 m
.66153 .50768 L
s
.2 1 0 r
.62404 .50081 m
.6511 .48824 L
s
.8 1 0 r
.61446 .48068 m
.64016 .46849 L
s
1 .6 0 r
.60389 .45979 m
.62796 .44802 L
s
1 0 0 r
.72254 .62342 m
.75519 .60679 L
s
1 0 .6 r
.7124 .60415 m
.74387 .58793 L
s
.8 0 1 r
.70225 .58488 m
.73254 .56908 L
s
.2 0 1 r
.69211 .5656 m
.72122 .55023 L
s
0 .4 1 r
.68195 .54632 m
.70989 .53139 L
s
0 1 1 r
.67177 .52702 m
.69854 .51254 L
s
0 1 .4 r
.66153 .50768 m
.68709 .49365 L
s
.2 1 0 r
.6511 .48824 m
.67538 .47466 L
s
.8 1 0 r
.64016 .46849 m
.663 .45538 L
s
1 .6 0 r
.62796 .44802 m
.64904 .43539 L
s
.2 1 0 r
.67538 .47466 m
.69612 .46066 L
s
.8 1 0 r
.663 .45538 m
.68225 .44193 L
s
0 1 .4 r
.68709 .49365 m
.70912 .47913 L
s
0 1 1 r
.69854 .51254 m
.72175 .49748 L
s
1 .6 0 r
.64904 .43539 m
.66646 .42256 L
s
0 .4 1 r
.70989 .53139 m
.73425 .51581 L
s
.2 0 1 r
.72122 .55023 m
.7467 .53414 L
s
.8 0 1 r
.73254 .56908 m
.75915 .55249 L
s
1 0 .6 r
.74387 .58793 m
.77161 .57085 L
s
1 0 0 r
.75519 .60679 m
.78408 .58923 L
s
0 g
.25 Mabswid
.61241 0 m
.97291 .505 L
s
.97291 .505 m
1 .75117 L
s
1 .75117 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.03495 .22504 m
0 .48612 L
s
0 .48612 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.61241 0 m
.03495 .22504 L
s
.03495 .22504 m
.61241 0 L
s
.03495 .22504 m
.03971 .2297 L
s
[(-2)] .02544 .21571 1 .98073 Mshowa
.16988 .17246 m
.17445 .1773 L
s
[(-1)] .16074 .16277 .9432 1 Mshowa
.31082 .11753 m
.31518 .12256 L
s
[(0)] .3021 .10747 .86675 1 Mshowa
.45818 .0601 m
.46231 .06533 L
s
[(1)] .44992 .04965 .7903 1 Mshowa
.61241 0 m
.61628 .00542 L
s
[(2)] .60467 -0.01084 .71386 1 Mshowa
.125 Mabswid
.06148 .2147 m
.06431 .21752 L
s
.08823 .20428 m
.09104 .20712 L
s
.11521 .19376 m
.118 .19663 L
s
.14243 .18316 m
.14519 .18604 L
s
.19758 .16166 m
.20029 .16459 L
s
.22551 .15078 m
.22821 .15373 L
s
.2537 .13979 m
.25637 .14277 L
s
.28213 .12871 m
.28478 .13171 L
s
.33977 .10625 m
.34236 .10929 L
s
.36897 .09487 m
.37153 .09794 L
s
.39844 .08339 m
.40097 .08648 L
s
.42817 .0718 m
.43068 .07491 L
s
.48846 .0483 m
.49091 .05146 L
s
.51902 .03639 m
.52144 .03958 L
s
.54986 .02437 m
.55225 .02758 L
s
.58099 .01224 m
.58335 .01547 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 256.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001@2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00gOooool5o`0008Kooooo003Mooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0Q_ooool00=ko
oooo00?oV9RHob4Q8Oo^k^h0Qoooool00=oooooo00?oV9RHob4Q8Oo^k^h0Q_ooool00>3ooooo00?o
MgMgofIVI_ooool0QOooool00>7ooooo00?o0000ooooooooool0Q?ooool00=gooooo00Go0000okZj
^_ooooooV9RHoa0@4026ooooo`00gOooool01OnHV9So410@o`000?lQ8B7oc<c<08Kooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003Tooooo`;o0000P_ooool0
0>7ooooo0ol000000ooooooo0000ooooo`21ooooo`00goooool2o`0000Cooooo0_l00021ooooo`00
g?ooool3o`0000Kooooo00?o0000ooooool00000P?ooool00=[ooooo0_l00009ooooo`03o`000?oo
oooo0000083ooooo003Gooooo`?o000000?oooooo`000?ooool02?ooool01?l0003oooooooooool0
001oooooo`00e?ooool3o`0000Cooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooo
oooo000007kooooo003Booooo`;o00004Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo07_ooooo002Zooooo`Co000000?o410@ooooooooool07_ooool3o`0001?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1kooooo`00[?ooool00ol0003oooooooooo`0Nooooo`;o
000000?oooooo`000?ooool04oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07[o
oooo002/ooooo`03o`000?oooooooooo01_ooooo0ol00004ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`1iooooo`00[?ooool00ol0003ooooooooo
o`0Iooooo`;o00006oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo07Wooooo002/
ooooo`03o`000?oooooooooo01Kooooo0ol0000Mooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool02?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^06_ooooo002/ooooo`03o`000?oooooo
oooo01Cooooo0_l000000ooooooo0000ooooo`0Mooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01oooool01OmgMgOoV9RHoooooonHV9SoMgMg06_ooooo002/ooooo`03o`000?oooooo
oooo017ooooo0ol00004ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`06ooooo`05oa0@4?ooooooooooooooool@4100Joooool00:[ooooo00?oEEEE
ofIVI_l000004Oooool2o`0002Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06
ooooo`05o`000?ooooooooooooooool00000Joooool00;_ooooo0ol0000Wooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000006_ooooo002i
ooooo`;o000000?oooooo`000?ooool09oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Cooooo00Go410@oooooooooooooooooa0@401[ooooo`00]_ooool3o`0000Cooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`1[ooooo`00/oooool3o`0002oooooo00?o0000ooooooooool02Oooool2
o`0000Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1[ooooo`00/Oooool2o`0003;ooooo00?o0000
ooooooooool02?ooool01?l0003oooooooooool0001dooooo`00[_ooool3o`000003ooooool0003o
oooo037ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1aooooo`00[?ooool2o`00
00Gooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
077ooooo002Yooooo`?o0000>_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo073o
oooo002Wooooo`;o0000?Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo06oooooo
002Tooooo`?o000000?oooooo`000?ooool0??ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo06oooooo002Rooooo`;o0000@_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo06kooooo001gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08oooool3o`0004Cooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1]ooooo`00Moooool01OmgMgOoV9RHoooooonHV9So
MgMg027ooooo0_l00017ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0K?ooool0
07Oooooo00Go410@oooooooooooooooooa0@400Nooooo`?o00000_ooool00ol0003oooooooooo`14
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0K?ooool007Oooooo00Go0000oooo
ooooooooooooo`00000Looooo`;o0000C?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo06_ooooo001gooooo`05o`000?ooooooooooooooool000006Oooool3o`0004kooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`1Zooooo`00Moooool01Ol@413ooooooooooooooooo
410@01Kooooo0ol0001Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0J_ooool0
07Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Dooooo`;o00000oooool00ol0003oooooooooo`1>
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0JOooool007Oooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Aooooo`?o0000E_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo06Sooooo002;ooooo`;o0000FOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
06Sooooo0028ooooo`?o0000Foooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo06Oo
oooo0026ooooo`;o00000oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo01Gooooo
0_l0001Xooooo`00Poooool3o`00063ooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`1Uooooo`00POooool2o`0006?ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1U
ooooo`00O_ooool4o`0006Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`1Toooo
o`00O?ooool2o`0000Cooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo06?ooooo001iooooo`?o0000J_ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo06?ooooo001gooooo`;o0000KOooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo06;ooooo001dooooo`?o000000?oooooo`000?ooool0K?ooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo067ooooo001aooooo`?o0000L_ooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo063ooooo0019ooooo`Co000000?o410@ooooooooool07oooool2o`0007Go
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1Pooooo`00Boooool00ol0003ooooo
ooooo`0Nooooo`?o0000Moooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo05oooooo
0010ooooo`Ko00001Oooool00ol0003oooooooooo`0Looooo`;o00000_ooool00ol0003ooooooooo
o`1eooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0G_ooool004_ooooo00?o0000
ooooooooool06Oooool3o`0007cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1N
ooooo`00Boooool00ol0003oooooooooo`0Gooooo`;o0000Ooooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo05gooooo001;ooooo`03o`000?oooooooooo01Cooooo0ol00021ooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0G?ooool004_ooooo00?o0000ooooooooool0
4_ooool2o`0000?ooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo05_ooooo0019ooooo`03oeEEEOmVIVKo0000017ooooo0ol00026ooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool0Foooool005_ooooo0_l00029ooooo`03o`000?oooooo
oooo027ooooo0_l0001Looooo`00F?ooool3o`000003ooooool0003ooooo08Sooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`1Iooooo`00E_ooool2o`0008kooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`1Iooooo`00Doooool3o`00093ooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`1Hooooo`00D?ooool3o`0009?ooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1Gooooo`00C_ooool2o`0000;ooooo00?o0000ooooooooool0TOooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo05Kooooo001;ooooo`?o00001Oooool00ol0
003oooooooooo`2@ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0E_ooool004Wo
oooo0_l0002Kooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0EOooool004Kooooo
1?l0002Looooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0E?ooool004Cooooo0_l0
002Pooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0E?ooool001[ooooo1Ol0000R
ooooo`?o0000X_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo05?ooooo000Joooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@08?ooool2o`000:Gooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`1Booooo`004_ooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h07_ooool3o`00
0003ooooool0003ooooo0:Cooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`1Aoooo
o`007?ooool00onHV9So8B4Qonk^kP0Kooooo`;o0000Z_ooool00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo057ooooo000Mooooo`03ogMgMomVIVKooooo01Oooooo0ol0002]ooooo`03o`00
0?oooooooooo02_ooooo00?o0000ooooooooool0D?ooool001kooooo00?o0000ooooooooool05?oo
ool2o`000;3ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`1?ooooo`006_ooool0
1Ol0003o^[ZjoooooonHV9So410@01?ooooo0ol00002ooooo`03o`000?oooooooooo0:gooooo00?o
0000ooooooooool0;?ooool2o`00053ooooo000Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`04?oo
ool3o`000;Gooooo00?o0000ooooooooool0;?ooool2o`00053ooooo000]ooooo`;o0000^?ooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo04gooooo000Zooooo`?o000000?oooooo`00
0?ooool0]oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo04gooooo000Xooooo`;o
0000_Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo04cooooo000Uooooo`?o0000
_oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo04_ooooo000Tooooo`;o0000`Ooo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo04[ooooo000Jooooo`Co000000?o410@
ooooooooool00oooool00ol0003oooooo`000030ooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool0B_ooool001cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0002o
ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0BOooool0017ooooo1_l00005oooo
o`03o`000?oooooooooo00Gooooo0_l00002ooooo`03o`000?oooooooooo0;cooooo00?o0000oooo
ooooool0<oooool00ol0003oooooooooo`18ooooo`007?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0^oooool00ol0003oooooooooo`0cooooo`03
o`000?oooooooooo00Oooooo1Ol0000looooo`007?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo00Kooooo00GoV9RHob4Q8Oo^k^koooooodA4A00looooo`007?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00ol0003ooooo
ooooo`0eooooo`03o`000?oooooooooo00Kooooo00?oV9RHob4Q8Oo^k^h0?Oooool001cooooo00?o
0000ooooooooool01?ooool3o`0000Kooooo00?o0000ooooooooool0^?ooool00ol0003ooooooooo
o`0fooooo`03o`000?oooooooooo00Kooooo00?oV9RHob4Q8Oo^k^h0??ooool001[ooooo00?oEEEE
ofIVI_l000001_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;Oooooo00?o0000
ooooooooool0=_ooool00ol0003oooooooooo`07ooooo`03ogMgMomVIVKooooo03_ooooo000Soooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0]_ooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0>_ooool002?ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`2eooooo`03o`000?oooooooooo03Oooooo0_l00004ooooo`05
o`000?nj^[[ooooooiRHV?l@4100??ooool002?ooooo0_l0000;ooooo`03o`000?oooooooooo0;Co
oooo00?o0000ooooooooool0=_ooool00ol0003oooooo`000004ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`0??ooool002?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`2cooooo`03
o`000?oooooooooo03Wooooo00?o0000ooooooooool0@_ooool002;ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0
@Oooool002;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`2`ooooo`;o0000?Ooo
ool00ol0003oooooooooo`10ooooo`008_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo0:cooooo0ol000000ooooooo0000ooooo`0looooo`03o`000?oooooooooo043ooooo000Roooo
o`;o00004Oooool00ol0003oooooooooo`2Xooooo`?o00001Oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo03oooooo000Rooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool0Y?ooool3o`0000Wooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0nooooo`00
8_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo0:3ooooo0ol0000=ooooo`03o`00
0?oooooooooo03[ooooo00?o0000ooooooooool0?_ooool002;ooooo0ol0000Cooooo`03o`000?oo
oooooooo09cooooo0ol0000Aooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0?Ooo
ool002;ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`2Iooooo`;o00005?ooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo03cooooo000Qooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool0UOooool3o`0001Oooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`0kooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo097ooooo0ol0000Kooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0>oooool0
00Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0SOooool3o`0001oooooo00?o0000
ooooooooool0>_ooool00ol0003oooooooooo`0jooooo`001Ol00002ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`02ooooo`;o00006_ooool00ol0003oooooooooo`29
ooooo`?o00008oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03Wooooo0007oooo
o`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool0Q_ooool2o`0002Kooooo00?o0000ooooooooool0>_ooool2
o`0003[ooooo0007ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`22ooooo`?o0000:Ooo
ool00ol0003oooooooooo`0iooooo`;o0000>_ooool000Oooooo00Go410@oooooooooooooooooa0@
400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`1nooooo`?o0000;Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03Oooooo0007
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`;o00007_oo
ool00ol0003oooooooooo`1jooooo`?o0000<Oooool00ol0003oooooooooo`0iooooo`03o`000?oo
oooooooo03Oooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Cooooo0_l0
000Pooooo`03o`000?oooooooooo07Kooooo0ol0000eooooo`03o`000?oooooooooo03Wooooo00?o
0000ooooooooool0=_ooool0023ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1b
ooooo`?o0000>?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03Gooooo000Poooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool0Koooool2o`0003cooooo00?o0000oooo
ooooool0>_ooool00ol0003oooooooooo`0dooooo`008?ooool2o`0002?ooooo00?o0000oooooooo
ool0Joooool3o`0003oooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0dooooo`00
8?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo06Oooooo0ol00013ooooo`03o`00
0?oooooooooo03Wooooo00?o0000ooooooooool0<oooool0023ooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`1Sooooo`?o0000Aoooool00ol0003oooooooooo`0iooooo`03o`000?oo
oooooooo03;ooooo000Pooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0Goooool3
o`0004[ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0booooo`008?ooool00ol0
003oooooooooo`0Vooooo`;o0000GOooool2o`0004kooooo00?o0000ooooooooool0>Oooool00ol0
003oooooooooo`0aooooo`007oooool3o`0002Wooooo00?o0000ooooooooool0Eoooool3o`00057o
oooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0`ooooo`007oooool00ol0003ooooo
ooooo`0Zooooo`03o`000?oooooooooo05?ooooo0ol0001Eooooo`03o`000?oooooooooo03Wooooo
00?o0000ooooooooool0;oooool001oooooo00?o0000ooooooooool0:oooool00ol0003ooooooooo
o`1?ooooo`?o0000F?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02oooooo000O
ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0Boooool3o`0005cooooo00?o0000
ooooooooool0>?ooool2o`00033ooooo000Oooooo`?o0000;Oooool00ol0003oooooooooo`17oooo
o`?o0000H?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02gooooo000Oooooo`03
o`000?oooooooooo02kooooo00?o0000ooooooooool0A?ooool2o`0006Cooooo00?o0000oooooooo
ool0>?ooool00ol0003oooooooooo`0]ooooo`005?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Ko
oooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`10ooooo`?o0000Ioooool00ol0003o
ooooooooo`0hooooo`03o`000?oooooooooo02cooooo000Dooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo03cooooo0ol0001Zooooo`03
o`000?oooooooooo03Wooooo00?o0000ooooooooool0:oooool001Cooooo00Go410@oooooooooooo
oooooa0@4005ooooo`;o0000<oooool00ol0003oooooooooo`0hooooo`?o0000K_ooool00ol0003o
ooooooooo`0iooooo`03o`000?oooooooooo02[ooooo000Dooooo`05o`000?ooooooooooooooool0
00001Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo03Cooooo0ol0001booooo`03
o`000?oooooooooo03Sooooo00?o0000ooooooooool0:_ooool001Cooooo00Go0000oooooooooooo
ooooo`000005ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0<?ooool3o`0007Ko
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Yooooo`005?ooool01Ol@413ooooo
oooooooooooo410@00Gooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0]ooooo`;o
0000N_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02Sooooo000Dooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo02Wo
oooo0ol0001looooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0:?ooool001Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o0000>?ooool00ol0003oooooooooo`0Uooooo`?o
0000P?ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02Oooooo000Nooooo`03o`00
0?oooooooooo03Sooooo00?o0000ooooooooool08Oooool3o`0008Cooooo00?o0000ooooooooool0
>?ooool00ol0003oooooooooo`0Vooooo`007Oooool00ol0003oooooooooo`0jooooo`03o`000?oo
oooooooo01gooooo0ol00028ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool09Ooo
ool001gooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Jooooo`;o0000S?ooool0
0ol0003oooooooooo`0gooooo`03o`000?oooooooooo02Gooooo000Mooooo`;o0000?Oooool00ol0
003oooooooooo`0Fooooo`?o0000S_ooool00ol0003oooooooooo`0gooooo`;o00009_ooool001go
oooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Booooo`?o0000T_ooool00ol0003o
ooooooooo`0hooooo`03o`000?oooooooooo02?ooooo000Mooooo`03o`000?oooooooooo03kooooo
00?o0000ooooooooool03_ooool3o`0009Kooooo00?o0000ooooooooool0=oooool00ol0003ooooo
ooooo`0Sooooo`007Oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00[ooooo0ol0
002Jooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool08_ooool001gooooo00?o0000
ooooooooool0@?ooool00ol0003oooooooooo`06ooooo`?o0000W_ooool00ol0003oooooooooo`0g
ooooo`03o`000?oooooooooo027ooooo000Looooo`?o0000@_ooool00ol0003oooooooooo`03oooo
o`;o0000XOooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo023ooooo000Looooo`03
o`000?oooooooooo04?ooooo00?o0000ooooool000000_l0002Tooooo`03o`000?oooooooooo03Oo
oooo00?o0000ooooooooool08?ooool001cooooo00?o0000ooooooooool0@_ooool3o`000:Sooooo
00?o0000ooooooooool0=oooool00ol0003oooooooooo`09ooooo`;o000000?o410@ooooooooool0
4Oooool001cooooo00?o0000ooooooooool0?oooool3o`0000?ooooo00?o0000ooooooooool0Y_oo
ool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04_oo
ool001cooooo0ol0000looooo`?o00001oooool00ol0003oooooooooo`2Vooooo`03o`000?oooooo
oooo03Kooooo00?o0000ooooooooool01_ooool5o`0001?ooooo000Looooo`03o`000?oooooooooo
03Wooooo0ol0000;ooooo`03o`000?oooooooooo0:Gooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`05ooooo`04odA4A?oMgMgoooooo`0001Cooooo00001_ooooook^k^oc8b<_l0003o
<S8bonk^kPGooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooo
ooooo`0gooooo`;o00003oooool00ol0003oooooooooo`2<ooooo`;ooiT05oooool00ol0003ooooo
ooooo`0gooooo`03o`000?oooooooooo00Cooooo00CogMgMoeEEEOoooooo00005?ooool00006oooo
oomgMgOoV9RHoooooonHV9SoMgMg1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0
003oooooooooo`0dooooo`?o00004_ooool00ol0003oooooooooo`2:ooooo`03oonI0?oooooooooo
01Sooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`05ooooo`03ogMgMoo<c<co0000
01Cooooo00000ooooooo410@ooooo`02ooooo`03oa0@4?oooooooooo00kooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0aooooo`?o00005_ooool00ol0003oooooooooo`28ooooo`03
oonI0?oooooooooo01[ooooo00?o0000ooooooooool0=_ooool2o`0000Gooooo00?ok^k^odA4A?l0
00005?ooool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool03Oooool00omgMgOo<S8b
ooooo`03ooooo`;o0000<?ooool3o`0001[ooooo00?o0000ooooooooool0Q_ooool00oooV@3ooooo
ooooo`0Looooo`03o`000?oooooooooo03Cooooo00?o0000ooooool000001_ooool00omgMgOo0000
ooooo`0Cooooo`0000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0:ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`0/ooooo`?o00007_ooool00ol0003ooooo
ooooo`24ooooo`03oonI0?oooooooooo01gooooo00?o0000ooooooooool0=oooool00ol0003ooooo
ooooo`0Iooooo`0000?ooooooa0@4?ooool00_ooool00ol@413oooooooooo`0:ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool0:_ooool2o`0002;ooooo00?o0000ooooooooool0POoo
ool2oonI027ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Iooooo`0000Kooooo
ogMgMonHV9SooooooiRHV?mgMgL<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
9oooool3o`0002Gooooo0_l0001oooooo`;ooiT09?ooool00ol0003oooooooooo`0fooooo`03o`00
0?oooooooooo01Sooooo00001_ooooook^k^oc8b<_l0003o<S8bonk^kPcooooo1?l00005ooooo`;o
00009Oooool3o`0002[ooooo00?o0000ooooooooool0Noooool00oooV@3oooooooooo`0;ooooo`;o
c?l06?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo01Oooooo000Kooooo`03o`00
0?oooooooooo027ooooo0ol0000^ooooo`03o`000?oooooooooo07Sooooo0_ooV@0=ooooo`03olco
0?oooooooooo01Wooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Gooooo`006ooo
ool00ol0003oooooooooo`0Nooooo`?o0000<_ooool00ol0003oooooooooo`1eooooo`;ooiT03Ooo
ool2olco01cooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Fooooo`006oooool0
0ol0003oooooooooo`0Kooooo`?o0000=_ooool00ol0003oooooooooo`1booooo`;ooiT03_ooool0
0oo<o`3oooooooooo`0Mooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool05Oooool0
01[ooooo00?o0000ooooooooool06_ooool2o`0003[ooooo00?o0000ooooooooool0Koooool2oonI
00kooooo0_o<o`0Qooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool05?ooool001[o
oooo0_l0000Hooooo`?o0000?Oooool00ol0003oooooooooo`1/ooooo`;ooiT03oooool00oo<o`3o
ooooooooo`0Rooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool05?ooool001[ooooo
00?o0000ooooooooool05?ooool3o`00047ooooo00?o0000ooooooooool0JOooool2oonI00oooooo
0_o<o`0<ooooo`;o<ol05oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo01?ooooo
000Jooooo`03o`000?oooooooooo017ooooo0ol00015ooooo`03o`000?oooooooooo06Gooooo0ooo
V@0?ooooo`;oc?l03Oooool00olco`3oooooooooo`0Hooooo`03o`000?oooooooooo03Kooooo00?o
0000ooooooooool04_ooool001[ooooo00?o0000ooooooooool03_ooool3o`0004Wooooo00?o0000
ooooooooool0HOooool3oonI017ooooo00?oc?l0ooooooooool02oooool2oc?o01cooooo00?o0000
ooooooooool0=Oooool2o`0001?ooooo000Jooooo`03o`000?oooooooooo00cooooo0_l0001=oooo
o`03o`000?oooooooooo05gooooo0oooV@0Booooo`;oc?l03Oooool00olco`3oooooooooo`0Moooo
o`03o`000?oooooooooo03Cooooo0_l0000Cooooo`006Oooool3o`0000[ooooo0ol0001@ooooo`03
o`000?oooooooooo05Wooooo0oooV@0Cooooo`;oc?l03_ooool00olco`3oooooooooo`0Oooooo`03
o`000?oooooooooo03Gooooo00?o0000ooooooooool04?ooool001[ooooo00?o0000ooooooooool0
1_ooool3o`0005Cooooo00?o0000ooooooooool0EOooool3oonI01Cooooo0_o<o`0>ooooo`;o<ol0
8_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00oooooo000Iooooo`03o`000?oo
oooooooo00Cooooo0ol0001Hooooo`03o`000?oooooooooo057ooooo0oooV@0Eooooo`;oc?l03_oo
ool2oc?o00_ooooo0_l0ofHHooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool03ooo
ool001Wooooo00Co0000oooooooooooooooo0ol0001Looooo`03o`000?oooooooooo04gooooo0ooo
V@0Fooooo`;oc?l03_ooool2oc?o00cooooo00?o0?mVooooooooool06Oooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo00kooooo000Iooooo`Co0000H?ooool00ol0003oooooooooo`19
ooooo`?ooiT05_ooool3olco00kooooo0_lco`0<ooooo`;o0?mV7Oooool00ol0003oooooooooo`0e
ooooo`03o`000?oooooooooo00gooooo000Iooooo`;o0000Hoooool00ol0003oooooooooo`14oooo
o`CooiT05_ooool3olco00oooooo0_lco`0=ooooo`03o`3oI_oooooooooo01kooooo00?o0000oooo
ooooool0=?ooool00ol0003oooooooooo`0=ooooo`003oooool4o`000003oa0@4?oooooooooo00Go
oooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0nooooo`GooiT05oooool3olco013o
oooo0_lco`0>ooooo`03o`3oI_oooooooooo01oooooo00?o0000ooooooooool0=Oooool00ol0003o
ooooooooo`0<ooooo`004Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo067ooooo
00?o0000ooooooooool0=_ooool7oonI01Wooooo0oo<o`0Aooooo`;o<ol03_ooool2o`3oIR?ooooo
00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0;ooooo`004Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool09oooool>oonI01kooooo0_o<
o`0Cooooo`03oc?o0?oooooooooo00gooooo00?o0?mVooooooooool02_ooool2o`3ooaSooooo00?o
0000ooooooooool0=Oooool00ol0003oooooooooo`0:ooooo`004Oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0Coooool3olco01?ooooo0_lco`0>
ooooo`;o0?mV3?ooool00ol0ooooooooooooo`0Iooooo`03o`000?oooooooooo03Cooooo00?o0000
ooooooooool02_ooool0017ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Qoooo
o`03o`000?oooooooooo04_ooooo0oo<o`0Cooooo`?o<ol03_ooool2o`3oIPcooooo0_l0oolMoooo
o`03o`000?oooooooooo03Cooooo00?o0000ooooooooool02Oooool0017ooooo00?o0000oooooooo
ool03?ooool2o`0006;ooooo00?o0000ooooooooool0AOooool5olco01?ooooo0olco`0@ooooo`03
o`3oI_oooooooooo00[ooooo0_l0oolOooooo`03o`000?oooooooooo03?ooooo0ol0000:ooooo`00
4Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0
?oooool5olco01Gooooo0olco`0Aooooo`;o0?mV3?ooool00ol0ooooooooooooo`0Pooooo`03o`00
0?oooooooooo02oooooo0ol00002ooooo`03o`000?oooooooooo00Sooooo000?ooooo`03oeEEEOmV
IVKo0000017ooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0iooooo`Goc?l05_oo
ool4oc?o017ooooo0ol0ofH<ooooo`;o0?oo9?ooool00ol0003oooooooooo`0[ooooo`?o00001Ooo
ool00ol0003oooooooooo`08ooooo`009?ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooo
oooo033ooooo2?o<o`0Hooooo`?o<ol04oooool2o`3oIPgooooo0_l0oolWooooo`03o`000?oooooo
oooo02Kooooo1?l00008ooooo`03o`000?oooooooooo00Sooooo000Uooooo`03o`000?oooooooooo
063ooooo00?o0000ooooooooool09_ooool9olco01gooooo0olco`0Cooooo`?o0?mV3Oooool2o`3o
o`kooooo0_l0I_lJooooo`03o`000?oooooooooo02;ooooo0ol0000<ooooo`03o`000?oooooooooo
00Sooooo000Vooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool08?ooool5olco02;o
oooo1?lco`0Dooooo`;o0?mV3oooool00ol0ooooooooooooo`0=ooooo`03o`1Voooooooooooo01[o
oooo00?o0000ooooooooool07oooool3o`00013ooooo00?o0000ooooooooool01oooool002Oooooo
00?o0000ooooooooool0H?ooool00ol0003oooooooooo`13ooooo`?o<ol05Oooool3o`3oIPoooooo
0_l0ool>ooooo`;o06Ko7_ooool00ol0003oooooooooo`0Jooooo`Co00004oooool00ol0003ooooo
ooooo`07ooooo`00:?ooool2o`00067ooooo00?o0000ooooooooool0?oooool3oc?o01Kooooo0_l0
ofH@ooooo`;o0?oo3_ooool2o`1Vob7ooooo00?o0000ooooooooool05_ooool3o`0001Oooooo00?o
0000ooooooooool01oooool002[ooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0i
ooooo`Go<ol05_ooool3o`3oIQ3ooooo0_l0ool?ooooo`03o`1Voooooooooooo02;ooooo00?o0000
ooooooooool04_ooool3o`0001[ooooo00?o0000ooooooooool01oooool002_ooooo00?o0000oooo
ooooool0Goooool00ol0003oooooooooo`0cooooo`Go<ol06?ooool3o`3oIQ7ooooo0_l0ool?oooo
o`;o06Ko9_ooool00ol0003oooooooooo`0=ooooo`Co00007Oooool00ol0003oooooooooo`07oooo
o`00;?ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo02[ooooo2?lco`0Iooooo`Co
0?mV4_ooool2o`3oo`oooooo0_l0I_l<ooooo`;o<`3o6_ooool00ol0003oooooooooo`0:ooooo`?o
00008Oooool00ol0003oooooooooo`07ooooo`00;Oooool00ol0003oooooooooo`1Oooooo`03o`00
0?oooooooooo01oooooo2_lco`0Nooooo`?o0?mV5?ooool2o`3oo`oooooo0_l0I_l<ooooo`;o<`3o
7Oooool00ol0003oooooooooo`06ooooo`?o00009?ooool00ol0003oooooooooo`07ooooo`00;_oo
ool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo01Wooooo1Olco`0Tooooo`Co0?mV5Ooo
ool2o`3oo`oooooo0_l0I_l<ooooo`;o<`3o8?ooool01?l0003oooooooooooooool4o`0002Oooooo
00?o0000ooooooooool01oooool002oooooo0_l0001Pooooo`03o`000?oooooooooo03gooooo1?l0
ofHFooooo`?o0?oo3oooool2o`1Vo`gooooo00?o<`3oooooooooool08Oooool3o`0002cooooo00?o
0000ooooooooool01_ooool0037ooooo00?o0000ooooooooool0G_ooool2o`0003[ooooo0ol0ofHH
ooooo`;o0?oo4?ooool2o`1Vo`gooooo0_lc0?lQooooo`?o000000?oooooo`000?ooool0;?ooool0
0ol0003oooooooooo`06ooooo`00<_ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo
03;ooooo1Ol0ofHHooooo`?o0?oo3oooool3o`1Vo`gooooo0_lc0?lPooooo`?o00001?ooool00ol0
003oooooooooo`0[ooooo`03o`000?oooooooooo00Kooooo000cooooo`03o`000?oooooooooo05oo
oooo00?o0000ooooooooool0;?ooool5o`3oIQ[ooooo0ol0ool@ooooo`;o06Ko3_ooool2oc<0o`go
oooo0_o<0?l?ooooo`Co00002?ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo00Ko
oooo000dooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool09_ooool5o`3oIQ_ooooo
1?l0ool@ooooo`?o06Ko3_ooool2oc<0o`gooooo0_o<0?l>ooooo`?o00003Oooool00ol0003ooooo
ooooo`0Yooooo`03o`000?oooooooooo00Kooooo000eooooo`03o`000?oooooooooo05oooooo00?o
0000ooooooooool08?ooool5o`3oIQgooooo0ol0oolBooooo`;o06Ko4?ooool00olc0?oooooooooo
o`0;ooooo`;oc03o3Oooool3o`00017ooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`06ooooo`00=_ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo017ooooo3_l0ofHN
ooooo`Co0?oo4_ooool3o`1Voa3ooooo0_lc0?l=ooooo`03ol`0oooooooooooo00Wooooo1?l0000E
ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool01_ooool003Oooooo0_l0001Poooo
o`03o`000?oooooooooo03Sooooo1?l0oolCooooo`?o06Ko4Oooool2oc<0o`gooooo0_o<0?l9oooo
o`?o00006Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Kooooo000iooooo`03
o`000?oooooooooo05kooooo00?o0000ooooooooool0<oooool4o`3ooaCooooo0ol0I_lBooooo`;o
<`3o3Oooool2ol`0o`Sooooo0ol0000Mooooo`03o`000?oooooooooo02Oooooo00?o0000oooooooo
ool01Oooool003[ooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0]ooooo`Go0?oo
5_ooool2o`1Voa;ooooo0olc0?l=ooooo`;oc03o1_ooool4o`0000?ooooo0_oo09TLooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool01Oooool003_ooooo00?o0000ooooooooool0G_oo
ool00ol0003oooooooooo`0Wooooo`Go0?oo6?ooool3o`1Voa;ooooo0_lc0?l?ooooo`03ol`0oooo
oooooooo00?ooooo0ol00006ooooo`03ool0VOoooooooooo01gooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`05ooooo`00??ooool00ol0003oooooooooo`1Nooooo`03o`000?oooooo
oooo01kooooo2?l0oolJooooo`?o06Ko4oooool2oc<0o`oooooo0_o<0?l3ooooo`?o00001oooool2
ool0VB3ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`05ooooo`00?Oooool00ol0
003oooooooooo`1Nooooo`03o`000?oooooooooo01;ooooo2ol0oolOooooo`?o06Ko5?ooool2oc<0
o`oooooo0_o<0?l00ooooooo0000o`000002o`0000Wooooo00?oo`2Iooooooooool08Oooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo00Gooooo000nooooo`;o0000Goooool00ol0003o
ooooooooo`0;ooooo`Ko0?oo9oooool3o`1VoaCooooo0olc0?l@ooooo`04ol`0ool0003o0000o`00
00_ooooo0_oo09TUooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool01Oooool0043o
oooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`0cooooo`Co06Ko5?ooool3oc<0oa7o
oooo0_o<0?l00ol0003oooooooooo`0;ooooo`03ool0VOoooooooooo02Kooooo00?o0000oooooooo
ool08_ooool00ol0003oooooooooo`05ooooo`00@Oooool00ol0003oooooooooo`1Mooooo`03o`00
0?oooooooooo02kooooo1?l0I_lEooooo`?o<`3o4?ooool01?l0003oc03ool`0ooo<0?l>ooooo`;o
o`2I2oooool2ool001gooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`05ooooo`00
@_ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo02Sooooo1Ol0I_lGooooo`;o<`3o
4?ooool01?l0003oc03ool`0ooo<0?l?ooooo`;oo`2I3?ooool00ooo003oooooooooo`0Mooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool01Oooool004?ooooo00?o0000ooooooooool0
GOooool00ol0003oooooooooo`0Qooooo`Ko06Ko6Oooool3oc<0o`oooooo00Co0000ol`0ooo<0?oo
c03o4?ooool2ool0V@cooooo0_oo000Qooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool01?ooool004Cooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`0Gooooo`Wo06Ko
7?ooool3oc<0o`kooooo0ol00002ol`0oa7ooooo0_oo09T=ooooo`03ool00?oooooooooo02;ooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`04ooooo`00AOooool00ol0003ooooooooo
o`1Mooooo`03o`000?oooooooooo00_ooooo2ol0I_lRooooo`?o<`3o3_ooool3o`0000?oc03o4Ooo
ool2ool0V@gooooo0_oo000Vooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool01?oo
ool004Kooooo0_l0001Nooooo`03o`000?oooooooooo00Cooooo1_l0I_lYooooo`Co<`3o3_ooool3
o`000003ooooooo<0?ooc03o01;ooooo0_oo09T>ooooo`03ool00?oooooooooo02Oooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`04ooooo`00B?ooool00ol0003oooooooooo`1Loooo
o`03o`000?oooooooooo02kooooo1?lc0?l>ooooo`Co00000_ooool2ol`0oa7ooooo0ooo09T>oooo
o`;oo`00:_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Cooooo0019ooooo`03
o`000?oooooooooo05cooooo00?o0000ooooooooool0:Oooool4oc<0o`oooooo0ol00003ooooo`?o
c03o4Oooool2ool0V@oooooo0_oo000]ooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool01?ooool004[ooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`0Sooooo`Go<`3o
4?ooool3o`0000?ooooo0oo<0?lBooooo`;oo`2I3_ooool3ool0033ooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`04ooooo`00Boooool00ol0003oooooooooo`1Looooo`03o`000?oo
oooooooo01cooooo1_lc0?lAooooo`Co00000_ooool4ol`0oa;ooooo0ooo09T>ooooo`;oo`00=?oo
ool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo001<ooooo`03o`000?oooooo
oooo05cooooo00?o0000ooooooooool04_ooool9oc<0oaCooooo0ol00002ooooo`Coc03o5?ooool2
ool0V@oooooo0_oo000gooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool00oooool0
04gooooo0_l0001Mooooo`03o`000?oooooooooo00Gooooo3?lc0?lJooooo`?o000000?ooooool`0
ooo<0?l00_o<0?lEooooo`?oo`2I3oooool2ool003Wooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`03ooooo`00Coooool00ol0003oooooooooo`1Kooooo`03o`000?lc0?oo<`3o00Co
<`3o8oooool3o`0000Coc03o5_ooool3ool0VA3ooooo0_oo000looooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool00oooool0053ooooo00?o0000ooooooooool0Foooool00ol0003ooooo
ooooo`0Rooooo`?o00001?o<0?lGooooo`?oo`2I4Oooool2ool003oooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`03ooooo`00DOooool00ol0003oooooooooo`1Kooooo`03o`000?oo
oooooooo01kooooo0_l00004ol`0oaOooooo1?oo09TBooooo`;oo`00@_ooool00ol0003ooooooooo
o`0Hooooo`03o`000?oooooooooo00?ooooo001Booooo`03o`000?oooooooooo05_ooooo00?o0000
ooooooooool06_ooool5ol`0oaSooooo0ooo09TDooooo`;oo`00AOooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo00?ooooo001Cooooo`03o`000?oooooooooo05_ooooo00?o0000oooo
ooooool05Oooool4ol`0oa[ooooo0ooo09TEooooo`;oo`00Aoooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo00?ooooo001Dooooo`;o0000G?ooool00ol0003oooooooooo`0<ooooo`So
c03o6oooool3ool0VAKooooo0_oo001:ooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool00oooool005Kooooo00?o0000ooooooooool0F_ooool00ol0003oc03ool`0o`0;ol`0o`;ooooo
0ol0000Jooooo`Coo`2I5_ooool3ool004gooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`02ooooo`00Eoooool00ol0003oooooooooo`1Dooooo`Koc03o00?o0000ooooooooool02?oo
ool4o`0001Sooooo1Ooo09TGooooo`?oo`00DOooool00ol0003oooooooooo`0Eooooo`03o`000?oo
oooooooo00;ooooo001Hooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool01?ooool3
o`0001Sooooo1?oo09TIooooo`?oo`00EOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo00;ooooo001Iooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool00ol0000Foooo
o`Goo`2I6Oooool4ool005Sooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`02oooo
o`00F_ooool00ol0003oooooooooo`1Jooooo`;o00004_ooool7ool0VA_ooooo0ooo001Mooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool00_ooool005_ooooo00?o0000ooooooooool0
FOooool00ol0003oooooooooo`0;ooooo`Koo`2I7oooool3ool0067ooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`02ooooo`00G?ooool2o`0005Wooooo00?o0000ooooooooool01?oo
ool7ool0VB;ooooo0ooo001Uooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool00_oo
ool005kooooo00?o0000ooooooooool0E?ooool9ool0VBGooooo1?oo001Yooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool00_ooool005oooooo00?o0000ooooooooool0COooool6ool0
V@;ooooo00?o0000ooooooooool09?ooool5ool006gooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`01ooooo`00H?ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo01oo
oooo1Ooo001cooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00Oooool0067ooooo
00?o0000ooooooooool0Doooool00ol0003oooooooooo`0Jooooo`Goo`00NOooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo007ooooo001Rooooo`03o`000?oooooooooo05;ooooo00?o
0000ooooooooool04oooool7ool007oooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`01ooooo`00Hoooool2o`0005;ooooo00?o0000ooooooooool03Oooool6ool008Oooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`01ooooo`00IOooool00ol0003oooooooooo`1?oooo
o`03o`000?oooooooooo00Kooooo1ooo002=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool00Oooool006Kooooo00?o0000ooooooooool0COooool:ool009Gooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`01ooooo`00Ioooool00ol0003oooooooooo`15ooooo`Ooo`00
00?oooooo`000?ooool0WOooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo007ooooo
001Xooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0WOooool00ol0003ooooooooo
o`0;ooooo`7o00000Oooool1ooooo`00JOooool00ol0003oooooooooo`1;ooooo`03o`000?oooooo
oooo09gooooo00?o0000ooooooooool02oooool1o`00007ooooo0Oooool006[ooooo00?o0000oooo
ooooool0B_ooool00ol0003oooooooooo`2Nooooo`03o`000?oooooooooo00[ooooo0Ol00001oooo
o`7ooooo001[ooooo`;o0000B_ooool00ol0003oooooooooo`2Oooooo`03o`000?oooooooooo00Wo
oooo0Ol00001ooooo`7ooooo001]ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0
X?ooool00ol0003oooooooooo`08ooooo`7o00000Oooool1ooooo`00K_ooool00ol0003ooooooooo
o`16ooooo`03o`000?oooooooooo0:7ooooo00?o0000ooooooooool01oooool1o`00007ooooo0Ooo
ool006oooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`2Qooooo`03o`000?oooooo
oooo00Oooooo0Ol00001ooooo`7ooooo001`ooooo`03o`000?oooooooooo04Cooooo00?o0000oooo
ooooool0X_ooool00ol0003oooooooooo`06ooooo`7o00000Oooool1ooooo`00LOooool00ol0003o
ooooooooo`13ooooo`03o`000?oooooooooo0:?ooooo00?o0000ooooooooool01Oooool1o`00007o
oooo0Oooool007;ooooo0_l00012ooooo`03o`000?oooooooooo0:Gooooo00?o0000ooooooooool0
1Oooool1o`00007ooooo001dooooo`03o`000?oooooooooo03oooooo00?o0000ooooooooool0Y_oo
ool00ol0003oooooooooo`04ooooo`7o00000Oooool007Gooooo00?o0000ooooooooool0?_ooool0
0ol0003oooooooooo`2Vooooo`03o`000?oooooooooo00Cooooo0Ol00001ooooo`00M_ooool00ol0
003oooooooooo`0mooooo`03o`000?oooooooooo0:Oooooo00?o0000ooooooooool00oooool1o`00
007ooooo001gooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0Z?ooool00ol0003o
ooooooooo`02ooooo`7o00000Oooool007Sooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`2Yooooo`05o`000?ooooooooooooooool000000Oooool007Wooooo00?o0000ooooooooool0
>_ooool00ol0003oooooooooo`2Zooooo`04o`000?ooooooooooo`00007ooooo001jooooo`;o0000
>_ooool00ol0003oooooooooo`2Zooooo`04o`000?ooooooooooo`00007ooooo001looooo`03o`00
0?oooooooooo03Oooooo00?o0000ooooooooool0Zoooool00ol0003oooooooooo`01o`000000OOoo
ool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo0:cooooo0Ol00001ooooo`7o0000001n
ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0[Oooool2o`000000Ooooool00ol0
003oooooooooo`0dooooo`03o`000?oooooooooo0:cooooo0ol00000083ooooo00?o0000oooooooo
ool0<oooool00ol0003oooooooooo`2Xooooo`Co00000oooool0087ooooo0_l0000cooooo`03o`00
0?oooooooooo0:Gooooo0ol00007ooooo`00Poooool00ol0003oooooooooo`0`ooooo`03o`000?oo
oooooooo0:7ooooo1?l0000:ooooo`00Q?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooo
oooo09gooooo1?l0000>ooooo`00QOooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo
09Wooooo1?l0000Booooo`00Q_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo09Go
oooo1?l0000Fooooo`00Qoooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo09;ooooo
0ol0000Jooooo`00R?ooool2o`0002cooooo00?o0000ooooooooool0S_ooool4o`0001gooooo002:
ooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0R_ooool4o`00027ooooo002;oooo
o`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0Q_ooool4o`0002Gooooo002<ooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool0P_ooool4o`0002Wooooo002=ooooo`03o`00
0?oooooooooo02Kooooo00?o0000ooooooooool0Ooooool3o`0002gooooo002>ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool0Noooool4o`00033ooooo002?ooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool0Moooool4o`0003Cooooo002@ooooo`;o00009?ooool00ol0
003oooooooooo`1cooooo`Co0000>?ooool009;ooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`1`ooooo`?o0000??ooool009?ooooo00?o0000ooooooooool08?ooool00ol0003ooooo
ooooo`1/ooooo`Co0000?oooool009Cooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`1Xooooo`Co0000@oooool009Gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1T
ooooo`Co0000Aoooool009Kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1Poooo
o`Co0000Boooool009Oooooo0_l0000Mooooo`03o`000?oooooooooo05gooooo0ol0001?ooooo`00
VOooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo05Wooooo1?l0001Booooo`00V_oo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo05Gooooo1?l0001Fooooo`00Voooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo057ooooo1?l0001Jooooo`00W?ooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo04gooooo1?l0001Nooooo`00WOooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo04[ooooo0ol0001Rooooo`00W_ooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo04Kooooo1?l0001Uooooo`00Woooool2o`0001Cooooo00?o
0000ooooooooool0@oooool4o`0006Wooooo002Qooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool0?oooool4o`0006gooooo002Rooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool0>oooool4o`00077ooooo002Sooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool0>?ooool3o`0007Gooooo002Tooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
=?ooool4o`0007Sooooo002Uooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0<?oo
ool4o`0007cooooo002Vooooo`;o00003Oooool00ol0003oooooooooo`0/ooooo`Co0000P?ooool0
0:Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Yooooo`?o0000Q?ooool00:Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Uooooo`Co0000Qoooool00:[ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Qooooo`Co0000Roooool00:_ooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`0Mooooo`Co0000Soooool00:cooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`0Iooooo`Co0000Toooool00:gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0Fooooo`?o0000Uoooool00:kooooo0_l00005ooooo`03
o`000?oooooooooo01;ooooo1?l0002Jooooo`00/?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00kooooo1?l0002Nooooo`00/Oooool01Ol0003ooooooooooooooooo000000cooooo
1?l0002Rooooo`00/_ooool01?l0003oooooooooool00008ooooo`Co0000Y_ooool00;?ooooo00?o
0000ooooool000001Oooool3o`000:[ooooo002dooooo`;o000000?oooooo`000?l000000_l0002]
ooooo`00]Oooool2o`000;7ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000
\
\>"],
  ImageRangeCache->{{{0, 359}, {319.688, 0}} -> {-0.0710364, -0.0181728, \
0.0035149, 0.0035149}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .89104 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-16 1.0656 -0.0363427 1.0656 [
[.02544 .21571 -12 -8.9133 ]
[.02544 .21571 0 .0867 ]
[.16074 .16277 -11.6592 -9 ]
[.16074 .16277 .34081 0 ]
[.3021 .10747 -5.60025 -9 ]
[.3021 .10747 .39975 0 ]
[.44992 .04965 -5.37091 -9 ]
[.44992 .04965 .62909 0 ]
[.60467 -0.01084 -5.14157 -9 ]
[.60467 -0.01084 .85843 0 ]
[.66454 .05085 0 -6.20675 ]
[.66454 .05085 6 2.79325 ]
[.80797 .25198 0 -6.0417 ]
[.80797 .25198 6 2.9583 ]
[.93071 .4241 0 -5.90576 ]
[.93071 .4241 6 3.09424 ]
[.02254 .22988 -12 -2.74631 ]
[.02254 .22988 0 6.25369 ]
[.0142 .29178 -24 -2.78907 ]
[.0142 .29178 0 6.21093 ]
[.00558 .35578 -6 -2.83339 ]
[.00558 .35578 0 6.16661 ]
[-0.00334 .42198 -18 -2.87938 ]
[-0.00334 .42198 0 6.12062 ]
[-0.01257 .49051 -6 -2.92712 ]
[-0.01257 .49051 0 6.07288 ]
[ 0 0 0 0 ]
[ 1 .89104 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03495 .22504 m
.61241 0 L
s
.03495 .22504 m
.03971 .2297 L
s
[(-2)] .02544 .21571 1 .98073 Mshowa
.16988 .17246 m
.17445 .1773 L
s
[(-1)] .16074 .16277 .9432 1 Mshowa
.31082 .11753 m
.31518 .12256 L
s
[(0)] .3021 .10747 .86675 1 Mshowa
.45818 .0601 m
.46231 .06533 L
s
[(1)] .44992 .04965 .7903 1 Mshowa
.61241 0 m
.61628 .00542 L
s
[(2)] .60467 -0.01084 .71386 1 Mshowa
.125 Mabswid
.06148 .2147 m
.06431 .21752 L
s
.08823 .20428 m
.09104 .20712 L
s
.11521 .19376 m
.118 .19663 L
s
.14243 .18316 m
.14519 .18604 L
s
.19758 .16166 m
.20029 .16459 L
s
.22551 .15078 m
.22821 .15373 L
s
.2537 .13979 m
.25637 .14277 L
s
.28213 .12871 m
.28478 .13171 L
s
.33977 .10625 m
.34236 .10929 L
s
.36897 .09487 m
.37153 .09794 L
s
.39844 .08339 m
.40097 .08648 L
s
.42817 .0718 m
.43068 .07491 L
s
.48846 .0483 m
.49091 .05146 L
s
.51902 .03639 m
.52144 .03958 L
s
.54986 .02437 m
.55225 .02758 L
s
.58099 .01224 m
.58335 .01547 L
s
.25 Mabswid
.61241 0 m
.97291 .505 L
s
.65208 .05558 m
.64586 .05794 L
s
[(0)] .66454 .05085 -1 .37928 Mshowa
.79537 .2563 m
.78907 .25846 L
s
[(2)] .80797 .25198 -1 .3426 Mshowa
.91799 .42808 m
.91164 .43006 L
s
[(4)] .93071 .4241 -1 .31239 Mshowa
.125 Mabswid
.69012 .10886 m
.68637 .11025 L
s
.72662 .16 m
.72286 .16135 L
s
.76168 .2091 m
.75791 .21042 L
s
.82778 .3017 m
.82399 .30297 L
s
.85897 .3454 m
.85518 .34664 L
s
.88903 .3875 m
.88522 .38871 L
s
.94594 .46722 m
.94211 .46839 L
s
.25 Mabswid
.03495 .22504 m
0 .48612 L
s
.03495 .22504 m
.04116 .22262 L
s
[(-1)] .02254 .22988 1 -0.38971 Mshowa
.02665 .28704 m
.03288 .28468 L
s
[(-0.5)] .0142 .29178 1 -0.38021 Mshowa
.01807 .35115 m
.02431 .34884 L
s
[(0)] .00558 .35578 1 -0.37036 Mshowa
.00919 .41747 m
.01546 .41521 L
s
[(0.5)] -0.00334 .42198 1 -0.36014 Mshowa
0 .48612 m
.00629 .48392 L
s
[(1)] -0.01257 .49051 1 -0.34953 Mshowa
.125 Mabswid
.03331 .23728 m
.03704 .23583 L
s
.03166 .2496 m
.03539 .24816 L
s
.03 .262 m
.03373 .26056 L
s
.02833 .27448 m
.03207 .27305 L
s
.02496 .29969 m
.0287 .29828 L
s
.02325 .31243 m
.02699 .31102 L
s
.02154 .32525 m
.02528 .32385 L
s
.01981 .33816 m
.02355 .33676 L
s
.01632 .36423 m
.02007 .36285 L
s
.01455 .37741 m
.01831 .37603 L
s
.01278 .39067 m
.01653 .3893 L
s
.01099 .40402 m
.01475 .40266 L
s
.00738 .43101 m
.01114 .42966 L
s
.00555 .44464 m
.00932 .4433 L
s
.00371 .45837 m
.00748 .45704 L
s
.00186 .4722 m
.00563 .47087 L
s
.25 Mabswid
.03495 .22504 m
0 .48612 L
s
0 .48612 m
.46953 .89104 L
s
.46953 .89104 m
.47294 .65459 L
s
.47294 .65459 m
.03495 .22504 L
s
.61241 0 m
.97291 .505 L
s
.97291 .505 m
1 .75117 L
s
1 .75117 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.03495 .22504 m
0 .48612 L
s
0 .48612 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.61241 0 m
.03495 .22504 L
s
.47294 .65459 m
.97291 .505 L
s
.97291 .505 m
1 .75117 L
s
1 .75117 m
.46953 .89104 L
s
.46953 .89104 m
.47294 .65459 L
s
0 0 m
1 0 L
1 .89104 L
0 .89104 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.45372 .70357 m
.49512 .70061 L
s
1 0 .6 r
.45238 .68312 m
.49243 .68022 L
s
1 0 0 r
.49512 .70061 m
.53792 .69531 L
s
.8 0 1 r
.45103 .66263 m
.48973 .6598 L
s
1 0 .6 r
.49243 .68022 m
.53391 .67504 L
s
.2 0 1 r
.44968 .64209 m
.48703 .63933 L
s
.8 0 1 r
.48973 .6598 m
.52989 .65472 L
s
1 0 0 r
.53792 .69531 m
.58084 .68772 L
s
0 .4 1 r
.44832 .62151 m
.48433 .61882 L
s
.2 0 1 r
.48703 .63933 m
.52587 .63437 L
s
1 0 .6 r
.53391 .67504 m
.57557 .66759 L
s
0 1 1 r
.44697 .60088 m
.48161 .59827 L
s
0 .4 1 r
.48433 .61882 m
.52184 .61398 L
s
.8 0 1 r
.52989 .65472 m
.57028 .64742 L
s
0 1 .4 r
.44561 .5802 m
.4789 .57767 L
s
0 1 1 r
.48161 .59827 m
.51781 .59355 L
s
.2 0 1 r
.52587 .63437 m
.56499 .62723 L
s
.2 1 0 r
.44425 .55943 m
.47617 .557 L
s
0 1 .4 r
.4789 .57767 m
.51376 .57308 L
s
0 .4 1 r
.52184 .61398 m
.55969 .60699 L
s
1 0 0 r
.58084 .68772 m
.62313 .67793 L
s
.8 1 0 r
.44291 .53853 m
.47343 .53622 L
s
.2 1 0 r
.47617 .557 m
.5097 .55255 L
s
1 0 .6 r
.57557 .66759 m
.61663 .65797 L
s
0 1 1 r
.51781 .59355 m
.55438 .58673 L
s
.8 0 1 r
.57028 .64742 m
.61012 .638 L
s
.8 1 0 r
.47343 .53622 m
.50562 .53193 L
s
0 1 .4 r
.51376 .57308 m
.54906 .56643 L
s
1 .6 0 r
.44159 .51733 m
.47067 .51521 L
s
.2 0 1 r
.56499 .62723 m
.60361 .61799 L
s
.2 1 0 r
.5097 .55255 m
.54373 .54608 L
s
1 .6 0 r
.47067 .51521 m
.50149 .51113 L
s
0 .4 1 r
.55969 .60699 m
.59708 .59795 L
s
.8 1 0 r
.50562 .53193 m
.53837 .52566 L
s
0 1 1 r
.55438 .58673 m
.59055 .57789 L
s
1 .6 0 r
.50149 .51113 m
.53293 .50508 L
s
0 1 .4 r
.54906 .56643 m
.584 .5578 L
s
1 0 0 r
.62313 .67793 m
.66429 .66602 L
s
1 0 .6 r
.61663 .65797 m
.65659 .64629 L
s
.2 1 0 r
.54373 .54608 m
.57744 .53767 L
s
.8 0 1 r
.61012 .638 m
.64889 .62654 L
s
.8 1 0 r
.53837 .52566 m
.57085 .51748 L
s
.2 0 1 r
.60361 .61799 m
.64118 .60676 L
s
1 .6 0 r
.53293 .50508 m
.56416 .49715 L
s
0 .4 1 r
.59708 .59795 m
.63346 .58696 L
s
0 1 1 r
.59055 .57789 m
.62573 .56715 L
s
0 1 .4 r
.584 .5578 m
.61799 .54731 L
s
.2 1 0 r
.57744 .53767 m
.61024 .52744 L
s
.8 1 0 r
.57085 .51748 m
.60244 .50752 L
s
1 0 0 r
.66429 .66602 m
.70393 .65209 L
s
1 .6 0 r
.56416 .49715 m
.59453 .48747 L
s
1 0 .6 r
.65659 .64629 m
.69504 .63262 L
s
.8 0 1 r
.64889 .62654 m
.68615 .61313 L
s
.2 0 1 r
.64118 .60676 m
.67725 .59364 L
s
0 .4 1 r
.63346 .58696 m
.66835 .57413 L
s
0 1 1 r
.62573 .56715 m
.65944 .55461 L
s
0 1 .4 r
.61799 .54731 m
.65053 .53508 L
s
.2 1 0 r
.61024 .52744 m
.64159 .51552 L
s
.8 1 0 r
.60244 .50752 m
.6326 .49592 L
s
1 .6 0 r
.59453 .48747 m
.62348 .4762 L
s
1 0 0 r
.70393 .65209 m
.74153 .63622 L
s
1 0 .6 r
.69504 .63262 m
.73145 .61707 L
s
.8 0 1 r
.68615 .61313 m
.72137 .59793 L
s
.2 0 1 r
.67725 .59364 m
.71129 .57877 L
s
0 .4 1 r
.66835 .57413 m
.70121 .55962 L
s
0 1 1 r
.65944 .55461 m
.69112 .54046 L
s
0 1 .4 r
.65053 .53508 m
.68103 .52129 L
s
.2 1 0 r
.64159 .51552 m
.67091 .50211 L
s
.8 1 0 r
.6326 .49592 m
.66073 .4829 L
s
1 .6 0 r
.62348 .4762 m
.65036 .46357 L
s
1 0 0 r
.74153 .63622 m
.77633 .61869 L
s
1 0 .6 r
.73145 .61707 m
.76507 .59994 L
s
.8 0 1 r
.72137 .59793 m
.75381 .58119 L
s
.2 0 1 r
.71129 .57877 m
.74255 .56246 L
s
0 .4 1 r
.70121 .55962 m
.73129 .54373 L
s
0 1 1 r
.69112 .54046 m
.72004 .525 L
s
0 1 .4 r
.68103 .52129 m
.70879 .50628 L
s
.2 1 0 r
.67091 .50211 m
.6975 .48755 L
s
.8 1 0 r
.66073 .4829 m
.68613 .46879 L
s
1 .6 0 r
.65036 .46357 m
.67449 .44992 L
s
.67449 .44992 m
.69509 .43585 L
s
.8 1 0 r
.68613 .46879 m
.70801 .45419 L
s
.2 1 0 r
.6975 .48755 m
.72056 .47242 L
s
0 1 .4 r
.70879 .50628 m
.73298 .49062 L
s
0 1 1 r
.72004 .525 m
.74536 .50882 L
s
0 .4 1 r
.73129 .54373 m
.75773 .52704 L
s
.2 0 1 r
.74255 .56246 m
.77011 .54527 L
s
.8 0 1 r
.75381 .58119 m
.7825 .56353 L
s
1 0 .6 r
.76507 .59994 m
.79491 .5818 L
s
1 0 0 r
.77633 .61869 m
.80732 .60008 L
s
0 g
.25 Mabswid
.61241 0 m
.97291 .505 L
s
.97291 .505 m
1 .75117 L
s
1 .75117 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.03495 .22504 m
0 .48612 L
s
0 .48612 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.61241 0 m
.03495 .22504 L
s
.03495 .22504 m
.61241 0 L
s
.03495 .22504 m
.03971 .2297 L
s
[(-2)] .02544 .21571 1 .98073 Mshowa
.16988 .17246 m
.17445 .1773 L
s
[(-1)] .16074 .16277 .9432 1 Mshowa
.31082 .11753 m
.31518 .12256 L
s
[(0)] .3021 .10747 .86675 1 Mshowa
.45818 .0601 m
.46231 .06533 L
s
[(1)] .44992 .04965 .7903 1 Mshowa
.61241 0 m
.61628 .00542 L
s
[(2)] .60467 -0.01084 .71386 1 Mshowa
.125 Mabswid
.06148 .2147 m
.06431 .21752 L
s
.08823 .20428 m
.09104 .20712 L
s
.11521 .19376 m
.118 .19663 L
s
.14243 .18316 m
.14519 .18604 L
s
.19758 .16166 m
.20029 .16459 L
s
.22551 .15078 m
.22821 .15373 L
s
.2537 .13979 m
.25637 .14277 L
s
.28213 .12871 m
.28478 .13171 L
s
.33977 .10625 m
.34236 .10929 L
s
.36897 .09487 m
.37153 .09794 L
s
.39844 .08339 m
.40097 .08648 L
s
.42817 .0718 m
.43068 .07491 L
s
.48846 .0483 m
.49091 .05146 L
s
.51902 .03639 m
.52144 .03958 L
s
.54986 .02437 m
.55225 .02758 L
s
.58099 .01224 m
.58335 .01547 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 256.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001@2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00gOooool5o`0008Kooooo003Mooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0Q_ooool00=ko
oooo00?oV9RHob4Q8Oo^k^h0Qoooool00=oooooo00?oV9RHob4Q8Oo^k^h0Q_ooool00>3ooooo00?o
MgMgofIVI_ooool0QOooool00>7ooooo00?o0000ooooooooool0Q?ooool00=gooooo00Go0000okZj
^_ooooooV9RHoa0@4026ooooo`00gOooool01OnHV9So410@o`000?lQ8B7oc<c<08Kooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003Tooooo`;o0000P_ooool0
0>7ooooo0ol000000ooooooo0000ooooo`21ooooo`00goooool2o`0000Cooooo0_l00021ooooo`00
g?ooool3o`0000Kooooo00?o0000ooooool00000P?ooool00=[ooooo0_l00009ooooo`03o`000?oo
oooo0000083ooooo003Gooooo`?o000000?oooooo`000?ooool02?ooool01?l0003oooooooooool0
001oooooo`00e?ooool3o`0000Cooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooo
oooo000007kooooo003Booooo`;o00004Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo07_ooooo002Zooooo`Co000000?o410@ooooooooool07_ooool3o`0001?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1kooooo`00[?ooool00ol0003oooooooooo`0Nooooo`;o
000000?oooooo`000?ooool04oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07[o
oooo002/ooooo`03o`000?oooooooooo01_ooooo0ol00004ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`1iooooo`00[?ooool00ol0003ooooooooo
o`0Iooooo`;o00006oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo07Wooooo002/
ooooo`03o`000?oooooooooo01Kooooo0ol0000Mooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool02?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^06_ooooo002/ooooo`03o`000?oooooo
oooo01Cooooo0_l000000ooooooo0000ooooo`0Mooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01oooool01OmgMgOoV9RHoooooonHV9SoMgMg06_ooooo002/ooooo`03o`000?oooooo
oooo017ooooo0ol00004ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`06ooooo`05oa0@4?ooooooooooooooool@4100Joooool00:[ooooo00?oEEEE
ofIVI_l000004Oooool2o`0002Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06
ooooo`05o`000?ooooooooooooooool00000Joooool00;_ooooo0ol0000Wooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000006_ooooo002i
ooooo`;o000000?oooooo`000?ooool09oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Cooooo00Go410@oooooooooooooooooa0@401[ooooo`00]_ooool3o`0000Cooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`1[ooooo`00/oooool3o`0002oooooo00?o0000ooooooooool02Oooool2
o`0000Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1[ooooo`00/Oooool2o`0003;ooooo00?o0000
ooooooooool02?ooool01?l0003oooooooooool0001dooooo`00[_ooool3o`000003ooooool0003o
oooo037ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1aooooo`00[?ooool2o`00
00Gooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
077ooooo002Yooooo`?o0000>_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo073o
oooo002Wooooo`;o0000?Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo06oooooo
002Tooooo`?o000000?oooooo`000?ooool0??ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo06oooooo002Rooooo`;o0000@_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo06kooooo001gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08oooool3o`0004Cooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1]ooooo`00Moooool01OmgMgOoV9RHoooooonHV9So
MgMg027ooooo0_l00017ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0K?ooool0
07Oooooo00Go410@oooooooooooooooooa0@400Nooooo`?o00000_ooool00ol0003oooooooooo`14
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0K?ooool007Oooooo00Go0000oooo
ooooooooooooo`00000Looooo`;o0000C?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo06_ooooo001gooooo`05o`000?ooooooooooooooool000006Oooool3o`0004kooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`1Zooooo`00Moooool01Ol@413ooooooooooooooooo
410@01Kooooo0ol0001Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0J_ooool0
07Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Dooooo`;o00000oooool00ol0003oooooooooo`1>
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0JOooool007Oooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Aooooo`?o0000E_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo06Sooooo002;ooooo`;o0000FOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
06Sooooo0028ooooo`?o0000Foooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo06Oo
oooo0026ooooo`;o00000oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo01Gooooo
0_l0001Xooooo`00Poooool3o`00063ooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`1Uooooo`00POooool2o`0006?ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1U
ooooo`00O_ooool4o`0006Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`1Toooo
o`00O?ooool2o`0000Cooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo06?ooooo001iooooo`?o0000J_ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo06?ooooo001gooooo`;o0000KOooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo06;ooooo001dooooo`?o000000?oooooo`000?ooool0K?ooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo067ooooo001aooooo`?o0000L_ooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo063ooooo0019ooooo`Co000000?o410@ooooooooool07oooool2o`0007Go
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1Pooooo`00Boooool00ol0003ooooo
ooooo`0Nooooo`?o0000Moooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo05oooooo
0010ooooo`Ko00001Oooool00ol0003oooooooooo`0Looooo`;o00000_ooool00ol0003ooooooooo
o`1eooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0G_ooool004_ooooo00?o0000
ooooooooool06Oooool3o`0007cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1N
ooooo`00Boooool00ol0003oooooooooo`0Gooooo`;o0000Ooooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo05gooooo001;ooooo`03o`000?oooooooooo01Cooooo0ol00021ooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0G?ooool004_ooooo00?o0000ooooooooool0
4_ooool2o`0000?ooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo05_ooooo0019ooooo`03oeEEEOmVIVKo0000017ooooo0ol00026ooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool0Foooool005_ooooo0_l00029ooooo`03o`000?oooooo
oooo027ooooo0_l0001Looooo`00F?ooool3o`000003ooooool0003ooooo08Sooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`1Iooooo`00E_ooool2o`0008kooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`1Iooooo`00Doooool3o`00093ooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`1Hooooo`00D?ooool3o`0009?ooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1Gooooo`00C_ooool2o`0000;ooooo00?o0000ooooooooool0TOooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo05Kooooo001;ooooo`?o00001Oooool00ol0
003oooooooooo`2@ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0E_ooool004Wo
oooo0_l0002Kooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0EOooool004Kooooo
1?l0002Looooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0E?ooool004Cooooo0_l0
002Pooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0E?ooool001[ooooo1Ol0000R
ooooo`?o0000X_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo05?ooooo000Joooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@08?ooool2o`000:Gooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`1Booooo`004_ooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h07_ooool3o`00
0003ooooool0003ooooo0:Cooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`1Aoooo
o`007?ooool00onHV9So8B4Qonk^kP0Kooooo`;o0000Z_ooool00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo057ooooo000Mooooo`03ogMgMomVIVKooooo01Oooooo0ol0002]ooooo`03o`00
0?oooooooooo02_ooooo00?o0000ooooooooool0D?ooool001kooooo00?o0000ooooooooool05?oo
ool2o`000;3ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`1?ooooo`006_ooool0
1Ol0003o^[ZjoooooonHV9So410@01?ooooo0ol00002ooooo`03o`000?oooooooooo0:gooooo00?o
0000ooooooooool0;?ooool2o`00053ooooo000Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`04?oo
ool3o`000;Gooooo00?o0000ooooooooool0;?ooool2o`00053ooooo000]ooooo`;o0000^?ooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo04gooooo000Zooooo`?o000000?oooooo`00
0?ooool0]oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo04gooooo000Xooooo`;o
0000_Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo04cooooo000Uooooo`?o0000
_oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo04_ooooo000Tooooo`;o0000`Ooo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo04[ooooo000Jooooo`Co000000?o410@
ooooooooool00oooool00ol0003oooooo`000030ooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool0B_ooool001cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0002o
ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0BOooool0017ooooo1_l00005oooo
o`03o`000?oooooooooo00Gooooo0_l00002ooooo`03o`000?oooooooooo0;cooooo00?o0000oooo
ooooool0<oooool00ol0003oooooooooo`18ooooo`007?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0^oooool00ol0003oooooooooo`0cooooo`03
o`000?oooooooooo00Oooooo1Ol0000looooo`007?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo00Kooooo00GoV9RHob4Q8Oo^k^koooooodA4A00looooo`007?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00ol0003ooooo
ooooo`0eooooo`03o`000?oooooooooo00Kooooo00?oV9RHob4Q8Oo^k^h0?Oooool001cooooo00?o
0000ooooooooool01?ooool3o`0000Kooooo00?o0000ooooooooool0^?ooool00ol0003ooooooooo
o`0fooooo`03o`000?oooooooooo00Kooooo00?oV9RHob4Q8Oo^k^h0??ooool001[ooooo00?oEEEE
ofIVI_l000001_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;Oooooo00?o0000
ooooooooool0=_ooool00ol0003oooooooooo`07ooooo`03ogMgMomVIVKooooo03_ooooo000Soooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0]_ooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0>_ooool002?ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`2eooooo`03o`000?oooooooooo03Oooooo0_l00004ooooo`05
o`000?nj^[[ooooooiRHV?l@4100??ooool002?ooooo0_l0000;ooooo`03o`000?oooooooooo0;Co
oooo00?o0000ooooooooool0=_ooool00ol0003oooooo`000004ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`0??ooool002?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`2cooooo`03
o`000?oooooooooo03Wooooo00?o0000ooooooooool0@_ooool002;ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0
@Oooool002;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`2`ooooo`;o0000?Ooo
ool00ol0003oooooooooo`10ooooo`008_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo0:cooooo0ol000000ooooooo0000ooooo`0looooo`03o`000?oooooooooo043ooooo000Roooo
o`;o00004Oooool00ol0003oooooooooo`2Xooooo`?o00001Oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo03oooooo000Rooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool0Y?ooool3o`0000Wooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0nooooo`00
8_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo0:3ooooo0ol0000=ooooo`03o`00
0?oooooooooo03[ooooo00?o0000ooooooooool0?_ooool002;ooooo0ol0000Cooooo`03o`000?oo
oooooooo09cooooo0ol0000Aooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0?Ooo
ool002;ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`2Iooooo`;o00005?ooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo03cooooo000Qooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool0UOooool3o`0001Oooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`0kooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo097ooooo0ol0000Kooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0>oooool0
00Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0SOooool3o`0001oooooo00?o0000
ooooooooool0>_ooool00ol0003oooooooooo`0jooooo`001Ol00002ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`02ooooo`;o00006_ooool00ol0003oooooooooo`29
ooooo`?o00008oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03Wooooo0007oooo
o`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool0Q_ooool2o`0002Kooooo00?o0000ooooooooool0>_ooool2
o`0003[ooooo0007ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`22ooooo`?o0000:Ooo
ool00ol0003oooooooooo`0iooooo`;o0000>_ooool000Oooooo00Go410@oooooooooooooooooa0@
400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`1nooooo`?o0000;Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03Oooooo0007
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`;o00007_oo
ool00ol0003oooooooooo`1jooooo`?o0000<Oooool00ol0003oooooooooo`0iooooo`03o`000?oo
oooooooo03Oooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Cooooo0_l0
000Pooooo`03o`000?oooooooooo07Kooooo0ol0000eooooo`03o`000?oooooooooo03Wooooo00?o
0000ooooooooool0=_ooool0023ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1b
ooooo`?o0000>?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03Gooooo000Poooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool0Koooool2o`0003cooooo00?o0000oooo
ooooool0>_ooool00ol0003oooooooooo`0dooooo`008?ooool2o`0002?ooooo00?o0000oooooooo
ool0Joooool3o`0003oooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0dooooo`00
8?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo06Oooooo0ol00013ooooo`03o`00
0?oooooooooo03Wooooo00?o0000ooooooooool0<oooool0023ooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`1Sooooo`?o0000Aoooool00ol0003oooooooooo`0iooooo`03o`000?oo
oooooooo03;ooooo000Pooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0Goooool3
o`0004[ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0booooo`008?ooool00ol0
003oooooooooo`0Vooooo`;o0000GOooool2o`0004kooooo00?o0000ooooooooool0>Oooool00ol0
003oooooooooo`0aooooo`007oooool3o`0002Wooooo00?o0000ooooooooool0Eoooool3o`00057o
oooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0`ooooo`007oooool00ol0003ooooo
ooooo`0Zooooo`03o`000?oooooooooo05?ooooo0ol0001Eooooo`03o`000?oooooooooo03Wooooo
00?o0000ooooooooool0;oooool001oooooo00?o0000ooooooooool0:oooool00ol0003ooooooooo
o`1?ooooo`?o0000F?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02oooooo000O
ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0Boooool3o`0005cooooo00?o0000
ooooooooool0>?ooool2o`00033ooooo000Oooooo`?o0000;Oooool00ol0003oooooooooo`17oooo
o`?o0000H?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02gooooo000Oooooo`03
o`000?oooooooooo02kooooo00?o0000ooooooooool0A?ooool2o`0006Cooooo00?o0000oooooooo
ool0>?ooool00ol0003oooooooooo`0]ooooo`005?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Ko
oooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`10ooooo`?o0000Ioooool00ol0003o
ooooooooo`0hooooo`03o`000?oooooooooo02cooooo000Dooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo03cooooo0ol0001Zooooo`03
o`000?oooooooooo03Wooooo00?o0000ooooooooool0:oooool001Cooooo00Go410@oooooooooooo
oooooa0@4005ooooo`;o0000<oooool00ol0003oooooooooo`0hooooo`?o0000K_ooool00ol0003o
ooooooooo`0iooooo`03o`000?oooooooooo02[ooooo000Dooooo`05o`000?ooooooooooooooool0
00001Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo03Cooooo0ol0001booooo`03
o`000?oooooooooo03Sooooo00?o0000ooooooooool0:_ooool001Cooooo00Go0000oooooooooooo
ooooo`000005ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0<?ooool3o`0007Ko
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Yooooo`005?ooool01Ol@413ooooo
oooooooooooo410@00Gooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0]ooooo`;o
0000N_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02Sooooo000Dooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo02Wo
oooo0ol0001looooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0:?ooool001Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o0000>?ooool00ol0003oooooooooo`0Uooooo`?o
0000P?ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02Oooooo000Nooooo`03o`00
0?oooooooooo03Sooooo00?o0000ooooooooool08Oooool3o`0008Cooooo00?o0000ooooooooool0
>?ooool00ol0003oooooooooo`0Vooooo`007Oooool00ol0003oooooooooo`0jooooo`03o`000?oo
oooooooo01gooooo0ol00028ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool09Ooo
ool001gooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Jooooo`;o0000S?ooool0
0ol0003oooooooooo`0gooooo`03o`000?oooooooooo02Gooooo000Mooooo`;o0000?Oooool00ol0
003oooooooooo`0Fooooo`?o0000S_ooool00ol0003oooooooooo`0gooooo`;o00009_ooool001go
oooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Booooo`?o0000T_ooool00ol0003o
ooooooooo`0hooooo`03o`000?oooooooooo02?ooooo000Mooooo`03o`000?oooooooooo03kooooo
00?o0000ooooooooool03_ooool3o`0009Kooooo00?o0000ooooooooool0=oooool00ol0003ooooo
ooooo`0Sooooo`007Oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00[ooooo0ol0
002Jooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool08_ooool001gooooo00?o0000
ooooooooool0@?ooool00ol0003oooooooooo`06ooooo`?o0000W_ooool00ol0003oooooooooo`0g
ooooo`03o`000?oooooooooo027ooooo000Looooo`?o0000@_ooool00ol0003oooooooooo`03oooo
o`;o0000XOooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo023ooooo000Looooo`03
o`000?oooooooooo04?ooooo00?o0000ooooool000000_l0002Tooooo`03o`000?oooooooooo03Oo
oooo00?o0000ooooooooool08?ooool001cooooo00?o0000ooooooooool0@_ooool3o`000:Sooooo
00?o0000ooooooooool0=oooool00ol0003oooooooooo`09ooooo`;o000000?o410@ooooooooool0
4Oooool001cooooo00?o0000ooooooooool0?oooool3o`0000?ooooo00?o0000ooooooooool0Y_oo
ool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04_oo
ool001cooooo0ol0000looooo`?o00001oooool00ol0003oooooooooo`2Vooooo`03o`000?oooooo
oooo03Kooooo00?o0000ooooooooool01_ooool5o`0001?ooooo000Looooo`03o`000?oooooooooo
03Wooooo0ol0000;ooooo`03o`000?oooooooooo0:Gooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`05ooooo`04odA4A?oMgMgoooooo`0001Cooooo00001_ooooook^k^oc8b<_l0003o
<S8bonk^kPGooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooo
ooooo`0gooooo`;o00003oooool00ol0003oooooooooo`2Uooooo`03o`000?oooooooooo03Oooooo
00?o0000ooooooooool01?ooool01?oMgMgoEEEEooooool0000Dooooo`0000KoooooogMgMonHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
03Cooooo0ol0000Booooo`03o`000?oooooooooo0:Gooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`05ooooo`03ogMgMoo<c<co000001Cooooo00000ooooooo410@ooooo`02ooooo`03
oa0@4?oooooooooo00kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0aooooo`?o
00005_ooool00ol0003oooooooooo`2Uooooo`03o`000?oooooooooo03Kooooo0_l00005ooooo`03
onk^k_m4A4Co000001Cooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00gooooo
00?oMgMgoc8b<_ooool00oooool2o`00033ooooo0ol0000Jooooo`03o`000?oooooooooo0:Gooooo
00?o0000ooooooooool0=?ooool00ol0003oooooo`000006ooooo`03ogMgMol0003ooooo01?ooooo
00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00[ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c004ooooo`03o`000?oooooooooo02cooooo0ol0000Nooooo`03o`000?oooooooooo0:Cooooo
00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Iooooo`0000?ooooooa0@4?ooool00_oo
ool00ol@413oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0:_oo
ool2o`0002;ooooo00?o0000ooooooooool0TOooool2oonI017ooooo00?o0000ooooooooool0=_oo
ool00ol0003oooooooooo`0Iooooo`0000KoooooogMgMonHV9SooooooiRHV?mgMgL<ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool09oooool3o`0002Gooooo0_l0002@ooooo`03oonI
0?oooooooooo01;ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Hooooo`0000Ko
ooooonk^k_lb<S;o0000oc8b<_o^k^h<ooooo`Co00001Oooool2o`0002Gooooo0ol0000Zooooo`03
o`000?oooooooooo08_ooooo0_ooV@0Fooooo`03o`000?oooooooooo03Kooooo00?o0000oooooooo
ool05oooool001_ooooo00?o0000ooooooooool08Oooool3o`0002kooooo00?o0000ooooooooool0
ROooool00oooV@3oooooooooo`0Gooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0
5oooool001_ooooo00?o0000ooooooooool07_ooool3o`0003;ooooo00?o0000ooooooooool0Qooo
ool00oooV@3oooooooooo`0Hooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool05_oo
ool001_ooooo00?o0000ooooooooool06oooool3o`0003Kooooo00?o0000ooooooooool0Q?ooool2
oonI01cooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Eooooo`006_ooool00ol0
003oooooooooo`0Jooooo`;o0000>_ooool00ol0003oooooooooo`21ooooo`;ooiT02oooool2olco
01;ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Dooooo`006_ooool2o`0001So
oooo0ol0000mooooo`03o`000?oooooooooo07kooooo0_ooV@0<ooooo`03olco0?oooooooooo01?o
oooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0Dooooo`006_ooool00ol0003ooooo
ooooo`0Dooooo`?o0000@Oooool00ol0003oooooooooo`1kooooo`;ooiT03?ooool2olco01Kooooo
00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Cooooo`006_ooool00ol0003ooooooooo
o`0Aooooo`?o0000AOooool00ol0003oooooooooo`1hooooo`;ooiT03Oooool00oo<o`3ooooooooo
o`0Gooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool04_ooool001[ooooo00?o0000
ooooooooool03_ooool3o`0004Wooooo00?o0000ooooooooool0MOooool2oonI00kooooo00?oc?l0
ooooooooool06Oooool00ol0003oooooooooo`0eooooo`;o00004oooool001[ooooo00?o0000oooo
ooooool03?ooool2o`0004gooooo00?o0000ooooooooool0LOooool3oonI00kooooo0_o<o`0Moooo
o`03o`000?oooooooooo03Cooooo0_l0000Cooooo`006Oooool3o`0000[ooooo0ol0001@ooooo`03
o`000?oooooooooo06kooooo0_ooV@0?ooooo`;oc?l02oooool2oc?o01?ooooo00?o0000oooooooo
ool0=Oooool00ol0003oooooooooo`0@ooooo`006_ooool00ol0003oooooooooo`06ooooo`?o0000
E?ooool00ol0003oooooooooo`1[ooooo`;ooiT03oooool2olco00cooooo00?o<ol0ooooooooool0
4oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00oooooo000Iooooo`03o`000?oo
oooooooo00Cooooo0ol0001Hooooo`03o`000?oooooooooo06Oooooo0oooV@0@ooooo`03olco0?oo
oooooooo00[ooooo0_lco`0Gooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool03ooo
ool001Wooooo00Co0000oooooooooooooooo0ol0001Looooo`03o`000?oooooooooo06Cooooo0_oo
V@0Aooooo`;oc?l03?ooool00olco`3oooooooooo`0Hooooo`03o`000?oooooooooo03Gooooo00?o
0000ooooooooool03_ooool001Wooooo1?l0001Pooooo`03o`000?oooooooooo063ooooo0oooV@0A
ooooo`;oc?l03Oooool00olco`3oooooooooo`0Jooooo`03o`000?oooooooooo03Gooooo00?o0000
ooooooooool03Oooool001Wooooo0_l0001Sooooo`03o`000?oooooooooo05cooooo0oooV@0Boooo
o`;oc?l03Oooool2oc?o01kooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0=oooo
o`003oooool4o`000003oa0@4?oooooooooo00Gooooo00?o0000ooooooooool0HOooool00ol0003o
ooooooooo`1Hooooo`?ooiT04_ooool3olco00gooooo0_lco`0;ooooo`;o0?mV4oooool00ol0003o
ooooooooo`0eooooo`03o`000?oooooooooo00cooooo000Aooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0HOooool00ol0003oooooooooo`1Dooooo`?ooiT04oooool2olco00kooooo
0_lco`0<ooooo`03o`3oI_oooooooooo01Cooooo00?o0000ooooooooool0=Oooool00ol0003ooooo
ooooo`0;ooooo`004Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo067ooooo00?o
0000ooooooooool0Coooool4oonI01Cooooo0_o<o`0?ooooo`03oc?o0?oooooooooo00[ooooo0_l0
ofHHooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool02_ooool0017ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo04_ooooo0oooV@0E
ooooo`?oc?l03oooool2oc?o00_ooooo0_l0ofHKooooo`03o`000?oooooooooo03Cooooo00?o0000
ooooooooool02_ooool0017ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Qoooo
o`03o`000?oooooooooo04Oooooo0oooV@0Fooooo`;oc?l04?ooool2oc?o00cooooo00?o0?mVoooo
ooooool07?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Wooooo000Aooooo`03
o`000?oooooooooo00cooooo0_l0001Rooooo`03o`000?oooooooooo047ooooo1OooV@0Fooooo`?o
c?l03oooool3oc?o00cooooo0_l0ofHOooooo`03o`000?oooooooooo03?ooooo0ol0000:ooooo`00
4Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0
>oooool5oonI01Sooooo0oo<o`0@ooooo`;o<ol03Oooool2o`3oIPgooooo0_l0oolCooooo`03o`00
0?oooooooooo02oooooo0ol00002ooooo`03o`000?oooooooooo00Sooooo000?ooooo`03oeEEEOmV
IVKo0000017ooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`0booooo`SooiT06Ooo
ool4olco013ooooo0olco`0=ooooo`;o0?mV3_ooool00ol0ooooooooooooo`0Dooooo`03o`000?oo
oooooooo02_ooooo0ol00005ooooo`03o`000?oooooooooo00Sooooo000Tooooo`03o`000?oooooo
oooo063ooooo00?o0000ooooooooool09oooool:oonI01kooooo0oo<o`0Booooo`;o<ol03oooool0
0ol0ofKoooooooooo`0<ooooo`;o0?oo6?ooool00ol0003oooooooooo`0Vooooo`Co00002?ooool0
0ol0003oooooooooo`08ooooo`009Oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo
027ooooo1OooV@0Tooooo`Coc?l04_ooool3oc?o00oooooo0_l0ofH>ooooo`03o`3ooooooooooooo
01Wooooo00?o0000ooooooooool08_ooool3o`0000cooooo00?o0000ooooooooool02?ooool002Ko
oooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`15ooooo`Coc?l04oooool3oc?o013o
oooo0_l0ofH>ooooo`;o0?oo7?ooool00ol0003oooooooooo`0Oooooo`?o00004?ooool00ol0003o
ooooooooo`07ooooo`009oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo047ooooo
0oo<o`0Dooooo`?o<ol04Oooool2o`3oIPoooooo00?o0?ooooooooooool07Oooool00ol0003ooooo
ooooo`0Jooooo`Co00004oooool00ol0003oooooooooo`07ooooo`00:?ooool2o`00067ooooo00?o
0000ooooooooool0??ooool4olco01Gooooo0_lco`0Booooo`;o0?mV3oooool2o`3oo`_ooooo0_l0
I_lDooooo`03o`000?oooooooooo01Kooooo0ol0000Gooooo`03o`000?oooooooooo00Oooooo000Z
ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool0=_ooool5olco01Kooooo0olco`0B
ooooo`;o0?mV3oooool2o`3oo`cooooo00?o06Koooooooooool05Oooool00ol0003oooooooooo`0B
ooooo`?o00006_ooool00ol0003oooooooooo`07ooooo`00:oooool00ol0003oooooooooo`1Ooooo
o`03o`000?oooooooooo02gooooo2?o<o`0Hooooo`?o<ol04oooool2o`3oIPoooooo0_l0ool<oooo
o`;o06Ko6Oooool00ol0003oooooooooo`0=ooooo`Co00007Oooool00ol0003oooooooooo`07oooo
o`00;?ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo027ooooo2oo<o`0Mooooo`?o
<ol05?ooool2o`3oIPoooooo0_l0ool=ooooo`03o`1Voooooooooooo01Wooooo00?o0000oooooooo
ool02_ooool3o`00027ooooo00?o0000ooooooooool01oooool002gooooo00?o0000ooooooooool0
Goooool00ol0003oooooooooo`0Kooooo`Goc?l09Oooool3oc?o01Cooooo0ol0ofH?ooooo`;o0?oo
3Oooool2o`1Voagooooo00?o0000ooooooooool01_ooool3o`0002Cooooo00?o0000ooooooooool0
1oooool002kooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`10ooooo`Co<ol05?oo
ool3o`3oIQ3ooooo0_l0ool>ooooo`03o`1Voooooooooooo01kooooo00Co0000oooooooooooooooo
1?l0000Wooooo`03o`000?oooooooooo00Oooooo000_ooooo`;o0000H?ooool00ol0003ooooooooo
o`0looooo`?o<ol05Oooool3o`3oIQ3ooooo0ol0ool>ooooo`;o06Ko2oooool2oc<0oaGooooo0ol0
000/ooooo`03o`000?oooooooooo00Kooooo000aooooo`03o`000?oooooooooo05kooooo0_l0000g
ooooo`Go<ol05_ooool2o`3oIQ7ooooo0_l0ool?ooooo`;o06Ko3?ooool00olc0?ooooooooooo`0B
ooooo`?o000000?oooooo`000?ooool0;?ooool00ol0003oooooooooo`06ooooo`00<_ooool00ol0
003oooooooooo`1Oooooo`03o`000?oooooooooo02oooooo1Olco`0Hooooo`?o0?mV4?ooool3o`3o
o`oooooo0_l0I_l<ooooo`;o<`3o4_ooool3o`0000Cooooo00?o0000ooooooooool0:oooool00ol0
003oooooooooo`06ooooo`00<oooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo02Ko
oooo2?lco`0Jooooo`?o0?mV4Oooool2o`3ooa3ooooo0_l0I_l=ooooo`03oc<0oooooooooooo00ko
oooo1?l00008ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool01_ooool003Cooooo
00?o0000ooooooooool0Goooool00ol0003oooooooooo`0Jooooo`_o<ol07oooool3o`3oIQ;ooooo
0_l0ool@ooooo`;o06Ko3Oooool2oc<0o`kooooo0ol0000=ooooo`03o`000?oooooooooo02Wooooo
00?o0000ooooooooool01_ooool003Gooooo00?o0000ooooooooool0Goooool00ol0003ooooooooo
o`0Cooooo`Ko<ol09_ooool4o`3oIQ;ooooo0ol0ool@ooooo`;o06Ko3_ooool00olc0?oooooooooo
o`0;ooooo`?o00004Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Kooooo000f
ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool0>?ooool6o`3oIQCooooo0_l0oolA
ooooo`;o06Ko3_ooool2oc<0o`[ooooo00Co0000ol`0ooo<0?oo00005Oooool00ol0003ooooooooo
o`0Wooooo`03o`000?oooooooooo00Kooooo000gooooo`;o0000H?ooool00ol0003oooooooooo`0b
ooooo`Go0?mV6?ooool2o`3ooa3ooooo0ol0I_l>ooooo`;o<`3o2Oooool2o`0000;oc03o6?ooool0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Kooooo000iooooo`03o`000?oooooooooo
05kooooo00?o0000ooooooooool0;Oooool4o`3oIQ[ooooo0ol0ool@ooooo`;o06Ko3oooool2oc<0
o`Sooooo0ol000000oooooooc03oooooo`0Jooooo`03o`000?oooooooooo02Oooooo00?o0000oooo
ooooool01Oooool003[ooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0Xooooo`Co
0?mV6_ooool4o`3ooa7ooooo0_l0I_l@ooooo`03oc<0oooooooooooo00Cooooo1?l00002ooooo`;o
c03o7Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Gooooo000kooooo`03o`00
0?oooooooooo05kooooo00?o0000ooooooooool08?ooool7o`3oIQ[ooooo1?l0oolCooooo`;o06Ko
4?ooool2oc<0o`Cooooo0ol00004ooooo`;oc03o8?ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo00Gooooo000looooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool04ooo
ool<o`3oIQgooooo1?l0oolDooooo`?o06Ko4?ooool2oc<0o`?ooooo0ol00006ooooo`03ol`0oooo
oooooooo023ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`05ooooo`00?Oooool0
0ol0003oooooooooo`1Nooooo`03o`000?oooooooooo00cooooo1_l0ofHUooooo`Co0?oo5Oooool3
o`1Voa7ooooo0_lc0?l00ooooooo0000o`000002o`0000Oooooo0_o<0?lTooooo`03o`000?oooooo
oooo02Cooooo00?o0000ooooooooool01Oooool003kooooo0_l0001Oooooo`03o`000?oooooooooo
03;ooooo1?l0oolFooooo`?o06Ko4_ooool2oc<0o`?o00002Oooool2ol`0o`kooooo0_oo09TGoooo
o`03o`000?oooooooooo02?ooooo00?o0000ooooooooool01Oooool0043ooooo00?o0000oooooooo
ool0GOooool00ol0003oooooooooo`0/ooooo`Go0?oo5oooool3o`1Voa;ooooo0olc0?l2o`0000_o
oooo00?oc03oooooooooool03?ooool2ool0VA[ooooo00?o0000ooooooooool08_ooool00ol0003o
ooooooooo`05ooooo`00@Oooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo02Gooooo
1_l0oolIooooo`?o06Ko4oooool2oc<0o`;o00003?ooool2ol`0o`kooooo00?oo`2Iooooooooool0
6oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Gooooo0012ooooo`03o`000?oo
oooooooo05gooooo00?o0000ooooooooool07_ooool6o`3ooacooooo0ol0I_lCooooo`03o`000?lc
0?oo<`3o00kooooo0_o<0?l>ooooo`;oo`2I7_ooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo00Gooooo0013ooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool05_ooool7
o`3ooaoooooo0ol0I_lCooooo`;o00000_lc0?l?ooooo`03ol`0oooooooooooo00cooooo0_oo09TQ
ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool01?ooool004Cooooo00?o0000oooo
ooooool0GOooool00ol0003oooooooooo`0=ooooo`So0?oo8_ooool4o`1Voa;ooooo0ol00003oc<0
o`oooooo0_o<0?l>ooooo`03ool0VOoooooooooo02;ooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`04ooooo`00AOooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo00Ko
oooo1_l0oolVooooo`Co06Ko4oooool3o`0000?o<`3o3oooool3ol`0o`kooooo0_oo09T<ooooo`;o
o`006?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Cooooo0016ooooo`;o0000
G_ooool00ol0003oooooooooo`0]ooooo`Co06Ko5?ooool3o`0000?o<`3o4?ooool2ol`0o`oooooo
0_oo09T<ooooo`;oo`006oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Cooooo
0018ooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool09oooool5o`1VoaCooooo0ol0
0004oc<0oa7ooooo0_o<0?l>ooooo`?oo`2I3Oooool00ooo003oooooooooo`0Kooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool01?ooool004Wooooo00?o0000ooooooooool0G?ooool0
0ol0003oooooooooo`0Oooooo`Oo06Ko5_ooool3o`0000?o<`3o4_ooool3ol`0o`kooooo0_oo09T>
ooooo`;oo`007oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Cooooo001:oooo
o`03o`000?oooooooooo05cooooo00?o0000ooooooooool06?ooool6o`1Voa[ooooo0ol00003oc<0
oa?ooooo0_o<0?l?ooooo`;oo`2I3_ooool2ool002;ooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`04ooooo`00Boooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo013o
oooo1ol0I_lLooooo`Co00000olc0?lCooooo`?oc03o3oooool2ool0V@oooooo00?oo`00oooooooo
ool08oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00Cooooo001<ooooo`03o`00
0?oooooooooo05cooooo00?o0000ooooooooool01_ooool9o`1Vob3ooooo0ol00004oc<0oa?ooooo
0oo<0?l@ooooo`;oo`2I3oooool2ool002Oooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`03ooooo`00COooool2o`0005gooooo00?o0000ooooool0I_l01Ol0I_lVooooo`03o`000?lc
0?oo<`3o00?o<`3o5Oooool2ol`0oa7ooooo0_oo09T?ooooo`;oo`00:Oooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00?ooooo001?ooooo`03o`000?oooooooooo05_ooooo00?o0000
ooooooooool09oooool4oc<0oaOooooo0oo<0?lAooooo`;oo`2I3oooool2ool002cooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`03ooooo`00D?ooool00ol0003oooooooooo`1Koooo
o`03o`000?oooooooooo027ooooo1Olc0?lHooooo`?oc03o4_ooool2ool0V@oooooo0_oo000_oooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool00oooool0057ooooo00?o0000oooooooo
ool0Foooool00ol0003oooooooooo`0Iooooo`Oo<`3o00?o0000ooooooooool05Oooool5ol`0oa?o
oooo0_oo09T?ooooo`;oo`00<_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00?o
oooo001Booooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool04_ooool6oc<0o`;ooooo
0ol0000Fooooo`Coc03o5Oooool3ool0V@oooooo0_oo000eooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool00oooool005?ooooo00?o0000ooooooooool0Foooool00ol0003ooooooooo
o`0:ooooo`Oo<`3o1?ooool4o`0001Gooooo1?o<0?lFooooo`?oo`2I4?ooool2ool003Oooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`03ooooo`00E?ooool2o`0005cooooo00?o0000
ooooooooool02Olc0?l8ooooo`?o00005?ooool5ol`0oaOooooo0ooo09T@ooooo`?oo`00>_ooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00?ooooo001Fooooo`03o`000?oooooooooo
05Kooooo1_lc0?l>ooooo`?o00004oooool4ol`0oaWooooo0ooo09TAooooo`;oo`00?_ooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo00;ooooo001Gooooo`03o`000?oooooooooo05[o
oooo00?o0000ooooooooool02?ooool4o`0001;ooooo1?o<0?lIooooo`Coo`2I4_ooool2ool0047o
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`02ooooo`00F?ooool00ol0003ooooo
ooooo`1Jooooo`03o`000?oooooooooo00Cooooo0ol0000Aooooo`Goc03o6_ooool3ool0VA?ooooo
0ooo0014ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00_ooool005Wooooo00?o
0000ooooooooool0F_ooool00ol0003oooooooooo`03o`00013ooooo1?o<0?lLooooo`?oo`2I5?oo
ool2ool004Oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`02ooooo`00F_ooool0
0ol0003oooooooooo`1Jooooo`;o00003_ooool5ol`0oagooooo0ooo09TDooooo`?oo`00B_ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00;ooooo001Kooooo`03o`000?oooooooooo
05Wooooo00?o0000ooooooooool01_ooool7ol`0oakooooo1?oo09TDooooo`?oo`00C_ooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo00;ooooo001Looooo`;o0000F?ooool:ol`0ob3o
oooo1Ooo09TEooooo`?oo`00D_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;o
oooo001Nooooo`03o`000?oooooooooo04kooooo1oo<0?l00ooooooo0000ooooo`0Rooooo`Goo`2I
5oooool3ool005Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`02ooooo`00Gooo
ool00ol0003oooooooooo`1Eooooo`03o`000?oooooooooo01gooooo1?oo09TIooooo`?oo`00FOoo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo007ooooo001Pooooo`03o`000?oooooo
oooo05Cooooo00?o0000ooooooooool06?ooool5ool0VA[ooooo0ooo001Mooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool00Oooool0067ooooo00?o0000ooooooooool0Doooool00ol0
003oooooooooo`0Cooooo`Goo`2I7?ooool3ool0067ooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`01ooooo`00H_ooool00ol0003oooooooooo`1Booooo`03o`000?oooooooooo00[o
oooo2Ooo09TNooooo`?oo`00IOooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo007o
oooo001Sooooo`;o0000D_ooool=ool0VB?ooooo1?oo001Yooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool00Oooool006Gooooo00?o0000ooooooooool0B?ooool7ool0V@03o`000?oo
oooooooo02Sooooo1Ooo001]ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00Ooo
ool006Kooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0Sooooo`Goo`00Loooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo007ooooo001Wooooo`03o`000?oooooooooo
04gooooo00?o0000ooooooooool07Oooool6ool007Wooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`01ooooo`00J?ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo01Ko
oooo1ooo0020ooooo`03o`000?oooooooooo00_ooooo0Ol00001ooooo`7ooooo001Yooooo`03o`00
0?oooooooooo04_ooooo00?o0000ooooooooool03oooool7ool008Oooooo00?o0000ooooooooool0
2oooool1o`00007ooooo0Oooool006[ooooo00?o0000ooooooooool0B_ooool00ol0003ooooooooo
o`08ooooo`Ooo`00Soooool00ol0003oooooooooo`0:ooooo`7o00000Oooool1ooooo`00Joooool2
o`0004[ooooo2ooo002Gooooo`03o`000?oooooooooo00Wooooo0Ol00001ooooo`7ooooo001]oooo
o`03o`000?oooooooooo043ooooo1ooo00000ol0003oooooooooo`2Pooooo`03o`000?oooooooooo
00Sooooo0Ol00001ooooo`7ooooo001^ooooo`03o`000?oooooooooo04Kooooo00?o0000oooooooo
ool0XOooool00ol0003oooooooooo`07ooooo`7o00000Oooool1ooooo`00Koooool00ol0003ooooo
ooooo`15ooooo`03o`000?oooooooooo0:7ooooo00?o0000ooooooooool01oooool1o`00007ooooo
0Oooool0073ooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`2Rooooo`03o`000?oo
oooooooo00Kooooo0Ol00001ooooo`7ooooo001aooooo`03o`000?oooooooooo04?ooooo00?o0000
ooooooooool0Xoooool00ol0003oooooooooo`05ooooo`7o00000Oooool1ooooo`00L_ooool2o`00
04;ooooo00?o0000ooooooooool0YOooool00ol0003oooooooooo`05ooooo`7o00000Oooool007Co
oooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`2Vooooo`03o`000?oooooooooo00Co
oooo0Ol00001ooooo`00MOooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo0:Kooooo
00?o0000ooooooooool01?ooool1o`00007ooooo001fooooo`03o`000?oooooooooo03gooooo00?o
0000ooooooooool0Yoooool00ol0003oooooooooo`03ooooo`7o00000Oooool007Oooooo00?o0000
ooooooooool0??ooool00ol0003oooooooooo`2Xooooo`03o`000?oooooooooo00;ooooo0Ol00001
ooooo`00N?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo0:Wooooo00Go0000oooo
ooooooooooooo`000001ooooo`00NOooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo
0:[ooooo00Co0000oooooooooooo00000Oooool007[ooooo0_l0000jooooo`03o`000?oooooooooo
0:[ooooo00Co0000oooooooooooo00000Oooool007cooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`2[ooooo`03o`000?oooooooooo007o0000001mooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool0[?ooool1o`00007ooooo0Ol0000007kooooo00?o0000ooooooooool0
=Oooool00ol0003oooooooooo`2]ooooo`;o0000001oooooo`03o`000?oooooooooo03Cooooo00?o
0000ooooooooool0[?ooool3o`000000P?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooo
oooo0:Sooooo1?l00003ooooo`00POooool2o`0003?ooooo00?o0000ooooooooool0YOooool3o`00
00Oooooo0023ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0XOooool4o`0000[o
oooo0024ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0WOooool4o`0000kooooo
0025ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0VOooool4o`0001;ooooo0026
ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0UOooool4o`0001Kooooo0027oooo
o`03o`000?oooooooooo02cooooo00?o0000ooooooooool0T_ooool3o`0001[ooooo0028ooooo`;o
0000;?ooool00ol0003oooooooooo`2>ooooo`Co00007Oooool008[ooooo00?o0000ooooooooool0
:Oooool00ol0003oooooooooo`2:ooooo`Co00008Oooool008_ooooo00?o0000ooooooooool0:?oo
ool00ol0003oooooooooo`26ooooo`Co00009Oooool008cooooo00?o0000ooooooooool09oooool0
0ol0003oooooooooo`22ooooo`Co0000:Oooool008gooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`1oooooo`?o0000;Oooool008kooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`1kooooo`Co0000<?ooool008oooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`1gooooo`Co0000=?ooool0093ooooo0_l0000Tooooo`03o`000?oooooooooo07?ooooo1?l0
000hooooo`00T_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo073ooooo0ol0000l
ooooo`00Toooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo06cooooo1?l0000ooooo
o`00U?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo06Sooooo1?l00013ooooo`00
UOooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo06Cooooo1?l00017ooooo`00U_oo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo063ooooo1?l0001;ooooo`00Uoooool2
o`0001gooooo00?o0000ooooooooool0GOooool3o`0004oooooo002Iooooo`03o`000?oooooooooo
01[ooooo00?o0000ooooooooool0FOooool4o`0005;ooooo002Jooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool0EOooool4o`0005Kooooo002Kooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool0DOooool4o`0005[ooooo002Looooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool0COooool4o`0005kooooo002Mooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool0B_ooool3o`0006;ooooo002Nooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool0A_ooool4o`0006Gooooo002Oooooo`;o00005?ooool00ol0003oooooooooo`13ooooo`Co
0000JOooool00:7ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0oooooo`Co0000
KOooool00:;ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0kooooo`Co0000LOoo
ool00:?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0hooooo`?o0000MOooool0
0:Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0dooooo`Co0000N?ooool00:Go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0`ooooo`Co0000O?ooool00:Kooooo
0_l0000=ooooo`03o`000?oooooooooo02cooooo1?l00020ooooo`00Z?ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo02Wooooo0ol00024ooooo`00ZOooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo02Gooooo1?l00027ooooo`00Z_ooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo027ooooo1?l0002;ooooo`00Zoooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo01gooooo1?l0002?ooooo`00[?ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo01Wooooo1?l0002Cooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo01Kooooo0ol0002Gooooo`00[_ooool2o`0000Gooooo00?o0000ooooooooool04_ooool4
o`0009[ooooo002`ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03_ooool4o`00
09kooooo002aooooo`05o`000?ooooooooooooooool000003?ooool4o`000:;ooooo002booooo`04
o`000?ooooooooooo`0000Sooooo1?l0002Vooooo`00/oooool00ol0003oooooo`000005ooooo`?o
0000Z_ooool00;Cooooo0_l000000ooooooo0000o`000002o`000:gooooo002eooooo`;o0000/Ooo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {319.688, 0}} -> {-0.0710364, -0.0181728, \
0.0035149, 0.0035149}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .89104 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-16 1.0656 -0.0363427 1.0656 [
[.02544 .21571 -12 -8.9133 ]
[.02544 .21571 0 .0867 ]
[.16074 .16277 -11.6592 -9 ]
[.16074 .16277 .34081 0 ]
[.3021 .10747 -5.60025 -9 ]
[.3021 .10747 .39975 0 ]
[.44992 .04965 -5.37091 -9 ]
[.44992 .04965 .62909 0 ]
[.60467 -0.01084 -5.14157 -9 ]
[.60467 -0.01084 .85843 0 ]
[.66454 .05085 0 -6.20675 ]
[.66454 .05085 6 2.79325 ]
[.80797 .25198 0 -6.0417 ]
[.80797 .25198 6 2.9583 ]
[.93071 .4241 0 -5.90576 ]
[.93071 .4241 6 3.09424 ]
[.02254 .22988 -12 -2.74631 ]
[.02254 .22988 0 6.25369 ]
[.0142 .29178 -24 -2.78907 ]
[.0142 .29178 0 6.21093 ]
[.00558 .35578 -6 -2.83339 ]
[.00558 .35578 0 6.16661 ]
[-0.00334 .42198 -18 -2.87938 ]
[-0.00334 .42198 0 6.12062 ]
[-0.01257 .49051 -6 -2.92712 ]
[-0.01257 .49051 0 6.07288 ]
[ 0 0 0 0 ]
[ 1 .89104 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03495 .22504 m
.61241 0 L
s
.03495 .22504 m
.03971 .2297 L
s
[(-2)] .02544 .21571 1 .98073 Mshowa
.16988 .17246 m
.17445 .1773 L
s
[(-1)] .16074 .16277 .9432 1 Mshowa
.31082 .11753 m
.31518 .12256 L
s
[(0)] .3021 .10747 .86675 1 Mshowa
.45818 .0601 m
.46231 .06533 L
s
[(1)] .44992 .04965 .7903 1 Mshowa
.61241 0 m
.61628 .00542 L
s
[(2)] .60467 -0.01084 .71386 1 Mshowa
.125 Mabswid
.06148 .2147 m
.06431 .21752 L
s
.08823 .20428 m
.09104 .20712 L
s
.11521 .19376 m
.118 .19663 L
s
.14243 .18316 m
.14519 .18604 L
s
.19758 .16166 m
.20029 .16459 L
s
.22551 .15078 m
.22821 .15373 L
s
.2537 .13979 m
.25637 .14277 L
s
.28213 .12871 m
.28478 .13171 L
s
.33977 .10625 m
.34236 .10929 L
s
.36897 .09487 m
.37153 .09794 L
s
.39844 .08339 m
.40097 .08648 L
s
.42817 .0718 m
.43068 .07491 L
s
.48846 .0483 m
.49091 .05146 L
s
.51902 .03639 m
.52144 .03958 L
s
.54986 .02437 m
.55225 .02758 L
s
.58099 .01224 m
.58335 .01547 L
s
.25 Mabswid
.61241 0 m
.97291 .505 L
s
.65208 .05558 m
.64586 .05794 L
s
[(0)] .66454 .05085 -1 .37928 Mshowa
.79537 .2563 m
.78907 .25846 L
s
[(2)] .80797 .25198 -1 .3426 Mshowa
.91799 .42808 m
.91164 .43006 L
s
[(4)] .93071 .4241 -1 .31239 Mshowa
.125 Mabswid
.69012 .10886 m
.68637 .11025 L
s
.72662 .16 m
.72286 .16135 L
s
.76168 .2091 m
.75791 .21042 L
s
.82778 .3017 m
.82399 .30297 L
s
.85897 .3454 m
.85518 .34664 L
s
.88903 .3875 m
.88522 .38871 L
s
.94594 .46722 m
.94211 .46839 L
s
.25 Mabswid
.03495 .22504 m
0 .48612 L
s
.03495 .22504 m
.04116 .22262 L
s
[(-1)] .02254 .22988 1 -0.38971 Mshowa
.02665 .28704 m
.03288 .28468 L
s
[(-0.5)] .0142 .29178 1 -0.38021 Mshowa
.01807 .35115 m
.02431 .34884 L
s
[(0)] .00558 .35578 1 -0.37036 Mshowa
.00919 .41747 m
.01546 .41521 L
s
[(0.5)] -0.00334 .42198 1 -0.36014 Mshowa
0 .48612 m
.00629 .48392 L
s
[(1)] -0.01257 .49051 1 -0.34953 Mshowa
.125 Mabswid
.03331 .23728 m
.03704 .23583 L
s
.03166 .2496 m
.03539 .24816 L
s
.03 .262 m
.03373 .26056 L
s
.02833 .27448 m
.03207 .27305 L
s
.02496 .29969 m
.0287 .29828 L
s
.02325 .31243 m
.02699 .31102 L
s
.02154 .32525 m
.02528 .32385 L
s
.01981 .33816 m
.02355 .33676 L
s
.01632 .36423 m
.02007 .36285 L
s
.01455 .37741 m
.01831 .37603 L
s
.01278 .39067 m
.01653 .3893 L
s
.01099 .40402 m
.01475 .40266 L
s
.00738 .43101 m
.01114 .42966 L
s
.00555 .44464 m
.00932 .4433 L
s
.00371 .45837 m
.00748 .45704 L
s
.00186 .4722 m
.00563 .47087 L
s
.25 Mabswid
.03495 .22504 m
0 .48612 L
s
0 .48612 m
.46953 .89104 L
s
.46953 .89104 m
.47294 .65459 L
s
.47294 .65459 m
.03495 .22504 L
s
.61241 0 m
.97291 .505 L
s
.97291 .505 m
1 .75117 L
s
1 .75117 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.03495 .22504 m
0 .48612 L
s
0 .48612 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.61241 0 m
.03495 .22504 L
s
.47294 .65459 m
.97291 .505 L
s
.97291 .505 m
1 .75117 L
s
1 .75117 m
.46953 .89104 L
s
.46953 .89104 m
.47294 .65459 L
s
0 0 m
1 0 L
1 .89104 L
0 .89104 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.45686 .71918 m
.50067 .71607 L
s
1 0 .6 r
.45553 .69892 m
.49801 .69587 L
s
1 0 0 r
.50067 .71607 m
.54583 .71054 L
s
.8 0 1 r
.45419 .67861 m
.49534 .67562 L
s
1 0 .6 r
.49801 .69587 m
.54186 .69043 L
s
.2 0 1 r
.45286 .65826 m
.49267 .65534 L
s
.8 0 1 r
.49534 .67562 m
.53788 .67029 L
s
0 .4 1 r
.45152 .63786 m
.48999 .63501 L
s
1 0 0 r
.54583 .71054 m
.59101 .70261 L
s
.2 0 1 r
.49267 .65534 m
.5339 .65012 L
s
0 1 1 r
.45017 .61742 m
.48731 .61464 L
s
1 0 .6 r
.54186 .69043 m
.58579 .68265 L
s
0 .4 1 r
.48999 .63501 m
.52991 .6299 L
s
.8 0 1 r
.53788 .67029 m
.58055 .66265 L
s
0 1 .4 r
.44883 .59693 m
.48462 .59423 L
s
0 1 1 r
.48731 .61464 m
.52591 .60965 L
s
.2 0 1 r
.5339 .65012 m
.57531 .64262 L
s
.2 1 0 r
.44748 .5764 m
.48192 .57377 L
s
0 1 .4 r
.48462 .59423 m
.52191 .58936 L
s
0 .4 1 r
.52991 .6299 m
.57006 .62256 L
s
.8 1 0 r
.44613 .55581 m
.47922 .55327 L
s
1 0 0 r
.59101 .70261 m
.63547 .69241 L
s
.2 1 0 r
.48192 .57377 m
.5179 .56903 L
s
0 1 1 r
.52591 .60965 m
.5648 .60246 L
s
1 0 .6 r
.58579 .68265 m
.62903 .67261 L
s
1 .6 0 r
.44478 .53515 m
.47651 .5327 L
s
.8 1 0 r
.47922 .55327 m
.51388 .54865 L
s
0 1 .4 r
.52191 .58936 m
.55953 .58233 L
s
.8 0 1 r
.58055 .66265 m
.62258 .65279 L
s
1 .6 0 r
.47651 .5327 m
.50984 .52822 L
s
.2 0 1 r
.57531 .64262 m
.61612 .63294 L
s
.2 1 0 r
.5179 .56903 m
.55425 .56216 L
s
0 .4 1 r
.57006 .62256 m
.60965 .61307 L
s
.8 1 0 r
.51388 .54865 m
.54897 .54196 L
s
0 1 1 r
.5648 .60246 m
.60318 .59316 L
s
1 .6 0 r
.50984 .52822 m
.54366 .52172 L
s
0 1 .4 r
.55953 .58233 m
.59669 .57323 L
s
1 0 0 r
.63547 .69241 m
.67877 .68 L
s
.2 1 0 r
.55425 .56216 m
.5902 .55328 L
s
1 0 .6 r
.62903 .67261 m
.67113 .66042 L
s
.8 1 0 r
.54897 .54196 m
.58369 .53329 L
s
.8 0 1 r
.62258 .65279 m
.66349 .64081 L
s
.2 0 1 r
.61612 .63294 m
.65584 .62118 L
s
1 .6 0 r
.54366 .52172 m
.57717 .51326 L
s
0 .4 1 r
.60965 .61307 m
.64819 .60154 L
s
0 1 1 r
.60318 .59316 m
.64052 .58187 L
s
0 1 .4 r
.59669 .57323 m
.63285 .56218 L
s
.2 1 0 r
.5902 .55328 m
.62517 .54247 L
s
.8 1 0 r
.58369 .53329 m
.61748 .52274 L
s
1 .6 0 r
.57717 .51326 m
.60977 .50298 L
s
1 0 0 r
.67877 .68 m
.72053 .66546 L
s
1 0 .6 r
.67113 .66042 m
.71171 .64613 L
s
.8 0 1 r
.66349 .64081 m
.70288 .62678 L
s
.2 0 1 r
.65584 .62118 m
.69405 .60742 L
s
0 .4 1 r
.64819 .60154 m
.68521 .58805 L
s
0 1 1 r
.64052 .58187 m
.67637 .56867 L
s
0 1 .4 r
.63285 .56218 m
.66752 .54927 L
s
.2 1 0 r
.62517 .54247 m
.65867 .52986 L
s
.8 1 0 r
.61748 .52274 m
.64981 .51044 L
s
1 .6 0 r
.60977 .50298 m
.64093 .491 L
s
1 0 0 r
.72053 .66546 m
.76027 .64886 L
s
1 0 .6 r
.71171 .64613 m
.75026 .62984 L
s
.8 0 1 r
.70288 .62678 m
.74024 .61081 L
s
.2 0 1 r
.69405 .60742 m
.73023 .59178 L
s
0 .4 1 r
.68521 .58805 m
.72021 .57275 L
s
0 1 1 r
.67637 .56867 m
.71019 .55371 L
s
0 1 .4 r
.66752 .54927 m
.70017 .53467 L
s
.2 1 0 r
.65867 .52986 m
.69015 .51563 L
s
.8 1 0 r
.64981 .51044 m
.68011 .49658 L
s
1 .6 0 r
.64093 .491 m
.67006 .47752 L
s
1 0 0 r
.76027 .64886 m
.79722 .63045 L
s
1 0 .6 r
.75026 .62984 m
.78602 .61181 L
s
.8 0 1 r
.74024 .61081 m
.77482 .59317 L
s
.2 0 1 r
.73023 .59178 m
.76363 .57454 L
s
0 .4 1 r
.72021 .57275 m
.75243 .55592 L
s
0 1 1 r
.71019 .55371 m
.74125 .5373 L
s
0 1 .4 r
.70017 .53467 m
.73006 .51869 L
s
.2 1 0 r
.69015 .51563 m
.71888 .50008 L
s
.8 1 0 r
.68011 .49658 m
.7077 .48148 L
s
1 .6 0 r
.67006 .47752 m
.69648 .46288 L
s
.69648 .46288 m
.71939 .44767 L
s
.8 1 0 r
.7077 .48148 m
.73173 .46574 L
s
.2 1 0 r
.71888 .50008 m
.74403 .48382 L
s
0 1 .4 r
.73006 .51869 m
.75632 .50191 L
s
0 1 1 r
.74125 .5373 m
.76863 .52002 L
s
0 .4 1 r
.75243 .55592 m
.78094 .53814 L
s
.2 0 1 r
.76363 .57454 m
.79327 .55628 L
s
.8 0 1 r
.77482 .59317 m
.8056 .57445 L
s
1 0 .6 r
.78602 .61181 m
.81795 .59262 L
s
1 0 0 r
.79722 .63045 m
.83032 .61082 L
s
0 g
.25 Mabswid
.61241 0 m
.97291 .505 L
s
.97291 .505 m
1 .75117 L
s
1 .75117 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.03495 .22504 m
0 .48612 L
s
0 .48612 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.61241 0 m
.03495 .22504 L
s
.03495 .22504 m
.61241 0 L
s
.03495 .22504 m
.03971 .2297 L
s
[(-2)] .02544 .21571 1 .98073 Mshowa
.16988 .17246 m
.17445 .1773 L
s
[(-1)] .16074 .16277 .9432 1 Mshowa
.31082 .11753 m
.31518 .12256 L
s
[(0)] .3021 .10747 .86675 1 Mshowa
.45818 .0601 m
.46231 .06533 L
s
[(1)] .44992 .04965 .7903 1 Mshowa
.61241 0 m
.61628 .00542 L
s
[(2)] .60467 -0.01084 .71386 1 Mshowa
.125 Mabswid
.06148 .2147 m
.06431 .21752 L
s
.08823 .20428 m
.09104 .20712 L
s
.11521 .19376 m
.118 .19663 L
s
.14243 .18316 m
.14519 .18604 L
s
.19758 .16166 m
.20029 .16459 L
s
.22551 .15078 m
.22821 .15373 L
s
.2537 .13979 m
.25637 .14277 L
s
.28213 .12871 m
.28478 .13171 L
s
.33977 .10625 m
.34236 .10929 L
s
.36897 .09487 m
.37153 .09794 L
s
.39844 .08339 m
.40097 .08648 L
s
.42817 .0718 m
.43068 .07491 L
s
.48846 .0483 m
.49091 .05146 L
s
.51902 .03639 m
.52144 .03958 L
s
.54986 .02437 m
.55225 .02758 L
s
.58099 .01224 m
.58335 .01547 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 256.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001@2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00gOooool5o`0008Kooooo003Mooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0Q_ooool00=ko
oooo00?oV9RHob4Q8Oo^k^h0Qoooool00=oooooo00?oV9RHob4Q8Oo^k^h0Q_ooool00>3ooooo00?o
MgMgofIVI_ooool0QOooool00>7ooooo00?o0000ooooooooool0Q?ooool00=gooooo00Go0000okZj
^_ooooooV9RHoa0@4026ooooo`00gOooool01OnHV9So410@o`000?lQ8B7oc<c<08Kooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003Tooooo`;o0000P_ooool0
0>7ooooo0ol000000ooooooo0000ooooo`21ooooo`00goooool2o`0000Cooooo0_l00021ooooo`00
g?ooool3o`0000Kooooo00?o0000ooooool00000P?ooool00=[ooooo0_l00009ooooo`03o`000?oo
oooo0000083ooooo003Gooooo`?o000000?oooooo`000?ooool02?ooool01?l0003oooooooooool0
001oooooo`00e?ooool3o`0000Cooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooo
oooo000007kooooo003Booooo`;o00004Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo07_ooooo002Zooooo`Co000000?o410@ooooooooool07_ooool3o`0001?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1kooooo`00[?ooool00ol0003oooooooooo`0Nooooo`;o
000000?oooooo`000?ooool04oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07[o
oooo002/ooooo`03o`000?oooooooooo01_ooooo0ol00004ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`1iooooo`00[?ooool00ol0003ooooooooo
o`0Iooooo`;o00006oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo07Wooooo002/
ooooo`03o`000?oooooooooo01Kooooo0ol0000Mooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool02?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^06_ooooo002/ooooo`03o`000?oooooo
oooo01Cooooo0_l000000ooooooo0000ooooo`0Mooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01oooool01OmgMgOoV9RHoooooonHV9SoMgMg06_ooooo002/ooooo`03o`000?oooooo
oooo017ooooo0ol00004ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`06ooooo`05oa0@4?ooooooooooooooool@4100Joooool00:[ooooo00?oEEEE
ofIVI_l000004Oooool2o`0002Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06
ooooo`05o`000?ooooooooooooooool00000Joooool00;_ooooo0ol0000Wooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000006_ooooo002i
ooooo`;o000000?oooooo`000?ooool09oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Cooooo00Go410@oooooooooooooooooa0@401[ooooo`00]_ooool3o`0000Cooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`1[ooooo`00/oooool3o`0002oooooo00?o0000ooooooooool02Oooool2
o`0000Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1[ooooo`00/Oooool2o`0003;ooooo00?o0000
ooooooooool02?ooool01?l0003oooooooooool0001dooooo`00[_ooool3o`000003ooooool0003o
oooo037ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1aooooo`00[?ooool2o`00
00Gooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
077ooooo002Yooooo`?o0000>_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo073o
oooo002Wooooo`;o0000?Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo06oooooo
002Tooooo`?o000000?oooooo`000?ooool0??ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo06oooooo002Rooooo`;o0000@_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo06kooooo001gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08oooool3o`0004Cooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1]ooooo`00Moooool01OmgMgOoV9RHoooooonHV9So
MgMg027ooooo0_l00017ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0K?ooool0
07Oooooo00Go410@oooooooooooooooooa0@400Nooooo`?o00000_ooool00ol0003oooooooooo`14
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0K?ooool007Oooooo00Go0000oooo
ooooooooooooo`00000Looooo`;o0000C?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo06_ooooo001gooooo`05o`000?ooooooooooooooool000006Oooool3o`0004kooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`1Zooooo`00Moooool01Ol@413ooooooooooooooooo
410@01Kooooo0ol0001Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0J_ooool0
07Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Dooooo`;o00000oooool00ol0003oooooooooo`1>
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0JOooool007Oooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Aooooo`?o0000E_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo06Sooooo002;ooooo`;o0000FOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
06Sooooo0028ooooo`?o0000Foooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo06Oo
oooo0026ooooo`;o00000oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo01Gooooo
0_l0001Xooooo`00Poooool3o`00063ooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`1Uooooo`00POooool2o`0006?ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1U
ooooo`00O_ooool4o`0006Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`1Toooo
o`00O?ooool2o`0000Cooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo06?ooooo001iooooo`?o0000J_ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo06?ooooo001gooooo`;o0000KOooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo06;ooooo001dooooo`?o000000?oooooo`000?ooool0K?ooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo067ooooo001aooooo`?o0000L_ooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo063ooooo0019ooooo`Co000000?o410@ooooooooool07oooool2o`0007Go
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1Pooooo`00Boooool00ol0003ooooo
ooooo`0Nooooo`?o0000Moooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo05oooooo
0010ooooo`Ko00001Oooool00ol0003oooooooooo`0Looooo`;o00000_ooool00ol0003ooooooooo
o`1eooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0G_ooool004_ooooo00?o0000
ooooooooool06Oooool3o`0007cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1N
ooooo`00Boooool00ol0003oooooooooo`0Gooooo`;o0000Ooooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo05gooooo001;ooooo`03o`000?oooooooooo01Cooooo0ol00021ooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0G?ooool004_ooooo00?o0000ooooooooool0
4_ooool2o`0000?ooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo05_ooooo0019ooooo`03oeEEEOmVIVKo0000017ooooo0ol00026ooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool0Foooool005_ooooo0_l00029ooooo`03o`000?oooooo
oooo027ooooo0_l0001Looooo`00F?ooool3o`000003ooooool0003ooooo08Sooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`1Iooooo`00E_ooool2o`0008kooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`1Iooooo`00Doooool3o`00093ooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`1Hooooo`00D?ooool3o`0009?ooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1Gooooo`00C_ooool2o`0000;ooooo00?o0000ooooooooool0TOooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo05Kooooo001;ooooo`?o00001Oooool00ol0
003oooooooooo`2@ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0E_ooool004Wo
oooo0_l0002Kooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0EOooool004Kooooo
1?l0002Looooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0E?ooool004Cooooo0_l0
002Pooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0E?ooool001[ooooo1Ol0000R
ooooo`?o0000X_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo05?ooooo000Joooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@08?ooool2o`000:Gooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`1Booooo`004_ooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h07_ooool3o`00
0003ooooool0003ooooo0:Cooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`1Aoooo
o`007?ooool00onHV9So8B4Qonk^kP0Kooooo`;o0000Z_ooool00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo057ooooo000Mooooo`03ogMgMomVIVKooooo01Oooooo0ol0002]ooooo`03o`00
0?oooooooooo02_ooooo00?o0000ooooooooool0D?ooool001kooooo00?o0000ooooooooool05?oo
ool2o`000;3ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`1?ooooo`006_ooool0
1Ol0003o^[ZjoooooonHV9So410@01?ooooo0ol00002ooooo`03o`000?oooooooooo0:gooooo00?o
0000ooooooooool0;?ooool2o`00053ooooo000Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`04?oo
ool3o`000;Gooooo00?o0000ooooooooool0;?ooool2o`00053ooooo000]ooooo`;o0000^?ooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo04gooooo000Zooooo`?o000000?oooooo`00
0?ooool0]oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo04gooooo000Xooooo`;o
0000_Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo04cooooo000Uooooo`?o0000
_oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo04_ooooo000Tooooo`;o0000`Ooo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo04[ooooo000Jooooo`Co000000?o410@
ooooooooool00oooool00ol0003oooooo`000030ooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool0B_ooool001cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0002o
ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0BOooool0017ooooo1_l00005oooo
o`03o`000?oooooooooo00Gooooo0_l00002ooooo`03o`000?oooooooooo0;cooooo00?o0000oooo
ooooool0<oooool00ol0003oooooooooo`18ooooo`007?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0^oooool00ol0003oooooooooo`0cooooo`03
o`000?oooooooooo00Oooooo1Ol0000looooo`007?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo00Kooooo00GoV9RHob4Q8Oo^k^koooooodA4A00looooo`007?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00ol0003ooooo
ooooo`0eooooo`03o`000?oooooooooo00Kooooo00?oV9RHob4Q8Oo^k^h0?Oooool001cooooo00?o
0000ooooooooool01?ooool3o`0000Kooooo00?o0000ooooooooool0^?ooool00ol0003ooooooooo
o`0fooooo`03o`000?oooooooooo00Kooooo00?oV9RHob4Q8Oo^k^h0??ooool001[ooooo00?oEEEE
ofIVI_l000001_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;Oooooo00?o0000
ooooooooool0=_ooool00ol0003oooooooooo`07ooooo`03ogMgMomVIVKooooo03_ooooo000Soooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0]_ooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0>_ooool002?ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`2eooooo`03o`000?oooooooooo03Oooooo0_l00004ooooo`05
o`000?nj^[[ooooooiRHV?l@4100??ooool002?ooooo0_l0000;ooooo`03o`000?oooooooooo0;Co
oooo00?o0000ooooooooool0=_ooool00ol0003oooooo`000004ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`0??ooool002?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`2cooooo`03
o`000?oooooooooo03Wooooo00?o0000ooooooooool0@_ooool002;ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0
@Oooool002;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`2`ooooo`;o0000?Ooo
ool00ol0003oooooooooo`10ooooo`008_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo0:cooooo0ol000000ooooooo0000ooooo`0looooo`03o`000?oooooooooo043ooooo000Roooo
o`;o00004Oooool00ol0003oooooooooo`2Xooooo`?o00001Oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo03oooooo000Rooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool0Y?ooool3o`0000Wooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0nooooo`00
8_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo0:3ooooo0ol0000=ooooo`03o`00
0?oooooooooo03[ooooo00?o0000ooooooooool0?_ooool002;ooooo0ol0000Cooooo`03o`000?oo
oooooooo09cooooo0ol0000Aooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0?Ooo
ool002;ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`2Iooooo`;o00005?ooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo03cooooo000Qooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool0UOooool3o`0001Oooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`0kooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo097ooooo0ol0000Kooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0>oooool0
00Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0SOooool3o`0001oooooo00?o0000
ooooooooool0>_ooool00ol0003oooooooooo`0jooooo`001Ol00002ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`02ooooo`;o00006_ooool00ol0003oooooooooo`29
ooooo`?o00008oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03Wooooo0007oooo
o`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool0Q_ooool2o`0002Kooooo00?o0000ooooooooool0>_ooool2
o`0003[ooooo0007ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`22ooooo`?o0000:Ooo
ool00ol0003oooooooooo`0iooooo`;o0000>_ooool000Oooooo00Go410@oooooooooooooooooa0@
400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`1nooooo`?o0000;Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03Oooooo0007
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`;o00007_oo
ool00ol0003oooooooooo`1jooooo`?o0000<Oooool00ol0003oooooooooo`0iooooo`03o`000?oo
oooooooo03Oooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Cooooo0_l0
000Pooooo`03o`000?oooooooooo07Kooooo0ol0000eooooo`03o`000?oooooooooo03Wooooo00?o
0000ooooooooool0=_ooool0023ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1b
ooooo`?o0000>?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03Gooooo000Poooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool0Koooool2o`0003cooooo00?o0000oooo
ooooool0>_ooool00ol0003oooooooooo`0dooooo`008?ooool2o`0002?ooooo00?o0000oooooooo
ool0Joooool3o`0003oooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0dooooo`00
8?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo06Oooooo0ol00013ooooo`03o`00
0?oooooooooo03Wooooo00?o0000ooooooooool0<oooool0023ooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`1Sooooo`?o0000Aoooool00ol0003oooooooooo`0iooooo`03o`000?oo
oooooooo03;ooooo000Pooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0Goooool3
o`0004[ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0booooo`008?ooool00ol0
003oooooooooo`0Vooooo`;o0000GOooool2o`0004kooooo00?o0000ooooooooool0>Oooool00ol0
003oooooooooo`0aooooo`007oooool3o`0002Wooooo00?o0000ooooooooool0Eoooool3o`00057o
oooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0`ooooo`007oooool00ol0003ooooo
ooooo`0Zooooo`03o`000?oooooooooo05?ooooo0ol0001Eooooo`03o`000?oooooooooo03Wooooo
00?o0000ooooooooool0;oooool001oooooo00?o0000ooooooooool0:oooool00ol0003ooooooooo
o`1?ooooo`?o0000F?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02oooooo000O
ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0Boooool3o`0005cooooo00?o0000
ooooooooool0>?ooool2o`00033ooooo000Oooooo`?o0000;Oooool00ol0003oooooooooo`17oooo
o`?o0000H?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02gooooo000Oooooo`03
o`000?oooooooooo02kooooo00?o0000ooooooooool0A?ooool2o`0006Cooooo00?o0000oooooooo
ool0>?ooool00ol0003oooooooooo`0]ooooo`005?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Ko
oooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`10ooooo`?o0000Ioooool00ol0003o
ooooooooo`0hooooo`03o`000?oooooooooo02cooooo000Dooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo03cooooo0ol0001Zooooo`03
o`000?oooooooooo03Wooooo00?o0000ooooooooool0:oooool001Cooooo00Go410@oooooooooooo
oooooa0@4005ooooo`;o0000<oooool00ol0003oooooooooo`0hooooo`?o0000K_ooool00ol0003o
ooooooooo`0iooooo`03o`000?oooooooooo02[ooooo000Dooooo`05o`000?ooooooooooooooool0
00001Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo03Cooooo0ol0001booooo`03
o`000?oooooooooo03Sooooo00?o0000ooooooooool0:_ooool001Cooooo00Go0000oooooooooooo
ooooo`000005ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0<?ooool3o`0007Ko
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Yooooo`005?ooool01Ol@413ooooo
oooooooooooo410@00Gooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0]ooooo`;o
0000N_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02Sooooo000Dooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo02Wo
oooo0ol0001looooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0:?ooool001Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o0000>?ooool00ol0003oooooooooo`0Uooooo`?o
0000P?ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02Oooooo000Nooooo`03o`00
0?oooooooooo03Sooooo00?o0000ooooooooool08Oooool3o`0008Cooooo00?o0000ooooooooool0
>?ooool00ol0003oooooooooo`0Vooooo`007Oooool00ol0003oooooooooo`0jooooo`03o`000?oo
oooooooo01gooooo0ol00028ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool09Ooo
ool001gooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Jooooo`;o0000S?ooool0
0ol0003oooooooooo`0gooooo`03o`000?oooooooooo02Gooooo000Mooooo`;o0000?Oooool00ol0
003oooooooooo`0Fooooo`?o0000S_ooool00ol0003oooooooooo`0gooooo`;o00009_ooool001go
oooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Booooo`?o0000T_ooool00ol0003o
ooooooooo`0hooooo`03o`000?oooooooooo02?ooooo000Mooooo`03o`000?oooooooooo03kooooo
00?o0000ooooooooool03_ooool3o`0009Kooooo00?o0000ooooooooool0=oooool00ol0003ooooo
ooooo`0Sooooo`007Oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00[ooooo0ol0
002Jooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool08_ooool001gooooo00?o0000
ooooooooool0@?ooool00ol0003oooooooooo`06ooooo`?o0000W_ooool00ol0003oooooooooo`0g
ooooo`03o`000?oooooooooo027ooooo000Looooo`?o0000@_ooool00ol0003oooooooooo`03oooo
o`;o0000XOooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo023ooooo000Looooo`03
o`000?oooooooooo04?ooooo00?o0000ooooool000000_l0002Tooooo`03o`000?oooooooooo03Oo
oooo00?o0000ooooooooool08?ooool001cooooo00?o0000ooooooooool0@_ooool3o`000:Sooooo
00?o0000ooooooooool0=oooool00ol0003oooooooooo`09ooooo`;o000000?o410@ooooooooool0
4Oooool001cooooo00?o0000ooooooooool0?oooool3o`0000?ooooo00?o0000ooooooooool0Y_oo
ool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04_oo
ool001cooooo0ol0000looooo`?o00001oooool00ol0003oooooooooo`2Vooooo`03o`000?oooooo
oooo03Kooooo00?o0000ooooooooool01_ooool5o`0001?ooooo000Looooo`03o`000?oooooooooo
03Wooooo0ol0000;ooooo`03o`000?oooooooooo0:Gooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`05ooooo`04odA4A?oMgMgoooooo`0001Cooooo00001_ooooook^k^oc8b<_l0003o
<S8bonk^kPGooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooo
ooooo`0gooooo`;o00003oooool00ol0003oooooooooo`2Uooooo`03o`000?oooooooooo03Oooooo
00?o0000ooooooooool01?ooool01?oMgMgoEEEEooooool0000Dooooo`0000KoooooogMgMonHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
03Cooooo0ol0000Booooo`03o`000?oooooooooo0:Gooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`05ooooo`03ogMgMoo<c<co000001Cooooo00000ooooooo410@ooooo`02ooooo`03
oa0@4?oooooooooo00kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0aooooo`?o
00005_ooool00ol0003oooooooooo`2Uooooo`03o`000?oooooooooo03Kooooo0_l00005ooooo`03
onk^k_m4A4Co000001Cooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00gooooo
00?oMgMgoc8b<_ooool00oooool2o`00033ooooo0ol0000Jooooo`03o`000?oooooooooo0:Gooooo
00?o0000ooooooooool0=?ooool00ol0003oooooo`000006ooooo`03ogMgMol0003ooooo01?ooooo
00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00[ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c004ooooo`03o`000?oooooooooo02cooooo0ol0000Nooooo`03o`000?oooooooooo0:Cooooo
00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Iooooo`0000?ooooooa0@4?ooool00_oo
ool00ol@413oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0:_oo
ool2o`0002;ooooo00?o0000ooooooooool0Y?ooool00ol0003oooooooooo`0fooooo`03o`000?oo
oooooooo01Wooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`cooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Wooooo`?o00009Oooool2o`000:Gooooo00?o0000ooooooooool0
=_ooool00ol0003oooooooooo`0Hooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h<ooooo`Co
00001Oooool2o`0002Gooooo0ol0000Zooooo`03o`000?oooooooooo0:?ooooo00?o0000oooooooo
ool0=_ooool00ol0003oooooooooo`0Gooooo`006oooool00ol0003oooooooooo`0Qooooo`?o0000
;_ooool00ol0003oooooooooo`2Sooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0
5oooool001_ooooo00?o0000ooooooooool07_ooool3o`0003;ooooo00?o0000ooooooooool0U?oo
ool2oonI00cooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Fooooo`006oooool0
0ol0003oooooooooo`0Kooooo`?o0000=_ooool00ol0003oooooooooo`2Booooo`03oonI0?oooooo
oooo00gooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0Eooooo`006_ooool00ol0
003oooooooooo`0Jooooo`;o0000>_ooool00ol0003oooooooooo`2?ooooo`;ooiT04Oooool00ol0
003oooooooooo`0fooooo`03o`000?oooooooooo01Cooooo000Jooooo`;o00006?ooool3o`0003go
oooo00?o0000ooooooooool0S?ooool2oonI01Cooooo00?o0000ooooooooool0=Oooool00ol0003o
ooooooooo`0Dooooo`006_ooool00ol0003oooooooooo`0Dooooo`?o0000@Oooool00ol0003ooooo
ooooo`2:ooooo`03oonI0?oooooooooo01Cooooo00?o0000ooooooooool0=_ooool00ol0003ooooo
ooooo`0Cooooo`006_ooool00ol0003oooooooooo`0Aooooo`?o0000AOooool00ol0003ooooooooo
o`27ooooo`;ooiT06?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo01;ooooo000J
ooooo`03o`000?oooooooooo00kooooo0ol00019ooooo`03o`000?oooooooooo08Cooooo0_ooV@0<
ooooo`;oc?l03Oooool00ol0003oooooooooo`0eooooo`;o00004oooool001[ooooo00?o0000oooo
ooooool03?ooool2o`0004gooooo00?o0000ooooooooool0POooool2oonI00gooooo00?oc?l0oooo
ooooool03_ooool00ol0003oooooooooo`0dooooo`;o00004oooool001Wooooo0ol0000:ooooo`?o
0000D?ooool00ol0003oooooooooo`1oooooo`03oonI0?oooooooooo00_ooooo0_o<o`0Booooo`03
o`000?oooooooooo03Gooooo00?o0000ooooooooool04?ooool001[ooooo00?o0000ooooooooool0
1_ooool3o`0005Cooooo00?o0000ooooooooool0O?ooool2oonI00cooooo0_o<o`0Dooooo`03o`00
0?oooooooooo03Kooooo00?o0000ooooooooool03oooool001Wooooo00?o0000ooooooooool01?oo
ool3o`0005Sooooo00?o0000ooooooooool0NOooool2oonI00gooooo00?oc?l0ooooooooool05Ooo
ool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00oooooo000Iooooo`04o`000?oooooo
ooooooooo`?o0000G?ooool00ol0003oooooooooo`1fooooo`;ooiT03Oooool2olco01Wooooo00?o
0000ooooooooool0=Oooool00ol0003oooooooooo`0>ooooo`006Oooool4o`00063ooooo00?o0000
ooooooooool0L_ooool3oonI00gooooo0_o<o`0<ooooo`;o<ol03_ooool00ol0003oooooooooo`0e
ooooo`03o`000?oooooooooo00gooooo000Iooooo`;o0000Hoooool00ol0003oooooooooo`1_oooo
o`;ooiT03_ooool2olco00gooooo00?o<ol0ooooooooool03oooool00ol0003oooooooooo`0doooo
o`03o`000?oooooooooo00gooooo000?ooooo`Co000000?o410@ooooooooool01Oooool00ol0003o
ooooooooo`1Qooooo`03o`000?oooooooooo06cooooo0_ooV@0?ooooo`03olco0?oooooooooo00_o
oooo0_lco`0Booooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool03?ooool0017ooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo06Sooooo
0oooV@0?ooooo`;oc?l03?ooool2oc?o01Gooooo00?o0000ooooooooool0=Oooool00ol0003ooooo
ooooo`0;ooooo`004Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo067ooooo00?o
0000ooooooooool0I?ooool3oonI013ooooo0_o<o`0=ooooo`03oc?o0?oooooooooo01Kooooo00?o
0000ooooooooool0=Oooool00ol0003oooooooooo`0:ooooo`004Oooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0H?ooool3oonI017ooooo0_o<o`0=
ooooo`;o<ol06_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00[ooooo000Aoooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`1Moooo
o`;ooiT04_ooool2olco00gooooo0_lco`0<ooooo`;o0?mV3oooool00ol0003oooooooooo`0doooo
o`03o`000?oooooooooo00Wooooo000Aooooo`03o`000?oooooooooo00cooooo0_l0001Rooooo`03
o`000?oooooooooo05Wooooo0oooV@0Booooo`;oc?l03Oooool2oc?o00gooooo00?o0?mVoooooooo
ool03oooool00ol0003oooooooooo`0cooooo`?o00002_ooool0017ooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo05Gooooo0oooV@0Cooooo`;oc?l0
3Oooool2oc?o00gooooo0_l0ofHCooooo`03o`000?oooooooooo02oooooo0ol00002ooooo`03o`00
0?oooooooooo00Sooooo000?ooooo`03oeEEEOmVIVKo0000017ooooo00?o0000ooooooooool0H?oo
ool00ol0003oooooooooo`1Aooooo`?ooiT05?ooool2olco00gooooo0_lco`0>ooooo`03o`3oI_oo
oooooooo01Cooooo00?o0000ooooooooool0:oooool3o`0000Gooooo00?o0000ooooooooool02?oo
ool002Cooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1=ooooo`?ooiT05?ooool3
olco00gooooo0_lco`0>ooooo`;o0?mV6?ooool00ol0003oooooooooo`0Vooooo`Co00002?ooool0
0ol0003oooooooooo`08ooooo`009Oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo
04Sooooo1?ooV@0Dooooo`?oc?l03_ooool2oc?o00oooooo00?o0?mVooooooooool06Oooool00ol0
003oooooooooo`0Rooooo`?o00003?ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003o
ooooooooo`1Pooooo`03o`000?oooooooooo04Cooooo0oooV@0Eooooo`?oc?l03oooool2oc?o00oo
oooo0_l0ofH;ooooo`;o0?oo3oooool00ol0003oooooooooo`0Oooooo`?o00004?ooool00ol0003o
ooooooooo`07ooooo`009oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo03kooooo
1OooV@0Eooooo`?oc?l04?ooool2oc?o00oooooo0_l0ofH<ooooo`03o`3ooooooooooooo013ooooo
00?o0000ooooooooool06_ooool4o`0001?ooooo00?o0000ooooooooool01oooool002Sooooo0_l0
001Qooooo`03o`000?oooooooooo03Sooooo1OooV@0Fooooo`Coc?l04Oooool2oc?o00oooooo0_l0
ofH<ooooo`;o0?oo5?ooool00ol0003oooooooooo`0Fooooo`?o00005oooool00ol0003ooooooooo
o`07ooooo`00:_ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo02oooooo2?ooV@0H
ooooo`?oc?l04oooool2oc?o00oooooo0_l0ofH=ooooo`03o`3ooooooooooooo01Gooooo00?o0000
ooooooooool04_ooool3o`0001[ooooo00?o0000ooooooooool01oooool002_ooooo00?o0000oooo
ooooool0Goooool00ol0003oooooooooo`0Sooooo`_ooiT07?ooool4olco01?ooooo0olco`0?oooo
o`;o0?mV3Oooool2o`3ooaWooooo00?o0000ooooooooool03Oooool4o`0001gooooo00?o0000oooo
ooooool01oooool002cooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0Looooo`Ko
oiT08oooool4olco01Cooooo0olco`0@ooooo`;o0?mV3_ooool00ol0ooooooooooooo`0Iooooo`03
o`000?oooooooooo00[ooooo0ol0000Qooooo`03o`000?oooooooooo00Oooooo000]ooooo`03o`00
0?oooooooooo05oooooo00?o0000ooooooooool0@?ooool4olco01Gooooo0olco`0Aooooo`;o0?mV
3_ooool2o`3oo`_ooooo0_l0I_l@ooooo`03o`000?oooooooooo00Kooooo0ol0000Tooooo`03o`00
0?oooooooooo00Oooooo000^ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool0>ooo
ool4olco01Kooooo0olco`0Booooo`;o0?mV3_ooool2o`3oo`cooooo00?o06Koooooooooool04Ooo
ool01?l0003oooooooooooooool4o`0002Oooooo00?o0000ooooooooool01oooool002oooooo0_l0
001Pooooo`03o`000?oooooooooo03Kooooo1?o<o`0Gooooo`?o<ol04oooool2o`3oIPkooooo0_l0
ool<ooooo`;o06Ko5Oooool3o`0002cooooo00?o0000ooooooooool01_ooool0037ooooo00?o0000
ooooooooool0G_ooool2o`0003;ooooo1?o<o`0Hooooo`?o<ol05?ooool2o`3oIPkooooo0_l0ool=
ooooo`03o`1Voooooooooooo01;ooooo0ol000000ooooooo0000ooooo`0/ooooo`03o`000?oooooo
oooo00Kooooo000booooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool0:?ooool7olco
01Wooooo0olco`0Eooooo`;o0?mV3_ooool2o`3oo`gooooo0_l0I_lBooooo`?o00001?ooool00ol0
003oooooooooo`0[ooooo`03o`000?oooooooooo00Kooooo000cooooo`03o`000?oooooooooo05oo
oooo00?o0000ooooooooool07?ooool;olco01gooooo0olco`0Eooooo`?o0?mV3_ooool2o`3oo`ko
oooo00?o06Koooooooooool03_ooool4o`0000Sooooo00?o0000ooooooooool0:_ooool00ol0003o
ooooooooo`06ooooo`00=?ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo01Gooooo
1_o<o`0Tooooo`Co<ol05Oooool3o`3oIPkooooo0ol0ool>ooooo`;o06Ko3?ooool2oc<0o`?o0000
3Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00Kooooo000eooooo`03o`000?oo
oooooooo05oooooo00?o0000ooooooooool0>_ooool4oc?o01Kooooo0ol0ofH?ooooo`;o0?oo3ooo
ool2o`1Vo`cooooo0_lc0?l2o`00017ooooo00?o0000ooooooooool0:?ooool00ol0003ooooooooo
o`06ooooo`00=_ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo03Cooooo1Olco`0G
ooooo`?o0?mV4?ooool2o`3oo`oooooo0_l0I_l;ooooo`;o000000?o<`3oo`000?ooool05?ooool0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Kooooo000gooooo`;o0000H?ooool00ol0
003oooooooooo`0]ooooo`Ko<ol06Oooool3o`3oIQ3ooooo0ol0ool@ooooo`03o`1Voooooooooooo
00Sooooo0ol00002oc<0oaOooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`06oooo
o`00>Oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo02Kooooo1_lco`0Looooo`?o
0?mV4Oooool2o`3ooa7ooooo0_l0I_l8ooooo`?o000000?ooooooc<0oolc0?l06_ooool00ol0003o
ooooooooo`0Wooooo`03o`000?oooooooooo00Gooooo000jooooo`03o`000?oooooooooo05kooooo
00?o0000ooooooooool07oooool6oc?o01oooooo0ol0ofHBooooo`;o0?oo4Oooool2o`1Vo`Kooooo
1?l00003ooooo`03oc<0oooooooooooo01_ooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`05ooooo`00>oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo01Gooooo2Olc
o`0Qooooo`Co0?mV4_ooool3o`3ooa7ooooo0_l0I_l5ooooo`?o00001Oooool2oc<0o`cooooo0_o<
0?lAooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool01Oooool003cooooo00?o0000
ooooooooool0G_ooool00ol0003oooooooooo`0>ooooo`Ko<ol09Oooool5o`3oIQCooooo0_l0oolA
ooooo`?o06Ko1?ooool3o`0000Kooooo0_lc0?l<ooooo`;oc03o4oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo00Gooooo000mooooo`03o`000?oooooooooo05kooooo00?o0000oooo
ooooool0=?ooool4o`3oIQOooooo0_l0oolAooooo`;o06Ko0oooool4o`0000Oooooo0_lc0?l<oooo
o`;oc03o5_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00Gooooo000nooooo`;o
0000Goooool00ol0003oooooooooo`0^ooooo`Go0?mV6?ooool3o`3ooa7ooooo0_l0I_l2ooooo`?o
00002Oooool2oc<0o`gooooo00?oc03oooooooooool05oooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo00Gooooo0010ooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool0
9oooool6o`3oIQSooooo1Ol0oolAooooo`?o06Ko00Coooooo`000?l0003o00002_ooool2oc<0o`go
oooo0_o<0?lKooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool01Oooool0047ooooo
00?o0000ooooooooool0GOooool00ol0003oooooooooo`0Pooooo`Ko0?mV6_ooool4o`3ooaCooooo
0_l0I_l4o`0000_ooooo0_lc0?l=ooooo`;oc03o7_ooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo00Gooooo0012ooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool06?oo
ool7o`3oIQcooooo1?l0oolEooooo`?o06Ko0_l0000=ooooo`;o<`3o3Oooool2ol`0o`gooooo0_oo
09TAooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool01Oooool004?ooooo00?o0000
ooooooooool0GOooool00ol0003oooooooooo`0?ooooo`So0?mV7_ooool5o`3ooaKooooo0ol0I_l2
o`0000gooooo0olc0?l=ooooo`;oc03o3_ooool00ooo09Woooooooooo`0Booooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool01?ooool004Cooooo00?o0000ooooooooool0GOooool00ol0
003oooooooooo`08ooooo`Ko0?mV8_ooool4o`3ooaSooooo0ol0I_l2o`0000kooooo0_lc0?l>oooo
o`;oc03o3_ooool2ool0VAKooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`04oooo
o`00AOooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo02_ooooo1?l0oolHooooo`Co
06Ko00?o0000ooooooooool03_ooool2oc<0o`oooooo00?oc03oooooooooool03?ooool2ool0VAWo
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`04ooooo`00A_ooool2o`0005kooooo
00?o0000ooooooooool09Oooool5o`3ooaWooooo0ol0I_l2o`00013ooooo0olc0?l?ooooo`;oc03o
3_ooool00ooo09Woooooooooo`0Jooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
1?ooool004Sooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`0Pooooo`Co0?oo6ooo
ool3o`1Vo`;o00004Oooool2oc<0oa3ooooo0_o<0?l>ooooo`;oo`2I7Oooool00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo00Cooooo0019ooooo`03o`000?oooooooooo05cooooo00?o0000
ooooooooool06_ooool5o`3ooacooooo0ol0I_l00ol0003oooooooooo`0@ooooo`?o<`3o4?ooool2
ol`0o`oooooo00?oo`2Iooooooooool02_ooool2ool001;ooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`04ooooo`00B_ooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo
01;ooooo1ol0oolMooooo`Co06Ko00?o0000ooooooooool04Oooool2oc<0oa7ooooo0_o<0?l?oooo
o`;oo`2I3?ooool00ooo003oooooooooo`0Cooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool01?ooool004_ooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`02ooooo`oo
0?oo7oooool5o`1Vo`;o00005?ooool2oc<0oa7ooooo0_o<0?l?ooooo`;oo`2I3?ooool2ool001Oo
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`04ooooo`00C?ooool00ol0003ooooo
ooooo`1Looooo`03o`000?oooooooooo02_ooooo1?l0I_l3o`0001Gooooo0olc0?l@ooooo`?oc03o
3oooool2ool0V@cooooo0_oo000Jooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
0oooool004gooooo0_l0001Mooooo`03o`000?oooooooooo02Kooooo1?l0I_l01?oooooo0000o`00
0?l0000Eooooo`?o<`3o4Oooool2ol`0oa3ooooo0_oo09T=ooooo`03ool00?oooooooooo01[ooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`03ooooo`00Coooool00ol0003ooooooooo
o`1Kooooo`03o`000?oooooooooo023ooooo1Ol0I_l2ooooo`?o00005Oooool3oc<0oa;ooooo0_o<
0?l@ooooo`;oo`2I3Oooool2ool001kooooo00?o0000ooooooooool06_ooool00ol0003ooooooooo
o`03ooooo`00D?ooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo01_ooooo1?l0I_l3
ooooo`Co00005?ooool4oc<0oa;ooooo0oo<0?l@ooooo`;oo`2I3_ooool00ooo003oooooooooo`0O
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool00oooool0057ooooo00?o0000oooo
ooooool0Foooool00ol0003oooooooooo`0Aooooo`Wo06Ko1?ooool3o`0001Gooooo0olc0?lCoooo
o`?oc03o4Oooool2ool0V@kooooo0_oo000Sooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool00oooool005;ooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`03ooooo`go
06Ko2_ooool3o`0001Cooooo1?lc0?lCooooo`?oc03o4Oooool3ool0V@kooooo0_oo000Vooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool00oooool005?ooooo00?o0000ooooooooool0
FOooool7o`1Voa?ooooo1?l0000Booooo`Go<`3o5?ooool3ol`0oa7ooooo0ooo09T?ooooo`;oo`00
:?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00?ooooo001Dooooo`;o0000G?oo
ool00ol0003oooooooooo`0Aooooo`?o00004_ooool4oc<0oaGooooo1?o<0?lBooooo`;oo`2I3ooo
ool3ool002_ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`03ooooo`00E_ooool0
0ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00gooooo0ol0000@ooooo`Go<`3o5_ooool3
ol`0oa?ooooo0ooo09T?ooooo`;oo`00;oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo00;ooooo001Gooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool02?ooool4o`00
00cooooo1olc0?lHooooo`?oc03o5?ooool2ool0VA3ooooo0_oo000booooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool00_ooool005Sooooo00?o0000ooooooooool0F_ooool00ol0003o
ooooooooo`04ooooo`?o00002Oooool7oc<0oacooooo0oo<0?lDooooo`?oo`2I4?ooool2ool003Go
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`02ooooo`00FOooool00ol0003ooooo
ooooo`1Jooooo`03o`000?oooooooooo00?o00001Oooool7oc<0oaoooooo1?o<0?lDooooo`?oo`2I
4?ooool3ool003Oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`02ooooo`00F_oo
ool00ol0003oooooooooo`1Jooooo`[o<`3o8oooool3ol`0oaKooooo0_oo09T@ooooo`?oo`00>ooo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00;ooooo001Kooooo`03o`000?oooooo
oooo05;ooooo1olc0?l00ol0003oooooooooo`0Vooooo`Coc03o5_ooool3ool0VA3ooooo0_oo000o
ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00_ooool005cooooo0_l0001Ioooo
o`03o`000?oooooooooo02?ooooo0oo<0?lGooooo`?oo`2I4?ooool3ool004;ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`02ooooo`00G_ooool00ol0003oooooooooo`1Fooooo`03
o`000?oooooooooo01gooooo1_o<0?lGooooo`?oo`2I4Oooool2ool004Kooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`02ooooo`00Goooool00ol0003oooooooooo`1Eooooo`03o`00
0?oooooooooo01Kooooo1oo<0?lIooooo`Coo`2I4Oooool3ool004Sooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`01ooooo`00H?ooool00ol0003oooooooooo`1Dooooo`03o`000?oo
oooooooo00oooooo1oo<0?lMooooo`?oo`2I4_ooool3ool004cooooo00?o0000ooooooooool04?oo
ool00ol0003oooooooooo`01ooooo`00HOooool00ol0003oooooooooo`1Cooooo`03o`000?oooooo
oooo00Sooooo1oo<0?lPooooo`Coo`2I4_ooool3ool0053ooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`01ooooo`00H_ooool00ol0003oooooooooo`1Booooo`_oc03o8_ooool5ool0
VA?ooooo0ooo001Dooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00Oooool006?o
oooo0_l0001;ooooo`Ooc03o00?o0000ooooooooool09Oooool5ool0VAGooooo0ooo001Hooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool00Oooool006Gooooo00?o0000ooooooooool0
Coooool00ol0003oooooooooo`0Pooooo`Goo`2I5oooool3ool005_ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`01ooooo`00I_ooool00ol0003oooooooooo`1>ooooo`03o`000?oo
oooooooo01_ooooo1Ooo09THooooo`Coo`00Goooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo007ooooo001Wooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool05_ooool5
ool0VA[ooooo0ooo001Tooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool00Oooool0
06Sooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0@ooooo`Koo`2I6oooool4ool0
06Sooooo00?o0000ooooooooool02oooool1o`00007ooooo0Oooool006Wooooo00?o0000oooooooo
ool0Boooool00ol0003oooooooooo`09ooooo`Ooo`2I7Oooool4ool006cooooo00?o0000oooooooo
ool02oooool1o`00007ooooo0Oooool006[ooooo00?o0000ooooooooool0B_ooool00ol0003oo`2I
ool0V@09ool0VB7ooooo0ooo001aooooo`03o`000?oooooooooo00[ooooo0Ol00001ooooo`7ooooo
001[ooooo`;o0000A?ooool7ool0VBSooooo1?oo001eooooo`03o`000?oooooooooo00Wooooo0Ol0
0001ooooo`7ooooo001]ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool08_ooool4
ool007[ooooo00?o0000ooooooooool02?ooool1o`00007ooooo0Oooool006kooooo00?o0000oooo
ooooool0A_ooool00ol0003oooooooooo`0Mooooo`Goo`00Ooooool00ol0003oooooooooo`07oooo
o`7o00000Oooool1ooooo`00Koooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo01So
oooo1Ooo0024ooooo`03o`000?oooooooooo00Oooooo0Ol00001ooooo`7ooooo001`ooooo`03o`00
0?oooooooooo04Cooooo00?o0000ooooooooool03_ooool:ool008[ooooo00?o0000ooooooooool0
1_ooool1o`00007ooooo0Oooool0077ooooo00?o0000ooooooooool0@oooool00ol0003oooooool0
000>ool009Gooooo00?o0000ooooooooool01Oooool1o`00007ooooo0Oooool007;ooooo0_l0000m
ooooo`Soo`00YOooool00ol0003oooooooooo`05ooooo`7o00000Oooool007Cooooo00?o0000oooo
ooooool0?oooool00ol0003oooooooooo`2Vooooo`03o`000?oooooooooo00Cooooo0Ol00001oooo
o`00MOooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo0:Kooooo00?o0000oooooooo
ool01?ooool1o`00007ooooo001fooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0
Yoooool00ol0003oooooooooo`03ooooo`7o00000Oooool007Oooooo00?o0000ooooooooool0??oo
ool00ol0003oooooooooo`2Xooooo`03o`000?oooooooooo00;ooooo0Ol00001ooooo`00N?ooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo0:Wooooo00Go0000ooooooooooooooooo`00
0001ooooo`00NOooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo0:[ooooo00Co0000
oooooooooooo00000Oooool007[ooooo0_l0000jooooo`03o`000?oooooooooo0:[ooooo00Co0000
oooooooooooo00000Oooool007cooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`2[
ooooo`03o`000?oooooooooo007o0000001mooooo`03o`000?oooooooooo03Kooooo00?o0000oooo
ooooool0[?ooool1o`00007ooooo0Ol0000007kooooo00?o0000ooooooooool0=Oooool00ol0003o
ooooooooo`2]ooooo`;o0000001oooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0
[?ooool3o`000000P?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo0:Sooooo1?l0
0003ooooo`00POooool2o`0003?ooooo00?o0000ooooooooool0YOooool3o`0000Oooooo0023oooo
o`03o`000?oooooooooo033ooooo00?o0000ooooooooool0XOooool4o`0000[ooooo0024ooooo`03
o`000?oooooooooo02oooooo00?o0000ooooooooool0WOooool4o`0000kooooo0025ooooo`03o`00
0?oooooooooo02kooooo00?o0000ooooooooool0VOooool4o`0001;ooooo0026ooooo`03o`000?oo
oooooooo02gooooo00?o0000ooooooooool0UOooool4o`0001Kooooo0027ooooo`03o`000?oooooo
oooo02cooooo00?o0000ooooooooool0T_ooool3o`0001[ooooo0028ooooo`;o0000;?ooool00ol0
003oooooooooo`2>ooooo`Co00007Oooool008[ooooo00?o0000ooooooooool0:Oooool00ol0003o
ooooooooo`2:ooooo`Co00008Oooool008_ooooo00?o0000ooooooooool0:?ooool00ol0003ooooo
ooooo`26ooooo`Co00009Oooool008cooooo00?o0000ooooooooool09oooool00ol0003ooooooooo
o`22ooooo`Co0000:Oooool008gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`1o
ooooo`?o0000;Oooool008kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1koooo
o`Co0000<?ooool008oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`1gooooo`Co
0000=?ooool0093ooooo0_l0000Tooooo`03o`000?oooooooooo07?ooooo1?l0000hooooo`00T_oo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo073ooooo0ol0000looooo`00Toooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo06cooooo1?l0000oooooo`00U?ooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo06Sooooo1?l00013ooooo`00UOooool00ol0003o
ooooooooo`0Nooooo`03o`000?oooooooooo06Cooooo1?l00017ooooo`00U_ooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo063ooooo1?l0001;ooooo`00Uoooool2o`0001gooooo00?o
0000ooooooooool0GOooool3o`0004oooooo002Iooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool0FOooool4o`0005;ooooo002Jooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool0EOooool4o`0005Kooooo002Kooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool0DOooool4o`0005[ooooo002Looooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
COooool4o`0005kooooo002Mooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0B_oo
ool3o`0006;ooooo002Nooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0A_ooool4
o`0006Gooooo002Oooooo`;o00005?ooool00ol0003oooooooooo`13ooooo`Co0000JOooool00:7o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0oooooo`Co0000KOooool00:;ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0kooooo`Co0000LOooool00:?ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0hooooo`?o0000MOooool00:Cooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0dooooo`Co0000N?ooool00:Gooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0`ooooo`Co0000O?ooool00:Kooooo0_l0000=ooooo`03
o`000?oooooooooo02cooooo1?l00020ooooo`00Z?ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo02Wooooo0ol00024ooooo`00ZOooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo02Gooooo1?l00027ooooo`00Z_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo027ooooo1?l0002;ooooo`00Zoooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
01gooooo1?l0002?ooooo`00[?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Wo
oooo1?l0002Cooooo`00[Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Kooooo
0ol0002Gooooo`00[_ooool2o`0000Gooooo00?o0000ooooooooool04_ooool4o`0009[ooooo002`
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03_ooool4o`0009kooooo002aoooo
o`05o`000?ooooooooooooooool000003?ooool4o`000:;ooooo002booooo`04o`000?oooooooooo
o`0000Sooooo1?l0002Vooooo`00/oooool00ol0003oooooo`000005ooooo`?o0000Z_ooool00;Co
oooo0_l000000ooooooo0000o`000002o`000:gooooo002eooooo`;o0000/Oooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {319.688, 0}} -> {-0.0710364, -0.0181728, \
0.0035149, 0.0035149}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .89104 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-16 1.0656 -0.0363427 1.0656 [
[.02544 .21571 -12 -8.9133 ]
[.02544 .21571 0 .0867 ]
[.16074 .16277 -11.6592 -9 ]
[.16074 .16277 .34081 0 ]
[.3021 .10747 -5.60025 -9 ]
[.3021 .10747 .39975 0 ]
[.44992 .04965 -5.37091 -9 ]
[.44992 .04965 .62909 0 ]
[.60467 -0.01084 -5.14157 -9 ]
[.60467 -0.01084 .85843 0 ]
[.66454 .05085 0 -6.20675 ]
[.66454 .05085 6 2.79325 ]
[.80797 .25198 0 -6.0417 ]
[.80797 .25198 6 2.9583 ]
[.93071 .4241 0 -5.90576 ]
[.93071 .4241 6 3.09424 ]
[.02254 .22988 -12 -2.74631 ]
[.02254 .22988 0 6.25369 ]
[.0142 .29178 -24 -2.78907 ]
[.0142 .29178 0 6.21093 ]
[.00558 .35578 -6 -2.83339 ]
[.00558 .35578 0 6.16661 ]
[-0.00334 .42198 -18 -2.87938 ]
[-0.00334 .42198 0 6.12062 ]
[-0.01257 .49051 -6 -2.92712 ]
[-0.01257 .49051 0 6.07288 ]
[ 0 0 0 0 ]
[ 1 .89104 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03495 .22504 m
.61241 0 L
s
.03495 .22504 m
.03971 .2297 L
s
[(-2)] .02544 .21571 1 .98073 Mshowa
.16988 .17246 m
.17445 .1773 L
s
[(-1)] .16074 .16277 .9432 1 Mshowa
.31082 .11753 m
.31518 .12256 L
s
[(0)] .3021 .10747 .86675 1 Mshowa
.45818 .0601 m
.46231 .06533 L
s
[(1)] .44992 .04965 .7903 1 Mshowa
.61241 0 m
.61628 .00542 L
s
[(2)] .60467 -0.01084 .71386 1 Mshowa
.125 Mabswid
.06148 .2147 m
.06431 .21752 L
s
.08823 .20428 m
.09104 .20712 L
s
.11521 .19376 m
.118 .19663 L
s
.14243 .18316 m
.14519 .18604 L
s
.19758 .16166 m
.20029 .16459 L
s
.22551 .15078 m
.22821 .15373 L
s
.2537 .13979 m
.25637 .14277 L
s
.28213 .12871 m
.28478 .13171 L
s
.33977 .10625 m
.34236 .10929 L
s
.36897 .09487 m
.37153 .09794 L
s
.39844 .08339 m
.40097 .08648 L
s
.42817 .0718 m
.43068 .07491 L
s
.48846 .0483 m
.49091 .05146 L
s
.51902 .03639 m
.52144 .03958 L
s
.54986 .02437 m
.55225 .02758 L
s
.58099 .01224 m
.58335 .01547 L
s
.25 Mabswid
.61241 0 m
.97291 .505 L
s
.65208 .05558 m
.64586 .05794 L
s
[(0)] .66454 .05085 -1 .37928 Mshowa
.79537 .2563 m
.78907 .25846 L
s
[(2)] .80797 .25198 -1 .3426 Mshowa
.91799 .42808 m
.91164 .43006 L
s
[(4)] .93071 .4241 -1 .31239 Mshowa
.125 Mabswid
.69012 .10886 m
.68637 .11025 L
s
.72662 .16 m
.72286 .16135 L
s
.76168 .2091 m
.75791 .21042 L
s
.82778 .3017 m
.82399 .30297 L
s
.85897 .3454 m
.85518 .34664 L
s
.88903 .3875 m
.88522 .38871 L
s
.94594 .46722 m
.94211 .46839 L
s
.25 Mabswid
.03495 .22504 m
0 .48612 L
s
.03495 .22504 m
.04116 .22262 L
s
[(-1)] .02254 .22988 1 -0.38971 Mshowa
.02665 .28704 m
.03288 .28468 L
s
[(-0.5)] .0142 .29178 1 -0.38021 Mshowa
.01807 .35115 m
.02431 .34884 L
s
[(0)] .00558 .35578 1 -0.37036 Mshowa
.00919 .41747 m
.01546 .41521 L
s
[(0.5)] -0.00334 .42198 1 -0.36014 Mshowa
0 .48612 m
.00629 .48392 L
s
[(1)] -0.01257 .49051 1 -0.34953 Mshowa
.125 Mabswid
.03331 .23728 m
.03704 .23583 L
s
.03166 .2496 m
.03539 .24816 L
s
.03 .262 m
.03373 .26056 L
s
.02833 .27448 m
.03207 .27305 L
s
.02496 .29969 m
.0287 .29828 L
s
.02325 .31243 m
.02699 .31102 L
s
.02154 .32525 m
.02528 .32385 L
s
.01981 .33816 m
.02355 .33676 L
s
.01632 .36423 m
.02007 .36285 L
s
.01455 .37741 m
.01831 .37603 L
s
.01278 .39067 m
.01653 .3893 L
s
.01099 .40402 m
.01475 .40266 L
s
.00738 .43101 m
.01114 .42966 L
s
.00555 .44464 m
.00932 .4433 L
s
.00371 .45837 m
.00748 .45704 L
s
.00186 .4722 m
.00563 .47087 L
s
.25 Mabswid
.03495 .22504 m
0 .48612 L
s
0 .48612 m
.46953 .89104 L
s
.46953 .89104 m
.47294 .65459 L
s
.47294 .65459 m
.03495 .22504 L
s
.61241 0 m
.97291 .505 L
s
.97291 .505 m
1 .75117 L
s
1 .75117 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.03495 .22504 m
0 .48612 L
s
0 .48612 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.61241 0 m
.03495 .22504 L
s
.47294 .65459 m
.97291 .505 L
s
.97291 .505 m
1 .75117 L
s
1 .75117 m
.46953 .89104 L
s
.46953 .89104 m
.47294 .65459 L
s
0 0 m
1 0 L
1 .89104 L
0 .89104 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.45994 .73455 m
.50614 .7313 L
s
1 0 .6 r
.45863 .71446 m
.5035 .71127 L
s
1 0 0 r
.50614 .7313 m
.55362 .72552 L
s
.8 0 1 r
.45731 .69433 m
.50086 .6912 L
s
1 0 .6 r
.5035 .71127 m
.54969 .70559 L
s
.2 0 1 r
.45598 .67416 m
.49822 .67109 L
s
.8 0 1 r
.50086 .6912 m
.54575 .68562 L
s
0 .4 1 r
.45466 .65394 m
.49556 .65094 L
s
1 0 0 r
.55362 .72552 m
.60103 .71728 L
s
.2 0 1 r
.49822 .67109 m
.54181 .66562 L
s
0 1 1 r
.45333 .63368 m
.49291 .63075 L
s
1 0 .6 r
.54969 .70559 m
.59585 .69748 L
s
0 .4 1 r
.49556 .65094 m
.53785 .64557 L
s
0 1 .4 r
.452 .61338 m
.49024 .61052 L
s
.8 0 1 r
.54575 .68562 m
.59067 .67765 L
s
0 1 1 r
.49291 .63075 m
.5339 .62549 L
s
.2 1 0 r
.45066 .59304 m
.48758 .59024 L
s
.2 0 1 r
.54181 .66562 m
.58547 .65778 L
s
0 1 .4 r
.49024 .61052 m
.52993 .60538 L
s
0 .4 1 r
.53785 .64557 m
.58027 .63788 L
s
.8 1 0 r
.44933 .57265 m
.4849 .56993 L
s
.2 1 0 r
.48758 .59024 m
.52596 .58522 L
s
1 0 0 r
.60103 .71728 m
.64764 .70668 L
s
0 1 1 r
.5339 .62549 m
.57506 .61795 L
s
1 .6 0 r
.44799 .55221 m
.48222 .54957 L
s
.8 1 0 r
.4849 .56993 m
.52197 .56503 L
s
1 0 .6 r
.59585 .69748 m
.64125 .68704 L
s
0 1 .4 r
.52993 .60538 m
.56984 .59798 L
s
.8 0 1 r
.59067 .67765 m
.63486 .66737 L
s
1 .6 0 r
.48222 .54957 m
.51799 .54479 L
s
.2 1 0 r
.52596 .58522 m
.56461 .57799 L
s
.2 0 1 r
.58547 .65778 m
.62845 .64768 L
s
.8 1 0 r
.52197 .56503 m
.55937 .55796 L
s
0 .4 1 r
.58027 .63788 m
.62204 .62796 L
s
0 1 1 r
.57506 .61795 m
.61562 .60821 L
s
1 .6 0 r
.51799 .54479 m
.55413 .53789 L
s
0 1 .4 r
.56984 .59798 m
.60919 .58844 L
s
1 0 0 r
.64764 .70668 m
.69304 .69379 L
s
.2 1 0 r
.56461 .57799 m
.60276 .56864 L
s
1 0 .6 r
.64125 .68704 m
.68547 .67435 L
s
.8 1 0 r
.55937 .55796 m
.59631 .54881 L
s
.8 0 1 r
.63486 .66737 m
.67789 .65488 L
s
1 .6 0 r
.55413 .53789 m
.58985 .52895 L
s
.2 0 1 r
.62845 .64768 m
.6703 .6354 L
s
0 .4 1 r
.62204 .62796 m
.6627 .6159 L
s
0 1 1 r
.61562 .60821 m
.6551 .59638 L
s
0 1 .4 r
.60919 .58844 m
.64749 .57684 L
s
.2 1 0 r
.60276 .56864 m
.63987 .55727 L
s
.8 1 0 r
.59631 .54881 m
.63224 .53769 L
s
1 .6 0 r
.58985 .52895 m
.62461 .51809 L
s
1 0 0 r
.69304 .69379 m
.73691 .67866 L
s
1 0 .6 r
.68547 .67435 m
.72815 .65946 L
s
.8 0 1 r
.67789 .65488 m
.71939 .64024 L
s
.2 0 1 r
.6703 .6354 m
.71062 .62102 L
s
0 .4 1 r
.6627 .6159 m
.70185 .60178 L
s
0 1 1 r
.6551 .59638 m
.69307 .58253 L
s
0 1 .4 r
.64749 .57684 m
.68429 .56327 L
s
.2 1 0 r
.63987 .55727 m
.6755 .544 L
s
.8 1 0 r
.63224 .53769 m
.66671 .52471 L
s
1 .6 0 r
.62461 .51809 m
.6579 .50541 L
s
1 0 0 r
.73691 .67866 m
.77877 .66135 L
s
1 0 .6 r
.72815 .65946 m
.76883 .64244 L
s
.8 0 1 r
.71939 .64024 m
.75888 .62354 L
s
.2 0 1 r
.71062 .62102 m
.74893 .60463 L
s
0 .4 1 r
.70185 .60178 m
.73897 .58571 L
s
0 1 1 r
.69307 .58253 m
.72902 .5668 L
s
0 1 .4 r
.68429 .56327 m
.71906 .54788 L
s
.2 1 0 r
.6755 .544 m
.7091 .52896 L
s
.8 1 0 r
.66671 .52471 m
.69914 .51003 L
s
1 .6 0 r
.6579 .50541 m
.68918 .4911 L
s
1 0 0 r
.77877 .66135 m
.81788 .64208 L
s
1 0 .6 r
.76883 .64244 m
.80673 .62354 L
s
.8 0 1 r
.75888 .62354 m
.79559 .60501 L
s
.2 0 1 r
.74893 .60463 m
.78446 .58648 L
s
0 .4 1 r
.73897 .58571 m
.77333 .56796 L
s
0 1 1 r
.72902 .5668 m
.7622 .54945 L
s
0 1 .4 r
.71906 .54788 m
.75108 .53095 L
s
.2 1 0 r
.7091 .52896 m
.73996 .51245 L
s
.8 1 0 r
.69914 .51003 m
.72885 .49396 L
s
1 .6 0 r
.68918 .4911 m
.71774 .47548 L
s
.71774 .47548 m
.74272 .45913 L
s
.8 1 0 r
.72885 .49396 m
.75494 .47709 L
s
.2 1 0 r
.73996 .51245 m
.76716 .49507 L
s
0 1 .4 r
.75108 .53095 m
.7794 .51307 L
s
0 1 1 r
.7622 .54945 m
.79165 .53109 L
s
0 .4 1 r
.77333 .56796 m
.80391 .54913 L
s
.2 0 1 r
.78446 .58648 m
.81618 .56718 L
s
.8 0 1 r
.79559 .60501 m
.82846 .58525 L
s
1 0 .6 r
.80673 .62354 m
.84076 .60334 L
s
1 0 0 r
.81788 .64208 m
.85307 .62145 L
s
0 g
.25 Mabswid
.61241 0 m
.97291 .505 L
s
.97291 .505 m
1 .75117 L
s
1 .75117 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.03495 .22504 m
0 .48612 L
s
0 .48612 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.61241 0 m
.03495 .22504 L
s
.03495 .22504 m
.61241 0 L
s
.03495 .22504 m
.03971 .2297 L
s
[(-2)] .02544 .21571 1 .98073 Mshowa
.16988 .17246 m
.17445 .1773 L
s
[(-1)] .16074 .16277 .9432 1 Mshowa
.31082 .11753 m
.31518 .12256 L
s
[(0)] .3021 .10747 .86675 1 Mshowa
.45818 .0601 m
.46231 .06533 L
s
[(1)] .44992 .04965 .7903 1 Mshowa
.61241 0 m
.61628 .00542 L
s
[(2)] .60467 -0.01084 .71386 1 Mshowa
.125 Mabswid
.06148 .2147 m
.06431 .21752 L
s
.08823 .20428 m
.09104 .20712 L
s
.11521 .19376 m
.118 .19663 L
s
.14243 .18316 m
.14519 .18604 L
s
.19758 .16166 m
.20029 .16459 L
s
.22551 .15078 m
.22821 .15373 L
s
.2537 .13979 m
.25637 .14277 L
s
.28213 .12871 m
.28478 .13171 L
s
.33977 .10625 m
.34236 .10929 L
s
.36897 .09487 m
.37153 .09794 L
s
.39844 .08339 m
.40097 .08648 L
s
.42817 .0718 m
.43068 .07491 L
s
.48846 .0483 m
.49091 .05146 L
s
.51902 .03639 m
.52144 .03958 L
s
.54986 .02437 m
.55225 .02758 L
s
.58099 .01224 m
.58335 .01547 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 256.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001@2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00gOooool5o`0008Kooooo003Mooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0Q_ooool00=ko
oooo00?oV9RHob4Q8Oo^k^h0Qoooool00=oooooo00?oV9RHob4Q8Oo^k^h0Q_ooool00>3ooooo00?o
MgMgofIVI_ooool0QOooool00>7ooooo00?o0000ooooooooool0Q?ooool00=gooooo00Go0000okZj
^_ooooooV9RHoa0@4026ooooo`00gOooool01OnHV9So410@o`000?lQ8B7oc<c<08Kooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003Tooooo`;o0000P_ooool0
0>7ooooo0ol000000ooooooo0000ooooo`21ooooo`00goooool2o`0000Cooooo0_l00021ooooo`00
g?ooool3o`0000Kooooo00?o0000ooooool00000P?ooool00=[ooooo0_l00009ooooo`03o`000?oo
oooo0000083ooooo003Gooooo`?o000000?oooooo`000?ooool02?ooool01?l0003oooooooooool0
001oooooo`00e?ooool3o`0000Cooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooo
oooo000007kooooo003Booooo`;o00004Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo07_ooooo002Zooooo`Co000000?o410@ooooooooool07_ooool3o`0001?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1kooooo`00[?ooool00ol0003oooooooooo`0Nooooo`;o
000000?oooooo`000?ooool04oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07[o
oooo002/ooooo`03o`000?oooooooooo01_ooooo0ol00004ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`1iooooo`00[?ooool00ol0003ooooooooo
o`0Iooooo`;o00006oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo07Wooooo002/
ooooo`03o`000?oooooooooo01Kooooo0ol0000Mooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool02?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^06_ooooo002/ooooo`03o`000?oooooo
oooo01Cooooo0_l000000ooooooo0000ooooo`0Mooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01oooool01OmgMgOoV9RHoooooonHV9SoMgMg06_ooooo002/ooooo`03o`000?oooooo
oooo017ooooo0ol00004ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`06ooooo`05oa0@4?ooooooooooooooool@4100Joooool00:[ooooo00?oEEEE
ofIVI_l000004Oooool2o`0002Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06
ooooo`05o`000?ooooooooooooooool00000Joooool00;_ooooo0ol0000Wooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000006_ooooo002i
ooooo`;o000000?oooooo`000?ooool09oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Cooooo00Go410@oooooooooooooooooa0@401[ooooo`00]_ooool3o`0000Cooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`1[ooooo`00/oooool3o`0002oooooo00?o0000ooooooooool02Oooool2
o`0000Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1[ooooo`00/Oooool2o`0003;ooooo00?o0000
ooooooooool02?ooool01?l0003oooooooooool0001dooooo`00[_ooool3o`000003ooooool0003o
oooo037ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1aooooo`00[?ooool2o`00
00Gooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
077ooooo002Yooooo`?o0000>_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo073o
oooo002Wooooo`;o0000?Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo06oooooo
002Tooooo`?o000000?oooooo`000?ooool0??ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo06oooooo002Rooooo`;o0000@_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo06kooooo001gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08oooool3o`0004Cooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1]ooooo`00Moooool01OmgMgOoV9RHoooooonHV9So
MgMg027ooooo0_l00017ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0K?ooool0
07Oooooo00Go410@oooooooooooooooooa0@400Nooooo`?o00000_ooool00ol0003oooooooooo`14
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0K?ooool007Oooooo00Go0000oooo
ooooooooooooo`00000Looooo`;o0000C?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo06_ooooo001gooooo`05o`000?ooooooooooooooool000006Oooool3o`0004kooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`1Zooooo`00Moooool01Ol@413ooooooooooooooooo
410@01Kooooo0ol0001Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0J_ooool0
07Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Dooooo`;o00000oooool00ol0003oooooooooo`1>
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0JOooool007Oooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Aooooo`?o0000E_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo06Sooooo002;ooooo`;o0000FOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
06Sooooo0028ooooo`?o0000Foooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo06Oo
oooo0026ooooo`;o00000oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo01Gooooo
0_l0001Xooooo`00Poooool3o`00063ooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`1Uooooo`00POooool2o`0006?ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1U
ooooo`00O_ooool4o`0006Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`1Toooo
o`00O?ooool2o`0000Cooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo06?ooooo001iooooo`?o0000J_ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo06?ooooo001gooooo`;o0000KOooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo06;ooooo001dooooo`?o000000?oooooo`000?ooool0K?ooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo067ooooo001aooooo`?o0000L_ooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo063ooooo0019ooooo`Co000000?o410@ooooooooool07oooool2o`0007Go
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1Pooooo`00Boooool00ol0003ooooo
ooooo`0Nooooo`?o0000Moooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo05oooooo
0010ooooo`Ko00001Oooool00ol0003oooooooooo`0Looooo`;o00000_ooool00ol0003ooooooooo
o`1eooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0G_ooool004_ooooo00?o0000
ooooooooool06Oooool3o`0007cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1N
ooooo`00Boooool00ol0003oooooooooo`0Gooooo`;o0000Ooooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo05gooooo001;ooooo`03o`000?oooooooooo01Cooooo0ol00021ooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0G?ooool004_ooooo00?o0000ooooooooool0
4_ooool2o`0000?ooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo05_ooooo0019ooooo`03oeEEEOmVIVKo0000017ooooo0ol00026ooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool0Foooool005_ooooo0_l00029ooooo`03o`000?oooooo
oooo027ooooo0_l0001Looooo`00F?ooool3o`000003ooooool0003ooooo08Sooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`1Iooooo`00E_ooool2o`0008kooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`1Iooooo`00Doooool3o`00093ooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`1Hooooo`00D?ooool3o`0009?ooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1Gooooo`00C_ooool2o`0000;ooooo00?o0000ooooooooool0TOooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo05Kooooo001;ooooo`?o00001Oooool00ol0
003oooooooooo`2@ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0E_ooool004Wo
oooo0_l0002Kooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0EOooool004Kooooo
1?l0002Looooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0E?ooool004Cooooo0_l0
002Pooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0E?ooool001[ooooo1Ol0000R
ooooo`?o0000X_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo05?ooooo000Joooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@08?ooool2o`000:Gooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`1Booooo`004_ooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h07_ooool3o`00
0003ooooool0003ooooo0:Cooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`1Aoooo
o`007?ooool00onHV9So8B4Qonk^kP0Kooooo`;o0000Z_ooool00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo057ooooo000Mooooo`03ogMgMomVIVKooooo01Oooooo0ol0002]ooooo`03o`00
0?oooooooooo02_ooooo00?o0000ooooooooool0D?ooool001kooooo00?o0000ooooooooool05?oo
ool2o`000;3ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`1?ooooo`006_ooool0
1Ol0003o^[ZjoooooonHV9So410@01?ooooo0ol00002ooooo`03o`000?oooooooooo0:gooooo00?o
0000ooooooooool0;?ooool2o`00053ooooo000Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`04?oo
ool3o`000;Gooooo00?o0000ooooooooool0;?ooool2o`00053ooooo000]ooooo`;o0000^?ooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo04gooooo000Zooooo`?o000000?oooooo`00
0?ooool0]oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo04gooooo000Xooooo`;o
0000_Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo04cooooo000Uooooo`?o0000
_oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo04_ooooo000Tooooo`;o0000`Ooo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo04[ooooo000Jooooo`Co000000?o410@
ooooooooool00oooool00ol0003oooooo`000030ooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool0B_ooool001cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0002o
ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0BOooool0017ooooo1_l00005oooo
o`03o`000?oooooooooo00Gooooo0_l00002ooooo`03o`000?oooooooooo0;cooooo00?o0000oooo
ooooool0<oooool00ol0003oooooooooo`18ooooo`007?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0^oooool00ol0003oooooooooo`0cooooo`03
o`000?oooooooooo00Oooooo1Ol0000looooo`007?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo00Kooooo00GoV9RHob4Q8Oo^k^koooooodA4A00looooo`007?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00ol0003ooooo
ooooo`0eooooo`03o`000?oooooooooo00Kooooo00?oV9RHob4Q8Oo^k^h0?Oooool001cooooo00?o
0000ooooooooool01?ooool3o`0000Kooooo00?o0000ooooooooool0^?ooool00ol0003ooooooooo
o`0fooooo`03o`000?oooooooooo00Kooooo00?oV9RHob4Q8Oo^k^h0??ooool001[ooooo00?oEEEE
ofIVI_l000001_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;Oooooo00?o0000
ooooooooool0=_ooool00ol0003oooooooooo`07ooooo`03ogMgMomVIVKooooo03_ooooo000Soooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0]_ooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0>_ooool002?ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`2eooooo`03o`000?oooooooooo03Oooooo0_l00004ooooo`05
o`000?nj^[[ooooooiRHV?l@4100??ooool002?ooooo0_l0000;ooooo`03o`000?oooooooooo0;Co
oooo00?o0000ooooooooool0=_ooool00ol0003oooooo`000004ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`0??ooool002?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`2cooooo`03
o`000?oooooooooo03Wooooo00?o0000ooooooooool0@_ooool002;ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0
@Oooool002;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`2`ooooo`;o0000?Ooo
ool00ol0003oooooooooo`10ooooo`008_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo0:cooooo0ol000000ooooooo0000ooooo`0looooo`03o`000?oooooooooo043ooooo000Roooo
o`;o00004Oooool00ol0003oooooooooo`2Xooooo`?o00001Oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo03oooooo000Rooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool0Y?ooool3o`0000Wooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0nooooo`00
8_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo0:3ooooo0ol0000=ooooo`03o`00
0?oooooooooo03[ooooo00?o0000ooooooooool0?_ooool002;ooooo0ol0000Cooooo`03o`000?oo
oooooooo09cooooo0ol0000Aooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0?Ooo
ool002;ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`2Iooooo`;o00005?ooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo03cooooo000Qooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool0UOooool3o`0001Oooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`0kooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo097ooooo0ol0000Kooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0>oooool0
00Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0SOooool3o`0001oooooo00?o0000
ooooooooool0>_ooool00ol0003oooooooooo`0jooooo`001Ol00002ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`02ooooo`;o00006_ooool00ol0003oooooooooo`29
ooooo`?o00008oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03Wooooo0007oooo
o`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool0Q_ooool2o`0002Kooooo00?o0000ooooooooool0>_ooool2
o`0003[ooooo0007ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`22ooooo`?o0000:Ooo
ool00ol0003oooooooooo`0iooooo`;o0000>_ooool000Oooooo00Go410@oooooooooooooooooa0@
400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`1nooooo`?o0000;Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03Oooooo0007
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`;o00007_oo
ool00ol0003oooooooooo`1jooooo`?o0000<Oooool00ol0003oooooooooo`0iooooo`03o`000?oo
oooooooo03Oooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Cooooo0_l0
000Pooooo`03o`000?oooooooooo07Kooooo0ol0000eooooo`03o`000?oooooooooo03Wooooo00?o
0000ooooooooool0=_ooool0023ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1b
ooooo`?o0000>?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03Gooooo000Poooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool0Koooool2o`0003cooooo00?o0000oooo
ooooool0>_ooool00ol0003oooooooooo`0dooooo`008?ooool2o`0002?ooooo00?o0000oooooooo
ool0Joooool3o`0003oooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0dooooo`00
8?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo06Oooooo0ol00013ooooo`03o`00
0?oooooooooo03Wooooo00?o0000ooooooooool0<oooool0023ooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`1Sooooo`?o0000Aoooool00ol0003oooooooooo`0iooooo`03o`000?oo
oooooooo03;ooooo000Pooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0Goooool3
o`0004[ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0booooo`008?ooool00ol0
003oooooooooo`0Vooooo`;o0000GOooool2o`0004kooooo00?o0000ooooooooool0>Oooool00ol0
003oooooooooo`0aooooo`007oooool3o`0002Wooooo00?o0000ooooooooool0Eoooool3o`00057o
oooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0`ooooo`007oooool00ol0003ooooo
ooooo`0Zooooo`03o`000?oooooooooo05?ooooo0ol0001Eooooo`03o`000?oooooooooo03Wooooo
00?o0000ooooooooool0;oooool001oooooo00?o0000ooooooooool0:oooool00ol0003ooooooooo
o`1?ooooo`?o0000F?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02oooooo000O
ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0Boooool3o`0005cooooo00?o0000
ooooooooool0>?ooool2o`00033ooooo000Oooooo`?o0000;Oooool00ol0003oooooooooo`17oooo
o`?o0000H?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02gooooo000Oooooo`03
o`000?oooooooooo02kooooo00?o0000ooooooooool0A?ooool2o`0006Cooooo00?o0000oooooooo
ool0>?ooool00ol0003oooooooooo`0]ooooo`005?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Ko
oooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`10ooooo`?o0000Ioooool00ol0003o
ooooooooo`0hooooo`03o`000?oooooooooo02cooooo000Dooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo03cooooo0ol0001Zooooo`03
o`000?oooooooooo03Wooooo00?o0000ooooooooool0:oooool001Cooooo00Go410@oooooooooooo
oooooa0@4005ooooo`;o0000<oooool00ol0003oooooooooo`0hooooo`?o0000K_ooool00ol0003o
ooooooooo`0iooooo`03o`000?oooooooooo02[ooooo000Dooooo`05o`000?ooooooooooooooool0
00001Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo03Cooooo0ol0001booooo`03
o`000?oooooooooo03Sooooo00?o0000ooooooooool0:_ooool001Cooooo00Go0000oooooooooooo
ooooo`000005ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0<?ooool3o`0007Ko
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Yooooo`005?ooool01Ol@413ooooo
oooooooooooo410@00Gooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0]ooooo`;o
0000N_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02Sooooo000Dooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo02Wo
oooo0ol0001looooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0:?ooool001Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o0000>?ooool00ol0003oooooooooo`0Uooooo`?o
0000P?ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02Oooooo000Nooooo`03o`00
0?oooooooooo03Sooooo00?o0000ooooooooool08Oooool3o`0008Cooooo00?o0000ooooooooool0
>?ooool00ol0003oooooooooo`0Vooooo`007Oooool00ol0003oooooooooo`0jooooo`03o`000?oo
oooooooo01gooooo0ol00028ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool09Ooo
ool001gooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Jooooo`;o0000S?ooool0
0ol0003oooooooooo`0gooooo`03o`000?oooooooooo02Gooooo000Mooooo`;o0000?Oooool00ol0
003oooooooooo`0Fooooo`?o0000S_ooool00ol0003oooooooooo`0gooooo`;o00009_ooool001go
oooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Booooo`?o0000T_ooool00ol0003o
ooooooooo`0hooooo`03o`000?oooooooooo02?ooooo000Mooooo`03o`000?oooooooooo03kooooo
00?o0000ooooooooool03_ooool3o`0009Kooooo00?o0000ooooooooool0=oooool00ol0003ooooo
ooooo`0Sooooo`007Oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00[ooooo0ol0
002Jooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool08_ooool001gooooo00?o0000
ooooooooool0@?ooool00ol0003oooooooooo`06ooooo`?o0000W_ooool00ol0003oooooooooo`0g
ooooo`03o`000?oooooooooo027ooooo000Looooo`?o0000@_ooool00ol0003oooooooooo`03oooo
o`;o0000XOooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo023ooooo000Looooo`03
o`000?oooooooooo04?ooooo00?o0000ooooool000000_l0002Tooooo`03o`000?oooooooooo03Oo
oooo00?o0000ooooooooool08?ooool001cooooo00?o0000ooooooooool0@_ooool3o`000:Sooooo
00?o0000ooooooooool0=oooool00ol0003oooooooooo`09ooooo`;o000000?o410@ooooooooool0
4Oooool001cooooo00?o0000ooooooooool0?oooool3o`0000?ooooo00?o0000ooooooooool0Y_oo
ool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04_oo
ool001cooooo0ol0000looooo`?o00001oooool00ol0003oooooooooo`2Vooooo`03o`000?oooooo
oooo03Kooooo00?o0000ooooooooool01_ooool5o`0001?ooooo000Looooo`03o`000?oooooooooo
03Wooooo0ol0000;ooooo`03o`000?oooooooooo0:Gooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`05ooooo`04odA4A?oMgMgoooooo`0001Cooooo00001_ooooook^k^oc8b<_l0003o
<S8bonk^kPGooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooo
ooooo`0gooooo`;o00003oooool00ol0003oooooooooo`2Uooooo`03o`000?oooooooooo03Oooooo
00?o0000ooooooooool01?ooool01?oMgMgoEEEEooooool0000Dooooo`0000KoooooogMgMonHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
03Cooooo0ol0000Booooo`03o`000?oooooooooo0:Gooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`05ooooo`03ogMgMoo<c<co000001Cooooo00000ooooooo410@ooooo`02ooooo`03
oa0@4?oooooooooo00kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0aooooo`?o
00005_ooool00ol0003oooooooooo`2Uooooo`03o`000?oooooooooo03Kooooo0_l00005ooooo`03
onk^k_m4A4Co000001Cooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00gooooo
00?oMgMgoc8b<_ooool00oooool2o`00033ooooo0ol0000Jooooo`03o`000?oooooooooo0:Gooooo
00?o0000ooooooooool0=?ooool00ol0003oooooo`000006ooooo`03ogMgMol0003ooooo01?ooooo
00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00[ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c004ooooo`03o`000?oooooooooo02cooooo0ol0000Nooooo`03o`000?oooooooooo0:Cooooo
00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Iooooo`0000?ooooooa0@4?ooool00_oo
ool00ol@413oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0:_oo
ool2o`0002;ooooo00?o0000ooooooooool0Y?ooool00ol0003oooooooooo`0fooooo`03o`000?oo
oooooooo01Wooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`cooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Wooooo`?o00009Oooool2o`000:Gooooo00?o0000ooooooooool0
=_ooool00ol0003oooooooooo`0Hooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h<ooooo`Co
00001Oooool2o`0002Gooooo0ol0000Zooooo`03o`000?oooooooooo0:?ooooo00?o0000oooooooo
ool0=_ooool00ol0003oooooooooo`0Gooooo`006oooool00ol0003oooooooooo`0Qooooo`?o0000
;_ooool00ol0003oooooooooo`2Sooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0
5oooool001_ooooo00?o0000ooooooooool07_ooool3o`0003;ooooo00?o0000ooooooooool0X_oo
ool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo01Kooooo000Kooooo`03o`000?oooooo
oooo01_ooooo0ol0000fooooo`03o`000?oooooooooo0:;ooooo00?o0000ooooooooool0=_ooool0
0ol0003oooooooooo`0Eooooo`006_ooool00ol0003oooooooooo`0Jooooo`;o0000>_ooool00ol0
003oooooooooo`2Rooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool05?ooool001[o
oooo0_l0000Hooooo`?o0000?Oooool00ol0003oooooooooo`2Rooooo`03o`000?oooooooooo03Go
oooo00?o0000ooooooooool05?ooool001[ooooo00?o0000ooooooooool05?ooool3o`00047ooooo
00?o0000ooooooooool0V?ooool2oonI00Oooooo00?o0000ooooooooool0=_ooool00ol0003ooooo
ooooo`0Cooooo`006_ooool00ol0003oooooooooo`0Aooooo`?o0000AOooool00ol0003ooooooooo
o`2Eooooo`;ooiT02_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo01;ooooo000J
ooooo`03o`000?oooooooooo00kooooo0ol00019ooooo`03o`000?oooooooooo09;ooooo0_ooV@0=
ooooo`03o`000?oooooooooo03Gooooo0_l0000Cooooo`006_ooool00ol0003oooooooooo`0<oooo
o`;o0000COooool00ol0003oooooooooo`2@ooooo`03oonI0?oooooooooo00kooooo00?o0000oooo
ooooool0=?ooool2o`0001?ooooo000Iooooo`?o00002_ooool3o`00053ooooo00?o0000oooooooo
ool0SOooool2oonI01;ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0@ooooo`00
6_ooool00ol0003oooooooooo`06ooooo`?o0000E?ooool00ol0003oooooooooo`2:ooooo`;ooiT0
5?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00oooooo000Iooooo`03o`000?oo
oooooooo00Cooooo0ol0001Hooooo`03o`000?oooooooooo08Oooooo0_ooV@0=ooooo`;oc?l02?oo
ool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00oooooo000Iooooo`04o`000?oooooo
ooooooooo`?o0000G?ooool00ol0003oooooooooo`24ooooo`;ooiT03Oooool2olco00_ooooo00?o
0000ooooooooool0=Oooool00ol0003oooooooooo`0>ooooo`006Oooool4o`00063ooooo00?o0000
ooooooooool0P_ooool00oooV@3oooooooooo`0;ooooo`;oc?l03_ooool00ol0003oooooooooo`0e
ooooo`03o`000?oooooooooo00gooooo000Iooooo`;o0000Hoooool00ol0003oooooooooo`1ooooo
o`;ooiT03Oooool00oo<o`3oooooooooo`0?ooooo`03o`000?oooooooooo03Cooooo00?o0000oooo
ooooool03Oooool000oooooo1?l000000ol@413oooooooooo`05ooooo`03o`000?oooooooooo067o
oooo00?o0000ooooooooool0O?ooool2oonI00gooooo0_o<o`0Booooo`03o`000?oooooooooo03Go
oooo00?o0000ooooooooool03?ooool0017ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`1Qooooo`03o`000?oooooooooo07Wooooo0_ooV@0=ooooo`;oc?l05Oooool00ol0003ooooo
ooooo`0eooooo`03o`000?oooooooooo00_ooooo000Aooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool0HOooool00ol0003oooooooooo`1eooooo`?ooiT03Oooool2olco00gooooo0_lc
o`09ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool02_ooool0017ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo07;ooooo0_ooV@0?
ooooo`03olco0?oooooooooo00_ooooo0_lco`0<ooooo`03o`000?oooooooooo03Cooooo00?o0000
ooooooooool02_ooool0017ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Qoooo
o`03o`000?oooooooooo06oooooo0_ooV@0?ooooo`;oc?l03?ooool2oc?o00oooooo00?o0000oooo
ooooool0=?ooool00ol0003oooooooooo`09ooooo`004Oooool00ol0003oooooooooo`0<ooooo`;o
0000H_ooool00ol0003oooooooooo`1/ooooo`;ooiT03oooool2olco00gooooo00?o<ol0oooooooo
ool03oooool00ol0003oooooooooo`0cooooo`?o00002_ooool0017ooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo06Sooooo0oooV@0@ooooo`03olco
0?oooooooooo00_ooooo0_lco`0Cooooo`03o`000?oooooooooo02oooooo0ol00002ooooo`03o`00
0?oooooooooo00Sooooo000?ooooo`03oeEEEOmVIVKo0000017ooooo00?o0000ooooooooool0H?oo
ool00ol0003oooooooooo`1Tooooo`?ooiT04Oooool2olco00cooooo0_lco`0Fooooo`03o`000?oo
oooooooo02_ooooo0ol00005ooooo`03o`000?oooooooooo00Sooooo000Tooooo`03o`000?oooooo
oooo063ooooo00?o0000ooooooooool0H?ooool3oonI01;ooooo0_o<o`0<ooooo`;o<ol03Oooool2
o`3oIP[ooooo00?o0000ooooooooool09_ooool4o`0000Sooooo00?o0000ooooooooool02?ooool0
02Gooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Mooooo`;ooiT04_ooool3olco
00cooooo0_lco`0=ooooo`;o0?mV3Oooool00ol0003oooooooooo`0Rooooo`?o00003?ooool00ol0
003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo05Wo
oooo0oooV@0Booooo`;oc?l03_ooool00olco`3oooooooooo`0<ooooo`03o`3oI_oooooooooo00go
oooo00?o0000ooooooooool07oooool3o`00013ooooo00?o0000ooooooooool01oooool002Oooooo
00?o0000ooooooooool0H?ooool00ol0003oooooooooo`1Eooooo`?ooiT04oooool2olco00kooooo
0_lco`0=ooooo`;o0?mV4Oooool00ol0003oooooooooo`0Jooooo`Co00004oooool00ol0003ooooo
ooooo`07ooooo`00:?ooool2o`00067ooooo00?o0000ooooooooool0DOooool3oonI01Cooooo0_o<
o`0>ooooo`;o<ol03Oooool2o`3oIQCooooo00?o0000ooooooooool05_ooool3o`0001Oooooo00?o
0000ooooooooool01oooool002[ooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`1=
ooooo`?ooiT05?ooool3olco00kooooo0_lco`0>ooooo`03o`3oI_oooooooooo01Gooooo00?o0000
ooooooooool04_ooool3o`0001[ooooo00?o0000ooooooooool01oooool002_ooooo00?o0000oooo
ooooool0Goooool00ol0003oooooooooo`18ooooo`CooiT05?ooool3olco00oooooo0_lco`0>oooo
o`;o0?mV3?ooool2o`3oo`_ooooo00?o0000ooooooooool03Oooool4o`0001gooooo00?o0000oooo
ooooool01oooool002cooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`13ooooo`Co
oiT05Oooool3olco00oooooo0olco`0>ooooo`;o0?mV3?ooool2o`3oo`gooooo00?o0000oooooooo
ool02_ooool3o`00027ooooo00?o0000ooooooooool01oooool002gooooo00?o0000ooooooooool0
Goooool00ol0003oooooooooo`0mooooo`GooiT05oooool2olco013ooooo0_lco`0?ooooo`;o0?mV
3Oooool00ol0ooooooooooooo`0>ooooo`03o`000?oooooooooo00Kooooo0ol0000Tooooo`03o`00
0?oooooooooo00Oooooo000^ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool0=_oo
ool6oonI01Wooooo0oo<o`0@ooooo`;o<ol03oooool2o`3oIPgooooo0_l0oolBooooo`04o`000?oo
ooooooooooooo`Co00009oooool00ol0003oooooooooo`07ooooo`00;oooool2o`00063ooooo00?o
0000ooooooooool0;oooool6oonI01cooooo0oo<o`0Aooooo`;o<ol03oooool2o`3oIPgooooo0_l0
oolEooooo`?o0000;?ooool00ol0003oooooooooo`06ooooo`00<Oooool00ol0003oooooooooo`1N
ooooo`;o0000:Oooool6oonI01oooooo0oo<o`0Aooooo`?o<ol03oooool2o`3oIPkooooo00?o0?oo
ooooooooool04_ooool3o`000003ooooool0003ooooo02cooooo00?o0000ooooooooool01_ooool0
03;ooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0Mooooo`WooiT08Oooool4olco
017ooooo0olco`0?ooooo`?o0?mV3_ooool2o`3oo`cooooo0_l0I_l4ooooo`?o00001?ooool00ol0
003oooooooooo`0[ooooo`03o`000?oooooooooo00Kooooo000cooooo`03o`000?oooooooooo05oo
oooo00?o0000ooooooooool05_ooool6oonI02Gooooo1Oo<o`0Booooo`?o<ol04?ooool2o`3oIPoo
oooo0_l0ool<ooooo`;o06Ko0_ooool4o`0000Sooooo00?o0000ooooooooool0:_ooool00ol0003o
ooooooooo`06ooooo`00=?ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo03cooooo
1?o<o`0Dooooo`?o<ol04Oooool2o`3oIPoooooo0_l0ool=ooooo`03o`1Voooooooo000000;o0000
3Oooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00Kooooo000eooooo`03o`000?oo
oooooooo05oooooo00?o0000ooooooooool0=_ooool5olco01Gooooo0olco`0Aooooo`?o0?mV4?oo
ool00ol0ooooooooooooo`0;ooooo`;o06Ko0_l0000Aooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool01_ooool003Kooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`0_
ooooo`Koc?l05oooool3oc?o01;ooooo0_l0ofHAooooo`;o0?oo2oooool01?l0003o06Koo`1Vool0
000Eooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool01_ooool003Oooooo0_l0001P
ooooo`03o`000?oooooooooo02Sooooo1_o<o`0Jooooo`?o<ol04_ooool3o`3oIQ7ooooo0_l0ool:
ooooo`?o000000?o06Koooooooooool05_ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo00Kooooo000iooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool08Oooool6olco
01cooooo1?lco`0Cooooo`;o0?mV4_ooool2o`3oo`Wooooo0ol000000ooooooo06Koo`1Vo`0<oooo
o`;o<`3o3?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Gooooo000jooooo`03
o`000?oooooooooo05kooooo00?o0000ooooooooool05oooool9olco01gooooo1Olco`0Eooooo`;o
0?mV4Oooool3o`3oo`Oooooo1?l00002ooooo`;o06Ko3?ooool2oc<0o`oooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`05ooooo`00>oooool00ol0003oooooooooo`1Nooooo`03o`00
0?oooooooooo013ooooo1_o<o`0Rooooo`Co<ol05oooool3o`3oIQ7ooooo0_l0ool7ooooo`?o0000
1?ooool2o`1Vo`gooooo00?o<`3oooooooooool04?ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo00Gooooo000looooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0<ooo
ool4oc?o01Sooooo0ol0ofHBooooo`;o0?oo1_ooool3o`0000Gooooo0_l0I_l=ooooo`;o<`3o4ooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Gooooo000mooooo`03o`000?oooooo
oooo05kooooo00?o0000ooooooooool0;Oooool5oc?o01Wooooo0ol0ofHBooooo`?o0?oo1?ooool4
o`0000Kooooo0_l0I_l=ooooo`;o<`3o5_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo
oooo00Gooooo000nooooo`;o0000Goooool00ol0003oooooooooo`0Xooooo`Co<ol06oooool3o`3o
IQ;ooooo0ol0ool4ooooo`?o00002?ooool2o`1Vo`kooooo00?o<`3oooooooooool05oooool00ol0
003oooooooooo`0Sooooo`03o`000?oooooooooo00Gooooo0010ooooo`03o`000?oooooooooo05go
oooo00?o0000ooooooooool07oooool8oc?o01cooooo0ol0ofHBooooo`?o0?oo1?ooool3o`0000Wo
oooo0_l0I_l>ooooo`;o<`3o3?ooool2ol`0o`gooooo00?o0000ooooooooool08_ooool00ol0003o
ooooooooo`05ooooo`00@Oooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo017ooooo
3Olco`0Pooooo`Co0?mV4_ooool3o`3oo`?ooooo1?l00009ooooo`?o06Ko3_ooool2oc<0o`cooooo
0_o<0?l@ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool01Oooool004;ooooo00?o
0000ooooooooool0GOooool00ol0003oooooooooo`0:ooooo`Ko<ol0:?ooool5o`3oIQ?ooooo0ol0
ool3ooooo`?o00002oooool2o`1Vo`oooooo0_lc0?l<ooooo`;oc03o4_ooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo00Gooooo0013ooooo`03o`000?oooooooooo05gooooo00?o0000
ooooooooool0<oooool4o`3oIQCooooo1?l0ool3ooooo`?o00003?ooool2o`1Vo`oooooo0_lc0?l=
ooooo`03ol`0oooooooooooo01?ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`04
ooooo`00A?ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo02gooooo1Ol0ofHEoooo
o`?o0?oo0oooool4o`0000cooooo0ol0I_l?ooooo`;o<`3o3Oooool2ol`0oaOooooo00?o0000oooo
ooooool08?ooool00ol0003oooooooooo`04ooooo`00AOooool00ol0003oooooooooo`1Mooooo`03
o`000?oooooooooo02Gooooo1ol0ofHGooooo`?o0?oo0oooool3o`0000kooooo0_l0I_l@ooooo`;o
<`3o3Oooool2ol`0oa[ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`04ooooo`00
A_ooool2o`0005kooooo00?o0000ooooooooool07_ooool6o`3oIQ_ooooo0ol0ool3ooooo`?o0000
3_ooool3o`1Voa3ooooo0_lc0?l=ooooo`;oc03o3Oooool2ool0V@kooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`04ooooo`00B?ooool00ol0003oooooooooo`1Looooo`03o`000?oo
oooooooo01Kooooo1ol0ofHMooooo`Co0?oo0_ooool4o`0000kooooo0ol0I_lAooooo`;o<`3o3Ooo
ool2ol`0o`gooooo0_oo09T@ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool01?oo
ool004Wooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`0;ooooo`[o0?mV8Oooool3
o`3oo`?ooooo0ol0000@ooooo`;o06Ko4_ooool2oc<0o`gooooo0_o<0?l=ooooo`;oo`2I4oooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Cooooo001:ooooo`03o`000?oooooooooo
05cooooo00?o0000ooooooooool01?ooool6o`3oIRSooooo0ol0ool3ooooo`?o00004?ooool3o`1V
oa7ooooo0olc0?l=ooooo`;oc03o3_ooool00ooo09Woooooooooo`0Dooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool01?ooool004_ooooo00?o0000ooooooooool0G?ooool00ol0003o
ooooooooo`0^ooooo`?o0?oo0_ooool4o`00013ooooo0ol0I_lBooooo`;o<`3o3_ooool2ol`0o`ko
oooo0_oo09THooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool01?ooool004cooooo
00?o0000ooooooooool0G?ooool00ol0003oooooooooo`0Xooooo`Go0?oo0_ooool3o`00017ooooo
0ol0I_lCooooo`;o<`3o3_ooool2ol`0o`kooooo0_oo09TKooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool00oooool004gooooo0_l0001Mooooo`03o`000?oooooooooo023ooooo1ol0
ool4ooooo`?o00004?ooool4o`1Voa?ooooo0olc0?l>ooooo`;oc03o3_ooool2ool0V@gooooo0_oo
000>ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool00oooool004oooooo00?o0000
ooooooooool0Foooool00ol0003oooooooooo`0Hooooo`Oo0?oo2?ooool3o`00013ooooo0ol0I_lD
ooooo`?o<`3o3oooool2ol`0o`kooooo0_oo09T>ooooo`03ool00?oooooooooo00oooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`03ooooo`00D?ooool00ol0003oooooooooo`1Koooo
o`03o`000?oooooooooo013ooooo1ol0ool;ooooo`Co00003oooool4o`1Voa?ooooo1?lc0?l@oooo
o`;oc03o3_ooool2ool0V@kooooo0_oo000Cooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool00oooool0057ooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`05ooooo`[o
0?oo3oooool3o`0000kooooo1Ol0I_lDooooo`?o<`3o4Oooool3ol`0o`kooooo0_oo09T>ooooo`;o
o`005_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00?ooooo001Booooo`03o`00
0?oooooooooo05_ooooo1ol0oolFooooo`?o00003?ooool5o`1VoaKooooo0olc0?lBooooo`;oc03o
4?ooool00ooo09Woooooooooo`0=ooooo`03ool00?oooooooooo01Oooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`03ooooo`00Doooool00ol0003oooooooooo`1Kooooo`03o`000?oo
oooooooo01Gooooo1?l0000;ooooo`Co06Ko6?ooool3oc<0oa?ooooo0_o<0?l@ooooo`;oo`2I3_oo
ool2ool001[ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`03ooooo`00E?ooool2
o`0005cooooo00?o0000ooooooooool04Oooool3o`0000[ooooo1Ol0I_lIooooo`?o<`3o5?ooool2
ol`0oa3ooooo0_oo09T?ooooo`03ool00?oooooooooo01_ooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`03ooooo`00E_ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo
00gooooo0ol00008ooooo`Go06Ko7?ooool2oc<0oaCooooo0oo<0?l@ooooo`;oo`2I3oooool2ool0
01oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`02ooooo`00Eoooool00ol0003o
ooooooooo`1Jooooo`03o`000?oooooooooo00Sooooo1?l00006ooooo`Go06Ko7_ooool3oc<0oa?o
oooo0oo<0?l@ooooo`?oo`2I3oooool2ool002;ooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`02ooooo`00F?ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00Cooooo
0ol00003ooooo`Oo06Ko8?ooool3oc<0oa?ooooo0oo<0?l@ooooo`?oo`2I4?ooool2ool002Gooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`02ooooo`00FOooool00ol0003ooooooooo
o`1Jooooo`03o`000?oooooo06Ko00Wo06Ko8_ooool5oc<0oa?ooooo0oo<0?lAooooo`;oo`2I4?oo
ool3ool002Oooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`02ooooo`00F_ooool0
0ol0003oooooooooo`1Dooooo`Oo06Ko00?o0000ooooooooool09?ooool5oc<0oaGooooo0oo<0?lA
ooooo`?oo`2I4?ooool2ool002_ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`02
ooooo`00Foooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo023ooooo1Olc0?lGoooo
o`?oc03o4_ooool2ool0VA7ooooo0_oo000^ooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool00_ooool005cooooo0_l0001Iooooo`03o`000?oooooooooo01_ooooo1Olc0?lHooooo`Co
c03o4_ooool3ool0VA7ooooo0_oo000aooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool00_ooool005kooooo00?o0000ooooooooool0E_ooool00ol0003oooooooooo`0Fooooo`Go<`3o
6_ooool3ol`0oa?ooooo0ooo09TAooooo`?oo`00=?ooool00ol0003oooooooooo`0@ooooo`03o`00
0?oooooooooo00;ooooo001Oooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool03Ooo
ool9oc<0oa_ooooo1?o<0?lCooooo`?oo`2I4_ooool2ool003Oooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`01ooooo`00H?ooool00ol0003oooooooooo`1Dooooo`03o`000?lc0?oo
<`3o00go<`3o8?ooool4ol`0oaCooooo0ooo09TCooooo`;oo`00>_ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo007ooooo001Qooooo`03o`000?oooooooooo04gooooo1olc0?l/oooo
o`?oc03o5_ooool2ool0VA?ooooo0ooo000mooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool00Oooool006;ooooo00?o0000ooooooooool0D_ooool00ol0003oooooooooo`0Vooooo`Co
c03o5_ooool3ool0VA?ooooo0_oo0011ooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool00Oooool006?ooooo0_l0001Booooo`03o`000?oooooooooo023ooooo1_o<0?lGooooo`?oo`2I
5?ooool2ool004Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`01ooooo`00IOoo
ool00ol0003oooooooooo`1?ooooo`03o`000?oooooooooo01Wooooo1oo<0?lJooooo`?oo`2I5?oo
ool3ool004Kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`01ooooo`00I_ooool0
0ol0003oooooooooo`1>ooooo`03o`000?oooooooooo017ooooo2?o<0?lNooooo`?oo`2I5?ooool3
ool004[ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`01ooooo`00Ioooool00ol0
003oooooooooo`1=ooooo`03o`000?oooooooooo00[ooooo1oo<0?lRooooo`Coo`2I5?ooool3ool0
04kooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`01ooooo`00J?ooool00ol0003o
ooooooooo`1<ooooo`03o`000?ooooooc03o00[oc03o9?ooool5ool0VAGooooo0ooo001Booooo`03
o`000?oooooooooo00_ooooo0Ol00001ooooo`7ooooo001Yooooo`03o`000?oooooooooo04Gooooo
2?o<0?lZooooo`Goo`2I5_ooool4ool005Gooooo00?o0000ooooooooool02oooool1o`00007ooooo
0Oooool006[ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0Sooooo`Koo`2I5ooo
ool4ool005[ooooo00?o0000ooooooooool02_ooool1o`00007ooooo0Oooool006_ooooo0_l0001:
ooooo`03o`000?oooooooooo01kooooo1Ooo09TJooooo`?oo`00Goooool00ol0003oooooooooo`09
ooooo`7o00000Oooool1ooooo`00KOooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo
01Wooooo1Ooo09TKooooo`Coo`00Hoooool00ol0003oooooooooo`08ooooo`7o00000Oooool1oooo
o`00K_ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo01;ooooo1ooo09TLooooo`Co
o`00J?ooool00ol0003oooooooooo`07ooooo`7o00000Oooool1ooooo`00Koooool00ol0003ooooo
ooooo`15ooooo`03o`000?oooooooooo00_ooooo1ooo09TOooooo`Coo`00K?ooool00ol0003ooooo
ooooo`07ooooo`7o00000Oooool1ooooo`00L?ooool00ol0003oooooooooo`14ooooo`03o`000?oo
oooooooo00_oo`2I8_ooool4ool0077ooooo00?o0000ooooooooool01_ooool1o`00007ooooo0Ooo
ool0077ooooo00?o0000ooooooooool0?_ooool8ool0VBWooooo1?oo001fooooo`03o`000?oooooo
oooo00Gooooo0Ol00001ooooo`7ooooo001booooo`;o0000@_ooool00ol0003oooooooooo`0Voooo
o`Coo`00Noooool00ol0003oooooooooo`05ooooo`7o00000Oooool007Cooooo00?o0000oooooooo
ool0?oooool00ol0003oooooooooo`0Qooooo`Goo`00P?ooool00ol0003oooooooooo`04ooooo`7o
00000Oooool007Gooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0Looooo`Goo`00
QOooool00ol0003oooooooooo`04ooooo`7o00000Oooool007Kooooo00?o0000ooooooooool0?Ooo
ool00ol0003oooooooooo`0Aooooo`_oo`00Roooool00ol0003oooooooooo`03ooooo`7o00000Ooo
ool007Oooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`05ooooo`coo`00Uoooool0
0ol0003oooooooooo`02ooooo`7o00000Oooool007Sooooo00?o0000ooooooooool0>oooool8ool0
0:Cooooo00Go0000ooooooooooooooooo`000001ooooo`00NOooool00ol0003oooooooooo`0foooo
o`Coo`0000?o0000ooooooooool0Z_ooool01?l0003oooooooooool00001ooooo`00N_ooool2o`00
03[ooooo00?o0000ooooooooool0Z_ooool01?l0003oooooooooool00001ooooo`00O?ooool00ol0
003oooooooooo`0gooooo`03o`000?oooooooooo0:_ooooo00?o0000ooooooooool00Ol0000007go
oooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`2/ooooo`7o00000Oooool1o`000000
O_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo0:gooooo0_l0000007oooooo00?o
0000ooooooooool0=?ooool00ol0003oooooooooo`2/ooooo`?o00000020ooooo`03o`000?oooooo
oooo03?ooooo00?o0000ooooooooool0Z?ooool4o`0000?ooooo0021ooooo`;o0000<oooool00ol0
003oooooooooo`2Uooooo`?o00001oooool008?ooooo00?o0000ooooooooool0<?ooool00ol0003o
ooooooooo`2Qooooo`Co00002_ooool008Cooooo00?o0000ooooooooool0;oooool00ol0003ooooo
ooooo`2Mooooo`Co00003_ooool008Gooooo00?o0000ooooooooool0;_ooool00ol0003ooooooooo
o`2Iooooo`Co00004_ooool008Kooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`2E
ooooo`Co00005_ooool008Oooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`2Boooo
o`?o00006_ooool008Sooooo0_l0000/ooooo`03o`000?oooooooooo08kooooo1?l0000Mooooo`00
R_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo08[ooooo1?l0000Qooooo`00Rooo
ool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo08Kooooo1?l0000Uooooo`00S?ooool0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo08;ooooo1?l0000Yooooo`00SOooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo07oooooo0ol0000]ooooo`00S_ooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo07_ooooo1?l0000`ooooo`00Soooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo07Oooooo1?l0000dooooo`00T?ooool2o`0002Cooooo00?o
0000ooooooooool0Loooool4o`0003Sooooo002Booooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool0L?ooool3o`0003cooooo002Cooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool0K?ooool4o`0003oooooo002Dooooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool0J?ooool4o`0004?ooooo002Eooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
I?ooool4o`0004Oooooo002Fooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0H?oo
ool4o`0004_ooooo002Gooooo`;o00007Oooool00ol0003oooooooooo`1Mooooo`?o0000Coooool0
09Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1Iooooo`Co0000D_ooool009[o
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1Eooooo`Co0000E_ooool009_ooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`1Aooooo`Co0000F_ooool009cooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`1=ooooo`Co0000G_ooool009gooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`1:ooooo`?o0000H_ooool009kooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`16ooooo`Co0000IOooool009oooooo0_l0000Dooooo`03
o`000?oooooooooo04?ooooo1?l0001Yooooo`00XOooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo03oooooo1?l0001]ooooo`00X_ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo03_ooooo1?l0001aooooo`00Xoooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo03Sooooo0ol0001eooooo`00Y?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
03Cooooo1?l0001hooooo`00YOooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo033o
oooo1?l0001looooo`00Y_ooool2o`0000gooooo00?o0000ooooooooool0;?ooool4o`00083ooooo
002Xooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0:Oooool3o`0008Cooooo002Y
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool09Oooool4o`0008Oooooo002Zoooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool08Oooool4o`0008_ooooo002[ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool07Oooool4o`0008oooooo002/ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool06Oooool4o`0009?ooooo002]ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool05_ooool3o`0009Oooooo002^ooooo`;o00001Oooool0
0ol0003oooooooooo`0Booooo`Co0000V_ooool00;3ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0>ooooo`Co0000W_ooool00;7ooooo00Go0000ooooooooooooooooo`00000<oooo
o`Co0000X_ooool00;;ooooo00Co0000oooooooooooo00002?ooool4o`000:Kooooo002cooooo`03
o`000?oooooo000000Gooooo0ol0002Zooooo`00]?ooool2o`000003ooooool0003o000000;o0000
[Oooool00;Gooooo0_l0002aooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
\
\>"],
  ImageRangeCache->{{{0, 359}, {319.688, 0}} -> {-0.0710364, -0.0181728, \
0.0035149, 0.0035149}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .89104 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-16 1.0656 -0.0363427 1.0656 [
[.02544 .21571 -12 -8.9133 ]
[.02544 .21571 0 .0867 ]
[.16074 .16277 -11.6592 -9 ]
[.16074 .16277 .34081 0 ]
[.3021 .10747 -5.60025 -9 ]
[.3021 .10747 .39975 0 ]
[.44992 .04965 -5.37091 -9 ]
[.44992 .04965 .62909 0 ]
[.60467 -0.01084 -5.14157 -9 ]
[.60467 -0.01084 .85843 0 ]
[.66454 .05085 0 -6.20675 ]
[.66454 .05085 6 2.79325 ]
[.80797 .25198 0 -6.0417 ]
[.80797 .25198 6 2.9583 ]
[.93071 .4241 0 -5.90576 ]
[.93071 .4241 6 3.09424 ]
[.02254 .22988 -12 -2.74631 ]
[.02254 .22988 0 6.25369 ]
[.0142 .29178 -24 -2.78907 ]
[.0142 .29178 0 6.21093 ]
[.00558 .35578 -6 -2.83339 ]
[.00558 .35578 0 6.16661 ]
[-0.00334 .42198 -18 -2.87938 ]
[-0.00334 .42198 0 6.12062 ]
[-0.01257 .49051 -6 -2.92712 ]
[-0.01257 .49051 0 6.07288 ]
[ 0 0 0 0 ]
[ 1 .89104 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03495 .22504 m
.61241 0 L
s
.03495 .22504 m
.03971 .2297 L
s
[(-2)] .02544 .21571 1 .98073 Mshowa
.16988 .17246 m
.17445 .1773 L
s
[(-1)] .16074 .16277 .9432 1 Mshowa
.31082 .11753 m
.31518 .12256 L
s
[(0)] .3021 .10747 .86675 1 Mshowa
.45818 .0601 m
.46231 .06533 L
s
[(1)] .44992 .04965 .7903 1 Mshowa
.61241 0 m
.61628 .00542 L
s
[(2)] .60467 -0.01084 .71386 1 Mshowa
.125 Mabswid
.06148 .2147 m
.06431 .21752 L
s
.08823 .20428 m
.09104 .20712 L
s
.11521 .19376 m
.118 .19663 L
s
.14243 .18316 m
.14519 .18604 L
s
.19758 .16166 m
.20029 .16459 L
s
.22551 .15078 m
.22821 .15373 L
s
.2537 .13979 m
.25637 .14277 L
s
.28213 .12871 m
.28478 .13171 L
s
.33977 .10625 m
.34236 .10929 L
s
.36897 .09487 m
.37153 .09794 L
s
.39844 .08339 m
.40097 .08648 L
s
.42817 .0718 m
.43068 .07491 L
s
.48846 .0483 m
.49091 .05146 L
s
.51902 .03639 m
.52144 .03958 L
s
.54986 .02437 m
.55225 .02758 L
s
.58099 .01224 m
.58335 .01547 L
s
.25 Mabswid
.61241 0 m
.97291 .505 L
s
.65208 .05558 m
.64586 .05794 L
s
[(0)] .66454 .05085 -1 .37928 Mshowa
.79537 .2563 m
.78907 .25846 L
s
[(2)] .80797 .25198 -1 .3426 Mshowa
.91799 .42808 m
.91164 .43006 L
s
[(4)] .93071 .4241 -1 .31239 Mshowa
.125 Mabswid
.69012 .10886 m
.68637 .11025 L
s
.72662 .16 m
.72286 .16135 L
s
.76168 .2091 m
.75791 .21042 L
s
.82778 .3017 m
.82399 .30297 L
s
.85897 .3454 m
.85518 .34664 L
s
.88903 .3875 m
.88522 .38871 L
s
.94594 .46722 m
.94211 .46839 L
s
.25 Mabswid
.03495 .22504 m
0 .48612 L
s
.03495 .22504 m
.04116 .22262 L
s
[(-1)] .02254 .22988 1 -0.38971 Mshowa
.02665 .28704 m
.03288 .28468 L
s
[(-0.5)] .0142 .29178 1 -0.38021 Mshowa
.01807 .35115 m
.02431 .34884 L
s
[(0)] .00558 .35578 1 -0.37036 Mshowa
.00919 .41747 m
.01546 .41521 L
s
[(0.5)] -0.00334 .42198 1 -0.36014 Mshowa
0 .48612 m
.00629 .48392 L
s
[(1)] -0.01257 .49051 1 -0.34953 Mshowa
.125 Mabswid
.03331 .23728 m
.03704 .23583 L
s
.03166 .2496 m
.03539 .24816 L
s
.03 .262 m
.03373 .26056 L
s
.02833 .27448 m
.03207 .27305 L
s
.02496 .29969 m
.0287 .29828 L
s
.02325 .31243 m
.02699 .31102 L
s
.02154 .32525 m
.02528 .32385 L
s
.01981 .33816 m
.02355 .33676 L
s
.01632 .36423 m
.02007 .36285 L
s
.01455 .37741 m
.01831 .37603 L
s
.01278 .39067 m
.01653 .3893 L
s
.01099 .40402 m
.01475 .40266 L
s
.00738 .43101 m
.01114 .42966 L
s
.00555 .44464 m
.00932 .4433 L
s
.00371 .45837 m
.00748 .45704 L
s
.00186 .4722 m
.00563 .47087 L
s
.25 Mabswid
.03495 .22504 m
0 .48612 L
s
0 .48612 m
.46953 .89104 L
s
.46953 .89104 m
.47294 .65459 L
s
.47294 .65459 m
.03495 .22504 L
s
.61241 0 m
.97291 .505 L
s
.97291 .505 m
1 .75117 L
s
1 .75117 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.03495 .22504 m
0 .48612 L
s
0 .48612 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.61241 0 m
.03495 .22504 L
s
.47294 .65459 m
.97291 .505 L
s
.97291 .505 m
1 .75117 L
s
1 .75117 m
.46953 .89104 L
s
.46953 .89104 m
.47294 .65459 L
s
0 0 m
1 0 L
1 .89104 L
0 .89104 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.46298 .74967 m
.51152 .74628 L
s
1 0 .6 r
.46168 .72976 m
.50891 .72643 L
s
1 0 0 r
.51152 .74628 m
.56128 .74028 L
s
.8 0 1 r
.46037 .70981 m
.5063 .70653 L
s
1 0 .6 r
.50891 .72643 m
.55739 .72052 L
s
.2 0 1 r
.45906 .68981 m
.50368 .6866 L
s
.8 0 1 r
.5063 .70653 m
.55349 .70072 L
s
0 .4 1 r
.45775 .66977 m
.50105 .66662 L
s
.2 0 1 r
.50368 .6866 m
.54959 .68088 L
s
1 0 0 r
.56128 .74028 m
.61089 .73173 L
s
0 1 1 r
.45643 .64969 m
.49842 .6466 L
s
0 .4 1 r
.50105 .66662 m
.54567 .66101 L
s
1 0 .6 r
.55739 .72052 m
.60576 .71209 L
s
0 1 .4 r
.45512 .62957 m
.49578 .62655 L
s
.8 0 1 r
.55349 .70072 m
.60063 .69242 L
s
0 1 1 r
.49842 .6466 m
.54175 .64109 L
s
.2 1 0 r
.4538 .6094 m
.49314 .60645 L
s
.2 0 1 r
.54959 .68088 m
.59548 .67271 L
s
0 1 .4 r
.49578 .62655 m
.53782 .62115 L
s
.8 1 0 r
.45247 .58919 m
.49049 .58631 L
s
0 .4 1 r
.54567 .66101 m
.59032 .65297 L
s
.2 1 0 r
.49314 .60645 m
.53389 .60116 L
s
1 0 0 r
.61089 .73173 m
.65963 .72074 L
s
1 .6 0 r
.45115 .56894 m
.48784 .56613 L
s
0 1 1 r
.54175 .64109 m
.58516 .63321 L
s
.8 1 0 r
.49049 .58631 m
.52995 .58114 L
s
1 0 .6 r
.60576 .71209 m
.65329 .70125 L
s
0 1 .4 r
.53782 .62115 m
.57999 .6134 L
s
1 .6 0 r
.48784 .56613 m
.526 .56108 L
s
.8 0 1 r
.60063 .69242 m
.64696 .68174 L
s
.2 1 0 r
.53389 .60116 m
.57481 .59357 L
s
.2 0 1 r
.59548 .67271 m
.64061 .6622 L
s
.8 1 0 r
.52995 .58114 m
.56962 .5737 L
s
0 .4 1 r
.59032 .65297 m
.63425 .64263 L
s
1 .6 0 r
.526 .56108 m
.56442 .55381 L
s
0 1 1 r
.58516 .63321 m
.62789 .62304 L
s
0 1 .4 r
.57999 .6134 m
.62151 .60342 L
s
.2 1 0 r
.57481 .59357 m
.61513 .58377 L
s
1 0 0 r
.65963 .72074 m
.70711 .70738 L
s
1 0 .6 r
.65329 .70125 m
.6996 .68808 L
s
.8 1 0 r
.56962 .5737 m
.60874 .5641 L
s
.8 0 1 r
.64696 .68174 m
.69208 .66876 L
s
1 .6 0 r
.56442 .55381 m
.60234 .5444 L
s
.2 0 1 r
.64061 .6622 m
.68455 .64942 L
s
0 .4 1 r
.63425 .64263 m
.67702 .63006 L
s
0 1 1 r
.62789 .62304 m
.66948 .61069 L
s
0 1 .4 r
.62151 .60342 m
.66193 .59129 L
s
.2 1 0 r
.61513 .58377 m
.65437 .57187 L
s
.8 1 0 r
.60874 .5641 m
.6468 .55243 L
s
1 .6 0 r
.60234 .5444 m
.63923 .53298 L
s
1 0 0 r
.70711 .70738 m
.75307 .69168 L
s
1 0 .6 r
.6996 .68808 m
.74437 .67261 L
s
.8 0 1 r
.69208 .66876 m
.73568 .65353 L
s
.2 0 1 r
.68455 .64942 m
.72697 .63443 L
s
0 .4 1 r
.67702 .63006 m
.71826 .61533 L
s
0 1 1 r
.66948 .61069 m
.70955 .59621 L
s
0 1 .4 r
.66193 .59129 m
.70083 .57708 L
s
.2 1 0 r
.65437 .57187 m
.69211 .55794 L
s
.8 1 0 r
.6468 .55243 m
.68337 .53879 L
s
1 .6 0 r
.63923 .53298 m
.67464 .51963 L
s
1 0 0 r
.75307 .69168 m
.79705 .67367 L
s
1 0 .6 r
.74437 .67261 m
.78717 .65489 L
s
.8 0 1 r
.73568 .65353 m
.77728 .6361 L
s
.2 0 1 r
.72697 .63443 m
.76739 .61731 L
s
0 .4 1 r
.71826 .61533 m
.7575 .59852 L
s
0 1 1 r
.70955 .59621 m
.74761 .57972 L
s
0 1 .4 r
.70083 .57708 m
.73772 .56092 L
s
.2 1 0 r
.69211 .55794 m
.72783 .54212 L
s
.8 1 0 r
.68337 .53879 m
.71793 .52331 L
s
1 .6 0 r
.67464 .51963 m
.70803 .5045 L
s
1 0 0 r
.79705 .67367 m
.83829 .65357 L
s
1 0 .6 r
.78717 .65489 m
.82721 .63514 L
s
.8 0 1 r
.77728 .6361 m
.81613 .61671 L
s
.2 0 1 r
.76739 .61731 m
.80505 .59829 L
s
0 .4 1 r
.7575 .59852 m
.79398 .57987 L
s
0 1 1 r
.74761 .57972 m
.78292 .56147 L
s
0 1 .4 r
.73772 .56092 m
.77185 .54307 L
s
.2 1 0 r
.72783 .54212 m
.7608 .52467 L
s
.8 1 0 r
.71793 .52331 m
.74974 .50629 L
s
1 .6 0 r
.70803 .5045 m
.73869 .48791 L
s
.73869 .48791 m
.76571 .47044 L
s
.8 1 0 r
.74974 .50629 m
.77787 .48831 L
s
.2 1 0 r
.7608 .52467 m
.79005 .50621 L
s
0 1 .4 r
.77185 .54307 m
.80223 .52412 L
s
0 1 1 r
.78292 .56147 m
.81442 .54205 L
s
0 .4 1 r
.79398 .57987 m
.82663 .56 L
s
.2 0 1 r
.80505 .59829 m
.83885 .57796 L
s
.8 0 1 r
.81613 .61671 m
.85108 .59594 L
s
1 0 .6 r
.82721 .63514 m
.86333 .61394 L
s
1 0 0 r
.83829 .65357 m
.87558 .63196 L
s
0 g
.25 Mabswid
.61241 0 m
.97291 .505 L
s
.97291 .505 m
1 .75117 L
s
1 .75117 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.03495 .22504 m
0 .48612 L
s
0 .48612 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.61241 0 m
.03495 .22504 L
s
.03495 .22504 m
.61241 0 L
s
.03495 .22504 m
.03971 .2297 L
s
[(-2)] .02544 .21571 1 .98073 Mshowa
.16988 .17246 m
.17445 .1773 L
s
[(-1)] .16074 .16277 .9432 1 Mshowa
.31082 .11753 m
.31518 .12256 L
s
[(0)] .3021 .10747 .86675 1 Mshowa
.45818 .0601 m
.46231 .06533 L
s
[(1)] .44992 .04965 .7903 1 Mshowa
.61241 0 m
.61628 .00542 L
s
[(2)] .60467 -0.01084 .71386 1 Mshowa
.125 Mabswid
.06148 .2147 m
.06431 .21752 L
s
.08823 .20428 m
.09104 .20712 L
s
.11521 .19376 m
.118 .19663 L
s
.14243 .18316 m
.14519 .18604 L
s
.19758 .16166 m
.20029 .16459 L
s
.22551 .15078 m
.22821 .15373 L
s
.2537 .13979 m
.25637 .14277 L
s
.28213 .12871 m
.28478 .13171 L
s
.33977 .10625 m
.34236 .10929 L
s
.36897 .09487 m
.37153 .09794 L
s
.39844 .08339 m
.40097 .08648 L
s
.42817 .0718 m
.43068 .07491 L
s
.48846 .0483 m
.49091 .05146 L
s
.51902 .03639 m
.52144 .03958 L
s
.54986 .02437 m
.55225 .02758 L
s
.58099 .01224 m
.58335 .01547 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 256.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001@2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00gOooool5o`0008Kooooo003Mooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0Q_ooool00=ko
oooo00?oV9RHob4Q8Oo^k^h0Qoooool00=oooooo00?oV9RHob4Q8Oo^k^h0Q_ooool00>3ooooo00?o
MgMgofIVI_ooool0QOooool00>7ooooo00?o0000ooooooooool0Q?ooool00=gooooo00Go0000okZj
^_ooooooV9RHoa0@4026ooooo`00gOooool01OnHV9So410@o`000?lQ8B7oc<c<08Kooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003Tooooo`;o0000P_ooool0
0>7ooooo0ol000000ooooooo0000ooooo`21ooooo`00goooool2o`0000Cooooo0_l00021ooooo`00
g?ooool3o`0000Kooooo00?o0000ooooool00000P?ooool00=[ooooo0_l00009ooooo`03o`000?oo
oooo0000083ooooo003Gooooo`?o000000?oooooo`000?ooool02?ooool01?l0003oooooooooool0
001oooooo`00e?ooool3o`0000Cooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooo
oooo000007kooooo003Booooo`;o00004Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo07_ooooo002Zooooo`Co000000?o410@ooooooooool07_ooool3o`0001?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1kooooo`00[?ooool00ol0003oooooooooo`0Nooooo`;o
000000?oooooo`000?ooool04oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07[o
oooo002/ooooo`03o`000?oooooooooo01_ooooo0ol00004ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`1iooooo`00[?ooool00ol0003ooooooooo
o`0Iooooo`;o00006oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo07Wooooo002/
ooooo`03o`000?oooooooooo01Kooooo0ol0000Mooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool02?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^06_ooooo002/ooooo`03o`000?oooooo
oooo01Cooooo0_l000000ooooooo0000ooooo`0Mooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01oooool01OmgMgOoV9RHoooooonHV9SoMgMg06_ooooo002/ooooo`03o`000?oooooo
oooo017ooooo0ol00004ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`06ooooo`05oa0@4?ooooooooooooooool@4100Joooool00:[ooooo00?oEEEE
ofIVI_l000004Oooool2o`0002Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06
ooooo`05o`000?ooooooooooooooool00000Joooool00;_ooooo0ol0000Wooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000006_ooooo002i
ooooo`;o000000?oooooo`000?ooool09oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Cooooo00Go410@oooooooooooooooooa0@401[ooooo`00]_ooool3o`0000Cooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`1[ooooo`00/oooool3o`0002oooooo00?o0000ooooooooool02Oooool2
o`0000Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1[ooooo`00/Oooool2o`0003;ooooo00?o0000
ooooooooool02?ooool01?l0003oooooooooool0001dooooo`00[_ooool3o`000003ooooool0003o
oooo037ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1aooooo`00[?ooool2o`00
00Gooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
077ooooo002Yooooo`?o0000>_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo073o
oooo002Wooooo`;o0000?Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo06oooooo
002Tooooo`?o000000?oooooo`000?ooool0??ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo06oooooo002Rooooo`;o0000@_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo06kooooo001gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08oooool3o`0004Cooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1]ooooo`00Moooool01OmgMgOoV9RHoooooonHV9So
MgMg027ooooo0_l00017ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0K?ooool0
07Oooooo00Go410@oooooooooooooooooa0@400Nooooo`?o00000_ooool00ol0003oooooooooo`14
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0K?ooool007Oooooo00Go0000oooo
ooooooooooooo`00000Looooo`;o0000C?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo06_ooooo001gooooo`05o`000?ooooooooooooooool000006Oooool3o`0004kooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`1Zooooo`00Moooool01Ol@413ooooooooooooooooo
410@01Kooooo0ol0001Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0J_ooool0
07Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Dooooo`;o00000oooool00ol0003oooooooooo`1>
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0JOooool007Oooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Aooooo`?o0000E_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo06Sooooo002;ooooo`;o0000FOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
06Sooooo0028ooooo`?o0000Foooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo06Oo
oooo0026ooooo`;o00000oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo01Gooooo
0_l0001Xooooo`00Poooool3o`00063ooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`1Uooooo`00POooool2o`0006?ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1U
ooooo`00O_ooool4o`0006Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`1Toooo
o`00O?ooool2o`0000Cooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo06?ooooo001iooooo`?o0000J_ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo06?ooooo001gooooo`;o0000KOooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo06;ooooo001dooooo`?o000000?oooooo`000?ooool0K?ooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo067ooooo001aooooo`?o0000L_ooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo063ooooo0019ooooo`Co000000?o410@ooooooooool07oooool2o`0007Go
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1Pooooo`00Boooool00ol0003ooooo
ooooo`0Nooooo`?o0000Moooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo05oooooo
0010ooooo`Ko00001Oooool00ol0003oooooooooo`0Looooo`;o00000_ooool00ol0003ooooooooo
o`1eooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0G_ooool004_ooooo00?o0000
ooooooooool06Oooool3o`0007cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1N
ooooo`00Boooool00ol0003oooooooooo`0Gooooo`;o0000Ooooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo05gooooo001;ooooo`03o`000?oooooooooo01Cooooo0ol00021ooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0G?ooool004_ooooo00?o0000ooooooooool0
4_ooool2o`0000?ooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo05_ooooo0019ooooo`03oeEEEOmVIVKo0000017ooooo0ol00026ooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool0Foooool005_ooooo0_l00029ooooo`03o`000?oooooo
oooo027ooooo0_l0001Looooo`00F?ooool3o`000003ooooool0003ooooo08Sooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`1Iooooo`00E_ooool2o`0008kooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`1Iooooo`00Doooool3o`00093ooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`1Hooooo`00D?ooool3o`0009?ooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1Gooooo`00C_ooool2o`0000;ooooo00?o0000ooooooooool0TOooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo05Kooooo001;ooooo`?o00001Oooool00ol0
003oooooooooo`2@ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0E_ooool004Wo
oooo0_l0002Kooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0EOooool004Kooooo
1?l0002Looooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0E?ooool004Cooooo0_l0
002Pooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0E?ooool001[ooooo1Ol0000R
ooooo`?o0000X_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo05?ooooo000Joooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@08?ooool2o`000:Gooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`1Booooo`004_ooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h07_ooool3o`00
0003ooooool0003ooooo0:Cooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`1Aoooo
o`007?ooool00onHV9So8B4Qonk^kP0Kooooo`;o0000Z_ooool00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo057ooooo000Mooooo`03ogMgMomVIVKooooo01Oooooo0ol0002]ooooo`03o`00
0?oooooooooo02_ooooo00?o0000ooooooooool0D?ooool001kooooo00?o0000ooooooooool05?oo
ool2o`000;3ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`1?ooooo`006_ooool0
1Ol0003o^[ZjoooooonHV9So410@01?ooooo0ol00002ooooo`03o`000?oooooooooo0:gooooo00?o
0000ooooooooool0;?ooool2o`00053ooooo000Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`04?oo
ool3o`000;Gooooo00?o0000ooooooooool0;?ooool2o`00053ooooo000]ooooo`;o0000^?ooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo04gooooo000Zooooo`?o000000?oooooo`00
0?ooool0]oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo04gooooo000Xooooo`;o
0000_Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo04cooooo000Uooooo`?o0000
_oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo04_ooooo000Tooooo`;o0000`Ooo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo04[ooooo000Jooooo`Co000000?o410@
ooooooooool00oooool00ol0003oooooo`000030ooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool0B_ooool001cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0002o
ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0BOooool0017ooooo1_l00005oooo
o`03o`000?oooooooooo00Gooooo0_l00002ooooo`03o`000?oooooooooo0;cooooo00?o0000oooo
ooooool0<oooool00ol0003oooooooooo`18ooooo`007?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0^oooool00ol0003oooooooooo`0cooooo`03
o`000?oooooooooo00Oooooo1Ol0000looooo`007?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo00Kooooo00GoV9RHob4Q8Oo^k^koooooodA4A00looooo`007?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00ol0003ooooo
ooooo`0eooooo`03o`000?oooooooooo00Kooooo00?oV9RHob4Q8Oo^k^h0?Oooool001cooooo00?o
0000ooooooooool01?ooool3o`0000Kooooo00?o0000ooooooooool0^?ooool00ol0003ooooooooo
o`0fooooo`03o`000?oooooooooo00Kooooo00?oV9RHob4Q8Oo^k^h0??ooool001[ooooo00?oEEEE
ofIVI_l000001_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;Oooooo00?o0000
ooooooooool0=_ooool00ol0003oooooooooo`07ooooo`03ogMgMomVIVKooooo03_ooooo000Soooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0]_ooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0>_ooool002?ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`2eooooo`03o`000?oooooooooo03Oooooo0_l00004ooooo`05
o`000?nj^[[ooooooiRHV?l@4100??ooool002?ooooo0_l0000;ooooo`03o`000?oooooooooo0;Co
oooo00?o0000ooooooooool0=_ooool00ol0003oooooo`000004ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`0??ooool002?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`2cooooo`03
o`000?oooooooooo03Wooooo00?o0000ooooooooool0@_ooool002;ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0
@Oooool002;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`2`ooooo`;o0000?Ooo
ool00ol0003oooooooooo`10ooooo`008_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo0:cooooo0ol000000ooooooo0000ooooo`0looooo`03o`000?oooooooooo043ooooo000Roooo
o`;o00004Oooool00ol0003oooooooooo`2Xooooo`?o00001Oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo03oooooo000Rooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool0Y?ooool3o`0000Wooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0nooooo`00
8_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo0:3ooooo0ol0000=ooooo`03o`00
0?oooooooooo03[ooooo00?o0000ooooooooool0?_ooool002;ooooo0ol0000Cooooo`03o`000?oo
oooooooo09cooooo0ol0000Aooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0?Ooo
ool002;ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`2Iooooo`;o00005?ooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo03cooooo000Qooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool0UOooool3o`0001Oooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`0kooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo097ooooo0ol0000Kooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0>oooool0
00Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0SOooool3o`0001oooooo00?o0000
ooooooooool0>_ooool00ol0003oooooooooo`0jooooo`001Ol00002ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`02ooooo`;o00006_ooool00ol0003oooooooooo`29
ooooo`?o00008oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03Wooooo0007oooo
o`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool0Q_ooool2o`0002Kooooo00?o0000ooooooooool0>_ooool2
o`0003[ooooo0007ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`22ooooo`?o0000:Ooo
ool00ol0003oooooooooo`0iooooo`;o0000>_ooool000Oooooo00Go410@oooooooooooooooooa0@
400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`1nooooo`?o0000;Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03Oooooo0007
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`;o00007_oo
ool00ol0003oooooooooo`1jooooo`?o0000<Oooool00ol0003oooooooooo`0iooooo`03o`000?oo
oooooooo03Oooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Cooooo0_l0
000Pooooo`03o`000?oooooooooo07Kooooo0ol0000eooooo`03o`000?oooooooooo03Wooooo00?o
0000ooooooooool0=_ooool0023ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1b
ooooo`?o0000>?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03Gooooo000Poooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool0Koooool2o`0003cooooo00?o0000oooo
ooooool0>_ooool00ol0003oooooooooo`0dooooo`008?ooool2o`0002?ooooo00?o0000oooooooo
ool0Joooool3o`0003oooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0dooooo`00
8?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo06Oooooo0ol00013ooooo`03o`00
0?oooooooooo03Wooooo00?o0000ooooooooool0<oooool0023ooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`1Sooooo`?o0000Aoooool00ol0003oooooooooo`0iooooo`03o`000?oo
oooooooo03;ooooo000Pooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0Goooool3
o`0004[ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0booooo`008?ooool00ol0
003oooooooooo`0Vooooo`;o0000GOooool2o`0004kooooo00?o0000ooooooooool0>Oooool00ol0
003oooooooooo`0aooooo`007oooool3o`0002Wooooo00?o0000ooooooooool0Eoooool3o`00057o
oooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0`ooooo`007oooool00ol0003ooooo
ooooo`0Zooooo`03o`000?oooooooooo05?ooooo0ol0001Eooooo`03o`000?oooooooooo03Wooooo
00?o0000ooooooooool0;oooool001oooooo00?o0000ooooooooool0:oooool00ol0003ooooooooo
o`1?ooooo`?o0000F?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02oooooo000O
ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0Boooool3o`0005cooooo00?o0000
ooooooooool0>?ooool2o`00033ooooo000Oooooo`?o0000;Oooool00ol0003oooooooooo`17oooo
o`?o0000H?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02gooooo000Oooooo`03
o`000?oooooooooo02kooooo00?o0000ooooooooool0A?ooool2o`0006Cooooo00?o0000oooooooo
ool0>?ooool00ol0003oooooooooo`0]ooooo`005?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Ko
oooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`10ooooo`?o0000Ioooool00ol0003o
ooooooooo`0hooooo`03o`000?oooooooooo02cooooo000Dooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo03cooooo0ol0001Zooooo`03
o`000?oooooooooo03Wooooo00?o0000ooooooooool0:oooool001Cooooo00Go410@oooooooooooo
oooooa0@4005ooooo`;o0000<oooool00ol0003oooooooooo`0hooooo`?o0000K_ooool00ol0003o
ooooooooo`0iooooo`03o`000?oooooooooo02[ooooo000Dooooo`05o`000?ooooooooooooooool0
00001Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo03Cooooo0ol0001booooo`03
o`000?oooooooooo03Sooooo00?o0000ooooooooool0:_ooool001Cooooo00Go0000oooooooooooo
ooooo`000005ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0<?ooool3o`0007Ko
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Yooooo`005?ooool01Ol@413ooooo
oooooooooooo410@00Gooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0]ooooo`;o
0000N_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02Sooooo000Dooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo02Wo
oooo0ol0001looooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0:?ooool001Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o0000>?ooool00ol0003oooooooooo`0Uooooo`?o
0000P?ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02Oooooo000Nooooo`03o`00
0?oooooooooo03Sooooo00?o0000ooooooooool08Oooool3o`0008Cooooo00?o0000ooooooooool0
>?ooool00ol0003oooooooooo`0Vooooo`007Oooool00ol0003oooooooooo`0jooooo`03o`000?oo
oooooooo01gooooo0ol00028ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool09Ooo
ool001gooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Jooooo`;o0000S?ooool0
0ol0003oooooooooo`0gooooo`03o`000?oooooooooo02Gooooo000Mooooo`;o0000?Oooool00ol0
003oooooooooo`0Fooooo`?o0000S_ooool00ol0003oooooooooo`0gooooo`;o00009_ooool001go
oooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Booooo`?o0000T_ooool00ol0003o
ooooooooo`0hooooo`03o`000?oooooooooo02?ooooo000Mooooo`03o`000?oooooooooo03kooooo
00?o0000ooooooooool03_ooool3o`0009Kooooo00?o0000ooooooooool0=oooool00ol0003ooooo
ooooo`0Sooooo`007Oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00[ooooo0ol0
002Jooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool08_ooool001gooooo00?o0000
ooooooooool0@?ooool00ol0003oooooooooo`06ooooo`?o0000W_ooool00ol0003oooooooooo`0g
ooooo`03o`000?oooooooooo027ooooo000Looooo`?o0000@_ooool00ol0003oooooooooo`03oooo
o`;o0000XOooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo023ooooo000Looooo`03
o`000?oooooooooo04?ooooo00?o0000ooooool000000_l0002Tooooo`03o`000?oooooooooo03Oo
oooo00?o0000ooooooooool08?ooool001cooooo00?o0000ooooooooool0@_ooool3o`000:Sooooo
00?o0000ooooooooool0=oooool00ol0003oooooooooo`09ooooo`;o000000?o410@ooooooooool0
4Oooool001cooooo00?o0000ooooooooool0?oooool3o`0000?ooooo00?o0000ooooooooool0Y_oo
ool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04_oo
ool001cooooo0ol0000looooo`?o00001oooool00ol0003oooooooooo`2Vooooo`03o`000?oooooo
oooo03Kooooo00?o0000ooooooooool01_ooool5o`0001?ooooo000Looooo`03o`000?oooooooooo
03Wooooo0ol0000;ooooo`03o`000?oooooooooo0:Gooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`05ooooo`04odA4A?oMgMgoooooo`0001Cooooo00001_ooooook^k^oc8b<_l0003o
<S8bonk^kPGooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooo
ooooo`0gooooo`;o00003oooool00ol0003oooooooooo`2Uooooo`03o`000?oooooooooo03Oooooo
00?o0000ooooooooool01?ooool01?oMgMgoEEEEooooool0000Dooooo`0000KoooooogMgMonHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
03Cooooo0ol0000Booooo`03o`000?oooooooooo0:Gooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`05ooooo`03ogMgMoo<c<co000001Cooooo00000ooooooo410@ooooo`02ooooo`03
oa0@4?oooooooooo00kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0aooooo`?o
00005_ooool00ol0003oooooooooo`2Uooooo`03o`000?oooooooooo03Kooooo0_l00005ooooo`03
onk^k_m4A4Co000001Cooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00gooooo
00?oMgMgoc8b<_ooool00oooool2o`00033ooooo0ol0000Jooooo`03o`000?oooooooooo0:Gooooo
00?o0000ooooooooool0=?ooool00ol0003oooooo`000006ooooo`03ogMgMol0003ooooo01?ooooo
00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00[ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c004ooooo`03o`000?oooooooooo02cooooo0ol0000Nooooo`03o`000?oooooooooo0:Cooooo
00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Iooooo`0000?ooooooa0@4?ooool00_oo
ool00ol@413oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0:_oo
ool2o`0002;ooooo00?o0000ooooooooool0Y?ooool00ol0003oooooooooo`0fooooo`03o`000?oo
oooooooo01Wooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`cooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Wooooo`?o00009Oooool2o`000:Gooooo00?o0000ooooooooool0
=_ooool00ol0003oooooooooo`0Hooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h<ooooo`Co
00001Oooool2o`0002Gooooo0ol0000Zooooo`03o`000?oooooooooo0:?ooooo00?o0000oooooooo
ool0=_ooool00ol0003oooooooooo`0Gooooo`006oooool00ol0003oooooooooo`0Qooooo`?o0000
;_ooool00ol0003oooooooooo`2Sooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0
5oooool001_ooooo00?o0000ooooooooool07_ooool3o`0003;ooooo00?o0000ooooooooool0X_oo
ool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo01Kooooo000Kooooo`03o`000?oooooo
oooo01_ooooo0ol0000fooooo`03o`000?oooooooooo0:;ooooo00?o0000ooooooooool0=_ooool0
0ol0003oooooooooo`0Eooooo`006_ooool00ol0003oooooooooo`0Jooooo`;o0000>_ooool00ol0
003oooooooooo`2Rooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool05?ooool001[o
oooo0_l0000Hooooo`?o0000?Oooool00ol0003oooooooooo`2Rooooo`03o`000?oooooooooo03Go
oooo00?o0000ooooooooool05?ooool001[ooooo00?o0000ooooooooool05?ooool3o`00047ooooo
00?o0000ooooooooool0XOooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo01?ooooo
000Jooooo`03o`000?oooooooooo017ooooo0ol00015ooooo`03o`000?oooooooooo0:7ooooo00?o
0000ooooooooool0=_ooool00ol0003oooooooooo`0Booooo`006_ooool00ol0003oooooooooo`0>
ooooo`?o0000BOooool00ol0003oooooooooo`2Qooooo`03o`000?oooooooooo03Gooooo0_l0000C
ooooo`006_ooool00ol0003oooooooooo`0<ooooo`;o0000COooool00ol0003oooooooooo`2Loooo
o`;ooiT00oooool00ol0003oooooooooo`0dooooo`;o00004oooool001Wooooo0ol0000:ooooo`?o
0000D?ooool00ol0003oooooooooo`2Jooooo`03oonI0?oooooooooo00Cooooo00?o0000oooooooo
ool0=Oooool00ol0003oooooooooo`0@ooooo`006_ooool00ol0003oooooooooo`06ooooo`?o0000
E?ooool00ol0003oooooooooo`2Gooooo`;ooiT01oooool00ol0003oooooooooo`0fooooo`03o`00
0?oooooooooo00oooooo000Iooooo`03o`000?oooooooooo00Cooooo0ol0001Hooooo`03o`000?oo
oooooooo09Gooooo00?ooiT0ooooooooool02?ooool00ol0003oooooooooo`0eooooo`03o`000?oo
oooooooo00oooooo000Iooooo`04o`000?ooooooooooooooo`?o0000G?ooool00ol0003ooooooooo
o`2Booooo`;ooiT03?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00kooooo000I
ooooo`Co0000H?ooool00ol0003oooooooooo`2@ooooo`03oonI0?oooooooooo00gooooo00?o0000
ooooooooool0=Oooool00ol0003oooooooooo`0=ooooo`006Oooool2o`0006?ooooo00?o0000oooo
ooooool0SOooool2oonI00_ooooo0_o<o`04ooooo`03o`000?oooooooooo03Cooooo00?o0000oooo
ooooool03Oooool000oooooo1?l000000ol@413oooooooooo`05ooooo`03o`000?oooooooooo067o
oooo00?o0000ooooooooool0R_ooool2oonI00cooooo00?oc?l0ooooooooool01?ooool00ol0003o
ooooooooo`0eooooo`03o`000?oooooooooo00cooooo000Aooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0HOooool00ol0003oooooooooo`28ooooo`03oonI0?oooooooooo00[ooooo
0_o<o`08ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool02oooool0017ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo08Gooooo0_oo
V@0<ooooo`03olco0?oooooooooo00Wooooo00?o0000ooooooooool0=Oooool00ol0003ooooooooo
o`0:ooooo`004Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo067ooooo00?o0000
ooooooooool0P_ooool2oonI00cooooo0_o<o`0=ooooo`03o`000?oooooooooo03Cooooo00?o0000
ooooooooool02_ooool0017ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Qoooo
o`03o`000?oooooooooo083ooooo00?ooiT0ooooooooool02oooool00oo<o`3oooooooooo`0>oooo
o`03o`000?oooooooooo03Cooooo00?o0000ooooooooool02Oooool0017ooooo00?o0000oooooooo
ool03?ooool2o`0006;ooooo00?o0000ooooooooool0OOooool2oonI00cooooo0_o<o`0;ooooo`;o
<ol01?ooool00ol0003oooooooooo`0cooooo`?o00002_ooool0017ooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo07[ooooo0_ooV@0<ooooo`;oc?l0
3?ooool00olco`3oooooooooo`05ooooo`03o`000?oooooooooo02oooooo0ol00002ooooo`03o`00
0?oooooooooo00Sooooo000?ooooo`03oeEEEOmVIVKo0000017ooooo00?o0000ooooooooool0H?oo
ool00ol0003oooooooooo`1fooooo`?ooiT03?ooool2olco00gooooo00?o<ol0ooooooooool01ooo
ool00ol0003oooooooooo`0[ooooo`?o00001Oooool00ol0003oooooooooo`08ooooo`009?ooool0
0ol0003oooooooooo`1Pooooo`03o`000?oooooooooo07?ooooo0_ooV@0>ooooo`03olco0?oooooo
oooo00_ooooo0_lco`0;ooooo`03o`000?oooooooooo02Kooooo1?l00008ooooo`03o`000?oooooo
oooo00Sooooo000Uooooo`03o`000?oooooooooo063ooooo00?o0000ooooooooool0L?ooool2oonI
00kooooo0_o<o`0=ooooo`03oc?o0?oooooooooo00cooooo00?o0000ooooooooool08_ooool3o`00
00cooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool0H?ooool00ol0003o
ooooooooo`1]ooooo`;ooiT03_ooool2olco00kooooo00?o<ol0ooooooooool03Oooool00ol0003o
ooooooooo`0Oooooo`?o00004?ooool00ol0003oooooooooo`07ooooo`009oooool00ol0003ooooo
ooooo`1Pooooo`03o`000?oooooooooo06Wooooo0oooV@0>ooooo`;oc?l03oooool00olco`3ooooo
ooooo`08ooooo`;o0?mV1Oooool00ol0003oooooooooo`0Jooooo`Co00004oooool00ol0003ooooo
ooooo`07ooooo`00:?ooool2o`00067ooooo00?o0000ooooooooool0IOooool3oonI00oooooo0_o<
o`0?ooooo`;o<ol02_ooool00ol0ofKoooooooooo`06ooooo`03o`000?oooooooooo01Kooooo0ol0
000Gooooo`03o`000?oooooooooo00Oooooo000Zooooo`03o`000?oooooooooo05oooooo00?o0000
ooooooooool0HOooool3oonI00oooooo0oo<o`0?ooooo`;o<ol02_ooool2o`3oIP[ooooo00?o0000
ooooooooool04_ooool3o`0001[ooooo00?o0000ooooooooool01oooool002_ooooo00?o0000oooo
ooooool0Goooool00ol0003oooooooooo`1Mooooo`?ooiT04?ooool2olco00oooooo0olco`0;oooo
o`03o`3oI_oooooooooo00_ooooo00?o0000ooooooooool03Oooool4o`0001gooooo00?o0000oooo
ooooool01oooool002cooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`1Iooooo`?o
oiT04Oooool2olco00oooooo0_lco`0=ooooo`03o`3oI_oooooooooo00cooooo00?o0000oooooooo
ool02_ooool3o`00027ooooo00?o0000ooooooooool01oooool002gooooo00?o0000ooooooooool0
Goooool00ol0003oooooooooo`1Eooooo`?ooiT04_ooool2olco00oooooo0_lco`0=ooooo`;o0?mV
4?ooool00ol0003oooooooooo`06ooooo`?o00009?ooool00ol0003oooooooooo`07ooooo`00;_oo
ool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo057ooooo0oooV@0Booooo`?oc?l03ooo
ool2oc?o00kooooo00?o0?mVooooooooool02_ooool2o`3oo`Gooooo00Co0000oooooooooooooooo
1?l0000Wooooo`03o`000?oooooooooo00Oooooo000_ooooo`;o0000H?ooool00ol0003ooooooooo
o`1<ooooo`CooiT04oooool2olco013ooooo0_lco`0>ooooo`;o0?mV3?ooool00ol0oooooooooooo
o`06ooooo`?o0000;?ooool00ol0003oooooooooo`06ooooo`00<Oooool00ol0003oooooooooo`1N
ooooo`;o0000Aoooool5oonI01Gooooo0_o<o`0@ooooo`;o<ol03_ooool2o`3oIPcooooo0_l0ool6
ooooo`?o000000?oooooo`000?ooool0;?ooool00ol0003oooooooooo`06ooooo`00<_ooool00ol0
003oooooooooo`1Oooooo`03o`000?oooooooooo043ooooo1?ooV@0Gooooo`?oc?l04?ooool2oc?o
00kooooo0_l0ofH<ooooo`;o0?oo1Oooool3o`0000Cooooo00?o0000ooooooooool0:oooool00ol0
003oooooooooo`06ooooo`00<oooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo03_o
oooo1?ooV@0Hooooo`?oc?l04Oooool2oc?o00oooooo00?o0?mVooooooooool02oooool01?l0oooo
ooooooooooooool4o`0000Sooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`06oooo
o`00=?ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo03Gooooo1OooV@0Iooooo`?o
c?l04_ooool2oc?o00oooooo0_l0ofH<ooooo`;o0?oo00Coooooo`000?l0003o00003Oooool00ol0
003oooooooooo`0Yooooo`03o`000?oooooooooo00Kooooo000eooooo`03o`000?oooooooooo05oo
oooo00?o0000ooooooooool0<?ooool4oonI01_ooooo0oo<o`0Booooo`?o<ol03oooool2o`3oIPgo
oooo00Co0?ooo`000?l0003o00002Oooool2o`1Vo`Kooooo00?o0000ooooooooool0:?ooool00ol0
003oooooooooo`06ooooo`00=_ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo02Oo
oooo2?ooV@0Looooo`?oc?l04_ooool3oc?o013ooooo0_l0ofH<ooooo`04o`000?l0oooo0?ooo`00
00_ooooo00?o06Koooooooooool01oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
00Kooooo000gooooo`;o0000H?ooool00ol0003oooooooooo`0Jooooo`cooiT08?ooool4olco01;o
oooo0olco`0@ooooo`?o0?mV2oooool2o`0000;o0?oo3?ooool2o`1Vo`[ooooo00?o0000oooooooo
ool09oooool00ol0003oooooooooo`06ooooo`00>Oooool00ol0003oooooooooo`1Nooooo`03o`00
0?oooooooooo01;ooooo1oooV@0Wooooo`Goc?l04oooool3oc?o017ooooo0_l0ofH;ooooo`?o0000
0_l0ool<ooooo`;o06Ko3Oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Gooooo
000jooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0>oooool4olco01Cooooo1?lc
o`0Booooo`;o0?mV2Oooool4o`000003ooooool0oooo0?oo00gooooo00?o06Koooooooooool03_oo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00Gooooo000kooooo`03o`000?oooooo
oooo05kooooo00?o0000ooooooooool0=Oooool5olco01Gooooo0olco`0Cooooo`?o0?mV2?ooool3
o`0000?ooooo0_l0ool=ooooo`;o06Ko4_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo00Gooooo000looooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0;Oooool7olco
01Oooooo0olco`0Dooooo`;o0?mV2?ooool3o`0000Cooooo0_l0ool>ooooo`03o`1Voooooooooooo
00[ooooo0_lc0?l6ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool01Oooool003go
oooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0Vooooo`Koc?l06oooool3oc?o01Co
oooo0ol0ofH6ooooo`Co00001Oooool2o`3oo`kooooo0_l0I_l;ooooo`;o<`3o2Oooool00ol0003o
ooooooooo`0Tooooo`03o`000?oooooooooo00Gooooo000nooooo`;o0000Goooool00ol0003ooooo
ooooo`0Nooooo`Ooc?l07Oooool4oc?o01Cooooo0ol0ofH6ooooo`?o00001_ooool3o`3oo`kooooo
0_l0I_l<ooooo`03oc<0oooooooooooo00[ooooo00?o0000ooooooooool08oooool00ol0003ooooo
ooooo`05ooooo`00@?ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo01?ooooo2_o<
o`0Oooooo`Go<ol05_ooool2o`3oIPKooooo0ol00007ooooo`;o0?oo3oooool2o`1Vo`cooooo0_lc
0?l>ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool01Oooool0047ooooo00?o0000
ooooooooool0GOooool00ol0003oooooooooo`0<ooooo`Koc?l09Oooool4oc?o01Sooooo0ol0ofH4
ooooo`Co00002?ooool2o`3oo`oooooo0_l0I_l<ooooo`;o<`3o4Oooool00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo00Gooooo0012ooooo`03o`000?oooooooooo05gooooo00?o0000oooo
ooooool0<_ooool4oc?o01Wooooo0ol0ofH4ooooo`?o00002Oooool3o`3oo`oooooo0_l0I_l=oooo
o`03oc<0oooooooooooo017ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`05oooo
o`00@oooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo02cooooo1Olco`0Jooooo`?o
0?mV1?ooool3o`0000[ooooo0_l0ool@ooooo`;o06Ko3Oooool2oc<0o`cooooo0_o<0?l7ooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool01?ooool004Cooooo00?o0000ooooooooool0
GOooool00ol0003oooooooooo`0Vooooo`Go<ol06oooool4o`3oIP?ooooo1?l0000:ooooo`?o0?oo
4?ooool2o`1Vo`gooooo0_lc0?l<ooooo`;oc03o2_ooool00ol0003oooooooooo`0Pooooo`03o`00
0?oooooooooo00Cooooo0015ooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool08?oo
ool5oc?o01gooooo0ol0ofH4ooooo`?o00002oooool3o`3ooa3ooooo0ol0I_l=ooooo`;o<`3o3Ooo
ool00oo<0?ooooooooooo`0;ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool01?oo
ool004Kooooo0_l0001Nooooo`03o`000?oooooooooo01Sooooo1olco`0Nooooo`Co0?mV1?ooool3
o`0000_ooooo0ol0oolAooooo`;o06Ko3_ooool2oc<0o`gooooo0_o<0?l?ooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool01?ooool004Sooooo00?o0000ooooooooool0G?ooool00ol0
003oooooooooo`0=ooooo`[o<ol08?ooool5o`3oIPCooooo1?l0000;ooooo`?o0?oo4_ooool2o`1V
o`kooooo0_lc0?l=ooooo`;oc03o4Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
00Cooooo0019ooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool01Oooool7oc?o02Go
oooo1Ol0ofH6ooooo`?o00003?ooool3o`3ooa;ooooo0ol0I_l>ooooo`;o<`3o3_ooool00oo<0?oo
ooooooooo`0Booooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool01?ooool004[ooooo
00?o0000ooooooooool0G?ooool00ol0003oooooooooo`0/ooooo`Co0?mV2?ooool3o`0000cooooo
0ol0oolCooooo`;o06Ko3oooool2oc<0o`kooooo0_o<0?l<ooooo`;oo`2I2?ooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo00Cooooo001;ooooo`03o`000?oooooooooo05cooooo00?o
0000ooooooooool09_ooool5o`3oIPSooooo1?l0000;ooooo`Co0?oo5?ooool2o`1Vo`oooooo0_lc
0?l>ooooo`;oc03o3?ooool2ool0V@_ooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`04ooooo`00C?ooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo023ooooo1Ol0ofH:
ooooo`?o00003?ooool3o`3ooaGooooo0ol0I_l>ooooo`?o<`3o3_ooool2ol`0o`gooooo00?oo`2I
ooooooooool03?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00?ooooo001=oooo
o`;o0000GOooool00ol0003oooooooooo`0Jooooo`Go0?mV3?ooool3o`0000_ooooo1?l0oolEoooo
o`?o06Ko3oooool2oc<0o`oooooo0_o<0?l=ooooo`;oo`2I3oooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo00?ooooo001?ooooo`03o`000?oooooooooo05_ooooo00?o0000oooooooo
ool04_ooool7o`3oIPkooooo0ol0000;ooooo`?o0?oo5oooool2o`1Voa3ooooo0_lc0?l?ooooo`;o
c03o3Oooool2ool0VA;ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`03ooooo`00
D?ooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo00Oooooo2_l0ofHAooooo`Co0000
2_ooool4o`3ooaOooooo0ol0I_l?ooooo`?o<`3o4?ooool00oo<0?ooooooooooo`0<ooooo`03ool0
VOoooooooooo01?ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`03ooooo`00DOoo
ool00ol0003oooooooooo`1Kooooo`03o`000?oooooo0?mV00Ko0?mV6?ooool3o`0000_ooooo0ol0
oolHooooo`?o06Ko4?ooool2oc<0oa7ooooo0_o<0?l=ooooo`;oo`2I3?ooool2ool000Wooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`03ooooo`00D_ooool00ol0003oooooooooo`1K
ooooo`03o`000?oooooooooo01[ooooo0ol00009ooooo`Go0?oo5oooool4o`1Voa7ooooo0_lc0?lA
ooooo`;oc03o3Oooool2ool0V@gooooo00?oo`00ooooooooool02_ooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo00?ooooo001Cooooo`03o`000?oooooooooo05_ooooo00?o0000oooo
ooooool05Oooool4o`0000Gooooo1ol0oolIooooo`?o06Ko4_ooool3oc<0oa7ooooo0_o<0?l=oooo
o`;oo`2I3Oooool2ool000gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`03oooo
o`00E?ooool2o`0005cooooo00?o0000ooooooooool04Oooool3o`000003ooooool0oooo0?oo00Ko
0?oo7?ooool4o`1Voa;ooooo0olc0?lAooooo`?oc03o3Oooool2ool0V@kooooo00?oo`00oooooooo
ool03_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00?ooooo001Fooooo`03o`00
0?oooooooooo05[ooooo00?o0000ooooooooool03Oooool7o`3oob3ooooo1?l0I_lCooooo`?o<`3o
4_ooool2ol`0o`kooooo0_oo09T>ooooo`;oo`004_ooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo00;ooooo001Gooooo`03o`000?oooooooooo05[ooooo00Co0000oooooooooooooooo
2ol0oolRooooo`Go06Ko5?ooool3oc<0oa?ooooo0_o<0?l>ooooo`;oo`2I3oooool00ooo003ooooo
ooooo`0Cooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool00_ooool005Sooooo00?o
0000ooooooooool0E_ooool7o`3oo`Cooooo0ol0000Qooooo`Go06Ko5_ooool3oc<0oa?ooooo0oo<
0?l>ooooo`;oo`2I3oooool2ool001Oooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`02ooooo`00FOooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00?o00008?ooool4
o`1VoaSooooo0olc0?lDooooo`;oc03o3oooool2ool0VA3ooooo00?oo`00ooooooooool05oooool0
0ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00;ooooo001Jooooo`03o`000?oooooooooo
05[ooooo0_l0000Nooooo`Go06Ko6?ooool4oc<0oaGooooo0_o<0?l?ooooo`;oo`2I4?ooool2ool0
01_ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`02ooooo`00Foooool00ol0003o
ooooooooo`1Iooooo`03o`000?oooooooooo01Sooooo1Ol0I_lJooooo`?o<`3o5_ooool3ol`0o`ko
oooo0ooo09T?ooooo`?oo`007_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00;o
oooo001Looooo`;o0000FOooool00ol0003oooooooooo`0Aooooo`Oo06Ko6oooool4oc<0oaKooooo
0oo<0?l?ooooo`;oo`2I4?ooool2ool002;ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`02ooooo`00G_ooool00ol0003oooooooooo`1Fooooo`03o`000?oooooooooo00[ooooo1ol0
I_lNooooo`Co<`3o5oooool3ol`0oa3ooooo0_oo09T@ooooo`;oo`009Oooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo00;ooooo001Oooooo`03o`000?oooooooooo05Gooooo00?o0000
ooooool0I_l02_l0I_lQooooo`Co<`3o6?ooool3ol`0oa3ooooo0ooo09T?ooooo`?oo`009oooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo007ooooo001Pooooo`03o`000?oooooooooo
04oooooo1ol0I_lXooooo`Co<`3o6Oooool3ol`0oa7ooooo0_oo09T@ooooo`;oo`00:oooool00ol0
003oooooooooo`0@ooooo`03o`000?oooooooooo007ooooo001Qooooo`03o`000?oooooooooo05?o
oooo00?o0000ooooooooool08oooool4oc<0oaWooooo1?o<0?lBooooo`;oo`2I4?ooool2ool002ko
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`01ooooo`00H_ooool00ol0003ooooo
ooooo`1Booooo`03o`000?oooooooooo01kooooo1Olc0?lJooooo`?oc03o4oooool3ool0V@oooooo
0ooo000aooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool00Oooool006?ooooo0_l0
001Booooo`03o`000?oooooooooo01Wooooo1Olc0?lKooooo`Coc03o4oooool3ool0VA3ooooo0_oo
000eooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00Oooool006Gooooo00?o0000
ooooooooool0Coooool00ol0003oooooooooo`0Booooo`Oo<`3o6oooool5ol`0oaCooooo0ooo09T@
ooooo`?oo`00=oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo007ooooo001Voooo
o`03o`000?oooooooooo04kooooo00?o0000ooooooooool02oooool7oc<0oagooooo1Oo<0?lFoooo
o`?oo`2I4Oooool2ool003_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`01oooo
o`00Ioooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo00_o<`3o7oooool5ol`0oaOo
oooo1?oo09TAooooo`?oo`00?_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo007o
oooo001Xooooo`03o`000?oooooooooo04Oooooo2?lc0?lTooooo`Koc03o6?ooool4ool0VA?ooooo
0_oo0012ooooo`03o`000?oooooooooo00_ooooo0Ol00001ooooo`7ooooo001Yooooo`03o`000?oo
oooooooo04_ooooo00?o0000ooooooooool07oooool5ol`0oa_ooooo0ooo09TDooooo`?oo`00A?oo
ool00ol0003oooooooooo`0;ooooo`7o00000Oooool1ooooo`00J_ooool00ol0003oooooooooo`1:
ooooo`03o`000?oooooooooo01[ooooo1Oo<0?lLooooo`Coo`2I5?ooool3ool004Sooooo00?o0000
ooooooooool02_ooool1o`00007ooooo0Oooool006_ooooo0_l0001:ooooo`03o`000?oooooooooo
01?ooooo1oo<0?lMooooo`Coo`2I5Oooool3ool004cooooo00?o0000ooooooooool02Oooool1o`00
007ooooo0Oooool006gooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0<ooooo`Oo
c03o8?ooool4ool0VAKooooo0ooo001@ooooo`03o`000?oooooooooo00Sooooo0Ol00001ooooo`7o
oooo001^ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool03?o<0?lSooooo`Coo`2I
5_ooool4ool005Cooooo00?o0000ooooooooool01oooool1o`00007ooooo0Oooool006oooooo00?o
0000ooooooooool0@?ooool8ol`0ob_ooooo1?oo09TGooooo`?oo`00F?ooool00ol0003ooooooooo
o`07ooooo`7o00000Oooool1ooooo`00L?ooool00ol0003oooooooooo`14ooooo`03o`000?oooooo
oooo02Kooooo1Ooo09THooooo`?oo`00G?ooool00ol0003oooooooooo`06ooooo`7o00000Oooool1
ooooo`00LOooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo027ooooo1Ooo09TJoooo
o`?oo`00H?ooool00ol0003oooooooooo`05ooooo`7o00000Oooool1ooooo`00L_ooool2o`0004;o
oooo00?o0000ooooooooool07Oooool5ool0VAcooooo0ooo001Tooooo`03o`000?oooooooooo00Go
oooo0Ol00001ooooo`00M?ooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo01Kooooo
1ooo09TMooooo`Coo`00J?ooool00ol0003oooooooooo`04ooooo`7o00000Oooool007Gooooo00?o
0000ooooooooool0?_ooool00ol0003oooooooooo`0>ooooo`Soo`2I8?ooool4ool006cooooo00?o
0000ooooooooool01?ooool1o`00007ooooo001fooooo`03o`000?oooooooooo03gooooo00?o0000
ooooooooool00_ooool<ool0VBCooooo1?oo001aooooo`03o`000?oooooooooo00?ooooo0Ol00001
ooooo`00Moooool00ol0003oooooooooo`0iooooo`Soo`2I;?ooool4ool007Kooooo00?o0000oooo
ooooool00_ooool1o`00007ooooo001hooooo`03o`000?oooooooooo03_ooooo00?o0000oooooooo
ool0:?ooool6ool007_ooooo00Go0000ooooooooooooooooo`000001ooooo`00NOooool00ol0003o
ooooooooo`0jooooo`03o`000?oooooooooo01oooooo2Ooo0022ooooo`04o`000?ooooooooooo`00
007ooooo001jooooo`;o0000>_ooool00ol0003oooooooooo`0Gooooo`Soo`00Roooool01?l0003o
ooooooooool00001ooooo`00O?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00ko
oooo2Ooo002Dooooo`03o`000?oooooooooo007o0000001mooooo`03o`000?oooooooooo03Kooooo
00?o0000ooooooooool01_ooool8ool009kooooo0Ol00001ooooo`7o0000001nooooo`03o`000?oo
oooooooo03Gooooo00?o0000ool00?oo00001_oo002Wooooo`;o0000001oooooo`03o`000?oooooo
oooo037ooooo1?oo002^ooooo`?o00000020ooooo`03o`000?oooooooooo03?ooooo00?o0000oooo
ooooool0Z?ooool4o`0000?ooooo0021ooooo`;o0000<oooool00ol0003oooooooooo`2Uooooo`?o
00001oooool008?ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`2Qooooo`Co0000
2_ooool008Cooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`2Mooooo`Co00003_oo
ool008Gooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`2Iooooo`Co00004_ooool0
08Kooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`2Eooooo`Co00005_ooool008Oo
oooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`2Booooo`?o00006_ooool008Sooooo
0_l0000/ooooo`03o`000?oooooooooo08kooooo1?l0000Mooooo`00R_ooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo08[ooooo1?l0000Qooooo`00Roooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo08Kooooo1?l0000Uooooo`00S?ooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo08;ooooo1?l0000Yooooo`00SOooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo07oooooo0ol0000]ooooo`00S_ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo07_ooooo1?l0000`ooooo`00Soooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo07Oooooo1?l0000dooooo`00T?ooool2o`0002Cooooo00?o0000ooooooooool0Loooool4
o`0003Sooooo002Booooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0L?ooool3o`00
03cooooo002Cooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0K?ooool4o`0003oo
oooo002Dooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0J?ooool4o`0004?ooooo
002Eooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0I?ooool4o`0004Oooooo002F
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0H?ooool4o`0004_ooooo002Goooo
o`;o00007Oooool00ol0003oooooooooo`1Mooooo`?o0000Coooool009Wooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`1Iooooo`Co0000D_ooool009[ooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`1Eooooo`Co0000E_ooool009_ooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`1Aooooo`Co0000F_ooool009cooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`1=ooooo`Co0000G_ooool009gooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`1:ooooo`?o0000H_ooool009kooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`16ooooo`Co0000IOooool009oooooo0_l0000Dooooo`03o`000?oooooooooo04?ooooo
1?l0001Yooooo`00XOooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo03oooooo1?l0
001]ooooo`00X_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03_ooooo1?l0001a
ooooo`00Xoooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03Sooooo0ol0001eoooo
o`00Y?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03Cooooo1?l0001hooooo`00
YOooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo033ooooo1?l0001looooo`00Y_oo
ool2o`0000gooooo00?o0000ooooooooool0;?ooool4o`00083ooooo002Xooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool0:Oooool3o`0008Cooooo002Yooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool09Oooool4o`0008Oooooo002Zooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool08Oooool4o`0008_ooooo002[ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool07Oooool4o`0008oooooo002/ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool06Oooool4o`0009?ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool05_ooool3o`0009Oooooo002^ooooo`;o00001Oooool00ol0003oooooooooo`0Boooo
o`Co0000V_ooool00;3ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0>ooooo`Co
0000W_ooool00;7ooooo00Go0000ooooooooooooooooo`00000<ooooo`Co0000X_ooool00;;ooooo
00Co0000oooooooooooo00002?ooool4o`000:Kooooo002cooooo`03o`000?oooooo000000Gooooo
0ol0002Zooooo`00]?ooool2o`000003ooooool0003o000000;o0000[Oooool00;Gooooo0_l0002a
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {319.688, 0}} -> {-0.0710364, -0.0181728, \
0.0035149, 0.0035149}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .89104 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-16 1.0656 -0.0363427 1.0656 [
[.02544 .21571 -12 -8.9133 ]
[.02544 .21571 0 .0867 ]
[.16074 .16277 -11.6592 -9 ]
[.16074 .16277 .34081 0 ]
[.3021 .10747 -5.60025 -9 ]
[.3021 .10747 .39975 0 ]
[.44992 .04965 -5.37091 -9 ]
[.44992 .04965 .62909 0 ]
[.60467 -0.01084 -5.14157 -9 ]
[.60467 -0.01084 .85843 0 ]
[.66454 .05085 0 -6.20675 ]
[.66454 .05085 6 2.79325 ]
[.80797 .25198 0 -6.0417 ]
[.80797 .25198 6 2.9583 ]
[.93071 .4241 0 -5.90576 ]
[.93071 .4241 6 3.09424 ]
[.02254 .22988 -12 -2.74631 ]
[.02254 .22988 0 6.25369 ]
[.0142 .29178 -24 -2.78907 ]
[.0142 .29178 0 6.21093 ]
[.00558 .35578 -6 -2.83339 ]
[.00558 .35578 0 6.16661 ]
[-0.00334 .42198 -18 -2.87938 ]
[-0.00334 .42198 0 6.12062 ]
[-0.01257 .49051 -6 -2.92712 ]
[-0.01257 .49051 0 6.07288 ]
[ 0 0 0 0 ]
[ 1 .89104 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03495 .22504 m
.61241 0 L
s
.03495 .22504 m
.03971 .2297 L
s
[(-2)] .02544 .21571 1 .98073 Mshowa
.16988 .17246 m
.17445 .1773 L
s
[(-1)] .16074 .16277 .9432 1 Mshowa
.31082 .11753 m
.31518 .12256 L
s
[(0)] .3021 .10747 .86675 1 Mshowa
.45818 .0601 m
.46231 .06533 L
s
[(1)] .44992 .04965 .7903 1 Mshowa
.61241 0 m
.61628 .00542 L
s
[(2)] .60467 -0.01084 .71386 1 Mshowa
.125 Mabswid
.06148 .2147 m
.06431 .21752 L
s
.08823 .20428 m
.09104 .20712 L
s
.11521 .19376 m
.118 .19663 L
s
.14243 .18316 m
.14519 .18604 L
s
.19758 .16166 m
.20029 .16459 L
s
.22551 .15078 m
.22821 .15373 L
s
.2537 .13979 m
.25637 .14277 L
s
.28213 .12871 m
.28478 .13171 L
s
.33977 .10625 m
.34236 .10929 L
s
.36897 .09487 m
.37153 .09794 L
s
.39844 .08339 m
.40097 .08648 L
s
.42817 .0718 m
.43068 .07491 L
s
.48846 .0483 m
.49091 .05146 L
s
.51902 .03639 m
.52144 .03958 L
s
.54986 .02437 m
.55225 .02758 L
s
.58099 .01224 m
.58335 .01547 L
s
.25 Mabswid
.61241 0 m
.97291 .505 L
s
.65208 .05558 m
.64586 .05794 L
s
[(0)] .66454 .05085 -1 .37928 Mshowa
.79537 .2563 m
.78907 .25846 L
s
[(2)] .80797 .25198 -1 .3426 Mshowa
.91799 .42808 m
.91164 .43006 L
s
[(4)] .93071 .4241 -1 .31239 Mshowa
.125 Mabswid
.69012 .10886 m
.68637 .11025 L
s
.72662 .16 m
.72286 .16135 L
s
.76168 .2091 m
.75791 .21042 L
s
.82778 .3017 m
.82399 .30297 L
s
.85897 .3454 m
.85518 .34664 L
s
.88903 .3875 m
.88522 .38871 L
s
.94594 .46722 m
.94211 .46839 L
s
.25 Mabswid
.03495 .22504 m
0 .48612 L
s
.03495 .22504 m
.04116 .22262 L
s
[(-1)] .02254 .22988 1 -0.38971 Mshowa
.02665 .28704 m
.03288 .28468 L
s
[(-0.5)] .0142 .29178 1 -0.38021 Mshowa
.01807 .35115 m
.02431 .34884 L
s
[(0)] .00558 .35578 1 -0.37036 Mshowa
.00919 .41747 m
.01546 .41521 L
s
[(0.5)] -0.00334 .42198 1 -0.36014 Mshowa
0 .48612 m
.00629 .48392 L
s
[(1)] -0.01257 .49051 1 -0.34953 Mshowa
.125 Mabswid
.03331 .23728 m
.03704 .23583 L
s
.03166 .2496 m
.03539 .24816 L
s
.03 .262 m
.03373 .26056 L
s
.02833 .27448 m
.03207 .27305 L
s
.02496 .29969 m
.0287 .29828 L
s
.02325 .31243 m
.02699 .31102 L
s
.02154 .32525 m
.02528 .32385 L
s
.01981 .33816 m
.02355 .33676 L
s
.01632 .36423 m
.02007 .36285 L
s
.01455 .37741 m
.01831 .37603 L
s
.01278 .39067 m
.01653 .3893 L
s
.01099 .40402 m
.01475 .40266 L
s
.00738 .43101 m
.01114 .42966 L
s
.00555 .44464 m
.00932 .4433 L
s
.00371 .45837 m
.00748 .45704 L
s
.00186 .4722 m
.00563 .47087 L
s
.25 Mabswid
.03495 .22504 m
0 .48612 L
s
0 .48612 m
.46953 .89104 L
s
.46953 .89104 m
.47294 .65459 L
s
.47294 .65459 m
.03495 .22504 L
s
.61241 0 m
.97291 .505 L
s
.97291 .505 m
1 .75117 L
s
1 .75117 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.03495 .22504 m
0 .48612 L
s
0 .48612 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.61241 0 m
.03495 .22504 L
s
.47294 .65459 m
.97291 .505 L
s
.97291 .505 m
1 .75117 L
s
1 .75117 m
.46953 .89104 L
s
.46953 .89104 m
.47294 .65459 L
s
0 0 m
1 0 L
1 .89104 L
0 .89104 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.46597 .76456 m
.51682 .76103 L
s
1 0 .6 r
.46468 .74482 m
.51423 .74135 L
s
1 0 0 r
.51682 .76103 m
.56884 .75481 L
s
.8 0 1 r
.46339 .72504 m
.51164 .72162 L
s
1 0 .6 r
.51423 .74135 m
.56498 .73521 L
s
.2 0 1 r
.46209 .70521 m
.50905 .70186 L
s
.8 0 1 r
.51164 .72162 m
.56112 .71558 L
s
0 .4 1 r
.46079 .68535 m
.50645 .68205 L
s
.2 0 1 r
.50905 .70186 m
.55725 .69591 L
s
1 0 0 r
.56884 .75481 m
.62061 .74596 L
s
0 1 1 r
.45949 .66544 m
.50385 .66221 L
s
0 .4 1 r
.50645 .68205 m
.55337 .6762 L
s
1 0 .6 r
.56498 .73521 m
.61553 .72648 L
s
0 1 .4 r
.45819 .6455 m
.50124 .64232 L
s
0 1 1 r
.50385 .66221 m
.54949 .65645 L
s
.8 0 1 r
.56112 .71558 m
.61044 .70696 L
s
.2 1 0 r
.45688 .62551 m
.49862 .6224 L
s
0 1 .4 r
.50124 .64232 m
.5456 .63667 L
s
.2 0 1 r
.55725 .69591 m
.60534 .68742 L
s
.8 1 0 r
.45557 .60548 m
.496 .60244 L
s
0 .4 1 r
.55337 .6762 m
.60023 .66784 L
s
.2 1 0 r
.49862 .6224 m
.5417 .61686 L
s
1 .6 0 r
.45426 .5854 m
.49337 .58243 L
s
0 1 1 r
.54949 .65645 m
.59511 .64823 L
s
.8 1 0 r
.496 .60244 m
.53779 .59701 L
s
1 0 0 r
.62061 .74596 m
.67144 .7346 L
s
1 0 .6 r
.61553 .72648 m
.66516 .71526 L
s
0 1 .4 r
.5456 .63667 m
.58998 .62859 L
s
1 .6 0 r
.49337 .58243 m
.53388 .57712 L
s
.8 0 1 r
.61044 .70696 m
.65888 .6959 L
s
.2 1 0 r
.5417 .61686 m
.58485 .60892 L
s
.2 0 1 r
.60534 .68742 m
.65258 .67651 L
s
.8 1 0 r
.53779 .59701 m
.57971 .58922 L
s
0 .4 1 r
.60023 .66784 m
.64628 .65709 L
s
1 .6 0 r
.53388 .57712 m
.57456 .56948 L
s
0 1 1 r
.59511 .64823 m
.63997 .63765 L
s
0 1 .4 r
.58998 .62859 m
.63365 .61819 L
s
.2 1 0 r
.58485 .60892 m
.62732 .59869 L
s
1 0 0 r
.67144 .7346 m
.72099 .72078 L
s
.8 1 0 r
.57971 .58922 m
.62099 .57917 L
s
1 0 .6 r
.66516 .71526 m
.71354 .70162 L
s
1 .6 0 r
.57456 .56948 m
.61464 .55963 L
s
.8 0 1 r
.65888 .6959 m
.70608 .68245 L
s
.2 0 1 r
.65258 .67651 m
.69861 .66325 L
s
0 .4 1 r
.64628 .65709 m
.69113 .64403 L
s
0 1 1 r
.63997 .63765 m
.68365 .6248 L
s
0 1 .4 r
.63365 .61819 m
.67616 .60554 L
s
.2 1 0 r
.62732 .59869 m
.66866 .58626 L
s
.8 1 0 r
.62099 .57917 m
.66116 .56697 L
s
1 .6 0 r
.61464 .55963 m
.65364 .54766 L
s
1 0 0 r
.72099 .72078 m
.76901 .70453 L
s
1 0 .6 r
.71354 .70162 m
.76038 .68559 L
s
.8 0 1 r
.70608 .68245 m
.75175 .66664 L
s
.2 0 1 r
.69861 .66325 m
.74311 .64767 L
s
0 .4 1 r
.69113 .64403 m
.73446 .6287 L
s
0 1 1 r
.68365 .6248 m
.72581 .60971 L
s
0 1 .4 r
.67616 .60554 m
.71715 .59071 L
s
.2 1 0 r
.66866 .58626 m
.70849 .5717 L
s
.8 1 0 r
.66116 .56697 m
.69982 .55268 L
s
1 .6 0 r
.65364 .54766 m
.69115 .53365 L
s
1 0 0 r
.76901 .70453 m
.8151 .68585 L
s
1 0 .6 r
.76038 .68559 m
.80528 .66718 L
s
.8 0 1 r
.75175 .66664 m
.79546 .64851 L
s
.2 0 1 r
.74311 .64767 m
.78563 .62984 L
s
0 .4 1 r
.73446 .6287 m
.7758 .61116 L
s
0 1 1 r
.72581 .60971 m
.76598 .59248 L
s
0 1 .4 r
.71715 .59071 m
.75615 .5738 L
s
.2 1 0 r
.70849 .5717 m
.74631 .55511 L
s
.8 1 0 r
.69982 .55268 m
.73648 .53643 L
s
1 .6 0 r
.69115 .53365 m
.72665 .51773 L
s
1 0 0 r
.8151 .68585 m
.85847 .66493 L
s
1 0 .6 r
.80528 .66718 m
.84745 .6466 L
s
.8 0 1 r
.79546 .64851 m
.83643 .62828 L
s
.2 0 1 r
.78563 .62984 m
.82541 .60996 L
s
0 .4 1 r
.7758 .61116 m
.8144 .59165 L
s
0 1 1 r
.76598 .59248 m
.80339 .57334 L
s
0 1 .4 r
.75615 .5738 m
.79239 .55504 L
s
.2 1 0 r
.74631 .55511 m
.78139 .53675 L
s
.8 1 0 r
.73648 .53643 m
.7704 .51847 L
s
1 .6 0 r
.72665 .51773 m
.75941 .50019 L
s
.75941 .50019 m
.78846 .48163 L
s
.8 1 0 r
.7704 .51847 m
.80057 .49942 L
s
.2 1 0 r
.78139 .53675 m
.81269 .51723 L
s
0 1 .4 r
.79239 .55504 m
.82482 .53505 L
s
0 1 1 r
.80339 .57334 m
.83697 .55289 L
s
0 .4 1 r
.8144 .59165 m
.84912 .57075 L
s
.2 0 1 r
.82541 .60996 m
.86129 .58863 L
s
.8 0 1 r
.83643 .62828 m
.87347 .60652 L
s
1 0 .6 r
.84745 .6466 m
.88566 .62444 L
s
1 0 0 r
.85847 .66493 m
.89786 .64237 L
s
0 g
.25 Mabswid
.61241 0 m
.97291 .505 L
s
.97291 .505 m
1 .75117 L
s
1 .75117 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.03495 .22504 m
0 .48612 L
s
0 .48612 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.61241 0 m
.03495 .22504 L
s
.03495 .22504 m
.61241 0 L
s
.03495 .22504 m
.03971 .2297 L
s
[(-2)] .02544 .21571 1 .98073 Mshowa
.16988 .17246 m
.17445 .1773 L
s
[(-1)] .16074 .16277 .9432 1 Mshowa
.31082 .11753 m
.31518 .12256 L
s
[(0)] .3021 .10747 .86675 1 Mshowa
.45818 .0601 m
.46231 .06533 L
s
[(1)] .44992 .04965 .7903 1 Mshowa
.61241 0 m
.61628 .00542 L
s
[(2)] .60467 -0.01084 .71386 1 Mshowa
.125 Mabswid
.06148 .2147 m
.06431 .21752 L
s
.08823 .20428 m
.09104 .20712 L
s
.11521 .19376 m
.118 .19663 L
s
.14243 .18316 m
.14519 .18604 L
s
.19758 .16166 m
.20029 .16459 L
s
.22551 .15078 m
.22821 .15373 L
s
.2537 .13979 m
.25637 .14277 L
s
.28213 .12871 m
.28478 .13171 L
s
.33977 .10625 m
.34236 .10929 L
s
.36897 .09487 m
.37153 .09794 L
s
.39844 .08339 m
.40097 .08648 L
s
.42817 .0718 m
.43068 .07491 L
s
.48846 .0483 m
.49091 .05146 L
s
.51902 .03639 m
.52144 .03958 L
s
.54986 .02437 m
.55225 .02758 L
s
.58099 .01224 m
.58335 .01547 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 256.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001@2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00gOooool5o`0008Kooooo003Mooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0Q_ooool00=ko
oooo00?oV9RHob4Q8Oo^k^h0Qoooool00=oooooo00?oV9RHob4Q8Oo^k^h0Q_ooool00>3ooooo00?o
MgMgofIVI_ooool0QOooool00>7ooooo00?o0000ooooooooool0Q?ooool00=gooooo00Go0000okZj
^_ooooooV9RHoa0@4026ooooo`00gOooool01OnHV9So410@o`000?lQ8B7oc<c<08Kooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003Tooooo`;o0000P_ooool0
0>7ooooo0ol000000ooooooo0000ooooo`21ooooo`00goooool2o`0000Cooooo0_l00021ooooo`00
g?ooool3o`0000Kooooo00?o0000ooooool00000P?ooool00=[ooooo0_l00009ooooo`03o`000?oo
oooo0000083ooooo003Gooooo`?o000000?oooooo`000?ooool02?ooool01?l0003oooooooooool0
001oooooo`00e?ooool3o`0000Cooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooo
oooo000007kooooo003Booooo`;o00004Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo07_ooooo002Zooooo`Co000000?o410@ooooooooool07_ooool3o`0001?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1kooooo`00[?ooool00ol0003oooooooooo`0Nooooo`;o
000000?oooooo`000?ooool04oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07[o
oooo002/ooooo`03o`000?oooooooooo01_ooooo0ol00004ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`1iooooo`00[?ooool00ol0003ooooooooo
o`0Iooooo`;o00006oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo07Wooooo002/
ooooo`03o`000?oooooooooo01Kooooo0ol0000Mooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool02?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^06_ooooo002/ooooo`03o`000?oooooo
oooo01Cooooo0_l000000ooooooo0000ooooo`0Mooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01oooool01OmgMgOoV9RHoooooonHV9SoMgMg06_ooooo002/ooooo`03o`000?oooooo
oooo017ooooo0ol00004ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`06ooooo`05oa0@4?ooooooooooooooool@4100Joooool00:[ooooo00?oEEEE
ofIVI_l000004Oooool2o`0002Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06
ooooo`05o`000?ooooooooooooooool00000Joooool00;_ooooo0ol0000Wooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000006_ooooo002i
ooooo`;o000000?oooooo`000?ooool09oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Cooooo00Go410@oooooooooooooooooa0@401[ooooo`00]_ooool3o`0000Cooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`1[ooooo`00/oooool3o`0002oooooo00?o0000ooooooooool02Oooool2
o`0000Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1[ooooo`00/Oooool2o`0003;ooooo00?o0000
ooooooooool02?ooool01?l0003oooooooooool0001dooooo`00[_ooool3o`000003ooooool0003o
oooo037ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1aooooo`00[?ooool2o`00
00Gooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
077ooooo002Yooooo`?o0000>_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo073o
oooo002Wooooo`;o0000?Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo06oooooo
002Tooooo`?o000000?oooooo`000?ooool0??ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo06oooooo002Rooooo`;o0000@_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo06kooooo001gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08oooool3o`0004Cooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1]ooooo`00Moooool01OmgMgOoV9RHoooooonHV9So
MgMg027ooooo0_l00017ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0K?ooool0
07Oooooo00Go410@oooooooooooooooooa0@400Nooooo`?o00000_ooool00ol0003oooooooooo`14
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0K?ooool007Oooooo00Go0000oooo
ooooooooooooo`00000Looooo`;o0000C?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo06_ooooo001gooooo`05o`000?ooooooooooooooool000006Oooool3o`0004kooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`1Zooooo`00Moooool01Ol@413ooooooooooooooooo
410@01Kooooo0ol0001Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0J_ooool0
07Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Dooooo`;o00000oooool00ol0003oooooooooo`1>
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0JOooool007Oooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Aooooo`?o0000E_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo06Sooooo002;ooooo`;o0000FOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
06Sooooo0028ooooo`?o0000Foooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo06Oo
oooo0026ooooo`;o00000oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo01Gooooo
0_l0001Xooooo`00Poooool3o`00063ooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`1Uooooo`00POooool2o`0006?ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1U
ooooo`00O_ooool4o`0006Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`1Toooo
o`00O?ooool2o`0000Cooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo06?ooooo001iooooo`?o0000J_ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo06?ooooo001gooooo`;o0000KOooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo06;ooooo001dooooo`?o000000?oooooo`000?ooool0K?ooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo067ooooo001aooooo`?o0000L_ooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo063ooooo0019ooooo`Co000000?o410@ooooooooool07oooool2o`0007Go
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1Pooooo`00Boooool00ol0003ooooo
ooooo`0Nooooo`?o0000Moooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo05oooooo
0010ooooo`Ko00001Oooool00ol0003oooooooooo`0Looooo`;o00000_ooool00ol0003ooooooooo
o`1eooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0G_ooool004_ooooo00?o0000
ooooooooool06Oooool3o`0007cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1N
ooooo`00Boooool00ol0003oooooooooo`0Gooooo`;o0000Ooooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo05gooooo001;ooooo`03o`000?oooooooooo01Cooooo0ol00021ooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0G?ooool004_ooooo00?o0000ooooooooool0
4_ooool2o`0000?ooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo05_ooooo0019ooooo`03oeEEEOmVIVKo0000017ooooo0ol00026ooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool0Foooool005_ooooo0_l00029ooooo`03o`000?oooooo
oooo027ooooo0_l0001Looooo`00F?ooool3o`000003ooooool0003ooooo08Sooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`1Iooooo`00E_ooool2o`0008kooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`1Iooooo`00Doooool3o`00093ooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`1Hooooo`00D?ooool3o`0009?ooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1Gooooo`00C_ooool2o`0000;ooooo00?o0000ooooooooool0TOooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo05Kooooo001;ooooo`?o00001Oooool00ol0
003oooooooooo`2@ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0E_ooool004Wo
oooo0_l0002Kooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0EOooool004Kooooo
1?l0002Looooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0E?ooool004Cooooo0_l0
002Pooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0E?ooool001[ooooo1Ol0000R
ooooo`?o0000X_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo05?ooooo000Joooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@08?ooool2o`000:Gooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`1Booooo`004_ooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h07_ooool3o`00
0003ooooool0003ooooo0:Cooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`1Aoooo
o`007?ooool00onHV9So8B4Qonk^kP0Kooooo`;o0000Z_ooool00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo057ooooo000Mooooo`03ogMgMomVIVKooooo01Oooooo0ol0002]ooooo`03o`00
0?oooooooooo02_ooooo00?o0000ooooooooool0D?ooool001kooooo00?o0000ooooooooool05?oo
ool2o`000;3ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`1?ooooo`006_ooool0
1Ol0003o^[ZjoooooonHV9So410@01?ooooo0ol00002ooooo`03o`000?oooooooooo0:gooooo00?o
0000ooooooooool0;?ooool2o`00053ooooo000Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`04?oo
ool3o`000;Gooooo00?o0000ooooooooool0;?ooool2o`00053ooooo000]ooooo`;o0000^?ooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo04gooooo000Zooooo`?o000000?oooooo`00
0?ooool0]oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo04gooooo000Xooooo`;o
0000_Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo04cooooo000Uooooo`?o0000
_oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo04_ooooo000Tooooo`;o0000`Ooo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo04[ooooo000Jooooo`Co000000?o410@
ooooooooool00oooool00ol0003oooooo`000030ooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool0B_ooool001cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0002o
ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0BOooool0017ooooo1_l00005oooo
o`03o`000?oooooooooo00Gooooo0_l00002ooooo`03o`000?oooooooooo0;cooooo00?o0000oooo
ooooool0<oooool00ol0003oooooooooo`18ooooo`007?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0^oooool00ol0003oooooooooo`0cooooo`03
o`000?oooooooooo00Oooooo1Ol0000looooo`007?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo00Kooooo00GoV9RHob4Q8Oo^k^koooooodA4A00looooo`007?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00ol0003ooooo
ooooo`0eooooo`03o`000?oooooooooo00Kooooo00?oV9RHob4Q8Oo^k^h0?Oooool001cooooo00?o
0000ooooooooool01?ooool3o`0000Kooooo00?o0000ooooooooool0^?ooool00ol0003ooooooooo
o`0fooooo`03o`000?oooooooooo00Kooooo00?oV9RHob4Q8Oo^k^h0??ooool001[ooooo00?oEEEE
ofIVI_l000001_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;Oooooo00?o0000
ooooooooool0=_ooool00ol0003oooooooooo`07ooooo`03ogMgMomVIVKooooo03_ooooo000Soooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0]_ooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0>_ooool002?ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`2eooooo`03o`000?oooooooooo03Oooooo0_l00004ooooo`05
o`000?nj^[[ooooooiRHV?l@4100??ooool002?ooooo0_l0000;ooooo`03o`000?oooooooooo0;Co
oooo00?o0000ooooooooool0=_ooool00ol0003oooooo`000004ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`0??ooool002?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`2cooooo`03
o`000?oooooooooo03Wooooo00?o0000ooooooooool0@_ooool002;ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0
@Oooool002;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`2`ooooo`;o0000?Ooo
ool00ol0003oooooooooo`10ooooo`008_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo0:cooooo0ol000000ooooooo0000ooooo`0looooo`03o`000?oooooooooo043ooooo000Roooo
o`;o00004Oooool00ol0003oooooooooo`2Xooooo`?o00001Oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo03oooooo000Rooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool0Y?ooool3o`0000Wooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0nooooo`00
8_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo0:3ooooo0ol0000=ooooo`03o`00
0?oooooooooo03[ooooo00?o0000ooooooooool0?_ooool002;ooooo0ol0000Cooooo`03o`000?oo
oooooooo09cooooo0ol0000Aooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0?Ooo
ool002;ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`2Iooooo`;o00005?ooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo03cooooo000Qooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool0UOooool3o`0001Oooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`0kooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo097ooooo0ol0000Kooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0>oooool0
00Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0SOooool3o`0001oooooo00?o0000
ooooooooool0>_ooool00ol0003oooooooooo`0jooooo`001Ol00002ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`02ooooo`;o00006_ooool00ol0003oooooooooo`29
ooooo`?o00008oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03Wooooo0007oooo
o`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool0Q_ooool2o`0002Kooooo00?o0000ooooooooool0>_ooool2
o`0003[ooooo0007ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`22ooooo`?o0000:Ooo
ool00ol0003oooooooooo`0iooooo`;o0000>_ooool000Oooooo00Go410@oooooooooooooooooa0@
400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`1nooooo`?o0000;Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03Oooooo0007
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`;o00007_oo
ool00ol0003oooooooooo`1jooooo`?o0000<Oooool00ol0003oooooooooo`0iooooo`03o`000?oo
oooooooo03Oooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Cooooo0_l0
000Pooooo`03o`000?oooooooooo07Kooooo0ol0000eooooo`03o`000?oooooooooo03Wooooo00?o
0000ooooooooool0=_ooool0023ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1b
ooooo`?o0000>?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03Gooooo000Poooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool0Koooool2o`0003cooooo00?o0000oooo
ooooool0>_ooool00ol0003oooooooooo`0dooooo`008?ooool2o`0002?ooooo00?o0000oooooooo
ool0Joooool3o`0003oooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0dooooo`00
8?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo06Oooooo0ol00013ooooo`03o`00
0?oooooooooo03Wooooo00?o0000ooooooooool0<oooool0023ooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`1Sooooo`?o0000Aoooool00ol0003oooooooooo`0iooooo`03o`000?oo
oooooooo03;ooooo000Pooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0Goooool3
o`0004[ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0booooo`008?ooool00ol0
003oooooooooo`0Vooooo`;o0000GOooool2o`0004kooooo00?o0000ooooooooool0>Oooool00ol0
003oooooooooo`0aooooo`007oooool3o`0002Wooooo00?o0000ooooooooool0Eoooool3o`00057o
oooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0`ooooo`007oooool00ol0003ooooo
ooooo`0Zooooo`03o`000?oooooooooo05?ooooo0ol0001Eooooo`03o`000?oooooooooo03Wooooo
00?o0000ooooooooool0;oooool001oooooo00?o0000ooooooooool0:oooool00ol0003ooooooooo
o`1?ooooo`?o0000F?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02oooooo000O
ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0Boooool3o`0005cooooo00?o0000
ooooooooool0>?ooool2o`00033ooooo000Oooooo`?o0000;Oooool00ol0003oooooooooo`17oooo
o`?o0000H?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02gooooo000Oooooo`03
o`000?oooooooooo02kooooo00?o0000ooooooooool0A?ooool2o`0006Cooooo00?o0000oooooooo
ool0>?ooool00ol0003oooooooooo`0]ooooo`005?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Ko
oooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`10ooooo`?o0000Ioooool00ol0003o
ooooooooo`0hooooo`03o`000?oooooooooo02cooooo000Dooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo03cooooo0ol0001Zooooo`03
o`000?oooooooooo03Wooooo00?o0000ooooooooool0:oooool001Cooooo00Go410@oooooooooooo
oooooa0@4005ooooo`;o0000<oooool00ol0003oooooooooo`0hooooo`?o0000K_ooool00ol0003o
ooooooooo`0iooooo`03o`000?oooooooooo02[ooooo000Dooooo`05o`000?ooooooooooooooool0
00001Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo03Cooooo0ol0001booooo`03
o`000?oooooooooo03Sooooo00?o0000ooooooooool0:_ooool001Cooooo00Go0000oooooooooooo
ooooo`000005ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0<?ooool3o`0007Ko
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Yooooo`005?ooool01Ol@413ooooo
oooooooooooo410@00Gooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0]ooooo`;o
0000N_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02Sooooo000Dooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo02Wo
oooo0ol0001looooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0:?ooool001Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o0000>?ooool00ol0003oooooooooo`0Uooooo`?o
0000P?ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02Oooooo000Nooooo`03o`00
0?oooooooooo03Sooooo00?o0000ooooooooool08Oooool3o`0008Cooooo00?o0000ooooooooool0
>?ooool00ol0003oooooooooo`0Vooooo`007Oooool00ol0003oooooooooo`0jooooo`03o`000?oo
oooooooo01gooooo0ol00028ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool09Ooo
ool001gooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Jooooo`;o0000S?ooool0
0ol0003oooooooooo`0gooooo`03o`000?oooooooooo02Gooooo000Mooooo`;o0000?Oooool00ol0
003oooooooooo`0Fooooo`?o0000S_ooool00ol0003oooooooooo`0gooooo`;o00009_ooool001go
oooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Booooo`?o0000T_ooool00ol0003o
ooooooooo`0hooooo`03o`000?oooooooooo02?ooooo000Mooooo`03o`000?oooooooooo03kooooo
00?o0000ooooooooool03_ooool3o`0009Kooooo00?o0000ooooooooool0=oooool00ol0003ooooo
ooooo`0Sooooo`007Oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00[ooooo0ol0
002Jooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool08_ooool001gooooo00?o0000
ooooooooool0@?ooool00ol0003oooooooooo`06ooooo`?o0000W_ooool00ol0003oooooooooo`0g
ooooo`03o`000?oooooooooo027ooooo000Looooo`?o0000@_ooool00ol0003oooooooooo`03oooo
o`;o0000XOooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo023ooooo000Looooo`03
o`000?oooooooooo04?ooooo00?o0000ooooool000000_l0002Tooooo`03o`000?oooooooooo03Oo
oooo00?o0000ooooooooool08?ooool001cooooo00?o0000ooooooooool0@_ooool3o`000:Sooooo
00?o0000ooooooooool0=oooool00ol0003oooooooooo`09ooooo`;o000000?o410@ooooooooool0
4Oooool001cooooo00?o0000ooooooooool0?oooool3o`0000?ooooo00?o0000ooooooooool0Y_oo
ool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04_oo
ool001cooooo0ol0000looooo`?o00001oooool00ol0003oooooooooo`2Vooooo`03o`000?oooooo
oooo03Kooooo00?o0000ooooooooool01_ooool5o`0001?ooooo000Looooo`03o`000?oooooooooo
03Wooooo0ol0000;ooooo`03o`000?oooooooooo0:Gooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`05ooooo`04odA4A?oMgMgoooooo`0001Cooooo00001_ooooook^k^oc8b<_l0003o
<S8bonk^kPGooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooo
ooooo`0gooooo`;o00003oooool00ol0003oooooooooo`2Uooooo`03o`000?oooooooooo03Oooooo
00?o0000ooooooooool01?ooool01?oMgMgoEEEEooooool0000Dooooo`0000KoooooogMgMonHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
03Cooooo0ol0000Booooo`03o`000?oooooooooo0:Gooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`05ooooo`03ogMgMoo<c<co000001Cooooo00000ooooooo410@ooooo`02ooooo`03
oa0@4?oooooooooo00kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0aooooo`?o
00005_ooool00ol0003oooooooooo`2Uooooo`03o`000?oooooooooo03Kooooo0_l00005ooooo`03
onk^k_m4A4Co000001Cooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00gooooo
00?oMgMgoc8b<_ooool00oooool2o`00033ooooo0ol0000Jooooo`03o`000?oooooooooo0:Gooooo
00?o0000ooooooooool0=?ooool00ol0003oooooo`000006ooooo`03ogMgMol0003ooooo01?ooooo
00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00[ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c004ooooo`03o`000?oooooooooo02cooooo0ol0000Nooooo`03o`000?oooooooooo0:Cooooo
00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Iooooo`0000?ooooooa0@4?ooool00_oo
ool00ol@413oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0:_oo
ool2o`0002;ooooo00?o0000ooooooooool0Y?ooool00ol0003oooooooooo`0fooooo`03o`000?oo
oooooooo01Wooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`cooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Wooooo`?o00009Oooool2o`000:Gooooo00?o0000ooooooooool0
=_ooool00ol0003oooooooooo`0Hooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h<ooooo`Co
00001Oooool2o`0002Gooooo0ol0000Zooooo`03o`000?oooooooooo0:?ooooo00?o0000oooooooo
ool0=_ooool00ol0003oooooooooo`0Gooooo`006oooool00ol0003oooooooooo`0Qooooo`?o0000
;_ooool00ol0003oooooooooo`2Sooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0
5oooool001_ooooo00?o0000ooooooooool07_ooool3o`0003;ooooo00?o0000ooooooooool0X_oo
ool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo01Kooooo000Kooooo`03o`000?oooooo
oooo01_ooooo0ol0000fooooo`03o`000?oooooooooo0:;ooooo00?o0000ooooooooool0=_ooool0
0ol0003oooooooooo`0Eooooo`006_ooool00ol0003oooooooooo`0Jooooo`;o0000>_ooool00ol0
003oooooooooo`2Rooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool05?ooool001[o
oooo0_l0000Hooooo`?o0000?Oooool00ol0003oooooooooo`2Rooooo`03o`000?oooooooooo03Go
oooo00?o0000ooooooooool05?ooool001[ooooo00?o0000ooooooooool05?ooool3o`00047ooooo
00?o0000ooooooooool0XOooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo01?ooooo
000Jooooo`03o`000?oooooooooo017ooooo0ol00015ooooo`03o`000?oooooooooo0:7ooooo00?o
0000ooooooooool0=_ooool00ol0003oooooooooo`0Booooo`006_ooool00ol0003oooooooooo`0>
ooooo`?o0000BOooool00ol0003oooooooooo`2Qooooo`03o`000?oooooooooo03Gooooo0_l0000C
ooooo`006_ooool00ol0003oooooooooo`0<ooooo`;o0000COooool00ol0003oooooooooo`2Qoooo
o`03o`000?oooooooooo03Cooooo0_l0000Cooooo`006Oooool3o`0000[ooooo0ol0001@ooooo`03
o`000?oooooooooo0:7ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0@ooooo`00
6_ooool00ol0003oooooooooo`06ooooo`?o0000E?ooool00ol0003oooooooooo`2Pooooo`03o`00
0?oooooooooo03Kooooo00?o0000ooooooooool03oooool001Wooooo00?o0000ooooooooool01?oo
ool3o`0005Sooooo00?o0000ooooooooool0X?ooool00ol0003oooooooooo`0eooooo`03o`000?oo
oooooooo00oooooo000Iooooo`04o`000?ooooooooooooooo`?o0000G?ooool00ol0003ooooooooo
o`2Pooooo`03o`000?ooV@3ooooo03Gooooo00?o0000ooooooooool03_ooool001Wooooo1?l0001P
ooooo`03o`000?oooooooooo09gooooo0_ooV@000ooooooo0000ooooo`0fooooo`03o`000?oooooo
oooo00gooooo000Iooooo`;o0000Hoooool00ol0003oooooooooo`2Kooooo`03oonI0?oooooooooo
00;ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0=ooooo`003oooool4o`000003
oa0@4?oooooooooo00Gooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`2Hooooo`;o
oiT01Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00cooooo000Aooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`2Eooooo`;ooiT0
2?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00_ooooo000Aooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`2Cooooo`03oonI0?oo
oooooooo00Wooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0:ooooo`004Oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0T?ooool2
oonI00cooooo00?oc?l0o`000?ooool0=Oooool00ol0003oooooooooo`0:ooooo`004Oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0SOooool2oonI
00cooooo0_o<o`02ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool02Oooool0017o
oooo00?o0000ooooooooool03?ooool2o`0006;ooooo00?o0000ooooooooool0R_ooool2oonI00go
oooo00?oc?l0ooooooooool00_ooool00ol0003oooooooooo`0cooooo`?o00002_ooool0017ooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo08Sooooo
00?ooiT0ooooooooool02oooool2olco00Kooooo00?o0000ooooooooool0;oooool3o`0000;ooooo
00?o0000ooooooooool02?ooool000oooooo00?oEEEEofIVI_l000004Oooool00ol0003ooooooooo
o`1Pooooo`03o`000?oooooooooo08Gooooo0_ooV@0<ooooo`;oc?l02Oooool00ol0003ooooooooo
o`0[ooooo`?o00001Oooool00ol0003oooooooooo`08ooooo`009?ooool00ol0003oooooooooo`1P
ooooo`03o`000?oooooooooo08;ooooo0_ooV@0=ooooo`03olco0?oooooooooo00[ooooo00?o0000
ooooooooool09_ooool4o`0000Sooooo00?o0000ooooooooool02?ooool002Gooooo00?o0000oooo
ooooool0H?ooool00ol0003oooooooooo`1oooooo`;ooiT03Oooool2olco00cooooo0_lco`000ol0
003oooooooooo`0Rooooo`?o00003?ooool00ol0003oooooooooo`08ooooo`009_ooool00ol0003o
ooooooooo`1Pooooo`03o`000?oooooooooo07cooooo0_ooV@0=ooooo`;oc?l03Oooool01?lco`3o
ooooooooool0000Qooooo`?o00004?ooool00ol0003oooooooooo`07ooooo`009oooool00ol0003o
ooooooooo`1Pooooo`03o`000?oooooooooo07Wooooo0_ooV@0=ooooo`;oc?l03Oooool2oc?o00Co
oooo00?o0000ooooooooool06_ooool4o`0001?ooooo00?o0000ooooooooool01oooool002Sooooo
0_l0001Qooooo`03o`000?oooooooooo07Kooooo0_ooV@0>ooooo`03olco0?oooooooooo00cooooo
00?o<ol0ooooooooool01Oooool00ol0003oooooooooo`0Fooooo`?o00005oooool00ol0003ooooo
ooooo`07ooooo`00:_ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo07?ooooo0_oo
V@0>ooooo`;oc?l03_ooool00olco`3oooooooooo`07ooooo`03o`000?oooooooooo01;ooooo0ol0
000Jooooo`03o`000?oooooooooo00Oooooo000[ooooo`03o`000?oooooooooo05oooooo00?o0000
ooooooooool0L?ooool2oonI00kooooo0_o<o`0>ooooo`;o<ol02oooool00ol0003oooooooooo`0=
ooooo`Co00007Oooool00ol0003oooooooooo`07ooooo`00;?ooool00ol0003oooooooooo`1Ooooo
o`03o`000?oooooooooo06gooooo0_ooV@0>ooooo`;oc?l03oooool00olco`3oooooooooo`09oooo
o`;o0?mV00?o0000ooooooooool02_ooool3o`00027ooooo00?o0000ooooooooool01oooool002go
oooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`1Yooooo`?ooiT03_ooool2olco00oo
oooo0_lco`0;ooooo`05o`3oI_ooooooooooooooool000002?ooool3o`0002Cooooo00?o0000oooo
ooooool01oooool002kooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`1Uooooo`?o
oiT03oooool2olco00oooooo0_lco`0;ooooo`;o0?mV1Oooool01?l0003oooooooooooooool4o`00
02Oooooo00?o0000ooooooooool01oooool002oooooo0_l0001Pooooo`03o`000?oooooooooo067o
oooo0oooV@0?ooooo`?oc?l03oooool2oc?o00_ooooo0_l0ofH8ooooo`?o0000;?ooool00ol0003o
ooooooooo`06ooooo`00<Oooool00ol0003oooooooooo`1Nooooo`;o0000GOooool4oonI013ooooo
0_o<o`0@ooooo`;o<ol03?ooool00ol0ofKoooooooooo`05ooooo`?o000000?oooooo`000?ooool0
;?ooool00ol0003oooooooooo`06ooooo`00<_ooool00ol0003oooooooooo`1Oooooo`03o`000?oo
oooooooo05Oooooo0oooV@0Booooo`;oc?l04?ooool2oc?o00cooooo0_l0ofH5ooooo`?o00001?oo
ool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo00Kooooo000cooooo`03o`000?oooooo
oooo05oooooo00?o0000ooooooooool0Doooool3oonI01?ooooo0_o<o`0@ooooo`;o<ol03Oooool0
1?l0ofKoooooooooooooool4o`0000Gooooo0_l0ool00ooooooo0000ooooo`0[ooooo`03o`000?oo
oooooooo00Kooooo000dooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool0Coooool3
oonI01?ooooo0oo<o`0@ooooo`;o<ol03Oooool2o`3oIP04ooooool0003o0000o`0000Sooooo00?o
0?ooooooooooool00_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo00Kooooo000e
ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool0B_ooool4oonI01?ooooo0oo<o`0@
ooooo`?o<ol03Oooool2o`3oIP?o00002Oooool2o`3oo`Kooooo00?o0000ooooooooool0:?ooool0
0ol0003oooooooooo`06ooooo`00=_ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo
04Cooooo1OooV@0Eooooo`;oc?l04?ooool3oc?o00kooooo0_l0ofH2o`0000[ooooo0_l0ool9oooo
o`03o`000?oooooooooo02Oooooo00?o0000ooooooooool01_ooool003Oooooo0_l0001Pooooo`03
o`000?oooooooooo03oooooo1?ooV@0Gooooo`?oc?l04?ooool2oc?o00kooooo00?o0000o`3oI_l0
ofH03Oooool00ol0ooooooooooooo`09ooooo`03o`000?oooooooooo02Oooooo00?o0000oooooooo
ool01_ooool003Wooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0jooooo`CooiT0
6?ooool3olco013ooooo0olco`0=ooooo`;o00000_l0ofH=ooooo`;o0?oo3Oooool00ol0003ooooo
ooooo`0Wooooo`03o`000?oooooooooo00Gooooo000jooooo`03o`000?oooooooooo05kooooo00?o
0000ooooooooool0=?ooool5oonI01Wooooo0oo<o`0Aooooo`;o<ol03?ooool4o`0000;o0?mV3_oo
ool00ol0ooooooooooooo`0:ooooo`;o06Ko0_ooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo00Gooooo000kooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0;_ooool5
oonI01_ooooo0oo<o`0Aooooo`?o<ol02oooool3o`0000;ooooo0_l0ofH>ooooo`;o0?oo3?ooool0
0ol0I_ooooooooooo`03ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool01Oooool0
03cooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`0Xooooo`GooiT07Oooool3olco
017ooooo0olco`0;ooooo`?o00000oooool2o`3oIPkooooo0_l0ool<ooooo`;o06Ko1_ooool00ol0
003oooooooooo`0Uooooo`03o`000?oooooooooo00Gooooo000mooooo`03o`000?oooooooooo05ko
oooo00?o0000ooooooooool08?ooool7oonI01kooooo1?o<o`0Booooo`;o<ol02_ooool4o`0000Co
oooo0_l0ofH>ooooo`;o0?oo3?ooool2o`1Vo`Wooooo00?o0000ooooooooool09?ooool00ol0003o
ooooooooo`05ooooo`00?_ooool2o`0005oooooo00?o0000ooooooooool05Oooool:oonI023ooooo
1Oo<o`0Cooooo`?o<ol02Oooool3o`0000Gooooo0ol0ofH=ooooo`?o0?oo3Oooool00ol0I_oooooo
ooooo`0:ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool01Oooool0043ooooo00?o
0000ooooooooool0GOooool00ol0003oooooooooo`0=ooooo`OooiT09Oooool5olco01Gooooo0olc
o`09ooooo`?o00001_ooool2o`3oIPkooooo0_l0ool>ooooo`;o06Ko3_ooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo00Gooooo0011ooooo`03o`000?oooooooooo05gooooo00?o0000
ooooooooool0=?ooool4olco01Oooooo0olco`08ooooo`Co00001oooool2o`3oIPkooooo0_l0ool?
ooooo`03o`1Voooooooooooo00[ooooo0_lc0?l3ooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool01Oooool004;ooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`0^oooo
o`Goc?l05oooool4oc?o00Sooooo0ol00008ooooo`?o0?mV3_ooool2o`3oo`oooooo0_l0I_l;oooo
o`;o<`3o1Oooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Gooooo0013ooooo`03
o`000?oooooooooo05gooooo00?o0000ooooooooool0:?ooool5olco01Wooooo0olco`09ooooo`?o
00002?ooool3o`3oIPoooooo0_l0ool?ooooo`;o06Ko3?ooool00olc0?ooooooooooo`06ooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool01?ooool004Cooooo00?o0000ooooooooool0
GOooool00ol0003oooooooooo`0Nooooo`Woc?l06_ooool4oc?o00Sooooo1?l00007ooooo`Co0?mV
4?ooool2o`3oo`oooooo0_l0I_l<ooooo`;o<`3o2_ooool00ol0003oooooooooo`0Pooooo`03o`00
0?oooooooooo00Cooooo0015ooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool04?oo
ool=olco023ooooo0olco`09ooooo`?o00002?ooool3o`3oIQ7ooooo0ol0ool>ooooo`?o06Ko3?oo
ool2oc<0o`gooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`04ooooo`00A_ooool2
o`0005kooooo00?o0000ooooooooool02?ooool7olco02Wooooo1?lco`09ooooo`?o00002?ooool3
o`3oIQ;ooooo0_l0ool?ooooo`;o06Ko3_ooool00olc0?ooooooooooo`0>ooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool01?ooool004Sooooo00?o0000ooooooooool0G?ooool00ol0
003oooooooooo`0dooooo`?o<ol02Oooool4o`0000Sooooo0ol0ofHCooooo`;o0?oo3oooool2o`1V
o`kooooo0_lc0?l<ooooo`;oc03o0oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
00Cooooo0019ooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool0;_ooool5oc?o00Wo
oooo0ol00009ooooo`?o0?mV5?ooool2o`3oo`oooooo0_l0I_l>ooooo`;o<`3o3?ooool2ol`0o`Ko
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`04ooooo`00B_ooool00ol0003ooooo
ooooo`1Looooo`03o`000?oooooooooo02Kooooo1olco`0;ooooo`?o00002Oooool3o`3oIQCooooo
0ol0ool>ooooo`?o06Ko3_ooool2oc<0o`gooooo00?oc03oooooooooool01oooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo00Cooooo001;ooooo`03o`000?oooooooooo05cooooo00?o
0000ooooooooool07Oooool8oc?o00kooooo1?l00009ooooo`?o0?mV5?ooool3o`3oo`oooooo0_l0
I_l?ooooo`;o<`3o3Oooool2ol`0o`_ooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`04ooooo`00C?ooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo01Gooooo1olco`0C
ooooo`?o00002_ooool3o`3oIQCooooo0ol0ool@ooooo`;o06Ko3oooool2oc<0o`gooooo0_o<0?l>
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool00oooool004gooooo0_l0001Moooo
o`03o`000?oooooooooo00Wooooo2olco`0Gooooo`?o00002?ooool5o`3oIQCooooo0ol0ool@oooo
o`?o06Ko4?ooool00olc0?ooooooooooo`0<ooooo`03ol`0oooooooooooo00kooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`03ooooo`00Coooool00ol0003oooooooooo`1Kooooo`04
o`000?ooooooooooooooo`Oo<ol07oooool3o`0000Kooooo1Ol0ofHFooooo`?o0?oo4Oooool2o`1V
oa7ooooo0_lc0?l=ooooo`;oc03o3?ooool2ool0V@Cooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`03ooooo`00D?ooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo02;o
oooo1?l00005ooooo`Co0?mV5oooool4o`3ooa;ooooo0_l0I_lAooooo`;o<`3o3Oooool2ol`0o`co
oooo0_oo09T7ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool00oooool0057ooooo
00?o0000ooooooooool0Foooool00ol0003oooooooooo`0Nooooo`?o00001?ooool5o`3oIQSooooo
0ol0oolCooooo`?o06Ko4Oooool2oc<0o`gooooo0_o<0?l=ooooo`03ool0VOoooooooooo00Sooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`03ooooo`00D_ooool00ol0003ooooooooo
o`1Kooooo`03o`000?oooooooooo01[ooooo0ol00002ooooo`Go0?mV6Oooool4o`3ooa?ooooo0ol0
I_lAooooo`?o<`3o3Oooool2ol`0o`gooooo0_oo09T<ooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool00oooool005?ooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`0E
ooooo`;o00001ol0ofHJooooo`Co0?oo5?ooool3o`1Voa;ooooo0_lc0?l>ooooo`;oc03o3Oooool2
ool0V@kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`03ooooo`00E?ooool2o`00
05cooooo00?o0000ooooooooool03oooool7o`3oIQgooooo1?l0oolEooooo`?o06Ko4oooool2oc<0
o`kooooo0_o<0?l>ooooo`03ool0VOoooooooooo00oooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`03ooooo`00E_ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00?o
oooo2ol0ofH2o`0001oooooo0ol0oolFooooo`?o06Ko4oooool3oc<0o`kooooo0_o<0?l>ooooo`;o
o`2I3?ooool2ool000Gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`02ooooo`00
Eoooool00ol0003oooooooooo`1Hooooo`Oo0?mV1_ooool4o`0001kooooo1?l0oolFooooo`?o06Ko
5?ooool2oc<0o`oooooo0_o<0?l>ooooo`;oo`2I3?ooool2ool000Sooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`02ooooo`00F?ooool00ol0003oooooooooo`1Jooooo`03o`000?oo
oooooooo00Cooooo0ol0000Looooo`Ko0?oo5oooool3o`1VoaGooooo0_lc0?l?ooooo`;oc03o3_oo
ool2ool0V@cooooo0_oo000;ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00_oo
ool005Wooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`03o`0001Sooooo1ol0oolJ
ooooo`?o06Ko5Oooool3oc<0o`kooooo0oo<0?l>ooooo`;oo`2I3?ooool2ool000gooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`02ooooo`00F_ooool00ol0003oooooooooo`1Joooo
o`;o00004oooool8o`3ooakooooo0ol0I_lEooooo`?o<`3o3oooool2ol`0o`oooooo0_oo09T=oooo
o`03ool00?oooooooooo00kooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`02oooo
o`00Foooool00ol0003oooooooooo`1Iooooo`03o`000?oooooooooo00_ooooo1ol0oolRooooo`Co
06Ko5Oooool3oc<0oa3ooooo0_o<0?l?ooooo`;oo`2I3Oooool2ool001;ooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`02ooooo`00G?ooool2o`0005Wooooo00?o0000ooooooooool0
2ol0oolTooooo`Go06Ko5_ooool3oc<0oa3ooooo0oo<0?l?ooooo`;oo`2I3Oooool2ool001Gooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`02ooooo`00G_ooool00ol0003ooooooooo
o`1Aooooo`So0?oo:_ooool5o`1VoaOooooo1?lc0?lAooooo`;oc03o4?ooool2ool0V@gooooo0_oo
000Hooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00_ooool005oooooo00?o0000
ooooooooool0EOooool00ol0003oooooooooo`0Tooooo`Ko06Ko6?ooool4oc<0oa;ooooo0oo<0?l@
ooooo`;oo`2I3Oooool2ool001[ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`01
ooooo`00H?ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo01oooooo1Ol0I_lKoooo
o`?o<`3o4oooool3ol`0oa3ooooo0ooo09T=ooooo`;oo`007Oooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo007ooooo001Qooooo`03o`000?oooooooooo05?ooooo00?o0000oooooooo
ool06_ooool5o`1Voacooooo1?lc0?lCooooo`?oc03o4Oooool2ool0V@kooooo0_oo000Pooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool00Oooool006;ooooo00?o0000ooooooooool0
D_ooool00ol0003oooooooooo`0Cooooo`Oo06Ko7Oooool4oc<0oaCooooo0oo<0?lAooooo`?oo`2I
3_ooool2ool002?ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`01ooooo`00Hooo
ool2o`0005;ooooo00?o0000ooooooooool03?ooool7o`1Vob3ooooo1?lc0?lEooooo`?oc03o4_oo
ool2ool0V@oooooo0_oo000Vooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool00Ooo
ool006Gooooo00?o0000ooooooooool0Coooool01?l0003oooooooooooooool;o`1Vob?ooooo1?lc
0?lFooooo`?oc03o4_ooool3ool0V@oooooo0_oo000Xooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool00Oooool006Kooooo00?o0000ooooooooool0B_ooool8o`1Vob[ooooo1?lc0?lG
ooooo`?oc03o4oooool2ool0VA3ooooo0_oo000[ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool00Oooool006Oooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0Voooo
o`Go<`3o6?ooool3ol`0oa?ooooo0ooo09T@ooooo`;oo`00;_ooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo007ooooo001Xooooo`03o`000?oooooooooo04cooooo00?o0000oooooooo
ool08Oooool5oc<0oa[ooooo0oo<0?lCooooo`?oo`2I4?ooool3ool0037ooooo00?o0000oooooooo
ool02oooool1o`00007ooooo0Oooool006Wooooo00?o0000ooooooooool0Boooool00ol0003ooooo
ooooo`0Looooo`Go<`3o7?ooool3ol`0oaCooooo0_oo09TAooooo`;oo`00=?ooool00ol0003ooooo
ooooo`0;ooooo`7o00000Oooool1ooooo`00J_ooool00ol0003oooooooooo`1:ooooo`03o`000?oo
oooooooo01Gooooo1olc0?lLooooo`Goc03o5?ooool3ool0VA7ooooo0_oo000gooooo`03o`000?oo
oooooooo00[ooooo0Ol00001ooooo`7ooooo001[ooooo`;o0000B_ooool00ol0003oooooooooo`0=
ooooo`So<`3o7Oooool6ol`0oaKooooo0ooo09TAooooo`?oo`00>_ooool00ol0003oooooooooo`09
ooooo`7o00000Oooool1ooooo`00KOooool00ol0003oooooooooo`17ooooo`04o`000?oooooooooo
ooooo`co<`3o8?ooool5ol`0oaWooooo0ooo09TBooooo`;oo`00?_ooool00ol0003oooooooooo`08
ooooo`7o00000Oooool1ooooo`00K_ooool00ol0003oooooooooo`12ooooo`So<`3o9_ooool6ol`0
oa[ooooo1?oo09TBooooo`?oo`00@Oooool00ol0003oooooooooo`07ooooo`7o00000Oooool1oooo
o`00Koooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo02;ooooo1Oo<0?lLooooo`Co
o`2I4oooool3ool004Cooooo00?o0000ooooooooool01oooool1o`00007ooooo0Oooool0073ooooo
00?o0000ooooooooool0A?ooool00ol0003oooooooooo`0Mooooo`Goc03o7Oooool4ool0VACooooo
0ooo0018ooooo`03o`000?oooooooooo00Kooooo0Ol00001ooooo`7ooooo001aooooo`03o`000?oo
oooooooo04?ooooo00?o0000ooooooooool05_ooool7ol`0oakooooo1?oo09TEooooo`?oo`00C?oo
ool00ol0003oooooooooo`05ooooo`7o00000Oooool1ooooo`00L_ooool2o`0004;ooooo00?o0000
ooooooooool03oooool8ol`0ob7ooooo1?oo09TFooooo`?oo`00D?ooool00ol0003oooooooooo`05
ooooo`7o00000Oooool007Cooooo00?o0000ooooooooool0?oooool00ol0003oooooooooo`03oooo
o`coc03o9?ooool5ool0VAKooooo1?oo001Dooooo`03o`000?oooooooooo00Cooooo0Ol00001oooo
o`00MOooool00ol0003oooooooooo`0kooooo`Woc03o;?ooool4ool0VASooooo0ooo001Hooooo`03
o`000?oooooooooo00Cooooo0Ol00001ooooo`00M_ooool00ol0003oooooooooo`0mooooo`03o`00
0?oooooooooo02[ooooo1Ooo09TIooooo`?oo`00G?ooool00ol0003oooooooooo`03ooooo`7o0000
0Oooool007Oooooo00?o0000ooooooooool0??ooool00ol0003oooooooooo`0Tooooo`Koo`2I6ooo
ool3ool0063ooooo00?o0000ooooooooool00_ooool1o`00007ooooo001hooooo`03o`000?oooooo
oooo03_ooooo00?o0000ooooooooool07oooool5ool0VAkooooo0ooo001Tooooo`05o`000?oooooo
ooooooooool000000Oooool007Wooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0H
ooooo`Ooo`2I7_ooool5ool006Sooooo00Co0000oooooooooooo00000Oooool007[ooooo0_l0000j
ooooo`03o`000?oooooooooo00oooooo2Ooo09TOooooo`Koo`00KOooool01?l0003oooooooooool0
0001ooooo`00O?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00?ooooo3?oo09TS
ooooo`Goo`00M?ooool00ol0003oooooooooo`01o`000000OOooool00ol0003oooooooooo`0doooo
o`Soo`2I:Oooool6ool007[ooooo0Ol00001ooooo`7o0000001nooooo`03o`000?oooooooooo03Go
oooo00?o0000ooooooooool09_ooool6ool0087ooooo0_l0000007oooooo00?o0000ooooooooool0
=?ooool00ol0003oooooooooo`0Qooooo`Goo`00Q_ooool3o`000000P?ooool00ol0003ooooooooo
o`0cooooo`03o`000?oooooooooo01[ooooo1ooo0027ooooo`Co00000oooool0087ooooo0_l0000c
ooooo`03o`000?oooooooooo017ooooo2Ooo002;ooooo`?o00001oooool008?ooooo00?o0000oooo
ooooool0<?ooool00ol0003oooooooooo`08ooooo`Woo`00T?ooool4o`0000[ooooo0024ooooo`03
o`000?oooooooooo02oooooo00?o0000oooooooo00002?oo002Eooooo`Co00003_ooool008Gooooo
00?o0000ooooooooool0;?ooool4ool009[ooooo1?l0000Booooo`00Q_ooool00ol0003ooooooooo
o`0]ooooo`03o`000?oooooooooo09Gooooo1?l0000Fooooo`00Qoooool00ol0003oooooooooo`0/
ooooo`03o`000?oooooooooo09;ooooo0ol0000Jooooo`00R?ooool2o`0002cooooo00?o0000oooo
ooooool0S_ooool4o`0001gooooo002:ooooo`03o`000?oooooooooo02Wooooo00?o0000oooooooo
ool0R_ooool4o`00027ooooo002;ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0
Q_ooool4o`0002Gooooo002<ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0P_oo
ool4o`0002Wooooo002=ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0Ooooool3
o`0002gooooo002>ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0Noooool4o`00
033ooooo002?ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0Moooool4o`0003Co
oooo002@ooooo`;o00009?ooool00ol0003oooooooooo`1cooooo`Co0000>?ooool009;ooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`1`ooooo`?o0000??ooool009?ooooo00?o0000
ooooooooool08?ooool00ol0003oooooooooo`1/ooooo`Co0000?oooool009Cooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`1Xooooo`Co0000@oooool009Gooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`1Tooooo`Co0000Aoooool009Kooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`1Pooooo`Co0000Boooool009Oooooo0_l0000Mooooo`03o`000?oo
oooooooo05gooooo0ol0001?ooooo`00VOooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo05Wooooo1?l0001Booooo`00V_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
05Gooooo1?l0001Fooooo`00Voooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo057o
oooo1?l0001Jooooo`00W?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04gooooo
1?l0001Nooooo`00WOooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04[ooooo0ol0
001Rooooo`00W_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04Kooooo1?l0001U
ooooo`00Woooool2o`0001Cooooo00?o0000ooooooooool0@oooool4o`0006Wooooo002Qooooo`03
o`000?oooooooooo017ooooo00?o0000ooooooooool0?oooool4o`0006gooooo002Rooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool0>oooool4o`00077ooooo002Sooooo`03o`000?oo
oooooooo00oooooo00?o0000ooooooooool0>?ooool3o`0007Gooooo002Tooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool0=?ooool4o`0007Sooooo002Uooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool0<?ooool4o`0007cooooo002Vooooo`;o00003Oooool00ol0003o
ooooooooo`0/ooooo`Co0000P?ooool00:Sooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0Yooooo`?o0000Q?ooool00:Wooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0Uooooo`Co0000Qoooool00:[ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Q
ooooo`Co0000Roooool00:_ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Moooo
o`Co0000Soooool00:cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Iooooo`Co
0000Toooool00:gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Fooooo`?o0000
Uoooool00:kooooo0_l00005ooooo`03o`000?oooooooooo01;ooooo1?l0002Jooooo`00/?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00kooooo1?l0002Nooooo`00/Oooool01Ol0
003ooooooooooooooooo000000cooooo1?l0002Rooooo`00/_ooool01?l0003oooooooooool00008
ooooo`Co0000Y_ooool00;?ooooo00?o0000ooooool000001Oooool3o`000:[ooooo002dooooo`;o
000000?oooooo`000?l000000_l0002]ooooo`00]Oooool2o`000;7ooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {319.688, 0}} -> {-0.0710364, -0.0181728, \
0.0035149, 0.0035149}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .89104 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-16 1.0656 -0.0363427 1.0656 [
[.02544 .21571 -12 -8.9133 ]
[.02544 .21571 0 .0867 ]
[.16074 .16277 -11.6592 -9 ]
[.16074 .16277 .34081 0 ]
[.3021 .10747 -5.60025 -9 ]
[.3021 .10747 .39975 0 ]
[.44992 .04965 -5.37091 -9 ]
[.44992 .04965 .62909 0 ]
[.60467 -0.01084 -5.14157 -9 ]
[.60467 -0.01084 .85843 0 ]
[.66454 .05085 0 -6.20675 ]
[.66454 .05085 6 2.79325 ]
[.80797 .25198 0 -6.0417 ]
[.80797 .25198 6 2.9583 ]
[.93071 .4241 0 -5.90576 ]
[.93071 .4241 6 3.09424 ]
[.02254 .22988 -12 -2.74631 ]
[.02254 .22988 0 6.25369 ]
[.0142 .29178 -24 -2.78907 ]
[.0142 .29178 0 6.21093 ]
[.00558 .35578 -6 -2.83339 ]
[.00558 .35578 0 6.16661 ]
[-0.00334 .42198 -18 -2.87938 ]
[-0.00334 .42198 0 6.12062 ]
[-0.01257 .49051 -6 -2.92712 ]
[-0.01257 .49051 0 6.07288 ]
[ 0 0 0 0 ]
[ 1 .89104 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03495 .22504 m
.61241 0 L
s
.03495 .22504 m
.03971 .2297 L
s
[(-2)] .02544 .21571 1 .98073 Mshowa
.16988 .17246 m
.17445 .1773 L
s
[(-1)] .16074 .16277 .9432 1 Mshowa
.31082 .11753 m
.31518 .12256 L
s
[(0)] .3021 .10747 .86675 1 Mshowa
.45818 .0601 m
.46231 .06533 L
s
[(1)] .44992 .04965 .7903 1 Mshowa
.61241 0 m
.61628 .00542 L
s
[(2)] .60467 -0.01084 .71386 1 Mshowa
.125 Mabswid
.06148 .2147 m
.06431 .21752 L
s
.08823 .20428 m
.09104 .20712 L
s
.11521 .19376 m
.118 .19663 L
s
.14243 .18316 m
.14519 .18604 L
s
.19758 .16166 m
.20029 .16459 L
s
.22551 .15078 m
.22821 .15373 L
s
.2537 .13979 m
.25637 .14277 L
s
.28213 .12871 m
.28478 .13171 L
s
.33977 .10625 m
.34236 .10929 L
s
.36897 .09487 m
.37153 .09794 L
s
.39844 .08339 m
.40097 .08648 L
s
.42817 .0718 m
.43068 .07491 L
s
.48846 .0483 m
.49091 .05146 L
s
.51902 .03639 m
.52144 .03958 L
s
.54986 .02437 m
.55225 .02758 L
s
.58099 .01224 m
.58335 .01547 L
s
.25 Mabswid
.61241 0 m
.97291 .505 L
s
.65208 .05558 m
.64586 .05794 L
s
[(0)] .66454 .05085 -1 .37928 Mshowa
.79537 .2563 m
.78907 .25846 L
s
[(2)] .80797 .25198 -1 .3426 Mshowa
.91799 .42808 m
.91164 .43006 L
s
[(4)] .93071 .4241 -1 .31239 Mshowa
.125 Mabswid
.69012 .10886 m
.68637 .11025 L
s
.72662 .16 m
.72286 .16135 L
s
.76168 .2091 m
.75791 .21042 L
s
.82778 .3017 m
.82399 .30297 L
s
.85897 .3454 m
.85518 .34664 L
s
.88903 .3875 m
.88522 .38871 L
s
.94594 .46722 m
.94211 .46839 L
s
.25 Mabswid
.03495 .22504 m
0 .48612 L
s
.03495 .22504 m
.04116 .22262 L
s
[(-1)] .02254 .22988 1 -0.38971 Mshowa
.02665 .28704 m
.03288 .28468 L
s
[(-0.5)] .0142 .29178 1 -0.38021 Mshowa
.01807 .35115 m
.02431 .34884 L
s
[(0)] .00558 .35578 1 -0.37036 Mshowa
.00919 .41747 m
.01546 .41521 L
s
[(0.5)] -0.00334 .42198 1 -0.36014 Mshowa
0 .48612 m
.00629 .48392 L
s
[(1)] -0.01257 .49051 1 -0.34953 Mshowa
.125 Mabswid
.03331 .23728 m
.03704 .23583 L
s
.03166 .2496 m
.03539 .24816 L
s
.03 .262 m
.03373 .26056 L
s
.02833 .27448 m
.03207 .27305 L
s
.02496 .29969 m
.0287 .29828 L
s
.02325 .31243 m
.02699 .31102 L
s
.02154 .32525 m
.02528 .32385 L
s
.01981 .33816 m
.02355 .33676 L
s
.01632 .36423 m
.02007 .36285 L
s
.01455 .37741 m
.01831 .37603 L
s
.01278 .39067 m
.01653 .3893 L
s
.01099 .40402 m
.01475 .40266 L
s
.00738 .43101 m
.01114 .42966 L
s
.00555 .44464 m
.00932 .4433 L
s
.00371 .45837 m
.00748 .45704 L
s
.00186 .4722 m
.00563 .47087 L
s
.25 Mabswid
.03495 .22504 m
0 .48612 L
s
0 .48612 m
.46953 .89104 L
s
.46953 .89104 m
.47294 .65459 L
s
.47294 .65459 m
.03495 .22504 L
s
.61241 0 m
.97291 .505 L
s
.97291 .505 m
1 .75117 L
s
1 .75117 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.03495 .22504 m
0 .48612 L
s
0 .48612 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.61241 0 m
.03495 .22504 L
s
.47294 .65459 m
.97291 .505 L
s
.97291 .505 m
1 .75117 L
s
1 .75117 m
.46953 .89104 L
s
.46953 .89104 m
.47294 .65459 L
s
0 0 m
1 0 L
1 .89104 L
0 .89104 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.46891 .77921 m
.52203 .77556 L
s
1 0 .6 r
.46763 .75964 m
.51947 .75604 L
s
1 0 0 r
.52203 .77556 m
.57627 .76912 L
s
.8 0 1 r
.46635 .74003 m
.51691 .73648 L
s
1 0 .6 r
.51947 .75604 m
.57245 .74968 L
s
.2 0 1 r
.46507 .72037 m
.51434 .71688 L
s
.8 0 1 r
.51691 .73648 m
.56863 .73021 L
s
0 .4 1 r
.46379 .70068 m
.51177 .69725 L
s
.2 0 1 r
.51434 .71688 m
.56479 .7107 L
s
0 1 1 r
.4625 .68095 m
.50919 .67757 L
s
1 0 0 r
.57627 .76912 m
.63019 .75998 L
s
0 .4 1 r
.51177 .69725 m
.56095 .69116 L
s
0 1 .4 r
.46121 .66118 m
.5066 .65786 L
s
1 0 .6 r
.57245 .74968 m
.62515 .74065 L
s
0 1 1 r
.50919 .67757 m
.55711 .67158 L
s
.8 0 1 r
.56863 .73021 m
.6201 .7213 L
s
.2 1 0 r
.45992 .64136 m
.50401 .6381 L
s
0 1 .4 r
.5066 .65786 m
.55325 .65197 L
s
.2 0 1 r
.56479 .7107 m
.61505 .70191 L
s
.8 1 0 r
.45862 .6215 m
.50142 .61831 L
s
.2 1 0 r
.50401 .6381 m
.54939 .63231 L
s
0 .4 1 r
.56095 .69116 m
.60998 .68249 L
s
1 .6 0 r
.45732 .60161 m
.49882 .59848 L
s
.8 1 0 r
.50142 .61831 m
.54552 .61263 L
s
0 1 1 r
.55711 .67158 m
.60491 .66304 L
s
1 0 0 r
.63019 .75998 m
.68309 .74825 L
s
0 1 .4 r
.55325 .65197 m
.59983 .64355 L
s
1 .6 0 r
.49882 .59848 m
.54165 .5929 L
s
1 0 .6 r
.62515 .74065 m
.67686 .72907 L
s
.2 1 0 r
.54939 .63231 m
.59475 .62404 L
s
.8 0 1 r
.6201 .7213 m
.67063 .70985 L
s
.2 0 1 r
.61505 .70191 m
.66439 .69061 L
s
.8 1 0 r
.54552 .61263 m
.58965 .6045 L
s
0 .4 1 r
.60998 .68249 m
.65814 .67135 L
s
1 .6 0 r
.54165 .5929 m
.58455 .58492 L
s
0 1 1 r
.60491 .66304 m
.65188 .65205 L
s
0 1 .4 r
.59983 .64355 m
.64562 .63274 L
s
.2 1 0 r
.59475 .62404 m
.63934 .61339 L
s
1 0 0 r
.68309 .74825 m
.73468 .734 L
s
.8 1 0 r
.58965 .6045 m
.63306 .59403 L
s
1 0 .6 r
.67686 .72907 m
.72728 .71498 L
s
1 .6 0 r
.58455 .58492 m
.62677 .57463 L
s
.8 0 1 r
.67063 .70985 m
.71988 .69594 L
s
.2 0 1 r
.66439 .69061 m
.71247 .67688 L
s
0 .4 1 r
.65814 .67135 m
.70505 .65781 L
s
0 1 1 r
.65188 .65205 m
.69763 .63871 L
s
0 1 .4 r
.64562 .63274 m
.6902 .61959 L
s
.2 1 0 r
.63934 .61339 m
.68276 .60046 L
s
.8 1 0 r
.63306 .59403 m
.67531 .5813 L
s
1 .6 0 r
.62677 .57463 m
.66786 .56213 L
s
1 0 0 r
.73468 .734 m
.78475 .71721 L
s
1 0 .6 r
.72728 .71498 m
.77618 .69839 L
s
.8 0 1 r
.71988 .69594 m
.76761 .67957 L
s
.2 0 1 r
.71247 .67688 m
.75903 .66074 L
s
0 .4 1 r
.70505 .65781 m
.75045 .64189 L
s
0 1 1 r
.69763 .63871 m
.74186 .62303 L
s
0 1 .4 r
.6902 .61959 m
.73326 .60416 L
s
.2 1 0 r
.68276 .60046 m
.72466 .58528 L
s
.8 1 0 r
.67531 .5813 m
.71606 .56639 L
s
1 .6 0 r
.66786 .56213 m
.70744 .54749 L
s
1 0 0 r
.78475 .71721 m
.83293 .69787 L
s
1 0 .6 r
.77618 .69839 m
.82317 .67932 L
s
.8 0 1 r
.76761 .67957 m
.81341 .66077 L
s
.2 0 1 r
.75903 .66074 m
.80364 .64221 L
s
0 .4 1 r
.75045 .64189 m
.79388 .62365 L
s
0 1 1 r
.74186 .62303 m
.78411 .60509 L
s
0 1 .4 r
.73326 .60416 m
.77435 .58652 L
s
.2 1 0 r
.72466 .58528 m
.76458 .56795 L
s
.8 1 0 r
.71606 .56639 m
.75481 .54938 L
s
1 .6 0 r
.70744 .54749 m
.74503 .5308 L
s
1 0 0 r
.83293 .69787 m
.87842 .67616 L
s
1 0 .6 r
.82317 .67932 m
.86745 .65793 L
s
.8 0 1 r
.81341 .66077 m
.85649 .63971 L
s
.2 0 1 r
.80364 .64221 m
.84554 .62149 L
s
0 .4 1 r
.79388 .62365 m
.83459 .60329 L
s
0 1 1 r
.78411 .60509 m
.82364 .58508 L
s
0 1 .4 r
.77435 .58652 m
.81269 .56689 L
s
.2 1 0 r
.76458 .56795 m
.80175 .5487 L
s
.8 1 0 r
.75481 .54938 m
.79082 .53052 L
s
1 .6 0 r
.74503 .5308 m
.77989 .51234 L
s
.77989 .51234 m
.81098 .49271 L
s
.8 1 0 r
.79082 .53052 m
.82304 .51041 L
s
.2 1 0 r
.80175 .5487 m
.83511 .52813 L
s
0 1 .4 r
.81269 .56689 m
.84719 .54587 L
s
0 1 1 r
.82364 .58508 m
.85928 .56363 L
s
0 .4 1 r
.83459 .60329 m
.87138 .5814 L
s
.2 0 1 r
.84554 .62149 m
.8835 .59919 L
s
.8 0 1 r
.85649 .63971 m
.89562 .617 L
s
1 0 .6 r
.86745 .65793 m
.90776 .63482 L
s
1 0 0 r
.87842 .67616 m
.91991 .65266 L
s
0 g
.25 Mabswid
.61241 0 m
.97291 .505 L
s
.97291 .505 m
1 .75117 L
s
1 .75117 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.03495 .22504 m
0 .48612 L
s
0 .48612 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.61241 0 m
.03495 .22504 L
s
.03495 .22504 m
.61241 0 L
s
.03495 .22504 m
.03971 .2297 L
s
[(-2)] .02544 .21571 1 .98073 Mshowa
.16988 .17246 m
.17445 .1773 L
s
[(-1)] .16074 .16277 .9432 1 Mshowa
.31082 .11753 m
.31518 .12256 L
s
[(0)] .3021 .10747 .86675 1 Mshowa
.45818 .0601 m
.46231 .06533 L
s
[(1)] .44992 .04965 .7903 1 Mshowa
.61241 0 m
.61628 .00542 L
s
[(2)] .60467 -0.01084 .71386 1 Mshowa
.125 Mabswid
.06148 .2147 m
.06431 .21752 L
s
.08823 .20428 m
.09104 .20712 L
s
.11521 .19376 m
.118 .19663 L
s
.14243 .18316 m
.14519 .18604 L
s
.19758 .16166 m
.20029 .16459 L
s
.22551 .15078 m
.22821 .15373 L
s
.2537 .13979 m
.25637 .14277 L
s
.28213 .12871 m
.28478 .13171 L
s
.33977 .10625 m
.34236 .10929 L
s
.36897 .09487 m
.37153 .09794 L
s
.39844 .08339 m
.40097 .08648 L
s
.42817 .0718 m
.43068 .07491 L
s
.48846 .0483 m
.49091 .05146 L
s
.51902 .03639 m
.52144 .03958 L
s
.54986 .02437 m
.55225 .02758 L
s
.58099 .01224 m
.58335 .01547 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 256.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001@2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00gOooool5o`0008Kooooo003Mooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0Q_ooool00=ko
oooo00?oV9RHob4Q8Oo^k^h0Qoooool00=oooooo00?oV9RHob4Q8Oo^k^h0Q_ooool00>3ooooo00?o
MgMgofIVI_ooool0QOooool00>7ooooo00?o0000ooooooooool0Q?ooool00=gooooo00Go0000okZj
^_ooooooV9RHoa0@4026ooooo`00gOooool01OnHV9So410@o`000?lQ8B7oc<c<08Kooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003Tooooo`;o0000P_ooool0
0>7ooooo0ol000000ooooooo0000ooooo`21ooooo`00goooool2o`0000Cooooo0_l00021ooooo`00
g?ooool3o`0000Kooooo00?o0000ooooool00000P?ooool00=[ooooo0_l00009ooooo`03o`000?oo
oooo0000083ooooo003Gooooo`?o000000?oooooo`000?ooool02?ooool01?l0003oooooooooool0
001oooooo`00e?ooool3o`0000Cooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooo
oooo000007kooooo003Booooo`;o00004Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo07_ooooo002Zooooo`Co000000?o410@ooooooooool07_ooool3o`0001?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1kooooo`00[?ooool00ol0003oooooooooo`0Nooooo`;o
000000?oooooo`000?ooool04oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07[o
oooo002/ooooo`03o`000?oooooooooo01_ooooo0ol00004ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`1iooooo`00[?ooool00ol0003ooooooooo
o`0Iooooo`;o00006oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo07Wooooo002/
ooooo`03o`000?oooooooooo01Kooooo0ol0000Mooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool02?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^06_ooooo002/ooooo`03o`000?oooooo
oooo01Cooooo0_l000000ooooooo0000ooooo`0Mooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01oooool01OmgMgOoV9RHoooooonHV9SoMgMg06_ooooo002/ooooo`03o`000?oooooo
oooo017ooooo0ol00004ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`06ooooo`05oa0@4?ooooooooooooooool@4100Joooool00:[ooooo00?oEEEE
ofIVI_l000004Oooool2o`0002Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06
ooooo`05o`000?ooooooooooooooool00000Joooool00;_ooooo0ol0000Wooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000006_ooooo002i
ooooo`;o000000?oooooo`000?ooool09oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Cooooo00Go410@oooooooooooooooooa0@401[ooooo`00]_ooool3o`0000Cooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`1[ooooo`00/oooool3o`0002oooooo00?o0000ooooooooool02Oooool2
o`0000Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1[ooooo`00/Oooool2o`0003;ooooo00?o0000
ooooooooool02?ooool01?l0003oooooooooool0001dooooo`00[_ooool3o`000003ooooool0003o
oooo037ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1aooooo`00[?ooool2o`00
00Gooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
077ooooo002Yooooo`?o0000>_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo073o
oooo002Wooooo`;o0000?Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo06oooooo
002Tooooo`?o000000?oooooo`000?ooool0??ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo06oooooo002Rooooo`;o0000@_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo06kooooo001gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08oooool3o`0004Cooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1]ooooo`00Moooool01OmgMgOoV9RHoooooonHV9So
MgMg027ooooo0_l00017ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0K?ooool0
07Oooooo00Go410@oooooooooooooooooa0@400Nooooo`?o00000_ooool00ol0003oooooooooo`14
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0K?ooool007Oooooo00Go0000oooo
ooooooooooooo`00000Looooo`;o0000C?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo06_ooooo001gooooo`05o`000?ooooooooooooooool000006Oooool3o`0004kooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`1Zooooo`00Moooool01Ol@413ooooooooooooooooo
410@01Kooooo0ol0001Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0J_ooool0
07Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Dooooo`;o00000oooool00ol0003oooooooooo`1>
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0JOooool007Oooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Aooooo`?o0000E_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo06Sooooo002;ooooo`;o0000FOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
06Sooooo0028ooooo`?o0000Foooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo06Oo
oooo0026ooooo`;o00000oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo01Gooooo
0_l0001Xooooo`00Poooool3o`00063ooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`1Uooooo`00POooool2o`0006?ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1U
ooooo`00O_ooool4o`0006Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`1Toooo
o`00O?ooool2o`0000Cooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo06?ooooo001iooooo`?o0000J_ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo06?ooooo001gooooo`;o0000KOooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo06;ooooo001dooooo`?o000000?oooooo`000?ooool0K?ooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo067ooooo001aooooo`?o0000L_ooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo063ooooo0019ooooo`Co000000?o410@ooooooooool07oooool2o`0007Go
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1Pooooo`00Boooool00ol0003ooooo
ooooo`0Nooooo`?o0000Moooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo05oooooo
0010ooooo`Ko00001Oooool00ol0003oooooooooo`0Looooo`;o00000_ooool00ol0003ooooooooo
o`1eooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0G_ooool004_ooooo00?o0000
ooooooooool06Oooool3o`0007cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1N
ooooo`00Boooool00ol0003oooooooooo`0Gooooo`;o0000Ooooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo05gooooo001;ooooo`03o`000?oooooooooo01Cooooo0ol00021ooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0G?ooool004_ooooo00?o0000ooooooooool0
4_ooool2o`0000?ooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo05_ooooo0019ooooo`03oeEEEOmVIVKo0000017ooooo0ol00026ooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool0Foooool005_ooooo0_l00029ooooo`03o`000?oooooo
oooo027ooooo0_l0001Looooo`00F?ooool3o`000003ooooool0003ooooo08Sooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`1Iooooo`00E_ooool2o`0008kooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`1Iooooo`00Doooool3o`00093ooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`1Hooooo`00D?ooool3o`0009?ooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1Gooooo`00C_ooool2o`0000;ooooo00?o0000ooooooooool0TOooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo05Kooooo001;ooooo`?o00001Oooool00ol0
003oooooooooo`2@ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0E_ooool004Wo
oooo0_l0002Kooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0EOooool004Kooooo
1?l0002Looooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0E?ooool004Cooooo0_l0
002Pooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0E?ooool001[ooooo1Ol0000R
ooooo`?o0000X_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo05?ooooo000Joooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@08?ooool2o`000:Gooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`1Booooo`004_ooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h07_ooool3o`00
0003ooooool0003ooooo0:Cooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`1Aoooo
o`007?ooool00onHV9So8B4Qonk^kP0Kooooo`;o0000Z_ooool00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo057ooooo000Mooooo`03ogMgMomVIVKooooo01Oooooo0ol0002]ooooo`03o`00
0?oooooooooo02_ooooo00?o0000ooooooooool0D?ooool001kooooo00?o0000ooooooooool05?oo
ool2o`000;3ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`1?ooooo`006_ooool0
1Ol0003o^[ZjoooooonHV9So410@01?ooooo0ol00002ooooo`03o`000?oooooooooo0:gooooo00?o
0000ooooooooool0;?ooool2o`00053ooooo000Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`04?oo
ool3o`000;Gooooo00?o0000ooooooooool0;?ooool2o`00053ooooo000]ooooo`;o0000^?ooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo04gooooo000Zooooo`?o000000?oooooo`00
0?ooool0]oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo04gooooo000Xooooo`;o
0000_Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo04cooooo000Uooooo`?o0000
_oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo04_ooooo000Tooooo`;o0000`Ooo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo04[ooooo000Jooooo`Co000000?o410@
ooooooooool00oooool00ol0003oooooo`000030ooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool0B_ooool001cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0002o
ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0BOooool0017ooooo1_l00005oooo
o`03o`000?oooooooooo00Gooooo0_l00002ooooo`03o`000?oooooooooo0;cooooo00?o0000oooo
ooooool0<oooool00ol0003oooooooooo`18ooooo`007?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0^oooool00ol0003oooooooooo`0cooooo`03
o`000?oooooooooo00Oooooo1Ol0000looooo`007?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo00Kooooo00GoV9RHob4Q8Oo^k^koooooodA4A00looooo`007?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00ol0003ooooo
ooooo`0eooooo`03o`000?oooooooooo00Kooooo00?oV9RHob4Q8Oo^k^h0?Oooool001cooooo00?o
0000ooooooooool01?ooool3o`0000Kooooo00?o0000ooooooooool0^?ooool00ol0003ooooooooo
o`0fooooo`03o`000?oooooooooo00Kooooo00?oV9RHob4Q8Oo^k^h0??ooool001[ooooo00?oEEEE
ofIVI_l000001_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;Oooooo00?o0000
ooooooooool0=_ooool00ol0003oooooooooo`07ooooo`03ogMgMomVIVKooooo03_ooooo000Soooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0]_ooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0>_ooool002?ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`2eooooo`03o`000?oooooooooo03Oooooo0_l00004ooooo`05
o`000?nj^[[ooooooiRHV?l@4100??ooool002?ooooo0_l0000;ooooo`03o`000?oooooooooo0;Co
oooo00?o0000ooooooooool0=_ooool00ol0003oooooo`000004ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`0??ooool002?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`2cooooo`03
o`000?oooooooooo03Wooooo00?o0000ooooooooool0@_ooool002;ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0
@Oooool002;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`2`ooooo`;o0000?Ooo
ool00ol0003oooooooooo`10ooooo`008_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo0:cooooo0ol000000ooooooo0000ooooo`0looooo`03o`000?oooooooooo043ooooo000Roooo
o`;o00004Oooool00ol0003oooooooooo`2Xooooo`?o00001Oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo03oooooo000Rooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool0Y?ooool3o`0000Wooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0nooooo`00
8_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo0:3ooooo0ol0000=ooooo`03o`00
0?oooooooooo03[ooooo00?o0000ooooooooool0?_ooool002;ooooo0ol0000Cooooo`03o`000?oo
oooooooo09cooooo0ol0000Aooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0?Ooo
ool002;ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`2Iooooo`;o00005?ooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo03cooooo000Qooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool0UOooool3o`0001Oooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`0kooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo097ooooo0ol0000Kooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0>oooool0
00Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0SOooool3o`0001oooooo00?o0000
ooooooooool0>_ooool00ol0003oooooooooo`0jooooo`001Ol00002ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`02ooooo`;o00006_ooool00ol0003oooooooooo`29
ooooo`?o00008oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03Wooooo0007oooo
o`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool0Q_ooool2o`0002Kooooo00?o0000ooooooooool0>_ooool2
o`0003[ooooo0007ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`22ooooo`?o0000:Ooo
ool00ol0003oooooooooo`0iooooo`;o0000>_ooool000Oooooo00Go410@oooooooooooooooooa0@
400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`1nooooo`?o0000;Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03Oooooo0007
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`;o00007_oo
ool00ol0003oooooooooo`1jooooo`?o0000<Oooool00ol0003oooooooooo`0iooooo`03o`000?oo
oooooooo03Oooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Cooooo0_l0
000Pooooo`03o`000?oooooooooo07Kooooo0ol0000eooooo`03o`000?oooooooooo03Wooooo00?o
0000ooooooooool0=_ooool0023ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1b
ooooo`?o0000>?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03Gooooo000Poooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool0Koooool2o`0003cooooo00?o0000oooo
ooooool0>_ooool00ol0003oooooooooo`0dooooo`008?ooool2o`0002?ooooo00?o0000oooooooo
ool0Joooool3o`0003oooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0dooooo`00
8?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo06Oooooo0ol00013ooooo`03o`00
0?oooooooooo03Wooooo00?o0000ooooooooool0<oooool0023ooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`1Sooooo`?o0000Aoooool00ol0003oooooooooo`0iooooo`03o`000?oo
oooooooo03;ooooo000Pooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0Goooool3
o`0004[ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0booooo`008?ooool00ol0
003oooooooooo`0Vooooo`;o0000GOooool2o`0004kooooo00?o0000ooooooooool0>Oooool00ol0
003oooooooooo`0aooooo`007oooool3o`0002Wooooo00?o0000ooooooooool0Eoooool3o`00057o
oooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0`ooooo`007oooool00ol0003ooooo
ooooo`0Zooooo`03o`000?oooooooooo05?ooooo0ol0001Eooooo`03o`000?oooooooooo03Wooooo
00?o0000ooooooooool0;oooool001oooooo00?o0000ooooooooool0:oooool00ol0003ooooooooo
o`1?ooooo`?o0000F?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02oooooo000O
ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0Boooool3o`0005cooooo00?o0000
ooooooooool0>?ooool2o`00033ooooo000Oooooo`?o0000;Oooool00ol0003oooooooooo`17oooo
o`?o0000H?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02gooooo000Oooooo`03
o`000?oooooooooo02kooooo00?o0000ooooooooool0A?ooool2o`0006Cooooo00?o0000oooooooo
ool0>?ooool00ol0003oooooooooo`0]ooooo`005?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Ko
oooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`10ooooo`?o0000Ioooool00ol0003o
ooooooooo`0hooooo`03o`000?oooooooooo02cooooo000Dooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo03cooooo0ol0001Zooooo`03
o`000?oooooooooo03Wooooo00?o0000ooooooooool0:oooool001Cooooo00Go410@oooooooooooo
oooooa0@4005ooooo`;o0000<oooool00ol0003oooooooooo`0hooooo`?o0000K_ooool00ol0003o
ooooooooo`0iooooo`03o`000?oooooooooo02[ooooo000Dooooo`05o`000?ooooooooooooooool0
00001Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo03Cooooo0ol0001booooo`03
o`000?oooooooooo03Sooooo00?o0000ooooooooool0:_ooool001Cooooo00Go0000oooooooooooo
ooooo`000005ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0<?ooool3o`0007Ko
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Yooooo`005?ooool01Ol@413ooooo
oooooooooooo410@00Gooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0]ooooo`;o
0000N_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02Sooooo000Dooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo02Wo
oooo0ol0001looooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0:?ooool001Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o0000>?ooool00ol0003oooooooooo`0Uooooo`?o
0000P?ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02Oooooo000Nooooo`03o`00
0?oooooooooo03Sooooo00?o0000ooooooooool08Oooool3o`0008Cooooo00?o0000ooooooooool0
>?ooool00ol0003oooooooooo`0Vooooo`007Oooool00ol0003oooooooooo`0jooooo`03o`000?oo
oooooooo01gooooo0ol00028ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool09Ooo
ool001gooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Jooooo`;o0000S?ooool0
0ol0003oooooooooo`0gooooo`03o`000?oooooooooo02Gooooo000Mooooo`;o0000?Oooool00ol0
003oooooooooo`0Fooooo`?o0000S_ooool00ol0003oooooooooo`0gooooo`;o00009_ooool001go
oooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Booooo`?o0000T_ooool00ol0003o
ooooooooo`0hooooo`03o`000?oooooooooo02?ooooo000Mooooo`03o`000?oooooooooo03kooooo
00?o0000ooooooooool03_ooool3o`0009Kooooo00?o0000ooooooooool0=oooool00ol0003ooooo
ooooo`0Sooooo`007Oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00[ooooo0ol0
002Jooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool08_ooool001gooooo00?o0000
ooooooooool0@?ooool00ol0003oooooooooo`06ooooo`?o0000W_ooool00ol0003oooooooooo`0g
ooooo`03o`000?oooooooooo027ooooo000Looooo`?o0000@_ooool00ol0003oooooooooo`03oooo
o`;o0000XOooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo023ooooo000Looooo`03
o`000?oooooooooo04?ooooo00?o0000ooooool000000_l0002Tooooo`03o`000?oooooooooo03Oo
oooo00?o0000ooooooooool08?ooool001cooooo00?o0000ooooooooool0@_ooool3o`000:Sooooo
00?o0000ooooooooool0=oooool00ol0003oooooooooo`09ooooo`;o000000?o410@ooooooooool0
4Oooool001cooooo00?o0000ooooooooool0?oooool3o`0000?ooooo00?o0000ooooooooool0Y_oo
ool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04_oo
ool001cooooo0ol0000looooo`?o00001oooool00ol0003oooooooooo`2Vooooo`03o`000?oooooo
oooo03Kooooo00?o0000ooooooooool01_ooool5o`0001?ooooo000Looooo`03o`000?oooooooooo
03Wooooo0ol0000;ooooo`03o`000?oooooooooo0:Gooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`05ooooo`04odA4A?oMgMgoooooo`0001Cooooo00001_ooooook^k^oc8b<_l0003o
<S8bonk^kPGooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooo
ooooo`0gooooo`;o00003oooool00ol0003oooooooooo`2Uooooo`03o`000?oooooooooo03Oooooo
00?o0000ooooooooool01?ooool01?oMgMgoEEEEooooool0000Dooooo`0000KoooooogMgMonHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
03Cooooo0ol0000Booooo`03o`000?oooooooooo0:Gooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`05ooooo`03ogMgMoo<c<co000001Cooooo00000ooooooo410@ooooo`02ooooo`03
oa0@4?oooooooooo00kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0aooooo`?o
00005_ooool00ol0003oooooooooo`2Uooooo`03o`000?oooooooooo03Kooooo0_l00005ooooo`03
onk^k_m4A4Co000001Cooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00gooooo
00?oMgMgoc8b<_ooool00oooool2o`00033ooooo0ol0000Jooooo`03o`000?oooooooooo0:Gooooo
00?o0000ooooooooool0=?ooool00ol0003oooooo`000006ooooo`03ogMgMol0003ooooo01?ooooo
00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00[ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c004ooooo`03o`000?oooooooooo02cooooo0ol0000Nooooo`03o`000?oooooooooo0:Cooooo
00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Iooooo`0000?ooooooa0@4?ooool00_oo
ool00ol@413oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0:_oo
ool2o`0002;ooooo00?o0000ooooooooool0Y?ooool00ol0003oooooooooo`0fooooo`03o`000?oo
oooooooo01Wooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`cooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Wooooo`?o00009Oooool2o`000:Gooooo00?o0000ooooooooool0
=_ooool00ol0003oooooooooo`0Hooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h<ooooo`Co
00001Oooool2o`0002Gooooo0ol0000Zooooo`03o`000?oooooooooo0:?ooooo00?o0000oooooooo
ool0=_ooool00ol0003oooooooooo`0Gooooo`006oooool00ol0003oooooooooo`0Qooooo`?o0000
;_ooool00ol0003oooooooooo`2Sooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0
5oooool001_ooooo00?o0000ooooooooool07_ooool3o`0003;ooooo00?o0000ooooooooool0X_oo
ool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo01Kooooo000Kooooo`03o`000?oooooo
oooo01_ooooo0ol0000fooooo`03o`000?oooooooooo0:;ooooo00?o0000ooooooooool0=_ooool0
0ol0003oooooooooo`0Eooooo`006_ooool00ol0003oooooooooo`0Jooooo`;o0000>_ooool00ol0
003oooooooooo`2Rooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool05?ooool001[o
oooo0_l0000Hooooo`?o0000?Oooool00ol0003oooooooooo`2Rooooo`03o`000?oooooooooo03Go
oooo00?o0000ooooooooool05?ooool001[ooooo00?o0000ooooooooool05?ooool3o`00047ooooo
00?o0000ooooooooool0XOooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo01?ooooo
000Jooooo`03o`000?oooooooooo017ooooo0ol00015ooooo`03o`000?oooooooooo0:7ooooo00?o
0000ooooooooool0=_ooool00ol0003oooooooooo`0Booooo`006_ooool00ol0003oooooooooo`0>
ooooo`?o0000BOooool00ol0003oooooooooo`2Qooooo`03o`000?oooooooooo03Gooooo0_l0000C
ooooo`006_ooool00ol0003oooooooooo`0<ooooo`;o0000COooool00ol0003oooooooooo`2Qoooo
o`03o`000?oooooooooo03Cooooo0_l0000Cooooo`006Oooool3o`0000[ooooo0ol0001@ooooo`03
o`000?oooooooooo0:7ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0@ooooo`00
6_ooool00ol0003oooooooooo`06ooooo`?o0000E?ooool00ol0003oooooooooo`2Pooooo`03o`00
0?oooooooooo03Kooooo00?o0000ooooooooool03oooool001Wooooo00?o0000ooooooooool01?oo
ool3o`0005Sooooo00?o0000ooooooooool0X?ooool00ol0003oooooooooo`0eooooo`03o`000?oo
oooooooo00oooooo000Iooooo`04o`000?ooooooooooooooo`?o0000G?ooool00ol0003ooooooooo
o`2Pooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool03_ooool001Wooooo1?l0001P
ooooo`03o`000?oooooooooo0:3ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0=
ooooo`006Oooool2o`0006?ooooo00?o0000ooooooooool0X?ooool00ol0003oooooooooo`0doooo
o`03o`000?oooooooooo00gooooo000?ooooo`Co000000?o410@ooooooooool01Oooool00ol0003o
ooooooooo`1Qooooo`03o`000?oooooooooo09oooooo00?o0000ooooooooool0=Oooool00ol0003o
ooooooooo`0<ooooo`004Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo067ooooo
00?o0000ooooooooool0Woooool01?l0003oooooooooooooool2oonI03;ooooo00?o0000oooooooo
ool02oooool0017ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Qooooo`03o`00
0?oooooooooo09oooooo00?o0000oonI0?ooV@00=Oooool00ol0003oooooooooo`0:ooooo`004Ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo067ooooo00?o0000ooooooooool0W_oo
ool00oooV@3o0000ooooo`0eooooo`03o`000?oooooooooo00[ooooo000Aooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`2Kooooo`;ooiT00_ooool0
0ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Wooooo000Aooooo`03o`000?oooooooooo
00cooooo0_l0001Rooooo`03o`000?oooooooooo09Sooooo0_ooV@04ooooo`03o`000?oooooooooo
03?ooooo0ol0000:ooooo`004Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo063o
oooo00?o0000ooooooooool0U_ooool00oooV@3oooooooooo`05ooooo`03o`000?oooooooooo02oo
oooo0ol00002ooooo`03o`000?oooooooooo00Sooooo000?ooooo`03oeEEEOmVIVKo0000017ooooo
00?o0000ooooooooool0H?ooool00ol0003oooooooooo`2Cooooo`;ooiT02Oooool00ol0003ooooo
ooooo`02olco02Wooooo0ol00005ooooo`03o`000?oooooooooo00Sooooo000Tooooo`03o`000?oo
oooooooo063ooooo00?o0000ooooooooool0T?ooool2oonI00cooooo00?o0000olco0?ooool09_oo
ool4o`0000Sooooo00?o0000ooooooooool02?ooool002Gooooo00?o0000ooooooooool0H?ooool0
0ol0003oooooooooo`2>ooooo`03oonI0?oooooooooo00_ooooo00?oc?l0ooooool000009?ooool3
o`0000cooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000ooooooooool0H?ooool00ol0
003oooooooooo`2;ooooo`;ooiT03?ooool2olco00;ooooo00?o0000ooooooooool07oooool3o`00
013ooooo00?o0000ooooooooool01oooool002Oooooo00?o0000ooooooooool0H?ooool00ol0003o
ooooooooo`28ooooo`;ooiT03?ooool2olco00Gooooo00?o0000ooooooooool06_ooool4o`0001?o
oooo00?o0000ooooooooool01oooool002Sooooo0_l0001Qooooo`03o`000?oooooooooo08Kooooo
00?ooiT0ooooooooool02oooool00oo<o`3oooooooooo`06ooooo`03o`000?oooooooooo01Kooooo
0ol0000Gooooo`03o`000?oooooooooo00Oooooo000Zooooo`03o`000?oooooooooo05oooooo00?o
0000ooooooooool0Poooool2oonI00cooooo0_o<o`0:ooooo`04o`000?oooooo<ol0oc?o017ooooo
0ol0000Jooooo`03o`000?oooooooooo00Oooooo000[ooooo`03o`000?oooooooooo05oooooo00?o
0000ooooooooool0P?ooool2oonI00cooooo0_o<o`0=ooooo`03o`000?oooooooooo00gooooo1?l0
000Mooooo`03o`000?oooooooooo00Oooooo000/ooooo`03o`000?oooooooooo05oooooo00?o0000
ooooooooool0O?ooool3oonI00gooooo00?oc?l0ooooooooool02oooool2oc?o0003o`000?oooooo
oooo00[ooooo0ol0000Qooooo`03o`000?oooooooooo00Oooooo000]ooooo`03o`000?oooooooooo
05oooooo00?o0000ooooooooool0NOooool2oonI00kooooo0_o<o`0<ooooo`;o<ol00oooool00ol0
003oooooooooo`06ooooo`?o00009?ooool00ol0003oooooooooo`07ooooo`00;_ooool00ol0003o
ooooooooo`1Oooooo`03o`000?oooooooooo07Kooooo0_ooV@0>ooooo`;oc?l03Oooool00olco`3o
ooooooooo`04ooooo`04o`000?ooooooooooooooo`Co00009oooool00ol0003oooooooooo`07oooo
o`00;oooool2o`00063ooooo00?o0000ooooooooool0L_ooool3oonI00oooooo00?oc?l0oooooooo
ool02oooool2oc?o00Sooooo0ol0000/ooooo`03o`000?oooooooooo00Kooooo000aooooo`03o`00
0?oooooooooo05kooooo0_l0001`ooooo`;ooiT04?ooool2olco00gooooo00?o<ol0ooooooooool0
1Oooool3o`000003ooooool0003ooooo00;o0?mV:_ooool00ol0003oooooooooo`06ooooo`00<_oo
ool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo06[ooooo0oooV@0@ooooo`;oc?l03Ooo
ool2oc?o00Gooooo0ol00004ooooo`03o`000?l0ofKooooo02_ooooo00?o0000ooooooooool01_oo
ool003?ooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`1Vooooo`?ooiT04?ooool3
olco00gooooo0_lco`03ooooo`Co00001_ooool00ol0ofKoooooo`00000/ooooo`03o`000?oooooo
oooo00Kooooo000dooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool0Hoooool2oonI
013ooooo0oo<o`0>ooooo`;o<ol00_ooool3o`0000Sooooo0_l0ofH3ooooo`03o`000?oooooooooo
02Wooooo00?o0000ooooooooool01_ooool003Gooooo00?o0000ooooooooool0Goooool00ol0003o
ooooooooo`1Oooooo`?ooiT04?ooool2olco00oooooo0_lco`001?oooooo0000o`000?l00009oooo
o`;o0?mV1_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00Kooooo000fooooo`03
o`000?oooooooooo05oooooo00?o0000ooooooooool0Foooool3oonI013ooooo0oo<o`0?ooooo`;o
<ol00ol0000;ooooo`03o`3oI_oooooooooo00Oooooo00?o0000ooooooooool09oooool00ol0003o
ooooooooo`06ooooo`00=oooool2o`00063ooooo00?o0000ooooooooool0Eoooool3oonI017ooooo
0_o<o`0@ooooo`;o<ol000?o0000ooooooooool02oooool2o`3oIP[ooooo00Co0000ooooool0oooo
0?oo9_ooool00ol0003oooooooooo`06ooooo`00>Oooool00ol0003oooooooooo`1Nooooo`03o`00
0?oooooooooo05;ooooo1?ooV@0Aooooo`?oc?l03oooool00ol0003o<ol0oc?o000>ooooo`;o0?mV
3?ooool00ol0oooo0000ooooo`0Xooooo`03o`000?oooooooooo00Gooooo000jooooo`03o`000?oo
oooooooo05kooooo00?o0000ooooooooool0C_ooool3oonI01;ooooo0oo<o`0>ooooo`?o00000_lc
o`0>ooooo`;o0?mV3Oooool01?l0ooooooooooooool0000Xooooo`03o`000?oooooooooo00Gooooo
000kooooo`03o`000?oooooooooo05kooooo00?o0000ooooooooool0BOooool4oonI01;ooooo0oo<
o`0>ooooo`?o000000?ooooooc?o0?lco`003_ooool2o`3oIPgooooo0_l0ool4ooooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool01Oooool003cooooo00?o0000ooooooooool0G_ooool0
0ol0003oooooooooo`15ooooo`?ooiT04oooool3olco00kooooo0ol000001?oooooo<ol0oc?o0?lc
o`0=ooooo`?o0?mV3Oooool2o`3oo`Kooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`05ooooo`00?Oooool00ol0003oooooooooo`1Nooooo`03o`000?oooooooooo043ooooo1?ooV@0D
ooooo`;oc?l03Oooool4o`0000;ooooo0_lco`0>ooooo`;o0?mV3oooool00ol0ooooooooooooo`07
ooooo`04o`000?oooooo06Koo`1Vob?ooooo00?o0000ooooooooool01Oooool003kooooo0_l0001O
ooooo`03o`000?oooooooooo03cooooo0oooV@0Eooooo`?oc?l03?ooool3o`0000Cooooo0_lco`0>
ooooo`;o0?mV3oooool2o`3oo`_ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`05
ooooo`00@?ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo03Kooooo1OooV@0Eoooo
o`?oc?l03?ooool3o`0000Gooooo0_lco`0>ooooo`;o0?mV3oooool2o`3oo`_ooooo0_l0I_l00ooo
oooo0000ooooo`0Sooooo`03o`000?oooooooooo00Gooooo0011ooooo`03o`000?oooooooooo05go
oooo00?o0000ooooooooool0;_ooool7oonI01Oooooo0oo<o`0;ooooo`Co00001Oooool3oc?o00go
oooo0ol0ofH>ooooo`?o0?oo2oooool2o`1Vo`Cooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`05ooooo`00@_ooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo02Gooooo
2?ooV@0Kooooo`?oc?l02oooool3o`0000Kooooo0olco`0>ooooo`;o0?mV3oooool2o`3oo`gooooo
00?o06Koooooooooool01?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00Gooooo
0013ooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool07Oooool7oonI023ooooo0oo<
o`0;ooooo`?o00001_ooool3oc?o00oooooo0_l0ofH?ooooo`;o0?oo3Oooool2o`1Vo`Sooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`04ooooo`00A?ooool00ol0003oooooooooo`1M
ooooo`03o`000?oooooooooo017ooooo2oooV@0Rooooo`Goc?l02_ooool4o`0000Kooooo0olco`0?
ooooo`?o0?mV3_ooool3o`3oo`gooooo0_l0I_l;ooooo`03o`000?lc0?oo<`3o023ooooo00?o0000
ooooooooool01?ooool004Gooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`09oooo
o`OooiT0:?ooool5olco00cooooo0ol00007ooooo`?o<ol04?ooool2o`3oIPoooooo0_l0ool?oooo
o`03o`1Voooooooooooo00_ooooo00?o<`3oo`000?ooool08?ooool00ol0003oooooooooo`04oooo
o`00A_ooool2o`0005kooooo00?o0000ooooooooool0<oooool4olco00kooooo0ol00006ooooo`Co
<ol04Oooool2o`3oIPoooooo0_l0ool?ooooo`;o06Ko3?ooool2oc<0o`;ooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`04ooooo`00B?ooool00ol0003oooooooooo`1Looooo`03o`00
0?oooooooooo02gooooo1Oo<o`0>ooooo`Co00001_ooool3oc?o01;ooooo0ol0ofH>ooooo`?o0?oo
3oooool2o`1Vo`cooooo0_lc0?l4ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
1?ooool004Wooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`0Wooooo`Goc?l04?oo
ool3o`0000Kooooo1?lco`0Booooo`?o0?mV3oooool2o`3ooa3ooooo0_l0I_l=ooooo`03oc<0oooo
oooooooo00Gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`04ooooo`00B_ooool0
0ol0003oooooooooo`1Looooo`03o`000?oooooooooo01oooooo1oo<o`0Booooo`?o00001Oooool4
oc?o01?ooooo0ol0ofH@ooooo`;o0?oo4?ooool2o`1Vo`gooooo0_lc0?l9ooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool01?ooool004_ooooo00?o0000ooooooooool0G?ooool00ol0
003oooooooooo`0Gooooo`Ooc?l05Oooool4o`0000Cooooo1?lco`0Dooooo`?o0?mV4?ooool3o`3o
oa7ooooo00?o06Koooooooooool02oooool2oc<0o`cooooo00?o0000ol`0ooooool06oooool00ol0
003oooooooooo`04ooooo`00C?ooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo00_o
oooo2oo<o`0Iooooo`?o00001Oooool3oc?o01Kooooo0_l0ofHAooooo`;o0?oo4_ooool2o`1Vo`go
oooo00?o<`3oooooooooool02oooool00oo<0?ooooooo`00000Mooooo`03o`000?oooooooooo00?o
oooo001=ooooo`;o0000GOooool00ol0003oooooooooo`03ooooo`Ooc?l08Oooool3o`0000Cooooo
1?lco`0Fooooo`?o0?mV4Oooool2o`3ooa;ooooo0_l0I_l=ooooo`;o<`3o3?ooool2ol`0o`;ooooo
00?o0000ooooooooool06oooool00ol0003oooooooooo`03ooooo`00Coooool00ol0003ooooooooo
o`1Kooooo`03o`000?oooooooooo02Oooooo0ol000000ooooooo<ol0oc?o0004oc?o01Oooooo0ol0
ofHAooooo`?o0?oo4_ooool2o`1Vo`gooooo0_lc0?l<ooooo`;oc03o1Oooool00ol0003ooooooooo
o`0Jooooo`03o`000?oooooooooo00?ooooo001@ooooo`03o`000?oooooooooo05_ooooo00?o0000
ooooooooool08_ooool00ol0003o<ol0oc?o0005oc?o01[ooooo0ol0ofHBooooo`;o0?oo4_ooool3
o`1Vo`gooooo0_lc0?l=ooooo`03ol`0oooooooooooo00Kooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`03ooooo`00DOooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo
01[ooooo2?lco`0Nooooo`?o0?mV4oooool2o`3ooa;ooooo0_l0I_l>ooooo`;o<`3o3Oooool2ol`0
o`[ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`03ooooo`00D_ooool00ol0003o
ooooooooo`1Kooooo`03o`000?oooooooooo01;ooooo1olco`001?oooooo0000o`000?l0000Noooo
o`Co0?mV4oooool3o`3ooa7ooooo0ol0I_l>ooooo`;o<`3o3Oooool2ol`0o`cooooo00?oo`2Io`00
0?ooool06?ooool00ol0003oooooooooo`03ooooo`00Doooool00ol0003oooooooooo`1Kooooo`03
o`000?oooooooooo00Kooooo2olco`04ooooo`Co00007?ooool5o`3oIQGooooo0_l0oolBooooo`;o
06Ko3oooool2oc<0o`kooooo00?oc03oooooooooool02_ooool2ool0V@03ooooool0003ooooo01So
oooo00?o0000ooooooooool00oooool005Cooooo0_l0001Looooo`So<ol03?ooool3o`0001_ooooo
1Ol0ofHGooooo`?o0?oo4Oooool3o`1Vo`oooooo0_lc0?l>ooooo`;oc03o3?ooool00ooo09Wooooo
ooooo`02ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool00oooool005Kooooo00?o
0000ooooooooool0F_ooool00ol0003oooooooooo`0=ooooo`?o00006?ooool6o`3oIQSooooo1?l0
oolBooooo`;o06Ko4?ooool2oc<0o`kooooo0_o<0?l<ooooo`;oo`2I1_ooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo00;ooooo001Gooooo`03o`000?oooooooooo05[ooooo00?o0000
ooooooooool02?ooool4o`0001Kooooo1Ol0ofHJooooo`Co0?oo4oooool3o`1Vo`oooooo0olc0?l>
ooooo`;oc03o3?ooool2ool0V@Wooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`02
ooooo`00F?ooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00Cooooo0ol0000Eoooo
o`Go0?mV6oooool4o`3ooaCooooo0ol0I_l@ooooo`;o<`3o3_ooool3ol`0o`cooooo0_oo09T<oooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00_ooool005Wooooo00?o0000oooooooo
ool0F_ooool00ol0003oooooooooo`03o`00017ooooo1ol0ofHLooooo`Co0?oo5Oooool3o`1Voa3o
oooo0olc0?l>ooooo`;oc03o3_ooool00ooo09Woooooooooo`0;ooooo`03ool00?l0003ooooo01Go
oooo00?o0000ooooooooool00_ooool005[ooooo00?o0000ooooooooool0F_ooool2o`0000gooooo
1ol0ofHOooooo`Co0?oo5_ooool3o`1Voa7ooooo0_lc0?l?ooooo`;oc03o3_ooool2ool0V@cooooo
0_oo0002ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00_ooool005_ooooo00?o
0000ooooooooool0FOooool01?l0003oooooooooooooool;o`3oIR?ooooo0ol0oolFooooo`Co06Ko
4Oooool3oc<0o`oooooo0_o<0?l>ooooo`;oo`2I3Oooool00ooo003oooooooooo`03ooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool00_ooool005cooooo0_l0001Eooooo`So0?mV:_oo
ool4o`3ooaGooooo1?l0I_lCooooo`;o<`3o4?ooool2ol`0o`kooooo0_oo09T=ooooo`;oo`001ooo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00;ooooo001Nooooo`03o`000?oooooo
oooo05Kooooo00?o0000ooooooooool09_ooool5o`3ooaGooooo1?l0I_lDooooo`?o<`3o3oooool3
ol`0o`kooooo0_oo09T=ooooo`;oo`002_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo00;ooooo001Oooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool08Oooool5o`3o
oaKooooo1?l0I_lEooooo`?o<`3o4?ooool2ol`0o`kooooo0ooo09T=ooooo`;oo`003?ooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo007ooooo001Pooooo`03o`000?oooooooooo05Co
oooo00?o0000ooooooooool07?ooool5o`3ooaOooooo1?l0I_lFooooo`?o<`3o4?ooool3ol`0o`ko
oooo0_oo09T?ooooo`03ool00?oooooooooo00gooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`01ooooo`00HOooool00ol0003oooooooooo`1Cooooo`03o`000?oooooooooo01Gooooo
1ol0oolHooooo`Co06Ko5oooool3oc<0oa7ooooo0_o<0?l?ooooo`;oo`2I3oooool2ool0017ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`01ooooo`00H_ooool00ol0003ooooooooo
o`1Booooo`03o`000?oooooooooo00gooooo2?l0oolKooooo`Co06Ko5oooool4oc<0oa7ooooo0oo<
0?l?ooooo`;oo`2I3oooool2ool001Cooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`01ooooo`00Hoooool2o`0005;ooooo00Co0000oooooooooooooooo3?l0oolOooooo`Co06Ko6?oo
ool3oc<0oa?ooooo0_o<0?l@ooooo`;oo`2I3oooool2ool001Oooooo00?o0000ooooooooool03Ooo
ool00ol0003oooooooooo`01ooooo`00IOooool00ol0003oooooooooo`1;ooooo`So0?oo9_ooool5
o`1VoaSooooo1?lc0?lCooooo`?oc03o3oooool3ool0V@oooooo0_oo000Iooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool00Oooool006Kooooo00?o0000ooooooooool0C_ooool00ol0
003oooooooooo`0Rooooo`Go06Ko6_ooool3oc<0oaCooooo0oo<0?l@ooooo`;oo`2I3oooool3ool0
01cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`01ooooo`00Ioooool00ol0003o
ooooooooo`1=ooooo`03o`000?oooooooooo01gooooo1Ol0I_lLooooo`?o<`3o5Oooool2ol`0oa3o
oooo0ooo09T?ooooo`;oo`008?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo007o
oooo001Xooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool05_ooool7o`1Voagooooo
1?lc0?lEooooo`?oc03o4?ooool2ool0VA3ooooo0_oo000Sooooo`03o`000?oooooooooo00_ooooo
0Ol00001ooooo`7ooooo001Yooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool03_oo
ool8o`1Vob3ooooo1?lc0?lFooooo`?oc03o4?ooool3ool0VA3ooooo0_oo000Uooooo`03o`000?oo
oooooooo00_ooooo0Ol00001ooooo`7ooooo001Zooooo`03o`000?oooooooooo04[ooooo00?o0000
ooooooooool00_ooool<o`1VobCooooo1?lc0?lGooooo`?oc03o4Oooool2ool0VA7ooooo0_oo000X
ooooo`03o`000?oooooooooo00[ooooo0Ol00001ooooo`7ooooo001[ooooo`;o0000Aoooool8o`1V
obcooooo1?lc0?lGooooo`Coc03o4Oooool3ool0VA7ooooo0_oo000[ooooo`03o`000?oooooooooo
00Wooooo0Ol00001ooooo`7ooooo001]ooooo`03o`000?oooooooooo04Oooooo00?o0000oooooooo
ool0:Oooool5oc<0oaOooooo1?o<0?lBooooo`?oo`2I4Oooool3ool002kooooo00?o0000oooooooo
ool02?ooool1o`00007ooooo0Oooool006kooooo00?o0000ooooooooool0A_ooool00ol0003ooooo
ooooo`0Sooooo`Ko<`3o6?ooool4ol`0oa?ooooo0ooo09TBooooo`;oo`00<_ooool00ol0003ooooo
ooooo`07ooooo`7o00000Oooool1ooooo`00Koooool00ol0003oooooooooo`15ooooo`03o`000?oo
oooooooo01kooooo1Olc0?lJooooo`Coc03o5?ooool3ool0VA?ooooo0_oo000dooooo`03o`000?oo
oooooooo00Oooooo0Ol00001ooooo`7ooooo001`ooooo`03o`000?oooooooooo04Cooooo00?o0000
ooooooooool05oooool7oc<0oa_ooooo1?o<0?lEooooo`?oo`2I4oooool3ool003Oooooo00?o0000
ooooooooool01_ooool1o`00007ooooo0Oooool0077ooooo00?o0000ooooooooool0@oooool00ol0
003oooooooooo`0>ooooo`Wo<`3o7Oooool5ol`0oaKooooo0ooo09TDooooo`;oo`00>oooool00ol0
003oooooooooo`05ooooo`7o00000Oooool1ooooo`00L_ooool2o`0004;ooooo00?o0000oooooooo
ool00oooool<oc<0ob;ooooo1?o<0?lHooooo`?oo`2I5?ooool3ool003kooooo00?o0000oooooooo
ool01Oooool1o`00007ooooo001dooooo`03o`000?oooooooooo03gooooo2?lc0?lYooooo`Goc03o
6Oooool3ool0VACooooo0ooo0012ooooo`03o`000?oooooooooo00Cooooo0Ol00001ooooo`00MOoo
ool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo02Kooooo1_o<0?lKooooo`?oo`2I4ooo
ool4ool004Gooooo00?o0000ooooooooool01?ooool1o`00007ooooo001fooooo`03o`000?oooooo
oooo03gooooo00?o0000ooooooooool08Oooool5ol`0oakooooo0ooo09TCooooo`?oo`00B_ooool0
0ol0003oooooooooo`03ooooo`7o00000Oooool007Oooooo00?o0000ooooooooool0??ooool00ol0
003oooooooooo`0Jooooo`Ooc03o7oooool4ool0VA?ooooo0ooo001>ooooo`03o`000?oooooooooo
00;ooooo0Ol00001ooooo`00N?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo017o
oooo2Oo<0?lQooooo`Goo`2I4oooool4ool005;ooooo00Go0000ooooooooooooooooo`000001oooo
o`00NOooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo00Cooooo3Oo<0?lVooooo`Co
o`2I5Oooool3ool005Oooooo00Co0000oooooooooooo00000Oooool007[ooooo0_l0000hooooo`Wo
c03o;_ooool5ool0VAGooooo1?oo001Jooooo`04o`000?ooooooooooo`00007ooooo001looooo`03
o`000?oooooooooo03Oooooo00?o0000ooooooooool0;Oooool5ool0VAOooooo0ooo001Oooooo`03
o`000?oooooooooo007o0000001mooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0
9oooool6ool0VAWooooo0ooo001Sooooo`7o00000Oooool1o`000000O_ooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo02;ooooo1Ooo09TKooooo`Coo`00Ioooool2o`000000Ooooool0
0ol0003oooooooooo`0dooooo`03o`000?oooooooooo01_ooooo1ooo09TKooooo`Goo`00J_ooool3
o`000000P?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo01;ooooo2Ooo09TNoooo
o`Coo`00Joooool4o`0000?ooooo0021ooooo`;o0000<oooool00ol0003oooooooooo`05ooooo`go
o`2I8_ooool5ool006cooooo0ol00007ooooo`00Poooool00ol0003oooooooooo`0_ooooo`Woo`2I
:_ooool5ool006gooooo1?l0000:ooooo`00Q?ooool00ol0003oooooooooo`0_ooooo`03o`000?oo
oooooooo02Wooooo1_oo001^ooooo`Co00003_ooool008Gooooo00?o0000ooooooooool0;_ooool0
0ol0003oooooooooo`0Sooooo`Koo`00L?ooool4o`0001;ooooo0026ooooo`03o`000?oooooooooo
02gooooo00?o0000ooooooooool07?ooool7ool007;ooooo1?l0000Fooooo`00Qoooool00ol0003o
ooooooooo`0/ooooo`03o`000?oooooooooo01?ooooo2Ooo001fooooo`?o00006_ooool008Sooooo
0_l0000/ooooo`03o`000?oooooooooo00Gooooo3_oo001kooooo`Co00007Oooool008[ooooo00?o
0000ooooooooool0:?ooool9ool008Gooooo1?l0000Qooooo`00Roooool00ol0003oooooooooo`0X
ooooo`03o`000?oooooooooo08Kooooo1?l0000Uooooo`00S?ooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo08;ooooo1?l0000Yooooo`00SOooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo07oooooo0ol0000]ooooo`00S_ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo07_ooooo1?l0000`ooooo`00Soooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo07Oooooo1?l0000dooooo`00T?ooool2o`0002Cooooo00?o0000ooooooooool0Loooool4
o`0003Sooooo002Booooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0L?ooool3o`00
03cooooo002Cooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0K?ooool4o`0003oo
oooo002Dooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0J?ooool4o`0004?ooooo
002Eooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0I?ooool4o`0004Oooooo002F
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0H?ooool4o`0004_ooooo002Goooo
o`;o00007Oooool00ol0003oooooooooo`1Mooooo`?o0000Coooool009Wooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`1Iooooo`Co0000D_ooool009[ooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`1Eooooo`Co0000E_ooool009_ooooo00?o0000ooooooooool06?oo
ool00ol0003oooooooooo`1Aooooo`Co0000F_ooool009cooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`1=ooooo`Co0000G_ooool009gooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`1:ooooo`?o0000H_ooool009kooooo00?o0000ooooooooool05Oooool00ol0003o
ooooooooo`16ooooo`Co0000IOooool009oooooo0_l0000Dooooo`03o`000?oooooooooo04?ooooo
1?l0001Yooooo`00XOooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo03oooooo1?l0
001]ooooo`00X_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03_ooooo1?l0001a
ooooo`00Xoooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03Sooooo0ol0001eoooo
o`00Y?ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03Cooooo1?l0001hooooo`00
YOooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo033ooooo1?l0001looooo`00Y_oo
ool2o`0000gooooo00?o0000ooooooooool0;?ooool4o`00083ooooo002Xooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool0:Oooool3o`0008Cooooo002Yooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool09Oooool4o`0008Oooooo002Zooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool08Oooool4o`0008_ooooo002[ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool07Oooool4o`0008oooooo002/ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool06Oooool4o`0009?ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool05_ooool3o`0009Oooooo002^ooooo`;o00001Oooool00ol0003oooooooooo`0Boooo
o`Co0000V_ooool00;3ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0>ooooo`Co
0000W_ooool00;7ooooo00Go0000ooooooooooooooooo`00000<ooooo`Co0000X_ooool00;;ooooo
00Co0000oooooooooooo00002?ooool4o`000:Kooooo002cooooo`03o`000?oooooo000000Gooooo
0ol0002Zooooo`00]?ooool2o`000003ooooool0003o000000;o0000[Oooool00;Gooooo0_l0002a
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {319.688, 0}} -> {-0.0710364, -0.0181728, \
0.0035149, 0.0035149}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .89104 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-16 1.0656 -0.0363427 1.0656 [
[.02544 .21571 -12 -8.9133 ]
[.02544 .21571 0 .0867 ]
[.16074 .16277 -11.6592 -9 ]
[.16074 .16277 .34081 0 ]
[.3021 .10747 -5.60025 -9 ]
[.3021 .10747 .39975 0 ]
[.44992 .04965 -5.37091 -9 ]
[.44992 .04965 .62909 0 ]
[.60467 -0.01084 -5.14157 -9 ]
[.60467 -0.01084 .85843 0 ]
[.66454 .05085 0 -6.20675 ]
[.66454 .05085 6 2.79325 ]
[.80797 .25198 0 -6.0417 ]
[.80797 .25198 6 2.9583 ]
[.93071 .4241 0 -5.90576 ]
[.93071 .4241 6 3.09424 ]
[.02254 .22988 -12 -2.74631 ]
[.02254 .22988 0 6.25369 ]
[.0142 .29178 -24 -2.78907 ]
[.0142 .29178 0 6.21093 ]
[.00558 .35578 -6 -2.83339 ]
[.00558 .35578 0 6.16661 ]
[-0.00334 .42198 -18 -2.87938 ]
[-0.00334 .42198 0 6.12062 ]
[-0.01257 .49051 -6 -2.92712 ]
[-0.01257 .49051 0 6.07288 ]
[ 0 0 0 0 ]
[ 1 .89104 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03495 .22504 m
.61241 0 L
s
.03495 .22504 m
.03971 .2297 L
s
[(-2)] .02544 .21571 1 .98073 Mshowa
.16988 .17246 m
.17445 .1773 L
s
[(-1)] .16074 .16277 .9432 1 Mshowa
.31082 .11753 m
.31518 .12256 L
s
[(0)] .3021 .10747 .86675 1 Mshowa
.45818 .0601 m
.46231 .06533 L
s
[(1)] .44992 .04965 .7903 1 Mshowa
.61241 0 m
.61628 .00542 L
s
[(2)] .60467 -0.01084 .71386 1 Mshowa
.125 Mabswid
.06148 .2147 m
.06431 .21752 L
s
.08823 .20428 m
.09104 .20712 L
s
.11521 .19376 m
.118 .19663 L
s
.14243 .18316 m
.14519 .18604 L
s
.19758 .16166 m
.20029 .16459 L
s
.22551 .15078 m
.22821 .15373 L
s
.2537 .13979 m
.25637 .14277 L
s
.28213 .12871 m
.28478 .13171 L
s
.33977 .10625 m
.34236 .10929 L
s
.36897 .09487 m
.37153 .09794 L
s
.39844 .08339 m
.40097 .08648 L
s
.42817 .0718 m
.43068 .07491 L
s
.48846 .0483 m
.49091 .05146 L
s
.51902 .03639 m
.52144 .03958 L
s
.54986 .02437 m
.55225 .02758 L
s
.58099 .01224 m
.58335 .01547 L
s
.25 Mabswid
.61241 0 m
.97291 .505 L
s
.65208 .05558 m
.64586 .05794 L
s
[(0)] .66454 .05085 -1 .37928 Mshowa
.79537 .2563 m
.78907 .25846 L
s
[(2)] .80797 .25198 -1 .3426 Mshowa
.91799 .42808 m
.91164 .43006 L
s
[(4)] .93071 .4241 -1 .31239 Mshowa
.125 Mabswid
.69012 .10886 m
.68637 .11025 L
s
.72662 .16 m
.72286 .16135 L
s
.76168 .2091 m
.75791 .21042 L
s
.82778 .3017 m
.82399 .30297 L
s
.85897 .3454 m
.85518 .34664 L
s
.88903 .3875 m
.88522 .38871 L
s
.94594 .46722 m
.94211 .46839 L
s
.25 Mabswid
.03495 .22504 m
0 .48612 L
s
.03495 .22504 m
.04116 .22262 L
s
[(-1)] .02254 .22988 1 -0.38971 Mshowa
.02665 .28704 m
.03288 .28468 L
s
[(-0.5)] .0142 .29178 1 -0.38021 Mshowa
.01807 .35115 m
.02431 .34884 L
s
[(0)] .00558 .35578 1 -0.37036 Mshowa
.00919 .41747 m
.01546 .41521 L
s
[(0.5)] -0.00334 .42198 1 -0.36014 Mshowa
0 .48612 m
.00629 .48392 L
s
[(1)] -0.01257 .49051 1 -0.34953 Mshowa
.125 Mabswid
.03331 .23728 m
.03704 .23583 L
s
.03166 .2496 m
.03539 .24816 L
s
.03 .262 m
.03373 .26056 L
s
.02833 .27448 m
.03207 .27305 L
s
.02496 .29969 m
.0287 .29828 L
s
.02325 .31243 m
.02699 .31102 L
s
.02154 .32525 m
.02528 .32385 L
s
.01981 .33816 m
.02355 .33676 L
s
.01632 .36423 m
.02007 .36285 L
s
.01455 .37741 m
.01831 .37603 L
s
.01278 .39067 m
.01653 .3893 L
s
.01099 .40402 m
.01475 .40266 L
s
.00738 .43101 m
.01114 .42966 L
s
.00555 .44464 m
.00932 .4433 L
s
.00371 .45837 m
.00748 .45704 L
s
.00186 .4722 m
.00563 .47087 L
s
.25 Mabswid
.03495 .22504 m
0 .48612 L
s
0 .48612 m
.46953 .89104 L
s
.46953 .89104 m
.47294 .65459 L
s
.47294 .65459 m
.03495 .22504 L
s
.61241 0 m
.97291 .505 L
s
.97291 .505 m
1 .75117 L
s
1 .75117 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.03495 .22504 m
0 .48612 L
s
0 .48612 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.61241 0 m
.03495 .22504 L
s
.47294 .65459 m
.97291 .505 L
s
.97291 .505 m
1 .75117 L
s
1 .75117 m
.46953 .89104 L
s
.46953 .89104 m
.47294 .65459 L
s
0 0 m
1 0 L
1 .89104 L
0 .89104 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.47181 .79363 m
.52717 .78986 L
s
1 0 .6 r
.47054 .77423 m
.52463 .7705 L
s
1 0 0 r
.52717 .78986 m
.5836 .78322 L
s
.8 0 1 r
.46928 .75478 m
.5221 .75111 L
s
1 0 .6 r
.52463 .7705 m
.57981 .76394 L
s
.2 0 1 r
.46801 .7353 m
.51955 .73168 L
s
.8 0 1 r
.5221 .75111 m
.57602 .74463 L
s
0 .4 1 r
.46674 .71578 m
.517 .71221 L
s
.2 0 1 r
.51955 .73168 m
.57222 .72528 L
s
0 1 1 r
.46546 .69621 m
.51445 .6927 L
s
1 0 0 r
.5836 .78322 m
.63962 .7738 L
s
0 .4 1 r
.517 .71221 m
.56842 .7059 L
s
0 1 .4 r
.46418 .67661 m
.51189 .67315 L
s
1 0 .6 r
.57981 .76394 m
.63463 .75462 L
s
0 1 1 r
.51445 .6927 m
.56461 .68648 L
s
.2 1 0 r
.4629 .65697 m
.50932 .65357 L
s
.8 0 1 r
.57602 .74463 m
.62962 .73542 L
s
0 1 .4 r
.51189 .67315 m
.56079 .66702 L
s
.8 1 0 r
.46162 .63728 m
.50675 .63394 L
s
.2 0 1 r
.57222 .72528 m
.62461 .71618 L
s
.2 1 0 r
.50932 .65357 m
.55697 .64754 L
s
0 .4 1 r
.56842 .7059 m
.6196 .69692 L
s
1 .6 0 r
.46034 .61755 m
.50418 .61428 L
s
.8 1 0 r
.50675 .63394 m
.55313 .62801 L
s
0 1 1 r
.56461 .68648 m
.61457 .67762 L
s
1 0 0 r
.63962 .7738 m
.69457 .76172 L
s
1 .6 0 r
.50418 .61428 m
.5493 .60845 L
s
0 1 .4 r
.56079 .66702 m
.60954 .6583 L
s
1 0 .6 r
.63463 .75462 m
.68839 .74268 L
s
.2 1 0 r
.55697 .64754 m
.60449 .63894 L
s
.8 0 1 r
.62962 .73542 m
.68221 .72361 L
s
.8 1 0 r
.55313 .62801 m
.59944 .61955 L
s
.2 0 1 r
.62461 .71618 m
.67602 .70451 L
s
1 .6 0 r
.5493 .60845 m
.59439 .60013 L
s
0 .4 1 r
.6196 .69692 m
.66983 .6854 L
s
0 1 1 r
.61457 .67762 m
.66362 .66625 L
s
0 1 .4 r
.60954 .6583 m
.65741 .64708 L
s
.2 1 0 r
.60449 .63894 m
.65119 .62789 L
s
.8 1 0 r
.59944 .61955 m
.64496 .60867 L
s
1 0 0 r
.69457 .76172 m
.74818 .74704 L
s
1 0 .6 r
.68839 .74268 m
.74084 .72815 L
s
1 .6 0 r
.59439 .60013 m
.63872 .58942 L
s
.8 0 1 r
.68221 .72361 m
.7335 .70925 L
s
.2 0 1 r
.67602 .70451 m
.72614 .69033 L
s
0 .4 1 r
.66983 .6854 m
.71878 .67139 L
s
0 1 1 r
.66362 .66625 m
.71142 .65243 L
s
0 1 .4 r
.65741 .64708 m
.70404 .63345 L
s
.2 1 0 r
.65119 .62789 m
.69666 .61446 L
s
.8 1 0 r
.64496 .60867 m
.68928 .59544 L
s
1 .6 0 r
.63872 .58942 m
.68188 .57641 L
s
1 0 0 r
.74818 .74704 m
.80029 .72972 L
s
1 0 .6 r
.74084 .72815 m
.79178 .71104 L
s
.8 0 1 r
.7335 .70925 m
.78327 .69234 L
s
.2 0 1 r
.72614 .69033 m
.77475 .67363 L
s
0 .4 1 r
.71878 .67139 m
.76622 .65491 L
s
0 1 1 r
.71142 .65243 m
.75769 .63618 L
s
0 1 .4 r
.70404 .63345 m
.74916 .61744 L
s
.2 1 0 r
.69666 .61446 m
.74062 .59869 L
s
.8 1 0 r
.68928 .59544 m
.73208 .57992 L
s
1 .6 0 r
.68188 .57641 m
.72353 .56115 L
s
1 0 0 r
.80029 .72972 m
.85054 .70975 L
s
1 0 .6 r
.79178 .71104 m
.84084 .69131 L
s
.8 0 1 r
.78327 .69234 m
.83114 .67287 L
s
.2 0 1 r
.77475 .67363 m
.82144 .65443 L
s
0 .4 1 r
.76622 .65491 m
.81173 .63599 L
s
0 1 1 r
.75769 .63618 m
.80203 .61754 L
s
0 1 .4 r
.74916 .61744 m
.79232 .59908 L
s
.2 1 0 r
.74062 .59869 m
.78261 .58063 L
s
.8 1 0 r
.73208 .57992 m
.7729 .56217 L
s
1 .6 0 r
.72353 .56115 m
.76319 .54371 L
s
1 0 0 r
.85054 .70975 m
.89814 .68727 L
s
1 0 .6 r
.84084 .69131 m
.88724 .66914 L
s
.8 0 1 r
.83114 .67287 m
.87633 .65102 L
s
.2 0 1 r
.82144 .65443 m
.86544 .6329 L
s
0 .4 1 r
.81173 .63599 m
.85454 .61479 L
s
0 1 1 r
.80203 .61754 m
.84365 .59669 L
s
0 1 .4 r
.79232 .59908 m
.83277 .5786 L
s
.2 1 0 r
.78261 .58063 m
.82188 .56051 L
s
.8 1 0 r
.7729 .56217 m
.81101 .54243 L
s
1 .6 0 r
.76319 .54371 m
.80013 .52435 L
s
.80013 .52435 m
.83327 .50367 L
s
.8 1 0 r
.81101 .54243 m
.84527 .52129 L
s
.2 1 0 r
.82188 .56051 m
.85729 .53893 L
s
0 1 .4 r
.83277 .5786 m
.86932 .55658 L
s
0 1 1 r
.84365 .59669 m
.88136 .57425 L
s
0 .4 1 r
.85454 .61479 m
.89341 .59194 L
s
.2 0 1 r
.86544 .6329 m
.90548 .60964 L
s
.8 0 1 r
.87633 .65102 m
.91755 .62736 L
s
1 0 .6 r
.88724 .66914 m
.92964 .6451 L
s
1 0 0 r
.89814 .68727 m
.94174 .66286 L
s
0 g
.25 Mabswid
.61241 0 m
.97291 .505 L
s
.97291 .505 m
1 .75117 L
s
1 .75117 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.03495 .22504 m
0 .48612 L
s
0 .48612 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.61241 0 m
.03495 .22504 L
s
.03495 .22504 m
.61241 0 L
s
.03495 .22504 m
.03971 .2297 L
s
[(-2)] .02544 .21571 1 .98073 Mshowa
.16988 .17246 m
.17445 .1773 L
s
[(-1)] .16074 .16277 .9432 1 Mshowa
.31082 .11753 m
.31518 .12256 L
s
[(0)] .3021 .10747 .86675 1 Mshowa
.45818 .0601 m
.46231 .06533 L
s
[(1)] .44992 .04965 .7903 1 Mshowa
.61241 0 m
.61628 .00542 L
s
[(2)] .60467 -0.01084 .71386 1 Mshowa
.125 Mabswid
.06148 .2147 m
.06431 .21752 L
s
.08823 .20428 m
.09104 .20712 L
s
.11521 .19376 m
.118 .19663 L
s
.14243 .18316 m
.14519 .18604 L
s
.19758 .16166 m
.20029 .16459 L
s
.22551 .15078 m
.22821 .15373 L
s
.2537 .13979 m
.25637 .14277 L
s
.28213 .12871 m
.28478 .13171 L
s
.33977 .10625 m
.34236 .10929 L
s
.36897 .09487 m
.37153 .09794 L
s
.39844 .08339 m
.40097 .08648 L
s
.42817 .0718 m
.43068 .07491 L
s
.48846 .0483 m
.49091 .05146 L
s
.51902 .03639 m
.52144 .03958 L
s
.54986 .02437 m
.55225 .02758 L
s
.58099 .01224 m
.58335 .01547 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 256.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001@2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00gOooool5o`0008Kooooo003Mooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0Q_ooool00=ko
oooo00?oV9RHob4Q8Oo^k^h0Qoooool00=oooooo00?oV9RHob4Q8Oo^k^h0Q_ooool00>3ooooo00?o
MgMgofIVI_ooool0QOooool00>7ooooo00?o0000ooooooooool0Q?ooool00=gooooo00Go0000okZj
^_ooooooV9RHoa0@4026ooooo`00gOooool01OnHV9So410@o`000?lQ8B7oc<c<08Kooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003Tooooo`;o0000P_ooool0
0>7ooooo0ol000000ooooooo0000ooooo`21ooooo`00goooool2o`0000Cooooo0_l00021ooooo`00
g?ooool3o`0000Kooooo00?o0000ooooool00000P?ooool00=[ooooo0_l00009ooooo`03o`000?oo
oooo0000083ooooo003Gooooo`?o000000?oooooo`000?ooool02?ooool01?l0003oooooooooool0
001oooooo`00e?ooool3o`0000Cooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooo
oooo000007kooooo003Booooo`;o00004Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo07_ooooo002Zooooo`Co000000?o410@ooooooooool07_ooool3o`0001?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1kooooo`00[?ooool00ol0003oooooooooo`0Nooooo`;o
000000?oooooo`000?ooool04oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07[o
oooo002/ooooo`03o`000?oooooooooo01_ooooo0ol00004ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`1iooooo`00[?ooool00ol0003ooooooooo
o`0Iooooo`;o00006oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo07Wooooo002/
ooooo`03o`000?oooooooooo01Kooooo0ol0000Mooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool02?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^06_ooooo002/ooooo`03o`000?oooooo
oooo01Cooooo0_l000000ooooooo0000ooooo`0Mooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01oooool01OmgMgOoV9RHoooooonHV9SoMgMg06_ooooo002/ooooo`03o`000?oooooo
oooo017ooooo0ol00004ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`06ooooo`05oa0@4?ooooooooooooooool@4100Joooool00:[ooooo00?oEEEE
ofIVI_l000004Oooool2o`0002Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06
ooooo`05o`000?ooooooooooooooool00000Joooool00;_ooooo0ol0000Wooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000006_ooooo002i
ooooo`;o000000?oooooo`000?ooool09oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Cooooo00Go410@oooooooooooooooooa0@401[ooooo`00]_ooool3o`0000Cooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`1[ooooo`00/oooool3o`0002oooooo00?o0000ooooooooool02Oooool2
o`0000Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1[ooooo`00/Oooool2o`0003;ooooo00?o0000
ooooooooool02?ooool01?l0003oooooooooool0001dooooo`00[_ooool3o`000003ooooool0003o
oooo037ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1aooooo`00[?ooool2o`00
00Gooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
077ooooo002Yooooo`?o0000>_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo073o
oooo002Wooooo`;o0000?Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo06oooooo
002Tooooo`?o000000?oooooo`000?ooool0??ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo06oooooo002Rooooo`;o0000@_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo06kooooo001gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08oooool3o`0004Cooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1]ooooo`00Moooool01OmgMgOoV9RHoooooonHV9So
MgMg027ooooo0_l00017ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0K?ooool0
07Oooooo00Go410@oooooooooooooooooa0@400Nooooo`?o00000_ooool00ol0003oooooooooo`14
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0K?ooool007Oooooo00Go0000oooo
ooooooooooooo`00000Looooo`;o0000C?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo06_ooooo001gooooo`05o`000?ooooooooooooooool000006Oooool3o`0004kooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`1Zooooo`00Moooool01Ol@413ooooooooooooooooo
410@01Kooooo0ol0001Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0J_ooool0
07Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Dooooo`;o00000oooool00ol0003oooooooooo`1>
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0JOooool007Oooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Aooooo`?o0000E_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo06Sooooo002;ooooo`;o0000FOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
06Sooooo0028ooooo`?o0000Foooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo06Oo
oooo0026ooooo`;o00000oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo01Gooooo
0_l0001Xooooo`00Poooool3o`00063ooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`1Uooooo`00POooool2o`0006?ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1U
ooooo`00O_ooool4o`0006Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`1Toooo
o`00O?ooool2o`0000Cooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo06?ooooo001iooooo`?o0000J_ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo06?ooooo001gooooo`;o0000KOooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo06;ooooo001dooooo`?o000000?oooooo`000?ooool0K?ooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo067ooooo001aooooo`?o0000L_ooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo063ooooo0019ooooo`Co000000?o410@ooooooooool07oooool2o`0007Go
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1Pooooo`00Boooool00ol0003ooooo
ooooo`0Nooooo`?o0000Moooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo05oooooo
0010ooooo`Ko00001Oooool00ol0003oooooooooo`0Looooo`;o00000_ooool00ol0003ooooooooo
o`1eooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0G_ooool004_ooooo00?o0000
ooooooooool06Oooool3o`0007cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1N
ooooo`00Boooool00ol0003oooooooooo`0Gooooo`;o0000Ooooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo05gooooo001;ooooo`03o`000?oooooooooo01Cooooo0ol00021ooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0G?ooool004_ooooo00?o0000ooooooooool0
4_ooool2o`0000?ooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo05_ooooo0019ooooo`03oeEEEOmVIVKo0000017ooooo0ol00026ooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool0Foooool005_ooooo0_l00029ooooo`03o`000?oooooo
oooo027ooooo0_l0001Looooo`00F?ooool3o`000003ooooool0003ooooo08Sooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`1Iooooo`00E_ooool2o`0008kooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`1Iooooo`00Doooool3o`00093ooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`1Hooooo`00D?ooool3o`0009?ooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1Gooooo`00C_ooool2o`0000;ooooo00?o0000ooooooooool0TOooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo05Kooooo001;ooooo`?o00001Oooool00ol0
003oooooooooo`2@ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0E_ooool004Wo
oooo0_l0002Kooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0EOooool004Kooooo
1?l0002Looooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0E?ooool004Cooooo0_l0
002Pooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0E?ooool001[ooooo1Ol0000R
ooooo`?o0000X_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo05?ooooo000Joooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@08?ooool2o`000:Gooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`1Booooo`004_ooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h07_ooool3o`00
0003ooooool0003ooooo0:Cooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`1Aoooo
o`007?ooool00onHV9So8B4Qonk^kP0Kooooo`;o0000Z_ooool00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo057ooooo000Mooooo`03ogMgMomVIVKooooo01Oooooo0ol0002]ooooo`03o`00
0?oooooooooo02_ooooo00?o0000ooooooooool0D?ooool001kooooo00?o0000ooooooooool05?oo
ool2o`000;3ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`1?ooooo`006_ooool0
1Ol0003o^[ZjoooooonHV9So410@01?ooooo0ol00002ooooo`03o`000?oooooooooo0:gooooo00?o
0000ooooooooool0;?ooool2o`00053ooooo000Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`04?oo
ool3o`000;Gooooo00?o0000ooooooooool0;?ooool2o`00053ooooo000]ooooo`;o0000^?ooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo04gooooo000Zooooo`?o000000?oooooo`00
0?ooool0]oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo04gooooo000Xooooo`;o
0000_Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo04cooooo000Uooooo`?o0000
_oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo04_ooooo000Tooooo`;o0000`Ooo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo04[ooooo000Jooooo`Co000000?o410@
ooooooooool00oooool00ol0003oooooo`000030ooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool0B_ooool001cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0002o
ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0BOooool0017ooooo1_l00005oooo
o`03o`000?oooooooooo00Gooooo0_l00002ooooo`03o`000?oooooooooo0;cooooo00?o0000oooo
ooooool0<oooool00ol0003oooooooooo`18ooooo`007?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0^oooool00ol0003oooooooooo`0cooooo`03
o`000?oooooooooo00Oooooo1Ol0000looooo`007?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo00Kooooo00GoV9RHob4Q8Oo^k^koooooodA4A00looooo`007?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00ol0003ooooo
ooooo`0eooooo`03o`000?oooooooooo00Kooooo00?oV9RHob4Q8Oo^k^h0?Oooool001cooooo00?o
0000ooooooooool01?ooool3o`0000Kooooo00?o0000ooooooooool0^?ooool00ol0003ooooooooo
o`0fooooo`03o`000?oooooooooo00Kooooo00?oV9RHob4Q8Oo^k^h0??ooool001[ooooo00?oEEEE
ofIVI_l000001_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;Oooooo00?o0000
ooooooooool0=_ooool00ol0003oooooooooo`07ooooo`03ogMgMomVIVKooooo03_ooooo000Soooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0]_ooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0>_ooool002?ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`2eooooo`03o`000?oooooooooo03Oooooo0_l00004ooooo`05
o`000?nj^[[ooooooiRHV?l@4100??ooool002?ooooo0_l0000;ooooo`03o`000?oooooooooo0;Co
oooo00?o0000ooooooooool0=_ooool00ol0003oooooo`000004ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`0??ooool002?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`2cooooo`03
o`000?oooooooooo03Wooooo00?o0000ooooooooool0@_ooool002;ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0
@Oooool002;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`2`ooooo`;o0000?Ooo
ool00ol0003oooooooooo`10ooooo`008_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo0:cooooo0ol000000ooooooo0000ooooo`0looooo`03o`000?oooooooooo043ooooo000Roooo
o`;o00004Oooool00ol0003oooooooooo`2Xooooo`?o00001Oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo03oooooo000Rooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool0Y?ooool3o`0000Wooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0nooooo`00
8_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo0:3ooooo0ol0000=ooooo`03o`00
0?oooooooooo03[ooooo00?o0000ooooooooool0?_ooool002;ooooo0ol0000Cooooo`03o`000?oo
oooooooo09cooooo0ol0000Aooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0?Ooo
ool002;ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`2Iooooo`;o00005?ooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo03cooooo000Qooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool0UOooool3o`0001Oooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`0kooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo097ooooo0ol0000Kooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0>oooool0
00Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0SOooool3o`0001oooooo00?o0000
ooooooooool0>_ooool00ol0003oooooooooo`0jooooo`001Ol00002ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`02ooooo`;o00006_ooool00ol0003oooooooooo`29
ooooo`?o00008oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03Wooooo0007oooo
o`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool0Q_ooool2o`0002Kooooo00?o0000ooooooooool0>_ooool2
o`0003[ooooo0007ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`22ooooo`?o0000:Ooo
ool00ol0003oooooooooo`0iooooo`;o0000>_ooool000Oooooo00Go410@oooooooooooooooooa0@
400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`1nooooo`?o0000;Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03Oooooo0007
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`;o00007_oo
ool00ol0003oooooooooo`1jooooo`?o0000<Oooool00ol0003oooooooooo`0iooooo`03o`000?oo
oooooooo03Oooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Cooooo0_l0
000Pooooo`03o`000?oooooooooo07Kooooo0ol0000eooooo`03o`000?oooooooooo03Wooooo00?o
0000ooooooooool0=_ooool0023ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1b
ooooo`?o0000>?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03Gooooo000Poooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool0Koooool2o`0003cooooo00?o0000oooo
ooooool0>_ooool00ol0003oooooooooo`0dooooo`008?ooool2o`0002?ooooo00?o0000oooooooo
ool0Joooool3o`0003oooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0dooooo`00
8?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo06Oooooo0ol00013ooooo`03o`00
0?oooooooooo03Wooooo00?o0000ooooooooool0<oooool0023ooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`1Sooooo`?o0000Aoooool00ol0003oooooooooo`0iooooo`03o`000?oo
oooooooo03;ooooo000Pooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0Goooool3
o`0004[ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0booooo`008?ooool00ol0
003oooooooooo`0Vooooo`;o0000GOooool2o`0004kooooo00?o0000ooooooooool0>Oooool00ol0
003oooooooooo`0aooooo`007oooool3o`0002Wooooo00?o0000ooooooooool0Eoooool3o`00057o
oooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0`ooooo`007oooool00ol0003ooooo
ooooo`0Zooooo`03o`000?oooooooooo05?ooooo0ol0001Eooooo`03o`000?oooooooooo03Wooooo
00?o0000ooooooooool0;oooool001oooooo00?o0000ooooooooool0:oooool00ol0003ooooooooo
o`1?ooooo`?o0000F?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02oooooo000O
ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0Boooool3o`0005cooooo00?o0000
ooooooooool0>?ooool2o`00033ooooo000Oooooo`?o0000;Oooool00ol0003oooooooooo`17oooo
o`?o0000H?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02gooooo000Oooooo`03
o`000?oooooooooo02kooooo00?o0000ooooooooool0A?ooool2o`0006Cooooo00?o0000oooooooo
ool0>?ooool00ol0003oooooooooo`0]ooooo`005?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Ko
oooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`10ooooo`?o0000Ioooool00ol0003o
ooooooooo`0hooooo`03o`000?oooooooooo02cooooo000Dooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo03cooooo0ol0001Zooooo`03
o`000?oooooooooo03Wooooo00?o0000ooooooooool0:oooool001Cooooo00Go410@oooooooooooo
oooooa0@4005ooooo`;o0000<oooool00ol0003oooooooooo`0hooooo`?o0000K_ooool00ol0003o
ooooooooo`0iooooo`03o`000?oooooooooo02[ooooo000Dooooo`05o`000?ooooooooooooooool0
00001Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo03Cooooo0ol0001booooo`03
o`000?oooooooooo03Sooooo00?o0000ooooooooool0:_ooool001Cooooo00Go0000oooooooooooo
ooooo`000005ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0<?ooool3o`0007Ko
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Yooooo`005?ooool01Ol@413ooooo
oooooooooooo410@00Gooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0]ooooo`;o
0000N_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02Sooooo000Dooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo02Wo
oooo0ol0001looooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0:?ooool001Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o0000>?ooool00ol0003oooooooooo`0Uooooo`?o
0000P?ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02Oooooo000Nooooo`03o`00
0?oooooooooo03Sooooo00?o0000ooooooooool08Oooool3o`0008Cooooo00?o0000ooooooooool0
>?ooool00ol0003oooooooooo`0Vooooo`007Oooool00ol0003oooooooooo`0jooooo`03o`000?oo
oooooooo01gooooo0ol00028ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool09Ooo
ool001gooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Jooooo`;o0000S?ooool0
0ol0003oooooooooo`0gooooo`03o`000?oooooooooo02Gooooo000Mooooo`;o0000?Oooool00ol0
003oooooooooo`0Fooooo`?o0000S_ooool00ol0003oooooooooo`0gooooo`;o00009_ooool001go
oooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Booooo`?o0000T_ooool00ol0003o
ooooooooo`0hooooo`03o`000?oooooooooo02?ooooo000Mooooo`03o`000?oooooooooo03kooooo
00?o0000ooooooooool03_ooool3o`0009Kooooo00?o0000ooooooooool0=oooool00ol0003ooooo
ooooo`0Sooooo`007Oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00[ooooo0ol0
002Jooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool08_ooool001gooooo00?o0000
ooooooooool0@?ooool00ol0003oooooooooo`06ooooo`?o0000W_ooool00ol0003oooooooooo`0g
ooooo`03o`000?oooooooooo027ooooo000Looooo`?o0000@_ooool00ol0003oooooooooo`03oooo
o`;o0000XOooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo023ooooo000Looooo`03
o`000?oooooooooo04?ooooo00?o0000ooooool000000_l0002Tooooo`03o`000?oooooooooo03Oo
oooo00?o0000ooooooooool08?ooool001cooooo00?o0000ooooooooool0@_ooool3o`000:Sooooo
00?o0000ooooooooool0=oooool00ol0003oooooooooo`09ooooo`;o000000?o410@ooooooooool0
4Oooool001cooooo00?o0000ooooooooool0?oooool3o`0000?ooooo00?o0000ooooooooool0Y_oo
ool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04_oo
ool001cooooo0ol0000looooo`?o00001oooool00ol0003oooooooooo`2Vooooo`03o`000?oooooo
oooo03Kooooo00?o0000ooooooooool01_ooool5o`0001?ooooo000Looooo`03o`000?oooooooooo
03Wooooo0ol0000;ooooo`03o`000?oooooooooo0:Gooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`05ooooo`04odA4A?oMgMgoooooo`0001Cooooo00001_ooooook^k^oc8b<_l0003o
<S8bonk^kPGooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooo
ooooo`0gooooo`;o00003oooool00ol0003oooooooooo`2Uooooo`03o`000?oooooooooo03Oooooo
00?o0000ooooooooool01?ooool01?oMgMgoEEEEooooool0000Dooooo`0000KoooooogMgMonHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
03Cooooo0ol0000Booooo`03o`000?oooooooooo0:Gooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`05ooooo`03ogMgMoo<c<co000001Cooooo00000ooooooo410@ooooo`02ooooo`03
oa0@4?oooooooooo00kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0aooooo`?o
00005_ooool00ol0003oooooooooo`2Uooooo`03o`000?oooooooooo03Kooooo0_l00005ooooo`03
onk^k_m4A4Co000001Cooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00gooooo
00?oMgMgoc8b<_ooool00oooool2o`00033ooooo0ol0000Jooooo`03o`000?oooooooooo0:Gooooo
00?o0000ooooooooool0=?ooool00ol0003oooooo`000006ooooo`03ogMgMol0003ooooo01?ooooo
00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00[ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c004ooooo`03o`000?oooooooooo02cooooo0ol0000Nooooo`03o`000?oooooooooo0:Cooooo
00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Iooooo`0000?ooooooa0@4?ooool00_oo
ool00ol@413oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0:_oo
ool2o`0002;ooooo00?o0000ooooooooool0Y?ooool00ol0003oooooooooo`0fooooo`03o`000?oo
oooooooo01Wooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`cooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Wooooo`?o00009Oooool2o`000:Gooooo00?o0000ooooooooool0
=_ooool00ol0003oooooooooo`0Hooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h<ooooo`Co
00001Oooool2o`0002Gooooo0ol0000Zooooo`03o`000?oooooooooo0:?ooooo00?o0000oooooooo
ool0=_ooool00ol0003oooooooooo`0Gooooo`006oooool00ol0003oooooooooo`0Qooooo`?o0000
;_ooool00ol0003oooooooooo`2Sooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0
5oooool001_ooooo00?o0000ooooooooool07_ooool3o`0003;ooooo00?o0000ooooooooool0X_oo
ool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo01Kooooo000Kooooo`03o`000?oooooo
oooo01_ooooo0ol0000fooooo`03o`000?oooooooooo0:;ooooo00?o0000ooooooooool0=_ooool0
0ol0003oooooooooo`0Eooooo`006_ooool00ol0003oooooooooo`0Jooooo`;o0000>_ooool00ol0
003oooooooooo`2Rooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool05?ooool001[o
oooo0_l0000Hooooo`?o0000?Oooool00ol0003oooooooooo`2Rooooo`03o`000?oooooooooo03Go
oooo00?o0000ooooooooool05?ooool001[ooooo00?o0000ooooooooool05?ooool3o`00047ooooo
00?o0000ooooooooool0XOooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo01?ooooo
000Jooooo`03o`000?oooooooooo017ooooo0ol00015ooooo`03o`000?oooooooooo0:7ooooo00?o
0000ooooooooool0=_ooool00ol0003oooooooooo`0Booooo`006_ooool00ol0003oooooooooo`0>
ooooo`?o0000BOooool00ol0003oooooooooo`2Qooooo`03o`000?oooooooooo03Gooooo0_l0000C
ooooo`006_ooool00ol0003oooooooooo`0<ooooo`;o0000COooool00ol0003oooooooooo`2Qoooo
o`03o`000?oooooooooo03Cooooo0_l0000Cooooo`006Oooool3o`0000[ooooo0ol0001@ooooo`03
o`000?oooooooooo0:7ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0@ooooo`00
6_ooool00ol0003oooooooooo`06ooooo`?o0000E?ooool00ol0003oooooooooo`2Pooooo`03o`00
0?oooooooooo03Kooooo00?o0000ooooooooool03oooool001Wooooo00?o0000ooooooooool01?oo
ool3o`0005Sooooo00?o0000ooooooooool0X?ooool00ol0003oooooooooo`0eooooo`03o`000?oo
oooooooo00oooooo000Iooooo`04o`000?ooooooooooooooo`?o0000G?ooool00ol0003ooooooooo
o`2Pooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool03_ooool001Wooooo1?l0001P
ooooo`03o`000?oooooooooo0:3ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0=
ooooo`006Oooool2o`0006?ooooo00?o0000ooooooooool0X?ooool00ol0003oooooooooo`0doooo
o`03o`000?oooooooooo00gooooo000?ooooo`Co000000?o410@ooooooooool01Oooool00ol0003o
ooooooooo`1Qooooo`03o`000?oooooooooo09oooooo00?o0000ooooooooool0=Oooool00ol0003o
ooooooooo`0<ooooo`004Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo067ooooo
00?o0000ooooooooool0Woooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00_ooooo
000Aooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0HOooool00ol0003ooooooooo
o`2Oooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool02_ooool0017ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo09oooooo00?o0000
ooooooooool0=?ooool00ol0003oooooooooo`0:ooooo`004Oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo067ooooo00?o0000ooooooooool0Woooool00ol0003oooooooooo`06oooo
o`;ooiT0;?ooool00ol0003oooooooooo`09ooooo`004Oooool00ol0003oooooooooo`0<ooooo`;o
0000H_ooool00ol0003oooooooooo`2Nooooo`03o`000?oooooooooo00Gooooo00?ooiT0oooooooo
ool0:oooool3o`0000[ooooo000Aooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
H?ooool00ol0003oooooooooo`2Nooooo`03o`000?oooooooooo00;ooooo0_ooV@0[ooooo`?o0000
0_ooool00ol0003oooooooooo`08ooooo`003oooool00omEEEGoIVIVo`00000Aooooo`03o`000?oo
oooooooo063ooooo00?o0000ooooooooool0W_ooool01?l0003ooooooonI0?ooV@0Zooooo`?o0000
1Oooool00ol0003oooooooooo`08ooooo`009?ooool00ol0003oooooooooo`1Pooooo`03o`000?oo
oooooooo09kooooo00?o0000ooooooooool09_ooool4o`0000Sooooo00?o0000ooooooooool02?oo
ool002Gooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`2Kooooo`;ooiT000?ooooo
o`000?ooool08oooool3o`0000cooooo00?o0000ooooooooool02?ooool002Kooooo00?o0000oooo
ooooool0H?ooool00ol0003oooooooooo`2Iooooo`05oonI0?ooooooooooooooool000002?ooool2
olco01Oooooo0ol0000@ooooo`03o`000?oooooooooo00Oooooo000Wooooo`03o`000?oooooooooo
063ooooo00?o0000ooooooooool0U_ooool2oonI00Gooooo00?o0000ooooooooool00oooool2olco
01Gooooo1?l0000Cooooo`03o`000?oooooooooo00Oooooo000Xooooo`;o0000HOooool00ol0003o
ooooooooo`2Cooooo`;ooiT02?ooool01Ol0003oooooooooooooooooc?l001Cooooo0ol0000Goooo
o`03o`000?oooooooooo00Oooooo000Zooooo`03o`000?oooooooooo05oooooo00?o0000oooooooo
ool0T?ooool2oonI00_ooooo00?o0000olco0?o<o`004_ooool3o`0001[ooooo00?o0000oooooooo
ool01oooool002_ooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`2=ooooo`;ooiT0
3?ooool2olco0003o`000?oooooooooo00gooooo1?l0000Mooooo`03o`000?oooooooooo00Oooooo
000/ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool0Roooool00oooV@3ooooooooo
o`0;ooooo`04olco0?ooooooooooo`0000cooooo0ol0000Qooooo`03o`000?oooooooooo00Oooooo
000]ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool0R?ooool2oonI00cooooo0_o<
o`04ooooo`03o`000?oooooooooo00Gooooo0_lco`02o`0002Cooooo00?o0000ooooooooool01ooo
ool002kooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`25ooooo`;ooiT03?ooool2
olco00Oooooo00Go0000ooooooooooooooooo`000002oc?o0003o`000?oooooooooo02Gooooo00?o
0000ooooooooool01oooool002oooooo0_l0001Pooooo`03o`000?oooooooooo08;ooooo0_ooV@0<
ooooo`;oc?l02_ooool3o`000003oc?o0?oooooooooo02Wooooo00?o0000ooooooooool01_ooool0
037ooooo00?o0000ooooooooool0G_ooool2o`00083ooooo0_ooV@0=ooooo`03olco0?oooooooooo
00Oooooo0ol000000ooooooo0000oc?o000/ooooo`03o`000?oooooooooo00Kooooo000booooo`03
o`000?oooooooooo05oooooo00?o0000ooooooooool0Noooool2oonI00gooooo0_o<o`07ooooo`?o
00000_ooool2oc?o0003o`000?oooooooooo02_ooooo00?o0000ooooooooool01_ooool003?ooooo
00?o0000ooooooooool0Goooool00ol0003oooooooooo`1gooooo`?ooiT03Oooool2olco00Gooooo
1?l00004ooooo`05oc?o0?ooooooooooooooool00000;?ooool00ol0003oooooooooo`06ooooo`00
=?ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo07Cooooo0_ooV@0?ooooo`03olco
0?oooooooooo00;ooooo0ol00006ooooo`;o<ol01Oooool00ol0003oooooooooo`04ooooo`;o0?mV
8oooool00ol0003oooooooooo`06ooooo`00=Oooool00ol0003oooooooooo`1Oooooo`03o`000?oo
oooooooo077ooooo0_ooV@0?ooooo`;oc?l00_ooool3o`0000Oooooo0_lco`08ooooo`03o`000?oo
oooooooo00;ooooo00?o0?mVooooooooool08oooool00ol0003oooooooooo`06ooooo`00=_ooool0
0ol0003oooooooooo`1Oooooo`03o`000?oooooooooo06kooooo0_ooV@0?ooooo`;oc?l01?l00008
ooooo`;o<ol02oooool01?l0003oooooo`3oI_l0ofHVooooo`03o`000?oooooooooo00Kooooo000g
ooooo`;o0000H?ooool00ol0003oooooooooo`1Zooooo`?ooiT03_ooool3olco00;o00002_ooool2
oc?o00gooooo00?o0000o`3oI_ooool09oooool00ol0003oooooooooo`06ooooo`00>Oooool00ol0
003oooooooooo`1Nooooo`03o`000?oooooooooo06Kooooo0oooV@0?ooooo`;oc?l00_l0000;oooo
o`;o<ol03_ooool2o`3oIP03o`000?oooooooooo02Oooooo00?o0000ooooooooool01Oooool003[o
oooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`1Rooooo`?ooiT03oooool01?l0003o
c?l0olco0?l0000=ooooo`03oc?o0?oooooooooo00gooooo00Go0?mVooooooooooooooooo`00000X
ooooo`03o`000?oooooooooo00Gooooo000kooooo`03o`000?oooooooooo05kooooo00?o0000oooo
ooooool0G_ooool3oonI00oooooo00Co0000olco0?o<o`3oc?l03_ooool2oc?o00kooooo0_l0ofH5
ooooo`03o`000?oooooooooo00?ooooo0_l0oolPooooo`03o`000?oooooooooo00Gooooo000loooo
o`03o`000?oooooooooo05kooooo00?o0000ooooooooool0F_ooool3oonI00oooooo0_l00002olco
00oooooo0_lco`0?ooooo`03o`3oI_oooooooooo00Gooooo00?o0000ooooooooool00_ooool00ol0
ooooooooooooo`0Pooooo`03o`000?oooooooooo00Gooooo000mooooo`03o`000?oooooooooo05ko
oooo00?o0000ooooooooool0E_ooool3oonI00kooooo1?l00002olco00oooooo0_lco`0?ooooo`;o
0?mV2Oooool01?l0003oooooo`3oool0oolSooooo`03o`000?oooooooooo00Gooooo000nooooo`;o
0000Goooool00ol0003oooooooooo`1Aooooo`CooiT03_ooool3o`000004ooooooo<o`3oc?l0olco
00kooooo0olco`0>ooooo`?o0?mV2oooool00ol0oooo0000ooooo`0Tooooo`03o`000?oooooooooo
00Gooooo0010ooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool0COooool3oonI00oo
oooo0ol000001?ooooooc?l0olco0?o<o`0?ooooo`;o<ol03oooool2o`3oIPgooooo00Co0?oooooo
oooooooo00009?ooool00ol0003oooooooooo`05ooooo`00@Oooool00ol0003oooooooooo`1Moooo
o`03o`000?oooooooooo04Sooooo1?ooV@0>ooooo`Co000000Coooooolco0?o<o`3oc?l04?ooool2
oc?o00oooooo0_l0ofH=ooooo`;o0?oo1?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo00Gooooo0012ooooo`03o`000?oooooooooo05gooooo00?o0000ooooooooool0@oooool4oonI
00oooooo0ol00002ooooo`?oc?l04?ooool3oc?o00kooooo0ol0ofH=ooooo`;o0?oo1_ooool00ol0
003oooooooooo`03ooooo`;o06Ko7?ooool00ol0003oooooooooo`05ooooo`00@oooool00ol0003o
ooooooooo`1Mooooo`03o`000?oooooooooo03oooooo0oooV@0@ooooo`?o00000oooool2olco017o
oooo0_lco`0?ooooo`;o0?mV3oooool00ol0ooooooooooooo`07ooooo`05o`000?oooooooooooooo
ool0I_l07oooool00ol0003oooooooooo`04ooooo`00A?ooool00ol0003oooooooooo`1Mooooo`03
o`000?oooooooooo03[ooooo1?ooV@0?ooooo`Co00000oooool3olco017ooooo0_lco`0?ooooo`;o
0?mV3oooool2o`3oo`_ooooo00?o0000o`1Vool0I_l08?ooool00ol0003oooooooooo`04ooooo`00
AOooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo03?ooooo1_ooV@0@ooooo`?o0000
1?ooool3olco017ooooo0olco`0>ooooo`?o0?mV3_ooool3o`3oo`cooooo0_l0I_l00ol0003ooooo
ooooo`0Oooooo`03o`000?oooooooooo00Cooooo0016ooooo`;o0000G_ooool00ol0003ooooooooo
o`0[ooooo`OooiT04oooool3o`0000Cooooo0oo<o`0Aooooo`?o<ol03oooool2o`3oIPoooooo0_l0
ool>ooooo`05o`1Vooooooooooooooooool000008?ooool00ol0003oooooooooo`04ooooo`00B?oo
ool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo02;ooooo2?ooV@0Fooooo`Co00001?oo
ool3olco017ooooo0olco`0@ooooo`;o0?mV3oooool2o`3oo`kooooo0_l0I_l4ooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool01?ooool004Wooooo00?o0000ooooooooool0G?ooool0
0ol0003oooooooooo`0Jooooo`OooiT06oooool3o`0000Cooooo1?o<o`0Aooooo`?o<ol04?ooool3
o`3oIPkooooo0ol0ool>ooooo`;o06Ko1oooool00ol0003oooooooooo`02ooooo`;o<`3o6Oooool0
0ol0003oooooooooo`04ooooo`00B_ooool00ol0003oooooooooo`1Looooo`03o`000?oooooooooo
017ooooo2?ooV@0Oooooo`?o00000_ooool5olco01;ooooo0olco`0Aooooo`;o0?mV3oooool2o`3o
oa3ooooo00?o06Koooooooooool02?ooool01?l0003ooooooooooolc0?lKooooo`03o`000?oooooo
oooo00Cooooo001;ooooo`03o`000?oooooooooo05cooooo00?o0000ooooooooool02Oooool7oonI
02?ooooo1?l00005olco01Cooooo0olco`0Booooo`;o0?mV3oooool2o`3ooa3ooooo0_l0I_l<oooo
o`03o`000?lc0?oooooo01_ooooo00?o0000ooooooooool01?ooool004cooooo00?o0000oooooooo
ool0G?ooool00ol0003oooooooooo`04ooooo`CooiT09oooool00ol0003oc?l0olco0004olco01Ko
oooo0olco`0Booooo`?o0?mV3oooool2o`3ooa3ooooo0_l0I_l<ooooo`;o<`3o00?oooooo`000?oo
ool07?ooool00ol0003oooooooooo`03ooooo`00COooool2o`0005gooooo00?o0000ooooooooool0
:_ooool5olco01Wooooo0olco`0Cooooo`;o0?mV4?ooool2o`3ooa3ooooo0_l0I_l=ooooo`05oc<0
ooooooooooooooooool000007Oooool00ol0003oooooooooo`03ooooo`00Coooool00ol0003ooooo
ooooo`1Kooooo`03o`000?oooooooooo02Cooooo1Oo<o`000ol0003oooooooooo`0Hooooo`?o<ol0
4oooool3o`3oIQ3ooooo0_l0ool@ooooo`;o06Ko3Oooool2oc<0o`Gooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`03ooooo`00D?ooool00ol0003oooooooooo`1Kooooo`03o`000?oo
oooooooo01cooooo1oo<o`03o`0001Wooooo1?lco`0Dooooo`;o0?mV4Oooool2o`3ooa3ooooo0_l0
I_l=ooooo`;o<`3o2?ooool01?l0003oooooooooooooool2ol`0oaKooooo00?o0000ooooooooool0
0oooool0057ooooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`0Dooooo`Ooc?l00ooo
ool3o`0001Wooooo1?lco`0Eooooo`?o0?mV4Oooool2o`3ooa3ooooo0_l0I_l>ooooo`03oc<0oooo
oooooooo00Wooooo00?o0000ol`0ooo<0?l06?ooool00ol0003oooooooooo`03ooooo`00D_ooool0
0ol0003oooooooooo`1Kooooo`03o`000?oooooooooo00Sooooo2oo<o`07ooooo`?o00006Oooool3
oc?o01Kooooo0ol0ofHBooooo`;o0?oo4?ooool2o`1Vo`kooooo0_lc0?l<ooooo`03ol`0ool0003o
oooo01Sooooo00?o0000ooooooooool00oooool005?ooooo00?o0000ooooooooool0Foooool00ol0
003oooooolco0007olco00kooooo1?l0000Hooooo`Co<ol05Oooool4o`3oIQ;ooooo0ol0ool@oooo
o`;o06Ko3_ooool2oc<0o`cooooo0_o<0?l00ooooooo0000ooooo`0Hooooo`03o`000?oooooooooo
00?ooooo001Dooooo`;o0000G?ooool00ol0003oooooooooo`0Aooooo`?o00005oooool5oc?o01Go
oooo1?l0ofHCooooo`?o0?oo4?ooool3o`1Vo`kooooo0_lc0?l<ooooo`;oc03o1?ooool00ol0003o
ooooooooo`0Fooooo`03o`000?oooooooooo00?ooooo001Fooooo`03o`000?oooooooooo05[ooooo
00?o0000ooooooooool03Oooool3o`0001Gooooo1Olco`0Fooooo`Co0?mV5?ooool3o`3ooa3ooooo
0ol0I_l>ooooo`?o<`3o3?ooool2ol`0o`Oooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`02ooooo`00Eoooool00ol0003oooooooooo`1Jooooo`03o`000?oooooooooo00Sooooo1?l0
000Cooooo`Go<ol05oooool4o`3oIQGooooo0ol0oolAooooo`;o06Ko3oooool2oc<0o`kooooo00?o
c03oooooooooool02?ooool00ol0003oooooooooo`02ool0VA?ooooo00?o0000ooooooooool00_oo
ool005Sooooo00?o0000ooooooooool0F_ooool00ol0003oooooooooo`04ooooo`?o00004?ooool7
oc?o01Sooooo1?l0ofHFooooo`?o0?oo4Oooool3o`1Vo`oooooo0_lc0?l>ooooo`;oc03o3?ooool0
0ol0003oo`2Iooooo`0Dooooo`03o`000?oooooooooo00;ooooo001Iooooo`03o`000?oooooooooo
05[ooooo00?o0000ooooooooool00ol0000;ooooo`So<ol06oooool4o`3oIQKooooo1?l0oolAoooo
o`?o06Ko4?ooool2oc<0o`kooooo0_o<0?l=ooooo`03ool0VOl0003ooooo01Gooooo00?o0000oooo
ooooool00_ooool005[ooooo00?o0000ooooooooool0F_ooool2o`0000;ooooo3?lco`0Oooooo`Co
0?mV5oooool3o`3ooa?ooooo0_l0I_lAooooo`;o<`3o3_ooool2ol`0o`gooooo0_oo09T2ooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool00_ooool005_ooooo00?o0000ooooooooool0
EOooool8oc?o02Kooooo1Ol0ofHHooooo`?o0?oo4oooool3o`1Voa3ooooo0olc0?l>ooooo`;oc03o
3Oooool2ool0V@Gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`02ooooo`00G?oo
ool2o`0005Wooooo00?o0000ooooooooool08_ooool5o`3oIQ[ooooo0ol0oolCooooo`?o06Ko4?oo
ool3oc<0o`kooooo0oo<0?l=ooooo`;oo`2I2?ooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo00;ooooo001Nooooo`03o`000?oooooooooo05Kooooo00?o0000ooooooooool07Oooool5
o`3oIQcooooo0ol0oolCooooo`?o06Ko4Oooool2oc<0o`oooooo0_o<0?l?ooooo`03ool0VOoooooo
oooo00Wooooo00Co0000oooooooo003oo`003oooool00ol0003oooooooooo`02ooooo`00Goooool0
0ol0003oooooooooo`1Eooooo`03o`000?oooooooooo01Kooooo1ol0ofHMooooo`Co0?oo4oooool3
o`1Voa7ooooo0olc0?l?ooooo`;oc03o3oooool2ool0V@cooooo00?o0000ool00?ooool04Oooool0
0ol0003oooooooooo`01ooooo`00H?ooool00ol0003oooooooooo`1Dooooo`03o`000?oooooooooo
00kooooo2?l0ofHPooooo`Co0?oo4oooool4o`1Voa7ooooo0olc0?l@ooooo`;oc03o3oooool2ool0
V@gooooo00?oo`00ooooool000004_ooool00ol0003oooooooooo`01ooooo`00HOooool00ol0003o
ooooooooo`1Cooooo`03o`000?oooooooooo00;ooooo3?l0ofHTooooo`Co0?oo5?ooool3o`1Voa?o
oooo0_lc0?lAooooo`;oc03o3oooool2ool0V@gooooo0_oo0003ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool00Oooool006;ooooo00?o0000ooooooooool0Coooool8o`3oIRcooooo
1?l0oolDooooo`Co06Ko4oooool3oc<0oa3ooooo0oo<0?l>ooooo`?oo`2I3Oooool2ool000Kooooo
00?o0000ooooooooool03_ooool00ol0003oooooooooo`01ooooo`00Hoooool2o`0005;ooooo00?o
0000ooooooooool0:Oooool5o`3ooaGooooo0ol0I_lDooooo`?o<`3o4?ooool3ol`0o`oooooo0_oo
09T>ooooo`;oo`002Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo007ooooo001U
ooooo`03o`000?oooooooooo04oooooo00?o0000ooooooooool08oooool6o`3ooaOooooo0ol0I_lE
ooooo`;o<`3o4Oooool2ol`0oa3ooooo0_oo09T?ooooo`03ool00?oooooooooo00Wooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`01ooooo`00I_ooool00ol0003oooooooooo`1>oooo
o`03o`000?oooooooooo01kooooo1Ol0oolIooooo`Co06Ko5Oooool3oc<0oa3ooooo0oo<0?l?oooo
o`?oo`2I3oooool2ool000gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`01oooo
o`00Ioooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo01Oooooo1ol0oolJooooo`Co
06Ko5_ooool3oc<0oa3ooooo0oo<0?l@ooooo`;oo`2I4?ooool2ool0013ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`01ooooo`00J?ooool00ol0003oooooooooo`1<ooooo`03o`00
0?oooooooooo00kooooo2Ol0oolMooooo`Co06Ko5oooool3oc<0oa7ooooo0_o<0?lAooooo`;oo`2I
4?ooool2ool001?ooooo00?o0000ooooooooool02oooool1o`00007ooooo0Oooool006Wooooo00?o
0000ooooooooool0Boooool00ol0003oooooooooo`02ooooo`co0?oo8_ooool4o`1VoaSooooo0olc
0?lAooooo`?oc03o4Oooool2ool0V@oooooo0ooo000Eooooo`03o`000?oooooooooo00_ooooo0Ol0
0001ooooo`7ooooo001Zooooo`03o`000?oooooooooo04Oooooo2?l0oolYooooo`Go06Ko6?ooool4
oc<0oa7ooooo0oo<0?lAooooo`?oo`2I3oooool2ool001Wooooo00?o0000ooooooooool02_ooool1
o`00007ooooo0Oooool006_ooooo0_l0001:ooooo`03o`000?oooooooooo02Gooooo1_l0I_lJoooo
o`?o<`3o4oooool2ol`0oa;ooooo0_oo09T@ooooo`;oo`007?ooool00ol0003oooooooooo`09oooo
o`7o00000Oooool1ooooo`00KOooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo01oo
oooo1_l0I_lMooooo`?o<`3o4oooool3ol`0oa;ooooo0_oo09T?ooooo`?oo`007oooool00ol0003o
ooooooooo`08ooooo`7o00000Oooool1ooooo`00K_ooool00ol0003oooooooooo`16ooooo`03o`00
0?oooooooooo01Sooooo1ol0I_lNooooo`Go<`3o4oooool3ol`0oa;ooooo0ooo09T?ooooo`;oo`00
8oooool00ol0003oooooooooo`07ooooo`7o00000Oooool1ooooo`00Koooool00ol0003ooooooooo
o`15ooooo`03o`000?oooooooooo00oooooo2Ol0I_lOooooo`Ko<`3o5Oooool3ol`0oa?ooooo0_oo
09T@ooooo`;oo`009Oooool00ol0003oooooooooo`07ooooo`7o00000Oooool1ooooo`00L?ooool0
0ol0003oooooooooo`14ooooo`03o`000?oooooooooo00?ooooo3?l0I_lSooooo`Go<`3o6?ooool3
ol`0oa?ooooo0ooo09T?ooooo`?oo`00:?ooool00ol0003oooooooooo`06ooooo`7o00000Oooool1
ooooo`00LOooool00ol0003oooooooooo`11ooooo`So06Ko:Oooool6oc<0oaWooooo1?o<0?lCoooo
o`?oo`2I4?ooool2ool002cooooo00?o0000ooooooooool01Oooool1o`00007ooooo0Oooool007;o
oooo0_l00012ooooo`03o`000?oooooooooo02Oooooo1_lc0?lKooooo`Coc03o4oooool4ool0VA3o
oooo0ooo000_ooooo`03o`000?oooooooooo00Gooooo0Ol00001ooooo`00M?ooool00ol0003ooooo
ooooo`0oooooo`03o`000?oooooooooo02;ooooo1Olc0?lNooooo`?oc03o5?ooool3ool0VA;ooooo
0_oo000cooooo`03o`000?oooooooooo00Cooooo0Ol00001ooooo`00MOooool00ol0003ooooooooo
o`0nooooo`03o`000?oooooooooo01cooooo1_lc0?lOooooo`Coc03o5?ooool3ool0VA?ooooo0_oo
000eooooo`03o`000?oooooooooo00Cooooo0Ol00001ooooo`00M_ooool00ol0003oooooooooo`0m
ooooo`03o`000?oooooooooo01Kooooo1_lc0?lQooooo`Coc03o5?ooool4ool0VA?ooooo0ooo000h
ooooo`03o`000?oooooooooo00?ooooo0Ol00001ooooo`00Moooool00ol0003oooooooooo`0loooo
o`03o`000?oooooooooo013ooooo1_lc0?lRooooo`Goc03o5Oooool3ool0VAGooooo0_oo000loooo
o`03o`000?oooooooooo00;ooooo0Ol00001ooooo`00N?ooool00ol0003oooooooooo`0kooooo`03
o`000?oooooooooo00Gooooo2olc0?lTooooo`Coc03o5_ooool4ool0VAGooooo0ooo000oooooo`05
o`000?ooooooooooooooool000000Oooool007Wooooo00?o0000ooooooooool0>Oooool9oc<0ob[o
oooo1Oo<0?lGooooo`?oo`2I5_ooool3ool004?ooooo00Co0000oooooooooooo00000Oooool007[o
oooo0_l0000jooooo`03o`000?oooooooooo02Wooooo1_o<0?lIooooo`?oo`2I5_ooool3ool004Ko
oooo00Co0000oooooooooooo00000Oooool007cooooo00?o0000ooooooooool0=oooool00ol0003o
ooooooooo`0Sooooo`Koc03o6oooool4ool0VAKooooo0ooo001:ooooo`03o`000?oooooooooo007o
0000001mooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool07?ooool7ol`0oacooooo
1Ooo09TGooooo`?oo`00C_ooool1o`00007ooooo0Ol0000007kooooo00?o0000ooooooooool0=Ooo
ool00ol0003oooooooooo`0Cooooo`Woc03o7oooool4ool0VASooooo1?oo001Booooo`;o0000001o
ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool01Oooool>ol`0ob?ooooo1Ooo09TI
ooooo`?oo`00EOooool3o`000000P?ooool00ol0003oooooooooo`0booooo`Woc03o;?ooool5ool0
VA[ooooo1?oo001Dooooo`Co00000oooool0087ooooo0_l0000cooooo`03o`000?oooooooooo02[o
oooo1ooo09TLooooo`?oo`00EOooool3o`0000Oooooo0023ooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool09?ooool6ool0VB3ooooo0ooo001Dooooo`Co00002_ooool008Cooooo00?o
0000ooooooooool0;oooool00ol0003oooooooooo`0Nooooo`Koo`2I8_ooool4ool005?ooooo1?l0
000>ooooo`00QOooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01Sooooo1_oo09TS
ooooo`Goo`00Doooool4o`0001;ooooo0026ooooo`03o`000?oooooooooo02gooooo00?o0000oooo
ooooool04_ooool6ool0VBCooooo1Ooo001Dooooo`Co00005_ooool008Oooooo00?o0000oooooooo
ool0;?ooool00ol0003oooooooooo`06ooooo`coo`2I9Oooool5ool005Kooooo0ol0000Jooooo`00
R?ooool2o`0002cooooo2Ooo09T/ooooo`Goo`00Eoooool4o`0001gooooo002:ooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool0;?ooool6ool005Sooooo1?l0000Qooooo`00Roooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo02Kooooo1_oo001Jooooo`Co00009Oooool0
08cooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0Nooooo`Soo`00G?ooool4o`00
02Wooooo002=ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool05Oooool9ool0067o
oooo0ol0000]ooooo`00S_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Oooooo
3_oo001Vooooo`Co0000<?ooool008oooooo00?o0000ooooooooool09?ooool:ool0073ooooo1?l0
000dooooo`00T?ooool2o`0002Cooooo00?o0000ooooooooool0Loooool4o`0003Sooooo002Boooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool0L?ooool3o`0003cooooo002Cooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0K?ooool4o`0003oooooo002Dooooo`03o`00
0?oooooooooo01oooooo00?o0000ooooooooool0J?ooool4o`0004?ooooo002Eooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool0I?ooool4o`0004Oooooo002Fooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool0H?ooool4o`0004_ooooo002Gooooo`;o00007Oooool00ol0
003oooooooooo`1Mooooo`?o0000Coooool009Wooooo00?o0000ooooooooool06_ooool00ol0003o
ooooooooo`1Iooooo`Co0000D_ooool009[ooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`1Eooooo`Co0000E_ooool009_ooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`1Aooooo`Co0000F_ooool009cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1=
ooooo`Co0000G_ooool009gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1:oooo
o`?o0000H_ooool009kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`16ooooo`Co
0000IOooool009oooooo0_l0000Dooooo`03o`000?oooooooooo04?ooooo1?l0001Yooooo`00XOoo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo03oooooo1?l0001]ooooo`00X_ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03_ooooo1?l0001aooooo`00Xoooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo03Sooooo0ol0001eooooo`00Y?ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo03Cooooo1?l0001hooooo`00YOooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo033ooooo1?l0001looooo`00Y_ooool2o`0000gooooo00?o
0000ooooooooool0;?ooool4o`00083ooooo002Xooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool0:Oooool3o`0008Cooooo002Yooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool09Oooool4o`0008Oooooo002Zooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool08Oooool4o`0008_ooooo002[ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
7Oooool4o`0008oooooo002/ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06Ooo
ool4o`0009?ooooo002]ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool05_ooool3
o`0009Oooooo002^ooooo`;o00001Oooool00ol0003oooooooooo`0Booooo`Co0000V_ooool00;3o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0>ooooo`Co0000W_ooool00;7ooooo
00Go0000ooooooooooooooooo`00000<ooooo`Co0000X_ooool00;;ooooo00Co0000oooooooooooo
00002?ooool4o`000:Kooooo002cooooo`03o`000?oooooo000000Gooooo0ol0002Zooooo`00]?oo
ool2o`000003ooooool0003o000000;o0000[Oooool00;Gooooo0_l0002aooooo`00oooooomYoooo
o`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {319.688, 0}} -> {-0.0710364, -0.0181728, \
0.0035149, 0.0035149}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .89104 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-16 1.0656 -0.0363427 1.0656 [
[.02544 .21571 -12 -8.9133 ]
[.02544 .21571 0 .0867 ]
[.16074 .16277 -11.6592 -9 ]
[.16074 .16277 .34081 0 ]
[.3021 .10747 -5.60025 -9 ]
[.3021 .10747 .39975 0 ]
[.44992 .04965 -5.37091 -9 ]
[.44992 .04965 .62909 0 ]
[.60467 -0.01084 -5.14157 -9 ]
[.60467 -0.01084 .85843 0 ]
[.66454 .05085 0 -6.20675 ]
[.66454 .05085 6 2.79325 ]
[.80797 .25198 0 -6.0417 ]
[.80797 .25198 6 2.9583 ]
[.93071 .4241 0 -5.90576 ]
[.93071 .4241 6 3.09424 ]
[.02254 .22988 -12 -2.74631 ]
[.02254 .22988 0 6.25369 ]
[.0142 .29178 -24 -2.78907 ]
[.0142 .29178 0 6.21093 ]
[.00558 .35578 -6 -2.83339 ]
[.00558 .35578 0 6.16661 ]
[-0.00334 .42198 -18 -2.87938 ]
[-0.00334 .42198 0 6.12062 ]
[-0.01257 .49051 -6 -2.92712 ]
[-0.01257 .49051 0 6.07288 ]
[ 0 0 0 0 ]
[ 1 .89104 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03495 .22504 m
.61241 0 L
s
.03495 .22504 m
.03971 .2297 L
s
[(-2)] .02544 .21571 1 .98073 Mshowa
.16988 .17246 m
.17445 .1773 L
s
[(-1)] .16074 .16277 .9432 1 Mshowa
.31082 .11753 m
.31518 .12256 L
s
[(0)] .3021 .10747 .86675 1 Mshowa
.45818 .0601 m
.46231 .06533 L
s
[(1)] .44992 .04965 .7903 1 Mshowa
.61241 0 m
.61628 .00542 L
s
[(2)] .60467 -0.01084 .71386 1 Mshowa
.125 Mabswid
.06148 .2147 m
.06431 .21752 L
s
.08823 .20428 m
.09104 .20712 L
s
.11521 .19376 m
.118 .19663 L
s
.14243 .18316 m
.14519 .18604 L
s
.19758 .16166 m
.20029 .16459 L
s
.22551 .15078 m
.22821 .15373 L
s
.2537 .13979 m
.25637 .14277 L
s
.28213 .12871 m
.28478 .13171 L
s
.33977 .10625 m
.34236 .10929 L
s
.36897 .09487 m
.37153 .09794 L
s
.39844 .08339 m
.40097 .08648 L
s
.42817 .0718 m
.43068 .07491 L
s
.48846 .0483 m
.49091 .05146 L
s
.51902 .03639 m
.52144 .03958 L
s
.54986 .02437 m
.55225 .02758 L
s
.58099 .01224 m
.58335 .01547 L
s
.25 Mabswid
.61241 0 m
.97291 .505 L
s
.65208 .05558 m
.64586 .05794 L
s
[(0)] .66454 .05085 -1 .37928 Mshowa
.79537 .2563 m
.78907 .25846 L
s
[(2)] .80797 .25198 -1 .3426 Mshowa
.91799 .42808 m
.91164 .43006 L
s
[(4)] .93071 .4241 -1 .31239 Mshowa
.125 Mabswid
.69012 .10886 m
.68637 .11025 L
s
.72662 .16 m
.72286 .16135 L
s
.76168 .2091 m
.75791 .21042 L
s
.82778 .3017 m
.82399 .30297 L
s
.85897 .3454 m
.85518 .34664 L
s
.88903 .3875 m
.88522 .38871 L
s
.94594 .46722 m
.94211 .46839 L
s
.25 Mabswid
.03495 .22504 m
0 .48612 L
s
.03495 .22504 m
.04116 .22262 L
s
[(-1)] .02254 .22988 1 -0.38971 Mshowa
.02665 .28704 m
.03288 .28468 L
s
[(-0.5)] .0142 .29178 1 -0.38021 Mshowa
.01807 .35115 m
.02431 .34884 L
s
[(0)] .00558 .35578 1 -0.37036 Mshowa
.00919 .41747 m
.01546 .41521 L
s
[(0.5)] -0.00334 .42198 1 -0.36014 Mshowa
0 .48612 m
.00629 .48392 L
s
[(1)] -0.01257 .49051 1 -0.34953 Mshowa
.125 Mabswid
.03331 .23728 m
.03704 .23583 L
s
.03166 .2496 m
.03539 .24816 L
s
.03 .262 m
.03373 .26056 L
s
.02833 .27448 m
.03207 .27305 L
s
.02496 .29969 m
.0287 .29828 L
s
.02325 .31243 m
.02699 .31102 L
s
.02154 .32525 m
.02528 .32385 L
s
.01981 .33816 m
.02355 .33676 L
s
.01632 .36423 m
.02007 .36285 L
s
.01455 .37741 m
.01831 .37603 L
s
.01278 .39067 m
.01653 .3893 L
s
.01099 .40402 m
.01475 .40266 L
s
.00738 .43101 m
.01114 .42966 L
s
.00555 .44464 m
.00932 .4433 L
s
.00371 .45837 m
.00748 .45704 L
s
.00186 .4722 m
.00563 .47087 L
s
.25 Mabswid
.03495 .22504 m
0 .48612 L
s
0 .48612 m
.46953 .89104 L
s
.46953 .89104 m
.47294 .65459 L
s
.47294 .65459 m
.03495 .22504 L
s
.61241 0 m
.97291 .505 L
s
.97291 .505 m
1 .75117 L
s
1 .75117 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.03495 .22504 m
0 .48612 L
s
0 .48612 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.61241 0 m
.03495 .22504 L
s
.47294 .65459 m
.97291 .505 L
s
.97291 .505 m
1 .75117 L
s
1 .75117 m
.46953 .89104 L
s
.46953 .89104 m
.47294 .65459 L
s
0 0 m
1 0 L
1 .89104 L
0 .89104 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.47466 .80783 m
.53223 .80394 L
s
1 0 .6 r
.47341 .78859 m
.52972 .78475 L
s
.8 0 1 r
.47215 .76931 m
.5272 .76551 L
s
1 0 0 r
.54832 .80206 m
.53223 .80394 L
s
.2 0 1 r
.4709 .75 m
.52468 .74624 L
s
1 0 .6 r
.52972 .78475 m
.58706 .77798 L
s
.8 0 1 r
.5272 .76551 m
.58331 .75882 L
s
0 .4 1 r
.46964 .73064 m
.52216 .72694 L
s
.2 0 1 r
.52468 .74624 m
.57954 .73963 L
s
0 1 1 r
.46838 .71124 m
.51963 .70759 L
s
0 .4 1 r
.52216 .72694 m
.57578 .72041 L
s
0 1 .4 r
.46711 .69181 m
.51709 .68821 L
s
1 0 .6 r
.59855 .77604 m
.58706 .77798 L
s
0 1 1 r
.51963 .70759 m
.572 .70115 L
s
.2 1 0 r
.46584 .67233 m
.51455 .66879 L
s
.8 0 1 r
.58331 .75882 m
.63901 .74933 L
s
0 1 .4 r
.51709 .68821 m
.56822 .68186 L
s
.8 1 0 r
.46457 .65281 m
.51201 .64933 L
s
.2 0 1 r
.57954 .73963 m
.63404 .73025 L
s
.2 1 0 r
.51455 .66879 m
.56443 .66253 L
s
1 .6 0 r
.4633 .63326 m
.50946 .62983 L
s
0 .4 1 r
.57578 .72041 m
.62907 .71114 L
s
.8 1 0 r
.51201 .64933 m
.56063 .64317 L
s
0 1 1 r
.572 .70115 m
.62409 .69199 L
s
1 .6 0 r
.50946 .62983 m
.55683 .62377 L
s
0 1 .4 r
.56822 .68186 m
.6191 .67282 L
s
.2 1 0 r
.56443 .66253 m
.6141 .65362 L
s
.8 0 1 r
.63901 .74933 m
.69363 .73717 L
s
.8 1 0 r
.56063 .64317 m
.60909 .63438 L
s
.2 0 1 r
.63404 .73025 m
.6875 .71822 L
s
1 .6 0 r
.55683 .62377 m
.60408 .61512 L
s
0 .4 1 r
.62907 .71114 m
.68135 .69925 L
s
0 1 1 r
.62409 .69199 m
.6752 .68025 L
s
0 1 .4 r
.6191 .67282 m
.66903 .66122 L
s
.2 1 0 r
.6141 .65362 m
.66286 .64217 L
s
.8 1 0 r
.60909 .63438 m
.65669 .6231 L
s
1 .6 0 r
.60408 .61512 m
.6505 .604 L
s
.8 0 1 r
.69363 .73717 m
.74692 .72238 L
s
.2 0 1 r
.6875 .71822 m
.73963 .70359 L
s
0 .4 1 r
.68135 .69925 m
.73233 .68479 L
s
0 1 1 r
.6752 .68025 m
.72502 .66597 L
s
0 1 .4 r
.66903 .66122 m
.7177 .64713 L
s
.2 1 0 r
.66286 .64217 m
.71038 .62827 L
s
.8 1 0 r
.65669 .6231 m
.70305 .60939 L
s
1 .6 0 r
.6505 .604 m
.69571 .59049 L
s
.8 0 1 r
.74692 .72238 m
.79872 .70494 L
s
.2 0 1 r
.73963 .70359 m
.79026 .68636 L
s
0 .4 1 r
.73233 .68479 m
.7818 .66777 L
s
0 1 1 r
.72502 .66597 m
.77333 .64916 L
s
0 1 .4 r
.7177 .64713 m
.76485 .63054 L
s
.2 1 0 r
.71038 .62827 m
.75637 .61192 L
s
.8 1 0 r
.70305 .60939 m
.74789 .59328 L
s
1 .6 0 r
.69571 .59049 m
.7394 .57463 L
s
.8 0 1 r
.79872 .70494 m
.84865 .68483 L
s
.2 0 1 r
.79026 .68636 m
.83901 .6665 L
s
0 .4 1 r
.7818 .66777 m
.82937 .64817 L
s
0 1 1 r
.77333 .64916 m
.81973 .62984 L
s
0 1 .4 r
.76485 .63054 m
.81008 .6115 L
s
.2 1 0 r
.75637 .61192 m
.80043 .59316 L
s
.8 1 0 r
.74789 .59328 m
.79078 .57481 L
s
1 .6 0 r
.7394 .57463 m
.78113 .55646 L
s
1 0 .6 r
.84785 .70732 m
.85829 .70316 L
s
.85829 .70316 m
.9068 .68022 L
s
.8 0 1 r
.84865 .68483 m
.89595 .6622 L
s
.2 0 1 r
.83901 .6665 m
.88511 .64418 L
s
0 .4 1 r
.82937 .64817 m
.87428 .62617 L
s
0 1 1 r
.81973 .62984 m
.86344 .60817 L
s
0 1 .4 r
.81008 .6115 m
.85262 .59018 L
s
.2 1 0 r
.80043 .59316 m
.84179 .57219 L
s
.8 1 0 r
.79078 .57481 m
.83097 .5542 L
s
1 .6 0 r
.78113 .55646 m
.82015 .53623 L
s
1 0 0 r
.90383 .70471 m
.91764 .69825 L
s
1 .6 0 r
.82015 .53623 m
.85533 .51453 L
s
.8 1 0 r
.83097 .5542 m
.86728 .53206 L
s
.2 1 0 r
.84179 .57219 m
.87925 .54961 L
s
0 1 .4 r
.85262 .59018 m
.89123 .56718 L
s
0 1 1 r
.86344 .60817 m
.90322 .58476 L
s
0 .4 1 r
.87428 .62617 m
.91522 .60237 L
s
.2 0 1 r
.88511 .64418 m
.92723 .61999 L
s
.8 0 1 r
.89595 .6622 m
.93926 .63762 L
s
1 0 .6 r
.9068 .68022 m
.95129 .65527 L
s
1 0 0 r
.91764 .69825 m
.96334 .67295 L
s
0 g
.25 Mabswid
.61241 0 m
.97291 .505 L
s
.97291 .505 m
1 .75117 L
s
1 .75117 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.03495 .22504 m
0 .48612 L
s
0 .48612 m
.61856 .26991 L
s
.61856 .26991 m
.61241 0 L
s
.61241 0 m
.03495 .22504 L
s
.03495 .22504 m
.61241 0 L
s
.03495 .22504 m
.03971 .2297 L
s
[(-2)] .02544 .21571 1 .98073 Mshowa
.16988 .17246 m
.17445 .1773 L
s
[(-1)] .16074 .16277 .9432 1 Mshowa
.31082 .11753 m
.31518 .12256 L
s
[(0)] .3021 .10747 .86675 1 Mshowa
.45818 .0601 m
.46231 .06533 L
s
[(1)] .44992 .04965 .7903 1 Mshowa
.61241 0 m
.61628 .00542 L
s
[(2)] .60467 -0.01084 .71386 1 Mshowa
.125 Mabswid
.06148 .2147 m
.06431 .21752 L
s
.08823 .20428 m
.09104 .20712 L
s
.11521 .19376 m
.118 .19663 L
s
.14243 .18316 m
.14519 .18604 L
s
.19758 .16166 m
.20029 .16459 L
s
.22551 .15078 m
.22821 .15373 L
s
.2537 .13979 m
.25637 .14277 L
s
.28213 .12871 m
.28478 .13171 L
s
.33977 .10625 m
.34236 .10929 L
s
.36897 .09487 m
.37153 .09794 L
s
.39844 .08339 m
.40097 .08648 L
s
.42817 .0718 m
.43068 .07491 L
s
.48846 .0483 m
.49091 .05146 L
s
.51902 .03639 m
.52144 .03958 L
s
.54986 .02437 m
.55225 .02758 L
s
.58099 .01224 m
.58335 .01547 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 256.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001@2000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00gOooool5o`0008Kooooo003Mooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0Q_ooool00=ko
oooo00?oV9RHob4Q8Oo^k^h0Qoooool00=oooooo00?oV9RHob4Q8Oo^k^h0Q_ooool00>3ooooo00?o
MgMgofIVI_ooool0QOooool00>7ooooo00?o0000ooooooooool0Q?ooool00=gooooo00Go0000okZj
^_ooooooV9RHoa0@4026ooooo`00gOooool01OnHV9So410@o`000?lQ8B7oc<c<08Kooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003Tooooo`;o0000P_ooool0
0>7ooooo0ol000000ooooooo0000ooooo`21ooooo`00goooool2o`0000Cooooo0_l00021ooooo`00
g?ooool3o`0000Kooooo00?o0000ooooool00000P?ooool00=[ooooo0_l00009ooooo`03o`000?oo
oooo0000083ooooo003Gooooo`?o000000?oooooo`000?ooool02?ooool01?l0003oooooooooool0
001oooooo`00e?ooool3o`0000Cooooo00?o0000ooooooooool01oooool01Ol0003ooooooooooooo
oooo000007kooooo003Booooo`;o00004Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo07_ooooo002Zooooo`Co000000?o410@ooooooooool07_ooool3o`0001?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`1kooooo`00[?ooool00ol0003oooooooooo`0Nooooo`;o
000000?oooooo`000?ooool04oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo07[o
oooo002/ooooo`03o`000?oooooooooo01_ooooo0ol00004ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`1iooooo`00[?ooool00ol0003ooooooooo
o`0Iooooo`;o00006oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo07Wooooo002/
ooooo`03o`000?oooooooooo01Kooooo0ol0000Mooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool02?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^06_ooooo002/ooooo`03o`000?oooooo
oooo01Cooooo0_l000000ooooooo0000ooooo`0Mooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01oooool01OmgMgOoV9RHoooooonHV9SoMgMg06_ooooo002/ooooo`03o`000?oooooo
oooo017ooooo0ol00004ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`06ooooo`05oa0@4?ooooooooooooooool@4100Joooool00:[ooooo00?oEEEE
ofIVI_l000004Oooool2o`0002Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06
ooooo`05o`000?ooooooooooooooool00000Joooool00;_ooooo0ol0000Wooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000006_ooooo002i
ooooo`;o000000?oooooo`000?ooool09oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Cooooo00Go410@oooooooooooooooooa0@401[ooooo`00]_ooool3o`0000Cooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Cooooo00GoMgMg
oiRHV?ooooooV9RHogMgM`1[ooooo`00/oooool3o`0002oooooo00?o0000ooooooooool02Oooool2
o`0000Gooooo00Gok^k^oc8b<_l0003o<S8bonk^kP1[ooooo`00/Oooool2o`0003;ooooo00?o0000
ooooooooool02?ooool01?l0003oooooooooool0001dooooo`00[_ooool3o`000003ooooool0003o
oooo037ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1aooooo`00[?ooool2o`00
00Gooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
077ooooo002Yooooo`?o0000>_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo073o
oooo002Wooooo`;o0000?Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo06oooooo
002Tooooo`?o000000?oooooo`000?ooool0??ooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo06oooooo002Rooooo`;o0000@_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooo
oooo06kooooo001gooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08oooool3o`0004Cooooo00?o0000
ooooooooool03oooool00ol0003oooooooooo`1]ooooo`00Moooool01OmgMgOoV9RHoooooonHV9So
MgMg027ooooo0_l00017ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0K?ooool0
07Oooooo00Go410@oooooooooooooooooa0@400Nooooo`?o00000_ooool00ol0003oooooooooo`14
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0K?ooool007Oooooo00Go0000oooo
ooooooooooooo`00000Looooo`;o0000C?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo06_ooooo001gooooo`05o`000?ooooooooooooooool000006Oooool3o`0004kooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`1Zooooo`00Moooool01Ol@413ooooooooooooooooo
410@01Kooooo0ol0001Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0J_ooool0
07Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Dooooo`;o00000oooool00ol0003oooooooooo`1>
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0JOooool007Oooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP0Aooooo`?o0000E_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo06Sooooo002;ooooo`;o0000FOooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo
06Sooooo0028ooooo`?o0000Foooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo06Oo
oooo0026ooooo`;o00000oooool00ol0003oooooooooo`1Hooooo`03o`000?oooooooooo01Gooooo
0_l0001Xooooo`00Poooool3o`00063ooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`1Uooooo`00POooool2o`0006?ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1U
ooooo`00O_ooool4o`0006Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`1Toooo
o`00O?ooool2o`0000Cooooo00?o0000ooooooooool0HOooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo06?ooooo001iooooo`?o0000J_ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo06?ooooo001gooooo`;o0000KOooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo06;ooooo001dooooo`?o000000?oooooo`000?ooool0K?ooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo067ooooo001aooooo`?o0000L_ooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo063ooooo0019ooooo`Co000000?o410@ooooooooool07oooool2o`0007Go
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1Pooooo`00Boooool00ol0003ooooo
ooooo`0Nooooo`?o0000Moooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo05oooooo
0010ooooo`Ko00001Oooool00ol0003oooooooooo`0Looooo`;o00000_ooool00ol0003ooooooooo
o`1eooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0G_ooool004_ooooo00?o0000
ooooooooool06Oooool3o`0007cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1N
ooooo`00Boooool00ol0003oooooooooo`0Gooooo`;o0000Ooooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo05gooooo001;ooooo`03o`000?oooooooooo01Cooooo0ol00021ooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0G?ooool004_ooooo00?o0000ooooooooool0
4_ooool2o`0000?ooooo00?o0000ooooooooool0O_ooool00ol0003oooooooooo`0Qooooo`03o`00
0?oooooooooo05_ooooo0019ooooo`03oeEEEOmVIVKo0000017ooooo0ol00026ooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool0Foooool005_ooooo0_l00029ooooo`03o`000?oooooo
oooo027ooooo0_l0001Looooo`00F?ooool3o`000003ooooool0003ooooo08Sooooo00?o0000oooo
ooooool08oooool00ol0003oooooooooo`1Iooooo`00E_ooool2o`0008kooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`1Iooooo`00Doooool3o`00093ooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`1Hooooo`00D?ooool3o`0009?ooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`1Gooooo`00C_ooool2o`0000;ooooo00?o0000ooooooooool0TOooool0
0ol0003oooooooooo`0Vooooo`03o`000?oooooooooo05Kooooo001;ooooo`?o00001Oooool00ol0
003oooooooooo`2@ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0E_ooool004Wo
oooo0_l0002Kooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0EOooool004Kooooo
1?l0002Looooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0E?ooool004Cooooo0_l0
002Pooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0E?ooool001[ooooo1Ol0000R
ooooo`?o0000X_ooool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo05?ooooo000Joooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@08?ooool2o`000:Gooooo00?o0000ooooooooool0:_ooool0
0ol0003oooooooooo`1Booooo`004_ooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h07_ooool3o`00
0003ooooool0003ooooo0:Cooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`1Aoooo
o`007?ooool00onHV9So8B4Qonk^kP0Kooooo`;o0000Z_ooool00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo057ooooo000Mooooo`03ogMgMomVIVKooooo01Oooooo0ol0002]ooooo`03o`00
0?oooooooooo02_ooooo00?o0000ooooooooool0D?ooool001kooooo00?o0000ooooooooool05?oo
ool2o`000;3ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`1?ooooo`006_ooool0
1Ol0003o^[ZjoooooonHV9So410@01?ooooo0ol00002ooooo`03o`000?oooooooooo0:gooooo00?o
0000ooooooooool0;?ooool2o`00053ooooo000Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`04?oo
ool3o`000;Gooooo00?o0000ooooooooool0;?ooool2o`00053ooooo000]ooooo`;o0000^?ooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo04gooooo000Zooooo`?o000000?oooooo`00
0?ooool0]oooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo04gooooo000Xooooo`;o
0000_Oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo04cooooo000Uooooo`?o0000
_oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo04_ooooo000Tooooo`;o0000`Ooo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo04[ooooo000Jooooo`Co000000?o410@
ooooooooool00oooool00ol0003oooooo`000030ooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool0B_ooool001cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0002o
ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0BOooool0017ooooo1_l00005oooo
o`03o`000?oooooooooo00Gooooo0_l00002ooooo`03o`000?oooooooooo0;cooooo00?o0000oooo
ooooool0<oooool00ol0003oooooooooo`18ooooo`007?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool0^oooool00ol0003oooooooooo`0cooooo`03
o`000?oooooooooo00Oooooo1Ol0000looooo`007?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool0^_ooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo00Kooooo00GoV9RHob4Q8Oo^k^koooooodA4A00looooo`007?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0^Oooool00ol0003ooooo
ooooo`0eooooo`03o`000?oooooooooo00Kooooo00?oV9RHob4Q8Oo^k^h0?Oooool001cooooo00?o
0000ooooooooool01?ooool3o`0000Kooooo00?o0000ooooooooool0^?ooool00ol0003ooooooooo
o`0fooooo`03o`000?oooooooooo00Kooooo00?oV9RHob4Q8Oo^k^h0??ooool001[ooooo00?oEEEE
ofIVI_l000001_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo0;Oooooo00?o0000
ooooooooool0=_ooool00ol0003oooooooooo`07ooooo`03ogMgMomVIVKooooo03_ooooo000Soooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0]_ooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0>_ooool002?ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`2eooooo`03o`000?oooooooooo03Oooooo0_l00004ooooo`05
o`000?nj^[[ooooooiRHV?l@4100??ooool002?ooooo0_l0000;ooooo`03o`000?oooooooooo0;Co
oooo00?o0000ooooooooool0=_ooool00ol0003oooooo`000004ooooo`05oiRHV?l@413o0000ob4Q
8Oo<c<`0??ooool002?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`2cooooo`03
o`000?oooooooooo03Wooooo00?o0000ooooooooool0@_ooool002;ooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`2booooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0
@Oooool002;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`2`ooooo`;o0000?Ooo
ool00ol0003oooooooooo`10ooooo`008_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooo
oooo0:cooooo0ol000000ooooooo0000ooooo`0looooo`03o`000?oooooooooo043ooooo000Roooo
o`;o00004Oooool00ol0003oooooooooo`2Xooooo`?o00001Oooool00ol0003oooooooooo`0koooo
o`03o`000?oooooooooo03oooooo000Rooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool0Y?ooool3o`0000Wooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0nooooo`00
8_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo0:3ooooo0ol0000=ooooo`03o`00
0?oooooooooo03[ooooo00?o0000ooooooooool0?_ooool002;ooooo0ol0000Cooooo`03o`000?oo
oooooooo09cooooo0ol0000Aooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0?Ooo
ool002;ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`2Iooooo`;o00005?ooool0
0ol0003oooooooooo`0kooooo`03o`000?oooooooooo03cooooo000Qooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool0UOooool3o`0001Oooooo00?o0000ooooooooool0>oooool00ol0
003oooooooooo`0kooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo097ooooo0ol0000Kooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0>oooool0
00Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`03
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0SOooool3o`0001oooooo00?o0000
ooooooooool0>_ooool00ol0003oooooooooo`0jooooo`001Ol00002ooooo`05oa0@4?oooooooooo
ooooool@41004?ooool00ol0003oooooooooo`02ooooo`;o00006_ooool00ol0003oooooooooo`29
ooooo`?o00008oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03Wooooo0007oooo
o`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool0Q_ooool2o`0002Kooooo00?o0000ooooooooool0>_ooool2
o`0003[ooooo0007ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb
<S;oc<c<00Cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`22ooooo`?o0000:Ooo
ool00ol0003oooooooooo`0iooooo`;o0000>_ooool000Oooooo00Go410@oooooooooooooooooa0@
400<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`1nooooo`?o0000;Oooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03Oooooo0007
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06ooooo`;o00007_oo
ool00ol0003oooooooooo`1jooooo`?o0000<Oooool00ol0003oooooooooo`0iooooo`03o`000?oo
oooooooo03Oooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Cooooo0_l0
000Pooooo`03o`000?oooooooooo07Kooooo0ol0000eooooo`03o`000?oooooooooo03Wooooo00?o
0000ooooooooool0=_ooool0023ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1b
ooooo`?o0000>?ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo03Gooooo000Poooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool0Koooool2o`0003cooooo00?o0000oooo
ooooool0>_ooool00ol0003oooooooooo`0dooooo`008?ooool2o`0002?ooooo00?o0000oooooooo
ool0Joooool3o`0003oooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0dooooo`00
8?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo06Oooooo0ol00013ooooo`03o`00
0?oooooooooo03Wooooo00?o0000ooooooooool0<oooool0023ooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`1Sooooo`?o0000Aoooool00ol0003oooooooooo`0iooooo`03o`000?oo
oooooooo03;ooooo000Pooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0Goooool3
o`0004[ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0booooo`008?ooool00ol0
003oooooooooo`0Vooooo`;o0000GOooool2o`0004kooooo00?o0000ooooooooool0>Oooool00ol0
003oooooooooo`0aooooo`007oooool3o`0002Wooooo00?o0000ooooooooool0Eoooool3o`00057o
oooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`0`ooooo`007oooool00ol0003ooooo
ooooo`0Zooooo`03o`000?oooooooooo05?ooooo0ol0001Eooooo`03o`000?oooooooooo03Wooooo
00?o0000ooooooooool0;oooool001oooooo00?o0000ooooooooool0:oooool00ol0003ooooooooo
o`1?ooooo`?o0000F?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02oooooo000O
ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0Boooool3o`0005cooooo00?o0000
ooooooooool0>?ooool2o`00033ooooo000Oooooo`?o0000;Oooool00ol0003oooooooooo`17oooo
o`?o0000H?ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo02gooooo000Oooooo`03
o`000?oooooooooo02kooooo00?o0000ooooooooool0A?ooool2o`0006Cooooo00?o0000oooooooo
ool0>?ooool00ol0003oooooooooo`0]ooooo`005?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Ko
oooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`10ooooo`?o0000Ioooool00ol0003o
ooooooooo`0hooooo`03o`000?oooooooooo02cooooo000Dooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo03cooooo0ol0001Zooooo`03
o`000?oooooooooo03Wooooo00?o0000ooooooooool0:oooool001Cooooo00Go410@oooooooooooo
oooooa0@4005ooooo`;o0000<oooool00ol0003oooooooooo`0hooooo`?o0000K_ooool00ol0003o
ooooooooo`0iooooo`03o`000?oooooooooo02[ooooo000Dooooo`05o`000?ooooooooooooooool0
00001Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo03Cooooo0ol0001booooo`03
o`000?oooooooooo03Sooooo00?o0000ooooooooool0:_ooool001Cooooo00Go0000oooooooooooo
ooooo`000005ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0<?ooool3o`0007Ko
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Yooooo`005?ooool01Ol@413ooooo
oooooooooooo410@00Gooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0]ooooo`;o
0000N_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02Sooooo000Dooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo02Wo
oooo0ol0001looooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0:?ooool001Cooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o0000>?ooool00ol0003oooooooooo`0Uooooo`?o
0000P?ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo02Oooooo000Nooooo`03o`00
0?oooooooooo03Sooooo00?o0000ooooooooool08Oooool3o`0008Cooooo00?o0000ooooooooool0
>?ooool00ol0003oooooooooo`0Vooooo`007Oooool00ol0003oooooooooo`0jooooo`03o`000?oo
oooooooo01gooooo0ol00028ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool09Ooo
ool001gooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`0Jooooo`;o0000S?ooool0
0ol0003oooooooooo`0gooooo`03o`000?oooooooooo02Gooooo000Mooooo`;o0000?Oooool00ol0
003oooooooooo`0Fooooo`?o0000S_ooool00ol0003oooooooooo`0gooooo`;o00009_ooool001go
oooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Booooo`?o0000T_ooool00ol0003o
ooooooooo`0hooooo`03o`000?oooooooooo02?ooooo000Mooooo`03o`000?oooooooooo03kooooo
00?o0000ooooooooool03_ooool3o`0009Kooooo00?o0000ooooooooool0=oooool00ol0003ooooo
ooooo`0Sooooo`007Oooool00ol0003oooooooooo`0oooooo`03o`000?oooooooooo00[ooooo0ol0
002Jooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool08_ooool001gooooo00?o0000
ooooooooool0@?ooool00ol0003oooooooooo`06ooooo`?o0000W_ooool00ol0003oooooooooo`0g
ooooo`03o`000?oooooooooo027ooooo000Looooo`?o0000@_ooool00ol0003oooooooooo`03oooo
o`;o0000XOooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo023ooooo000Looooo`03
o`000?oooooooooo04?ooooo00?o0000ooooool000000_l0002Tooooo`03o`000?oooooooooo03Oo
oooo00?o0000ooooooooool08?ooool001cooooo00?o0000ooooooooool0@_ooool3o`000:Sooooo
00?o0000ooooooooool0=oooool00ol0003oooooooooo`09ooooo`;o000000?o410@ooooooooool0
4Oooool001cooooo00?o0000ooooooooool0?oooool3o`0000?ooooo00?o0000ooooooooool0Y_oo
ool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04_oo
ool001cooooo0ol0000looooo`?o00001oooool00ol0003oooooooooo`2Vooooo`03o`000?oooooo
oooo03Kooooo00?o0000ooooooooool01_ooool5o`0001?ooooo000Looooo`03o`000?oooooooooo
03Wooooo0ol0000;ooooo`03o`000?oooooooooo0:Gooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`05ooooo`04odA4A?oMgMgoooooo`0001Cooooo00001_ooooook^k^oc8b<_l0003o
<S8bonk^kPGooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooo
ooooo`0gooooo`;o00003oooool00ol0003oooooooooo`2Uooooo`03o`000?oooooooooo03Oooooo
00?o0000ooooooooool01?ooool01?oMgMgoEEEEooooool0000Dooooo`0000KoooooogMgMonHV9So
oooooiRHV?mgMgL5ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
03Cooooo0ol0000Booooo`03o`000?oooooooooo0:Gooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`05ooooo`03ogMgMoo<c<co000001Cooooo00000ooooooo410@ooooo`02ooooo`03
oa0@4?oooooooooo00kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0aooooo`?o
00005_ooool00ol0003oooooooooo`2Uooooo`03o`000?oooooooooo03Kooooo0_l00005ooooo`03
onk^k_m4A4Co000001Cooooo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00gooooo
00?oMgMgoc8b<_ooool00oooool2o`00033ooooo0ol0000Jooooo`03o`000?oooooooooo0:Gooooo
00?o0000ooooooooool0=?ooool00ol0003oooooo`000006ooooo`03ogMgMol0003ooooo01?ooooo
00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00[ooooo00Go0000ob4Q8Ol0003o<S8b
olc<c004ooooo`03o`000?oooooooooo02cooooo0ol0000Nooooo`03o`000?oooooooooo0:Cooooo
00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Iooooo`0000?ooooooa0@4?ooool00_oo
ool00ol@413oooooooooo`0:ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0:_oo
ool2o`0002;ooooo00?o0000ooooooooool0Y?ooool00ol0003oooooooooo`0fooooo`03o`000?oo
oooooooo01Wooooo00001_ooooooMgMgoiRHV?ooooooV9RHogMgM`cooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Wooooo`?o00009Oooool2o`000:Gooooo00?o0000ooooooooool0
=_ooool00ol0003oooooooooo`0Hooooo`0000Koooooonk^k_lb<S;o0000oc8b<_o^k^h<ooooo`Co
00001Oooool2o`0002Gooooo0ol0000Zooooo`03o`000?oooooooooo0:?ooooo00?o0000oooooooo
ool0=_ooool00ol0003oooooooooo`0Gooooo`006oooool00ol0003oooooooooo`0Qooooo`?o0000
;_ooool00ol0003oooooooooo`2Sooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0
5oooool001_ooooo00?o0000ooooooooool07_ooool3o`0003;ooooo00?o0000ooooooooool0X_oo
ool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo01Kooooo000Kooooo`03o`000?oooooo
oooo01_ooooo0ol0000fooooo`03o`000?oooooooooo0:;ooooo00?o0000ooooooooool0=_ooool0
0ol0003oooooooooo`0Eooooo`006_ooool00ol0003oooooooooo`0Jooooo`;o0000>_ooool00ol0
003oooooooooo`2Rooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool05?ooool001[o
oooo0_l0000Hooooo`?o0000?Oooool00ol0003oooooooooo`2Rooooo`03o`000?oooooooooo03Go
oooo00?o0000ooooooooool05?ooool001[ooooo00?o0000ooooooooool05?ooool3o`00047ooooo
00?o0000ooooooooool0XOooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo01?ooooo
000Jooooo`03o`000?oooooooooo017ooooo0ol00015ooooo`03o`000?oooooooooo0:7ooooo00?o
0000ooooooooool0=_ooool00ol0003oooooooooo`0Booooo`006_ooool00ol0003oooooooooo`0>
ooooo`?o0000BOooool00ol0003oooooooooo`2Qooooo`03o`000?oooooooooo03Gooooo0_l0000C
ooooo`006_ooool00ol0003oooooooooo`0<ooooo`;o0000COooool00ol0003oooooooooo`2Qoooo
o`03o`000?oooooooooo03Cooooo0_l0000Cooooo`006Oooool3o`0000[ooooo0ol0001@ooooo`03
o`000?oooooooooo0:7ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0@ooooo`00
6_ooool00ol0003oooooooooo`06ooooo`?o0000E?ooool00ol0003oooooooooo`2Pooooo`03o`00
0?oooooooooo03Kooooo00?o0000ooooooooool03oooool001Wooooo00?o0000ooooooooool01?oo
ool3o`0005Sooooo00?o0000ooooooooool0X?ooool00ol0003oooooooooo`0eooooo`03o`000?oo
oooooooo00oooooo000Iooooo`04o`000?ooooooooooooooo`?o0000G?ooool00ol0003ooooooooo
o`2Pooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool03_ooool001Wooooo1?l0001P
ooooo`03o`000?oooooooooo0:3ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0=
ooooo`006Oooool2o`0006?ooooo00?o0000ooooooooool0X?ooool00ol0003oooooooooo`0doooo
o`03o`000?oooooooooo00gooooo000?ooooo`Co000000?o410@ooooooooool01Oooool00ol0003o
ooooooooo`1Qooooo`03o`000?oooooooooo09oooooo00?o0000ooooooooool0=Oooool00ol0003o
ooooooooo`0<ooooo`004Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo067ooooo
00?o0000ooooooooool0Woooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00_ooooo
000Aooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0HOooool00ol0003ooooooooo
o`2Oooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool02_ooool0017ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`1Qooooo`03o`000?oooooooooo09oooooo00?o0000
ooooooooool0=?ooool00ol0003oooooooooo`0:ooooo`004Oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo067ooooo00?o0000ooooooooool0Woooool00ol0003oooooooooo`0doooo
o`03o`000?oooooooooo00Wooooo000Aooooo`03o`000?oooooooooo00cooooo0_l0001Rooooo`03
o`000?oooooooooo09kooooo00?o0000ooooooooool0<oooool3o`0000[ooooo000Aooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`2Nooooo`03o`00
0?oooooooooo02oooooo0ol00002ooooo`03o`000?oooooooooo00Sooooo000?ooooo`03oeEEEOmV
IVKo0000017ooooo00?o0000ooooooooool0H?ooool00ol0003oooooooooo`2Nooooo`03o`000?oo
oooooooo02_ooooo0ol00005ooooo`03o`000?oooooooooo00Sooooo000Tooooo`03o`000?oooooo
oooo063ooooo00?o0000ooooooooool0W_ooool00ol0003oooooooooo`0:ooooo`;ooiT06_ooool4
o`0000Sooooo00?o0000ooooooooool02?ooool002Gooooo00?o0000ooooooooool0H?ooool00ol0
003oooooooooo`2Nooooo`03o`000?oooooooooo00Oooooo0_ooV@0Iooooo`?o00003?ooool00ol0
003oooooooooo`08ooooo`009_ooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo09go
oooo00?o0000ooooooooool01_ooool00oooV@3oooooooooo`0Fooooo`?o00004?ooool00ol0003o
ooooooooo`07ooooo`009oooool00ol0003oooooooooo`1Pooooo`03o`000?oooooooooo09gooooo
00?o0000ooooooooool00oooool2oonI01Gooooo1?l0000Cooooo`03o`000?oooooooooo00Oooooo
000Xooooo`;o0000HOooool00ol0003oooooooooo`2Mooooo`03o`000?oooooooooo00;ooiT05?oo
ool3o`0001Oooooo00?o0000ooooooooool01oooool002[ooooo00?o0000ooooooooool0Goooool0
0ol0003oooooooooo`2Mooooo`03o`000?ooV@3ooooo01;ooooo0ol0000Jooooo`03o`000?oooooo
oooo00Oooooo000[ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool0Voooool2oonI
0003o`000?oooooooooo00Wooooo0_o<o`02ooooo`Co00007Oooool00ol0003oooooooooo`07oooo
o`00;?ooool00ol0003oooooooooo`1Oooooo`03o`000?oooooooooo09Sooooo0_ooV@02ooooo`03
o`000?oooooooooo00Oooooo0_o<o`001?oooooo0000o`000?l0000Qooooo`03o`000?oooooooooo
00Oooooo000]ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool0UOooool2oonI00Go
oooo00?o0000ooooooooool01Oooool01?o<o`3o0000o`000?l0000Tooooo`03o`000?oooooooooo
00Oooooo000^ooooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool0T_ooool2oonI00So
oooo00Go0000ooooooooooooooooo`000002olco0003o`000?oooooooooo02Gooooo00?o0000oooo
ooooool01oooool002oooooo0_l0001Pooooo`03o`000?oooooooooo08oooooo0_ooV@0;ooooo`;o
00000_o<o`0[ooooo`03o`000?oooooooooo00Kooooo000aooooo`03o`000?oooooooooo05kooooo
0_l0002>ooooo`03oonI0?oooooooooo00Sooooo0ol000000ooooooo0000ooooo`0/ooooo`03o`00
0?oooooooooo00Kooooo000booooo`03o`000?oooooooooo05oooooo00?o0000ooooooooool0ROoo
ool2oonI00Sooooo0ol00002ooooo`;oc?l000?o0000ooooooooool02Oooool2oc?o023ooooo00?o
0000ooooooooool01_ooool003?ooooo00?o0000ooooooooool0Goooool00ol0003oooooooooo`26
ooooo`;ooiT01_ooool4o`0000?ooooo0_o<o`03ooooo`03o`000?oooooooooo00Kooooo0_lco`0R
ooooo`03o`000?oooooooooo00Kooooo000dooooo`03o`000?oooooooooo05oooooo00?o0000oooo
ooooool0Poooool2oonI00Gooooo0ol00005ooooo`;oc?l01_ooool00ol0003oooooooooo`04oooo
o`03oc?o0?oooooooooo02;ooooo00?o0000ooooooooool01_ooool003Gooooo00?o0000oooooooo
ool0Goooool00ol0003oooooooooo`20ooooo`;ooiT01?ooool3o`0000Kooooo0_o<o`09ooooo`04
o`000?ooooooooooooooo`;o<ol09Oooool00ol0003oooooooooo`06ooooo`00=_ooool00ol0003o
ooooooooo`1Oooooo`03o`000?oooooooooo07gooooo0_ooV@02ooooo`Co00001oooool2olco00co
oooo00?o0000oc?o0?lco`009oooool00ol0003oooooooooo`06ooooo`00=oooool2o`00063ooooo
00?o0000ooooooooool0NOooool3oonI0004ooooool0003o0000o`0000[ooooo00?oc?l0oooooooo
ool03?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo00Kooooo000iooooo`03o`00
0?oooooooooo05kooooo00?o0000ooooooooool0M_ooool2oonI0004ooooool0003o0000o`0000_o
oooo0_o<o`0=ooooo`;o<ol000?oooooo`000?ooool02Oooool2o`3oIQgooooo00?o0000oooooooo
ool01Oooool003[ooooo00?o0000ooooooooool0G_ooool00ol0003oooooooooo`1cooooo`;ooiT0
0ol0000<ooooo`;oc?l03Oooool2oc?o00Cooooo00?o0000ooooooooool01Oooool2o`3oIQoooooo
00?o0000ooooooooool01Oooool003_ooooo00?o0000ooooooooool0G_ooool00ol0003ooooooooo
o`1`ooooo`;ooiT000?o0000ooooooooool03?ooool2olco00gooooo0_lco`07ooooo`03o`000?oo
oooooooo00;ooooo0_l0ofHQooooo`03o`000?oooooooooo00Gooooo000looooo`03o`000?oooooo
oooo05kooooo00?o0000ooooooooool0K?ooool3oonI00kooooo0oo<o`0=ooooo`;o<ol02Oooool0
0ol0003oooooooooo`02o`3oIR?ooooo00?o0000ooooooooool01Oooool003gooooo00?o0000oooo
ooooool0G_ooool00ol0003oooooooooo`1Wooooo`04o`000?ooV@3ooiT0oonI00oooooo0_o<o`0>
ooooo`;o<ol03?ooool00ol0003o0?mVooooo`0Tooooo`03o`000?oooooooooo00Gooooo000noooo
o`;o0000Goooool00ol0003oooooooooo`1Sooooo`04o`000?ooV@3ooiT0oonI00oooooo0oo<o`0>
ooooo`;o<ol03Oooool2o`3oIP03o`000?oooooooooo02?ooooo00?o0000ooooooooool01Oooool0
043ooooo00?o0000ooooooooool0GOooool00ol0003oooooooooo`1Oooooo`04o`000?ooV@3ooiT0
oonI013ooooo0_o<o`0?ooooo`;o<ol03Oooool2o`3oIP?ooooo00?o0000ooooooooool01oooool2
o`3ooaWooooo00?o0000ooooooooool01Oooool0047ooooo00?o0000ooooooooool0GOooool00ol0
003oooooooooo`1Jooooo`;o00000oooV@0@ooooo`?oc?l03oooool2oc?o00gooooo0_l0ofH6oooo
o`03o`000?oooooooooo00Cooooo0_l0oolKooooo`03o`000?oooooooooo00Gooooo0012ooooo`03
o`000?oooooooooo05gooooo00?o0000ooooooooool0E_ooool2o`0000?ooiT04Oooool2olco013o
oooo0_lco`0=ooooo`;o0?mV2?ooool00ol0003oooooooooo`02ooooo`;o0?oo7Oooool00ol0003o
ooooooooo`05ooooo`00@oooool00ol0003oooooooooo`1Mooooo`03o`000?oooooooooo05;ooooo
0_l00003oonI017ooooo0oo<o`0@ooooo`;o<ol03Oooool2o`3oIP_ooooo00Co0000ooooool0oooo
0?oo8?ooool00ol0003oooooooooo`04ooooo`00A?ooool00ol0003oooooooooo`1Mooooo`03o`00
0?oooooooooo04gooooo0ol00003oonI01;ooooo0_o<o`0Aooooo`;o<ol03Oooool2o`3oIPkooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`04ooooo`00AOooool00ol0003ooooooooo
o`1Mooooo`03o`000?oooooooooo04Wooooo0ol00003oonI01;ooooo0oo<o`0@ooooo`?o<ol03Ooo
ool2o`3oIPkooooo0_l0ool00ooooooo0000ooooo`08ooooo`;o06Ko5_ooool00ol0003ooooooooo
o`04ooooo`00A_ooool2o`0005kooooo00?o0000ooooooooool0AOooool2o`0000CooiT04oooool2
olco017ooooo0_lco`0>ooooo`;o0?mV3_ooool2o`3oo`Cooooo00?o0000ooooooooool01Oooool0
0ol0I_ooooooooooo`0Fooooo`03o`000?oooooooooo00Cooooo0018ooooo`03o`000?oooooooooo
05cooooo00?o0000ooooooooool0@?ooool2o`0000CooiT05?ooool3olco017ooooo0_lco`0>oooo
o`;o0?mV3_ooool2o`3oo`Kooooo00?o0000ooooooooool00oooool2o`1VoaWooooo00?o0000oooo
ooooool01?ooool004Wooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`0looooo`03
o`000?ooV@3ooiT000;ooiT05Oooool3olco01;ooooo0_lco`0>ooooo`;o0?mV3_ooool2o`3oo`Wo
oooo00?o0000ooooooooool00_l0I_lKooooo`03o`000?oooooooooo00Cooooo001:ooooo`03o`00
0?oooooooooo05cooooo00?o0000ooooooooool0>?ooool4oonI01Gooooo1?o<o`0Cooooo`;o<ol0
3_ooool2o`3oIPkooooo0_l0ool<ooooo`03o`000?l0I_oooooo01cooooo00?o0000ooooooooool0
1?ooool004_ooooo00?o0000ooooooooool0G?ooool00ol0003oooooooooo`0cooooo`CooiT05_oo
ool3olco01Cooooo0olco`0>ooooo`;o0?mV3_ooool2o`3oo`gooooo0_l0I_l00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00Cooooo001<ooooo`03o`000?oooooooooo05cooooo00?o0000
ooooooooool0;Oooool5oonI01Kooooo1?o<o`0Dooooo`?o<ol03_ooool3o`3oIPoooooo00?o0?oo
ooooooooool02oooool2o`1Vo`?ooooo00?o0000ooooooooool01_ooool2oc<0oa?ooooo00?o0000
ooooooooool00oooool004gooooo0_l0001Mooooo`03o`000?oooooooooo02Oooooo1OooV@02o`00
01Gooooo1?o<o`0Eooooo`?o<ol03oooool2o`3oIQ3ooooo0_l0ool=ooooo`03o`1Voooooooooooo
00?ooooo00?o0000ooooooooool01?ooool2oc<0oaGooooo00?o0000ooooooooool00oooool004oo
oooo00?o0000ooooooooool0Foooool00ol0003oooooooooo`0Oooooo`OooiT000Coooooo`000?l0
003o00005?ooool4olco01Kooooo0olco`0@ooooo`;o0?mV4?ooool2o`3oo`gooooo0_l0I_l7oooo
o`03o`000?oooooooooo00;ooooo00?o<`3oooooooooool05Oooool00ol0003oooooooooo`03oooo
o`00D?ooool00ol0003oooooooooo`1Kooooo`03o`000?oooooooooo01Kooooo2?ooV@04ooooo`Co
00004oooool4olco01Kooooo1?lco`0Aooooo`;o0?mV4?ooool2o`3oo`gooooo0_l0I_l:ooooo`04
o`000?oooooo<`3ooc<0oaSooooo00?o0000ooooooooool00oooool0057ooooo00?o0000oooooooo
ool0Foooool00ol0003oooooooooo`09ooooo`cooiT02Oooool3o`0001?ooooo1?o<o`0Gooooo`?o
<ol04_ooool3o`3oIQ3ooooo0_l0ool=ooooo`;o06Ko3?ooool00olc0?oo0000ooooo`0Iooooo`03
o`000?oooooooooo00?ooooo001Booooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool0
2?ooV@0Booooo`?o00004Oooool5olco01Sooooo0olco`0Booooo`?o0?mV4?ooool3o`3oo`gooooo
0_l0I_l<ooooo`;o<`3o0_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00?ooooo
001Cooooo`03o`000?oooooooooo05_ooooo00?o0000ooooooooool05Oooool4o`0000oooooo1Oo<
o`0Jooooo`?o<ol04_ooool3o`3oIQ7ooooo0_l0ool?ooooo`03o`1Voooooooooooo00_ooooo00?o
<`3oooooooooool00_ooool00ol0003oooooooooo`06ooooo`;oc03o3oooool00ol0003ooooooooo
o`03ooooo`00E?ooool2o`0005cooooo00?o0000ooooooooool04Oooool3o`0000kooooo1Oo<o`0L
ooooo`?o<ol04_ooool3o`3oIQ7ooooo0ol0ool?ooooo`;o06Ko3?ooool2oc<0o`Kooooo00?o0000
ooooooooool00oooool2ol`0oa7ooooo00?o0000ooooooooool00oooool005Kooooo00?o0000oooo
ooooool0F_ooool00ol0003oooooooooo`0=ooooo`?o00002_ooool7olco01gooooo1?lco`0Boooo
o`?o0?mV4_ooool2o`3ooa3ooooo0_l0I_l<ooooo`;o<`3o2Oooool01Ol0003ooooooooooooooooo
c03o01Cooooo00?o0000ooooooooool00_ooool005Oooooo00?o0000ooooooooool0F_ooool00ol0
003oooooooooo`08ooooo`Co00001Oooool8olco023ooooo1?lco`0Booooo`Co0?mV4_ooool3o`3o
oa3ooooo0_l0I_l<ooooo`;o<`3o3?ooool00ol0003oc03ool`0o`0Eooooo`03o`000?oooooooooo
00;ooooo001Hooooo`03o`000?oooooooooo05[ooooo00?o0000ooooooooool01?ooool<olco02Co
oooo1?lco`0Cooooo`?o0?mV5?ooool2o`3ooa7ooooo0_l0I_l<ooooo`;o<`3o3Oooool2ol`0o`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool00_ooool005Wooooo00?o0000ooooooooool0
F?ooool8olco02cooooo1?lco`0Dooooo`?o0?mV5?ooool3o`3ooa3ooooo0ol0I_l<ooooo`;o<`3o
3Oooool2ol`0o`;ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`02ooooo`00F_oo
ool00ol0003oooooooooo`1Jooooo`;o0000:_ooool5oc?o01Gooooo0ol0ofHDooooo`?o0?oo4?oo
ool3o`1Vo`kooooo00?o<`3oooooooooool03?ooool00oo<0?ooooooooooo`03ooooo`03o`000?oo
oooooooo00Gooooo0_oo09T<ooooo`03o`000?oooooooooo00;ooooo001Kooooo`03o`000?oooooo
oooo05Wooooo00?o0000ooooooooool08oooool6oc?o01Oooooo0ol0ofHEooooo`;o0?oo4Oooool2
o`1Vo`oooooo0_lc0?l=ooooo`;oc03o1oooool00ol0003oooooooooo`02ooooo`;oo`2I3_ooool0
0ol0003oooooooooo`02ooooo`00G?ooool2o`0005Wooooo00?o0000ooooooooool07_ooool5oc?o
01Wooooo1?l0ofHEooooo`?o0?oo4?ooool3o`1Vo`oooooo0_lc0?l=ooooo`;oc03o2_ooool01?l0
003oooooool0VOoo09T@ooooo`03o`000?oooooooooo00;ooooo001Nooooo`03o`000?oooooooooo
05Kooooo00?o0000ooooooooool05oooool7oc?o01[ooooo1?l0ofHFooooo`?o0?oo4?ooool3o`1V
oa3ooooo0_lc0?l=ooooo`;oc03o3?ooool00ooo09Wo0000ooooo`0Aooooo`03o`000?oooooooooo
00;ooooo001Oooooo`03o`000?oooooooooo05Gooooo00?o0000ooooooooool03_ooool9oc?o01co
oooo1Ol0ofHGooooo`?o0?oo4Oooool2o`1Voa7ooooo0_lc0?l=ooooo`;oc03o3Oooool00ooo09Wo
ooooo`00000Cooooo`03o`000?oooooooooo007ooooo001Pooooo`03o`000?oooooooooo05Cooooo
00?o0000ooooooooool00_ooool<oc?o027ooooo1?l0ofHHooooo`Co0?oo4Oooool3o`1Voa3ooooo
0olc0?l=ooooo`;oc03o3Oooool2ool0V@?ooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`01ooooo`00HOooool00ol0003oooooooooo`1@ooooo`So<ol0:?ooool5o`3oIQOooooo1Ol0
oolBooooo`?o06Ko4?ooool3oc<0o`kooooo0_o<0?l=ooooo`;oo`2I1_ooool00ol0003ooooooooo
o`04ooooo`;oo`002Oooool00ol0003oooooooooo`01ooooo`00H_ooool00ol0003oooooooooo`1B
ooooo`03o`000?oooooooooo02Cooooo1_l0ofHHooooo`Co0?oo5?ooool3o`1Voa7ooooo0_lc0?l?
ooooo`;oc03o3Oooool2ool0V@Wooooo00Co0000oooooooooooooooo0_oo000;ooooo`03o`000?oo
oooooooo007ooooo001Sooooo`;o0000D_ooool00ol0003oooooooooo`0Oooooo`Go0?mV6_ooool4
o`3ooaGooooo0ol0I_lAooooo`?o<`3o3oooool2ol`0o`gooooo0_oo09T<ooooo`03o`000?oo003o
o`0000gooooo00?o0000ooooooooool00Oooool006Gooooo00?o0000ooooooooool0Coooool00ol0
003oooooooooo`0Hooooo`Oo0?mV6oooool4o`3ooaKooooo0ol0I_lAooooo`?o<`3o4?ooool2ol`0
o`gooooo0_oo09T=ooooo`03ool00?l0003ooooo00kooooo00?o0000ooooooooool00Oooool006Ko
oooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0?ooooo`Wo0?mV7Oooool5o`3ooaOo
oooo0ol0I_lBooooo`;o<`3o4Oooool2ol`0o`gooooo0_oo09T>ooooo`04ool00?ooooooooooo`00
00kooooo00?o0000ooooooooool00Oooool006Oooooo00?o0000ooooooooool0COooool00ol0003o
ooooooooo`03ooooo`co0?mV8_ooool4o`3ooaWooooo0ol0I_lBooooo`?o<`3o4?ooool3ol`0o`go
oooo0_oo09T>ooooo`;oo`001?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo007o
oooo001Xooooo`03o`000?oooooooooo04[ooooo2?l0ofHYooooo`Go0?oo6Oooool4o`1Voa;ooooo
0olc0?lAooooo`;oc03o3_ooool2ool0V@kooooo0_oo0007ooooo`03o`000?oooooooooo00_ooooo
0Ol00001ooooo`7ooooo001Yooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool09_oo
ool6o`3ooa_ooooo0ol0I_lCooooo`?o<`3o4Oooool3ol`0o`kooooo0_oo09T>ooooo`;oo`002Ooo
ool00ol0003oooooooooo`0;ooooo`7o00000Oooool1ooooo`00J_ooool00ol0003oooooooooo`1:
ooooo`03o`000?oooooooooo027ooooo1Ol0oolNooooo`?o06Ko4oooool3oc<0oa;ooooo0_o<0?l?
ooooo`;oo`2I3_ooool2ool000cooooo00?o0000ooooooooool02_ooool1o`00007ooooo0Oooool0
06_ooooo0_l0001:ooooo`03o`000?oooooooooo01_ooooo1_l0oolOooooo`Co06Ko4oooool3oc<0
oa?ooooo0_o<0?l?ooooo`;oo`2I3_ooool2ool000oooooo00?o0000ooooooooool02Oooool1o`00
007ooooo0Oooool006gooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Eooooo`Ko
0?oo8Oooool4o`1VoaCooooo0olc0?lCooooo`?oc03o3oooool2ool0V@oooooo00?oo`00oooooooo
ool04?ooool00ol0003oooooooooo`08ooooo`7o00000Oooool1ooooo`00K_ooool00ol0003ooooo
ooooo`16ooooo`03o`000?oooooooooo00oooooo1_l0oolRooooo`Go06Ko5Oooool3oc<0oa?ooooo
0oo<0?l@ooooo`;oo`2I4?ooool00ooo003oooooooooo`0Booooo`03o`000?oooooooooo00Oooooo
0Ol00001ooooo`7ooooo001_ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool01?oo
ool;o`3oobCooooo1?l0I_lFooooo`Co<`3o4oooool3ol`0oc[ooooo00?o0000ooooooooool01ooo
ool1o`00007ooooo0Oooool0073ooooo00?o0000ooooooooool0@_ooool9o`3oob[ooooo1Ol0I_lF
ooooo`Co<`3o4oooool4ol`0ockooooo00?o0000ooooooooool01_ooool1o`00007ooooo0Oooool0
077ooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`0Xooooo`Ko06Ko6?ooool3oc<0
oaCooooo0oo<0?m3ooooo`03o`000?oooooooooo00Gooooo0Ol00001ooooo`7ooooo001booooo`;o
0000@_ooool00ol0003oooooooooo`0Sooooo`Ko06Ko6_ooool4oc<0oaCooooo0oo<0?m7ooooo`03
o`000?oooooooooo00Gooooo0Ol00001ooooo`00M?ooool00ol0003oooooooooo`0oooooo`03o`00
0?oooooooooo01cooooo1ol0I_lKooooo`Go<`3o5?ooool4ol`0od_ooooo00?o0000ooooooooool0
1?ooool1o`00007ooooo001eooooo`03o`000?oooooooooo03kooooo00?o0000ooooooooool04ooo
ool9o`1Voakooooo1?lc0?lFooooo`?oc03oCoooool00ol0003oooooooooo`04ooooo`7o00000Ooo
ool007Kooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`06ooooo`go06Ko8_ooool5
oc<0oaKooooo1?o<0?mCooooo`03o`000?oooooooooo00?ooooo0Ol00001ooooo`00Moooool00ol0
003oooooooooo`0looooo`Wo06Ko:_ooool5oc<0oaOooooo1?o<0?mHooooo`03o`000?oooooooooo
00;ooooo0Ol00001ooooo`00N?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo02[o
oooo1_lc0?lIooooo`?oc03oGOooool01Ol0003ooooooooooooooooo0000007ooooo001iooooo`03
o`000?oooooooooo03[ooooo00?o0000ooooooooool09?ooool6oc<0oa_ooooo1?o<0?mQooooo`04
o`000?ooooooooooo`00007ooooo001jooooo`;o0000>_ooool00ol0003oooooooooo`0Mooooo`Oo
<`3o7?ooool5ol`0ofGooooo00Co0000oooooooooooo00000Oooool007cooooo00?o0000oooooooo
ool0=oooool00ol0003oooooooooo`0Dooooo`Wo<`3o7oooool4ol`0of_ooooo00?o0000oooooooo
ool00Ol0000007gooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0;ooooo`Wo<`3o
8oooool5ol`0og3ooooo0Ol00001ooooo`7o0000001nooooo`03o`000?oooooooooo03Gooooo00?o
0000ooooooooool00_ooool9oc<0obSooooo1?o<0?mfooooo`;o0000001oooooo`03o`000?oooooo
oooo03Cooooo1Olc0?l/ooooo`Goc03oNOooool3o`000000P?ooool00ol0003oooooooooo`0coooo
o`03o`000?oooooooooo02Wooooo1Oo<0?mjooooo`Co00000oooool0087ooooo0_l0000cooooo`03
o`000?oooooooooo02Cooooo1Oo<0?mlooooo`?o00001oooool008?ooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`0Nooooo`Koc03oOOooool4o`0000[ooooo0024ooooo`03o`000?oo
oooooooo02oooooo00?o0000ooooooooool05Oooool9ol`0ogoooooo1?l0000>ooooo`00QOooool0
0ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00Oooooo3_o<0?n4ooooo`Co00004_ooool0
08Kooooo00?o0000ooooooooool0;Oooool:ol`0ohkooooo1?l0000Fooooo`00Qoooool00ol0003o
ooooooooo`0/ooooo`03o`000?oooooooooo09;ooooo0ol0000Jooooo`00R?ooool2o`0002cooooo
00?o0000ooooooooool09_ooool3ool0VFGooooo1?l0000Mooooo`00R_ooool00ol0003ooooooooo
o`0Yooooo`03o`000?oooooooooo01oooooo1ooo09UTooooo`Co00008Oooool008_ooooo00?o0000
ooooooooool0:?ooool00ol0003oooooooooo`0Fooooo`Woo`2IIoooool4o`0002Gooooo002<oooo
o`03o`000?oooooooooo02Oooooo00?o0000ooooooooool03?ooool:ool0VFcooooo1?l0000Yoooo
o`00SOooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00?ooooo2Ooo09Ucooooo`?o
0000;Oooool008kooooo00?o0000ooooooooool09Oooool00ol0003oo`2Iool0V@03ool0VGSooooo
1?l0000`ooooo`00Soooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo07Oooooo1?l0
000dooooo`00T?ooool2o`0002Cooooo00?o0000ooooooooool0Loooool4o`0003Sooooo002Boooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool0L?ooool3o`0003cooooo002Cooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool05?ooool4ool005Cooooo1?l0000oooooo`00
U?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00Sooooo3?oo001Dooooo`Co0000
@oooool009Gooooo00?o0000ooooooooool07_ooool00ol0003oo`00ool00008ool005cooooo1?l0
0017ooooo`00U_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo063ooooo1?l0001;
ooooo`00Uoooool2o`0001gooooo00?o0000ooooooooool0GOooool3o`0004oooooo002Iooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool0FOooool4o`0005;ooooo002Jooooo`03o`00
0?oooooooooo01Wooooo00?o0000ooooooooool0EOooool4o`0005Kooooo002Kooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool0DOooool4o`0005[ooooo002Looooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool0COooool4o`0005kooooo002Mooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool0B_ooool3o`0006;ooooo002Nooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool0A_ooool4o`0006Gooooo002Oooooo`;o00005?ooool00ol0003ooooo
ooooo`13ooooo`Co0000JOooool00:7ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0oooooo`Co0000KOooool00:;ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0k
ooooo`Co0000LOooool00:?ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0hoooo
o`?o0000MOooool00:Cooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0dooooo`Co
0000N?ooool00:Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0`ooooo`Co0000
O?ooool00:Kooooo0_l0000=ooooo`03o`000?oooooooooo02cooooo1?l00020ooooo`00Z?ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Wooooo0ol00024ooooo`00ZOooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo02Gooooo1?l00027ooooo`00Z_ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo027ooooo1?l0002;ooooo`00Zoooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo01gooooo1?l0002?ooooo`00[?ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo01Wooooo1?l0002Cooooo`00[Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo01Kooooo0ol0002Gooooo`00[_ooool2o`0000Gooooo00?o0000oooo
ooooool04_ooool4o`0009[ooooo002`ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool03_ooool4o`0009kooooo002aooooo`05o`000?ooooooooooooooool000003?ooool4o`000:;o
oooo002booooo`04o`000?ooooooooooo`0000Sooooo1?l0002Vooooo`00/oooool00ol0003ooooo
o`000005ooooo`?o0000Z_ooool00;Cooooo0_l000000ooooooo0000o`000002o`000:gooooo002e
ooooo`;o0000/Oooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {319.688, 0}} -> {-0.0710364, -0.0181728, \
0.0035149, 0.0035149}}]
}, Closed]]
}, Open  ]],

Cell[TextData[{
  "Each colored line in this animation represents a different contour of \
constant phase. Initially the phase is a plane, ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi] = \[Kappa]\ y\)]],
  ", but the phase fronts are refracted by the inhomogeneous region, causing \
them to spread and curve outward.  The contours of constant phase are easy to \
create since phase is conserved along each ray trajectory. Thus, the constant \
phase contours can be found by merely connecting points that were initially \
on the same constant phase contour. \n\tIn Cell ",
  ButtonBox["5.44",
    ButtonData:>"Cell 5.44",
    ButtonStyle->"Hyperlink"],
  ", we display the ray trajectories along with a single constant phase \
contour (in red), plotting the latter at several equally-spaced times:"
}], "Text"],

Cell[BoxData[
    \(\(rays\  = \ 
        Table[ParametricPlot[{\(phasedata[\([10]\)]\)[\([n, 
                  1]\)], \(phasedata[\([10]\)]\)[\([n, 2]\)]}, {t, 0, 6}, 
            DisplayFunction \[Rule] Identity], {n, 1, 10}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 5.42"],

Cell[BoxData[
    \(\(phasecontour = 
        Table[ListPlot[
            Table[{\(phasedata[\([10]\)]\)[\([n, 
                    1]\)], \(phasedata[\([10]\)]\)[\([n, 2]\)]}, {n, 1, 10}], 
            PlotJoined \[Rule] True, PlotStyle \[Rule] RGBColor[1, 0, 0], 
            DisplayFunction \[Rule] Identity], {t, 0, 6, 1}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 5.43"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Show[rays, phasecontour, DisplayFunction \[Rule] $DisplayFunction, 
        PlotRange \[Rule] {{\(-3\), 3}, {0, 8}}, AspectRatio \[Rule] 8/6, 
        AxesLabel \[Rule] {"\<x\>", "\<y\>"}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 5.44"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.33333 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.166667 0 0.166667 [
[0 -0.0125 -6 -9 ]
[0 -0.0125 6 0 ]
[.16667 -0.0125 -6 -9 ]
[.16667 -0.0125 6 0 ]
[.33333 -0.0125 -6 -9 ]
[.33333 -0.0125 6 0 ]
[.66667 -0.0125 -3 -9 ]
[.66667 -0.0125 3 0 ]
[.83333 -0.0125 -3 -9 ]
[.83333 -0.0125 3 0 ]
[1 -0.0125 -3 -9 ]
[1 -0.0125 3 0 ]
[1.025 0 0 -6 ]
[1.025 0 10 6 ]
[.4875 .16667 -6 -4.5 ]
[.4875 .16667 0 4.5 ]
[.4875 .33333 -6 -4.5 ]
[.4875 .33333 0 4.5 ]
[.4875 .5 -6 -4.5 ]
[.4875 .5 0 4.5 ]
[.4875 .66667 -6 -4.5 ]
[.4875 .66667 0 4.5 ]
[.4875 .83333 -6 -4.5 ]
[.4875 .83333 0 4.5 ]
[.4875 1 -6 -4.5 ]
[.4875 1 0 4.5 ]
[.4875 1.16667 -6 -4.5 ]
[.4875 1.16667 0 4.5 ]
[.4875 1.33333 -6 -4.5 ]
[.4875 1.33333 0 4.5 ]
[.5 1.35833 -5 0 ]
[.5 1.35833 5 12 ]
[ 0 0 0 0 ]
[ 1 1.33333 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
0 0 m
0 .00625 L
s
[(-3)] 0 -0.0125 0 1 Mshowa
.16667 0 m
.16667 .00625 L
s
[(-2)] .16667 -0.0125 0 1 Mshowa
.33333 0 m
.33333 .00625 L
s
[(-1)] .33333 -0.0125 0 1 Mshowa
.66667 0 m
.66667 .00625 L
s
[(1)] .66667 -0.0125 0 1 Mshowa
.83333 0 m
.83333 .00625 L
s
[(2)] .83333 -0.0125 0 1 Mshowa
1 0 m
1 .00625 L
s
[(3)] 1 -0.0125 0 1 Mshowa
.125 Mabswid
.03333 0 m
.03333 .00375 L
s
.06667 0 m
.06667 .00375 L
s
.1 0 m
.1 .00375 L
s
.13333 0 m
.13333 .00375 L
s
.2 0 m
.2 .00375 L
s
.23333 0 m
.23333 .00375 L
s
.26667 0 m
.26667 .00375 L
s
.3 0 m
.3 .00375 L
s
.36667 0 m
.36667 .00375 L
s
.4 0 m
.4 .00375 L
s
.43333 0 m
.43333 .00375 L
s
.46667 0 m
.46667 .00375 L
s
.53333 0 m
.53333 .00375 L
s
.56667 0 m
.56667 .00375 L
s
.6 0 m
.6 .00375 L
s
.63333 0 m
.63333 .00375 L
s
.7 0 m
.7 .00375 L
s
.73333 0 m
.73333 .00375 L
s
.76667 0 m
.76667 .00375 L
s
.8 0 m
.8 .00375 L
s
.86667 0 m
.86667 .00375 L
s
.9 0 m
.9 .00375 L
s
.93333 0 m
.93333 .00375 L
s
.96667 0 m
.96667 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .16667 m
.50625 .16667 L
s
[(1)] .4875 .16667 1 0 Mshowa
.5 .33333 m
.50625 .33333 L
s
[(2)] .4875 .33333 1 0 Mshowa
.5 .5 m
.50625 .5 L
s
[(3)] .4875 .5 1 0 Mshowa
.5 .66667 m
.50625 .66667 L
s
[(4)] .4875 .66667 1 0 Mshowa
.5 .83333 m
.50625 .83333 L
s
[(5)] .4875 .83333 1 0 Mshowa
.5 1 m
.50625 1 L
s
[(6)] .4875 1 1 0 Mshowa
.5 1.16667 m
.50625 1.16667 L
s
[(7)] .4875 1.16667 1 0 Mshowa
.5 1.33333 m
.50625 1.33333 L
s
[(8)] .4875 1.33333 1 0 Mshowa
.125 Mabswid
.5 .03333 m
.50375 .03333 L
s
.5 .06667 m
.50375 .06667 L
s
.5 .1 m
.50375 .1 L
s
.5 .13333 m
.50375 .13333 L
s
.5 .2 m
.50375 .2 L
s
.5 .23333 m
.50375 .23333 L
s
.5 .26667 m
.50375 .26667 L
s
.5 .3 m
.50375 .3 L
s
.5 .36667 m
.50375 .36667 L
s
.5 .4 m
.50375 .4 L
s
.5 .43333 m
.50375 .43333 L
s
.5 .46667 m
.50375 .46667 L
s
.5 .53333 m
.50375 .53333 L
s
.5 .56667 m
.50375 .56667 L
s
.5 .6 m
.50375 .6 L
s
.5 .63333 m
.50375 .63333 L
s
.5 .7 m
.50375 .7 L
s
.5 .73333 m
.50375 .73333 L
s
.5 .76667 m
.50375 .76667 L
s
.5 .8 m
.50375 .8 L
s
.5 .86667 m
.50375 .86667 L
s
.5 .9 m
.50375 .9 L
s
.5 .93333 m
.50375 .93333 L
s
.5 .96667 m
.50375 .96667 L
s
.5 1.03333 m
.50375 1.03333 L
s
.5 1.06667 m
.50375 1.06667 L
s
.5 1.1 m
.50375 1.1 L
s
.5 1.13333 m
.50375 1.13333 L
s
.5 1.2 m
.50375 1.2 L
s
.5 1.23333 m
.50375 1.23333 L
s
.5 1.26667 m
.50375 1.26667 L
s
.5 1.3 m
.50375 1.3 L
s
.25 Mabswid
.5 0 m
.5 1.33333 L
s
gsave
.5 1.35833 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 1.33333 L
0 1.33333 L
closepath
clip
newpath
.5 Mabswid
.425 .075 m
.425 .07623 L
.425 .07736 L
.425 .07865 L
.425 .07988 L
.425 .08101 L
.425 .08206 L
.425 .08442 L
.425 .08681 L
.425 .08944 L
.425 .09221 L
.425 .09475 L
.425 .09602 L
.425 .0974 L
.425 .09993 L
.425 .10262 L
.425 .1055 L
.425 .10824 L
.425 .11072 L
.425 .11322 L
.425 .11557 L
.425 .11813 L
.425 .12095 L
.425 .12389 L
.425 .12664 L
.425 .13156 L
.425 .13431 L
.425 .13683 L
.425 .13977 L
.425 .14249 L
.425 .14547 L
.425 .14865 L
.425 .1514 L
.425 .15398 L
.425 .15681 L
.425 .15987 L
.42499 .1624 L
.42499 .1651 L
.42499 .16999 L
.42499 .17298 L
.42498 .17582 L
.42497 .18114 L
.42497 .18389 L
.42496 .18681 L
.42494 .1921 L
.42493 .19506 L
.42492 .19786 L
.42489 .20119 L
.42487 .20432 L
.42481 .21006 L
Mistroke
.42477 .21316 L
.42471 .21653 L
.42458 .22298 L
.4244 .22911 L
.42415 .23545 L
.42375 .24279 L
.42321 .25029 L
.42249 .25777 L
.42138 .2667 L
.41964 .2772 L
.41735 .28797 L
.41461 .29839 L
.40521 .32518 L
.394 .34973 L
.35937 .41632 L
.33871 .46091 L
.32187 .49924 L
.30598 .53565 L
.28909 .5744 L
.27283 .61168 L
.25554 .65133 L
.23888 .68951 L
.22287 .72624 L
.20582 .76533 L
.18941 .80296 L
.17197 .84295 L
.15517 .88148 L
.139 .91855 L
.1218 .95799 L
.10524 .99596 L
.08932 1.03248 L
.07237 1.07135 L
.05605 1.10877 L
.05592 1.10906 L
Mfstroke
.44167 .075 m
.44167 .07623 L
.44167 .07736 L
.44167 .07865 L
.44167 .07988 L
.44167 .08101 L
.44167 .08206 L
.44167 .08442 L
.44167 .08681 L
.44167 .08944 L
.44167 .09076 L
.44167 .09218 L
.44167 .09475 L
.44167 .09613 L
.44167 .09741 L
.44167 .10032 L
.44167 .10289 L
.44167 .10562 L
.44167 .10831 L
.44167 .11084 L
.44167 .11311 L
.44167 .11557 L
.44167 .11833 L
.44167 .12091 L
.44167 .12374 L
.44167 .12678 L
.44167 .12996 L
.44167 .13297 L
.44167 .13568 L
.44167 .13862 L
.44167 .14116 L
.44167 .14397 L
.44167 .1469 L
.44167 .14965 L
.44166 .15457 L
.44166 .15733 L
.44166 .15987 L
.44166 .16488 L
.44166 .16769 L
.44166 .17025 L
.44166 .17264 L
.44165 .17524 L
.44165 .17997 L
.44164 .18265 L
.44164 .18561 L
.44163 .18851 L
.44162 .19164 L
.44161 .19459 L
.4416 .19731 L
.44157 .20272 L
Mistroke
.44152 .20824 L
.44145 .2143 L
.44136 .22025 L
.44124 .22589 L
.44103 .23294 L
.44069 .24118 L
.44019 .24973 L
.43949 .2584 L
.43849 .26778 L
.43692 .27889 L
.43483 .29037 L
.43233 .30155 L
.42386 .33044 L
.41403 .35699 L
.38619 .42688 L
.37043 .4725 L
.35738 .51211 L
.345 .54984 L
.33184 .59001 L
.31917 .62866 L
.30569 .66976 L
.29272 .70935 L
.28024 .74742 L
.26695 .78795 L
.25417 .82696 L
.24058 .86841 L
.22748 .90836 L
.21489 .94679 L
.20149 .98767 L
.18858 1.02704 L
.17617 1.06489 L
.16296 1.10519 L
.15025 1.14398 L
.14996 1.14486 L
Mfstroke
.45833 .075 m
.45833 .07623 L
.45833 .07736 L
.45833 .07865 L
.45833 .07988 L
.45833 .08101 L
.45833 .08206 L
.45833 .08442 L
.45833 .08681 L
.45833 .08944 L
.45833 .09076 L
.45833 .09218 L
.45833 .09475 L
.45833 .09613 L
.45833 .09741 L
.45833 .10032 L
.45833 .10289 L
.45833 .10562 L
.45833 .10831 L
.45833 .11084 L
.45833 .11311 L
.45833 .11557 L
.45833 .11833 L
.45833 .12091 L
.45833 .12374 L
.45833 .12678 L
.45833 .12996 L
.45833 .13297 L
.45833 .13568 L
.45833 .13862 L
.45833 .14116 L
.45833 .14397 L
.45833 .1469 L
.45833 .14965 L
.45833 .15457 L
.45833 .15734 L
.45833 .15988 L
.45833 .16489 L
.45833 .1677 L
.45833 .17026 L
.45832 .17265 L
.45832 .17525 L
.45832 .18 L
.45831 .18268 L
.45831 .18564 L
.4583 .18855 L
.4583 .19169 L
.45829 .19465 L
.45828 .19739 L
.45826 .20282 L
Mistroke
.45822 .20838 L
.45817 .2145 L
.45809 .22052 L
.458 .22625 L
.45783 .23346 L
.45771 .23777 L
.45756 .24193 L
.45719 .25016 L
.45658 .25982 L
.4557 .27025 L
.45453 .28079 L
.45263 .29417 L
.45021 .30783 L
.43731 .36047 L
.41675 .4341 L
.40565 .48066 L
.3964 .52124 L
.3876 .55996 L
.37824 .60118 L
.36923 .64085 L
.35965 .68302 L
.35042 .72365 L
.34154 .76272 L
.3321 .80431 L
.323 .84434 L
.31334 .88688 L
.30403 .92788 L
.29507 .96731 L
.28554 1.00927 L
.27636 1.04966 L
.26754 1.08851 L
.25814 1.12987 L
.2491 1.16968 L
.24854 1.17213 L
Mfstroke
.475 .075 m
.475 .07623 L
.475 .07736 L
.475 .07865 L
.475 .07988 L
.475 .08101 L
.475 .08206 L
.475 .08442 L
.475 .08681 L
.475 .08944 L
.475 .09076 L
.475 .09218 L
.475 .09475 L
.475 .09741 L
.475 .10032 L
.475 .10307 L
.475 .10562 L
.475 .1081 L
.475 .11044 L
.475 .11313 L
.475 .11557 L
.475 .11813 L
.475 .12095 L
.475 .12389 L
.475 .12664 L
.475 .12921 L
.475 .13156 L
.475 .13426 L
.475 .13683 L
.475 .13961 L
.475 .14256 L
.475 .14508 L
.475 .14786 L
.475 .15084 L
.475 .15405 L
.475 .15709 L
.475 .15988 L
.475 .16489 L
.475 .16771 L
.475 .17027 L
.47499 .17266 L
.47499 .17526 L
.47499 .18001 L
.47499 .1827 L
.47499 .18566 L
.47498 .18858 L
.47498 .19173 L
.47497 .1947 L
.47497 .19744 L
.47495 .20289 L
Mistroke
.47493 .20848 L
.47489 .21464 L
.47485 .22072 L
.47479 .22652 L
.47468 .23383 L
.4746 .23822 L
.4745 .24247 L
.47426 .25091 L
.47386 .26086 L
.47327 .27167 L
.47249 .28264 L
.47123 .29661 L
.46964 .31091 L
.46137 .36591 L
.4491 .44052 L
.44258 .48736 L
.43707 .52855 L
.43183 .5679 L
.42624 .6098 L
.42086 .65012 L
.41515 .69299 L
.40964 .73429 L
.40435 .774 L
.39871 .81627 L
.39329 .85696 L
.38752 .90021 L
.38196 .94188 L
.37662 .98197 L
.37093 1.02461 L
.36546 1.06567 L
.36019 1.10516 L
.35459 1.1472 L
.34919 1.18766 L
.34886 1.19015 L
Mfstroke
.49167 .075 m
.49167 .07623 L
.49167 .07736 L
.49167 .07865 L
.49167 .07988 L
.49167 .08101 L
.49167 .08206 L
.49167 .08442 L
.49167 .08681 L
.49167 .08944 L
.49167 .09076 L
.49167 .09218 L
.49167 .09475 L
.49167 .09741 L
.49167 .10032 L
.49167 .10307 L
.49167 .10562 L
.49167 .1081 L
.49167 .11044 L
.49167 .11313 L
.49167 .11557 L
.49167 .11813 L
.49167 .12095 L
.49167 .12389 L
.49167 .12664 L
.49167 .12921 L
.49167 .13156 L
.49167 .13426 L
.49167 .13683 L
.49167 .13961 L
.49167 .14256 L
.49167 .14508 L
.49167 .14786 L
.49167 .15084 L
.49167 .15406 L
.49167 .15709 L
.49167 .15988 L
.49167 .1649 L
.49167 .16771 L
.49167 .17027 L
.49166 .17267 L
.49166 .17527 L
.49166 .18002 L
.49166 .18271 L
.49166 .18568 L
.49166 .18859 L
.49166 .19174 L
.49166 .19472 L
.49166 .19746 L
.49165 .20293 L
Mistroke
.49164 .20853 L
.49163 .21471 L
.49161 .22082 L
.49159 .22665 L
.49156 .23402 L
.49153 .23846 L
.49149 .24275 L
.49141 .2513 L
.49127 .26141 L
.49106 .27242 L
.49079 .28362 L
.48979 .31255 L
.48841 .34193 L
.48695 .3688 L
.48288 .4438 L
.48073 .49075 L
.47891 .53224 L
.47716 .5719 L
.47531 .61413 L
.47352 .65477 L
.47162 .69798 L
.46979 .7396 L
.46804 .77963 L
.46616 .82223 L
.46436 .86324 L
.46245 .90683 L
.4606 .94882 L
.45883 .98923 L
.45694 1.03221 L
.45512 1.0736 L
.45337 1.11339 L
.45151 1.15576 L
.44972 1.19654 L
.44961 1.19905 L
Mfstroke
.50833 .075 m
.50833 .07623 L
.50833 .07736 L
.50833 .07865 L
.50833 .07988 L
.50833 .08101 L
.50833 .08206 L
.50833 .08442 L
.50833 .08681 L
.50833 .08944 L
.50833 .09076 L
.50833 .09218 L
.50833 .09475 L
.50833 .09741 L
.50833 .10032 L
.50833 .10307 L
.50833 .10562 L
.50833 .1081 L
.50833 .11044 L
.50833 .11313 L
.50833 .11557 L
.50833 .11813 L
.50833 .12095 L
.50833 .12389 L
.50833 .12664 L
.50833 .12921 L
.50833 .13156 L
.50833 .13426 L
.50833 .13683 L
.50833 .13961 L
.50833 .14256 L
.50833 .14508 L
.50833 .14786 L
.50833 .15084 L
.50833 .15406 L
.50833 .15709 L
.50833 .15988 L
.50833 .1649 L
.50833 .16771 L
.50833 .17027 L
.50834 .17267 L
.50834 .17527 L
.50834 .18002 L
.50834 .18271 L
.50834 .18568 L
.50834 .18859 L
.50834 .19174 L
.50834 .19472 L
.50834 .19746 L
.50835 .20293 L
Mistroke
.50836 .20853 L
.50837 .21471 L
.50839 .22082 L
.50841 .22665 L
.50844 .23402 L
.50847 .23846 L
.50851 .24275 L
.50859 .2513 L
.50873 .26141 L
.50894 .27242 L
.50921 .28362 L
.51021 .31255 L
.51159 .34193 L
.51305 .3688 L
.51712 .4438 L
.51927 .49075 L
.52109 .53224 L
.52284 .5719 L
.52469 .61413 L
.52648 .65477 L
.52838 .69798 L
.53021 .7396 L
.53196 .77963 L
.53384 .82223 L
.53564 .86324 L
.53755 .90683 L
.5394 .94882 L
.54117 .98923 L
.54306 1.03221 L
.54488 1.0736 L
.54663 1.11339 L
.54849 1.15576 L
.55028 1.19654 L
.55039 1.19905 L
Mfstroke
.525 .075 m
.525 .07623 L
.525 .07736 L
.525 .07865 L
.525 .07988 L
.525 .08101 L
.525 .08206 L
.525 .08442 L
.525 .08681 L
.525 .08944 L
.525 .09076 L
.525 .09218 L
.525 .09475 L
.525 .09741 L
.525 .10032 L
.525 .10307 L
.525 .10562 L
.525 .1081 L
.525 .11044 L
.525 .11313 L
.525 .11557 L
.525 .11813 L
.525 .12095 L
.525 .12389 L
.525 .12664 L
.525 .12921 L
.525 .13156 L
.525 .13426 L
.525 .13683 L
.525 .13961 L
.525 .14256 L
.525 .14508 L
.525 .14786 L
.525 .15084 L
.525 .15405 L
.525 .15709 L
.525 .15988 L
.525 .16489 L
.525 .16771 L
.525 .17027 L
.52501 .17266 L
.52501 .17526 L
.52501 .18001 L
.52501 .1827 L
.52501 .18566 L
.52502 .18858 L
.52502 .19173 L
.52503 .1947 L
.52503 .19744 L
.52505 .20289 L
Mistroke
.52507 .20848 L
.52511 .21464 L
.52515 .22072 L
.52521 .22652 L
.52532 .23383 L
.5254 .23822 L
.5255 .24247 L
.52574 .25091 L
.52614 .26086 L
.52673 .27167 L
.52751 .28264 L
.52877 .29661 L
.53036 .31091 L
.53863 .36591 L
.5509 .44052 L
.55742 .48736 L
.56293 .52855 L
.56817 .5679 L
.57376 .6098 L
.57914 .65012 L
.58485 .69299 L
.59036 .73429 L
.59565 .774 L
.60129 .81627 L
.60671 .85696 L
.61248 .90021 L
.61804 .94188 L
.62338 .98197 L
.62907 1.02461 L
.63454 1.06567 L
.63981 1.10516 L
.64541 1.1472 L
.65081 1.18766 L
.65114 1.19015 L
Mfstroke
.54167 .075 m
.54167 .07623 L
.54167 .07736 L
.54167 .07865 L
.54167 .07988 L
.54167 .08101 L
.54167 .08206 L
.54167 .08442 L
.54167 .08681 L
.54167 .08944 L
.54167 .09076 L
.54167 .09218 L
.54167 .09475 L
.54167 .09613 L
.54167 .09741 L
.54167 .10032 L
.54167 .10289 L
.54167 .10562 L
.54167 .10831 L
.54167 .11084 L
.54167 .11311 L
.54167 .11557 L
.54167 .11833 L
.54167 .12091 L
.54167 .12374 L
.54167 .12678 L
.54167 .12996 L
.54167 .13297 L
.54167 .13568 L
.54167 .13862 L
.54167 .14116 L
.54167 .14397 L
.54167 .1469 L
.54167 .14965 L
.54167 .15457 L
.54167 .15734 L
.54167 .15988 L
.54167 .16489 L
.54167 .1677 L
.54167 .17026 L
.54168 .17265 L
.54168 .17525 L
.54168 .18 L
.54169 .18268 L
.54169 .18564 L
.5417 .18855 L
.5417 .19169 L
.54171 .19465 L
.54172 .19739 L
.54174 .20282 L
Mistroke
.54178 .20838 L
.54183 .2145 L
.54191 .22052 L
.542 .22625 L
.54217 .23346 L
.54229 .23777 L
.54244 .24193 L
.54281 .25016 L
.54342 .25982 L
.5443 .27025 L
.54547 .28079 L
.54737 .29417 L
.54979 .30783 L
.56269 .36047 L
.58325 .4341 L
.59435 .48066 L
.6036 .52124 L
.6124 .55996 L
.62176 .60118 L
.63077 .64085 L
.64035 .68302 L
.64958 .72365 L
.65846 .76272 L
.6679 .80431 L
.677 .84434 L
.68666 .88688 L
.69597 .92788 L
.70493 .96731 L
.71446 1.00927 L
.72364 1.04966 L
.73246 1.08851 L
.74186 1.12987 L
.7509 1.16968 L
.75146 1.17213 L
Mfstroke
.55833 .075 m
.55833 .07623 L
.55833 .07736 L
.55833 .07865 L
.55833 .07988 L
.55833 .08101 L
.55833 .08206 L
.55833 .08442 L
.55833 .08681 L
.55833 .08944 L
.55833 .09076 L
.55833 .09218 L
.55833 .09475 L
.55833 .09613 L
.55833 .09741 L
.55833 .10032 L
.55833 .10289 L
.55833 .10562 L
.55833 .10831 L
.55833 .11084 L
.55833 .11311 L
.55833 .11557 L
.55833 .11833 L
.55833 .12091 L
.55833 .12374 L
.55833 .12678 L
.55833 .12996 L
.55833 .13297 L
.55833 .13568 L
.55833 .13862 L
.55833 .14116 L
.55833 .14397 L
.55833 .1469 L
.55833 .14965 L
.55834 .15457 L
.55834 .15733 L
.55834 .15987 L
.55834 .16488 L
.55834 .16769 L
.55834 .17025 L
.55834 .17264 L
.55835 .17524 L
.55835 .17997 L
.55836 .18265 L
.55836 .18561 L
.55837 .18851 L
.55838 .19164 L
.55839 .19459 L
.5584 .19731 L
.55843 .20272 L
Mistroke
.55848 .20824 L
.55855 .2143 L
.55864 .22025 L
.55876 .22589 L
.55897 .23294 L
.55931 .24118 L
.55981 .24973 L
.56051 .2584 L
.56151 .26778 L
.56308 .27889 L
.56517 .29037 L
.56767 .30155 L
.57614 .33044 L
.58597 .35699 L
.61381 .42688 L
.62957 .4725 L
.64262 .51211 L
.655 .54984 L
.66816 .59001 L
.68083 .62866 L
.69431 .66976 L
.70728 .70935 L
.71976 .74742 L
.73305 .78795 L
.74583 .82696 L
.75942 .86841 L
.77252 .90836 L
.78511 .94679 L
.79851 .98767 L
.81142 1.02704 L
.82383 1.06489 L
.83704 1.10519 L
.84975 1.14398 L
.85004 1.14486 L
Mfstroke
.575 .075 m
.575 .07623 L
.575 .07736 L
.575 .07865 L
.575 .07988 L
.575 .08101 L
.575 .08206 L
.575 .08442 L
.575 .08681 L
.575 .08944 L
.575 .09221 L
.575 .09475 L
.575 .09602 L
.575 .0974 L
.575 .09993 L
.575 .10262 L
.575 .1055 L
.575 .10824 L
.575 .11072 L
.575 .11322 L
.575 .11557 L
.575 .11813 L
.575 .12095 L
.575 .12389 L
.575 .12664 L
.575 .13156 L
.575 .13431 L
.575 .13683 L
.575 .13977 L
.575 .14249 L
.575 .14547 L
.575 .14865 L
.575 .1514 L
.575 .15398 L
.575 .15681 L
.575 .15987 L
.57501 .1624 L
.57501 .1651 L
.57501 .16999 L
.57501 .17298 L
.57502 .17582 L
.57503 .18114 L
.57503 .18389 L
.57504 .18681 L
.57506 .1921 L
.57507 .19506 L
.57508 .19786 L
.57511 .20119 L
.57513 .20432 L
.57519 .21006 L
Mistroke
.57523 .21316 L
.57529 .21653 L
.57542 .22298 L
.5756 .22911 L
.57585 .23545 L
.57625 .24279 L
.57679 .25029 L
.57751 .25777 L
.57862 .2667 L
.58036 .2772 L
.58265 .28797 L
.58539 .29839 L
.59479 .32518 L
.606 .34973 L
.64063 .41632 L
.66129 .46091 L
.67813 .49924 L
.69402 .53565 L
.71091 .5744 L
.72717 .61168 L
.74446 .65133 L
.76112 .68951 L
.77713 .72624 L
.79418 .76533 L
.81059 .80296 L
.82803 .84295 L
.84483 .88148 L
.861 .91855 L
.8782 .95799 L
.89476 .99596 L
.91068 1.03248 L
.92763 1.07135 L
.94395 1.10877 L
.94408 1.10906 L
Mfstroke
1 0 0 r
.425 .075 m
.44167 .075 L
.45833 .075 L
.475 .075 L
.49167 .075 L
.50833 .075 L
.525 .075 L
.54167 .075 L
.55833 .075 L
.575 .075 L
s
.42286 .25421 m
.43973 .25575 L
.45678 .25705 L
.47399 .25799 L
.49131 .25849 L
.50869 .25849 L
.52601 .25799 L
.54322 .25705 L
.56027 .25575 L
.57714 .25421 L
s
.32244 .49794 m
.35763 .51134 L
.39622 .52201 L
.43697 .52932 L
.47887 .53302 L
.52113 .53302 L
.56303 .52932 L
.60378 .52201 L
.64237 .51134 L
.67756 .49794 L
s
.25579 .65074 m
.3057 .66973 L
.3593 .68455 L
.41494 .69454 L
.47155 .69954 L
.52845 .69954 L
.58506 .69454 L
.6407 .68455 L
.6943 .66973 L
.74421 .65074 L
s
.18917 .80351 m
.25379 .82811 L
.32238 .84707 L
.39292 .85974 L
.46424 .86604 L
.53576 .86604 L
.60708 .85974 L
.67762 .84707 L
.74621 .82811 L
.81083 .80351 L
s
.12255 .95628 m
.20188 .98648 L
.28546 1.0096 L
.37089 1.02495 L
.45692 1.03255 L
.54308 1.03255 L
.62911 1.02495 L
.71454 1.0096 L
.79812 .98648 L
.87745 .95628 L
s
.05592 1.10906 m
.14996 1.14486 L
.24854 1.17213 L
.34886 1.19015 L
.44961 1.19905 L
.55039 1.19905 L
.65114 1.19015 L
.75146 1.17213 L
.85004 1.14486 L
.94408 1.10906 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 383.938},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001gb000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`002?ooool01OnHV9So410@o`000?lb<S;oc<c<03;ooooo1Ol0000coooo
o`Co000000?o410@ooooooooool0Hoooool4o`000003oa0@4?oooooooooo02oooooo1Ol0000boooo
o`05oiRHV?l@413o0000oc8b<_o<c<`05Oooool000Sooooo00Go410@okZj^_ooooooMgMgoc8b<P0b
ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0=Oooool00ol0003oooooooooo`1Wooooo`03o`000?oo
oooooooo037ooooo00GoV9RHob4Q8Oo^k^koooooodA4A00booooo`05oa0@4?nj^[[oooooogMgMolb
<S805Oooool000Ko00001_ooool00ol0003oooooooooo`0Xooooo`Ko00000oooool00onHV9So8B4Q
onk^kP0[ooooo`Ko00001Oooool00ol0003oooooooooo`1Wooooo`03o`000?oooooooooo03;ooooo
00?oV9RHob4Q8Oo^k^h0=oooool00ol0003oooooooooo`0Cooooo`002oooool00onYZJWo410@oooo
o`0cooooo`03oiRHV?lQ8B7ok^k^03Gooooo00?o0000ooooooooool0Ioooool00ol0003ooooooooo
o`0cooooo`03oiRHV?lQ8B7ok^k^03Gooooo00?oZJVYoa0@4?ooool05?ooool000[ooooo00?o410@
o`000?nj^[X0=Oooool00omgMgOoIVIVooooo`0dooooo`03o`000?oooooooooo06Oooooo00?o0000
ooooooooool0=?ooool00omgMgOoIVIVooooo`0cooooo`03oa0@4?l0003o^[Zj01Gooooo000;oooo
o`03okZj^_lQ8B7ooooo03Gooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`1Woooo
o`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0<oooool00onj^[[o8B4Qooooo`0Doooo
o`002?ooool01Ol@413oV9RHoooooonj^[[o000003;ooooo00Go0000okZj^_ooooooV9RHoa0@400e
ooooo`03o`000?oooooooooo06Oooooo00?o0000ooooooooool0<Oooool01Ol0003o^[ZjoooooonH
V9So410@03;ooooo00Go410@oiRHV?oooooo^[Zjo`00000Eooooo`002?ooool01OnYZJWo410@o`00
0?l@413oZJVY03;ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c00cooooo`03oeEEEOmVIVKo000006Oo
oooo00?oEEEEofIVI_l00000<oooool01OnHV9So410@o`000?lQ8B7oc<c<03;ooooo00GoZJVYoa0@
4?l0003o410@ojVYZ@0Eooooo`00oooooomYooooo`00oooooomYooooo`00oooooomNooooo`;o0000
0_ooool2o`0000Gooooo003ooooooekooooo00Kok^k^ob4Q8On7QhOo^[Zjo`000?oMgMd5ooooo`00
oooooomOooooo`04omgMgOl0003o410@olc<c0Kooooo0007oooooooo0000C?l0000<ooooo`04onk^
k_lQ8B7o410@onk^kPKooooo0007ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00[ooooo00Co8B4QogMgMomgMgOo
<S8b1_ooool000Oooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo03Cooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo03Cooooo00?o0000ooooooooool02Oooool2o`0000;ooooo0_l00005ooooo`00[?oo
ool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0
003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooo
ooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2i
ooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooo
oooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wo
oooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/
ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03
o`000?oooooooooo0;Wooooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Ooo
ool00:cooooo00?o0000ooooooooool0^Oooool009Cooooo<_oo002Rooooo`00U?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`2Pooooo`00U?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`2Pooooo`00U?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`2Pooooo`00U?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`2Pooooo`00U?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooo000000;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2Poooo
o`00U?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`2Pooooo`00U?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooo000000;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2Pooooo`00U?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000?o00001Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`2Pooooo`00U?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`2Pooooo`00U?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooo000000;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2Poooo
o`00U?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`2Pooooo`00U?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooo000000;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2Pooooo`00U?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`2Pooooo`00U?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
000000;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2Pooooo`00U?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`2Pooooo`00U?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2Pooooo`00U?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`2Pooooo`00U?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000;ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`2Pooooo`00U?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooo000000?o00001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2Pooooo`00U?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`2Pooooo`00U?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2Pooooo`00U?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`2Pooooo`00U?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000;ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`2Pooooo`00U?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2P
ooooo`00U?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000;ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`2Pooooo`00U?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooo000000;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`2Pooooo`00
U?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo000000;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`2Pooooo`00U?ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01?l000001ol@413ooooooooooooooooo0000ooooool0
00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0:3ooooo002Dooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo0:3ooooo002Dooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000000ol0
0005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo0:3ooooo002Dooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooool000000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0:3ooooo002Doooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo0:3ooooo002Dooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool0
00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0:3ooooo002Dooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo0:3ooooo002Dooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooo
ool01_l0003ooooooooooomEEEGoIVIVo`0000Gooooo00?o0000ooooool000000_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo0:3ooooo002Dooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooool000000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0:3ooooo
002Dooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000000_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo0:3ooooo002Dooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooool000000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0:3ooooo002Doooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo0:3ooooo002Dooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool0
00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0:3ooooo002Dooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooool000000ol00005ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0:3ooooo
002Dooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000000_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo0:3ooooo002Dooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooool000000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0:3ooooo002Doooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo0:3ooooo002Dooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool0
00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0:3ooooo002Dooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo0:3ooooo002Dooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000000_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0:3ooooo002Cooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo0:3ooooo002Cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000000_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo0:3ooooo002Cooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooool000000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0:3o
oooo002Cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000000_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo0:3ooooo002Cooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooool000000ol00005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo0:3ooooo002Cooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo0:3ooooo002Cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000000_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo0:3ooooo002Cooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooool000000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo09oo
oooo002Cooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000000_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo09oooooo002Cooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooool000000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo09oooooo002C
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo09oooooo002Cooooo`Woo`000_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Ooo002Qooooo`00Toooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooooooob;oo`000_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo09oooooo002Cooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo09oooooo002Booooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo09oooooo002Booooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?l00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo09oooooo002Booooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo09oo
oooo002Booooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo09oooooo002Booooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo09ko
oooo002Booooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo09kooooo002Booooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo09ko
oooo002Aooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo09gooooo002Aooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo09go
oooo002Aooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo09gooooo002Aooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo09go
oooo002@ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo09cooooo002@ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00ol000000ooooooo0000ooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo09cooooo
002@ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00000oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo09cooooo002?ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00Co
0000oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo09_ooooo
002?ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00000oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo09_ooooo002?ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00Co
0000oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo09_ooooo
002>ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00000oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo09[ooooo002>ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00Co
0000oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo09[ooooo
002>ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00Co0000oooooooooooo00000oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo09[ooooo002=ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00Co
0000oooooooooooo00000oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo09Wooooo
002=ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`03ooooo`Go00000oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0VOooool008cooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00Go0000ob4Q8Oo^k^koooooodA4A003ooooo`04o`00
0?ooooooooooo`0000?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`2Hooooo`00
S?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1?ooool01?l0003oV9RHob4Q8Oo^k^h4ooooo`03o`000?oooooooooo00?o000000?oooooo`000?oo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`2Hooooo`00Roooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01?ooool01Ol0003ooooooiRHV?lQ8B7ok^k^00?o
oooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
09Sooooo002;ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`04ooooo`05o`000?ooooooooooogMgMomVIVH00oooool01?l0003oooooooooool00003
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0Uoooool008[ooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00Go0000oooo
ooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`2Gooooo`00R_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool01Ol0003o^[ZjoooooonHV9So410@00?ooooo00Co
0000oooooooooooo00000oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo09Oooooo
0029ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`05o`000?l@413o0000ob4Q8Oo<c<`00oooool01?l0003oooooooooool00003ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0U_ooool008Wooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0U_ooool008Sooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01_ooool01?l0003oooooooooool00003ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool0UOooool008Sooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`2Eooooo`00Qoooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool0
00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo09Cooooo0027ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool0U?ooool008Kooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01?l0003ooooo
ooooooooool3o`0000;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2Cooooo`00
Q_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo09;ooooo0025ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo
00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool0T_ooool008Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000Co
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2Aooooo`00Q?ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`06ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo097ooooo0024ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00Go0000oooooooooooo
ooooo`000004ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0T?ooool008?ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`2@ooooo`00Poooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`05o`00
0?ooooooooooooooool000001?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo08oo
oooo0022ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Kooooo00Go0000ooooooooooooooooo`000004ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool0Soooool008;ooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`2>ooooo`00POooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool0
00001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo08kooooo0021ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Oooooo00Co0000oooooooooooooooo0ol00002ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool0SOooool0083ooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool01Ol0003ooooo
oooooooooooo000000Cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`2<ooooo`00
P?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0
1oooool00ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`07ooooo`03o`000?oooooooooo08cooooo001oooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0Roooool007oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`2;ooooo`00O_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo08[ooooo001noooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool0R_ooool007gooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`29ooooo`00OOooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo08Wooooo001looooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0R?oo
ool007cooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`28ooooo`00Noooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo0ol00003ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool0Qoooool007_ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003o
ooooooooo`27ooooo`00N_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo08Kooooo
001jooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02?ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0Q_ooool007[ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`26ooooo`00NOooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo08Gooooo001iooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool0QOooool007Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`24ooooo`00N?oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo08Cooooo001gooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool0Poooool007Oooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`23ooooo`00M_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00;o
oooo0ol00003ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0P_ooool007Kooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`22ooooo`00M_ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo08;ooooo001eooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool0POooool007Gooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`21oooo
o`00M?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo083ooooo001dooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool0P?ooool007Cooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`20ooooo`00Loooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo07oooooo001cooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00Gooooo00KoV9RHoa0@4?l0003o<S8bolc<c?l0
0005ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`1oooooo`00L_ooool2ool000_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00Gooooo00Ko410@okZj^_ooooooMgMgoc8b<_l00005ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool02_ooool2ool0083ooooo001booooo`04o`000?oo
ooooo`00ool000Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00Wooooo0_l00005ooooo`?o00001?ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`06ooooo`?oo`00
00?oooooo`000?ooool0Ooooool007;ooooo00Co0000oooooooooooooooo0ooo0005ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`08ooooo`03ojVY
ZOl@413o000000Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`04ooooo`;oo`00
1?ooool00ol0003oooooooooo`1nooooo`00LOooool00ol0003oooooooooo`05ooooo`;oo`000ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01ooo
ool01?l@413o0000okZj^_l00005ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
0_ooool2ool000Oooooo00?o0000ooooooooool0OOooool0077ooooo00?o0000ooooooooool01ooo
ool2ool00003ooooool0003ooooo00_ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`08ooooo`03okZj^_lQ8B7o000000Gooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool01?l0003oo`00ool0
0?oo0009ooooo`03o`000?oooooooooo07gooooo001`ooooo`03o`000?oooooooooo00[ooooo0ooo
000;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01_ooool01?l@413oV9RHoooo
oonj^[X2o`0000Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool02?ooool3ool000cooooo00?o0000ooooooooool0
OOooool0073ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`05ool000Kooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`06ooooo`05ojVYZOl@413o0000oa0@4?l00000
1_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`04ooooo`Coo`000_ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo07cooooo001_ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01Ooo
ool4ool00003ooooool0003ooooo00cooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0<ooooo`03o`000?ooooooo`0000?oo`001oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo07cooooo001_ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool4
ool000_ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`09ooooo`Coo`002oooool0
0ol0003oooooooooo`0;ooooo`03o`000?oooooooooo07_ooooo001^ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`05ool000Kooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`04ooooo`Goo`000_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0Noooool006kooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Gooooo1Ooo00000ooooooo
0000ooooo`0;ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0;ooooo`03o`000?ooooooo`0000Coo`001oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0N_ooool006gooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo2Ooo0005ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`Woo`00
3?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
N_ooool006gooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool01OoooolJool000Oooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0N_oo
ool006cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1iooooo`00K?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0;ooooo`03o`000?oooooooooo07Wooooo001[ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool0N?ooool006_ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`1hooooo`00Joooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo07Oooooo001Z
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0Moooool006[ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`1fooooo`00JOooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo07Kooooo001Yooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
M_ooool006Wooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1eooooo`00J?ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Cooooo0ol00005ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool0MOooool006Sooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`1dooooo`00J?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo07Co
oooo001Wooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0Loooool006Oooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`1cooooo`00I_ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo07;ooooo001Vooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool0L_ooool006Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1booooo`00
IOooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo077ooooo001Tooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool0LOooool006Cooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`1`ooooo`00Hoooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo
00Gooooo0ol00006ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0L?ooool006?o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1_ooooo`00H_ooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo06oooooo001Rooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool0Koooool0067ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`1^
ooooo`00HOooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool03_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo06kooooo001Pooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool0KOooool0063ooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`1]ooooo`00H?ooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0?ooooo`03o`000?oo
oooooooo06cooooo001Oooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0K?ooool0
05oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`1[ooooo`00G_ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00Gooooo0ol00006ooooo`03o`000?oooooooooo00ko
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0Joooool005kooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003ooooo
ooooo`1[ooooo`00G_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo06[ooooo001M
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0J_ooool005gooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`1Yooooo`00GOooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo06Wooooo001Looooo`;oo`004?ooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0?ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool03_ooool2ool006[ooooo001Looooo`03o`000?oo
ooooo`0000;oo`003Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00oooooo00?o
0000ooooooooool02oooool3ool00003ooooool0003ooooo06Wooooo001Kooooo`03o`000?oooooo
oooo00?ooooo0ooo000:ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03oooool0
0ol0003oooooooooo`08ooooo`?oo`001Oooool00ol0003oooooooooo`1Wooooo`00Foooool00ol0
003oooooooooo`06ooooo`;oo`001oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool03_ooool2o`000003oa0@4?oooooooooo00Cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`05ooooo`;oo`002?ooool00ol0003oooooooooo`1Woooo
o`00F_ooool00ol0003oooooooooo`09ooooo`?oo`001?ooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0?ooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool00_ooool3ool000_ooooo00?o0000oooooooo
ool0I_ooool005[ooooo00?o0000ooooooooool03?ooool3ool00003ooooool0003ooooo013ooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0=ooooo`Go00001_ooool3o`0000Kooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00oooooo
00?o0000oooooooo00000_oo000>ooooo`03o`000?oooooooooo06Kooooo001Iooooo`03o`000?oo
oooooooo013ooooo0ooo000@ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03Ooo
ool01?m4A4CogMgMooooool00007ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00kooooo0ooo000Booooo`03o`00
0?oooooooooo06Gooooo001Iooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00ooo
000=ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool03Oooool01?oMgMgoEEEEoooo
ool00007ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0@ooooo`03o`000?oooooooooo00_ooooo0ooo0002ooooo`03o`000?oooooooooo013ooooo
00?o0000ooooooooool0IOooool005Wooooo00?o0000ooooooooool04?ooool00ol0003ooooooooo
o`03ooooo`Coo`002Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo00kooooo00?o
MgMgolc<c?l000001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`07ooooo`Coo`001Oooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo06Gooooo001Hooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool02?ooool4ool000Gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0>
ooooo`03onk^k_l0003o000000Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00oooool4ool000[ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`1Tooooo`00F?ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo00cooooo0ooo00000ooooooo0000ooooo`0Aooooo`03o`000?oooooooooo
00oooooo0_l00007ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0@ooooo`03o`000?ooooooo`0000;oo`003_ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo06Cooooo001Gooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool03oooool5ool000kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0=ooooo`Go
o`004Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo06?ooooo001Gooooo`03o`00
0?oooooooooo013ooooo00?o0000ooooooooool04Oooool01?l0003oooooooooooooool6ool000So
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oo
oooo00?o0000ooooooooool03oooool00ol0003oooooooooo`06ooooo`Ooo`000oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0Hoooool005Kooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Oooooo
1_oo0002ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01_oo000:ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Rooooo`00E_oo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03_oo
ool8ool000gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo00_ooooo1ooo000Aooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`1Rooooo`00EOooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`03ooooo`Woo`001?ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool9
ool000Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool0HOooool005Gooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool03?oooolLool0
00gooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool0HOooool005Gooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003o
ooooooooo`1Qooooo`00E?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo063ooooo
001Dooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0H?ooool005?ooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`1Oooooo`00Doooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Aoooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo05oooooo001Booooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool0G_ooool005;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Aooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1Nooooo`00D_oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo05kooooo001Aooooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool0GOooool0057ooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04?ooool00ol0
003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`1Mooooo`00D?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo00Oo
oooo0ol00007ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0Aooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0G?ooool0053ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`1Looooo`00Coooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0@ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo05_ooooo001?ooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool0Foooool004kooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`07oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Boooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1Joooo
o`00C_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo05[ooooo001>ooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool0F_ooool004gooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`1Iooooo`00COooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo00Oooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo01;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo05Wooooo001<ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0F?ooool004co
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`1Hooooo`00Boooool00ol0003ooooo
ooooo`0Dooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo00Oooooo0ol00008ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool0Eoooool004_ooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04_ooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`1Gooooo`00B_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool04oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo00Oooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo05Kooooo001:oooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0E_ooool004[ooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`1Fooooo`00BOooool00ol0003oooooooooo`0Dooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo05Gooooo0019ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool0EOoo
ool004Sooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Dooooo`00B?ooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool02?ooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo05Cooooo0017ooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool0Doooool004Oooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`1Cooooo`00Aoooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo00Oooooo0ol0
0008ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0Doooool004Kooooo0_oo000F
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0D
ooooo`;oo`00E?ooool004Kooooo00?o0000oooooooo00000_oo000Booooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo
01Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Aooooo`?oo`0000?oooooo`00
0?ooool0Doooool004Gooooo00?o0000ooooooooool00oooool3ool000oooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01?ooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00gooooo0ooo0005ooooo`03
o`000?oooooooooo057ooooo0015ooooo`03o`000?oooooooooo00Kooooo0_oo000=ooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo01?ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0;ooooo`;oo`00
2?ooool00ol0003oooooooooo`1Aooooo`00A?ooool00ol0003oooooooooo`09ooooo`?oo`002Ooo
ool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool02?oo
ool3ool000_ooooo00?o0000ooooooooool0D?ooool004Cooooo00?o0000ooooooooool03?ooool2
ool000Oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooo
oooo01?ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo00Gooooo0_oo000>ooooo`03o`000?oooooooooo053ooooo0013ooooo`03o`000?oooooooooo
00oooooo0ooo0004ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0Cooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool05Oooool00ol0
003oooooooooo`02ooooo`?oo`004Oooool00ol0003oooooooooo`1?ooooo`00@oooool00ol0003o
ooooooooo`0Booooo`?oo`0000?o0000ooooooooool05_ooool00ol0003oooooooooo`0Dooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Eooooo`03
o`000?ooooooo`0000;oo`005?ooool00ol0003oooooooooo`1?ooooo`00@oooool00ol0003ooooo
ooooo`0Eooooo`?oo`005Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01?ooooo
00Ko0000odA4A?l0003o0000oc8b<_oMgMd5ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool04oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01?ooooo0ooo000Goooo
o`03o`000?oooooooooo04oooooo0012ooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool00ooo000Booooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool05?ooool01_l0003o
ooooooooooooooooMgMgoc8b<PGooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool04?ooool3ool000;ooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`1>ooooo`00@_ooool00ol0003oooooooooo`0Foooo
o`03o`000?oooooooooo00?ooooo0ooo000?ooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo0ol00009oooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0=oooo
o`?oo`001Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo04kooooo0011ooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool01oooool4ool000_ooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`0Dooooo`06o`000?oooooooooooooooomgMgOo<S8b1Oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool05?ooool0
0ol0003oooooooooo`09ooooo`Coo`002Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo04gooooo0011ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02oooool3ool0
00Sooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`0Dooooo`;o000000Co8B4Qo`00
0?lb<S;oc<c<1Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Cooooo00?o0000
ooooooooool05?ooool00ol0003oooooooooo`06ooooo`?oo`003Oooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo04gooooo0010ooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool03_ooool3ool000Cooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Doooo
o`;o00002Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`02ooooo`?oo`004?ooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo04cooooo0010ooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool04_ooool3ool00003ooooool0003ooooo01Kooooo00?o0000ooooooooool05?ooool2o`0000Wo
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo01Go
oooo00?o0000oooooooo00000_oo000Dooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool0C?ooool003oooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Eooooo`Goo`00
5?ooool00ol0003oooooooooo`0Dooooo`Go00001_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo01Cooooo00?o0000ooooooooool04_ooool5ool001Oooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`1;ooooo`00?oooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo01Kooooo00Co0000oooooooooooooooo1_oo000=ooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool02oooool6ool000?ooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo04_ooooo000oooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`08ooooo`Goo`002?ooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo00Kooooo1Ooo000:ooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`1;ooooo`00?_ooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool03Oooool6ool000;ooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool05Oooool00ol0003oooooooooo`06ool000oooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04[ooooo000nooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Cooooo`Woo`004Oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03oooool9ool0
01Gooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
04[ooooo000mooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo00Cooooo3?oo0005ooooo`03o`000?oooooooooo00So
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`03ooooo`coo`001_ooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`19ooooo`00?Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`0@ooooob;oo`004_ooool00ol0003ooooo
ooooo`0Eooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`19ooooo`00?Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Sooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo04Wooooo000l
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0B?ooool003cooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Wooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`18ooooo`00??ooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo01Gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo04Sooooo000kooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
Aoooool003_ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`08ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`17ooooo`00>_ooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0Eooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04Kooooo000jooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool0A_ooool003Wooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`0Eooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`15ooooo`00>Oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo04Gooooo
000hooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06?ooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool02Oooool3o`0000[ooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`14ooooo`00>?ooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0I
ooooo`03o`000?oooooooooo04Cooooo000gooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Kooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool0@oooool003Oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Hooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`13ooooo`00
=_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo04;ooooo000fooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool0@_ooool003Gooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`11ooooo`00=Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
00Wooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
047ooooo000dooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0@?ooool003Cooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`10ooooo`00=?ooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo043ooooo000cooooo`03o`000?oooooooooo01[ooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool02_ooool3o`0000[ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0o
ooooo`00<oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool02_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool06?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo03oooooo000booooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool0?_ooool003;ooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
5oooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0nooooo`00<_ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo03kooooo000aooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0?Oooool0
037ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
01Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0mooooo`00<Oooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06?ooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`0Jooooo`03o`000?oooooooooo03gooooo000`ooooo`;oo`006oooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`0Hooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06Oooool2ool003kooooo
000`ooooo`03o`000?ooooooo`0000;oo`006?ooool00ol0003oooooooooo`0Jooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool05_ooool3ool00003ooooool0003ooooo03gooooo000_
ooooo`03o`000?oooooooooo00?ooooo0ooo000Eooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`0Cooooo`?oo`001Oooool00ol0003oooooooooo`0k
ooooo`00;oooool00ol0003oooooooooo`06ooooo`;oo`004_ooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0:oooo
o`?o00002_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Wooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0@ooooo`;oo`002?ooool00ol0003oooooooooo`0koooo
o`00;_ooool00ol0003oooooooooo`09ooooo`?oo`003oooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo01Sooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool03Oooool3ool000_ooooo00?o0000oooooooo
ool0>_ooool002kooooo00?o0000ooooooooool03?ooool2ool000gooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
6Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00_ooooo0_oo000>ooooo`03o`00
0?oooooooooo03[ooooo000]ooooo`03o`000?oooooooooo00oooooo0ooo0009ooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`07ooooo`?oo`004Ooo
ool00ol0003oooooooooo`0iooooo`00;Oooool00ol0003oooooooooo`0Booooo`?oo`001_ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06?ooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool01?ooool3
ool001Cooooo00?o0000ooooooooool0>Oooool002gooooo00?o0000ooooooooool05Oooool2ool0
00Cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
00;ooooo0_oo000Gooooo`03o`000?oooooooooo03Wooooo000/ooooo`03o`000?oooooooooo01So
oooo0ooo00000ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01_ooooo00Co0000ool00?oo
003oo`006_ooool00ol0003oooooooooo`0hooooo`00;?ooool00ol0003oooooooooo`0Kooooo`?o
o`006oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo01Sooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`0Iooooo`?oo`007Oooool00ol0003oooooooooo`0hooooo`00
:oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00Coo`005_ooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`0Dooooo`Coo`000_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo03Oooooo
000[ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool01?ooool4ool001;ooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`07o`000?ooooook^k^oc8b<_l0003o
410@olc<c006ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo013ooooo1?oo0006ooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool0=oooool002[ooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`09ooooo`Coo`003_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo
00Oo0000oooooomEEEGoMgMgoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool03?ooool4ool0
00_ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0fooooo`00:_ooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo00gooooo1?oo000:ooooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool06Oooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00Co
oooo0ol0000;ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`08ooooo`Coo`003oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo03Ko
oooo000Yooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool04Oooool4ool000Kooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Iooooo`07o`000?oooooo0000oiRHV?oo
ooooV9RHob4Q8@06ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0Iooooo`03o`000?oooooooooo00Cooooo1?oo000Cooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool0=Oooool002Wooooo00?o0000ooooooooool07?ooool00ol0003o
ooooooooo`0Fooooo`Coo`0000?oooooo`000?ooool06oooool00ol0003oooooooooo`0Iooooo`07
o`000?oooooo0000oeEEEOl0003o410@olc<c006ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool06Oooool00ol0003oooooooooo`0Jooooo`03o`000?ooooooo`0000?oo`006?ooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo03Gooooo000Yooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool06_ooool5ool001Wooooo00?o0000ooooooooool06Oooool01?l0
003ooooooeEEEOn7QhL9ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`0Gooooo`Goo`007?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo03Gooooo000Xooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool06oooool01?l0
003oooooooooooooool5ool001Cooooo00?o0000ooooooooool06Oooool01Ol0003oooooomgMgOl@
413oV9RH00Sooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo01;ooooo1Ooo0003ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`0dooooo`00:?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool01_ooool6ool000gooooo00?o0000ooooooooool06Oooool0
2?l0003oooooooooooooooooc<c<odA4A?l0003o410@1_ooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool02oooool6ool000Sooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo03Cooooo000Wooooo`03o`00
0?oooooooooo01gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0=ooooo`Koo`00
1oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00Gooooo1_oo000?ooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0cooooo`009ooo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool04ooo
ool5ool000;ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`05ool001Gooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo03?ooooo000V
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0H
ooooo`Soo`005_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool05?ooool8ool001[ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo03;ooooo000Vooooo`03o`000?oooooooooo01gooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00?ooooo2Ooo000=oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`Woo`001Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`0booooo`009_ooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0<ooooo`Wo
o`001?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool00_ooool9ool000kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool0<_ooool002Gooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
5OoooolVool001Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo01kooooo00?o0000ooooooooool0<Oooool002Gooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`0aooooo`009?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooo
oooo01[ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo033ooooo000Tooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool02oooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0<?ooool002?o
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0_ooooo`008oooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool06oooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0Nooooo`03o`000?oooooooooo02oooooo000Rooooo`03o`000?oooooooooo01kooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01oooooo00?o
0000ooooooooool0;_ooool002;ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0^
ooooo`008_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo02kooooo000Qooooo`03
o`000?oooooooooo01kooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool0;Oooool0027ooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`0]ooooo`008?ooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Kooooo`03o`000?oo
oooooooo00_ooooo0ol0000<ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool06ooo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0;?oo
ool0023ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo01_ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0/ooooo`007oooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo02_ooooo000Oooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool0:oooool001kooooo00?o0000ooooooooool07oooool00ol0003ooooo
ooooo`0Nooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`0Kooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool08?ooool00ol0003ooooo
ooooo`0Zooooo`007_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01kooooo00?o
0000ooooooooool06oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01_ooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02[ooooo000N
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0:_ooool001gooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool07?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`0Yooooo`007Oooool00ol0003oooooooooo`0Oooooo`03
o`000?oooooooooo01kooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0Looooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0Oooooo`03
o`000?oooooooooo02Wooooo000Looooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0
7oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
:?ooool001cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo01kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Xooooo`006oooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool07?ooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo00cooooo0ol0000=ooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool09oooool001_ooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`0Wooooo`006oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01oo
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00co
oooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo02Oo
oooo000Jooooo`;oo`008Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo01oooooo
00?o0000ooooooooool07oooool2ool002Sooooo000Looooo`?oo`007_ooool00ol0003ooooooooo
o`0Nooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool07?ooool3ool002[ooooo000O
ooooo`;oo`006oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01oooooo00?o0000
ooooooooool06Oooool2ool002gooooo000Qooooo`?oo`006?ooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Moooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool05_ooool3ool002oooooo000Tooooo`?o
o`005Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01cooooo00?o0000oooooooo
ool07Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
ool04oooool3ool003;ooooo000Wooooo`;oo`004_ooool00ol0003oooooooooo`0Pooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`0Mooooo`03o`00
0?oooooooooo023ooooo00?o0000ooooooooool04?ooool2ool003Gooooo000Yooooo`?oo`003ooo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool03Ooo
ool3ool003Oooooo000/ooooo`;oo`003Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool02oooool2ool003[ooooo000^ooooo`?oo`002Oooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool07Oooool00ol0
003oooooooooo`0<ooooo`?o00003Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`07ooooo`?oo`00??ooool0037o
oooo0ooo0006ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool07Oooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool03Oooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool08?ooool00ol0003o
ooooooooo`04ooooo`?oo`00?oooool003Cooooo0_oo0004ooooo`03o`000?oooooooooo01oooooo
00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00gooooo
00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool07oooool00ol0003oooooooooo`02ooooo`;oo`00@_ooool003Kooooo0ooo
00000ol0003oooooooooo`0Pooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo023ooooo00Co0000ool00?oo003oo`00
A?ooool003Wooooo0ooo000Pooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool07Ooo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01kooooo0ooo0017ooooo`00??ooool3
ool001gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool06_ooool4ool004[ooooo000oooooo`Coo`006?ooool00ol0
003oooooooooo`0Nooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`0Fooooo`?oo`00C_ooool004?ooooo0ooo000Eooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01;o
oooo1?oo001Aooooo`00A_ooool4ool0017ooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool03_ooool4ool005Gooooo
001:ooooo`Coo`003Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool01?ooool00ol0003ok^k^ooooo`06ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00_ooooo0ooo
001Iooooo`00C_ooool3ool000[ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo00Cooooo00?oEEEEojVYZOooool01_ooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`07
ooooo`Coo`00G?ooool0057ooooo1?oo0005ooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`04ooooo`03ojVYZOmEEEGooooo00Kooooo0ol0000=oooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`02oooo
o`Coo`00H?ooool005Gooooo0ooo0002ooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool07_ooool00ol0003oooooooooo`05ooooo`03ob4Q8Ooooooooooo00Gooooo00?o0000oooooooo
ool03Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01oooooo00?o0000oooooooo
00000_oo001Tooooo`00F?ooool5ool001kooooo00?o0000ooooooooool07_ooool00ol0003ooooo
ooooo`05ooooo`03oeEEEOo<c<cooooo00Gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0Nooooo`03o`000?oooooooooo01cooooo1Ooo001Wooooo`00GOooool5ool001Wooooo00?o
0000ooooooooool07_ooool00ol0003oooooooooo`05ooooo`03ojVYZOmgMgOooooo00Gooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo01Oooooo1Ooo
001/ooooo`00H_ooool6ool001?ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`02
ooooo`05oa0@4?oooooooooooooooolb<S801_ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool04Oooool6ool0077ooooo001Xooooo`Goo`003_ooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00;ooooo1Ol00006ooooo`03o`000?oooooo
oooo00kooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`0;ooooo`Goo`00Moooool0
06gooooo1_oo0008ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`0>ooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool01Oooool6ool0
07cooooo001cooooo`Goo`000oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00go
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00Go
o`00P_ooool007Sooooo2Ooo000Kooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
3_ooool00ol0003oooooooooo`0Iooooo`Soo`00Qoooool0087ooooo2ooo000@ooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0>ooooo`_oo`00Sooo
ool008cooooo2ooo0005ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool03_ooool0
0ol0003oooooooooo`03ooooo`_oo`00V_ooool009Oooooo;?oo002Uooooo`00[?ooool00ol0003o
ooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003ooooooooo
o`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2ioooo
o`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?oo
ool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0
003oooooooooo`2iooooo`00[?ooool3o`000;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo
002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/oooo
o`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`00
0?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooo
oooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wooooo002/ooooo`03o`000?oooooooooo0;Wo
oooo002/ooooo`?o0000^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000
ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000oooooooo
ool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Ooo
ool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:co
oooo00?o0000ooooooooool0^Oooool00:cooooo00?o0000ooooooooool0^Oooool00:cooooo0ol0
002iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2ioooo
o`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?oo
ool00ol0003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00[?ooool00ol0
003oooooooooo`2iooooo`00[?ooool00ol0003oooooooooo`2iooooo`00XOooool01Oo<c<co8B4Q
o`000?lQ8B7oc<c<00Kooooo00?o0000ooooooooool0^Oooool00:7ooooo00Go8B4QoiRHV?oooooo
V9RHob4Q8@06ooooo`03o`000?oooooooooo0;Wooooo002Qooooo`05o`000?ooooooooooooooool0
00001_ooool3o`000;Wooooo002Qooooo`05oc8b<_nHV9SooooooiRHV?lb<S80`_ooool00:7ooooo
00Goc<c<o`000?l0003o0000olc<c032ooooo`00XOooool01Ol@413o^[Zjoooooonj^[[o410@0<;o
oooo002Qooooo`05o`000?nj^[[ooooookZj^_l00000`_ooool00:7ooooo00GoZJVYoa0@4?l0003o
410@ojVYZ@32ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00ZOooool3o`000003oa0@4?oooooooooo0;Wooooo002[ooooo`03oa0@4?nj^[[ooooo0;[ooooo
002[ooooo`03oiRHV?lb<S;ooooo0;[ooooo002[ooooo`03omgMgOl0003o^[Zj0;[ooooo002[oooo
o`03oeEEEOmgMgOoA4A40;[ooooo002Zooooo`05omgMgOl@413oooooob4Q8OoMgMd0^Oooool00:[o
oooo00GoIVIVohN7QoooooooV9RHoeEEE@2iooooo`00ZOooool00oo^k^ko0000onk^kP02ooooo`03
o`000?oMgMgooooo0;Oooooo002Yooooo`04oa0@4?l0003o0000ooooo`;o000000?o410@oooooooo
ool0]_ooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {478.875, 0}} -> {-3.14142, -0.279475, \
0.0227148, 0.0227148}}]
}, Open  ]],

Cell[TextData[{
  "Of course, the rays are everywhere perpendicular to the phase fronts. \
Their refraction outward is a simple consequence of Snell's law: rays bend \
toward regions of lower phase speed. \n\tAs the rays diverge, the wave \
amplitude decreases. The reason is easy to comprehend: Eq. ",
  ButtonBox["(5.2.59)",
    ButtonData:>"(5.2.59)",
    ButtonStyle->"Hyperlink"],
  " implies that the average flux ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["\[CapitalGamma]",
            FontWeight->"Bold"], "=", 
          RowBox[{
            SubscriptBox[
              StyleBox["v",
                FontWeight->"Bold",
                FontSlant->"Plain"], "g"], " ", "\[Epsilon]"}]}], 
        TraditionalForm]]],
  " for a wavepacket with energy density ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\)]],
  " is directed only along the wavepacket trajectories, and therefore energy \
never crosses these trajectories. Wave power (flux integrated over an area) \
travels down the tubes created by adjacent rays, so the total wave power \
traveling along any tube is conserved. As the rays spread the tubes increase \
in cross-sectional area, so  the energy flux (and wave amplitude) decreases \
to compensate.  \n\t\tMore precisely, for wave propagation in 2 dimensions, \
assume that the distance between two adjacent rays spreads from ",
  Cell[BoxData[
      \(TraditionalForm\`d\_1\)]],
  " at point ",
  Cell[BoxData[
      \(TraditionalForm\`1\)]],
  " to ",
  Cell[BoxData[
      \(TraditionalForm\`d\_2 > d\_1\)]],
  "at point ",
  Cell[BoxData[
      \(TraditionalForm\`2\)]],
  " further down the ray tube, and that a wave packet travels along the tube \
(see Fig. ",
  ButtonBox["5.11",
    ButtonData:>"Fig. 5.11",
    ButtonStyle->"Hyperlink"],
  ").  Then the energy flux decreases as the packet travels from points 1 to \
2, satisfying"
}], "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\(\[CapitalGamma]\_2\) 
          d\_2 = \[CapitalGamma]\_1\ d\_1\)]],
  ". "
}], "NE3",
  CellTags->"(5.3.16)"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004/0002Eb000`400?l00000o`00003oooooool]
ooooo`00ooooool]ooooo`00ooooool]ooooo`00ooooool]ooooo`00ooooool]ooooo`00ooooool]
ooooo`00ooooool]ooooo`00ooooool]ooooo`00ooooool]ooooo`00ooooool]ooooo`00ooooool]
ooooo`00ooooool]ooooo`00ooooool]ooooo`00ooooool]ooooo`00ooooool]ooooo`00ooooool]
ooooo`001ooooomh0?ooo`80>CWoX`3oool8ooooo`001ooooomh0?ooo`80>CWoX`3oool8ooooo`00
1ooooomh0?ooo`80>CWoX`3oool8ooooo`001ooooomh0?ooo`80>CWoX`3oool8ooooo`001ooooomh
0?ooo`80>CWoX`3oool8ooooo`001ooooomh0?ooo`80>CWoX`3oool8ooooo`001ooooomh0?ooo`03
06][o`0i>Ol0W9co0:80oooo2?ooool000OoooooN03oool00`2LW?l0>CWo03Tio`2R0?ooo`Sooooo
0007ooooogP0oooo00<0W9co03Tio`0i>Ol0XP3oool8ooooo`001ooooomh0?ooo`0309bLo`0i>Ol0
>CWo0:80oooo2?ooool000OoooooN03oool00`2LW?l0>CWo03Tio`2R0?ooo`Sooooo0007ooooogP0
oooo00<0W9co03Tio`0i>Ol0XP3oool8ooooo`001ooooomh0?ooo`0309bLo`0i>Ol0>CWo0:80oooo
2?ooool000OoooooN03oool00`2LW?l0>CWo03Tio`2R0?ooo`Sooooo0007ooooogP0oooo00<0W9co
03Tio`0i>Ol0XP3oool8ooooo`001ooooomh0?ooo`0309bLo`0i>Ol0>CWo0:80oooo2?ooool000Oo
ooooN03oool00`2LW?l0>CWo03Tio`2R0?ooo`Sooooo0007ooooogP0oooo00<0W9co03Tio`0i>Ol0
XP3oool8ooooo`001ooooomh0?ooo`0309bLo`0i>Ol0>CWo0:80oooo2?ooool000OoooooN03oool0
0`2LW?l0>CWo03Tio`2R0?ooo`Sooooo0007ooooogP0oooo00<0W9co03Tio`0i>Ol0XP3oool8oooo
o`001ooooomh0?ooo`040<k>o`0i>Ol0>CWo0<k>oj40oooo2?ooool000OoooooN@3oool203Tio`03
09bLo`3oool0oooo09l0oooo2?ooool000OoooooN@3oool203Tio`0309bLo`3oool0oooo09l0oooo
2?ooool000OoooooN@3oool203Tio`0309bLo`3oool0oooo09l0oooo2?ooool000OoooooN@3oool2
03Tio`0309bLo`3oool0oooo09l0oooo2?ooool000OoooooN@3oool203Tio`0309bLo`3oool0oooo
09l0oooo2?ooool000OoooooN@3oool203Tio`0309bLo`3oool0oooo09l0oooo2?ooool000Oooooo
N@3oool203Tio`0309bLo`3oool0oooo09l0oooo2?ooool000OoooooN@3oool203Tio`0309bLo`3o
ool0oooo09l0oooo2?ooool000OoooooN@3oool203Tio`0309bLo`3oool0oooo09l0oooo2?ooool0
00OoooooN@3oool203Tio`0309bLo`3oool0oooo09l0oooo2?ooool000OoooooN@3oool203Tio`03
09bLo`3oool0oooo09l0oooo2?ooool000OoooooN@3oool203Tio`0309bLo`3oool0oooo09l0oooo
2?ooool000OoooooN@3oool203Tio`0309bLo`3oool0oooo09l0oooo2?ooool000OoooooN@3oool2
03Tio`0309bLo`3oool0oooo09l0oooo2?ooool000OoooooN@3oool203Tio`0309bLo`3oool0oooo
09l0oooo2?ooool000OoooooN@3oool00`2LW?l0>CWo03Tio`2Q0?ooo`Sooooo0007ooooogT0oooo
00<0W9co03Tio`0i>Ol0X@3oool8ooooo`001ooooomi0?ooo`0309bLo`0i>Ol0>CWo0:40oooo2?oo
ool000OoooooN@3oool00`2LW?l0>CWo03Tio`2Q0?ooo`Sooooo0007ooooogT0oooo00<0W9co03Ti
o`0i>Ol0;@3oool;03TiofT0oooo2?ooool000OoooooN@3oool00`2LW?l0>CWo03Tio`0_0?ooo`03
09bLo`0i>Ol0>CWo0080>CWo00<0W9co0<k>o`3oool0JP3oool8ooooo`001ooooomi0?ooo`0309bL
o`0i>Ol0>CWo0340oooo0`0i>Om]0?ooo`Sooooo0007ooooogT0oooo00<0W9co03Tio`0i>Ol0<@3o
ool303Tiofd0oooo2?ooool000OoooooN@3oool00`2LW?l0>CWo03Tio`0a0?ooo`<0>CWoK@3oool8
ooooo`001ooooomi0?ooo`0309bLo`0i>Ol0>CWo0340oooo0`0i>Om]0?ooo`Sooooo0007ooooogT0
oooo00<0W9co03Tio`0i>Ol0<@3oool303Tiofd0oooo2?ooool000OoooooN@3oool00`2LW?l0>CWo
03Tio`0a0?ooo`<0>CWoK@3oool8ooooo`001ooooomi0?ooo`0309bLo`0i>Ol0>CWo0340oooo0`0i
>Om]0?ooo`Sooooo0007ooooogT0oooo00<0W9co03Tio`0i>Ol0<@3oool303Tiofd0oooo2?ooool0
00OoooooN@3oool00`2LW?l0>CWo03Tio`0:0?oooa40W9co5P3oool303Tiofd0oooo2?ooool000Oo
ooooN@3oool00`2LW?l0>CWo03Tio`0:0?oooa40>CWo5P3oool303Tiofd0oooo2?ooool000Oooooo
NP3oool303Tio``0oooo00<0c/ko09bLo`0i>Ol01`0i>Ol00`2LW?l0oooo0?ooo`0G0?ooo`<0>CWo
K@3oool8ooooo`001ooooomj0?ooo`<0>CWo3P3oool00`3>c_l0>CWo03Tio`0403Tioa/0oooo0`0i
>Om]0?ooo`Sooooo0007ooooogX0oooo0`0i>Ol?0?ooo`H0>CWo6`3oool303Tiofd0oooo2?ooool0
00OoooooNP3oool303Tio`l0oooo00<0Jf_o03Tio`0i>Ol00`0i>OlK0?ooo`<0>CWoK@3oool8oooo
o`001ooooomj0?ooo`<0>CWo3`3oool00`2LW?l0>CWo03Tio`0303Tioa/0oooo0`0i>Om]0?ooo`So
oooo0007ooooogX0oooo0`0i>Ol?0?ooo`0309bLo`0i>Ol0>CWo00<0>CWo6`3oool303Tiofd0oooo
2?ooool000OoooooNP3oool303Tioa00oooo1P0i>OlJ0?ooo`<0>CWoK@3oool8ooooo`001ooooomj
0?ooo`<0>CWo403oool603TioaX0oooo0`0i>Om]0?ooo`Sooooo0007ooooogX0oooo0`0i>Ol@0?oo
o`H0>CWo6P3oool303Tiofd0oooo2?ooool000OoooooNP3oool303Tioa40oooo1@0i>Ol00`2LW?l0
oooo0?ooo`0G0?ooo`<0>CWoK@3oool8ooooo`001ooooomj0?ooo`<0>CWo4@3oool503Tio`0309bL
o`3oool0oooo01<0oooo00@0W9co0?ooo`3oool0oooo0`0i>Om]0?ooo`Sooooo0007ooooogX0oooo
0`0i>OlA0?ooo`D0>CWo00<0W9co0?ooo`3oool0503oool603Tiofd0oooo2?ooool000OoooooNP3o
ool303Tioa40oooo00<0Jf_o03Tio`0i>Ol00P0i>Ol00`2LW?l0oooo0?ooo`0E0?ooo`0306][o`0i
>Ol0>CWo0080>CWoK@3oool8ooooo`001ooooomj0?ooo`<0>CWo4@3oool00`2LW?l0>CWo03Tio`03
03TioaT0oooo00<0W9co03Tio`0i>Ol0K@3oool8ooooo`001ooooomj0?ooo`<0>CWo4@3oool00`2L
W?l0>CWo03Tio`0303Tioa/0oooo00<0W9co0?ooo`3oool0J`3oool8ooooo`001ooooomk0?ooo`80
>CWo00<0W9co0?ooo`3oool03P3oool00`3>c_l0>CWo03Tio`0303TiohT0oooo2?ooool000Oooooo
N`3oool203Tio`0309bLo`3oool0oooo00l0oooo1P0i>On80?ooo`Sooooo0007ooooog/0oooo0P0i
>Ol00`2LW?l0oooo0?ooo`0?0?ooo`H0>CWoR03oool8ooooo`001ooooomk0?ooo`80>CWo00<0W9co
0?ooo`3oool03`3oool603TiohP0oooo2?ooool000OoooooN`3oool203Tio`0309bLo`3oool0oooo
0100oooo1@0i>Ol00`3>c_l0oooo0?ooo`250?ooo`Sooooo0007ooooog/0oooo0P0i>Ol00`2LW?l0
oooo0?ooo`0@0?ooo`D0>CWo00<0W9co0?ooo`3oool0Q@3oool8ooooo`001ooooomk0?ooo`80>CWo
00<0W9co0?ooo`3oool0403oool503Tio`0309bLo`3oool0oooo08D0oooo2?ooool000OoooooN`3o
ool203Tio`0309bLo`3oool0oooo0100oooo00<0W9co03Tio`0i>Ol00P0i>Ol00`1[Jol0oooo0?oo
o`250?ooo`Sooooo0007ooooog/0oooo0P0i>Ol00`2LW?l0oooo0?ooo`0@0?ooo`0309bLo`0i>Ol0
>CWo00<0>CWoQ`3oool8ooooo`001ooooomk0?ooo`80>CWo00<0W9co0?ooo`3oool0403oool00`2L
W?l0>CWo03Tio`0303Tioa40oooo00<0W9co0<k>o`3oool0L`3oool8ooooo`001ooooomk0?ooo`80
>CWo00<0W9co0?ooo`3oool04@3oool503Tioa40oooo00<0>CWo09bLo`3oool0L`3oool8ooooo`00
1ooooomk0?ooo`80>CWo00<0W9co0?ooo`3oool04@3oool603Tioa00oooo00<0>CWo09bLo`3oool0
L`3oool8ooooo`001ooooomk0?ooo`80>CWo00<0W9co0?ooo`3oool04@3oool603Tio`l0oooo00<0
W9co03Tio`0i>Ol0M03oool8ooooo`001ooooomk0?ooo`80>CWo00<0W9co0?ooo`3oool04@3oool6
03Tio`0309bLo`3oool0oooo00`0oooo00<0W9co03Tio`0i>Ol0M03oool8ooooo`001ooooomk0?oo
o`80>CWo00<0W9co0?ooo`3oool04@3oool603Tio`0309bLo`3oool0oooo00/0oooo00@0W9co03Ti
o`0i>Ol0>CWoM03oool8ooooo`001ooooomk0?ooo`80>CWo00<0W9co0?ooo`3oool04@3oool703Ti
o``0oooo00<0W9co03Tio`0i>Ol00P0i>Omd0?ooo`Sooooo0007ooooog/0oooo00<0W9co03Tio`0i
>Ol04P3oool00`2LW?l0>CWo03Tio`0503Tio`0306][o`2LW?l0W9co00P0W9co1P0i>Omd0?ooo`So
oooo0007ooooog/0oooo00<0W9co03Tio`0i>Ol03`3ooolL03Tiog@0oooo2?ooool000OoooooN`3o
ool00`2LW?l0>CWo03Tio`0?0?oooa`0W9coM03oool8ooooo`001ooooomk0?ooo`0309bLo`0i>Ol0
>CWo09l0oooo2?ooool000OoooooN`3oool00`2LW?l0>CWo03Tio`2O0?ooo`Sooooo0007ooooog/0
oooo00<0W9co03Tio`0i>Ol0W`3oool8ooooo`001ooooomk0?ooo`0309bLo`0i>Ol0>CWo09l0oooo
2?ooool000OoooooN`3oool00`2LW?l0>CWo03Tio`2O0?ooo`Sooooo0007ooooog/0oooo00<0W9co
03Tio`0i>Ol0W`3oool8ooooo`001ooooomk0?ooo`0309bLo`0i>Ol0>CWo09l0oooo2?ooool000Oo
ooooN`3oool00`2LW?l0>CWo03Tio`2O0?ooo`Sooooo0007ooooog/0oooo00<0W9co03Tio`0i>Ol0
W`3oool8ooooo`001ooooomd0?ooo`030<k>o`2LW?l0Jf_o00`0>CWo102LW?nF0?ooo`Sooooo0007
ooooog<0oooo500i>OnF0?ooo`Sooooo0007ooooog80oooo00<0W9co03Tio`0i>Ol04P0i>OnF0?oo
o`Sooooo0007ooooog<0oooo4`0i>OnG0?ooo`Sooooo0007ooooog<0oooo00<0W9co03Tio`0i>Ol0
400i>OnG0?ooo`Sooooo0007ooooog@0oooo4@0i>Ol00`1[Jol0oooo0?ooo`2E0?ooo`Sooooo0007
ooooog@0oooo00<0W9co03Tio`0i>Ol03P0i>Ol00`2LW?l0oooo0?ooo`2E0?ooo`Sooooo0007oooo
og@0oooo00<0c/ko03Tio`0i>Ol03P0i>Ol00`3>c_l0oooo0?ooo`2E0?ooo`Sooooo0007ooooogD0
oooo400i>OnH0?ooo`Sooooo0007ooooogD0oooo00<0W9co03Tio`0i>Ol03@0i>OnH0?ooo`Sooooo
0007ooooogH0oooo3P0i>Ol00`2LW?l0oooo0?ooo`2F0?ooo`Sooooo0007ooooogH0oooo00<0Jf_o
03Tio`0i>Ol02`0i>Ol00`2LW?l0oooo0?ooo`2F0?ooo`Sooooo0007ooooogH0oooo00<0c/ko03Ti
o`0i>Ol02`0i>Ol00`3>c_l0oooo0?ooo`2F0?ooo`Sooooo0007ooooogL0oooo3@0i>OnI0?ooo`So
oooo0007ooooogL0oooo00<0W9co03Tio`0i>Ol02@0i>Ol00`2LW?l0oooo0?ooo`2G0?ooo`Sooooo
0007ooooogP0oooo2`0i>OnJ0?ooo`Sooooo0007ooooogP0oooo00<0W9co03Tio`0i>Ol01`0i>Ol0
0`1[Jol0oooo0?ooo`2H0?ooo`Sooooo0007ooooogP0oooo00<0c/ko03Tio`0i>Ol01`0i>Ol00`3>
c_l0oooo0?ooo`2H0?ooo`Sooooo0007ooooogT0oooo2@0i>OnK0?ooo`Sooooo0007ooooogT0oooo
00<0W9co03Tio`0i>Ol01P0i>OnK0?ooo`Sooooo0007ooooogT0oooo00<0W9co03Tio`0i>Ol01@0i
>OnL0?ooo`Sooooo0007ooooogX0oooo1`0i>OnL0?ooo`Sooooo0007ooooog/0oooo1@0i>Ol00`2L
W?l0oooo0?ooo`2J0?ooo`Sooooo0007ooooog/0oooo1@0i>Ol00`2LW?l0oooo0?ooo`2J0?ooo`So
oooo0007ooooog/0oooo00<0W9co03Tio`0i>Ol00P0i>Ol00`3>c_l0oooo0?ooo`2J0?ooo`Sooooo
0007ooooog/0oooo00<0W9co03Tio`0i>Ol00P0i>OnM0?ooo`Sooooo0007ooooog`0oooo0`0i>Ol0
0`2LW?l0oooo0?ooo`2K0?ooo`Sooooo0007ooooogd0oooo0P0i>OnN0?ooo`Sooooo0007ooooogd0
oooo00<0>CWo06][o`3oool0W@3oool8ooooo`001ooooomm0?ooo`80W9coWP3oool8ooooo`001ooo
oomm0?ooo`030<k>o`3oool0oooo09d0oooo2?ooool000Ooooooo`3ooolN0?ooo`Sooooo0007oooo
ohT0oooo00<0P820000000000000200000290?ooo`Sooooo0007oooooh/0oooo00<0`<300410@000
00000P0000000`10@400`<300?ooo`2:0?ooo`Sooooo0007ooooohd0oooo0`0000000`20P800oooo
0?ooo`2:0?ooo`Sooooo0007ooooohd0oooo0`0000000`20P800oooo0?ooo`2:0?ooo`Sooooo0007
ooooohd0oooo0`0000000`20P800oooo0?ooo`2:0?ooo`Sooooo0007ooooohd0oooo0`0000000`20
P800oooo0?ooo`2:0?ooo`Sooooo0007ooooohd0oooo0`0000000`20P800oooo0?ooo`2:0?ooo`So
oooo0007ooooohd0oooo0`0000000`20P800oooo0?ooo`2:0?ooo`Sooooo0007ooooohd0oooo0`00
00000`20P800oooo0?ooo`2:0?ooo`Sooooo0007ooooohd0oooo0`0000000`20P800oooo0?ooo`2:
0?ooo`Sooooo0007ooooofd0oooo00<0`<300820P00000000P0000000`10@400P8200?ooo`040?oo
o`060<30`0000000000000000010@400`<303P3oool3000000030820P03oool0oooo08X0oooo2?oo
ool000OoooooK@3oool8000000@0oooo00<0P8200000000000000`00000>0?ooo`<0000000<0P820
0?ooo`3oool0RP3oool8ooooo`001ooooom[0?ooo`030<30`0000000000000<000000`20P8020000
00030<30`03oool0oooo00@0000000@0@4100820P0000000`<30303oool3000000030820P03oool0
oooo08X0oooo2?ooool000OoooooJ`3oool01@10@4000000000000000000@41000D0oooo00D0P820
0410@020P800oooo0820P003000000050820P03oool0oooo0410@020P8002`3oool3000000030820
P03oool0oooo08X0oooo2?ooool000OoooooJ`3oool4000000P0oooo00<000000820P020P8000`00
00001P20P800oooo0?ooo`3oool000000820P0X0oooo0`0000000`20P800oooo0?ooo`2:0?ooo`So
oooo0007ooooof/0oooo100000090?ooo`0300000010@40000000080000000<0P8200?ooo`3oool0
0P3oool00`10@400oooo0?ooo`080?ooo`<0000000<0P8200?ooo`3oool0RP3oool8ooooo`001ooo
oom[0?ooo`@000002@3oool00`20P800000000000003000000l0oooo0`0000000`20P800oooo0?oo
o`2:0?ooo`Sooooo0007ooooof/0oooo1000000:0?ooo`030410@00000000000008000003`3oool3
000000030820P03oool0oooo08X0oooo2?ooool000OoooooJ`3oool4000000X0oooo00<0P8200000
000000000P00000?0?ooo`<0000000<0P8200?ooo`3oool0RP3oool8ooooo`001ooooom[0?ooo`05
0410@0000000000000000020P8002P3oool4000000030820P03oool0oooo00`0oooo0`0000000`20
P800oooo0?ooo`2:0?ooo`Sooooo0007ooooof/0oooo00D0P82000000000000000000820P00;0?oo
o`<0000000<0@4100?ooo`3oool0303oool3000000030820P03oool0oooo08X0oooo2?ooool000Oo
ooooK03oool4000000/0oooo00@0P82000000000000000003P3oool3000000030820P03oool0oooo
08X0oooo2?ooool000OoooooK03oool01@20P8000000000000000000P82000X0oooo00@0P8200000
0000000000002P3oool01030`<00oooo0?ooo`3oool3000000030820P03oool0oooo08X0oooo2?oo
ool000OoooooK@3oool4000000/0oooo1000000:0?ooo`H0000000<0P8200?ooo`3oool0RP3oool8
ooooo`001ooooom]0?ooo`050820P0000000000000000020P8002P3oool4000000/0oooo00<0`<30
0000000000000P0000000`20P800oooo0?ooo`2:0?ooo`Sooooo0007ooooofh0oooo00@0P8200000
0000000000002`3oool3000000030<30`03oool0oooo00X0oooo00@0P8200410@0000000P820S03o
ool8ooooo`001ooooom_0?ooo`<0000000<0P8200?ooo`3oool0203oool3000000030820P03oool0
oooo00d0oooo00<0P8200?ooo`3oool0RP3oool8ooooo`001ooooom_0?ooo`040<30`00000000000
0410@0X0oooo0`0000000`10@400oooo0?ooo`2J0?ooo`Sooooo0007ooooog40oooo0`0000090?oo
o`@00000W03oool8ooooo`001oooooma0?ooo`040<30`000000000000410@0P0oooo1000002L0?oo
o`Sooooo0007ooooog80oooo00@0P82000000000000000001`3oool5000002/0oooo00<0P8200000
003oool0K@3oool8ooooo`001ooooomc0?ooo`040820P000000000000410@0D0oooo0P20P8040000
02P0oooo00<0P8200410@00000000P0000000`20P800oooo0?ooo`1[0?ooo`Sooooo0007ooooocl0
oooo00<0P8200?ooo`3oool0<`3oool01020P800@41000000010@4020820P0030410@0000000`<30
00@0000000<0`<300?ooo`3oool08@3oool00`30`<00P82000000006000000030820P03oool0oooo
06/0oooo2?ooool000Oooooo?P3oool3000003L0oooo100000020?ooo`050820P000000000000000
0020P8008@3oool00`20P800000000000009000006d0oooo2?ooool000Oooooo?@3oool00`30`<00
000000000004000000030820P030`<00oooo03L0oooo00D0P82000000000000000000410@00N0?oo
o`030<30`020P800000000`00000K@3oool8ooooo`001ooooolm0?ooo`030820P0000000000000L0
0000>03oool4000001`0oooo00<0P8200000000000003P00001]0?ooo`Sooooo0007ooooocd0oooo
300000000`20P800oooo0?ooo`0c0?ooo`@000006@3oool00`30`<00P8200000000B000006`0oooo
2?ooool000Oooooo?@3oool?000003<0oooo1@00000G0?oooaH00000K03oool8ooooo`001oooooll
0?ooo`030820P0000000000000h000000P20P80a0?ooo`@000004`3oool00`30`<00P8200000000G
000006`0oooo2?ooool000Oooooo?03ooolF00000080P820;03oool4000000030<30`03oool0oooo
00/0oooo0`20P80L000002/0P82000<0`<300?ooo`3oool0?P3oool8ooooo`001oooooll0?oooaT0
000000<0P8200?ooo`3oool0:03oool01@20P8000000000000000000P82000`0oooo00<0P8200000
00000000B00000000`20P800oooo0?ooo`0n0?ooo`Sooooo0007oooooa40oooo:`20P80K00000003
0820P03oool0oooo02H0oooo00D0P82000000000000000000410@00>0?ooo`030<30`020P800@410
04H0000000<0P8200?ooo`3oool0?P3oool8ooooo`001ooooolA0?ooodT0000000<0P8200?ooo`3o
ool0903oool400000180oooo00<0P8200000000000005`00001/0?ooo`Sooooo0007oooooa40oooo
B@0000020820P2D0oooo1000000D0?ooo`030820P010@400000001D00000K03oool8ooooo`001ooo
oolA0?ooodL00000:03oool00`20P800000000000002000000030820P03oool0oooo01@0oooo00<0
P8200000000000004P00001/0?ooo`Sooooo0007oooooc`0oooo00<0P8200000000000005@000002
0820P2L0oooo00<0`<300820P020P8001@0000000`20P800oooo0?ooo`0F0?ooo`030<30`020P800
000001000000K03oool8ooooo`001ooooolm0?oooa<0000000<0@4100820P030`<00<@3oool00`20
P800`<300?ooo`0K0?ooo`80P8203000001]0?ooo`Sooooo0007ooooocd0oooo4@0000000`20P800
oooo0?ooo`1E0?ooo`X00000K@3oool8ooooo`001ooooolm0?ooo`h0000000<0@4100820P03oool0
FP3oool00`20P800000000000004000000030410@03oool0oooo06/0oooo2?ooool000Oooooo?@3o
ool<000000030820P03oool0oooo05l0oooo100000000`20P800oooo0?ooo`1[0?ooo`Sooooo0007
ooooocd0oooo00<0@4100000000000001@0000000`10@400P8200<30`01U0?ooo`80P820KP3oool8
ooooo`001ooooolm0?ooo`030820P0000000000000@00000f@3oool8ooooo`001oooooln0?ooo`80
00000P20P83K0?ooo`Sooooo0007ooooool0oooo7P3oool8ooooo`001ooooooo0?oooah0oooo2?oo
ool000Ooooooo`3ooolN0?ooo`Sooooo0007ooooool0oooo7P3oool8ooooo`001ooooomT0?ooo`<0
P820]P3oool8ooooo`001ooooomT0?ooo`<00000]P3oool8ooooo`001ooooomT0?ooo`<00000]P3o
ool8ooooo`001ooooomS0?ooo`040820P000000000000820P2h0oooo0P0000000`20P800oooo0?oo
o`230?ooo`Sooooo0007oooooe<0oooo00<0lX200>@0003T00001@3T00080?ooo`040820P0000000
00000820P2h0oooo0P0000000`20P800oooo0?ooo`230?ooo`Sooooo0007oooooe<0oooo00<0lX20
0>@0003T00003@3T0000102b@400LP000780002b@4030?:0P0030?W0`03oool0oooo02P0oooo00<0
@4100000001b00002P3bP80;0>@000030?:0P03oool0oooo06d0oooo2?ooool000OoooooD`3oool0
0`3bP800i0000>@0001G0>@000030?:0P03oool0oooo06d0oooo2?ooool000OoooooF`3oool80?:0
P4<0i0001`3bP8000`3i`<00oooo0?ooo`1]0?ooo`Sooooo0007ooooof<0oooo00<0P82000000000
0000103oool00`3bP800i0000>@0000a0>@000030?:0P03oool0oooo07`0oooo2?ooool000Oooooo
H`3oool00`10@40000000000000J0?ooo`030?W0`03bP800lX2001<0lX2000<0LP0000000020P800
Q03oool8ooooo`001ooooomS0?ooo`<00000<03oool2000000030820P03oool0oooo0880oooo2?oo
ool000OoooooH`3oool300000300oooo0P0000000`20P800oooo0?ooo`220?ooo`Sooooo0007oooo
of<0oooo0P0000000`10@400oooo0?ooo`0^0?ooo`80000000<0@4100?ooo`3oool0PP3oool8oooo
o`001ooooomS0?ooo`80000000<0P8200?ooo`3oool0;`3oool2000008@0oooo2?ooool000Oooooo
H`3oool2000000030820P03oool0oooo02l0oooo0P0000240?ooo`Sooooo0007ooooof80oooo0`00
00000`20P800oooo0?ooo`0_0?ooo`800000Q03oool8ooooo`001ooooomR0?ooo`<0000000<0P820
0?ooo`3oool0;`3oool2000008@0oooo2?ooool000OoooooHP3oool3000000030<30`03oool0oooo
02l0oooo00<0P820000000000000P`3oool8ooooo`001ooooomR0?ooo`<00000<P3oool00`20P800
0000000000230?ooo`Sooooo0007ooooof80oooo0`00000b0?ooo`030820P0000000000008<0oooo
2?ooool000OoooooHP3oool300000380oooo00<0P820000000000000P`3oool8ooooo`001ooooomQ
0?ooo`040820P0000000000000000380oooo00@0`<30000000000000P820PP3oool8ooooo`001ooo
oomQ0?ooo`030820P0000000000003@0oooo0P0000000`20P800oooo0?ooo`200?ooo`Sooooo0007
ooooof40oooo00<0P820000000000000=03oool2000000030820P03oool0oooo0800oooo2?ooool0
00OoooooH@3oool00`20P80000000000000d0?ooo`80000000<0@4100?ooo`3oool0P03oool8oooo
o`001ooooomQ0?ooo`030820P0000000000003@0oooo00<0P820000000000000PP3oool8ooooo`00
1ooooomQ0?ooo`030410@0000000@41003@0oooo00<0P820000000000000PP3oool8ooooo`001ooo
oomQ0?ooo`80000000<0P8200?ooo`3oool0<P3oool00`20P8000000000000220?ooo`Sooooo0007
ooooof40oooo0P0000000`20P800oooo0?ooo`0b0?ooo`030820P000000000000880oooo2?ooool0
00OoooooH@3oool2000000030820P03oool0oooo03<0oooo0`0000210?ooo`Sooooo0007ooooof40
oooo0P0000000`20P800oooo0?ooo`0c0?ooo`<00000P@3oool8ooooo`001ooooomP0?ooo`040820
P000000000000820P3D0oooo0`0000210?ooo`Sooooo0007ooooof00oooo0`00000f0?ooo`<00000
P@3oool8ooooo`001ooooomP0?ooo`<00000=`3oool2000000030820P03oool0oooo07h0oooo2?oo
ool000OoooooH03oool3000003L0oooo0P0000000`20P800oooo0?ooo`1n0?ooo`Sooooo0007oooo
of00oooo0`00000g0?ooo`80000000<0P8200?ooo`3oool0OP3oool8ooooo`001ooooomP0?ooo`<0
0000=`3oool2000000030410@03oool0oooo07h0oooo2?ooool000OoooooG`3oool01020P8000000
00000000000g0?ooo`030820P000000000000800oooo2?ooool000OoooooG`3oool00`20P8000000
0000000h0?ooo`030820P000000000000800oooo2?ooool000OoooooG`3oool00`20P80000000000
000h0?ooo`030820P000000000000800oooo2?ooool000OoooooG`3oool00`20P80000000000000h
0?ooo`030820P000000000000800oooo2?ooool000OoooooG`3oool00`20P80000000000000i0?oo
o`<00000O`3oool8ooooo`001ooooomO0?ooo`030410@0000000000003T0oooo0`00001o0?ooo`So
oooo0007oooooel0oooo0P0000000`20P800oooo0?ooo`0g0?ooo`<00000O`3oool8ooooo`001ooo
oomO0?ooo`80000000<0P8200?ooo`3oool0=`3oool3000007l0oooo2?ooool000OoooooG`3oool2
000000030820P03oool0oooo03P0oooo0P0000000`20P800oooo0?ooo`1l0?ooo`Sooooo0007oooo
oel0oooo0P0000000`20P800oooo0?ooo`0h0?ooo`80000000<0P8200?ooo`3oool0O03oool8oooo
o`001ooooomO0?ooo`80000000<0P8200?ooo`3oool0>03oool2000000030820P03oool0oooo07`0
oooo2?ooool000OoooooGP3oool01020P800000000000020P80j0?ooo`80000000<0P8200?ooo`3o
ool0O03oool8ooooo`001ooooomN0?ooo`040820P000000000000<30`3X0oooo00<0P82000000000
0000OP3oool8ooooo`001ooooomN0?ooo`030820P0000000000003/0oooo00<0P820000000000000
OP3oool8ooooo`001ooooomN0?ooo`030820P0000000000003/0oooo00<0P820000000000000OP3o
ool8ooooo`001ooooomN0?ooo`030820P0000000000003/0oooo00@0`<30000000000000`<30O@3o
ool8ooooo`001ooooomN0?ooo`<00000?03oool2000000030820P03oool0oooo07/0oooo2?ooool0
00OoooooGP3oool3000003`0oooo0P0000000`20P800oooo0?ooo`1k0?ooo`Sooooo0007oooooeh0
oooo0P0000000`20P800oooo0?ooo`0j0?ooo`80000000<0P8200?ooo`3oool0N`3oool8ooooo`00
1ooooomN0?ooo`800000?P3oool2000007d0oooo2?ooool000OoooooGP3oool2000003h0oooo0P00
001m0?ooo`Sooooo0007oooooed0oooo0`00000n0?ooo`800000O@3oool8ooooo`001ooooomM0?oo
o`<00000?P3oool00`10@40000000820P01l0?ooo`Sooooo0007oooooed0oooo0`00000n0?ooo`03
0820P0000000000007`0oooo2?ooool000OoooooG@3oool3000003h0oooo00<0P820000000000000
O03oool8ooooo`001ooooomM0?ooo`80000000<0@4100?ooo`3oool0?03oool00`20P80000000000
001l0?ooo`Sooooo0007oooooe`0oooo00@0P820000000000000P820?`3oool2000000030820P03o
ool0oooo07T0oooo2?ooool000OoooooG03oool01020P800000000000020P80o0?ooo`80000000<0
P8200?ooo`3oool0N@3oool8ooooo`001ooooomL0?ooo`040820P000000000000820P3l0oooo0P00
00000`20P800oooo0?ooo`1i0?ooo`Sooooo0007oooooe`0oooo00@0P820000000000000P820?`3o
ool00`10@40000000410@01k0?ooo`Sooooo0007oooooe`0oooo00@0P820000000000000P820?`3o
ool00`20P80000000000001k0?ooo`Sooooo0007oooooe`0oooo00@0P820000000000000P820?`3o
ool00`20P80000000000001k0?ooo`Sooooo0007oooooe`0oooo00<0P820000000000000@03oool0
0`20P80000000000001k0?ooo`Sooooo0007oooooe`0oooo0`0000110?ooo`<00000NP3oool8oooo
o`001ooooomL0?ooo`<00000@@3oool3000007X0oooo2?ooool000OoooooG03oool300000440oooo
0`00001j0?ooo`Sooooo0007oooooe`0oooo0`0000110?ooo`040820P000000000000<30`7T0oooo
2?ooool000OoooooG03oool300000480oooo0P0000000`20P800oooo0?ooo`1g0?ooo`Sooooo0007
oooooe`0oooo0P0000000`10@400oooo0?ooo`100?ooo`80000000<0P8200?ooo`3oool0M`3oool8
ooooo`001ooooomL0?ooo`80000000<0P8200?ooo`3oool0@03oool2000000030820P03oool0oooo
07L0oooo2?ooool000OoooooG03oool2000000030820P03oool0oooo0400oooo00<0P82000000000
0000N@3oool8ooooo`001ooooomL0?ooo`80000000<0P8200?ooo`3oool0@03oool00`20P8000000
0000001i0?ooo`Sooooo0007oooooe`0oooo0P0000000`20P800oooo0?ooo`100?ooo`030820P000
0000000007T0oooo2?ooool000OoooooF`3oool3000000030820P03oool0oooo0400oooo00<0P820
000000000000N@3oool8ooooo`001ooooomK0?ooo`<0000000<0P8200?ooo`3oool0@@3oool20000
00030820P03oool0oooo07H0oooo2?ooool000OoooooF`3oool3000004@0oooo0P0000000`20P800
oooo0?ooo`1f0?ooo`Sooooo0007oooooe/0oooo0`0000140?ooo`80000000<0P8200?ooo`3oool0
MP3oool8ooooo`001ooooomK0?ooo`<00000A@3oool2000007P0oooo2?ooool000OoooooF`3oool3
000004D0oooo0P00001h0?ooo`Sooooo0007oooooe/0oooo0`0000150?ooo`800000N03oool8oooo
o`001ooooomK0?ooo`<00000A@3oool2000007P0oooo2?ooool000OoooooF`3oool3000004D0oooo
00<0P820000000000000M`3oool8ooooo`001ooooomJ0?ooo`040820P000000000000820P4D0oooo
00<0P820000000000000M`3oool8ooooo`001ooooomJ0?ooo`030820P0000000000004H0oooo00<0
P820000000000000M`3oool8ooooo`001ooooomJ0?ooo`030820P0000000000004L0oooo0P000000
0`20P800oooo0?ooo`1d0?ooo`Sooooo0007oooooeX0oooo00<0P820000000000000A`3oool20000
00030820P03oool0oooo07@0oooo2?ooool000OoooooFP3oool00`20P8000000000000170?ooo`80
000000<0P8200?ooo`3oool0M03oool8ooooo`001ooooomJ0?ooo`030820P0000000000004L0oooo
0P0000000`20P800oooo0?ooo`1d0?ooo`Sooooo0007oooooeX0oooo00<0P820000000000000A`3o
ool00`20P80000000000001f0?ooo`Sooooo0007oooooeX0oooo00<0P820000000000000A`3oool0
0`20P80000000000001f0?ooo`Sooooo0007oooooeX0oooo00<0@410000000000000A`3oool00`20
P80000000000001f0?ooo`Sooooo0007oooooeX0oooo0P0000000`20P800oooo0?ooo`160?ooo`<0
0000M@3oool8ooooo`001ooooomJ0?ooo`80000000<0P8200?ooo`3oool0AP3oool3000007D0oooo
2?ooool000OoooooFP3oool2000000030820P03oool0oooo04H0oooo0`00001e0?ooo`Sooooo0007
oooooeX0oooo0P0000000`20P800oooo0?ooo`170?ooo`80000000<0P8200?ooo`3oool0LP3oool8
ooooo`001ooooomJ0?ooo`80000000<0P8200?ooo`3oool0A`3oool2000000030820P03oool0oooo
0780oooo2?ooool000OoooooFP3oool2000000030820P03oool0oooo04L0oooo00<0P82000000000
0000M03oool8ooooo`001ooooomJ0?ooo`80000000<0P8200?ooo`3oool0A`3oool00`20P8000000
0000001d0?ooo`Sooooo0007oooooeX0oooo0P0000000`20P800oooo0?ooo`170?ooo`030820P000
0000000007@0oooo2?ooool000OoooooF@3oool01020P800000000000030`<190?ooo`040<30`000
00000000000007<0oooo2?ooool000OoooooF@3oool3000004/0oooo0`00001c0?ooo`Sooooo0007
oooooeT0oooo0`00001;0?ooo`<00000L`3oool8ooooo`001ooooomI0?ooo`<00000C03oool20000
00030820P03oool0oooo0700oooo2?ooool000OoooooF@3oool3000004`0oooo0P0000000`20P800
oooo0?ooo`1`0?ooo`Sooooo0007oooooeT0oooo0`00001<0?ooo`80000000<0@4100?ooo`3oool0
L03oool8ooooo`001ooooomI0?ooo`<00000C03oool00`20P80000000000001b0?ooo`Sooooo0007
oooooeT0oooo0`00001<0?ooo`030820P000000000000780oooo2?ooool000OoooooF@3oool30000
04`0oooo00@0P820000000000000P820L@3oool8ooooo`001ooooomH0?ooo`030820P00000000000
04h0oooo0P0000000`20P800oooo0?ooo`1_0?ooo`Sooooo0007oooooeP0oooo00<0P82000000000
0000CP3oool2000000030410@03oool0oooo06l0oooo2?ooool000OoooooF03oool00`20P8000000
0000001?0?ooo`800000L@3oool8ooooo`001ooooomH0?ooo`030820P0000000000004l0oooo0P00
001a0?ooo`Sooooo0007oooooeP0oooo00<0P820000000000000C`3oool200000740oooo2?ooool0
00OoooooF03oool00`20P80000000000001?0?ooo`030410@000000000000700oooo2?ooool000Oo
ooooF03oool00`20P80000000000001?0?ooo`030820P000000000000700oooo2?ooool000Oooooo
F03oool00`20P80000000000001?0?ooo`030820P000000000000700oooo2?ooool000OoooooF03o
ool00`20P80000000000001?0?ooo`040<30`000000000000820P6l0oooo2?ooool000OoooooF03o
ool00`20P80000000000001@0?ooo`80000000<0P8200?ooo`3oool0K@3oool8ooooo`001ooooomH
0?ooo`030820P000000000000500oooo0P0000000`10@400oooo0?ooo`1]0?ooo`Sooooo0007oooo
oeP0oooo00<0P820000000000000D03oool00`20P80000000000001_0?ooo`Sooooo0007oooooeP0
oooo00<0@41000000010@400D03oool00`20P80000000000001_0?ooo`Sooooo0007oooooeP0oooo
0P0000000`20P800oooo0?ooo`1>0?ooo`030820P0000000000006l0oooo2?ooool000OoooooF03o
ool2000000030820P03oool0oooo04h0oooo00@0`<300000000000000000KP3oool8ooooo`001ooo
oomH0?ooo`80000000<0P8200?ooo`3oool0C`3oool3000006h0oooo2?ooool000OoooooF03oool2
000000030820P03oool0oooo04l0oooo0`00001^0?ooo`Sooooo0007oooooeP0oooo0P0000000`20
P800oooo0?ooo`1?0?ooo`040820P000000000000820P6d0oooo2?ooool000OoooooF03oool20000
00030820P03oool0oooo0500oooo0P0000000`20P800oooo0?ooo`1[0?ooo`Sooooo0007oooooeP0
oooo0P0000000`20P800oooo0?ooo`1@0?ooo`80000000<0@4100?ooo`3oool0J`3oool8ooooo`00
1ooooomH0?ooo`80000000<0P8200?ooo`3oool0D03oool00`20P80000000000001]0?ooo`Sooooo
0007oooooeP0oooo0P0000000`20P800oooo0?ooo`1@0?ooo`030820P0000000000006d0oooo2?oo
ool000OoooooF03oool2000000030820P03oool0oooo0500oooo00@0P820000000000000P820K03o
ool8ooooo`001ooooomH0?ooo`80000000<0P8200?ooo`3oool0D@3oool3000006`0oooo2?ooool0
00OoooooF03oool2000000030820P03oool0oooo0540oooo0`00001/0?ooo`Sooooo0007oooooeP0
oooo0P0000000`20P800oooo0?ooo`1A0?ooo`<0000000<0P8200?ooo`3oool0J@3oool8ooooo`00
1ooooomH0?ooo`80000000<0P8200?ooo`3oool0DP3oool2000000030820P03oool0oooo06T0oooo
2?ooool000OoooooF03oool2000000030820P03oool0oooo0580oooo0P0000000`20P800oooo0?oo
o`1Y0?ooo`Sooooo0007oooooeP0oooo0P0000000`20P800oooo0?ooo`1B0?ooo`030410@0000000
000006/0oooo2?ooool000OoooooE`3oool00`20P80000000000001E0?ooo`030820P00000000000
06/0oooo2?ooool000OoooooE`3oool00`20P80000000000001E0?ooo`040820P000000000000820
P6X0oooo2?ooool000OoooooE`3oool00`20P80000000000001F0?ooo`80000000<0P8200?ooo`3o
ool0J03oool8ooooo`001ooooomG0?ooo`030820P0000000000005H0oooo0P0000000`20P800oooo
0?ooo`1X0?ooo`Sooooo0007oooooeL0oooo00<0P820000000000000EP3oool00`20P80000000000
001Z0?ooo`Sooooo0007oooooeL0oooo00<0P820000000000000E`3oool2000006X0oooo2?ooool0
00OoooooE`3oool00`20P80000000000001G0?ooo`<00000J@3oool8ooooo`001ooooomG0?ooo`03
0820P0000000000005L0oooo00<0P820000000000000J@3oool8ooooo`001ooooomG0?ooo`030820
P0000000000005L0oooo00<0P820000000000000J@3oool8ooooo`001ooooomG0?ooo`030820P000
0000000005L0oooo00@0`<30000000000000P820J03oool8ooooo`001ooooomG0?ooo`030820P000
0000000005P0oooo0P0000000`20P800oooo0?ooo`1V0?ooo`Sooooo0007oooooeL0oooo00<0P820
000000000000F03oool2000000030410@03oool0oooo06H0oooo2?ooool000OoooooE`3oool00`20
P80000000000001H0?ooo`030820P0000000000006P0oooo2?ooool000OoooooE`3oool00`20P800
00000000001H0?ooo`030820P0000000000006P0oooo2?ooool000OoooooE`3oool00`20P8000000
0000001H0?ooo`040<30`00000000000000006L0oooo2?ooool000OoooooE`3oool00`20P8000000
0000001I0?ooo`<00000I`3oool8ooooo`001ooooomG0?ooo`030820P0000000000005T0oooo0`00
001W0?ooo`Sooooo0007oooooeL0oooo00<0P820000000000000F@3oool3000000030820P03oool0
oooo06@0oooo2?ooool000OoooooE`3oool00`20P80000000000001J0?ooo`80000000<0P8200?oo
o`3oool0I03oool8ooooo`001ooooomG0?ooo`030820P0000000000005X0oooo0P0000000`10@400
oooo0?ooo`1T0?ooo`Sooooo0007oooooeL0oooo00<0P820000000000000FP3oool00`20P8000000
0000001V0?ooo`Sooooo0007oooooeL0oooo00<0P820000000000000FP3oool00`20P80000000000
001V0?ooo`Sooooo0007oooooeL0oooo00<0P820000000000000FP3oool01020P800000000000020
P81U0?ooo`Sooooo0007oooooeL0oooo00<0@41000000020P800F`3oool2000000030820P03oool0
oooo06<0oooo2?ooool000OoooooE`3oool2000005`0oooo0P0000000`20P800oooo0?ooo`1S0?oo
o`Sooooo0007oooooeL0oooo0P00001L0?ooo`030820P0000000000006D0oooo2?ooool000Oooooo
E`3oool2000005d0oooo0P00001U0?ooo`Sooooo0007oooooeL0oooo0P00001M0?ooo`800000I@3o
ool8ooooo`001ooooomG0?ooo`800000G@3oool00`10@40000000000001T0?ooo`Sooooo0007oooo
oeL0oooo0P00001M0?ooo`030820P0000000000006@0oooo2?ooool000OoooooE`3oool2000005d0
oooo00@0P820000000000000`<30H`3oool8ooooo`001ooooomG0?ooo`800000GP3oool200000003
0820P03oool0oooo0640oooo2?ooool000OoooooE`3oool2000005h0oooo0P0000000`20P800oooo
0?ooo`1Q0?ooo`Sooooo0007oooooeL0oooo0P00001N0?ooo`030410@0000000000006<0oooo2?oo
ool000OoooooE`3oool2000005h0oooo00<0P820000000000000H`3oool8ooooo`001ooooomG0?oo
o`800000GP3oool01020P800000000000020P81R0?ooo`Sooooo0007oooooeL0oooo0P00001O0?oo
o`<00000HP3oool8ooooo`001ooooomG0?ooo`800000G`3oool300000680oooo2?ooool000Oooooo
E`3oool2000005l0oooo0`0000000`20P800oooo0?ooo`1O0?ooo`Sooooo0007oooooeL0oooo0P00
001P0?ooo`80000000<0P8200?ooo`3oool0G`3oool8ooooo`001ooooomG0?ooo`800000H03oool2
000000030410@03oool0oooo05l0oooo2?ooool000OoooooE`3oool200000600oooo00<0P8200000
00000000H@3oool8ooooo`001ooooomG0?ooo`800000H03oool01020P800000000000020P81P0?oo
o`Sooooo0007oooooeL0oooo0P00001Q0?ooo`<00000H03oool8ooooo`001ooooomG0?ooo`800000
H@3oool300000600oooo2?ooool000OoooooE`3oool200000640oooo00@0P820000000000000P820
G`3oool8ooooo`001ooooomG0?ooo`800000HP3oool2000000030820P03oool0oooo05d0oooo2?oo
ool000OoooooEP3oool2000000030820P03oool0oooo0600oooo00<0@410000000000000G`3oool8
ooooo`001ooooomF0?ooo`80000000<0P8200?ooo`3oool0H03oool00`20P80000000000001O0?oo
o`Sooooo0007oooooeH0oooo0P0000000`20P800oooo0?ooo`1P0?ooo`040820P000000000000<30
`5h0oooo2?ooool000OoooooEP3oool2000000030820P03oool0oooo0640oooo0P0000000`20P800
oooo0?ooo`1L0?ooo`Sooooo0007oooooeH0oooo0P0000000`20P800oooo0?ooo`1Q0?ooo`800000
00<0P8200?ooo`3oool0G03oool8ooooo`001ooooomF0?ooo`80000000<0P8200?ooo`3oool0H@3o
ool00`20P80000000000001N0?ooo`Sooooo0007oooooeH0oooo0P0000000`20P800oooo0?ooo`1R
0?ooo`800000GP3oool8ooooo`001ooooomF0?ooo`80000000<0P8200?ooo`3oool0HP3oool00`10
@40000000000001M0?ooo`Sooooo0007oooooeH0oooo0P0000000`20P800oooo0?ooo`1R0?ooo`03
0820P0000000000005d0oooo2?ooool000OoooooEP3oool2000000030820P03oool0oooo0680oooo
00@0P820000000000000`<30G03oool8ooooo`001ooooomF0?ooo`80000000<0P8200?ooo`3oool0
H`3oool2000000030820P03oool0oooo05X0oooo2?ooool000OoooooEP3oool2000000030820P03o
ool0oooo06<0oooo0P0000000`20P800oooo0?ooo`1J0?ooo`Sooooo0007oooooeH0oooo0P000000
0`20P800oooo0?ooo`1S0?ooo`030410@0000000000005`0oooo2?ooool000OoooooEP3oool20000
00030820P03oool0oooo06<0oooo00<0P820000000000000G03oool8ooooo`001ooooomF0?ooo`80
000000<0P8200?ooo`3oool0H`3oool01020P800000000000020P81K0?ooo`Sooooo0007oooooeH0
oooo0P0000000`20P800oooo0?ooo`1T0?ooo`<00000F`3oool8ooooo`001ooooomE0?ooo`040<30
`000000000000<30`6H0oooo0`00001K0?ooo`Sooooo0007oooooeD0oooo00<0P820000000000000
I`3oool3000000030820P03oool0oooo05P0oooo2?ooool000OoooooE@3oool00`20P80000000000
001X0?ooo`80000000<0P8200?ooo`3oool0F03oool8ooooo`001ooooomE0?ooo`030820P0000000
000006P0oooo0P0000000`10@400oooo0?ooo`1H0?ooo`Sooooo0007oooooeD0oooo00<0P8200000
00000000J03oool00`20P80000000000001J0?ooo`Sooooo0007oooooeD0oooo00<0P82000000000
0000J03oool00`20P80000000000001J0?ooo`Sooooo0007oooooeD0oooo00<0P820000000000000
J03oool01020P800000000000000001I0?ooo`Sooooo0007oooooeD0oooo00<0P820000000000000
J@3oool3000005T0oooo2?ooool000OoooooE@3oool00`20P80000000000001Y0?ooo`<0000000<0
P8200?ooo`3oool0EP3oool8ooooo`001ooooomE0?ooo`030820P0000000000006X0oooo0P000000
0`20P800oooo0?ooo`1F0?ooo`Sooooo0007oooooeD0oooo00<0P820000000000000JP3oool00`10
@40000000000001H0?ooo`Sooooo0007oooooeD0oooo00<0P820000000000000JP3oool00`20P800
00000000001H0?ooo`Sooooo0007oooooeD0oooo00<0P820000000000000JP3oool01030`<000000
00000020P81G0?ooo`Sooooo0007oooooeD0oooo00<0P820000000000000J`3oool2000000030820
P03oool0oooo05D0oooo2?ooool000OoooooE@3oool00`20P80000000000001[0?ooo`030820P000
0000000005L0oooo2?ooool000OoooooE@3oool00`20P80000000000001/0?ooo`800000E`3oool8
ooooo`001ooooomE0?ooo`030820P0000000000006`0oooo0P0000000`20P800oooo0?ooo`1D0?oo
o`Sooooo0007oooooeD0oooo00<0@41000000010@400K03oool00`20P80000000000001F0?ooo`So
oooo0007oooooeD0oooo0P0000000`20P800oooo0?ooo`1Z0?ooo`040820P000000000000820P5D0
oooo2?ooool000OoooooE@3oool2000000030820P03oool0oooo06/0oooo0P0000000`20P800oooo
0?ooo`1C0?ooo`Sooooo0007oooooeD0oooo0P0000000`20P800oooo0?ooo`1[0?ooo`<00000E@3o
ool8ooooo`001ooooomE0?ooo`80000000<0P8200?ooo`3oool0@@3oool00`20P80000000000000=
000000030820P03oool0oooo01L0oooo00<0P820000000000000E@3oool8ooooo`001ooooomE0?oo
o`80000000<0P8200?ooo`3oool0@P3oool00`20P80000000000000=000001T0oooo00@0P8200000
000000000000E03oool8ooooo`001ooooomE0?ooo`80000000<0P8200?ooo`3oool0@`3oool00`20
P80000000000000<000001X0oooo0`00001D0?ooo`Sooooo0007oooooeD0oooo0P0000000`20P800
oooo0?ooo`140?ooo`030<30`0000000P82000X0oooo00<0@4100000003oool0603oool01020P800
000000000020P81C0?ooo`Sooooo0007oooooeD0oooo0P0000000`20P800oooo0?ooo`150?ooo`03
0820P0000000P82000X0oooo00<000000820P03oool0603oool2000000030820P03oool0oooo0540
oooo2?ooool000OoooooE@3oool2000000030820P03oool0oooo04H0oooo00<0P82000000020P800
2P3oool00`30`<00oooo0?ooo`0G0?ooo`80000000<0@4100?ooo`3oool0D@3oool8ooooo`001ooo
oomE0?ooo`80000000<0P8200?ooo`3oool0A`3oool00`20P80000000820P00S0?ooo`030820P000
0000000005<0oooo2?ooool000OoooooE@3oool2000000030820P03oool0oooo04L0oooo00@0`<30
000000000000`<308P3oool01020P800000000000030`<1B0?ooo`Sooooo0007oooooeD0oooo0P00
00000`20P800oooo0?ooo`190?ooo`030410@0000000oooo0280oooo0P0000000`20P800oooo0?oo
o`1@0?ooo`Sooooo0007oooooe@0oooo0`0000000`20P800oooo0?ooo`0[0?ooo`@000001`3oool0
1020P800000000000020P80@0?ooo`8000008P3oool300000580oooo2?ooool000OoooooE03oool3
000000030820P03oool0oooo02T0oooo00<0P820000000000000100000000`20P800`<300?ooo`03
0?ooo`D0000000<0`<300?ooo`3oool0303oool00`30`<0000000410@00R0?ooo`800000DP3oool8
ooooo`001ooooomD0?ooo`<0000000<0P8200?ooo`3oool0:03oool00`20P8000000000000070000
00<0oooo1`00000?0?ooo`<000008@3oool200000580oooo2?ooool000OoooooE03oool300000003
0820P03oool0oooo02P0oooo100000001@20P800oooo0?ooo`3oool0P8200080@4100P3oool02@20
P8000000000000000000P8200?ooo`30`<0000000<30`00>0?ooo`030410@0000000@4100200oooo
00<0@410000000000000D@3oool8ooooo`001ooooomD0?ooo`<0000000<0P8200?ooo`3oool09`3o
ool4000000030820P03oool0oooo00@0oooo00@0P8200000003oool0oooo0`0000001@20P800oooo
0?ooo`3oool0000000h0oooo00@0P82000000000000000007`3oool00`20P80000000000001A0?oo
o`Sooooo0007oooooe@0oooo0`0000000`30`<00oooo0?ooo`0W0?ooo`@00000203oool00`20P800
@4100?ooo`03000000060820P03oool0oooo0?ooo`30`<00@4103P3oool3000000030<30`03oool0
oooo01`0oooo00@0`<30000000000000P820D03oool8ooooo`001ooooomD0?ooo`<00000:P3oool4
000000T0oooo00<0@4100000000000000P0000000`10@400oooo0?ooo`020?ooo`030<30`03oool0
oooo00`0oooo00@0P820000000000000@4107`3oool2000000030820P03oool0oooo04h0oooo2?oo
ool000OoooooE03oool3000002X0oooo1000000:0?ooo`D00000503oool3000001l0oooo0`00001@
0?ooo`Sooooo0007oooooe@0oooo0`00000Z0?ooo`@000002`3oool4000001@0oooo0`0000000`20
P800oooo0?ooo`0L0?ooo`030820P000000000000500oooo2?ooool000OoooooE03oool3000002X0
oooo100000000`20P800oooo0?ooo`080?ooo`030820P00000000000008000001P3oool00`000000
P8200?ooo`0:0?ooo`<0000000<0P8200?ooo`3oool0703oool01020P800000000000000001?0?oo
o`Sooooo0007oooooe<0oooo00@0P8200000000000000000:`3oool3000000030820P03oool0oooo
00P0oooo00<0`<300000000000000P0000060?ooo`030820P010@400oooo00T0oooo00D0P8200000
0000000000000820P00O0?ooo`<00000C`3oool8ooooo`001ooooomC0?ooo`040820P00000000000
000002/0oooo0`0000000`20P800oooo0?ooo`090?ooo`@0000000<0P8200?ooo`3oool0103oool0
0`000000oooo0?ooo`080?ooo`@0000000<0P8200?ooo`3oool07@3oool3000004l0oooo2?ooool0
00OoooooD`3oool01020P800000000000000000[0?ooo`040820P00000000000000000/0oooo00D0
P82000000000000000000820P0060?ooo`030410@0000000`<3000L0oooo00<0P820000000000000
0P0000000`30`<00oooo0?ooo`0M0?ooo`040820P000000000000820P4h0oooo2?ooool000Oooooo
D`3oool01020P800000000000000000/0?ooo`@000002P3oool01@30`<000000000000000000@410
00H0oooo00@0`<30000000000000P820103oool00`20P800000000000003000000030410@03oool0
oooo01l0oooo0P0000000`10@400oooo0?ooo`1<0?ooo`Sooooo0007oooooe<0oooo00@0P8200000
000000000000;@3oool3000000030820P03oool0oooo00P0oooo100000080?ooo``0000000<0P820
0?ooo`3oool07`3oool00`20P80000000000001>0?ooo`Sooooo0007oooooe<0oooo00@0P8200000
000000000000;@3oool01010@400000000000010@40:0?ooo`040820P00000000000000000P0oooo
00<0`<30000000000000200000000`20P800oooo0?ooo`0P0?ooo`030820P0000000000004h0oooo
2?ooool000OoooooD`3oool01020P800000000000000000^0?ooo`<000002`3oool4000000T0oooo
2000000T0?ooo`040820P00000000000000004d0oooo2?ooool000OoooooD`3oool01020P8000000
00000000000^0?ooo`040410@00000000000000000X0oooo1000000:0?ooo`030<30`020P800P820
0080P82000<0`<300?ooo`3oool0903oool3000004d0oooo2?ooool000OoooooD`3oool01020P800
000000000000000_0?ooo`<0000000<0P8200?ooo`3oool01`3oool4000000030820P03oool0oooo
03<0oooo0`0000000`20P800oooo0?ooo`0J0?ooo`<00000;@3oool8ooooo`001ooooomC0?ooo`04
0410@000000000000820P300oooo00@0@410000000000000P820203oool4000000030820P03oool0
oooo03@0oooo0P0000000`20P800oooo0?ooo`0G0?ooo`030<30`010@400000000<0000000<0P820
0?ooo`3oool0:P3oool8ooooo`001oooool]0?ooo`040<30`020P800P8200820P280oooo0`00000b
0?ooo`040820P000000000000410@0L0oooo100000000`10@400oooo0?ooo`0d0?ooo`80000000<0
@4100?ooo`3oool04`3oool00`30`<00P8200820P007000000030410@03oool0oooo02X0oooo2?oo
ool000Oooooo;@3oool5000000030820P03oool0oooo01h0oooo0`00000c0?ooo`040820P0000000
00000820P0H0oooo00<0P8200000000000000P00000f0?ooo`030820P0000000000001<0oooo3@00
000/0?ooo`Sooooo0007ooooobd0oooo1`0000000`10@400P8200<30`00L0?ooo`<00000=03oool0
1@20P800@41000000020P800`<300080oooo00<0`<3000000020P8001000000f0?ooo`040820P000
000000000<30`0l0oooo0P20P80>000002`0oooo2?ooool000Oooooo;03oool00`20P80000000000
0009000001/0oooo0`00000f0?ooo`030820P0000000000000@0000000<0oooo0000000000000P00
00000`20P800oooo0?ooo`0d0?ooo`80000000<0P8200?ooo`3oool02`3ooolC000002/0oooo2?oo
ool000Oooooo;03oool00`20P80000000000000:000000030410@020P800`<3001L0oooo0`00000h
0?ooo`@0P8200`3oool3000000030820P03oool0oooo03@0oooo0P0000000`10@400oooo0?ooo`08
0?ooo`030<30`010@400000001<00000:`3oool8ooooo`001oooool/0?ooo`030820P00000000000
00h000005P3oool3000003l0oooo1000000g0?ooo`800000203oool00`20P80000000000000E0000
02/0oooo2?ooool000Oooooo;03oool00`10@40000000000000@000000030820P03oool0oooo0140
oooo0`00000o0?ooo`040820P00000000000000003L0oooo0P0000000`20P800oooo0?ooo`020?oo
o`030820P010@400000001P00000:`3oool8ooooo`001oooool/0?oooaH0000000<0P8200?ooo`3o
ool03P3oool3000003l0oooo00D0P82000000000000000000820P00f0?ooo`060410@00000000000
0<30`020P800@410A`000008ooooo`001oooool/0?oooaT000003P3oool300000400oooo1000000f
0?ooo`030820P000000000000080ooooB0000008ooooo`001oooool/0820P1/000000`20P8080?oo
o`040820P000000000000820P400oooo1000000f0?ooo`040<30`000000000000820P0<0oooo00<0
P8200410@0000000600000000`10@400P8200820P00X0820P0Sooooo0007oooood/000001`3oool0
1020P800000000000020P8100?ooo`@0000000<0P8200?ooo`3oool0=03oool2000000030820P03o
ool0oooo00@0oooo00<0P8200000000000005@0000000`20P800oooo0?ooo`0X0?ooo`Sooooo0007
ooooodL000000P20P8090?ooo`040820P000000000000820P440oooo0`0000000`20P800oooo0?oo
o`0d0?ooo`030410@0000000000000P0oooo00<0P8200410@00000004`00000[0?ooo`Sooooo0007
ooooob/0oooo6P00000=0?ooo`040820P000000000000820P440oooo1000000f0?ooo`030820P000
0000000000/0oooo00<0P8200000000000004000000[0?ooo`Sooooo0007ooooob`0oooo5P000002
0820P0h0oooo00@0P820000000000000P820@@3oool01020P800000000000000000f0?ooo`040820
P00000000000000000`0oooo00<0`<300820P010@4003@0000000`20P800oooo0?ooo`0Y0?ooo`So
oooo0007ooooob`0oooo4P0000020820P180oooo00@0P820000000000000P820@@3oool01@10@400
0000000000000000P82003H0oooo0`0000000`30`<00oooo0?ooo`0=0?ooo`80P8202P00000/0?oo
o`Sooooo0007ooooob`0oooo00<0P8200000000000003@00000F0?ooo`040820P000000000000820
P3d0oooo00<0P8200000000000001P00000f0?ooo`<0000000<0P8200?ooo`3oool04@3oool80000
02`0oooo2?ooool000Oooooo;03oool00`20P800000000000009000000030410@020P800oooo01L0
oooo00@0P820000000000000P820@03oool40820P0800000=`3oool2000000030820P03oool0oooo
0180oooo00<0`<300820P00000000`0000000`20P800oooo0?ooo`0Z0?ooo`Sooooo0007ooooob`0
oooo00<0P8200000000000001`0000000`20P800oooo0?ooo`0I0?ooo`030820P0000000000007h0
oooo0`00000H0?ooo`80000000<0P8200?ooo`3oool0:P3oool8ooooo`001oooool]0?ooo`H00000
0P20P80M0?ooo`030820P0000000000007h0oooo00<0@4100000000000006P3oool00`30`<00oooo
0?ooo`0Z0?ooo`Sooooo0007ooooobd0oooo0P0000000`10@400P8200<30`00P0?ooo`<00000OP3o
ool01020P80000000000000000160?ooo`Sooooo0007oooooe80oooo0`00001o0?ooo`<00000AP3o
ool8ooooo`001ooooomB0?ooo`<00000O`3oool3000000030<30`03oool0oooo04<0oooo2?ooool0
00OoooooDP3oool300000800oooo0P0000000`20P800oooo0?ooo`130?ooo`Sooooo0007oooooe80
oooo0`0000200?ooo`80000000<0P8200?ooo`3oool0@`3oool8ooooo`001ooooomB0?ooo`800000
P@3oool3000004D0oooo2?ooool000OoooooDP3oool200000840oooo00<0P820000000000000A@3o
ool8ooooo`001ooooomB0?ooo`800000P@3oool01030`<00000000000020P8140?ooo`Sooooo0007
oooooe80oooo0P0000220?ooo`80000000<0P8200?ooo`3oool0@P3oool8ooooo`001ooooomB0?oo
o`800000PP3oool00`20P8000000000000140?ooo`Sooooo0007ooooocl0oooo00@0lX200>@0003T
0000i0003`3oool2000008<0oooo0`0000130?ooo`Sooooo0007ooooocl0oooo00<0jd100>@0003T
0000103T00040?:0P0L0oooo0`0000230?ooo`030410@0000000000000l0oooo0`3bP80a0?ooo`So
oooo0007ooooocl0oooo3P3T00040?ooo`80000000<0P8200?ooo`3oool0P@3oool01020P8000000
00000020P80:0?ooo`P0i000<03oool8ooooo`001ooooom20?ooo`040?W0`03bP800lX200>]0@0/0
i0000P1b00000`2b@400oooo0?ooo`210?ooo`040<30`000000000000820P0<0oooo103bP80;0>@0
0300oooo2?ooool000OoooooB@3oool0103i`<00lX200?:0P03[@40;0>@000030>]0@03bP800lX20
0080lX20NP3oool0103i`<00LP000780001b000;0>@000<0lX20=03oool8ooooo`001ooooom@0?oo
o`030?:0P03T0000i00000h0i000L03oool00`3bP800i0000>@0000>0>@003/0oooo2?ooool000Oo
ooooD`3oool00`3i`<00lX200?:0P0020?:0P0d0i00000<0jd100?:0P03bP8000P3bP81M0?ooo`D0
lX2000<0jd100>@0003T0000303T00030?:0P3l0oooo2?ooool000OoooooG03oool00`3bP800i000
0>@0000B0>@00500oooo5P3T00000`3bP800oooo0?ooo`130?ooo`Sooooo0007ooooof00oooo1@3b
P80C0>@000L0lX20;03oool00`3i`<00lX200?:0P0080?:0P0030>]0@03T0000i00001<0i00000<0
jd100?:0P03bP8000`3bP81;0?ooo`Sooooo0007ooooofT0ooooGP3T00000`3bP800oooo0?ooo`1C
0?ooo`Sooooo0007ooooog40oooo1`3bP80o0>@000/0lX20F`3oool8ooooo`001ooooomo0?ooob`0
lX2000<0nL300?ooo`3oool0K`3oool8ooooo`001ooooooo0?oooah0oooo2?ooool000Ooooooo`3o
oolN0?ooo`Sooooo0007ooooool0oooo7P3oool8ooooo`001ooooooo0?oooah0oooo2?ooool000Oo
ooooo`3ooolN0?ooo`Sooooo0007ooooool0oooo7P3oool8ooooo`001ooooooo0?oooah0oooo2?oo
ool000Ooooooo`3ooolN0?ooo`Sooooo0007ooooool0oooo7P3oool8ooooo`001ooooooo0?oooah0
oooo2?ooool000Ooooooo`3ooolN0?ooo`Sooooo0007oooooiT0oooo0`0i>Ol00`2LW?l0oooo0?oo
o`1n0?ooo`Sooooo0007oooooiT0oooo0`0i>Ol00`2LW?l0oooo0?ooo`1n0?ooo`Sooooo0007oooo
oiT0oooo0`0i>Ol00`2LW?l0oooo0?ooo`1n0?ooo`Sooooo0007oooooiT0oooo0`0i>Ol00`2LW?l0
oooo0?ooo`1n0?ooo`Sooooo0007oooooiT0oooo0`0i>Ol00`2LW?l0oooo0?ooo`1n0?ooo`Sooooo
0007oooooiT0oooo0`0i>Ol00`2LW?l0oooo0?ooo`1n0?ooo`Sooooo0007oooooiT0oooo0`0i>Ol0
0`2LW?l0oooo0?ooo`1n0?ooo`Sooooo0007oooooiT0oooo0`0i>Ol00`2LW?l0oooo0?ooo`1n0?oo
o`Sooooo0007oooooiT0oooo0`0i>Ol00`2LW?l0oooo0?ooo`1n0?ooo`Sooooo0007oooooiT0oooo
0`0i>Ol00`2LW?l0oooo0?ooo`1n0?ooo`Sooooo0007oooooiT0oooo0`0i>Ol00`2LW?l0oooo0?oo
o`1n0?ooo`Sooooo0007oooooiT0oooo0`0i>Ol00`2LW?l0oooo0?ooo`1n0?ooo`Sooooo0007oooo
oiT0oooo0`0i>Ol00`2LW?l0oooo0?ooo`1n0?ooo`Sooooo0007oooooiT0oooo0`0i>Ol00`2LW?l0
oooo0?ooo`1n0?ooo`Sooooo0007oooooiT0oooo0`0i>Ol00`2LW?l0oooo0?ooo`1n0?ooo`Sooooo
0007oooooiT0oooo0`0i>Ol00`2LW?l0oooo0?ooo`1n0?ooo`Sooooo0007oooooiT0oooo0`0i>Ol0
0`2LW?l0oooo0?ooo`1n0?ooo`Sooooo0007oooooiT0oooo0`0i>Ol00`2LW?l0oooo0?ooo`1n0?oo
o`Sooooo0007oooooiT0oooo0`0i>Ol00`2LW?l0oooo0?ooo`0S0?ooo`030<O7o`2>S_l0SXko00h0
SXkoBP3oool8ooooo`001ooooonI0?ooo`<0>CWo00<0W9co0?ooo`3oool0903oool@01dModX0oooo
2?ooool000OoooooV@3oool303Tio`0309bLo`3oool0oooo02D0oooo00<0EUKo01dMo`0M7Ol0300M
7Ol00`2>S_l0oooo0?ooo`170?ooo`Sooooo0007oooooiT0oooo0`0i>Ol00`2LW?l0oooo0?ooo`0V
0?ooo`0305IFo`0M7Ol0EUKo00X0SXko00<07Ago05IFo`3oool0B03oool8ooooo`001ooooonI0?oo
o`<0>CWo00<0W9co0?ooo`3oool09`3oool201dMo`/0oooo00<07Ago0?ooo`3oool0A`3oool8oooo
o`001ooooonI0?ooo`<0>CWo00<0W9co0?ooo`3oool0:03oool00`1FE_l07Ago0<O7o`090?ooo`03
0<O7o`0M7Ol0oooo04L0oooo2?ooool000OoooooV@3oool303Tio`0309bLo`3oool0oooo02T0oooo
0P0M7OmC0?ooo`Sooooo0007oooooiT0oooo0`0i>Ol00`2LW?l0oooo0?ooo`0Z0?ooo`0301dMo`1F
E_l0oooo0540oooo2?ooool000OoooooV@3oool303Tio`0309bLo`3oool0oooo02X0oooo00<0SXko
01dMo`0M7Ol0D@3oool8ooooo`001ooooonI0?ooo`<0>CWo00<0W9co0?ooo`3oool0:`3oool00`1F
E_l07Ago08j>o`1@0?ooo`Sooooo0007oooooiT0oooo0`0i>Ol00`2LW?l0oooo0?ooo`040?ooo`03
0<O7o`2>S_l0SXko00h0SXko5`3oool00`2>S_l07Ago08j>o`1?0?ooo`Sooooo0007oooooiT0oooo
0`0i>Ol00`2LW?l0oooo0?ooo`040?ooo`0308j>o`0M7Ol07Ago00h07Ago603oool00`2>S_l07Ago
08j>o`1>0?ooo`Sooooo0007oooooiT0oooo0`0i>Ol00`2LW?l0oooo0?ooo`070?ooo`030<O7o`2>
S_l07Ago00L07Ago00<0SXko0<O7o`3oool06@3oool01037aol07Ago01dMo`2>S_m=0?ooo`Sooooo
0007oooooiT0oooo0`0i>Ol00`2LW?l0oooo0?ooo`090?ooo`0308j>o`0M7Ol07Ago00@07Ago00<0
SXko0?ooo`3oool0703oool201dMo`0308j>o`3oool0oooo04X0oooo2?ooool000OoooooV@3oool3
03Tio`0309bLo`3oool0oooo00X0oooo1P0M7Ol00`2>S_l0oooo0?ooo`0L0?ooo`0305IFo`0M7Ol0
7Ago04`0oooo2?ooool000OoooooV@3oool303Tio`0309bLo`3oool0oooo00X0oooo1P0M7Ol00`2>
S_l0oooo0?ooo`0L0?ooo`0408j>o`0M7Ol07Ago08j>od/0oooo2?ooool000OoooooV@3oool303Ti
o`0309bLo`3oool0oooo00/0oooo1@0M7Ol00`2>S_l0oooo0?ooo`0L0?ooo`040<O7o`0M7Ol07Ago
05IFod/0oooo2?ooool000OoooooV@3oool303Tio`0309bLo`3oool0oooo00/0oooo1@0M7Ol00`2>
S_l0oooo0?ooo`0M0?ooo`<07Ago00<0SXko0?ooo`3oool0B03oool8ooooo`001ooooonI0?ooo`<0
>CWo00<0W9co0?ooo`3oool02`3oool00`2>S_l07Ago01dMo`0301dMoal0oooo100M7Om:0?ooo`So
oooo0007oooooiT0oooo0`0i>Ol00`2LW?l0oooo0?ooo`0;0?ooo`0308j>o`0M7Ol07Ago00<07Ago
4P3oool00`2>S_l07Ago0?ooo`0:0?ooo`@07AgoBP3oool8ooooo`001ooooonI0?ooo`<0>CWo00<0
W9co0?ooo`3oool02`3oool00`2>S_l07Ago01dMo`0301dMoa<0oooo00<07Ago08j>o`3oool0203o
ool00`2>S_l07Ago01dMo`0201dModX0oooo2?ooool000OoooooV@3oool303Tio`0309bLo`3oool0
oooo00/0oooo00<0alOo01dMo`0M7Ol00`0M7Ol00`2>S_l0oooo0?ooo`0@0?ooo`0301dMo`1FE_l0
oooo00P0oooo00<0EUKo01dMo`0M7Ol00P0M7Om:0?ooo`Sooooo0007oooooiT0oooo0`0i>Ol00`2L
W?l0oooo0?ooo`0<0?ooo`H07Ago4`3oool00`0M7Ol0SXko0?ooo`070?ooo`@07AgoB`3oool8oooo
o`001ooooonI0?ooo`<0>CWo00<0W9co0?ooo`3oool0303oool601dMoa<0oooo00@0EUKo01dMo`2>
S_l0alOo0`3oool00`2>S_l0EUKo01dMo`0301dMo`0305IFo`3oool0oooo04T0oooo2?ooool000Oo
ooooV@3oool303Tio`0309bLo`3oool0oooo00`0oooo00<0EUKo01dMo`0M7Ol00`0M7OlD0?ooo`03
05IFo`0M7Ol07Ago00T07Ago00<0alOo0?ooo`3oool0B@3oool8ooooo`001ooooonG0?ooo`X0>CWo
00<0W9co0?ooo`3oool01`3oool00`2>S_l07Ago01dMo`0301dMo`0308j>o`3oool0oooo0180oooo
2P0M7Ol00`2>S_l0oooo0?ooo`1:0?ooo`Sooooo0007oooooi40oooo00<0W9co03Tio`0i>Ol03`0i
>Ol00`2LW?l0oooo0?ooo`050?ooo`0308j>o`0M7Ol07Ago00<07Ago00<0SXko0?ooo`3oool04`3o
ool00`37aol0SXko01dMo`0401dMo`0308j>o`3oool0oooo04`0oooo2?ooool000OoooooT03oool0
0`2LW?l0>CWo03Tio`0B03Tio`H0oooo00<0SXko01dMo`0M7Ol00`0M7Ol00`2>S_l0oooo0?ooo`1Y
0?ooo`Sooooo0007oooooi40oooo4`0i>Ol00`1[Jol0oooo0?ooo`050?ooo`D07Ago00<0EUKo0?oo
o`3oool0J@3oool8ooooo`001ooooonA0?oooa<0>CWo00<0W9co0?ooo`3oool01@3oool601dMof/0
oooo2?ooool000OoooooT@3oool00`2LW?l0>CWo03Tio`0@03Tio`P0oooo1P0M7Om[0?ooo`Sooooo
0007oooooi40oooo00<0c/ko03Tio`0i>Ol03`0i>Ol00`1[Jol0oooo0?ooo`070?ooo`D07Ago00<0
alOo0?ooo`3oool0J03oool8ooooo`001ooooonB0?oooa40>CWo00<0W9co0?ooo`3oool01`3oool5
01dMo`0308j>o`3oool0oooo06P0oooo2?ooool000OoooooTP3oool00`2LW?l0>CWo03Tio`0>03Ti
o`030<k>o`3oool0oooo00L0oooo1@0M7Ol00`2>S_l0oooo0?ooo`1X0?ooo`Sooooo0007oooooi<0
oooo400i>Ol:0?ooo`0308j>o`0M7Ol07Ago00807Ago00<0SXko0?ooo`3oool0J03oool8ooooo`00
1ooooonC0?ooo`0306][o`0i>Ol0>CWo00`0>CWo00<0W9co0?ooo`3oool0203oool00`2>S_l07Ago
01dMo`0301dMofX0oooo2?ooool000OoooooT`3oool00`2LW?l0>CWo03Tio`0;03Tio`0306][o`3o
ool0oooo00T0oooo00<0SXko01dMo`0M7Ol00`0M7OlA0?ooo`80alOoE`3oool8ooooo`001ooooonD
0?ooo`d0>CWo00<0W9co0?ooo`3oool02P3oool501dMoa40oooo0P2>S_mG0?ooo`Sooooo0007oooo
oi@0oooo3@0i>Ol00`3>c_l0oooo0?ooo`0:0?ooo`H07Ago403oool208j>oeL0oooo2?ooool000Oo
ooooU@3oool<03Tio`d0oooo1P0M7Ol@0?ooo`807AgoE`3oool8ooooo`001ooooonE0?ooo`/0>CWo
3P3oool601dMo`030<O7o`3oool0oooo00d0oooo0P0M7OmG0?ooo`Sooooo0007oooooiD0oooo00<0
W9co03Tio`0i>Ol0200i>Ol>0?ooo`H07Ago00<0SXko0?ooo`3oool0303oool301dMoeL0oooo2?oo
ool000OoooooU@3oool00`3>c_l0>CWo03Tio`0703Tio`0309bLo`3oool0oooo00`0oooo1P0M7Ol0
0`1FE_l0oooo0?ooo`0;0?ooo`0405IFo`0M7Ol07Ago01dMoeL0oooo2?ooool000OoooooUP3oool9
03Tio`h0oooo00<0SXko01dMo`0M7Ol01P0M7Ol:08j>o`H07AgoE`3oool8ooooo`001ooooonG0?oo
o`P0>CWo2`3oool00`2>S_l07Ago01dMo`0I01dMoeL0oooo2?ooool000OoooooU`3oool703Tio`03
06][o`3oool0oooo00T0oooo00<0alOo08j>o`2>S_l06@2>S_mG0?ooo`Sooooo0007oooooiL0oooo
00<0W9co03Tio`0i>Ol0100i>Ol00`2LW?l0oooo0?ooo`1l0?ooo`Sooooo0007oooooiL0oooo00<0
W9co03Tio`0i>Ol0100i>Ol00`2LW?l0oooo0?ooo`1l0?ooo`Sooooo0007oooooiP0oooo1P0i>Omo
0?ooo`Sooooo0007oooooiP0oooo1P0i>Omo0?ooo`Sooooo0007oooooiP0oooo00<0W9co03Tio`0i
>Ol00P0i>On00?ooo`Sooooo0007oooooiP0oooo00D0W9co03Tio`0i>Ol0>CWo09bLo`200?ooo`So
oooo0007oooooiT0oooo0`0i>Ol00`3>c_l0oooo0?ooo`1n0?ooo`Sooooo0007oooooiT0oooo0`0i
>On10?ooo`Sooooo0007oooooiX0oooo00<0>CWo09bLo`3oool0P03oool8ooooo`001ooooonJ0?oo
o`0303Tio`3oool0oooo0800oooo2?ooool000OoooooVP3oool00`3>c_l0oooo0?ooo`200?ooo`So
oooo003oooooobgooooo003oooooobgooooo003oooooobgooooo003oooooobgooooo003oooooobgo
oooo003oooooobgooooo003oooooobgooooo003oooooobgooooo003oooooobgooooo003oooooobgo
oooo003oooooobgooooo003oooooobgooooo003oooooobgooooo003oooooobgooooo0000\
\>"], "Picture",
  Evaluatable->False,
  ImageSize->{100.312, 199.75},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell[TextData[{
  "Fig. 5.11 Energy flux (blue arrows) travelling up the tube created by \
adjacent rays (black lines) separated by ",
  Cell[BoxData[
      \(TraditionalForm\`d\_1\)]],
  "at the bottom and ",
  Cell[BoxData[
      \(TraditionalForm\`d\_2\)]],
  "at the top."
}], "Caption",
  CellTags->"Fig. 5.11"],

Cell[TextData[{
  "It is possible use Eq. ",
  ButtonBox["(5.3.16)",
    ButtonData:>"(5.3.16)",
    ButtonStyle->"Hyperlink"],
  " to determine how the wave amplitude varies in the above example, but to \
do so would require a specific form for the wave equation, so that a \
dispersion function ",
  Cell[BoxData[
      \(TraditionalForm\`D\)]],
  " can be constructed. (This is as opposed to the form of the dispersion ",
  StyleBox["relation",
    FontSlant->"Italic"],
  ", Eq. ",
  ButtonBox["(5.3.8)",
    ButtonData:>"(5.3.8)",
    ButtonStyle->"Hyperlink"],
  ", which is all we need to know in order to detemine the evolution of the \
phase. Several different wave equations could have this dispersion relation.) \
We leave this to the exercises. "
}], "Text",
  CellTags->"i:136"],

Cell[TextData[{
  "\tThe situation is more complex when the inhomogeneity focusses rays \
rather than causing them to diverge. Below, we repeat the previous example \
for the case where ",
  Cell[BoxData[
      FormBox[
        RowBox[{"c", "(", 
          StyleBox["r",
            FontWeight->"Bold",
            FontSlant->"Plain"], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  " is depressed in a small region rather than elevated:"
}], "Text"],

Cell[BoxData[
    \(c[r_]\  := \((1 + \ 
            Tanh[\((\((r[\([2]\)] - 2)\)^2\  + \  .2  r[\([1]\)]^2)\)*3])\)/
        2\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 5.45"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Plot3D[c[{x, y}], {x, \(-2\), 2}, {y, 0, 4}, 
        PlotRange -> {0, 3}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 5.46"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .81114 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% SurfaceGraphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
5.55112e-17 1.04977 -0.0679587 1.04977 [
[.02757 .24618 -12 -8.70276 ]
[.02757 .24618 0 .29724 ]
[.17646 .18758 -11.7989 -9 ]
[.17646 .18758 .20112 0 ]
[.3345 .12542 -5.5867 -9 ]
[.3345 .12542 .4133 0 ]
[.50253 .05935 -5.27396 -9 ]
[.50253 .05935 .72604 0 ]
[.68156 -0.01098 -4.96123 -9 ]
[.68156 -0.01098 1.03877 0 ]
[.70096 -0.00478 0 -6.26206 ]
[.70096 -0.00478 6 2.73794 ]
[.78313 .12104 0 -6.13858 ]
[.78313 .12104 6 2.86142 ]
[.8565 .23339 0 -6.03127 ]
[.8565 .23339 6 2.96873 ]
[.9224 .33431 0 -5.93715 ]
[.9224 .33431 6 3.06285 ]
[.98191 .42546 0 -5.85393 ]
[.98191 .42546 6 3.14607 ]
[.02494 .25992 -6 -2.73794 ]
[.02494 .25992 0 6.26206 ]
[.0131 .33416 -6 -2.80073 ]
[.0131 .33416 0 6.19927 ]
[.00067 .41207 -6 -2.86695 ]
[.00067 .41207 0 6.13305 ]
[-0.0124 .49393 -6 -2.93688 ]
[-0.0124 .49393 0 6.06312 ]
[ 0 0 0 0 ]
[ 1 .81114 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(-2)] .02757 .24618 1 .93395 Mshowa
.18558 .19702 m
.19014 .20174 L
s
[(-1)] .17646 .18758 .96648 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.51046 .06981 m
.51442 .07504 L
s
[(1)] .50253 .05935 .75799 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(2)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.68874 0 m
.68263 .00239 L
s
[(0)] .70096 -0.00478 -1 .39157 Mshowa
.7708 .12553 m
.76464 .12778 L
s
[(1)] .78313 .12104 -1 .36413 Mshowa
.84407 .23761 m
.83786 .23973 L
s
[(2)] .8565 .23339 -1 .34028 Mshowa
.9099 .3383 m
.90365 .34029 L
s
[(3)] .9224 .33431 -1 .31937 Mshowa
.96935 .42924 m
.96306 .43113 L
s
[(4)] .98191 .42546 -1 .30087 Mshowa
.125 Mabswid
.70593 .0263 m
.70226 .02771 L
s
.72272 .05198 m
.71904 .05338 L
s
.73912 .07706 m
.73543 .07845 L
s
.75514 .10158 m
.75145 .10294 L
s
.78611 .14895 m
.78241 .15028 L
s
.80108 .17185 m
.79737 .17317 L
s
.81573 .19425 m
.81201 .19555 L
s
.83006 .21617 m
.82633 .21745 L
s
.8578 .2586 m
.85407 .25986 L
s
.87123 .27915 m
.8675 .28039 L
s
.88439 .29928 m
.88065 .3005 L
s
.89727 .31899 m
.89353 .3202 L
s
.92227 .35722 m
.91851 .3584 L
s
.93439 .37576 m
.93063 .37693 L
s
.94627 .39394 m
.94251 .3951 L
s
.95792 .41176 m
.95416 .41291 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
.03716 .25514 m
.04327 .25274 L
s
[(0)] .02494 .25992 1 -0.39157 Mshowa
.02537 .32952 m
.03151 .3272 L
s
[(1)] .0131 .33416 1 -0.37762 Mshowa
.013 .40759 m
.01917 .40535 L
s
[(2)] .00067 .41207 1 -0.3629 Mshowa
0 .48963 m
.0062 .48748 L
s
[(3)] -0.0124 .49393 1 -0.34736 Mshowa
.125 Mabswid
.03485 .26973 m
.03852 .26831 L
s
.03251 .28447 m
.03618 .28305 L
s
.03016 .29934 m
.03383 .29793 L
s
.02778 .31436 m
.03145 .31296 L
s
.02295 .34483 m
.02663 .34345 L
s
.0205 .36029 m
.02419 .35892 L
s
.01802 .37591 m
.02172 .37454 L
s
.01552 .39167 m
.01922 .39032 L
s
.01045 .42367 m
.01416 .42234 L
s
.00788 .43991 m
.01159 .43859 L
s
.00528 .45632 m
.00899 .45501 L
s
.00265 .47289 m
.00637 .47159 L
s
.25 Mabswid
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
.40529 .59895 m
.03716 .25514 L
s
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.40529 .59895 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.39787 .81114 L
s
.39787 .81114 m
.40529 .59895 L
s
0 0 m
1 0 L
1 .81114 L
0 .81114 L
closepath
clip
newpath
.5 Mabswid
.659 .748 .916 r
.38048 .64682 .40291 .66687 .44035 .65608 .41824 .63575 Metetra
.659 .748 .916 r
.41824 .63575 .44035 .65608 .47831 .64513 .45654 .62451 Metetra
.659 .748 .916 r
.45654 .62451 .47831 .64513 .5168 .63403 .49539 .61312 Metetra
.659 .748 .916 r
.49539 .61312 .5168 .63403 .55584 .62277 .53479 .60156 Metetra
.659 .748 .916 r
.53479 .60156 .55584 .62277 .59544 .61135 .57477 .58983 Metetra
.659 .748 .916 r
.57477 .58983 .59544 .61135 .63561 .59977 .61533 .57793 Metetra
.659 .748 .916 r
.61533 .57793 .63561 .59977 .67637 .58801 .65649 .56586 Metetra
.659 .748 .916 r
.65649 .56586 .67637 .58801 .71772 .57609 .69826 .55361 Metetra
.659 .748 .916 r
.69826 .55361 .71772 .57609 .75968 .56399 .74066 .54117 Metetra
.659 .748 .916 r
.74066 .54117 .75968 .56399 .80226 .55171 .78369 .52855 Metetra
.659 .748 .916 r
.78369 .52855 .80226 .55171 .84548 .53924 .82737 .51574 Metetra
.659 .748 .916 r
.82737 .51574 .84548 .53924 .88936 .52659 .87173 .50273 Metetra
.659 .748 .916 r
.87173 .50273 .88936 .52659 .9339 .51375 .91676 .48951 Metetra
.659 .748 .916 r
.91676 .48951 .9339 .51375 .97912 .50071 .9625 .4761 Metetra
.659 .748 .916 r
.35746 .62625 .38048 .64682 .41824 .63575 .39555 .61488 Metetra
.659 .748 .916 r
.39555 .61488 .41824 .63575 .45654 .62451 .4342 .60335 Metetra
.659 .748 .916 r
.4342 .60335 .45654 .62451 .49539 .61312 .4734 .59165 Metetra
.659 .748 .916 r
.4734 .59165 .49539 .61312 .53479 .60156 .51318 .57978 Metetra
.659 .748 .916 r
.51318 .57978 .53479 .60156 .57477 .58983 .55354 .56773 Metetra
.659 .748 .916 r
.55354 .56773 .57477 .58983 .61533 .57793 .5945 .5555 Metetra
.659 .748 .916 r
.5945 .5555 .61533 .57793 .65649 .56586 .63607 .5431 Metetra
.659 .748 .916 r
.63607 .5431 .65649 .56586 .69826 .55361 .67826 .5305 Metetra
.659 .748 .916 r
.67826 .5305 .69826 .55361 .74066 .54117 .7211 .51772 Metetra
.659 .748 .916 r
.7211 .51772 .74066 .54117 .78369 .52855 .76459 .50474 Metetra
.659 .748 .916 r
.76459 .50474 .78369 .52855 .82737 .51574 .80875 .49156 Metetra
.659 .748 .916 r
.80875 .49156 .82737 .51574 .87173 .50273 .85359 .47818 Metetra
.659 .748 .916 r
.85359 .47818 .87173 .50273 .91676 .48951 .89914 .46458 Metetra
.659 .748 .916 r
.89914 .46458 .91676 .48951 .9625 .4761 .9454 .45078 Metetra
.659 .748 .916 r
.33382 .60513 .35746 .62625 .39555 .61488 .37225 .59346 Metetra
.659 .748 .916 r
.37225 .59346 .39555 .61488 .4342 .60335 .41125 .58161 Metetra
.659 .748 .916 r
.41125 .58161 .4342 .60335 .4734 .59165 .45082 .56959 Metetra
.659 .748 .916 r
.45082 .56959 .4734 .59165 .51318 .57978 .49097 .55739 Metetra
.659 .748 .916 r
.49097 .55739 .51318 .57978 .55354 .56773 .53172 .545 Metetra
.659 .748 .916 r
.53172 .545 .55354 .56773 .5945 .5555 .57308 .53243 Metetra
.659 .748 .916 r
.57308 .53243 .5945 .5555 .63607 .5431 .61507 .51967 Metetra
.659 .747 .916 r
.61507 .51967 .63607 .5431 .67826 .5305 .6577 .50672 Metetra
.659 .748 .916 r
.6577 .50672 .67826 .5305 .7211 .51772 .70099 .49358 Metetra
.659 .748 .916 r
.70099 .49358 .7211 .51772 .76459 .50474 .74495 .48024 Metetra
.659 .748 .916 r
.74495 .48024 .76459 .50474 .80875 .49156 .78959 .46668 Metetra
.659 .748 .916 r
.78959 .46668 .80875 .49156 .85359 .47818 .83493 .45291 Metetra
.659 .748 .916 r
.83493 .45291 .85359 .47818 .89914 .46458 .881 .43892 Metetra
.659 .748 .916 r
.881 .43892 .89914 .46458 .9454 .45078 .9278 .42471 Metetra
.659 .748 .916 r
.30955 .58344 .33382 .60513 .37225 .59346 .34833 .57143 Metetra
.659 .748 .915 r
.34833 .57143 .37225 .59346 .41125 .58161 .38768 .55921 Metetra
.66 .747 .915 r
.38768 .55921 .41125 .58161 .45082 .56959 .42762 .54675 Metetra
.661 .747 .914 r
.42762 .54675 .45082 .56959 .49097 .55739 .46815 .53404 Metetra
.661 .745 .913 r
.46815 .53404 .49097 .55739 .53172 .545 .5093 .52108 Metetra
.661 .743 .911 r
.5093 .52108 .53172 .545 .57308 .53243 .55106 .50796 Metetra
.66 .741 .91 r
.55106 .50796 .57308 .53243 .61507 .51967 .59347 .49476 Metetra
.658 .74 .91 r
.59347 .49476 .61507 .51967 .6577 .50672 .63653 .48152 Metetra
.657 .74 .911 r
.63653 .48152 .6577 .50672 .70099 .49358 .68027 .46819 Metetra
.657 .742 .913 r
.68027 .46819 .70099 .49358 .74495 .48024 .72471 .45468 Metetra
.657 .744 .914 r
.72471 .45468 .74495 .48024 .78959 .46668 .76985 .4409 Metetra
.658 .746 .915 r
.76985 .4409 .78959 .46668 .83493 .45291 .81572 .42683 Metetra
.658 .747 .915 r
.81572 .42683 .83493 .45291 .881 .43892 .86231 .41247 Metetra
.659 .747 .916 r
.86231 .41247 .881 .43892 .9278 .42471 .90966 .39785 Metetra
.661 .748 .914 r
.28463 .56109 .30955 .58344 .34833 .57143 .32376 .54855 Metetra
.664 .747 .912 r
.32376 .54855 .34833 .57143 .38768 .55921 .36349 .53547 Metetra
.67 .744 .906 r
.36349 .53547 .38768 .55921 .42762 .54675 .40384 .52157 Metetra
.676 .737 .896 r
.40384 .52157 .42762 .54675 .46815 .53404 .44478 .50674 Metetra
.678 .724 .884 r
.44478 .50674 .46815 .53404 .5093 .52108 .48631 .49132 Metetra
.673 .707 .873 r
.48631 .49132 .5093 .52108 .55106 .50796 .52842 .47609 Metetra
.663 .692 .867 r
.52842 .47609 .55106 .50796 .59347 .49476 .57115 .46181 Metetra
.651 .683 .867 r
.57115 .46181 .59347 .49476 .63653 .48152 .61457 .44882 Metetra
.642 .684 .874 r
.61457 .44882 .63653 .48152 .68027 .46819 .65874 .43681 Metetra
.639 .694 .885 r
.65874 .43681 .68027 .46819 .72471 .45468 .7037 .425 Metetra
.643 .711 .897 r
.7037 .425 .72471 .45468 .76985 .4409 .74941 .4126 Metetra
.649 .728 .907 r
.74941 .4126 .76985 .4409 .81572 .42683 .79586 .39922 Metetra
.654 .739 .912 r
.79586 .39922 .81572 .42683 .86231 .41247 .84304 .38497 Metetra
.657 .745 .915 r
.84304 .38497 .86231 .41247 .90966 .39785 .89097 .3701 Metetra
.668 .747 .91 r
.25903 .53791 .28463 .56109 .32376 .54855 .29856 .52433 Metetra
.68 .745 .9 r
.29856 .52433 .32376 .54855 .36349 .53547 .33875 .5091 Metetra
.696 .735 .881 r
.33875 .5091 .36349 .53547 .40384 .52157 .3796 .49144 Metetra
.704 .713 .856 r
.3796 .49144 .40384 .52157 .44478 .50674 .42102 .47166 Metetra
.697 .684 .834 r
.42102 .47166 .44478 .50674 .48631 .49132 .46292 .45156 Metetra
.679 .656 .82 r
.46292 .45156 .48631 .49132 .52842 .47609 .50529 .43313 Metetra
.658 .634 .814 r
.50529 .43313 .52842 .47609 .57115 .46181 .54822 .41748 Metetra
.637 .62 .816 r
.54822 .41748 .57115 .46181 .61457 .44882 .59185 .40494 Metetra
.618 .615 .825 r
.59185 .40494 .61457 .44882 .65874 .43681 .63633 .39524 Metetra
.606 .622 .842 r
.63633 .39524 .65874 .43681 .7037 .425 .68176 .38729 Metetra
.606 .647 .864 r
.68176 .38729 .7037 .425 .74941 .4126 .7281 .37908 Metetra
.62 .683 .887 r
.7281 .37908 .74941 .4126 .79586 .39922 .77526 .36874 Metetra
.639 .716 .904 r
.77526 .36874 .79586 .39922 .84304 .38497 .82311 .35589 Metetra
.651 .736 .912 r
.82311 .35589 .84304 .38497 .89097 .3701 .87168 .34129 Metetra
.673 .749 .908 r
.23271 .51415 .25903 .53791 .29856 .52433 .27265 .49963 Metetra
.691 .749 .895 r
.27265 .49963 .29856 .52433 .33875 .5091 .31331 .48267 Metetra
.712 .743 .876 r
.31331 .48267 .33875 .5091 .3796 .49144 .35466 .46241 Metetra
.721 .73 .858 r
.35466 .46241 .3796 .49144 .42102 .47166 .39657 .43994 Metetra
.713 .713 .849 r
.39657 .43994 .42102 .47166 .46292 .45156 .43889 .41795 Metetra
.693 .698 .85 r
.43889 .41795 .46292 .45156 .50529 .43313 .48162 .3985 Metetra
.67 .686 .857 r
.48162 .3985 .50529 .43313 .54822 .41748 .52489 .38229 Metetra
.643 .675 .865 r
.52489 .38229 .54822 .41748 .59185 .40494 .56885 .36942 Metetra
.615 .664 .874 r
.56885 .36942 .59185 .40494 .63633 .39524 .61366 .35985 Metetra
.591 .657 .883 r
.61366 .35985 .63633 .39524 .68176 .38729 .65948 .35292 Metetra
.583 .663 .893 r
.65948 .35292 .68176 .38729 .7281 .37908 .70634 .34659 Metetra
.599 .687 .904 r
.70634 .34659 .7281 .37908 .77526 .36874 .7541 .33805 Metetra
.626 .716 .911 r
.7541 .33805 .77526 .36874 .82311 .35589 .8026 .32612 Metetra
.646 .735 .914 r
.8026 .32612 .82311 .35589 .87168 .34129 .85179 .31163 Metetra
.668 .752 .913 r
.20561 .49017 .23271 .51415 .27265 .49963 .24587 .47584 Metetra
.681 .759 .91 r
.24587 .47584 .27265 .49963 .31331 .48267 .28685 .45982 Metetra
.701 .775 .909 r
.28685 .45982 .31331 .48267 .35466 .46241 .32855 .44133 Metetra
.718 .796 .913 r
.32855 .44133 .35466 .46241 .39657 .43994 .37088 .42069 Metetra
.721 .817 .925 r
.37088 .42069 .39657 .43994 .43889 .41795 .41371 .3997 Metetra
.703 .827 .941 r
.41371 .3997 .43889 .41795 .48162 .3985 .45701 .38038 Metetra
.671 .825 .957 r
.45701 .38038 .48162 .3985 .52489 .38229 .50086 .36387 Metetra
.631 .815 .971 r
.50086 .36387 .52489 .38229 .56885 .36942 .54539 .35049 Metetra
.591 .8 .979 r
.54539 .35049 .56885 .36942 .61366 .35985 .59077 .33996 Metetra
.566 .784 .981 r
.59077 .33996 .61366 .35985 .65948 .35292 .63711 .33119 Metetra
.575 .773 .973 r
.63711 .33119 .65948 .35292 .70634 .34659 .68442 .32214 Metetra
.607 .764 .955 r
.68442 .32214 .70634 .34659 .7541 .33805 .73261 .3109 Metetra
.635 .756 .935 r
.73261 .3109 .7541 .33805 .8026 .32612 .78158 .2971 Metetra
.65 .751 .923 r
.78158 .2971 .8026 .32612 .85179 .31163 .83133 .28151 Metetra
.661 .751 .917 r
.17771 .46555 .20561 .49017 .24587 .47584 .21829 .45154 Metetra
.664 .757 .919 r
.21829 .45154 .24587 .47584 .28685 .45982 .25953 .43694 Metetra
.67 .774 .927 r
.25953 .43694 .28685 .45982 .32855 .44133 .30146 .42148 Metetra
.676 .805 .944 r
.30146 .42148 .32855 .44133 .37088 .42069 .34408 .40502 Metetra
.674 .847 .966 r
.34408 .40502 .37088 .42069 .41371 .3997 .38735 .38793 Metetra
.651 .882 .982 r
.38735 .38793 .41371 .3997 .45701 .38038 .43126 .37099 Metetra
.613 .896 .988 r
.43126 .37099 .45701 .38038 .50086 .36387 .47581 .35501 Metetra
.577 .891 .989 r
.47581 .35501 .50086 .36387 .54539 .35049 .52108 .34031 Metetra
.565 .879 .992 r
.52108 .34031 .54539 .35049 .59077 .33996 .56715 .32658 Metetra
.585 .861 .995 r
.56715 .32658 .59077 .33996 .63711 .33119 .61406 .31301 Metetra
.618 .831 .982 r
.61406 .31301 .63711 .33119 .68442 .32214 .66184 .29879 Metetra
.642 .796 .956 r
.66184 .29879 .68442 .32214 .73261 .3109 .71045 .28354 Metetra
.652 .769 .934 r
.71045 .28354 .73261 .3109 .78158 .2971 .7599 .26734 Metetra
.657 .755 .922 r
.7599 .26734 .78158 .2971 .83133 .28151 .8102 .25047 Metetra
.659 .748 .916 r
.14902 .44 .17771 .46555 .21829 .45154 .18995 .42578 Metetra
.659 .75 .917 r
.18995 .42578 .21829 .45154 .25953 .43694 .23154 .4113 Metetra
.66 .754 .92 r
.23154 .4113 .25953 .43694 .30146 .42148 .2738 .39653 Metetra
.66 .764 .926 r
.2738 .39653 .30146 .42148 .34408 .40502 .31676 .38144 Metetra
.66 .779 .937 r
.31676 .38144 .34408 .40502 .38735 .38793 .36043 .36605 Metetra
.658 .797 .949 r
.36043 .36605 .38735 .38793 .43126 .37099 .40481 .35044 Metetra
.654 .811 .959 r
.40481 .35044 .43126 .37099 .47581 .35501 .44993 .3347 Metetra
.651 .816 .963 r
.44993 .3347 .47581 .35501 .52108 .34031 .49581 .31886 Metetra
.651 .81 .96 r
.49581 .31886 .52108 .34031 .56715 .32658 .54248 .30287 Metetra
.653 .795 .95 r
.54248 .30287 .56715 .32658 .61406 .31301 .58996 .28664 Metetra
.656 .777 .938 r
.58996 .28664 .61406 .31301 .66184 .29879 .63826 .27007 Metetra
.658 .763 .927 r
.63826 .27007 .66184 .29879 .71045 .28354 .68741 .25313 Metetra
.658 .754 .921 r
.68741 .25313 .71045 .28354 .7599 .26734 .73744 .23583 Metetra
.659 .75 .917 r
.73744 .23583 .7599 .26734 .8102 .25047 .78835 .21819 Metetra
.659 .748 .916 r
.11949 .41362 .14902 .44 .18995 .42578 .16078 .39899 Metetra
.659 .748 .916 r
.16078 .39899 .18995 .42578 .23154 .4113 .20276 .38412 Metetra
.659 .748 .916 r
.20276 .38412 .23154 .4113 .2738 .39653 .24542 .36901 Metetra
.659 .749 .917 r
.24542 .36901 .2738 .39653 .31676 .38144 .28879 .35365 Metetra
.659 .751 .918 r
.28879 .35365 .31676 .38144 .36043 .36605 .3329 .33802 Metetra
.659 .752 .919 r
.3329 .33802 .36043 .36605 .40481 .35044 .37774 .32213 Metetra
.659 .754 .92 r
.37774 .32213 .40481 .35044 .44993 .3347 .42335 .30598 Metetra
.659 .755 .921 r
.42335 .30598 .44993 .3347 .49581 .31886 .46974 .28955 Metetra
.659 .754 .92 r
.46974 .28955 .49581 .31886 .54248 .30287 .51694 .27284 Metetra
.659 .752 .919 r
.51694 .27284 .54248 .30287 .58996 .28664 .56496 .25584 Metetra
.659 .751 .918 r
.56496 .25584 .58996 .28664 .63826 .27007 .61383 .23854 Metetra
.659 .749 .917 r
.61383 .23854 .63826 .27007 .68741 .25313 .66358 .22093 Metetra
.659 .748 .916 r
.66358 .22093 .68741 .25313 .73744 .23583 .71421 .203 Metetra
.659 .748 .916 r
.71421 .203 .73744 .23583 .78835 .21819 .76576 .18475 Metetra
.659 .748 .916 r
.08906 .38643 .11949 .41362 .16078 .39899 .13073 .37136 Metetra
.659 .748 .916 r
.13073 .37136 .16078 .39899 .20276 .38412 .1731 .35604 Metetra
.659 .748 .916 r
.1731 .35604 .20276 .38412 .24542 .36901 .21618 .34046 Metetra
.659 .748 .916 r
.21618 .34046 .24542 .36901 .28879 .35365 .25998 .32462 Metetra
.659 .748 .916 r
.25998 .32462 .28879 .35365 .3329 .33802 .30453 .30851 Metetra
.659 .748 .916 r
.30453 .30851 .3329 .33802 .37774 .32213 .34984 .29212 Metetra
.659 .748 .916 r
.34984 .29212 .37774 .32213 .42335 .30598 .39594 .27545 Metetra
.659 .748 .916 r
.39594 .27545 .42335 .30598 .46974 .28955 .44284 .25849 Metetra
.659 .748 .916 r
.44284 .25849 .46974 .28955 .51694 .27284 .49057 .24123 Metetra
.659 .748 .916 r
.49057 .24123 .51694 .27284 .56496 .25584 .53914 .22367 Metetra
.659 .748 .916 r
.53914 .22367 .56496 .25584 .61383 .23854 .58859 .20578 Metetra
.659 .748 .916 r
.58859 .20578 .61383 .23854 .66358 .22093 .63894 .18758 Metetra
.659 .748 .916 r
.63894 .18758 .66358 .22093 .71421 .203 .6902 .16904 Metetra
.659 .748 .916 r
.6902 .16904 .71421 .203 .76576 .18475 .74241 .15016 Metetra
.659 .748 .916 r
.0577 .35841 .08906 .38643 .13073 .37136 .09976 .34287 Metetra
.659 .748 .916 r
.09976 .34287 .13073 .37136 .1731 .35604 .14252 .32707 Metetra
.659 .748 .916 r
.14252 .32707 .1731 .35604 .21618 .34046 .18601 .31101 Metetra
.659 .748 .916 r
.18601 .31101 .21618 .34046 .25998 .32462 .23025 .29466 Metetra
.659 .748 .916 r
.23025 .29466 .25998 .32462 .30453 .30851 .27525 .27804 Metetra
.659 .748 .916 r
.27525 .27804 .30453 .30851 .34984 .29212 .32104 .26112 Metetra
.659 .748 .916 r
.32104 .26112 .34984 .29212 .39594 .27545 .36763 .24391 Metetra
.659 .748 .916 r
.36763 .24391 .39594 .27545 .44284 .25849 .41505 .22639 Metetra
.659 .748 .916 r
.41505 .22639 .44284 .25849 .49057 .24123 .46332 .20856 Metetra
.659 .748 .916 r
.46332 .20856 .49057 .24123 .53914 .22367 .51246 .1904 Metetra
.659 .748 .916 r
.51246 .1904 .53914 .22367 .58859 .20578 .5625 .17191 Metetra
.659 .748 .916 r
.5625 .17191 .58859 .20578 .63894 .18758 .61346 .15309 Metetra
.659 .748 .916 r
.61346 .15309 .63894 .18758 .6902 .16904 .66536 .13391 Metetra
.659 .748 .916 r
.66536 .13391 .6902 .16904 .74241 .15016 .71824 .11438 Metetra
.659 .748 .916 r
.02537 .32952 .0577 .35841 .09976 .34287 .06781 .3135 Metetra
.659 .748 .916 r
.06781 .3135 .09976 .34287 .14252 .32707 .11098 .2972 Metetra
.659 .748 .916 r
.11098 .2972 .14252 .32707 .18601 .31101 .15489 .28061 Metetra
.659 .748 .916 r
.15489 .28061 .18601 .31101 .23025 .29466 .19957 .26374 Metetra
.659 .748 .916 r
.19957 .26374 .23025 .29466 .27525 .27804 .24503 .24658 Metetra
.659 .748 .916 r
.24503 .24658 .27525 .27804 .32104 .26112 .2913 .2291 Metetra
.659 .748 .916 r
.2913 .2291 .32104 .26112 .36763 .24391 .3384 .21132 Metetra
.659 .748 .916 r
.3384 .21132 .36763 .24391 .41505 .22639 .38634 .19322 Metetra
.659 .748 .916 r
.38634 .19322 .41505 .22639 .46332 .20856 .43516 .17478 Metetra
.659 .748 .916 r
.43516 .17478 .46332 .20856 .51246 .1904 .48488 .15601 Metetra
.659 .748 .916 r
.48488 .15601 .51246 .1904 .5625 .17191 .53551 .13689 Metetra
.659 .748 .916 r
.53551 .13689 .5625 .17191 .61346 .15309 .5871 .11741 Metetra
.659 .748 .916 r
.5871 .11741 .61346 .15309 .66536 .13391 .63966 .09756 Metetra
.659 .748 .916 r
.63966 .09756 .66536 .13391 .71824 .11438 .69323 .07733 Metetra
0 g
.25 Mabswid
.68874 0 m
.96935 .42924 L
s
.96935 .42924 m
1 .6535 L
s
1 .6535 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.03716 .25514 m
0 .48963 L
s
0 .48963 m
.70298 .24544 L
s
.70298 .24544 m
.68874 0 L
s
.68874 0 m
.03716 .25514 L
s
.03716 .25514 m
.68874 0 L
s
.03716 .25514 m
.04196 .25962 L
s
[(-2)] .02757 .24618 1 .93395 Mshowa
.18558 .19702 m
.19014 .20174 L
s
[(-1)] .17646 .18758 .96648 1 Mshowa
.34306 .13535 m
.34735 .14032 L
s
[(0)] .3345 .12542 .86223 1 Mshowa
.51046 .06981 m
.51442 .07504 L
s
[(1)] .50253 .05935 .75799 1 Mshowa
.68874 0 m
.69233 .00549 L
s
[(2)] .68156 -0.01098 .65374 1 Mshowa
.125 Mabswid
.06616 .24378 m
.06901 .2465 L
s
.09549 .2323 m
.09832 .23504 L
s
.12517 .22067 m
.12797 .22345 L
s
.1552 .20892 m
.15797 .21172 L
s
.21633 .18498 m
.21903 .18784 L
s
.24744 .1728 m
.25012 .17569 L
s
.27893 .16047 m
.28157 .16339 L
s
.3108 .14799 m
.31341 .15094 L
s
.37572 .12257 m
.37826 .12558 L
s
.40878 .10962 m
.41128 .11266 L
s
.44225 .09652 m
.44471 .09959 L
s
.47614 .08324 m
.47856 .08635 L
s
.54521 .0562 m
.54755 .05937 L
s
.58041 .04242 m
.5827 .04562 L
s
.61605 .02846 m
.6183 .03169 L
s
.65216 .01432 m
.65436 .01759 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 233.562},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X00018b000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00l?ooool5o`0007?ooooo003`ooooo`05oiRHV?lQ8B7ok^k^oooooom4
A4@0Loooool00?7ooooo00?oV9RHob4Q8Oo^k^h0M?ooool00?;ooooo00?oV9RHob4Q8Oo^k^h0Looo
ool00??ooooo00?oMgMgofIVI_ooool0L_ooool00?Cooooo00?o0000ooooooooool0LOooool00?3o
oooo00Go0000okZj^_ooooooV9RHoa0@4009ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0IOooool0
0?3ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c009ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0IOoo
ool00?kooooo00Go410@oooooooooooooooooa0@401Uooooo`00o_ooool01Ol0003ooooooooooooo
oooo000006Gooooo003nooooo`05o`000?ooooooooooooooool00000IOooool00?kooooo00Go410@
oooooooooooooooooa0@401Uooooo`00o_ooool01OmgMgOoV9RHoooooonHV9SoMgMg06Gooooo003f
ooooo`Co00001?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^06Gooooo003dooooo`?o000000Cooooo
o`000?oooooo0000KOooool00?;ooooo0_l00004ooooo`;o0000K_ooool00>oooooo0ol00006oooo
o`03o`000?oooooo000006gooooo003/ooooo`?o00002Oooool00ol0003oooooo`00001]ooooo`00
j_ooool3o`0000_ooooo00Co0000oooooooooooo0000K?ooool00>Oooooo0ol00003ooooo`03o`00
0?oooooooooo00Sooooo00Go0000ooooooooooooooooo`00001[ooooo`00iOooool2o`00017ooooo
00Go0000ooooooooooooooooo`00001[ooooo`00h_ooool3o`0001?ooooo00?o0000ooooooooool0
0_ooool2o`0006Wooooo003Pooooo`;o00005oooool01?l0003oooooooooooooool2o`0006Wooooo
003Mooooo`Co00006?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo06Oooooo002d
ooooo`Co000000?o410@ooooooooool07oooool3o`0001cooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`1Vooooo`00]_ooool00ol0003oooooooooo`0Oooooo`;o00007oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo06Gooooo002fooooo`03o`000?oooooooooo01co
oooo0ol0000Qooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0IOooool00;Kooooo
00?o0000ooooooooool06_ooool2o`0002Cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`1Tooooo`00]_ooool00ol0003oooooooooo`0Gooooo`?o000000?oooooo`000?ooool08ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo06?ooooo002fooooo`03o`000?oooooo
oooo01Gooooo0_l0000Yooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Hoooool0
0;Kooooo00?o0000ooooooooool04_ooool3o`0002_ooooo00?o0000ooooooooool01oooool2o`00
06?ooooo002dooooo`03oeEEEOmVIVKo0000017ooooo0ol0000^ooooo`03o`000?oooooooooo00Oo
oooo0_l0001Sooooo`00a_ooool3o`00033ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`1Qooooo`00`oooool3o`0000;ooooo00?o0000ooooooooool0;_ooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo063ooooo0031ooooo`;o0000=_ooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo063ooooo002nooooo`?o0000>?ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo05oooooo002looooo`;o0000>oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo05kooooo002iooooo`Co0000??ooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo05kooooo002fooooo`?o00001?ooool00ol0003oooooooooo`0iooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool0GOooool00;Cooooo0_l00013ooooo`;o00003Oooool3
o`0005gooooo002aooooo`?o0000@_ooool3o`000003ojRoj_l0003ooooo00gooooo00?o0000oooo
ooooool0G?ooool00:oooooo0_l00013ooooo`;o00001?nX_nX2o`0000kooooo00?o0000oooooooo
ool0Foooool00:cooooo0ol00002ooooo`03o`000?oooooooooo03gooooo0ol00006ojRojP03o`00
0?nX_n[o000000kooooo00?o0000ooooooooool0F_ooool00:[ooooo0_l00012ooooo`?o00002OnX
_nX00ol0003oZ;oZo`00000>ooooo`03o`000?oooooooooo05[ooooo002Wooooo`?o0000@_ooool2
o`0000coZ;oZ00Co0000ojRoj_nX_n[o00003_ooool00ol0003oooooooooo`1Iooooo`00Y?ooool3
o`0004;ooooo0ol0000>ojRojP05o`000?nX_n[oZ;oZojRoj_l000003_ooool00ol0003ooooooooo
o`1Hooooo`00NOooool01Oo^k^ko<S8bo`000?lb<S;ok^k^02Cooooo0_l000000ooooooo0000oooo
o`10ooooo`;o00004OnX_nX01Ol0003oZ;oZojRoj_nX_n[o000000kooooo00?o0000ooooooooool0
F?ooool007Wooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Qooooo`?o0000@_ooool3o`000003ojRo
j_l0003oZ;oZ013oZ;oZ00?o0000ojRoj_nX_nX00_nX_nX00ol0003oooooooooo`0<ooooo`;o0000
F?ooool007Wooooo00Go410@oooooooooooooooooa0@400Oooooo`;o0000@_ooool3o`0000GoZ;oZ
00?o0000ojRoj_nX_nX03_nX_nX00ol0003oZ;oZojRojP03ojRojP03o`000?oooooooooo00_ooooo
0_l0001Hooooo`00NOooool01Ol0003ooooooooooooooooo000001cooooo0ol00011ooooo`?o0000
2OnX_nX00ol0003oZ;oZojRojP0=ojRojP03o`000?nX_n[oZ;oZ00?oZ;oZ00?o0000ooooooooool0
3?ooool00ol0003oooooooooo`09ooooo`Co000000?o410@ooooooooool0A_ooool007Wooooo00Go
0000ooooooooooooooooo`00000Jooooo`;o0000@Oooool3o`0000coZ;oZ00?o0000ojRoj_nX_nX0
3OnX_nX00ol0003oZ;oZojRojP04ojRojP03o`000?oooooooooo00cooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`18ooooo`00NOooool01Ol@413ooooooooooooooooo410@01Oooooo
0ol00002ooooo`03o`000?oooooooooo03_ooooo0ol0000@ojRojP03o`000?nX_n[oZ;oZ00coZ;oZ
00?o0000ojRoj_nX_nX01?nX_nX2o`0000kooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`18ooooo`00NOooool01OmgMgOoV9RHoooooonHV9SoMgMg01Cooooo0ol00010ooooo`?o0000
5?nX_nX00ol0003oZ;oZojRojP0;ojRojP04o`000?nX_n[oZ;oZojRojP?o000000?oZ;oZo`000?oo
ool03Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo04Sooooo001iooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h04_ooool2o`00043ooooo0ol000000onX_n[o0000ojRojP0DojRojP03
o`000?nX_n[oZ;oZ00_oZ;oZ00Co0000ojRoj_l0003o00001OnX_nX00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0B?ooool008gooooo0ol00010ooooo`;o
00001OnX_nX00ol0003oZ;oZojRojP0CojRojP03o`000?nX_n[oZ;oZ00WoZ;oZ0ol00008ojRojP03
o`000?oooooooooo00cooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`18ooooo`00
Roooool2o`0000;ooooo00?o0000ooooooooool0>oooool3o`0000SoZ;oZ00?o0000ojRoj_nX_nX0
4onX_nX00ol0003oZ;oZojRojP05ojRojP?o00000_nX_nX00ol0003oZ;oZojRojP06ojRojP03o`00
0?oooooooooo00cooooo0_l00008ooooo`03o`000?oooooooooo04Sooooo0028ooooo`?o0000?ooo
ool3o`0000_oZ;oZ00?o0000ojRoj_nX_nX04onX_nX00ol0003oZ;oZojRojP03ojRojP;o00001OnX
_nX00ol0003oZ;oZojRojP07ojRojP03o`000?oooooooooo00[ooooo00?o0000ooooool000001_oo
ool00omEEEGoIVIVo`00001:ooooo`00Q_ooool2o`00043ooooo0_l0000?ojRojP03o`000?nX_n[o
Z;oZ01?oZ;oZ00?o0000ojRoj_l000000_l00007ojRojP03o`000?nX_n[oZ;oZ00SoZ;oZ00?o0000
ooooooooool03?ooool00ol0003oooooooooo`1@ooooo`00Poooool3o`0003oooooo0ol0000BojRo
jP03o`000?nX_n[oZ;oZ01;oZ;oZ0_l0000:ojRojP03o`000?nX_n[oZ;oZ00WoZ;oZ00?o0000oooo
ooooool02oooool00ol0003oooooooooo`1@ooooo`00POooool3o`0003oooooo0_l0000FojRojP03
o`000?nX_n[oZ;oZ00koZ;oZ0ol000000onX_n[o0000ojRojP09ojRojP03o`000?nX_n[oZ;oZ00Wo
Z;oZ00?o0000ooooooooool03?ooool00ol0003oooooooooo`1?ooooo`00O_ooool3o`0000?ooooo
00?o0000ooooooooool0>Oooool3o`000003ojRoj_l0003oZ;oZ01GoZ;oZ00?o0000ojRoj_nX_nX0
3?nX_nX2o`0000GoZ;oZ00?o0000ojRoj_nX_nX01onX_nX00ol0003oZ;oZojRojP0:ojRojP03o`00
0?oooooooooo00cooooo00?o0000ooooooooool0C_ooool007_ooooo0ol00010ooooo`;o00001OnX
_nX00ol0003oZ;oZojRojP0DojRojP03o`000?nX_n[oZ;oZ00SoZ;oZ0ol00008ojRojP03o`000?nX
_n[oZ;oZ00KoZ;oZ00?o0000ojRoj_nX_nX02onX_nX00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo04kooooo001iooooo`;o0000@?ooool3o`0000SoZ;oZ00?o0000ojRoj_nX_nX05?nX_nX0
0ol0003oZ;oZojRojP05ojRojP;o00003?nX_nX00ol0003oZ;oZojRojP05ojRojP03o`000?nX_n[o
Z;oZ00_oZ;oZ00?o0000ooooooooool03?ooool00ol0003oooooooooo`1=ooooo`00M_ooool3o`00
043ooooo0_l0000<ojRojP03o`000?nX_n[oZ;oZ01?oZ;oZ00?o0000ojRoj_nX_nX00onX_nX2o`00
00koZ;oZ00?o0000ojRoj_nX_nX01OnX_nX00ol0003oZ;oZojRojP0<ojRojP03o`000?oooooooooo
00cooooo0_l0001=ooooo`00M?ooool2o`0000?ooooo00?o0000ooooooooool0>oooool2o`0000ko
Z;oZ00?o0000ojRoj_nX_nX05?nX_nX00ol0003oZ;oZo`000002o`00017oZ;oZ00?o0000ojRoj_nX
_nX01?nX_nX00ol0003oZ;oZojRojP0<ojRojP;o00003?ooool2o`0004kooooo001aooooo`?o0000
@?ooool3o`00017oZ;oZ00?o0000ojRoj_nX_nX04onX_nX2o`0001GoZ;oZ00?o0000ojRoj_nX_nX0
0onX_nX00ol0003oZ;oZojRojP09ojRojP?o000000?oZ;oZo`000?ooool03Oooool00ol0003ooooo
ooooo`1;ooooo`00Koooool2o`00047ooooo0_l0000EojRojP03o`000?nX_n[oZ;oZ00ooZ;oZ0ol0
00000onX_n[o0000ojRojP0EojRojP03o`000?nX_n[oZ;oZ00;oZ;oZ00?o0000ojRoj_nX_nX01_nX
_nX3o`0000GoZ;oZ00?o0000ooooooooool03?ooool00ol0003oooooooooo`1:ooooo`00A?ooool4
o`000003oa0@4?oooooooooo027ooooo0ol00010ooooo`?o000000?oZ;oZo`000?nX_nX05OnX_nX0
0ol0003oZ;oZojRojP0;ojRojP?o00001OnX_nX00ol0003oZ;oZojRojP0CojRojP03o`000?nX_n[o
Z;oZ00;oZ;oZ00?o0000ojRoj_nX_nX00onX_nX3o`0000WoZ;oZ00?o0000ooooooooool02oooool0
0ol0003oooooooooo`1:ooooo`00A_ooool00ol0003oooooooooo`0Pooooo`?o00000_ooool00ol0
003oooooooooo`0kooooo`?o00001OnX_nX00ol0003oZ;oZojRojP0CojRojP03o`000?nX_n[oZ;oZ
00SoZ;oZ0ol00009ojRojP03o`000?nX_n[oZ;oZ01?oZ;oZ00Go0000ojRoj_nX_n[oZ;oZo`000002
ojRojP?o00003OnX_nX00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo04Wooooo000koooo
o`Ko00001Oooool00ol0003oooooooooo`0Nooooo`;o0000@?ooool3o`0000WoZ;oZ00?o0000ojRo
j_nX_nX04onX_nX00ol0003oZ;oZojRojP04ojRojP?o00003OnX_nX00ol0003oZ;oZojRojP0CojRo
jP03o`000?nX_n[oZ;oZ00?o00004?nX_nX00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
04Wooooo0016ooooo`03o`000?oooooooooo01_ooooo0ol0000oooooo`?o00003OnX_nX00ol0003o
Z;oZojRojP0CojRojP03o`000?nX_n[oZ;oZ00?o00004?nX_nX00ol0003oZ;oZojRojP0CojRojPCo
00004onX_nX00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo04Sooooo0016ooooo`03o`00
0?oooooooooo01Wooooo0_l0000oooooo`?o00004OnX_nX00ol0003oZ;oZojRojP0BojRojP?o0000
5?nX_nX00ol0003oZ;oZojRojP0?ojRojP?o000000CoZ;oZo`000?nX_n[o00005?nX_nX00ol0003o
ooooooooo`0:ooooo`?o0000B?ooool004Kooooo00?o0000ooooooooool05_ooool3o`000003oooo
ool0003ooooo03cooooo0_l0000EojRojP03o`000?nX_n[oZ;oZ00koZ;oZ0ol000000onX_n[o0000
ojRojP0EojRojP03o`000?nX_n[oZ;oZ00_oZ;oZ0ol00005ojRojP03o`000?nX_n[o000001?oZ;oZ
00?o0000ooooooooool02oooool00ol0003oooooooooo`17ooooo`00A_ooool00ol0003ooooooooo
o`0Dooooo`;o0000?oooool3o`000003ojRoj_l0003oZ;oZ01CoZ;oZ00?o0000ojRoj_nX_nX02onX
_nX3o`0000GoZ;oZ00?o0000ojRoj_nX_nX04onX_nX00ol0003oZ;oZojRojP08ojRojP?o00002OnX
_nX2o`0001CoZ;oZ00?o0000ooooooooool02oooool00ol0003oooooooooo`16ooooo`00A?ooool0
0omEEEGoIVIVo`00000Cooooo`?o0000?_ooool3o`0000GoZ;oZ00?o0000ojRoj_nX_nX04onX_nX0
0ol0003oZ;oZojRojP07ojRojP?o00002OnX_nX00ol0003oZ;oZojRojP0CojRojP03o`000?nX_n[o
Z;oZ00CoZ;oZ0ol0000<ojRojP;o00005OnX_nX00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo04Gooooo001Gooooo`?o0000?oooool2o`0000WoZ;oZ00?o0000ojRoj_nX_nX04onX_nX00ol0
003oZ;oZojRojP03ojRojP?o00003OnX_nX00ol0003oZ;oZojRojP0CojRojP03o`000?nX_n[oZ;oZ
00?o00004?nX_nX00ol0003oZ;oZojRojP0CojRojP;o00003?ooool00ol0003oooooooooo`15oooo
o`00EOooool2o`0000;ooooo00?o0000ooooooooool0>_ooool3o`0000coZ;oZ00?o0000ojRoj_nX
_nX04onX_nX00ol0003oZ;oZo`000002o`00013oZ;oZ00?o0000ojRoj_nX_nX04onX_nX3o`0001?o
Z;oZ0_l0000AojRojP?o000000?oZ;oZo`000?ooool03?ooool00ol0003oooooooooo`14ooooo`00
D_ooool3o`0003kooooo0ol0000@ojRojP03o`000?nX_n[oZ;oZ01;oZ;oZ0_l0000DojRojP03o`00
0?nX_n[oZ;oZ00ooZ;oZ0ol000000onX_n[o0000ojRojP0CojRojP;o00003onX_nX2o`0000GoZ;oZ
00?o0000ooooooooool02oooool00ol0003oooooooooo`13ooooo`00D?ooool2o`0003oooooo0_l0
000DojRojP03o`000?nX_n[oZ;oZ00koZ;oZ0ol000000onX_n[o0000ojRojP0DojRojP03o`000?nX
_n[oZ;oZ00coZ;oZ0_l00005ojRojP03o`000?nX_n[oZ;oZ017oZ;oZ00?o0000ojRoj_l000002onX
_nX3o`0000OoZ;oZ00?o0000ooooooooool02oooool00ol0003oooooooooo`13ooooo`00COooool3
o`0003kooooo0ol000000onX_n[o0000ojRojP0DojRojP03o`000?nX_n[oZ;oZ00[oZ;oZ0ol00005
ojRojP03o`000?nX_n[oZ;oZ01?oZ;oZ00?o0000ojRoj_nX_nX02?nX_nX3o`0000SoZ;oZ00?o0000
ojRoj_nX_nX04?nX_nX01?l0003oZ;oZojRoj_l00007ojRojP?o00002onX_nX00ol0003ooooooooo
o`0:ooooo`?o0000@oooool004_ooooo1?l0000looooo`?o00001OnX_nX00ol0003oZ;oZojRojP0C
ojRojP03o`000?nX_n[oZ;oZ00OoZ;oZ0_l00009ojRojP03o`000?nX_n[oZ;oZ01;oZ;oZ00?o0000
ojRoj_nX_nX01_nX_nX2o`0000coZ;oZ00?o0000ojRoj_nX_nX03onX_nX01?l0003oZ;oZojRoj_l0
0005ojRojP;o00003onX_nX00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo047ooooo0018
ooooo`?o00001?ooool00ol0003oooooooooo`0fooooo`?o00002OnX_nX00ol0003oZ;oZojRojP0C
ojRojP03o`000?nX_n[oZ;oZ00?oZ;oZ0ol0000<ojRojP03o`000?nX_n[oZ;oZ01;oZ;oZ00?o0000
ojRoj_nX_nX00onX_nX2o`0000koZ;oZ00?o0000ojRoj_nX_nX03onX_nX01_l0003oZ;oZojRoj_nX
_n[o0000ojRojP?o00004OnX_nX00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo047ooooo
0015ooooo`?o0000?Oooool3o`0000goZ;oZ00?o0000ojRoj_nX_nX04onX_nX00ol0003oZ;oZo`00
0002o`00013oZ;oZ00?o0000ojRoj_nX_nX04_nX_nX00ol0003oZ;oZo`000002o`00017oZ;oZ00?o
0000ojRoj_nX_nX03_nX_nX01?l0003oZ;oZojRoj_nX_nX2o`0001GoZ;oZ00?o0000ooooooooool0
2oooool00ol0003oooooooooo`10ooooo`00@oooool2o`0003gooooo0ol0000@ojRojP03o`000?nX
_n[oZ;oZ01?oZ;oZ0_l0000DojRojP03o`000?nX_n[oZ;oZ017oZ;oZ0_l0000EojRojP03o`000?nX
_n[oZ;oZ00goZ;oZ1?l000000onX_n[o0000ojRojP0DojRojP03o`000?oooooooooo00cooooo00?o
0000ooooooooool0?oooool0043ooooo1?l0000looooo`;o00005?nX_nX00ol0003oZ;oZojRojP0?
ojRojP?o000000?oZ;oZo`000?nX_nX04onX_nX00ol0003oZ;oZojRojP0>ojRojP?o000000?oZ;oZ
o`000?nX_nX05OnX_nX00ol0003oZ;oZojRojP0:ojRojP?o00001OnX_nX00ol0003oZ;oZojRojP0C
ojRojP03o`000?oooooooooo00_ooooo00?o0000ooooooooool0?oooool003kooooo0_l00004oooo
o`03o`000?oooooooooo03Kooooo0ol000000onX_n[o0000ojRojP0DojRojP03o`000?nX_n[oZ;oZ
00coZ;oZ0_l00005ojRojP03o`000?nX_n[oZ;oZ01;oZ;oZ00?o0000ojRoj_nX_nX02_nX_nX3o`00
00GoZ;oZ00?o0000ojRoj_nX_nX04onX_nX00ol0003oZ;oZojRojP07ojRojP?o00000_nX_nX00ol0
003oZ;oZojRojP04ojRojP03o`000?nX_n[oZ;oZ01?oZ;oZ00?o0000ooooooooool02oooool00ol0
003oooooooooo`0nooooo`00>oooool3o`0003cooooo0ol00005ojRojP03o`000?nX_n[oZ;oZ01?o
Z;oZ00?o0000ojRoj_nX_nX02?nX_nX3o`0000SoZ;oZ00?o0000ojRoj_nX_nX04_nX_nX00ol0003o
Z;oZojRojP07ojRojP;o00002OnX_nX00ol0003oZ;oZojRojP0CojRojP03o`000?nX_n[oZ;oZ00?o
Z;oZ0ol00005ojRojP03o`000?nX_n[oZ;oZ00GoZ;oZ00?o0000ojRoj_nX_nX04_nX_nX00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo03gooooo000iooooo`;o0000?Oooool2o`0000WoZ;oZ
00?o0000ojRoj_nX_nX04_nX_nX00ol0003oZ;oZojRojP06ojRojP;o00003?nX_nX00ol0003oZ;oZ
ojRojP0BojRojP03o`000?nX_n[oZ;oZ00?oZ;oZ0ol0000<ojRojP03o`000?nX_n[oZ;oZ01?oZ;oZ
00?o0000ojRoj_l000000_l00008ojRojP03o`000?nX_n[oZ;oZ00GoZ;oZ00?o0000ojRoj_nX_nX0
4_nX_nX2o`0000cooooo0_l00009ooooo`Go0000<Oooool0013ooooo1Ol0000Qooooo`Co0000>ooo
ool3o`0000coZ;oZ00?o0000ojRoj_nX_nX04_nX_nX00ol0003oZ;oZojRojP03ojRojP;o00003_nX
_nX00ol0003oZ;oZojRojP0CojRojP03o`000?nX_n[o000000;o00004?nX_nX00ol0003oZ;oZojRo
jP0BojRojP;o00002onX_nX00ol0003oZ;oZojRojP06ojRojP03o`000?nX_n[oZ;oZ00koZ;oZ0ol0
00000onX_n[o0000ooooo`0=ooooo`03o`000?oooooooooo00Kooooo00GoV9RHob4Q8Oo^k^kooooo
odA4A00aooooo`004?ooool01OnHV9So8B4Qonk^k_ooooooA4A401kooooo0ol00004ooooo`03o`00
0?oooooooooo03Gooooo0ol0000@ojRojP03o`000?nX_n[oZ;oZ01;oZ;oZ00?o0000ojRoj_l00000
0_l0000AojRojP03o`000?nX_n[oZ;oZ01;oZ;oZ0_l0000DojRojP03o`000?nX_n[oZ;oZ00koZ;oZ
0ol000000onX_n[o0000ojRojP0;ojRojP03o`000?nX_n[oZ;oZ00KoZ;oZ00?o0000ojRoj_nX_nX0
2_nX_nX3o`0000GoZ;oZ00?o0000ooooooooool03?ooool00ol0003oooooooooo`06ooooo`03oiRH
V?lQ8B7ok^k^03;ooooo0008ooooo`Ko00000oooool00onHV9So8B4Qonk^kP0Mooooo`;o0000?Ooo
ool2o`0001CoZ;oZ00?o0000ojRoj_nX_nX04OnX_nX2o`0001GoZ;oZ00?o0000ojRoj_nX_nX03_nX
_nX3o`000003ojRoj_l0003oZ;oZ01?oZ;oZ00?o0000ojRoj_nX_nX02onX_nX3o`0000GoZ;oZ00?o
0000ojRoj_nX_nX02OnX_nX00ol0003oZ;oZojRojP06ojRojP03o`000?nX_n[oZ;oZ00OoZ;oZ0ol0
0009ojRojP03o`000?oooooooooo00_ooooo00?o0000ooooooooool01oooool00onHV9So8B4Qonk^
kP0aooooo`004_ooool00onHV9So8B4Qonk^kP0Iooooo`?o0000??ooool3o`000003ojRoj_l0003o
Z;oZ01?oZ;oZ00?o0000ojRoj_nX_nX03_nX_nX3o`0000;oZ;oZ00?o0000ojRoj_nX_nX04onX_nX0
0ol0003oZ;oZojRojP0:ojRojP?o00001OnX_nX00ol0003oZ;oZojRojP0BojRojP03o`000?nX_n[o
Z;oZ00OoZ;oZ0ol00009ojRojP03o`000?nX_n[oZ;oZ00SoZ;oZ00?o0000ojRoj_nX_nX01onX_nX0
0ol0003oZ;oZojRojP03ojRojP?o00003OnX_nX00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00Oooooo00?oMgMgofIVI_ooool0<?ooool001?ooooo00?oMgMgofIVI_ooool05_ooool2o`00
0003ooooool0003ooooo03Wooooo0ol00005ojRojP03o`000?nX_n[oZ;oZ01;oZ;oZ00?o0000ojRo
j_nX_nX02_nX_nX3o`0000KoZ;oZ00?o0000ojRoj_nX_nX04_nX_nX00ol0003oZ;oZojRojP07ojRo
jP?o00002OnX_nX00ol0003oZ;oZojRojP0BojRojP03o`000?nX_n[oZ;oZ00?oZ;oZ0ol0000=ojRo
jP03o`000?nX_n[oZ;oZ00OoZ;oZ00?o0000ojRoj_nX_nX02?nX_nX00ol0003oZ;oZo`000002o`00
013oZ;oZ00?o0000ooooooooool03?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
02oooooo000Dooooo`03o`000?oooooooooo01;ooooo0ol00004ooooo`03o`000?oooooooooo03Go
oooo0_l00009ojRojP03o`000?nX_n[oZ;oZ01;oZ;oZ00?o0000ojRoj_nX_nX01onX_nX2o`0000[o
Z;oZ00?o0000ojRoj_nX_nX04_nX_nX00ol0003oZ;oZojRojP03ojRojP?o00003OnX_nX00ol0003o
Z;oZojRojP0BojRojP03o`000?nX_n[o000000;o00004?nX_nX00ol0003oZ;oZojRojP07ojRojP03
o`000?nX_n[oZ;oZ00SoZ;oZ0_l0000DojRojP03o`000?oooooooooo00_ooooo0_l00004ooooo`05
o`000?nj^[[ooooooiRHV?l@4100<Oooool0013ooooo00Go0000okZj^_ooooooV9RHoa0@400Boooo
o`;o0000??ooool3o`0000coZ;oZ00?o0000ojRoj_nX_nX04_nX_nX00ol0003oZ;oZojRojP03ojRo
jP?o00003OnX_nX00ol0003oZ;oZojRojP0BojRojP03o`000?nX_n[o000000;o00004?nX_nX00ol0
003oZ;oZojRojP0BojRojP;o00005?nX_nX00ol0003oZ;oZojRojP06ojRojP03o`000?nX_n[oZ;oZ
00GoZ;oZ0ol000000onX`N_o0000ojRojP0DojRojP03o`000?oooooooooo00Wooooo00?o0000oooo
ool000001?ooool01OnHV9So410@o`000?lQ8B7oc<c<037ooooo000@ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`03oooool3o`0003_ooooo0ol0000@ojRojP03o`000?nX_n[oZ;oZ01;oZ;oZ00?o0000
ojRoj_l000000_l0000AojRojP03o`000?nX_n[oZ;oZ013oZ;oZ0ol0000DojRojP03o`000?nX_n[o
Z;oZ00koZ;oZ0ol000000onX`>_o0000ojRojP0DojRojP03o`000?nX_n[oZ;oZ00GoZ;oZ00?o0000
ojRoj_nX_nX00_nX_nX3o`0000GoZ<7[00?o0000ojRoj_nX_nX04_nX_nX00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo03Oooooo000Qooooo`?o00000_ooool00ol0003oooooooooo`0goooo
o`;o00005?nX_nX00ol0003oZ;oZojRojP0@ojRojP?o00005OnX_nX00ol0003oZ;oZojRojP0<ojRo
jP?o00000_nX_nX00ol0003oZ;oZojRojP0CojRojP03o`000?nX_n[oZ;oZ00[oZ;oZ0ol00005ojS0
j`03o`000?nX_n[oZ;oZ01;oZ;oZ00?o0000ojRoj_nX_nX01?nX_nX2o`000004ojRoj_l0003o0000
o`0000WoZ<7[00?o0000ojRoj_nX_nX04_nX_nX00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo03Oooooo000Oooooo`;o0000??ooool3o`0000;oZ;oZ00?o0000ojRoj_nX_nX04_nX_nX00ol0
003oZ;oZojRojP0<ojRojP?o00000onX_nX00ol0003oZ;oZojRojP0CojRojP03o`000?nX_n[oZ;oZ
00SoZ;oZ0ol00006ojRojP03o`000?nX_n[oZ;oZ01;oZ;oZ00?o0000ojRoj_nX_nX01onX_nX3o`00
00WoZ<3[00?o0000ojRoj_nX_nX04_nX_nX00ol0003oZ;oZojRojP06o`0000goZ<7[00?o0000ojRo
j_nX_nX04_nX_nX00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03Kooooo000Looooo`?o
0000??ooool2o`0000KoZ;oZ00?o0000ojRoj_nX_nX04_nX_nX00ol0003oZ;oZojRojP08ojRojP?o
00001onX_nX00ol0003oZ;oZojRojP0CojRojP03o`000?nX_n[oZ;oZ00CoZ;oZ0ol0000:ojRojP03
o`000?nX_n[oZ;oZ01;oZ;oZ00?o0000ojRoj_nX_nX00onX_nX3o`0000goZ<3[00?o0000ojRoj_nX
_nX04OnX_nX6o`0000;oZ<7[00?o0000ojS1jonX`N/03?nX`N/00ol0003oZ;oZojRojP0@ojRojP?o
00003Oooool00ol0003oooooooooo`0eooooo`006oooool3o`0003[ooooo0ol00009ojRojP03o`00
0?nX_n[oZ;oZ01;oZ;oZ00?o0000ojRoj_nX_nX01?nX_nX3o`0000_oZ;oZ00?o0000ojRoj_nX_nX0
4onX_nX00ol0003oZ;oZojRojP03o`0000koZ;oZ00?o0000ojRoj_nX_nX04_nX_nX00ol0003oZ;oZ
o`000002o`00017oZ<3[00?o0000ojRoj_nX_nX03OnX_nX6o`0000KoZ<7[00?o0000ojS1jonX`N/0
2onX`N/00ol0003oZ;oZojRojP0=ojRojP?o00000_nX`N`00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo03Gooooo000Kooooo`03o`000?oooooo000003Sooooo0_l0000=ojRojP03o`000?nX
_n[oZ;oZ01;oZ;oZ00?o0000ojRoj_nX_nX00ol0000?ojRojP03o`000?nX_n[oZ;oZ01;oZ;oZ0ol0
000BojRojP03o`000?nX_n[oZ;oZ013oZ;oZ0ol0000DojS0j`03o`000?nX_n[oZ;oZ00[oZ;oZ1_l0
0002ojS3k@03o`000?nX`N_oZ<7[00GoZ<7[00?o0000ojS1jonX`N/02onX`N/00ol0003oZ;oZojRo
jP08ojRojPCo00001_nX`N`00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo03Cooooo000@
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool2o`000003ooooool0003ooooo03?ooooo0ol0
000@ojRojP03o`000?nX_n[oZ;oZ017oZ;oZ0ol0000CojRojP03o`000?nX_n[oZ;oZ00koZ;oZ0ol0
00000onX_n[o0000ojRojP0CojRojP03o`000?nX_n[oZ;oZ00coZ;oZ0ol00002ojS0j`03o`000?nX
`>_oZ<3[01?oZ<3[00?o0000ojRoj_nX_nX01_nX_nX6o`0000KoZ<?]00?o0000ojS1jonX`N/01?nX
`N/00ol0003oZ<7[ojS1j`0<ojS1j`03o`000?nX_n[oZ;oZ00CoZ;oZ0ol0000;ojS1k003o`000?oo
oooooooo00[ooooo0_l0000eooooo`004?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00Go
0000ooooooooooooooooo`00000aooooo`;o00005?nX_nX00ol0003oZ;oZojRojP0=ojRojP?o0000
00?oZ;oZo`000?nX_nX05?nX_nX00ol0003oZ;oZojRojP0:ojRojP?o00001OnX_nX00ol0003oZ;oZ
ojRojP0BojRojP03o`000?nX_n[oZ;oZ00SoZ;oZ0ol00006ojS0j`03o`000?nX`>_oZ<3[01?oZ<3[
00?o0000ojRoj_nX_nX00_nX_nX5o`0000_oZ<?]00?o0000ojS1jonX`N/01?nX`N/00ol0003oZ<7[
ojS1j`0<ojS1j`03o`000?nX_n[oZ;oZ00?o00003_nX`N`00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo03?ooooo000@ooooo`05oa0@4?ooooooooooooooool@41001Oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo02_ooooo0ol000000onX_n[o0000ojRojP0DojRojP03o`00
0?nX_n[oZ;oZ00[oZ;oZ0_l00005ojRojP03o`000?nX_n[oZ;oZ01?oZ;oZ00?o0000ojRoj_nX_nX0
1onX_nX2o`0000WoZ;oZ00?o0000ojRoj_nX_nX04_nX_nX00ol0003oZ;oZojRojP04ojRojP?o0000
2_nX`>/00ol0003oZ<3[ojS0j`0CojS0j`Ko00003onX`nd00ol0003oZ<7[ojS1j`04ojS1j`03o`00
0?nX`N_oZ<7[00_oZ<7[0ol0000BojS1k003o`000?oooooooooo00_ooooo00?o0000ooooooooool0
<_ooool0013ooooo00Go0000ooooooooooooooooo`000005ooooo`;o00001Oooool00ol0003ooooo
ooooo`0Xooooo`;o00001OnX_nX00ol0003oZ;oZojRojP0CojRojP03o`000?nX_n[oZ;oZ00KoZ;oZ
0ol00008ojRojP03o`000?nX_n[oZ;oZ01?oZ;oZ00?o0000ojRoj_nX_nX00onX_nX3o`0000coZ;oZ
00?o0000ojRoj_nX_nX04_nX_nX00ol0003oZ;oZojRojP03o`0000koZ<3[00?o0000ojS0jonX`>/0
4OnX`>/4o`0001?oZ<?]00?o0000ojS1jonX`N/00onX`N/00ol0003oZ<7[ojS1j`08ojS1j`?o0000
00?oY/C_o`000?nX`N`04onX`N`00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo037ooooo
000@ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo02Cooooo0ol00008ojRojP03o`000?nX_n[oZ;oZ01?oZ;oZ00?o0000ojRoj_nX_nX0
0onX_nX2o`0000coZ;oZ00?o0000ojRoj_nX_nX04onX_nX00ol0003oZ;oZo`000002o`00013oZ;oZ
00?o0000ojRoj_nX_nX04OnX_nX3o`0001;oZ<3[00?o0000ojS0jonX`>/03OnX`>/4o`000003ojO6
l?l0003oZ<?]01?oZ<?]00?o0000ojS1jonX`N/01?nX`N/00ol0003oZ<7[ojS1j`04ojS1j`?o0000
1OnVa>l00ol0003oZ<7/ojS1k00BojS1k003o`000?oooooooooo00[ooooo00?o0000ooooooooool0
<Oooool0013ooooo00Go410@oooooooooooooooooa0@4005ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool08Oooool2o`0000coZ;oZ00?o0000ojRoj_nX_nX04onX_nX00ol0003oZ;oZ
o`000002o`0000ooZ;oZ00?o0000ojRoj_nX_nX04_nX_nX2o`0001CoZ;oZ00?o0000ojRoj_nX_nX0
3OnX_nX3o`000003ojS1jol0003oZ<3[01?oZ<3[00?o0000ojS0jonX`>/02OnX`>/4o`0000GoYlK`
00?o0000ojS3kOnX`nd04_nX`nd00ol0003oZ<7[ojS1j`04ojS1j`03o`000?nX`N_oZ<7[00?o0000
2OnVa>l00ol0003oZ<7/ojS1k00AojS1k003o`000?oooooooooo00_ooooo00?o0000ooooooooool0
<?ooool0013ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool07Oooool3o`0000ooZ;oZ00?o0000ojRoj_nX_nX04_nX_nX2o`0001?oZ;oZ
00?o0000ojRoj_nX_nX03_nX_nX3o`000003ojRoj_l0003oZ;oZ01?oZ;oZ00?o0000ojRoj_nX_nX0
2_nX_nX3o`0000GoZ<7[00?o0000ojS0jonX`>/04_nX`>/00ol0003oZ<3[ojS0j`05ojS0j`Co0000
2OnWa_000ol0003oZ<?]ojS3k@0BojS3k@03o`000?nX`N_oZ<7[00?oZ<7[0ol0000<ojK4k`03o`00
0?nX`NcoZ<7/01;oZ<7/00?o0000ooooooooool02_ooool00ol0003oooooooooo`0`ooooo`004?oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`0Jooooo`;o00004onX_nX00ol0003oZ;oZojRojP0>ojRojP?o000000?oZ;oZo`000?nX_nX0
4onX_nX00ol0003oZ;oZojRojP0:ojRojP?o00001OnX_nX00ol0003oZ;oZojRojP0BojRojP03o`00
0?nX_n[oZ;oZ00OoZ;oZ0_l00009ojS1j`03o`000?nX`>_oZ<3[01;oZ<3[00Co0000ojS0jonX`>_o
Z<3[1Ol0000<ojO6l003o`000?nX`ngoZ<?]01;oZ<?]00?o0000ojS1jol000000_l000000onVa>oo
0000ojK4k`0=ojK4k`03o`000?nX`NcoZ<7/017oZ<7/0_l0000;ooooo`;o0000<Oooool001Wooooo
0_l0000;ooooo`03o`000?oooooooooo01Kooooo0ol00002ojRojP03o`000?nX_n[oZ;oZ017oZ;oZ
00?o0000ojRoj_nX_nX02_nX_nX3o`0000GoZ;oZ00?o0000ojRoj_nX_nX04_nX_nX00ol0003oZ;oZ
ojRojP07ojRojP;o00002OnX_nX00ol0003oZ;oZojRojP0BojRojP03o`000?nX_n[oZ;oZ00?oZ;oZ
0ol0000<ojS1j`03o`000?nX`>_oZ<3[01;oZ<3[1Ol0000@ojO6l003o`000?nX`ngoZ<?]013oZ<?]
0ol00005ojK4k`03o`000?nVa>ooY/C_00coY/C_00?o0000ojS1k?nX`N`03OnX`N`3o`000003ojK0
k?l0003ooooo00cooooo00?o0000ooooooooool0;_ooool001Wooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`0Cooooo`;o00001_nX_nX00ol0003oZ;oZojRojP0AojRojP03o`000?nX
_n[oZ;oZ00OoZ;oZ0_l00009ojRojP03o`000?nX_n[oZ;oZ01;oZ;oZ00?o0000ojRoj_nX_nX00onX
_nX3o`0000coZ;oZ00?o0000ojRoj_nX_nX04_nX_nX00ol0003oZ;oZo`000002o`00013oZ<7[00?o
0000ojS0jonX`>/03_nX`>/5o`0001?oYlK`00?o0000ojS3kOnX`nd03OnX`nd3o`0000;oY<_d00?o
0000ojK4konVa>l01?nVa>l00ol0003oY/C_ojK4k`0;ojK4k`03o`000?nX`NcoZ<7/00[oZ<7/0ol0
0005ojK0k003o`000?oooooooooo00[ooooo00?o0000ooooooooool0;_ooool001Wooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`0?ooooo`?o00002OnX_nX00ol0003oZ;oZojRojP0A
ojRojP03o`000?nX_n[oZ;oZ00?oZ;oZ0ol0000<ojRojP03o`000?nX_n[oZ;oZ01;oZ;oZ00?o0000
ojRoj_l000000_l0000@ojRojP03o`000?nX_n[oZ;oZ017oZ;oZ0_l0000DojS1j`03o`000?nX`>_o
Z<3[00[oZ<3[1_l000000onWbo?o0000ojO6l00CojO6l003o`000?nX`ngoZ<?]00SoZ<?]1?l00006
ojC;m003o`000?nVa>ooY/C_00CoY/C_00?o0000ojK4konVa>l02onVa>l00ol0003oZ<7/ojS1k006
ojS1k0?o00002OnV`>`00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02gooooo000Ioooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool03?ooool2o`0000goZ;oZ00?o0000ojRo
j_nX_nX04OnX_nX00ol0003oZ;oZo`000002o`00013oZ;oZ00?o0000ojRoj_nX_nX04OnX_nX2o`00
01CoZ;oZ00?o0000ojRoj_nX_nX03OnX_nX3o`000003ojS1jol0003oZ<7[01?oZ<7[00?o0000ojS0
jonX`>/01onX`>/6o`0000GoYl_c00?o0000ojO6l?nWa_004_nWa_000ol0003oZ<?]ojS3k@04ojS3
k@?o00002onTbo@00ol0003oY/C_ojK4k`03ojK4k`03o`000?nVa>ooY/C_00_oY/C_00?o0000ojS1
k?nX`N`00onX`N`3o`0000coY/3/00?o0000ooooooooool02oooool00ol0003oooooooooo`0/oooo
o`006Oooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo00Sooooo0ol0000@ojRojP03
o`000?nX_n[oZ;oZ013oZ;oZ0ol0000CojRojP03o`000?nX_n[oZ;oZ00goZ;oZ0ol00002ojRojP03
o`000?nX_n[oZ;oZ017oZ;oZ00?o0000ojRoj_nX_nX02_nX_nX3o`0000GoZ<7[00?o0000ojS1jonX
`N/04_nX`N/00ol0003oZ<3[ojS0j`04ojS0j`;o000000?oZ<3[o`000?l000002OnWbo<00ol0003o
YlK`ojO6l00BojO6l003o`000?nX`ngoZ<?]00?o00003onTbo@00ol0003oY/C_ojK4k`03ojK4k`03
o`000?nVa>ooY/C_00_oY/C_00?o0000ojS1k?l000000_l0000@ojK0k003o`000?oooooooooo00[o
oooo00?o0000ooooooooool0;?ooool001Sooooo0ol0000@ooooo`;o00001_ooool3o`0001?oZ;oZ
00?o0000ojRoj_nX_nX03?nX_nX3o`0000?oZ;oZ00?o0000ojRoj_nX_nX04OnX_nX00ol0003oZ;oZ
ojRojP0:ojRojP;o00001_nX_nX00ol0003oZ;oZojRojP0AojRojP03o`000?nX_n[oZ;oZ00OoZ;oZ
0_l00009ojS1j`03o`000?nX`N_oZ<7[01;oZ<7[00?o0000ojS0jonX`>/01_l0000<ojO;l`03o`00
0?nWa_3oYlK`013oYlK`1?l0000CojC;m003o`000?nVa>ooY/C_00?oY/C_00?o0000ojK4konVa>l0
2OnVa>l3o`0001CoY/3/00?o0000ooooooooool02_ooool2o`0002cooooo000Hooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool00ol00003ojRojP03o`000?nX_n[oZ;oZ017oZ;oZ00?o
0000ojRoj_nX_nX02?nX_nX3o`0000OoZ;oZ00?o0000ojRoj_nX_nX04OnX_nX00ol0003oZ;oZojRo
jP06ojRojP?o00002OnX_nX00ol0003oZ;oZojRojP0AojRojP03o`000?nX_n[oZ;oZ00?oZ;oZ0ol0
000<ojS1j`03o`000?nX`N_oZ<7[017oZ<7[1_l0000@ojO;l`03o`000?nWa_3oYlK`00coYlK`0ol0
0003oikDn`03o`000?nTboCoY<_d017oY<_d00?o0000ojK4konVa>l00onVa>l00ol0003oY/C_ojK4
k`05ojK4k`Co00000_nR`Nl00ol0003oY/3/ojK0k00BojK0k003o`000?oooooooooo00[ooooo0_l0
000/ooooo`006?ooool00ol0003oooooooooo`0Booooo`?o00001onX_nX00ol0003oZ;oZojRojP0A
ojRojP03o`000?nX_n[oZ;oZ00CoZ;oZ0ol0000;ojRojP03o`000?nX_n[oZ;oZ017oZ;oZ00?o0000
ojRoj_nX_nX00onX_nX2o`0000goZ;oZ00?o0000ojRoj_nX_nX04OnX_nX00ol0003oZ;oZo`000002
o`00013oZ<7[00?o0000ojS1jonX`N/03OnX`N/6o`0001CoYl_c00?o0000ojO6l?nWa_002?nWa_03
o`0000OoW]Ck00?o0000ojC;m?nTbo@04OnTbo@00ol0003oY/C_ojK4k`03ojK4k`03o`000?nVa>oo
000000Co00001onR`Nl00ol0003oY/3/ojK0k00BojK0k003o`000?oooooooooo00[ooooo00?o0000
ooooooooool0:_ooool001Sooooo00?o0000ooooooooool03oooool3o`0000_oZ;oZ00?o0000ojRo
j_nX_nX04OnX_nX00ol0003oZ;oZojRojP03o`0000ooZ;oZ00?o0000ojRoj_nX_nX04OnX_nX00ol0
003oZ;oZo`000002o`00013oZ;oZ00?o0000ojRoj_nX_nX04?nX_nX2o`0001CoZ<7[00?o0000ojS1
jonX`N/02OnX`N/6o`0000?oY/oe00?o0000ojO;lonWbo<04_nWbo<00ol0003oYlK`ojO6l004ojO6
l0?o00002onNe?/00ol0003oY<_dojC;m00AojC;m003o`000?nVa>ooY/C_00Co00003OnR`Nl00ol0
003oY/3/ojK0k00AojK0k003o`000?oooooooooo00_ooooo00?o0000ooooooooool0:Oooool001So
oooo00?o0000ooooooooool03?ooool3o`0000ooZ;oZ00?o0000ojRoj_nX_nX04?nX_nX3o`0001?o
Z;oZ00?o0000ojRoj_nX_nX04?nX_nX2o`0001CoZ;oZ00?o0000ojRoj_nX_nX03?nX_nX3o`0000;o
Z<7[00?o0000ojS1jonX`N/04_nX`N/00ol0003oZ<7[ojS1j`05ojS1j`Ko00001onVcoD00ol0003o
Yl_cojO;l`0BojO;l`03o`000?nWa_3oYlK`00?o00003onNe?/00ol0003oY<_dojC;m00?ojC;m0Co
00001?nR`Nl00ol0003oX/7_oj;1k`0;oj;1k`03o`000?nV`>coY/3/017oY/3/00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0Xooooo`006?ooool2o`0000[ooooo0ol0000CojRojP03o`00
0?nX_n[oZ;oZ00coZ;oZ0ol00003ojRojP03o`000?nX_n[oZ;oZ017oZ;oZ00?o0000ojRoj_nX_nX0
3?nX_nX3o`000003ojRoj_l0003oZ;oZ01CoZ;oZ00?o0000ojRoj_nX_nX02?nX_nX3o`0000KoZ<7[
00?o0000ojS1jonX`N/04_nX`N/01?l0003oZ<7[ojS1jonX`N/6o`0000_oY/oe00?o0000ojO;lonW
bo<04?nWbo<4o`0001?oW]Ck00?o0000ojC;m?nTbo@02_nTbo@4o`0000;oVl?d00?o0000oj;1konR
`Nl00onR`Nl00ol0003oX/7_oj;1k`0<oj;1k`03o`000?nV`>coY/3/00ooY/3/0ol0000<ooooo`03
o`000?oooooooooo02Sooooo000Hooooo`03o`000?oooooooooo00Kooooo0ol00003ojRojP03o`00
0?nX_n[oZ;oZ017oZ;oZ00?o0000ojRoj_nX_nX02OnX_nX2o`0000OoZ;oZ00?o0000ojRoj_nX_nX0
4OnX_nX00ol0003oZ;oZojRojP08ojRojP?o00001OnX_nX00ol0003oZ;oZojRojP0CojRojP03o`00
0?nX_n[oZ;oZ00CoZ;oZ0ol0000:ojS1j`03o`000?nX`N_oZ<7[01;oZ<7[1_l0000?ojK?m@03o`00
0?nWbo?oYl_c00coYl_c0ol00004oiGLoP03o`000?nNe?_oW]Ck017oW]Ck00?o0000ojC;m?nTbo@0
1OnTbo@4o`0000OoVl?d00?o0000oj;1konR`Nl00onR`Nl00ol0003oX/7_oj;1k`0;oj;1k`03o`00
0?nV`>coY/3/00_oY/3/1?l00002ojFlj@03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
9oooool001Sooooo00?o0000ooooooooool01?ooool2o`0000OoZ;oZ00?o0000ojRoj_nX_nX04OnX
_nX00ol0003oZ;oZojRojP06ojRojP;o00002_nX_nX00ol0003oZ;oZojRojP0AojRojP03o`000?nX
_n[oZ;oZ00CoZ;oZ0ol00009ojRojP03o`000?nX_n[oZ;oZ01?oZ;oZ00?o0000ojRoj_nX_nX00ol0
000>ojS1j`03o`000?nX`N_oZ<7[00ooZ<7[1Ol0000CojK?m@03o`000?nWbo?oYl_c00SoYl_c0ol0
0008oiGLoP03o`000?nNe?_oW]Ck017oW]Ck00?o0000ojC;m?nTbo@01?l0000<oi_3m003o`000?nR
`NooX/7_00?oX/7_00?o0000oj;1konR`Nl02onR`Nl00ol0003oY/3/ojK0k005ojK0k0Go00001onU
_>T00ol0003oooooooooo`0:ooooo`;o0000:?ooool001Oooooo00?o0000ooooooooool00oooool2
o`0000[oZ;oZ00?o0000ojRoj_nX_nX04OnX_nX00ol0003oZ;oZojRojP02ojRojP?o00003OnX_nX0
0ol0003oZ;oZojRojP0AojRojP03o`000?nX_n[oZ;oZ00?o00003OnX_nX00ol0003oZ;oZojRojP0B
ojRojP?o00004_nX`N/00ol0003oZ<7[ojS1j`0;ojS1j`Co00001?nVd?H00ol0003oY/oeojK?m@0A
ojK?m@03o`000?nWbo?oYl_c00CoYl_c0ol0000<oiGLoP;o00003onNe?/5o`00017oVl?d00?o0000
oj;1konR`Nl00onR`Nl00ol0003oX/7_oj;1k`0;oj;1k`03o`000?nV`>coY/3/00Co00003OnU_>T0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Oooooo00GoV9RHoa0@4?l0003o<S8bolc<
c00Jooooo`005oooool00ol0003oooooooooo`03o`0000goZ;oZ00?o0000ojRoj_nX_nX04OnX_nX0
1?l0003oZ;oZo`000?l0000AojRojP03o`000?nX_n[oZ;oZ013oZ;oZ0ol0000AojRojP03o`000?nX
_n[oZ;oZ00koZ;oZ0ol000000onX`>_o0000ojS1j`0CojS1j`03o`000?nX`N_oZ<7[00OoZ<7[1?l0
0008ojK@mP03o`000?nVcoGoY/oe017oY/oe00?o0000ojO;lonWbo<00ol0000AoiGLoP03o`000?nN
e?_oW]Ck00OoW]Ck1Ol00003oi?5n@03o`000?nK`oCoVl?d017oVl?d00?o0000oj;1konR`Nl00_nR
`Nl00ol0003oX/7_oj;1k`0:oj;1k`Co00004OnU_>T00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo00Kooooo00Go410@okZj^_ooooooMgMgoc8b<P0Jooooo`005oooool3o`00017oZ;oZ00?o
0000ojRoj_nX_nX04?nX_nX2o`0001CoZ;oZ00?o0000ojRoj_nX_nX03?nX_nX3o`000003ojRoj_l0
003oZ;oZ01;oZ;oZ00?o0000ojRoj_nX_nX02_nX_nX3o`0000GoZ<3[00?o0000ojS1jonX`N/04_nX
`N/00ol0003oZ<7[ojS1j`03ojS1j`Co00003?nVd?H00ol0003oY/oeojK?m@0?ojK?m@Co00005OnE
g?h01?l0003oW]CkoikDnonNe?/5o`0000WoTlGi00?o0000oi_3m?nK`o@04?nK`o@00ol0003oX/7_
oj;1k`03oj;1k`03o`000?nR`NooX/7_00KoX/7_0ol00002oj2gj@03o`000?nU_>WoYKcY017oYKcY
00?o0000ooooooooool02oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01Sooooo
000Gooooo`;o00004onX_nX00ol0003oZ;oZojRojP0<ojRojP?o00000_nX_nX00ol0003oZ;oZojRo
jP0BojRojP03o`000?nX_n[oZ;oZ00SoZ;oZ0ol00005ojRojP03o`000?nX_n[oZ;oZ017oZ;oZ00?o
0000ojRoj_nX_nX01onX_nX2o`0000WoZ<3[00?o0000ojS1jonX`N/04_nX`N/00ol0003oZ<7[o`00
0003o`00013oY]3f00?o0000ojK?mOnVcoD02_nVcoD4o`0000CoT>7m0_l0000AoiGLoPKo00003onC
aOT00ol0003oVl?doi_3m00@oi_3m003o`000?nR`NooX/7_00?oX/7_00?o0000oj;1konR`Nl00_nR
`Nl3o`0000KoX;OY00?o0000ojFljOnU_>T04OnU_>T00ol0003oooooooooo`0:ooooo`03o`000?oo
oooooooo00Sooooo00?oZJVYoa0@4?ooool06Oooool000gooooo1?l000000ol@413oooooooooo`03
ooooo`03o`000?oooooo000001?oZ;oZ00?o0000ojRoj_nX_nX02?nX_nX3o`0000KoZ;oZ00?o0000
ojRoj_nX_nX04_nX_nX00ol0003oZ;oZojRojP04ojRojP?o00002OnX_nX00ol0003oZ;oZojRojP0A
ojRojP03o`000?nX_n[oZ;oZ00?oZ;oZ0ol0000<ojS0j`03o`000?nX`N_oZ<7[013oZ<7[1?l0000D
ojK@mP03o`000?nVcoGoY/oe00GoY/oe1?l0000:oi3Qo@;o00002_nEg?h5o`0000?oT<Sk00?o0000
oi?5nOnCaOT04?nCaOT00ol0003oVl?doi_3m00@oi_3m003o`000?nR`NooX/7_00;oX/7_00?o0000
oj;1kol000000_l0000:oj2gj@03o`000?nU_>WoYKcY017oYKcY00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`06ooooo`03oa0@4?l0003o^[Zj01[ooooo000?ooooo`03o`000?oooooooooo
00Gooooo00Co0000oooooooooooo00004onX_nX00ol0003oZ;oZojRojP04ojRojP?o00002_nX_nX0
0ol0003oZ;oZojRojP0BojRojP03o`000?nX_n[oZ;oZ00?o00003OnX_nX00ol0003oZ;oZojRojP0A
ojRojP03o`000?nX_n[o000000;o00004?nX`>/00ol0003oZ<7[ojS1j`0<ojS1j`Co00000onWcoD0
0ol0003oY]3fojK@mP0BojK@mP03o`000?nVcoGoY/oe00Co00004?n@hOd2o`0000?oUMcn1Ol00009
oi38n`03o`000?nCaOWoTlGi013oTlGi00?o0000oi_3m?nK`o@04?nK`o@00ol0003oX/7_oj;1k`03
o`0000goX;OY00?o0000ojFljOnU_>T04OnU_>T00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo00Kooooo00?o^[Zjob4Q8Oooool06Oooool000oooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`02ooooo`03o`000?nX_n[oZ;oZ017oZ;oZ00?o0000ojRoj_nX_nX00ol0000>ojRo
jP03o`000?nX_n[oZ;oZ017oZ;oZ0ol0000AojRojP03o`000?nX_n[oZ;oZ013oZ;oZ0ol0000CojS0
j`03o`000?nX`N_oZ<7[00SoZ<7[1?l00007ojO?m@03o`000?nVd?KoY]3f017oY]3f0ol0000Doi3Q
o@Go00003on@b?/00ol0003oTlGioi?5n@0@oi?5n@03o`000?nK`oCoVl?d00coVl?d1_l00003oj2g
j@03o`000?nP]nWoX;OY00_oX;OY00?o0000ojFljOnU_>T04OnU_>T00ol0003oooooooooo`09oooo
o`?o00001?ooool01Ol@413oV9RHoooooonj^[[o000001[ooooo000?ooooo`03o`000?oooooooooo
00Cooooo0_l00004ooooo`;o00004OnX_nX3o`0001;oZ;oZ00?o0000ojRoj_nX_nX03OnX_nX3o`00
00;oZ;oZ00?o0000ojRoj_nX_nX04?nX_nX00ol0003oZ;oZojRojP0<ojRojP?o00000onX`>/00ol0
003oZ<3[ojS0j`0AojS0j`03o`000?nX`N_oZ<7[00GoZ<7[1?l0000:ojO?m@;o00003_nVd?H3o`00
00?oTnCm0_l0000>oi3Qo@Co00001?nGc?X00ol0003oT<Skoi38n`0>oi38n`03o`000?nCaOWoTlGi
013oTlGi00?o0000oi_3m?nK`o@00_nK`o@9o`0000CoVJoW00?o0000oj2gjOnP]nT00onP]nT00ol0
003oX;OYoj2gj@0;oj2gj@03o`000?nU_>WoYKcY00ooYKcY0ol0000<ooooo`03o`000?oooooooooo
00;ooooo00GoZJVYoa0@4?l0003o410@ojVYZ@0Jooooo`003oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Gooooo00?o0000ojRoj_nX_nX02onX_nX3o`0000?oZ;oZ00?o0000ojRo
j_nX_nX04?nX_nX00ol0003oZ;oZojRojP0:ojRojP;o00001_nX_nX00ol0003oZ;oZojRojP0@ojRo
jP03o`000?nX_n[oZ;oZ00SoZ;oZ0ol00007ojS0j`03o`000?nX`>_oZ<3[017oZ<3[00Co0000ojS1
jonX`N_oZ<7[1?l0000?ojO?m@03o`000?nVd?KoY]3f00SoY]3f0ol00008oi?To@?o00002?n@hOd3
o`0000WoUlcj00?o0000oi38non@b?/03_n@b?/00ol0003oTlGioi?5n@0=oi?5n@Oo00003_nI[nL0
0ol0003oX;OYoj2gj@02oj2gj@03o`000?nP]nWoX;OY00_oX;OY00?o0000ojFljOnU_>T03?nU_>T3
o`0000;oY[cY00?o0000ooooooooool02oooool00ol0003oooooooooo`0Pooooo`003oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o0000ojRoj_nX_nX01onX_nX3o`00
00OoZ;oZ00?o0000ojRoj_nX_nX04?nX_nX00ol0003oZ;oZojRojP06ojRojP?o00002OnX_nX00ol0
003oZ;oZojRojP0@ojRojP03o`000?nX_n[oZ;oZ00CoZ;oZ0ol0000;ojS0j`03o`000?nX`>_oZ<3[
017oZ<3[1Ol0000BojO?m@03o`000?nVd?KoY]3f00CoY]3f0ol0000>oi?To@;o00000_n@hOd4o`00
00goUlcj00?o0000oi38non@b?/03_n@b?/00ol0003oTlGioi?5n@07oi?5n@Go00000onEZN@00ol0
003oVJoWoiV_i`0@oiV_i`03o`000?nP]nWoX;OY00;oX;OY00?o0000oj2gjOnP]nT02onP]nT00ol0
003oYKcYojFlj@07ojFlj@Co00001_nV_>T00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
023ooooo000?ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool00ol0003o
Z;oZojRojP03ojRojP?o00002onX_nX00ol0003oZ;oZojRojP0@ojRojP03o`000?nX_n[oZ;oZ00?o
Z;oZ0_l0000=ojRojP03o`000?nX_n[oZ;oZ013oZ;oZ00?o0000ojRoj_nX_nX00ol0000?ojS0j`03
o`000?nX`>_oZ<3[00goZ<3[1_l0000EojO?m@03o`000?nVd?KoY]3f00?o00004OnCi?d4o`0001;o
Ulcj00?o0000oi38non@b?/03_n@b?/01?l0003oTlGioi?5nOnCaOT5o`0000WoUJWT00?o0000oiV_
ionI[nL03onI[nL00ol0003oX;OYoj2gj@03oj2gj@03o`000?nP]nWoX;OY00[oX;OY00?o0000ojFl
jOnU_>T01?nU_>T3o`0000_oY[cY00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Ooooo
o`003Oooool00omEEEGoIVIVo`000006ooooo`03o`000?oooooooooo00Sooooo00?o0000ojRoj_l0
00000_l0000?ojRojP03o`000?nX_n[oZ;oZ013oZ;oZ00?o0000ojRoj_l000000_l0000@ojRojP03
o`000?nX_n[oZ;oZ00ooZ;oZ0ol0000CojS0j`03o`000?nX`>_oZ<3[00WoZ<3[1_l00003ojS<lP03
o`000?nWcoGoYloe01;oYloe0ol0000@oi?To@Co00001?nQd?P00ol0003oUlcjoiO<nP0@oiO<nP03
o`000?n@b?_oT<Sk00[oT<Sk1ol0000?oiFYi003o`000?nI[nOoVJoW00ooVJoW00?o0000oj2gjOnP
]nT00onP]nT00ol0003oX;OYoj2gj@0:oj2gj@03o`000?nU_>WoYKcY00?o00003_nV_>T00ol0003o
ooooooooo`0;ooooo`03o`000?oooooooooo01kooooo000Eooooo`03o`000?oooooooooo00[ooooo
00?o0000ojRoj_nX_nX04OnX_nX00ol0003oZ;oZojRojP0?ojRojP?o00004onX_nX00ol0003oZ;oZ
ojRojP0;ojRojP?o00000onX_nX00ol0003oZ<3[ojS0j`0AojS0j`03o`000?nX`>_oZ<3[00GoZ<3[
1_l00007ojS<lP03o`000?nWcoGoYloe00koYloe0ol00003oicUo0?o00002OnCi?d4o`0000WoXM3h
00?o0000oiO<n_nGc?X04?nGc?X00ol0003oT<Skoi38n`02oi38n`Oo00001?nGZ>800ol0003oUJWT
oiFYi00?oiFYi003o`000?nI[nOoVJoW013oVJoW00?o0000oj2gjOnP]nT00_nP]nT00ol0003oX;OY
oj2gj@09oj2gj@Co00004_nV_>T00ol0003oooooooooo`0:ooooo`;o00007oooool001Gooooo0_l0
000<ooooo`03o`000?nX_n[oZ;oZ017oZ;oZ00?o0000ojRoj_nX_nX02onX_nX3o`0000?oZ;oZ00?o
0000ojRoj_nX_nX04OnX_nX00ol0003oZ;oZojRojP07ojRojP?o00001onX_nX00ol0003oZ<3[ojS0
j`0AojS0j`04o`000?nX`>_oZ<3[ojS0j`Ko00002onXc?82o`0000coYloe0_l00009oicUo0?o0000
0_nCi?d4o`0000koXM3h0_l0000?oiO<nPKo00003?nGZ>800ol0003oUJWToiFYi00?oiFYi003o`00
0?nI[nOoVJoW013oVJoW00?o0000oj2gjOnP]nT00_nP]nT00ol0003oX;OYoj2gj@04oj2gj@Co0000
0_nS]nL00ol0003oY[cYojJlj@0BojJlj@03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
7Oooool001Gooooo00?o0000ooooooooool03?ooool00ol0003oZ;oZojRojP0AojRojP03o`000?nX
_n[oZ;oZ00OoZ;oZ0ol00007ojRojP03o`000?nX_n[oZ;oZ017oZ;oZ00?o0000ojRoj_nX_nX00onX
_nX3o`0000_oZ;oZ00?o0000ojS0jonX`>/04OnX`>/6o`00013oZ<cb00?o0000ojO?mOnWcoD01_nW
coD3o`0000goW>Gl0ol0000Doj7@n003o`000?nGc?[oUlcj00OoUlcj1Ol00002oifYg`03o`000?nG
Z>;oUjSR00koUjSR00?o0000oiFYi?nEZN@03onEZN@00ol0003oVJoWoiV_i`0?oiV_i`03o`000?nP
]nWoX;OY00?oX;OY00?o0000oj2gjOl000000ol00007oj>gi`03o`000?nV_>WoY[cY017oY[cY00?o
0000ooooooooool02oooool00ol0003oooooooooo`0Looooo`005Oooool00ol0003oooooooooo`0=
ooooo`03o`000?nX_n[oZ;oZ017oZ;oZ00?o0000ojRoj_nX_nX00onX_nX3o`0000_oZ;oZ00?o0000
ojRoj_nX_nX04OnX_nX00ol0003oZ;oZo`000002o`0000ooZ;oZ00?o0000ojS0jonX`>/03OnX`>/6
o`0001CoZ<cb00?o0000ojO?mOnWcoD00onWcoD2o`0000goW>Gl0ol00003oj_Cm003o`000?nQd?So
XM3h01;oXM3h00Co0000oiO<n_nGc?[oUlcj1Ol00008oifYg`03o`000?nGZ>;oUjSR00koUjSR00?o
0000oiFYi?nEZN@03_nEZN@00ol0003oVJoWoiV_i`0@oiV_i`03o`000?nP]nWoX;OY00Co00003?nS
]nL00ol0003oY[cYojJlj@0AojJlj@03o`000?oooooooooo00[ooooo00?o0000ooooooooool07?oo
ool001Gooooo00?o0000ooooooooool03_ooool00ol0003oZ;oZojRojP0AojRojP03o`000?nX_n[o
000000;o00003onX_nX00ol0003oZ;oZojRojP0@ojRojP;o00004onX_nX00ol0003oZ<3[ojS0j`0:
ojS0j`Go00000onXanl00ol0003oZ<cbojS<lP0BojS<lP03o`000?nWcoGo000000;o00003OnLiO`2
o`0000OoZm?d00?o0000oj7@n?nQd?P04OnQd?P4o`0000koWJWO00?o0000oiNXh_nGZ>803OnGZ>80
0ol0003oUJWToiFYi00?oiFYi003o`000?nI[nOoVJoW00koVJoW1?l00003oj>gi`03o`000?nS]nOo
XkOW00[oXkOW00?o0000ojJljOnV_>T04OnV_>T2o`0000cooooo00?o0000ooooooooool06oooool0
01Gooooo00?o0000ooooooooool03oooool00ol0003oZ;oZojRojP0@ojRojP?o00004_nX_nX00ol0
003oZ;oZojRojP0<ojRojP?o00000_nX_nX00ol0003oZ;oZojRojP0AojRojP03o`000?nX`>_oZ<3[
00KoZ<3[1Ol00007ojS7k`03o`000?nXc?;oZ<cb017oZ<cb1?l0000<oicUo0;o00002_n[do@2o`00
00koXM3h0ol000000onT[=go0000oifYg`0?oifYg`03o`000?nGZ>;oUjSR00koUjSR00?o0000oiFY
i?nEZN@03onEZN@00ol0003oVJoWoiV_i`09oiV_i`Co00000_nN[^<00ol0003oXkOWoj>gi`03oj>g
i`03o`000?nS]nOoXkOW00[oXkOW00?o0000ojJljOnV_>T03OnV_>T3o`000003ojRnj_l0003ooooo
00cooooo00?o0000ooooooooool06_ooool001Cooooo0_l0000Booooo`03o`000?nX_n[oZ;oZ00co
Z;oZ0ol00003ojRojP03o`000?nX_n[oZ;oZ013oZ;oZ00?o0000ojRoj_nX_nX02?nX_nX3o`0000Ko
Z;oZ00?o0000ojRoj_nX_nX04OnX_nX00ol0003oZ<3[ojS0j`02ojS0j`Go00002onXanl00ol0003o
Z<cbojS<lP0=ojS<lP?o00001?nVhO/3o`0000KoW>Gl0ol0000>oj_Cm003o`000?nQd?SoXM3h00So
XM3h0ol00005ojB/g@03o`000?nMZMooWJWO00koWJWO00?o0000oiNXh_nGZ>803_nGZ>800ol0003o
UJWToiFYi00>oiFYi003o`000?nI[nOoVJoW00GoVJoW1?l00007oij^h`03o`000?nS]nOoXkOW00?o
XkOW00?o0000oj>gionS]nL02_nS]nL00ol0003oY[cYojJlj@09ojJlj@?o00001OnX_^X00ol0003o
ooooooooo`0:ooooo`;o00006oooool001Cooooo00?o0000ooooooooool04_ooool00ol0003oZ;oZ
ojRojP08ojRojP?o00001onX_nX00ol0003oZ;oZojRojP0@ojRojP03o`000?nX_n[oZ;oZ00CoZ;oZ
0ol0000:ojRojP03o`000?nX_n[oZ;oZ017oZ;oZ1_l0000?ojS7k`03o`000?nXc?;oZ<cb00[oZ<cb
0_l0000:ojKQn`?o000000?oW>Glo`000?l000004_n[do@00ol0003oXM3hoj7@n004oj7@n0?o0000
2?nT[=d00ol0003oWJWOoifYg`0?oifYg`03o`000?nGZ>;oUjSR00goUjSR00?o0000oiFYi?nEZN@0
3onEZN@00ol0003oVJoWoiV_i`04o`0000coWZkS00?o0000oj>gionS]nL00_nS]nL00ol0003oXkOW
oj>gi`0;oj>gi`03o`000?nV_>WoY[cY00KoY[cY0_l00009ojRnjP03o`000?oooooooooo00Wooooo
0_l0000Kooooo`005?ooool00ol0003oooooooooo`0Cooooo`03o`000?nX_n[oZ;oZ00CoZ;oZ0ol0
000;ojRojP03o`000?nX_n[oZ;oZ013oZ;oZ00?o0000ojRoj_nX_nX00ol0000>ojRojP03o`000?nX
_n[oZ;oZ00koZ;oZ1Ol0000CojS7k`03o`000?nXc?;oZ<cb00KoZ<cb0ol0000>ojKQn`?o00005?n[
do@00ol0003oXM3hoj7@n003o`0000coY:cM00?o0000oifYgonMZMl03_nMZMl00ol0003oUjSRoiNX
hP0>oiNXhP03o`000?nEZNCoUJWT00_oUJWT1_l0000@oij^h`03o`000?nS]nOoXkOW00?oXkOW00?o
0000oj>gionS]nL02_nS]nL00ol0003oY[cYojJlj@03ojJlj@?o00002onX_^X00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo01Wooooo000Dooooo`03o`000?oooooooooo01Cooooo00?o0000
ojRoj_nX_nX00ol0000?ojRojP03o`000?nX_n[oZ;oZ00ooZ;oZ0ol0000BojRojP03o`000?nX_n[o
Z;oZ00[oZ;oZ1Ol00003ojS3k@03o`000?nXanooZ<O_017oZ<O_00?o0000ojS<l_nXc?800onXc?82
o`0000ooY^7k0_l00003ok?Cl003o`000?n[doCoZm?d017oZm?d0ol0000@ojB/g@03o`000?nMZMoo
WJWO00koWJWO00?o0000oiNXh_nGZ>803_nGZ>800ol0003oUJWToiFYi002oiFYi0So00001?nKYMd0
0ol0003oWZkSoij^h`0@oij^h`03o`000?nS]nOoXkOW00?oXkOW00?o0000oj>gionS]nL02_nS]nL0
0ol0003oY[cYo`000002o`0000ooZ;kZ00?o0000ooooooooool02_ooool00ol0003oooooooooo`0H
ooooo`005?ooool00ol0003oooooooooo`0Eooooo`;o00004onX_nX00ol0003oZ;oZojRojP0;ojRo
jP?o00000onX_nX00ol0003oZ;oZojRojP0@ojRojP03o`000?nX_n[oZ;oZ00KoZ;oZ1Ol00007ojS3
k@03o`000?nXanooZ<O_017oZ<O_00?o0000ojS<l_l000000_l0000?ojKQn`;o00001_ncdo000ol0
003oZm?doj_Cm00=oj_Cm0?o000000?oZjoKo`000?nT[=d04?nT[=d00ol0003oWJWOoifYg`0?oifY
g`03o`000?nGZ>;oUjSR00coUjSR1_l0000=oi^Ug@03o`000?nN[^?oWZkS013oWZkS00?o0000oj>g
ionS]nL00onS]nL00ol0003oXkOWoj>gi`08oj>gi`?o00004onX_^X00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo01Oooooo000Dooooo`;o00006?ooool00ol0003oZ;oZojRojP0AojRojP03
o`000?nX_n[oZ;oZ00OoZ;oZ0ol00007ojRojP03o`000?nX_n[oZ;oZ013oZ;oZ00?o0000ojRoj_nX
_nX00_nX_nX5o`0000_oZ<?]00?o0000ojS7konXanl04?nXanl3o`0000koY^7k0ol00009ok?Cl0;o
00002_n[do@3o`0000GoZjoK00?o0000ojB/gOnT[=d03onT[=d00ol0003oWJWOoifYg`0>oifYg`03
o`000?nGZ>;oUjSR00OoUjSR1Ol00002oi^Oe`03o`000?nKYMgoVjGM00ooVjGM00?o0000oij^honN
[^<04?nN[^<00ol0003oXkOWoj>gi`02oj>gi`03o`000?nS]nOoXkOW00CoXkOW1?l00002ojNmj@03
o`000?nX_^[oZ;kZ01;oZ;kZ00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Gooooo`00
4oooool00ol0003oooooooooo`0Iooooo`03o`000?nX_n[oZ;oZ017oZ;oZ00?o0000ojRoj_nX_nX0
0onX_nX3o`0000_oZ;oZ00?o0000ojRoj_nX_nX04?nX_nX00ol0003oZ;oZo`000003o`0000ooZ<?]
00?o0000ojS7konXanl03?nXanl3o`0000?o[=Sg0_l0000:ojKQn`;o00003_ncdo000ol0003oZm?d
oj_Cm004oj_Cm0?o00002On[[m/00ol0003oY:cMojB/g@0>ojB/g@03o`000?nMZMooWJWO00ooWJWO
00Co0000oiNXh_nGZ>;oUjSR1Ol00008oi^Oe`03o`000?nKYMgoVjGM00koVjGM00?o0000oij^honN
[^<04?nN[^<00ol0003oXkOWoj>gi`03oj>gi`03o`000?nS]nOo000000?o00001onW_NT00ol0003o
Z;kZojRnjP0AojRnjP03o`000?oooooooooo00[ooooo00?o0000ooooooooool05_ooool001?ooooo
00?o0000ooooooooool06_ooool00ol0003oZ;oZojRojP0AojRojP03o`000?nX_n[o000000;o0000
3onX_nX00ol0003oZ;oZojRojP0>ojRojPCo00004onX`nd00ol0003oZ<O_ojS7k`08ojS7k`?o0000
2?n/f?L3o`0000GoY^7k0_l0000Aok?Cl003o`000?n[doCoZm?d00?o00003?n[[m/00ol0003oY:cM
ojB/g@0?ojB/g@03o`000?nMZMooWJWO00coWJWO1_l0000=oi^Oe`03o`000?nKYMgoVjGM00ooVjGM
00?o0000oij^honN[^<04?nN[^<00ol0003oXkOWoj>gi`04o`0000coYkgY00?o0000ojRnj_nX_^X0
4OnX_^X00ol0003oooooooooo`09ooooo`;o00005oooool001?ooooo00?o0000ooooooooool06ooo
ool2o`00017oZ;oZ0ol0000BojRojP03o`000?nX_n[oZ;oZ00[oZ;oZ1?l00003ojS1j`03o`000?nX
`ngoZ<?]017oZ<?]00?o0000ojS7konXanl01?nXanl3o`0000ko[=Sg0_l000000onVhO_o0000o`00
000Cok?Cl0?o00004?n[[m/00ol0003oY:cMojB/g@0?ojB/g@03o`000?nMZMooWJWO00KoWJWO1Ol0
0003oijMd`03o`000?nKWmOoVioG00koVioG00?o0000oi^UgOnKYMd03onKYMd00ol0003oWZkSoij^
h`0>oij^h`Co00000onW_NT00ol0003oYkgYojNmj@0:ojNmj@03o`000?nX_^[oZ;kZ013oZ;kZ0ol0
000;ooooo`03o`000?oooooooooo01Gooooo000Cooooo`03o`000?oooooooooo01gooooo00?o0000
ojRoj_nX_nX02onX_nX3o`0000?oZ;oZ00?o0000ojRoj_nX_nX04?nX_nX00ol0003oZ;oZojRojP06
ojRojPCo00001onX`N/00ol0003oZ<?]ojS3k@0AojS3k@03o`000?nXanooZ<O_00?o00004_n/f?L3
o`0001;o/m?`0_l000000ona/]Wo0000oj^_f`0Aoj^_f`03o`000?nT[=goY:cM00koY:cM00Co0000
oifYgonMZMooWJWO1Ol00009oijMd`03o`000?nKWmOoVioG00goVioG00?o0000oi^UgOnKYMd03onK
YMd00ol0003oWZkSoij^h`0;oij^h`?o00000_nV^^P00ol0003oYkgYojNmj@03ojNmj@03o`000?nW
_NWoYkgY00[oYkgY00?o0000ojRnj_nX_^X03?nX_^X3o`0000;oZ;oZ00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0Dooooo`004oooool3o`0001kooooo00?o0000ojRoj_nX_nX01onX_nX3
o`0000OoZ;oZ00?o0000ojRoj_nX_nX04?nX_nX00ol0003oZ;oZojRojP02ojRojPCo00002onX`N/0
0ol0003oZ<?]ojS3k@0@ojS3k@?o00004on/f?L2o`0000?o^=7/00?o0000ok?Cl?ncdo003Oncdo02
o`0000Co/K;I00?o0000oj^_fon[[m/03on[[m/00ol0003oY:cMojB/g@0>ojB/g@Co00003_nNWM<0
0ol0003oVioGoi^Oe`0>oi^Oe`03o`000?nKYMgoVjGM00ooVjGM00?o0000oij^honN[^<01onN[^<3
o`0000KoY[[X00?o0000ojNmjOnW_NT00onW_NT00ol0003oYkgYojNmj@0:ojNmj@03o`000?nX_^[o
Z;kZ00OoZ;kZ1?l00006ojRojP03o`000?oooooooooo00[ooooo00?o0000ooooooooool04oooool0
01?ooooo00?o0000ooooooooool07oooool00ol0003oZ;oZojRojP03ojRojP?o00002onX_nX00ol0
003oZ;oZojRojP0@ojRojPGo00003onX`N/00ol0003oZ<?]ojS3k@0<ojS3k@?o00000on]c_400ol0
003o[=SgojcHm`0>ojcHm`;o00001_nhdN`00ol0003o/m?`ok?Cl009ok?Cl0?o00001ona/]T00ol0
003oZjoKoj^_f`0?oj^_f`03o`000?nT[=goY:cM00[oY:cM0ol000000onSW]3o0000oijMd`0@oijM
d`03o`000?nKWmOoVioG00koVioG00?o0000oi^UgOnKYMd03_nKYMd00ol0003oWZkSoij^h`04oij^
h`?o00002_nV^^P00ol0003oYkgYojNmj@03ojNmj@03o`000?nW_NWoYkgY00WoYkgY00?o0000ojRn
j_nX_^X01?nX_^X3o`0000_oZ;oZ00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Coooo
o`004_ooool00ol0003oooooooooo`0Qooooo`03o`000?nX_n[o000000;o00003onX_nX00ol0003o
Z;oZojRojP0=ojRojPCo00004onX`N/00ol0003oZ<?]ojS3k@09ojS3k@;o00001on]c_42o`0000_o
[=Sg0ol00009okSAk0;o00001oncdo02o`0000[o/K;I00?o0000oj^_fon[[m/04?n[[m/00ol0003o
Y:cMojB/g@06ojB/g@?o00001OnSW]000ol0003oWYgCoijMd`0>oijMd`03o`000?nKWmOoVioG00ko
VioG00?o0000oi^UgOnKYMd03onKYMd00ol0003oWZkSoij^h`03o`0000goY[[X00?o0000ojNmjOnW
_NT00onW_NT00ol0003oYkgYojNmj@0:ojNmj@03o`000?nX_^[oZ;kZ00?o00003_nX_nX00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo01;ooooo0007ooooo`Go00001_ooool00ol0003ooooo
ooooo`0Rooooo`;o00004_nX_nX00ol0003oZ;oZojRojP09ojRojPGo00000_nX_nX00ol0003oZ<7[
ojS1j`0AojS1j`03o`000?nX`ngoZ<?]00KoZ<?]0_l0000;ojg>l@03o`000?n/f?Oo[=Sg00Ko[=Sg
0_l0000>okSAk003o`000?ncdo3o/m?`00;o/m?`0_l0000=ok6bf@03o`000?n[[m_oZjoK00ooZjoK
00?o0000ojB/gOnT[=d00onT[=d3o`0000SoXik@00?o0000oijMdonNWM<03onNWM<00ol0003oVioG
oi^Oe`0>oi^Oe`03o`000?nKYMgoVjGM00goVjGM1?l0000AojJjj003o`000?nW_NWoYkgY00?oYkgY
00?o0000ojNmjOnW_NT02OnW_NT3o`0001;oZ;oZ00?o0000ooooooooool02Oooool2o`0000[ooooo
0_l000000ol@413oooooooooo`04ooooo`001oooool01OnHV9So8B4Qonk^k_ooooooA4A400Kooooo
00?o0000ooooooooool09?ooool00ol0003oZ;oZojRojP0@ojRojP03o`000?nX_n[oZ;oZ00KoZ;oZ
1?l00006ojRojP03o`000?nX`N_oZ<7[017oZ<7[00?o0000ojS3kOnX`nd00_nX`nd3o`0000ko[Lka
0_l00004ojcHm`;o00004OnhdN`01?l0003o/m?`o`000?l0000@ok6bf@03o`000?n[[m_oZjoK00oo
ZjoK00?o0000ojB/gOl000000_l0000<oj>Nd003o`000?nNWM?oWYgC00koWYgC00?o0000oi^OeonK
WmL03_nKWmL00ol0003oVjGMoi^Ug@09oi^Ug@Co00000_nT]^D00ol0003oY[[XojJjj00AojJjj003
o`000?nW_NWoYkgY00?oYkgY00?o0000ojNmjOnW_NT01OnW_NT3o`000003ojRoj_l0003oZ;oZ01?o
Z;oZ00?o0000ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00Go
oooo0008ooooo`03oiRHV?lQ8B7ok^k^00Oooooo00?o0000ooooooooool09Oooool00ol0003oZ;oZ
ojRojP0@ojRojP03o`000?nX_n[oZ;oZ00;oZ;oZ1?l0000:ojRojP03o`000?nX`N_oZ<7[017oZ<7[
00Co0000ojS3kOl0003o00004on]c_401?l0003o[=Sgo`000?l0000CokSAk0;o00004_na/]T00ol0
003oZjoKoj^_f`0?oj^_f`;o00003onSW]000ol0003oWYgCoijMd`0?oijMd`03o`000?nKWmOoVioG
00koVioG00?o0000oi^UgOnKYMd01?nKYMd4o`0000OoY;KU00?o0000ojJjj?nV^^P04OnV^^P00ol0
003oYkgYojNmj@03ojNmj@04o`000?nW_NWoYkgYojNmj@?o00001OnX_nX00ol0003oZ;oZojRojP0A
ojRojP03o`000?oooooooooo00[ooooo00?o0000ooooooooool01Oooool5o`0000Kooooo0009oooo
o`03oiRHV?lQ8B7ok^k^00Kooooo0_l0000Wooooo`03o`000?nX_n[oZ;oZ013oZ;oZ1Ol0000>ojRo
jP03o`000?nX`N_oZ<7[013oZ<7[0ol0000Dojg>l@?o00004_nhdN`2o`000003okJffOl0003o/K;I
01;o/K;I00?o0000oj^_fon[[m/02on[[m/3o`000003ojRRd?l0003oXik@00ooXik@00?o0000oijM
donNWM<03_nNWM<00ol0003oVioGoi^Oe`0>oi^Oe`03o`000?nKYMgoVjGM00Co00003?nT]^D00ol0
003oY[[XojJjj00@ojJjj003o`000?nW_NWoYkgY00?oYkgY1?l00009ojRojP03o`000?nX_n[oZ;oZ
017oZ;oZ00?o0000ooooooooool02_ooool00ol0003oooooooooo`04ooooo`04odA4A?oMgMgooooo
o`0000Oooooo000:ooooo`03ogMgMomVIVKooooo00Gooooo00?o0000ooooooooool09oooool00ol0
003oZ;oZojRojP0=ojRojPCo00004_nX_nX00ol0003oZ<7[ojS1j`0<ojS1j`?o00000on[a^d00ol0
003o[Lkaojg>l@0?ojg>l@;o00000ongbnT00ol0003o^=7/okSAk00=okSAk0;o00001?nf]]T00ol0
003o/K;Iok6bf@0Aok6bf@03o`000?n[[m_oZjoK00OoZjoK0ol00005ojRRd003o`000?nSW]3oXik@
00goXik@00?o0000oijMdonNWM<03onNWM<00ol0003oVioGoi^Oe`0<oi^Oe`Co00004?nT]^D00ol0
003oY[[XojJjj00AojJjj003o`000?nW_NWoYkgY00Co00003?nX_nX00ol0003oZ;oZojRojP0?ojRo
jP?o00002oooool00ol0003oooooooooo`04ooooo`04omgMgOmEEEGoooooo`0000Oooooo000;oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0:Oooool00ol0003oZ;oZojRojP09ojRo
jPGo00000_nX_nX00ol0003oZ;oZojRojP0@ojRojP03o`000?nX`N_oZ<7[00SoZ<7[0ol00007oj_6
k@03o`000?n]c_7o[Lka00co[Lka0_l00006okO;j@;o00002onhdN`2o`0000Oo][KI00?o0000ok6b
fOna/]T04?na/]T00ol0003oZjoKoj^_f`04oj^_f`?o00002?nXX]000ol0003oXik@oj>Nd00>oj>N
d003o`000?nNWM?oWYgC00koWYgC00?o0000oi^OeonKWmL02?nKWmL4o`0000;oXk7R00?o0000ojBf
iOnT]^D04?nT]^D00ol0003oY[[XojJjj00?ojJjj0Co00001?nX_nX00ol0003oZ;oZojRojP0:ojRo
jP03o`000?nX_n[oZ;oZ00_oZ;oZ0ol00002ojRojP03o`000?oooooooooo00[ooooo00?o0000oooo
ooooool01?ooool00omgMgOoc<c<o`000007ooooo`001oooool01Ol0003o^[ZjoooooonHV9So410@
00Gooooo00?o0000ooooooooool0:_ooool00ol0003oZ;oZojRojP05ojRojPGo00001_nX_nX00ol0
003oZ;oZojRojP0@ojRojP03o`000?nX`N_oZ<7[00CoZ<7[0ol0000;oj_6k@;o00002_n]c_42o`00
00[o]l_Y00?o0000okSAk?nhdN`01_nhdN`2o`0000[o][KI00?o0000ok6bfOna/]T04?na/]T00ol0
003oZjoKoj^_f`03o`0000coZ:;@00?o0000oj>Nd?nSW]003_nSW]000ol0003oWYgCoijMd`0>oijM
d`03o`000?nKWmOoVioG00CoVioG0ol00007oj>ahP03o`000?nT]^GoY;KU013oY;KU00?o0000ojJj
j?nV^^P02onV^^P3o`0000;oZ;kZ00?o0000ojRoj_nX_nX00onX_nX00ol0003oZ;oZojRojP0:ojRo
jP03o`000?nX_n[oZ;oZ00SoZ;oZ0ol00006ojRojP03o`000?oooooooooo00Sooooo0ol00005oooo
o`03onk^k_m4A4Co000000Oooooo0007ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`01Oooool00ol0
003oooooooooo`0[ooooo`04o`000?nX_n[oZ;oZojRojPGo00002_nX_nX00ol0003oZ;oZojRojP0@
ojRojP03o`000?nX`N_oZ<7[00?o00004?n[a^d00ol0003o[Lkaojg>l@05ojg>l@;o00003OngbnT2
o`0000Co^=7/0_l0000=okJff@03o`000?na/]Wo/K;I00oo/K;I0ol0000?ojRRd003o`000?nSW]3o
Xik@00koXik@00?o0000oijMdonNWM<03_nNWM<00ol0003oVioGoi^Oe`04o`0000_oXk7R00?o0000
ojBfiOnT]^D04?nT]^D00ol0003oY[[XojJjj007ojJjj0?o00001_nX_^X00ol0003oZ;oZojRojP03
ojRojP03o`000?nX_n[oZ;oZ00[oZ;oZ00?o0000ojRoj_nX_nX01?nX_nX3o`0000[oZ;oZ00?o0000
ooooooooool01?ooool3o`0000;ooooo00?o0000ooooooooool01?ooool00omgMgOo0000ooooo`06
ooooo`004Oooool00ol0003oooooooooo`0/ooooo`Go00003_nX_nX00ol0003oZ;oZojRojP0?ojRo
jP?o00005?n[a^d00ol0003o[Lkaojg>l@02ojg>l@;o00004OngbnT01?l0003o^=7/o`000?l0000@
okJff@03o`000?na/]Wo/K;I00_o/K;I0ol000000on]Ym7o0000ojRRd00@ojRRd003o`000?nSW]3o
Xik@00koXik@00?o0000oijMdonNWM<03?nNWM<4o`00013oXk7R00?o0000ojBfiOnT]^D03onT]^D0
0ol0003oY[[XojJjj004ojJjj0?o00002_nX_^X00ol0003oZ;oZojRojP03ojRojP03o`000?nX_n[o
Z;oZ00[oZ;oZ00?o0000ojRoj_nX_nX00ol0000=ojRojP04o`000?ooooooooooooooo`?o00001Ooo
ool00ol0003oooooooooo`0=ooooo`004Oooool2o`0002_ooooo0_l000000ooooooo0000o`00000A
ojRojP03o`000?nX_n[oZ;oZ00_oZ;oZ0ol00003ojW1j`03o`000?n[a^goZlK]01;oZlK]00Co0000
ojg>lOl0003o00004ongbnT2o`0001;o][KI00?o0000ok6bfOna/]T02Ona/]T2o`0000Go[JOA00?o
0000ojRRd?nXX]003_nXX]000ol0003oXik@oj>Nd00>oj>Nd003o`000?nNWM?oWYgC00SoWYgC1?l0
0002ojB_g`03o`000?nS/N;oXk7R013oXk7R00?o0000ojBfiOnT]^D03onT]^D00ol0003oY[[XojJj
j003o`0000goZ;kZ00?o0000ojRoj_nX_nX01?nX_nX00ol0003oZ;oZojRojP08ojRojPCo00004OnX
_nX3o`0000Sooooo00?o0000ooooooooool03Oooool0017ooooo00?o0000ooooooooool09oooool3
o`0000Gooooo00?o0000ojRoj_nX_nX03onX_nX00ol0003oZ;oZojRojP07ojRojP?o00001onY`N/0
0ol0003oZlK]oj_6k@0Aoj_6k@?o00004_ngbnT2o`000003okRjfol0003o][KI01;o][KI00?o0000
ok6bfOna/]T01_na/]T2o`0000Oo[JOA00?o0000ojRRd?nXX]003onXX]000ol0003oXik@oj>Nd00>
oj>Nd003o`000?nNWM?oWYgC00CoWYgC0ol00007ojB_g`03o`000?nS/N;oXk7R00ooXk7R00?o0000
ojBfiOnT]^D03_nT]^D4o`00017oZ;kZ00?o0000ojRoj_nX_nX00onX_nX00ol0003oZ;oZojRojP05
ojRojP?o00000_nX_nX00ol0003oZ;oZojRojP0AojRojP03o`000?oooooooooo00Oooooo00?o0000
ooooooooool03Oooool0017ooooo00?o0000ooooooooool09?ooool3o`0000Wooooo00?o0000ojRo
j_nX_nX03onX_nX00ol0003oZ;oZojRojP03ojRojP?o00002onY`N/00ol0003oZlK]oj_6k@0=oj_6
k@?o00000onca^P00ol0003o]l_YokO;j@0>okO;j@03o`000?nh^]_o^;[K00;o^;[K00?o0000okJf
fOnf]]T04Onf]]T00ol0003o/K;Iok6bf@02ok6bf@?o00002_n]Ym400ol0003oZ:;@ojRRd00>ojRR
d003o`000?nSW]3oXik@00koXik@00?o0000oijMdonNWM<01?l0000;ojB_g`03o`000?nS/N;oXk7R
00ooXk7R00?o0000ojBfiOnT]^D02OnT]^D4o`0000;oZ;kY00?o0000ojRnj_nX_^X04OnX_^X00ol0
003oZ;oZojRojP03ojRojP04o`000?nX_n[oZ;oZojRojP?o00001_nX_nX00ol0003oZ;oZojRojP0@
ojRojP03o`000?oooooooooo00Sooooo00?o0000ooooooooool03?ooool0013ooooo00?o0000oooo
ooooool08_ooool3o`0000gooooo00?o0000ojRoj_nX_nX03onX_nX00ol0003oZ;oZo`000002o`00
00ooZL7[0_l0000;oj_6k@;o00001onca^P00ol0003o]l_YokO;j@0;okO;j@;o00001_nh^]/00ol0
003o][KIokJff@0AokJff@04o`000?na/]Wo0000o`0000go[JOA00?o0000ojRRd?nXX]003_nXX]00
0ol0003oXik@oj>Nd00>oj>Nd0?o00004?nT[ml00ol0003oXk7Roj>ahP0?oj>ahP03o`000?nT]^Go
Y;KU00GoY;KU0ol00007ojRnj@03o`000?nX_^[oZ;kZ013oZ;kZ00?o0000ojRoj_nX_nX01?nX_nX3
o`0000[oZ;oZ00?o0000ojRoj_nX_nX04?nX_nX00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00cooooo000@ooooo`03o`000?oooooooooo01oooooo0ol0000Aooooo`03o`000?nX_n[oZ;oZ
00koZ;oZ0ol0000CojW1j`03o`000?n[a^goZlK]00KoZlK]0_l0000:ok?6j0;o00002OngbnT2o`00
00Wo^;[K00?o0000okJffOnf]]T04?nf]]T2o`00013o[JOA00?o0000ojRRd?nXX]003_nXX]000ol0
003oXik@oj>Nd00:oj>Nd0?o000000?oYZkMo`000?nT[ml04?nT[ml00ol0003oXk7Roj>ahP0@oj>a
hP03o`000?nT]^GoY;KU00Co00002onX_^T00ol0003oZ;kZojRnjP0@ojRnjP03o`000?nX_n[oZ;oZ
00?o000000?oZ;oZo`000?nX_nX02_nX_nX00ol0003oZ;oZojRojP0?ojRojP?o00002?ooool00ol0
003oooooooooo`0<ooooo`004?ooool2o`0001gooooo0ol0000Eooooo`03o`000?nX_n[oZ;oZ00[o
Z;oZ0ol00003ojW0jP03o`000?nY`N_oZL7[017oZL7[00?o0000oj_6kOn[a^d00_n[a^d3o`0000ko
/lKX00?o0000okO;jOngbnT01?ngbnT2o`0000_o^;[K00?o0000okJffOnf]]T03_nf]]T2o`000003
ok:_eOl0003o[JOA00oo[JOA00?o0000ojRRd?nXX]003_nXX]000ol0003oXik@oj>Nd007oj>Nd0?o
00001OnV[]d00ol0003oY:oOojB_g`0?ojB_g`03o`000?nS/N;oXk7R00ooXk7R0ol0000@ojRnj@03
o`000?nX_^[oZ;kZ00koZ;kZ1?l00004ojRojP03o`000?nX_n[oZ;oZ00[oZ;oZ00?o0000ojRoj_nX
_nX02onX_nX3o`0000;oZ;oZ00?o0000ooooooooool01_ooool00ol0003oooooooooo`0<ooooo`00
4?ooool00ol0003oooooooooo`0Iooooo`?o00006Oooool00ol0003oZ;oZojRojP06ojRojP?o0000
1onY`>X00ol0003oZL7[ojW1j`0AojW1j`04o`000?n[a^go0000o`0001;o/lKX00?o0000okO;jOng
bnT00_ngbnT00ol0003o^;[KokRjf`0<okRjf`03o`000?nf]]Wo][KI00_o][KI0_l00004ok:_e@03
o`000?n]Ym7o[JOA00ko[JOA00?o0000ojRRd?nXX]003_nXX]000ol0003oXik@oj>Nd003oj>Nd0?o
00002OnV[]d00ol0003oY:oOojB_g`0?ojB_g`03o`000?nS/N;oXk7R00_oXk7R0ol000000onX_NWo
0000ojRnj@0AojRnj@03o`000?nX_^[oZ;kZ00WoZ;kZ1?l00002ojRojP03o`000?nX_n[oZ;oZ00Co
Z;oZ00?o0000ojRoj_nX_nX02_nX_nX00ol0003oZ;oZojRojP07ojRojP?o00001_nX_nX00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00cooooo000@ooooo`03o`000?oooooooooo01Kooooo
0ol0000Mooooo`03o`000?nX_n[oZ;oZ00?oZ;oZ0_l0000;ojW0jP03o`000?nY`N_oZL7[013oZL7[
0ol0000Dok?6j004o`000?ngbnWo0000o`00013o^;[K00?o0000okJffOnf]]T01onf]]T3o`0000Ko
/ZoE00?o0000ojfWdOn]Ym403on]Ym400ol0003oZ:;@ojRRd00=ojRRd003o`000?nSW]3oXik@00?o
00003OnV[]d00ol0003oY:oOojB_g`0>ojB_g`03o`000?nS/N;oXk7R00SoXk7R0ol00005ojRmj@03
o`000?nX_^WoZ;kY013oZ;kY00?o0000ojRnj_nX_^X01OnX_^X3o`0000OoZ;oZ00?o0000ojRoj_nX
_nX01?nX_nX00ol0003oZ;oZojRojP09ojRojP03o`000?nX_n[oZ;oZ00CoZ;oZ0ol0000:ojRojP03
o`000?oooooooooo00Cooooo00?o0000ooooooooool03?ooool0013ooooo00?o0000ooooooooool0
4oooool3o`00027ooooo00?o0000ojRoj_l000000_l0000>ojW0jP;o00003OnY`N/3o`0000?o[/;X
00?o0000ok?6j?nca^P04Onca^P2o`0001;o^;[K00?o0000okJffOnf]]T01Onf]]T2o`0000[o/ZoE
00?o0000ojfWdOn]Ym403_n]Ym400ol0003oZ:;@ojRRd00=ojRRd0?o00004?nV[]d00ol0003oY:oO
ojB_g`0?ojB_g`03o`000?nS/N;oXk7R00CoXk7R0ol00009ojRmj@03o`000?nX_^WoZ;kY013oZ;kY
00?o0000ojRnj_nX_^X01?l0000;ojRojP03o`000?nX_n[oZ;oZ00?oZ;oZ00?o0000ojRoj_nX_nX0
2_nX_nX00ol0003oZ;oZojRojP03o`0000goZ;oZ00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0<ooooo`003oooool00ol0003oooooooooo`0Booooo`;o00009Oooool2o`0001;oZL3Z00?o
0000ojW1jonY`N/01onY`N/3o`0000Oo[/;X00?o0000ok?6j?nca^P03_nca^P2o`000003okJnh?l0
003o^;[K01;o^;[K00?o0000okJffOnf]]T00_nf]]T2o`0000go/ZoE00?o0000ojfWdOn]Ym403_n]
Ym400ol0003oZ:;@ojRRd009ojRRd0?o000000?oZK7Mo`000?nV[]d04OnV[]d00ol0003oY:oOojB_
g`0?ojB_g`03o`000?nS/N;oXk7R00?o00003OnX_NT00ol0003oZ;kYojRnj@0?ojRnj@?o00004?nX
_nX00ol0003oZ;oZojRojP03ojRojP03o`000?nX_n[oZ;oZ00SoZ;oZ1?l0000AojRojP03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool02oooool000oooooo00?o0000ooooooooool03oooool3
o`0002Wooooo00?o0000ojW0j_nY`>X04?nY`>X00ol0003oZL7[ojW1j`03ojW1j`?o00002on^`^P0
0ol0003o/lKXok?6j00;ok?6j0;o00001?nf_^000ol0003o^;[KokRjf`0AokRjf`04o`000?nf]]Wo
0000o`0000oo/ZoE00?o0000ojfWdOn]Ym403_n]Ym400ol0003oZ:;@ojRRd006ojRRd0?o00001OnY
/Md00ol0003oYZkMojJ^g@0@ojJ^g@03o`000?nT[mooY:oO00goY:oO1?l0000AojRmj@03o`000?nX
_^WoZ;kY00_oZ;kY0ol000000onX_n[o0000ojRojP0@ojRojP03o`000?nX_n[oZ;oZ00CoZ;oZ00?o
0000ojRoj_nX_nX00onX_nX4o`0000;oZ;oZ00?o0000ojRoj_nX_nX04OnX_nX00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00_ooooo000?ooooo`;o00003Oooool3o`0002gooooo00?o0000
ojW0j_nY`>X04?nY`>X00ol0003oZL7[o`000002o`0000oo[/;X00?o0000ok?6j?nca^P02?nca^P2
o`0000Oo][kP00?o0000okRjfonh^]/04?nh^]/2o`0001;o/ZoE00?o0000ojfWdOn]Ym403_n]Ym40
0ol0003oZ:;@ojRRd002ojRRd0?o00002OnY/Md00ol0003oYZkMojJ^g@0?ojJ^g@03o`000?nT[moo
Y:oO00WoY:oO1?l00002ojRmj@03o`000?nX_NWoZ;gY013oZ;gY00?o0000ojRnjOnX_^T02?nX_^T3
o`0000GoZ;oZ00?o0000ojRoj_nX_nX03onX_nX00ol0003oZ;oZojRojP04ojRojPGo00001onX_nX0
0ol0003oZ;oZojRojP0@ojRojP03o`000?oooooooooo00?ooooo00?o0000ooooooooool02oooool0
00oooooo00?o0000ooooooooool02Oooool3o`00037ooooo00?o0000ojW0j_nY`>X03onY`>X2o`00
01?o[/;X00?o0000ok?6j?nca^P01Onca^P2o`0000[o][kP00?o0000okRjfonh^]/03Onh^]/2o`00
0003okBffol0003o/ZoE017o/ZoE00?o0000ojfWdOn]Ym403_n]Ym400ol0003oZ:;@o`000002o`00
00goZK7M00?o0000ojJ^gOnV[]d03onV[]d00ol0003oY:oOojB_g`05ojB_g`?o00001onX_NT00ol0
003oZ;gYojRmj@0@ojRmj@03o`000?nX_^WoZ;kY00CoZ;kY0ol00009ojRojP03o`000?nX_n[oZ;oZ
00ooZ;oZ00?o0000ojRoj_nX_nX01?l0000<ojRojP03o`000?nX_n[oZ;oZ013oZ;oZ00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`0;ooooo`003oooool00ol0003oooooooooo`06ooooo`?o
0000=Oooool00ol0003oZL3ZojW0jP0;ojW0jP?o00000_n[`>T00ol0003o[/;Xojk2j00Aojk2j003
o`000?nca^So/lKX00;o/lKX0_l0000=okJnh003o`000?nh^]_o^;[K00[o^;[K0_l00004okBff`03
o`000?nb[mGo/ZoE013o/ZoE00?o0000ojfWdOn]Ym403On]Ym42o`00013oZK7M00?o0000ojJ^gOnV
[]d04?nV[]d00ol0003oY:oOojB_g`04o`0000_oZ;gY00?o0000ojRmjOnX_NT04?nX_NT00ol0003o
Z;kYojRnj@03o`0000coZ;oZ00?o0000ojRoj_nX_nX03onX_nX3o`0000CoZ;oZ00?o0000ojRoj_nX
_nX02_nX_nX00ol0003oZ;oZojRojP0>ojRojP?o00000oooool00ol0003oooooooooo`0;ooooo`00
3oooool00ol0003oooooooooo`03ooooo`?o0000>Oooool00ol0003oZL3ZojW0jP07ojW0jP?o0000
1_n[`>T00ol0003o[/;Xojk2j00Aojk2j004o`000?nca^So0000o`0000oo][kP00?o0000okRjfonh
^]/02?nh^]/2o`0000Oo];KK00?o0000ok:_eOnb[mD03onb[mD00ol0003o[JOAojfWd@0:ojfWd@?o
000000?o[;COo`000?nY/Md04?nY/Md00ol0003oYZkMojJ^g@0?ojJ^g@?o00004?nX_NT00ol0003o
Z;gYojRmj@0>ojRmj@Co00004?nX_nX00ol0003oZ;oZojRojP0;ojRojP?o000000?oZ;oZo`000?nX
_nX01OnX_nX00ol0003oZ;oZojRojP09ojRojP03o`000?nX_n[oZ;oZ00[oZ;oZ1?l00002ojRojP05
o`000?ooooooooooooooool000003Oooool000kooooo00Co0000oooooooooooooooo0ol0000moooo
o`03o`000?nY`>[oZL3Z00?oZL3Z0ol0000:oj_0j@03o`000?n^`^So[/;X013o[/;X0_l0000BokJn
h003o`000?nh^]_o^;[K00Go^;[K0_l00009okBff`03o`000?nb[mGo/ZoE013o/ZoE00?o0000ojfW
dOn]Ym401_n]Ym43o`0000Go[;CO00?o0000ojVagOnY/Md03onY/Md00ol0003oYZkMojJ^g@0;ojJ^
g@?o000000?oZ;gXo`000?nX_NT04OnX_NT00ol0003oZ;gYojRmj@09ojRmj@Co00000_nX_nX00ol0
003oZ;oZojRojP0@ojRojP03o`000?nX_n[oZ;oZ00OoZ;oZ0ol00005ojRojP03o`000?nX_n[oZ;oZ
00?oZ;oZ00?o0000ojRoj_nX_nX02_nX_nX00ol0003oZ;oZojRojP05ojRojPCo00001onX_nX01?l0
003oooooooooool0000=ooooo`003_ooool4o`00047ooooo00?o0000ojW0j_l000000_l0000>oj_0
j@03o`000?n^`^So[/;X00co[/;X0ol000000on`_nGo0000okJnh00BokJnh003o`000?nh^]_o^;[K
00;o^;[K0_l0000<okBff`03o`000?nb[mGo/ZoE013o/ZoE00?o0000ojfWdOn]Ym400_n]Ym43o`00
00Wo[;CO00?o0000ojVagOnY/Md03_nY/Md00ol0003oYZkMojJ^g@08ojJ^g@?o00001OnX_NP00ol0
003oZ;gYojRmj@0@ojRmj@03o`000?nX_NWoZ;gY00GoZ;gY0ol00007ojRojP03o`000?nX_n[oZ;oZ
00ooZ;oZ00?o0000ojRoj_nX_nX01?nX_nX3o`0000WoZ;oZ00?o0000ojRoj_nX_nX00onX_nX00ol0
003oZ;oZojRojP0:ojRojP03o`000?nX_n[oZ;oZ00Co00003?nX_nX00ol0003oooooo`00000=oooo
o`003_ooool2o`0004Cooooo0_l0000Aoj_0j@03o`000?n^`^So[/;X00Wo[/;X0_l00005ok2oi@03
o`000?nf_^3o][kP017o][kP00Co0000okRjfol0003o00003ond]]/00ol0003o/ZoEok:_e@0?ok:_
e@03o`000?n]Ym7o000000;o00003On/]=l00ol0003oZK7MojVag@0>ojVag@03o`000?nV[]goYZkM
00CoYZkM0ol00009ojRmj003o`000?nX_NWoZ;gY013oZ;gY00?o0000ojRmjOnX_NT01?l0000;ojRo
jP03o`000?nX_n[oZ;oZ00ooZ;oZ00?o0000ojRoj_nX_nX00ol0000=ojRojP03o`000?nX_n[oZ;oZ
00?oZ;oZ00?o0000ojRoj_nX_nX02OnX_nX3o`00013oZ;oZ00Co0000oooooooooooo00003?ooool0
00?ooooo00GoV9RHoa0@4?l0003o<S8bolc<c008ooooo`03o`000?oooooooooo04?ooooo00?o0000
oj_0jOn[`>T03on[`>T00ol0003o[/;Xojk2j006ojk2j0;o00002?n`_nD00ol0003o][kPokJnh00@
okJnh0;o00004Ond]]/00ol0003o/ZoEok:_e@0?ok:_e@;o00004On/]=l00ol0003oZK7MojVag@0>
ojVag@03o`000?nV[]goYZkM00?o00003OnX_NP00ol0003oZ;gYojRmj@0?ojRmj@?o00004?nX_nX0
0ol0003oZ;oZojRojP0=ojRojPCo00004OnX_nX00ol0003oZ;oZojRojP03ojRojP03o`000?nX_n[o
Z;oZ00GoZ;oZ0ol000000onX_n[o0000ojRojP0AojRojP03o`000?oooooo000000cooooo0003oooo
o`05oa0@4?nj^[[oooooogMgMolb<S802Oooool00ol0003oooooooooo`13ooooo`03o`000?n[`>Wo
Zl3Y00ooZl3Y00?o0000ojk2j?n^`^P00_n^`^P3o`0000_o/;oU00?o0000okJnh?nf_^003?nf_^03
o`000003ok:lhOl0003o];KK017o];KK00?o0000ok:_eOnb[mD02onb[mD3o`000003ojfih_l0003o
[;CO013o[;CO00?o0000ojVagOnY/Md03OnY/Md4o`00017oZ;gX00?o0000ojRmjOnX_NT02onX_NT3
o`000003ojRoj_l0003oZ;oZ013oZ;oZ00?o0000ojRoj_nX_nX02OnX_nX4o`0000;oZ;oZ00?o0000
ojRoj_nX_nX04?nX_nX00ol0003oZ;oZojRojP03ojRojP03o`000?nX_n[oZ;oZ00;oZ;oZ0ol00005
ojRojP03o`000?nX_n[oZ;oZ00ooZ;oZ00?o0000ooooool000003?ooool000Oooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`13ooooo`03o`000?n[`>WoZl3Y00ooZl3Y00Co0000ojk2
j?l0003o00003on`_nD00ol0003o][kPokJnh009okJnh0;o00001Onb_>400ol0003o];KKokBff`0@
okBff`03o`000?nb[mGo/ZoE00Oo/ZoE0ol00005ojfihP03o`000?n/]=oo[;CO00oo[;CO00?o0000
ojVagOnY/Md02OnY/Md3o`0000;oZ;gX00?o0000ojRmj?nX_NP04?nX_NP00ol0003oZ;gYojRmj@08
ojRmj@?o00001OnX_nX00ol0003oZ;oZojRojP0?ojRojP03o`000?nX_n[oZ;oZ00GoZ;oZ0ol00007
ojRojP03o`000?nX_n[oZ;oZ013oZ;oZ00?o0000ojRoj_nX_nX00onX_nX4o`0000WoZ;oZ00?o0000
ojRoj_nX_nX03onX_nX2o`0000cooooo0006ooooo`03ojVYZOl@413ooooo00[ooooo0_l00014oooo
o`03o`000?n[`>WoZl3Y00goZl3Y1?l0000Aok2oi@03o`000?nf_^3o][kP00Ko][kP0_l00008ok:l
h@03o`000?nd]]_o];KK00oo];KK00?o0000ok:_eOnb[mD01?nb[mD3o`0000Wo[KWR00?o0000ojbd
gon/]=l03on/]=l00ol0003oZK7MojVag@04ojVag@Co00001_nX_NP00ol0003oZ;gXojRmj00@ojRm
j003o`000?nX_NWoZ;gY00CoZ;gY0ol00009ojRojP03o`000?nX_n[oZ;oZ00ooZ;oZ00?o0000ojRo
j_nX_nX01?l0000;ojRojP03o`000?nX_n[oZ;oZ013oZ;oZ00?o0000ojRoj_nX_nX01?l0000<ojRo
jP03o`000?nX_n[oZ;oZ00goZ;oZ0ol0000<ooooo`001Oooool00ol@413o0000okZj^P0=ooooo`03
o`000?oooooooooo04;ooooo00?o0000oj_0jOn[`>T02On[`>T3o`0000Co[;oX00?o0000ok2oiOn`
_nD03on`_nD00ol0003o][kPokJnh002okJnh0?o00002onb_>400ol0003o];KKokBff`0?okBff`03
o`000?nb[mGo/ZoE00?o00003?n]^N800ol0003o[;COojbdg`0@ojbdg`03o`000?nY/MgoZK7M00?o
00002onX_NP00ol0003oZ;gXojRmj00@ojRmj003o`000?nX_NWoZ;gY00?o00003?nX_nX00ol0003o
Z;oZojRojP0?ojRojP?o00004?nX_nX00ol0003oZ;oZojRojP0>ojRojPCo00001?nX_nX00ol0003o
Z;oZojRojP09ojRojP03o`000?nX_n[oZ;oZ00WoZ;oZ1?l00002ooooo`03o`000?oooooooooo00[o
oooo0006ooooo`03okZj^_lQ8B7ooooo00gooooo00?o0000ooooooooool0@_ooool00ol0003oZl3Y
oj_0j@04oj_0j@Co00002?n/_nP00ol0003o/;oUok2oi@0?ok2oi@04o`000?nf_^3o0000o`0000oo
/[cQ00?o0000okBffond]]/03_nd]]/3o`00013o[KWR00?o0000ojbdgon/]=l03on/]=l3o`0000oo
Z;gX00?o0000ojRmj?nX_NP03_nX_NP4o`00013oZ;oZ00?o0000ojRoj_nX_nX02onX_nX3o`000003
ojRoj_l0003oZ;oZ017oZ;oZ00?o0000ojRoj_nX_nX02OnX_nX4o`0000;oZ;oZ00?o0000ojRoj_nX
_nX00onX_nX00ol0003oZ;oZojRojP0:ojRojP03o`000?nX_n[oZ;oZ00GoZ;oZ0ol00006ooooo`03
o`000?oooooooooo00[ooooo0003ooooo`05oa0@4?nHV9SooooookZj^_l000003oooool00ol0003o
ooooooooo`12ooooo`03o`000?n[`>WoZl3Y00?o00003On/_nP00ol0003o/;oUok2oi@0>ok2oi@;o
00004Onb_>400ol0003o];KKokBff`0;okBff`?o000000?o[KcUo`000?n]^N804On]^N800ol0003o
[;COojbdg`0;ojbdg`?o000000?oZKkYo`000?nX_NP04?nX_NP00ol0003oZ;gXojRmj009ojRmj0Co
00000_nX_nX00ol0003oZ;oZojRojP0@ojRojP03o`000?nX_n[oZ;oZ00OoZ;oZ0ol00005ojRojP03
o`000?nX_n[oZ;oZ013oZ;oZ00?o0000ojRoj_nX_nX01OnX_nX3o`0000OoZ;oZ00?o0000ojRoj_nX
_nX00onX_nX00ol0003oZ;oZojRojP0:ojRojP03o`000?nX_n[oZ;oZ00Co00002Oooool00ol0003o
ooooooooo`0:ooooo`000oooool01OnYZJWo410@o`000?l@413oZJVY013ooooo0_l00013ooooo`;o
00004On/_nP00ol0003o/;oUok2oi@0:ok2oi@?o00000_n^_^H00ol0003o/[cQok:lh@0?ok:lh@03
o`000?nd]]_o];KK00Oo];KK0ol00005ojfli@03o`000?n]^N;o[KWR013o[KWR00?o0000ojbdgon/
]=l01on/]=l3o`0000GoZKkY00?o0000ojRmj?nX_NP03onX_NP00ol0003oZ;gXojRmj005ojRmj0?o
00001onX_nX00ol0003oZ;oZojRojP0?ojRojP03o`000?nX_n[oZ;oZ00CoZ;oZ0ol00009ojRojP03
o`000?nX_n[oZ;oZ013oZ;oZ00?o0000ojRoj_nX_nX01?l0000;ojRojP03o`000?nX_n[oZ;oZ00?o
Z;oZ00?o0000ojRoj_nX_nX02OnX_nX3o`0000kooooo00?o0000ooooooooool02Oooool001[ooooo
00?o0000ooooooooool0@Oooool00ol0003o[;oXojboj00@ojboj003o`000?n`_nGo/;oU00Ko/;oU
0ol00006ojjniP03o`000?nb_>7o/[cQ00oo/[cQ00?o0000okBffond]]/00ond]]/3o`0000Wo[KcU
00?o0000ojfih_n]^N803on]^N800ol0003o[;COojbdg`04ojbdg`?o00002OnY_^T00ol0003oZ;gX
ojRmj00?ojRmj003o`000?nX_NSoZ;gX00Co00002onX_nX00ol0003oZ;oZojRojP0?ojRojP03o`00
0?nX_n[oZ;oZ00?o00003OnX_nX00ol0003oZ;oZojRojP0>ojRojPCo00004?nX_nX00ol0003oZ;oZ
ojRojP02ojRojP03o`000?nX_n[oZ;oZ00KoZ;oZ0ol0000Aooooo`03o`000?oooooooooo00Wooooo
000Kooooo`03o`000?oooooooooo047ooooo00?o0000ojboj?n/_nP04?n/_nP00ol0003o/;oUok2o
i@03ok2oi@;o00002_n^_^H00ol0003o/[cQok:lh@0?ok:lh@03o`000?nd]]_o000000;o00003On]
_>D00ol0003o[KWRojfihP0?ojfihP03o`000?n/]=oo[;CO00?o00003OnY_^T00ol0003oZ;gXojRm
j00>ojRmj0?o00004?nX_nX00ol0003oZ;oZojRojP0=ojRojPCo00004OnX_nX00ol0003oZ;oZojRo
jP09ojRojPCo00000_nX_nX00ol0003oZ;oZojRojP0?ojRojP03o`000?nX_n[oZ;oZ00?oZ;oZ00?o
0000ojRoj_nX_nX00_nX_nX3o`0001Cooooo00?o0000ooooooooool02Oooool001cooooo00?o0000
ooooooooool0@Oooool00ol0003o[;oXojboj00@ojboj003o`000?n`_nGo000000;o00003On^_^H0
0ol0003o/[cQok:lh@0>ok:lh@;o00004On]_>D00ol0003o[KWRojfihP0=ojfihPCo00004OnY_^T0
0ol0003oZ;gXojRmj00:ojRmj0?o000000?oZ;oZo`000?nX_nX04OnX_nX00ol0003oZ;oZojRojP09
ojRojP?o00000_nX_nX00ol0003oZ;oZojRojP0AojRojP03o`000?nX_n[oZ;oZ00GoZ;oZ0ol00007
ojRojP03o`000?nX_n[oZ;oZ00ooZ;oZ00?o0000ojRoj_nX_nX00onX_nX4o`0001Oooooo00?o0000
ooooooooool02Oooool001gooooo00?o0000ooooooooool0@Oooool00ol0003o[;oXojboj00?ojbo
j0;o00004On^_^H00ol0003o/[cQok:lh@0:ok:lh@?o00000_n[_^L00ol0003o[KcUojfli@0?ojfl
i@03o`000?n]^N;o[KWR00Wo[KWR0ol00003ojVnj@03o`000?nY_^WoZKkY00ooZKkY00?o0000ojRm
j?nX_NP01onX_NP3o`0000GoZ;oZ00?o0000ojRoj_nX_nX04?nX_nX00ol0003oZ;oZojRojP04ojRo
jPCo00001_nX_nX00ol0003oZ;oZojRojP0AojRojP03o`000?nX_n[oZ;oZ00Co00002onX_nX00ol0
003oZ;oZojRojP0?ojRojP03o`000?nX_n[oZ;oZ00Co00006Oooool00ol0003oooooooooo`09oooo
o`007_ooool2o`0004;ooooo00?o0000ojboj?n/_nP02on/_nP3o`0000;oZkoX00?o0000ojjni_n^
_^H03on^_^H00ol0003o/[cQok:lh@06ok:lh@?o00001_n[_^L00ol0003o[KcUojfli@0?ojfli@03
o`000?n]^N;o[KWR00Co[KWR1?l00007ojVnj@03o`000?nY_^WoZKkY00ooZKkY00?o0000ojRmj?nX
_NP00onX_NP3o`0000WoZ;oZ00?o0000ojRoj_nX_nX04?nX_nX00ol0003oZ;oZojRojP03o`0000_o
Z;oZ00?o0000ojRoj_nX_nX04?nX_nX3o`00013oZ;oZ00?o0000ojRoj_nX_nX03OnX_nX4o`0000?o
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`09ooooo`008?ooool00ol0003ooooo
ooooo`10ooooo`03o`000?n/_nSo[;oX00Oo[;oX0ol00006oj^oj003o`000?n^_^Ko[[kV00oo[[kV
00?o0000ok:lhOnb_>400onb_>42o`0000[oZkkW00?o0000ojfliOn]_>D03on]_>D00ol0003o[KWR
ojfihP03o`0000coZKkY00?o0000ojVnjOnY_^T03onY_^T00ol0003oZ;gXo`000002o`0000goZ;oZ
00?o0000ojRoj_nX_nX03_nX_nX4o`0000ooZ;oZ00?o0000ojRoj_nX_nX03?nX_nX3o`000003ojRo
j_l0003oZ;oZ013oZ;oZ00?o0000ojRoj_nX_nX02OnX_nX4o`0000Sooooo00?o0000ooooooooool0
5_ooool00ol0003oooooooooo`09ooooo`008Oooool00ol0003oooooooooo`10ooooo`03o`000?n/
_nSo[;oX00?o[;oX0ol0000:oj^oj003o`000?n^_^Ko[[kV00oo[[kV00?o0000ok:lhOl000000_l0
000=oj^ni`03o`000?n]_>Go[KcU00ko[KcU0ol0000@ojVnj@03o`000?nY_^WoZKkY00goZKkY0ol0
000AojRojP03o`000?nX_n[oZ;oZ00WoZ;oZ1?l00002ojRojP03o`000?nX_n[oZ;oZ00ooZ;oZ00?o
0000ojRoj_nX_nX02?nX_nX3o`0000GoZ;oZ00?o0000ojRoj_nX_nX03onX_nX00ol0003oZ;oZojRo
jP05ojRojP?o00003Oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo00Sooooo000R
ooooo`03o`000?oooooooooo043ooooo00?o0000ojboj?l000000_l0000>oj^oj003o`000?n^_^Ko
[[kV00go[[kV0ol0000Aoj^ni`03o`000?n]_>Go[KcU00[o[KcU0ol00002ojVoj@03o`000?nY_^Wo
ZKkY00ooZKkY00?o0000ojVnjOnY_^T02OnY_^T3o`0000;oZ;oZ00?o0000ojRoj_nX_nX04?nX_nX0
0ol0003oZ;oZojRojP05ojRojP?o00001onX_nX00ol0003oZ;oZojRojP0?ojRojP03o`000?nX_n[o
Z;oZ00CoZ;oZ0ol00009ojRojP03o`000?nX_n[oZ;oZ00ooZ;oZ00?o0000ojRoj_nX_nX01?l0000A
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02?ooool002?ooooo0_l00011oooo
o`;o00004On[_nP00ol0003o[[kVojjniP09ojjniP?o00000onY_nT00ol0003oZkkWoj^ni`0?oj^n
i`03o`000?n]_>Go[KcU00Ko[KcU0ol00006ojVoj@03o`000?nY_^WoZKkY00ooZKkY00?o0000ojVn
jOnY_^T01?nY_^T4o`0000KoZ;oZ00?o0000ojRoj_nX_nX04?nX_nX00ol0003oZ;oZojRojP04o`00
00_oZ;oZ00?o0000ojRoj_nX_nX03onX_nX00ol0003oZ;oZojRojP03o`0000goZ;oZ00?o0000ojRo
j_nX_nX03OnX_nX4o`0001Gooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`08oooo
o`009Oooool00ol0003oooooooooo`10ooooo`03o`000?n[_nSoZkoX00ooZkoX00?o0000ojjni_n^
_^H01?n^_^H4o`0000OoZKoY00?o0000oj^nion[_^L03on[_^L00ol0003o[KcUojfli@03ojfli@;o
00002_nY_nT00ol0003oZKkYojVnj@0?ojVnj@03o`000?nY_^WoZKkY00?o00002onX_nX00ol0003o
Z;oZojRojP0?ojRojP?o00004?nX_nX00ol0003oZ;oZojRojP0=ojRojPCo00004?nX_nX00ol0003o
Z;oZojRojP09ojRojPCo00006_ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo00So
oooo000Vooooo`03o`000?oooooooooo043ooooo00?o0000oj^oj?n[_nP03on[_nP00ol0003o[[kV
ojjniP03o`0000coZKoY00?o0000oj^nion[_^L03on[_^L00ol0003o[KcUo`000002o`0000goZKoY
00?o0000ojVnjOnY_^T03OnY_^T4o`0000ooZ;oZ00?o0000ojRoj_nX_nX02onX_nX3o`000003ojRo
j_l0003oZ;oZ017oZ;oZ00?o0000ojRoj_nX_nX02OnX_nX3o`0000?oZ;oZ00?o0000ojRoj_nX_nX0
3onX_nX00ol0003oZ;oZojRojP05ojRojP?o00007oooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo00Sooooo000Wooooo`03o`000?oooooooooo043ooooo0_l0000>oj^oj0Co00004?nY
_nT00ol0003oZkkWoj^ni`0=oj^ni`?o00004OnY_nT00ol0003oZKkYojVnj@09ojVnj@?o00000_nX
_nX00ol0003oZ;oZojRojP0?ojRojP03o`000?nX_n[oZ;oZ00OoZ;oZ0ol00005ojRojP03o`000?nX
_n[oZ;oZ013oZ;oZ00?o0000ojRoj_nX_nX01?nX_nX4o`0000OoZ;oZ00?o0000ojRoj_nX_nX03onX
_nX00ol0003oZ;oZojRojP04o`0002;ooooo00?o0000ooooooooool04oooool00ol0003ooooooooo
o`08ooooo`00:?ooool2o`0004;ooooo00?o0000oj^oj?n[_nP02?n[_nP3o`0000CoZKoY00?o0000
ojVojOnY_nT03_nY_nT00ol0003oZkkWoj^ni`09oj^ni`?o00000onX_nX00ol0003oZKoYojVoj@0?
ojVoj@03o`000?nY_^WoZKkY00CoZKkY1?l00006ojRojP03o`000?nX_n[oZ;oZ00ooZ;oZ00?o0000
ojRoj_nX_nX00onX_nX3o`0000WoZ;oZ00?o0000ojRoj_nX_nX04?nX_nX00ol0003oZ;oZojRojP03
o`0000coZ;oZ00?o0000ojRoj_nX_nX03OnX_nX4o`0002Oooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`08ooooo`00:_ooool00ol0003oooooooooo`10ooooo`03o`000?n[_nSoZkoX
00CoZkoX0ol00008ojVoj@03o`000?nY_nWoZKoY00koZKoY00?o0000oj^nion[_^L01?n[_^L4o`00
00OoZ;oZ00?o0000ojVojOnY_nT03onY_nT00ol0003oZKkYojVnj@03o`0000_oZ;oZ00?o0000ojRo
j_nX_nX03onX_nX00ol0003oZ;oZo`000002o`0000goZ;oZ00?o0000ojRoj_nX_nX03_nX_nX4o`00
013oZ;oZ00?o0000ojRoj_nX_nX02OnX_nX3o`0002cooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`08ooooo`00:oooool00ol0003oooooooooo`10ooooo`03o`000?n[_nSoZkoX00?o
00003?nY_nT00ol0003oZKoYojVoj@0>ojVoj@03o`000?n[_^OoZkkW00?o00003?nX_nX00ol0003o
ZKoYojVoj@0=ojVoj@Co00003onX_nX00ol0003oZ;oZojRojP0=ojRojP?o00004OnX_nX00ol0003o
Z;oZojRojP09ojRojPCo00000_nX_nX00ol0003oZ;oZojRojP0@ojRojP03o`000?nX_n[oZ;oZ00Co
Z;oZ1?l0000`ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool01oooool002cooooo
00?o0000ooooooooool0@?ooool2o`00013oZKoY00?o0000ojVojOnY_nT03?nY_nT4o`00013oZ;oZ
00?o0000ojVojOnY_nT02OnY_nT3o`0000?oZ;oZ00?o0000ojRoj_nX_nX03_nX_nX00ol0003oZ;oZ
ojRojP09ojRojP?o00000onX_nX00ol0003oZ;oZojRojP0?ojRojP03o`000?nX_n[oZ;oZ00GoZ;oZ
0ol00007ojRojP03o`000?nX_n[oZ;oZ013oZ;oZ00?o0000ojRoj_nX_nX00ol0000dooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool01oooool002gooooo0_l00011ooooo`03o`000?nY
_nWoZKoY00ooZKoY00?o0000ojVojOnY_nT02?nY_nT3o`0000CoZ;oZ00?o0000ojRoj_nX_nX03_nX
_nX00ol0003oZKoYojVoj@04ojVoj@Co00001onX_nX00ol0003oZ;oZojRojP0>ojRojP03o`000?nX
_n[oZ;oZ00CoZ;oZ1?l00007ojRojP03o`000?nX_n[oZ;oZ00ooZ;oZ00?o0000ojRoj_nX_nX01?l0
000;ojRojP03o`000?nX_n[oZ;oZ00ooZ;oZ0ol0000hooooo`03o`000?oooooooooo013ooooo00?o
0000ooooooooool01oooool002oooooo00?o0000ooooooooool0?oooool00ol0003oZKoYojVoj@0?
ojVoj@03o`000?nY_nWoZKoY00CoZKoY0ol00008ojRojP03o`000?nX_n[oZ;oZ00koZ;oZ00?o0000
ojVojOnY_nT00ol0000<ojRojP03o`000?nX_n[oZ;oZ00koZ;oZ00?o0000ojRoj_nX_nX00ol0000<
ojRojP03o`000?nX_n[oZ;oZ00goZ;oZ1?l0000@ojRojP03o`000?nX_n[oZ;oZ00_oZ;oZ0ol0000l
ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool01oooool0033ooooo00?o0000oooo
ooooool0?oooool00ol0003oZKoYojVoj@0?ojVoj@03o`000?nY_nWoZKoY00?o00003?nX_nX00ol0
003oZ;oZojRojP0<ojRojPCo00004?nX_nX00ol0003oZ;oZojRojP0<ojRojPCo00004?nX_nX00ol0
003oZ;oZojRojP09ojRojP?o00000_nX_nX00ol0003oZ;oZojRojP0?ojRojP03o`000?nX_n[oZ;oZ
00SoZ;oZ0ol00010ooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool01oooool0037o
oooo00?o0000ooooooooool0?oooool00ol0003oZKoYojVoj@0=ojVoj@Co00004?nX_nX00ol0003o
Z;oZojRojP08ojRojP?o00000onX_nX00ol0003oZ;oZojRojP0?ojRojP03o`000?nX_n[oZ;oZ00So
Z;oZ0ol00004ojRojP03o`000?nX_n[oZ;oZ00koZ;oZ00?o0000ojRoj_nX_nX01?nX_nX4o`0000Ko
Z;oZ00?o0000ojRoj_nX_nX03onX_nX00ol0003oZ;oZojRojP04ojRojP?o0000@oooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo00Oooooo000booooo`;o0000@?ooool00ol0003oZKoY
ojVoj@09ojVoj@?o00001?nX_nX00ol0003oZ;oZojRojP0>ojRojP03o`000?nX_n[oZ;oZ00CoZ;oZ
0ol00007ojRojP03o`000?nX_n[oZ;oZ00ooZ;oZ00?o0000ojRoj_nX_nX01?nX_nX3o`0000SoZ;oZ
00?o0000ojRoj_nX_nX03_nX_nX00ol0003oZ;oZojRojP03o`0000_oZ;oZ00?o0000ojRoj_nX_nX0
3onX_nX00ol0003oZ;oZojRojP03o`0004Oooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`07ooooo`00=?ooool00ol0003oooooooooo`0nooooo`03o`000?nY_nWoZKoY00CoZKoY1?l0
0008ojRojP03o`000?nX_n[oZ;oZ00koZ;oZ00?o0000ojRoj_nX_nX00ol0000;ojRojP03o`000?nX
_n[oZ;oZ00ooZ;oZ00?o0000ojRoj_nX_nX00ol0000<ojRojP03o`000?nX_n[oZ;oZ00coZ;oZ1?l0
000?ojRojP03o`000?nX_n[oZ;oZ00goZ;oZ1?l0001;ooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool01_ooool003Gooooo00?o0000ooooooooool0?_ooool00ol0003oZKoYojVoj@03
o`0000goZ;oZ00?o0000ojRoj_nX_nX03?nX_nX4o`0000ooZ;oZ00?o0000ojRoj_nX_nX03OnX_nX4
o`00013oZ;oZ00?o0000ojRoj_nX_nX02?nX_nX3o`0000;oZ;oZ00?o0000ojRoj_nX_nX03onX_nX0
0ol0003oZ;oZojRojP09ojRojP?o0000Coooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo00Kooooo000fooooo`03o`000?oooooooooo03kooooo0_l0000AojRojP03o`000?nX_n[oZ;oZ
00SoZ;oZ0ol00003ojRojP03o`000?nX_n[oZ;oZ00koZ;oZ00?o0000ojRoj_nX_nX02OnX_nX3o`00
00?oZ;oZ00?o0000ojRoj_nX_nX03onX_nX00ol0003oZ;oZojRojP04ojRojP?o00001_nX_nX00ol0
003oZ;oZojRojP0?ojRojP03o`000?nX_n[oZ;oZ00CoZ;oZ1?l0001Cooooo`03o`000?oooooooooo
00cooooo00?o0000ooooooooool01_ooool003Oooooo00?o0000ooooooooool0?oooool00ol0003o
Z;oZojRojP0?ojRojP03o`000?nX_n[oZ;oZ00CoZ;oZ0ol00007ojRojP03o`000?nX_n[oZ;oZ00ko
Z;oZ00?o0000ojRoj_nX_nX01?nX_nX4o`0000OoZ;oZ00?o0000ojRoj_nX_nX03onX_nX00ol0003o
Z;oZojRojP03o`0000[oZ;oZ00?o0000ojRoj_nX_nX03onX_nX00ol0003oZ;oZojRojP03o`0005So
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`06ooooo`00>?ooool2o`00043ooooo
00?o0000ojRoj_nX_nX03onX_nX00ol0003oZ;oZojRojP03o`0000_oZ;oZ00?o0000ojRoj_nX_nX0
3_nX_nX00ol0003oZ;oZojRojP03o`0000coZ;oZ00?o0000ojRoj_nX_nX03OnX_nX4o`0000koZ;oZ
00?o0000ojRoj_nX_nX03OnX_nX4o`0005cooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`06ooooo`00>_ooool00ol0003oooooooooo`0nooooo`;o00003_nX_nX4o`0000ooZ;oZ00?o
0000ojRoj_nX_nX03?nX_nX4o`00013oZ;oZ00?o0000ojRoj_nX_nX02OnX_nX3o`0000;oZ;oZ00?o
0000ojRoj_nX_nX03_nX_nX00ol0003oZ;oZojRojP09ojRojP?o0000H?ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00Kooooo000kooooo`03o`000?oooooooooo03oooooo00?o0000
ojRoj_nX_nX02?nX_nX3o`0000?oZ;oZ00?o0000ojRoj_nX_nX03_nX_nX00ol0003oZ;oZojRojP08
ojRojP?o00001?nX_nX00ol0003oZ;oZojRojP0>ojRojP03o`000?nX_n[oZ;oZ00CoZ;oZ1?l00006
ojRojP03o`000?nX_n[oZ;oZ00koZ;oZ00?o0000ojRoj_nX_nX01?nX_nX4o`0006Cooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`06ooooo`00??ooool00ol0003oooooooooo`0ooooo
o`03o`000?nX_n[oZ;oZ00CoZ;oZ0ol00007ojRojP03o`000?nX_n[oZ;oZ00koZ;oZ00?o0000ojRo
j_nX_nX01?nX_nX3o`0000SoZ;oZ00?o0000ojRoj_nX_nX03_nX_nX00ol0003oZ;oZojRojP03o`00
00_oZ;oZ00?o0000ojRoj_nX_nX03_nX_nX00ol0003oZ;oZojRojP03o`0006Wooooo00?o0000oooo
ooooool02?ooool00ol0003oooooooooo`06ooooo`00?Oooool2o`00043ooooo00?o0000ojRoj_nX
_nX00ol0000;ojRojP03o`000?nX_n[oZ;oZ00koZ;oZ00?o0000ojRoj_nX_nX00ol0000<ojRojP03
o`000?nX_n[oZ;oZ00coZ;oZ1?l0000?ojRojP03o`000?nX_n[oZ;oZ00coZ;oZ1?l0001]ooooo`03
o`000?oooooooooo00Sooooo00?o0000ooooooooool01Oooool003oooooo00?o0000ooooooooool0
?_ooool2o`0000ooZ;oZ00?o0000ojRoj_nX_nX03?nX_nX4o`00013oZ;oZ00?o0000ojRoj_nX_nX0
2?nX_nX3o`0000?oZ;oZ00?o0000ojRoj_nX_nX03_nX_nX00ol0003oZ;oZojRojP08ojRojP?o0000
LOooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo00Gooooo0010ooooo`03o`000?oo
oooooooo03kooooo00?o0000ojRoj_nX_nX03_nX_nX00ol0003oZ;oZojRojP08ojRojP?o00000onX
_nX00ol0003oZ;oZojRojP0?ojRojP03o`000?nX_n[oZ;oZ00CoZ;oZ0ol00007ojRojP03o`000?nX
_n[oZ;oZ00koZ;oZ00?o0000ojRoj_nX_nX01?nX_nX3o`0007Gooooo00?o0000ooooooooool01ooo
ool00ol0003oooooooooo`05ooooo`00@Oooool00ol0003oooooooooo`0nooooo`03o`000?nX_n[o
Z;oZ00koZ;oZ00?o0000ojRoj_nX_nX01?nX_nX3o`0000OoZ;oZ00?o0000ojRoj_nX_nX03onX_nX0
0ol0003oZ;oZojRojP03o`0000_oZ;oZ00?o0000ojRoj_nX_nX03_nX_nX00ol0003oZ;oZojRojP03
o`0007Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`00@_ooool2o`00
03oooooo00?o0000ojRoj_nX_nX03_nX_nX00ol0003oZ;oZojRojP03o`0000_oZ;oZ00?o0000ojRo
j_nX_nX03OnX_nX4o`0000ooZ;oZ00?o0000ojRoj_nX_nX03?nX_nX4o`0007cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`00A?ooool00ol0003oooooooooo`0mooooo`03
o`000?nX_n[oZ;oZ00coZ;oZ1?l0000?ojRojP03o`000?nX_n[oZ;oZ00WoZ;oZ0ol00003ojRojP03
o`000?nX_n[oZ;oZ00koZ;oZ00?o0000ojRoj_nX_nX01_nX_nX5o`00087ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`00AOooool00ol0003oooooooooo`0mooooo`03o`00
0?nX_n[oZ;oZ00SoZ;oZ0ol00003ojRojP03o`000?nX_n[oZ;oZ00koZ;oZ00?o0000ojRoj_nX_nX0
1?nX_nX4o`0000OoZ;oZ00?o0000ojRoj_nX_nX03_nX_nX00ol0003oZ;oZojRojP05o`0008Oooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`00A_ooool00ol0003ooooooooo
o`0mooooo`03o`000?nX_n[oZ;oZ00CoZ;oZ0ol00007ojRojP03o`000?nX_n[oZ;oZ00koZ;oZ00?o
0000ojRoj_nX_nX00ol0000<ojRojP03o`000?nX_n[oZ;oZ00coZ;oZ1?l0002=ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01Oooool004Oooooo0_l0000nooooo`03o`000?nX_n[o
Z;oZ00?o00002onX_nX00ol0003oZ;oZojRojP0<ojRojPCo00004?nX_nX00ol0003oZ;oZojRojP08
ojRojP?o0000TOooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo0019oooo
o`03o`000?oooooooooo03cooooo0_l0000?ojRojP03o`000?nX_n[oZ;oZ00SoZ;oZ0ol00004ojRo
jP03o`000?nX_n[oZ;oZ00koZ;oZ00?o0000ojRoj_nX_nX01?nX_nX3o`0009Gooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`04ooooo`00B_ooool00ol0003oooooooooo`0mooooo`03
o`000?nX_n[oZ;oZ00goZ;oZ00?o0000ojRoj_nX_nX01?nX_nX3o`0000SoZ;oZ00?o0000ojRoj_nX
_nX03_nX_nX00ol0003oZ;oZojRojP03o`0009Wooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`04ooooo`00Boooool00ol0003oooooooooo`0mooooo`03o`000?nX_n[oZ;oZ00goZ;oZ
00?o0000ojRoj_nX_nX00ol0000<ojRojP03o`000?nX_n[oZ;oZ00coZ;oZ1?l0002Mooooo`05o`00
0?ooooooooooooooool000001_ooool004cooooo0_l0000nooooo`03o`000?nX_n[oZ;oZ00coZ;oZ
0ol0000@ojRojP03o`000?nX_n[oZ;oZ00SoZ;oZ0ol0002Qooooo`05o`000?ooooooooooooooool0
00001_ooool004kooooo00?o0000ooooooooool0??ooool00ol0003oZ;oZojRojP08ojRojP?o0000
0onX_nX00ol0003oZ;oZojRojP0>ojRojP03o`000?nX_n[oZ;oZ00CoZ;oZ0ol0002Uooooo`04o`00
0?ooooooooooo`0000Kooooo001?ooooo`03o`000?oooooooooo03cooooo00?o0000ojRoj_nX_nX0
1?nX_nX3o`0000OoZ;oZ00?o0000ojRoj_nX_nX03_nX_nX00ol0003oZ;oZojRojP03o`000:Wooooo
00?o0000ooooool000001_ooool0053ooooo00?o0000ooooooooool0??ooool00ol0003oZ;oZojRo
jP03o`0000_oZ;oZ00?o0000ojRoj_nX_nX03?nX_nX4o`000:cooooo00Co0000oooooooooooo0000
1Oooool0057ooooo0_l0000mooooo`;o00003onX_nX00ol0003oZ;oZojRojP08ojRojP?o0000/Ooo
ool00ol0003oooooo`000005ooooo`00Doooool00ol0003oooooooooo`0looooo`03o`000?nX_n[o
Z;oZ00goZ;oZ00?o0000ojRoj_nX_nX01?nX_nX3o`000;Gooooo0_l00005ooooo`00E?ooool00ol0
003oooooooooo`0looooo`03o`000?nX_n[oZ;oZ00goZ;oZ00?o0000ojRoj_nX_nX00ol0002goooo
o`?o00001Oooool005Gooooo00?o0000ooooooooool0??ooool00ol0003oZ;oZojRojP0;ojRojPCo
0000]_ooool4o`0000Sooooo001Fooooo`03o`000?oooooooooo03cooooo00?o0000ojRoj_nX_nX0
1OnX_nX5o`000;Kooooo1?l0000<ooooo`00Eoooool2o`0003gooooo00?o0000ojRoj_nX_nX01?l0
002gooooo`Co00004?ooool005Wooooo00?o0000ooooooooool0>oooool2o`000;Sooooo0ol0000D
ooooo`00F_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo0;?ooooo1?l0000Goooo
o`00Foooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo0:oooooo1?l0000Kooooo`00
G?ooool2o`0003Wooooo00?o0000ooooooooool0Zoooool4o`0001oooooo001Nooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool0Yoooool4o`0002?ooooo001Oooooo`03o`000?oooooo
oooo03Gooooo00?o0000ooooooooool0Xoooool4o`0002Oooooo001Pooooo`03o`000?oooooooooo
03Cooooo00?o0000ooooooooool0Woooool4o`0002_ooooo001Qooooo`;o0000=?ooool00ol0003o
ooooooooo`2Looooo`?o0000;oooool006?ooooo00?o0000ooooooooool0<Oooool00ol0003ooooo
ooooo`2Hooooo`Co0000<_ooool006Cooooo00?o0000ooooooooool0<?ooool00ol0003ooooooooo
o`2Dooooo`Co0000=_ooool006Gooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`2@
ooooo`Co0000>_ooool006Kooooo0_l0000_ooooo`03o`000?oooooooooo08cooooo1?l0000noooo
o`00J?ooool00ol0003oooooooooo`0/ooooo`03o`000?oooooooooo08Sooooo1?l00012ooooo`00
JOooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo08Cooooo1?l00016ooooo`00J_oo
ool00ol0003oooooooooo`0Yooooo`03o`000?oooooooooo087ooooo1?l0001:ooooo`00Joooool2
o`0002Wooooo00?o0000ooooooooool0O_ooool3o`0004kooooo001]ooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool0N_ooool4o`00057ooooo001^ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0M_ooool4o`0005Gooooo001_ooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool0L_ooool4o`0005Wooooo001`ooooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool0K_ooool4o`0005gooooo001aooooo`;o00008oooool00ol0003oooooooooo`1Z
ooooo`Co0000HOooool007?ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1Voooo
o`Co0000IOooool007Cooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`1Rooooo`Co
0000JOooool007Gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1Oooooo`?o0000
KOooool007Kooooo0_l0000Nooooo`03o`000?oooooooooo05_ooooo1?l0001`ooooo`00N?ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo05Oooooo1?l0001dooooo`00NOooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo05?ooooo1?l0001hooooo`00N_ooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo04oooooo1?l0001looooo`00Noooool2o`0001Wooooo
00?o0000ooooooooool0Boooool4o`00083ooooo001mooooo`03o`000?oooooooooo01Kooooo00?o
0000ooooooooool0Aoooool4o`0008Cooooo001nooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool0A?ooool3o`0008Sooooo001oooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool0@?ooool4o`0008_ooooo0020ooooo`;o00005?ooool00ol0003oooooooooo`0looooo`Co
0000Soooool008;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`0hooooo`Co0000
Toooool008?ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0dooooo`Co0000Uooo
ool008Cooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0`ooooo`Co0000Voooool0
08Gooooo0_l0000?ooooo`03o`000?oooooooooo02cooooo1?l0002Oooooo`00Qoooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo02Sooooo1?l0002Sooooo`00R?ooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo02Kooooo0ol0002Wooooo`00ROooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo02;ooooo1?l0002Zooooo`00R_ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo01kooooo1?l0002^ooooo`00Roooool2o`0000Sooooo00?o0000oooo
ooooool06_ooool4o`000;;ooooo002=ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool05_ooool4o`000;Kooooo002>ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
4_ooool4o`000;[ooooo002?ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool03_oo
ool4o`000;kooooo002@ooooo`;o00000oooool00ol0003oooooooooo`0;ooooo`?o0000`_ooool0
09;ooooo00Co0000oooooooooooo00002Oooool4o`000<Gooooo002Cooooo`03o`000?oooooo0000
00Gooooo1?l00039ooooo`00U?ooool2o`000003ooooool0003o000000;o0000cOooool009Gooooo
0_l0003Aooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {290.938, 0}} -> {-0.040844, 0.0227724, \
0.00350012, 0.00350012}}]
}, Open  ]],

Cell[BoxData[
    \(\(phasedata\  = \ 
        Table[{x[t], 
              y[t], \[Phi][t]} /. \(sol[{x0, y0}, 
                k0[{x0, 
                    y0}]]\)[\([1]\)], {y0, \(- .9\),  .9,  .2}, {x0, \
\(-1.5\), 1.5,  .2}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 5.47"],

Cell[BoxData[
    \(\(Table[
        Table[ScatterPlot3D[phasedata[\([n]\)], PlotJoined \[Rule] True, 
            PlotStyle \[Rule] Hue[n/Length[phasedata]], 
            DisplayFunction \[Rule] Identity], {n, 1, 
            Length[phasedata]}], {t,  .5, 6,  .2}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 5.48"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Table[
        Show[%[\([n]\)], DisplayFunction \[Rule] $DisplayFunction, 
          PlotRange \[Rule] {{\(-2\), 2}, {\(- .5\), 7}, {\(-1\), 1}}], {n, 
          1, Length[%]}];\)\)], "Input",
  ShowCellTags->True,
  CellTags->"Cell 5.49"],

Cell[CellGroupData[{

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .92059 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-16 1.0763 -0.0263982 1.0763 [
[.01694 .18568 -11.9631 -9 ]
[.01694 .18568 .03693 0 ]
[.13793 .13897 -11.619 -9 ]
[.13793 .13897 .38095 0 ]
[.26292 .09073 -5.63752 -9 ]
[.26292 .09073 .36248 0 ]
[.39212 .04087 -5.46552 -9 ]
[.39212 .04087 .53448 0 ]
[.52574 -0.01069 -5.29351 -9 ]
[.52574 -0.01069 .70649 0 ]
[.58272 .04263 0 -6.19654 ]
[.58272 .04263 6 2.80346 ]
[.71715 .21863 0 -6.07114 ]
[.71715 .21863 6 2.92886 ]
[.83675 .37523 0 -5.963 ]
[.83675 .37523 6 3.037 ]
[.94385 .51546 0 -5.8688 ]
[.94385 .51546 6 3.1312 ]
[.01386 .20006 -12 -2.76892 ]
[.01386 .20006 0 6.23108 ]
[.00748 .25499 -24 -2.80073 ]
[.00748 .25499 0 6.19927 ]
[.00093 .31131 -6 -2.83339 ]
[.00093 .31131 0 6.16661 ]
[-0.00579 .36907 -18 -2.86695 ]
[-0.00579 .36907 0 6.13305 ]
[-0.01268 .42831 -6 -2.90143 ]
[-0.01268 .42831 0 6.09857 ]
[ 0 0 0 0 ]
[ 1 .92059 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02642 .19522 m
.53391 0 L
s
.02642 .19522 m
.03116 .2 L
s
[(-2)] .01694 .18568 .99384 1 Mshowa
.14712 .14879 m
.15172 .1537 L
s
[(-1)] .13793 .13897 .93651 1 Mshowa
.2718 .10083 m
.27624 .10588 L
s
[(0)] .26292 .09073 .87917 1 Mshowa
.40066 .05126 m
.40493 .05646 L
s
[(1)] .39212 .04087 .82184 1 Mshowa
.53391 0 m
.538 .00534 L
s
[(2)] .52574 -0.01069 .7645 1 Mshowa
.125 Mabswid
.05025 .18606 m
.05308 .18894 L
s
.07424 .17683 m
.07705 .17973 L
s
.09837 .16755 m
.10117 .17046 L
s
.12267 .1582 m
.12545 .16113 L
s
.17173 .13933 m
.17447 .14229 L
s
.19651 .1298 m
.19923 .13278 L
s
.22144 .1202 m
.22414 .1232 L
s
.24654 .11055 m
.24922 .11356 L
s
.29723 .09105 m
.29988 .0941 L
s
.32283 .0812 m
.32546 .08427 L
s
.3486 .07129 m
.35121 .07437 L
s
.37455 .06131 m
.37713 .06441 L
s
.42695 .04115 m
.4295 .04428 L
s
.45342 .03096 m
.45594 .03412 L
s
.48007 .02071 m
.48257 .02388 L
s
.5069 .01039 m
.50938 .01358 L
s
.25 Mabswid
.53391 0 m
.9804 .58403 L
s
.57014 .04738 m
.56384 .04975 L
s
[(0)] .58272 .04263 -1 .37701 Mshowa
.70445 .22307 m
.6981 .22529 L
s
[(2)] .71715 .21863 -1 .34914 Mshowa
.82396 .37939 m
.81756 .38147 L
s
[(4)] .83675 .37523 -1 .32511 Mshowa
.93098 .51938 m
.92454 .52134 L
s
[(6)] .94385 .51546 -1 .30418 Mshowa
.125 Mabswid
.60525 .09331 m
.60147 .09471 L
s
.63931 .13786 m
.63552 .13924 L
s
.67236 .1811 m
.66856 .18245 L
s
.73562 .26383 m
.7318 .26514 L
s
.7659 .30345 m
.76207 .30473 L
s
.79534 .34195 m
.7915 .34322 L
s
.85181 .41581 m
.84796 .41704 L
s
.87891 .45126 m
.87506 .45247 L
s
.90529 .48577 m
.90143 .48696 L
s
.95601 .55212 m
.95214 .55328 L
s
.25 Mabswid
.02642 .19522 m
0 .42381 L
s
.02642 .19522 m
.0327 .19281 L
s
[(-1)] .01386 .20006 1 -0.38468 Mshowa
.02006 .25024 m
.02635 .24786 L
s
[(-0.5)] .00748 .25499 1 -0.37762 Mshowa
.01354 .30664 m
.01985 .3043 L
s
[(0)] .00093 .31131 1 -0.37036 Mshowa
.00686 .36448 m
.01318 .36218 L
s
[(0.5)] -0.00579 .36907 1 -0.3629 Mshowa
0 .42381 m
.00634 .42156 L
s
[(1)] -0.01268 .42831 1 -0.35524 Mshowa
.125 Mabswid
.02516 .20612 m
.02893 .20468 L
s
.0239 .21707 m
.02767 .21563 L
s
.02262 .22807 m
.0264 .22664 L
s
.02135 .23913 m
.02512 .2377 L
s
.01877 .26141 m
.02255 .25999 L
s
.01747 .27263 m
.02125 .27122 L
s
.01617 .28391 m
.01995 .2825 L
s
.01486 .29525 m
.01864 .29384 L
s
.01222 .31809 m
.01601 .3167 L
s
.01089 .3296 m
.01468 .32821 L
s
.00955 .34117 m
.01334 .33978 L
s
.00821 .35279 m
.012 .35141 L
s
.0055 .37622 m
.0093 .37485 L
s
.00414 .38803 m
.00793 .38666 L
s
.00276 .39989 m
.00656 .39853 L
s
.00139 .41182 m
.00519 .41047 L
s
.25 Mabswid
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.54154 .92059 L
s
.54154 .92059 m
.5414 .7134 L
s
.5414 .7134 m
.02642 .19522 L
s
.53391 0 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.53391 0 m
.02642 .19522 L
s
.5414 .7134 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.54154 .92059 L
s
.54154 .92059 m
.5414 .7134 L
s
0 0 m
1 0 L
1 .92059 L
0 .92059 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.22093 .5386 m
.24532 .53047 L
s
1 0 .6 r
.2069 .50041 m
.23129 .49221 L
s
.8 0 1 r
.19282 .46209 m
.2172 .45377 L
s
.2 0 1 r
.17871 .42369 m
.20306 .41524 L
s
1 0 0 r
.24532 .53047 m
.26983 .52225 L
s
0 .4 1 r
.16456 .38521 m
.1889 .37663 L
s
1 0 .6 r
.23129 .49221 m
.25584 .48396 L
s
0 1 1 r
.15039 .34665 m
.17471 .33794 L
s
.8 0 1 r
.2172 .45377 m
.24173 .4454 L
s
0 1 .4 r
.1362 .30802 m
.16049 .29917 L
s
.2 0 1 r
.20306 .41524 m
.22758 .40673 L
s
1 0 0 r
.26983 .52225 m
.29445 .51394 L
s
.2 1 0 r
.12197 .26931 m
.14624 .26033 L
s
0 .4 1 r
.1889 .37663 m
.21339 .36799 L
s
1 0 .6 r
.25584 .48396 m
.28054 .47564 L
s
.8 1 0 r
.10772 .23052 m
.13197 .22141 L
s
0 1 1 r
.17471 .33794 m
.19918 .32917 L
s
.8 0 1 r
.24173 .4454 m
.26642 .43697 L
s
1 .6 0 r
.09344 .19166 m
.11767 .18241 L
s
0 1 .4 r
.16049 .29917 m
.18494 .29027 L
s
.2 0 1 r
.22758 .40673 m
.25225 .39818 L
s
1 0 0 r
.29445 .51394 m
.3192 .50555 L
s
.2 1 0 r
.14624 .26033 m
.17067 .25129 L
s
0 .4 1 r
.21339 .36799 m
.23804 .3593 L
s
1 0 .6 r
.28054 .47564 m
.30539 .46727 L
s
.8 1 0 r
.13197 .22141 m
.15638 .21223 L
s
0 1 1 r
.19918 .32917 m
.22381 .32034 L
s
.8 0 1 r
.26642 .43697 m
.29127 .42849 L
s
1 .6 0 r
.11767 .18241 m
.14205 .1731 L
s
0 1 .4 r
.18494 .29027 m
.20955 .2813 L
s
.2 0 1 r
.25225 .39818 m
.27708 .38956 L
s
1 0 0 r
.3192 .50555 m
.34408 .49712 L
s
.2 1 0 r
.17067 .25129 m
.19526 .24219 L
s
0 .4 1 r
.23804 .3593 m
.26286 .35055 L
s
1 0 .6 r
.30539 .46727 m
.33039 .45884 L
s
.8 1 0 r
.15638 .21223 m
.18094 .203 L
s
0 1 1 r
.22381 .32034 m
.2486 .31145 L
s
.8 0 1 r
.29127 .42849 m
.31629 .41995 L
s
1 .6 0 r
.14205 .1731 m
.16659 .16373 L
s
0 1 .4 r
.20955 .2813 m
.23432 .27228 L
s
.2 0 1 r
.27708 .38956 m
.30208 .38089 L
s
1 0 0 r
.34408 .49712 m
.36913 .48867 L
s
.2 1 0 r
.19526 .24219 m
.22001 .23303 L
s
0 .4 1 r
.26286 .35055 m
.28783 .34174 L
s
1 0 .6 r
.33039 .45884 m
.35557 .45036 L
s
.8 1 0 r
.18094 .203 m
.20566 .19371 L
s
0 1 1 r
.2486 .31145 m
.27355 .30251 L
s
.8 0 1 r
.31629 .41995 m
.34146 .41136 L
s
1 .6 0 r
.16659 .16373 m
.1913 .1543 L
s
0 1 .4 r
.23432 .27228 m
.25925 .26321 L
s
.2 0 1 r
.30208 .38089 m
.32723 .37216 L
s
1 0 0 r
.36913 .48867 m
.39439 .48023 L
s
.2 1 0 r
.22001 .23303 m
.24491 .22382 L
s
0 .4 1 r
.28783 .34174 m
.31296 .33288 L
s
1 0 .6 r
.35557 .45036 m
.38091 .44184 L
s
.8 1 0 r
.20566 .19371 m
.23055 .18435 L
s
0 1 1 r
.27355 .30251 m
.29867 .29351 L
s
.8 0 1 r
.34146 .41136 m
.3668 .40271 L
s
1 .6 0 r
.1913 .1543 m
.21616 .14481 L
s
0 1 .4 r
.25925 .26321 m
.28434 .25407 L
s
.2 0 1 r
.32723 .37216 m
.35255 .36338 L
s
1 0 0 r
.39439 .48023 m
.41987 .47182 L
s
.2 1 0 r
.24491 .22382 m
.26998 .21454 L
s
0 .4 1 r
.31296 .33288 m
.33826 .32396 L
s
1 0 .6 r
.38091 .44184 m
.40643 .43327 L
s
.8 1 0 r
.23055 .18435 m
.2556 .17494 L
s
0 1 1 r
.29867 .29351 m
.32395 .28445 L
s
.8 0 1 r
.3668 .40271 m
.39231 .39401 L
s
1 .6 0 r
.21616 .14481 m
.24119 .13526 L
s
0 1 .4 r
.28434 .25407 m
.3096 .24487 L
s
.2 0 1 r
.35255 .36338 m
.37804 .35454 L
s
1 0 0 r
.41987 .47182 m
.44561 .46343 L
s
.2 1 0 r
.26998 .21454 m
.29522 .20521 L
s
0 .4 1 r
.33826 .32396 m
.36373 .31498 L
s
1 0 .6 r
.40643 .43327 m
.43213 .42467 L
s
.8 1 0 r
.2556 .17494 m
.28081 .16546 L
s
0 1 1 r
.32395 .28445 m
.34939 .27533 L
s
.8 0 1 r
.39231 .39401 m
.41799 .38525 L
s
1 .6 0 r
.24119 .13526 m
.26638 .12564 L
s
0 1 .4 r
.3096 .24487 m
.33502 .23561 L
s
.2 0 1 r
.37804 .35454 m
.4037 .34564 L
s
1 0 0 r
.44561 .46343 m
.47159 .45503 L
s
.2 1 0 r
.29522 .20521 m
.32062 .19581 L
s
0 .4 1 r
.36373 .31498 m
.38936 .30594 L
s
1 0 .6 r
.43213 .42467 m
.45801 .41601 L
s
.8 1 0 r
.28081 .16546 m
.30619 .15592 L
s
0 1 1 r
.34939 .27533 m
.375 .26616 L
s
.8 0 1 r
.41799 .38525 m
.44383 .37643 L
s
1 .6 0 r
.26638 .12564 m
.29174 .11596 L
s
0 1 .4 r
.33502 .23561 m
.36061 .22629 L
s
.2 0 1 r
.4037 .34564 m
.42952 .33668 L
s
1 0 0 r
.47159 .45503 m
.4978 .44661 L
s
.2 1 0 r
.32062 .19581 m
.34619 .18635 L
s
0 .4 1 r
.38936 .30594 m
.41517 .29684 L
s
1 0 .6 r
.45801 .41601 m
.48408 .4073 L
s
.8 1 0 r
.30619 .15592 m
.33174 .14632 L
s
0 1 1 r
.375 .26616 m
.40078 .25692 L
s
.8 0 1 r
.44383 .37643 m
.46985 .36756 L
s
1 .6 0 r
.29174 .11596 m
.31726 .10622 L
s
0 1 .4 r
.36061 .22629 m
.38637 .21691 L
s
.2 0 1 r
.42952 .33668 m
.45552 .32766 L
s
1 0 0 r
.4978 .44661 m
.5242 .43812 L
s
.2 1 0 r
.34619 .18635 m
.37193 .17683 L
s
0 .4 1 r
.41517 .29684 m
.44114 .28768 L
s
1 0 .6 r
.48408 .4073 m
.51032 .39854 L
s
.8 1 0 r
.33174 .14632 m
.35746 .13666 L
s
0 1 1 r
.40078 .25692 m
.42674 .24762 L
s
.8 0 1 r
.46985 .36756 m
.49604 .35862 L
s
1 .6 0 r
.31726 .10622 m
.34296 .09641 L
s
0 1 .4 r
.38637 .21691 m
.4123 .20747 L
s
.2 0 1 r
.45552 .32766 m
.48168 .31859 L
s
1 0 0 r
.5242 .43812 m
.55077 .42955 L
s
.2 1 0 r
.37193 .17683 m
.39784 .16724 L
s
0 .4 1 r
.44114 .28768 m
.46729 .27846 L
s
1 0 .6 r
.51032 .39854 m
.53672 .3897 L
s
.8 1 0 r
.35746 .13666 m
.38335 .12693 L
s
0 1 1 r
.42674 .24762 m
.45286 .23825 L
s
.8 0 1 r
.49604 .35862 m
.52241 .34963 L
s
1 .6 0 r
.34296 .09641 m
.36883 .08653 L
s
0 1 .4 r
.4123 .20747 m
.43841 .19796 L
s
.2 0 1 r
.48168 .31859 m
.50803 .30945 L
s
1 0 0 r
.55077 .42955 m
.57748 .42087 L
s
.2 1 0 r
.39784 .16724 m
.42392 .15759 L
s
0 .4 1 r
.46729 .27846 m
.49361 .26918 L
s
1 0 .6 r
.53672 .3897 m
.56331 .38081 L
s
.8 1 0 r
.38335 .12693 m
.40941 .11713 L
s
0 1 1 r
.45286 .23825 m
.47916 .22883 L
s
.8 0 1 r
.52241 .34963 m
.54895 .34058 L
s
1 .6 0 r
.36883 .08653 m
.39487 .07659 L
s
0 1 .4 r
.43841 .19796 m
.46469 .18839 L
s
.2 0 1 r
.50803 .30945 m
.53455 .30025 L
s
1 0 0 r
.57748 .42087 m
.60433 .4121 L
s
.2 1 0 r
.42392 .15759 m
.45018 .14787 L
s
0 .4 1 r
.49361 .26918 m
.52011 .25983 L
s
1 0 .6 r
.56331 .38081 m
.59006 .37184 L
s
.8 1 0 r
.40941 .11713 m
.43565 .10727 L
s
0 1 1 r
.47916 .22883 m
.50564 .21934 L
s
.8 0 1 r
.54895 .34058 m
.57567 .33146 L
s
1 .6 0 r
.39487 .07659 m
.42108 .06659 L
s
0 1 .4 r
.46469 .18839 m
.49114 .17876 L
s
.2 0 1 r
.53455 .30025 m
.56124 .29099 L
s
.2 1 0 r
.45018 .14787 m
.47662 .13809 L
s
0 .4 1 r
.52011 .25983 m
.54679 .25043 L
s
.8 1 0 r
.43565 .10727 m
.46206 .09734 L
s
0 1 1 r
.50564 .21934 m
.5323 .20979 L
s
1 .6 0 r
.42108 .06659 m
.44747 .05651 L
s
0 1 .4 r
.49114 .17876 m
.51778 .16906 L
s
.2 1 0 r
.47662 .13809 m
.50323 .12825 L
s
.8 1 0 r
.46206 .09734 m
.48865 .08735 L
s
1 .6 0 r
.44747 .05651 m
.47404 .04637 L
s
0 g
.25 Mabswid
.53391 0 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.53391 0 m
.02642 .19522 L
s
.02642 .19522 m
.53391 0 L
s
.02642 .19522 m
.03116 .2 L
s
[(-2)] .01694 .18568 .99384 1 Mshowa
.14712 .14879 m
.15172 .1537 L
s
[(-1)] .13793 .13897 .93651 1 Mshowa
.2718 .10083 m
.27624 .10588 L
s
[(0)] .26292 .09073 .87917 1 Mshowa
.40066 .05126 m
.40493 .05646 L
s
[(1)] .39212 .04087 .82184 1 Mshowa
.53391 0 m
.538 .00534 L
s
[(2)] .52574 -0.01069 .7645 1 Mshowa
.125 Mabswid
.05025 .18606 m
.05308 .18894 L
s
.07424 .17683 m
.07705 .17973 L
s
.09837 .16755 m
.10117 .17046 L
s
.12267 .1582 m
.12545 .16113 L
s
.17173 .13933 m
.17447 .14229 L
s
.19651 .1298 m
.19923 .13278 L
s
.22144 .1202 m
.22414 .1232 L
s
.24654 .11055 m
.24922 .11356 L
s
.29723 .09105 m
.29988 .0941 L
s
.32283 .0812 m
.32546 .08427 L
s
.3486 .07129 m
.35121 .07437 L
s
.37455 .06131 m
.37713 .06441 L
s
.42695 .04115 m
.4295 .04428 L
s
.45342 .03096 m
.45594 .03412 L
s
.48007 .02071 m
.48257 .02388 L
s
.5069 .01039 m
.50938 .01358 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 265.125},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001Bb000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00`oooool5o`000:3ooooo0033ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@0X?ooool00<Cooooo00?oV9RHob4Q8Oo^k^h0XOooool00<Gooooo00?oV9RH
ob4Q8Oo^k^h0X?ooool00<Kooooo00?oMgMgofIVI_ooool0Woooool00<Oooooo00?o0000oooooooo
ool0W_ooool00<?ooooo00Go0000okZj^_ooooooV9RHoa0@402Pooooo`00`oooool01OnHV9So410@
o`000?lQ8B7oc<c<0:3ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003;ooooo`;o0000Voooool00<Sooooo0ol000000ooooooo0000ooooo`2Jooooo`00a_oo
ool2o`0000Cooooo0_l0002Jooooo`00`oooool3o`0000Kooooo00?o0000ooooool00000VOooool0
0<3ooooo1?l00008ooooo`04o`000?ooooooooooo`0009Sooooo002Hooooo`Co000000?o410@oooo
ooooool07oooool2o`0000Cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0002H
ooooo`00V_ooool00ol0003oooooooooo`0Nooooo`?o00003_ooool01Ol0003ooooooooooooooooo
000009Oooooo002Jooooo`03o`000?oooooooooo01cooooo0_l0000Aooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0U?ooool009[ooooo00?o0000ooooooooool06Oooool3o`0000;o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo09?o
oooo002Jooooo`03o`000?oooooooooo01Kooooo0ol0000Fooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^08Kooooo002Jooooo`03o`00
0?oooooooooo01Cooooo0_l0000Iooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1oooool01OmgMgOoV9RHoooooonHV9SoMgMg08Kooooo002Jooooo`03o`000?oooooooooo017ooooo
0ol000000ooooooo0000ooooo`0Hooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1_ooool01Ol@413ooooooooooooooooo410@08Kooooo002Hooooo`03oeEEEOmVIVKo0000017ooooo
0_l0000Nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool01Ol0003ooooo
oooooooooooo000008Kooooo002Yooooo`?o00008?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000026ooooo`00Yoooool3o`0002;ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@
4100Q_ooool00:Cooooo0ol00002ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Q_ooool00:7ooooo
0ol0000Cooooo`;ooiT04oooool00ol0003oooooooooo`08ooooo`;o00001?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^08Kooooo002Oooooo`;o00004oooool3oonI01Gooooo00?o0000ooooooooool0
1oooool01?l0003oooooooooool0002>ooooo`00W?ooool3o`000003ooooool0003ooooo00oooooo
0oooV@0Hooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0S?ooool009[ooooo0_l0
0005ooooo`03o`000?oooooooooo00[ooooo0oooV@0Kooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0Roooool009Oooooo0ol0000Aooooo`?ooiT07_ooool00ol0003oooooooooo`0<
ooooo`03o`000?oooooooooo08[ooooo001/ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h08oooool3
o`000003ooooool0003ooooo00kooooo0oooV@0Qooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0ROooool006cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Qooooo`;o00004_ooool2
oonI02Cooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`29ooooo`00K?ooool01Ol@
413ooooooooooooooooo410@01kooooo0ol0000Booooo`;ooiT09_ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo08Sooooo001/ooooo`05o`000?ooooooooooooooool000007?ooool3
o`00017ooooo0oooV@0Xooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Qoooool0
06cooooo00Go0000ooooooooooooooooo`00000Iooooo`?o00000_ooool00ol0003oooooooooo`0=
ooooo`;ooiT0:oooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo08Kooooo001/oooo
o`05oa0@4?ooooooooooooooool@41005oooool2o`0001?ooooo0_ooV@0]ooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool0Q_ooool006cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0D
ooooo`?o00004_ooool3oonI02oooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`25
ooooo`00K?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^017ooooo0ol00002ooooo`03o`000?oooooo
oooo00gooooo0oooV@0booooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0Q?ooool0
083ooooo0_l0000Booooo`?ooiT09Oooool2olco00kooooo00?o0000ooooooooool04oooool00ol0
003oooooooooo`23ooooo`00OOooool3o`00017ooooo0oooV@0Uooooo`?oc?l04?ooool00ol0003o
ooooooooo`0Dooooo`03o`000?oooooooooo08;ooooo001kooooo`;o000000?oooooo`000?ooool0
3_ooool3oonI02Gooooo0oo<o`0Cooooo`03o`000?oooooooooo01Cooooo0_l00023ooooo`00N?oo
ool3o`00017ooooo0_ooV@0Uooooo`?oc?l05_ooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooo000008?ooooo001eooooo`?o00004Oooool3oonI02Gooooo0_o<o`0Iooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool0P?ooool007?ooooo1?l0000?ooooo`?ooiT09Oooool3olco
01_ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1oooooo`00L?ooool3o`0000Co
oooo00?o0000ooooooooool02Oooool3oonI02Kooooo0_o<o`0Nooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool0Ooooool006kooooo0_l0000Aooooo`;ooiT09oooool2olco023ooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`1nooooo`00@oooool4o`000003oa0@4?oo
oooooooo027ooooo0ol0000Aooooo`;ooiT09_ooool3olco02;ooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`1mooooo`00AOooool00ol0003oooooooooo`0Pooooo`?o00000oooool0
0ol0003oooooooooo`0<ooooo`;ooiT09Oooool3olco02Gooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`1looooo`00>_ooool6o`0000Gooooo00?o0000ooooooooool07_ooool2o`00
01?ooooo0_ooV@0Uooooo`;oc?l0:?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
07cooooo0015ooooo`03o`000?oooooooooo01_ooooo0ol0000Booooo`?ooiT09?ooool3olco02[o
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1kooooo`00AOooool00ol0003ooooo
ooooo`0Iooooo`;o00000_ooool00ol0003oooooooooo`0=ooooo`?ooiT09?ooool3olco02gooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`1jooooo`00AOooool00ol0003ooooooooo
o`0Fooooo`?o00004Oooool3oonI02Cooooo0oo<o`0`ooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool0NOooool004Gooooo00?o0000ooooooooool05?ooool2o`00017ooooo0oooV@0T
ooooo`?oc?l0:?ooool2oc?o00Wooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1i
ooooo`00@oooool00omEEEGoIVIVo`00000Cooooo`?o000000?oooooo`000?ooool03Oooool3oonI
02Cooooo0oo<o`0Xooooo`?o<ol02oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
07Sooooo001Fooooo`?o00004Oooool2oonI02Gooooo0_o<o`0Xooooo`?o<ol03_ooool00ol0003o
ooooooooo`0Oooooo`03o`000?oooooooooo07Oooooo001Dooooo`;o00004Oooool3oonI02Gooooo
0_o<o`0Wooooo`?o<ol04Oooool00ol0003oooooooooo`0Oooooo`;o0000N?ooool0057ooooo0ol0
00000ooooooo0000ooooo`0=ooooo`?ooiT09Oooool3olco02Kooooo0olco`0Dooooo`03o`000?oo
oooooooo023ooooo00?o0000ooooooooool0M_ooool004oooooo0_l0000Aooooo`;ooiT09_ooool2
olco02Kooooo0olco`0Gooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0MOooool0
04cooooo0ol0000@ooooo`?ooiT09_ooool2olco02Gooooo0olco`0Jooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool0M?ooool004Wooooo1?l0000?ooooo`?ooiT09_ooool3olco02Co
oooo0olco`0Mooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0Loooool004Oooooo
0_l00004ooooo`03o`000?oooooooooo00Wooooo0oooV@0Vooooo`?oc?l09?ooool3oc?o023ooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`1booooo`00A?ooool3o`0000oooooo0ooo
V@0Wooooo`;oc?l09Oooool2oc?o02?ooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`1booooo`006_ooool5o`0002?ooooo0ol0000>ooooo`?ooiT09oooool3olco02Gooooo0_lco`0U
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0LOooool001[ooooo00GoV9RHob4Q
8Oo^k^koooooodA4A00Pooooo`?o00000oooool00ol0003oooooooooo`09ooooo`;ooiT09oooool3
olco02Gooooo0olco`0Wooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0L?ooool0
01;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^01oooooo0_l0000@ooooo`;ooiT09_ooool3olco
02Kooooo0_lco`0Zooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0Koooool001co
oooo00?oV9RHob4Q8Oo^k^h06oooool3o`00013ooooo0_ooV@0Uooooo`?oc?l09oooool2oc?o02Ko
oooo0_l0ofH4ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0Koooool001gooooo
00?oMgMgofIVI_ooool05oooool3o`0000?ooooo00?o0000ooooooooool02oooool2oonI02Cooooo
0oo<o`0Wooooo`?o<ol09Oooool3o`3oIPKooooo00?o0000ooooooooool0:?ooool00ol0003ooooo
ooooo`1^ooooo`007_ooool00ol0003oooooooooo`0Dooooo`;o00004_ooool2oonI02Cooooo0_o<
o`0Wooooo`?o<ol09Oooool3o`3oIPWooooo00?o0000ooooooooool0:Oooool00ol0003ooooooooo
o`1]ooooo`006_ooool01Ol0003o^[ZjoooooonHV9So410@01?ooooo0ol0000Aooooo`?ooiT08ooo
ool3olco02Kooooo0olco`0Uooooo`?o0?mV3?ooool00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo06cooooo000Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`04Oooool2o`0000?ooooo00?o
0000ooooooooool02oooool3oonI02?ooooo0oo<o`0Vooooo`?o<ol09_ooool2o`3oIPoooooo00?o
0000ooooooooool0:_ooool2o`0006gooooo000]ooooo`?o00004Oooool2oonI02?ooooo0oo<o`0V
ooooo`?o<ol09_ooool3o`3oIQ7ooooo00?o0000ooooooooool0:_ooool2o`0006gooooo000Zoooo
o`?o00004Oooool3oonI02;ooooo0oo<o`0Wooooo`;o<ol09oooool2o`3oIQCooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`1Zooooo`00:?ooool2o`0000?ooooo00?o0000oooooooo
ool02oooool3oonI02;ooooo0oo<o`0Wooooo`?o<ol09oooool2o`3oIQKooooo00?o0000oooooooo
ool0;Oooool00ol0003oooooooooo`1Yooooo`009Oooool3o`0001;ooooo00?ooiT0ooooooooool0
8Oooool2olco02Oooooo0olco`0Wooooo`?o0?mV6?ooool00ol0003oooooooooo`0]ooooo`03o`00
0?oooooooooo06Wooooo000Tooooo`03o`000?oooooooooo03Cooooo0oo<o`0Vooooo`?o<ol09ooo
ool3o`3oIQ_ooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1Xooooo`006_ooool4
o`000003oa0@4?oooooooooo00?ooooo0_l0000booooo`?oc?l09_ooool3oc?o02Oooooo0ol0ofHN
ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0Ioooool001cooooo00?o0000oooo
ooooool01Oooool2o`00033ooooo0_o<o`0Vooooo`?o<ol09oooool3o`3oIR7ooooo00?o0000oooo
ooooool0<?ooool00ol0003oooooooooo`1Vooooo`004Oooool6o`0000Gooooo00?o0000oooooooo
ool01?ooool4o`0002cooooo0oo<o`0Vooooo`;o<ol09oooool3o`3oIRCooooo00?o0000oooooooo
ool0<?ooool00ol0003oooooooooo`08ooooo`Go0000FOooool001cooooo00?o0000ooooooooool0
1Oooool01?l0003oooooooooool0000Xooooo`?oc?l09_ooool3oc?o02Oooooo0_l0ofHWooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool01OnHV9So8B4Qonk^k_ooooooA4A4
05Wooooo000Looooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0Sooooo`;oc?l09_ooool3oc?o02Oooooo0ol0ofHWooooo`;o0?oo00?o0000oooooooo
ool0<_ooool00ol0003oooooooooo`07ooooo`03oiRHV?lQ8B7ok^k^05[ooooo000Looooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Pooooo`;oc?l0
9_ooool2oc?o02Oooooo0ol0ofHWooooo`?o0?oo0_ooool00ol0003oooooooooo`0cooooo`03o`00
0?oooooooooo00Oooooo00?oV9RHob4Q8Oo^k^h0FOooool001cooooo00?o0000ooooooooool01?oo
ool2o`0000Gooooo00?o0000ooooooooool07Oooool2olco02Gooooo0olco`0Vooooo`?o0?mV9ooo
ool3o`3oo`Gooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`07ooooo`03ogMgMomV
IVKooooo05Sooooo000Jooooo`03oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0Jooooo`;oc?l09?ooool3oc?o02Kooooo0ol0ofHXooooo`;o0?oo2?ooool0
0ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0Eoooool0
02?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Gooooo`;oc?l08oooool3oc?o
02Kooooo0ol0ofHXooooo`?o0?oo2_ooool00ol0003oooooooooo`0eooooo`;o00001?ooool01Ol0
003o^[ZjoooooonHV9So410@05Wooooo000Sooooo`;o00002?ooool00ol0003oooooooooo`0Coooo
o`?oc?l08_ooool3oc?o02Oooooo0_l0ofHXooooo`?o0?oo3Oooool00ol0003oooooooooo`0coooo
o`;o000000?oooooo`000?ooool00oooool01OnHV9So410@o`000?lQ8B7oc<c<05Wooooo000Soooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool03oooool3olco02;ooooo0olco`0Woooo
o`?o0?mV9oooool3o`3ooa3ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`1Ooooo
o`008oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo00gooooo00?oc?l0oooooooo
ool08Oooool2oc?o02Oooooo0ol0ofHWooooo`?o0?oo4oooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo05oooooo000Sooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
;Oooool3oc?o02Kooooo0ol0ofHWooooo`?o0?oo5Oooool2o`0003[ooooo00?o0000ooooooooool0
G_ooool002;ooooo0_l0000=ooooo`03o`000?oooooooooo02Wooooo0olco`0Vooooo`?o0?mV9ooo
ool3o`3ooaGooooo0ol000000ooooooo0000ooooo`0jooooo`03o`000?oooooooooo05gooooo000R
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool09_ooool2oc?o02Kooooo0ol0ofHW
ooooo`?o0?oo5Oooool3o`0000Gooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`1L
ooooo`008_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02;ooooo0olco`0Voooo
o`;o0?mV9oooool3o`3ooaGooooo0ol00009ooooo`03o`000?oooooooooo03Sooooo00?o0000oooo
ooooool0G?ooool002;ooooo0ol0000?ooooo`03o`000?oooooooooo01kooooo0olco`0Vooooo`?o
0?mV9_ooool3o`3ooaGooooo0ol0000=ooooo`03o`000?oooooooooo03Sooooo00?o0000oooooooo
ool0Foooool002;ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0Kooooo`;o<ol0
9_ooool3o`3oIRKooooo0ol0oolFooooo`;o00004?ooool00ol0I_oo0000ooooo`0iooooo`03o`00
0?oooooooooo05[ooooo000Rooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool05ooo
ool3oc?o02Gooooo0ol0ofHVooooo`?o0?oo5_ooool3o`0000oooooo0ol0I_l2ooooo`03o`000?oo
oooooooo03Sooooo00?o0000ooooooooool0FOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`0Cooooo`?o<ol09Oooool3o`3oIROooooo0_l0oolFooooo`?o0000
3oooool3o`1Vo`Gooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1Iooooo`001ooo
ool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`0?ooooo`?o<ol09Oooool3o`3oIROooooo
0ol0oolEooooo`?o00003oooool3o`1Vo`Wooooo00?o0000ooooooooool0>?ooool00ol0003ooooo
ooooo`1Hooooo`001Ol00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool02oooool3oc?o02Kooooo
0_l0ofHWooooo`?o0?oo5Oooool3o`0000oooooo0ol0I_l=ooooo`03o`000?oooooooooo03Sooooo
00?o0000ooooooooool0Eoooool000Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMg
Molb<S;ooooo00?ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`07ooooo`?o<ol0
9_ooool3o`3oIRKooooo0ol0oolEooooo`?o00003oooool3o`1Voa7ooooo00?o0000ooooooooool0
=oooool2o`0005Sooooo0007ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`05ooooo`03
oc?o0?oooooooooo02Cooooo0ol0ofHVooooo`?o0?oo5_ooool2o`00013ooooo0_l0I_lEooooo`03
o`000?oooooooooo03Sooooo00?o0000ooooooooool0EOooool000Oooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03o`000?oooooooooo00Kooooo0_l0000Iooooo`03o`000?oooooooooo02Wo
oooo0_l0ofHVooooo`?o0?oo5_ooool3o`0000oooooo0ol0I_lHooooo`03o`000?oooooooooo03Oo
oooo00?o0000ooooooooool0EOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Uooooo`?o
0?mV9_ooool2o`3ooaKooooo0ol0000?ooooo`?o06Ko6oooool00ol0003oooooooooo`0hooooo`03
o`000?oooooooooo05Cooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Go
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Qooooo`?o0?mV9_ooool3o`3ooaGo
oooo0ol0000?ooooo`?o06Ko7oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo05?o
oooo000Qooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool07Oooool3o`3oIRKooooo
0ol0oolEooooo`?o00003oooool3o`1Vob?ooooo00?o0000ooooooooool0>?ooool00ol0003ooooo
ooooo`1Booooo`008?ooool3o`0001gooooo00?o0000ooooooooool06Oooool3o`3oIRKooooo0ol0
oolFooooo`;o00003oooool3o`1VobOooooo00?o0000ooooooooool0=oooool00ol0003ooooooooo
o`1Booooo`008Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01Gooooo0ol0ofHV
ooooo`?o0?oo5_ooool3o`0000kooooo0ol0I_l[ooooo`03o`000?oooooooooo03Oooooo00?o0000
ooooooooool0DOooool0023ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`0Boooo
o`;o0?mV9_ooool3o`3ooaKooooo0ol0000?ooooo`;o06Ko;oooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo053ooooo000Pooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool03_ooool3o`3oIRKooooo0_l0oolFooooo`?o00004?ooool2o`1Vob[ooooo0_lc0?l5ooooo`03
o`000?oooooooooo03Sooooo00?o0000ooooooooool0Coooool0023ooooo0_l0000Rooooo`03o`00
0?oooooooooo00[ooooo0ol0ofHVooooo`?o0?oo5Oooool3o`00017ooooo0_l0I_lYooooo`?o<`3o
2?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo04oooooo000Pooooo`03o`000?oo
oooooooo02;ooooo00?o0000ooooooooool01oooool2o`3oIRKooooo0ol0oolFooooo`;o00004_oo
ool2o`1VobSooooo0olc0?l<ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0C_oo
ool0023ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`03ooooo`?o0?mV9_ooool2
o`3ooaKooooo0ol0000Aooooo`?o06Ko9oooool3oc<0oa3ooooo00?o0000ooooooooool0=oooool0
0ol0003oooooooooo`1=ooooo`008?ooool3o`0002Cooooo00?o0000ooooool0ofH00_l0ofHVoooo
o`?o0?oo5Oooool3o`00017ooooo0ol0I_lWooooo`?o<`3o5?ooool00ol0003oooooooooo`0foooo
o`;o0000C_ooool0023ooooo00?o0000ooooooooool09Oooool00ol0ofKoooooooooo`0Tooooo`?o
0?oo5Oooool3o`00017ooooo0ol0I_lWooooo`?o<`3o6?ooool00ol0003oooooooooo`0fooooo`03
o`000?oooooooooo04cooooo000Dooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01oooool00ol0003o
ooooooooo`0Vooooo`03o`000?oooooooooo023ooooo0ol0oolEooooo`?o00004Oooool3o`1VobOo
oooo0olc0?lKooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0Boooool001Cooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo02Sooooo00?o0000oooooooo
ool07?ooool3o`3ooaKooooo0_l0000Aooooo`?o06Ko9oooool3oc<0oaoooooo00?o0000oooooooo
ool0=oooool00ol0003oooooooooo`1:ooooo`005?ooool01Ol@413ooooooooooooooooo410@00Ko
oooo0_l0000Zooooo`03o`000?oooooooooo01Sooooo0ol0oolFooooo`?o00004Oooool2o`1VobOo
oooo0olc0?lSooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0BOooool001Cooooo
00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo02[ooooo00?o0000oooooooo
ool05Oooool2o`3ooaKooooo0ol0000Aooooo`?o06Ko9oooool2oc<0obOooooo00?o0000oooooooo
ool0=_ooool00ol0003oooooooooo`19ooooo`005?ooool01Ol0003ooooooooooooooooo000000Ko
oooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Aooooo`?o0?oo5Oooool3o`00017o
oooo0ol0I_lWooooo`?o<`3o:_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo04So
oooo000Dooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`0/ooooo`03
o`000?oooooooooo00gooooo0ol0oolEooooo`?o00004?ooool4o`1VobOooooo0olc0?l^ooooo`03
o`000?oooooooooo03Kooooo00?o0000ooooooooool0Aoooool001Cooooo00GoMgMgoiRHV?oooooo
V9RHogMgM`06ooooo`;o0000;_ooool00ol0003oooooooooo`0:ooooo`;o0?oo5Oooool3o`0000oo
oooo1?l0I_lXooooo`?o<`3o<Oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo04Ko
oooo000Dooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`0^ooooo`03
o`000?oooooooooo00Kooooo0ol0oolEooooo`;o00003oooool3o`1VobWooooo0olc0?lXooooo`;o
c03o2oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo04Gooooo000Oooooo`03o`00
0?oooooooooo02oooooo00?o0000ooooooooool00_ooool3o`3ooaGooooo0ol0000>ooooo`?o06Ko
:Oooool3oc<0obSooooo0oo<0?l>ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0
AOooool001kooooo00?o0000ooooooooool0<Oooool01?l0003oooooo`3oool0oolEooooo`?o0000
3_ooool3o`1VobWooooo0olc0?lXooooo`?oc03o4_ooool00ol0003oooooooooo`0fooooo`03o`00
0?oooooooooo04Cooooo000Nooooo`;o0000<Oooool3o`3ooaCooooo0ol0000>ooooo`?o06Ko:Ooo
ool3oc<0obSooooo0oo<0?lFooooo`03o`000?oooooooooo03Kooooo0_l00014ooooo`007_ooool0
0ol0003oooooooooo`0]ooooo`?o0?oo0oooool00ol0003oooooooooo`0>ooooo`?o00003_ooool3
o`1VobWooooo0olc0?lXooooo`?oc03o6_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooo
000004Cooooo000Nooooo`03o`000?oooooooooo02cooooo00?o0?ooooooooooool01Oooool00ol0
003oooooooooo`0;ooooo`;o00003_ooool3o`1Vob[ooooo0_lc0?lXooooo`?oc03o7Oooool00ol0
003oooooooooo`0fooooo`03o`000?oooooooooo04;ooooo000Nooooo`03o`000?oooooooooo03Go
oooo00?o0000ooooooooool01oooool3o`0000kooooo0_l0I_lZooooo`?o<`3o9oooool3ol`0ob7o
oooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`11ooooo`007_ooool2o`0003Oooooo
00?o0000ooooooooool00oooool3o`0000kooooo0ol0I_lYooooo`?o<`3o9oooool3ol`0obGooooo
00?o0000ooooooooool0=_ooool00ol0003oooooooooo`10ooooo`007_ooool00ol0003ooooooooo
o`0gooooo`03o`000?oooooo000000;o00003_ooool3o`1VobWooooo0olc0?lWooooo`?oc03o:Ooo
ool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo03oooooo000Nooooo`03o`000?oooooo
oooo03Kooooo0ol0000?ooooo`;o06Ko:Oooool3oc<0obOooooo0oo<0?l]ooooo`03o`000?oooooo
oooo03Gooooo00?o0000ooooooooool0?oooool001kooooo0_l0000eooooo`;o00000oooool00ol0
003oooooooooo`09ooooo`?o06Ko:?ooool3oc<0obOooooo0oo<0?laooooo`03o`000?oooooooooo
03Gooooo00?o0000ooooooooool02Oooool2o`000003oa0@4?oooooooooo033ooooo000Mooooo`03
o`000?oooooooooo03;ooooo0ol00006ooooo`03o`000?oooooooooo00Gooooo0ol0I_lXooooo`?o
<`3o9oooool3ol`0ocCooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo037ooooo0002ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Go
oooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo02oooooo0ol0000:oooo
o`03o`000?oooooooooo00;ooooo0_l0I_lVooooo`Go<`3o:?ooool2ol`0ocSooooo00?o0000oooo
ooooool0=_ooool00ol0003oooooooooo`05ooooo`Go0000<_ooool000;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
02cooooo0ol0000>ooooo`04o`000?l0I_oo06Koo`1VobGooooo0olc0?lZooooo`?oc03o:?ooool2
ool0VA7ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`05ooooo`04odA4A?oMgMgo
ooooo`0003?ooooo0002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003ooooooooo
o`03ooooo`;o0000:_ooool3o`0000oooooo0ol0I_l00ol0003oooooooooo`0Rooooo`?o<`3o:_oo
ool3ol`0obSooooo0ooo09TDooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool01?oo
ool01?oMgMgoEEEEooooool0000cooooo`000_ooool01Ol0003ooooooooooooooooo000000oooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Wooooo`;o00004?ooool2o`1Vo`Cooooo
00?o0000ooooooooool07_ooool3oc<0ob[ooooo0oo<0?lXooooo`?oo`2I6?ooool00ol0003ooooo
ooooo`0eooooo`03o`000?oooooooooo00Cooooo00?oMgMgolc<c?l00000<oooool000;ooooo00Go
0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003o
ooooooooo`0Tooooo`?o00003oooool3o`1Vo`Oooooo00?o0000ooooooooool06oooool2oc<0ob[o
oooo0oo<0?lXooooo`?oo`2I7?ooool00ol0003oooooooooo`0dooooo`;o00001Oooool00oo^k^ko
A4A4o`00000cooooo`000_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000oooooooo
ool01oooool00ol0003oooooooooo`0Qooooo`?o00003oooool3o`1Vo`_ooooo00?o0000oooooooo
ool05oooool3oc<0obWooooo0oo<0?lXooooo`?oo`2I7oooool00ol0003oooooooooo`0cooooo`04
o`000?ooooooooooo`0000Gooooo00?oMgMgo`000?ooool0<_ooool000;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo0_l0000Oooooo`?o00004Oooool00ol0
I_ooooooooooo`0=ooooo`03o`000?oooooooooo01?ooooo0olc0?lZooooo`;oc03o:?ooool3ool0
VB?ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0hooooo`000_ooool01Oo^k^ko
<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo01cooooo0ol0000Uoooo
o`03o`000?oooooooooo013ooooo0_lc0?lZooooo`?oc03o9oooool3ool0VBOooooo00?o0000oooo
ooooool0=Oooool00ol0003oooooooooo`0gooooo`007?ooool00ol0003oooooooooo`0Iooooo`?o
0000:Oooool00ol0003oooooooooo`0<ooooo`?o<`3o:Oooool3ol`0obOooooo0ooo09T[ooooo`03
o`000?oooooooooo03Gooooo00?o0000ooooooooool0=_ooool001cooooo00?o0000ooooooooool0
5oooool2o`0002gooooo00?o0000ooooooooool02?ooool3oc<0obWooooo0oo<0?lWooooo`?oo`2I
;oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo03Gooooo000Looooo`;o00005Ooo
ool3o`00033ooooo00?o0000ooooooooool01Oooool2oc<0obWooooo0oo<0?lWooooo`?oo`2I<ooo
ool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo03Gooooo000Looooo`03o`000?oooooo
oooo017ooooo0ol0000dooooo`04o`000?ooooooooooooooo`?o<`3o:?ooool3ol`0obOooooo0ooo
09Tfooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0=?ooool001cooooo00?o0000
ooooooooool03_ooool3o`0003Sooooo0olc0?lXooooo`?oc03o9oooool3ool0VC[ooooo00?o0000
ooooooooool0=Oooool00ol0003oooooooooo`0cooooo`007?ooool00ol0003oooooooooo`0;oooo
o`?o0000>?ooool3oc<0o`03ooooool0003ooooo02?ooooo1Oo<0?lWooooo`?oo`2I?_ooool00ol0
003oooooooooo`0eooooo`03o`000?oooooooooo03;ooooo000Looooo`;o00002_ooool2o`0003So
oooo0olc0?l5ooooo`03o`000?oooooooooo01kooooo0oo<0?lYooooo`?oo`2I@_ooool00ol0003o
ooooooooo`0dooooo`03o`000?oooooooooo03;ooooo000Kooooo`;o00002?ooool3o`0003Oooooo
0olc0?l9ooooo`03o`000?oooooooooo01[ooooo0oo<0?lYooooo`?oo`2I:oooool2ool001Wooooo
00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0aooooo`006oooool00ol0003ooooooooo
o`04ooooo`?o0000>?ooool2oc<0o`gooooo00?o0000ooooooooool05_ooool3ol`0ob[ooooo0_oo
09T[ooooo`?oo`007?ooool00ol0003oooooooooo`0cooooo`;o0000<_ooool001_ooooo00Co0000
oooooooooooooooo0ol0000hooooo`?o<`3o4?ooool00ol0003oooooooooo`0Cooooo`;oc03o:_oo
ool3ool0VB[ooooo0ooo000Oooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0;ooo
ool001_ooooo1?l0000hooooo`?o<`3o5?ooool00ol0003oooooooooo`0?ooooo`?oc03o:Oooool3
ool0VB[ooooo0ooo000Sooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0;oooool0
01_ooooo0_l0000iooooo`03oc<0oooooooooooo01Kooooo00?o0000ooooooooool02oooool3ol`0
obWooooo0ooo09TZooooo`?oo`009oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo
02kooooo000Aooooo`Co000000?o410@ooooooooool01Oooool00ol0003oooooooooo`1@ooooo`03
o`000?oooooooooo00Sooooo0_o<0?lYooooo`?oo`2I:_ooool3ool002_ooooo00?o0000oooooooo
ool0=?ooool00ol0003oooooooooo`0]ooooo`004oooool00ol0003oooooooooo`08ooooo`03o`00
0?oooooooooo053ooooo00?o0000ooooooooool01?ooool3ol`0obSooooo0ooo09TZooooo`?oo`00
;oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02cooooo000Cooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`03ol`0obWooooo0_oo
09TXooooo`Goo`00<oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02cooooo000C
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0Coooool3ol`0obWooooo0ooo09TW
ooooo`?oo`00>?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02_ooooo000Coooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0Boooool3ol`0o`;ooooo00?o0000oooo
ooooool09?ooool3ool0VBOooooo0ooo000looooo`03o`000?oooooooooo03Cooooo00?o0000oooo
ooooool0:_ooool001?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`17ooooo`?o
c03o1_ooool00ol0003oooooooooo`0Oooooo`Coo`2I9oooool3ool0043ooooo00?o0000oooooooo
ool0=?ooool00ol0003oooooooooo`0Yooooo`004oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo04Cooooo0_o<0?l:ooooo`03o`000?oooooooooo01[ooooo1?oo09TXooooo`?oo`00
A?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02Sooooo000Aooooo`03oeEEEOmV
IVKo0000013ooooo00?o0000ooooooooool0@?ooool3ol`0o`gooooo00?o0000ooooooooool05_oo
ool3ool0VBWooooo0ooo0018ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0:?oo
ool002Gooooo00?o0000ooooooooool0??ooool3ol`0oa7ooooo00?o0000ooooooooool04_ooool3
ool0VBWooooo0ooo001<ooooo`03o`000?oooooooooo03;ooooo0_l0000Yooooo`009_ooool2o`00
03Wooooo0oo<0?lEooooo`03o`000?oooooooooo00kooooo0ooo09TYooooo`?oo`00Coooool00ol0
003oooooooooo`0dooooo`03o`000?oooooooooo02Kooooo000Xooooo`03o`000?oooooooooo03;o
oooo1?o<0?lHooooo`03o`000?oooooooooo00cooooo0_oo09TYooooo`?oo`00Doooool00ol0003o
ooooooooo`0dooooo`03o`000?oooooooooo02Gooooo000Yooooo`03o`000?oooooooooo02oooooo
0_o<0?lMooooo`03o`000?oooooooooo00Sooooo0ooo09TXooooo`?oo`00Eoooool00ol0003ooooo
ooooo`0cooooo`03o`000?oooooooooo02Gooooo000Zooooo`03o`000?oooooooooo04kooooo00?o
0000ooooooooool01?ooool3ool0VBWooooo0_oo001Kooooo`03o`000?oooooooooo03?ooooo00?o
0000ooooooooool09?ooool002_ooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`03
ool0VBWooooo0ooo001Nooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool08oooool0
02cooooo00?o0000ooooooooool0COooool3ool0VBWooooo0ooo001Rooooo`03o`000?oooooooooo
03?ooooo00?o0000ooooooooool08_ooool002gooooo00?o0000ooooooooool0BOooool3ool0V@;o
oooo00?o0000ooooooooool08oooool4ool006Gooooo00?o0000ooooooooool0<oooool00ol0003o
ooooooooo`0Rooooo`00;_ooool00ol0003oooooooooo`16ooooo`;oo`2I1_ooool00ol0003ooooo
ooooo`0Nooooo`Coo`00J_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo027ooooo
000_ooooo`03o`000?oooooooooo04;ooooo0ooo09T9ooooo`03o`000?oooooooooo01[ooooo0ooo
001_ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool08?ooool0033ooooo00?o0000
ooooooooool0?_ooool3ool0V@gooooo00?o0000ooooooooool05_ooool3ool007?ooooo00?o0000
ooooooooool0<oooool00ol0003oooooooooo`0Oooooo`00<Oooool2o`0003_ooooo0ooo09TAoooo
o`03o`000?oooooooooo01;ooooo0ooo001gooooo`03o`000?oooooooooo03;ooooo0_l0000Poooo
o`00<oooool00ol0003oooooooooo`0dooooo`Coo`2I5Oooool00ol0003oooooooooo`0>ooooo`?o
o`00Noooool00ol0003oooooooooo`0aooooo`;o00008?ooool003Cooooo00?o0000ooooooooool0
<?ooool3ool0VA[ooooo00?o0000ooooooooool02_ooool3ool007kooooo00?o0000ooooooooool0
<oooool00ol0003oooooooooo`0Mooooo`00=Oooool00ol0003oooooooooo`0/ooooo`?oo`2I7_oo
ool00ol0003oooooooooo`06ooooo`?oo`00P_ooool00ol0003oooooooooo`0cooooo`03o`000?oo
oooooooo01cooooo000fooooo`03o`000?oooooooooo02Sooooo0ooo09TRooooo`03o`000?oooooo
oooo00?ooooo0_oo0026ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool07?ooool0
03Oooooo00?o0000ooooooooool09_ooool00ooo09Woooooooooo`0Tooooo`03o`000?ooooooo`00
00;oo`00ROooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01_ooooo000hooooo`03
o`000?oooooooooo04_ooooo0ooo002=ooooo`03o`000?oooooooooo03;ooooo00?o0000oooooooo
ool01oooool01Oo^k^ko<S8bo`000?l@413oc<c<00kooooo000iooooo`03o`000?oooooooooo04Oo
oooo0ooo0003ooooo`03o`000?oooooooooo08_ooooo00?o0000ooooooooool0<_ooool00ol0003o
ooooooooo`06ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B403_ooool003[ooooo00?o0000oooooooo
ool0@_ooool4ool000Oooooo00?o0000ooooooooool0R_ooool00ol0003oooooooooo`0cooooo`03
o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`00000>ooooo`00>oooool00ol0003o
ooooooooo`0nooooo`?oo`003?ooool00ol0003oooooooooo`2:ooooo`03o`000?oooooooooo03;o
oooo00?o0000ooooooooool01Oooool01Ol0003oV9RHoooooonHV9So8B4Q00kooooo000looooo`03
o`000?oooooooooo03[ooooo0ooo000@ooooo`03o`000?oooooooooo08[ooooo00?o0000oooooooo
ool0<_ooool00ol0003oooooooooo`04ooooo`05o`000?mEEEGo0000oa0@4?o<c<`03_ooool003go
oooo0_l0000gooooo`?oo`005?ooool00ol0003oooooooooo`2:ooooo`03o`000?oooooooooo03;o
oooo0_l00004ooooo`03oeEEEOn7QhOooooo013ooooo000oooooo`03o`000?oooooooooo037ooooo
0ooo000Hooooo`03o`000?oooooooooo08[ooooo00?o0000ooooooooool0;oooool2o`000003oooo
ool0003ooooo00?ooooo00?ogMgMoa0@4?nHV9P04?ooool0043ooooo00?o0000ooooooooool0;Ooo
ool3ool001cooooo00?o0000ooooooooool0R_ooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo00?ooooo00Coc<c<odA4A?l0003o410@3_ooool0047ooooo00?o0000ooooooooool0:Ooo
ool3ool0023ooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`0booooo`03o`000?oo
oooooooo01Cooooo0012ooooo`03o`000?oooooooooo02Kooooo0_oo000Tooooo`03o`000?oooooo
oooo08Wooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Cooooo`00@oooool00ol0
003oooooooooo`0Rooooo`?oo`009oooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo
03;ooooo00?o0000ooooooooool04_ooool004Cooooo00?o0000ooooooooool07_ooool3ool002_o
oooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo01;o
oooo0015ooooo`03o`000?oooooooooo01cooooo00?oo`00ooooooooool0;Oooool00ol0003ooooo
ooooo`29ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool04Oooool004Kooooo00?o
0000ooooooooool0C?ooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo037ooooo00?o
0000ooooooooool04?ooool004Oooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`28
ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool03oooool004Sooooo0_l0001=oooo
o`03o`000?oooooooooo08Sooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0?oooo
o`00B_ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo08Sooooo00?o0000oooooooo
ool0<Oooool2o`0000oooooo001;ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0
R?ooool00ol0003oooooooooo`0`ooooo`;o00003oooool004cooooo00?o0000ooooooooool0Booo
ool00ol0003oooooooooo`28ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool03?oo
ool004gooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`28ooooo`03o`000?oooooo
oooo037ooooo00?o0000ooooooooool02oooool004kooooo00?o0000ooooooooool0Boooool00ol0
003oooooooooo`27ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool02oooool004oo
oooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`27ooooo`03o`000?oooooooooo037o
oooo00?o0000ooooooooool02_ooool0053ooooo00?o0000ooooooooool0Boooool00ol0003ooooo
ooooo`27ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool02Oooool0057ooooo00?o
0000ooooooooool0Boooool00ol0003oooooooooo`27ooooo`03o`000?oooooooooo037ooooo00?o
0000ooooooooool02?ooool005;ooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`27
ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool02?ooool005?ooooo0_l0001<oooo
o`03o`000?oooooooooo08Oooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`07oooo
o`00EOooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo08Kooooo00?o0000oooooooo
ool0<Oooool00ol0003oooooooooo`06ooooo`00E_ooool00ol0003oooooooooo`1:ooooo`03o`00
0?oooooooooo08Kooooo00?o0000ooooooooool0;oooool3o`0000Oooooo001Gooooo`03o`000?oo
oooooooo04[ooooo00?o0000ooooooooool0Q_ooool00ol0003oooooooooo`0[ooooo`?o00000_oo
ool00ol0003oooooooooo`05ooooo`00F?ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooo
oooo08Kooooo00?o0000ooooooooool09oooool3o`0000Gooooo00?o0000ooooooooool01Oooool0
05Wooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`26ooooo`03o`000?oooooooooo
02;ooooo1?l00008ooooo`03o`000?oooooooooo00Gooooo001Jooooo`03o`000?oooooooooo04[o
oooo00?o0000ooooooooool0Q_ooool00ol0003oooooooooo`0Nooooo`?o00003?ooool00ol0003o
ooooooooo`05ooooo`00Foooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo08Gooooo
00?o0000ooooooooool06_ooool4o`0000oooooo00?o0000ooooooooool01Oooool005cooooo00?o
0000ooooooooool0B_ooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo01Kooooo0ol0
000Dooooo`03o`000?oooooooooo00Cooooo001Mooooo`03o`000?oooooooooo04[ooooo00?o0000
ooooooooool0QOooool00ol0003oooooooooo`0Booooo`?o00005oooool00ol0003oooooooooo`04
ooooo`00G_ooool2o`0004_ooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`0=oooo
o`Co00006_ooool00ol0003oooooooooo`04ooooo`00H?ooool00ol0003oooooooooo`19ooooo`03
o`000?oooooooooo08Gooooo00?o0000ooooooooool02Oooool3o`0001kooooo00?o0000oooooooo
ool01?ooool0067ooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`25ooooo`03o`00
0?oooooooooo00Cooooo1?l0000Qooooo`03o`000?oooooooooo00Cooooo001Rooooo`03o`000?oo
oooooooo04Wooooo00?o0000ooooooooool0Q?ooool01?l0003oooooooooooooool3o`0002Gooooo
00?o0000ooooooooool01?ooool006?ooooo00?o0000ooooooooool0BOooool00ol0003ooooooooo
o`24ooooo`?o0000:?ooool00ol0003oooooooooo`04ooooo`00I?ooool00ol0003oooooooooo`19
ooooo`03o`000?oooooooooo07oooooo1?l000000ooooooo0000ooooo`0Xooooo`03o`000?oooooo
oooo00Cooooo001Uooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0Noooool3o`00
00Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`04ooooo`00I_ooool00ol0003o
ooooooooo`19ooooo`03o`000?oooooooooo07Kooooo1?l0000:ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool01?ooool006Oooooo00?o0000ooooooooool0BOooool00ol0003ooooo
ooooo`1booooo`?o00003oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00?ooooo
001Xooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0K_ooool3o`0001;ooooo00?o
0000ooooooooool09Oooool00ol0003oooooooooo`03ooooo`00JOooool00ol0003oooooooooo`19
ooooo`03o`000?oooooooooo06Wooooo1?l0000Fooooo`03o`000?oooooooooo02Cooooo00?o0000
ooooooooool00oooool006[ooooo0_l0001:ooooo`03o`000?oooooooooo06Gooooo0ol0000Koooo
o`03o`000?oooooooooo02?ooooo00?o0000ooooooooool00oooool006cooooo00?o0000oooooooo
ool0B?ooool00ol0003oooooooooo`1Pooooo`Co00007oooool00ol0003oooooooooo`0Rooooo`03
o`000?oooooooooo00?ooooo001]ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0
G?ooool3o`0002Cooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`03ooooo`00K_oo
ool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo05Sooooo0ol0000Xooooo`03o`000?oo
oooooooo023ooooo00?o0000ooooooooool00oooool006oooooo00?o0000ooooooooool0B?ooool0
0ol0003oooooooooo`1Cooooo`Co0000:oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooo
oooo00?ooooo001`ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0Coooool3o`00
033ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`03ooooo`00LOooool00ol0003o
ooooooooo`18ooooo`03o`000?oooooooooo04[ooooo1?l0000dooooo`03o`000?oooooooooo01ko
oooo00?o0000ooooooooool00oooool007;ooooo00?o0000ooooooooool0B?ooool00ol0003ooooo
ooooo`16ooooo`?o0000>Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00;ooooo
001cooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0@_ooool3o`0003gooooo00?o
0000ooooooooool07Oooool00ol0003oooooooooo`02ooooo`00M?ooool00ol0003oooooooooo`18
ooooo`03o`000?oooooooooo03gooooo1?l00011ooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool00_ooool007Gooooo0_l00019ooooo`03o`000?oooooooooo03Wooooo0ol00015oooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool00_ooool007Oooooo00?o0000oooooooo
ool0Aoooool00ol0003oooooooooo`0dooooo`Co0000BOooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo00;ooooo001hooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0
<?ooool3o`0004kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`02ooooo`00NOoo
ool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo02cooooo0ol0001Booooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool00_ooool007[ooooo00?o0000ooooooooool0Aoooool0
0ol0003oooooooooo`0Wooooo`Co0000E_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooo
oooo00;ooooo001kooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool08oooool3o`00
05_ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`02ooooo`00O?ooool00ol0003o
ooooooooo`17ooooo`03o`000?oooooooooo01kooooo1?l0001Nooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool00_ooool007gooooo00?o0000ooooooooool0Aoooool00ol0003ooooo
ooooo`0Jooooo`?o0000Hoooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo007ooooo
001nooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool05_ooool3o`0006Oooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`01ooooo`00Ooooool00ol0003oooooooooo`17
ooooo`03o`000?oooooooooo017ooooo1?l0001[ooooo`03o`000?oooooooooo01Gooooo00?o0000
ooooooooool00Oooool0083ooooo0_l00018ooooo`03o`000?oooooooooo00gooooo0ol0001`oooo
o`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00Oooool008;ooooo00?o0000oooooooo
ool0A_ooool00ol0003oooooooooo`08ooooo`Co0000M?ooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo007ooooo0023ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool0
1?ooool3o`0007Sooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`01ooooo`00Q?oo
ool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo00?o0000O?ooool00ol0003ooooooooo
o`0Booooo`03o`000?oooooooooo007ooooo0025ooooo`03o`000?oooooooooo04Kooooo0_l00020
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool00Oooool008Kooooo00?o0000oooo
ooooool0AOooool00ol0003oooooooooo`20ooooo`03o`000?oooooooooo013ooooo00?o0000oooo
ooooool00Oooool008Oooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`21ooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool00Oooool008Sooooo00?o0000ooooooooool0
@oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo00oooooo0Ol00001ooooo`7ooooo
0029ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0P_ooool00ol0003ooooooooo
o`0?ooooo`7o00000Oooool1ooooo`00R_ooool00ol0003oooooooooo`11ooooo`03o`000?oooooo
oooo08?ooooo00?o0000ooooooooool03_ooool1o`00007ooooo0Oooool008_ooooo0_l00011oooo
o`03o`000?oooooooooo08Cooooo00?o0000ooooooooool03Oooool1o`00007ooooo0Oooool008go
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo00co
oooo0Ol00001ooooo`7ooooo002>ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0
Q_ooool00ol0003oooooooooo`0;ooooo`7o00000Oooool1ooooo`00Soooool00ol0003ooooooooo
o`0looooo`03o`000?oooooooooo08Oooooo00?o0000ooooooooool02_ooool1o`00007ooooo0Ooo
ool0093ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`27ooooo`03o`000?oooooo
oooo00[ooooo0Ol00001ooooo`7ooooo002Aooooo`03o`000?oooooooooo03[ooooo00?o0000oooo
ooooool0R?ooool00ol0003oooooooooo`09ooooo`7o00000Oooool1ooooo`00T_ooool00ol0003o
ooooooooo`0iooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool02?ooool1o`00007o
oooo0Oooool009?ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`2:ooooo`03o`00
0?oooooooooo00Sooooo0Ol00001ooooo`00U?ooool00ol0003oooooooooo`0gooooo`03o`000?oo
oooooooo08_ooooo00?o0000ooooooooool01oooool1o`00007ooooo002Eooooo`03o`000?oooooo
oooo03Kooooo00?o0000ooooooooool0S?ooool00ol0003oooooooooo`06ooooo`7o00000Oooool0
09Kooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`2<ooooo`03o`000?oooooooooo
00Kooooo0Ol00001ooooo`00Uoooool2o`0003Gooooo00?o0000ooooooooool0SOooool00ol0003o
ooooooooo`05ooooo`7o00000Oooool009Wooooo00?o0000ooooooooool0<_ooool00ol0003ooooo
ooooo`2>ooooo`03o`000?oooooooooo00Cooooo0Ol00001ooooo`00V_ooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo08oooooo00?o0000ooooooooool00oooool1o`00007ooooo002K
ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0T?ooool00ol0003oooooooooo`02
ooooo`7o00000Oooool009cooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`2Aoooo
o`05o`000?ooooooooooooooool000000Oooool009gooooo00?o0000ooooooooool0;_ooool00ol0
003oooooooooo`2Aooooo`05o`000?ooooooooooooooool000000Oooool009kooooo00?o0000oooo
ooooool0;Oooool00ol0003oooooooooo`2Booooo`04o`000?ooooooooooooooo`7o0000002Ooooo
o`03o`000?oooooooooo02cooooo00?o0000ooooooooool0Toooool00ol0003oooooooooo`01o`00
0000X?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo09Cooooo0Ol00001ooooo`7o
0000002Qooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0UOooool2o`000000X_oo
ool2o`0002[ooooo00?o0000ooooooooool0U?ooool3o`000000Y?ooool00ol0003oooooooooo`0W
ooooo`03o`000?oooooooooo093ooooo1?l00003ooooo`00YOooool00ol0003oooooooooo`0Voooo
o`03o`000?oooooooooo08gooooo0ol00007ooooo`00Y_ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo08Wooooo1?l0000:ooooo`00Yoooool00ol0003oooooooooo`0Tooooo`03o`00
0?oooooooooo08Gooooo1?l0000>ooooo`00Z?ooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo08;ooooo0ol0000Booooo`00ZOooool00ol0003oooooooooo`0Rooooo`03o`000?oooooo
oooo07kooooo1?l0000Eooooo`00Z_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
07[ooooo1?l0000Iooooo`00Zoooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo07Go
oooo1?l0000Mooooo`00[?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo07;ooooo
0ol0000Qooooo`00[Oooool2o`00023ooooo00?o0000ooooooooool0K_ooool4o`0002Cooooo002_
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0J_ooool4o`0002Sooooo002`oooo
o`03o`000?oooooooooo01cooooo00?o0000ooooooooool0Ioooool3o`0002cooooo002aooooo`03
o`000?oooooooooo01_ooooo00?o0000ooooooooool0Hoooool4o`0002oooooo002booooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool0Goooool4o`0003?ooooo002cooooo`03o`000?oo
oooooooo01Wooooo00?o0000ooooooooool0G?ooool3o`0003Oooooo002dooooo`03o`000?oooooo
oooo01Sooooo00?o0000ooooooooool0F?ooool4o`0003[ooooo002eooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool0E?ooool4o`0003kooooo002fooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool0D?ooool4o`0004;ooooo002gooooo`03o`000?oooooooooo01Gooooo
00?o0000ooooooooool0COooool3o`0004Kooooo002hooooo`;o00005Oooool00ol0003ooooooooo
o`19ooooo`Co0000BOooool00;[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`15
ooooo`Co0000COooool00;_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`12oooo
o`?o0000DOooool00;cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0nooooo`Co
0000E?ooool00;gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0jooooo`Co0000
F?ooool00;kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0fooooo`Co0000G?oo
ool00;oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0cooooo`?o0000H?ooool0
0<3ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0_ooooo`Co0000Hoooool00<7o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0[ooooo`Co0000Ioooool00<;ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Xooooo`?o0000Joooool00<?ooooo00?o
0000ooooooooool02Oooool00ol0003oooooooooo`0Tooooo`Co0000K_ooool00<Cooooo0_l00009
ooooo`03o`000?oooooooooo023ooooo1?l0001booooo`00a_ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo01gooooo0ol0001fooooo`00aoooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo01Wooooo1?l0001iooooo`00b?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo01Gooooo1?l0001mooooo`00bOooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo017ooooo1?l00021ooooo`00b_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00kooooo0ol00025ooooo`00boooool01Ol0003ooooooooooooooooo000000cooooo1?l00028
ooooo`00c?ooool01?l0003oooooooooool00008ooooo`Co0000S?ooool00<gooooo00?o0000oooo
ool000001Oooool3o`00093ooooo003>ooooo`;o000000?oooooo`000?l000000_l0002Cooooo`00
coooool2o`0009Oooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWo
oooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {330.375, 0}} -> {-0.0771432, -0.0315529, \
0.00350368, 0.00350368}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .92059 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-16 1.0763 -0.0263982 1.0763 [
[.01694 .18568 -11.9631 -9 ]
[.01694 .18568 .03693 0 ]
[.13793 .13897 -11.619 -9 ]
[.13793 .13897 .38095 0 ]
[.26292 .09073 -5.63752 -9 ]
[.26292 .09073 .36248 0 ]
[.39212 .04087 -5.46552 -9 ]
[.39212 .04087 .53448 0 ]
[.52574 -0.01069 -5.29351 -9 ]
[.52574 -0.01069 .70649 0 ]
[.58272 .04263 0 -6.19654 ]
[.58272 .04263 6 2.80346 ]
[.71715 .21863 0 -6.07114 ]
[.71715 .21863 6 2.92886 ]
[.83675 .37523 0 -5.963 ]
[.83675 .37523 6 3.037 ]
[.94385 .51546 0 -5.8688 ]
[.94385 .51546 6 3.1312 ]
[.01386 .20006 -12 -2.76892 ]
[.01386 .20006 0 6.23108 ]
[.00748 .25499 -24 -2.80073 ]
[.00748 .25499 0 6.19927 ]
[.00093 .31131 -6 -2.83339 ]
[.00093 .31131 0 6.16661 ]
[-0.00579 .36907 -18 -2.86695 ]
[-0.00579 .36907 0 6.13305 ]
[-0.01268 .42831 -6 -2.90143 ]
[-0.01268 .42831 0 6.09857 ]
[ 0 0 0 0 ]
[ 1 .92059 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02642 .19522 m
.53391 0 L
s
.02642 .19522 m
.03116 .2 L
s
[(-2)] .01694 .18568 .99384 1 Mshowa
.14712 .14879 m
.15172 .1537 L
s
[(-1)] .13793 .13897 .93651 1 Mshowa
.2718 .10083 m
.27624 .10588 L
s
[(0)] .26292 .09073 .87917 1 Mshowa
.40066 .05126 m
.40493 .05646 L
s
[(1)] .39212 .04087 .82184 1 Mshowa
.53391 0 m
.538 .00534 L
s
[(2)] .52574 -0.01069 .7645 1 Mshowa
.125 Mabswid
.05025 .18606 m
.05308 .18894 L
s
.07424 .17683 m
.07705 .17973 L
s
.09837 .16755 m
.10117 .17046 L
s
.12267 .1582 m
.12545 .16113 L
s
.17173 .13933 m
.17447 .14229 L
s
.19651 .1298 m
.19923 .13278 L
s
.22144 .1202 m
.22414 .1232 L
s
.24654 .11055 m
.24922 .11356 L
s
.29723 .09105 m
.29988 .0941 L
s
.32283 .0812 m
.32546 .08427 L
s
.3486 .07129 m
.35121 .07437 L
s
.37455 .06131 m
.37713 .06441 L
s
.42695 .04115 m
.4295 .04428 L
s
.45342 .03096 m
.45594 .03412 L
s
.48007 .02071 m
.48257 .02388 L
s
.5069 .01039 m
.50938 .01358 L
s
.25 Mabswid
.53391 0 m
.9804 .58403 L
s
.57014 .04738 m
.56384 .04975 L
s
[(0)] .58272 .04263 -1 .37701 Mshowa
.70445 .22307 m
.6981 .22529 L
s
[(2)] .71715 .21863 -1 .34914 Mshowa
.82396 .37939 m
.81756 .38147 L
s
[(4)] .83675 .37523 -1 .32511 Mshowa
.93098 .51938 m
.92454 .52134 L
s
[(6)] .94385 .51546 -1 .30418 Mshowa
.125 Mabswid
.60525 .09331 m
.60147 .09471 L
s
.63931 .13786 m
.63552 .13924 L
s
.67236 .1811 m
.66856 .18245 L
s
.73562 .26383 m
.7318 .26514 L
s
.7659 .30345 m
.76207 .30473 L
s
.79534 .34195 m
.7915 .34322 L
s
.85181 .41581 m
.84796 .41704 L
s
.87891 .45126 m
.87506 .45247 L
s
.90529 .48577 m
.90143 .48696 L
s
.95601 .55212 m
.95214 .55328 L
s
.25 Mabswid
.02642 .19522 m
0 .42381 L
s
.02642 .19522 m
.0327 .19281 L
s
[(-1)] .01386 .20006 1 -0.38468 Mshowa
.02006 .25024 m
.02635 .24786 L
s
[(-0.5)] .00748 .25499 1 -0.37762 Mshowa
.01354 .30664 m
.01985 .3043 L
s
[(0)] .00093 .31131 1 -0.37036 Mshowa
.00686 .36448 m
.01318 .36218 L
s
[(0.5)] -0.00579 .36907 1 -0.3629 Mshowa
0 .42381 m
.00634 .42156 L
s
[(1)] -0.01268 .42831 1 -0.35524 Mshowa
.125 Mabswid
.02516 .20612 m
.02893 .20468 L
s
.0239 .21707 m
.02767 .21563 L
s
.02262 .22807 m
.0264 .22664 L
s
.02135 .23913 m
.02512 .2377 L
s
.01877 .26141 m
.02255 .25999 L
s
.01747 .27263 m
.02125 .27122 L
s
.01617 .28391 m
.01995 .2825 L
s
.01486 .29525 m
.01864 .29384 L
s
.01222 .31809 m
.01601 .3167 L
s
.01089 .3296 m
.01468 .32821 L
s
.00955 .34117 m
.01334 .33978 L
s
.00821 .35279 m
.012 .35141 L
s
.0055 .37622 m
.0093 .37485 L
s
.00414 .38803 m
.00793 .38666 L
s
.00276 .39989 m
.00656 .39853 L
s
.00139 .41182 m
.00519 .41047 L
s
.25 Mabswid
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.54154 .92059 L
s
.54154 .92059 m
.5414 .7134 L
s
.5414 .7134 m
.02642 .19522 L
s
.53391 0 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.53391 0 m
.02642 .19522 L
s
.5414 .7134 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.54154 .92059 L
s
.54154 .92059 m
.5414 .7134 L
s
0 0 m
1 0 L
1 .92059 L
0 .92059 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.23639 .55306 m
.26058 .54478 L
s
1 0 .6 r
.22248 .51532 m
.24675 .50716 L
s
.8 0 1 r
.20852 .4773 m
.2328 .46907 L
s
.2 0 1 r
.19451 .43915 m
.21877 .43079 L
s
1 0 0 r
.26058 .54478 m
.28481 .53631 L
s
0 .4 1 r
.18046 .40091 m
.20471 .39243 L
s
1 0 .6 r
.24675 .50716 m
.27114 .4989 L
s
0 1 1 r
.16639 .36259 m
.19062 .35398 L
s
.8 0 1 r
.2328 .46907 m
.25723 .46078 L
s
0 1 .4 r
.1523 .3242 m
.1765 .31546 L
s
.2 0 1 r
.21877 .43079 m
.24319 .42239 L
s
1 0 0 r
.28481 .53631 m
.30903 .52767 L
s
.2 1 0 r
.13817 .28573 m
.16235 .27686 L
s
0 .4 1 r
.20471 .39243 m
.22911 .38389 L
s
1 0 .6 r
.27114 .4989 m
.29565 .49055 L
s
.8 1 0 r
.12402 .24719 m
.14818 .23819 L
s
0 1 1 r
.19062 .35398 m
.21499 .34531 L
s
.8 0 1 r
.25723 .46078 m
.28181 .45243 L
s
1 .6 0 r
.10984 .20857 m
.13397 .19944 L
s
0 1 .4 r
.1765 .31546 m
.20085 .30666 L
s
.2 0 1 r
.24319 .42239 m
.26776 .41393 L
s
.2 1 0 r
.16235 .27686 m
.18669 .26793 L
s
1 0 0 r
.30903 .52767 m
.33328 .51894 L
s
0 .4 1 r
.22911 .38389 m
.25366 .3753 L
s
1 0 .6 r
.29565 .49055 m
.32028 .48213 L
s
.8 1 0 r
.14818 .23819 m
.17249 .22912 L
s
0 1 1 r
.21499 .34531 m
.23953 .33659 L
s
.8 0 1 r
.28181 .45243 m
.30654 .44402 L
s
1 .6 0 r
.13397 .19944 m
.15826 .19024 L
s
0 1 .4 r
.20085 .30666 m
.22537 .2978 L
s
.2 0 1 r
.26776 .41393 m
.2925 .40541 L
s
.2 1 0 r
.18669 .26793 m
.21118 .25894 L
s
0 .4 1 r
.25366 .3753 m
.27838 .36665 L
s
1 0 0 r
.33328 .51894 m
.35761 .51022 L
s
1 0 .6 r
.32028 .48213 m
.34505 .47366 L
s
.8 1 0 r
.17249 .22912 m
.19696 .22 L
s
0 1 1 r
.23953 .33659 m
.26422 .32781 L
s
.8 0 1 r
.30654 .44402 m
.33142 .43556 L
s
1 .6 0 r
.15826 .19024 m
.18271 .18098 L
s
0 1 .4 r
.22537 .2978 m
.25004 .28889 L
s
.2 0 1 r
.2925 .40541 m
.31739 .39684 L
s
.2 1 0 r
.21118 .25894 m
.23583 .24989 L
s
0 .4 1 r
.27838 .36665 m
.30325 .35795 L
s
1 0 0 r
.35761 .51022 m
.38214 .50161 L
s
1 0 .6 r
.34505 .47366 m
.36997 .46517 L
s
.8 1 0 r
.19696 .22 m
.22159 .21082 L
s
0 1 1 r
.26422 .32781 m
.28907 .31898 L
s
.8 0 1 r
.33142 .43556 m
.35647 .42704 L
s
1 .6 0 r
.18271 .18098 m
.20732 .17166 L
s
0 1 .4 r
.25004 .28889 m
.27487 .27992 L
s
.2 0 1 r
.31739 .39684 m
.34244 .38822 L
s
.2 1 0 r
.23583 .24989 m
.26064 .24079 L
s
0 .4 1 r
.30325 .35795 m
.32828 .3492 L
s
1 0 0 r
.38214 .50161 m
.40695 .49316 L
s
1 0 .6 r
.36997 .46517 m
.3951 .4567 L
s
.8 1 0 r
.22159 .21082 m
.24638 .20157 L
s
0 1 1 r
.28907 .31898 m
.31409 .31008 L
s
.8 0 1 r
.35647 .42704 m
.38169 .41849 L
s
1 .6 0 r
.20732 .17166 m
.23209 .16228 L
s
0 1 .4 r
.27487 .27992 m
.29986 .27089 L
s
.2 0 1 r
.34244 .38822 m
.36766 .37954 L
s
.2 1 0 r
.26064 .24079 m
.28561 .23162 L
s
0 .4 1 r
.32828 .3492 m
.35348 .34038 L
s
1 0 0 r
.40695 .49316 m
.43213 .4849 L
s
1 0 .6 r
.3951 .4567 m
.42046 .44826 L
s
.8 1 0 r
.24638 .20157 m
.27133 .19227 L
s
0 1 1 r
.31409 .31008 m
.33927 .30113 L
s
.8 0 1 r
.38169 .41849 m
.40709 .40989 L
s
1 .6 0 r
.23209 .16228 m
.25702 .15284 L
s
0 1 .4 r
.29986 .27089 m
.32502 .2618 L
s
.2 0 1 r
.36766 .37954 m
.39304 .3708 L
s
.2 1 0 r
.28561 .23162 m
.31074 .2224 L
s
0 .4 1 r
.35348 .34038 m
.37884 .33151 L
s
1 0 0 r
.43213 .4849 m
.45773 .47682 L
s
1 0 .6 r
.42046 .44826 m
.44607 .43983 L
s
.8 1 0 r
.27133 .19227 m
.29644 .18291 L
s
0 1 1 r
.33927 .30113 m
.36461 .29212 L
s
.8 0 1 r
.40709 .40989 m
.43266 .40125 L
s
1 .6 0 r
.25702 .15284 m
.28211 .14334 L
s
0 1 .4 r
.32502 .2618 m
.35034 .25266 L
s
.2 0 1 r
.39304 .3708 m
.41859 .36201 L
s
.2 1 0 r
.31074 .2224 m
.33604 .21311 L
s
0 .4 1 r
.37884 .33151 m
.40437 .32258 L
s
1 0 0 r
.45773 .47682 m
.48375 .46888 L
s
1 0 .6 r
.44607 .43983 m
.47192 .43141 L
s
.8 1 0 r
.29644 .18291 m
.32172 .17349 L
s
0 1 1 r
.36461 .29212 m
.39011 .28305 L
s
.8 0 1 r
.43266 .40125 m
.45842 .39257 L
s
1 .6 0 r
.28211 .14334 m
.30736 .13378 L
s
0 1 .4 r
.35034 .25266 m
.37583 .24345 L
s
.2 0 1 r
.41859 .36201 m
.44431 .35316 L
s
.2 1 0 r
.33604 .21311 m
.36151 .20376 L
s
0 .4 1 r
.40437 .32258 m
.43007 .31359 L
s
1 0 0 r
.48375 .46888 m
.51016 .46098 L
s
1 0 .6 r
.47192 .43141 m
.498 .42295 L
s
.8 1 0 r
.32172 .17349 m
.34716 .164 L
s
0 1 1 r
.39011 .28305 m
.41579 .27393 L
s
.8 0 1 r
.45842 .39257 m
.48435 .38383 L
s
1 .6 0 r
.30736 .13378 m
.33279 .12415 L
s
0 1 .4 r
.37583 .24345 m
.40148 .23418 L
s
.2 0 1 r
.44431 .35316 m
.4702 .34426 L
s
.2 1 0 r
.36151 .20376 m
.38714 .19436 L
s
0 .4 1 r
.43007 .31359 m
.45594 .30454 L
s
1 0 0 r
.51016 .46098 m
.53687 .45303 L
s
1 0 .6 r
.498 .42295 m
.52427 .41443 L
s
.8 1 0 r
.34716 .164 m
.37277 .15445 L
s
0 1 1 r
.41579 .27393 m
.44163 .26474 L
s
.8 0 1 r
.48435 .38383 m
.51046 .37502 L
s
1 .6 0 r
.33279 .12415 m
.35838 .11446 L
s
0 1 .4 r
.40148 .23418 m
.4273 .22485 L
s
.2 0 1 r
.4702 .34426 m
.49626 .33529 L
s
.2 1 0 r
.38714 .19436 m
.41294 .18489 L
s
1 0 0 r
.53687 .45303 m
.56379 .44494 L
s
0 .4 1 r
.45594 .30454 m
.48197 .29543 L
s
1 0 .6 r
.52427 .41443 m
.5507 .40582 L
s
.8 1 0 r
.37277 .15445 m
.39856 .14484 L
s
0 1 1 r
.44163 .26474 m
.46765 .25549 L
s
.8 0 1 r
.51046 .37502 m
.53673 .36616 L
s
1 .6 0 r
.35838 .11446 m
.38414 .10471 L
s
0 1 .4 r
.4273 .22485 m
.4533 .21546 L
s
.2 0 1 r
.49626 .33529 m
.52249 .32627 L
s
1 0 0 r
.56379 .44494 m
.5908 .43666 L
s
.2 1 0 r
.41294 .18489 m
.43892 .17535 L
s
0 .4 1 r
.48197 .29543 m
.50818 .28627 L
s
1 0 .6 r
.5507 .40582 m
.57728 .39711 L
s
.8 1 0 r
.39856 .14484 m
.42451 .13516 L
s
0 1 1 r
.46765 .25549 m
.49384 .24618 L
s
.8 0 1 r
.53673 .36616 m
.56318 .35723 L
s
1 .6 0 r
.38414 .10471 m
.41007 .09489 L
s
0 1 .4 r
.4533 .21546 m
.47947 .20601 L
s
.2 0 1 r
.52249 .32627 m
.5489 .31718 L
s
1 0 0 r
.5908 .43666 m
.61785 .42818 L
s
.2 1 0 r
.43892 .17535 m
.46506 .16576 L
s
0 .4 1 r
.50818 .28627 m
.53457 .27704 L
s
1 0 .6 r
.57728 .39711 m
.60399 .38831 L
s
.8 1 0 r
.42451 .13516 m
.45063 .12542 L
s
0 1 1 r
.49384 .24618 m
.5202 .23681 L
s
.8 0 1 r
.56318 .35723 m
.58979 .34824 L
s
1 .6 0 r
.41007 .09489 m
.43617 .08501 L
s
0 1 .4 r
.47947 .20601 m
.50581 .19649 L
s
.2 0 1 r
.5489 .31718 m
.57548 .30804 L
s
.2 1 0 r
.46506 .16576 m
.49139 .1561 L
s
0 .4 1 r
.53457 .27704 m
.56113 .26775 L
s
.8 1 0 r
.45063 .12542 m
.47693 .11562 L
s
0 1 1 r
.5202 .23681 m
.54674 .22737 L
s
1 .6 0 r
.43617 .08501 m
.46245 .07506 L
s
0 1 .4 r
.50581 .19649 m
.53233 .18691 L
s
.2 1 0 r
.49139 .1561 m
.51788 .14637 L
s
.8 1 0 r
.47693 .11562 m
.50341 .10575 L
s
1 .6 0 r
.46245 .07506 m
.48891 .06504 L
s
0 g
.25 Mabswid
.53391 0 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.53391 0 m
.02642 .19522 L
s
.02642 .19522 m
.53391 0 L
s
.02642 .19522 m
.03116 .2 L
s
[(-2)] .01694 .18568 .99384 1 Mshowa
.14712 .14879 m
.15172 .1537 L
s
[(-1)] .13793 .13897 .93651 1 Mshowa
.2718 .10083 m
.27624 .10588 L
s
[(0)] .26292 .09073 .87917 1 Mshowa
.40066 .05126 m
.40493 .05646 L
s
[(1)] .39212 .04087 .82184 1 Mshowa
.53391 0 m
.538 .00534 L
s
[(2)] .52574 -0.01069 .7645 1 Mshowa
.125 Mabswid
.05025 .18606 m
.05308 .18894 L
s
.07424 .17683 m
.07705 .17973 L
s
.09837 .16755 m
.10117 .17046 L
s
.12267 .1582 m
.12545 .16113 L
s
.17173 .13933 m
.17447 .14229 L
s
.19651 .1298 m
.19923 .13278 L
s
.22144 .1202 m
.22414 .1232 L
s
.24654 .11055 m
.24922 .11356 L
s
.29723 .09105 m
.29988 .0941 L
s
.32283 .0812 m
.32546 .08427 L
s
.3486 .07129 m
.35121 .07437 L
s
.37455 .06131 m
.37713 .06441 L
s
.42695 .04115 m
.4295 .04428 L
s
.45342 .03096 m
.45594 .03412 L
s
.48007 .02071 m
.48257 .02388 L
s
.5069 .01039 m
.50938 .01358 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 265.125},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001Bb000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00`oooool5o`000:3ooooo0033ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@0X?ooool00<Cooooo00?oV9RHob4Q8Oo^k^h0XOooool00<Gooooo00?oV9RH
ob4Q8Oo^k^h0X?ooool00<Kooooo00?oMgMgofIVI_ooool0Woooool00<Oooooo00?o0000oooooooo
ool0W_ooool00<?ooooo00Go0000okZj^_ooooooV9RHoa0@402Pooooo`00`oooool01OnHV9So410@
o`000?lQ8B7oc<c<0:3ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003;ooooo`;o0000Voooool00<Sooooo0ol000000ooooooo0000ooooo`2Jooooo`00a_oo
ool2o`0000Cooooo0_l0002Jooooo`00`oooool3o`0000Kooooo00?o0000ooooool00000VOooool0
0<3ooooo1?l00008ooooo`04o`000?ooooooooooo`0009Sooooo002Hooooo`Co000000?o410@oooo
ooooool07oooool2o`0000Cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0002H
ooooo`00V_ooool00ol0003oooooooooo`0Nooooo`?o00003_ooool01Ol0003ooooooooooooooooo
000009Oooooo002Jooooo`03o`000?oooooooooo01cooooo0_l0000Aooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0U?ooool009[ooooo00?o0000ooooooooool06Oooool3o`0000;o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo09?o
oooo002Jooooo`03o`000?oooooooooo01Kooooo0ol0000Fooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^08Kooooo002Jooooo`03o`00
0?oooooooooo01Cooooo0_l0000Iooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1oooool01OmgMgOoV9RHoooooonHV9SoMgMg08Kooooo002Jooooo`03o`000?oooooooooo017ooooo
0ol000000ooooooo0000ooooo`0Hooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1_ooool01Ol@413ooooooooooooooooo410@08Kooooo002Hooooo`03oeEEEOmVIVKo0000017ooooo
0_l0000Nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool01Ol0003ooooo
oooooooooooo000008Kooooo002Yooooo`?o00008?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000026ooooo`00Yoooool3o`0002;ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@
4100Q_ooool00:Cooooo0ol00002ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Q_ooool00:7ooooo
0ol0000Xooooo`03o`000?oooooooooo00Sooooo0_l00004ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h0Q_ooool009oooooo0_l0000[ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo
0000S_ooool009cooooo0ol000000ooooooo0000ooooo`0Zooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0S?ooool009[ooooo0_l00005ooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`2;ooooo`00Uoooool3o`0003;ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`2:ooooo`00K?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^02?ooooo0ol000000ooooooo0000ooooo`0booooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0ROooool006cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Qooooo`;o0000:?ooool2
oonI00kooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`29ooooo`00K?ooool01Ol@
413ooooooooooooooooo410@01kooooo0ol0000Wooooo`?ooiT04?ooool00ol0003oooooooooo`0>
ooooo`03o`000?oooooooooo08Sooooo001/ooooo`05o`000?ooooooooooooooool000007?ooool3
o`0002Kooooo0oooV@0Cooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0Qoooool0
06cooooo00Go0000ooooooooooooooooo`00000Iooooo`?o00000_ooool00ol0003oooooooooo`0Q
ooooo`?ooiT05_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo08Kooooo001/oooo
o`05oa0@4?ooooooooooooooool@41005oooool2o`0002Kooooo0oooV@0Iooooo`03o`000?oooooo
oooo013ooooo00?o0000ooooooooool0Q_ooool006cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0D
ooooo`?o00009Oooool3oonI01cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`25
ooooo`00K?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^017ooooo0ol00002ooooo`03o`000?oooooo
oooo027ooooo0_ooV@0Oooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0Q?ooool0
083ooooo0_l0000Wooooo`;ooiT08Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
08?ooooo001mooooo`?o00009_ooool3oonI02?ooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`22ooooo`00Noooool2o`000003ooooool0003ooooo02Cooooo0_ooV@0Vooooo`03o`00
0?oooooooooo01Cooooo0_l00023ooooo`00N?ooool3o`0002Oooooo0_ooV@0Xooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooool00000Poooool007Gooooo0ol0000Wooooo`?ooiT0:_ooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo083ooooo001cooooo`Co00009Oooool3oonI
02gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1oooooo`00L?ooool3o`0000Co
oooo00?o0000ooooooooool07oooool3oonI02Gooooo0_o<o`09ooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool0Ooooool006kooooo0_l0000Vooooo`?ooiT09Oooool3olco00_ooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`1nooooo`00@oooool4o`000003oa0@4?oo
oooooooo027ooooo0ol0000Uooooo`?ooiT09Oooool3olco00kooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`1mooooo`00AOooool00ol0003oooooooooo`0Pooooo`?o00000oooool0
0ol0003oooooooooo`0Pooooo`;ooiT09Oooool3olco017ooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`1looooo`00>_ooool6o`0000Gooooo00?o0000ooooooooool07_ooool2o`00
02Kooooo0oooV@0Uooooo`;oc?l05?ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo
07cooooo0015ooooo`03o`000?oooooooooo01_ooooo0ol0000Uooooo`?ooiT09Oooool3olco01Ko
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1kooooo`00AOooool00ol0003ooooo
ooooo`0Iooooo`;o00000_ooool00ol0003oooooooooo`0Pooooo`?ooiT09_ooool2olco01Wooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`1jooooo`00AOooool00ol0003ooooooooo
o`0Fooooo`?o00009?ooool3oonI02Oooooo0_o<o`0Kooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool0NOooool004Gooooo00?o0000ooooooooool05?ooool2o`0002Cooooo0oooV@0W
ooooo`?oc?l07Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo07Wooooo0013oooo
o`03oeEEEOmVIVKo000001?ooooo0ol000000ooooooo0000ooooo`0Qooooo`;ooiT09oooool3olco
023ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1hooooo`00E_ooool3o`0002Go
oooo0_ooV@0Wooooo`;oc?l08oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo07Oo
oooo001Dooooo`;o00009_ooool2oonI02Kooooo0oo<o`0Uooooo`03o`000?oooooooooo01oooooo
0_l0001hooooo`00DOooool3o`000003ooooool0003ooooo02?ooooo0_ooV@0Uooooo`?oc?l0:?oo
ool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo07Kooooo001?ooooo`;o00009oooool2
oonI02Cooooo0oo<o`0[ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0MOooool0
04cooooo0ol0000Vooooo`?ooiT08oooool3olco02Sooooo0_lco`04ooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool0M?ooool004Wooooo1?l0000Uooooo`?ooiT08oooool3olco02So
oooo0olco`06ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0Loooool004Oooooo
0_l00004ooooo`03o`000?oooooooooo01oooooo0oooV@0Tooooo`;oc?l0:?ooool3oc?o00Wooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`1booooo`00A?ooool3o`0002Gooooo0ooo
V@0Tooooo`?oc?l09oooool3oc?o00cooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`1booooo`006_ooool5o`0002?ooooo0ol0000Tooooo`?ooiT09?ooool3olco02Oooooo0olco`0?
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0LOooool001[ooooo00GoV9RHob4Q
8Oo^k^koooooodA4A00Pooooo`?o00000oooool00ol0003oooooooooo`0Oooooo`;ooiT09?ooool3
olco02Oooooo0olco`0Booooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0L?ooool0
01;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^01oooooo0_l0000Uooooo`?ooiT09?ooool2olco
02Oooooo0olco`0Eooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0Koooool001co
oooo00?oV9RHob4Q8Oo^k^h06oooool3o`0002Cooooo0oooV@0Uooooo`;oc?l09_ooool3oc?o01So
oooo00?o0000ooooooooool09oooool00ol0003oooooooooo`1_ooooo`007Oooool00omgMgOoIVIV
ooooo`0Gooooo`?o00000oooool00ol0003oooooooooo`0Oooooo`;ooiT09_ooool2olco02Gooooo
0olco`0Kooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0K_ooool001kooooo00?o
0000ooooooooool05?ooool2o`0002Gooooo0oooV@0Vooooo`;oc?l09Oooool2oc?o01kooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`1]ooooo`006_ooool01Ol0003o^[ZjoooooonH
V9So410@01?ooooo0ol0000Tooooo`?ooiT09_ooool3olco02Cooooo0olco`0Pooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool0K?ooool001[ooooo00GoV9RHoa0@4?l0003o8B4Qolc<
c00Aooooo`;o00000oooool00ol0003oooooooooo`0Oooooo`;ooiT09_ooool3olco02Cooooo0olc
o`0Sooooo`03o`000?oooooooooo02[ooooo0_l0001]ooooo`00;Oooool3o`0002Cooooo0oooV@0U
ooooo`?oc?l09?ooool3oc?o02Kooooo00?o0000ooooooooool0:_ooool2o`0006gooooo000Zoooo
o`?o00009?ooool3oonI02Gooooo0oo<o`0Uooooo`;o<ol09oooool2o`3oIP03o`000?oooooooooo
02cooooo00?o0000ooooooooool0J_ooool002Sooooo0_l00003ooooo`03o`000?oooooooooo01ko
oooo0oooV@0Uooooo`?oc?l09Oooool3oc?o02Kooooo0ol0ofH2ooooo`03o`000?oooooooooo02go
oooo00?o0000ooooooooool0JOooool002Gooooo0ol0000Sooooo`?ooiT09_ooool2olco02Kooooo
0_lco`0Vooooo`?o0?mV1Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo06Wooooo
000Tooooo`03o`000?oooooooooo027ooooo0oooV@0Vooooo`?oc?l09_ooool2oc?o02Kooooo0_l0
ofH8ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0J?ooool001[ooooo1?l00000
0ol@413oooooooooo`03ooooo`;o00008?ooool2oonI02Kooooo0oo<o`0Vooooo`?o<ol09Oooool3
o`3oIP[ooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`1Wooooo`007?ooool00ol0
003oooooooooo`05ooooo`;o00007Oooool3oonI02Kooooo0_o<o`0Vooooo`?o<ol09Oooool3o`3o
IPgooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`1Vooooo`004Oooool6o`0000Go
oooo00?o0000ooooooooool01?ooool4o`0001Wooooo0oooV@0Vooooo`?oc?l09_ooool2oc?o02Go
oooo0ol0ofH@ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool02?ooool5o`0005Wo
oooo000Looooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo00005oooool00oooV@3o
ooooooooo`0Tooooo`?oc?l09_ooool3oc?o02Gooooo0_l0ofHCooooo`03o`000?oooooooooo037o
oooo00?o0000ooooooooool01oooool01OnHV9So8B4Qonk^k_ooooooA4A405Wooooo000Looooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0hooooo`?o
c?l09_ooool3oc?o02Gooooo0ol0ofHEooooo`03o`000?oooooooooo03;ooooo00?o0000oooooooo
ool01oooool00onHV9So8B4Qonk^kP1Jooooo`007?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool0=?ooool3olco02Kooooo0olco`0Vooooo`;o0?mV
6?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Oooooo00?oV9RHob4Q8Oo^k^h0
FOooool001cooooo00?o0000ooooooooool01?ooool2o`0000Gooooo00?o0000ooooooooool0<?oo
ool3olco02Kooooo0olco`0Wooooo`;o0?mV6_ooool00ol0003oooooooooo`0dooooo`03o`000?oo
oooooooo00Oooooo00?oMgMgofIVI_ooool0F?ooool001[ooooo00?oEEEEofIVI_l000001_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo02gooooo0_o<o`0Vooooo`?o<ol09oooool3
o`3oIQcooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo
oooo05Oooooo000Sooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0:Oooool3olco
02Kooooo0_lco`0Wooooo`?o0?mV7oooool00ol0003oooooooooo`0eooooo`;o00001?ooool01Ol0
003o^[ZjoooooonHV9So410@05Wooooo000Sooooo`;o00002?ooool00ol0003oooooooooo`0Uoooo
o`?oc?l09_ooool3oc?o02Oooooo0_l0ofHRooooo`03o`000?oooooooooo00;o0?oo<Oooool2o`00
0003ooooool0003ooooo00?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c01Iooooo`008oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo02;ooooo0_o<o`0Vooooo`?o<ol09oooool3o`3o
IRCooooo00?o0000o`3oool0ool0=oooool00ol0003oooooooooo`1Oooooo`008oooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo01kooooo0oo<o`0Vooooo`;o<ol09oooool3o`3oIRGo
oooo0_l0ool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo05oooooo000Sooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool06_ooool3olco02Kooooo0olco`0Vooooo`?o0?mV
9_ooool2o`3oo`03ooooool0003o000003[ooooo00?o0000ooooooooool0G_ooool002;ooooo0_l0
000=ooooo`03o`000?oooooooooo01Oooooo0_o<o`0Vooooo`?o<ol09_ooool3o`3oIROooooo0_l0
ool3o`000003ooooool0003ooooo03[ooooo00?o0000ooooooooool0GOooool002;ooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0Cooooo`?oc?l09Oooool3oc?o02Kooooo0ol0ofHW
ooooo`;o0?oo0ol00005ooooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0G?ooool0
02;ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0?ooooo`?oc?l09Oooool3oc?o
02Oooooo0_l0ofHWooooo`;o0?oo0ol00009ooooo`03o`000?oooooooooo03Sooooo00?o0000oooo
ooooool0G?ooool002;ooooo0ol0000?ooooo`03o`000?oooooooooo00gooooo00?oc?l0oooooooo
ool08oooool3oc?o02Oooooo0ol0ofHWooooo`04o`3oool0003o0000o`0000gooooo00?o0000oooo
ooooool0>?ooool00ol0003oooooooooo`1Kooooo`008_ooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo033ooooo0_lco`0Wooooo`?o0?mV9oooool2o`3oo`;o00004Oooool00ol0003o
ooooooooo`0hooooo`03o`000?oooooooooo05[ooooo000Rooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool0;?ooool3oc?o02Kooooo0ol0ofHWooooo`;o0?oo0ol0000Dooooo`03o`00
0?oooooooooo03Sooooo00?o0000ooooooooool0FOooool000Oooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooooooo
ool04_ooool00ol0003oooooooooo`0Xooooo`?o<ol09_ooool3o`3oIROooooo0_l0ool3o`0001Oo
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1Iooooo`001oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0Uooooo`;o<ol09_ooool3o`3oIROooooo0_l0ool3o`0001_o
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1Hooooo`001Ol00002ooooo`05oa0@
4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Go
oooo00?o0000ooooooooool08Oooool3oc?o02Kooooo0_l0ofHWooooo`;o0?oo0ol0000Oooooo`03
o`000?oooooooooo03Sooooo00?o0000ooooooooool0Eoooool000Oooooo00Go0000oooooooooooo
ooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool05_ooool00ol0003o
ooooooooo`0Mooooo`?o<ol09_ooool3o`3oIRKooooo0_l0ool3o`0002?ooooo00?o0000oooooooo
ool0=oooool2o`0005Sooooo0007ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o
8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`0Joooo
o`;o<ol09_ooool3o`3oIRKooooo0ol0ool2o`0002Kooooo00?o06Koo`000?ooool0>Oooool00ol0
003oooooooooo`1Eooooo`001oooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000oooo
ooooool01_ooool2o`0001Wooooo00?o0000ooooooooool05_ooool3oc?o02Gooooo0ol0ofHVoooo
o`?o0?oo0ol0000Uooooo`?o06Ko0_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo
05Gooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool04_ooool3oc?o02Gooooo0ol0ofHWoooo
o`;o0?oo0ol0000Uooooo`?o06Ko1Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo
05Cooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000oooo
ooooool06_ooool00ol0003oooooooooo`0?ooooo`;o<ol09Oooool3o`3oIROooooo0_l0ool3o`00
02Gooooo0ol0I_l9ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0Doooool0027o
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0;ooooo`?o<ol09Oooool2o`3oIROo
oooo0_l0ool3o`0002Gooooo0ol0I_l=ooooo`03o`000?oooooooooo03Sooooo00?o0000oooooooo
ool0D_ooool0023ooooo0ol0000Mooooo`03o`000?oooooooooo00Oooooo0olco`0Uooooo`?o0?mV
9_ooool3o`3oo`;o00009Oooool3o`1Voa7ooooo00?o0000ooooooooool0=oooool00ol0003ooooo
ooooo`1Booooo`008Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00Gooooo00?o
<ol0ooooooooool08oooool3o`3oIRKooooo0ol0ool3o`0002Cooooo0ol0I_lEooooo`03o`000?oo
oooooooo03Oooooo00?o0000ooooooooool0DOooool0023ooooo00?o0000ooooooooool07oooool0
0ol0003oooooooooo`0Xooooo`;o0?mV9_ooool3o`3oo`?o00009?ooool3o`1VoaWooooo00?o0000
ooooooooool0=oooool00ol0003oooooooooo`1@ooooo`008?ooool00ol0003oooooooooo`0Poooo
o`03o`000?oooooooooo02Cooooo0ol0ofHVooooo`;o0?oo0ol0000Tooooo`?o06Ko7?ooool00ol0
003oooooooooo`0hooooo`03o`000?oooooooooo04oooooo000Pooooo`;o00008_ooool00ol0003o
ooooooooo`0Pooooo`?o0?mV9_ooool2o`3oo`?o00009Oooool2o`1Vob3ooooo00?o0000oooooooo
ool0=oooool00ol0003oooooooooo`1?ooooo`008?ooool00ol0003oooooooooo`0Rooooo`03o`00
0?oooooooooo01gooooo0_l0ofHVooooo`?o0?oo0_l0000Uooooo`?o06Ko8oooool00ol0003ooooo
ooooo`0gooooo`03o`000?oooooooooo04kooooo000Pooooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool06Oooool3o`3oIRGooooo0ol0ool3o`0002Cooooo0ol0I_lWooooo`03o`000?oo
oooooooo03Oooooo00?o0000ooooooooool0COooool0023ooooo0ol0000Tooooo`03o`000?oooooo
oooo01Gooooo0ol0ofHUooooo`?o0?oo0ol0000Tooooo`?o06Ko:oooool00ol0003oooooooooo`0f
ooooo`;o0000C_ooool0023ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Boooo
o`;o0?mV9Oooool3o`3oo`?o00009?ooool3o`1VobSooooo0_lc0?l5ooooo`03o`000?oooooooooo
03Kooooo00?o0000ooooooooool0C?ooool001Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP07oooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool03_ooool3o`3oIRGooooo0_l0ool3o`00
02Cooooo0ol0I_lXooooo`?o<`3o1oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo
04_ooooo000Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`0Xoooo
o`03o`000?oooooooooo00[ooooo0ol0ofHUooooo`?o0?oo0_l0000Uooooo`;o06Ko:?ooool3oc<0
o`_ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`1:ooooo`005?ooool01Ol@413o
oooooooooooooooo410@00Kooooo0_l0000Zooooo`03o`000?oooooooooo00Oooooo0_l0ofHUoooo
o`?o0?oo0ol0000Tooooo`?o06Ko9oooool3oc<0o`oooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`19ooooo`005?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooo
ooooool0:_ooool00ol0003oooooooooo`03ooooo`?o0?mV9Oooool2o`3oo`?o00009?ooool3o`1V
obOooooo0olc0?lCooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0BOooool001Co
oooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo02_ooooo00?o0000oooo
ool0ofH00_l0ofHUooooo`;o0?oo0ol0000Tooooo`?o06Ko9oooool3oc<0oaOooooo00?o0000oooo
ooooool0=_ooool00ol0003oooooooooo`18ooooo`005?ooool01Ol@413ooooooooooooooooo410@
00Kooooo00?o0000ooooooooool0;?ooool00ol0ofKoooooooooo`0Sooooo`;o0?oo0ol0000Toooo
o`?o06Ko9oooool3oc<0oa_ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`17oooo
o`005?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo0_l0000^ooooo`03o`000?oooooooooo
023ooooo00Co0?ooo`000?l0003o00009?ooool3o`1VobOooooo0olc0?lNooooo`03o`000?oooooo
oooo03Oooooo00?o0000ooooooooool0A_ooool001Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06
ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool07?ooool2o`3oo`;o00009Oooool2
o`1VobOooooo0olc0?lRooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0AOooool0
01oooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Hooooo`;o0?oo0ol0000Toooo
o`?o06Ko9oooool2oc<0obKooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`15oooo
o`007_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo01Cooooo0_l0ool3o`0002Co
oooo0ol0I_lWooooo`?o<`3o:Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo04Co
oooo000Nooooo`;o0000<oooool00ol0003oooooooooo`0@ooooo`;o0?oo0ol0000Tooooo`?o06Ko
9oooool3oc<0obgooooo00?o0000ooooooooool0=_ooool2o`0004Cooooo000Nooooo`03o`000?oo
oooooooo03?ooooo00?o0000ooooooooool03?ooool2o`3oo`?o00009?ooool3o`1VobOooooo0olc
0?laooooo`03o`000?oooooooooo03Cooooo00?o0000ooooool00000A?ooool001kooooo00?o0000
ooooooooool0=?ooool00ol0003oooooooooo`08ooooo`?o0?oo0_l0000Tooooo`?o06Ko9oooool3
oc<0ocCooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`12ooooo`007_ooool00ol0
003oooooooooo`0eooooo`03o`000?oooooooooo00?ooooo1?l0ool3o`0002Cooooo0_l0I_lWoooo
o`?o<`3o:oooool2ol`0o`_ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`11oooo
o`007_ooool2o`0003Oooooo00?o0000ooooool0ool00_l0ool01?oooooo0000o`000?l0000Toooo
o`?o06Ko9_ooool3oc<0ob_ooooo0oo<0?l>ooooo`03o`000?oooooooooo03Kooooo00?o0000oooo
ooooool0@?ooool001kooooo00?o0000ooooooooool0=Oooool3o`3oo`04ooooool0003o0000o`00
02Cooooo0ol0I_lVooooo`?o<`3o:oooool3ol`0oa;ooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`0oooooo`007_ooool00ol0003oooooooooo`0booooo`?o0?oo00Coooooo`000?l0
003o00009Oooool2o`1VobKooooo0olc0?l[ooooo`?oc03o5_ooool00ol0003oooooooooo`0eoooo
o`03o`000?oooooooooo03oooooo000Nooooo`;o0000<_ooool00ol0ooooooooooooo`02o`0000?o
oooo00?o0000ooooooooool07oooool3o`1VobKooooo0_lc0?l[ooooo`?oc03o6_ooool00ol0003o
ooooooooo`0eooooo`03o`000?oooooooooo00Wooooo0_l000000ol@413oooooooooo`0`ooooo`00
7Oooool00ol0003oooooooooo`0booooo`?o00001_ooool00ol0003oooooooooo`0Kooooo`?o06Ko
9_ooool3oc<0ob[ooooo0oo<0?lMooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0aooooo`000_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0_ooooo`?o
00002_ooool00ol0003oooooooooo`0Gooooo`?o06Ko9_ooool3oc<0obWooooo1?o<0?lQooooo`03
o`000?oooooooooo03Kooooo00?o0000ooooooooool01Oooool5o`0003;ooooo0002ooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003o
ooooooooo`0/ooooo`?o00003_ooool00ol0003oooooooooo`0Cooooo`?o06Ko9_ooool3oc<0obOo
oooo1Oo<0?lVooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool01Oooool01?m4A4Co
gMgMooooool0000cooooo`000_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000oooo
ooooool00oooool2o`0002[ooooo0ol0000Booooo`03o`000?oooooooooo00oooooo0ol0I_lVoooo
o`?o<`3o9oooool3ol`0obcooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`04oooo
o`04omgMgOmEEEGoooooo`0003?ooooo0002ooooo`05o`000?ooooooooooooooool000003oooool0
0omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo02Oooooo0_l0000Fooooo`03o`000?oooooo
oooo00_ooooo0ol0I_lVooooo`?o<`3o9oooool3ol`0oc3ooooo00?o0000ooooooooool0=Oooool0
0ol0003oooooooooo`04ooooo`03ogMgMoo<c<co000003?ooooo0002ooooo`05o`000?oooooooooo
ooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool09?oo
ool3o`0001Wooooo00?o0000ooooooooool01_ooool4o`1VobOooooo0_lc0?lWooooo`?oc03o=?oo
ool00ol0003oooooooooo`0dooooo`;o00001Oooool00oo^k^koA4A4o`00000cooooo`000_ooool0
1Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0Qooooo`?o00007Oooool00ol0003oooooooooo`02ooooo`?o06Ko:?ooool3oc<0obOooooo0_o<
0?lgooooo`03o`000?oooooooooo03?ooooo00Co0000oooooooooooo00001Oooool00omgMgOo0000
ooooo`0booooo`000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool0
1oooool2o`0001oooooo0ol0000Qooooo`04o`000?l0I_oo06Koo`1VobSooooo0olc0?lWooooo`?o
c03o>_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo03Sooooo0002ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000ooooooooool07?ooool3o`0002;o
oooo0ol0I_l00ol0003oooooooooo`0Vooooo`;o<`3o9oooool3ol`0ob[ooooo0_oo09TBooooo`03
o`000?oooooooooo03Gooooo00?o0000ooooooooool0=oooool001cooooo00?o0000ooooooooool0
6Oooool3o`0002?ooooo0_l0I_l4ooooo`03o`000?oooooooooo02;ooooo0olc0?lVooooo`?oc03o
:_ooool3ool0VAGooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0fooooo`007?oo
ool00ol0003oooooooooo`0Gooooo`;o00008oooool3o`1Vo`Oooooo00?o0000ooooooooool07_oo
ool3oc<0obKooooo0oo<0?lZooooo`?oo`2I6Oooool00ol0003oooooooooo`0eooooo`03o`000?oo
oooooooo03Gooooo000Looooo`;o00005Oooool3o`0002;ooooo0ol0I_l;ooooo`03o`000?oooooo
oooo01[ooooo0olc0?lVooooo`?oc03o:_ooool3ool0VAgooooo00?o0000ooooooooool0=?ooool0
0ol0003oooooooooo`0eooooo`007?ooool00ol0003oooooooooo`0Aooooo`?o00009?ooool00ol0
I_ooooooooooo`0=ooooo`03o`000?oooooooooo01Kooooo0olc0?lVooooo`?oc03o:_ooool3ool0
VB3ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0dooooo`007?ooool00ol0003o
ooooooooo`0>ooooo`?o0000>?ooool00ol0003oooooooooo`0Booooo`?o<`3o9_ooool3ol`0ob[o
oooo0ooo09TTooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0<oooool001cooooo
00?o0000ooooooooool02oooool3o`0003cooooo00?o0000ooooooooool03_ooool3oc<0obKooooo
0oo<0?l[ooooo`;oo`2I:?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo03;ooooo
000Looooo`;o00002_ooool2o`00043ooooo00?o0000ooooooooool02Oooool4oc<0obOooooo0_o<
0?l[ooooo`?oo`2I:oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo03;ooooo000K
ooooo`;o00002?ooool3o`0004?ooooo00?o0000ooooooooool01Oooool3oc<0obSooooo0oo<0?lZ
ooooo`?oo`2I;oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo037ooooo000Koooo
o`03o`000?oooooooooo00Cooooo0ol00017ooooo`04o`000?ooooooooooooooo`?o<`3o:?ooool3
ol`0obWooooo1?oo09Tcooooo`03o`000?oooooooooo03?ooooo0_l0000booooo`006oooool01?l0
003oooooooooooooool3o`0004_ooooo0olc0?lYooooo`;oc03o9oooool5ool0VCOooooo00?o0000
ooooooooool0=Oooool00ol0003oooooooooo`0_ooooo`006oooool4o`0004cooooo0_lc0?l00ooo
oooo0000ooooo`0Vooooo`?oc03o9_ooool3ool0VCgooooo00?o0000ooooooooool0=?ooool00ol0
003oooooooooo`0_ooooo`006oooool2o`0004_ooooo0olc0?l4ooooo`03o`000?oooooooooo027o
oooo0oo<0?lVooooo`?oo`2I@Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02ko
oooo000Aooooo`Co000000?o410@ooooooooool01Oooool00ol0003oooooooooo`15ooooo`?o<`3o
2?ooool00ol0003oooooooooo`0Mooooo`?oc03o9_ooool3ool0VB_ooooo0_oo000Hooooo`03o`00
0?oooooooooo03Cooooo00?o0000ooooooooool0;Oooool001?ooooo00?o0000ooooooooool02?oo
ool00ol0003oooooooooo`12ooooo`;o<`3o3?ooool00ol0003oooooooooo`0Iooooo`?oc03o9_oo
ool3ool0VB_ooooo0ooo000Kooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0;?oo
ool001?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0nooooo`?o<`3o3oooool0
0ol0003oooooooooo`0Eooooo`?oc03o9_ooool3ool0VB_ooooo0ooo000Oooooo`03o`000?oooooo
oooo03?ooooo00?o0000ooooooooool0;?ooool001?ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0jooooo`?o<`3o4oooool00ol0003oooooooooo`0Aooooo`?oc03o9_ooool3ool0
VB_ooooo0ooo000Rooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0:oooool001?o
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0gooooo`;o<`3o5oooool00ol0003o
ooooooooo`0<ooooo`Coc03o9oooool2ool0VB_ooooo0ooo000Vooooo`03o`000?oooooooooo03Co
oooo00?o0000ooooooooool0:_ooool001?ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`1@ooooo`03o`000?oooooooooo00Sooooo0oo<0?lXooooo`?oo`2I:_ooool3ool002[ooooo
00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Yooooo`004oooool00ol0003ooooooooo
o`0=ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool01?ooool3ol`0obSooooo0ooo
09TYooooo`Coo`00;_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02Sooooo000A
ooooo`03oeEEEOmVIVKo0000013ooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`03
ol`0obSooooo0ooo09TWooooo`Goo`00<oooool00ol0003oooooooooo`0cooooo`03o`000?oooooo
oooo02Sooooo000Uooooo`03o`000?oooooooooo04oooooo0oo<0?lXooooo`?oo`2I9oooool3ool0
03Wooooo00?o0000ooooooooool0<_ooool2o`0002Wooooo000Vooooo`;o0000C?ooool3ol`0o`;o
oooo00?o0000ooooooooool08oooool3ool0VBOooooo0ooo000looooo`03o`000?oooooooooo03Co
oooo00?o0000ooooooooool09_ooool002Sooooo00?o0000ooooooooool0A_ooool3ol`0o`Gooooo
00?o0000ooooooooool08?ooool3ool0VBOooooo0ooo0010ooooo`03o`000?oooooooooo03Cooooo
00?o0000ooooooooool09Oooool002Wooooo00?o0000ooooooooool0@oooool2ol`0o`Wooooo00?o
0000ooooooooool06oooool4ool0VBOooooo0ooo0014ooooo`03o`000?oooooooooo03?ooooo00?o
0000ooooooooool09Oooool002[ooooo00?o0000ooooooooool0?oooool3ol`0o`cooooo00?o0000
ooooooooool05oooool3ool0VBSooooo0ooo0018ooooo`03o`000?oooooooooo03?ooooo00?o0000
ooooooooool09?ooool002_ooooo00?o0000ooooooooool0>oooool3ol`0oa3ooooo00?o0000oooo
ooooool04oooool3ool0VBSooooo0ooo001<ooooo`03o`000?oooooooooo03?ooooo00?o0000oooo
ooooool08oooool002cooooo00?o0000ooooooooool0=oooool3ol`0oaCooooo00?o0000oooooooo
ool03oooool3ool0VBOooooo1?oo001@ooooo`03o`000?oooooooooo03?ooooo00?o0000oooooooo
ool08_ooool002gooooo00?o0000ooooooooool0<_ooool4ol`0oaSooooo00?o0000ooooooooool0
2oooool3ool0VBKooooo1?oo001Dooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0
8_ooool002kooooo00?o0000ooooooooool0;oooool2ol`0oagooooo00?o0000ooooooooool01ooo
ool3ool0VBKooooo0ooo001Iooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool08Ooo
ool002oooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`03ooooo`?oo`2I9_ooool3
ool005gooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Pooooo`00<?ooool00ol0
003oooooooooo`1>ooooo`03o`000?oooooooooo00;oo`2I9_ooool3ool0067ooooo00?o0000oooo
ooooool0<oooool00ol0003oooooooooo`0Oooooo`00<Oooool2o`0004kooooo0ooo09TUooooo`?o
o`00IOooool00ol0003oooooooooo`0booooo`;o00008?ooool003?ooooo00?o0000ooooooooool0
B?ooool3ool0V@;ooooo00?o0000ooooooooool08?ooool3ool006Wooooo00?o0000ooooooooool0
<Oooool2o`00023ooooo000dooooo`03o`000?oooooooooo04Gooooo0_oo09T6ooooo`03o`000?oo
oooooooo01cooooo0ooo001/ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool07Ooo
ool003Gooooo00?o0000ooooooooool0@Oooool3ool0V@Wooooo00?o0000ooooooooool06?ooool3
ool0073ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Looooo`00=_ooool00ol0
003oooooooooo`0mooooo`?oo`2I3Oooool00ol0003oooooooooo`0Cooooo`Coo`00M?ooool00ol0
003oooooooooo`0booooo`03o`000?oooooooooo01cooooo000gooooo`03o`000?oooooooooo03Wo
oooo0ooo09TAooooo`03o`000?oooooooooo00oooooo0ooo001iooooo`03o`000?oooooooooo03;o
oooo00?o0000ooooooooool06oooool003Sooooo00?o0000ooooooooool0=?ooool4ool0VAGooooo
00?o0000ooooooooool02oooool3ool007gooooo00?o0000ooooooooool0<_ooool00ol0003ooooo
ooooo`07ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`03_ooool003Wooooo00?o0000ooooooooool0
<?ooool3ool0VA[ooooo00?o0000ooooooooool01oooool3ool0087ooooo00?o0000ooooooooool0
<_ooool00ol0003oooooooooo`06ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B403_ooool003[ooooo
00?o0000ooooooooool0;?ooool3ool0VAkooooo00?o0000ooooooooool01?ooool2ool008Cooooo
00?o0000ooooooooool0<oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool0
00003_ooool003_ooooo00?o0000ooooooooool0:?ooool3ool0VB;ooooo00?o0000ooooooooool0
0ooo0027ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool01Oooool01Ol0003oV9RH
oooooonHV9So8B4Q00kooooo000looooo`03o`000?oooooooooo02Kooooo00?oo`2Iooooooooool0
8oooool3ool008_ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`04ooooo`05o`00
0?mEEEGo0000oa0@4?o<c<`03_ooool003gooooo0_l00019ooooo`?oo`000_ooool00ol0003ooooo
ooooo`2:ooooo`03o`000?oooooooooo03;ooooo0_l00004ooooo`03oeEEEOn7QhOooooo013ooooo
000oooooo`03o`000?oooooooooo04?ooooo0ooo0006ooooo`03o`000?oooooooooo08[ooooo00?o
0000ooooooooool0;oooool2o`000003ooooool0003ooooo00?ooooo00?ogMgMoa0@4?nHV9P04?oo
ool0043ooooo00?o0000ooooooooool0?oooool3ool000[ooooo00?o0000ooooooooool0R_ooool0
0ol0003oooooooooo`0aooooo`03o`000?oooooooooo00?ooooo00Coc<c<odA4A?l0003o410@3_oo
ool0047ooooo00?o0000ooooooooool0??ooool2ool000kooooo00?o0000ooooooooool0ROooool0
0ol0003oooooooooo`0booooo`03o`000?oooooooooo01Cooooo0012ooooo`03o`000?oooooooooo
03Sooooo0ooo000Aooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool0<_ooool00ol0
003oooooooooo`0Cooooo`00@oooool00ol0003oooooooooo`0dooooo`?oo`005Oooool00ol0003o
ooooooooo`29ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool04_ooool004Cooooo
00?o0000ooooooooool0<Oooool2ool001Wooooo00?o0000ooooooooool0ROooool00ol0003ooooo
ooooo`0aooooo`03o`000?oooooooooo01;ooooo0015ooooo`03o`000?oooooooooo02gooooo0ooo
000Looooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool0<Oooool00ol0003ooooooooo
o`0Aooooo`00A_ooool00ol0003oooooooooo`0Yooooo`?oo`008?ooool00ol0003oooooooooo`29
ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool04?ooool004Oooooo00?o0000oooo
ooooool09Oooool3ool002Cooooo00?o0000ooooooooool0R?ooool00ol0003oooooooooo`0boooo
o`03o`000?oooooooooo00oooooo0018ooooo`;o00008Oooool4ool002Sooooo00?o0000oooooooo
ool0R?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00oooooo001:ooooo`03o`00
0?oooooooooo01cooooo0_oo000]ooooo`03o`000?oooooooooo08Sooooo00?o0000ooooooooool0
<Oooool2o`0000oooooo001;ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0R?oo
ool00ol0003oooooooooo`0`ooooo`;o00003oooool004cooooo00?o0000ooooooooool0Boooool0
0ol0003oooooooooo`28ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool03?ooool0
04gooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`28ooooo`03o`000?oooooooooo
037ooooo00?o0000ooooooooool02oooool004kooooo00?o0000ooooooooool0Boooool00ol0003o
ooooooooo`27ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool02oooool004oooooo
00?o0000ooooooooool0Boooool00ol0003oooooooooo`27ooooo`03o`000?oooooooooo037ooooo
00?o0000ooooooooool02_ooool0053ooooo00?o0000ooooooooool0Boooool00ol0003ooooooooo
o`27ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool02Oooool0057ooooo00?o0000
ooooooooool0Boooool00ol0003oooooooooo`27ooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool02?ooool005;ooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`27oooo
o`03o`000?oooooooooo033ooooo00?o0000ooooooooool02?ooool005?ooooo0_l0001<ooooo`03
o`000?oooooooooo08Oooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`07ooooo`00
EOooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo08Kooooo00?o0000ooooooooool0
<Oooool00ol0003oooooooooo`06ooooo`00E_ooool00ol0003oooooooooo`1:ooooo`03o`000?oo
oooooooo08Kooooo00?o0000ooooooooool0;oooool3o`0000Oooooo001Gooooo`03o`000?oooooo
oooo04[ooooo00?o0000ooooooooool0Q_ooool00ol0003oooooooooo`0[ooooo`?o00000_ooool0
0ol0003oooooooooo`05ooooo`00F?ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo
08Kooooo00?o0000ooooooooool09oooool3o`0000Gooooo00?o0000ooooooooool01Oooool005Wo
oooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`26ooooo`03o`000?oooooooooo02;o
oooo1?l00008ooooo`03o`000?oooooooooo00Gooooo001Jooooo`03o`000?oooooooooo04[ooooo
00?o0000ooooooooool0Q_ooool00ol0003oooooooooo`0Nooooo`?o00003?ooool00ol0003ooooo
ooooo`05ooooo`00Foooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo08Gooooo00?o
0000ooooooooool06_ooool4o`0000oooooo00?o0000ooooooooool01Oooool005cooooo00?o0000
ooooooooool0B_ooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo01Kooooo0ol0000D
ooooo`03o`000?oooooooooo00Cooooo001Mooooo`03o`000?oooooooooo04[ooooo00?o0000oooo
ooooool0QOooool00ol0003oooooooooo`0Booooo`?o00005oooool00ol0003oooooooooo`04oooo
o`00G_ooool2o`0004_ooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`0=ooooo`Co
00006_ooool00ol0003oooooooooo`04ooooo`00H?ooool00ol0003oooooooooo`19ooooo`03o`00
0?oooooooooo08Gooooo00?o0000ooooooooool02Oooool3o`0001kooooo00?o0000ooooooooool0
1?ooool0067ooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`25ooooo`03o`000?oo
oooooooo00Cooooo1?l0000Qooooo`03o`000?oooooooooo00Cooooo001Rooooo`03o`000?oooooo
oooo04Wooooo00?o0000ooooooooool0Q?ooool01?l0003oooooooooooooool3o`0002Gooooo00?o
0000ooooooooool01?ooool006?ooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`24
ooooo`?o0000:?ooool00ol0003oooooooooo`04ooooo`00I?ooool00ol0003oooooooooo`19oooo
o`03o`000?oooooooooo07oooooo1?l000000ooooooo0000ooooo`0Xooooo`03o`000?oooooooooo
00Cooooo001Uooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0Noooool3o`0000Ko
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`04ooooo`00I_ooool00ol0003ooooo
ooooo`19ooooo`03o`000?oooooooooo07Kooooo1?l0000:ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool01?ooool006Oooooo00?o0000ooooooooool0BOooool00ol0003ooooooooo
o`1booooo`?o00003oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00?ooooo001X
ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0K_ooool3o`0001;ooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`03ooooo`00JOooool00ol0003oooooooooo`19oooo
o`03o`000?oooooooooo06Wooooo1?l0000Fooooo`03o`000?oooooooooo02Cooooo00?o0000oooo
ooooool00oooool006[ooooo0_l0001:ooooo`03o`000?oooooooooo06Gooooo0ol0000Kooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool00oooool006cooooo00?o0000ooooooooool0
B?ooool00ol0003oooooooooo`1Pooooo`Co00007oooool00ol0003oooooooooo`0Rooooo`03o`00
0?oooooooooo00?ooooo001]ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0G?oo
ool3o`0002Cooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`03ooooo`00K_ooool0
0ol0003oooooooooo`18ooooo`03o`000?oooooooooo05Sooooo0ol0000Xooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool00oooool006oooooo00?o0000ooooooooool0B?ooool00ol0
003oooooooooo`1Cooooo`Co0000:oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo
00?ooooo001`ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0Coooool3o`00033o
oooo00?o0000ooooooooool07oooool00ol0003oooooooooo`03ooooo`00LOooool00ol0003ooooo
ooooo`18ooooo`03o`000?oooooooooo04[ooooo1?l0000dooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool00oooool007;ooooo00?o0000ooooooooool0B?ooool00ol0003ooooooooo
o`16ooooo`?o0000>Oooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00;ooooo001c
ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0@_ooool3o`0003gooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`02ooooo`00M?ooool00ol0003oooooooooo`18oooo
o`03o`000?oooooooooo03gooooo1?l00011ooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool00_ooool007Gooooo0_l00019ooooo`03o`000?oooooooooo03Wooooo0ol00015ooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool00_ooool007Oooooo00?o0000ooooooooool0
Aoooool00ol0003oooooooooo`0dooooo`Co0000BOooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo00;ooooo001hooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0<?oo
ool3o`0004kooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`02ooooo`00NOooool0
0ol0003oooooooooo`17ooooo`03o`000?oooooooooo02cooooo0ol0001Booooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool00_ooool007[ooooo00?o0000ooooooooool0Aoooool00ol0
003oooooooooo`0Wooooo`Co0000E_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo
00;ooooo001kooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool08oooool3o`0005_o
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`02ooooo`00O?ooool00ol0003ooooo
ooooo`17ooooo`03o`000?oooooooooo01kooooo1?l0001Nooooo`03o`000?oooooooooo01Oooooo
00?o0000ooooooooool00_ooool007gooooo00?o0000ooooooooool0Aoooool00ol0003ooooooooo
o`0Jooooo`?o0000Hoooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo007ooooo001n
ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool05_ooool3o`0006Oooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`01ooooo`00Ooooool00ol0003oooooooooo`17oooo
o`03o`000?oooooooooo017ooooo1?l0001[ooooo`03o`000?oooooooooo01Gooooo00?o0000oooo
ooooool00Oooool0083ooooo0_l00018ooooo`03o`000?oooooooooo00gooooo0ol0001`ooooo`03
o`000?oooooooooo01Cooooo00?o0000ooooooooool00Oooool008;ooooo00?o0000ooooooooool0
A_ooool00ol0003oooooooooo`08ooooo`Co0000M?ooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo007ooooo0023ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool01?oo
ool3o`0007Sooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`01ooooo`00Q?ooool0
0ol0003oooooooooo`16ooooo`03o`000?oooooooooo00?o0000O?ooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo007ooooo0025ooooo`03o`000?oooooooooo04Kooooo0_l00020oooo
o`03o`000?oooooooooo017ooooo00?o0000ooooooooool00Oooool008Kooooo00?o0000oooooooo
ool0AOooool00ol0003oooooooooo`20ooooo`03o`000?oooooooooo013ooooo00?o0000oooooooo
ool00Oooool008Oooooo00?o0000ooooooooool0A?ooool00ol0003oooooooooo`21ooooo`03o`00
0?oooooooooo00oooooo00?o0000ooooooooool00Oooool008Sooooo00?o0000ooooooooool0@ooo
ool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo00oooooo0Ol00001ooooo`7ooooo0029
ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`0?
ooooo`7o00000Oooool1ooooo`00R_ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo
08?ooooo00?o0000ooooooooool03_ooool1o`00007ooooo0Oooool008_ooooo0_l00011ooooo`03
o`000?oooooooooo08Cooooo00?o0000ooooooooool03Oooool1o`00007ooooo0Oooool008gooooo
00?o0000ooooooooool0?_ooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo00cooooo
0Ol00001ooooo`7ooooo002>ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0Q_oo
ool00ol0003oooooooooo`0;ooooo`7o00000Oooool1ooooo`00Soooool00ol0003oooooooooo`0l
ooooo`03o`000?oooooooooo08Oooooo00?o0000ooooooooool02_ooool1o`00007ooooo0Oooool0
093ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`27ooooo`03o`000?oooooooooo
00[ooooo0Ol00001ooooo`7ooooo002Aooooo`03o`000?oooooooooo03[ooooo00?o0000oooooooo
ool0R?ooool00ol0003oooooooooo`09ooooo`7o00000Oooool1ooooo`00T_ooool00ol0003ooooo
ooooo`0iooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool02?ooool1o`00007ooooo
0Oooool009?ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`2:ooooo`03o`000?oo
oooooooo00Sooooo0Ol00001ooooo`00U?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooo
oooo08_ooooo00?o0000ooooooooool01oooool1o`00007ooooo002Eooooo`03o`000?oooooooooo
03Kooooo00?o0000ooooooooool0S?ooool00ol0003oooooooooo`06ooooo`7o00000Oooool009Ko
oooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`2<ooooo`03o`000?oooooooooo00Ko
oooo0Ol00001ooooo`00Uoooool2o`0003Gooooo00?o0000ooooooooool0SOooool00ol0003ooooo
ooooo`05ooooo`7o00000Oooool009Wooooo00?o0000ooooooooool0<_ooool00ol0003ooooooooo
o`2>ooooo`03o`000?oooooooooo00Cooooo0Ol00001ooooo`00V_ooool00ol0003oooooooooo`0a
ooooo`03o`000?oooooooooo08oooooo00?o0000ooooooooool00oooool1o`00007ooooo002Koooo
o`03o`000?oooooooooo033ooooo00?o0000ooooooooool0T?ooool00ol0003oooooooooo`02oooo
o`7o00000Oooool009cooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`2Aooooo`05
o`000?ooooooooooooooool000000Oooool009gooooo00?o0000ooooooooool0;_ooool00ol0003o
ooooooooo`2Aooooo`05o`000?ooooooooooooooool000000Oooool009kooooo00?o0000oooooooo
ool0;Oooool00ol0003oooooooooo`2Booooo`04o`000?ooooooooooooooo`7o0000002Oooooo`03
o`000?oooooooooo02cooooo00?o0000ooooooooool0Toooool00ol0003oooooooooo`01o`000000
X?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo09Cooooo0Ol00001ooooo`7o0000
002Qooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0UOooool2o`000000X_ooool2
o`0002[ooooo00?o0000ooooooooool0U?ooool3o`000000Y?ooool00ol0003oooooooooo`0Woooo
o`03o`000?oooooooooo093ooooo1?l00003ooooo`00YOooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo08gooooo0ol00007ooooo`00Y_ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo08Wooooo1?l0000:ooooo`00Yoooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo08Gooooo1?l0000>ooooo`00Z?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo08;ooooo0ol0000Booooo`00ZOooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
07kooooo1?l0000Eooooo`00Z_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo07[o
oooo1?l0000Iooooo`00Zoooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo07Gooooo
1?l0000Mooooo`00[?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo07;ooooo0ol0
000Qooooo`00[Oooool2o`00023ooooo00?o0000ooooooooool0K_ooool4o`0002Cooooo002_oooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool0J_ooool4o`0002Sooooo002`ooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool0Ioooool3o`0002cooooo002aooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool0Hoooool4o`0002oooooo002booooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool0Goooool4o`0003?ooooo002cooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool0G?ooool3o`0003Oooooo002dooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool0F?ooool4o`0003[ooooo002eooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool0E?ooool4o`0003kooooo002fooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool0D?ooool4o`0004;ooooo002gooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool0COooool3o`0004Kooooo002hooooo`;o00005Oooool00ol0003oooooooooo`19
ooooo`Co0000BOooool00;[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`15oooo
o`Co0000COooool00;_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`12ooooo`?o
0000DOooool00;cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0nooooo`Co0000
E?ooool00;gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0jooooo`Co0000F?oo
ool00;kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0fooooo`Co0000G?ooool0
0;oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0cooooo`?o0000H?ooool00<3o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0_ooooo`Co0000Hoooool00<7ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0[ooooo`Co0000Ioooool00<;ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0Xooooo`?o0000Joooool00<?ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0Tooooo`Co0000K_ooool00<Cooooo0_l00009oooo
o`03o`000?oooooooooo023ooooo1?l0001booooo`00a_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo01gooooo0ol0001fooooo`00aoooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo01Wooooo1?l0001iooooo`00b?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo01Gooooo1?l0001mooooo`00bOooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo017ooooo1?l00021ooooo`00b_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00kooooo0ol00025ooooo`00boooool01Ol0003ooooooooooooooooo000000cooooo1?l00028oooo
o`00c?ooool01?l0003oooooooooool00008ooooo`Co0000S?ooool00<gooooo00?o0000ooooool0
00001Oooool3o`00093ooooo003>ooooo`;o000000?oooooo`000?l000000_l0002Cooooo`00cooo
ool2o`0009Oooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {330.375, 0}} -> {-0.0771432, -0.0315529, \
0.00350368, 0.00350368}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .92059 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-16 1.0763 -0.0263982 1.0763 [
[.01694 .18568 -11.9631 -9 ]
[.01694 .18568 .03693 0 ]
[.13793 .13897 -11.619 -9 ]
[.13793 .13897 .38095 0 ]
[.26292 .09073 -5.63752 -9 ]
[.26292 .09073 .36248 0 ]
[.39212 .04087 -5.46552 -9 ]
[.39212 .04087 .53448 0 ]
[.52574 -0.01069 -5.29351 -9 ]
[.52574 -0.01069 .70649 0 ]
[.58272 .04263 0 -6.19654 ]
[.58272 .04263 6 2.80346 ]
[.71715 .21863 0 -6.07114 ]
[.71715 .21863 6 2.92886 ]
[.83675 .37523 0 -5.963 ]
[.83675 .37523 6 3.037 ]
[.94385 .51546 0 -5.8688 ]
[.94385 .51546 6 3.1312 ]
[.01386 .20006 -12 -2.76892 ]
[.01386 .20006 0 6.23108 ]
[.00748 .25499 -24 -2.80073 ]
[.00748 .25499 0 6.19927 ]
[.00093 .31131 -6 -2.83339 ]
[.00093 .31131 0 6.16661 ]
[-0.00579 .36907 -18 -2.86695 ]
[-0.00579 .36907 0 6.13305 ]
[-0.01268 .42831 -6 -2.90143 ]
[-0.01268 .42831 0 6.09857 ]
[ 0 0 0 0 ]
[ 1 .92059 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02642 .19522 m
.53391 0 L
s
.02642 .19522 m
.03116 .2 L
s
[(-2)] .01694 .18568 .99384 1 Mshowa
.14712 .14879 m
.15172 .1537 L
s
[(-1)] .13793 .13897 .93651 1 Mshowa
.2718 .10083 m
.27624 .10588 L
s
[(0)] .26292 .09073 .87917 1 Mshowa
.40066 .05126 m
.40493 .05646 L
s
[(1)] .39212 .04087 .82184 1 Mshowa
.53391 0 m
.538 .00534 L
s
[(2)] .52574 -0.01069 .7645 1 Mshowa
.125 Mabswid
.05025 .18606 m
.05308 .18894 L
s
.07424 .17683 m
.07705 .17973 L
s
.09837 .16755 m
.10117 .17046 L
s
.12267 .1582 m
.12545 .16113 L
s
.17173 .13933 m
.17447 .14229 L
s
.19651 .1298 m
.19923 .13278 L
s
.22144 .1202 m
.22414 .1232 L
s
.24654 .11055 m
.24922 .11356 L
s
.29723 .09105 m
.29988 .0941 L
s
.32283 .0812 m
.32546 .08427 L
s
.3486 .07129 m
.35121 .07437 L
s
.37455 .06131 m
.37713 .06441 L
s
.42695 .04115 m
.4295 .04428 L
s
.45342 .03096 m
.45594 .03412 L
s
.48007 .02071 m
.48257 .02388 L
s
.5069 .01039 m
.50938 .01358 L
s
.25 Mabswid
.53391 0 m
.9804 .58403 L
s
.57014 .04738 m
.56384 .04975 L
s
[(0)] .58272 .04263 -1 .37701 Mshowa
.70445 .22307 m
.6981 .22529 L
s
[(2)] .71715 .21863 -1 .34914 Mshowa
.82396 .37939 m
.81756 .38147 L
s
[(4)] .83675 .37523 -1 .32511 Mshowa
.93098 .51938 m
.92454 .52134 L
s
[(6)] .94385 .51546 -1 .30418 Mshowa
.125 Mabswid
.60525 .09331 m
.60147 .09471 L
s
.63931 .13786 m
.63552 .13924 L
s
.67236 .1811 m
.66856 .18245 L
s
.73562 .26383 m
.7318 .26514 L
s
.7659 .30345 m
.76207 .30473 L
s
.79534 .34195 m
.7915 .34322 L
s
.85181 .41581 m
.84796 .41704 L
s
.87891 .45126 m
.87506 .45247 L
s
.90529 .48577 m
.90143 .48696 L
s
.95601 .55212 m
.95214 .55328 L
s
.25 Mabswid
.02642 .19522 m
0 .42381 L
s
.02642 .19522 m
.0327 .19281 L
s
[(-1)] .01386 .20006 1 -0.38468 Mshowa
.02006 .25024 m
.02635 .24786 L
s
[(-0.5)] .00748 .25499 1 -0.37762 Mshowa
.01354 .30664 m
.01985 .3043 L
s
[(0)] .00093 .31131 1 -0.37036 Mshowa
.00686 .36448 m
.01318 .36218 L
s
[(0.5)] -0.00579 .36907 1 -0.3629 Mshowa
0 .42381 m
.00634 .42156 L
s
[(1)] -0.01268 .42831 1 -0.35524 Mshowa
.125 Mabswid
.02516 .20612 m
.02893 .20468 L
s
.0239 .21707 m
.02767 .21563 L
s
.02262 .22807 m
.0264 .22664 L
s
.02135 .23913 m
.02512 .2377 L
s
.01877 .26141 m
.02255 .25999 L
s
.01747 .27263 m
.02125 .27122 L
s
.01617 .28391 m
.01995 .2825 L
s
.01486 .29525 m
.01864 .29384 L
s
.01222 .31809 m
.01601 .3167 L
s
.01089 .3296 m
.01468 .32821 L
s
.00955 .34117 m
.01334 .33978 L
s
.00821 .35279 m
.012 .35141 L
s
.0055 .37622 m
.0093 .37485 L
s
.00414 .38803 m
.00793 .38666 L
s
.00276 .39989 m
.00656 .39853 L
s
.00139 .41182 m
.00519 .41047 L
s
.25 Mabswid
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.54154 .92059 L
s
.54154 .92059 m
.5414 .7134 L
s
.5414 .7134 m
.02642 .19522 L
s
.53391 0 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.53391 0 m
.02642 .19522 L
s
.5414 .7134 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.54154 .92059 L
s
.54154 .92059 m
.5414 .7134 L
s
0 0 m
1 0 L
1 .92059 L
0 .92059 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.25173 .5669 m
.27565 .55814 L
s
1 0 .6 r
.23785 .52984 m
.26193 .52153 L
s
.8 0 1 r
.22401 .49227 m
.24817 .48407 L
s
.2 0 1 r
.21012 .45441 m
.23429 .44615 L
s
0 .4 1 r
.19618 .41642 m
.22033 .40804 L
s
1 0 0 r
.27565 .55814 m
.29938 .54902 L
s
1 0 .6 r
.26193 .52153 m
.28604 .51302 L
s
0 1 1 r
.18221 .37835 m
.20634 .36983 L
s
.8 0 1 r
.24817 .48407 m
.27245 .47578 L
s
0 1 .4 r
.16821 .34019 m
.19232 .33155 L
s
.2 0 1 r
.23429 .44615 m
.2586 .43782 L
s
.2 1 0 r
.15418 .30197 m
.17827 .2932 L
s
0 .4 1 r
.22033 .40804 m
.24463 .3996 L
s
1 0 0 r
.29938 .54902 m
.32287 .53967 L
s
1 0 .6 r
.28604 .51302 m
.31016 .50435 L
s
.8 1 0 r
.14012 .26367 m
.16419 .25477 L
s
0 1 1 r
.20634 .36983 m
.23062 .36127 L
s
.8 0 1 r
.27245 .47578 m
.29684 .4674 L
s
1 .6 0 r
.12604 .22529 m
.15009 .21626 L
s
0 1 .4 r
.19232 .33155 m
.21658 .32286 L
s
.2 0 1 r
.2586 .43782 m
.28306 .42944 L
s
.2 1 0 r
.17827 .2932 m
.20251 .28437 L
s
0 .4 1 r
.24463 .3996 m
.26909 .39111 L
s
.8 1 0 r
.16419 .25477 m
.18841 .24581 L
s
1 0 .6 r
.31016 .50435 m
.33429 .49558 L
s
0 1 1 r
.23062 .36127 m
.25506 .35265 L
s
1 0 0 r
.32287 .53967 m
.34622 .53031 L
s
.8 0 1 r
.29684 .4674 m
.32135 .45894 L
s
1 .6 0 r
.15009 .21626 m
.17429 .20717 L
s
0 1 .4 r
.21658 .32286 m
.241 .31411 L
s
.2 0 1 r
.28306 .42944 m
.30768 .421 L
s
.2 1 0 r
.20251 .28437 m
.22691 .27549 L
s
0 .4 1 r
.26909 .39111 m
.29371 .38256 L
s
.8 1 0 r
.18841 .24581 m
.21279 .23679 L
s
0 1 1 r
.25506 .35265 m
.27966 .34397 L
s
1 0 .6 r
.33429 .49558 m
.35851 .48682 L
s
.8 0 1 r
.32135 .45894 m
.346 .45044 L
s
1 0 0 r
.34622 .53031 m
.36963 .52113 L
s
1 .6 0 r
.17429 .20717 m
.19864 .19802 L
s
0 1 .4 r
.241 .31411 m
.26557 .3053 L
s
.2 0 1 r
.30768 .421 m
.33245 .41251 L
s
.2 1 0 r
.22691 .27549 m
.25146 .26655 L
s
0 .4 1 r
.29371 .38256 m
.31848 .37396 L
s
.8 1 0 r
.21279 .23679 m
.23732 .22772 L
s
0 1 1 r
.27966 .34397 m
.30441 .33524 L
s
1 0 .6 r
.35851 .48682 m
.38291 .47817 L
s
.8 0 1 r
.346 .45044 m
.37081 .44192 L
s
1 .6 0 r
.19864 .19802 m
.22316 .18882 L
s
0 1 .4 r
.26557 .3053 m
.29031 .29644 L
s
1 0 0 r
.36963 .52113 m
.39331 .51227 L
s
.2 0 1 r
.33245 .41251 m
.35737 .40396 L
s
.2 1 0 r
.25146 .26655 m
.27618 .25755 L
s
0 .4 1 r
.31848 .37396 m
.34341 .36531 L
s
.8 1 0 r
.23732 .22772 m
.26202 .21859 L
s
0 1 1 r
.30441 .33524 m
.32933 .32645 L
s
1 0 .6 r
.38291 .47817 m
.4076 .46968 L
s
.8 0 1 r
.37081 .44192 m
.39581 .43341 L
s
1 .6 0 r
.22316 .18882 m
.24783 .17955 L
s
0 1 .4 r
.29031 .29644 m
.3152 .28751 L
s
.2 0 1 r
.35737 .40396 m
.38247 .39537 L
s
1 0 0 r
.39331 .51227 m
.41745 .50379 L
s
.2 1 0 r
.27618 .25755 m
.30105 .24849 L
s
0 .4 1 r
.34341 .36531 m
.36851 .35659 L
s
.8 1 0 r
.26202 .21859 m
.28687 .2094 L
s
0 1 1 r
.32933 .32645 m
.3544 .31761 L
s
1 0 .6 r
.4076 .46968 m
.43266 .46139 L
s
.8 0 1 r
.39581 .43341 m
.42105 .42493 L
s
1 .6 0 r
.24783 .17955 m
.27266 .17022 L
s
0 1 .4 r
.3152 .28751 m
.34026 .27853 L
s
.2 0 1 r
.38247 .39537 m
.40774 .38675 L
s
1 0 0 r
.41745 .50379 m
.44214 .49574 L
s
.2 1 0 r
.30105 .24849 m
.32608 .23938 L
s
0 .4 1 r
.36851 .35659 m
.39377 .34783 L
s
.8 1 0 r
.28687 .2094 m
.31188 .20015 L
s
0 1 1 r
.3544 .31761 m
.37964 .30871 L
s
1 0 .6 r
.43266 .46139 m
.45813 .45329 L
s
.8 0 1 r
.42105 .42493 m
.44653 .41648 L
s
1 .6 0 r
.27266 .17022 m
.29765 .16084 L
s
0 1 .4 r
.34026 .27853 m
.36547 .2695 L
s
.2 0 1 r
.40774 .38675 m
.43319 .37807 L
s
1 0 0 r
.44214 .49574 m
.46746 .48809 L
s
.2 1 0 r
.32608 .23938 m
.35128 .23021 L
s
0 .4 1 r
.39377 .34783 m
.41919 .33901 L
s
.8 1 0 r
.31188 .20015 m
.33706 .19084 L
s
0 1 1 r
.37964 .30871 m
.40504 .29975 L
s
1 0 .6 r
.45813 .45329 m
.48402 .44531 L
s
.8 0 1 r
.44653 .41648 m
.47225 .40802 L
s
1 .6 0 r
.29765 .16084 m
.3228 .15139 L
s
0 1 .4 r
.36547 .2695 m
.39086 .2604 L
s
1 0 0 r
.46746 .48809 m
.49345 .48078 L
s
.2 0 1 r
.43319 .37807 m
.45882 .36936 L
s
.2 1 0 r
.35128 .23021 m
.37664 .22097 L
s
0 .4 1 r
.41919 .33901 m
.44478 .33013 L
s
.8 1 0 r
.33706 .19084 m
.3624 .18146 L
s
0 1 1 r
.40504 .29975 m
.43061 .29073 L
s
1 0 .6 r
.48402 .44531 m
.51029 .43738 L
s
.8 0 1 r
.47225 .40802 m
.4982 .39953 L
s
1 0 0 r
.49345 .48078 m
.52009 .47368 L
s
1 .6 0 r
.3228 .15139 m
.34812 .14188 L
s
0 1 .4 r
.39086 .2604 m
.41641 .25124 L
s
.2 0 1 r
.45882 .36936 m
.48462 .36058 L
s
.2 1 0 r
.37664 .22097 m
.40217 .21168 L
s
0 .4 1 r
.44478 .33013 m
.47054 .32119 L
s
.8 1 0 r
.3624 .18146 m
.3879 .17203 L
s
0 1 1 r
.43061 .29073 m
.45635 .28165 L
s
1 0 .6 r
.51029 .43738 m
.53688 .4294 L
s
1 0 0 r
.52009 .47368 m
.54732 .46662 L
s
.8 0 1 r
.4982 .39953 m
.52434 .39098 L
s
1 .6 0 r
.34812 .14188 m
.37361 .1323 L
s
0 1 .4 r
.41641 .25124 m
.44212 .24203 L
s
.2 0 1 r
.48462 .36058 m
.5106 .35175 L
s
.2 1 0 r
.40217 .21168 m
.42786 .20232 L
s
0 .4 1 r
.47054 .32119 m
.49647 .3122 L
s
1 0 0 r
.54732 .46662 m
.57496 .45939 L
s
.8 1 0 r
.3879 .17203 m
.41358 .16254 L
s
1 0 .6 r
.53688 .4294 m
.56366 .42128 L
s
0 1 1 r
.45635 .28165 m
.48226 .27252 L
s
.8 0 1 r
.52434 .39098 m
.55064 .38234 L
s
1 .6 0 r
.37361 .1323 m
.39926 .12267 L
s
0 1 .4 r
.44212 .24203 m
.46801 .23275 L
s
.2 0 1 r
.5106 .35175 m
.53674 .34286 L
s
.2 1 0 r
.42786 .20232 m
.45373 .1929 L
s
0 .4 1 r
.49647 .3122 m
.52257 .30314 L
s
1 0 0 r
.57496 .45939 m
.60275 .45182 L
s
1 0 .6 r
.56366 .42128 m
.59054 .41296 L
s
.8 1 0 r
.41358 .16254 m
.43942 .15298 L
s
0 1 1 r
.48226 .27252 m
.50833 .26332 L
s
.8 0 1 r
.55064 .38234 m
.57708 .3736 L
s
1 .6 0 r
.39926 .12267 m
.42509 .11297 L
s
0 1 .4 r
.46801 .23275 m
.49406 .22341 L
s
.2 0 1 r
.53674 .34286 m
.56305 .33389 L
s
1 0 0 r
.60275 .45182 m
.63046 .44384 L
s
.2 1 0 r
.45373 .1929 m
.47977 .18342 L
s
0 .4 1 r
.52257 .30314 m
.54884 .29403 L
s
1 0 .6 r
.59054 .41296 m
.61744 .40445 L
s
.8 1 0 r
.43942 .15298 m
.46544 .14336 L
s
0 1 1 r
.50833 .26332 m
.53458 .25406 L
s
.8 0 1 r
.57708 .3736 m
.60366 .36476 L
s
1 .6 0 r
.42509 .11297 m
.45108 .1032 L
s
0 1 .4 r
.49406 .22341 m
.52029 .21401 L
s
.2 0 1 r
.56305 .33389 m
.58953 .32487 L
s
.2 1 0 r
.47977 .18342 m
.50597 .17388 L
s
0 .4 1 r
.54884 .29403 m
.57529 .28485 L
s
.8 1 0 r
.46544 .14336 m
.49163 .13367 L
s
0 1 1 r
.53458 .25406 m
.56101 .24474 L
s
1 .6 0 r
.45108 .1032 m
.47725 .09338 L
s
0 1 .4 r
.52029 .21401 m
.5467 .20455 L
s
.2 1 0 r
.50597 .17388 m
.53236 .16428 L
s
.8 1 0 r
.49163 .13367 m
.51799 .12392 L
s
1 .6 0 r
.47725 .09338 m
.50359 .08348 L
s
0 g
.25 Mabswid
.53391 0 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.53391 0 m
.02642 .19522 L
s
.02642 .19522 m
.53391 0 L
s
.02642 .19522 m
.03116 .2 L
s
[(-2)] .01694 .18568 .99384 1 Mshowa
.14712 .14879 m
.15172 .1537 L
s
[(-1)] .13793 .13897 .93651 1 Mshowa
.2718 .10083 m
.27624 .10588 L
s
[(0)] .26292 .09073 .87917 1 Mshowa
.40066 .05126 m
.40493 .05646 L
s
[(1)] .39212 .04087 .82184 1 Mshowa
.53391 0 m
.538 .00534 L
s
[(2)] .52574 -0.01069 .7645 1 Mshowa
.125 Mabswid
.05025 .18606 m
.05308 .18894 L
s
.07424 .17683 m
.07705 .17973 L
s
.09837 .16755 m
.10117 .17046 L
s
.12267 .1582 m
.12545 .16113 L
s
.17173 .13933 m
.17447 .14229 L
s
.19651 .1298 m
.19923 .13278 L
s
.22144 .1202 m
.22414 .1232 L
s
.24654 .11055 m
.24922 .11356 L
s
.29723 .09105 m
.29988 .0941 L
s
.32283 .0812 m
.32546 .08427 L
s
.3486 .07129 m
.35121 .07437 L
s
.37455 .06131 m
.37713 .06441 L
s
.42695 .04115 m
.4295 .04428 L
s
.45342 .03096 m
.45594 .03412 L
s
.48007 .02071 m
.48257 .02388 L
s
.5069 .01039 m
.50938 .01358 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 265.125},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001Bb000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00`oooool5o`000:3ooooo0033ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@0X?ooool00<Cooooo00?oV9RHob4Q8Oo^k^h0XOooool00<Gooooo00?oV9RH
ob4Q8Oo^k^h0X?ooool00<Kooooo00?oMgMgofIVI_ooool0Woooool00<Oooooo00?o0000oooooooo
ool0W_ooool00<?ooooo00Go0000okZj^_ooooooV9RHoa0@402Pooooo`00`oooool01OnHV9So410@
o`000?lQ8B7oc<c<0:3ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003;ooooo`;o0000Voooool00<Sooooo0ol000000ooooooo0000ooooo`2Jooooo`00a_oo
ool2o`0000Cooooo0_l0002Jooooo`00`oooool3o`0000Kooooo00?o0000ooooool00000VOooool0
0<3ooooo1?l00008ooooo`04o`000?ooooooooooo`0009Sooooo002Hooooo`Co000000?o410@oooo
ooooool07oooool2o`0000Cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0002H
ooooo`00V_ooool00ol0003oooooooooo`0Nooooo`?o00003_ooool01Ol0003ooooooooooooooooo
000009Oooooo002Jooooo`03o`000?oooooooooo01cooooo0_l0000Aooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0U?ooool009[ooooo00?o0000ooooooooool06Oooool3o`0000;o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo09?o
oooo002Jooooo`03o`000?oooooooooo01Kooooo0ol0000Fooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^08Kooooo002Jooooo`03o`00
0?oooooooooo01Cooooo0_l0000Iooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1oooool01OmgMgOoV9RHoooooonHV9SoMgMg08Kooooo002Jooooo`03o`000?oooooooooo017ooooo
0ol000000ooooooo0000ooooo`0Hooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1_ooool01Ol@413ooooooooooooooooo410@08Kooooo002Hooooo`03oeEEEOmVIVKo0000017ooooo
0_l0000Nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool01Ol0003ooooo
oooooooooooo000008Kooooo002Yooooo`?o00008?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000026ooooo`00Yoooool3o`0002;ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@
4100Q_ooool00:Cooooo0ol00002ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Q_ooool00:7ooooo
0ol0000Xooooo`03o`000?oooooooooo00Sooooo0_l00004ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h0Q_ooool009oooooo0_l0000[ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo
0000S_ooool009cooooo0ol000000ooooooo0000ooooo`0Zooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0S?ooool009[ooooo0_l00005ooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`2;ooooo`00Uoooool3o`0003;ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`2:ooooo`00K?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^02?ooooo0ol000000ooooooo0000ooooo`0booooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0ROooool006cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Qooooo`;o0000>?ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo08Wooooo001/ooooo`05oa0@4?oooooooooo
ooooool@41007_ooool3o`0003[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`28
ooooo`00K?ooool01Ol0003ooooooooooooooooo000001cooooo0ol0000looooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0Qoooool006cooooo00Go0000ooooooooooooooooo`00000I
ooooo`?o00000_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool0Q_ooool006cooooo00Go410@oooooooooooooooooa0@400Gooooo`;o0000@_ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo08Kooooo001/ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL05?ooool3o`0004Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`25
ooooo`00K?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^017ooooo0ol00002ooooo`03o`000?oooooo
oooo03Oooooo0_ooV@09ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0Q?ooool0
083ooooo0_l0000looooo`?ooiT02oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
08?ooooo001mooooo`?o0000>oooool3oonI00kooooo00?o0000ooooooooool05?ooool00ol0003o
ooooooooo`22ooooo`00Noooool2o`000003ooooool0003ooooo03Sooooo0oooV@0Aooooo`03o`00
0?oooooooooo01Cooooo0_l00023ooooo`00N?ooool3o`0003[ooooo0oooV@0Dooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooool00000Poooool007Gooooo0ol0000jooooo`?ooiT05oooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo083ooooo001cooooo`Co0000>Oooool2oonI
01[ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1oooooo`00L?ooool3o`0000Co
oooo00?o0000ooooooooool0=?ooool2oonI01cooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`1oooooo`00K_ooool2o`0003_ooooo0oooV@0Nooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool0O_ooool004?ooooo1?l000000ol@413oooooooooo`0Qooooo`?o0000>ooo
ool2oonI027ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1mooooo`00AOooool0
0ol0003oooooooooo`0Pooooo`?o00000oooool00ol0003oooooooooo`0fooooo`;ooiT08oooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo07cooooo000jooooo`Ko00001Oooool00ol0
003oooooooooo`0Nooooo`;o0000??ooool3oonI02Gooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`1looooo`00AOooool00ol0003oooooooooo`0Kooooo`?o0000>oooool3oonI02So
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1kooooo`00AOooool00ol0003ooooo
ooooo`0Iooooo`;o00000_ooool00ol0003oooooooooo`0fooooo`?ooiT09Oooool2olco00Cooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`1jooooo`00AOooool00ol0003ooooooooo
o`0Fooooo`?o0000>_ooool3oonI02Gooooo0oo<o`06ooooo`03o`000?oooooooooo01gooooo00?o
0000ooooooooool0NOooool004Gooooo00?o0000ooooooooool05?ooool2o`0003[ooooo0oooV@0U
ooooo`?oc?l02Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo07Wooooo0013oooo
o`03oeEEEOmVIVKo000001?ooooo0ol000000ooooooo0000ooooo`0gooooo`;ooiT09Oooool3olco
00cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`1hooooo`00E_ooool3o`0003[o
oooo0oooV@0Uooooo`;oc?l03oooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo07Oo
oooo001Dooooo`;o0000>_ooool3oonI02Gooooo0oo<o`0Aooooo`03o`000?oooooooooo01oooooo
0_l0001hooooo`00DOooool3o`000003ooooool0003ooooo03Kooooo0oooV@0Vooooo`;oc?l05?oo
ool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo07Kooooo001?ooooo`;o0000>Oooool3
oonI02Oooooo0_o<o`0Fooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0MOooool0
04cooooo0ol0000hooooo`?ooiT09oooool3olco01Sooooo00?o0000ooooooooool08_ooool00ol0
003oooooooooo`1dooooo`00BOooool4o`0003Sooooo0_ooV@0Wooooo`?oc?l06oooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo07?ooooo0017ooooo`;o00001?ooool00ol0003ooooo
ooooo`0booooo`?ooiT09oooool2olco01kooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`1booooo`00A?ooool3o`0003Sooooo0oooV@0Wooooo`?oc?l08?ooool00ol0003ooooooooo
o`0Tooooo`03o`000?oooooooooo07;ooooo000Jooooo`Go00008oooool3o`0003Sooooo0_ooV@0W
ooooo`?oc?l08oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo077ooooo000Joooo
o`05oiRHV?lQ8B7ok^k^oooooom4A4@08?ooool3o`0000?ooooo00?o0000ooooooooool0<oooool2
oonI02Kooooo0oo<o`0Vooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0L?ooool0
01;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^01oooooo0_l0000iooooo`?ooiT09Oooool3olco
02Oooooo0_lco`000ol0003oooooooooo`0Wooooo`03o`000?oooooooooo06oooooo000Looooo`03
oiRHV?lQ8B7ok^k^01_ooooo0ol0000iooooo`;ooiT09Oooool3olco02Oooooo0olco`02ooooo`03
o`000?oooooooooo02Oooooo00?o0000ooooooooool0Koooool001gooooo00?oMgMgofIVI_ooool0
5oooool3o`0000?ooooo00?o0000ooooooooool0=?ooool2oonI02Gooooo0_o<o`0Wooooo`?o<ol0
1Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo06kooooo000Nooooo`03o`000?oo
oooooooo01Cooooo0_l0000jooooo`?ooiT09?ooool3olco02Oooooo0_lco`08ooooo`03o`000?oo
oooooooo02Wooooo00?o0000ooooooooool0KOooool001[ooooo00Go0000okZj^_ooooooV9RHoa0@
400Cooooo`?o0000>Oooool3oonI02Cooooo0oo<o`0Wooooo`?o<ol02_ooool00ol0003ooooooooo
o`0Zooooo`03o`000?oooooooooo06cooooo000Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`04Ooo
ool2o`0000?ooooo00?o0000ooooooooool0=?ooool2oonI02Cooooo0oo<o`0Wooooo`?o<ol03Ooo
ool00ol0003oooooooooo`0Zooooo`;o0000KOooool002gooooo0ol0000iooooo`?ooiT08oooool3
olco02Oooooo0olco`0@ooooo`03o`000?oooooooooo02[ooooo0_l0001]ooooo`00:_ooool3o`00
03Wooooo0oooV@0Sooooo`?oc?l09oooool3oc?o01?ooooo00?o0000ooooooooool0;?ooool00ol0
003oooooooooo`1Zooooo`00:?ooool2o`0000?ooooo00?o0000ooooooooool0=?ooool2oonI02Co
oooo0_o<o`0Wooooo`?o<ol05_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo06Wo
oooo000Uooooo`?o0000>Oooool3oonI02?ooooo0oo<o`0Vooooo`?o<ol06Oooool00ol0003ooooo
ooooo`0]ooooo`03o`000?oooooooooo06Wooooo000Tooooo`03o`000?oooooooooo03Oooooo0ooo
V@0Sooooo`?oc?l09_ooool3oc?o01cooooo00?o0000ooooooooool0;_ooool00ol0003ooooooooo
o`1Xooooo`006_ooool4o`000003oa0@4?oooooooooo00?ooooo0_l0000fooooo`;ooiT08oooool3
olco02Kooooo0olco`0Oooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0Ioooool0
01cooooo00?o0000ooooooooool01Oooool2o`0003?ooooo0oooV@0Sooooo`;oc?l09oooool2oc?o
02;ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`1Vooooo`004Oooool6o`0000Go
oooo00?o0000ooooooooool01?ooool4o`0002oooooo0oooV@0Tooooo`;oc?l09_ooool3oc?o02Co
oooo00?o0000ooooooooool00_l0ofH^ooooo`03o`000?oooooooooo00Sooooo1Ol0001Iooooo`00
7?ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0002cooooo0_ooV@0Uooooo`;o
c?l09Oooool3oc?o02Oooooo00?o0000o`3oI_l0ofH0<Oooool00ol0003oooooooooo`07ooooo`05
oiRHV?lQ8B7ok^k^oooooom4A4@0FOooool001cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo02Kooooo0oooV@0Uooooo`;oc?l09?ooool3oc?o02Oo
oooo0ol0ofH00ol0003oooooooooo`0booooo`03o`000?oooooooooo00Oooooo00?oV9RHob4Q8Oo^
k^h0F_ooool001cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo02;ooooo0oooV@0Uooooo`?oc?l08oooool3oc?o02Oooooo0ol0ofH3ooooo`03o`00
0?oooooooooo03?ooooo00?o0000ooooooooool01oooool00onHV9So8B4Qonk^kP1Iooooo`007?oo
ool00ol0003oooooooooo`04ooooo`;o00001Oooool00ol0003oooooooooo`0Oooooo`;ooiT09Ooo
ool3olco02?ooooo0olco`0Wooooo`?o0?mV1_ooool00ol0003oooooooooo`0dooooo`03o`000?oo
oooooooo00Oooooo00?oMgMgofIVI_ooool0F?ooool001[ooooo00?oEEEEofIVI_l000001_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo01_ooooo0oooV@0Uooooo`;oc?l09?ooool2
oc?o02Oooooo0ol0ofH9ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`1Gooooo`008oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
01Oooooo0oooV@0Uooooo`?oc?l08oooool3oc?o02Oooooo0_l0ofH<ooooo`03o`000?oooooooooo
03Gooooo0_l00004ooooo`05o`000?nj^[[ooooooiRHV?l@4100FOooool002?ooooo0_l00008oooo
o`03o`000?oooooooooo01Gooooo00?ooiT0ooooooooool08oooool3olco02?ooooo0olco`0Woooo
o`?o0?mV3_ooool00ol0003oooooooooo`0cooooo`;o000000?oooooo`000?ooool00oooool01OnH
V9So410@o`000?lQ8B7oc<c<05Wooooo000Sooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool0>?ooool2olco02?ooooo0olco`0Wooooo`?o0?mV4Oooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo05oooooo000Sooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool0=?ooool3olco02;ooooo0olco`0Wooooo`?o0?mV5?ooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo05oooooo000Sooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0
<?ooool3olco02;ooooo0olco`0Wooooo`?o0?mV5_ooool2o`0003[ooooo00?o0000ooooooooool0
G_ooool002;ooooo0_l0000=ooooo`03o`000?oooooooooo02gooooo0_o<o`0Sooooo`;o<ol09ooo
ool3o`3oIQKooooo0ol000000ooooooo0000ooooo`0jooooo`03o`000?oooooooooo05gooooo000R
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0:Oooool3olco02;ooooo0olco`0W
ooooo`;o0?mV5_ooool3o`0000Gooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`1L
ooooo`008_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo02Gooooo0oo<o`0Roooo
o`?o<ol09oooool3o`3oIQGooooo0ol00009ooooo`03o`000?oooooooooo00?ooooo0_l0oolcoooo
o`03o`000?oooooooooo05cooooo000Rooooo`?o00003oooool00ol0003oooooooooo`0Qooooo`?o
c?l08oooool2oc?o02Oooooo0ol0ofHEooooo`?o00003Oooool00ol0003oooooo`3oo`02o`3oocKo
oooo00?o0000ooooooooool0Foooool002;ooooo00?o0000ooooooooool04?ooool00ol0003ooooo
ooooo`0Mooooo`?oc?l09?ooool2oc?o02Kooooo0ol0ofHFooooo`;o00003oooool2o`3oo`03o`00
0?oooooooooo03Sooooo00?o0000ooooooooool0F_ooool002;ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`0Iooooo`?oc?l09Oooool2oc?o02Gooooo0ol0ofHFooooo`?o00003_oo
ool3o`3oo`?ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1Iooooo`001oooool0
1Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd0
1Oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo01Kooooo0_o<o`0Vooooo`;o<ol0
9?ooool3o`3oIQKooooo0ol0000>ooooo`?o0?oo1_ooool00ol0003oooooooooo`0hooooo`03o`00
0?oooooooooo05Wooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo
00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo01;ooooo
0oo<o`0Uooooo`?o<ol09?ooool2o`3oIQKooooo0ol0000>ooooo`?o0?oo2_ooool00ol0003ooooo
ooooo`0hooooo`03o`000?oooooooooo05Sooooo0005o`0000;ooooo00Go410@oooooooooooooooo
oa0@400@ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`0>ooooo`?oc?l08oooool5oc?o02Cooooo0ol0ofHEooooo`?o00003oooool2o`3oo`kooooo
00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1Gooooo`001oooool01Ol0003ooooooooo
oooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0Fooooo`03o`00
0?oooooooooo00cooooo00?oc?l0ooooooooool08Oooool3oc?o02Kooooo0ol0ofHEooooo`?o0000
3oooool3o`3ooa7ooooo00?o0000ooooooooool0=oooool2o`0005Sooooo0007ooooo`05o`000?oo
ooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`0/ooooo`?o<ol09_ooool3o`3oIQKooooo0_l0000?ooooo`?o
0?oo5Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo05Gooooo0007ooooo`05oa0@
4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`;o00006Oooool00ol0003o
ooooooooo`0Xooooo`?o<ol09_ooool3o`3oIQKooooo0ol0000>ooooo`?o0?oo6Oooool00ol0003o
ooooooooo`0gooooo`03o`000?oooooooooo05Gooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool09Oooool2oc?o02Kooooo0ol0ofHFooooo`?o00003_ooool3o`3ooacooooo00?o0000oooooooo
ool0>?ooool00ol0003oooooooooo`1Dooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00co
oooo1?l00005ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool08Oooool3oc?o02Ko
oooo0_l0ofHFooooo`?o00003_ooool3o`3oob3ooooo00?o0000ooooooooool0>?ooool00ol0003o
ooooooooo`1Cooooo`008Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo01gooooo
0olco`0Vooooo`?o0?mV5Oooool3o`0000kooooo0ol0oolTooooo`03o`000?oooooooooo03Sooooo
00?o0000ooooooooool0D_ooool0023ooooo0ol0000Mooooo`03o`000?oooooooooo01[ooooo0_lc
o`0Vooooo`?o0?mV5_ooool2o`0000oooooo0_l0oolXooooo`03o`000?oooooooooo03Oooooo00?o
0000ooooooooool0D_ooool0027ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`0F
ooooo`?o<ol09_ooool2o`3oIQKooooo0ol0000?ooooo`;o0?oo:_ooool00ol0I_oo0000ooooo`0h
ooooo`03o`000?oooooooooo057ooooo000Pooooo`03o`000?oooooooooo01oooooo00?o0000oooo
ooooool04_ooool3oc?o02Kooooo0ol0ofHEooooo`?o00004?ooool2o`3oobWooooo0ol0I_l2oooo
o`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0D?ooool0023ooooo00?o0000oooooooo
ool08?ooool00ol0003oooooooooo`0?ooooo`;o<ol09_ooool3o`3oIQGooooo0ol0000@ooooo`?o
0?oo:?ooool3o`1Vo`Gooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1?ooooo`00
8?ooool2o`0002;ooooo00?o0000ooooooooool02oooool3oc?o02Gooooo0ol0ofHEooooo`?o0000
3_ooool5o`3oobSooooo0ol0I_l9ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0
Coooool0023ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`07ooooo`?o<ol09Ooo
ool3o`3oIQKooooo0_l0000>ooooo`?o0?oo:_ooool3o`1Vo`gooooo00?o0000ooooooooool0=ooo
ool00ol0003oooooooooo`1>ooooo`008?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo00Gooooo00?o<ol0ooooooooool08oooool3o`3oIQKooooo0ol0000=ooooo`?o0?oo:_ooool3
o`1Voa7ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`1=ooooo`008?ooool3o`00
02Cooooo00?o0000ooooooooool0:?ooool2o`3oIQKooooo0ol0000=ooooo`?o0?oo:_ooool3o`1V
oaGooooo00?o0000ooooooooool0=_ooool2o`0004kooooo000Pooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool09?ooool3o`3oIQGooooo0ol0000>ooooo`;o0?oo:_ooool3o`1VoaWo
oooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`1<ooooo`005?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Pooooo`?o
0?mV5Oooool3o`0000kooooo0ol0oolYooooo`?o06Ko7?ooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo04_ooooo000Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003o
ooooooooo`0Xooooo`03o`000?oooooooooo01gooooo0_l0ofHFooooo`;o00003_ooool3o`3oob[o
oooo0_l0I_lPooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0B_ooool001Cooooo
00Go410@oooooooooooooooooa0@4006ooooo`;o0000:_ooool00ol0003oooooooooo`0Iooooo`?o
0?mV5Oooool3o`0000gooooo0ol0oolZooooo`?o06Ko8oooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo04Wooooo000Dooooo`05o`000?ooooooooooooooool000001_ooool00ol0003o
ooooooooo`0Zooooo`03o`000?oooooooooo01Gooooo0ol0ofHEooooo`?o00003Oooool3o`3oob[o
oooo0ol0I_lWooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0BOooool001Cooooo
00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo02_ooooo00?o0000oooooooo
ool04_ooool2o`3oIQGooooo0ol0000=ooooo`?o0?oo:_ooool3o`1Vob_ooooo00?o0000oooooooo
ool0=_ooool00ol0003oooooooooo`18ooooo`005?ooool01Ol@413ooooooooooooooooo410@00Ko
oooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0>ooooo`?o0?mV5?ooool3o`0000ko
oooo0_l0oolZooooo`?o06Ko9oooool2oc<0o`Kooooo00?o0000ooooooooool0=_ooool00ol0003o
ooooooooo`17ooooo`005?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo0_l0000^ooooo`03
o`000?oooooooooo00[ooooo0ol0ofHDooooo`?o00003_ooool3o`3oobWooooo0ol0I_lWooooo`?o
<`3o2?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo04Kooooo000Dooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo00Oo
oooo0_l0ofHEooooo`;o00003_ooool3o`3oobWooooo0ol0I_lWooooo`?o<`3o3?ooool00ol0003o
ooooooooo`0gooooo`03o`000?oooooooooo04Gooooo000Oooooo`03o`000?oooooooooo02oooooo
00?o0000ooooooooool00oooool3o`3oIQCooooo0ol0000>ooooo`;o0?oo:Oooool3o`1VobSooooo
0_lc0?l@ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0AOooool001kooooo00?o
0000ooooooooool0<Oooool00ol0003oooooo`3oIP02o`3oIQCooooo0ol0000>ooooo`?o0?oo:?oo
ool3o`1VobSooooo0olc0?lCooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0A?oo
ool001kooooo0_l0000cooooo`03o`3oI_oooooooooo01;ooooo0ol0000>ooooo`?o0?oo:?ooool3
o`1VobSooooo0olc0?lGooooo`03o`000?oooooooooo03Kooooo0_l00014ooooo`007_ooool00ol0
003oooooooooo`0cooooo`03o`000?oooooooooo00kooooo0ol0000?ooooo`;o0?oo9oooool4o`1V
obSooooo0olc0?lKooooo`03o`000?oooooooooo03Cooooo00?o0000ooooool00000A?ooool001ko
oooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0;ooooo`;o00003oooool3o`3oobKo
oooo0ol0I_lYooooo`?o<`3o7_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo04;o
oooo000Nooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool01oooool3o`0000kooooo
0ol0oolVooooo`?o06Ko:Oooool3oc<0ob;ooooo00?o0000ooooooooool0=_ooool00ol0003ooooo
ooooo`11ooooo`007_ooool2o`0003Oooooo00?o0000ooooooooool00oooool3o`0000oooooo0_l0
oolVooooo`?o06Ko:Oooool3oc<0obKooooo00?o0000ooooooooool0=_ooool00ol0003ooooooooo
o`10ooooo`007_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooo000000;o00003oooool3
o`3oobGooooo0ol0I_lYooooo`?o<`3o:_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooo
oooo03oooooo000Nooooo`03o`000?oooooooooo03Kooooo0ol0000?ooooo`?o0?oo9Oooool3o`1V
obWooooo0olc0?l^ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0?oooool001ko
oooo0_l0000eooooo`;o00000oooool00ol0003oooooooooo`09ooooo`?o0?oo9Oooool3o`1Vob[o
oooo0_lc0?lbooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool02Oooool2o`000003
oa0@4?oooooooooo033ooooo000Mooooo`03o`000?oooooooooo03;ooooo0ol00006ooooo`03o`00
0?oooooooooo00Gooooo0ol0oolVooooo`;o06Ko:_ooool3oc<0obOooooo0_o<0?l;ooooo`03o`00
0?oooooooooo03Kooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0aooooo`000_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oM
gMd01Oooool00ol0003oooooooooo`0_ooooo`?o00002_ooool01?l0003oooooooooooooool3o`3o
obKooooo0ol0I_lYooooo`?o<`3o9oooool3ol`0o`kooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`05ooooo`Go0000<_ooool000;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05oooo
o`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo02cooooo0ol0000>oooo
o`03o`000?l0oooo0?oo02Kooooo0ol0I_lXooooo`Co<`3o9oooool3ol`0oa;ooooo00?o0000oooo
ooooool0=Oooool00ol0003oooooooooo`05ooooo`04odA4A?oMgMgoooooo`0003?ooooo0002oooo
o`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03ooooo`;o0000:_ooool3
o`0000oooooo0ol0ool00ol0003oooooooooo`0Sooooo`;o06Ko9oooool4oc<0obSooooo0oo<0?lF
ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool01?ooool01?oMgMgoEEEEooooool0
000cooooo`000_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`0Wooooo`;o00003oooool3o`3oo`Cooooo00?o0000ooooooooool07ooo
ool3o`1VobKooooo0olc0?lYooooo`?oc03o6_ooool00ol0003oooooooooo`0eooooo`03o`000?oo
oooooooo00Cooooo00?oMgMgolc<c?l00000<oooool000;ooooo00Go0000ooooooooooooooooo`00
000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Tooooo`?o0000
4?ooool00ol0ooooooooooooo`06ooooo`03o`000?oooooooooo01_ooooo0ol0I_lVooooo`?o<`3o
:Oooool3ol`0oakooooo00?o0000ooooooooool0=?ooool2o`0000Gooooo00?ok^k^odA4A?l00000
<oooool000;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo
00?o0000ooooooooool08Oooool3o`0001gooooo00?o0000ooooooooool05oooool3o`1VobKooooo
0olc0?lZooooo`;oc03o8Oooool00ol0003oooooooooo`0cooooo`04o`000?ooooooooooo`0000Go
oooo00?oMgMgo`000?ooool0<_ooool000;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03
o`000?oooooooooo00Oooooo0_l0000Oooooo`?o00008Oooool00ol0003oooooooooo`0Cooooo`?o
06Ko9_ooool3oc<0ob[ooooo0oo<0?lTooooo`03o`000?oooooooooo03Gooooo00?o0000oooooooo
ool0>?ooool000;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003o
ooooooooo`0Looooo`?o00009Oooool00ol0003oooooooooo`0?ooooo`?o06Ko9_ooool3oc<0ob[o
oooo0oo<0?lXooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0=oooool001cooooo
00?o0000ooooooooool06Oooool3o`0002Wooooo00?o0000ooooooooool03?ooool2o`1VobKooooo
0olc0?lZooooo`?oc03o;?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo03Kooooo
000Looooo`03o`000?oooooooooo01Oooooo0_l0000]ooooo`03o`000?oooooooooo00Sooooo0ol0
I_lVooooo`;o<`3o:_ooool3ol`0oc3ooooo00?o0000ooooooooool0=Oooool00ol0003ooooooooo
o`0eooooo`007?ooool2o`0001Gooooo0ol0000`ooooo`03o`000?oooooooooo00Cooooo0ol0I_lV
ooooo`?o<`3o:Oooool3ol`0ocCooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0e
ooooo`007?ooool00ol0003oooooooooo`0Aooooo`?o0000=?ooool00ol0003oooooooooo`03o`1V
obKooooo0olc0?lXooooo`Coc03o=oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo
03Cooooo000Looooo`03o`000?oooooooooo00kooooo0ol0000fooooo`Co06Ko9_ooool3oc<0obOo
oooo1?o<0?lYooooo`;oo`2I4Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo03?o
oooo000Looooo`03o`000?oooooooooo00_ooooo0ol0000fooooo`?o06Ko0oooool00ol0003ooooo
ooooo`0Qooooo`?o<`3o9oooool3ol`0ob[ooooo0ooo09TDooooo`03o`000?oooooooooo03Gooooo
00?o0000ooooooooool0<_ooool001cooooo0_l0000:ooooo`;o0000=_ooool3o`1Vo`Oooooo00?o
0000ooooooooool07Oooool3oc<0obOooooo0oo<0?lZooooo`?oo`2I6?ooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo03;ooooo000Kooooo`;o00002?ooool3o`0003Gooooo0ol0I_l;
ooooo`03o`000?oooooooooo01[ooooo0_lc0?lWooooo`?oc03o:_ooool3ool0VAcooooo00?o0000
ooooooooool0=?ooool00ol0003oooooooooo`0aooooo`006oooool00ol0003oooooooooo`04oooo
o`?o0000=oooool00ol0I_ooooooooooo`0=ooooo`03o`000?oooooooooo01Kooooo0olc0?lVoooo
o`?oc03o:_ooool3ool0VB3ooooo00?o0000ooooooooool0<oooool2o`0003;ooooo000Kooooo`04
o`000?ooooooooooooooo`?o0000Boooool00ol0003oooooooooo`0Booooo`?o<`3o9_ooool3ol`0
ob[ooooo0ooo09TSooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0;oooool001_o
oooo1?l0001?ooooo`03o`000?oooooooooo00kooooo0olc0?lVooooo`?oc03o:Oooool4ool0VBOo
oooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0_ooooo`006oooool2o`0005;ooooo
00?o0000ooooooooool02Oooool4oc<0obOooooo0_o<0?lWooooo`Goo`2I;?ooool00ol0003ooooo
ooooo`0dooooo`03o`000?oooooooooo02kooooo000Aooooo`Co000000?o410@ooooooooool01Ooo
ool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo00Gooooo0olc0?lXooooo`?oc03o9_oo
ool3ool0VC;ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0]ooooo`004oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo053ooooo00Co0000oooooooooooooooo0olc
0?lXooooo`?oc03o9_ooool3ool0VCKooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0/ooooo`004oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo053ooooo0olc0?lX
ooooo`?oc03o9_ooool3ool0VC[ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0/
ooooo`004oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo04gooooo0_lc0?l00ooo
oooo0000ooooo`0Uooooo`?oc03o9_ooool3ool0VCgooooo00?o0000ooooooooool0=?ooool00ol0
003oooooooooo`0[ooooo`004oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo04Wo
oooo0olc0?l4ooooo`03o`000?oooooooooo023ooooo0oo<0?lVooooo`?oo`2I@Oooool00ol0003o
ooooooooo`0dooooo`03o`000?oooooooooo02[ooooo000Cooooo`03o`000?oooooooooo00cooooo
00?o0000ooooooooool0AOooool3oc<0o`Sooooo00?o0000ooooooooool07?ooool3ol`0obKooooo
0ooo09T[ooooo`;oo`006?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02Wooooo
000Cooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0@_ooool2oc<0o`cooooo00?o
0000ooooooooool05oooool4ol`0obGooooo1?oo09T[ooooo`?oo`006oooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo02Sooooo000Aooooo`03oeEEEOmVIVKo0000013ooooo00?o0000
ooooooooool0?_ooool3oc<0o`oooooo00?o0000ooooooooool04oooool3ol`0obGooooo1?oo09T/
ooooo`?oo`007oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02Sooooo000Uoooo
o`03o`000?oooooooooo03[ooooo0olc0?lCooooo`03o`000?oooooooooo00oooooo0oo<0?lUoooo
o`?oo`2I;?ooool4ool002?ooooo00?o0000ooooooooool0<_ooool2o`0002Wooooo000Vooooo`;o
0000>Oooool00olc0?ooooooooooo`0Eooooo`03o`000?oooooooooo00_ooooo0oo<0?lUooooo`?o
o`2I:_ooool5ool002Oooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Vooooo`00
:?ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00Wooooo0_o<0?lUooooo`?oo`2I
:Oooool4ool002gooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Uooooo`00:Ooo
ool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00Gooooo0oo<0?lTooooo`?oo`2I:Ooo
ool3ool003;ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Uooooo`00:_ooool0
0ol0003oooooooooo`1>ooooo`04o`000?ooooooooooooooo`?oc03o9?ooool3ool0VBWooooo0ooo
000fooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool09?ooool002_ooooo00?o0000
ooooooooool0C_ooool3ol`0obCooooo0ooo09TXooooo`Coo`00>_ooool00ol0003oooooooooo`0c
ooooo`03o`000?oooooooooo02?ooooo000/ooooo`03o`000?oooooooooo04[ooooo0oo<0?l00ooo
oooo0000ooooo`0Rooooo`;oo`2I9_ooool5ool003oooooo00?o0000ooooooooool0<oooool00ol0
003oooooooooo`0Rooooo`00;Oooool00ol0003oooooooooo`16ooooo`?oc03o1Oooool00ol0003o
ooooooooo`0Mooooo`?oo`2I9?ooool4ool004Cooooo00?o0000ooooooooool0<oooool00ol0003o
ooooooooo`0Rooooo`00;_ooool00ol0003oooooooooo`13ooooo`;oc03o2Oooool00ol0003ooooo
ooooo`0Iooooo`?oo`2I8oooool4ool004Wooooo00?o0000ooooooooool0<oooool00ol0003ooooo
ooooo`0Qooooo`00;oooool00ol0003oooooooooo`0oooooo`?oc03o3?ooool00ol0003ooooooooo
o`0Eooooo`?oo`2I8oooool3ool004kooooo00?o0000ooooooooool0<oooool00ol0003ooooooooo
o`0Pooooo`00<?ooool00ol0003oooooooooo`0kooooo`?oc03o4?ooool00ol0003oooooooooo`0@
ooooo`Coo`2I8oooool3ool005;ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0O
ooooo`00<Oooool2o`0003Sooooo0oo<0?lDooooo`03o`000?oooooooooo00cooooo0ooo09TToooo
o`?oo`00E_ooool00ol0003oooooooooo`0booooo`;o00008?ooool003?ooooo00?o0000oooooooo
ool0<Oooool4ol`0oaSooooo00?o0000ooooooooool02?ooool3ool0VB?ooooo1?oo001Jooooo`03
o`000?oooooooooo037ooooo0_l0000Pooooo`00=?ooool00ol0003oooooooooo`0^ooooo`;oc03o
7Oooool00ol0003oooooooooo`04ooooo`?oo`2I8_ooool4ool005kooooo00?o0000ooooooooool0
<oooool00ol0003oooooooooo`0Mooooo`00=Oooool00ol0003oooooooooo`1=ooooo`04o`000?oo
ooooooooooooo`;oo`2I8_ooool3ool006?ooooo00?o0000ooooooooool0<oooool00ol0003ooooo
ooooo`0Looooo`00=_ooool00ol0003oooooooooo`1=ooooo`?oo`2I8Oooool3ool006Oooooo00?o
0000ooooooooool0<_ooool00ol0003oooooooooo`0Looooo`00=oooool00ol0003oooooooooo`19
ooooo`?oo`2I00?oooooo`000?ooool07_ooool3ool006_ooooo00?o0000ooooooooool0<_ooool0
0ol0003oooooooooo`0Kooooo`00>?ooool00ol0003oooooooooo`16ooooo`;oo`2I1Oooool00ol0
003oooooooooo`0Iooooo`?oo`00Koooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo
00Oooooo00Gok^k^oc8b<_l0003o410@olc<c00>ooooo`00>Oooool00ol0003oooooooooo`12oooo
o`?oo`2I2?ooool00ol0003oooooooooo`0Eooooo`?oo`00Loooool00ol0003oooooooooo`0boooo
o`03o`000?oooooooooo00Kooooo00GoEEEEogMgMoooooooV9RHob4Q8@0>ooooo`00>_ooool00ol0
003oooooooooo`0nooooo`?oo`2I3?ooool00ol0003oooooooooo`0Aooooo`?oo`00M_ooool00ol0
003oooooooooo`0cooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`00000>
ooooo`00>oooool00ol0003oooooooooo`0kooooo`;oo`2I4?ooool00ol0003oooooooooo`0>oooo
o`;oo`00N_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00Gooooo00Go0000oiRH
V?ooooooV9RHob4Q8@0>ooooo`00??ooool00ol0003oooooooooo`0gooooo`?oo`2I4oooool00ol0
003oooooooooo`0:ooooo`?oo`00OOooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo
00Cooooo00Go0000oeEEEOl0003o410@olc<c00>ooooo`00?Oooool2o`0003Cooooo0ooo09TGoooo
o`03o`000?oooooooooo00Oooooo0_oo0021ooooo`03o`000?oooooooooo03;ooooo0_l00004oooo
o`03oeEEEOn7QhOooooo013ooooo000oooooo`03o`000?oooooooooo02oooooo0_oo09TKooooo`03
o`000?oooooooooo00Cooooo0_oo0024ooooo`03o`000?oooooooooo02oooooo0_l000000ooooooo
0000ooooo`03ooooo`03omgMgOl@413oV9RH013ooooo0010ooooo`03o`000?oooooooooo02_ooooo
0ooo09TNooooo`03o`000?oooooooooo00?oo`00Qoooool00ol0003oooooooooo`0aooooo`03o`00
0?oooooooooo00?ooooo00Coc<c<odA4A?l0003o410@3_ooool0047ooooo00?o0000ooooooooool0
9oooool3ool0VB7ooooo0ooo002:ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0
5?ooool004;ooooo00?o0000ooooooooool09Oooool00ooo09Woooooooooo`0Pooooo`;oo`000_oo
ool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool04ooo
ool004?ooooo00?o0000ooooooooool0A?ooool3ool000Gooooo00?o0000ooooooooool0ROooool0
0ol0003oooooooooo`0booooo`03o`000?oooooooooo01;ooooo0014ooooo`03o`000?oooooooooo
043ooooo0ooo0009ooooo`03o`000?oooooooooo08Wooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`0Booooo`00AOooool00ol0003oooooooooo`0mooooo`;oo`003Oooool00ol0003o
ooooooooo`29ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool04Oooool004Kooooo
00?o0000ooooooooool0>Oooool3ool0013ooooo00?o0000ooooooooool0ROooool00ol0003ooooo
ooooo`0aooooo`03o`000?oooooooooo013ooooo0017ooooo`03o`000?oooooooooo03Gooooo0ooo
000Dooooo`03o`000?oooooooooo08Sooooo00?o0000ooooooooool0<_ooool00ol0003ooooooooo
o`0?ooooo`00B?ooool2o`0003?ooooo0_oo000Hooooo`03o`000?oooooooooo08Sooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`0?ooooo`00B_ooool00ol0003oooooooooo`0]oooo
o`?oo`006oooool00ol0003oooooooooo`28ooooo`03o`000?oooooooooo037ooooo0_l0000?oooo
o`00Boooool00ol0003oooooooooo`0Yooooo`?oo`007oooool00ol0003oooooooooo`28ooooo`03
o`000?oooooooooo033ooooo0_l0000?ooooo`00C?ooool00ol0003oooooooooo`0Vooooo`;oo`00
8oooool00ol0003oooooooooo`28ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
3?ooool004gooooo00?o0000ooooooooool08_ooool3ool002Kooooo00?o0000ooooooooool0R?oo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00_ooooo001>ooooo`03o`000?oooooo
oooo01kooooo0ooo000Zooooo`03o`000?oooooooooo08Oooooo00?o0000ooooooooool0<Oooool0
0ol0003oooooooooo`0;ooooo`00Coooool00ol0003oooooooooo`0Looooo`03ool00?oooooooooo
02cooooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo
00[ooooo001@ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0Qoooool00ol0003o
ooooooooo`0aooooo`03o`000?oooooooooo00Wooooo001Aooooo`03o`000?oooooooooo04_ooooo
00?o0000ooooooooool0Qoooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Sooooo
001Booooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0Qoooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo00Sooooo001Cooooo`;o0000C?ooool00ol0003oooooooooo`27
ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool01oooool005Gooooo00?o0000oooo
ooooool0B_ooool00ol0003oooooooooo`26ooooo`03o`000?oooooooooo037ooooo00?o0000oooo
ooooool01_ooool005Kooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`26ooooo`03
o`000?oooooooooo02oooooo0ol00007ooooo`00Eoooool00ol0003oooooooooo`1:ooooo`03o`00
0?oooooooooo08Kooooo00?o0000ooooooooool0:oooool3o`0000;ooooo00?o0000ooooooooool0
1Oooool005Sooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`26ooooo`03o`000?oo
oooooooo02Oooooo0ol00005ooooo`03o`000?oooooooooo00Gooooo001Iooooo`03o`000?oooooo
oooo04[ooooo00?o0000ooooooooool0Q_ooool00ol0003oooooooooo`0Rooooo`Co00002?ooool0
0ol0003oooooooooo`05ooooo`00F_ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo
08Kooooo00?o0000ooooooooool07_ooool3o`0000cooooo00?o0000ooooooooool01Oooool005_o
oooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo01[o
oooo1?l0000?ooooo`03o`000?oooooooooo00Gooooo001Looooo`03o`000?oooooooooo04[ooooo
00?o0000ooooooooool0QOooool00ol0003oooooooooo`0Fooooo`?o00005?ooool00ol0003ooooo
ooooo`04ooooo`00GOooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo08Gooooo00?o
0000ooooooooool04_ooool3o`0001Oooooo00?o0000ooooooooool01?ooool005kooooo0_l0001;
ooooo`03o`000?oooooooooo08Gooooo00?o0000ooooooooool03Oooool4o`0001[ooooo00?o0000
ooooooooool01?ooool0063ooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`25oooo
o`03o`000?oooooooooo00Wooooo0ol0000Nooooo`03o`000?oooooooooo00Cooooo001Qooooo`03
o`000?oooooooooo04Wooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`04ooooo`Co
00008Oooool00ol0003oooooooooo`04ooooo`00H_ooool00ol0003oooooooooo`19ooooo`03o`00
0?oooooooooo08Cooooo00Co0000oooooooooooooooo0ol0000Uooooo`03o`000?oooooooooo00Co
oooo001Sooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0Q?ooool3o`0002Sooooo
00?o0000ooooooooool01?ooool006Cooooo00?o0000ooooooooool0BOooool00ol0003ooooooooo
o`1oooooo`Co000000?oooooo`000?ooool0:?ooool00ol0003oooooooooo`04ooooo`00IOooool0
0ol0003oooooooooo`19ooooo`03o`000?oooooooooo07_ooooo0ol00006ooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool01?ooool006Kooooo00?o0000ooooooooool0BOooool00ol0
003oooooooooo`1fooooo`Co00002_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
00Cooooo001Wooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0L_ooool3o`0000oo
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`03ooooo`00J?ooool00ol0003ooooo
ooooo`19ooooo`03o`000?oooooooooo06kooooo0ol0000Booooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool00oooool006Wooooo00?o0000ooooooooool0BOooool00ol0003ooooooooo
o`1Yooooo`Co00005_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00?ooooo001Z
ooooo`;o0000B_ooool00ol0003oooooooooo`1Uooooo`?o00006oooool00ol0003oooooooooo`0S
ooooo`03o`000?oooooooooo00?ooooo001/ooooo`03o`000?oooooooooo04Sooooo00?o0000oooo
ooooool0H?ooool4o`0001oooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`03oooo
o`00KOooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo05cooooo0ol0000Tooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool00oooool006kooooo00?o0000ooooooooool0
B?ooool00ol0003oooooooooo`1Hooooo`?o0000:?ooool00ol0003oooooooooo`0Pooooo`03o`00
0?oooooooooo00?ooooo001_ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0Dooo
ool4o`0002_ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`03ooooo`00L?ooool0
0ol0003oooooooooo`18ooooo`03o`000?oooooooooo04oooooo0ol0000`ooooo`03o`000?oooooo
oooo01oooooo00?o0000ooooooooool00oooool0077ooooo00?o0000ooooooooool0B?ooool00ol0
003oooooooooo`1:ooooo`Co0000=?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
00?ooooo001booooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0A_ooool3o`0003Wo
oooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`02ooooo`00Loooool00ol0003ooooo
ooooo`18ooooo`03o`000?oooooooooo04;ooooo0ol0000mooooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool00_ooool007Cooooo00?o0000ooooooooool0B?ooool00ol0003ooooooooo
o`0mooooo`Co0000@Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00;ooooo001e
ooooo`;o0000BOooool00ol0003oooooooooo`0iooooo`?o0000AOooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo00;ooooo001gooooo`03o`000?oooooooooo04Oooooo00?o0000oooo
ooooool0=?ooool4o`0004Wooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`02oooo
o`00N?ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo033ooooo0ol0001>ooooo`03
o`000?oooooooooo01[ooooo00?o0000ooooooooool00_ooool007Wooooo00?o0000ooooooooool0
Aoooool00ol0003oooooooooo`0/ooooo`?o0000D_ooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo00;ooooo001jooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool09ooo
ool4o`0005Kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`02ooooo`00Noooool0
0ol0003oooooooooo`17ooooo`03o`000?oooooooooo02?ooooo0ol0001Kooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool00_ooool007cooooo00?o0000ooooooooool0Aoooool00ol0
003oooooooooo`0Nooooo`Co0000G_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
00;ooooo001mooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool06_ooool3o`0006?o
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`01ooooo`00O_ooool00ol0003ooooo
ooooo`17ooooo`03o`000?oooooooooo01Kooooo0ol0001Wooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool00Oooool007oooooo00?o0000ooooooooool0Aoooool00ol0003ooooooooo
o`0Aooooo`Co0000Joooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo007ooooo0020
ooooo`;o0000B?ooool00ol0003oooooooooo`0=ooooo`?o0000L?ooool00ol0003oooooooooo`0D
ooooo`03o`000?oooooooooo007ooooo0022ooooo`03o`000?oooooooooo04Kooooo00?o0000oooo
ooooool02?ooool4o`0007Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`01oooo
o`00Poooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo00Cooooo0ol0001hooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool00Oooool008Cooooo00?o0000ooooooooool0
A_ooool00ol0003oooooooooo`03o`0007cooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`01ooooo`00QOooool00ol0003oooooooooo`16ooooo`;o0000P?ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo007ooooo0026ooooo`03o`000?oooooooooo04Gooooo00?o0000
ooooooooool0P?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo007ooooo0027oooo
o`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0POooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo007ooooo0028ooooo`03o`000?oooooooooo04?ooooo00?o0000oooooooo
ool0P_ooool00ol0003oooooooooo`0?ooooo`7o00000Oooool1ooooo`00ROooool00ol0003ooooo
ooooo`12ooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool03oooool1o`00007ooooo
0Oooool008[ooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`23ooooo`03o`000?oo
oooooooo00kooooo0Ol00001ooooo`7ooooo002;ooooo`;o0000@Oooool00ol0003oooooooooo`24
ooooo`03o`000?oooooooooo00gooooo0Ol00001ooooo`7ooooo002=ooooo`03o`000?oooooooooo
03kooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`0<ooooo`7o00000Oooool1oooo
o`00S_ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo08Kooooo00?o0000oooooooo
ool02oooool1o`00007ooooo0Oooool008oooooo00?o0000ooooooooool0??ooool00ol0003ooooo
ooooo`27ooooo`03o`000?oooooooooo00[ooooo0Ol00001ooooo`7ooooo002@ooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`0:ooooo`7o00000Ooo
ool1ooooo`00TOooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo08Sooooo00?o0000
ooooooooool02Oooool1o`00007ooooo0Oooool009;ooooo00?o0000ooooooooool0>Oooool00ol0
003oooooooooo`29ooooo`03o`000?oooooooooo00Sooooo0Ol00001ooooo`7ooooo002Cooooo`03
o`000?oooooooooo03Sooooo00?o0000ooooooooool0R_ooool00ol0003oooooooooo`08ooooo`7o
00000Oooool009Cooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`2;ooooo`03o`00
0?oooooooooo00Oooooo0Ol00001ooooo`00UOooool00ol0003oooooooooo`0fooooo`03o`000?oo
oooooooo08cooooo00?o0000ooooooooool01_ooool1o`00007ooooo002Fooooo`03o`000?oooooo
oooo03Gooooo00?o0000ooooooooool0S?ooool00ol0003oooooooooo`06ooooo`7o00000Oooool0
09Oooooo0_l0000eooooo`03o`000?oooooooooo08gooooo00?o0000ooooooooool01Oooool1o`00
007ooooo002Iooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0S_ooool00ol0003o
ooooooooo`04ooooo`7o00000Oooool009[ooooo00?o0000ooooooooool0<Oooool00ol0003ooooo
ooooo`2?ooooo`03o`000?oooooooooo00?ooooo0Ol00001ooooo`00Voooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo093ooooo00?o0000ooooooooool00_ooool1o`00007ooooo002L
ooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0TOooool01Ol0003ooooooooooooo
oooo0000007ooooo002Mooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0TOooool0
1Ol0003ooooooooooooooooo0000007ooooo002Nooooo`03o`000?oooooooooo02gooooo00?o0000
ooooooooool0T_ooool01?l0003oooooooooooooool1o`000000Woooool00ol0003oooooooooo`0/
ooooo`03o`000?oooooooooo09?ooooo00?o0000ooooooooool00Ol000000:3ooooo00?o0000oooo
ooooool0:oooool00ol0003oooooooooo`2Dooooo`7o00000Oooool1o`000000XOooool00ol0003o
ooooooooo`0Zooooo`03o`000?oooooooooo09Gooooo0_l000000:;ooooo0_l0000Zooooo`03o`00
0?oooooooooo09Cooooo0ol000000:Cooooo00?o0000ooooooooool09oooool00ol0003ooooooooo
o`2@ooooo`Co00000oooool00:Gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`2=
ooooo`?o00001oooool00:Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`29oooo
o`Co00002_ooool00:Oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`25ooooo`Co
00003_ooool00:Sooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`22ooooo`?o0000
4_ooool00:Wooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`1nooooo`Co00005Ooo
ool00:[ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`1jooooo`Co00006Oooool0
0:_ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`1eooooo`Co00007Oooool00:co
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1booooo`?o00008Oooool00:gooooo
0_l0000Pooooo`03o`000?oooooooooo06kooooo1?l0000Tooooo`00[oooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo06[ooooo1?l0000Xooooo`00/?ooool00ol0003oooooooooo`0L
ooooo`03o`000?oooooooooo06Oooooo0ol0000/ooooo`00/Oooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo06?ooooo1?l0000_ooooo`00/_ooool00ol0003oooooooooo`0Jooooo`03
o`000?oooooooooo05oooooo1?l0000cooooo`00/oooool00ol0003oooooooooo`0Iooooo`03o`00
0?oooooooooo05cooooo0ol0000gooooo`00]?ooool00ol0003oooooooooo`0Hooooo`03o`000?oo
oooooooo05Sooooo1?l0000jooooo`00]Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo05Cooooo1?l0000nooooo`00]_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo
053ooooo1?l00012ooooo`00]oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04go
oooo0ol00016ooooo`00^?ooool2o`0001Gooooo00?o0000ooooooooool0BOooool4o`0004Wooooo
002jooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0AOooool4o`0004gooooo002k
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0@_ooool3o`00057ooooo002loooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool0?_ooool4o`0005Cooooo002mooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool0>_ooool4o`0005Sooooo002nooooo`03o`00
0?oooooooooo00kooooo00?o0000ooooooooool0=_ooool4o`0005cooooo002oooooo`03o`000?oo
oooooooo00gooooo00?o0000ooooooooool0<oooool3o`00063ooooo0030ooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool0;oooool4o`0006?ooooo0031ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool0:oooool4o`0006Oooooo0032ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool0:?ooool3o`0006_ooooo0033ooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool09?ooool4o`0006kooooo0034ooooo`;o00002Oooool00ol0003ooooooooo
o`0Pooooo`Co0000L_ooool00<Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0M
ooooo`?o0000M_ooool00<Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Ioooo
o`Co0000NOooool00<Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Eooooo`Co
0000OOooool00<Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Aooooo`Co0000
POooool00<[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0>ooooo`?o0000QOoo
ool00<_ooooo00Go0000ooooooooooooooooo`00000<ooooo`Co0000R?ooool00<cooooo00Co0000
oooooooooooo00002?ooool4o`0008cooooo003=ooooo`03o`000?oooooo000000Gooooo0ol0002@
ooooo`00c_ooool2o`000003ooooool0003o000000;o0000Toooool00<oooooo0_l0002Gooooo`00
oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
\
\>"],
  ImageRangeCache->{{{0, 359}, {330.375, 0}} -> {-0.0771432, -0.0315529, \
0.00350368, 0.00350368}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .92059 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-16 1.0763 -0.0263982 1.0763 [
[.01694 .18568 -11.9631 -9 ]
[.01694 .18568 .03693 0 ]
[.13793 .13897 -11.619 -9 ]
[.13793 .13897 .38095 0 ]
[.26292 .09073 -5.63752 -9 ]
[.26292 .09073 .36248 0 ]
[.39212 .04087 -5.46552 -9 ]
[.39212 .04087 .53448 0 ]
[.52574 -0.01069 -5.29351 -9 ]
[.52574 -0.01069 .70649 0 ]
[.58272 .04263 0 -6.19654 ]
[.58272 .04263 6 2.80346 ]
[.71715 .21863 0 -6.07114 ]
[.71715 .21863 6 2.92886 ]
[.83675 .37523 0 -5.963 ]
[.83675 .37523 6 3.037 ]
[.94385 .51546 0 -5.8688 ]
[.94385 .51546 6 3.1312 ]
[.01386 .20006 -12 -2.76892 ]
[.01386 .20006 0 6.23108 ]
[.00748 .25499 -24 -2.80073 ]
[.00748 .25499 0 6.19927 ]
[.00093 .31131 -6 -2.83339 ]
[.00093 .31131 0 6.16661 ]
[-0.00579 .36907 -18 -2.86695 ]
[-0.00579 .36907 0 6.13305 ]
[-0.01268 .42831 -6 -2.90143 ]
[-0.01268 .42831 0 6.09857 ]
[ 0 0 0 0 ]
[ 1 .92059 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02642 .19522 m
.53391 0 L
s
.02642 .19522 m
.03116 .2 L
s
[(-2)] .01694 .18568 .99384 1 Mshowa
.14712 .14879 m
.15172 .1537 L
s
[(-1)] .13793 .13897 .93651 1 Mshowa
.2718 .10083 m
.27624 .10588 L
s
[(0)] .26292 .09073 .87917 1 Mshowa
.40066 .05126 m
.40493 .05646 L
s
[(1)] .39212 .04087 .82184 1 Mshowa
.53391 0 m
.538 .00534 L
s
[(2)] .52574 -0.01069 .7645 1 Mshowa
.125 Mabswid
.05025 .18606 m
.05308 .18894 L
s
.07424 .17683 m
.07705 .17973 L
s
.09837 .16755 m
.10117 .17046 L
s
.12267 .1582 m
.12545 .16113 L
s
.17173 .13933 m
.17447 .14229 L
s
.19651 .1298 m
.19923 .13278 L
s
.22144 .1202 m
.22414 .1232 L
s
.24654 .11055 m
.24922 .11356 L
s
.29723 .09105 m
.29988 .0941 L
s
.32283 .0812 m
.32546 .08427 L
s
.3486 .07129 m
.35121 .07437 L
s
.37455 .06131 m
.37713 .06441 L
s
.42695 .04115 m
.4295 .04428 L
s
.45342 .03096 m
.45594 .03412 L
s
.48007 .02071 m
.48257 .02388 L
s
.5069 .01039 m
.50938 .01358 L
s
.25 Mabswid
.53391 0 m
.9804 .58403 L
s
.57014 .04738 m
.56384 .04975 L
s
[(0)] .58272 .04263 -1 .37701 Mshowa
.70445 .22307 m
.6981 .22529 L
s
[(2)] .71715 .21863 -1 .34914 Mshowa
.82396 .37939 m
.81756 .38147 L
s
[(4)] .83675 .37523 -1 .32511 Mshowa
.93098 .51938 m
.92454 .52134 L
s
[(6)] .94385 .51546 -1 .30418 Mshowa
.125 Mabswid
.60525 .09331 m
.60147 .09471 L
s
.63931 .13786 m
.63552 .13924 L
s
.67236 .1811 m
.66856 .18245 L
s
.73562 .26383 m
.7318 .26514 L
s
.7659 .30345 m
.76207 .30473 L
s
.79534 .34195 m
.7915 .34322 L
s
.85181 .41581 m
.84796 .41704 L
s
.87891 .45126 m
.87506 .45247 L
s
.90529 .48577 m
.90143 .48696 L
s
.95601 .55212 m
.95214 .55328 L
s
.25 Mabswid
.02642 .19522 m
0 .42381 L
s
.02642 .19522 m
.0327 .19281 L
s
[(-1)] .01386 .20006 1 -0.38468 Mshowa
.02006 .25024 m
.02635 .24786 L
s
[(-0.5)] .00748 .25499 1 -0.37762 Mshowa
.01354 .30664 m
.01985 .3043 L
s
[(0)] .00093 .31131 1 -0.37036 Mshowa
.00686 .36448 m
.01318 .36218 L
s
[(0.5)] -0.00579 .36907 1 -0.3629 Mshowa
0 .42381 m
.00634 .42156 L
s
[(1)] -0.01268 .42831 1 -0.35524 Mshowa
.125 Mabswid
.02516 .20612 m
.02893 .20468 L
s
.0239 .21707 m
.02767 .21563 L
s
.02262 .22807 m
.0264 .22664 L
s
.02135 .23913 m
.02512 .2377 L
s
.01877 .26141 m
.02255 .25999 L
s
.01747 .27263 m
.02125 .27122 L
s
.01617 .28391 m
.01995 .2825 L
s
.01486 .29525 m
.01864 .29384 L
s
.01222 .31809 m
.01601 .3167 L
s
.01089 .3296 m
.01468 .32821 L
s
.00955 .34117 m
.01334 .33978 L
s
.00821 .35279 m
.012 .35141 L
s
.0055 .37622 m
.0093 .37485 L
s
.00414 .38803 m
.00793 .38666 L
s
.00276 .39989 m
.00656 .39853 L
s
.00139 .41182 m
.00519 .41047 L
s
.25 Mabswid
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.54154 .92059 L
s
.54154 .92059 m
.5414 .7134 L
s
.5414 .7134 m
.02642 .19522 L
s
.53391 0 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.53391 0 m
.02642 .19522 L
s
.5414 .7134 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.54154 .92059 L
s
.54154 .92059 m
.5414 .7134 L
s
0 0 m
1 0 L
1 .92059 L
0 .92059 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.26726 .58001 m
.29091 .57041 L
s
1 0 .6 r
.25311 .54374 m
.27692 .53495 L
s
.8 0 1 r
.2393 .50685 m
.26327 .4985 L
s
.2 0 1 r
.22553 .46944 m
.24958 .46121 L
s
0 .4 1 r
.21171 .43175 m
.23576 .42345 L
s
1 0 0 r
.29091 .57041 m
.31393 .56027 L
s
0 1 1 r
.19783 .39392 m
.22187 .3855 L
s
1 0 .6 r
.27692 .53495 m
.30054 .52578 L
s
.8 0 1 r
.26327 .4985 m
.28727 .48996 L
s
0 1 .4 r
.18393 .356 m
.20795 .34746 L
s
.2 0 1 r
.24958 .46121 m
.27374 .45289 L
s
.2 1 0 r
.17 .31802 m
.194 .30935 L
s
0 .4 1 r
.23576 .42345 m
.25996 .4151 L
s
.8 1 0 r
.15604 .27996 m
.18002 .27116 L
s
0 1 1 r
.22187 .3855 m
.24606 .37704 L
s
1 0 .6 r
.30054 .52578 m
.32392 .51639 L
s
.8 0 1 r
.28727 .48996 m
.31127 .48125 L
s
1 .6 0 r
.14206 .24182 m
.16601 .23289 L
s
1 0 0 r
.31393 .56027 m
.33629 .54997 L
s
0 1 .4 r
.20795 .34746 m
.23212 .33887 L
s
.2 0 1 r
.27374 .45289 m
.29802 .44447 L
s
.2 1 0 r
.194 .30935 m
.21815 .30062 L
s
0 .4 1 r
.25996 .4151 m
.28431 .40668 L
s
.8 1 0 r
.18002 .27116 m
.20415 .2623 L
s
0 1 1 r
.24606 .37704 m
.27041 .36851 L
s
1 .6 0 r
.16601 .23289 m
.19012 .22391 L
s
.8 0 1 r
.31127 .48125 m
.33529 .47245 L
s
0 1 .4 r
.23212 .33887 m
.25645 .33022 L
s
1 0 .6 r
.32392 .51639 m
.34716 .50699 L
s
.2 0 1 r
.29802 .44447 m
.32242 .43598 L
s
1 0 0 r
.33629 .54997 m
.35834 .53988 L
s
.2 1 0 r
.21815 .30062 m
.24245 .29184 L
s
0 .4 1 r
.28431 .40668 m
.30881 .39821 L
s
.8 1 0 r
.20415 .2623 m
.22843 .25339 L
s
0 1 1 r
.27041 .36851 m
.29491 .35994 L
s
1 .6 0 r
.19012 .22391 m
.21439 .21487 L
s
0 1 .4 r
.25645 .33022 m
.28093 .32152 L
s
.8 0 1 r
.33529 .47245 m
.35939 .46365 L
s
.2 0 1 r
.32242 .43598 m
.34694 .42745 L
s
1 0 .6 r
.34716 .50699 m
.37046 .49778 L
s
.2 1 0 r
.24245 .29184 m
.26691 .28301 L
s
0 .4 1 r
.30881 .39821 m
.33346 .38968 L
s
1 0 0 r
.35834 .53988 m
.38051 .53022 L
s
.8 1 0 r
.22843 .25339 m
.25287 .24443 L
s
0 1 1 r
.29491 .35994 m
.31956 .35131 L
s
1 .6 0 r
.21439 .21487 m
.2388 .20577 L
s
0 1 .4 r
.28093 .32152 m
.30556 .31275 L
s
.8 0 1 r
.35939 .46365 m
.38368 .45497 L
s
.2 0 1 r
.34694 .42745 m
.37163 .41889 L
s
.2 1 0 r
.26691 .28301 m
.29153 .27412 L
s
1 0 .6 r
.37046 .49778 m
.39403 .48887 L
s
0 .4 1 r
.33346 .38968 m
.35827 .38111 L
s
.8 1 0 r
.25287 .24443 m
.27747 .2354 L
s
0 1 1 r
.31956 .35131 m
.34437 .34262 L
s
1 0 0 r
.38051 .53022 m
.40312 .52114 L
s
1 .6 0 r
.2388 .20577 m
.26338 .19661 L
s
0 1 .4 r
.30556 .31275 m
.33036 .30394 L
s
.8 0 1 r
.38368 .45497 m
.40825 .44645 L
s
.2 0 1 r
.37163 .41889 m
.39652 .41036 L
s
.2 1 0 r
.29153 .27412 m
.3163 .26517 L
s
0 .4 1 r
.35827 .38111 m
.38324 .37249 L
s
1 0 .6 r
.39403 .48887 m
.41804 .48037 L
s
.8 1 0 r
.27747 .2354 m
.30222 .22632 L
s
0 1 1 r
.34437 .34262 m
.36935 .33388 L
s
1 0 0 r
.40312 .52114 m
.42638 .51269 L
s
1 .6 0 r
.26338 .19661 m
.28811 .18739 L
s
0 1 .4 r
.33036 .30394 m
.35531 .29507 L
s
.8 0 1 r
.40825 .44645 m
.43318 .43812 L
s
.2 0 1 r
.39652 .41036 m
.42163 .40184 L
s
.2 1 0 r
.3163 .26517 m
.34124 .25616 L
s
0 .4 1 r
.38324 .37249 m
.40839 .36383 L
s
1 0 .6 r
.41804 .48037 m
.44261 .47228 L
s
.8 1 0 r
.30222 .22632 m
.32714 .21718 L
s
0 1 1 r
.36935 .33388 m
.39448 .32508 L
s
1 0 0 r
.42638 .51269 m
.45042 .50489 L
s
1 .6 0 r
.28811 .18739 m
.313 .17812 L
s
0 1 .4 r
.35531 .29507 m
.38043 .28614 L
s
.8 0 1 r
.43318 .43812 m
.45853 .42998 L
s
.2 0 1 r
.42163 .40184 m
.44698 .39336 L
s
.2 1 0 r
.34124 .25616 m
.36633 .2471 L
s
0 .4 1 r
.40839 .36383 m
.43371 .35513 L
s
1 0 .6 r
.44261 .47228 m
.46781 .4646 L
s
.8 1 0 r
.32714 .21718 m
.35221 .20798 L
s
0 1 1 r
.39448 .32508 m
.41978 .31623 L
s
1 0 0 r
.45042 .50489 m
.4753 .49772 L
s
1 .6 0 r
.313 .17812 m
.33806 .16878 L
s
0 1 .4 r
.38043 .28614 m
.40571 .27715 L
s
.8 0 1 r
.45853 .42998 m
.48429 .42198 L
s
.2 0 1 r
.44698 .39336 m
.47258 .38487 L
s
.2 1 0 r
.36633 .2471 m
.39159 .23797 L
s
1 0 .6 r
.46781 .4646 m
.49367 .45726 L
s
0 .4 1 r
.43371 .35513 m
.45921 .34638 L
s
.8 1 0 r
.35221 .20798 m
.37745 .19872 L
s
0 1 1 r
.41978 .31623 m
.44525 .30732 L
s
1 0 0 r
.4753 .49772 m
.50107 .49113 L
s
1 .6 0 r
.33806 .16878 m
.36328 .15939 L
s
0 1 .4 r
.40571 .27715 m
.43115 .2681 L
s
.8 0 1 r
.48429 .42198 m
.51043 .41402 L
s
.2 0 1 r
.47258 .38487 m
.4984 .37635 L
s
1 0 .6 r
.49367 .45726 m
.52018 .45013 L
s
.2 1 0 r
.39159 .23797 m
.41702 .22879 L
s
0 .4 1 r
.45921 .34638 m
.48489 .33757 L
s
1 0 0 r
.50107 .49113 m
.52776 .48499 L
s
.8 1 0 r
.37745 .19872 m
.40285 .1894 L
s
0 1 1 r
.44525 .30732 m
.47088 .29836 L
s
1 .6 0 r
.36328 .15939 m
.38866 .14993 L
s
0 1 .4 r
.43115 .2681 m
.45676 .25899 L
s
.8 0 1 r
.51043 .41402 m
.53688 .40601 L
s
1 0 .6 r
.52018 .45013 m
.54727 .44305 L
s
.2 0 1 r
.4984 .37635 m
.52441 .36776 L
s
1 0 0 r
.52776 .48499 m
.55541 .47908 L
s
.2 1 0 r
.41702 .22879 m
.4426 .21955 L
s
0 .4 1 r
.48489 .33757 m
.51073 .32871 L
s
.8 1 0 r
.40285 .1894 m
.42842 .18002 L
s
0 1 1 r
.47088 .29836 m
.49668 .28933 L
s
1 0 .6 r
.54727 .44305 m
.57477 .43579 L
s
1 .6 0 r
.38866 .14993 m
.41421 .14041 L
s
.8 0 1 r
.53688 .40601 m
.56353 .39785 L
s
1 0 0 r
.55541 .47908 m
.58389 .47303 L
s
0 1 .4 r
.45676 .25899 m
.48254 .24983 L
s
.2 0 1 r
.52441 .36776 m
.55058 .35909 L
s
.2 1 0 r
.4426 .21955 m
.46836 .21024 L
s
0 .4 1 r
.51073 .32871 m
.53675 .31979 L
s
.8 1 0 r
.42842 .18002 m
.45416 .17057 L
s
1 0 0 r
.58389 .47303 m
.61288 .46647 L
s
0 1 1 r
.49668 .28933 m
.52265 .28025 L
s
1 0 .6 r
.57477 .43579 m
.60242 .42818 L
s
.8 0 1 r
.56353 .39785 m
.59027 .3895 L
s
1 .6 0 r
.41421 .14041 m
.43992 .13083 L
s
0 1 .4 r
.48254 .24983 m
.50848 .2406 L
s
.2 0 1 r
.55058 .35909 m
.57688 .35032 L
s
.2 1 0 r
.46836 .21024 m
.49429 .20088 L
s
0 .4 1 r
.53675 .31979 m
.56292 .31079 L
s
1 0 0 r
.61288 .46647 m
.6418 .4592 L
s
1 0 .6 r
.60242 .42818 m
.62999 .42017 L
s
.8 1 0 r
.45416 .17057 m
.48006 .16107 L
s
0 1 1 r
.52265 .28025 m
.54879 .2711 L
s
.8 0 1 r
.59027 .3895 m
.61704 .38096 L
s
1 .6 0 r
.43992 .13083 m
.46581 .12118 L
s
0 1 .4 r
.50848 .2406 m
.5346 .23132 L
s
.2 0 1 r
.57688 .35032 m
.60332 .34145 L
s
.2 1 0 r
.49429 .20088 m
.52038 .19145 L
s
0 .4 1 r
.56292 .31079 m
.58927 .30174 L
s
.8 1 0 r
.48006 .16107 m
.50614 .1515 L
s
0 1 1 r
.54879 .2711 m
.5751 .2619 L
s
1 .6 0 r
.46581 .12118 m
.49186 .11147 L
s
0 1 .4 r
.5346 .23132 m
.56089 .22197 L
s
.2 1 0 r
.52038 .19145 m
.54665 .18196 L
s
.8 1 0 r
.50614 .1515 m
.53239 .14187 L
s
1 .6 0 r
.49186 .11147 m
.51809 .1017 L
s
0 g
.25 Mabswid
.53391 0 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.53391 0 m
.02642 .19522 L
s
.02642 .19522 m
.53391 0 L
s
.02642 .19522 m
.03116 .2 L
s
[(-2)] .01694 .18568 .99384 1 Mshowa
.14712 .14879 m
.15172 .1537 L
s
[(-1)] .13793 .13897 .93651 1 Mshowa
.2718 .10083 m
.27624 .10588 L
s
[(0)] .26292 .09073 .87917 1 Mshowa
.40066 .05126 m
.40493 .05646 L
s
[(1)] .39212 .04087 .82184 1 Mshowa
.53391 0 m
.538 .00534 L
s
[(2)] .52574 -0.01069 .7645 1 Mshowa
.125 Mabswid
.05025 .18606 m
.05308 .18894 L
s
.07424 .17683 m
.07705 .17973 L
s
.09837 .16755 m
.10117 .17046 L
s
.12267 .1582 m
.12545 .16113 L
s
.17173 .13933 m
.17447 .14229 L
s
.19651 .1298 m
.19923 .13278 L
s
.22144 .1202 m
.22414 .1232 L
s
.24654 .11055 m
.24922 .11356 L
s
.29723 .09105 m
.29988 .0941 L
s
.32283 .0812 m
.32546 .08427 L
s
.3486 .07129 m
.35121 .07437 L
s
.37455 .06131 m
.37713 .06441 L
s
.42695 .04115 m
.4295 .04428 L
s
.45342 .03096 m
.45594 .03412 L
s
.48007 .02071 m
.48257 .02388 L
s
.5069 .01039 m
.50938 .01358 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 265.125},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001Bb000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00`oooool5o`000:3ooooo0033ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@0X?ooool00<Cooooo00?oV9RHob4Q8Oo^k^h0XOooool00<Gooooo00?oV9RH
ob4Q8Oo^k^h0X?ooool00<Kooooo00?oMgMgofIVI_ooool0Woooool00<Oooooo00?o0000oooooooo
ool0W_ooool00<?ooooo00Go0000okZj^_ooooooV9RHoa0@402Pooooo`00`oooool01OnHV9So410@
o`000?lQ8B7oc<c<0:3ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003;ooooo`;o0000Voooool00<Sooooo0ol000000ooooooo0000ooooo`2Jooooo`00a_oo
ool2o`0000Cooooo0_l0002Jooooo`00`oooool3o`0000Kooooo00?o0000ooooool00000VOooool0
0<3ooooo1?l00008ooooo`04o`000?ooooooooooo`0009Sooooo002Hooooo`Co000000?o410@oooo
ooooool07oooool2o`0000Cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0002H
ooooo`00V_ooool00ol0003oooooooooo`0Nooooo`?o00003_ooool01Ol0003ooooooooooooooooo
000009Oooooo002Jooooo`03o`000?oooooooooo01cooooo0_l0000Aooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0U?ooool009[ooooo00?o0000ooooooooool06Oooool3o`0000;o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo09?o
oooo002Jooooo`03o`000?oooooooooo01Kooooo0ol0000Fooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^08Kooooo002Jooooo`03o`00
0?oooooooooo01Cooooo0_l0000Iooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1oooool01OmgMgOoV9RHoooooonHV9SoMgMg08Kooooo002Jooooo`03o`000?oooooooooo017ooooo
0ol000000ooooooo0000ooooo`0Hooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1_ooool01Ol@413ooooooooooooooooo410@08Kooooo002Hooooo`03oeEEEOmVIVKo0000017ooooo
0_l0000Nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool01Ol0003ooooo
oooooooooooo000008Kooooo002Yooooo`?o00008?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000026ooooo`00Yoooool3o`0002;ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@
4100Q_ooool00:Cooooo0ol00002ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Q_ooool00:7ooooo
0ol0000Xooooo`03o`000?oooooooooo00Sooooo0_l00004ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h0Q_ooool009oooooo0_l0000[ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo
0000S_ooool009cooooo0ol000000ooooooo0000ooooo`0Zooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0S?ooool009[ooooo0_l00005ooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`2;ooooo`00Uoooool3o`0003;ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`2:ooooo`00K?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^02?ooooo0ol000000ooooooo0000ooooo`0booooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0ROooool006cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Qooooo`;o0000>?ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo08Wooooo001/ooooo`05oa0@4?oooooooooo
ooooool@41007_ooool3o`0003[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`28
ooooo`00K?ooool01Ol0003ooooooooooooooooo000001cooooo0ol0000looooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0Qoooool006cooooo00Go0000ooooooooooooooooo`00000I
ooooo`?o00000_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool0Q_ooool006cooooo00Go410@oooooooooooooooooa0@400Gooooo`;o0000@_ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo08Kooooo001/ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL05?ooool3o`0004Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`25
ooooo`00K?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^017ooooo0ol00002ooooo`03o`000?oooooo
oooo04;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`24ooooo`00P?ooool2o`00
04[ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`23ooooo`00OOooool3o`0004co
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`22ooooo`00Noooool2o`000003oooo
ool0003ooooo04cooooo00?o0000ooooooooool05?ooool2o`0008?ooooo001hooooo`?o0000DOoo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooo000008?ooooo001eooooo`?o0000E?ooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo083ooooo001cooooo`Co0000Coooool2oonI
00Cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1oooooo`00L?ooool3o`0000Co
oooo00?o0000ooooooooool0BOooool3oonI00Kooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`1oooooo`00K_ooool2o`00053ooooo0oooV@09ooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool0O_ooool004?ooooo1?l000000ol@413oooooooooo`0Qooooo`?o0000Cooo
ool3oonI00cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1mooooo`00AOooool0
0ol0003oooooooooo`0Pooooo`?o00000oooool00ol0003oooooooooo`19ooooo`?ooiT03oooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo07cooooo000jooooo`Ko00001Oooool00ol0
003oooooooooo`0Nooooo`;o0000Coooool3oonI01;ooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`1looooo`00AOooool00ol0003oooooooooo`0Kooooo`?o0000C_ooool3oonI01Go
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1kooooo`00AOooool00ol0003ooooo
ooooo`0Iooooo`;o00000_ooool00ol0003oooooooooo`19ooooo`?ooiT06?ooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo07[ooooo0015ooooo`03o`000?oooooooooo01Kooooo0ol0
001=ooooo`?ooiT06oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo07Wooooo0015
ooooo`03o`000?oooooooooo01Cooooo0_l0001>ooooo`;ooiT07_ooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo07Wooooo0013ooooo`03oeEEEOmVIVKo000001?ooooo0ol000000ooo
oooo0000ooooo`1;ooooo`;ooiT08?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo
07Sooooo001Fooooo`?o0000C_ooool3oonI02;ooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`1gooooo`00E?ooool2o`0004oooooo0_ooV@0Uooooo`03o`000?oooooooooo01oooooo
0_l0001hooooo`00DOooool3o`000003ooooool0003ooooo04cooooo0_ooV@0Uooooo`;oc?l000?o
0000ooooooooool08?ooool00ol0003oooooooooo`1fooooo`00Coooool2o`0004oooooo0oooV@0T
ooooo`?oc?l00_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo07Gooooo001<oooo
o`?o0000C_ooool3oonI02Cooooo0oo<o`05ooooo`03o`000?oooooooooo02;ooooo00?o0000oooo
ooooool0M?ooool004Wooooo1?l0001>ooooo`;ooiT09Oooool2olco00Sooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`1cooooo`00Aoooool2o`0000Cooooo00?o0000ooooooooool0
B?ooool3oonI02Gooooo0_o<o`0:ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
L_ooool004Cooooo0ol0001>ooooo`?ooiT09Oooool3olco00cooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`1booooo`006_ooool5o`0002?ooooo0ol0001=ooooo`?ooiT09_ooool2
olco00oooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`1aooooo`006_ooool01OnH
V9So8B4Qonk^k_ooooooA4A4023ooooo0ol00003ooooo`03o`000?oooooooooo04Oooooo0oooV@0W
ooooo`;oc?l04Oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo073ooooo000Boooo
o`Ko00000oooool00onHV9So8B4Qonk^kP0Oooooo`;o0000COooool3oonI02Oooooo0oo<o`0Coooo
o`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0Koooool001cooooo00?oV9RHob4Q8Oo^
k^h06oooool3o`0004gooooo0_ooV@0Wooooo`?oc?l05_ooool00ol0003oooooooooo`0Wooooo`03
o`000?oooooooooo06oooooo000Mooooo`03ogMgMomVIVKooooo01Oooooo0ol00003ooooo`03o`00
0?oooooooooo04Oooooo0oooV@0Wooooo`;oc?l06Oooool00ol0003oooooooooo`0Xooooo`03o`00
0?oooooooooo06kooooo000Nooooo`03o`000?oooooooooo01Cooooo0_l0001=ooooo`?ooiT09ooo
ool3olco01_ooooo00?o0000ooooooooool0:Oooool00ol0003oooooooooo`1]ooooo`006_ooool0
1Ol0003o^[ZjoooooonHV9So410@01?ooooo0ol0001=ooooo`;ooiT09oooool3olco01kooooo00?o
0000ooooooooool0:_ooool00ol0003oooooooooo`1/ooooo`006_ooool01OnHV9So410@o`000?lQ
8B7oc<c<017ooooo0_l00003ooooo`03o`000?oooooooooo04Oooooo0oooV@0Vooooo`?oc?l08Ooo
ool00ol0003oooooooooo`02oc?o02Sooooo0_l0001]ooooo`00;Oooool3o`0004cooooo0oooV@0V
ooooo`?oc?l09?ooool00ol0003o<ol0oc?o000Zooooo`;o0000KOooool002[ooooo0ol0001=oooo
o`;ooiT09_ooool3olco02Kooooo00?o<ol0o`000?ooool0;Oooool00ol0003oooooooooo`1Zoooo
o`00:?ooool2o`0000?ooooo00?o0000ooooooooool0Aoooool3oonI02Kooooo0_o<o`0Wooooo`;o
<ol000?oooooo`000?ooool0;_ooool00ol0003oooooooooo`1Yooooo`009Oooool3o`0004cooooo
0oooV@0Vooooo`?oc?l09oooool2oc?o00?ooooo00?o0000ooooooooool0;Oooool00ol0003ooooo
ooooo`1Yooooo`009?ooool00ol0003oooooooooo`1:ooooo`?ooiT09_ooool3olco02Oooooo0olc
o`05ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0J?ooool001[ooooo1?l00000
0ol@413oooooooooo`03ooooo`;o0000B?ooool3oonI02Kooooo0oo<o`0Wooooo`?o<ol02?ooool0
0ol0003oooooooooo`0_ooooo`03o`000?oooooooooo06Oooooo000Looooo`03o`000?oooooooooo
00Gooooo0_l00015ooooo`?ooiT09_ooool3olco02Oooooo0olco`0;ooooo`03o`000?oooooooooo
033ooooo00?o0000ooooooooool0I_ooool0017ooooo1_l00005ooooo`03o`000?oooooooooo00Co
oooo1?l00012ooooo`;ooiT09_ooool3olco02Oooooo0olco`0>ooooo`03o`000?oooooooooo033o
oooo00?o0000ooooooooool02?ooool5o`0005Wooooo000Looooo`03o`000?oooooooooo00Gooooo
00Co0000oooooooooooo0000?_ooool3oonI02Kooooo0_o<o`0Wooooo`?o<ol04Oooool00ol0003o
ooooooooo`0aooooo`03o`000?oooooooooo00Oooooo00GoV9RHob4Q8Oo^k^koooooodA4A01Ioooo
o`007?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0>?ooool3oonI02Kooooo0oo<o`0Vooooo`?o<ol05?ooool00ol0003oooooooooo`0booooo`03
o`000?oooooooooo00Oooooo00?oV9RHob4Q8Oo^k^h0F_ooool001cooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03Gooooo0_ooV@0Vooooo`?oc?l0
9_ooool3oc?o01Oooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`07ooooo`03oiRH
V?lQ8B7ok^k^05Wooooo000Looooo`03o`000?oooooooooo00Cooooo0_l00005ooooo`03o`000?oo
oooooooo037ooooo0oooV@0Uooooo`?oc?l09_ooool3oc?o01[ooooo00?o0000ooooooooool0=?oo
ool00ol0003oooooooooo`07ooooo`03ogMgMomVIVKooooo05Sooooo000Jooooo`03oeEEEOmVIVKo
000000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0]ooooo`?ooiT09Oooool3
olco02Oooooo0_lco`0Mooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`1Gooooo`008oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
02[ooooo0_ooV@0Uooooo`?oc?l09oooool3oc?o01oooooo00?o0000ooooooooool01Oooool2o`3o
IRkooooo0_l00004ooooo`05o`000?nj^[[ooooooiRHV?l@4100FOooool002?ooooo0_l00008oooo
o`03o`000?oooooooooo02Kooooo0oooV@0Uooooo`;oc?l09oooool3oc?o02;ooooo00?o0000oooo
ooooool00_ooool3o`3oIRkooooo0_l000000ooooooo0000ooooo`03ooooo`05oiRHV?l@413o0000
ob4Q8Oo<c<`0FOooool002?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`0Roooo
o`?ooiT09Oooool3olco02Kooooo0olco`0Uooooo`03o`000?oooooo0?mV00;o0?mV=Oooool00ol0
003oooooooooo`1Oooooo`008oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo01oo
oooo0_ooV@0Uooooo`?oc?l09_ooool3oc?o02Oooooo00?o0?mVo`000?l0ofH0>?ooool00ol0003o
ooooooooo`1Oooooo`008oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo01_ooooo
0oooV@0Uooooo`;oc?l09_ooool3oc?o02Oooooo0ol0ofH2o`0003[ooooo00?o0000ooooooooool0
G_ooool002;ooooo0_l0000=ooooo`03o`000?oooooooooo01Oooooo0oooV@0Uooooo`?oc?l09_oo
ool2oc?o02Oooooo0ol0ofH3o`000003ooooool0003ooooo03[ooooo00?o0000ooooooooool0GOoo
ool002;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Eooooo`03oonI0?oooooo
oooo02?ooooo0oo<o`0Vooooo`?o<ol09oooool2o`3oIP?o00001Oooool00ol0003oooooooooo`0i
ooooo`03o`000?oooooooooo05cooooo000Rooooo`03o`000?oooooooooo00kooooo00?o0000oooo
ooooool0>?ooool2olco02Kooooo0olco`0Wooooo`;o0?mV0ol00009ooooo`03o`000?oooooooooo
03Sooooo00?o0000ooooooooool0G?ooool002;ooooo0ol0000?ooooo`03o`000?oooooooooo03Co
oooo0oo<o`0Uooooo`?o<ol09oooool2o`3oIP?o00003Oooool00ol0003oooooooooo`0hooooo`03
o`000?oooooooooo05_ooooo000Rooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
<?ooool3olco02Gooooo0olco`0Wooooo`?o0?mV0_l0000Aooooo`03o`000?oooooooooo03Sooooo
00?o0000ooooooooool0F_ooool002;ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`0]ooooo`;oc?l09Oooool3oc?o02Oooooo0ol0ofH3o`0001Cooooo00?o0000ooooooooool0>?oo
ool00ol0003oooooooooo`1Iooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ
8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo02Wooooo0oo<o`0Uooooo`;o<ol09oooool3o`3oIP?o00005oooool00ol0003ooooo
ooooo`0hooooo`03o`000?oooooooooo05Wooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
1Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Cooooo`03o`00
0?oooooooooo02Gooooo0oo<o`0Uooooo`?o<ol09_ooool3o`3oIP?o00006oooool00ol0003ooooo
ooooo`0hooooo`03o`000?oooooooooo05Sooooo0005o`0000;ooooo00Go410@oooooooooooooooo
oa0@400@ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool05Oooool00ol0003ooooo
ooooo`0Rooooo`;oc?l09Oooool3oc?o02Kooooo0ol0ofH3o`0001oooooo00?o0000ooooooooool0
0oooool2o`3ooc?ooooo00?o0000ooooooooool0Eoooool000Oooooo00Go0000oooooooooooooooo
o`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`0Nooooo`?oc?l09Oooool2oc?o02Kooooo0ol0ofH3o`0002?ooooo00?o0000ooooool0ool0
0_l0ooleooooo`;o0000F?ooool000Oooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`00
0?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo01[o
oooo0oo<o`0Uooooo`?o<ol09_ooool2o`3oIP03ooooool0003o000002Gooooo0_l0ool00ol0003o
ooooooooo`0hooooo`03o`000?oooooooooo05Gooooo0007ooooo`05oa0@4?ooooooooooooooool@
41003?ooool00ol0003oooooooooo`06ooooo`;o00006Oooool00ol0003oooooooooo`0Gooooo`;o
c?l09Oooool3oc?o02Kooooo0ol0ofH3o`0002Cooooo0ol0ool3ooooo`03o`000?oooooooooo03Oo
oooo00?o0000ooooooooool0EOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0Cooooo`?o
c?l09Oooool2oc?o02Kooooo0ol0ofH3o`0002Cooooo0ol0ool6ooooo`03o`000?oooooooooo03So
oooo00?o0000ooooooooool0E?ooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co
00001Oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00oooooo0oo<o`0Uooooo`?o
<ol09_ooool2o`3oIP?o00009?ooool3o`3oo`[ooooo00?o0000ooooooooool0>?ooool00ol0003o
ooooooooo`1Cooooo`008Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00gooooo
00?oc?l0ooooooooool08oooool3oc?o02Kooooo0_l0ofH3o`0002Cooooo0ol0ool>ooooo`03o`00
0?oooooooooo03Sooooo00?o0000ooooooooool0D_ooool0023ooooo0ol0000Mooooo`03o`000?oo
oooooooo02oooooo0olco`0Vooooo`?o0?mV0_l0000Tooooo`?o0?oo4_ooool00ol0003ooooooooo
o`0gooooo`03o`000?oooooooooo05;ooooo000Qooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool0:oooool3oc?o02Kooooo0ol0ofH3o`0002?ooooo0ol0oolFooooo`03o`000?oooooo
oooo03Oooooo00?o0000ooooooooool0DOooool0023ooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`0Wooooo`?o<ol09_ooool3o`3oIP?o00009?ooool2o`3ooa[ooooo00?o0000oooo
ooooool0=oooool00ol0003oooooooooo`1@ooooo`008?ooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo02Cooooo0_lco`0Vooooo`?o0?mV0ol0000Tooooo`?o0?oo7?ooool00ol0003o
ooooooooo`0hooooo`03o`000?oooooooooo04oooooo000Pooooo`;o00008_ooool00ol0003ooooo
ooooo`0Pooooo`?o<ol09_ooool2o`3oIP?o00009?ooool3o`3oob3ooooo00?o0000ooooooooool0
=oooool00ol0003oooooooooo`1?ooooo`008?ooool00ol0003oooooooooo`0Rooooo`03o`000?oo
oooooooo01cooooo0olco`0Vooooo`?o0?mV0_l0000Tooooo`?o0?oo9?ooool00ol0003ooooooooo
o`0gooooo`03o`000?oooooooooo04kooooo000Pooooo`03o`000?oooooooooo02?ooooo00?o0000
ooooooooool06Oooool2oc?o02Kooooo0ol0ofH3o`0002?ooooo0ol0oolWooooo`03o`1Vool0003o
oooo03Sooooo00?o0000ooooooooool0COooool0023ooooo0ol0000Tooooo`03o`000?oooooooooo
01Gooooo0olco`0Vooooo`;o0?mV0ol0000Sooooo`?o0?oo9oooool3o`1Vo`;ooooo00?o0000oooo
ooooool0=_ooool2o`0004kooooo000Pooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool04Oooool3oc?o02Kooooo0_l0ofH3o`0002Cooooo0_l0oolWooooo`?o06Ko1_ooool00ol0003o
ooooooooo`0fooooo`03o`000?oooooooooo04cooooo000Dooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo00kooooo0_lco`0Vooooo`;o
0?mV0ol0000Tooooo`?o0?oo9oooool2o`1Vo`Wooooo00?o0000ooooooooool0=oooool00ol0003o
ooooooooo`1;ooooo`005?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo00?o0000oooooooo
ool0:?ooool00ol0003oooooooooo`0:ooooo`?o<ol09Oooool3o`3oIP;o00009?ooool3o`3oobOo
oooo0ol0I_l<ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0B_ooool001Cooooo
00Go410@oooooooooooooooooa0@4006ooooo`;o0000:_ooool00ol0003oooooooooo`06ooooo`?o
<ol09Oooool3o`3oIP?o00008oooool3o`3oobOooooo0ol0I_l@ooooo`03o`000?oooooooooo03Oo
oooo00?o0000ooooooooool0BOooool001Cooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo02[ooooo00?o0000ooooooooool01?ooool00olco`3oooooooooo`0Sooooo`?o
0?mV0ol0000Sooooo`?o0?oo9oooool3o`1VoaCooooo00?o0000ooooooooool0=_ooool00ol0003o
ooooooooo`19ooooo`005?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool0:oooool00ol0003oooooooooo`0Wooooo`;o0?mV0ol0000Sooooo`?o0?oo9oooool3o`1VoaSo
oooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`18ooooo`005?ooool01Ol@413ooooo
oooooooooooo410@00Kooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Sooooo`;o
0?mV0ol0000Tooooo`;o0?oo9oooool3o`1Voacooooo00?o0000ooooooooool0=_ooool00ol0003o
ooooooooo`17ooooo`005?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo0_l0000^ooooo`03
o`000?oooooooooo01oooooo0_l0ofH3o`0002Cooooo0ol0oolVooooo`?o06Ko7oooool00ol0003o
ooooooooo`0gooooo`03o`000?oooooooooo04Kooooo000Dooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01_ooooo0ol0ofH2o`0002Co
oooo0ol0oolVooooo`?o06Ko8oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo04Go
oooo000Oooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool05_ooool4o`3oIP?o0000
8oooool3o`3oobKooooo0ol0I_lWooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0
AOooool001kooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Booooo`?o0?mV00Co
ooooo`000?l0003o00008oooool3o`3oobOooooo0_l0I_l[ooooo`03o`000?oooooooooo03Kooooo
00?o0000ooooooooool0A?ooool001kooooo0_l0000cooooo`03o`000?oooooooooo00kooooo0ol0
ofH01?oooooo0000o`000?l0000Sooooo`?o0?oo9oooool3o`1VobOooooo0_lc0?l5ooooo`03o`00
0?oooooooooo03Kooooo0_l00014ooooo`007_ooool00ol0003oooooooooo`0cooooo`03o`000?oo
oooooooo00[ooooo0ol0ofH01?oooooo0000o`000?l0000Tooooo`;o0?oo9oooool3o`1VobOooooo
0olc0?l8ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooool00000A?ooool001kooooo00?o
0000ooooooooool0=?ooool00ol0003oooooooooo`07ooooo`;o0?mV0_ooool2o`0002Cooooo0ol0
oolVooooo`?o06Ko9oooool3oc<0o`_ooooo00?o0000ooooooooool0=_ooool00ol0003ooooooooo
o`12ooooo`007_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00?ooooo0ol0ofH0
1?oooooo0000o`000?l0000Sooooo`?o0?oo9_ooool3o`1VobOooooo0olc0?l?ooooo`03o`000?oo
oooooooo03Kooooo00?o0000ooooooooool0@Oooool001kooooo0_l0000gooooo`03o`000?oooooo
0?mV00;o0?mV00Coooooo`000?l0003o00008oooool3o`3oobKooooo0ol0I_lWooooo`?o<`3o4ooo
ool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo043ooooo000Nooooo`03o`000?oooooo
oooo03Oooooo00?o0?mVooooool000000_l0000Rooooo`Co0?oo9oooool2o`1VobOooooo0olc0?lG
ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0?oooool001kooooo00?o0000oooo
ooooool0=_ooool3o`0002;ooooo0ol0oolXooooo`?o06Ko9oooool2oc<0oa_ooooo00?o0000oooo
ooooool0=Oooool00ol0003oooooooooo`0oooooo`007_ooool2o`0003Gooooo0_l00003ooooo`03
o`000?oooooooooo01cooooo0ol0oolXooooo`?o06Ko9oooool3oc<0oakooooo00?o0000oooooooo
ool0=Oooool00ol0003oooooooooo`09ooooo`;o000000?o410@ooooooooool0<?ooool001gooooo
00?o0000ooooooooool0<_ooool3o`0000Kooooo00?o0000ooooooooool06?ooool3o`3oobSooooo
0ol0I_lWooooo`?o<`3o8Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Wooooo
00?o0000ooooooooool0<Oooool000;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0;oooool3o`0000[o
oooo00?o0000ooooooooool05Oooool2o`3oobSooooo0ol0I_lWooooo`?o<`3o9Oooool00ol0003o
ooooooooo`0fooooo`03o`000?oooooooooo00Gooooo1Ol0000booooo`000_ooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool0;?ooool3o`0000kooooo00?o0000ooooooooool04Oooool3o`3oobOooooo0ol0I_lWooooo`?o
<`3o:Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00Gooooo00CoA4A4omgMgOoo
oooo0000<oooool000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo
00?ooooo0_l0000Zooooo`?o00004_ooool00ol0003oooooooooo`0=ooooo`?o0?oo9oooool3o`1V
obOooooo0olc0?l]ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool01?ooool01?oM
gMgoEEEEooooool0000cooooo`000_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMg
oc8b<_ooool01?ooool00ol0003oooooooooo`0Wooooo`;o00005_ooool00ol0003oooooooooo`0:
ooooo`;o0?oo9_ooool4o`1VobOooooo0olc0?laooooo`03o`000?oooooooooo03Gooooo00?o0000
ooooooooool01?ooool00omgMgOoc<c<o`00000cooooo`000_ooool01Ol0003ooooooooooooooooo
000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo02Cooooo0ol0
000Iooooo`03o`000?oooooooooo00Kooooo0ol0oolUooooo`?o06Ko:?ooool3oc<0obSooooo0_o<
0?l;ooooo`03o`000?oooooooooo03Cooooo0_l00005ooooo`03onk^k_m4A4Co000003?ooooo0002
ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`07ooooo`03o`000?oo
oooooooo027ooooo0ol0000Mooooo`03o`000?oooooooooo00;ooooo0ol0oolUooooo`?o06Ko:?oo
ool3oc<0obSooooo0oo<0?l=ooooo`03o`000?oooooooooo03?ooooo00Co0000oooooooooooo0000
1Oooool00omgMgOo0000ooooo`0booooo`000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo
00?o0000ooooooooool01oooool2o`0001oooooo0ol0000Qooooo`04o`000?oooooo0?ooo`3oobGo
oooo0ol0I_lYooooo`;o<`3o:?ooool3ol`0oa7ooooo00?o0000ooooooooool0=Oooool00ol0003o
ooooooooo`0hooooo`000_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03
o`000?oooooooooo01cooooo0ol0000Sooooo`?o0?oo9Oooool2o`1VobWooooo0olc0?lWooooo`?o
c03o5Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo03Oooooo000Looooo`03o`00
0?oooooooooo01Wooooo0ol0000Sooooo`?o0?oo0oooool00ol0003oooooooooo`0Oooooo`?o06Ko
:?ooool3oc<0obOooooo0oo<0?lIooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0
=_ooool001cooooo00?o0000ooooooooool05oooool2o`0002Gooooo00?o0?ooooooooooool01Ooo
ool00ol0003oooooooooo`0Kooooo`?o06Ko9oooool4oc<0obOooooo0oo<0?lMooooo`03o`000?oo
oooooooo03Gooooo00?o0000ooooooooool0=Oooool001cooooo0_l0000Eooooo`?o0000<?ooool0
0ol0003oooooooooo`0Gooooo`?o06Ko9_ooool4oc<0obSooooo0oo<0?lQooooo`03o`000?oooooo
oooo03Cooooo00?o0000ooooooooool0=Oooool001cooooo00?o0000ooooooooool04Oooool3o`00
03Cooooo00?o0000ooooooooool04oooool3o`1VobKooooo0olc0?lYooooo`?oc03o9?ooool00ol0
003oooooooooo`0eooooo`03o`000?oooooooooo03Cooooo000Looooo`03o`000?oooooooooo00ko
oooo0ol0000hooooo`03o`000?oooooooooo00oooooo0ol0I_lVooooo`?o<`3o:Oooool3ol`0obSo
oooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0cooooo`007?ooool00ol0003ooooo
ooooo`0;ooooo`?o0000??ooool00ol0003oooooooooo`0<ooooo`;o06Ko9_ooool3oc<0obSooooo
1?o<0?l/ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0<_ooool001cooooo0_l0
000:ooooo`;o0000@?ooool00ol0003oooooooooo`08ooooo`?o06Ko9Oooool3oc<0obKooooo1Oo<
0?laooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0<_ooool001_ooooo0_l00008
ooooo`?o0000@oooool00ol0003oooooooooo`04ooooo`?o06Ko9Oooool3oc<0obKooooo0oo<0?lg
ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0<Oooool001_ooooo00?o0000oooo
ooooool01?ooool3o`0004Oooooo00?o0000ooooooooool00ol0I_lUooooo`?o<`3o9_ooool3ol`0
oc_ooooo00?o0000ooooooooool0<oooool2o`0003;ooooo000Kooooo`04o`000?oooooooooooooo
o`?o0000BOooool4o`1VobKooooo0_lc0?lVooooo`?oc03o:oooool2ool0VA7ooooo00?o0000oooo
ooooool0=Oooool00ol0003oooooooooo`0_ooooo`006oooool4o`0004Wooooo0ol0I_l3ooooo`03
o`000?oooooooooo027ooooo0olc0?lVooooo`;oc03o:oooool3ool0VACooooo00?o0000oooooooo
ool0=?ooool00ol0003oooooooooo`0_ooooo`006oooool2o`0004Sooooo0ol0I_l7ooooo`03o`00
0?oooooooooo01gooooo0olc0?lVooooo`?oc03o:_ooool3ool0VASooooo00?o0000ooooooooool0
=?ooool00ol0003oooooooooo`0^ooooo`004Oooool4o`000003oa0@4?oooooooooo00Gooooo00?o
0000ooooooooool0@_ooool3o`1Vo`_ooooo00?o0000ooooooooool06_ooool2oc<0obKooooo0oo<
0?lZooooo`?oo`2I7?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02gooooo000C
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0@?ooool00ol0I_ooooooooooo`0=
ooooo`03o`000?oooooooooo01Kooooo0olc0?lTooooo`Coc03o:_ooool3ool0VB3ooooo00?o0000
ooooooooool0=?ooool00ol0003oooooooooo`0/ooooo`004oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo053ooooo00?o0000ooooooooool04_ooool3oc<0ob?ooooo1?o<0?l[oooo
o`?oo`2I9?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02cooooo000Cooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0>ooooo`?o
<`3o8oooool3ol`0ob_ooooo1?oo09TWooooo`03o`000?oooooooooo03Cooooo00?o0000oooooooo
ool0:oooool001?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1@ooooo`03o`00
0?oooooooooo00Wooooo1?lc0?lSooooo`?oc03o:Oooool5ool0VBcooooo00?o0000ooooooooool0
=?ooool00ol0003oooooooooo`0Zooooo`004oooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo053ooooo00?o0000ooooooooool01Oooool3oc<0obCooooo0oo<0?lWooooo`Goo`2I<_oo
ool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02Wooooo000Cooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool0D?ooool01?l0003oooooooooooooool3oc<0obCooooo0oo<
0?lUooooo`Goo`2I>?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02Sooooo000A
ooooo`03oeEEEOmVIVKo0000013ooooo00?o0000ooooooooool0D?ooool3oc<0obCooooo0oo<0?lU
ooooo`?oo`2I?_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02Sooooo000Uoooo
o`03o`000?oooooooooo04gooooo0_lc0?l00ooooooo0000ooooo`0Qooooo`?oc03o9Oooool3ool0
VD;ooooo00?o0000ooooooooool0<_ooool2o`0002Wooooo000Vooooo`;o0000B_ooool3oc<0o`Co
oooo00?o0000ooooooooool07Oooool2ol`0obGooooo0ooo09U5ooooo`03o`000?oooooooooo03Co
oooo00?o0000ooooooooool09_ooool002Sooooo00?o0000ooooooooool0A?ooool3oc<0o`Oooooo
00?o0000ooooooooool06_ooool3ol`0obCooooo0ooo09T^ooooo`?oo`006?ooool00ol0003ooooo
ooooo`0dooooo`03o`000?oooooooooo02Gooooo000Yooooo`03o`000?oooooooooo047ooooo0_lc
0?l;ooooo`03o`000?oooooooooo01Kooooo0oo<0?lRooooo`Goo`2I;_ooool3ool001cooooo00?o
0000ooooooooool0<oooool00ol0003oooooooooo`0Uooooo`00:_ooool00ol0003oooooooooo`0m
ooooo`?o<`3o3_ooool00ol0003oooooooooo`0Cooooo`;oc03o8_ooool3ool0VC3ooooo0ooo000P
ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool09?ooool002_ooooo00?o0000oooo
ooooool0>Oooool3oc<0oa;ooooo00?o0000ooooooooool03oooool3ol`0ob7ooooo0ooo09T_oooo
o`Coo`009?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02?ooooo000/ooooo`03
o`000?oooooooooo03Oooooo00?o<`3oooooooooool05?ooool00ol0003oooooooooo`0;ooooo`?o
c03o8Oooool3ool0VBgooooo1Ooo000Yooooo`03o`000?oooooooooo03?ooooo00?o0000oooooooo
ool08_ooool002gooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`08ooooo`;oc03o
8Oooool3ool0VBcooooo1?oo000^ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0
8_ooool002kooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`04ooooo`?oc03o7ooo
ool4ool0VB[ooooo1Ooo000cooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool08Ooo
ool002oooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`03ol`0oaoooooo0ooo09TY
ooooo`Goo`00>Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo023ooooo000`oooo
o`03o`000?oooooooooo04kooooo0_o<0?lOooooo`?oo`2I9oooool5ool003oooooo00?o0000oooo
ooooool0<oooool00ol0003oooooooooo`0Oooooo`00<Oooool2o`0004_ooooo0oo<0?l00ooooooo
0000ooooo`0Kooooo`?oo`2I9_ooool4ool004Gooooo00?o0000ooooooooool0<_ooool2o`00023o
oooo000cooooo`03o`000?oooooooooo04Gooooo0oo<0?l5ooooo`03o`000?oooooooooo01Oooooo
0_oo09TTooooo`Goo`00B_ooool00ol0003oooooooooo`0aooooo`;o00008?ooool003Cooooo00?o
0000ooooooooool0@Oooool3ol`0o`Wooooo00?o0000ooooooooool04oooool3ool0VB;ooooo1?oo
001?ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool07Oooool003Gooooo00?o0000
ooooooooool0??ooool4ol`0o`gooooo00?o0000ooooooooool03oooool3ool0VB7ooooo1?oo001D
ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool07?ooool003Kooooo00?o0000oooo
ooooool0>?ooool3ol`0oa;ooooo00?o0000ooooooooool03?ooool2ool0VB3ooooo1?oo001Ioooo
o`03o`000?oooooooooo03;ooooo00?o0000ooooooooool07?ooool003Oooooo00?o0000oooooooo
ool0=?ooool3ol`0oaKooooo00?o0000ooooooooool02?ooool3ool0VAgooooo1Ooo001Nooooo`03
o`000?oooooooooo03;ooooo00?o0000ooooooooool06oooool003Sooooo00?o0000ooooooooool0
<?ooool3ol`0oa[ooooo00?o0000ooooooooool01?ooool3ool0VAgooooo0ooo001Tooooo`03o`00
0?oooooooooo03;ooooo00?o0000ooooooooool01oooool01Oo^k^ko<S8bo`000?l@413oc<c<00ko
oooo000iooooo`03o`000?oooooooooo02kooooo00?oc03oooooooooool07?ooool01?l0003ooooo
ooooooooool2ool0VAgooooo0ooo001Xooooo`03o`000?oooooooooo03;ooooo00?o0000oooooooo
ool01_ooool01OmEEEGoMgMgoooooonHV9So8B4Q00kooooo000jooooo`03o`000?oooooooooo04go
oooo0ooo09TLooooo`?oo`00Joooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Go
oooo00Go0000ooooooooooooooooo`00000>ooooo`00>oooool00ol0003oooooooooo`19ooooo`?o
o`2I00?oooooo`000?ooool06_ooool2ool006oooooo00?o0000ooooooooool0<_ooool00ol0003o
ooooooooo`05ooooo`05o`000?nHV9SooooooiRHV?lQ8B403_ooool003cooooo00?o0000oooooooo
ool0A_ooool2ool0V@Gooooo00?o0000ooooooooool05Oooool3ool007;ooooo00?o0000oooooooo
ool0<_ooool00ol0003oooooooooo`04ooooo`05o`000?mEEEGo0000oa0@4?o<c<`03_ooool003go
oooo0_l00013ooooo`?oo`2I2?ooool00ol0003oooooooooo`0Booooo`;oo`00M_ooool00ol0003o
ooooooooo`0booooo`;o00001?ooool00omEEEGoQhN7ooooo`0@ooooo`00?oooool00ol0003ooooo
ooooo`0nooooo`;oo`2I3?ooool00ol0003oooooooooo`0?ooooo`;oo`00NOooool00ol0003ooooo
ooooo`0_ooooo`;o000000?oooooo`000?ooool00oooool00ooMgMgo410@oiRHV00@ooooo`00@?oo
ool00ol0003oooooooooo`0kooooo`;oo`2I3oooool00ol0003oooooooooo`0;ooooo`?oo`00O?oo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00?ooooo00Coc<c<odA4A?l0003o410@
3_ooool0047ooooo00?o0000ooooooooool0=oooool3ool0VA;ooooo00?o0000ooooooooool01ooo
ool3ool007oooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Dooooo`00@_ooool0
0ol0003oooooooooo`0cooooo`?oo`2I5_ooool00ol0003oooooooooo`04ooooo`;oo`00Poooool0
0ol0003oooooooooo`0booooo`03o`000?oooooooooo01?ooooo0013ooooo`03o`000?oooooooooo
033ooooo0_oo09TJooooo`03o`000?oooooooooo00?oo`00Q_ooool00ol0003oooooooooo`0boooo
o`03o`000?oooooooooo01;ooooo0014ooooo`03o`000?oooooooooo02cooooo0ooo09TMooooo`;o
o`00R_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo01;ooooo0015ooooo`03o`00
0?oooooooooo02Sooooo0ooo09TNooooo`;oo`0000?oooooo`000?ooool0R_ooool00ol0003ooooo
ooooo`0aooooo`03o`000?oooooooooo017ooooo0016ooooo`03o`000?oooooooooo02Kooooo00?o
o`2Iooooooooool07?ooool3ool000Cooooo00?o0000ooooooooool0ROooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo013ooooo0017ooooo`03o`000?oooooooooo047ooooo0ooo0008
ooooo`03o`000?oooooooooo08Sooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0?
ooooo`00B?ooool2o`0003oooooo0_oo000<ooooo`03o`000?oooooooooo08Sooooo00?o0000oooo
ooooool0<Oooool00ol0003oooooooooo`0?ooooo`00B_ooool00ol0003oooooooooo`0jooooo`;o
o`003oooool00ol0003oooooooooo`28ooooo`03o`000?oooooooooo037ooooo0_l0000?ooooo`00
Boooool00ol0003oooooooooo`0hooooo`03ool00?oooooooooo013ooooo00?o0000ooooooooool0
R?ooool00ol0003oooooooooo`0`ooooo`;o00003oooool004cooooo00?o0000ooooooooool0=Ooo
ool2ool001Cooooo00?o0000ooooooooool0R?ooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo00cooooo001=ooooo`03o`000?oooooooooo03;ooooo0_oo000Gooooo`03o`000?oooooo
oooo08Sooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0;ooooo`00C_ooool00ol0
003oooooooooo`0^ooooo`?oo`006_ooool00ol0003oooooooooo`27ooooo`03o`000?oooooooooo
037ooooo00?o0000ooooooooool02oooool004oooooo00?o0000ooooooooool0:_ooool3ool001ko
oooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00[o
oooo001@ooooo`03o`000?oooooooooo02Oooooo0_oo000Rooooo`03o`000?oooooooooo08Oooooo
00?o0000ooooooooool0<Oooool00ol0003oooooooooo`09ooooo`00DOooool00ol0003ooooooooo
o`0Sooooo`?oo`009Oooool00ol0003oooooooooo`27ooooo`03o`000?oooooooooo037ooooo00?o
0000ooooooooool02?ooool005;ooooo00?o0000ooooooooool08?ooool2ool002Wooooo00?o0000
ooooooooool0Qoooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Sooooo001Coooo
o`;o00007oooool00ooo003oooooooooo`0Zooooo`03o`000?oooooooooo08Oooooo00?o0000oooo
ooooool0<?ooool00ol0003oooooooooo`07ooooo`00EOooool00ol0003oooooooooo`1:ooooo`03
o`000?oooooooooo08Kooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`06ooooo`00
E_ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo08Kooooo00?o0000ooooooooool0
;oooool3o`0000Oooooo001Gooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0Q_oo
ool00ol0003oooooooooo`0[ooooo`?o00000_ooool00ol0003oooooooooo`05ooooo`00F?ooool0
0ol0003oooooooooo`1:ooooo`03o`000?oooooooooo08Kooooo00?o0000ooooooooool09oooool3
o`0000Gooooo00?o0000ooooooooool01Oooool005Wooooo00?o0000ooooooooool0B_ooool00ol0
003oooooooooo`26ooooo`03o`000?oooooooooo02;ooooo1?l00008ooooo`03o`000?oooooooooo
00Gooooo001Jooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0Q_ooool00ol0003o
ooooooooo`0Nooooo`?o00003?ooool00ol0003oooooooooo`05ooooo`00Foooool00ol0003ooooo
ooooo`1:ooooo`03o`000?oooooooooo08Gooooo00?o0000ooooooooool06_ooool4o`0000oooooo
00?o0000ooooooooool01Oooool005cooooo00?o0000ooooooooool0B_ooool00ol0003ooooooooo
o`25ooooo`03o`000?oooooooooo01Kooooo0ol0000Dooooo`03o`000?oooooooooo00Cooooo001M
ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`0B
ooooo`?o00005oooool00ol0003oooooooooo`04ooooo`00G_ooool2o`0004_ooooo00?o0000oooo
ooooool0QOooool00ol0003oooooooooo`0=ooooo`Co00006_ooool00ol0003oooooooooo`04oooo
o`00H?ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo08Gooooo00?o0000oooooooo
ool02Oooool3o`0001kooooo00?o0000ooooooooool01?ooool0067ooooo00?o0000ooooooooool0
BOooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo00Cooooo1?l0000Qooooo`03o`00
0?oooooooooo00Cooooo001Rooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0Q?oo
ool01?l0003oooooooooooooool3o`0002Gooooo00?o0000ooooooooool01?ooool006?ooooo00?o
0000ooooooooool0BOooool00ol0003oooooooooo`24ooooo`?o0000:?ooool00ol0003ooooooooo
o`04ooooo`00I?ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo07oooooo1?l00000
0ooooooo0000ooooo`0Xooooo`03o`000?oooooooooo00Cooooo001Uooooo`03o`000?oooooooooo
04Wooooo00?o0000ooooooooool0Noooool3o`0000Kooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`04ooooo`00I_ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo07Ko
oooo1?l0000:ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool01?ooool006Oooooo
00?o0000ooooooooool0BOooool00ol0003oooooooooo`1booooo`?o00003oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo00?ooooo001Xooooo`03o`000?oooooooooo04Wooooo00?o
0000ooooooooool0K_ooool3o`0001;ooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`03ooooo`00JOooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo06Wooooo1?l0000F
ooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool00oooool006[ooooo0_l0001:oooo
o`03o`000?oooooooooo06Gooooo0ol0000Kooooo`03o`000?oooooooooo02?ooooo00?o0000oooo
ooooool00oooool006cooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`1Pooooo`Co
00007oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00?ooooo001]ooooo`03o`00
0?oooooooooo04Sooooo00?o0000ooooooooool0G?ooool3o`0002Cooooo00?o0000ooooooooool0
8Oooool00ol0003oooooooooo`03ooooo`00K_ooool00ol0003oooooooooo`18ooooo`03o`000?oo
oooooooo05Sooooo0ol0000Xooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool00ooo
ool006oooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`1Cooooo`Co0000:oooool0
0ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00?ooooo001`ooooo`03o`000?oooooooooo
04Sooooo00?o0000ooooooooool0Coooool3o`00033ooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`03ooooo`00LOooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo04[o
oooo1?l0000dooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool00oooool007;ooooo
00?o0000ooooooooool0B?ooool00ol0003oooooooooo`16ooooo`?o0000>Oooool00ol0003ooooo
ooooo`0Nooooo`03o`000?oooooooooo00;ooooo001cooooo`03o`000?oooooooooo04Sooooo00?o
0000ooooooooool0@_ooool3o`0003gooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`02ooooo`00M?ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo03gooooo1?l00011
ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool00_ooool007Gooooo0_l00019oooo
o`03o`000?oooooooooo03Wooooo0ol00015ooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool00_ooool007Oooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0dooooo`Co
0000BOooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00;ooooo001hooooo`03o`00
0?oooooooooo04Oooooo00?o0000ooooooooool0<?ooool3o`0004kooooo00?o0000ooooooooool0
6_ooool00ol0003oooooooooo`02ooooo`00NOooool00ol0003oooooooooo`17ooooo`03o`000?oo
oooooooo02cooooo0ol0001Booooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool00_oo
ool007[ooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Wooooo`Co0000E_ooool0
0ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00;ooooo001kooooo`03o`000?oooooooooo
04Oooooo00?o0000ooooooooool08oooool3o`0005_ooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`02ooooo`00O?ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo01ko
oooo1?l0001Nooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool00_ooool007gooooo
00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Jooooo`?o0000Hoooool00ol0003ooooo
ooooo`0Gooooo`03o`000?oooooooooo007ooooo001nooooo`03o`000?oooooooooo04Oooooo00?o
0000ooooooooool05_ooool3o`0006Oooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`01ooooo`00Ooooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo017ooooo1?l0001[
ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool00Oooool0083ooooo0_l00018oooo
o`03o`000?oooooooooo00gooooo0ol0001`ooooo`03o`000?oooooooooo01Cooooo00?o0000oooo
ooooool00Oooool008;ooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`08ooooo`Co
0000M?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo007ooooo0023ooooo`03o`00
0?oooooooooo04Kooooo00?o0000ooooooooool01?ooool3o`0007Sooooo00?o0000ooooooooool0
4oooool00ol0003oooooooooo`01ooooo`00Q?ooool00ol0003oooooooooo`16ooooo`03o`000?oo
oooooooo00?o0000O?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo007ooooo0025
ooooo`03o`000?oooooooooo04Kooooo0_l00020ooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool00Oooool008Kooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`20oooo
o`03o`000?oooooooooo013ooooo00?o0000ooooooooool00Oooool008Oooooo00?o0000oooooooo
ool0A?ooool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool00Oooool008Sooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`22ooooo`03o`00
0?oooooooooo00oooooo0Ol00001ooooo`7ooooo0029ooooo`03o`000?oooooooooo04;ooooo00?o
0000ooooooooool0P_ooool00ol0003oooooooooo`0?ooooo`7o00000Oooool1ooooo`00R_ooool0
0ol0003oooooooooo`11ooooo`03o`000?oooooooooo08?ooooo00?o0000ooooooooool03_ooool1
o`00007ooooo0Oooool008_ooooo0_l00011ooooo`03o`000?oooooooooo08Cooooo00?o0000oooo
ooooool03Oooool1o`00007ooooo0Oooool008gooooo00?o0000ooooooooool0?_ooool00ol0003o
ooooooooo`25ooooo`03o`000?oooooooooo00cooooo0Ol00001ooooo`7ooooo002>ooooo`03o`00
0?oooooooooo03gooooo00?o0000ooooooooool0Q_ooool00ol0003oooooooooo`0;ooooo`7o0000
0Oooool1ooooo`00Soooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo08Oooooo00?o
0000ooooooooool02_ooool1o`00007ooooo0Oooool0093ooooo00?o0000ooooooooool0>oooool0
0ol0003oooooooooo`27ooooo`03o`000?oooooooooo00[ooooo0Ol00001ooooo`7ooooo002Aoooo
o`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0R?ooool00ol0003oooooooooo`09oooo
o`7o00000Oooool1ooooo`00T_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo08Wo
oooo00?o0000ooooooooool02?ooool1o`00007ooooo0Oooool009?ooooo00?o0000ooooooooool0
>?ooool00ol0003oooooooooo`2:ooooo`03o`000?oooooooooo00Sooooo0Ol00001ooooo`00U?oo
ool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo08_ooooo00?o0000ooooooooool01ooo
ool1o`00007ooooo002Eooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0S?ooool0
0ol0003oooooooooo`06ooooo`7o00000Oooool009Kooooo00?o0000ooooooooool0=Oooool00ol0
003oooooooooo`2<ooooo`03o`000?oooooooooo00Kooooo0Ol00001ooooo`00Uoooool2o`0003Go
oooo00?o0000ooooooooool0SOooool00ol0003oooooooooo`05ooooo`7o00000Oooool009Wooooo
00?o0000ooooooooool0<_ooool00ol0003oooooooooo`2>ooooo`03o`000?oooooooooo00Cooooo
0Ol00001ooooo`00V_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo08oooooo00?o
0000ooooooooool00oooool1o`00007ooooo002Kooooo`03o`000?oooooooooo033ooooo00?o0000
ooooooooool0T?ooool00ol0003oooooooooo`02ooooo`7o00000Oooool009cooooo00?o0000oooo
ooooool0;oooool00ol0003oooooooooo`2Aooooo`05o`000?ooooooooooooooool000000Oooool0
09gooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`2Aooooo`05o`000?oooooooooo
ooooool000000Oooool009kooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`2Boooo
o`04o`000?ooooooooooooooo`7o0000002Oooooo`03o`000?oooooooooo02cooooo00?o0000oooo
ooooool0Toooool00ol0003oooooooooo`01o`000000X?ooool00ol0003oooooooooo`0[ooooo`03
o`000?oooooooooo09Cooooo0Ol00001ooooo`7o0000002Qooooo`03o`000?oooooooooo02[ooooo
00?o0000ooooooooool0UOooool2o`000000X_ooool2o`0002[ooooo00?o0000ooooooooool0U?oo
ool3o`000000Y?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo093ooooo1?l00003
ooooo`00YOooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo08gooooo0ol00007oooo
o`00Y_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo08Wooooo1?l0000:ooooo`00
Yoooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo08Gooooo1?l0000>ooooo`00Z?oo
ool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo08;ooooo0ol0000Booooo`00ZOooool0
0ol0003oooooooooo`0Rooooo`03o`000?oooooooooo07kooooo1?l0000Eooooo`00Z_ooool00ol0
003oooooooooo`0Qooooo`03o`000?oooooooooo07[ooooo1?l0000Iooooo`00Zoooool00ol0003o
ooooooooo`0Qooooo`03o`000?oooooooooo07Gooooo1?l0000Mooooo`00[?ooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo07;ooooo0ol0000Qooooo`00[Oooool2o`00023ooooo00?o
0000ooooooooool0K_ooool4o`0002Cooooo002_ooooo`03o`000?oooooooooo01gooooo00?o0000
ooooooooool0J_ooool4o`0002Sooooo002`ooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool0Ioooool3o`0002cooooo002aooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool0Hoooool4o`0002oooooo002booooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0
Goooool4o`0003?ooooo002cooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0G?oo
ool3o`0003Oooooo002dooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0F?ooool4
o`0003[ooooo002eooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0E?ooool4o`00
03kooooo002fooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0D?ooool4o`0004;o
oooo002gooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0COooool3o`0004Kooooo
002hooooo`;o00005Oooool00ol0003oooooooooo`19ooooo`Co0000BOooool00;[ooooo00?o0000
ooooooooool04_ooool00ol0003oooooooooo`15ooooo`Co0000COooool00;_ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`12ooooo`?o0000DOooool00;cooooo00?o0000oooooooo
ool04?ooool00ol0003oooooooooo`0nooooo`Co0000E?ooool00;gooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`0jooooo`Co0000F?ooool00;kooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`0fooooo`Co0000G?ooool00;oooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`0cooooo`?o0000H?ooool00<3ooooo00?o0000ooooooooool03?ooool00ol0
003oooooooooo`0_ooooo`Co0000Hoooool00<7ooooo00?o0000ooooooooool02oooool00ol0003o
ooooooooo`0[ooooo`Co0000Ioooool00<;ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`0Xooooo`?o0000Joooool00<?ooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0Tooooo`Co0000K_ooool00<Cooooo0_l00009ooooo`03o`000?oooooooooo023ooooo1?l0001b
ooooo`00a_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01gooooo0ol0001foooo
o`00aoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Wooooo1?l0001iooooo`00
b?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Gooooo1?l0001mooooo`00bOoo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo1?l00021ooooo`00b_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00kooooo0ol00025ooooo`00boooool01Ol0
003ooooooooooooooooo000000cooooo1?l00028ooooo`00c?ooool01?l0003oooooooooool00008
ooooo`Co0000S?ooool00<gooooo00?o0000ooooool000001Oooool3o`00093ooooo003>ooooo`;o
000000?oooooo`000?l000000_l0002Cooooo`00coooool2o`0009Oooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {330.375, 0}} -> {-0.0771432, -0.0315529, \
0.00350368, 0.00350368}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .92059 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-16 1.0763 -0.0263982 1.0763 [
[.01694 .18568 -11.9631 -9 ]
[.01694 .18568 .03693 0 ]
[.13793 .13897 -11.619 -9 ]
[.13793 .13897 .38095 0 ]
[.26292 .09073 -5.63752 -9 ]
[.26292 .09073 .36248 0 ]
[.39212 .04087 -5.46552 -9 ]
[.39212 .04087 .53448 0 ]
[.52574 -0.01069 -5.29351 -9 ]
[.52574 -0.01069 .70649 0 ]
[.58272 .04263 0 -6.19654 ]
[.58272 .04263 6 2.80346 ]
[.71715 .21863 0 -6.07114 ]
[.71715 .21863 6 2.92886 ]
[.83675 .37523 0 -5.963 ]
[.83675 .37523 6 3.037 ]
[.94385 .51546 0 -5.8688 ]
[.94385 .51546 6 3.1312 ]
[.01386 .20006 -12 -2.76892 ]
[.01386 .20006 0 6.23108 ]
[.00748 .25499 -24 -2.80073 ]
[.00748 .25499 0 6.19927 ]
[.00093 .31131 -6 -2.83339 ]
[.00093 .31131 0 6.16661 ]
[-0.00579 .36907 -18 -2.86695 ]
[-0.00579 .36907 0 6.13305 ]
[-0.01268 .42831 -6 -2.90143 ]
[-0.01268 .42831 0 6.09857 ]
[ 0 0 0 0 ]
[ 1 .92059 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02642 .19522 m
.53391 0 L
s
.02642 .19522 m
.03116 .2 L
s
[(-2)] .01694 .18568 .99384 1 Mshowa
.14712 .14879 m
.15172 .1537 L
s
[(-1)] .13793 .13897 .93651 1 Mshowa
.2718 .10083 m
.27624 .10588 L
s
[(0)] .26292 .09073 .87917 1 Mshowa
.40066 .05126 m
.40493 .05646 L
s
[(1)] .39212 .04087 .82184 1 Mshowa
.53391 0 m
.538 .00534 L
s
[(2)] .52574 -0.01069 .7645 1 Mshowa
.125 Mabswid
.05025 .18606 m
.05308 .18894 L
s
.07424 .17683 m
.07705 .17973 L
s
.09837 .16755 m
.10117 .17046 L
s
.12267 .1582 m
.12545 .16113 L
s
.17173 .13933 m
.17447 .14229 L
s
.19651 .1298 m
.19923 .13278 L
s
.22144 .1202 m
.22414 .1232 L
s
.24654 .11055 m
.24922 .11356 L
s
.29723 .09105 m
.29988 .0941 L
s
.32283 .0812 m
.32546 .08427 L
s
.3486 .07129 m
.35121 .07437 L
s
.37455 .06131 m
.37713 .06441 L
s
.42695 .04115 m
.4295 .04428 L
s
.45342 .03096 m
.45594 .03412 L
s
.48007 .02071 m
.48257 .02388 L
s
.5069 .01039 m
.50938 .01358 L
s
.25 Mabswid
.53391 0 m
.9804 .58403 L
s
.57014 .04738 m
.56384 .04975 L
s
[(0)] .58272 .04263 -1 .37701 Mshowa
.70445 .22307 m
.6981 .22529 L
s
[(2)] .71715 .21863 -1 .34914 Mshowa
.82396 .37939 m
.81756 .38147 L
s
[(4)] .83675 .37523 -1 .32511 Mshowa
.93098 .51938 m
.92454 .52134 L
s
[(6)] .94385 .51546 -1 .30418 Mshowa
.125 Mabswid
.60525 .09331 m
.60147 .09471 L
s
.63931 .13786 m
.63552 .13924 L
s
.67236 .1811 m
.66856 .18245 L
s
.73562 .26383 m
.7318 .26514 L
s
.7659 .30345 m
.76207 .30473 L
s
.79534 .34195 m
.7915 .34322 L
s
.85181 .41581 m
.84796 .41704 L
s
.87891 .45126 m
.87506 .45247 L
s
.90529 .48577 m
.90143 .48696 L
s
.95601 .55212 m
.95214 .55328 L
s
.25 Mabswid
.02642 .19522 m
0 .42381 L
s
.02642 .19522 m
.0327 .19281 L
s
[(-1)] .01386 .20006 1 -0.38468 Mshowa
.02006 .25024 m
.02635 .24786 L
s
[(-0.5)] .00748 .25499 1 -0.37762 Mshowa
.01354 .30664 m
.01985 .3043 L
s
[(0)] .00093 .31131 1 -0.37036 Mshowa
.00686 .36448 m
.01318 .36218 L
s
[(0.5)] -0.00579 .36907 1 -0.3629 Mshowa
0 .42381 m
.00634 .42156 L
s
[(1)] -0.01268 .42831 1 -0.35524 Mshowa
.125 Mabswid
.02516 .20612 m
.02893 .20468 L
s
.0239 .21707 m
.02767 .21563 L
s
.02262 .22807 m
.0264 .22664 L
s
.02135 .23913 m
.02512 .2377 L
s
.01877 .26141 m
.02255 .25999 L
s
.01747 .27263 m
.02125 .27122 L
s
.01617 .28391 m
.01995 .2825 L
s
.01486 .29525 m
.01864 .29384 L
s
.01222 .31809 m
.01601 .3167 L
s
.01089 .3296 m
.01468 .32821 L
s
.00955 .34117 m
.01334 .33978 L
s
.00821 .35279 m
.012 .35141 L
s
.0055 .37622 m
.0093 .37485 L
s
.00414 .38803 m
.00793 .38666 L
s
.00276 .39989 m
.00656 .39853 L
s
.00139 .41182 m
.00519 .41047 L
s
.25 Mabswid
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.54154 .92059 L
s
.54154 .92059 m
.5414 .7134 L
s
.5414 .7134 m
.02642 .19522 L
s
.53391 0 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.53391 0 m
.02642 .19522 L
s
.5414 .7134 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.54154 .92059 L
s
.54154 .92059 m
.5414 .7134 L
s
0 0 m
1 0 L
1 .92059 L
0 .92059 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.28345 .59255 m
.30699 .58181 L
s
1 0 .6 r
.26856 .55692 m
.29211 .54727 L
s
.8 0 1 r
.25448 .52081 m
.27818 .51198 L
s
.2 0 1 r
.24074 .48409 m
.2646 .4757 L
s
0 .4 1 r
.22704 .44683 m
.25097 .43857 L
s
0 1 1 r
.21328 .4093 m
.23722 .40097 L
s
1 0 .6 r
.29211 .54727 m
.31501 .53709 L
s
0 1 .4 r
.19947 .37163 m
.2234 .36319 L
s
.8 0 1 r
.27818 .51198 m
.30169 .50277 L
s
1 0 0 r
.30699 .58181 m
.32913 .57041 L
s
.2 0 1 r
.2646 .4757 m
.28848 .46712 L
s
.2 1 0 r
.18564 .33388 m
.20955 .32531 L
s
0 .4 1 r
.25097 .43857 m
.27502 .43021 L
s
.8 1 0 r
.17178 .29605 m
.19567 .28736 L
s
0 1 1 r
.23722 .40097 m
.26131 .39259 L
s
1 .6 0 r
.15789 .25815 m
.18176 .24933 L
s
0 1 .4 r
.2234 .36319 m
.24748 .35469 L
s
.8 0 1 r
.30169 .50277 m
.32496 .49335 L
s
.2 0 1 r
.28848 .46712 m
.31237 .45838 L
s
1 0 .6 r
.31501 .53709 m
.33728 .52674 L
s
.2 1 0 r
.20955 .32531 m
.23361 .31669 L
s
0 .4 1 r
.27502 .43021 m
.29919 .42177 L
s
1 0 0 r
.32913 .57041 m
.34997 .55905 L
s
.8 1 0 r
.19567 .28736 m
.2197 .27861 L
s
0 1 1 r
.26131 .39259 m
.28554 .38414 L
s
1 .6 0 r
.18176 .24933 m
.20577 .24045 L
s
0 1 .4 r
.24748 .35469 m
.27171 .34614 L
s
.2 0 1 r
.31237 .45838 m
.33627 .44954 L
s
.2 1 0 r
.23361 .31669 m
.25782 .30801 L
s
.8 0 1 r
.32496 .49335 m
.34809 .48391 L
s
0 .4 1 r
.29919 .42177 m
.32347 .41325 L
s
1 0 .6 r
.33728 .52674 m
.35922 .5166 L
s
.8 1 0 r
.2197 .27861 m
.24389 .2698 L
s
0 1 1 r
.28554 .38414 m
.30992 .37564 L
s
1 .6 0 r
.20577 .24045 m
.22994 .23151 L
s
1 0 0 r
.34997 .55905 m
.37031 .54823 L
s
0 1 .4 r
.27171 .34614 m
.29609 .33753 L
s
.2 1 0 r
.25782 .30801 m
.28218 .29928 L
s
.2 0 1 r
.33627 .44954 m
.36026 .44071 L
s
0 .4 1 r
.32347 .41325 m
.34788 .40468 L
s
.8 0 1 r
.34809 .48391 m
.37128 .47465 L
s
.8 1 0 r
.24389 .2698 m
.26824 .26094 L
s
0 1 1 r
.30992 .37564 m
.33446 .36708 L
s
1 0 .6 r
.35922 .5166 m
.38128 .50691 L
s
1 .6 0 r
.22994 .23151 m
.25427 .22252 L
s
0 1 .4 r
.29609 .33753 m
.32063 .32887 L
s
.2 1 0 r
.28218 .29928 m
.3067 .29049 L
s
1 0 0 r
.37031 .54823 m
.39091 .53817 L
s
.2 0 1 r
.36026 .44071 m
.38443 .43199 L
s
0 .4 1 r
.34788 .40468 m
.37245 .39609 L
s
.8 1 0 r
.26824 .26094 m
.29274 .25202 L
s
.8 0 1 r
.37128 .47465 m
.39474 .46571 L
s
0 1 1 r
.33446 .36708 m
.35915 .35848 L
s
1 .6 0 r
.25427 .22252 m
.27875 .21347 L
s
0 1 .4 r
.32063 .32887 m
.34532 .32016 L
s
1 0 .6 r
.38128 .50691 m
.40378 .49779 L
s
.2 1 0 r
.3067 .29049 m
.33138 .28164 L
s
.2 0 1 r
.38443 .43199 m
.40889 .42344 L
s
0 .4 1 r
.37245 .39609 m
.39721 .38752 L
s
1 0 0 r
.39091 .53817 m
.41222 .52894 L
s
.8 1 0 r
.29274 .25202 m
.3174 .24304 L
s
0 1 1 r
.35915 .35848 m
.384 .34983 L
s
.8 0 1 r
.39474 .46571 m
.41863 .45717 L
s
1 .6 0 r
.27875 .21347 m
.30338 .20436 L
s
0 1 .4 r
.34532 .32016 m
.37018 .31139 L
s
1 0 .6 r
.40378 .49779 m
.42693 .4893 L
s
.2 1 0 r
.33138 .28164 m
.35621 .27274 L
s
.2 0 1 r
.40889 .42344 m
.4337 .41508 L
s
0 .4 1 r
.39721 .38752 m
.4222 .37898 L
s
.8 1 0 r
.3174 .24304 m
.34221 .23401 L
s
0 1 1 r
.384 .34983 m
.40903 .34114 L
s
.8 0 1 r
.41863 .45717 m
.44308 .44906 L
s
1 0 0 r
.41222 .52894 m
.43445 .52056 L
s
1 .6 0 r
.30338 .20436 m
.32818 .1952 L
s
0 1 .4 r
.37018 .31139 m
.39519 .30256 L
s
1 0 .6 r
.42693 .4893 m
.45085 .48147 L
s
.2 1 0 r
.35621 .27274 m
.38121 .26379 L
s
.2 0 1 r
.4337 .41508 m
.45892 .40691 L
s
0 .4 1 r
.4222 .37898 m
.44743 .37046 L
s
.8 1 0 r
.34221 .23401 m
.36718 .22492 L
s
0 1 1 r
.40903 .34114 m
.43423 .33241 L
s
.8 0 1 r
.44308 .44906 m
.46816 .44134 L
s
1 0 0 r
.43445 .52056 m
.45767 .51306 L
s
1 .6 0 r
.32818 .1952 m
.35313 .18597 L
s
0 1 .4 r
.39519 .30256 m
.42037 .29368 L
s
1 0 .6 r
.45085 .48147 m
.47561 .47427 L
s
.2 1 0 r
.38121 .26379 m
.40636 .25477 L
s
.2 0 1 r
.45892 .40691 m
.48455 .39887 L
s
0 .4 1 r
.44743 .37046 m
.4729 .36194 L
s
.8 1 0 r
.36718 .22492 m
.39232 .21577 L
s
.8 0 1 r
.46816 .44134 m
.49389 .43397 L
s
1 0 0 r
.45767 .51306 m
.48192 .50642 L
s
0 1 1 r
.43423 .33241 m
.45961 .32363 L
s
1 .6 0 r
.35313 .18597 m
.37825 .17669 L
s
0 1 .4 r
.42037 .29368 m
.44571 .28475 L
s
1 0 .6 r
.47561 .47427 m
.50124 .46765 L
s
.2 1 0 r
.40636 .25477 m
.43168 .2457 L
s
.2 0 1 r
.48455 .39887 m
.51057 .39089 L
s
0 .4 1 r
.4729 .36194 m
.49859 .35339 L
s
1 0 0 r
.48192 .50642 m
.50723 .50062 L
s
.8 0 1 r
.49389 .43397 m
.52027 .42682 L
s
.8 1 0 r
.39232 .21577 m
.41762 .20656 L
s
0 1 1 r
.45961 .32363 m
.48515 .31479 L
s
1 0 .6 r
.50124 .46765 m
.52781 .46149 L
s
1 .6 0 r
.37825 .17669 m
.40353 .16734 L
s
0 1 .4 r
.44571 .28475 m
.47122 .27575 L
s
1 0 0 r
.50723 .50062 m
.53369 .49557 L
s
.2 1 0 r
.43168 .2457 m
.45717 .23656 L
s
.2 0 1 r
.51057 .39089 m
.53689 .38285 L
s
.8 0 1 r
.52027 .42682 m
.54722 .4197 L
s
0 .4 1 r
.49859 .35339 m
.52448 .34478 L
s
1 0 .6 r
.52781 .46149 m
.55531 .45555 L
s
.8 1 0 r
.41762 .20656 m
.44308 .19729 L
s
0 1 1 r
.48515 .31479 m
.51087 .3059 L
s
1 0 0 r
.53369 .49557 m
.56148 .49098 L
s
1 .6 0 r
.40353 .16734 m
.42897 .15793 L
s
0 1 .4 r
.47122 .27575 m
.49689 .2667 L
s
.8 0 1 r
.54722 .4197 m
.57458 .41242 L
s
.2 0 1 r
.53689 .38285 m
.5634 .37466 L
s
1 0 .6 r
.55531 .45555 m
.58366 .44948 L
s
.2 1 0 r
.45717 .23656 m
.48282 .22737 L
s
1 0 0 r
.56148 .49098 m
.59073 .48638 L
s
0 .4 1 r
.52448 .34478 m
.55051 .33608 L
s
.8 1 0 r
.44308 .19729 m
.46871 .18796 L
s
0 1 1 r
.51087 .3059 m
.53675 .29695 L
s
1 0 0 r
.59073 .48638 m
.62118 .48106 L
s
1 .6 0 r
.42897 .15793 m
.45458 .14847 L
s
1 0 .6 r
.58366 .44948 m
.6125 .44289 L
s
0 1 .4 r
.49689 .2667 m
.52273 .25759 L
s
.8 0 1 r
.57458 .41242 m
.6021 .40478 L
s
.2 0 1 r
.5634 .37466 m
.59001 .36628 L
s
.2 1 0 r
.48282 .22737 m
.50863 .21812 L
s
0 .4 1 r
.55051 .33608 m
.57669 .32727 L
s
1 0 0 r
.62118 .48106 m
.65184 .47457 L
s
.8 1 0 r
.46871 .18796 m
.49451 .17857 L
s
0 1 1 r
.53675 .29695 m
.5628 .28793 L
s
1 0 .6 r
.6125 .44289 m
.64128 .4356 L
s
.8 0 1 r
.6021 .40478 m
.62953 .39674 L
s
1 .6 0 r
.45458 .14847 m
.48035 .13894 L
s
0 1 .4 r
.52273 .25759 m
.54873 .24841 L
s
.2 0 1 r
.59001 .36628 m
.61664 .35771 L
s
.2 1 0 r
.50863 .21812 m
.53462 .20881 L
s
0 .4 1 r
.57669 .32727 m
.603 .31838 L
s
.8 1 0 r
.49451 .17857 m
.52047 .16912 L
s
0 1 1 r
.5628 .28793 m
.58901 .27884 L
s
1 .6 0 r
.48035 .13894 m
.5063 .12935 L
s
0 1 .4 r
.54873 .24841 m
.57491 .23918 L
s
.2 1 0 r
.53462 .20881 m
.56078 .19943 L
s
.8 1 0 r
.52047 .16912 m
.54661 .1596 L
s
1 .6 0 r
.5063 .12935 m
.53242 .11969 L
s
0 g
.25 Mabswid
.53391 0 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.53391 0 m
.02642 .19522 L
s
.02642 .19522 m
.53391 0 L
s
.02642 .19522 m
.03116 .2 L
s
[(-2)] .01694 .18568 .99384 1 Mshowa
.14712 .14879 m
.15172 .1537 L
s
[(-1)] .13793 .13897 .93651 1 Mshowa
.2718 .10083 m
.27624 .10588 L
s
[(0)] .26292 .09073 .87917 1 Mshowa
.40066 .05126 m
.40493 .05646 L
s
[(1)] .39212 .04087 .82184 1 Mshowa
.53391 0 m
.538 .00534 L
s
[(2)] .52574 -0.01069 .7645 1 Mshowa
.125 Mabswid
.05025 .18606 m
.05308 .18894 L
s
.07424 .17683 m
.07705 .17973 L
s
.09837 .16755 m
.10117 .17046 L
s
.12267 .1582 m
.12545 .16113 L
s
.17173 .13933 m
.17447 .14229 L
s
.19651 .1298 m
.19923 .13278 L
s
.22144 .1202 m
.22414 .1232 L
s
.24654 .11055 m
.24922 .11356 L
s
.29723 .09105 m
.29988 .0941 L
s
.32283 .0812 m
.32546 .08427 L
s
.3486 .07129 m
.35121 .07437 L
s
.37455 .06131 m
.37713 .06441 L
s
.42695 .04115 m
.4295 .04428 L
s
.45342 .03096 m
.45594 .03412 L
s
.48007 .02071 m
.48257 .02388 L
s
.5069 .01039 m
.50938 .01358 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 265.125},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001Bb000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00`oooool5o`000:3ooooo0033ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@0X?ooool00<Cooooo00?oV9RHob4Q8Oo^k^h0XOooool00<Gooooo00?oV9RH
ob4Q8Oo^k^h0X?ooool00<Kooooo00?oMgMgofIVI_ooool0Woooool00<Oooooo00?o0000oooooooo
ool0W_ooool00<?ooooo00Go0000okZj^_ooooooV9RHoa0@402Pooooo`00`oooool01OnHV9So410@
o`000?lQ8B7oc<c<0:3ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003;ooooo`;o0000Voooool00<Sooooo0ol000000ooooooo0000ooooo`2Jooooo`00a_oo
ool2o`0000Cooooo0_l0002Jooooo`00`oooool3o`0000Kooooo00?o0000ooooool00000VOooool0
0<3ooooo1?l00008ooooo`04o`000?ooooooooooo`0009Sooooo002Hooooo`Co000000?o410@oooo
ooooool07oooool2o`0000Cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0002H
ooooo`00V_ooool00ol0003oooooooooo`0Nooooo`?o00003_ooool01Ol0003ooooooooooooooooo
000009Oooooo002Jooooo`03o`000?oooooooooo01cooooo0_l0000Aooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0U?ooool009[ooooo00?o0000ooooooooool06Oooool3o`0000;o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo09?o
oooo002Jooooo`03o`000?oooooooooo01Kooooo0ol0000Fooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^08Kooooo002Jooooo`03o`00
0?oooooooooo01Cooooo0_l0000Iooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1oooool01OmgMgOoV9RHoooooonHV9SoMgMg08Kooooo002Jooooo`03o`000?oooooooooo017ooooo
0ol000000ooooooo0000ooooo`0Hooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1_ooool01Ol@413ooooooooooooooooo410@08Kooooo002Hooooo`03oeEEEOmVIVKo0000017ooooo
0_l0000Nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool01Ol0003ooooo
oooooooooooo000008Kooooo002Yooooo`?o00008?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000026ooooo`00Yoooool3o`0002;ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@
4100Q_ooool00:Cooooo0ol00002ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Q_ooool00:7ooooo
0ol0000Xooooo`03o`000?oooooooooo00Sooooo0_l00004ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h0Q_ooool009oooooo0_l0000[ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo
0000S_ooool009cooooo0ol000000ooooooo0000ooooo`0Zooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0S?ooool009[ooooo0_l00005ooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`2;ooooo`00Uoooool3o`0003;ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`2:ooooo`00K?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^02?ooooo0ol000000ooooooo0000ooooo`0booooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0ROooool006cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Qooooo`;o0000>?ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo08Wooooo001/ooooo`05oa0@4?oooooooooo
ooooool@41007_ooool3o`0003[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`28
ooooo`00K?ooool01Ol0003ooooooooooooooooo000001cooooo0ol0000looooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0Qoooool006cooooo00Go0000ooooooooooooooooo`00000I
ooooo`?o00000_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool0Q_ooool006cooooo00Go410@oooooooooooooooooa0@400Gooooo`;o0000@_ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo08Kooooo001/ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL05?ooool3o`0004Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`25
ooooo`00K?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^017ooooo0ol00002ooooo`03o`000?oooooo
oooo04;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`24ooooo`00P?ooool2o`00
04[ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`23ooooo`00OOooool3o`0004co
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`22ooooo`00Noooool2o`000003oooo
ool0003ooooo04cooooo00?o0000ooooooooool05?ooool2o`0008?ooooo001hooooo`?o0000DOoo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooo000008?ooooo001eooooo`?o0000E?ooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo083ooooo001cooooo`Co0000EOooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo07oooooo001`ooooo`?o00001?ooool00ol0003o
ooooooooo`1Booooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0Ooooool006kooooo
0_l0001Looooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0O_ooool004?ooooo1?l0
00000ol@413oooooooooo`0Qooooo`?o0000G_ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo07gooooo0015ooooo`03o`000?oooooooooo023ooooo0ol00003ooooo`03o`000?oooooo
oooo05_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1looooo`00>_ooool6o`00
00Gooooo00?o0000ooooooooool07_ooool2o`0006Cooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`1looooo`00AOooool00ol0003oooooooooo`0Kooooo`?o0000IOooool00oooV@3o
0000ooooo`0Looooo`03o`000?oooooooooo07_ooooo0015ooooo`03o`000?oooooooooo01Wooooo
0_l00002ooooo`03o`000?oooooooooo063ooooo0oooV@000ooooooo0000ooooo`0Mooooo`03o`00
0?oooooooooo07[ooooo0015ooooo`03o`000?oooooooooo01Kooooo0ol0001Tooooo`?ooiT01?oo
ool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo07Wooooo0015ooooo`03o`000?oooooo
oooo01Cooooo0_l0001Tooooo`?ooiT01oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooo
oooo07Wooooo0013ooooo`03oeEEEOmVIVKo000001?ooooo0ol000000ooooooo0000ooooo`1Poooo
o`?ooiT02_ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo07Sooooo001Fooooo`?o
0000Hoooool3oonI00gooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`1gooooo`00
E?ooool2o`0006?ooooo0oooV@0@ooooo`03o`000?oooooooooo01oooooo0_l0001hooooo`00DOoo
ool3o`000003ooooool0003ooooo05oooooo0oooV@0Cooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool0M_ooool004oooooo0_l0001Rooooo`?ooiT05_ooool00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo07Gooooo001<ooooo`?o0000H_ooool2oonI01Wooooo00?o0000oooo
ooooool08_ooool00ol0003oooooooooo`1dooooo`00BOooool4o`00067ooooo0oooV@0Kooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool0Loooool004Oooooo0_l00004ooooo`03o`00
0?oooooooooo05_ooooo0oooV@0Nooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0
L_ooool004Cooooo0ol0001Qooooo`?ooiT08Oooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo07;ooooo000Jooooo`Go00008oooool3o`00067ooooo0_ooV@0Tooooo`03o`000?oooooo
oooo00;oc?l08oooool00ol0003oooooooooo`1aooooo`006_ooool01OnHV9So8B4Qonk^k_oooooo
A4A4023ooooo0ol00003ooooo`03o`000?oooooooooo05cooooo0_ooV@0Vooooo`03o`000?o<o`3o
c?l002Kooooo00?o0000ooooooooool0L?ooool001;ooooo1_l00003ooooo`03oiRHV?lQ8B7ok^k^
01oooooo0_l0001Sooooo`;ooiT09Oooool3olco0003o`000?oooooooooo02Oooooo00?o0000oooo
ooooool0Koooool001cooooo00?oV9RHob4Q8Oo^k^h06oooool3o`0006?ooooo0_ooV@0Uooooo`;o
c?l00oooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo06oooooo000Mooooo`03ogMg
MomVIVKooooo01Oooooo0ol00003ooooo`03o`000?oooooooooo05gooooo0oooV@0Tooooo`?oc?l0
1Oooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo06kooooo000Nooooo`03o`000?oo
oooooooo01Cooooo0_l0001Sooooo`?ooiT09?ooool3olco00Sooooo00?o0000ooooooooool0:Ooo
ool00ol0003oooooooooo`1]ooooo`006_ooool01Ol0003o^[ZjoooooonHV9So410@01?ooooo0ol0
001Rooooo`?ooiT09?ooool3olco00_ooooo00?o0000ooooooooool0:_ooool00ol0003ooooooooo
o`1/ooooo`006_ooool01OnHV9So410@o`000?lQ8B7oc<c<017ooooo0_l00003ooooo`03o`000?oo
oooooooo05cooooo0oooV@0Tooooo`?oc?l03_ooool00ol0003oooooooooo`0Zooooo`;o0000KOoo
ool002gooooo0ol0001Qooooo`?ooiT09?ooool3olco017ooooo00?o0000ooooooooool0:_ooool2
o`0006gooooo000Zooooo`?o0000H_ooool2oonI02Cooooo0oo<o`0Dooooo`03o`000?oooooooooo
02cooooo00?o0000ooooooooool0J_ooool002Sooooo0_l00003ooooo`03o`000?oooooooooo05co
oooo0oooV@0Tooooo`;oc?l05oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo06Wo
oooo000Uooooo`?o0000HOooool3oonI02Gooooo0_o<o`0Iooooo`03o`000?oooooooooo02gooooo
00?o0000ooooooooool0JOooool002Cooooo00?o0000ooooooooool0H?ooool2oonI02Kooooo0_o<
o`0Kooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0J?ooool001[ooooo1?l00000
0ol@413oooooooooo`03ooooo`;o0000G_ooool3oonI02Kooooo0_o<o`0Mooooo`03o`000?oooooo
oooo00Gooooo0_lco`0Xooooo`03o`000?oooooooooo06Oooooo000Looooo`03o`000?oooooooooo
00Gooooo0_l0001Kooooo`?ooiT09_ooool3olco01oooooo00?o0000ooooooooool00_ooool3oc?o
02_ooooo00?o0000ooooooooool0I_ooool0017ooooo1_l00005ooooo`03o`000?oooooooooo00Co
oooo1?l0001Hooooo`;ooiT09_ooool3olco02;ooooo00?o0000oooooolco`000_lco`0^ooooo`03
o`000?oooooooooo00Sooooo1Ol0001Iooooo`007?ooool00ol0003oooooooooo`05ooooo`04o`00
0?ooooooooooo`0005Cooooo0oooV@0Uooooo`?oc?l09?ooool00olco`3o0000oc?o000booooo`03
o`000?oooooooooo00Oooooo00GoV9RHob4Q8Oo^k^koooooodA4A01Iooooo`007?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0C_ooool3oonI02Go
oooo0oo<o`0Tooooo`?o<ol000?oooooo`000?ooool0<oooool00ol0003oooooooooo`07ooooo`03
oiRHV?lQ8B7ok^k^05[ooooo000Looooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`1:ooooo`?ooiT09Oooool3olco02Cooooo0olco`04ooooo`03o`00
0?oooooooooo03?ooooo00?o0000ooooooooool01oooool00onHV9So8B4Qonk^kP1Iooooo`007?oo
ool00ol0003oooooooooo`04ooooo`;o00001Oooool00ol0003oooooooooo`16ooooo`?ooiT09_oo
ool2olco02Gooooo0_lco`07ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool01ooo
ool00omgMgOoIVIVooooo`1Hooooo`006_ooool00omEEEGoIVIVo`000006ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool0@_ooool3oonI02Kooooo0oo<o`0Tooooo`?o<ol02Oooool0
0ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0Eoooool0
02?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0oooooo`;ooiT09_ooool3olco
02Cooooo0olco`0<ooooo`03o`000?oooooooooo03Gooooo0_l00004ooooo`05o`000?nj^[[ooooo
oiRHV?l@4100FOooool002?ooooo0_l00008ooooo`03o`000?oooooooooo03_ooooo0oooV@0Voooo
o`;oc?l09?ooool3oc?o00oooooo00?o0000ooooooooool0<oooool2o`000003ooooool0003ooooo
00?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c01Iooooo`008oooool00ol0003oooooooooo`08oooo
o`03o`000?oooooooooo03Oooooo0oooV@0Vooooo`?oc?l09?ooool2oc?o01;ooooo00?o0000oooo
ooooool0=oooool00ol0003oooooooooo`1Oooooo`008oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo03Cooooo0_ooV@0Vooooo`?oc?l09Oooool2oc?o01Cooooo00?o0000oooooooo
ool0=oooool00ol0003oooooooooo`1Oooooo`008oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo033ooooo0oooV@0Uooooo`?oc?l09_ooool2oc?o01Gooooo0_l0000jooooo`03o`00
0?oooooooooo05kooooo000Rooooo`;o00003Oooool00ol0003oooooooooo`0/ooooo`?ooiT09Ooo
ool3olco02Oooooo0_lco`0Dooooo`?o000000?oooooo`000?ooool02oooool2o`3oIRgooooo00?o
0000ooooooooool0GOooool002;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0Y
ooooo`;ooiT09Oooool3olco02Oooooo0olco`0Cooooo`?o00001Oooool00ol0003oooooooooo`06
ooooo`?o0?mV<?ooool00ol0003oooooooooo`1Looooo`008_ooool00ol0003oooooooooo`0>oooo
o`03o`000?oooooooooo02Gooooo0oooV@0Uooooo`;oc?l09oooool3oc?o01?ooooo0ol00009oooo
o`03o`000?oooooooooo00;ooooo0ol0ofHcooooo`03o`000?oooooooooo05cooooo000Rooooo`?o
00003oooool00ol0003oooooooooo`0Qooooo`?ooiT09Oooool3olco02Kooooo0olco`0Cooooo`?o
00003Oooool01?l0003o0?mVo`3oI_l0ofHgooooo`03o`000?oooooooooo05_ooooo000Rooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool07_ooool2oonI02Gooooo0oo<o`0Vooooo`?o
<ol05?ooool2o`0000oooooo0_l0ofH00ol0003oooooooooo`0hooooo`03o`000?oooooooooo05[o
oooo000Rooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool06_ooool3oonI02Gooooo
0_o<o`0Vooooo`?o<ol05?ooool3o`0000kooooo0ol0ofH3ooooo`03o`000?oooooooooo03Sooooo
00?o0000ooooooooool0FOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q
1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`0Fooooo`?ooiT09Oooool3olco02Kooooo0_lco`0Dooooo`?o00003oooool2o`3oIPKo
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1Iooooo`001oooool01OmgMgOoV9RH
oooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooooooo
ool04oooool00ol0003oooooooooo`0Dooooo`03oonI0?oooooooooo02?ooooo0oo<o`0Vooooo`?o
<ol04oooool3o`00013ooooo0_l0ofH9ooooo`03o`000?oooooooooo03Sooooo00?o0000oooooooo
ool0F?ooool000Go00000_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo03Oooooo0_o<o`0Vooooo`?o
<ol04oooool3o`00013ooooo0ol0ofH<ooooo`03o`000?oooooooooo03Sooooo00?o0000oooooooo
ool0Eoooool000Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?o
oooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`0cooooo`?oc?l09Oooool3oc?o01?o
oooo0ol0000@ooooo`?o0?mV4?ooool00ol0003oooooooooo`0gooooo`;o0000F?ooool000Oooooo
00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo02oooooo0oo<o`0Uooooo`?o<ol05?ooool2o`00
017ooooo0_l0ofHDooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0EOooool000Oo
oooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Kooooo0_l0000Ioooo
o`03o`000?oooooooooo02_ooooo0oo<o`0Uooooo`?o<ol05?ooool3o`00013ooooo0ol0ofHGoooo
o`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0EOooool000Oooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`0Vooooo`Coc?l09Oooool3oc?o01Cooooo0ol0000@ooooo`?o0?mV6_ooool00ol0
003oooooooooo`0hooooo`03o`000?oooooooooo05Cooooo0007ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0000Gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Roooo
o`?oc?l09Oooool4oc?o01Cooooo0ol0000@ooooo`?o0?mV7_ooool00ol0003oooooooooo`0hoooo
o`03o`000?oooooooooo05?ooooo000Qooooo`03o`000?oooooooooo01_ooooo00?o0000oooooooo
ool07_ooool3olco02Gooooo0olco`0Eooooo`?o00004?ooool3o`3oIR;ooooo00?o0000oooooooo
ool00_ooool2o`3oocCooooo00?o0000ooooooooool0D_ooool0023ooooo0ol0000Mooooo`03o`00
0?oooooooooo01[ooooo0oo<o`0Uooooo`?o<ol05_ooool2o`00013ooooo0ol0ofHVooooo`04o`00
0?l0oooo0?ooo`3oocKooooo00?o0000ooooooooool0D_ooool0027ooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`0Gooooo`;oc?l09Oooool3oc?o01Kooooo0ol0000?ooooo`?o0?mV
9oooool3o`3oo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0DOooool0023ooooo00?o
0000ooooooooool07oooool00ol0003oooooooooo`0Cooooo`?oc?l09Oooool2oc?o01Kooooo0ol0
000=ooooo`Go0?mV:?ooool2o`3oo`Cooooo00?o0000ooooooooool0=oooool00ol0003ooooooooo
o`1@ooooo`008?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00oooooo0oo<o`0U
ooooo`?o<ol05Oooool3o`0000gooooo0ol0ofHZooooo`?o0?oo1_ooool00ol0003oooooooooo`0h
ooooo`03o`000?oooooooooo04oooooo000Pooooo`;o00008_ooool00ol0003oooooooooo`0=oooo
o`03olco0?oooooooooo02?ooooo0olco`0Eooooo`?o00003Oooool3o`3oIR[ooooo0ol0ool:oooo
o`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0Coooool0023ooooo00?o0000oooooooo
ool08_ooool00ol0003oooooooooo`0`ooooo`;o<ol05_ooool2o`0000gooooo0ol0ofHZooooo`?o
0?oo3_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo04kooooo000Pooooo`03o`00
0?oooooooooo02?ooooo00?o0000ooooooooool0;?ooool3oc?o01Gooooo0ol0000=ooooo`;o0?mV
:_ooool3o`3ooa;ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`1=ooooo`008?oo
ool3o`0002Cooooo00?o0000ooooooooool0:?ooool3oc?o01Gooooo0ol0000=ooooo`?o0?mV:Ooo
ool3o`3ooaKooooo00?o0000ooooooooool0=_ooool2o`0004kooooo000Pooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool09?ooool3oc?o01Gooooo0ol0000=ooooo`?o0?mV:?ooool4
o`3ooa[ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`1<ooooo`005?ooool01Oo^
k^ko<S8bo`000?lb<S;ok^k^00Oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0P
ooooo`?o<ol05Oooool3o`0000kooooo0_l0ofHWooooo`Co0?oo7_ooool00ol0003oooooooooo`0g
ooooo`03o`000?oooooooooo04_ooooo000Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool0
0ol0003oooooooooo`0Xooooo`03o`000?oooooooooo01cooooo0olco`0Fooooo`;o00003_ooool3
o`3oIRKooooo0ol0oolSooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0B_ooool0
01Cooooo00Go410@oooooooooooooooooa0@4006ooooo`;o0000:_ooool00ol0003oooooooooo`0I
ooooo`;o<ol05_ooool3o`0000gooooo0ol0ofHVooooo`?o0?oo9oooool00ol0003oooooooooo`0g
ooooo`03o`000?oooooooooo04Wooooo000Dooooo`05o`000?ooooooooooooooool000001_ooool0
0ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01Gooooo0olco`0Eooooo`?o00003Oooool3
o`3oIRKooooo0ol0oolZooooo`03o`1Vool0003ooooo03Oooooo00?o0000ooooooooool0BOooool0
01Cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo02_ooooo00?o0000
ooooooooool04Oooool3oc?o01Gooooo0ol0000=ooooo`?o0?mV9_ooool3o`3oob[ooooo0ol0I_l2
ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0B?ooool001Cooooo00Go410@oooo
oooooooooooooa0@4006ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool03_ooool2
oc?o01Gooooo0ol0000=ooooo`?o0?mV9_ooool3o`3oob[ooooo0ol0I_l6ooooo`03o`000?oooooo
oooo03Kooooo00?o0000ooooooooool0Aoooool001Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06
ooooo`;o0000;_ooool00ol0003oooooooooo`0:ooooo`?o<ol05?ooool3o`0000kooooo0_l0ofHV
ooooo`?o0?oo:_ooool3o`1Vo`Wooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`16
ooooo`005?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0;_ooool0
0ol0003oooooooooo`07ooooo`;o<ol05Oooool2o`0000kooooo0ol0ofHVooooo`;o0?oo:_ooool3
o`1Vo`gooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`15ooooo`007oooool00ol0
003oooooooooo`0_ooooo`03o`000?oooooooooo00Gooooo00?o<ol0ooooooooool04_ooool3o`00
00gooooo0ol0ofHVooooo`?o0?oo:Oooool3o`1Voa7ooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`15ooooo`007_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo01Ko
oooo0ol0000>ooooo`;o0?mV9_ooool3o`3oobWooooo0ol0I_lEooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool0A?ooool001kooooo0_l0000cooooo`03o`000?oooooooooo01;ooooo
0ol0000>ooooo`?o0?mV9_ooool2o`3oobOooooo1Ol0I_lIooooo`03o`000?oooooooooo03Kooooo
0_l00014ooooo`007_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00kooooo0ol0
000>ooooo`?o0?mV9_ooool3o`3oobKooooo0ol0I_lOooooo`03o`000?oooooooooo03Cooooo00?o
0000ooooool00000A?ooool001kooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0;
ooooo`;o00003oooool2o`3oIRKooooo0ol0oolVooooo`?o06Ko8_ooool00ol0003oooooooooo`0f
ooooo`03o`000?oooooooooo04;ooooo000Nooooo`03o`000?oooooooooo03Gooooo00?o0000oooo
ooooool01oooool3o`0000kooooo0ol0ofHUooooo`?o0?oo9_ooool3o`1VobKooooo00?o0000oooo
ooooool0=_ooool00ol0003oooooooooo`11ooooo`007_ooool2o`0003Oooooo00?o0000oooooooo
ool00oooool3o`0000kooooo0ol0ofHUooooo`?o0?oo9_ooool3o`1Vob[ooooo00?o0000oooooooo
ool0=_ooool00ol0003oooooooooo`10ooooo`007_ooool00ol0003oooooooooo`0gooooo`03o`00
0?oooooo000000;o00003oooool2o`3oIRGooooo0ol0oolVooooo`?o06Ko;_ooool00ol0003ooooo
ooooo`0fooooo`03o`000?oooooooooo03oooooo000Nooooo`03o`000?oooooooooo03Kooooo0ol0
000?ooooo`?o0?mV9Oooool2o`3oobKooooo0ol0I_lZooooo`;o<`3o1_ooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo03oooooo000Nooooo`;o0000=Oooool2o`0000?ooooo00?o0000
ooooooooool02Oooool3o`3oIRGooooo0ol0oolVooooo`;o06Ko:_ooool3oc<0o`Wooooo00?o0000
ooooooooool0=Oooool00ol0003oooooooooo`09ooooo`;o000000?o410@ooooooooool0<?ooool0
01gooooo00?o0000ooooooooool0<_ooool3o`0000Kooooo00?o0000ooooooooool01Oooool3o`3o
IRGooooo0ol0oolVooooo`?o06Ko:Oooool3oc<0o`cooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo037ooooo0002ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooo
oooo02oooooo0ol0000:ooooo`03o`000?oooooooooo00Co0?mV9_ooool2o`3oobKooooo0ol0I_lY
ooooo`?o<`3o4?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Gooooo1Ol0000b
ooooo`000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool0;?ooool3o`0000kooooo0_l0ofHWooooo`?o0?oo9Oooool3
o`1VobOooooo1Olc0?lDooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool01Oooool0
1?m4A4CogMgMooooool0000cooooo`000_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o
0000ooooooooool00oooool2o`0002[ooooo0ol0000Booooo`03o`000?oooooooooo02;ooooo0ol0
oolUooooo`?o06Ko9oooool3oc<0oa[ooooo00?o0000ooooooooool0=Oooool00ol0003ooooooooo
o`04ooooo`04omgMgOmEEEGoooooo`0003?ooooo0002ooooo`05o`000?ooooooooooooooool00000
3oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo02Oooooo0_l0000Fooooo`03o`00
0?oooooooooo01kooooo0ol0oolUooooo`?o06Ko9oooool3oc<0oakooooo00?o0000ooooooooool0
=Oooool00ol0003oooooooooo`04ooooo`03ogMgMoo<c<co000003?ooooo0002ooooo`05o`000?oo
ooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooooooo
ool09?ooool3o`0001Wooooo00?o0000ooooooooool06Oooool4o`3oobKooooo0_l0I_lWooooo`?o
<`3o8_ooool00ol0003oooooooooo`0dooooo`;o00001Oooool00oo^k^koA4A4o`00000cooooo`00
0_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`0Qooooo`?o00007Oooool00ol0003oooooooooo`0Eooooo`?o0?oo9oooool3o`1VobKo
oooo0olc0?lUooooo`03o`000?oooooooooo03?ooooo00Co0000oooooooooooo00001Oooool00omg
MgOo0000ooooo`0booooo`000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooo
ooooool01oooool2o`0001oooooo0ol0000Qooooo`03o`000?oooooooooo017ooooo0ol0oolWoooo
o`?o06Ko9_ooool3oc<0obWooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0hoooo
o`000_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo
01cooooo0ol0000Uooooo`03o`000?oooooooooo00gooooo0ol0oolWooooo`?o06Ko9_ooool3oc<0
obgooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0gooooo`007?ooool00ol0003o
ooooooooo`0Iooooo`?o0000:Oooool00ol0003oooooooooo`0:ooooo`;o0?oo9Oooool5o`1VobGo
oooo1?lc0?laooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0=_ooool001cooooo
00?o0000ooooooooool05oooool2o`0002gooooo00?o0000ooooooooool01_ooool3o`3oobCooooo
0ol0I_lVooooo`Co<`3o=_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo03Gooooo
000Looooo`;o00005Oooool3o`00033ooooo00?o0000ooooooooool00_ooool3o`3oobCooooo0ol0
I_lVooooo`?o<`3o;?ooool3ol`0o`cooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0eooooo`007?ooool00ol0003oooooooooo`0Aooooo`?o0000=?ooool01?l0003oooooo`3oool0
oolTooooo`?o06Ko9_ooool3oc<0ob[ooooo1Oo<0?l?ooooo`03o`000?oooooooooo03Gooooo00?o
0000ooooooooool0=?ooool001cooooo00?o0000ooooooooool03_ooool3o`0003Kooooo0ol0oolT
ooooo`;o06Ko9_ooool3oc<0obWooooo1?o<0?lEooooo`03o`000?oooooooooo03Gooooo00?o0000
ooooooooool0<oooool001cooooo00?o0000ooooooooool02oooool3o`0003Kooooo0ol0ool3oooo
o`03o`000?oooooooooo01kooooo0ol0I_lUooooo`?o<`3o:Oooool3ol`0oa[ooooo00?o0000oooo
ooooool0=Oooool00ol0003oooooooooo`0booooo`007?ooool2o`0000[ooooo0_l0000hooooo`03
o`3ooooooooooooo00Gooooo00?o0000ooooooooool06_ooool3o`1VobGooooo0olc0?lYooooo`?o
c03o7_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo03;ooooo000Kooooo`;o0000
2?ooool3o`0004?ooooo00?o0000ooooooooool05oooool2o`1VobGooooo0olc0?lXooooo`Coc03o
8_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo037ooooo000Kooooo`03o`000?oo
oooooooo00Cooooo0ol00017ooooo`03o`000?oooooooooo01?ooooo0ol0I_lTooooo`?o<`3o9_oo
ool5ol`0obOooooo00?o0000ooooooooool0<oooool2o`0003;ooooo000Kooooo`04o`000?oooooo
ooooooooo`?o0000Boooool00ol0003oooooooooo`0?ooooo`?o06Ko8oooool4oc<0obKooooo0oo<
0?l/ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0;oooool001_ooooo1?l0001?
ooooo`03o`000?oooooooooo00cooooo0_l0I_lSooooo`?o<`3o9oooool3ol`0oc3ooooo00?o0000
ooooooooool0=?ooool00ol0003oooooooooo`0_ooooo`006oooool2o`0005;ooooo00?o0000oooo
ooooool02?ooool3o`1Vob;ooooo0olc0?lWooooo`?oc03o=?ooool00ol0003oooooooooo`0doooo
o`03o`000?oooooooooo02kooooo000Aooooo`Co000000?o410@ooooooooool01Oooool00ol0003o
ooooooooo`1@ooooo`03o`000?oooooooooo00Cooooo0ol0I_lRooooo`?o<`3o9_ooool4ol`0ocSo
oooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0]ooooo`004oooool00ol0003ooooo
ooooo`08ooooo`03o`000?oooooooooo053ooooo00Co0000oooooooooooooooo0_l0I_lRooooo`?o
<`3o9Oooool4ol`0ocgooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0/ooooo`00
4oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo053ooooo0ol0I_lQooooo`?o<`3o
9?ooool4ol`0od;ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0/ooooo`004ooo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo04cooooo0ol0I_l00ooooooo0000oooo
o`0Nooooo`?o<`3o8_ooool5ol`0oc7ooooo0ooo09TBooooo`03o`000?oooooooooo03Cooooo00?o
0000ooooooooool0:oooool001?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`18
ooooo`?o06Ko1Oooool00ol0003oooooooooo`0Jooooo`;o<`3o8_ooool3ol`0oc7ooooo1Ooo09TF
ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0:_ooool001?ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`13ooooo`Co06Ko2Oooool00ol0003oooooooooo`0Foooo
o`?o<`3o8Oooool3ol`0oboooooo1Ooo09TLooooo`03o`000?oooooooooo03Cooooo00?o0000oooo
ooooool0:Oooool001?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`10ooooo`;o
06Ko3_ooool00ol0003oooooooooo`0Booooo`?o<`3o8Oooool3ol`0obgooooo1Ooo09TRooooo`03
o`000?oooooooooo03Cooooo00?o0000ooooooooool0:?ooool0017ooooo00?oEEEEofIVI_l00000
4?ooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo00oooooo0_lc0?lRooooo`;oc03o
:oooool5ool0VBSooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Xooooo`009Ooo
ool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo00_ooooo0olc0?lQooooo`?oc03o:?oo
ool5ool0VBkooooo00?o0000ooooooooool0<_ooool2o`0002Wooooo000Vooooo`;o0000DOooool0
0ol0003oooooooooo`08ooooo`;o<`3o8Oooool3ol`0obOooooo1?oo09Tcooooo`03o`000?oooooo
oooo03Cooooo00?o0000ooooooooool09_ooool002Sooooo00?o0000ooooooooool0C_ooool00ol0
003oooooooooo`06ooooo`;o<`3o8Oooool2ol`0obGooooo1Ooo09Thooooo`03o`000?oooooooooo
03Cooooo00?o0000ooooooooool09Oooool002Wooooo00?o0000ooooooooool0C_ooool00ol0003o
ooooooooo`02ooooo`?o<`3o8?ooool3ol`0ob?ooooo1?oo09Tnooooo`03o`000?oooooooooo03?o
oooo00?o0000ooooooooool09Oooool002[ooooo00?o0000ooooooooool0C_ooool01?l0003o<`3o
oc<0oolc0?lPooooo`?oc03o8Oooool5ool0VD?ooooo00?o0000ooooooooool0<oooool00ol0003o
ooooooooo`0Tooooo`00:oooool00ol0003oooooooooo`1<ooooo`;o<`3o00?o0000ooooooooool0
7Oooool3ol`0ob3ooooo1?oo09U9ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0
8oooool002cooooo00?o0000ooooooooool0B?ooool3oc<0o`?ooooo00?o0000ooooooooool06?oo
ool4ol`0oaoooooo1?oo09U>ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool08_oo
ool002gooooo00?o0000ooooooooool0A?ooool3oc<0o`Oooooo00?o0000ooooooooool05?ooool3
ol`0ob3ooooo0ooo09Tfooooo`?oo`006Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooo
oooo02;ooooo000^ooooo`03o`000?oooooooooo047ooooo0_lc0?l;ooooo`03o`000?oooooooooo
017ooooo0_o<0?lPooooo`?oo`2I=_ooool3ool001gooooo00?o0000ooooooooool0<oooool00ol0
003oooooooooo`0Qooooo`00;oooool00ol0003oooooooooo`0mooooo`?o<`3o3_ooool00ol0003o
ooooooooo`0>ooooo`;oc03o7oooool3ool0VCKooooo0ooo000Qooooo`03o`000?oooooooooo03?o
oooo00?o0000ooooooooool08?ooool0033ooooo00?o0000ooooooooool0>Oooool3oc<0oa;ooooo
00?o0000ooooooooool02oooool2ol`0oagooooo1?oo09Tbooooo`Ooo`009Oooool00ol0003ooooo
ooooo`0cooooo`03o`000?oooooooooo01oooooo000aooooo`;o0000>?ooool00olc0?oooooooooo
o`0Dooooo`03o`000?oooooooooo00Sooooo0_o<0?lLooooo`?oo`2I;oooool7ool002gooooo00?o
0000ooooooooool0<_ooool2o`00023ooooo000cooooo`03o`000?oooooooooo04gooooo00?o0000
ooooooooool01?ooool3ol`0oa_ooooo0ooo09T]ooooo`Goo`00=Oooool00ol0003oooooooooo`0a
ooooo`;o00008?ooool003Cooooo00?o0000ooooooooool0COooool01?l0003oooooooooooooool2
ol`0oa_ooooo0ooo09TYooooo`Ooo`00>_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooo
oooo01gooooo000eooooo`03o`000?oooooooooo04gooooo00?o0000ol`0ooo<0?l06_ooool3ool0
VBGooooo1ooo0012ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool07?ooool003Ko
oooo00?o0000ooooooooool0B_ooool3ol`0o`03o`000?oooooooooo01Oooooo0_oo09TSooooo`Go
o`00B_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01cooooo000gooooo`03o`00
0?oooooooooo04Kooooo0oo<0?l4ooooo`03o`000?oooooooooo01?ooooo0ooo09TQooooo`Coo`00
D?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01_ooooo000hooooo`03o`000?oo
oooooooo04?ooooo0_o<0?l8ooooo`03o`000?oooooooooo00oooooo0ooo09TPooooo`Coo`00EOoo
ool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00Oooooo00Gok^k^oc8b<_l0003o410@
olc<c00>ooooo`00>Oooool00ol0003oooooooooo`0oooooo`?oc03o2oooool00ol0003ooooooooo
o`0<ooooo`;oo`2I7oooool4ool005[ooooo00?o0000ooooooooool0<_ooool00ol0003ooooooooo
o`06ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B403_ooool003[ooooo00?o0000ooooooooool0>ooo
ool3ol`0o`oooooo00?o0000ooooooooool02?ooool3ool0VAgooooo1?oo001Nooooo`03o`000?oo
oooooooo03?ooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000kooooo
000kooooo`03o`000?oooooooooo03Sooooo0_o<0?lCooooo`03o`000?oooooooooo00Gooooo0_oo
09TMooooo`?oo`00Hoooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00Gooooo00Go
0000oiRHV?ooooooV9RHob4Q8@0>ooooo`00??ooool00ol0003oooooooooo`0dooooo`?oc03o5_oo
ool00ol0003oooooooooo`02ooooo`;oo`2I7?ooool3ool006Oooooo00?o0000ooooooooool0<_oo
ool00ol0003oooooooooo`04ooooo`05o`000?mEEEGo0000oa0@4?o<c<`03_ooool003gooooo0_l0
000aooooo`?oc03o6_ooool01?l0003oooooool0VOoo09TKooooo`?oo`00Joooool00ol0003ooooo
ooooo`0booooo`;o00001?ooool00omEEEGoQhN7ooooo`0@ooooo`00?oooool00ol0003ooooooooo
o`0]ooooo`03ol`0oooooooooooo01cooooo00?oo`2Iooooooooool06?ooool3ool006oooooo00?o
0000ooooooooool0;oooool2o`000003ooooool0003ooooo00?ooooo00?ogMgMoa0@4?nHV9P04?oo
ool0043ooooo00?o0000ooooooooool0BOooool2ool0V@03ooooool0003ooooo01Gooooo0ooo001c
ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool00oooool01?o<c<coA4A4o`000?l@
410>ooooo`00@Oooool00ol0003oooooooooo`16ooooo`;oo`2I1?ooool00ol0003oooooooooo`0@
ooooo`?oo`00M_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01Cooooo0012oooo
o`03o`000?oooooooooo04;ooooo0ooo09T7ooooo`03o`000?oooooooooo00gooooo0_oo001joooo
o`03o`000?oooooooooo03;ooooo00?o0000ooooooooool04oooool004?ooooo00?o0000oooooooo
ool0?_ooool3ool0V@_ooooo00?o0000ooooooooool02oooool00ooo003oooooooooo`1kooooo`03
o`000?oooooooooo03;ooooo00?o0000ooooooooool04_ooool004Cooooo00?o0000ooooooooool0
>oooool2ool0V@oooooo00?o0000ooooooooool02?ooool2ool007oooooo00?o0000ooooooooool0
<Oooool00ol0003oooooooooo`0Booooo`00AOooool00ol0003oooooooooo`0hooooo`;oo`2I4_oo
ool00ol0003oooooooooo`05ooooo`;oo`00P_ooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo017ooooo0016ooooo`03o`000?oooooooooo03Kooooo00?oo`2Iooooooooool04oooool0
1?l0003oooooooooooooool3ool008Gooooo00?o0000ooooooooool0<Oooool00ol0003ooooooooo
o`0@ooooo`00Aoooool00ol0003oooooooooo`0cooooo`;oo`2I5oooool00ol0003oo`00ool00028
ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool03oooool004Sooooo0_l0000aoooo
o`;oo`2I6?ooool2ool00003o`000?oooooooooo08Sooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`0?ooooo`00B_ooool00ol0003oooooooooo`0[ooooo`?oo`2I5oooool3ool000?o
oooo00?o0000ooooooooool0R?ooool00ol0003oooooooooo`0aooooo`;o00003oooool004_ooooo
00?o0000ooooooooool09oooool3ool0VASooooo0_oo0007ooooo`03o`000?oooooooooo08Sooooo
00?o0000ooooooooool0<?ooool2o`0000oooooo001<ooooo`03o`000?oooooooooo02Gooooo00?o
o`2Iooooooooool05oooool2ool000[ooooo00?o0000ooooooooool0R?ooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo00cooooo001=ooooo`03o`000?oooooooooo03cooooo0_oo000=
ooooo`03o`000?oooooooooo08Sooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0;
ooooo`00C_ooool00ol0003oooooooooo`0jooooo`03ool00?oooooooooo00kooooo00?o0000oooo
ooooool0Qoooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00_ooooo001?ooooo`03
o`000?oooooooooo03Oooooo0_oo000Booooo`03o`000?oooooooooo08Oooooo00?o0000oooooooo
ool0<Oooool00ol0003oooooooooo`0:ooooo`00D?ooool00ol0003oooooooooo`0dooooo`;oo`00
5Oooool00ol0003oooooooooo`27ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
2Oooool0057ooooo00?o0000ooooooooool0<Oooool2ool001Sooooo00?o0000ooooooooool0Qooo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Sooooo001Booooo`03o`000?oooooo
oooo02oooooo00?oo`00ooooooooool06Oooool00ol0003oooooooooo`27ooooo`03o`000?oooooo
oooo033ooooo00?o0000ooooooooool02?ooool005?ooooo0_l0000]ooooo`;oo`007Oooool00ol0
003oooooooooo`27ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool01oooool005Go
oooo00?o0000ooooooooool0:?ooool2ool0023ooooo00?o0000ooooooooool0Q_ooool00ol0003o
ooooooooo`0aooooo`03o`000?oooooooooo00Kooooo001Fooooo`03o`000?oooooooooo02Gooooo
0_oo000Sooooo`03o`000?oooooooooo08Kooooo00?o0000ooooooooool0;oooool3o`0000Oooooo
001Gooooo`03o`000?oooooooooo02;ooooo0_oo000Vooooo`03o`000?oooooooooo08Kooooo00?o
0000ooooooooool0:oooool3o`0000;ooooo00?o0000ooooooooool01Oooool005Sooooo00?o0000
ooooooooool07oooool2ool002Wooooo00?o0000ooooooooool0Q_ooool00ol0003oooooooooo`0W
ooooo`?o00001Oooool00ol0003oooooooooo`05ooooo`00FOooool00ol0003oooooooooo`0Moooo
o`03ool00?oooooooooo02[ooooo00?o0000ooooooooool0Q_ooool00ol0003oooooooooo`0Roooo
o`Co00002?ooool00ol0003oooooooooo`05ooooo`00F_ooool00ol0003oooooooooo`1:ooooo`03
o`000?oooooooooo08Kooooo00?o0000ooooooooool07_ooool3o`0000cooooo00?o0000oooooooo
ool01Oooool005_ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`25ooooo`03o`00
0?oooooooooo01[ooooo1?l0000?ooooo`03o`000?oooooooooo00Gooooo001Looooo`03o`000?oo
oooooooo04[ooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`0Fooooo`?o00005?oo
ool00ol0003oooooooooo`04ooooo`00GOooool00ol0003oooooooooo`1:ooooo`03o`000?oooooo
oooo08Gooooo00?o0000ooooooooool04_ooool3o`0001Oooooo00?o0000ooooooooool01?ooool0
05kooooo0_l0001;ooooo`03o`000?oooooooooo08Gooooo00?o0000ooooooooool03Oooool4o`00
01[ooooo00?o0000ooooooooool01?ooool0063ooooo00?o0000ooooooooool0BOooool00ol0003o
ooooooooo`25ooooo`03o`000?oooooooooo00Wooooo0ol0000Nooooo`03o`000?oooooooooo00Co
oooo001Qooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0QOooool00ol0003ooooo
ooooo`04ooooo`Co00008Oooool00ol0003oooooooooo`04ooooo`00H_ooool00ol0003ooooooooo
o`19ooooo`03o`000?oooooooooo08Cooooo00Co0000oooooooooooooooo0ol0000Uooooo`03o`00
0?oooooooooo00Cooooo001Sooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0Q?oo
ool3o`0002Sooooo00?o0000ooooooooool01?ooool006Cooooo00?o0000ooooooooool0BOooool0
0ol0003oooooooooo`1oooooo`Co000000?oooooo`000?ooool0:?ooool00ol0003oooooooooo`04
ooooo`00IOooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo07_ooooo0ol00006oooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool01?ooool006Kooooo00?o0000oooooooo
ool0BOooool00ol0003oooooooooo`1fooooo`Co00002_ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo00Cooooo001Wooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0
L_ooool3o`0000oooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`03ooooo`00J?oo
ool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo06kooooo0ol0000Booooo`03o`000?oo
oooooooo02Gooooo00?o0000ooooooooool00oooool006Wooooo00?o0000ooooooooool0BOooool0
0ol0003oooooooooo`1Yooooo`Co00005_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooo
oooo00?ooooo001Zooooo`;o0000B_ooool00ol0003oooooooooo`1Uooooo`?o00006oooool00ol0
003oooooooooo`0Sooooo`03o`000?oooooooooo00?ooooo001/ooooo`03o`000?oooooooooo04So
oooo00?o0000ooooooooool0H?ooool4o`0001oooooo00?o0000ooooooooool08_ooool00ol0003o
ooooooooo`03ooooo`00KOooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo05cooooo
0ol0000Tooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool00oooool006kooooo00?o
0000ooooooooool0B?ooool00ol0003oooooooooo`1Hooooo`?o0000:?ooool00ol0003ooooooooo
o`0Pooooo`03o`000?oooooooooo00?ooooo001_ooooo`03o`000?oooooooooo04Sooooo00?o0000
ooooooooool0Doooool4o`0002_ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`03
ooooo`00L?ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo04oooooo0ol0000`oooo
o`03o`000?oooooooooo01oooooo00?o0000ooooooooool00oooool0077ooooo00?o0000oooooooo
ool0B?ooool00ol0003oooooooooo`1:ooooo`Co0000=?ooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo00?ooooo001booooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0
A_ooool3o`0003Wooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`02ooooo`00Looo
ool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo04;ooooo0ol0000mooooo`03o`000?oo
oooooooo01gooooo00?o0000ooooooooool00_ooool007Cooooo00?o0000ooooooooool0B?ooool0
0ol0003oooooooooo`0mooooo`Co0000@Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo00;ooooo001eooooo`;o0000BOooool00ol0003oooooooooo`0iooooo`?o0000AOooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo00;ooooo001gooooo`03o`000?oooooooooo04Oo
oooo00?o0000ooooooooool0=?ooool4o`0004Wooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`02ooooo`00N?ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo033ooooo
0ol0001>ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool00_ooool007Wooooo00?o
0000ooooooooool0Aoooool00ol0003oooooooooo`0/ooooo`?o0000D_ooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo00;ooooo001jooooo`03o`000?oooooooooo04Oooooo00?o0000
ooooooooool09oooool4o`0005Kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`02
ooooo`00Noooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo02?ooooo0ol0001Koooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool00_ooool007cooooo00?o0000oooooooo
ool0Aoooool00ol0003oooooooooo`0Nooooo`Co0000G_ooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo00;ooooo001mooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0
6_ooool3o`0006?ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`01ooooo`00O_oo
ool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo01Kooooo0ol0001Wooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool00Oooool007oooooo00?o0000ooooooooool0Aoooool0
0ol0003oooooooooo`0Aooooo`Co0000Joooool00ol0003oooooooooo`0Eooooo`03o`000?oooooo
oooo007ooooo0020ooooo`;o0000B?ooool00ol0003oooooooooo`0=ooooo`?o0000L?ooool00ol0
003oooooooooo`0Dooooo`03o`000?oooooooooo007ooooo0022ooooo`03o`000?oooooooooo04Ko
oooo00?o0000ooooooooool02?ooool4o`0007Cooooo00?o0000ooooooooool04oooool00ol0003o
ooooooooo`01ooooo`00Poooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo00Cooooo
0ol0001hooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00Oooool008Cooooo00?o
0000ooooooooool0A_ooool00ol0003oooooooooo`03o`0007cooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`01ooooo`00QOooool00ol0003oooooooooo`16ooooo`;o0000P?ooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo007ooooo0026ooooo`03o`000?oooooooooo
04Gooooo00?o0000ooooooooool0P?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
007ooooo0027ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0POooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo007ooooo0028ooooo`03o`000?oooooooooo04?ooooo
00?o0000ooooooooool0P_ooool00ol0003oooooooooo`0?ooooo`7o00000Oooool1ooooo`00ROoo
ool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool03ooo
ool1o`00007ooooo0Oooool008[ooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`23
ooooo`03o`000?oooooooooo00kooooo0Ol00001ooooo`7ooooo002;ooooo`;o0000@Oooool00ol0
003oooooooooo`24ooooo`03o`000?oooooooooo00gooooo0Ol00001ooooo`7ooooo002=ooooo`03
o`000?oooooooooo03kooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`0<ooooo`7o
00000Oooool1ooooo`00S_ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo08Kooooo
00?o0000ooooooooool02oooool1o`00007ooooo0Oooool008oooooo00?o0000ooooooooool0??oo
ool00ol0003oooooooooo`27ooooo`03o`000?oooooooooo00[ooooo0Ol00001ooooo`7ooooo002@
ooooo`03o`000?oooooooooo03_ooooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`0:
ooooo`7o00000Oooool1ooooo`00TOooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo
08Sooooo00?o0000ooooooooool02Oooool1o`00007ooooo0Oooool009;ooooo00?o0000oooooooo
ool0>Oooool00ol0003oooooooooo`29ooooo`03o`000?oooooooooo00Sooooo0Ol00001ooooo`7o
oooo002Cooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0R_ooool00ol0003ooooo
ooooo`08ooooo`7o00000Oooool009Cooooo00?o0000ooooooooool0=oooool00ol0003ooooooooo
o`2;ooooo`03o`000?oooooooooo00Oooooo0Ol00001ooooo`00UOooool00ol0003oooooooooo`0f
ooooo`03o`000?oooooooooo08cooooo00?o0000ooooooooool01_ooool1o`00007ooooo002Foooo
o`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0S?ooool00ol0003oooooooooo`06oooo
o`7o00000Oooool009Oooooo0_l0000eooooo`03o`000?oooooooooo08gooooo00?o0000oooooooo
ool01Oooool1o`00007ooooo002Iooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0
S_ooool00ol0003oooooooooo`04ooooo`7o00000Oooool009[ooooo00?o0000ooooooooool0<Ooo
ool00ol0003oooooooooo`2?ooooo`03o`000?oooooooooo00?ooooo0Ol00001ooooo`00Voooool0
0ol0003oooooooooo`0`ooooo`03o`000?oooooooooo093ooooo00?o0000ooooooooool00_ooool1
o`00007ooooo002Looooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0TOooool01Ol0
003ooooooooooooooooo0000007ooooo002Mooooo`03o`000?oooooooooo02kooooo00?o0000oooo
ooooool0TOooool01Ol0003ooooooooooooooooo0000007ooooo002Nooooo`03o`000?oooooooooo
02gooooo00?o0000ooooooooool0T_ooool01?l0003oooooooooooooool1o`000000Woooool00ol0
003oooooooooo`0/ooooo`03o`000?oooooooooo09?ooooo00?o0000ooooooooool00Ol000000:3o
oooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`2Dooooo`7o00000Oooool1o`000000
XOooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo09Gooooo0_l000000:;ooooo0_l0
000Zooooo`03o`000?oooooooooo09Cooooo0ol000000:Cooooo00?o0000ooooooooool09oooool0
0ol0003oooooooooo`2@ooooo`Co00000oooool00:Gooooo00?o0000ooooooooool09_ooool00ol0
003oooooooooo`2=ooooo`?o00001oooool00:Kooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`29ooooo`Co00002_ooool00:Oooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`25ooooo`Co00003_ooool00:Sooooo00?o0000ooooooooool08oooool00ol0003ooooooooo
o`22ooooo`?o00004_ooool00:Wooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`1n
ooooo`Co00005Oooool00:[ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`1joooo
o`Co00006Oooool00:_ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`1eooooo`Co
00007Oooool00:cooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1booooo`?o0000
8Oooool00:gooooo0_l0000Pooooo`03o`000?oooooooooo06kooooo1?l0000Tooooo`00[oooool0
0ol0003oooooooooo`0Mooooo`03o`000?oooooooooo06[ooooo1?l0000Xooooo`00/?ooool00ol0
003oooooooooo`0Looooo`03o`000?oooooooooo06Oooooo0ol0000/ooooo`00/Oooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo06?ooooo1?l0000_ooooo`00/_ooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo05oooooo1?l0000cooooo`00/oooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo05cooooo0ol0000gooooo`00]?ooool00ol0003oooooooooo`0H
ooooo`03o`000?oooooooooo05Sooooo1?l0000jooooo`00]Oooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo05Cooooo1?l0000nooooo`00]_ooool00ol0003oooooooooo`0Fooooo`03
o`000?oooooooooo053ooooo1?l00012ooooo`00]oooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo04gooooo0ol00016ooooo`00^?ooool2o`0001Gooooo00?o0000ooooooooool0BOoo
ool4o`0004Wooooo002jooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0AOooool4
o`0004gooooo002kooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0@_ooool3o`00
057ooooo002looooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0?_ooool4o`0005Co
oooo002mooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0>_ooool4o`0005Sooooo
002nooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0=_ooool4o`0005cooooo002o
ooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0<oooool3o`00063ooooo0030oooo
o`03o`000?oooooooooo00cooooo00?o0000ooooooooool0;oooool4o`0006?ooooo0031ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool0:oooool4o`0006Oooooo0032ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool0:?ooool3o`0006_ooooo0033ooooo`03o`000?oo
oooooooo00Wooooo00?o0000ooooooooool09?ooool4o`0006kooooo0034ooooo`;o00002Oooool0
0ol0003oooooooooo`0Pooooo`Co0000L_ooool00<Kooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`0Mooooo`?o0000M_ooool00<Oooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0Iooooo`Co0000NOooool00<Sooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0Eooooo`Co0000OOooool00<Wooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`0Aooooo`Co0000POooool00<[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0>
ooooo`?o0000QOooool00<_ooooo00Go0000ooooooooooooooooo`00000<ooooo`Co0000R?ooool0
0<cooooo00Co0000oooooooooooo00002?ooool4o`0008cooooo003=ooooo`03o`000?oooooo0000
00Gooooo0ol0002@ooooo`00c_ooool2o`000003ooooool0003o000000;o0000Toooool00<oooooo
0_l0002Gooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {330.375, 0}} -> {-0.0771432, -0.0315529, \
0.00350368, 0.00350368}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .92059 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-16 1.0763 -0.0263982 1.0763 [
[.01694 .18568 -11.9631 -9 ]
[.01694 .18568 .03693 0 ]
[.13793 .13897 -11.619 -9 ]
[.13793 .13897 .38095 0 ]
[.26292 .09073 -5.63752 -9 ]
[.26292 .09073 .36248 0 ]
[.39212 .04087 -5.46552 -9 ]
[.39212 .04087 .53448 0 ]
[.52574 -0.01069 -5.29351 -9 ]
[.52574 -0.01069 .70649 0 ]
[.58272 .04263 0 -6.19654 ]
[.58272 .04263 6 2.80346 ]
[.71715 .21863 0 -6.07114 ]
[.71715 .21863 6 2.92886 ]
[.83675 .37523 0 -5.963 ]
[.83675 .37523 6 3.037 ]
[.94385 .51546 0 -5.8688 ]
[.94385 .51546 6 3.1312 ]
[.01386 .20006 -12 -2.76892 ]
[.01386 .20006 0 6.23108 ]
[.00748 .25499 -24 -2.80073 ]
[.00748 .25499 0 6.19927 ]
[.00093 .31131 -6 -2.83339 ]
[.00093 .31131 0 6.16661 ]
[-0.00579 .36907 -18 -2.86695 ]
[-0.00579 .36907 0 6.13305 ]
[-0.01268 .42831 -6 -2.90143 ]
[-0.01268 .42831 0 6.09857 ]
[ 0 0 0 0 ]
[ 1 .92059 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02642 .19522 m
.53391 0 L
s
.02642 .19522 m
.03116 .2 L
s
[(-2)] .01694 .18568 .99384 1 Mshowa
.14712 .14879 m
.15172 .1537 L
s
[(-1)] .13793 .13897 .93651 1 Mshowa
.2718 .10083 m
.27624 .10588 L
s
[(0)] .26292 .09073 .87917 1 Mshowa
.40066 .05126 m
.40493 .05646 L
s
[(1)] .39212 .04087 .82184 1 Mshowa
.53391 0 m
.538 .00534 L
s
[(2)] .52574 -0.01069 .7645 1 Mshowa
.125 Mabswid
.05025 .18606 m
.05308 .18894 L
s
.07424 .17683 m
.07705 .17973 L
s
.09837 .16755 m
.10117 .17046 L
s
.12267 .1582 m
.12545 .16113 L
s
.17173 .13933 m
.17447 .14229 L
s
.19651 .1298 m
.19923 .13278 L
s
.22144 .1202 m
.22414 .1232 L
s
.24654 .11055 m
.24922 .11356 L
s
.29723 .09105 m
.29988 .0941 L
s
.32283 .0812 m
.32546 .08427 L
s
.3486 .07129 m
.35121 .07437 L
s
.37455 .06131 m
.37713 .06441 L
s
.42695 .04115 m
.4295 .04428 L
s
.45342 .03096 m
.45594 .03412 L
s
.48007 .02071 m
.48257 .02388 L
s
.5069 .01039 m
.50938 .01358 L
s
.25 Mabswid
.53391 0 m
.9804 .58403 L
s
.57014 .04738 m
.56384 .04975 L
s
[(0)] .58272 .04263 -1 .37701 Mshowa
.70445 .22307 m
.6981 .22529 L
s
[(2)] .71715 .21863 -1 .34914 Mshowa
.82396 .37939 m
.81756 .38147 L
s
[(4)] .83675 .37523 -1 .32511 Mshowa
.93098 .51938 m
.92454 .52134 L
s
[(6)] .94385 .51546 -1 .30418 Mshowa
.125 Mabswid
.60525 .09331 m
.60147 .09471 L
s
.63931 .13786 m
.63552 .13924 L
s
.67236 .1811 m
.66856 .18245 L
s
.73562 .26383 m
.7318 .26514 L
s
.7659 .30345 m
.76207 .30473 L
s
.79534 .34195 m
.7915 .34322 L
s
.85181 .41581 m
.84796 .41704 L
s
.87891 .45126 m
.87506 .45247 L
s
.90529 .48577 m
.90143 .48696 L
s
.95601 .55212 m
.95214 .55328 L
s
.25 Mabswid
.02642 .19522 m
0 .42381 L
s
.02642 .19522 m
.0327 .19281 L
s
[(-1)] .01386 .20006 1 -0.38468 Mshowa
.02006 .25024 m
.02635 .24786 L
s
[(-0.5)] .00748 .25499 1 -0.37762 Mshowa
.01354 .30664 m
.01985 .3043 L
s
[(0)] .00093 .31131 1 -0.37036 Mshowa
.00686 .36448 m
.01318 .36218 L
s
[(0.5)] -0.00579 .36907 1 -0.3629 Mshowa
0 .42381 m
.00634 .42156 L
s
[(1)] -0.01268 .42831 1 -0.35524 Mshowa
.125 Mabswid
.02516 .20612 m
.02893 .20468 L
s
.0239 .21707 m
.02767 .21563 L
s
.02262 .22807 m
.0264 .22664 L
s
.02135 .23913 m
.02512 .2377 L
s
.01877 .26141 m
.02255 .25999 L
s
.01747 .27263 m
.02125 .27122 L
s
.01617 .28391 m
.01995 .2825 L
s
.01486 .29525 m
.01864 .29384 L
s
.01222 .31809 m
.01601 .3167 L
s
.01089 .3296 m
.01468 .32821 L
s
.00955 .34117 m
.01334 .33978 L
s
.00821 .35279 m
.012 .35141 L
s
.0055 .37622 m
.0093 .37485 L
s
.00414 .38803 m
.00793 .38666 L
s
.00276 .39989 m
.00656 .39853 L
s
.00139 .41182 m
.00519 .41047 L
s
.25 Mabswid
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.54154 .92059 L
s
.54154 .92059 m
.5414 .7134 L
s
.5414 .7134 m
.02642 .19522 L
s
.53391 0 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.53391 0 m
.02642 .19522 L
s
.5414 .7134 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.54154 .92059 L
s
.54154 .92059 m
.5414 .7134 L
s
0 0 m
1 0 L
1 .92059 L
0 .92059 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.3006 .6048 m
.32452 .59271 L
s
1 0 .6 r
.28466 .56951 m
.3081 .55872 L
s
.8 0 1 r
.26985 .53404 m
.29329 .52435 L
s
.2 0 1 r
.25583 .4981 m
.27943 .48923 L
s
0 .4 1 r
.24216 .46153 m
.26591 .45312 L
s
0 1 1 r
.22852 .42444 m
.25235 .41615 L
s
0 1 .4 r
.21483 .38706 m
.23867 .37871 L
s
.8 0 1 r
.29329 .52435 m
.31609 .51413 L
s
.2 1 0 r
.2011 .34955 m
.22492 .34108 L
s
.2 0 1 r
.27943 .48923 m
.30283 .47999 L
s
1 0 .6 r
.3081 .55872 m
.33014 .54727 L
s
0 .4 1 r
.26591 .45312 m
.28968 .4445 L
s
1 0 0 r
.32452 .59271 m
.34582 .57983 L
s
.8 1 0 r
.18733 .31196 m
.21113 .30337 L
s
0 1 1 r
.25235 .41615 m
.27629 .40776 L
s
1 .6 0 r
.17354 .2743 m
.19732 .26558 L
s
0 1 .4 r
.23867 .37871 m
.26264 .37029 L
s
.2 1 0 r
.22492 .34108 m
.24888 .33256 L
s
.2 0 1 r
.30283 .47999 m
.32599 .47052 L
s
0 .4 1 r
.28968 .4445 m
.31346 .43573 L
s
.8 0 1 r
.31609 .51413 m
.33825 .50374 L
s
.8 1 0 r
.21113 .30337 m
.23508 .29472 L
s
0 1 1 r
.27629 .40776 m
.30034 .39928 L
s
1 0 .6 r
.33014 .54727 m
.35089 .53586 L
s
1 .6 0 r
.19732 .26558 m
.22124 .2568 L
s
0 1 .4 r
.26264 .37029 m
.28676 .36182 L
s
1 0 0 r
.34582 .57983 m
.36476 .56736 L
s
.2 1 0 r
.24888 .33256 m
.273 .32398 L
s
0 .4 1 r
.31346 .43573 m
.33725 .42685 L
s
.8 1 0 r
.23508 .29472 m
.25918 .28601 L
s
.2 0 1 r
.32599 .47052 m
.34901 .46105 L
s
0 1 1 r
.30034 .39928 m
.32451 .39073 L
s
.8 0 1 r
.33825 .50374 m
.36009 .49355 L
s
1 .6 0 r
.22124 .2568 m
.24532 .24797 L
s
0 1 .4 r
.28676 .36182 m
.31103 .35329 L
s
1 0 .6 r
.35089 .53586 m
.37113 .52499 L
s
.2 1 0 r
.273 .32398 m
.29727 .31535 L
s
.8 1 0 r
.25918 .28601 m
.28343 .27725 L
s
0 .4 1 r
.33725 .42685 m
.36113 .41799 L
s
0 1 1 r
.32451 .39073 m
.3488 .38213 L
s
1 0 0 r
.36476 .56736 m
.3829 .55589 L
s
.2 0 1 r
.34901 .46105 m
.37209 .45175 L
s
1 .6 0 r
.24532 .24797 m
.26955 .23908 L
s
0 1 .4 r
.31103 .35329 m
.33545 .3447 L
s
.8 0 1 r
.36009 .49355 m
.38204 .48382 L
s
.2 1 0 r
.29727 .31535 m
.32169 .30666 L
s
.8 1 0 r
.28343 .27725 m
.30783 .26844 L
s
1 0 .6 r
.37113 .52499 m
.39163 .51489 L
s
0 .4 1 r
.36113 .41799 m
.38518 .40924 L
s
0 1 1 r
.3488 .38213 m
.37326 .37352 L
s
1 .6 0 r
.26955 .23908 m
.29394 .23013 L
s
.2 0 1 r
.37209 .45175 m
.39544 .44278 L
s
0 1 .4 r
.33545 .3447 m
.36002 .33607 L
s
1 0 0 r
.3829 .55589 m
.40152 .54552 L
s
.2 1 0 r
.32169 .30666 m
.34627 .29791 L
s
.8 0 1 r
.38204 .48382 m
.40444 .47466 L
s
.8 1 0 r
.30783 .26844 m
.33239 .25957 L
s
0 .4 1 r
.38518 .40924 m
.40952 .40066 L
s
0 1 1 r
.37326 .37352 m
.3979 .36492 L
s
1 0 .6 r
.39163 .51489 m
.41284 .50562 L
s
1 .6 0 r
.29394 .23013 m
.31848 .22113 L
s
0 1 .4 r
.36002 .33607 m
.38476 .32739 L
s
.2 0 1 r
.39544 .44278 m
.41922 .43421 L
s
.2 1 0 r
.34627 .29791 m
.371 .28912 L
s
.8 0 1 r
.40444 .47466 m
.42748 .46614 L
s
1 0 0 r
.40152 .54552 m
.42123 .53621 L
s
.8 1 0 r
.33239 .25957 m
.35711 .25064 L
s
0 .4 1 r
.40952 .40066 m
.43421 .39227 L
s
0 1 1 r
.3979 .36492 m
.42277 .35634 L
s
1 .6 0 r
.31848 .22113 m
.34317 .21207 L
s
0 1 .4 r
.38476 .32739 m
.40966 .31867 L
s
.2 0 1 r
.41922 .43421 m
.44355 .42606 L
s
1 0 .6 r
.41284 .50562 m
.43495 .49721 L
s
.2 1 0 r
.371 .28912 m
.3959 .28026 L
s
.8 0 1 r
.42748 .46614 m
.45128 .45828 L
s
.8 1 0 r
.35711 .25064 m
.38198 .24166 L
s
1 0 0 r
.42123 .53621 m
.4422 .52798 L
s
0 .4 1 r
.43421 .39227 m
.45931 .38407 L
s
0 1 1 r
.42277 .35634 m
.44788 .3478 L
s
1 .6 0 r
.34317 .21207 m
.36803 .20296 L
s
0 1 .4 r
.40966 .31867 m
.43474 .30991 L
s
.2 0 1 r
.44355 .42606 m
.4685 .41832 L
s
1 0 .6 r
.43495 .49721 m
.45806 .48967 L
s
.2 1 0 r
.3959 .28026 m
.42095 .27136 L
s
.8 0 1 r
.45128 .45828 m
.47592 .45105 L
s
.8 1 0 r
.38198 .24166 m
.40702 .23261 L
s
1 0 0 r
.4422 .52798 m
.4644 .52083 L
s
0 .4 1 r
.45931 .38407 m
.48482 .376 L
s
0 1 1 r
.44788 .3478 m
.47323 .33925 L
s
1 .6 0 r
.36803 .20296 m
.39304 .19378 L
s
.2 0 1 r
.4685 .41832 m
.49411 .41092 L
s
1 0 .6 r
.45806 .48967 m
.48219 .48301 L
s
0 1 .4 r
.43474 .30991 m
.45999 .3011 L
s
.2 1 0 r
.42095 .27136 m
.44617 .26239 L
s
.8 0 1 r
.47592 .45105 m
.50143 .44441 L
s
1 0 0 r
.4644 .52083 m
.4878 .51479 L
s
.8 1 0 r
.40702 .23261 m
.43221 .22351 L
s
0 .4 1 r
.48482 .376 m
.51071 .36798 L
s
0 1 1 r
.47323 .33925 m
.49879 .33067 L
s
1 0 .6 r
.48219 .48301 m
.50737 .47719 L
s
.2 0 1 r
.49411 .41092 m
.52036 .40374 L
s
1 .6 0 r
.39304 .19378 m
.41822 .18455 L
s
0 1 .4 r
.45999 .3011 m
.48542 .29224 L
s
.8 0 1 r
.50143 .44441 m
.52786 .43822 L
s
.2 1 0 r
.44617 .26239 m
.47155 .25337 L
s
1 0 0 r
.4878 .51479 m
.51236 .50989 L
s
1 0 .6 r
.50737 .47719 m
.5337 .47211 L
s
.8 1 0 r
.43221 .22351 m
.45757 .21435 L
s
0 .4 1 r
.51071 .36798 m
.53689 .35992 L
s
.2 0 1 r
.52036 .40374 m
.54718 .39659 L
s
0 1 1 r
.49879 .33067 m
.52454 .32202 L
s
.8 0 1 r
.52786 .43822 m
.55523 .43226 L
s
1 .6 0 r
.41822 .18455 m
.44355 .17525 L
s
1 0 0 r
.51236 .50989 m
.53821 .50606 L
s
0 1 .4 r
.48542 .29224 m
.51101 .28332 L
s
1 0 .6 r
.5337 .47211 m
.56135 .46751 L
s
.2 1 0 r
.47155 .25337 m
.49709 .24429 L
s
1 0 0 r
.53821 .50606 m
.56574 .50302 L
s
.2 0 1 r
.54718 .39659 m
.5744 .38928 L
s
0 .4 1 r
.53689 .35992 m
.56328 .3517 L
s
.8 0 1 r
.55523 .43226 m
.58343 .42616 L
s
.8 1 0 r
.45757 .21435 m
.48309 .20514 L
s
1 0 .6 r
.56135 .46751 m
.59046 .46288 L
s
0 1 1 r
.52454 .32202 m
.55045 .31329 L
s
1 0 0 r
.56574 .50302 m
.59559 .50008 L
s
1 .6 0 r
.44355 .17525 m
.46906 .1659 L
s
0 1 .4 r
.51101 .28332 m
.53676 .27434 L
s
1 0 0 r
.59559 .50008 m
.62782 .49609 L
s
1 0 .6 r
.59046 .46288 m
.62076 .45754 L
s
.8 0 1 r
.58343 .42616 m
.61213 .41955 L
s
.2 1 0 r
.49709 .24429 m
.5228 .23515 L
s
.2 0 1 r
.5744 .38928 m
.60178 .38162 L
s
0 .4 1 r
.56328 .3517 m
.58975 .34329 L
s
1 0 0 r
.62782 .49609 m
.66082 .49026 L
s
.8 1 0 r
.48309 .20514 m
.50878 .19586 L
s
0 1 1 r
.55045 .31329 m
.5765 .30446 L
s
1 0 .6 r
.62076 .45754 m
.65127 .45103 L
s
1 .6 0 r
.46906 .1659 m
.49473 .15648 L
s
0 1 .4 r
.53676 .27434 m
.56268 .26529 L
s
.8 0 1 r
.61213 .41955 m
.64076 .41222 L
s
.2 0 1 r
.60178 .38162 m
.62907 .37355 L
s
.2 1 0 r
.5228 .23515 m
.54868 .22595 L
s
0 .4 1 r
.58975 .34329 m
.61625 .33469 L
s
.8 1 0 r
.50878 .19586 m
.53464 .18652 L
s
0 1 1 r
.5765 .30446 m
.60267 .29553 L
s
1 .6 0 r
.49473 .15648 m
.52056 .14701 L
s
0 1 .4 r
.56268 .26529 m
.58875 .25617 L
s
.2 1 0 r
.54868 .22595 m
.57473 .21669 L
s
.8 1 0 r
.53464 .18652 m
.56066 .17712 L
s
1 .6 0 r
.52056 .14701 m
.54657 .13747 L
s
0 g
.25 Mabswid
.53391 0 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.53391 0 m
.02642 .19522 L
s
.02642 .19522 m
.53391 0 L
s
.02642 .19522 m
.03116 .2 L
s
[(-2)] .01694 .18568 .99384 1 Mshowa
.14712 .14879 m
.15172 .1537 L
s
[(-1)] .13793 .13897 .93651 1 Mshowa
.2718 .10083 m
.27624 .10588 L
s
[(0)] .26292 .09073 .87917 1 Mshowa
.40066 .05126 m
.40493 .05646 L
s
[(1)] .39212 .04087 .82184 1 Mshowa
.53391 0 m
.538 .00534 L
s
[(2)] .52574 -0.01069 .7645 1 Mshowa
.125 Mabswid
.05025 .18606 m
.05308 .18894 L
s
.07424 .17683 m
.07705 .17973 L
s
.09837 .16755 m
.10117 .17046 L
s
.12267 .1582 m
.12545 .16113 L
s
.17173 .13933 m
.17447 .14229 L
s
.19651 .1298 m
.19923 .13278 L
s
.22144 .1202 m
.22414 .1232 L
s
.24654 .11055 m
.24922 .11356 L
s
.29723 .09105 m
.29988 .0941 L
s
.32283 .0812 m
.32546 .08427 L
s
.3486 .07129 m
.35121 .07437 L
s
.37455 .06131 m
.37713 .06441 L
s
.42695 .04115 m
.4295 .04428 L
s
.45342 .03096 m
.45594 .03412 L
s
.48007 .02071 m
.48257 .02388 L
s
.5069 .01039 m
.50938 .01358 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 265.125},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001Bb000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00`oooool5o`000:3ooooo0033ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@0X?ooool00<Cooooo00?oV9RHob4Q8Oo^k^h0XOooool00<Gooooo00?oV9RH
ob4Q8Oo^k^h0X?ooool00<Kooooo00?oMgMgofIVI_ooool0Woooool00<Oooooo00?o0000oooooooo
ool0W_ooool00<?ooooo00Go0000okZj^_ooooooV9RHoa0@402Pooooo`00`oooool01OnHV9So410@
o`000?lQ8B7oc<c<0:3ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003;ooooo`;o0000Voooool00<Sooooo0ol000000ooooooo0000ooooo`2Jooooo`00a_oo
ool2o`0000Cooooo0_l0002Jooooo`00`oooool3o`0000Kooooo00?o0000ooooool00000VOooool0
0<3ooooo1?l00008ooooo`04o`000?ooooooooooo`0009Sooooo002Hooooo`Co000000?o410@oooo
ooooool07oooool2o`0000Cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0002H
ooooo`00V_ooool00ol0003oooooooooo`0Nooooo`?o00003_ooool01Ol0003ooooooooooooooooo
000009Oooooo002Jooooo`03o`000?oooooooooo01cooooo0_l0000Aooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0U?ooool009[ooooo00?o0000ooooooooool06Oooool3o`0000;o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo09?o
oooo002Jooooo`03o`000?oooooooooo01Kooooo0ol0000Fooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^08Kooooo002Jooooo`03o`00
0?oooooooooo01Cooooo0_l0000Iooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1oooool01OmgMgOoV9RHoooooonHV9SoMgMg08Kooooo002Jooooo`03o`000?oooooooooo017ooooo
0ol000000ooooooo0000ooooo`0Hooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1_ooool01Ol@413ooooooooooooooooo410@08Kooooo002Hooooo`03oeEEEOmVIVKo0000017ooooo
0_l0000Nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool01Ol0003ooooo
oooooooooooo000008Kooooo002Yooooo`?o00008?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000026ooooo`00Yoooool3o`0002;ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@
4100Q_ooool00:Cooooo0ol00002ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Q_ooool00:7ooooo
0ol0000Xooooo`03o`000?oooooooooo00Sooooo0_l00004ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h0Q_ooool009oooooo0_l0000[ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo
0000S_ooool009cooooo0ol000000ooooooo0000ooooo`0Zooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0S?ooool009[ooooo0_l00005ooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`2;ooooo`00Uoooool3o`0003;ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`2:ooooo`00K?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^02?ooooo0ol000000ooooooo0000ooooo`0booooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0ROooool006cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Qooooo`;o0000>?ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo08Wooooo001/ooooo`05oa0@4?oooooooooo
ooooool@41007_ooool3o`0003[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`28
ooooo`00K?ooool01Ol0003ooooooooooooooooo000001cooooo0ol0000looooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0Qoooool006cooooo00Go0000ooooooooooooooooo`00000I
ooooo`?o00000_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool0Q_ooool006cooooo00Go410@oooooooooooooooooa0@400Gooooo`;o0000@_ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo08Kooooo001/ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL05?ooool3o`0004Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`25
ooooo`00K?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^017ooooo0ol00002ooooo`03o`000?oooooo
oooo04;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`24ooooo`00P?ooool2o`00
04[ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`23ooooo`00OOooool3o`0004co
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`22ooooo`00Noooool2o`000003oooo
ool0003ooooo04cooooo00?o0000ooooooooool05?ooool2o`0008?ooooo001hooooo`?o0000DOoo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooo000008?ooooo001eooooo`?o0000E?ooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo083ooooo001cooooo`Co0000EOooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo07oooooo001`ooooo`?o00001?ooool00ol0003o
ooooooooo`1Booooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0Ooooool006kooooo
0_l0001Looooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0O_ooool004?ooooo1?l0
00000ol@413oooooooooo`0Qooooo`?o0000G_ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo07gooooo0015ooooo`03o`000?oooooooooo023ooooo0ol00003ooooo`03o`000?oooooo
oooo05_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1looooo`00>_ooool6o`00
00Gooooo00?o0000ooooooooool07_ooool2o`0006Cooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`1looooo`00AOooool00ol0003oooooooooo`0Kooooo`?o0000I_ooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo07_ooooo0015ooooo`03o`000?oooooooooo01Wooooo
0_l00002ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`1jooooo`00AOooool00ol0003oooooooooo`0Fooooo`?o0000Joooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo07Wooooo0015ooooo`03o`000?oooooooooo01Cooooo0_l0001^
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0NOooool004?ooooo00?oEEEEofIV
I_l000004oooool3o`000003ooooool0003ooooo06gooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`1hooooo`00E_ooool3o`0007?ooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`1gooooo`00E?ooool2o`0007Kooooo00?o0000ooooooooool00_ooV@0Mooooo`;o0000
N?ooool0057ooooo0ol000000ooooooo0000ooooo`1eooooo`03o`000?ooV@3ooiT0023ooooo00?o
0000ooooooooool0M_ooool004oooooo0_l0001hooooo`?ooiT000?o0000ooooooooool08Oooool0
0ol0003oooooooooo`1eooooo`00C?ooool3o`0007Sooooo0_ooV@03ooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool0M?ooool004Wooooo1?l0001gooooo`?ooiT01Oooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo07?ooooo0017ooooo`;o00001?ooool00ol0003ooooo
ooooo`1aooooo`?ooiT02?ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo07;ooooo
0014ooooo`?o0000Moooool3oonI00_ooooo00?o0000ooooooooool09?ooool00ol0003ooooooooo
o`1booooo`006_ooool5o`0002?ooooo0ol0001fooooo`?ooiT03_ooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo077ooooo000Jooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@08?ooool3
o`0000?ooooo00?o0000ooooooooool0L?ooool3oonI017ooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`1`ooooo`004_ooool6o`0000?ooooo00?oV9RHob4Q8Oo^k^h07oooool2o`00
07Oooooo0_ooV@0Dooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0Koooool001co
oooo00?oV9RHob4Q8Oo^k^h06oooool3o`0007Kooooo0oooV@0Fooooo`03o`000?oooooooooo02Oo
oooo00?o0000ooooooooool0Koooool001gooooo00?oMgMgofIVI_ooool05oooool3o`0000?ooooo
00?o0000ooooooooool0L?ooool3oonI01Wooooo00?o0000ooooooooool0:?ooool00ol0003ooooo
ooooo`1^ooooo`007_ooool00ol0003oooooooooo`0Dooooo`;o0000M_ooool3oonI01cooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`1]ooooo`006_ooool01Ol0003o^[ZjoooooonH
V9So410@01?ooooo0ol0001eooooo`?ooiT07oooool00ol0003oooooooooo`05ooooo`;oc?l08ooo
ool00ol0003oooooooooo`1/ooooo`006_ooool01OnHV9So410@o`000?lQ8B7oc<c<017ooooo0_l0
0003ooooo`03o`000?oooooooooo06oooooo0oooV@0Rooooo`03o`000?oooooooooo00;ooooo0oo<
o`0Uooooo`;o0000KOooool002gooooo0ol0001eooooo`;ooiT09Oooool00ol0003oooooolco0002
olco02Sooooo0_l0001]ooooo`00:_ooool3o`0007Gooooo0oooV@0Vooooo`03olco0?l0003oc?l0
02gooooo00?o0000ooooooooool0J_ooool002Sooooo0_l00003ooooo`03o`000?oooooooooo06oo
oooo0oooV@0Vooooo`?oc?l000?oooooo`000?ooool0;_ooool00ol0003oooooooooo`1Yooooo`00
9Oooool3o`0007Cooooo0oooV@0Vooooo`?oc?l01?ooool00ol0003oooooooooo`0]ooooo`03o`00
0?oooooooooo06Wooooo000Tooooo`03o`000?oooooooooo07;ooooo0oooV@0Wooooo`;oc?l01ooo
ool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo06Sooooo000Jooooo`Co000000?o410@
ooooooooool00oooool2o`00073ooooo0oooV@0Wooooo`?oc?l02Oooool00ol0003oooooooooo`0_
ooooo`03o`000?oooooooooo06Oooooo000Looooo`03o`000?oooooooooo00Gooooo0_l0001^oooo
o`;ooiT09oooool3olco00cooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`1Voooo
o`004Oooool6o`0000Gooooo00?o0000ooooooooool01?ooool4o`0006[ooooo0oooV@0Vooooo`?o
c?l03oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Sooooo1Ol0001Iooooo`00
7?ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0006Kooooo0oooV@0Vooooo`?o
c?l04_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Oooooo00GoV9RHob4Q8Oo^
k^koooooodA4A01Iooooo`007?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0HOooool2oonI02Kooooo0oo<o`0Eooooo`03o`000?oooooooooo03;o
oooo00?o0000ooooooooool01oooool00onHV9So8B4Qonk^kP1Jooooo`007?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0GOooool3oonI02Kooooo
0_o<o`0Hooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool01oooool00onHV9So8B4Q
onk^kP1Iooooo`007?ooool00ol0003oooooooooo`04ooooo`;o00001Oooool00ol0003ooooooooo
o`1Iooooo`?ooiT09_ooool3olco01[ooooo00?o0000ooooooooool02_ooool2oc?o02Sooooo00?o
0000ooooooooool01oooool00omgMgOoIVIVooooo`1Hooooo`006_ooool00omEEEGoIVIVo`000006
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0E_ooool2oonI02Kooooo0oo<o`0M
ooooo`03o`000?oooooooooo00Oooooo0olco`0Zooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool0Eoooool002?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`1Boooo
o`?ooiT09Oooool3olco023ooooo00?o0000ooooooooool01?ooool3oc?o02kooooo0_l00004oooo
o`05o`000?nj^[[ooooooiRHV?l@4100FOooool002?ooooo0_l00008ooooo`03o`000?oooooooooo
04kooooo0oooV@0Uooooo`?oc?l08oooool01?l0003oooooooooooooool3oc?o02oooooo0_l00000
0ooooooo0000ooooo`03ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0FOooool002?ooooo00?o0000
ooooooooool02?ooool00ol0003oooooooooo`1:ooooo`?ooiT09Oooool3olco02Kooooo00Co0000
oc?o0?lco`3o<ol0=_ooool00ol0003oooooooooo`1Oooooo`008oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo04Kooooo0oooV@0Vooooo`;oc?l09oooool2oc?o0003o`000?oooooo
oooo03Oooooo00?o0000ooooooooool0Goooool002?ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`12ooooo`?ooiT09_ooool3olco02Kooooo0olco`000ooooooo0000o`00000joooo
o`03o`000?oooooooooo05kooooo000Rooooo`;o00003Oooool00ol0003oooooooooo`0oooooo`;o
oiT09_ooool3olco02Kooooo0olco`001_oooooo0000o`000?l0003oooooo`0003_ooooo00?o0000
ooooooooool0GOooool002;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0koooo
o`?ooiT09_ooool2olco02Kooooo0olco`001?oooooo0000o`000?l00005ooooo`03o`000?oooooo
oooo03Wooooo00?o0000ooooooooool0G?ooool002;ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`0gooooo`?ooiT09_ooool3olco02Kooooo0_lco`001?oooooo0000o`000?l00009
ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0G?ooool002;ooooo0ol0000?oooo
o`03o`000?oooooooooo03Cooooo0_ooV@0Vooooo`?oc?l09_ooool3oc?o00?o00003Oooool00ol0
003oooooooooo`0hooooo`03o`000?oooooooooo05_ooooo000Rooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool0<?ooool3oonI02Gooooo0oo<o`0Vooooo`?o<ol000?oooooo`000?l0
00004Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo05[ooooo000Rooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool0;?ooool3oonI02Gooooo0oo<o`0Vooooo`?o<ol0
00Coooooo`000?l0003o00005?ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo05Wo
oooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0
003o<S8bomgMg@05ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0:Oooool2oonI
02Gooooo0oo<o`0Vooooo`?o<ol000Coooooo`000?l0003o00005oooool00ol0003oooooooooo`09
ooooo`;o0?mV;Oooool00ol0003oooooooooo`1Iooooo`001oooool01OmgMgOoV9RHoooooonHV9So
MgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool04oooool0
0ol0003oooooooooo`0Uooooo`?ooiT09Oooool2olco02Kooooo0olco`001?oooooo0000o`000?l0
000Kooooo`03o`000?oooooooooo00Gooooo0ol0ofH`ooooo`03o`000?oooooooooo05Sooooo0005
o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool05Oooool00ol0003oooooooooo`0Qooooo`?ooiT09Oooool3olco02Kooooo0_lc
o`001?oooooo0000o`000?l0000Oooooo`04o`000?ooooooooooooooo`?o0?mV=?ooool00ol0003o
ooooooooo`1Gooooo`001oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_oo
ool00oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo01kooooo0_ooV@0Uooooo`?o
c?l09_ooool3oc?o00?o00008oooool00ol0003o0?mVo`3oIP0gooooo`;o0000F?ooool000Oooooo
00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo01[ooooo0oooV@0Uooooo`;oc?l09_ooool3oc?o
0003ooooool0003o000002Cooooo0ol0ofH00ol0003oooooooooo`0hooooo`03o`000?oooooooooo
05Gooooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06oooo
o`;o00006Oooool00ol0003oooooooooo`0Gooooo`;ooiT09Oooool3olco02Kooooo0_lco`001?oo
oooo0000o`000?l0000Sooooo`?o0?mV1?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooo
oooo05Gooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool05Oooool00oooV@3oooooooooo`0R
ooooo`?oc?l09_ooool3oc?o00?o00008oooool3o`3oIPOooooo00?o0000ooooooooool0>?ooool0
0ol0003oooooooooo`1Dooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005
ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0=oooool2olco02Kooooo0olco`03
o`0002?ooooo0ol0ofH;ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0Doooool0
027ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0cooooo`?oc?l09Oooool3oc?o
00?o00008oooool3o`3oIPoooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1Boooo
o`008?ooool3o`0001gooooo00?o0000ooooooooool0;oooool3olco02Gooooo0olco`000ooooooo
0000o`00000Sooooo`?o0?mV4oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo05;o
oooo000Qooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0;?ooool2olco02Gooooo
0olco`001?oooooo0000o`000?l0000Rooooo`?o0?mV5oooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo057ooooo000Pooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool0
:?ooool3olco02Gooooo0_lco`001?oooooo0000o`000?l0000Rooooo`?o0?mV6oooool00ol0003o
ooooooooo`0gooooo`03o`000?oooooooooo053ooooo000Pooooo`03o`000?oooooooooo023ooooo
00?o0000ooooooooool09?ooool3olco02Gooooo0olco`03o`0002?ooooo0_l0ofHNooooo`03o`00
0?oooooooooo03Sooooo00?o0000ooooooooool0Coooool0023ooooo0_l0000Rooooo`03o`000?oo
oooooooo027ooooo0_o<o`0Uooooo`?o<ol00ol0000Sooooo`?o0?mV8Oooool00ol0003ooooooooo
o`03ooooo`;o0?oo<_ooool00ol0003oooooooooo`1?ooooo`008?ooool00ol0003oooooooooo`0R
ooooo`03o`000?oooooooooo01gooooo0oo<o`0Uooooo`;o<ol000?oooooo`000?l000008oooool3
o`3oIRGooooo00?o0000ooooool0ool00_l0ooleooooo`03o`000?oooooooooo04kooooo000Poooo
o`03o`000?oooooooooo02?ooooo00?o0000ooooooooool06Oooool3olco02Gooooo0olco`03o`00
02;ooooo0ol0ofHWooooo`;o0?oo00?o0000ooooooooool0=oooool00ol0003oooooooooo`1=oooo
o`008?ooool3o`0002Cooooo00?o0000ooooooooool05_ooool2olco02Gooooo0olco`03o`0002;o
oooo0ol0ofHWooooo`?o0?oo0oooool00ol0003oooooooooo`0fooooo`;o0000C_ooool0023ooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Booooo`?oc?l09Oooool2oc?o00?o0000
8_ooool3o`3oIROooooo0ol0ool7ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0
C?ooool001Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP07ooooo`03o`000?oooooooooo02Kooooo
00?o0000ooooooooool03_ooool3olco02Gooooo0_lco`03o`0002?ooooo0_l0ofHWooooo`?o0?oo
2_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo04_ooooo000Dooooo`05ogMgMonH
V9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo00cooooo
00?oc?l0ooooooooool08oooool3oc?o00;o00008oooool3o`3oIRKooooo0ol0ool>ooooo`03o`00
0?oooooooooo03Oooooo00?o0000ooooooooool0B_ooool001Cooooo00Go410@oooooooooooooooo
oa0@4006ooooo`;o0000:_ooool00ol0003oooooooooo`0_ooooo`;o<ol00ol0000Rooooo`?o0?mV
9_ooool3o`3ooa;ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`19ooooo`005?oo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0:_ooool00ol0003ooooo
ooooo`0[ooooo`;o<ol00ol0000Sooooo`;o0?mV9_ooool3o`3ooaKooooo00?o0000ooooooooool0
=_ooool00ol0003oooooooooo`19ooooo`005?ooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Wooooo`;o<ol00ol0000Sooooo`?o0?mV
9_ooool2o`3ooa[ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`18ooooo`005?oo
ool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool0;?ooool00ol0003ooooo
ooooo`0Sooooo`;o<ol00ol0000Sooooo`?o0?mV9_ooool3o`3ooagooooo00?o0000ooooooooool0
=_ooool00ol0003oooooooooo`17ooooo`005?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo
0_l0000^ooooo`03o`000?oooooooooo01kooooo0olco`03o`0002Cooooo0_l0ofHVooooo`?o0?oo
8?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo04Kooooo000Dooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01[ooooo
0olco`000ooooooo0000o`00000Tooooo`?o0?mV9Oooool3o`3oobCooooo00?o0000ooooooooool0
=oooool00ol0003oooooooooo`15ooooo`007oooool00ol0003oooooooooo`0_ooooo`03o`000?oo
oooooooo01Kooooo0olco`001?oooooo0000o`000?l0000Sooooo`?o0?mV9Oooool3o`3oobOooooo
00?o06Koo`000?ooool0=oooool00ol0003oooooooooo`15ooooo`007_ooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo01;ooooo0olco`001?oooooo0000o`000?l0000Rooooo`Co0?mV
9Oooool3o`3oobOooooo0ol0I_l2ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0
A?ooool001kooooo0_l0000cooooo`03o`000?oooooooooo00oooooo0_lco`001?oooooo0000o`00
0?l0000Qooooo`Co0?mV9_ooool3o`3oobOooooo0ol0I_l6ooooo`03o`000?oooooooooo03Kooooo
0_l00014ooooo`007_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00_ooooo0olc
o`03o`00027ooooo0ol0ofHUooooo`Go0?oo:?ooool2o`1Vo`[ooooo00?o0000ooooooooool0=?oo
ool00ol0003oooooo`000014ooooo`007_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooo
oooo00Oooooo0olco`000ooooooo0000o`00000Qooooo`?o0?mV9Oooool3o`3oob[ooooo0ol0I_l<
ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0@_ooool001kooooo00?o0000oooo
ooooool0=Oooool00ol0003oooooooooo`05ooooo`03oc?o0?oooooo000000;o00008?ooool3o`3o
IRGooooo0ol0oolZooooo`?o06Ko4?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo
047ooooo000Nooooo`;o0000=oooool00ol0003oooooooooo`03ooooo`?o00008Oooool2o`3oIRGo
oooo0ol0oolYooooo`Co06Ko5?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo043o
oooo000Nooooo`03o`000?oooooooooo03Oooooo00?o0000ooooool000000_l0000Qooooo`?o0?mV
9Oooool2o`3oobOooooo1Ol0I_lIooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0
?oooool001kooooo00?o0000ooooooooool0=_ooool3o`00027ooooo0ol0ofHUooooo`?o0?oo9_oo
ool3o`1Voaoooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0oooooo`007_ooool2
o`0003Gooooo0_l00003ooooo`03o`000?oooooooooo01cooooo0_l0ofHUooooo`?o0?oo9_ooool3
o`1Vob?ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`09ooooo`;o000000?o410@
ooooooooool0<?ooool001gooooo00?o0000ooooooooool0<_ooool3o`0000Kooooo00?o0000oooo
ooooool06?ooool3o`3oIRGooooo0_l0oolVooooo`?o06Ko9_ooool00ol0003oooooooooo`0foooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0<Oooool000;ooooo00Gok^k^oc8b<_l0
003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000
ooooooooool0;oooool3o`0000[ooooo00?o0000ooooooooool05?ooool3o`3oIRGooooo0ol0oolU
ooooo`?o06Ko:_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Gooooo1Ol0000b
ooooo`000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;o
oooo00Cooooo00?o0000ooooooooool0;?ooool3o`0000kooooo00?o0000ooooooooool04Oooool2
o`3oIRGooooo0ol0oolUooooo`?o06Ko;_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooo
oooo00Gooooo00CoA4A4omgMgOoooooo0000<oooool000;ooooo00Go410@oooooooooooooooooa0@
400@ooooo`03o`000?oooooooooo00?ooooo0_l0000Zooooo`?o00004_ooool00ol0003ooooooooo
o`0=ooooo`?o0?mV9Oooool2o`3oobGooooo0ol0I_lZooooo`?o<`3o1Oooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo00Cooooo00CogMgMoeEEEOoooooo0000<oooool000;ooooo00Go
0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0
9oooool2o`0001Kooooo00?o0000ooooooooool02Oooool3o`3oIRGooooo0ol0oolTooooo`?o06Ko
:_ooool3oc<0o`Wooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`04ooooo`03ogMg
Moo<c<co000003?ooooo0002ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Q
o`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool09?ooool3o`0001Wooooo00?o0000oooooooo
ool01Oooool3o`3oIRGooooo0ol0oolRooooo`Go06Ko:_ooool3oc<0o`gooooo00?o0000oooooooo
ool0=?ooool2o`0000Gooooo00?ok^k^odA4A?l00000<oooool000;ooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08Oooool3o`0001go
oooo00?o0000ooooooooool01?l0ofHVooooo`;o0?oo8_ooool3o`1Vob_ooooo1?lc0?l@ooooo`03
o`000?oooooooooo03?ooooo00Co0000oooooooooooo00001Oooool00omgMgOo0000ooooo`0boooo
o`000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool2o`00
01oooooo0ol0000Qooooo`;o0?mV9oooool3o`3oob7ooooo0ol0I_lYooooo`Go<`3o5Oooool00ol0
003oooooooooo`0eooooo`03o`000?oooooooooo03Sooooo0002ooooo`05onk^k_lb<S;o0000oc8b
<_o^k^h03?ooool4o`0000Gooooo00?o0000ooooooooool07?ooool3o`0002Gooooo00?o0000oooo
ooooool08_ooool3o`3oob7ooooo0ol0I_lYooooo`?o<`3o6oooool00ol0003oooooooooo`0eoooo
o`03o`000?oooooooooo03Oooooo000Looooo`03o`000?oooooooooo01Wooooo0ol0000Yooooo`03
o`000?oooooooooo01kooooo0ol0oolRooooo`;o06Ko:Oooool3oc<0oaoooooo00?o0000oooooooo
ool0=Oooool00ol0003oooooooooo`0fooooo`007?ooool00ol0003oooooooooo`0Gooooo`;o0000
;Oooool00ol0003oooooooooo`0Iooooo`Co0?oo8_ooool3o`1VobSooooo0olc0?lSooooo`03o`00
0?oooooooooo03Gooooo00?o0000ooooooooool0=Oooool001cooooo0_l0000Eooooo`?o0000<?oo
ool00ol0003oooooooooo`0Eooooo`?o0?oo8oooool3o`1VobOooooo1?lc0?lWooooo`03o`000?oo
oooooooo03Cooooo00?o0000ooooooooool0=Oooool001cooooo00?o0000ooooooooool04Oooool3
o`0003Cooooo00?o0000ooooooooool04Oooool3o`3oobCooooo0_l0I_lVooooo`Co<`3o:oooool0
0ol0003oooooooooo`0eooooo`03o`000?oooooooooo03Cooooo000Looooo`03o`000?oooooooooo
00kooooo0ol0000hooooo`03o`000?oooooooooo00gooooo0ol0oolTooooo`?o06Ko9?ooool4oc<0
oc3ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0cooooo`007?ooool00ol0003o
ooooooooo`0;ooooo`?o0000??ooool00ol0003oooooooooo`0:ooooo`;o0?oo9?ooool3o`1Vob;o
oooo1Olc0?leooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0<_ooool001cooooo
0_l0000:ooooo`;o0000@?ooool00ol0003oooooooooo`06ooooo`?o0?oo9?ooool2o`1Vob;ooooo
0olc0?lkooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0<_ooool001_ooooo0_l0
0008ooooo`?o0000@oooool00ol0003oooooooooo`02ooooo`?o0?oo9?ooool3o`1Vob7ooooo0olc
0?l_ooooo`?oc03o3Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo037ooooo000K
ooooo`03o`000?oooooooooo00Cooooo0ol00017ooooo`04o`000?oooooo0?ooo`3oobCooooo0ol0
I_lQooooo`?o<`3o;Oooool5ol`0oa7ooooo00?o0000ooooooooool0<oooool2o`0003;ooooo000K
ooooo`04o`000?ooooooooooooooo`?o0000BOooool3o`3oobCooooo0_l0I_lPooooo`Co<`3o;?oo
ool4ol`0oaKooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0_ooooo`006oooool4
o`0004Wooooo0ol0ool3ooooo`03o`000?oooooooooo01kooooo0ol0I_lNooooo`Co<`3o:oooool5
ol`0oa_ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0_ooooo`006oooool2o`00
04[ooooo00?o0?ooooooooooool01Oooool00ol0003oooooooooo`0Jooooo`?o06Ko7_ooool3oc<0
ob[ooooo1Oo<0?lQooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0;_ooool0017o
oooo1?l000000ol@413oooooooooo`05ooooo`03o`000?oooooooooo053ooooo00?o0000oooooooo
ool05oooool2o`1Voakooooo0olc0?lXooooo`Goc03o9oooool00ol0003oooooooooo`0dooooo`03
o`000?oooooooooo02gooooo000Cooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0
D?ooool00ol0003oooooooooo`0Cooooo`?o06Ko7Oooool3oc<0obOooooo1?o<0?l]ooooo`03o`00
0?oooooooooo03Cooooo00?o0000ooooooooool0;?ooool001?ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo00oooooo0ol0I_lNooooo`;o<`3o9Ooo
ool5ol`0oc;ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0/ooooo`004oooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool02oooool3
o`1Voakooooo0olc0?lSooooo`Coc03o=oooool00ol0003oooooooooo`0dooooo`03o`000?oooooo
oooo02_ooooo000Cooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0D?ooool00ol0
003oooooooooo`06ooooo`Co06Ko7_ooool3oc<0ob7ooooo1Oo<0?llooooo`03o`000?oooooooooo
03Cooooo00?o0000ooooooooool0:_ooool001?ooooo00?o0000ooooooooool03?ooool00ol0003o
ooooooooo`1@ooooo`03o`000?oooooooooo00;ooooo0ol0I_lPooooo`;o<`3o8Oooool3ol`0od;o
oooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Yooooo`004oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo053ooooo00Co0000o`1Vool0I_oo06Ko8?ooool3oc<0ob3o
oooo0oo<0?m6ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0:?ooool0017ooooo
00?oEEEEofIVI_l000004?ooool00ol0003oooooooooo`1=ooooo`?o06Ko00?o0000ooooooooool0
7Oooool3oc<0ob3ooooo0oo<0?m:ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0
:?ooool002Gooooo00?o0000ooooooooool0B_ooool2o`1Vo`Cooooo00?o0000ooooooooool06_oo
ool2oc<0ob3ooooo0oo<0?lgooooo`?oo`2I5?ooool00ol0003oooooooooo`0booooo`;o0000:Ooo
ool002Kooooo0_l00017ooooo`?o06Ko1oooool00ol0003oooooooooo`0Fooooo`?o<`3o7_ooool4
ol`0ocGooooo1Ooo09TGooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool09_ooool0
02Sooooo00?o0000ooooooooool0@Oooool3o`1Vo`[ooooo00?o0000ooooooooool05?ooool2oc<0
oakooooo0oo<0?ldooooo`Goo`2I7Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo
02Gooooo000Yooooo`03o`000?oooooooooo03oooooo00?o06Koooooooooool03?ooool00ol0003o
ooooooooo`0Aooooo`;o<`3o7Oooool3ol`0oc;ooooo1Ooo09TSooooo`03o`000?oooooooooo03?o
oooo00?o0000ooooooooool09Oooool002[ooooo00?o0000ooooooooool0C_ooool00ol0003ooooo
ooooo`0=ooooo`?o<`3o7?ooool3ol`0obgooooo2?oo09TYooooo`03o`000?oooooooooo03?ooooo
00?o0000ooooooooool09?ooool002_ooooo00?o0000ooooooooool0C_ooool00ol0003ooooooooo
o`09ooooo`?o<`3o7?ooool3ol`0obWooooo1ooo09Tbooooo`03o`000?oooooooooo03?ooooo00?o
0000ooooooooool08oooool002cooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`06
ooooo`;o<`3o6oooool4ol`0obOooooo1Ooo09Tjooooo`03o`000?oooooooooo03?ooooo00?o0000
ooooooooool08_ooool002gooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`02oooo
o`?o<`3o6_ooool3ol`0obGooooo1_oo09Toooooo`03o`000?oooooooooo03?ooooo00?o0000oooo
ooooool08_ooool002kooooo00?o0000ooooooooool0C_ooool01?l0003o<`3ooc<0oolc0?lKoooo
o`;oc03o8Oooool7ool0VDKooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Qoooo
o`00;oooool00ol0003oooooooooo`1<ooooo`;o<`3o00?o0000ooooooooool06_ooool00oo<0?oo
ooooooooo`0Mooooo`Coo`2IC_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo023o
oooo000`ooooo`03o`000?oooooooooo04Sooooo0olc0?l3ooooo`03o`000?oooooooooo01Oooooo
0_o<0?lLooooo`Coo`2IDoooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo01oooooo
000aooooo`;o0000A_ooool2oc<0o`Oooooo00?o0000ooooooooool05?ooool2ol`0oa[ooooo1?oo
09UHooooo`03o`000?oooooooooo03;ooooo0_l0000Pooooo`00<oooool00ol0003oooooooooo`11
ooooo`;o<`3o2_ooool00ol0003oooooooooo`0@ooooo`?oc03o6Oooool3ool0VEgooooo00?o0000
ooooooooool0<Oooool2o`00023ooooo000dooooo`03o`000?oooooooooo03gooooo0olc0?l=oooo
o`03o`000?oooooooooo00cooooo0oo<0?lIooooo`?oo`2I@Oooool4ool001_ooooo00?o0000oooo
ooooool0<oooool00ol0003oooooooooo`0Mooooo`00=Oooool00ol0003oooooooooo`0iooooo`?o
<`3o4Oooool00ol0003oooooooooo`09ooooo`;oc03o6Oooool3ool0VCoooooo1Ooo000Pooooo`03
o`000?oooooooooo03?ooooo00?o0000ooooooooool07?ooool003Kooooo00?o0000ooooooooool0
=oooool00olc0?ooooooooooo`0Cooooo`03o`000?oooooooooo00Gooooo0oo<0?lIooooo`;oo`2I
>_ooool8ool002Kooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Looooo`00=ooo
ool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo00;ooooo0_o<0?lIooooo`?oo`2I<_oo
ool:ool002oooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Kooooo`00>?ooool0
0ol0003oooooooooo`1=ooooo`04o`000?ooooooc03ool`0oaWooooo0_oo09T[ooooo`[oo`00>_oo
ool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00Oooooo00Gok^k^oc8b<_l0003o410@
olc<c00>ooooo`00>Oooool00ol0003oooooooooo`1<ooooo`;oc03o6Oooool2ool0VBCooooo2Ooo
0015ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool01_ooool01OmEEEGoMgMgoooo
oonHV9So8B4Q00kooooo000jooooo`03o`000?oooooooooo04[ooooo00Coc03ooooooooooooo0000
5Oooool3ool0VB3ooooo1_oo001>ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0
1Oooool01Ol0003ooooooooooooooooo000000kooooo000kooooo`03o`000?oooooooooo04Oooooo
0_o<0?l4ooooo`03o`000?oooooooooo013ooooo0_oo09TOooooo`Coo`00EOooool00ol0003ooooo
ooooo`0booooo`03o`000?oooooooooo00Gooooo00Go0000oiRHV?ooooooV9RHob4Q8@0>ooooo`00
??ooool00ol0003oooooooooo`14ooooo`;oc03o1oooool00ol0003oooooooooo`0=ooooo`;oo`2I
7Oooool4ool005[ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`04ooooo`05o`00
0?mEEEGo0000oa0@4?o<c<`03_ooool003gooooo0_l00011ooooo`?oc03o2_ooool00ol0003ooooo
ooooo`09ooooo`?oo`2I6oooool4ool005oooooo00?o0000ooooooooool0<_ooool2o`0000Cooooo
00?oEEEEohN7Qoooool04?ooool003oooooo00?o0000ooooooooool0>oooool3ol`0o`kooooo00?o
0000ooooooooool01_ooool2ool0VA[ooooo1?oo001Tooooo`03o`000?oooooooooo02oooooo0_l0
00000ooooooo0000ooooo`03ooooo`03omgMgOl@413oV9RH013ooooo0010ooooo`03o`000?oooooo
oooo03Sooooo0_o<0?lBooooo`03o`000?oooooooooo00?ooooo0_oo09TIooooo`?oo`00JOooool0
0ol0003oooooooooo`0aooooo`03o`000?oooooooooo00?ooooo00Coc<c<odA4A?l0003o410@3_oo
ool0047ooooo00?o0000ooooooooool0=?ooool3ol`0oaGooooo00?o0000ooooooooool00_oo09TH
ooooo`?oo`00K?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01Cooooo0012oooo
o`03o`000?oooooooooo033ooooo0oo<0?lIooooo`03o`000?oo09Wooooo01Kooooo0ooo001`oooo
o`03o`000?oooooooooo03;ooooo00?o0000ooooooooool04oooool004?ooooo00?o0000oooooooo
ool0;_ooool00oo<0?ooooooooooo`0Iooooo`;oo`2I00?o0000ooooooooool04oooool2ool007Co
oooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Booooo`00A?ooool00ol0003ooooo
ooooo`17ooooo`;oo`2I0oooool00ol0003oooooooooo`0@ooooo`;oo`00Moooool00ol0003ooooo
ooooo`0aooooo`03o`000?oooooooooo01;ooooo0015ooooo`03o`000?oooooooooo04Cooooo0_oo
09T6ooooo`03o`000?oooooooooo00cooooo0ooo001jooooo`03o`000?oooooooooo037ooooo00?o
0000ooooooooool04Oooool004Kooooo00?o0000ooooooooool0@_ooool00ooo09Woooooooooo`07
ooooo`03o`000?oooooooooo00Wooooo0_oo001nooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool04?ooool004Oooooo00?o0000ooooooooool0?oooool2ool0V@_ooooo00?o0000oooo
ooooool01_ooool2ool0083ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0?oooo
o`00B?ooool2o`0003gooooo0_oo09T>ooooo`03o`000?oooooooooo00?ooooo0_oo0023ooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool03oooool004[ooooo00?o0000ooooooooool0
=oooool3ool0VA7ooooo00?o0000ooooooooool00_oo0026ooooo`03o`000?oooooooooo037ooooo
0_l0000?ooooo`00Boooool00ol0003oooooooooo`0dooooo`;oo`2I5Oooool2ool008Wooooo00?o
0000ooooooooool0<?ooool2o`0000oooooo001<ooooo`03o`000?oooooooooo037ooooo0_oo09TF
ooooo`03ool00?oooooo000008[ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0<
ooooo`00COooool00ol0003oooooooooo`0^ooooo`;oo`2I5_ooool2ool000?ooooo00?o0000oooo
ooooool0R?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00_ooooo001>ooooo`03
o`000?oooooooooo02_ooooo0_oo09TGooooo`03ool00?oooooooooo00Cooooo00?o0000oooooooo
ool0Qoooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00_ooooo001?ooooo`03o`00
0?oooooooooo02Sooooo0_oo09TGooooo`;oo`002?ooool00ol0003oooooooooo`27ooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool02_ooool0053ooooo00?o0000ooooooooool09_oo
ool00ooo09Woooooooooo`0Fooooo`03ool00?oooooooooo00Wooooo00?o0000ooooooooool0Qooo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Wooooo001Aooooo`03o`000?oooooo
oooo03cooooo0_oo000=ooooo`03o`000?oooooooooo08Oooooo00?o0000ooooooooool0<Oooool0
0ol0003oooooooooo`08ooooo`00D_ooool00ol0003oooooooooo`0jooooo`03ool00?oooooooooo
00kooooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo
00Sooooo001Cooooo`;o0000>?ooool2ool001;ooooo00?o0000ooooooooool0Qoooool00ol0003o
ooooooooo`0`ooooo`03o`000?oooooooooo00Oooooo001Eooooo`03o`000?oooooooooo03Cooooo
00?oo`00ooooooooool04oooool00ol0003oooooooooo`26ooooo`03o`000?oooooooooo037ooooo
00?o0000ooooooooool01_ooool005Kooooo00?o0000ooooooooool0<Oooool2ool001Oooooo00?o
0000ooooooooool0Q_ooool00ol0003oooooooooo`0_ooooo`?o00001oooool005Oooooo00?o0000
ooooooooool0;oooool00ooo003oooooooooo`0Hooooo`03o`000?oooooooooo08Kooooo00?o0000
ooooooooool0:oooool3o`0000;ooooo00?o0000ooooooooool01Oooool005Sooooo00?o0000oooo
ooooool0;Oooool00ooo003oooooooooo`0Jooooo`03o`000?oooooooooo08Kooooo00?o0000oooo
ooooool09oooool3o`0000Gooooo00?o0000ooooooooool01Oooool005Wooooo00?o0000oooooooo
ool0:_ooool2ool001kooooo00?o0000ooooooooool0Q_ooool00ol0003oooooooooo`0Rooooo`Co
00002?ooool00ol0003oooooooooo`05ooooo`00F_ooool00ol0003oooooooooo`0Wooooo`;oo`00
8Oooool00ol0003oooooooooo`26ooooo`03o`000?oooooooooo01kooooo0ol0000<ooooo`03o`00
0?oooooooooo00Gooooo001Kooooo`03o`000?oooooooooo02Cooooo0_oo000Tooooo`03o`000?oo
oooooooo08Gooooo00?o0000ooooooooool06_ooool4o`0000oooooo00?o0000ooooooooool01Ooo
ool005cooooo00?o0000ooooooooool08Oooool2ool002Oooooo00?o0000ooooooooool0QOooool0
0ol0003oooooooooo`0Fooooo`?o00005?ooool00ol0003oooooooooo`04ooooo`00GOooool00ol0
003oooooooooo`0Oooooo`03ool00?oooooooooo02Sooooo00?o0000ooooooooool0QOooool00ol0
003oooooooooo`0Booooo`?o00005oooool00ol0003oooooooooo`04ooooo`00G_ooool2o`0004_o
oooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`0=ooooo`Co00006_ooool00ol0003o
ooooooooo`04ooooo`00H?ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo08Gooooo
00?o0000ooooooooool02Oooool3o`0001kooooo00?o0000ooooooooool01?ooool0067ooooo00?o
0000ooooooooool0BOooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo00Cooooo1?l0
000Qooooo`03o`000?oooooooooo00Cooooo001Rooooo`03o`000?oooooooooo04Wooooo00?o0000
ooooooooool0Q?ooool01?l0003oooooooooooooool3o`0002Gooooo00?o0000ooooooooool01?oo
ool006?ooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`24ooooo`?o0000:?ooool0
0ol0003oooooooooo`04ooooo`00I?ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo
07oooooo1?l000000ooooooo0000ooooo`0Xooooo`03o`000?oooooooooo00Cooooo001Uooooo`03
o`000?oooooooooo04Wooooo00?o0000ooooooooool0Noooool3o`0000Kooooo00?o0000oooooooo
ool09_ooool00ol0003oooooooooo`04ooooo`00I_ooool00ol0003oooooooooo`19ooooo`03o`00
0?oooooooooo07Kooooo1?l0000:ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
1?ooool006Oooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`1booooo`?o00003ooo
ool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00?ooooo001Xooooo`03o`000?oooooo
oooo04Wooooo00?o0000ooooooooool0K_ooool3o`0001;ooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`03ooooo`00JOooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo
06Wooooo1?l0000Fooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool00oooool006[o
oooo0_l0001:ooooo`03o`000?oooooooooo06Gooooo0ol0000Kooooo`03o`000?oooooooooo02?o
oooo00?o0000ooooooooool00oooool006cooooo00?o0000ooooooooool0B?ooool00ol0003ooooo
ooooo`1Pooooo`Co00007oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00?ooooo
001]ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0G?ooool3o`0002Cooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`03ooooo`00K_ooool00ol0003oooooooooo`18
ooooo`03o`000?oooooooooo05Sooooo0ol0000Xooooo`03o`000?oooooooooo023ooooo00?o0000
ooooooooool00oooool006oooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`1Coooo
o`Co0000:oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00?ooooo001`ooooo`03
o`000?oooooooooo04Sooooo00?o0000ooooooooool0Coooool3o`00033ooooo00?o0000oooooooo
ool07oooool00ol0003oooooooooo`03ooooo`00LOooool00ol0003oooooooooo`18ooooo`03o`00
0?oooooooooo04[ooooo1?l0000dooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool0
0oooool007;ooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`16ooooo`?o0000>Ooo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00;ooooo001cooooo`03o`000?oooooo
oooo04Sooooo00?o0000ooooooooool0@_ooool3o`0003gooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`02ooooo`00M?ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo
03gooooo1?l00011ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool00_ooool007Go
oooo0_l00019ooooo`03o`000?oooooooooo03Wooooo0ol00015ooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool00_ooool007Oooooo00?o0000ooooooooool0Aoooool00ol0003ooooo
ooooo`0dooooo`Co0000BOooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00;ooooo
001hooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0<?ooool3o`0004kooooo00?o
0000ooooooooool06_ooool00ol0003oooooooooo`02ooooo`00NOooool00ol0003oooooooooo`17
ooooo`03o`000?oooooooooo02cooooo0ol0001Booooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool00_ooool007[ooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Woooo
o`Co0000E_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00;ooooo001kooooo`03
o`000?oooooooooo04Oooooo00?o0000ooooooooool08oooool3o`0005_ooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`02ooooo`00O?ooool00ol0003oooooooooo`17ooooo`03o`00
0?oooooooooo01kooooo1?l0001Nooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
0_ooool007gooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Jooooo`?o0000Hooo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo007ooooo001nooooo`03o`000?oooooo
oooo04Oooooo00?o0000ooooooooool05_ooool3o`0006Oooooo00?o0000ooooooooool05_ooool0
0ol0003oooooooooo`01ooooo`00Ooooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo
017ooooo1?l0001[ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool00Oooool0083o
oooo0_l00018ooooo`03o`000?oooooooooo00gooooo0ol0001`ooooo`03o`000?oooooooooo01Co
oooo00?o0000ooooooooool00Oooool008;ooooo00?o0000ooooooooool0A_ooool00ol0003ooooo
ooooo`08ooooo`Co0000M?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo007ooooo
0023ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool01?ooool3o`0007Sooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`01ooooo`00Q?ooool00ol0003oooooooooo`16
ooooo`03o`000?oooooooooo00?o0000O?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo007ooooo0025ooooo`03o`000?oooooooooo04Kooooo0_l00020ooooo`03o`000?oooooooooo
017ooooo00?o0000ooooooooool00Oooool008Kooooo00?o0000ooooooooool0AOooool00ol0003o
ooooooooo`20ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00Oooool008Oooooo
00?o0000ooooooooool0A?ooool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo00oooooo
00?o0000ooooooooool00Oooool008Sooooo00?o0000ooooooooool0@oooool00ol0003ooooooooo
o`22ooooo`03o`000?oooooooooo00oooooo0Ol00001ooooo`7ooooo0029ooooo`03o`000?oooooo
oooo04;ooooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`0?ooooo`7o00000Oooool1
ooooo`00R_ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo08?ooooo00?o0000oooo
ooooool03_ooool1o`00007ooooo0Oooool008_ooooo0_l00011ooooo`03o`000?oooooooooo08Co
oooo00?o0000ooooooooool03Oooool1o`00007ooooo0Oooool008gooooo00?o0000ooooooooool0
?_ooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo00cooooo0Ol00001ooooo`7ooooo
002>ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0Q_ooool00ol0003ooooooooo
o`0;ooooo`7o00000Oooool1ooooo`00Soooool00ol0003oooooooooo`0looooo`03o`000?oooooo
oooo08Oooooo00?o0000ooooooooool02_ooool1o`00007ooooo0Oooool0093ooooo00?o0000oooo
ooooool0>oooool00ol0003oooooooooo`27ooooo`03o`000?oooooooooo00[ooooo0Ol00001oooo
o`7ooooo002Aooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0R?ooool00ol0003o
ooooooooo`09ooooo`7o00000Oooool1ooooo`00T_ooool00ol0003oooooooooo`0iooooo`03o`00
0?oooooooooo08Wooooo00?o0000ooooooooool02?ooool1o`00007ooooo0Oooool009?ooooo00?o
0000ooooooooool0>?ooool00ol0003oooooooooo`2:ooooo`03o`000?oooooooooo00Sooooo0Ol0
0001ooooo`00U?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo08_ooooo00?o0000
ooooooooool01oooool1o`00007ooooo002Eooooo`03o`000?oooooooooo03Kooooo00?o0000oooo
ooooool0S?ooool00ol0003oooooooooo`06ooooo`7o00000Oooool009Kooooo00?o0000oooooooo
ool0=Oooool00ol0003oooooooooo`2<ooooo`03o`000?oooooooooo00Kooooo0Ol00001ooooo`00
Uoooool2o`0003Gooooo00?o0000ooooooooool0SOooool00ol0003oooooooooo`05ooooo`7o0000
0Oooool009Wooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`2>ooooo`03o`000?oo
oooooooo00Cooooo0Ol00001ooooo`00V_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooo
oooo08oooooo00?o0000ooooooooool00oooool1o`00007ooooo002Kooooo`03o`000?oooooooooo
033ooooo00?o0000ooooooooool0T?ooool00ol0003oooooooooo`02ooooo`7o00000Oooool009co
oooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`2Aooooo`05o`000?oooooooooooooo
ool000000Oooool009gooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`2Aooooo`05
o`000?ooooooooooooooool000000Oooool009kooooo00?o0000ooooooooool0;Oooool00ol0003o
ooooooooo`2Booooo`04o`000?ooooooooooooooo`7o0000002Oooooo`03o`000?oooooooooo02co
oooo00?o0000ooooooooool0Toooool00ol0003oooooooooo`01o`000000X?ooool00ol0003ooooo
ooooo`0[ooooo`03o`000?oooooooooo09Cooooo0Ol00001ooooo`7o0000002Qooooo`03o`000?oo
oooooooo02[ooooo00?o0000ooooooooool0UOooool2o`000000X_ooool2o`0002[ooooo00?o0000
ooooooooool0U?ooool3o`000000Y?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo
093ooooo1?l00003ooooo`00YOooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo08go
oooo0ol00007ooooo`00Y_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo08Wooooo
1?l0000:ooooo`00Yoooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo08Gooooo1?l0
000>ooooo`00Z?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo08;ooooo0ol0000B
ooooo`00ZOooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo07kooooo1?l0000Eoooo
o`00Z_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo07[ooooo1?l0000Iooooo`00
Zoooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo07Gooooo1?l0000Mooooo`00[?oo
ool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo07;ooooo0ol0000Qooooo`00[Oooool2
o`00023ooooo00?o0000ooooooooool0K_ooool4o`0002Cooooo002_ooooo`03o`000?oooooooooo
01gooooo00?o0000ooooooooool0J_ooool4o`0002Sooooo002`ooooo`03o`000?oooooooooo01co
oooo00?o0000ooooooooool0Ioooool3o`0002cooooo002aooooo`03o`000?oooooooooo01_ooooo
00?o0000ooooooooool0Hoooool4o`0002oooooo002booooo`03o`000?oooooooooo01[ooooo00?o
0000ooooooooool0Goooool4o`0003?ooooo002cooooo`03o`000?oooooooooo01Wooooo00?o0000
ooooooooool0G?ooool3o`0003Oooooo002dooooo`03o`000?oooooooooo01Sooooo00?o0000oooo
ooooool0F?ooool4o`0003[ooooo002eooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool0E?ooool4o`0003kooooo002fooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
D?ooool4o`0004;ooooo002gooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0COoo
ool3o`0004Kooooo002hooooo`;o00005Oooool00ol0003oooooooooo`19ooooo`Co0000BOooool0
0;[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`15ooooo`Co0000COooool00;_o
oooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`12ooooo`?o0000DOooool00;cooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`0nooooo`Co0000E?ooool00;gooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`0jooooo`Co0000F?ooool00;kooooo00?o0000
ooooooooool03_ooool00ol0003oooooooooo`0fooooo`Co0000G?ooool00;oooooo00?o0000oooo
ooooool03Oooool00ol0003oooooooooo`0cooooo`?o0000H?ooool00<3ooooo00?o0000oooooooo
ool03?ooool00ol0003oooooooooo`0_ooooo`Co0000Hoooool00<7ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`0[ooooo`Co0000Ioooool00<;ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`0Xooooo`?o0000Joooool00<?ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`0Tooooo`Co0000K_ooool00<Cooooo0_l00009ooooo`03o`000?oooooooooo
023ooooo1?l0001booooo`00a_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01go
oooo0ol0001fooooo`00aoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Wooooo
1?l0001iooooo`00b?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Gooooo1?l0
001mooooo`00bOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo1?l00021
ooooo`00b_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00kooooo0ol00025oooo
o`00boooool01Ol0003ooooooooooooooooo000000cooooo1?l00028ooooo`00c?ooool01?l0003o
ooooooooool00008ooooo`Co0000S?ooool00<gooooo00?o0000ooooool000001Oooool3o`00093o
oooo003>ooooo`;o000000?oooooo`000?l000000_l0002Cooooo`00coooool2o`0009Oooooo003o
ooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000
\
\>"],
  ImageRangeCache->{{{0, 359}, {330.375, 0}} -> {-0.0771432, -0.0315529, \
0.00350368, 0.00350368}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .92059 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-16 1.0763 -0.0263982 1.0763 [
[.01694 .18568 -11.9631 -9 ]
[.01694 .18568 .03693 0 ]
[.13793 .13897 -11.619 -9 ]
[.13793 .13897 .38095 0 ]
[.26292 .09073 -5.63752 -9 ]
[.26292 .09073 .36248 0 ]
[.39212 .04087 -5.46552 -9 ]
[.39212 .04087 .53448 0 ]
[.52574 -0.01069 -5.29351 -9 ]
[.52574 -0.01069 .70649 0 ]
[.58272 .04263 0 -6.19654 ]
[.58272 .04263 6 2.80346 ]
[.71715 .21863 0 -6.07114 ]
[.71715 .21863 6 2.92886 ]
[.83675 .37523 0 -5.963 ]
[.83675 .37523 6 3.037 ]
[.94385 .51546 0 -5.8688 ]
[.94385 .51546 6 3.1312 ]
[.01386 .20006 -12 -2.76892 ]
[.01386 .20006 0 6.23108 ]
[.00748 .25499 -24 -2.80073 ]
[.00748 .25499 0 6.19927 ]
[.00093 .31131 -6 -2.83339 ]
[.00093 .31131 0 6.16661 ]
[-0.00579 .36907 -18 -2.86695 ]
[-0.00579 .36907 0 6.13305 ]
[-0.01268 .42831 -6 -2.90143 ]
[-0.01268 .42831 0 6.09857 ]
[ 0 0 0 0 ]
[ 1 .92059 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02642 .19522 m
.53391 0 L
s
.02642 .19522 m
.03116 .2 L
s
[(-2)] .01694 .18568 .99384 1 Mshowa
.14712 .14879 m
.15172 .1537 L
s
[(-1)] .13793 .13897 .93651 1 Mshowa
.2718 .10083 m
.27624 .10588 L
s
[(0)] .26292 .09073 .87917 1 Mshowa
.40066 .05126 m
.40493 .05646 L
s
[(1)] .39212 .04087 .82184 1 Mshowa
.53391 0 m
.538 .00534 L
s
[(2)] .52574 -0.01069 .7645 1 Mshowa
.125 Mabswid
.05025 .18606 m
.05308 .18894 L
s
.07424 .17683 m
.07705 .17973 L
s
.09837 .16755 m
.10117 .17046 L
s
.12267 .1582 m
.12545 .16113 L
s
.17173 .13933 m
.17447 .14229 L
s
.19651 .1298 m
.19923 .13278 L
s
.22144 .1202 m
.22414 .1232 L
s
.24654 .11055 m
.24922 .11356 L
s
.29723 .09105 m
.29988 .0941 L
s
.32283 .0812 m
.32546 .08427 L
s
.3486 .07129 m
.35121 .07437 L
s
.37455 .06131 m
.37713 .06441 L
s
.42695 .04115 m
.4295 .04428 L
s
.45342 .03096 m
.45594 .03412 L
s
.48007 .02071 m
.48257 .02388 L
s
.5069 .01039 m
.50938 .01358 L
s
.25 Mabswid
.53391 0 m
.9804 .58403 L
s
.57014 .04738 m
.56384 .04975 L
s
[(0)] .58272 .04263 -1 .37701 Mshowa
.70445 .22307 m
.6981 .22529 L
s
[(2)] .71715 .21863 -1 .34914 Mshowa
.82396 .37939 m
.81756 .38147 L
s
[(4)] .83675 .37523 -1 .32511 Mshowa
.93098 .51938 m
.92454 .52134 L
s
[(6)] .94385 .51546 -1 .30418 Mshowa
.125 Mabswid
.60525 .09331 m
.60147 .09471 L
s
.63931 .13786 m
.63552 .13924 L
s
.67236 .1811 m
.66856 .18245 L
s
.73562 .26383 m
.7318 .26514 L
s
.7659 .30345 m
.76207 .30473 L
s
.79534 .34195 m
.7915 .34322 L
s
.85181 .41581 m
.84796 .41704 L
s
.87891 .45126 m
.87506 .45247 L
s
.90529 .48577 m
.90143 .48696 L
s
.95601 .55212 m
.95214 .55328 L
s
.25 Mabswid
.02642 .19522 m
0 .42381 L
s
.02642 .19522 m
.0327 .19281 L
s
[(-1)] .01386 .20006 1 -0.38468 Mshowa
.02006 .25024 m
.02635 .24786 L
s
[(-0.5)] .00748 .25499 1 -0.37762 Mshowa
.01354 .30664 m
.01985 .3043 L
s
[(0)] .00093 .31131 1 -0.37036 Mshowa
.00686 .36448 m
.01318 .36218 L
s
[(0.5)] -0.00579 .36907 1 -0.3629 Mshowa
0 .42381 m
.00634 .42156 L
s
[(1)] -0.01268 .42831 1 -0.35524 Mshowa
.125 Mabswid
.02516 .20612 m
.02893 .20468 L
s
.0239 .21707 m
.02767 .21563 L
s
.02262 .22807 m
.0264 .22664 L
s
.02135 .23913 m
.02512 .2377 L
s
.01877 .26141 m
.02255 .25999 L
s
.01747 .27263 m
.02125 .27122 L
s
.01617 .28391 m
.01995 .2825 L
s
.01486 .29525 m
.01864 .29384 L
s
.01222 .31809 m
.01601 .3167 L
s
.01089 .3296 m
.01468 .32821 L
s
.00955 .34117 m
.01334 .33978 L
s
.00821 .35279 m
.012 .35141 L
s
.0055 .37622 m
.0093 .37485 L
s
.00414 .38803 m
.00793 .38666 L
s
.00276 .39989 m
.00656 .39853 L
s
.00139 .41182 m
.00519 .41047 L
s
.25 Mabswid
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.54154 .92059 L
s
.54154 .92059 m
.5414 .7134 L
s
.5414 .7134 m
.02642 .19522 L
s
.53391 0 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.53391 0 m
.02642 .19522 L
s
.5414 .7134 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.54154 .92059 L
s
.54154 .92059 m
.5414 .7134 L
s
0 0 m
1 0 L
1 .92059 L
0 .92059 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.31864 .61695 m
.34377 .60338 L
s
1 0 .6 r
.30173 .58181 m
.32554 .56967 L
s
.8 0 1 r
.28587 .54669 m
.3092 .53585 L
s
.2 0 1 r
.27113 .51138 m
.29445 .50165 L
s
0 .4 1 r
.25718 .47561 m
.28066 .4667 L
s
0 1 1 r
.24357 .4392 m
.26721 .43075 L
s
0 1 .4 r
.23 .40226 m
.25371 .39394 L
s
.2 1 0 r
.21637 .36504 m
.2401 .35666 L
s
.2 0 1 r
.29445 .50165 m
.31715 .49139 L
s
.8 1 0 r
.20271 .32769 m
.22641 .31919 L
s
0 .4 1 r
.28066 .4667 m
.30396 .45742 L
s
.8 0 1 r
.3092 .53585 m
.33113 .52435 L
s
0 1 1 r
.26721 .43075 m
.29087 .4221 L
s
1 0 .6 r
.32554 .56967 m
.34675 .55673 L
s
1 .6 0 r
.18901 .29026 m
.2127 .28164 L
s
1 0 0 r
.34377 .60338 m
.36476 .58879 L
s
0 1 .4 r
.25371 .39394 m
.27754 .38552 L
s
.2 1 0 r
.2401 .35666 m
.26396 .34821 L
s
.8 1 0 r
.22641 .31919 m
.25027 .31064 L
s
0 .4 1 r
.30396 .45742 m
.32701 .44792 L
s
0 1 1 r
.29087 .4221 m
.31454 .41329 L
s
.2 0 1 r
.31715 .49139 m
.33921 .48096 L
s
1 .6 0 r
.2127 .28164 m
.23653 .27296 L
s
0 1 .4 r
.27754 .38552 m
.30148 .37701 L
s
.8 0 1 r
.33113 .52435 m
.35179 .51289 L
s
.2 1 0 r
.26396 .34821 m
.28797 .33971 L
s
1 0 .6 r
.34675 .55673 m
.3656 .5442 L
s
.8 1 0 r
.25027 .31064 m
.27428 .30203 L
s
1 0 0 r
.36476 .58879 m
.3816 .57514 L
s
0 1 1 r
.31454 .41329 m
.33822 .40439 L
s
1 .6 0 r
.23653 .27296 m
.26052 .26423 L
s
0 .4 1 r
.32701 .44792 m
.34992 .43841 L
s
0 1 .4 r
.30148 .37701 m
.32554 .36843 L
s
.2 0 1 r
.33921 .48096 m
.36095 .47073 L
s
.2 1 0 r
.28797 .33971 m
.31213 .33115 L
s
.8 0 1 r
.35179 .51289 m
.37194 .50198 L
s
.8 1 0 r
.27428 .30203 m
.29843 .29337 L
s
1 .6 0 r
.26052 .26423 m
.28466 .25544 L
s
0 1 1 r
.33822 .40439 m
.36198 .3955 L
s
0 1 .4 r
.32554 .36843 m
.34972 .3598 L
s
1 0 .6 r
.3656 .5442 m
.38365 .53268 L
s
0 .4 1 r
.34992 .43841 m
.37289 .42908 L
s
.2 1 0 r
.31213 .33115 m
.33643 .32254 L
s
.2 0 1 r
.36095 .47073 m
.3828 .46096 L
s
.8 1 0 r
.29843 .29337 m
.32274 .28466 L
s
1 0 0 r
.3816 .57514 m
.39699 .56317 L
s
1 .6 0 r
.28466 .25544 m
.30895 .2466 L
s
.8 0 1 r
.37194 .50198 m
.39234 .49184 L
s
0 1 1 r
.36198 .3955 m
.38592 .38671 L
s
0 1 .4 r
.34972 .3598 m
.37406 .35116 L
s
0 .4 1 r
.37289 .42908 m
.39613 .42007 L
s
.2 1 0 r
.33643 .32254 m
.36089 .31387 L
s
1 0 .6 r
.38365 .53268 m
.40219 .52227 L
s
.8 1 0 r
.32274 .28466 m
.3472 .27589 L
s
.2 0 1 r
.3828 .46096 m
.40509 .45177 L
s
1 .6 0 r
.30895 .2466 m
.33339 .23771 L
s
0 1 1 r
.38592 .38671 m
.41014 .37809 L
s
0 1 .4 r
.37406 .35116 m
.39859 .34253 L
s
1 0 0 r
.39699 .56317 m
.4131 .55265 L
s
.8 0 1 r
.39234 .49184 m
.41345 .48253 L
s
.2 1 0 r
.36089 .31387 m
.3855 .30517 L
s
0 .4 1 r
.39613 .42007 m
.4198 .41146 L
s
.8 1 0 r
.3472 .27589 m
.37182 .26706 L
s
.2 0 1 r
.40509 .45177 m
.42802 .44321 L
s
1 0 .6 r
.40219 .52227 m
.4218 .51292 L
s
1 .6 0 r
.33339 .23771 m
.35799 .22875 L
s
0 1 1 r
.41014 .37809 m
.43472 .36968 L
s
0 1 .4 r
.39859 .34253 m
.42333 .33393 L
s
.2 1 0 r
.3855 .30517 m
.41029 .29642 L
s
0 .4 1 r
.4198 .41146 m
.44401 .40328 L
s
.8 0 1 r
.41345 .48253 m
.43546 .47408 L
s
1 0 0 r
.4131 .55265 m
.43078 .54339 L
s
.8 1 0 r
.37182 .26706 m
.39659 .25818 L
s
.2 0 1 r
.42802 .44321 m
.45171 .43531 L
s
1 .6 0 r
.35799 .22875 m
.38275 .21974 L
s
1 0 .6 r
.4218 .51292 m
.44267 .50465 L
s
0 1 1 r
.43472 .36968 m
.4597 .36145 L
s
0 1 .4 r
.42333 .33393 m
.44832 .32535 L
s
.2 1 0 r
.41029 .29642 m
.43525 .28763 L
s
0 .4 1 r
.44401 .40328 m
.46885 .39551 L
s
.8 0 1 r
.43546 .47408 m
.45846 .46651 L
s
.8 1 0 r
.39659 .25818 m
.42153 .24925 L
s
1 0 0 r
.43078 .54339 m
.45014 .53539 L
s
.2 0 1 r
.45171 .43531 m
.47622 .42806 L
s
1 .6 0 r
.38275 .21974 m
.40766 .21067 L
s
1 0 .6 r
.44267 .50465 m
.46476 .49747 L
s
0 1 1 r
.4597 .36145 m
.48508 .35335 L
s
0 1 .4 r
.44832 .32535 m
.47355 .31677 L
s
0 .4 1 r
.46885 .39551 m
.49432 .38809 L
s
.8 0 1 r
.45846 .46651 m
.48247 .45982 L
s
.2 1 0 r
.43525 .28763 m
.46038 .2788 L
s
.8 1 0 r
.42153 .24925 m
.44662 .24026 L
s
.2 0 1 r
.47622 .42806 m
.50161 .42139 L
s
1 0 0 r
.45014 .53539 m
.47103 .52868 L
s
1 0 .6 r
.46476 .49747 m
.48804 .49141 L
s
1 .6 0 r
.40766 .21067 m
.43273 .20155 L
s
0 1 1 r
.48508 .35335 m
.51084 .34531 L
s
0 1 .4 r
.47355 .31677 m
.49899 .30817 L
s
.8 0 1 r
.48247 .45982 m
.50752 .45398 L
s
0 .4 1 r
.49432 .38809 m
.52044 .38088 L
s
.2 1 0 r
.46038 .2788 m
.48568 .26991 L
s
.2 0 1 r
.50161 .42139 m
.52791 .41518 L
s
1 0 0 r
.47103 .52868 m
.49325 .52337 L
s
.8 1 0 r
.44662 .24026 m
.47188 .23121 L
s
1 0 .6 r
.48804 .49141 m
.51248 .48649 L
s
.8 0 1 r
.50752 .45398 m
.53373 .44888 L
s
1 .6 0 r
.43273 .20155 m
.45797 .19236 L
s
0 1 1 r
.51084 .34531 m
.5369 .33721 L
s
0 .4 1 r
.52044 .38088 m
.54713 .37371 L
s
0 1 .4 r
.49899 .30817 m
.52461 .29949 L
s
1 0 0 r
.49325 .52337 m
.51664 .51951 L
s
.2 0 1 r
.52791 .41518 m
.55514 .40919 L
s
1 0 .6 r
.51248 .48649 m
.5382 .48264 L
s
.2 1 0 r
.48568 .26991 m
.51114 .26096 L
s
.8 0 1 r
.53373 .44888 m
.56124 .44426 L
s
1 0 0 r
.51664 .51951 m
.54131 .51708 L
s
.8 1 0 r
.47188 .23121 m
.4973 .2221 L
s
1 0 .6 r
.5382 .48264 m
.56559 .47959 L
s
0 .4 1 r
.54713 .37371 m
.57422 .36637 L
s
0 1 1 r
.5369 .33721 m
.56315 .32897 L
s
.2 0 1 r
.55514 .40919 m
.58321 .40307 L
s
1 0 0 r
.54131 .51708 m
.56803 .51577 L
s
1 .6 0 r
.45797 .19236 m
.48337 .18312 L
s
.8 0 1 r
.56124 .44426 m
.5902 .43962 L
s
0 1 .4 r
.52461 .29949 m
.55039 .29073 L
s
1 0 0 r
.56803 .51577 m
.59842 .51463 L
s
1 0 .6 r
.56559 .47959 m
.5953 .47664 L
s
1 0 0 r
.59842 .51463 m
.63309 .51185 L
s
.2 1 0 r
.51114 .26096 m
.53677 .25195 L
s
1 0 .6 r
.5953 .47664 m
.62737 .47264 L
s
.8 0 1 r
.5902 .43962 m
.62035 .43426 L
s
1 0 0 r
.63309 .51185 m
.6691 .50633 L
s
.2 0 1 r
.58321 .40307 m
.61176 .39644 L
s
.8 1 0 r
.4973 .2221 m
.52288 .21294 L
s
0 .4 1 r
.57422 .36637 m
.60146 .35868 L
s
0 1 1 r
.56315 .32897 m
.58949 .32053 L
s
1 0 .6 r
.62737 .47264 m
.66021 .46678 L
s
1 .6 0 r
.48337 .18312 m
.50893 .17382 L
s
0 1 .4 r
.55039 .29073 m
.57631 .28187 L
s
.8 0 1 r
.62035 .43426 m
.6507 .42772 L
s
.2 1 0 r
.53677 .25195 m
.56255 .24287 L
s
.2 0 1 r
.61176 .39644 m
.64025 .38909 L
s
0 .4 1 r
.60146 .35868 m
.62862 .35058 L
s
.8 1 0 r
.52288 .21294 m
.54863 .20371 L
s
0 1 1 r
.58949 .32053 m
.61586 .3119 L
s
1 .6 0 r
.50893 .17382 m
.53466 .16445 L
s
0 1 .4 r
.57631 .28187 m
.60235 .27292 L
s
.2 1 0 r
.56255 .24287 m
.5885 .23373 L
s
.8 1 0 r
.54863 .20371 m
.57455 .19442 L
s
1 .6 0 r
.53466 .16445 m
.56055 .15503 L
s
0 g
.25 Mabswid
.53391 0 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.53391 0 m
.02642 .19522 L
s
.02642 .19522 m
.53391 0 L
s
.02642 .19522 m
.03116 .2 L
s
[(-2)] .01694 .18568 .99384 1 Mshowa
.14712 .14879 m
.15172 .1537 L
s
[(-1)] .13793 .13897 .93651 1 Mshowa
.2718 .10083 m
.27624 .10588 L
s
[(0)] .26292 .09073 .87917 1 Mshowa
.40066 .05126 m
.40493 .05646 L
s
[(1)] .39212 .04087 .82184 1 Mshowa
.53391 0 m
.538 .00534 L
s
[(2)] .52574 -0.01069 .7645 1 Mshowa
.125 Mabswid
.05025 .18606 m
.05308 .18894 L
s
.07424 .17683 m
.07705 .17973 L
s
.09837 .16755 m
.10117 .17046 L
s
.12267 .1582 m
.12545 .16113 L
s
.17173 .13933 m
.17447 .14229 L
s
.19651 .1298 m
.19923 .13278 L
s
.22144 .1202 m
.22414 .1232 L
s
.24654 .11055 m
.24922 .11356 L
s
.29723 .09105 m
.29988 .0941 L
s
.32283 .0812 m
.32546 .08427 L
s
.3486 .07129 m
.35121 .07437 L
s
.37455 .06131 m
.37713 .06441 L
s
.42695 .04115 m
.4295 .04428 L
s
.45342 .03096 m
.45594 .03412 L
s
.48007 .02071 m
.48257 .02388 L
s
.5069 .01039 m
.50938 .01358 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 265.125},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001Bb000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00`oooool5o`000:3ooooo0033ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@0X?ooool00<Cooooo00?oV9RHob4Q8Oo^k^h0XOooool00<Gooooo00?oV9RH
ob4Q8Oo^k^h0X?ooool00<Kooooo00?oMgMgofIVI_ooool0Woooool00<Oooooo00?o0000oooooooo
ool0W_ooool00<?ooooo00Go0000okZj^_ooooooV9RHoa0@402Pooooo`00`oooool01OnHV9So410@
o`000?lQ8B7oc<c<0:3ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003;ooooo`;o0000Voooool00<Sooooo0ol000000ooooooo0000ooooo`2Jooooo`00a_oo
ool2o`0000Cooooo0_l0002Jooooo`00`oooool3o`0000Kooooo00?o0000ooooool00000VOooool0
0<3ooooo1?l00008ooooo`04o`000?ooooooooooo`0009Sooooo002Hooooo`Co000000?o410@oooo
ooooool07oooool2o`0000Cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0002H
ooooo`00V_ooool00ol0003oooooooooo`0Nooooo`?o00003_ooool01Ol0003ooooooooooooooooo
000009Oooooo002Jooooo`03o`000?oooooooooo01cooooo0_l0000Aooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0U?ooool009[ooooo00?o0000ooooooooool06Oooool3o`0000;o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo09?o
oooo002Jooooo`03o`000?oooooooooo01Kooooo0ol0000Fooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^08Kooooo002Jooooo`03o`00
0?oooooooooo01Cooooo0_l0000Iooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1oooool01OmgMgOoV9RHoooooonHV9SoMgMg08Kooooo002Jooooo`03o`000?oooooooooo017ooooo
0ol000000ooooooo0000ooooo`0Hooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1_ooool01Ol@413ooooooooooooooooo410@08Kooooo002Hooooo`03oeEEEOmVIVKo0000017ooooo
0_l0000Nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool01Ol0003ooooo
oooooooooooo000008Kooooo002Yooooo`?o00008?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000026ooooo`00Yoooool3o`0002;ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@
4100Q_ooool00:Cooooo0ol00002ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Q_ooool00:7ooooo
0ol0000Xooooo`03o`000?oooooooooo00Sooooo0_l00004ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h0Q_ooool009oooooo0_l0000[ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo
0000S_ooool009cooooo0ol000000ooooooo0000ooooo`0Zooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0S?ooool009[ooooo0_l00005ooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`2;ooooo`00Uoooool3o`0003;ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`2:ooooo`00K?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^02?ooooo0ol000000ooooooo0000ooooo`0booooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0ROooool006cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Qooooo`;o0000>?ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo08Wooooo001/ooooo`05oa0@4?oooooooooo
ooooool@41007_ooool3o`0003[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`28
ooooo`00K?ooool01Ol0003ooooooooooooooooo000001cooooo0ol0000looooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0Qoooool006cooooo00Go0000ooooooooooooooooo`00000I
ooooo`?o00000_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool0Q_ooool006cooooo00Go410@oooooooooooooooooa0@400Gooooo`;o0000@_ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo08Kooooo001/ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL05?ooool3o`0004Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`25
ooooo`00K?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^017ooooo0ol00002ooooo`03o`000?oooooo
oooo04;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`24ooooo`00P?ooool2o`00
04[ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`23ooooo`00OOooool3o`0004co
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`22ooooo`00Noooool2o`000003oooo
ool0003ooooo04cooooo00?o0000ooooooooool05?ooool2o`0008?ooooo001hooooo`?o0000DOoo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooo000008?ooooo001eooooo`?o0000E?ooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo083ooooo001cooooo`Co0000EOooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo07oooooo001`ooooo`?o00001?ooool00ol0003o
ooooooooo`1Booooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0Ooooool006kooooo
0_l0001Looooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0O_ooool004?ooooo1?l0
00000ol@413oooooooooo`0Qooooo`?o0000G_ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo07gooooo0015ooooo`03o`000?oooooooooo023ooooo0ol00003ooooo`03o`000?oooooo
oooo05_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1looooo`00>_ooool6o`00
00Gooooo00?o0000ooooooooool07_ooool2o`0006Cooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`1looooo`00AOooool00ol0003oooooooooo`0Kooooo`?o0000I_ooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo07_ooooo0015ooooo`03o`000?oooooooooo01Wooooo
0_l00002ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`1jooooo`00AOooool00ol0003oooooooooo`0Fooooo`?o0000Joooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo07Wooooo0015ooooo`03o`000?oooooooooo01Cooooo0_l0001^
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0NOooool004?ooooo00?oEEEEofIV
I_l000004oooool3o`000003ooooool0003ooooo06gooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`1hooooo`00E_ooool3o`0007?ooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`1gooooo`00E?ooool2o`0007Kooooo00?o0000ooooooooool07oooool2o`0007Sooooo
001Aooooo`?o000000?oooooo`000?ooool0MOooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo07Kooooo001?ooooo`;o0000Noooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo07Gooooo001<ooooo`?o0000OOooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
07Cooooo0019ooooo`Co0000Ooooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo07?o
oooo0017ooooo`;o00001?ooool00ol0003oooooooooo`1looooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool0L_ooool004Cooooo0ol00025ooooo`03o`000?oooooooooo00Gooooo0_oo
V@0Mooooo`03o`000?oooooooooo07;ooooo000Jooooo`Go00008oooool3o`0008Oooooo00?o0000
ooooooooool00_ooool3oonI023ooooo00?o0000ooooooooool0LOooool001[ooooo00GoV9RHob4Q
8Oo^k^koooooodA4A00Pooooo`?o00000oooool00ol0003oooooooooo`24ooooo`03o`000?oooooo
oiT000;ooiT09?ooool00ol0003oooooooooo`1`ooooo`004_ooool6o`0000?ooooo00?oV9RHob4Q
8Oo^k^h07oooool2o`0008cooooo00?ooiT0o`000?ooV@00:?ooool00ol0003oooooooooo`1_oooo
o`007?ooool00onHV9So8B4Qonk^kP0Kooooo`?o0000Roooool3oonI0003ooooool0003ooooo02So
oooo00?o0000ooooooooool0Koooool001gooooo00?oMgMgofIVI_ooool05oooool3o`0000?ooooo
00?o0000ooooooooool0QOooool3oonI00Cooooo00?o0000ooooooooool0:?ooool00ol0003ooooo
ooooo`1^ooooo`007_ooool00ol0003oooooooooo`0Dooooo`;o0000S?ooool2oonI00Oooooo00?o
0000ooooooooool0:Oooool00ol0003oooooooooo`1]ooooo`006_ooool01Ol0003o^[ZjoooooonH
V9So410@01?ooooo0ol0002;ooooo`?ooiT02Oooool00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo06cooooo000Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`04Oooool2o`0000?ooooo00?o
0000ooooooooool0QOooool3oonI00cooooo00?o0000ooooooooool0:_ooool2o`0006gooooo000]
ooooo`?o0000R_ooool3oonI00oooooo00?o0000ooooooooool0:_ooool2o`0006gooooo000Zoooo
o`?o0000R_ooool3oonI01;ooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`1Zoooo
o`00:?ooool2o`0000?ooooo00?o0000ooooooooool0Q?ooool3oonI01Gooooo00?o0000oooooooo
ool0;Oooool00ol0003oooooooooo`1Yooooo`009Oooool3o`0008[ooooo0_ooV@0Hooooo`03o`00
0?oooooooooo02gooooo00?o0000ooooooooool0JOooool002Cooooo00?o0000ooooooooool0R?oo
ool3oonI01[ooooo00?o0000ooooooooool02Oooool2olco02?ooooo00?o0000ooooooooool0J?oo
ool001[ooooo1?l000000ol@413oooooooooo`03ooooo`;o0000Q_ooool3oonI01gooooo00?o0000
ooooooooool01_ooool3olco02Kooooo00?o0000ooooooooool0Ioooool001cooooo00?o0000oooo
ooooool01Oooool2o`0008?ooooo0oooV@0Pooooo`03o`000?oooooooooo00?ooooo0oo<o`0Zoooo
o`03o`000?oooooooooo06Kooooo000Aooooo`Ko00001Oooool00ol0003oooooooooo`04ooooo`Co
0000Ooooool3oonI02?ooooo00Co0000oooooooooooooooo0_o<o`0]ooooo`03o`000?oooooooooo
00Sooooo1Ol0001Iooooo`007?ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`00
07_ooooo0oooV@0Vooooo`04o`000?o<o`3oc?l0olco033ooooo00?o0000ooooooooool01oooool0
1OnHV9So8B4Qonk^k_ooooooA4A405Wooooo000Looooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`1fooooo`;ooiT09oooool2olco0003o`000?oooooo
oooo03;ooooo00?o0000ooooooooool01oooool00onHV9So8B4Qonk^kP1Jooooo`007?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0L_ooool3oonI
02Kooooo0oo<o`02ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool01oooool00onH
V9So8B4Qonk^kP1Iooooo`007?ooool00ol0003oooooooooo`04ooooo`;o00001Oooool00ol0003o
ooooooooo`1^ooooo`?ooiT09_ooool3olco00Gooooo00?o0000ooooooooool0=?ooool00ol0003o
ooooooooo`07ooooo`03ogMgMomVIVKooooo05Sooooo000Jooooo`03oeEEEOmVIVKo000000Kooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`1[ooooo`;ooiT09_ooool3olco00Sooooo
00?o0000ooooooooool0=?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo05Oooooo
000Sooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Ioooool3oonI02Kooooo0_o<
o`0;ooooo`03o`000?oooooooooo03Gooooo0_l00004ooooo`05o`000?nj^[[ooooooiRHV?l@4100
FOooool002?ooooo0_l00008ooooo`03o`000?oooooooooo06?ooooo0oooV@0Vooooo`?oc?l03Ooo
ool00ol0003oooooooooo`0cooooo`;o000000?oooooo`000?ooool00oooool01OnHV9So410@o`00
0?lQ8B7oc<c<05Wooooo000Sooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0H?oo
ool2oonI02Kooooo0oo<o`0@ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0Gooo
ool002?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Looooo`?ooiT09Oooool3
olco01?ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`1Oooooo`008oooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo05Sooooo0oooV@0Uooooo`?oc?l05Oooool2o`00
013ooooo0_lco`0Xooooo`03o`000?oooooooooo05kooooo000Rooooo`;o00003Oooool00ol0003o
ooooooooo`1Eooooo`;ooiT09Oooool3olco01Gooooo0ol000000ooooooo0000ooooo`0<ooooo`?o
<ol0:oooool00ol0003oooooooooo`1Mooooo`008_ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo057ooooo0oooV@0Uooooo`;oc?l05Oooool3o`0000Gooooo00?o0000ooooooooool0
1oooool3oc?o02oooooo00?o0000ooooooooool0G?ooool002;ooooo00?o0000ooooooooool03_oo
ool00ol0003oooooooooo`1=ooooo`?ooiT09Oooool3olco01Cooooo0ol00009ooooo`03o`000?oo
oooooooo00?ooooo0olco`0booooo`03o`000?oooooooooo05cooooo000Rooooo`?o00003oooool0
0ol0003oooooooooo`19ooooo`?ooiT09Oooool3olco01Cooooo0ol0000=ooooo`03o`000?oooooo
<ol000;o<ol0=_ooool00ol0003oooooooooo`1Kooooo`008_ooool00ol0003oooooooooo`0@oooo
o`03o`000?oooooooooo04Gooooo0oooV@0Vooooo`;oc?l05Oooool2o`0000oooooo0_lco`000ol0
003oooooooooo`0hooooo`03o`000?oooooooooo05[ooooo000Rooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool0@Oooool3oonI02Kooooo0oo<o`0Dooooo`?o00003oooool2oc?o00?o
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1Iooooo`001oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0
003oooooooooo`0Booooo`03o`000?oooooooooo03kooooo0_ooV@0Vooooo`?oc?l05?ooool3o`00
00oooooo0olco`05ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0FOooool000Oo
oooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04oooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0>_ooool3oonI02Gooooo0oo<o`0Doooo
o`?o00003oooool3oc?o00Wooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1Hoooo
o`001Ol00002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0=_ooool3oonI02Gooooo0oo<o`0Doooo
o`?o00003oooool3oc?o00gooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1Goooo
o`001oooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0
003oooooooooo`0Fooooo`03o`000?oooooooooo03?ooooo0_ooV@0Uooooo`?oc?l05?ooool3o`00
00oooooo0olco`0Aooooo`03o`000?oooooooooo03Oooooo0_l0001Hooooo`001oooool01Ol0003o
oooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool0;oooool3oonI02Gooooo0_o<o`0Eooooo`;o00003oooool3
oc?o01Gooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1Eooooo`001oooool01Ol@
413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01_ooool2o`0001Wooooo00?o0000
ooooooooool0:oooool3oonI02Gooooo0oo<o`0Dooooo`?o00003oooool2oc?o01Wooooo00?o0000
ooooooooool0=oooool00ol0003oooooooooo`1Eooooo`001oooool01OmgMgOoV9RHoooooonHV9So
MgMg00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooo
oooo02Oooooo0oooV@0Uooooo`?oc?l05?ooool3o`0000oooooo0olco`0Kooooo`03o`000?oooooo
oooo00Wooooo0_l0ofH]ooooo`03o`000?oooooooooo05Cooooo0007ooooo`05onk^k_lb<S;o0000
oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0S
ooooo`?ooiT09Oooool3olco01Cooooo0ol0000?ooooo`?o<ol07oooool00ol0003oooooooooo`05
ooooo`?o0?mV<?ooool00ol0003oooooooooo`1Cooooo`008Oooool00ol0003oooooooooo`0Koooo
o`03o`000?oooooooooo01oooooo0oooV@0Tooooo`Coc?l05?ooool3o`0000oooooo0olco`0Soooo
o`04o`000?ooooooooooooooo`?o0?mV=?ooool00ol0003oooooooooo`1Booooo`008?ooool3o`00
01gooooo00?o0000ooooooooool06oooool3oonI02Cooooo0oo<o`0Fooooo`;o00003Oooool5oc?o
02Oooooo00?o0000o`3oI_l0ofH0=oooool00ol0003oooooooooo`1Booooo`008Oooool00ol0003o
ooooooooo`0Mooooo`03o`000?oooooooooo01Oooooo0oooV@0Tooooo`?oc?l05_ooool3o`0000co
oooo0olco`0Yooooo`?o0?mV00?oooooo`000?ooool0>?ooool00ol0003oooooooooo`1Aooooo`00
8?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo01Gooooo00?ooiT0ooooooooool0
8_ooool3olco01Kooooo0ol0000<ooooo`?o<ol0:Oooool3o`3oIPGooooo00?o0000ooooooooool0
=oooool00ol0003oooooooooo`1@ooooo`008?ooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo03Oooooo0_o<o`0Fooooo`?o00003?ooool3oc?o02Sooooo1?l0ofH8ooooo`03o`000?oo
oooooooo03Sooooo00?o0000ooooooooool0Coooool0023ooooo0_l0000Rooooo`03o`000?oooooo
oooo03?ooooo0oo<o`0Eooooo`?o00003Oooool2oc?o02Oooooo1?l0ofH=ooooo`03o`000?oooooo
oooo03Oooooo00?o0000ooooooooool0Coooool0023ooooo00?o0000ooooooooool08_ooool00ol0
003oooooooooo`0_ooooo`?oc?l05_ooool2o`0000gooooo0olco`0Vooooo`?o0?mV4_ooool00ol0
003oooooooooo`0gooooo`03o`000?oooooooooo04kooooo000Pooooo`03o`000?oooooooooo02?o
oooo00?o0000ooooooooool0;?ooool2olco01Kooooo0ol0000<ooooo`?o<ol09_ooool3o`3oIQKo
oooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`1=ooooo`008?ooool3o`0002Cooooo
00?o0000ooooooooool0:?ooool3olco01Gooooo0ol0000=ooooo`;o<ol09_ooool3o`3oIQ[ooooo
00?o0000ooooooooool0=_ooool2o`0004kooooo000Pooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool09?ooool3olco01Gooooo0ol0000=ooooo`?o<ol09Oooool3o`3oIQkooooo00?o
0000ooooooooool0=_ooool00ol0003oooooooooo`1<ooooo`005?ooool01Oo^k^ko<S8bo`000?lb
<S;ok^k^00Oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Qooooo`;oc?l05Ooo
ool3o`0000gooooo0olco`0Uooooo`?o0?mV8Oooool00ol0003oooooooooo`0gooooo`03o`000?oo
oooooooo04_ooooo000Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003ooooooooo
o`0Xooooo`03o`000?oooooooooo01gooooo0oo<o`0Eooooo`;o00003_ooool2oc?o02Gooooo0ol0
ofHUooooo`04o`000?ooooooooooooooo`?o0?oo<oooool00ol0003oooooooooo`1:ooooo`005?oo
ool01Ol@413ooooooooooooooooo410@00Kooooo0_l0000Zooooo`03o`000?oooooooooo01Wooooo
0oo<o`0Eooooo`?o00003Oooool3oc?o02Gooooo0_l0ofHWooooo`;o0?oo00?o0000o`3oool0ool0
=oooool00ol0003oooooooooo`19ooooo`005?ooool01Ol0003ooooooooooooooooo000000Kooooo
00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0Fooooo`;oc?l05Oooool3o`0000gooooo
0olco`0Uooooo`?o0?mV9_ooool3o`3oo`?ooooo00?o0000ooooooooool0=_ooool00ol0003ooooo
ooooo`19ooooo`005?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0
:oooool00ol0003oooooooooo`0Booooo`?oc?l05?ooool3o`0000kooooo0_lco`0Uooooo`?o0?mV
9_ooool3o`3oo`Oooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`18ooooo`005?oo
ool01Ol@413ooooooooooooooooo410@00Kooooo00?o0000ooooooooool0;?ooool00ol0003ooooo
ooooo`0>ooooo`?oc?l05?ooool3o`0000kooooo0olco`0Uooooo`;o0?mV9_ooool3o`3oo`_ooooo
00?o0000ooooooooool0=_ooool00ol0003oooooooooo`17ooooo`005?ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00Kooooo0_l0000^ooooo`03o`000?oooooooooo00cooooo00?oc?l0ooooooooool0
4_ooool3o`0000kooooo0olco`0Uooooo`?o0?mV9_ooool2o`3oo`kooooo00?o0000ooooooooool0
=oooool00ol0003oooooooooo`16ooooo`005?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo
00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Nooooo`;o00003_ooool3oc?o02Gooooo
0ol0ofHVooooo`?o0?oo4Oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo04Gooooo
000Oooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool06_ooool3o`0000gooooo0olc
o`0Uooooo`?o0?mV9_ooool3o`3ooaGooooo00?o0000ooooooooool0=_ooool00ol0003ooooooooo
o`15ooooo`007_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo01Kooooo0ol0000=
ooooo`?o<ol09Oooool3o`3oIRKooooo0ol0oolIooooo`03o`000?oooooooooo03Kooooo00?o0000
ooooooooool0A?ooool001kooooo0_l0000cooooo`03o`000?oooooooooo01;ooooo0ol0000>oooo
o`;o<ol09Oooool3o`3oIRKooooo0ol0oolMooooo`03o`000?oooooooooo03Kooooo0_l00014oooo
o`007_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00kooooo0ol0000>ooooo`?o
<ol09Oooool2o`3oIRKooooo0ol0oolQooooo`03o`000?oooooooooo03Cooooo00?o0000ooooool0
0000A?ooool001kooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0;ooooo`;o0000
3oooool2oc?o02Gooooo0ol0ofHTooooo`Co0?oo9?ooool00ol0003oooooooooo`0fooooo`03o`00
0?oooooooooo04;ooooo000Nooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool01ooo
ool3o`0000kooooo0olco`0Tooooo`?o0?mV8oooool4o`3oobSooooo00?o06Koo`000?ooool0=ooo
ool00ol0003oooooooooo`11ooooo`007_ooool2o`0003Oooooo00?o0000ooooooooool00oooool3
o`0000gooooo1?lco`0Tooooo`?o0?mV8oooool3o`3oobWooooo0ol0I_l2ooooo`03o`000?oooooo
oooo03Kooooo00?o0000ooooooooool0@?ooool001kooooo00?o0000ooooooooool0=oooool00ol0
003oooooo`000002o`0000gooooo0olco`0Tooooo`Co0?mV8oooool3o`3oobWooooo0ol0I_l6oooo
o`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0?oooool001kooooo00?o0000oooooooo
ool0=_ooool3o`0000gooooo0olco`0Tooooo`?o0?mV9?ooool3o`3oobWooooo0ol0I_l:ooooo`03
o`000?oooooooooo03Gooooo00?o0000ooooooooool0?oooool001kooooo0_l0000eooooo`;o0000
0oooool00ol0003oooooooooo`07ooooo`?o<ol09?ooool3o`3oIRCooooo0ol0oolYooooo`?o06Ko
3_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00Wooooo0_l000000ol@413ooooo
ooooo`0`ooooo`007Oooool00ol0003oooooooooo`0booooo`?o00001_ooool00ol0003ooooooooo
o`05ooooo`03oc?o0?oooooooooo02;ooooo0ol0ofHTooooo`?o0?oo:Oooool3o`1Voa7ooooo00?o
0000ooooooooool0=_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo037ooooo0002
ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8b
omgMg@05ooooo`03o`000?oooooooooo02oooooo0ol0000:ooooo`03o`000?oooooooooo02Oooooo
0_l0ofHTooooo`?o0?oo:?ooool4o`1VoaGooooo00?o0000ooooooooool0=_ooool00ol0003ooooo
ooooo`05ooooo`Go0000<_ooool000;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo02cooooo0ol0000>ooooo`03o`00
0?oooooooooo02?ooooo0ol0ofHSooooo`?o0?oo9_ooool5o`1Voa[ooooo00?o0000ooooooooool0
=Oooool00ol0003oooooooooo`05ooooo`04odA4A?oMgMgoooooo`0003?ooooo0002ooooo`05oa0@
4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03ooooo`;o0000:_ooool3o`0001;o
oooo00?o0000ooooooooool07oooool3o`3oIR;ooooo1?l0oolUooooo`Co06Ko8?ooool00ol0003o
ooooooooo`0eooooo`03o`000?oooooooooo00Cooooo00CogMgMoeEEEOoooooo0000<oooool000;o
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool09oooool2o`0001Kooooo00?o0000ooooooooool07?ooool2o`3oIR;ooooo0ol0oolUoooo
o`Co06Ko9Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00Cooooo00?oMgMgolc<
c?l00000<oooool000;ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Tooooo`?o00006Oooool00ol0003oooooooooo`0H
ooooo`?o0?mV8Oooool3o`3oobGooooo0ol0I_lZooooo`03o`000?oooooooooo03Cooooo0_l00005
ooooo`03onk^k_m4A4Co000003?ooooo0002ooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo027ooooo0ol0000Mooooo`03o`000?oooooo
oooo01Cooooo0ol0ofHQooooo`?o0?oo9Oooool3o`1Vobgooooo00?o0000ooooooooool0<oooool0
1?l0003oooooooooool00005ooooo`03ogMgMol0003ooooo03;ooooo0002ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`;o00007oooool3o`00027ooooo00?o
0000ooooooooool04Oooool2o`3oIR;ooooo0_l0oolUooooo`?o06Ko<Oooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo03Sooooo0002ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?oo
ool4o`0000Gooooo00?o0000ooooooooool07?ooool3o`0002Gooooo00?o0000ooooooooool03Ooo
ool3o`3oIR7ooooo0ol0oolSooooo`Co06Ko;Oooool2oc<0o`Kooooo00?o0000ooooooooool0=Ooo
ool00ol0003oooooooooo`0gooooo`007?ooool00ol0003oooooooooo`0Iooooo`?o0000:Oooool0
0ol0003oooooooooo`09ooooo`?o0?mV8Oooool3o`3oob7ooooo1Ol0I_l^ooooo`?o<`3o2Oooool0
0ol0003oooooooooo`0eooooo`03o`000?oooooooooo03Kooooo000Looooo`03o`000?oooooooooo
01Oooooo0_l0000]ooooo`03o`000?oooooooooo00Gooooo0ol0ofHRooooo`;o0?oo8Oooool3o`1V
oc3ooooo0olc0?l=ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0=Oooool001co
oooo0_l0000Eooooo`?o0000<?ooool00ol0003oooooooooo`04o`3oIR;ooooo0ol0oolPooooo`?o
06Ko;oooool4oc<0oa7ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0eooooo`00
7?ooool00ol0003oooooooooo`0Aooooo`?o0000=?ooool2o`3oIR?ooooo0ol0oolPooooo`?o06Ko
;Oooool5oc<0oaGooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0dooooo`007?oo
ool00ol0003oooooooooo`0>ooooo`?o0000>?ooool00ol0003oooooooooo`0Oooooo`;o0?oo8Ooo
ool2o`1Vob_ooooo1Olc0?lKooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0<ooo
ool001cooooo00?o0000ooooooooool02oooool3o`0003cooooo00?o0000ooooooooool06oooool3
o`3oob3ooooo0ol0I_lXooooo`Go<`3o8Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooo
oooo03;ooooo000Looooo`;o00002_ooool2o`00043ooooo00?o0000ooooooooool05oooool3o`3o
ob3ooooo0ol0I_lWooooo`Co<`3o9oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo
03;ooooo000Kooooo`;o00002?ooool3o`0004?ooooo00?o0000ooooooooool05?ooool2o`3oob3o
oooo0ol0I_lUooooo`Go<`3o;?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo037o
oooo000Kooooo`03o`000?oooooooooo00Cooooo0ol00017ooooo`03o`000?oooooooooo013ooooo
0ol0oolNooooo`Co06Ko9?ooool4oc<0oc;ooooo00?o0000ooooooooool0<oooool2o`0003;ooooo
000Kooooo`04o`000?ooooooooooooooo`?o0000Boooool00ol0003oooooooooo`0<ooooo`?o0?oo
7_ooool3o`1Vob?ooooo1Olc0?lfooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0
;oooool001_ooooo1?l0001?ooooo`03o`000?oooooooooo00Wooooo0_l0oolNooooo`?o06Ko8_oo
ool4oc<0occooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0_ooooo`006oooool2
o`0005;ooooo00?o0000ooooooooool01Oooool3o`3ooakooooo0_l0I_lQooooo`Co<`3o@Oooool0
0ol0003oooooooooo`0dooooo`03o`000?oooooooooo02kooooo000Aooooo`Co000000?o410@oooo
ooooool01Oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo00;ooooo0_l0oolOoooo
o`;o06Ko7oooool4oc<0ocKooooo0oo<0?l=ooooo`03o`000?oooooooooo03Cooooo00?o0000oooo
ooooool0;Oooool001?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1@ooooo`04
o`000?oooooo0?ooo`3ooakooooo0ol0I_lMooooo`Co<`3o=Oooool5ol`0oa7ooooo00?o0000oooo
ooooool0=?ooool00ol0003oooooooooo`0/ooooo`004oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo04kooooo0ol0oolMooooo`?o06Ko7Oooool3oc<0ocCooooo1Oo<0?lGooooo`03
o`000?oooooooooo03?ooooo00?o0000ooooooooool0;?ooool001?ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`1:ooooo`?o0?oo0oooool00ol0003oooooooooo`0Hooooo`;o06Ko
7Oooool3oc<0oc;ooooo1Oo<0?lLooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0
:oooool001?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`18ooooo`03o`3ooooo
oooooooo00Gooooo00?o0000ooooooooool05Oooool2o`1Voacooooo0olc0?l]ooooo`Soc03o8_oo
ool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02[ooooo000Cooooo`03o`000?oooooo
oooo00cooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0Booooo`;o06Ko7?ooool2
oc<0obWooooo1oo<0?l[ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0:Oooool0
01?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo
00oooooo0_l0I_lKooooo`?o<`3o9_ooool5ol`0oc?ooooo00?o0000ooooooooool0=?ooool00ol0
003oooooooooo`0Xooooo`004Oooool00omEEEGoIVIVo`00000@ooooo`03o`000?oooooooooo053o
oooo00?o0000ooooooooool03?ooool2o`1Voa[ooooo0olc0?lUooooo`Coc03o>Oooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo02Sooooo000Uooooo`03o`000?oooooooooo053ooooo
00?o0000ooooooooool02?ooool3o`1Voa[ooooo0_lc0?lSooooo`Goc03o?_ooool00ol0003ooooo
ooooo`0booooo`;o0000:Oooool002Kooooo0_l0001Aooooo`03o`000?oooooooooo00Gooooo0_l0
I_lJooooo`?o<`3o8Oooool4ol`0od?ooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0Vooooo`00:?ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00?ooooo0_l0I_lJ
ooooo`;o<`3o8?ooool4ol`0odSooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0U
ooooo`00:Oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooo06Ko00;o06Ko6_ooool2oc<0
oakooooo1?o<0?m=ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool09Oooool002[o
oooo00?o0000ooooooooool0C?ooool3o`1Voa[ooooo0olc0?lLooooo`Coc03oD_ooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo02Cooooo000[ooooo`03o`000?oooooooooo04Wooooo
0_l0I_l3ooooo`03o`000?oooooooooo01Gooooo0_lc0?lKooooo`Coc03o?_ooool4ool0VAGooooo
00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Sooooo`00;?ooool00ol0003ooooooooo
o`15ooooo`?o06Ko1_ooool00ol0003oooooooooo`0Booooo`;o<`3o6Oooool4ol`0ocgooooo1Ooo
09TJooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool08_ooool002gooooo00?o0000
ooooooooool0@Oooool3o`1Vo`[ooooo00?o0000ooooooooool03oooool2oc<0oaSooooo0oo<0?li
ooooo`Soo`2I7oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02;ooooo000^oooo
o`03o`000?oooooooooo03oooooo00?o06Koooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`;o<`3o5oooool3ol`0oc;ooooo2_oo09TXooooo`03o`000?oooooooooo03?ooooo00?o0000oooo
ooooool08Oooool002oooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`09ooooo`;o
<`3o5oooool2ol`0ob_ooooo2_oo09Tcooooo`03o`000?oooooooooo03?ooooo00?o0000oooooooo
ool08?ooool0033ooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`06ooooo`;o<`3o
5oooool2ol`0obCooooo2Ooo09Tnooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0
7oooool0037ooooo0_l0001?ooooo`03o`000?oooooooooo00;ooooo0olc0?lFooooo`?oc03o8?oo
ool6ool0VDSooooo00?o0000ooooooooool0<_ooool2o`00023ooooo000cooooo`03o`000?oooooo
oooo04gooooo00Co0000oooooolc0?oo<`3o5oooool2ol`0oaoooooo1?oo09U?ooooo`03o`000?oo
oooooooo037ooooo0_l0000Pooooo`00=?ooool00ol0003oooooooooo`1<ooooo`;o<`3o5oooool2
ol`0oagooooo1?oo09UCooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool07Oooool0
03Gooooo00?o0000ooooooooool0B?ooool3oc<0o`;ooooo00?o0000ooooooooool04_ooool2ol`0
oa_ooooo1?oo09UHooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool07?ooool003Ko
oooo00?o0000ooooooooool0AOooool2oc<0o`Kooooo00?o0000ooooooooool04?ooool00oo<0?oo
ooooooooo`0Gooooo`Coo`2IGOooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01co
oooo000gooooo`03o`000?oooooooooo04;ooooo0_lc0?l9ooooo`03o`000?oooooooooo00gooooo
0_o<0?lGooooo`?oo`2IH_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01_ooooo
000hooooo`03o`000?oooooooooo03oooooo0_lc0?l<ooooo`03o`000?oooooooooo00[ooooo0_o<
0?lFooooo`?oo`2II_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00Oooooo00Go
k^k^oc8b<_l0003o410@olc<c00>ooooo`00>Oooool00ol0003oooooooooo`0looooo`;o<`3o3ooo
ool00ol0003oooooooooo`07ooooo`;oc03o5Oooool3ool0VDWooooo1?oo000Mooooo`03o`000?oo
oooooooo03;ooooo00?o0000ooooooooool01_ooool01OmEEEGoMgMgoooooonHV9So8B4Q00kooooo
000jooooo`03o`000?oooooooooo03Wooooo0_lc0?lBooooo`03o`000?oooooooooo00Cooooo0_o<
0?lEooooo`;oo`2IA_ooool6ool0027ooooo00?o0000ooooooooool0<oooool00ol0003ooooooooo
o`05ooooo`05o`000?ooooooooooooooool000003_ooool003_ooooo00?o0000ooooooooool0=ooo
ool00olc0?ooooooooooo`0Cooooo`04o`000?ooooooooooooooo`;oc03o5Oooool2ool0VCoooooo
2Ooo000Xooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool01Oooool01Ol0003oV9RH
oooooonHV9So8B4Q00kooooo000looooo`03o`000?oooooooooo04gooooo00?o0000ol`0ooo<0?l0
5?ooool3ool0VBgooooo5?oo000booooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0
1?ooool01Ol0003oEEEEo`000?l@413oc<c<00kooooo000mooooo`;o0000COooool00oo<0?oo0000
ooooo`0Booooo`;oo`2I8Oooool?ool004Oooooo00?o0000ooooooooool0<_ooool2o`0000Cooooo
00?oEEEEohN7Qoooool04?ooool003oooooo00?o0000ooooooooool0B?ooool2ol`0o`;ooooo00?o
0000ooooooooool03_ooool2ool0VB3ooooo0ooo001Gooooo`03o`000?oooooooooo02oooooo0_l0
00000ooooooo0000ooooo`03ooooo`03omgMgOl@413oV9RH013ooooo0010ooooo`03o`000?oooooo
oooo04Gooooo0_o<0?l5ooooo`03o`000?oooooooooo00cooooo00?oo`2Iooooooooool06_ooool6
ool005_ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`03ooooo`04olc<c?m4A4Co
0000oa0@40kooooo0011ooooo`03o`000?oooooooooo04;ooooo0_o<0?l8ooooo`03o`000?oooooo
oooo00Wooooo0_oo09THooooo`Goo`00HOooool00ol0003oooooooooo`0booooo`03o`000?oooooo
oooo01Cooooo0012ooooo`03o`000?oooooooooo043ooooo00?oc03oooooooooool02Oooool00ol0
003oooooooooo`07ooooo`03ool0VOoooooooooo01Gooooo0ooo001Wooooo`03o`000?oooooooooo
03;ooooo00?o0000ooooooooool04oooool004?ooooo00?o0000ooooooooool0?Oooool2ol`0o`go
oooo00?o0000ooooooooool01?ooool2ool0VAKooooo0_oo001[ooooo`03o`000?oooooooooo03;o
oooo00?o0000ooooooooool04_ooool004Cooooo00?o0000ooooooooool0>_ooool2ol`0oa3ooooo
00?o0000ooooooooool00_ooool00ooo09Woooooooooo`0Dooooo`;oo`00K_ooool00ol0003ooooo
ooooo`0aooooo`03o`000?oooooooooo01;ooooo0015ooooo`03o`000?oooooooooo03Kooooo0oo<
0?lCooooo`04o`000?ooooooo`2Iool0VACooooo0ooo001aooooo`03o`000?oooooooooo037ooooo
00?o0000ooooooooool04Oooool004Kooooo00?o0000ooooooooool0<_ooool3ol`0oaOooooo00?o
o`2Iooooooooool04Oooool3ool007Gooooo00?o0000ooooooooool0<Oooool00ol0003ooooooooo
o`0@ooooo`00Aoooool00ol0003oooooooooo`0`ooooo`03ol`0oooooooooooo01Kooooo0_oo09T0
0ooooooo0000ooooo`0?ooooo`;oo`00N?ooool00ol0003oooooooooo`0booooo`03o`000?oooooo
oooo00oooooo0018ooooo`;o0000B?ooool00ooo09Woooooooooo`02ooooo`03o`000?oooooooooo
00_ooooo0_oo001kooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool03oooool004[o
oooo00?o0000ooooooooool0@oooool2ool0V@Kooooo00?o0000ooooooooool02?ooool2ool007ko
oooo00?o0000ooooooooool0<Oooool2o`0000oooooo001;ooooo`03o`000?oooooooooo047ooooo
00?oo`2Iooooooooool01oooool00ol0003oooooooooo`06ooooo`03ool00?oooooooooo07oooooo
00?o0000ooooooooool0<?ooool2o`0000oooooo001<ooooo`03o`000?oooooooooo03kooooo0_oo
09T;ooooo`03o`000?oooooooooo00Cooooo00?oo`00ooooooooool0POooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo00cooooo001=ooooo`03o`000?oooooooooo03_ooooo0_oo09T>
ooooo`03o`000?oooooooooo00;ooooo00?oo`00ooooooooool0Poooool00ol0003oooooooooo`0a
ooooo`03o`000?oooooooooo00_ooooo001>ooooo`03o`000?oooooooooo03Wooooo00?oo`2Ioooo
ooooool03oooool01?l0003oooooool00?oo0026ooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool02oooool004oooooo00?o0000ooooooooool0=_ooool2ool0VA?ooooo00?oo`00oooo
ooooool0Qoooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00[ooooo001@ooooo`03
o`000?oooooooooo03?ooooo0_oo09TDooooo`03ool00?oooooo000008Wooooo00?o0000oooooooo
ool0<Oooool00ol0003oooooooooo`09ooooo`00DOooool00ol0003oooooooooo`0`ooooo`;oo`2I
5Oooool01Ooo003ooooooooooooooooo000008Wooooo00?o0000ooooooooool0<Oooool00ol0003o
ooooooooo`08ooooo`00D_ooool00ol0003oooooooooo`0]ooooo`;oo`2I5Oooool2ool000Gooooo
00?o0000ooooooooool0Qoooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Sooooo
001Cooooo`;o0000:oooool2ool0VAKooooo00?oo`00ooooooooool01_ooool00ol0003ooooooooo
o`27ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool01oooool005Gooooo00?o0000
ooooooooool09oooool00ooo09Woooooooooo`0Dooooo`;oo`002_ooool00ol0003oooooooooo`26
ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool01_ooool005Kooooo00?o0000oooo
ooooool0??ooool00ooo003oooooooooo`0;ooooo`03o`000?oooooooooo08Kooooo00?o0000oooo
ooooool0;oooool3o`0000Oooooo001Gooooo`03o`000?oooooooooo03Wooooo0_oo000?ooooo`03
o`000?oooooooooo08Kooooo00?o0000ooooooooool0:oooool3o`0000;ooooo00?o0000oooooooo
ool01Oooool005Sooooo00?o0000ooooooooool0=oooool00ooo003oooooooooo`0@ooooo`03o`00
0?oooooooooo08Kooooo00?o0000ooooooooool09oooool3o`0000Gooooo00?o0000ooooooooool0
1Oooool005Wooooo00?o0000ooooooooool0=?ooool2ool001Cooooo00?o0000ooooooooool0Q_oo
ool00ol0003oooooooooo`0Rooooo`Co00002?ooool00ol0003oooooooooo`05ooooo`00F_ooool0
0ol0003oooooooooo`0booooo`03ool00?oooooooooo01Gooooo00?o0000ooooooooool0Q_ooool0
0ol0003oooooooooo`0Nooooo`?o00003?ooool00ol0003oooooooooo`05ooooo`00Foooool00ol0
003oooooooooo`0`ooooo`03ool00?oooooooooo01Oooooo00?o0000ooooooooool0QOooool00ol0
003oooooooooo`0Jooooo`Co00003oooool00ol0003oooooooooo`05ooooo`00G?ooool00ol0003o
ooooooooo`0]ooooo`;oo`006oooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo01Ko
oooo0ol0000Dooooo`03o`000?oooooooooo00Cooooo001Mooooo`03o`000?oooooooooo02_ooooo
00?oo`00ooooooooool07?ooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo01;ooooo
0ol0000Gooooo`03o`000?oooooooooo00Cooooo001Nooooo`;o0000:Oooool2ool0023ooooo00?o
0000ooooooooool0QOooool00ol0003oooooooooo`0=ooooo`Co00006_ooool00ol0003ooooooooo
o`04ooooo`00H?ooool00ol0003oooooooooo`0Tooooo`;oo`008oooool00ol0003oooooooooo`25
ooooo`03o`000?oooooooooo00Wooooo0ol0000Nooooo`03o`000?oooooooooo00Cooooo001Qoooo
o`03o`000?oooooooooo02;ooooo00?oo`00ooooooooool09?ooool00ol0003oooooooooo`25oooo
o`03o`000?oooooooooo00Cooooo1?l0000Qooooo`03o`000?oooooooooo00Cooooo001Rooooo`03
o`000?oooooooooo023ooooo00?oo`00ooooooooool09_ooool00ol0003oooooooooo`24ooooo`04
o`000?ooooooooooooooo`?o00009Oooool00ol0003oooooooooo`04ooooo`00Hoooool00ol0003o
ooooooooo`19ooooo`03o`000?oooooooooo08Cooooo0ol0000Xooooo`03o`000?oooooooooo00Co
oooo001Tooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0Ooooool4o`000003oooo
ool0003ooooo02Sooooo00?o0000ooooooooool01?ooool006Gooooo00?o0000ooooooooool0BOoo
ool00ol0003oooooooooo`1kooooo`?o00001_ooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo00Cooooo001Vooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0M_ooool4
o`0000[ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`04ooooo`00Ioooool00ol0
003oooooooooo`19ooooo`03o`000?oooooooooo07;ooooo0ol0000?ooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool00oooool006Sooooo00?o0000ooooooooool0BOooool00ol0003o
ooooooooo`1^ooooo`?o00004_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00?o
oooo001Yooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0JOooool4o`0001Kooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`03ooooo`00J_ooool2o`0004[ooooo00?o
0000ooooooooool0IOooool3o`0001_ooooo00?o0000ooooooooool08oooool00ol0003ooooooooo
o`03ooooo`00K?ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo063ooooo1?l0000O
ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool00oooool006gooooo00?o0000oooo
ooooool0B?ooool00ol0003oooooooooo`1Looooo`?o00009?ooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo00?ooooo001^ooooo`03o`000?oooooooooo04Sooooo00?o0000oooooooo
ool0F?ooool3o`0002Sooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`03ooooo`00
Koooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo05?ooooo1?l0000[ooooo`03o`00
0?oooooooooo023ooooo00?o0000ooooooooool00oooool0073ooooo00?o0000ooooooooool0B?oo
ool00ol0003oooooooooo`1?ooooo`?o0000<?ooool00ol0003oooooooooo`0Oooooo`03o`000?oo
oooooooo00?ooooo001aooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0B_ooool4
o`0003Cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`03ooooo`00L_ooool00ol0
003oooooooooo`18ooooo`03o`000?oooooooooo04Kooooo0ol0000iooooo`03o`000?oooooooooo
01kooooo00?o0000ooooooooool00_ooool007?ooooo00?o0000ooooooooool0B?ooool00ol0003o
ooooooooo`12ooooo`?o0000?Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00;o
oooo001dooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0?Oooool4o`00047ooooo
00?o0000ooooooooool07?ooool00ol0003oooooooooo`02ooooo`00MOooool2o`0004Wooooo00?o
0000ooooooooool0>Oooool3o`0004Gooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`02ooooo`00Moooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo03Cooooo1?l00019
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool00_ooool007Sooooo00?o0000oooo
ooooool0Aoooool00ol0003oooooooooo`0`ooooo`?o0000C_ooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo00;ooooo001iooooo`03o`000?oooooooooo04Oooooo00?o0000oooooooo
ool0;?ooool3o`0005;ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`02ooooo`00
N_ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo02Oooooo1?l0001Fooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool00_ooool007_ooooo00?o0000ooooooooool0Aooo
ool00ol0003oooooooooo`0Sooooo`?o0000Foooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo00;ooooo001looooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool07_ooool4
o`0005kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`02ooooo`00OOooool00ol0
003oooooooooo`17ooooo`03o`000?oooooooooo01[ooooo0ol0001Sooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool00Oooool007kooooo00?o0000ooooooooool0Aoooool00ol0003o
ooooooooo`0Fooooo`?o0000Ioooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo007o
oooo001oooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool04Oooool4o`0006_ooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`01ooooo`00P?ooool2o`0004Sooooo00?o
0000ooooooooool03Oooool3o`00073ooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`01ooooo`00P_ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo00Sooooo1?l0001d
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00Oooool008?ooooo00?o0000oooo
ooooool0A_ooool00ol0003oooooooooo`04ooooo`?o0000N?ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo007ooooo0024ooooo`03o`000?oooooooooo04Kooooo00?o0000oooooooo
ool00ol0001looooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00Oooool008Gooooo
00?o0000ooooooooool0A_ooool2o`00083ooooo00?o0000ooooooooool04Oooool00ol0003ooooo
ooooo`01ooooo`00Q_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo083ooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`01ooooo`00Qoooool00ol0003oooooooooo`14
ooooo`03o`000?oooooooooo087ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`01
ooooo`00R?ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo08;ooooo00?o0000oooo
ooooool03oooool1o`00007ooooo0Oooool008Wooooo00?o0000ooooooooool0@_ooool00ol0003o
ooooooooo`22ooooo`03o`000?oooooooooo00oooooo0Ol00001ooooo`7ooooo002:ooooo`03o`00
0?oooooooooo047ooooo00?o0000ooooooooool0Poooool00ol0003oooooooooo`0>ooooo`7o0000
0Oooool1ooooo`00Roooool2o`00047ooooo00?o0000ooooooooool0Q?ooool00ol0003ooooooooo
o`0=ooooo`7o00000Oooool1ooooo`00SOooool00ol0003oooooooooo`0nooooo`03o`000?oooooo
oooo08Gooooo00?o0000ooooooooool03?ooool1o`00007ooooo0Oooool008kooooo00?o0000oooo
ooooool0?Oooool00ol0003oooooooooo`26ooooo`03o`000?oooooooooo00_ooooo0Ol00001oooo
o`7ooooo002?ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0Qoooool00ol0003o
ooooooooo`0:ooooo`7o00000Oooool1ooooo`00T?ooool00ol0003oooooooooo`0kooooo`03o`00
0?oooooooooo08Oooooo00?o0000ooooooooool02_ooool1o`00007ooooo0Oooool0097ooooo00?o
0000ooooooooool0>_ooool00ol0003oooooooooo`28ooooo`03o`000?oooooooooo00Wooooo0Ol0
0001ooooo`7ooooo002Booooo`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0ROooool0
0ol0003oooooooooo`08ooooo`7o00000Oooool1ooooo`00Toooool00ol0003oooooooooo`0hoooo
o`03o`000?oooooooooo08[ooooo00?o0000ooooooooool02?ooool1o`00007ooooo002Dooooo`03
o`000?oooooooooo03Oooooo00?o0000ooooooooool0Roooool00ol0003oooooooooo`07ooooo`7o
00000Oooool009Gooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`2<ooooo`03o`00
0?oooooooooo00Kooooo0Ol00001ooooo`00U_ooool00ol0003oooooooooo`0eooooo`03o`000?oo
oooooooo08cooooo00?o0000ooooooooool01_ooool1o`00007ooooo002Gooooo`;o0000=Oooool0
0ol0003oooooooooo`2=ooooo`03o`000?oooooooooo00Gooooo0Ol00001ooooo`00VOooool00ol0
003oooooooooo`0booooo`03o`000?oooooooooo08kooooo00?o0000ooooooooool01?ooool1o`00
007ooooo002Jooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0Soooool00ol0003o
ooooooooo`03ooooo`7o00000Oooool009_ooooo00?o0000ooooooooool0<?ooool00ol0003ooooo
ooooo`2@ooooo`03o`000?oooooooooo00;ooooo0Ol00001ooooo`00W?ooool00ol0003ooooooooo
o`0_ooooo`03o`000?oooooooooo097ooooo00Go0000ooooooooooooooooo`000001ooooo`00WOoo
ool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo097ooooo00Go0000oooooooooooooooo
o`000001ooooo`00W_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo09;ooooo00Co
0000oooooooooooooooo0Ol0000009oooooo00?o0000ooooooooool0;?ooool00ol0003ooooooooo
o`2Cooooo`03o`000?oooooooooo007o0000002Pooooo`03o`000?oooooooooo02_ooooo00?o0000
ooooooooool0U?ooool1o`00007ooooo0Ol000000:7ooooo00?o0000ooooooooool0:_ooool00ol0
003oooooooooo`2Eooooo`;o0000002Rooooo`;o0000:_ooool00ol0003oooooooooo`2Dooooo`?o
0000002Tooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0T?ooool4o`0000?ooooo
002Uooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0SOooool3o`0000Oooooo002V
ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0ROooool4o`0000[ooooo002Woooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0QOooool4o`0000kooooo002Xooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool0P_ooool3o`0001;ooooo002Yooooo`03o`00
0?oooooooooo02;ooooo00?o0000ooooooooool0O_ooool4o`0001Gooooo002Zooooo`03o`000?oo
oooooooo027ooooo00?o0000ooooooooool0N_ooool4o`0001Wooooo002[ooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool0MOooool4o`0001gooooo002/ooooo`03o`000?oooooooooo
023ooooo00?o0000ooooooooool0L_ooool3o`00027ooooo002]ooooo`;o00008?ooool00ol0003o
ooooooooo`1^ooooo`Co00009?ooool00:oooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`1Zooooo`Co0000:?ooool00;3ooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`1Wooooo`?o0000;?ooool00;7ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1S
ooooo`Co0000;oooool00;;ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1Ooooo
o`Co0000<oooool00;?ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1Looooo`?o
0000=oooool00;Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`1Hooooo`Co0000
>_ooool00;Gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1Dooooo`Co0000?_oo
ool00;Kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1@ooooo`Co0000@_ooool0
0;Oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1=ooooo`?o0000A_ooool00;So
oooo0_l0000Eooooo`03o`000?oooooooooo04Wooooo1?l00019ooooo`00^_ooool00ol0003ooooo
ooooo`0Booooo`03o`000?oooooooooo04Gooooo1?l0001=ooooo`00^oooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo04;ooooo0ol0001Aooooo`00_?ooool00ol0003oooooooooo`0@
ooooo`03o`000?oooooooooo03kooooo1?l0001Dooooo`00_Oooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo03[ooooo1?l0001Hooooo`00__ooool00ol0003oooooooooo`0>ooooo`03
o`000?oooooooooo03Kooooo1?l0001Looooo`00_oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo03?ooooo0ol0001Pooooo`00`?ooool00ol0003oooooooooo`0<ooooo`03o`000?oo
oooooooo02oooooo1?l0001Sooooo`00`Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooo
oooo02_ooooo1?l0001Wooooo`00`_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo
02Sooooo0ol0001[ooooo`00`oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02Co
oooo1?l0001^ooooo`00a?ooool2o`0000Wooooo00?o0000ooooooooool08?ooool4o`0007;ooooo
0036ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool07Oooool3o`0007Kooooo0037
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06Oooool4o`0007Wooooo0038oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05Oooool4o`0007gooooo0039ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool04Oooool4o`00087ooooo003:ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool03_ooool3o`0008Gooooo003;ooooo`05o`000?oo
ooooooooooooool000003?ooool4o`0008Sooooo003<ooooo`04o`000?ooooooooooo`0000Sooooo
1?l0002<ooooo`00cOooool00ol0003oooooo`000005ooooo`?o0000T?ooool00<kooooo0_l00000
0ooooooo0000o`000002o`0009?ooooo003?ooooo`;o0000Uoooool00?ooooooJOooool00?oooooo
JOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {330.375, 0}} -> {-0.0771432, -0.0315529, \
0.00350368, 0.00350368}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .92059 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-16 1.0763 -0.0263982 1.0763 [
[.01694 .18568 -11.9631 -9 ]
[.01694 .18568 .03693 0 ]
[.13793 .13897 -11.619 -9 ]
[.13793 .13897 .38095 0 ]
[.26292 .09073 -5.63752 -9 ]
[.26292 .09073 .36248 0 ]
[.39212 .04087 -5.46552 -9 ]
[.39212 .04087 .53448 0 ]
[.52574 -0.01069 -5.29351 -9 ]
[.52574 -0.01069 .70649 0 ]
[.58272 .04263 0 -6.19654 ]
[.58272 .04263 6 2.80346 ]
[.71715 .21863 0 -6.07114 ]
[.71715 .21863 6 2.92886 ]
[.83675 .37523 0 -5.963 ]
[.83675 .37523 6 3.037 ]
[.94385 .51546 0 -5.8688 ]
[.94385 .51546 6 3.1312 ]
[.01386 .20006 -12 -2.76892 ]
[.01386 .20006 0 6.23108 ]
[.00748 .25499 -24 -2.80073 ]
[.00748 .25499 0 6.19927 ]
[.00093 .31131 -6 -2.83339 ]
[.00093 .31131 0 6.16661 ]
[-0.00579 .36907 -18 -2.86695 ]
[-0.00579 .36907 0 6.13305 ]
[-0.01268 .42831 -6 -2.90143 ]
[-0.01268 .42831 0 6.09857 ]
[ 0 0 0 0 ]
[ 1 .92059 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02642 .19522 m
.53391 0 L
s
.02642 .19522 m
.03116 .2 L
s
[(-2)] .01694 .18568 .99384 1 Mshowa
.14712 .14879 m
.15172 .1537 L
s
[(-1)] .13793 .13897 .93651 1 Mshowa
.2718 .10083 m
.27624 .10588 L
s
[(0)] .26292 .09073 .87917 1 Mshowa
.40066 .05126 m
.40493 .05646 L
s
[(1)] .39212 .04087 .82184 1 Mshowa
.53391 0 m
.538 .00534 L
s
[(2)] .52574 -0.01069 .7645 1 Mshowa
.125 Mabswid
.05025 .18606 m
.05308 .18894 L
s
.07424 .17683 m
.07705 .17973 L
s
.09837 .16755 m
.10117 .17046 L
s
.12267 .1582 m
.12545 .16113 L
s
.17173 .13933 m
.17447 .14229 L
s
.19651 .1298 m
.19923 .13278 L
s
.22144 .1202 m
.22414 .1232 L
s
.24654 .11055 m
.24922 .11356 L
s
.29723 .09105 m
.29988 .0941 L
s
.32283 .0812 m
.32546 .08427 L
s
.3486 .07129 m
.35121 .07437 L
s
.37455 .06131 m
.37713 .06441 L
s
.42695 .04115 m
.4295 .04428 L
s
.45342 .03096 m
.45594 .03412 L
s
.48007 .02071 m
.48257 .02388 L
s
.5069 .01039 m
.50938 .01358 L
s
.25 Mabswid
.53391 0 m
.9804 .58403 L
s
.57014 .04738 m
.56384 .04975 L
s
[(0)] .58272 .04263 -1 .37701 Mshowa
.70445 .22307 m
.6981 .22529 L
s
[(2)] .71715 .21863 -1 .34914 Mshowa
.82396 .37939 m
.81756 .38147 L
s
[(4)] .83675 .37523 -1 .32511 Mshowa
.93098 .51938 m
.92454 .52134 L
s
[(6)] .94385 .51546 -1 .30418 Mshowa
.125 Mabswid
.60525 .09331 m
.60147 .09471 L
s
.63931 .13786 m
.63552 .13924 L
s
.67236 .1811 m
.66856 .18245 L
s
.73562 .26383 m
.7318 .26514 L
s
.7659 .30345 m
.76207 .30473 L
s
.79534 .34195 m
.7915 .34322 L
s
.85181 .41581 m
.84796 .41704 L
s
.87891 .45126 m
.87506 .45247 L
s
.90529 .48577 m
.90143 .48696 L
s
.95601 .55212 m
.95214 .55328 L
s
.25 Mabswid
.02642 .19522 m
0 .42381 L
s
.02642 .19522 m
.0327 .19281 L
s
[(-1)] .01386 .20006 1 -0.38468 Mshowa
.02006 .25024 m
.02635 .24786 L
s
[(-0.5)] .00748 .25499 1 -0.37762 Mshowa
.01354 .30664 m
.01985 .3043 L
s
[(0)] .00093 .31131 1 -0.37036 Mshowa
.00686 .36448 m
.01318 .36218 L
s
[(0.5)] -0.00579 .36907 1 -0.3629 Mshowa
0 .42381 m
.00634 .42156 L
s
[(1)] -0.01268 .42831 1 -0.35524 Mshowa
.125 Mabswid
.02516 .20612 m
.02893 .20468 L
s
.0239 .21707 m
.02767 .21563 L
s
.02262 .22807 m
.0264 .22664 L
s
.02135 .23913 m
.02512 .2377 L
s
.01877 .26141 m
.02255 .25999 L
s
.01747 .27263 m
.02125 .27122 L
s
.01617 .28391 m
.01995 .2825 L
s
.01486 .29525 m
.01864 .29384 L
s
.01222 .31809 m
.01601 .3167 L
s
.01089 .3296 m
.01468 .32821 L
s
.00955 .34117 m
.01334 .33978 L
s
.00821 .35279 m
.012 .35141 L
s
.0055 .37622 m
.0093 .37485 L
s
.00414 .38803 m
.00793 .38666 L
s
.00276 .39989 m
.00656 .39853 L
s
.00139 .41182 m
.00519 .41047 L
s
.25 Mabswid
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.54154 .92059 L
s
.54154 .92059 m
.5414 .7134 L
s
.5414 .7134 m
.02642 .19522 L
s
.53391 0 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.53391 0 m
.02642 .19522 L
s
.5414 .7134 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.54154 .92059 L
s
.54154 .92059 m
.5414 .7134 L
s
0 0 m
1 0 L
1 .92059 L
0 .92059 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.33712 .62905 m
.36437 .61397 L
s
1 0 .6 r
.31968 .59402 m
.3447 .58039 L
s
.8 0 1 r
.30285 .55905 m
.32655 .54685 L
s
.2 0 1 r
.28706 .52409 m
.31029 .5132 L
s
0 .4 1 r
.27239 .48894 m
.29561 .47917 L
s
0 1 1 r
.25851 .45332 m
.28189 .44438 L
s
0 1 .4 r
.24496 .41707 m
.2685 .40859 L
s
.2 1 0 r
.23146 .38029 m
.25506 .37194 L
s
.8 1 0 r
.2179 .34323 m
.24152 .33482 L
s
0 .4 1 r
.29561 .47917 m
.31821 .46886 L
s
1 .6 0 r
.2043 .30604 m
.2279 .29751 L
s
0 1 1 r
.28189 .44438 m
.30508 .43507 L
s
.2 0 1 r
.31029 .5132 m
.33212 .50166 L
s
0 1 .4 r
.2685 .40859 m
.29205 .39992 L
s
.8 0 1 r
.32655 .54685 m
.34766 .53386 L
s
1 0 .6 r
.3447 .58039 m
.3656 .56573 L
s
.2 1 0 r
.25506 .37194 m
.27879 .36349 L
s
1 0 0 r
.36437 .61397 m
.38618 .59738 L
s
.8 1 0 r
.24152 .33482 m
.26527 .32635 L
s
1 .6 0 r
.2279 .29751 m
.25165 .28893 L
s
0 1 1 r
.30508 .43507 m
.32802 .42553 L
s
0 1 .4 r
.29205 .39992 m
.31561 .39107 L
s
0 .4 1 r
.31821 .46886 m
.34016 .45839 L
s
.2 1 0 r
.27879 .36349 m
.30262 .35496 L
s
.2 0 1 r
.33212 .50166 m
.35268 .49015 L
s
.8 1 0 r
.26527 .32635 m
.28917 .31782 L
s
.8 0 1 r
.34766 .53386 m
.36643 .52127 L
s
1 .6 0 r
.25165 .28893 m
.27554 .2803 L
s
1 0 .6 r
.3656 .56573 m
.38236 .55202 L
s
0 1 .4 r
.31561 .39107 m
.33918 .38214 L
s
0 1 1 r
.32802 .42553 m
.35083 .41598 L
s
.2 1 0 r
.30262 .35496 m
.32656 .34635 L
s
0 .4 1 r
.34016 .45839 m
.3618 .44813 L
s
1 0 0 r
.38618 .59738 m
.40131 .58242 L
s
.8 1 0 r
.28917 .31782 m
.31321 .30923 L
s
.2 0 1 r
.35268 .49015 m
.37274 .47919 L
s
1 .6 0 r
.27554 .2803 m
.29958 .27161 L
s
0 1 .4 r
.33918 .38214 m
.36283 .37321 L
s
.2 1 0 r
.32656 .34635 m
.35063 .33769 L
s
.8 0 1 r
.36643 .52127 m
.3844 .50971 L
s
0 1 1 r
.35083 .41598 m
.37369 .40662 L
s
.8 1 0 r
.31321 .30923 m
.3374 .30059 L
s
0 .4 1 r
.3618 .44813 m
.38355 .43832 L
s
1 .6 0 r
.29958 .27161 m
.32378 .26287 L
s
1 0 .6 r
.38236 .55202 m
.39768 .54 L
s
.2 0 1 r
.37274 .47919 m
.39305 .46901 L
s
0 1 .4 r
.36283 .37321 m
.38666 .3644 L
s
.2 1 0 r
.35063 .33769 m
.37485 .32901 L
s
1 0 0 r
.40131 .58242 m
.41361 .57017 L
s
0 1 1 r
.37369 .40662 m
.39682 .39758 L
s
.8 1 0 r
.3374 .30059 m
.36174 .2919 L
s
.8 0 1 r
.3844 .50971 m
.40285 .49924 L
s
1 .6 0 r
.32378 .26287 m
.34812 .25407 L
s
0 .4 1 r
.38355 .43832 m
.40573 .42909 L
s
0 1 .4 r
.38666 .3644 m
.41076 .35575 L
s
.2 1 0 r
.37485 .32901 m
.39926 .32036 L
s
1 0 .6 r
.39768 .54 m
.41371 .52943 L
s
.2 0 1 r
.39305 .46901 m
.41405 .45966 L
s
.8 1 0 r
.36174 .2919 m
.38625 .28316 L
s
0 1 1 r
.39682 .39758 m
.42037 .38894 L
s
1 .6 0 r
.34812 .25407 m
.37262 .24522 L
s
0 .4 1 r
.40573 .42909 m
.42855 .4205 L
s
1 0 0 r
.41361 .57017 m
.42658 .55981 L
s
.8 0 1 r
.40285 .49924 m
.42237 .48986 L
s
0 1 .4 r
.41076 .35575 m
.43522 .34731 L
s
.2 1 0 r
.39926 .32036 m
.42389 .31173 L
s
.8 1 0 r
.38625 .28316 m
.41091 .27439 L
s
0 1 1 r
.42037 .38894 m
.44447 .38073 L
s
.2 0 1 r
.41405 .45966 m
.43596 .45118 L
s
1 0 .6 r
.41371 .52943 m
.4313 .52013 L
s
1 .6 0 r
.37262 .24522 m
.39728 .23632 L
s
0 .4 1 r
.42855 .4205 m
.45213 .41258 L
s
.8 0 1 r
.42237 .48986 m
.44313 .48156 L
s
0 1 .4 r
.43522 .34731 m
.46008 .33905 L
s
.2 1 0 r
.42389 .31173 m
.44876 .30312 L
s
1 0 0 r
.42658 .55981 m
.4416 .55085 L
s
.8 1 0 r
.41091 .27439 m
.43575 .26557 L
s
0 1 1 r
.44447 .38073 m
.46918 .37293 L
s
.2 0 1 r
.43596 .45118 m
.45884 .44358 L
s
1 .6 0 r
.39728 .23632 m
.4221 .22736 L
s
1 0 .6 r
.4313 .52013 m
.45057 .51209 L
s
0 .4 1 r
.45213 .41258 m
.47652 .40529 L
s
.8 0 1 r
.44313 .48156 m
.46512 .47435 L
s
0 1 .4 r
.46008 .33905 m
.48534 .33093 L
s
.2 1 0 r
.44876 .30312 m
.47386 .29452 L
s
1 0 0 r
.4416 .55085 m
.45882 .54324 L
s
0 1 1 r
.46918 .37293 m
.49454 .36548 L
s
.2 0 1 r
.45884 .44358 m
.48274 .43687 L
s
.8 1 0 r
.43575 .26557 m
.46076 .25671 L
s
1 .6 0 r
.4221 .22736 m
.44707 .21834 L
s
0 .4 1 r
.47652 .40529 m
.50179 .3986 L
s
1 0 .6 r
.45057 .51209 m
.47136 .50536 L
s
.8 0 1 r
.46512 .47435 m
.48829 .46826 L
s
0 1 .4 r
.48534 .33093 m
.51098 .32285 L
s
.2 1 0 r
.47386 .29452 m
.49918 .28589 L
s
.2 0 1 r
.48274 .43687 m
.50767 .431 L
s
0 1 1 r
.49454 .36548 m
.52053 .35825 L
s
1 0 0 r
.45882 .54324 m
.47792 .53715 L
s
.8 1 0 r
.46076 .25671 m
.48594 .2478 L
s
0 .4 1 r
.50179 .3986 m
.52796 .39237 L
s
1 0 .6 r
.47136 .50536 m
.49346 .50003 L
s
1 .6 0 r
.44707 .21834 m
.4722 .20927 L
s
.8 0 1 r
.48829 .46826 m
.51261 .46332 L
s
.2 0 1 r
.50767 .431 m
.53375 .42588 L
s
0 1 .4 r
.51098 .32285 m
.53691 .31473 L
s
1 0 0 r
.47792 .53715 m
.49841 .53272 L
s
0 1 1 r
.52053 .35825 m
.54709 .35106 L
s
.2 1 0 r
.49918 .28589 m
.52468 .27719 L
s
1 0 .6 r
.49346 .50003 m
.51673 .49615 L
s
0 .4 1 r
.52796 .39237 m
.55506 .38636 L
s
.8 0 1 r
.51261 .46332 m
.5382 .45946 L
s
.8 1 0 r
.48594 .2478 m
.51127 .23882 L
s
.2 0 1 r
.53375 .42588 m
.56112 .42124 L
s
1 0 0 r
.49841 .53272 m
.51992 .53008 L
s
1 0 .6 r
.51673 .49615 m
.54128 .49371 L
s
1 .6 0 r
.4722 .20927 m
.4975 .20013 L
s
.8 0 1 r
.5382 .45946 m
.56546 .45639 L
s
0 1 1 r
.54709 .35106 m
.57404 .34369 L
s
1 0 0 r
.59928 .53017 m
.63742 .52819 L
s
.56793 .52965 m
.59928 .53017 L
s
.51992 .53008 m
.54258 .52919 L
s
0 1 .4 r
.53691 .31473 m
.56303 .30646 L
s
0 .4 1 r
.55506 .38636 m
.58299 .38021 L
s
1 0 0 r
.54258 .52919 m
.56793 .52965 L
s
1 0 .6 r
.54128 .49371 m
.56788 .4924 L
s
.2 0 1 r
.56112 .42124 m
.58995 .41658 L
s
.2 1 0 r
.52468 .27719 m
.55033 .2684 L
s
1 0 .6 r
.56788 .4924 m
.59812 .49125 L
s
1 0 0 r
.63742 .52819 m
.67703 .52255 L
s
.8 0 1 r
.56546 .45639 m
.59502 .45343 L
s
1 0 .6 r
.59812 .49125 m
.63262 .48846 L
s
.8 1 0 r
.51127 .23882 m
.53677 .22979 L
s
.8 0 1 r
.59502 .45343 m
.62693 .44941 L
s
.2 0 1 r
.58995 .41658 m
.61994 .4112 L
s
1 0 .6 r
.63262 .48846 m
.66846 .48291 L
s
0 .4 1 r
.58299 .38021 m
.6114 .37356 L
s
1 .6 0 r
.4975 .20013 m
.52296 .19094 L
s
0 1 1 r
.57404 .34369 m
.60115 .33597 L
s
0 1 .4 r
.56303 .30646 m
.58924 .298 L
s
.8 0 1 r
.62693 .44941 m
.6596 .44354 L
s
.2 1 0 r
.55033 .2684 m
.57612 .25951 L
s
.2 0 1 r
.61994 .4112 m
.65015 .40464 L
s
.8 1 0 r
.53677 .22979 m
.56243 .22068 L
s
0 .4 1 r
.6114 .37356 m
.63974 .36618 L
s
0 1 1 r
.60115 .33597 m
.62817 .32785 L
s
1 .6 0 r
.52296 .19094 m
.54858 .18169 L
s
0 1 .4 r
.58924 .298 m
.61548 .28933 L
s
.2 1 0 r
.57612 .25951 m
.60203 .25053 L
s
.8 1 0 r
.56243 .22068 m
.58825 .21151 L
s
1 .6 0 r
.54858 .18169 m
.57436 .17238 L
s
0 g
.25 Mabswid
.53391 0 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.53391 0 m
.02642 .19522 L
s
.02642 .19522 m
.53391 0 L
s
.02642 .19522 m
.03116 .2 L
s
[(-2)] .01694 .18568 .99384 1 Mshowa
.14712 .14879 m
.15172 .1537 L
s
[(-1)] .13793 .13897 .93651 1 Mshowa
.2718 .10083 m
.27624 .10588 L
s
[(0)] .26292 .09073 .87917 1 Mshowa
.40066 .05126 m
.40493 .05646 L
s
[(1)] .39212 .04087 .82184 1 Mshowa
.53391 0 m
.538 .00534 L
s
[(2)] .52574 -0.01069 .7645 1 Mshowa
.125 Mabswid
.05025 .18606 m
.05308 .18894 L
s
.07424 .17683 m
.07705 .17973 L
s
.09837 .16755 m
.10117 .17046 L
s
.12267 .1582 m
.12545 .16113 L
s
.17173 .13933 m
.17447 .14229 L
s
.19651 .1298 m
.19923 .13278 L
s
.22144 .1202 m
.22414 .1232 L
s
.24654 .11055 m
.24922 .11356 L
s
.29723 .09105 m
.29988 .0941 L
s
.32283 .0812 m
.32546 .08427 L
s
.3486 .07129 m
.35121 .07437 L
s
.37455 .06131 m
.37713 .06441 L
s
.42695 .04115 m
.4295 .04428 L
s
.45342 .03096 m
.45594 .03412 L
s
.48007 .02071 m
.48257 .02388 L
s
.5069 .01039 m
.50938 .01358 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 265.125},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001Bb000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00`oooool5o`000:3ooooo0033ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@0X?ooool00<Cooooo00?oV9RHob4Q8Oo^k^h0XOooool00<Gooooo00?oV9RH
ob4Q8Oo^k^h0X?ooool00<Kooooo00?oMgMgofIVI_ooool0Woooool00<Oooooo00?o0000oooooooo
ool0W_ooool00<?ooooo00Go0000okZj^_ooooooV9RHoa0@402Pooooo`00`oooool01OnHV9So410@
o`000?lQ8B7oc<c<0:3ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003;ooooo`;o0000Voooool00<Sooooo0ol000000ooooooo0000ooooo`2Jooooo`00a_oo
ool2o`0000Cooooo0_l0002Jooooo`00`oooool3o`0000Kooooo00?o0000ooooool00000VOooool0
0<3ooooo1?l00008ooooo`04o`000?ooooooooooo`0009Sooooo002Hooooo`Co000000?o410@oooo
ooooool07oooool2o`0000Cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0002H
ooooo`00V_ooool00ol0003oooooooooo`0Nooooo`?o00003_ooool01Ol0003ooooooooooooooooo
000009Oooooo002Jooooo`03o`000?oooooooooo01cooooo0_l0000Aooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0U?ooool009[ooooo00?o0000ooooooooool06Oooool3o`0000;o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo09?o
oooo002Jooooo`03o`000?oooooooooo01Kooooo0ol0000Fooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^08Kooooo002Jooooo`03o`00
0?oooooooooo01Cooooo0_l0000Iooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1oooool01OmgMgOoV9RHoooooonHV9SoMgMg08Kooooo002Jooooo`03o`000?oooooooooo017ooooo
0ol000000ooooooo0000ooooo`0Hooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1_ooool01Ol@413ooooooooooooooooo410@08Kooooo002Hooooo`03oeEEEOmVIVKo0000017ooooo
0_l0000Nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool01Ol0003ooooo
oooooooooooo000008Kooooo002Yooooo`?o00008?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000026ooooo`00Yoooool3o`0002;ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@
4100Q_ooool00:Cooooo0ol00002ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Q_ooool00:7ooooo
0ol0000Xooooo`03o`000?oooooooooo00Sooooo0_l00004ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h0Q_ooool009oooooo0_l0000[ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo
0000S_ooool009cooooo0ol000000ooooooo0000ooooo`0Zooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0S?ooool009[ooooo0_l00005ooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`2;ooooo`00Uoooool3o`0003;ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`2:ooooo`00K?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^02?ooooo0ol000000ooooooo0000ooooo`0booooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0ROooool006cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Qooooo`;o0000>?ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo08Wooooo001/ooooo`05oa0@4?oooooooooo
ooooool@41007_ooool3o`0003[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`28
ooooo`00K?ooool01Ol0003ooooooooooooooooo000001cooooo0ol0000looooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0Qoooool006cooooo00Go0000ooooooooooooooooo`00000I
ooooo`?o00000_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool0Q_ooool006cooooo00Go410@oooooooooooooooooa0@400Gooooo`;o0000@_ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo08Kooooo001/ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL05?ooool3o`0004Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`25
ooooo`00K?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^017ooooo0ol00002ooooo`03o`000?oooooo
oooo04;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`24ooooo`00P?ooool2o`00
04[ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`23ooooo`00OOooool3o`0004co
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`22ooooo`00Noooool2o`000003oooo
ool0003ooooo04cooooo00?o0000ooooooooool05?ooool2o`0008?ooooo001hooooo`?o0000DOoo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooo000008?ooooo001eooooo`?o0000E?ooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo083ooooo001cooooo`Co0000EOooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo07oooooo001`ooooo`?o00001?ooool00ol0003o
ooooooooo`1Booooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0Ooooool006kooooo
0_l0001Looooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0O_ooool004?ooooo1?l0
00000ol@413oooooooooo`0Qooooo`?o0000G_ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo07gooooo0015ooooo`03o`000?oooooooooo023ooooo0ol00003ooooo`03o`000?oooooo
oooo05_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1looooo`00>_ooool6o`00
00Gooooo00?o0000ooooooooool07_ooool2o`0006Cooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`1looooo`00AOooool00ol0003oooooooooo`0Kooooo`?o0000I_ooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo07_ooooo0015ooooo`03o`000?oooooooooo01Wooooo
0_l00002ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`1jooooo`00AOooool00ol0003oooooooooo`0Fooooo`?o0000Joooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo07Wooooo0015ooooo`03o`000?oooooooooo01Cooooo0_l0001^
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0NOooool004?ooooo00?oEEEEofIV
I_l000004oooool3o`000003ooooool0003ooooo06gooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`1hooooo`00E_ooool3o`0007?ooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`1gooooo`00E?ooool2o`0007Kooooo00?o0000ooooooooool07oooool2o`0007Sooooo
001Aooooo`?o000000?oooooo`000?ooool0MOooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo07Kooooo001?ooooo`;o0000Noooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo07Gooooo001<ooooo`?o0000OOooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
07Cooooo0019ooooo`Co0000Ooooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo07?o
oooo0017ooooo`;o00001?ooool00ol0003oooooooooo`1looooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool0L_ooool004Cooooo0ol00025ooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool0L_ooool001[ooooo1Ol0000Sooooo`?o0000Qoooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo077ooooo000Jooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@08?ooool3
o`0000?ooooo00?o0000ooooooooool0Q?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo073ooooo000Booooo`Ko00000oooool00onHV9So8B4Qonk^kP0Oooooo`;o0000SOooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo06oooooo000Looooo`03oiRHV?lQ8B7ok^k^01_o
oooo0ol0002?ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0Koooool001gooooo
00?oMgMgofIVI_ooool05oooool3o`0000?ooooo00?o0000ooooooooool0S?ooool00ol0003ooooo
ooooo`09ooooo`;ooiT07Oooool00ol0003oooooooooo`1^ooooo`007_ooool00ol0003ooooooooo
o`0Dooooo`;o0000UOooool00ol0003oooooooooo`06ooooo`?ooiT08?ooool00ol0003ooooooooo
o`1]ooooo`006_ooool01Ol0003o^[ZjoooooonHV9So410@01?ooooo0ol0002Gooooo`03o`000?oo
oooooooo00?ooooo0oooV@0Tooooo`03o`000?oooooooooo06cooooo000Jooooo`05oiRHV?l@413o
0000ob4Q8Oo<c<`04Oooool2o`0000?ooooo00?o0000ooooooooool0U?ooool01?l0003ooooooooo
ooooool2oonI02Oooooo0_l0001]ooooo`00;Oooool3o`0009cooooo00Co0000oonI0?ooV@3ooiT0
:Oooool2o`0006gooooo000Zooooo`?o0000WOooool2oonI0003o`000?oooooooooo02cooooo00?o
0000ooooooooool0J_ooool002Sooooo0_l00003ooooo`03o`000?oooooooooo09Oooooo0oooV@02
ooooo`03o`000?oooooooooo02gooooo00?o0000ooooooooool0JOooool002Gooooo0ol0002Loooo
o`?ooiT01Oooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo06Wooooo000Tooooo`03
o`000?oooooooooo09[ooooo0oooV@08ooooo`03o`000?oooooooooo02kooooo00?o0000oooooooo
ool0J?ooool001[ooooo1?l000000ol@413oooooooooo`03ooooo`;o0000VOooool2oonI00_ooooo
00?o0000ooooooooool0;oooool00ol0003oooooooooo`1Wooooo`007?ooool00ol0003ooooooooo
o`05ooooo`;o0000U_ooool3oonI00gooooo00?o0000ooooooooool0<?ooool00ol0003ooooooooo
o`1Vooooo`004Oooool6o`0000Gooooo00?o0000ooooooooool01?ooool4o`0009;ooooo0oooV@0@
ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool02?ooool5o`0005Wooooo000Loooo
o`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo0000Soooool2oonI01?ooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`07ooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@0FOoo
ool001cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo08[ooooo0_ooV@0Eooooo`03o`000?oooooooooo00kooooo0_o<o`0Rooooo`03o`000?oooooo
oooo00Oooooo00?oV9RHob4Q8Oo^k^h0F_ooool001cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo08Kooooo0oooV@0Gooooo`03o`000?oooooooooo
00_ooooo0oo<o`0Uooooo`03o`000?oooooooooo00Oooooo00?oV9RHob4Q8Oo^k^h0FOooool001co
oooo00?o0000ooooooooool01?ooool2o`0000Gooooo00?o0000ooooooooool0Poooool2oonI01[o
oooo00?o0000ooooooooool02?ooool3olco02Wooooo00?o0000ooooooooool01oooool00omgMgOo
IVIVooooo`1Hooooo`006_ooool00omEEEGoIVIVo`000006ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool0Ooooool3oonI01cooooo00?o0000ooooooooool01Oooool3olco02cooooo
00?o0000ooooooooool02?ooool00ol0003oooooooooo`1Gooooo`008oooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo07[ooooo1?ooV@0Oooooo`03o`000?oooooooooo00;ooooo0oo<
o`0`ooooo`;o00001?ooool01Ol0003o^[ZjoooooonHV9So410@05Wooooo000Sooooo`;o00002?oo
ool00ol0003oooooooooo`1fooooo`?ooiT08oooool00ol0003oooooolco0002olco037ooooo0_l0
00000ooooooo0000ooooo`03ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0FOooool002?ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`1booooo`?ooiT09_ooool00ol0003oc?l0oooo
o`0gooooo`03o`000?oooooooooo05oooooo000Sooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool0K_ooool3oonI02Kooooo0oo<o`000ol0003oooooooooo`0gooooo`03o`000?oooooo
oooo05oooooo000Sooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0Joooool2oonI
02Kooooo0oo<o`02ooooo`;o0000>_ooool00ol0003oooooooooo`1Nooooo`008_ooool2o`0000go
oooo00?o0000ooooooooool0Ioooool3oonI02Gooooo0oo<o`02ooooo`?o000000?oooooo`000?oo
ool0>_ooool00ol0003oooooooooo`1Mooooo`008_ooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo06?ooooo0oooV@0Uooooo`?oc?l00_ooool3o`0000Gooooo00?o0000ooooooooool0
>Oooool00ol0003oooooooooo`1Looooo`008_ooool00ol0003oooooooooo`0>ooooo`03o`000?oo
oooooooo063ooooo0_ooV@0Uooooo`?oc?l00_ooool3o`0000Wooooo00?o0000ooooooooool0>?oo
ool00ol0003oooooooooo`1Looooo`008_ooool3o`0000oooooo00?o0000ooooooooool0G?ooool3
oonI02Gooooo0_o<o`02ooooo`?o00003Oooool00ol0003oooooooooo`0hooooo`03o`000?oooooo
oooo05_ooooo000Rooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0F?ooool3oonI
02Gooooo0oo<o`02ooooo`;o00004Oooool00ol0003oooooooooo`0?ooooo`;o<ol09oooool00ol0
003oooooooooo`1Jooooo`008_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo05Co
oooo0oooV@0Uooooo`?oc?l00_ooool3o`0001Cooooo00?o0000ooooooooool02oooool3oc?o02[o
oooo00?o0000ooooooooool0FOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o
8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool04_ooool00ol0
003oooooooooo`1@ooooo`?ooiT09_ooool2olco00;ooooo0ol0000Gooooo`03o`000?oooooooooo
00Sooooo0olco`0]ooooo`03o`000?oooooooooo05Wooooo0007ooooo`05ogMgMonHV9SooooooiRH
V?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Coooo
o`03o`000?oooooooooo04cooooo0oooV@0Vooooo`?oc?l000Coooooo`000?l0003o00006oooool0
0ol0003oooooooooo`04ooooo`?o<ol0<Oooool00ol0003oooooooooo`1Hooooo`001Ol00002oooo
o`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool0BOooool2oonI02Kooooo0oo<o`001?oooooo0000o`000?l0
000Oooooo`03o`000?oooooooooo00?o<ol0=Oooool00ol0003oooooooooo`1Gooooo`001oooool0
1Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool00oooool00ol0003ooooooooo
o`0Fooooo`03o`000?oooooooooo04Gooooo0oooV@0Uooooo`?oc?l000Coooooo`000?l0003o0000
8_ooool00olco`3o0000oc?o000hooooo`;o0000F?ooool000Oooooo00Go0000oooooooooooooooo
o`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`0Gooooo`03
o`000?oooooooooo047ooooo0oooV@0Uooooo`?oc?l00_ooool2o`0002;ooooo0olco`02ooooo`03
o`000?oooooooooo03Sooooo00?o0000ooooooooool0EOooool000Oooooo00Go410@oooooooooooo
oooooa0@400<ooooo`03o`000?oooooooooo00Kooooo0_l0000Iooooo`03o`000?oooooooooo03ko
oooo0_ooV@0Uooooo`?oc?l00_ooool3o`00027ooooo0olco`06ooooo`03o`000?oooooooooo03Oo
oooo00?o0000ooooooooool0EOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0jooooo`?o
oiT09Oooool2olco00;ooooo0ol0000Qooooo`?o<ol02Oooool00ol0003oooooooooo`0hooooo`03
o`000?oooooooooo05Cooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Go
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0fooooo`?ooiT09Oooool3olco0004
ooooool0003o0000o`0002;ooooo0_lco`0=ooooo`03o`000?oooooooooo03Sooooo00?o0000oooo
ooooool0Doooool0027ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`0cooooo`;o
oiT09Oooool3olco0004ooooool0003o0000o`0002;ooooo0olco`0@ooooo`03o`000?oooooooooo
03Sooooo00?o0000ooooooooool0D_ooool0023ooooo0ol0000Mooooo`03o`000?oooooooooo02oo
oooo0oooV@0Uooooo`;oc?l00_ooool2o`0002;ooooo0olco`0Dooooo`03o`000?oooooooooo03Oo
oooo00?o0000ooooooooool0D_ooool0027ooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`0[ooooo`?ooiT09Oooool3olco0004ooooool0003o0000o`00027ooooo0olco`0Hooooo`03
o`000?oooooooooo03Oooooo00?o0000ooooooooool0DOooool0023ooooo00?o0000ooooooooool0
7oooool00ol0003oooooooooo`0Xooooo`;ooiT09Oooool3olco0004ooooool0003o0000o`00027o
oooo0olco`0Looooo`03o`000?oooooooooo00Sooooo0_l0ofH]ooooo`03o`000?oooooooooo053o
oooo000Pooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool09?ooool3oonI02Gooooo
0_o<o`001?oooooo0000o`000?l0000Qooooo`?o<ol07oooool00ol0003oooooooooo`05ooooo`?o
0?mV<?ooool00ol0003oooooooooo`1?ooooo`008?ooool2o`0002;ooooo00?o0000ooooooooool0
8Oooool2oonI02Gooooo0oo<o`03o`0002;ooooo0_lco`0Sooooo`04o`000?ooooooooooooooo`?o
0?mV<oooool00ol0003oooooooooo`1?ooooo`008?ooool00ol0003oooooooooo`0Rooooo`03o`00
0?oooooooooo01kooooo0_ooV@0Tooooo`?oc?l000?oooooo`000?l000008_ooool3oc?o02Kooooo
00?o0000o`3oI_l0ofH0=oooool00ol0003oooooooooo`1>ooooo`008?ooool00ol0003ooooooooo
o`0Sooooo`03o`000?oooooooooo01[ooooo0oooV@0Tooooo`;oc?l000Coooooo`000?l0003o0000
8Oooool3oc?o02Kooooo0ol0ofH00ooooooo0000ooooo`0hooooo`03o`000?oooooooooo04gooooo
000Pooooo`?o00009?ooool00ol0003oooooooooo`0Fooooo`?ooiT09?ooool3olco00?o00008Ooo
ool3oc?o02Kooooo0ol0ofH5ooooo`03o`000?oooooooooo03Kooooo0_l0001>ooooo`008?ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo01Cooooo00?ooiT0ooooooooool08_ooool3
olco00?o00008?ooool4oc?o02Kooooo0ol0ofH9ooooo`03o`000?oooooooooo03Kooooo00?o0000
ooooooooool0C?ooool001Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP07ooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool0=Oooool3olco00?o00008?ooool3oc?o02Gooooo1Ol0ofH<
ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0Boooool001Cooooo00GoMgMgoiRH
V?ooooooV9RHogMgM`06ooooo`03o`000?oooooooooo02Sooooo00?o0000ooooooooool0<?ooool4
olco0003ooooool0003o0000023ooooo0olco`0Uooooo`?o0?mV4_ooool00ol0003oooooooooo`0g
ooooo`03o`000?oooooooooo04[ooooo000Dooooo`05oa0@4?ooooooooooooooool@41001_ooool2
o`0002[ooooo00?o0000ooooooooool0;?ooool3olco00;ooooo0ol0000Oooooo`?o<ol09Oooool3
o`3oIQKooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`19ooooo`005?ooool01Ol0
003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0X
ooooo`?oc?l00_ooool3o`0001oooooo0olco`0Uooooo`?o0?mV6_ooool00ol0003oooooooooo`0f
ooooo`03o`000?oooooooooo04Wooooo000Dooooo`05o`000?ooooooooooooooool000001_ooool0
0ol0003oooooooooo`0[ooooo`03o`000?oooooooooo02Cooooo0oo<o`02ooooo`?o00007oooool3
oc?o02Gooooo0ol0ofHNooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0B?ooool0
01Cooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo02cooooo00?o0000
ooooooooool08Oooool2olco00;ooooo0ol0000Oooooo`?o<ol09Oooool3o`3oIR;ooooo00?o0000
ooooooooool0=_ooool00ol0003oooooooooo`17ooooo`005?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Kooooo0_l0000^ooooo`03o`000?oooooooooo01gooooo0oo<o`001?oooooo0000o`000?l0
000Pooooo`;o<ol09Oooool3o`3oIRGooooo00Co0000oooooooooooooooo0ol0oolcooooo`03o`00
0?oooooooooo04Kooooo000Dooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003ooooo
ooooo`0^ooooo`03o`000?oooooooooo01Wooooo0oo<o`02ooooo`;o00008?ooool3oc?o02Gooooo
0_l0ofHWooooo`;o0?oo00?o0000o`3oool0ool0=oooool00ol0003oooooooooo`15ooooo`007ooo
ool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01Kooooo0_o<o`02ooooo`?o00007ooo
ool3oc?o02Gooooo0ol0ofHVooooo`?o0?oo0oooool00ol0003oooooooooo`0fooooo`03o`000?oo
oooooooo04Gooooo000Nooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool04_ooool3
olco0004ooooool0003o0000o`00023ooooo0_lco`0Uooooo`?o0?mV9_ooool3o`3oo`Oooooo00?o
0000ooooooooool0=_ooool00ol0003oooooooooo`14ooooo`007_ooool2o`0003?ooooo00?o0000
ooooooooool03_ooool3olco0004ooooool0003o0000o`00023ooooo0olco`0Tooooo`?o0?mV9_oo
ool3o`3oo`_ooooo00?o0000ooooooooool0=_ooool2o`0004Cooooo000Nooooo`03o`000?oooooo
oooo03?ooooo00?o0000ooooooooool03?ooool00oo<o`3oooooo`000002o`00023ooooo0olco`0R
ooooo`Go0?mV9Oooool4o`3oo`oooooo00?o0000ooooooooool0=?ooool00ol0003oooooo`000014
ooooo`007_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00_ooooo0_l0000Qoooo
o`;o<ol08_ooool3o`3oIRGooooo1Ol0oolCooooo`03o`000?oooooooooo03Kooooo00?o0000oooo
ooooool0@_ooool001kooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`07ooooo`?o
00008?ooool3oc?o027ooooo0ol0ofHUooooo`?o0?oo6Oooool00ol0003oooooooooo`0fooooo`03
o`000?oooooooooo047ooooo000Nooooo`;o0000=oooool00ol0003oooooooooo`03ooooo`?o0000
8?ooool3oc?o027ooooo0ol0ofHUooooo`?o0?oo7Oooool00ol0003oooooooooo`0fooooo`03o`00
0?oooooooooo043ooooo000Nooooo`03o`000?oooooooooo03Oooooo00?o0000ooooool000000_l0
000Qooooo`;o<ol08_ooool2o`3oIRGooooo0ol0oolQooooo`03o`000?oooooooooo03Kooooo00?o
0000ooooooooool0?oooool001kooooo00?o0000ooooooooool0=_ooool3o`00027ooooo0olco`0Q
ooooo`?o0?mV9?ooool3o`3oobGooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0o
ooooo`007_ooool2o`0003Gooooo0_l00003ooooo`03o`000?oooooooooo01_ooooo0olco`0Qoooo
o`?o0?mV8_ooool5o`3oobWooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`09oooo
o`;o000000?o410@ooooooooool0<?ooool001gooooo00?o0000ooooooooool0<_ooool3o`0000Ko
oooo00?o0000ooooooooool05oooool3oc?o02;ooooo0_l0ofHRooooo`?o0?oo;_ooool00ol0003o
ooooooooo`0fooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0<Oooool000;ooooo
00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM
00Gooooo00?o0000ooooooooool0;oooool3o`0000[ooooo00?o0000ooooooooool04oooool3oc?o
02;ooooo0ol0ofHQooooo`?o0?oo;oooool3o`1Vo`03o`000?oooooooooo03Kooooo00?o0000oooo
ooooool01Oooool5o`0003;ooooo0002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q
8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0/ooooo`?o00003_ooool00ol0
003oooooooooo`0?ooooo`?o<ol08_ooool3o`3oIR7ooooo0ol0ool]ooooo`Go06Ko1?ooool00ol0
003oooooooooo`0eooooo`03o`000?oooooooooo00Gooooo00CoA4A4omgMgOoooooo0000<oooool0
00;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo0_l0000Z
ooooo`?o00004_ooool00ol0003oooooooooo`0;ooooo`?o<ol08oooool2o`3oIR7ooooo0ol0ool/
ooooo`Co06Ko2_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00Cooooo00CogMgM
oeEEEOoooooo0000<oooool000;ooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool09oooool2o`0001Kooooo00?o0000ooooooooool01ooo
ool3oc?o02?ooooo0ol0ofHNooooo`Go0?oo:_ooool5o`1Vo`oooooo00?o0000ooooooooool0=Ooo
ool00ol0003oooooooooo`04ooooo`03ogMgMoo<c<co000003?ooooo0002ooooo`05o`000?oooooo
ooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000ooooooooool0
9?ooool3o`0001Wooooo00?o0000ooooooooool01Oooool00olco`3oooooooooo`0Qooooo`?o0?mV
7_ooool3o`3oob[ooooo1Ol0I_lEooooo`03o`000?oooooooooo03Cooooo0_l00005ooooo`03onk^
k_m4A4Co000003?ooooo0002ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo027ooooo0ol0000Mooooo`03o`000?oooooooooo02Kooooo
0_l0ofHNooooo`?o0?oo:?ooool5o`1Voa[ooooo00?o0000ooooooooool0<oooool01?l0003ooooo
ooooool00005ooooo`03ogMgMol0003ooooo03;ooooo0002ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03?ooool00ol0003oooooooooo`07ooooo`;o00007oooool3o`00027ooooo00?o0000oooooooo
ool08_ooool3o`3oIQgooooo0ol0oolWooooo`Co06Ko8?ooool00ol0003oooooooooo`0eooooo`03
o`000?oooooooooo03Sooooo0002ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Go
oooo00?o0000ooooooooool07?ooool3o`0002Gooooo00?o0000ooooooooool07oooool2o`3oIQko
oooo0_l0oolUooooo`Go06Ko9Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo03Oo
oooo000Looooo`03o`000?oooooooooo01Wooooo0ol0000Yooooo`03o`000?oooooooooo01cooooo
0_l0ofHMooooo`?o0?oo8oooool4o`1Vob_ooooo00?o0000ooooooooool0=Oooool00ol0003ooooo
ooooo`0fooooo`007?ooool00ol0003oooooooooo`0Gooooo`;o0000;Oooool00ol0003ooooooooo
o`0Hooooo`?o0?mV7Oooool2o`3oob7ooooo1Ol0I_l`ooooo`03o`000?oooooooooo03Gooooo00?o
0000ooooooooool0=Oooool001cooooo0_l0000Eooooo`?o0000<?ooool00ol0003oooooooooo`0D
ooooo`?o0?mV7_ooool2o`3ooaoooooo1?l0I_lfooooo`03o`000?oooooooooo03Cooooo00?o0000
ooooooooool0=Oooool001cooooo00?o0000ooooooooool04Oooool3o`0003Cooooo00?o0000oooo
ooooool04Oooool2o`3oIQkooooo0ol0oolMooooo`Co06Ko>_ooool00ol0003oooooooooo`0eoooo
o`03o`000?oooooooooo03Cooooo000Looooo`03o`000?oooooooooo00kooooo0ol0000hooooo`03
o`000?oooooooooo00gooooo0ol0ofHMooooo`?o0?oo7Oooool3o`1VocKooooo0olc0?l6ooooo`03
o`000?oooooooooo03Gooooo00?o0000ooooooooool0<oooool001cooooo00?o0000ooooooooool0
2oooool3o`0003cooooo00?o0000ooooooooool02Oooool3o`3oIQkooooo0_l0oolMooooo`?o06Ko
=?ooool5oc<0o`[ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0booooo`007?oo
ool2o`0000[ooooo0_l00010ooooo`03o`000?oooooooooo00Gooooo0ol0ofHNooooo`?o0?oo7?oo
ool3o`1Voc;ooooo1Olc0?l@ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0<_oo
ool001_ooooo0_l00008ooooo`?o0000@oooool00ol0003oooooooooo`04o`3oIQkooooo0ol0oolM
ooooo`;o06Ko<?ooool5oc<0oaKooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0a
ooooo`006oooool00ol0003oooooooooo`04ooooo`?o0000Aoooool2o`3oIR3ooooo0_l0oolMoooo
o`?o06Ko;Oooool5oc<0oacooooo00?o0000ooooooooool0<oooool2o`0003;ooooo000Kooooo`04
o`000?ooooooooooooooo`?o0000Boooool00ol0003oooooooooo`0Kooooo`?o0?oo7?ooool3o`1V
ob_ooooo1Olc0?lQooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0;oooool001_o
oooo1?l0001?ooooo`03o`000?oooooooooo01Sooooo0_l0oolLooooo`?o06Ko9oooool7oc<0obOo
oooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0_ooooo`006oooool2o`0005;ooooo
00?o0000ooooooooool05Oooool2o`3ooa_ooooo0ol0I_lSooooo`Oo<`3o;oooool00ol0003ooooo
ooooo`0dooooo`03o`000?oooooooooo02kooooo000Aooooo`Co000000?o410@ooooooooool01Ooo
ool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo017ooooo0ol0oolJooooo`?o06Ko8Ooo
ool5oc<0ocOooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0]ooooo`004oooool0
0ol0003oooooooooo`08ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool03Oooool3
o`3ooa[ooooo0ol0I_lPooooo`Co<`3o?Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooo
oooo02cooooo000Cooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0D?ooool00ol0
003oooooooooo`0:ooooo`;o0?oo6_ooool3o`1Voaoooooo1?lc0?m2ooooo`03o`000?oooooooooo
03?ooooo00?o0000ooooooooool0;?ooool001?ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`1@ooooo`03o`000?oooooooooo00Kooooo0ol0oolJooooo`;o06Ko7_ooool4oc<0odKo
oooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0[ooooo`004oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool00_ooool3o`3ooa_ooooo
0_l0I_lLooooo`Co<`3oBoooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02[ooooo
000Cooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0D?ooool01?l0003oooooo`3o
ool0oolMooooo`03o`1Voooooooooooo01Wooooo0olc0?lnooooo`Coc03o3_ooool00ol0003ooooo
ooooo`0dooooo`03o`000?oooooooooo02Wooooo000Cooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool0C_ooool3o`3ooagooooo0_l0I_lIooooo`?o<`3o??ooool5ol`0oa?ooooo00?o
0000ooooooooool0=?ooool00ol0003oooooooooo`0Xooooo`004Oooool00omEEEGoIVIVo`00000@
ooooo`03o`000?oooooooooo04_ooooo0_l0ool3ooooo`03o`000?oooooooooo01Sooooo0_l0I_lI
ooooo`;o<`3o=oooool8ol`0oaWooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0X
ooooo`009Oooool00ol0003oooooooooo`19ooooo`03o`3ooooooooooooo00Cooooo00?o0000oooo
ooooool05?ooool3o`1VoaSooooo0olc0?l^ooooo`_oc03o8_ooool00ol0003oooooooooo`0boooo
o`;o0000:Oooool002Kooooo0_l0001Aooooo`03o`000?oooooooooo017ooooo0_l0I_lGooooo`Co
<`3o:?ooool9ol`0obgooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Vooooo`00
:?ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00oooooo0_l0I_lFooooo`?o<`3o
9Oooool7ol`0ocOooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Uooooo`00:Ooo
ool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00cooooo0_l0I_lFooooo`;o<`3o9?oo
ool4ol`0ocoooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Uooooo`00:_ooool0
0ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00[ooooo00?o06Koooooooooool05Oooool0
0olc0?ooooooooooo`0Nooooo`Koc03oA?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooo
oooo02Cooooo000[ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool01oooool2o`1V
oaKooooo0_lc0?lKooooo`Koc03oBoooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo
02?ooooo000/ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool01?ooool2o`1VoaKo
oooo0_lc0?lIooooo`Coc03oD_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02;o
oooo000]ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool00ol0I_lFooooo`;o<`3o
6?ooool3ol`0oeKooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Rooooo`00;_oo
ool00ol0003oooooooooo`1=ooooo`?o06Ko5oooool2oc<0oaOooooo0oo<0?mJooooo`03o`000?oo
oooooooo03?ooooo00?o0000ooooooooool08Oooool002oooooo00?o0000ooooooooool0B_ooool2
o`1Vo`;ooooo00?o0000ooooooooool04oooool2oc<0oaOooooo0_o<0?mNooooo`03o`000?oooooo
oooo03?ooooo00?o0000ooooooooool08?ooool0033ooooo00?o0000ooooooooool0A_ooool3o`1V
o`Gooooo00?o0000ooooooooool04?ooool2oc<0oaOooooo0_o<0?m7ooooo`Coo`2I5_ooool00ol0
003oooooooooo`0cooooo`03o`000?oooooooooo01oooooo000aooooo`;o0000@oooool3o`1Vo`Wo
oooo00?o0000ooooooooool03_ooool00olc0?ooooooooooo`0Dooooo`?oc03o@oooool6ool0VA_o
oooo00?o0000ooooooooool0<_ooool2o`00023ooooo000cooooo`03o`000?oooooooooo03oooooo
00?o06Koooooooooool02oooool00ol0003oooooooooo`0;ooooo`;o<`3o5Oooool2ol`0ocgooooo
2Ooo09TRooooo`03o`000?oooooooooo037ooooo0_l0000Pooooo`00=?ooool00ol0003ooooooooo
o`1=ooooo`03o`000?oooooooooo00Sooooo0_lc0?lEooooo`;oc03o:ooooolDool0VB_ooooo00?o
0000ooooooooool0<oooool00ol0003oooooooooo`0Mooooo`00=Oooool00ol0003oooooooooo`1=
ooooo`03o`000?oooooooooo00Cooooo0olc0?lEooooo`;oc03o9?ooool9ool0VD3ooooo00?o0000
ooooooooool0<oooool00ol0003oooooooooo`0Looooo`00=_ooool00ol0003oooooooooo`1=oooo
o`04o`000?ooooooooooooooo`;o<`3o5_ooool2ol`0oaoooooo1ooo09U:ooooo`03o`000?oooooo
oooo03;ooooo00?o0000ooooooooool07?ooool003Oooooo00?o0000ooooooooool0COooool00ol0
003o<`3ooc<0o`0Fooooo`;oc03o6oooool6ool0VE;ooooo00?o0000ooooooooool0<_ooool00ol0
003oooooooooo`0Kooooo`00>?ooool00ol0003oooooooooo`1;ooooo`;o<`3o00?o0000oooooooo
ool04_ooool3ol`0oaWooooo1?oo09UIooooo`03o`000?oooooooooo03;ooooo00?o0000oooooooo
ool01oooool01Oo^k^ko<S8bo`000?l@413oc<c<00kooooo000iooooo`03o`000?oooooooooo04Wo
oooo00Go<`3oooooooooooooooooo`00000Aooooo`;oc03o6?ooool4ool0VEkooooo00?o0000oooo
ooooool0<_ooool00ol0003oooooooooo`06ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B403_ooool0
03[ooooo00?o0000ooooooooool0A_ooool2oc<0o`Gooooo00?o0000ooooooooool03?ooool2ol`0
oaOooooo0ooo09URooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool01Oooool01Ol0
003ooooooooooooooooo000000kooooo000kooooo`03o`000?oooooooooo04?ooooo0_lc0?l8oooo
o`03o`000?oooooooooo00[ooooo00?oc03oooooooooool05?ooool3ool0VFKooooo00?o0000oooo
ooooool0<_ooool00ol0003oooooooooo`05ooooo`05o`000?nHV9SooooooiRHV?lQ8B403_ooool0
03cooooo00?o0000ooooooooool0@?ooool2oc<0o`_ooooo00?o0000ooooooooool01oooool2ol`0
oaGooooo0_oo09UZooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool01?ooool01Ol0
003oEEEEo`000?l@413oc<c<00kooooo000mooooo`;o0000?_ooool2oc<0o`kooooo00?o0000oooo
ooooool01Oooool00oo<0?ooooooooooo`0Cooooo`;oo`2IKOooool00ol0003oooooooooo`0boooo
o`;o00001?ooool00omEEEGoQhN7ooooo`0@ooooo`00?oooool00ol0003oooooooooo`0iooooo`;o
<`3o4Oooool00ol0003oooooooooo`02ooooo`;oc03o5?ooool2ool0VDgooooo1?oo000Oooooo`03
o`000?oooooooooo02oooooo0_l000000ooooooo0000ooooo`03ooooo`03omgMgOl@413oV9RH013o
oooo0010ooooo`03o`000?oooooooooo03Oooooo00?o<`3oooooooooool04_ooool01?l0003ooooo
ooooooo<0?lDooooo`;oo`2IB?ooool7ool002Cooooo00?o0000ooooooooool0<Oooool00ol0003o
ooooooooo`03ooooo`04olc<c?m4A4Co0000oa0@40kooooo0011ooooo`03o`000?oooooooooo04co
oooo0_o<0?lCooooo`;oo`2I@Oooool9ool002_ooooo00?o0000ooooooooool0<_ooool00ol0003o
ooooooooo`0Dooooo`00@_ooool00ol0003oooooooooo`1:ooooo`03ol`0oooooooo0000017ooooo
0_oo09TOooooobCoo`00=Oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01?ooooo
0013ooooo`03o`000?oooooooooo04Oooooo0_o<0?l3ooooo`03o`000?oooooooooo00cooooo0_oo
09TJooooo`Ooo`00F_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01;ooooo0014
ooooo`03o`000?oooooooooo04Cooooo0_o<0?l6ooooo`03o`000?oooooooooo00[ooooo00?oo`2I
ooooooooool05Oooool5ool006;ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0B
ooooo`00AOooool00ol0003oooooooooo`12ooooo`03ol`0oooooooooooo00Oooooo00?o0000oooo
ooooool01oooool2ool0VAGooooo0ooo001Xooooo`03o`000?oooooooooo037ooooo00?o0000oooo
ooooool04Oooool004Kooooo00?o0000ooooooooool0?oooool2ol`0o`_ooooo00?o0000oooooooo
ool01Oooool00ooo09Woooooooooo`0Booooo`?oo`00K?ooool00ol0003oooooooooo`0aooooo`03
o`000?oooooooooo013ooooo0017ooooo`03o`000?oooooooooo03cooooo0_o<0?l>ooooo`03o`00
0?oooooooooo00?ooooo00?oo`2Iooooooooool04Oooool2ool006oooooo00?o0000ooooooooool0
<_ooool00ol0003oooooooooo`0?ooooo`00B?ooool2o`0003[ooooo0_o<0?lAooooo`05o`000?oo
oooooooooooooooo09T04_ooool2ool007;ooooo00?o0000ooooooooool0<Oooool00ol0003ooooo
ooooo`0?ooooo`00B_ooool00ol0003oooooooooo`0eooooo`;oc03o5?ooool00ol0003oo`2Iool0
V@0Aooooo`;oo`00MOooool00ol0003oooooooooo`0aooooo`;o00003oooool004_ooooo00?o0000
ooooooooool0<_ooool2ol`0oaKooooo00?oo`2Io`000?ooool03oooool2ool007Sooooo00?o0000
ooooooooool0<?ooool2o`0000oooooo001<ooooo`03o`000?oooooooooo033ooooo00?oc03ooooo
ooooool05Oooool01?oo09Woooooooooool0000>ooooo`03ool00?oooooooooo07Wooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`0<ooooo`00COooool00ol0003oooooooooo`16oooo
o`03ool0VOoooooooooo00;ooooo00?o0000ooooooooool02Oooool2ool007gooooo00?o0000oooo
ooooool0<Oooool00ol0003oooooooooo`0;ooooo`00C_ooool00ol0003oooooooooo`14ooooo`03
ool0VOoooooooooo00Cooooo00?o0000ooooooooool01oooool00ooo003oooooooooo`1mooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool02oooool004oooooo00?o0000ooooooooool0
@Oooool2ool0V@Sooooo00?o0000ooooooooool01Oooool00ooo003oooooooooo`1oooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool02_ooool0053ooooo00?o0000ooooooooool0?ooo
ool00ooo09Woooooooooo`09ooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool0POoo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Wooooo001Aooooo`03o`000?oooooo
oooo03cooooo0_oo09T=ooooo`05o`000?oooooooooooooooooo0000QOooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo00Sooooo001Booooo`03o`000?oooooooooo03[ooooo00?oo`2I
ooooooooool03_ooool00ol0003oooooool00027ooooo`03o`000?oooooooooo033ooooo00?o0000
ooooooooool02?ooool005?ooooo0_l0000iooooo`03ool0VOoooooooooo013ooooo00?oo`00oooo
ooooool0Qoooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Oooooo001Eooooo`03
o`000?oooooooooo03Cooooo0_oo09TBooooo`03ool00?oooooo000008Sooooo00?o0000oooooooo
ool0<Oooool00ol0003oooooooooo`06ooooo`00E_ooool00ol0003oooooooooo`0aooooo`;oo`2I
4oooool01Ooo003ooooooooooooooooo000008Sooooo00?o0000ooooooooool0;oooool3o`0000Oo
oooo001Gooooo`03o`000?oooooooooo02kooooo0_oo09TDooooo`03ool00?oooooooooo00?ooooo
00?o0000ooooooooool0Q_ooool00ol0003oooooooooo`0[ooooo`?o00000_ooool00ol0003ooooo
ooooo`05ooooo`00F?ooool00ol0003oooooooooo`0[ooooo`;oo`2I5Oooool00ooo003ooooooooo
o`05ooooo`03o`000?oooooooooo08Kooooo00?o0000ooooooooool09oooool3o`0000Gooooo00?o
0000ooooooooool01Oooool005Wooooo00?o0000ooooooooool0:Oooool00ooo09Woooooooooo`0D
ooooo`03ool00?oooooooooo00Oooooo00?o0000ooooooooool0Q_ooool00ol0003oooooooooo`0R
ooooo`Co00002?ooool00ol0003oooooooooo`05ooooo`00F_ooool00ol0003oooooooooo`0moooo
o`;oo`002oooool00ol0003oooooooooo`26ooooo`03o`000?oooooooooo01kooooo0ol0000<oooo
o`03o`000?oooooooooo00Gooooo001Kooooo`03o`000?oooooooooo03_ooooo00?oo`00oooooooo
ool03?ooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo01[ooooo1?l0000?ooooo`03
o`000?oooooooooo00Gooooo001Looooo`03o`000?oooooooooo03Wooooo00?oo`00ooooooooool0
3_ooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo01Kooooo0ol0000Dooooo`03o`00
0?oooooooooo00Cooooo001Mooooo`03o`000?oooooooooo03Oooooo00?oo`00ooooooooool04?oo
ool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo01;ooooo0ol0000Gooooo`03o`000?oo
oooooooo00Cooooo001Nooooo`;o0000=_ooool00ooo003oooooooooo`0Booooo`03o`000?oooooo
oooo08Gooooo00?o0000ooooooooool03Oooool4o`0001[ooooo00?o0000ooooooooool01?ooool0
063ooooo00?o0000ooooooooool0<_ooool00ooo003oooooooooo`0Dooooo`03o`000?oooooooooo
08Gooooo00?o0000ooooooooool02Oooool3o`0001kooooo00?o0000ooooooooool01?ooool0067o
oooo00?o0000ooooooooool0;oooool2ool001Sooooo00?o0000ooooooooool0QOooool00ol0003o
ooooooooo`04ooooo`Co00008Oooool00ol0003oooooooooo`04ooooo`00H_ooool00ol0003ooooo
ooooo`0/ooooo`;oo`006oooool00ol0003oooooooooo`24ooooo`04o`000?ooooooooooooooo`?o
00009Oooool00ol0003oooooooooo`04ooooo`00Hoooool00ol0003oooooooooo`0Yooooo`;oo`00
7_ooool00ol0003oooooooooo`24ooooo`?o0000:?ooool00ol0003oooooooooo`04ooooo`00I?oo
ool00ol0003oooooooooo`0Wooooo`03ool00?oooooooooo01oooooo00?o0000ooooooooool0Oooo
ool4o`000003ooooool0003ooooo02Sooooo00?o0000ooooooooool01?ooool006Gooooo00?o0000
ooooooooool09?ooool2ool002?ooooo00?o0000ooooooooool0Noooool3o`0000Kooooo00?o0000
ooooooooool09_ooool00ol0003oooooooooo`04ooooo`00I_ooool00ol0003oooooooooo`0Roooo
o`03ool00?oooooooooo02Cooooo00?o0000ooooooooool0M_ooool4o`0000[ooooo00?o0000oooo
ooooool09Oooool00ol0003oooooooooo`04ooooo`00Ioooool00ol0003oooooooooo`19ooooo`03
o`000?oooooooooo07;ooooo0ol0000?ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool00oooool006Sooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`1^ooooo`?o0000
4_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00?ooooo001Yooooo`03o`000?oo
oooooooo04Wooooo00?o0000ooooooooool0JOooool4o`0001Kooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`03ooooo`00J_ooool2o`0004[ooooo00?o0000ooooooooool0IOooool3
o`0001_ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`03ooooo`00K?ooool00ol0
003oooooooooo`18ooooo`03o`000?oooooooooo063ooooo1?l0000Oooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool00oooool006gooooo00?o0000ooooooooool0B?ooool00ol0003o
ooooooooo`1Looooo`?o00009?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00?o
oooo001^ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0F?ooool3o`0002Sooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`03ooooo`00Koooool00ol0003ooooooooo
o`18ooooo`03o`000?oooooooooo05?ooooo1?l0000[ooooo`03o`000?oooooooooo023ooooo00?o
0000ooooooooool00oooool0073ooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`1?
ooooo`?o0000<?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00?ooooo001aoooo
o`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0B_ooool4o`0003Cooooo00?o0000oooo
ooooool07_ooool00ol0003oooooooooo`03ooooo`00L_ooool00ol0003oooooooooo`18ooooo`03
o`000?oooooooooo04Kooooo0ol0000iooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool00_ooool007?ooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`12ooooo`?o0000
?Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00;ooooo001dooooo`03o`000?oo
oooooooo04Sooooo00?o0000ooooooooool0?Oooool4o`00047ooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`02ooooo`00MOooool2o`0004Wooooo00?o0000ooooooooool0>Oooool3
o`0004Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`02ooooo`00Moooool00ol0
003oooooooooo`17ooooo`03o`000?oooooooooo03Cooooo1?l00019ooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool00_ooool007Sooooo00?o0000ooooooooool0Aoooool00ol0003o
ooooooooo`0`ooooo`?o0000C_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00;o
oooo001iooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0;?ooool3o`0005;ooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`02ooooo`00N_ooool00ol0003ooooooooo
o`17ooooo`03o`000?oooooooooo02Oooooo1?l0001Fooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool00_ooool007_ooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0S
ooooo`?o0000Foooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00;ooooo001loooo
o`03o`000?oooooooooo04Oooooo00?o0000ooooooooool07_ooool4o`0005kooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`02ooooo`00OOooool00ol0003oooooooooo`17ooooo`03
o`000?oooooooooo01[ooooo0ol0001Sooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool00Oooool007kooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Fooooo`?o0000
Ioooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo007ooooo001oooooo`03o`000?oo
oooooooo04Oooooo00?o0000ooooooooool04Oooool4o`0006_ooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`01ooooo`00P?ooool2o`0004Sooooo00?o0000ooooooooool03Oooool3
o`00073ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`01ooooo`00P_ooool00ol0
003oooooooooo`16ooooo`03o`000?oooooooooo00Sooooo1?l0001dooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool00Oooool008?ooooo00?o0000ooooooooool0A_ooool00ol0003o
ooooooooo`04ooooo`?o0000N?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo007o
oooo0024ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool00ol0001looooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool00Oooool008Gooooo00?o0000ooooooooool0A_oo
ool2o`00083ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`01ooooo`00Q_ooool0
0ol0003oooooooooo`15ooooo`03o`000?oooooooooo083ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`01ooooo`00Qoooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo
087ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`01ooooo`00R?ooool00ol0003o
ooooooooo`13ooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool03oooool1o`00007o
oooo0Oooool008Wooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`22ooooo`03o`00
0?oooooooooo00oooooo0Ol00001ooooo`7ooooo002:ooooo`03o`000?oooooooooo047ooooo00?o
0000ooooooooool0Poooool00ol0003oooooooooo`0>ooooo`7o00000Oooool1ooooo`00Roooool2
o`00047ooooo00?o0000ooooooooool0Q?ooool00ol0003oooooooooo`0=ooooo`7o00000Oooool1
ooooo`00SOooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo08Gooooo00?o0000oooo
ooooool03?ooool1o`00007ooooo0Oooool008kooooo00?o0000ooooooooool0?Oooool00ol0003o
ooooooooo`26ooooo`03o`000?oooooooooo00_ooooo0Ol00001ooooo`7ooooo002?ooooo`03o`00
0?oooooooooo03cooooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`0:ooooo`7o0000
0Oooool1ooooo`00T?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo08Oooooo00?o
0000ooooooooool02_ooool1o`00007ooooo0Oooool0097ooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`28ooooo`03o`000?oooooooooo00Wooooo0Ol00001ooooo`7ooooo002Boooo
o`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`08oooo
o`7o00000Oooool1ooooo`00Toooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo08[o
oooo00?o0000ooooooooool02?ooool1o`00007ooooo002Dooooo`03o`000?oooooooooo03Oooooo
00?o0000ooooooooool0Roooool00ol0003oooooooooo`07ooooo`7o00000Oooool009Gooooo00?o
0000ooooooooool0=_ooool00ol0003oooooooooo`2<ooooo`03o`000?oooooooooo00Kooooo0Ol0
0001ooooo`00U_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo08cooooo00?o0000
ooooooooool01_ooool1o`00007ooooo002Gooooo`;o0000=Oooool00ol0003oooooooooo`2=oooo
o`03o`000?oooooooooo00Gooooo0Ol00001ooooo`00VOooool00ol0003oooooooooo`0booooo`03
o`000?oooooooooo08kooooo00?o0000ooooooooool01?ooool1o`00007ooooo002Jooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool0Soooool00ol0003oooooooooo`03ooooo`7o0000
0Oooool009_ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`2@ooooo`03o`000?oo
oooooooo00;ooooo0Ol00001ooooo`00W?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooo
oooo097ooooo00Go0000ooooooooooooooooo`000001ooooo`00WOooool00ol0003oooooooooo`0^
ooooo`03o`000?oooooooooo097ooooo00Go0000ooooooooooooooooo`000001ooooo`00W_ooool0
0ol0003oooooooooo`0]ooooo`03o`000?oooooooooo09;ooooo00Co0000oooooooooooooooo0Ol0
000009oooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`2Cooooo`03o`000?oooooo
oooo007o0000002Pooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0U?ooool1o`00
007ooooo0Ol000000:7ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`2Eooooo`;o
0000002Rooooo`;o0000:_ooool00ol0003oooooooooo`2Dooooo`?o0000002Tooooo`03o`000?oo
oooooooo02Oooooo00?o0000ooooooooool0T?ooool4o`0000?ooooo002Uooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool0SOooool3o`0000Oooooo002Vooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0ROooool4o`0000[ooooo002Wooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool0QOooool4o`0000kooooo002Xooooo`03o`000?oooooooooo02?ooooo
00?o0000ooooooooool0P_ooool3o`0001;ooooo002Yooooo`03o`000?oooooooooo02;ooooo00?o
0000ooooooooool0O_ooool4o`0001Gooooo002Zooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool0N_ooool4o`0001Wooooo002[ooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool0MOooool4o`0001gooooo002/ooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool0L_ooool3o`00027ooooo002]ooooo`;o00008?ooool00ol0003oooooooooo`1^ooooo`Co0000
9?ooool00:oooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1Zooooo`Co0000:?oo
ool00;3ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1Wooooo`?o0000;?ooool0
0;7ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Sooooo`Co0000;oooool00;;o
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1Oooooo`Co0000<oooool00;?ooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`1Looooo`?o0000=oooool00;Cooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`1Hooooo`Co0000>_ooool00;Gooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`1Dooooo`Co0000?_ooool00;Kooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`1@ooooo`Co0000@_ooool00;Oooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`1=ooooo`?o0000A_ooool00;Sooooo0_l0000Eooooo`03o`00
0?oooooooooo04Wooooo1?l00019ooooo`00^_ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo04Gooooo1?l0001=ooooo`00^oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo04;ooooo0ol0001Aooooo`00_?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
03kooooo1?l0001Dooooo`00_Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03[o
oooo1?l0001Hooooo`00__ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03Kooooo
1?l0001Looooo`00_oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03?ooooo0ol0
001Pooooo`00`?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02oooooo1?l0001S
ooooo`00`Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02_ooooo1?l0001Woooo
o`00`_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Sooooo0ol0001[ooooo`00
`oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02Cooooo1?l0001^ooooo`00a?oo
ool2o`0000Wooooo00?o0000ooooooooool08?ooool4o`0007;ooooo0036ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool07Oooool3o`0007Kooooo0037ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool06Oooool4o`0007Wooooo0038ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool05Oooool4o`0007gooooo0039ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool04Oooool4o`00087ooooo003:ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool03_ooool3o`0008Gooooo003;ooooo`05o`000?ooooooooooooooool000003?oo
ool4o`0008Sooooo003<ooooo`04o`000?ooooooooooo`0000Sooooo1?l0002<ooooo`00cOooool0
0ol0003oooooo`000005ooooo`?o0000T?ooool00<kooooo0_l000000ooooooo0000o`000002o`00
09?ooooo003?ooooo`;o0000Uoooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {330.375, 0}} -> {-0.0771432, -0.0315529, \
0.00350368, 0.00350368}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .92059 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-16 1.0763 -0.0263982 1.0763 [
[.01694 .18568 -11.9631 -9 ]
[.01694 .18568 .03693 0 ]
[.13793 .13897 -11.619 -9 ]
[.13793 .13897 .38095 0 ]
[.26292 .09073 -5.63752 -9 ]
[.26292 .09073 .36248 0 ]
[.39212 .04087 -5.46552 -9 ]
[.39212 .04087 .53448 0 ]
[.52574 -0.01069 -5.29351 -9 ]
[.52574 -0.01069 .70649 0 ]
[.58272 .04263 0 -6.19654 ]
[.58272 .04263 6 2.80346 ]
[.71715 .21863 0 -6.07114 ]
[.71715 .21863 6 2.92886 ]
[.83675 .37523 0 -5.963 ]
[.83675 .37523 6 3.037 ]
[.94385 .51546 0 -5.8688 ]
[.94385 .51546 6 3.1312 ]
[.01386 .20006 -12 -2.76892 ]
[.01386 .20006 0 6.23108 ]
[.00748 .25499 -24 -2.80073 ]
[.00748 .25499 0 6.19927 ]
[.00093 .31131 -6 -2.83339 ]
[.00093 .31131 0 6.16661 ]
[-0.00579 .36907 -18 -2.86695 ]
[-0.00579 .36907 0 6.13305 ]
[-0.01268 .42831 -6 -2.90143 ]
[-0.01268 .42831 0 6.09857 ]
[ 0 0 0 0 ]
[ 1 .92059 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02642 .19522 m
.53391 0 L
s
.02642 .19522 m
.03116 .2 L
s
[(-2)] .01694 .18568 .99384 1 Mshowa
.14712 .14879 m
.15172 .1537 L
s
[(-1)] .13793 .13897 .93651 1 Mshowa
.2718 .10083 m
.27624 .10588 L
s
[(0)] .26292 .09073 .87917 1 Mshowa
.40066 .05126 m
.40493 .05646 L
s
[(1)] .39212 .04087 .82184 1 Mshowa
.53391 0 m
.538 .00534 L
s
[(2)] .52574 -0.01069 .7645 1 Mshowa
.125 Mabswid
.05025 .18606 m
.05308 .18894 L
s
.07424 .17683 m
.07705 .17973 L
s
.09837 .16755 m
.10117 .17046 L
s
.12267 .1582 m
.12545 .16113 L
s
.17173 .13933 m
.17447 .14229 L
s
.19651 .1298 m
.19923 .13278 L
s
.22144 .1202 m
.22414 .1232 L
s
.24654 .11055 m
.24922 .11356 L
s
.29723 .09105 m
.29988 .0941 L
s
.32283 .0812 m
.32546 .08427 L
s
.3486 .07129 m
.35121 .07437 L
s
.37455 .06131 m
.37713 .06441 L
s
.42695 .04115 m
.4295 .04428 L
s
.45342 .03096 m
.45594 .03412 L
s
.48007 .02071 m
.48257 .02388 L
s
.5069 .01039 m
.50938 .01358 L
s
.25 Mabswid
.53391 0 m
.9804 .58403 L
s
.57014 .04738 m
.56384 .04975 L
s
[(0)] .58272 .04263 -1 .37701 Mshowa
.70445 .22307 m
.6981 .22529 L
s
[(2)] .71715 .21863 -1 .34914 Mshowa
.82396 .37939 m
.81756 .38147 L
s
[(4)] .83675 .37523 -1 .32511 Mshowa
.93098 .51938 m
.92454 .52134 L
s
[(6)] .94385 .51546 -1 .30418 Mshowa
.125 Mabswid
.60525 .09331 m
.60147 .09471 L
s
.63931 .13786 m
.63552 .13924 L
s
.67236 .1811 m
.66856 .18245 L
s
.73562 .26383 m
.7318 .26514 L
s
.7659 .30345 m
.76207 .30473 L
s
.79534 .34195 m
.7915 .34322 L
s
.85181 .41581 m
.84796 .41704 L
s
.87891 .45126 m
.87506 .45247 L
s
.90529 .48577 m
.90143 .48696 L
s
.95601 .55212 m
.95214 .55328 L
s
.25 Mabswid
.02642 .19522 m
0 .42381 L
s
.02642 .19522 m
.0327 .19281 L
s
[(-1)] .01386 .20006 1 -0.38468 Mshowa
.02006 .25024 m
.02635 .24786 L
s
[(-0.5)] .00748 .25499 1 -0.37762 Mshowa
.01354 .30664 m
.01985 .3043 L
s
[(0)] .00093 .31131 1 -0.37036 Mshowa
.00686 .36448 m
.01318 .36218 L
s
[(0.5)] -0.00579 .36907 1 -0.3629 Mshowa
0 .42381 m
.00634 .42156 L
s
[(1)] -0.01268 .42831 1 -0.35524 Mshowa
.125 Mabswid
.02516 .20612 m
.02893 .20468 L
s
.0239 .21707 m
.02767 .21563 L
s
.02262 .22807 m
.0264 .22664 L
s
.02135 .23913 m
.02512 .2377 L
s
.01877 .26141 m
.02255 .25999 L
s
.01747 .27263 m
.02125 .27122 L
s
.01617 .28391 m
.01995 .2825 L
s
.01486 .29525 m
.01864 .29384 L
s
.01222 .31809 m
.01601 .3167 L
s
.01089 .3296 m
.01468 .32821 L
s
.00955 .34117 m
.01334 .33978 L
s
.00821 .35279 m
.012 .35141 L
s
.0055 .37622 m
.0093 .37485 L
s
.00414 .38803 m
.00793 .38666 L
s
.00276 .39989 m
.00656 .39853 L
s
.00139 .41182 m
.00519 .41047 L
s
.25 Mabswid
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.54154 .92059 L
s
.54154 .92059 m
.5414 .7134 L
s
.5414 .7134 m
.02642 .19522 L
s
.53391 0 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.53391 0 m
.02642 .19522 L
s
.5414 .7134 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.54154 .92059 L
s
.54154 .92059 m
.5414 .7134 L
s
0 0 m
1 0 L
1 .92059 L
0 .92059 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.35564 .64108 m
.38555 .6245 L
s
1 0 .6 r
.33807 .60618 m
.36519 .59103 L
s
.8 0 1 r
.32071 .57131 m
.34561 .55762 L
s
.2 0 1 r
.30396 .5365 m
.32755 .52424 L
s
0 .4 1 r
.28825 .5017 m
.31136 .49077 L
s
0 1 1 r
.27364 .46671 m
.29676 .4569 L
s
0 1 .4 r
.25982 .43125 m
.2831 .42227 L
s
.2 1 0 r
.24635 .39515 m
.26977 .38665 L
s
.8 1 0 r
.23291 .35853 m
.2564 .35015 L
s
1 .6 0 r
.21941 .32162 m
.24292 .31318 L
s
0 1 1 r
.29676 .4569 m
.31925 .44655 L
s
0 1 .4 r
.2831 .42227 m
.30618 .41293 L
s
0 .4 1 r
.31136 .49077 m
.3331 .47917 L
s
.2 1 0 r
.26977 .38665 m
.29322 .37794 L
s
.2 0 1 r
.32755 .52424 m
.34857 .5112 L
s
.8 0 1 r
.34561 .55762 m
.36642 .54289 L
s
.8 1 0 r
.2564 .35015 m
.28002 .34168 L
s
1 0 .6 r
.36519 .59103 m
.38691 .57436 L
s
1 0 0 r
.38555 .6245 m
.40944 .6057 L
s
1 .6 0 r
.24292 .31318 m
.26657 .30469 L
s
0 1 .4 r
.30618 .41293 m
.32902 .40336 L
s
.2 1 0 r
.29322 .37794 m
.31667 .36906 L
s
0 1 1 r
.31925 .44655 m
.34111 .43604 L
s
.8 1 0 r
.28002 .34168 m
.30374 .33311 L
s
0 .4 1 r
.3331 .47917 m
.35357 .46762 L
s
1 .6 0 r
.26657 .30469 m
.29036 .29613 L
s
.2 0 1 r
.34857 .5112 m
.36725 .49856 L
s
.8 0 1 r
.36642 .54289 m
.3831 .52913 L
s
.2 1 0 r
.31667 .36906 m
.34013 .3601 L
s
0 1 .4 r
.32902 .40336 m
.35172 .39377 L
s
.8 1 0 r
.30374 .33311 m
.32757 .32447 L
s
0 1 1 r
.34111 .43604 m
.36265 .42574 L
s
1 0 .6 r
.38691 .57436 m
.40197 .55933 L
s
1 .6 0 r
.29036 .29613 m
.31429 .28752 L
s
0 .4 1 r
.35357 .46762 m
.37353 .45662 L
s
1 0 0 r
.40944 .6057 m
.42404 .58908 L
s
.2 1 0 r
.34013 .3601 m
.36367 .35114 L
s
.8 1 0 r
.32757 .32447 m
.35153 .31579 L
s
.2 0 1 r
.36725 .49856 m
.38514 .48695 L
s
0 1 .4 r
.35172 .39377 m
.37448 .38437 L
s
1 .6 0 r
.31429 .28752 m
.33837 .27885 L
s
0 1 1 r
.36265 .42574 m
.38429 .41589 L
s
.8 0 1 r
.3831 .52913 m
.39835 .51705 L
s
0 .4 1 r
.37353 .45662 m
.39374 .4464 L
s
.2 1 0 r
.36367 .35114 m
.38739 .3423 L
s
.8 1 0 r
.35153 .31579 m
.37563 .30709 L
s
1 0 .6 r
.40197 .55933 m
.41421 .54703 L
s
0 1 .4 r
.37448 .38437 m
.3975 .3753 L
s
1 .6 0 r
.33837 .27885 m
.36259 .27013 L
s
.2 0 1 r
.38514 .48695 m
.4035 .47644 L
s
0 1 1 r
.38429 .41589 m
.40637 .40663 L
s
1 0 0 r
.42404 .58908 m
.43359 .57675 L
s
.2 1 0 r
.38739 .3423 m
.41138 .33362 L
s
.8 1 0 r
.37563 .30709 m
.39993 .2984 L
s
.8 0 1 r
.39835 .51705 m
.41431 .50643 L
s
0 .4 1 r
.39374 .4464 m
.41465 .43701 L
s
1 .6 0 r
.36259 .27013 m
.38698 .26137 L
s
0 1 .4 r
.3975 .3753 m
.42094 .36663 L
s
0 1 1 r
.40637 .40663 m
.42908 .39801 L
s
1 0 .6 r
.41421 .54703 m
.42712 .53663 L
s
.2 0 1 r
.4035 .47644 m
.42293 .46702 L
s
.2 1 0 r
.41138 .33362 m
.43572 .32515 L
s
.8 1 0 r
.39993 .2984 m
.42445 .28974 L
s
1 .6 0 r
.38698 .26137 m
.41153 .25257 L
s
0 1 .4 r
.42094 .36663 m
.44493 .3584 L
s
0 .4 1 r
.41465 .43701 m
.43645 .4285 L
s
.8 0 1 r
.41431 .50643 m
.43182 .4971 L
s
1 0 0 r
.43359 .57675 m
.44306 .56711 L
s
0 1 1 r
.42908 .39801 m
.45255 .39006 L
s
.2 0 1 r
.42293 .46702 m
.44359 .45869 L
s
.2 1 0 r
.43572 .32515 m
.46046 .31687 L
s
.8 1 0 r
.42445 .28974 m
.44919 .28111 L
s
1 0 .6 r
.42712 .53663 m
.44207 .52762 L
s
1 .6 0 r
.41153 .25257 m
.43625 .24373 L
s
0 1 .4 r
.44493 .3584 m
.46952 .35057 L
s
0 .4 1 r
.43645 .4285 m
.45923 .42087 L
s
.8 0 1 r
.43182 .4971 m
.45099 .48903 L
s
1 0 0 r
.44306 .56711 m
.4547 .55892 L
s
0 1 1 r
.45255 .39006 m
.47682 .38275 L
s
.2 0 1 r
.44359 .45869 m
.46548 .45145 L
s
.2 1 0 r
.46046 .31687 m
.4856 .30872 L
s
.8 1 0 r
.44919 .28111 m
.47417 .27248 L
s
1 0 .6 r
.44207 .52762 m
.45921 .51998 L
s
0 1 .4 r
.46952 .35057 m
.49475 .34309 L
s
0 .4 1 r
.45923 .42087 m
.48301 .41413 L
s
1 .6 0 r
.43625 .24373 m
.46114 .23484 L
s
0 1 1 r
.47682 .38275 m
.50196 .37603 L
s
.8 0 1 r
.45099 .48903 m
.47168 .48227 L
s
1 0 0 r
.4547 .55892 m
.46898 .55207 L
s
.2 0 1 r
.46548 .45145 m
.48853 .44534 L
s
.2 1 0 r
.4856 .30872 m
.51111 .30062 L
s
.8 1 0 r
.47417 .27248 m
.49937 .26382 L
s
0 .4 1 r
.48301 .41413 m
.50782 .40824 L
s
0 1 .4 r
.49475 .34309 m
.52062 .33584 L
s
1 0 .6 r
.45921 .51998 m
.47821 .51386 L
s
1 .6 0 r
.46114 .23484 m
.48619 .2259 L
s
0 1 1 r
.50196 .37603 m
.52801 .36978 L
s
.8 0 1 r
.47168 .48227 m
.49368 .47691 L
s
1 0 0 r
.46898 .55207 m
.48543 .54684 L
s
.2 0 1 r
.48853 .44534 m
.51273 .44038 L
s
0 .4 1 r
.50782 .40824 m
.53377 .40311 L
s
.2 1 0 r
.51111 .30062 m
.53691 .29247 L
s
1 0 .6 r
.47821 .51386 m
.4986 .50941 L
s
0 1 .4 r
.52062 .33584 m
.54704 .32862 L
s
.8 1 0 r
.49937 .26382 m
.52474 .2551 L
s
.8 0 1 r
.49368 .47691 m
.51684 .47302 L
s
0 1 1 r
.52801 .36978 m
.55498 .36374 L
s
.2 0 1 r
.51273 .44038 m
.5382 .4365 L
s
1 0 0 r
.48543 .54684 m
.50323 .54351 L
s
1 .6 0 r
.48619 .2259 m
.51141 .2169 L
s
1 0 0 r
.59865 .5464 m
.6413 .54472 L
s
.5652 .54463 m
.59865 .5464 L
s
0 .4 1 r
.53377 .40311 m
.56101 .39845 L
s
1 0 .6 r
.4986 .50941 m
.52001 .50676 L
s
1 0 0 r
.6413 .54472 m
.68479 .53871 L
s
.54135 .54269 m
.5652 .54463 L
s
.8 0 1 r
.51684 .47302 m
.54127 .47057 L
s
.2 0 1 r
.5382 .4365 m
.56532 .43342 L
s
1 0 0 r
.50323 .54351 m
.52173 .54217 L
s
0 1 .4 r
.54704 .32862 m
.57387 .32123 L
s
1 0 0 r
.52173 .54217 m
.54135 .54269 L
s
1 0 .6 r
.59897 .50685 m
.63693 .50486 L
s
.56778 .50633 m
.59897 .50685 L
s
.52001 .50676 m
.54255 .50587 L
s
.2 1 0 r
.53691 .29247 m
.56291 .28418 L
s
0 1 1 r
.55498 .36374 m
.58277 .35758 L
s
1 0 .6 r
.54255 .50587 m
.56778 .50633 L
s
.8 0 1 r
.54127 .47057 m
.56773 .46925 L
s
0 .4 1 r
.56101 .39845 m
.58969 .39377 L
s
.8 1 0 r
.52474 .2551 m
.55027 .24628 L
s
.8 0 1 r
.56773 .46925 m
.59783 .4681 L
s
1 0 .6 r
.63693 .50486 m
.67635 .4992 L
s
.2 0 1 r
.56532 .43342 m
.59474 .43044 L
s
.8 0 1 r
.59783 .4681 m
.63215 .4653 L
s
1 .6 0 r
.51141 .2169 m
.53678 .20784 L
s
.2 0 1 r
.59474 .43044 m
.6265 .42642 L
s
0 .4 1 r
.58969 .39377 m
.61954 .38837 L
s
.8 0 1 r
.63215 .4653 m
.66781 .45973 L
s
0 1 1 r
.58277 .35758 m
.61104 .3509 L
s
0 1 .4 r
.57387 .32123 m
.60084 .31349 L
s
.2 1 0 r
.56291 .28418 m
.58899 .27568 L
s
.2 0 1 r
.6265 .42642 m
.659 .42052 L
s
.8 1 0 r
.55027 .24628 m
.57593 .23737 L
s
0 .4 1 r
.61954 .38837 m
.64959 .38179 L
s
1 .6 0 r
.53678 .20784 m
.56231 .19871 L
s
0 1 1 r
.61104 .3509 m
.63924 .3435 L
s
0 1 .4 r
.60084 .31349 m
.62772 .30534 L
s
.2 1 0 r
.58899 .27568 m
.61509 .26699 L
s
.8 1 0 r
.57593 .23737 m
.60171 .22836 L
s
1 .6 0 r
.56231 .19871 m
.588 .18952 L
s
0 g
.25 Mabswid
.53391 0 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.53391 0 m
.02642 .19522 L
s
.02642 .19522 m
.53391 0 L
s
.02642 .19522 m
.03116 .2 L
s
[(-2)] .01694 .18568 .99384 1 Mshowa
.14712 .14879 m
.15172 .1537 L
s
[(-1)] .13793 .13897 .93651 1 Mshowa
.2718 .10083 m
.27624 .10588 L
s
[(0)] .26292 .09073 .87917 1 Mshowa
.40066 .05126 m
.40493 .05646 L
s
[(1)] .39212 .04087 .82184 1 Mshowa
.53391 0 m
.538 .00534 L
s
[(2)] .52574 -0.01069 .7645 1 Mshowa
.125 Mabswid
.05025 .18606 m
.05308 .18894 L
s
.07424 .17683 m
.07705 .17973 L
s
.09837 .16755 m
.10117 .17046 L
s
.12267 .1582 m
.12545 .16113 L
s
.17173 .13933 m
.17447 .14229 L
s
.19651 .1298 m
.19923 .13278 L
s
.22144 .1202 m
.22414 .1232 L
s
.24654 .11055 m
.24922 .11356 L
s
.29723 .09105 m
.29988 .0941 L
s
.32283 .0812 m
.32546 .08427 L
s
.3486 .07129 m
.35121 .07437 L
s
.37455 .06131 m
.37713 .06441 L
s
.42695 .04115 m
.4295 .04428 L
s
.45342 .03096 m
.45594 .03412 L
s
.48007 .02071 m
.48257 .02388 L
s
.5069 .01039 m
.50938 .01358 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 265.125},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001Bb000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00`oooool5o`000:3ooooo0033ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@0X?ooool00<Cooooo00?oV9RHob4Q8Oo^k^h0XOooool00<Gooooo00?oV9RH
ob4Q8Oo^k^h0X?ooool00<Kooooo00?oMgMgofIVI_ooool0Woooool00<Oooooo00?o0000oooooooo
ool0W_ooool00<?ooooo00Go0000okZj^_ooooooV9RHoa0@402Pooooo`00`oooool01OnHV9So410@
o`000?lQ8B7oc<c<0:3ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003;ooooo`;o0000Voooool00<Sooooo0ol000000ooooooo0000ooooo`2Jooooo`00a_oo
ool2o`0000Cooooo0_l0002Jooooo`00`oooool3o`0000Kooooo00?o0000ooooool00000VOooool0
0<3ooooo1?l00008ooooo`04o`000?ooooooooooo`0009Sooooo002Hooooo`Co000000?o410@oooo
ooooool07oooool2o`0000Cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0002H
ooooo`00V_ooool00ol0003oooooooooo`0Nooooo`?o00003_ooool01Ol0003ooooooooooooooooo
000009Oooooo002Jooooo`03o`000?oooooooooo01cooooo0_l0000Aooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0U?ooool009[ooooo00?o0000ooooooooool06Oooool3o`0000;o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo09?o
oooo002Jooooo`03o`000?oooooooooo01Kooooo0ol0000Fooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^08Kooooo002Jooooo`03o`00
0?oooooooooo01Cooooo0_l0000Iooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1oooool01OmgMgOoV9RHoooooonHV9SoMgMg08Kooooo002Jooooo`03o`000?oooooooooo017ooooo
0ol000000ooooooo0000ooooo`0Hooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1_ooool01Ol@413ooooooooooooooooo410@08Kooooo002Hooooo`03oeEEEOmVIVKo0000017ooooo
0_l0000Nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool01Ol0003ooooo
oooooooooooo000008Kooooo002Yooooo`?o00008?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000026ooooo`00Yoooool3o`0002;ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@
4100Q_ooool00:Cooooo0ol00002ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Q_ooool00:7ooooo
0ol0000Xooooo`03o`000?oooooooooo00Sooooo0_l00004ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h0Q_ooool009oooooo0_l0000[ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo
0000S_ooool009cooooo0ol000000ooooooo0000ooooo`0Zooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0S?ooool009[ooooo0_l00005ooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`2;ooooo`00Uoooool3o`0003;ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`2:ooooo`00K?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^02?ooooo0ol000000ooooooo0000ooooo`0booooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0ROooool006cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Qooooo`;o0000>?ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo08Wooooo001/ooooo`05oa0@4?oooooooooo
ooooool@41007_ooool3o`0003[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`28
ooooo`00K?ooool01Ol0003ooooooooooooooooo000001cooooo0ol0000looooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0Qoooool006cooooo00Go0000ooooooooooooooooo`00000I
ooooo`?o00000_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool0Q_ooool006cooooo00Go410@oooooooooooooooooa0@400Gooooo`;o0000@_ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo08Kooooo001/ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL05?ooool3o`0004Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`25
ooooo`00K?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^017ooooo0ol00002ooooo`03o`000?oooooo
oooo04;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`24ooooo`00P?ooool2o`00
04[ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`23ooooo`00OOooool3o`0004co
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`22ooooo`00Noooool2o`000003oooo
ool0003ooooo04cooooo00?o0000ooooooooool05?ooool2o`0008?ooooo001hooooo`?o0000DOoo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooo000008?ooooo001eooooo`?o0000E?ooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo083ooooo001cooooo`Co0000EOooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo07oooooo001`ooooo`?o00001?ooool00ol0003o
ooooooooo`1Booooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0Ooooool006kooooo
0_l0001Looooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0O_ooool004?ooooo1?l0
00000ol@413oooooooooo`0Qooooo`?o0000G_ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo07gooooo0015ooooo`03o`000?oooooooooo023ooooo0ol00003ooooo`03o`000?oooooo
oooo05_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1looooo`00>_ooool6o`00
00Gooooo00?o0000ooooooooool07_ooool2o`0006Cooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`1looooo`00AOooool00ol0003oooooooooo`0Kooooo`?o0000I_ooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo07_ooooo0015ooooo`03o`000?oooooooooo01Wooooo
0_l00002ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`1jooooo`00AOooool00ol0003oooooooooo`0Fooooo`?o0000Joooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo07Wooooo0015ooooo`03o`000?oooooooooo01Cooooo0_l0001^
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0NOooool004?ooooo00?oEEEEofIV
I_l000004oooool3o`000003ooooool0003ooooo06gooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`1hooooo`00E_ooool3o`0007?ooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`1gooooo`00E?ooool2o`0007Kooooo00?o0000ooooooooool07oooool2o`0007Sooooo
001Aooooo`?o000000?oooooo`000?ooool0MOooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo07Kooooo001?ooooo`;o0000Noooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo07Gooooo001<ooooo`?o0000OOooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
07Cooooo0019ooooo`Co0000Ooooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo07?o
oooo0017ooooo`;o00001?ooool00ol0003oooooooooo`1looooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool0L_ooool004Cooooo0ol00025ooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool0L_ooool001[ooooo1Ol0000Sooooo`?o0000Qoooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo077ooooo000Jooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@08?ooool3
o`0000?ooooo00?o0000ooooooooool0Q?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo073ooooo000Booooo`Ko00000oooool00onHV9So8B4Qonk^kP0Oooooo`;o0000SOooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo06oooooo000Looooo`03oiRHV?lQ8B7ok^k^01_o
oooo0ol0002?ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0Koooool001gooooo
00?oMgMgofIVI_ooool05oooool3o`0000?ooooo00?o0000ooooooooool0S?ooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooooooo06kooooo000Nooooo`03o`000?oooooooooo01Cooooo0_l0
002Eooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0KOooool001[ooooo00Go0000
okZj^_ooooooV9RHoa0@400Cooooo`?o0000Uoooool00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo06cooooo000Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`04Oooool2o`0000?ooooo00?o
0000ooooooooool0U?ooool00ol0003oooooooooo`0Zooooo`;o0000KOooool002gooooo0ol0002L
ooooo`03o`000?oooooooooo02[ooooo0_l0001]ooooo`00:_ooool3o`0009oooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`1Zooooo`00:?ooool2o`0000?ooooo00?o0000oooooooo
ool0W?ooool00ol0003oooooooooo`0>ooooo`;ooiT07Oooool00ol0003oooooooooo`1Yooooo`00
9Oooool3o`000:Cooooo00?o0000ooooooooool02oooool3oonI01oooooo00?o0000ooooooooool0
JOooool002Cooooo00?o0000ooooooooool0YOooool00ol0003oooooooooo`08ooooo`?ooiT08ooo
ool00ol0003oooooooooo`1Xooooo`006_ooool4o`000003oa0@4?oooooooooo00?ooooo0_l0002V
ooooo`03o`000?oooooooooo00Gooooo0oooV@0Wooooo`03o`000?oooooooooo06Oooooo000Loooo
o`03o`000?oooooooooo00Gooooo0_l0002Vooooo`03o`000?oooooooooo00;ooooo0oooV@0[oooo
o`03o`000?oooooooooo06Kooooo000Aooooo`Ko00001Oooool00ol0003oooooooooo`04ooooo`Co
0000YOooool00ol0003ooooooonI0002oonI02kooooo00?o0000ooooooooool02?ooool5o`0005Wo
oooo000Looooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooo0000Y?ooool00ol0003o
oiT0ooooo`0aooooo`03o`000?oooooooooo00Oooooo00GoV9RHob4Q8Oo^k^koooooodA4A01Ioooo
o`007?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0W_ooool3oonI0003o`000?oooooooooo03;ooooo00?o0000ooooooooool01oooool00onHV9So
8B4Qonk^kP1Jooooo`007?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0V_ooool3oonI00?ooooo00?o0000ooooooooool0<oooool00ol0003ooooo
ooooo`07ooooo`03oiRHV?lQ8B7ok^k^05Wooooo000Looooo`03o`000?oooooooooo00Cooooo0_l0
0005ooooo`03o`000?oooooooooo09Oooooo0_ooV@06ooooo`03o`000?oooooooooo03Cooooo00?o
0000ooooooooool01oooool00omgMgOoIVIVooooo`1Hooooo`006_ooool00omEEEGoIVIVo`000006
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0Toooool3oonI00Sooooo00?o0000
ooooooooool0=?ooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo05Oooooo000Soooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0Soooool3oonI00_ooooo00?o0000oooo
ooooool0=Oooool2o`0000Cooooo00Go0000okZj^_ooooooV9RHoa0@401Iooooo`008oooool2o`00
00Sooooo00?o0000ooooooooool0Roooool3oonI00kooooo00?o0000ooooooooool0<oooool2o`00
0003ooooool0003ooooo00?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c01Iooooo`008oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo08Oooooo0oooV@0Aooooo`03o`000?oooooooooo
01;ooooo0_o<o`0Sooooo`03o`000?oooooooooo05oooooo000Sooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0Poooool3oonI01Cooooo00?o0000ooooooooool03oooool3olco02Go
oooo00?o0000ooooooooool0Goooool002?ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`20ooooo`;ooiT05_ooool2o`0000kooooo0oo<o`0Yooooo`03o`000?oooooooooo05kooooo
000Rooooo`;o00003Oooool00ol0003oooooooooo`1looooo`?ooiT05Oooool3o`000003ooooool0
003ooooo00_ooooo0_o<o`0]ooooo`03o`000?oooooooooo05gooooo000Rooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool0N?ooool3oonI01Gooooo0ol00005ooooo`03o`000?oooooo
oooo00Kooooo0oo<o`0`ooooo`03o`000?oooooooooo05cooooo000Rooooo`03o`000?oooooooooo
00kooooo00?o0000ooooooooool0MOooool2oonI01Gooooo0ol00009ooooo`03o`000?oooooooooo
00;ooooo0oo<o`0cooooo`03o`000?oooooooooo05cooooo000Rooooo`?o00003oooool00ol0003o
ooooooooo`1aooooo`?ooiT05?ooool3o`0000gooooo00Co0000olco0?o<o`3oc?l0=oooool00ol0
003oooooooooo`1Kooooo`008_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo06go
oooo0oooV@0Eooooo`;o00003_ooool3olco0003o`000?oooooooooo03Sooooo00?o0000oooooooo
ool0F_ooool002;ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`1Yooooo`?ooiT0
5Oooool3o`0000gooooo0oo<o`04ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0
FOooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000
o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`1Uooooo`?o
oiT05Oooool3o`0000kooooo0_o<o`07ooooo`03o`000?oooooooooo03Sooooo00?o0000oooooooo
ool0FOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo
<S8booooo`04ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0HOooool3oonI01Go
oooo0ol0000>ooooo`?oc?l02_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo05So
oooo0005o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1Nooooo`;ooiT05Oooool3o`0000ko
oooo0oo<o`0>ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0Eoooool000Oooooo
00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`1Jooooo`?ooiT05?ooool3o`0000kooooo0oo<o`0Booooo`03
o`000?oooooooooo03Oooooo0_l0001Hooooo`001oooool01Ol0003ooooooooooooooooo000000co
oooo00Go0000ob4Q8Ol0003o<S8bolc<c004ooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool0E_ooool3oonI01Gooooo0_l0000<ooooo`Goc?l05_ooool00ol0003oooooooooo`0>oooo
o`;o<ol0:?ooool00ol0003oooooooooo`1Eooooo`001oooool01Ol@413ooooooooooooooooo410@
00cooooo00?o0000ooooooooool01_ooool2o`0001Wooooo00?o0000ooooooooool0Doooool2oonI
01Gooooo0ol0000;ooooo`?oc?l07?ooool00ol0003oooooooooo`0:ooooo`?o<ol0:_ooool00ol0
003oooooooooo`1Eooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo04oooooo0oooV@0Doooo
o`?o00002oooool3olco01oooooo00?o0000ooooooooool01oooool3oc?o02kooooo00?o0000oooo
ooooool0E?ooool000Oooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0
003oooooooooo`0Jooooo`03o`000?oooooooooo04_ooooo0oooV@0Dooooo`?o00002oooool3olco
02?ooooo00?o0000ooooooooool00_ooool4oc?o03;ooooo00?o0000ooooooooool0Doooool0027o
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`17ooooo`?ooiT05?ooool3o`0000co
oooo0_o<o`0Wooooo`04o`000?lco`3o<ol0oc?o03Oooooo00?o0000ooooooooool0D_ooool0023o
oooo0ol0000Mooooo`03o`000?oooooooooo04;ooooo1?ooV@0Eooooo`;o00003?ooool3olco02Ko
oooo0olco`000ooooooo0000ooooo`0hooooo`03o`000?oooooooooo05;ooooo000Qooooo`03o`00
0?oooooooooo01gooooo00?o0000ooooooooool0?_ooool3oonI01Kooooo0ol0000;ooooo`?oc?l0
9_ooool3oc?o00Gooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`1Aooooo`008?oo
ool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo03[ooooo0oooV@0Fooooo`?o00003?oo
ool2olco02Kooooo0olco`09ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0D?oo
ool0023ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0fooooo`?ooiT05_ooool3
o`0000cooooo0oo<o`0Uooooo`?o<ol03?ooool00ol0003oooooooooo`0hooooo`03o`000?oooooo
oooo04oooooo000Pooooo`;o00008_ooool00ol0003oooooooooo`0cooooo`;ooiT05_ooool3o`00
00cooooo0oo<o`0Uooooo`?o<ol04?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo
04oooooo000Pooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0;oooool3oonI01Ko
oooo0_l0000=ooooo`;oc?l09Oooool3oc?o01Cooooo00?o0000ooooooooool0=oooool00ol0003o
ooooooooo`1>ooooo`008?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo02_ooooo
0oooV@0Fooooo`?o00003?ooool3olco02?ooooo1?lco`0Hooooo`03o`000?oooooooooo03Oooooo
00?o0000ooooooooool0COooool0023ooooo0ol0000Tooooo`03o`000?oooooooooo02Sooooo0_oo
V@0Fooooo`?o00003?ooool3olco02;ooooo1?lco`0Mooooo`03o`000?oooooooooo00Sooooo0_l0
ofH/ooooo`;o0000C_ooool0023ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0T
ooooo`?ooiT05Oooool3o`0000gooooo0_o<o`0Rooooo`?o<ol08_ooool00ol0003oooooooooo`04
ooooo`?o0?mV;oooool00ol0003oooooooooo`1<ooooo`005?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Oooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0Qooooo`;ooiT05Oooool3
o`0000gooooo0oo<o`0Qooooo`?o<ol09Oooool01?l0003oooooooooooooool3o`3oIS?ooooo00?o
0000ooooooooool0Boooool001Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`000?oo
oooooooo02Sooooo00?o0000ooooooooool07_ooool2oonI01Gooooo0_l0000=ooooo`?oc?l08Ooo
ool3oc?o02Wooooo00?o0000o`3oI_l0ofH0=oooool00ol0003oooooooooo`1:ooooo`005?ooool0
1Ol@413ooooooooooooooooo410@00Kooooo0_l0000Zooooo`03o`000?oooooooooo01[ooooo0ooo
V@0Dooooo`?o00003Oooool2olco02;ooooo0_lco`0Yooooo`?o0?mV00?oooooo`000?ooool0>?oo
ool00ol0003oooooooooo`19ooooo`005?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o
0000ooooooooool0:_ooool00ol0003oooooooooo`0Fooooo`?ooiT05?ooool3o`0000gooooo0oo<
o`0Qooooo`?o<ol0:?ooool3o`3oIPGooooo00?o0000ooooooooool0=_ooool00ol0003ooooooooo
o`19ooooo`005?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0:ooo
ool00ol0003oooooooooo`0Dooooo`03oonI0?oooooooooo01;ooooo0ol0000=ooooo`?oc?l08Ooo
ool3oc?o02Oooooo1?l0ofH9ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0B?oo
ool001Cooooo00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo02cooooo00?o
0000ooooooooool09Oooool3o`0000kooooo0_o<o`0Qooooo`?o<ol09Oooool5o`3oIPkooooo00?o
0000ooooooooool0=_ooool00ol0003oooooooooo`17ooooo`005?ooool01OmgMgOoV9RHoooooonH
V9SoMgMg00Kooooo0_l0000^ooooo`03o`000?oooooooooo027ooooo0ol0000>ooooo`?oc?l08?oo
ool3oc?o02Cooooo1?l0ofHCooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0A_oo
ool001Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo02kooooo00?o
0000ooooooooool07_ooool2o`0000kooooo0oo<o`0Pooooo`?o<ol08oooool4o`3oIQSooooo00?o
0000ooooooooool0=oooool00ol0003oooooooooo`15ooooo`007oooool00ol0003oooooooooo`0_
ooooo`03o`000?oooooooooo01[ooooo0ol0000=ooooo`?oc?l08Oooool2oc?o02?ooooo0ol0ofHM
ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0AOooool001kooooo00?o0000oooo
ooooool0<Oooool00ol0003oooooooooo`0Fooooo`?o00003?ooool4olco027ooooo0olco`0Roooo
o`?o0?mV8Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo04Cooooo000Nooooo`;o
0000<oooool00ol0003oooooooooo`0Booooo`?o00003?ooool3olco02;ooooo0olco`0Rooooo`?o
0?mV9Oooool00ol0003oooooooooo`0fooooo`;o0000A?ooool001kooooo00?o0000ooooooooool0
<oooool00ol0003oooooooooo`0>ooooo`?o00003?ooool3olco02?ooooo0_lco`0Qooooo`Co0?mV
:Oooool00ol0003oooooooooo`03o`3ooc7ooooo00?o0000ooooool00000A?ooool001kooooo00?o
0000ooooooooool0=?ooool00ol0003oooooooooo`0;ooooo`;o00003?ooool3olco02?ooooo0olc
o`0Oooooo`Co0?mV:oooool2o`3oo`03o`000?l0oooo0?oo03Kooooo00?o0000ooooooooool0@_oo
ool001kooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`07ooooo`?o00003?ooool2
olco02Cooooo0_lco`0Oooooo`?o0?mV:oooool4o`3oo`?ooooo00?o0000ooooooooool0=_ooool0
0ol0003oooooooooo`11ooooo`007_ooool2o`0003Oooooo00?o0000ooooooooool00oooool3o`00
00cooooo0oo<o`0Sooooo`?o<ol07_ooool3o`3oIR_ooooo0ol0ool8ooooo`03o`000?oooooooooo
03Kooooo00?o0000ooooooooool0@?ooool001kooooo00?o0000ooooooooool0=oooool00ol0003o
ooooo`000002o`0000cooooo0oo<o`0Rooooo`Co<ol07_ooool3o`3oIR_ooooo0ol0ool<ooooo`03
o`000?oooooooooo03Kooooo00?o0000ooooooooool0?oooool001kooooo00?o0000ooooooooool0
=_ooool3o`0000kooooo00?oc?l0ooooooooool08?ooool3oc?o023ooooo0_l0ofHZooooo`Co0?oo
4?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo03oooooo000Nooooo`;o0000=Ooo
ool2o`0000?ooooo00?o0000ooooooooool0:oooool3oc?o023ooooo0ol0ofHWooooo`Go0?oo5Ooo
ool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00Wooooo0_l000000ol@413ooooooooo
o`0`ooooo`007Oooool00ol0003oooooooooo`0booooo`?o00001_ooool00ol0003oooooooooo`0W
ooooo`?o<ol08?ooool3o`3oIRKooooo1?l0oolJooooo`03o`000?oooooooooo03Kooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0aooooo`000_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003ooooooooo
o`0_ooooo`?o00002_ooool00ol0003oooooooooo`0Tooooo`;o<ol08Oooool2o`3oIRCooooo1Ol0
oolOooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool01Oooool5o`0003;ooooo0002
ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`0/ooooo`?o00003_ooool00ol0003oooooooooo`0Pooooo`?o<ol08?oo
ool3o`3oIR;ooooo1?l0oolUooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool01Ooo
ool01?m4A4CogMgMooooool0000cooooo`000_ooool01Ol@413ooooooooooooooooo410@013ooooo
00?o0000ooooooooool00oooool2o`0002[ooooo0ol0000Booooo`03o`000?oooooooooo01cooooo
0olco`0Pooooo`?o0?mV8?ooool5o`3oob[ooooo00?o0000ooooooooool0=Oooool00ol0003ooooo
ooooo`04ooooo`04omgMgOmEEEGoooooo`0003?ooooo0002ooooo`05o`000?ooooooooooooooool0
00003oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo02Oooooo0_l0000Fooooo`03
o`000?oooooooooo01Wooooo0_lco`0Qooooo`;o0?mV7oooool4o`3ooc3ooooo00?o0000oooooooo
ool0=Oooool00ol0003oooooooooo`04ooooo`03ogMgMoo<c<co000003?ooooo0002ooooo`05o`00
0?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool09?ooool3o`0001Wooooo00?o0000ooooooooool05Oooool3oc?o023ooooo0ol0ofHMoooo
o`Co0?oo=Oooool00ol0003oooooooooo`0dooooo`;o00001Oooool00oo^k^koA4A4o`00000coooo
o`000_ooool01Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool00ol0
003oooooooooo`0Qooooo`?o00007Oooool00ol0003oooooooooo`0Aooooo`?o<ol08?ooool3o`3o
IQcooooo1?l0ooleooooo`?o06Ko00?oooooo`000?ooool0=?ooool01?l0003oooooooooool00005
ooooo`03ogMgMol0003ooooo03;ooooo0002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool0
0ol0003oooooooooo`07ooooo`;o00007oooool3o`00027ooooo00?o0000ooooooooool03_ooool2
oc?o027ooooo0_l0ofHKooooo`Co0?oo=?ooool5o`1Vo`Gooooo00?o0000ooooooooool0=Oooool0
0ol0003oooooooooo`0hooooo`000_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005
ooooo`03o`000?oooooooooo01cooooo0ol0000Uooooo`03o`000?oooooooooo00[ooooo0olco`0P
ooooo`?o0?mV6_ooool3o`3ooc?ooooo1Ol0I_l;ooooo`03o`000?oooooooooo03Gooooo00?o0000
ooooooooool0=oooool001cooooo00?o0000ooooooooool06Oooool3o`0002Wooooo00?o0000oooo
ooooool01oooool2oc?o027ooooo0_l0ofHJooooo`?o0?oo<Oooool5o`1Voa7ooooo00?o0000oooo
ooooool0=Oooool00ol0003oooooooooo`0fooooo`007?ooool00ol0003oooooooooo`0Gooooo`;o
0000;Oooool00ol0003oooooooooo`05ooooo`03oc?o0?oooooooooo01oooooo0_l0ofHIooooo`?o
0?oo;Oooool7o`1VoaOooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0eooooo`00
7?ooool2o`0001Gooooo0ol0000`ooooo`03o`000?oooooooooo02?ooooo0ol0ofHIooooo`;o0?oo
:Oooool7o`1Voaoooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0eooooo`007?oo
ool00ol0003oooooooooo`0Aooooo`?o0000=?ooool00ol0003oooooooooo`0Oooooo`?o0?mV6Ooo
ool3o`3oobKooooo1Ol0I_lVooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0=?oo
ool001cooooo00?o0000ooooooooool03_ooool3o`0003Sooooo00?o0000ooooooooool07?ooool2
o`3oIQ[ooooo0_l0oolSooooo`Ko06Ko;?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooo
oooo03?ooooo000Looooo`03o`000?oooooooooo00_ooooo0ol0000looooo`03o`000?oooooooooo
01Sooooo0ol0ofHJooooo`;o0?oo7_ooool7o`1Voc?ooooo00?o0000ooooooooool0=Oooool00ol0
003oooooooooo`0booooo`007?ooool2o`0000[ooooo0_l00010ooooo`03o`000?oooooooooo01Go
oooo0_l0ofHJooooo`?o0?oo7?ooool4o`1Voc_ooooo00?o0000ooooooooool0=?ooool00ol0003o
ooooooooo`0booooo`006oooool2o`0000Sooooo0ol00013ooooo`03o`000?oooooooooo01;ooooo
0_l0ofHIooooo`?o0?oo7?ooool3o`1Vod3ooooo00?o0000ooooooooool0=?ooool00ol0003ooooo
ooooo`0aooooo`006oooool00ol0003oooooooooo`04ooooo`?o0000Aoooool00ol0003ooooooooo
o`0>ooooo`?o0?mV6Oooool2o`3ooacooooo0ol0I_m4ooooo`03o`000?oooooooooo03?ooooo0_l0
000booooo`006oooool01?l0003oooooooooooooool3o`0004_ooooo00?o0000ooooooooool02_oo
ool3o`3oIQWooooo0ol0oolKooooo`?o06KoAoooool00ol0003oooooooooo`0eooooo`03o`000?oo
oooooooo02oooooo000Kooooo`Co0000Coooool00ol0003oooooooooo`07ooooo`;o0?mV6_ooool2
o`3ooa_ooooo0ol0I_llooooo`Ko<`3o2Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooo
oooo02oooooo000Kooooo`;o0000D_ooool00ol0003oooooooooo`03ooooo`?o0?mV6_ooool2o`3o
oa[ooooo0ol0I_lgooooo`So<`3o4?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo
02kooooo000Aooooo`Co000000?o410@ooooooooool01Oooool00ol0003oooooooooo`1@ooooo`03
o`000?oooooo0?mV00;o0?mV6oooool2o`3ooaWooooo0ol0I_leooooo`Go<`3o6Oooool00ol0003o
ooooooooo`0dooooo`03o`000?oooooooooo02gooooo000Cooooo`03o`000?oooooooooo00Sooooo
00?o0000ooooooooool0D?ooool00ol0ofKoooooooooo`0Kooooo`03o`3ooooooooooooo01Kooooo
0ol0I_l`ooooo`So<`3o7oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02cooooo
000Cooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`0Hooooo`;o0?oo5_ooool3o`1Vob[ooooo2Olc0?lXooooo`03o`000?oooooooooo03?ooooo00?o
0000ooooooooool0;?ooool001?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1@
ooooo`03o`000?oooooooooo01Gooooo0_l0oolFooooo`;o06Ko9?ooool9oc<0oc7ooooo00?o0000
ooooooooool0=?ooool00ol0003oooooooooo`0[ooooo`004oooool00ol0003oooooooooo`0;oooo
o`03o`000?oooooooooo053ooooo00?o0000ooooooooool04Oooool3o`3ooaKooooo0_l0I_lPoooo
o`Ko<`3o>oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02[ooooo000Cooooo`03
o`000?oooooooooo00cooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0>ooooo`;o
0?oo5oooool2o`1Voakooooo1?lc0?m2ooooo`03o`000?oooooooooo03Cooooo00?o0000oooooooo
ool0:Oooool001?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1@ooooo`03o`00
0?oooooooooo00_ooooo0_l0oolGooooo`;o06Ko7?ooool4oc<0odOooooo00?o0000ooooooooool0
=?ooool00ol0003oooooooooo`0Xooooo`004Oooool00omEEEGoIVIVo`00000@ooooo`03o`000?oo
oooooooo053ooooo00?o0000ooooooooool02?ooool2o`3ooaKooooo0ol0I_lJooooo`Co<`3oC?oo
ool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02Sooooo000Uooooo`03o`000?oooooo
oooo053ooooo00?o0000ooooooooool01Oooool2o`3ooaKooooo0_l0I_lIooooo`Co<`3oDOooool0
0ol0003oooooooooo`0booooo`;o0000:Oooool002Kooooo0_l0001Aooooo`03o`000?oooooooooo
00;ooooo0_l0oolFooooo`;o06Ko6?ooool3oc<0oeGooooo00?o0000ooooooooool0=?ooool00ol0
003oooooooooo`0Vooooo`00:?ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00;o
0?oo5_ooool2o`1VoaOooooo0olc0?mIooooo`03o`000?oooooooooo03Cooooo00?o0000oooooooo
ool09Oooool002Wooooo00?o0000ooooooooool0COooool3o`3ooaOooooo00?o06Koooooooooool0
5?ooool3oc<0odKooooo1_o<0?lAooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0
9Oooool002[ooooo00?o0000ooooooooool0B_ooool2o`3oo`;ooooo00?o0000ooooooooool04ooo
ool2o`1VoaGooooo0_lc0?lmooooo`coc03o6?ooool00ol0003oooooooooo`0cooooo`03o`000?oo
oooooooo02Cooooo000[ooooo`03o`000?oooooooooo04Sooooo00?o0?ooooooooooool00oooool0
0ol0003oooooooooo`0@ooooo`;o06Ko5Oooool2oc<0ocCooooo2oo<0?lUooooo`03o`000?oooooo
oooo03?ooooo00?o0000ooooooooool08oooool002cooooo00?o0000ooooooooool0C_ooool00ol0
003oooooooooo`0=ooooo`;o06Ko5Oooool2oc<0obCooooo4_o<0?laooooo`03o`000?oooooooooo
03?ooooo00?o0000ooooooooool08_ooool002gooooo00?o0000ooooooooool0C_ooool00ol0003o
ooooooooo`0;ooooo`03o`1Voooooooooooo01?ooooo0_lc0?lOooooo`Ooc03o@oooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo02;ooooo000^ooooo`03o`000?oooooooooo04kooooo
00?o0000ooooooooool02?ooool2o`1VoaCooooo0_lc0?lKooooo`Koc03oBoooool00ol0003ooooo
ooooo`0cooooo`03o`000?oooooooooo027ooooo000_ooooo`03o`000?oooooooooo04kooooo00?o
0000ooooooooool01Oooool2o`1VoaGooooo00?o<`3oooooooooool05oooool4ol`0oe;ooooo00?o
0000ooooooooool0<oooool00ol0003oooooooooo`0Pooooo`00<?ooool00ol0003oooooooooo`1>
ooooo`03o`000?oooooooooo00;ooooo0_l0I_lEooooo`;o<`3o5oooool3ol`0oeOooooo00?o0000
ooooooooool0<oooool00ol0003oooooooooo`0Oooooo`00<Oooool2o`0004oooooo00Co0000oooo
oooooooo06Ko5_ooool00olc0?ooooooooooo`0Dooooo`?oc03oFoooool00ol0003oooooooooo`0b
ooooo`;o00008?ooool003?ooooo00?o0000ooooooooool0COooool2o`1VoaGooooo0_lc0?lDoooo
o`?oc03oGoooool00ol0003oooooooooo`0aooooo`;o00008?ooool003Cooooo00?o0000oooooooo
ool0B_ooool2o`1Vo`03ooooool0003ooooo01;ooooo0_lc0?lCooooo`?oc03oH_ooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo01gooooo000eooooo`03o`000?oooooooooo04Kooooo
0ol0I_l4ooooo`03o`000?oooooooooo00kooooo0_lc0?lCooooo`;oc03oI_ooool00ol0003ooooo
ooooo`0cooooo`03o`000?oooooooooo01cooooo000fooooo`03o`000?oooooooooo04?ooooo0_l0
I_l8ooooo`03o`000?oooooooooo00_ooooo0_lc0?lCooooo`;oc03oJOooool00ol0003ooooooooo
o`0booooo`03o`000?oooooooooo01cooooo000gooooo`03o`000?oooooooooo047ooooo00?o06Ko
ooooooooool02Oooool00ol0003oooooooooo`09ooooo`03oc<0oooooooooooo017ooooo0_o<0?m<
ooooo`Ooo`2I6Oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01_ooooo000hoooo
o`03o`000?oooooooooo04gooooo00?o0000ooooooooool01oooool00olc0?ooooooooooo`0@oooo
o`;oc03o@Oooool=ool0VB7ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`07oooo
o`05onk^k_lb<S;o0000oa0@4?o<c<`03_ooool003Wooooo00?o0000ooooooooool0COooool00ol0
003oooooooooo`05ooooo`03oc<0oooooooooooo00oooooo0_o<0?lOooooobCoo`2I;oooool00ol0
003oooooooooo`0booooo`03o`000?oooooooooo00Kooooo00GoEEEEogMgMoooooooV9RHob4Q8@0>
ooooo`00>_ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo00?ooooo00?o<`3ooooo
ooooool03oooool00oo<0?ooooooooooo`0Hooooo`Ooo`2IDoooool00ol0003oooooooooo`0coooo
o`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`00000>ooooo`00>oooool00ol0
003oooooooooo`1=ooooo`03o`000?oooooooooo00;o<`3o4Oooool00oo<0?ooooooooooo`0Doooo
o`Goo`2IFoooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00Gooooo00Go0000oiRH
V?ooooooV9RHob4Q8@0>ooooo`00??ooool00ol0003oooooooooo`1=ooooo`;o<`3o4_ooool00oo<
0?ooooooooooo`0Booooo`?oo`2IHOooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo
00Cooooo00Go0000oeEEEOl0003o410@olc<c00>ooooo`00?Oooool2o`0004cooooo00?o<`3ooooo
ool000004?ooool2ol`0oa;ooooo0ooo09UUooooo`03o`000?oooooooooo03;ooooo0_l00004oooo
o`03oeEEEOn7QhOooooo013ooooo000oooooo`03o`000?oooooooooo04Oooooo0_lc0?l3ooooo`03
o`000?oooooooooo00cooooo00?oc03oooooooooool04?ooool2ool0VFWooooo00?o0000oooooooo
ool0;oooool2o`000003ooooool0003ooooo00?ooooo00?ogMgMoa0@4?nHV9P04?ooool0043ooooo
00?o0000ooooooooool0A?ooool2oc<0o`Kooooo00?o0000ooooooooool02_ooool00oo<0?oooooo
ooooo`0@ooooo`03ool0VOoooooooooo06[ooooo00?o0000ooooooooool0<Oooool00ol0003ooooo
ooooo`03ooooo`04olc<c?m4A4Co0000oa0@40kooooo0011ooooo`03o`000?oooooooooo047ooooo
0_lc0?l9ooooo`03o`000?oooooooooo00Sooooo00?oc03oooooooooool03oooool2ool0VFgooooo
00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Dooooo`00@_ooool00ol0003ooooooooo
o`0nooooo`;o<`3o3?ooool00ol0003oooooooooo`05ooooo`;oc03o4?ooool2ool0VG3ooooo00?o
0000ooooooooool0<_ooool00ol0003oooooooooo`0Cooooo`00@oooool00ol0003oooooooooo`0k
ooooo`;o<`3o3oooool00ol0003oooooooooo`03ooooo`03ol`0oooooooooooo00oooooo00?oo`2I
ooooooooool0LOooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01;ooooo0014oooo
o`03o`000?oooooooooo03Wooooo00?o<`3oooooooooool04?ooool00ol0003oooooooooo`02ol`0
oa3ooooo0_oo09Ueooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool04_ooool004Go
oooo00?o0000ooooooooool0C?ooool00ol0003oc03oooooo`0?ooooo`;oo`2IDoooool4ool0027o
oooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Aooooo`00A_ooool00ol0003ooooo
ooooo`1:ooooo`;oc03o00?o0000ooooooooool03Oooool00ooo09Woooooooooo`0GoooooaCoo`00
8Oooool7ool002Kooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0@ooooo`00Aooo
ool00ol0003oooooooooo`18ooooo`05ol`0ooooooooooooooooool000003Oooool00ooo09Wooooo
ooooo`0Dooooo`Coo`005?oooolQool002gooooo00?o0000ooooooooool0<_ooool00ol0003ooooo
ooooo`0?ooooo`00B?ooool2o`0004Oooooo00?oc03oooooooooool00oooool00ol0003ooooooooo
o`0:ooooo`03ool0VOoooooooooo017ooooo0ooo001Wooooo`03o`000?oooooooooo037ooooo00?o
0000ooooooooool03oooool004[ooooo00?o0000ooooooooool0@oooool00oo<0?ooooooooooo`05
ooooo`03o`000?oooooooooo00Sooooo00?oo`2Iooooooooool03oooool3ool006_ooooo00?o0000
ooooooooool0<Oooool2o`0000oooooo001;ooooo`03o`000?oooooooooo047ooooo00?oc03ooooo
ooooool01oooool00ol0003oooooooooo`06ooooo`03ool0VOoooooooooo00kooooo0_oo001_oooo
o`03o`000?oooooooooo033ooooo0_l0000?ooooo`00C?ooool00ol0003oooooooooo`0nooooo`;o
c03o2oooool00ol0003oooooooooo`04ooooo`03ool0VOoooooooooo00gooooo0_oo001booooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool03?ooool004gooooo00?o0000ooooooooool0
>oooool2ol`0o`kooooo00?o0000ooooooooool00_ooool00ooo09Woooooooooo`0=ooooo`03ool0
0?oooooooooo07?ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0;ooooo`00C_oo
ool00ol0003oooooooooo`0hooooo`;oc03o4Oooool01?l0003ooooooooooooo09T?ooooo`03ool0
0?oooooooooo07Cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0;ooooo`00Cooo
ool00ol0003oooooooooo`0fooooo`03ol`0oooooooooooo01;ooooo00?o0000ool0VOooool03_oo
ool00ooo003oooooooooo`1fooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool02_oo
ool0053ooooo00?o0000ooooooooool0<oooool2ol`0oaGooooo00?oo`2Io`000?ooool03Oooool0
0ooo003oooooooooo`1hooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool02Oooool0
057ooooo00?o0000ooooooooool0<Oooool00oo<0?ooooooooooo`0Dooooo`04ool0VOoooooooooo
o`0000cooooo00?oo`00ooooooooool0N_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooo
oooo00Sooooo001Booooo`03o`000?oooooooooo04Gooooo0_oo09T4ooooo`03o`000?oooooooooo
00Sooooo00?oo`00ooooooooool0O?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo
00Sooooo001Cooooo`;o0000A?ooool00ooo09Woooooooooo`05ooooo`03o`000?oooooooooo00Oo
oooo00?oo`00ooooooooool0OOooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Oo
oooo001Eooooo`03o`000?oooooooooo03oooooo0_oo09T9ooooo`03o`000?oooooooooo00Gooooo
00?oo`00ooooooooool0O_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Kooooo
001Fooooo`03o`000?oooooooooo03gooooo00?oo`2Iooooooooool02_ooool00ol0003ooooooooo
o`03ooooo`03ool00?oooooooooo083ooooo00?o0000ooooooooool0;oooool3o`0000Oooooo001G
ooooo`03o`000?oooooooooo03_ooooo00?oo`2Iooooooooool03?ooool01Ol0003ooooooooooooo
ooooo`0008Cooooo00?o0000ooooooooool0:oooool3o`0000;ooooo00?o0000ooooooooool01Ooo
ool005Sooooo00?o0000ooooooooool0>?ooool2ool0VA3ooooo00Co0000ooooooooooooo`00QOoo
ool00ol0003oooooooooo`0Wooooo`?o00001Oooool00ol0003oooooooooo`05ooooo`00FOooool0
0ol0003oooooooooo`0eooooo`;oo`2I4oooool00ol0003oo`00ooooo`26ooooo`03o`000?oooooo
oooo02;ooooo1?l00008ooooo`03o`000?oooooooooo00Gooooo001Jooooo`03o`000?oooooooooo
03;ooooo0_oo09TEooooo`03ool00?l0003ooooo08Oooooo00?o0000ooooooooool07_ooool3o`00
00cooooo00?o0000ooooooooool01Oooool005_ooooo00?o0000ooooooooool0<?ooool00ooo09Wo
ooooooooo`0Dooooo`04ool00?ooooooooooo`0008Oooooo00?o0000ooooooooool06_ooool4o`00
00oooooo00?o0000ooooooooool01Oooool005cooooo00?o0000ooooooooool0;Oooool2ool0VAKo
oooo00?oo`00ooooooooool00_ooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo01Ko
oooo0ol0000Dooooo`03o`000?oooooooooo00Cooooo001Mooooo`03o`000?oooooooooo02_ooooo
00?oo`2Iooooooooool05?ooool2ool000Kooooo00?o0000ooooooooool0QOooool00ol0003ooooo
ooooo`0Booooo`?o00005oooool00ol0003oooooooooo`04ooooo`00G_ooool2o`00047ooooo00?o
o`00ooooooooool01oooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo00gooooo1?l0
000Jooooo`03o`000?oooooooooo00Cooooo001Pooooo`03o`000?oooooooooo03gooooo00?oo`00
ooooooooool02Oooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo00Wooooo0ol0000N
ooooo`03o`000?oooooooooo00Cooooo001Qooooo`03o`000?oooooooooo03[ooooo0_oo000=oooo
o`03o`000?oooooooooo08Gooooo00?o0000ooooooooool01?ooool4o`00027ooooo00?o0000oooo
ooooool01?ooool006;ooooo00?o0000ooooooooool0>?ooool00ooo003oooooooooo`0>ooooo`03
o`000?oooooooooo08Cooooo00Co0000oooooooooooooooo0ol0000Uooooo`03o`000?oooooooooo
00Cooooo001Sooooo`03o`000?oooooooooo03Kooooo00?oo`00ooooooooool04?ooool00ol0003o
ooooooooo`24ooooo`?o0000:?ooool00ol0003oooooooooo`04ooooo`00I?ooool00ol0003ooooo
ooooo`0cooooo`;oo`005?ooool00ol0003oooooooooo`1oooooo`Co000000?oooooo`000?ooool0
:?ooool00ol0003oooooooooo`04ooooo`00IOooool00ol0003oooooooooo`0`ooooo`;oo`005ooo
ool00ol0003oooooooooo`1kooooo`?o00001_ooool00ol0003oooooooooo`0Vooooo`03o`000?oo
oooooooo00Cooooo001Vooooo`03o`000?oooooooooo02kooooo00?oo`00ooooooooool06?ooool0
0ol0003oooooooooo`1fooooo`Co00002_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo00Cooooo001Wooooo`03o`000?oooooooooo02_ooooo0_oo000Looooo`03o`000?oooooooooo
07;ooooo0ol0000?ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00oooool006So
oooo00?o0000ooooooooool0:?ooool2ool001oooooo00?o0000ooooooooool0K_ooool3o`0001;o
oooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`03ooooo`00JOooool00ol0003ooooo
ooooo`0Vooooo`03ool00?oooooooooo023ooooo00?o0000ooooooooool0JOooool4o`0001Kooooo
00?o0000ooooooooool09?ooool00ol0003oooooooooo`03ooooo`00J_ooool2o`0002Gooooo00?o
o`00ooooooooool08_ooool00ol0003oooooooooo`1Uooooo`?o00006oooool00ol0003ooooooooo
o`0Sooooo`03o`000?oooooooooo00?ooooo001/ooooo`03o`000?oooooooooo04Sooooo00?o0000
ooooooooool0H?ooool4o`0001oooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`03
ooooo`00KOooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo05cooooo0ol0000Toooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool00oooool006kooooo00?o0000oooooooo
ool0B?ooool00ol0003oooooooooo`1Hooooo`?o0000:?ooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo00?ooooo001_ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0
Doooool4o`0002_ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`03ooooo`00L?oo
ool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo04oooooo0ol0000`ooooo`03o`000?oo
oooooooo01oooooo00?o0000ooooooooool00oooool0077ooooo00?o0000ooooooooool0B?ooool0
0ol0003oooooooooo`1:ooooo`Co0000=?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooo
oooo00?ooooo001booooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0A_ooool3o`00
03Wooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`02ooooo`00Loooool00ol0003o
ooooooooo`18ooooo`03o`000?oooooooooo04;ooooo0ol0000mooooo`03o`000?oooooooooo01go
oooo00?o0000ooooooooool00_ooool007Cooooo00?o0000ooooooooool0B?ooool00ol0003ooooo
ooooo`0mooooo`Co0000@Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00;ooooo
001eooooo`;o0000BOooool00ol0003oooooooooo`0iooooo`?o0000AOooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo00;ooooo001gooooo`03o`000?oooooooooo04Oooooo00?o0000
ooooooooool0=?ooool4o`0004Wooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`02
ooooo`00N?ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo033ooooo0ol0001>oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool00_ooool007Wooooo00?o0000oooooooo
ool0Aoooool00ol0003oooooooooo`0/ooooo`?o0000D_ooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo00;ooooo001jooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0
9oooool4o`0005Kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`02ooooo`00Nooo
ool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo02?ooooo0ol0001Kooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool00_ooool007cooooo00?o0000ooooooooool0Aoooool0
0ol0003oooooooooo`0Nooooo`Co0000G_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo00;ooooo001mooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool06_ooool3o`00
06?ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`01ooooo`00O_ooool00ol0003o
ooooooooo`17ooooo`03o`000?oooooooooo01Kooooo0ol0001Wooooo`03o`000?oooooooooo01Ko
oooo00?o0000ooooooooool00Oooool007oooooo00?o0000ooooooooool0Aoooool00ol0003ooooo
ooooo`0Aooooo`Co0000Joooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo007ooooo
0020ooooo`;o0000B?ooool00ol0003oooooooooo`0=ooooo`?o0000L?ooool00ol0003ooooooooo
o`0Dooooo`03o`000?oooooooooo007ooooo0022ooooo`03o`000?oooooooooo04Kooooo00?o0000
ooooooooool02?ooool4o`0007Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`01
ooooo`00Poooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo00Cooooo0ol0001hoooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00Oooool008Cooooo00?o0000oooooooo
ool0A_ooool00ol0003oooooooooo`03o`0007cooooo00?o0000ooooooooool04_ooool00ol0003o
ooooooooo`01ooooo`00QOooool00ol0003oooooooooo`16ooooo`;o0000P?ooool00ol0003ooooo
ooooo`0Aooooo`03o`000?oooooooooo007ooooo0026ooooo`03o`000?oooooooooo04Gooooo00?o
0000ooooooooool0P?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo007ooooo0027
ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool0POooool00ol0003oooooooooo`0?
ooooo`03o`000?oooooooooo007ooooo0028ooooo`03o`000?oooooooooo04?ooooo00?o0000oooo
ooooool0P_ooool00ol0003oooooooooo`0?ooooo`7o00000Oooool1ooooo`00ROooool00ol0003o
ooooooooo`12ooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool03oooool1o`00007o
oooo0Oooool008[ooooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`23ooooo`03o`00
0?oooooooooo00kooooo0Ol00001ooooo`7ooooo002;ooooo`;o0000@Oooool00ol0003ooooooooo
o`24ooooo`03o`000?oooooooooo00gooooo0Ol00001ooooo`7ooooo002=ooooo`03o`000?oooooo
oooo03kooooo00?o0000ooooooooool0QOooool00ol0003oooooooooo`0<ooooo`7o00000Oooool1
ooooo`00S_ooool00ol0003oooooooooo`0mooooo`03o`000?oooooooooo08Kooooo00?o0000oooo
ooooool02oooool1o`00007ooooo0Oooool008oooooo00?o0000ooooooooool0??ooool00ol0003o
ooooooooo`27ooooo`03o`000?oooooooooo00[ooooo0Ol00001ooooo`7ooooo002@ooooo`03o`00
0?oooooooooo03_ooooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`0:ooooo`7o0000
0Oooool1ooooo`00TOooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo08Sooooo00?o
0000ooooooooool02Oooool1o`00007ooooo0Oooool009;ooooo00?o0000ooooooooool0>Oooool0
0ol0003oooooooooo`29ooooo`03o`000?oooooooooo00Sooooo0Ol00001ooooo`7ooooo002Coooo
o`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0R_ooool00ol0003oooooooooo`08oooo
o`7o00000Oooool009Cooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`2;ooooo`03
o`000?oooooooooo00Oooooo0Ol00001ooooo`00UOooool00ol0003oooooooooo`0fooooo`03o`00
0?oooooooooo08cooooo00?o0000ooooooooool01_ooool1o`00007ooooo002Fooooo`03o`000?oo
oooooooo03Gooooo00?o0000ooooooooool0S?ooool00ol0003oooooooooo`06ooooo`7o00000Ooo
ool009Oooooo0_l0000eooooo`03o`000?oooooooooo08gooooo00?o0000ooooooooool01Oooool1
o`00007ooooo002Iooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0S_ooool00ol0
003oooooooooo`04ooooo`7o00000Oooool009[ooooo00?o0000ooooooooool0<Oooool00ol0003o
ooooooooo`2?ooooo`03o`000?oooooooooo00?ooooo0Ol00001ooooo`00Voooool00ol0003ooooo
ooooo`0`ooooo`03o`000?oooooooooo093ooooo00?o0000ooooooooool00_ooool1o`00007ooooo
002Looooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0TOooool01Ol0003ooooooooo
oooooooo0000007ooooo002Mooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0TOoo
ool01Ol0003ooooooooooooooooo0000007ooooo002Nooooo`03o`000?oooooooooo02gooooo00?o
0000ooooooooool0T_ooool01?l0003oooooooooooooool1o`000000Woooool00ol0003ooooooooo
o`0/ooooo`03o`000?oooooooooo09?ooooo00?o0000ooooooooool00Ol000000:3ooooo00?o0000
ooooooooool0:oooool00ol0003oooooooooo`2Dooooo`7o00000Oooool1o`000000XOooool00ol0
003oooooooooo`0Zooooo`03o`000?oooooooooo09Gooooo0_l000000:;ooooo0_l0000Zooooo`03
o`000?oooooooooo09Cooooo0ol000000:Cooooo00?o0000ooooooooool09oooool00ol0003ooooo
ooooo`2@ooooo`Co00000oooool00:Gooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`2=ooooo`?o00001oooool00:Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`29
ooooo`Co00002_ooool00:Oooooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`25oooo
o`Co00003_ooool00:Sooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`22ooooo`?o
00004_ooool00:Wooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`1nooooo`Co0000
5Oooool00:[ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`1jooooo`Co00006Ooo
ool00:_ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`1eooooo`Co00007Oooool0
0:cooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1booooo`?o00008Oooool00:go
oooo0_l0000Pooooo`03o`000?oooooooooo06kooooo1?l0000Tooooo`00[oooool00ol0003ooooo
ooooo`0Mooooo`03o`000?oooooooooo06[ooooo1?l0000Xooooo`00/?ooool00ol0003ooooooooo
o`0Looooo`03o`000?oooooooooo06Oooooo0ol0000/ooooo`00/Oooool00ol0003oooooooooo`0K
ooooo`03o`000?oooooooooo06?ooooo1?l0000_ooooo`00/_ooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo05oooooo1?l0000cooooo`00/oooool00ol0003oooooooooo`0Iooooo`03
o`000?oooooooooo05cooooo0ol0000gooooo`00]?ooool00ol0003oooooooooo`0Hooooo`03o`00
0?oooooooooo05Sooooo1?l0000jooooo`00]Oooool00ol0003oooooooooo`0Gooooo`03o`000?oo
oooooooo05Cooooo1?l0000nooooo`00]_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooo
oooo053ooooo1?l00012ooooo`00]oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo
04gooooo0ol00016ooooo`00^?ooool2o`0001Gooooo00?o0000ooooooooool0BOooool4o`0004Wo
oooo002jooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0AOooool4o`0004gooooo
002kooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0@_ooool3o`00057ooooo002l
ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0?_ooool4o`0005Cooooo002moooo
o`03o`000?oooooooooo00oooooo00?o0000ooooooooool0>_ooool4o`0005Sooooo002nooooo`03
o`000?oooooooooo00kooooo00?o0000ooooooooool0=_ooool4o`0005cooooo002oooooo`03o`00
0?oooooooooo00gooooo00?o0000ooooooooool0<oooool3o`00063ooooo0030ooooo`03o`000?oo
oooooooo00cooooo00?o0000ooooooooool0;oooool4o`0006?ooooo0031ooooo`03o`000?oooooo
oooo00_ooooo00?o0000ooooooooool0:oooool4o`0006Oooooo0032ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool0:?ooool3o`0006_ooooo0033ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool09?ooool4o`0006kooooo0034ooooo`;o00002Oooool00ol0003ooooo
ooooo`0Pooooo`Co0000L_ooool00<Kooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`0Mooooo`?o0000M_ooool00<Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0I
ooooo`Co0000NOooool00<Sooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Eoooo
o`Co0000OOooool00<Wooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0Aooooo`Co
0000POooool00<[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0>ooooo`?o0000
QOooool00<_ooooo00Go0000ooooooooooooooooo`00000<ooooo`Co0000R?ooool00<cooooo00Co
0000oooooooooooo00002?ooool4o`0008cooooo003=ooooo`03o`000?oooooo000000Gooooo0ol0
002@ooooo`00c_ooool2o`000003ooooool0003o000000;o0000Toooool00<oooooo0_l0002Goooo
o`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYoooo
o`00\
\>"],
  ImageRangeCache->{{{0, 359}, {330.375, 0}} -> {-0.0771432, -0.0315529, \
0.00350368, 0.00350368}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .92059 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-16 1.0763 -0.0263982 1.0763 [
[.01694 .18568 -11.9631 -9 ]
[.01694 .18568 .03693 0 ]
[.13793 .13897 -11.619 -9 ]
[.13793 .13897 .38095 0 ]
[.26292 .09073 -5.63752 -9 ]
[.26292 .09073 .36248 0 ]
[.39212 .04087 -5.46552 -9 ]
[.39212 .04087 .53448 0 ]
[.52574 -0.01069 -5.29351 -9 ]
[.52574 -0.01069 .70649 0 ]
[.58272 .04263 0 -6.19654 ]
[.58272 .04263 6 2.80346 ]
[.71715 .21863 0 -6.07114 ]
[.71715 .21863 6 2.92886 ]
[.83675 .37523 0 -5.963 ]
[.83675 .37523 6 3.037 ]
[.94385 .51546 0 -5.8688 ]
[.94385 .51546 6 3.1312 ]
[.01386 .20006 -12 -2.76892 ]
[.01386 .20006 0 6.23108 ]
[.00748 .25499 -24 -2.80073 ]
[.00748 .25499 0 6.19927 ]
[.00093 .31131 -6 -2.83339 ]
[.00093 .31131 0 6.16661 ]
[-0.00579 .36907 -18 -2.86695 ]
[-0.00579 .36907 0 6.13305 ]
[-0.01268 .42831 -6 -2.90143 ]
[-0.01268 .42831 0 6.09857 ]
[ 0 0 0 0 ]
[ 1 .92059 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02642 .19522 m
.53391 0 L
s
.02642 .19522 m
.03116 .2 L
s
[(-2)] .01694 .18568 .99384 1 Mshowa
.14712 .14879 m
.15172 .1537 L
s
[(-1)] .13793 .13897 .93651 1 Mshowa
.2718 .10083 m
.27624 .10588 L
s
[(0)] .26292 .09073 .87917 1 Mshowa
.40066 .05126 m
.40493 .05646 L
s
[(1)] .39212 .04087 .82184 1 Mshowa
.53391 0 m
.538 .00534 L
s
[(2)] .52574 -0.01069 .7645 1 Mshowa
.125 Mabswid
.05025 .18606 m
.05308 .18894 L
s
.07424 .17683 m
.07705 .17973 L
s
.09837 .16755 m
.10117 .17046 L
s
.12267 .1582 m
.12545 .16113 L
s
.17173 .13933 m
.17447 .14229 L
s
.19651 .1298 m
.19923 .13278 L
s
.22144 .1202 m
.22414 .1232 L
s
.24654 .11055 m
.24922 .11356 L
s
.29723 .09105 m
.29988 .0941 L
s
.32283 .0812 m
.32546 .08427 L
s
.3486 .07129 m
.35121 .07437 L
s
.37455 .06131 m
.37713 .06441 L
s
.42695 .04115 m
.4295 .04428 L
s
.45342 .03096 m
.45594 .03412 L
s
.48007 .02071 m
.48257 .02388 L
s
.5069 .01039 m
.50938 .01358 L
s
.25 Mabswid
.53391 0 m
.9804 .58403 L
s
.57014 .04738 m
.56384 .04975 L
s
[(0)] .58272 .04263 -1 .37701 Mshowa
.70445 .22307 m
.6981 .22529 L
s
[(2)] .71715 .21863 -1 .34914 Mshowa
.82396 .37939 m
.81756 .38147 L
s
[(4)] .83675 .37523 -1 .32511 Mshowa
.93098 .51938 m
.92454 .52134 L
s
[(6)] .94385 .51546 -1 .30418 Mshowa
.125 Mabswid
.60525 .09331 m
.60147 .09471 L
s
.63931 .13786 m
.63552 .13924 L
s
.67236 .1811 m
.66856 .18245 L
s
.73562 .26383 m
.7318 .26514 L
s
.7659 .30345 m
.76207 .30473 L
s
.79534 .34195 m
.7915 .34322 L
s
.85181 .41581 m
.84796 .41704 L
s
.87891 .45126 m
.87506 .45247 L
s
.90529 .48577 m
.90143 .48696 L
s
.95601 .55212 m
.95214 .55328 L
s
.25 Mabswid
.02642 .19522 m
0 .42381 L
s
.02642 .19522 m
.0327 .19281 L
s
[(-1)] .01386 .20006 1 -0.38468 Mshowa
.02006 .25024 m
.02635 .24786 L
s
[(-0.5)] .00748 .25499 1 -0.37762 Mshowa
.01354 .30664 m
.01985 .3043 L
s
[(0)] .00093 .31131 1 -0.37036 Mshowa
.00686 .36448 m
.01318 .36218 L
s
[(0.5)] -0.00579 .36907 1 -0.3629 Mshowa
0 .42381 m
.00634 .42156 L
s
[(1)] -0.01268 .42831 1 -0.35524 Mshowa
.125 Mabswid
.02516 .20612 m
.02893 .20468 L
s
.0239 .21707 m
.02767 .21563 L
s
.02262 .22807 m
.0264 .22664 L
s
.02135 .23913 m
.02512 .2377 L
s
.01877 .26141 m
.02255 .25999 L
s
.01747 .27263 m
.02125 .27122 L
s
.01617 .28391 m
.01995 .2825 L
s
.01486 .29525 m
.01864 .29384 L
s
.01222 .31809 m
.01601 .3167 L
s
.01089 .3296 m
.01468 .32821 L
s
.00955 .34117 m
.01334 .33978 L
s
.00821 .35279 m
.012 .35141 L
s
.0055 .37622 m
.0093 .37485 L
s
.00414 .38803 m
.00793 .38666 L
s
.00276 .39989 m
.00656 .39853 L
s
.00139 .41182 m
.00519 .41047 L
s
.25 Mabswid
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.54154 .92059 L
s
.54154 .92059 m
.5414 .7134 L
s
.5414 .7134 m
.02642 .19522 L
s
.53391 0 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.53391 0 m
.02642 .19522 L
s
.5414 .7134 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.54154 .92059 L
s
.54154 .92059 m
.5414 .7134 L
s
0 0 m
1 0 L
1 .92059 L
0 .92059 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.37404 .653 m
.40679 .63497 L
s
1 0 .6 r
.3565 .61826 m
.38627 .60161 L
s
.8 0 1 r
.33901 .58352 m
.36601 .5683 L
s
.2 0 1 r
.32172 .54881 m
.34652 .53506 L
s
0 .4 1 r
.30505 .51415 m
.32854 .50185 L
s
0 1 1 r
.28942 .47952 m
.31243 .46854 L
s
0 1 .4 r
.27488 .44469 m
.29789 .43484 L
s
.2 1 0 r
.26113 .40938 m
.2843 .40038 L
s
.8 1 0 r
.24772 .37344 m
.27103 .36491 L
s
1 .6 0 r
.23434 .33698 m
.25773 .32857 L
s
0 1 .4 r
.29789 .43484 m
.32028 .42446 L
s
.2 1 0 r
.2843 .40038 m
.30728 .391 L
s
0 1 1 r
.31243 .46854 m
.33407 .4569 L
s
.8 1 0 r
.27103 .36491 m
.29438 .35617 L
s
0 .4 1 r
.32854 .50185 m
.34946 .48875 L
s
.2 0 1 r
.34652 .53506 m
.36723 .52027 L
s
1 .6 0 r
.25773 .32857 m
.28124 .32007 L
s
.8 0 1 r
.36601 .5683 m
.38763 .55156 L
s
1 0 .6 r
.38627 .60161 m
.41006 .58272 L
s
1 0 0 r
.40679 .63497 m
.43353 .61387 L
s
.2 1 0 r
.30728 .391 m
.33001 .38139 L
s
.8 1 0 r
.29438 .35617 m
.31772 .34727 L
s
0 1 .4 r
.32028 .42446 m
.34204 .41391 L
s
1 .6 0 r
.28124 .32007 m
.30485 .31147 L
s
0 1 1 r
.33407 .4569 m
.35444 .44531 L
s
0 .4 1 r
.34946 .48875 m
.36806 .47607 L
s
.2 0 1 r
.36723 .52027 m
.38384 .50645 L
s
.8 1 0 r
.31772 .34727 m
.34107 .33827 L
s
.2 1 0 r
.33001 .38139 m
.35261 .37177 L
s
1 .6 0 r
.30485 .31147 m
.32857 .30281 L
s
0 1 .4 r
.34204 .41391 m
.36348 .40357 L
s
.8 0 1 r
.38763 .55156 m
.40262 .53647 L
s
0 1 1 r
.35444 .44531 m
.37432 .43427 L
s
1 0 .6 r
.41006 .58272 m
.42459 .56602 L
s
.8 1 0 r
.34107 .33827 m
.3645 .32929 L
s
1 .6 0 r
.32857 .30281 m
.35242 .29409 L
s
0 .4 1 r
.36806 .47607 m
.38587 .46441 L
s
.2 1 0 r
.35261 .37177 m
.37526 .36234 L
s
1 0 0 r
.43353 .61387 m
.44899 .59517 L
s
0 1 .4 r
.36348 .40357 m
.38503 .39368 L
s
.2 0 1 r
.38384 .50645 m
.39902 .49432 L
s
0 1 1 r
.37432 .43427 m
.39444 .424 L
s
.8 1 0 r
.3645 .32929 m
.38811 .32041 L
s
1 .6 0 r
.35242 .29409 m
.37641 .28537 L
s
.8 0 1 r
.40262 .53647 m
.4148 .52411 L
s
.2 1 0 r
.37526 .36234 m
.39817 .35324 L
s
0 .4 1 r
.38587 .46441 m
.40415 .45386 L
s
0 1 .4 r
.38503 .39368 m
.407 .38439 L
s
1 0 .6 r
.42459 .56602 m
.43409 .55364 L
s
.8 1 0 r
.38811 .32041 m
.41199 .31171 L
s
1 .6 0 r
.37641 .28537 m
.40059 .27665 L
s
.2 0 1 r
.39902 .49432 m
.41491 .48366 L
s
0 1 1 r
.39444 .424 m
.41524 .41459 L
s
.2 1 0 r
.39817 .35324 m
.4215 .34454 L
s
1 0 0 r
.44899 .59517 m
.45692 .58267 L
s
0 1 .4 r
.407 .38439 m
.42961 .37574 L
s
.8 0 1 r
.4148 .52411 m
.42765 .51366 L
s
0 .4 1 r
.40415 .45386 m
.42349 .44441 L
s
.8 1 0 r
.41199 .31171 m
.43621 .30321 L
s
1 .6 0 r
.40059 .27665 m
.42499 .26797 L
s
.2 1 0 r
.4215 .34454 m
.44537 .33628 L
s
0 1 1 r
.41524 .41459 m
.43694 .40604 L
s
.2 0 1 r
.41491 .48366 m
.43233 .47429 L
s
1 0 .6 r
.43409 .55364 m
.44352 .54395 L
s
0 1 .4 r
.42961 .37574 m
.45296 .36776 L
s
0 .4 1 r
.42349 .44441 m
.44405 .43603 L
s
.8 1 0 r
.43621 .30321 m
.46083 .2949 L
s
1 .6 0 r
.42499 .26797 m
.44962 .25931 L
s
.8 0 1 r
.42765 .51366 m
.44253 .50462 L
s
1 0 0 r
.45692 .58267 m
.46335 .57436 L
s
.2 1 0 r
.44537 .33628 m
.46985 .32843 L
s
0 1 1 r
.43694 .40604 m
.45961 .39839 L
s
.2 0 1 r
.43233 .47429 m
.45141 .46619 L
s
1 0 .6 r
.44352 .54395 m
.45511 .53573 L
s
0 1 .4 r
.45296 .36776 m
.47712 .36042 L
s
0 .4 1 r
.44405 .43603 m
.46583 .42877 L
s
.8 1 0 r
.46083 .2949 m
.48585 .28672 L
s
1 .6 0 r
.44962 .25931 m
.47448 .25066 L
s
.8 0 1 r
.44253 .50462 m
.45959 .49695 L
s
.2 1 0 r
.46985 .32843 m
.49496 .32092 L
s
0 1 1 r
.45961 .39839 m
.48327 .39162 L
s
1 0 0 r
.46335 .57436 m
.47119 .56779 L
s
0 1 .4 r
.47712 .36042 m
.50214 .35368 L
s
.2 0 1 r
.45141 .46619 m
.47201 .4594 L
s
1 0 .6 r
.45511 .53573 m
.46931 .52885 L
s
0 .4 1 r
.46583 .42877 m
.48877 .42264 L
s
.8 1 0 r
.48585 .28672 m
.51124 .2786 L
s
1 .6 0 r
.47448 .25066 m
.49956 .24197 L
s
0 1 1 r
.48327 .39162 m
.50797 .38571 L
s
.2 1 0 r
.49496 .32092 m
.5207 .31365 L
s
1 0 0 r
.47119 .56779 m
.48146 .56238 L
s
.8 0 1 r
.45959 .49695 m
.4785 .4908 L
s
0 1 .4 r
.50214 .35368 m
.52806 .34741 L
s
.2 0 1 r
.47201 .4594 m
.4939 .45402 L
s
1 0 .6 r
.46931 .52885 m
.48568 .5236 L
s
0 .4 1 r
.48877 .42264 m
.51286 .41766 L
s
1 0 0 r
.59733 .56286 m
.64503 .56116 L
s
.56039 .56028 m
.59733 .56286 L
s
0 1 1 r
.50797 .38571 m
.53379 .38055 L
s
1 0 0 r
.48146 .56238 m
.49387 .55846 L
s
.8 1 0 r
.51124 .2786 m
.53692 .27043 L
s
.8 0 1 r
.4785 .4908 m
.49879 .48634 L
s
.2 1 0 r
.5207 .31365 m
.547 .3064 L
s
1 0 0 r
.64503 .56116 m
.69243 .55469 L
s
1 .6 0 r
.49956 .24197 m
.52481 .23322 L
s
.2 0 1 r
.4939 .45402 m
.51694 .45011 L
s
1 0 0 r
.53729 .5574 m
.56039 .56028 L
s
0 1 .4 r
.52806 .34741 m
.55489 .34135 L
s
0 .4 1 r
.51286 .41766 m
.5382 .41376 L
s
1 0 .6 r
.48568 .5236 m
.5034 .52025 L
s
.59835 .52316 m
.64079 .52147 L
s
.56506 .52137 m
.59835 .52316 L
s
1 0 0 r
.49387 .55846 m
.50739 .55636 L
s
0 1 1 r
.53379 .38055 m
.5609 .37588 L
s
1 0 0 r
.52139 .55606 m
.53729 .5574 L
s
.8 0 1 r
.49879 .48634 m
.52009 .48367 L
s
1 0 .6 r
.64079 .52147 m
.68407 .51543 L
s
.54132 .51942 m
.56506 .52137 L
s
.2 0 1 r
.51694 .45011 m
.54125 .44766 L
s
1 0 0 r
.50739 .55636 m
.52139 .55606 L
s
0 .4 1 r
.5382 .41376 m
.56519 .41067 L
s
1 0 .6 r
.5034 .52025 m
.5218 .51891 L
s
.2 1 0 r
.547 .3064 m
.57369 .29899 L
s
1 0 .6 r
.5218 .51891 m
.54132 .51942 L
s
.8 0 1 r
.59867 .48377 m
.63645 .48177 L
s
.56763 .48325 m
.59867 .48377 L
s
.52009 .48367 m
.54253 .48278 L
s
.8 1 0 r
.53692 .27043 m
.56279 .26211 L
s
0 1 .4 r
.55489 .34135 m
.58255 .33517 L
s
.8 0 1 r
.54253 .48278 m
.56763 .48325 L
s
.2 0 1 r
.54125 .44766 m
.56759 .44633 L
s
0 1 1 r
.5609 .37588 m
.58944 .37119 L
s
1 .6 0 r
.52481 .23322 m
.55021 .22438 L
s
.2 0 1 r
.56759 .44633 m
.59753 .44517 L
s
.8 0 1 r
.63645 .48177 m
.67567 .47609 L
s
0 .4 1 r
.56519 .41067 m
.59446 .40769 L
s
.2 0 1 r
.59753 .44517 m
.63169 .44236 L
s
0 .4 1 r
.59446 .40769 m
.62606 .40364 L
s
0 1 1 r
.58944 .37119 m
.61914 .36577 L
s
.2 0 1 r
.63169 .44236 m
.66718 .43677 L
s
0 1 .4 r
.58255 .33517 m
.61068 .32846 L
s
.2 1 0 r
.57369 .29899 m
.60053 .29122 L
s
.8 1 0 r
.56279 .26211 m
.58874 .25359 L
s
0 .4 1 r
.62606 .40364 m
.65841 .39772 L
s
1 .6 0 r
.55021 .22438 m
.57574 .21544 L
s
0 1 1 r
.61914 .36577 m
.64905 .35916 L
s
0 1 .4 r
.61068 .32846 m
.63874 .32104 L
s
.2 1 0 r
.60053 .29122 m
.62728 .28305 L
s
.8 1 0 r
.58874 .25359 m
.61472 .24487 L
s
1 .6 0 r
.57574 .21544 m
.6014 .20641 L
s
0 g
.25 Mabswid
.53391 0 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.53391 0 m
.02642 .19522 L
s
.02642 .19522 m
.53391 0 L
s
.02642 .19522 m
.03116 .2 L
s
[(-2)] .01694 .18568 .99384 1 Mshowa
.14712 .14879 m
.15172 .1537 L
s
[(-1)] .13793 .13897 .93651 1 Mshowa
.2718 .10083 m
.27624 .10588 L
s
[(0)] .26292 .09073 .87917 1 Mshowa
.40066 .05126 m
.40493 .05646 L
s
[(1)] .39212 .04087 .82184 1 Mshowa
.53391 0 m
.538 .00534 L
s
[(2)] .52574 -0.01069 .7645 1 Mshowa
.125 Mabswid
.05025 .18606 m
.05308 .18894 L
s
.07424 .17683 m
.07705 .17973 L
s
.09837 .16755 m
.10117 .17046 L
s
.12267 .1582 m
.12545 .16113 L
s
.17173 .13933 m
.17447 .14229 L
s
.19651 .1298 m
.19923 .13278 L
s
.22144 .1202 m
.22414 .1232 L
s
.24654 .11055 m
.24922 .11356 L
s
.29723 .09105 m
.29988 .0941 L
s
.32283 .0812 m
.32546 .08427 L
s
.3486 .07129 m
.35121 .07437 L
s
.37455 .06131 m
.37713 .06441 L
s
.42695 .04115 m
.4295 .04428 L
s
.45342 .03096 m
.45594 .03412 L
s
.48007 .02071 m
.48257 .02388 L
s
.5069 .01039 m
.50938 .01358 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 265.125},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001Bb000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00`oooool5o`000:3ooooo0033ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@0X?ooool00<Cooooo00?oV9RHob4Q8Oo^k^h0XOooool00<Gooooo00?oV9RH
ob4Q8Oo^k^h0X?ooool00<Kooooo00?oMgMgofIVI_ooool0Woooool00<Oooooo00?o0000oooooooo
ool0W_ooool00<?ooooo00Go0000okZj^_ooooooV9RHoa0@402Pooooo`00`oooool01OnHV9So410@
o`000?lQ8B7oc<c<0:3ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003;ooooo`;o0000Voooool00<Sooooo0ol000000ooooooo0000ooooo`2Jooooo`00a_oo
ool2o`0000Cooooo0_l0002Jooooo`00`oooool3o`0000Kooooo00?o0000ooooool00000VOooool0
0<3ooooo1?l00008ooooo`04o`000?ooooooooooo`0009Sooooo002Hooooo`Co000000?o410@oooo
ooooool07oooool2o`0000Cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0002H
ooooo`00V_ooool00ol0003oooooooooo`0Nooooo`?o00003_ooool01Ol0003ooooooooooooooooo
000009Oooooo002Jooooo`03o`000?oooooooooo01cooooo0_l0000Aooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0U?ooool009[ooooo00?o0000ooooooooool06Oooool3o`0000;o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo09?o
oooo002Jooooo`03o`000?oooooooooo01Kooooo0ol0000Fooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^08Kooooo002Jooooo`03o`00
0?oooooooooo01Cooooo0_l0000Iooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1oooool01OmgMgOoV9RHoooooonHV9SoMgMg08Kooooo002Jooooo`03o`000?oooooooooo017ooooo
0ol000000ooooooo0000ooooo`0Hooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1_ooool01Ol@413ooooooooooooooooo410@08Kooooo002Hooooo`03oeEEEOmVIVKo0000017ooooo
0_l0000Nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool01Ol0003ooooo
oooooooooooo000008Kooooo002Yooooo`?o00008?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000026ooooo`00Yoooool3o`0002;ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@
4100Q_ooool00:Cooooo0ol00002ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Q_ooool00:7ooooo
0ol0000Xooooo`03o`000?oooooooooo00Sooooo0_l00004ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h0Q_ooool009oooooo0_l0000[ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo
0000S_ooool009cooooo0ol000000ooooooo0000ooooo`0Zooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0S?ooool009[ooooo0_l00005ooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`2;ooooo`00Uoooool3o`0003;ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`2:ooooo`00K?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^02?ooooo0ol000000ooooooo0000ooooo`0booooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0ROooool006cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Qooooo`;o0000>?ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo08Wooooo001/ooooo`05oa0@4?oooooooooo
ooooool@41007_ooool3o`0003[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`28
ooooo`00K?ooool01Ol0003ooooooooooooooooo000001cooooo0ol0000looooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0Qoooool006cooooo00Go0000ooooooooooooooooo`00000I
ooooo`?o00000_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool0Q_ooool006cooooo00Go410@oooooooooooooooooa0@400Gooooo`;o0000@_ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo08Kooooo001/ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL05?ooool3o`0004Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`25
ooooo`00K?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^017ooooo0ol00002ooooo`03o`000?oooooo
oooo04;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`24ooooo`00P?ooool2o`00
04[ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`23ooooo`00OOooool3o`0004co
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`22ooooo`00Noooool2o`000003oooo
ool0003ooooo04cooooo00?o0000ooooooooool05?ooool2o`0008?ooooo001hooooo`?o0000DOoo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooo000008?ooooo001eooooo`?o0000E?ooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo083ooooo001cooooo`Co0000EOooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo07oooooo001`ooooo`?o00001?ooool00ol0003o
ooooooooo`1Booooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0Ooooool006kooooo
0_l0001Looooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0O_ooool004?ooooo1?l0
00000ol@413oooooooooo`0Qooooo`?o0000G_ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo07gooooo0015ooooo`03o`000?oooooooooo023ooooo0ol00003ooooo`03o`000?oooooo
oooo05_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1looooo`00>_ooool6o`00
00Gooooo00?o0000ooooooooool07_ooool2o`0006Cooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`1looooo`00AOooool00ol0003oooooooooo`0Kooooo`?o0000I_ooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo07_ooooo0015ooooo`03o`000?oooooooooo01Wooooo
0_l00002ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`1jooooo`00AOooool00ol0003oooooooooo`0Fooooo`?o0000Joooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo07Wooooo0015ooooo`03o`000?oooooooooo01Cooooo0_l0001^
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0NOooool004?ooooo00?oEEEEofIV
I_l000004oooool3o`000003ooooool0003ooooo06gooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`1hooooo`00E_ooool3o`0007?ooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`1gooooo`00E?ooool2o`0007Kooooo00?o0000ooooooooool07oooool2o`0007Sooooo
001Aooooo`?o000000?oooooo`000?ooool0MOooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo07Kooooo001?ooooo`;o0000Noooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo07Gooooo001<ooooo`?o0000OOooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
07Cooooo0019ooooo`Co0000Ooooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo07?o
oooo0017ooooo`;o00001?ooool00ol0003oooooooooo`1looooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool0L_ooool004Cooooo0ol00025ooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool0L_ooool001[ooooo1Ol0000Sooooo`?o0000Qoooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo077ooooo000Jooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@08?ooool3
o`0000?ooooo00?o0000ooooooooool0Q?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo073ooooo000Booooo`Ko00000oooool00onHV9So8B4Qonk^kP0Oooooo`;o0000SOooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo06oooooo000Looooo`03oiRHV?lQ8B7ok^k^01_o
oooo0ol0002?ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0Koooool001gooooo
00?oMgMgofIVI_ooool05oooool3o`0000?ooooo00?o0000ooooooooool0S?ooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooooooo06kooooo000Nooooo`03o`000?oooooooooo01Cooooo0_l0
002Eooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0KOooool001[ooooo00Go0000
okZj^_ooooooV9RHoa0@400Cooooo`?o0000Uoooool00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo06cooooo000Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`04Oooool2o`0000?ooooo00?o
0000ooooooooool0U?ooool00ol0003oooooooooo`0Zooooo`;o0000KOooool002gooooo0ol0002L
ooooo`03o`000?oooooooooo02[ooooo0_l0001]ooooo`00:_ooool3o`0009oooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`1Zooooo`00:?ooool2o`0000?ooooo00?o0000oooooooo
ool0W?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo06Wooooo000Uooooo`?o0000
Y?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo06Wooooo000Tooooo`03o`000?oo
oooooooo0:Gooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1Xooooo`006_ooool4
o`000003oa0@4?oooooooooo00?ooooo0_l0002Vooooo`03o`000?oooooooooo02oooooo00?o0000
ooooooooool0Ioooool001cooooo00?o0000ooooooooool01Oooool2o`000:Kooooo00?o0000oooo
ooooool0<?ooool00ol0003oooooooooo`1Vooooo`004Oooool6o`0000Gooooo00?o0000oooooooo
ool01?ooool4o`000:Gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`08ooooo`Go
0000FOooool001cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0002Tooooo`03
o`000?oooooooooo01;ooooo0_ooV@0Mooooo`03o`000?oooooooooo00Oooooo00GoV9RHob4Q8Oo^
k^koooooodA4A01Iooooo`007?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool0XOooool00ol0003oooooooooo`0?ooooo`?ooiT08?ooool00ol0003o
ooooooooo`07ooooo`03oiRHV?lQ8B7ok^k^05[ooooo000Looooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`2Pooooo`03o`000?oooooooooo00cooooo
0oooV@0Tooooo`03o`000?oooooooooo00Oooooo00?oV9RHob4Q8Oo^k^h0FOooool001cooooo00?o
0000ooooooooool01?ooool2o`0000Gooooo00?o0000ooooooooool0Woooool00ol0003ooooooooo
o`0:ooooo`;ooiT0:?ooool00ol0003oooooooooo`07ooooo`03ogMgMomVIVKooooo05Sooooo000J
ooooo`03oeEEEOmVIVKo000000Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`2N
ooooo`03o`000?oooooooooo00Oooooo0oooV@0Zooooo`03o`000?oooooooooo00Sooooo00?o0000
ooooooooool0Eoooool002?ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`2Moooo
o`03o`000?oooooooooo00Cooooo0oooV@0^ooooo`;o00001?ooool01Ol0003o^[ZjoooooonHV9So
410@05Wooooo000Sooooo`;o00002?ooool00ol0003oooooooooo`2Looooo`03o`000?oooooooooo
00CooiT0;oooool2o`000003ooooool0003ooooo00?ooooo00GoV9RHoa0@4?l0003o8B4Qolc<c01I
ooooo`008oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo09[ooooo00CooiT0o`00
0?ooV@3ooiT0=oooool00ol0003oooooooooo`1Oooooo`008oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo09Kooooo0oooV@000ooooooo0000ooooo`0hooooo`03o`000?oooooooooo
05oooooo000Sooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0T_ooool3oonI00?o
oooo0_l0000jooooo`03o`000?oooooooooo05kooooo000Rooooo`;o00003Oooool00ol0003ooooo
ooooo`2>ooooo`?ooiT00oooool3o`000003ooooool0003ooooo03[ooooo00?o0000ooooooooool0
GOooool002;ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`2;ooooo`;ooiT00ooo
ool3o`0000Gooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`1Looooo`008_ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo08Oooooo0oooV@02ooooo`?o00002Oooool0
0ol0003oooooooooo`0Eooooo`;oc?l08Oooool00ol0003oooooooooo`1Looooo`008_ooool3o`00
00oooooo00?o0000ooooooooool0Poooool3oonI00;ooooo0ol0000=ooooo`03o`000?oooooooooo
017ooooo0oo<o`0Tooooo`03o`000?oooooooooo05_ooooo000Rooooo`03o`000?oooooooooo013o
oooo00?o0000ooooooooool0Ooooool3oonI00?ooooo0_l0000Aooooo`03o`000?oooooooooo00go
oooo0oo<o`0Xooooo`03o`000?oooooooooo05[ooooo000Rooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool0Noooool3oonI00?ooooo0ol0000Dooooo`03o`000?oooooooooo00Wooooo
0oo<o`0/ooooo`03o`000?oooooooooo05Wooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h0
1Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo01;o
oooo00?o0000ooooooooool0Moooool3oonI00?ooooo0ol0000Gooooo`03o`000?oooooooooo00Ko
oooo0oo<o`0_ooooo`03o`000?oooooooooo05Wooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Cooooo`03
o`000?oooooooooo07Cooooo0_ooV@03ooooo`?o00006oooool00ol0003oooooooooo`02ooooo`?o
c?l0<oooool00ol0003oooooooooo`1Hooooo`001Ol00002ooooo`05oa0@4?ooooooooooooooool@
41004?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool0L?ooool3oonI00;ooooo0ol0000Oooooo`04o`000?ooooooc?l0olco03Oooooo00?o0000oooo
ooooool0Eoooool000Oooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo
00?ooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1/ooooo`?ooiT00_ooool3o`00
027ooooo0_o<o`000ol0003oooooooooo`0gooooo`;o0000F?ooool000Oooooo00Go0000oooooooo
ooooooooo`00000<ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01?ooool00ol0003oooooooooo`0G
ooooo`03o`000?oooooooooo06Wooooo0_ooV@03ooooo`;o00008Oooool3olco00?ooooo00?o0000
ooooooooool0>?ooool00ol0003oooooooooo`1Eooooo`001oooool01Ol@413ooooooooooooooooo
410@00cooooo00?o0000ooooooooool01_ooool2o`0001Wooooo00?o0000ooooooooool0IOooool3
oonI00;ooooo0ol0000Oooooo`Coc?l01oooool00ol0003oooooooooo`0gooooo`03o`000?oooooo
oooo05Gooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0HOooool3oonI00;ooooo0ol0000M
ooooo`Goc?l02oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo05Cooooo0007oooo
o`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000ooooooooool06_ooool0
0ol0003oooooooooo`1Nooooo`;ooiT00_ooool3o`0001gooooo0oo<o`0Aooooo`03o`000?oooooo
oooo03Sooooo00?o0000ooooooooool0Doooool0027ooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`1Jooooo`?ooiT000Coooooo`000?l0003o00007Oooool3olco01Gooooo00?o0000
ooooooooool0>?ooool00ol0003oooooooooo`1Booooo`008?ooool3o`0001gooooo00?o0000oooo
ooooool0E_ooool3oonI00;ooooo0_l0000Mooooo`?oc?l06Oooool00ol0003oooooooooo`0>oooo
o`;o<ol09oooool00ol0003oooooooooo`1Booooo`008Oooool00ol0003oooooooooo`0Mooooo`03
o`000?oooooooooo05?ooooo0_ooV@02ooooo`?o00007Oooool2olco01gooooo00?o0000oooooooo
ool02_ooool3oc?o02[ooooo00?o0000ooooooooool0DOooool0023ooooo00?o0000ooooooooool0
7oooool00ol0003oooooooooo`1?ooooo`?ooiT000Coooooo`000?l0003o00007Oooool3olco023o
oooo00?o0000ooooooooool01_ooool3oc?o02kooooo00?o0000ooooooooool0D?ooool0023ooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`1;ooooo`?ooiT000Coooooo`000?l0003o
00007Oooool3olco02?ooooo00?o0000ooooooooool00_ooool4oc?o03;ooooo00?o0000oooooooo
ool0Coooool0023ooooo0_l0000Rooooo`03o`000?oooooooooo04Sooooo0_ooV@001?oooooo0000
o`000?l0000Nooooo`;oc?l09_ooool00olco`3o0000oc?o0002oc?o03Kooooo00?o0000oooooooo
ool0Coooool0023ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`14ooooo`?ooiT0
00?oooooo`000?l000007_ooool3olco02Gooooo0olco`02ooooo`03o`000?oooooooooo03Oooooo
00?o0000ooooooooool0C_ooool0023ooooo00?o0000ooooooooool08oooool00ol0003ooooooooo
o`10ooooo`?ooiT000Coooooo`000?l0003o00007Oooool3olco02Gooooo0olco`06ooooo`03o`00
0?oooooooooo03Oooooo00?o0000ooooooooool0COooool0023ooooo0ol0000Tooooo`03o`000?oo
oooooooo03cooooo0oooV@001?oooooo0000o`000?l0000Mooooo`?oc?l09Oooool3oc?o00[ooooo
00?o0000ooooooooool0=_ooool2o`0004kooooo000Pooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool0=oooool4oonI0004ooooool0003o0000o`0001cooooo1?o<o`0Tooooo`Co<ol0
3_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo04cooooo000Dooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo03?ooooo
0oooV@02ooooo`?o00007?ooool3olco02Cooooo1?lco`0Booooo`03o`000?oooooooooo03Oooooo
00?o0000ooooooooool0Boooool001Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`03o`00
0?oooooooooo02Sooooo00?o0000ooooooooool0;oooool3oonI00?ooooo0_l0000Looooo`?oc?l0
9?ooool3oc?o01Oooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`1:ooooo`005?oo
ool01Ol@413ooooooooooooooooo410@00Kooooo0_l0000Zooooo`03o`000?oooooooooo02_ooooo
0oooV@03ooooo`?o00006oooool3olco02Cooooo0olco`0Kooooo`03o`000?oooooooooo03Oooooo
00?o0000ooooooooool0BOooool001Cooooo00Go0000ooooooooooooooooo`000006ooooo`03o`00
0?oooooooooo02[ooooo00?o0000ooooooooool0:?ooool2oonI00?ooooo0ol0000Looooo`;oc?l0
9?ooool3oc?o01oooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`19ooooo`005?oo
ool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0:oooool00ol0003ooooo
ooooo`0Tooooo`?ooiT00_ooool3o`0001cooooo0oo<o`0Rooooo`Co<ol08oooool00ol0003ooooo
ooooo`06ooooo`?o0?mV;Oooool00ol0003oooooooooo`18ooooo`005?ooool01Ol@413ooooooooo
oooooooo410@00Kooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Pooooo`?ooiT0
0_ooool3o`0001cooooo0oo<o`0Qooooo`Co<ol0:?ooool00ol0003oooooooooo`05o`3oIS7ooooo
00?o0000ooooooooool0Aoooool001Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`;o0000
;_ooool00ol0003oooooooooo`0Mooooo`;ooiT00_ooool3o`0001gooooo0_o<o`0Qooooo`?o<ol0
:_ooool2o`3oIP03o`000?l0ofKo0?mV03Oooooo00?o0000ooooooooool0A_ooool001Cooooo00Go
k^k^oc8b<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool0
6Oooool3oonI00;ooooo0_l0000Mooooo`?oc?l08?ooool3oc?o02Sooooo1Ol0ofH3ooooo`03o`00
0?oooooooooo03Oooooo00?o0000ooooooooool0AOooool001oooooo00?o0000ooooooooool0;ooo
ool00ol0003oooooooooo`0Fooooo`;ooiT00_ooool3o`0001cooooo0oo<o`0Pooooo`?o<ol09ooo
ool4o`3oIPWooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`15ooooo`007_ooool0
0ol0003oooooooooo`0aooooo`03o`000?oooooooooo01Cooooo00?ooiT0ooooool000000_l0000M
ooooo`;oc?l08?ooool3oc?o02Gooooo1Ol0ofH>ooooo`03o`000?oooooooooo03Kooooo00?o0000
ooooooooool0A?ooool001kooooo0_l0000cooooo`03o`000?oooooooooo01;ooooo0ol0000Moooo
o`?oc?l07_ooool4oc?o02Cooooo1?l0ofHDooooo`03o`000?oooooooooo03Kooooo0_l00014oooo
o`007_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00kooooo0ol0000Mooooo`?o
c?l07_ooool3oc?o02?ooooo1Ol0ofHIooooo`03o`000?oooooooooo03Cooooo00?o0000ooooool0
0000A?ooool001kooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0;ooooo`;o0000
7_ooool2olco01kooooo0olco`0Rooooo`Co0?mV7_ooool00ol0003oooooooooo`0fooooo`03o`00
0?oooooooooo04;ooooo000Nooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool01ooo
ool3o`0001gooooo0oo<o`0Mooooo`?o<ol08?ooool5o`3oIR?ooooo00?o0000ooooooooool0=_oo
ool00ol0003oooooooooo`11ooooo`007_ooool2o`0003Oooooo00?o0000ooooooooool00oooool3
o`0001kooooo0_o<o`0Nooooo`;o<ol08?ooool3o`3oIRWooooo00?o0000ooooooooool0=_ooool0
0ol0003oooooooooo`10ooooo`007_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooo0000
00;o00007oooool2olco01gooooo0olco`0Oooooo`?o0?mV;Oooool00ol0003oooooooooo`0foooo
o`03o`000?oooooooooo03oooooo000Nooooo`03o`000?oooooooooo03Kooooo0ol0000Oooooo`?o
c?l07?ooool3oc?o01oooooo0ol0ofHaooooo`03o`000?oooooo0?oo00;o0?oo<oooool00ol0003o
ooooooooo`0oooooo`007_ooool2o`0003Gooooo0_l00003ooooo`03o`000?oooooooooo01Wooooo
0oo<o`0Mooooo`;o<ol07oooool3o`3oIS7ooooo1?l0ool00ol0003oooooooooo`0eooooo`03o`00
0?oooooooooo00Wooooo0_l000000ol@413oooooooooo`0`ooooo`007Oooool00ol0003ooooooooo
o`0booooo`?o00001_ooool00ol0003oooooooooo`0Fooooo`;oc?l07Oooool3oc?o01gooooo1?l0
ofH_ooooo`Go0?oo1?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Wooooo00?o
0000ooooooooool0<Oooool000;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Ooo
ool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0;oooool3o`0000[ooooo
00?o0000ooooooooool04_ooool3olco01gooooo0_lco`0Mooooo`?o0?mV;_ooool5o`3oo`[ooooo
00?o0000ooooooooool0=_ooool00ol0003oooooooooo`05ooooo`Go0000<_ooool000;ooooo00Go
MgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`00
0?oooooooooo02cooooo0ol0000>ooooo`03o`000?oooooooooo00kooooo0oo<o`0Nooooo`;o<ol0
7?ooool3o`3oIRcooooo1Ol0ool@ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0
1Oooool01?m4A4CogMgMooooool0000cooooo`000_ooool01Ol@413ooooooooooooooooo410@013o
oooo00?o0000ooooooooool00oooool2o`0002[ooooo0ol0000Booooo`03o`000?oooooooooo00co
oooo00?oc?l0ooooooooool07Oooool2oc?o01_ooooo0ol0ofHZooooo`Go0?oo5_ooool00ol0003o
ooooooooo`0eooooo`03o`000?oooooooooo00Cooooo00CogMgMoeEEEOoooooo0000<oooool000;o
oooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000oooo
ooooool09oooool2o`0001Kooooo00?o0000ooooooooool0:Oooool2oc?o01_ooooo0_l0ofHWoooo
o`Ko0?oo7?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00Cooooo00?oMgMgolc<
c?l00000<oooool000;ooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ8B7o0000
oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Tooooo`?o00006Oooool00ol0003oooooooooo`0V
ooooo`;o<ol06_ooool3o`3oIR;ooooo1ol0oolSooooo`03o`000?oooooooooo03Cooooo0_l00005
ooooo`03onk^k_m4A4Co000003?ooooo0002ooooo`05oa0@4?ooooooooooooooool@41003?ooool0
0ol0003oooooooooo`07ooooo`03o`000?oooooooooo027ooooo0ol0000Mooooo`03o`000?oooooo
oooo02?ooooo0_lco`0Jooooo`;o0?mV8?ooool5o`3oob[ooooo00?o0000ooooooooool0<oooool0
1?l0003oooooooooool00005ooooo`03ogMgMol0003ooooo03;ooooo0002ooooo`05ogMgMonHV9So
oooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`;o00007oooool3o`00027ooooo00?o
0000ooooooooool07oooool3oc?o01[ooooo0_l0ofHNooooo`Co0?oo<?ooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo03Sooooo0002ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?oo
ool4o`0000Gooooo00?o0000ooooooooool07?ooool3o`0002Gooooo00?o0000ooooooooool07?oo
ool2oc?o01[ooooo0ol0ofHLooooo`Co0?oo=Oooool00ol0003oooooooooo`0eooooo`03o`000?oo
oooooooo03Oooooo000Looooo`03o`000?oooooooooo01Wooooo0ol0000Yooooo`03o`000?oooooo
oooo01Wooooo0_lco`0Jooooo`;o0?mV6oooool4o`3ooc[ooooo00?o0000ooooooooool0=Oooool0
0ol0003oooooooooo`0fooooo`007?ooool00ol0003oooooooooo`0Gooooo`;o0000;Oooool00ol0
003oooooooooo`0Eooooo`?o<ol06_ooool2o`3oIQWooooo1?l0ooloooooo`03o`000?oooooooooo
03Gooooo00?o0000ooooooooool0=Oooool001cooooo0_l0000Eooooo`?o0000<?ooool00ol0003o
ooooooooo`0Aooooo`?o<ol06_ooool3o`3oIQSooooo0ol0oolnooooo`?o06Ko0oooool00ol0003o
ooooooooo`0dooooo`03o`000?oooooooooo03Gooooo000Looooo`03o`000?oooooooooo017ooooo
0ol0000dooooo`03o`000?oooooooooo00kooooo0_lco`0Kooooo`;o0?mV6?ooool3o`3ooccooooo
1Ol0I_l6ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0=?ooool001cooooo00?o
0000ooooooooool03_ooool3o`0003Sooooo00?o0000ooooooooool02_ooool3oc?o01_ooooo0_l0
ofHHooooo`;o0?oo=oooool8o`1Vo`cooooo00?o0000ooooooooool0=Oooool00ol0003ooooooooo
o`0cooooo`007?ooool00ol0003oooooooooo`0;ooooo`?o0000??ooool00ol0003oooooooooo`07
ooooo`;o<ol06oooool3o`3oIQSooooo0_l0ool^ooooo`_o06Ko5Oooool00ol0003oooooooooo`0e
ooooo`03o`000?oooooooooo03;ooooo000Looooo`;o00002_ooool2o`00043ooooo00?o0000oooo
ooooool01Oooool00olco`3oooooooooo`0Hooooo`?o0?mV6?ooool3o`3oobOooooo2Ol0I_lQoooo
o`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0<_ooool001_ooooo0_l00008ooooo`?o
0000@oooool00ol0003oooooooooo`0Mooooo`;o0?mV6Oooool2o`3oob?ooooo1ol0I_l[ooooo`03
o`000?oooooooooo03Cooooo00?o0000ooooooooool0<Oooool001_ooooo00?o0000ooooooooool0
1?ooool3o`0004Oooooo00?o0000ooooooooool06_ooool2o`3oIQWooooo0_l0oolQooooo`Co06Ko
<oooool00ol0003oooooooooo`0cooooo`;o0000<_ooool001_ooooo00Co0000oooooooooooooooo
0ol0001;ooooo`03o`000?oooooooooo01Sooooo00?o0?mVooooooooool05_ooool3o`3ooagooooo
1_l0I_lgooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0;oooool001_ooooo1?l0
001?ooooo`03o`000?oooooooooo01Gooooo0_l0ofHGooooo`;o0?oo6_ooool6o`1Vockooooo00?o
0000ooooooooool0=?ooool00ol0003oooooooooo`0_ooooo`006oooool2o`0005;ooooo00?o0000
ooooooooool04_ooool2o`3oIQOooooo0_l0oolHooooo`Co06KoAOooool00ol0003oooooooooo`0d
ooooo`03o`000?oooooooooo02kooooo000Aooooo`Co000000?o410@ooooooooool01Oooool00ol0
003oooooooooo`1@ooooo`03o`000?oooooooooo00kooooo0ol0ofHFooooo`?o0?oo5oooool3o`1V
od[ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0]ooooo`004oooool00ol0003o
ooooooooo`08ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool02oooool2o`3oIQOo
oooo0_l0oolGooooo`?o06KoC_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02co
oooo000Cooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0D?ooool00ol0003ooooo
ooooo`08ooooo`;o0?mV5oooool2o`3ooaOooooo0_l0I_mBooooo`03o`000?oooooooooo03?ooooo
00?o0000ooooooooool0;?ooool001?ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`1@ooooo`03o`000?oooooooooo00Gooooo0_l0ofHHooooo`03o`3ooooooooooooo01Cooooo0ol0
I_m6ooooo`Co<`3o2_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02_ooooo000C
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`02
ooooo`;o0?mV6?ooool2o`3ooaCooooo0ol0I_m3ooooo`Ko<`3o3oooool00ol0003oooooooooo`0d
ooooo`03o`000?oooooooooo02[ooooo000Cooooo`03o`000?oooooooooo00cooooo00?o0000oooo
ooooool0D?ooool01?l0003oooooo`3oI_l0ofHIooooo`03o`3ooooooooooooo017ooooo0ol0I_ln
ooooo`So<`3o5_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02Wooooo000Coooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool0D?ooool00ol0ofKoooooooooo`0Goooo
o`;o0?oo4oooool00ol0I_ooooooooooo`0[oooooaCo<`3o7oooool00ol0003oooooooooo`0doooo
o`03o`000?oooooooooo02Sooooo000Aooooo`03oeEEEOmVIVKo0000013ooooo00?o0000oooooooo
ool0D?ooool00ol0003oooooooooo`0Dooooo`;o0?oo4oooool2o`1Voaoooooo3olc0?ldooooo`03
o`000?oooooooooo03?ooooo00?o0000ooooooooool0:?ooool002Gooooo00?o0000ooooooooool0
D?ooool00ol0003oooooooooo`0Booooo`03o`3ooooooooooooo01;ooooo00?o06Koooooooooool0
7?ooool3oc<0odCooooo00?o0000ooooooooool0<_ooool2o`0002Wooooo000Vooooo`;o0000DOoo
ool00ol0003oooooooooo`0?ooooo`;o0?oo4oooool2o`1VoaWooooo1_lc0?m7ooooo`03o`000?oo
oooooooo03Cooooo00?o0000ooooooooool09_ooool002Sooooo00?o0000ooooooooool0C_ooool0
0ol0003oooooooooo`0=ooooo`;o0?oo4oooool2o`1VoaKooooo1Olc0?m>ooooo`03o`000?oooooo
oooo03Cooooo00?o0000ooooooooool09Oooool002Wooooo00?o0000ooooooooool0C_ooool00ol0
003oooooooooo`09ooooo`?o0?oo4oooool2o`1VoaKooooo0_lc0?mDooooo`03o`000?oooooooooo
03?ooooo00?o0000ooooooooool09Oooool002[ooooo00?o0000ooooooooool0C_ooool00ol0003o
ooooooooo`06ooooo`;o0?oo5?ooool2o`1VoaKooooo0_lc0?mGooooo`03o`000?oooooooooo03?o
oooo00?o0000ooooooooool09?ooool002_ooooo00?o0000ooooooooool0C_ooool00ol0003ooooo
ooooo`03ooooo`;o0?oo5Oooool00ol0I_ooooooooooo`0Cooooo`?o<`3oF_ooool00ol0003ooooo
ooooo`0cooooo`03o`000?oooooooooo02?ooooo000/ooooo`03o`000?oooooooooo04kooooo00?o
0000ooooooooool00_l0oolEooooo`;o06Ko4oooool3oc<0oekooooo00?o0000ooooooooool0<ooo
ool00ol0003oooooooooo`0Rooooo`00;Oooool00ol0003oooooooooo`1>ooooo`;o0?oo5_ooool0
0ol0I_ooooooooooo`0@ooooo`?o<`3oHOooool00ol0003oooooooooo`0cooooo`03o`000?oooooo
oooo02;ooooo000^ooooo`03o`000?oooooooooo04_ooooo0_l0ool00ooooooo0000ooooo`0Coooo
o`;o06Ko4Oooool2oc<0odoooooo1?o<0?lBooooo`03o`000?oooooooooo03?ooooo00?o0000oooo
ooooool08Oooool002oooooo00?o0000ooooooooool0BOooool00ol0ooooooooooooo`02ooooo`03
o`000?oooooooooo013ooooo00?o06Koooooooooool04?ooool00olc0?ooooooooooo`18ooooo`Oo
c03o5oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo023ooooo000`ooooo`03o`00
0?oooooooooo04kooooo00?o0000ooooooooool03Oooool2o`1Voa7ooooo0_lc0?lNooooobgoc03o
7oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo01oooooo000aooooo`;o0000Cooo
ool00ol0003oooooooooo`0;ooooo`03o`1Voooooooooooo013ooooo00?o<`3oooooooooool06Ooo
ool5ol`0odgooooo00?o0000ooooooooool0<_ooool2o`00023ooooo000cooooo`03o`000?oooooo
oooo04gooooo00?o0000ooooooooool02?ooool2o`1Voa7ooooo0_lc0?lIooooo`?oc03oDoooool0
0ol0003oooooooooo`0aooooo`;o00008?ooool003Cooooo00?o0000ooooooooool0COooool00ol0
003oooooooooo`05ooooo`;o06Ko4_ooool00olc0?ooooooooooo`0Eooooo`Coc03oE_ooool00ol0
003oooooooooo`0cooooo`03o`000?oooooooooo01gooooo000eooooo`03o`000?oooooooooo04go
oooo00?o0000ooooooooool00oooool00ol0I_ooooooooooo`0@ooooo`;o<`3o5Oooool3ol`0oe_o
oooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Looooo`00=_ooool00ol0003ooooo
ooooo`1=ooooo`03o`000?oooooooooo00;o06Ko4_ooool00olc0?ooooooooooo`0Booooo`?oc03o
Goooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01cooooo000gooooo`03o`000?oo
oooooooo04gooooo0_l0I_lCooooo`03oc<0oooooooooooo013ooooo0oo<0?mSooooo`03o`000?oo
oooooooo03;ooooo00?o0000ooooooooool06oooool003Sooooo00?o0000ooooooooool0Boooool0
0ol0I_ooooooo`00000Booooo`03oc<0oooooooooooo00oooooo0_o<0?mWooooo`03o`000?oooooo
oooo03;ooooo00?o0000ooooooooool01oooool01Oo^k^ko<S8bo`000?l@413oc<c<00kooooo000i
ooooo`03o`000?oooooooooo04Sooooo0_l0I_l3ooooo`03o`000?oooooooooo00kooooo00?o<`3o
ooooooooool03_ooool2ol`0of[ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`06
ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B403_ooool003[ooooo00?o0000ooooooooool0AOooool2
o`1Vo`Kooooo00?o0000ooooooooool03?ooool00olc0?ooooooooooo`0>ooooo`03ol`0oooooooo
oooo06[ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`05ooooo`05o`000?oooooo
ooooooooool000003_ooool003_ooooo00?o0000ooooooooool0@oooool00ol0I_ooooooooooo`07
ooooo`03o`000?oooooooooo00[ooooo00?o<`3oooooooooool03_ooool00oo<0?ooooooooooo`1/
ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool01Oooool01Ol0003oV9RHoooooonH
V9So8B4Q00kooooo000looooo`03o`000?oooooooooo047ooooo00?o06Koooooooooool02Oooool0
0ol0003oooooooooo`08ooooo`03oc<0oooooooooooo00kooooo00?oc03oooooooooool0Coooool5
ool0VA[ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`04ooooo`05o`000?mEEEGo
0000oa0@4?o<c<`03_ooool003gooooo0_l0001>ooooo`03o`000?oooooooooo00Kooooo00?o<`3o
ooooooooool03_ooool00oo<0?ooooooooooo`0Kooooo`koo`2I8?ooool7ool0VB3ooooo00?o0000
ooooooooool0<_ooool2o`0000Cooooo00?oEEEEohN7Qoooool04?ooool003oooooo00?o0000oooo
ooooool0C?ooool00ol0003oooooooooo`03ooooo`;o<`3o4?ooool00oo<0?ooooooooooo`0Foooo
o`Koo`2I3_ooool:ool0V@_ooooo2ooo09TXooooo`03o`000?oooooooooo02oooooo0_l000000ooo
oooo0000ooooo`03ooooo`03omgMgOl@413oV9RH013ooooo0010ooooo`03o`000?oooooooooo04co
oooo00?o0000ooooooooool00_lc0?l@ooooo`;oc03o5?ooool5ool0VAkooooo2ooo09Tdooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool00oooool01?o<c<coA4A4o`000?l@410>oooo
o`00@Oooool00ol0003oooooooooo`1<ooooo`03o`000?lc0?oooooo013ooooo00?oc03ooooooooo
ool04?ooool4ool0VF;ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Dooooo`00
@_ooool00ol0003oooooooooo`1:ooooo`;o<`3o00?o0000ooooooooool03_ooool00oo<0?oooooo
ooooo`0?ooooo`;oo`2IIoooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01?ooooo
0013ooooo`03o`000?oooooooooo04Oooooo0_lc0?l3ooooo`03o`000?oooooooooo00cooooo00?o
c03oooooooooool03oooool00ooo09Woooooooooo`1Xooooo`03o`000?oooooooooo03;ooooo00?o
0000ooooooooool04_ooool004Cooooo00?o0000ooooooooool0AOooool00olc0?ooooooooooo`04
ooooo`03o`000?oooooooooo00[ooooo00?oc03oooooooooool03_ooool2ool0VFcooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`0Booooo`00AOooool00ol0003oooooooooo`12oooo
o`;o<`3o2?ooool00ol0003oooooooooo`09ooooo`03ol`0oooooooooooo00cooooo0_oo09U_oooo
o`03o`000?oooooooooo037ooooo00?o0000ooooooooool04Oooool004Kooooo00?o0000oooooooo
ool0?oooool2oc<0o`_ooooo00?o0000ooooooooool01oooool00oo<0?ooooooooooo`0<ooooo`03
ool0VOoooooooooo073ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0@ooooo`00
Aoooool00ol0003oooooooooo`0mooooo`03oc<0oooooooooooo00cooooo00?o0000ooooooooool0
1Oooool00oo<0?ooooooooooo`0=ooooo`03ool0VOoooooooooo073ooooo00?o0000ooooooooool0
<_ooool00ol0003oooooooooo`0?ooooo`00B?ooool2o`0003cooooo00?o<`3oooooooooool03_oo
ool00ol0003oooooooooo`03ooooo`03ol`0oooooooooooo00gooooo00?oo`2Iooooooooool0L_oo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00oooooo001:ooooo`03o`000?oooooo
oooo04_ooooo00?o0000ooooooooool00_o<0?l?ooooo`03ool0VOoooooooooo07Cooooo00?o0000
ooooooooool0<Oooool2o`0000oooooo001;ooooo`03o`000?oooooooooo04_ooooo00?o0000ol`0
ooooool03oooool00ooo09Woooooooooo`0Hooooo`Koo`00<Oooool5ool002;ooooo00?o0000oooo
ooooool0<?ooool2o`0000oooooo001<ooooo`03o`000?oooooooooo04[ooooo00?oc03oo`000?oo
ool03oooool00ooo09Woooooooooo`0@ooooo`Soo`001_ooool6ool002?ooooo2?oo000Xooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool03?ooool004gooooo00?o0000ooooooooool0
Aoooool2ol`0o`;ooooo00?o0000ooooooooool03?ooool00ooo09Woooooooooo`0?ooooo`;oo`00
5?ooool:ool000gooooo3?oo000aooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
2oooool004kooooo00?o0000ooooooooool0AOooool00oo<0?ooooooooooo`03ooooo`03o`000?oo
oooooooo00[ooooo00?oo`2Iooooooooool03Oooool3ool0023ooooo3Ooo000mooooo`03o`000?oo
oooooooo037ooooo00?o0000ooooooooool02oooool004oooooo00?o0000ooooooooool0@oooool0
0oo<0?ooooooooooo`05ooooo`03o`000?oooooooooo00Sooooo00?oo`2Iooooooooool03?ooool2
ool006kooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0:ooooo`00D?ooool00ol0
003oooooooooo`10ooooo`;oc03o2Oooool00ol0003oooooooooo`06ooooo`03ool0VOoooooooooo
00gooooo00?oo`00ooooooooool0K_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo
00Wooooo001Aooooo`03o`000?oooooooooo03gooooo0_o<0?l<ooooo`03o`000?oooooooooo00Co
oooo00?oo`2Iooooooooool03Oooool00ooo003oooooooooo`1`ooooo`03o`000?oooooooooo037o
oooo00?o0000ooooooooool02?ooool005;ooooo00?o0000ooooooooool0>_ooool2ol`0o`oooooo
00?o0000ooooooooool00_ooool00ooo09Woooooooooo`0<ooooo`;oo`00M?ooool00ol0003ooooo
ooooo`0`ooooo`03o`000?oooooooooo00Sooooo001Cooooo`;o0000>Oooool00oo<0?oooooooooo
o`0@ooooo`04o`000?ooooooooooool0V@kooooo00?oo`00ooooooooool0MOooool00ol0003ooooo
ooooo`0`ooooo`03o`000?oooooooooo00Oooooo001Eooooo`03o`000?oooooooooo03Cooooo0_o<
0?lDooooo`;oo`2I3_ooool00ooo003oooooooooo`1fooooo`03o`000?oooooooooo037ooooo00?o
0000ooooooooool01_ooool005Kooooo00?o0000ooooooooool0<_ooool00oo<0?ooooooooooo`0C
ooooo`03ool0VOoooooo000000kooooo00?oo`00ooooooooool0Moooool00ol0003oooooooooo`0_
ooooo`?o00001oooool005Oooooo00?o0000ooooooooool0A_ooool01Ooo09Wooooooooooooooooo
000000cooooo00?oo`00ooooooooool0NOooool00ol0003oooooooooo`0[ooooo`?o00000_ooool0
0ol0003oooooooooo`05ooooo`00F?ooool00ol0003oooooooooo`14ooooo`03ool0VOoooooooooo
00?ooooo00?o0000ooooooooool02Oooool00ooo003oooooooooo`1jooooo`03o`000?oooooooooo
02Oooooo0ol00005ooooo`03o`000?oooooooooo00Gooooo001Iooooo`03o`000?oooooooooo04;o
oooo00?oo`2Iooooooooool01Oooool00ol0003oooooooooo`07ooooo`03ool00?oooooooooo07co
oooo00?o0000ooooooooool08_ooool4o`0000Sooooo00?o0000ooooooooool01Oooool005[ooooo
00?o0000ooooooooool0@?ooool00ooo09Woooooooooo`07ooooo`03o`000?oooooooooo00Kooooo
00?oo`00ooooooooool0OOooool00ol0003oooooooooo`0Nooooo`?o00003?ooool00ol0003ooooo
ooooo`05ooooo`00Foooool00ol0003oooooooooo`0nooooo`03ool0VOoooooooooo00Wooooo00?o
0000ooooooooool01?ooool00ooo003oooooooooo`1nooooo`03o`000?oooooooooo01[ooooo1?l0
000?ooooo`03o`000?oooooooooo00Gooooo001Looooo`03o`000?oooooooooo03_ooooo0_oo09T=
ooooo`03o`000?oooooooooo00;ooooo00?oo`00ooooooooool0P?ooool00ol0003oooooooooo`0F
ooooo`?o00005?ooool00ol0003oooooooooo`04ooooo`00GOooool00ol0003oooooooooo`0hoooo
o`;oo`2I4?ooool01?l0003ooooooooooooo0024ooooo`03o`000?oooooooooo01;ooooo0ol0000G
ooooo`03o`000?oooooooooo00Cooooo001Nooooo`;o0000=_ooool2ool0VA?ooooo00?o0000oooo
oooo0000QOooool00ol0003oooooooooo`0=ooooo`Co00006_ooool00ol0003oooooooooo`04oooo
o`00H?ooool00ol0003oooooooooo`0aooooo`;oo`2I5_ooool00ooo003oooooooooo`25ooooo`03
o`000?oooooooooo00Wooooo0ol0000Nooooo`03o`000?oooooooooo00Cooooo001Qooooo`03o`00
0?oooooooooo02kooooo0_oo09TFooooo`;oo`0000?oooooo`000?ooool0Q_ooool00ol0003ooooo
ooooo`04ooooo`Co00008Oooool00ol0003oooooooooo`04ooooo`00H_ooool00ol0003ooooooooo
o`0/ooooo`03ool0VOoooooooooo01Gooooo00?oo`00ooooooooool00_ooool00ol0003ooooooooo
o`24ooooo`04o`000?ooooooooooooooo`?o00009Oooool00ol0003oooooooooo`04ooooo`00Hooo
ool00ol0003oooooooooo`12ooooo`03ool00?oooooooooo00Cooooo00?o0000ooooooooool0Q?oo
ool3o`0002Sooooo00?o0000ooooooooool01?ooool006Cooooo00?o0000ooooooooool0?oooool2
ool000Sooooo00?o0000ooooooooool0Ooooool4o`000003ooooool0003ooooo02Sooooo00?o0000
ooooooooool01?ooool006Gooooo00?o0000ooooooooool0?Oooool00ooo003oooooooooo`09oooo
o`03o`000?oooooooooo07_ooooo0ol00006ooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool01?ooool006Kooooo00?o0000ooooooooool0>oooool00ooo003oooooooooo`0;ooooo`03
o`000?oooooooooo07Kooooo1?l0000:ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool01?ooool006Oooooo00?o0000ooooooooool0>Oooool00ooo003oooooooooo`0=ooooo`03o`00
0?oooooooooo07;ooooo0ol0000?ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
0oooool006Sooooo00?o0000ooooooooool0=_ooool2ool0017ooooo00?o0000ooooooooool0K_oo
ool3o`0001;ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`03ooooo`00JOooool0
0ol0003oooooooooo`0cooooo`;oo`005?ooool00ol0003oooooooooo`1Yooooo`Co00005_ooool0
0ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00?ooooo001Zooooo`;o0000<Oooool2ool0
01Oooooo00?o0000ooooooooool0IOooool3o`0001_ooooo00?o0000ooooooooool08oooool00ol0
003oooooooooo`03ooooo`00K?ooool00ol0003oooooooooo`0]ooooo`03ool00?oooooooooo01So
oooo00?o0000ooooooooool0H?ooool4o`0001oooooo00?o0000ooooooooool08_ooool00ol0003o
ooooooooo`03ooooo`00KOooool00ol0003oooooooooo`0Zooooo`;oo`007?ooool00ol0003ooooo
ooooo`1Looooo`?o00009?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00?ooooo
001^ooooo`03o`000?oooooooooo02Oooooo0_oo000Oooooo`03o`000?oooooooooo05Sooooo0ol0
000Xooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool00oooool006oooooo00?o0000
ooooooooool09Oooool00ooo003oooooooooo`0Pooooo`03o`000?oooooooooo05?ooooo1?l0000[
ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool00oooool0073ooooo00?o0000oooo
ooooool0B?ooool00ol0003oooooooooo`1?ooooo`?o0000<?ooool00ol0003oooooooooo`0Ooooo
o`03o`000?oooooooooo00?ooooo001aooooo`03o`000?oooooooooo04Sooooo00?o0000oooooooo
ool0B_ooool4o`0003Cooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`03ooooo`00
L_ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo04Kooooo0ol0000iooooo`03o`00
0?oooooooooo01kooooo00?o0000ooooooooool00_ooool007?ooooo00?o0000ooooooooool0B?oo
ool00ol0003oooooooooo`12ooooo`?o0000?Oooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo00;ooooo001dooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0?Oooool4
o`00047ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`02ooooo`00MOooool2o`00
04Wooooo00?o0000ooooooooool0>Oooool3o`0004Gooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`02ooooo`00Moooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo03Co
oooo1?l00019ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool00_ooool007Sooooo
00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0`ooooo`?o0000C_ooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo00;ooooo001iooooo`03o`000?oooooooooo04Oooooo00?o
0000ooooooooool0;?ooool3o`0005;ooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`02ooooo`00N_ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo02Oooooo1?l0001F
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool00_ooool007_ooooo00?o0000oooo
ooooool0Aoooool00ol0003oooooooooo`0Sooooo`?o0000Foooool00ol0003oooooooooo`0Goooo
o`03o`000?oooooooooo00;ooooo001looooo`03o`000?oooooooooo04Oooooo00?o0000oooooooo
ool07_ooool4o`0005kooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`02ooooo`00
OOooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo01[ooooo0ol0001Sooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool00Oooool007kooooo00?o0000ooooooooool0Aooo
ool00ol0003oooooooooo`0Fooooo`?o0000Ioooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo007ooooo001oooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool04Oooool4
o`0006_ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`01ooooo`00P?ooool2o`00
04Sooooo00?o0000ooooooooool03Oooool3o`00073ooooo00?o0000ooooooooool05?ooool00ol0
003oooooooooo`01ooooo`00P_ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo00So
oooo1?l0001dooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00Oooool008?ooooo
00?o0000ooooooooool0A_ooool00ol0003oooooooooo`04ooooo`?o0000N?ooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo007ooooo0024ooooo`03o`000?oooooooooo04Kooooo00?o
0000ooooooooool00ol0001looooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00Ooo
ool008Gooooo00?o0000ooooooooool0A_ooool2o`00083ooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`01ooooo`00Q_ooool00ol0003oooooooooo`15ooooo`03o`000?oooooooooo
083ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`01ooooo`00Qoooool00ol0003o
ooooooooo`14ooooo`03o`000?oooooooooo087ooooo00?o0000ooooooooool03oooool00ol0003o
ooooooooo`01ooooo`00R?ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo08;ooooo
00?o0000ooooooooool03oooool1o`00007ooooo0Oooool008Wooooo00?o0000ooooooooool0@_oo
ool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo00oooooo0Ol00001ooooo`7ooooo002:
ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0Poooool00ol0003oooooooooo`0>
ooooo`7o00000Oooool1ooooo`00Roooool2o`00047ooooo00?o0000ooooooooool0Q?ooool00ol0
003oooooooooo`0=ooooo`7o00000Oooool1ooooo`00SOooool00ol0003oooooooooo`0nooooo`03
o`000?oooooooooo08Gooooo00?o0000ooooooooool03?ooool1o`00007ooooo0Oooool008kooooo
00?o0000ooooooooool0?Oooool00ol0003oooooooooo`26ooooo`03o`000?oooooooooo00_ooooo
0Ol00001ooooo`7ooooo002?ooooo`03o`000?oooooooooo03cooooo00?o0000ooooooooool0Qooo
ool00ol0003oooooooooo`0:ooooo`7o00000Oooool1ooooo`00T?ooool00ol0003oooooooooo`0k
ooooo`03o`000?oooooooooo08Oooooo00?o0000ooooooooool02_ooool1o`00007ooooo0Oooool0
097ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`28ooooo`03o`000?oooooooooo
00Wooooo0Ol00001ooooo`7ooooo002Booooo`03o`000?oooooooooo03Wooooo00?o0000oooooooo
ool0ROooool00ol0003oooooooooo`08ooooo`7o00000Oooool1ooooo`00Toooool00ol0003ooooo
ooooo`0hooooo`03o`000?oooooooooo08[ooooo00?o0000ooooooooool02?ooool1o`00007ooooo
002Dooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0Roooool00ol0003ooooooooo
o`07ooooo`7o00000Oooool009Gooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`2<
ooooo`03o`000?oooooooooo00Kooooo0Ol00001ooooo`00U_ooool00ol0003oooooooooo`0eoooo
o`03o`000?oooooooooo08cooooo00?o0000ooooooooool01_ooool1o`00007ooooo002Gooooo`;o
0000=Oooool00ol0003oooooooooo`2=ooooo`03o`000?oooooooooo00Gooooo0Ol00001ooooo`00
VOooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo08kooooo00?o0000ooooooooool0
1?ooool1o`00007ooooo002Jooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0Sooo
ool00ol0003oooooooooo`03ooooo`7o00000Oooool009_ooooo00?o0000ooooooooool0<?ooool0
0ol0003oooooooooo`2@ooooo`03o`000?oooooooooo00;ooooo0Ol00001ooooo`00W?ooool00ol0
003oooooooooo`0_ooooo`03o`000?oooooooooo097ooooo00Go0000ooooooooooooooooo`000001
ooooo`00WOooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo097ooooo00Go0000oooo
ooooooooooooo`000001ooooo`00W_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo
09;ooooo00Co0000oooooooooooooooo0Ol0000009oooooo00?o0000ooooooooool0;?ooool00ol0
003oooooooooo`2Cooooo`03o`000?oooooooooo007o0000002Pooooo`03o`000?oooooooooo02_o
oooo00?o0000ooooooooool0U?ooool1o`00007ooooo0Ol000000:7ooooo00?o0000ooooooooool0
:_ooool00ol0003oooooooooo`2Eooooo`;o0000002Rooooo`;o0000:_ooool00ol0003ooooooooo
o`2Dooooo`?o0000002Tooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0T?ooool4
o`0000?ooooo002Uooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0SOooool3o`00
00Oooooo002Vooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0ROooool4o`0000[o
oooo002Wooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0QOooool4o`0000kooooo
002Xooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0P_ooool3o`0001;ooooo002Y
ooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0O_ooool4o`0001Gooooo002Zoooo
o`03o`000?oooooooooo027ooooo00?o0000ooooooooool0N_ooool4o`0001Wooooo002[ooooo`03
o`000?oooooooooo027ooooo00?o0000ooooooooool0MOooool4o`0001gooooo002/ooooo`03o`00
0?oooooooooo023ooooo00?o0000ooooooooool0L_ooool3o`00027ooooo002]ooooo`;o00008?oo
ool00ol0003oooooooooo`1^ooooo`Co00009?ooool00:oooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`1Zooooo`Co0000:?ooool00;3ooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`1Wooooo`?o0000;?ooool00;7ooooo00?o0000ooooooooool06oooool00ol0003o
ooooooooo`1Sooooo`Co0000;oooool00;;ooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`1Oooooo`Co0000<oooool00;?ooooo00?o0000ooooooooool06Oooool00ol0003ooooooooo
o`1Looooo`?o0000=oooool00;Cooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`1H
ooooo`Co0000>_ooool00;Gooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1Doooo
o`Co0000?_ooool00;Kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1@ooooo`Co
0000@_ooool00;Oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1=ooooo`?o0000
A_ooool00;Sooooo0_l0000Eooooo`03o`000?oooooooooo04Wooooo1?l00019ooooo`00^_ooool0
0ol0003oooooooooo`0Booooo`03o`000?oooooooooo04Gooooo1?l0001=ooooo`00^oooool00ol0
003oooooooooo`0Aooooo`03o`000?oooooooooo04;ooooo0ol0001Aooooo`00_?ooool00ol0003o
ooooooooo`0@ooooo`03o`000?oooooooooo03kooooo1?l0001Dooooo`00_Oooool00ol0003ooooo
ooooo`0?ooooo`03o`000?oooooooooo03[ooooo1?l0001Hooooo`00__ooool00ol0003ooooooooo
o`0>ooooo`03o`000?oooooooooo03Kooooo1?l0001Looooo`00_oooool00ol0003oooooooooo`0=
ooooo`03o`000?oooooooooo03?ooooo0ol0001Pooooo`00`?ooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo02oooooo1?l0001Sooooo`00`Oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo02_ooooo1?l0001Wooooo`00`_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo02Sooooo0ol0001[ooooo`00`oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo02Cooooo1?l0001^ooooo`00a?ooool2o`0000Wooooo00?o0000ooooooooool08?ooool4
o`0007;ooooo0036ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool07Oooool3o`00
07Kooooo0037ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06Oooool4o`0007Wo
oooo0038ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05Oooool4o`0007gooooo
0039ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04Oooool4o`00087ooooo003:
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03_ooool3o`0008Gooooo003;oooo
o`05o`000?ooooooooooooooool000003?ooool4o`0008Sooooo003<ooooo`04o`000?oooooooooo
o`0000Sooooo1?l0002<ooooo`00cOooool00ol0003oooooo`000005ooooo`?o0000T?ooool00<ko
oooo0_l000000ooooooo0000o`000002o`0009?ooooo003?ooooo`;o0000Uoooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {330.375, 0}} -> {-0.0771432, -0.0315529, \
0.00350368, 0.00350368}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .92059 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-16 1.0763 -0.0263982 1.0763 [
[.01694 .18568 -11.9631 -9 ]
[.01694 .18568 .03693 0 ]
[.13793 .13897 -11.619 -9 ]
[.13793 .13897 .38095 0 ]
[.26292 .09073 -5.63752 -9 ]
[.26292 .09073 .36248 0 ]
[.39212 .04087 -5.46552 -9 ]
[.39212 .04087 .53448 0 ]
[.52574 -0.01069 -5.29351 -9 ]
[.52574 -0.01069 .70649 0 ]
[.58272 .04263 0 -6.19654 ]
[.58272 .04263 6 2.80346 ]
[.71715 .21863 0 -6.07114 ]
[.71715 .21863 6 2.92886 ]
[.83675 .37523 0 -5.963 ]
[.83675 .37523 6 3.037 ]
[.94385 .51546 0 -5.8688 ]
[.94385 .51546 6 3.1312 ]
[.01386 .20006 -12 -2.76892 ]
[.01386 .20006 0 6.23108 ]
[.00748 .25499 -24 -2.80073 ]
[.00748 .25499 0 6.19927 ]
[.00093 .31131 -6 -2.83339 ]
[.00093 .31131 0 6.16661 ]
[-0.00579 .36907 -18 -2.86695 ]
[-0.00579 .36907 0 6.13305 ]
[-0.01268 .42831 -6 -2.90143 ]
[-0.01268 .42831 0 6.09857 ]
[ 0 0 0 0 ]
[ 1 .92059 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02642 .19522 m
.53391 0 L
s
.02642 .19522 m
.03116 .2 L
s
[(-2)] .01694 .18568 .99384 1 Mshowa
.14712 .14879 m
.15172 .1537 L
s
[(-1)] .13793 .13897 .93651 1 Mshowa
.2718 .10083 m
.27624 .10588 L
s
[(0)] .26292 .09073 .87917 1 Mshowa
.40066 .05126 m
.40493 .05646 L
s
[(1)] .39212 .04087 .82184 1 Mshowa
.53391 0 m
.538 .00534 L
s
[(2)] .52574 -0.01069 .7645 1 Mshowa
.125 Mabswid
.05025 .18606 m
.05308 .18894 L
s
.07424 .17683 m
.07705 .17973 L
s
.09837 .16755 m
.10117 .17046 L
s
.12267 .1582 m
.12545 .16113 L
s
.17173 .13933 m
.17447 .14229 L
s
.19651 .1298 m
.19923 .13278 L
s
.22144 .1202 m
.22414 .1232 L
s
.24654 .11055 m
.24922 .11356 L
s
.29723 .09105 m
.29988 .0941 L
s
.32283 .0812 m
.32546 .08427 L
s
.3486 .07129 m
.35121 .07437 L
s
.37455 .06131 m
.37713 .06441 L
s
.42695 .04115 m
.4295 .04428 L
s
.45342 .03096 m
.45594 .03412 L
s
.48007 .02071 m
.48257 .02388 L
s
.5069 .01039 m
.50938 .01358 L
s
.25 Mabswid
.53391 0 m
.9804 .58403 L
s
.57014 .04738 m
.56384 .04975 L
s
[(0)] .58272 .04263 -1 .37701 Mshowa
.70445 .22307 m
.6981 .22529 L
s
[(2)] .71715 .21863 -1 .34914 Mshowa
.82396 .37939 m
.81756 .38147 L
s
[(4)] .83675 .37523 -1 .32511 Mshowa
.93098 .51938 m
.92454 .52134 L
s
[(6)] .94385 .51546 -1 .30418 Mshowa
.125 Mabswid
.60525 .09331 m
.60147 .09471 L
s
.63931 .13786 m
.63552 .13924 L
s
.67236 .1811 m
.66856 .18245 L
s
.73562 .26383 m
.7318 .26514 L
s
.7659 .30345 m
.76207 .30473 L
s
.79534 .34195 m
.7915 .34322 L
s
.85181 .41581 m
.84796 .41704 L
s
.87891 .45126 m
.87506 .45247 L
s
.90529 .48577 m
.90143 .48696 L
s
.95601 .55212 m
.95214 .55328 L
s
.25 Mabswid
.02642 .19522 m
0 .42381 L
s
.02642 .19522 m
.0327 .19281 L
s
[(-1)] .01386 .20006 1 -0.38468 Mshowa
.02006 .25024 m
.02635 .24786 L
s
[(-0.5)] .00748 .25499 1 -0.37762 Mshowa
.01354 .30664 m
.01985 .3043 L
s
[(0)] .00093 .31131 1 -0.37036 Mshowa
.00686 .36448 m
.01318 .36218 L
s
[(0.5)] -0.00579 .36907 1 -0.3629 Mshowa
0 .42381 m
.00634 .42156 L
s
[(1)] -0.01268 .42831 1 -0.35524 Mshowa
.125 Mabswid
.02516 .20612 m
.02893 .20468 L
s
.0239 .21707 m
.02767 .21563 L
s
.02262 .22807 m
.0264 .22664 L
s
.02135 .23913 m
.02512 .2377 L
s
.01877 .26141 m
.02255 .25999 L
s
.01747 .27263 m
.02125 .27122 L
s
.01617 .28391 m
.01995 .2825 L
s
.01486 .29525 m
.01864 .29384 L
s
.01222 .31809 m
.01601 .3167 L
s
.01089 .3296 m
.01468 .32821 L
s
.00955 .34117 m
.01334 .33978 L
s
.00821 .35279 m
.012 .35141 L
s
.0055 .37622 m
.0093 .37485 L
s
.00414 .38803 m
.00793 .38666 L
s
.00276 .39989 m
.00656 .39853 L
s
.00139 .41182 m
.00519 .41047 L
s
.25 Mabswid
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.54154 .92059 L
s
.54154 .92059 m
.5414 .7134 L
s
.5414 .7134 m
.02642 .19522 L
s
.53391 0 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.53391 0 m
.02642 .19522 L
s
.5414 .7134 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.54154 .92059 L
s
.54154 .92059 m
.5414 .7134 L
s
0 0 m
1 0 L
1 .92059 L
0 .92059 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.39225 .6648 m
.42789 .64534 L
s
1 0 .6 r
.3748 .63024 m
.40741 .61212 L
s
.8 0 1 r
.35735 .59566 m
.38699 .57893 L
s
.2 0 1 r
.33993 .56108 m
.36681 .54579 L
s
0 .4 1 r
.32273 .52652 m
.34742 .51271 L
s
0 1 1 r
.30614 .49202 m
.32952 .47967 L
s
0 1 .4 r
.29058 .45754 m
.31349 .44653 L
s
.2 1 0 r
.27611 .42287 m
.29902 .41299 L
s
.8 1 0 r
.26242 .38772 m
.28549 .37868 L
s
1 .6 0 r
.24907 .35194 m
.27229 .34337 L
s
.2 1 0 r
.29902 .41299 m
.32131 .40257 L
s
.8 1 0 r
.28549 .37868 m
.30836 .36927 L
s
0 1 .4 r
.31349 .44653 m
.33503 .43484 L
s
1 .6 0 r
.27229 .34337 m
.29552 .33461 L
s
0 1 1 r
.32952 .47967 m
.35035 .46652 L
s
0 .4 1 r
.34742 .51271 m
.36804 .49786 L
s
.2 0 1 r
.36681 .54579 m
.38834 .52898 L
s
.8 0 1 r
.38699 .57893 m
.41066 .55996 L
s
1 0 .6 r
.40741 .61212 m
.43403 .59092 L
s
1 0 0 r
.42789 .64534 m
.45778 .62195 L
s
.8 1 0 r
.30836 .36927 m
.331 .35963 L
s
1 .6 0 r
.29552 .33461 m
.31876 .32567 L
s
.2 1 0 r
.32131 .40257 m
.34297 .39198 L
s
0 1 .4 r
.33503 .43484 m
.35531 .42321 L
s
0 1 1 r
.35035 .46652 m
.36886 .45379 L
s
0 .4 1 r
.36804 .49786 m
.38457 .48399 L
s
1 .6 0 r
.31876 .32567 m
.342 .31665 L
s
.8 1 0 r
.331 .35963 m
.35349 .34998 L
s
.2 1 0 r
.34297 .39198 m
.36431 .3816 L
s
.2 0 1 r
.38834 .52898 m
.40326 .51382 L
s
0 1 .4 r
.35531 .42321 m
.37509 .41212 L
s
.8 0 1 r
.41066 .55996 m
.42513 .54319 L
s
1 .6 0 r
.342 .31665 m
.36533 .30764 L
s
0 1 1 r
.36886 .45379 m
.38659 .44208 L
s
.8 1 0 r
.35349 .34998 m
.37603 .34052 L
s
1 0 .6 r
.43403 .59092 m
.44942 .57214 L
s
.2 1 0 r
.36431 .3816 m
.38576 .37168 L
s
0 .4 1 r
.38457 .48399 m
.39968 .47181 L
s
1 0 0 r
.45778 .62195 m
.47501 .60092 L
s
0 1 .4 r
.37509 .41212 m
.39512 .40182 L
s
1 .6 0 r
.36533 .30764 m
.38882 .29873 L
s
.2 0 1 r
.40326 .51382 m
.41539 .50141 L
s
.8 1 0 r
.37603 .34052 m
.39884 .33139 L
s
0 1 1 r
.38659 .44208 m
.40479 .4315 L
s
.2 1 0 r
.38576 .37168 m
.40763 .36236 L
s
.8 0 1 r
.42513 .54319 m
.43459 .53075 L
s
1 .6 0 r
.38882 .29873 m
.41259 .29 L
s
0 .4 1 r
.39968 .47181 m
.4155 .46111 L
s
0 1 .4 r
.39512 .40182 m
.41583 .39237 L
s
.8 1 0 r
.39884 .33139 m
.42206 .32266 L
s
1 0 .6 r
.44942 .57214 m
.45731 .55958 L
s
.2 1 0 r
.40763 .36236 m
.43013 .35368 L
s
.2 0 1 r
.41539 .50141 m
.42818 .49092 L
s
0 1 1 r
.40479 .4315 m
.42403 .42201 L
s
1 .6 0 r
.41259 .29 m
.4367 .28148 L
s
.8 1 0 r
.42206 .32266 m
.44582 .31437 L
s
0 1 .4 r
.41583 .39237 m
.43743 .3838 L
s
1 0 0 r
.47501 .60092 m
.48252 .58797 L
s
0 .4 1 r
.4155 .46111 m
.43284 .4517 L
s
.8 0 1 r
.43459 .53075 m
.44398 .52102 L
s
.2 1 0 r
.43013 .35368 m
.45337 .34567 L
s
0 1 1 r
.42403 .42201 m
.4445 .4136 L
s
1 .6 0 r
.4367 .28148 m
.4612 .27314 L
s
.2 0 1 r
.42818 .49092 m
.44299 .48184 L
s
1 0 .6 r
.45731 .55958 m
.46371 .55123 L
s
.8 1 0 r
.44582 .31437 m
.47018 .3065 L
s
0 1 .4 r
.43743 .3838 m
.45999 .37611 L
s
0 .4 1 r
.43284 .4517 m
.45183 .44357 L
s
.8 0 1 r
.44398 .52102 m
.45551 .51276 L
s
.2 1 0 r
.45337 .34567 m
.47741 .33831 L
s
0 1 1 r
.4445 .4136 m
.46618 .40631 L
s
1 .6 0 r
.4612 .27314 m
.4861 .26494 L
s
1 0 0 r
.48252 .58797 m
.48689 .58133 L
s
.2 0 1 r
.44299 .48184 m
.45997 .47414 L
s
.8 1 0 r
.47018 .3065 m
.49517 .29897 L
s
0 1 .4 r
.45999 .37611 m
.48354 .36932 L
s
1 0 .6 r
.46371 .55123 m
.47151 .54464 L
s
.2 1 0 r
.47741 .33831 m
.50231 .33155 L
s
0 .4 1 r
.45183 .44357 m
.47232 .43676 L
s
.8 0 1 r
.45551 .51276 m
.46965 .50585 L
s
0 1 1 r
.46618 .40631 m
.48901 .40016 L
s
1 0 0 r
.48689 .58133 m
.49115 .57729 L
s
1 .6 0 r
.4861 .26494 m
.51137 .2568 L
s
0 1 .4 r
.48354 .36932 m
.50812 .36339 L
s
.8 1 0 r
.49517 .29897 m
.52079 .29167 L
s
1 0 .6 r
.47151 .54464 m
.48174 .53921 L
s
.2 0 1 r
.45997 .47414 m
.47879 .46797 L
s
1 0 0 r
.5958 .57925 m
.64868 .57742 L
s
.55451 .57616 m
.5958 .57925 L
s
.2 1 0 r
.50231 .33155 m
.52811 .32525 L
s
0 .4 1 r
.47232 .43676 m
.49411 .43135 L
s
1 0 0 r
.64868 .57742 m
.69998 .57047 L
s
.49115 .57729 m
.49654 .57426 L
s
.8 0 1 r
.46965 .50585 m
.48593 .50058 L
s
0 1 1 r
.48901 .40016 m
.51298 .39516 L
s
1 0 0 r
.5311 .57278 m
.55451 .57616 L
s
1 0 .6 r
.59703 .53969 m
.6445 .53799 L
s
.56027 .5371 m
.59703 .53969 L
s
0 1 .4 r
.50812 .36339 m
.53381 .35822 L
s
1 0 .6 r
.48174 .53921 m
.49408 .53527 L
s
1 0 0 r
.49654 .57426 m
.50321 .57217 L
s
1 .6 0 r
.51137 .2568 m
.53693 .2486 L
s
.2 0 1 r
.47879 .46797 m
.49898 .46349 L
s
.8 1 0 r
.52079 .29167 m
.54696 .2844 L
s
1 0 .6 r
.6445 .53799 m
.69168 .53148 L
s
1 0 0 r
.51887 .57131 m
.5311 .57278 L
s
0 .4 1 r
.49411 .43135 m
.51705 .42743 L
s
1 0 .6 r
.53728 .5342 m
.56027 .5371 L
s
1 0 0 r
.50321 .57217 m
.51058 .57119 L
s
.2 1 0 r
.52811 .32525 m
.55481 .31918 L
s
0 1 1 r
.51298 .39516 m
.5382 .39125 L
s
1 0 0 r
.51058 .57119 m
.51887 .57131 L
s
.8 0 1 r
.48593 .50058 m
.50357 .49722 L
s
.59806 .50014 m
.6403 .49844 L
s
.56493 .49835 m
.59806 .50014 L
s
1 0 .6 r
.49408 .53527 m
.50754 .53315 L
s
0 1 .4 r
.53381 .35822 m
.56079 .35353 L
s
1 0 .6 r
.52146 .53285 m
.53728 .5342 L
s
.2 0 1 r
.49898 .46349 m
.52018 .46081 L
s
.8 0 1 r
.6403 .49844 m
.68336 .49238 L
s
.54131 .49639 m
.56493 .49835 L
s
0 .4 1 r
.51705 .42743 m
.54124 .42496 L
s
1 0 .6 r
.50754 .53315 m
.52146 .53285 L
s
0 1 1 r
.5382 .39125 m
.56506 .38815 L
s
.8 0 1 r
.50357 .49722 m
.52188 .49587 L
s
.8 1 0 r
.54696 .2844 m
.57352 .27697 L
s
.8 0 1 r
.52188 .49587 m
.54131 .49639 L
s
.2 0 1 r
.59838 .46091 m
.63597 .4589 L
s
.56749 .46038 m
.59838 .46091 L
s
.52018 .46081 m
.54251 .45991 L
s
1 .6 0 r
.53693 .2486 m
.56267 .24025 L
s
.2 1 0 r
.55481 .31918 m
.58233 .31297 L
s
.2 0 1 r
.54251 .45991 m
.56749 .46038 L
s
0 .4 1 r
.54124 .42496 m
.56744 .42364 L
s
0 1 .4 r
.56079 .35353 m
.58919 .34882 L
s
0 .4 1 r
.56744 .42364 m
.59725 .42247 L
s
.2 0 1 r
.63597 .4589 m
.675 .45319 L
s
0 1 1 r
.56506 .38815 m
.59419 .38515 L
s
0 .4 1 r
.59725 .42247 m
.63124 .41965 L
s
0 1 1 r
.59419 .38515 m
.62564 .38109 L
s
0 1 .4 r
.58919 .34882 m
.61875 .34338 L
s
0 .4 1 r
.63124 .41965 m
.66655 .41404 L
s
.2 1 0 r
.58233 .31297 m
.61033 .30625 L
s
.8 1 0 r
.57352 .27697 m
.60023 .26917 L
s
1 .6 0 r
.56267 .24025 m
.58849 .23171 L
s
0 1 1 r
.62564 .38109 m
.65783 .37515 L
s
0 1 .4 r
.61875 .34338 m
.64851 .33675 L
s
.2 1 0 r
.61033 .30625 m
.63825 .29879 L
s
.8 1 0 r
.60023 .26917 m
.62685 .26097 L
s
1 .6 0 r
.58849 .23171 m
.61434 .22297 L
s
0 g
.25 Mabswid
.53391 0 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.53391 0 m
.02642 .19522 L
s
.02642 .19522 m
.53391 0 L
s
.02642 .19522 m
.03116 .2 L
s
[(-2)] .01694 .18568 .99384 1 Mshowa
.14712 .14879 m
.15172 .1537 L
s
[(-1)] .13793 .13897 .93651 1 Mshowa
.2718 .10083 m
.27624 .10588 L
s
[(0)] .26292 .09073 .87917 1 Mshowa
.40066 .05126 m
.40493 .05646 L
s
[(1)] .39212 .04087 .82184 1 Mshowa
.53391 0 m
.538 .00534 L
s
[(2)] .52574 -0.01069 .7645 1 Mshowa
.125 Mabswid
.05025 .18606 m
.05308 .18894 L
s
.07424 .17683 m
.07705 .17973 L
s
.09837 .16755 m
.10117 .17046 L
s
.12267 .1582 m
.12545 .16113 L
s
.17173 .13933 m
.17447 .14229 L
s
.19651 .1298 m
.19923 .13278 L
s
.22144 .1202 m
.22414 .1232 L
s
.24654 .11055 m
.24922 .11356 L
s
.29723 .09105 m
.29988 .0941 L
s
.32283 .0812 m
.32546 .08427 L
s
.3486 .07129 m
.35121 .07437 L
s
.37455 .06131 m
.37713 .06441 L
s
.42695 .04115 m
.4295 .04428 L
s
.45342 .03096 m
.45594 .03412 L
s
.48007 .02071 m
.48257 .02388 L
s
.5069 .01039 m
.50938 .01358 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 265.125},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001Bb000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00`oooool5o`000:3ooooo0033ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@0X?ooool00<Cooooo00?oV9RHob4Q8Oo^k^h0XOooool00<Gooooo00?oV9RH
ob4Q8Oo^k^h0X?ooool00<Kooooo00?oMgMgofIVI_ooool0Woooool00<Oooooo00?o0000oooooooo
ool0W_ooool00<?ooooo00Go0000okZj^_ooooooV9RHoa0@402Pooooo`00`oooool01OnHV9So410@
o`000?lQ8B7oc<c<0:3ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003;ooooo`;o0000Voooool00<Sooooo0ol000000ooooooo0000ooooo`2Jooooo`00a_oo
ool2o`0000Cooooo0_l0002Jooooo`00`oooool3o`0000Kooooo00?o0000ooooool00000VOooool0
0<3ooooo1?l00008ooooo`04o`000?ooooooooooo`0009Sooooo002Hooooo`Co000000?o410@oooo
ooooool07oooool2o`0000Cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0002H
ooooo`00V_ooool00ol0003oooooooooo`0Nooooo`?o00003_ooool01Ol0003ooooooooooooooooo
000009Oooooo002Jooooo`03o`000?oooooooooo01cooooo0_l0000Aooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0U?ooool009[ooooo00?o0000ooooooooool06Oooool3o`0000;o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo09?o
oooo002Jooooo`03o`000?oooooooooo01Kooooo0ol0000Fooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^08Kooooo002Jooooo`03o`00
0?oooooooooo01Cooooo0_l0000Iooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1oooool01OmgMgOoV9RHoooooonHV9SoMgMg08Kooooo002Jooooo`03o`000?oooooooooo017ooooo
0ol000000ooooooo0000ooooo`0Hooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1_ooool01Ol@413ooooooooooooooooo410@08Kooooo002Hooooo`03oeEEEOmVIVKo0000017ooooo
0_l0000Nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool01Ol0003ooooo
oooooooooooo000008Kooooo002Yooooo`?o00008?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000026ooooo`00Yoooool3o`0002;ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@
4100Q_ooool00:Cooooo0ol00002ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Q_ooool00:7ooooo
0ol0000Xooooo`03o`000?oooooooooo00Sooooo0_l00004ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h0Q_ooool009oooooo0_l0000[ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo
0000S_ooool009cooooo0ol000000ooooooo0000ooooo`0Zooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0S?ooool009[ooooo0_l00005ooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`2;ooooo`00Uoooool3o`0003;ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`2:ooooo`00K?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^02?ooooo0ol000000ooooooo0000ooooo`0booooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0ROooool006cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Qooooo`;o0000>?ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo08Wooooo001/ooooo`05oa0@4?oooooooooo
ooooool@41007_ooool3o`0003[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`28
ooooo`00K?ooool01Ol0003ooooooooooooooooo000001cooooo0ol0000looooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0Qoooool006cooooo00Go0000ooooooooooooooooo`00000I
ooooo`?o00000_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool0Q_ooool006cooooo00Go410@oooooooooooooooooa0@400Gooooo`;o0000@_ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo08Kooooo001/ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL05?ooool3o`0004Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`25
ooooo`00K?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^017ooooo0ol00002ooooo`03o`000?oooooo
oooo04;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`24ooooo`00P?ooool2o`00
04[ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`23ooooo`00OOooool3o`0004co
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`22ooooo`00Noooool2o`000003oooo
ool0003ooooo04cooooo00?o0000ooooooooool05?ooool2o`0008?ooooo001hooooo`?o0000DOoo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooo000008?ooooo001eooooo`?o0000E?ooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo083ooooo001cooooo`Co0000EOooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo07oooooo001`ooooo`?o00001?ooool00ol0003o
ooooooooo`1Booooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0Ooooool006kooooo
0_l0001Looooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0O_ooool004?ooooo1?l0
00000ol@413oooooooooo`0Qooooo`?o0000G_ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo07gooooo0015ooooo`03o`000?oooooooooo023ooooo0ol00003ooooo`03o`000?oooooo
oooo05_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1looooo`00>_ooool6o`00
00Gooooo00?o0000ooooooooool07_ooool2o`0006Cooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`1looooo`00AOooool00ol0003oooooooooo`0Kooooo`?o0000I_ooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo07_ooooo0015ooooo`03o`000?oooooooooo01Wooooo
0_l00002ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`1jooooo`00AOooool00ol0003oooooooooo`0Fooooo`?o0000Joooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo07Wooooo0015ooooo`03o`000?oooooooooo01Cooooo0_l0001^
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0NOooool004?ooooo00?oEEEEofIV
I_l000004oooool3o`000003ooooool0003ooooo06gooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`1hooooo`00E_ooool3o`0007?ooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`1gooooo`00E?ooool2o`0007Kooooo00?o0000ooooooooool07oooool2o`0007Sooooo
001Aooooo`?o000000?oooooo`000?ooool0MOooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo07Kooooo001?ooooo`;o0000Noooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo07Gooooo001<ooooo`?o0000OOooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
07Cooooo0019ooooo`Co0000Ooooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo07?o
oooo0017ooooo`;o00001?ooool00ol0003oooooooooo`1looooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool0L_ooool004Cooooo0ol00025ooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool0L_ooool001[ooooo1Ol0000Sooooo`?o0000Qoooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo077ooooo000Jooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@08?ooool3
o`0000?ooooo00?o0000ooooooooool0Q?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo073ooooo000Booooo`Ko00000oooool00onHV9So8B4Qonk^kP0Oooooo`;o0000SOooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo06oooooo000Looooo`03oiRHV?lQ8B7ok^k^01_o
oooo0ol0002?ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0Koooool001gooooo
00?oMgMgofIVI_ooool05oooool3o`0000?ooooo00?o0000ooooooooool0S?ooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooooooo06kooooo000Nooooo`03o`000?oooooooooo01Cooooo0_l0
002Eooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0KOooool001[ooooo00Go0000
okZj^_ooooooV9RHoa0@400Cooooo`?o0000Uoooool00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo06cooooo000Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`04Oooool2o`0000?ooooo00?o
0000ooooooooool0U?ooool00ol0003oooooooooo`0Zooooo`;o0000KOooool002gooooo0ol0002L
ooooo`03o`000?oooooooooo02[ooooo0_l0001]ooooo`00:_ooool3o`0009oooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`1Zooooo`00:?ooool2o`0000?ooooo00?o0000oooooooo
ool0W?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo06Wooooo000Uooooo`?o0000
Y?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo06Wooooo000Tooooo`03o`000?oo
oooooooo0:Gooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1Xooooo`006_ooool4
o`000003oa0@4?oooooooooo00?ooooo0_l0002Vooooo`03o`000?oooooooooo02oooooo00?o0000
ooooooooool0Ioooool001cooooo00?o0000ooooooooool01Oooool2o`000:Kooooo00?o0000oooo
ooooool0<?ooool00ol0003oooooooooo`1Vooooo`004Oooool6o`0000Gooooo00?o0000oooooooo
ool01?ooool4o`000:Gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`08ooooo`Go
0000FOooool001cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0002Tooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool01OnHV9So8B4Qonk^k_ooooooA4A4
05Wooooo000Looooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`2Qooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool01oooool00onHV9So
8B4Qonk^kP1Jooooo`007?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0X?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Oooooo
00?oV9RHob4Q8Oo^k^h0FOooool001cooooo00?o0000ooooooooool01?ooool2o`0000Gooooo00?o
0000ooooooooool0Woooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Oooooo00?o
MgMgofIVI_ooool0F?ooool001[ooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo09kooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo05Oooooo000Sooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0WOooool00ol0003oooooooooo`0Gooooo`;ooiT07?ooool2o`0000Cooooo00Go0000okZj
^_ooooooV9RHoa0@401Iooooo`008oooool2o`0000Sooooo00?o0000ooooooooool0W?ooool00ol0
003oooooooooo`0Dooooo`?ooiT07?ooool2o`000003ooooool0003ooooo00?ooooo00GoV9RHoa0@
4?l0003o8B4Qolc<c01Iooooo`008oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
09_ooooo00?o0000ooooooooool04Oooool3oonI02?ooooo00?o0000ooooooooool0Goooool002?o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`2Jooooo`03o`000?oooooooooo00ko
oooo0oooV@0Vooooo`03o`000?oooooooooo05oooooo000Sooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0V?ooool2o`0000gooooo0oooV@0Zooooo`03o`000?oooooooooo05kooooo
000Rooooo`;o00003Oooool00ol0003oooooooooo`2Dooooo`?o000000?oooooo`000?ooool02Ooo
ool3oonI02kooooo00?o0000ooooooooool0GOooool002;ooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`2@ooooo`?o00001Oooool00ol0003oooooooooo`05ooooo`;ooiT0<_ooool0
0ol0003oooooooooo`1Looooo`008_ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo
08cooooo0ol00009ooooo`04o`000?ooooooooooooooo`?ooiT0=?ooool00ol0003oooooooooo`1L
ooooo`008_ooool3o`0000oooooo00?o0000ooooooooool0R?ooool3o`0000gooooo00?o0000oonI
0?ooV@00>?ooool00ol0003oooooooooo`1Kooooo`008_ooool00ol0003oooooooooo`0@ooooo`03
o`000?oooooooooo08Gooooo0_l0000<ooooo`CooiT000?oooooo`000?ooool0>Oooool00ol0003o
ooooooooo`1Jooooo`008_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo087ooooo
0ol0000:ooooo`CooiT01_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo05Wooooo
0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o
<S8bomgMg@05ooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool0OOooool3o`0000[o
oooo0oooV@0:ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0FOooool000Oooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03
o`000?oooooooooo01?ooooo00?o0000ooooooooool0NOooool3o`0000[ooooo0oooV@0>ooooo`03
o`000?oooooooooo03Sooooo00?o0000ooooooooool0F?ooool000Go00000_ooool01Ol@413ooooo
oooooooooooo410@013ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Eooooo`03
o`000?oooooooooo07Gooooo0ol0000:ooooo`?ooiT04_ooool00ol0003oooooooooo`0Cooooo`?o
c?l08_ooool00ol0003oooooooooo`1Gooooo`001oooool01Ol0003ooooooooooooooooo000000oo
oooo00?oMgMgoc8b<_ooool00oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo077o
oooo0ol0000:ooooo`?ooiT05_ooool00ol0003oooooooooo`0=ooooo`Goc?l09Oooool2o`0005So
oooo0007ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<
00Cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1^ooooo`;o00002_ooool3oonI
01[ooooo00?o0000ooooooooool02Oooool3olco02cooooo00?o0000ooooooooool0EOooool000Oo
oooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Kooooo0_l0000Ioooo
o`03o`000?oooooooooo06[ooooo0ol00009ooooo`?ooiT07_ooool00ol0003oooooooooo`05oooo
o`?oc?l0;oooool00ol0003oooooooooo`1Eooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo
06Kooooo0ol00009ooooo`?ooiT08Oooool00ol0003oooooooooo`02ooooo`?oc?l0<oooool00ol0
003oooooooooo`1Dooooo`001oooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005oooo
o`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0H_ooool3o`0000Sooooo1?ooV@0Uoooo
o`04o`000?o<o`3oc?l0olco03Oooooo00?o0000ooooooooool0Doooool0027ooooo00?o0000oooo
ooooool06oooool00ol0003oooooooooo`1Nooooo`?o00002?ooool3oonI02Cooooo1Oo<o`000ooo
oooo0000ooooo`0iooooo`03o`000?oooooooooo05;ooooo000Pooooo`?o00007Oooool00ol0003o
ooooooooo`1Kooooo`;o00002?ooool3oonI02Cooooo0oo<o`07ooooo`03o`000?oooooooooo03Oo
oooo00?o0000ooooooooool0D_ooool0027ooooo00?o0000ooooooooool07Oooool00ol0003ooooo
ooooo`1Gooooo`?o00001oooool3oonI02Cooooo0oo<o`0;ooooo`03o`000?oooooooooo03Oooooo
00?o0000ooooooooool0DOooool0023ooooo00?o0000ooooooooool07oooool00ol0003ooooooooo
o`1Cooooo`?o00002?ooool2oonI02Cooooo0oo<o`0?ooooo`03o`000?oooooooooo03Oooooo00?o
0000ooooooooool0D?ooool0023ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`1?
ooooo`?o00002?ooool3oonI02?ooooo0oo<o`0Booooo`03o`000?oooooooooo03Sooooo00?o0000
ooooooooool0Coooool0023ooooo0_l0000Rooooo`03o`000?oooooooooo04_ooooo0ol00008oooo
o`?ooiT08Oooool5olco01Kooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`1?oooo
o`008?ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo04Sooooo0_l00009ooooo`;o
oiT08Oooool3olco01cooooo00?o0000ooooooooool03Oooool3oc?o02Oooooo00?o0000oooooooo
ool0C_ooool0023ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`14ooooo`?o0000
2?ooool3oonI023ooooo0oo<o`0Pooooo`03o`000?oooooooooo00Wooooo0olco`0[ooooo`03o`00
0?oooooooooo04gooooo000Pooooo`?o00009?ooool00ol0003oooooooooo`10ooooo`?o00002?oo
ool3oonI023ooooo0oo<o`0Tooooo`03o`000?oooooooooo00Gooooo0olco`0^ooooo`;o0000C_oo
ool0023ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0looooo`?o00002Oooool2
oonI023ooooo0oo<o`0Xooooo`03o`000?oooooooooo00Co<ol0<_ooool00ol0003oooooooooo`1<
ooooo`005?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oooooo00?o0000ooooooooool09_ooool0
0ol0003oooooooooo`0hooooo`?o00002Oooool3oonI01kooooo1?o<o`0Yooooo`;o<ol000?o0000
oc?o0?lco`00=oooool00ol0003oooooooooo`1;ooooo`005?ooool01OmgMgOoV9RHoooooonHV9So
MgMg00Kooooo00?o0000ooooooooool0:?ooool00ol0003oooooooooo`0eooooo`;o00002Oooool3
oonI01kooooo0oo<o`0Yooooo`Co<ol00oooool00ol0003oooooooooo`0gooooo`03o`000?oooooo
oooo04[ooooo000Dooooo`05oa0@4?ooooooooooooooool@41001_ooool2o`0002[ooooo00?o0000
ooooooooool0<Oooool3o`0000Wooooo0_ooV@0Nooooo`?oc?l09oooool5oc?o00Sooooo00?o0000
ooooooooool0=oooool00ol0003oooooooooo`19ooooo`005?ooool01Ol0003ooooooooooooooooo
000000Kooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`0]ooooo`?o00002Oooool3
oonI01gooooo0oo<o`0Vooooo`Co<ol03_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooo
oooo04Wooooo000Dooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`0[
ooooo`03o`000?oooooooooo02Wooooo0ol0000:ooooo`;ooiT07_ooool2olco02Cooooo1Olco`0C
ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0B?ooool001Cooooo00Go410@oooo
oooooooooooooa0@4006ooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool09Oooool3
o`0000_ooooo0_ooV@0Mooooo`?oc?l08_ooool4oc?o01Wooooo00?o0000ooooooooool0=_ooool0
0ol0003oooooooooo`17ooooo`005?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo0_l0000^
ooooo`03o`000?oooooooooo027ooooo0ol0000;ooooo`?ooiT07?ooool3olco027ooooo1?lco`0M
ooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0A_ooool001Cooooo00Gok^k^oc8b
<_l0003o<S8bonk^kP06ooooo`03o`000?oooooooooo02kooooo00?o0000ooooooooool07_ooool2
o`0000_ooooo0oooV@0Mooooo`;oc?l08?ooool4oc?o02;ooooo00?o0000ooooooooool0=oooool0
0ol0003oooooooooo`15ooooo`007oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo
01[ooooo0ol0000;ooooo`;ooiT07Oooool3olco01gooooo1Olco`0Wooooo`03o`000?oooooooooo
03Kooooo00?o0000ooooooooool0AOooool001kooooo00?o0000ooooooooool0<Oooool00ol0003o
ooooooooo`0Fooooo`?o00002oooool3oonI01gooooo0_o<o`0Mooooo`?o<ol0;Oooool00ol0003o
ooooooooo`05ooooo`?o0?mV;_ooool00ol0003oooooooooo`14ooooo`007_ooool2o`0003?ooooo
00?o0000ooooooooool04_ooool3o`0000_ooooo0oooV@0Nooooo`;oc?l07?ooool3oc?o037ooooo
00?o0000ooooool0ofH01?l0ofHbooooo`;o0000A?ooool001kooooo00?o0000ooooooooool0<ooo
ool00ol0003oooooooooo`0>ooooo`?o00003?ooool2oonI01kooooo0oo<o`0Kooooo`?o<ol0<Ooo
ool4o`3oIP03o`000?oooooooooo03Cooooo00?o0000ooooool00000A?ooool001kooooo00?o0000
ooooooooool0=?ooool00ol0003oooooooooo`0;ooooo`;o00003?ooool3oonI01gooooo0oo<o`0K
ooooo`?o<ol0;oooool5o`3oIPCooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`12
ooooo`007_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00Oooooo0ol0000<oooo
o`;ooiT07_ooool2olco01_ooooo0olco`0[ooooo`Oo0?mV2_ooool00ol0003oooooooooo`0foooo
o`03o`000?oooooooooo047ooooo000Nooooo`;o0000=oooool00ol0003oooooooooo`03ooooo`?o
00003_ooool00oooV@3oooooooooo`0Kooooo`?oc?l06_ooool3oc?o02Oooooo1ol0ofHBooooo`03
o`000?oooooooooo03Kooooo00?o0000ooooooooool0@?ooool001kooooo00?o0000ooooooooool0
=oooool00ol0003oooooo`000002o`0002gooooo0_o<o`0Jooooo`?o<ol09Oooool5o`3oIQ[ooooo
00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0oooooo`007_ooool00ol0003ooooooooo
o`0fooooo`?o0000;_ooool2olco01Wooooo0olco`0Tooooo`Co0?mV8?ooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo03oooooo000Nooooo`;o0000=Oooool2o`0000?ooooo00?o0000
ooooooooool0:Oooool2olco01Wooooo0_lco`0Rooooo`Go0?mV9Oooool00ol0003oooooooooo`0e
ooooo`03o`000?oooooooooo00Wooooo0_l000000ol@413oooooooooo`0`ooooo`007Oooool00ol0
003oooooooooo`0booooo`?o00001_ooool00ol0003oooooooooo`0Vooooo`;oc?l06?ooool3oc?o
023ooooo1?l0ofHZooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`0aooooo`000_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45oooo
o`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0_ooooo`?o00002_ooool0
0ol0003oooooooooo`0Sooooo`;oc?l06?ooool2oc?o01oooooo1?l0ofH_ooooo`03o`000?oooooo
oooo03Kooooo00?o0000ooooooooool01Oooool5o`0003;ooooo0002ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0/
ooooo`?o00003_ooool00ol0003oooooooooo`0Pooooo`;oc?l06?ooool2oc?o01gooooo1?l0ofHd
ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool01Oooool01?m4A4CogMgMooooool0
000cooooo`000_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool00ooo
ool2o`0002[ooooo0ol0000Booooo`03o`000?oooooooooo01cooooo0oo<o`0Hooooo`;o<ol06ooo
ool4o`3oISWooooo00Co0000o`3oool0oooo0?oo=?ooool00ol0003oooooooooo`04ooooo`04omgM
gOmEEEGoooooo`0003?ooooo0002ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo
<S8booooo`04ooooo`03o`000?oooooooooo02Oooooo0_l0000Fooooo`03o`000?oooooooooo01Wo
oooo0_o<o`0Jooooo`03oc?o0?oooooooooo01Oooooo1?l0ofHhooooo`Go0?oo00?oooooo`000?oo
ool0=_ooool00ol0003oooooooooo`04ooooo`03ogMgMoo<c<co000003?ooooo0002ooooo`05o`00
0?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Gooooo00?o0000oooo
ooooool09?ooool3o`0001Wooooo00?o0000ooooooooool05_ooool2olco01[ooooo0_lco`0Goooo
o`?o0?mV=oooool5o`3oo`Oooooo00?o0000ooooooooool0=?ooool2o`0000Gooooo00?ok^k^odA4
A?l00000<oooool000;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool08Oooool3o`0001gooooo00?o0000ooooooooool04_ooool3olco
01[ooooo0_lco`0Fooooo`?o0?mV=Oooool5o`3oo`cooooo00?o0000ooooooooool0<oooool01?l0
003oooooooooool00005ooooo`03ogMgMol0003ooooo03;ooooo0002ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`;o00007oooool3o`00027ooooo00?o0000
ooooooooool03_ooool3olco01[ooooo0olco`0Eooooo`?o0?mV<?ooool8o`3ooa;ooooo00?o0000
ooooooooool0=Oooool00ol0003oooooooooo`0hooooo`000_ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^00cooooo1?l00005ooooo`03o`000?oooooooooo01cooooo0ol0000Uooooo`03o`000?oooooo
oooo00cooooo00?oc?l0ooooooooool06Oooool2oc?o01Kooooo0_l0ofHZooooo`Wo0?oo6oooool0
0ol0003oooooooooo`0eooooo`03o`000?oooooooooo03Oooooo000Looooo`03o`000?oooooooooo
01Wooooo0ol0000Yooooo`03o`000?oooooooooo02Gooooo0_lco`0Fooooo`;o0?mV8oooool9o`3o
obGooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0fooooo`007?ooool00ol0003o
ooooooooo`0Gooooo`;o0000;Oooool00ol0003oooooooooo`0Rooooo`;o<ol05Oooool3o`3oIQoo
oooo1_l0ool_ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0=Oooool001cooooo
0_l0000Eooooo`?o0000<?ooool00ol0003oooooooooo`0Pooooo`03oc?o0?oooooooooo01?ooooo
0_l0ofHNooooo`Co0?oo=_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo03Gooooo
000Looooo`03o`000?oooooooooo017ooooo0ol0000dooooo`03o`000?oooooooooo01gooooo0_lc
o`0Dooooo`;o0?mV7?ooool4o`3ooc[ooooo00?o0000ooooooooool0=Oooool00ol0003ooooooooo
o`0dooooo`007?ooool00ol0003oooooooooo`0>ooooo`?o0000>?ooool00ol0003oooooooooo`0J
ooooo`;o<ol05?ooool2o`3oIQ_ooooo0ol0ooloooooo`03o`000?oooooooooo03Gooooo00?o0000
ooooooooool0<oooool001cooooo00?o0000ooooooooool02oooool3o`0003cooooo00?o0000oooo
ooooool05_ooool3oc?o01Gooooo00?o0?mVooooooooool05oooool4o`3ood?ooooo00?o0000oooo
ooooool0=Oooool00ol0003oooooooooo`0booooo`007?ooool2o`0000[ooooo0_l00010ooooo`03
o`000?oooooooooo01;ooooo0olco`0Fooooo`;o0?mV5_ooool4o`3oodSooooo00?o0000oooooooo
ool0=?ooool00ol0003oooooooooo`0booooo`006oooool2o`0000Sooooo0ol00013ooooo`03o`00
0?oooooooooo00oooooo0_lco`0Gooooo`;o0?mV5Oooool3o`3oodGooooo1?l0I_l4ooooo`03o`00
0?oooooooooo03Cooooo00?o0000ooooooooool0<Oooool001_ooooo00?o0000ooooooooool01?oo
ool3o`0004Oooooo00?o0000ooooooooool02oooool3oc?o01Oooooo0_l0ofHEooooo`;o0?oo@_oo
ool6o`1Vo`Wooooo00?o0000ooooooooool0<oooool2o`0003;ooooo000Kooooo`04o`000?oooooo
ooooooooo`?o0000Boooool00ol0003oooooooooo`08ooooo`;o<ol06?ooool2o`3oIQGooooo0_l0
oollooooo`So06Ko3oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo02oooooo000K
ooooo`Co0000Coooool00ol0003oooooooooo`06ooooo`03oc?o0?oooooooooo01Kooooo0_l0ofHE
ooooo`;o0?oo<oooool;o`1VoaSooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0_
ooooo`006oooool2o`0005;ooooo00?o0000ooooooooool07?ooool2o`3oIQCooooo0ol0oolSoooo
oa;o06Ko9?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02kooooo000Aooooo`Co
000000?o410@ooooooooool01Oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo01[o
oooo00?o0?mVooooooooool04_ooool2o`3ooaoooooo1ol0I_lgooooo`03o`000?oooooooooo03Co
oooo00?o0000ooooooooool0;Oooool001?ooooo00?o0000ooooooooool02?ooool00ol0003ooooo
ooooo`1@ooooo`03o`000?oooooooooo01Oooooo0_l0ofHCooooo`;o0?oo6oooool6o`1Vocoooooo
00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0/ooooo`004oooool00ol0003ooooooooo
o`09ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool05?ooool2o`3oIQCooooo00?o
0?ooooooooooool06?ooool3o`1VodKooooo00?o0000ooooooooool0<oooool00ol0003ooooooooo
o`0/ooooo`004oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo053ooooo00?o0000
ooooooooool04Oooool2o`3oIQCooooo0_l0oolGooooo`Co06KoBOooool00ol0003oooooooooo`0d
ooooo`03o`000?oooooooooo02_ooooo000Cooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool0D?ooool00ol0003oooooooooo`0?ooooo`03o`3oI_oooooooooo01?ooooo00?o0?oooooo
ooooool05?ooool3o`1Vodkooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Zoooo
o`004oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo053ooooo00?o0000oooooooo
ool03?ooool2o`3oIQCooooo0_l0oolDooooo`?o06KoD_ooool00ol0003oooooooooo`0dooooo`03
o`000?oooooooooo02Wooooo000Cooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
D?ooool00ol0003oooooooooo`09ooooo`;o0?mV5Oooool00ol0ooooooooooooo`0Booooo`;o06Ko
E_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02Sooooo000Aooooo`03oeEEEOmV
IVKo0000013ooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`06ooooo`;o0?mV5Ooo
ool2o`3ooa?ooooo0_l0I_mIooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0:?oo
ool002Gooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`03ooooo`;o0?mV5_ooool0
0ol0ooooooooooooo`0Aooooo`;o06KoC?ooool4oc<0o`cooooo00?o0000ooooooooool0<_ooool2
o`0002Wooooo000Vooooo`;o0000DOooool00ol0003oooooooooo`02o`3oIQKooooo0_l0oolBoooo
o`;o06KoAoooool7oc<0oa3ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Voooo
o`00:?ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooo0?mV01Oooooo00?o0?oooooooooo
ool04?ooool2o`1Vod3ooooo2Olc0?lHooooo`03o`000?oooooooooo03Cooooo00?o0000oooooooo
ool09Oooool002Wooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0Dooooo`;o0?oo
4Oooool2o`1Voakooooo9?lc0?lRooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0
9Oooool002[ooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0Booooo`03o`3ooooo
oooooooo013ooooo00?o06Koooooooooool05oooool7oc<0odOooooo00?o0000ooooooooool0<ooo
ool00ol0003oooooooooo`0Tooooo`00:oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooo
oooo00oooooo0_l0oolBooooo`03o`1Voooooooooooo01?ooooo1Olc0?m?ooooo`03o`000?oooooo
oooo03?ooooo00?o0000ooooooooool08oooool002cooooo00?o0000ooooooooool0C_ooool00ol0
003oooooooooo`0<ooooo`;o0?oo4oooool00ol0I_ooooooooooo`0Aooooo`?o<`3oEOooool00ol0
003oooooooooo`0cooooo`03o`000?oooooooooo02;ooooo000]ooooo`03o`000?oooooooooo04ko
oooo00?o0000ooooooooool02_ooool00ol0ooooooooooooo`0Aooooo`;o06Ko4Oooool3oc<0oeSo
oooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Rooooo`00;_ooool00ol0003ooooo
ooooo`1>ooooo`03o`000?oooooooooo00Oooooo0_l0oolCooooo`03o`1Voooooooooooo00oooooo
0_lc0?mLooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool08Oooool002oooooo00?o
0000ooooooooool0C_ooool00ol0003oooooooooo`04ooooo`;o0?oo4oooool2o`1Voa7ooooo00?o
<`3oooooooooool0GOooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo023ooooo000`
ooooo`03o`000?oooooooooo04kooooo00Co0000oooooooooooooooo0_l0oolDooooo`03o`1Voooo
oooooooo00oooooo0_lc0?mQooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool07ooo
ool0037ooooo0_l0001?ooooo`03o`000?oooooo0?oo01Cooooo0_l0I_l@ooooo`;o<`3oI?ooool0
0ol0003oooooooooo`0booooo`;o00008?ooool003?ooooo00?o0000ooooooooool0C?ooool2o`3o
oaCooooo00?o06Koooooooooool03oooool00olc0?ooooooooooo`1Uooooo`03o`000?oooooooooo
037ooooo0_l0000Pooooo`00=?ooool00ol0003oooooooooo`1:ooooo`04o`3oooooooooooooo`00
01;ooooo00?o06Koooooooooool03_ooool2oc<0oe3ooooo1Oo<0?lCooooo`03o`000?oooooooooo
03?ooooo00?o0000ooooooooool07Oooool003Gooooo00?o0000ooooooooool0COooool00ol0003o
ooooooooo`0>ooooo`03o`1Voooooooooooo00kooooo00?o<`3oooooooooool06oooool7ol`0obOo
oooo1oo<0?lIooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool07?ooool003Kooooo
00?o0000ooooooooool0COooool00ol0003oooooooooo`0;ooooo`;o06Ko4?ooool00olc0?oooooo
ooooo`0Fooooo`Koc03o1ooooolAol`0o`_ooooo2oo<0?lQooooo`03o`000?oooooooooo03;ooooo
00?o0000ooooooooool07?ooool003Oooooo00?o0000ooooooooool0COooool00ol0003ooooooooo
o`09ooooo`03o`1Voooooooooooo00oooooo00?o<`3oooooooooool04oooool4ol`0oakooooo2oo<
0?l]ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool06oooool003Sooooo00?o0000
ooooooooool0COooool00ol0003oooooooooo`06ooooo`;o06Ko4Oooool00olc0?ooooooooooo`0A
ooooo`?oc03oFoooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00Oooooo00Gok^k^
oc8b<_l0003o410@olc<c00>ooooo`00>Oooool00ol0003oooooooooo`1=ooooo`03o`000?oooooo
oooo00Cooooo00?o06Koooooooooool04?ooool00olc0?ooooooooooo`0@ooooo`;oc03oGoooool0
0ol0003oooooooooo`0booooo`03o`000?oooooooooo00Kooooo00GoEEEEogMgMoooooooV9RHob4Q
8@0>ooooo`00>_ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo00;ooooo00?o06Ko
ooooooooool04?ooool00olc0?ooooooooooo`0>ooooo`?oc03oHOooool00ol0003oooooooooo`0c
ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`00000>ooooo`00>oooool0
0ol0003oooooooooo`1=ooooo`04o`000?oooooo06Koo`1Voa;ooooo00?o<`3oooooooooool03Ooo
ool2ol`0ofGooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`05ooooo`05o`000?nH
V9SooooooiRHV?lQ8B403_ooool003cooooo00?o0000ooooooooool0COooool00ol0I_oooooooooo
o`0Aooooo`03oc<0oooooooooooo00gooooo00?oc03oooooooooool0I_ooool00ol0003ooooooooo
o`0booooo`03o`000?oooooooooo00Cooooo00Go0000oeEEEOl0003o410@olc<c00>ooooo`00?Ooo
ool2o`0004_ooooo0_l0I_l00ooooooo0000ooooo`0@ooooo`03oc<0oooooooooooo00gooooo00?o
c03oooooooooool0J?ooool00ol0003oooooooooo`0booooo`;o00001?ooool00omEEEGoQhN7oooo
o`0@ooooo`00?oooool00ol0003oooooooooo`16ooooo`;o06Ko1?ooool00ol0003oooooooooo`0=
ooooo`03oc<0oooooooooooo00gooooo00?oc03oooooooooool0J_ooool00ol0003oooooooooo`0_
ooooo`;o000000?oooooo`000?ooool00oooool00ooMgMgo410@oiRHV00@ooooo`00@?ooool00ol0
003oooooooooo`14ooooo`03o`1Voooooooooooo00Gooooo00?o0000ooooooooool02oooool00olc
0?ooooooooooo`0=ooooo`03ol`0oooooooooooo06cooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`03ooooo`04olc<c?m4A4Co0000oa0@40kooooo0011ooooo`03o`000?oooooooooo
04;ooooo00?o06Koooooooooool01oooool00ol0003oooooooooo`08ooooo`;o<`3o3oooool00oo<
0?ooooooooooo`1]ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool05?ooool004;o
oooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`06ooooo`03oc<0oooooooooooo00ko
oooo00?oc03oooooooooool0C_ooool5ool0VAcooooo00?o0000ooooooooool0<_ooool00ol0003o
ooooooooo`0Cooooo`00@oooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo00Cooooo
00?o<`3oooooooooool03oooool00oo<0?ooooooooooo`0Coooooa7oo`2I8oooool7ool0VB;ooooo
00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Booooo`00A?ooool00ol0003ooooooooo
o`1<ooooo`03o`000?oooooooooo00;ooooo00?o<`3oooooooooool03oooool00oo<0?oooooooooo
o`0@ooooo`Coo`2I4Oooool:ool0V@gooooo3?oo09TZooooo`03o`000?oooooooooo037ooooo00?o
0000ooooooooool04_ooool004Gooooo00?o0000ooooooooool0C?ooool01?l0003ooooooooooolc
0?lAooooo`03ol`0oooooooooooo00kooooo0ooo09TOooooo`goo`2I=oooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo017ooooo0016ooooo`03o`000?oooooooooo04cooooo00?o0000
oc<0ooooool04?ooool00oo<0?ooooooooooo`0=ooooo`;oo`2IIoooool00ol0003oooooooooo`0a
ooooo`03o`000?oooooooooo013ooooo0017ooooo`03o`000?oooooooooo04[ooooo0_lc0?l00ol0
003oooooooooo`0?ooooo`03ol`0oooooooooooo00cooooo00?oo`2Iooooooooool0Ioooool00ol0
003oooooooooo`0booooo`03o`000?oooooooooo00oooooo0018ooooo`;o0000B?ooool2oc<0o`?o
oooo00?o0000ooooooooool03Oooool00oo<0?ooooooooooo`0<ooooo`03ool0VOoooooooooo06Wo
oooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0?ooooo`00B_ooool00ol0003ooooo
ooooo`13ooooo`;o<`3o1_ooool00ol0003oooooooooo`0;ooooo`03ol`0oooooooooooo00cooooo
00?oo`2Iooooooooool0Joooool00ol0003oooooooooo`0aooooo`;o00003oooool004_ooooo00?o
0000ooooooooool0@Oooool00olc0?ooooooooooo`07ooooo`03o`000?oooooooooo00Wooooo00?o
c03oooooooooool03Oooool00ooo09Woooooooooo`1/ooooo`03o`000?oooooooooo033ooooo0_l0
000?ooooo`00C?ooool00ol0003oooooooooo`0nooooo`;o<`3o2oooool00ol0003oooooooooo`07
ooooo`03ol`0oooooooooooo00gooooo00?oo`2Iooooooooool0K_ooool00ol0003oooooooooo`0a
ooooo`03o`000?oooooooooo00cooooo001=ooooo`03o`000?oooooooooo03cooooo00?o<`3ooooo
ooooool03?ooool00ol0003oooooooooo`04ooooo`;oc03o3oooool00ooo09Woooooooooo`1`oooo
o`03o`000?oooooooooo037ooooo00?o0000ooooooooool02oooool004kooooo00?o0000oooooooo
ool0Boooool00ol0003oooooooooo`02ooooo`03ol`0oooooooooooo00oooooo00?oo`2Ioooooooo
ool0L?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00_ooooo001?ooooo`03o`00
0?oooooooooo04_ooooo00Co0000ooooooooooooc03o4Oooool00ooo09Woooooooooo`1booooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool02_ooool0053ooooo00?o0000ooooooooool0
Boooool2ol`0oa7ooooo00?oo`2Iooooooooool03oooool4ool003Wooooo1?oo000Tooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool02Oooool0057ooooo00?o0000ooooooooool0BOoo
ool00oo<0?ooooooo`00000@ooooo`03ool0VOoooooooooo00cooooo1?oo0004ooooo`Woo`00:_oo
ool6ool002Wooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`08ooooo`00D_ooool0
0ol0003oooooooooo`17ooooo`05ol`0ooooooooooooooooool000003oooool00ooo09Wooooooooo
o`0;ooooo`03ool00?oooooooooo00oooooo2ooo000Jooooo`Goo`00<?ooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo00Sooooo001Cooooo`;o0000AOooool2ol`0o`Gooooo00?o0000
ooooooooool02oooool00ooo09Woooooooooo`0;ooooo`03ool00?oooooooooo01_ooooo6_oo000f
ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool01oooool005Gooooo00?o0000oooo
ooooool0@?ooool2ol`0o`Sooooo00?o0000ooooooooool02Oooool00ooo09Woooooooooo`0;oooo
o`03ool00?oooooooooo06cooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`06oooo
o`00E_ooool00ol0003oooooooooo`0nooooo`03ol`0oooooooooooo00Wooooo00?o0000oooooooo
ool01oooool00ooo09Woooooooooo`0<ooooo`03ool00?oooooooooo06gooooo00?o0000oooooooo
ool0;oooool3o`0000Oooooo001Gooooo`03o`000?oooooooooo03_ooooo0_o<0?l=ooooo`03o`00
0?oooooooooo00Gooooo00?oo`2Iooooooooool03?ooool00ooo003oooooooooo`1_ooooo`03o`00
0?oooooooooo02_ooooo0ol00002ooooo`03o`000?oooooooooo00Gooooo001Hooooo`03o`000?oo
oooooooo03Sooooo0_o<0?l@ooooo`03o`000?oooooooooo00;ooooo0_oo09T?ooooo`03ool00?oo
oooooooo073ooooo00?o0000ooooooooool09oooool3o`0000Gooooo00?o0000ooooooooool01Ooo
ool005Wooooo00?o0000ooooooooool0=_ooool00oo<0?ooooooooooo`0Aooooo`04o`000?oooooo
ooooool0VA3ooooo00?oo`00ooooooooool0L_ooool00ol0003oooooooooo`0Rooooo`Co00002?oo
ool00ol0003oooooooooo`05ooooo`00F_ooool00ol0003oooooooooo`0dooooo`03ol`0oooooooo
oooo01?ooooo00?o0000ool0VOooool03oooool00ooo003oooooooooo`1dooooo`03o`000?oooooo
oooo01kooooo0ol0000<ooooo`03o`000?oooooooooo00Gooooo001Kooooo`03o`000?oooooooooo
04Sooooo0_oo09T00ol0003oooooooooo`0=ooooo`03ool00?oooooooooo07Gooooo00?o0000oooo
ooooool06_ooool4o`0000oooooo00?o0000ooooooooool01Oooool005cooooo00?o0000oooooooo
ool0A_ooool01Ooo09Wooooooooooooooooo000000kooooo00?oo`00ooooooooool0M_ooool00ol0
003oooooooooo`0Fooooo`?o00005?ooool00ol0003oooooooooo`04ooooo`00GOooool00ol0003o
ooooooooo`14ooooo`03ool0VOoooooooooo00?ooooo00?o0000ooooooooool02_ooool00ooo003o
ooooooooo`1hooooo`03o`000?oooooooooo01;ooooo0ol0000Gooooo`03o`000?oooooooooo00Co
oooo001Nooooo`;o0000@oooool00ooo09Woooooooooo`05ooooo`03o`000?oooooooooo00Sooooo
00?oo`00ooooooooool0N_ooool00ol0003oooooooooo`0=ooooo`Co00006_ooool00ol0003ooooo
ooooo`04ooooo`00H?ooool00ol0003oooooooooo`0nooooo`;oo`2I2Oooool00ol0003ooooooooo
o`06ooooo`03ool00?oooooooooo07cooooo00?o0000ooooooooool02Oooool3o`0001kooooo00?o
0000ooooooooool01?ooool0067ooooo00?o0000ooooooooool0>oooool2ool0V@cooooo00?o0000
ooooooooool01Oooool00ooo003oooooooooo`1mooooo`03o`000?oooooooooo00Cooooo1?l0000Q
ooooo`03o`000?oooooooooo00Cooooo001Rooooo`03o`000?oooooooooo03Sooooo0_oo09T?oooo
o`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool0O_ooool01?l0003oooooooooooooool3
o`0002Gooooo00?o0000ooooooooool01?ooool006?ooooo00?o0000ooooooooool0=_ooool00ooo
09Woooooooooo`0@ooooo`03o`000?oooooooooo00;oo`00P_ooool3o`0002Sooooo00?o0000oooo
ooooool01?ooool006Cooooo00?o0000ooooooooool0<oooool2ool0VACooooo00?o0000ool00?oo
ool0Ooooool4o`000003ooooool0003ooooo02Sooooo00?o0000ooooooooool01?ooool006Gooooo
00?o0000ooooooooool0<?ooool2ool0VAKooooo00?oo`00o`000?ooool0O?ooool3o`0000Kooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`04ooooo`00I_ooool00ol0003ooooooooo
o`0^ooooo`03ool0VOoooooooooo01Gooooo00Coo`00oooooooooooo0000N?ooool4o`0000[ooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`04ooooo`00Ioooool00ol0003ooooooooo
o`13ooooo`;oo`001?ooool00ol0003oooooooooo`1booooo`?o00003oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo00?ooooo001Xooooo`03o`000?oooooooooo047ooooo00?oo`00
ooooooooool01Oooool00ol0003oooooooooo`1^ooooo`?o00004_ooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo00?ooooo001Yooooo`03o`000?oooooooooo03oooooo00?oo`00oooo
ooooool01oooool00ol0003oooooooooo`1Yooooo`Co00005_ooool00ol0003oooooooooo`0Toooo
o`03o`000?oooooooooo00?ooooo001Zooooo`;o0000?_ooool00ooo003oooooooooo`09ooooo`03
o`000?oooooooooo06Gooooo0ol0000Kooooo`03o`000?oooooooooo02?ooooo00?o0000oooooooo
ool00oooool006cooooo00?o0000ooooooooool0>Oooool2ool000gooooo00?o0000ooooooooool0
H?ooool4o`0001oooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`03ooooo`00KOoo
ool00ol0003oooooooooo`0fooooo`;oo`004?ooool00ol0003oooooooooo`1Looooo`?o00009?oo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00?ooooo001^ooooo`03o`000?oooooo
oooo03?ooooo0_oo000Cooooo`03o`000?oooooooooo05Sooooo0ol0000Xooooo`03o`000?oooooo
oooo023ooooo00?o0000ooooooooool00oooool006oooooo00?o0000ooooooooool0<?ooool2ool0
01Kooooo00?o0000ooooooooool0Doooool4o`0002_ooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`03ooooo`00L?ooool00ol0003oooooooooo`0]ooooo`;oo`006Oooool00ol0003o
ooooooooo`1?ooooo`?o0000<?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00?o
oooo001aooooo`03o`000?oooooooooo02[ooooo0_oo000Looooo`03o`000?oooooooooo04[ooooo
1?l0000dooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool00oooool007;ooooo00?o
0000ooooooooool0:?ooool00ooo003oooooooooo`0Mooooo`03o`000?oooooooooo04Kooooo0ol0
000iooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool00_ooool007?ooooo00?o0000
ooooooooool0B?ooool00ol0003oooooooooo`12ooooo`?o0000?Oooool00ol0003oooooooooo`0M
ooooo`03o`000?oooooooooo00;ooooo001dooooo`03o`000?oooooooooo04Sooooo00?o0000oooo
ooooool0?Oooool4o`00047ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`02oooo
o`00MOooool2o`0004Wooooo00?o0000ooooooooool0>Oooool3o`0004Gooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`02ooooo`00Moooool00ol0003oooooooooo`17ooooo`03o`00
0?oooooooooo03Cooooo1?l00019ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
0_ooool007Sooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0`ooooo`?o0000C_oo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00;ooooo001iooooo`03o`000?oooooo
oooo04Oooooo00?o0000ooooooooool0;?ooool3o`0005;ooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`02ooooo`00N_ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo
02Oooooo1?l0001Fooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool00_ooool007_o
oooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Sooooo`?o0000Foooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo00;ooooo001looooo`03o`000?oooooooooo04Oooooo
00?o0000ooooooooool07_ooool4o`0005kooooo00?o0000ooooooooool05oooool00ol0003ooooo
ooooo`02ooooo`00OOooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo01[ooooo0ol0
001Sooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool00Oooool007kooooo00?o0000
ooooooooool0Aoooool00ol0003oooooooooo`0Fooooo`?o0000Ioooool00ol0003oooooooooo`0F
ooooo`03o`000?oooooooooo007ooooo001oooooo`03o`000?oooooooooo04Oooooo00?o0000oooo
ooooool04Oooool4o`0006_ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`01oooo
o`00P?ooool2o`0004Sooooo00?o0000ooooooooool03Oooool3o`00073ooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`01ooooo`00P_ooool00ol0003oooooooooo`16ooooo`03o`00
0?oooooooooo00Sooooo1?l0001dooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
0Oooool008?ooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`04ooooo`?o0000N?oo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo007ooooo0024ooooo`03o`000?oooooo
oooo04Kooooo00?o0000ooooooooool00ol0001looooo`03o`000?oooooooooo01;ooooo00?o0000
ooooooooool00Oooool008Gooooo00?o0000ooooooooool0A_ooool2o`00083ooooo00?o0000oooo
ooooool04Oooool00ol0003oooooooooo`01ooooo`00Q_ooool00ol0003oooooooooo`15ooooo`03
o`000?oooooooooo083ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`01ooooo`00
Qoooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo087ooooo00?o0000ooooooooool0
3oooool00ol0003oooooooooo`01ooooo`00R?ooool00ol0003oooooooooo`13ooooo`03o`000?oo
oooooooo08;ooooo00?o0000ooooooooool03oooool1o`00007ooooo0Oooool008Wooooo00?o0000
ooooooooool0@_ooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo00oooooo0Ol00001
ooooo`7ooooo002:ooooo`03o`000?oooooooooo047ooooo00?o0000ooooooooool0Poooool00ol0
003oooooooooo`0>ooooo`7o00000Oooool1ooooo`00Roooool2o`00047ooooo00?o0000oooooooo
ool0Q?ooool00ol0003oooooooooo`0=ooooo`7o00000Oooool1ooooo`00SOooool00ol0003ooooo
ooooo`0nooooo`03o`000?oooooooooo08Gooooo00?o0000ooooooooool03?ooool1o`00007ooooo
0Oooool008kooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`26ooooo`03o`000?oo
oooooooo00_ooooo0Ol00001ooooo`7ooooo002?ooooo`03o`000?oooooooooo03cooooo00?o0000
ooooooooool0Qoooool00ol0003oooooooooo`0:ooooo`7o00000Oooool1ooooo`00T?ooool00ol0
003oooooooooo`0kooooo`03o`000?oooooooooo08Oooooo00?o0000ooooooooool02_ooool1o`00
007ooooo0Oooool0097ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`28ooooo`03
o`000?oooooooooo00Wooooo0Ol00001ooooo`7ooooo002Booooo`03o`000?oooooooooo03Wooooo
00?o0000ooooooooool0ROooool00ol0003oooooooooo`08ooooo`7o00000Oooool1ooooo`00Tooo
ool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo08[ooooo00?o0000ooooooooool02?oo
ool1o`00007ooooo002Dooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0Roooool0
0ol0003oooooooooo`07ooooo`7o00000Oooool009Gooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`2<ooooo`03o`000?oooooooooo00Kooooo0Ol00001ooooo`00U_ooool00ol0003o
ooooooooo`0eooooo`03o`000?oooooooooo08cooooo00?o0000ooooooooool01_ooool1o`00007o
oooo002Gooooo`;o0000=Oooool00ol0003oooooooooo`2=ooooo`03o`000?oooooooooo00Gooooo
0Ol00001ooooo`00VOooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo08kooooo00?o
0000ooooooooool01?ooool1o`00007ooooo002Jooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool0Soooool00ol0003oooooooooo`03ooooo`7o00000Oooool009_ooooo00?o0000oooo
ooooool0<?ooool00ol0003oooooooooo`2@ooooo`03o`000?oooooooooo00;ooooo0Ol00001oooo
o`00W?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo097ooooo00Go0000oooooooo
ooooooooo`000001ooooo`00WOooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo097o
oooo00Go0000ooooooooooooooooo`000001ooooo`00W_ooool00ol0003oooooooooo`0]ooooo`03
o`000?oooooooooo09;ooooo00Co0000oooooooooooooooo0Ol0000009oooooo00?o0000oooooooo
ool0;?ooool00ol0003oooooooooo`2Cooooo`03o`000?oooooooooo007o0000002Pooooo`03o`00
0?oooooooooo02_ooooo00?o0000ooooooooool0U?ooool1o`00007ooooo0Ol000000:7ooooo00?o
0000ooooooooool0:_ooool00ol0003oooooooooo`2Eooooo`;o0000002Rooooo`;o0000:_ooool0
0ol0003oooooooooo`2Dooooo`?o0000002Tooooo`03o`000?oooooooooo02Oooooo00?o0000oooo
ooooool0T?ooool4o`0000?ooooo002Uooooo`03o`000?oooooooooo02Kooooo00?o0000oooooooo
ool0SOooool3o`0000Oooooo002Vooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
ROooool4o`0000[ooooo002Wooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool0QOoo
ool4o`0000kooooo002Xooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0P_ooool3
o`0001;ooooo002Yooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0O_ooool4o`00
01Gooooo002Zooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0N_ooool4o`0001Wo
oooo002[ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool0MOooool4o`0001gooooo
002/ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0L_ooool3o`00027ooooo002]
ooooo`;o00008?ooool00ol0003oooooooooo`1^ooooo`Co00009?ooool00:oooooo00?o0000oooo
ooooool07Oooool00ol0003oooooooooo`1Zooooo`Co0000:?ooool00;3ooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`1Wooooo`?o0000;?ooool00;7ooooo00?o0000ooooooooool0
6oooool00ol0003oooooooooo`1Sooooo`Co0000;oooool00;;ooooo00?o0000ooooooooool06_oo
ool00ol0003oooooooooo`1Oooooo`Co0000<oooool00;?ooooo00?o0000ooooooooool06Oooool0
0ol0003oooooooooo`1Looooo`?o0000=oooool00;Cooooo00?o0000ooooooooool06?ooool00ol0
003oooooooooo`1Hooooo`Co0000>_ooool00;Gooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`1Dooooo`Co0000?_ooool00;Kooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`1@ooooo`Co0000@_ooool00;Oooooo00?o0000ooooooooool05Oooool00ol0003ooooooooo
o`1=ooooo`?o0000A_ooool00;Sooooo0_l0000Eooooo`03o`000?oooooooooo04Wooooo1?l00019
ooooo`00^_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo04Gooooo1?l0001=oooo
o`00^oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04;ooooo0ol0001Aooooo`00
_?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03kooooo1?l0001Dooooo`00_Ooo
ool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03[ooooo1?l0001Hooooo`00__ooool0
0ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03Kooooo1?l0001Looooo`00_oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo03?ooooo0ol0001Pooooo`00`?ooool00ol0003o
ooooooooo`0<ooooo`03o`000?oooooooooo02oooooo1?l0001Sooooo`00`Oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo02_ooooo1?l0001Wooooo`00`_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo02Sooooo0ol0001[ooooo`00`oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo02Cooooo1?l0001^ooooo`00a?ooool2o`0000Wooooo00?o0000oooo
ooooool08?ooool4o`0007;ooooo0036ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool07Oooool3o`0007Kooooo0037ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
6Oooool4o`0007Wooooo0038ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05Ooo
ool4o`0007gooooo0039ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04Oooool4
o`00087ooooo003:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03_ooool3o`00
08Gooooo003;ooooo`05o`000?ooooooooooooooool000003?ooool4o`0008Sooooo003<ooooo`04
o`000?ooooooooooo`0000Sooooo1?l0002<ooooo`00cOooool00ol0003oooooo`000005ooooo`?o
0000T?ooool00<kooooo0_l000000ooooooo0000o`000002o`0009?ooooo003?ooooo`;o0000Uooo
ool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {330.375, 0}} -> {-0.0771432, -0.0315529, \
0.00350368, 0.00350368}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .92059 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-16 1.0763 -0.0263982 1.0763 [
[.01694 .18568 -11.9631 -9 ]
[.01694 .18568 .03693 0 ]
[.13793 .13897 -11.619 -9 ]
[.13793 .13897 .38095 0 ]
[.26292 .09073 -5.63752 -9 ]
[.26292 .09073 .36248 0 ]
[.39212 .04087 -5.46552 -9 ]
[.39212 .04087 .53448 0 ]
[.52574 -0.01069 -5.29351 -9 ]
[.52574 -0.01069 .70649 0 ]
[.58272 .04263 0 -6.19654 ]
[.58272 .04263 6 2.80346 ]
[.71715 .21863 0 -6.07114 ]
[.71715 .21863 6 2.92886 ]
[.83675 .37523 0 -5.963 ]
[.83675 .37523 6 3.037 ]
[.94385 .51546 0 -5.8688 ]
[.94385 .51546 6 3.1312 ]
[.01386 .20006 -12 -2.76892 ]
[.01386 .20006 0 6.23108 ]
[.00748 .25499 -24 -2.80073 ]
[.00748 .25499 0 6.19927 ]
[.00093 .31131 -6 -2.83339 ]
[.00093 .31131 0 6.16661 ]
[-0.00579 .36907 -18 -2.86695 ]
[-0.00579 .36907 0 6.13305 ]
[-0.01268 .42831 -6 -2.90143 ]
[-0.01268 .42831 0 6.09857 ]
[ 0 0 0 0 ]
[ 1 .92059 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02642 .19522 m
.53391 0 L
s
.02642 .19522 m
.03116 .2 L
s
[(-2)] .01694 .18568 .99384 1 Mshowa
.14712 .14879 m
.15172 .1537 L
s
[(-1)] .13793 .13897 .93651 1 Mshowa
.2718 .10083 m
.27624 .10588 L
s
[(0)] .26292 .09073 .87917 1 Mshowa
.40066 .05126 m
.40493 .05646 L
s
[(1)] .39212 .04087 .82184 1 Mshowa
.53391 0 m
.538 .00534 L
s
[(2)] .52574 -0.01069 .7645 1 Mshowa
.125 Mabswid
.05025 .18606 m
.05308 .18894 L
s
.07424 .17683 m
.07705 .17973 L
s
.09837 .16755 m
.10117 .17046 L
s
.12267 .1582 m
.12545 .16113 L
s
.17173 .13933 m
.17447 .14229 L
s
.19651 .1298 m
.19923 .13278 L
s
.22144 .1202 m
.22414 .1232 L
s
.24654 .11055 m
.24922 .11356 L
s
.29723 .09105 m
.29988 .0941 L
s
.32283 .0812 m
.32546 .08427 L
s
.3486 .07129 m
.35121 .07437 L
s
.37455 .06131 m
.37713 .06441 L
s
.42695 .04115 m
.4295 .04428 L
s
.45342 .03096 m
.45594 .03412 L
s
.48007 .02071 m
.48257 .02388 L
s
.5069 .01039 m
.50938 .01358 L
s
.25 Mabswid
.53391 0 m
.9804 .58403 L
s
.57014 .04738 m
.56384 .04975 L
s
[(0)] .58272 .04263 -1 .37701 Mshowa
.70445 .22307 m
.6981 .22529 L
s
[(2)] .71715 .21863 -1 .34914 Mshowa
.82396 .37939 m
.81756 .38147 L
s
[(4)] .83675 .37523 -1 .32511 Mshowa
.93098 .51938 m
.92454 .52134 L
s
[(6)] .94385 .51546 -1 .30418 Mshowa
.125 Mabswid
.60525 .09331 m
.60147 .09471 L
s
.63931 .13786 m
.63552 .13924 L
s
.67236 .1811 m
.66856 .18245 L
s
.73562 .26383 m
.7318 .26514 L
s
.7659 .30345 m
.76207 .30473 L
s
.79534 .34195 m
.7915 .34322 L
s
.85181 .41581 m
.84796 .41704 L
s
.87891 .45126 m
.87506 .45247 L
s
.90529 .48577 m
.90143 .48696 L
s
.95601 .55212 m
.95214 .55328 L
s
.25 Mabswid
.02642 .19522 m
0 .42381 L
s
.02642 .19522 m
.0327 .19281 L
s
[(-1)] .01386 .20006 1 -0.38468 Mshowa
.02006 .25024 m
.02635 .24786 L
s
[(-0.5)] .00748 .25499 1 -0.37762 Mshowa
.01354 .30664 m
.01985 .3043 L
s
[(0)] .00093 .31131 1 -0.37036 Mshowa
.00686 .36448 m
.01318 .36218 L
s
[(0.5)] -0.00579 .36907 1 -0.3629 Mshowa
0 .42381 m
.00634 .42156 L
s
[(1)] -0.01268 .42831 1 -0.35524 Mshowa
.125 Mabswid
.02516 .20612 m
.02893 .20468 L
s
.0239 .21707 m
.02767 .21563 L
s
.02262 .22807 m
.0264 .22664 L
s
.02135 .23913 m
.02512 .2377 L
s
.01877 .26141 m
.02255 .25999 L
s
.01747 .27263 m
.02125 .27122 L
s
.01617 .28391 m
.01995 .2825 L
s
.01486 .29525 m
.01864 .29384 L
s
.01222 .31809 m
.01601 .3167 L
s
.01089 .3296 m
.01468 .32821 L
s
.00955 .34117 m
.01334 .33978 L
s
.00821 .35279 m
.012 .35141 L
s
.0055 .37622 m
.0093 .37485 L
s
.00414 .38803 m
.00793 .38666 L
s
.00276 .39989 m
.00656 .39853 L
s
.00139 .41182 m
.00519 .41047 L
s
.25 Mabswid
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.54154 .92059 L
s
.54154 .92059 m
.5414 .7134 L
s
.5414 .7134 m
.02642 .19522 L
s
.53391 0 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.53391 0 m
.02642 .19522 L
s
.5414 .7134 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.54154 .92059 L
s
.54154 .92059 m
.5414 .7134 L
s
0 0 m
1 0 L
1 .92059 L
0 .92059 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.41029 .67649 m
.44882 .65563 L
s
1 0 .6 r
.39293 .6421 m
.42841 .62255 L
s
.8 0 1 r
.37556 .60769 m
.40802 .58949 L
s
.2 0 1 r
.35819 .57327 m
.38769 .55647 L
s
0 .4 1 r
.34085 .53884 m
.36761 .52349 L
s
0 1 1 r
.32373 .50444 m
.34831 .49058 L
s
0 1 .4 r
.30722 .4701 m
.3305 .4577 L
s
.2 1 0 r
.29173 .43577 m
.31454 .42472 L
s
.8 1 0 r
.27733 .40125 m
.30013 .39134 L
s
1 .6 0 r
.2637 .36626 m
.28666 .35719 L
s
.8 1 0 r
.30013 .39134 m
.32232 .38088 L
s
1 .6 0 r
.28666 .35719 m
.30944 .34775 L
s
.2 1 0 r
.31454 .42472 m
.33598 .41299 L
s
0 1 .4 r
.3305 .4577 m
.35123 .4445 L
s
0 1 1 r
.34831 .49058 m
.36884 .47567 L
s
0 .4 1 r
.36761 .52349 m
.38904 .50661 L
s
.2 0 1 r
.38769 .55647 m
.41126 .53741 L
s
.8 0 1 r
.40802 .58949 m
.43452 .5682 L
s
1 0 .6 r
.42841 .62255 m
.45816 .59904 L
s
1 0 0 r
.44882 .65563 m
.48192 .62998 L
s
1 .6 0 r
.30944 .34775 m
.33197 .33808 L
s
.8 1 0 r
.32232 .38088 m
.34388 .37026 L
s
.2 1 0 r
.33598 .41299 m
.35617 .40131 L
s
0 1 .4 r
.35123 .4445 m
.36966 .43172 L
s
0 1 1 r
.36884 .47567 m
.3853 .46174 L
s
1 .6 0 r
.33197 .33808 m
.35436 .3284 L
s
.8 1 0 r
.34388 .37026 m
.36513 .35984 L
s
0 .4 1 r
.38904 .50661 m
.4039 .49139 L
s
.2 1 0 r
.35617 .40131 m
.37586 .39019 L
s
.2 0 1 r
.41126 .53741 m
.42566 .52057 L
s
0 1 .4 r
.36966 .43172 m
.38731 .41997 L
s
1 .6 0 r
.35436 .3284 m
.3768 .31891 L
s
.8 0 1 r
.43452 .5682 m
.44984 .54933 L
s
.8 1 0 r
.36513 .35984 m
.38648 .34989 L
s
0 1 1 r
.3853 .46174 m
.40034 .44951 L
s
1 0 .6 r
.45816 .59904 m
.47532 .57791 L
s
.2 1 0 r
.37586 .39019 m
.3958 .37985 L
s
1 0 0 r
.48192 .62998 m
.50133 .60654 L
s
0 .4 1 r
.4039 .49139 m
.41598 .47893 L
s
1 .6 0 r
.3768 .31891 m
.3995 .30975 L
s
0 1 .4 r
.38731 .41997 m
.40542 .40934 L
s
.8 1 0 r
.38648 .34989 m
.40825 .34054 L
s
.2 0 1 r
.42566 .52057 m
.43508 .50808 L
s
0 1 1 r
.40034 .44951 m
.41608 .43877 L
s
.2 1 0 r
.3958 .37985 m
.41641 .37037 L
s
1 .6 0 r
.3995 .30975 m
.42261 .30099 L
s
.8 0 1 r
.44984 .54933 m
.4577 .53672 L
s
.8 1 0 r
.40825 .34054 m
.43064 .33183 L
s
0 .4 1 r
.41598 .47893 m
.42871 .4684 L
s
0 1 .4 r
.40542 .40934 m
.42458 .39982 L
s
1 .6 0 r
.42261 .30099 m
.44626 .29268 L
s
.2 1 0 r
.41641 .37037 m
.43791 .36176 L
s
1 0 .6 r
.47532 .57791 m
.48278 .56491 L
s
0 1 1 r
.41608 .43877 m
.43334 .42933 L
s
.2 0 1 r
.43508 .50808 m
.44443 .49831 L
s
.8 1 0 r
.43064 .33183 m
.45377 .32379 L
s
0 1 .4 r
.42458 .39982 m
.44495 .39138 L
s
0 .4 1 r
.42871 .4684 m
.44345 .45928 L
s
1 0 0 r
.50133 .60654 m
.5091 .59294 L
s
.8 0 1 r
.4577 .53672 m
.46406 .52833 L
s
1 .6 0 r
.44626 .29268 m
.4705 .28478 L
s
.2 1 0 r
.43791 .36176 m
.46036 .35406 L
s
0 1 1 r
.43334 .42933 m
.45225 .42116 L
s
.2 0 1 r
.44443 .49831 m
.4559 .49001 L
s
.8 1 0 r
.45377 .32379 m
.47771 .31641 L
s
0 1 .4 r
.44495 .39138 m
.46652 .38407 L
s
1 0 .6 r
.48278 .56491 m
.48713 .55824 L
s
0 .4 1 r
.44345 .45928 m
.46035 .45155 L
s
1 .6 0 r
.4705 .28478 m
.49538 .27723 L
s
.2 1 0 r
.46036 .35406 m
.4838 .34724 L
s
.8 0 1 r
.46406 .52833 m
.47183 .52171 L
s
.8 1 0 r
.47771 .31641 m
.50248 .30963 L
s
0 1 1 r
.45225 .42116 m
.47264 .41433 L
s
1 0 0 r
.59425 .59544 m
.65229 .59347 L
s
.54832 .59199 m
.59425 .59544 L
s
.2 0 1 r
.4559 .49001 m
.46998 .48308 L
s
0 1 .4 r
.46652 .38407 m
.48925 .37789 L
s
1 0 0 r
.65229 .59347 m
.70744 .58606 L
s
1 0 .6 r
.48713 .55824 m
.49137 .55418 L
s
1 0 0 r
.5091 .59294 m
.5121 .58807 L
s
.2 1 0 r
.4838 .34724 m
.50826 .34129 L
s
1 .6 0 r
.49538 .27723 m
.52087 .2699 L
s
1 0 0 r
.52391 .58833 m
.54832 .59199 L
s
.8 0 1 r
.47183 .52171 m
.48201 .51626 L
s
0 .4 1 r
.46035 .45155 m
.47907 .44535 L
s
1 0 .6 r
.59551 .55615 m
.64814 .55432 L
s
.55442 .55305 m
.59551 .55615 L
s
.8 1 0 r
.50248 .30963 m
.52816 .30331 L
s
0 1 1 r
.47264 .41433 m
.49432 .4089 L
s
1 0 .6 r
.64814 .55432 m
.6992 .54734 L
s
.49137 .55418 m
.49674 .55114 L
s
1 0 0 r
.51511 .58713 m
.52391 .58833 L
s
.2 0 1 r
.46998 .48308 m
.48619 .47778 L
s
0 1 .4 r
.48925 .37789 m
.5131 .37288 L
s
1 0 .6 r
.53112 .54965 m
.55442 .55305 L
s
1 0 0 r
.5121 .58807 m
.51307 .58704 L
s
.51307 .58704 m
.51511 .58713 L
s
.51296 .58704 m
.51307 .58704 L
s
.51313 .58699 m
.51296 .58704 L
s
.51307 .58704 m
.51313 .58699 L
s
.8 0 1 r
.59674 .51674 m
.64399 .51503 L
s
.56016 .51414 m
.59674 .51674 L
s
.2 1 0 r
.50826 .34129 m
.53383 .3361 L
s
.8 0 1 r
.48201 .51626 m
.4943 .5123 L
s
1 0 .6 r
.49674 .55114 m
.50337 .54904 L
s
0 .4 1 r
.47907 .44535 m
.49917 .44085 L
s
1 .6 0 r
.52087 .2699 m
.54691 .26262 L
s
.8 0 1 r
.64399 .51503 m
.69094 .5085 L
s
1 0 .6 r
.51896 .54817 m
.53112 .54965 L
s
0 1 1 r
.49432 .4089 m
.51715 .40497 L
s
.8 0 1 r
.53729 .51123 m
.56016 .51414 L
s
1 0 .6 r
.50337 .54904 m
.51071 .54805 L
s
.8 1 0 r
.52816 .30331 m
.55473 .29722 L
s
0 1 .4 r
.5131 .37288 m
.5382 .36895 L
s
1 0 .6 r
.51071 .54805 m
.51896 .54817 L
s
.2 0 1 r
.48619 .47778 m
.50373 .47441 L
s
.59777 .47734 m
.6398 .47564 L
s
.5648 .47554 m
.59777 .47734 L
s
.8 0 1 r
.4943 .5123 m
.50769 .51018 L
s
.2 1 0 r
.53383 .3361 m
.56068 .3314 L
s
.8 0 1 r
.52154 .50988 m
.53729 .51123 L
s
0 .4 1 r
.49917 .44085 m
.52027 .43817 L
s
.2 0 1 r
.6398 .47564 m
.68266 .46955 L
s
.54129 .47358 m
.5648 .47554 L
s
0 1 1 r
.51715 .40497 m
.54122 .40249 L
s
.8 0 1 r
.50769 .51018 m
.52154 .50988 L
s
0 1 .4 r
.5382 .36895 m
.56493 .36584 L
s
.2 0 1 r
.50373 .47441 m
.52196 .47306 L
s
1 .6 0 r
.54691 .26262 m
.57335 .25515 L
s
.2 0 1 r
.52196 .47306 m
.54129 .47358 L
s
0 .4 1 r
.59809 .43826 m
.6355 .43625 L
s
.56735 .43774 m
.59809 .43826 L
s
.52027 .43817 m
.54249 .43726 L
s
.8 1 0 r
.55473 .29722 m
.58212 .29099 L
s
0 .4 1 r
.54249 .43726 m
.56735 .43774 L
s
0 1 1 r
.54122 .40249 m
.5673 .40116 L
s
.2 1 0 r
.56068 .3314 m
.58894 .32667 L
s
0 1 1 r
.5673 .40116 m
.59696 .39999 L
s
0 .4 1 r
.6355 .43625 m
.67434 .43052 L
s
0 1 .4 r
.56493 .36584 m
.59392 .36283 L
s
0 1 1 r
.59696 .39999 m
.63079 .39716 L
s
0 1 .4 r
.59392 .36283 m
.62521 .35876 L
s
.2 1 0 r
.58894 .32667 m
.61835 .32121 L
s
0 1 1 r
.63079 .39716 m
.66593 .39152 L
s
.8 1 0 r
.58212 .29099 m
.60998 .28425 L
s
1 .6 0 r
.57335 .25515 m
.59993 .24734 L
s
0 1 .4 r
.62521 .35876 m
.65725 .3528 L
s
.2 1 0 r
.61835 .32121 m
.64797 .31456 L
s
.8 1 0 r
.60998 .28425 m
.63777 .27677 L
s
1 .6 0 r
.59993 .24734 m
.62642 .23912 L
s
0 g
.25 Mabswid
.53391 0 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.53391 0 m
.02642 .19522 L
s
.02642 .19522 m
.53391 0 L
s
.02642 .19522 m
.03116 .2 L
s
[(-2)] .01694 .18568 .99384 1 Mshowa
.14712 .14879 m
.15172 .1537 L
s
[(-1)] .13793 .13897 .93651 1 Mshowa
.2718 .10083 m
.27624 .10588 L
s
[(0)] .26292 .09073 .87917 1 Mshowa
.40066 .05126 m
.40493 .05646 L
s
[(1)] .39212 .04087 .82184 1 Mshowa
.53391 0 m
.538 .00534 L
s
[(2)] .52574 -0.01069 .7645 1 Mshowa
.125 Mabswid
.05025 .18606 m
.05308 .18894 L
s
.07424 .17683 m
.07705 .17973 L
s
.09837 .16755 m
.10117 .17046 L
s
.12267 .1582 m
.12545 .16113 L
s
.17173 .13933 m
.17447 .14229 L
s
.19651 .1298 m
.19923 .13278 L
s
.22144 .1202 m
.22414 .1232 L
s
.24654 .11055 m
.24922 .11356 L
s
.29723 .09105 m
.29988 .0941 L
s
.32283 .0812 m
.32546 .08427 L
s
.3486 .07129 m
.35121 .07437 L
s
.37455 .06131 m
.37713 .06441 L
s
.42695 .04115 m
.4295 .04428 L
s
.45342 .03096 m
.45594 .03412 L
s
.48007 .02071 m
.48257 .02388 L
s
.5069 .01039 m
.50938 .01358 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 265.125},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001Bb000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00`oooool5o`000:3ooooo0033ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@0X?ooool00<Cooooo00?oV9RHob4Q8Oo^k^h0XOooool00<Gooooo00?oV9RH
ob4Q8Oo^k^h0X?ooool00<Kooooo00?oMgMgofIVI_ooool0Woooool00<Oooooo00?o0000oooooooo
ool0W_ooool00<?ooooo00Go0000okZj^_ooooooV9RHoa0@402Pooooo`00`oooool01OnHV9So410@
o`000?lQ8B7oc<c<0:3ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003;ooooo`;o0000Voooool00<Sooooo0ol000000ooooooo0000ooooo`2Jooooo`00a_oo
ool2o`0000Cooooo0_l0002Jooooo`00`oooool3o`0000Kooooo00?o0000ooooool00000VOooool0
0<3ooooo1?l00008ooooo`04o`000?ooooooooooo`0009Sooooo002Hooooo`Co000000?o410@oooo
ooooool07oooool2o`0000Cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0002H
ooooo`00V_ooool00ol0003oooooooooo`0Nooooo`?o00003_ooool01Ol0003ooooooooooooooooo
000009Oooooo002Jooooo`03o`000?oooooooooo01cooooo0_l0000Aooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0U?ooool009[ooooo00?o0000ooooooooool06Oooool3o`0000;o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo09?o
oooo002Jooooo`03o`000?oooooooooo01Kooooo0ol0000Fooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^08Kooooo002Jooooo`03o`00
0?oooooooooo01Cooooo0_l0000Iooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1oooool01OmgMgOoV9RHoooooonHV9SoMgMg08Kooooo002Jooooo`03o`000?oooooooooo017ooooo
0ol000000ooooooo0000ooooo`0Hooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1_ooool01Ol@413ooooooooooooooooo410@08Kooooo002Hooooo`03oeEEEOmVIVKo0000017ooooo
0_l0000Nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool01Ol0003ooooo
oooooooooooo000008Kooooo002Yooooo`?o00008?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000026ooooo`00Yoooool3o`0002;ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@
4100Q_ooool00:Cooooo0ol00002ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Q_ooool00:7ooooo
0ol0000Xooooo`03o`000?oooooooooo00Sooooo0_l00004ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h0Q_ooool009oooooo0_l0000[ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo
0000S_ooool009cooooo0ol000000ooooooo0000ooooo`0Zooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0S?ooool009[ooooo0_l00005ooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`2;ooooo`00Uoooool3o`0003;ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`2:ooooo`00K?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^02?ooooo0ol000000ooooooo0000ooooo`0booooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0ROooool006cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Qooooo`;o0000>?ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo08Wooooo001/ooooo`05oa0@4?oooooooooo
ooooool@41007_ooool3o`0003[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`28
ooooo`00K?ooool01Ol0003ooooooooooooooooo000001cooooo0ol0000looooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0Qoooool006cooooo00Go0000ooooooooooooooooo`00000I
ooooo`?o00000_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool0Q_ooool006cooooo00Go410@oooooooooooooooooa0@400Gooooo`;o0000@_ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo08Kooooo001/ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL05?ooool3o`0004Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`25
ooooo`00K?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^017ooooo0ol00002ooooo`03o`000?oooooo
oooo04;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`24ooooo`00P?ooool2o`00
04[ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`23ooooo`00OOooool3o`0004co
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`22ooooo`00Noooool2o`000003oooo
ool0003ooooo04cooooo00?o0000ooooooooool05?ooool2o`0008?ooooo001hooooo`?o0000DOoo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooo000008?ooooo001eooooo`?o0000E?ooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo083ooooo001cooooo`Co0000EOooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo07oooooo001`ooooo`?o00001?ooool00ol0003o
ooooooooo`1Booooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0Ooooool006kooooo
0_l0001Looooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0O_ooool004?ooooo1?l0
00000ol@413oooooooooo`0Qooooo`?o0000G_ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo07gooooo0015ooooo`03o`000?oooooooooo023ooooo0ol00003ooooo`03o`000?oooooo
oooo05_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1looooo`00>_ooool6o`00
00Gooooo00?o0000ooooooooool07_ooool2o`0006Cooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`1looooo`00AOooool00ol0003oooooooooo`0Kooooo`?o0000I_ooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo07_ooooo0015ooooo`03o`000?oooooooooo01Wooooo
0_l00002ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`1jooooo`00AOooool00ol0003oooooooooo`0Fooooo`?o0000Joooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo07Wooooo0015ooooo`03o`000?oooooooooo01Cooooo0_l0001^
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0NOooool004?ooooo00?oEEEEofIV
I_l000004oooool3o`000003ooooool0003ooooo06gooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`1hooooo`00E_ooool3o`0007?ooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`1gooooo`00E?ooool2o`0007Kooooo00?o0000ooooooooool07oooool2o`0007Sooooo
001Aooooo`?o000000?oooooo`000?ooool0MOooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo07Kooooo001?ooooo`;o0000Noooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo07Gooooo001<ooooo`?o0000OOooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
07Cooooo0019ooooo`Co0000Ooooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo07?o
oooo0017ooooo`;o00001?ooool00ol0003oooooooooo`1looooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool0L_ooool004Cooooo0ol00025ooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool0L_ooool001[ooooo1Ol0000Sooooo`?o0000Qoooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo077ooooo000Jooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@08?ooool3
o`0000?ooooo00?o0000ooooooooool0Q?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo073ooooo000Booooo`Ko00000oooool00onHV9So8B4Qonk^kP0Oooooo`;o0000SOooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo06oooooo000Looooo`03oiRHV?lQ8B7ok^k^01_o
oooo0ol0002?ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0Koooool001gooooo
00?oMgMgofIVI_ooool05oooool3o`0000?ooooo00?o0000ooooooooool0S?ooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooooooo06kooooo000Nooooo`03o`000?oooooooooo01Cooooo0_l0
002Eooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0KOooool001[ooooo00Go0000
okZj^_ooooooV9RHoa0@400Cooooo`?o0000Uoooool00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo06cooooo000Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`04Oooool2o`0000?ooooo00?o
0000ooooooooool0U?ooool00ol0003oooooooooo`0Zooooo`;o0000KOooool002gooooo0ol0002L
ooooo`03o`000?oooooooooo02[ooooo0_l0001]ooooo`00:_ooool3o`0009oooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`1Zooooo`00:?ooool2o`0000?ooooo00?o0000oooooooo
ool0W?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo06Wooooo000Uooooo`?o0000
Y?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo06Wooooo000Tooooo`03o`000?oo
oooooooo0:Gooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1Xooooo`006_ooool4
o`000003oa0@4?oooooooooo00?ooooo0_l0002Vooooo`03o`000?oooooooooo02oooooo00?o0000
ooooooooool0Ioooool001cooooo00?o0000ooooooooool01Oooool2o`000:Kooooo00?o0000oooo
ooooool0<?ooool00ol0003oooooooooo`1Vooooo`004Oooool6o`0000Gooooo00?o0000oooooooo
ool01?ooool4o`000:Gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`08ooooo`Go
0000FOooool001cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0002Tooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool01OnHV9So8B4Qonk^k_ooooooA4A4
05Wooooo000Looooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`2Qooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool01oooool00onHV9So
8B4Qonk^kP1Jooooo`007?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0X?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Oooooo
00?oV9RHob4Q8Oo^k^h0FOooool001cooooo00?o0000ooooooooool01?ooool2o`0000Gooooo00?o
0000ooooooooool0Woooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Oooooo00?o
MgMgofIVI_ooool0F?ooool001[ooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo09kooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo05Oooooo000Sooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0WOooool00ol0003oooooooooo`0eooooo`;o00001?ooool01Ol0003o^[ZjoooooonHV9So
410@05Wooooo000Sooooo`;o00002?ooool00ol0003oooooooooo`2Looooo`03o`000?oooooooooo
03?ooooo0_l000000ooooooo0000ooooo`03ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0FOooool0
02?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2Kooooo`03o`000?oooooooooo
03Oooooo00?o0000ooooooooool0Goooool002?ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`2Jooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0Goooool002?ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`2Hooooo`;o0000>_ooool00ol0003ooooo
ooooo`1Nooooo`008_ooool2o`0000gooooo00?o0000ooooooooool0U?ooool3o`000003ooooool0
003ooooo01cooooo0_ooV@0Looooo`03o`000?oooooooooo05gooooo000Rooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool0T?ooool3o`0000Gooooo00?o0000ooooooooool05oooool3
oonI01oooooo00?o0000ooooooooool0G?ooool002;ooooo00?o0000ooooooooool03_ooool00ol0
003oooooooooo`2<ooooo`?o00002Oooool00ol0003oooooooooo`0Cooooo`?ooiT08_ooool00ol0
003oooooooooo`1Looooo`008_ooool3o`0000oooooo00?o0000ooooooooool0R?ooool3o`0000go
oooo00?o0000ooooooooool03oooool3oonI02Kooooo00?o0000ooooooooool0Foooool002;ooooo
00?o0000ooooooooool04?ooool00ol0003oooooooooo`25ooooo`;o00004Oooool00ol0003ooooo
ooooo`0;ooooo`?ooiT0:_ooool00ol0003oooooooooo`1Jooooo`008_ooool00ol0003ooooooooo
o`0Aooooo`03o`000?oooooooooo087ooooo0ol0000Dooooo`03o`000?oooooooooo00Oooooo0ooo
V@0^ooooo`03o`000?oooooooooo05Wooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool0OOooool3o`0001Oooooo00?o0000ooooooooool00oooool4oonI037ooooo
00?o0000ooooooooool0FOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
NOooool3o`0001_ooooo00?o0000oonI0?ooV@000_ooV@0fooooo`03o`000?oooooooooo05Sooooo
0005o`0000;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool05Oooool00ol0003oooooooooo`1eooooo`?o00006oooool3oonI0003oooo
ool0003ooooo03Wooooo00?o0000ooooooooool0Eoooool000Oooooo00Go0000oooooooooooooooo
o`00000?ooooo`03ogMgMolb<S;ooooo00?ooooo00?o0000ooooooooool05_ooool00ol0003ooooo
ooooo`1aooooo`?o00006oooool3oonI00Gooooo00?o0000ooooooooool0=oooool2o`0005Sooooo
0007ooooo`05o`000?ooooooooooooooool000003?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Co
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`1^ooooo`;o00006oooool3oonI00Wo
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1Eooooo`001oooool01Ol@413ooooo
oooooooooooo410@00cooooo00?o0000ooooooooool01_ooool2o`0001Wooooo00?o0000oooooooo
ool0J_ooool3o`0001[ooooo0oooV@0=ooooo`03o`000?oooooooooo03Oooooo00?o0000oooooooo
ool0EOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1Vooooo`?o00006?ooool5oonI013o
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1Dooooo`001oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool0H_ooool3o`0001Sooooo0oooV@0Fooooo`03o`000?oooooooooo01;ooooo0oo<o`0Sooooo`03
o`000?oooooooooo05?ooooo000Qooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0
G_ooool3o`0001Sooooo0oooV@0Jooooo`03o`000?oooooooooo00cooooo1Oo<o`0Wooooo`03o`00
0?oooooooooo05;ooooo000Pooooo`?o00007Oooool00ol0003oooooooooo`1Kooooo`;o00006?oo
ool3oonI01kooooo00?o0000ooooooooool02?ooool3olco02cooooo00?o0000ooooooooool0D_oo
ool0027ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1Gooooo`?o00005oooool3
oonI02;ooooo00?o0000ooooooooool01?ooool3olco033ooooo00?o0000ooooooooool0DOooool0
023ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`1Cooooo`?o00005_ooool4oonI
02Kooooo00?o0000ooooooooool00oo<o`0dooooo`03o`000?oooooooooo053ooooo000Pooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool0Coooool3o`0001Kooooo0oooV@0Yooooo`04
olco0?l0003oc?l0olco03Sooooo00?o0000ooooooooool0Coooool0023ooooo0_l0000Rooooo`03
o`000?oooooooooo04_ooooo0ol0000Fooooo`?ooiT09oooool5olco00;ooooo00?o0000oooooooo
ool0=oooool00ol0003oooooooooo`1?ooooo`008?ooool00ol0003oooooooooo`0Rooooo`03o`00
0?oooooooooo04Sooooo0_l0000Fooooo`?ooiT09_ooool4olco00Sooooo00?o0000ooooooooool0
=oooool00ol0003oooooooooo`1>ooooo`008?ooool00ol0003oooooooooo`0Sooooo`03o`000?oo
oooooooo04Cooooo0ol0000Fooooo`;ooiT09?ooool5olco00gooooo00?o0000ooooooooool0=ooo
ool00ol0003oooooooooo`1=ooooo`008?ooool3o`0002Cooooo00?o0000ooooooooool0@?ooool3
o`0001Kooooo0oooV@0Rooooo`Coc?l04oooool00ol0003oooooooooo`0fooooo`;o0000C_ooool0
023ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0looooo`?o00005_ooool3oonI
027ooooo1?o<o`0Hooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0C?ooool001Co
oooo00Gok^k^oc8b<_l0003o<S8bonk^kP07ooooo`03o`000?oooooooooo02Kooooo00?o0000oooo
ooooool0>?ooool3o`0001Oooooo0_ooV@0Pooooo`Coc?l07?ooool00ol0003oooooooooo`0goooo
o`03o`000?oooooooooo04_ooooo000Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0
003oooooooooo`0Xooooo`03o`000?oooooooooo03Gooooo0_l0000Gooooo`?ooiT07Oooool5olco
027ooooo00?o0000ooooooooool03?ooool3oc?o02Sooooo00?o0000ooooooooool0B_ooool001Co
oooo00Go410@oooooooooooooooooa0@4006ooooo`;o0000:_ooool00ol0003oooooooooo`0aoooo
o`?o00005oooool2oonI01cooooo1?o<o`0Wooooo`03o`000?oooooooooo00Sooooo0olco`0/oooo
o`03o`000?oooooooooo04Wooooo000Dooooo`05o`000?ooooooooooooooool000001_ooool00ol0
003oooooooooo`0Zooooo`03o`000?oooooooooo02gooooo0ol0000Hooooo`;ooiT06_ooool4olco
02cooooo00?o0000ooooooooool01?ooool3oc?o02oooooo00?o0000ooooooooool0BOooool001Co
oooo00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo02_ooooo00?o0000oooo
ooooool0:Oooool3o`0001Sooooo0oooV@0Iooooo`?oc?l0<?ooool00olco`3o0000oc?o0004oc?o
03?ooooo00?o0000ooooooooool0B?ooool001Cooooo00Go410@oooooooooooooooooa0@4006oooo
o`03o`000?oooooooooo02cooooo00?o0000ooooooooool09Oooool3o`0001Sooooo0oooV@0Ioooo
o`?oc?l0;?ooool7oc?o00;ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`17oooo
o`005?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo0_l0000^ooooo`03o`000?oooooooooo
027ooooo0ol0000Iooooo`;ooiT06_ooool2olco02[ooooo1Olco`09ooooo`03o`000?oooooooooo
03Oooooo00?o0000ooooooooool0A_ooool001Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP06oooo
o`03o`000?oooooooooo02kooooo00?o0000ooooooooool07_ooool2o`0001Wooooo0oooV@0Joooo
o`;oc?l0:?ooool4oc?o00oooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`15oooo
o`007oooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo01[ooooo0ol0000Iooooo`;o
oiT06_ooool3olco02Gooooo1Olco`0Dooooo`03o`000?oooooooooo03Kooooo00?o0000oooooooo
ool0AOooool001kooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Fooooo`?o0000
6_ooool2oonI01Wooooo0oo<o`0Rooooo`Ko<ol06_ooool00ol0003oooooooooo`0fooooo`03o`00
0?oooooooooo04Cooooo000Nooooo`;o0000<oooool00ol0003oooooooooo`0Booooo`?o00006_oo
ool3oonI01Wooooo0_o<o`0Oooooo`Ko<ol08Oooool00ol0003oooooooooo`0fooooo`;o0000A?oo
ool001kooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0>ooooo`?o00006oooool2
oonI01Wooooo0oo<o`0Looooo`Go<ol0:?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooo
000004Cooooo000Nooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool02oooool2o`00
01cooooo0_ooV@0Iooooo`;oc?l06oooool4oc?o02gooooo00?o0000ooooooooool0=_ooool00ol0
003oooooooooo`12ooooo`007_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00Oo
oooo0ol0000Looooo`;ooiT06Oooool2olco01[ooooo0olco`0booooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool0@Oooool001kooooo0_l0000gooooo`03o`000?oooooooooo00?ooooo
0ol0000Mooooo`;ooiT06?ooool3olco01Wooooo0olco`0fooooo`03o`000?oooooooooo00?ooooo
1?l0ofH_ooooo`03o`000?oooooooooo043ooooo000Nooooo`03o`000?oooooooooo03Oooooo00?o
0000ooooool000000_l0000Nooooo`;ooiT06?ooool2olco01Wooooo0olco`0jooooo`03o`000?l0
ofKo0?mV00;o0?mV=?ooool00ol0003oooooooooo`0oooooo`007_ooool00ol0003oooooooooo`0f
ooooo`?o00007oooool2oonI01Sooooo0_o<o`0Hooooo`?o<ol0=Oooool8o`3oIP03ooooool0003o
oooo03Kooooo00?o0000ooooooooool0?oooool001kooooo0_l0000eooooo`;o00000oooool00ol0
003oooooooooo`0Iooooo`?ooiT06?ooool2olco01Sooooo0_lco`0^ooooo`[o0?mV2_ooool00ol0
003oooooooooo`0eooooo`03o`000?oooooooooo00Wooooo0_l000000ol@413oooooooooo`0`oooo
o`007Oooool00ol0003oooooooooo`0booooo`?o00001_ooool00ol0003oooooooooo`0Eooooo`?o
oiT06_ooool00oo<o`3oooooooooo`0Eooooo`?o<ol09oooool9o`3oIQCooooo00?o0000oooooooo
ool0=_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo037ooooo0002ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo02oooooo0ol0000:ooooo`03o`000?oooooooooo01?ooooo00?ooiT0oooo
ooooool06Oooool2olco01Kooooo0_lco`0Sooooo`Oo0?mV7_ooool00ol0003oooooooooo`0foooo
o`03o`000?oooooooooo00Gooooo1Ol0000booooo`000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0;?ooool3o`00
00kooooo00?o0000ooooooooool0;?ooool2olco01Kooooo0_lco`0Qooooo`Co0?mV9_ooool00ol0
003oooooooooo`0eooooo`03o`000?oooooooooo00Gooooo00CoA4A4omgMgOoooooo0000<oooool0
00;ooooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo0_l0000Z
ooooo`?o00004_ooool00ol0003oooooooooo`0Xooooo`?oc?l05Oooool3oc?o01gooooo1_l0ofH[
ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool01?ooool01?oMgMgoEEEEooooool0
000cooooo`000_ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool01?oo
ool00ol0003oooooooooo`0Wooooo`;o00005_ooool00ol0003oooooooooo`0Uooooo`;oc?l05_oo
ool2oc?o01[ooooo1_l0ofHbooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool01?oo
ool00omgMgOoc<c<o`00000cooooo`000_ooool01Ol0003ooooooooooooooooo000000cooooo00Go
0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo02Cooooo0ol0000Iooooo`03o`00
0?oooooooooo02;ooooo0_o<o`0Fooooo`;o<ol06Oooool3o`3oISWooooo00?o0000ooooooooool0
=?ooool2o`0000Gooooo00?ok^k^odA4A?l00000<oooool000;ooooo00Go410@oooooooooooooooo
oa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08Oooool3o`0001gooooo
00?o0000ooooooooool07oooool2olco01Kooooo0_lco`0Hooooo`?o0?mV??ooool00ol0003ooooo
ooooo`0cooooo`04o`000?ooooooooooo`0000Gooooo00?oMgMgo`000?ooool0<_ooool000;ooooo
00GoMgMgoiRHV?ooooooV9RHogMgM`0<ooooo`03o`000?oooooooooo00Oooooo0_l0000Oooooo`?o
00008Oooool00ol0003oooooooooo`0Mooooo`03olco0?oooooooooo01Cooooo0_lco`0Gooooo`?o
0?mV@?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo03Sooooo0002ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000ooooooooool07?ooool3o`0002Go
oooo00?o0000ooooooooool06_ooool2olco01Gooooo0_lco`0Gooooo`;o0?mVA?ooool00ol0003o
ooooooooo`0eooooo`03o`000?oooooooooo03Oooooo000Looooo`03o`000?oooooooooo01Wooooo
0ol0000Yooooo`03o`000?oooooooooo01Oooooo0_o<o`0Eooooo`;o<ol05oooool2o`3oITGooooo
0_l0ool00ol0003o0?ooooooo`0eooooo`03o`000?oooooooooo03Kooooo000Looooo`03o`000?oo
oooooooo01Oooooo0_l0000]ooooo`03o`000?oooooooooo01?ooooo0oo<o`0Fooooo`03oc?o0?oo
oooooooo01Cooooo0ol0ofI1ooooo`Ko0?oo0oooool00ol0003oooooooooo`0eooooo`03o`000?oo
oooooooo03Gooooo000Looooo`;o00005Oooool3o`00033ooooo00?o0000ooooooooool03oooool3
olco01Oooooo0_lco`0Eooooo`;o0?mV??ooool8o`3oo`[ooooo00?o0000ooooooooool0=?ooool0
0ol0003oooooooooo`0eooooo`007?ooool00ol0003oooooooooo`0Aooooo`?o0000=?ooool00ol0
003oooooooooo`0=ooooo`03olco0?oooooooooo01Kooooo0_lco`0Eooooo`;o0?mV:_oooolDo`3o
oa;ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0dooooo`007?ooool00ol0003o
ooooooooo`0>ooooo`?o0000>?ooool00ol0003oooooooooo`0Sooooo`;o<ol05?ooool3o`3oIQgo
oooo3ol0oolWooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0<oooool001cooooo
00?o0000ooooooooool02oooool3o`0003cooooo00?o0000ooooooooool08Oooool00olco`3ooooo
ooooo`0Booooo`;o0?mV7Oooool3o`3oocOooooo00?o0000ooooooooool0=Oooool00ol0003ooooo
ooooo`0booooo`007?ooool2o`0000[ooooo0_l00010ooooo`03o`000?oooooooooo01kooooo0_lc
o`0Cooooo`;o0?mV6_ooool5o`3ooc_ooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0booooo`006oooool2o`0000Sooooo0ol00013ooooo`03o`000?oooooooooo01_ooooo0_lco`0C
ooooo`;o0?mV5oooool5o`3ood7ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0a
ooooo`006oooool00ol0003oooooooooo`04ooooo`?o0000Aoooool00ol0003oooooooooo`0Hoooo
o`;o<ol04oooool2o`3oIQKooooo0ol0oom7ooooo`03o`000?oooooooooo03?ooooo0_l0000boooo
o`006oooool01?l0003oooooooooooooool3o`0004_ooooo00?o0000ooooooooool05_ooool00olc
o`3oooooooooo`0Aooooo`;o0?mV5_ooool2o`3ood[ooooo00?o0000ooooooooool0=Oooool00ol0
003oooooooooo`0_ooooo`006oooool4o`0004oooooo00?o0000ooooooooool04oooool2oc?o01?o
oooo00?o0?mVooooooooool05?ooool2o`3oodgooooo00?o0000ooooooooool0=?ooool00ol0003o
ooooooooo`0_ooooo`006oooool2o`0005;ooooo00?o0000ooooooooool04?ooool2oc?o01Cooooo
00?o0?mVooooooooool04_ooool3o`3ooe3ooooo00?o0000ooooooooool0=?ooool00ol0003ooooo
ooooo`0^ooooo`004Oooool4o`000003oa0@4?oooooooooo00Gooooo00?o0000ooooooooool0D?oo
ool00ol0003oooooooooo`0=ooooo`;o<ol05Oooool00ol0ofKoooooooooo`0@ooooo`?o0?ooE?oo
ool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02gooooo000Cooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0;ooooo`03oc?o0?oooooo
oooo01?ooooo0_l0ofHBooooo`03o`3ooooooooooooo04cooooo1?l0I_l6ooooo`03o`000?oooooo
oooo03Cooooo00?o0000ooooooooool0;?ooool001?ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`1@ooooo`03o`000?oooooooooo00Sooooo0_lco`0Dooooo`;o0?mV4_ooool2o`3o
odSooooo1ol0I_l;ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0;?ooool001?o
oooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo00Ko
oooo00?o<ol0ooooooooool04oooool00ol0ofKoooooooooo`0Aooooo`03o`3ooooooooooooo01_o
oooo;Ol0I_lBooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0:oooool001?ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo01Wooooo
0_l0ofHBooooo`;o0?oo6Oooool5o`1Vod3ooooo00?o0000ooooooooool0=?ooool00ol0003ooooo
ooooo`0Zooooo`004oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo053ooooo00?o
0000ooooooooool05_ooool2o`3oIQ;ooooo0_l0oolHooooo`?o06KoA_ooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo02Wooooo000Cooooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0D?ooool00ol0003oooooooooo`0Dooooo`03o`3oI_oooooooooo017ooooo00?o0?oo
ooooooooool05Oooool3o`1Vod[ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0X
ooooo`004Oooool00omEEEGoIVIVo`00000@ooooo`03o`000?oooooooooo053ooooo00?o0000oooo
ooooool04_ooool00ol0ofKoooooooooo`0@ooooo`;o0?oo5Oooool3o`1Vodkooooo00?o0000oooo
ooooool0<oooool00ol0003oooooooooo`0Xooooo`009Oooool00ol0003oooooooooo`1@ooooo`03
o`000?oooooooooo013ooooo00?o0?mVooooooooool04?ooool00ol0ooooooooooooo`0Booooo`?o
06KoD_ooool00ol0003oooooooooo`0booooo`;o0000:Oooool002Kooooo0_l0001Aooooo`03o`00
0?oooooooooo00kooooo00?o0?mVooooooooool04?ooool00ol0ooooooooooooo`0@ooooo`?o06Ko
EOooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02Kooooo000Xooooo`03o`000?oo
oooooooo04kooooo00?o0000ooooooooool03?ooool2o`3oIQ;ooooo00?o0?ooooooooooool03_oo
ool3o`1VoeWooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Uooooo`00:Oooool0
0ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00Wooooo0_l0ofHBooooo`;o0?oo3oooool2
o`1Voegooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Uooooo`00:_ooool00ol0
003oooooooooo`1>ooooo`03o`000?oooooooooo00Kooooo0_l0ofHCooooo`03o`3ooooooooooooo
00kooooo00?o06Koooooooooool0G_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo
02Cooooo000[ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool00oooool2o`3oIQCo
oooo00?o0?ooooooooooool03_ooool00ol0I_ooooooooooo`1Pooooo`03o`000?oooooooooo03?o
oooo00?o0000ooooooooool08oooool002cooooo00?o0000ooooooooool0C_ooool01Ol0003ooooo
oooooooooooo0?mV01Gooooo00?o0?ooooooooooool03_ooool00ol0I_ooooooooooo`1?ooooo`Co
<`3o3oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02;ooooo000]ooooo`03o`00
0?oooooooooo04kooooo00?o0000ooooooooool05Oooool00ol0ooooooooooooo`0>ooooo`03o`1V
oooooooooooo01Oooooo4_lc0?lPooooo`Oo<`3o4oooool00ol0003oooooooooo`0cooooo`03o`00
0?oooooooooo02;ooooo000^ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool04_oo
ool2o`3ooa3ooooo00?o06Koooooooooool05Oooool3oc<0oa;ooooo8?lc0?lKooooo`03o`000?oo
oooooooo03?ooooo00?o0000ooooooooool08Oooool002oooooo00?o0000ooooooooool0C_ooool0
0ol0003oooooooooo`0@ooooo`03o`3ooooooooooooo00oooooo00?o06Koooooooooool04_ooool4
oc<0oe7ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Pooooo`00<?ooool00ol0
003oooooooooo`1>ooooo`03o`000?oooooooooo00gooooo0_l0oolAooooo`03o`1Voooooooooooo
00oooooo1?lc0?mFooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool07oooool0037o
oooo0_l0001?ooooo`03o`000?oooooooooo00_ooooo00?o0?ooooooooooool04?ooool00ol0I_oo
ooooooooo`0>ooooo`;o<`3oFoooool00ol0003oooooooooo`0booooo`;o00008?ooool003?ooooo
00?o0000ooooooooool0COooool00ol0003oooooooooo`09ooooo`03o`3ooooooooooooo013ooooo
00?o06Koooooooooool03_ooool00olc0?ooooooooooo`1Looooo`03o`000?oooooooooo037ooooo
0_l0000Pooooo`00=?ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo00Kooooo0_l0
oolBooooo`03o`1Voooooooooooo00gooooo0_lc0?mOooooo`03o`000?oooooooooo03?ooooo00?o
0000ooooooooool07Oooool003Gooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`03
ooooo`;o0?oo4oooool00ol0I_ooooooooooo`0<ooooo`;o<`3oH_ooool00ol0003oooooooooo`0c
ooooo`03o`000?oooooooooo01cooooo000fooooo`03o`000?oooooooooo04gooooo00?o0000oooo
ooooool00_l0oolDooooo`03o`1Voooooooooooo00cooooo00?o<`3oooooooooool0Hoooool00ol0
003oooooooooo`0booooo`03o`000?oooooooooo01cooooo000gooooo`03o`000?oooooooooo04go
oooo0_l0oolEooooo`03o`1Voooooooooooo00gooooo00?o<`3oooooooooool0I?ooool00ol0003o
ooooooooo`0booooo`03o`000?oooooooooo01_ooooo000hooooo`03o`000?oooooooooo04_ooooo
00?o0?ooooooool000005?ooool00ol0I_ooooooooooo`0=ooooo`03oc<0oooooooooooo06Kooooo
00?o0000ooooooooool0<_ooool00ol0003oooooooooo`07ooooo`05onk^k_lb<S;o0000oa0@4?o<
c<`03_ooool003Wooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0?ooooo`;o06Ko
3oooool00olc0?ooooooooooo`1Xooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0
1_ooool01OmEEEGoMgMgoooooonHV9So8B4Q00kooooo000jooooo`03o`000?oooooooooo04gooooo
00?o0000ooooooooool03Oooool00ol0I_ooooooooooo`0>ooooo`03oc<0oooooooooooo01?ooooo
2oo<0?l`ooooo`Goc03o5_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Gooooo
00Go0000ooooooooooooooooo`00000>ooooo`00>oooool00ol0003oooooooooo`1=ooooo`03o`00
0?oooooooooo00_ooooo00?o06Koooooooooool03oooool00olc0?ooooooooooo`0?ooooo`Coc03o
2oooool6ol`0ob;ooooo2?o<0?lLooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0
1Oooool01Ol0003oV9RHoooooonHV9So8B4Q00kooooo000looooo`03o`000?oooooooooo04gooooo
00?o0000ooooooooool02Oooool00ol0I_ooooooooooo`0?ooooo`03oc<0oooooooooooo00gooooo
0oo<0?lEooooob;oc03o9Oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00Cooooo
00Go0000oeEEEOl0003o410@olc<c00>ooooo`00?Oooool2o`0004kooooo00?o0000ooooooooool0
1oooool00ol0I_ooooooooooo`0?ooooo`03oc<0oooooooooooo00cooooo0_o<0?mPooooo`03o`00
0?oooooooooo03;ooooo0_l00004ooooo`03oeEEEOn7QhOooooo013ooooo000oooooo`03o`000?oo
oooooooo04cooooo00?o0000ooooooooool01Oooool00ol0I_ooooooooooo`0?ooooo`03oc<0oooo
oooooooo00cooooo00?oc03oooooooooool0HOooool00ol0003oooooooooo`0_ooooo`;o000000?o
ooooo`000?ooool00oooool00ooMgMgo410@oiRHV00@ooooo`00@?ooool00ol0003oooooooooo`1<
ooooo`03o`000?oooooooooo00;ooooo0_l0I_lAooooo`03oc<0oooooooooooo00cooooo00?oc03o
ooooooooool0Hoooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00?ooooo00Coc<c<
odA4A?l0003o410@3_ooool0047ooooo00?o0000ooooooooool0C?ooool01?l0003oooooo`1Vool0
I_lBooooo`03oc<0oooooooooooo00cooooo00?oc03oooooooooool0I?ooool00ol0003ooooooooo
o`0booooo`03o`000?oooooooooo01Cooooo0012ooooo`03o`000?oooooooooo04_ooooo0_l0I_lC
ooooo`03oc<0oooooooooooo00gooooo00?oc03oooooooooool0IOooool00ol0003oooooooooo`0b
ooooo`03o`000?oooooooooo01?ooooo0013ooooo`03o`000?oooooooooo04Wooooo00Co06Kooooo
oooooooo00004Oooool00olc0?ooooooooooo`0=ooooo`03ol`0oooooooooooo06Oooooo00?o0000
ooooooooool0<_ooool00ol0003oooooooooo`0Booooo`00A?ooool00ol0003oooooooooo`16oooo
o`;o06Ko1?ooool00ol0003oooooooooo`0=ooooo`03oc<0oooooooooooo00gooooo00?oc03ooooo
ooooool0JOooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo01;ooooo0015ooooo`03
o`000?oooooooooo04Cooooo00?o06Koooooooooool01Oooool00ol0003oooooooooo`0;ooooo`03
oc<0oooooooooooo00kooooo00?oc03oooooooooool0J_ooool00ol0003oooooooooo`0aooooo`03
o`000?oooooooooo017ooooo0016ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0
2Oooool00olc0?ooooooooooo`0>ooooo`03ol`0oooooooooooo06cooooo00?o0000ooooooooool0
<Oooool00ol0003oooooooooo`0@ooooo`00Aoooool00ol0003oooooooooo`1<ooooo`03o`000?oo
oooooooo00Oooooo00?o<`3oooooooooool03_ooool00oo<0?ooooooooooo`1]ooooo`03o`000?oo
oooooooo03;ooooo00?o0000ooooooooool03oooool004Sooooo0_l0001=ooooo`03o`000?oooooo
oooo00Gooooo00?o<`3oooooooooool03_ooool00oo<0?ooooooooooo`0>ooooo`ooo`2I;oooool5
ool0VAkooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0?ooooo`00B_ooool00ol0
003oooooooooo`1;ooooo`03o`000?oooooooooo00?ooooo00?o<`3oooooooooool03oooool00oo<
0?ooooooooooo`0<ooooo`;oo`2I3oooool;ool0VA_ooooo2Ooo09TTooooo`03o`000?oooooooooo
037ooooo0_l0000?ooooo`00Boooool00ol0003oooooooooo`1;ooooo`05o`000?oooooooooooooo
oolc0?l04Oooool00oo<0?ooooooooooo`0;ooooo`;oo`2I7?oooolKool0VBkooooo00?o0000oooo
ooooool0<?ooool2o`0000oooooo001<ooooo`03o`000?oooooooooo04_ooooo00?o0000oc<0oolc
0?l04Oooool00oo<0?ooooooooooo`0;ooooo`03ool0VOoooooooooo06Kooooo00?o0000oooooooo
ool0<Oooool00ol0003oooooooooo`0<ooooo`00COooool00ol0003oooooooooo`19ooooo`;o<`3o
00?o0000ooooooooool03oooool00oo<0?ooooooooooo`0<ooooo`03ool0VOoooooooooo06Oooooo
00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0;ooooo`00C_ooool00ol0003ooooooooo
o`16ooooo`;o<`3o0oooool00ol0003oooooooooo`0=ooooo`03ol`0oooooooooooo00cooooo00?o
o`2Iooooooooool0J?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00_ooooo001?
ooooo`03o`000?oooooooooo04?ooooo0_lc0?l6ooooo`03o`000?oooooooooo00[ooooo0_o<0?l?
ooooo`03ool0VOoooooooooo06Wooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0:
ooooo`00D?ooool00ol0003oooooooooo`10ooooo`;o<`3o2Oooool00ol0003oooooooooo`08oooo
o`03ol`0oooooooooooo00kooooo00?oo`2Iooooooooool0Joooool00ol0003oooooooooo`0aoooo
o`03o`000?oooooooooo00Wooooo001Aooooo`03o`000?oooooooooo03kooooo00?o<`3ooooooooo
ool02_ooool00ol0003oooooooooo`06ooooo`03ol`0oooooooooooo00oooooo00?oo`2Ioooooooo
ool0K?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Sooooo001Booooo`03o`00
0?oooooooooo04_ooooo00?o0000ooooooooool01?ooool00oo<0?ooooooooooo`0@ooooo`03ool0
VOoooooooooo06gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`08ooooo`00Dooo
ool2o`0004cooooo00?o0000ooooooooool00_ooool00oo<0?ooooooooooo`0@ooooo`03ool0VOoo
oooooooo06oooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`07ooooo`00EOooool0
0ol0003oooooooooo`1:ooooo`04o`000?oooooooooool`0oa?ooooo00?oo`2Iooooooooool0Kooo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Kooooo001Fooooo`03o`000?oooooo
oooo04[ooooo00?o0000ol`0ooooool04_ooool00ooo09Woooooooooo`18ooooo`Coo`009Oooool0
0ol0003oooooooooo`0_ooooo`?o00001oooool005Oooooo00?o0000ooooooooool0BOooool00oo<
0?oo0000ooooo`0Aooooo`03ool0VOoooooooooo00_ooooo2Ooo000^ooooo`Ooo`00:_ooool00ol0
003oooooooooo`0[ooooo`?o00000_ooool00ol0003oooooooooo`05ooooo`00F?ooool00ol0003o
ooooooooo`16ooooo`;oc03o0_ooool00ol0003oooooooooo`0>ooooo`03ool0VOoooooooooo00co
oooo00?oo`00ooooooooool01_ooool8ool0023ooooo1_oo000booooo`03o`000?oooooooooo02Oo
oooo0ol00005ooooo`03o`000?oooooooooo00Gooooo001Iooooo`03o`000?oooooooooo04?ooooo
0_o<0?l5ooooo`03o`000?oooooooooo00cooooo00?oo`2Iooooooooool03?ooool00ooo003ooooo
ooooo`0?ooooo`Ooo`003Oooool<ool003Wooooo00?o0000ooooooooool08_ooool4o`0000Sooooo
00?o0000ooooooooool01Oooool005[ooooo00?o0000ooooooooool0@Oooool00oo<0?oooooooooo
o`06ooooo`03o`000?oooooooooo00[ooooo00?oo`2Iooooooooool03Oooool00ooo003ooooooooo
o`0Fooooo`goo`00A_ooool00ol0003oooooooooo`0Nooooo`?o00003?ooool00ol0003ooooooooo
o`05ooooo`00Foooool00ol0003oooooooooo`0nooooo`;oc03o2_ooool00ol0003oooooooooo`07
ooooo`;oo`2I3oooool00ooo003oooooooooo`1Zooooo`03o`000?oooooooooo01[ooooo1?l0000?
ooooo`03o`000?oooooooooo00Gooooo001Looooo`03o`000?oooooooooo03_ooooo0_o<0?l=oooo
o`03o`000?oooooooooo00Gooooo00?oo`2Iooooooooool03_ooool00ooo003oooooooooo`1/oooo
o`03o`000?oooooooooo01Kooooo0ol0000Dooooo`03o`000?oooooooooo00Cooooo001Mooooo`03
o`000?oooooooooo03Wooooo00?oc03oooooooooool03_ooool00ol0003oooooooooo`02ooooo`;o
o`2I4?ooool00ooo003oooooooooo`1^ooooo`03o`000?oooooooooo01;ooooo0ol0000Gooooo`03
o`000?oooooooooo00Cooooo001Nooooo`;o0000>?ooool00oo<0?ooooooooooo`0@ooooo`04o`00
0?ooooooooooool0VA;ooooo00?oo`00ooooooooool0Koooool00ol0003oooooooooo`0=ooooo`Co
00006_ooool00ol0003oooooooooo`04ooooo`00H?ooool00ol0003oooooooooo`19ooooo`03o`00
0?oo09Wooooo017ooooo00?oo`00ooooooooool0LOooool00ol0003oooooooooo`09ooooo`?o0000
7_ooool00ol0003oooooooooo`04ooooo`00HOooool00ol0003oooooooooo`17ooooo`;oo`2I00?o
0000ooooooooool03oooool00ooo003oooooooooo`1cooooo`03o`000?oooooooooo00Cooooo1?l0
000Qooooo`03o`000?oooooooooo00Cooooo001Rooooo`03o`000?oooooooooo04Gooooo00Goo`2I
ooooooooooooooooo`00000?ooooo`03ool00?oooooooooo07Cooooo00Co0000oooooooooooooooo
0ol0000Uooooo`03o`000?oooooooooo00Cooooo001Sooooo`03o`000?oooooooooo04;ooooo0_oo
09T5ooooo`03o`000?oooooooooo00cooooo00?oo`00ooooooooool0MOooool3o`0002Sooooo00?o
0000ooooooooool01?ooool006Cooooo00?o0000ooooooooool0?oooool2ool0V@Sooooo00?o0000
ooooooooool02_ooool00ooo003oooooooooo`1booooo`Co000000?oooooo`000?ooool0:?ooool0
0ol0003oooooooooo`04ooooo`00IOooool00ol0003oooooooooo`0mooooo`03ool0VOoooooooooo
00Wooooo00?o0000ooooooooool02?ooool00ooo003oooooooooo`1`ooooo`?o00001_ooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo00Cooooo001Vooooo`03o`000?oooooooooo03[o
oooo0_oo09T=ooooo`03o`000?oooooooooo00Gooooo0_oo001_ooooo`Co00002_ooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo00Cooooo001Wooooo`03o`000?oooooooooo03Oooooo
0_oo09T@ooooo`03o`000?oooooooooo00?ooooo00?oo`00ooooooooool0K?ooool3o`0000oooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`03ooooo`00J?ooool00ol0003ooooooooo
o`0eooooo`03ool0VOoooooooooo017ooooo00Go0000ooooooooooooooooool0001/ooooo`?o0000
4_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00?ooooo001Yooooo`03o`000?oo
oooooooo03;ooooo0_oo09TEooooo`03o`000?oo003oo`0006Wooooo1?l0000Fooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool00oooool006[ooooo0_l0000aooooo`03ool0VOoooooo
oooo01Gooooo00?oo`00o`000?ooool0I_ooool3o`0001_ooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`03ooooo`00K?ooool00ol0003oooooooooo`14ooooo`;oo`000_ooool00ol0
003oooooooooo`1Pooooo`Co00007oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
00?ooooo001]ooooo`03o`000?oooooooooo04;ooooo00?oo`00ooooooooool00oooool00ol0003o
ooooooooo`1Looooo`?o00009?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00?o
oooo001^ooooo`03o`000?oooooooooo043ooooo00?oo`00ooooooooool01Oooool00ol0003ooooo
ooooo`1Hooooo`?o0000:?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00?ooooo
001_ooooo`03o`000?oooooooooo03gooooo0_oo0009ooooo`03o`000?oooooooooo05?ooooo1?l0
000[ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool00oooool0073ooooo00?o0000
ooooooooool0>_ooool2ool000cooooo00?o0000ooooooooool0Coooool3o`00033ooooo00?o0000
ooooooooool07oooool00ol0003oooooooooo`03ooooo`00LOooool00ol0003oooooooooo`0goooo
o`;oo`003oooool00ol0003oooooooooo`1:ooooo`Co0000=?ooool00ol0003oooooooooo`0Noooo
o`03o`000?oooooooooo00?ooooo001booooo`03o`000?oooooooooo03Cooooo0_oo000Booooo`03
o`000?oooooooooo04Kooooo0ol0000iooooo`03o`000?oooooooooo01kooooo00?o0000oooooooo
ool00_ooool007?ooooo00?o0000ooooooooool0<_ooool00ooo003oooooooooo`0Cooooo`03o`00
0?oooooooooo04;ooooo0ol0000mooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
0_ooool007Cooooo00?o0000ooooooooool0;oooool2ool001Oooooo00?o0000ooooooooool0?Ooo
ool4o`00047ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`02ooooo`00MOooool2
o`0002gooooo0_oo000Jooooo`03o`000?oooooooooo03Wooooo0ol00015ooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool00_ooool007Oooooo00?o0000ooooooooool0:Oooool00ooo
003oooooooooo`0Kooooo`03o`000?oooooooooo03Cooooo1?l00019ooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool00_ooool007Sooooo00?o0000ooooooooool0Aoooool00ol0003o
ooooooooo`0`ooooo`?o0000C_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00;o
oooo001iooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0;?ooool3o`0005;ooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`02ooooo`00N_ooool00ol0003ooooooooo
o`17ooooo`03o`000?oooooooooo02Oooooo1?l0001Fooooo`03o`000?oooooooooo01Sooooo00?o
0000ooooooooool00_ooool007_ooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0S
ooooo`?o0000Foooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00;ooooo001loooo
o`03o`000?oooooooooo04Oooooo00?o0000ooooooooool07_ooool4o`0005kooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`02ooooo`00OOooool00ol0003oooooooooo`17ooooo`03
o`000?oooooooooo01[ooooo0ol0001Sooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool00Oooool007kooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Fooooo`?o0000
Ioooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo007ooooo001oooooo`03o`000?oo
oooooooo04Oooooo00?o0000ooooooooool04Oooool4o`0006_ooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`01ooooo`00P?ooool2o`0004Sooooo00?o0000ooooooooool03Oooool3
o`00073ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`01ooooo`00P_ooool00ol0
003oooooooooo`16ooooo`03o`000?oooooooooo00Sooooo1?l0001dooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool00Oooool008?ooooo00?o0000ooooooooool0A_ooool00ol0003o
ooooooooo`04ooooo`?o0000N?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo007o
oooo0024ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool00ol0001looooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool00Oooool008Gooooo00?o0000ooooooooool0A_oo
ool2o`00083ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`01ooooo`00Q_ooool0
0ol0003oooooooooo`15ooooo`03o`000?oooooooooo083ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`01ooooo`00Qoooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo
087ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`01ooooo`00R?ooool00ol0003o
ooooooooo`13ooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool03oooool1o`00007o
oooo0Oooool008Wooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`22ooooo`03o`00
0?oooooooooo00oooooo0Ol00001ooooo`7ooooo002:ooooo`03o`000?oooooooooo047ooooo00?o
0000ooooooooool0Poooool00ol0003oooooooooo`0>ooooo`7o00000Oooool1ooooo`00Roooool2
o`00047ooooo00?o0000ooooooooool0Q?ooool00ol0003oooooooooo`0=ooooo`7o00000Oooool1
ooooo`00SOooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo08Gooooo00?o0000oooo
ooooool03?ooool1o`00007ooooo0Oooool008kooooo00?o0000ooooooooool0?Oooool00ol0003o
ooooooooo`26ooooo`03o`000?oooooooooo00_ooooo0Ol00001ooooo`7ooooo002?ooooo`03o`00
0?oooooooooo03cooooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`0:ooooo`7o0000
0Oooool1ooooo`00T?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo08Oooooo00?o
0000ooooooooool02_ooool1o`00007ooooo0Oooool0097ooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`28ooooo`03o`000?oooooooooo00Wooooo0Ol00001ooooo`7ooooo002Boooo
o`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`08oooo
o`7o00000Oooool1ooooo`00Toooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo08[o
oooo00?o0000ooooooooool02?ooool1o`00007ooooo002Dooooo`03o`000?oooooooooo03Oooooo
00?o0000ooooooooool0Roooool00ol0003oooooooooo`07ooooo`7o00000Oooool009Gooooo00?o
0000ooooooooool0=_ooool00ol0003oooooooooo`2<ooooo`03o`000?oooooooooo00Kooooo0Ol0
0001ooooo`00U_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo08cooooo00?o0000
ooooooooool01_ooool1o`00007ooooo002Gooooo`;o0000=Oooool00ol0003oooooooooo`2=oooo
o`03o`000?oooooooooo00Gooooo0Ol00001ooooo`00VOooool00ol0003oooooooooo`0booooo`03
o`000?oooooooooo08kooooo00?o0000ooooooooool01?ooool1o`00007ooooo002Jooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool0Soooool00ol0003oooooooooo`03ooooo`7o0000
0Oooool009_ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`2@ooooo`03o`000?oo
oooooooo00;ooooo0Ol00001ooooo`00W?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooo
oooo097ooooo00Go0000ooooooooooooooooo`000001ooooo`00WOooool00ol0003oooooooooo`0^
ooooo`03o`000?oooooooooo097ooooo00Go0000ooooooooooooooooo`000001ooooo`00W_ooool0
0ol0003oooooooooo`0]ooooo`03o`000?oooooooooo09;ooooo00Co0000oooooooooooooooo0Ol0
000009oooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`2Cooooo`03o`000?oooooo
oooo007o0000002Pooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0U?ooool1o`00
007ooooo0Ol000000:7ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`2Eooooo`;o
0000002Rooooo`;o0000:_ooool00ol0003oooooooooo`2Dooooo`?o0000002Tooooo`03o`000?oo
oooooooo02Oooooo00?o0000ooooooooool0T?ooool4o`0000?ooooo002Uooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool0SOooool3o`0000Oooooo002Vooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0ROooool4o`0000[ooooo002Wooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool0QOooool4o`0000kooooo002Xooooo`03o`000?oooooooooo02?ooooo
00?o0000ooooooooool0P_ooool3o`0001;ooooo002Yooooo`03o`000?oooooooooo02;ooooo00?o
0000ooooooooool0O_ooool4o`0001Gooooo002Zooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool0N_ooool4o`0001Wooooo002[ooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool0MOooool4o`0001gooooo002/ooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool0L_ooool3o`00027ooooo002]ooooo`;o00008?ooool00ol0003oooooooooo`1^ooooo`Co0000
9?ooool00:oooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1Zooooo`Co0000:?oo
ool00;3ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1Wooooo`?o0000;?ooool0
0;7ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Sooooo`Co0000;oooool00;;o
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1Oooooo`Co0000<oooool00;?ooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`1Looooo`?o0000=oooool00;Cooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`1Hooooo`Co0000>_ooool00;Gooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`1Dooooo`Co0000?_ooool00;Kooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`1@ooooo`Co0000@_ooool00;Oooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`1=ooooo`?o0000A_ooool00;Sooooo0_l0000Eooooo`03o`00
0?oooooooooo04Wooooo1?l00019ooooo`00^_ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo04Gooooo1?l0001=ooooo`00^oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo04;ooooo0ol0001Aooooo`00_?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
03kooooo1?l0001Dooooo`00_Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03[o
oooo1?l0001Hooooo`00__ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03Kooooo
1?l0001Looooo`00_oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03?ooooo0ol0
001Pooooo`00`?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02oooooo1?l0001S
ooooo`00`Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02_ooooo1?l0001Woooo
o`00`_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Sooooo0ol0001[ooooo`00
`oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02Cooooo1?l0001^ooooo`00a?oo
ool2o`0000Wooooo00?o0000ooooooooool08?ooool4o`0007;ooooo0036ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool07Oooool3o`0007Kooooo0037ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool06Oooool4o`0007Wooooo0038ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool05Oooool4o`0007gooooo0039ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool04Oooool4o`00087ooooo003:ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool03_ooool3o`0008Gooooo003;ooooo`05o`000?ooooooooooooooool000003?oo
ool4o`0008Sooooo003<ooooo`04o`000?ooooooooooo`0000Sooooo1?l0002<ooooo`00cOooool0
0ol0003oooooo`000005ooooo`?o0000T?ooool00<kooooo0_l000000ooooooo0000o`000002o`00
09?ooooo003?ooooo`;o0000Uoooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {330.375, 0}} -> {-0.0771432, -0.0315529, \
0.00350368, 0.00350368}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .92059 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-16 1.0763 -0.0263982 1.0763 [
[.01694 .18568 -11.9631 -9 ]
[.01694 .18568 .03693 0 ]
[.13793 .13897 -11.619 -9 ]
[.13793 .13897 .38095 0 ]
[.26292 .09073 -5.63752 -9 ]
[.26292 .09073 .36248 0 ]
[.39212 .04087 -5.46552 -9 ]
[.39212 .04087 .53448 0 ]
[.52574 -0.01069 -5.29351 -9 ]
[.52574 -0.01069 .70649 0 ]
[.58272 .04263 0 -6.19654 ]
[.58272 .04263 6 2.80346 ]
[.71715 .21863 0 -6.07114 ]
[.71715 .21863 6 2.92886 ]
[.83675 .37523 0 -5.963 ]
[.83675 .37523 6 3.037 ]
[.94385 .51546 0 -5.8688 ]
[.94385 .51546 6 3.1312 ]
[.01386 .20006 -12 -2.76892 ]
[.01386 .20006 0 6.23108 ]
[.00748 .25499 -24 -2.80073 ]
[.00748 .25499 0 6.19927 ]
[.00093 .31131 -6 -2.83339 ]
[.00093 .31131 0 6.16661 ]
[-0.00579 .36907 -18 -2.86695 ]
[-0.00579 .36907 0 6.13305 ]
[-0.01268 .42831 -6 -2.90143 ]
[-0.01268 .42831 0 6.09857 ]
[ 0 0 0 0 ]
[ 1 .92059 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02642 .19522 m
.53391 0 L
s
.02642 .19522 m
.03116 .2 L
s
[(-2)] .01694 .18568 .99384 1 Mshowa
.14712 .14879 m
.15172 .1537 L
s
[(-1)] .13793 .13897 .93651 1 Mshowa
.2718 .10083 m
.27624 .10588 L
s
[(0)] .26292 .09073 .87917 1 Mshowa
.40066 .05126 m
.40493 .05646 L
s
[(1)] .39212 .04087 .82184 1 Mshowa
.53391 0 m
.538 .00534 L
s
[(2)] .52574 -0.01069 .7645 1 Mshowa
.125 Mabswid
.05025 .18606 m
.05308 .18894 L
s
.07424 .17683 m
.07705 .17973 L
s
.09837 .16755 m
.10117 .17046 L
s
.12267 .1582 m
.12545 .16113 L
s
.17173 .13933 m
.17447 .14229 L
s
.19651 .1298 m
.19923 .13278 L
s
.22144 .1202 m
.22414 .1232 L
s
.24654 .11055 m
.24922 .11356 L
s
.29723 .09105 m
.29988 .0941 L
s
.32283 .0812 m
.32546 .08427 L
s
.3486 .07129 m
.35121 .07437 L
s
.37455 .06131 m
.37713 .06441 L
s
.42695 .04115 m
.4295 .04428 L
s
.45342 .03096 m
.45594 .03412 L
s
.48007 .02071 m
.48257 .02388 L
s
.5069 .01039 m
.50938 .01358 L
s
.25 Mabswid
.53391 0 m
.9804 .58403 L
s
.57014 .04738 m
.56384 .04975 L
s
[(0)] .58272 .04263 -1 .37701 Mshowa
.70445 .22307 m
.6981 .22529 L
s
[(2)] .71715 .21863 -1 .34914 Mshowa
.82396 .37939 m
.81756 .38147 L
s
[(4)] .83675 .37523 -1 .32511 Mshowa
.93098 .51938 m
.92454 .52134 L
s
[(6)] .94385 .51546 -1 .30418 Mshowa
.125 Mabswid
.60525 .09331 m
.60147 .09471 L
s
.63931 .13786 m
.63552 .13924 L
s
.67236 .1811 m
.66856 .18245 L
s
.73562 .26383 m
.7318 .26514 L
s
.7659 .30345 m
.76207 .30473 L
s
.79534 .34195 m
.7915 .34322 L
s
.85181 .41581 m
.84796 .41704 L
s
.87891 .45126 m
.87506 .45247 L
s
.90529 .48577 m
.90143 .48696 L
s
.95601 .55212 m
.95214 .55328 L
s
.25 Mabswid
.02642 .19522 m
0 .42381 L
s
.02642 .19522 m
.0327 .19281 L
s
[(-1)] .01386 .20006 1 -0.38468 Mshowa
.02006 .25024 m
.02635 .24786 L
s
[(-0.5)] .00748 .25499 1 -0.37762 Mshowa
.01354 .30664 m
.01985 .3043 L
s
[(0)] .00093 .31131 1 -0.37036 Mshowa
.00686 .36448 m
.01318 .36218 L
s
[(0.5)] -0.00579 .36907 1 -0.3629 Mshowa
0 .42381 m
.00634 .42156 L
s
[(1)] -0.01268 .42831 1 -0.35524 Mshowa
.125 Mabswid
.02516 .20612 m
.02893 .20468 L
s
.0239 .21707 m
.02767 .21563 L
s
.02262 .22807 m
.0264 .22664 L
s
.02135 .23913 m
.02512 .2377 L
s
.01877 .26141 m
.02255 .25999 L
s
.01747 .27263 m
.02125 .27122 L
s
.01617 .28391 m
.01995 .2825 L
s
.01486 .29525 m
.01864 .29384 L
s
.01222 .31809 m
.01601 .3167 L
s
.01089 .3296 m
.01468 .32821 L
s
.00955 .34117 m
.01334 .33978 L
s
.00821 .35279 m
.012 .35141 L
s
.0055 .37622 m
.0093 .37485 L
s
.00414 .38803 m
.00793 .38666 L
s
.00276 .39989 m
.00656 .39853 L
s
.00139 .41182 m
.00519 .41047 L
s
.25 Mabswid
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.54154 .92059 L
s
.54154 .92059 m
.5414 .7134 L
s
.5414 .7134 m
.02642 .19522 L
s
.53391 0 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.53391 0 m
.02642 .19522 L
s
.5414 .7134 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.54154 .92059 L
s
.54154 .92059 m
.5414 .7134 L
s
0 0 m
1 0 L
1 .92059 L
0 .92059 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.42816 .68807 m
.46956 .66584 L
s
1 0 .6 r
.41088 .65385 m
.44924 .63288 L
s
.8 0 1 r
.3936 .61961 m
.42892 .59996 L
s
.2 0 1 r
.37631 .58535 m
.40863 .56707 L
s
0 .4 1 r
.35902 .55108 m
.38839 .53421 L
s
0 1 1 r
.34176 .51681 m
.36841 .50139 L
s
0 1 .4 r
.32472 .48256 m
.34919 .46864 L
s
.2 1 0 r
.30829 .44837 m
.33146 .43593 L
s
.8 1 0 r
.29286 .4142 m
.31557 .40311 L
s
1 .6 0 r
.27853 .37984 m
.30124 .36989 L
s
.30124 .36989 m
.32333 .3594 L
s
.8 1 0 r
.31557 .40311 m
.33692 .39134 L
s
.2 1 0 r
.33146 .43593 m
.3521 .42268 L
s
0 1 .4 r
.34919 .46864 m
.36963 .45368 L
s
0 1 1 r
.36841 .50139 m
.38974 .48445 L
s
0 .4 1 r
.38839 .53421 m
.41186 .51507 L
s
.2 0 1 r
.40863 .56707 m
.43501 .54568 L
s
.8 0 1 r
.42892 .59996 m
.45854 .57635 L
s
1 0 .6 r
.44924 .63288 m
.48219 .60711 L
s
1 0 0 r
.46956 .66584 m
.50592 .63795 L
s
1 .6 0 r
.32333 .3594 m
.34479 .34874 L
s
.8 1 0 r
.33692 .39134 m
.35702 .37962 L
s
.2 1 0 r
.3521 .42268 m
.37045 .40985 L
s
0 1 .4 r
.36963 .45368 m
.38601 .4397 L
s
1 .6 0 r
.34479 .34874 m
.36594 .33829 L
s
0 1 1 r
.38974 .48445 m
.40453 .46917 L
s
.8 1 0 r
.35702 .37962 m
.37663 .36846 L
s
0 .4 1 r
.41186 .51507 m
.42619 .49817 L
s
.2 1 0 r
.37045 .40985 m
.38802 .39806 L
s
.2 0 1 r
.43501 .54568 m
.45026 .52674 L
s
1 .6 0 r
.36594 .33829 m
.38719 .32831 L
s
0 1 .4 r
.38601 .4397 m
.40099 .42742 L
s
.8 0 1 r
.45854 .57635 m
.47561 .55513 L
s
.8 1 0 r
.37663 .36846 m
.39647 .35809 L
s
1 0 .6 r
.48219 .60711 m
.50151 .58355 L
s
0 1 1 r
.40453 .46917 m
.41655 .45666 L
s
.2 1 0 r
.38802 .39806 m
.40605 .3874 L
s
1 0 0 r
.50592 .63795 m
.52762 .6121 L
s
1 .6 0 r
.38719 .32831 m
.40886 .31892 L
s
0 .4 1 r
.42619 .49817 m
.43557 .48562 L
s
0 1 .4 r
.40099 .42742 m
.41666 .41664 L
s
.8 1 0 r
.39647 .35809 m
.41699 .34857 L
s
.2 0 1 r
.45026 .52674 m
.45808 .51407 L
s
1 .6 0 r
.40886 .31892 m
.43115 .31019 L
s
0 1 1 r
.41655 .45666 m
.42922 .44609 L
s
.2 1 0 r
.40605 .3874 m
.42512 .37784 L
s
.8 1 0 r
.41699 .34857 m
.43839 .33994 L
s
.8 0 1 r
.47561 .55513 m
.48305 .54207 L
s
0 1 .4 r
.41666 .41664 m
.43384 .40717 L
s
0 .4 1 r
.43557 .48562 m
.44487 .47581 L
s
1 .6 0 r
.43115 .31019 m
.45418 .30212 L
s
.2 1 0 r
.42512 .37784 m
.44539 .36938 L
s
0 1 1 r
.42922 .44609 m
.4439 .43693 L
s
1 0 .6 r
.50151 .58355 m
.50924 .56989 L
s
.2 0 1 r
.45808 .51407 m
.46442 .50565 L
s
.8 1 0 r
.43839 .33994 m
.46073 .33221 L
s
0 1 .4 r
.43384 .40717 m
.45266 .39897 L
s
0 .4 1 r
.44487 .47581 m
.4563 .46749 L
s
1 .6 0 r
.45418 .30212 m
.47799 .29472 L
s
.2 1 0 r
.44539 .36938 m
.46687 .36203 L
s
1 0 0 r
.52762 .6121 m
.53594 .59778 L
s
.8 0 1 r
.48305 .54207 m
.48738 .53537 L
s
1 0 0 r
.59271 .61144 m
.65585 .60932 L
s
.54212 .60764 m
.59271 .61144 L
s
0 1 1 r
.4439 .43693 m
.46072 .42918 L
s
.8 1 0 r
.46073 .33221 m
.48406 .32537 L
s
.2 0 1 r
.46442 .50565 m
.47215 .499 L
s
1 0 0 r
.65585 .60932 m
.7148 .60145 L
s
.51648 .6038 m
.54212 .60764 L
s
1 .6 0 r
.47799 .29472 m
.50266 .28791 L
s
0 1 .4 r
.45266 .39897 m
.47295 .39211 L
s
1 0 .6 r
.59397 .57242 m
.65173 .57044 L
s
.54826 .56894 m
.59397 .57242 L
s
0 .4 1 r
.4563 .46749 m
.4703 .46052 L
s
.2 1 0 r
.46687 .36203 m
.48948 .35584 L
s
1 0 .6 r
.65173 .57044 m
.70662 .56299 L
s
.8 0 1 r
.48738 .53537 m
.4916 .53129 L
s
1 0 .6 r
.50924 .56989 m
.51222 .56501 L
s
.8 1 0 r
.48406 .32537 m
.5084 .3194 L
s
1 0 0 r
.51098 .60299 m
.51648 .6038 L
s
1 0 .6 r
.52397 .56527 m
.54826 .56894 L
s
.2 0 1 r
.47215 .499 m
.48228 .49352 L
s
0 1 1 r
.46072 .42918 m
.47936 .42296 L
s
1 0 0 r
.5153 .60305 m
.51098 .60299 L
s
.52275 .60212 m
.5153 .60305 L
s
.8 0 1 r
.59523 .53327 m
.64762 .53143 L
s
.55434 .53016 m
.59523 .53327 L
s
1 0 0 r
.53003 .59987 m
.52275 .60212 L
s
1 .6 0 r
.50266 .28791 m
.5282 .28158 L
s
0 1 .4 r
.47295 .39211 m
.49453 .38667 L
s
.8 0 1 r
.64762 .53143 m
.69843 .52442 L
s
.4916 .53129 m
.49694 .52824 L
s
1 0 .6 r
.51522 .56406 m
.52397 .56527 L
s
0 .4 1 r
.4703 .46052 m
.48644 .45521 L
s
.2 1 0 r
.48948 .35584 m
.51322 .35081 L
s
.8 0 1 r
.53115 .52674 m
.55434 .53016 L
s
1 0 .6 r
.51222 .56501 m
.51319 .56397 L
s
1 0 0 r
.53547 .5968 m
.53003 .59987 L
s
1 0 .6 r
.51318 .56397 m
.51522 .56406 L
s
.51308 .56398 m
.51318 .56397 L
s
.51325 .56393 m
.51308 .56398 L
s
.51319 .56397 m
.51325 .56393 L
s
.2 0 1 r
.59646 .49401 m
.64348 .49229 L
s
.56006 .4914 m
.59646 .49401 L
s
.8 1 0 r
.5084 .3194 m
.53385 .31419 L
s
.2 0 1 r
.48228 .49352 m
.49451 .48955 L
s
.8 0 1 r
.49694 .52824 m
.50354 .52613 L
s
1 0 0 r
.53594 .59778 m
.53775 .5947 L
s
0 1 1 r
.47936 .42296 m
.49936 .41844 L
s
.2 0 1 r
.64348 .49229 m
.69021 .48574 L
s
1 0 0 r
.53775 .5947 m
.53547 .5968 L
s
.8 0 1 r
.51905 .52526 m
.53115 .52674 L
s
0 1 .4 r
.49453 .38667 m
.51725 .38272 L
s
.2 0 1 r
.53729 .48848 m
.56006 .4914 L
s
.8 0 1 r
.50354 .52613 m
.51084 .52514 L
s
1 .6 0 r
.5282 .28158 m
.55465 .27547 L
s
.2 1 0 r
.51322 .35081 m
.5382 .34687 L
s
.8 0 1 r
.51084 .52514 m
.51905 .52526 L
s
0 .4 1 r
.48644 .45521 m
.5039 .45182 L
s
.59748 .45476 m
.63932 .45305 L
s
.56467 .45296 m
.59748 .45476 L
s
.2 0 1 r
.49451 .48955 m
.50783 .48742 L
s
.8 1 0 r
.53385 .31419 m
.56057 .30947 L
s
.2 0 1 r
.52162 .48712 m
.53729 .48848 L
s
0 1 1 r
.49936 .41844 m
.52035 .41574 L
s
0 .4 1 r
.63932 .45305 m
.68196 .44694 L
s
.54128 .45099 m
.56467 .45296 L
s
0 1 .4 r
.51725 .38272 m
.54121 .38023 L
s
.2 0 1 r
.50783 .48742 m
.52162 .48712 L
s
.2 1 0 r
.5382 .34687 m
.5648 .34375 L
s
0 .4 1 r
.5039 .45182 m
.52204 .45046 L
s
.52204 .45046 m
.54128 .45099 L
s
0 1 1 r
.5978 .41584 m
.63503 .41382 L
s
.56721 .41531 m
.5978 .41584 L
s
.52035 .41574 m
.54247 .41484 L
s
1 .6 0 r
.55465 .27547 m
.58191 .26922 L
s
0 1 1 r
.54247 .41484 m
.56721 .41531 L
s
0 1 .4 r
.54121 .38023 m
.56716 .3789 L
s
.8 1 0 r
.56057 .30947 m
.5887 .30473 L
s
0 1 .4 r
.56716 .3789 m
.59668 .37772 L
s
0 1 1 r
.63503 .41382 m
.67368 .40807 L
s
.2 1 0 r
.5648 .34375 m
.59365 .34073 L
s
0 1 .4 r
.59668 .37772 m
.63034 .37488 L
s
.2 1 0 r
.59365 .34073 m
.62479 .33664 L
s
.8 1 0 r
.5887 .30473 m
.61797 .29926 L
s
0 1 .4 r
.63034 .37488 m
.66531 .36923 L
s
1 .6 0 r
.58191 .26922 m
.60963 .26246 L
s
.2 1 0 r
.62479 .33664 m
.65667 .33066 L
s
.8 1 0 r
.61797 .29926 m
.64744 .29259 L
s
1 .6 0 r
.60963 .26246 m
.63728 .25496 L
s
0 g
.25 Mabswid
.53391 0 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.53391 0 m
.02642 .19522 L
s
.02642 .19522 m
.53391 0 L
s
.02642 .19522 m
.03116 .2 L
s
[(-2)] .01694 .18568 .99384 1 Mshowa
.14712 .14879 m
.15172 .1537 L
s
[(-1)] .13793 .13897 .93651 1 Mshowa
.2718 .10083 m
.27624 .10588 L
s
[(0)] .26292 .09073 .87917 1 Mshowa
.40066 .05126 m
.40493 .05646 L
s
[(1)] .39212 .04087 .82184 1 Mshowa
.53391 0 m
.538 .00534 L
s
[(2)] .52574 -0.01069 .7645 1 Mshowa
.125 Mabswid
.05025 .18606 m
.05308 .18894 L
s
.07424 .17683 m
.07705 .17973 L
s
.09837 .16755 m
.10117 .17046 L
s
.12267 .1582 m
.12545 .16113 L
s
.17173 .13933 m
.17447 .14229 L
s
.19651 .1298 m
.19923 .13278 L
s
.22144 .1202 m
.22414 .1232 L
s
.24654 .11055 m
.24922 .11356 L
s
.29723 .09105 m
.29988 .0941 L
s
.32283 .0812 m
.32546 .08427 L
s
.3486 .07129 m
.35121 .07437 L
s
.37455 .06131 m
.37713 .06441 L
s
.42695 .04115 m
.4295 .04428 L
s
.45342 .03096 m
.45594 .03412 L
s
.48007 .02071 m
.48257 .02388 L
s
.5069 .01039 m
.50938 .01358 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 265.125},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001Bb000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00`oooool5o`000:3ooooo0033ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@0X?ooool00<Cooooo00?oV9RHob4Q8Oo^k^h0XOooool00<Gooooo00?oV9RH
ob4Q8Oo^k^h0X?ooool00<Kooooo00?oMgMgofIVI_ooool0Woooool00<Oooooo00?o0000oooooooo
ool0W_ooool00<?ooooo00Go0000okZj^_ooooooV9RHoa0@402Pooooo`00`oooool01OnHV9So410@
o`000?lQ8B7oc<c<0:3ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003;ooooo`;o0000Voooool00<Sooooo0ol000000ooooooo0000ooooo`2Jooooo`00a_oo
ool2o`0000Cooooo0_l0002Jooooo`00`oooool3o`0000Kooooo00?o0000ooooool00000VOooool0
0<3ooooo1?l00008ooooo`04o`000?ooooooooooo`0009Sooooo002Hooooo`Co000000?o410@oooo
ooooool07oooool2o`0000Cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0002H
ooooo`00V_ooool00ol0003oooooooooo`0Nooooo`?o00003_ooool01Ol0003ooooooooooooooooo
000009Oooooo002Jooooo`03o`000?oooooooooo01cooooo0_l0000Aooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0U?ooool009[ooooo00?o0000ooooooooool06Oooool3o`0000;o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo09?o
oooo002Jooooo`03o`000?oooooooooo01Kooooo0ol0000Fooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^08Kooooo002Jooooo`03o`00
0?oooooooooo01Cooooo0_l0000Iooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1oooool01OmgMgOoV9RHoooooonHV9SoMgMg08Kooooo002Jooooo`03o`000?oooooooooo017ooooo
0ol000000ooooooo0000ooooo`0Hooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1_ooool01Ol@413ooooooooooooooooo410@08Kooooo002Hooooo`03oeEEEOmVIVKo0000017ooooo
0_l0000Nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool01Ol0003ooooo
oooooooooooo000008Kooooo002Yooooo`?o00008?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000026ooooo`00Yoooool3o`0002;ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@
4100Q_ooool00:Cooooo0ol00002ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Q_ooool00:7ooooo
0ol0000Xooooo`03o`000?oooooooooo00Sooooo0_l00004ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h0Q_ooool009oooooo0_l0000[ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo
0000S_ooool009cooooo0ol000000ooooooo0000ooooo`0Zooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0S?ooool009[ooooo0_l00005ooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`2;ooooo`00Uoooool3o`0003;ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`2:ooooo`00K?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^02?ooooo0ol000000ooooooo0000ooooo`0booooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0ROooool006cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Qooooo`;o0000>?ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo08Wooooo001/ooooo`05oa0@4?oooooooooo
ooooool@41007_ooool3o`0003[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`28
ooooo`00K?ooool01Ol0003ooooooooooooooooo000001cooooo0ol0000looooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0Qoooool006cooooo00Go0000ooooooooooooooooo`00000I
ooooo`?o00000_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool0Q_ooool006cooooo00Go410@oooooooooooooooooa0@400Gooooo`;o0000@_ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo08Kooooo001/ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL05?ooool3o`0004Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`25
ooooo`00K?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^017ooooo0ol00002ooooo`03o`000?oooooo
oooo04;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`24ooooo`00P?ooool2o`00
04[ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`23ooooo`00OOooool3o`0004co
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`22ooooo`00Noooool2o`000003oooo
ool0003ooooo04cooooo00?o0000ooooooooool05?ooool2o`0008?ooooo001hooooo`?o0000DOoo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooo000008?ooooo001eooooo`?o0000E?ooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo083ooooo001cooooo`Co0000EOooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo07oooooo001`ooooo`?o00001?ooool00ol0003o
ooooooooo`1Booooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0Ooooool006kooooo
0_l0001Looooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0O_ooool004?ooooo1?l0
00000ol@413oooooooooo`0Qooooo`?o0000G_ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo07gooooo0015ooooo`03o`000?oooooooooo023ooooo0ol00003ooooo`03o`000?oooooo
oooo05_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1looooo`00>_ooool6o`00
00Gooooo00?o0000ooooooooool07_ooool2o`0006Cooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`1looooo`00AOooool00ol0003oooooooooo`0Kooooo`?o0000I_ooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo07_ooooo0015ooooo`03o`000?oooooooooo01Wooooo
0_l00002ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`1jooooo`00AOooool00ol0003oooooooooo`0Fooooo`?o0000Joooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo07Wooooo0015ooooo`03o`000?oooooooooo01Cooooo0_l0001^
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0NOooool004?ooooo00?oEEEEofIV
I_l000004oooool3o`000003ooooool0003ooooo06gooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`1hooooo`00E_ooool3o`0007?ooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`1gooooo`00E?ooool2o`0007Kooooo00?o0000ooooooooool07oooool2o`0007Sooooo
001Aooooo`?o000000?oooooo`000?ooool0MOooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo07Kooooo001?ooooo`;o0000Noooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo07Gooooo001<ooooo`?o0000OOooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
07Cooooo0019ooooo`Co0000Ooooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo07?o
oooo0017ooooo`;o00001?ooool00ol0003oooooooooo`1looooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool0L_ooool004Cooooo0ol00025ooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool0L_ooool001[ooooo1Ol0000Sooooo`?o0000Qoooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo077ooooo000Jooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@08?ooool3
o`0000?ooooo00?o0000ooooooooool0Q?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo073ooooo000Booooo`Ko00000oooool00onHV9So8B4Qonk^kP0Oooooo`;o0000SOooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo06oooooo000Looooo`03oiRHV?lQ8B7ok^k^01_o
oooo0ol0002?ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0Koooool001gooooo
00?oMgMgofIVI_ooool05oooool3o`0000?ooooo00?o0000ooooooooool0S?ooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooooooo06kooooo000Nooooo`03o`000?oooooooooo01Cooooo0_l0
002Eooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0KOooool001[ooooo00Go0000
okZj^_ooooooV9RHoa0@400Cooooo`?o0000Uoooool00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo06cooooo000Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`04Oooool2o`0000?ooooo00?o
0000ooooooooool0U?ooool00ol0003oooooooooo`0Zooooo`;o0000KOooool002gooooo0ol0002L
ooooo`03o`000?oooooooooo02[ooooo0_l0001]ooooo`00:_ooool3o`0009oooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`1Zooooo`00:?ooool2o`0000?ooooo00?o0000oooooooo
ool0W?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo06Wooooo000Uooooo`?o0000
Y?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo06Wooooo000Tooooo`03o`000?oo
oooooooo0:Gooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1Xooooo`006_ooool4
o`000003oa0@4?oooooooooo00?ooooo0_l0002Vooooo`03o`000?oooooooooo02oooooo00?o0000
ooooooooool0Ioooool001cooooo00?o0000ooooooooool01Oooool2o`000:Kooooo00?o0000oooo
ooooool0<?ooool00ol0003oooooooooo`1Vooooo`004Oooool6o`0000Gooooo00?o0000oooooooo
ool01?ooool4o`000:Gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`08ooooo`Go
0000FOooool001cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0002Tooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool01OnHV9So8B4Qonk^k_ooooooA4A4
05Wooooo000Looooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`2Qooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool01oooool00onHV9So
8B4Qonk^kP1Jooooo`007?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0X?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Oooooo
00?oV9RHob4Q8Oo^k^h0FOooool001cooooo00?o0000ooooooooool01?ooool2o`0000Gooooo00?o
0000ooooooooool0Woooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Oooooo00?o
MgMgofIVI_ooool0F?ooool001[ooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo09kooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo05Oooooo000Sooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0WOooool00ol0003oooooooooo`0eooooo`;o00001?ooool01Ol0003o^[ZjoooooonHV9So
410@05Wooooo000Sooooo`;o00002?ooool00ol0003oooooooooo`2Looooo`03o`000?oooooooooo
03?ooooo0_l000000ooooooo0000ooooo`03ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0FOooool0
02?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2Kooooo`03o`000?oooooooooo
03Oooooo00?o0000ooooooooool0Goooool002?ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`2Jooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0Goooool002?ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`2Hooooo`;o0000>_ooool00ol0003ooooo
ooooo`1Nooooo`008_ooool2o`0000gooooo00?o0000ooooooooool0U?ooool3o`000003ooooool0
003ooooo03[ooooo00?o0000ooooooooool0GOooool002;ooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`2@ooooo`?o00001Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooo
oooo05cooooo000Rooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0S?ooool3o`00
00Wooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1Looooo`008_ooool3o`0000oo
oooo00?o0000ooooooooool0R?ooool3o`0000gooooo00?o0000ooooooooool0>?ooool00ol0003o
ooooooooo`1Kooooo`008_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo08Gooooo
0_l0000Aooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0F_ooool002;ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`21ooooo`?o00005?ooool00ol0003ooooooooo
o`0hooooo`03o`000?oooooooooo05Wooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool0OOooool3o`0001Oooooo00?o0000ooooooooool06?ooool3oonI01gooooo
00?o0000ooooooooool0FOooool000Oooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q
2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool0
NOooool3o`0001_ooooo00?o0000ooooooooool04_ooool5oonI027ooooo00?o0000ooooooooool0
F?ooool000Go00000_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo07Gooooo0ol0000Oooooo`03o`00
0?oooooooooo00gooooo1?ooV@0Wooooo`03o`000?oooooooooo05Oooooo0007ooooo`05o`000?oo
ooooooooooooool000003oooool00omgMgOo<S8booooo`03ooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool0LOooool3o`0002?ooooo00?o0000ooooooooool01oooool5oonI02_ooooo
0_l0001Hooooo`001oooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o
<S8bolc<c004ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0K_ooool2o`0002Oo
oooo00?o0000ooooooooool00_ooool4oonI03;ooooo00?o0000ooooooooool0EOooool000Oooooo
00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Kooooo0_l0000Iooooo`03
o`000?oooooooooo06[ooooo0ol0000Yooooo`03oonI0?l0003ooiT000;ooiT0=_ooool00ol0003o
ooooooooo`1Eooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo06Kooooo0ol0000Xooooo`Co
oiT000?oooooo`000?ooool0>Oooool00ol0003oooooooooo`1Dooooo`001oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool0H_ooool3o`0002Kooooo1OooV@06ooooo`03o`000?oooooooooo03Sooooo00?o0000oooooooo
ool0Doooool0027ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Nooooo`?o0000
9_ooool3oonI00cooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1Booooo`008?oo
ool3o`0001gooooo00?o0000ooooooooool0Foooool2o`0002Kooooo0oooV@0@ooooo`03o`000?oo
oooooooo03Oooooo00?o0000ooooooooool0D_ooool0027ooooo00?o0000ooooooooool07Oooool0
0ol0003oooooooooo`1Gooooo`?o00009Oooool3oonI01Cooooo00?o0000ooooooooool0=oooool0
0ol0003oooooooooo`1Aooooo`008?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo
05?ooooo0ol0000Uooooo`?ooiT06?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo
053ooooo000Pooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0Coooool3o`0002?o
oooo1OooV@0Kooooo`03o`000?oooooooooo01;ooooo0oo<o`0Sooooo`03o`000?oooooooooo04oo
oooo000Pooooo`;o00008_ooool00ol0003oooooooooo`1;ooooo`?o00008_ooool4oonI027ooooo
00?o0000ooooooooool03?ooool5olco02Kooooo00?o0000ooooooooool0Coooool0023ooooo00?o
0000ooooooooool08_ooool00ol0003oooooooooo`18ooooo`;o00008_ooool3oonI02Kooooo00?o
0000ooooooooool01_ooool5olco02cooooo00?o0000ooooooooool0C_ooool0023ooooo00?o0000
ooooooooool08oooool00ol0003oooooooooo`14ooooo`?o00008Oooool3oonI02[ooooo00?o0000
ooooooooool01Oo<o`0booooo`03o`000?oooooooooo04gooooo000Pooooo`?o00009?ooool00ol0
003oooooooooo`10ooooo`?o00008Oooool3oonI02_ooooo0oo<o`000ol0003oc?l0ooooo`0foooo
o`;o0000C_ooool0023ooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0looooo`?o
00008Oooool3oonI02Wooooo1Oo<o`04ooooo`03o`000?oooooooooo03Kooooo00?o0000oooooooo
ool0C?ooool001Cooooo00Gok^k^oc8b<_l0003o<S8bonk^kP07ooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool0>?ooool3o`0002;ooooo0_ooV@0Vooooo`Koc?l02Oooool00ol0003o
ooooooooo`0gooooo`03o`000?oooooooooo04_ooooo000Dooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo03Gooooo0_l0000Rooooo`?o
oiT08Oooool7olco013ooooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`1:ooooo`00
5?ooool01Ol@413ooooooooooooooooo410@00Kooooo0_l0000Zooooo`03o`000?oooooooooo037o
oooo0ol0000Rooooo`;ooiT08?ooool4olco01Sooooo00?o0000ooooooooool0=oooool00ol0003o
ooooooooo`19ooooo`005?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000oooooooo
ool0:_ooool00ol0003oooooooooo`0]ooooo`?o00008oooool2oonI01kooooo1?o<o`0Mooooo`03
o`000?oooooooooo03Kooooo00?o0000ooooooooool0BOooool001Cooooo00Go0000oooooooooooo
ooooo`000006ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0:Oooool3o`0002?o
oooo0oooV@0Kooooo`Goc?l08_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo04So
oooo000Dooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`0/ooooo`03
o`000?oooooooooo02Gooooo0ol0000Sooooo`?ooiT06_ooool4olco02Sooooo00?o0000oooooooo
ool0=_ooool00ol0003oooooooooo`17ooooo`005?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Ko
oooo0_l0000^ooooo`03o`000?oooooooooo027ooooo0ol0000Tooooo`;ooiT06_ooool3olco02co
oooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`16ooooo`005?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Nooooo`;o
00009?ooool3oonI01Wooooo0oo<o`0`ooooo`03o`000?oooooooooo00Wooooo1?lco`0Zooooo`03
o`000?oooooooooo04Gooooo000Oooooo`03o`000?oooooooooo02oooooo00?o0000ooooooooool0
6_ooool3o`0002Cooooo0_ooV@0Iooooo`?oc?l0=?ooool00ol0003oooooooooo`03ooooo`Go<ol0
;_ooool00ol0003oooooooooo`15ooooo`007_ooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo01Kooooo0ol0000Uooooo`;ooiT06?ooool3olco03Gooooo0olco`000ol0003o<ol0oc?o
0002oc?o03Cooooo00?o0000ooooooooool0A?ooool001kooooo0_l0000cooooo`03o`000?oooooo
oooo01;ooooo0ol0000Vooooo`;ooiT06?ooool2olco02kooooo2_lco`04ooooo`03o`000?oooooo
oooo03Kooooo0_l00014ooooo`007_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo
00kooooo0ol0000Xooooo`03oonI0?oooooooooo01Gooooo0oo<o`0Wooooo`Wo<ol03oooool00ol0
003oooooooooo`0dooooo`03o`000?oooooo000004Cooooo000Nooooo`03o`000?oooooooooo03Co
oooo00?o0000ooooooooool02oooool2o`0002Wooooo0_ooV@0Fooooo`;oc?l08Oooool9oc?o01So
oooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`12ooooo`007_ooool00ol0003ooooo
ooooo`0eooooo`03o`000?oooooooooo00Oooooo0ol0000Yooooo`;ooiT05_ooool2olco01gooooo
1_lco`0Rooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0@Oooool001kooooo0_l0
000gooooo`03o`000?oooooooooo00?ooooo0ol0000Yooooo`?ooiT05Oooool3olco01_ooooo1?lc
o`0Yooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0@?ooool001kooooo00?o0000
ooooooooool0=oooool00ol0003oooooo`000002o`0002[ooooo0_ooV@0Fooooo`;oc?l06_ooool4
oc?o02kooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`0oooooo`007_ooool00ol0
003oooooooooo`0fooooo`?o0000:oooool2oonI01Kooooo0_o<o`0Iooooo`?o<ol0<oooool00ol0
003oooooooooo`0eooooo`03o`000?oooooooooo03oooooo000Nooooo`;o0000=Oooool2o`0000?o
oooo00?o0000ooooooooool09_ooool2oonI01Kooooo0_o<o`0Hooooo`?o<ol0=oooool00ol0003o
ooooooooo`0eooooo`03o`000?oooooooooo00Wooooo0_l000000ol@413oooooooooo`0`ooooo`00
7Oooool00ol0003oooooooooo`0booooo`?o00001_ooool00ol0003oooooooooo`0Tooooo`03oonI
0?oooooooooo01Cooooo0_o<o`0Gooooo`?o<ol0>_ooool00ol0003oooooooooo`0fooooo`03o`00
0?oooooooooo00Wooooo00?o0000ooooooooool0<Oooool000;ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM00Gooooo00?o0000oooooooo
ool0;oooool3o`0000[ooooo00?o0000ooooooooool08Oooool2oonI01Gooooo0_o<o`0Gooooo`;o
<ol0?_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Gooooo1Ol0000booooo`00
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0;?ooool3o`0000kooooo00?o0000ooooooooool07_ooool2oonI01Go
oooo0_o<o`0Fooooo`?o<ol0@Oooool00ol0003o0?mVo`3oIP05o`3oIS3ooooo00?o0000oooooooo
ool01Oooool01?m4A4CogMgMooooool0000cooooo`000_ooool01Ol@413ooooooooooooooooo410@
013ooooo00?o0000ooooooooool00oooool2o`0002[ooooo0ol0000Booooo`03o`000?oooooooooo
01[ooooo0oooV@0Fooooo`03olco0?oooooooooo01?ooooo0olco`0jooooo`_o0?mV00?o0000oooo
ooooool0=Oooool00ol0003oooooooooo`04ooooo`04omgMgOmEEEGoooooo`0003?ooooo0002oooo
o`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo
oooo02Oooooo0_l0000Fooooo`03o`000?oooooooooo01Kooooo0oooV@0Gooooo`;oc?l04oooool3
oc?o03;ooooo2ol0ofH<ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool01?ooool0
0omgMgOoc<c<o`00000cooooo`000_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000
ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo02Cooooo0ol0000Iooooo`03o`000?oo
oooooooo01Cooooo00?ooiT0ooooooooool05_ooool2olco01Cooooo00?o<ol0ooooooooool08Ooo
oolBo`3oIQSooooo00?o0000ooooooooool0=?ooool2o`0000Gooooo00?ok^k^odA4A?l00000<ooo
ool000;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool08Oooool3o`0001gooooo00?o0000ooooooooool0:oooool00oo<o`3ooooooooo
o`0Booooo`;o<ol07Oooool7o`3oIR[ooooo00?o0000ooooooooool0<oooool01?l0003ooooooooo
ool00005ooooo`03ogMgMol0003ooooo03;ooooo0002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`;o00007oooool3o`00027ooooo00?o0000ooooooooool0
:?ooool2olco01Cooooo00?o<ol0ooooooooool05oooool6o`3oIS;ooooo00?o0000ooooooooool0
=Oooool00ol0003oooooooooo`0hooooo`000_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo
1?l00005ooooo`03o`000?oooooooooo01cooooo0ol0000Uooooo`03o`000?oooooooooo02Kooooo
00?oc?l0ooooooooool04_ooool2oc?o01Oooooo0ol0ofHiooooo`03o`000?oooooooooo03Gooooo
00?o0000ooooooooool0=oooool001cooooo00?o0000ooooooooool06Oooool3o`0002Wooooo00?o
0000ooooooooool08oooool2olco01?ooooo0_lco`0Eooooo`Co0?mV?Oooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo03Kooooo000Looooo`03o`000?oooooooooo01Oooooo0_l0000]
ooooo`03o`000?oooooooooo023ooooo0_o<o`0Cooooo`;o<ol05?ooool3o`3oIT;ooooo00?o0000
ooooooooool0=Oooool00ol0003oooooooooo`0eooooo`007?ooool2o`0001Gooooo0ol0000`oooo
o`03o`000?oooooooooo01kooooo00?oc?l0ooooooooool04Oooool2oc?o01?ooooo0ol0ofI6oooo
o`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=Oooool001cooooo00?o0000oooooooo
ool04Oooool3o`0003Cooooo00?o0000ooooooooool06oooool2olco01?ooooo00?o<ol0oooooooo
ool04Oooool2o`3oITWooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0dooooo`00
7?ooool00ol0003oooooooooo`0>ooooo`?o0000>?ooool00ol0003oooooooooo`0Hooooo`;oc?l0
4oooool2oc?o01;ooooo0_l0ofI<ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0
<oooool001cooooo00?o0000ooooooooool02oooool3o`0003cooooo00?o0000ooooooooool05?oo
ool3olco01Cooooo00?o<ol0ooooooooool04?ooool2o`3oIT_ooooo1?l0ool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo03;ooooo000Looooo`;o00002_ooool2o`00043ooooo00?o0000
ooooooooool04?ooool3olco01Gooooo0_lco`0Aooooo`;o0?mVAoooool6o`3oo`Gooooo00?o0000
ooooooooool0=?ooool00ol0003oooooooooo`0booooo`006oooool2o`0000Sooooo0ol00013oooo
o`03o`000?oooooooooo00kooooo00?oc?l0ooooooooool05Oooool00olco`3oooooooooo`0?oooo
o`;o0?mV@?ooool9o`3oo`cooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0aoooo
o`006oooool00ol0003oooooooooo`04ooooo`?o0000Aoooool00ol0003oooooooooo`0Sooooo`;o
<ol04?ooool2o`3oIQoooooo8ol0oolFooooo`03o`000?oooooooooo03?ooooo0_l0000booooo`00
6oooool01?l0003oooooooooooooool3o`0004_ooooo00?o0000ooooooooool08Oooool00olco`3o
ooooooooo`0?ooooo`03o`3oI_oooooooooo01Sooooo1ol0ooliooooo`03o`000?oooooooooo03Go
oooo00?o0000ooooooooool0;oooool001_ooooo1?l0001?ooooo`03o`000?oooooooooo01kooooo
0_lco`0Aooooo`03o`3oI_oooooooooo01Cooooo1Ol0oom1ooooo`03o`000?oooooooooo03Cooooo
00?o0000ooooooooool0;oooool001_ooooo0_l0001Booooo`03o`000?oooooooooo01cooooo00?o
<ol0ooooooooool04?ooool00ol0ofKoooooooooo`0Booooo`?o0?ooAoooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo02kooooo000Aooooo`Co000000?o410@ooooooooool01Oooool0
0ol0003oooooooooo`1@ooooo`03o`000?oooooooooo01Wooooo0_lco`0Aooooo`;o0?mV4_ooool3
o`3ood_ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0]ooooo`004oooool00ol0
003oooooooooo`08ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool05oooool00olc
o`3oooooooooo`0@ooooo`03o`3oI_oooooooooo013ooooo0_l0oom?ooooo`03o`000?oooooooooo
03Cooooo00?o0000ooooooooool0;?ooool001?ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`1@ooooo`03o`000?oooooooooo01Gooooo00?o<ol0ooooooooool04?ooool00ol0ofKo
ooooooooo`0?ooooo`;o0?ooD_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02co
oooo000Cooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0D?ooool00ol0003ooooo
ooooo`0Booooo`;o<ol04_ooool00ol0ofKoooooooooo`0>ooooo`;o0?ooE?ooool00ol0003ooooo
ooooo`0dooooo`03o`000?oooooooooo02_ooooo000Cooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0D?ooool00ol0003oooooooooo`0?ooooo`;o<ol04oooool00ol0ofKooooooooo
o`0=ooooo`;o0?ooEoooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02[ooooo000C
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0<
ooooo`;o<ol05?ooool00ol0ofKoooooooooo`0=ooooo`03o`3ooooooooooooo05Sooooo00?o0000
ooooooooool0=?ooool00ol0003oooooooooo`0Yooooo`004oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo053ooooo00?o0000ooooooooool02Oooool2oc?o01Gooooo00?o0?mVoooo
ooooool03Oooool00ol0ooooooooooooo`1>ooooo`Co06Ko2?ooool00ol0003oooooooooo`0doooo
o`03o`000?oooooooooo02Sooooo000Aooooo`03oeEEEOmVIVKo0000013ooooo00?o0000oooooooo
ool0D?ooool00ol0003oooooooooo`07ooooo`03oc?o0?oooooooooo01Cooooo00?o0?mVoooooooo
ool03Oooool00ol0ooooooooooooo`0Jooooo`Oo06Ko9oooool7o`1Vo`gooooo00?o0000oooooooo
ool0<oooool00ol0003oooooooooo`0Xooooo`009Oooool00ol0003oooooooooo`1@ooooo`03o`00
0?oooooooooo01cooooo00?o0?mVooooooooool03Oooool00ol0ooooooooooooo`0Eooooo`Ko06Ko
1ooooolAo`1Vo`_ooooo2ol0I_lEooooo`03o`000?oooooooooo03;ooooo0_l0000Yooooo`009_oo
ool2o`00057ooooo00?o0000ooooooooool06Oooool2o`3oIPoooooo00?o0?ooooooooooool04_oo
ool4o`1Voakooooo2ol0I_lPooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool09_oo
ool002Sooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0Gooooo`;o0?mV4?ooool0
0ol0ooooooooooooo`0@ooooo`?o06KoC_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooo
oooo02Gooooo000Yooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool05Oooool00ol0
ofKoooooooooo`0?ooooo`03o`3ooooooooooooo00oooooo0_l0I_mBooooo`03o`000?oooooooooo
03?ooooo00?o0000ooooooooool09Oooool002[ooooo00?o0000ooooooooool0C_ooool00ol0003o
ooooooooo`0Booooo`;o0?mV4Oooool00ol0ooooooooooooo`0=ooooo`?o06KoEOooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo02Cooooo000[ooooo`03o`000?oooooooooo04kooooo
00?o0000ooooooooool03oooool2o`3oIQ;ooooo00?o0?ooooooooooool03?ooool2o`1VoeWooooo
00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Sooooo`00;?ooool00ol0003ooooooooo
o`1>ooooo`03o`000?oooooooooo00gooooo00?o0?mVooooooooool04Oooool00ol0oooooooooooo
o`0<ooooo`03o`1Voooooooooooo05[ooooo00?o0000ooooooooool0<oooool00ol0003ooooooooo
o`0Rooooo`00;Oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00[ooooo0_l0ofHC
ooooo`03o`3ooooooooooooo00cooooo00?o06Koooooooooool0Foooool00ol0003oooooooooo`0c
ooooo`03o`000?oooooooooo02;ooooo000^ooooo`03o`000?oooooooooo04kooooo00?o0000oooo
ooooool01oooool2o`3oIQCooooo00?o0?ooooooooooool03?ooool00ol0I_ooooooooooo`1Moooo
o`03o`000?oooooooooo03?ooooo00?o0000ooooooooool08Oooool002oooooo00?o0000oooooooo
ool0C_ooool00ol0003oooooooooo`05ooooo`03o`3oI_oooooooooo01?ooooo00?o0?oooooooooo
ool03?ooool00ol0I_ooooooooooo`1Oooooo`03o`000?oooooooooo03?ooooo00?o0000oooooooo
ool08?ooool0033ooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`03ooooo`03o`3o
I_oooooooooo01?ooooo00?o0?ooooooooooool03?ooool00ol0I_ooooooooooo`1Qooooo`03o`00
0?oooooooooo03?ooooo00?o0000ooooooooool07oooool0037ooooo0_l0001?ooooo`03o`000?oo
oooooooo01Kooooo0_l0ool>ooooo`03o`1Voooooooooooo04kooooo1Olc0?l@ooooo`03o`000?oo
oooooooo03;ooooo0_l0000Pooooo`00<oooool00ol0003oooooooooo`1=ooooo`03o`000?oooooo
oooo01Cooooo00?o0?ooooooooooool03_ooool00ol0I_ooooooooooo`0@oooooaCo<`3o8_ooool8
oc<0oaKooooo00?o0000ooooooooool0<Oooool2o`00023ooooo000dooooo`03o`000?oooooooooo
04gooooo00?o0000ooooooooool04Oooool2o`3ooa3ooooo00?o06Koooooooooool03oooool2oc<0
oaCooooo2_lc0?l=ooooo`_o<`3o7_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo
01gooooo000eooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool03oooool00ol0oooo
ooooooooo`0?ooooo`03o`1Voooooooooooo00kooooo0_lc0?lPooooo`go<`3o:_ooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo01cooooo000fooooo`03o`000?oooooooooo04gooooo
00?o0000ooooooooool03Oooool00ol0ooooooooooooo`0?ooooo`03o`1Voooooooooooo00kooooo
00?o<`3oooooooooool0F?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01cooooo
000gooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool02_ooool2o`3ooa;ooooo00?o
06Koooooooooool03?ooool2oc<0oecooooo00?o0000ooooooooool0<_ooool00ol0003ooooooooo
o`0Kooooo`00>?ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo00Oooooo0_l0oolC
ooooo`03o`1Voooooooooooo00cooooo00?o<`3oooooooooool0GOooool00ol0003oooooooooo`0b
ooooo`03o`000?oooooooooo00Oooooo00Gok^k^oc8b<_l0003o410@olc<c00>ooooo`00>Oooool0
0ol0003oooooooooo`1=ooooo`03o`000?oooooooooo00Cooooo0_l0oolDooooo`03o`1Voooooooo
oooo00cooooo00?o<`3oooooooooool0Goooool00ol0003oooooooooo`0booooo`03o`000?oooooo
oooo00Kooooo00GoEEEEogMgMoooooooV9RHob4Q8@0>ooooo`00>_ooool00ol0003oooooooooo`1=
ooooo`03o`000?oooooooooo00;ooooo00?o0?ooooooooooool05?ooool00ol0I_ooooooooooo`0<
ooooo`03oc<0oooooooooooo05oooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`05
ooooo`05o`000?ooooooooooooooool000003_ooool003_ooooo00?o0000ooooooooool0COooool0
1?l0003oooooo`3oool0oolFooooo`03o`1Voooooooooooo00cooooo00?o<`3oooooooooool0HOoo
ool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00Gooooo00Go0000oiRHV?ooooooV9RH
ob4Q8@0>ooooo`00??ooool00ol0003oooooooooo`1=ooooo`03o`3ooooooooooooo01Cooooo0_l0
I_l>ooooo`03oc<0oooooooooooo06?ooooo00?o0000ooooooooool0<_ooool00ol0003ooooooooo
o`04ooooo`05o`000?mEEEGo0000oa0@4?o<c<`03_ooool003gooooo0_l0001>ooooo`03o`000?oo
oooooooo01;ooooo00?o06Koooooooooool03_ooool00olc0?ooooooooooo`1Tooooo`03o`000?oo
oooooooo03;ooooo0_l00004ooooo`03oeEEEOn7QhOooooo013ooooo000oooooo`03o`000?oooooo
oooo04cooooo00?o0000ooooooooool04?ooool00ol0I_ooooooooooo`0>ooooo`03oc<0oooooooo
oooo06Kooooo00?o0000ooooooooool0;oooool2o`000003ooooool0003ooooo00?ooooo00?ogMgM
oa0@4?nHV9P04?ooool0043ooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0=oooo
o`;o06Ko4?ooool00olc0?ooooooooooo`0?ooooo`Ooc03o=Oooool5ol`0oaSooooo00?o0000oooo
ooooool0<Oooool00ol0003oooooooooo`03ooooo`04olc<c?m4A4Co0000oa0@40kooooo0011oooo
o`03o`000?oooooooooo04cooooo00?o0000ooooooooool02oooool00ol0I_ooooooooooo`0?oooo
o`03oc<0oooooooooooo00cooooo1?o<0?l7ooooo`Koc03o9_ooool9ol`0oagooooo00?o0000oooo
ooooool0<_ooool00ol0003oooooooooo`0Dooooo`00@_ooool00ol0003oooooooooo`1<ooooo`03
o`000?oooooooooo00Wooooo00?o06Koooooooooool04?ooool00olc0?ooooooooooo`0;ooooo`03
ol`0oooooooooooo00oooooo2oo<0?l>ooooo`goc03o9oooool00ol0003oooooooooo`0booooo`03
o`000?oooooooooo01?ooooo0013ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0
1_ooool2o`1Voa;ooooo00?o<`3oooooooooool03?ooool00oo<0?ooooooooooo`0Jooooo`koc03o
=Oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01;ooooo0014ooooo`03o`000?oo
oooooooo04cooooo00?o0000ooooooooool00oooool2o`1Voa?ooooo00?o<`3oooooooooool03?oo
ool00oo<0?ooooooooooo`1Oooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool04_oo
ool004Gooooo00?o0000ooooooooool0C?ooool01Ol0003ooooooooooooooooo06Ko01Cooooo00?o
<`3oooooooooool03?ooool00oo<0?ooooooooooo`1Qooooo`03o`000?oooooooooo037ooooo00?o
0000ooooooooool04Oooool004Kooooo00?o0000ooooooooool0C?ooool00ol0003o06Koo`1Vo`0D
ooooo`03oc<0oooooooooooo00cooooo00?oc03oooooooooool0Hoooool00ol0003oooooooooo`0a
ooooo`03o`000?oooooooooo013ooooo0017ooooo`03o`000?oooooooooo04[ooooo0_l0I_l00ol0
003oooooooooo`0Aooooo`;o<`3o3oooool00oo<0?ooooooooooo`1Sooooo`03o`000?oooooooooo
03;ooooo00?o0000ooooooooool03oooool004Sooooo0_l00019ooooo`05o`1Voooooooooooooooo
ool000004Oooool00olc0?ooooooooooo`0>ooooo`03ol`0oooooooooooo06Gooooo00?o0000oooo
ooooool0<Oooool00ol0003oooooooooo`0?ooooo`00B_ooool00ol0003oooooooooo`15ooooo`03
o`1Voooooooooooo00?ooooo00?o0000ooooooooool03Oooool00olc0?ooooooooooo`0?ooooo`03
ol`0oooooooooooo06Kooooo00?o0000ooooooooool0<Oooool2o`0000oooooo001;ooooo`03o`00
0?oooooooooo04_ooooo00?o0000ooooooooool02_ooool2oc<0oa7ooooo00?oc03oooooooooool0
J?ooool00ol0003oooooooooo`0`ooooo`;o00003oooool004cooooo00?o0000ooooooooool0Booo
ool00ol0003oooooooooo`08ooooo`03oc<0oooooooooooo017ooooo00?oc03oooooooooool0JOoo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00cooooo001=ooooo`03o`000?oooooo
oooo04_ooooo00?o0000ooooooooool01_ooool00olc0?ooooooooooo`0Aooooo`03ol`0oooooooo
oooo06_ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0;ooooo`00C_ooool00ol0
003oooooooooo`1;ooooo`03o`000?oooooooooo00Cooooo00?o<`3oooooooooool04Oooool00oo<
0?ooooooooooo`0;ooooo`Coo`2I>?ooool5ool0VB3ooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`0;ooooo`00Coooool00ol0003oooooooooo`1;ooooo`04o`000?oooooooooooooo
o`;o<`3o4oooool00oo<0?ooooooooooo`0<ooooo`04ool0VOooooooooooooooo`Goo`2I:_ooool9
ool0VBKooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0:ooooo`00D?ooool00ol0
003oooooooooo`1;ooooo`03o`000?lc0?oo<`3o01Cooooo00?oc03oooooooooool03?ooool00ooo
09Woooooooooo`07ooooo`coo`2I4?ooool>ool0VC3ooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`09ooooo`00DOooool00ol0003oooooooooo`1:ooooo`03oc<0ool0003ooooo01?o
oooo00?oc03oooooooooool03Oooool00ooo09Woooooooooo`0Coooooa3oo`2I?oooool00ol0003o
ooooooooo`0aooooo`03o`000?oooooooooo00Sooooo001Booooo`03o`000?oooooooooo04Oooooo
0_lc0?l2ooooo`03o`000?oooooooooo00oooooo0_o<0?l?ooooo`03ool0VOoooooooooo06Cooooo
00?o0000ooooooooool0<?ooool00ol0003oooooooooo`08ooooo`00Doooool2o`0004Gooooo0_lc
0?l5ooooo`03o`000?oooooooooo00gooooo00?oc03oooooooooool03_ooool00ooo09Wooooooooo
o`1Vooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool01oooool005Gooooo00?o0000
ooooooooool0@Oooool00olc0?ooooooooooo`06ooooo`03o`000?oooooooooo00_ooooo00?oc03o
ooooooooool03oooool00ooo09Woooooooooo`1Vooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool01_ooool005Kooooo00?o0000ooooooooool0?oooool00olc0?ooooooooooo`08oooo
o`03o`000?oooooooooo00Wooooo00?oc03oooooooooool03oooool00ooo09Woooooooooo`1Xoooo
o`03o`000?oooooooooo02oooooo0ol00007ooooo`00Eoooool00ol0003oooooooooo`1:ooooo`03
o`000?oooooooooo00Kooooo0_o<0?lBooooo`03ool0VOoooooooooo06Wooooo00?o0000oooooooo
ool0:oooool3o`0000;ooooo00?o0000ooooooooool01Oooool005Sooooo00?o0000ooooooooool0
B_ooool00ol0003oooooooooo`04ooooo`03ol`0oooooooooooo017ooooo00?oo`2Iooooooooool0
Joooool00ol0003oooooooooo`0Wooooo`?o00001Oooool00ol0003oooooooooo`05ooooo`00FOoo
ool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo00;ooooo00?oc03oooooooooool04Ooo
ool00ooo09Woooooooooo`0;ooooo`03ool00?oooooooooo05oooooo00?o0000ooooooooool08_oo
ool4o`0000Sooooo00?o0000ooooooooool01Oooool005[ooooo00?o0000ooooooooool0B_ooool0
1?l0003oooooooooooo<0?lCooooo`03ool0VOoooooooooo00_ooooo0_oo001Rooooo`03o`000?oo
oooooooo01kooooo0ol0000<ooooo`03o`000?oooooooooo00Gooooo001Kooooo`03o`000?oooooo
oooo04[ooooo0_o<0?lCooooo`03ool0VOoooooooooo00[ooooo0_oo00000oooooooo`00ooooo`0f
ooooo`Coo`009oooool00ol0003oooooooooo`0Jooooo`Co00003oooool00ol0003oooooooooo`05
ooooo`00G?ooool00ol0003oooooooooo`17ooooo`;oc03o00?oooooo`000?ooool04Oooool00ooo
09Woooooooooo`05ooooo`Koo`000_ooool00ooo003oooooooooo`0_ooooo`Ooo`00;?ooool00ol0
003oooooooooo`0Fooooo`?o00005?ooool00ol0003oooooooooo`04ooooo`00GOooool00ol0003o
ooooooooo`15ooooo`03ol`0oooooooooooo00;ooooo00?o0000ooooooooool03Oooool2ool0V@go
oooo1Ooo000Yooooo`Ooo`00=?ooool00ol0003oooooooooo`0Booooo`?o00005oooool00ol0003o
ooooooooo`04ooooo`00G_ooool2o`0004?ooooo0_o<0?l6ooooo`03o`000?oooooooooo00_ooooo
00?oo`2Iooooooooool03oooool00ooo003oooooooooo`0:ool001;ooooo3Ooo000looooo`03o`00
0?oooooooooo00gooooo1?l0000Jooooo`03o`000?oooooooooo00Cooooo001Pooooo`03o`000?oo
oooooooo03kooooo0_o<0?l9ooooo`03o`000?oooooooooo00Wooooo00?oo`2Iooooooooool03ooo
ool00ooo003oooooooooo`0;oooooa;oo`00B_ooool00ol0003oooooooooo`09ooooo`?o00007_oo
ool00ol0003oooooooooo`04ooooo`00HOooool00ol0003oooooooooo`0looooo`03ol`0oooooooo
oooo00[ooooo00?o0000ooooooooool01oooool00ooo09Woooooooooo`0@ooooo`03ool00?oooooo
oooo06Sooooo00?o0000ooooooooool01?ooool4o`00027ooooo00?o0000ooooooooool01?ooool0
06;ooooo00?o0000ooooooooool0>Oooool2ol`0o`kooooo00?o0000ooooooooool01?ooool2ool0
VA;ooooo00?oo`00ooooooooool0JOooool01?l0003oooooooooooooool3o`0002Gooooo00?o0000
ooooooooool01?ooool006?ooooo00?o0000ooooooooool0=oooool00oo<0?ooooooooooo`0?oooo
o`03o`000?oooooooooo00;ooooo00?oo`2Iooooooooool04Oooool00ooo003oooooooooo`1[oooo
o`?o0000:?ooool00ol0003oooooooooo`04ooooo`00I?ooool00ol0003oooooooooo`19ooooo`04
o`000?ooooooooooool0VA?ooooo00?oo`00ooooooooool0J?ooool4o`000003ooooool0003ooooo
02Sooooo00?o0000ooooooooool01?ooool006Gooooo00?o0000ooooooooool0BOooool00ol0003o
o`2Iooooo`0Booooo`03ool00?oooooooooo06Kooooo0ol00006ooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool01?ooool006Kooooo00?o0000ooooooooool0B?ooool00ooo09Wo0000
ooooo`0Booooo`03ool00?oooooooooo06;ooooo1?l0000:ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool01?ooool006Oooooo00?o0000ooooooooool0AOooool2ool0V@;ooooo00?o
0000ooooooooool03oooool00ooo003oooooooooo`1Pooooo`?o00003oooool00ol0003ooooooooo
o`0Uooooo`03o`000?oooooooooo00?ooooo001Xooooo`03o`000?oooooooooo04;ooooo0_oo09T5
ooooo`03o`000?oooooooooo00gooooo00?oo`00ooooooooool0G_ooool3o`0001;ooooo00?o0000
ooooooooool09Oooool00ol0003oooooooooo`03ooooo`00JOooool00ol0003oooooooooo`0ooooo
o`;oo`2I2?ooool00ol0003oooooooooo`0:ooooo`;oo`00GOooool4o`0001Kooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`03ooooo`00J_ooool2o`0003gooooo0_oo09T;ooooo`03
o`000?oooooooooo00Sooooo00?oo`00ooooooooool0F_ooool3o`0001_ooooo00?o0000oooooooo
ool08oooool00ol0003oooooooooo`03ooooo`00K?ooool00ol0003oooooooooo`0iooooo`03ool0
VOoooooooooo00cooooo00?o0000ooooooooool01_ooool00ooo003oooooooooo`1Gooooo`Co0000
7oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00?ooooo001]ooooo`03o`000?oo
oooooooo03Kooooo0_oo09T@ooooo`03o`000?oooooooooo00?ooooo0_oo001Gooooo`?o00009?oo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00?ooooo001^ooooo`03o`000?oooooo
oooo03?ooooo0_oo09TCooooo`05o`000?oooooooooooooooooo0000E_ooool3o`0002Sooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`03ooooo`00Koooool00ol0003oooooooooo`0a
ooooo`03ool0VOoooooooooo01Cooooo00?o0000oooooooo0000Doooool4o`0002_ooooo00?o0000
ooooooooool08?ooool00ol0003oooooooooo`03ooooo`00L?ooool00ol0003oooooooooo`17oooo
o`;oo`00DOooool3o`00033ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`03oooo
o`00LOooool00ol0003oooooooooo`15ooooo`04ool00?ooooooooooo`0004cooooo1?l0000doooo
o`03o`000?oooooooooo01kooooo00?o0000ooooooooool00oooool007;ooooo00?o0000oooooooo
ool0@oooool00ooo003oooooooooo`02ooooo`03o`000?oooooooooo04Kooooo0ol0000iooooo`03
o`000?oooooooooo01kooooo00?o0000ooooooooool00_ooool007?ooooo00?o0000ooooooooool0
@?ooool2ool000Kooooo00?o0000ooooooooool0@_ooool3o`0003gooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`02ooooo`00M?ooool00ol0003oooooooooo`0mooooo`;oo`002Ooo
ool00ol0003oooooooooo`0mooooo`Co0000@Oooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo00;ooooo001eooooo`;o0000>oooool2ool000cooooo00?o0000ooooooooool0>Oooool3
o`0004Gooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`02ooooo`00Moooool00ol0
003oooooooooo`0fooooo`;oo`003oooool00ol0003oooooooooo`0dooooo`Co0000BOooool00ol0
003oooooooooo`0Kooooo`03o`000?oooooooooo00;ooooo001hooooo`03o`000?oooooooooo03?o
oooo0_oo000Booooo`03o`000?oooooooooo033ooooo0ol0001>ooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool00_ooool007Wooooo00?o0000ooooooooool0<?ooool2ool001Gooooo
00?o0000ooooooooool0;?ooool3o`0005;ooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`02ooooo`00N_ooool00ol0003oooooooooo`0]ooooo`;oo`006?ooool00ol0003ooooooooo
o`0Wooooo`Co0000E_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00;ooooo001k
ooooo`03o`000?oooooooooo02_ooooo00?oo`00ooooooooool06Oooool00ol0003oooooooooo`0S
ooooo`?o0000Foooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00;ooooo001loooo
o`03o`000?oooooooooo04Oooooo00?o0000ooooooooool07_ooool4o`0005kooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`02ooooo`00OOooool00ol0003oooooooooo`17ooooo`03
o`000?oooooooooo01[ooooo0ol0001Sooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool00Oooool007kooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Fooooo`?o0000
Ioooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo007ooooo001oooooo`03o`000?oo
oooooooo04Oooooo00?o0000ooooooooool04Oooool4o`0006_ooooo00?o0000ooooooooool05Ooo
ool00ol0003oooooooooo`01ooooo`00P?ooool2o`0004Sooooo00?o0000ooooooooool03Oooool3
o`00073ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`01ooooo`00P_ooool00ol0
003oooooooooo`16ooooo`03o`000?oooooooooo00Sooooo1?l0001dooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool00Oooool008?ooooo00?o0000ooooooooool0A_ooool00ol0003o
ooooooooo`04ooooo`?o0000N?ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo007o
oooo0024ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool00ol0001looooo`03o`00
0?oooooooooo01;ooooo00?o0000ooooooooool00Oooool008Gooooo00?o0000ooooooooool0A_oo
ool2o`00083ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`01ooooo`00Q_ooool0
0ol0003oooooooooo`15ooooo`03o`000?oooooooooo083ooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`01ooooo`00Qoooool00ol0003oooooooooo`14ooooo`03o`000?oooooooooo
087ooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`01ooooo`00R?ooool00ol0003o
ooooooooo`13ooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool03oooool1o`00007o
oooo0Oooool008Wooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`22ooooo`03o`00
0?oooooooooo00oooooo0Ol00001ooooo`7ooooo002:ooooo`03o`000?oooooooooo047ooooo00?o
0000ooooooooool0Poooool00ol0003oooooooooo`0>ooooo`7o00000Oooool1ooooo`00Roooool2
o`00047ooooo00?o0000ooooooooool0Q?ooool00ol0003oooooooooo`0=ooooo`7o00000Oooool1
ooooo`00SOooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo08Gooooo00?o0000oooo
ooooool03?ooool1o`00007ooooo0Oooool008kooooo00?o0000ooooooooool0?Oooool00ol0003o
ooooooooo`26ooooo`03o`000?oooooooooo00_ooooo0Ol00001ooooo`7ooooo002?ooooo`03o`00
0?oooooooooo03cooooo00?o0000ooooooooool0Qoooool00ol0003oooooooooo`0:ooooo`7o0000
0Oooool1ooooo`00T?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo08Oooooo00?o
0000ooooooooool02_ooool1o`00007ooooo0Oooool0097ooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`28ooooo`03o`000?oooooooooo00Wooooo0Ol00001ooooo`7ooooo002Boooo
o`03o`000?oooooooooo03Wooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`08oooo
o`7o00000Oooool1ooooo`00Toooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo08[o
oooo00?o0000ooooooooool02?ooool1o`00007ooooo002Dooooo`03o`000?oooooooooo03Oooooo
00?o0000ooooooooool0Roooool00ol0003oooooooooo`07ooooo`7o00000Oooool009Gooooo00?o
0000ooooooooool0=_ooool00ol0003oooooooooo`2<ooooo`03o`000?oooooooooo00Kooooo0Ol0
0001ooooo`00U_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo08cooooo00?o0000
ooooooooool01_ooool1o`00007ooooo002Gooooo`;o0000=Oooool00ol0003oooooooooo`2=oooo
o`03o`000?oooooooooo00Gooooo0Ol00001ooooo`00VOooool00ol0003oooooooooo`0booooo`03
o`000?oooooooooo08kooooo00?o0000ooooooooool01?ooool1o`00007ooooo002Jooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool0Soooool00ol0003oooooooooo`03ooooo`7o0000
0Oooool009_ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`2@ooooo`03o`000?oo
oooooooo00;ooooo0Ol00001ooooo`00W?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooo
oooo097ooooo00Go0000ooooooooooooooooo`000001ooooo`00WOooool00ol0003oooooooooo`0^
ooooo`03o`000?oooooooooo097ooooo00Go0000ooooooooooooooooo`000001ooooo`00W_ooool0
0ol0003oooooooooo`0]ooooo`03o`000?oooooooooo09;ooooo00Co0000oooooooooooooooo0Ol0
000009oooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`2Cooooo`03o`000?oooooo
oooo007o0000002Pooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0U?ooool1o`00
007ooooo0Ol000000:7ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`2Eooooo`;o
0000002Rooooo`;o0000:_ooool00ol0003oooooooooo`2Dooooo`?o0000002Tooooo`03o`000?oo
oooooooo02Oooooo00?o0000ooooooooool0T?ooool4o`0000?ooooo002Uooooo`03o`000?oooooo
oooo02Kooooo00?o0000ooooooooool0SOooool3o`0000Oooooo002Vooooo`03o`000?oooooooooo
02Gooooo00?o0000ooooooooool0ROooool4o`0000[ooooo002Wooooo`03o`000?oooooooooo02Co
oooo00?o0000ooooooooool0QOooool4o`0000kooooo002Xooooo`03o`000?oooooooooo02?ooooo
00?o0000ooooooooool0P_ooool3o`0001;ooooo002Yooooo`03o`000?oooooooooo02;ooooo00?o
0000ooooooooool0O_ooool4o`0001Gooooo002Zooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool0N_ooool4o`0001Wooooo002[ooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool0MOooool4o`0001gooooo002/ooooo`03o`000?oooooooooo023ooooo00?o0000oooooooo
ool0L_ooool3o`00027ooooo002]ooooo`;o00008?ooool00ol0003oooooooooo`1^ooooo`Co0000
9?ooool00:oooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1Zooooo`Co0000:?oo
ool00;3ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1Wooooo`?o0000;?ooool0
0;7ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Sooooo`Co0000;oooool00;;o
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1Oooooo`Co0000<oooool00;?ooooo
00?o0000ooooooooool06Oooool00ol0003oooooooooo`1Looooo`?o0000=oooool00;Cooooo00?o
0000ooooooooool06?ooool00ol0003oooooooooo`1Hooooo`Co0000>_ooool00;Gooooo00?o0000
ooooooooool05oooool00ol0003oooooooooo`1Dooooo`Co0000?_ooool00;Kooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`1@ooooo`Co0000@_ooool00;Oooooo00?o0000oooooooo
ool05Oooool00ol0003oooooooooo`1=ooooo`?o0000A_ooool00;Sooooo0_l0000Eooooo`03o`00
0?oooooooooo04Wooooo1?l00019ooooo`00^_ooool00ol0003oooooooooo`0Booooo`03o`000?oo
oooooooo04Gooooo1?l0001=ooooo`00^oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooo
oooo04;ooooo0ol0001Aooooo`00_?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo
03kooooo1?l0001Dooooo`00_Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03[o
oooo1?l0001Hooooo`00__ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03Kooooo
1?l0001Looooo`00_oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03?ooooo0ol0
001Pooooo`00`?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02oooooo1?l0001S
ooooo`00`Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02_ooooo1?l0001Woooo
o`00`_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Sooooo0ol0001[ooooo`00
`oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02Cooooo1?l0001^ooooo`00a?oo
ool2o`0000Wooooo00?o0000ooooooooool08?ooool4o`0007;ooooo0036ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool07Oooool3o`0007Kooooo0037ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool06Oooool4o`0007Wooooo0038ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool05Oooool4o`0007gooooo0039ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool04Oooool4o`00087ooooo003:ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool03_ooool3o`0008Gooooo003;ooooo`05o`000?ooooooooooooooool000003?oo
ool4o`0008Sooooo003<ooooo`04o`000?ooooooooooo`0000Sooooo1?l0002<ooooo`00cOooool0
0ol0003oooooo`000005ooooo`?o0000T?ooool00<kooooo0_l000000ooooooo0000o`000002o`00
09?ooooo003?ooooo`;o0000Uoooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool0
0?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {330.375, 0}} -> {-0.0771432, -0.0315529, \
0.00350368, 0.00350368}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .92059 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-16 1.0763 -0.0263982 1.0763 [
[.01694 .18568 -11.9631 -9 ]
[.01694 .18568 .03693 0 ]
[.13793 .13897 -11.619 -9 ]
[.13793 .13897 .38095 0 ]
[.26292 .09073 -5.63752 -9 ]
[.26292 .09073 .36248 0 ]
[.39212 .04087 -5.46552 -9 ]
[.39212 .04087 .53448 0 ]
[.52574 -0.01069 -5.29351 -9 ]
[.52574 -0.01069 .70649 0 ]
[.58272 .04263 0 -6.19654 ]
[.58272 .04263 6 2.80346 ]
[.71715 .21863 0 -6.07114 ]
[.71715 .21863 6 2.92886 ]
[.83675 .37523 0 -5.963 ]
[.83675 .37523 6 3.037 ]
[.94385 .51546 0 -5.8688 ]
[.94385 .51546 6 3.1312 ]
[.01386 .20006 -12 -2.76892 ]
[.01386 .20006 0 6.23108 ]
[.00748 .25499 -24 -2.80073 ]
[.00748 .25499 0 6.19927 ]
[.00093 .31131 -6 -2.83339 ]
[.00093 .31131 0 6.16661 ]
[-0.00579 .36907 -18 -2.86695 ]
[-0.00579 .36907 0 6.13305 ]
[-0.01268 .42831 -6 -2.90143 ]
[-0.01268 .42831 0 6.09857 ]
[ 0 0 0 0 ]
[ 1 .92059 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02642 .19522 m
.53391 0 L
s
.02642 .19522 m
.03116 .2 L
s
[(-2)] .01694 .18568 .99384 1 Mshowa
.14712 .14879 m
.15172 .1537 L
s
[(-1)] .13793 .13897 .93651 1 Mshowa
.2718 .10083 m
.27624 .10588 L
s
[(0)] .26292 .09073 .87917 1 Mshowa
.40066 .05126 m
.40493 .05646 L
s
[(1)] .39212 .04087 .82184 1 Mshowa
.53391 0 m
.538 .00534 L
s
[(2)] .52574 -0.01069 .7645 1 Mshowa
.125 Mabswid
.05025 .18606 m
.05308 .18894 L
s
.07424 .17683 m
.07705 .17973 L
s
.09837 .16755 m
.10117 .17046 L
s
.12267 .1582 m
.12545 .16113 L
s
.17173 .13933 m
.17447 .14229 L
s
.19651 .1298 m
.19923 .13278 L
s
.22144 .1202 m
.22414 .1232 L
s
.24654 .11055 m
.24922 .11356 L
s
.29723 .09105 m
.29988 .0941 L
s
.32283 .0812 m
.32546 .08427 L
s
.3486 .07129 m
.35121 .07437 L
s
.37455 .06131 m
.37713 .06441 L
s
.42695 .04115 m
.4295 .04428 L
s
.45342 .03096 m
.45594 .03412 L
s
.48007 .02071 m
.48257 .02388 L
s
.5069 .01039 m
.50938 .01358 L
s
.25 Mabswid
.53391 0 m
.9804 .58403 L
s
.57014 .04738 m
.56384 .04975 L
s
[(0)] .58272 .04263 -1 .37701 Mshowa
.70445 .22307 m
.6981 .22529 L
s
[(2)] .71715 .21863 -1 .34914 Mshowa
.82396 .37939 m
.81756 .38147 L
s
[(4)] .83675 .37523 -1 .32511 Mshowa
.93098 .51938 m
.92454 .52134 L
s
[(6)] .94385 .51546 -1 .30418 Mshowa
.125 Mabswid
.60525 .09331 m
.60147 .09471 L
s
.63931 .13786 m
.63552 .13924 L
s
.67236 .1811 m
.66856 .18245 L
s
.73562 .26383 m
.7318 .26514 L
s
.7659 .30345 m
.76207 .30473 L
s
.79534 .34195 m
.7915 .34322 L
s
.85181 .41581 m
.84796 .41704 L
s
.87891 .45126 m
.87506 .45247 L
s
.90529 .48577 m
.90143 .48696 L
s
.95601 .55212 m
.95214 .55328 L
s
.25 Mabswid
.02642 .19522 m
0 .42381 L
s
.02642 .19522 m
.0327 .19281 L
s
[(-1)] .01386 .20006 1 -0.38468 Mshowa
.02006 .25024 m
.02635 .24786 L
s
[(-0.5)] .00748 .25499 1 -0.37762 Mshowa
.01354 .30664 m
.01985 .3043 L
s
[(0)] .00093 .31131 1 -0.37036 Mshowa
.00686 .36448 m
.01318 .36218 L
s
[(0.5)] -0.00579 .36907 1 -0.3629 Mshowa
0 .42381 m
.00634 .42156 L
s
[(1)] -0.01268 .42831 1 -0.35524 Mshowa
.125 Mabswid
.02516 .20612 m
.02893 .20468 L
s
.0239 .21707 m
.02767 .21563 L
s
.02262 .22807 m
.0264 .22664 L
s
.02135 .23913 m
.02512 .2377 L
s
.01877 .26141 m
.02255 .25999 L
s
.01747 .27263 m
.02125 .27122 L
s
.01617 .28391 m
.01995 .2825 L
s
.01486 .29525 m
.01864 .29384 L
s
.01222 .31809 m
.01601 .3167 L
s
.01089 .3296 m
.01468 .32821 L
s
.00955 .34117 m
.01334 .33978 L
s
.00821 .35279 m
.012 .35141 L
s
.0055 .37622 m
.0093 .37485 L
s
.00414 .38803 m
.00793 .38666 L
s
.00276 .39989 m
.00656 .39853 L
s
.00139 .41182 m
.00519 .41047 L
s
.25 Mabswid
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.54154 .92059 L
s
.54154 .92059 m
.5414 .7134 L
s
.5414 .7134 m
.02642 .19522 L
s
.53391 0 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.53391 0 m
.02642 .19522 L
s
.5414 .7134 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.54154 .92059 L
s
.54154 .92059 m
.5414 .7134 L
s
0 0 m
1 0 L
1 .92059 L
0 .92059 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.44585 .69953 m
.49014 .67595 L
s
1 0 .6 r
.42866 .66548 m
.46989 .64313 L
s
.8 0 1 r
.41147 .63141 m
.44965 .61035 L
s
.2 0 1 r
.39427 .59732 m
.42943 .57759 L
s
0 .4 1 r
.37705 .56322 m
.40922 .54486 L
s
0 1 1 r
.35984 .5291 m
.38908 .51216 L
s
0 1 .4 r
.34267 .49498 m
.36919 .4795 L
s
.2 1 0 r
.32571 .46088 m
.35006 .44691 L
s
.8 1 0 r
.30934 .42685 m
.33242 .41436 L
s
1 .6 0 r
.29399 .39283 m
.3166 .3817 L
s
.3166 .3817 m
.33786 .36989 L
s
.8 1 0 r
.33242 .41436 m
.35297 .40107 L
s
.2 1 0 r
.35006 .44691 m
.37041 .43189 L
s
0 1 .4 r
.36919 .4795 m
.39043 .46249 L
s
0 1 1 r
.38908 .51216 m
.41245 .49294 L
s
0 .4 1 r
.40922 .54486 m
.43549 .52338 L
s
.2 0 1 r
.42943 .57759 m
.45891 .55388 L
s
.8 0 1 r
.44965 .61035 m
.48246 .58445 L
s
1 0 .6 r
.46989 .64313 m
.50608 .61512 L
s
1 0 0 r
.49014 .67595 m
.52976 .64588 L
s
1 .6 0 r
.33786 .36989 m
.35787 .35813 L
s
.8 1 0 r
.35297 .40107 m
.37123 .38819 L
s
.2 1 0 r
.37041 .43189 m
.38672 .41786 L
s
0 1 .4 r
.39043 .46249 m
.40516 .44716 L
s
1 .6 0 r
.35787 .35813 m
.37738 .34694 L
s
0 1 1 r
.41245 .49294 m
.42672 .47597 L
s
.8 1 0 r
.37123 .38819 m
.38872 .37636 L
s
0 .4 1 r
.43549 .52338 m
.45067 .50436 L
s
.2 1 0 r
.38672 .41786 m
.40163 .40554 L
s
.2 0 1 r
.45891 .55388 m
.47591 .53256 L
s
1 .6 0 r
.37738 .34694 m
.39714 .33653 L
s
.8 0 1 r
.48246 .58445 m
.50168 .56079 L
s
0 1 .4 r
.40516 .44716 m
.41712 .4346 L
s
.8 1 0 r
.38872 .37636 m
.40667 .36566 L
s
1 0 .6 r
.50608 .61512 m
.52768 .58914 L
s
0 1 1 r
.42672 .47597 m
.43606 .46338 L
s
1 0 0 r
.52976 .64588 m
.55382 .61764 L
s
.2 1 0 r
.40163 .40554 m
.41723 .39473 L
s
1 .6 0 r
.39714 .33653 m
.41756 .32698 L
s
0 .4 1 r
.45067 .50436 m
.45846 .49164 L
s
0 1 .4 r
.41712 .4346 m
.42974 .42399 L
s
.8 1 0 r
.40667 .36566 m
.42565 .35607 L
s
1 .6 0 r
.41756 .32698 m
.43886 .31832 L
s
.2 0 1 r
.47591 .53256 m
.48331 .51944 L
s
.2 1 0 r
.41723 .39473 m
.43433 .38521 L
s
0 1 1 r
.43606 .46338 m
.44531 .45353 L
s
.8 1 0 r
.42565 .35607 m
.44583 .34758 L
s
0 1 .4 r
.42974 .42399 m
.44434 .4148 L
s
.8 0 1 r
.50168 .56079 m
.50938 .54708 L
s
0 .4 1 r
.45846 .49164 m
.46477 .48318 L
s
1 .6 0 r
.43886 .31832 m
.4611 .31057 L
s
1 0 0 r
.5912 .62722 m
.65937 .62496 L
s
.53598 .62311 m
.5912 .62722 L
s
.2 1 0 r
.43433 .38521 m
.45306 .37699 L
s
0 1 1 r
.44531 .45353 m
.45668 .44517 L
s
1 0 0 r
.65937 .62496 m
.72207 .61666 L
s
.8 1 0 r
.44583 .34758 m
.4672 .34021 L
s
1 0 .6 r
.52768 .58914 m
.53595 .57476 L
s
1 0 0 r
.50906 .6191 m
.53598 .62311 L
s
.2 0 1 r
.48331 .51944 m
.48762 .51272 L
s
1 0 .6 r
.59244 .58848 m
.65528 .58635 L
s
.54208 .58467 m
.59244 .58848 L
s
0 1 .4 r
.44434 .4148 m
.46109 .40702 L
s
1 .6 0 r
.4611 .31057 m
.48432 .30371 L
s
0 .4 1 r
.46477 .48318 m
.47246 .47651 L
s
1 0 .6 r
.65528 .58635 m
.71395 .57846 L
s
.51657 .58081 m
.54208 .58467 L
s
.2 1 0 r
.45306 .37699 m
.47326 .37011 L
s
1 0 0 r
.5068 .6187 m
.50906 .6191 L
s
.51747 .61891 m
.5068 .6187 L
s
.53244 .61708 m
.51747 .61891 L
s
.8 0 1 r
.5937 .54961 m
.65119 .54762 L
s
.54821 .54612 m
.5937 .54961 L
s
0 1 1 r
.45668 .44517 m
.47063 .43818 L
s
1 0 0 r
.55382 .61764 m
.56275 .60258 L
s
.8 1 0 r
.4672 .34021 m
.48971 .334 L
s
1 0 0 r
.54684 .61265 m
.53244 .61708 L
s
.8 0 1 r
.65119 .54762 m
.70582 .54015 L
s
.2 0 1 r
.48762 .51272 m
.49182 .50862 L
s
.8 0 1 r
.50938 .54708 m
.51234 .54217 L
s
1 .6 0 r
.48432 .30371 m
.50855 .29772 L
s
1 0 .6 r
.5111 .58 m
.51657 .58081 L
s
.8 0 1 r
.52404 .54243 m
.54821 .54612 L
s
0 .4 1 r
.47246 .47651 m
.48254 .47101 L
s
0 1 .4 r
.46109 .40702 m
.47964 .40077 L
s
1 0 .6 r
.51541 .58005 m
.5111 .58 L
s
.52282 .57912 m
.51541 .58005 L
s
.2 0 1 r
.59496 .51061 m
.64709 .50876 L
s
.55426 .50748 m
.59496 .51061 L
s
1 0 .6 r
.53007 .57686 m
.52282 .57912 L
s
.2 1 0 r
.47326 .37011 m
.49474 .36465 L
s
.2 0 1 r
.64709 .50876 m
.69766 .50172 L
s
.49182 .50862 m
.49713 .50556 L
s
1 0 0 r
.5578 .60651 m
.54684 .61265 L
s
.8 0 1 r
.51533 .54122 m
.52404 .54243 L
s
0 1 1 r
.47063 .43818 m
.48668 .43285 L
s
.8 1 0 r
.48971 .334 m
.51334 .32895 L
s
.2 0 1 r
.53119 .50406 m
.55426 .50748 L
s
.8 0 1 r
.51234 .54217 m
.51331 .54113 L
s
1 0 .6 r
.53548 .57378 m
.53007 .57686 L
s
.8 0 1 r
.5133 .54113 m
.51533 .54122 L
s
.5132 .54113 m
.5133 .54113 L
s
.51337 .54108 m
.5132 .54113 L
s
.51331 .54113 m
.51337 .54108 L
s
0 .4 1 r
.59619 .4715 m
.64298 .46978 L
s
.55995 .46888 m
.59619 .4715 L
s
1 .6 0 r
.50855 .29772 m
.53387 .29249 L
s
0 .4 1 r
.48254 .47101 m
.49471 .46702 L
s
.2 0 1 r
.49713 .50556 m
.5037 .50344 L
s
1 0 .6 r
.53595 .57476 m
.53775 .57166 L
s
0 1 .4 r
.47964 .40077 m
.49954 .39624 L
s
0 .4 1 r
.64298 .46978 m
.68948 .46319 L
s
1 0 .6 r
.53775 .57166 m
.53548 .57378 L
s
.2 0 1 r
.51914 .50257 m
.53119 .50406 L
s
.2 1 0 r
.49474 .36465 m
.51735 .36068 L
s
0 .4 1 r
.5373 .46595 m
.55995 .46888 L
s
.2 0 1 r
.5037 .50344 m
.51097 .50245 L
s
.8 1 0 r
.51334 .32895 m
.5382 .325 L
s
.2 0 1 r
.51097 .50245 m
.51914 .50257 L
s
0 1 1 r
.48668 .43285 m
.50406 .42945 L
s
1 0 0 r
.56339 .60127 m
.5578 .60651 L
s
0 1 1 r
.5972 .4324 m
.63883 .43069 L
s
.56455 .43059 m
.5972 .4324 L
s
0 .4 1 r
.49471 .46702 m
.50798 .46488 L
s
1 .6 0 r
.53387 .29249 m
.56047 .28776 L
s
0 .4 1 r
.5217 .46458 m
.5373 .46595 L
s
0 1 .4 r
.49954 .39624 m
.52044 .39353 L
s
0 1 1 r
.63883 .43069 m
.68127 .42455 L
s
.54126 .42861 m
.56455 .43059 L
s
.2 1 0 r
.51735 .36068 m
.54119 .35819 L
s
0 .4 1 r
.50798 .46488 m
.5217 .46458 L
s
.8 1 0 r
.5382 .325 m
.56467 .32186 L
s
0 1 1 r
.50406 .42945 m
.52212 .42808 L
s
.52212 .42808 m
.54126 .42861 L
s
0 1 .4 r
.59752 .39363 m
.63457 .3916 L
s
.56707 .3931 m
.59752 .39363 L
s
1 0 0 r
.56275 .60258 m
.56339 .60127 L
s
0 1 .4 r
.52044 .39353 m
.54245 .39262 L
s
.54245 .39262 m
.56707 .3931 L
s
.2 1 0 r
.54119 .35819 m
.56702 .35685 L
s
1 .6 0 r
.56047 .28776 m
.58846 .28301 L
s
.2 1 0 r
.56702 .35685 m
.5964 .35567 L
s
0 1 .4 r
.63457 .3916 m
.67303 .38583 L
s
.8 1 0 r
.56467 .32186 m
.59338 .31884 L
s
.2 1 0 r
.5964 .35567 m
.6299 .35282 L
s
.8 1 0 r
.59338 .31884 m
.62438 .31474 L
s
1 .6 0 r
.58846 .28301 m
.61759 .27752 L
s
.2 1 0 r
.6299 .35282 m
.6647 .34715 L
s
.8 1 0 r
.62438 .31474 m
.6561 .30873 L
s
1 .6 0 r
.61759 .27752 m
.64691 .27082 L
s
0 g
.25 Mabswid
.53391 0 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.53391 0 m
.02642 .19522 L
s
.02642 .19522 m
.53391 0 L
s
.02642 .19522 m
.03116 .2 L
s
[(-2)] .01694 .18568 .99384 1 Mshowa
.14712 .14879 m
.15172 .1537 L
s
[(-1)] .13793 .13897 .93651 1 Mshowa
.2718 .10083 m
.27624 .10588 L
s
[(0)] .26292 .09073 .87917 1 Mshowa
.40066 .05126 m
.40493 .05646 L
s
[(1)] .39212 .04087 .82184 1 Mshowa
.53391 0 m
.538 .00534 L
s
[(2)] .52574 -0.01069 .7645 1 Mshowa
.125 Mabswid
.05025 .18606 m
.05308 .18894 L
s
.07424 .17683 m
.07705 .17973 L
s
.09837 .16755 m
.10117 .17046 L
s
.12267 .1582 m
.12545 .16113 L
s
.17173 .13933 m
.17447 .14229 L
s
.19651 .1298 m
.19923 .13278 L
s
.22144 .1202 m
.22414 .1232 L
s
.24654 .11055 m
.24922 .11356 L
s
.29723 .09105 m
.29988 .0941 L
s
.32283 .0812 m
.32546 .08427 L
s
.3486 .07129 m
.35121 .07437 L
s
.37455 .06131 m
.37713 .06441 L
s
.42695 .04115 m
.4295 .04428 L
s
.45342 .03096 m
.45594 .03412 L
s
.48007 .02071 m
.48257 .02388 L
s
.5069 .01039 m
.50938 .01358 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 265.125},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001Bb000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00`oooool5o`000:3ooooo0033ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@0X?ooool00<Cooooo00?oV9RHob4Q8Oo^k^h0XOooool00<Gooooo00?oV9RH
ob4Q8Oo^k^h0X?ooool00<Kooooo00?oMgMgofIVI_ooool0Woooool00<Oooooo00?o0000oooooooo
ool0W_ooool00<?ooooo00Go0000okZj^_ooooooV9RHoa0@402Pooooo`00`oooool01OnHV9So410@
o`000?lQ8B7oc<c<0:3ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003;ooooo`;o0000Voooool00<Sooooo0ol000000ooooooo0000ooooo`2Jooooo`00a_oo
ool2o`0000Cooooo0_l0002Jooooo`00`oooool3o`0000Kooooo00?o0000ooooool00000VOooool0
0<3ooooo1?l00008ooooo`04o`000?ooooooooooo`0009Sooooo002Hooooo`Co000000?o410@oooo
ooooool07oooool2o`0000Cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0002H
ooooo`00V_ooool00ol0003oooooooooo`0Nooooo`?o00003_ooool01Ol0003ooooooooooooooooo
000009Oooooo002Jooooo`03o`000?oooooooooo01cooooo0_l0000Aooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0U?ooool009[ooooo00?o0000ooooooooool06Oooool3o`0000;o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo09?o
oooo002Jooooo`03o`000?oooooooooo01Kooooo0ol0000Fooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^08Kooooo002Jooooo`03o`00
0?oooooooooo01Cooooo0_l0000Iooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1oooool01OmgMgOoV9RHoooooonHV9SoMgMg08Kooooo002Jooooo`03o`000?oooooooooo017ooooo
0ol000000ooooooo0000ooooo`0Hooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1_ooool01Ol@413ooooooooooooooooo410@08Kooooo002Hooooo`03oeEEEOmVIVKo0000017ooooo
0_l0000Nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool01Ol0003ooooo
oooooooooooo000008Kooooo002Yooooo`?o00008?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000026ooooo`00Yoooool3o`0002;ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@
4100Q_ooool00:Cooooo0ol00002ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Q_ooool00:7ooooo
0ol0000Xooooo`03o`000?oooooooooo00Sooooo0_l00004ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h0Q_ooool009oooooo0_l0000[ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo
0000S_ooool009cooooo0ol000000ooooooo0000ooooo`0Zooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0S?ooool009[ooooo0_l00005ooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`2;ooooo`00Uoooool3o`0003;ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`2:ooooo`00K?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^02?ooooo0ol000000ooooooo0000ooooo`0booooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0ROooool006cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Qooooo`;o0000>?ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo08Wooooo001/ooooo`05oa0@4?oooooooooo
ooooool@41007_ooool3o`0003[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`28
ooooo`00K?ooool01Ol0003ooooooooooooooooo000001cooooo0ol0000looooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0Qoooool006cooooo00Go0000ooooooooooooooooo`00000I
ooooo`?o00000_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool0Q_ooool006cooooo00Go410@oooooooooooooooooa0@400Gooooo`;o0000@_ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo08Kooooo001/ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL05?ooool3o`0004Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`25
ooooo`00K?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^017ooooo0ol00002ooooo`03o`000?oooooo
oooo04;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`24ooooo`00P?ooool2o`00
04[ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`23ooooo`00OOooool3o`0004co
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`22ooooo`00Noooool2o`000003oooo
ool0003ooooo04cooooo00?o0000ooooooooool05?ooool2o`0008?ooooo001hooooo`?o0000DOoo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooo000008?ooooo001eooooo`?o0000E?ooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo083ooooo001cooooo`Co0000EOooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo07oooooo001`ooooo`?o00001?ooool00ol0003o
ooooooooo`1Booooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0Ooooool006kooooo
0_l0001Looooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0O_ooool004?ooooo1?l0
00000ol@413oooooooooo`0Qooooo`?o0000G_ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo07gooooo0015ooooo`03o`000?oooooooooo023ooooo0ol00003ooooo`03o`000?oooooo
oooo05_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1looooo`00>_ooool6o`00
00Gooooo00?o0000ooooooooool07_ooool2o`0006Cooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`1looooo`00AOooool00ol0003oooooooooo`0Kooooo`?o0000I_ooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo07_ooooo0015ooooo`03o`000?oooooooooo01Wooooo
0_l00002ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`1jooooo`00AOooool00ol0003oooooooooo`0Fooooo`?o0000Joooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo07Wooooo0015ooooo`03o`000?oooooooooo01Cooooo0_l0001^
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0NOooool004?ooooo00?oEEEEofIV
I_l000004oooool3o`000003ooooool0003ooooo06gooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`1hooooo`00E_ooool3o`0007?ooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`1gooooo`00E?ooool2o`0007Kooooo00?o0000ooooooooool07oooool2o`0007Sooooo
001Aooooo`?o000000?oooooo`000?ooool0MOooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo07Kooooo001?ooooo`;o0000Noooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo07Gooooo001<ooooo`?o0000OOooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
07Cooooo0019ooooo`Co0000Ooooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo07?o
oooo0017ooooo`;o00001?ooool00ol0003oooooooooo`1looooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool0L_ooool004Cooooo0ol00025ooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool0L_ooool001[ooooo1Ol0000Sooooo`?o0000Qoooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo077ooooo000Jooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@08?ooool3
o`0000?ooooo00?o0000ooooooooool0Q?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo073ooooo000Booooo`Ko00000oooool00onHV9So8B4Qonk^kP0Oooooo`;o0000SOooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo06oooooo000Looooo`03oiRHV?lQ8B7ok^k^01_o
oooo0ol0002?ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0Koooool001gooooo
00?oMgMgofIVI_ooool05oooool3o`0000?ooooo00?o0000ooooooooool0S?ooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooooooo06kooooo000Nooooo`03o`000?oooooooooo01Cooooo0_l0
002Eooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0KOooool001[ooooo00Go0000
okZj^_ooooooV9RHoa0@400Cooooo`?o0000Uoooool00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo06cooooo000Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`04Oooool2o`0000?ooooo00?o
0000ooooooooool0U?ooool00ol0003oooooooooo`0Zooooo`;o0000KOooool002gooooo0ol0002L
ooooo`03o`000?oooooooooo02[ooooo0_l0001]ooooo`00:_ooool3o`0009oooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`1Zooooo`00:?ooool2o`0000?ooooo00?o0000oooooooo
ool0W?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo06Wooooo000Uooooo`?o0000
Y?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo06Wooooo000Tooooo`03o`000?oo
oooooooo0:Gooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1Xooooo`006_ooool4
o`000003oa0@4?oooooooooo00?ooooo0_l0002Vooooo`03o`000?oooooooooo02oooooo00?o0000
ooooooooool0Ioooool001cooooo00?o0000ooooooooool01Oooool2o`000:Kooooo00?o0000oooo
ooooool0<?ooool00ol0003oooooooooo`1Vooooo`004Oooool6o`0000Gooooo00?o0000oooooooo
ool01?ooool4o`000:Gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`08ooooo`Go
0000FOooool001cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0002Tooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool01OnHV9So8B4Qonk^k_ooooooA4A4
05Wooooo000Looooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`2Qooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool01oooool00onHV9So
8B4Qonk^kP1Jooooo`007?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0X?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Oooooo
00?oV9RHob4Q8Oo^k^h0FOooool001cooooo00?o0000ooooooooool01?ooool2o`0000Gooooo00?o
0000ooooooooool0Woooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Oooooo00?o
MgMgofIVI_ooool0F?ooool001[ooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo09kooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo05Oooooo000Sooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0WOooool00ol0003oooooooooo`0eooooo`;o00001?ooool01Ol0003o^[ZjoooooonHV9So
410@05Wooooo000Sooooo`;o00002?ooool00ol0003oooooooooo`2Looooo`03o`000?oooooooooo
03?ooooo0_l000000ooooooo0000ooooo`03ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0FOooool0
02?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2Kooooo`03o`000?oooooooooo
03Oooooo00?o0000ooooooooool0Goooool002?ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`2Jooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0Goooool002?ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`2Hooooo`;o0000>_ooool00ol0003ooooo
ooooo`1Nooooo`008_ooool2o`0000gooooo00?o0000ooooooooool0U?ooool3o`000003ooooool0
003ooooo03[ooooo00?o0000ooooooooool0GOooool002;ooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`2@ooooo`?o00001Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooo
oooo05cooooo000Rooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0S?ooool3o`00
00Wooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1Looooo`008_ooool3o`0000oo
oooo00?o0000ooooooooool0R?ooool3o`0000gooooo00?o0000ooooooooool0>?ooool00ol0003o
ooooooooo`1Kooooo`008_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo08Gooooo
0_l0000Aooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0F_ooool002;ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`21ooooo`?o00005?ooool00ol0003ooooooooo
o`0hooooo`03o`000?oooooooooo05Wooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool0OOooool3o`0001Oooooo00?o0000ooooooooool0>?ooool00ol0003ooooo
ooooo`1Iooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1iooooo`?o0000
6oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo05Sooooo0005o`0000;ooooo00Go
410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`1eooooo`?o00007oooool00ol0003oooooooooo`0hooooo`03o`00
0?oooooooooo05Oooooo0007ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8b
ooooo`03ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0LOooool3o`0002?ooooo
00?o0000ooooooooool0=oooool2o`0005Sooooo0007ooooo`05o`000?ooooooooooooooool00000
3?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`1^ooooo`;o00009oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo05Go
oooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`;o
00006Oooool00ol0003oooooooooo`1Zooooo`?o0000:_ooool00ol0003oooooooooo`0Fooooo`?o
oiT07_ooool00ol0003oooooooooo`1Eooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00co
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo06Ko
oooo0ol0000]ooooo`03o`000?oooooooooo017ooooo1OooV@0Rooooo`03o`000?oooooooooo05Co
oooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000oooooooo
ool06_ooool00ol0003oooooooooo`1Rooooo`?o0000<Oooool00ol0003oooooooooo`0<ooooo`Co
oiT0:?ooool00ol0003oooooooooo`1Cooooo`008Oooool00ol0003oooooooooo`0Kooooo`03o`00
0?oooooooooo05kooooo0ol0000eooooo`03o`000?oooooooooo00Kooooo1OooV@0]ooooo`03o`00
0?oooooooooo05;ooooo000Pooooo`?o00007Oooool00ol0003oooooooooo`1Kooooo`;o0000>Ooo
ool00ol0003oooooooooo`05oonI03;ooooo00?o0000ooooooooool0D_ooool0027ooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`1Gooooo`?o0000>Oooool3oonI0003o`000?ooV@3o
oooo03Oooooo00?o0000ooooooooool0DOooool0023ooooo00?o0000ooooooooool07oooool00ol0
003oooooooooo`1Cooooo`?o0000=_ooool6oonI00Cooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`1@ooooo`008?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo04oo
oooo0ol0000booooo`OooiT02_ooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo04oo
oooo000Pooooo`;o00008_ooool00ol0003oooooooooo`1;ooooo`?o0000<Oooool4oonI01;ooooo
00?o0000ooooooooool0=oooool00ol0003oooooooooo`1?ooooo`008?ooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo04Sooooo0_l0000`ooooo`CooiT05oooool00ol0003ooooooooo
o`0gooooo`03o`000?oooooooooo04kooooo000Pooooo`03o`000?oooooooooo02?ooooo00?o0000
ooooooooool0A?ooool3o`0002kooooo1?ooV@0Looooo`03o`000?oooooooooo03Oooooo00?o0000
ooooooooool0COooool0023ooooo0ol0000Tooooo`03o`000?oooooooooo043ooooo0ol0000]oooo
o`CooiT08Oooool00ol0003oooooooooo`0fooooo`;o0000C_ooool0023ooooo00?o0000oooooooo
ool09Oooool00ol0003oooooooooo`0looooo`?o0000;?ooool4oonI02Kooooo00?o0000oooooooo
ool03oooool4olco02?ooooo00?o0000ooooooooool0C?ooool001Cooooo00Gok^k^oc8b<_l0003o
<S8bonk^kP07ooooo`03o`000?oooooooooo02Kooooo00?o0000ooooooooool0>?ooool3o`0002co
oooo0oooV@0Zooooo`03o`000?oooooooooo00[ooooo1Oo<o`0Xooooo`03o`000?oooooooooo04_o
oooo000Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`0Xooooo`03
o`000?oooooooooo03Gooooo0_l0000/ooooo`?ooiT0;_ooool00ol0003oooooooooo`04ooooo`Go
c?l0;_ooool00ol0003oooooooooo`1:ooooo`005?ooool01Ol@413ooooooooooooooooo410@00Ko
oooo0_l0000Zooooo`03o`000?oooooooooo037ooooo0ol0000[ooooo`?ooiT0<_ooool00ol0003o
c?l0olco0003olco03Cooooo00?o0000ooooooooool0BOooool001Cooooo00Go0000oooooooooooo
ooooo`000006ooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0;Oooool3o`0002co
oooo0_ooV@0^ooooo`Soc?l000?o0000ooooooooool0=_ooool00ol0003oooooooooo`19ooooo`00
5?ooool01Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooooooool0:oooool00ol0003o
ooooooooo`0Yooooo`?o0000;?ooool3oonI02Oooooo2Oo<o`09ooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool0B?ooool001Cooooo00Go410@oooooooooooooooooa0@4006ooooo`03
o`000?oooooooooo02cooooo00?o0000ooooooooool09Oooool3o`0002gooooo0_ooV@0Qooooo`Wo
c?l04oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo04Oooooo000Dooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool2o`0002kooooo00?o0000ooooooooool08Oooool3o`0002ko
oooo0_ooV@0Mooooo`Koc?l07?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo04Ko
oooo000Dooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01_ooool00ol0003oooooooooo`0^ooooo`03
o`000?oooooooooo01kooooo0_l0000_ooooo`;ooiT06oooool4olco02?ooooo00?o0000oooooooo
ool0=oooool00ol0003oooooooooo`15ooooo`007oooool00ol0003oooooooooo`0_ooooo`03o`00
0?oooooooooo01[ooooo0ol0000_ooooo`;ooiT06Oooool4olco02Sooooo00?o0000ooooooooool0
=_ooool00ol0003oooooooooo`15ooooo`007_ooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo01Kooooo0ol0000`ooooo`;ooiT06?ooool3olco02gooooo00?o0000ooooooooool0=_oo
ool00ol0003oooooooooo`14ooooo`007_ooool2o`0003?ooooo00?o0000ooooooooool04_ooool3
o`00033ooooo0oooV@0Fooooo`Coc?l0<Oooool00ol0003oooooooooo`0fooooo`;o0000A?ooool0
01kooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0>ooooo`?o0000<Oooool2oonI
01Kooooo0oo<o`0fooooo`03o`000?oooooooooo03Cooooo00?o0000ooooool00000A?ooool001ko
oooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0;ooooo`;o0000<_ooool2oonI01Go
oooo0oo<o`0iooooo`03o`000?oooooooooo00Oooooo1?lco`0[ooooo`03o`000?oooooooooo04;o
oooo000Nooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool01oooool3o`0003?ooooo
00?ooiT0ooooooooool04_ooool3olco03gooooo00Co0000oooooooooooooooo1Olco`0`ooooo`03
o`000?oooooooooo047ooooo000Nooooo`;o0000=oooool00ol0003oooooooooo`03ooooo`?o0000
=?ooool2oonI01?ooooo0_o<o`0looooo`Go<ol000?o0000oc?o0?lco`00=_ooool00ol0003ooooo
ooooo`10ooooo`007_ooool00ol0003oooooooooo`0gooooo`03o`000?oooooo000000;o0000=_oo
ool00oooV@3oooooooooo`0Aooooo`;oc?l0:_oooolDoc?o00Kooooo00?o0000ooooooooool0=_oo
ool00ol0003oooooooooo`0oooooo`007_ooool00ol0003oooooooooo`0fooooo`?o0000=oooool2
oonI01;ooooo0_o<o`0Tooooo`So<ol06oooool00ol0003oooooooooo`0eooooo`03o`000?oooooo
oooo03oooooo000Nooooo`;o0000=Oooool2o`0000?ooooo00?o0000ooooooooool0<_ooool2oonI
01;ooooo0_o<o`0Nooooo`So<ol09?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo
00Wooooo0_l000000ol@413oooooooooo`0`ooooo`007Oooool00ol0003oooooooooo`0booooo`?o
00001_ooool00ol0003oooooooooo`0`ooooo`03oonI0?oooooooooo013ooooo0_o<o`0Jooooo`Ko
<ol0;?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool0<Oooool000;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co
0000o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0;oooool3o`0000[ooooo00?o0000oooo
ooooool0;Oooool2oonI01;ooooo00?oc?l0ooooooooool05oooool3oc?o03?ooooo00?o0000oooo
ooooool0=_ooool00ol0003oooooooooo`05ooooo`Go0000<_ooool000;ooooo00GoMgMgoiRHV?oo
ooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo
02cooooo0ol0000>ooooo`03o`000?oooooooooo02[ooooo0_ooV@0Booooo`;oc?l05_ooool4oc?o
03Oooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`05ooooo`04odA4A?oMgMgooooo
o`0003?ooooo0002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03
ooooo`;o0000:_ooool3o`0001;ooooo00?o0000ooooooooool09oooool2oonI01?ooooo00?oc?l0
ooooooooool04oooool3oc?o03cooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`04
ooooo`04omgMgOmEEEGoooooo`0003?ooooo0002ooooo`05o`000?ooooooooooooooool000003ooo
ool00omgMgOo<S8booooo`04ooooo`03o`000?oooooooooo02Oooooo0_l0000Fooooo`03o`000?oo
oooooooo02Gooooo00?ooiT0ooooooooool04Oooool2olco01?ooooo0olco`10ooooo`03o`000?oo
oooooooo03Gooooo00?o0000ooooooooool01?ooool00omgMgOoc<c<o`00000cooooo`000_ooool0
1Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`00
0?oooooooooo02Cooooo0ol0000Iooooo`03o`000?oooooooooo02;ooooo0_ooV@0Cooooo`03olco
0?oooooooooo017ooooo0_lco`14ooooo`03o`000?oooooooooo03Cooooo0_l00005ooooo`03onk^
k_m4A4Co000003?ooooo0002ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo027ooooo0ol0000Mooooo`03o`000?oooooooooo01oooooo
0_ooV@0Cooooo`;oc?l04_ooool2oc?o04Kooooo00?o0000ooooooooool0<oooool01?l0003ooooo
ooooool00005ooooo`03ogMgMol0003ooooo03;ooooo0002ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03?ooool00ol0003oooooooooo`07ooooo`;o00007oooool3o`00027ooooo00?o0000oooooooo
ool06oooool3oonI01Cooooo00?oc?l0ooooooooool04?ooool2oc?o04Wooooo00?o0000ooooool0
ofH00ol0ofHbooooo`03o`000?oooooooooo03Sooooo0002ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h03?ooool4o`0000Gooooo00?o0000ooooooooool07?ooool3o`0002Gooooo00?o0000oooooooo
ool05oooool3oonI01Gooooo0_o<o`0Aooooo`;o<ol0A_ooool6o`3oIP03o`000?oooooooooo03Go
oooo00?o0000ooooooooool0=oooool001cooooo00?o0000ooooooooool06Oooool3o`0002Wooooo
00?o0000ooooooooool05Oooool00oooV@3oooooooooo`0Eooooo`03olco0?oooooooooo00oooooo
0_lco`0Toooooa7o0?mV2_ooool9o`3oIPOooooo00?o0000ooooooooool0=Oooool00ol0003ooooo
ooooo`0fooooo`007?ooool00ol0003oooooooooo`0Gooooo`;o0000;Oooool00ol0003ooooooooo
o`0Zooooo`;oc?l04?ooool2oc?o01Wooooo3Ol0ofHAooooo`[o0?mV4Oooool00ol0003ooooooooo
o`0eooooo`03o`000?oooooooooo03Gooooo000Looooo`;o00005Oooool3o`00033ooooo00?o0000
ooooooooool0:?ooool00oo<o`3oooooooooo`0?ooooo`03oc?o0?oooooooooo01Kooooo0ol0ofHj
ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=Oooool001cooooo00?o0000oooo
ooooool04Oooool3o`0003Cooooo00?o0000ooooooooool09Oooool2olco017ooooo00?o<ol0oooo
ooooool05?ooool3o`3oISgooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0doooo
o`007?ooool00ol0003oooooooooo`0>ooooo`?o0000>?ooool00ol0003oooooooooo`0Rooooo`;o
c?l04_ooool00olco`3oooooooooo`0Booooo`?o0?mV@Oooool00ol0003oooooooooo`0eooooo`03
o`000?oooooooooo03?ooooo000Looooo`03o`000?oooooooooo00_ooooo0ol0000looooo`03o`00
0?oooooooooo023ooooo00?oc?l0ooooooooool04?ooool2oc?o01;ooooo0ol0ofI5ooooo`03o`00
0?oooooooooo03Gooooo00?o0000ooooooooool0<_ooool001cooooo0_l0000:ooooo`;o0000@?oo
ool00ol0003oooooooooo`0Mooooo`;oc?l04_ooool00olco`3oooooooooo`0@ooooo`;o0?mVBOoo
ool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo03;ooooo000Kooooo`;o00002?ooool3
o`0004?ooooo00?o0000ooooooooool06_ooool2olco01?ooooo00?o<ol0ooooooooool03oooool2
o`3oITcooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0aooooo`006oooool00ol0
003oooooooooo`04ooooo`?o0000Aoooool00ol0003oooooooooo`0Hooooo`03olco0?oooooooooo
01;ooooo00?o<ol0ooooooooool03_ooool2o`3oIToooooo00?o0000ooooooooool0<oooool2o`00
03;ooooo000Kooooo`04o`000?ooooooooooooooo`?o0000Boooool00ol0003oooooooooo`0Eoooo
o`;oc?l04oooool2oc?o00oooooo0_l0ofIAooooo`03o`000?oooooooooo03Gooooo00?o0000oooo
ooooool0;oooool001_ooooo1?l0001?ooooo`03o`000?oooooooooo01?ooooo00?oc?l0oooooooo
ool04_ooool00olco`3oooooooooo`0>ooooo`03o`3oI_oooooooooo05;ooooo00?o0000oooooooo
ool0=?ooool00ol0003oooooooooo`0_ooooo`006oooool2o`0005;ooooo00?o0000ooooooooool0
4Oooool00oo<o`3oooooooooo`0Booooo`03oc?o0?oooooooooo00gooooo0_l0ofI@ooooo`Co0?oo
0_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02kooooo000Aooooo`Co000000?o
410@ooooooooool01Oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo00oooooo00?o
c?l0ooooooooool04_ooool00olco`3oooooooooo`0=ooooo`03o`3oI_oooooooooo01Oooooo4_l0
oolPooooo`Oo0?oo1oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02gooooo000C
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0Q
ooooo`;o<ol03oooool00ol0ofKoooooooooo`0Eooooo`?o0?oo4_oooolPo`3oo`oooooo00?o0000
ooooooooool0=?ooool00ol0003oooooooooo`0/ooooo`004oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo053ooooo00?o0000ooooooooool07oooool00olco`3oooooooooo`0>oooo
o`03o`3oI_oooooooooo01;ooooo1?l0oom5ooooo`03o`000?oooooooooo03?ooooo00?o0000oooo
ooooool0;?ooool001?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1@ooooo`03
o`000?oooooooooo01cooooo0_lco`0@ooooo`03o`3oI_oooooooooo00oooooo1?l0oom9ooooo`03
o`000?oooooooooo03Cooooo00?o0000ooooooooool0:oooool001?ooooo00?o0000ooooooooool0
2oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo01[ooooo00?o<ol0ooooooooool0
3oooool00ol0ofKoooooooooo`0>ooooo`;o0?ooC_ooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo02[ooooo000Cooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0D?oo
ool00ol0003oooooooooo`0Hooooo`03oc?o0?oooooooooo00oooooo00?o0?mVooooooooool03_oo
ool00ol0ooooooooooooo`1?ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0:Ooo
ool001?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooo
oooo01Gooooo0_lco`0Aooooo`03o`3oI_oooooooooo00gooooo0_l0oomCooooo`03o`000?oooooo
oooo03Cooooo00?o0000ooooooooool0:?ooool0017ooooo00?oEEEEofIVI_l000004?ooool00ol0
003oooooooooo`1@ooooo`03o`000?oooooooooo01?ooooo00?o<ol0ooooooooool04?ooool00ol0
ofKoooooooooo`0=ooooo`03o`3ooooooooooooo05Cooooo00?o0000ooooooooool0<oooool00ol0
003oooooooooo`0Xooooo`009Oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo013o
oooo0_lco`0Booooo`03o`3oI_oooooooooo00gooooo00?o0?ooooooooooool0E_ooool00ol0003o
ooooooooo`0booooo`;o0000:Oooool002Kooooo0_l0001Aooooo`03o`000?oooooooooo00gooooo
0_lco`0Cooooo`03o`3oI_oooooooooo00kooooo00?o0?ooooooooooool0E_ooool00ol0003ooooo
ooooo`0dooooo`03o`000?oooooooooo02Kooooo000Xooooo`03o`000?oooooooooo04kooooo00?o
0000ooooooooool03?ooool00olco`3oooooooooo`0Booooo`03o`3oI_oooooooooo00kooooo00?o
0?ooooooooooool0F?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02Gooooo000Y
ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool02_ooool00olco`3oooooooooo`0A
ooooo`;o0?mV4?ooool00ol0ooooooooooooo`1Jooooo`03o`000?oooooooooo03?ooooo00?o0000
ooooooooool09Oooool002[ooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0Loooo
o`03o`3oI_oooooooooo00oooooo00?o0?ooooooooooool04_ooool;o`1Voc3ooooo1Ol0I_l:oooo
o`03o`000?oooooooooo03?ooooo00?o0000ooooooooool09?ooool002_ooooo00?o0000oooooooo
ool0C_ooool00ol0003oooooooooo`0Jooooo`03o`3oI_oooooooooo00oooooo00?o0?oooooooooo
ool03oooool4o`1Vo`_ooooo1_l0I_lRooooo`So06Ko4?ooool00ol0003oooooooooo`0cooooo`03
o`000?oooooooooo02?ooooo000/ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0
6?ooool00ol0ofKoooooooooo`0?ooooo`03o`3ooooooooooooo00gooooo0ol0I_lEooooob;o06Ko
6Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02;ooooo000]ooooo`03o`000?oo
oooooooo04kooooo00?o0000ooooooooool05_ooool00ol0ofKoooooooooo`0?ooooo`03o`3ooooo
oooooooo00gooooo00?o06Koooooooooool0DOooool00ol0003oooooooooo`0cooooo`03o`000?oo
oooooooo02;ooooo000^ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool05?ooool0
0ol0ofKoooooooooo`0?ooooo`03o`3ooooooooooooo00cooooo0_l0I_mEooooo`03o`000?oooooo
oooo03?ooooo00?o0000ooooooooool08Oooool002oooooo00?o0000ooooooooool0C_ooool00ol0
003oooooooooo`0Aooooo`;o0?mV4_ooool00ol0ooooooooooooo`0;ooooo`03o`1Voooooooooooo
05Kooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Pooooo`00<?ooool00ol0003o
ooooooooo`1>ooooo`03o`000?oooooooooo00oooooo00?o0?mVooooooooool04Oooool00ol0oooo
ooooooooo`0;ooooo`03o`1Voooooooooooo05Sooooo00?o0000ooooooooool0<oooool00ol0003o
ooooooooo`0Oooooo`00<Oooool2o`0004oooooo00?o0000ooooooooool03?ooool2o`3oIQ?ooooo
00?o0?ooooooooooool03?ooool00ol0I_ooooooooooo`1Iooooo`03o`000?oooooooooo03;ooooo
0_l0000Pooooo`00<oooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo00Wooooo0_l0
ofHEooooo`03o`3ooooooooooooo00_ooooo00?o06Koooooooooool0Foooool00ol0003ooooooooo
o`0aooooo`;o00008?ooool003Cooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`07
ooooo`03o`3oI_oooooooooo01Cooooo00?o0?ooooooooooool02oooool00ol0I_ooooooooooo`1L
ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool07Oooool003Gooooo00?o0000oooo
ooooool0COooool00ol0003oooooooooo`05ooooo`03o`3oI_oooooooooo01?ooooo0_l0ool>oooo
o`03o`1Voooooooooooo05gooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Loooo
o`00=_ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo01Wooooo00?o0?oooooooooo
ool03Oooool00ol0I_ooooooooooo`1Oooooo`03o`000?oooooooooo03;ooooo00?o0000oooooooo
ool07?ooool003Oooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0Gooooo`03o`3o
oooooooooooo00gooooo00?o06Koooooooooool0Boooool4oc<0oa;ooooo00?o0000ooooooooool0
<_ooool00ol0003oooooooooo`0Kooooo`00>?ooool00ol0003oooooooooo`1=ooooo`03o`000?oo
oooooooo01Cooooo0_l0ool?ooooo`03o`1Voooooooooooo00kooooo3olc0?lZooooo`Go<`3o5ooo
ool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00Oooooo00Gok^k^oc8b<_l0003o410@
olc<c00>ooooo`00>Oooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo01;ooooo00?o
0?ooooooooooool03oooool00ol0I_ooooooooooo`0<ooooo`;o<`3o3oooool;oc<0oa[ooooo1Olc
0?lMooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool01_ooool01OmEEEGoMgMgoooo
oonHV9So8B4Q00kooooo000jooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool04?oo
ool00ol0ooooooooooooo`0?ooooo`03o`1Voooooooooooo00cooooo00?o<`3oooooooooool06_oo
oolJoc<0ob;ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`05ooooo`05o`000?oo
ooooooooooooool000003_ooool003_ooooo00?o0000ooooooooool0COooool00ol0003ooooooooo
o`0=ooooo`;o0?oo4Oooool00ol0I_ooooooooooo`0<ooooo`03oc<0oooooooooooo05Sooooo00?o
0000ooooooooool0<_ooool00ol0003oooooooooo`05ooooo`05o`000?nHV9SooooooiRHV?lQ8B40
3_ooool003cooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0:ooooo`;o0?oo4_oo
ool00ol0I_ooooooooooo`0<ooooo`03oc<0oooooooooooo05[ooooo00?o0000ooooooooool0<_oo
ool00ol0003oooooooooo`04ooooo`05o`000?mEEEGo0000oa0@4?o<c<`03_ooool003gooooo0_l0
001>ooooo`03o`000?oooooooooo00Sooooo00?o0?ooooooooooool04_ooool00ol0I_oooooooooo
o`0;ooooo`03oc<0oooooooooooo05cooooo00?o0000ooooooooool0<_ooool2o`0000Cooooo00?o
EEEEohN7Qoooool04?ooool003oooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`05
ooooo`;o0?oo5?ooool00ol0I_ooooooooooo`0<ooooo`03oc<0oooooooooooo05gooooo00?o0000
ooooooooool0;oooool2o`000003ooooool0003ooooo00?ooooo00?ogMgMoa0@4?nHV9P04?ooool0
043ooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`02ooooo`;o0?oo5?ooool2o`1V
o`kooooo00?o<`3oooooooooool0Goooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo
00?ooooo00Coc<c<odA4A?l0003o410@3_ooool0047ooooo00?o0000ooooooooool0C?ooool01?l0
003oooooooooool0oolEooooo`03o`1Voooooooooooo00kooooo00?o<`3oooooooooool0Goooool0
0ol0003oooooooooo`0booooo`03o`000?oooooooooo01Cooooo0012ooooo`03o`000?oooooooooo
04cooooo00?o0000o`3oooooool05?ooool00ol0I_ooooooooooo`0?ooooo`03oc<0oooooooooooo
063ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Cooooo`00@oooool00ol0003o
ooooooooo`1<ooooo`03o`000?oooooooooo01;ooooo00?o06Koooooooooool03oooool00olc0?oo
ooooooooo`1Rooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool04_ooool004Cooooo
00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0@ooooo`03o`1Voooooooooooo013ooooo
00?o<`3oooooooooool0Hoooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo01;ooooo
0015ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool03_ooool00ol0I_oooooooooo
o`0@ooooo`03oc<0oooooooooooo00[ooooo00?oc03oooooooooool0>_ooool4ol`0oa[ooooo00?o
0000ooooooooool0<Oooool00ol0003oooooooooo`0Aooooo`00A_ooool00ol0003oooooooooo`1<
ooooo`03o`000?oooooooooo00cooooo00?o06Koooooooooool04?ooool00olc0?ooooooooooo`0;
ooooo`Woc03o;_ooool6ol`0oaoooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0@
ooooo`00Aoooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo00Wooooo0_l0I_lBoooo
o`03oc<0oooooooooooo00_ooooo00?oc03oooooooooool01oooool<ol`0oacooooo1_o<0?lUoooo
o`03o`000?oooooooooo03;ooooo00?o0000ooooooooool03oooool004Sooooo0_l0001=ooooo`03
o`000?oooooooooo00Kooooo0_l0I_lCooooo`03oc<0oooooooooooo00cooooo00?oc03ooooooooo
ool04ooooolLol`0obcooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0?ooooo`00
B_ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo00?ooooo0_l0I_lDooooo`03oc<0
oooooooooooo00cooooo00?oc03oooooooooool0GOooool00ol0003oooooooooo`0aooooo`;o0000
3oooool004_ooooo00?o0000ooooooooool0Boooool01Ol0003ooooooooooooooooo06Ko01Cooooo
0_lc0?l>ooooo`03ol`0oooooooooooo05oooooo00?o0000ooooooooool0<?ooool2o`0000oooooo
001<ooooo`03o`000?oooooooooo04_ooooo00?o0000o`1Vool0I_l05?ooool00olc0?oooooooooo
o`0>ooooo`03ol`0oooooooooooo063ooooo00?o0000ooooooooool0<Oooool00ol0003ooooooooo
o`0<ooooo`00COooool00ol0003oooooooooo`19ooooo`;o06Ko00?o0000ooooooooool04_ooool0
0olc0?ooooooooooo`0>ooooo`03ol`0oooooooooooo06;ooooo00?o0000ooooooooool0<Oooool0
0ol0003oooooooooo`0;ooooo`00C_ooool00ol0003oooooooooo`17ooooo`05o`1Voooooooooooo
ooooool000004_ooool00olc0?ooooooooooo`0?ooooo`03ol`0oooooooooooo06;ooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`0;ooooo`00Coooool00ol0003oooooooooo`1;oooo
o`03o`000?oooooooooo00gooooo0_lc0?lAooooo`03ol`0oooooooooooo06Cooooo00?o0000oooo
ooooool0<Oooool00ol0003oooooooooo`0:ooooo`00D?ooool00ol0003oooooooooo`1;ooooo`03
o`000?oooooooooo00_ooooo00?o<`3oooooooooool04?ooool00oo<0?ooooooooooo`1Vooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool02Oooool0057ooooo00?o0000ooooooooool0
Boooool00ol0003oooooooooo`09ooooo`03oc<0oooooooooooo013ooooo00?oc03oooooooooool0
2oooool2ool0VE_ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`08ooooo`00D_oo
ool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo00Oooooo00?o<`3oooooooooool04Ooo
ool00oo<0?ooooooooooo`09ooooo`;oo`2I00?oooooool0VOooool0Foooool00ol0003ooooooooo
o`0`ooooo`03o`000?oooooooooo00Sooooo001Cooooo`;o0000C?ooool00ol0003oooooooooo`04
ooooo`;o<`3o4oooool00oo<0?ooooooooooo`04ooooo`Koo`2I0oooool00ooo09Woooooooooo`0c
ooooo`Koo`2I8_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Oooooo001Eoooo
o`03o`000?oooooooooo04[ooooo00Co0000oooooooooooooooo0_lc0?lDooooo`03ol`0oooooooo
oooo00Oooooo1ooo09T/ooooo`[oo`2I:?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooo
oooo00Kooooo001Fooooo`03o`000?oooooooooo04[ooooo00?o0000oc<0oolc0?l05?ooool2ol`0
o`oooooo3Ooo09TBooooo`ooo`2I<oooool00ol0003oooooooooo`0_ooooo`?o00001oooool005Oo
oooo00?o0000ooooooooool0BOooool00olc0?oo0000ooooo`0Cooooo`03ol`0oooooooooooo00ko
oooo00?oo`2Iooooooooool02ooooolBool0VD?ooooo00?o0000ooooooooool0:oooool3o`0000;o
oooo00?o0000ooooooooool01Oooool005Sooooo00?o0000ooooooooool0A_ooool2oc<0o`;ooooo
00?o0000ooooooooool04?ooool00oo<0?ooooooooooo`0?ooooo`03ool0VOoooooooooo067ooooo
00?o0000ooooooooool09oooool3o`0000Gooooo00?o0000ooooooooool01Oooool005Wooooo00?o
0000ooooooooool0@oooool2oc<0o`Gooooo00?o0000ooooooooool03Oooool2ol`0oa7ooooo00?o
o`2Iooooooooool0Hoooool00ol0003oooooooooo`0Rooooo`Co00002?ooool00ol0003ooooooooo
o`05ooooo`00F_ooool00ol0003oooooooooo`11ooooo`03oc<0oooooooooooo00Kooooo00?o0000
ooooooooool02oooool00oo<0?ooooooooooo`0@ooooo`03ool0VOoooooooooo06Gooooo00?o0000
ooooooooool07_ooool3o`0000cooooo00?o0000ooooooooool01Oooool005_ooooo00?o0000oooo
ooooool0B_ooool00ol0003oooooooooo`08ooooo`;oc03o4_ooool00ooo09Woooooooooo`0<oooo
o`03ool00?oooooooooo05Oooooo00?o0000ooooooooool06_ooool4o`0000oooooo00?o0000oooo
ooooool01Oooool005cooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`06ooooo`03
ol`0oooooooooooo017ooooo00?oo`2Iooooooooool03?ooool2ool005[ooooo00?o0000oooooooo
ool05_ooool3o`0001Cooooo00?o0000ooooooooool01?ooool005gooooo00?o0000ooooooooool0
B_ooool00ol0003oooooooooo`04ooooo`03ol`0oooooooooooo01;ooooo00?oo`2Iooooooooool0
2_ooool2ool00003oooooooo003ooooo05[ooooo00?o0000ooooooooool04_ooool3o`0001Oooooo
00?o0000ooooooooool01?ooool005kooooo0_l0001;ooooo`04o`000?ooooooooooooooo`;oc03o
5?ooool00ooo09Woooooooooo`09ooooo`;oo`000_ooool00ooo003oooooooooo`1Kooooo`03o`00
0?oooooooooo00gooooo1?l0000Jooooo`03o`000?oooooooooo00Cooooo001Pooooo`03o`000?oo
oooooooo04Wooooo00?o0000ol`0ooo<0?l05Oooool00ooo09Woooooooooo`08ooooo`;oo`000ooo
ool00ooo003oooooooooo`1Mooooo`03o`000?oooooooooo00Wooooo0ol0000Nooooo`03o`000?oo
oooooooo00Cooooo001Qooooo`03o`000?oooooooooo04Oooooo0_o<0?l00ol0003oooooooooo`0B
ooooo`;oo`2I2Oooool2ool000Gooooo00?oo`00ooooooooool0G_ooool00ol0003oooooooooo`04
ooooo`Co00008Oooool00ol0003oooooooooo`04ooooo`00H_ooool00ol0003oooooooooo`14oooo
o`;oc03o0oooool00ol0003oooooooooo`0@ooooo`03ool0VOooooooo`0000Woo`001_ooool00ooo
003oooooooooo`0_ooooo`Koo`00:_ooool01?l0003oooooooooooooool3o`0002Gooooo00?o0000
ooooooooool01?ooool006?ooooo00?o0000ooooooooool0@_ooool00oo<0?ooooooooooo`04oooo
o`03o`000?oooooooooo00kooooo00?oo`2Iooooooooool01?ooool5ool000Oooooo00?oo`00oooo
ooooool09Oooool:ool0037ooooo0ol0000Xooooo`03o`000?oooooooooo00Cooooo001Tooooo`03
o`000?oooooooooo03oooooo0_o<0?l8ooooo`03o`000?oooooooooo00_ooooo0_oo09T<ooooo`_o
o`005?ooool@ool003Oooooo1?l000000ooooooo0000ooooo`0Xooooo`03o`000?oooooooooo00Co
oooo001Uooooo`03o`000?oooooooooo03cooooo0_o<0?l;ooooo`03o`000?oooooooooo00Wooooo
00?oo`2Iooooooooool04Oooool00ooo003oooooooooo`03oooooaCoo`00A?ooool3o`0000Kooooo
00?o0000ooooooooool09_ooool00ol0003oooooooooo`04ooooo`00I_ooool00ol0003ooooooooo
o`0jooooo`03ol`0oooooooooooo00cooooo00?o0000ooooooooool01oooool00ooo09Wooooooooo
o`0Aooooo`03ool00?oooooooooo05Sooooo1?l0000:ooooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool01?ooool006Oooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`04
ooooo`;oo`2I4oooool00ooo003oooooooooo`1Fooooo`?o00003oooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo00?ooooo001Xooooo`03o`000?oooooooooo04Wooooo00?o0000oooo
ooooool00_ooool00ooo09Woooooooooo`0Booooo`03ool00?oooooooooo05Cooooo0ol0000Boooo
o`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00oooool006Wooooo00?o0000oooooooo
ool0BOooool01?l0003ooooooooooooo09TDooooo`03ool00?oooooooooo057ooooo1?l0000Foooo
o`03o`000?oooooooooo02Cooooo00?o0000ooooooooool00oooool006[ooooo0_l0001:ooooo`;o
o`2I5?ooool00ooo003oooooooooo`1?ooooo`?o00006oooool00ol0003oooooooooo`0Sooooo`03
o`000?oooooooooo00?ooooo001/ooooo`03o`000?oooooooooo04Gooooo0_oo09T00ooooooo0000
ooooo`0Aooooo`;oo`00C_ooool4o`0001oooooo00?o0000ooooooooool08_ooool00ol0003ooooo
ooooo`03ooooo`00KOooool00ol0003oooooooooo`13ooooo`03ool0VOoooooooooo00;ooooo00?o
0000ooooooooool03_ooool00ooo003oooooooooo`1;ooooo`?o00009?ooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo00?ooooo001^ooooo`03o`000?oooooooooo043ooooo0_oo09T6
ooooo`03o`000?oooooooooo00_ooooo0_oo001;ooooo`?o0000:?ooool00ol0003oooooooooo`0P
ooooo`03o`000?oooooooooo00?ooooo001_ooooo`03o`000?oooooooooo03gooooo0_oo09T9oooo
o`03o`000?oooooooooo00Wooooo00?oo`00ooooooooool0Aoooool4o`0002_ooooo00?o0000oooo
ooooool08?ooool00ol0003oooooooooo`03ooooo`00L?ooool00ol0003oooooooooo`0jooooo`;o
o`2I3?ooool00ol0003oooooooooo`07ooooo`03ool00?oooooooooo04Gooooo0ol0000`ooooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool00oooool0077ooooo00?o0000ooooooooool0
>?ooool00ooo09Woooooooooo`0=ooooo`03o`000?oooooooooo00Cooooo0_oo0014ooooo`Co0000
=?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00?ooooo001booooo`03o`000?oo
oooooooo03Gooooo0_oo09TAooooo`03o`000?oooooooooo00;ooooo00?oo`00ooooooooool0@Ooo
ool3o`0003Wooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`02ooooo`00Loooool0
0ol0003oooooooooo`0cooooo`03ool0VOoooooooooo01;ooooo00Co0000oooooooo003oo`00@Ooo
ool3o`0003gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`02ooooo`00M?ooool0
0ol0003oooooooooo`18ooooo`03ool00?oooooooooo03gooooo1?l00011ooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool00_ooool007Gooooo0_l00017ooooo`03ool00?oooooo0000
03_ooooo0ol00015ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool00_ooool007Oo
oooo00?o0000ooooooooool0@_ooool2ool000?ooooo00?o0000ooooooooool0=?ooool4o`0004Wo
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`02ooooo`00N?ooool00ol0003ooooo
ooooo`0oooooo`;oo`001_ooool00ol0003oooooooooo`0`ooooo`?o0000C_ooool00ol0003ooooo
ooooo`0Jooooo`03o`000?oooooooooo00;ooooo001iooooo`03o`000?oooooooooo03gooooo00?o
o`00ooooooooool01oooool00ol0003oooooooooo`0/ooooo`?o0000D_ooool00ol0003ooooooooo
o`0Iooooo`03o`000?oooooooooo00;ooooo001jooooo`03o`000?oooooooooo03[ooooo0_oo000;
ooooo`03o`000?oooooooooo02Oooooo1?l0001Fooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool00_ooool007_ooooo00?o0000ooooooooool0=oooool2ool000kooooo00?o0000oooo
ooooool08oooool3o`0005_ooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`02oooo
o`00O?ooool00ol0003oooooooooo`0dooooo`;oo`004Oooool00ol0003oooooooooo`0Nooooo`Co
0000G_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00;ooooo001mooooo`03o`00
0?oooooooooo03;ooooo00?oo`00ooooooooool04_ooool00ol0003oooooooooo`0Jooooo`?o0000
Hoooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo007ooooo001nooooo`03o`000?oo
oooooooo02oooooo0_oo000Fooooo`03o`000?oooooooooo01Kooooo0ol0001Wooooo`03o`000?oo
oooooooo01Kooooo00?o0000ooooooooool00Oooool007oooooo00?o0000ooooooooool0;Oooool0
0ooo003oooooooooo`0Gooooo`03o`000?oooooooooo017ooooo1?l0001[ooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool00Oooool0083ooooo0_l00018ooooo`03o`000?oooooooooo
00gooooo0ol0001`ooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00Oooool008;o
oooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`08ooooo`Co0000M?ooool00ol0003o
ooooooooo`0Cooooo`03o`000?oooooooooo007ooooo0023ooooo`03o`000?oooooooooo04Kooooo
00?o0000ooooooooool01?ooool3o`0007Sooooo00?o0000ooooooooool04oooool00ol0003ooooo
ooooo`01ooooo`00Q?ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo00?o0000O?oo
ool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo007ooooo0025ooooo`03o`000?oooooo
oooo04Kooooo0_l00020ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool00Oooool0
08Kooooo00?o0000ooooooooool0AOooool00ol0003oooooooooo`20ooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool00Oooool008Oooooo00?o0000ooooooooool0A?ooool00ol0003o
ooooooooo`21ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00Oooool008Sooooo
00?o0000ooooooooool0@oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo00oooooo
0Ol00001ooooo`7ooooo0029ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool0P_oo
ool00ol0003oooooooooo`0?ooooo`7o00000Oooool1ooooo`00R_ooool00ol0003oooooooooo`11
ooooo`03o`000?oooooooooo08?ooooo00?o0000ooooooooool03_ooool1o`00007ooooo0Oooool0
08_ooooo0_l00011ooooo`03o`000?oooooooooo08Cooooo00?o0000ooooooooool03Oooool1o`00
007ooooo0Oooool008gooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`25ooooo`03
o`000?oooooooooo00cooooo0Ol00001ooooo`7ooooo002>ooooo`03o`000?oooooooooo03gooooo
00?o0000ooooooooool0Q_ooool00ol0003oooooooooo`0;ooooo`7o00000Oooool1ooooo`00Sooo
ool00ol0003oooooooooo`0looooo`03o`000?oooooooooo08Oooooo00?o0000ooooooooool02_oo
ool1o`00007ooooo0Oooool0093ooooo00?o0000ooooooooool0>oooool00ol0003oooooooooo`27
ooooo`03o`000?oooooooooo00[ooooo0Ol00001ooooo`7ooooo002Aooooo`03o`000?oooooooooo
03[ooooo00?o0000ooooooooool0R?ooool00ol0003oooooooooo`09ooooo`7o00000Oooool1oooo
o`00T_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo08Wooooo00?o0000oooooooo
ool02?ooool1o`00007ooooo0Oooool009?ooooo00?o0000ooooooooool0>?ooool00ol0003ooooo
ooooo`2:ooooo`03o`000?oooooooooo00Sooooo0Ol00001ooooo`00U?ooool00ol0003ooooooooo
o`0gooooo`03o`000?oooooooooo08_ooooo00?o0000ooooooooool01oooool1o`00007ooooo002E
ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0S?ooool00ol0003oooooooooo`06
ooooo`7o00000Oooool009Kooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`2<oooo
o`03o`000?oooooooooo00Kooooo0Ol00001ooooo`00Uoooool2o`0003Gooooo00?o0000oooooooo
ool0SOooool00ol0003oooooooooo`05ooooo`7o00000Oooool009Wooooo00?o0000ooooooooool0
<_ooool00ol0003oooooooooo`2>ooooo`03o`000?oooooooooo00Cooooo0Ol00001ooooo`00V_oo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo08oooooo00?o0000ooooooooool00ooo
ool1o`00007ooooo002Kooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0T?ooool0
0ol0003oooooooooo`02ooooo`7o00000Oooool009cooooo00?o0000ooooooooool0;oooool00ol0
003oooooooooo`2Aooooo`05o`000?ooooooooooooooool000000Oooool009gooooo00?o0000oooo
ooooool0;_ooool00ol0003oooooooooo`2Aooooo`05o`000?ooooooooooooooool000000Oooool0
09kooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`2Booooo`04o`000?oooooooooo
ooooo`7o0000002Oooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0Toooool00ol0
003oooooooooo`01o`000000X?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo09Co
oooo0Ol00001ooooo`7o0000002Qooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool0
UOooool2o`000000X_ooool2o`0002[ooooo00?o0000ooooooooool0U?ooool3o`000000Y?ooool0
0ol0003oooooooooo`0Wooooo`03o`000?oooooooooo093ooooo1?l00003ooooo`00YOooool00ol0
003oooooooooo`0Vooooo`03o`000?oooooooooo08gooooo0ol00007ooooo`00Y_ooool00ol0003o
ooooooooo`0Uooooo`03o`000?oooooooooo08Wooooo1?l0000:ooooo`00Yoooool00ol0003ooooo
ooooo`0Tooooo`03o`000?oooooooooo08Gooooo1?l0000>ooooo`00Z?ooool00ol0003ooooooooo
o`0Sooooo`03o`000?oooooooooo08;ooooo0ol0000Booooo`00ZOooool00ol0003oooooooooo`0R
ooooo`03o`000?oooooooooo07kooooo1?l0000Eooooo`00Z_ooool00ol0003oooooooooo`0Qoooo
o`03o`000?oooooooooo07[ooooo1?l0000Iooooo`00Zoooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo07Gooooo1?l0000Mooooo`00[?ooool00ol0003oooooooooo`0Pooooo`03o`00
0?oooooooooo07;ooooo0ol0000Qooooo`00[Oooool2o`00023ooooo00?o0000ooooooooool0K_oo
ool4o`0002Cooooo002_ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0J_ooool4
o`0002Sooooo002`ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0Ioooool3o`00
02cooooo002aooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0Hoooool4o`0002oo
oooo002booooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0Goooool4o`0003?ooooo
002cooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0G?ooool3o`0003Oooooo002d
ooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0F?ooool4o`0003[ooooo002eoooo
o`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0E?ooool4o`0003kooooo002fooooo`03
o`000?oooooooooo01Kooooo00?o0000ooooooooool0D?ooool4o`0004;ooooo002gooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool0COooool3o`0004Kooooo002hooooo`;o00005Ooo
ool00ol0003oooooooooo`19ooooo`Co0000BOooool00;[ooooo00?o0000ooooooooool04_ooool0
0ol0003oooooooooo`15ooooo`Co0000COooool00;_ooooo00?o0000ooooooooool04Oooool00ol0
003oooooooooo`12ooooo`?o0000DOooool00;cooooo00?o0000ooooooooool04?ooool00ol0003o
ooooooooo`0nooooo`Co0000E?ooool00;gooooo00?o0000ooooooooool03oooool00ol0003ooooo
ooooo`0jooooo`Co0000F?ooool00;kooooo00?o0000ooooooooool03_ooool00ol0003ooooooooo
o`0fooooo`Co0000G?ooool00;oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0c
ooooo`?o0000H?ooool00<3ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0_oooo
o`Co0000Hoooool00<7ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0[ooooo`Co
0000Ioooool00<;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Xooooo`?o0000
Joooool00<?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Tooooo`Co0000K_oo
ool00<Cooooo0_l00009ooooo`03o`000?oooooooooo023ooooo1?l0001booooo`00a_ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo01gooooo0ol0001fooooo`00aoooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo01Wooooo1?l0001iooooo`00b?ooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo01Gooooo1?l0001mooooo`00bOooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo017ooooo1?l00021ooooo`00b_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00kooooo0ol00025ooooo`00boooool01Ol0003ooooooooooooooooo
000000cooooo1?l00028ooooo`00c?ooool01?l0003oooooooooool00008ooooo`Co0000S?ooool0
0<gooooo00?o0000ooooool000001Oooool3o`00093ooooo003>ooooo`;o000000?oooooo`000?l0
00000_l0002Cooooo`00coooool2o`0009Oooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {330.375, 0}} -> {-0.0771432, -0.0315529, \
0.00350368, 0.00350368}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .92059 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-16 1.0763 -0.0263982 1.0763 [
[.01694 .18568 -11.9631 -9 ]
[.01694 .18568 .03693 0 ]
[.13793 .13897 -11.619 -9 ]
[.13793 .13897 .38095 0 ]
[.26292 .09073 -5.63752 -9 ]
[.26292 .09073 .36248 0 ]
[.39212 .04087 -5.46552 -9 ]
[.39212 .04087 .53448 0 ]
[.52574 -0.01069 -5.29351 -9 ]
[.52574 -0.01069 .70649 0 ]
[.58272 .04263 0 -6.19654 ]
[.58272 .04263 6 2.80346 ]
[.71715 .21863 0 -6.07114 ]
[.71715 .21863 6 2.92886 ]
[.83675 .37523 0 -5.963 ]
[.83675 .37523 6 3.037 ]
[.94385 .51546 0 -5.8688 ]
[.94385 .51546 6 3.1312 ]
[.01386 .20006 -12 -2.76892 ]
[.01386 .20006 0 6.23108 ]
[.00748 .25499 -24 -2.80073 ]
[.00748 .25499 0 6.19927 ]
[.00093 .31131 -6 -2.83339 ]
[.00093 .31131 0 6.16661 ]
[-0.00579 .36907 -18 -2.86695 ]
[-0.00579 .36907 0 6.13305 ]
[-0.01268 .42831 -6 -2.90143 ]
[-0.01268 .42831 0 6.09857 ]
[ 0 0 0 0 ]
[ 1 .92059 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02642 .19522 m
.53391 0 L
s
.02642 .19522 m
.03116 .2 L
s
[(-2)] .01694 .18568 .99384 1 Mshowa
.14712 .14879 m
.15172 .1537 L
s
[(-1)] .13793 .13897 .93651 1 Mshowa
.2718 .10083 m
.27624 .10588 L
s
[(0)] .26292 .09073 .87917 1 Mshowa
.40066 .05126 m
.40493 .05646 L
s
[(1)] .39212 .04087 .82184 1 Mshowa
.53391 0 m
.538 .00534 L
s
[(2)] .52574 -0.01069 .7645 1 Mshowa
.125 Mabswid
.05025 .18606 m
.05308 .18894 L
s
.07424 .17683 m
.07705 .17973 L
s
.09837 .16755 m
.10117 .17046 L
s
.12267 .1582 m
.12545 .16113 L
s
.17173 .13933 m
.17447 .14229 L
s
.19651 .1298 m
.19923 .13278 L
s
.22144 .1202 m
.22414 .1232 L
s
.24654 .11055 m
.24922 .11356 L
s
.29723 .09105 m
.29988 .0941 L
s
.32283 .0812 m
.32546 .08427 L
s
.3486 .07129 m
.35121 .07437 L
s
.37455 .06131 m
.37713 .06441 L
s
.42695 .04115 m
.4295 .04428 L
s
.45342 .03096 m
.45594 .03412 L
s
.48007 .02071 m
.48257 .02388 L
s
.5069 .01039 m
.50938 .01358 L
s
.25 Mabswid
.53391 0 m
.9804 .58403 L
s
.57014 .04738 m
.56384 .04975 L
s
[(0)] .58272 .04263 -1 .37701 Mshowa
.70445 .22307 m
.6981 .22529 L
s
[(2)] .71715 .21863 -1 .34914 Mshowa
.82396 .37939 m
.81756 .38147 L
s
[(4)] .83675 .37523 -1 .32511 Mshowa
.93098 .51938 m
.92454 .52134 L
s
[(6)] .94385 .51546 -1 .30418 Mshowa
.125 Mabswid
.60525 .09331 m
.60147 .09471 L
s
.63931 .13786 m
.63552 .13924 L
s
.67236 .1811 m
.66856 .18245 L
s
.73562 .26383 m
.7318 .26514 L
s
.7659 .30345 m
.76207 .30473 L
s
.79534 .34195 m
.7915 .34322 L
s
.85181 .41581 m
.84796 .41704 L
s
.87891 .45126 m
.87506 .45247 L
s
.90529 .48577 m
.90143 .48696 L
s
.95601 .55212 m
.95214 .55328 L
s
.25 Mabswid
.02642 .19522 m
0 .42381 L
s
.02642 .19522 m
.0327 .19281 L
s
[(-1)] .01386 .20006 1 -0.38468 Mshowa
.02006 .25024 m
.02635 .24786 L
s
[(-0.5)] .00748 .25499 1 -0.37762 Mshowa
.01354 .30664 m
.01985 .3043 L
s
[(0)] .00093 .31131 1 -0.37036 Mshowa
.00686 .36448 m
.01318 .36218 L
s
[(0.5)] -0.00579 .36907 1 -0.3629 Mshowa
0 .42381 m
.00634 .42156 L
s
[(1)] -0.01268 .42831 1 -0.35524 Mshowa
.125 Mabswid
.02516 .20612 m
.02893 .20468 L
s
.0239 .21707 m
.02767 .21563 L
s
.02262 .22807 m
.0264 .22664 L
s
.02135 .23913 m
.02512 .2377 L
s
.01877 .26141 m
.02255 .25999 L
s
.01747 .27263 m
.02125 .27122 L
s
.01617 .28391 m
.01995 .2825 L
s
.01486 .29525 m
.01864 .29384 L
s
.01222 .31809 m
.01601 .3167 L
s
.01089 .3296 m
.01468 .32821 L
s
.00955 .34117 m
.01334 .33978 L
s
.00821 .35279 m
.012 .35141 L
s
.0055 .37622 m
.0093 .37485 L
s
.00414 .38803 m
.00793 .38666 L
s
.00276 .39989 m
.00656 .39853 L
s
.00139 .41182 m
.00519 .41047 L
s
.25 Mabswid
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.54154 .92059 L
s
.54154 .92059 m
.5414 .7134 L
s
.5414 .7134 m
.02642 .19522 L
s
.53391 0 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.53391 0 m
.02642 .19522 L
s
.5414 .7134 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.54154 .92059 L
s
.54154 .92059 m
.5414 .7134 L
s
0 0 m
1 0 L
1 .92059 L
0 .92059 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.46337 .71089 m
.51054 .68598 L
s
1 0 .6 r
.44627 .677 m
.49037 .6533 L
s
.8 0 1 r
.42917 .6431 m
.47021 .62065 L
s
.2 0 1 r
.41205 .60918 m
.45006 .58802 L
s
0 .4 1 r
.39492 .57524 m
.42993 .55542 L
s
0 1 1 r
.37779 .54129 m
.40982 .52285 L
s
0 1 .4 r
.36066 .50732 m
.38977 .49031 L
s
.2 1 0 r
.34356 .47335 m
.36997 .45781 L
s
.8 1 0 r
.32668 .4394 m
.35093 .42539 L
s
1 .6 0 r
.31039 .40552 m
.33336 .39299 L
s
.33336 .39299 m
.35382 .37965 L
s
.8 1 0 r
.35093 .42539 m
.37119 .41031 L
s
.2 1 0 r
.36997 .45781 m
.39111 .44074 L
s
0 1 .4 r
.38977 .49031 m
.41303 .47102 L
s
0 1 1 r
.40982 .52285 m
.43597 .50129 L
s
0 .4 1 r
.42993 .55542 m
.45928 .53161 L
s
.2 0 1 r
.45006 .58802 m
.48272 .56201 L
s
.8 0 1 r
.47021 .62065 m
.50623 .5925 L
s
1 0 .6 r
.49037 .6533 m
.52981 .62307 L
s
1 0 0 r
.51054 .68598 m
.55344 .65375 L
s
1 .6 0 r
.35382 .37965 m
.37201 .36673 L
s
.8 1 0 r
.37119 .41031 m
.38743 .39623 L
s
.2 1 0 r
.39111 .44074 m
.40578 .42535 L
s
0 1 .4 r
.41303 .47102 m
.42724 .45398 L
s
1 .6 0 r
.37201 .36673 m
.38942 .35486 L
s
0 1 1 r
.43597 .50129 m
.45108 .48218 L
s
.8 1 0 r
.38743 .39623 m
.40227 .38387 L
s
0 .4 1 r
.45928 .53161 m
.4762 .5102 L
s
.2 0 1 r
.48272 .56201 m
.50185 .53825 L
s
.2 1 0 r
.40578 .42535 m
.41769 .41275 L
s
1 .6 0 r
.38942 .35486 m
.40729 .34413 L
s
.8 0 1 r
.50623 .5925 m
.52773 .56641 L
s
0 1 .4 r
.42724 .45398 m
.43653 .44134 L
s
1 0 .6 r
.52981 .62307 m
.55375 .59471 L
s
.8 1 0 r
.40227 .38387 m
.4178 .37301 L
s
1 0 0 r
.55344 .65375 m
.5799 .62315 L
s
0 1 1 r
.45108 .48218 m
.45883 .46942 L
s
.2 1 0 r
.41769 .41275 m
.43025 .4021 L
s
1 .6 0 r
.40729 .34413 m
.42618 .33451 L
s
0 .4 1 r
.4762 .5102 m
.48357 .49704 L
s
.8 1 0 r
.4178 .37301 m
.43482 .36347 L
s
0 1 .4 r
.43653 .44134 m
.44575 .43146 L
s
1 .6 0 r
.42618 .33451 m
.44627 .32599 L
s
1 0 0 r
.5897 .64281 m
.66284 .6404 L
s
.52991 .63838 m
.5897 .64281 L
s
.2 1 0 r
.43025 .4021 m
.44479 .39288 L
s
.2 0 1 r
.50185 .53825 m
.50952 .52447 L
s
0 1 1 r
.45883 .46942 m
.46511 .46093 L
s
1 0 0 r
.66284 .6404 m
.72925 .63167 L
s
1 0 .6 r
.59093 .60434 m
.65878 .60207 L
s
.53597 .6002 m
.59093 .60434 L
s
1 0 0 r
.50172 .63422 m
.52991 .63838 L
s
.8 1 0 r
.43482 .36347 m
.45346 .35522 L
s
0 1 .4 r
.44575 .43146 m
.45707 .42307 L
s
1 0 .6 r
.65878 .60207 m
.72119 .59373 L
s
1 .6 0 r
.44627 .32599 m
.46754 .31859 L
s
.8 0 1 r
.52773 .56641 m
.53596 .55196 L
s
1 0 .6 r
.50919 .59618 m
.53597 .6002 L
s
0 .4 1 r
.48357 .49704 m
.48786 .49028 L
s
1 0 0 r
.5196 .63457 m
.50267 .63421 L
s
.54201 .63185 m
.5196 .63457 L
s
.8 0 1 r
.59218 .56575 m
.65473 .56361 L
s
.54206 .56191 m
.59218 .56575 L
s
1 0 0 r
.50267 .63421 m
.50172 .63422 L
s
.2 1 0 r
.44479 .39288 m
.46145 .38506 L
s
0 1 1 r
.46511 .46093 m
.47277 .45423 L
s
.8 0 1 r
.65473 .56361 m
.71312 .55568 L
s
1 0 0 r
.56347 .62531 m
.54201 .63185 L
s
.8 0 1 r
.51667 .55804 m
.54206 .56191 L
s
.8 1 0 r
.45346 .35522 m
.47357 .34831 L
s
1 0 .6 r
.50695 .59577 m
.50919 .59618 L
s
.51756 .59598 m
.50695 .59577 L
s
.53246 .59415 m
.51756 .59598 L
s
.2 0 1 r
.59344 .52702 m
.65066 .52502 L
s
.54816 .52351 m
.59344 .52702 L
s
0 1 .4 r
.45707 .42307 m
.47095 .41605 L
s
1 0 .6 r
.55375 .59471 m
.56263 .57958 L
s
1 .6 0 r
.46754 .31859 m
.48994 .31236 L
s
1 0 .6 r
.54679 .5897 m
.53246 .59415 L
s
.2 0 1 r
.65066 .52502 m
.70502 .51751 L
s
0 .4 1 r
.48786 .49028 m
.49204 .48617 L
s
.2 0 1 r
.50952 .52447 m
.51246 .51954 L
s
.8 0 1 r
.51123 .55722 m
.51667 .55804 L
s
.2 0 1 r
.52411 .51981 m
.54816 .52351 L
s
0 1 1 r
.47277 .45423 m
.48281 .44871 L
s
.2 1 0 r
.46145 .38506 m
.47991 .3788 L
s
.8 0 1 r
.51551 .55728 m
.51123 .55722 L
s
.52289 .55635 m
.51551 .55728 L
s
0 .4 1 r
.59469 .48816 m
.64658 .48631 L
s
.55419 .48502 m
.59469 .48816 L
s
.8 0 1 r
.53011 .55407 m
.52289 .55635 L
s
1 0 0 r
.57996 .61613 m
.56347 .62531 L
s
.8 1 0 r
.47357 .34831 m
.49495 .34283 L
s
0 .4 1 r
.64658 .48631 m
.6969 .47924 L
s
.49204 .48617 m
.49733 .48309 L
s
1 0 .6 r
.5577 .58353 m
.54679 .5897 L
s
.2 0 1 r
.51544 .51859 m
.52411 .51981 L
s
0 1 .4 r
.47095 .41605 m
.48693 .4107 L
s
1 .6 0 r
.48994 .31236 m
.51346 .30729 L
s
0 .4 1 r
.53122 .48158 m
.55419 .48502 L
s
.2 0 1 r
.51246 .51954 m
.51342 .5185 L
s
.8 0 1 r
.53549 .55098 m
.53011 .55407 L
s
1 0 0 r
.5799 .62315 m
.58946 .60736 L
s
.2 0 1 r
.51342 .5185 m
.51544 .51859 L
s
.51332 .51851 m
.51342 .5185 L
s
.51348 .51845 m
.51332 .51851 L
s
.51342 .5185 m
.51348 .51845 L
s
0 1 1 r
.59591 .4492 m
.64248 .44747 L
s
.55985 .44657 m
.59591 .4492 L
s
.48281 .44871 m
.49492 .44471 L
s
0 .4 1 r
.49733 .48309 m
.50387 .48096 L
s
.8 0 1 r
.53596 .55196 m
.53775 .54885 L
s
.2 1 0 r
.47991 .3788 m
.49973 .37425 L
s
0 1 1 r
.64248 .44747 m
.68876 .44086 L
s
.8 0 1 r
.53775 .54885 m
.53549 .55098 L
s
0 .4 1 r
.51923 .48009 m
.53122 .48158 L
s
.8 1 0 r
.49495 .34283 m
.51745 .33886 L
s
0 1 1 r
.5373 .44363 m
.55985 .44657 L
s
0 .4 1 r
.50387 .48096 m
.5111 .47997 L
s
1 .6 0 r
.51346 .30729 m
.5382 .30333 L
s
0 .4 1 r
.5111 .47997 m
.51923 .48009 L
s
0 1 .4 r
.48693 .4107 m
.50422 .40729 L
s
1 0 .6 r
.56327 .57827 m
.5577 .58353 L
s
0 1 .4 r
.59692 .41025 m
.63835 .40853 L
s
.56442 .40843 m
.59692 .41025 L
s
0 1 1 r
.49492 .44471 m
.50812 .44256 L
s
.52178 .44225 m
.5373 .44363 L
s
.2 1 0 r
.49973 .37425 m
.52052 .37153 L
s
0 1 .4 r
.63835 .40853 m
.68059 .40237 L
s
.54125 .40644 m
.56442 .40843 L
s
1 0 0 r
.58892 .60781 m
.57996 .61613 L
s
.8 1 0 r
.51745 .33886 m
.54118 .33635 L
s
0 1 1 r
.50812 .44256 m
.52178 .44225 L
s
1 .6 0 r
.5382 .30333 m
.56455 .30019 L
s
0 1 .4 r
.50422 .40729 m
.52219 .40592 L
s
.52219 .40592 m
.54125 .40644 L
s
.2 1 0 r
.59723 .37163 m
.63411 .36959 L
s
.56693 .3711 m
.59723 .37163 L
s
.52052 .37153 m
.54243 .37062 L
s
1 0 .6 r
.56263 .57958 m
.56327 .57827 L
s
.2 1 0 r
.54243 .37062 m
.56693 .3711 L
s
.8 1 0 r
.54118 .33635 m
.56689 .33501 L
s
.56689 .33501 m
.59612 .33382 L
s
.2 1 0 r
.63411 .36959 m
.67239 .36381 L
s
1 .6 0 r
.56455 .30019 m
.59312 .29715 L
s
.8 1 0 r
.59612 .33382 m
.62946 .33096 L
s
1 .6 0 r
.59312 .29715 m
.62397 .29304 L
s
.8 1 0 r
.62946 .33096 m
.6641 .32527 L
s
1 0 0 r
.58946 .60736 m
.58892 .60781 L
s
1 .6 0 r
.62397 .29304 m
.65554 .28702 L
s
0 g
.25 Mabswid
.53391 0 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.53391 0 m
.02642 .19522 L
s
.02642 .19522 m
.53391 0 L
s
.02642 .19522 m
.03116 .2 L
s
[(-2)] .01694 .18568 .99384 1 Mshowa
.14712 .14879 m
.15172 .1537 L
s
[(-1)] .13793 .13897 .93651 1 Mshowa
.2718 .10083 m
.27624 .10588 L
s
[(0)] .26292 .09073 .87917 1 Mshowa
.40066 .05126 m
.40493 .05646 L
s
[(1)] .39212 .04087 .82184 1 Mshowa
.53391 0 m
.538 .00534 L
s
[(2)] .52574 -0.01069 .7645 1 Mshowa
.125 Mabswid
.05025 .18606 m
.05308 .18894 L
s
.07424 .17683 m
.07705 .17973 L
s
.09837 .16755 m
.10117 .17046 L
s
.12267 .1582 m
.12545 .16113 L
s
.17173 .13933 m
.17447 .14229 L
s
.19651 .1298 m
.19923 .13278 L
s
.22144 .1202 m
.22414 .1232 L
s
.24654 .11055 m
.24922 .11356 L
s
.29723 .09105 m
.29988 .0941 L
s
.32283 .0812 m
.32546 .08427 L
s
.3486 .07129 m
.35121 .07437 L
s
.37455 .06131 m
.37713 .06441 L
s
.42695 .04115 m
.4295 .04428 L
s
.45342 .03096 m
.45594 .03412 L
s
.48007 .02071 m
.48257 .02388 L
s
.5069 .01039 m
.50938 .01358 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 265.125},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001Bb000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00`oooool5o`000:3ooooo0033ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@0X?ooool00<Cooooo00?oV9RHob4Q8Oo^k^h0XOooool00<Gooooo00?oV9RH
ob4Q8Oo^k^h0X?ooool00<Kooooo00?oMgMgofIVI_ooool0Woooool00<Oooooo00?o0000oooooooo
ool0W_ooool00<?ooooo00Go0000okZj^_ooooooV9RHoa0@402Pooooo`00`oooool01OnHV9So410@
o`000?lQ8B7oc<c<0:3ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003;ooooo`;o0000Voooool00<Sooooo0ol000000ooooooo0000ooooo`2Jooooo`00a_oo
ool2o`0000Cooooo0_l0002Jooooo`00`oooool3o`0000Kooooo00?o0000ooooool00000VOooool0
0<3ooooo1?l00008ooooo`04o`000?ooooooooooo`0009Sooooo002Hooooo`Co000000?o410@oooo
ooooool07oooool2o`0000Cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0002H
ooooo`00V_ooool00ol0003oooooooooo`0Nooooo`?o00003_ooool01Ol0003ooooooooooooooooo
000009Oooooo002Jooooo`03o`000?oooooooooo01cooooo0_l0000Aooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0U?ooool009[ooooo00?o0000ooooooooool06Oooool3o`0000;o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo09?o
oooo002Jooooo`03o`000?oooooooooo01Kooooo0ol0000Fooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^08Kooooo002Jooooo`03o`00
0?oooooooooo01Cooooo0_l0000Iooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1oooool01OmgMgOoV9RHoooooonHV9SoMgMg08Kooooo002Jooooo`03o`000?oooooooooo017ooooo
0ol000000ooooooo0000ooooo`0Hooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1_ooool01Ol@413ooooooooooooooooo410@08Kooooo002Hooooo`03oeEEEOmVIVKo0000017ooooo
0_l0000Nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool01Ol0003ooooo
oooooooooooo000008Kooooo002Yooooo`?o00008?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000026ooooo`00Yoooool3o`0002;ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@
4100Q_ooool00:Cooooo0ol00002ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Q_ooool00:7ooooo
0ol0000Xooooo`03o`000?oooooooooo00Sooooo0_l00004ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h0Q_ooool009oooooo0_l0000[ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo
0000S_ooool009cooooo0ol000000ooooooo0000ooooo`0Zooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0S?ooool009[ooooo0_l00005ooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`2;ooooo`00Uoooool3o`0003;ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`2:ooooo`00K?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^02?ooooo0ol000000ooooooo0000ooooo`0booooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0ROooool006cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Qooooo`;o0000>?ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo08Wooooo001/ooooo`05oa0@4?oooooooooo
ooooool@41007_ooool3o`0003[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`28
ooooo`00K?ooool01Ol0003ooooooooooooooooo000001cooooo0ol0000looooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0Qoooool006cooooo00Go0000ooooooooooooooooo`00000I
ooooo`?o00000_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool0Q_ooool006cooooo00Go410@oooooooooooooooooa0@400Gooooo`;o0000@_ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo08Kooooo001/ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL05?ooool3o`0004Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`25
ooooo`00K?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^017ooooo0ol00002ooooo`03o`000?oooooo
oooo04;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`24ooooo`00P?ooool2o`00
04[ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`23ooooo`00OOooool3o`0004co
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`22ooooo`00Noooool2o`000003oooo
ool0003ooooo04cooooo00?o0000ooooooooool05?ooool2o`0008?ooooo001hooooo`?o0000DOoo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooo000008?ooooo001eooooo`?o0000E?ooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo083ooooo001cooooo`Co0000EOooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo07oooooo001`ooooo`?o00001?ooool00ol0003o
ooooooooo`1Booooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0Ooooool006kooooo
0_l0001Looooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0O_ooool004?ooooo1?l0
00000ol@413oooooooooo`0Qooooo`?o0000G_ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo07gooooo0015ooooo`03o`000?oooooooooo023ooooo0ol00003ooooo`03o`000?oooooo
oooo05_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1looooo`00>_ooool6o`00
00Gooooo00?o0000ooooooooool07_ooool2o`0006Cooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`1looooo`00AOooool00ol0003oooooooooo`0Kooooo`?o0000I_ooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo07_ooooo0015ooooo`03o`000?oooooooooo01Wooooo
0_l00002ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`1jooooo`00AOooool00ol0003oooooooooo`0Fooooo`?o0000Joooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo07Wooooo0015ooooo`03o`000?oooooooooo01Cooooo0_l0001^
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0NOooool004?ooooo00?oEEEEofIV
I_l000004oooool3o`000003ooooool0003ooooo06gooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`1hooooo`00E_ooool3o`0007?ooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`1gooooo`00E?ooool2o`0007Kooooo00?o0000ooooooooool07oooool2o`0007Sooooo
001Aooooo`?o000000?oooooo`000?ooool0MOooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo07Kooooo001?ooooo`;o0000Noooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo07Gooooo001<ooooo`?o0000OOooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
07Cooooo0019ooooo`Co0000Ooooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo07?o
oooo0017ooooo`;o00001?ooool00ol0003oooooooooo`1looooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool0L_ooool004Cooooo0ol00025ooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool0L_ooool001[ooooo1Ol0000Sooooo`?o0000Qoooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo077ooooo000Jooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@08?ooool3
o`0000?ooooo00?o0000ooooooooool0Q?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo073ooooo000Booooo`Ko00000oooool00onHV9So8B4Qonk^kP0Oooooo`;o0000SOooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo06oooooo000Looooo`03oiRHV?lQ8B7ok^k^01_o
oooo0ol0002?ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0Koooool001gooooo
00?oMgMgofIVI_ooool05oooool3o`0000?ooooo00?o0000ooooooooool0S?ooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooooooo06kooooo000Nooooo`03o`000?oooooooooo01Cooooo0_l0
002Eooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0KOooool001[ooooo00Go0000
okZj^_ooooooV9RHoa0@400Cooooo`?o0000Uoooool00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo06cooooo000Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`04Oooool2o`0000?ooooo00?o
0000ooooooooool0U?ooool00ol0003oooooooooo`0Zooooo`;o0000KOooool002gooooo0ol0002L
ooooo`03o`000?oooooooooo02[ooooo0_l0001]ooooo`00:_ooool3o`0009oooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`1Zooooo`00:?ooool2o`0000?ooooo00?o0000oooooooo
ool0W?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo06Wooooo000Uooooo`?o0000
Y?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo06Wooooo000Tooooo`03o`000?oo
oooooooo0:Gooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1Xooooo`006_ooool4
o`000003oa0@4?oooooooooo00?ooooo0_l0002Vooooo`03o`000?oooooooooo02oooooo00?o0000
ooooooooool0Ioooool001cooooo00?o0000ooooooooool01Oooool2o`000:Kooooo00?o0000oooo
ooooool0<?ooool00ol0003oooooooooo`1Vooooo`004Oooool6o`0000Gooooo00?o0000oooooooo
ool01?ooool4o`000:Gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`08ooooo`Go
0000FOooool001cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0002Tooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool01OnHV9So8B4Qonk^k_ooooooA4A4
05Wooooo000Looooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`2Qooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool01oooool00onHV9So
8B4Qonk^kP1Jooooo`007?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0X?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Oooooo
00?oV9RHob4Q8Oo^k^h0FOooool001cooooo00?o0000ooooooooool01?ooool2o`0000Gooooo00?o
0000ooooooooool0Woooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Oooooo00?o
MgMgofIVI_ooool0F?ooool001[ooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo09kooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo05Oooooo000Sooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0WOooool00ol0003oooooooooo`0eooooo`;o00001?ooool01Ol0003o^[ZjoooooonHV9So
410@05Wooooo000Sooooo`;o00002?ooool00ol0003oooooooooo`2Looooo`03o`000?oooooooooo
03?ooooo0_l000000ooooooo0000ooooo`03ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0FOooool0
02?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2Kooooo`03o`000?oooooooooo
03Oooooo00?o0000ooooooooool0Goooool002?ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`2Jooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0Goooool002?ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`2Hooooo`;o0000>_ooool00ol0003ooooo
ooooo`1Nooooo`008_ooool2o`0000gooooo00?o0000ooooooooool0U?ooool3o`000003ooooool0
003ooooo03[ooooo00?o0000ooooooooool0GOooool002;ooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`2@ooooo`?o00001Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooo
oooo05cooooo000Rooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0S?ooool3o`00
00Wooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1Looooo`008_ooool3o`0000oo
oooo00?o0000ooooooooool0R?ooool3o`0000gooooo00?o0000ooooooooool0>?ooool00ol0003o
ooooooooo`1Kooooo`008_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo08Gooooo
0_l0000Aooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0F_ooool002;ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`21ooooo`?o00005?ooool00ol0003ooooooooo
o`0hooooo`03o`000?oooooooooo05Wooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool0OOooool3o`0001Oooooo00?o0000ooooooooool0>?ooool00ol0003ooooo
ooooo`1Iooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1iooooo`?o0000
6oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo05Sooooo0005o`0000;ooooo00Go
410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`1eooooo`?o00007oooool00ol0003oooooooooo`0hooooo`03o`00
0?oooooooooo05Oooooo0007ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8b
ooooo`03ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0LOooool3o`0002?ooooo
00?o0000ooooooooool0=oooool2o`0005Sooooo0007ooooo`05o`000?ooooooooooooooool00000
3?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`1^ooooo`;o00009oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo05Go
oooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`;o
00006Oooool00ol0003oooooooooo`1Zooooo`?o0000:_ooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo05Gooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0I_ooool3o`0002go
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1Dooooo`001oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool0H_ooool3o`00037ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1Cooooo`00
8Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo05kooooo0ol0000eooooo`03o`00
0?oooooooooo03Sooooo00?o0000ooooooooool0D_ooool0023ooooo0ol0000Mooooo`03o`000?oo
oooooooo05_ooooo0_l0000iooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0D_oo
ool0027ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1Gooooo`?o0000??ooool0
0ol0003oooooooooo`0Eooooo`?ooiT07oooool00ol0003oooooooooo`1Aooooo`008?ooool00ol0
003oooooooooo`0Oooooo`03o`000?oooooooooo05?ooooo0ol00010ooooo`03o`000?oooooooooo
00oooooo1OooV@0Sooooo`03o`000?oooooooooo053ooooo000Pooooo`03o`000?oooooooooo023o
oooo00?o0000ooooooooool0Coooool3o`0004?ooooo00?o0000ooooooooool02_ooool5oonI02Wo
oooo00?o0000ooooooooool0Coooool0023ooooo0_l0000Rooooo`03o`000?oooooooooo04_ooooo
0ol00017ooooo`03o`000?oooooooooo00Cooooo1OooV@0^ooooo`03o`000?oooooooooo04oooooo
000Pooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool0B?ooool2o`0004Wooooo0_oo
V@000ol0003ooiT0oonI0003oonI03Cooooo00?o0000ooooooooool0C_ooool0023ooooo00?o0000
ooooooooool08oooool00ol0003oooooooooo`14ooooo`?o0000@_ooool9oonI00?ooooo00?o0000
ooooooooool0=oooool00ol0003oooooooooo`1=ooooo`008?ooool3o`0002Cooooo00?o0000oooo
ooooool0@?ooool3o`0003cooooo2OooV@0=ooooo`03o`000?oooooooooo03Kooooo0_l0001>oooo
o`008?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03cooooo0ol0000iooooo`Ko
oiT05oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo04cooooo000Dooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo03So
oooo0ol0000hooooo`CooiT07Oooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo04_o
oooo000Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`0Xooooo`03
o`000?oooooooooo03Gooooo0_l0000gooooo`CooiT08_ooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo04[ooooo000Dooooo`05oa0@4?ooooooooooooooool@41001_ooool2o`0002[o
oooo00?o0000ooooooooool0<Oooool3o`0003Kooooo0oooV@0Wooooo`03o`000?oooooooooo03Oo
oooo00?o0000ooooooooool0BOooool001Cooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo02[ooooo00?o0000ooooooooool0;Oooool3o`0003Gooooo1?ooV@0[ooooo`03
o`000?oooooooooo03Kooooo00?o0000ooooooooool0BOooool001Cooooo00Go0000oooooooooooo
ooooo`000006ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0:Oooool3o`0003Go
oooo0oooV@0`ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0B?ooool001Cooooo
00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo02cooooo00?o0000oooooooo
ool09Oooool3o`0003Gooooo0oooV@0dooooo`03o`000?oooooooooo00cooooo1?o<o`0Vooooo`03
o`000?oooooooooo04Oooooo000Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool2o`0002ko
oooo00?o0000ooooooooool08Oooool3o`0003Gooooo0oooV@0gooooo`03o`000?oooooooooo00Oo
oooo1Oo<o`0[ooooo`03o`000?oooooooooo04Kooooo000Dooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h01_ooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo01kooooo0_l0000fooooo`;o
oiT0>oooool00ol0003oc?l0olco0006olco037ooooo00?o0000ooooooooool0AOooool001oooooo
00?o0000ooooooooool0;oooool00ol0003oooooooooo`0Jooooo`?o0000=_ooool2oonI02[ooooo
5?o<o`000ol0003oooooooooo`0fooooo`03o`000?oooooooooo04Gooooo000Nooooo`03o`000?oo
oooooooo037ooooo00?o0000ooooooooool05_ooool3o`0003Oooooo0_ooV@0Nooooo`koc?l05Ooo
ool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo04Cooooo000Nooooo`;o0000<oooool0
0ol0003oooooooooo`0Booooo`?o0000>?ooool2oonI01cooooo1?o<o`0Tooooo`03o`000?oooooo
oooo03Kooooo0_l00014ooooo`007_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo
00kooooo0ol0000iooooo`;ooiT06_ooool4olco02Wooooo00?o0000ooooooooool0=?ooool00ol0
003oooooo`000014ooooo`007_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00_o
oooo0_l0000kooooo`03oonI0?oooooooooo01Oooooo0oo<o`0]ooooo`03o`000?oooooooooo03Ko
oooo00?o0000ooooooooool0@_ooool001kooooo00?o0000ooooooooool0=Oooool00ol0003ooooo
ooooo`07ooooo`?o0000>oooool2oonI01Kooooo1?o<o`0aooooo`03o`000?oooooooooo03Kooooo
00?o0000ooooooooool0@Oooool001kooooo0_l0000gooooo`03o`000?oooooooooo00?ooooo0ol0
000mooooo`03oonI0?oooooooooo01?ooooo0oo<o`0fooooo`03o`000?oooooooooo03Kooooo00?o
0000ooooooooool0@?ooool001kooooo00?o0000ooooooooool0=oooool00ol0003oooooo`000002
o`0003kooooo0_ooV@0Cooooo`?oc?l0>_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooo
oooo03oooooo000Nooooo`03o`000?oooooooooo03Kooooo0ol00010ooooo`03oonI0?oooooooooo
017ooooo0_o<o`0nooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0?oooool001ko
oooo0_l0000eooooo`;o00000oooool00ol0003oooooooooo`0kooooo`;ooiT04_ooool2olco047o
oooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`09ooooo`;o000000?o410@oooooooo
ool0<?ooool001gooooo00?o0000ooooooooool0<_ooool3o`0000Kooooo00?o0000ooooooooool0
>Oooool00oooV@3oooooooooo`0@ooooo`;oc?l0@oooool00ol0003oooooooooo`05ooooo`Co<ol0
;Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo037ooooo0002ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03
o`000?oooooooooo02oooooo0ol0000:ooooo`03o`000?oooooooooo03Kooooo0_ooV@0Aooooo`;o
c?l0A_ooool00ol0003o<ol0oc?o0004oc?o03;ooooo00?o0000ooooooooool01Oooool5o`0003;o
oooo0002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL01Oooool2ob4Q8@Sooooo00?oMgMgoc8b<_oo
ool01?ooool00ol0003oooooooooo`0/ooooo`?o00003_ooool00ol0003oooooooooo`0dooooo`03
oonI0?oooooooooo013ooooo00?oc?l0ooooooooool06oooool[oc?o0003ooooool0003ooooo03Ko
oooo00?o0000ooooooooool01Oooool01?m4A4CogMgMooooool0000cooooo`000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool2o`0002[ooooo0ol0000Boooo
o`03o`000?oooooooooo037ooooo0_ooV@0Aooooo`;oc?l06?ooool6oc?o02gooooo00?o0000oooo
ooooool0=Oooool00ol0003oooooooooo`04ooooo`04omgMgOmEEEGoooooo`0003?ooooo0002oooo
o`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo
oooo02Oooooo0_l0000Fooooo`03o`000?oooooooooo02oooooo00?ooiT0ooooooooool03oooool2
olco01Oooooo0olco`0dooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool01?ooool0
0omgMgOoc<c<o`00000cooooo`000_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000
ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo02Cooooo0ol0000Iooooo`03o`000?oo
oooooooo02cooooo0_ooV@0@ooooo`;oc?l05_ooool3oc?o03Sooooo00?o0000ooooooooool0=?oo
ool2o`0000Gooooo00?ok^k^odA4A?l00000<oooool000;ooooo00Go410@oooooooooooooooooa0@
400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08Oooool3o`0001gooooo00?o
0000ooooooooool0:_ooool00oooV@3oooooooooo`0>ooooo`;oc?l05Oooool3oc?o03_ooooo00?o
0000ooooooooool0<oooool01?l0003oooooooooool00005ooooo`03ogMgMol0003ooooo03;ooooo
0002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`;o0000
7oooool3o`00027ooooo00?o0000ooooooooool09oooool2oonI013ooooo00?oc?l0ooooooooool0
4_ooool3oc?o03oooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0hooooo`000_oo
ool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo01cooooo
0ol0000Uooooo`03o`000?oooooooooo02Gooooo00?ooiT0ooooooooool03oooool00oo<o`3ooooo
ooooo`0@ooooo`?o<ol0@oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo03Oooooo
000Looooo`03o`000?oooooooooo01Wooooo0ol0000Yooooo`03o`000?oooooooooo02;ooooo0_oo
V@0Aooooo`03olco0?oooooooooo00kooooo0olco`17ooooo`03o`000?oooooooooo03Gooooo00?o
0000ooooooooool0=_ooool001cooooo00?o0000ooooooooool05oooool2o`0002gooooo00?o0000
ooooooooool08?ooool00oooV@3oooooooooo`0@ooooo`03olco0?oooooooooo00kooooo00?o<ol0
ooooooooool0BOooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo03Gooooo000Loooo
o`;o00005Oooool3o`00033ooooo00?o0000ooooooooool07Oooool2oonI01;ooooo00?oc?l0oooo
ooooool03_ooool00olco`3oooooooooo`1;ooooo`03o`000?oooooooooo03Cooooo00?o0000oooo
ooooool0=Oooool001cooooo00?o0000ooooooooool04Oooool3o`0003Cooooo00?o0000oooooooo
ool06_ooool2oonI01?ooooo00?oc?l0ooooooooool03Oooool2oc?o04kooooo00?o0000oooooooo
ool0=Oooool00ol0003oooooooooo`0dooooo`007?ooool00ol0003oooooooooo`0>ooooo`?o0000
>?ooool00ol0003oooooooooo`0Hooooo`03oonI0?oooooooooo01;ooooo00?oc?l0ooooooooool0
3Oooool00olco`3oooooooooo`1?ooooo`04o`000?l0ofKo0?mVo`3oISCooooo00?o0000oooooooo
ool0<oooool001cooooo00?o0000ooooooooool02oooool3o`0003cooooo00?o0000ooooooooool0
5_ooool00oooV@3oooooooooo`0Booooo`03olco0?oooooooooo00gooooo00?o<ol0ooooooooool0
5OoooolDo`3oIR3ooooo1ol0ofH00ooooooo0000ooooo`0fooooo`03o`000?oooooooooo03;ooooo
000Looooo`;o00002_ooool2o`00043ooooo00?o0000ooooooooool0:?ooool2olco00oooooo00?o
<ol0ooooooooool04_ooool4o`3oIQCooooo8?l0ofH9ooooo`03o`000?oooooooooo03Cooooo00?o
0000ooooooooool0<_ooool001_ooooo0_l00008ooooo`?o0000@oooool00ol0003oooooooooo`0V
ooooo`03olco0?oooooooooo00kooooo00?o<ol0ooooooooool04?ooool3o`3oIT;ooooo00?o0000
ooooooooool0=?ooool00ol0003oooooooooo`0aooooo`006oooool00ol0003oooooooooo`04oooo
o`?o0000Aoooool00ol0003oooooooooo`0Sooooo`;oc?l04Oooool00olco`3oooooooooo`0>oooo
o`;o0?mVA_ooool00ol0003oooooooooo`0cooooo`;o0000<_ooool001_ooooo00Co0000oooooooo
oooooooo0ol0001;ooooo`03o`000?oooooooooo027ooooo00?oc?l0ooooooooool04?ooool00olc
o`3oooooooooo`0=ooooo`;o0?mVB?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo
02oooooo000Kooooo`Co0000Coooool00ol0003oooooooooo`0Oooooo`03olco0?oooooooooo013o
oooo00?o<ol0ooooooooool03?ooool2o`3oIT_ooooo00?o0000ooooooooool0=?ooool00ol0003o
ooooooooo`0_ooooo`006oooool2o`0005;ooooo00?o0000ooooooooool07?ooool2olco01;ooooo
00?o<ol0ooooooooool03?ooool00ol0ofKoooooooooo`1<ooooo`03o`000?oooooooooo03Cooooo
00?o0000ooooooooool0;_ooool0017ooooo1?l000000ol@413oooooooooo`05ooooo`03o`000?oo
oooooooo053ooooo00?o0000ooooooooool06_ooool00oo<o`3oooooooooo`0Aooooo`03oc?o0?oo
oooooooo00cooooo00?o0?mVooooooooool0C_ooool00ol0003oooooooooo`0dooooo`03o`000?oo
oooooooo02gooooo000Cooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0D?ooool0
0ol0003oooooooooo`0Gooooo`;oc?l04oooool00olco`3oooooooooo`0<ooooo`03o`3oI_oooooo
oooo053ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0/ooooo`004oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool05?ooool2olco
01Cooooo00?o<ol0ooooooooool03?ooool00ol0ofKoooooooooo`1Booooo`03o`000?oooooooooo
03?ooooo00?o0000ooooooooool0;?ooool001?ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`1@ooooo`03o`000?oooooooooo01;ooooo00?oc?l0ooooooooool04oooool00olco`3o
ooooooooo`0<ooooo`03o`3oI_oooooooooo05?ooooo00?o0000ooooooooool0=?ooool00ol0003o
ooooooooo`0[ooooo`004oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo053ooooo
00?o0000ooooooooool04?ooool00oo<o`3oooooooooo`0Booooo`;o<ol03_ooool00ol0ofKooooo
ooooo`1<ooooo`Go0?oo1?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02[ooooo
000Cooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`0Sooooo`03oc?o0?oooooooooo00kooooo00?o0?mVooooooooool04_oooolAo`3oob;ooooo1ol0
ool:ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0:Oooool001?ooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo027ooooo00?o<ol0
ooooooooool03_ooool00ol0ofKoooooooooo`0?ooooo`Co0?oo4Oooool:o`3oo`gooooo2ol0oolB
ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0:?ooool0017ooooo00?oEEEEofIV
I_l000004?ooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo01oooooo00?o<ol0oooo
ooooool03_ooool00ol0ofKoooooooooo`0=ooooo`?o0?oo7oooool=o`3ooakooooo00?o0000oooo
ooooool0<oooool00ol0003oooooooooo`0Xooooo`009Oooool00ol0003oooooooooo`1@ooooo`03
o`000?oooooooooo01gooooo00?o<ol0ooooooooool03oooool00ol0ofKoooooooooo`0<ooooo`03
o`3ooooooooooooo04cooooo00?o0000ooooooooool0<_ooool2o`0002Wooooo000Vooooo`;o0000
DOooool00ol0003oooooooooo`0Kooooo`03oc?o0?oooooooooo00oooooo00?o0?mVooooooooool0
2oooool2o`3oodoooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Vooooo`00:?oo
ool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo01Wooooo0_lco`0Aooooo`03o`3oI_oo
oooooooo00_ooooo00?o0?ooooooooooool0D?ooool00ol0003oooooooooo`0dooooo`03o`000?oo
oooooooo02Gooooo000Yooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool05_ooool2
oc?o01;ooooo00?o0?mVooooooooool02oooool00ol0ooooooooooooo`1Booooo`03o`000?oooooo
oooo03?ooooo00?o0000ooooooooool09Oooool002[ooooo00?o0000ooooooooool0C_ooool00ol0
003oooooooooo`0Cooooo`;o<ol04oooool00ol0ofKoooooooooo`0<ooooo`03o`3ooooooooooooo
05?ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Tooooo`00:oooool00ol0003o
ooooooooo`1>ooooo`03o`000?oooooooooo017ooooo00?o<ol0ooooooooool04_ooool00ol0ofKo
ooooooooo`0<ooooo`03o`3ooooooooooooo05Gooooo00?o0000ooooooooool0<oooool00ol0003o
ooooooooo`0Sooooo`00;?ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo00kooooo
0_lco`0Cooooo`;o0?mV3_ooool00ol0ooooooooooooo`1Gooooo`03o`000?oooooooooo03?ooooo
00?o0000ooooooooool08_ooool002gooooo00?o0000ooooooooool0C_ooool00ol0003ooooooooo
o`0<ooooo`03oc?o0?oooooooooo01;ooooo00?o0?mVooooooooool03_ooool00ol0oooooooooooo
o`1Gooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool08_ooool002kooooo00?o0000
ooooooooool0C_ooool00ol0003oooooooooo`0Oooooo`03o`3oI_oooooooooo00kooooo00?o0?oo
ooooooooool0FOooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo027ooooo000_oooo
o`03o`000?oooooooooo04kooooo00?o0000ooooooooool07Oooool00ol0ofKoooooooooo`0?oooo
o`03o`3ooooooooooooo00kooooo1ol0I_ldooooo`Go06Ko3?ooool00ol0003oooooooooo`0coooo
o`03o`000?oooooooooo023ooooo000`ooooo`03o`000?oooooooooo04kooooo00?o0000oooooooo
ool06oooool00ol0ofKoooooooooo`0?ooooo`03o`3ooooooooooooo00_ooooo1?l0I_l7ooooo`Ko
06Ko9Oooool9o`1Voa;ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Oooooo`00
<Oooool2o`0004oooooo00?o0000ooooooooool06Oooool00ol0ofKoooooooooo`0@ooooo`03o`3o
oooooooooooo00[ooooo00?o06Koooooooooool03oooool;o`1Vo`kooooo3?l0I_lLooooo`03o`00
0?oooooooooo03;ooooo0_l0000Pooooo`00<oooool00ol0003oooooooooo`1=ooooo`03o`000?oo
oooooooo01Oooooo00?o0?mVooooooooool04?ooool00ol0ooooooooooooo`0;ooooo`03o`1Voooo
oooooooo01[ooooo3_l0I_lYooooo`03o`000?oooooooooo037ooooo0_l0000Pooooo`00=?ooool0
0ol0003oooooooooo`1=ooooo`03o`000?oooooooooo01Cooooo0_l0ofHBooooo`03o`3ooooooooo
oooo00_ooooo00?o06Koooooooooool0D_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooo
oooo01gooooo000eooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool04Oooool2o`3o
IQ?ooooo00?o0?ooooooooooool02oooool00ol0I_ooooooooooo`1Dooooo`03o`000?oooooooooo
03?ooooo00?o0000ooooooooool07?ooool003Kooooo00?o0000ooooooooool0COooool00ol0003o
ooooooooo`0>ooooo`;o0?mV5?ooool00ol0ooooooooooooo`0;ooooo`03o`1Voooooooooooo05Ko
oooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Looooo`00=oooool00ol0003ooooo
ooooo`1=ooooo`03o`000?oooooooooo00cooooo00?o0?mVooooooooool04_ooool2o`3oo`kooooo
00?o06Koooooooooool0Eoooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01_ooooo
000hooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool02Oooool2o`3oIQCooooo00?o
0?ooooooooooool03Oooool00ol0I_ooooooooooo`1Iooooo`03o`000?oooooooooo03;ooooo00?o
0000ooooooooool01oooool01Oo^k^ko<S8bo`000?l@413oc<c<00kooooo000iooooo`03o`000?oo
oooooooo04gooooo00?o0000ooooooooool01oooool00ol0ofKoooooooooo`0Cooooo`03o`3ooooo
oooooooo00kooooo00?o06Koooooooooool0F_ooool00ol0003oooooooooo`0booooo`03o`000?oo
oooooooo00Kooooo00GoEEEEogMgMoooooooV9RHob4Q8@0>ooooo`00>_ooool00ol0003ooooooooo
o`1=ooooo`03o`000?oooooooooo01[ooooo0_l0ool@ooooo`03o`1Voooooooooooo05_ooooo00?o
0000ooooooooool0<oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool00000
3_ooool003_ooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0Hooooo`03o`3ooooo
oooooooo013ooooo00?o06Koooooooooool0G?ooool00ol0003oooooooooo`0booooo`03o`000?oo
oooooooo00Gooooo00Go0000oiRHV?ooooooV9RHob4Q8@0>ooooo`00??ooool00ol0003ooooooooo
o`1=ooooo`03o`000?oooooooooo01Kooooo00?o0?ooooooooooool04?ooool00ol0I_oooooooooo
o`1Nooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool01?ooool01Ol0003oEEEEo`00
0?l@413oc<c<00kooooo000mooooo`;o0000C_ooool00ol0003oooooooooo`0Dooooo`03o`3ooooo
oooooooo013ooooo00?o06Koooooooooool02oooool7oc<0ocGooooo1Olc0?lDooooo`03o`000?oo
oooooooo03;ooooo0_l00004ooooo`03oeEEEOn7QhOooooo013ooooo000oooooo`03o`000?oooooo
oooo04cooooo00?o0000ooooooooool04Oooool2o`3ooa;ooooo00?o06Koooooooooool03?ooool0
0olc0?ooooooooooo`04ooooo`Co<`3o:?ooool9oc<0oa[ooooo00?o0000ooooooooool0;oooool2
o`000003ooooool0003ooooo00?ooooo00?ogMgMoa0@4?nHV9P04?ooool0043ooooo00?o0000oooo
ooooool0C?ooool00ol0003oooooooooo`0?ooooo`03o`3ooooooooooooo017ooooo00?o06Kooooo
ooooool03?ooool00olc0?ooooooooooo`09ooooo`[o<`3o4?ooool>oc<0obCooooo00?o0000oooo
ooooool0<Oooool00ol0003oooooooooo`03ooooo`04olc<c?m4A4Co0000oa0@40kooooo0011oooo
o`03o`000?oooooooooo04cooooo00?o0000ooooooooool03?ooool2o`3ooa?ooooo00?o06Kooooo
ooooool03Oooool00olc0?ooooooooooo`0Coooooa3o<`3o<_ooool00ol0003oooooooooo`0boooo
o`03o`000?oooooooooo01Cooooo0012ooooo`03o`000?oooooooooo04cooooo00?o0000oooooooo
ool02Oooool2o`3ooa?ooooo0_l0I_l?ooooo`03oc<0oooooooooooo05Oooooo00?o0000oooooooo
ool0<_ooool00ol0003oooooooooo`0Cooooo`00@oooool00ol0003oooooooooo`1<ooooo`03o`00
0?oooooooooo00Oooooo00?o0?ooooooooooool04_ooool00ol0I_ooooooooooo`0>ooooo`03oc<0
oooooooooooo05Wooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Booooo`00A?oo
ool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo00Cooooo0_l0oolDooooo`03o`1Voooo
oooooooo00oooooo00?o<`3oooooooooool0F_ooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo01;ooooo0015ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool00_ooool0
0ol0ooooooooooooo`0Cooooo`03o`1Voooooooooooo00oooooo00?o<`3oooooooooool0G?ooool0
0ol0003oooooooooo`0aooooo`03o`000?oooooooooo017ooooo0016ooooo`03o`000?oooooooooo
04cooooo00Co0000oooooooooooo0?oo5Oooool00ol0I_ooooooooooo`0@ooooo`03oc<0oooooooo
oooo05gooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0@ooooo`00Aoooool00ol0
003oooooooooo`1<ooooo`03o`000?oooooooooo01Cooooo00?o06Koooooooooool04?ooool00olc
0?ooooooooooo`1Nooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool03oooool004So
oooo0_l0001=ooooo`03o`000?oooooooooo01;ooooo00?o06Koooooooooool04?ooool00olc0?oo
ooooooooo`0;ooooo`03ol`0oooooooooooo05;ooooo00?o0000ooooooooool0<Oooool00ol0003o
ooooooooo`0?ooooo`00B_ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo013ooooo
00?o06Koooooooooool04?ooool00olc0?ooooooooooo`0;ooooo`;oc03oEOooool00ol0003ooooo
ooooo`0aooooo`;o00003oooool004_ooooo00?o0000ooooooooool0Boooool00ol0003ooooooooo
o`0=ooooo`;o06Ko4_ooool00olc0?ooooooooooo`0:ooooo`;oc03o00?ooooool`0ooooool0=Ooo
ool4ol`0oacooooo00?o0000ooooooooool0<?ooool2o`0000oooooo001<ooooo`03o`000?oooooo
oooo04_ooooo00?o0000ooooooooool02_ooool2o`1Voa?ooooo00?o<`3oooooooooool01Oooool9
ol`0oc3ooooo1oo<0?lQooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool03?ooool0
04gooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`08ooooo`03o`1Voooooooooooo
017ooooo0_lc0?l?ooooo`Woc03o8oooool6ol`0obWooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`0;ooooo`00C_ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo00Go
oooo0_l0I_lCooooo`03oc<0oooooooooooo00oooooo00?oc03oooooooooool01_ooool8ol`0o`ko
oooo3Oo<0?l_ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool02oooool004oooooo
00?o0000ooooooooool0Boooool00ol0003oooooooooo`02ooooo`;o06Ko5?ooool00olc0?oooooo
ooooo`0?ooooo`03ol`0oooooooooooo00oooooo3_o<0?lmooooo`03o`000?oooooooooo037ooooo
00?o0000ooooooooool02_ooool0053ooooo00?o0000ooooooooool0Boooool01?l0003ooooooooo
ool0I_lEooooo`03oc<0oooooooooooo013ooooo00?oc03oooooooooool0Foooool00ol0003ooooo
ooooo`0aooooo`03o`000?oooooooooo00Wooooo001Aooooo`03o`000?oooooooooo04_ooooo0_l0
I_lDooooo`;o<`3o4_ooool00oo<0?ooooooooooo`1Mooooo`03o`000?oooooooooo037ooooo00?o
0000ooooooooool02?ooool005;ooooo00?o0000ooooooooool0BOooool00ol0I_ooooooo`00000C
ooooo`03oc<0oooooooooooo017ooooo00?oc03oooooooooool0Goooool00ol0003oooooooooo`0`
ooooo`03o`000?oooooooooo00Sooooo001Cooooo`;o0000C?ooool00ol0003oooooooooo`0?oooo
o`03oc<0oooooooooooo017ooooo00?oc03oooooooooool03?ooool00ooo09Woooooooooo`1Boooo
o`03o`000?oooooooooo033ooooo00?o0000ooooooooool01oooool005Gooooo00?o0000oooooooo
ool0B_ooool00ol0003oooooooooo`0=ooooo`03oc<0oooooooooooo017ooooo00?oc03ooooooooo
ool03?ooool2ool0VECooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`06ooooo`00
E_ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo00_ooooo00?o<`3oooooooooool0
4_ooool00oo<0?ooooooooooo`0:ooooo`?oo`2IE_ooool00ol0003oooooooooo`0_ooooo`?o0000
1oooool005Oooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`08ooooo`;o<`3o5?oo
ool00oo<0?ooooooooooo`09ooooo`;oo`2I00?oooooool0VOooool0Eoooool00ol0003ooooooooo
o`0[ooooo`?o00000_ooool00ol0003oooooooooo`05ooooo`00F?ooool00ol0003oooooooooo`1:
ooooo`03o`000?oooooooooo00Gooooo0_lc0?lEooooo`03ol`0oooooooooooo00Oooooo0ooo09T3
ooooo`03ool0VOoooooooooo05Oooooo00?o0000ooooooooool09oooool3o`0000Gooooo00?o0000
ooooooooool01Oooool005Wooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`03oooo
o`03oc<0oooooooooooo01?ooooo0_o<0?l6ooooo`Coo`2I1Oooool00ooo09Woooooooooo`0aoooo
o`Coo`2I9?ooool00ol0003oooooooooo`0Rooooo`Co00002?ooool00ol0003oooooooooo`05oooo
o`00F_ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo00;o<`3o5Oooool00oo<0?oo
ooooool0V@06ool0V@Wooooo00?oo`2Iooooooooool0:_ooool7ool0VBWooooo00?o0000oooooooo
ool07_ooool3o`0000cooooo00?o0000ooooooooool01Oooool005_ooooo00?o0000ooooooooool0
B_ooool2oc<0oaKooooo00?oc03oooooooooool01oooool=ool0VB;ooooo1ooo09T`ooooo`03o`00
0?oooooooooo01[ooooo1?l0000?ooooo`03o`000?oooooooooo00Gooooo001Looooo`03o`000?oo
oooooooo04Sooooo00?o<`3oooooool000005?ooool2ol`0oa7ooooo00?oo`2Iooooooooool00ooo
oolRool0VCSooooo00?o0000ooooooooool05_ooool3o`0001Cooooo00?o0000ooooooooool01?oo
ool005gooooo00?o0000ooooooooool0AOooool2oc<0o`?ooooo00?o0000ooooooooool04?ooool0
0oo<0?ooooooooooo`0@ooooo`03ool0VOoooooooooo00_ooooo00?oo`00ooooooooool0DOooool0
0ol0003oooooooooo`0Booooo`?o00005oooool00ol0003oooooooooo`04ooooo`00G_ooool2o`00
04Cooooo00?o<`3oooooooooool01?ooool00ol0003oooooooooo`0>ooooo`03ol`0oooooooooooo
013ooooo00?oo`2Iooooooooool02oooool2ool005Cooooo00?o0000ooooooooool03Oooool4o`00
01[ooooo00?o0000ooooooooool01?ooool0063ooooo00?o0000ooooooooool0BOooool00ol0003o
ooooooooo`0;ooooo`;oc03o4oooool00ooo09Woooooooooo`0:ooooo`;oo`00E_ooool00ol0003o
ooooooooo`09ooooo`?o00007_ooool00ol0003oooooooooo`04ooooo`00HOooool00ol0003ooooo
ooooo`19ooooo`03o`000?oooooooooo00Wooooo00?oc03oooooooooool04_ooool00ooo09Wooooo
ooooo`09ooooo`;oo`0000?oooooool00?ooool0E_ooool00ol0003oooooooooo`04ooooo`Co0000
8Oooool00ol0003oooooooooo`04ooooo`00H_ooool00ol0003oooooooooo`19ooooo`03o`000?oo
oooooooo00Oooooo00?oc03oooooooooool04_ooool00ooo09Woooooooooo`08ooooo`;oo`000_oo
ool00ooo003oooooooooo`1Fooooo`04o`000?ooooooooooooooo`?o00009Oooool00ol0003ooooo
ooooo`04ooooo`00Hoooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo00Cooooo0_o<
0?lDooooo`03ool0VOoooooooooo00Sooooo00?oo`00ooooooooool00_ooool00ooo003ooooooooo
o`1Gooooo`?o0000:?ooool00ol0003oooooooooo`04ooooo`00I?ooool00ol0003oooooooooo`19
ooooo`04o`000?ooooooooooooooo`;oc03o5?ooool2ool0V@Wooooo0_oo0004ooooo`03ool00?oo
oooooooo05Cooooo1?l000000ooooooo0000ooooo`0Xooooo`03o`000?oooooooooo00Cooooo001U
ooooo`03o`000?oooooooooo04Wooooo00?o0000ol`0ooo<0?l05Oooool00ooo09Woooooooooo`06
ooooo`?oo`001_ooool00ooo003oooooooooo`1Aooooo`?o00001_ooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo00Cooooo001Vooooo`03o`000?oooooooooo04Oooooo0_o<0?l00ol0
003oooooooooo`0Cooooo`03ool0VOoooooooooo00Gooooo0_oo0008ooooo`03ool00?oooooooooo
04kooooo1?l0000:ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool01?ooool006Oo
oooo00?o0000ooooooooool0A?ooool2ol`0o`?ooooo00?o0000ooooooooool02oooool?ool000Wo
oooo00?oo`00ooooooooool0;?ooool6ool001[ooooo0ol0000?ooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool00oooool006Sooooo00?o0000ooooooooool0@Oooool2ol`0o`Kooooo
00?o0000ooooooooool03_ooool5ool000kooooo00?oo`00ooooooooool08_ooool;ool001gooooo
0ol0000Booooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00oooool006Wooooo00?o
0000ooooooooool0?_ooool2ol`0o`Wooooo00?o0000ooooooooool03?ooool00ooo09Wooooooooo
o`03ooooo`coo`0000?oooooool00?ooool04_oooolBool002Cooooo1?l0000Fooooo`03o`000?oo
oooooooo02Cooooo00?o0000ooooooooool00oooool006[ooooo0_l0000mooooo`03ol`0oooooooo
oooo00[ooooo00?o0000ooooooooool02_ooool00ooo09Woooooooooo`0@oooooaGoo`00<oooool3
o`0001_ooooo00?o0000ooooooooool08oooool00ol0003oooooooooo`03ooooo`00K?ooool00ol0
003oooooooooo`18ooooo`03o`000?oooooooooo00Oooooo0_oo09TBooooo`03ool00?oooooooooo
04;ooooo1?l0000Oooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool00oooool006go
oooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`05ooooo`03ool0VOoooooooooo017o
oooo00?oo`00ooooooooool0@?ooool3o`0002Cooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`03ooooo`00K_ooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00?ooooo
00?oo`2Iooooooooool04Oooool00ooo003oooooooooo`0nooooo`?o0000:?ooool00ol0003ooooo
ooooo`0Pooooo`03o`000?oooooooooo00?ooooo001_ooooo`03o`000?oooooooooo04Sooooo00?o
0000ooooooooool00_oo09TBooooo`;oo`00?Oooool4o`0002_ooooo00?o0000ooooooooool08?oo
ool00ol0003oooooooooo`03ooooo`00L?ooool00ol0003oooooooooo`18ooooo`;oo`2I4oooool0
0ooo003oooooooooo`0jooooo`?o0000<?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooo
oooo00?ooooo001aooooo`03o`000?oooooooooo04Gooooo0_oo09T00ooooooo0000ooooo`0Aoooo
o`03ool00?oooooooooo03Oooooo1?l0000dooooo`03o`000?oooooooooo01kooooo00?o0000oooo
ooooool00oooool007;ooooo00?o0000ooooooooool0@_ooool2ool0V@Cooooo00?o0000oooooooo
ool03_ooool00ooo003oooooooooo`0eooooo`?o0000>Oooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo00;ooooo001cooooo`03o`000?oooooooooo043ooooo00?oo`2Iooooooooool0
1Oooool00ol0003oooooooooo`0;ooooo`;oo`00=Oooool3o`0003gooooo00?o0000ooooooooool0
7Oooool00ol0003oooooooooo`02ooooo`00M?ooool00ol0003oooooooooo`0mooooo`;oo`2I2Ooo
ool00ol0003oooooooooo`09ooooo`03ool00?oooooooooo037ooooo1?l00011ooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool00_ooool007Gooooo0_l0000kooooo`;oo`2I3?ooool0
0ol0003oooooooooo`07ooooo`03ool00?oooooooooo02oooooo0ol00015ooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool00_ooool007Oooooo00?o0000ooooooooool0=_ooool2ool0
V@oooooo00?o0000ooooooooool01?ooool2ool002kooooo1?l00019ooooo`03o`000?oooooooooo
01_ooooo00?o0000ooooooooool00_ooool007Sooooo00?o0000ooooooooool0=?ooool00ooo09Wo
ooooooooo`0@ooooo`03o`000?oooooooooo00;ooooo00?oo`00ooooooooool0:oooool3o`0004ko
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`02ooooo`00NOooool00ol0003ooooo
ooooo`17ooooo`04o`000?ooooooooooool002_ooooo0ol0001Booooo`03o`000?oooooooooo01Wo
oooo00?o0000ooooooooool00_ooool007[ooooo00?o0000ooooooooool0Aoooool00ol0003oo`00
ooooo`0Wooooo`Co0000E_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00;ooooo
001kooooo`03o`000?oooooooooo04Gooooo0_oo00000ol0003oooooooooo`0Sooooo`?o0000Fooo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00;ooooo001looooo`03o`000?oooooo
oooo04;ooooo0_oo0003ooooo`03o`000?oooooooooo01kooooo1?l0001Nooooo`03o`000?oooooo
oooo01Oooooo00?o0000ooooooooool00_ooool007gooooo00?o0000ooooooooool0?oooool2ool0
00Kooooo00?o0000ooooooooool06_ooool3o`0006?ooooo00?o0000ooooooooool05oooool00ol0
003oooooooooo`01ooooo`00O_ooool00ol0003oooooooooo`0looooo`;oo`002Oooool00ol0003o
ooooooooo`0Fooooo`?o0000Ioooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo007o
oooo001oooooo`03o`000?oooooooooo03[ooooo00?oo`00ooooooooool02_ooool00ol0003ooooo
ooooo`0Aooooo`Co0000Joooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo007ooooo
0020ooooo`;o0000>?ooool2ool000kooooo00?o0000ooooooooool03Oooool3o`00073ooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`01ooooo`00P_ooool00ol0003oooooooooo`0c
ooooo`;oo`004Oooool00ol0003oooooooooo`08ooooo`Co0000M?ooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo007ooooo0023ooooo`03o`000?oooooooooo033ooooo0_oo000Doooo
o`03o`000?oooooooooo00Cooooo0ol0001hooooo`03o`000?oooooooooo01?ooooo00?o0000oooo
ooooool00Oooool008Cooooo00?o0000ooooooooool0;_ooool00ooo003oooooooooo`0Eooooo`03
o`000?oooooooooo00?o0000O?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo007o
oooo0025ooooo`03o`000?oooooooooo04Kooooo0_l00020ooooo`03o`000?oooooooooo017ooooo
00?o0000ooooooooool00Oooool008Kooooo00?o0000ooooooooool0AOooool00ol0003ooooooooo
o`20ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00Oooool008Oooooo00?o0000
ooooooooool0A?ooool00ol0003oooooooooo`21ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool00Oooool008Sooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`22oooo
o`03o`000?oooooooooo00oooooo0Ol00001ooooo`7ooooo0029ooooo`03o`000?oooooooooo04;o
oooo00?o0000ooooooooool0P_ooool00ol0003oooooooooo`0?ooooo`7o00000Oooool1ooooo`00
R_ooool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo08?ooooo00?o0000ooooooooool0
3_ooool1o`00007ooooo0Oooool008_ooooo0_l00011ooooo`03o`000?oooooooooo08Cooooo00?o
0000ooooooooool03Oooool1o`00007ooooo0Oooool008gooooo00?o0000ooooooooool0?_ooool0
0ol0003oooooooooo`25ooooo`03o`000?oooooooooo00cooooo0Ol00001ooooo`7ooooo002>oooo
o`03o`000?oooooooooo03gooooo00?o0000ooooooooool0Q_ooool00ol0003oooooooooo`0;oooo
o`7o00000Oooool1ooooo`00Soooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo08Oo
oooo00?o0000ooooooooool02_ooool1o`00007ooooo0Oooool0093ooooo00?o0000ooooooooool0
>oooool00ol0003oooooooooo`27ooooo`03o`000?oooooooooo00[ooooo0Ol00001ooooo`7ooooo
002Aooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0R?ooool00ol0003ooooooooo
o`09ooooo`7o00000Oooool1ooooo`00T_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooo
oooo08Wooooo00?o0000ooooooooool02?ooool1o`00007ooooo0Oooool009?ooooo00?o0000oooo
ooooool0>?ooool00ol0003oooooooooo`2:ooooo`03o`000?oooooooooo00Sooooo0Ol00001oooo
o`00U?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo08_ooooo00?o0000oooooooo
ool01oooool1o`00007ooooo002Eooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0
S?ooool00ol0003oooooooooo`06ooooo`7o00000Oooool009Kooooo00?o0000ooooooooool0=Ooo
ool00ol0003oooooooooo`2<ooooo`03o`000?oooooooooo00Kooooo0Ol00001ooooo`00Uoooool2
o`0003Gooooo00?o0000ooooooooool0SOooool00ol0003oooooooooo`05ooooo`7o00000Oooool0
09Wooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`2>ooooo`03o`000?oooooooooo
00Cooooo0Ol00001ooooo`00V_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo08oo
oooo00?o0000ooooooooool00oooool1o`00007ooooo002Kooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool0T?ooool00ol0003oooooooooo`02ooooo`7o00000Oooool009cooooo00?o
0000ooooooooool0;oooool00ol0003oooooooooo`2Aooooo`05o`000?ooooooooooooooool00000
0Oooool009gooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`2Aooooo`05o`000?oo
ooooooooooooool000000Oooool009kooooo00?o0000ooooooooool0;Oooool00ol0003ooooooooo
o`2Booooo`04o`000?ooooooooooooooo`7o0000002Oooooo`03o`000?oooooooooo02cooooo00?o
0000ooooooooool0Toooool00ol0003oooooooooo`01o`000000X?ooool00ol0003oooooooooo`0[
ooooo`03o`000?oooooooooo09Cooooo0Ol00001ooooo`7o0000002Qooooo`03o`000?oooooooooo
02[ooooo00?o0000ooooooooool0UOooool2o`000000X_ooool2o`0002[ooooo00?o0000oooooooo
ool0U?ooool3o`000000Y?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo093ooooo
1?l00003ooooo`00YOooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo08gooooo0ol0
0007ooooo`00Y_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo08Wooooo1?l0000:
ooooo`00Yoooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo08Gooooo1?l0000>oooo
o`00Z?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo08;ooooo0ol0000Booooo`00
ZOooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo07kooooo1?l0000Eooooo`00Z_oo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo07[ooooo1?l0000Iooooo`00Zoooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo07Gooooo1?l0000Mooooo`00[?ooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo07;ooooo0ol0000Qooooo`00[Oooool2o`00023o
oooo00?o0000ooooooooool0K_ooool4o`0002Cooooo002_ooooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool0J_ooool4o`0002Sooooo002`ooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool0Ioooool3o`0002cooooo002aooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool0Hoooool4o`0002oooooo002booooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool0Goooool4o`0003?ooooo002cooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool0G?ooool3o`0003Oooooo002dooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
F?ooool4o`0003[ooooo002eooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0E?oo
ool4o`0003kooooo002fooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0D?ooool4
o`0004;ooooo002gooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0COooool3o`00
04Kooooo002hooooo`;o00005Oooool00ol0003oooooooooo`19ooooo`Co0000BOooool00;[ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`15ooooo`Co0000COooool00;_ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`12ooooo`?o0000DOooool00;cooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0nooooo`Co0000E?ooool00;gooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0jooooo`Co0000F?ooool00;kooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0fooooo`Co0000G?ooool00;oooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0cooooo`?o0000H?ooool00<3ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0_ooooo`Co0000Hoooool00<7ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0[ooooo`Co0000Ioooool00<;ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0Xooooo`?o0000Joooool00<?ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0Tooooo`Co0000K_ooool00<Cooooo0_l00009ooooo`03o`000?oooooooooo023ooooo
1?l0001booooo`00a_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01gooooo0ol0
001fooooo`00aoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Wooooo1?l0001i
ooooo`00b?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Gooooo1?l0001moooo
o`00bOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo1?l00021ooooo`00
b_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00kooooo0ol00025ooooo`00booo
ool01Ol0003ooooooooooooooooo000000cooooo1?l00028ooooo`00c?ooool01?l0003ooooooooo
ool00008ooooo`Co0000S?ooool00<gooooo00?o0000ooooool000001Oooool3o`00093ooooo003>
ooooo`;o000000?oooooo`000?l000000_l0002Cooooo`00coooool2o`0009Oooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {330.375, 0}} -> {-0.0771432, -0.0315529, \
0.00350368, 0.00350368}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .92059 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-16 1.0763 -0.0263982 1.0763 [
[.01694 .18568 -11.9631 -9 ]
[.01694 .18568 .03693 0 ]
[.13793 .13897 -11.619 -9 ]
[.13793 .13897 .38095 0 ]
[.26292 .09073 -5.63752 -9 ]
[.26292 .09073 .36248 0 ]
[.39212 .04087 -5.46552 -9 ]
[.39212 .04087 .53448 0 ]
[.52574 -0.01069 -5.29351 -9 ]
[.52574 -0.01069 .70649 0 ]
[.58272 .04263 0 -6.19654 ]
[.58272 .04263 6 2.80346 ]
[.71715 .21863 0 -6.07114 ]
[.71715 .21863 6 2.92886 ]
[.83675 .37523 0 -5.963 ]
[.83675 .37523 6 3.037 ]
[.94385 .51546 0 -5.8688 ]
[.94385 .51546 6 3.1312 ]
[.01386 .20006 -12 -2.76892 ]
[.01386 .20006 0 6.23108 ]
[.00748 .25499 -24 -2.80073 ]
[.00748 .25499 0 6.19927 ]
[.00093 .31131 -6 -2.83339 ]
[.00093 .31131 0 6.16661 ]
[-0.00579 .36907 -18 -2.86695 ]
[-0.00579 .36907 0 6.13305 ]
[-0.01268 .42831 -6 -2.90143 ]
[-0.01268 .42831 0 6.09857 ]
[ 0 0 0 0 ]
[ 1 .92059 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02642 .19522 m
.53391 0 L
s
.02642 .19522 m
.03116 .2 L
s
[(-2)] .01694 .18568 .99384 1 Mshowa
.14712 .14879 m
.15172 .1537 L
s
[(-1)] .13793 .13897 .93651 1 Mshowa
.2718 .10083 m
.27624 .10588 L
s
[(0)] .26292 .09073 .87917 1 Mshowa
.40066 .05126 m
.40493 .05646 L
s
[(1)] .39212 .04087 .82184 1 Mshowa
.53391 0 m
.538 .00534 L
s
[(2)] .52574 -0.01069 .7645 1 Mshowa
.125 Mabswid
.05025 .18606 m
.05308 .18894 L
s
.07424 .17683 m
.07705 .17973 L
s
.09837 .16755 m
.10117 .17046 L
s
.12267 .1582 m
.12545 .16113 L
s
.17173 .13933 m
.17447 .14229 L
s
.19651 .1298 m
.19923 .13278 L
s
.22144 .1202 m
.22414 .1232 L
s
.24654 .11055 m
.24922 .11356 L
s
.29723 .09105 m
.29988 .0941 L
s
.32283 .0812 m
.32546 .08427 L
s
.3486 .07129 m
.35121 .07437 L
s
.37455 .06131 m
.37713 .06441 L
s
.42695 .04115 m
.4295 .04428 L
s
.45342 .03096 m
.45594 .03412 L
s
.48007 .02071 m
.48257 .02388 L
s
.5069 .01039 m
.50938 .01358 L
s
.25 Mabswid
.53391 0 m
.9804 .58403 L
s
.57014 .04738 m
.56384 .04975 L
s
[(0)] .58272 .04263 -1 .37701 Mshowa
.70445 .22307 m
.6981 .22529 L
s
[(2)] .71715 .21863 -1 .34914 Mshowa
.82396 .37939 m
.81756 .38147 L
s
[(4)] .83675 .37523 -1 .32511 Mshowa
.93098 .51938 m
.92454 .52134 L
s
[(6)] .94385 .51546 -1 .30418 Mshowa
.125 Mabswid
.60525 .09331 m
.60147 .09471 L
s
.63931 .13786 m
.63552 .13924 L
s
.67236 .1811 m
.66856 .18245 L
s
.73562 .26383 m
.7318 .26514 L
s
.7659 .30345 m
.76207 .30473 L
s
.79534 .34195 m
.7915 .34322 L
s
.85181 .41581 m
.84796 .41704 L
s
.87891 .45126 m
.87506 .45247 L
s
.90529 .48577 m
.90143 .48696 L
s
.95601 .55212 m
.95214 .55328 L
s
.25 Mabswid
.02642 .19522 m
0 .42381 L
s
.02642 .19522 m
.0327 .19281 L
s
[(-1)] .01386 .20006 1 -0.38468 Mshowa
.02006 .25024 m
.02635 .24786 L
s
[(-0.5)] .00748 .25499 1 -0.37762 Mshowa
.01354 .30664 m
.01985 .3043 L
s
[(0)] .00093 .31131 1 -0.37036 Mshowa
.00686 .36448 m
.01318 .36218 L
s
[(0.5)] -0.00579 .36907 1 -0.3629 Mshowa
0 .42381 m
.00634 .42156 L
s
[(1)] -0.01268 .42831 1 -0.35524 Mshowa
.125 Mabswid
.02516 .20612 m
.02893 .20468 L
s
.0239 .21707 m
.02767 .21563 L
s
.02262 .22807 m
.0264 .22664 L
s
.02135 .23913 m
.02512 .2377 L
s
.01877 .26141 m
.02255 .25999 L
s
.01747 .27263 m
.02125 .27122 L
s
.01617 .28391 m
.01995 .2825 L
s
.01486 .29525 m
.01864 .29384 L
s
.01222 .31809 m
.01601 .3167 L
s
.01089 .3296 m
.01468 .32821 L
s
.00955 .34117 m
.01334 .33978 L
s
.00821 .35279 m
.012 .35141 L
s
.0055 .37622 m
.0093 .37485 L
s
.00414 .38803 m
.00793 .38666 L
s
.00276 .39989 m
.00656 .39853 L
s
.00139 .41182 m
.00519 .41047 L
s
.25 Mabswid
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.54154 .92059 L
s
.54154 .92059 m
.5414 .7134 L
s
.5414 .7134 m
.02642 .19522 L
s
.53391 0 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.53391 0 m
.02642 .19522 L
s
.5414 .7134 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.54154 .92059 L
s
.54154 .92059 m
.5414 .7134 L
s
0 0 m
1 0 L
1 .92059 L
0 .92059 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.48072 .72213 m
.53077 .69593 L
s
1 0 .6 r
.46371 .68841 m
.51068 .66338 L
s
.8 0 1 r
.44669 .65467 m
.49059 .63086 L
s
.2 0 1 r
.42966 .62092 m
.47052 .59836 L
s
0 .4 1 r
.41262 .58715 m
.45046 .5659 L
s
0 1 1 r
.39558 .55336 m
.43042 .53346 L
s
0 1 .4 r
.37852 .51956 m
.41041 .50104 L
s
.2 1 0 r
.36147 .48574 m
.39045 .46866 L
s
.8 1 0 r
.34445 .45192 m
.37074 .43633 L
s
1 .6 0 r
.32764 .41812 m
.35178 .40405 L
s
.35178 .40405 m
.37196 .38893 L
s
.8 1 0 r
.37074 .43633 m
.39179 .41919 L
s
.2 1 0 r
.39045 .46866 m
.41361 .4493 L
s
0 1 .4 r
.41041 .50104 m
.43644 .4794 L
s
0 1 1 r
.43042 .53346 m
.45964 .50955 L
s
0 .4 1 r
.45046 .5659 m
.48297 .53978 L
s
.2 0 1 r
.47052 .59836 m
.50638 .57009 L
s
.8 0 1 r
.49059 .63086 m
.52985 .60049 L
s
1 0 .6 r
.51068 .66338 m
.55338 .63098 L
s
1 0 0 r
.53077 .69593 m
.57698 .66157 L
s
1 .6 0 r
.37196 .38893 m
.38813 .37479 L
s
.8 1 0 r
.39179 .41919 m
.40639 .40374 L
s
.2 1 0 r
.41361 .4493 m
.42775 .4322 L
s
0 1 .4 r
.43644 .4794 m
.45148 .46022 L
s
1 .6 0 r
.38813 .37479 m
.4029 .3624 L
s
0 1 1 r
.45964 .50955 m
.47649 .48806 L
s
0 .4 1 r
.48297 .53978 m
.50202 .51592 L
s
.8 1 0 r
.40639 .40374 m
.41825 .39109 L
s
.2 0 1 r
.50638 .57009 m
.52778 .54389 L
s
.2 1 0 r
.42775 .4322 m
.43701 .41951 L
s
.8 0 1 r
.52985 .60049 m
.55368 .572 L
s
1 .6 0 r
.4029 .3624 m
.41836 .3515 L
s
1 0 .6 r
.55338 .63098 m
.57971 .60024 L
s
0 1 .4 r
.45148 .46022 m
.4592 .44741 L
s
.8 1 0 r
.41825 .39109 m
.43075 .38041 L
s
1 0 0 r
.57698 .66157 m
.60586 .62864 L
s
0 1 1 r
.47649 .48806 m
.48382 .47484 L
s
1 0 0 r
.58822 .65819 m
.66626 .65565 L
s
.52392 .65346 m
.58822 .65819 L
s
1 .6 0 r
.41836 .3515 m
.43531 .34193 L
s
.2 1 0 r
.43701 .41951 m
.44619 .40959 L
s
1 0 0 r
.66626 .65565 m
.73634 .64651 L
s
1 0 .6 r
.58944 .62 m
.66224 .61759 L
s
.52993 .61554 m
.58944 .62 L
s
1 0 0 r
.49447 .64915 m
.52392 .65346 L
s
.8 1 0 r
.43075 .38041 m
.44522 .37116 L
s
0 .4 1 r
.50202 .51592 m
.50965 .50208 L
s
0 1 .4 r
.4592 .44741 m
.46545 .43889 L
s
1 0 .6 r
.66224 .61759 m
.72835 .60882 L
s
1 0 0 r
.52171 .65003 m
.49859 .64953 L
s
.55146 .64645 m
.52171 .65003 L
s
.8 0 1 r
.59068 .58168 m
.65821 .57939 L
s
.53598 .57752 m
.59068 .58168 L
s
1 0 .6 r
.50188 .61137 m
.52993 .61554 L
s
1 0 0 r
.49859 .64953 m
.49447 .64915 L
s
1 .6 0 r
.43531 .34193 m
.45386 .33365 L
s
.2 1 0 r
.44619 .40959 m
.45745 .40117 L
s
.8 0 1 r
.65821 .57939 m
.72033 .57102 L
s
.2 0 1 r
.52778 .54389 m
.53597 .52938 L
s
1 0 0 r
.57993 .63783 m
.55146 .64645 L
s
.8 0 1 r
.50932 .57348 m
.53598 .57752 L
s
0 1 1 r
.48382 .47484 m
.48809 .46806 L
s
1 0 .6 r
.51969 .61172 m
.50283 .61136 L
s
.54199 .60899 m
.51969 .61172 L
s
.2 0 1 r
.59193 .54322 m
.65418 .54108 L
s
.54204 .53937 m
.59193 .54322 L
s
1 0 .6 r
.50283 .61136 m
.50188 .61137 L
s
.8 1 0 r
.44522 .37116 m
.46181 .36332 L
s
0 1 .4 r
.46545 .43889 m
.47308 .43216 L
s
.2 0 1 r
.65418 .54108 m
.7123 .53311 L
s
1 0 .6 r
.56335 .60242 m
.54199 .60899 L
s
.2 0 1 r
.51677 .53548 m
.54204 .53937 L
s
1 .6 0 r
.45386 .33365 m
.47388 .32672 L
s
.8 0 1 r
.50709 .57307 m
.50932 .57348 L
s
.51766 .57328 m
.50709 .57307 L
s
.53249 .57143 m
.51766 .57328 L
s
0 .4 1 r
.59318 .50464 m
.65013 .50264 L
s
.54811 .50112 m
.59318 .50464 L
s
.2 1 0 r
.45745 .40117 m
.47126 .39413 L
s
.8 0 1 r
.55368 .572 m
.56251 .5568 L
s
.54675 .56697 m
.53249 .57143 L
s
0 .4 1 r
.65013 .50264 m
.70424 .4951 L
s
0 1 1 r
.48809 .46806 m
.49226 .46393 L
s
0 .4 1 r
.50965 .50208 m
.51259 .49714 L
s
.2 0 1 r
.51135 .53466 m
.51677 .53548 L
s
0 .4 1 r
.52417 .4974 m
.54811 .50112 L
s
0 1 .4 r
.47308 .43216 m
.48307 .42662 L
s
.8 1 0 r
.46181 .36332 m
.48019 .35703 L
s
1 0 0 r
.60196 .62569 m
.57993 .63783 L
s
.2 0 1 r
.51562 .53472 m
.51135 .53466 L
s
.52296 .53378 m
.51562 .53472 L
s
0 1 1 r
.59443 .46593 m
.64607 .46407 L
s
.55411 .46278 m
.59443 .46593 L
s
.2 0 1 r
.53015 .5315 m
.52296 .53378 L
s
1 0 .6 r
.57976 .5932 m
.56335 .60242 L
s
1 .6 0 r
.47388 .32672 m
.49515 .32122 L
s
0 1 1 r
.64607 .46407 m
.69615 .45697 L
s
.49226 .46393 m
.49752 .46084 L
s
.8 0 1 r
.55761 .56077 m
.54675 .56697 L
s
0 .4 1 r
.51554 .49618 m
.52417 .4974 L
s
.2 1 0 r
.47126 .39413 m
.48717 .38876 L
s
0 1 1 r
.53125 .45932 m
.55411 .46278 L
s
0 .4 1 r
.51259 .49714 m
.51354 .49609 L
s
.2 0 1 r
.5355 .52839 m
.53015 .5315 L
s
1 0 .6 r
.57971 .60024 m
.58922 .58437 L
s
0 .4 1 r
.51354 .49609 m
.51554 .49618 L
s
.51344 .49609 m
.51354 .49609 L
s
.5136 .49604 m
.51344 .49609 L
s
.51354 .49609 m
.5136 .49604 L
s
0 1 .4 r
.59564 .42711 m
.64199 .42537 L
s
.55974 .42447 m
.59564 .42711 L
s
.48307 .42662 m
.49513 .4226 L
s
0 1 1 r
.49752 .46084 m
.50403 .4587 L
s
.2 0 1 r
.53597 .52938 m
.53776 .52626 L
s
.8 1 0 r
.48019 .35703 m
.49991 .35247 L
s
0 1 .4 r
.64199 .42537 m
.68805 .41874 L
s
.2 0 1 r
.53776 .52626 m
.5355 .52839 L
s
0 1 1 r
.51932 .45782 m
.53125 .45932 L
s
1 .6 0 r
.49515 .32122 m
.51754 .31723 L
s
0 1 .4 r
.5373 .42152 m
.55974 .42447 L
s
0 1 1 r
.50403 .4587 m
.51123 .4577 L
s
.51123 .4577 m
.51932 .45782 L
s
.2 1 0 r
.48717 .38876 m
.50438 .38533 L
s
.8 0 1 r
.56315 .55549 m
.55761 .56077 L
s
.2 1 0 r
.59664 .38831 m
.63788 .38658 L
s
.5643 .38648 m
.59664 .38831 L
s
0 1 .4 r
.49513 .4226 m
.50826 .42045 L
s
1 0 0 r
.60586 .62864 m
.61608 .61211 L
s
0 1 .4 r
.52186 .42014 m
.5373 .42152 L
s
.8 1 0 r
.49991 .35247 m
.52061 .34974 L
s
.2 1 0 r
.63788 .38658 m
.67992 .3804 L
s
.54123 .38449 m
.5643 .38648 L
s
1 0 .6 r
.58868 .58483 m
.57976 .5932 L
s
1 .6 0 r
.51754 .31723 m
.54117 .31472 L
s
0 1 .4 r
.50826 .42045 m
.52186 .42014 L
s
.2 1 0 r
.50438 .38533 m
.52227 .38396 L
s
.52227 .38396 m
.54123 .38449 L
s
.8 1 0 r
.59695 .34984 m
.63365 .3478 L
s
.5668 .34931 m
.59695 .34984 L
s
.52061 .34974 m
.54241 .34883 L
s
.8 0 1 r
.56251 .5568 m
.56315 .55549 L
s
1 0 0 r
.61431 .61431 m
.60196 .62569 L
s
.8 1 0 r
.54241 .34883 m
.5668 .34931 L
s
1 .6 0 r
.54117 .31472 m
.56675 .31337 L
s
.56675 .31337 m
.59585 .31219 L
s
.8 1 0 r
.63365 .3478 m
.67175 .34199 L
s
1 .6 0 r
.59585 .31219 m
.62903 .30932 L
s
.62903 .30932 m
.6635 .30361 L
s
1 0 .6 r
.58922 .58437 m
.58868 .58483 L
s
1 0 0 r
.61608 .61211 m
.61431 .61431 L
s
0 g
.25 Mabswid
.53391 0 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.53391 0 m
.02642 .19522 L
s
.02642 .19522 m
.53391 0 L
s
.02642 .19522 m
.03116 .2 L
s
[(-2)] .01694 .18568 .99384 1 Mshowa
.14712 .14879 m
.15172 .1537 L
s
[(-1)] .13793 .13897 .93651 1 Mshowa
.2718 .10083 m
.27624 .10588 L
s
[(0)] .26292 .09073 .87917 1 Mshowa
.40066 .05126 m
.40493 .05646 L
s
[(1)] .39212 .04087 .82184 1 Mshowa
.53391 0 m
.538 .00534 L
s
[(2)] .52574 -0.01069 .7645 1 Mshowa
.125 Mabswid
.05025 .18606 m
.05308 .18894 L
s
.07424 .17683 m
.07705 .17973 L
s
.09837 .16755 m
.10117 .17046 L
s
.12267 .1582 m
.12545 .16113 L
s
.17173 .13933 m
.17447 .14229 L
s
.19651 .1298 m
.19923 .13278 L
s
.22144 .1202 m
.22414 .1232 L
s
.24654 .11055 m
.24922 .11356 L
s
.29723 .09105 m
.29988 .0941 L
s
.32283 .0812 m
.32546 .08427 L
s
.3486 .07129 m
.35121 .07437 L
s
.37455 .06131 m
.37713 .06441 L
s
.42695 .04115 m
.4295 .04428 L
s
.45342 .03096 m
.45594 .03412 L
s
.48007 .02071 m
.48257 .02388 L
s
.5069 .01039 m
.50938 .01358 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 265.125},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001Bb000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00`oooool5o`000:3ooooo0033ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@0X?ooool00<Cooooo00?oV9RHob4Q8Oo^k^h0XOooool00<Gooooo00?oV9RH
ob4Q8Oo^k^h0X?ooool00<Kooooo00?oMgMgofIVI_ooool0Woooool00<Oooooo00?o0000oooooooo
ool0W_ooool00<?ooooo00Go0000okZj^_ooooooV9RHoa0@402Pooooo`00`oooool01OnHV9So410@
o`000?lQ8B7oc<c<0:3ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003;ooooo`;o0000Voooool00<Sooooo0ol000000ooooooo0000ooooo`2Jooooo`00a_oo
ool2o`0000Cooooo0_l0002Jooooo`00`oooool3o`0000Kooooo00?o0000ooooool00000VOooool0
0<3ooooo1?l00008ooooo`04o`000?ooooooooooo`0009Sooooo002Hooooo`Co000000?o410@oooo
ooooool07oooool2o`0000Cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0002H
ooooo`00V_ooool00ol0003oooooooooo`0Nooooo`?o00003_ooool01Ol0003ooooooooooooooooo
000009Oooooo002Jooooo`03o`000?oooooooooo01cooooo0_l0000Aooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0U?ooool009[ooooo00?o0000ooooooooool06Oooool3o`0000;o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo09?o
oooo002Jooooo`03o`000?oooooooooo01Kooooo0ol0000Fooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^08Kooooo002Jooooo`03o`00
0?oooooooooo01Cooooo0_l0000Iooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1oooool01OmgMgOoV9RHoooooonHV9SoMgMg08Kooooo002Jooooo`03o`000?oooooooooo017ooooo
0ol000000ooooooo0000ooooo`0Hooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1_ooool01Ol@413ooooooooooooooooo410@08Kooooo002Hooooo`03oeEEEOmVIVKo0000017ooooo
0_l0000Nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool01Ol0003ooooo
oooooooooooo000008Kooooo002Yooooo`?o00008?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000026ooooo`00Yoooool3o`0002;ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@
4100Q_ooool00:Cooooo0ol00002ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Q_ooool00:7ooooo
0ol0000Xooooo`03o`000?oooooooooo00Sooooo0_l00004ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h0Q_ooool009oooooo0_l0000[ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo
0000S_ooool009cooooo0ol000000ooooooo0000ooooo`0Zooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0S?ooool009[ooooo0_l00005ooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`2;ooooo`00Uoooool3o`0003;ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`2:ooooo`00K?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^02?ooooo0ol000000ooooooo0000ooooo`0booooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0ROooool006cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Qooooo`;o0000>?ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo08Wooooo001/ooooo`05oa0@4?oooooooooo
ooooool@41007_ooool3o`0003[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`28
ooooo`00K?ooool01Ol0003ooooooooooooooooo000001cooooo0ol0000looooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0Qoooool006cooooo00Go0000ooooooooooooooooo`00000I
ooooo`?o00000_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool0Q_ooool006cooooo00Go410@oooooooooooooooooa0@400Gooooo`;o0000@_ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo08Kooooo001/ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL05?ooool3o`0004Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`25
ooooo`00K?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^017ooooo0ol00002ooooo`03o`000?oooooo
oooo04;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`24ooooo`00P?ooool2o`00
04[ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`23ooooo`00OOooool3o`0004co
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`22ooooo`00Noooool2o`000003oooo
ool0003ooooo04cooooo00?o0000ooooooooool05?ooool2o`0008?ooooo001hooooo`?o0000DOoo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooo000008?ooooo001eooooo`?o0000E?ooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo083ooooo001cooooo`Co0000EOooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo07oooooo001`ooooo`?o00001?ooool00ol0003o
ooooooooo`1Booooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0Ooooool006kooooo
0_l0001Looooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0O_ooool004?ooooo1?l0
00000ol@413oooooooooo`0Qooooo`?o0000G_ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo07gooooo0015ooooo`03o`000?oooooooooo023ooooo0ol00003ooooo`03o`000?oooooo
oooo05_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1looooo`00>_ooool6o`00
00Gooooo00?o0000ooooooooool07_ooool2o`0006Cooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`1looooo`00AOooool00ol0003oooooooooo`0Kooooo`?o0000I_ooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo07_ooooo0015ooooo`03o`000?oooooooooo01Wooooo
0_l00002ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`1jooooo`00AOooool00ol0003oooooooooo`0Fooooo`?o0000Joooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo07Wooooo0015ooooo`03o`000?oooooooooo01Cooooo0_l0001^
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0NOooool004?ooooo00?oEEEEofIV
I_l000004oooool3o`000003ooooool0003ooooo06gooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`1hooooo`00E_ooool3o`0007?ooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`1gooooo`00E?ooool2o`0007Kooooo00?o0000ooooooooool07oooool2o`0007Sooooo
001Aooooo`?o000000?oooooo`000?ooool0MOooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo07Kooooo001?ooooo`;o0000Noooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo07Gooooo001<ooooo`?o0000OOooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
07Cooooo0019ooooo`Co0000Ooooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo07?o
oooo0017ooooo`;o00001?ooool00ol0003oooooooooo`1looooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool0L_ooool004Cooooo0ol00025ooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool0L_ooool001[ooooo1Ol0000Sooooo`?o0000Qoooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo077ooooo000Jooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@08?ooool3
o`0000?ooooo00?o0000ooooooooool0Q?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo073ooooo000Booooo`Ko00000oooool00onHV9So8B4Qonk^kP0Oooooo`;o0000SOooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo06oooooo000Looooo`03oiRHV?lQ8B7ok^k^01_o
oooo0ol0002?ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0Koooool001gooooo
00?oMgMgofIVI_ooool05oooool3o`0000?ooooo00?o0000ooooooooool0S?ooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooooooo06kooooo000Nooooo`03o`000?oooooooooo01Cooooo0_l0
002Eooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0KOooool001[ooooo00Go0000
okZj^_ooooooV9RHoa0@400Cooooo`?o0000Uoooool00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo06cooooo000Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`04Oooool2o`0000?ooooo00?o
0000ooooooooool0U?ooool00ol0003oooooooooo`0Zooooo`;o0000KOooool002gooooo0ol0002L
ooooo`03o`000?oooooooooo02[ooooo0_l0001]ooooo`00:_ooool3o`0009oooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`1Zooooo`00:?ooool2o`0000?ooooo00?o0000oooooooo
ool0W?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo06Wooooo000Uooooo`?o0000
Y?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo06Wooooo000Tooooo`03o`000?oo
oooooooo0:Gooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1Xooooo`006_ooool4
o`000003oa0@4?oooooooooo00?ooooo0_l0002Vooooo`03o`000?oooooooooo02oooooo00?o0000
ooooooooool0Ioooool001cooooo00?o0000ooooooooool01Oooool2o`000:Kooooo00?o0000oooo
ooooool0<?ooool00ol0003oooooooooo`1Vooooo`004Oooool6o`0000Gooooo00?o0000oooooooo
ool01?ooool4o`000:Gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`08ooooo`Go
0000FOooool001cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0002Tooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool01OnHV9So8B4Qonk^k_ooooooA4A4
05Wooooo000Looooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`2Qooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool01oooool00onHV9So
8B4Qonk^kP1Jooooo`007?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0X?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Oooooo
00?oV9RHob4Q8Oo^k^h0FOooool001cooooo00?o0000ooooooooool01?ooool2o`0000Gooooo00?o
0000ooooooooool0Woooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Oooooo00?o
MgMgofIVI_ooool0F?ooool001[ooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo09kooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo05Oooooo000Sooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0WOooool00ol0003oooooooooo`0eooooo`;o00001?ooool01Ol0003o^[ZjoooooonHV9So
410@05Wooooo000Sooooo`;o00002?ooool00ol0003oooooooooo`2Looooo`03o`000?oooooooooo
03?ooooo0_l000000ooooooo0000ooooo`03ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0FOooool0
02?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2Kooooo`03o`000?oooooooooo
03Oooooo00?o0000ooooooooool0Goooool002?ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`2Jooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0Goooool002?ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`2Hooooo`;o0000>_ooool00ol0003ooooo
ooooo`1Nooooo`008_ooool2o`0000gooooo00?o0000ooooooooool0U?ooool3o`000003ooooool0
003ooooo03[ooooo00?o0000ooooooooool0GOooool002;ooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`2@ooooo`?o00001Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooo
oooo05cooooo000Rooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0S?ooool3o`00
00Wooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1Looooo`008_ooool3o`0000oo
oooo00?o0000ooooooooool0R?ooool3o`0000gooooo00?o0000ooooooooool0>?ooool00ol0003o
ooooooooo`1Kooooo`008_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo08Gooooo
0_l0000Aooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0F_ooool002;ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`21ooooo`?o00005?ooool00ol0003ooooooooo
o`0hooooo`03o`000?oooooooooo05Wooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool0OOooool3o`0001Oooooo00?o0000ooooooooool0>?ooool00ol0003ooooo
ooooo`1Iooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1iooooo`?o0000
6oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo05Sooooo0005o`0000;ooooo00Go
410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`1eooooo`?o00007oooool00ol0003oooooooooo`0hooooo`03o`00
0?oooooooooo05Oooooo0007ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8b
ooooo`03ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0LOooool3o`0002?ooooo
00?o0000ooooooooool0=oooool2o`0005Sooooo0007ooooo`05o`000?ooooooooooooooool00000
3?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`1^ooooo`;o00009oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo05Go
oooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`;o
00006Oooool00ol0003oooooooooo`1Zooooo`?o0000:_ooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo05Gooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0I_ooool3o`0002go
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1Dooooo`001oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool0H_ooool3o`00037ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1Cooooo`00
8Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo05kooooo0ol0000eooooo`03o`00
0?oooooooooo03Sooooo00?o0000ooooooooool0D_ooool0023ooooo0ol0000Mooooo`03o`000?oo
oooooooo05_ooooo0_l0000iooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0D_oo
ool0027ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1Gooooo`?o0000??ooool0
0ol0003oooooooooo`0gooooo`03o`000?oooooooooo057ooooo000Pooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool0Doooool3o`00043ooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`1@ooooo`008?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo04oo
oooo0ol00013ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0Coooool0023ooooo
0_l0000Rooooo`03o`000?oooooooooo04_ooooo0ol00017ooooo`03o`000?oooooooooo03Oooooo
00?o0000ooooooooool0Coooool0023ooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`18ooooo`;o0000Boooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo04kooooo000P
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0A?ooool3o`0004kooooo00?o0000
ooooooooool0=oooool00ol0003oooooooooo`1=ooooo`008?ooool3o`0002Cooooo00?o0000oooo
ooooool0@?ooool3o`0005;ooooo00?o0000ooooooooool04_ooool4oonI023ooooo0_l0001>oooo
o`008?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo03cooooo0ol0001Fooooo`03
o`000?oooooooooo00cooooo1OooV@0Uooooo`03o`000?oooooooooo04cooooo000Dooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01oooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo03So
oooo0ol0001Iooooo`03o`000?oooooooooo00Cooooo2?ooV@0[ooooo`03o`000?oooooooooo04_o
oooo000Dooooo`05ogMgMonHV9SooooooiRHV?mgMgL01_ooool00ol0003oooooooooo`0Xooooo`03
o`000?oooooooooo03Gooooo0_l00017oooooaKooiT000?o0000oonI0?ooV@000oooV@0dooooo`03
o`000?oooooooooo04[ooooo000Dooooo`05oa0@4?ooooooooooooooool@41001_ooool2o`0002[o
oooo00?o0000ooooooooool0<Oooool3o`0004?ooooo1_ooV@0Gooooo`03o`000?oooooooooo03Oo
oooo00?o0000ooooooooool0BOooool001Cooooo00Go0000ooooooooooooooooo`000006ooooo`03
o`000?oooooooooo02[ooooo00?o0000ooooooooool0;Oooool3o`0004;ooooo1?ooV@0Nooooo`03
o`000?oooooooooo03Kooooo00?o0000ooooooooool0BOooool001Cooooo00Go0000oooooooooooo
ooooo`000006ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0:Oooool3o`00043o
oooo1OooV@0Sooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0B?ooool001Cooooo
00Go410@oooooooooooooooooa0@4006ooooo`03o`000?oooooooooo02cooooo00?o0000oooooooo
ool09Oooool3o`0003kooooo1OooV@0Yooooo`03o`000?oooooooooo03Kooooo00?o0000oooooooo
ool0Aoooool001Cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`06ooooo`;o0000;_ooool00ol0003o
ooooooooo`0Qooooo`?o0000?_ooool3oonI02kooooo00?o0000ooooooooool0=oooool00ol0003o
ooooooooo`16ooooo`005?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooooooo
ool0;_ooool00ol0003oooooooooo`0Nooooo`;o0000?oooool2oonI03;ooooo00?o0000oooooooo
ool0=oooool00ol0003oooooooooo`15ooooo`007oooool00ol0003oooooooooo`0_ooooo`03o`00
0?oooooooooo01[ooooo0ol0000oooooo`;ooiT0=Oooool00ol0003oooooooooo`0fooooo`03o`00
0?oooooooooo04Gooooo000Nooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool05_oo
ool3o`0003oooooo0oooV@0hooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0A?oo
ool001kooooo0_l0000cooooo`03o`000?oooooooooo01;ooooo0ol0000oooooo`?ooiT0??ooool0
0ol0003oooooooooo`0;ooooo`Coc?l09oooool2o`0004Cooooo000Nooooo`03o`000?oooooooooo
03?ooooo00?o0000ooooooooool03_ooool3o`00047ooooo00?ooiT0ooooooooool0?_ooool00ol0
003oooooooooo`03ooooo`Ooc?l0:_ooool00ol0003oooooo`000014ooooo`007_ooool00ol0003o
ooooooooo`0dooooo`03o`000?oooooooooo00_ooooo0_l00013ooooo`03oonI0?oooooooooo03co
oooo0oo<o`000ol0003oc?l0olco0003olco03?ooooo00?o0000ooooooooool0@_ooool001kooooo
00?o0000ooooooooool0=Oooool00ol0003oooooooooo`07ooooo`?o0000A?ooool00oooV@3ooooo
ooooo`0Kooooob;oc?l01?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo047ooooo
000Nooooo`;o0000=oooool00ol0003oooooooooo`03ooooo`?o0000AOooool2oonI01Oooooo1oo<
o`0Wooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0@?ooool001kooooo00?o0000
ooooooooool0=oooool00ol0003oooooo`000002o`0004Kooooo0_ooV@0Dooooo`Goc?l0;oooool0
0ol0003oooooooooo`0fooooo`03o`000?oooooooooo03oooooo000Nooooo`03o`000?oooooooooo
03Kooooo0ol00018ooooo`03oonI0?oooooooooo01;ooooo0_o<o`0eooooo`03o`000?oooooooooo
03Gooooo00?o0000ooooooooool0?oooool001kooooo0_l0000eooooo`;o00000oooool00ol0003o
ooooooooo`13ooooo`;ooiT04oooool2olco03Sooooo00?o0000ooooooooool0=Oooool00ol0003o
ooooooooo`09ooooo`;o000000?o410@ooooooooool0<?ooool001gooooo00?o0000ooooooooool0
<_ooool3o`0000Kooooo00?o0000ooooooooool0@Oooool00oooV@3oooooooooo`0Aooooo`;oc?l0
>_ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
<Oooool000;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000
o`000?lb<S;ogMgM00Gooooo00?o0000ooooooooool0;oooool3o`0000[ooooo00?o0000oooooooo
ool0?oooool00oooV@3oooooooooo`0?ooooo`?oc?l0?Oooool00ol0003oooooooooo`0fooooo`03
o`000?oooooooooo00Gooooo1Ol0000booooo`000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0;?ooool3o`0000ko
oooo00?o0000ooooooooool0?Oooool00oooV@3oooooooooo`0>ooooo`;oc?l0@Oooool00ol0003o
ooooooooo`0eooooo`03o`000?oooooooooo00Gooooo00CoA4A4omgMgOoooooo0000<oooool000;o
oooo00Go410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00?ooooo0_l0000Zoooo
o`?o00004_ooool00ol0003oooooooooo`0jooooo`;ooiT03oooool2olco04Cooooo00?o0000oooo
ooooool0=Oooool00ol0003oooooooooo`04ooooo`04omgMgOmEEEGoooooo`0003?ooooo0002oooo
o`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo
oooo02Oooooo0_l0000Fooooo`03o`000?oooooooooo03Sooooo00?ooiT0ooooooooool03_ooool0
0oo<o`3oooooooooo`15ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool01?ooool0
0omgMgOoc<c<o`00000cooooo`000_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000
ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo02Cooooo0ol0000Iooooo`03o`000?oo
oooooooo03Kooooo00?ooiT0ooooooooool03_ooool00oo<o`3oooooooooo`17ooooo`03o`000?oo
oooooooo00;ooooo1?lco`0^ooooo`;o00001Oooool00oo^k^koA4A4o`00000cooooo`000_ooool0
1Ol@413ooooooooooooooooo410@00cooooo00?o0000ooooooooool01oooool00ol0003ooooooooo
o`0Qooooo`?o00007Oooool00ol0003oooooooooo`0dooooo`03oonI0?oooooooooo00kooooo00?o
c?l0ooooooooool06Oooool7oc?o02Kooooo0_lco`000ol0003o<ol0oc?o0002oc?o037ooooo00Co
0000oooooooooooo00001Oooool00omgMgOo0000ooooo`0booooo`000_ooool01OmgMgOoV9RHoooo
oonHV9SoMgMg00cooooo00?o0000ooooooooool01oooool2o`0001oooooo0ol0000Qooooo`03o`00
0?oooooooooo03;ooooo00?ooiT0ooooooooool03_ooool00oo<o`3oooooooooo`0Eooooo`Go<ol0
1ooooolAoc?o00_ooooo2_lco`03ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0
>?ooool000;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003ooooo
ooooo`0Looooo`?o00009Oooool00ol0003oooooooooo`0_ooooo`;ooiT04?ooool00oo<o`3ooooo
ooooo`0Booooo`Co<ol07Oooool;oc?o00kooooo00?o0000ooooooooool0=Oooool00ol0003ooooo
ooooo`0gooooo`007?ooool00ol0003oooooooooo`0Iooooo`?o0000:Oooool00ol0003ooooooooo
o`0]ooooo`03oonI0?oooooooooo00oooooo00?oc?l0ooooooooool04?ooool3oc?o03_ooooo00?o
0000ooooooooool0=Oooool00ol0003oooooooooo`0fooooo`007?ooool00ol0003oooooooooo`0G
ooooo`;o0000;Oooool00ol0003oooooooooo`0[ooooo`03oonI0?oooooooooo00oooooo00?oc?l0
ooooooooool03_ooool3oc?o03oooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0e
ooooo`007?ooool2o`0001Gooooo0ol0000`ooooo`03o`000?oooooooooo02Wooooo00?ooiT0oooo
ooooool03oooool00oo<o`3oooooooooo`0=ooooo`;o<ol0@oooool00ol0003oooooooooo`0doooo
o`03o`000?oooooooooo03Gooooo000Looooo`03o`000?oooooooooo017ooooo0ol0000dooooo`03
o`000?oooooooooo02Oooooo00?ooiT0ooooooooool03oooool00oo<o`3oooooooooo`0<ooooo`;o
<ol0AOooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo03Cooooo000Looooo`03o`00
0?oooooooooo00kooooo0ol0000hooooo`03o`000?oooooooooo02Cooooo0_ooV@0Aooooo`03olco
0?oooooooooo00cooooo00?o<ol0ooooooooool0A_ooool00ol0003oooooooooo`0eooooo`03o`00
0?oooooooooo03?ooooo000Looooo`03o`000?oooooooooo00_ooooo0ol0000looooo`03o`000?oo
oooooooo02;ooooo00?ooiT0ooooooooool04?ooool00oo<o`3oooooooooo`0<ooooo`03oc?o0?oo
oooooooo04Sooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0booooo`007?ooool2
o`0000[ooooo0_l00010ooooo`03o`000?oooooooooo01oooooo0_ooV@0Booooo`03olco0?oooooo
oooo00cooooo00?o<ol0ooooooooool0B_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooo
oooo03;ooooo000Kooooo`;o00002?ooool3o`0004?ooooo00?o0000ooooooooool07?ooool2oonI
01?ooooo00?oc?l0ooooooooool03?ooool00olco`3oooooooooo`1<ooooo`03o`000?oooooooooo
03Cooooo00?o0000ooooooooool0<Oooool001_ooooo00?o0000ooooooooool01?ooool3o`0004Oo
oooo00?o0000ooooooooool06_ooool00oooV@3oooooooooo`0Booooo`03olco0?oooooooooo00co
oooo00?o<ol0ooooooooool0C_ooool00ol0003oooooooooo`0cooooo`;o0000<_ooool001_ooooo
00Co0000oooooooooooooooo0ol0001;ooooo`03o`000?oooooooooo01Sooooo00?ooiT0oooooooo
ool04Oooool2olco00kooooo00?o<ol0ooooooooool04oooool:o`3oIRoooooo0ol0ofH00ol0003o
0?mVooooo`0eooooo`03o`000?oooooooooo02oooooo000Kooooo`Co0000Coooool00ol0003ooooo
ooooo`0Zooooo`03olco0?oooooooooo00kooooo00?o<ol0ooooooooool03oooool4o`3oIP[ooooo
1_l0ofHRooooo`Oo0?mV1?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02oooooo
000Kooooo`;o0000D_ooool00ol0003oooooooooo`0Xooooo`03olco0?oooooooooo00kooooo00?o
<ol0ooooooooool03_ooool2o`3oIQCooooo2_l0ofH<ooooo`co0?mV3?ooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo02kooooo000Aooooo`Co000000?o410@ooooooooool01Oooool0
0ol0003oooooooooo`1@ooooo`03o`000?oooooooooo02Kooooo00?oc?l0ooooooooool03_ooool0
0olco`3oooooooooo`0=ooooo`;o0?mV8?ooool<o`3oIQWooooo00?o0000ooooooooool0=?ooool0
0ol0003oooooooooo`0]ooooo`004oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo
053ooooo00?o0000ooooooooool09?ooool00oo<o`3oooooooooo`0>ooooo`03oc?o0?oooooooooo
00cooooo0_l0ofI8ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0;?ooool001?o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo02;o
oooo00?oc?l0ooooooooool03oooool00olco`3oooooooooo`0;ooooo`03o`3oI_oooooooooo04Wo
oooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0/ooooo`004oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool07oooool2olco017ooooo
00?o<ol0ooooooooool02oooool00ol0ofKoooooooooo`1:ooooo`03o`000?oooooooooo03Cooooo
00?o0000ooooooooool0:oooool001?ooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`1@ooooo`03o`000?oooooooooo01cooooo0_o<o`0Booooo`03oc?o0?oooooooooo00_ooooo00?o
0?mVooooooooool0C?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02[ooooo000C
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0I
ooooo`;oc?l04oooool00olco`3oooooooooo`0;ooooo`03o`3oI_oooooooooo04kooooo00?o0000
ooooooooool0=?ooool00ol0003oooooooooo`0Yooooo`004oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo053ooooo00?o0000ooooooooool05oooool00oo<o`3oooooooooo`0Boooo
o`03oc?o0?oooooooooo00_ooooo00?o0?mVooooooooool0D?ooool00ol0003oooooooooo`0doooo
o`03o`000?oooooooooo02Sooooo000Aooooo`03oeEEEOmVIVKo0000013ooooo00?o0000oooooooo
ool0D?ooool00ol0003oooooooooo`0Dooooo`;oc?l04oooool2oc?o00kooooo00?o0?mVoooooooo
ool0DOooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02Sooooo000Uooooo`03o`00
0?oooooooooo053ooooo00?o0000ooooooooool04_ooool00oo<o`3oooooooooo`0Booooo`03oc?o
0?oooooooooo00gooooo00?o0?mVooooooooool0Doooool00ol0003oooooooooo`0booooo`;o0000
:Oooool002Kooooo0_l0001Aooooo`03o`000?oooooooooo02Gooooo00?o<ol0ooooooooool03_oo
ool00ol0ofKoooooooooo`1Cooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool09_oo
ool002Sooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0Sooooo`;o<ol04Oooool0
0ol0ofKoooooooooo`0<ooooo`go0?oo<?ooool5o`3oo`Kooooo00?o0000ooooooooool0=?ooool0
0ol0003oooooooooo`0Uooooo`00:Oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo
027ooooo00?o<ol0ooooooooool04?ooool00ol0ofKoooooooooo`0;ooooo`;o0?oo3Oooool4o`3o
ob?ooooo2Ol0ool<ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool09Oooool002[o
oooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0Oooooo`03oc?o0?oooooooooo017o
oooo00?o0?mVooooooooool02_ooool00ol0ooooooooooooo`0Aooooo`Wo0?oo3_ooool<o`3ooaKo
oooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Tooooo`00:oooool00ol0003ooooo
ooooo`1>ooooo`03o`000?oooooooooo01cooooo0_lco`0Cooooo`03o`3oI_oooooooooo00[ooooo
00?o0?ooooooooooool06oooool>o`3oob?ooooo00?o0000ooooooooool0<oooool00ol0003ooooo
ooooo`0Sooooo`00;?ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo01[ooooo00?o
<ol0ooooooooool04_ooool00ol0ofKoooooooooo`0;ooooo`03o`3ooooooooooooo04gooooo00?o
0000ooooooooool0<oooool00ol0003oooooooooo`0Rooooo`00;Oooool00ol0003oooooooooo`1>
ooooo`03o`000?oooooooooo01Oooooo0_lco`0Dooooo`03o`3oI_oooooooooo00_ooooo00?o0?oo
ooooooooool0C_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02;ooooo000^oooo
o`03o`000?oooooooooo04kooooo00?o0000ooooooooool05Oooool00olco`3oooooooooo`0Coooo
o`03o`3oI_oooooooooo00_ooooo00?o0?ooooooooooool0D?ooool00ol0003oooooooooo`0coooo
o`03o`000?oooooooooo027ooooo000_ooooo`03o`000?oooooooooo04kooooo00?o0000oooooooo
ool04_ooool2oc?o01Cooooo0_l0ofH>ooooo`03o`3ooooooooooooo057ooooo00?o0000oooooooo
ool0<oooool00ol0003oooooooooo`0Pooooo`00<?ooool00ol0003oooooooooo`1>ooooo`03o`00
0?oooooooooo013ooooo00?o<ol0ooooooooool04oooool00ol0ofKoooooooooo`0=ooooo`03o`3o
oooooooooooo05?ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Oooooo`00<Ooo
ool2o`0004oooooo00?o0000ooooooooool03_ooool00olco`3oooooooooo`0Cooooo`03o`3oI_oo
oooooooo00kooooo00?o0?ooooooooooool0E?ooool00ol0003oooooooooo`0booooo`;o00008?oo
ool003?ooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0Qooooo`;o0?mV4?ooool0
0ol0ooooooooooooo`1Fooooo`03o`000?oooooooooo037ooooo0_l0000Pooooo`00=?ooool00ol0
003oooooooooo`1=ooooo`03o`000?oooooooooo01oooooo00?o0?mVooooooooool04?ooool00ol0
ooooooooooooo`1Fooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool07Oooool003Go
oooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0Mooooo`03o`3oI_oooooooooo013o
oooo00?o0?ooooooooooool0A_ooool4o`1Vo`kooooo00?o0000ooooooooool0<oooool00ol0003o
ooooooooo`0Looooo`00=_ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo01_ooooo
00?o0?mVooooooooool04?ooool00ol0ooooooooooooo`0;ooooo`Wo06Ko;Oooool6o`1Voa?ooooo
00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Looooo`00=oooool00ol0003ooooooooo
o`1=ooooo`03o`000?oooooooooo01Sooooo0_l0ofHBooooo`03o`3ooooooooooooo00cooooo00?o
06Koooooooooool01_ooool<o`1Voacooooo1Ol0I_lJooooo`03o`000?oooooooooo03;ooooo00?o
0000ooooooooool06oooool003Sooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0E
ooooo`;o0?mV4oooool00ol0ooooooooooooo`0<ooooo`03o`1Voooooooooooo01?ooooo7?l0I_lP
ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool01oooool01Oo^k^ko<S8bo`000?l@
413oc<c<00kooooo000iooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool04_ooool2
o`3oIQCooooo00?o0?ooooooooooool03Oooool00ol0I_ooooooooooo`1@ooooo`03o`000?oooooo
oooo03;ooooo00?o0000ooooooooool01_ooool01OmEEEGoMgMgoooooonHV9So8B4Q00kooooo000j
ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool04?ooool00ol0ofKoooooooooo`0B
ooooo`;o0?oo3oooool00ol0I_ooooooooooo`1Aooooo`03o`000?oooooooooo03?ooooo00?o0000
ooooooooool01Oooool01Ol0003ooooooooooooooooo000000kooooo000kooooo`03o`000?oooooo
oooo04gooooo00?o0000ooooooooool03Oooool2o`3oIQCooooo00?o0?ooooooooooool03_ooool0
0ol0I_ooooooooooo`1Cooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool01Oooool0
1Ol0003oV9RHoooooonHV9So8B4Q00kooooo000looooo`03o`000?oooooooooo04gooooo00?o0000
ooooooooool02_ooool2o`3oIQGooooo00?o0?ooooooooooool03_ooool00ol0I_ooooooooooo`1E
ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool01?ooool01Ol0003oEEEEo`000?l@
413oc<c<00kooooo000mooooo`;o0000C_ooool00ol0003oooooooooo`08ooooo`03o`3oI_oooooo
oooo01Cooooo00?o0?ooooooooooool03oooool00ol0I_ooooooooooo`1Fooooo`03o`000?oooooo
oooo03;ooooo0_l00004ooooo`03oeEEEOn7QhOooooo013ooooo000oooooo`03o`000?oooooooooo
04cooooo00?o0000ooooooooool07Oooool00ol0ooooooooooooo`0?ooooo`03o`1Voooooooooooo
05Sooooo00?o0000ooooooooool0;oooool2o`000003ooooool0003ooooo00?ooooo00?ogMgMoa0@
4?nHV9P04?ooool0043ooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0Kooooo`03
o`3ooooooooooooo00oooooo00?o06Koooooooooool0F_ooool00ol0003oooooooooo`0aooooo`03
o`000?oooooooooo00?ooooo00Coc<c<odA4A?l0003o410@3_ooool0047ooooo00?o0000oooooooo
ool0C?ooool00ol0003oooooooooo`0Iooooo`03o`3ooooooooooooo00oooooo00?o06Kooooooooo
ool02oooool2oc<0odkooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Dooooo`00
@_ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo01Oooooo00?o0?ooooooooooool0
4?ooool00ol0I_ooooooooooo`09ooooo`;o<`3o00?ooooooc<0ooooool0C_ooool00ol0003ooooo
ooooo`0booooo`03o`000?oooooooooo01?ooooo0013ooooo`03o`000?oooooooooo04cooooo00?o
0000ooooooooool05?ooool2o`3ooa;ooooo00?o06Koooooooooool01Oooool5oc<0o`?ooooo00?o
<`3oooooooooool0<_ooool6oc<0oaKooooo00?o0000ooooooooool0<_ooool00ol0003ooooooooo
o`0Booooo`00A?ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo017ooooo0_l0oolC
ooooo`03o`1Voooooooooooo00Oooooo1olc0?l/ooooo`Wo<`3o7Oooool00ol0003oooooooooo`0a
ooooo`03o`000?oooooooooo01;ooooo0015ooooo`03o`000?oooooooooo04cooooo00?o0000oooo
ooooool03oooool00ol0ooooooooooooo`0Aooooo`;o06Ko3oooool=oc<0oa;ooooo3olc0?lWoooo
o`03o`000?oooooooooo037ooooo00?o0000ooooooooool04Oooool004Kooooo00?o0000oooooooo
ool0C?ooool00ol0003oooooooooo`0<ooooo`;o0?oo4oooool00ol0I_ooooooooooo`0>ooooo`03
oc<0oooooooooooo00_ooooo4_lc0?lgooooo`03o`000?oooooooooo037ooooo00?o0000oooooooo
ool04?ooool004Oooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`09ooooo`;o0?oo
5?ooool00ol0I_ooooooooooo`0?ooooo`03oc<0oooooooooooo05Cooooo00?o0000ooooooooool0
<_ooool00ol0003oooooooooo`0?ooooo`00B?ooool2o`0004gooooo00?o0000ooooooooool01ooo
ool00ol0ooooooooooooo`0Cooooo`03o`1Voooooooooooo00oooooo00?o<`3oooooooooool0E_oo
ool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00oooooo001:ooooo`03o`000?oooooo
oooo04_ooooo00?o0000ooooooooool01?ooool2o`3ooaCooooo0_l0I_lAooooo`03oc<0oooooooo
oooo05Sooooo00?o0000ooooooooool0<Oooool2o`0000oooooo001;ooooo`03o`000?oooooooooo
04_ooooo00?o0000ooooooooool00_ooool00ol0ooooooooooooo`0Cooooo`03o`1Voooooooooooo
013ooooo00?o<`3oooooooooool03?ooool00oo<0?ooooooooooo`1;ooooo`03o`000?oooooooooo
033ooooo0_l0000?ooooo`00C?ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo01Ko
oooo00?o06Koooooooooool04?ooool00olc0?ooooooooooo`0<ooooo`03ol`0oooooooooooo04go
oooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0<ooooo`00COooool00ol0003ooooo
ooooo`1;ooooo`03o`000?oooooooooo01Cooooo00?o06Koooooooooool04Oooool00olc0?oooooo
ooooo`0:ooooo`?oc03oD?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00_ooooo
001>ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04_ooool00ol0I_oooooooooo
o`0Aooooo`03oc<0oooooooooooo00Wooooo0_o<0?l00oooooooc03oooooo`1@ooooo`03o`000?oo
oooooooo037ooooo00?o0000ooooooooool02oooool004oooooo00?o0000ooooooooool0Boooool0
0ol0003oooooooooo`0?ooooo`;o06Ko4oooool00olc0?ooooooooooo`08ooooo`;oc03o0oooool0
0oo<0?ooooooooooo`1@ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool02_ooool0
053ooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0<ooooo`;o06Ko4oooool2oc<0
o`Wooooo0_o<0?l5ooooo`03ol`0oooooooooooo033ooooo1?o<0?lMooooo`03o`000?oooooooooo
037ooooo00?o0000ooooooooool02Oooool0057ooooo00?o0000ooooooooool0Boooool00ol0003o
ooooooooo`0:ooooo`03o`1Voooooooooooo01;ooooo00?o<`3oooooooo<0?l02Oo<0?l6ooooo`03
ol`0oooooooooooo02[ooooo1oo<0?lRooooo`03o`000?oooooooooo037ooooo00?o0000oooooooo
ool02?ooool005;ooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`07ooooo`;o06Ko
5?ooool00olc0?ooooooooooo`04ooooo`Goc03o1oooool00oo<0?ooooooooooo`0Sooooo`Ooc03o
:_ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Sooooo001Cooooo`;o0000C?oo
ool00ol0003oooooooooo`04ooooo`;o06Ko5?ooool2oc<0o`cooooo2oo<0?lCooooo`ooc03o<_oo
ool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Oooooo001Eooooo`03o`000?oooooo
oooo04[ooooo00?o0000ooooooooool00_ooool00ol0I_ooooooooooo`0Cooooo`03oc<0oooooooo
oooo017ooooo00?oc03oooooooooool00ooooolCol`0od7ooooo00?o0000ooooooooool0<Oooool0
0ol0003oooooooooo`06ooooo`00E_ooool00ol0003oooooooooo`1:ooooo`04o`000?oooooo06Ko
o`1VoaGooooo00?o<`3oooooooooool04Oooool00oo<0?ooooooooooo`0;ooooo`03ool0VOoooooo
oooo04_ooooo00?o0000ooooooooool0;oooool3o`0000Oooooo001Gooooo`03o`000?oooooooooo
04[ooooo00?o06Koooooooooool04oooool2oc<0oa?ooooo00?oc03oooooooooool02oooool2ool0
VDkooooo00?o0000ooooooooool0:oooool3o`0000;ooooo00?o0000ooooooooool01Oooool005So
oooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0Aooooo`03oc<0oooooooooooo01;o
oooo00?oc03oooooooooool02oooool2ool0VE3ooooo00?o0000ooooooooool09oooool3o`0000Go
oooo00?o0000ooooooooool01Oooool005Wooooo00?o0000ooooooooool0B_ooool00ol0003ooooo
ooooo`0?ooooo`03oc<0oooooooooooo01;ooooo00?oc03oooooooooool02_ooool3ool0VE;ooooo
00?o0000ooooooooool08_ooool4o`0000Sooooo00?o0000ooooooooool01Oooool005[ooooo00?o
0000ooooooooool0B_ooool00ol0003oooooooooo`0<ooooo`;o<`3o5?ooool00oo<0?oooooooooo
o`09ooooo`;oo`2I0_ooool00ooo09Woooooooooo`1Aooooo`03o`000?oooooooooo01kooooo0ol0
000<ooooo`03o`000?oooooooooo00Gooooo001Kooooo`03o`000?oooooooooo04[ooooo00?o0000
ooooooooool02Oooool2oc<0oaCooooo0_o<0?l;ooooo`05ool0VOoooooooooooooooooo09T0E?oo
ool00ol0003oooooooooo`0Jooooo`Co00003oooool00ol0003oooooooooo`05ooooo`00G?ooool0
0ol0003oooooooooo`1:ooooo`03o`000?oooooooooo00Oooooo00?o<`3oooooooooool04oooool0
0oo<0?ooooooooooo`08ooooo`?oo`2I1?ooool00ooo09Woooooooooo`1Cooooo`03o`000?oooooo
oooo01Kooooo0ol0000Dooooo`03o`000?oooooooooo00Cooooo001Mooooo`03o`000?oooooooooo
04[ooooo00?o0000ooooooooool01?ooool2oc<0oaGooooo00?oc03oooooooooool01_ooool3ool0
V@Kooooo00?oo`2Iooooooooool0EOooool00ol0003oooooooooo`0Booooo`?o00005oooool00ol0
003oooooooooo`04ooooo`00G_ooool2o`0004_ooooo00Co0000oooooooooooooooo0_lc0?lEoooo
o`;oc03o0oooool6ool0V@Sooooo00?oo`2Iooooooooool0;Oooool4ool0VBKooooo00?o0000oooo
ooooool03Oooool4o`0001[ooooo00?o0000ooooooooool01?ooool0063ooooo00?o0000oooooooo
ool0BOooool00ol0003o<`3ooc<0o`0Booooo`[oo`2I3Oooool00ooo09Woooooooooo`0<ooooo`03
ool00?oooooooooo01Sooooo1ooo09T[ooooo`03o`000?oooooooooo00Wooooo0ol0000Nooooo`03
o`000?oooooooooo00Cooooo001Qooooo`03o`000?oooooooooo04Sooooo00?o<`3oo`000?ooool0
5Oooool00oo<0?ooooooooooo`0:ool0V@Kooooo00?oo`2Iooooooooool03Oooool00ooo003ooooo
ooooo`0Aooooo`Ooo`2I<oooool00ol0003oooooooooo`04ooooo`Co00008Oooool00ol0003ooooo
ooooo`04ooooo`00H_ooool00ol0003oooooooooo`15ooooo`;o<`3o0_ooool00ol0003ooooooooo
o`0Booooo`03ol`0oooooooooooo00_ooooo2Ooo09T<ooooo`03ool00?oooooooooo00;ooooo4?oo
09Tjooooo`04o`000?ooooooooooooooo`?o00009Oooool00ol0003oooooooooo`04ooooo`00Hooo
ool00ol0003oooooooooo`13ooooo`03oc<0oooooooooooo00?ooooo00?o0000ooooooooool03ooo
ool2ol`0oa;ooooo00?oo`2Iooooooooool00_ooool;ool0V@;oo`001?oo09U;ooooo`?o0000:?oo
ool00ol0003oooooooooo`04ooooo`00I?ooool00ol0003oooooooooo`19ooooo`03o`000?oooooo
oooo00gooooo00?oc03oooooooooool04Oooool00ooo09Woooooooooo`0=ooooo`;oo`00C?ooool4
o`000003ooooool0003ooooo02Sooooo00?o0000ooooooooool01?ooool006Gooooo00?o0000oooo
ooooool0BOooool00ol0003oooooooooo`0;ooooo`03ol`0oooooooooooo017ooooo00?oo`2Ioooo
ooooool03?ooool2ool00003oooooooo003ooooo04Sooooo0ol00006ooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool01?ooool006Kooooo00?o0000ooooooooool0BOooool00ol0003o
ooooooooo`08ooooo`;oc03o4_ooool2ool0V@gooooo0_oo0002ooooo`03ool00?oooooooooo04Co
oooo1?l0000:ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool01?ooool006Oooooo
00?o0000ooooooooool0BOooool00ol0003oooooooooo`05ooooo`;oc03o4oooool00ooo09Wooooo
ooooo`0;ooooo`;oo`000oooool00ooo003oooooooooo`12ooooo`?o00003oooool00ol0003ooooo
ooooo`0Uooooo`03o`000?oooooooooo00?ooooo001Xooooo`03o`000?oooooooooo04Wooooo00?o
0000ooooooooool00_ooool2ol`0oaCooooo00?oo`2Iooooooooool02_ooool2ool000Cooooo00?o
o`00ooooooooool0@?ooool3o`0001;ooooo00?o0000ooooooooool09Oooool00ol0003ooooooooo
o`03ooooo`00JOooool00ol0003oooooooooo`19ooooo`04o`000?ooooooc03ool`0oaGooooo00?o
o`2Iooooooooool02?ooool3ool000Gooooo00?oo`00ooooooooool0?Oooool4o`0001Kooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`03ooooo`00J_ooool2o`0004[ooooo00?oc03o
ooooooooool04oooool2ool0V@Kooooo1Ooo0007ooooo`03ool00?oooooooooo03_ooooo0ol0000K
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool00oooool006cooooo00?o0000oooo
ooooool0AOooool2ol`0o`03ooooool0003ooooo01;ooooo00?oo`2Iooooooooool00_ooool4ool0
00_ooooo00?oo`00ooooooooool0:Oooool5ool000[ooooo1?l0000Oooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool00oooool006gooooo00?o0000ooooooooool0@_ooool2ol`0o`Co
oooo00?o0000ooooooooool01?ooool6ool000Gooooo00?oo`2Iool00?oo00000ooo000>ooooo`03
ool00?oooooooooo02;ooooo2?oo000<ooooo`?o00009?ooool00ol0003oooooooooo`0Qooooo`03
o`000?oooooooooo00?ooooo001^ooooo`03o`000?oooooooooo03oooooo0_o<0?l7ooooo`03o`00
0?oooooooooo00Oooooo2?oo000Booooo`03ool00?oooooooooo01cooooo1ooo000Aooooo`?o0000
:?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00?ooooo001_ooooo`03o`000?oo
oooooooo03gooooo00?oc03oooooooooool02?ooool00ol0003oooooooooo`0:ooooo`03ool0VOoo
003oo`0000_oo`001oooool00ooo003oooooooooo`0<oooooa7oo`005?ooool4o`0002_ooooo00?o
0000ooooooooool08?ooool00ol0003oooooooooo`03ooooo`00L?ooool00ol0003oooooooooo`18
ooooo`03o`000?oooooooooo00Sooooo00?oo`2Iooooooooool03?oooolFool002;ooooo0ol0000`
ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool00oooool0077ooooo00?o0000oooo
ooooool0B?ooool00ol0003oooooooooo`06ooooo`03ool0VOoooooooooo017ooooo0_oo000^oooo
o`Co0000=?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00?ooooo001booooo`03
o`000?oooooooooo04Sooooo00?o0000ooooooooool00oooool2ool0VA?ooooo00?oo`00oooooooo
ool0:oooool3o`0003Wooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`02ooooo`00
Loooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00;oo`2I5?ooool00ooo003ooooo
ooooo`0Yooooo`?o0000?Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00;ooooo
001dooooo`03o`000?oooooooooo04Sooooo0_oo09TEooooo`03ool00?oooooooooo02Kooooo1?l0
0011ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool00_ooool007Gooooo0_l00016
ooooo`;oo`2I00?oooooo`000?ooool04_ooool2ool002Kooooo0ol00015ooooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool00_ooool007Oooooo00?o0000ooooooooool0@_ooool00ooo
09Woooooooooo`02ooooo`03o`000?oooooooooo00oooooo00?oo`00ooooooooool08_ooool4o`00
04Wooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`02ooooo`00N?ooool00ol0003o
ooooooooo`0oooooo`;oo`2I1_ooool00ol0003oooooooooo`0=ooooo`03ool00?oooooooooo023o
oooo0ol0001>ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool00_ooool007Wooooo
00?o0000ooooooooool0??ooool2ool0V@Wooooo00?o0000ooooooooool02oooool00ooo003ooooo
ooooo`0Nooooo`?o0000D_ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00;ooooo
001jooooo`03o`000?oooooooooo03Wooooo0_oo09T<ooooo`03o`000?oooooooooo00Sooooo0_oo
000Mooooo`Co0000E_ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo00;ooooo001k
ooooo`03o`000?oooooooooo03Oooooo00?oo`2Iooooooooool03Oooool00ol0003oooooooooo`06
ooooo`03ool00?oooooooooo01[ooooo0ol0001Kooooo`03o`000?oooooooooo01Oooooo00?o0000
ooooooooool00_ooool007cooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`04oooo
o`03ool00?oooooooooo01Oooooo1?l0001Nooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool00_ooool007gooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`02ooooo`03
ool00?oooooooooo01Gooooo0ol0001Sooooo`03o`000?oooooooooo01Oooooo00?o0000oooooooo
ool00Oooool007kooooo00?o0000ooooooooool0Aoooool01?l0003oooooool00?oo000Eooooo`?o
0000Ioooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo007ooooo001oooooo`03o`00
0?oooooooooo04Kooooo0_oo000Cooooo`Co0000Joooool00ol0003oooooooooo`0Eooooo`03o`00
0?oooooooooo007ooooo0020ooooo`;o0000A?ooool2ool000;ooooo00?o0000ooooooooool03Ooo
ool3o`00073ooooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`01ooooo`00P_ooool0
0ol0003oooooooooo`0oooooo`;oo`001Oooool00ol0003oooooooooo`08ooooo`Co0000M?ooool0
0ol0003oooooooooo`0Cooooo`03o`000?oooooooooo007ooooo0023ooooo`03o`000?oooooooooo
03_ooooo0ooo0008ooooo`03o`000?oooooooooo00Cooooo0ol0001hooooo`03o`000?oooooooooo
01?ooooo00?o0000ooooooooool00Oooool008Cooooo00?o0000ooooooooool0>?ooool2ool000co
oooo00?o0000ooooooooool00ol0001looooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool00Oooool008Gooooo00?o0000ooooooooool0=Oooool2ool000oooooo0_l00020ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool00Oooool008Kooooo00?o0000ooooooooool0<_oo
ool2ool0017ooooo00?o0000ooooooooool0P?ooool00ol0003oooooooooo`0@ooooo`03o`000?oo
oooooooo007ooooo0027ooooo`03o`000?oooooooooo033ooooo00?oo`00ooooooooool04Oooool0
0ol0003oooooooooo`21ooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool00Oooool0
08Sooooo00?o0000ooooooooool0@oooool00ol0003oooooooooo`22ooooo`03o`000?oooooooooo
00oooooo0Ol00001ooooo`7ooooo0029ooooo`03o`000?oooooooooo04;ooooo00?o0000oooooooo
ool0P_ooool00ol0003oooooooooo`0?ooooo`7o00000Oooool1ooooo`00R_ooool00ol0003ooooo
ooooo`11ooooo`03o`000?oooooooooo08?ooooo00?o0000ooooooooool03_ooool1o`00007ooooo
0Oooool008_ooooo0_l00011ooooo`03o`000?oooooooooo08Cooooo00?o0000ooooooooool03Ooo
ool1o`00007ooooo0Oooool008gooooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`25
ooooo`03o`000?oooooooooo00cooooo0Ol00001ooooo`7ooooo002>ooooo`03o`000?oooooooooo
03gooooo00?o0000ooooooooool0Q_ooool00ol0003oooooooooo`0;ooooo`7o00000Oooool1oooo
o`00Soooool00ol0003oooooooooo`0looooo`03o`000?oooooooooo08Oooooo00?o0000oooooooo
ool02_ooool1o`00007ooooo0Oooool0093ooooo00?o0000ooooooooool0>oooool00ol0003ooooo
ooooo`27ooooo`03o`000?oooooooooo00[ooooo0Ol00001ooooo`7ooooo002Aooooo`03o`000?oo
oooooooo03[ooooo00?o0000ooooooooool0R?ooool00ol0003oooooooooo`09ooooo`7o00000Ooo
ool1ooooo`00T_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo08Wooooo00?o0000
ooooooooool02?ooool1o`00007ooooo0Oooool009?ooooo00?o0000ooooooooool0>?ooool00ol0
003oooooooooo`2:ooooo`03o`000?oooooooooo00Sooooo0Ol00001ooooo`00U?ooool00ol0003o
ooooooooo`0gooooo`03o`000?oooooooooo08_ooooo00?o0000ooooooooool01oooool1o`00007o
oooo002Eooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0S?ooool00ol0003ooooo
ooooo`06ooooo`7o00000Oooool009Kooooo00?o0000ooooooooool0=Oooool00ol0003ooooooooo
o`2<ooooo`03o`000?oooooooooo00Kooooo0Ol00001ooooo`00Uoooool2o`0003Gooooo00?o0000
ooooooooool0SOooool00ol0003oooooooooo`05ooooo`7o00000Oooool009Wooooo00?o0000oooo
ooooool0<_ooool00ol0003oooooooooo`2>ooooo`03o`000?oooooooooo00Cooooo0Ol00001oooo
o`00V_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo08oooooo00?o0000oooooooo
ool00oooool1o`00007ooooo002Kooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool0
T?ooool00ol0003oooooooooo`02ooooo`7o00000Oooool009cooooo00?o0000ooooooooool0;ooo
ool00ol0003oooooooooo`2Aooooo`05o`000?ooooooooooooooool000000Oooool009gooooo00?o
0000ooooooooool0;_ooool00ol0003oooooooooo`2Aooooo`05o`000?ooooooooooooooool00000
0Oooool009kooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`2Booooo`04o`000?oo
ooooooooooooo`7o0000002Oooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0Tooo
ool00ol0003oooooooooo`01o`000000X?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooo
oooo09Cooooo0Ol00001ooooo`7o0000002Qooooo`03o`000?oooooooooo02[ooooo00?o0000oooo
ooooool0UOooool2o`000000X_ooool2o`0002[ooooo00?o0000ooooooooool0U?ooool3o`000000
Y?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo093ooooo1?l00003ooooo`00YOoo
ool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo08gooooo0ol00007ooooo`00Y_ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo08Wooooo1?l0000:ooooo`00Yoooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo08Gooooo1?l0000>ooooo`00Z?ooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo08;ooooo0ol0000Booooo`00ZOooool00ol0003ooooo
ooooo`0Rooooo`03o`000?oooooooooo07kooooo1?l0000Eooooo`00Z_ooool00ol0003ooooooooo
o`0Qooooo`03o`000?oooooooooo07[ooooo1?l0000Iooooo`00Zoooool00ol0003oooooooooo`0Q
ooooo`03o`000?oooooooooo07Gooooo1?l0000Mooooo`00[?ooool00ol0003oooooooooo`0Poooo
o`03o`000?oooooooooo07;ooooo0ol0000Qooooo`00[Oooool2o`00023ooooo00?o0000oooooooo
ool0K_ooool4o`0002Cooooo002_ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
J_ooool4o`0002Sooooo002`ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0Iooo
ool3o`0002cooooo002aooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool0Hoooool4
o`0002oooooo002booooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool0Goooool4o`00
03?ooooo002cooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0G?ooool3o`0003Oo
oooo002dooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0F?ooool4o`0003[ooooo
002eooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0E?ooool4o`0003kooooo002f
ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0D?ooool4o`0004;ooooo002goooo
o`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0COooool3o`0004Kooooo002hooooo`;o
00005Oooool00ol0003oooooooooo`19ooooo`Co0000BOooool00;[ooooo00?o0000ooooooooool0
4_ooool00ol0003oooooooooo`15ooooo`Co0000COooool00;_ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`12ooooo`?o0000DOooool00;cooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`0nooooo`Co0000E?ooool00;gooooo00?o0000ooooooooool03oooool00ol0
003oooooooooo`0jooooo`Co0000F?ooool00;kooooo00?o0000ooooooooool03_ooool00ol0003o
ooooooooo`0fooooo`Co0000G?ooool00;oooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`0cooooo`?o0000H?ooool00<3ooooo00?o0000ooooooooool03?ooool00ol0003ooooooooo
o`0_ooooo`Co0000Hoooool00<7ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0[
ooooo`Co0000Ioooool00<;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Xoooo
o`?o0000Joooool00<?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Tooooo`Co
0000K_ooool00<Cooooo0_l00009ooooo`03o`000?oooooooooo023ooooo1?l0001booooo`00a_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01gooooo0ol0001fooooo`00aoooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Wooooo1?l0001iooooo`00b?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo01Gooooo1?l0001mooooo`00bOooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo017ooooo1?l00021ooooo`00b_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00kooooo0ol00025ooooo`00boooool01Ol0003ooooooooo
oooooooo000000cooooo1?l00028ooooo`00c?ooool01?l0003oooooooooool00008ooooo`Co0000
S?ooool00<gooooo00?o0000ooooool000001Oooool3o`00093ooooo003>ooooo`;o000000?ooooo
o`000?l000000_l0002Cooooo`00coooool2o`0009Oooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {330.375, 0}} -> {-0.0771432, -0.0315529, \
0.00350368, 0.00350368}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .92059 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-16 1.0763 -0.0263982 1.0763 [
[.01694 .18568 -11.9631 -9 ]
[.01694 .18568 .03693 0 ]
[.13793 .13897 -11.619 -9 ]
[.13793 .13897 .38095 0 ]
[.26292 .09073 -5.63752 -9 ]
[.26292 .09073 .36248 0 ]
[.39212 .04087 -5.46552 -9 ]
[.39212 .04087 .53448 0 ]
[.52574 -0.01069 -5.29351 -9 ]
[.52574 -0.01069 .70649 0 ]
[.58272 .04263 0 -6.19654 ]
[.58272 .04263 6 2.80346 ]
[.71715 .21863 0 -6.07114 ]
[.71715 .21863 6 2.92886 ]
[.83675 .37523 0 -5.963 ]
[.83675 .37523 6 3.037 ]
[.94385 .51546 0 -5.8688 ]
[.94385 .51546 6 3.1312 ]
[.01386 .20006 -12 -2.76892 ]
[.01386 .20006 0 6.23108 ]
[.00748 .25499 -24 -2.80073 ]
[.00748 .25499 0 6.19927 ]
[.00093 .31131 -6 -2.83339 ]
[.00093 .31131 0 6.16661 ]
[-0.00579 .36907 -18 -2.86695 ]
[-0.00579 .36907 0 6.13305 ]
[-0.01268 .42831 -6 -2.90143 ]
[-0.01268 .42831 0 6.09857 ]
[ 0 0 0 0 ]
[ 1 .92059 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02642 .19522 m
.53391 0 L
s
.02642 .19522 m
.03116 .2 L
s
[(-2)] .01694 .18568 .99384 1 Mshowa
.14712 .14879 m
.15172 .1537 L
s
[(-1)] .13793 .13897 .93651 1 Mshowa
.2718 .10083 m
.27624 .10588 L
s
[(0)] .26292 .09073 .87917 1 Mshowa
.40066 .05126 m
.40493 .05646 L
s
[(1)] .39212 .04087 .82184 1 Mshowa
.53391 0 m
.538 .00534 L
s
[(2)] .52574 -0.01069 .7645 1 Mshowa
.125 Mabswid
.05025 .18606 m
.05308 .18894 L
s
.07424 .17683 m
.07705 .17973 L
s
.09837 .16755 m
.10117 .17046 L
s
.12267 .1582 m
.12545 .16113 L
s
.17173 .13933 m
.17447 .14229 L
s
.19651 .1298 m
.19923 .13278 L
s
.22144 .1202 m
.22414 .1232 L
s
.24654 .11055 m
.24922 .11356 L
s
.29723 .09105 m
.29988 .0941 L
s
.32283 .0812 m
.32546 .08427 L
s
.3486 .07129 m
.35121 .07437 L
s
.37455 .06131 m
.37713 .06441 L
s
.42695 .04115 m
.4295 .04428 L
s
.45342 .03096 m
.45594 .03412 L
s
.48007 .02071 m
.48257 .02388 L
s
.5069 .01039 m
.50938 .01358 L
s
.25 Mabswid
.53391 0 m
.9804 .58403 L
s
.57014 .04738 m
.56384 .04975 L
s
[(0)] .58272 .04263 -1 .37701 Mshowa
.70445 .22307 m
.6981 .22529 L
s
[(2)] .71715 .21863 -1 .34914 Mshowa
.82396 .37939 m
.81756 .38147 L
s
[(4)] .83675 .37523 -1 .32511 Mshowa
.93098 .51938 m
.92454 .52134 L
s
[(6)] .94385 .51546 -1 .30418 Mshowa
.125 Mabswid
.60525 .09331 m
.60147 .09471 L
s
.63931 .13786 m
.63552 .13924 L
s
.67236 .1811 m
.66856 .18245 L
s
.73562 .26383 m
.7318 .26514 L
s
.7659 .30345 m
.76207 .30473 L
s
.79534 .34195 m
.7915 .34322 L
s
.85181 .41581 m
.84796 .41704 L
s
.87891 .45126 m
.87506 .45247 L
s
.90529 .48577 m
.90143 .48696 L
s
.95601 .55212 m
.95214 .55328 L
s
.25 Mabswid
.02642 .19522 m
0 .42381 L
s
.02642 .19522 m
.0327 .19281 L
s
[(-1)] .01386 .20006 1 -0.38468 Mshowa
.02006 .25024 m
.02635 .24786 L
s
[(-0.5)] .00748 .25499 1 -0.37762 Mshowa
.01354 .30664 m
.01985 .3043 L
s
[(0)] .00093 .31131 1 -0.37036 Mshowa
.00686 .36448 m
.01318 .36218 L
s
[(0.5)] -0.00579 .36907 1 -0.3629 Mshowa
0 .42381 m
.00634 .42156 L
s
[(1)] -0.01268 .42831 1 -0.35524 Mshowa
.125 Mabswid
.02516 .20612 m
.02893 .20468 L
s
.0239 .21707 m
.02767 .21563 L
s
.02262 .22807 m
.0264 .22664 L
s
.02135 .23913 m
.02512 .2377 L
s
.01877 .26141 m
.02255 .25999 L
s
.01747 .27263 m
.02125 .27122 L
s
.01617 .28391 m
.01995 .2825 L
s
.01486 .29525 m
.01864 .29384 L
s
.01222 .31809 m
.01601 .3167 L
s
.01089 .3296 m
.01468 .32821 L
s
.00955 .34117 m
.01334 .33978 L
s
.00821 .35279 m
.012 .35141 L
s
.0055 .37622 m
.0093 .37485 L
s
.00414 .38803 m
.00793 .38666 L
s
.00276 .39989 m
.00656 .39853 L
s
.00139 .41182 m
.00519 .41047 L
s
.25 Mabswid
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.54154 .92059 L
s
.54154 .92059 m
.5414 .7134 L
s
.5414 .7134 m
.02642 .19522 L
s
.53391 0 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.53391 0 m
.02642 .19522 L
s
.5414 .7134 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.54154 .92059 L
s
.54154 .92059 m
.5414 .7134 L
s
0 0 m
1 0 L
1 .92059 L
0 .92059 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.49791 .73327 m
.55083 .70579 L
s
1 0 .6 r
.48099 .69971 m
.53081 .67337 L
s
.8 0 1 r
.46405 .66614 m
.5108 .64098 L
s
.2 0 1 r
.44711 .63255 m
.49081 .60862 L
s
0 .4 1 r
.43015 .59894 m
.47083 .57629 L
s
0 1 1 r
.41319 .56532 m
.45086 .54398 L
s
0 1 .4 r
.39622 .53168 m
.43092 .51169 L
s
.2 1 0 r
.37925 .49802 m
.41099 .47944 L
s
.8 1 0 r
.36227 .46435 m
.39112 .44721 L
s
1 .6 0 r
.34533 .43068 m
.3715 .41503 L
s
.3715 .41503 m
.39246 .39783 L
s
.8 1 0 r
.39112 .44721 m
.41418 .42778 L
s
.2 1 0 r
.41099 .47944 m
.43691 .45771 L
s
0 1 .4 r
.43092 .51169 m
.46001 .48769 L
s
0 1 1 r
.45086 .54398 m
.48323 .51775 L
s
0 .4 1 r
.47083 .57629 m
.50652 .54789 L
s
.2 0 1 r
.49081 .60862 m
.52989 .57812 L
s
.8 0 1 r
.5108 .64098 m
.55331 .60844 L
s
1 0 .6 r
.53081 .67337 m
.57681 .63884 L
s
1 0 0 r
.55083 .70579 m
.60035 .66933 L
s
1 .6 0 r
.39246 .39783 m
.407 .38233 L
s
.8 1 0 r
.41418 .42778 m
.42826 .41062 L
s
.2 1 0 r
.43691 .45771 m
.45189 .43846 L
s
0 1 .4 r
.46001 .48769 m
.47678 .46611 L
s
0 1 1 r
.48323 .51775 m
.50219 .49379 L
s
1 .6 0 r
.407 .38233 m
.41881 .36965 L
s
0 .4 1 r
.50652 .54789 m
.52783 .52158 L
s
.8 1 0 r
.42826 .41062 m
.43748 .39789 L
s
.2 0 1 r
.52989 .57812 m
.5536 .5495 L
s
.8 0 1 r
.55331 .60844 m
.57951 .57756 L
s
.2 1 0 r
.45189 .43846 m
.45957 .4256 L
s
1 .6 0 r
.41881 .36965 m
.43125 .35892 L
s
1 0 0 r
.58676 .67338 m
.66965 .67071 L
s
.51801 .66835 m
.58676 .67338 L
s
1 0 .6 r
.57681 .63884 m
.60555 .60575 L
s
1 0 0 r
.66965 .67071 m
.74335 .66116 L
s
0 1 .4 r
.47678 .46611 m
.48408 .45284 L
s
1 0 .6 r
.58797 .63546 m
.66565 .63291 L
s
.52397 .6307 m
.58797 .63546 L
s
1 0 0 r
.60035 .66933 m
.6317 .6341 L
s
.8 1 0 r
.43748 .39789 m
.44661 .38793 L
s
1 0 0 r
.48731 .6639 m
.51801 .66835 L
s
1 0 .6 r
.66565 .63291 m
.73541 .62372 L
s
.8 0 1 r
.5892 .5974 m
.66166 .59498 L
s
.52997 .59293 m
.5892 .5974 L
s
1 0 0 r
.52379 .6653 m
.49456 .66466 L
s
.56081 .66088 m
.52379 .6653 L
s
.49456 .66466 m
.48731 .6639 L
s
1 0 .6 r
.49466 .62637 m
.52397 .6307 L
s
1 .6 0 r
.43125 .35892 m
.44566 .34964 L
s
0 1 1 r
.50219 .49379 m
.50978 .4799 L
s
.2 1 0 r
.45957 .4256 m
.46579 .41705 L
s
.8 0 1 r
.66166 .59498 m
.72746 .58617 L
s
1 0 .6 r
.52179 .62726 m
.49877 .62675 L
s
.5514 .62366 m
.52179 .62726 L
s
.2 0 1 r
.59043 .55922 m
.65765 .55693 L
s
.53599 .55505 m
.59043 .55922 L
s
.8 0 1 r
.50205 .58873 m
.52997 .59293 L
s
1 0 0 r
.59622 .65023 m
.56081 .66088 L
s
1 0 .6 r
.49877 .62675 m
.49466 .62637 L
s
.8 1 0 r
.44661 .38793 m
.45783 .37948 L
s
.2 0 1 r
.65765 .55693 m
.71948 .54852 L
s
0 .4 1 r
.52783 .52158 m
.53598 .50701 L
s
1 0 .6 r
.57973 .615 m
.5514 .62366 L
s
.2 0 1 r
.50946 .55099 m
.53599 .55505 L
s
0 1 .4 r
.48408 .45284 m
.48833 .44604 L
s
.8 0 1 r
.51977 .58909 m
.503 .58873 L
s
.54197 .58635 m
.51977 .58909 L
s
0 .4 1 r
.59167 .52091 m
.65364 .51876 L
s
.54202 .51705 m
.59167 .52091 L
s
.8 0 1 r
.503 .58873 m
.50205 .58873 L
s
1 .6 0 r
.44566 .34964 m
.46217 .34178 L
s
.2 1 0 r
.46579 .41705 m
.47338 .4103 L
s
0 .4 1 r
.65364 .51876 m
.71148 .51076 L
s
.8 0 1 r
.56323 .57974 m
.54197 .58635 L
s
0 .4 1 r
.51687 .51314 m
.54202 .51705 L
s
.2 0 1 r
.50724 .55058 m
.50946 .55099 L
s
.51776 .55079 m
.50724 .55058 L
s
.53251 .54894 m
.51776 .55079 L
s
0 1 1 r
.59292 .48247 m
.64961 .48046 L
s
.54807 .47893 m
.59292 .48247 L
s
.8 1 0 r
.45783 .37948 m
.47158 .37242 L
s
.2 0 1 r
.5536 .5495 m
.5624 .53424 L
s
.54671 .54445 m
.53251 .54894 L
s
0 1 1 r
.64961 .48046 m
.70345 .47289 L
s
0 1 .4 r
.48833 .44604 m
.49247 .44189 L
s
0 1 1 r
.50978 .4799 m
.51271 .47494 L
s
1 0 0 r
.62378 .63516 m
.59622 .65023 L
s
0 .4 1 r
.51148 .51231 m
.51687 .51314 L
s
0 1 1 r
.52424 .4752 m
.54807 .47893 L
s
.2 1 0 r
.47338 .4103 m
.48332 .40474 L
s
1 .6 0 r
.46217 .34178 m
.48046 .33547 L
s
1 0 .6 r
.60166 .6028 m
.57973 .615 L
s
0 .4 1 r
.51573 .51237 m
.51148 .51231 L
s
.52303 .51143 m
.51573 .51237 L
s
0 1 .4 r
.59416 .4439 m
.64556 .44203 L
s
.55404 .44074 m
.59416 .4439 L
s
0 .4 1 r
.53018 .50914 m
.52303 .51143 L
s
.8 0 1 r
.57957 .57048 m
.56323 .57974 L
s
0 1 .4 r
.64556 .44203 m
.69541 .43491 L
s
.49247 .44189 m
.49771 .43879 L
s
.2 0 1 r
.55752 .53822 m
.54671 .54445 L
s
0 1 1 r
.51565 .47398 m
.52424 .4752 L
s
.8 1 0 r
.47158 .37242 m
.48741 .36703 L
s
0 1 .4 r
.53129 .43727 m
.55404 .44074 L
s
0 1 1 r
.51271 .47494 m
.51366 .47388 L
s
0 .4 1 r
.53551 .50602 m
.53018 .50914 L
s
.8 0 1 r
.57951 .57756 m
.58898 .56162 L
s
0 1 1 r
.51365 .47389 m
.51565 .47398 L
s
.51355 .47389 m
.51365 .47389 L
s
.51372 .47384 m
.51355 .47389 L
s
.51366 .47388 m
.51372 .47384 L
s
.2 1 0 r
.59537 .40523 m
.6415 .40349 L
s
.55964 .40258 m
.59537 .40523 L
s
.48332 .40474 m
.49533 .4007 L
s
0 1 .4 r
.49771 .43879 m
.50419 .43665 L
s
0 .4 1 r
.53598 .50701 m
.53776 .50387 L
s
1 .6 0 r
.48046 .33547 m
.50009 .33089 L
s
.2 1 0 r
.6415 .40349 m
.68734 .39683 L
s
0 .4 1 r
.53776 .50387 m
.53551 .50602 L
s
0 1 .4 r
.51941 .43577 m
.53129 .43727 L
s
.2 1 0 r
.53731 .39962 m
.55964 .40258 L
s
0 1 .4 r
.50419 .43665 m
.51136 .43565 L
s
.51136 .43565 m
.51941 .43577 L
s
.8 1 0 r
.48741 .36703 m
.50454 .36359 L
s
.2 0 1 r
.56304 .53292 m
.55752 .53822 L
s
.8 1 0 r
.59637 .36658 m
.63741 .36484 L
s
.56417 .36474 m
.59637 .36658 L
s
.2 1 0 r
.49533 .4007 m
.5084 .39854 L
s
1 0 .6 r
.60555 .60575 m
.61571 .58915 L
s
.2 1 0 r
.52193 .39823 m
.53731 .39962 L
s
1 .6 0 r
.50009 .33089 m
.52069 .32816 L
s
.8 1 0 r
.63741 .36484 m
.67925 .35864 L
s
.54122 .36274 m
.56417 .36474 L
s
.8 0 1 r
.58844 .56208 m
.57957 .57048 L
s
.2 1 0 r
.5084 .39854 m
.52193 .39823 L
s
.8 1 0 r
.50454 .36359 m
.52234 .36221 L
s
.52234 .36221 m
.54122 .36274 L
s
1 .6 0 r
.59668 .32825 m
.6332 .32621 L
s
.56666 .32772 m
.59668 .32825 L
s
.52069 .32816 m
.54239 .32724 L
s
.2 0 1 r
.5624 .53424 m
.56304 .53292 L
s
1 0 .6 r
.61395 .59137 m
.60166 .6028 L
s
1 .6 0 r
.54239 .32724 m
.56666 .32772 L
s
.6332 .32621 m
.67112 .32038 L
s
1 0 0 r
.63957 .62078 m
.62378 .63516 L
s
.6317 .6341 m
.64259 .61685 L
s
.8 0 1 r
.58898 .56162 m
.58844 .56208 L
s
1 0 .6 r
.61571 .58915 m
.61395 .59137 L
s
1 0 0 r
.64259 .61685 m
.63957 .62078 L
s
0 g
.25 Mabswid
.53391 0 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.53391 0 m
.02642 .19522 L
s
.02642 .19522 m
.53391 0 L
s
.02642 .19522 m
.03116 .2 L
s
[(-2)] .01694 .18568 .99384 1 Mshowa
.14712 .14879 m
.15172 .1537 L
s
[(-1)] .13793 .13897 .93651 1 Mshowa
.2718 .10083 m
.27624 .10588 L
s
[(0)] .26292 .09073 .87917 1 Mshowa
.40066 .05126 m
.40493 .05646 L
s
[(1)] .39212 .04087 .82184 1 Mshowa
.53391 0 m
.538 .00534 L
s
[(2)] .52574 -0.01069 .7645 1 Mshowa
.125 Mabswid
.05025 .18606 m
.05308 .18894 L
s
.07424 .17683 m
.07705 .17973 L
s
.09837 .16755 m
.10117 .17046 L
s
.12267 .1582 m
.12545 .16113 L
s
.17173 .13933 m
.17447 .14229 L
s
.19651 .1298 m
.19923 .13278 L
s
.22144 .1202 m
.22414 .1232 L
s
.24654 .11055 m
.24922 .11356 L
s
.29723 .09105 m
.29988 .0941 L
s
.32283 .0812 m
.32546 .08427 L
s
.3486 .07129 m
.35121 .07437 L
s
.37455 .06131 m
.37713 .06441 L
s
.42695 .04115 m
.4295 .04428 L
s
.45342 .03096 m
.45594 .03412 L
s
.48007 .02071 m
.48257 .02388 L
s
.5069 .01039 m
.50938 .01358 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 265.125},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001Bb000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00`oooool5o`000:3ooooo0033ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@0X?ooool00<Cooooo00?oV9RHob4Q8Oo^k^h0XOooool00<Gooooo00?oV9RH
ob4Q8Oo^k^h0X?ooool00<Kooooo00?oMgMgofIVI_ooool0Woooool00<Oooooo00?o0000oooooooo
ool0W_ooool00<?ooooo00Go0000okZj^_ooooooV9RHoa0@402Pooooo`00`oooool01OnHV9So410@
o`000?lQ8B7oc<c<0:3ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003;ooooo`;o0000Voooool00<Sooooo0ol000000ooooooo0000ooooo`2Jooooo`00a_oo
ool2o`0000Cooooo0_l0002Jooooo`00`oooool3o`0000Kooooo00?o0000ooooool00000VOooool0
0<3ooooo1?l00008ooooo`04o`000?ooooooooooo`0009Sooooo002Hooooo`Co000000?o410@oooo
ooooool07oooool2o`0000Cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0002H
ooooo`00V_ooool00ol0003oooooooooo`0Nooooo`?o00003_ooool01Ol0003ooooooooooooooooo
000009Oooooo002Jooooo`03o`000?oooooooooo01cooooo0_l0000Aooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0U?ooool009[ooooo00?o0000ooooooooool06Oooool3o`0000;o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo09?o
oooo002Jooooo`03o`000?oooooooooo01Kooooo0ol0000Fooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^08Kooooo002Jooooo`03o`00
0?oooooooooo01Cooooo0_l0000Iooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1oooool01OmgMgOoV9RHoooooonHV9SoMgMg08Kooooo002Jooooo`03o`000?oooooooooo017ooooo
0ol000000ooooooo0000ooooo`0Hooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1_ooool01Ol@413ooooooooooooooooo410@08Kooooo002Hooooo`03oeEEEOmVIVKo0000017ooooo
0_l0000Nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool01Ol0003ooooo
oooooooooooo000008Kooooo002Yooooo`?o00008?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000026ooooo`00Yoooool3o`0002;ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@
4100Q_ooool00:Cooooo0ol00002ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Q_ooool00:7ooooo
0ol0000Xooooo`03o`000?oooooooooo00Sooooo0_l00004ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h0Q_ooool009oooooo0_l0000[ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo
0000S_ooool009cooooo0ol000000ooooooo0000ooooo`0Zooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0S?ooool009[ooooo0_l00005ooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`2;ooooo`00Uoooool3o`0003;ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`2:ooooo`00K?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^02?ooooo0ol000000ooooooo0000ooooo`0booooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0ROooool006cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Qooooo`;o0000>?ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo08Wooooo001/ooooo`05oa0@4?oooooooooo
ooooool@41007_ooool3o`0003[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`28
ooooo`00K?ooool01Ol0003ooooooooooooooooo000001cooooo0ol0000looooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0Qoooool006cooooo00Go0000ooooooooooooooooo`00000I
ooooo`?o00000_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool0Q_ooool006cooooo00Go410@oooooooooooooooooa0@400Gooooo`;o0000@_ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo08Kooooo001/ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL05?ooool3o`0004Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`25
ooooo`00K?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^017ooooo0ol00002ooooo`03o`000?oooooo
oooo04;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`24ooooo`00P?ooool2o`00
04[ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`23ooooo`00OOooool3o`0004co
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`22ooooo`00Noooool2o`000003oooo
ool0003ooooo04cooooo00?o0000ooooooooool05?ooool2o`0008?ooooo001hooooo`?o0000DOoo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooo000008?ooooo001eooooo`?o0000E?ooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo083ooooo001cooooo`Co0000EOooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo07oooooo001`ooooo`?o00001?ooool00ol0003o
ooooooooo`1Booooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0Ooooool006kooooo
0_l0001Looooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0O_ooool004?ooooo1?l0
00000ol@413oooooooooo`0Qooooo`?o0000G_ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo07gooooo0015ooooo`03o`000?oooooooooo023ooooo0ol00003ooooo`03o`000?oooooo
oooo05_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1looooo`00>_ooool6o`00
00Gooooo00?o0000ooooooooool07_ooool2o`0006Cooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`1looooo`00AOooool00ol0003oooooooooo`0Kooooo`?o0000I_ooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo07_ooooo0015ooooo`03o`000?oooooooooo01Wooooo
0_l00002ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`1jooooo`00AOooool00ol0003oooooooooo`0Fooooo`?o0000Joooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo07Wooooo0015ooooo`03o`000?oooooooooo01Cooooo0_l0001^
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0NOooool004?ooooo00?oEEEEofIV
I_l000004oooool3o`000003ooooool0003ooooo06gooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`1hooooo`00E_ooool3o`0007?ooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`1gooooo`00E?ooool2o`0007Kooooo00?o0000ooooooooool07oooool2o`0007Sooooo
001Aooooo`?o000000?oooooo`000?ooool0MOooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo07Kooooo001?ooooo`;o0000Noooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo07Gooooo001<ooooo`?o0000OOooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
07Cooooo0019ooooo`Co0000Ooooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo07?o
oooo0017ooooo`;o00001?ooool00ol0003oooooooooo`1looooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool0L_ooool004Cooooo0ol00025ooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool0L_ooool001[ooooo1Ol0000Sooooo`?o0000Qoooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo077ooooo000Jooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@08?ooool3
o`0000?ooooo00?o0000ooooooooool0Q?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo073ooooo000Booooo`Ko00000oooool00onHV9So8B4Qonk^kP0Oooooo`;o0000SOooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo06oooooo000Looooo`03oiRHV?lQ8B7ok^k^01_o
oooo0ol0002?ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0Koooool001gooooo
00?oMgMgofIVI_ooool05oooool3o`0000?ooooo00?o0000ooooooooool0S?ooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooooooo06kooooo000Nooooo`03o`000?oooooooooo01Cooooo0_l0
002Eooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0KOooool001[ooooo00Go0000
okZj^_ooooooV9RHoa0@400Cooooo`?o0000Uoooool00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo06cooooo000Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`04Oooool2o`0000?ooooo00?o
0000ooooooooool0U?ooool00ol0003oooooooooo`0Zooooo`;o0000KOooool002gooooo0ol0002L
ooooo`03o`000?oooooooooo02[ooooo0_l0001]ooooo`00:_ooool3o`0009oooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`1Zooooo`00:?ooool2o`0000?ooooo00?o0000oooooooo
ool0W?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo06Wooooo000Uooooo`?o0000
Y?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo06Wooooo000Tooooo`03o`000?oo
oooooooo0:Gooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1Xooooo`006_ooool4
o`000003oa0@4?oooooooooo00?ooooo0_l0002Vooooo`03o`000?oooooooooo02oooooo00?o0000
ooooooooool0Ioooool001cooooo00?o0000ooooooooool01Oooool2o`000:Kooooo00?o0000oooo
ooooool0<?ooool00ol0003oooooooooo`1Vooooo`004Oooool6o`0000Gooooo00?o0000oooooooo
ool01?ooool4o`000:Gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`08ooooo`Go
0000FOooool001cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0002Tooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool01OnHV9So8B4Qonk^k_ooooooA4A4
05Wooooo000Looooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`2Qooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool01oooool00onHV9So
8B4Qonk^kP1Jooooo`007?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0X?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Oooooo
00?oV9RHob4Q8Oo^k^h0FOooool001cooooo00?o0000ooooooooool01?ooool2o`0000Gooooo00?o
0000ooooooooool0Woooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Oooooo00?o
MgMgofIVI_ooool0F?ooool001[ooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo09kooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo05Oooooo000Sooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0WOooool00ol0003oooooooooo`0eooooo`;o00001?ooool01Ol0003o^[ZjoooooonHV9So
410@05Wooooo000Sooooo`;o00002?ooool00ol0003oooooooooo`2Looooo`03o`000?oooooooooo
03?ooooo0_l000000ooooooo0000ooooo`03ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0FOooool0
02?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2Kooooo`03o`000?oooooooooo
03Oooooo00?o0000ooooooooool0Goooool002?ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`2Jooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0Goooool002?ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`2Hooooo`;o0000>_ooool00ol0003ooooo
ooooo`1Nooooo`008_ooool2o`0000gooooo00?o0000ooooooooool0U?ooool3o`000003ooooool0
003ooooo03[ooooo00?o0000ooooooooool0GOooool002;ooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`2@ooooo`?o00001Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooo
oooo05cooooo000Rooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0S?ooool3o`00
00Wooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1Looooo`008_ooool3o`0000oo
oooo00?o0000ooooooooool0R?ooool3o`0000gooooo00?o0000ooooooooool0>?ooool00ol0003o
ooooooooo`1Kooooo`008_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo08Gooooo
0_l0000Aooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0F_ooool002;ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`21ooooo`?o00005?ooool00ol0003ooooooooo
o`0hooooo`03o`000?oooooooooo05Wooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool0OOooool3o`0001Oooooo00?o0000ooooooooool0>?ooool00ol0003ooooo
ooooo`1Iooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1iooooo`?o0000
6oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo05Sooooo0005o`0000;ooooo00Go
410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`1eooooo`?o00007oooool00ol0003oooooooooo`0hooooo`03o`00
0?oooooooooo05Oooooo0007ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8b
ooooo`03ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0LOooool3o`0002?ooooo
00?o0000ooooooooool0=oooool2o`0005Sooooo0007ooooo`05o`000?ooooooooooooooool00000
3?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`1^ooooo`;o00009oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo05Go
oooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`;o
00006Oooool00ol0003oooooooooo`1Zooooo`?o0000:_ooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo05Gooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0I_ooool3o`0002go
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1Dooooo`001oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool0H_ooool3o`00037ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1Cooooo`00
8Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo05kooooo0ol0000eooooo`03o`00
0?oooooooooo03Sooooo00?o0000ooooooooool0D_ooool0023ooooo0ol0000Mooooo`03o`000?oo
oooooooo05_ooooo0_l0000iooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0D_oo
ool0027ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1Gooooo`?o0000??ooool0
0ol0003oooooooooo`0gooooo`03o`000?oooooooooo057ooooo000Pooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool0Doooool3o`00043ooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`1@ooooo`008?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo04oo
oooo0ol00013ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0Coooool0023ooooo
0_l0000Rooooo`03o`000?oooooooooo04_ooooo0ol00017ooooo`03o`000?oooooooooo03Oooooo
00?o0000ooooooooool0Coooool0023ooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`18ooooo`;o0000Boooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo04kooooo000P
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0A?ooool3o`0004kooooo00?o0000
ooooooooool0=oooool00ol0003oooooooooo`1=ooooo`008?ooool3o`0002Cooooo00?o0000oooo
ooooool0@?ooool3o`0005;ooooo00?o0000ooooooooool0=_ooool2o`0004kooooo000Pooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0??ooool3o`0005Kooooo00?o0000oooooooo
ool0=_ooool00ol0003oooooooooo`1<ooooo`005?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oo
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0hooooo`?o0000FOooool00ol0003o
ooooooooo`0gooooo`03o`000?oooooooooo04_ooooo000Dooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo03Gooooo0_l0001Mooooo`03
o`000?oooooooooo03Oooooo00?o0000ooooooooool0B_ooool001Cooooo00Go410@oooooooooooo
oooooa0@4006ooooo`;o0000:_ooool00ol0003oooooooooo`0aooooo`?o0000H?ooool00ol0003o
ooooooooo`0gooooo`03o`000?oooooooooo04Wooooo000Dooooo`05o`000?ooooooooooooooool0
00001_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo02gooooo0ol0001Tooooo`03
o`000?oooooooooo013ooooo1?ooV@0Rooooo`03o`000?oooooooooo04Wooooo000Dooooo`05o`00
0?ooooooooooooooool000001_ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo02Wo
oooo0ol0001Xooooo`03o`000?oooooooooo00Wooooo1_ooV@0Wooooo`03o`000?oooooooooo04So
oooo000Dooooo`05oa0@4?ooooooooooooooool@41001_ooool00ol0003oooooooooo`0/ooooo`03
o`000?oooooooooo02Gooooo0ol0001/ooooo`03o`000?oooooooiT000SooiT0;_ooool00ol0003o
ooooooooo`17ooooo`005?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Kooooo0_l0000^ooooo`03
o`000?oooooooooo027ooooo0ol0001?ooooob3ooiT000?o0000oonI0?ooool0=oooool00ol0003o
ooooooooo`16ooooo`005?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Kooooo00?o0000oooooooo
ool0;_ooool00ol0003oooooooooo`0Nooooo`;o0000Boooool7oonI027ooooo00?o0000oooooooo
ool0=oooool00ol0003oooooooooo`15ooooo`007oooool00ol0003oooooooooo`0_ooooo`03o`00
0?oooooooooo01[ooooo0ol00018ooooo`GooiT0:Oooool00ol0003oooooooooo`0fooooo`03o`00
0?oooooooooo04Gooooo000Nooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool05_oo
ool3o`0004Sooooo0oooV@0_ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0A?oo
ool001kooooo0_l0000cooooo`03o`000?oooooooooo01;ooooo0ol00018ooooo`?ooiT0<oooool0
0ol0003oooooooooo`0fooooo`;o0000A?ooool001kooooo00?o0000ooooooooool0<oooool00ol0
003oooooooooo`0>ooooo`?o0000BOooool2oonI03Oooooo00?o0000ooooooooool0=?ooool00ol0
003oooooo`000014ooooo`007_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00_o
oooo0_l0001;ooooo`03oonI0?oooooooooo03Oooooo00?o0000ooooooooool0=_ooool00ol0003o
ooooooooo`12ooooo`007_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00Oooooo
0ol0001;ooooo`;ooiT0>oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo047ooooo
000Nooooo`;o0000=oooool00ol0003oooooooooo`03ooooo`?o0000C?ooool2oonI03kooooo00?o
0000ooooooooool0=_ooool00ol0003oooooooooo`10ooooo`007_ooool00ol0003oooooooooo`0g
ooooo`03o`000?oooooo000000;o0000C_ooool00oooV@3oooooooooo`0oooooo`03o`000?oooooo
oooo03Kooooo00?o0000ooooooooool0?oooool001kooooo00?o0000ooooooooool0=_ooool3o`00
053ooooo00?ooiT0ooooooooool0@Oooool00ol0003oooooooooo`08ooooo`Coc?l0:Oooool00ol0
003oooooooooo`0oooooo`007_ooool2o`0003Gooooo0_l00003ooooo`03o`000?oooooooooo04co
oooo00?ooiT0ooooooooool06Oooool>olco01cooooo00?o0000ooooooooool01oo<o`0^ooooo`03
o`000?oooooooooo00Wooooo0_l000000ol@413oooooooooo`0`ooooo`007Oooool00ol0003ooooo
ooooo`0booooo`?o00001_ooool00ol0003oooooooooo`1:ooooo`03oonI0?oooooooooo01Gooooo
1Oo<o`0>ooooo`[oc?l02oooool7olco0003o`000?o<o`3oc?l003Kooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`0aooooo`000_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo
0_lQ8B45ooooo`05odA4A?l0003o0000oc8b<_oMgMd01Oooool00ol0003oooooooooo`0_ooooo`?o
00002_ooool00ol0003oooooooooo`18ooooo`03oonI0?oooooooooo01;ooooo1?o<o`0Mooooo`_o
c?l02?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Gooooo1Ol0000booooo`00
0_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Co
oooo00?o0000ooooooooool0;?ooool3o`0000kooooo00?o0000ooooooooool0A_ooool00oooV@3o
ooooooooo`0@ooooo`?oc?l0=Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00Go
oooo00CoA4A4omgMgOoooooo0000<oooool000;ooooo00Go410@oooooooooooooooooa0@400@oooo
o`03o`000?oooooooooo00?ooooo0_l0000Zooooo`?o00004_ooool00ol0003oooooooooo`14oooo
o`03oonI0?oooooooooo00kooooo0oo<o`0iooooo`03o`000?oooooooooo03Gooooo00?o0000oooo
ooooool01?ooool01?oMgMgoEEEEooooool0000cooooo`000_ooool01Ol0003ooooooooooooooooo
000000oooooo00?oMgMgoc8b<_ooool01?ooool00ol0003oooooooooo`0Wooooo`;o00005_ooool0
0ol0003oooooooooo`12ooooo`03oonI0?oooooooooo00gooooo0_o<o`0mooooo`03o`000?oooooo
oooo03Gooooo00?o0000ooooooooool01?ooool00omgMgOoc<c<o`00000cooooo`000_ooool01Ol0
003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oo
oooooooo02Cooooo0ol0000Iooooo`03o`000?oooooooooo043ooooo00?ooiT0ooooooooool03?oo
ool2olco043ooooo00?o0000ooooooooool0=?ooool2o`0000Gooooo00?ok^k^odA4A?l00000<ooo
ool000;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool08Oooool3o`0001gooooo00?o0000ooooooooool0?_ooool00oooV@3ooooooooo
o`0<ooooo`03olco0?oooooooooo043ooooo00?o0000ooooooooool0<oooool01?l0003ooooooooo
ool00005ooooo`03ogMgMol0003ooooo03;ooooo0002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0
3?ooool00ol0003oooooooooo`07ooooo`;o00007oooool3o`00027ooooo00?o0000ooooooooool0
??ooool00oooV@3oooooooooo`0<ooooo`03olco0?oooooooooo04;ooooo00?o0000ooooooooool0
=Oooool00ol0003oooooooooo`0hooooo`000_ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo
1?l00005ooooo`03o`000?oooooooooo01cooooo0ol0000Uooooo`03o`000?oooooooooo03[ooooo
00?ooiT0ooooooooool03?ooool00oo<o`3oooooooooo`14ooooo`03o`000?oooooooooo03Gooooo
00?o0000ooooooooool0=oooool001cooooo00?o0000ooooooooool06Oooool3o`0002Wooooo00?o
0000ooooooooool0>?ooool00oooV@3oooooooooo`0<ooooo`03olco0?oooooooooo04Kooooo00?o
0000ooooooooool0=Oooool00ol0003oooooooooo`0fooooo`007?ooool00ol0003oooooooooo`0G
ooooo`;o0000;Oooool00ol0003oooooooooo`0fooooo`03oonI0?oooooooooo00cooooo00?oc?l0
ooooooooool0B?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo03Gooooo000Loooo
o`;o00005Oooool3o`00033ooooo00?o0000ooooooooool0<oooool2oonI00kooooo00?oc?l0oooo
ooooool04oooool:oc?o02gooooo00?o0000oooooolco`001?lco`0`ooooo`03o`000?oooooooooo
03Gooooo000Looooo`03o`000?oooooooooo017ooooo0ol0000dooooo`03o`000?oooooooooo037o
oooo00?ooiT0ooooooooool03_ooool00oo<o`3oooooooooo`0>ooooo`Go<ol02_ooool6oc?o02;o
oooo1Olco`000ol0003o<ol0ooooo`0eooooo`03o`000?oooooooooo03Cooooo000Looooo`03o`00
0?oooooooooo00kooooo0ol0000hooooo`03o`000?oooooooooo02oooooo00?ooiT0ooooooooool0
3_ooool00oo<o`3oooooooooo`0<ooooo`?o<ol05OoooolRoc?o00Kooooo00?o0000ooooooooool0
=Oooool00ol0003oooooooooo`0cooooo`007?ooool00ol0003oooooooooo`0;ooooo`?o0000??oo
ool00ol0003oooooooooo`0]ooooo`03oonI0?oooooooooo00kooooo00?oc?l0ooooooooool03?oo
ool00olco`3oooooooooo`0oooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0<_oo
ool001cooooo0_l0000:ooooo`;o0000@?ooool00ol0003oooooooooo`0[ooooo`03oonI0?oooooo
oooo00kooooo00?oc?l0ooooooooool02oooool2oc?o04?ooooo00?o0000ooooooooool0=?ooool0
0ol0003oooooooooo`0booooo`006oooool2o`0000Sooooo0ol00013ooooo`03o`000?oooooooooo
02Wooooo00?ooiT0ooooooooool03oooool00oo<o`3oooooooooo`0:ooooo`03oc?o0?oooooooooo
04Cooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0aooooo`006oooool00ol0003o
ooooooooo`04ooooo`?o0000Aoooool00ol0003oooooooooo`0Vooooo`;ooiT04Oooool00oo<o`3o
ooooooooo`0:ooooo`03oc?o0?oooooooooo04Kooooo00?o0000ooooooooool0<oooool2o`0003;o
oooo000Kooooo`04o`000?ooooooooooooooo`?o0000Boooool00ol0003oooooooooo`0Sooooo`;o
oiT04_ooool00oo<o`3oooooooooo`0;ooooo`03oc?o0?oooooooooo04Kooooo00?o0000oooooooo
ool0=Oooool00ol0003oooooooooo`0_ooooo`006oooool4o`0004oooooo00?o0000ooooooooool0
8?ooool2oonI01?ooooo00?oc?l0ooooooooool02oooool00olco`3oooooooooo`18ooooo`03o`00
0?oooooooooo03Cooooo00?o0000ooooooooool0;oooool001_ooooo0_l0001Booooo`03o`000?oo
oooooooo01kooooo00?ooiT0ooooooooool04_ooool00oo<o`3oooooooooo`0;ooooo`03oc?o0?oo
oooooooo04[ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0^ooooo`004Oooool4
o`000003oa0@4?oooooooooo00Gooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0K
ooooo`;ooiT04oooool2olco00kooooo00?o<ol0ooooooooool0Boooool00ol0003oooooooooo`0d
ooooo`03o`000?oooooooooo02gooooo000Cooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool0D?ooool00ol0003oooooooooo`0Iooooo`03oonI0?oooooooooo01;ooooo00?oc?l0oooo
ooooool03Oooool00olco`3oooooooooo`1=ooooo`03o`000?oooooooooo03Cooooo00?o0000oooo
ooooool0;?ooool001?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1@ooooo`03
o`000?oooooooooo02cooooo00?oc?l0ooooooooool03_ooool00olco`3oooooooooo`1:ooooo`Co
0?mV00?o0000ooooooooool0<oooool00ol0003oooooooooo`0/ooooo`004oooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0:_ooool00oo<o`3ooooo
ooooo`0>ooooo`03oc?o0?oooooooooo00gooooo3ol0ofHYooooo`Ko0?mV1?ooool00ol0003ooooo
ooooo`0dooooo`03o`000?oooooooooo02_ooooo000Cooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool0D?ooool00ol0003oooooooooo`0Xooooo`03olco0?oooooooooo00oooooo00?o
<ol0ooooooooool02oooool2o`3oIPoooooo2ol0ofHIooooo`Go0?mV2oooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo02[ooooo000Cooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool0D?ooool00ol0003oooooooooo`0Vooooo`03olco0?oooooooooo00oooooo00?o<ol0
ooooooooool02oooool00ol0ofKoooooooooo`0JoooooaWo0?mV4Oooool00ol0003oooooooooo`0d
ooooo`03o`000?oooooooooo02Wooooo000Cooooo`03o`000?oooooooooo00gooooo00?o0000oooo
ooooool0D?ooool00ol0003oooooooooo`0Sooooo`;oc?l04Oooool00olco`3oooooooooo`0;oooo
o`03o`3oI_oooooooooo04Kooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Xoooo
o`004Oooool00omEEEGoIVIVo`00000@ooooo`03o`000?oooooooooo053ooooo00?o0000oooooooo
ool08?ooool2olco01;ooooo00?o<ol0ooooooooool02oooool00ol0ofKoooooooooo`18ooooo`03
o`000?oooooooooo03?ooooo00?o0000ooooooooool0:?ooool002Gooooo00?o0000ooooooooool0
D?ooool00ol0003oooooooooo`0Nooooo`03olco0?oooooooooo01;ooooo00?o<ol0ooooooooool0
2_ooool00ol0ofKoooooooooo`1:ooooo`03o`000?oooooooooo03;ooooo0_l0000Yooooo`009_oo
ool2o`00057ooooo00?o0000ooooooooool06oooool2olco01Cooooo00?o<ol0ooooooooool02ooo
ool00ol0ofKoooooooooo`1:ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool09_oo
ool002Sooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0Iooooo`;oc?l05?ooool2
oc?o00gooooo00?o0?mVooooooooool0C?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooo
oooo02Gooooo000Yooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool05oooool00oo<
o`3oooooooooo`0Cooooo`03oc?o0?oooooooooo00gooooo00?o0?mVooooooooool0COooool00ol0
003oooooooooo`0cooooo`03o`000?oooooooooo02Gooooo000Zooooo`03o`000?oooooooooo04ko
oooo00?o0000ooooooooool05Oooool00oo<o`3oooooooooo`0Cooooo`03oc?o0?oooooooooo00ko
oooo00?o0?mVooooooooool0C_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02Co
oooo000[ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0:?ooool2oc?o013ooooo
00?o0?mVooooooooool0D?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02?ooooo
000/ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool09_ooool00olco`3ooooooooo
o`0@ooooo`03o`3oI_oooooooooo057ooooo00?o0000ooooooooool0<oooool00ol0003ooooooooo
o`0Rooooo`00;Oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo02Cooooo00?o<ol0
ooooooooool04?ooool00ol0ofKoooooooooo`0:ooooo`Co0?oo=oooool5o`3oo`Sooooo00?o0000
ooooooooool0<oooool00ol0003oooooooooo`0Rooooo`00;_ooool00ol0003oooooooooo`1>oooo
o`03o`000?oooooooooo02;ooooo00?o<ol0ooooooooool04?ooool00ol0ofKoooooooooo`0;oooo
o`04o`3oooooooooooooooooo`Go0?oo:Oooool9o`3oo`kooooo00?o0000ooooooooool0<oooool0
0ol0003oooooooooo`0Qooooo`00;oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo
01oooooo0_lco`0Booooo`03o`3oI_oooooooooo00_ooooo00?o0?ooooooooooool01oooool<o`3o
o`oooooo3_l0oolHooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool08?ooool0033o
oooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0Looooo`;o<ol05?ooool00ol0ofKo
ooooooooo`0;ooooo`03o`3ooooooooooooo01?ooooo3ol0oolWooooo`03o`000?oooooooooo03?o
oooo00?o0000ooooooooool07oooool0037ooooo0_l0001?ooooo`03o`000?oooooooooo01[ooooo
00?o<ol0ooooooooool04oooool00ol0ofKoooooooooo`0;ooooo`03o`3ooooooooooooo04_ooooo
00?o0000ooooooooool0<_ooool2o`00023ooooo000cooooo`03o`000?oooooooooo04gooooo00?o
0000ooooooooool05oooool2oc?o01Cooooo0_l0ofH=ooooo`03o`3ooooooooooooo04gooooo00?o
0000ooooooooool0<Oooool2o`00023ooooo000dooooo`03o`000?oooooooooo04gooooo00?o0000
ooooooooool05?ooool2oc?o01Gooooo00?o0?mVooooooooool03Oooool00ol0ooooooooooooo`1=
ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool07Oooool003Gooooo00?o0000oooo
ooooool0COooool00ol0003oooooooooo`0Booooo`03oc?o0?oooooooooo01Cooooo00?o0?mVoooo
ooooool03Oooool00ol0ooooooooooooo`1?ooooo`03o`000?oooooooooo03?ooooo00?o0000oooo
ooooool07?ooool003Kooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0@ooooo`03
oc?o0?oooooooooo01Cooooo00?o0?mVooooooooool03_ooool00ol0ooooooooooooo`1@ooooo`03
o`000?oooooooooo03;ooooo00?o0000ooooooooool07?ooool003Oooooo00?o0000ooooooooool0
COooool00ol0003oooooooooo`0Tooooo`;o0?mV4?ooool00ol0ooooooooooooo`1Booooo`03o`00
0?oooooooooo03;ooooo00?o0000ooooooooool06oooool003Sooooo00?o0000ooooooooool0COoo
ool00ol0003oooooooooo`0Rooooo`03o`3oI_oooooooooo00oooooo00?o0?ooooooooooool02ooo
ool00ol0I_ooooooooooo`16ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool01ooo
ool01Oo^k^ko<S8bo`000?l@413oc<c<00kooooo000iooooo`03o`000?oooooooooo04gooooo00?o
0000ooooooooool08?ooool00ol0ofKoooooooooo`0?ooooo`03o`3ooooooooooooo00_ooooo0_l0
I_m9ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool01_ooool01OmEEEGoMgMgoooo
oonHV9So8B4Q00kooooo000jooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool07_oo
ool00ol0ofKoooooooooo`0@ooooo`03o`3ooooooooooooo00Wooooo0_l0I_l00ooooooo06Kooooo
o`0eooooo`Co06Ko3oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Gooooo00Go
0000ooooooooooooooooo`00000>ooooo`00>oooool00ol0003oooooooooo`1=ooooo`03o`000?oo
oooooooo01_ooooo0_l0ofHBooooo`03o`3ooooooooooooo00Gooooo1Ol0I_l2ooooo`03o`1Voooo
oooooooo02kooooo1ol0I_lDooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool01Ooo
ool01Ol0003oV9RHoooooonHV9So8B4Q00kooooo000looooo`03o`000?oooooooooo04gooooo00?o
0000ooooooooool06?ooool2o`3oIQ?ooooo00?o0?ooooooooooool02_ooool5o`1VobWooooo1_l0
I_lLooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool01?ooool01Ol0003oEEEEo`00
0?l@413oc<c<00kooooo000mooooo`;o0000C_ooool00ol0003oooooooooo`0Eooooo`;o0?mV4ooo
ool2o`3oo`oooooo00?o06Koooooooooool02_l0I_lBooooo`go06Ko8oooool00ol0003ooooooooo
o`0booooo`;o00001?ooool00omEEEGoQhN7ooooo`0@ooooo`00?oooool00ol0003oooooooooo`1<
ooooo`03o`000?oooooooooo01;ooooo0_l0ofHDooooo`03o`3ooooooooooooo00kooooo00?o06Ko
ooooooooool02ooooolBo`1Voc7ooooo00?o0000ooooooooool0;oooool2o`000003ooooool0003o
oooo00?ooooo00?ogMgMoa0@4?nHV9P04?ooool0043ooooo00?o0000ooooooooool0C?ooool00ol0
003oooooooooo`0?ooooo`;o0?mV5Oooool00ol0ooooooooooooo`0?ooooo`03o`1Voooooooooooo
04oooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`03ooooo`04olc<c?m4A4Co0000
oa0@40kooooo0011ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool03?ooool2o`3o
IQGooooo0_l0oolAooooo`03o`1Voooooooooooo053ooooo00?o0000ooooooooool0<_ooool00ol0
003oooooooooo`0Dooooo`00@_ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo00[o
oooo00?o0?mVooooooooool05?ooool00ol0ooooooooooooo`0@ooooo`03o`1Voooooooooooo05;o
oooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Cooooo`00@oooool00ol0003ooooo
ooooo`1<ooooo`03o`000?oooooooooo01kooooo0_l0oolBooooo`03o`1Voooooooooooo00_ooooo
0_lc0?m7ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool04_ooool004Cooooo00?o
0000ooooooooool0C?ooool00ol0003oooooooooo`0Looooo`03o`3ooooooooooooo017ooooo00?o
06Koooooooooool03?ooool00olc0?ooooooooooo`17ooooo`03o`000?oooooooooo037ooooo00?o
0000ooooooooool04_ooool004Gooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0J
ooooo`03o`3ooooooooooooo01;ooooo00?o06Koooooooooool02_ooool2oc<0od_ooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`0Aooooo`00A_ooool00ol0003oooooooooo`1<oooo
o`03o`000?oooooooooo01Oooooo0_l0oolDooooo`03o`1Voooooooooooo00Wooooo0_lc0?l00ooo
oooo<`3oooooo`1;ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool04?ooool004Oo
oooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0Eooooo`03o`3ooooooooooooo01?o
oooo00?o06Koooooooooool01oooool3oc<0o`?ooooo00?o<`3oooooooooool0B_ooool00ol0003o
ooooooooo`0booooo`03o`000?oooooooooo00oooooo0018ooooo`;o0000COooool00ol0003ooooo
ooooo`0Booooo`;o0?oo5?ooool2o`1Vo`Kooooo1?lc0?l5ooooo`03oc<0oooooooooooo037ooooo
1?lc0?lGooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool03oooool004[ooooo00?o
0000ooooooooool0Boooool00ol0003oooooooooo`0@ooooo`03o`3ooooooooooooo01?ooooo00?o
06Kooooooolc0?l01_lc0?l9ooooo`03oc<0oooooooooooo02[ooooo1olc0?lLooooo`03o`000?oo
oooooooo037ooooo0_l0000?ooooo`00Boooool00ol0003oooooooooo`1;ooooo`03o`000?oooooo
oooo00gooooo0_l0oolEooooo`03o`1Voooooooooooo00Oooooo3Olc0?lRooooo`Oo<`3o9?ooool0
0ol0003oooooooooo`0`ooooo`;o00003oooool004cooooo00?o0000ooooooooool0Boooool00ol0
003oooooooooo`0;ooooo`03o`3ooooooooooooo01?ooooo0_l0I_lAooooo`03oc<0oooooooooooo
00?ooooo8_lc0?l/ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool03?ooool004go
oooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`08ooooo`;o0?oo5Oooool00ol0I_oo
ooooooooo`0@ooooo`03oc<0oooooooooooo00_ooooo00?oc03oooooooooool0AOooool00ol0003o
ooooooooo`0aooooo`03o`000?oooooooooo00_ooooo001>ooooo`03o`000?oooooooooo04_ooooo
00?o0000ooooooooool01_ooool00ol0ooooooooooooo`0Dooooo`03o`1Voooooooooooo013ooooo
00?o<`3oooooooooool02oooool2ol`0odOooooo00?o0000ooooooooool0<Oooool00ol0003ooooo
ooooo`0;ooooo`00Coooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo00Cooooo00?o
0?ooooooooooool04oooool2o`1Voa?ooooo00?o<`3oooooooooool02_ooool2ol`0odWooooo00?o
0000ooooooooool0<Oooool00ol0003oooooooooo`0:ooooo`00D?ooool00ol0003oooooooooo`1;
ooooo`03o`000?oooooooooo01Sooooo00?o06Koooooooooool04_ooool00olc0?ooooooooooo`09
ooooo`;oc03o00?ooooool`0ooooool0BOooool00ol0003oooooooooo`0aooooo`03o`000?oooooo
oooo00Wooooo001Aooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool05_ooool00ol0
I_ooooooooooo`0Booooo`03oc<0oooooooooooo00Sooooo0_o<0?l2ooooo`03ol`0oooooooooooo
04[ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`08ooooo`00D_ooool00ol0003o
ooooooooo`1;ooooo`03o`000?oooooooooo01?ooooo0_l0I_lDooooo`03oc<0oooooooooooo00So
oooo00?oc03oooooooooool00_ooool00oo<0?ooooooooooo`1;ooooo`03o`000?oooooooooo033o
oooo00?o0000ooooooooool02?ooool005?ooooo0_l0001<ooooo`03o`000?oooooooooo017ooooo
00?o06Koooooooooool04_ooool2oc<0o`Sooooo0oo<0?l4ooooo`03ol`0oooooooooooo04gooooo
00?o0000ooooooooool0<?ooool00ol0003oooooooooo`07ooooo`00EOooool00ol0003ooooooooo
o`1:ooooo`03o`000?oooooooooo00kooooo0_l0I_lDooooo`03oc<0oooooooooooo00Gooooo0oo<
0?l7ooooo`03ol`0oooooooooooo04gooooo00?o0000ooooooooool0<Oooool00ol0003ooooooooo
o`06ooooo`00E_ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo00_ooooo0_l0I_lE
ooooo`03oc<0oooooooooooo00Koc03o2Oooool00oo<0?ooooooooooo`0[ooooo`Goc03o7oooool0
0ol0003oooooooooo`0_ooooo`?o00001oooool005Oooooo00?o0000ooooooooool0B_ooool00ol0
003oooooooooo`09ooooo`03o`1Voooooooooooo00kooooo2_o<0?l>ooooo`03ol`0oooooooooooo
00_ooooo00?oo`2Iooooooooool05oooool7ol`0obGooooo00?o0000ooooooooool0:oooool3o`00
00;ooooo00?o0000ooooooooool01Oooool005Sooooo00?o0000ooooooooool0B_ooool00ol0003o
ooooooooo`06ooooo`;o06Ko5Oooool5ol`0o`kooooo00?oc03oooooooooool02oooool2ool0VA;o
oooo1oo<0?l]ooooo`03o`000?oooooooooo02Oooooo0ol00005ooooo`03o`000?oooooooooo00Go
oooo001Iooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool00oooool2o`1VoaKooooo
00?o<`3oooooooooool00oooool<ol`0o`03ooooooo<0?oooooo00cooooo0_oo09T3oooooa3oc03o
=Oooool00ol0003oooooooooo`0Rooooo`Co00002?ooool00ol0003oooooooooo`05ooooo`00F_oo
ool00ol0003oooooooooo`1:ooooo`05o`000?ooooooooooooooool0I_l05oooool00olc0?oooooo
ooooo`0@ooooo`koc03o00?oo`2Iol`0oooo09T00oo<0?m6ooooo`03o`000?oooooooooo01kooooo
0ol0000<ooooo`03o`000?oooooooooo00Gooooo001Kooooo`03o`000?oooooooooo04[ooooo00?o
0000ooooool0I_l05_ooool2oc<0oa;ooooo00?oc03oooooooooool02oooool00ooo09Woooooool0
V@1:ooooo`03o`000?oooooooooo01[ooooo1?l0000?ooooo`03o`000?oooooooooo00Gooooo001L
ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool05?ooool00olc0?ooooooooooo`0A
ooooo`03ol`0oooooooooooo00[ooooo0_oo09T2ooooo`03ool0VOoooooooooo04Wooooo00?o0000
ooooooooool05_ooool3o`0001Cooooo00?o0000ooooooooool01?ooool005gooooo00?o0000oooo
ooooool0B_ooool00ol0003oooooooooo`0Booooo`03oc<0oooooooooooo017ooooo00?oc03ooooo
ooooool02Oooool2ool0V@?ooooo00?oo`2Iooooooooool0Boooool00ol0003oooooooooo`0Boooo
o`?o00005oooool00ol0003oooooooooo`04ooooo`00G_ooool2o`0004_ooooo00?o0000oooooooo
ool03oooool2oc<0oa;ooooo0_o<0?l;ooooo`03ool0VOoooooooooo00?ooooo00?oo`2Ioooooooo
ool0C?ooool00ol0003oooooooooo`0=ooooo`Co00006_ooool00ol0003oooooooooo`04ooooo`00
H?ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo00cooooo0_lc0?lCooooo`03ol`0
oooooooooooo00Wooooo0_oo09T5ooooo`03ool0VOoooooooooo04kooooo00?o0000ooooooooool0
2Oooool3o`0001kooooo00?o0000ooooooooool01?ooool0067ooooo00?o0000ooooooooool0BOoo
ool00ol0003oooooooooo`09ooooo`;o<`3o5?ooool00oo<0?ooooooooooo`08ooooo`;oo`2I1_oo
ool00ooo09Woooooooooo`1@ooooo`03o`000?oooooooooo00Cooooo1?l0000Qooooo`03o`000?oo
oooooooo00Cooooo001Rooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool01_ooool2
oc<0oaGooooo00?oc03oooooooooool01_ooool3ool0V@Oooooo00?oo`2Iooooooooool03?ooool0
0ooo003oooooooooo`12ooooo`04o`000?ooooooooooooooo`?o00009Oooool00ol0003ooooooooo
o`04ooooo`00Hoooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo00Cooooo00?o<`3o
ooooooooool04oooool2ol`0o`Kooooo0ooo09T9ooooo`03ool0VOoooooooooo00cooooo0_oo0015
ooooo`?o0000:?ooool00ol0003oooooooooo`04ooooo`00I?ooool00ol0003oooooooooo`19oooo
o`04o`000?ooooooooooooooo`;o<`3o5Oooool00oo<0?ooooooool0V@06ool0V@_ooooo00?oo`2I
ooooooooool03?ooool2ool001_ooooo1Ooo09TRooooo`Co000000?oooooo`000?ooool0:?ooool0
0ol0003oooooooooo`04ooooo`00IOooool00ol0003oooooooooo`19ooooo`03o`000?lc0?oo<`3o
00_ooooo3_oo09TAooooo`03ool0VOoooooooooo00cooooo0_oo000Dooooo`Soo`2I9?ooool3o`00
00Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`04ooooo`00I_ooool00ol0003o
ooooooooo`17ooooo`;o<`3o00?o0000ooooooooool04?ooool:ool0V@kooooo00?oo`2Ioooooooo
ool03?ooool2ool000kooooo1ooo09TXooooo`Co00002_ooool00ol0003oooooooooo`0Uooooo`03
o`000?oooooooooo00Cooooo001Wooooo`03o`000?oooooooooo04Gooooo00Go<`3ooooooooooooo
ooooo`00000Cooooo`03ol`0oooooooooooo00Gooooo2ooo09T2ooooo`03ool0VOoooooooooo00co
oooo0_oo000?ool0VBcooooo0ol0000?ooooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool00oooool006Sooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0?ooooo`03ol`0
oooooooooooo017ooooo3ooo09T2ool00003oooooooo003ooooo03Oooooo0ol0000Booooo`03o`00
0?oooooooooo02Gooooo00?o0000ooooooooool00oooool006Wooooo00?o0000ooooooooool0BOoo
ool00ol0003oooooooooo`0=ooooo`03ol`0oooooooooooo017ooooo0_oo09T<ooooo`;oo`000_oo
ool00ooo003oooooooooo`0cooooo`Co00005_ooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo00?ooooo001Zooooo`;o0000B_ooool00ol0003oooooooooo`0:ooooo`;oc03o4oooool0
0ooo09Woooooooooo`0:ooooo`;oo`000oooool00ooo003oooooooooo`0aooooo`?o00006oooool0
0ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00?ooooo001/ooooo`03o`000?oooooooooo
04Sooooo00?o0000ooooooooool01oooool2ol`0oaCooooo00?oo`2Iooooooooool02_ooool00ooo
003oooooooooo`02ooooo`03ool00?oooooooooo02kooooo1?l0000Oooooo`03o`000?oooooooooo
02;ooooo00?o0000ooooooooool00oooool006gooooo00?o0000ooooooooool0B?ooool00ol0003o
ooooooooo`04ooooo`;oc03o5?ooool2ool0V@_ooooo0_oo0004ooooo`03ool00?oooooooooo02co
oooo0ol0000Tooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool00oooool006kooooo
00?o0000ooooooooool0B?ooool01?l0003oooooooooooooool2ol`0oaGooooo00?oo`2Ioooooooo
ool02?ooool3ool000Gooooo00?oo`00ooooooooool0:_ooool3o`0002Sooooo00?o0000oooooooo
ool08?ooool00ol0003oooooooooo`03ooooo`00Koooool00ol0003oooooooooo`18ooooo`03o`00
0?ooooooc03o01Gooooo0_oo09T7ooooo`Coo`002?ooool00ooo003oooooooooo`0Vooooo`Co0000
:oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00?ooooo001`ooooo`03o`000?oo
oooooooo04Oooooo0_o<0?lEooooo`03ool0VOoooooooooo00?ooooo1?oo000;ooooo`03ool00?oo
oooooooo02Cooooo0ol0000`ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool00ooo
ool0077ooooo00?o0000ooooooooool0A?ooool2ol`0o`;ooooo00?o0000ooooooooool04Oooool0
0ooo09Woooooool00004ool000kooooo00?oo`00ooooooooool08Oooool4o`0000Goo`00;oooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00?ooooo001booooo`03o`000?oooooooooo
047ooooo0_o<0?l5ooooo`Soo`001oooool6ool001;ooooo00?oo`00ooooooooool07_ooool8ool0
03Gooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`02ooooo`00Loooool00ol0003o
ooooooooo`0oooooo`03ol`0oooooooooooo00Kooooo00?o0000ooooooooool02ooo00000ooooooo
o`2Iooooo`0Dooooo`03ool00?oooooooooo01Oooooo2?oo00000ol0003oooooooooo`0kooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool00_ooool007Cooooo00?o0000ooooooooool0
B?ooool00ol0003oooooooooo`04ooooo`koo`003Oooool2ool000Wooooo4Ooo0002ooooo`Co0000
@Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00;ooooo001eooooo`;o0000BOoo
ool00ol0003oooooooooo`07ooooo`;oo`2I2?oooolHool0013ooooo0ol00015ooooo`03o`000?oo
oooooooo01cooooo00?o0000ooooooooool00_ooool007Oooooo00?o0000ooooooooool0Aoooool0
0ol0003oooooooooo`04ooooo`;oo`2I5Oooool00ooo003oooooooooo`0Fooooo`Co0000BOooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00;ooooo001hooooo`03o`000?oooooooooo
04Oooooo00Co0000oooooooooooooooo0_oo09TEooooo`;oo`005_ooool3o`0004kooooo00?o0000
ooooooooool06_ooool00ol0003oooooooooo`02ooooo`00NOooool00ol0003oooooooooo`17oooo
o`03o`000?oo09Woo`2I01Kooooo00?oo`00ooooooooool04oooool3o`0005;ooooo00?o0000oooo
ooooool06Oooool00ol0003oooooooooo`02ooooo`00N_ooool00ol0003oooooooooo`15ooooo`;o
o`2I00?o0000ooooooooool05?ooool00ooo003oooooooooo`0@ooooo`Co0000E_ooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo00;ooooo001kooooo`03o`000?oooooooooo04?ooooo
00Goo`2Iooooooooooooooooo`00000Cooooo`;oo`004?ooool3o`0005_ooooo00?o0000oooooooo
ool05oooool00ol0003oooooooooo`02ooooo`00O?ooool00ol0003oooooooooo`10ooooo`;oo`2I
1Oooool00ol0003oooooooooo`0?ooooo`03ool00?oooooooooo00cooooo1?l0001Nooooo`03o`00
0?oooooooooo01Oooooo00?o0000ooooooooool00_ooool007gooooo00?o0000ooooooooool0?Ooo
ool2ool0V@Sooooo00?o0000ooooooooool03Oooool00ooo003oooooooooo`0:ooooo`?o0000Hooo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo007ooooo001nooooo`03o`000?oooooo
oooo03[ooooo0_oo09T;ooooo`03o`000?oooooooooo00[ooooo0_oo000:ooooo`?o0000Ioooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo007ooooo001oooooo`03o`000?oooooooooo
03Sooooo00?oo`2Iooooooooool03?ooool00ol0003oooooooooo`08ooooo`03ool00?oooooooooo
00Kooooo1?l0001[ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool00Oooool0083o
oooo0_l00018ooooo`03o`000?oooooooooo00Kooooo00?oo`00ooooooooool01?ooool3o`00073o
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`01ooooo`00P_ooool00ol0003ooooo
ooooo`16ooooo`03o`000?oooooooooo00?ooooo0_oo0003ooooo`Co0000M?ooool00ol0003ooooo
ooooo`0Cooooo`03o`000?oooooooooo007ooooo0023ooooo`03o`000?oooooooooo04Kooooo00?o
0000ooooooooool00_oo0002ooooo`?o0000N?ooool00ol0003oooooooooo`0Cooooo`03o`000?oo
oooooooo007ooooo0024ooooo`03o`000?oooooooooo04Kooooo0_oo00001?oooooo0000o`000?l0
001looooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00Oooool008Gooooo00?o0000
ooooooooool0@oooool2ool00003ooooool0003o0000083ooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`01ooooo`00Q_ooool00ol0003oooooooooo`10ooooo`;oo`000oooool00ol0
003oooooooooo`20ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00Oooool008Oo
oooo00?o0000ooooooooool0?Oooool2ool000Gooooo00?o0000ooooooooool0POooool00ol0003o
ooooooooo`0?ooooo`03o`000?oooooooooo007ooooo0028ooooo`03o`000?oooooooooo03[ooooo
0_oo0007ooooo`03o`000?oooooooooo08;ooooo00?o0000ooooooooool03oooool1o`00007ooooo
0Oooool008Wooooo00?o0000ooooooooool0=oooool2ool000Wooooo00?o0000ooooooooool0P_oo
ool00ol0003oooooooooo`0?ooooo`7o00000Oooool1ooooo`00R_ooool00ol0003oooooooooo`0d
ooooo`;oo`002oooool00ol0003oooooooooo`23ooooo`03o`000?oooooooooo00kooooo0Ol00001
ooooo`7ooooo002;ooooo`;o0000<oooool00ooo003oooooooooo`0;ooooo`03o`000?oooooooooo
08Cooooo00?o0000ooooooooool03Oooool1o`00007ooooo0Oooool008gooooo00?o0000oooooooo
ool0?_ooool00ol0003oooooooooo`25ooooo`03o`000?oooooooooo00cooooo0Ol00001ooooo`7o
oooo002>ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0Q_ooool00ol0003ooooo
ooooo`0;ooooo`7o00000Oooool1ooooo`00Soooool00ol0003oooooooooo`0looooo`03o`000?oo
oooooooo08Oooooo00?o0000ooooooooool02_ooool1o`00007ooooo0Oooool0093ooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`27ooooo`03o`000?oooooooooo00[ooooo0Ol00001
ooooo`7ooooo002Aooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0R?ooool00ol0
003oooooooooo`09ooooo`7o00000Oooool1ooooo`00T_ooool00ol0003oooooooooo`0iooooo`03
o`000?oooooooooo08Wooooo00?o0000ooooooooool02?ooool1o`00007ooooo0Oooool009?ooooo
00?o0000ooooooooool0>?ooool00ol0003oooooooooo`2:ooooo`03o`000?oooooooooo00Sooooo
0Ol00001ooooo`00U?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo08_ooooo00?o
0000ooooooooool01oooool1o`00007ooooo002Eooooo`03o`000?oooooooooo03Kooooo00?o0000
ooooooooool0S?ooool00ol0003oooooooooo`06ooooo`7o00000Oooool009Kooooo00?o0000oooo
ooooool0=Oooool00ol0003oooooooooo`2<ooooo`03o`000?oooooooooo00Kooooo0Ol00001oooo
o`00Uoooool2o`0003Gooooo00?o0000ooooooooool0SOooool00ol0003oooooooooo`05ooooo`7o
00000Oooool009Wooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`2>ooooo`03o`00
0?oooooooooo00Cooooo0Ol00001ooooo`00V_ooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo08oooooo00?o0000ooooooooool00oooool1o`00007ooooo002Kooooo`03o`000?oooooo
oooo033ooooo00?o0000ooooooooool0T?ooool00ol0003oooooooooo`02ooooo`7o00000Oooool0
09cooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`2Aooooo`05o`000?oooooooooo
ooooool000000Oooool009gooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`2Aoooo
o`05o`000?ooooooooooooooool000000Oooool009kooooo00?o0000ooooooooool0;Oooool00ol0
003oooooooooo`2Booooo`04o`000?ooooooooooooooo`7o0000002Oooooo`03o`000?oooooooooo
02cooooo00?o0000ooooooooool0Toooool00ol0003oooooooooo`01o`000000X?ooool00ol0003o
ooooooooo`0[ooooo`03o`000?oooooooooo09Cooooo0Ol00001ooooo`7o0000002Qooooo`03o`00
0?oooooooooo02[ooooo00?o0000ooooooooool0UOooool2o`000000X_ooool2o`0002[ooooo00?o
0000ooooooooool0U?ooool3o`000000Y?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooo
oooo093ooooo1?l00003ooooo`00YOooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo
08gooooo0ol00007ooooo`00Y_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo08Wo
oooo1?l0000:ooooo`00Yoooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo08Gooooo
1?l0000>ooooo`00Z?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo08;ooooo0ol0
000Booooo`00ZOooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo07kooooo1?l0000E
ooooo`00Z_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo07[ooooo1?l0000Ioooo
o`00Zoooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo07Gooooo1?l0000Mooooo`00
[?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo07;ooooo0ol0000Qooooo`00[Ooo
ool2o`00023ooooo00?o0000ooooooooool0K_ooool4o`0002Cooooo002_ooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool0J_ooool4o`0002Sooooo002`ooooo`03o`000?oooooooooo
01cooooo00?o0000ooooooooool0Ioooool3o`0002cooooo002aooooo`03o`000?oooooooooo01_o
oooo00?o0000ooooooooool0Hoooool4o`0002oooooo002booooo`03o`000?oooooooooo01[ooooo
00?o0000ooooooooool0Goooool4o`0003?ooooo002cooooo`03o`000?oooooooooo01Wooooo00?o
0000ooooooooool0G?ooool3o`0003Oooooo002dooooo`03o`000?oooooooooo01Sooooo00?o0000
ooooooooool0F?ooool4o`0003[ooooo002eooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool0E?ooool4o`0003kooooo002fooooo`03o`000?oooooooooo01Kooooo00?o0000oooooooo
ool0D?ooool4o`0004;ooooo002gooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0
COooool3o`0004Kooooo002hooooo`;o00005Oooool00ol0003oooooooooo`19ooooo`Co0000BOoo
ool00;[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`15ooooo`Co0000COooool0
0;_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`12ooooo`?o0000DOooool00;co
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0nooooo`Co0000E?ooool00;gooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`0jooooo`Co0000F?ooool00;kooooo00?o
0000ooooooooool03_ooool00ol0003oooooooooo`0fooooo`Co0000G?ooool00;oooooo00?o0000
ooooooooool03Oooool00ol0003oooooooooo`0cooooo`?o0000H?ooool00<3ooooo00?o0000oooo
ooooool03?ooool00ol0003oooooooooo`0_ooooo`Co0000Hoooool00<7ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0[ooooo`Co0000Ioooool00<;ooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`0Xooooo`?o0000Joooool00<?ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`0Tooooo`Co0000K_ooool00<Cooooo0_l00009ooooo`03o`000?oooooo
oooo023ooooo1?l0001booooo`00a_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
01gooooo0ol0001fooooo`00aoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Wo
oooo1?l0001iooooo`00b?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Gooooo
1?l0001mooooo`00bOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo1?l0
0021ooooo`00b_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00kooooo0ol00025
ooooo`00boooool01Ol0003ooooooooooooooooo000000cooooo1?l00028ooooo`00c?ooool01?l0
003oooooooooool00008ooooo`Co0000S?ooool00<gooooo00?o0000ooooool000001Oooool3o`00
093ooooo003>ooooo`;o000000?oooooo`000?l000000_l0002Cooooo`00coooool2o`0009Oooooo
003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
0000\
\>"],
  ImageRangeCache->{{{0, 359}, {330.375, 0}} -> {-0.0771432, -0.0315529, \
0.00350368, 0.00350368}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .92059 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-16 1.0763 -0.0263982 1.0763 [
[.01694 .18568 -11.9631 -9 ]
[.01694 .18568 .03693 0 ]
[.13793 .13897 -11.619 -9 ]
[.13793 .13897 .38095 0 ]
[.26292 .09073 -5.63752 -9 ]
[.26292 .09073 .36248 0 ]
[.39212 .04087 -5.46552 -9 ]
[.39212 .04087 .53448 0 ]
[.52574 -0.01069 -5.29351 -9 ]
[.52574 -0.01069 .70649 0 ]
[.58272 .04263 0 -6.19654 ]
[.58272 .04263 6 2.80346 ]
[.71715 .21863 0 -6.07114 ]
[.71715 .21863 6 2.92886 ]
[.83675 .37523 0 -5.963 ]
[.83675 .37523 6 3.037 ]
[.94385 .51546 0 -5.8688 ]
[.94385 .51546 6 3.1312 ]
[.01386 .20006 -12 -2.76892 ]
[.01386 .20006 0 6.23108 ]
[.00748 .25499 -24 -2.80073 ]
[.00748 .25499 0 6.19927 ]
[.00093 .31131 -6 -2.83339 ]
[.00093 .31131 0 6.16661 ]
[-0.00579 .36907 -18 -2.86695 ]
[-0.00579 .36907 0 6.13305 ]
[-0.01268 .42831 -6 -2.90143 ]
[-0.01268 .42831 0 6.09857 ]
[ 0 0 0 0 ]
[ 1 .92059 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02642 .19522 m
.53391 0 L
s
.02642 .19522 m
.03116 .2 L
s
[(-2)] .01694 .18568 .99384 1 Mshowa
.14712 .14879 m
.15172 .1537 L
s
[(-1)] .13793 .13897 .93651 1 Mshowa
.2718 .10083 m
.27624 .10588 L
s
[(0)] .26292 .09073 .87917 1 Mshowa
.40066 .05126 m
.40493 .05646 L
s
[(1)] .39212 .04087 .82184 1 Mshowa
.53391 0 m
.538 .00534 L
s
[(2)] .52574 -0.01069 .7645 1 Mshowa
.125 Mabswid
.05025 .18606 m
.05308 .18894 L
s
.07424 .17683 m
.07705 .17973 L
s
.09837 .16755 m
.10117 .17046 L
s
.12267 .1582 m
.12545 .16113 L
s
.17173 .13933 m
.17447 .14229 L
s
.19651 .1298 m
.19923 .13278 L
s
.22144 .1202 m
.22414 .1232 L
s
.24654 .11055 m
.24922 .11356 L
s
.29723 .09105 m
.29988 .0941 L
s
.32283 .0812 m
.32546 .08427 L
s
.3486 .07129 m
.35121 .07437 L
s
.37455 .06131 m
.37713 .06441 L
s
.42695 .04115 m
.4295 .04428 L
s
.45342 .03096 m
.45594 .03412 L
s
.48007 .02071 m
.48257 .02388 L
s
.5069 .01039 m
.50938 .01358 L
s
.25 Mabswid
.53391 0 m
.9804 .58403 L
s
.57014 .04738 m
.56384 .04975 L
s
[(0)] .58272 .04263 -1 .37701 Mshowa
.70445 .22307 m
.6981 .22529 L
s
[(2)] .71715 .21863 -1 .34914 Mshowa
.82396 .37939 m
.81756 .38147 L
s
[(4)] .83675 .37523 -1 .32511 Mshowa
.93098 .51938 m
.92454 .52134 L
s
[(6)] .94385 .51546 -1 .30418 Mshowa
.125 Mabswid
.60525 .09331 m
.60147 .09471 L
s
.63931 .13786 m
.63552 .13924 L
s
.67236 .1811 m
.66856 .18245 L
s
.73562 .26383 m
.7318 .26514 L
s
.7659 .30345 m
.76207 .30473 L
s
.79534 .34195 m
.7915 .34322 L
s
.85181 .41581 m
.84796 .41704 L
s
.87891 .45126 m
.87506 .45247 L
s
.90529 .48577 m
.90143 .48696 L
s
.95601 .55212 m
.95214 .55328 L
s
.25 Mabswid
.02642 .19522 m
0 .42381 L
s
.02642 .19522 m
.0327 .19281 L
s
[(-1)] .01386 .20006 1 -0.38468 Mshowa
.02006 .25024 m
.02635 .24786 L
s
[(-0.5)] .00748 .25499 1 -0.37762 Mshowa
.01354 .30664 m
.01985 .3043 L
s
[(0)] .00093 .31131 1 -0.37036 Mshowa
.00686 .36448 m
.01318 .36218 L
s
[(0.5)] -0.00579 .36907 1 -0.3629 Mshowa
0 .42381 m
.00634 .42156 L
s
[(1)] -0.01268 .42831 1 -0.35524 Mshowa
.125 Mabswid
.02516 .20612 m
.02893 .20468 L
s
.0239 .21707 m
.02767 .21563 L
s
.02262 .22807 m
.0264 .22664 L
s
.02135 .23913 m
.02512 .2377 L
s
.01877 .26141 m
.02255 .25999 L
s
.01747 .27263 m
.02125 .27122 L
s
.01617 .28391 m
.01995 .2825 L
s
.01486 .29525 m
.01864 .29384 L
s
.01222 .31809 m
.01601 .3167 L
s
.01089 .3296 m
.01468 .32821 L
s
.00955 .34117 m
.01334 .33978 L
s
.00821 .35279 m
.012 .35141 L
s
.0055 .37622 m
.0093 .37485 L
s
.00414 .38803 m
.00793 .38666 L
s
.00276 .39989 m
.00656 .39853 L
s
.00139 .41182 m
.00519 .41047 L
s
.25 Mabswid
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.54154 .92059 L
s
.54154 .92059 m
.5414 .7134 L
s
.5414 .7134 m
.02642 .19522 L
s
.53391 0 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.53391 0 m
.02642 .19522 L
s
.5414 .7134 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.54154 .92059 L
s
.54154 .92059 m
.5414 .7134 L
s
0 0 m
1 0 L
1 .92059 L
0 .92059 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.51494 .7443 m
.57072 .71558 L
s
1 0 .6 r
.4981 .7109 m
.55078 .68329 L
s
.8 0 1 r
.48124 .67749 m
.53085 .65103 L
s
.2 0 1 r
.46438 .64406 m
.51093 .6188 L
s
0 .4 1 r
.44752 .61062 m
.49102 .58659 L
s
0 1 1 r
.43064 .57716 m
.47113 .55441 L
s
0 1 .4 r
.41376 .54368 m
.45126 .52226 L
s
.2 1 0 r
.39686 .51019 m
.4314 .49013 L
s
.8 1 0 r
.37996 .47668 m
.41157 .45803 L
s
1 .6 0 r
.36306 .44316 m
.39179 .42596 L
s
.39179 .42596 m
.41475 .40646 L
s
.8 1 0 r
.41157 .45803 m
.43737 .43622 L
s
.2 1 0 r
.4314 .49013 m
.46036 .46603 L
s
0 1 .4 r
.45126 .52226 m
.48348 .49592 L
s
0 1 1 r
.47113 .55441 m
.50667 .5259 L
s
0 .4 1 r
.49102 .58659 m
.52992 .55596 L
s
.2 0 1 r
.51093 .6188 m
.55324 .5861 L
s
.8 0 1 r
.53085 .65103 m
.57663 .61633 L
s
1 0 .6 r
.55078 .68329 m
.60008 .64664 L
s
1 0 0 r
.57072 .71558 m
.62358 .67705 L
s
1 .6 0 r
.41475 .40646 m
.42877 .38923 L
s
.8 1 0 r
.43737 .43622 m
.45228 .4169 L
s
.2 1 0 r
.46036 .46603 m
.47706 .44438 L
s
0 1 .4 r
.48348 .49592 m
.50236 .47187 L
s
0 1 1 r
.50667 .5259 m
.52787 .49948 L
s
1 .6 0 r
.42877 .38923 m
.43795 .37646 L
s
0 .4 1 r
.52992 .55596 m
.55353 .52721 L
s
1 0 0 r
.58532 .68838 m
.67299 .68558 L
s
.51217 .68306 m
.58532 .68838 L
s
.2 0 1 r
.55324 .5861 m
.57932 .55509 L
s
.8 1 0 r
.45228 .4169 m
.45994 .404 L
s
1 0 0 r
.67299 .68558 m
.75027 .67564 L
s
1 0 .6 r
.58651 .65072 m
.66902 .64804 L
s
.51808 .64566 m
.58651 .65072 L
s
.8 0 1 r
.57663 .61633 m
.60523 .58309 L
s
1 0 0 r
.48024 .67847 m
.51217 .68306 L
s
1 0 .6 r
.66902 .64804 m
.74239 .63844 L
s
.2 1 0 r
.47706 .44438 m
.48433 .43106 L
s
.8 0 1 r
.58773 .61293 m
.66506 .61037 L
s
.52403 .60815 m
.58773 .61293 L
s
1 0 .6 r
.60008 .64664 m
.63127 .61124 L
s
1 0 0 r
.52585 .68038 m
.49058 .6796 L
s
.57004 .67513 m
.52585 .68038 L
s
1 .6 0 r
.43795 .37646 m
.44704 .36647 L
s
1 0 0 r
.49058 .6796 m
.48024 .67847 L
s
1 0 .6 r
.48753 .64119 m
.51808 .64566 L
s
.8 0 1 r
.66506 .61037 m
.73449 .60114 L
s
1 0 0 r
.62358 .67705 m
.65743 .63954 L
s
.2 0 1 r
.58896 .57502 m
.66108 .57258 L
s
.53001 .57053 m
.58896 .57502 L
s
1 0 .6 r
.52386 .6426 m
.49475 .64195 L
s
.5607 .63815 m
.52386 .6426 L
s
.8 0 1 r
.49486 .6038 m
.52403 .60815 L
s
1 0 .6 r
.49475 .64195 m
.48753 .64119 L
s
1 0 0 r
.61235 .6625 m
.57004 .67513 L
s
0 1 .4 r
.50236 .47187 m
.50992 .45793 L
s
.8 1 0 r
.45994 .404 m
.46613 .39541 L
s
.2 0 1 r
.66108 .57258 m
.72657 .56374 L
s
.8 0 1 r
.52186 .6047 m
.49895 .60419 L
s
.55134 .60108 m
.52186 .6047 L
s
0 .4 1 r
.59019 .53698 m
.6571 .53468 L
s
.536 .53278 m
.59019 .53698 L
s
.2 0 1 r
.50221 .56631 m
.53001 .57053 L
s
1 0 .6 r
.59595 .62746 m
.5607 .63815 L
s
.8 0 1 r
.49895 .60419 m
.49486 .6038 L
s
1 .6 0 r
.44704 .36647 m
.4582 .35799 L
s
0 .4 1 r
.6571 .53468 m
.71863 .52623 L
s
0 1 1 r
.52787 .49948 m
.53599 .48485 L
s
.8 0 1 r
.57954 .59238 m
.55134 .60108 L
s
0 .4 1 r
.50959 .52871 m
.536 .53278 L
s
.2 1 0 r
.48433 .43106 m
.48856 .42423 L
s
.2 0 1 r
.51986 .56667 m
.50316 .5663 L
s
.54195 .56391 m
.51986 .56667 L
s
0 1 1 r
.59143 .49881 m
.6531 .49664 L
s
.54201 .49493 m
.59143 .49881 L
s
.2 0 1 r
.50316 .5663 m
.50221 .56631 L
s
.8 1 0 r
.46613 .39541 m
.47368 .38864 L
s
0 1 1 r
.6531 .49664 m
.71067 .48861 L
s
.2 0 1 r
.56311 .55728 m
.54195 .56391 L
s
0 1 1 r
.51697 .491 m
.54201 .49493 L
s
0 .4 1 r
.50738 .5283 m
.50959 .52871 L
s
.51785 .52851 m
.50738 .5283 L
s
.53254 .52665 m
.51785 .52851 L
s
0 1 .4 r
.59266 .46051 m
.64909 .45849 L
s
.54802 .45696 m
.59266 .46051 L
s
1 .6 0 r
.4582 .35799 m
.47189 .35091 L
s
0 .4 1 r
.55353 .52721 m
.56228 .51189 L
s
.54667 .52215 m
.53254 .52665 L
s
1 0 0 r
.64544 .64457 m
.61235 .6625 L
s
0 1 .4 r
.64909 .45849 m
.70268 .45089 L
s
.2 1 0 r
.48856 .42423 m
.49268 .42007 L
s
0 1 .4 r
.50992 .45793 m
.51282 .45294 L
s
1 0 .6 r
.62338 .61232 m
.59595 .62746 L
s
0 1 1 r
.5116 .49017 m
.51697 .491 L
s
0 1 .4 r
.5243 .45321 m
.54802 .45696 L
s
.8 1 0 r
.47368 .38864 m
.48358 .38306 L
s
.8 0 1 r
.60136 .58012 m
.57954 .59238 L
s
0 1 1 r
.51583 .49023 m
.5116 .49017 L
s
.5231 .48929 m
.51583 .49023 L
s
.2 1 0 r
.5939 .42208 m
.64506 .42021 L
s
.55396 .41891 m
.5939 .42208 L
s
0 1 1 r
.53022 .48699 m
.5231 .48929 L
s
.2 0 1 r
.57937 .54798 m
.56311 .55728 L
s
.2 1 0 r
.64506 .42021 m
.69467 .41306 L
s
.49268 .42007 m
.4979 .41695 L
s
0 .4 1 r
.55743 .51589 m
.54667 .52215 L
s
0 1 .4 r
.51575 .45198 m
.5243 .45321 L
s
1 .6 0 r
.47189 .35091 m
.48765 .3455 L
s
.2 1 0 r
.53132 .41543 m
.55396 .41891 L
s
0 1 .4 r
.51282 .45294 m
.51377 .45189 L
s
0 1 1 r
.53553 .48386 m
.53022 .48699 L
s
.2 0 1 r
.57932 .55509 m
.58874 .53908 L
s
0 1 .4 r
.51377 .45189 m
.51575 .45198 L
s
.51367 .45189 m
.51377 .45189 L
s
.51383 .45184 m
.51367 .45189 L
s
.51377 .45189 m
.51383 .45184 L
s
.8 1 0 r
.5951 .38355 m
.64102 .38181 L
s
.55954 .38089 m
.5951 .38355 L
s
.48358 .38306 m
.49553 .37901 L
s
.2 1 0 r
.4979 .41695 m
.50435 .4148 L
s
0 1 1 r
.53599 .48485 m
.53776 .4817 L
s
.8 1 0 r
.64102 .38181 m
.68664 .37512 L
s
0 1 1 r
.53776 .4817 m
.53553 .48386 L
s
.2 1 0 r
.5195 .41392 m
.53132 .41543 L
s
.8 1 0 r
.53731 .37792 m
.55954 .38089 L
s
.2 1 0 r
.50435 .4148 m
.51148 .41379 L
s
.51148 .41379 m
.5195 .41392 L
s
1 .6 0 r
.48765 .3455 m
.5047 .34205 L
s
0 .4 1 r
.56292 .51056 m
.55743 .51589 L
s
1 .6 0 r
.59609 .34505 m
.63695 .34331 L
s
.56405 .34321 m
.59609 .34505 L
s
.8 1 0 r
.49553 .37901 m
.50854 .37684 L
s
.8 0 1 r
.60523 .58309 m
.61535 .56642 L
s
.8 1 0 r
.52201 .37653 m
.53731 .37792 L
s
1 .6 0 r
.63695 .34331 m
.67859 .33709 L
s
.5412 .3412 m
.56405 .34321 L
s
.2 0 1 r
.5882 .53954 m
.57937 .54798 L
s
.8 1 0 r
.50854 .37684 m
.52201 .37653 L
s
1 .6 0 r
.5047 .34205 m
.52242 .34067 L
s
.52242 .34067 m
.5412 .3412 L
s
0 .4 1 r
.56228 .51189 m
.56292 .51056 L
s
.8 0 1 r
.61359 .56864 m
.60136 .58012 L
s
1 0 .6 r
.63909 .59787 m
.62338 .61232 L
s
.63127 .61124 m
.6421 .59391 L
s
1 0 0 r
.66469 .62722 m
.64544 .64457 L
s
.2 0 1 r
.58874 .53908 m
.5882 .53954 L
s
1 0 0 r
.65743 .63954 m
.669 .62157 L
s
.8 0 1 r
.61535 .56642 m
.61359 .56864 L
s
1 0 .6 r
.6421 .59391 m
.63909 .59787 L
s
1 0 0 r
.669 .62157 m
.66469 .62722 L
s
0 g
.25 Mabswid
.53391 0 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.53391 0 m
.02642 .19522 L
s
.02642 .19522 m
.53391 0 L
s
.02642 .19522 m
.03116 .2 L
s
[(-2)] .01694 .18568 .99384 1 Mshowa
.14712 .14879 m
.15172 .1537 L
s
[(-1)] .13793 .13897 .93651 1 Mshowa
.2718 .10083 m
.27624 .10588 L
s
[(0)] .26292 .09073 .87917 1 Mshowa
.40066 .05126 m
.40493 .05646 L
s
[(1)] .39212 .04087 .82184 1 Mshowa
.53391 0 m
.538 .00534 L
s
[(2)] .52574 -0.01069 .7645 1 Mshowa
.125 Mabswid
.05025 .18606 m
.05308 .18894 L
s
.07424 .17683 m
.07705 .17973 L
s
.09837 .16755 m
.10117 .17046 L
s
.12267 .1582 m
.12545 .16113 L
s
.17173 .13933 m
.17447 .14229 L
s
.19651 .1298 m
.19923 .13278 L
s
.22144 .1202 m
.22414 .1232 L
s
.24654 .11055 m
.24922 .11356 L
s
.29723 .09105 m
.29988 .0941 L
s
.32283 .0812 m
.32546 .08427 L
s
.3486 .07129 m
.35121 .07437 L
s
.37455 .06131 m
.37713 .06441 L
s
.42695 .04115 m
.4295 .04428 L
s
.45342 .03096 m
.45594 .03412 L
s
.48007 .02071 m
.48257 .02388 L
s
.5069 .01039 m
.50938 .01358 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 265.125},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001Bb000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00`oooool5o`000:3ooooo0033ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@0X?ooool00<Cooooo00?oV9RHob4Q8Oo^k^h0XOooool00<Gooooo00?oV9RH
ob4Q8Oo^k^h0X?ooool00<Kooooo00?oMgMgofIVI_ooool0Woooool00<Oooooo00?o0000oooooooo
ool0W_ooool00<?ooooo00Go0000okZj^_ooooooV9RHoa0@402Pooooo`00`oooool01OnHV9So410@
o`000?lQ8B7oc<c<0:3ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003;ooooo`;o0000Voooool00<Sooooo0ol000000ooooooo0000ooooo`2Jooooo`00a_oo
ool2o`0000Cooooo0_l0002Jooooo`00`oooool3o`0000Kooooo00?o0000ooooool00000VOooool0
0<3ooooo1?l00008ooooo`04o`000?ooooooooooo`0009Sooooo002Hooooo`Co000000?o410@oooo
ooooool07oooool2o`0000Cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0002H
ooooo`00V_ooool00ol0003oooooooooo`0Nooooo`?o00003_ooool01Ol0003ooooooooooooooooo
000009Oooooo002Jooooo`03o`000?oooooooooo01cooooo0_l0000Aooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0U?ooool009[ooooo00?o0000ooooooooool06Oooool3o`0000;o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo09?o
oooo002Jooooo`03o`000?oooooooooo01Kooooo0ol0000Fooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^08Kooooo002Jooooo`03o`00
0?oooooooooo01Cooooo0_l0000Iooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1oooool01OmgMgOoV9RHoooooonHV9SoMgMg08Kooooo002Jooooo`03o`000?oooooooooo017ooooo
0ol000000ooooooo0000ooooo`0Hooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1_ooool01Ol@413ooooooooooooooooo410@08Kooooo002Hooooo`03oeEEEOmVIVKo0000017ooooo
0_l0000Nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool01Ol0003ooooo
oooooooooooo000008Kooooo002Yooooo`?o00008?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000026ooooo`00Yoooool3o`0002;ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@
4100Q_ooool00:Cooooo0ol00002ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Q_ooool00:7ooooo
0ol0000Xooooo`03o`000?oooooooooo00Sooooo0_l00004ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h0Q_ooool009oooooo0_l0000[ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo
0000S_ooool009cooooo0ol000000ooooooo0000ooooo`0Zooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0S?ooool009[ooooo0_l00005ooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`2;ooooo`00Uoooool3o`0003;ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`2:ooooo`00K?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^02?ooooo0ol000000ooooooo0000ooooo`0booooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0ROooool006cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Qooooo`;o0000>?ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo08Wooooo001/ooooo`05oa0@4?oooooooooo
ooooool@41007_ooool3o`0003[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`28
ooooo`00K?ooool01Ol0003ooooooooooooooooo000001cooooo0ol0000looooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0Qoooool006cooooo00Go0000ooooooooooooooooo`00000I
ooooo`?o00000_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool0Q_ooool006cooooo00Go410@oooooooooooooooooa0@400Gooooo`;o0000@_ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo08Kooooo001/ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL05?ooool3o`0004Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`25
ooooo`00K?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^017ooooo0ol00002ooooo`03o`000?oooooo
oooo04;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`24ooooo`00P?ooool2o`00
04[ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`23ooooo`00OOooool3o`0004co
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`22ooooo`00Noooool2o`000003oooo
ool0003ooooo04cooooo00?o0000ooooooooool05?ooool2o`0008?ooooo001hooooo`?o0000DOoo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooo000008?ooooo001eooooo`?o0000E?ooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo083ooooo001cooooo`Co0000EOooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo07oooooo001`ooooo`?o00001?ooool00ol0003o
ooooooooo`1Booooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0Ooooool006kooooo
0_l0001Looooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0O_ooool004?ooooo1?l0
00000ol@413oooooooooo`0Qooooo`?o0000G_ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo07gooooo0015ooooo`03o`000?oooooooooo023ooooo0ol00003ooooo`03o`000?oooooo
oooo05_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1looooo`00>_ooool6o`00
00Gooooo00?o0000ooooooooool07_ooool2o`0006Cooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`1looooo`00AOooool00ol0003oooooooooo`0Kooooo`?o0000I_ooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo07_ooooo0015ooooo`03o`000?oooooooooo01Wooooo
0_l00002ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`1jooooo`00AOooool00ol0003oooooooooo`0Fooooo`?o0000Joooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo07Wooooo0015ooooo`03o`000?oooooooooo01Cooooo0_l0001^
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0NOooool004?ooooo00?oEEEEofIV
I_l000004oooool3o`000003ooooool0003ooooo06gooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`1hooooo`00E_ooool3o`0007?ooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`1gooooo`00E?ooool2o`0007Kooooo00?o0000ooooooooool07oooool2o`0007Sooooo
001Aooooo`?o000000?oooooo`000?ooool0MOooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo07Kooooo001?ooooo`;o0000Noooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo07Gooooo001<ooooo`?o0000OOooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
07Cooooo0019ooooo`Co0000Ooooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo07?o
oooo0017ooooo`;o00001?ooool00ol0003oooooooooo`1looooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool0L_ooool004Cooooo0ol00025ooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool0L_ooool001[ooooo1Ol0000Sooooo`?o0000Qoooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo077ooooo000Jooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@08?ooool3
o`0000?ooooo00?o0000ooooooooool0Q?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo073ooooo000Booooo`Ko00000oooool00onHV9So8B4Qonk^kP0Oooooo`;o0000SOooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo06oooooo000Looooo`03oiRHV?lQ8B7ok^k^01_o
oooo0ol0002?ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0Koooool001gooooo
00?oMgMgofIVI_ooool05oooool3o`0000?ooooo00?o0000ooooooooool0S?ooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooooooo06kooooo000Nooooo`03o`000?oooooooooo01Cooooo0_l0
002Eooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0KOooool001[ooooo00Go0000
okZj^_ooooooV9RHoa0@400Cooooo`?o0000Uoooool00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo06cooooo000Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`04Oooool2o`0000?ooooo00?o
0000ooooooooool0U?ooool00ol0003oooooooooo`0Zooooo`;o0000KOooool002gooooo0ol0002L
ooooo`03o`000?oooooooooo02[ooooo0_l0001]ooooo`00:_ooool3o`0009oooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`1Zooooo`00:?ooool2o`0000?ooooo00?o0000oooooooo
ool0W?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo06Wooooo000Uooooo`?o0000
Y?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo06Wooooo000Tooooo`03o`000?oo
oooooooo0:Gooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1Xooooo`006_ooool4
o`000003oa0@4?oooooooooo00?ooooo0_l0002Vooooo`03o`000?oooooooooo02oooooo00?o0000
ooooooooool0Ioooool001cooooo00?o0000ooooooooool01Oooool2o`000:Kooooo00?o0000oooo
ooooool0<?ooool00ol0003oooooooooo`1Vooooo`004Oooool6o`0000Gooooo00?o0000oooooooo
ool01?ooool4o`000:Gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`08ooooo`Go
0000FOooool001cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0002Tooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool01OnHV9So8B4Qonk^k_ooooooA4A4
05Wooooo000Looooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`2Qooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool01oooool00onHV9So
8B4Qonk^kP1Jooooo`007?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0X?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Oooooo
00?oV9RHob4Q8Oo^k^h0FOooool001cooooo00?o0000ooooooooool01?ooool2o`0000Gooooo00?o
0000ooooooooool0Woooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Oooooo00?o
MgMgofIVI_ooool0F?ooool001[ooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo09kooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo05Oooooo000Sooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0WOooool00ol0003oooooooooo`0eooooo`;o00001?ooool01Ol0003o^[ZjoooooonHV9So
410@05Wooooo000Sooooo`;o00002?ooool00ol0003oooooooooo`2Looooo`03o`000?oooooooooo
03?ooooo0_l000000ooooooo0000ooooo`03ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0FOooool0
02?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2Kooooo`03o`000?oooooooooo
03Oooooo00?o0000ooooooooool0Goooool002?ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`2Jooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0Goooool002?ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`2Hooooo`;o0000>_ooool00ol0003ooooo
ooooo`1Nooooo`008_ooool2o`0000gooooo00?o0000ooooooooool0U?ooool3o`000003ooooool0
003ooooo03[ooooo00?o0000ooooooooool0GOooool002;ooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`2@ooooo`?o00001Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooo
oooo05cooooo000Rooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0S?ooool3o`00
00Wooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1Looooo`008_ooool3o`0000oo
oooo00?o0000ooooooooool0R?ooool3o`0000gooooo00?o0000ooooooooool0>?ooool00ol0003o
ooooooooo`1Kooooo`008_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo08Gooooo
0_l0000Aooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0F_ooool002;ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`21ooooo`?o00005?ooool00ol0003ooooooooo
o`0hooooo`03o`000?oooooooooo05Wooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool0OOooool3o`0001Oooooo00?o0000ooooooooool0>?ooool00ol0003ooooo
ooooo`1Iooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1iooooo`?o0000
6oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo05Sooooo0005o`0000;ooooo00Go
410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`1eooooo`?o00007oooool00ol0003oooooooooo`0hooooo`03o`00
0?oooooooooo05Oooooo0007ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8b
ooooo`03ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0LOooool3o`0002?ooooo
00?o0000ooooooooool0=oooool2o`0005Sooooo0007ooooo`05o`000?ooooooooooooooool00000
3?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`1^ooooo`;o00009oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo05Go
oooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`;o
00006Oooool00ol0003oooooooooo`1Zooooo`?o0000:_ooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo05Gooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0I_ooool3o`0002go
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1Dooooo`001oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool0H_ooool3o`00037ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1Cooooo`00
8Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo05kooooo0ol0000eooooo`03o`00
0?oooooooooo03Sooooo00?o0000ooooooooool0D_ooool0023ooooo0ol0000Mooooo`03o`000?oo
oooooooo05_ooooo0_l0000iooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0D_oo
ool0027ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1Gooooo`?o0000??ooool0
0ol0003oooooooooo`0gooooo`03o`000?oooooooooo057ooooo000Pooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool0Doooool3o`00043ooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`1@ooooo`008?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo04oo
oooo0ol00013ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0Coooool0023ooooo
0_l0000Rooooo`03o`000?oooooooooo04_ooooo0ol00017ooooo`03o`000?oooooooooo03Oooooo
00?o0000ooooooooool0Coooool0023ooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`18ooooo`;o0000Boooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo04kooooo000P
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0A?ooool3o`0004kooooo00?o0000
ooooooooool0=oooool00ol0003oooooooooo`1=ooooo`008?ooool3o`0002Cooooo00?o0000oooo
ooooool0@?ooool3o`0005;ooooo00?o0000ooooooooool0=_ooool2o`0004kooooo000Pooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0??ooool3o`0005Kooooo00?o0000oooooooo
ool0=_ooool00ol0003oooooooooo`1<ooooo`005?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oo
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0hooooo`?o0000FOooool00ol0003o
ooooooooo`0gooooo`03o`000?oooooooooo04_ooooo000Dooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo03Gooooo0_l0001Mooooo`03
o`000?oooooooooo03Oooooo00?o0000ooooooooool0B_ooool001Cooooo00Go410@oooooooooooo
oooooa0@4006ooooo`;o0000:_ooool00ol0003oooooooooo`0aooooo`?o0000H?ooool00ol0003o
ooooooooo`0gooooo`03o`000?oooooooooo04Wooooo000Dooooo`05o`000?ooooooooooooooool0
00001_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo02gooooo0ol0001Tooooo`03
o`000?oooooooooo03Kooooo00?o0000ooooooooool0BOooool001Cooooo00Go0000oooooooooooo
ooooo`000006ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0:Oooool3o`0006So
oooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`18ooooo`005?ooool01Ol@413ooooo
oooooooooooo410@00Kooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Uooooo`?o
0000K?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo04Oooooo000Dooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool2o`0002kooooo00?o0000ooooooooool08Oooool3o`0006oo
oooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`16ooooo`005?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Nooooo`;o
0000Loooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo04Gooooo000Oooooo`03o`00
0?oooooooooo02oooooo00?o0000ooooooooool06_ooool3o`0007Kooooo00?o0000ooooooooool0
=_ooool00ol0003oooooooooo`15ooooo`007_ooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo01Kooooo0ol0001jooooo`03o`000?oooooooooo00kooooo1?ooV@0Tooooo`03o`000?oo
oooooooo04Cooooo000Nooooo`;o0000<oooool00ol0003oooooooooo`0Booooo`?o0000F_ooool>
oonI01Kooooo00?o0000ooooooooool01_ooool7oonI02Wooooo0_l00014ooooo`007_ooool00ol0
003oooooooooo`0cooooo`03o`000?oooooooooo00kooooo0ol0001Hooooo`GooiT03_ooool:oonI
00_ooooo0_ooV@000ol0003ooiT0oonI0005oonI02oooooo00?o0000ooooool00000A?ooool001ko
oooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0;ooooo`;o0000EOooool6oonI01go
oooo2oooV@02ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0@_ooool001kooooo
00?o0000ooooooooool0=Oooool00ol0003oooooooooo`07ooooo`?o0000Doooool4oonI037ooooo
00?o0000ooooooooool0=_ooool00ol0003oooooooooo`11ooooo`007_ooool2o`0003Oooooo00?o
0000ooooooooool00oooool3o`0005Gooooo00?ooiT0ooooooooool0=?ooool00ol0003ooooooooo
o`0fooooo`03o`000?oooooooooo043ooooo000Nooooo`03o`000?oooooooooo03Oooooo00?o0000
ooooool000000_l0001Gooooo`03oonI0?oooooooooo03Kooooo00?o0000ooooooooool0=_ooool0
0ol0003oooooooooo`0oooooo`007_ooool00ol0003oooooooooo`0fooooo`?o0000F?ooool2oonI
03[ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0oooooo`007_ooool2o`0003Go
oooo0_l00003ooooo`03o`000?oooooooooo05Cooooo00?ooiT0ooooooooool0>oooool00ol0003o
ooooooooo`0eooooo`03o`000?oooooooooo00Wooooo0_l000000ol@413oooooooooo`0`ooooo`00
7Oooool00ol0003oooooooooo`0booooo`?o00001_ooool00ol0003oooooooooo`1Booooo`03oonI
0?oooooooooo03cooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo037ooooo0002ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo
00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo02oooooo0ol0000:ooooo`03
o`000?oooooooooo053ooooo00?ooiT0ooooooooool0?_ooool00ol0003oooooooooo`0fooooo`03
o`000?oooooooooo00Gooooo1Ol0000booooo`000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Go
oooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool0;?ooool3o`0000ko
oooo00?o0000ooooooooool0C_ooool00oooV@3oooooooooo`10ooooo`03o`000?oooooooooo03Go
oooo00?o0000ooooooooool01Oooool01?m4A4CogMgMooooool0000cooooo`000_ooool01Ol@413o
oooooooooooooooo410@013ooooo00?o0000ooooooooool00oooool2o`0002[ooooo0ol0000Boooo
o`03o`000?oooooooooo04cooooo00?ooiT0ooooooooool0@_ooool00ol0003oooooooooo`08oooo
o`?oc?l0:_ooool00ol0003oooooooooo`04ooooo`04omgMgOmEEEGoooooo`0003?ooooo0002oooo
o`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8booooo`04ooooo`03o`000?oooooo
oooo02Oooooo0_l0000Fooooo`03o`000?oooooooooo04[ooooo00?ooiT0ooooooooool04oooool@
olco027ooooo00?o0000ooooooooool00_ooool5olco02kooooo00?o0000ooooooooool01?ooool0
0omgMgOoc<c<o`00000cooooo`000_ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000
ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo02Cooooo0ol0000Iooooo`03o`000?oo
oooooooo04Wooooo00?ooiT0ooooooooool03_ooool5olco013ooooo2Oo<o`0Hooooo`03olco0?l0
003oc?l000;oc?l0<oooool2o`0000Gooooo00?ok^k^odA4A?l00000<oooool000;ooooo00Go410@
oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool08Ooo
ool3o`0001gooooo00?o0000ooooooooool0Aoooool00oooV@3oooooooooo`0<ooooo`?oc?l07_oo
oolHolco0003ooooool0003ooooo03Cooooo00Co0000oooooooooooo00001Oooool00omgMgOo0000
ooooo`0booooo`000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool0
1oooool2o`0001oooooo0ol0000Qooooo`03o`000?oooooooooo04Gooooo00?ooiT0ooooooooool0
3?ooool00oo<o`3oooooooooo`0iooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0
>?ooool000;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003ooooo
ooooo`0Looooo`?o00009Oooool00ol0003oooooooooo`13ooooo`03oonI0?oooooooooo00cooooo
00?oc?l0ooooooooool0>oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo03Oooooo
000Looooo`03o`000?oooooooooo01Wooooo0ol0000Yooooo`03o`000?oooooooooo04;ooooo00?o
oiT0ooooooooool02oooool00oo<o`3oooooooooo`0mooooo`03o`000?oooooooooo03Gooooo00?o
0000ooooooooool0=_ooool001cooooo00?o0000ooooooooool05oooool2o`0002gooooo00?o0000
ooooooooool0@?ooool00oooV@3oooooooooo`0;ooooo`03olco0?oooooooooo03oooooo00?o0000
ooooooooool0=Oooool00ol0003oooooooooo`0eooooo`007?ooool2o`0001Gooooo0ol0000`oooo
o`03o`000?oooooooooo03kooooo00?ooiT0ooooooooool02oooool00oo<o`3oooooooooo`11oooo
o`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=Oooool001cooooo00?o0000oooooooo
ool04Oooool3o`0003Cooooo00?o0000ooooooooool0?Oooool00oooV@3oooooooooo`0:ooooo`03
olco0?oooooooooo04;ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0dooooo`00
7?ooool00ol0003oooooooooo`0>ooooo`?o0000>?ooool00ol0003oooooooooo`0kooooo`03oonI
0?oooooooooo00[ooooo00?oc?l0ooooooooool0A?ooool00ol0003oooooooooo`0eooooo`03o`00
0?oooooooooo03?ooooo000Looooo`03o`000?oooooooooo00_ooooo0ol0000looooo`03o`000?oo
oooooooo03Sooooo0_ooV@0=ooooo`03olco0?oooooooooo04Gooooo00?o0000ooooooooool0=Ooo
ool00ol0003oooooooooo`0booooo`007?ooool2o`0000[ooooo0_l00010ooooo`03o`000?oooooo
oooo03Kooooo00?ooiT0ooooooooool03?ooool00oo<o`3oooooooooo`17ooooo`03o`000?oooooo
oooo03Cooooo00?o0000ooooooooool0<_ooool001_ooooo0_l00008ooooo`?o0000@oooool00ol0
003oooooooooo`0dooooo`03oonI0?oooooooooo00gooooo00?oc?l0ooooooooool03oooool6oc?o
03?ooooo00?o0000oc?o0?lco`000_lco`0booooo`03o`000?oooooooooo037ooooo000Kooooo`03
o`000?oooooooooo00Cooooo0ol00017ooooo`03o`000?oooooooooo037ooooo0_ooV@0?ooooo`03
olco0?oooooooooo00_ooooo1Olco`06ooooo`Ko<ol09Oooool8oc?o0003ooooool0003ooooo03Co
oooo0_l0000booooo`006oooool01?l0003oooooooooooooool3o`0004_ooooo00?o0000oooooooo
ool0;oooool00oooV@3oooooooooo`0?ooooo`03olco0?oooooooooo00[ooooo00?o<ol0oooooooo
ool03oooool;oc?o00kooooo3?lco`09ooooo`03o`000?oooooooooo03Gooooo00?o0000oooooooo
ool0;oooool001_ooooo1?l0001?ooooo`03o`000?oooooooooo02gooooo00?ooiT0ooooooooool0
3oooool00oo<o`3oooooooooo`0;ooooo`03oc?o0?oooooooooo01[ooooo3_lco`0Fooooo`03o`00
0?oooooooooo03Cooooo00?o0000ooooooooool0;oooool001_ooooo0_l0001Booooo`03o`000?oo
oooooooo02[ooooo0_ooV@0Aooooo`03olco0?oooooooooo00_ooooo00?o<ol0ooooooooool0@?oo
ool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02kooooo000Aooooo`Co000000?o410@
ooooooooool01Oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo02Oooooo0_ooV@0B
ooooo`03olco0?oooooooooo00cooooo00?o<ol0ooooooooool0@Oooool00ol0003oooooooooo`0d
ooooo`03o`000?oooooooooo02gooooo000Cooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool0D?ooool00ol0003oooooooooo`0Uooooo`03oonI0?oooooooooo01;ooooo00?oc?l0oooo
ooooool02oooool00olco`3oooooooooo`13ooooo`03o`000?oooooooooo03Cooooo00?o0000oooo
ooooool0;?ooool001?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1@ooooo`03
o`000?oooooooooo02;ooooo0_ooV@0Dooooo`03olco0?oooooooooo00cooooo00?o<ol0oooooooo
ool0A?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02cooooo000Cooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0Oooooo`;ooiT0
5?ooool2olco00kooooo00?o<ol0ooooooooool0AOooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo02_ooooo000Cooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0D?oo
ool00ol0003oooooooooo`0Mooooo`03oonI0?oooooooooo01?ooooo00?oc?l0ooooooooool03Ooo
ool00olco`3oooooooooo`17ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0:_oo
ool001?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1@ooooo`03o`000?oooooo
oooo01_ooooo00?ooiT0ooooooooool04oooool00oo<o`3oooooooooo`0=ooooo`03oc?o0?oooooo
oooo04Wooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Yooooo`004oooool00ol0
003oooooooooo`0=ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0;_ooool2olco
013ooooo00?o<ol0ooooooooool0B_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo
02Sooooo000Aooooo`03oeEEEOmVIVKo0000013ooooo00?o0000ooooooooool0D?ooool00ol0003o
ooooooooo`0/ooooo`03olco0?oooooooooo00oooooo00?o<ol0ooooooooool0C?ooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo02Sooooo000Uooooo`03o`000?oooooooooo053ooooo
00?o0000ooooooooool0:_ooool00oo<o`3oooooooooo`0?ooooo`03oc?o0?oooooooooo00_ooooo
1ol0ofHdooooo`Go0?mV0oooool00ol0003oooooooooo`0booooo`;o0000:Oooool002Kooooo0_l0
001Aooooo`03o`000?oooooooooo02Sooooo00?oc?l0ooooooooool04?ooool00olco`3ooooooooo
o`0;ooooo`03o`3oI_oooooooooo00Cooooo1?l0ofHWooooo`Wo0?mV2?ooool00ol0003ooooooooo
o`0dooooo`03o`000?oooooooooo02Kooooo000Xooooo`03o`000?oooooooooo04kooooo00?o0000
ooooooooool09_ooool2olco01;ooooo00?o<ol0ooooooooool02oooool00ol0ofKoooooooooo`09
ooooo`Wo0?mV4?ooool>o`3oIQ;ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0U
ooooo`00:Oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo02?ooooo0_o<o`0Doooo
o`03oc?o0?oooooooooo00_ooooo00?o0?mVooooooooool04_ooool@o`3oIR7ooooo00?o0000oooo
ooooool0<oooool00ol0003oooooooooo`0Uooooo`00:_ooool00ol0003oooooooooo`1>ooooo`03
o`000?oooooooooo027ooooo00?oc?l0ooooooooool04oooool00olco`3oooooooooo`0;ooooo`03
o`3oI_oooooooooo04Gooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Tooooo`00
:oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo01kooooo0_o<o`0Dooooo`;o<ol0
3_ooool00ol0ofKoooooooooo`16ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0
8oooool002cooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0Kooooo`;oc?l05Ooo
ool00olco`3oooooooooo`0>ooooo`03o`3oI_oooooooooo04Oooooo00?o0000ooooooooool0<ooo
ool00ol0003oooooooooo`0Rooooo`00;Oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooo
oooo01Wooooo00?oc?l0ooooooooool05?ooool00olco`3oooooooooo`0>ooooo`03o`3oI_oooooo
oooo04Sooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Rooooo`00;_ooool00ol0
003oooooooooo`1>ooooo`03o`000?oooooooooo01Oooooo00?oc?l0ooooooooool05?ooool00olc
o`3oooooooooo`0?ooooo`03o`3oI_oooooooooo04Wooooo00?o0000ooooooooool0<oooool00ol0
003oooooooooo`0Qooooo`00;oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo02_o
oooo0_lco`0Aooooo`03o`3oI_oooooooooo04_ooooo00?o0000ooooooooool0<oooool00ol0003o
ooooooooo`0Pooooo`00<?ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo02Wooooo
00?o<ol0ooooooooool04?ooool00ol0ofKoooooooooo`0:ooooo`03o`3ooooooooooooo043ooooo
00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Oooooo`00<Oooool2o`0004oooooo00?o
0000ooooooooool09oooool00olco`3oooooooooo`0@ooooo`03o`3oI_oooooooooo00[ooooo0_l0
oom3ooooo`03o`000?oooooooooo03;ooooo0_l0000Pooooo`00<oooool00ol0003oooooooooo`1=
ooooo`03o`000?oooooooooo02Gooooo00?o<ol0ooooooooool04?ooool00ol0ofKoooooooooo`06
ooooo`Go0?oo00?oooooo`3oooooool0=Oooool4o`3oo`[ooooo00?o0000ooooooooool0<Oooool2
o`00023ooooo000dooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool08_ooool2oc?o
01;ooooo00?o0?mVooooooooool01Oooool8o`3ooc3ooooo1ol0ool>ooooo`03o`000?oooooooooo
03?ooooo00?o0000ooooooooool07Oooool003Gooooo00?o0000ooooooooool0COooool00ol0003o
ooooooooo`0Oooooo`;o<ol04oooool00ol0ofKoooooooooo`0<ooooo`go0?oo7oooool6o`3ooaKo
oooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Looooo`00=_ooool00ol0003ooooo
ooooo`1=ooooo`03o`000?oooooooooo01cooooo0_lco`0Cooooo`;o0?mV3oooool00ol0oooooooo
ooooo`0:oooooaoo0?oo7Oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01cooooo
000gooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool06_ooool00olco`3ooooooooo
o`0Booooo`03o`3oI_oooooooooo00kooooo00?o0?ooooooooooool0B?ooool00ol0003ooooooooo
o`0booooo`03o`000?oooooooooo01_ooooo000hooooo`03o`000?oooooooooo04gooooo00?o0000
ooooooooool05oooool2oc?o01Cooooo00?o0?mVooooooooool03oooool00ol0ooooooooooooo`19
ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool01oooool01Oo^k^ko<S8bo`000?l@
413oc<c<00kooooo000iooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool05?ooool2
oc?o01Gooooo00?o0?mVooooooooool03oooool00ol0ooooooooooooo`1;ooooo`03o`000?oooooo
oooo03;ooooo00?o0000ooooooooool01_ooool01OmEEEGoMgMgoooooonHV9So8B4Q00kooooo000j
ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool04_ooool00olco`3oooooooooo`0C
ooooo`;o0?mV4Oooool00ol0ooooooooooooo`0;ooooo`03o`1Voooooooooooo03kooooo00?o0000
ooooooooool0<oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool000003_oo
ool003_ooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0Vooooo`03o`3oI_oooooo
oooo013ooooo00?o0?ooooooooooool02oooool00ol0I_ooooooooooo`10ooooo`03o`000?oooooo
oooo03;ooooo00?o0000ooooooooool01Oooool01Ol0003oV9RHoooooonHV9So8B4Q00kooooo000l
ooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool09?ooool00ol0ofKoooooooooo`0@
ooooo`03o`3ooooooooooooo00[ooooo0ol0I_m3ooooo`03o`000?oooooooooo03;ooooo00?o0000
ooooooooool01?ooool01Ol0003oEEEEo`000?l@413oc<c<00kooooo000mooooo`;o0000C_ooool0
0ol0003oooooooooo`0Rooooo`03o`3oI_oooooooooo013ooooo00?o0?ooooooooooool02Oooool2
o`1Vo`03ooooool0I_oooooo04Cooooo00?o0000ooooooooool0<_ooool2o`0000Cooooo00?oEEEE
ohN7Qoooool04?ooool003oooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0Ooooo
o`;o0?mV4_ooool00ol0ooooooooooooo`08ooooo`;o06Ko0oooool00ol0I_ooooooooooo`14oooo
o`03o`000?oooooooooo02oooooo0_l000000ooooooo0000ooooo`03ooooo`03omgMgOl@413oV9RH
013ooooo0010ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool07?ooool2o`3oIQ;o
oooo0_l0ool9ooooo`;o06Ko1Oooool00ol0I_ooooooooooo`15ooooo`03o`000?oooooooooo037o
oooo00?o0000ooooooooool00oooool01?o<c<coA4A4o`000?l@410>ooooo`00@Oooool00ol0003o
ooooooooo`1<ooooo`03o`000?oooooooooo01Wooooo0_l0ofHCooooo`03o`3ooooooooo06Ko00Wo
06Ko1_ooool00ol0I_ooooooooooo`0^ooooo`Ko06Ko4_ooool00ol0003oooooooooo`0booooo`03
o`000?oooooooooo01Cooooo0012ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0
5_ooool2o`3oIQCooooo00?o0?ooooooooooool01?ooool5o`1Vo`Oooooo00?o06Koooooooooool0
9?ooool:o`1VoaWooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Cooooo`00@ooo
ool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo01Cooooo00?o0?mVooooooooool04ooo
ool00ol0ooooooooooooo`0:ooooo`_o06Ko4oooool@o`1VobCooooo00?o0000ooooooooool0<_oo
ool00ol0003oooooooooo`0Booooo`00A?ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooo
oooo017ooooo0_l0ofHEooooo`03o`3ooooooooooooo013ooooo00?o06Koooooooooool00ooooolC
o`1VocGooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Booooo`00AOooool00ol0
003oooooooooo`1<ooooo`03o`000?oooooooooo00kooooo0_l0ofHEooooo`;o0?oo4_ooool00ol0
I_ooooooooooo`0;ooooo`03oc<0oooooooooooo03oooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`0Aooooo`00A_ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo00co
oooo00?o0?mVooooooooool05?ooool00ol0ooooooooooooo`0Aooooo`03o`1Voooooooooooo00_o
oooo0_lc0?m2ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool04?ooool004Oooooo
00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0Qooooo`03o`3ooooooooooooo017ooooo
00?o06Koooooooooool02oooool2oc<0od?ooooo00?o0000ooooooooool0<_ooool00ol0003ooooo
ooooo`0?ooooo`00B?ooool2o`0004gooooo00?o0000ooooooooool07oooool00ol0oooooooooooo
o`0Aooooo`03o`1Voooooooooooo00[ooooo0olc0?m5ooooo`03o`000?oooooooooo037ooooo00?o
0000ooooooooool03oooool004[ooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0M
ooooo`03o`3ooooooooooooo017ooooo00?o06Koooooooooool02Oooool2oc<0o`;ooooo00?o<`3o
ooooooooool0A?ooool00ol0003oooooooooo`0aooooo`;o00003oooool004_ooooo00?o0000oooo
ooooool0Boooool00ol0003oooooooooo`0Jooooo`;o0?oo4_ooool2o`1Vo`_ooooo00Go<`3ooooo
oooooooooooooc<0o`18ooooo`03o`000?oooooooooo033ooooo0_l0000?ooooo`00C?ooool00ol0
003oooooooooo`1;ooooo`03o`000?oooooooooo01Oooooo0_l0oolCooooo`03o`1Voooooooooooo
00Sooooo0olc0?l4ooooo`03oc<0oooooooooooo04Oooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`0<ooooo`00COooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo01Co
oooo0_l0oolDooooo`03o`1Voooooooooooo00Kooooo0olc0?l6ooooo`03oc<0oooooooooooo04Wo
oooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0;ooooo`00C_ooool00ol0003ooooo
ooooo`1;ooooo`03o`000?oooooooooo017ooooo0_l0oolEooooo`04o`1Vooooooooooooooooo`Ko
<`3o2?ooool00olc0?ooooooooooo`0/ooooo`Go<`3o6Oooool00ol0003oooooooooo`0aooooo`03
o`000?oooooooooo00_ooooo001?ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0
3oooool00ol0ooooooooooooo`0?ooooo`[o<`3o3Oooool00olc0?ooooooooooo`0<ooooo`03ol`0
oooooooooooo01Oooooo1olc0?lOooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool0
2_ooool0053ooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0<ooooo`;o0?oo5Ooo
ool2o`1Vo`03oooooolc0?oo<`3o00So<`3o1_ooool00olc0?ooooooooooo`0;ooooo`?oc03o4_oo
ool7oc<0obOooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`09ooooo`00DOooool0
0ol0003oooooooooo`1;ooooo`03o`000?oooooooooo00Wooooo0_l0oolFooooo`03o`1Voooooooo
oooo00_ooooo2Olc0?l:ooooo`03ol`0ooooooooc03o00?ooooo4?lc0?l_ooooo`03o`000?oooooo
oooo037ooooo00?o0000ooooooooool02?ooool005;ooooo00?o0000ooooooooool0Boooool00ol0
003oooooooooo`07ooooo`03o`3ooooooooooooo01Gooooo00?o06Koooooooooool04?ooool00olc
0?ooooooooooo`02ooooo`Wo<`3o00?oc03ooc<0ooo<0?l01?lc0?m0ooooo`03o`000?oooooooooo
033ooooo00?o0000ooooooooool02?ooool005?ooooo0_l0001<ooooo`03o`000?oooooooooo01go
oooo00?o06Koooooooooool04?ooool00olc0?ooooooooooo`0:ooooo`;oc03o0_ooool00oo<0?oo
ooooooooo`13ooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool01oooool005Gooooo
00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0Kooooo`03o`1Voooooooooooo013ooooo
00?o<`3oooooooooool02Oooool2ol`0o`?ooooo00?oc03oooooooooool0A?ooool00ol0003ooooo
ooooo`0aooooo`03o`000?oooooooooo00Kooooo001Fooooo`03o`000?oooooooooo04[ooooo00?o
0000ooooooooool06Oooool00ol0I_ooooooooooo`0?ooooo`;o<`3o2oooool00oo<0?oooooooooo
o`03ooooo`03ol`0oooooooooooo04Gooooo00?o0000ooooooooool0;oooool3o`0000Oooooo001G
ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool05_ooool2o`1Voa7ooooo00?o<`3o
ooooooooool02Oooool2ol`0o`Gooooo00?oc03oooooooooool0Aoooool00ol0003oooooooooo`0[
ooooo`?o00000_ooool00ol0003oooooooooo`05ooooo`00F?ooool00ol0003oooooooooo`1:oooo
o`03o`000?oooooooooo01?ooooo0_l0I_lBooooo`03oc<0oooooooooooo00Sooooo0_o<0?l6oooo
o`03ol`0oooooooooooo04Wooooo00?o0000ooooooooool09oooool3o`0000Gooooo00?o0000oooo
ooooool01Oooool005Wooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0@ooooo`;o
06Ko4oooool00olc0?ooooooooooo`06ooooo`?oc03o1oooool00oo<0?ooooooooooo`0<ooooo`03
ool0VOoooooooooo03cooooo00?o0000ooooooooool08_ooool4o`0000Sooooo00?o0000oooooooo
ool01Oooool005[ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0=ooooo`;o06Ko
4oooool2oc<0o`Kooooo0oo<0?l9ooooo`03ol`0oooooooooooo00cooooo0_oo09Toooooo`03o`00
0?oooooooooo01kooooo0ol0000<ooooo`03o`000?oooooooooo00Gooooo001Kooooo`03o`000?oo
oooooooo04[ooooo00?o0000ooooooooool02oooool00ol0I_ooooooooooo`0Booooo`03oc<0oooo
oooooooo00;ooooo1?o<0?l;ooooo`03ol`0oooooooooooo00cooooo0_oo09TJooooo`Goc03o8Ooo
ool00ol0003oooooooooo`0Jooooo`Co00003oooool00ol0003oooooooooo`05ooooo`00G?ooool0
0ol0003oooooooooo`1:ooooo`03o`000?oooooooooo00Sooooo0_l0I_l9ooooo`Koc03o1Oooool0
0olc0?ooc03ool`0o`03ol`0o`kooooo00?oc03oooooooooool03?ooool2ool0VA?ooooo2?o<0?lW
ooooo`03o`000?oooooooooo01Kooooo0ol0000Dooooo`03o`000?oooooooooo00Cooooo001Moooo
o`03o`000?oooooooooo04[ooooo00?o0000ooooooooool01Oooool2o`1Vo`oooooo2?o<0?lBoooo
o`03ol`0oooooooooooo00cooooo00?oo`2Ioooooooo09T03?ooool7ol`0oc3ooooo00?o0000oooo
ooooool04_ooool3o`0001Oooooo00?o0000ooooooooool01?ooool005kooooo0_l0001;ooooo`03
o`000?oooooooooo00;ooooo0_l0I_lEooooo`03oc<0ooo<0?ooc03o00_oc03o1oooool00oo<0?oo
ooooooooo`0<ooooo`03ool0VOo<0?ooo`2I00goc03o>?ooool00ol0003oooooooooo`0=ooooo`Co
00006_ooool00ol0003oooooooooo`04ooooo`00H?ooool00ol0003oooooooooo`19ooooo`04o`00
0?ooooooooooo`1VoaKooooo00?o<`3oooooooooool03?oooolDol`0o`;oo`2I00?oooooool0VOoo
ool0A_ooool00ol0003oooooooooo`09ooooo`?o00007_ooool00ol0003oooooooooo`04ooooo`00
HOooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo01Gooooo00?o<`3oooooooooool0
4Oooool2ol`0o`cooooo0_oo09T3ooooo`03ool0VOoooooooooo04Kooooo00?o0000ooooooooool0
1?ooool4o`00027ooooo00?o0000ooooooooool01?ooool006;ooooo00?o0000ooooooooool0BOoo
ool00ol0003oooooooooo`0Booooo`;o<`3o4oooool00oo<0?ooooooooooo`0:ooooo`;oo`2I1?oo
ool00ooo09Woooooooooo`17ooooo`04o`000?ooooooooooooooo`?o00009Oooool00ol0003ooooo
ooooo`04ooooo`00Hoooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo00oooooo0_lc
0?lDooooo`03ol`0oooooooooooo00[ooooo00?oo`2Iooooooooool00oooool00ooo09Wooooooooo
o`0<ooooo`03ool00?oooooooooo03[ooooo0ol0000Xooooo`03o`000?oooooooooo00Cooooo001T
ooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool03Oooool00olc0?ooooooooooo`0C
ooooo`03ol`0oooooooooooo00Wooooo0_oo09T5ooooo`03ool0VOoooooooooo00cooooo0_oo000h
ooooo`Co000000?oooooo`000?ooool0:?ooool00ol0003oooooooooo`04ooooo`00IOooool00ol0
003oooooooooo`19ooooo`03o`000?oooooooooo00[ooooo0_lc0?lDooooo`;oc03o2_ooool2ool0
V@Kooooo00?oo`2Iooooooooool03?ooool2ool003Kooooo0ol00006ooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool01?ooool006Kooooo00?o0000ooooooooool0BOooool00ol0003o
ooooooooo`07ooooo`;o<`3o5Oooool00oo<0?ooooooooooo`07ooooo`?oo`2I1oooool00ooo09Wo
ooooooooo`0<ooooo`;oo`00<oooool4o`0000[ooooo00?o0000ooooooooool09Oooool00ol0003o
ooooooooo`04ooooo`00Ioooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo00Gooooo
00?o<`3oooooooooool05?ooool00oo<0?ooooooooooo`05ooooo`?oo`2I2Oooool00ooo09Wooooo
ooooo`0<ooooo`03ool00?ooooooo`00033ooooo0ol0000?ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool00oooool006Sooooo00?o0000ooooooooool0BOooool00ol0003ooooooooo
o`02ooooo`;o<`3o5_ooool00oo<0?ooooooooooo`03ooooo`?oo`2I2oooool00ooo09Wooooooooo
o`0<ooooo`03ool00?ooooooo`0002kooooo0ol0000Booooo`03o`000?oooooooooo02Gooooo00?o
0000ooooooooool00oooool006Wooooo00?o0000ooooooooool0BOooool01?l0003ooooooc<0oolc
0?lFooooo`Soo`2I3Oooool00ooo09Woooooooooo`0<ooooo`03ool00?ooooooo`0001Oooooo1Ooo
09T?ooooo`Co00005_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00?ooooo001Z
ooooo`;o0000B_ooool00olc0?ooooooooooo`04oooooa;oo`2I5?ooool00ooo09Woooooooooo`0<
ooooo`04ool00?ooooooooooool000oooooo2?oo09TAooooo`?o00006oooool00ol0003ooooooooo
o`0Sooooo`03o`000?oooooooooo00?ooooo001/ooooo`03o`000?oooooooooo04Kooooo00?o<`3o
ooooool000002oooool;ool0VA?ooooo0_oo09T=ooooo`;oo`000_ooool00ooo003oooooooooo`06
ooooo`Soo`2I5Oooool4o`0001oooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`03
ooooo`00KOooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo017ooooo00?oc03ooooo
oooo09T02_oo09T7ooooo`03ool0VOoooooooooo00Sooooo0ooo09T2ool000?oo`2I00?oo`00ool0
VOoo09T01ooo09TJooooo`?o00009?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo
00?ooooo001^ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool03_ooool2ol`0o`go
oooo4_oo09T00oooooooo`00ool00004ooooo`03ool00?oooooooooo01oooooo0ol0000Xooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool00oooool006oooooo00?o0000ooooooooool0
B?ooool00ol0003oooooooooo`0;ooooo`;oc03o5?ooool00ooo09Woooooooooo`0:ooooo`03ool0
0?oooooooooo00?ooooo00?oo`00ooooooooool07?ooool4o`0002_ooooo00?o0000ooooooooool0
8?ooool00ol0003oooooooooo`03ooooo`00L?ooool00ol0003oooooooooo`18ooooo`03o`000?oo
oooooooo00Wooooo00?oc03oooooooooool04_ooool2ool0V@_ooooo0_oo0005ooooo`03ool00?oo
oooooooo01[ooooo0ol0000`ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool00ooo
ool0077ooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`06ooooo`;oc03o5?ooool0
0ooo09Woooooooooo`09ooooo`;oo`001_ooool00ooo003oooooooooo`0Gooooo`Co0000=?ooool0
0ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00?ooooo001booooo`03o`000?oooooooooo
04Sooooo00?o0000ooooooooool00oooool2ol`0oaGooooo00?oo`2Iooooooooool01oooool3ool0
00Sooooo00?oo`00ooooooooool05?ooool3o`0003Wooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`02ooooo`00Loooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00;o
c03o5_ooool00ooo09Woooooooooo`05ooooo`?oo`002_ooool00ooo003oooooooooo`0Booooo`?o
0000?Oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00;ooooo001dooooo`03o`00
0?oooooooooo04Sooooo0_o<0?lGooooo`03ool0VOoooooooooo00;ooooo1?oo000<ooooo`03ool0
0?oooooooooo00oooooo1?l00011ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool0
0_ooool007Gooooo0_l00017ooooo`03ol`0oooooooo000001Gooooo0_oo09T2ooooo`?oo`003ooo
ool00ooo003oooooooooo`0=ooooo`?o0000AOooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo00;ooooo001gooooo`03o`000?oooooooooo04;ooooo0_o<0?l3ooooo`03o`000?oooooo
oooo013ooooo1_oo000Aooooo`03ool00?oooooooooo00[ooooo1?l0000Dooooo`Goo`00<?ooool0
0ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00;ooooo001hooooo`03o`000?oooooooooo
03oooooo2ooo0008ooooo`Ooo`0000?oo`2Iooooooooool04_ooool2ool000[ooooo0ol0000?oooo
o`Woo`00=_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00;ooooo001iooooo`03
o`000?oooooooooo04;ooooo1Ooo00000ol0003oooooool00007ool000Kooooo00?oo`2Ioooooooo
ool04_ooool00ooo003oooooooooo`07ooooo`?o00002Oooool9ool0043ooooo00?o0000oooooooo
ool06Oooool00ol0003oooooooooo`02ooooo`00N_ooool00ol0003oooooooooo`16ooooo`ooo`00
00?oo`2Iooooooooool04Oooool2ool000Cooooo4_oo001:ooooo`03o`000?oooooooooo01Sooooo
00?o0000ooooooooool00_ooool007_ooooo00?o0000ooooooooool0Aoooool00ol0003ooooooooo
o`07ooooo`;oo`2I00?oooooool00?oo00006?oo0002o`0005_ooooo00?o0000ooooooooool05ooo
ool00ol0003oooooooooo`02ooooo`00O?ooool00ol0003oooooooooo`17ooooo`03o`000?oooooo
oooo00Cooooo0_oo09TDooooo`;oo`000_ooool4o`0005kooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`02ooooo`00OOooool00ol0003oooooooooo`17ooooo`04o`000?oooooooooo
ooooo`;oo`2I5Oooool00ooo003oooooo`000002o`0006?ooooo00?o0000ooooooooool05oooool0
0ol0003oooooooooo`01ooooo`00O_ooool00ol0003oooooooooo`17ooooo`03o`000?oo09Woo`2I
01Gooooo0_oo0002o`0006Oooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`01oooo
o`00Ooooool00ol0003oooooooooo`15ooooo`;oo`2I00?o0000ooooooooool04Oooool2o`000003
ool00?l0003ooooo06[ooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`01ooooo`00
P?ooool2o`0004?ooooo0_oo09T3ooooo`03o`000?oooooooooo00gooooo0ol00002ool006kooooo
00?o0000ooooooooool05?ooool00ol0003oooooooooo`01ooooo`00P_ooool00ol0003ooooooooo
o`0nooooo`;oo`2I1_ooool00ol0003oooooooooo`08ooooo`Co00000_ooool00ooo003ooooooooo
o`1_ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00Oooool008?ooooo00?o0000
ooooooooool0>oooool2ool0V@Wooooo00?o0000ooooooooool01?ooool3o`0000Cooooo0_oo001b
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00Oooool008Cooooo00?o0000oooo
ooooool0>Oooool00ooo09Woooooooooo`0:ooooo`03o`000?oooooooooo00?o00001_ooool00ooo
003oooooooooo`1cooooo`03o`000?oooooooooo01;ooooo00?o0000ooooooooool00Oooool008Go
oooo00?o0000ooooooooool0A_ooool2o`0000Oooooo0_oo001gooooo`03o`000?oooooooooo017o
oooo00?o0000ooooooooool00Oooool008Kooooo00?o0000ooooooooool0AOooool00ol0003ooooo
ooooo`04ooooo`;oo`00N_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo007ooooo
0027ooooo`03o`000?oooooooooo04Cooooo00?o0000ooooooooool00_ooool2ool007gooooo00?o
0000ooooooooool03oooool00ol0003oooooooooo`01ooooo`00R?ooool00ol0003oooooooooo`13
ooooo`05o`000?oooooooooooooooooo0000P?ooool00ol0003oooooooooo`0?ooooo`7o00000Ooo
ool1ooooo`00ROooool00ol0003oooooooooo`12ooooo`04o`000?ooooooo`00ool0087ooooo00?o
0000ooooooooool03oooool1o`00007ooooo0Oooool008[ooooo00?o0000ooooooooool0@Oooool2
ool008Cooooo00?o0000ooooooooool03_ooool1o`00007ooooo0Oooool008_ooooo0_l0000ooooo
o`;oo`0000?o0000ooooooooool0Q?ooool00ol0003oooooooooo`0=ooooo`7o00000Oooool1oooo
o`00SOooool00ol0003oooooooooo`0jooooo`;oo`000_ooool00ol0003oooooooooo`25ooooo`03
o`000?oooooooooo00cooooo0Ol00001ooooo`7ooooo002>ooooo`03o`000?oooooooooo03Sooooo
00?oo`00ooooooooool00_ooool00ol0003oooooooooo`26ooooo`03o`000?oooooooooo00_ooooo
0Ol00001ooooo`7ooooo002?ooooo`03o`000?oooooooooo03Gooooo0_oo0005ooooo`03o`000?oo
oooooooo08Oooooo00?o0000ooooooooool02_ooool1o`00007ooooo0Oooool0093ooooo00?o0000
ooooooooool0<oooool00ooo003oooooooooo`05ooooo`03o`000?oooooooooo08Oooooo00?o0000
ooooooooool02_ooool1o`00007ooooo0Oooool0097ooooo00?o0000ooooooooool0>_ooool00ol0
003oooooooooo`28ooooo`03o`000?oooooooooo00Wooooo0Ol00001ooooo`7ooooo002Booooo`03
o`000?oooooooooo03Wooooo00?o0000ooooooooool0ROooool00ol0003oooooooooo`08ooooo`7o
00000Oooool1ooooo`00Toooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo08[ooooo
00?o0000ooooooooool02?ooool1o`00007ooooo002Dooooo`03o`000?oooooooooo03Oooooo00?o
0000ooooooooool0Roooool00ol0003oooooooooo`07ooooo`7o00000Oooool009Gooooo00?o0000
ooooooooool0=_ooool00ol0003oooooooooo`2<ooooo`03o`000?oooooooooo00Kooooo0Ol00001
ooooo`00U_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo08cooooo00?o0000oooo
ooooool01_ooool1o`00007ooooo002Gooooo`;o0000=Oooool00ol0003oooooooooo`2=ooooo`03
o`000?oooooooooo00Gooooo0Ol00001ooooo`00VOooool00ol0003oooooooooo`0booooo`03o`00
0?oooooooooo08kooooo00?o0000ooooooooool01?ooool1o`00007ooooo002Jooooo`03o`000?oo
oooooooo037ooooo00?o0000ooooooooool0Soooool00ol0003oooooooooo`03ooooo`7o00000Ooo
ool009_ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`2@ooooo`03o`000?oooooo
oooo00;ooooo0Ol00001ooooo`00W?ooool00ol0003oooooooooo`0_ooooo`03o`000?oooooooooo
097ooooo00Go0000ooooooooooooooooo`000001ooooo`00WOooool00ol0003oooooooooo`0^oooo
o`03o`000?oooooooooo097ooooo00Go0000ooooooooooooooooo`000001ooooo`00W_ooool00ol0
003oooooooooo`0]ooooo`03o`000?oooooooooo09;ooooo00Co0000oooooooooooooooo0Ol00000
09oooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`2Cooooo`03o`000?oooooooooo
007o0000002Pooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0U?ooool1o`00007o
oooo0Ol000000:7ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`2Eooooo`;o0000
002Rooooo`;o0000:_ooool00ol0003oooooooooo`2Dooooo`?o0000002Tooooo`03o`000?oooooo
oooo02Oooooo00?o0000ooooooooool0T?ooool4o`0000?ooooo002Uooooo`03o`000?oooooooooo
02Kooooo00?o0000ooooooooool0SOooool3o`0000Oooooo002Vooooo`03o`000?oooooooooo02Go
oooo00?o0000ooooooooool0ROooool4o`0000[ooooo002Wooooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool0QOooool4o`0000kooooo002Xooooo`03o`000?oooooooooo02?ooooo00?o
0000ooooooooool0P_ooool3o`0001;ooooo002Yooooo`03o`000?oooooooooo02;ooooo00?o0000
ooooooooool0O_ooool4o`0001Gooooo002Zooooo`03o`000?oooooooooo027ooooo00?o0000oooo
ooooool0N_ooool4o`0001Wooooo002[ooooo`03o`000?oooooooooo027ooooo00?o0000oooooooo
ool0MOooool4o`0001gooooo002/ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
L_ooool3o`00027ooooo002]ooooo`;o00008?ooool00ol0003oooooooooo`1^ooooo`Co00009?oo
ool00:oooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1Zooooo`Co0000:?ooool0
0;3ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1Wooooo`?o0000;?ooool00;7o
oooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Sooooo`Co0000;oooool00;;ooooo
00?o0000ooooooooool06_ooool00ol0003oooooooooo`1Oooooo`Co0000<oooool00;?ooooo00?o
0000ooooooooool06Oooool00ol0003oooooooooo`1Looooo`?o0000=oooool00;Cooooo00?o0000
ooooooooool06?ooool00ol0003oooooooooo`1Hooooo`Co0000>_ooool00;Gooooo00?o0000oooo
ooooool05oooool00ol0003oooooooooo`1Dooooo`Co0000?_ooool00;Kooooo00?o0000oooooooo
ool05_ooool00ol0003oooooooooo`1@ooooo`Co0000@_ooool00;Oooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`1=ooooo`?o0000A_ooool00;Sooooo0_l0000Eooooo`03o`000?oo
oooooooo04Wooooo1?l00019ooooo`00^_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo04Gooooo1?l0001=ooooo`00^oooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
04;ooooo0ol0001Aooooo`00_?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03ko
oooo1?l0001Dooooo`00_Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo03[ooooo
1?l0001Hooooo`00__ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03Kooooo1?l0
001Looooo`00_oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03?ooooo0ol0001P
ooooo`00`?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02oooooo1?l0001Soooo
o`00`Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02_ooooo1?l0001Wooooo`00
`_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Sooooo0ol0001[ooooo`00`ooo
ool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02Cooooo1?l0001^ooooo`00a?ooool2
o`0000Wooooo00?o0000ooooooooool08?ooool4o`0007;ooooo0036ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool07Oooool3o`0007Kooooo0037ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool06Oooool4o`0007Wooooo0038ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool05Oooool4o`0007gooooo0039ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool04Oooool4o`00087ooooo003:ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool03_ooool3o`0008Gooooo003;ooooo`05o`000?ooooooooooooooool000003?ooool4
o`0008Sooooo003<ooooo`04o`000?ooooooooooo`0000Sooooo1?l0002<ooooo`00cOooool00ol0
003oooooo`000005ooooo`?o0000T?ooool00<kooooo0_l000000ooooooo0000o`000002o`0009?o
oooo003?ooooo`;o0000Uoooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?oo
ooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {330.375, 0}} -> {-0.0771432, -0.0315529, \
0.00350368, 0.00350368}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .92059 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-16 1.0763 -0.0263982 1.0763 [
[.01694 .18568 -11.9631 -9 ]
[.01694 .18568 .03693 0 ]
[.13793 .13897 -11.619 -9 ]
[.13793 .13897 .38095 0 ]
[.26292 .09073 -5.63752 -9 ]
[.26292 .09073 .36248 0 ]
[.39212 .04087 -5.46552 -9 ]
[.39212 .04087 .53448 0 ]
[.52574 -0.01069 -5.29351 -9 ]
[.52574 -0.01069 .70649 0 ]
[.58272 .04263 0 -6.19654 ]
[.58272 .04263 6 2.80346 ]
[.71715 .21863 0 -6.07114 ]
[.71715 .21863 6 2.92886 ]
[.83675 .37523 0 -5.963 ]
[.83675 .37523 6 3.037 ]
[.94385 .51546 0 -5.8688 ]
[.94385 .51546 6 3.1312 ]
[.01386 .20006 -12 -2.76892 ]
[.01386 .20006 0 6.23108 ]
[.00748 .25499 -24 -2.80073 ]
[.00748 .25499 0 6.19927 ]
[.00093 .31131 -6 -2.83339 ]
[.00093 .31131 0 6.16661 ]
[-0.00579 .36907 -18 -2.86695 ]
[-0.00579 .36907 0 6.13305 ]
[-0.01268 .42831 -6 -2.90143 ]
[-0.01268 .42831 0 6.09857 ]
[ 0 0 0 0 ]
[ 1 .92059 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02642 .19522 m
.53391 0 L
s
.02642 .19522 m
.03116 .2 L
s
[(-2)] .01694 .18568 .99384 1 Mshowa
.14712 .14879 m
.15172 .1537 L
s
[(-1)] .13793 .13897 .93651 1 Mshowa
.2718 .10083 m
.27624 .10588 L
s
[(0)] .26292 .09073 .87917 1 Mshowa
.40066 .05126 m
.40493 .05646 L
s
[(1)] .39212 .04087 .82184 1 Mshowa
.53391 0 m
.538 .00534 L
s
[(2)] .52574 -0.01069 .7645 1 Mshowa
.125 Mabswid
.05025 .18606 m
.05308 .18894 L
s
.07424 .17683 m
.07705 .17973 L
s
.09837 .16755 m
.10117 .17046 L
s
.12267 .1582 m
.12545 .16113 L
s
.17173 .13933 m
.17447 .14229 L
s
.19651 .1298 m
.19923 .13278 L
s
.22144 .1202 m
.22414 .1232 L
s
.24654 .11055 m
.24922 .11356 L
s
.29723 .09105 m
.29988 .0941 L
s
.32283 .0812 m
.32546 .08427 L
s
.3486 .07129 m
.35121 .07437 L
s
.37455 .06131 m
.37713 .06441 L
s
.42695 .04115 m
.4295 .04428 L
s
.45342 .03096 m
.45594 .03412 L
s
.48007 .02071 m
.48257 .02388 L
s
.5069 .01039 m
.50938 .01358 L
s
.25 Mabswid
.53391 0 m
.9804 .58403 L
s
.57014 .04738 m
.56384 .04975 L
s
[(0)] .58272 .04263 -1 .37701 Mshowa
.70445 .22307 m
.6981 .22529 L
s
[(2)] .71715 .21863 -1 .34914 Mshowa
.82396 .37939 m
.81756 .38147 L
s
[(4)] .83675 .37523 -1 .32511 Mshowa
.93098 .51938 m
.92454 .52134 L
s
[(6)] .94385 .51546 -1 .30418 Mshowa
.125 Mabswid
.60525 .09331 m
.60147 .09471 L
s
.63931 .13786 m
.63552 .13924 L
s
.67236 .1811 m
.66856 .18245 L
s
.73562 .26383 m
.7318 .26514 L
s
.7659 .30345 m
.76207 .30473 L
s
.79534 .34195 m
.7915 .34322 L
s
.85181 .41581 m
.84796 .41704 L
s
.87891 .45126 m
.87506 .45247 L
s
.90529 .48577 m
.90143 .48696 L
s
.95601 .55212 m
.95214 .55328 L
s
.25 Mabswid
.02642 .19522 m
0 .42381 L
s
.02642 .19522 m
.0327 .19281 L
s
[(-1)] .01386 .20006 1 -0.38468 Mshowa
.02006 .25024 m
.02635 .24786 L
s
[(-0.5)] .00748 .25499 1 -0.37762 Mshowa
.01354 .30664 m
.01985 .3043 L
s
[(0)] .00093 .31131 1 -0.37036 Mshowa
.00686 .36448 m
.01318 .36218 L
s
[(0.5)] -0.00579 .36907 1 -0.3629 Mshowa
0 .42381 m
.00634 .42156 L
s
[(1)] -0.01268 .42831 1 -0.35524 Mshowa
.125 Mabswid
.02516 .20612 m
.02893 .20468 L
s
.0239 .21707 m
.02767 .21563 L
s
.02262 .22807 m
.0264 .22664 L
s
.02135 .23913 m
.02512 .2377 L
s
.01877 .26141 m
.02255 .25999 L
s
.01747 .27263 m
.02125 .27122 L
s
.01617 .28391 m
.01995 .2825 L
s
.01486 .29525 m
.01864 .29384 L
s
.01222 .31809 m
.01601 .3167 L
s
.01089 .3296 m
.01468 .32821 L
s
.00955 .34117 m
.01334 .33978 L
s
.00821 .35279 m
.012 .35141 L
s
.0055 .37622 m
.0093 .37485 L
s
.00414 .38803 m
.00793 .38666 L
s
.00276 .39989 m
.00656 .39853 L
s
.00139 .41182 m
.00519 .41047 L
s
.25 Mabswid
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.54154 .92059 L
s
.54154 .92059 m
.5414 .7134 L
s
.5414 .7134 m
.02642 .19522 L
s
.53391 0 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.53391 0 m
.02642 .19522 L
s
.5414 .7134 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.54154 .92059 L
s
.54154 .92059 m
.5414 .7134 L
s
0 0 m
1 0 L
1 .92059 L
0 .92059 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.5318 .75523 m
.59045 .72528 L
s
1 0 .6 r
.51504 .72199 m
.57059 .69312 L
s
.8 0 1 r
.49828 .68874 m
.55073 .66099 L
s
.2 0 1 r
.4815 .65547 m
.53088 .62888 L
s
0 .4 1 r
.46472 .62219 m
.51105 .59681 L
s
0 1 1 r
.44792 .58889 m
.49124 .56476 L
s
0 1 .4 r
.43112 .55557 m
.47144 .53273 L
s
.2 1 0 r
.41431 .52224 m
.45165 .50073 L
s
.8 1 0 r
.3975 .4889 m
.43189 .46876 L
s
1 .6 0 r
.38067 .45553 m
.41214 .43681 L
s
.41214 .43681 m
.43783 .41492 L
s
.8 1 0 r
.43189 .46876 m
.46072 .44457 L
s
.2 1 0 r
.45165 .50073 m
.48373 .4743 L
s
0 1 .4 r
.47144 .53273 m
.50681 .5041 L
s
0 1 1 r
.49124 .56476 m
.52996 .534 L
s
0 .4 1 r
.51105 .59681 m
.55317 .56397 L
s
.2 0 1 r
.53088 .62888 m
.57645 .59403 L
s
.8 0 1 r
.55073 .66099 m
.59979 .62417 L
s
1 0 .6 r
.57059 .69312 m
.6232 .6544 L
s
1 0 0 r
.59045 .72528 m
.64666 .68472 L
s
1 .6 0 r
.43783 .41492 m
.45268 .39554 L
s
.8 1 0 r
.46072 .44457 m
.47734 .42284 L
s
.2 1 0 r
.48373 .4743 m
.50252 .45016 L
s
0 1 .4 r
.50681 .5041 m
.52792 .47758 L
s
1 0 0 r
.5839 .7032 m
.67629 .70026 L
s
.5064 .69759 m
.5839 .7032 L
s
0 1 1 r
.52996 .534 m
.55346 .50514 L
s
1 0 0 r
.67629 .70026 m
.75711 .68994 L
s
1 0 .6 r
.58508 .6658 m
.67235 .66298 L
s
.51226 .66044 m
.58508 .6658 L
s
0 .4 1 r
.55317 .56397 m
.57913 .53282 L
s
1 0 0 r
.47325 .69286 m
.5064 .69759 L
s
1 .6 0 r
.45268 .39554 m
.4603 .38259 L
s
1 0 .6 r
.67235 .66298 m
.74929 .65299 L
s
.8 0 1 r
.58629 .62827 m
.66842 .62557 L
s
.51817 .62319 m
.58629 .62827 L
s
1 0 0 r
.52788 .69526 m
.48665 .69435 L
s
.57916 .68921 m
.52788 .69526 L
s
.2 0 1 r
.57645 .59403 m
.60492 .56065 L
s
1 0 0 r
.48665 .69435 m
.47325 .69286 L
s
1 0 .6 r
.48048 .65583 m
.51226 .66044 L
s
.8 0 1 r
.66842 .62557 m
.74145 .61593 L
s
.8 1 0 r
.47734 .42284 m
.48458 .40947 L
s
.2 0 1 r
.58751 .59062 m
.66447 .58804 L
s
.5241 .58581 m
.58751 .59062 L
s
.8 0 1 r
.59979 .62417 m
.63084 .58861 L
s
1 0 .6 r
.5259 .65775 m
.49079 .65696 L
s
.56989 .65247 m
.5259 .65775 L
s
.49079 .65696 m
.48048 .65583 L
s
.8 0 1 r
.48776 .61869 m
.51817 .62319 L
s
1 0 0 r
.62832 .67465 m
.57916 .68921 L
s
.2 0 1 r
.66447 .58804 m
.73358 .57877 L
s
1 0 .6 r
.6232 .6544 m
.65688 .6167 L
s
0 .4 1 r
.58873 .55284 m
.66052 .5504 L
s
.53004 .54833 m
.58873 .55284 L
s
.8 0 1 r
.52392 .62011 m
.49496 .61946 L
s
.56059 .61564 m
.52392 .62011 L
s
.2 0 1 r
.49506 .58145 m
.5241 .58581 L
s
.8 0 1 r
.49496 .61946 m
.48776 .61869 L
s
1 0 .6 r
.612 .63979 m
.56989 .65247 L
s
.2 1 0 r
.50252 .45016 m
.51005 .43616 L
s
1 .6 0 r
.4603 .38259 m
.46646 .37398 L
s
0 .4 1 r
.66052 .5504 m
.7257 .54151 L
s
1 0 0 r
.64666 .68472 m
.68305 .64495 L
s
.2 0 1 r
.52194 .58234 m
.49913 .58183 L
s
.55128 .57871 m
.52194 .58234 L
s
0 1 1 r
.58995 .51494 m
.65655 .51263 L
s
.53601 .51073 m
.58995 .51494 L
s
0 .4 1 r
.50238 .54409 m
.53004 .54833 L
s
.8 0 1 r
.59568 .6049 m
.56059 .61564 L
s
.2 0 1 r
.49913 .58183 m
.49506 .58145 L
s
0 1 1 r
.65655 .51263 m
.71779 .50414 L
s
0 1 .4 r
.52792 .47758 m
.536 .46289 L
s
.2 0 1 r
.57935 .56998 m
.55128 .57871 L
s
0 1 1 r
.50972 .50663 m
.53601 .51073 L
s
.8 1 0 r
.48458 .40947 m
.48879 .40262 L
s
0 .4 1 r
.51994 .54445 m
.50332 .54409 L
s
.54193 .54169 m
.51994 .54445 L
s
0 1 .4 r
.59118 .47691 m
.65257 .47473 L
s
.54199 .47301 m
.59118 .47691 L
s
0 .4 1 r
.50332 .54409 m
.50238 .54409 L
s
1 .6 0 r
.46646 .37398 m
.47398 .36718 L
s
0 1 .4 r
.65257 .47473 m
.70987 .46667 L
s
0 .4 1 r
.56299 .53503 m
.54193 .54169 L
s
0 1 .4 r
.51707 .46907 m
.54199 .47301 L
s
0 1 1 r
.50752 .50622 m
.50972 .50663 L
s
.51794 .50644 m
.50752 .50622 L
s
.53256 .50457 m
.51794 .50644 L
s
.2 1 0 r
.59241 .43875 m
.64857 .43672 L
s
.54797 .43519 m
.59241 .43875 L
s
1 0 0 r
.66693 .6539 m
.62832 .67465 L
s
0 1 1 r
.55346 .50514 m
.56217 .48975 L
s
.54663 .50005 m
.53256 .50457 L
s
1 0 .6 r
.64493 .62177 m
.612 .63979 L
s
.2 1 0 r
.64857 .43672 m
.70192 .42909 L
s
.8 1 0 r
.48879 .40262 m
.49289 .39844 L
s
.2 1 0 r
.51005 .43616 m
.51294 .43116 L
s
.8 0 1 r
.62298 .58969 m
.59568 .6049 L
s
0 1 .4 r
.51173 .46824 m
.51707 .46907 L
s
.2 1 0 r
.52437 .43142 m
.54797 .43519 L
s
1 .6 0 r
.47398 .36718 m
.48384 .36158 L
s
.2 0 1 r
.60106 .55766 m
.57935 .56998 L
s
0 1 .4 r
.51593 .4683 m
.51173 .46824 L
s
.52317 .46735 m
.51593 .4683 L
s
.8 1 0 r
.59364 .40046 m
.64456 .39858 L
s
.55389 .39728 m
.59364 .40046 L
s
0 1 .4 r
.53026 .46504 m
.52317 .46735 L
s
0 .4 1 r
.57918 .52569 m
.56299 .53503 L
s
.8 1 0 r
.64456 .39858 m
.69395 .39141 L
s
.49289 .39844 m
.49809 .39532 L
s
0 1 1 r
.55734 .49377 m
.54663 .50005 L
s
.2 1 0 r
.51586 .43019 m
.52437 .43142 L
s
.8 1 0 r
.53135 .39379 m
.55389 .39728 L
s
.2 1 0 r
.51294 .43116 m
.51388 .4301 L
s
0 1 .4 r
.53554 .4619 m
.53026 .46504 L
s
0 .4 1 r
.57913 .53282 m
.5885 .51675 L
s
.2 1 0 r
.51388 .4301 m
.51586 .43019 L
s
.51378 .4301 m
.51388 .4301 L
s
.51394 .43005 m
.51378 .4301 L
s
.51388 .4301 m
.51394 .43005 L
s
1 .6 0 r
.59484 .36208 m
.64054 .36032 L
s
.55944 .35941 m
.59484 .36208 L
s
.48384 .36158 m
.49573 .35752 L
s
.8 1 0 r
.49809 .39532 m
.50451 .39316 L
s
0 1 .4 r
.536 .46289 m
.53776 .45974 L
s
1 .6 0 r
.64054 .36032 m
.68595 .35362 L
s
0 1 .4 r
.53776 .45974 m
.53554 .4619 L
s
.8 1 0 r
.51958 .39227 m
.53135 .39379 L
s
1 .6 0 r
.53732 .35643 m
.55944 .35941 L
s
.8 1 0 r
.50451 .39316 m
.51161 .39215 L
s
.51161 .39215 m
.51958 .39227 L
s
0 1 1 r
.5628 .48842 m
.55734 .49377 L
s
1 .6 0 r
.49573 .35752 m
.50868 .35534 L
s
.2 0 1 r
.60492 .56065 m
.61498 .5439 L
s
1 .6 0 r
.52209 .35504 m
.53732 .35643 L
s
0 .4 1 r
.58797 .51722 m
.57918 .52569 L
s
1 .6 0 r
.50868 .35534 m
.52209 .35504 L
s
0 1 1 r
.56217 .48975 m
.5628 .48842 L
s
.2 0 1 r
.61324 .54613 m
.60106 .55766 L
s
.8 0 1 r
.63861 .57517 m
.62298 .58969 L
s
.63084 .58861 m
.64161 .5712 L
s
1 0 .6 r
.66409 .60433 m
.64493 .62177 L
s
1 0 0 r
.68968 .63362 m
.66693 .6539 L
s
0 .4 1 r
.5885 .51675 m
.58797 .51722 L
s
1 0 .6 r
.65688 .6167 m
.66839 .59866 L
s
.2 0 1 r
.61498 .5439 m
.61324 .54613 L
s
1 0 0 r
.68305 .64495 m
.69531 .62628 L
s
.8 0 1 r
.64161 .5712 m
.63861 .57517 L
s
1 0 .6 r
.66839 .59866 m
.66409 .60433 L
s
1 0 0 r
.69531 .62628 m
.68968 .63362 L
s
0 g
.25 Mabswid
.53391 0 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.53391 0 m
.02642 .19522 L
s
.02642 .19522 m
.53391 0 L
s
.02642 .19522 m
.03116 .2 L
s
[(-2)] .01694 .18568 .99384 1 Mshowa
.14712 .14879 m
.15172 .1537 L
s
[(-1)] .13793 .13897 .93651 1 Mshowa
.2718 .10083 m
.27624 .10588 L
s
[(0)] .26292 .09073 .87917 1 Mshowa
.40066 .05126 m
.40493 .05646 L
s
[(1)] .39212 .04087 .82184 1 Mshowa
.53391 0 m
.538 .00534 L
s
[(2)] .52574 -0.01069 .7645 1 Mshowa
.125 Mabswid
.05025 .18606 m
.05308 .18894 L
s
.07424 .17683 m
.07705 .17973 L
s
.09837 .16755 m
.10117 .17046 L
s
.12267 .1582 m
.12545 .16113 L
s
.17173 .13933 m
.17447 .14229 L
s
.19651 .1298 m
.19923 .13278 L
s
.22144 .1202 m
.22414 .1232 L
s
.24654 .11055 m
.24922 .11356 L
s
.29723 .09105 m
.29988 .0941 L
s
.32283 .0812 m
.32546 .08427 L
s
.3486 .07129 m
.35121 .07437 L
s
.37455 .06131 m
.37713 .06441 L
s
.42695 .04115 m
.4295 .04428 L
s
.45342 .03096 m
.45594 .03412 L
s
.48007 .02071 m
.48257 .02388 L
s
.5069 .01039 m
.50938 .01358 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 265.125},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001Bb000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00`oooool5o`000:3ooooo0033ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@0X?ooool00<Cooooo00?oV9RHob4Q8Oo^k^h0XOooool00<Gooooo00?oV9RH
ob4Q8Oo^k^h0X?ooool00<Kooooo00?oMgMgofIVI_ooool0Woooool00<Oooooo00?o0000oooooooo
ool0W_ooool00<?ooooo00Go0000okZj^_ooooooV9RHoa0@402Pooooo`00`oooool01OnHV9So410@
o`000?lQ8B7oc<c<0:3ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003;ooooo`;o0000Voooool00<Sooooo0ol000000ooooooo0000ooooo`2Jooooo`00a_oo
ool2o`0000Cooooo0_l0002Jooooo`00`oooool3o`0000Kooooo00?o0000ooooool00000VOooool0
0<3ooooo1?l00008ooooo`04o`000?ooooooooooo`0009Sooooo002Hooooo`Co000000?o410@oooo
ooooool07oooool2o`0000Cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0002H
ooooo`00V_ooool00ol0003oooooooooo`0Nooooo`?o00003_ooool01Ol0003ooooooooooooooooo
000009Oooooo002Jooooo`03o`000?oooooooooo01cooooo0_l0000Aooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0U?ooool009[ooooo00?o0000ooooooooool06Oooool3o`0000;o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo09?o
oooo002Jooooo`03o`000?oooooooooo01Kooooo0ol0000Fooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^08Kooooo002Jooooo`03o`00
0?oooooooooo01Cooooo0_l0000Iooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1oooool01OmgMgOoV9RHoooooonHV9SoMgMg08Kooooo002Jooooo`03o`000?oooooooooo017ooooo
0ol000000ooooooo0000ooooo`0Hooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1_ooool01Ol@413ooooooooooooooooo410@08Kooooo002Hooooo`03oeEEEOmVIVKo0000017ooooo
0_l0000Nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool01Ol0003ooooo
oooooooooooo000008Kooooo002Yooooo`?o00008?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000026ooooo`00Yoooool3o`0002;ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@
4100Q_ooool00:Cooooo0ol00002ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Q_ooool00:7ooooo
0ol0000Xooooo`03o`000?oooooooooo00Sooooo0_l00004ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h0Q_ooool009oooooo0_l0000[ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo
0000S_ooool009cooooo0ol000000ooooooo0000ooooo`0Zooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0S?ooool009[ooooo0_l00005ooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`2;ooooo`00Uoooool3o`0003;ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`2:ooooo`00K?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^02?ooooo0ol000000ooooooo0000ooooo`0booooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0ROooool006cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Qooooo`;o0000>?ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo08Wooooo001/ooooo`05oa0@4?oooooooooo
ooooool@41007_ooool3o`0003[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`28
ooooo`00K?ooool01Ol0003ooooooooooooooooo000001cooooo0ol0000looooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0Qoooool006cooooo00Go0000ooooooooooooooooo`00000I
ooooo`?o00000_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool0Q_ooool006cooooo00Go410@oooooooooooooooooa0@400Gooooo`;o0000@_ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo08Kooooo001/ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL05?ooool3o`0004Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`25
ooooo`00K?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^017ooooo0ol00002ooooo`03o`000?oooooo
oooo04;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`24ooooo`00P?ooool2o`00
04[ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`23ooooo`00OOooool3o`0004co
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`22ooooo`00Noooool2o`000003oooo
ool0003ooooo04cooooo00?o0000ooooooooool05?ooool2o`0008?ooooo001hooooo`?o0000DOoo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooo000008?ooooo001eooooo`?o0000E?ooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo083ooooo001cooooo`Co0000EOooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo07oooooo001`ooooo`?o00001?ooool00ol0003o
ooooooooo`1Booooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0Ooooool006kooooo
0_l0001Looooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0O_ooool004?ooooo1?l0
00000ol@413oooooooooo`0Qooooo`?o0000G_ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo07gooooo0015ooooo`03o`000?oooooooooo023ooooo0ol00003ooooo`03o`000?oooooo
oooo05_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1looooo`00>_ooool6o`00
00Gooooo00?o0000ooooooooool07_ooool2o`0006Cooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`1looooo`00AOooool00ol0003oooooooooo`0Kooooo`?o0000I_ooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo07_ooooo0015ooooo`03o`000?oooooooooo01Wooooo
0_l00002ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`1jooooo`00AOooool00ol0003oooooooooo`0Fooooo`?o0000Joooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo07Wooooo0015ooooo`03o`000?oooooooooo01Cooooo0_l0001^
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0NOooool004?ooooo00?oEEEEofIV
I_l000004oooool3o`000003ooooool0003ooooo06gooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`1hooooo`00E_ooool3o`0007?ooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`1gooooo`00E?ooool2o`0007Kooooo00?o0000ooooooooool07oooool2o`0007Sooooo
001Aooooo`?o000000?oooooo`000?ooool0MOooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo07Kooooo001?ooooo`;o0000Noooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo07Gooooo001<ooooo`?o0000OOooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
07Cooooo0019ooooo`Co0000Ooooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo07?o
oooo0017ooooo`;o00001?ooool00ol0003oooooooooo`1looooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool0L_ooool004Cooooo0ol00025ooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool0L_ooool001[ooooo1Ol0000Sooooo`?o0000Qoooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo077ooooo000Jooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@08?ooool3
o`0000?ooooo00?o0000ooooooooool0Q?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo073ooooo000Booooo`Ko00000oooool00onHV9So8B4Qonk^kP0Oooooo`;o0000SOooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo06oooooo000Looooo`03oiRHV?lQ8B7ok^k^01_o
oooo0ol0002?ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0Koooool001gooooo
00?oMgMgofIVI_ooool05oooool3o`0000?ooooo00?o0000ooooooooool0S?ooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooooooo06kooooo000Nooooo`03o`000?oooooooooo01Cooooo0_l0
002Eooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0KOooool001[ooooo00Go0000
okZj^_ooooooV9RHoa0@400Cooooo`?o0000Uoooool00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo06cooooo000Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`04Oooool2o`0000?ooooo00?o
0000ooooooooool0U?ooool00ol0003oooooooooo`0Zooooo`;o0000KOooool002gooooo0ol0002L
ooooo`03o`000?oooooooooo02[ooooo0_l0001]ooooo`00:_ooool3o`0009oooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`1Zooooo`00:?ooool2o`0000?ooooo00?o0000oooooooo
ool0W?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo06Wooooo000Uooooo`?o0000
Y?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo06Wooooo000Tooooo`03o`000?oo
oooooooo0:Gooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1Xooooo`006_ooool4
o`000003oa0@4?oooooooooo00?ooooo0_l0002Vooooo`03o`000?oooooooooo02oooooo00?o0000
ooooooooool0Ioooool001cooooo00?o0000ooooooooool01Oooool2o`000:Kooooo00?o0000oooo
ooooool0<?ooool00ol0003oooooooooo`1Vooooo`004Oooool6o`0000Gooooo00?o0000oooooooo
ool01?ooool4o`000:Gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`08ooooo`Go
0000FOooool001cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0002Tooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool01OnHV9So8B4Qonk^k_ooooooA4A4
05Wooooo000Looooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`2Qooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool01oooool00onHV9So
8B4Qonk^kP1Jooooo`007?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0X?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Oooooo
00?oV9RHob4Q8Oo^k^h0FOooool001cooooo00?o0000ooooooooool01?ooool2o`0000Gooooo00?o
0000ooooooooool0Woooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Oooooo00?o
MgMgofIVI_ooool0F?ooool001[ooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo09kooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo05Oooooo000Sooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0WOooool00ol0003oooooooooo`0eooooo`;o00001?ooool01Ol0003o^[ZjoooooonHV9So
410@05Wooooo000Sooooo`;o00002?ooool00ol0003oooooooooo`2Looooo`03o`000?oooooooooo
03?ooooo0_l000000ooooooo0000ooooo`03ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0FOooool0
02?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2Kooooo`03o`000?oooooooooo
03Oooooo00?o0000ooooooooool0Goooool002?ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`2Jooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0Goooool002?ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`2Hooooo`;o0000>_ooool00ol0003ooooo
ooooo`1Nooooo`008_ooool2o`0000gooooo00?o0000ooooooooool0U?ooool3o`000003ooooool0
003ooooo03[ooooo00?o0000ooooooooool0GOooool002;ooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`2@ooooo`?o00001Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooo
oooo05cooooo000Rooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0S?ooool3o`00
00Wooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1Looooo`008_ooool3o`0000oo
oooo00?o0000ooooooooool0R?ooool3o`0000gooooo00?o0000ooooooooool0>?ooool00ol0003o
ooooooooo`1Kooooo`008_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo08Gooooo
0_l0000Aooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0F_ooool002;ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`21ooooo`?o00005?ooool00ol0003ooooooooo
o`0hooooo`03o`000?oooooooooo05Wooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool0OOooool3o`0001Oooooo00?o0000ooooooooool0>?ooool00ol0003ooooo
ooooo`1Iooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1iooooo`?o0000
6oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo05Sooooo0005o`0000;ooooo00Go
410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`1eooooo`?o00007oooool00ol0003oooooooooo`0hooooo`03o`00
0?oooooooooo05Oooooo0007ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8b
ooooo`03ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0LOooool3o`0002?ooooo
00?o0000ooooooooool0=oooool2o`0005Sooooo0007ooooo`05o`000?ooooooooooooooool00000
3?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`1^ooooo`;o00009oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo05Go
oooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`;o
00006Oooool00ol0003oooooooooo`1Zooooo`?o0000:_ooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo05Gooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0I_ooool3o`0002go
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1Dooooo`001oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool0H_ooool3o`00037ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1Cooooo`00
8Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo05kooooo0ol0000eooooo`03o`00
0?oooooooooo03Sooooo00?o0000ooooooooool0D_ooool0023ooooo0ol0000Mooooo`03o`000?oo
oooooooo05_ooooo0_l0000iooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0D_oo
ool0027ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1Gooooo`?o0000??ooool0
0ol0003oooooooooo`0gooooo`03o`000?oooooooooo057ooooo000Pooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool0Doooool3o`00043ooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`1@ooooo`008?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo04oo
oooo0ol00013ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0Coooool0023ooooo
0_l0000Rooooo`03o`000?oooooooooo04_ooooo0ol00017ooooo`03o`000?oooooooooo03Oooooo
00?o0000ooooooooool0Coooool0023ooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`18ooooo`;o0000Boooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo04kooooo000P
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0A?ooool3o`0004kooooo00?o0000
ooooooooool0=oooool00ol0003oooooooooo`1=ooooo`008?ooool3o`0002Cooooo00?o0000oooo
ooooool0@?ooool3o`0005;ooooo00?o0000ooooooooool0=_ooool2o`0004kooooo000Pooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0??ooool3o`0005Kooooo00?o0000oooooooo
ool0=_ooool00ol0003oooooooooo`1<ooooo`005?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oo
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0hooooo`?o0000FOooool00ol0003o
ooooooooo`0gooooo`03o`000?oooooooooo04_ooooo000Dooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo03Gooooo0_l0001Mooooo`03
o`000?oooooooooo03Oooooo00?o0000ooooooooool0B_ooool001Cooooo00Go410@oooooooooooo
oooooa0@4006ooooo`;o0000:_ooool00ol0003oooooooooo`0aooooo`?o0000H?ooool00ol0003o
ooooooooo`0gooooo`03o`000?oooooooooo04Wooooo000Dooooo`05o`000?ooooooooooooooool0
00001_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo02gooooo0ol0001Tooooo`03
o`000?oooooooooo03Kooooo00?o0000ooooooooool0BOooool001Cooooo00Go0000oooooooooooo
ooooo`000006ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0:Oooool3o`0006So
oooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`18ooooo`005?ooool01Ol@413ooooo
oooooooooooo410@00Kooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Uooooo`?o
0000K?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo04Oooooo000Dooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool2o`0002kooooo00?o0000ooooooooool08Oooool3o`0006oo
oooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`16ooooo`005?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Nooooo`;o
0000Loooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo04Gooooo000Oooooo`03o`00
0?oooooooooo02oooooo00?o0000ooooooooool06_ooool3o`0007Kooooo00?o0000ooooooooool0
=_ooool00ol0003oooooooooo`15ooooo`007_ooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo01Kooooo0ol0001jooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0A?oo
ool001kooooo0_l0000cooooo`03o`000?oooooooooo01;ooooo0ol0001nooooo`03o`000?oooooo
oooo03Kooooo0_l00014ooooo`007_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo
00kooooo0ol00022ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooool00000A?ooool001ko
oooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0;ooooo`;o0000QOooool00ol0003o
ooooooooo`0fooooo`03o`000?oooooooooo04;ooooo000Nooooo`03o`000?oooooooooo03Gooooo
00?o0000ooooooooool01oooool3o`0008Sooooo00?o0000ooooooooool0=_ooool00ol0003ooooo
ooooo`11ooooo`007_ooool2o`0003Oooooo00?o0000ooooooooool00oooool3o`0008cooooo00?o
0000ooooooooool03Oooool3oonI02Kooooo00?o0000ooooooooool0@?ooool001kooooo00?o0000
ooooooooool0=oooool00ol0003oooooo`000002o`0006Gooooo4?ooV@0Kooooo`03o`000?oooooo
oooo00Oooooo1OooV@0Zooooo`03o`000?oooooooooo03oooooo000Nooooo`03o`000?oooooooooo
03Kooooo0ol0001Sooooo`GooiT04?ooool9oonI01?ooooo00Co0000oooooooooooooooo1OooV@0_
ooooo`03o`000?oooooooooo03oooooo000Nooooo`;o0000=Oooool2o`0000?ooooo00?o0000oooo
ooooool0GOooool3oonI01kooooo5?ooV@000ol0003ooiT0oonI000eooooo`03o`000?oooooooooo
00Wooooo0_l000000ol@413oooooooooo`0`ooooo`007Oooool00ol0003oooooooooo`0booooo`?o
00001_ooool00ol0003oooooooooo`1Kooooo`03oonI0?oooooooooo03?ooooo00?o0000oooooooo
ool0=_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo037ooooo0002ooooo`05onk^
k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05oooo
o`03o`000?oooooooooo02oooooo0ol0000:ooooo`03o`000?oooooooooo05Wooooo00?ooiT0oooo
ooooool0=Oooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo00Gooooo1Ol0000boooo
o`000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo
00Cooooo00?o0000ooooooooool0;?ooool3o`0000kooooo00?o0000ooooooooool0Eoooool00ooo
V@3oooooooooo`0gooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool01Oooool01?m4
A4CogMgMooooool0000cooooo`000_ooool01Ol@413ooooooooooooooooo410@013ooooo00?o0000
ooooooooool00oooool2o`0002[ooooo0ol0000Booooo`03o`000?oooooooooo05Gooooo00?ooiT0
ooooooooool0>Oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo00Cooooo00CogMgM
oeEEEOoooooo0000<oooool000;ooooo00Go0000ooooooooooooooooo`00000?ooooo`03ogMgMolb
<S;ooooo00Cooooo00?o0000ooooooooool09oooool2o`0001Kooooo00?o0000ooooooooool0E?oo
ool00oooV@3oooooooooo`0jooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool01?oo
ool00omgMgOoc<c<o`00000cooooo`000_ooool01Ol0003ooooooooooooooooo000000cooooo00Go
0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oooooooooo02Cooooo0ol0000Iooooo`03o`00
0?oooooooooo05;ooooo00?ooiT0ooooooooool0??ooool00ol0003oooooooooo`0dooooo`;o0000
1Oooool00oo^k^koA4A4o`00000cooooo`000_ooool01Ol@413ooooooooooooooooo410@00cooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`0Qooooo`?o00007Oooool00ol0003ooooo
ooooo`1@ooooo`03oonI0?oooooooooo03gooooo00?o0000ooooooooool0<oooool01?l0003ooooo
ooooool00005ooooo`03ogMgMol0003ooooo03;ooooo0002ooooo`05ogMgMonHV9SooooooiRHV?mg
MgL03?ooool00ol0003oooooooooo`07ooooo`;o00007oooool3o`00027ooooo00?o0000oooooooo
ool0Coooool00oooV@3oooooooooo`0nooooo`03o`000?oooooooooo03Gooooo00?o0000oooooooo
ool0>?ooool000;ooooo00Gok^k^oc8b<_l0003o<S8bonk^kP0<ooooo`Co00001Oooool00ol0003o
ooooooooo`0Looooo`?o00009Oooool00ol0003oooooooooo`1=ooooo`03oonI0?oooooooooo043o
oooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0gooooo`007?ooool00ol0003ooooo
ooooo`0Iooooo`?o0000:Oooool00ol0003oooooooooo`1;ooooo`03oonI0?oooooooooo00cooooo
2Oo<o`0]ooooo`03o`000?oooooooooo00?ooooo1Oo<o`0]ooooo`03o`000?oooooooooo03Kooooo
000Looooo`03o`000?oooooooooo01Oooooo0_l0000]ooooo`03o`000?oooooooooo04Wooooo00?o
oiT0ooooooooool02oooool2olco00Wooooo1_o<o`0Uooooo`?oc?l000?o0000olco0?o<o`000_o<
o`0cooooo`03o`000?oooooooooo03Gooooo000Looooo`;o00005Oooool3o`00033ooooo00?o0000
ooooooooool0B?ooool00oooV@3oooooooooo`0:ooooo`03olco0?oooooooooo00oooooo2oo<o`0>
ooooo`coc?l01?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo03Gooooo000Loooo
o`03o`000?oooooooooo017ooooo0ol0000dooooo`03o`000?oooooooooo04Kooooo00?ooiT0oooo
ooooool02oooool00oo<o`3oooooooooo`0Jooooo`koc?l04?ooool00ol0003oooooooooo`0eoooo
o`03o`000?oooooooooo03Cooooo000Looooo`03o`000?oooooooooo00kooooo0ol0000hooooo`03
o`000?oooooooooo04Cooooo00?ooiT0ooooooooool02oooool00oo<o`3oooooooooo`0jooooo`03
o`000?oooooooooo03Gooooo00?o0000ooooooooool0<oooool001cooooo00?o0000ooooooooool0
2oooool3o`0003cooooo00?o0000ooooooooool0@_ooool00oooV@3oooooooooo`0<ooooo`03olco
0?oooooooooo03_ooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0booooo`007?oo
ool2o`0000[ooooo0_l00010ooooo`03o`000?oooooooooo047ooooo00?ooiT0ooooooooool02ooo
ool00oo<o`3oooooooooo`0mooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0<_oo
ool001_ooooo0_l00008ooooo`?o0000@oooool00ol0003oooooooooo`0oooooo`03oonI0?oooooo
oooo00cooooo00?oc?l0ooooooooool0?_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooo
oooo037ooooo000Kooooo`03o`000?oooooooooo00Cooooo0ol00017ooooo`03o`000?oooooooooo
03cooooo0_ooV@0>ooooo`03olco0?oooooooooo043ooooo00?o0000ooooooooool0<oooool2o`00
03;ooooo000Kooooo`04o`000?ooooooooooooooo`?o0000Boooool00ol0003oooooooooo`0joooo
o`03oonI0?oooooooooo00gooooo00?oc?l0ooooooooool0@Oooool00ol0003oooooooooo`0eoooo
o`03o`000?oooooooooo02oooooo000Kooooo`Co0000Coooool00ol0003oooooooooo`0hooooo`03
oonI0?oooooooooo00gooooo00?oc?l0ooooooooool0@oooool00ol0003oooooooooo`0dooooo`03
o`000?oooooooooo02oooooo000Kooooo`;o0000D_ooool00ol0003oooooooooo`0fooooo`03oonI
0?oooooooooo00kooooo00?oc?l0ooooooooool0A?ooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo02kooooo000Aooooo`Co000000?o410@ooooooooool01Oooool00ol0003ooooooooo
o`1@ooooo`03o`000?oooooooooo03Cooooo00?ooiT0ooooooooool03_ooool00oo<o`3ooooooooo
o`16ooooo`04o`000?lco`3o<ol0oc?o03?ooooo00?o0000ooooooooool0;Oooool001?ooooo00?o
0000ooooooooool02?ooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo03;ooooo00?o
oiT0ooooooooool03_ooool00oo<o`3oooooooooo`0;ooooo`Wo<ol0;Oooool6oc?o0003ooooool0
003ooooo03Gooooo00?o0000ooooooooool0;?ooool001?ooooo00?o0000ooooooooool02Oooool0
0ol0003oooooooooo`1@ooooo`03o`000?oooooooooo033ooooo00?ooiT0ooooooooool03_ooool0
0oo<o`3oooooooooo`0<ooooo`03oc?o0?oooooooooo00Kooooo2?lco`0Oooooo`Ko<ol02?ooool0
0ol0003oooooooooo`0cooooo`03o`000?oooooooooo02cooooo000Cooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0]ooooo`;ooiT04Oooool00oo<
o`3oooooooooo`0;ooooo`03oc?o0?oooooooooo00oooooo1olco`0<ooooo`co<ol03_ooool00ol0
003oooooooooo`0dooooo`03o`000?oooooooooo02_ooooo000Cooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0Zooooo`;ooiT04_ooool00oo<o`3o
ooooooooo`0<ooooo`03oc?o0?oooooooooo01Kooooo3?lco`0Kooooo`03o`000?oooooooooo03Co
oooo00?o0000ooooooooool0:_ooool001?ooooo00?o0000ooooooooool03?ooool00ol0003ooooo
ooooo`1@ooooo`03o`000?oooooooooo02Oooooo0_ooV@0Booooo`;oc?l03_ooool00olco`3ooooo
ooooo`0oooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0:Oooool001?ooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo02Gooooo00?o
oiT0ooooooooool04Oooool00oo<o`3oooooooooo`0>ooooo`03oc?o0?oooooooooo043ooooo00?o
0000ooooooooool0=?ooool00ol0003oooooooooo`0Xooooo`004Oooool00omEEEGoIVIVo`00000@
ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool08_ooool2oonI01?ooooo00?oc?l0
ooooooooool03_ooool00olco`3oooooooooo`12ooooo`03o`000?oooooooooo03?ooooo00?o0000
ooooooooool0:?ooool002Gooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0Ooooo
o`;ooiT05?ooool00oo<o`3oooooooooo`0?ooooo`03oc?o0?oooooooooo04?ooooo00?o0000oooo
ooooool0<_ooool2o`0002Wooooo000Vooooo`;o0000DOooool00ol0003oooooooooo`0Mooooo`03
oonI0?oooooooooo01?ooooo00?oc?l0ooooooooool03oooool00olco`3oooooooooo`14ooooo`03
o`000?oooooooooo03Cooooo00?o0000ooooooooool09_ooool002Sooooo00?o0000ooooooooool0
C_ooool00ol0003oooooooooo`0booooo`03olco0?oooooooooo00oooooo00?o<ol0ooooooooool0
A_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02Gooooo000Yooooo`03o`000?oo
oooooooo04kooooo00?o0000ooooooooool0<?ooool00oo<o`3oooooooooo`0?ooooo`03oc?o0?oo
oooooooo00[ooooo0_l0ofHlooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool09Ooo
ool002[ooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0^ooooo`03olco0?oooooo
oooo00oooooo00?o<ol0ooooooooool02Oooool2o`3oIP03ooooool0ofKooooo03cooooo00?o0000
ooooooooool0<oooool00ol0003oooooooooo`0Tooooo`00:oooool00ol0003oooooooooo`1>oooo
o`03o`000?oooooooooo02cooooo00?oc?l0ooooooooool03oooool00olco`3oooooooooo`05oooo
o`Go0?mV0oooool00ol0ofKoooooooooo`0aooooo`Ko0?mV1Oooool00ol0003oooooooooo`0coooo
o`03o`000?oooooooooo02?ooooo000/ooooo`03o`000?oooooooooo04kooooo00?o0000oooooooo
ool0:Oooool2olco017ooooo00?o<ol0ooooooooool01oooool7o`3oIR_ooooo2Ol0ofH<ooooo`03
o`000?oooooooooo03?ooooo00?o0000ooooooooool08_ooool002gooooo00?o0000ooooooooool0
C_ooool00ol0003oooooooooo`0Vooooo`;oc?l04Oooool2oc?o00oooooo3Ol0ofHAooooo`oo0?mV
5Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02;ooooo000^ooooo`03o`000?oo
oooooooo04kooooo00?o0000ooooooooool08oooool2olco01;ooooo00?o<ol0ooooooooool03_oo
ool00ol0ofKoooooooooo`0;oooooa7o0?mV9Oooool00ol0003oooooooooo`0cooooo`03o`000?oo
oooooooo027ooooo000_ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool08Oooool0
0oo<o`3oooooooooo`0Aooooo`03oc?o0?oooooooooo00oooooo00?o0?mVooooooooool0@_ooool0
0ol0003oooooooooo`0cooooo`03o`000?oooooooooo023ooooo000`ooooo`03o`000?oooooooooo
04kooooo00?o0000ooooooooool07_ooool2olco01?ooooo00?o<ol0ooooooooool03oooool00ol0
ofKoooooooooo`14ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool07oooool0037o
oooo0_l0001?ooooo`03o`000?oooooooooo01_ooooo0_o<o`0Dooooo`03oc?o0?oooooooooo00oo
oooo00?o0?mVooooooooool0A_ooool00ol0003oooooooooo`0booooo`;o00008?ooool003?ooooo
00?o0000ooooooooool0COooool00ol0003oooooooooo`0Iooooo`03olco0?oooooooooo01?ooooo
00?o<ol0ooooooooool03oooool00ol0ofKoooooooooo`0;ooooo`;o0?oo>oooool00ol0003ooooo
ooooo`0aooooo`;o00008?ooool003Cooooo00?o0000ooooooooool0COooool00ol0003ooooooooo
o`0]ooooo`03oc?o0?oooooooooo00oooooo00?o0?mVooooooooool03?ooool00ol0oooooooooooo
o`0jooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool07Oooool003Gooooo00?o0000
ooooooooool0COooool00ol0003oooooooooo`0[ooooo`03oc?o0?oooooooooo013ooooo00?o0?mV
ooooooooool02_ooool2o`3oockooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0L
ooooo`00=_ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo02Wooooo00?o<ol0oooo
ooooool04?ooool00ol0ofKoooooooooo`09ooooo`;o0?oo00?oooooo`3oooooool0?_ooool00ol0
003oooooooooo`0booooo`03o`000?oooooooooo01cooooo000gooooo`03o`000?oooooooooo04go
oooo00?o0000ooooooooool09_ooool2oc?o01;ooooo00?o0?mVooooooooool01oooool3o`3oo`;o
oooo00?o0?ooooooooooool0?oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01_o
oooo000hooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool08oooool2oc?o01;ooooo
0_l0ofH6ooooo`Co0?oo1Oooool00ol0ooooooooooooo`0`ooooo`Co0?oo3?ooool00ol0003ooooo
ooooo`0booooo`03o`000?oooooooooo00Oooooo00Gok^k^oc8b<_l0003o410@olc<c00>ooooo`00
>Oooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo023ooooo0_lco`0Cooooo`03o`3o
I_oooooo0?oo00Ko0?oo2?ooool00ol0ooooooooooooo`0Zooooo`Oo0?oo4Oooool00ol0003ooooo
ooooo`0booooo`03o`000?oooooooooo00Kooooo00GoEEEEogMgMoooooooV9RHob4Q8@0>ooooo`00
>_ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo01gooooo0_lco`0Dooooo`03o`3o
I_oooooooooo00Oooooo2Ol0oolUooooo`Oo0?oo6?ooool00ol0003oooooooooo`0cooooo`03o`00
0?oooooooooo00Gooooo00Go0000ooooooooooooooooo`00000>ooooo`00>oooool00ol0003ooooo
ooooo`1=ooooo`03o`000?oooooooooo01_ooooo00?o<ol0ooooooooool04oooool00ol0ofKooooo
ooooo`0?ooooo`03o`3ooooooooo0?oo00So0?oo3_ooool>o`3oob3ooooo00?o0000ooooooooool0
<_ooool00ol0003oooooooooo`05ooooo`05o`000?nHV9SooooooiRHV?lQ8B403_ooool003cooooo
00?o0000ooooooooool0COooool00ol0003oooooooooo`0Hooooo`;o<ol05Oooool00ol0ofKooooo
ooooo`0?ooooo`03o`3ooooooooooooo00Wooooo0_l0ool00ol0I_oo0?ooo`3oo`09o`3ooboooooo
00?o0000ooooooooool0<_ooool00ol0003oooooooooo`04ooooo`05o`000?mEEEGo0000oa0@4?o<
c<`03_ooool003gooooo0_l0001>ooooo`03o`000?oooooooooo01Gooooo0_lco`0Eooooo`;o0?mV
4Oooool00ol0ooooooooooooo`0;ooooo`;o06Ko>oooool00ol0003oooooooooo`0booooo`;o0000
1?ooool00omEEEGoQhN7ooooo`0@ooooo`00?oooool00ol0003oooooooooo`1<ooooo`03o`000?oo
oooooooo01?ooooo00?o<ol0ooooooooool05?ooool00ol0ofKoooooooooo`0@ooooo`03o`3ooooo
oooooooo00_ooooo0_l0I_lmooooo`03o`000?oooooooooo02oooooo0_l000000ooooooo0000oooo
o`03ooooo`03omgMgOl@413oV9RH013ooooo0010ooooo`03o`000?oooooooooo04cooooo00?o0000
ooooooooool0:?ooool00ol0ofKoooooooooo`0Aooooo`03o`3ooooooooooooo00Wooooo0_l0I_l0
0ooooooo06Koooooo`0mooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool00oooool0
1?o<c<coA4A4o`000?l@410>ooooo`00@Oooool00ol0003oooooooooo`1<ooooo`03o`000?oooooo
oooo02Kooooo00?o0?mVooooooooool04Oooool00ol0ooooooooooooo`08ooooo`;o06Ko0_ooool0
0ol0I_ooooooooooo`0mooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool05?ooool0
04;ooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0Tooooo`03o`3oI_oooooooooo
017ooooo00?o0?ooooooooooool02?ooool00ol0I_ooooooooooo`02ooooo`03o`1Voooooooooooo
03kooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Cooooo`00@oooool00ol0003o
ooooooooo`1<ooooo`03o`000?oooooooooo027ooooo0_l0ofHBooooo`;o0?oo2Oooool2o`1Vo`Co
oooo00?o06Koooooooooool0@?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01;o
oooo0014ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool07_ooool2o`3oIQ?ooooo
00?o0?ooooooooooool01_ooool3o`1Vo`Kooooo00?o06Koooooooooool0@Oooool00ol0003ooooo
ooooo`0aooooo`03o`000?oooooooooo01;ooooo0015ooooo`03o`000?oooooooooo04cooooo00?o
0000ooooooooool06oooool2o`3oIQCooooo00?o0?ooooooooooool01Oooool2o`1Vo`Sooooo00?o
06Koooooooooool0@oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo017ooooo0016
ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool06?ooool2o`3oIQ3ooooo1?l0I_l2
o`3oo`?ooooo1Ol0I_l9ooooo`03o`1Voooooooooooo00_ooooo00?o<`3oooooooooool07_ooool5
o`1VoaCooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0@ooooo`00Aoooool00ol0
003oooooooooo`1<ooooo`03o`000?oooooooooo01Kooooo00?o0?mVooooooooool04oooool6o`1V
o`gooooo00?o06Koooooooooool02oooool2oc<0oaWooooo1ol0I_lIooooo`03o`000?oooooooooo
03;ooooo00?o0000ooooooooool03oooool004Sooooo0_l0001=ooooo`03o`000?oooooooooo01?o
oooo0_l0ofHEooooo`03o`3ooooooooooooo00?ooooo3?l0I_l00ooooooo06Koooooo`0<ooooo`;o
<`3o4oooool7o`1Vob7ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0?ooooo`00
B_ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo013ooooo0_l0ofHFooooo`03o`3o
oooooooooooo013ooooo3_l0I_l00olc0?oo06Kooc<0o`0Co`1VobWooooo00?o0000ooooooooool0
<Oooool2o`0000oooooo001;ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool03_oo
ool00ol0ofKoooooooooo`0Dooooo`;o0?oo4_ooool00ol0I_ooooooooooo`0;ooooo`03oc<0oooo
oooo<`3o03kooooo00?o0000ooooooooool0<?ooool2o`0000oooooo001<ooooo`03o`000?oooooo
oooo04_ooooo00?o0000ooooooooool08oooool00ol0ooooooooooooo`0Aooooo`03o`1Voooooooo
oooo00[ooooo0_lc0?l2ooooo`03oc<0oooooooooooo03gooooo00?o0000ooooooooool0<Oooool0
0ol0003oooooooooo`0<ooooo`00COooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo
027ooooo00?o0?ooooooooooool04Oooool00ol0I_ooooooooooo`09ooooo`;o<`3o0oooool00olc
0?ooooooooooo`0oooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool02oooool004ko
oooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0Nooooo`;o0?oo4_ooool2o`1Vo`_o
oooo00?o<`3oooooooooool00oooool00olc0?ooooooooooo`0oooooo`03o`000?oooooooooo037o
oooo00?o0000ooooooooool02oooool004oooooo00?o0000ooooooooool0Boooool00ol0003ooooo
ooooo`0Kooooo`;o0?oo4oooool00ol0I_ooooooooooo`09ooooo`;o<`3o1Oooool00olc0?oooooo
ooooo`11ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool02_ooool0053ooooo00?o
0000ooooooooool0Boooool00ol0003oooooooooo`0Hooooo`;o0?oo5?ooool00ol0I_oooooooooo
o`08ooooo`;o<`3o1_ooool00olc0?ooooooooooo`0;ooooo`03ol`0oooooooooooo03Gooooo00?o
0000ooooooooool0<Oooool00ol0003oooooooooo`09ooooo`00DOooool00ol0003oooooooooo`1;
ooooo`03o`000?oooooooooo01Gooooo0_l0oolEooooo`03o`1Voooooooooooo00Kooooo0olc0?l7
ooooo`03oc<0oooooooooooo00cooooo00?oc03oooooooooool0=_ooool00ol0003oooooooooo`0a
ooooo`03o`000?oooooooooo00Sooooo001Booooo`03o`000?oooooooooo04_ooooo00?o0000oooo
ooooool04oooool00ol0ooooooooooooo`0Cooooo`;o06Ko1_ooool3oc<0o`Wooooo00?o<`3ooooo
ooooool03?ooool00oo<0?ooooooooooo`0hooooo`03o`000?oooooooooo033ooooo00?o0000oooo
ooooool02?ooool005?ooooo0_l0001<ooooo`03o`000?oooooooooo013ooooo0_l0oolEooooo`03
o`1Voooooooo<`3o00Ko<`3o2oooool00olc0?ooooooooooo`0<ooooo`03ol`0oooooooooooo01Wo
oooo1Olc0?lLooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool01oooool005Gooooo
00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0=ooooo`;o0?oo2oooool>oc<0oa7ooooo
00?o<`3oooooooooool03?ooool2ol`0oa?ooooo2?lc0?lQooooo`03o`000?oooooooooo037ooooo
00?o0000ooooooooool01_ooool005Kooooo00?o0000ooooooooool0B_ooool00ol0003ooooooooo
o`0:ooooo`;o0?oo4oooool:oc<0o`kooooo00?o<`3oooooooooool03?ooool2ol`0o`gooooo1olc
0?lZooooo`03o`000?oooooooooo02oooooo0ol00007ooooo`00Eoooool00ol0003oooooooooo`1:
ooooo`03o`000?oooooooooo00Sooooo00?o0?ooooooooooool05Oooool00ol0I_ooooooooooo`05
ooooo`_o<`3o0_ooool00olc0?ooooooooooo`0<ooooo`;oc03o3_lc0?lbooooo`03o`000?oooooo
oooo02_ooooo0ol00002ooooo`03o`000?oooooooooo00Gooooo001Hooooo`03o`000?oooooooooo
04[ooooo00?o0000ooooooooool07_ooool00ol0I_ooooooooooo`0Aooooo`oo<`3o0_o<0?l00ooo
ooooc03oooooo`10ooooo`03o`000?oooooooooo02Oooooo0ol00005ooooo`03o`000?oooooooooo
00Gooooo001Iooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool07?ooool00ol0I_oo
ooooooooo`0Aooooo`;o<`3o3?ooool2ol`0o`;ooooo00?oc03oooooooooool0@Oooool00ol0003o
ooooooooo`0Rooooo`Co00002?ooool00ol0003oooooooooo`05ooooo`00F_ooool00ol0003ooooo
ooooo`1:ooooo`03o`000?oooooooooo01Wooooo0_l0I_lCooooo`03oc<0oooooooooooo00[ooooo
0_o<0?l3ooooo`03ol`0oooooooooooo04?ooooo00?o0000ooooooooool07_ooool3o`0000cooooo
00?o0000ooooooooool01Oooool005_ooooo00?o0000ooooooooool0B_ooool00ol0003ooooooooo
o`0Fooooo`;o06Ko5?ooool00olc0?ooooooooooo`09ooooo`;oc03o1?ooool00oo<0?oooooooooo
o`0<ooooo`;oo`2I=_ooool00ol0003oooooooooo`0Jooooo`Co00003oooool00ol0003ooooooooo
o`05ooooo`00G?ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo01?ooooo0_l0I_lE
ooooo`03oc<0oooooooooooo00Sooooo0_o<0?l5ooooo`03ol`0oooooooooooo00cooooo00?oo`2I
oooooooo09T0=oooool00ol0003oooooooooo`0Fooooo`?o00005?ooool00ol0003oooooooooo`04
ooooo`00GOooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo013ooooo0_l0I_lEoooo
o`;o<`3o2?ooool3ol`0o`Kooooo00?oc03oooooooooool03?ooool00ooo09Woooooool0V@0ioooo
o`03o`000?oooooooooo01;ooooo0ol0000Gooooo`03o`000?oooooooooo00Cooooo001Nooooo`;o
0000Boooool00ol0003oooooooooo`0>ooooo`03o`1Voooooooooooo01Cooooo00?o<`3ooooooooo
ool01?ooool4ol`0o`Wooooo00?oc03oooooooooool02oooool00ooo09Woooooool0V@0kooooo`03
o`000?oooooooooo00gooooo1?l0000Jooooo`03o`000?oooooooooo00Cooooo001Pooooo`03o`00
0?oooooooooo04Wooooo00?o0000ooooooooool02oooool2o`1VoaKooooo00?o<`3oooooooooool0
0_ooool3ol`0o`cooooo00?oc03oooooooooool02oooool01?oo09Wooooooooooooo09Tlooooo`03
o`000?oooooooooo00Wooooo0ol0000Nooooo`03o`000?oooooooooo00Cooooo001Qooooo`03o`00
0?oooooooooo04Wooooo00?o0000ooooooooool02?ooool2o`1VoaOooooo00?o<`3ool`0ooo<0?l0
0oo<0?l>ooooo`03ol`0oooooooooooo00_ooooo00Coo`2Iooooooooooooo`2I5_ooool5ol`0ob?o
oooo00?o0000ooooooooool01?ooool4o`00027ooooo00?o0000ooooooooool01?ooool006;ooooo
00?o0000ooooooooool0BOooool00ol0003oooooooooo`05ooooo`;o06Ko1Oooool8ol`0o`Oooooo
1_o<0?lBooooo`03ol`0oooooooooooo00_ooooo00Coo`2Iooooooooooooo`2I3oooool8ol`0obSo
oooo00Co0000oooooooooooooooo0ol0000Uooooo`03o`000?oooooooooo00Cooooo001Sooooo`03
o`000?oooooooooo04Wooooo00?o0000ooooooooool00oooool00ol0I_ooooooooooo`09ooooo`_o
c03o0_ooool00olc0?ooooooooooo`0Booooo`03ol`0oooooooooooo00[ooooo0_oo09T3ooooo`03
ool0VOoooooooooo00Gooooo2?o<0?laooooo`?o0000:?ooool00ol0003oooooooooo`04ooooo`00
I?ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo01?ooooo3Oo<0?l>ooooo`;oc03o
2?ooool3ol`0o`;oo`2I1?o<0?l00ooo09Woc03ool`0o`06ol`0ocGooooo1?l000000ooooooo0000
ooooo`0Xooooo`03o`000?oooooooooo00Cooooo001Uooooo`03o`000?oooooooooo04Wooooo00?o
0000ooooooooool06?ooool00olc0?ooooooooooo`04oooooaSoc03o00?oooooool0VOoo09T01Ooo
ool00ooo09Woooooooooo`0<ooooo`03ool00?oooooooooo02[ooooo0ol00006ooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool01?ooool006Kooooo00?o0000ooooooooool0BOooool0
0ol0003oooooooooo`0Eooooo`;o<`3o4oooool00oo<0?ooooooooooo`09ooooo`03ool0VOoooooo
oooo00Cooooo00?oo`2Iooooooooool03?ooool2ool002Sooooo1?l0000:ooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool01?ooool006Oooooo00?o0000ooooooooool0BOooool00ol0
003oooooooooo`0Booooo`;o<`3o4oooool2ol`0o`[ooooo0_oo09T6ooooo`03ool0VOoooooooooo
00_ooooo0ooo000Vooooo`?o00003oooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo
00?ooooo001Xooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool03oooool2oc<0oaCo
oooo00?oc03oooooooooool02?ooool2ool0V@Oooooo00?oo`2Iooooooooool02oooool00ooo003o
ooooool0000Tooooo`?o00004_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00?o
oooo001Yooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool03?ooool2oc<0oaGooooo
00?oc03oooooooooool01_ooool3ool0V@Sooooo00?oo`2Iooooooooool02oooool00ooo003ooooo
ool0000Qooooo`Co00005_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00?ooooo
001Zooooo`;o0000B_ooool00ol0003oooooooooo`09ooooo`;o<`3o5Oooool2ol`0o`Kooooo0ooo
09T:ooooo`03ool0VOoooooooooo00_ooooo00?oo`00oooooooo00007oooool3o`0001_ooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`03ooooo`00K?ooool00ol0003oooooooooo`18
ooooo`03o`000?oooooooooo00Kooooo0_lc0?lFooooo`03ol`0oooooooooooo00;ooooo1?oo09T<
ooooo`03ool0VOoooooooooo00_ooooo00?oo`00oooooooo00007?ooool4o`0001oooooo00?o0000
ooooooooool08_ooool00ol0003oooooooooo`03ooooo`00KOooool00ol0003oooooooooo`18oooo
o`03o`000?oooooooooo00?ooooo0_lc0?lGooooo`03ol`0oooooooooooo00?oo`2I3oooool00ooo
09Woooooooooo`0;ooooo`04ool00?ooooooooooool001Wooooo0ol0000Tooooo`03o`000?oooooo
oooo027ooooo00?o0000ooooooooool00oooool006kooooo00?o0000ooooooooool0B?ooool00ol0
003oooooooooo`02oc<0oaKooooo1_oo09TAooooo`03ool0VOoooooooooo00_ooooo00Coo`00oooo
ooooooooo`005oooool3o`0002Sooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`03
ooooo`00Koooool00ol0003oooooooooo`18ooooo`03o`000?lc0?oooooo013ooooo1ooo09T00oo<
0?ooooooooooo`0Booooo`;oo`2I3?ooool2ool000;ooooo00?oo`00ooooooooool04Oooool5ool0
VB_ooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`03ooooo`00L?ooool00ol0003o
ooooooooo`17oooooa?oo`2I1_ooool00oo<0?ooooooooooo`0Booooo`03ool0VOoooooooooo00[o
oooo0_oo0003ooooo`03ool00?oooooooooo00Wooooo2Ooo09T00ol0003oooooooooo`0^ooooo`03
o`000?oooooooooo01oooooo00?o0000ooooooooool00oooool0077ooooo00?o0000ooooooooool0
B?ooool00ol0003oooooooooo`02ooooo`_oo`2I1Oooool2ol`0oaCooooo00?oo`2Iooooooooool0
2Oooool2ool000Cooooo00?oo`00ooooooooool00_ooool8ool0V@?ooooo1?l0000dooooo`03o`00
0?oooooooooo01kooooo00?o0000ooooooooool00oooool007;ooooo00?o0000ooooooooool0B?oo
ool00ol0003oooooooooo`0<ooooo`coo`2I3Oooool2ool0V@Gooooo1Ooo09T2ool000Goo`2I00?o
o`00ool0VOoo09T00ooo09T8ooooo`?o0000>Oooool00ol0003oooooooooo`0Nooooo`03o`000?oo
oooooooo00;ooooo001cooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool03?ooool2
ol`0o`Wooooo5?oo09T4ooooo`03ool00?oooooooooo00Cooooo00?oo`00ooooooooool02Oooool3
o`0003gooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`02ooooo`00M?ooool00ol0
003oooooooooo`18ooooo`03o`000?oooooooooo00Wooooo0_o<0?lEooooo`;oo`2I2_ooool2ool0
00Kooooo00?oo`00ooooooooool01_ooool4o`00047ooooo00?o0000ooooooooool07?ooool00ol0
003oooooooooo`02ooooo`00MOooool2o`0004Wooooo00?o0000ooooooooool01_ooool2ol`0oaKo
oooo00?oo`2Iooooooooool02?ooool2ool000Oooooo00?oo`00ooooooooool01?ooool3o`0004Go
oooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`02ooooo`00Moooool00ol0003ooooo
ooooo`17ooooo`03o`000?oooooooooo00?ooooo0_o<0?lGooooo`03ool0VOoooooooooo00Kooooo
0ooo0008ooooo`04ool00?ooooooooooooooo`Co0000BOooool00ol0003oooooooooo`0Kooooo`03
o`000?oooooooooo00;ooooo001hooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool0
0_o<0?lGooooo`;oo`2I1_ooool3ool000[ooooo00?oo`00ooooool000000_l0001>ooooo`03o`00
0?oooooooooo01[ooooo00?o0000ooooooooool00_ooool007Wooooo00?o0000ooooooooool0Aooo
ool2ol`0oaSooooo00?oo`2Iooooooooool00oooool3ool000cooooo00?oo`00o`000?l00000D_oo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00;ooooo001jooooo`03o`000?oooooo
oooo04Cooooo0_o<0?l00ooooooo0000ooooo`0Eooooo`;oo`2I0oooool3ool000_ooooo0_l00002
ool005Kooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`02ooooo`00Noooool00ol0
003oooooooooo`12ooooo`03ol`0oooooooooooo00;ooooo00?o0000ooooooooool04_ooool00ooo
09Woooooooooo`03ool000_ooooo0ol000000oooooooo`00ooooo`1Hooooo`03o`000?oooooooooo
01Oooooo00?o0000ooooooooool00_ooool007cooooo00?o0000ooooooooool0Aoooool00ol0003o
ooooooooo`0>ooooo`Koo`002_ooool4o`0000?ooooo00?oo`00ooooooooool08Oooool5ool003;o
oooo00?o0000ooooooooool05oooool00ol0003oooooooooo`02ooooo`00OOooool00ol0003ooooo
ooooo`0hooooo`coo`000oooool00ol0003oooooooooo`04ooooo`Woo`000_oo09T;ooooo`?o0000
1Oooool2ool001_ooooo2Ooo000hooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
0Oooool007kooooo00?o0000ooooooooool0?_ooool?ool000Oooooo0_oo09T:ooooo`?o00001ooo
ool00ooo003oooooooooo`0Booooo`Woo`00@_ooool00ol0003oooooooooo`0Fooooo`03o`000?oo
oooooooo007ooooo001oooooo`03o`000?oooooooooo04Oooooo00?o0000oooooooo00003?oo0005
ooooo`Co00002Oooool00ooo003oooooool0000Cool004cooooo00?o0000ooooooooool05Oooool0
0ol0003oooooooooo`01ooooo`00P?ooool2o`0004Sooooo00?o0000ooooooooool01?ooool2ool0
V@Gooooo5?oo001Qooooo`03o`000?oooooooooo01Cooooo00?o0000ooooooooool00Oooool008;o
oooo00?o0000ooooooooool0A_ooool01?l0003oooooooooooooool2ool0V@Gooooo1?l0000=oooo
o`;oo`00IOooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo007ooooo0023ooooo`03
o`000?oooooooooo04Kooooo00?o0000ool0VOoo09T01?ooool3o`00013ooooo00?oo`00oooooooo
ool0IOooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo007ooooo0024ooooo`03o`00
0?oooooooooo04Cooooo0_oo09T00ol0003oooooooooo`03o`0001;ooooo00?oo`00ooooooooool0
Ioooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo007ooooo0025ooooo`03o`000?oo
oooooooo047ooooo0_oo09T3ooooo`;o00004oooool2ool006_ooooo00?o0000ooooooooool04Ooo
ool00ol0003oooooooooo`01ooooo`00Q_ooool00ol0003oooooooooo`0nooooo`;oo`2I1Oooool0
0ol0003oooooooooo`0Aooooo`03ool00?oooooooooo06cooooo00?o0000ooooooooool04?ooool0
0ol0003oooooooooo`01ooooo`00Qoooool00ol0003oooooooooo`0looooo`03ool0VOoooooooooo
00Gooooo00?o0000ooooooooool04?ooool00ooo003oooooooooo`1^ooooo`03o`000?oooooooooo
00oooooo00?o0000ooooooooool00Oooool008Sooooo00?o0000ooooooooool0@oooool00ol0003o
ooooooooo`0?ooooo`03ool00?oooooooooo073ooooo00?o0000ooooooooool03oooool1o`00007o
oooo0Oooool008Wooooo00?o0000ooooooooool0@_ooool00ol0003oooooooooo`0=ooooo`;oo`00
Loooool00ol0003oooooooooo`0?ooooo`7o00000Oooool1ooooo`00R_ooool00ol0003ooooooooo
o`11ooooo`03o`000?oooooooooo00_ooooo0_oo001fooooo`03o`000?oooooooooo00kooooo0Ol0
0001ooooo`7ooooo002;ooooo`;o0000@Oooool00ol0003oooooooooo`08ooooo`?oo`00NOooool0
0ol0003oooooooooo`0=ooooo`7o00000Oooool1ooooo`00SOooool00ol0003oooooooooo`0noooo
o`03o`000?oooooooooo00Kooooo0_oo001mooooo`03o`000?oooooooooo00cooooo0Ol00001oooo
o`7ooooo002>ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool01?ooool2ool0083o
oooo00?o0000ooooooooool02oooool1o`00007ooooo0Oooool008oooooo00?o0000ooooooooool0
??ooool00ol0003oooooooooo`02ooooo`;oo`00Poooool00ol0003oooooooooo`0:ooooo`7o0000
0Oooool1ooooo`00T?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo00;oo`00QOoo
ool00ol0003oooooooooo`0:ooooo`7o00000Oooool1ooooo`00TOooool00ol0003oooooooooo`0j
ooooo`?oo`00R?ooool00ol0003oooooooooo`09ooooo`7o00000Oooool1ooooo`00T_ooool00ol0
003oooooooooo`0gooooo`;oo`0000?o0000ooooooooool0ROooool00ol0003oooooooooo`08oooo
o`7o00000Oooool1ooooo`00Toooool00ol0003oooooooooo`0eooooo`04ool00?ooooooooooo`00
08cooooo00?o0000ooooooooool02?ooool1o`00007ooooo002Dooooo`03o`000?oooooooooo03Oo
oooo00?o0000ooooooooool0Roooool00ol0003oooooooooo`07ooooo`7o00000Oooool009Gooooo
00?o0000ooooooooool0=_ooool00ol0003oooooooooo`2<ooooo`03o`000?oooooooooo00Kooooo
0Ol00001ooooo`00U_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo08cooooo00?o
0000ooooooooool01_ooool1o`00007ooooo002Gooooo`;o0000=Oooool00ol0003oooooooooo`2=
ooooo`03o`000?oooooooooo00Gooooo0Ol00001ooooo`00VOooool00ol0003oooooooooo`0boooo
o`03o`000?oooooooooo08kooooo00?o0000ooooooooool01?ooool1o`00007ooooo002Jooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool0Soooool00ol0003oooooooooo`03ooooo`7o
00000Oooool009_ooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`2@ooooo`03o`00
0?oooooooooo00;ooooo0Ol00001ooooo`00W?ooool00ol0003oooooooooo`0_ooooo`03o`000?oo
oooooooo097ooooo00Go0000ooooooooooooooooo`000001ooooo`00WOooool00ol0003ooooooooo
o`0^ooooo`03o`000?oooooooooo097ooooo00Go0000ooooooooooooooooo`000001ooooo`00W_oo
ool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo09;ooooo00Co0000oooooooooooooooo
0Ol0000009oooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`2Cooooo`03o`000?oo
oooooooo007o0000002Pooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0U?ooool1
o`00007ooooo0Ol000000:7ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`2Eoooo
o`;o0000002Rooooo`;o0000:_ooool00ol0003oooooooooo`2Dooooo`?o0000002Tooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool0T?ooool4o`0000?ooooo002Uooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool0SOooool3o`0000Oooooo002Vooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0ROooool4o`0000[ooooo002Wooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool0QOooool4o`0000kooooo002Xooooo`03o`000?oooooooooo02?o
oooo00?o0000ooooooooool0P_ooool3o`0001;ooooo002Yooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool0O_ooool4o`0001Gooooo002Zooooo`03o`000?oooooooooo027ooooo00?o
0000ooooooooool0N_ooool4o`0001Wooooo002[ooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool0MOooool4o`0001gooooo002/ooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool0L_ooool3o`00027ooooo002]ooooo`;o00008?ooool00ol0003oooooooooo`1^ooooo`Co
00009?ooool00:oooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1Zooooo`Co0000
:?ooool00;3ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1Wooooo`?o0000;?oo
ool00;7ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Sooooo`Co0000;oooool0
0;;ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1Oooooo`Co0000<oooool00;?o
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1Looooo`?o0000=oooool00;Cooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`1Hooooo`Co0000>_ooool00;Gooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`1Dooooo`Co0000?_ooool00;Kooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`1@ooooo`Co0000@_ooool00;Oooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`1=ooooo`?o0000A_ooool00;Sooooo0_l0000Eooooo`03
o`000?oooooooooo04Wooooo1?l00019ooooo`00^_ooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo04Gooooo1?l0001=ooooo`00^oooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo04;ooooo0ol0001Aooooo`00_?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo03kooooo1?l0001Dooooo`00_Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
03[ooooo1?l0001Hooooo`00__ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03Ko
oooo1?l0001Looooo`00_oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03?ooooo
0ol0001Pooooo`00`?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02oooooo1?l0
001Sooooo`00`Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02_ooooo1?l0001W
ooooo`00`_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Sooooo0ol0001[oooo
o`00`oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02Cooooo1?l0001^ooooo`00
a?ooool2o`0000Wooooo00?o0000ooooooooool08?ooool4o`0007;ooooo0036ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool07Oooool3o`0007Kooooo0037ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool06Oooool4o`0007Wooooo0038ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool05Oooool4o`0007gooooo0039ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool04Oooool4o`00087ooooo003:ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool03_ooool3o`0008Gooooo003;ooooo`05o`000?ooooooooooooooool00000
3?ooool4o`0008Sooooo003<ooooo`04o`000?ooooooooooo`0000Sooooo1?l0002<ooooo`00cOoo
ool00ol0003oooooo`000005ooooo`?o0000T?ooool00<kooooo0_l000000ooooooo0000o`000002
o`0009?ooooo003?ooooo`;o0000Uoooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {330.375, 0}} -> {-0.0771432, -0.0315529, \
0.00350368, 0.00350368}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .92059 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-16 1.0763 -0.0263982 1.0763 [
[.01694 .18568 -11.9631 -9 ]
[.01694 .18568 .03693 0 ]
[.13793 .13897 -11.619 -9 ]
[.13793 .13897 .38095 0 ]
[.26292 .09073 -5.63752 -9 ]
[.26292 .09073 .36248 0 ]
[.39212 .04087 -5.46552 -9 ]
[.39212 .04087 .53448 0 ]
[.52574 -0.01069 -5.29351 -9 ]
[.52574 -0.01069 .70649 0 ]
[.58272 .04263 0 -6.19654 ]
[.58272 .04263 6 2.80346 ]
[.71715 .21863 0 -6.07114 ]
[.71715 .21863 6 2.92886 ]
[.83675 .37523 0 -5.963 ]
[.83675 .37523 6 3.037 ]
[.94385 .51546 0 -5.8688 ]
[.94385 .51546 6 3.1312 ]
[.01386 .20006 -12 -2.76892 ]
[.01386 .20006 0 6.23108 ]
[.00748 .25499 -24 -2.80073 ]
[.00748 .25499 0 6.19927 ]
[.00093 .31131 -6 -2.83339 ]
[.00093 .31131 0 6.16661 ]
[-0.00579 .36907 -18 -2.86695 ]
[-0.00579 .36907 0 6.13305 ]
[-0.01268 .42831 -6 -2.90143 ]
[-0.01268 .42831 0 6.09857 ]
[ 0 0 0 0 ]
[ 1 .92059 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02642 .19522 m
.53391 0 L
s
.02642 .19522 m
.03116 .2 L
s
[(-2)] .01694 .18568 .99384 1 Mshowa
.14712 .14879 m
.15172 .1537 L
s
[(-1)] .13793 .13897 .93651 1 Mshowa
.2718 .10083 m
.27624 .10588 L
s
[(0)] .26292 .09073 .87917 1 Mshowa
.40066 .05126 m
.40493 .05646 L
s
[(1)] .39212 .04087 .82184 1 Mshowa
.53391 0 m
.538 .00534 L
s
[(2)] .52574 -0.01069 .7645 1 Mshowa
.125 Mabswid
.05025 .18606 m
.05308 .18894 L
s
.07424 .17683 m
.07705 .17973 L
s
.09837 .16755 m
.10117 .17046 L
s
.12267 .1582 m
.12545 .16113 L
s
.17173 .13933 m
.17447 .14229 L
s
.19651 .1298 m
.19923 .13278 L
s
.22144 .1202 m
.22414 .1232 L
s
.24654 .11055 m
.24922 .11356 L
s
.29723 .09105 m
.29988 .0941 L
s
.32283 .0812 m
.32546 .08427 L
s
.3486 .07129 m
.35121 .07437 L
s
.37455 .06131 m
.37713 .06441 L
s
.42695 .04115 m
.4295 .04428 L
s
.45342 .03096 m
.45594 .03412 L
s
.48007 .02071 m
.48257 .02388 L
s
.5069 .01039 m
.50938 .01358 L
s
.25 Mabswid
.53391 0 m
.9804 .58403 L
s
.57014 .04738 m
.56384 .04975 L
s
[(0)] .58272 .04263 -1 .37701 Mshowa
.70445 .22307 m
.6981 .22529 L
s
[(2)] .71715 .21863 -1 .34914 Mshowa
.82396 .37939 m
.81756 .38147 L
s
[(4)] .83675 .37523 -1 .32511 Mshowa
.93098 .51938 m
.92454 .52134 L
s
[(6)] .94385 .51546 -1 .30418 Mshowa
.125 Mabswid
.60525 .09331 m
.60147 .09471 L
s
.63931 .13786 m
.63552 .13924 L
s
.67236 .1811 m
.66856 .18245 L
s
.73562 .26383 m
.7318 .26514 L
s
.7659 .30345 m
.76207 .30473 L
s
.79534 .34195 m
.7915 .34322 L
s
.85181 .41581 m
.84796 .41704 L
s
.87891 .45126 m
.87506 .45247 L
s
.90529 .48577 m
.90143 .48696 L
s
.95601 .55212 m
.95214 .55328 L
s
.25 Mabswid
.02642 .19522 m
0 .42381 L
s
.02642 .19522 m
.0327 .19281 L
s
[(-1)] .01386 .20006 1 -0.38468 Mshowa
.02006 .25024 m
.02635 .24786 L
s
[(-0.5)] .00748 .25499 1 -0.37762 Mshowa
.01354 .30664 m
.01985 .3043 L
s
[(0)] .00093 .31131 1 -0.37036 Mshowa
.00686 .36448 m
.01318 .36218 L
s
[(0.5)] -0.00579 .36907 1 -0.3629 Mshowa
0 .42381 m
.00634 .42156 L
s
[(1)] -0.01268 .42831 1 -0.35524 Mshowa
.125 Mabswid
.02516 .20612 m
.02893 .20468 L
s
.0239 .21707 m
.02767 .21563 L
s
.02262 .22807 m
.0264 .22664 L
s
.02135 .23913 m
.02512 .2377 L
s
.01877 .26141 m
.02255 .25999 L
s
.01747 .27263 m
.02125 .27122 L
s
.01617 .28391 m
.01995 .2825 L
s
.01486 .29525 m
.01864 .29384 L
s
.01222 .31809 m
.01601 .3167 L
s
.01089 .3296 m
.01468 .32821 L
s
.00955 .34117 m
.01334 .33978 L
s
.00821 .35279 m
.012 .35141 L
s
.0055 .37622 m
.0093 .37485 L
s
.00414 .38803 m
.00793 .38666 L
s
.00276 .39989 m
.00656 .39853 L
s
.00139 .41182 m
.00519 .41047 L
s
.25 Mabswid
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.54154 .92059 L
s
.54154 .92059 m
.5414 .7134 L
s
.5414 .7134 m
.02642 .19522 L
s
.53391 0 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.53391 0 m
.02642 .19522 L
s
.5414 .7134 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.54154 .92059 L
s
.54154 .92059 m
.5414 .7134 L
s
0 0 m
1 0 L
1 .92059 L
0 .92059 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.54851 .76605 m
.61002 .7349 L
s
1 0 .6 r
.53183 .73298 m
.59023 .70286 L
s
.8 0 1 r
.51515 .69988 m
.57044 .67086 L
s
.2 0 1 r
.49845 .66677 m
.55067 .63889 L
s
0 .4 1 r
.48175 .63365 m
.53091 .60694 L
s
0 1 1 r
.46504 .60051 m
.51117 .57502 L
s
0 1 .4 r
.44833 .56735 m
.49145 .54312 L
s
.2 1 0 r
.4316 .53418 m
.47174 .51125 L
s
.8 1 0 r
.41487 .50099 m
.45204 .4794 L
s
1 .6 0 r
.39813 .46779 m
.43237 .44758 L
s
.43237 .44758 m
.46107 .42331 L
s
.8 1 0 r
.45204 .4794 m
.48398 .45287 L
s
.2 1 0 r
.47174 .51125 m
.50696 .48251 L
s
0 1 .4 r
.49145 .54312 m
.53 .51223 L
s
0 1 1 r
.51117 .57502 m
.55311 .54204 L
s
0 .4 1 r
.53091 .60694 m
.57628 .57193 L
s
.2 0 1 r
.55067 .63889 m
.59951 .6019 L
s
.8 0 1 r
.57044 .67086 m
.62281 .63196 L
s
1 0 .6 r
.59023 .70286 m
.64618 .6621 L
s
1 0 0 r
.61002 .7349 m
.66959 .69234 L
s
1 .6 0 r
.46107 .42331 m
.47762 .4015 L
s
.8 1 0 r
.48398 .45287 m
.50269 .42864 L
s
1 0 0 r
.5825 .71783 m
.67955 .71477 L
s
.5007 .71195 m
.5825 .71783 L
s
.2 1 0 r
.50696 .48251 m
.52797 .45589 L
s
1 0 0 r
.67955 .71477 m
.76387 .70407 L
s
1 0 .6 r
.58366 .68068 m
.67564 .67774 L
s
.50651 .67505 m
.58366 .68068 L
s
0 1 .4 r
.53 .51223 m
.55339 .48326 L
s
1 0 0 r
.46634 .70708 m
.5007 .71195 L
s
1 0 .6 r
.67564 .67774 m
.7561 .66736 L
s
.8 0 1 r
.58486 .64341 m
.67174 .64058 L
s
.51238 .63804 m
.58486 .64341 L
s
1 0 0 r
.52988 .70996 m
.48277 .70892 L
s
.58818 .70313 m
.52988 .70996 L
s
.48277 .70892 m
.46634 .70708 L
s
0 1 1 r
.55311 .54204 m
.57894 .51077 L
s
1 0 .6 r
.47353 .67029 m
.50651 .67505 L
s
.8 0 1 r
.67174 .64058 m
.74832 .63055 L
s
.2 0 1 r
.58607 .60602 m
.66782 .60331 L
s
.51826 .60092 m
.58607 .60602 L
s
1 0 .6 r
.52792 .67271 m
.48688 .67179 L
s
.57897 .66663 m
.52792 .67271 L
s
0 .4 1 r
.57628 .57193 m
.60461 .53841 L
s
1 0 .6 r
.48688 .67179 m
.47353 .67029 L
s
.8 0 1 r
.48075 .6334 m
.51238 .63804 L
s
.2 0 1 r
.66782 .60331 m
.74051 .59363 L
s
1 0 0 r
.64412 .68667 m
.58818 .70313 L
s
1 .6 0 r
.47762 .4015 m
.48482 .38808 L
s
0 .4 1 r
.58728 .56851 m
.66389 .56592 L
s
.52416 .56368 m
.58728 .56851 L
s
.2 0 1 r
.59951 .6019 m
.63041 .56618 L
s
.8 0 1 r
.52596 .63533 m
.49101 .63454 L
s
.56974 .63003 m
.52596 .63533 L
s
.49101 .63454 m
.48075 .6334 L
s
.2 0 1 r
.48799 .5964 m
.51826 .60092 L
s
1 0 .6 r
.6279 .65199 m
.57897 .66663 L
s
0 .4 1 r
.66389 .56592 m
.73268 .55661 L
s
.8 0 1 r
.62281 .63196 m
.65633 .59409 L
s
0 1 1 r
.58849 .53087 m
.65996 .52841 L
s
.53008 .52633 m
.58849 .53087 L
s
.2 0 1 r
.52399 .59782 m
.49515 .59717 L
s
.56049 .59334 m
.52399 .59782 L
s
0 .4 1 r
.49526 .5593 m
.52416 .56368 L
s
.2 0 1 r
.49515 .59717 m
.48799 .5964 L
s
.8 0 1 r
.61166 .61728 m
.56974 .63003 L
s
.8 1 0 r
.50269 .42864 m
.51018 .41459 L
s
0 1 1 r
.65996 .52841 m
.72483 .51949 L
s
1 0 .6 r
.64618 .6621 m
.68238 .62214 L
s
0 .4 1 r
.52201 .5602 m
.49931 .55969 L
s
.55122 .55655 m
.52201 .5602 L
s
0 1 .4 r
.58971 .4931 m
.656 .49078 L
s
.53602 .48887 m
.58971 .4931 L
s
0 1 1 r
.50255 .52208 m
.53008 .52633 L
s
.2 0 1 r
.59542 .58254 m
.56049 .59334 L
s
0 .4 1 r
.49931 .55969 m
.49526 .5593 L
s
1 0 0 r
.66959 .69234 m
.70855 .65034 L
s
0 1 .4 r
.656 .49078 m
.71696 .48226 L
s
.2 1 0 r
.52797 .45589 m
.53601 .44114 L
s
0 .4 1 r
.57915 .54778 m
.55122 .55655 L
s
0 1 .4 r
.50985 .48477 m
.53602 .48887 L
s
1 .6 0 r
.48482 .38808 m
.48902 .38121 L
s
0 1 1 r
.52003 .52244 m
.50348 .52208 L
s
.54191 .51967 m
.52003 .52244 L
s
.2 1 0 r
.59093 .45521 m
.65204 .45303 L
s
.54197 .4513 m
.59093 .45521 L
s
0 1 1 r
.50348 .52208 m
.50255 .52208 L
s
.2 1 0 r
.65204 .45303 m
.70907 .44494 L
s
0 1 1 r
.56288 .51298 m
.54191 .51967 L
s
.2 1 0 r
.51717 .44734 m
.54197 .4513 L
s
1 0 0 r
.68825 .66316 m
.64412 .68667 L
s
0 1 .4 r
.50767 .48435 m
.50985 .48477 L
s
.51804 .48457 m
.50767 .48435 L
s
.53259 .48269 m
.51804 .48457 L
s
.8 1 0 r
.59216 .41719 m
.64806 .41515 L
s
.54793 .41361 m
.59216 .41719 L
s
1 0 .6 r
.66632 .63114 m
.6279 .65199 L
s
0 1 .4 r
.55339 .48326 m
.56206 .46781 L
s
.54659 .47815 m
.53259 .48269 L
s
.8 0 1 r
.64444 .59918 m
.61166 .61728 L
s
.8 1 0 r
.64806 .41515 m
.70116 .4075 L
s
1 .6 0 r
.48902 .38121 m
.4931 .37702 L
s
.8 1 0 r
.51018 .41459 m
.51306 .40957 L
s
.2 0 1 r
.62259 .56727 m
.59542 .58254 L
s
.2 1 0 r
.51185 .44651 m
.51717 .44734 L
s
.8 1 0 r
.52443 .40984 m
.54793 .41361 L
s
0 .4 1 r
.60077 .53541 m
.57915 .54778 L
s
.2 1 0 r
.51604 .44657 m
.51185 .44651 L
s
.52324 .44562 m
.51604 .44657 L
s
1 .6 0 r
.59339 .37904 m
.64407 .37716 L
s
.55381 .37585 m
.59339 .37904 L
s
.2 1 0 r
.53029 .4433 m
.52324 .44562 L
s
0 1 1 r
.57899 .5036 m
.56288 .51298 L
s
1 .6 0 r
.64407 .37716 m
.69322 .36996 L
s
.4931 .37702 m
.49827 .37388 L
s
0 1 .4 r
.55725 .47185 m
.54659 .47815 L
s
.8 1 0 r
.51596 .4086 m
.52443 .40984 L
s
1 .6 0 r
.53138 .37235 m
.55381 .37585 L
s
.8 1 0 r
.51306 .40957 m
.514 .40851 L
s
.2 1 0 r
.53555 .44014 m
.53029 .4433 L
s
0 1 1 r
.57894 .51077 m
.58827 .49463 L
s
.8 1 0 r
.51399 .40851 m
.51596 .4086 L
s
.51389 .40851 m
.51399 .40851 L
s
.51405 .40846 m
.51389 .40851 L
s
.514 .40851 m
.51405 .40846 L
s
1 .6 0 r
.49827 .37388 m
.50466 .37171 L
s
.2 1 0 r
.53601 .44114 m
.53776 .43797 L
s
.53776 .43797 m
.53555 .44014 L
s
1 .6 0 r
.51967 .37082 m
.53138 .37235 L
s
.50466 .37171 m
.51173 .3707 L
s
.51173 .3707 m
.51967 .37082 L
s
0 1 .4 r
.56269 .46648 m
.55725 .47185 L
s
0 .4 1 r
.60461 .53841 m
.61463 .52159 L
s
0 1 1 r
.58774 .4951 m
.57899 .5036 L
s
0 1 .4 r
.56206 .46781 m
.56269 .46648 L
s
0 .4 1 r
.61289 .52383 m
.60077 .53541 L
s
.2 0 1 r
.63814 .55269 m
.62259 .56727 L
s
.63041 .56618 m
.64113 .5487 L
s
.8 0 1 r
.6635 .58166 m
.64444 .59918 L
s
1 0 .6 r
.68897 .61076 m
.66632 .63114 L
s
0 1 1 r
.58827 .49463 m
.58774 .4951 L
s
1 0 0 r
.71454 .63998 m
.68825 .66316 L
s
.8 0 1 r
.65633 .59409 m
.66778 .57597 L
s
0 .4 1 r
.61463 .52159 m
.61289 .52383 L
s
1 0 .6 r
.68238 .62214 m
.69457 .60338 L
s
.2 0 1 r
.64113 .5487 m
.63814 .55269 L
s
1 0 0 r
.70855 .65034 m
.72152 .63096 L
s
.8 0 1 r
.66778 .57597 m
.6635 .58166 L
s
1 0 .6 r
.69457 .60338 m
.68897 .61076 L
s
1 0 0 r
.72152 .63096 m
.71454 .63998 L
s
0 g
.25 Mabswid
.53391 0 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.53391 0 m
.02642 .19522 L
s
.02642 .19522 m
.53391 0 L
s
.02642 .19522 m
.03116 .2 L
s
[(-2)] .01694 .18568 .99384 1 Mshowa
.14712 .14879 m
.15172 .1537 L
s
[(-1)] .13793 .13897 .93651 1 Mshowa
.2718 .10083 m
.27624 .10588 L
s
[(0)] .26292 .09073 .87917 1 Mshowa
.40066 .05126 m
.40493 .05646 L
s
[(1)] .39212 .04087 .82184 1 Mshowa
.53391 0 m
.538 .00534 L
s
[(2)] .52574 -0.01069 .7645 1 Mshowa
.125 Mabswid
.05025 .18606 m
.05308 .18894 L
s
.07424 .17683 m
.07705 .17973 L
s
.09837 .16755 m
.10117 .17046 L
s
.12267 .1582 m
.12545 .16113 L
s
.17173 .13933 m
.17447 .14229 L
s
.19651 .1298 m
.19923 .13278 L
s
.22144 .1202 m
.22414 .1232 L
s
.24654 .11055 m
.24922 .11356 L
s
.29723 .09105 m
.29988 .0941 L
s
.32283 .0812 m
.32546 .08427 L
s
.3486 .07129 m
.35121 .07437 L
s
.37455 .06131 m
.37713 .06441 L
s
.42695 .04115 m
.4295 .04428 L
s
.45342 .03096 m
.45594 .03412 L
s
.48007 .02071 m
.48257 .02388 L
s
.5069 .01039 m
.50938 .01358 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 265.125},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001Bb000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00`oooool5o`000:3ooooo0033ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@0X?ooool00<Cooooo00?oV9RHob4Q8Oo^k^h0XOooool00<Gooooo00?oV9RH
ob4Q8Oo^k^h0X?ooool00<Kooooo00?oMgMgofIVI_ooool0Woooool00<Oooooo00?o0000oooooooo
ool0W_ooool00<?ooooo00Go0000okZj^_ooooooV9RHoa0@402Pooooo`00`oooool01OnHV9So410@
o`000?lQ8B7oc<c<0:3ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003;ooooo`;o0000Voooool00<Sooooo0ol000000ooooooo0000ooooo`2Jooooo`00a_oo
ool2o`0000Cooooo0_l0002Jooooo`00`oooool3o`0000Kooooo00?o0000ooooool00000VOooool0
0<3ooooo1?l00008ooooo`04o`000?ooooooooooo`0009Sooooo002Hooooo`Co000000?o410@oooo
ooooool07oooool2o`0000Cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0002H
ooooo`00V_ooool00ol0003oooooooooo`0Nooooo`?o00003_ooool01Ol0003ooooooooooooooooo
000009Oooooo002Jooooo`03o`000?oooooooooo01cooooo0_l0000Aooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0U?ooool009[ooooo00?o0000ooooooooool06Oooool3o`0000;o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo09?o
oooo002Jooooo`03o`000?oooooooooo01Kooooo0ol0000Fooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^08Kooooo002Jooooo`03o`00
0?oooooooooo01Cooooo0_l0000Iooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1oooool01OmgMgOoV9RHoooooonHV9SoMgMg08Kooooo002Jooooo`03o`000?oooooooooo017ooooo
0ol000000ooooooo0000ooooo`0Hooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1_ooool01Ol@413ooooooooooooooooo410@08Kooooo002Hooooo`03oeEEEOmVIVKo0000017ooooo
0_l0000Nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool01Ol0003ooooo
oooooooooooo000008Kooooo002Yooooo`?o00008?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000026ooooo`00Yoooool3o`0002;ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@
4100Q_ooool00:Cooooo0ol00002ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Q_ooool00:7ooooo
0ol0000Xooooo`03o`000?oooooooooo00Sooooo0_l00004ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h0Q_ooool009oooooo0_l0000[ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo
0000S_ooool009cooooo0ol000000ooooooo0000ooooo`0Zooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0S?ooool009[ooooo0_l00005ooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`2;ooooo`00Uoooool3o`0003;ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`2:ooooo`00K?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^02?ooooo0ol000000ooooooo0000ooooo`0booooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0ROooool006cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Qooooo`;o0000>?ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo08Wooooo001/ooooo`05oa0@4?oooooooooo
ooooool@41007_ooool3o`0003[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`28
ooooo`00K?ooool01Ol0003ooooooooooooooooo000001cooooo0ol0000looooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0Qoooool006cooooo00Go0000ooooooooooooooooo`00000I
ooooo`?o00000_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool0Q_ooool006cooooo00Go410@oooooooooooooooooa0@400Gooooo`;o0000@_ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo08Kooooo001/ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL05?ooool3o`0004Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`25
ooooo`00K?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^017ooooo0ol00002ooooo`03o`000?oooooo
oooo04;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`24ooooo`00P?ooool2o`00
04[ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`23ooooo`00OOooool3o`0004co
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`22ooooo`00Noooool2o`000003oooo
ool0003ooooo04cooooo00?o0000ooooooooool05?ooool2o`0008?ooooo001hooooo`?o0000DOoo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooo000008?ooooo001eooooo`?o0000E?ooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo083ooooo001cooooo`Co0000EOooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo07oooooo001`ooooo`?o00001?ooool00ol0003o
ooooooooo`1Booooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0Ooooool006kooooo
0_l0001Looooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0O_ooool004?ooooo1?l0
00000ol@413oooooooooo`0Qooooo`?o0000G_ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo07gooooo0015ooooo`03o`000?oooooooooo023ooooo0ol00003ooooo`03o`000?oooooo
oooo05_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1looooo`00>_ooool6o`00
00Gooooo00?o0000ooooooooool07_ooool2o`0006Cooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`1looooo`00AOooool00ol0003oooooooooo`0Kooooo`?o0000I_ooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo07_ooooo0015ooooo`03o`000?oooooooooo01Wooooo
0_l00002ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`1jooooo`00AOooool00ol0003oooooooooo`0Fooooo`?o0000Joooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo07Wooooo0015ooooo`03o`000?oooooooooo01Cooooo0_l0001^
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0NOooool004?ooooo00?oEEEEofIV
I_l000004oooool3o`000003ooooool0003ooooo06gooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`1hooooo`00E_ooool3o`0007?ooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`1gooooo`00E?ooool2o`0007Kooooo00?o0000ooooooooool07oooool2o`0007Sooooo
001Aooooo`?o000000?oooooo`000?ooool0MOooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo07Kooooo001?ooooo`;o0000Noooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo07Gooooo001<ooooo`?o0000OOooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
07Cooooo0019ooooo`Co0000Ooooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo07?o
oooo0017ooooo`;o00001?ooool00ol0003oooooooooo`1looooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool0L_ooool004Cooooo0ol00025ooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool0L_ooool001[ooooo1Ol0000Sooooo`?o0000Qoooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo077ooooo000Jooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@08?ooool3
o`0000?ooooo00?o0000ooooooooool0Q?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo073ooooo000Booooo`Ko00000oooool00onHV9So8B4Qonk^kP0Oooooo`;o0000SOooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo06oooooo000Looooo`03oiRHV?lQ8B7ok^k^01_o
oooo0ol0002?ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0Koooool001gooooo
00?oMgMgofIVI_ooool05oooool3o`0000?ooooo00?o0000ooooooooool0S?ooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooooooo06kooooo000Nooooo`03o`000?oooooooooo01Cooooo0_l0
002Eooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0KOooool001[ooooo00Go0000
okZj^_ooooooV9RHoa0@400Cooooo`?o0000Uoooool00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo06cooooo000Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`04Oooool2o`0000?ooooo00?o
0000ooooooooool0U?ooool00ol0003oooooooooo`0Zooooo`;o0000KOooool002gooooo0ol0002L
ooooo`03o`000?oooooooooo02[ooooo0_l0001]ooooo`00:_ooool3o`0009oooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`1Zooooo`00:?ooool2o`0000?ooooo00?o0000oooooooo
ool0W?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo06Wooooo000Uooooo`?o0000
Y?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo06Wooooo000Tooooo`03o`000?oo
oooooooo0:Gooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1Xooooo`006_ooool4
o`000003oa0@4?oooooooooo00?ooooo0_l0002Vooooo`03o`000?oooooooooo02oooooo00?o0000
ooooooooool0Ioooool001cooooo00?o0000ooooooooool01Oooool2o`000:Kooooo00?o0000oooo
ooooool0<?ooool00ol0003oooooooooo`1Vooooo`004Oooool6o`0000Gooooo00?o0000oooooooo
ool01?ooool4o`000:Gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`08ooooo`Go
0000FOooool001cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0002Tooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool01OnHV9So8B4Qonk^k_ooooooA4A4
05Wooooo000Looooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`2Qooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool01oooool00onHV9So
8B4Qonk^kP1Jooooo`007?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0X?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Oooooo
00?oV9RHob4Q8Oo^k^h0FOooool001cooooo00?o0000ooooooooool01?ooool2o`0000Gooooo00?o
0000ooooooooool0Woooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Oooooo00?o
MgMgofIVI_ooool0F?ooool001[ooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo09kooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo05Oooooo000Sooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0WOooool00ol0003oooooooooo`0eooooo`;o00001?ooool01Ol0003o^[ZjoooooonHV9So
410@05Wooooo000Sooooo`;o00002?ooool00ol0003oooooooooo`2Looooo`03o`000?oooooooooo
03?ooooo0_l000000ooooooo0000ooooo`03ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0FOooool0
02?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2Kooooo`03o`000?oooooooooo
03Oooooo00?o0000ooooooooool0Goooool002?ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`2Jooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0Goooool002?ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`2Hooooo`;o0000>_ooool00ol0003ooooo
ooooo`1Nooooo`008_ooool2o`0000gooooo00?o0000ooooooooool0U?ooool3o`000003ooooool0
003ooooo03[ooooo00?o0000ooooooooool0GOooool002;ooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`2@ooooo`?o00001Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooo
oooo05cooooo000Rooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0S?ooool3o`00
00Wooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1Looooo`008_ooool3o`0000oo
oooo00?o0000ooooooooool0R?ooool3o`0000gooooo00?o0000ooooooooool0>?ooool00ol0003o
ooooooooo`1Kooooo`008_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo08Gooooo
0_l0000Aooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0F_ooool002;ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`21ooooo`?o00005?ooool00ol0003ooooooooo
o`0hooooo`03o`000?oooooooooo05Wooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool0OOooool3o`0001Oooooo00?o0000ooooooooool0>?ooool00ol0003ooooo
ooooo`1Iooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1iooooo`?o0000
6oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo05Sooooo0005o`0000;ooooo00Go
410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`1eooooo`?o00007oooool00ol0003oooooooooo`0hooooo`03o`00
0?oooooooooo05Oooooo0007ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8b
ooooo`03ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0LOooool3o`0002?ooooo
00?o0000ooooooooool0=oooool2o`0005Sooooo0007ooooo`05o`000?ooooooooooooooool00000
3?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`1^ooooo`;o00009oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo05Go
oooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`;o
00006Oooool00ol0003oooooooooo`1Zooooo`?o0000:_ooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo05Gooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0I_ooool3o`0002go
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1Dooooo`001oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool0H_ooool3o`00037ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1Cooooo`00
8Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo05kooooo0ol0000eooooo`03o`00
0?oooooooooo03Sooooo00?o0000ooooooooool0D_ooool0023ooooo0ol0000Mooooo`03o`000?oo
oooooooo05_ooooo0_l0000iooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0D_oo
ool0027ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1Gooooo`?o0000??ooool0
0ol0003oooooooooo`0gooooo`03o`000?oooooooooo057ooooo000Pooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool0Doooool3o`00043ooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`1@ooooo`008?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo04oo
oooo0ol00013ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0Coooool0023ooooo
0_l0000Rooooo`03o`000?oooooooooo04_ooooo0ol00017ooooo`03o`000?oooooooooo03Oooooo
00?o0000ooooooooool0Coooool0023ooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`18ooooo`;o0000Boooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo04kooooo000P
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0A?ooool3o`0004kooooo00?o0000
ooooooooool0=oooool00ol0003oooooooooo`1=ooooo`008?ooool3o`0002Cooooo00?o0000oooo
ooooool0@?ooool3o`0005;ooooo00?o0000ooooooooool0=_ooool2o`0004kooooo000Pooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0??ooool3o`0005Kooooo00?o0000oooooooo
ool0=_ooool00ol0003oooooooooo`1<ooooo`005?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oo
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0hooooo`?o0000FOooool00ol0003o
ooooooooo`0gooooo`03o`000?oooooooooo04_ooooo000Dooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo03Gooooo0_l0001Mooooo`03
o`000?oooooooooo03Oooooo00?o0000ooooooooool0B_ooool001Cooooo00Go410@oooooooooooo
oooooa0@4006ooooo`;o0000:_ooool00ol0003oooooooooo`0aooooo`?o0000H?ooool00ol0003o
ooooooooo`0gooooo`03o`000?oooooooooo04Wooooo000Dooooo`05o`000?ooooooooooooooool0
00001_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo02gooooo0ol0001Tooooo`03
o`000?oooooooooo03Kooooo00?o0000ooooooooool0BOooool001Cooooo00Go0000oooooooooooo
ooooo`000006ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0:Oooool3o`0006So
oooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`18ooooo`005?ooool01Ol@413ooooo
oooooooooooo410@00Kooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Uooooo`?o
0000K?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo04Oooooo000Dooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool2o`0002kooooo00?o0000ooooooooool08Oooool3o`0006oo
oooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`16ooooo`005?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Nooooo`;o
0000Loooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo04Gooooo000Oooooo`03o`00
0?oooooooooo02oooooo00?o0000ooooooooool06_ooool3o`0007Kooooo00?o0000ooooooooool0
=_ooool00ol0003oooooooooo`15ooooo`007_ooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo01Kooooo0ol0001jooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0A?oo
ool001kooooo0_l0000cooooo`03o`000?oooooooooo01;ooooo0ol0001nooooo`03o`000?oooooo
oooo03Kooooo0_l00014ooooo`007_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo
00kooooo0ol00022ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooool00000A?ooool001ko
oooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0;ooooo`;o0000QOooool00ol0003o
ooooooooo`0fooooo`03o`000?oooooooooo04;ooooo000Nooooo`03o`000?oooooooooo03Gooooo
00?o0000ooooooooool01oooool3o`0008Sooooo00?o0000ooooooooool0=_ooool00ol0003ooooo
ooooo`11ooooo`007_ooool2o`0003Oooooo00?o0000ooooooooool00oooool3o`0008cooooo00?o
0000ooooooooool0=_ooool00ol0003oooooooooo`10ooooo`007_ooool00ol0003oooooooooo`0g
ooooo`03o`000?oooooo000000;o0000T?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooo
oooo03oooooo000Nooooo`03o`000?oooooooooo03Kooooo0ol0002Dooooo`03o`000?oooooooooo
03Gooooo00?o0000ooooooooool0?oooool001kooooo0_l0000eooooo`;o00000oooool00ol0003o
ooooooooo`2Booooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool02Oooool2o`000003
oa0@4?oooooooooo033ooooo000Mooooo`03o`000?oooooooooo03;ooooo0ol00006ooooo`03o`00
0?oooooooooo097ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo037ooooo0002ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo
00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo02oooooo0ol0000:ooooo`03
o`000?oooooooooo097ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`05ooooo`Go
0000<_ooool000;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo
<S8booooo`04ooooo`03o`000?oooooooooo02cooooo0ol0000>ooooo`03o`000?oooooooooo067o
oooo2OooV@0Wooooo`03o`000?oooooooooo00Wooooo1OooV@0Wooooo`03o`000?oooooooooo00Go
oooo00CoA4A4omgMgOoooooo0000<oooool000;ooooo00Go410@oooooooooooooooooa0@400@oooo
o`03o`000?oooooooooo00?ooooo0_l0000Zooooo`?o00004_ooool00ol0003oooooooooo`1Noooo
o`;ooiT02Oooool6oonI02;ooooo00?o0000ooooooooool02?ooV@0]ooooo`03o`000?oooooooooo
00Cooooo00CogMgMoeEEEOoooooo0000<oooool000;ooooo00Go0000ooooooooooooooooo`00000?
ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool09oooool2o`0001Kooooo00?o0000
ooooooooool0G?ooool00oooV@3oooooooooo`0?ooooo`_ooiT03_ooool:oonI0003o`000?ooV@3o
oooo03Gooooo00?o0000ooooooooool01?ooool00omgMgOoc<c<o`00000cooooo`000_ooool01Ol0
003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c005ooooo`03o`000?oo
oooooooo02Cooooo0ol0000Iooooo`03o`000?oooooooooo05[ooooo00?ooiT0ooooooooool06ooo
ool>oonI00_ooooo00?o0000ooooooooool0=?ooool2o`0000Gooooo00?ok^k^odA4A?l00000<ooo
ool000;ooooo00Go410@oooooooooooooooooa0@400<ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool08Oooool3o`0001gooooo00?o0000ooooooooool0FOooool00oooV@3ooooooooo
o`0dooooo`03o`000?oooooooooo03?ooooo00Co0000oooooooooooo00001Oooool00omgMgOo0000
ooooo`0booooo`000_ooool01OmgMgOoV9RHoooooonHV9SoMgMg00cooooo00?o0000ooooooooool0
1oooool2o`0001oooooo0ol0000Qooooo`03o`000?oooooooooo05Oooooo00?ooiT0ooooooooool0
=_ooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo03Sooooo0002ooooo`05onk^k_lb
<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo00?o0000ooooooooool07?ooool3o`0002Gooooo
00?o0000ooooooooool0E_ooool00oooV@3oooooooooo`0gooooo`03o`000?oooooooooo03Gooooo
00?o0000ooooooooool0=oooool001cooooo00?o0000ooooooooool06Oooool3o`0002Wooooo00?o
0000ooooooooool0EOooool00oooV@3oooooooooo`0hooooo`03o`000?oooooooooo03Gooooo00?o
0000ooooooooool0=_ooool001cooooo00?o0000ooooooooool05oooool2o`0002gooooo00?o0000
ooooooooool0Doooool00oooV@3oooooooooo`0jooooo`03o`000?oooooooooo03Gooooo00?o0000
ooooooooool0=Oooool001cooooo0_l0000Eooooo`?o0000<?ooool00ol0003oooooooooo`1Aoooo
o`03oonI0?oooooooooo03cooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0eoooo
o`007?ooool00ol0003oooooooooo`0Aooooo`?o0000=?ooool00ol0003oooooooooo`1?ooooo`03
oonI0?oooooooooo03gooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0dooooo`00
7?ooool00ol0003oooooooooo`0>ooooo`?o0000>?ooool00ol0003oooooooooo`1>ooooo`03oonI
0?oooooooooo03kooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0cooooo`007?oo
ool00ol0003oooooooooo`0;ooooo`?o0000??ooool00ol0003oooooooooo`1<ooooo`03oonI0?oo
oooooooo00_ooooo00?oc?l0ooooooooool0<_ooool00ol0003oooooooooo`02ooooo`Coc?l0;ooo
ool00ol0003oooooooooo`0booooo`007?ooool2o`0000[ooooo0_l00010ooooo`03o`000?oooooo
oooo04[ooooo00?ooiT0ooooooooool02oooool9olco02cooooo0_o<o`001?l0003oc?l0olco0?o<
o`0cooooo`03o`000?oooooooooo03;ooooo000Kooooo`;o00002?ooool3o`0004?ooooo00?o0000
ooooooooool0B?ooool00oooV@3oooooooooo`0<ooooo`03olco0?oooooooooo00Kooooo2oo<o`0L
ooooo`Goc?l00oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo037ooooo000Koooo
o`03o`000?oooooooooo00Cooooo0ol00017ooooo`03o`000?oooooooooo04Oooooo00?ooiT0oooo
ooooool02oooool00oo<o`3oooooooooo`0Boooooacoc?l02Oooool00ol0003oooooooooo`0coooo
o`;o0000<_ooool001_ooooo00Co0000oooooooooooooooo0ol0001;ooooo`03o`000?oooooooooo
04Gooooo00?ooiT0ooooooooool03?ooool00oo<o`3oooooooooo`0gooooo`03o`000?oooooooooo
03Gooooo00?o0000ooooooooool0;oooool001_ooooo1?l0001?ooooo`03o`000?oooooooooo04;o
oooo0_ooV@0>ooooo`03olco0?oooooooooo03Wooooo00?o0000ooooooooool0=?ooool00ol0003o
ooooooooo`0_ooooo`006oooool2o`0005;ooooo00?o0000ooooooooool0@?ooool00oooV@3ooooo
ooooo`0>ooooo`03olco0?oooooooooo03[ooooo00?o0000ooooooooool0=?ooool00ol0003ooooo
ooooo`0^ooooo`004Oooool4o`000003oa0@4?oooooooooo00Gooooo00?o0000ooooooooool0D?oo
ool00ol0003oooooooooo`0nooooo`03oonI0?oooooooooo00kooooo00?oc?l0ooooooooool0??oo
ool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02gooooo000Cooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0looooo`03oonI0?oooooo
oooo00oooooo00?oc?l0ooooooooool0?Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooo
oooo02cooooo000Cooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0D?ooool00ol0
003oooooooooo`0iooooo`;ooiT04Oooool00oo<o`3oooooooooo`0oooooo`03o`000?oooooooooo
03?ooooo00?o0000ooooooooool0;?ooool001?ooooo00?o0000ooooooooool02_ooool00ol0003o
ooooooooo`1@ooooo`03o`000?oooooooooo03Oooooo00?ooiT0ooooooooool04?ooool00oo<o`3o
ooooooooo`0:ooooo`03oc?o0?oooooooooo03?ooooo00?o0000ooooooooool0=?ooool00ol0003o
ooooooooo`0[ooooo`004oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo053ooooo
00?o0000ooooooooool0=Oooool00oooV@3oooooooooo`0@ooooo`03olco0?oooooooooo00[ooooo
0_lco`0fooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0:_ooool001?ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo03?ooooo00?o
oiT0ooooooooool04?ooool00oo<o`3oooooooooo`09ooooo`;o<ol000?ooooooc?o0?ooool0=_oo
ool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02Wooooo000Cooooo`03o`000?oooooo
oooo00gooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`0`ooooo`;ooiT04_ooool0
0oo<o`3oooooooooo`05ooooo`Go<ol00_ooool00olco`3oooooooooo`0booooo`Go<ol000?o0000
ooooooooool0=?ooool00ol0003oooooooooo`0Xooooo`004Oooool00omEEEGoIVIVo`00000@oooo
o`03o`000?oooooooooo053ooooo00?o0000ooooooooool0;_ooool00oooV@3oooooooooo`0Aoooo
o`03olco0?oooooooooo00[ooooo1Olco`0Zooooo`Wo<ol01_ooool00ol0003oooooooooo`0coooo
o`03o`000?oooooooooo02Sooooo000Uooooo`03o`000?oooooooooo053ooooo00?o0000oooooooo
ool0:oooool2oonI01;ooooo0_o<o`0?ooooo`03oc?o0?oooooooooo00[o<ol04Oooool?oc?o013o
oooo00?o0000ooooooooool0<_ooool2o`0002Wooooo000Vooooo`;o0000DOooool00ol0003ooooo
ooooo`0Xooooo`;ooiT04oooool00oo<o`3oooooooooo`0>ooooo`03oc?o0?oooooooooo00_ooooo
4Olco`0Oooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool09_ooool002Sooooo00?o
0000ooooooooool0C_ooool00ol0003oooooooooo`0Wooooo`03oonI0?oooooooooo01;ooooo00?o
c?l0ooooooooool03oooool00olco`3oooooooooo`0looooo`03o`000?oooooooooo03Cooooo00?o
0000ooooooooool09Oooool002Wooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0T
ooooo`;ooiT05?ooool00oo<o`3oooooooooo`0?ooooo`03oc?o0?oooooooooo03kooooo00?o0000
ooooooooool0<oooool00ol0003oooooooooo`0Uooooo`00:_ooool00ol0003oooooooooo`1>oooo
o`03o`000?oooooooooo02;ooooo00?ooiT0ooooooooool04oooool00oo<o`3oooooooooo`0?oooo
o`03oc?o0?oooooooooo043ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Toooo
o`00:oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo023ooooo00?ooiT0oooooooo
ool04oooool00oo<o`3oooooooooo`0?ooooo`03oc?o0?oooooooooo00_ooooo0_l0ofHeooooo`03
o`000?oooooooooo03?ooooo00?o0000ooooooooool08oooool002cooooo00?o0000ooooooooool0
C_ooool00ol0003oooooooooo`0dooooo`03olco0?oooooooooo00oooooo00?o<ol0ooooooooool0
3?ooool00ol0ofKoooooooooo`0eooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0
8_ooool002gooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0booooo`03olco0?oo
oooooooo013ooooo00?o<ol0ooooooooool02_ooool2o`3oISSooooo00?o0000ooooooooool0<ooo
ool00ol0003oooooooooo`0Rooooo`00;_ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooo
oooo033ooooo00?oc?l0ooooooooool04?ooool00olco`3oooooooooo`09ooooo`?o0?mV>_ooool0
0ol0003oooooooooo`0cooooo`03o`000?oooooooooo027ooooo000_ooooo`03o`000?oooooooooo
04kooooo00?o0000ooooooooool0;Oooool2olco01;ooooo00?o<ol0ooooooooool01oooool3o`3o
IP;ooooo00?o0?mVooooooooool0>Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo
023ooooo000`ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0:_ooool2olco01;o
oooo0_lco`06ooooo`Co0?mV1?ooool00ol0ofKoooooooooo`0aooooo`Co0?mV1_ooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo01oooooo000aooooo`;o0000Coooool00ol0003ooooo
ooooo`0Xooooo`03olco0?oooooooooo017ooooo00?o<ol0ooooool0ofH01_l0ofH8ooooo`03o`3o
I_oooooooooo02[ooooo1ol0ofH;ooooo`03o`000?oooooooooo03;ooooo0_l0000Pooooo`00<ooo
ool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo02Gooooo0_o<o`0Cooooo`03oc?o0?oo
oooooooo00Oooooo2?l0ofHVooooo`Oo0?mV4oooool00ol0003oooooooooo`0aooooo`;o00008?oo
ool003Cooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0Rooooo`;oc?l05?ooool0
0olco`3oooooooooo`0>ooooo`03o`3oI_oooooo0?mV00So0?mV3_ooool?o`3oIQ[ooooo00?o0000
ooooooooool0<oooool00ol0003oooooooooo`0Mooooo`00=Oooool00ol0003oooooooooo`1=oooo
o`03o`000?oooooooooo023ooooo00?oc?l0ooooooooool04oooool00olco`3oooooooooo`0?oooo
o`03o`3oI_oooooooooo00Sooooo0ol0ofH00ol0oooo0?mVo`3oIP08o`3oIR[ooooo00?o0000oooo
ooooool0<oooool00ol0003oooooooooo`0Looooo`00=_ooool00ol0003oooooooooo`1=ooooo`03
o`000?oooooooooo01gooooo0_o<o`0Dooooo`;o<ol04Oooool00ol0ofKoooooooooo`0;ooooo`;o
0?oo=Oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01cooooo000gooooo`03o`00
0?oooooooooo04gooooo00?o0000ooooooooool06oooool00oo<o`3oooooooooo`0Cooooo`03oc?o
0?oooooooooo013ooooo00?o0?mVooooooooool02oooool2o`3oocOooooo00?o0000ooooooooool0
<_ooool00ol0003oooooooooo`0Kooooo`00>?ooool00ol0003oooooooooo`1=ooooo`03o`000?oo
oooooooo02oooooo00?o<ol0ooooooooool04?ooool00ol0ofKoooooooooo`0:ooooo`?o0?oo>Ooo
ool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00Oooooo00Gok^k^oc8b<_l0003o410@
olc<c00>ooooo`00>Oooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo02gooooo00?o
<ol0ooooooooool04Oooool00ol0ofKoooooooooo`08ooooo`;o0?oo0_ooool00ol0oooooooooooo
o`0hooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool01_ooool01OmEEEGoMgMgoooo
oonHV9So8B4Q00kooooo000jooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0:ooo
ool00olco`3oooooooooo`0Aooooo`03o`3oI_oooooooooo00Sooooo00Go0?oooooooooooooooooo
o`3oo`0kooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool01Oooool01Ol0003ooooo
oooooooooooo000000kooooo000kooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0
:?ooool2oc?o01;ooooo0_l0ofH8ooooo`?o0?oo1?ooool00ol0ooooooooooooo`0jooooo`03o`00
0?oooooooooo03;ooooo00?o0000ooooooooool01Oooool01Ol0003oV9RHoooooonHV9So8B4Q00ko
oooo000looooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool09Oooool2oc?o01?ooooo
00?o0?mVooooooooool01Oooool3o`3oo`Kooooo00?o0?ooooooooooool0??ooool00ol0003ooooo
ooooo`0booooo`03o`000?oooooooooo00Cooooo00Go0000oeEEEOl0003o410@olc<c00>ooooo`00
?Oooool2o`0004kooooo00?o0000ooooooooool08_ooool2oc?o01Cooooo00?o0?mVooooooooool0
1_l0ool8ooooo`03o`3ooooooooooooo02cooooo1?l0ool>ooooo`03o`000?oooooooooo03;ooooo
0_l00004ooooo`03oeEEEOn7QhOooooo013ooooo000oooooo`03o`000?oooooooooo04cooooo00?o
0000ooooooooool07oooool2oc?o013ooooo2Ol0ool=ooooo`03o`3ooooooooooooo00cooooo00?o
06Koooooooooool05oooool7o`3ooa?ooooo00?o0000ooooooooool0;oooool2o`000003ooooool0
003ooooo00?ooooo00?ogMgMoa0@4?nHV9P04?ooool0043ooooo00?o0000ooooooooool0C?ooool0
0ol0003oooooooooo`0Mooooo`03oc?o0?oooooooooo01?ooooo1Ol0ool=ooooo`03o`3ooooooooo
oooo00cooooo0_l0I_lBooooo`Oo0?oo6oooool00ol0003oooooooooo`0aooooo`03o`000?oooooo
oooo00?ooooo00Coc<c<odA4A?l0003o410@3_ooool0047ooooo00?o0000ooooooooool0C?ooool0
0ol0003oooooooooo`0Jooooo`;o<ol05Oooool00ol0ofKoooooooooo`03ooooo`go0?oo3_ooool2
o`1Vo`?ooooo4?l0oolRooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool05?ooool0
04;ooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0Gooooo`;o<ol05_ooool00ol0
ofKoooooooooo`0@ooooo`ko0?oo0_l0I_l4o`3ooc?ooooo00?o0000ooooooooool0<_ooool00ol0
003oooooooooo`0Cooooo`00@oooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo01Go
oooo00?o<ol0ooooooooool05?ooool2o`3oIQ;ooooo00?o0?ooooooooooool02oooool00ol0I_oo
ooooo`1Vo`0hooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool04_ooool004Cooooo
00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0Zooooo`03o`3oI_oooooooooo017ooooo
00?o0?ooooooooooool02_ooool2o`1Vo`03ooooool0I_oooooo03Wooooo00?o0000ooooooooool0
<Oooool00ol0003oooooooooo`0Booooo`00AOooool00ol0003oooooooooo`1<ooooo`03o`000?oo
oooooooo02Sooooo00?o0?mVooooooooool04Oooool00ol0ooooooooooooo`09ooooo`;o06Ko0_oo
ool00ol0I_ooooooooooo`0jooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool04Ooo
ool004Kooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0Uooooo`;o0?mV4_ooool2
o`3oo`_ooooo00?o06Koooooooooool00_ooool00ol0I_ooooooooooo`0kooooo`03o`000?oooooo
oooo037ooooo00?o0000ooooooooool04?ooool004Oooooo00?o0000ooooooooool0C?ooool00ol0
003oooooooooo`0Rooooo`;o0?mV4oooool00ol0ooooooooooooo`09ooooo`;o06Ko1?ooool00ol0
I_ooooooooooo`0looooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool03oooool004So
oooo0_l0001=ooooo`03o`000?oooooooooo023ooooo00?o0?mVooooooooool04_ooool00ol0oooo
ooooooooo`08ooooo`;o06Ko1Oooool00ol0I_ooooooooooo`0<ooooo`03oc<0oooooooooooo02oo
oooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0?ooooo`00B_ooool00ol0003ooooo
ooooo`1;ooooo`03o`000?oooooooooo01gooooo0_l0ofHDooooo`03o`3ooooooooooooo00Kooooo
0ol0I_l6ooooo`03o`1Voooooooooooo00_ooooo0olc0?lbooooo`03o`000?oooooooooo037ooooo
0_l0000?ooooo`00Boooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo01[ooooo0_l0
ofHDooooo`;o0?oo1_ooool3o`1Vo`Sooooo00?o06Koooooooooool02oooool00olc0?oooooooc<0
o`0dooooo`03o`000?oooooooooo033ooooo0_l0000?ooooo`00C?ooool00ol0003oooooooooo`1;
ooooo`03o`000?oooooooooo01Oooooo0_l0ofHEooooo`03o`3ooooooooo06Ko00Ko06Ko2_ooool0
0ol0I_ooooooooooo`0;ooooo`03oc<0oooooooo<`3o01_ooooo1Ol0I_lFooooo`03o`000?oooooo
oooo037ooooo00?o0000ooooooooool03?ooool004gooooo00?o0000ooooooooool0Boooool00ol0
003oooooooooo`0Eooooo`03o`3oI_oooooooooo00Wooooo3_l0I_lAooooo`03o`1Voooooooooooo
00[ooooo00Co<`3ooooooooooooo<`3o4oooool8o`1Voacooooo00?o0000ooooooooool0<Oooool0
0ol0003oooooooooo`0;ooooo`00C_ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo
01;ooooo0_l0ofHBooooo`[o06Ko3_ooool00ol0I_ooooooooooo`0:ooooo`04oc<0oooooooooooo
oc<0o`gooooo1ol0I_lTooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool02oooool0
04oooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0@ooooo`03o`3oI_oooooooooo
01Cooooo00?o0?ooooooooooool01Oooool;o`1Vo`;ooooo00?o06Koooooooooool02Oooool2oc<0
o`03ooooool0I_oo<`3o00ko06Ko;?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo
00[ooooo001@ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool09Oooool00ol0oooo
ooooooooo`0Aooooo`co06Ko0_lc0?l3o`1Vo`03oooooolc0?oooooo03[ooooo00?o0000oooooooo
ool0<Oooool00ol0003oooooooooo`09ooooo`00DOooool00ol0003oooooooooo`1;ooooo`03o`00
0?oooooooooo02?ooooo00?o0?ooooooooooool04Oooool2o`1Vo`Wooooo0_lc0?l5ooooo`03oc<0
oooooooooooo03_ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`08ooooo`00D_oo
ool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo023ooooo0_l0oolCooooo`03o`1Voooo
oooooooo00Sooooo00?o<`3oooooooooool01?ooool00olc0?ooooooooooo`0;ooooo`03ol`0oooo
oooooooo02oooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`08ooooo`00Doooool2
o`0004cooooo00?o0000ooooooooool07Oooool2o`3ooaCooooo00?o06Koooooooooool01oooool2
oc<0o`Kooooo00?o<`3oooooooooool03?ooool00oo<0?ooooooooooo`0`ooooo`03o`000?oooooo
oooo033ooooo00?o0000ooooooooool01oooool005Gooooo00?o0000ooooooooool0B_ooool00ol0
003oooooooooo`0Jooooo`;o0?oo5?ooool2o`1Vo`Sooooo0_lc0?l7ooooo`03oc<0oooooooooooo
00cooooo00?oc03oooooooooool0<Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo
00Kooooo001Fooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool05oooool2o`3ooaGo
oooo00?o06Koooooooooool01Oooool3oc<0o`Sooooo00?o<`3oooooooooool03?ooool2ol`0ocCo
oooo00?o0000ooooooooool0;oooool3o`0000Oooooo001Gooooo`03o`000?oooooooooo04[ooooo
00?o0000ooooooooool05Oooool00ol0ooooooooooooo`0Cooooo`;o06Ko1Oooool3oc<0o`_ooooo
00?o<`3oooooooooool02oooool2ol`0ocKooooo00?o0000ooooooooool0:oooool3o`0000;ooooo
00?o0000ooooooooool01Oooool005Sooooo00?o0000ooooooooool0B_ooool00ol0003ooooooooo
o`0Booooo`;o0?oo5Oooool00ol0I_ooooooooooo`02ooooo`?o<`3o3Oooool00olc0?oooooooooo
o`0;ooooo`03ol`0ooooooooc03o03Oooooo00?o0000ooooooooool09oooool3o`0000Gooooo00?o
0000ooooooooool01Oooool005Wooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0?
ooooo`;o0?oo5Oooool7oc<0o`oooooo00?o<`3oooooooooool02oooool00oo<0?oooooool`0o`0F
ooooo`Go<`3o7_ooool00ol0003oooooooooo`0Rooooo`Co00002?ooool00ol0003oooooooooo`05
ooooo`00F_ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo00cooooo0_l0ool5oooo
oa;o<`3o00?o06Koooooooooool04_ooool00olc0?ooooooooooo`0;ooooo`04ol`0oooooooooooo
ol`0o`kooooo2?lc0?lTooooo`03o`000?oooooooooo01kooooo0ol0000<ooooo`03o`000?oooooo
oooo00Gooooo001Kooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool02_ooool00ol0
ooooooooooooo`0;ooooo`_o<`3o5Oooool00olc0?ooooooooooo`0:ooooo`;oc03o0_ooool00oo<
0?ooooooooooo`05ooooo`So<`3o;?ooool00ol0003oooooooooo`0Jooooo`Co00003oooool00ol0
003oooooooooo`05ooooo`00G?ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo023o
oooo00?o06Kooooooolc0?l02_lc0?l8ooooo`;o<`3o2?ooool3oc<0o`;oc03o0olc0?l00oo<0?oo
<`3ooc<0o`06oc<0o`Gooooo00?oo`2Iooooooooool0;Oooool00ol0003oooooooooo`0Fooooo`?o
00005?ooool00ol0003oooooooooo`04ooooo`00GOooool00ol0003oooooooooo`1:ooooo`03o`00
0?oooooooooo01gooooo0_l0I_l=oooooa;o<`3o00?ooooool`0ooo<0?l01?ooool00oo<0?oooooo
ooooo`0<ooooo`03ool0VOoooooooooo02kooooo00?o0000ooooooooool04_ooool3o`0001Oooooo
00?o0000ooooooooool01?ooool005kooooo0_l0001;ooooo`03o`000?oooooooooo01[ooooo0_l0
I_lEooooo`03oc<0oooooooooooo00Wooooo00?oc03oooooooooool00oooool00oo<0?oooooooooo
o`0<ooooo`03ool0VOoooooooooo033ooooo00?o0000ooooooooool03Oooool4o`0001[ooooo00?o
0000ooooooooool01?ooool0063ooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0H
ooooo`03o`1Voooooooooooo01?ooooo0_lc0?l:ooooo`;oc03o1Oooool00oo<0?ooooooooooo`0;
ooooo`;oo`2I=?ooool00ol0003oooooooooo`09ooooo`?o00007_ooool00ol0003oooooooooo`04
ooooo`00HOooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo01Gooooo0_l0I_lEoooo
o`03oc<0oooooooooooo00Sooooo0_o<0?l6ooooo`03ol`0oooooooooooo00_ooooo00?oo`2Ioooo
oooo09T0=Oooool00ol0003oooooooooo`04ooooo`Co00008Oooool00ol0003oooooooooo`04oooo
o`00H_ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo01;ooooo0_l0I_lFooooo`03
oc<0oooooooooooo00Kooooo0oo<0?l7ooooo`03ol`0oooooooooooo00_ooooo00?oo`2Ioooooooo
09T0=_ooool01?l0003oooooooooooooool3o`0002Gooooo00?o0000ooooooooool01?ooool006?o
oooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0?ooooo`;o06Ko5_ooool2oc<0o`Ko
oooo0oo<0?l9ooooo`03ol`0oooooooooooo00_ooooo00?oo`2Ioooooooo09T0>?ooool3o`0002So
oooo00?o0000ooooooooool01?ooool006Cooooo00?o0000ooooooooool0BOooool00ol0003ooooo
ooooo`0<ooooo`;o06Ko5oooool00olc0?ooooooooooo`02ooooo`Coc03o2oooool00oo<0?oooooo
ooooo`0;ooooo`04ool0VOooooooooooool0VCCooooo1?l000000ooooooo0000ooooo`0Xooooo`03
o`000?oooooooooo00Cooooo001Uooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0
2_ooool00ol0I_ooooooooooo`0Fooooo`03oc<0oooooooooooo00?oc03o3_ooool00oo<0?oooooo
ooooo`0;ooooo`04ool0VOooooooooooool0VC;ooooo0ol00006ooooo`03o`000?oooooooooo02Ko
oooo00?o0000ooooooooool01?ooool006Kooooo00?o0000ooooooooool0BOooool00ol0003ooooo
ooooo`07ooooo`;o06Ko5_ooool6ol`0oa3ooooo00?oc03oooooooooool02_ooool2ool0V@;ooooo
00?oo`2Iooooooooool03?ooool00ooo003oooooooooo`02ooooo`Goc03o5oooool4o`0000[ooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`04ooooo`00Ioooool00ol0003ooooooooo
o`19ooooo`03o`000?oooooooooo00Cooooo2oo<0?l8ooooo`Ooc03o00?o<`3oooooooooool04Ooo
ool2ol`0o`_ooooo0_oo09T3ooooo`03ool0VOoooooooooo00Wooooo1?o<0?l00ooo003oc03ool`0
o`02ol`0oaWooooo0ol0000?ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00ooo
ool006Sooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`07ooooo`Goc03o0_ooool8
ol`0o`Kooooo00?o<`3oooooooooool04Oooool00oo<0?ooooooooooo`09ooooo`;oo`2I1?ooool0
0ooo09Woooooooooo`02ooooo`Soc03o0oooool00ooo003oooooooooo`0Iooooo`?o00004_ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00?ooooo001Yooooo`03o`000?oooooooooo
04Wooooo00?o0000ooooooooool02oooool?ol`0o`03oc<0oooooooooooo017ooooo00?oc03ooooo
ooooool00oooool5ol`0o`;oo`2I1Oo<0?l00ooo09Woc03ool`0o`03ol`0o`Wooooo0ooo000Goooo
o`Co00005_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00?ooooo001Zooooo`;o
0000B_ooool00ol0003oooooooooo`0Fooooo`;o<`3o00?ooooool`0ooo<0?l06?o<0?l4ooooo`03
ool0VOoooooooooo00Cooooo00?oo`2Iooooooooool03?ooool00ooo003oooooool0000Eooooo`?o
00006oooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo00?ooooo001/ooooo`03o`00
0?oooooooooo04Sooooo00?o0000ooooooooool04oooool2oc<0oaCooooo00?oc03oooooooooool0
2?ooool2ool0V@Oooooo00?oo`2Iooooooooool02oooool00ooo003oooooool0000Booooo`Co0000
7oooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00?ooooo001]ooooo`03o`000?oo
oooooooo04Sooooo00?o0000ooooooooool04?ooool2oc<0oaGooooo00?oc03oooooooooool01ooo
ool2ool0V@Sooooo00?oo`2Iooooooooool02oooool01?oo003ooooooooooooo000?ooooo`?o0000
9?ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo00?ooooo001^ooooo`03o`000?oo
oooooooo04Sooooo00?o0000ooooooooool03Oooool2oc<0oaGooooo0_o<0?l7ooooo`?oo`2I2Ooo
ool00ooo09Woooooooooo`0;ooooo`04ool00?ooooooooooool000gooooo0ol0000Xooooo`03o`00
0?oooooooooo023ooooo00?o0000ooooooooool00oooool006oooooo00?o0000ooooooooool0B?oo
ool00ol0003oooooooooo`0:ooooo`;o<`3o5_ooool00oo<0?ooooooooooo`04ooooo`?oo`2I2ooo
ool00ooo09Woooooooooo`0;ooooo`05ool00?oooooooooooooooooo00002Oooool4o`0002_ooooo
00?o0000ooooooooool08?ooool00ol0003oooooooooo`03ooooo`00L?ooool00ol0003ooooooooo
o`18ooooo`03o`000?oooooooooo00Oooooo0_lc0?lGooooo`03ol`0oooooooooooo00;ooooo0ooo
09T=ooooo`03ool0VOoooooooooo00_ooooo00Goo`00ooooooooooooooooool00007ooooo`?o0000
<?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00?ooooo001aooooo`03o`000?oo
oooooooo04Sooooo00?o0000ooooooooool01?ooool2oc<0oaSooooo00?oc03oooooooooool00ooo
09T?ooooo`03ool0VOoooooooooo00_ooooo00Goo`00ooooooooooooooooool00004ooooo`Co0000
=?ooool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00?ooooo001booooo`03o`000?oo
oooooooo04Sooooo00Co0000oooooooooooooooo0_lc0?lHooooo`;oc03o0ooo09T@ooooo`;oo`2I
3?ooool2ool000?ooooo00?oo`00ooooooooool00ol0000iooooo`03o`000?oooooooooo01kooooo
00?o0000ooooooooool00_ooool007?ooooo00?o0000ooooooooool0B?ooool00ol0003ooooooc<0
o`0Fooooo`Koo`2I4_ooool00ooo09Woooooooooo`0:ooooo`;oo`001?ooool01?oo003o0000o`00
0?l0000=ooooo`Coo`2I;?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo00;ooooo
001dooooo`03o`000?oooooooooo047ooooo1?oo09T3ooooo`03o`000?oooooooooo00cooooo2Ooo
09T2ooooo`03ol`0oooooooooooo01;ooooo00?oo`2Iooooooooool02_ooool01?oo003ooooooooo
ooooool2o`000003ool00?l0003ooooo00Sooooo1ooo09Taooooo`03o`000?oooooooooo01cooooo
00?o0000ooooooooool00_ooool007Gooooo0_l00014oooooa?oo`2I2Oooool2ol`0oa?ooooo0_oo
09T;ooooo`;oo`0000Koooooo`000?l0003o0000oooooooo0004ooooo`Ooo`2I>?ooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo00;ooooo001gooooo`03o`000?oooooooooo04Oooooo
2Ooo09T;ooooo`;oc03o5?ooool00ooo09Woooooooooo`09ooooo`;oo`000ol00002ooooo`03ool0
VOoo003oo`2I00Coo`2I@?ooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00;ooooo
001hooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool01Oooool=ool0VA;ooooo0_oo
09T00oooooooo`2Iool0V@07ool0V@;oo`001ooo09T00ooo003oooooooooo`15ooooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool00_ooool007Wooooo00?o0000ooooooooool0Aoooool0
0ol0003oooooooooo`0;ooooo`;oc03o1?oooolEool0V@Kooooo0_l000000ooo003oooooooooo`06
ooooo`03ool00?oooooooooo04Oooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`02
ooooo`00N_ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo00Sooooo0_o<0?lFoooo
o`03ool0VOoooooooooo00Cooooo1?l00002ool000Sooooo00?oo`00ooooooooool0BOooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo00;ooooo001kooooo`03o`000?oooooooooo04Oo
oooo00?o0000ooooooooool01Oooool2ol`0oaKooooo0_oo09T4ooooo`?o000000Coooooool00?oo
003oo`002Oooool00ooo003oooooooooo`1;ooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool00_ooool007cooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`02ooooo`;o
c03o5oooool00ooo09Woooooooooo`04o`0000Coo`002oooool00ooo003oooooooooo`1<ooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool00_ooool007gooooo00?o0000ooooooooool0
Aoooool01?l0003ooooool`0ooo<0?lGooooo`;oo`2I0ol00004ool000gooooo0_oo001@ooooo`03
o`000?oooooooooo01Oooooo00?o0000ooooooooool00Oooool007kooooo00?o0000ooooooooool0
A_ooool2ol`0oaSooooo00?oo`2Io`000?l000000ooo000@ooooo`03ool00?oooooooooo057ooooo
00?o0000ooooooooool05_ooool00ol0003oooooooooo`01ooooo`00Ooooool00ol0003ooooooooo
o`14ooooo`04ol`0ooooooooooooo`0001?ooooo0ol00004ool0017ooooo0_oo001Eooooo`03o`00
0?oooooooooo01Gooooo00?o0000ooooooooool00Oooool0083ooooo0_l00018ooooo`03o`000?oo
oooooooo00cooooo1ooo000Dooooo`03ool00?oooooooooo05Kooooo00?o0000ooooooooool05?oo
ool00ol0003oooooooooo`01ooooo`00P_ooool00ol0003oooooooooo`16ooooo`03o`000?oooooo
oooo00;ooooo2Ooo00000ol0003oooooooooo`02ool0VAGooooo00?oo`00ooooooooool07Oooool6
ool003Gooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`01ooooo`00Poooool00ol0
003oooooooooo`0`oooooa[oo`000oooool3o`0000Cooooo0_oo09TEooooo`;oo`005oooool9ool0
03_ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`01ooooo`00Q?ooool00ol0003o
ooooooooo`0fooooo`coo`001?ooool00ol0003oooooooooo`03o`0000Gooooo0_oo09TFooooo`03
ool00?oooooooooo00kooooo2Ooo0015ooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool00Oooool008Gooooo00?o0000ooooooooool0@Oooool=ool000;oo`2I5?oooolEool004oooooo
00?o0000ooooooooool04Oooool00ol0003oooooooooo`01ooooo`00Q_ooool00ol0003ooooooooo
o`15ooooo`03o`000?oooooooooo00?ooooo0_oo09TFool00003oooooooo003ooooo06;ooooo00?o
0000ooooooooool04?ooool00ol0003oooooooooo`01ooooo`00Qoooool00ol0003oooooooooo`14
ooooo`04o`000?ooooooooooooooo`;oo`2I5oooool2ool006Gooooo00?o0000ooooooooool03ooo
ool00ol0003oooooooooo`01ooooo`00R?ooool00ol0003oooooooooo`13ooooo`04o`000?oooooo
o`2Iool0VASooooo00?oo`00ooooooooool0I_ooool00ol0003oooooooooo`0?ooooo`7o00000Ooo
ool1ooooo`00ROooool00ol0003oooooooooo`12ooooo`;oo`2I6Oooool00ooo003oooooooooo`1W
ooooo`03o`000?oooooooooo00oooooo0Ol00001ooooo`7ooooo002:ooooo`03o`000?oooooooooo
03oooooo0_oo09T00ol0003oooooooooo`0Fooooo`;oo`00Joooool00ol0003oooooooooo`0>oooo
o`7o00000Oooool1ooooo`00Roooool2o`0003kooooo00Coo`2Ioooooooooooo00005oooool00ooo
003oooooooooo`1/ooooo`03o`000?oooooooooo00gooooo0Ol00001ooooo`7ooooo002=ooooo`03
o`000?oooooooooo03kooooo00?o0000ooooooooool04oooool2ool0073ooooo00?o0000oooooooo
ool03?ooool1o`00007ooooo0Oooool008kooooo00?o0000ooooooooool0?Oooool00ol0003ooooo
ooooo`0Aooooo`;oo`00Loooool00ol0003oooooooooo`0;ooooo`7o00000Oooool1ooooo`00Sooo
ool00ol0003oooooooooo`0looooo`03o`000?oooooooooo00oooooo0_oo001fooooo`03o`000?oo
oooooooo00[ooooo0Ol00001ooooo`7ooooo002@ooooo`03o`000?oooooooooo03_ooooo00?o0000
ooooooooool03Oooool2ool007Sooooo00?o0000ooooooooool02_ooool1o`00007ooooo0Oooool0
097ooooo00?o0000ooooooooool0>_ooool00ol0003oooooooooo`0;ooooo`;oo`00Noooool00ol0
003oooooooooo`09ooooo`7o00000Oooool1ooooo`00T_ooool00ol0003oooooooooo`0iooooo`03
o`000?oooooooooo00Wooooo0_oo001nooooo`03o`000?oooooooooo00Sooooo0Ol00001ooooo`7o
oooo002Cooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool01oooool2ool0087ooooo
00?o0000ooooooooool02?ooool1o`00007ooooo002Dooooo`03o`000?oooooooooo03Oooooo00?o
0000ooooooooool01Oooool2ool008Cooooo00?o0000ooooooooool01oooool1o`00007ooooo002E
ooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool00oooool2ool008Oooooo00?o0000
ooooooooool01_ooool1o`00007ooooo002Fooooo`03o`000?oooooooooo03Gooooo00Co0000oooo
oooooooooooo0_oo0029ooooo`03o`000?oooooooooo00Kooooo0Ol00001ooooo`00Uoooool2o`00
03Gooooo00Co0000ooooooooooooo`00S?ooool00ol0003oooooooooo`05ooooo`7o00000Oooool0
09Wooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`2>ooooo`03o`000?oooooooooo
00Cooooo0Ol00001ooooo`00V_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo08oo
oooo00?o0000ooooooooool00oooool1o`00007ooooo002Kooooo`03o`000?oooooooooo033ooooo
00?o0000ooooooooool0T?ooool00ol0003oooooooooo`02ooooo`7o00000Oooool009cooooo00?o
0000ooooooooool0;oooool00ol0003oooooooooo`2Aooooo`05o`000?ooooooooooooooool00000
0Oooool009gooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`2Aooooo`05o`000?oo
ooooooooooooool000000Oooool009kooooo00?o0000ooooooooool0;Oooool00ol0003ooooooooo
o`2Booooo`04o`000?ooooooooooooooo`7o0000002Oooooo`03o`000?oooooooooo02cooooo00?o
0000ooooooooool0Toooool00ol0003oooooooooo`01o`000000X?ooool00ol0003oooooooooo`0[
ooooo`03o`000?oooooooooo09Cooooo0Ol00001ooooo`7o0000002Qooooo`03o`000?oooooooooo
02[ooooo00?o0000ooooooooool0UOooool2o`000000X_ooool2o`0002[ooooo00?o0000oooooooo
ool0U?ooool3o`000000Y?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo093ooooo
1?l00003ooooo`00YOooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo08gooooo0ol0
0007ooooo`00Y_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo08Wooooo1?l0000:
ooooo`00Yoooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo08Gooooo1?l0000>oooo
o`00Z?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo08;ooooo0ol0000Booooo`00
ZOooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo07kooooo1?l0000Eooooo`00Z_oo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo07[ooooo1?l0000Iooooo`00Zoooool0
0ol0003oooooooooo`0Qooooo`03o`000?oooooooooo07Gooooo1?l0000Mooooo`00[?ooool00ol0
003oooooooooo`0Pooooo`03o`000?oooooooooo07;ooooo0ol0000Qooooo`00[Oooool2o`00023o
oooo00?o0000ooooooooool0K_ooool4o`0002Cooooo002_ooooo`03o`000?oooooooooo01gooooo
00?o0000ooooooooool0J_ooool4o`0002Sooooo002`ooooo`03o`000?oooooooooo01cooooo00?o
0000ooooooooool0Ioooool3o`0002cooooo002aooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool0Hoooool4o`0002oooooo002booooo`03o`000?oooooooooo01[ooooo00?o0000oooo
ooooool0Goooool4o`0003?ooooo002cooooo`03o`000?oooooooooo01Wooooo00?o0000oooooooo
ool0G?ooool3o`0003Oooooo002dooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0
F?ooool4o`0003[ooooo002eooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0E?oo
ool4o`0003kooooo002fooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0D?ooool4
o`0004;ooooo002gooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool0COooool3o`00
04Kooooo002hooooo`;o00005Oooool00ol0003oooooooooo`19ooooo`Co0000BOooool00;[ooooo
00?o0000ooooooooool04_ooool00ol0003oooooooooo`15ooooo`Co0000COooool00;_ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`12ooooo`?o0000DOooool00;cooooo00?o0000
ooooooooool04?ooool00ol0003oooooooooo`0nooooo`Co0000E?ooool00;gooooo00?o0000oooo
ooooool03oooool00ol0003oooooooooo`0jooooo`Co0000F?ooool00;kooooo00?o0000oooooooo
ool03_ooool00ol0003oooooooooo`0fooooo`Co0000G?ooool00;oooooo00?o0000ooooooooool0
3Oooool00ol0003oooooooooo`0cooooo`?o0000H?ooool00<3ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`0_ooooo`Co0000Hoooool00<7ooooo00?o0000ooooooooool02oooool0
0ol0003oooooooooo`0[ooooo`Co0000Ioooool00<;ooooo00?o0000ooooooooool02_ooool00ol0
003oooooooooo`0Xooooo`?o0000Joooool00<?ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`0Tooooo`Co0000K_ooool00<Cooooo0_l00009ooooo`03o`000?oooooooooo023ooooo
1?l0001booooo`00a_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo01gooooo0ol0
001fooooo`00aoooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo01Wooooo1?l0001i
ooooo`00b?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo01Gooooo1?l0001moooo
o`00bOooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo017ooooo1?l00021ooooo`00
b_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00kooooo0ol00025ooooo`00booo
ool01Ol0003ooooooooooooooooo000000cooooo1?l00028ooooo`00c?ooool01?l0003ooooooooo
ool00008ooooo`Co0000S?ooool00<gooooo00?o0000ooooool000001Oooool3o`00093ooooo003>
ooooo`;o000000?oooooo`000?l000000_l0002Cooooo`00coooool2o`0009Oooooo003oooooofWo
oooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {330.375, 0}} -> {-0.0771432, -0.0315529, \
0.00350368, 0.00350368}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .92059 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-16 1.0763 -0.0263982 1.0763 [
[.01694 .18568 -11.9631 -9 ]
[.01694 .18568 .03693 0 ]
[.13793 .13897 -11.619 -9 ]
[.13793 .13897 .38095 0 ]
[.26292 .09073 -5.63752 -9 ]
[.26292 .09073 .36248 0 ]
[.39212 .04087 -5.46552 -9 ]
[.39212 .04087 .53448 0 ]
[.52574 -0.01069 -5.29351 -9 ]
[.52574 -0.01069 .70649 0 ]
[.58272 .04263 0 -6.19654 ]
[.58272 .04263 6 2.80346 ]
[.71715 .21863 0 -6.07114 ]
[.71715 .21863 6 2.92886 ]
[.83675 .37523 0 -5.963 ]
[.83675 .37523 6 3.037 ]
[.94385 .51546 0 -5.8688 ]
[.94385 .51546 6 3.1312 ]
[.01386 .20006 -12 -2.76892 ]
[.01386 .20006 0 6.23108 ]
[.00748 .25499 -24 -2.80073 ]
[.00748 .25499 0 6.19927 ]
[.00093 .31131 -6 -2.83339 ]
[.00093 .31131 0 6.16661 ]
[-0.00579 .36907 -18 -2.86695 ]
[-0.00579 .36907 0 6.13305 ]
[-0.01268 .42831 -6 -2.90143 ]
[-0.01268 .42831 0 6.09857 ]
[ 0 0 0 0 ]
[ 1 .92059 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02642 .19522 m
.53391 0 L
s
.02642 .19522 m
.03116 .2 L
s
[(-2)] .01694 .18568 .99384 1 Mshowa
.14712 .14879 m
.15172 .1537 L
s
[(-1)] .13793 .13897 .93651 1 Mshowa
.2718 .10083 m
.27624 .10588 L
s
[(0)] .26292 .09073 .87917 1 Mshowa
.40066 .05126 m
.40493 .05646 L
s
[(1)] .39212 .04087 .82184 1 Mshowa
.53391 0 m
.538 .00534 L
s
[(2)] .52574 -0.01069 .7645 1 Mshowa
.125 Mabswid
.05025 .18606 m
.05308 .18894 L
s
.07424 .17683 m
.07705 .17973 L
s
.09837 .16755 m
.10117 .17046 L
s
.12267 .1582 m
.12545 .16113 L
s
.17173 .13933 m
.17447 .14229 L
s
.19651 .1298 m
.19923 .13278 L
s
.22144 .1202 m
.22414 .1232 L
s
.24654 .11055 m
.24922 .11356 L
s
.29723 .09105 m
.29988 .0941 L
s
.32283 .0812 m
.32546 .08427 L
s
.3486 .07129 m
.35121 .07437 L
s
.37455 .06131 m
.37713 .06441 L
s
.42695 .04115 m
.4295 .04428 L
s
.45342 .03096 m
.45594 .03412 L
s
.48007 .02071 m
.48257 .02388 L
s
.5069 .01039 m
.50938 .01358 L
s
.25 Mabswid
.53391 0 m
.9804 .58403 L
s
.57014 .04738 m
.56384 .04975 L
s
[(0)] .58272 .04263 -1 .37701 Mshowa
.70445 .22307 m
.6981 .22529 L
s
[(2)] .71715 .21863 -1 .34914 Mshowa
.82396 .37939 m
.81756 .38147 L
s
[(4)] .83675 .37523 -1 .32511 Mshowa
.93098 .51938 m
.92454 .52134 L
s
[(6)] .94385 .51546 -1 .30418 Mshowa
.125 Mabswid
.60525 .09331 m
.60147 .09471 L
s
.63931 .13786 m
.63552 .13924 L
s
.67236 .1811 m
.66856 .18245 L
s
.73562 .26383 m
.7318 .26514 L
s
.7659 .30345 m
.76207 .30473 L
s
.79534 .34195 m
.7915 .34322 L
s
.85181 .41581 m
.84796 .41704 L
s
.87891 .45126 m
.87506 .45247 L
s
.90529 .48577 m
.90143 .48696 L
s
.95601 .55212 m
.95214 .55328 L
s
.25 Mabswid
.02642 .19522 m
0 .42381 L
s
.02642 .19522 m
.0327 .19281 L
s
[(-1)] .01386 .20006 1 -0.38468 Mshowa
.02006 .25024 m
.02635 .24786 L
s
[(-0.5)] .00748 .25499 1 -0.37762 Mshowa
.01354 .30664 m
.01985 .3043 L
s
[(0)] .00093 .31131 1 -0.37036 Mshowa
.00686 .36448 m
.01318 .36218 L
s
[(0.5)] -0.00579 .36907 1 -0.3629 Mshowa
0 .42381 m
.00634 .42156 L
s
[(1)] -0.01268 .42831 1 -0.35524 Mshowa
.125 Mabswid
.02516 .20612 m
.02893 .20468 L
s
.0239 .21707 m
.02767 .21563 L
s
.02262 .22807 m
.0264 .22664 L
s
.02135 .23913 m
.02512 .2377 L
s
.01877 .26141 m
.02255 .25999 L
s
.01747 .27263 m
.02125 .27122 L
s
.01617 .28391 m
.01995 .2825 L
s
.01486 .29525 m
.01864 .29384 L
s
.01222 .31809 m
.01601 .3167 L
s
.01089 .3296 m
.01468 .32821 L
s
.00955 .34117 m
.01334 .33978 L
s
.00821 .35279 m
.012 .35141 L
s
.0055 .37622 m
.0093 .37485 L
s
.00414 .38803 m
.00793 .38666 L
s
.00276 .39989 m
.00656 .39853 L
s
.00139 .41182 m
.00519 .41047 L
s
.25 Mabswid
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.54154 .92059 L
s
.54154 .92059 m
.5414 .7134 L
s
.5414 .7134 m
.02642 .19522 L
s
.53391 0 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.53391 0 m
.02642 .19522 L
s
.5414 .7134 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.54154 .92059 L
s
.54154 .92059 m
.5414 .7134 L
s
0 0 m
1 0 L
1 .92059 L
0 .92059 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.56505 .77678 m
.62943 .74444 L
s
1 0 .6 r
.54846 .74386 m
.60971 .71253 L
s
.8 0 1 r
.53186 .71092 m
.59 .68066 L
s
.2 0 1 r
.51525 .67797 m
.5703 .64881 L
s
0 .4 1 r
.49863 .645 m
.55061 .61699 L
s
0 1 1 r
.48201 .61202 m
.53095 .5852 L
s
0 1 .4 r
.46537 .57902 m
.51129 .55343 L
s
.2 1 0 r
.44873 .54601 m
.49166 .52168 L
s
.8 1 0 r
.43207 .51298 m
.47204 .48996 L
s
1 .6 0 r
.41542 .47994 m
.45243 .45826 L
s
.45243 .45826 m
.48422 .43163 L
s
.8 1 0 r
.47204 .48996 m
.5071 .46111 L
s
.2 1 0 r
.49166 .52168 m
.53004 .49067 L
s
0 1 .4 r
.51129 .55343 m
.55304 .52031 L
s
0 1 1 r
.53095 .5852 m
.5761 .55004 L
s
0 .4 1 r
.55061 .61699 m
.59923 .57984 L
s
.2 0 1 r
.5703 .64881 m
.62242 .60973 L
s
.8 0 1 r
.59 .68066 m
.64568 .6397 L
s
1 0 .6 r
.60971 .71253 m
.669 .66976 L
s
1 0 0 r
.62943 .74444 m
.69237 .69991 L
s
.58111 .73227 m
.68277 .7291 L
s
.49506 .72613 m
.58111 .73227 L
s
.68277 .7291 m
.77055 .71803 L
s
1 .6 0 r
.48422 .43163 m
.50285 .40732 L
s
1 0 .6 r
.58226 .69538 m
.67889 .69231 L
s
.50083 .68947 m
.58226 .69538 L
s
1 0 0 r
.45952 .72113 m
.49506 .72613 L
s
.8 1 0 r
.5071 .46111 m
.52801 .43439 L
s
1 0 .6 r
.67889 .69231 m
.76283 .68156 L
s
.8 0 1 r
.58345 .65837 m
.67501 .65541 L
s
.50665 .65271 m
.58345 .65837 L
s
1 0 0 r
.53186 .72448 m
.47893 .72331 L
s
.59709 .71689 m
.53186 .72448 L
s
.47893 .72331 m
.45952 .72113 L
s
.2 1 0 r
.53004 .49067 m
.55332 .46159 L
s
1 0 .6 r
.46665 .68458 m
.50083 .68947 L
s
.8 0 1 r
.67501 .65541 m
.7551 .64499 L
s
.2 0 1 r
.58465 .62124 m
.67113 .61839 L
s
.51249 .61584 m
.58465 .62124 L
s
1 0 .6 r
.52992 .68748 m
.48301 .68643 L
s
.58795 .68061 m
.52992 .68748 L
s
.48301 .68643 m
.46665 .68458 L
s
0 1 .4 r
.55304 .52031 m
.57875 .48891 L
s
.8 0 1 r
.47382 .64793 m
.50665 .65271 L
s
.2 0 1 r
.67113 .61839 m
.74735 .60831 L
s
1 0 0 r
.65976 .69858 m
.59709 .71689 L
s
0 .4 1 r
.58585 .58398 m
.66723 .58126 L
s
.51835 .57885 m
.58585 .58398 L
s
.8 0 1 r
.52797 .65036 m
.48711 .64943 L
s
.57878 .64425 m
.52797 .65036 L
s
0 1 1 r
.5761 .55004 m
.6043 .51637 L
s
.8 0 1 r
.48711 .64943 m
.47382 .64793 L
s
.2 0 1 r
.48101 .61117 m
.51249 .61584 L
s
0 .4 1 r
.66723 .58126 m
.73958 .57153 L
s
1 0 .6 r
.64363 .66407 m
.58795 .68061 L
s
0 1 1 r
.58706 .5466 m
.66332 .544 L
s
.52422 .54175 m
.58706 .5466 L
s
0 .4 1 r
.59923 .57984 m
.62998 .54397 L
s
.2 0 1 r
.52601 .61311 m
.49122 .61232 L
s
.5696 .60779 m
.52601 .61311 L
s
.49122 .61232 m
.48101 .61117 L
s
0 .4 1 r
.48822 .57431 m
.51835 .57885 L
s
.8 0 1 r
.62748 .62954 m
.57878 .64425 L
s
0 1 1 r
.66332 .544 m
.73179 .53465 L
s
.2 0 1 r
.62242 .60973 m
.65578 .57169 L
s
0 1 .4 r
.58826 .50909 m
.6594 .50663 L
s
.53012 .50454 m
.58826 .50909 L
s
0 .4 1 r
.52405 .57574 m
.49535 .57509 L
s
.56039 .57124 m
.52405 .57574 L
s
0 1 1 r
.49546 .53735 m
.52422 .54175 L
s
0 .4 1 r
.49535 .57509 m
.48822 .57431 L
s
.2 0 1 r
.61133 .59499 m
.5696 .60779 L
s
1 .6 0 r
.50285 .40732 m
.51031 .39322 L
s
0 1 .4 r
.6594 .50663 m
.72398 .49767 L
s
.8 0 1 r
.64568 .6397 m
.68171 .59956 L
s
0 1 1 r
.52209 .53825 m
.49949 .53774 L
s
.55116 .53459 m
.52209 .53825 L
s
.2 1 0 r
.58948 .47146 m
.65546 .46913 L
s
.53603 .46722 m
.58948 .47146 L
s
0 1 .4 r
.50271 .50028 m
.53012 .50454 L
s
0 .4 1 r
.59515 .5604 m
.56039 .57124 L
s
0 1 1 r
.49949 .53774 m
.49546 .53735 L
s
1 0 .6 r
.669 .66976 m
.70776 .62756 L
s
.2 1 0 r
.65546 .46913 m
.71614 .46059 L
s
.8 1 0 r
.52801 .43439 m
.53602 .41959 L
s
0 1 1 r
.57897 .52578 m
.55116 .53459 L
s
.2 1 0 r
.50998 .4631 m
.53603 .46722 L
s
0 1 .4 r
.52011 .50064 m
.50364 .50027 L
s
.5419 .49785 m
.52011 .50064 L
s
.8 1 0 r
.59069 .43371 m
.65152 .43152 L
s
.54195 .42978 m
.59069 .43371 L
s
0 1 .4 r
.50364 .50027 m
.50271 .50028 L
s
1 0 0 r
.69237 .69991 m
.73393 .65571 L
s
.8 1 0 r
.65152 .43152 m
.70829 .4234 L
s
0 1 .4 r
.56277 .49113 m
.5419 .49785 L
s
1 0 0 r
.70941 .67235 m
.65976 .69858 L
s
.8 1 0 r
.51727 .42582 m
.54195 .42978 L
s
1 0 .6 r
.68755 .64045 m
.64363 .66407 L
s
.2 1 0 r
.50781 .46268 m
.50998 .4631 L
s
.51813 .4629 m
.50781 .46268 L
s
.53262 .46101 m
.51813 .4629 L
s
1 .6 0 r
.59191 .39583 m
.64755 .39379 L
s
.54788 .39224 m
.59191 .39583 L
s
.8 0 1 r
.66573 .6086 m
.62748 .62954 L
s
.2 1 0 r
.55332 .46159 m
.56195 .44608 L
s
.54655 .45646 m
.53262 .46101 L
s
.2 0 1 r
.64394 .5768 m
.61133 .59499 L
s
1 .6 0 r
.64755 .39379 m
.70041 .38611 L
s
.51031 .39322 m
.51317 .38818 L
s
0 .4 1 r
.6222 .54506 m
.59515 .5604 L
s
.8 1 0 r
.51197 .42498 m
.51727 .42582 L
s
1 .6 0 r
.52449 .38845 m
.54788 .39224 L
s
0 1 1 r
.60048 .51336 m
.57897 .52578 L
s
.8 1 0 r
.51614 .42504 m
.51197 .42498 L
s
.52331 .42408 m
.51614 .42504 L
s
.53033 .42176 m
.52331 .42408 L
s
0 1 .4 r
.5788 .48172 m
.56277 .49113 L
s
.2 1 0 r
.55716 .45013 m
.54655 .45646 L
s
1 .6 0 r
.51606 .38721 m
.52449 .38845 L
s
.51317 .38818 m
.51411 .38712 L
s
.8 1 0 r
.53556 .41859 m
.53033 .42176 L
s
0 1 .4 r
.57875 .48891 m
.58804 .47271 L
s
1 .6 0 r
.5141 .38712 m
.51606 .38721 L
s
.51401 .38712 m
.5141 .38712 L
s
.51417 .38707 m
.51401 .38712 L
s
.51411 .38712 m
.51417 .38707 L
s
.8 1 0 r
.53602 .41959 m
.53776 .41641 L
s
.53776 .41641 m
.53556 .41859 L
s
.2 1 0 r
.56258 .44474 m
.55716 .45013 L
s
0 1 1 r
.6043 .51637 m
.61427 .49949 L
s
0 1 .4 r
.58751 .47318 m
.5788 .48172 L
s
.2 1 0 r
.56195 .44608 m
.56258 .44474 L
s
0 1 1 r
.61254 .50174 m
.60048 .51336 L
s
0 .4 1 r
.63768 .53042 m
.6222 .54506 L
s
.62998 .54397 m
.64065 .52641 L
s
.2 0 1 r
.66292 .55921 m
.64394 .5768 L
s
.8 0 1 r
.68826 .58812 m
.66573 .6086 L
s
0 1 .4 r
.58804 .47271 m
.58751 .47318 L
s
1 0 .6 r
.71371 .61716 m
.68755 .64045 L
s
.2 0 1 r
.65578 .57169 m
.66717 .55349 L
s
1 0 0 r
.73927 .64632 m
.70941 .67235 L
s
0 1 1 r
.61427 .49949 m
.61254 .50174 L
s
.8 0 1 r
.68171 .59956 m
.69384 .58071 L
s
0 .4 1 r
.64065 .52641 m
.63768 .53042 L
s
1 0 .6 r
.70776 .62756 m
.72066 .60809 L
s
.2 0 1 r
.66717 .55349 m
.66292 .55921 L
s
.8 0 1 r
.69384 .58071 m
.68826 .58812 L
s
1 0 0 r
.73393 .65571 m
.74762 .63563 L
s
1 0 .6 r
.72066 .60809 m
.71371 .61716 L
s
1 0 0 r
.74762 .63563 m
.73927 .64632 L
s
0 g
.25 Mabswid
.53391 0 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.53391 0 m
.02642 .19522 L
s
.02642 .19522 m
.53391 0 L
s
.02642 .19522 m
.03116 .2 L
s
[(-2)] .01694 .18568 .99384 1 Mshowa
.14712 .14879 m
.15172 .1537 L
s
[(-1)] .13793 .13897 .93651 1 Mshowa
.2718 .10083 m
.27624 .10588 L
s
[(0)] .26292 .09073 .87917 1 Mshowa
.40066 .05126 m
.40493 .05646 L
s
[(1)] .39212 .04087 .82184 1 Mshowa
.53391 0 m
.538 .00534 L
s
[(2)] .52574 -0.01069 .7645 1 Mshowa
.125 Mabswid
.05025 .18606 m
.05308 .18894 L
s
.07424 .17683 m
.07705 .17973 L
s
.09837 .16755 m
.10117 .17046 L
s
.12267 .1582 m
.12545 .16113 L
s
.17173 .13933 m
.17447 .14229 L
s
.19651 .1298 m
.19923 .13278 L
s
.22144 .1202 m
.22414 .1232 L
s
.24654 .11055 m
.24922 .11356 L
s
.29723 .09105 m
.29988 .0941 L
s
.32283 .0812 m
.32546 .08427 L
s
.3486 .07129 m
.35121 .07437 L
s
.37455 .06131 m
.37713 .06441 L
s
.42695 .04115 m
.4295 .04428 L
s
.45342 .03096 m
.45594 .03412 L
s
.48007 .02071 m
.48257 .02388 L
s
.5069 .01039 m
.50938 .01358 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 265.125},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001Bb000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00`oooool5o`000:3ooooo0033ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@0X?ooool00<Cooooo00?oV9RHob4Q8Oo^k^h0XOooool00<Gooooo00?oV9RH
ob4Q8Oo^k^h0X?ooool00<Kooooo00?oMgMgofIVI_ooool0Woooool00<Oooooo00?o0000oooooooo
ool0W_ooool00<?ooooo00Go0000okZj^_ooooooV9RHoa0@402Pooooo`00`oooool01OnHV9So410@
o`000?lQ8B7oc<c<0:3ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003;ooooo`;o0000Voooool00<Sooooo0ol000000ooooooo0000ooooo`2Jooooo`00a_oo
ool2o`0000Cooooo0_l0002Jooooo`00`oooool3o`0000Kooooo00?o0000ooooool00000VOooool0
0<3ooooo1?l00008ooooo`04o`000?ooooooooooo`0009Sooooo002Hooooo`Co000000?o410@oooo
ooooool07oooool2o`0000Cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0002H
ooooo`00V_ooool00ol0003oooooooooo`0Nooooo`?o00003_ooool01Ol0003ooooooooooooooooo
000009Oooooo002Jooooo`03o`000?oooooooooo01cooooo0_l0000Aooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0U?ooool009[ooooo00?o0000ooooooooool06Oooool3o`0000;o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo09?o
oooo002Jooooo`03o`000?oooooooooo01Kooooo0ol0000Fooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^08Kooooo002Jooooo`03o`00
0?oooooooooo01Cooooo0_l0000Iooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1oooool01OmgMgOoV9RHoooooonHV9SoMgMg08Kooooo002Jooooo`03o`000?oooooooooo017ooooo
0ol000000ooooooo0000ooooo`0Hooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1_ooool01Ol@413ooooooooooooooooo410@08Kooooo002Hooooo`03oeEEEOmVIVKo0000017ooooo
0_l0000Nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool01Ol0003ooooo
oooooooooooo000008Kooooo002Yooooo`?o00008?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000026ooooo`00Yoooool3o`0002;ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@
4100Q_ooool00:Cooooo0ol00002ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Q_ooool00:7ooooo
0ol0000Xooooo`03o`000?oooooooooo00Sooooo0_l00004ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h0Q_ooool009oooooo0_l0000[ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo
0000S_ooool009cooooo0ol000000ooooooo0000ooooo`0Zooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0S?ooool009[ooooo0_l00005ooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`2;ooooo`00Uoooool3o`0003;ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`2:ooooo`00K?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^02?ooooo0ol000000ooooooo0000ooooo`0booooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0ROooool006cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Qooooo`;o0000>?ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo08Wooooo001/ooooo`05oa0@4?oooooooooo
ooooool@41007_ooool3o`0003[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`28
ooooo`00K?ooool01Ol0003ooooooooooooooooo000001cooooo0ol0000looooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0Qoooool006cooooo00Go0000ooooooooooooooooo`00000I
ooooo`?o00000_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool0Q_ooool006cooooo00Go410@oooooooooooooooooa0@400Gooooo`;o0000@_ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo08Kooooo001/ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL05?ooool3o`0004Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`25
ooooo`00K?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^017ooooo0ol00002ooooo`03o`000?oooooo
oooo04;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`24ooooo`00P?ooool2o`00
04[ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`23ooooo`00OOooool3o`0004co
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`22ooooo`00Noooool2o`000003oooo
ool0003ooooo04cooooo00?o0000ooooooooool05?ooool2o`0008?ooooo001hooooo`?o0000DOoo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooo000008?ooooo001eooooo`?o0000E?ooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo083ooooo001cooooo`Co0000EOooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo07oooooo001`ooooo`?o00001?ooool00ol0003o
ooooooooo`1Booooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0Ooooool006kooooo
0_l0001Looooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0O_ooool004?ooooo1?l0
00000ol@413oooooooooo`0Qooooo`?o0000G_ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo07gooooo0015ooooo`03o`000?oooooooooo023ooooo0ol00003ooooo`03o`000?oooooo
oooo05_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1looooo`00>_ooool6o`00
00Gooooo00?o0000ooooooooool07_ooool2o`0006Cooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`1looooo`00AOooool00ol0003oooooooooo`0Kooooo`?o0000I_ooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo07_ooooo0015ooooo`03o`000?oooooooooo01Wooooo
0_l00002ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`1jooooo`00AOooool00ol0003oooooooooo`0Fooooo`?o0000Joooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo07Wooooo0015ooooo`03o`000?oooooooooo01Cooooo0_l0001^
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0NOooool004?ooooo00?oEEEEofIV
I_l000004oooool3o`000003ooooool0003ooooo06gooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`1hooooo`00E_ooool3o`0007?ooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`1gooooo`00E?ooool2o`0007Kooooo00?o0000ooooooooool07oooool2o`0007Sooooo
001Aooooo`?o000000?oooooo`000?ooool0MOooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo07Kooooo001?ooooo`;o0000Noooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo07Gooooo001<ooooo`?o0000OOooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
07Cooooo0019ooooo`Co0000Ooooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo07?o
oooo0017ooooo`;o00001?ooool00ol0003oooooooooo`1looooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool0L_ooool004Cooooo0ol00025ooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool0L_ooool001[ooooo1Ol0000Sooooo`?o0000Qoooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo077ooooo000Jooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@08?ooool3
o`0000?ooooo00?o0000ooooooooool0Q?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo073ooooo000Booooo`Ko00000oooool00onHV9So8B4Qonk^kP0Oooooo`;o0000SOooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo06oooooo000Looooo`03oiRHV?lQ8B7ok^k^01_o
oooo0ol0002?ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0Koooool001gooooo
00?oMgMgofIVI_ooool05oooool3o`0000?ooooo00?o0000ooooooooool0S?ooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooooooo06kooooo000Nooooo`03o`000?oooooooooo01Cooooo0_l0
002Eooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0KOooool001[ooooo00Go0000
okZj^_ooooooV9RHoa0@400Cooooo`?o0000Uoooool00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo06cooooo000Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`04Oooool2o`0000?ooooo00?o
0000ooooooooool0U?ooool00ol0003oooooooooo`0Zooooo`;o0000KOooool002gooooo0ol0002L
ooooo`03o`000?oooooooooo02[ooooo0_l0001]ooooo`00:_ooool3o`0009oooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`1Zooooo`00:?ooool2o`0000?ooooo00?o0000oooooooo
ool0W?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo06Wooooo000Uooooo`?o0000
Y?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo06Wooooo000Tooooo`03o`000?oo
oooooooo0:Gooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1Xooooo`006_ooool4
o`000003oa0@4?oooooooooo00?ooooo0_l0002Vooooo`03o`000?oooooooooo02oooooo00?o0000
ooooooooool0Ioooool001cooooo00?o0000ooooooooool01Oooool2o`000:Kooooo00?o0000oooo
ooooool0<?ooool00ol0003oooooooooo`1Vooooo`004Oooool6o`0000Gooooo00?o0000oooooooo
ool01?ooool4o`000:Gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`08ooooo`Go
0000FOooool001cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0002Tooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool01OnHV9So8B4Qonk^k_ooooooA4A4
05Wooooo000Looooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`2Qooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool01oooool00onHV9So
8B4Qonk^kP1Jooooo`007?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0X?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Oooooo
00?oV9RHob4Q8Oo^k^h0FOooool001cooooo00?o0000ooooooooool01?ooool2o`0000Gooooo00?o
0000ooooooooool0Woooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Oooooo00?o
MgMgofIVI_ooool0F?ooool001[ooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo09kooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo05Oooooo000Sooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0WOooool00ol0003oooooooooo`0eooooo`;o00001?ooool01Ol0003o^[ZjoooooonHV9So
410@05Wooooo000Sooooo`;o00002?ooool00ol0003oooooooooo`2Looooo`03o`000?oooooooooo
03?ooooo0_l000000ooooooo0000ooooo`03ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0FOooool0
02?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2Kooooo`03o`000?oooooooooo
03Oooooo00?o0000ooooooooool0Goooool002?ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`2Jooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0Goooool002?ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`2Hooooo`;o0000>_ooool00ol0003ooooo
ooooo`1Nooooo`008_ooool2o`0000gooooo00?o0000ooooooooool0U?ooool3o`000003ooooool0
003ooooo03[ooooo00?o0000ooooooooool0GOooool002;ooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`2@ooooo`?o00001Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooo
oooo05cooooo000Rooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0S?ooool3o`00
00Wooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1Looooo`008_ooool3o`0000oo
oooo00?o0000ooooooooool0R?ooool3o`0000gooooo00?o0000ooooooooool0>?ooool00ol0003o
ooooooooo`1Kooooo`008_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo08Gooooo
0_l0000Aooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0F_ooool002;ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`21ooooo`?o00005?ooool00ol0003ooooooooo
o`0hooooo`03o`000?oooooooooo05Wooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool0OOooool3o`0001Oooooo00?o0000ooooooooool0>?ooool00ol0003ooooo
ooooo`1Iooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1iooooo`?o0000
6oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo05Sooooo0005o`0000;ooooo00Go
410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`1eooooo`?o00007oooool00ol0003oooooooooo`0hooooo`03o`00
0?oooooooooo05Oooooo0007ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8b
ooooo`03ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0LOooool3o`0002?ooooo
00?o0000ooooooooool0=oooool2o`0005Sooooo0007ooooo`05o`000?ooooooooooooooool00000
3?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`1^ooooo`;o00009oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo05Go
oooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`;o
00006Oooool00ol0003oooooooooo`1Zooooo`?o0000:_ooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo05Gooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0I_ooool3o`0002go
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1Dooooo`001oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool0H_ooool3o`00037ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1Cooooo`00
8Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo05kooooo0ol0000eooooo`03o`00
0?oooooooooo03Sooooo00?o0000ooooooooool0D_ooool0023ooooo0ol0000Mooooo`03o`000?oo
oooooooo05_ooooo0_l0000iooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0D_oo
ool0027ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1Gooooo`?o0000??ooool0
0ol0003oooooooooo`0gooooo`03o`000?oooooooooo057ooooo000Pooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool0Doooool3o`00043ooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`1@ooooo`008?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo04oo
oooo0ol00013ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0Coooool0023ooooo
0_l0000Rooooo`03o`000?oooooooooo04_ooooo0ol00017ooooo`03o`000?oooooooooo03Oooooo
00?o0000ooooooooool0Coooool0023ooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`18ooooo`;o0000Boooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo04kooooo000P
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0A?ooool3o`0004kooooo00?o0000
ooooooooool0=oooool00ol0003oooooooooo`1=ooooo`008?ooool3o`0002Cooooo00?o0000oooo
ooooool0@?ooool3o`0005;ooooo00?o0000ooooooooool0=_ooool2o`0004kooooo000Pooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0??ooool3o`0005Kooooo00?o0000oooooooo
ool0=_ooool00ol0003oooooooooo`1<ooooo`005?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oo
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0hooooo`?o0000FOooool00ol0003o
ooooooooo`0gooooo`03o`000?oooooooooo04_ooooo000Dooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo03Gooooo0_l0001Mooooo`03
o`000?oooooooooo03Oooooo00?o0000ooooooooool0B_ooool001Cooooo00Go410@oooooooooooo
oooooa0@4006ooooo`;o0000:_ooool00ol0003oooooooooo`0aooooo`?o0000H?ooool00ol0003o
ooooooooo`0gooooo`03o`000?oooooooooo04Wooooo000Dooooo`05o`000?ooooooooooooooool0
00001_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo02gooooo0ol0001Tooooo`03
o`000?oooooooooo03Kooooo00?o0000ooooooooool0BOooool001Cooooo00Go0000oooooooooooo
ooooo`000006ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0:Oooool3o`0006So
oooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`18ooooo`005?ooool01Ol@413ooooo
oooooooooooo410@00Kooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Uooooo`?o
0000K?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo04Oooooo000Dooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool2o`0002kooooo00?o0000ooooooooool08Oooool3o`0006oo
oooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`16ooooo`005?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Nooooo`;o
0000Loooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo04Gooooo000Oooooo`03o`00
0?oooooooooo02oooooo00?o0000ooooooooool06_ooool3o`0007Kooooo00?o0000ooooooooool0
=_ooool00ol0003oooooooooo`15ooooo`007_ooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo01Kooooo0ol0001jooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0A?oo
ool001kooooo0_l0000cooooo`03o`000?oooooooooo01;ooooo0ol0001nooooo`03o`000?oooooo
oooo03Kooooo0_l00014ooooo`007_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo
00kooooo0ol00022ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooool00000A?ooool001ko
oooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0;ooooo`;o0000QOooool00ol0003o
ooooooooo`0fooooo`03o`000?oooooooooo04;ooooo000Nooooo`03o`000?oooooooooo03Gooooo
00?o0000ooooooooool01oooool3o`0008Sooooo00?o0000ooooooooool0=_ooool00ol0003ooooo
ooooo`11ooooo`007_ooool2o`0003Oooooo00?o0000ooooooooool00oooool3o`0008cooooo00?o
0000ooooooooool0=_ooool00ol0003oooooooooo`10ooooo`007_ooool00ol0003oooooooooo`0g
ooooo`03o`000?oooooo000000;o0000T?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooo
oooo03oooooo000Nooooo`03o`000?oooooooooo03Kooooo0ol0002Dooooo`03o`000?oooooooooo
03Gooooo00?o0000ooooooooool0?oooool001kooooo0_l0000eooooo`;o00000oooool00ol0003o
ooooooooo`2Booooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool02Oooool2o`000003
oa0@4?oooooooooo033ooooo000Mooooo`03o`000?oooooooooo03;ooooo0ol00006ooooo`03o`00
0?oooooooooo097ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo037ooooo0002ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo
00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo02oooooo0ol0000:ooooo`03
o`000?oooooooooo097ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`05ooooo`Go
0000<_ooool000;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo
<S8booooo`04ooooo`03o`000?oooooooooo02cooooo0ol0000>ooooo`03o`000?oooooooooo097o
oooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`05ooooo`04odA4A?oMgMgoooooo`00
03?ooooo0002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03oooo
o`;o0000:_ooool3o`0001;ooooo00?o0000ooooooooool0TOooool00ol0003oooooooooo`0eoooo
o`03o`000?oooooooooo00Cooooo00CogMgMoeEEEOoooooo0000<oooool000;ooooo00Go0000oooo
ooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool09oooool2
o`0001Kooooo00?o0000ooooooooool0TOooool00ol0003oooooooooo`0eooooo`03o`000?oooooo
oooo00Cooooo00?oMgMgolc<c?l00000<oooool000;ooooo00Go0000ooooooooooooooooo`00000<
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Tooooo`?o00006Ooo
ool00ol0003oooooooooo`2Aooooo`03o`000?oooooooooo03Cooooo0_l00005ooooo`03onk^k_m4
A4Co000003?ooooo0002ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo027ooooo0ol0000Mooooo`03o`000?oooooooooo093ooooo00?o
0000ooooooooool0<oooool01?l0003oooooooooool00005ooooo`03ogMgMol0003ooooo03;ooooo
0002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`;o0000
7oooool3o`00027ooooo00?o0000ooooooooool0H?ooool4oonI02cooooo00?o0000ooooooooool0
2?ooool4oonI02Wooooo00?o0000ooooooooool0>?ooool000;ooooo00Gok^k^oc8b<_l0003o<S8b
onk^kP0<ooooo`Co00001Oooool00ol0003oooooooooo`0Looooo`?o00009Oooool00ol0003ooooo
ooooo`1Oooooo`04oonI0?ooooooooooooooo`GooiT0:?ooool01?l0003oooooooooooooool6oonI
02kooooo00?o0000ooooooooool0=oooool001cooooo00?o0000ooooooooool06Oooool3o`0002Wo
oooo00?o0000ooooooooool0GOooool00oooV@3oooooooooo`07ooooo`_ooiT07?ooool2oonI0003
o`000?ooV@3ooiT003Gooooo00?o0000ooooooooool0=_ooool001cooooo00?o0000ooooooooool0
5oooool2o`0002gooooo00?o0000ooooooooool0G?ooool00oooV@3oooooooooo`0BoooooacooiT0
0oooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo03Gooooo000Looooo`;o00005Ooo
ool3o`00033ooooo00?o0000ooooooooool0F_ooool00oooV@3oooooooooo`0cooooo`03o`000?oo
oooooooo03Cooooo00?o0000ooooooooool0=Oooool001cooooo00?o0000ooooooooool04Oooool3
o`0003Cooooo00?o0000ooooooooool0FOooool00oooV@3oooooooooo`0cooooo`03o`000?oooooo
oooo03Gooooo00?o0000ooooooooool0=?ooool001cooooo00?o0000ooooooooool03_ooool3o`00
03Sooooo00?o0000ooooooooool0F?ooool00oooV@3oooooooooo`0dooooo`03o`000?oooooooooo
03Gooooo00?o0000ooooooooool0<oooool001cooooo00?o0000ooooooooool02oooool3o`0003co
oooo00?o0000ooooooooool0E_ooool00oooV@3oooooooooo`0fooooo`03o`000?oooooooooo03Go
oooo00?o0000ooooooooool0<_ooool001cooooo0_l0000:ooooo`;o0000@?ooool00ol0003ooooo
ooooo`1Eooooo`03oonI0?oooooooooo03Oooooo00?o0000ooooooooool0=?ooool00ol0003ooooo
ooooo`0booooo`006oooool2o`0000Sooooo0ol00013ooooo`03o`000?oooooooooo05?ooooo00?o
oiT0ooooooooool0>Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo037ooooo000K
ooooo`03o`000?oooooooooo00Cooooo0ol00017ooooo`03o`000?oooooooooo057ooooo00?ooiT0
ooooooooool02_ooool00oo<o`3oooooooooo`0^ooooo`03o`000?oooooooooo03?ooooo0_l0000b
ooooo`006oooool01?l0003oooooooooooooool3o`0004_ooooo00?o0000ooooooooool0Coooool0
0oooV@3oooooooooo`0:ooooo`;oc?l0<?ooool00ol0003oooooooooo`0eooooo`03o`000?oooooo
oooo02oooooo000Kooooo`Co0000Coooool00ol0003oooooooooo`1>ooooo`03oonI0?oooooooooo
00Sooooo0_o<o`000oooooooc?l0ooooo`0`ooooo`04o`000?ooooooooooooooo`Coc?l0;oooool0
0ol0003oooooooooo`0_ooooo`006oooool2o`0005;ooooo00?o0000ooooooooool0C?ooool00ooo
V@3oooooooooo`04ooooo`Goc?l00_ooool00oo<o`3oooooooooo`0]ooooo`Coc?l000?o0000olco
0?o<o`00=?ooool00ol0003oooooooooo`0^ooooo`004Oooool4o`000003oa0@4?oooooooooo00Go
oooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`1:ooooo`03oonI0?oooooooooo00Wo
oooo1Oo<o`0Xooooo`Koc?l01Oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02go
oooo000Cooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0D?ooool00ol0003ooooo
ooooo`17ooooo`;ooiT03_ooool00oo<o`3oooooooooo`0:olco017ooooo3Oo<o`0<ooooo`03o`00
0?oooooooooo03Cooooo00?o0000ooooooooool0;?ooool001?ooooo00?o0000ooooooooool02Ooo
ool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo04Gooooo00?ooiT0ooooooooool03Ooo
ool00oo<o`3oooooooooo`0;oooooa7oc?l06_ooool00ol0003oooooooooo`0cooooo`03o`000?oo
oooooooo02cooooo000Cooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0D?ooool0
0ol0003oooooooooo`13ooooo`03oonI0?oooooooooo00kooooo00?oc?l0ooooooooool0=_ooool0
0ol0003oooooooooo`0dooooo`03o`000?oooooooooo02_ooooo000Cooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`11ooooo`03oonI0?oooooooooo
00kooooo00?oc?l0ooooooooool0>?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo
02[ooooo000Cooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0D?ooool00ol0003o
ooooooooo`0nooooo`;ooiT04?ooool00oo<o`3oooooooooo`0jooooo`03o`000?oooooooooo03Co
oooo00?o0000ooooooooool0:Oooool001?ooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`1@ooooo`03o`000?oooooooooo03cooooo00?ooiT0ooooooooool03oooool00oo<o`3ooooo
ooooo`0;ooooo`;o<ol0;oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02Sooooo
000Aooooo`03oeEEEOmVIVKo0000013ooooo00?o0000ooooooooool0D?ooool00ol0003ooooooooo
o`0jooooo`03oonI0?oooooooooo00oooooo00?oc?l0ooooooooool02_ooool3oc?o037ooooo00?o
0000ooooooooool0<oooool00ol0003oooooooooo`0Xooooo`009Oooool00ol0003oooooooooo`1@
ooooo`03o`000?oooooooooo03Sooooo00?ooiT0ooooooooool04?ooool00oo<o`3oooooooooo`08
ooooo`;o<ol000?ooooooc?o0?ooool0<_ooool00ol0003oooooooooo`0booooo`;o0000:Oooool0
02Kooooo0_l0001Aooooo`03o`000?oooooooooo03Kooooo00?ooiT0ooooooooool04?ooool00oo<
o`3oooooooooo`07ooooo`;o<ol00_ooool00olco`3oooooooooo`0booooo`03o`000?oooooooooo
03Cooooo00?o0000ooooooooool09_ooool002Sooooo00?o0000ooooooooool0C_ooool00ol0003o
ooooooooo`0dooooo`;ooiT04_ooool00oo<o`3oooooooooo`06ooooo`;o<ol01?ooool00olco`3o
ooooooooo`0cooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool09Oooool002Wooooo
00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0aooooo`;ooiT04_ooool01?o<o`3o<ol0
oc?o0?lco`04ooooo`?o<ol01Oooool00olco`3oooooooooo`0`ooooo`Co<ol000?oooooo`000?oo
ool0=?ooool00ol0003oooooooooo`0Uooooo`00:_ooool00ol0003oooooooooo`1>ooooo`03o`00
0?oooooooooo02oooooo00?ooiT0ooooooooool04Oooool00oo<o`3oooooooooo`06oc?o00Sooooo
00?o<ol0ooooooooool0:Oooool7oc?o00Kooooo00?o0000ooooooooool0<oooool00ol0003ooooo
ooooo`0Tooooo`00:oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo02cooooo0_oo
V@0Cooooo`03olco0?oooooooooo00Oooooo3Olco`0Pooooo`Oo<ol03_ooool00ol0003ooooooooo
o`0cooooo`03o`000?oooooooooo02?ooooo000/ooooo`03o`000?oooooooooo04kooooo00?o0000
ooooooooool0:Oooool2oonI01Cooooo00?oc?l0ooooooooool03_ooool00olco`3oooooooooo`04
ooooob3o<ol05_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02;ooooo000]oooo
o`03o`000?oooooooooo04kooooo00?o0000ooooooooool09oooool00oooV@3oooooooooo`0Coooo
o`03olco0?oooooooooo00oooooo00?o<ol0ooooooooool02oooool00ol0ofKoooooooooo`0/oooo
o`03o`000?oooooooooo03?ooooo00?o0000ooooooooool08_ooool002kooooo00?o0000oooooooo
ool0C_ooool00ol0003oooooooooo`0Tooooo`;ooiT05?ooool2olco017ooooo00?o<ol0oooooooo
ool02oooool2o`3oIRoooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Qooooo`00
;oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo02;ooooo00?ooiT0ooooooooool0
4oooool00oo<o`3oooooooooo`0@ooooo`03oc?o0?oooooooooo00_ooooo0_l0ofHaooooo`03o`00
0?oooooooooo03?ooooo00?o0000ooooooooool08?ooool0033ooooo00?o0000ooooooooool0C_oo
ool00ol0003oooooooooo`0fooooo`03olco0?oooooooooo013ooooo00?o<ol0ooooooooool02_oo
ool3o`3oIS?ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Oooooo`00<Oooool2
o`0004oooooo00?o0000ooooooooool0=?ooool00oo<o`3oooooooooo`0Aooooo`03oc?o0?oooooo
oooo00Sooooo0_l0ofH2ooooo`03o`3oI_oooooooooo03;ooooo00?o0000ooooooooool0<_ooool2
o`00023ooooo000cooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0<_ooool00oo<
o`3oooooooooo`0Aooooo`03oc?o0?oooooooooo00Sooooo00Go0?mVooooooooooooooooo`3oIP0f
ooooo`03o`000?oooooooooo037ooooo0_l0000Pooooo`00=?ooool00ol0003oooooooooo`1=oooo
o`03o`000?oooooooooo02oooooo0_o<o`0Booooo`;o<ol02?ooool3o`3oIPCooooo00?o0?mVoooo
ooooool0=?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo01gooooo000eooooo`03
o`000?oooooooooo04gooooo00?o0000ooooooooool0;?ooool2olco01?ooooo00?o<ol0oooooooo
ool01Oooool3o`3oIPKooooo00?o0?mVooooooooool0=_ooool00ol0003oooooooooo`0cooooo`03
o`000?oooooooooo01cooooo000fooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0
:Oooool2olco01Cooooo00?o<ol0ooooooooool01_l0ofH8ooooo`03o`3oI_oooooooooo02cooooo
1?l0ofH8ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool07?ooool003Oooooo00?o
0000ooooooooool0COooool00ol0003oooooooooo`0Vooooo`;oc?l04?ooool9o`3oIPgooooo00?o
0?mVooooooooool02oooool2o`3ooaWooooo1ol0ofH=ooooo`03o`000?oooooooooo03;ooooo00?o
0000ooooooooool06oooool003Sooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0T
ooooo`03olco0?oooooooooo01?ooooo00?o<ol0ooooooooool02Ol0ofH6ooooo`03o`3oI_oooooo
oooo00_ooooo00?o0?ooooooool0ool04_ooool7o`3oIQGooooo00?o0000ooooooooool0<_ooool0
0ol0003oooooooooo`07ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`03_ooool003Wooooo00?o0000
ooooooooool0COooool00ol0003oooooooooo`0Qooooo`;oc?l05Oooool00olco`3oooooooooo`0:
ooooo`Wo0?mV2_ooool00ol0ooooooooo`3oo`03oooooa3o0?mV7Oooool00ol0003oooooooooo`0b
ooooo`03o`000?oooooooooo00Kooooo00GoEEEEogMgMoooooooV9RHob4Q8@0>ooooo`00>_ooool0
0ol0003oooooooooo`1=ooooo`03o`000?oooooooooo01kooooo0_o<o`0Fooooo`03oc?o0?oooooo
oooo013ooooo00Co0?mVoooooooooooooooo2Ol0ofH00ol0oooo0?mVo`3oo`04o`3oIRgooooo00?o
0000ooooooooool0<oooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool00000
3_ooool003_ooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0Looooo`03olco0?oo
oooooooo01Cooooo0_lco`0Booooo`03o`3oI_oooooooooo00Wooooo0_l0ool00ooooooo0?oooooo
o`0booooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool01Oooool01Ol0003oV9RHoooo
oonHV9So8B4Q00kooooo000looooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0<Ooo
ool00olco`3oooooooooo`0Aooooo`03o`3oI_oooooooooo00Sooooo0_l0ool2ooooo`03o`3ooooo
oooooooo03?ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`04ooooo`05o`000?mE
EEGo0000oa0@4?o<c<`03_ooool003gooooo0_l0001>ooooo`03o`000?oooooooooo02oooooo00?o
<ol0ooooooooool04Oooool00ol0ofKoooooooooo`08ooooo`03o`3ooooooooooooo00;ooooo00?o
0?ooooooooooool0=?ooool00ol0003oooooooooo`0booooo`;o00001?ooool00omEEEGoQhN7oooo
o`0@ooooo`00?oooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo02cooooo0_lco`0B
ooooo`;o0?mV2Oooool2o`3oo`Cooooo00?o0?ooooooooooool0=_ooool00ol0003oooooooooo`0_
ooooo`;o000000?oooooo`000?ooool00oooool00ooMgMgo410@oiRHV00@ooooo`00@?ooool00ol0
003oooooooooo`1<ooooo`03o`000?oooooooooo02Wooooo0_lco`0Cooooo`03o`3oI_oooooooooo
00Oooooo0_l0ool5ooooo`03o`3ooooooooooooo03Sooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`03ooooo`04olc<c?m4A4Co0000oa0@40kooooo0011ooooo`03o`000?oooooooooo
04cooooo00?o0000ooooooooool09oooool00olco`3oooooooooo`0Booooo`03o`3oI_oooooooooo
00Gooooo0ol0ool6ooooo`03o`3ooooooooooooo00cooooo00?o06Koooooooooool0:_ooool00ol0
003oooooooooo`0booooo`03o`000?oooooooooo01Cooooo0012ooooo`03o`000?oooooooooo04co
oooo00?o0000ooooooooool09?ooool2oc?o01Cooooo00?o0?mVooooooooool00oooool3o`3oo`So
oooo00?o0?ooooooooooool03?ooool2o`1Vobgooooo00?o0000ooooooooool0<_ooool00ol0003o
ooooooooo`0Cooooo`00@oooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo027ooooo
0_lco`0Eooooo`03o`3oI_oooooooooo00Co0?oo2_ooool00ol0ooooooooooooo`0<ooooo`;o06Ko
6oooool5o`3oo`oooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Booooo`00A?oo
ool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo01kooooo0_lco`09ooooo`Oo0?oo1Ooo
ool5o`3oo`kooooo00?o0?ooooooooooool02oooool2o`1VoaCooooo2?l0oolEooooo`03o`000?oo
oooooooo037ooooo00?o0000ooooooooool04_ooool004Gooooo00?o0000ooooooooool0C?ooool0
0ol0003oooooooooo`0Looooo`03oc?o0?oooooooooo00gooooo2?l0oolBooooo`03o`3ooooooooo
oooo00_ooooo00?o06Koooooool0I_l03Oooool7o`3ooakooooo00?o0000ooooooooool0<Oooool0
0ol0003oooooooooo`0Aooooo`00A_ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo
01Wooooo0_lco`0Eooooo`go0?oo1oooool00ol0ooooooooooooo`0;ooooo`03o`1Vool0oooo06Ko
00ko0?oo9_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo013ooooo0017ooooo`03
o`000?oooooooooo04cooooo00?o0000ooooooooool05oooool00olco`3oooooooooo`0Eooooo`03
o`3oI_oooooooooo00[ooooo4ol0ool2o`1Vo`03o`3ooooooooo06Ko03Cooooo00?o0000oooooooo
ool0<_ooool00ol0003oooooooooo`0?ooooo`00B?ooool2o`0004gooooo00?o0000ooooooooool0
;Oooool00ol0ofKoooooooooo`0?ooooo`;o0?oo2oooool2o`1Vo`?ooooo00?o06Koooooooooool0
=?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00oooooo001:ooooo`03o`000?oo
oooooooo04_ooooo00?o0000ooooooooool0:oooool00ol0ofKoooooooooo`0?ooooo`03o`3ooooo
oooooooo00Wooooo0_l0I_l4ooooo`03o`1Voooooooooooo03Kooooo00?o0000ooooooooool0<Ooo
ool2o`0000oooooo001;ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0:?ooool2
o`3oIQ7ooooo00?o0?ooooooooooool02Oooool00ol0I_ooooooooooo`03ooooo`03o`1Voooooooo
oooo00cooooo00?o<`3oooooooooool0:Oooool00ol0003oooooooooo`0`ooooo`;o00003oooool0
04cooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0Uooooo`;o0?mV4_ooool00ol0
ooooooooooooo`08ooooo`;o06Ko1Oooool00ol0I_ooooooooooo`0;ooooo`?o<`3o;?ooool00ol0
003oooooooooo`0aooooo`03o`000?oooooooooo00cooooo001=ooooo`03o`000?oooooooooo04_o
oooo00?o0000ooooooooool08_ooool2o`3oIQ;ooooo0_l0ool8ooooo`?o06Ko1_ooool00ol0I_oo
ooooooooo`0;ooooo`03oc<0oooooooo<`3o02kooooo00?o0000ooooooooool0<Oooool00ol0003o
ooooooooo`0;ooooo`00C_ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo01oooooo
0_l0ofHCooooo`03o`3ooooooooooooo00Cooooo1?l0I_l9ooooo`03o`1Voooooooooooo00[ooooo
00?o<`3ooooooolc0?l0;oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00_ooooo
001?ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool07?ooool2o`3oIQCooooo00?o
0?ooooooooooool00_ooool3o`1Vo`cooooo00?o06Koooooooooool02_ooool01?lc0?oooooooooo
oolc0?l`ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool02_ooool0053ooooo00?o
0000ooooooooool0Boooool00ol0003oooooooooo`0Iooooo`;o0?mV5Oooool00ol0oooo06Koo`1V
o`03o`1Vo`kooooo00?o06Koooooooooool02_ooool01?lc0?oooooooooooolc0?lbooooo`03o`00
0?oooooooooo037ooooo00?o0000ooooooooool02Oooool0057ooooo00?o0000ooooooooool0Booo
ool00ol0003oooooooooo`0Fooooo`;o0?mV4_ooool6o`1Voa;ooooo00?o06Koooooooooool02_oo
ool01?lc0?oooooooooooolc0?lGooooo`Go06Ko6?ooool00ol0003oooooooooo`0aooooo`03o`00
0?oooooooooo00Sooooo001Booooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04ooo
ool2o`3oIPGooooo3ol0I_l2ooooo`03o`3ooooooooooooo01;ooooo00?o06Koooooooooool02Ooo
ool2oc<0o`?ooooo00?o<`3oooooooooool03Oooool8o`1Voakooooo00?o0000ooooooooool0<?oo
ool00ol0003oooooooooo`08ooooo`00Doooool2o`0004cooooo00?o0000ooooooooool04Oooool0
0ol0ofKoooooooooo`0;ooooo`_o06Ko4oooool2o`1Vo`[ooooo0_lc0?l4ooooo`03oc<0oooooooo
oooo00Kooooo2?l0I_lWooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool01oooool0
05Gooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0Wooooo`03o`3ooooooooo06Ko
00[o06Ko1oooool00ol0I_ooooooooooo`08ooooo`03o`1Voolc0?oo06Ko00Co06Ko00?o<`3oo`1V
ool0I_l01ol0I_l5ooooo`03ol`0oooooooooooo02Oooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`06ooooo`00E_ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo02Co
oooo0_l0ool=oooooa7o06Ko0_lc0?l5ooooo`03oc<0oooooooooooo00cooooo0_o<0?lZooooo`03
o`000?oooooooooo02oooooo0ol00007ooooo`00Eoooool00ol0003oooooooooo`1:ooooo`03o`00
0?oooooooooo027ooooo0_l0oolDooooo`03o`1Voooooooooooo00Oooooo0_lc0?l6ooooo`03oc<0
oooooooooooo00cooooo0_o<0?l/ooooo`03o`000?oooooooooo02_ooooo0ol00002ooooo`03o`00
0?oooooooooo00Gooooo001Hooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool07ooo
ool00ol0ooooooooooooo`0Booooo`;o06Ko2Oooool00olc0?ooooooooooo`05ooooo`03oc<0oooo
oooooooo00cooooo0_o<0?l^ooooo`03o`000?oooooooooo02Oooooo0ol00005ooooo`03o`000?oo
oooooooo00Gooooo001Iooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool07?ooool2
o`3ooaCooooo00?o06Koooooooooool01oooool2oc<0o`Oooooo00?o<`3oooooooooool03?ooool0
0oo<0?oooooool`0o`0_ooooo`03o`000?oooooooooo02;ooooo1?l00008ooooo`03o`000?oooooo
oooo00Gooooo001Jooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool06Oooool2o`3o
oaGooooo00?o06Koooooooooool01Oooool3oc<0o`Sooooo00?o<`3oooooooooool03?ooool00oo<
0?oooooool`0o`0aooooo`03o`000?oooooooooo01kooooo0ol0000<ooooo`03o`000?oooooooooo
00Gooooo001Kooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool05_ooool2o`3ooaKo
oooo00?o06Koooooooooool00oooool3oc<0o`[ooooo00?o<`3oooooooooool03?ooool00oo<0?oo
oooool`0o`0booooo`03o`000?oooooooooo01[ooooo1?l0000?ooooo`03o`000?oooooooooo00Go
oooo001Looooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool04oooool2o`3ooaOooooo
00Co06Kooooooooooooooooo0olc0?l<ooooo`03oc<0oooooooooooo00cooooo00Coc03ooooooooo
ooooc03o<oooool00ol0003oooooooooo`0Fooooo`?o00005?ooool00ol0003oooooooooo`04oooo
o`00GOooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo017ooooo00?o0?oooooooooo
ool05Oooool2o`1Vo`04oooooolc0?oo<`3ooc<0o`kooooo00?o<`3oooooooooool03?ooool01?o<
0?ooooooooooooo<0?leooooo`03o`000?oooooooooo01;ooooo0ol0000Gooooo`03o`000?oooooo
oooo00Cooooo001Nooooo`;o0000Boooool00ol0003oooooooooo`0>ooooo`;o0?oo4oooool8oc<0
o`oooooo0_lc0?l=ooooo`;oc03o0_ooool00oo<0?ooooooooooo`0<ooooo`03ool0VOoooooooooo
00;ooooo1Olc0?lOooooo`03o`000?oooooooooo00gooooo1?l0000Jooooo`03o`000?oooooooooo
00Cooooo001Pooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool02ooooolGoc<0o`?o
oooo00?o06Koooooooooool04?ooool00olc0?ooooooooooo`0;ooooo`;oc03o0oooool00oo<0?oo
ooooooooo`09ooooo`Co<`3o00?oo`2Ioc<0oolc0?l00_lc0?lUooooo`03o`000?oooooooooo00Wo
oooo0ol0000Nooooo`03o`000?oooooooooo00Cooooo001Qooooo`03o`000?oooooooooo04Wooooo
00?o0000ooooooooool04Oooool;oc<0o`Oooooo00?o06Koooooooooool04?ooool00olc0?oooooo
ooooo`0:ooooo`;oc03o1?ooool01?o<0?ooooooooooooooool9oc<0o`?ooooo00?oo`2Ioooooooo
ool0:Oooool00ol0003oooooooooo`04ooooo`Co00008Oooool00ol0003oooooooooo`04ooooo`00
H_ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo01_ooooo3?lc0?l<ooooo`;o<`3o
1Oooool6oc<0o`;oc03o1Olc0?l00oo<0?oo<`3ooc<0o`02oc<0o`[ooooo0_oo09T/ooooo`04o`00
0?ooooooooooooooo`?o00009Oooool00ol0003oooooooooo`04ooooo`00Hoooool00ol0003ooooo
ooooo`19ooooo`03o`000?oooooooooo01gooooo0_l0I_l7oooooa?o<`3o1Oooool00oo<0?oooooo
ooooo`04ooooo`03ol`0oooooooooooo00cooooo00?oo`2Ioooooooo09T0;Oooool3o`0002Sooooo
00?o0000ooooooooool01?ooool006Cooooo00?o0000ooooooooool0BOooool00ol0003ooooooooo
o`0Jooooo`;o06Ko4oooool00olc0?ooooooooooo`09ooooo`;oc03o1_ooool00oo<0?oooooooooo
o`0<ooooo`03ool0VOooooooo`2I02[ooooo1?l000000ooooooo0000ooooo`0Xooooo`03o`000?oo
oooooooo00Cooooo001Uooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool05oooool2
o`1Voa?ooooo0_lc0?l:ooooo`;oc03o1oooool00oo<0?ooooooooooo`0;ooooo`;oo`2I00?ooooo
ool0VOooool09oooool3o`0000Kooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`04
ooooo`00I_ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo01Cooooo0_l0I_lDoooo
o`03oc<0oooooooooooo00Oooooo0oo<0?l8ooooo`03ol`0oooooooooooo00_ooooo00Goo`2Ioooo
ooooooooooooool0V@0Tooooo`Co00002_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo00Cooooo001Wooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool04Oooool2o`1V
oaGooooo00?o<`3oooooooooool01Oooool3ol`0o`[ooooo00?oc03oooooooooool02oooool01Ooo
09Woooooooooooooooooo`2I02;ooooo0ol0000?ooooo`03o`000?oooooooooo02Gooooo00?o0000
ooooooooool00oooool006Sooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0>oooo
o`;o06Ko5_ooool00olc0?ooooooooooo`03ooooo`?oc03o3?ooool00oo<0?ooooooooooo`0;oooo
o`05ool0VOoooooooooooooooooo09T03_ooool00ooo003oooooooooo`0?ooooo`?o00004_ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00?ooooo001Yooooo`03o`000?oooooooooo
04Wooooo00?o0000ooooooooool02oooool2o`1VoaKooooo0_lc0?l3ooooo`?oc03o3Oooool2ol`0
o`cooooo0_oo09T3ooooo`03ool0VOoooooooooo00cooooo0_oo000=ooooo`Co00005_ooool00ol0
003oooooooooo`0Tooooo`03o`000?oooooooooo00?ooooo001Zooooo`;o0000B_ooool00ol0003o
ooooooooo`08ooooo`;o06Ko5oooool00olc0?ooooooooooo`03ol`0o`oooooo00?oc03ooooooooo
ool02_ooool2ool0V@Cooooo00?oo`2Iooooooooool03?ooool2ool000_ooooo0ol0000Kooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool00oooool006cooooo00?o0000ooooooooool0
B?ooool00ol0003oooooooooo`06ooooo`03o`1Voooooooooooo01Cooooo1_o<0?lAooooo`03ol`0
oooooooooooo00Wooooo0_oo09T5ooooo`03ool0VOoooooooooo00_ooooo0ooo0004ol`0o`Cooooo
1?l0000Oooooo`03o`000?oooooooooo02;ooooo00?o0000ooooooooool00oooool006gooooo00?o
0000ooooooooool0B?ooool<ol`0o`[ooooo2Oo<0?l2oc<0oa?ooooo0_o<0?l:ooooo`;oo`2I1_oo
ool00ooo09Woooooooooo`05ooooo`Koc03o00?oo`00ol`0oooo00001_ooool3o`0002Cooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`03ooooo`00K_ooool00ol0003oooooooooo`18
ooooo`03o`000?oooooooooo00?ooooo3oo<0?l7ooooo`;o<`3o5?ooool00oo<0?ooooooooooo`09
ooooo`03ool0VOoooooooooo00Gooooo00?oo`2Iol`0ooo<0?l01_o<0?l5ooooo`03ool00?oooooo
o`0000Cooooo0ol0000Xooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool00oooool0
06oooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0=ooooo`goc03o4oooool00oo<
0?oooooool`0o`08ol`0o`;oo`2I1oo<0?l00ooo09Woooooooooo`0;ooooo`04ool00?ooooooo`00
ooooo`Co0000:oooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00?ooooo001`oooo
o`03o`000?oooooooooo04Sooooo00?o0000ooooooooool05?ooool00olc0?ooooooooooo`02oooo
oaGoc03o1oooool2ool0V@Sooooo00?oo`2Iooooooooool02oooool01Ooo003oooooo`000?oo003o
0000033ooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`03ooooo`00LOooool00ol0
003oooooooooo`18ooooo`03o`000?oooooooooo017ooooo0_lc0?lEooooo`;oc03o2?ooool2ool0
V@Wooooo00?oo`2Iooooooooool02_ooool01Ol0003oo`00o`000?l0003oo`0003?ooooo00?o0000
ooooooooool07_ooool00ol0003oooooooooo`03ooooo`00L_ooool00ol0003oooooooooo`18oooo
o`03o`000?oooooooooo00kooooo0_lc0?lFooooo`03ol`0oooooooooooo00Kooooo0_oo09T:oooo
o`03ool0VOoooooooooo00Sooooo0ol000001?oo003ooooooooooooo000eooooo`03o`000?oooooo
oooo01kooooo00?o0000ooooooooool00_ooool007?ooooo00?o0000ooooooooool0B?ooool00ol0
003oooooooooo`0;ooooo`;o<`3o5oooool00oo<0?ooooooooooo`04ooooo`?oo`2I2oooool00ooo
09Woooooooooo`06ooooo`?o00000_ooool01?oo003ooooooooooooo000gooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool00_ooool007Cooooo00?o0000ooooooooool0B?ooool00ol0
003oooooooooo`08ooooo`;o<`3o5oooool2ol`0o`Cooooo0ooo09T<ooooo`;oo`2I1Oooool4o`00
00Cooooo00Coo`00ooooooooooooo`00>Oooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo00;ooooo001eooooo`;o0000BOooool00ol0003oooooooooo`06ooooo`03oc<0oooooooooooo
01Kooooo00Coc03ooooooooooooooooo0ooo09T>ooooo`03ool0VOoooooooooo00;ooooo0ol00006
ooooo`;oo`000_ooool00ooo003oooooooooo`0hooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool00_ooool007Oooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`03oooo
o`;o<`3o6?ooool00oo<0?ooooooool0V@02ool0V@oooooo0_oo09T00ooooooo0000o`000002o`00
00Oooooo0_oo0003ooooo`03ool00?oooooooooo03[ooooo00?o0000ooooooooool06oooool00ol0
003oooooooooo`02ooooo`00N?ooool00ol0003oooooooooo`17ooooo`05o`000?oooooooooooooo
oolc0?l06Oooool3ool0VA7ooooo00Coo`2Io`000?l0003o00002_ooool00ooo003oooooooooo`02
ooooo`03ool00?oooooooooo03cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`02
ooooo`00NOooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo01?ooooo1ooo09TBoooo
o`03o`000?oo09Wo000000_ooooo0_oo0005ooooo`03ool00?oooooooooo00_ooooo1?oo09T^oooo
o`03o`000?oooooooooo01Wooooo00?o0000ooooooooool00_ooool007[ooooo00?o0000oooooooo
ool0>Oooool4ool0V@[ooooo00?o0000ooooooooool02Oooool9ool0V@?ooooo0_o<0?l@ooooo`?o
00000_oo09T;ooooo`;oo`001_ooool00ooo003oooooooooo`05ooooo`Ooo`2I<oooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo00;ooooo001kooooo`03o`000?oooooooooo03cooooo
5_oo09T:ooooo`;oc03o3oooool3o`0000;ooooo00?oo`2Iooooooooool02Oooool2ool000Oooooo
00?oo`00oooooooo09T01_oo09Tkooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0
0_ooool007cooooo00?o0000ooooooooool0@?ooool:ool0V@oooooo0_o<0?l=ooooo`Co00000ooo
ool2ool0V@[ooooo0_oo0004ooooo`Coo`2I00?oo`00ool0VOoo09T0@_ooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo00;ooooo001mooooo`03o`000?oooooooooo04Oooooo00?o0000
oooooooo09T03?oo09T2ol`0o`cooooo0ol00005ooooo`goo`2I00?oo`00ool0VOoo09T01?oo09T3
ooooo`03ool00?oooooooooo04Cooooo00?o0000ooooooooool05oooool00ol0003oooooooooo`01
ooooo`00O_ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo00Wooooo0_o<0?lGool0
V@[ooooo0_oo0009ooooo`03ool00?oooooooooo04Kooooo00?o0000ooooooooool05_ooool00ol0
003oooooooooo`01ooooo`00Ooooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo00Ko
oooo0_o<0?l9ooooo`Co00002Oooool00ooo09Woooooooooo`07ooooo`?oo`002Oooool2ool004[o
oooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`01ooooo`00P?ooool2o`0004Sooooo
00?o0000ooooooooool00oooool2ol`0o`Sooooo0ol0000<ooooo`03ool0VOoooooooooo00Gooooo
0ooo000;ooooo`03ool00?oooooooooo04_ooooo00?o0000ooooooooool05?ooool00ol0003ooooo
ooooo`01ooooo`00P_ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo00;oc03o1_oo
ool4o`0000gooooo0_oo09T4ooooo`Coo`003?ooool2ool004oooooo00?o0000ooooooooool04ooo
ool00ol0003oooooooooo`01ooooo`00Poooool00ol0003oooooooooo`16ooooo`;oc03o1Oooool3
o`00013ooooo00Coo`2Ioooooooooooooooo0ooo000?ooooo`03ool00?oooooooooo04oooooo00?o
0000ooooooooool04oooool00ol0003oooooooooo`01ooooo`00Q?ooool00ol0003oooooooooo`14
ooooo`03ol`0oooooooo000000;ooooo0ol0000Aooooo`;oo`2I1?oo000Aooooo`03ool00?oooooo
oooo057ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`01ooooo`00QOooool00ol0
003oooooooooo`16ooooo`;o00004_ooool01?oo09Woo`00ool00?oo000Cooooo`;oo`00EOooool0
0ol0003oooooooooo`0Aooooo`03o`000?oooooooooo007ooooo0026ooooo`03o`000?oooooooooo
04Gooooo00?o0000ooooooooool02oooool7ool001Gooooo00?oo`00ooooooooool06oooool5ool0
03Kooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`01ooooo`00Qoooool00ol0003o
ooooooooo`0Yooooo`Goo`005_ooool00ol0003oooooooooo`0;ool000?ooooo00?oo`2Ioooooooo
ool05?ooool2ool001Oooooo1ooo000looooo`03o`000?oooooooooo00oooooo00?o0000oooooooo
ool00Oooool008Sooooo00?o0000ooooooooool0;?oooolJool000cooooo0_oo09TFooooo`03ool0
0?oooooooooo013ooooo1ooo0014ooooo`03o`000?oooooooooo00oooooo0Ol00001ooooo`7ooooo
0029ooooo`03o`000?oooooooooo037ooooo2_oo0007ooooo`03o`000?oooooooooo00[ooooo0_oo
09TGooooo`03ool00?oooooooooo00[ooooo1ooo001;ooooo`03o`000?oooooooooo00oooooo0Ol0
0001ooooo`7ooooo002:ooooo`03o`000?oooooooooo03[ooooo3ooo0003ooooo`;oo`2I4_oooolD
ool005?ooooo00?o0000ooooooooool03_ooool1o`00007ooooo0Oooool008_ooooo0_l00011oooo
o`03o`000?oooooooooo00Gooooo5ooo0004ooooo`03ool00?oooooooooo067ooooo00?o0000oooo
ooooool03Oooool1o`00007ooooo0Oooool008gooooo00?o0000ooooooooool0?_ooool00ol0003o
ooooooooo`05ooooo`03ool0VOoooooooooo01Kooooo0_oo001Uooooo`03o`000?oooooooooo00co
oooo0Ol00001ooooo`7ooooo002>ooooo`03o`000?oooooooooo03gooooo00?o0000ooooooooool0
0oooool2ool0VASooooo00?oo`00ooooooooool0I_ooool00ol0003oooooooooo`0;ooooo`7o0000
0Oooool1ooooo`00Soooool00ol0003oooooooooo`0looooo`04o`000?ooooooooooooooo`;oo`2I
6Oooool00ooo003oooooooooo`1Xooooo`03o`000?oooooooooo00[ooooo0Ol00001ooooo`7ooooo
002@ooooo`03o`000?oooooooooo03_ooooo00Co0000ooooooooooooo`2I6Oooool2ool006_ooooo
00?o0000ooooooooool02_ooool1o`00007ooooo0Oooool0097ooooo00?o0000ooooooooool0>_oo
ool00ol0003oooooooooo`0Hooooo`;oo`00K_ooool00ol0003oooooooooo`09ooooo`7o00000Ooo
ool1ooooo`00T_ooool00ol0003oooooooooo`0iooooo`03o`000?oooooooooo01Kooooo0_oo001a
ooooo`03o`000?oooooooooo00Sooooo0Ol00001ooooo`7ooooo002Cooooo`03o`000?oooooooooo
03Sooooo00?o0000ooooooooool05?ooool2ool007Cooooo00?o0000ooooooooool02?ooool1o`00
007ooooo002Dooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool04_ooool2ool007Oo
oooo00?o0000ooooooooool01oooool1o`00007ooooo002Eooooo`03o`000?oooooooooo03Kooooo
00?o0000ooooooooool04?ooool2ool007[ooooo00?o0000ooooooooool01_ooool1o`00007ooooo
002Fooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool03_ooool2ool007cooooo00?o
0000ooooooooool01_ooool1o`00007ooooo002Gooooo`;o0000=Oooool00ol0003oooooooooo`0<
ooooo`;oo`00Ooooool00ol0003oooooooooo`05ooooo`7o00000Oooool009Wooooo00?o0000oooo
ooooool0<_ooool00ol0003oooooooooo`0:ooooo`;oo`00P_ooool00ol0003oooooooooo`04oooo
o`7o00000Oooool009[ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`08ooooo`;o
o`00QOooool00ol0003oooooooooo`03ooooo`7o00000Oooool009_ooooo00?o0000ooooooooool0
<?ooool00ol0003oooooooooo`06ooooo`;oo`00R?ooool00ol0003oooooooooo`02ooooo`7o0000
0Oooool009cooooo00?o0000ooooooooool0;oooool00ol0003oooooooooo`05ooooo`03ool00?oo
oooooooo08Wooooo00Go0000ooooooooooooooooo`000001ooooo`00WOooool00ol0003ooooooooo
o`0^ooooo`03o`000?oooooooooo097ooooo00Go0000ooooooooooooooooo`000001ooooo`00W_oo
ool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo09;ooooo00Co0000oooooooooooooooo
0Ol0000009oooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`2Cooooo`03o`000?oo
oooooooo007o0000002Pooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0U?ooool1
o`00007ooooo0Ol000000:7ooooo00?o0000ooooooooool0:_ooool00ol0003oooooooooo`2Eoooo
o`;o0000002Rooooo`;o0000:_ooool00ol0003oooooooooo`2Dooooo`?o0000002Tooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool0T?ooool4o`0000?ooooo002Uooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool0SOooool3o`0000Oooooo002Vooooo`03o`000?oooooo
oooo02Gooooo00?o0000ooooooooool0ROooool4o`0000[ooooo002Wooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool0QOooool4o`0000kooooo002Xooooo`03o`000?oooooooooo02?o
oooo00?o0000ooooooooool0P_ooool3o`0001;ooooo002Yooooo`03o`000?oooooooooo02;ooooo
00?o0000ooooooooool0O_ooool4o`0001Gooooo002Zooooo`03o`000?oooooooooo027ooooo00?o
0000ooooooooool0N_ooool4o`0001Wooooo002[ooooo`03o`000?oooooooooo027ooooo00?o0000
ooooooooool0MOooool4o`0001gooooo002/ooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool0L_ooool3o`00027ooooo002]ooooo`;o00008?ooool00ol0003oooooooooo`1^ooooo`Co
00009?ooool00:oooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1Zooooo`Co0000
:?ooool00;3ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`1Wooooo`?o0000;?oo
ool00;7ooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`1Sooooo`Co0000;oooool0
0;;ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1Oooooo`Co0000<oooool00;?o
oooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`1Looooo`?o0000=oooool00;Cooooo
00?o0000ooooooooool06?ooool00ol0003oooooooooo`1Hooooo`Co0000>_ooool00;Gooooo00?o
0000ooooooooool05oooool00ol0003oooooooooo`1Dooooo`Co0000?_ooool00;Kooooo00?o0000
ooooooooool05_ooool00ol0003oooooooooo`1@ooooo`Co0000@_ooool00;Oooooo00?o0000oooo
ooooool05Oooool00ol0003oooooooooo`1=ooooo`?o0000A_ooool00;Sooooo0_l0000Eooooo`03
o`000?oooooooooo04Wooooo1?l00019ooooo`00^_ooool00ol0003oooooooooo`0Booooo`03o`00
0?oooooooooo04Gooooo1?l0001=ooooo`00^oooool00ol0003oooooooooo`0Aooooo`03o`000?oo
oooooooo04;ooooo0ol0001Aooooo`00_?ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooo
oooo03kooooo1?l0001Dooooo`00_Oooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
03[ooooo1?l0001Hooooo`00__ooool00ol0003oooooooooo`0>ooooo`03o`000?oooooooooo03Ko
oooo1?l0001Looooo`00_oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo03?ooooo
0ol0001Pooooo`00`?ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo02oooooo1?l0
001Sooooo`00`Oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo02_ooooo1?l0001W
ooooo`00`_ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo02Sooooo0ol0001[oooo
o`00`oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo02Cooooo1?l0001^ooooo`00
a?ooool2o`0000Wooooo00?o0000ooooooooool08?ooool4o`0007;ooooo0036ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool07Oooool3o`0007Kooooo0037ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool06Oooool4o`0007Wooooo0038ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool05Oooool4o`0007gooooo0039ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool04Oooool4o`00087ooooo003:ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool03_ooool3o`0008Gooooo003;ooooo`05o`000?ooooooooooooooool00000
3?ooool4o`0008Sooooo003<ooooo`04o`000?ooooooooooo`0000Sooooo1?l0002<ooooo`00cOoo
ool00ol0003oooooo`000005ooooo`?o0000T?ooool00<kooooo0_l000000ooooooo0000o`000002
o`0009?ooooo003?ooooo`;o0000Uoooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOoo
ool00?ooooooJOooool00?ooooooJOooool00001\
\>"],
  ImageRangeCache->{{{0, 359}, {330.375, 0}} -> {-0.0771432, -0.0315529, \
0.00350368, 0.00350368}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .92059 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-16 1.0763 -0.0263982 1.0763 [
[.01694 .18568 -11.9631 -9 ]
[.01694 .18568 .03693 0 ]
[.13793 .13897 -11.619 -9 ]
[.13793 .13897 .38095 0 ]
[.26292 .09073 -5.63752 -9 ]
[.26292 .09073 .36248 0 ]
[.39212 .04087 -5.46552 -9 ]
[.39212 .04087 .53448 0 ]
[.52574 -0.01069 -5.29351 -9 ]
[.52574 -0.01069 .70649 0 ]
[.58272 .04263 0 -6.19654 ]
[.58272 .04263 6 2.80346 ]
[.71715 .21863 0 -6.07114 ]
[.71715 .21863 6 2.92886 ]
[.83675 .37523 0 -5.963 ]
[.83675 .37523 6 3.037 ]
[.94385 .51546 0 -5.8688 ]
[.94385 .51546 6 3.1312 ]
[.01386 .20006 -12 -2.76892 ]
[.01386 .20006 0 6.23108 ]
[.00748 .25499 -24 -2.80073 ]
[.00748 .25499 0 6.19927 ]
[.00093 .31131 -6 -2.83339 ]
[.00093 .31131 0 6.16661 ]
[-0.00579 .36907 -18 -2.86695 ]
[-0.00579 .36907 0 6.13305 ]
[-0.01268 .42831 -6 -2.90143 ]
[-0.01268 .42831 0 6.09857 ]
[ 0 0 0 0 ]
[ 1 .92059 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02642 .19522 m
.53391 0 L
s
.02642 .19522 m
.03116 .2 L
s
[(-2)] .01694 .18568 .99384 1 Mshowa
.14712 .14879 m
.15172 .1537 L
s
[(-1)] .13793 .13897 .93651 1 Mshowa
.2718 .10083 m
.27624 .10588 L
s
[(0)] .26292 .09073 .87917 1 Mshowa
.40066 .05126 m
.40493 .05646 L
s
[(1)] .39212 .04087 .82184 1 Mshowa
.53391 0 m
.538 .00534 L
s
[(2)] .52574 -0.01069 .7645 1 Mshowa
.125 Mabswid
.05025 .18606 m
.05308 .18894 L
s
.07424 .17683 m
.07705 .17973 L
s
.09837 .16755 m
.10117 .17046 L
s
.12267 .1582 m
.12545 .16113 L
s
.17173 .13933 m
.17447 .14229 L
s
.19651 .1298 m
.19923 .13278 L
s
.22144 .1202 m
.22414 .1232 L
s
.24654 .11055 m
.24922 .11356 L
s
.29723 .09105 m
.29988 .0941 L
s
.32283 .0812 m
.32546 .08427 L
s
.3486 .07129 m
.35121 .07437 L
s
.37455 .06131 m
.37713 .06441 L
s
.42695 .04115 m
.4295 .04428 L
s
.45342 .03096 m
.45594 .03412 L
s
.48007 .02071 m
.48257 .02388 L
s
.5069 .01039 m
.50938 .01358 L
s
.25 Mabswid
.53391 0 m
.9804 .58403 L
s
.57014 .04738 m
.56384 .04975 L
s
[(0)] .58272 .04263 -1 .37701 Mshowa
.70445 .22307 m
.6981 .22529 L
s
[(2)] .71715 .21863 -1 .34914 Mshowa
.82396 .37939 m
.81756 .38147 L
s
[(4)] .83675 .37523 -1 .32511 Mshowa
.93098 .51938 m
.92454 .52134 L
s
[(6)] .94385 .51546 -1 .30418 Mshowa
.125 Mabswid
.60525 .09331 m
.60147 .09471 L
s
.63931 .13786 m
.63552 .13924 L
s
.67236 .1811 m
.66856 .18245 L
s
.73562 .26383 m
.7318 .26514 L
s
.7659 .30345 m
.76207 .30473 L
s
.79534 .34195 m
.7915 .34322 L
s
.85181 .41581 m
.84796 .41704 L
s
.87891 .45126 m
.87506 .45247 L
s
.90529 .48577 m
.90143 .48696 L
s
.95601 .55212 m
.95214 .55328 L
s
.25 Mabswid
.02642 .19522 m
0 .42381 L
s
.02642 .19522 m
.0327 .19281 L
s
[(-1)] .01386 .20006 1 -0.38468 Mshowa
.02006 .25024 m
.02635 .24786 L
s
[(-0.5)] .00748 .25499 1 -0.37762 Mshowa
.01354 .30664 m
.01985 .3043 L
s
[(0)] .00093 .31131 1 -0.37036 Mshowa
.00686 .36448 m
.01318 .36218 L
s
[(0.5)] -0.00579 .36907 1 -0.3629 Mshowa
0 .42381 m
.00634 .42156 L
s
[(1)] -0.01268 .42831 1 -0.35524 Mshowa
.125 Mabswid
.02516 .20612 m
.02893 .20468 L
s
.0239 .21707 m
.02767 .21563 L
s
.02262 .22807 m
.0264 .22664 L
s
.02135 .23913 m
.02512 .2377 L
s
.01877 .26141 m
.02255 .25999 L
s
.01747 .27263 m
.02125 .27122 L
s
.01617 .28391 m
.01995 .2825 L
s
.01486 .29525 m
.01864 .29384 L
s
.01222 .31809 m
.01601 .3167 L
s
.01089 .3296 m
.01468 .32821 L
s
.00955 .34117 m
.01334 .33978 L
s
.00821 .35279 m
.012 .35141 L
s
.0055 .37622 m
.0093 .37485 L
s
.00414 .38803 m
.00793 .38666 L
s
.00276 .39989 m
.00656 .39853 L
s
.00139 .41182 m
.00519 .41047 L
s
.25 Mabswid
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.54154 .92059 L
s
.54154 .92059 m
.5414 .7134 L
s
.5414 .7134 m
.02642 .19522 L
s
.53391 0 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.53391 0 m
.02642 .19522 L
s
.5414 .7134 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.54154 .92059 L
s
.54154 .92059 m
.5414 .7134 L
s
0 0 m
1 0 L
1 .92059 L
0 .92059 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.58145 .7874 m
.64867 .7539 L
s
1 0 .6 r
.56494 .75464 m
.62903 .72212 L
s
.8 0 1 r
.54842 .72186 m
.60939 .69038 L
s
.2 0 1 r
.53189 .68906 m
.58976 .65866 L
s
0 .4 1 r
.51535 .65625 m
.57015 .62696 L
s
0 1 1 r
.49881 .62342 m
.55056 .59529 L
s
0 1 .4 r
.48225 .59058 m
.53098 .56365 L
s
.2 1 0 r
.46569 .55773 m
.51141 .53203 L
s
.8 1 0 r
.44912 .52486 m
.49186 .50043 L
s
1 .6 0 r
.43254 .49197 m
.47233 .46886 L
s
.47233 .46886 m
.50724 .43991 L
s
.8 1 0 r
.49186 .50043 m
.53007 .4693 L
s
.2 1 0 r
.51141 .53203 m
.55297 .49878 L
s
0 1 .4 r
.53098 .56365 m
.57593 .52834 L
s
0 1 1 r
.55056 .59529 m
.59895 .55798 L
s
0 .4 1 r
.57015 .62696 m
.62204 .5877 L
s
.2 0 1 r
.58976 .65866 m
.64519 .61751 L
s
.8 0 1 r
.60939 .69038 m
.66841 .64739 L
s
1 0 .6 r
.62903 .72212 m
.69168 .67736 L
s
1 0 0 r
.64867 .7539 m
.71501 .70743 L
s
.57974 .74654 m
.68595 .74325 L
s
.4895 .74014 m
.57974 .74654 L
s
.68595 .74325 m
.77714 .73183 L
s
1 0 .6 r
.58088 .7099 m
.68209 .70671 L
s
.49523 .70372 m
.58088 .7099 L
s
1 0 0 r
.45278 .73501 m
.4895 .74014 L
s
1 0 .6 r
.68209 .70671 m
.76948 .69559 L
s
.8 0 1 r
.58206 .67314 m
.67825 .67006 L
s
.501 .6672 m
.58206 .67314 L
s
1 0 0 r
.53382 .73883 m
.47515 .73753 L
s
.6059 .73049 m
.53382 .73883 L
s
.47515 .73753 m
.45278 .73501 L
s
1 0 .6 r
.45985 .6987 m
.49523 .70372 L
s
1 .6 0 r
.50724 .43991 m
.52806 .41309 L
s
.8 0 1 r
.67825 .67006 m
.76181 .65925 L
s
.2 0 1 r
.58325 .63626 m
.67439 .63329 L
s
.5068 .63057 m
.58325 .63626 L
s
1 0 .6 r
.53189 .70207 m
.47919 .7009 L
s
.59682 .69444 m
.53189 .70207 L
s
.47919 .7009 m
.45985 .6987 L
s
.8 1 0 r
.53007 .4693 m
.55325 .44011 L
s
.8 0 1 r
.46697 .66229 m
.501 .6672 L
s
.2 0 1 r
.67439 .63329 m
.75412 .62282 L
s
0 .4 1 r
.58444 .59926 m
.67052 .5964 L
s
.51261 .59383 m
.58444 .59926 L
s
.8 0 1 r
.52995 .6652 m
.48326 .66415 L
s
.58772 .6583 m
.52995 .6652 L
s
1 0 0 r
.67525 .71036 m
.6059 .73049 L
s
.8 0 1 r
.48326 .66415 m
.46697 .66229 L
s
.2 1 0 r
.55297 .49878 m
.57856 .46726 L
s
.2 0 1 r
.47411 .62577 m
.5068 .63057 L
s
0 .4 1 r
.67052 .5964 m
.7464 .58628 L
s
1 0 .6 r
.6592 .67604 m
.59682 .69444 L
s
0 1 1 r
.58563 .56214 m
.66664 .5594 L
s
.51844 .55698 m
.58563 .56214 L
s
.2 0 1 r
.52802 .62821 m
.48734 .62729 L
s
.5786 .62208 m
.52802 .62821 L
s
0 1 .4 r
.57593 .52834 m
.604 .49454 L
s
.2 0 1 r
.48734 .62729 m
.47411 .62577 L
s
0 .4 1 r
.48127 .58915 m
.51261 .59383 L
s
0 1 1 r
.66664 .5594 m
.73866 .54964 L
s
.8 0 1 r
.64315 .64168 m
.58772 .6583 L
s
0 1 .4 r
.58683 .52489 m
.66275 .52228 L
s
.52429 .52002 m
.58683 .52489 L
s
0 1 1 r
.59895 .55798 m
.62956 .52196 L
s
0 .4 1 r
.52607 .5911 m
.49144 .59031 L
s
.56946 .58575 m
.52607 .5911 L
s
.49144 .59031 m
.48127 .58915 L
s
0 1 1 r
.48845 .55243 m
.51844 .55698 L
s
.2 0 1 r
.62708 .6073 m
.5786 .62208 L
s
0 1 .4 r
.66275 .52228 m
.73091 .51289 L
s
0 .4 1 r
.62204 .5877 m
.65524 .5495 L
s
.2 1 0 r
.58804 .48752 m
.65884 .48504 L
s
.53015 .48295 m
.58804 .48752 L
s
0 1 1 r
.52412 .55387 m
.49555 .55321 L
s
.56029 .54934 m
.52412 .55387 L
s
0 1 .4 r
.49565 .5156 m
.52429 .52002 L
s
0 1 1 r
.49555 .55321 m
.48845 .55243 L
s
0 .4 1 r
.61099 .57289 m
.56946 .58575 L
s
.2 1 0 r
.65884 .48504 m
.72313 .47605 L
s
.2 0 1 r
.64519 .61751 m
.68104 .57718 L
s
0 1 .4 r
.52216 .51651 m
.49967 .51599 L
s
.5511 .51283 m
.52216 .51651 L
s
.8 1 0 r
.58924 .45002 m
.65493 .44769 L
s
.53604 .44576 m
.58924 .45002 L
s
.2 1 0 r
.50287 .47867 m
.53015 .48295 L
s
0 1 1 r
.59489 .53846 m
.56029 .54934 L
s
0 1 .4 r
.49967 .51599 m
.49565 .5156 L
s
.8 0 1 r
.66841 .64739 m
.70697 .60499 L
s
.8 1 0 r
.65493 .44769 m
.71533 .43911 L
s
1 .6 0 r
.52806 .41309 m
.53603 .39824 L
s
0 1 .4 r
.57878 .50399 m
.5511 .51283 L
s
.8 1 0 r
.51011 .44163 m
.53604 .44576 L
s
.2 1 0 r
.52019 .47903 m
.5038 .47866 L
s
.54188 .47623 m
.52019 .47903 L
s
1 .6 0 r
.59045 .41241 m
.651 .41021 L
s
.54194 .40847 m
.59045 .41241 L
s
.2 1 0 r
.5038 .47866 m
.50287 .47867 L
s
1 0 .6 r
.69168 .67736 m
.73303 .63295 L
s
1 0 0 r
.7304 .68147 m
.67525 .71036 L
s
1 .6 0 r
.651 .41021 m
.7075 .40206 L
s
.2 1 0 r
.56265 .46949 m
.54188 .47623 L
s
1 0 .6 r
.70861 .64968 m
.6592 .67604 L
s
1 .6 0 r
.51736 .40448 m
.54194 .40847 L
s
.8 0 1 r
.68686 .61795 m
.64315 .64168 L
s
.8 1 0 r
.50794 .44121 m
.51011 .44163 L
s
.51822 .44143 m
.50794 .44121 L
s
.53264 .43953 m
.51822 .44143 L
s
1 0 0 r
.71501 .70743 m
.7592 .66105 L
s
.2 0 1 r
.66514 .58626 m
.62708 .6073 L
s
.8 1 0 r
.55325 .44011 m
.56184 .42455 L
s
.54651 .43496 m
.53264 .43953 L
s
0 .4 1 r
.64346 .55463 m
.61099 .57289 L
s
0 1 1 r
.62181 .52305 m
.59489 .53846 L
s
1 .6 0 r
.51209 .40365 m
.51736 .40448 L
s
0 1 .4 r
.60019 .49152 m
.57878 .50399 L
s
1 .6 0 r
.51624 .4037 m
.51209 .40365 L
s
.52338 .40275 m
.51624 .4037 L
s
.53037 .40041 m
.52338 .40275 L
s
.2 1 0 r
.57862 .46004 m
.56265 .46949 L
s
.8 1 0 r
.55707 .42861 m
.54651 .43496 L
s
1 .6 0 r
.53557 .39723 m
.53037 .40041 L
s
.2 1 0 r
.57856 .46726 m
.58781 .451 L
s
1 .6 0 r
.53603 .39824 m
.53777 .39505 L
s
.53777 .39505 m
.53557 .39723 L
s
.8 1 0 r
.56246 .4232 m
.55707 .42861 L
s
0 1 .4 r
.604 .49454 m
.61392 .47759 L
s
.2 1 0 r
.58728 .45147 m
.57862 .46004 L
s
.8 1 0 r
.56184 .42455 m
.56246 .4232 L
s
0 1 .4 r
.6122 .47985 m
.60019 .49152 L
s
0 1 1 r
.63722 .50835 m
.62181 .52305 L
s
.62956 .52196 m
.64017 .50433 L
s
0 .4 1 r
.66234 .53696 m
.64346 .55463 L
s
.2 0 1 r
.68756 .5657 m
.66514 .58626 L
s
.2 1 0 r
.58781 .451 m
.58728 .45147 L
s
.8 0 1 r
.7129 .59455 m
.68686 .61795 L
s
0 .4 1 r
.65524 .5495 m
.66657 .53122 L
s
1 0 .6 r
.73833 .62352 m
.70861 .64968 L
s
0 1 .4 r
.61392 .47759 m
.6122 .47985 L
s
1 0 0 r
.76387 .65262 m
.7304 .68147 L
s
.2 0 1 r
.68104 .57718 m
.69311 .55825 L
s
0 1 1 r
.64017 .50433 m
.63722 .50835 L
s
.8 0 1 r
.70697 .60499 m
.71981 .58544 L
s
0 .4 1 r
.66657 .53122 m
.66234 .53696 L
s
.2 0 1 r
.69311 .55825 m
.68756 .5657 L
s
1 0 .6 r
.73303 .63295 m
.74665 .61277 L
s
.8 0 1 r
.71981 .58544 m
.7129 .59455 L
s
1 0 0 r
.7592 .66105 m
.77363 .64028 L
s
1 0 .6 r
.74665 .61277 m
.73833 .62352 L
s
1 0 0 r
.77363 .64028 m
.76387 .65262 L
s
0 g
.25 Mabswid
.53391 0 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.53391 0 m
.02642 .19522 L
s
.02642 .19522 m
.53391 0 L
s
.02642 .19522 m
.03116 .2 L
s
[(-2)] .01694 .18568 .99384 1 Mshowa
.14712 .14879 m
.15172 .1537 L
s
[(-1)] .13793 .13897 .93651 1 Mshowa
.2718 .10083 m
.27624 .10588 L
s
[(0)] .26292 .09073 .87917 1 Mshowa
.40066 .05126 m
.40493 .05646 L
s
[(1)] .39212 .04087 .82184 1 Mshowa
.53391 0 m
.538 .00534 L
s
[(2)] .52574 -0.01069 .7645 1 Mshowa
.125 Mabswid
.05025 .18606 m
.05308 .18894 L
s
.07424 .17683 m
.07705 .17973 L
s
.09837 .16755 m
.10117 .17046 L
s
.12267 .1582 m
.12545 .16113 L
s
.17173 .13933 m
.17447 .14229 L
s
.19651 .1298 m
.19923 .13278 L
s
.22144 .1202 m
.22414 .1232 L
s
.24654 .11055 m
.24922 .11356 L
s
.29723 .09105 m
.29988 .0941 L
s
.32283 .0812 m
.32546 .08427 L
s
.3486 .07129 m
.35121 .07437 L
s
.37455 .06131 m
.37713 .06441 L
s
.42695 .04115 m
.4295 .04428 L
s
.45342 .03096 m
.45594 .03412 L
s
.48007 .02071 m
.48257 .02388 L
s
.5069 .01039 m
.50938 .01358 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 265.125},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001Bb000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00`oooool5o`000:3ooooo0033ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@0X?ooool00<Cooooo00?oV9RHob4Q8Oo^k^h0XOooool00<Gooooo00?oV9RH
ob4Q8Oo^k^h0X?ooool00<Kooooo00?oMgMgofIVI_ooool0Woooool00<Oooooo00?o0000oooooooo
ool0W_ooool00<?ooooo00Go0000okZj^_ooooooV9RHoa0@402Pooooo`00`oooool01OnHV9So410@
o`000?lQ8B7oc<c<0:3ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003;ooooo`;o0000Voooool00<Sooooo0ol000000ooooooo0000ooooo`2Jooooo`00a_oo
ool2o`0000Cooooo0_l0002Jooooo`00`oooool3o`0000Kooooo00?o0000ooooool00000VOooool0
0<3ooooo1?l00008ooooo`04o`000?ooooooooooo`0009Sooooo002Hooooo`Co000000?o410@oooo
ooooool07oooool2o`0000Cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0002H
ooooo`00V_ooool00ol0003oooooooooo`0Nooooo`?o00003_ooool01Ol0003ooooooooooooooooo
000009Oooooo002Jooooo`03o`000?oooooooooo01cooooo0_l0000Aooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0U?ooool009[ooooo00?o0000ooooooooool06Oooool3o`0000;o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo09?o
oooo002Jooooo`03o`000?oooooooooo01Kooooo0ol0000Fooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^08Kooooo002Jooooo`03o`00
0?oooooooooo01Cooooo0_l0000Iooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1oooool01OmgMgOoV9RHoooooonHV9SoMgMg08Kooooo002Jooooo`03o`000?oooooooooo017ooooo
0ol000000ooooooo0000ooooo`0Hooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1_ooool01Ol@413ooooooooooooooooo410@08Kooooo002Hooooo`03oeEEEOmVIVKo0000017ooooo
0_l0000Nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool01Ol0003ooooo
oooooooooooo000008Kooooo002Yooooo`?o00008?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000026ooooo`00Yoooool3o`0002;ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@
4100Q_ooool00:Cooooo0ol00002ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Q_ooool00:7ooooo
0ol0000Xooooo`03o`000?oooooooooo00Sooooo0_l00004ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h0Q_ooool009oooooo0_l0000[ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo
0000S_ooool009cooooo0ol000000ooooooo0000ooooo`0Zooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0S?ooool009[ooooo0_l00005ooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`2;ooooo`00Uoooool3o`0003;ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`2:ooooo`00K?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^02?ooooo0ol000000ooooooo0000ooooo`0booooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0ROooool006cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Qooooo`;o0000>?ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo08Wooooo001/ooooo`05oa0@4?oooooooooo
ooooool@41007_ooool3o`0003[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`28
ooooo`00K?ooool01Ol0003ooooooooooooooooo000001cooooo0ol0000looooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0Qoooool006cooooo00Go0000ooooooooooooooooo`00000I
ooooo`?o00000_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool0Q_ooool006cooooo00Go410@oooooooooooooooooa0@400Gooooo`;o0000@_ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo08Kooooo001/ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL05?ooool3o`0004Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`25
ooooo`00K?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^017ooooo0ol00002ooooo`03o`000?oooooo
oooo04;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`24ooooo`00P?ooool2o`00
04[ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`23ooooo`00OOooool3o`0004co
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`22ooooo`00Noooool2o`000003oooo
ool0003ooooo04cooooo00?o0000ooooooooool05?ooool2o`0008?ooooo001hooooo`?o0000DOoo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooo000008?ooooo001eooooo`?o0000E?ooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo083ooooo001cooooo`Co0000EOooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo07oooooo001`ooooo`?o00001?ooool00ol0003o
ooooooooo`1Booooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0Ooooool006kooooo
0_l0001Looooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0O_ooool004?ooooo1?l0
00000ol@413oooooooooo`0Qooooo`?o0000G_ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo07gooooo0015ooooo`03o`000?oooooooooo023ooooo0ol00003ooooo`03o`000?oooooo
oooo05_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1looooo`00>_ooool6o`00
00Gooooo00?o0000ooooooooool07_ooool2o`0006Cooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`1looooo`00AOooool00ol0003oooooooooo`0Kooooo`?o0000I_ooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo07_ooooo0015ooooo`03o`000?oooooooooo01Wooooo
0_l00002ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`1jooooo`00AOooool00ol0003oooooooooo`0Fooooo`?o0000Joooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo07Wooooo0015ooooo`03o`000?oooooooooo01Cooooo0_l0001^
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0NOooool004?ooooo00?oEEEEofIV
I_l000004oooool3o`000003ooooool0003ooooo06gooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`1hooooo`00E_ooool3o`0007?ooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`1gooooo`00E?ooool2o`0007Kooooo00?o0000ooooooooool07oooool2o`0007Sooooo
001Aooooo`?o000000?oooooo`000?ooool0MOooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo07Kooooo001?ooooo`;o0000Noooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo07Gooooo001<ooooo`?o0000OOooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
07Cooooo0019ooooo`Co0000Ooooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo07?o
oooo0017ooooo`;o00001?ooool00ol0003oooooooooo`1looooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool0L_ooool004Cooooo0ol00025ooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool0L_ooool001[ooooo1Ol0000Sooooo`?o0000Qoooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo077ooooo000Jooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@08?ooool3
o`0000?ooooo00?o0000ooooooooool0Q?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo073ooooo000Booooo`Ko00000oooool00onHV9So8B4Qonk^kP0Oooooo`;o0000SOooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo06oooooo000Looooo`03oiRHV?lQ8B7ok^k^01_o
oooo0ol0002?ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0Koooool001gooooo
00?oMgMgofIVI_ooool05oooool3o`0000?ooooo00?o0000ooooooooool0S?ooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooooooo06kooooo000Nooooo`03o`000?oooooooooo01Cooooo0_l0
002Eooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0KOooool001[ooooo00Go0000
okZj^_ooooooV9RHoa0@400Cooooo`?o0000Uoooool00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo06cooooo000Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`04Oooool2o`0000?ooooo00?o
0000ooooooooool0U?ooool00ol0003oooooooooo`0Zooooo`;o0000KOooool002gooooo0ol0002L
ooooo`03o`000?oooooooooo02[ooooo0_l0001]ooooo`00:_ooool3o`0009oooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`1Zooooo`00:?ooool2o`0000?ooooo00?o0000oooooooo
ool0W?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo06Wooooo000Uooooo`?o0000
Y?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo06Wooooo000Tooooo`03o`000?oo
oooooooo0:Gooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1Xooooo`006_ooool4
o`000003oa0@4?oooooooooo00?ooooo0_l0002Vooooo`03o`000?oooooooooo02oooooo00?o0000
ooooooooool0Ioooool001cooooo00?o0000ooooooooool01Oooool2o`000:Kooooo00?o0000oooo
ooooool0<?ooool00ol0003oooooooooo`1Vooooo`004Oooool6o`0000Gooooo00?o0000oooooooo
ool01?ooool4o`000:Gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`08ooooo`Go
0000FOooool001cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0002Tooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool01OnHV9So8B4Qonk^k_ooooooA4A4
05Wooooo000Looooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`2Qooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool01oooool00onHV9So
8B4Qonk^kP1Jooooo`007?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0X?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Oooooo
00?oV9RHob4Q8Oo^k^h0FOooool001cooooo00?o0000ooooooooool01?ooool2o`0000Gooooo00?o
0000ooooooooool0Woooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Oooooo00?o
MgMgofIVI_ooool0F?ooool001[ooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo09kooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo05Oooooo000Sooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0WOooool00ol0003oooooooooo`0eooooo`;o00001?ooool01Ol0003o^[ZjoooooonHV9So
410@05Wooooo000Sooooo`;o00002?ooool00ol0003oooooooooo`2Looooo`03o`000?oooooooooo
03?ooooo0_l000000ooooooo0000ooooo`03ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0FOooool0
02?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2Kooooo`03o`000?oooooooooo
03Oooooo00?o0000ooooooooool0Goooool002?ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`2Jooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0Goooool002?ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`2Hooooo`;o0000>_ooool00ol0003ooooo
ooooo`1Nooooo`008_ooool2o`0000gooooo00?o0000ooooooooool0U?ooool3o`000003ooooool0
003ooooo03[ooooo00?o0000ooooooooool0GOooool002;ooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`2@ooooo`?o00001Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooo
oooo05cooooo000Rooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0S?ooool3o`00
00Wooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1Looooo`008_ooool3o`0000oo
oooo00?o0000ooooooooool0R?ooool3o`0000gooooo00?o0000ooooooooool0>?ooool00ol0003o
ooooooooo`1Kooooo`008_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo08Gooooo
0_l0000Aooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0F_ooool002;ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`21ooooo`?o00005?ooool00ol0003ooooooooo
o`0hooooo`03o`000?oooooooooo05Wooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool0OOooool3o`0001Oooooo00?o0000ooooooooool0>?ooool00ol0003ooooo
ooooo`1Iooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1iooooo`?o0000
6oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo05Sooooo0005o`0000;ooooo00Go
410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`1eooooo`?o00007oooool00ol0003oooooooooo`0hooooo`03o`00
0?oooooooooo05Oooooo0007ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8b
ooooo`03ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0LOooool3o`0002?ooooo
00?o0000ooooooooool0=oooool2o`0005Sooooo0007ooooo`05o`000?ooooooooooooooool00000
3?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`1^ooooo`;o00009oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo05Go
oooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`;o
00006Oooool00ol0003oooooooooo`1Zooooo`?o0000:_ooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo05Gooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0I_ooool3o`0002go
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1Dooooo`001oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool0H_ooool3o`00037ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1Cooooo`00
8Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo05kooooo0ol0000eooooo`03o`00
0?oooooooooo03Sooooo00?o0000ooooooooool0D_ooool0023ooooo0ol0000Mooooo`03o`000?oo
oooooooo05_ooooo0_l0000iooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0D_oo
ool0027ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1Gooooo`?o0000??ooool0
0ol0003oooooooooo`0gooooo`03o`000?oooooooooo057ooooo000Pooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool0Doooool3o`00043ooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`1@ooooo`008?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo04oo
oooo0ol00013ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0Coooool0023ooooo
0_l0000Rooooo`03o`000?oooooooooo04_ooooo0ol00017ooooo`03o`000?oooooooooo03Oooooo
00?o0000ooooooooool0Coooool0023ooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`18ooooo`;o0000Boooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo04kooooo000P
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0A?ooool3o`0004kooooo00?o0000
ooooooooool0=oooool00ol0003oooooooooo`1=ooooo`008?ooool3o`0002Cooooo00?o0000oooo
ooooool0@?ooool3o`0005;ooooo00?o0000ooooooooool0=_ooool2o`0004kooooo000Pooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0??ooool3o`0005Kooooo00?o0000oooooooo
ool0=_ooool00ol0003oooooooooo`1<ooooo`005?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oo
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0hooooo`?o0000FOooool00ol0003o
ooooooooo`0gooooo`03o`000?oooooooooo04_ooooo000Dooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo03Gooooo0_l0001Mooooo`03
o`000?oooooooooo03Oooooo00?o0000ooooooooool0B_ooool001Cooooo00Go410@oooooooooooo
oooooa0@4006ooooo`;o0000:_ooool00ol0003oooooooooo`0aooooo`?o0000H?ooool00ol0003o
ooooooooo`0gooooo`03o`000?oooooooooo04Wooooo000Dooooo`05o`000?ooooooooooooooool0
00001_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo02gooooo0ol0001Tooooo`03
o`000?oooooooooo03Kooooo00?o0000ooooooooool0BOooool001Cooooo00Go0000oooooooooooo
ooooo`000006ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0:Oooool3o`0006So
oooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`18ooooo`005?ooool01Ol@413ooooo
oooooooooooo410@00Kooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Uooooo`?o
0000K?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo04Oooooo000Dooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool2o`0002kooooo00?o0000ooooooooool08Oooool3o`0006oo
oooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`16ooooo`005?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Nooooo`;o
0000Loooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo04Gooooo000Oooooo`03o`00
0?oooooooooo02oooooo00?o0000ooooooooool06_ooool3o`0007Kooooo00?o0000ooooooooool0
=_ooool00ol0003oooooooooo`15ooooo`007_ooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo01Kooooo0ol0001jooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0A?oo
ool001kooooo0_l0000cooooo`03o`000?oooooooooo01;ooooo0ol0001nooooo`03o`000?oooooo
oooo03Kooooo0_l00014ooooo`007_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo
00kooooo0ol00022ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooool00000A?ooool001ko
oooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0;ooooo`;o0000QOooool00ol0003o
ooooooooo`0fooooo`03o`000?oooooooooo04;ooooo000Nooooo`03o`000?oooooooooo03Gooooo
00?o0000ooooooooool01oooool3o`0008Sooooo00?o0000ooooooooool0=_ooool00ol0003ooooo
ooooo`11ooooo`007_ooool2o`0003Oooooo00?o0000ooooooooool00oooool3o`0008cooooo00?o
0000ooooooooool0=_ooool00ol0003oooooooooo`10ooooo`007_ooool00ol0003oooooooooo`0g
ooooo`03o`000?oooooo000000;o0000T?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooo
oooo03oooooo000Nooooo`03o`000?oooooooooo03Kooooo0ol0002Dooooo`03o`000?oooooooooo
03Gooooo00?o0000ooooooooool0?oooool001kooooo0_l0000eooooo`;o00000oooool00ol0003o
ooooooooo`2Booooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool02Oooool2o`000003
oa0@4?oooooooooo033ooooo000Mooooo`03o`000?oooooooooo03;ooooo0ol00006ooooo`03o`00
0?oooooooooo097ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo037ooooo0002ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo
00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo02oooooo0ol0000:ooooo`03
o`000?oooooooooo097ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`05ooooo`Go
0000<_ooool000;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo
<S8booooo`04ooooo`03o`000?oooooooooo02cooooo0ol0000>ooooo`03o`000?oooooooooo097o
oooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`05ooooo`04odA4A?oMgMgoooooo`00
03?ooooo0002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03oooo
o`;o0000:_ooool3o`0001;ooooo00?o0000ooooooooool0TOooool00ol0003oooooooooo`0eoooo
o`03o`000?oooooooooo00Cooooo00CogMgMoeEEEOoooooo0000<oooool000;ooooo00Go0000oooo
ooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool09oooool2
o`0001Kooooo00?o0000ooooooooool0TOooool00ol0003oooooooooo`0eooooo`03o`000?oooooo
oooo00Cooooo00?oMgMgolc<c?l00000<oooool000;ooooo00Go0000ooooooooooooooooo`00000<
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Tooooo`?o00006Ooo
ool00ol0003oooooooooo`2Aooooo`03o`000?oooooooooo03Cooooo0_l00005ooooo`03onk^k_m4
A4Co000003?ooooo0002ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo027ooooo0ol0000Mooooo`03o`000?oooooooooo093ooooo00?o
0000ooooooooool0<oooool01?l0003oooooooooool00005ooooo`03ogMgMol0003ooooo03;ooooo
0002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`;o0000
7oooool3o`00027ooooo00?o0000ooooooooool0T?ooool00ol0003oooooooooo`0eooooo`03o`00
0?oooooooooo03Sooooo0002ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo
00?o0000ooooooooool07?ooool3o`0002Gooooo00?o0000ooooooooool0T?ooool00ol0003ooooo
ooooo`0eooooo`03o`000?oooooooooo03Oooooo000Looooo`03o`000?oooooooooo01Wooooo0ol0
000Yooooo`03o`000?oooooooooo093ooooo00?o0000ooooooooool0=Oooool00ol0003ooooooooo
o`0fooooo`007?ooool00ol0003oooooooooo`0Gooooo`;o0000;Oooool00ol0003oooooooooo`1U
ooooo`03oonI0?oooooooooo02Sooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0e
ooooo`007?ooool2o`0001Gooooo0ol0000`ooooo`03o`000?oooooooooo06?ooooo0_ooV@0[oooo
o`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0=Oooool001cooooo00?o0000oooooooo
ool04Oooool3o`0003Cooooo00?o0000ooooooooool0H?ooool2oonI0003ooooooooV@3ooooo02[o
oooo00?o0000ooooooooool01oooool4oonI02[ooooo00?o0000ooooooooool0=?ooool001cooooo
00?o0000ooooooooool03_ooool3o`0003Sooooo00?o0000ooooooooool0F_ooool5oonI00;ooooo
00?ooiT0ooooooooool0:oooool00ol0003ooooooonI0006oonI02oooooo00?o0000ooooooooool0
<oooool001cooooo00?o0000ooooooooool02oooool3o`0003cooooo00?o0000ooooooooool0G_oo
ool4oonI02Sooooo1OooV@000ol0003oooooooooo`0eooooo`03o`000?oooooooooo03;ooooo000L
ooooo`;o00002_ooool2o`00043ooooo00?o0000ooooooooool0G_ooool00oooV@3oooooooooo`0:
oonI017ooooo3OooV@06ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0<_ooool0
01_ooooo0_l00008ooooo`?o0000@oooool00ol0003oooooooooo`1Looooo`03oonI0?oooooooooo
00_ooooo4OooV@0Dooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0<Oooool001_o
oooo00?o0000ooooooooool01?ooool3o`0004Oooooo00?o0000ooooooooool0Foooool00oooV@3o
ooooooooo`0aooooo`03o`000?oooooooooo03?ooooo0_l0000booooo`006oooool01?l0003ooooo
ooooooooool3o`0004_ooooo00?o0000ooooooooool0FOooool00oooV@3oooooooooo`0booooo`03
o`000?oooooooooo03Gooooo00?o0000ooooooooool0;oooool001_ooooo1?l0001?ooooo`03o`00
0?oooooooooo05Oooooo00?ooiT0ooooooooool02_ooool00oo<o`3oooooooooo`0Wooooo`03o`00
0?oooooooooo03Cooooo00?o0000ooooooooool0;oooool001_ooooo0_l0001Booooo`03o`000?oo
oooooooo05Gooooo00?ooiT0ooooooooool02oooool00oo<o`3oooooooooo`0Xooooo`03o`000?oo
oooooooo03Cooooo00?o0000ooooooooool0;_ooool0017ooooo1?l000000ol@413oooooooooo`05
ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0Doooool00oooV@3oooooooooo`0:
ooooo`?oc?l0:oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02gooooo000Coooo
o`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`1Boooo
o`03oonI0?oooooooooo00Sooooo0_o<o`000oooooooc?l0ooooo`0/ooooo`03o`000?oooooooooo
03Cooooo00?o0000ooooooooool0;?ooool001?ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`1@ooooo`03o`000?oooooooooo053ooooo00?ooiT0ooooooooool01oooool2olco00;o
oooo00?oc?l0ooooooooool0;Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02co
oooo000Cooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0D?ooool00ol0003ooooo
ooooo`1>ooooo`03oonI0?oooooooooo00Kooooo0_o<o`04ooooo`03olco0?oooooooooo02gooooo
00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0[ooooo`004oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0Boooool00oooV@3oc?l0olco
0008olco00Gooooo00?oc?l0ooooooooool0;oooool00ol0003oc?l0olco0002olco03;ooooo00?o
0000ooooooooool0:_ooool001?ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`1@
ooooo`03o`000?oooooooooo04Wooooo00?ooiT0ooooooooool01_o<o`08ooooo`03olco0?oooooo
oooo02Wooooo1oo<o`000ol0003oooooooooo`0dooooo`03o`000?oooooooooo02Wooooo000Coooo
o`03o`000?oooooooooo00gooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`17oooo
o`03oonI0?oooooooooo00Oooooo3Oo<o`0Pooooo`Ooc?l02?ooool00ol0003oooooooooo`0doooo
o`03o`000?oooooooooo02Sooooo000Aooooo`03oeEEEOmVIVKo0000013ooooo00?o0000oooooooo
ool0D?ooool00ol0003oooooooooo`15ooooo`03oonI0?oooooooooo00kooooo00?oc?l0oooooooo
ool01?oooolPolco013ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Xooooo`00
9Oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo04?ooooo00?ooiT0ooooooooool0
3oooool00oo<o`3oooooooooo`0;ooooo`03oc?o0?oooooooooo02Oooooo00?o0000ooooooooool0
<_ooool2o`0002Wooooo000Vooooo`;o0000DOooool00ol0003oooooooooo`11ooooo`03oonI0?oo
oooooooo00oooooo00?oc?l0ooooooooool02oooool2oc?o02Wooooo00?o0000ooooooooool0=?oo
ool00ol0003oooooooooo`0Vooooo`00:?ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooo
oooo043ooooo00?ooiT0ooooooooool03oooool00oo<o`3oooooooooo`0;ooooo`;o<ol0:oooool0
0ol0003oooooooooo`0dooooo`03o`000?oooooooooo02Gooooo000Yooooo`03o`000?oooooooooo
04kooooo00?o0000ooooooooool0?_ooool00oooV@3oooooooooo`0?ooooo`03olco0?oooooooooo
00[ooooo0olco`0]ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool09Oooool002[o
oooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0looooo`03oonI0?oooooooooo013o
oooo00?oc?l0ooooooooool02?ooool2oc?o00;ooooo00?o<ol0ooooooooool0;?ooool00ol0003o
ooooooooo`0cooooo`03o`000?oooooooooo02Cooooo000[ooooo`03o`000?oooooooooo04kooooo
00?o0000ooooooooool0>_ooool00oooV@3oooooooooo`0@ooooo`03olco0?oooooooooo00Sooooo
00Go<ol0oooooooooooooooooc?o000`ooooo`03o`000?oooooooooo03?ooooo00?o0000oooooooo
ool08oooool002cooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0gooooo`;ooiT0
4Oooool2olco00Sooooo0olco`04ooooo`03oc?o0?oooooooooo02oooooo00?o0000ooooooooool0
<oooool00ol0003oooooooooo`0Rooooo`00;Oooool00ol0003oooooooooo`1>ooooo`03o`000?oo
oooooooo03Cooooo0_ooV@0Booooo`03olco0?oooooooooo00Gooooo0olco`06ooooo`03oc?o0?oo
oooooooo033ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Rooooo`00;_ooool0
0ol0003oooooooooo`1>ooooo`03o`000?oooooooooo037ooooo0_ooV@0Cooooo`03olco0?oooooo
oooo00Ko<ol02?ooool00olco`3oooooooooo`0;ooooo`03o`3oI_oooooooooo01gooooo1Olco`02
ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool08Oooool002oooooo00?o0000oooo
ooooool0C_ooool00ol0003oooooooooo`0^ooooo`;ooiT03oooool9oc?o00gooooo00?o<ol0oooo
ooooool02oooool2o`3oIQSooooo1olco`08ooooo`03o`000?oooooooooo03?ooooo00?o0000oooo
ooooool08?ooool0033ooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0[ooooo`;o
oiT05?ooool00oo<o`3oooooooooo`09oc?o00Kooooo00?o<ol0ooooooooool02oooool2o`3oIQ;o
oooo1olco`0@ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool07oooool0037ooooo
0_l0001?ooooo`03o`000?oooooooooo02Sooooo0_ooV@0Eooooo`03olco0?oooooooooo00[ooooo
2Olco`0:ooooo`;o0?mV1?ooool?oc?o01Sooooo00?o0000ooooooooool0<_ooool2o`00023ooooo
000cooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool09Oooool2oonI01Kooooo00?o
c?l0ooooooooool03oooool00olco`3oooooooooo`02ooooo`Wo<ol000?o0?mVoc?o0?l0ofH01?lc
o`0Xooooo`03o`000?oooooooooo037ooooo0_l0000Pooooo`00=?ooool00ol0003oooooooooo`1=
ooooo`03o`000?oooooooooo02?ooooo00?ooiT0ooooooooool05?ooool2olco017ooooo00?o<ol0
ooooooooool02_ooool2o`3oIP03ooooool0ofKooooo02cooooo00?o0000ooooooooool0<oooool0
0ol0003oooooooooo`0Mooooo`00=Oooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo
03Sooooo00?oc?l0ooooooooool04?ooool00olco`3oooooooooo`09ooooo`;o0?mV0_ooool00ol0
ofKoooooooooo`0]ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool07?ooool003Ko
oooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0fooooo`03olco0?oooooooooo00oo
oooo0_lco`0;ooooo`03o`3oI_oooooooooo00;ooooo00?o0?mVooooooooool0;_ooool00ol0003o
ooooooooo`0booooo`03o`000?oooooooooo01cooooo000gooooo`03o`000?oooooooooo04gooooo
00?o0000ooooooooool0<oooool2olco017ooooo00?o<ol0ooooooooool02Oooool2o`3oIPCooooo
00?o0?mVooooooooool0<?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01_ooooo
000hooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0<?ooool2olco01;ooooo00?o
<ol0ooooooooool02?ooool2o`3oIPGooooo00?o0?mVooooooooool02oooool00ol0oooooooooooo
o`0Tooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool01oooool01Oo^k^ko<S8bo`00
0?l@413oc<c<00kooooo000iooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0;_oo
ool00oo<o`3oooooooooo`0Aooooo`03oc?o0?oooooooooo00Kooooo0ol0ofH6ooooo`03o`3oI_oo
oooooooo00cooooo00?o0?ooooooooooool09Oooool00ol0003oooooooooo`0booooo`03o`000?oo
oooooooo00Kooooo00GoEEEEogMgMoooooooV9RHob4Q8@0>ooooo`00>_ooool00ol0003ooooooooo
o`1=ooooo`03o`000?oooooooooo02_ooooo0_o<o`0Cooooo`03oc?o0?oooooooooo00Cooooo0ol0
ofH8ooooo`03o`3oI_oooooooooo00cooooo00?o0?ooooooooooool09_ooool00ol0003ooooooooo
o`0cooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`00000>ooooo`00>ooo
ool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo02Sooooo0_o<o`0Cooooo`;o<ol01ol0
ofH:ooooo`03o`3oI_oooooooooo00cooooo0_l0oolJooooo`Go0?mV2_ooool00ol0003ooooooooo
o`0booooo`03o`000?oooooooooo00Gooooo00Go0000oiRHV?ooooooV9RHob4Q8@0>ooooo`00??oo
ool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo02Gooooo0_o<o`09ooooo`ko0?mV4Ooo
ool00ol0ofKoooooooooo`0;ooooo`;o0?oo5?ooool7o`3oIQ3ooooo00?o0000ooooooooool0<_oo
ool00ol0003oooooooooo`04ooooo`05o`000?mEEEGo0000oa0@4?o<c<`03_ooool003gooooo0_l0
001>ooooo`03o`000?oooooooooo02?ooooo00?oc?l0ooooooooool03Oooool5o`3oIP03oooooolc
o`3ooooo01;ooooo00?o0?mVooooooooool02oooool00ol0ooooooooo`3oo`0=ooooo`Oo0?mV6?oo
ool00ol0003oooooooooo`0booooo`;o00001?ooool00omEEEGoQhN7ooooo`0@ooooo`00?oooool0
0ol0003oooooooooo`1<ooooo`03o`000?oooooooooo023ooooo0_o<o`0Eooooo`go0?mV1oooool0
0ol0ofKoooooooooo`0;ooooo`03o`3oool0ofKo0?oo00ko0?mV8?ooool00ol0003oooooooooo`0_
ooooo`;o000000?oooooo`000?ooool00oooool00ooMgMgo410@oiRHV00@ooooo`00@?ooool00ol0
003oooooooooo`1<ooooo`03o`000?oooooooooo01kooooo00?oc?l0ooooooooool05?ooool00olc
o`3oooooooooo`0;oooooa?o0?mV0_l0ool00ol0ofKoooooo`3oo`0_ooooo`03o`000?oooooooooo
037ooooo00?o0000ooooooooool00oooool01?o<c<coA4A4o`000?l@410>ooooo`00@Oooool00ol0
003oooooooooo`1<ooooo`03o`000?oooooooooo03?ooooo00?o<ol0ooooooooool04?ooool2o`3o
IP_ooooo0_l0ool3ooooo`03o`3ooooooooooooo02kooooo00?o0000ooooooooool0<_ooool00ol0
003oooooooooo`0Dooooo`00@_ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo033o
oooo0_lco`0Booooo`03o`3oI_oooooooooo00Wooooo0_l0ool4ooooo`03o`3ooooooooooooo00_o
oooo00?o06Koooooooooool08_ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01?o
oooo0013ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0;Oooool2oc?o01?ooooo
00?o0?mVooooooooool02Oooool00ol0ooooooooooooo`03ooooo`03o`3ooooooooooooo00cooooo
00?o06Koooooooooool08oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01;ooooo
0014ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0:oooool00olco`3ooooooooo
o`0Booooo`03o`3oI_oooooooooo00Sooooo0_l0ool5ooooo`03o`3ooooooooooooo00_ooooo0_l0
I_lWooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool04_ooool004Gooooo00?o0000
ooooooooool0C?ooool00ol0003oooooooooo`0Xooooo`;o<ol04oooool2o`3oIPSooooo0ol0ool6
ooooo`03o`3ooooooooooooo00_ooooo0_l0I_lYooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool04Oooool004Kooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0Uoooo
o`;o<ol05?ooool00ol0ofKoooooooooo`04ooooo`Co0?oo2Oooool00ol0ooooooooooooo`0:oooo
o`03o`1Voooooooo06Ko02[ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0@oooo
o`00Aoooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo02;ooooo0_lco`0Eooooo`03
o`3oI_oooooooooo00;ooooo0ol0ool<ooooo`03o`3ooooooooooooo00[ooooo00?o06Koooooool0
I_l0:oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00oooooo0018ooooo`;o0000
COooool00ol0003oooooooooo`0Oooooo`;o<ol05_ooool00ol0ofKo0?ooo`3oo`03o`3oo`kooooo
00?o0?ooooooooooool02_ooool00ol0I_ooooooo`1Vo`0Hooooo`Co0?oo4Oooool00ol0003ooooo
ooooo`0aooooo`03o`000?oooooooooo00oooooo001:ooooo`03o`000?oooooooooo04_ooooo00?o
0000ooooooooool07Oooool00olco`3oooooooooo`02ooooo`Co0?oo2oooool6o`3ooa;ooooo00?o
0?ooooooooooool02_ooool01?l0I_ooooooooooool0I_lBooooo`Ko0?oo5_ooool00ol0003ooooo
ooooo`0aooooo`;o00003oooool004_ooooo00?o0000ooooooooool0Boooool00ol0003ooooooooo
o`0Jooooo`;o<ol01oooool=o`3oo`;ooooo00?o0?mVooooooooool04_ooool00ol0oooooooooooo
o`09ooooo`;o06Ko0_ooool00ol0I_ooooooooooo`0;ooooo`Ko0?oo7Oooool00ol0003ooooooooo
o`0`ooooo`;o00003oooool004cooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0H
ooooo`03oc?o0?oooooooooo00kooooo3Ol0ool>ooooo`;o0?oo2_ooool2o`1Vo`?ooooo00?o06Ko
ooooooooool01_ooool6o`3oo`03oc<0oooooooooooo027ooooo00?o0000ooooooooool0<Oooool0
0ol0003oooooooooo`0<ooooo`00COooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo
02kooooo00?o0?mVooooooooool01?oooolIo`3oo`03o`1Vool0oooo0?oo00;o0?oo00?o06Koo`3o
ool0ool01ol0ool6ooooo`03oc<0oooooooooooo02;ooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`0;ooooo`00C_ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo02_o
oooo0_l0ofHCooooo`03o`3ooooooooooooo00Sooooo0_l0I_l4ooooo`03o`1Voooooooooooo00go
oooo00?o<`3oooooooooool08oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00_o
oooo001?ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0:?ooool2o`3oIQ?ooooo
0_l0ool9ooooo`;o06Ko1Oooool00ol0I_ooooooooooo`0<ooooo`;o<`3o9oooool00ol0003ooooo
ooooo`0aooooo`03o`000?oooooooooo00[ooooo001@ooooo`03o`000?oooooooooo04_ooooo00?o
0000ooooooooool09_ooool00ol0ofKoooooooooo`0Booooo`03o`3ooooooooooooo00Sooooo00?o
06Koooooooooool01?ooool00ol0I_ooooooooooo`0<ooooo`03oc<0oooooooo<`3o02Sooooo00?o
0000ooooooooool0<Oooool00ol0003oooooooooo`09ooooo`00DOooool00ol0003oooooooooo`1;
ooooo`03o`000?oooooooooo02?ooooo0_l0ofHDooooo`03o`3ooooooooooooo00Kooooo0ol0I_l7
ooooo`03o`1Voooooooooooo00_ooooo00?o<`3ooooooolc0?l0:_ooool00ol0003oooooooooo`0a
ooooo`03o`000?oooooooooo00Sooooo001Booooo`03o`000?oooooooooo04_ooooo00?o0000oooo
ooooool08?ooool2o`3oIQCooooo0_l0ool6ooooo`?o06Ko2Oooool00ol0I_ooooooooooo`0;oooo
o`03oc<0oooooooo<`3o02cooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`08oooo
o`00Doooool2o`0004cooooo00?o0000ooooooooool07Oooool2o`3oIQGooooo00?o0?oooooooooo
ool00_ooool4o`1Vo`_ooooo00?o06Koooooooooool02oooool01?lc0?oooooooooooolc0?l]oooo
o`03o`000?oooooooooo033ooooo00?o0000ooooooooool01oooool005Gooooo00?o0000oooooooo
ool0B_ooool00ol0003oooooooooo`0Jooooo`;o0?mV5_ooool00ol0ooooooooooooo`03o`1Vo`ko
oooo00?o06Koooooooooool02oooool01?lc0?oooooooooooolc0?l^ooooo`03o`000?oooooooooo
037ooooo00?o0000ooooooooool01_ooool005Kooooo00?o0000ooooooooool0B_ooool00ol0003o
ooooooooo`0Hooooo`03o`3oI_oooooooooo01?ooooo1_l0I_l@ooooo`03o`1Voooooooooooo00[o
oooo0_lc0?l2ooooo`03oc<0oooooooooooo00cooooo00?oc03oooooooooool00_ooool4o`1VoaWo
oooo00?o0000ooooooooool0;oooool3o`0000Oooooo001Gooooo`03o`000?oooooooooo04[ooooo
00?o0000ooooooooool05?ooool4o`1Vo`kooooo1ol0I_l00ol0ooooooooooooo`0Aooooo`;o06Ko
2oooool2oc<0o`?ooooo00?o<`3oooooooooool03?ooool2ol`0o`Co06Ko7_ooool00ol0003ooooo
ooooo`0[ooooo`?o00000_ooool00ol0003oooooooooo`05ooooo`00F?ooool00ol0003ooooooooo
o`1:ooooo`03o`000?oooooooooo01?ooooo00?o0?mVooooooooool03ol0I_l6ooooo`03o`3ooooo
oooooooo017ooooo00?o06Koooooooooool02Oooool2oc<0o`Cooooo00?o<`3oooooooooool01_oo
ool6o`1Vo`;oc03o9?ooool00ol0003oooooooooo`0Wooooo`?o00001Oooool00ol0003ooooooooo
o`05ooooo`00FOooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo01_ooooo2?l0I_l5
ooooo`;o0?oo4oooool00ol0I_ooooooooooo`08ooooo`;o<`3o1Oooool01?lc0?oooooooooooooo
ool6o`1Vo`Gooooo0_o<0?lVooooo`03o`000?oooooooooo02;ooooo1?l00008ooooo`03o`000?oo
oooooooo00Gooooo001Jooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool08_ooool<
o`1Vo`cooooo0_l0I_l5ooooo`Go06Ko00?o<`3oo`1Vool0I_l01?l0I_l00olc0?oo06Koo`1Vo`02
o`1Vo`[ooooo0_o<0?lXooooo`03o`000?oooooooooo01kooooo0ol0000<ooooo`03o`000?oooooo
oooo00Gooooo001Kooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool08_ooool2o`3o
o`Wooooo4ol0I_l3ooooo`;o<`3o1oooool00olc0?ooooooooooo`0;ooooo`03ol`0ooooooooc03o
02Sooooo00?o0000ooooooooool06_ooool4o`0000oooooo00?o0000ooooooooool01Oooool005co
oooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0Pooooo`03o`3ooooooooooooo01?o
oooo00?o06Koooooooooool01oooool2oc<0o`Sooooo00?o<`3oooooooooool02oooool00oo<0?oo
oooool`0o`0Zooooo`03o`000?oooooooooo01Kooooo0ol0000Dooooo`03o`000?oooooooooo00Co
oooo001Mooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool07Oooool2o`3ooaCooooo
0_l0I_l7ooooo`?o<`3o2Oooool00olc0?ooooooooooo`0;ooooo`03ol`0ooooooooc03o02cooooo
00?o0000ooooooooool04_ooool3o`0001Oooooo00?o0000ooooooooool01?ooool005kooooo0_l0
001;ooooo`03o`000?oooooooooo01[ooooo0_l0oolEooooo`03o`1Voooooooooooo00Cooooo0olc
0?l;ooooo`03oc<0oooooooooooo00_ooooo00Coc03oooooooooooooc03o;Oooool00ol0003ooooo
ooooo`0=ooooo`Co00006_ooool00ol0003oooooooooo`04ooooo`00H?ooool00ol0003ooooooooo
o`19ooooo`03o`000?oooooooooo01Oooooo0_l0oolFooooo`03o`1Voooooooooooo00;ooooo0olc
0?l=ooooo`03oc<0oooooooooooo00_ooooo00Coc03oooooooooooooc03o3_ooool00ooo09Wooooo
ooooo`0Nooooo`03o`000?oooooooooo00Wooooo0ol0000Nooooo`03o`000?oooooooooo00Cooooo
001Qooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool05?ooool2o`3ooaOooooo00?o
06Koooooooooool00olc0?l?ooooo`03oc<0oooooooooooo00_ooooo00Coc03oooooooooooooc03o
3oooool00ooo09Woooooooooo`0Oooooo`03o`000?oooooooooo00Cooooo1?l0000Qooooo`03o`00
0?oooooooooo00Cooooo001Rooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool04_oo
ool00ol0ooooooooooooo`0Eooooo`;o06Ko0olc0?l@ooooo`;o<`3o3?ooool2ol`0o`;ooooo00?o
c03oooooooooool03Oooool00ooo09Woooooooooo`0Pooooo`04o`000?ooooooooooooooo`?o0000
9Oooool00ol0003oooooooooo`04ooooo`00Hoooool00ol0003oooooooooo`19ooooo`03o`000?oo
oooooooo00oooooo0_l0oolDooooo`Ko<`3o4_ooool00olc0?ooooooooooo`0:ooooo`;oc03o0ooo
ool00oo<0?ooooooooooo`0=ooooo`03ool0VOoooooooooo02;ooooo0ol0000Xooooo`03o`000?oo
oooooooo00Cooooo001Tooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool03Oooool0
0ol0ooooooooooooo`0;ooooo`Wo<`3o0_ooool00ol0I_ooooooooooo`0Booooo`03oc<0oooooooo
oooo00Wooooo0_o<0?l4ooooo`03ol`0oooooooooooo00cooooo0_oo09T5oc<0oacooooo1?l00000
0ooooooo0000ooooo`0Xooooo`03o`000?oooooooooo00Cooooo001Uooooo`03o`000?oooooooooo
04Wooooo00?o0000ooooooooool01?oooolFoc<0o`Wooooo0_l0I_lCooooo`;o<`3o2_ooool2ol`0
o`Gooooo00?oc03oooooooooool01_ooool6oc<0o`03ool0VOlc0?ooo`2I01kooooo0ol00006oooo
o`03o`000?oooooooooo02Kooooo00?o0000ooooooooool01?ooool006Kooooo00?o0000oooooooo
ool0BOooool00ol0003oooooooooo`0:ooooo`_o<`3o2oooool2o`1VoaCooooo00?o<`3ooooooooo
ool02Oooool00oo<0?ooooooooooo`05ooooo`03ol`0oolc0?oo<`3o00Ko<`3o1Oooool00ooo09Wo
ooooool0V@0Kooooo`Co00002_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Co
oooo001Wooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool05?ooool=oc<0oa;ooooo
0_lc0?l00ooooooo<`3ooc<0o`07oc<0o`;oc03o1olc0?l00oo<0?ooooooooooo`0;ooooo`03ool0
VOooooooo`2I01Wooooo0ol0000?ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool0
0oooool006Sooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0Kooooo`03o`1Voooo
oooooooo00;ooooo5Olc0?l7ooooo`;oc03o2?ooool00oo<0?ooooooooooo`0:ooooo`;oo`2I0_oo
ool00ooo09Woooooooooo`0Dooooo`?o00004_ooool00ol0003oooooooooo`0Uooooo`03o`000?oo
oooooooo00?ooooo001Yooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool06?ooool2
o`1VoaGooooo00?o<`3oooooooooool01oooool2ol`0o`Wooooo00?oc03oooooooooool02_ooool0
1Ooo09Woooooooooooooooooo`2I00gooooo00?oo`00ooooooooool00oooool4o`0001Kooooo00?o
0000ooooooooool09?ooool00ol0003oooooooooo`03ooooo`00J_ooool2o`0004[ooooo00?o0000
ooooooooool05Oooool2o`1VoaGooooo0_lc0?l7ooooo`?oc03o2_ooool00oo<0?ooooooooooo`0:
ooooo`05ool0VOoooooooooooooooooo09T03_ooool00ooo003oooooooooo`03o`0001_ooooo00?o
0000ooooooooool08oooool00ol0003oooooooooo`03ooooo`00K?ooool00ol0003oooooooooo`18
ooooo`03o`000?oooooooooo01;ooooo0_l0I_lFooooo`03oc<0oooooooooooo00Cooooo0oo<0?l<
ooooo`03ol`0oooooooooooo00[ooooo00Goo`2Iooooooooooooooooool0V@0>ooooo`04ool00?l0
003o0000o`0001oooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`03ooooo`00KOoo
ool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00oooooo0_l0I_lFooooo`;o<`3o0ooo
ool4ol`0o`gooooo0_o<0?l;ooooo`;oo`2I0oooool00ooo09Woooooooooo`0:ooooo`;o00000_oo
000Sooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool00oooool006kooooo00?o0000
ooooooooool0B?ooool00ol0003oooooooooo`0=ooooo`03o`1Voooooooooooo01Gooooo00?o<`3o
ooooooo<0?l00oo<0?l@ooooo`03ol`0oooooooooooo00Wooooo0_oo09T4ooooo`03ool0VOoooooo
oooo00Sooooo0ol00003ool002Gooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`03
ooooo`00Koooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo00[ooooo0_l0I_lGoooo
o`?oc03o4_ooool2ol`0o`_ooooo00?oo`2Iooooooooool00oooool00ooo09Woooooooooo`05oooo
o`Co00000_ooool00ooo003oooooool0000Vooooo`03o`000?oooooooooo023ooooo00?o0000oooo
ooooool00oooool0073ooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`08ooooo`03
o`1Voooooooooooo01;ooooo1Oo<0?lDooooo`03ol`0oooooooooooo00Wooooo0_oo09T5ooooo`03
ool0VOoooooooooo00?ooooo0ol00005ooooo`04ool00?ooooooooooool002Oooooo00?o0000oooo
ooooool07oooool00ol0003oooooooooo`03ooooo`00LOooool00ol0003oooooooooo`18ooooo`03
o`000?oooooooooo01Gooooo1oo<0?l00ooooooo<`3ooc<0o`0Eooooo`03ol`0oooooooooooo00So
oooo0_oo09T6ooooo`03ool0VOoooooooooo00Co00001_ooool01_o<0?ooo`00ol`0ooo<0?ooo`00
ol`0obSooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`03ooooo`00L_ooool00ol0
003oooooooooo`11ooooo`koc03o2_ooool6ol`0o`Kooooo0_lc0?lEooooo`;oc03o2Oooool2ool0
V@Oooooo00Goo`2Io`000?l0003o0000ooooo`09ol`0o`05ool00?oooooooooooooooooo0000:_oo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00;ooooo001cooooo`03o`000?oooooo
oooo04Oooooo4Oo<0?l;ooooo`03oc<0oooooooooooo01Cooooo00?oc03oooooooooool01oooool2
ool0V@Gooooo0oo<0?l00ooo09Woc03ool`0o`03ol`0o`Sooooo00Goo`00ooooooooooooooooool0
000/ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool00_ooool007Cooooo00?o0000
ooooooooool0B?ooool00ol0003oooooooooo`07ooooo`goc03o00?ooooooc<0oolc0?l04oooool=
ol`0o`03ool0VOo<0?ooc03o00Goc03o0_l000000ooo09Woooooooooo`0;ooooo`05ool00?oooooo
oooooooooooo0000;_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00;ooooo001e
ooooo`;o0000BOooool00ol0003oooooooooo`0Booooo`03oc<0ooo<0?ooc03o01Coc03o00?ooooo
ol`0ooooool02?ooool2ool0V@?ooooo0ol00003ooooo`03ool0VOoooooooooo00_ooooo00Goo`00
ooooooooooooooooool0000_ooooo`03o`000?oooooooooo01cooooo00?o0000ooooooooool00_oo
ool007Oooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0?ooooo`;o<`3o5_ooool2
ol`0o`Oooooo0ooo09T00ooooooo0000o`000002o`0000Gooooo00?oo`2Iooooooooool02oooool0
1Ooo003oooooooooooooooooo`00037ooooo00?o0000ooooooooool06oooool00ol0003ooooooooo
o`02ooooo`00N?ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo00cooooo0_lc0?lG
ooooo`03ol`0oooooooooooo00Cooooo0ooo09T01?oooooo0000o`000?l00007ooooo`;oo`2I3Ooo
ool01Ooo003oooooooooooooooooo`0003?ooooo00?o0000ooooooooool06_ooool00ol0003ooooo
ooooo`02ooooo`00NOooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo00[ooooo00?o
<`3oooooooooool05_ooool01?o<0?ooooooooooooooool4ool0V@04ooooool0003o0000o`0000Wo
oooo00?oo`2Iooooooooool02oooool2ool000?ooooo00?oo`00ooooooooool0<oooool00ol0003o
ooooooooo`0Iooooo`03o`000?oooooooooo00;ooooo001jooooo`03o`000?oooooooooo04Oooooo
00?o0000ooooooooool01oooool2oc<0oaOooooo0_o<0?l01Oooooooo`2Iool0VOoo09Wooooo00Co
00002_ooool2ool0V@cooooo0_oo0004ooooo`03ool00?oooooooooo03Gooooo00?o0000oooooooo
ool06?ooool00ol0003oooooooooo`02ooooo`00Noooool00ol0003oooooooooo`17ooooo`03o`00
0?oooooooooo00Cooooo0_lc0?lHooooo`Coo`2I00Coooooo`000?l0003o00003Oooool00ooo09Wo
ooooooooo`0:ooooo`;oo`001Oooool00ooo003oooooooooo`0gooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool00_ooool007cooooo00?o0000ooooooooool0Aoooool00ol0003ooooo
ooooo`02ooooo`03oc<0oooooooooooo01Gooooo0ooo09T00ooooooo0000o`000002o`0000oooooo
00?oo`2Iooooooooool02_ooool00ooo003oooooooooo`04ooooo`03ool00?oooooooooo03Sooooo
00?o0000ooooooooool05oooool00ol0003oooooooooo`02ooooo`00OOooool00ol0003ooooooooo
o`17ooooo`03o`000?oooooooooo01?ooooo1_oo09T01?o<0?oo0000o`000?l0000Aooooo`;oo`2I
2oooool2ool000Kooooo00?oo`00ooooooooool0>_ooool00ol0003oooooooooo`0Gooooo`03o`00
0?oooooooooo007ooooo001nooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool02ooo
ool7ool0V@?ooooo0_o<0?l2o`0001?ooooo00?oo`2Iooooooooool02Oooool2ool000Oooooo00?o
o`00ooooooooool01_ooool6ool0VC3ooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`01ooooo`00Ooooool00ol0003oooooooooo`0aoooooa7oo`2I1Oooool00ol0003oooooooooo`03
ooooo`Ooo`2I1oooool01?l0003oc03ool`0ool0000Dooooo`;oo`2I2_ooool2ool000Sooooo00?o
o`00ool0VOoo09T01ooo09Tgooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool00Ooo
ool0083ooooo0_l0000hoooooaGoo`2I2oooool2o`0000;oc03o5_ooool00ooo09Woooooooooo`08
ooooo`;oo`0000?oooooool0VOoo09T01_oo09T00ooo003oooooooooo`10ooooo`03o`000?oooooo
oooo01Cooooo00?o0000ooooooooool00Oooool008;ooooo00?o0000ooooooooool0@_ooool?ool0
V@Co00000_o<0?lAoooooa7oo`2I00Coo`00ool0VOoo09Woo`2I1oooool00ooo003oooooooooo`12
ooooo`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00Oooool008?ooooo00?o0000oooo
ooooool0A_ooool00ol0003oooooooooo`04ooooo`?o00005ooo09T4ooooo`03ool0VOoooooooooo
00Sooooo0_oo0009ooooo`;oo`00AOooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo
007ooooo0024ooooo`03o`000?oooooooooo04Kooooo00?o0000ooooooooool00ol00003ooooo`;o
c03o6?ooool00ooo09Woooooooooo`06ooooo`?oo`002_ooool00ooo003oooooooooo`16ooooo`03
o`000?oooooooooo01;ooooo00?o0000ooooooooool00Oooool008Gooooo00?o0000ooooooooool0
A_ooool2o`0000Cooooo0_o<0?lHooooo`;oo`2I1Oooool4ool000_ooooo0_oo001:ooooo`03o`00
0?oooooooooo017ooooo00?o0000ooooooooool00Oooool008Kooooo00?o0000ooooooooool0AOoo
ool01?l0003oooooooooooooool2ol`0oaWooooo00Coo`2Ioooooooooooooooo1?oo000>ooooo`03
ool00?oooooooooo04_ooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`01ooooo`00
Qoooool00ol0003oooooooooo`14ooooo`04o`000?oooooooooool`0oaWooooo0_oo09T01?oooooo
o`00ool00?oo000@ooooo`;oo`00Coooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo
007ooooo0028ooooo`03o`000?oooooooooo04?ooooo00?o0000ooooooooool06?ooool00ooo09Wo
o`00ool00002ool001;ooooo00?oo`00ooooooooool0D?ooool00ol0003oooooooooo`0?ooooo`7o
00000Oooool1ooooo`00ROooool00ol0003oooooooooo`12ooooo`03o`000?oooooooooo01Gooooo
1?oo000Dooooo`;oo`00Doooool00ol0003oooooooooo`0?ooooo`7o00000Oooool1ooooo`00R_oo
ool00ol0003oooooooooo`11ooooo`03o`000?oooooooooo00oooooo1_oo00000ooo09Wooooooooo
o`0Dooooo`03ool00?oooooooooo05Cooooo00?o0000ooooooooool03_ooool1o`00007ooooo0Ooo
ool008_ooooo0_l00011ooooo`03o`000?oooooooooo00Oooooo2?oo0003ooooo`;oo`2I5oooool0
0ooo003oooooooooo`0Jooooo`Goo`00=oooool00ol0003oooooooooo`0=ooooo`7o00000Oooool1
ooooo`00SOooool00ol0003oooooooooo`0Qooooo`Ooo`005_ooool00ol0003oooooool00007ool0
00Wooooo0_oo09TGooooo`;oo`005Oooool8ool003gooooo00?o0000ooooooooool03?ooool1o`00
007ooooo0Oooool008kooooo00?o0000ooooooooool09OoooolJool000oooooo0_oo09THooooo`03
ool00?oooooooooo00kooooo1ooo0016ooooo`03o`000?oooooooooo00_ooooo0Ol00001ooooo`7o
oooo002?ooooo`03o`000?oooooooooo037ooooo2_oo00000ooooooo0000ooooo`0=ooooo`;oo`2I
6?ooool2ool000Wooooo2?oo001>ooooo`03o`000?oooooooooo00[ooooo0Ol00001ooooo`7ooooo
002@ooooo`03o`000?oooooooooo03[ooooo2_oo0004ooooo`;oo`2I4?oooolEool005Kooooo00?o
0000ooooooooool02_ooool1o`00007ooooo0Oooool0097ooooo00?o0000ooooooooool0>_ooool0
0ol0003oooooooooo`06oooooaKoo`001oooool2ool006?ooooo00?o0000ooooooooool02Oooool1
o`00007ooooo0Oooool009;ooooo00?o0000ooooooooool0>Oooool00ol0003oooooooooo`06oooo
o`;oo`2I6_ooool00ooo003oooooooooo`1Tooooo`03o`000?oooooooooo00Sooooo0Ol00001oooo
o`7ooooo002Cooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool01Oooool00ooo09Wo
ooooooooo`0Hooooo`;oo`00J?ooool00ol0003oooooooooo`08ooooo`7o00000Oooool009Cooooo
00?o0000ooooooooool0=oooool00ol0003oooooooooo`0Nooooo`;oo`00Joooool00ol0003ooooo
ooooo`07ooooo`7o00000Oooool009Gooooo00?o0000ooooooooool0=_ooool00ol0003ooooooooo
o`0Looooo`;oo`00K_ooool00ol0003oooooooooo`06ooooo`7o00000Oooool009Kooooo00?o0000
ooooooooool0=Oooool00ol0003oooooooooo`0Jooooo`;oo`00L?ooool00ol0003oooooooooo`06
ooooo`7o00000Oooool009Oooooo0_l0000eooooo`03o`000?oooooooooo01Sooooo0_oo001coooo
o`03o`000?oooooooooo00Gooooo0Ol00001ooooo`00VOooool00ol0003oooooooooo`0booooo`03
o`000?oooooooooo01Kooooo0_oo001fooooo`03o`000?oooooooooo00Cooooo0Ol00001ooooo`00
V_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo01Cooooo0_oo001iooooo`03o`00
0?oooooooooo00?ooooo0Ol00001ooooo`00Voooool00ol0003oooooooooo`0`ooooo`03o`000?oo
oooooooo01;ooooo0_oo001looooo`03o`000?oooooooooo00;ooooo0Ol00001ooooo`00W?ooool0
0ol0003oooooooooo`0_ooooo`03o`000?oooooooooo013ooooo0_oo001oooooo`05o`000?oooooo
ooooooooool000000Oooool009gooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0>
ooooo`;oo`00POooool01Ol0003ooooooooooooooooo0000007ooooo002Nooooo`03o`000?oooooo
oooo02gooooo00?o0000ooooooooool03?ooool2ool008Cooooo00Co0000oooooooooooooooo0Ol0
000009oooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0;ooooo`03ool00?oooooo
oooo08Gooooo00?o0000ooooooooool00Ol000000:3ooooo00?o0000ooooooooool0:oooool00ol0
003oooooooooo`2Dooooo`7o00000Oooool1o`000000XOooool00ol0003oooooooooo`0Zooooo`03
o`000?oooooooooo09Gooooo0_l000000:;ooooo0_l0000Zooooo`03o`000?oooooooooo09Cooooo
0ol000000:Cooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`2@ooooo`Co00000ooo
ool00:Gooooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`2=ooooo`?o00001oooool0
0:Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`29ooooo`Co00002_ooool00:Oo
oooo00?o0000ooooooooool09?ooool00ol0003oooooooooo`25ooooo`Co00003_ooool00:Sooooo
00?o0000ooooooooool08oooool00ol0003oooooooooo`22ooooo`?o00004_ooool00:Wooooo00?o
0000ooooooooool08_ooool00ol0003oooooooooo`1nooooo`Co00005Oooool00:[ooooo00?o0000
ooooooooool08Oooool00ol0003oooooooooo`1jooooo`Co00006Oooool00:_ooooo00?o0000oooo
ooooool08Oooool00ol0003oooooooooo`1eooooo`Co00007Oooool00:cooooo00?o0000oooooooo
ool08?ooool00ol0003oooooooooo`1booooo`?o00008Oooool00:gooooo0_l0000Pooooo`03o`00
0?oooooooooo06kooooo1?l0000Tooooo`00[oooool00ol0003oooooooooo`0Mooooo`03o`000?oo
oooooooo06[ooooo1?l0000Xooooo`00/?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooo
oooo06Oooooo0ol0000/ooooo`00/Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo
06?ooooo1?l0000_ooooo`00/_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo05oo
oooo1?l0000cooooo`00/oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo05cooooo
0ol0000gooooo`00]?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo05Sooooo1?l0
000jooooo`00]Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo05Cooooo1?l0000n
ooooo`00]_ooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo053ooooo1?l00012oooo
o`00]oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo04gooooo0ol00016ooooo`00
^?ooool2o`0001Gooooo00?o0000ooooooooool0BOooool4o`0004Wooooo002jooooo`03o`000?oo
oooooooo01;ooooo00?o0000ooooooooool0AOooool4o`0004gooooo002kooooo`03o`000?oooooo
oooo017ooooo00?o0000ooooooooool0@_ooool3o`00057ooooo002looooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool0?_ooool4o`0005Cooooo002mooooo`03o`000?oooooooooo00oo
oooo00?o0000ooooooooool0>_ooool4o`0005Sooooo002nooooo`03o`000?oooooooooo00kooooo
00?o0000ooooooooool0=_ooool4o`0005cooooo002oooooo`03o`000?oooooooooo00gooooo00?o
0000ooooooooool0<oooool3o`00063ooooo0030ooooo`03o`000?oooooooooo00cooooo00?o0000
ooooooooool0;oooool4o`0006?ooooo0031ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool0:oooool4o`0006Oooooo0032ooooo`03o`000?oooooooooo00[ooooo00?o0000oooooooo
ool0:?ooool3o`0006_ooooo0033ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
9?ooool4o`0006kooooo0034ooooo`;o00002Oooool00ol0003oooooooooo`0Pooooo`Co0000L_oo
ool00<Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0Mooooo`?o0000M_ooool0
0<Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0Iooooo`Co0000NOooool00<So
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0Eooooo`Co0000OOooool00<Wooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`0Aooooo`Co0000POooool00<[ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`0>ooooo`?o0000QOooool00<_ooooo00Go0000
ooooooooooooooooo`00000<ooooo`Co0000R?ooool00<cooooo00Co0000oooooooooooo00002?oo
ool4o`0008cooooo003=ooooo`03o`000?oooooo000000Gooooo0ol0002@ooooo`00c_ooool2o`00
0003ooooool0003o000000;o0000Toooool00<oooooo0_l0002Gooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {330.375, 0}} -> {-0.0771432, -0.0315529, \
0.00350368, 0.00350368}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .92059 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-16 1.0763 -0.0263982 1.0763 [
[.01694 .18568 -11.9631 -9 ]
[.01694 .18568 .03693 0 ]
[.13793 .13897 -11.619 -9 ]
[.13793 .13897 .38095 0 ]
[.26292 .09073 -5.63752 -9 ]
[.26292 .09073 .36248 0 ]
[.39212 .04087 -5.46552 -9 ]
[.39212 .04087 .53448 0 ]
[.52574 -0.01069 -5.29351 -9 ]
[.52574 -0.01069 .70649 0 ]
[.58272 .04263 0 -6.19654 ]
[.58272 .04263 6 2.80346 ]
[.71715 .21863 0 -6.07114 ]
[.71715 .21863 6 2.92886 ]
[.83675 .37523 0 -5.963 ]
[.83675 .37523 6 3.037 ]
[.94385 .51546 0 -5.8688 ]
[.94385 .51546 6 3.1312 ]
[.01386 .20006 -12 -2.76892 ]
[.01386 .20006 0 6.23108 ]
[.00748 .25499 -24 -2.80073 ]
[.00748 .25499 0 6.19927 ]
[.00093 .31131 -6 -2.83339 ]
[.00093 .31131 0 6.16661 ]
[-0.00579 .36907 -18 -2.86695 ]
[-0.00579 .36907 0 6.13305 ]
[-0.01268 .42831 -6 -2.90143 ]
[-0.01268 .42831 0 6.09857 ]
[ 0 0 0 0 ]
[ 1 .92059 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02642 .19522 m
.53391 0 L
s
.02642 .19522 m
.03116 .2 L
s
[(-2)] .01694 .18568 .99384 1 Mshowa
.14712 .14879 m
.15172 .1537 L
s
[(-1)] .13793 .13897 .93651 1 Mshowa
.2718 .10083 m
.27624 .10588 L
s
[(0)] .26292 .09073 .87917 1 Mshowa
.40066 .05126 m
.40493 .05646 L
s
[(1)] .39212 .04087 .82184 1 Mshowa
.53391 0 m
.538 .00534 L
s
[(2)] .52574 -0.01069 .7645 1 Mshowa
.125 Mabswid
.05025 .18606 m
.05308 .18894 L
s
.07424 .17683 m
.07705 .17973 L
s
.09837 .16755 m
.10117 .17046 L
s
.12267 .1582 m
.12545 .16113 L
s
.17173 .13933 m
.17447 .14229 L
s
.19651 .1298 m
.19923 .13278 L
s
.22144 .1202 m
.22414 .1232 L
s
.24654 .11055 m
.24922 .11356 L
s
.29723 .09105 m
.29988 .0941 L
s
.32283 .0812 m
.32546 .08427 L
s
.3486 .07129 m
.35121 .07437 L
s
.37455 .06131 m
.37713 .06441 L
s
.42695 .04115 m
.4295 .04428 L
s
.45342 .03096 m
.45594 .03412 L
s
.48007 .02071 m
.48257 .02388 L
s
.5069 .01039 m
.50938 .01358 L
s
.25 Mabswid
.53391 0 m
.9804 .58403 L
s
.57014 .04738 m
.56384 .04975 L
s
[(0)] .58272 .04263 -1 .37701 Mshowa
.70445 .22307 m
.6981 .22529 L
s
[(2)] .71715 .21863 -1 .34914 Mshowa
.82396 .37939 m
.81756 .38147 L
s
[(4)] .83675 .37523 -1 .32511 Mshowa
.93098 .51938 m
.92454 .52134 L
s
[(6)] .94385 .51546 -1 .30418 Mshowa
.125 Mabswid
.60525 .09331 m
.60147 .09471 L
s
.63931 .13786 m
.63552 .13924 L
s
.67236 .1811 m
.66856 .18245 L
s
.73562 .26383 m
.7318 .26514 L
s
.7659 .30345 m
.76207 .30473 L
s
.79534 .34195 m
.7915 .34322 L
s
.85181 .41581 m
.84796 .41704 L
s
.87891 .45126 m
.87506 .45247 L
s
.90529 .48577 m
.90143 .48696 L
s
.95601 .55212 m
.95214 .55328 L
s
.25 Mabswid
.02642 .19522 m
0 .42381 L
s
.02642 .19522 m
.0327 .19281 L
s
[(-1)] .01386 .20006 1 -0.38468 Mshowa
.02006 .25024 m
.02635 .24786 L
s
[(-0.5)] .00748 .25499 1 -0.37762 Mshowa
.01354 .30664 m
.01985 .3043 L
s
[(0)] .00093 .31131 1 -0.37036 Mshowa
.00686 .36448 m
.01318 .36218 L
s
[(0.5)] -0.00579 .36907 1 -0.3629 Mshowa
0 .42381 m
.00634 .42156 L
s
[(1)] -0.01268 .42831 1 -0.35524 Mshowa
.125 Mabswid
.02516 .20612 m
.02893 .20468 L
s
.0239 .21707 m
.02767 .21563 L
s
.02262 .22807 m
.0264 .22664 L
s
.02135 .23913 m
.02512 .2377 L
s
.01877 .26141 m
.02255 .25999 L
s
.01747 .27263 m
.02125 .27122 L
s
.01617 .28391 m
.01995 .2825 L
s
.01486 .29525 m
.01864 .29384 L
s
.01222 .31809 m
.01601 .3167 L
s
.01089 .3296 m
.01468 .32821 L
s
.00955 .34117 m
.01334 .33978 L
s
.00821 .35279 m
.012 .35141 L
s
.0055 .37622 m
.0093 .37485 L
s
.00414 .38803 m
.00793 .38666 L
s
.00276 .39989 m
.00656 .39853 L
s
.00139 .41182 m
.00519 .41047 L
s
.25 Mabswid
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.54154 .92059 L
s
.54154 .92059 m
.5414 .7134 L
s
.5414 .7134 m
.02642 .19522 L
s
.53391 0 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.53391 0 m
.02642 .19522 L
s
.5414 .7134 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.54154 .92059 L
s
.54154 .92059 m
.5414 .7134 L
s
0 0 m
1 0 L
1 .92059 L
0 .92059 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.59769 .79793 m
.66776 .76329 L
s
1 0 .6 r
.58127 .76532 m
.6482 .73164 L
s
.8 0 1 r
.56482 .73269 m
.62863 .70002 L
s
.2 0 1 r
.54837 .70005 m
.60907 .66842 L
s
0 .4 1 r
.53192 .66739 m
.58953 .63685 L
s
0 1 1 r
.51545 .63472 m
.57001 .6053 L
s
0 1 .4 r
.49898 .60204 m
.5505 .57378 L
s
.2 1 0 r
.4825 .56934 m
.53101 .54229 L
s
.8 1 0 r
.46601 .53662 m
.51153 .51082 L
s
1 .6 0 r
.44951 .50389 m
.49207 .47937 L
s
.49207 .47937 m
.53011 .44813 L
s
.8 1 0 r
.51153 .51082 m
.5529 .47744 L
s
.2 1 0 r
.53101 .54229 m
.57576 .50684 L
s
0 1 .4 r
.5505 .57378 m
.59868 .53632 L
s
0 1 1 r
.57001 .6053 m
.62166 .56587 L
s
0 .4 1 r
.58953 .63685 m
.64471 .59551 L
s
.2 0 1 r
.60907 .66842 m
.66782 .62523 L
s
.8 0 1 r
.62863 .70002 m
.69099 .65504 L
s
1 0 .6 r
.6482 .73164 m
.71422 .68492 L
s
1 0 0 r
.66776 .76329 m
.7375 .71491 L
s
.57838 .76064 m
.68909 .75724 L
s
.484 .75398 m
.57838 .76064 L
s
.68909 .75724 m
.78367 .74547 L
s
1 0 .6 r
.57952 .72425 m
.68526 .72094 L
s
.48968 .7178 m
.57952 .72425 L
s
1 0 0 r
.44612 .74873 m
.484 .75398 L
s
1 0 .6 r
.68526 .72094 m
.77606 .70946 L
s
.8 0 1 r
.58069 .68773 m
.68145 .68453 L
s
.49542 .68152 m
.58069 .68773 L
s
1 0 0 r
.53575 .75299 m
.4714 .75158 L
s
.6146 .74393 m
.53575 .75299 L
s
.4714 .75158 m
.44612 .74873 L
s
1 0 .6 r
.45314 .71265 m
.48968 .7178 L
s
.8 0 1 r
.68145 .68453 m
.76844 .67336 L
s
.2 0 1 r
.58186 .6511 m
.67762 .64801 L
s
.50117 .64514 m
.58186 .6511 L
s
1 0 .6 r
.53383 .71649 m
.47542 .71519 L
s
.60559 .70811 m
.53383 .71649 L
s
.47542 .71519 m
.45314 .71265 L
s
.8 0 1 r
.46021 .67648 m
.49542 .68152 L
s
.2 0 1 r
.67762 .64801 m
.7608 .63715 L
s
0 .4 1 r
.58304 .61435 m
.67378 .61137 L
s
.50694 .60864 m
.58304 .61435 L
s
.8 0 1 r
.53192 .67987 m
.47946 .67868 L
s
.59655 .6722 m
.53192 .67987 L
s
.47946 .67868 m
.46021 .67648 L
s
1 0 0 r
.69059 .72203 m
.6146 .74393 L
s
1 .6 0 r
.53011 .44813 m
.55318 .41883 L
s
.2 0 1 r
.46729 .6402 m
.50117 .64514 L
s
0 .4 1 r
.67378 .61137 m
.75314 .60085 L
s
0 1 1 r
.58423 .57748 m
.66993 .57461 L
s
.51273 .57203 m
.58423 .57748 L
s
.2 0 1 r
.52999 .64313 m
.48351 .64207 L
s
.5875 .6362 m
.52999 .64313 L
s
1 0 .6 r
.67462 .68788 m
.60559 .70811 L
s
.2 0 1 r
.48351 .64207 m
.46729 .6402 L
s
.8 1 0 r
.5529 .47744 m
.57838 .4458 L
s
0 .4 1 r
.4744 .60382 m
.50694 .60864 L
s
0 1 1 r
.66993 .57461 m
.74546 .56444 L
s
.8 0 1 r
.65865 .6537 m
.59655 .6722 L
s
0 1 .4 r
.58542 .54049 m
.66606 .53774 L
s
.51853 .53532 m
.58542 .54049 L
s
0 .4 1 r
.52806 .60627 m
.48757 .60534 L
s
.57842 .6001 m
.52806 .60627 L
s
.2 1 0 r
.57576 .50684 m
.6037 .47291 L
s
0 .4 1 r
.48757 .60534 m
.4744 .60382 L
s
0 1 1 r
.48153 .56733 m
.51273 .57203 L
s
0 1 .4 r
.66606 .53774 m
.73775 .52794 L
s
.2 0 1 r
.64267 .6195 m
.5875 .6362 L
s
.2 1 0 r
.58661 .50337 m
.66219 .50076 L
s
.52435 .49849 m
.58661 .50337 L
s
0 1 .4 r
.59868 .53632 m
.62914 .50015 L
s
0 1 1 r
.52612 .56929 m
.49165 .56849 L
s
.56931 .56392 m
.52612 .56929 L
s
.49165 .56849 m
.48153 .56733 L
s
0 1 .4 r
.48868 .53074 m
.51853 .53532 L
s
0 .4 1 r
.62667 .58527 m
.57842 .6001 L
s
.2 1 0 r
.66219 .50076 m
.73003 .49133 L
s
0 1 1 r
.62166 .56587 m
.6547 .52751 L
s
.8 1 0 r
.58781 .46614 m
.6583 .46365 L
s
.53019 .46155 m
.58781 .46614 L
s
0 1 .4 r
.52418 .53218 m
.49574 .53152 L
s
.56019 .52764 m
.52418 .53218 L
s
.2 1 0 r
.49584 .49405 m
.52435 .49849 L
s
0 1 .4 r
.49574 .53152 m
.48868 .53074 L
s
0 1 1 r
.61066 .551 m
.56931 .56392 L
s
.8 1 0 r
.6583 .46365 m
.72229 .45463 L
s
0 .4 1 r
.64471 .59551 m
.68038 .55501 L
s
.2 1 0 r
.52223 .49496 m
.49984 .49444 L
s
.55104 .49127 m
.52223 .49496 L
s
1 .6 0 r
.58901 .42878 m
.6544 .42643 L
s
.53605 .4245 m
.58901 .42878 L
s
.8 1 0 r
.50303 .45725 m
.53019 .46155 L
s
0 1 .4 r
.59463 .51671 m
.56019 .52764 L
s
.2 1 0 r
.49984 .49444 m
.49584 .49405 L
s
.2 0 1 r
.66782 .62523 m
.70619 .58264 L
s
1 .6 0 r
.6544 .42643 m
.71452 .41782 L
s
.2 1 0 r
.57859 .48239 m
.55104 .49127 L
s
1 .6 0 r
.51024 .42035 m
.53605 .4245 L
s
.8 1 0 r
.52028 .45762 m
.50396 .45725 L
s
.54186 .45481 m
.52028 .45762 L
s
.50396 .45725 m
.50303 .45725 L
s
1 0 0 r
.75124 .69052 m
.69059 .72203 L
s
.8 0 1 r
.69099 .65504 m
.73213 .61041 L
s
1 0 .6 r
.72951 .65884 m
.67462 .68788 L
s
.8 1 0 r
.56254 .44804 m
.54186 .45481 L
s
.8 0 1 r
.70783 .62722 m
.65865 .6537 L
s
.2 0 1 r
.68617 .59565 m
.64267 .6195 L
s
1 .6 0 r
.50808 .41993 m
.51024 .42035 L
s
.51831 .42015 m
.50808 .41993 L
s
.53267 .41825 m
.51831 .42015 L
s
1 0 .6 r
.71422 .68492 m
.75819 .63831 L
s
0 .4 1 r
.66456 .56413 m
.62667 .58527 L
s
1 .6 0 r
.55318 .41883 m
.56173 .40321 L
s
.54648 .41366 m
.53267 .41825 L
s
0 1 1 r
.64297 .53267 m
.61066 .551 L
s
0 1 .4 r
.62142 .50125 m
.59463 .51671 L
s
.2 1 0 r
.59991 .46988 m
.57859 .48239 L
s
1 0 0 r
.7375 .71491 m
.78436 .66637 L
s
.8 1 0 r
.57843 .43856 m
.56254 .44804 L
s
1 .6 0 r
.55699 .40729 m
.54648 .41366 L
s
.8 1 0 r
.57838 .4458 m
.58758 .42948 L
s
1 .6 0 r
.56235 .40186 m
.55699 .40729 L
s
.2 1 0 r
.6037 .47291 m
.61357 .45589 L
s
.8 1 0 r
.58705 .42996 m
.57843 .43856 L
s
1 .6 0 r
.56173 .40321 m
.56235 .40186 L
s
.2 1 0 r
.61186 .45816 m
.59991 .46988 L
s
0 1 .4 r
.63676 .48649 m
.62142 .50125 L
s
.62914 .50015 m
.6397 .48245 L
s
0 1 1 r
.66176 .51492 m
.64297 .53267 L
s
0 .4 1 r
.68687 .54348 m
.66456 .56413 L
s
.8 1 0 r
.58758 .42948 m
.58705 .42996 L
s
.2 0 1 r
.71208 .57215 m
.68617 .59565 L
s
0 1 1 r
.6547 .52751 m
.66598 .50915 L
s
.8 0 1 r
.7374 .60094 m
.70783 .62722 L
s
.2 1 0 r
.61357 .45589 m
.61186 .45816 L
s
1 0 .6 r
.76282 .62985 m
.72951 .65884 L
s
1 0 0 r
.78834 .65888 m
.75124 .69052 L
s
0 .4 1 r
.68038 .55501 m
.6924 .536 L
s
0 1 .4 r
.6397 .48245 m
.63676 .48649 L
s
.2 0 1 r
.70619 .58264 m
.71896 .563 L
s
0 1 1 r
.66598 .50915 m
.66176 .51492 L
s
0 .4 1 r
.6924 .536 m
.68687 .54348 L
s
.8 0 1 r
.73213 .61041 m
.74567 .59015 L
s
.2 0 1 r
.71896 .563 m
.71208 .57215 L
s
1 0 .6 r
.75819 .63831 m
.77253 .61744 L
s
.8 0 1 r
.74567 .59015 m
.7374 .60094 L
s
1 0 0 r
.78436 .66637 m
.79954 .64491 L
s
1 0 .6 r
.77253 .61744 m
.76282 .62985 L
s
1 0 0 r
.79954 .64491 m
.78834 .65888 L
s
0 g
.25 Mabswid
.53391 0 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.53391 0 m
.02642 .19522 L
s
.02642 .19522 m
.53391 0 L
s
.02642 .19522 m
.03116 .2 L
s
[(-2)] .01694 .18568 .99384 1 Mshowa
.14712 .14879 m
.15172 .1537 L
s
[(-1)] .13793 .13897 .93651 1 Mshowa
.2718 .10083 m
.27624 .10588 L
s
[(0)] .26292 .09073 .87917 1 Mshowa
.40066 .05126 m
.40493 .05646 L
s
[(1)] .39212 .04087 .82184 1 Mshowa
.53391 0 m
.538 .00534 L
s
[(2)] .52574 -0.01069 .7645 1 Mshowa
.125 Mabswid
.05025 .18606 m
.05308 .18894 L
s
.07424 .17683 m
.07705 .17973 L
s
.09837 .16755 m
.10117 .17046 L
s
.12267 .1582 m
.12545 .16113 L
s
.17173 .13933 m
.17447 .14229 L
s
.19651 .1298 m
.19923 .13278 L
s
.22144 .1202 m
.22414 .1232 L
s
.24654 .11055 m
.24922 .11356 L
s
.29723 .09105 m
.29988 .0941 L
s
.32283 .0812 m
.32546 .08427 L
s
.3486 .07129 m
.35121 .07437 L
s
.37455 .06131 m
.37713 .06441 L
s
.42695 .04115 m
.4295 .04428 L
s
.45342 .03096 m
.45594 .03412 L
s
.48007 .02071 m
.48257 .02388 L
s
.5069 .01039 m
.50938 .01358 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 265.125},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001Bb000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00`oooool5o`000:3ooooo0033ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@0X?ooool00<Cooooo00?oV9RHob4Q8Oo^k^h0XOooool00<Gooooo00?oV9RH
ob4Q8Oo^k^h0X?ooool00<Kooooo00?oMgMgofIVI_ooool0Woooool00<Oooooo00?o0000oooooooo
ool0W_ooool00<?ooooo00Go0000okZj^_ooooooV9RHoa0@402Pooooo`00`oooool01OnHV9So410@
o`000?lQ8B7oc<c<0:3ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003;ooooo`;o0000Voooool00<Sooooo0ol000000ooooooo0000ooooo`2Jooooo`00a_oo
ool2o`0000Cooooo0_l0002Jooooo`00`oooool3o`0000Kooooo00?o0000ooooool00000VOooool0
0<3ooooo1?l00008ooooo`04o`000?ooooooooooo`0009Sooooo002Hooooo`Co000000?o410@oooo
ooooool07oooool2o`0000Cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0002H
ooooo`00V_ooool00ol0003oooooooooo`0Nooooo`?o00003_ooool01Ol0003ooooooooooooooooo
000009Oooooo002Jooooo`03o`000?oooooooooo01cooooo0_l0000Aooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0U?ooool009[ooooo00?o0000ooooooooool06Oooool3o`0000;o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo09?o
oooo002Jooooo`03o`000?oooooooooo01Kooooo0ol0000Fooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^08Kooooo002Jooooo`03o`00
0?oooooooooo01Cooooo0_l0000Iooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1oooool01OmgMgOoV9RHoooooonHV9SoMgMg08Kooooo002Jooooo`03o`000?oooooooooo017ooooo
0ol000000ooooooo0000ooooo`0Hooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1_ooool01Ol@413ooooooooooooooooo410@08Kooooo002Hooooo`03oeEEEOmVIVKo0000017ooooo
0_l0000Nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool01Ol0003ooooo
oooooooooooo000008Kooooo002Yooooo`?o00008?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000026ooooo`00Yoooool3o`0002;ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@
4100Q_ooool00:Cooooo0ol00002ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Q_ooool00:7ooooo
0ol0000Xooooo`03o`000?oooooooooo00Sooooo0_l00004ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h0Q_ooool009oooooo0_l0000[ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo
0000S_ooool009cooooo0ol000000ooooooo0000ooooo`0Zooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0S?ooool009[ooooo0_l00005ooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`2;ooooo`00Uoooool3o`0003;ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`2:ooooo`00K?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^02?ooooo0ol000000ooooooo0000ooooo`0booooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0ROooool006cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Qooooo`;o0000>?ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo08Wooooo001/ooooo`05oa0@4?oooooooooo
ooooool@41007_ooool3o`0003[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`28
ooooo`00K?ooool01Ol0003ooooooooooooooooo000001cooooo0ol0000looooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0Qoooool006cooooo00Go0000ooooooooooooooooo`00000I
ooooo`?o00000_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool0Q_ooool006cooooo00Go410@oooooooooooooooooa0@400Gooooo`;o0000@_ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo08Kooooo001/ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL05?ooool3o`0004Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`25
ooooo`00K?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^017ooooo0ol00002ooooo`03o`000?oooooo
oooo04;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`24ooooo`00P?ooool2o`00
04[ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`23ooooo`00OOooool3o`0004co
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`22ooooo`00Noooool2o`000003oooo
ool0003ooooo04cooooo00?o0000ooooooooool05?ooool2o`0008?ooooo001hooooo`?o0000DOoo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooo000008?ooooo001eooooo`?o0000E?ooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo083ooooo001cooooo`Co0000EOooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo07oooooo001`ooooo`?o00001?ooool00ol0003o
ooooooooo`1Booooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0Ooooool006kooooo
0_l0001Looooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0O_ooool004?ooooo1?l0
00000ol@413oooooooooo`0Qooooo`?o0000G_ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo07gooooo0015ooooo`03o`000?oooooooooo023ooooo0ol00003ooooo`03o`000?oooooo
oooo05_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1looooo`00>_ooool6o`00
00Gooooo00?o0000ooooooooool07_ooool2o`0006Cooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`1looooo`00AOooool00ol0003oooooooooo`0Kooooo`?o0000I_ooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo07_ooooo0015ooooo`03o`000?oooooooooo01Wooooo
0_l00002ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`1jooooo`00AOooool00ol0003oooooooooo`0Fooooo`?o0000Joooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo07Wooooo0015ooooo`03o`000?oooooooooo01Cooooo0_l0001^
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0NOooool004?ooooo00?oEEEEofIV
I_l000004oooool3o`000003ooooool0003ooooo06gooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`1hooooo`00E_ooool3o`0007?ooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`1gooooo`00E?ooool2o`0007Kooooo00?o0000ooooooooool07oooool2o`0007Sooooo
001Aooooo`?o000000?oooooo`000?ooool0MOooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo07Kooooo001?ooooo`;o0000Noooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo07Gooooo001<ooooo`?o0000OOooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
07Cooooo0019ooooo`Co0000Ooooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo07?o
oooo0017ooooo`;o00001?ooool00ol0003oooooooooo`1looooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool0L_ooool004Cooooo0ol00025ooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool0L_ooool001[ooooo1Ol0000Sooooo`?o0000Qoooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo077ooooo000Jooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@08?ooool3
o`0000?ooooo00?o0000ooooooooool0Q?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo073ooooo000Booooo`Ko00000oooool00onHV9So8B4Qonk^kP0Oooooo`;o0000SOooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo06oooooo000Looooo`03oiRHV?lQ8B7ok^k^01_o
oooo0ol0002?ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0Koooool001gooooo
00?oMgMgofIVI_ooool05oooool3o`0000?ooooo00?o0000ooooooooool0S?ooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooooooo06kooooo000Nooooo`03o`000?oooooooooo01Cooooo0_l0
002Eooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0KOooool001[ooooo00Go0000
okZj^_ooooooV9RHoa0@400Cooooo`?o0000Uoooool00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo06cooooo000Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`04Oooool2o`0000?ooooo00?o
0000ooooooooool0U?ooool00ol0003oooooooooo`0Zooooo`;o0000KOooool002gooooo0ol0002L
ooooo`03o`000?oooooooooo02[ooooo0_l0001]ooooo`00:_ooool3o`0009oooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`1Zooooo`00:?ooool2o`0000?ooooo00?o0000oooooooo
ool0W?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo06Wooooo000Uooooo`?o0000
Y?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo06Wooooo000Tooooo`03o`000?oo
oooooooo0:Gooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1Xooooo`006_ooool4
o`000003oa0@4?oooooooooo00?ooooo0_l0002Vooooo`03o`000?oooooooooo02oooooo00?o0000
ooooooooool0Ioooool001cooooo00?o0000ooooooooool01Oooool2o`000:Kooooo00?o0000oooo
ooooool0<?ooool00ol0003oooooooooo`1Vooooo`004Oooool6o`0000Gooooo00?o0000oooooooo
ool01?ooool4o`000:Gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`08ooooo`Go
0000FOooool001cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0002Tooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool01OnHV9So8B4Qonk^k_ooooooA4A4
05Wooooo000Looooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`2Qooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool01oooool00onHV9So
8B4Qonk^kP1Jooooo`007?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0X?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Oooooo
00?oV9RHob4Q8Oo^k^h0FOooool001cooooo00?o0000ooooooooool01?ooool2o`0000Gooooo00?o
0000ooooooooool0Woooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Oooooo00?o
MgMgofIVI_ooool0F?ooool001[ooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo09kooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo05Oooooo000Sooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0WOooool00ol0003oooooooooo`0eooooo`;o00001?ooool01Ol0003o^[ZjoooooonHV9So
410@05Wooooo000Sooooo`;o00002?ooool00ol0003oooooooooo`2Looooo`03o`000?oooooooooo
03?ooooo0_l000000ooooooo0000ooooo`03ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0FOooool0
02?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2Kooooo`03o`000?oooooooooo
03Oooooo00?o0000ooooooooool0Goooool002?ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`2Jooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0Goooool002?ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`2Hooooo`;o0000>_ooool00ol0003ooooo
ooooo`1Nooooo`008_ooool2o`0000gooooo00?o0000ooooooooool0U?ooool3o`000003ooooool0
003ooooo03[ooooo00?o0000ooooooooool0GOooool002;ooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`2@ooooo`?o00001Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooo
oooo05cooooo000Rooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0S?ooool3o`00
00Wooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1Looooo`008_ooool3o`0000oo
oooo00?o0000ooooooooool0R?ooool3o`0000gooooo00?o0000ooooooooool0>?ooool00ol0003o
ooooooooo`1Kooooo`008_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo08Gooooo
0_l0000Aooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0F_ooool002;ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`21ooooo`?o00005?ooool00ol0003ooooooooo
o`0hooooo`03o`000?oooooooooo05Wooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool0OOooool3o`0001Oooooo00?o0000ooooooooool0>?ooool00ol0003ooooo
ooooo`1Iooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1iooooo`?o0000
6oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo05Sooooo0005o`0000;ooooo00Go
410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`1eooooo`?o00007oooool00ol0003oooooooooo`0hooooo`03o`00
0?oooooooooo05Oooooo0007ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8b
ooooo`03ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0LOooool3o`0002?ooooo
00?o0000ooooooooool0=oooool2o`0005Sooooo0007ooooo`05o`000?ooooooooooooooool00000
3?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`1^ooooo`;o00009oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo05Go
oooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`;o
00006Oooool00ol0003oooooooooo`1Zooooo`?o0000:_ooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo05Gooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0I_ooool3o`0002go
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1Dooooo`001oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool0H_ooool3o`00037ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1Cooooo`00
8Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo05kooooo0ol0000eooooo`03o`00
0?oooooooooo03Sooooo00?o0000ooooooooool0D_ooool0023ooooo0ol0000Mooooo`03o`000?oo
oooooooo05_ooooo0_l0000iooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0D_oo
ool0027ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1Gooooo`?o0000??ooool0
0ol0003oooooooooo`0gooooo`03o`000?oooooooooo057ooooo000Pooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool0Doooool3o`00043ooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`1@ooooo`008?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo04oo
oooo0ol00013ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0Coooool0023ooooo
0_l0000Rooooo`03o`000?oooooooooo04_ooooo0ol00017ooooo`03o`000?oooooooooo03Oooooo
00?o0000ooooooooool0Coooool0023ooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`18ooooo`;o0000Boooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo04kooooo000P
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0A?ooool3o`0004kooooo00?o0000
ooooooooool0=oooool00ol0003oooooooooo`1=ooooo`008?ooool3o`0002Cooooo00?o0000oooo
ooooool0@?ooool3o`0005;ooooo00?o0000ooooooooool0=_ooool2o`0004kooooo000Pooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0??ooool3o`0005Kooooo00?o0000oooooooo
ool0=_ooool00ol0003oooooooooo`1<ooooo`005?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oo
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0hooooo`?o0000FOooool00ol0003o
ooooooooo`0gooooo`03o`000?oooooooooo04_ooooo000Dooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo03Gooooo0_l0001Mooooo`03
o`000?oooooooooo03Oooooo00?o0000ooooooooool0B_ooool001Cooooo00Go410@oooooooooooo
oooooa0@4006ooooo`;o0000:_ooool00ol0003oooooooooo`0aooooo`?o0000H?ooool00ol0003o
ooooooooo`0gooooo`03o`000?oooooooooo04Wooooo000Dooooo`05o`000?ooooooooooooooool0
00001_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo02gooooo0ol0001Tooooo`03
o`000?oooooooooo03Kooooo00?o0000ooooooooool0BOooool001Cooooo00Go0000oooooooooooo
ooooo`000006ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0:Oooool3o`0006So
oooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`18ooooo`005?ooool01Ol@413ooooo
oooooooooooo410@00Kooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Uooooo`?o
0000K?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo04Oooooo000Dooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool2o`0002kooooo00?o0000ooooooooool08Oooool3o`0006oo
oooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`16ooooo`005?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Nooooo`;o
0000Loooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo04Gooooo000Oooooo`03o`00
0?oooooooooo02oooooo00?o0000ooooooooool06_ooool3o`0007Kooooo00?o0000ooooooooool0
=_ooool00ol0003oooooooooo`15ooooo`007_ooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo01Kooooo0ol0001jooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0A?oo
ool001kooooo0_l0000cooooo`03o`000?oooooooooo01;ooooo0ol0001nooooo`03o`000?oooooo
oooo03Kooooo0_l00014ooooo`007_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo
00kooooo0ol00022ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooool00000A?ooool001ko
oooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0;ooooo`;o0000QOooool00ol0003o
ooooooooo`0fooooo`03o`000?oooooooooo04;ooooo000Nooooo`03o`000?oooooooooo03Gooooo
00?o0000ooooooooool01oooool3o`0008Sooooo00?o0000ooooooooool0=_ooool00ol0003ooooo
ooooo`11ooooo`007_ooool2o`0003Oooooo00?o0000ooooooooool00oooool3o`0008cooooo00?o
0000ooooooooool0=_ooool00ol0003oooooooooo`10ooooo`007_ooool00ol0003oooooooooo`0g
ooooo`03o`000?oooooo000000;o0000T?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooo
oooo03oooooo000Nooooo`03o`000?oooooooooo03Kooooo0ol0002Dooooo`03o`000?oooooooooo
03Gooooo00?o0000ooooooooool0?oooool001kooooo0_l0000eooooo`;o00000oooool00ol0003o
ooooooooo`2Booooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool02Oooool2o`000003
oa0@4?oooooooooo033ooooo000Mooooo`03o`000?oooooooooo03;ooooo0ol00006ooooo`03o`00
0?oooooooooo097ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo037ooooo0002ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo
00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo02oooooo0ol0000:ooooo`03
o`000?oooooooooo097ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`05ooooo`Go
0000<_ooool000;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo
<S8booooo`04ooooo`03o`000?oooooooooo02cooooo0ol0000>ooooo`03o`000?oooooooooo097o
oooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`05ooooo`04odA4A?oMgMgoooooo`00
03?ooooo0002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03oooo
o`;o0000:_ooool3o`0001;ooooo00?o0000ooooooooool0TOooool00ol0003oooooooooo`0eoooo
o`03o`000?oooooooooo00Cooooo00CogMgMoeEEEOoooooo0000<oooool000;ooooo00Go0000oooo
ooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool09oooool2
o`0001Kooooo00?o0000ooooooooool0TOooool00ol0003oooooooooo`0eooooo`03o`000?oooooo
oooo00Cooooo00?oMgMgolc<c?l00000<oooool000;ooooo00Go0000ooooooooooooooooo`00000<
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Tooooo`?o00006Ooo
ool00ol0003oooooooooo`2Aooooo`03o`000?oooooooooo03Cooooo0_l00005ooooo`03onk^k_m4
A4Co000003?ooooo0002ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo027ooooo0ol0000Mooooo`03o`000?oooooooooo093ooooo00?o
0000ooooooooool0<oooool01?l0003oooooooooool00005ooooo`03ogMgMol0003ooooo03;ooooo
0002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`;o0000
7oooool3o`00027ooooo00?o0000ooooooooool0T?ooool00ol0003oooooooooo`0eooooo`03o`00
0?oooooooooo03Sooooo0002ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo
00?o0000ooooooooool07?ooool3o`0002Gooooo00?o0000ooooooooool0T?ooool00ol0003ooooo
ooooo`0eooooo`03o`000?oooooooooo03Oooooo000Looooo`03o`000?oooooooooo01Wooooo0ol0
000Yooooo`03o`000?oooooooooo093ooooo00?o0000ooooooooool0=Oooool00ol0003ooooooooo
o`0fooooo`007?ooool00ol0003oooooooooo`0Gooooo`;o0000;Oooool00ol0003oooooooooo`2@
ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0=Oooool001cooooo0_l0000Eoooo
o`?o0000<?ooool00ol0003oooooooooo`2@ooooo`03o`000?oooooooooo03Cooooo00?o0000oooo
ooooool0=Oooool001cooooo00?o0000ooooooooool04Oooool3o`0003Cooooo00?o0000oooooooo
ool0Joooool00oooV@3oooooooooo`0Qooooo`03o`000?oooooooooo03Gooooo00?o0000oooooooo
ool0=?ooool001cooooo00?o0000ooooooooool03_ooool3o`0003Sooooo00?o0000ooooooooool0
J_ooool00oooV@3oooooooooo`0Rooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0
<oooool001cooooo00?o0000ooooooooool02oooool3o`0003cooooo00?o0000ooooooooool0Iooo
ool3oonI02Gooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0booooo`007?ooool2
o`0000[ooooo0_l00010ooooo`03o`000?oooooooooo06Cooooo0_ooV@000ooooooooiT0ooooo`0V
ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0<_ooool001_ooooo0_l00008oooo
o`?o0000@oooool00ol0003oooooooooo`1Qooooo`;ooiT00_ooool00oooV@3oooooooooo`0Woooo
o`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0<Oooool001_ooooo00?o0000oooooooo
ool01?ooool3o`0004Oooooo00?o0000ooooooooool0G_ooool2oonI00Cooooo00?ooiT0oooooooo
ool0:?ooool00ol0003oooooooooo`0cooooo`;o0000<_ooool001_ooooo00Co0000oooooooooooo
oooo0ol0001;ooooo`03o`000?oooooooooo05?ooooo2_ooV@05ooooo`03oonI0?oooooooooo02Wo
oooo00?o0000ooooooooool00_ooool6oonI02gooooo00?o0000ooooooooool0;oooool001_ooooo
1?l0001?ooooo`03o`000?oooooooooo05Kooooo1OooV@06ooooo`03oonI0?oooooooooo02Cooooo
1_ooV@001?l0003ooiT0oonI0?ooV@0cooooo`03o`000?oooooooooo02oooooo000Kooooo`;o0000
D_ooool00ol0003oooooooooo`1Jooooo`_ooiT04_ooool@oonI00Oooooo00?o0000ooooooooool0
=?ooool00ol0003oooooooooo`0^ooooo`004Oooool4o`000003oa0@4?oooooooooo00Gooooo00?o
0000ooooooooool0D?ooool00ol0003oooooooooo`1Mooooo`03oonI0?oooooooooo00Cooooo1ooo
V@000oo<o`3ooiT0oonI0008oonI01Sooooo00?o0000ooooooooool0=?ooool00ol0003ooooooooo
o`0]ooooo`004oooool00ol0003oooooooooo`08ooooo`03o`000?oooooooooo053ooooo00?o0000
ooooooooool0G?ooool00oooV@3oooooooooo`0;ooooo`03olco0?oooooooooo027ooooo00?o0000
ooooooooool0=?ooool00ol0003oooooooooo`0/ooooo`004oooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo053ooooo00?o0000ooooooooool0F_ooool00oooV@3oooooooooo`0;oooo
o`03olco0?oooooooooo02?ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0/oooo
o`004oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo053ooooo00?o0000oooooooo
ool0F?ooool00oooV@3oooooooooo`0;ooooo`;oc?l09Oooool00ol0003oooooooooo`0dooooo`03
o`000?oooooooooo02_ooooo000Cooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0
D?ooool00ol0003oooooooooo`1Fooooo`03oonI0?oooooooooo00[ooooo0oo<o`0Wooooo`03o`00
0?oooooooooo03Cooooo00?o0000ooooooooool0:_ooool001?ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo05Gooooo00?ooiT0ooooooooool02?oo
ool2olco00;ooooo00?oc?l0ooooooooool09_ooool00ol0003oooooooooo`0dooooo`03o`000?oo
oooooooo02Wooooo000Cooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0D?ooool0
0ol0003oooooooooo`1Cooooo`03oonI0?oooooooooo00Oooooo0_o<o`03ooooo`03olco0?oooooo
oooo02Sooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Xooooo`004Oooool00omE
EEGoIVIVo`00000@ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0D?ooool2oonI
00Sooooo0_o<o`05ooooo`03olco0?oooooooooo02Wooooo00?o0000ooooooooool0<oooool00ol0
003oooooooooo`0Xooooo`009Oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo04ko
oooo00?ooiT0ooooooooool01Oooool3olco00Kooooo00?oc?l0ooooooooool0:oooool00ol0003o
ooooooooo`0booooo`;o0000:Oooool002Kooooo0_l0001Aooooo`03o`000?oooooooooo04cooooo
00?ooiT0ooooooooool01_o<o`08ooooo`03olco0?oooooooooo00[ooooo00?o<ol0ooooooooool0
7_ooool01?o<o`3o0000olco0?o<o`0dooooo`03o`000?oooooooooo02Kooooo000Xooooo`03o`00
0?oooooooooo04kooooo00?o0000ooooooooool0A_ooool9olco00gooooo00?oc?l0ooooooooool0
2oooool00olco`3oooooooooo`0Gooooo`Ooc?l00_ooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo02Gooooo000Yooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0B?oo
ool00oooV@3oooooooooo`09olco00Kooooo00?oc?l0ooooooooool02oooool00olco`3ooooooooo
o`0Aooooo`Ooc?l02_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02Gooooo000Z
ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0A_ooool00oooV@3oooooooooo`0:
ooooo`Woc?l02_ooool2oc?o00Cooooo3oo<o`0Booooo`03o`000?oooooooooo03?ooooo00?o0000
ooooooooool09?ooool002_ooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`14oooo
o`03oonI0?oooooooooo00oooooo00?oc?l0ooooooooool00_ooool9olco00;o<ol01Oo<o`0Roooo
o`03o`000?oooooooooo03?ooooo00?o0000ooooooooool08oooool002cooooo00?o0000oooooooo
ool0C_ooool00ol0003oooooooooo`11ooooo`;ooiT04Oooool00oo<o`3oooooooooo`0:ooooo`;o
<ol000?ooooooc?o0?ooool09oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02;o
oooo000]ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0?oooool00oooV@3ooooo
ooooo`0@ooooo`03olco0?oooooooooo00Wooooo0_lco`02ooooo`03oc?o0?oooooooooo02Oooooo
00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Rooooo`00;_ooool00ol0003ooooooooo
o`1>ooooo`03o`000?oooooooooo03gooooo00?ooiT0ooooooooool03oooool2olco00_ooooo00?o
<ol0ooooooooool00_ooool00olco`3oooooooooo`0Xooooo`03o`000?oooooooooo03?ooooo00?o
0000ooooooooool08Oooool002oooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`0j
ooooo`;ooiT04Oooool00oo<o`3oooooooooo`09ooooo`;o<ol01?ooool00olco`3oooooooooo`0Z
ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool08?ooool0033ooooo00?o0000oooo
ooooool0C_ooool00ol0003oooooooooo`0gooooo`;ooiT04_ooool00oo<o`3oooooooooo`08oooo
o`;o<ol01Oooool00olco`3oooooooooo`0;ooooo`03o`3oI_oooooooooo01kooooo00?o0000oooo
ooooool0<oooool00ol0003oooooooooo`0Oooooo`00<Oooool2o`0004oooooo00?o0000oooooooo
ool0=Oooool00oooV@3oooooooooo`0Aooooo`03olco0?oooooooooo00Kooooo0olco`06ooooo`03
oc?o0?oooooooooo00_ooooo0_l0ofHQooooo`03o`000?oooooooooo03;ooooo0_l0000Pooooo`00
<oooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo03;ooooo0_ooV@0Cooooo`03olco
0?oooooooooo00Cooooo0olco`08ooooo`03oc?o0?oooooooooo00_ooooo0_l0ofHSooooo`03o`00
0?oooooooooo037ooooo0_l0000Pooooo`00=?ooool00ol0003oooooooooo`1=ooooo`03o`000?oo
oooooooo02oooooo0_ooV@0Cooooo`;oc?l01olco`0:ooooo`03oc?o0?oooooooooo00_ooooo00?o
0?mVooooool0ofH06_ooool5oc?o00Cooooo00?o0000ooooooooool0<oooool00ol0003ooooooooo
o`0Mooooo`00=Oooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo02cooooo0_ooV@09
ooooo`ko<ol04Oooool00olco`3oooooooooo`0:ooooo`03o`3oI_oooooo0?mV01Cooooo1olco`0:
ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool07?ooool003Kooooo00?o0000oooo
ooooool0COooool00ol0003oooooooooo`0Zooooo`03oonI0?oooooooooo00oooooo2_lco`0>oooo
o`03oc?o0?oooooooooo00[ooooo00Co0?mVoooooooooooo0?mV3Oooool7oc?o01;ooooo00?o0000
ooooooooool0<_ooool00ol0003oooooooooo`0Looooo`00=oooool00ol0003oooooooooo`1=oooo
o`03o`000?oooooooooo02Oooooo0_ooV@0Eooooo`03olco0?oooooooooo00Cooooo2_lco`03oooo
o`03oc?o0?oooooooooo00Wooooo0_l0ofH2oc?o0003o`3oI_lco`3o<ol000co<ol06_ooool00ol0
003oooooooooo`0booooo`03o`000?oooooooooo01_ooooo000hooooo`03o`000?oooooooooo04go
oooo00?o0000ooooooooool09Oooool00oooV@3oooooooooo`0Dooooo`03olco0?oooooooooo00oo
oooo3Olco`02o`3oIP;o<ol00_ooool00ol0ofKoooooooooo`0Wooooo`03o`000?oooooooooo03;o
oooo00?o0000ooooooooool01oooool01Oo^k^ko<S8bo`000?l@413oc<c<00kooooo000iooooo`03
o`000?oooooooooo04gooooo00?o0000ooooooooool0>_ooool00oo<o`3oooooooooo`0@ooooo`;o
<ol02Oooool2o`3oIPGooooo00?o0?mVooooooooool0:Oooool00ol0003oooooooooo`0booooo`03
o`000?oooooooooo00Kooooo00GoEEEEogMgMoooooooV9RHob4Q8@0>ooooo`00>_ooool00ol0003o
ooooooooo`1=ooooo`03o`000?oooooooooo03Oooooo0_o<o`0Booooo`03oc?o0?oooooooooo00So
oooo00?o0?mVooooooooool01?ooool00ol0ofKoooooooooo`0;ooooo`03o`3ooooooooooooo01co
oooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`05ooooo`05o`000?oooooooooooooo
ool000003_ooool003_ooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0dooooo`;o
c?l04oooool00olco`3oooooooooo`07ooooo`;o0?mV1_ooool00ol0ofKoooooooooo`0;ooooo`;o
0?oo7oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00Gooooo00Go0000oiRHV?oo
ooooV9RHob4Q8@0>ooooo`00??ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo03;o
oooo00?oc?l0ooooooooool04_ooool00olco`3oooooooooo`06ooooo`;o0?mV1oooool00ol0ofKo
ooooooooo`0;ooooo`;o0?oo8Oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00Co
oooo00Go0000oeEEEOl0003o410@olc<c00>ooooo`00?Oooool2o`0004kooooo00?o0000oooooooo
ool0;oooool2olco01?ooooo0_lco`06ooooo`?o0?mV2?ooool00ol0ofKoooooooooo`0;ooooo`;o
0?oo8oooool00ol0003oooooooooo`0booooo`;o00001?ooool00omEEEGoQhN7ooooo`0@ooooo`00
?oooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo02cooooo0_o<o`0Dooooo`03oc?o
0?oooooooooo00?ooooo0ol0ofH:ooooo`03o`3oI_oooooooooo00_ooooo00?o0?ooooooool0ool0
9?ooool00ol0003oooooooooo`0_ooooo`;o000000?oooooo`000?ooool00oooool00ooMgMgo410@
oiRHV00@ooooo`00@?ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo02Wooooo0_o<
o`0Eooooo`04oc?o0?ooooooooooooooo`?o0?mV3?ooool00ol0ofKoooooooooo`0;ooooo`03o`3o
oooooooo0?oo02Kooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`03ooooo`04olc<
c?m4A4Co0000oa0@40kooooo0011ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0
9_ooool2olco01Kooooo00?o<ol0o`3oI_l0ofH00_l0ofH>ooooo`03o`3oI_oooooooooo00_ooooo
00?o0?ooooooool0ool05oooool5o`3oIP_ooooo00?o0000ooooooooool0<_ooool00ol0003ooooo
ooooo`0Dooooo`00@_ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo02Cooooo00?o
c?l0ooooooooool00_ooool8o`3oIPOooooo1_l0ofHAooooo`03o`3oI_oooooooooo00_ooooo00Co
0?oooooooooooooo0?oo3oooool8o`3oIQ7ooooo00?o0000ooooooooool0<_ooool00ol0003ooooo
ooooo`0Cooooo`00@oooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo027ooooo0_o<
o`09ooooo`_o0?mV0_ooool00olco`3oooooooooo`0Aooooo`03o`3oI_oooooooooo00[ooooo0_l0
ool2ooooo`03o`3ooooooooooooo00Kooooo2?l0ofHJooooo`03o`000?oooooooooo03;ooooo00?o
0000ooooooooool04_ooool004Cooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0O
ooooo`03olco0?oooooooooo00kooooo3Ol0ofH=ooooo`;o0?mV2Oooool2o`3oIP;o0?oo0ol0ofH0
0ol0oooo0?mVo`3oIP07o`3oIPGooooo00?o06Koooooooooool06oooool00ol0003oooooooooo`0a
ooooo`03o`000?oooooooooo01;ooooo0015ooooo`03o`000?oooooooooo04cooooo00?o0000oooo
ooooool0=Oooool00olco`3oooooooooo`04oooooaSo0?mV0_l0ool4ooooo`03o`3ooooooooooooo
00cooooo0_l0I_lNooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool04Oooool004Ko
oooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0booooo`;o<ol04_ooool00ol0ofKo
ooooooooo`09ooooo`03o`3ooooooooooooo00?ooooo00?o0?ooooooooooool02oooool3o`1Vob3o
oooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0@ooooo`00Aoooool00ol0003ooooo
ooooo`1<ooooo`03o`000?oooooooooo02oooooo0_lco`0Cooooo`03o`3oI_oooooooooo00Sooooo
0_l0ool5ooooo`03o`3ooooooooooooo00_ooooo00?o06Koooooool0I_l08Oooool00ol0003ooooo
ooooo`0booooo`03o`000?oooooooooo00oooooo0018ooooo`;o0000COooool00ol0003ooooooooo
o`0]ooooo`03oc?o0?oooooooooo017ooooo0_l0ofH9ooooo`;o0?oo1_ooool00ol0oooooooooooo
o`0;ooooo`04o`1Vooooooooooooo`1Vob;ooooo00?o0000ooooooooool0<Oooool00ol0003ooooo
ooooo`0?ooooo`00B_ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo02[ooooo0_lc
o`0Cooooo`03o`3oI_oooooooooo00Kooooo0ol0ool8ooooo`03o`3ooooooooooooo00[ooooo00Co
06Kooooooooooooo06Ko9?ooool00ol0003oooooooooo`0aooooo`;o00003oooool004_ooooo00?o
0000ooooooooool0Boooool00ol0003oooooooooo`0Wooooo`;o<ol05?ooool00ol0ofKooooooooo
o`04ooooo`?o0?oo2_ooool00ol0ooooooooooooo`0:ooooo`04o`1Vooooooooooooo`1VobKooooo
00?o0000ooooooooool0<?ooool2o`0000oooooo001<ooooo`03o`000?oooooooooo04_ooooo00?o
0000ooooooooool09?ooool2oc?o01Gooooo00?o0?mVooooooooool00_ooool3o`3oo`cooooo00?o
0?ooooooooooool02_ooool01Ol0I_oooooooooooooooooo06Ko02Oooooo00?o0000ooooooooool0
<Oooool00ol0003oooooooooo`0<ooooo`00COooool00ol0003oooooooooo`1;ooooo`03o`000?oo
oooooooo027ooooo0_lco`0Eooooo`;o0?mV0_ooool3o`3oo`kooooo00?o0?ooooooooooool02_oo
ool01Ol0I_oooooooooooooooooo06Ko02Wooooo00?o0000ooooooooool0<Oooool00ol0003ooooo
ooooo`0;ooooo`00C_ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo01oooooo00?o
<ol0ooooooooool04oooool6o`3ooa3ooooo00?o0?ooooooooooool02Oooool2o`1Vo`?ooooo00?o
06Koooooooooool02oooool00olc0?ooooooooooo`03ooooo`Co0?oo4oooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo00_ooooo001?ooooo`03o`000?oooooooooo04_ooooo00?o0000
ooooooooool06oooool4o`3oo`kooooo1ol0ool00ol0ofKoooooooooo`0Aooooo`;o0?oo2_ooool2
o`1Vo`Cooooo00?o06Koooooooooool03?ooool00olc0?oo0?ooo`3oo`03o`3ooaSooooo00?o0000
ooooooooool0<Oooool00ol0003oooooooooo`0:ooooo`00D?ooool00ol0003oooooooooo`1;oooo
o`03o`000?oooooooooo01[ooooo00?o<ol0ooooooooool03ol0ool6ooooo`03o`3oI_oooooooooo
017ooooo00?o0?ooooooooooool02Oooool00ol0I_ooooooooooo`03ooooo`03o`1Voooooooooooo
00Kooooo1_l0ool00olc0?ooooooooooo`0Mooooo`03o`000?oooooooooo037ooooo00?o0000oooo
ooooool02Oooool0057ooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0Rooooo`So
0?oo1Oooool2o`3oIQ?ooooo00?o0?ooooooooooool02?ooool2o`1Vo`Gooooo00Co06Kooooooooo
oooooooo1_l0ool4ooooo`;o<`3o8Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo
00Sooooo001Booooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0:Oooool<o`3oo`co
oooo0_l0ool5ooooo`Co0?oo0_l0I_l6o`3oo`03o`1Vool0oooo0?oo00;o0?oo2Oooool00olc0?oo
oooooc<0o`0Rooooo`03o`000?oooooooooo033ooooo00?o0000ooooooooool02?ooool005?ooooo
0_l0001<ooooo`03o`000?oooooooooo02Wooooo0_l0ofH9oooooa?o0?oo0oooool00ol0I_oooooo
ooooo`06ooooo`03o`1Voooooooooooo00[ooooo00?o<`3ooooooolc0?l09?ooool00ol0003ooooo
ooooo`0`ooooo`03o`000?oooooooooo00Oooooo001Eooooo`03o`000?oooooooooo04[ooooo00?o
0000ooooooooool09oooool00ol0ofKoooooooooo`0Cooooo`03o`3ooooooooooooo00Oooooo0_l0
I_l8ooooo`03o`1Voooooooooooo00[ooooo00?o<`3ooooooolc0?l09Oooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo00Kooooo001Fooooo`03o`000?oooooooooo04[ooooo00?o0000
ooooooooool09?ooool2o`3oIQCooooo0_l0ool7ooooo`?o06Ko2Oooool00ol0I_ooooooooooo`0:
ooooo`04oc<0oooooooooooooc<0obKooooo00?o0000ooooooooool0;oooool3o`0000Oooooo001G
ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool08Oooool2o`3oIQGooooo00?o0?oo
ooooooooool01?ooool3o`1Vo`_ooooo00?o06Koooooooooool02_ooool01?lc0?oooooooooooolc
0?lXooooo`03o`000?oooooooooo02_ooooo0ol00002ooooo`03o`000?oooooooooo00Gooooo001H
ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool07_ooool2o`3oIQKooooo00?o0?oo
ooooooooool00_ooool3o`1Vo`gooooo00?o06Koooooooooool02_ooool01?lc0?oooooooooooolc
0?l>ooooo`03ol`0oooooooooooo01Wooooo00?o0000ooooooooool09oooool3o`0000Gooooo00?o
0000ooooooooool01Oooool005Wooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0K
ooooo`;o0?mV5oooool00ol0ooooooooooooo`03o`1Vo`oooooo00?o06Koooooooooool02_ooool0
1?lc0?oooooooooooolc0?l>ooooo`;oc03o7?ooool00ol0003oooooooooo`0Rooooo`Co00002?oo
ool00ol0003oooooooooo`05ooooo`00F_ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooo
oooo01Wooooo00?o0?mVooooooooool05Oooool2o`3oo`?o06Ko4?ooool2o`1Vo`_ooooo0_lc0?l2
ooooo`03oc<0oooooooooooo00cooooo0_o<0?lNooooo`03o`000?oooooooooo01kooooo0ol0000<
ooooo`03o`000?oooooooooo00Gooooo001Kooooo`03o`000?oooooooooo04[ooooo00?o0000oooo
ooooool05_ooool2o`3oIQCooooo1_l0I_lBooooo`03o`1Voooooooooooo00Wooooo0_lc0?l3oooo
o`03oc<0oooooooooooo00cooooo0_o<0?l00ooooooo06Koo`1Vo`02o`1Voa[ooooo00?o0000oooo
ooooool06_ooool4o`0000oooooo00?o0000ooooooooool01Oooool005cooooo00?o0000oooooooo
ool0B_ooool00ol0003oooooooooo`0<ooooo`Co06Ko1?ooool00ol0ofKoooooooooo`0;ooooo`Wo
06Ko0_ooool00ol0ooooooooooooo`0Aooooo`;o06Ko2_ooool2oc<0o`Cooooo00?o<`3ooooooooo
ool02Oooool3o`1Vo`04ol`0ool0I_ooc03oo`1Voaoooooo00?o0000ooooooooool05_ooool3o`00
01Cooooo00?o0000ooooooooool01?ooool005gooooo00?o0000ooooooooool0B_ooool00ol0003o
ooooooooo`0?oooooa;o06Ko2Oooool2o`3ooa?ooooo00?o06Koooooooooool02?ooool2oc<0o`Go
oooo00?o<`3oooooooooool00oooool7o`1Vo`;ooooo00?oc03oooooooo<0?l08_ooool00ol0003o
ooooooooo`0Booooo`?o00005oooool00ol0003oooooooooo`04ooooo`00G_ooool2o`0004_ooooo
00?o0000ooooooooool04oooool9o`1Vo`_ooooo0_l0oolCooooo`;o06Ko2Oooool2oc<0o`Kooooo
00?o<`3oo`1Vool0I_l01?l0I_l8ooooo`03ol`0ooooooooc03o02Cooooo00?o0000ooooooooool0
3Oooool4o`0001[ooooo00?o0000ooooooooool01?ooool0063ooooo00?o0000ooooooooool0BOoo
ool00ol0003oooooooooo`0Kooooo`go06Ko4_ooool00ol0I_ooooooo`1Vo`07o`1Vo`;o<`3o1ol0
I_l00olc0?ooooooooooo`0<ooooo`04ol`0oooooooooooool`0obGooooo00?o0000ooooooooool0
2Oooool3o`0001kooooo00?o0000ooooooooool01?ooool0067ooooo00?o0000ooooooooool0BOoo
ool00ol0003oooooooooo`0Rooooo`03o`3ooooooooooooo00;ooooo5?l0I_l6ooooo`;o<`3o2?oo
ool00olc0?ooooooooooo`0<ooooo`04ol`0oooooooooooool`0obOooooo00?o0000ooooooooool0
1?ooool4o`00027ooooo00?o0000ooooooooool01?ooool006;ooooo00?o0000ooooooooool0BOoo
ool00ol0003oooooooooo`0Oooooo`;o0?oo5?ooool00ol0I_ooooooooooo`06ooooo`;o<`3o2Ooo
ool00olc0?ooooooooooo`0<ooooo`04ol`0oooooooooooool`0o`kooooo00?oo`2Iooooooooool0
5oooool01?l0003oooooooooooooool3o`0002Gooooo00?o0000ooooooooool01?ooool006?ooooo
00?o0000ooooooooool0BOooool00ol0003oooooooooo`0Looooo`;o0?oo5Oooool00ol0I_oooooo
ooooo`04ooooo`?o<`3o2_ooool00olc0?ooooooooooo`0<ooooo`04ol`0oooooooooooool`0o`oo
oooo00?oo`2Iooooooooool06?ooool3o`0002Sooooo00?o0000ooooooooool01?ooool006Cooooo
00?o0000ooooooooool0BOooool00ol0003oooooooooo`0Iooooo`;o0?oo5Oooool2o`1Vo`Cooooo
0olc0?l;ooooo`;o<`3o3_ooool01?o<0?ooooooooooooo<0?l?ooooo`03ool0VOoooooooooo01Go
oooo1?l000000ooooooo0000ooooo`0Xooooo`03o`000?oooooooooo00Cooooo001Uooooo`03o`00
0?oooooooooo04Wooooo00?o0000ooooooooool05_ooool2o`3ooaKooooo00Co06Kooooooooooooo
oooo0olc0?l=ooooo`03oc<0oooooooooooo00cooooo0_o<0?l2ooooo`03ol`0oooooooooooo00go
oooo00?oo`2Iooooooooool04oooool3o`0000Kooooo00?o0000ooooooooool09_ooool00ol0003o
ooooooooo`04ooooo`00I_ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo01Cooooo
00?o0?ooooooooooool05?ooool2o`1Vo`04oooooolc0?oo<`3ooc<0o`oooooo00?o<`3ooooooooo
ool02oooool2ol`0o`?ooooo00?oc03oooooooooool03?ooool2ool0VA;ooooo1?l0000:ooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool01?ooool006Oooooo00?o0000ooooooooool0
BOooool00ol0003oooooooooo`0Aooooo`;o0?oo5_ooool01?l0I_oo<`3ooc<0oolc0?lAooooo`03
oc<0oooooooooooo00[ooooo0_o<0?l4ooooo`03ol`0oooooooooooo00cooooo00?oo`2Ioooooooo
09T03oooool3o`0000oooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`03ooooo`00
J?ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo00oooooo00?o0?ooooooooooool0
4?ooool7oc<0oa;ooooo0_lc0?l;ooooo`;oc03o1Oooool00oo<0?ooooooooooo`0;ooooo`04oc<0
oooo09Wo<`3oool0V@gooooo0ol0000Booooo`03o`000?oooooooooo02Gooooo00?o0000oooooooo
ool00oooool006Wooooo00?o0000ooooooooool0BOooool00ol0003o<`3ooc<0o`02oc<0oaKooooo
2Olc0?l2ooooo`;o06Ko5?ooool00olc0?ooooooooooo`09ooooo`;oc03o1_ooool00oo<0?oooooo
ooooo`05ooooo`Oo<`3o00?oo`2Ioooooooo09T02_ooool4o`0001Kooooo00?o0000ooooooooool0
9?ooool00ol0003oooooooooo`03ooooo`00J_ooool2o`0004[ooooo00Co0000oooooooooooooooo
5_lc0?l9ooooo`;o06Ko5Oooool00olc0?ooooooooooo`09ooooo`03ol`0oooooooooooo00Gooooo
00?oc03ooooooolc0?l01_lc0?l6ooooo`04ool0VOooooooooooool0V@Oooooo0ol0000Kooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool00oooool006cooooo00?o0000ooooooooool0
B?ooool00ol0003oooooooooo`05ooooo`[o<`3o3_ooool2o`1VoaGooooo0_lc0?l:ooooo`;oc03o
0oooool4oc<0o`03ol`0oolc0?oo<`3o00cooooo00Coo`2Iooooooooooooo`2I1?ooool4o`0000Ko
oooo00?oo`00ooooooooool05_ooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00?o
oooo001]ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool03_ooool=oc<0o`03o`1V
oooooooooooo01?ooooo3?lc0?l2ol`0o`Go<`3o0oooool00oo<0?ooooooooooo`0<ooooo`04ool0
VOooooooooooool0V@;ooooo0ol0000:ooooo`03ool00?oooooooooo01Oooooo00?o0000oooooooo
ool08Oooool00ol0003oooooooooo`03ooooo`00K_ooool00ol0003oooooooooo`18ooooo`03o`00
0?oooooooooo01Sooooo00?o06Kooooooolc0?l05_lc0?l9ooooo`;oc03o2Oooool00oo<0?oooooo
ooooo`0<ooooo`04ool0VOooooooooooool0V@?o00003?ooool00ooo003oooooooooo`0Iooooo`03
o`000?oooooooooo023ooooo00?o0000ooooooooool00oooool006oooooo00?o0000ooooooooool0
B?ooool00ol0003oooooooooo`0Eooooo`;o06Ko5oooool00olc0?ooooooooooo`05ooooo`?oc03o
2Oooool2ol`0o`kooooo00Goo`2Io`000?l0003oo`2Io`00000>ooooo`03ool00?oooooooooo01[o
oooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`03ooooo`00L?ooool00ol0003ooooo
ooooo`18ooooo`03o`000?oooooooooo01;ooooo0_l0I_lGooooo`;o<`3o1Oooool3ol`0o`_ooooo
00?oc03oooooooooool03?ooool01Ol0003oo`2Io`000?ooooooo`2I00oooooo00?oo`00oooooooo
ool07?ooool00ol0003oooooooooo`0Oooooo`03o`000?oooooooooo00?ooooo001aooooo`03o`00
0?oooooooooo04Sooooo00?o0000ooooooooool03oooool2o`1VoaSooooo00?o<`3oooooooooool0
0_ooool3ol`0o`cooooo0_o<0?l;ooooo`?o00000_oo09T2ooooo`03ool0VOoooooooooo00cooooo
0ooo000Oooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool00oooool007;ooooo00?o
0000ooooooooool0B?ooool00ol0003oooooooooo`0<ooooo`;o06Ko6Oooool00olc0?oooooool`0
o`03ol`0o`kooooo00?oc03oooooooooool02?ooool3o`000003oooooooo09Woo`2I00?ooooo00?o
o`2Iooooooooool03?ooool00ooo003oooooool0000Qooooo`03o`000?oooooooooo01kooooo00?o
0000ooooooooool00_ooool007?ooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0:
ooooo`03o`1Voooooooooooo01Sooooo0oo<0?lAooooo`03ol`0oooooooooooo00Kooooo0ol00002
ooooo`;oo`2I1?ooool00ooo09Woooooooooo`0<ooooo`03ool00?ooooooo`0002?ooooo00?o0000
ooooooooool07Oooool00ol0003oooooooooo`02ooooo`00M?ooool00ol0003oooooooooo`18oooo
o`03o`000?oooooooooo027ooooo0oo<0?lBooooo`;oc03o1Oooool4o`0000?ooooo0_oo09T5oooo
o`03ool0VOoooooooooo00cooooo00?oo`00oooooooo00009Oooool00ol0003oooooooooo`0Loooo
o`03o`000?oooooooooo00;ooooo001eooooo`;o0000BOooool00ol0003oooooooooo`0Iooooo`Oo
c03o00?o<`3oooooooooool04Oooool00oo<0?ooooooooooo`02ooooo`?o00001Oooool2ool0V@Ko
oooo00?oo`2Iooooooooool01oooool5ol`0o`03ool00?ooooooo`0002Kooooo00?o0000oooooooo
ool07?ooool00ol0003oooooooooo`02ooooo`00Moooool00ol0003oooooooooo`0jooooo`Coc03o
2Oooool00ol0003oooooooooo`0=ooooo`_oc03o1?ooool2oc<0oa?ooooo0_o<0?l00ooooooo0000
o`000002o`0000Kooooo0_oo09T7ooooo`04ool0VOooooooooooooooo`Ooc03o0oooool2ool00003
oooooooo003ooooo02Oooooo00?o0000ooooooooool06oooool00ol0003oooooooooo`02ooooo`00
N?ooool00ol0003oooooooooo`0moooooaWoc03o3Oooool2oc<0oaCooooo00Coc03oo`000?l0003o
00002?ooool2ool0V@Kooooo0_o<0?l00ooo09Woc03ool`0o`02ol`0o`Wooooo00Coo`00oooooooo
ooooo`00:_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00;ooooo001iooooo`03
o`000?oooooooooo047ooooo2_o<0?lEooooo`;o<`3o5?ooool00ol0003oc03oo`000009ooooo`;o
o`2I00?ooooool`0ooo<0?l01Oo<0?l00oooooooo`2Iooooo`0<ooooo`04ool00?ooooooooooool0
02cooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`02ooooo`00N_ooool00ol0003o
ooooooooo`17ooooo`03o`000?oooooooooo00ooc03o1?ooool2oc<0oa7ooooo3oo<0?l2ool0V@?o
c03o1_ooool2ool0V@gooooo00Coo`00ooooooooooooo`00;_ooool00ol0003oooooooooo`0Hoooo
o`03o`000?oooooooooo00;ooooo001kooooo`03o`000?oooooooooo04Oooooo00?o0000oooooooo
ool03_oooolGol`0o`04o`000?oooooooooool`0o`Sooooo0ooo09T:ooooo`03ool0VOoooooooooo
00cooooo00Coo`00ooooooooooooo`00<?ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooo
oooo00;ooooo001looooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool03Oooool2oc<0
o`oooooo1?l00003ooooo`;oc03o1_ooool3ool0V@cooooo00?oo`2Iooooooooool02oooool2ool0
00;ooooo00?oo`00ooooooooool0;oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo
00;ooooo001mooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool02_ooool2oc<0o`ko
oooo0ol00006ooooo`03ol`0oooooooooooo00?ooooo0ooo09T=ooooo`;oo`2I3?ooool2ool000?o
oooo00?oo`00ooooooooool0<Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo007o
oooo001nooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool01oooool2oc<0o`gooooo
0ol00008ooooo`03ol`0oooooooooooo00Coo`2I3oooool00ooo09Woooooooooo`0:ooooo`;oo`00
1?ooool00ooo003oooooooooo`0cooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0
0Oooool007oooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`05ooooo`03oc<0oooo
oooooooo00Wooooo1?l00009ooooo`;oc03o0ooo09TAooooo`;oo`2I2oooool2ool000Gooooo00?o
o`00ooooooooool0=Oooool00ol0003oooooooooo`0Eooooo`03o`000?oooooooooo007ooooo0020
ooooo`;o0000B?ooool00ol0003oooooooooo`0=ooooo`?o00002oooool01?o<0?ooo`2Iool0VOoo
09TCooooo`03ool0VOoooooooooo00Wooooo0_oo0006ooooo`03ool00?oooooooooo03Oooooo00?o
0000ooooooooool05?ooool00ol0003oooooooooo`01ooooo`00P_ooool00ol0003oooooooooo`16
ooooo`03o`000?oooooooooo00Sooooo1?l0000<ooooo`?oo`2I5Oooool00ooo09Woooooooooo`08
ooooo`;oo`001oooool00ooo003oooooooooo`0iooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool00Oooool008?ooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`04oooo
o`?o00002_ooool6ool0VAKooooo0_oo09T9ooooo`;oo`002?ooool00ooo003oooooooooo`04oooo
o`Goo`2I<Oooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo007ooooo0024ooooo`03
o`000?oooooooooo02[ooooo1Ooo09TGooooo`03o`000?oooooooooo00?o00001Oooool8ool0V@;o
oooo0_o<0?lGooooo`03ool0VOoooooooooo00Oooooo0_oo0009ooooo`03ool00?oo09Woo`2I00Go
o`2I=oooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo007ooooo0025ooooo`03o`00
0?oooooooooo02gooooo3ooo09T:ooooo`;o00002?oo09T8ooooo`;oc03o6?ooool00ooo09Wooooo
ooooo`06ooooo`;oo`001?ooool6ool0V@03ool00?oo09Wooooo03kooooo00?o0000ooooooooool0
4Oooool00ol0003oooooooooo`01ooooo`00Q_ooool00ol0003oooooooooo`0boooooaGoo`2I3ooo
ool00oo<0?ooooooooooo`0Fooooo`;oo`2I1oooool2ool000Koo`2I1?ooool00ooo003ooooooooo
o`11ooooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool00Oooool008Oooooo00?o0000
ooooooooool0??ooool?ool0V@Sooooo0_o<0?l>oooooa7oo`2I0ooo00000ooo09Woooooooooo`07
ooooo`;oo`00AOooool00ol0003oooooooooo`0?ooooo`03o`000?oooooooooo007ooooo0028oooo
o`03o`000?oooooooooo04?ooooo00?o0000ooooooooool01?oooolHool0V@Sooooo0_oo09T4oooo
o`?oo`003?ooool00ooo003oooooooooo`16ooooo`03o`000?oooooooooo00oooooo0Ol00001oooo
o`7ooooo0029ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool02?ooool2ol`0oaWo
oooo00Coo`2Ioooooooooooooooo0ooo000>ooooo`03ool00?oooooooooo04Oooooo00?o0000oooo
ooooool03oooool1o`00007ooooo0Oooool008[ooooo00?o0000ooooooooool0@Oooool00ol0003o
ooooooooo`06ooooo`;oc03o6_ooool00ooo09Woooooool00002ool000oooooo0_oo001;ooooo`03
o`000?oooooooooo00kooooo0Ol00001ooooo`7ooooo002;ooooo`;o0000@Oooool00ol0003ooooo
ooooo`05ooooo`03ol`0oooooooooooo01Sooooo00Coo`2Iool00?oo003oo`004Oooool00ooo003o
ooooooooo`1<ooooo`03o`000?oooooooooo00gooooo0Ol00001ooooo`7ooooo002=ooooo`03o`00
0?oooooooooo03kooooo00?o0000ooooooooool07_ooool3ool001;ooooo0_oo001@ooooo`03o`00
0?oooooooooo00cooooo0Ol00001ooooo`7ooooo002>ooooo`03o`000?oooooooooo03gooooo00?o
0000ooooooooool06oooool3ool001Cooooo00?oo`00ooooooooool0DOooool00ol0003ooooooooo
o`0;ooooo`7o00000Oooool1ooooo`00Soooool00ol0003oooooooooo`0looooo`03o`000?oooooo
oooo01Sooooo0ooo00000ooo09Woooooooooo`0Booooo`;oo`00EOooool00ol0003oooooooooo`0:
ooooo`7o00000Oooool1ooooo`00T?ooool00ol0003oooooooooo`0kooooo`03o`000?oooooooooo
01;ooooo1_oo0002ool0VAGooooo00?oo`00ooooooooool06?ooool5ool003Sooooo00?o0000oooo
ooooool02_ooool1o`00007ooooo0Oooool0097ooooo00?o0000ooooooooool06oooool5ool001[o
oooo00?o0000ooooooooool02Oooool9ool000Cooooo0_oo09TEooooo`;oo`004oooool8ool003ko
oooo00?o0000ooooooooool02Oooool1o`00007ooooo0Oooool009;ooooo00?o0000ooooooooool0
7_ooool@ool000_ooooo00?o0000ooooooooool02Ooo000;ooooo`;oo`2I5_ooool00ooo003ooooo
ooooo`0;ooooo`Soo`00Aoooool00ol0003oooooooooo`08ooooo`7o00000Oooool1ooooo`00Tooo
ool00ol0003oooooooooo`0SoooooaSoo`004_ooool2ool0VAOooooo00?oo`00ooooooooool01?oo
ool8ool0053ooooo00?o0000ooooooooool02?ooool1o`00007ooooo002Dooooo`03o`000?oooooo
oooo02gooooo4?oo000=ooooo`;oo`2I2_oooolFool005Wooooo00?o0000ooooooooool01oooool1
o`00007ooooo002Eooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool00ooooolIool0
00cooooo00?oo`00ooooooooool0HOooool00ol0003oooooooooo`06ooooo`7o00000Oooool009Ko
oooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0<ooooo`;oo`2I6?ooool2ool006Co
oooo00?o0000ooooooooool01_ooool1o`00007ooooo002Gooooo`;o0000=Oooool00ol0003ooooo
ooooo`0;ooooo`03ool0VOoooooooooo01Kooooo0_oo001Wooooo`03o`000?oooooooooo00Gooooo
0Ol00001ooooo`00VOooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo02;ooooo0_oo
001Zooooo`03o`000?oooooooooo00Cooooo0Ol00001ooooo`00V_ooool00ol0003oooooooooo`0a
ooooo`03o`000?oooooooooo023ooooo0_oo001]ooooo`03o`000?oooooooooo00?ooooo0Ol00001
ooooo`00Voooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01kooooo0_oo001`oooo
o`03o`000?oooooooooo00;ooooo0Ol00001ooooo`00W?ooool00ol0003oooooooooo`0_ooooo`03
o`000?oooooooooo01cooooo0_oo001cooooo`05o`000?ooooooooooooooool000000Oooool009go
oooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Kooooo`03ool00?oooooooooo07?o
oooo00Go0000ooooooooooooooooo`000001ooooo`00W_ooool00ol0003oooooooooo`0]ooooo`03
o`000?oooooooooo01Wooooo0_oo001gooooo`04o`000?ooooooooooooooo`7o0000002Oooooo`03
o`000?oooooooooo02cooooo00?o0000ooooooooool05oooool2ool007[ooooo00?o0000oooooooo
ool00Ol000000:3ooooo00?o0000ooooooooool0:oooool00ol0003oooooooooo`0Eooooo`;oo`00
OOooool1o`00007ooooo0Ol000000:7ooooo00?o0000ooooooooool0:_ooool00ol0003ooooooooo
o`0Cooooo`;oo`00P?ooool2o`000000X_ooool2o`0002[ooooo00?o0000ooooooooool04Oooool2
ool0087ooooo0ol000000:Cooooo00?o0000ooooooooool09oooool00ol0003oooooooooo`0@oooo
o`03ool00?oooooooooo07gooooo1?l00003ooooo`00YOooool00ol0003oooooooooo`0Vooooo`03
o`000?oooooooooo08gooooo0ol00007ooooo`00Y_ooool00ol0003oooooooooo`0Uooooo`03o`00
0?oooooooooo08Wooooo1?l0000:ooooo`00Yoooool00ol0003oooooooooo`0Tooooo`03o`000?oo
oooooooo08Gooooo1?l0000>ooooo`00Z?ooool00ol0003oooooooooo`0Sooooo`03o`000?oooooo
oooo08;ooooo0ol0000Booooo`00ZOooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
07kooooo1?l0000Eooooo`00Z_ooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo07[o
oooo1?l0000Iooooo`00Zoooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo07Gooooo
1?l0000Mooooo`00[?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo07;ooooo0ol0
000Qooooo`00[Oooool2o`00023ooooo00?o0000ooooooooool0K_ooool4o`0002Cooooo002_oooo
o`03o`000?oooooooooo01gooooo00?o0000ooooooooool0J_ooool4o`0002Sooooo002`ooooo`03
o`000?oooooooooo01cooooo00?o0000ooooooooool0Ioooool3o`0002cooooo002aooooo`03o`00
0?oooooooooo01_ooooo00?o0000ooooooooool0Hoooool4o`0002oooooo002booooo`03o`000?oo
oooooooo01[ooooo00?o0000ooooooooool0Goooool4o`0003?ooooo002cooooo`03o`000?oooooo
oooo01Wooooo00?o0000ooooooooool0G?ooool3o`0003Oooooo002dooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool0F?ooool4o`0003[ooooo002eooooo`03o`000?oooooooooo01Oo
oooo00?o0000ooooooooool0E?ooool4o`0003kooooo002fooooo`03o`000?oooooooooo01Kooooo
00?o0000ooooooooool0D?ooool4o`0004;ooooo002gooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool0COooool3o`0004Kooooo002hooooo`;o00005Oooool00ol0003oooooooooo`19
ooooo`Co0000BOooool00;[ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`15oooo
o`Co0000COooool00;_ooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`12ooooo`?o
0000DOooool00;cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0nooooo`Co0000
E?ooool00;gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0jooooo`Co0000F?oo
ool00;kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0fooooo`Co0000G?ooool0
0;oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0cooooo`?o0000H?ooool00<3o
oooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0_ooooo`Co0000Hoooool00<7ooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0[ooooo`Co0000Ioooool00<;ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`0Xooooo`?o0000Joooool00<?ooooo00?o0000
ooooooooool02Oooool00ol0003oooooooooo`0Tooooo`Co0000K_ooool00<Cooooo0_l00009oooo
o`03o`000?oooooooooo023ooooo1?l0001booooo`00a_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo01gooooo0ol0001fooooo`00aoooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo01Wooooo1?l0001iooooo`00b?ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo01Gooooo1?l0001mooooo`00bOooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo017ooooo1?l00021ooooo`00b_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00kooooo0ol00025ooooo`00boooool01Ol0003ooooooooooooooooo000000cooooo1?l00028oooo
o`00c?ooool01?l0003oooooooooool00008ooooo`Co0000S?ooool00<gooooo00?o0000ooooool0
00001Oooool3o`00093ooooo003>ooooo`;o000000?oooooo`000?l000000_l0002Cooooo`00cooo
ool2o`0009Oooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo
003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {330.375, 0}} -> {-0.0771432, -0.0315529, \
0.00350368, 0.00350368}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .92059 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-16 1.0763 -0.0263982 1.0763 [
[.01694 .18568 -11.9631 -9 ]
[.01694 .18568 .03693 0 ]
[.13793 .13897 -11.619 -9 ]
[.13793 .13897 .38095 0 ]
[.26292 .09073 -5.63752 -9 ]
[.26292 .09073 .36248 0 ]
[.39212 .04087 -5.46552 -9 ]
[.39212 .04087 .53448 0 ]
[.52574 -0.01069 -5.29351 -9 ]
[.52574 -0.01069 .70649 0 ]
[.58272 .04263 0 -6.19654 ]
[.58272 .04263 6 2.80346 ]
[.71715 .21863 0 -6.07114 ]
[.71715 .21863 6 2.92886 ]
[.83675 .37523 0 -5.963 ]
[.83675 .37523 6 3.037 ]
[.94385 .51546 0 -5.8688 ]
[.94385 .51546 6 3.1312 ]
[.01386 .20006 -12 -2.76892 ]
[.01386 .20006 0 6.23108 ]
[.00748 .25499 -24 -2.80073 ]
[.00748 .25499 0 6.19927 ]
[.00093 .31131 -6 -2.83339 ]
[.00093 .31131 0 6.16661 ]
[-0.00579 .36907 -18 -2.86695 ]
[-0.00579 .36907 0 6.13305 ]
[-0.01268 .42831 -6 -2.90143 ]
[-0.01268 .42831 0 6.09857 ]
[ 0 0 0 0 ]
[ 1 .92059 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02642 .19522 m
.53391 0 L
s
.02642 .19522 m
.03116 .2 L
s
[(-2)] .01694 .18568 .99384 1 Mshowa
.14712 .14879 m
.15172 .1537 L
s
[(-1)] .13793 .13897 .93651 1 Mshowa
.2718 .10083 m
.27624 .10588 L
s
[(0)] .26292 .09073 .87917 1 Mshowa
.40066 .05126 m
.40493 .05646 L
s
[(1)] .39212 .04087 .82184 1 Mshowa
.53391 0 m
.538 .00534 L
s
[(2)] .52574 -0.01069 .7645 1 Mshowa
.125 Mabswid
.05025 .18606 m
.05308 .18894 L
s
.07424 .17683 m
.07705 .17973 L
s
.09837 .16755 m
.10117 .17046 L
s
.12267 .1582 m
.12545 .16113 L
s
.17173 .13933 m
.17447 .14229 L
s
.19651 .1298 m
.19923 .13278 L
s
.22144 .1202 m
.22414 .1232 L
s
.24654 .11055 m
.24922 .11356 L
s
.29723 .09105 m
.29988 .0941 L
s
.32283 .0812 m
.32546 .08427 L
s
.3486 .07129 m
.35121 .07437 L
s
.37455 .06131 m
.37713 .06441 L
s
.42695 .04115 m
.4295 .04428 L
s
.45342 .03096 m
.45594 .03412 L
s
.48007 .02071 m
.48257 .02388 L
s
.5069 .01039 m
.50938 .01358 L
s
.25 Mabswid
.53391 0 m
.9804 .58403 L
s
.57014 .04738 m
.56384 .04975 L
s
[(0)] .58272 .04263 -1 .37701 Mshowa
.70445 .22307 m
.6981 .22529 L
s
[(2)] .71715 .21863 -1 .34914 Mshowa
.82396 .37939 m
.81756 .38147 L
s
[(4)] .83675 .37523 -1 .32511 Mshowa
.93098 .51938 m
.92454 .52134 L
s
[(6)] .94385 .51546 -1 .30418 Mshowa
.125 Mabswid
.60525 .09331 m
.60147 .09471 L
s
.63931 .13786 m
.63552 .13924 L
s
.67236 .1811 m
.66856 .18245 L
s
.73562 .26383 m
.7318 .26514 L
s
.7659 .30345 m
.76207 .30473 L
s
.79534 .34195 m
.7915 .34322 L
s
.85181 .41581 m
.84796 .41704 L
s
.87891 .45126 m
.87506 .45247 L
s
.90529 .48577 m
.90143 .48696 L
s
.95601 .55212 m
.95214 .55328 L
s
.25 Mabswid
.02642 .19522 m
0 .42381 L
s
.02642 .19522 m
.0327 .19281 L
s
[(-1)] .01386 .20006 1 -0.38468 Mshowa
.02006 .25024 m
.02635 .24786 L
s
[(-0.5)] .00748 .25499 1 -0.37762 Mshowa
.01354 .30664 m
.01985 .3043 L
s
[(0)] .00093 .31131 1 -0.37036 Mshowa
.00686 .36448 m
.01318 .36218 L
s
[(0.5)] -0.00579 .36907 1 -0.3629 Mshowa
0 .42381 m
.00634 .42156 L
s
[(1)] -0.01268 .42831 1 -0.35524 Mshowa
.125 Mabswid
.02516 .20612 m
.02893 .20468 L
s
.0239 .21707 m
.02767 .21563 L
s
.02262 .22807 m
.0264 .22664 L
s
.02135 .23913 m
.02512 .2377 L
s
.01877 .26141 m
.02255 .25999 L
s
.01747 .27263 m
.02125 .27122 L
s
.01617 .28391 m
.01995 .2825 L
s
.01486 .29525 m
.01864 .29384 L
s
.01222 .31809 m
.01601 .3167 L
s
.01089 .3296 m
.01468 .32821 L
s
.00955 .34117 m
.01334 .33978 L
s
.00821 .35279 m
.012 .35141 L
s
.0055 .37622 m
.0093 .37485 L
s
.00414 .38803 m
.00793 .38666 L
s
.00276 .39989 m
.00656 .39853 L
s
.00139 .41182 m
.00519 .41047 L
s
.25 Mabswid
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.54154 .92059 L
s
.54154 .92059 m
.5414 .7134 L
s
.5414 .7134 m
.02642 .19522 L
s
.53391 0 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.53391 0 m
.02642 .19522 L
s
.5414 .7134 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.54154 .92059 L
s
.54154 .92059 m
.5414 .7134 L
s
0 0 m
1 0 L
1 .92059 L
0 .92059 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.61379 .80836 m
.6867 .7726 L
s
1 0 .6 r
.59744 .7759 m
.6672 .74107 L
s
.8 0 1 r
.58108 .74342 m
.64771 .70957 L
s
.2 0 1 r
.56471 .71094 m
.62823 .6781 L
s
0 .4 1 r
.54833 .67843 m
.60876 .64666 L
s
0 1 1 r
.53195 .64592 m
.58931 .61524 L
s
0 1 .4 r
.51555 .61339 m
.56987 .58384 L
s
.2 1 0 r
.49915 .58084 m
.55045 .55247 L
s
.8 1 0 r
.48274 .54828 m
.53104 .52112 L
s
1 .6 0 r
.46633 .5157 m
.51165 .48979 L
s
.51165 .48979 m
.55284 .4563 L
s
.8 1 0 r
.53104 .52112 m
.57559 .48553 L
s
.2 1 0 r
.55045 .55247 m
.59841 .51485 L
s
0 1 .4 r
.56987 .58384 m
.62128 .54424 L
s
0 1 1 r
.58931 .61524 m
.64423 .57372 L
s
0 .4 1 r
.60876 .64666 m
.66723 .60327 L
s
.2 0 1 r
.62823 .6781 m
.6903 .63291 L
s
1 0 0 r
.57705 .77457 m
.6922 .77105 L
s
.47857 .76766 m
.57705 .77457 L
s
.8 0 1 r
.64771 .70957 m
.71343 .66263 L
s
1 0 .6 r
.6672 .74107 m
.73662 .69243 L
s
1 0 0 r
.6867 .7726 m
.75986 .72233 L
s
.6922 .77105 m
.79011 .75895 L
s
1 0 .6 r
.57817 .73842 m
.68839 .735 L
s
.48421 .73172 m
.57817 .73842 L
s
1 0 0 r
.43954 .76229 m
.47857 .76766 L
s
1 0 .6 r
.68839 .735 m
.78256 .72317 L
s
.8 0 1 r
.57933 .70215 m
.68461 .69883 L
s
.4899 .69567 m
.57933 .70215 L
s
1 0 0 r
.53766 .76699 m
.46771 .76545 L
s
.62321 .75721 m
.53766 .76699 L
s
.46771 .76545 m
.43954 .76229 L
s
1 0 .6 r
.4465 .72644 m
.48421 .73172 L
s
.8 0 1 r
.68461 .69883 m
.77499 .68729 L
s
.2 0 1 r
.5805 .66576 m
.68081 .66255 L
s
.49561 .65952 m
.5805 .66576 L
s
1 0 .6 r
.53576 .73073 m
.47169 .7293 L
s
.61426 .72161 m
.53576 .73073 L
s
.47169 .7293 m
.4465 .72644 L
s
.8 0 1 r
.45352 .6905 m
.4899 .69567 L
s
.2 0 1 r
.68081 .66255 m
.7674 .65132 L
s
0 .4 1 r
.58167 .62926 m
.67699 .62615 L
s
.50133 .62327 m
.58167 .62926 L
s
.8 0 1 r
.53385 .69435 m
.4757 .69304 L
s
.60529 .68593 m
.53385 .69435 L
s
.4757 .69304 m
.45352 .6905 L
s
.2 0 1 r
.46055 .65445 m
.49561 .65952 L
s
1 0 0 r
.70577 .73358 m
.62321 .75721 L
s
0 .4 1 r
.67699 .62615 m
.7598 .61525 L
s
0 1 1 r
.58284 .59264 m
.67317 .58964 L
s
.50708 .5869 m
.58284 .59264 L
s
.2 0 1 r
.53194 .65786 m
.47972 .65667 L
s
.59629 .65015 m
.53194 .65786 L
s
.47972 .65667 m
.46055 .65445 L
s
1 0 .6 r
.68989 .6996 m
.61426 .72161 L
s
0 .4 1 r
.46761 .61831 m
.50133 .62327 L
s
0 1 1 r
.67317 .58964 m
.75217 .57907 L
s
0 1 .4 r
.58402 .5559 m
.66933 .55302 L
s
.51284 .55043 m
.58402 .5559 L
s
0 .4 1 r
.53003 .62125 m
.48375 .62018 L
s
.58727 .61429 m
.53003 .62125 L
s
.8 0 1 r
.67401 .6656 m
.60529 .68593 L
s
0 .4 1 r
.48375 .62018 m
.46761 .61831 L
s
1 .6 0 r
.55284 .4563 m
.5782 .42455 L
s
0 1 1 r
.47469 .58206 m
.50708 .5869 L
s
0 1 .4 r
.66933 .55302 m
.74452 .5428 L
s
.2 0 1 r
.65811 .63157 m
.59629 .65015 L
s
.2 1 0 r
.58521 .51904 m
.66549 .51628 L
s
.51862 .51384 m
.58521 .51904 L
s
0 1 1 r
.52811 .58452 m
.4878 .58358 L
s
.57824 .57833 m
.52811 .58452 L
s
.8 1 0 r
.57559 .48553 m
.6034 .45148 L
s
0 1 1 r
.4878 .58358 m
.47469 .58206 L
s
0 1 .4 r
.48178 .54571 m
.51284 .55043 L
s
.2 1 0 r
.66549 .51628 m
.73685 .50644 L
s
0 .4 1 r
.6422 .59751 m
.58727 .61429 L
s
.8 1 0 r
.58639 .48205 m
.66163 .47943 L
s
.52441 .47715 m
.58639 .48205 L
s
.2 1 0 r
.59841 .51485 m
.62872 .47854 L
s
0 1 .4 r
.52618 .54767 m
.49186 .54687 L
s
.56917 .54228 m
.52618 .54767 L
s
.49186 .54687 m
.48178 .54571 L
s
.2 1 0 r
.4889 .50925 m
.51862 .51384 L
s
0 1 1 r
.62627 .56343 m
.57824 .57833 L
s
.8 1 0 r
.66163 .47943 m
.72916 .46997 L
s
0 1 .4 r
.62128 .54424 m
.65417 .50573 L
s
1 .6 0 r
.58759 .44495 m
.65776 .44246 L
s
.53023 .44035 m
.58759 .44495 L
s
.2 1 0 r
.52424 .5107 m
.49593 .51004 L
s
.56009 .50614 m
.52424 .5107 L
s
.8 1 0 r
.49603 .47269 m
.52441 .47715 L
s
.2 1 0 r
.49593 .51004 m
.4889 .50925 L
s
0 1 .4 r
.61033 .52931 m
.56917 .54228 L
s
1 .6 0 r
.65776 .44246 m
.72145 .4334 L
s
0 1 1 r
.64423 .57372 m
.67973 .53305 L
s
.8 1 0 r
.5223 .47361 m
.50001 .47309 L
s
.55098 .4699 m
.5223 .47361 L
s
1 .6 0 r
.50319 .43603 m
.53023 .44035 L
s
.2 1 0 r
.59438 .49517 m
.56009 .50614 L
s
.8 1 0 r
.50001 .47309 m
.49603 .47269 L
s
0 .4 1 r
.66723 .60327 m
.70542 .5605 L
s
.8 1 0 r
.57841 .46099 m
.55098 .4699 L
s
1 0 0 r
.77192 .6995 m
.70577 .73358 L
s
1 .6 0 r
.52036 .4364 m
.50411 .43603 L
s
.54185 .43358 m
.52036 .4364 L
s
.50411 .43603 m
.50319 .43603 L
s
1 0 .6 r
.75026 .66794 m
.68989 .6996 L
s
.2 0 1 r
.6903 .63291 m
.73123 .58808 L
s
.8 0 1 r
.72864 .63643 m
.67401 .6656 L
s
1 .6 0 r
.56243 .42679 m
.54185 .43358 L
s
.2 0 1 r
.70705 .60497 m
.65811 .63157 L
s
0 .4 1 r
.6855 .57356 m
.6422 .59751 L
s
.8 0 1 r
.71343 .66263 m
.75717 .6158 L
s
0 1 1 r
.66398 .54221 m
.62627 .56343 L
s
0 1 .4 r
.64249 .5109 m
.61033 .52931 L
s
.2 1 0 r
.62104 .47964 m
.59438 .49517 L
s
.8 1 0 r
.59963 .44843 m
.57841 .46099 L
s
1 0 .6 r
.73662 .69243 m
.78324 .64365 L
s
1 .6 0 r
.57825 .41727 m
.56243 .42679 L
s
.5782 .42455 m
.58735 .40817 L
s
1 0 0 r
.75986 .72233 m
.80941 .67166 L
s
.8 1 0 r
.6034 .45148 m
.61322 .4344 L
s
1 .6 0 r
.58683 .40864 m
.57825 .41727 L
s
.8 1 0 r
.61152 .43668 m
.59963 .44843 L
s
.2 1 0 r
.63631 .46482 m
.62104 .47964 L
s
.62872 .47854 m
.63923 .46077 L
s
0 1 .4 r
.6612 .49309 m
.64249 .5109 L
s
0 1 1 r
.68619 .52147 m
.66398 .54221 L
s
1 .6 0 r
.58735 .40817 m
.58683 .40864 L
s
0 .4 1 r
.71128 .54996 m
.6855 .57356 L
s
0 1 .4 r
.65417 .50573 m
.66539 .48729 L
s
.2 0 1 r
.73648 .57857 m
.70705 .60497 L
s
.8 1 0 r
.61322 .4344 m
.61152 .43668 L
s
.8 0 1 r
.76178 .6073 m
.72864 .63643 L
s
1 0 .6 r
.78718 .63615 m
.75026 .66794 L
s
0 1 1 r
.67973 .53305 m
.69168 .51396 L
s
1 0 0 r
.81269 .66512 m
.77192 .6995 L
s
.2 1 0 r
.63923 .46077 m
.63631 .46482 L
s
0 .4 1 r
.70542 .5605 m
.71812 .54077 L
s
0 1 .4 r
.66539 .48729 m
.6612 .49309 L
s
0 1 1 r
.69168 .51396 m
.68619 .52147 L
s
.2 0 1 r
.73123 .58808 m
.74471 .56773 L
s
0 .4 1 r
.71812 .54077 m
.71128 .54996 L
s
.8 0 1 r
.75717 .6158 m
.77144 .59484 L
s
.2 0 1 r
.74471 .56773 m
.73648 .57857 L
s
1 0 .6 r
.78324 .64365 m
.79832 .6221 L
s
.8 0 1 r
.77144 .59484 m
.76178 .6073 L
s
1 0 0 r
.80941 .67166 m
.82534 .64952 L
s
1 0 .6 r
.79832 .6221 m
.78718 .63615 L
s
1 0 0 r
.82534 .64952 m
.81269 .66512 L
s
0 g
.25 Mabswid
.53391 0 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.53391 0 m
.02642 .19522 L
s
.02642 .19522 m
.53391 0 L
s
.02642 .19522 m
.03116 .2 L
s
[(-2)] .01694 .18568 .99384 1 Mshowa
.14712 .14879 m
.15172 .1537 L
s
[(-1)] .13793 .13897 .93651 1 Mshowa
.2718 .10083 m
.27624 .10588 L
s
[(0)] .26292 .09073 .87917 1 Mshowa
.40066 .05126 m
.40493 .05646 L
s
[(1)] .39212 .04087 .82184 1 Mshowa
.53391 0 m
.538 .00534 L
s
[(2)] .52574 -0.01069 .7645 1 Mshowa
.125 Mabswid
.05025 .18606 m
.05308 .18894 L
s
.07424 .17683 m
.07705 .17973 L
s
.09837 .16755 m
.10117 .17046 L
s
.12267 .1582 m
.12545 .16113 L
s
.17173 .13933 m
.17447 .14229 L
s
.19651 .1298 m
.19923 .13278 L
s
.22144 .1202 m
.22414 .1232 L
s
.24654 .11055 m
.24922 .11356 L
s
.29723 .09105 m
.29988 .0941 L
s
.32283 .0812 m
.32546 .08427 L
s
.3486 .07129 m
.35121 .07437 L
s
.37455 .06131 m
.37713 .06441 L
s
.42695 .04115 m
.4295 .04428 L
s
.45342 .03096 m
.45594 .03412 L
s
.48007 .02071 m
.48257 .02388 L
s
.5069 .01039 m
.50938 .01358 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 265.125},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001Bb000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00`oooool5o`000:3ooooo0033ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@0X?ooool00<Cooooo00?oV9RHob4Q8Oo^k^h0XOooool00<Gooooo00?oV9RH
ob4Q8Oo^k^h0X?ooool00<Kooooo00?oMgMgofIVI_ooool0Woooool00<Oooooo00?o0000oooooooo
ool0W_ooool00<?ooooo00Go0000okZj^_ooooooV9RHoa0@402Pooooo`00`oooool01OnHV9So410@
o`000?lQ8B7oc<c<0:3ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003;ooooo`;o0000Voooool00<Sooooo0ol000000ooooooo0000ooooo`2Jooooo`00a_oo
ool2o`0000Cooooo0_l0002Jooooo`00`oooool3o`0000Kooooo00?o0000ooooool00000VOooool0
0<3ooooo1?l00008ooooo`04o`000?ooooooooooo`0009Sooooo002Hooooo`Co000000?o410@oooo
ooooool07oooool2o`0000Cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0002H
ooooo`00V_ooool00ol0003oooooooooo`0Nooooo`?o00003_ooool01Ol0003ooooooooooooooooo
000009Oooooo002Jooooo`03o`000?oooooooooo01cooooo0_l0000Aooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0U?ooool009[ooooo00?o0000ooooooooool06Oooool3o`0000;o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo09?o
oooo002Jooooo`03o`000?oooooooooo01Kooooo0ol0000Fooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^08Kooooo002Jooooo`03o`00
0?oooooooooo01Cooooo0_l0000Iooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1oooool01OmgMgOoV9RHoooooonHV9SoMgMg08Kooooo002Jooooo`03o`000?oooooooooo017ooooo
0ol000000ooooooo0000ooooo`0Hooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1_ooool01Ol@413ooooooooooooooooo410@08Kooooo002Hooooo`03oeEEEOmVIVKo0000017ooooo
0_l0000Nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool01Ol0003ooooo
oooooooooooo000008Kooooo002Yooooo`?o00008?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000026ooooo`00Yoooool3o`0002;ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@
4100Q_ooool00:Cooooo0ol00002ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Q_ooool00:7ooooo
0ol0000Xooooo`03o`000?oooooooooo00Sooooo0_l00004ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h0Q_ooool009oooooo0_l0000[ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo
0000S_ooool009cooooo0ol000000ooooooo0000ooooo`0Zooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0S?ooool009[ooooo0_l00005ooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`2;ooooo`00Uoooool3o`0003;ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`2:ooooo`00K?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^02?ooooo0ol000000ooooooo0000ooooo`0booooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0ROooool006cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Qooooo`;o0000>?ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo08Wooooo001/ooooo`05oa0@4?oooooooooo
ooooool@41007_ooool3o`0003[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`28
ooooo`00K?ooool01Ol0003ooooooooooooooooo000001cooooo0ol0000looooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0Qoooool006cooooo00Go0000ooooooooooooooooo`00000I
ooooo`?o00000_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool0Q_ooool006cooooo00Go410@oooooooooooooooooa0@400Gooooo`;o0000@_ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo08Kooooo001/ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL05?ooool3o`0004Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`25
ooooo`00K?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^017ooooo0ol00002ooooo`03o`000?oooooo
oooo04;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`24ooooo`00P?ooool2o`00
04[ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`23ooooo`00OOooool3o`0004co
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`22ooooo`00Noooool2o`000003oooo
ool0003ooooo04cooooo00?o0000ooooooooool05?ooool2o`0008?ooooo001hooooo`?o0000DOoo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooo000008?ooooo001eooooo`?o0000E?ooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo083ooooo001cooooo`Co0000EOooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo07oooooo001`ooooo`?o00001?ooool00ol0003o
ooooooooo`1Booooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0Ooooool006kooooo
0_l0001Looooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0O_ooool004?ooooo1?l0
00000ol@413oooooooooo`0Qooooo`?o0000G_ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo07gooooo0015ooooo`03o`000?oooooooooo023ooooo0ol00003ooooo`03o`000?oooooo
oooo05_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1looooo`00>_ooool6o`00
00Gooooo00?o0000ooooooooool07_ooool2o`0006Cooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`1looooo`00AOooool00ol0003oooooooooo`0Kooooo`?o0000I_ooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo07_ooooo0015ooooo`03o`000?oooooooooo01Wooooo
0_l00002ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`1jooooo`00AOooool00ol0003oooooooooo`0Fooooo`?o0000Joooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo07Wooooo0015ooooo`03o`000?oooooooooo01Cooooo0_l0001^
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0NOooool004?ooooo00?oEEEEofIV
I_l000004oooool3o`000003ooooool0003ooooo06gooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`1hooooo`00E_ooool3o`0007?ooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`1gooooo`00E?ooool2o`0007Kooooo00?o0000ooooooooool07oooool2o`0007Sooooo
001Aooooo`?o000000?oooooo`000?ooool0MOooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo07Kooooo001?ooooo`;o0000Noooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo07Gooooo001<ooooo`?o0000OOooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
07Cooooo0019ooooo`Co0000Ooooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo07?o
oooo0017ooooo`;o00001?ooool00ol0003oooooooooo`1looooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool0L_ooool004Cooooo0ol00025ooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool0L_ooool001[ooooo1Ol0000Sooooo`?o0000Qoooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo077ooooo000Jooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@08?ooool3
o`0000?ooooo00?o0000ooooooooool0Q?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo073ooooo000Booooo`Ko00000oooool00onHV9So8B4Qonk^kP0Oooooo`;o0000SOooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo06oooooo000Looooo`03oiRHV?lQ8B7ok^k^01_o
oooo0ol0002?ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0Koooool001gooooo
00?oMgMgofIVI_ooool05oooool3o`0000?ooooo00?o0000ooooooooool0S?ooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooooooo06kooooo000Nooooo`03o`000?oooooooooo01Cooooo0_l0
002Eooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0KOooool001[ooooo00Go0000
okZj^_ooooooV9RHoa0@400Cooooo`?o0000Uoooool00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo06cooooo000Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`04Oooool2o`0000?ooooo00?o
0000ooooooooool0U?ooool00ol0003oooooooooo`0Zooooo`;o0000KOooool002gooooo0ol0002L
ooooo`03o`000?oooooooooo02[ooooo0_l0001]ooooo`00:_ooool3o`0009oooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`1Zooooo`00:?ooool2o`0000?ooooo00?o0000oooooooo
ool0W?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo06Wooooo000Uooooo`?o0000
Y?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo06Wooooo000Tooooo`03o`000?oo
oooooooo0:Gooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1Xooooo`006_ooool4
o`000003oa0@4?oooooooooo00?ooooo0_l0002Vooooo`03o`000?oooooooooo02oooooo00?o0000
ooooooooool0Ioooool001cooooo00?o0000ooooooooool01Oooool2o`000:Kooooo00?o0000oooo
ooooool0<?ooool00ol0003oooooooooo`1Vooooo`004Oooool6o`0000Gooooo00?o0000oooooooo
ool01?ooool4o`000:Gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`08ooooo`Go
0000FOooool001cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0002Tooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool01OnHV9So8B4Qonk^k_ooooooA4A4
05Wooooo000Looooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`2Qooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool01oooool00onHV9So
8B4Qonk^kP1Jooooo`007?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0X?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Oooooo
00?oV9RHob4Q8Oo^k^h0FOooool001cooooo00?o0000ooooooooool01?ooool2o`0000Gooooo00?o
0000ooooooooool0Woooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Oooooo00?o
MgMgofIVI_ooool0F?ooool001[ooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo09kooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo05Oooooo000Sooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0WOooool00ol0003oooooooooo`0eooooo`;o00001?ooool01Ol0003o^[ZjoooooonHV9So
410@05Wooooo000Sooooo`;o00002?ooool00ol0003oooooooooo`2Looooo`03o`000?oooooooooo
03?ooooo0_l000000ooooooo0000ooooo`03ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0FOooool0
02?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2Kooooo`03o`000?oooooooooo
03Oooooo00?o0000ooooooooool0Goooool002?ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`2Jooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0Goooool002?ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`2Hooooo`;o0000>_ooool00ol0003ooooo
ooooo`1Nooooo`008_ooool2o`0000gooooo00?o0000ooooooooool0U?ooool3o`000003ooooool0
003ooooo03[ooooo00?o0000ooooooooool0GOooool002;ooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`2@ooooo`?o00001Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooo
oooo05cooooo000Rooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0S?ooool3o`00
00Wooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1Looooo`008_ooool3o`0000oo
oooo00?o0000ooooooooool0R?ooool3o`0000gooooo00?o0000ooooooooool0>?ooool00ol0003o
ooooooooo`1Kooooo`008_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo08Gooooo
0_l0000Aooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0F_ooool002;ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`21ooooo`?o00005?ooool00ol0003ooooooooo
o`0hooooo`03o`000?oooooooooo05Wooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool0OOooool3o`0001Oooooo00?o0000ooooooooool0>?ooool00ol0003ooooo
ooooo`1Iooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1iooooo`?o0000
6oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo05Sooooo0005o`0000;ooooo00Go
410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`1eooooo`?o00007oooool00ol0003oooooooooo`0hooooo`03o`00
0?oooooooooo05Oooooo0007ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8b
ooooo`03ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0LOooool3o`0002?ooooo
00?o0000ooooooooool0=oooool2o`0005Sooooo0007ooooo`05o`000?ooooooooooooooool00000
3?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`1^ooooo`;o00009oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo05Go
oooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`;o
00006Oooool00ol0003oooooooooo`1Zooooo`?o0000:_ooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo05Gooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0I_ooool3o`0002go
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1Dooooo`001oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool0H_ooool3o`00037ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1Cooooo`00
8Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo05kooooo0ol0000eooooo`03o`00
0?oooooooooo03Sooooo00?o0000ooooooooool0D_ooool0023ooooo0ol0000Mooooo`03o`000?oo
oooooooo05_ooooo0_l0000iooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0D_oo
ool0027ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1Gooooo`?o0000??ooool0
0ol0003oooooooooo`0gooooo`03o`000?oooooooooo057ooooo000Pooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool0Doooool3o`00043ooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`1@ooooo`008?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo04oo
oooo0ol00013ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0Coooool0023ooooo
0_l0000Rooooo`03o`000?oooooooooo04_ooooo0ol00017ooooo`03o`000?oooooooooo03Oooooo
00?o0000ooooooooool0Coooool0023ooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`18ooooo`;o0000Boooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo04kooooo000P
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0A?ooool3o`0004kooooo00?o0000
ooooooooool0=oooool00ol0003oooooooooo`1=ooooo`008?ooool3o`0002Cooooo00?o0000oooo
ooooool0@?ooool3o`0005;ooooo00?o0000ooooooooool0=_ooool2o`0004kooooo000Pooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0??ooool3o`0005Kooooo00?o0000oooooooo
ool0=_ooool00ol0003oooooooooo`1<ooooo`005?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oo
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0hooooo`?o0000FOooool00ol0003o
ooooooooo`0gooooo`03o`000?oooooooooo04_ooooo000Dooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo03Gooooo0_l0001Mooooo`03
o`000?oooooooooo03Oooooo00?o0000ooooooooool0B_ooool001Cooooo00Go410@oooooooooooo
oooooa0@4006ooooo`;o0000:_ooool00ol0003oooooooooo`0aooooo`?o0000H?ooool00ol0003o
ooooooooo`0gooooo`03o`000?oooooooooo04Wooooo000Dooooo`05o`000?ooooooooooooooool0
00001_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo02gooooo0ol0001Tooooo`03
o`000?oooooooooo03Kooooo00?o0000ooooooooool0BOooool001Cooooo00Go0000oooooooooooo
ooooo`000006ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0:Oooool3o`0006So
oooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`18ooooo`005?ooool01Ol@413ooooo
oooooooooooo410@00Kooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Uooooo`?o
0000K?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo04Oooooo000Dooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool2o`0002kooooo00?o0000ooooooooool08Oooool3o`0006oo
oooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`16ooooo`005?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Nooooo`;o
0000Loooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo04Gooooo000Oooooo`03o`00
0?oooooooooo02oooooo00?o0000ooooooooool06_ooool3o`0007Kooooo00?o0000ooooooooool0
=_ooool00ol0003oooooooooo`15ooooo`007_ooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo01Kooooo0ol0001jooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0A?oo
ool001kooooo0_l0000cooooo`03o`000?oooooooooo01;ooooo0ol0001nooooo`03o`000?oooooo
oooo03Kooooo0_l00014ooooo`007_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo
00kooooo0ol00022ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooool00000A?ooool001ko
oooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0;ooooo`;o0000QOooool00ol0003o
ooooooooo`0fooooo`03o`000?oooooooooo04;ooooo000Nooooo`03o`000?oooooooooo03Gooooo
00?o0000ooooooooool01oooool3o`0008Sooooo00?o0000ooooooooool0=_ooool00ol0003ooooo
ooooo`11ooooo`007_ooool2o`0003Oooooo00?o0000ooooooooool00oooool3o`0008cooooo00?o
0000ooooooooool0=_ooool00ol0003oooooooooo`10ooooo`007_ooool00ol0003oooooooooo`0g
ooooo`03o`000?oooooo000000;o0000T?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooo
oooo03oooooo000Nooooo`03o`000?oooooooooo03Kooooo0ol0002Dooooo`03o`000?oooooooooo
03Gooooo00?o0000ooooooooool0?oooool001kooooo0_l0000eooooo`;o00000oooool00ol0003o
ooooooooo`2Booooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool02Oooool2o`000003
oa0@4?oooooooooo033ooooo000Mooooo`03o`000?oooooooooo03;ooooo0ol00006ooooo`03o`00
0?oooooooooo097ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo037ooooo0002ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo
00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo02oooooo0ol0000:ooooo`03
o`000?oooooooooo097ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`05ooooo`Go
0000<_ooool000;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo
<S8booooo`04ooooo`03o`000?oooooooooo02cooooo0ol0000>ooooo`03o`000?oooooooooo097o
oooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`05ooooo`04odA4A?oMgMgoooooo`00
03?ooooo0002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03oooo
o`;o0000:_ooool3o`0001;ooooo00?o0000ooooooooool0TOooool00ol0003oooooooooo`0eoooo
o`03o`000?oooooooooo00Cooooo00CogMgMoeEEEOoooooo0000<oooool000;ooooo00Go0000oooo
ooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool09oooool2
o`0001Kooooo00?o0000ooooooooool0TOooool00ol0003oooooooooo`0eooooo`03o`000?oooooo
oooo00Cooooo00?oMgMgolc<c?l00000<oooool000;ooooo00Go0000ooooooooooooooooo`00000<
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Tooooo`?o00006Ooo
ool00ol0003oooooooooo`2Aooooo`03o`000?oooooooooo03Cooooo0_l00005ooooo`03onk^k_m4
A4Co000003?ooooo0002ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo027ooooo0ol0000Mooooo`03o`000?oooooooooo093ooooo00?o
0000ooooooooool0<oooool01?l0003oooooooooool00005ooooo`03ogMgMol0003ooooo03;ooooo
0002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`;o0000
7oooool3o`00027ooooo00?o0000ooooooooool0T?ooool00ol0003oooooooooo`0eooooo`03o`00
0?oooooooooo03Sooooo0002ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo
00?o0000ooooooooool07?ooool3o`0002Gooooo00?o0000ooooooooool0T?ooool00ol0003ooooo
ooooo`0eooooo`03o`000?oooooooooo03Oooooo000Looooo`03o`000?oooooooooo01Wooooo0ol0
000Yooooo`03o`000?oooooooooo093ooooo00?o0000ooooooooool0=Oooool00ol0003ooooooooo
o`0fooooo`007?ooool00ol0003oooooooooo`0Gooooo`;o0000;Oooool00ol0003oooooooooo`2@
ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0=Oooool001cooooo0_l0000Eoooo
o`?o0000<?ooool00ol0003oooooooooo`2@ooooo`03o`000?oooooooooo03Cooooo00?o0000oooo
ooooool0=Oooool001cooooo00?o0000ooooooooool04Oooool3o`0003Cooooo00?o0000oooooooo
ool0Soooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo03Cooooo000Looooo`03o`00
0?oooooooooo00kooooo0ol0000hooooo`03o`000?oooooooooo08oooooo00?o0000ooooooooool0
=Oooool00ol0003oooooooooo`0cooooo`007?ooool00ol0003oooooooooo`0;ooooo`?o0000??oo
ool00ol0003oooooooooo`1booooo`03oonI0?oooooooooo01[ooooo00?o0000ooooooooool0=Ooo
ool00ol0003oooooooooo`0booooo`007?ooool2o`0000[ooooo0_l00010ooooo`03o`000?oooooo
oooo073ooooo0_ooV@0Mooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0<_ooool0
01_ooooo0_l00008ooooo`?o0000@oooool00ol0003oooooooooo`1^ooooo`;ooiT07oooool00ol0
003oooooooooo`0dooooo`03o`000?oooooooooo037ooooo000Kooooo`03o`000?oooooooooo00Co
oooo0ol00017ooooo`03o`000?oooooooooo06_ooooo0_ooV@000ooooooooiT0ooooo`0Oooooo`03
o`000?oooooooooo03?ooooo0_l0000booooo`006oooool01?l0003oooooooooooooool3o`0004_o
oooo00?o0000ooooooooool0JOooool01?ooV@3oooooooooooooV@0Qooooo`03o`000?oooooooooo
03Gooooo00?o0000ooooooooool0;oooool001_ooooo1?l0001?ooooo`03o`000?oooooooooo06Ko
oooo0_ooV@03ooooo`03oonI0?oooooooooo023ooooo00?o0000ooooooooool0=?ooool00ol0003o
ooooooooo`0_ooooo`006oooool2o`0005;ooooo00?o0000ooooooooool0I?ooool00oooV@3ooooo
ooooo`02ooooo`03oonI0?oooooooooo02;ooooo00?o0000ooooooooool0=?ooool00ol0003ooooo
ooooo`0^ooooo`004Oooool4o`000003oa0@4?oooooooooo00Gooooo00?o0000ooooooooool0D?oo
ool00ol0003oooooooooo`1Qooooo`;ooiT01Oooool00oooV@3oooooooooo`0Sooooo`03o`000?oo
oooooooo03Cooooo00?o0000ooooooooool0;Oooool001?ooooo00?o0000ooooooooool02?ooool0
0ol0003oooooooooo`1@ooooo`03o`000?oooooooooo05gooooo0oooV@06ooooo`03oonI0?oooooo
oooo02Gooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0/ooooo`004oooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0Eoooool5oonI
00Sooooo00?ooiT0ooooooooool02_ooool00oo<o`3oooooooooo`0Jooooo`04o`000?oooooooooo
ooooo`CooiT0;_ooool00ol0003oooooooooo`0/ooooo`004oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo053ooooo00?o0000ooooooooool0C?ooool:oonI00cooooo00?ooiT0oooo
ooooool02oooool00oo<o`3oooooooooo`0Gooooo`?ooiT000Co0000oonI0?ooV@3ooiT0<oooool0
0ol0003oooooooooo`0[ooooo`004oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo
053ooooo00?o0000ooooooooool0DOooool9oonI00Kooooo00?ooiT0ooooooooool02oooool00oo<
o`3oooooooooo`0Aooooo`OooiT01?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo
02[ooooo000Cooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0D?ooool00ol0003o
ooooooooo`1Iooooo`WooiT02_ooool2olco00Cooooo3oooV@0<ooooo`03o`000?oooooooooo03Co
oooo00?o0000ooooooooool0:Oooool001?ooooo00?o0000ooooooooool03Oooool00ol0003ooooo
ooooo`1@ooooo`03o`000?oooooooooo05cooooo00?ooiT0ooooooooool00_ooool9oonI00;oc?l0
1OooV@0Looooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0:?ooool0017ooooo00?o
EEEEofIVI_l000004?ooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo05[ooooo00?o
oiT0ooooooooool02_ooool2olco0003ooooooo<o`3ooooo027ooooo00?o0000ooooooooool0<ooo
ool00ol0003oooooooooo`0Xooooo`009Oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooo
oooo05Sooooo00?ooiT0ooooooooool02Oooool2olco00;ooooo00?oc?l0ooooooooool08_ooool0
0ol0003oooooooooo`0booooo`;o0000:Oooool002Kooooo0_l0001Aooooo`03o`000?oooooooooo
05Gooooo0_ooV@0;ooooo`03olco0?oooooooooo00;ooooo00?oc?l0ooooooooool08_ooool00ol0
003oooooooooo`0dooooo`03o`000?oooooooooo02Kooooo000Xooooo`03o`000?oooooooooo04ko
oooo00?o0000ooooooooool0E?ooool00oooV@3oooooooooo`09ooooo`;oc?l01?ooool00oo<o`3o
ooooooooo`0Tooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool09Oooool002Wooooo
00?o0000ooooooooool0C_ooool00ol0003oooooooooo`1Booooo`03oonI0?oooooooooo00Sooooo
0_o<o`05ooooo`03olco0?oooooooooo00_ooooo00?o<ol0ooooooooool06?ooool00ol0003ooooo
ooooo`0cooooo`03o`000?oooooooooo02Gooooo000Zooooo`03o`000?oooooooooo04kooooo00?o
0000ooooooooool0D?ooool00oooV@3oooooooooo`06ooooo`?oc?l01_ooool00oo<o`3ooooooooo
o`0;ooooo`;o<ol06oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02Cooooo000[
ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0C_ooool00oooV@3oooooooooo`04
ooooo`?oc?l02?ooool00oo<o`3oooooooooo`0;ooooo`;o<ol07Oooool00ol0003oooooooooo`0c
ooooo`03o`000?oooooooooo02?ooooo000/ooooo`03o`000?oooooooooo04kooooo00?o0000oooo
ooooool0Boooool2oonI00Ooc?l02_ooool00oo<o`3oooooooooo`0;ooooo`;o<ol06oooool4olco
0003o`000?oooooooooo03?ooooo00?o0000ooooooooool08_ooool002gooooo00?o0000oooooooo
ool0C_ooool00ol0003oooooooooo`0nooooo`koc?l04Oooool00oo<o`3oooooooooo`0:ooooo`03
oc?o0?oooooo<ol001?ooooo2?o<o`04ooooo`03o`000?oooooooooo03?ooooo00?o0000oooooooo
ool08_ooool002kooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`13ooooo`[oc?l0
3_ooool00oo<o`3oooooooooo`0:ooooo`03oc?o0?oooooo<ol000gooooo1oo<o`0=ooooo`03o`00
0?oooooooooo03?ooooo00?o0000ooooooooool08Oooool002oooooo00?o0000ooooooooool0C_oo
ool00ol0003oooooooooo`15ooooo`03oonI0?oooooooooo00Cooooo2_o<o`03ooooo`03olco0?oo
oooooooo00Wooooo0_lco`000oo<o`3o<ol0olco000=olco01Gooooo00?o0000ooooooooool0<ooo
ool00ol0003oooooooooo`0Pooooo`00<?ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooo
oooo04?ooooo00?ooiT0ooooooooool03oooool=olco00;o<ol00_o<o`000ooooooo<ol0ooooo`0S
ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool07oooool0037ooooo0_l0001?oooo
o`03o`000?oooooooooo047ooooo00?ooiT0ooooooooool04?ooool2olco00Wooooo0_lco`04oooo
o`03oc?o0?oooooooooo02Cooooo00?o0000ooooooooool0<_ooool2o`00023ooooo000cooooo`03
o`000?oooooooooo04gooooo00?o0000ooooooooool0?_ooool2oonI01;ooooo00?oc?l0oooooooo
ool02?ooool00olco`3oooooooooo`03ooooo`03oc?o0?oooooooooo00cooooo00?o0?mVoooooooo
ool05oooool00ol0003oooooooooo`0aooooo`;o00008?ooool003Cooooo00?o0000ooooooooool0
COooool00ol0003oooooooooo`0kooooo`;ooiT04oooool00oo<o`3oooooooooo`07ooooo`;o<ol0
1Oooool00olco`3oooooooooo`0<ooooo`;o0?mV6Oooool00ol0003oooooooooo`0cooooo`03o`00
0?oooooooooo01gooooo000eooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0>Ooo
ool00oooV@3oooooooooo`0Booooo`03olco0?oooooooooo00Kooooo0_lco`06ooooo`03oc?o0?oo
oooooooo00_ooooo0ol0ofHKooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool07?oo
ool003Kooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0fooooo`;ooiT04oooool2
olco00Kooooo0olco`07ooooo`03oc?o0?oooooooooo00_ooooo00?o0?mVooooool0ofH07Oooool0
0ol0003oooooooooo`0booooo`03o`000?oooooooooo01cooooo000gooooo`03o`000?oooooooooo
04gooooo00?o0000ooooooooool0<oooool2oonI01Cooooo00?oc?l0ooooooooool00oooool3oc?o
00[ooooo00?o<ol0ooooooooool02_ooool01?l0ofKoooooooooool0ofHNooooo`03o`000?oooooo
oooo03;ooooo00?o0000ooooooooool06oooool003Sooooo00?o0000ooooooooool0COooool00ol0
003oooooooooo`0aooooo`03oonI0?oooooooooo01?ooooo00Coc?l0oooooooooooooooo0olco`0<
ooooo`03oc?o0?oooooooooo00[ooooo00Co0?mVoooooooooooo0?mV8?ooool00ol0003ooooooooo
o`0booooo`03o`000?oooooooooo00Oooooo00Gok^k^oc8b<_l0003o410@olc<c00>ooooo`00>Ooo
ool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo02kooooo0_ooV@0Cooooo`Oo<ol03_oo
ool00olco`3oooooooooo`0:ooooo`04o`3oI_ooooooooooo`3oIQKooooo1Olco`07ooooo`03o`00
0?oooooooooo03;ooooo00?o0000ooooooooool01_ooool01OmEEEGoMgMgoooooonHV9So8B4Q00ko
oooo000jooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0:oooool2oonI00?ooooo
4_lco`02olco01;ooooo00?o<ol0ooooooooool02Oooool2o`3oIP?ooooo00?o0?mVooooooooool0
3?ooool8oc?o00cooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`05ooooo`05o`00
0?ooooooooooooooool000003_ooool003_ooooo00?o0000ooooooooool0COooool00ol0003ooooo
ooooo`0Yooooo`03oonI0?oooooooooo00Wooooo2olco`000oo<o`3oooooooooo`0Aooooo`03oc?o
0?oooooooooo00Wooooo00?o0?mVooooooooool00_ooool00ol0ofKoooooooooo`06ooooo`Co<ol0
00?o0?oooc?o0?lco`005Oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00Gooooo
00Go0000oiRHV?ooooooV9RHob4Q8@0>ooooo`00??ooool00ol0003oooooooooo`1=ooooo`03o`00
0?oooooooooo02Oooooo00?ooiT0ooooooooool05?ooool00oo<o`3o<ol0oc?o0009oc?o00Oooooo
0_lco`09ooooo`03oc?o0?l0ofKo0?mV00Co<ol000?o0?mVoc?o0?lco`001olco`04ooooo`03o`3o
oooooooooooo01Kooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`04ooooo`05o`00
0?mEEEGo0000oa0@4?o<c<`03_ooool003gooooo0_l0001>ooooo`03o`000?oooooooooo03cooooo
00?oc?l0ooooooooool02_oooolAoc?o00;o0?mV1Oooool00ol0ofKoooooooooo`0;ooooo`03o`3o
oooooooooooo01Sooooo00?o0000ooooooooool0<_ooool2o`0000Cooooo00?oEEEEohN7Qoooool0
4?ooool003oooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0iooooo`;oc?l04_oo
ool00olco`3oooooooooo`08ooooo`03o`3oI_oooooooooo00Cooooo00?o0?mVooooooooool02ooo
ool2o`3ooa_ooooo00?o0000ooooooooool0;oooool2o`000003ooooool0003ooooo00?ooooo00?o
gMgMoa0@4?nHV9P04?ooool0043ooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0f
ooooo`;oc?l04_ooool2oc?o00Wooooo0_l0ofH6ooooo`03o`3oI_oooooooooo00_ooooo0_l0oolM
ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool00oooool01?o<c<coA4A4o`000?l@
410>ooooo`00@Oooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo03Cooooo00?oc?l0
ooooooooool04Oooool00olco`3oooooooooo`08ooooo`03o`3oI_oooooooooo00Gooooo00?o0?mV
ooooooooool02oooool2o`3ooakooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0D
ooooo`00@_ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo037ooooo0_o<o`0Coooo
o`03oc?o0?oooooooooo00Kooooo0ol0ofH8ooooo`03o`3oI_oooooooooo00[ooooo00?o0?oooooo
ool0ool07oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01?ooooo0013ooooo`03
o`000?oooooooooo04cooooo00?o0000ooooooooool0;_ooool2olco01?ooooo0_lco`06ooooo`?o
0?mV2_ooool00ol0ofKoooooooooo`0:ooooo`03o`3ooooooooo0?oo027ooooo00?o0000oooooooo
ool0<_ooool00ol0003oooooooooo`0Booooo`00A?ooool00ol0003oooooooooo`1<ooooo`03o`00
0?oooooooooo02_ooooo0_o<o`0Dooooo`03oc?o0?oooooooooo00?ooooo0ol0ofH<ooooo`03o`3o
I_oooooooooo00[ooooo00Co0?oooooooooooooo0?oo8_ooool00ol0003oooooooooo`0aooooo`03
o`000?oooooooooo01;ooooo0015ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0
:?ooool2olco01Gooooo00Co<ol0oooooooooooooooo0ol0ofH>ooooo`03o`3oI_oooooooooo00[o
oooo00Co0?oooooooooooooo0?oo3Oooool00ol0I_ooooooooooo`0Dooooo`03o`000?oooooooooo
037ooooo00?o0000ooooooooool04Oooool004Kooooo00?o0000ooooooooool0C?ooool00ol0003o
ooooooooo`0Vooooo`03olco0?oooooooooo01?ooooo1_l0ofH@ooooo`03o`3oI_oooooooooo00Wo
oooo0_l0ool2ooooo`03o`3ooooooooooooo00cooooo00?o06Koooooooooool00_ooool5o`3oIPko
oooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0@ooooo`00Aoooool00ol0003ooooo
ooooo`1<ooooo`03o`000?oooooooooo02;ooooo2_l0ofH8ooooo`Oo0?mV5?ooool2o`3oIP[ooooo
0_l0ool3ooooo`03o`3ooooooooooooo00Wooooo0ol0ofH00ol0I_oo0?mVo`3oIP03o`3oIQ?ooooo
00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0?ooooo`00B?ooool2o`0004gooooo00?o
0000ooooooooool08Oooool01?o<o`3oooooooooooooool5o`3oIP03ooooool0ofKo0?mV00Ko0?mV
1Oooool00olco`3oooooooooo`0Booooo`03o`3oI_oooooooooo00Wooooo00?o0?ooooooooooool0
0_ooool00ol0ooooooooooooo`02ooooo`So0?mV00Coooooo`1Vool0I_oo06Ko6Oooool00ol0003o
ooooooooo`0aooooo`03o`000?oooooooooo00oooooo001:ooooo`03o`000?oooooooooo04_ooooo
00?o0000ooooooooool0:Oooool>o`3oIQCooooo00?o0?mVooooooooool00_ooool6o`3oIP;o0?oo
1?l0ofH00ol0oooo0?mVo`3oIP03o`3oIPSooooo00?o06Koooooool0I_l06oooool00ol0003ooooo
ooooo`0aooooo`;o00003oooool004_ooooo00?o0000ooooooooool0Boooool00ol0003ooooooooo
o`0booooo`;o<ol00_oooolIo`3oIPCooooo0_l0ool5ooooo`03o`3ooooooooooooo00_ooooo00?o
06Koooooool0I_l07Oooool00ol0003oooooooooo`0`ooooo`;o00003oooool004cooooo00?o0000
ooooooooool0Boooool00ol0003oooooooooo`0`ooooo`03oc?o0?oooooooooo01?ooooo00?o0?mV
ooooooooool02?ooool00ol0ooooooooooooo`05ooooo`03o`3ooooooooooooo00[ooooo00Co06Ko
oooooooooooo06Ko7_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00cooooo001=
ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0;Oooool2oc?o01Gooooo00?o0?mV
ooooooooool01oooool2o`3oo`Oooooo00?o0?ooooooooooool02_ooool01?l0I_ooooooooooool0
I_lPooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool02oooool004kooooo00?o0000
ooooooooool0Boooool00ol0003oooooooooo`0Zooooo`;o<ol05Oooool2o`3oIPOooooo0ol0ool8
ooooo`03o`3ooooooooooooo00[ooooo00Go06Koooooooooooooooooo`1Vo`0Pooooo`03o`000?oo
oooooooo037ooooo00?o0000ooooooooool02oooool004oooooo00?o0000ooooooooool0Boooool0
0ol0003oooooooooo`0Xooooo`03oc?o0?oooooooooo01Cooooo00?o0?mVooooooooool01?ooool3
o`3oo`[ooooo00?o0?ooooooooooool02_ooool01Ol0I_oooooooooooooooooo06Ko00gooooo00?o
<`3oooooooooool04_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00[ooooo001@
ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool09Oooool2oc?o01Kooooo00?o0?mV
ooooooooool00_ooool3o`3oo`cooooo00?o0?ooooooooooool02_ooool01Ol0I_oooooooooooooo
oooo06Ko00kooooo00?o<`3oooooooooool04oooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo00Wooooo001Aooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool08_ooool2
oc?o01Oooooo00?o0?mVooooooooool00ol0ool=ooooo`;o0?oo2oooool2o`1Vo`?ooooo00?o06Ko
ooooooooool03?ooool00olc0?ooooooooooo`0Eooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool02?ooool005;ooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0Poooo
o`03oc?o0?oooooooooo01Gooooo0_l0ofH3o`3oo`oooooo00?o0?ooooooooooool02Oooool2o`1V
o`Cooooo00?o06Koooooooooool03?ooool00olc0?ooooooooooo`0Gooooo`03o`000?oooooooooo
033ooooo00?o0000ooooooooool02?ooool005?ooooo0_l0001<ooooo`03o`000?oooooooooo01go
oooo0_lco`0Dooooo`Ko0?oo4Oooool00ol0ooooooooooooo`09ooooo`03o`1Voooooooooooo00?o
oooo00?o06Koooooooooool02oooool2oc<0o`03ooooool0oooo0?oo00;o0?oo5_ooool00ol0003o
ooooooooo`0`ooooo`03o`000?oooooooooo00Oooooo001Eooooo`03o`000?oooooooooo04[ooooo
00?o0000ooooooooool04oooool4o`3oo`Cooooo00?o<ol0ooooooooool02oooool9o`3oo`;ooooo
00?o0?mVooooooooool04?ooool2o`3oo`[ooooo0_l0I_l5ooooo`03o`1Voooooooooooo00Sooooo
0ol0ool01?lc0?oo0?oooc<0ool0oolJooooo`03o`000?oooooooooo037ooooo00?o0000oooooooo
ool01_ooool005Kooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0Foooooa;o0?oo
2Oooool2o`3oIQ;ooooo00?o0?ooooooooooool02?ooool2o`1Vo`Kooooo00?o06Koooooooooool0
0oooool6o`3oo`;ooooo00?o<`3ooooooolc0?l07Oooool00ol0003oooooooooo`0_ooooo`?o0000
1oooool005Oooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0Jooooo`Wo0?oo2ooo
ool2o`3oIQ?ooooo00?o0?ooooooooooool01oooool2o`1Vo`Oooooo00?o06Koo`3oool0ool01?l0
ool7ooooo`03oc<0oooooooo<`3o01oooooo00?o0000ooooooooool0:oooool3o`0000;ooooo00?o
0000ooooooooool01Oooool005Sooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0R
ooooo`go0?oo4Oooool2o`3oo`03ooooool0oooo0?oo00Ko0?oo00?o06Koo`3oool0ool01_l0ool0
0ol0I_ooooooooooo`0;ooooo`04oc<0oooooooooooooc<0ob3ooooo00?o0000ooooooooool09ooo
ool3o`0000Gooooo00?o0000ooooooooool01Oooool005Wooooo00?o0000ooooooooool0B_ooool0
0ol0003oooooooooo`0Xooooo`;o0?mV1?oooolDo`3oo`Kooooo0_l0I_l8ooooo`03o`1Voooooooo
oooo00_ooooo00Co<`3ooooooooooooo<`3o3_ooool00oo<0?ooooooooooo`0Aooooo`03o`000?oo
oooooooo02;ooooo1?l00008ooooo`03o`000?oooooooooo00Gooooo001Jooooo`03o`000?oooooo
oooo04[ooooo00?o0000ooooooooool09Oooool2o`3oIQCooooo0_l0ool8ooooo`;o06Ko2Oooool0
0ol0I_ooooooooooo`0;ooooo`04oc<0oooooooooooooc<0o`oooooo00?oc03oooooooooool04_oo
ool00ol0003oooooooooo`0Nooooo`?o00003?ooool00ol0003oooooooooo`05ooooo`00Foooool0
0ol0003oooooooooo`1:ooooo`03o`000?oooooooooo02;ooooo0_l0ofHEooooo`03o`3ooooooooo
oooo00Gooooo0ol0I_l:ooooo`03o`1Voooooooooooo00_ooooo00Co<`3ooooooooooooo<`3o3ooo
ool00oo<0?ooooooooooo`0Cooooo`03o`000?oooooooooo01[ooooo1?l0000?ooooo`03o`000?oo
oooooooo00Gooooo001Looooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool07oooool2
o`3oIQKooooo00?o0?ooooooooooool00oooool3o`1Vo`_ooooo0_l0I_l=ooooo`04oc<0oooooooo
oooooc<0o`oooooo00?oc03oooooooooool05Oooool00ol0003oooooooooo`0Fooooo`?o00005?oo
ool00ol0003oooooooooo`04ooooo`00GOooool00ol0003oooooooooo`1:ooooo`03o`000?oooooo
oooo01cooooo0_l0ofHFooooo`;o0?oo0oooool3o`1Vo`gooooo00?o06Koooooooooool02oooool2
oc<0o`;ooooo00?o<`3oooooooooool03?ooool2ol`0oaWooooo00?o0000ooooooooool04_ooool3
o`0001Oooooo00?o0000ooooooooool01?ooool005kooooo0_l0001;ooooo`03o`000?oooooooooo
01Wooooo0_l0ofHGooooo`03o`3ooooooooooooo00?o06Ko3oooool00ol0I_ooooooooooo`0:oooo
o`;o<`3o0oooool00olc0?ooooooooooo`0<ooooo`03ol`0ooooooooc03o01[ooooo00?o0000oooo
ooooool03Oooool4o`0001[ooooo00?o0000ooooooooool01?ooool0063ooooo00?o0000oooooooo
ool0BOooool00ol0003oooooooooo`0Gooooo`03o`3oI_oooooooooo01Kooooo00Co0?ooo`1Vool0
I_oo06Ko4?ooool2o`1Vo`_ooooo0_lc0?l4ooooo`03oc<0oooooooooooo00cooooo00?oc03ooooo
ooo<0?l07?ooool00ol0003oooooooooo`09ooooo`?o00007_ooool00ol0003oooooooooo`04oooo
o`00HOooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo02Wooooo1ol0I_lBooooo`03
o`1Voooooooooooo00Wooooo0_lc0?l6ooooo`03oc<0oooooooooooo00_ooooo00Coc03oo`1Vooo<
0?oo06Ko7Oooool00ol0003oooooooooo`04ooooo`Co00008Oooool00ol0003oooooooooo`04oooo
o`00H_ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo00Gooooo1?l0I_lFooooo`Wo
06Ko0_ooool2o`3ooaCooooo00?o06Koooooooooool02?ooool2oc<0o`Oooooo00?o<`3ooooooooo
ool01Oooool6o`1Vo`04ol`0oooooooooooool`0oakooooo00Co0000oooooooooooooooo0ol0000U
ooooo`03o`000?oooooooooo00Cooooo001Sooooo`03o`000?oooooooooo04Wooooo00?o0000oooo
ooooool02?oooolFo`1Vo`Wooooo0_l0oolDooooo`;o06Ko2Oooool2oc<0o`Sooooo00?o<`3ooooo
ool0I_l01_l0I_l5ooooo`04ol`0oooooooooooool`0o`kooooo00?oo`2Iooooooooool03oooool3
o`0002Sooooo00?o0000ooooooooool01?ooool006Cooooo00?o0000ooooooooool0BOooool00ol0
003oooooooooo`0<ooooo`[o06Ko3_ooool2o`3ooaGooooo00?o06Koooooooooool01oooool2oc<0
o`Gooooo1?l0I_l00olc0?oo06Koo`1Vo`0;ooooo`04ol`0oooooooooooool`0o`oooooo00?oo`2I
ooooooooool02oooool4o`000003ooooool0003ooooo02Sooooo00?o0000ooooooooool01?ooool0
06Gooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0Eooooo`go06Ko00?o0?oooooo
ooooool04oooool:o`1Vo`;o<`3o1ol0I_l3ooooo`03oc<0oooooooooooo00_ooooo00Coc03ooooo
ooooooooc03o3oooool00ooo09Woooooooooo`09ooooo`?o00001_ooool00ol0003oooooooooo`0V
ooooo`03o`000?oooooooooo00Cooooo001Vooooo`03o`000?oooooooooo04Wooooo00?o0000oooo
ooooool07oooool00ol0ooooooooo`1Vo`0Eo`1Vo`Sooooo0_lc0?l;ooooo`03oc<0oooooooooooo
00_ooooo00Coc03oooooooooooooc03o3oooool00ooo09Woooooooooo`06ooooo`Co00002_ooool0
0ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Cooooo001Wooooo`03o`000?oooooooooo
04Wooooo00?o0000ooooooooool07?ooool2o`3ooaKooooo00?o06Koooooooooool01?ooool3oc<0
o`_ooooo0_lc0?l=ooooo`04ol`0oooooooooooool`0o`oooooo00?oo`2Iooooooooool01?ooool3
o`0000oooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`03ooooo`00J?ooool00ol0
003oooooooooo`19ooooo`03o`000?oooooooooo01Wooooo0_l0oolFooooo`;o06Ko1?ooool3oc<0
o`gooooo00?o<`3oooooooooool02oooool2ol`0o`;ooooo00?oc03oooooooooool03?ooool3ool0
V@?ooooo0ol0000Booooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00oooool006Wo
oooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0Fooooo`;o0?oo5oooool01?l0I_oo
ooooooooooooool3oc<0o`kooooo0_lc0?l<ooooo`;oc03o0oooool00oo<0?ooooooooooo`0<oooo
o`03ool0VOooooooo`2I00Co00005_ooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo
00?ooooo001Zooooo`;o0000B_ooool00ol0003oooooooooo`0Cooooo`;o0?oo6?ooool00ol0I_oo
oooooc<0o`02oc<0oa3ooooo00?o<`3oooooooooool02_ooool2ol`0o`Gooooo00?oc03ooooooooo
ool02oooool01?oo09Wo0000ool0VOl0000Kooooo`03o`000?oooooooooo02?ooooo00?o0000oooo
ooooool00oooool006cooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0Aooooo`03
o`3ooooooooooooo01Kooooo00Co06Kooc<0oolc0?oo<`3o4_ooool00olc0?ooooooooooo`09oooo
o`;oc03o1_ooool00oo<0?ooooooooooo`09ooooo`;o000000Coo`2Io`000?ooooooo`2I7Oooool0
0ol0003oooooooooo`0Rooooo`03o`000?oooooooooo00?ooooo001]ooooo`03o`000?oooooooooo
04Sooooo00?o0000ooooooooool09oooool3oc<0oa?ooooo0_lc0?l:ooooo`;oc03o1oooool00oo<
0?ooooooooooo`07ooooo`?o000000Goooooool0VOooooooooooool0V@0>ooooo`03ool00?oooooo
oooo00kooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`03ooooo`00K_ooool00ol0
003oooooooooo`18ooooo`03o`000?oooooooooo023ooooo1_lc0?lEooooo`03oc<0oooooooooooo
00Wooooo00?oc03oooooooooool01_ooool00oo<0?ooooooooooo`05ooooo`;o00001?lc0?l01?oo
09Wooooooooooooo09T?ooooo`03ool00?oooooooooo00oooooo00?o0000ooooooooool08?ooool0
0ol0003oooooooooo`03ooooo`00Koooool00ol0003oooooooooo`12ooooo`Co<`3o0_ooool00ol0
003oooooooooo`0Dooooo`_o<`3o0oooool00ol0I_ooooooooooo`0Cooooo`;o<`3o2_ooool2ol`0
o`Sooooo00Coc03ooooooooooooooooo1olc0?l3ooooo`04ool0VOooooooooooool0V@oooooo00?o
o`00ooooooooool04?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo00?ooooo001`
ooooo`03o`000?oooooooooo04Gooooo6Olc0?l<ooooo`;o06Ko5Oooool00olc0?ooooooooooo`08
ooooo`;oc03o1oooool2oc<0o`03ol`0oolc0?oo<`3o00;o<`3o00?o0000ooooooooool01_ooool0
1?oo09Wooooooooooooo09T?ooooo`03ool00?oooooooooo01;ooooo00?o0000ooooooooool07ooo
ool00ol0003oooooooooo`03ooooo`00LOooool00ol0003oooooooooo`18ooooo`03o`000?lc0?oo
<`3o00So<`3o5?ooool2o`1VoaKooooo00?o<`3oooooooooool01oooool2ol`0o`;ooooo1olc0?l0
0oooooooc03oo`000002o`0000[ooooo00Coo`2Iooooooooooooo`2I3oooool00ooo003ooooooooo
o`0Dooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool00oooool007;ooooo00?o0000
ooooooooool0B?ooool00ol0003oooooooooo`07ooooo`ko<`3o1?ooool2o`1Voa7ooooo3olc0?l2
ol`0o`Co<`3o1Oooool00ol0003oc03ool`0o`0=ooooo`04ool0VOooooooooooool0V@oooooo0_oo
000Gooooo`03o`000?oooooooooo01kooooo00?o0000ooooooooool00_ooool007?ooooo00?o0000
ooooooooool0B?ooool00ol0003oooooooooo`0DoooooaOo<`3o1?ooool00olc0?ooooooooooo`05
ooooo`?oc03o2?ooool3o`000003ol`0oooooooooooo00cooooo00Coo`2Iooooooooooooo`2I3_oo
ool3ool001Wooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`02ooooo`00M?ooool0
0ol0003oooooooooo`18ooooo`03o`000?oooooooooo01Cooooo00?o06Koooooooooool05Oooool2
oc<0o`Cooooo1?o<0?l7ooooo`Co000000?ooooool`0ooo<0?l03Oooool2ool0V@;ooooo00?oo`2I
ooooooooool03?ooool00ooo003oooooool0000Kooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool00_ooool007Gooooo0_l00019ooooo`03o`000?oooooooooo017ooooo0_l0I_lGoooo
o`04oc<0ooooooooooooooooo`?oc03o2?ooool3o`0000Cooooo00?oc03oooooooooool02oooool2
ool0V@?ooooo00?oo`2Iooooooooool03?ooool00ooo003oooooool0000Looooo`03o`000?oooooo
oooo01cooooo00?o0000ooooooooool00_ooool007Oooooo00?o0000ooooooooool0Aoooool00ol0
003oooooooooo`0>ooooo`;o06Ko6?ooool00olc0?ooc03ool`0o`02ol`0o`Oooooo1?l00005oooo
o`;oc03o3?ooool2ool0V@Cooooo00?oo`2Iooooooooool03?ooool01?oo003ooooooooooooo000M
ooooo`03o`000?oooooooooo01_ooooo00?o0000ooooooooool00_ooool007Sooooo00?o0000oooo
ooooool0Aoooool00ol0003oooooooooo`0<ooooo`03o`1Voooooooooooo01Gooooo1?o<0?l8oooo
o`?o00002?ooool00oo<0?ooooooooooo`0:ooooo`;oo`2I1Oooool00ooo09Woooooooooo`0<oooo
o`04ool00?ooooooooooool001oooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`02
ooooo`00NOooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo023ooooo0oo<0?l00olc
0?ooooooooooo`06ooooo`?o00002Oooool2ol`0o`_ooooo0_oo09T6ooooo`03ool0VOoooooooooo
00_ooooo0_oo0002ooooo`03ool00?oooooooooo01oooooo00?o0000ooooooooool06Oooool00ol0
003oooooooooo`02ooooo`00N_ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo01Wo
oooo1_o<0?l2oc<0o`Kooooo1?l0000;ooooo`03ol`0oooooooooooo00Wooooo0_oo09T7ooooo`03
ool0VOoooooooooo00_ooooo00Goo`00ooooooooooooooooool0000Sooooo`03o`000?oooooooooo
01Sooooo00?o0000ooooooooool00_ooool007_ooooo00?o0000ooooooooool0Aoooool00ol0003o
ooooooooo`0@ooooo`Soc03o1?ooool2oc<0o`Gooooo0ol0000>ooooo`03ol`0oooooooooooo00So
oooo0_oo09T8ooooo`03ool0VOoooooooooo00Cooooo1Oo<0?l2ooooo`05ool00?oooooooooooooo
oooo00009Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00;ooooo001looooo`03
o`000?oooooooooo03;ooooo1Oo<0?l@ooooo`03o`000?oooooooooo00Oooooo2?o<0?l:ooooo`;o
<`3o0oooool4o`0000oooooo0_o<0?l9ooooo`;oo`2I2Oooool00ooo09Woc03ool`0o`05ol`0o`Ko
oooo00Goo`00ooooooooooooooooool0000Vooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool00_ooool007gooooo00?o0000ooooooooool0=OoooolKol`0oa3ooooo0_lc0?l2ooooo`?o
00004_ooool00oo<0?ooooooooooo`07ooooo`;oo`2I1?ooool6ol`0o`03ool0VOo<0?oooooo00_o
oooo00Goo`00ooooooooooooooooool0000Xooooo`03o`000?oooooooooo01Oooooo00?o0000oooo
ooooool00Oooool007kooooo00?o0000ooooooooool0>_ooool;ol`0o`;ooooo00?o0000oooooooo
ool05?ooool00olc0?ooooooo`000002o`0001?ooooo0_o<0?l8ooooo`;oo`2I1_o<0?l4ooooo`03
ool0VOoooooooooo00cooooo00Goo`00ooooooooooooooooool0000Zooooo`03o`000?oooooooooo
01Kooooo00?o0000ooooooooool00Oooool007oooooo00?o0000ooooooooool0A?ooool?ol`0o`So
oooo0_lc0?l2o`0000cooooo4Oo<0?l3ool0V@03ol`0oooooooooooo00Oooooo0_oo09T=ooooo`;o
o`000oooool00ooo003oooooooooo`0Zooooo`03o`000?oooooooooo01Gooooo00?o0000oooooooo
ool00Oooool0083ooooo0_l00018ooooo`03o`000?oooooooooo00Sooooo6?o<0?l7ooooo`;oc03o
1Oooool3ool0V@cooooo00?oo`2Iooooooooool02oooool2ool000Cooooo00?oo`00ooooooooool0
;?ooool00ol0003oooooooooo`0Dooooo`03o`000?oooooooooo007ooooo0022ooooo`03o`000?oo
oooooooo04Kooooo00?o0000ooooooooool02?ooool3o`0000;o<`3o6?ooool01?o<0?oooooooooo
ooooool4ool0V@kooooo00?oo`2Iooooooooool02_ooool2ool000Gooooo00?oo`00ooooooooool0
;_ooool00ol0003oooooooooo`0Cooooo`03o`000?oooooooooo007ooooo0023ooooo`03o`000?oo
oooooooo04Kooooo00?o0000ooooooooool01?ooool3o`000003oooooolc0?oo<`3o01Sooooo0_o<
0?l4ool0VA3ooooo0_oo09T;ooooo`;oo`001_ooool00ooo003oooooooooo`0_ooooo`03o`000?oo
oooooooo01?ooooo00?o0000ooooooooool00Oooool008Cooooo00?o0000ooooooooool0A_ooool0
0ol0003oooooooooo`03o`0000?ooooo00?o<`3oooooooooool05_ooool01?o<0?ooo`2Iool0VOoo
09TCooooo`03ool0VOoooooooooo00Wooooo0_oo0007ooooo`03ool00?oooooooooo037ooooo00?o
0000ooooooooool04_ooool00ol0003oooooooooo`01ooooo`00QOooool00ol0003oooooooooo`16
ooooo`;o00007?ooool4ool0VACooooo0_oo09T:ooooo`;oo`002?ooool00ooo003oooooooooo`0c
ooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool00Oooool008Kooooo00?o0000oooo
ooooool0AOooool00ol0003oooooooooo`0Hooooo`?oo`2I00?oc03oooooooooool05?ooool00ooo
09Woooooooooo`08ooooo`;oo`002Oooool00ooo003oooooooooo`0eooooo`03o`000?oooooooooo
013ooooo00?o0000ooooooooool00Oooool008Oooooo00?o0000ooooooooool0A?ooool00ol0003o
ooooooooo`0Booooo`Koo`2I00?ooooool`0ooo<0?l05Oooool2ool0V@Wooooo0_oo000:ooooo`03
ool00?oooooooooo03Oooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`01ooooo`00
R?ooool00ol0003oooooooooo`13ooooo`03o`000?oooooooooo00Wooooo2Ooo09T5ooooo`;oc03o
5_ooool00ooo09Woooooooooo`07ooooo`;oo`002_ooool2ool000;ooooo1Ooo09Tdooooo`03o`00
0?oooooooooo00oooooo0Ol00001ooooo`7ooooo0029ooooo`03o`000?oooooooooo02?ooooo1Ooo
09TJooooo`03o`000?oooooooooo00Woo`2I3?ooool2ol`0oaKooooo0_oo09T8ooooo`;oo`002?oo
ool8ool0VCWooooo00?o0000ooooooooool03oooool1o`00007ooooo0Oooool008[ooooo00?o0000
ooooooooool09_oooolNool0VA?ooooo0_o<0?lGooooo`03ool0VOoooooooooo00Kooooo0_oo0003
ooooo`Ooo`2I00?oooooool00?oo0000?oooool00ol0003oooooooooo`0>ooooo`7o00000Oooool1
ooooo`00Roooool2o`0002gooooo2ooo09T9ooooo`03o`000?oooooooooo017ooooo0_o<0?lHoooo
o`03ool0VOoooooooooo00Cooooo0ooo0005ool0V@Oooooo00?oo`00ooooooooool0@?ooool00ol0
003oooooooooo`0=ooooo`7o00000Oooool1ooooo`00SOooool00ol0003oooooooooo`0eooooo`oo
o`2I3Oooool00oo<0?ooooooooooo`09oooooa?oo`2I0ooo000=ooooo`;oo`00A?ooool00ol0003o
ooooooooo`0<ooooo`7o00000Oooool1ooooo`00S_ooool00ol0003oooooooooo`0mooooo`03o`00
0?oooooooooo00?ooooo6Ooo09T<ooooo`04ool0VOooooooooooooooo`?oo`003oooool00ooo003o
ooooooooo`15ooooo`03o`000?oooooooooo00_ooooo0Ol00001ooooo`7ooooo002?ooooo`03o`00
0?oooooooooo03cooooo00?o0000ooooooooool03?ooool2ol`0oaSooooo0_oo09T4ool0013ooooo
0_oo0019ooooo`03o`000?oooooooooo00[ooooo0Ol00001ooooo`7ooooo002@ooooo`03o`000?oo
oooooooo03_ooooo00?o0000ooooooooool02oooool00oo<0?ooooooooooo`0Fooooo`04ool0VOoo
003oo`00ool001?ooooo00?oo`00ooooooooool0BOooool00ol0003oooooooooo`0:ooooo`7o0000
0Oooool1ooooo`00TOooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo027ooooo1?oo
000Dooooo`;oo`00COooool00ol0003oooooooooo`09ooooo`7o00000Oooool1ooooo`00T_ooool0
0ol0003oooooooooo`0iooooo`03o`000?oooooooooo01kooooo0ooo00000ooo09Woooooooooo`0D
ooooo`03ool00?oooooooooo04kooooo00?o0000ooooooooool02?ooool1o`00007ooooo0Oooool0
09?ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`0Kooooo`?oo`000_oo09TFoooo
o`;oo`00D_ooool00ol0003oooooooooo`08ooooo`7o00000Oooool009Cooooo00?o0000oooooooo
ool0=oooool00ol0003oooooooooo`0Dooooo`Ooo`000ooo09TGooooo`03ool00?oooooooooo05?o
oooo00?o0000ooooooooool01oooool1o`00007ooooo002Eooooo`03o`000?oooooooooo03Kooooo
00?o0000ooooooooool02_ooool:ool000Gooooo0_oo09THooooo`;oo`005oooool5ool003_ooooo
00?o0000ooooooooool01_ooool1o`00007ooooo002Fooooo`03o`000?oooooooooo01Cooooo1_oo
000Kooooo`04o`000?ooooooooooooooo`Woo`003Oooool2ool0VAWooooo00?oo`00ooooooooool0
3oooool8ool0043ooooo00?o0000ooooooooool01_ooool1o`00007ooooo002Gooooo`;o00006?oo
oolQool001Cooooo0_oo09TIooooo`;oo`002Oooool9ool004Wooooo00?o0000ooooooooool01Ooo
ool1o`00007ooooo002Iooooo`03o`000?oooooooooo01cooooo2ooo000;ooooo`03o`000?oooooo
oooo01?ooooo0_oo09TJooooo`04ool00?ooooooooooooooo`Soo`00Doooool00ol0003ooooooooo
o`04ooooo`7o00000Oooool009[ooooo00?o0000ooooooooool09_ooool@ool000oooooo0_oo09T9
oooooaOoo`00G?ooool00ol0003oooooooooo`03ooooo`7o00000Oooool009_ooooo00?o0000oooo
ooooool0<?ooool00ol0003oooooooooo`02oooooa[oo`003oooool2ool006?ooooo00?o0000oooo
ooooool00_ooool1o`00007ooooo002Looooo`03o`000?oooooooooo02oooooo00?o0000oooooooo
ool0:Oooool2ool006Kooooo00Go0000ooooooooooooooooo`000001ooooo`00WOooool00ol0003o
ooooooooo`0^ooooo`03o`000?oooooooooo02Oooooo0_oo001Xooooo`05o`000?oooooooooooooo
ool000000Oooool009kooooo00?o0000ooooooooool0;Oooool00ol0003oooooooooo`0Uooooo`;o
o`00Joooool01?l0003oooooooooooooool1o`000000Woooool00ol0003oooooooooo`0/ooooo`03
o`000?oooooooooo02?ooooo0_oo001^ooooo`03o`000?oooooooooo007o0000002Pooooo`03o`00
0?oooooooooo02_ooooo00?o0000ooooooooool08?ooool3ool0077ooooo0Ol00001ooooo`7o0000
002Qooooo`03o`000?oooooooooo02[ooooo00?o0000ooooooooool07_ooool2ool007Gooooo0_l0
00000:;ooooo0_l0000Zooooo`03o`000?oooooooooo01cooooo0_oo001fooooo`?o0000002Toooo
o`03o`000?oooooooooo02Oooooo00?o0000ooooooooool06_ooool2ool007Cooooo1?l00003oooo
o`00YOooool00ol0003oooooooooo`0Vooooo`03o`000?oooooooooo01Sooooo0_oo001cooooo`?o
00001oooool00:Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Fooooo`;oo`00
LOooool4o`0000[ooooo002Wooooo`03o`000?oooooooooo02Cooooo00?o0000ooooooooool05Ooo
ool00ooo003oooooooooo`1]ooooo`Co00003_ooool00:Sooooo00?o0000ooooooooool08oooool0
0ol0003oooooooooo`22ooooo`?o00004_ooool00:Wooooo00?o0000ooooooooool08_ooool00ol0
003oooooooooo`1nooooo`Co00005Oooool00:[ooooo00?o0000ooooooooool08Oooool00ol0003o
ooooooooo`1jooooo`Co00006Oooool00:_ooooo00?o0000ooooooooool08Oooool00ol0003ooooo
ooooo`1eooooo`Co00007Oooool00:cooooo00?o0000ooooooooool08?ooool00ol0003ooooooooo
o`1booooo`?o00008Oooool00:gooooo0_l0000Pooooo`03o`000?oooooooooo06kooooo1?l0000T
ooooo`00[oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo06[ooooo1?l0000Xoooo
o`00/?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo06Oooooo0ol0000/ooooo`00
/Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo06?ooooo1?l0000_ooooo`00/_oo
ool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo05oooooo1?l0000cooooo`00/oooool0
0ol0003oooooooooo`0Iooooo`03o`000?oooooooooo05cooooo0ol0000gooooo`00]?ooool00ol0
003oooooooooo`0Hooooo`03o`000?oooooooooo05Sooooo1?l0000jooooo`00]Oooool00ol0003o
ooooooooo`0Gooooo`03o`000?oooooooooo05Cooooo1?l0000nooooo`00]_ooool00ol0003ooooo
ooooo`0Fooooo`03o`000?oooooooooo053ooooo1?l00012ooooo`00]oooool00ol0003ooooooooo
o`0Eooooo`03o`000?oooooooooo04gooooo0ol00016ooooo`00^?ooool2o`0001Gooooo00?o0000
ooooooooool0BOooool4o`0004Wooooo002jooooo`03o`000?oooooooooo01;ooooo00?o0000oooo
ooooool0AOooool4o`0004gooooo002kooooo`03o`000?oooooooooo017ooooo00?o0000oooooooo
ool0@_ooool3o`00057ooooo002looooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0
?_ooool4o`0005Cooooo002mooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0>_oo
ool4o`0005Sooooo002nooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0=_ooool4
o`0005cooooo002oooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0<oooool3o`00
063ooooo0030ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0;oooool4o`0006?o
oooo0031ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0:oooool4o`0006Oooooo
0032ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0:?ooool3o`0006_ooooo0033
ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool09?ooool4o`0006kooooo0034oooo
o`;o00002Oooool00ol0003oooooooooo`0Pooooo`Co0000L_ooool00<Kooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0Mooooo`?o0000M_ooool00<Oooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0Iooooo`Co0000NOooool00<Sooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`0Eooooo`Co0000OOooool00<Wooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`0Aooooo`Co0000POooool00<[ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0>ooooo`?o0000QOooool00<_ooooo00Go0000ooooooooooooooooo`00000<oooo
o`Co0000R?ooool00<cooooo00Co0000oooooooooooo00002?ooool4o`0008cooooo003=ooooo`03
o`000?oooooo000000Gooooo0ol0002@ooooo`00c_ooool2o`000003ooooool0003o000000;o0000
Toooool00<oooooo0_l0002Gooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00
oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {330.375, 0}} -> {-0.0771432, -0.0315529, \
0.00350368, 0.00350368}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .92059 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-16 1.0763 -0.0263982 1.0763 [
[.01694 .18568 -11.9631 -9 ]
[.01694 .18568 .03693 0 ]
[.13793 .13897 -11.619 -9 ]
[.13793 .13897 .38095 0 ]
[.26292 .09073 -5.63752 -9 ]
[.26292 .09073 .36248 0 ]
[.39212 .04087 -5.46552 -9 ]
[.39212 .04087 .53448 0 ]
[.52574 -0.01069 -5.29351 -9 ]
[.52574 -0.01069 .70649 0 ]
[.58272 .04263 0 -6.19654 ]
[.58272 .04263 6 2.80346 ]
[.71715 .21863 0 -6.07114 ]
[.71715 .21863 6 2.92886 ]
[.83675 .37523 0 -5.963 ]
[.83675 .37523 6 3.037 ]
[.94385 .51546 0 -5.8688 ]
[.94385 .51546 6 3.1312 ]
[.01386 .20006 -12 -2.76892 ]
[.01386 .20006 0 6.23108 ]
[.00748 .25499 -24 -2.80073 ]
[.00748 .25499 0 6.19927 ]
[.00093 .31131 -6 -2.83339 ]
[.00093 .31131 0 6.16661 ]
[-0.00579 .36907 -18 -2.86695 ]
[-0.00579 .36907 0 6.13305 ]
[-0.01268 .42831 -6 -2.90143 ]
[-0.01268 .42831 0 6.09857 ]
[ 0 0 0 0 ]
[ 1 .92059 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02642 .19522 m
.53391 0 L
s
.02642 .19522 m
.03116 .2 L
s
[(-2)] .01694 .18568 .99384 1 Mshowa
.14712 .14879 m
.15172 .1537 L
s
[(-1)] .13793 .13897 .93651 1 Mshowa
.2718 .10083 m
.27624 .10588 L
s
[(0)] .26292 .09073 .87917 1 Mshowa
.40066 .05126 m
.40493 .05646 L
s
[(1)] .39212 .04087 .82184 1 Mshowa
.53391 0 m
.538 .00534 L
s
[(2)] .52574 -0.01069 .7645 1 Mshowa
.125 Mabswid
.05025 .18606 m
.05308 .18894 L
s
.07424 .17683 m
.07705 .17973 L
s
.09837 .16755 m
.10117 .17046 L
s
.12267 .1582 m
.12545 .16113 L
s
.17173 .13933 m
.17447 .14229 L
s
.19651 .1298 m
.19923 .13278 L
s
.22144 .1202 m
.22414 .1232 L
s
.24654 .11055 m
.24922 .11356 L
s
.29723 .09105 m
.29988 .0941 L
s
.32283 .0812 m
.32546 .08427 L
s
.3486 .07129 m
.35121 .07437 L
s
.37455 .06131 m
.37713 .06441 L
s
.42695 .04115 m
.4295 .04428 L
s
.45342 .03096 m
.45594 .03412 L
s
.48007 .02071 m
.48257 .02388 L
s
.5069 .01039 m
.50938 .01358 L
s
.25 Mabswid
.53391 0 m
.9804 .58403 L
s
.57014 .04738 m
.56384 .04975 L
s
[(0)] .58272 .04263 -1 .37701 Mshowa
.70445 .22307 m
.6981 .22529 L
s
[(2)] .71715 .21863 -1 .34914 Mshowa
.82396 .37939 m
.81756 .38147 L
s
[(4)] .83675 .37523 -1 .32511 Mshowa
.93098 .51938 m
.92454 .52134 L
s
[(6)] .94385 .51546 -1 .30418 Mshowa
.125 Mabswid
.60525 .09331 m
.60147 .09471 L
s
.63931 .13786 m
.63552 .13924 L
s
.67236 .1811 m
.66856 .18245 L
s
.73562 .26383 m
.7318 .26514 L
s
.7659 .30345 m
.76207 .30473 L
s
.79534 .34195 m
.7915 .34322 L
s
.85181 .41581 m
.84796 .41704 L
s
.87891 .45126 m
.87506 .45247 L
s
.90529 .48577 m
.90143 .48696 L
s
.95601 .55212 m
.95214 .55328 L
s
.25 Mabswid
.02642 .19522 m
0 .42381 L
s
.02642 .19522 m
.0327 .19281 L
s
[(-1)] .01386 .20006 1 -0.38468 Mshowa
.02006 .25024 m
.02635 .24786 L
s
[(-0.5)] .00748 .25499 1 -0.37762 Mshowa
.01354 .30664 m
.01985 .3043 L
s
[(0)] .00093 .31131 1 -0.37036 Mshowa
.00686 .36448 m
.01318 .36218 L
s
[(0.5)] -0.00579 .36907 1 -0.3629 Mshowa
0 .42381 m
.00634 .42156 L
s
[(1)] -0.01268 .42831 1 -0.35524 Mshowa
.125 Mabswid
.02516 .20612 m
.02893 .20468 L
s
.0239 .21707 m
.02767 .21563 L
s
.02262 .22807 m
.0264 .22664 L
s
.02135 .23913 m
.02512 .2377 L
s
.01877 .26141 m
.02255 .25999 L
s
.01747 .27263 m
.02125 .27122 L
s
.01617 .28391 m
.01995 .2825 L
s
.01486 .29525 m
.01864 .29384 L
s
.01222 .31809 m
.01601 .3167 L
s
.01089 .3296 m
.01468 .32821 L
s
.00955 .34117 m
.01334 .33978 L
s
.00821 .35279 m
.012 .35141 L
s
.0055 .37622 m
.0093 .37485 L
s
.00414 .38803 m
.00793 .38666 L
s
.00276 .39989 m
.00656 .39853 L
s
.00139 .41182 m
.00519 .41047 L
s
.25 Mabswid
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.54154 .92059 L
s
.54154 .92059 m
.5414 .7134 L
s
.5414 .7134 m
.02642 .19522 L
s
.53391 0 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.53391 0 m
.02642 .19522 L
s
.5414 .7134 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.54154 .92059 L
s
.54154 .92059 m
.5414 .7134 L
s
0 0 m
1 0 L
1 .92059 L
0 .92059 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.62973 .81869 m
.70548 .78184 L
s
1 0 .6 r
.61346 .78638 m
.68606 .75043 L
s
.8 0 1 r
.59718 .75406 m
.66663 .71906 L
s
.2 0 1 r
.58089 .72173 m
.64722 .68771 L
s
0 .4 1 r
.56459 .68937 m
.62783 .65639 L
s
0 1 1 r
.54829 .65701 m
.60845 .62509 L
s
0 1 .4 r
.53197 .62463 m
.58908 .59381 L
s
.2 1 0 r
.51565 .59223 m
.56973 .56256 L
s
.8 1 0 r
.49932 .55982 m
.55039 .53134 L
s
1 .6 0 r
.48299 .5274 m
.53107 .50013 L
s
.53107 .50013 m
.57542 .46442 L
s
.8 1 0 r
.55039 .53134 m
.59814 .49357 L
s
1 0 0 r
.57572 .78833 m
.69526 .7847 L
s
.4732 .78118 m
.57572 .78833 L
s
.2 1 0 r
.56973 .56256 m
.62091 .52281 L
s
0 1 .4 r
.58908 .59381 m
.64375 .55212 L
s
0 1 1 r
.60845 .62509 m
.66665 .58151 L
s
0 .4 1 r
.62783 .65639 m
.68961 .61099 L
s
1 0 0 r
.69526 .7847 m
.79648 .77227 L
s
1 0 .6 r
.57683 .75241 m
.69149 .74888 L
s
.4788 .74547 m
.57683 .75241 L
s
.2 0 1 r
.64722 .68771 m
.71264 .64054 L
s
.8 0 1 r
.66663 .71906 m
.73572 .67018 L
s
1 0 .6 r
.68606 .75043 m
.75887 .6999 L
s
1 0 0 r
.70548 .78184 m
.78207 .72971 L
s
1 0 .6 r
.69149 .74888 m
.78898 .73672 L
s
1 0 0 r
.43303 .77569 m
.4732 .78118 L
s
.8 0 1 r
.57799 .71639 m
.68773 .71295 L
s
.48444 .70966 m
.57799 .71639 L
s
1 0 0 r
.53954 .78081 m
.46405 .77916 L
s
.63171 .77035 m
.53954 .78081 L
s
.46405 .77916 m
.43303 .77569 L
s
1 0 .6 r
.43995 .74007 m
.4788 .74547 L
s
.8 0 1 r
.68773 .71295 m
.78147 .70107 L
s
.2 0 1 r
.57915 .68025 m
.68395 .67691 L
s
.49011 .67374 m
.57915 .68025 L
s
1 0 .6 r
.53765 .74479 m
.46801 .74325 L
s
.62283 .73497 m
.53765 .74479 L
s
.46801 .74325 m
.43995 .74007 L
s
.8 0 1 r
.44691 .70435 m
.48444 .70966 L
s
.2 0 1 r
.68395 .67691 m
.77393 .66532 L
s
0 .4 1 r
.58031 .64399 m
.68017 .64076 L
s
.4958 .63772 m
.58031 .64399 L
s
.8 0 1 r
.53577 .70866 m
.47199 .70723 L
s
.61392 .6995 m
.53577 .70866 L
s
.47199 .70723 m
.44691 .70435 L
s
.2 0 1 r
.4539 .66854 m
.49011 .67374 L
s
0 .4 1 r
.68017 .64076 m
.76638 .62948 L
s
1 0 0 r
.7208 .74502 m
.63171 .77035 L
s
0 1 1 r
.58148 .60761 m
.67638 .60449 L
s
.5015 .60159 m
.58148 .60761 L
s
.2 0 1 r
.53387 .67241 m
.47598 .6711 L
s
.60499 .66395 m
.53387 .67241 L
s
.47598 .6711 m
.4539 .66854 L
s
0 .4 1 r
.4609 .63263 m
.4958 .63772 L
s
1 0 .6 r
.70501 .71121 m
.62283 .73497 L
s
0 1 1 r
.67638 .60449 m
.7588 .59354 L
s
0 1 .4 r
.58265 .57112 m
.67257 .56811 L
s
.50722 .56536 m
.58265 .57112 L
s
0 .4 1 r
.53197 .63605 m
.47998 .63485 L
s
.59603 .62831 m
.53197 .63605 L
s
.47998 .63485 m
.4609 .63263 L
s
.8 0 1 r
.68921 .67738 m
.61392 .6995 L
s
0 1 1 r
.46793 .59661 m
.5015 .60159 L
s
0 1 .4 r
.67257 .56811 m
.75121 .5575 L
s
.2 1 0 r
.58382 .53451 m
.66875 .53162 L
s
.51295 .52901 m
.58382 .53451 L
s
0 1 1 r
.53006 .59956 m
.484 .5985 L
s
.58705 .59257 m
.53006 .59956 L
s
.2 0 1 r
.67339 .64353 m
.60499 .66395 L
s
0 1 1 r
.484 .5985 m
.46793 .59661 L
s
0 1 .4 r
.47497 .56049 m
.50722 .56536 L
s
.2 1 0 r
.66875 .53162 m
.74359 .52136 L
s
0 .4 1 r
.65757 .60964 m
.59603 .62831 L
s
.8 1 0 r
.585 .49778 m
.66492 .49501 L
s
.51871 .49256 m
.585 .49778 L
s
0 1 .4 r
.52815 .56296 m
.48803 .56203 L
s
.57806 .55675 m
.52815 .56296 L
s
1 .6 0 r
.57542 .46442 m
.6031 .43024 L
s
0 1 .4 r
.48803 .56203 m
.47497 .56049 L
s
.2 1 0 r
.48203 .52427 m
.51295 .52901 L
s
.8 1 0 r
.66492 .49501 m
.73596 .48513 L
s
0 1 1 r
.64173 .57573 m
.58705 .59257 L
s
1 .6 0 r
.58618 .46092 m
.66107 .45829 L
s
.52448 .456 m
.58618 .46092 L
s
.8 1 0 r
.59814 .49357 m
.62831 .45712 L
s
.2 1 0 r
.52623 .52625 m
.49206 .52544 L
s
.56903 .52083 m
.52623 .52625 L
s
.49206 .52544 m
.48203 .52427 L
s
.8 1 0 r
.48912 .48795 m
.51871 .49256 L
s
0 1 .4 r
.62587 .54179 m
.57806 .55675 L
s
1 .6 0 r
.66107 .45829 m
.7283 .44879 L
s
.2 1 0 r
.62091 .52281 m
.65364 .48414 L
s
.8 1 0 r
.52431 .48941 m
.49612 .48874 L
s
.55999 .48483 m
.52431 .48941 L
s
1 .6 0 r
.49622 .45153 m
.52448 .456 L
s
.8 1 0 r
.49612 .48874 m
.48912 .48795 L
s
.2 1 0 r
.61 .50781 m
.56903 .52083 L
s
0 1 .4 r
.64375 .55212 m
.67908 .51128 L
s
1 .6 0 r
.52237 .45245 m
.50018 .45193 L
s
.55092 .44873 m
.52237 .45245 L
s
.8 1 0 r
.59412 .47381 m
.55999 .48483 L
s
1 .6 0 r
.50018 .45193 m
.49622 .45153 L
s
0 1 1 r
.66665 .58151 m
.70466 .53855 L
s
1 0 0 r
.79244 .70841 m
.7208 .74502 L
s
1 .6 0 r
.57823 .43979 m
.55092 .44873 L
s
1 0 .6 r
.77085 .67696 m
.70501 .71121 L
s
.8 0 1 r
.74929 .64557 m
.68921 .67738 L
s
0 .4 1 r
.68961 .61099 m
.73035 .56596 L
s
.2 0 1 r
.72777 .61422 m
.67339 .64353 L
s
0 .4 1 r
.70628 .58292 m
.65757 .60964 L
s
0 1 1 r
.68483 .55168 m
.64173 .57573 L
s
.2 0 1 r
.71264 .64054 m
.75617 .5935 L
s
0 1 .4 r
.66341 .52048 m
.62587 .54179 L
s
.2 1 0 r
.64202 .48933 m
.61 .50781 L
s
.8 1 0 r
.62067 .45823 m
.59412 .47381 L
s
1 .6 0 r
.59935 .42718 m
.57823 .43979 L
s
.8 0 1 r
.73572 .67018 m
.78211 .62117 L
s
1 0 .6 r
.75887 .6999 m
.80817 .64897 L
s
1 0 0 r
.78207 .72971 m
.83435 .67694 L
s
1 .6 0 r
.6031 .43024 m
.61288 .4131 L
s
.61118 .41538 m
.59935 .42718 L
s
.8 1 0 r
.63586 .44336 m
.62067 .45823 L
s
.62831 .45712 m
.63877 .4393 L
s
.2 1 0 r
.66063 .47145 m
.64202 .48933 L
s
0 1 .4 r
.68551 .49966 m
.66341 .52048 L
s
0 1 1 r
.71048 .52797 m
.68483 .55168 L
s
.2 1 0 r
.65364 .48414 m
.6648 .46563 L
s
0 .4 1 r
.73556 .55641 m
.70628 .58292 L
s
1 .6 0 r
.61288 .4131 m
.61118 .41538 L
s
.2 0 1 r
.76074 .58496 m
.72777 .61422 L
s
.8 0 1 r
.78603 .61363 m
.74929 .64557 L
s
0 1 .4 r
.67908 .51128 m
.69098 .49212 L
s
1 0 .6 r
.81142 .64241 m
.77085 .67696 L
s
.8 1 0 r
.63877 .4393 m
.63586 .44336 L
s
1 0 0 r
.83691 .67132 m
.79244 .70841 L
s
0 1 1 r
.70466 .53855 m
.71729 .51875 L
s
.2 1 0 r
.6648 .46563 m
.66063 .47145 L
s
0 1 .4 r
.69098 .49212 m
.68551 .49966 L
s
0 .4 1 r
.73035 .56596 m
.74375 .54552 L
s
0 1 1 r
.71729 .51875 m
.71048 .52797 L
s
.2 0 1 r
.75617 .5935 m
.77036 .57244 L
s
0 .4 1 r
.74375 .54552 m
.73556 .55641 L
s
.8 0 1 r
.78211 .62117 m
.79711 .59951 L
s
.2 0 1 r
.77036 .57244 m
.76074 .58496 L
s
1 0 .6 r
.80817 .64897 m
.82401 .62673 L
s
.8 0 1 r
.79711 .59951 m
.78603 .61363 L
s
1 0 0 r
.83435 .67694 m
.85105 .65412 L
s
1 0 .6 r
.82401 .62673 m
.81142 .64241 L
s
1 0 0 r
.85105 .65412 m
.83691 .67132 L
s
0 g
.25 Mabswid
.53391 0 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.53391 0 m
.02642 .19522 L
s
.02642 .19522 m
.53391 0 L
s
.02642 .19522 m
.03116 .2 L
s
[(-2)] .01694 .18568 .99384 1 Mshowa
.14712 .14879 m
.15172 .1537 L
s
[(-1)] .13793 .13897 .93651 1 Mshowa
.2718 .10083 m
.27624 .10588 L
s
[(0)] .26292 .09073 .87917 1 Mshowa
.40066 .05126 m
.40493 .05646 L
s
[(1)] .39212 .04087 .82184 1 Mshowa
.53391 0 m
.538 .00534 L
s
[(2)] .52574 -0.01069 .7645 1 Mshowa
.125 Mabswid
.05025 .18606 m
.05308 .18894 L
s
.07424 .17683 m
.07705 .17973 L
s
.09837 .16755 m
.10117 .17046 L
s
.12267 .1582 m
.12545 .16113 L
s
.17173 .13933 m
.17447 .14229 L
s
.19651 .1298 m
.19923 .13278 L
s
.22144 .1202 m
.22414 .1232 L
s
.24654 .11055 m
.24922 .11356 L
s
.29723 .09105 m
.29988 .0941 L
s
.32283 .0812 m
.32546 .08427 L
s
.3486 .07129 m
.35121 .07437 L
s
.37455 .06131 m
.37713 .06441 L
s
.42695 .04115 m
.4295 .04428 L
s
.45342 .03096 m
.45594 .03412 L
s
.48007 .02071 m
.48257 .02388 L
s
.5069 .01039 m
.50938 .01358 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 265.125},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001Bb000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00`oooool5o`000:3ooooo0033ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@0X?ooool00<Cooooo00?oV9RHob4Q8Oo^k^h0XOooool00<Gooooo00?oV9RH
ob4Q8Oo^k^h0X?ooool00<Kooooo00?oMgMgofIVI_ooool0Woooool00<Oooooo00?o0000oooooooo
ool0W_ooool00<?ooooo00Go0000okZj^_ooooooV9RHoa0@402Pooooo`00`oooool01OnHV9So410@
o`000?lQ8B7oc<c<0:3ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003;ooooo`;o0000Voooool00<Sooooo0ol000000ooooooo0000ooooo`2Jooooo`00a_oo
ool2o`0000Cooooo0_l0002Jooooo`00`oooool3o`0000Kooooo00?o0000ooooool00000VOooool0
0<3ooooo1?l00008ooooo`04o`000?ooooooooooo`0009Sooooo002Hooooo`Co000000?o410@oooo
ooooool07oooool2o`0000Cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0002H
ooooo`00V_ooool00ol0003oooooooooo`0Nooooo`?o00003_ooool01Ol0003ooooooooooooooooo
000009Oooooo002Jooooo`03o`000?oooooooooo01cooooo0_l0000Aooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0U?ooool009[ooooo00?o0000ooooooooool06Oooool3o`0000;o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo09?o
oooo002Jooooo`03o`000?oooooooooo01Kooooo0ol0000Fooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^08Kooooo002Jooooo`03o`00
0?oooooooooo01Cooooo0_l0000Iooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1oooool01OmgMgOoV9RHoooooonHV9SoMgMg08Kooooo002Jooooo`03o`000?oooooooooo017ooooo
0ol000000ooooooo0000ooooo`0Hooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1_ooool01Ol@413ooooooooooooooooo410@08Kooooo002Hooooo`03oeEEEOmVIVKo0000017ooooo
0_l0000Nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool01Ol0003ooooo
oooooooooooo000008Kooooo002Yooooo`?o00008?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000026ooooo`00Yoooool3o`0002;ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@
4100Q_ooool00:Cooooo0ol00002ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Q_ooool00:7ooooo
0ol0000Xooooo`03o`000?oooooooooo00Sooooo0_l00004ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h0Q_ooool009oooooo0_l0000[ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo
0000S_ooool009cooooo0ol000000ooooooo0000ooooo`0Zooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0S?ooool009[ooooo0_l00005ooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`2;ooooo`00Uoooool3o`0003;ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`2:ooooo`00K?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^02?ooooo0ol000000ooooooo0000ooooo`0booooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0ROooool006cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Qooooo`;o0000>?ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo08Wooooo001/ooooo`05oa0@4?oooooooooo
ooooool@41007_ooool3o`0003[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`28
ooooo`00K?ooool01Ol0003ooooooooooooooooo000001cooooo0ol0000looooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0Qoooool006cooooo00Go0000ooooooooooooooooo`00000I
ooooo`?o00000_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool0Q_ooool006cooooo00Go410@oooooooooooooooooa0@400Gooooo`;o0000@_ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo08Kooooo001/ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL05?ooool3o`0004Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`25
ooooo`00K?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^017ooooo0ol00002ooooo`03o`000?oooooo
oooo04;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`24ooooo`00P?ooool2o`00
04[ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`23ooooo`00OOooool3o`0004co
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`22ooooo`00Noooool2o`000003oooo
ool0003ooooo04cooooo00?o0000ooooooooool05?ooool2o`0008?ooooo001hooooo`?o0000DOoo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooo000008?ooooo001eooooo`?o0000E?ooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo083ooooo001cooooo`Co0000EOooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo07oooooo001`ooooo`?o00001?ooool00ol0003o
ooooooooo`1Booooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0Ooooool006kooooo
0_l0001Looooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0O_ooool004?ooooo1?l0
00000ol@413oooooooooo`0Qooooo`?o0000G_ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo07gooooo0015ooooo`03o`000?oooooooooo023ooooo0ol00003ooooo`03o`000?oooooo
oooo05_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1looooo`00>_ooool6o`00
00Gooooo00?o0000ooooooooool07_ooool2o`0006Cooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`1looooo`00AOooool00ol0003oooooooooo`0Kooooo`?o0000I_ooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo07_ooooo0015ooooo`03o`000?oooooooooo01Wooooo
0_l00002ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`1jooooo`00AOooool00ol0003oooooooooo`0Fooooo`?o0000Joooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo07Wooooo0015ooooo`03o`000?oooooooooo01Cooooo0_l0001^
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0NOooool004?ooooo00?oEEEEofIV
I_l000004oooool3o`000003ooooool0003ooooo06gooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`1hooooo`00E_ooool3o`0007?ooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`1gooooo`00E?ooool2o`0007Kooooo00?o0000ooooooooool07oooool2o`0007Sooooo
001Aooooo`?o000000?oooooo`000?ooool0MOooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo07Kooooo001?ooooo`;o0000Noooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo07Gooooo001<ooooo`?o0000OOooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
07Cooooo0019ooooo`Co0000Ooooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo07?o
oooo0017ooooo`;o00001?ooool00ol0003oooooooooo`1looooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool0L_ooool004Cooooo0ol00025ooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool0L_ooool001[ooooo1Ol0000Sooooo`?o0000Qoooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo077ooooo000Jooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@08?ooool3
o`0000?ooooo00?o0000ooooooooool0Q?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo073ooooo000Booooo`Ko00000oooool00onHV9So8B4Qonk^kP0Oooooo`;o0000SOooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo06oooooo000Looooo`03oiRHV?lQ8B7ok^k^01_o
oooo0ol0002?ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0Koooool001gooooo
00?oMgMgofIVI_ooool05oooool3o`0000?ooooo00?o0000ooooooooool0S?ooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooooooo06kooooo000Nooooo`03o`000?oooooooooo01Cooooo0_l0
002Eooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0KOooool001[ooooo00Go0000
okZj^_ooooooV9RHoa0@400Cooooo`?o0000Uoooool00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo06cooooo000Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`04Oooool2o`0000?ooooo00?o
0000ooooooooool0U?ooool00ol0003oooooooooo`0Zooooo`;o0000KOooool002gooooo0ol0002L
ooooo`03o`000?oooooooooo02[ooooo0_l0001]ooooo`00:_ooool3o`0009oooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`1Zooooo`00:?ooool2o`0000?ooooo00?o0000oooooooo
ool0W?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo06Wooooo000Uooooo`?o0000
Y?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo06Wooooo000Tooooo`03o`000?oo
oooooooo0:Gooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1Xooooo`006_ooool4
o`000003oa0@4?oooooooooo00?ooooo0_l0002Vooooo`03o`000?oooooooooo02oooooo00?o0000
ooooooooool0Ioooool001cooooo00?o0000ooooooooool01Oooool2o`000:Kooooo00?o0000oooo
ooooool0<?ooool00ol0003oooooooooo`1Vooooo`004Oooool6o`0000Gooooo00?o0000oooooooo
ool01?ooool4o`000:Gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`08ooooo`Go
0000FOooool001cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0002Tooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool01OnHV9So8B4Qonk^k_ooooooA4A4
05Wooooo000Looooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`2Qooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool01oooool00onHV9So
8B4Qonk^kP1Jooooo`007?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0X?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Oooooo
00?oV9RHob4Q8Oo^k^h0FOooool001cooooo00?o0000ooooooooool01?ooool2o`0000Gooooo00?o
0000ooooooooool0Woooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Oooooo00?o
MgMgofIVI_ooool0F?ooool001[ooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo09kooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo05Oooooo000Sooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0WOooool00ol0003oooooooooo`0eooooo`;o00001?ooool01Ol0003o^[ZjoooooonHV9So
410@05Wooooo000Sooooo`;o00002?ooool00ol0003oooooooooo`2Looooo`03o`000?oooooooooo
03?ooooo0_l000000ooooooo0000ooooo`03ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0FOooool0
02?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2Kooooo`03o`000?oooooooooo
03Oooooo00?o0000ooooooooool0Goooool002?ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`2Jooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0Goooool002?ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`2Hooooo`;o0000>_ooool00ol0003ooooo
ooooo`1Nooooo`008_ooool2o`0000gooooo00?o0000ooooooooool0U?ooool3o`000003ooooool0
003ooooo03[ooooo00?o0000ooooooooool0GOooool002;ooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`2@ooooo`?o00001Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooo
oooo05cooooo000Rooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0S?ooool3o`00
00Wooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1Looooo`008_ooool3o`0000oo
oooo00?o0000ooooooooool0R?ooool3o`0000gooooo00?o0000ooooooooool0>?ooool00ol0003o
ooooooooo`1Kooooo`008_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo08Gooooo
0_l0000Aooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0F_ooool002;ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`21ooooo`?o00005?ooool00ol0003ooooooooo
o`0hooooo`03o`000?oooooooooo05Wooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool0OOooool3o`0001Oooooo00?o0000ooooooooool0>?ooool00ol0003ooooo
ooooo`1Iooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1iooooo`?o0000
6oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo05Sooooo0005o`0000;ooooo00Go
410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`1eooooo`?o00007oooool00ol0003oooooooooo`0hooooo`03o`00
0?oooooooooo05Oooooo0007ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8b
ooooo`03ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0LOooool3o`0002?ooooo
00?o0000ooooooooool0=oooool2o`0005Sooooo0007ooooo`05o`000?ooooooooooooooool00000
3?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`1^ooooo`;o00009oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo05Go
oooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`;o
00006Oooool00ol0003oooooooooo`1Zooooo`?o0000:_ooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo05Gooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0I_ooool3o`0002go
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1Dooooo`001oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool0H_ooool3o`00037ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1Cooooo`00
8Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo05kooooo0ol0000eooooo`03o`00
0?oooooooooo03Sooooo00?o0000ooooooooool0D_ooool0023ooooo0ol0000Mooooo`03o`000?oo
oooooooo05_ooooo0_l0000iooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0D_oo
ool0027ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1Gooooo`?o0000??ooool0
0ol0003oooooooooo`0gooooo`03o`000?oooooooooo057ooooo000Pooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool0Doooool3o`00043ooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`1@ooooo`008?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo04oo
oooo0ol00013ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0Coooool0023ooooo
0_l0000Rooooo`03o`000?oooooooooo04_ooooo0ol00017ooooo`03o`000?oooooooooo03Oooooo
00?o0000ooooooooool0Coooool0023ooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`18ooooo`;o0000Boooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo04kooooo000P
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0A?ooool3o`0004kooooo00?o0000
ooooooooool0=oooool00ol0003oooooooooo`1=ooooo`008?ooool3o`0002Cooooo00?o0000oooo
ooooool0@?ooool3o`0005;ooooo00?o0000ooooooooool0=_ooool2o`0004kooooo000Pooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0??ooool3o`0005Kooooo00?o0000oooooooo
ool0=_ooool00ol0003oooooooooo`1<ooooo`005?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oo
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0hooooo`?o0000FOooool00ol0003o
ooooooooo`0gooooo`03o`000?oooooooooo04_ooooo000Dooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo03Gooooo0_l0001Mooooo`03
o`000?oooooooooo03Oooooo00?o0000ooooooooool0B_ooool001Cooooo00Go410@oooooooooooo
oooooa0@4006ooooo`;o0000:_ooool00ol0003oooooooooo`0aooooo`?o0000H?ooool00ol0003o
ooooooooo`0gooooo`03o`000?oooooooooo04Wooooo000Dooooo`05o`000?ooooooooooooooool0
00001_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo02gooooo0ol0001Tooooo`03
o`000?oooooooooo03Kooooo00?o0000ooooooooool0BOooool001Cooooo00Go0000oooooooooooo
ooooo`000006ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0:Oooool3o`0006So
oooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`18ooooo`005?ooool01Ol@413ooooo
oooooooooooo410@00Kooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Uooooo`?o
0000K?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo04Oooooo000Dooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool2o`0002kooooo00?o0000ooooooooool08Oooool3o`0006oo
oooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`16ooooo`005?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Nooooo`;o
0000Loooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo04Gooooo000Oooooo`03o`00
0?oooooooooo02oooooo00?o0000ooooooooool06_ooool3o`0007Kooooo00?o0000ooooooooool0
=_ooool00ol0003oooooooooo`15ooooo`007_ooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo01Kooooo0ol0001jooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0A?oo
ool001kooooo0_l0000cooooo`03o`000?oooooooooo01;ooooo0ol0001nooooo`03o`000?oooooo
oooo03Kooooo0_l00014ooooo`007_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo
00kooooo0ol00022ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooool00000A?ooool001ko
oooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0;ooooo`;o0000QOooool00ol0003o
ooooooooo`0fooooo`03o`000?oooooooooo04;ooooo000Nooooo`03o`000?oooooooooo03Gooooo
00?o0000ooooooooool01oooool3o`0008Sooooo00?o0000ooooooooool0=_ooool00ol0003ooooo
ooooo`11ooooo`007_ooool2o`0003Oooooo00?o0000ooooooooool00oooool3o`0008cooooo00?o
0000ooooooooool0=_ooool00ol0003oooooooooo`10ooooo`007_ooool00ol0003oooooooooo`0g
ooooo`03o`000?oooooo000000;o0000T?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooo
oooo03oooooo000Nooooo`03o`000?oooooooooo03Kooooo0ol0002Dooooo`03o`000?oooooooooo
03Gooooo00?o0000ooooooooool0?oooool001kooooo0_l0000eooooo`;o00000oooool00ol0003o
ooooooooo`2Booooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool02Oooool2o`000003
oa0@4?oooooooooo033ooooo000Mooooo`03o`000?oooooooooo03;ooooo0ol00006ooooo`03o`00
0?oooooooooo097ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo037ooooo0002ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo
00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo02oooooo0ol0000:ooooo`03
o`000?oooooooooo097ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`05ooooo`Go
0000<_ooool000;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo
<S8booooo`04ooooo`03o`000?oooooooooo02cooooo0ol0000>ooooo`03o`000?oooooooooo097o
oooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`05ooooo`04odA4A?oMgMgoooooo`00
03?ooooo0002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03oooo
o`;o0000:_ooool3o`0001;ooooo00?o0000ooooooooool0TOooool00ol0003oooooooooo`0eoooo
o`03o`000?oooooooooo00Cooooo00CogMgMoeEEEOoooooo0000<oooool000;ooooo00Go0000oooo
ooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool09oooool2
o`0001Kooooo00?o0000ooooooooool0TOooool00ol0003oooooooooo`0eooooo`03o`000?oooooo
oooo00Cooooo00?oMgMgolc<c?l00000<oooool000;ooooo00Go0000ooooooooooooooooo`00000<
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Tooooo`?o00006Ooo
ool00ol0003oooooooooo`2Aooooo`03o`000?oooooooooo03Cooooo0_l00005ooooo`03onk^k_m4
A4Co000003?ooooo0002ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo027ooooo0ol0000Mooooo`03o`000?oooooooooo093ooooo00?o
0000ooooooooool0<oooool01?l0003oooooooooool00005ooooo`03ogMgMol0003ooooo03;ooooo
0002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`;o0000
7oooool3o`00027ooooo00?o0000ooooooooool0T?ooool00ol0003oooooooooo`0eooooo`03o`00
0?oooooooooo03Sooooo0002ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo
00?o0000ooooooooool07?ooool3o`0002Gooooo00?o0000ooooooooool0T?ooool00ol0003ooooo
ooooo`0eooooo`03o`000?oooooooooo03Oooooo000Looooo`03o`000?oooooooooo01Wooooo0ol0
000Yooooo`03o`000?oooooooooo093ooooo00?o0000ooooooooool0=Oooool00ol0003ooooooooo
o`0fooooo`007?ooool00ol0003oooooooooo`0Gooooo`;o0000;Oooool00ol0003oooooooooo`2@
ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0=Oooool001cooooo0_l0000Eoooo
o`?o0000<?ooool00ol0003oooooooooo`2@ooooo`03o`000?oooooooooo03Cooooo00?o0000oooo
ooooool0=Oooool001cooooo00?o0000ooooooooool04Oooool3o`0003Cooooo00?o0000oooooooo
ool0Soooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo03Cooooo000Looooo`03o`00
0?oooooooooo00kooooo0ol0000hooooo`03o`000?oooooooooo08oooooo00?o0000ooooooooool0
=Oooool00ol0003oooooooooo`0cooooo`007?ooool00ol0003oooooooooo`0;ooooo`?o0000??oo
ool00ol0003oooooooooo`2?ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0<_oo
ool001cooooo0_l0000:ooooo`;o0000@?ooool00ol0003oooooooooo`2?ooooo`03o`000?oooooo
oooo03Cooooo00?o0000ooooooooool0<_ooool001_ooooo0_l00008ooooo`?o0000@oooool00ol0
003oooooooooo`1hooooo`03oonI0?oooooooooo01Cooooo00?o0000ooooooooool0=?ooool00ol0
003oooooooooo`0aooooo`006oooool00ol0003oooooooooo`04ooooo`?o0000Aoooool00ol0003o
ooooooooo`1gooooo`03oonI0?oooooooooo01Gooooo00?o0000ooooooooool0<oooool2o`0003;o
oooo000Kooooo`04o`000?ooooooooooooooo`?o0000Boooool00ol0003oooooooooo`1eooooo`03
oonI0?oooooooooo01Kooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0_ooooo`00
6oooool4o`0004oooooo00?o0000ooooooooool0Loooool2oonI01Wooooo00?o0000ooooooooool0
=?ooool00ol0003oooooooooo`0_ooooo`006oooool2o`0005;ooooo00?o0000ooooooooool0LOoo
ool2oonI01_ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0^ooooo`004Oooool4
o`000003oa0@4?oooooooooo00Gooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`1^
ooooo`;ooiT000?ooooooonI0?ooool06oooool00ol0003oooooooooo`0dooooo`03o`000?oooooo
oooo02gooooo000Cooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool0D?ooool00ol0
003oooooooooo`1[ooooo`;ooiT00_ooool00oooV@3oooooooooo`0Looooo`03o`000?oooooooooo
03Cooooo00?o0000ooooooooool0;?ooool001?ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`1@ooooo`03o`000?oooooooooo06Wooooo00?ooiT0ooooooooool00_ooool00oooV@3o
ooooooooo`0Mooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool0;?ooool001?ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo06Kooooo
0_ooV@04ooooo`03oonI0?oooooooooo01kooooo00?o0000ooooooooool0=?ooool00ol0003ooooo
ooooo`0[ooooo`004oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo053ooooo00?o
0000ooooooooool0Hoooool2oonI00Gooooo00?ooiT0ooooooooool02oooool00oo<o`3ooooooooo
o`0Booooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0:_ooool001?ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo05oooooo0oooV@06
ooooo`03oonI0?oooooooooo00_ooooo0_o<o`0Eooooo`03o`000?oooooooooo03Cooooo00?o0000
ooooooooool0:Oooool001?ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`1@oooo
o`03o`000?oooooooooo05_ooooo0oooV@08ooooo`03oonI0?oooooooooo00_ooooo0_o<o`0Goooo
o`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0:?ooool0017ooooo00?oEEEEofIVI_l0
00004?ooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo05?ooooo1oooV@0:ooooo`03
oonI0?oooooooooo00_ooooo0_o<o`0Iooooo`03o`000?ooV@3ooiT000?ooiT0<?ooool00ol0003o
ooooooooo`0Xooooo`009Oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo04Gooooo
3OooV@0Aooooo`03oonI0?oooooooooo00[ooooo00?oc?l0ooooooo<o`004oooool7oonI0003o`00
0?oooooooooo03;ooooo0_l0000Yooooo`009_ooool2o`00057ooooo00?o0000ooooooooool0B_oo
ool9oonI00kooooo00?ooiT0ooooooooool02_ooool00oo<o`3oooooolco000=ooooo`OooiT01ooo
ool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02Kooooo000Xooooo`03o`000?oooooo
oooo04kooooo00?o0000ooooooooool0Doooool:oonI00?ooooo00?ooiT0ooooooooool02Oooool2
olco0003oonI0?o<o`3ooiT000gooiT03oooool00ol0003oooooooooo`0dooooo`03o`000?oooooo
oooo02Gooooo000Yooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0G?ooool=oonI
00;oc?l00_ooV@000oooooooc?l0ooooo`0Mooooo`03o`000?oooooooooo03?ooooo00?o0000oooo
ooooool09Oooool002[ooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`1Kooooo`;o
oiT02Oooool2olco00Cooooo00?oc?l0ooooooooool02_ooool00olco`3oooooooooo`0Aooooo`03
o`000?oooooooooo03?ooooo00?o0000ooooooooool09?ooool002_ooooo00?o0000ooooooooool0
C_ooool00ol0003oooooooooo`1Iooooo`03oonI0?oooooooooo00Sooooo00?oc?l0ooooooooool0
0oooool00oo<o`3oooooooooo`0;ooooo`03oc?o0?oooooooooo01;ooooo00?o0000ooooooooool0
<oooool00ol0003oooooooooo`0Sooooo`00;?ooool00ol0003oooooooooo`1>ooooo`03o`000?oo
oooooooo05Oooooo00?ooiT0ooooooooool01oooool2olco00Gooooo00?oc?l0ooooooooool02ooo
ool00olco`3oooooooooo`0Dooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool08_oo
ool002gooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`1Eooooo`03oonI0?oooooo
oooo00Kooooo0_o<o`06ooooo`03olco0?oooooooooo00_ooooo0_lco`0Fooooo`03o`000?oooooo
oooo03?ooooo00?o0000ooooooooool08_ooool002kooooo00?o0000ooooooooool0C_ooool00ol0
003oooooooooo`1Booooo`;ooiT01_ooool3olco00Oooooo00?oc?l0ooooooooool02oooool2oc?o
01Sooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Qooooo`00;oooool00ol0003o
ooooooooo`1>ooooo`03o`000?oooooooooo053ooooo00?ooiT0ooooooooool00oooool3olco00[o
oooo00?oc?l0ooooooooool02_ooool00olco`3ooooooc?o000Iooooo`03o`000?oooooooooo03?o
oooo00?o0000ooooooooool08?ooool0033ooooo00?o0000ooooooooool0C_ooool00ol0003ooooo
ooooo`1>ooooo`04oonI0?ooooooooooooooo`?oc?l03?ooool00oo<o`3oooooooooo`0:ooooo`04
oc?o0?oooooooooooc?o01[ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Ooooo
o`00<Oooool2o`0004oooooo00?o0000ooooooooool0B_ooool7olco00kooooo00?oc?l0oooooooo
ool02_ooool01?lco`3ooooooooooolco`0Fooooo`Goc?l000?oooooo`000?ooool0<oooool2o`00
023ooooo000cooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0=ooooolBolco00;o
oiT04_ooool00oo<o`3oooooooooo`09ooooo`;o<ol00oooool00olco`3oooooooooo`0<ooooo`So
c?l01oooool00ol0003oooooooooo`0aooooo`;o00008?ooool003Cooooo00?o0000ooooooooool0
COooool00ol0003oooooooooo`0looooo`_oc?l000?ooiT0ooooooooool04Oooool00oo<o`3ooooo
ooooo`08ooooo`;o<ol01?ooool00olco`3oooooooooo`05ooooo`Goc?l000?o0?mVolco0?o<o`00
3oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo01gooooo000eooooo`03o`000?oo
oooooooo04gooooo00?o0000ooooooooool0AOooool00oooV@3oc?l0olco0009olco00Oooooo0_o<
o`08ooooo`03olco0?lco`3o<ol000Goc?l000?o<ol0olco0?o<o`001_o<o`05ooooo`03o`3oI_oo
oooooooo013ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Looooo`00=_ooool0
0ol0003oooooooooo`1=ooooo`03o`000?oooooooooo04?ooooo00?ooiT0ooooooooool02_oooolA
olco0003oc?o0?oooooooooo00Cooooo00?o<ol0ooooooooool02oooool00ol0ofKoooooooooo`0B
ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool07?ooool003Oooooo00?o0000oooo
ooooool0COooool00ol0003oooooooooo`10ooooo`;ooiT04_ooool00oo<o`3oooooooooo`07oooo
o`;o<ol01_ooool00olco`3oooooooooo`0;ooooo`;o0?mV5Oooool00ol0003oooooooooo`0boooo
o`03o`000?oooooooooo01_ooooo000hooooo`03o`000?oooooooooo04gooooo00?o0000oooooooo
ool0?Oooool2oonI01;ooooo0_o<o`08ooooo`;o<ol01oooool00olco`3oooooooooo`0;ooooo`;o
0?mV5oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00Oooooo00Gok^k^oc8b<_l0
003o410@olc<c00>ooooo`00>Oooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo03_o
oooo00?ooiT0ooooooooool04Oooool00oo<o`3oooooooooo`06ooooo`;o<ol02?ooool00olco`3o
ooooooooo`0;ooooo`;o0?mV6Oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00Ko
oooo00GoEEEEogMgMoooooooV9RHob4Q8@0>ooooo`00>_ooool00ol0003oooooooooo`1=ooooo`03
o`000?oooooooooo03Sooooo0_ooV@0Cooooo`03olco0?oooooooooo00Cooooo0olco`09ooooo`03
oc?o0?oooooooooo00_ooooo00?o0?mVooooool0ofH06Oooool00ol0003oooooooooo`0cooooo`03
o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`00000>ooooo`00>oooool00ol0003o
ooooooooo`1=ooooo`03o`000?oooooooooo03Gooooo0_ooV@0Cooooo`;oc?l01?ooool3oc?o00_o
oooo00?o<ol0ooooooooool02oooool00ol0ofKoooooo`3oIP0Kooooo`03o`000?oooooooooo03;o
oooo00?o0000ooooooooool01Oooool01Ol0003oV9RHoooooonHV9So8B4Q00kooooo000looooo`03
o`000?oooooooooo04gooooo00?o0000ooooooooool0<_ooool2oonI01Cooooo00?oc?l0oooooooo
ool00_ooool2oc?o00gooooo00?o<ol0ooooooooool02oooool01?l0ofKoooooooooool0ofHLoooo
o`03o`000?oooooooooo03;ooooo00?o0000ooooooooool01?ooool01Ol0003oEEEEo`000?l@413o
c<c<00kooooo000mooooo`;o0000C_ooool00ol0003oooooooooo`0_ooooo`;ooiT05Oooool00oo<
o`3oooooooooo`03oc?o00kooooo00?o<ol0ooooooooool02oooool01?l0ofKoooooooooool0ofH=
ooooo`03o`3ooooooooooooo00kooooo00?o0000ooooooooool0<_ooool2o`0000Cooooo00?oEEEE
ohN7Qoooool04?ooool003oooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0]oooo
o`03oonI0?oooooooooo01?ooooo1Olco`0?ooooo`;o<ol03?ooool2o`3oIP;ooooo00?o0?mVoooo
ooooool03?ooool00ol0ooooooooooooo`02ooooo`Go<ol02?ooool00ol0003oooooooooo`0_oooo
o`;o000000?oooooo`000?ooool00oooool00ooMgMgo410@oiRHV00@ooooo`00@?ooool00ol0003o
ooooooooo`1<ooooo`03o`000?oooooooooo02Wooooo2_lco`08ooooo`Oo<ol04oooool00olco`3o
ooooooooo`0:ooooo`;o0?mV0oooool00ol0ofKoooooooooo`09ooooo`?o<ol000?o0?oooc?o0?lc
o`000olco`0>ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool00oooool01?o<c<co
A4A4o`000?l@410>ooooo`00@Oooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo02So
oooo00?ooiT0ooooooooool00oooool<oc?o00Gooooo00?oc?l0ooooooooool04Oooool00olco`3o
ooooooooo`09ooooo`;o0?mV1?ooool00ol0ofKoooooooooo`02ooooo`So<ol000Coooooo`3oool0
oooo0?oo4oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01Cooooo0012ooooo`03
o`000?oooooooooo04cooooo00?o0000ooooooooool0>?ooool<oc?o00gooooo00?o<ol0oooooooo
ool00oooool5oc?o00;o0?mV1Olco`000ol0ofKo<ol0oc?o0003oc?o00Sooooo00?o0?ooooooool0
ool05Oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01?ooooo0013ooooo`03o`00
0?oooooooooo04cooooo00?o0000ooooooooool0>_ooool00oo<o`3oooooooooo`06oooooa?o<ol0
1?ooool00ol0ofKoooooooooo`04ooooo`03o`3oI_oooooooooo00_ooooo00?o0?ooooooool0ool0
5oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01;ooooo0014ooooo`03o`000?oo
oooooooo04cooooo00?o0000ooooooooool0=oooool2olco01?ooooo0_lco`09ooooo`;o0?mV1_oo
ool00ol0ofKoooooooooo`0;ooooo`04o`3oooooooooooooo`3ooaSooooo00?o0000ooooooooool0
<Oooool00ol0003oooooooooo`0Booooo`00AOooool00ol0003oooooooooo`1<ooooo`03o`000?oo
oooooooo03Cooooo0_o<o`0Dooooo`03oc?o0?oooooooooo00Oooooo0_l0ofH7ooooo`03o`3oI_oo
oooooooo00_ooooo00Co0?oooooooooooooo0?oo6_ooool00ol0003oooooooooo`0aooooo`03o`00
0?oooooooooo017ooooo0016ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0<_oo
ool00oo<o`3oooooooooo`0Cooooo`03oc?o0?oooooooooo00Kooooo0_l0ofH8ooooo`03o`3oI_oo
oooooooo00_ooooo00Go0?ooooooooooooooooooo`3oo`0Kooooo`03o`000?oooooooooo037ooooo
00?o0000ooooooooool04?ooool004Oooooo00?o0000ooooooooool0C?ooool00ol0003ooooooooo
o`0_ooooo`;oc?l05Oooool00olco`3oooooooooo`04ooooo`?o0?mV2Oooool00ol0ofKooooooooo
o`0;ooooo`05o`3oooooooooooooooooool0ool03Oooool00ol0I_ooooooooooo`0<ooooo`03o`00
0?oooooooooo03;ooooo00?o0000ooooooooool03oooool004Sooooo0_l0001=ooooo`03o`000?oo
oooooooo02gooooo00?oc?l0ooooooooool04oooool2oc?o00Cooooo0ol0ofH;ooooo`03o`3oI_oo
oooooooo00_ooooo00Go0?ooooooooooooooooooo`3oo`0>ooooo`03o`1Voooooooooooo00gooooo
00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0?ooooo`00B_ooool00ol0003ooooooooo
o`1;ooooo`03o`000?oooooooooo02[ooooo0_o<o`0Eooooo`04oc?o0?ooooooooooooooo`?o0?mV
3?ooool2o`3oIPcooooo0_l0ool3ooooo`03o`3ooooooooooooo00cooooo00?o06Koooooooooool0
3oooool00ol0003oooooooooo`0aooooo`;o00003oooool004_ooooo00?o0000ooooooooool0Booo
ool00ol0003oooooooooo`0Wooooo`;oc?l05_ooool00olco`3oooooo`3oIP02o`3oIPkooooo00?o
0?mVooooooooool02_ooool2o`3oo`Cooooo00?o0?ooooooooooool03?ooool00ol0I_oooooooooo
o`0Aooooo`03o`000?oooooooooo033ooooo0_l0000?ooooo`00C?ooool00ol0003oooooooooo`1;
ooooo`03o`000?oooooooooo02Gooooo00?oc?l0ooooooooool04_ooool6o`3oIQ3ooooo00?o0?mV
ooooooooool02_ooool00ol0ooooooooooooo`03ooooo`03o`3ooooooooooooo00_ooooo0_l0I_l5
o`3oIQ3ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0<ooooo`00COooool00ol0
003oooooooooo`1;ooooo`03o`000?oooooooooo01[ooooo3Ol0ofH9ooooo`Wo0?mV0_ooool00olc
o`3oooooooooo`0?ooooo`;o0?mV2oooool2o`3oo`Gooooo00?o0?ooooooooooool01Oooool6o`3o
IP03o`1Vool0ofKo06Ko01Kooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0;oooo
o`00C_ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo01gooooo1Ol0ofH4ooooo`Wo
0?mV2Oooool2oc?o017ooooo00?o0?mVooooooooool02Oooool2o`3oo`Kooooo00?o0?ooo`3oI_l0
ofH01_l0ofH5ooooo`03o`1Voooooooo06Ko01Oooooo00?o0000ooooooooool0<Oooool00ol0003o
ooooooooo`0;ooooo`00Coooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo027ooooo
4?l0ofH4ooooo`;o<ol04_ooool00ol0ofKoooooo`3oIP08o`3oIP;o0?oo1ol0ofH00ol0oooooooo
ooooo`0;ooooo`03o`1Voooooooo06Ko01Wooooo00?o0000ooooooooool0<Oooool00ol0003ooooo
ooooo`0:ooooo`00D?ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo033ooooo6_l0
ofH8ooooo`03o`3ooooooooooooo00Kooooo00?o0?ooooooooooool02_ooool2o`1Vo`;ooooo00?o
06Koooooooooool06?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Wooooo001A
ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0;oooool2oc?o01?ooooo0_l0ofH9
ooooo`;o0?oo2?ooool00ol0ooooooooooooo`0:ooooo`05o`1Vooooooooooooooooool0I_l03Ooo
ool00olc0?ooooooooooo`0<ooooo`03o`000?oooooooooo037ooooo00?o0000ooooooooool02?oo
ool005;ooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0/ooooo`;o<ol05?ooool0
0ol0ofKoooooooooo`07ooooo`;o0?oo2Oooool00ol0ooooooooooooo`0:ooooo`05o`1Voooooooo
ooooooooool0I_l03_ooool00olc0?ooooooooooo`0=ooooo`03o`000?oooooooooo033ooooo00?o
0000ooooooooool02?ooool005?ooooo0_l0001<ooooo`03o`000?oooooooooo02Wooooo0_lco`0E
ooooo`03o`3oI_oooooooooo00Gooooo0ol0ool:ooooo`03o`3ooooooooooooo00[ooooo00Go06Ko
ooooooooooooooooo`1Vo`0>ooooo`03oc<0oooooooooooo00oooooo00?o0000ooooooooool0<?oo
ool00ol0003oooooooooo`07ooooo`00EOooool00ol0003oooooooooo`1:ooooo`03o`000?oooooo
oooo02Kooooo0_lco`0Eooooo`;o0?mV1Oooool3o`3oo`_ooooo0_l0ool;ooooo`;o06Ko0oooool0
0ol0I_ooooooooooo`0<ooooo`;o<`3o4Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooo
oooo00Kooooo001Fooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool08oooool2oc?o
01Kooooo00?o0?mVooooooooool00_ooool3o`3oo`gooooo00?o0?ooooooooooool02Oooool2o`1V
o`Cooooo00?o06Koooooooooool02oooool3oc<0oa?ooooo00?o0000ooooooooool0;oooool3o`00
00Oooooo001Gooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool08?ooool2oc?o01Oo
oooo00?o0?mVooooooooool00ol0ool?ooooo`03o`3ooooooooooooo00Wooooo00?o06Kooooooooo
ool00oooool00ol0I_ooooooooooo`0;ooooo`03oc<0oooooooo<`3o01Gooooo00?o0000oooooooo
ool0:oooool3o`0000;ooooo00?o0000ooooooooool01Oooool005Sooooo00?o0000ooooooooool0
B_ooool00ol0003oooooooooo`0Nooooo`03oc?o0?oooooooooo01Kooooo00Co0?mVo`3oool0oooo
0?oo4?ooool2o`3oo`[ooooo0_l0I_l5ooooo`03o`1Voooooooooooo00_ooooo00Co<`3ooooooooo
oooo<`3o5_ooool00ol0003oooooooooo`0Wooooo`?o00001Oooool00ol0003oooooooooo`05oooo
o`00FOooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo033ooooo1ol0oolBooooo`03
o`3ooooooooooooo00Sooooo0_l0I_l7ooooo`03o`1Voooooooooooo00[ooooo00Go<`3oo`3oool0
oooo<`3oo`3oo`0Gooooo`03o`000?oooooooooo02;ooooo1?l00008ooooo`03o`000?oooooooooo
00Gooooo001Jooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool03?ooool4o`3ooaKo
oooo2Ol0ool2ooooo`;o0?mV5?ooool00ol0ooooooooooooo`07ooooo`;o06Ko2?ooool00ol0I_oo
ooooooooo`05ooooo`Go0?oo00Co<`3oo`3ooooooooo<`3o6_ooool00ol0003oooooooooo`0Noooo
o`?o00003?ooool00ol0003oooooooooo`05ooooo`00Foooool00ol0003oooooooooo`1:ooooo`03
o`000?oooooooooo00oooooo5_l0ool9ooooo`;o0?mV5?ooool2o`3oo`Sooooo0_l0I_l9ooooo`03
o`1Voooooooo0?oo00Ko0?oo1?ooool01?lc0?oooooooooooolc0?l>ooooo`03ol`0oooooooooooo
00[ooooo00?o0000ooooooooool06_ooool4o`0000oooooo00?o0000ooooooooool01Oooool005co
oooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0Cooooo`[o0?oo3_ooool2o`3oIQGo
oooo00?o0?ooooooooooool01oooool00ol0I_ooooooooooo`04ooooo`Co0?oo00?o06Koo`3oool0
ool02_ooool01?lc0?oooooooooooolc0?l?ooooo`03ol`0oooooooooooo00_ooooo00?o0000oooo
ooooool05_ooool3o`0001Cooooo00?o0000ooooooooool01?ooool005gooooo00?o0000oooooooo
ool0B_ooool00ol0003oooooooooo`0Looooo`go0?oo00?o0?mVooooooooool04oooool:o`3oo`;o
06Ko1ol0ool3ooooo`03o`1Voooooooooooo00[ooooo00Co<`3ooooooooooooo<`3o3oooool00oo<
0?ooooooooooo`0=ooooo`03o`000?oooooooooo01;ooooo0ol0000Gooooo`03o`000?oooooooooo
00Cooooo001Nooooo`;o0000Boooool00ol0003oooooooooo`0Vooooo`03o`3oI_oooooo0?oo01Go
0?oo1oooool3o`1Vo`_ooooo00?o06Koooooooooool02_ooool01?lc0?oooooooooooolc0?l?oooo
o`03ol`0oooooooooooo00oooooo00?o0000ooooooooool03Oooool4o`0001[ooooo00?o0000oooo
ooooool01?ooool0063ooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0Sooooo`;o
0?mV5_ooool00ol0ooooooooooooo`03ooooo`?o06Ko3?ooool2o`1Vo`cooooo00Co<`3ooooooooo
oooo<`3o3oooool2ol`0oa;ooooo00?o0000ooooooooool02Oooool3o`0001kooooo00?o0000oooo
ooooool01?ooool0067ooooo00?o0000ooooooooool0BOooool00ol0003oooooooooo`0Pooooo`;o
0?mV5_ooool2o`3oo`?ooooo0ol0I_l>ooooo`03o`1Voooooooooooo00[ooooo0_lc0?l2ooooo`03
oc<0oooooooooooo00gooooo0_o<0?lDooooo`03o`000?oooooooooo00Cooooo1?l0000Qooooo`03
o`000?oooooooooo00Cooooo001Rooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0
7Oooool2o`3oIQOooooo00?o0?ooooooool0I_l00ol0I_l?ooooo`;o06Ko2oooool2oc<0o`?ooooo
00?o<`3oooooooooool03Oooool2ol`0oaGooooo00Co0000oooooooooooooooo0ol0000Uooooo`03
o`000?oooooooooo00Cooooo001Sooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0
6_ooool2o`3oIQSooooo0ol0I_lBooooo`03o`1Voooooooooooo00Wooooo0_lc0?l4ooooo`03oc<0
oooooooooooo00gooooo0_o<0?lGooooo`?o0000:?ooool00ol0003oooooooooo`04ooooo`00I?oo
ool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo01Sooooo00?o0?mVooooooooool05Ooo
ool3o`1VoaCooooo00?o06Koooooooooool02?ooool2oc<0o`Gooooo00?o<`3oooooooooool03?oo
ool2ol`0o`03ooooooo<0?oooooo01;ooooo1?l000000ooooooo0000ooooo`0Xooooo`03o`000?oo
oooooooo00Cooooo001Uooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool0:Oooool6
o`1Vo`03o`3ooooooooooooo01;ooooo0_l0I_l9ooooo`;o<`3o1_ooool00olc0?ooooooooooo`0<
ooooo`04ol`0oooooooooooool`0o`kooooo00?oo`2Iooooooooool00ol00006ooooo`03o`000?oo
oooooooo02Kooooo00?o0000ooooooooool01?ooool006Kooooo00?o0000ooooooooool0BOooool0
0ol0003oooooooooo`0Qooooo`Oo06Ko0oooool2o`3ooaGooooo00?o06Koooooooooool01oooool2
oc<0o`Oooooo00?o<`3oooooooooool02?ooool4o`1Vo`04ol`0oooooooooooool`0o`kooooo00Co
0000ool0VOl0003o00002_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Cooooo
001Wooooo`03o`000?oooooooooo04Wooooo00?o0000o`1Vool0I_l00_l0I_lGooooo`Oo06Ko2Ooo
ool00ol0ooooooooooooo`0Cooooo`;o06Ko2?ooool2oc<0o`Sooooo00?o<`3oooooooooool00_oo
ool7o`1Vo`?ooooo00Coc03oooooooooooooc03o3?ooool3o`000003ool0VOoooooooooo00cooooo
00?o0000ooooooooool09Oooool00ol0003oooooooooo`03ooooo`00J?ooool00ol0003ooooooooo
o`19ooooo`04o`000?oooooooooooooooaOo06Ko3_ooool2o`3ooaGooooo00?o06Koooooooooool0
1_ooool2oc<0o`Sooooo00?o06Kooc<0ool0I_l01?l0I_l8ooooo`;oc03o0_ooool00oo<0?oooooo
ooooo`08ooooo`?o00000_ooool00ooo09Woooooooooo`0=ooooo`03o`000?oooooooooo02Gooooo
00?o0000ooooooooool00oooool006Wooooo00?o0000ooooooooool0BOooool00ol0003ooooooooo
o`05ooooo`[o06Ko5?ooool2o`3ooaKooooo00?o06Koooooooooool01Oooool2oc<0o`?ooooo1ol0
I_l00olc0?ooooooooooo`0;ooooo`05ol`0ooooooooooooooooooo<0?l01oooool4o`0000Cooooo
00?oo`2Iooooooooool03oooool00ol0003oooooooooo`0Tooooo`03o`000?oooooooooo00?ooooo
001Zooooo`;o0000B_ooool00ol0003oooooooooo`0>ooooo`ko06Ko1?ooool2o`3ooa7ooooo3?l0
I_l3oc<0o`Go06Ko1Oooool00olc0?ooooooooooo`0<ooooo`05ol`0ooooooooooooooooooo<0?l0
1Oooool3o`0000Kooooo0ooo09TBooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0
0oooool006cooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0KoooooaOo06Ko1?oo
ool00ol0I_ooooooooooo`02ooooo`?o<`3o3?ooool00olc0?ooooooooooo`0;ooooo`;oc03o0ooo
ool00oo<0?ooooooooooo`04o`0000Sooooo00?oo`2Ioooooooo09T05?ooool00ol0003ooooooooo
o`0Rooooo`03o`000?oooooooooo00?ooooo001]ooooo`03o`000?oooooooooo04Sooooo00?o0000
ooooooooool06oooool00ol0ooooooooooooo`0Eooooo`;o06Ko0_ooool3oc<0o`gooooo0_lc0?l<
ooooo`;oc03o1?ooool01?o<0?oo0000o`000?l0000;ooooo`03ool0VOooooooo`2I01Kooooo00?o
0000ooooooooool08Oooool00ol0003oooooooooo`03ooooo`00K_ooool00ol0003oooooooooo`18
ooooo`03o`000?oooooooooo01Sooooo0_l0oolGooooo`03o`1Voooooooo<`3o00;o<`3o3oooool0
0olc0?ooooooooooo`0:ooooo`;oc03o1?ooool00ol0003oc03oo`00000=ooooo`04ool0VOoooooo
ooooool0VAOooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`03ooooo`00Koooool0
0ol0003oooooooooo`18ooooo`03o`000?oooooooooo01Gooooo0_l0oolHooooo`?o<`3o4Oooool0
0olc0?ooooooooooo`0:ooooo`03ol`0oooooooooooo00Co000000?oc03oooooooooool03?ooool0
1?oo09Wooooooooooooo09T>ooooo`03ool00?oooooooooo00Oooooo00?o0000ooooooooool08?oo
ool00ol0003oooooooooo`03ooooo`00L?ooool00ol0003oooooooooo`18ooooo`03o`000?oooooo
oooo01?ooooo00?o0?ooooooooooool05Oooool3oc<0oa;ooooo0_lc0?l;ooooo`;oc03o0ol00003
ooooo`03ol`0oooooooooooo00cooooo00Coo`2Iooooooooooooo`2I3oooool00ooo003ooooooooo
o`08ooooo`03o`000?oooooooooo01oooooo00?o0000ooooooooool00oooool0077ooooo00?o0000
ooooooooool0B?ooool00ol0003oooooooooo`0Wooooo`?o<`3o00?o06Koooooooooool04Oooool0
0olc0?ooooooooooo`09ooooo`;oc03o0_l00005ooooo`03ol`0oooooooooooo00cooooo00Coo`2I
ooooooooooooo`2I3oooool00ooo003oooooooooo`0:ooooo`03o`000?oooooooooo01kooooo00?o
0000ooooooooool00oooool007;ooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0P
ooooo`Ko<`3o0_l0I_lDooooo`03oc<0oooooooooooo00Oooooo00?o0000ol`0ooo<0?l02?ooool0
0oo<0?ooooooooooo`0<ooooo`04ool0VOooooooooooool0V@oooooo00?oo`00ooooooooool03?oo
ool00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00;ooooo001cooooo`03o`000?oooooo
oooo04Sooooo00?o0000ooooooooool05oooool8oc<0o`Cooooo0_l0I_lEooooo`03oc<0oooooooo
oooo00Gooooo0_l00002ol`0o`Wooooo00?oc03oooooooooool01Oooool5oc<0o`;ooooo00Coo`2I
ooooooooooooo`2I3oooool2ool000oooooo00?o0000ooooooooool07Oooool00ol0003ooooooooo
o`02ooooo`00M?ooool00ol0003oooooooooo`0jooooo`Oo<`3o1oooool00ol0003oooooooooo`0>
ooooo`So<`3o2_ooool2o`1VoaGooooo0_lc0?l4ooooo`Co000000?ooooool`0ooooool02?ooool2
ol`0o`03oooooolc0?oo<`3o00Go<`3o1_ooool01?oo09Wooooooooooooo09T?ooooo`;oo`004Ooo
ool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00;ooooo001eooooo`;o0000?ooooolJ
oc<0oa3ooooo0_l0I_lFooooo`04oc<0ooooooooooooooooo`?o00000oooool2ol`0o`Gooooo2?lc
0?l<ooooo`04ool0VOooooooooooool0V@kooooo0_oo00000oooooooo`00ooooo`0@ooooo`03o`00
0?oooooooooo01cooooo00?o0000ooooooooool00_ooool007Oooooo00?o0000ooooooooool0Aooo
ool00ol0003ooooooc<0o`09oc<0oa;ooooo00?o06Koooooooooool05Oooool00olc0?oo0000o`00
0002o`0000Cooooo0_o<0?l7oc<0o`;ooooo0_o<0?l?ooooo`04ool0VOooooooooooool0V@kooooo
00Coo`00ooooooooooooo`004oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo00;o
oooo001hooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool02?ooool:oc<0o`Kooooo
0_l0I_l>oooooa3o<`3o0oo<0?l2oc<0o`Sooooo00?oc03oooooooooool03Oooool2ool0V@;ooooo
00?oo`2Iooooooooool03?ooool01?oo003oooooool00?oo000Eooooo`03o`000?oooooooooo01[o
oooo00?o0000ooooooooool00_ooool007Wooooo00?o0000ooooooooool0Aoooool00ol0003ooooo
ooooo`0AoooooaKo<`3o1Oooool2o`000003oc<0oooooooooooo00?ooooo0oo<0?l<ooooo`03ol`0
oooooooooooo00cooooo0_oo09T3ooooo`03ool0VOoooooooooo00cooooo00?oo`00oooooooo0000
6?ooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00;ooooo001jooooo`03o`000?oo
oooooooo04Oooooo00?o0000ooooooooool04_ooool2o`1Voa?ooooo1?l000001?oooooo<`3ooooo
ooooool4ol`0o`gooooo0_o<0?l=ooooo`;oo`2I1?ooool00ooo09Woooooooooo`0<ooooo`03ool0
0?ooooooo`0001[ooooo00?o0000ooooooooool06?ooool00ol0003oooooooooo`02ooooo`00Nooo
ool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo00oooooo0_l0I_lBooooo`?o00000ooo
ool2oc<0o`?oc03o4?ooool00oo<0?ooooooooooo`0;ooooo`;oo`2I1Oooool00ooo09Wooooooooo
o`0<ooooo`03ool00?ooooooo`0001cooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`02ooooo`00O?ooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo00gooooo00?o06Ko
ooooooooool03_ooool4o`0000Cooooo00Co<`3ool`0ooo<0?ooc03o4Oooool2ol`0o`cooooo0_oo
09T6ooooo`03ool0VOoooooooooo00_ooooo0_oo00000oooooooo`00ooooo`0Looooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool00_ooool007gooooo00?o0000ooooooooool0Aoooool0
0ol0003oooooooooo`0Jooooo`?o00001Oooool4ol`0oa?ooooo00?oc03oooooooooool02_ooool2
ool0V@Oooooo00?oo`2Iooooooooool02oooool01?oo003ooooooooooooo000Oooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool00Oooool007kooooo00?o0000ooooooooool0Aoooool0
0ol0003oooooooooo`0Fooooo`?o00001Oooool3ol`0o`03oc<0oooooooooooo01;ooooo0_o<0?l;
ooooo`;oo`2I2?ooool00ooo09Woooooooooo`0;ooooo`04ool00?ooooooooooool0027ooooo00?o
0000ooooooooool05_ooool00ol0003oooooooooo`01ooooo`00Ooooool00ol0003oooooooooo`17
ooooo`03o`000?oooooooooo017ooooo1?l00002ooooo`Koc03o0_lc0?lEooooo`03ol`0oooooooo
oooo00Wooooo0_oo09T8ooooo`;oo`2I3Oooool01?oo003ooooooooooooo000Sooooo`03o`000?oo
oooooooo01Gooooo00?o0000ooooooooool00Oooool0083ooooo0_l00018ooooo`03o`000?oooooo
oooo00gooooo2Oo<0?l4ooooo`;o<`3o5Oooool2ol`0o`[ooooo0_oo09T9ooooo`04ool0VOoooooo
ooooooooo`Koc03o1Oooool01?oo003ooooooooooooo000Uooooo`03o`000?oooooooooo01Cooooo
00?o0000ooooooooool00Oooool008;ooooo00?o0000ooooooooool0:_ooool8ol`0oaCooooo00?o
0000ooooooooool00oooool9ol`0o`_ooooo0_lc0?lFooooo`03ol`0oooooooooooo00Sooooo0_oo
09T4ooooo`_oc03o2_ooool01?oo003ooooooooooooo000Wooooo`03o`000?oooooooooo01?ooooo
00?o0000ooooooooool00Oooool008?ooooo00?o0000ooooooooool0;_oooolMol`0o`;ooooo0ol0
000=ooooo`;o<`3o5oooool00oo<0?ooooooooooo`05ooooo`;oc03o0_oo09T6ol`0o`Cooooo00?o
o`2Iooooooooool03?ooool2ool000;ooooo00?oo`00ooooooooool09_ooool00ol0003ooooooooo
o`0Cooooo`03o`000?oooooooooo007ooooo0024ooooo`03o`000?oooooooooo03_ooooo2oo<0?l0
0ol0003oooooooooo`03o`0000kooooo0_lc0?lCooooo`goc03o0ooo09T:ooooo`;oo`2I3Oooool2
ool000?ooooo00?oo`00ooooooooool0:?ooool00ol0003oooooooooo`0Booooo`03o`000?oooooo
oooo007ooooo0025ooooo`03o`000?oooooooooo04Gooooo2_o<0?l8ooooo`;o<`3o0ooooolBol`0
o`?ooooo00?oc03oooooooooool01?ooool3ool0V@cooooo00?oo`2Iooooooooool02oooool2ool0
00Cooooo00?oo`00ooooooooool0:_ooool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo
007ooooo0026ooooo`03o`000?oooooooooo04Gooooo00?o0000ooooooooool01_ooool=ol`0oa?o
oooo0_o<0?l3ooooo`Coo`2I3Oooool2ool0V@cooooo0_oo0005ooooo`03ool00?oooooooooo02co
oooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`01ooooo`00Qoooool00ol0003ooooo
ooooo`14ooooo`03o`000?oooooooooo00_ooooo00?o<`3oooooooooool05_ooool2ol`0o`;ooooo
0ooo09T@ooooo`03ool0VOoooooooooo00[ooooo0_oo0006ooooo`03ool00?oooooooooo02kooooo
00?o0000ooooooooool03oooool00ol0003oooooooooo`01ooooo`00R?ooool00ol0003ooooooooo
o`13ooooo`03o`000?oooooooooo02;ooooo0_o<0?l4ool0VA7ooooo0_oo09T;ooooo`;oo`001ooo
ool00ooo003oooooooooo`0`ooooo`03o`000?oooooooooo00oooooo0Ol00001ooooo`7ooooo0029
ooooo`03o`000?oooooooooo04;ooooo00?o0000ooooooooool08?ooool01?o<0?ooo`2Iool0VOoo
09TDooooo`03ool0VOoooooooooo00Wooooo0_oo0008ooooo`03ool00?oooooooooo037ooooo00?o
0000ooooooooool03oooool1o`00007ooooo0Oooool008[ooooo00?o0000ooooooooool0@Oooool0
0ol0003oooooooooo`0Mooooo`Coo`2I5_ooool00ooo09Woooooooooo`08ooooo`;oo`002?ooool2
ool003Gooooo00?o0000ooooooooool03_ooool1o`00007ooooo0Oooool008_ooooo0_l00011oooo
o`03o`000?oooooooooo01[ooooo0ooo09T00oo<0?ooooooooooo`0Eooooo`;oo`2I2Oooool2ool0
00Wooooo00?oo`00ooooooooool0=_ooool00ol0003oooooooooo`0=ooooo`7o00000Oooool1oooo
o`00SOooool00ol0003oooooooooo`0nooooo`03o`000?oooooooooo01?ooooo1ooo09T00ooooooo
c03oooooo`0Gooooo`03ool0VOoooooooooo00Oooooo0_oo0009ooooo`;oo`0000?oooooool0VOoo
09T00ooo09Tdooooo`03o`000?oooooooooo00cooooo0Ol00001ooooo`7ooooo002>ooooo`03o`00
0?oooooooooo01cooooo1?oo09TMooooo`03o`000?oooooooooo00[ooooo2Ooo09T6ooooo`;oc03o
5oooool2ool0V@Sooooo0_oo0006ooooo`Soo`2I>_ooool00ol0003oooooooooo`0;ooooo`7o0000
0Oooool1ooooo`00Soooool00ol0003oooooooooo`0Nooooo`Soo`2I5_ooool01?l0003ooooooooo
ooooool9ool0V@gooooo0_o<0?lHooooo`03ool0VOoooooooooo00Kooooo0_oo0008ool0V@;ooooo
0_oo000oooooo`03o`000?oooooooooo00[ooooo0Ol00001ooooo`7ooooo002@ooooo`03o`000?oo
oooooooo02;ooooo7Ooo09TDooooo`;oc03o6?ooool2ool0V@;ooooo1?oo09T3ool00003ool0VOoo
oooooooo00Sooooo00?oo`00ooooooooool0?oooool00ol0003oooooooooo`0:ooooo`7o00000Ooo
ool1ooooo`00TOooool00ol0003oooooooooo`0/ooooo`_oo`2I0oooool00ol0003oooooooooo`0C
ooooo`;oc03o4Oooool=ool0V@Coo`003?ooool2ool004?ooooo00?o0000ooooooooool02Oooool1
o`00007ooooo0Oooool009;ooooo00?o0000ooooooooool0=_ooool;ool0V@cooooo0_o<0?lCool0
V@Kooooo0_oo09T2ooooo`?oo`003oooool00ooo003oooooooooo`14ooooo`03o`000?oooooooooo
00Sooooo0Ol00001ooooo`7ooooo002Cooooo`03o`000?oooooooooo03Sooooo00?o0000oooooooo
ool01Oooool>ool0VAOooooo0_oo09T4ool0013ooooo0_oo0018ooooo`03o`000?oooooooooo00So
oooo0Ol00001ooooo`00U?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo02Sooooo
1?oo000Cooooo`03ool00?oooooooooo04Wooooo00?o0000ooooooooool01oooool1o`00007ooooo
002Eooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool09?ooool4ool001Kooooo00?o
o`00ooooooooool0Boooool00ol0003oooooooooo`06ooooo`7o00000Oooool009Kooooo00?o0000
ooooooooool0=Oooool00ol0003oooooooooo`0Qooooo`?oo`000_oo09TFooooo`;oo`00C_ooool0
0ol0003oooooooooo`06ooooo`7o00000Oooool009Oooooo0_l0000eooooo`03o`000?oooooooooo
01gooooo1?oo00000oooooooo`2Iool0V@0Gooooo`03ool00?oooooooooo04oooooo00?o0000oooo
ooooool01Oooool1o`00007ooooo002Iooooo`03o`000?oooooooooo03;ooooo00?o0000oooooooo
ool05oooool6ool000?ooooo0_oo09TGooooo`;oo`00Doooool00ol0003oooooooooo`04ooooo`7o
00000Oooool009[ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0@ooooo`Ooo`00
1oooool2ool0VASooooo00?oo`00ooooooooool04oooool5ool003cooooo00?o0000ooooooooool0
0oooool1o`00007ooooo002Kooooo`03o`000?oooooooooo00gooooo1_oo000Mooooo`03o`000?oo
oooooooo00Sooooo2?oo000<ooooo`;oo`2I6?ooool2ool000gooooo2Ooo0012ooooo`03o`000?oo
oooooooo00;ooooo0Ol00001ooooo`00W?ooool00ol0003oooooooooo`0@oooooaCoo`002oooool0
1?l0003oooooooooooooool7ool001;ooooo0_oo09TIooooo`03ool00?oooooooooo00Gooooo2?oo
001<ooooo`05o`000?ooooooooooooooool000000Oooool009gooooo00?o0000ooooooooool05_oo
ool<ool00003oooooooo003oo`0000goo`005oooool2ool0VAWooooo2_oo001Dooooo`05o`000?oo
ooooooooooooool000000Oooool009kooooo00?o0000ooooooooool08OoooolAool001Cooooo0_oo
09T5oooooaOoo`00G_ooool01?l0003oooooooooooooool1o`000000Woooool00ol0003ooooooooo
o`0/ooooo`03o`000?oooooooooo00;ooooo6ooo000Booooo`;oo`00H_ooool00ol0003ooooooooo
o`01o`000000X?ooool00ol0003oooooooooo`0[ooooo`03o`000?oooooooooo02gooooo0_oo001U
ooooo`7o00000Oooool1o`000000XOooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo
02_ooooo0_oo001Xooooo`;o0000002Rooooo`;o0000:_ooool00ol0003oooooooooo`0Yooooo`;o
o`00JOooool3o`000000Y?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo02Oooooo
0_oo001Wooooo`Co00000oooool00:Gooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`0Vooooo`03ool00?oooooooooo06Cooooo0ol00007ooooo`00Y_ooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo02Cooooo0_oo001Sooooo`Co00002_ooool00:Oooooo00?o0000oooo
ooooool09?ooool00ol0003oooooooooo`0Rooooo`;oo`00HOooool4o`0000kooooo002Xooooo`03
o`000?oooooooooo02?ooooo00?o0000ooooooooool08?ooool2ool0063ooooo0ol0000Booooo`00
ZOooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo01kooooo0_oo001Nooooo`Co0000
5Oooool00:[ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0Looooo`;oo`00G?oo
ool4o`0001Wooooo002[ooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool06_ooool0
0ooo003oooooooooo`1Hooooo`Co00007Oooool00:cooooo00?o0000ooooooooool08?ooool00ol0
003oooooooooo`1booooo`?o00008Oooool00:gooooo0_l0000Pooooo`03o`000?oooooooooo06ko
oooo1?l0000Tooooo`00[oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo06[ooooo
1?l0000Xooooo`00/?ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo06Oooooo0ol0
000/ooooo`00/Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo06?ooooo1?l0000_
ooooo`00/_ooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo05oooooo1?l0000coooo
o`00/oooool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo05cooooo0ol0000gooooo`00
]?ooool00ol0003oooooooooo`0Hooooo`03o`000?oooooooooo05Sooooo1?l0000jooooo`00]Ooo
ool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo05Cooooo1?l0000nooooo`00]_ooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo053ooooo1?l00012ooooo`00]oooool00ol0
003oooooooooo`0Eooooo`03o`000?oooooooooo04gooooo0ol00016ooooo`00^?ooool2o`0001Go
oooo00?o0000ooooooooool0BOooool4o`0004Wooooo002jooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool0AOooool4o`0004gooooo002kooooo`03o`000?oooooooooo017ooooo00?o
0000ooooooooool0@_ooool3o`00057ooooo002looooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool0?_ooool4o`0005Cooooo002mooooo`03o`000?oooooooooo00oooooo00?o0000oooo
ooooool0>_ooool4o`0005Sooooo002nooooo`03o`000?oooooooooo00kooooo00?o0000oooooooo
ool0=_ooool4o`0005cooooo002oooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0
<oooool3o`00063ooooo0030ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0;ooo
ool4o`0006?ooooo0031ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0:oooool4
o`0006Oooooo0032ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0:?ooool3o`00
06_ooooo0033ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool09?ooool4o`0006ko
oooo0034ooooo`;o00002Oooool00ol0003oooooooooo`0Pooooo`Co0000L_ooool00<Kooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`0Mooooo`?o0000M_ooool00<Oooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`0Iooooo`Co0000NOooool00<Sooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0Eooooo`Co0000OOooool00<Wooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0Aooooo`Co0000POooool00<[ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0>ooooo`?o0000QOooool00<_ooooo00Go0000oooooooooooooooo
o`00000<ooooo`Co0000R?ooool00<cooooo00Co0000oooooooooooo00002?ooool4o`0008cooooo
003=ooooo`03o`000?oooooo000000Gooooo0ol0002@ooooo`00c_ooool2o`000003ooooool0003o
000000;o0000Toooool00<oooooo0_l0002Gooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {330.375, 0}} -> {-0.0771432, -0.0315529, \
0.00350368, 0.00350368}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .92059 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-16 1.0763 -0.0263982 1.0763 [
[.01694 .18568 -11.9631 -9 ]
[.01694 .18568 .03693 0 ]
[.13793 .13897 -11.619 -9 ]
[.13793 .13897 .38095 0 ]
[.26292 .09073 -5.63752 -9 ]
[.26292 .09073 .36248 0 ]
[.39212 .04087 -5.46552 -9 ]
[.39212 .04087 .53448 0 ]
[.52574 -0.01069 -5.29351 -9 ]
[.52574 -0.01069 .70649 0 ]
[.58272 .04263 0 -6.19654 ]
[.58272 .04263 6 2.80346 ]
[.71715 .21863 0 -6.07114 ]
[.71715 .21863 6 2.92886 ]
[.83675 .37523 0 -5.963 ]
[.83675 .37523 6 3.037 ]
[.94385 .51546 0 -5.8688 ]
[.94385 .51546 6 3.1312 ]
[.01386 .20006 -12 -2.76892 ]
[.01386 .20006 0 6.23108 ]
[.00748 .25499 -24 -2.80073 ]
[.00748 .25499 0 6.19927 ]
[.00093 .31131 -6 -2.83339 ]
[.00093 .31131 0 6.16661 ]
[-0.00579 .36907 -18 -2.86695 ]
[-0.00579 .36907 0 6.13305 ]
[-0.01268 .42831 -6 -2.90143 ]
[-0.01268 .42831 0 6.09857 ]
[ 0 0 0 0 ]
[ 1 .92059 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02642 .19522 m
.53391 0 L
s
.02642 .19522 m
.03116 .2 L
s
[(-2)] .01694 .18568 .99384 1 Mshowa
.14712 .14879 m
.15172 .1537 L
s
[(-1)] .13793 .13897 .93651 1 Mshowa
.2718 .10083 m
.27624 .10588 L
s
[(0)] .26292 .09073 .87917 1 Mshowa
.40066 .05126 m
.40493 .05646 L
s
[(1)] .39212 .04087 .82184 1 Mshowa
.53391 0 m
.538 .00534 L
s
[(2)] .52574 -0.01069 .7645 1 Mshowa
.125 Mabswid
.05025 .18606 m
.05308 .18894 L
s
.07424 .17683 m
.07705 .17973 L
s
.09837 .16755 m
.10117 .17046 L
s
.12267 .1582 m
.12545 .16113 L
s
.17173 .13933 m
.17447 .14229 L
s
.19651 .1298 m
.19923 .13278 L
s
.22144 .1202 m
.22414 .1232 L
s
.24654 .11055 m
.24922 .11356 L
s
.29723 .09105 m
.29988 .0941 L
s
.32283 .0812 m
.32546 .08427 L
s
.3486 .07129 m
.35121 .07437 L
s
.37455 .06131 m
.37713 .06441 L
s
.42695 .04115 m
.4295 .04428 L
s
.45342 .03096 m
.45594 .03412 L
s
.48007 .02071 m
.48257 .02388 L
s
.5069 .01039 m
.50938 .01358 L
s
.25 Mabswid
.53391 0 m
.9804 .58403 L
s
.57014 .04738 m
.56384 .04975 L
s
[(0)] .58272 .04263 -1 .37701 Mshowa
.70445 .22307 m
.6981 .22529 L
s
[(2)] .71715 .21863 -1 .34914 Mshowa
.82396 .37939 m
.81756 .38147 L
s
[(4)] .83675 .37523 -1 .32511 Mshowa
.93098 .51938 m
.92454 .52134 L
s
[(6)] .94385 .51546 -1 .30418 Mshowa
.125 Mabswid
.60525 .09331 m
.60147 .09471 L
s
.63931 .13786 m
.63552 .13924 L
s
.67236 .1811 m
.66856 .18245 L
s
.73562 .26383 m
.7318 .26514 L
s
.7659 .30345 m
.76207 .30473 L
s
.79534 .34195 m
.7915 .34322 L
s
.85181 .41581 m
.84796 .41704 L
s
.87891 .45126 m
.87506 .45247 L
s
.90529 .48577 m
.90143 .48696 L
s
.95601 .55212 m
.95214 .55328 L
s
.25 Mabswid
.02642 .19522 m
0 .42381 L
s
.02642 .19522 m
.0327 .19281 L
s
[(-1)] .01386 .20006 1 -0.38468 Mshowa
.02006 .25024 m
.02635 .24786 L
s
[(-0.5)] .00748 .25499 1 -0.37762 Mshowa
.01354 .30664 m
.01985 .3043 L
s
[(0)] .00093 .31131 1 -0.37036 Mshowa
.00686 .36448 m
.01318 .36218 L
s
[(0.5)] -0.00579 .36907 1 -0.3629 Mshowa
0 .42381 m
.00634 .42156 L
s
[(1)] -0.01268 .42831 1 -0.35524 Mshowa
.125 Mabswid
.02516 .20612 m
.02893 .20468 L
s
.0239 .21707 m
.02767 .21563 L
s
.02262 .22807 m
.0264 .22664 L
s
.02135 .23913 m
.02512 .2377 L
s
.01877 .26141 m
.02255 .25999 L
s
.01747 .27263 m
.02125 .27122 L
s
.01617 .28391 m
.01995 .2825 L
s
.01486 .29525 m
.01864 .29384 L
s
.01222 .31809 m
.01601 .3167 L
s
.01089 .3296 m
.01468 .32821 L
s
.00955 .34117 m
.01334 .33978 L
s
.00821 .35279 m
.012 .35141 L
s
.0055 .37622 m
.0093 .37485 L
s
.00414 .38803 m
.00793 .38666 L
s
.00276 .39989 m
.00656 .39853 L
s
.00139 .41182 m
.00519 .41047 L
s
.25 Mabswid
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.54154 .92059 L
s
.54154 .92059 m
.5414 .7134 L
s
.5414 .7134 m
.02642 .19522 L
s
.53391 0 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.53391 0 m
.02642 .19522 L
s
.5414 .7134 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.54154 .92059 L
s
.54154 .92059 m
.5414 .7134 L
s
0 0 m
1 0 L
1 .92059 L
0 .92059 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.64553 .82893 m
.72411 .791 L
s
1 0 .6 r
.62934 .79677 m
.70476 .75971 L
s
.8 0 1 r
.61314 .7646 m
.68541 .72846 L
s
.2 0 1 r
.59693 .73241 m
.66607 .69724 L
s
0 .4 1 r
.58071 .70021 m
.64674 .66604 L
s
0 1 1 r
.56448 .668 m
.62743 .63486 L
s
0 1 .4 r
.54824 .63577 m
.60814 .60371 L
s
.2 1 0 r
.532 .60352 m
.58886 .57258 L
s
.8 1 0 r
.51575 .57127 m
.56959 .54147 L
s
1 .6 0 r
.49949 .53899 m
.55034 .51039 L
s
1 0 0 r
.57442 .80192 m
.6983 .79819 L
s
.4679 .79454 m
.57442 .80192 L
s
1 .6 0 r
.55034 .51039 m
.59787 .47248 L
s
1 0 .6 r
.57552 .76624 m
.69455 .7626 L
s
.47345 .75906 m
.57552 .76624 L
s
1 0 0 r
.6983 .79819 m
.80278 .78544 L
s
.8 1 0 r
.56959 .54147 m
.62054 .50156 L
s
.2 1 0 r
.58886 .57258 m
.64328 .53071 L
s
0 1 .4 r
.60814 .60371 m
.66607 .55995 L
s
0 1 1 r
.62743 .63486 m
.68893 .58926 L
s
1 0 .6 r
.69455 .7626 m
.79533 .75011 L
s
.8 0 1 r
.57666 .73046 m
.69081 .72691 L
s
.47906 .72348 m
.57666 .73046 L
s
1 0 0 r
.4266 .78894 m
.4679 .79454 L
s
0 .4 1 r
.64674 .66604 m
.71185 .61865 L
s
1 0 0 r
.5414 .79447 m
.46045 .79271 L
s
.64013 .78333 m
.5414 .79447 L
s
.2 0 1 r
.66607 .69724 m
.73483 .64812 L
s
.8 0 1 r
.68541 .72846 m
.75788 .67768 L
s
1 0 0 r
.46045 .79271 m
.4266 .78894 L
s
1 0 .6 r
.70476 .75971 m
.78099 .70731 L
s
.8 0 1 r
.69081 .72691 m
.78787 .71468 L
s
1 0 .6 r
.43347 .75354 m
.47345 .75906 L
s
.2 0 1 r
.57781 .69456 m
.68707 .6911 L
s
.48468 .68779 m
.57781 .69456 L
s
1 0 0 r
.72411 .791 m
.80414 .73705 L
s
1 0 .6 r
.53953 .75869 m
.46437 .75703 L
s
.6313 .74817 m
.53953 .75869 L
s
.46437 .75703 m
.43347 .75354 L
s
.8 0 1 r
.44038 .71805 m
.47906 .72348 L
s
.2 0 1 r
.68707 .6911 m
.78039 .67916 L
s
0 .4 1 r
.57896 .65854 m
.68331 .65519 L
s
.49033 .652 m
.57896 .65854 L
s
.8 0 1 r
.53766 .7228 m
.46832 .72125 L
s
.62245 .71292 m
.53766 .7228 L
s
.46832 .72125 m
.44038 .71805 L
s
.2 0 1 r
.44731 .68246 m
.48468 .68779 L
s
0 .4 1 r
.68331 .65519 m
.77288 .64354 L
s
0 1 1 r
.58012 .62241 m
.67954 .61916 L
s
.49599 .61611 m
.58012 .62241 L
s
.2 0 1 r
.53578 .68679 m
.47228 .68535 L
s
.61358 .67759 m
.53578 .68679 L
s
1 0 0 r
.73569 .75634 m
.64013 .78333 L
s
.2 0 1 r
.47228 .68535 m
.44731 .68246 L
s
0 .4 1 r
.45427 .64678 m
.49033 .652 L
s
0 1 1 r
.67954 .61916 m
.76536 .60783 L
s
1 0 .6 r
.71998 .72271 m
.6313 .74817 L
s
0 1 .4 r
.58128 .58616 m
.67576 .58302 L
s
.50166 .58011 m
.58128 .58616 L
s
0 .4 1 r
.53389 .65067 m
.47625 .64935 L
s
.60469 .64217 m
.53389 .65067 L
s
.47625 .64935 m
.45427 .64678 L
s
0 1 1 r
.46124 .61099 m
.49599 .61611 L
s
.8 0 1 r
.70426 .68905 m
.62245 .71292 L
s
0 1 .4 r
.67576 .58302 m
.75782 .57202 L
s
.2 1 0 r
.58245 .54979 m
.67197 .54677 L
s
.50736 .54401 m
.58245 .54979 L
s
0 1 1 r
.532 .61443 m
.48024 .61323 L
s
.59577 .60665 m
.532 .61443 L
s
.48024 .61323 m
.46124 .61099 L
s
.2 0 1 r
.68853 .65537 m
.61358 .67759 L
s
0 1 .4 r
.46824 .57511 m
.50166 .58011 L
s
.2 1 0 r
.67197 .54677 m
.75026 .53611 L
s
.8 1 0 r
.58362 .51331 m
.66817 .5104 L
s
.51307 .50779 m
.58362 .51331 L
s
0 1 .4 r
.5301 .57807 m
.48424 .577 L
s
.58684 .57105 m
.5301 .57807 L
s
0 .4 1 r
.67279 .62165 m
.60469 .64217 L
s
0 1 .4 r
.48424 .577 m
.46824 .57511 L
s
.2 1 0 r
.47525 .53912 m
.50736 .54401 L
s
.8 1 0 r
.66817 .5104 m
.74268 .50011 L
s
0 1 1 r
.65703 .58791 m
.59577 .60665 L
s
1 .6 0 r
.58479 .47671 m
.66435 .47393 L
s
.51879 .47147 m
.58479 .47671 L
s
.2 1 0 r
.5282 .5416 m
.48825 .54066 L
s
.57788 .53536 m
.5282 .5416 L
s
.48825 .54066 m
.47525 .53912 L
s
.8 1 0 r
.48229 .50303 m
.51307 .50779 L
s
1 .6 0 r
.66435 .47393 m
.73507 .46401 L
s
0 1 .4 r
.64126 .55414 m
.58684 .57105 L
s
1 .6 0 r
.59787 .47248 m
.6279 .4359 L
s
.8 1 0 r
.52628 .50501 m
.49227 .50421 L
s
.5689 .49958 m
.52628 .50501 L
s
.49227 .50421 m
.48229 .50303 L
s
1 .6 0 r
.48934 .46685 m
.51879 .47147 L
s
.2 1 0 r
.62548 .52034 m
.57788 .53536 L
s
.8 1 0 r
.62054 .50156 m
.65311 .46274 L
s
1 .6 0 r
.52437 .46831 m
.49631 .46764 L
s
.55989 .46371 m
.52437 .46831 L
s
.49631 .46764 m
.48934 .46685 L
s
.8 1 0 r
.60968 .48651 m
.5689 .49958 L
s
.2 1 0 r
.64328 .53071 m
.67844 .48971 L
s
1 .6 0 r
.59387 .45266 m
.55989 .46371 L
s
1 0 0 r
.81281 .71726 m
.73569 .75634 L
s
0 1 .4 r
.66607 .55995 m
.7039 .51681 L
s
1 0 .6 r
.79128 .68592 m
.71998 .72271 L
s
.8 0 1 r
.76979 .65463 m
.70426 .68905 L
s
.2 0 1 r
.74833 .6234 m
.68853 .65537 L
s
0 1 1 r
.68893 .58926 m
.72947 .54404 L
s
0 .4 1 r
.72691 .59221 m
.67279 .62165 L
s
0 1 1 r
.70552 .56108 m
.65703 .58791 L
s
0 1 .4 r
.68416 .52999 m
.64126 .55414 L
s
0 .4 1 r
.71185 .61865 m
.75517 .5714 L
s
.2 1 0 r
.66284 .49895 m
.62548 .52034 L
s
.8 1 0 r
.64155 .46796 m
.60968 .48651 L
s
1 .6 0 r
.62029 .43702 m
.59387 .45266 L
s
.2 0 1 r
.73483 .64812 m
.78099 .59889 L
s
.8 0 1 r
.75788 .67768 m
.80693 .62651 L
s
1 0 .6 r
.78099 .70731 m
.833 .65427 L
s
1 0 0 r
.80414 .73705 m
.85918 .68218 L
s
1 .6 0 r
.63541 .42209 m
.62029 .43702 L
s
.6279 .4359 m
.63831 .41801 L
s
.8 1 0 r
.66007 .45001 m
.64155 .46796 L
s
.2 1 0 r
.68484 .47804 m
.66284 .49895 L
s
0 1 .4 r
.7097 .50619 m
.68416 .52999 L
s
.8 1 0 r
.65311 .46274 m
.66422 .44417 L
s
0 1 1 r
.73466 .53445 m
.70552 .56108 L
s
0 .4 1 r
.75972 .56282 m
.72691 .59221 L
s
.2 0 1 r
.78489 .59131 m
.74833 .6234 L
s
.2 1 0 r
.67844 .48971 m
.69028 .47048 L
s
.8 0 1 r
.81015 .61992 m
.76979 .65463 L
s
1 .6 0 r
.63831 .41801 m
.63541 .42209 L
s
1 0 .6 r
.83553 .64864 m
.79128 .68592 L
s
1 0 0 r
.861 .67749 m
.81281 .71726 L
s
0 1 .4 r
.7039 .51681 m
.71647 .49692 L
s
.8 1 0 r
.66422 .44417 m
.66007 .45001 L
s
.2 1 0 r
.69028 .47048 m
.68484 .47804 L
s
0 1 1 r
.72947 .54404 m
.74281 .52352 L
s
0 1 .4 r
.71647 .49692 m
.7097 .50619 L
s
0 .4 1 r
.75517 .5714 m
.76929 .55025 L
s
0 1 1 r
.74281 .52352 m
.73466 .53445 L
s
.2 0 1 r
.78099 .59889 m
.79591 .57714 L
s
0 .4 1 r
.76929 .55025 m
.75972 .56282 L
s
.8 0 1 r
.80693 .62651 m
.82269 .60417 L
s
.2 0 1 r
.79591 .57714 m
.78489 .59131 L
s
1 0 .6 r
.833 .65427 m
.84961 .63135 L
s
.8 0 1 r
.82269 .60417 m
.81015 .61992 L
s
1 0 .6 r
.84961 .63135 m
.83553 .64864 L
s
1 0 0 r
.85918 .68218 m
.87667 .6587 L
s
.87667 .6587 m
.861 .67749 L
s
0 g
.25 Mabswid
.53391 0 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.53391 0 m
.02642 .19522 L
s
.02642 .19522 m
.53391 0 L
s
.02642 .19522 m
.03116 .2 L
s
[(-2)] .01694 .18568 .99384 1 Mshowa
.14712 .14879 m
.15172 .1537 L
s
[(-1)] .13793 .13897 .93651 1 Mshowa
.2718 .10083 m
.27624 .10588 L
s
[(0)] .26292 .09073 .87917 1 Mshowa
.40066 .05126 m
.40493 .05646 L
s
[(1)] .39212 .04087 .82184 1 Mshowa
.53391 0 m
.538 .00534 L
s
[(2)] .52574 -0.01069 .7645 1 Mshowa
.125 Mabswid
.05025 .18606 m
.05308 .18894 L
s
.07424 .17683 m
.07705 .17973 L
s
.09837 .16755 m
.10117 .17046 L
s
.12267 .1582 m
.12545 .16113 L
s
.17173 .13933 m
.17447 .14229 L
s
.19651 .1298 m
.19923 .13278 L
s
.22144 .1202 m
.22414 .1232 L
s
.24654 .11055 m
.24922 .11356 L
s
.29723 .09105 m
.29988 .0941 L
s
.32283 .0812 m
.32546 .08427 L
s
.3486 .07129 m
.35121 .07437 L
s
.37455 .06131 m
.37713 .06441 L
s
.42695 .04115 m
.4295 .04428 L
s
.45342 .03096 m
.45594 .03412 L
s
.48007 .02071 m
.48257 .02388 L
s
.5069 .01039 m
.50938 .01358 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 265.125},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001Bb000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00`oooool5o`000:3ooooo0033ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@0X?ooool00<Cooooo00?oV9RHob4Q8Oo^k^h0XOooool00<Gooooo00?oV9RH
ob4Q8Oo^k^h0X?ooool00<Kooooo00?oMgMgofIVI_ooool0Woooool00<Oooooo00?o0000oooooooo
ool0W_ooool00<?ooooo00Go0000okZj^_ooooooV9RHoa0@402Pooooo`00`oooool01OnHV9So410@
o`000?lQ8B7oc<c<0:3ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003;ooooo`;o0000Voooool00<Sooooo0ol000000ooooooo0000ooooo`2Jooooo`00a_oo
ool2o`0000Cooooo0_l0002Jooooo`00`oooool3o`0000Kooooo00?o0000ooooool00000VOooool0
0<3ooooo1?l00008ooooo`04o`000?ooooooooooo`0009Sooooo002Hooooo`Co000000?o410@oooo
ooooool07oooool2o`0000Cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0002H
ooooo`00V_ooool00ol0003oooooooooo`0Nooooo`?o00003_ooool01Ol0003ooooooooooooooooo
000009Oooooo002Jooooo`03o`000?oooooooooo01cooooo0_l0000Aooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0U?ooool009[ooooo00?o0000ooooooooool06Oooool3o`0000;o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo09?o
oooo002Jooooo`03o`000?oooooooooo01Kooooo0ol0000Fooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^08Kooooo002Jooooo`03o`00
0?oooooooooo01Cooooo0_l0000Iooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1oooool01OmgMgOoV9RHoooooonHV9SoMgMg08Kooooo002Jooooo`03o`000?oooooooooo017ooooo
0ol000000ooooooo0000ooooo`0Hooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1_ooool01Ol@413ooooooooooooooooo410@08Kooooo002Hooooo`03oeEEEOmVIVKo0000017ooooo
0_l0000Nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool01Ol0003ooooo
oooooooooooo000008Kooooo002Yooooo`?o00008?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000026ooooo`00Yoooool3o`0002;ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@
4100Q_ooool00:Cooooo0ol00002ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Q_ooool00:7ooooo
0ol0000Xooooo`03o`000?oooooooooo00Sooooo0_l00004ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h0Q_ooool009oooooo0_l0000[ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo
0000S_ooool009cooooo0ol000000ooooooo0000ooooo`0Zooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0S?ooool009[ooooo0_l00005ooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`2;ooooo`00Uoooool3o`0003;ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`2:ooooo`00K?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^02?ooooo0ol000000ooooooo0000ooooo`0booooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0ROooool006cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Qooooo`;o0000>?ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo08Wooooo001/ooooo`05oa0@4?oooooooooo
ooooool@41007_ooool3o`0003[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`28
ooooo`00K?ooool01Ol0003ooooooooooooooooo000001cooooo0ol0000looooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0Qoooool006cooooo00Go0000ooooooooooooooooo`00000I
ooooo`?o00000_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool0Q_ooool006cooooo00Go410@oooooooooooooooooa0@400Gooooo`;o0000@_ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo08Kooooo001/ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL05?ooool3o`0004Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`25
ooooo`00K?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^017ooooo0ol00002ooooo`03o`000?oooooo
oooo04;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`24ooooo`00P?ooool2o`00
04[ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`23ooooo`00OOooool3o`0004co
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`22ooooo`00Noooool2o`000003oooo
ool0003ooooo04cooooo00?o0000ooooooooool05?ooool2o`0008?ooooo001hooooo`?o0000DOoo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooo000008?ooooo001eooooo`?o0000E?ooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo083ooooo001cooooo`Co0000EOooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo07oooooo001`ooooo`?o00001?ooool00ol0003o
ooooooooo`1Booooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0Ooooool006kooooo
0_l0001Looooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0O_ooool004?ooooo1?l0
00000ol@413oooooooooo`0Qooooo`?o0000G_ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo07gooooo0015ooooo`03o`000?oooooooooo023ooooo0ol00003ooooo`03o`000?oooooo
oooo05_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1looooo`00>_ooool6o`00
00Gooooo00?o0000ooooooooool07_ooool2o`0006Cooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`1looooo`00AOooool00ol0003oooooooooo`0Kooooo`?o0000I_ooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo07_ooooo0015ooooo`03o`000?oooooooooo01Wooooo
0_l00002ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`1jooooo`00AOooool00ol0003oooooooooo`0Fooooo`?o0000Joooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo07Wooooo0015ooooo`03o`000?oooooooooo01Cooooo0_l0001^
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0NOooool004?ooooo00?oEEEEofIV
I_l000004oooool3o`000003ooooool0003ooooo06gooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`1hooooo`00E_ooool3o`0007?ooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`1gooooo`00E?ooool2o`0007Kooooo00?o0000ooooooooool07oooool2o`0007Sooooo
001Aooooo`?o000000?oooooo`000?ooool0MOooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo07Kooooo001?ooooo`;o0000Noooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo07Gooooo001<ooooo`?o0000OOooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
07Cooooo0019ooooo`Co0000Ooooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo07?o
oooo0017ooooo`;o00001?ooool00ol0003oooooooooo`1looooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool0L_ooool004Cooooo0ol00025ooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool0L_ooool001[ooooo1Ol0000Sooooo`?o0000Qoooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo077ooooo000Jooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@08?ooool3
o`0000?ooooo00?o0000ooooooooool0Q?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo073ooooo000Booooo`Ko00000oooool00onHV9So8B4Qonk^kP0Oooooo`;o0000SOooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo06oooooo000Looooo`03oiRHV?lQ8B7ok^k^01_o
oooo0ol0002?ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0Koooool001gooooo
00?oMgMgofIVI_ooool05oooool3o`0000?ooooo00?o0000ooooooooool0S?ooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooooooo06kooooo000Nooooo`03o`000?oooooooooo01Cooooo0_l0
002Eooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0KOooool001[ooooo00Go0000
okZj^_ooooooV9RHoa0@400Cooooo`?o0000Uoooool00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo06cooooo000Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`04Oooool2o`0000?ooooo00?o
0000ooooooooool0U?ooool00ol0003oooooooooo`0Zooooo`;o0000KOooool002gooooo0ol0002L
ooooo`03o`000?oooooooooo02[ooooo0_l0001]ooooo`00:_ooool3o`0009oooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`1Zooooo`00:?ooool2o`0000?ooooo00?o0000oooooooo
ool0W?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo06Wooooo000Uooooo`?o0000
Y?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo06Wooooo000Tooooo`03o`000?oo
oooooooo0:Gooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1Xooooo`006_ooool4
o`000003oa0@4?oooooooooo00?ooooo0_l0002Vooooo`03o`000?oooooooooo02oooooo00?o0000
ooooooooool0Ioooool001cooooo00?o0000ooooooooool01Oooool2o`000:Kooooo00?o0000oooo
ooooool0<?ooool00ol0003oooooooooo`1Vooooo`004Oooool6o`0000Gooooo00?o0000oooooooo
ool01?ooool4o`000:Gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`08ooooo`Go
0000FOooool001cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0002Tooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool01OnHV9So8B4Qonk^k_ooooooA4A4
05Wooooo000Looooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`2Qooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool01oooool00onHV9So
8B4Qonk^kP1Jooooo`007?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0X?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Oooooo
00?oV9RHob4Q8Oo^k^h0FOooool001cooooo00?o0000ooooooooool01?ooool2o`0000Gooooo00?o
0000ooooooooool0Woooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Oooooo00?o
MgMgofIVI_ooool0F?ooool001[ooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo09kooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo05Oooooo000Sooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0WOooool00ol0003oooooooooo`0eooooo`;o00001?ooool01Ol0003o^[ZjoooooonHV9So
410@05Wooooo000Sooooo`;o00002?ooool00ol0003oooooooooo`2Looooo`03o`000?oooooooooo
03?ooooo0_l000000ooooooo0000ooooo`03ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0FOooool0
02?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2Kooooo`03o`000?oooooooooo
03Oooooo00?o0000ooooooooool0Goooool002?ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`2Jooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0Goooool002?ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`2Hooooo`;o0000>_ooool00ol0003ooooo
ooooo`1Nooooo`008_ooool2o`0000gooooo00?o0000ooooooooool0U?ooool3o`000003ooooool0
003ooooo03[ooooo00?o0000ooooooooool0GOooool002;ooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`2@ooooo`?o00001Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooo
oooo05cooooo000Rooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0S?ooool3o`00
00Wooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1Looooo`008_ooool3o`0000oo
oooo00?o0000ooooooooool0R?ooool3o`0000gooooo00?o0000ooooooooool0>?ooool00ol0003o
ooooooooo`1Kooooo`008_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo08Gooooo
0_l0000Aooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0F_ooool002;ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`21ooooo`?o00005?ooool00ol0003ooooooooo
o`0hooooo`03o`000?oooooooooo05Wooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool0OOooool3o`0001Oooooo00?o0000ooooooooool0>?ooool00ol0003ooooo
ooooo`1Iooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1iooooo`?o0000
6oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo05Sooooo0005o`0000;ooooo00Go
410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`1eooooo`?o00007oooool00ol0003oooooooooo`0hooooo`03o`00
0?oooooooooo05Oooooo0007ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8b
ooooo`03ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0LOooool3o`0002?ooooo
00?o0000ooooooooool0=oooool2o`0005Sooooo0007ooooo`05o`000?ooooooooooooooool00000
3?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`1^ooooo`;o00009oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo05Go
oooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`;o
00006Oooool00ol0003oooooooooo`1Zooooo`?o0000:_ooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo05Gooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0I_ooool3o`0002go
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1Dooooo`001oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool0H_ooool3o`00037ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1Cooooo`00
8Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo05kooooo0ol0000eooooo`03o`00
0?oooooooooo03Sooooo00?o0000ooooooooool0D_ooool0023ooooo0ol0000Mooooo`03o`000?oo
oooooooo05_ooooo0_l0000iooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0D_oo
ool0027ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1Gooooo`?o0000??ooool0
0ol0003oooooooooo`0gooooo`03o`000?oooooooooo057ooooo000Pooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool0Doooool3o`00043ooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`1@ooooo`008?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo04oo
oooo0ol00013ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0Coooool0023ooooo
0_l0000Rooooo`03o`000?oooooooooo04_ooooo0ol00017ooooo`03o`000?oooooooooo03Oooooo
00?o0000ooooooooool0Coooool0023ooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`18ooooo`;o0000Boooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo04kooooo000P
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0A?ooool3o`0004kooooo00?o0000
ooooooooool0=oooool00ol0003oooooooooo`1=ooooo`008?ooool3o`0002Cooooo00?o0000oooo
ooooool0@?ooool3o`0005;ooooo00?o0000ooooooooool0=_ooool2o`0004kooooo000Pooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0??ooool3o`0005Kooooo00?o0000oooooooo
ool0=_ooool00ol0003oooooooooo`1<ooooo`005?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oo
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0hooooo`?o0000FOooool00ol0003o
ooooooooo`0gooooo`03o`000?oooooooooo04_ooooo000Dooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo03Gooooo0_l0001Mooooo`03
o`000?oooooooooo03Oooooo00?o0000ooooooooool0B_ooool001Cooooo00Go410@oooooooooooo
oooooa0@4006ooooo`;o0000:_ooool00ol0003oooooooooo`0aooooo`?o0000H?ooool00ol0003o
ooooooooo`0gooooo`03o`000?oooooooooo04Wooooo000Dooooo`05o`000?ooooooooooooooool0
00001_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo02gooooo0ol0001Tooooo`03
o`000?oooooooooo03Kooooo00?o0000ooooooooool0BOooool001Cooooo00Go0000oooooooooooo
ooooo`000006ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0:Oooool3o`0006So
oooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`18ooooo`005?ooool01Ol@413ooooo
oooooooooooo410@00Kooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Uooooo`?o
0000K?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo04Oooooo000Dooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool2o`0002kooooo00?o0000ooooooooool08Oooool3o`0006oo
oooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`16ooooo`005?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Nooooo`;o
0000Loooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo04Gooooo000Oooooo`03o`00
0?oooooooooo02oooooo00?o0000ooooooooool06_ooool3o`0007Kooooo00?o0000ooooooooool0
=_ooool00ol0003oooooooooo`15ooooo`007_ooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo01Kooooo0ol0001jooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0A?oo
ool001kooooo0_l0000cooooo`03o`000?oooooooooo01;ooooo0ol0001nooooo`03o`000?oooooo
oooo03Kooooo0_l00014ooooo`007_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo
00kooooo0ol00022ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooool00000A?ooool001ko
oooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0;ooooo`;o0000QOooool00ol0003o
ooooooooo`0fooooo`03o`000?oooooooooo04;ooooo000Nooooo`03o`000?oooooooooo03Gooooo
00?o0000ooooooooool01oooool3o`0008Sooooo00?o0000ooooooooool0=_ooool00ol0003ooooo
ooooo`11ooooo`007_ooool2o`0003Oooooo00?o0000ooooooooool00oooool3o`0008cooooo00?o
0000ooooooooool0=_ooool00ol0003oooooooooo`10ooooo`007_ooool00ol0003oooooooooo`0g
ooooo`03o`000?oooooo000000;o0000T?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooo
oooo03oooooo000Nooooo`03o`000?oooooooooo03Kooooo0ol0002Dooooo`03o`000?oooooooooo
03Gooooo00?o0000ooooooooool0?oooool001kooooo0_l0000eooooo`;o00000oooool00ol0003o
ooooooooo`2Booooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool02Oooool2o`000003
oa0@4?oooooooooo033ooooo000Mooooo`03o`000?oooooooooo03;ooooo0ol00006ooooo`03o`00
0?oooooooooo097ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo037ooooo0002ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo
00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo02oooooo0ol0000:ooooo`03
o`000?oooooooooo097ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`05ooooo`Go
0000<_ooool000;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo
<S8booooo`04ooooo`03o`000?oooooooooo02cooooo0ol0000>ooooo`03o`000?oooooooooo097o
oooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`05ooooo`04odA4A?oMgMgoooooo`00
03?ooooo0002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03oooo
o`;o0000:_ooool3o`0001;ooooo00?o0000ooooooooool0TOooool00ol0003oooooooooo`0eoooo
o`03o`000?oooooooooo00Cooooo00CogMgMoeEEEOoooooo0000<oooool000;ooooo00Go0000oooo
ooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool09oooool2
o`0001Kooooo00?o0000ooooooooool0TOooool00ol0003oooooooooo`0eooooo`03o`000?oooooo
oooo00Cooooo00?oMgMgolc<c?l00000<oooool000;ooooo00Go0000ooooooooooooooooo`00000<
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Tooooo`?o00006Ooo
ool00ol0003oooooooooo`2Aooooo`03o`000?oooooooooo03Cooooo0_l00005ooooo`03onk^k_m4
A4Co000003?ooooo0002ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo027ooooo0ol0000Mooooo`03o`000?oooooooooo093ooooo00?o
0000ooooooooool0<oooool01?l0003oooooooooool00005ooooo`03ogMgMol0003ooooo03;ooooo
0002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`;o0000
7oooool3o`00027ooooo00?o0000ooooooooool0T?ooool00ol0003oooooooooo`0eooooo`03o`00
0?oooooooooo03Sooooo0002ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo
00?o0000ooooooooool07?ooool3o`0002Gooooo00?o0000ooooooooool0T?ooool00ol0003ooooo
ooooo`0eooooo`03o`000?oooooooooo03Oooooo000Looooo`03o`000?oooooooooo01Wooooo0ol0
000Yooooo`03o`000?oooooooooo093ooooo00?o0000ooooooooool0=Oooool00ol0003ooooooooo
o`0fooooo`007?ooool00ol0003oooooooooo`0Gooooo`;o0000;Oooool00ol0003oooooooooo`2@
ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0=Oooool001cooooo0_l0000Eoooo
o`?o0000<?ooool00ol0003oooooooooo`2@ooooo`03o`000?oooooooooo03Cooooo00?o0000oooo
ooooool0=Oooool001cooooo00?o0000ooooooooool04Oooool3o`0003Cooooo00?o0000oooooooo
ool0Soooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo03Cooooo000Looooo`03o`00
0?oooooooooo00kooooo0ol0000hooooo`03o`000?oooooooooo08oooooo00?o0000ooooooooool0
=Oooool00ol0003oooooooooo`0cooooo`007?ooool00ol0003oooooooooo`0;ooooo`?o0000??oo
ool00ol0003oooooooooo`2?ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0<_oo
ool001cooooo0_l0000:ooooo`;o0000@?ooool00ol0003oooooooooo`2?ooooo`03o`000?oooooo
oooo03Cooooo00?o0000ooooooooool0<_ooool001_ooooo0_l00008ooooo`?o0000@oooool00ol0
003oooooooooo`2?ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0<Oooool001_o
oooo00?o0000ooooooooool01?ooool3o`0004Oooooo00?o0000ooooooooool0Soooool00ol0003o
ooooooooo`0cooooo`;o0000<_ooool001_ooooo00Co0000oooooooooooooooo0ol0001;ooooo`03
o`000?oooooooooo07oooooo00?ooiT0ooooooooool03?ooool00ol0003oooooooooo`0eooooo`03
o`000?oooooooooo02oooooo000Kooooo`Co0000Coooool00ol0003oooooooooo`1mooooo`;ooiT0
3oooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02oooooo000Kooooo`;o0000D_oo
ool00ol0003oooooooooo`1kooooo`;ooiT04Oooool00ol0003oooooooooo`0dooooo`03o`000?oo
oooooooo02kooooo000Aooooo`Co000000?o410@ooooooooool01Oooool00ol0003oooooooooo`1@
ooooo`03o`000?oooooooooo07Wooooo0_ooV@0Cooooo`03o`000?oooooooooo03Cooooo00?o0000
ooooooooool0;Oooool001?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`1@oooo
o`03o`000?oooooooooo07Oooooo00?ooiT0ooooooooV@005?ooool00ol0003oooooooooo`0doooo
o`03o`000?oooooooooo02cooooo000Cooooo`03o`000?oooooooooo00Wooooo00?o0000oooooooo
ool0D?ooool00ol0003oooooooooo`1eooooo`03oonI0?oooooooiT001Kooooo00?o0000oooooooo
ool0<oooool00ol0003oooooooooo`0/ooooo`004oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo053ooooo00?o0000ooooooooool0L_ooool2oonI0003ooooooooV@3ooooo01Kooooo
00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0[ooooo`004oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0Koooool2oonI00?ooooo00?o
oiT0ooooooooool05_ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo02[ooooo000C
ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0D?ooool00ol0003oooooooooo`1/
ooooo`;ooiT01?ooool00oooV@3oooooooooo`0:ooooo`03olco0?oooooooooo00_ooooo00?o0000
ooooooooool0=?ooool00ol0003oooooooooo`0Yooooo`004oooool00ol0003oooooooooo`0=oooo
o`03o`000?oooooooooo053ooooo00?o0000ooooooooool0J_ooool00oooV@3oooooooooo`03oooo
o`03oonI0?oooooooooo00_ooooo00?oc?l0ooooooooool03?ooool00ol0003oooooooooo`0doooo
o`03o`000?oooooooooo02Sooooo000Aooooo`03oeEEEOmVIVKo0000013ooooo00?o0000oooooooo
ool0D?ooool00ol0003oooooooooo`1Wooooo`;ooiT01Oooool00oooV@3oooooooooo`0;ooooo`03
olco0?oooooooooo00kooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Xooooo`00
9Oooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo06Cooooo0_ooV@06ooooo`03oonI
0?oooooooooo00_ooooo0_o<o`0Aooooo`03o`000?oooooooooo03;ooooo0_l0000Yooooo`009_oo
ool2o`00057ooooo00?o0000ooooooooool0H?ooool3oonI00Oooooo00?ooiT0ooooooooool02ooo
ool2olco01;ooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0Vooooo`00:?ooool0
0ol0003oooooooooo`1>ooooo`03o`000?oooooooooo05gooooo0oooV@0:ooooo`03oonI0?oooooo
oooo00[ooooo00?oc?l0ooooooo<o`004oooool00ol0003oooooooooo`0dooooo`03o`000?oooooo
oooo02Gooooo000Yooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0FOooool3oonI
00cooooo00?ooiT0ooooooooool02_ooool01?o<o`3oooooooooooo<o`0Dooooo`03o`000?oooooo
oooo03?ooooo00?o0000ooooooooool09Oooool002[ooooo00?o0000ooooooooool0C_ooool00ol0
003oooooooooo`1Aooooo`OooiT03_ooool00oooV@3oooooooooo`0:ooooo`04olco0?oooooooooo
olco01Kooooo00?o0000oonI0?ooV@000_ooV@0aooooo`03o`000?oooooooooo02Cooooo000[oooo
o`03o`000?oooooooooo04kooooo00?o0000ooooooooool0?_oooolBoonI01Cooooo00?ooiT0oooo
ooooool02Oooool2olco00?ooooo00?oc?l0ooooooooool03?ooool8oonI0003ooooool0003ooooo
03Cooooo00?o0000ooooooooool08oooool002cooooo00?o0000ooooooooool0C_ooool00ol0003o
ooooooooo`13ooooo`_ooiT05?ooool00oooV@3oooooooooo`08ooooo`;oc?l01?ooool00oo<o`3o
ooooooooo`05ooooo`GooiT000?o<ol0oonI0?ooV@002_ooool00ol0003oooooooooo`0cooooo`03
o`000?oooooooooo02;ooooo000]ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0
COooool;oonI00Oooooo0_ooV@08ooooo`03oonI0?o<o`3oc?l000GooiT000?oc?l0oonI0?ooV@00
1_ooV@05ooooo`03oc?o0?oooooooooo00[ooooo00?o0000ooooooooool0<oooool00ol0003ooooo
ooooo`0Rooooo`00;_ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo05Oooooo4Ooo
V@000oo<o`3oooooooooo`04ooooo`03olco0?oooooooooo00_ooooo00?o<ol0ooooooooool03?oo
ool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo027ooooo000_ooooo`03o`000?oooooo
oooo04kooooo00?o0000ooooooooool0Foooool00oooV@3oooooooooo`07ooooo`;oc?l01_ooool0
0oo<o`3oooooooooo`0;ooooo`03oc?o0?oooooooooo00kooooo00?o0000ooooooooool0<oooool0
0ol0003oooooooooo`0Pooooo`00<?ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo
05Sooooo0_ooV@08ooooo`;oc?l01oooool00oo<o`3oooooooooo`0;ooooo`;o<ol04Oooool00ol0
003oooooooooo`0cooooo`03o`000?oooooooooo01oooooo000aooooo`;o0000Coooool00ol0003o
ooooooooo`1Fooooo`03oonI0?oooooooooo00Kooooo0_o<o`08ooooo`03olco0?oooooooooo00_o
oooo0_lco`0Cooooo`03o`000?oooooooooo03;ooooo0_l0000Pooooo`00<oooool00ol0003ooooo
ooooo`1=ooooo`03o`000?oooooooooo05Cooooo00?ooiT0ooooooooool01?ooool3olco00Wooooo
00?oc?l0ooooooooool02oooool2oc?o01Gooooo00?o0000ooooooooool0<Oooool2o`00023ooooo
000dooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0DOooool2oonI00Cooooo0oo<
o`0;ooooo`03olco0?oooooooooo00_ooooo00?o<ol0oooooolco`005Oooool00ol0003ooooooooo
o`0cooooo`03o`000?oooooooooo01gooooo000eooooo`03o`000?oooooooooo04gooooo00?o0000
ooooooooool0Coooool00oooV@3oooooooooo`02ooooo`;oc?l03Oooool00oo<o`3oooooooooo`0;
ooooo`03oc?o0?oooooo<ol001Oooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0L
ooooo`00=_ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo04gooooo00?ooiT0oooo
ooooool00oo<o`0>ooooo`03olco0?oooooooooo00_ooooo00?o<ol0oooooolco`003_ooool00ol0
ofKoooooooooo`08ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool07?ooool003Oo
oooo00?o0000ooooooooool0COooool00ol0003oooooooooo`1:ooooo`Goc?l03oooool2olco00co
oooo0_lco`000ooooooo<ol0ooooo`0=ooooo`;o0?mV0oooool5olco00?ooooo00?o0000oooooooo
ool0<_ooool00ol0003oooooooooo`0Kooooo`00>?ooool00ol0003oooooooooo`1=ooooo`03o`00
0?oooooooooo033ooooo2_o<o`08ooooo`Ooc?l04oooool00oo<o`3oooooooooo`0:ooooo`;o<ol0
0_ooool00olco`3oooooooooo`0:ooooo`;oc?l00_l0ofH4olco00Wooooo00?o0000ooooooooool0
<_ooool00ol0003oooooooooo`07ooooo`05onk^k_lb<S;o0000oa0@4?o<c<`03_ooool003Wooooo
00?o0000ooooooooool0COooool00ol0003oooooooooo`0eooooo`coc?l01Oooool00oooV@3ooooo
ooooo`0Aooooo`03olco0?oooooooooo00Wooooo0_lco`03ooooo`03oc?o0?oooooooooo00?ooooo
2?o<o`000ooooooo0?mVo`3oIP0?ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool0
1_ooool01OmEEEGoMgMgoooooonHV9So8B4Q00kooooo000jooooo`03o`000?oooooooooo04gooooo
00?o0000ooooooooool0?oooool;olco00kooooo00?oc?l0ooooooooool00oooool5olco00;o<ol0
1?o<o`000olco`3oc?l0olco0004olco00Sooooo0_l0ofH@ooooo`03o`000?oooooooooo03?ooooo
00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo000000kooooo000kooooo`03o`00
0?oooooooooo04gooooo00?o0000ooooooooool0@Oooool00oooV@3oooooooooo`05oooooaCoc?l0
1?ooool00olco`3oooooooooo`04ooooo`03oc?o0?oooooooooo00_ooooo0_l0ofHBooooo`03o`00
0?oooooooooo03;ooooo00?o0000ooooooooool01Oooool01Ol0003oV9RHoooooonHV9So8B4Q00ko
oooo000looooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0?_ooool2oonI01?ooooo
0_o<o`09ooooo`;o<ol01_ooool00olco`3oooooooooo`0;ooooo`;o0?mV5?ooool00ol0003ooooo
ooooo`0booooo`03o`000?oooooooooo00Cooooo00Go0000oeEEEOl0003o410@olc<c00>ooooo`00
?Oooool2o`0004kooooo00?o0000ooooooooool0>oooool2oonI01Cooooo00?oc?l0ooooooooool0
1oooool2oc?o00Oooooo00?o<ol0ooooooooool02oooool00ol0ofKoooooo`3oIP0Eooooo`03o`00
0?oooooooooo03;ooooo0_l00004ooooo`03oeEEEOn7QhOooooo013ooooo000oooooo`03o`000?oo
oooooooo04cooooo00?o0000ooooooooool0>Oooool00oooV@3oooooooooo`0Cooooo`03olco0?oo
oooooooo00Kooooo0_lco`08ooooo`03oc?o0?oooooooooo00_ooooo00?o0?mVooooool0ofH05ooo
ool00ol0003oooooooooo`0_ooooo`;o000000?oooooo`000?ooool00oooool00ooMgMgo410@oiRH
V00@ooooo`00@?ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo03Kooooo0_ooV@0E
ooooo`03olco0?oooooooooo00Cooooo0olco`09ooooo`03oc?o0?oooooooooo00_ooooo00?o0?mV
ooooool0ofH03_ooool00ol0ooooooooooooo`08ooooo`03o`000?oooooooooo037ooooo00?o0000
ooooooooool00oooool01?o<c<coA4A4o`000?l@410>ooooo`00@Oooool00ol0003oooooooooo`1<
ooooo`03o`000?oooooooooo03Cooooo00?ooiT0ooooooooool04oooool2olco00Cooooo0olco`0;
ooooo`03oc?o0?oooooooooo00_ooooo00?o0?mVooooool0ofH03oooool00ol0ooooooooooooo`08
ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool05?ooool004;ooooo00?o0000oooo
ooooool0C?ooool00ol0003oooooooooo`0aooooo`;ooiT05Oooool01?o<o`3oooooooooooooool3
oc?o00cooooo0_lco`0<ooooo`;o0?mV00?oooooo`3oI_ooool03_ooool00ol0ooooooooooooo`0:
ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool04oooool004?ooooo00?o0000oooo
ooooool0C?ooool00ol0003oooooooooo`0^ooooo`;ooiT05_ooool00oo<o`3ooooooc?o0002oc?o
00kooooo00?o<ol0ooooooooool02_ooool2o`3oIP?ooooo00?o0?mVooooooooool02oooool2o`3o
o`kooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`0Booooo`00A?ooool00ol0003o
ooooooooo`1<ooooo`03o`000?oooooooooo02cooooo00?ooiT0ooooooooool04_ooool6oc?o013o
oooo00?o<ol0ooooooooool02_ooool00ol0ofKoooooooooo`02ooooo`03o`3oI_oooooooooo00_o
oooo00?o0?ooooooool0ool01Olco`0:ooooo`03o`000?oooooooooo037ooooo00?o0000oooooooo
ool04_ooool004Gooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0Rooooo`co<ol0
2Oooool9oc?o00;ooooo00?oc?l0ooooooooool03oooool2oc?o00_ooooo0_l0ofH4ooooo`03o`3o
I_oooooooooo00Kooooo1Olco`001?l0oooo<ol0o`3ooolco`0@ooooo`03o`000?oooooooooo037o
oooo00?o0000ooooooooool04Oooool004Kooooo00?o0000ooooooooool0C?ooool00ol0003ooooo
ooooo`0Wooooo`oo<ol02Oooool2olco017ooooo00?o<ol0ooooooooool02Oooool2o`3oIPGooooo
00?o0?mVoc?o0?lco`001olco`04ooooo`03o`3ooooooooo0?oo01?ooooo00?o0000ooooooooool0
<Oooool00ol0003oooooooooo`0@ooooo`00Aoooool00ol0003oooooooooo`1<ooooo`03o`000?oo
oooooooo037ooooo3Olco`0Booooo`03oc?o0?oooooo<ol000So<ol00_l0ofH6oc?o0003o`3oI_lc
o`3ooooo00_ooooo00Co0?oooooooooooooo0?oo4oooool00ol0003oooooooooo`0booooo`03o`00
0?oooooooooo00oooooo0018ooooo`;o0000COooool00ol0003oooooooooo`0iooooo`;oc?l00_oo
oolDoc?o00Sooooo00?o0?mVooooooooool01_ooool00ol0ofKoooooooooo`0:ooooo`04o`3ooooo
ooooooooo`3ooaGooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0?ooooo`00B_oo
ool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo03Kooooo0_o<o`0Cooooo`;o<ol02Ooo
ool2o`3oIPSooooo00?o0?mVooooooooool02_ooool01?l0ooooooooooooool0ool>ooooo`03o`1V
oooooooooooo00Kooooo00?o0000ooooooooool0<Oooool2o`0000oooooo001;ooooo`03o`000?oo
oooooooo04_ooooo00?o0000ooooooooool0<oooool2olco01Cooooo00?o<ol0ooooooooool01_oo
ool3o`3oIPWooooo00?o0?mVooooooooool02_ooool01?l0ooooooooooooool0ool?ooooo`03o`1V
oooooooooooo00Oooooo00?o0000ooooooooool0<?ooool2o`0000oooooo001<ooooo`03o`000?oo
oooooooo04_ooooo00?o0000ooooooooool0<?ooool2olco01Gooooo00?o<ol0ooooooooool01?oo
ool3o`3oIP_ooooo00?o0?mVooooooooool02_ooool01?l0ooooooooooooool0ool?ooooo`03o`1V
oooooooooooo00Wooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0<ooooo`00COoo
ool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo02gooooo0_o<o`0Eooooo`;o<ol00ooo
ool4o`3oIPcooooo0_l0ofH;ooooo`;o0?oo0_ooool00ol0ooooooooooooo`0=ooooo`03o`1Voooo
oooooooo00_ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0;ooooo`00C_ooool0
0ol0003oooooooooo`1;ooooo`03o`000?oooooooooo02[ooooo0_o<o`0Fooooo`03oc?o0?oooooo
0?mV00?o0?mV3oooool00ol0ofKoooooooooo`09ooooo`;o0?oo0oooool00ol0ooooooooooooo`0<
ooooo`;o06Ko3_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00_ooooo001?oooo
o`03o`000?oooooooooo04_ooooo00?o0000ooooooooool09oooool2olco01Oooooo0ol0ofHBoooo
o`03o`3oI_oooooooooo00Wooooo00?o0?ooooooooooool00_ooool00ol0ooooooooooooo`0<oooo
o`03o`1Voooooooo06Ko00oooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0:oooo
o`00D?ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo02Gooooo00?oc?l0oooooooo
ool04_ooool5o`3oIQ?ooooo0_l0ofH:ooooo`;o0?oo1?ooool00ol0ooooooooooooo`0<ooooo`03
o`1Voooooooo06Ko017ooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`09ooooo`00
DOooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo03;ooooo1ol0ofH2ooooo`;o<ol0
4oooool00ol0ofKoooooooooo`08ooooo`;o0?oo1Oooool00ol0ooooooooooooo`0;ooooo`05o`3o
I_l0I_oo0?mVo`1Vool0ofH04_ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00So
oooo001Booooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool04oooool?o`3oIPWooooo
1_l0ofH7ooooo`;o<ol05?ooool00ol0ofKoooooooooo`07ooooo`;o0?oo1_ooool00ol0oooooooo
ooooo`03ooooo`So0?mV0_l0I_l2ooooo`03o`1Voooooooooooo00_ooooo00?o<`3oooooooooool0
1?ooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Sooooo001Cooooo`;o0000C?oo
ool00ol0003oooooooooo`0Ioooooa7o0?mV2oooool2oc?o01Cooooo0_l0ofH8ooooo`;o0?oo1Ooo
ool2o`3oIP03o`3oool0ofKo0?mV00Co0?mV1oooool01Ol0I_oooooooooooooooooo06Ko00kooooo
00?o<`3oooooooooool01Oooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo00Oooooo
001Eooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool09?ooool=o`3oIP03oooooolc
o`3o<ol001?ooooo3?l0ofH00ol0oooo0?mVo`3oIP05o`3oIP03ooooool0oooooooo00cooooo00Go
06Koooooooooooooooooo`1Vo`0>ooooo`03oc<0oooooooooooo00Kooooo00?o0000ooooooooool0
<Oooool00ol0003oooooooooo`06ooooo`00E_ooool00ol0003oooooooooo`1:ooooo`03o`000?oo
oooooooo02oooooo00?o<ol0o`3oI_l0ofH05_l0ofH8ooooo`;o0?oo2?ooool00ol0oooooooooooo
o`0;ooooo`05o`1Vooooooooooooooooool0I_l03_ooool00olc0?ooooooooooo`08ooooo`03o`00
0?oooooooooo02oooooo0ol00007ooooo`00Eoooool00ol0003oooooooooo`1:ooooo`03o`000?oo
oooooooo02gooooo00?o<ol0ooooooooool05?ooool00ol0ofKoooooooooo`05ooooo`?o0?oo2?oo
ool2o`3oo`gooooo00Go06Koooooooooooooooooo`1Vo`0>ooooo`;o<`3o2oooool00ol0003ooooo
ooooo`0[ooooo`?o00000_ooool00ol0003oooooooooo`05ooooo`00F?ooool00ol0003ooooooooo
o`1:ooooo`03o`000?oooooooooo02[ooooo0_lco`0Fooooo`03o`3oI_oooooooooo00?ooooo0ol0
ool:ooooo`03o`3ooooooooooooo00_ooooo0_l0I_l3ooooo`03o`1Voooooooooooo00_ooooo0olc
0?l=ooooo`03o`000?oooooooooo02Oooooo0ol00005ooooo`03o`000?oooooooooo00Gooooo001I
ooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool09oooool2oc?o01Kooooo0_l0ofH3
ooooo`?o0?oo3?ooool00ol0ooooooooooooo`0:ooooo`;o06Ko1?ooool00ol0I_ooooooooooo`0;
ooooo`04oc<0oooooooooooooc<0o`kooooo00?o0000ooooooooool08_ooool4o`0000Sooooo00?o
0000ooooooooool01Oooool005[ooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0T
ooooo`;o<ol05oooool00ol0ofKoooooo`3oo`03o`3oo`kooooo00?o0?ooooooooooool02Oooool2
o`1Vo`Gooooo00?o06Koooooooooool02oooool01?lc0?oooooooooooolc0?l@ooooo`03o`000?oo
oooooooo01kooooo0ol0000<ooooo`03o`000?oooooooooo00Gooooo001Kooooo`03o`000?oooooo
oooo04[ooooo00?o0000ooooooooool08Oooool2oc?o01Sooooo0ol0ool@ooooo`;o0?oo2oooool0
0ol0I_ooooooooooo`04ooooo`03o`1Voooooooooooo00_ooooo00Co<`3ooooooooooooo<`3o4Ooo
ool00ol0003oooooooooo`0Jooooo`Co00003oooool00ol0003oooooooooo`05ooooo`00G?ooool0
0ol0003oooooooooo`1:ooooo`03o`000?oooooooooo01oooooo00?o<ol0ooooooooool05Oooool3
o`3ooa;ooooo00?o0?ooooooooooool02Oooool2o`1Vo`Kooooo00?o06Koooooooooool02oooool0
1Olc0?oooooooooooooooooo<`3o00gooooo00?oc03oooooooooool00_ooool00ol0003ooooooooo
o`0Fooooo`?o00005?ooool00ol0003oooooooooo`04ooooo`00GOooool00ol0003oooooooooo`1:
ooooo`03o`000?oooooooooo033ooooo1_l0ool00ol0ofKoooooooooo`0Aooooo`03o`3ooooooooo
oooo00Sooooo0_l0I_l7ooooo`03o`1Voooooooooooo00_ooooo00Go<`3ooooooooooooooooooc<0
o`0>ooooo`03ol`0oooooooooooo00?ooooo00?o0000ooooooooool04_ooool3o`0001Oooooo00?o
0000ooooooooool01?ooool005kooooo0_l0001;ooooo`03o`000?oooooooooo02Sooooo1ol0ool3
ooooo`;o0?mV5?ooool00ol0ooooooooooooo`07ooooo`;o06Ko2?ooool00ol0I_ooooooooooo`07
ooooo`Co0?oo00Go<`3oo`3ooooooooooooooc<0o`0>ooooo`03ol`0oooooooooooo00Gooooo00?o
0000ooooooooool03Oooool4o`0001[ooooo00?o0000ooooooooool01?ooool0063ooooo00?o0000
ooooooooool0BOooool00ol0003oooooooooo`05oooooa3o0?oo2oooool7o`3oo`Wooooo00?o0?mV
ooooooooool04_ooool2o`3oo`Sooooo0_l0I_l9ooooo`03o`1Vool0oooo0?oo00So0?oo0oooool0
1Olc0?oooooooooooooooooo<`3o00kooooo00?oc03oooooooooool01oooool00ol0003ooooooooo
o`09ooooo`?o00007_ooool00ol0003oooooooooo`04ooooo`00HOooool00ol0003oooooooooo`19
ooooo`03o`000?oooooooooo00_ooooo5?l0ool>ooooo`;o0?mV5?ooool00ol0ooooooooooooo`07
ooooo`04o`1Vooooooooooooooooo`Oo0?oo00?o06Koo`3oooooool02oooool01Olc0?oooooooooo
oooooooo<`3o00oooooo00?oc03oooooooooool02?ooool00ol0003oooooooooo`04ooooo`Co0000
8Oooool00ol0003oooooooooo`04ooooo`00H_ooool00ol0003oooooooooo`19ooooo`03o`000?oo
oooooooo01Kooooo3_l0ool6ooooo`;o0?mV3oooool?o`3oo`;o06Ko1?l0ool5ooooo`;o06Ko3Ooo
ool01Olc0?oooooooooooooooooo<`3o00oooooo00?oc03oooooooooool02Oooool01?l0003ooooo
ooooooooool3o`0002Gooooo00?o0000ooooooooool01?ooool006?ooooo00?o0000ooooooooool0
BOooool00ol0003oooooooooo`0SoooooaOo0?oo1Oooool00ol0ooooooooooooo`04ooooo`?o06Ko
2_ooool00ol0I_ooooooooooo`0<ooooo`05oc<0oooooooooooooooooolc0?l03_ooool3ol`0o`co
oooo0ol0000Xooooo`03o`000?oooooooooo00Cooooo001Tooooo`03o`000?oooooooooo04Wooooo
00?o0000ooooooooool09?ooool2o`3oIQKooooo0_l0ool4ooooo`?o06Ko3?ooool00ol0I_oooooo
ooooo`0;ooooo`;o<`3o0oooool00olc0?ooooooooooo`0<ooooo`03ol`0ooooooooc03o00Wooooo
1?l000000ooooooo0000ooooo`0Xooooo`03o`000?oooooooooo00Cooooo001Uooooo`03o`000?oo
oooooooo04Wooooo00?o0000ooooooooool08_ooool00ol0ofKoooooooooo`0Eooooo`04o`3ooooo
ooooooooooooo`?o06Ko3Oooool2o`1Vo`cooooo0_lc0?l4ooooo`03oc<0oooooooooooo00cooooo
00?oc03oooooooo<0?l01oooool3o`0000Kooooo00?o0000ooooooooool09_ooool00ol0003ooooo
ooooo`04ooooo`00I_ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo01oooooo0_l0
ofHGooooo`03o`3oool0I_oo06Ko00;o06Ko3oooool00ol0I_ooooooooooo`0:ooooo`;o<`3o1Ooo
ool00olc0?ooooooooooo`0<ooooo`03ol`0ooooooooc03o00Cooooo1?l00006ooooo`05ool0VOoo
ooooooooooooool000009oooool00ol0003oooooooooo`04ooooo`00Ioooool00ol0003ooooooooo
o`19ooooo`03o`000?oooooooooo01cooooo0_l0ofHGooooo`?o06Ko4Oooool2o`1Vo`_ooooo0_lc
0?l6ooooo`03oc<0oooooooooooo00_ooooo0_o<0?l01?ooooooc03oooooooooool3o`0000[ooooo
00?oo`2Iooooooooool00_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00?ooooo
001Xooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool06_ooool00ol0ofKooooooooo
o`0Dooooo`?o06Ko00?o0?ooooooooooool04?ooool00ol0I_ooooooooooo`09ooooo`;o<`3o1ooo
ool00olc0?ooooooooooo`0;ooooo`04ol`0oooooooooooool`0o`?o00003?ooool00ooo09Wooooo
ooooo`03ooooo`03o`000?oooooooooo02Gooooo00?o0000ooooooooool00oooool006Wooooo00?o
0000ooooooooool0BOooool00ol0003oooooooooo`0]ooooo`?o06Ko0_l0oolCooooo`03o`1Voooo
oooooooo00Sooooo0_lc0?l8ooooo`03oc<0oooooooooooo00_ooooo00Goc03oo`000?l0003oc03o
o`00000>ooooo`03ool0VOoooooooooo00Gooooo00?o0000ooooooooool09?ooool00ol0003ooooo
ooooo`03ooooo`00J_ooool2o`0004[ooooo00?o0000ooooooooool09_ooool6o`1Vo`03ooooool0
oooo0?oo01?ooooo0_l0I_l9ooooo`;o<`3o2Oooool00olc0?ooooooooooo`03ooooo`Go06Ko0_oo
ool2ol`0o`03o`000?ooooooc03o00oooooo00?oo`2Iooooooooool01oooool00ol0003ooooooooo
o`0Sooooo`03o`000?oooooooooo00?ooooo001/ooooo`03o`000?oooooooooo04Sooooo00?o0000
ooooooooool07Oooool8o`1Vo`Gooooo0_l0oolDooooo`03o`1Voooooooooooo00Oooooo0_lc0?l:
ooooo`03oc<0ool0I_oo06Ko00Co06Ko0oooool3o`000005ol`0ooooooooooooooooooo<0?l03ooo
ool2ool0V@[ooooo00?o0000ooooooooool08_ooool00ol0003oooooooooo`03ooooo`00KOooool0
0ol0003oooooooooo`12oooooa;o06Ko3?ooool7o`1Vo`_ooooo0_l0oolEooooo`03o`1Voooooooo
oooo00Kooooo0_lc0?l5ooooo`Ko06Ko00?o<`3oooooooooool01Oooool3o`0000;ooooo00Goc03o
oooooooooooooooool`0o`0>ooooo`?oo`2I3?ooool00ol0003oooooooooo`0Qooooo`03o`000?oo
oooooooo00?ooooo001^ooooo`03o`000?oooooooooo04Sooooo5ol0I_l@ooooo`;o0?oo5Oooool2
o`1Vo`Oooooo0_lc0?l7o`1Vo`Cooooo00?o<`3oooooooooool01?ooool3o`0000Cooooo00Goc03o
oooooooooooooooool`0o`0>ooooo`03ool0VOooooooo`2I00kooooo00?o0000ooooooooool08?oo
ool00ol0003oooooooooo`03ooooo`00Koooool00ol0003oooooooooo`18ooooo`03o`000?oooooo
oooo00Wooooo3ol0I_l:ooooo`03o`3ooooooooooooo00_ooooo4?l0I_l3oc<0o`;o06Ko2Oooool2
oc<0o`?ooooo1?l00005ooooo`;oc03o0oooool00oo<0?ooooooooooo`0<ooooo`03ool0VOoooooo
o`2I00oooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`03ooooo`00L?ooool00ol0
003oooooooooo`18ooooo`03o`000?oooooooooo01Oooooo6?l0I_l7ooooo`;o06Ko1?ooool3oc<0
o`gooooo00?o<`3oooooooooool00ol00007ooooo`;oc03o1?ooool00oo<0?ooooooooooo`0<oooo
o`04ool0VOooooooooooool0V@kooooo00?oo`00ooooool000008Oooool00ol0003oooooooooo`03
ooooo`00LOooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo01cooooo0_l0oolFoooo
o`04o`1Vooooooooooooooooo`?o<`3o3oooool01?lc0?oo0000o`000?l00008ooooo`;oc03o1Ooo
ool00oo<0?ooooooooooo`0;ooooo`;oo`2I0_ooool00ooo09Woooooooooo`0=ooooo`04ool00?oo
ooooooooo`00023ooooo00?o0000ooooooooool00oooool007;ooooo00?o0000ooooooooool0B?oo
ool00ol0003oooooooooo`0Iooooo`;o0?oo5oooool00ol0I_oooooooc<0o`02oc<0o`oooooo00?o
0000oc<0oolc0?l02oooool00oo<0?ooooooooooo`04ooooo`03ol`0oooooooooooo00_ooooo00Go
o`2Iooooooooooooooooool0V@0?ooooo`03ool00?oooooooooo00;ooooo00?o0000ooooooooool0
7_ooool00ol0003oooooooooo`02ooooo`00Loooool00ol0003oooooooooo`18ooooo`03o`000?oo
oooooooo01Kooooo0_l0oolGooooo`04o`1Voolc0?oo<`3ooc<0o`oooooo0ol000000olc0?oooooo
ooooo`09ooooo`;oc03o1_ooool00oo<0?ooooooooooo`0;ooooo`05ool0VOoooooooooooooooooo
09T03oooool00ooo003oooooooooo`04ooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool00_ooool007Cooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0Dooooo`03o`3o
oooooooooooo01Gooooo0olc0?l>ooooo`Co000000?ooooooc<0oolc0?l02_ooool2ol`0o`Oooooo
00?oc03oooooooooool02oooool01Ooo09Woooooooooooooooooo`2I00oooooo00?oo`00oooooooo
ool01_ooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00;ooooo001eooooo`;o0000
BOooool00ol0003oooooooooo`0Xooooo`?o<`3o3_ooool3o`0000Cooooo00?o<`3oooooooooool0
2?ooool2ol`0o`Sooooo00?oc03oooooooooool02_ooool2ool0V@?ooooo00?oo`2Iooooooooool0
3Oooool2ool000Sooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`02ooooo`00Mooo
ool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo02Cooooo0olc0?l00ol0I_oooooooooo
o`0:ooooo`Co00001Oooool2oc<0o`Wooooo0_o<0?l9ooooo`03ol`0oooooooooooo00[ooooo00?o
o`2Iooooooooool00_ooool00ooo09Woooooooooo`0=ooooo`;oo`002_ooool00ol0003ooooooooo
o`0Kooooo`03o`000?oooooooooo00;ooooo001hooooo`03o`000?oooooooooo04Oooooo00?o0000
ooooooooool07Oooool6oc<0o`;o06Ko2oooool3o`0000Sooooo00?o<`3oooooooooool01oooool2
ol`0o`Wooooo0_o<0?l3ooooo`Go<`3o1?ooool00ooo09Woooooooooo`02ooooo`03ool0VOoooooo
oooo00cooooo0ooo000<ooooo`03o`000?oooooooooo01[ooooo00?o0000ooooooooool00_ooool0
07Wooooo00?o0000ooooooooool0<oooool6oc<0o`kooooo00?o0000ooooooooool04oooool9oc<0
o`Cooooo0_l0I_l:ooooo`?o00002Oooool2oc<0o`Wooooo00?oc03oooooooooool01_ooool8oc<0
o`Sooooo00?oo`2Iooooooooool00_ooool00ooo09Woooooooooo`0<ooooo`03ool00?ooooooo`00
00kooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`02ooooo`00N_ooool00ol0003o
ooooooooo`0foooooa7o<`3o00?o0000ooooooooool02_ooool8oc<0o`cooooo00?o06Kooooooooo
ool01_ooool4o`0000_ooooo00?o<`3oooooooooool01oooool2ol`0o`;ooooo1olc0?l2ol`0o`co
oooo0_oo09T4ooooo`03ool0VOoooooooooo00cooooo00?oo`00oooooooo00004?ooool00ol0003o
ooooooooo`0Hooooo`03o`000?oooooooooo00;ooooo001kooooo`03o`000?oooooooooo03cooooo
5olc0?lBooooo`;o06Ko1_ooool3o`0000kooooo00?o<`3oooooooooool01?ooool2oc<0o`;oc03o
1?lc0?l6ooooo`03ol`0oooooooooooo00[ooooo0_oo09T5ooooo`03ool0VOoooooooooo00cooooo
00?oo`00oooooooo00004_ooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo00;ooooo
001looooo`03o`000?oooooooooo04Kooooo3olc0?l=ooooo`;o06Ko1?ooool4o`0000;ooooo5Olc
0?l3ol`0o`_ooooo00?oc03oooooooooool02_ooool00ooo09Woooooooooo`04ooooo`03ool0VOoo
oooooooo00_ooooo0_oo00000oooooooo`00ooooo`0Booooo`03o`000?oooooooooo01Oooooo00?o
0000ooooooooool00_ooool007gooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0:
oooooaWo<`3o3?ooool00olc0?ooooooooooo`02ooooo`Coc03o3?ooool2ol`0o`_ooooo0_oo09T6
ooooo`03ool0VOoooooooooo00_ooooo00Coo`00ooooooooooooo`005Oooool00ol0003ooooooooo
o`0Gooooo`03o`000?oooooooooo007ooooo001nooooo`03o`000?oooooooooo04Oooooo00?o0000
ooooooooool04_ooool2o`1Vo`;ooooo0ol0000Cooooo`;o<`3o00?ooooool`0ooo<0?l00_o<0?l?
ooooo`03ol`0oooooooooooo00Wooooo0_oo09T7ooooo`03ool0VOoooooooooo00_ooooo00Coo`00
ooooooooooooo`005oooool00ol0003oooooooooo`0Fooooo`03o`000?oooooooooo007ooooo001o
ooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool04?ooool00ol0I_oo0000o`000002
o`0001Cooooo00?o<`3ool`0ooo<0?l00_o<0?lAooooo`;oc03o2_ooool2ool0V@Sooooo00?oo`2I
ooooooooool02oooool01?oo003ooooooooooooo000Iooooo`03o`000?oooooooooo01Gooooo00?o
0000ooooooooool00Oooool0083ooooo0_l00018ooooo`03o`000?oooooooooo00gooooo0ol0000F
ooooo`?oc03o5?ooool00oo<0?ooooooooooo`08ooooo`;oo`2I2Oooool00ooo09Woooooooooo`0;
ooooo`04ool00?ooooooooooool001_ooooo00?o0000ooooooooool05?ooool00ol0003ooooooooo
o`01ooooo`00P_ooool00ol0003oooooooooo`16ooooo`03o`000?oooooooooo00Sooooo1?l0000E
ooooo`Coc03o5_ooool00oo<0?ooooooooooo`08ooooo`03ool0VOoooooooooo00Sooooo00?oo`2I
ooooooooool02_ooool2ool000;ooooo00?oo`00ooooooooool06oooool00ol0003oooooooooo`0C
ooooo`03o`000?oooooooooo007ooooo0023ooooo`03o`000?oooooooooo04Kooooo00?o0000oooo
ooooool01?ooool3o`0001Gooooo1?o<0?l2oc<0oaKooooo0_o<0?l9ooooo`;oo`2I2Oooool2ool0
V@cooooo00Goo`00ooooooooooooooooool0000Nooooo`03o`000?oooooooooo01?ooooo00?o0000
ooooooooool00Oooool008Cooooo00?o0000ooooooooool0A_ooool00ol0003oooooooooo`03o`00
01?ooooo1Oo<0?l2ooooo`;o<`3o5oooool00oo<0?ooooooooooo`07ooooo`;oo`2I2_ooool00ooo
09Woooooooooo`0;ooooo`05ool00?oooooooooooooooooo00008?ooool00ol0003oooooooooo`0B
ooooo`03o`000?oooooooooo007ooooo0025ooooo`03o`000?oooooooooo04Kooooo0_l0000?oooo
o`Ooc03o1_ooool00olc0?ooooooooooo`0Eooooo`;oc03o2?ooool2ool0V@[ooooo0_oo09T5ol`0
o`Sooooo00Goo`00ooooooooooooooooool0000Rooooo`03o`000?oooooooooo017ooooo00?o0000
ooooooooool00Oooool008Kooooo00?o0000ooooooooool09?ooool6ol`0oa_ooooo00?o0000oooo
ooooool01oooool7ol`0o`_ooooo0_lc0?lGooooo`03ol`0oooooooooooo00Oooooo00?oo`2Ioooo
ooooool01?ooool8ol`0o`_ooooo0_oo0003ooooo`03ool00?oooooooooo02;ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`01ooooo`00Qoooool00ol0003oooooooooo`0Woooooa;o
c03o2oooool00ol0003oooooooooo`07ol`0oa3ooooo0_lc0?lHooooo`03ol`0oooooooooooo00Ko
oooo0_oo09T7ol`0o`?ooooo0_oo09T<ooooo`;oo`001?ooool00ooo003oooooooooo`0Tooooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool00Oooool008Sooooo00?o0000ooooooooool0
;OoooolIol`0oaGooooo0_lc0?lHooooo`;oc03o0_ooool4ol`0o`?oo`2I00?oc03oooooooooool0
2?ooool00ooo09Woooooooooo`0:ooooo`;oo`001Oooool00ooo003oooooooooo`0Vooooo`03o`00
0?oooooooooo00oooooo0Ol00001ooooo`7ooooo0029ooooo`03o`000?oooooooooo03Oooooo4?o<
0?lAooooo`;o<`3o1ooooolGol`0o`Coo`2I3?ooool2ool0V@_ooooo0_oo0006ooooo`03ool00?oo
oooooooo02Oooooo00?o0000ooooooooool03oooool1o`00007ooooo0Oooool008[ooooo00?o0000
ooooooooool0@Oooool00ol0003oooooooooo`02oooooa[oc03o4?ooool2ol`0o`;ooooo0ooo09T?
ooooo`03ool0VOoooooooooo00Wooooo0_oo0007ooooo`03ool00?oooooooooo02Wooooo00?o0000
ooooooooool03_ooool1o`00007ooooo0Oooool008_ooooo0_l00011ooooo`03o`000?oooooooooo
013ooooo00?o<`3oooooooooool05oooool2ol`0o`Coo`2I4?ooool2ool0V@[ooooo0_oo0008oooo
o`03ool00?oooooooooo02_ooooo00?o0000ooooooooool03Oooool1o`00007ooooo0Oooool008go
oooo00?o0000ooooooooool0?_ooool00ol0003oooooooooo`0Xooooo`Coo`2I4oooool00ooo09Wo
ooooooooo`08ooooo`;oo`002?ooool2ool002oooooo00?o0000ooooooooool03?ooool1o`00007o
oooo0Oooool008kooooo00?o0000ooooooooool0?Oooool00ol0003oooooooooo`0Tooooo`Coo`2I
5_ooool00ooo09Woooooooooo`08ooooo`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool0
<?ooool00ol0003oooooooooo`0;ooooo`7o00000Oooool1ooooo`00Soooool00ol0003ooooooooo
o`0looooo`03o`000?oooooooooo027ooooo0ooo09T2ol`0oaKooooo0_oo09T9ooooo`;oo`002?oo
ool2ool003Cooooo00?o0000ooooooooool02_ooool1o`00007ooooo0Oooool0093ooooo00?o0000
ooooooooool0>oooool00ol0003oooooooooo`0Mooooo`Coo`2I00?ooooool`0ooo<0?l05oooool0
0ooo09Woooooooooo`07ooooo`;oo`002Oooool00ooo003oooooooooo`0dooooo`03o`000?oooooo
oooo00[ooooo0Ol00001ooooo`7ooooo002Aooooo`03o`000?oooooooooo03[ooooo00?o0000oooo
ooooool05oooool6ool0V@?ooooo0_o<0?lGooooo`;oo`2I2?ooool2ool000Wooooo0_oo000hoooo
o`03o`000?oooooooooo00Wooooo0Ol00001ooooo`7ooooo002Booooo`03o`000?oooooooooo03Wo
oooo00?o0000ooooooooool04?ooool7ool0V@Oooooo0_o<0?lHooooo`03ool0VOoooooooooo00Ko
oooo0_oo000:ooooo`03ool00?oo09Woo`2I00?oo`2I=_ooool00ol0003oooooooooo`08ooooo`7o
00000Oooool1ooooo`00Toooool00ol0003oooooooooo`0Eooooo`Koo`2I7Oooool00ol0003ooooo
ooooo`08ooooo`Soo`2I3?ooool2ol`0oaSooooo0_oo09T7ooooo`;oo`001?ooool6ool0V@;oo`00
00?oo`2Iooooooooool0>_ooool00ol0003oooooooooo`08ooooo`7o00000Oooool009Cooooo00?o
0000ooooooooool06?oooolDool0V@_ooooo00Co0000oooooooooooooooo1ooo09TBooooo`;oc03o
6Oooool00ooo09Woooooooooo`04ooooo`?oo`001_oo09T5ooooo`03ool00?oooooooooo03kooooo
00?o0000ooooooooool01oooool1o`00007ooooo002Eooooo`03o`000?oooooooooo01kooooo3?oo
09T00oooooooo`2Iool0V@0=ool0VAOooooo0_o<0?lIooooo`Koo`2I0ooo00000ooo09Wooooooooo
o`09ooooo`;oo`00@_ooool00ol0003oooooooooo`06ooooo`7o00000Oooool009Kooooo00?o0000
ooooooooool0:OoooolAool0VACooooo0_o<0?l5oooooaOoo`2I00?oooooool00?oo00000_oo000>
ooooo`03ool00?oooooooooo04;ooooo00?o0000ooooooooool01_ooool1o`00007ooooo002Goooo
o`;o0000=Oooool00ol0003oooooooooo`02oooooa_oo`2I4_ooool2ool0V@04oooooooo003oo`00
ool0013ooooo0_oo0016ooooo`03o`000?oooooooooo00Gooooo0Ol00001ooooo`00VOooool00ol0
003oooooooooo`0booooo`03o`000?oooooooooo02gooooo00?oo`2Iool00?oo00000_oo000Boooo
o`03ool00?oooooooooo04Oooooo00?o0000ooooooooool01?ooool1o`00007ooooo002Jooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool0:_ooool4ool001Cooooo0_oo001;ooooo`03
o`000?oooooooooo00?ooooo0Ol00001ooooo`00Voooool00ol0003oooooooooo`0`ooooo`03o`00
0?oooooooooo02Oooooo0ooo00000ooo09Woooooooooo`0Dooooo`03ool00?oooooooooo04cooooo
00?o0000ooooooooool00_ooool1o`00007ooooo002Looooo`03o`000?oooooooooo02oooooo00?o
0000ooooooooool08oooool4ool000;oo`2I5_ooool2ool0053ooooo00Go0000oooooooooooooooo
o`000001ooooo`00WOooool00ol0003oooooooooo`0^ooooo`03o`000?oooooooooo023ooooo0ooo
00000oooooooo`2Iool0V@0Hooooo`03ool00?oooooooooo053ooooo00Go0000oooooooooooooooo
o`000001ooooo`00W_ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo01Wooooo1ooo
0002ooooo`;oo`2I6?ooool2ool001?ooooo1?oo000mooooo`04o`000?ooooooooooooooo`7o0000
002Oooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool03_ooool;ool000Oooooo0_oo
09TIooooo`03ool00?oooooooooo00cooooo1ooo0012ooooo`03o`000?oooooooooo007o0000002P
ooooo`03o`000?oooooooooo00Gooooo1ooo000Oooooo`03o`000?oooooooooo00?ooooo2ooo000@
ooooo`;oo`2I6Oooool2ool000Sooooo1ooo001:ooooo`7o00000Oooool1o`000000XOooool00ol0
003oooooooooo`09ooooobOoo`006Oooool2ool0VAWooooo0_oo0003ooooo`Ooo`00D_ooool2o`00
0000X_ooool2o`00013ooooo3?oo000>ooooo`03o`000?oooooooooo01_ooooo00?oo`2Ioooooooo
ool05oooool7ool005Sooooo0ol000000:Cooooo00?o0000ooooooooool06OoooolAool001gooooo
6?oo001Kooooo`Co00000oooool00:Gooooo00?o0000ooooooooool09_ooool00ol0003ooooooooo
o`0Mool001Cooooo0_oo001Jooooo`?o00001oooool00:Kooooo00?o0000ooooooooool09Oooool0
0ol0003oooooooooo`0_ooooo`;oo`00F?ooool4o`0000[ooooo002Wooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool0;Oooool2ool005Kooooo1?l0000>ooooo`00Z?ooool00ol0003o
ooooooooo`0Sooooo`03o`000?oooooooooo02_ooooo0_oo001Eooooo`?o00004_ooool00:Wooooo
00?o0000ooooooooool08_ooool00ol0003oooooooooo`0Yooooo`;oo`00Doooool4o`0001Gooooo
002Zooooo`03o`000?oooooooooo027ooooo00?o0000ooooooooool09oooool2ool0057ooooo1?l0
000Iooooo`00Zoooool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo02Cooooo0_oo001?
ooooo`Co00007Oooool00:cooooo00?o0000ooooooooool08?ooool00ol0003oooooooooo`0Roooo
o`;oo`00C_ooool3o`00027ooooo002]ooooo`;o00008?ooool00ol0003oooooooooo`0Pooooo`;o
o`00C?ooool4o`0002Cooooo002_ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0
7oooool00ooo003oooooooooo`18ooooo`Co0000:?ooool00;3ooooo00?o0000ooooooooool07?oo
ool00ol0003oooooooooo`1Wooooo`?o0000;?ooool00;7ooooo00?o0000ooooooooool06oooool0
0ol0003oooooooooo`1Sooooo`Co0000;oooool00;;ooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`1Oooooo`Co0000<oooool00;?ooooo00?o0000ooooooooool06Oooool00ol0003o
ooooooooo`1Looooo`?o0000=oooool00;Cooooo00?o0000ooooooooool06?ooool00ol0003ooooo
ooooo`1Hooooo`Co0000>_ooool00;Gooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`1Dooooo`Co0000?_ooool00;Kooooo00?o0000ooooooooool05_ooool00ol0003oooooooooo`1@
ooooo`Co0000@_ooool00;Oooooo00?o0000ooooooooool05Oooool00ol0003oooooooooo`1=oooo
o`?o0000A_ooool00;Sooooo0_l0000Eooooo`03o`000?oooooooooo04Wooooo1?l00019ooooo`00
^_ooool00ol0003oooooooooo`0Booooo`03o`000?oooooooooo04Gooooo1?l0001=ooooo`00^ooo
ool00ol0003oooooooooo`0Aooooo`03o`000?oooooooooo04;ooooo0ol0001Aooooo`00_?ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo03kooooo1?l0001Dooooo`00_Oooool00ol0
003oooooooooo`0?ooooo`03o`000?oooooooooo03[ooooo1?l0001Hooooo`00__ooool00ol0003o
ooooooooo`0>ooooo`03o`000?oooooooooo03Kooooo1?l0001Looooo`00_oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo03?ooooo0ol0001Pooooo`00`?ooool00ol0003ooooooooo
o`0<ooooo`03o`000?oooooooooo02oooooo1?l0001Sooooo`00`Oooool00ol0003oooooooooo`0;
ooooo`03o`000?oooooooooo02_ooooo1?l0001Wooooo`00`_ooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo02Sooooo0ol0001[ooooo`00`oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo02Cooooo1?l0001^ooooo`00a?ooool2o`0000Wooooo00?o0000ooooooooool0
8?ooool4o`0007;ooooo0036ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool07Ooo
ool3o`0007Kooooo0037ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool06Oooool4
o`0007Wooooo0038ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool05Oooool4o`00
07gooooo0039ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool04Oooool4o`00087o
oooo003:ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool03_ooool3o`0008Gooooo
003;ooooo`05o`000?ooooooooooooooool000003?ooool4o`0008Sooooo003<ooooo`04o`000?oo
ooooooooo`0000Sooooo1?l0002<ooooo`00cOooool00ol0003oooooo`000005ooooo`?o0000T?oo
ool00<kooooo0_l000000ooooooo0000o`000002o`0009?ooooo003?ooooo`;o0000Uoooool00?oo
ooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00?ooooooJOooool00001
\
\>"],
  ImageRangeCache->{{{0, 359}, {330.375, 0}} -> {-0.0771432, -0.0315529, \
0.00350368, 0.00350368}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .92059 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-16 1.0763 -0.0263982 1.0763 [
[.01694 .18568 -11.9631 -9 ]
[.01694 .18568 .03693 0 ]
[.13793 .13897 -11.619 -9 ]
[.13793 .13897 .38095 0 ]
[.26292 .09073 -5.63752 -9 ]
[.26292 .09073 .36248 0 ]
[.39212 .04087 -5.46552 -9 ]
[.39212 .04087 .53448 0 ]
[.52574 -0.01069 -5.29351 -9 ]
[.52574 -0.01069 .70649 0 ]
[.58272 .04263 0 -6.19654 ]
[.58272 .04263 6 2.80346 ]
[.71715 .21863 0 -6.07114 ]
[.71715 .21863 6 2.92886 ]
[.83675 .37523 0 -5.963 ]
[.83675 .37523 6 3.037 ]
[.94385 .51546 0 -5.8688 ]
[.94385 .51546 6 3.1312 ]
[.01386 .20006 -12 -2.76892 ]
[.01386 .20006 0 6.23108 ]
[.00748 .25499 -24 -2.80073 ]
[.00748 .25499 0 6.19927 ]
[.00093 .31131 -6 -2.83339 ]
[.00093 .31131 0 6.16661 ]
[-0.00579 .36907 -18 -2.86695 ]
[-0.00579 .36907 0 6.13305 ]
[-0.01268 .42831 -6 -2.90143 ]
[-0.01268 .42831 0 6.09857 ]
[ 0 0 0 0 ]
[ 1 .92059 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02642 .19522 m
.53391 0 L
s
.02642 .19522 m
.03116 .2 L
s
[(-2)] .01694 .18568 .99384 1 Mshowa
.14712 .14879 m
.15172 .1537 L
s
[(-1)] .13793 .13897 .93651 1 Mshowa
.2718 .10083 m
.27624 .10588 L
s
[(0)] .26292 .09073 .87917 1 Mshowa
.40066 .05126 m
.40493 .05646 L
s
[(1)] .39212 .04087 .82184 1 Mshowa
.53391 0 m
.538 .00534 L
s
[(2)] .52574 -0.01069 .7645 1 Mshowa
.125 Mabswid
.05025 .18606 m
.05308 .18894 L
s
.07424 .17683 m
.07705 .17973 L
s
.09837 .16755 m
.10117 .17046 L
s
.12267 .1582 m
.12545 .16113 L
s
.17173 .13933 m
.17447 .14229 L
s
.19651 .1298 m
.19923 .13278 L
s
.22144 .1202 m
.22414 .1232 L
s
.24654 .11055 m
.24922 .11356 L
s
.29723 .09105 m
.29988 .0941 L
s
.32283 .0812 m
.32546 .08427 L
s
.3486 .07129 m
.35121 .07437 L
s
.37455 .06131 m
.37713 .06441 L
s
.42695 .04115 m
.4295 .04428 L
s
.45342 .03096 m
.45594 .03412 L
s
.48007 .02071 m
.48257 .02388 L
s
.5069 .01039 m
.50938 .01358 L
s
.25 Mabswid
.53391 0 m
.9804 .58403 L
s
.57014 .04738 m
.56384 .04975 L
s
[(0)] .58272 .04263 -1 .37701 Mshowa
.70445 .22307 m
.6981 .22529 L
s
[(2)] .71715 .21863 -1 .34914 Mshowa
.82396 .37939 m
.81756 .38147 L
s
[(4)] .83675 .37523 -1 .32511 Mshowa
.93098 .51938 m
.92454 .52134 L
s
[(6)] .94385 .51546 -1 .30418 Mshowa
.125 Mabswid
.60525 .09331 m
.60147 .09471 L
s
.63931 .13786 m
.63552 .13924 L
s
.67236 .1811 m
.66856 .18245 L
s
.73562 .26383 m
.7318 .26514 L
s
.7659 .30345 m
.76207 .30473 L
s
.79534 .34195 m
.7915 .34322 L
s
.85181 .41581 m
.84796 .41704 L
s
.87891 .45126 m
.87506 .45247 L
s
.90529 .48577 m
.90143 .48696 L
s
.95601 .55212 m
.95214 .55328 L
s
.25 Mabswid
.02642 .19522 m
0 .42381 L
s
.02642 .19522 m
.0327 .19281 L
s
[(-1)] .01386 .20006 1 -0.38468 Mshowa
.02006 .25024 m
.02635 .24786 L
s
[(-0.5)] .00748 .25499 1 -0.37762 Mshowa
.01354 .30664 m
.01985 .3043 L
s
[(0)] .00093 .31131 1 -0.37036 Mshowa
.00686 .36448 m
.01318 .36218 L
s
[(0.5)] -0.00579 .36907 1 -0.3629 Mshowa
0 .42381 m
.00634 .42156 L
s
[(1)] -0.01268 .42831 1 -0.35524 Mshowa
.125 Mabswid
.02516 .20612 m
.02893 .20468 L
s
.0239 .21707 m
.02767 .21563 L
s
.02262 .22807 m
.0264 .22664 L
s
.02135 .23913 m
.02512 .2377 L
s
.01877 .26141 m
.02255 .25999 L
s
.01747 .27263 m
.02125 .27122 L
s
.01617 .28391 m
.01995 .2825 L
s
.01486 .29525 m
.01864 .29384 L
s
.01222 .31809 m
.01601 .3167 L
s
.01089 .3296 m
.01468 .32821 L
s
.00955 .34117 m
.01334 .33978 L
s
.00821 .35279 m
.012 .35141 L
s
.0055 .37622 m
.0093 .37485 L
s
.00414 .38803 m
.00793 .38666 L
s
.00276 .39989 m
.00656 .39853 L
s
.00139 .41182 m
.00519 .41047 L
s
.25 Mabswid
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.54154 .92059 L
s
.54154 .92059 m
.5414 .7134 L
s
.5414 .7134 m
.02642 .19522 L
s
.53391 0 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.53391 0 m
.02642 .19522 L
s
.5414 .7134 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.54154 .92059 L
s
.54154 .92059 m
.5414 .7134 L
s
0 0 m
1 0 L
1 .92059 L
0 .92059 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.66119 .83907 m
.7426 .80009 L
s
1 0 .6 r
.64508 .80706 m
.72332 .76892 L
s
.8 0 1 r
.62895 .77504 m
.70403 .73779 L
s
.2 0 1 r
.61281 .74301 m
.68476 .70669 L
s
0 .4 1 r
.59667 .71095 m
.66551 .67561 L
s
0 1 1 r
.58052 .67889 m
.64627 .64455 L
s
0 1 .4 r
.56437 .64681 m
.62704 .61352 L
s
.2 1 0 r
.5482 .61471 m
.60783 .58251 L
s
.8 1 0 r
.53203 .5826 m
.58863 .55153 L
s
1 .6 0 r
.51585 .55048 m
.56945 .52057 L
s
1 0 0 r
.57313 .81535 m
.70129 .81152 L
s
.46266 .80774 m
.57313 .81535 L
s
1 0 .6 r
.57422 .77991 m
.69757 .77616 L
s
.46816 .77249 m
.57422 .77991 L
s
1 0 0 r
.70129 .81152 m
.809 .79846 L
s
.8 0 1 r
.57535 .74436 m
.69386 .7407 L
s
.47373 .73713 m
.57535 .74436 L
s
1 0 .6 r
.69757 .77616 m
.8016 .76335 L
s
1 0 0 r
.54324 .80797 m
.45688 .8061 L
s
.64844 .79617 m
.54324 .80797 L
s
1 .6 0 r
.56945 .52057 m
.62018 .4805 L
s
1 0 0 r
.42536 .80272 m
.46266 .80774 L
s
.8 1 0 r
.58863 .55153 m
.64281 .5095 L
s
.2 1 0 r
.60783 .58251 m
.6655 .53857 L
s
1 0 0 r
.42521 .80258 m
.45688 .8061 L
s
0 1 .4 r
.62704 .61352 m
.68826 .56773 L
s
.8 0 1 r
.69386 .7407 m
.79419 .72814 L
s
.2 0 1 r
.57649 .70869 m
.69014 .70513 L
s
.47932 .70168 m
.57649 .70869 L
s
1 0 .6 r
.42706 .76685 m
.46816 .77249 L
s
0 1 1 r
.64627 .64455 m
.71107 .59696 L
s
1 0 .6 r
.54138 .77242 m
.46078 .77065 L
s
.63967 .76122 m
.54138 .77242 L
s
0 .4 1 r
.66551 .67561 m
.73395 .62627 L
s
.2 0 1 r
.68476 .70669 m
.75689 .65566 L
s
1 0 .6 r
.46078 .77065 m
.42706 .76685 L
s
.8 0 1 r
.70403 .73779 m
.7799 .68513 L
s
.2 0 1 r
.69014 .70513 m
.78676 .69284 L
s
.8 0 1 r
.43392 .73159 m
.47373 .73713 L
s
0 .4 1 r
.57764 .67292 m
.68641 .66945 L
s
.48492 .66612 m
.57764 .67292 L
s
1 0 .6 r
.72332 .76892 m
.80296 .71468 L
s
.8 0 1 r
.53953 .73677 m
.4647 .7351 L
s
.63089 .72619 m
.53953 .73677 L
s
1 0 0 r
.7426 .80009 m
.82607 .74434 L
s
.8 0 1 r
.4647 .7351 m
.43392 .73159 L
s
.2 0 1 r
.44081 .69623 m
.47932 .70168 L
s
0 .4 1 r
.68641 .66945 m
.77931 .65745 L
s
0 1 1 r
.57879 .63702 m
.68267 .63365 L
s
.49054 .63046 m
.57879 .63702 L
s
.2 0 1 r
.53766 .701 m
.46863 .69944 L
s
.62208 .69107 m
.53766 .701 L
s
1 0 0 r
.75043 .76756 m
.64844 .79617 L
s
.2 0 1 r
.46863 .69944 m
.44081 .69623 L
s
0 .4 1 r
.44772 .66077 m
.48492 .66612 L
s
0 1 1 r
.68267 .63365 m
.77184 .62196 L
s
0 1 .4 r
.57994 .60101 m
.67892 .59775 L
s
.49617 .59469 m
.57994 .60101 L
s
0 .4 1 r
.53579 .66511 m
.47257 .66367 L
s
.61325 .65587 m
.53579 .66511 L
s
1 0 .6 r
.7348 .7341 m
.63967 .76122 L
s
0 .4 1 r
.47257 .66367 m
.44772 .66077 L
s
0 1 1 r
.45464 .62521 m
.49054 .63046 L
s
0 1 .4 r
.67892 .59775 m
.76435 .58637 L
s
.8 0 1 r
.71917 .70061 m
.63089 .72619 L
s
.2 1 0 r
.58109 .56489 m
.67515 .56174 L
s
.50182 .55882 m
.58109 .56489 L
s
0 1 1 r
.53391 .62912 m
.47653 .62779 L
s
.60439 .62058 m
.53391 .62912 L
s
.47653 .62779 m
.45464 .62521 L
s
0 1 .4 r
.46159 .58955 m
.49617 .59469 L
s
.2 0 1 r
.70352 .66709 m
.62208 .69107 L
s
.2 1 0 r
.67515 .56174 m
.75684 .5507 L
s
.8 1 0 r
.58225 .52865 m
.67138 .52562 L
s
.50749 .52284 m
.58225 .52865 L
s
0 1 .4 r
.53203 .593 m
.4805 .5918 L
s
.59552 .58519 m
.53203 .593 L
s
.4805 .5918 m
.46159 .58955 L
s
0 .4 1 r
.68786 .63354 m
.61325 .65587 L
s
.2 1 0 r
.46855 .55379 m
.50182 .55882 L
s
.8 1 0 r
.67138 .52562 m
.74932 .51492 L
s
1 .6 0 r
.58341 .49229 m
.66759 .48938 L
s
.51318 .48676 m
.58341 .49229 L
s
.2 1 0 r
.53014 .55677 m
.48448 .5557 L
s
.58662 .54972 m
.53014 .55677 L
s
0 1 1 r
.67219 .59997 m
.60439 .62058 L
s
.2 1 0 r
.48448 .5557 m
.46855 .55379 L
s
.8 1 0 r
.47553 .51794 m
.50749 .52284 L
s
1 .6 0 r
.66759 .48938 m
.74177 .47905 L
s
0 1 .4 r
.6565 .56637 m
.59552 .58519 L
s
.8 1 0 r
.52824 .52043 m
.48847 .51948 L
s
.5777 .51416 m
.52824 .52043 L
s
.48847 .51948 m
.47553 .51794 L
s
1 .6 0 r
.48254 .48198 m
.51318 .48676 L
s
.2 1 0 r
.6408 .53274 m
.58662 .54972 L
s
1 .6 0 r
.52634 .48397 m
.49247 .48316 L
s
.56876 .47852 m
.52634 .48397 L
s
.49247 .48316 m
.48254 .48198 L
s
.8 1 0 r
.62509 .49908 m
.5777 .51416 L
s
1 .6 0 r
.62018 .4805 m
.65259 .44155 L
s
.60936 .4654 m
.56876 .47852 L
s
.8 1 0 r
.64281 .5095 m
.67781 .46834 L
s
1 0 0 r
.83302 .72604 m
.75043 .76756 L
s
1 0 .6 r
.81156 .69481 m
.7348 .7341 L
s
.2 1 0 r
.6655 .53857 m
.70314 .49527 L
s
.8 0 1 r
.79013 .66363 m
.71917 .70061 L
s
.2 0 1 r
.76874 .63251 m
.70352 .66709 L
s
0 .4 1 r
.74738 .60143 m
.68786 .63354 L
s
0 1 .4 r
.68826 .56773 m
.7286 .52232 L
s
0 1 1 r
.72605 .5704 m
.67219 .59997 L
s
0 1 .4 r
.70476 .53942 m
.6565 .56637 L
s
.2 1 0 r
.6835 .50849 m
.6408 .53274 L
s
0 1 1 r
.71107 .59696 m
.75418 .5495 L
s
.8 1 0 r
.66228 .47761 m
.62509 .49908 L
s
1 .6 0 r
.64108 .44678 m
.60936 .4654 L
s
0 .4 1 r
.73395 .62627 m
.77988 .57681 L
s
.2 0 1 r
.75689 .65566 m
.8057 .60426 L
s
.8 0 1 r
.7799 .68513 m
.83165 .63183 L
s
1 0 .6 r
.80296 .71468 m
.85772 .65954 L
s
1 0 0 r
.82607 .74434 m
.8839 .68741 L
s
1 .6 0 r
.65952 .42876 m
.64108 .44678 L
s
.8 1 0 r
.68417 .45663 m
.66228 .47761 L
s
.2 1 0 r
.70892 .4846 m
.6835 .50849 L
s
1 .6 0 r
.65259 .44155 m
.66365 .42291 L
s
0 1 .4 r
.73376 .51269 m
.70476 .53942 L
s
0 1 1 r
.75871 .54089 m
.72605 .5704 L
s
0 .4 1 r
.78376 .56921 m
.74738 .60143 L
s
.8 1 0 r
.67781 .46834 m
.68958 .44903 L
s
.2 0 1 r
.80891 .59764 m
.76874 .63251 L
s
.8 0 1 r
.83416 .62618 m
.79013 .66363 L
s
1 0 .6 r
.85951 .65484 m
.81156 .69481 L
s
.2 1 0 r
.70314 .49527 m
.71565 .4753 L
s
1 .6 0 r
.66365 .42291 m
.65952 .42876 L
s
1 0 0 r
.88497 .68363 m
.83302 .72604 L
s
.8 1 0 r
.68958 .44903 m
.68417 .45663 L
s
0 1 .4 r
.7286 .52232 m
.74187 .50171 L
s
.2 1 0 r
.71565 .4753 m
.70892 .4846 L
s
0 1 1 r
.75418 .5495 m
.76822 .52827 L
s
0 1 .4 r
.74187 .50171 m
.73376 .51269 L
s
0 .4 1 r
.77988 .57681 m
.79472 .55497 L
s
0 1 1 r
.76822 .52827 m
.75871 .54089 L
s
.2 0 1 r
.8057 .60426 m
.82137 .58181 L
s
0 .4 1 r
.79472 .55497 m
.78376 .56921 L
s
.8 0 1 r
.83165 .63183 m
.84816 .60881 L
s
.2 0 1 r
.82137 .58181 m
.80891 .59764 L
s
.8 0 1 r
.84816 .60881 m
.83416 .62618 L
s
1 0 .6 r
.85772 .65954 m
.8751 .63595 L
s
.8751 .63595 m
.85951 .65484 L
s
1 0 0 r
.89996 .66619 m
.8839 .68741 L
s
.89983 .66604 m
.88497 .68363 L
s
0 g
.25 Mabswid
.53391 0 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.53391 0 m
.02642 .19522 L
s
.02642 .19522 m
.53391 0 L
s
.02642 .19522 m
.03116 .2 L
s
[(-2)] .01694 .18568 .99384 1 Mshowa
.14712 .14879 m
.15172 .1537 L
s
[(-1)] .13793 .13897 .93651 1 Mshowa
.2718 .10083 m
.27624 .10588 L
s
[(0)] .26292 .09073 .87917 1 Mshowa
.40066 .05126 m
.40493 .05646 L
s
[(1)] .39212 .04087 .82184 1 Mshowa
.53391 0 m
.538 .00534 L
s
[(2)] .52574 -0.01069 .7645 1 Mshowa
.125 Mabswid
.05025 .18606 m
.05308 .18894 L
s
.07424 .17683 m
.07705 .17973 L
s
.09837 .16755 m
.10117 .17046 L
s
.12267 .1582 m
.12545 .16113 L
s
.17173 .13933 m
.17447 .14229 L
s
.19651 .1298 m
.19923 .13278 L
s
.22144 .1202 m
.22414 .1232 L
s
.24654 .11055 m
.24922 .11356 L
s
.29723 .09105 m
.29988 .0941 L
s
.32283 .0812 m
.32546 .08427 L
s
.3486 .07129 m
.35121 .07437 L
s
.37455 .06131 m
.37713 .06441 L
s
.42695 .04115 m
.4295 .04428 L
s
.45342 .03096 m
.45594 .03412 L
s
.48007 .02071 m
.48257 .02388 L
s
.5069 .01039 m
.50938 .01358 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 265.125},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001Bb000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00`oooool5o`000:3ooooo0033ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@0X?ooool00<Cooooo00?oV9RHob4Q8Oo^k^h0XOooool00<Gooooo00?oV9RH
ob4Q8Oo^k^h0X?ooool00<Kooooo00?oMgMgofIVI_ooool0Woooool00<Oooooo00?o0000oooooooo
ool0W_ooool00<?ooooo00Go0000okZj^_ooooooV9RHoa0@402Pooooo`00`oooool01OnHV9So410@
o`000?lQ8B7oc<c<0:3ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003;ooooo`;o0000Voooool00<Sooooo0ol000000ooooooo0000ooooo`2Jooooo`00a_oo
ool2o`0000Cooooo0_l0002Jooooo`00`oooool3o`0000Kooooo00?o0000ooooool00000VOooool0
0<3ooooo1?l00008ooooo`04o`000?ooooooooooo`0009Sooooo002Hooooo`Co000000?o410@oooo
ooooool07oooool2o`0000Cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0002H
ooooo`00V_ooool00ol0003oooooooooo`0Nooooo`?o00003_ooool01Ol0003ooooooooooooooooo
000009Oooooo002Jooooo`03o`000?oooooooooo01cooooo0_l0000Aooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0U?ooool009[ooooo00?o0000ooooooooool06Oooool3o`0000;o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo09?o
oooo002Jooooo`03o`000?oooooooooo01Kooooo0ol0000Fooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^08Kooooo002Jooooo`03o`00
0?oooooooooo01Cooooo0_l0000Iooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1oooool01OmgMgOoV9RHoooooonHV9SoMgMg08Kooooo002Jooooo`03o`000?oooooooooo017ooooo
0ol000000ooooooo0000ooooo`0Hooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1_ooool01Ol@413ooooooooooooooooo410@08Kooooo002Hooooo`03oeEEEOmVIVKo0000017ooooo
0_l0000Nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool01Ol0003ooooo
oooooooooooo000008Kooooo002Yooooo`?o00008?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000026ooooo`00Yoooool3o`0002;ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@
4100Q_ooool00:Cooooo0ol00002ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Q_ooool00:7ooooo
0ol0000Xooooo`03o`000?oooooooooo00Sooooo0_l00004ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h0Q_ooool009oooooo0_l0000[ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo
0000S_ooool009cooooo0ol000000ooooooo0000ooooo`0Zooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0S?ooool009[ooooo0_l00005ooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`2;ooooo`00Uoooool3o`0003;ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`2:ooooo`00K?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^02?ooooo0ol000000ooooooo0000ooooo`0booooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0ROooool006cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Qooooo`;o0000>?ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo08Wooooo001/ooooo`05oa0@4?oooooooooo
ooooool@41007_ooool3o`0003[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`28
ooooo`00K?ooool01Ol0003ooooooooooooooooo000001cooooo0ol0000looooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0Qoooool006cooooo00Go0000ooooooooooooooooo`00000I
ooooo`?o00000_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool0Q_ooool006cooooo00Go410@oooooooooooooooooa0@400Gooooo`;o0000@_ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo08Kooooo001/ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL05?ooool3o`0004Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`25
ooooo`00K?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^017ooooo0ol00002ooooo`03o`000?oooooo
oooo04;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`24ooooo`00P?ooool2o`00
04[ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`23ooooo`00OOooool3o`0004co
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`22ooooo`00Noooool2o`000003oooo
ool0003ooooo04cooooo00?o0000ooooooooool05?ooool2o`0008?ooooo001hooooo`?o0000DOoo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooo000008?ooooo001eooooo`?o0000E?ooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo083ooooo001cooooo`Co0000EOooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo07oooooo001`ooooo`?o00001?ooool00ol0003o
ooooooooo`1Booooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0Ooooool006kooooo
0_l0001Looooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0O_ooool004?ooooo1?l0
00000ol@413oooooooooo`0Qooooo`?o0000G_ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo07gooooo0015ooooo`03o`000?oooooooooo023ooooo0ol00003ooooo`03o`000?oooooo
oooo05_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1looooo`00>_ooool6o`00
00Gooooo00?o0000ooooooooool07_ooool2o`0006Cooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`1looooo`00AOooool00ol0003oooooooooo`0Kooooo`?o0000I_ooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo07_ooooo0015ooooo`03o`000?oooooooooo01Wooooo
0_l00002ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`1jooooo`00AOooool00ol0003oooooooooo`0Fooooo`?o0000Joooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo07Wooooo0015ooooo`03o`000?oooooooooo01Cooooo0_l0001^
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0NOooool004?ooooo00?oEEEEofIV
I_l000004oooool3o`000003ooooool0003ooooo06gooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`1hooooo`00E_ooool3o`0007?ooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`1gooooo`00E?ooool2o`0007Kooooo00?o0000ooooooooool07oooool2o`0007Sooooo
001Aooooo`?o000000?oooooo`000?ooool0MOooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo07Kooooo001?ooooo`;o0000Noooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo07Gooooo001<ooooo`?o0000OOooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
07Cooooo0019ooooo`Co0000Ooooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo07?o
oooo0017ooooo`;o00001?ooool00ol0003oooooooooo`1looooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool0L_ooool004Cooooo0ol00025ooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool0L_ooool001[ooooo1Ol0000Sooooo`?o0000Qoooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo077ooooo000Jooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@08?ooool3
o`0000?ooooo00?o0000ooooooooool0Q?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo073ooooo000Booooo`Ko00000oooool00onHV9So8B4Qonk^kP0Oooooo`;o0000SOooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo06oooooo000Looooo`03oiRHV?lQ8B7ok^k^01_o
oooo0ol0002?ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0Koooool001gooooo
00?oMgMgofIVI_ooool05oooool3o`0000?ooooo00?o0000ooooooooool0S?ooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooooooo06kooooo000Nooooo`03o`000?oooooooooo01Cooooo0_l0
002Eooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0KOooool001[ooooo00Go0000
okZj^_ooooooV9RHoa0@400Cooooo`?o0000Uoooool00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo06cooooo000Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`04Oooool2o`0000?ooooo00?o
0000ooooooooool0U?ooool00ol0003oooooooooo`0Zooooo`;o0000KOooool002gooooo0ol0002L
ooooo`03o`000?oooooooooo02[ooooo0_l0001]ooooo`00:_ooool3o`0009oooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`1Zooooo`00:?ooool2o`0000?ooooo00?o0000oooooooo
ool0W?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo06Wooooo000Uooooo`?o0000
Y?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo06Wooooo000Tooooo`03o`000?oo
oooooooo0:Gooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1Xooooo`006_ooool4
o`000003oa0@4?oooooooooo00?ooooo0_l0002Vooooo`03o`000?oooooooooo02oooooo00?o0000
ooooooooool0Ioooool001cooooo00?o0000ooooooooool01Oooool2o`000:Kooooo00?o0000oooo
ooooool0<?ooool00ol0003oooooooooo`1Vooooo`004Oooool6o`0000Gooooo00?o0000oooooooo
ool01?ooool4o`000:Gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`08ooooo`Go
0000FOooool001cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0002Tooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool01OnHV9So8B4Qonk^k_ooooooA4A4
05Wooooo000Looooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`2Qooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool01oooool00onHV9So
8B4Qonk^kP1Jooooo`007?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0X?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Oooooo
00?oV9RHob4Q8Oo^k^h0FOooool001cooooo00?o0000ooooooooool01?ooool2o`0000Gooooo00?o
0000ooooooooool0Woooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Oooooo00?o
MgMgofIVI_ooool0F?ooool001[ooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo09kooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo05Oooooo000Sooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0WOooool00ol0003oooooooooo`0eooooo`;o00001?ooool01Ol0003o^[ZjoooooonHV9So
410@05Wooooo000Sooooo`;o00002?ooool00ol0003oooooooooo`2Looooo`03o`000?oooooooooo
03?ooooo0_l000000ooooooo0000ooooo`03ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0FOooool0
02?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2Kooooo`03o`000?oooooooooo
03Oooooo00?o0000ooooooooool0Goooool002?ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`2Jooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0Goooool002?ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`2Hooooo`;o0000>_ooool00ol0003ooooo
ooooo`1Nooooo`008_ooool2o`0000gooooo00?o0000ooooooooool0U?ooool3o`000003ooooool0
003ooooo03[ooooo00?o0000ooooooooool0GOooool002;ooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`2@ooooo`?o00001Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooo
oooo05cooooo000Rooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0S?ooool3o`00
00Wooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1Looooo`008_ooool3o`0000oo
oooo00?o0000ooooooooool0R?ooool3o`0000gooooo00?o0000ooooooooool0>?ooool00ol0003o
ooooooooo`1Kooooo`008_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo08Gooooo
0_l0000Aooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0F_ooool002;ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`21ooooo`?o00005?ooool00ol0003ooooooooo
o`0hooooo`03o`000?oooooooooo05Wooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool0OOooool3o`0001Oooooo00?o0000ooooooooool0>?ooool00ol0003ooooo
ooooo`1Iooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1iooooo`?o0000
6oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo05Sooooo0005o`0000;ooooo00Go
410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`1eooooo`?o00007oooool00ol0003oooooooooo`0hooooo`03o`00
0?oooooooooo05Oooooo0007ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8b
ooooo`03ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0LOooool3o`0002?ooooo
00?o0000ooooooooool0=oooool2o`0005Sooooo0007ooooo`05o`000?ooooooooooooooool00000
3?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`1^ooooo`;o00009oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo05Go
oooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`;o
00006Oooool00ol0003oooooooooo`1Zooooo`?o0000:_ooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo05Gooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0I_ooool3o`0002go
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1Dooooo`001oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool0H_ooool3o`00037ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1Cooooo`00
8Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo05kooooo0ol0000eooooo`03o`00
0?oooooooooo03Sooooo00?o0000ooooooooool0D_ooool0023ooooo0ol0000Mooooo`03o`000?oo
oooooooo05_ooooo0_l0000iooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0D_oo
ool0027ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1Gooooo`?o0000??ooool0
0ol0003oooooooooo`0gooooo`03o`000?oooooooooo057ooooo000Pooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool0Doooool3o`00043ooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`1@ooooo`008?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo04oo
oooo0ol00013ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0Coooool0023ooooo
0_l0000Rooooo`03o`000?oooooooooo04_ooooo0ol00017ooooo`03o`000?oooooooooo03Oooooo
00?o0000ooooooooool0Coooool0023ooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`18ooooo`;o0000Boooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo04kooooo000P
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0A?ooool3o`0004kooooo00?o0000
ooooooooool0=oooool00ol0003oooooooooo`1=ooooo`008?ooool3o`0002Cooooo00?o0000oooo
ooooool0@?ooool3o`0005;ooooo00?o0000ooooooooool0=_ooool2o`0004kooooo000Pooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0??ooool3o`0005Kooooo00?o0000oooooooo
ool0=_ooool00ol0003oooooooooo`1<ooooo`005?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oo
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0hooooo`?o0000FOooool00ol0003o
ooooooooo`0gooooo`03o`000?oooooooooo04_ooooo000Dooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo03Gooooo0_l0001Mooooo`03
o`000?oooooooooo03Oooooo00?o0000ooooooooool0B_ooool001Cooooo00Go410@oooooooooooo
oooooa0@4006ooooo`;o0000:_ooool00ol0003oooooooooo`0aooooo`?o0000H?ooool00ol0003o
ooooooooo`0gooooo`03o`000?oooooooooo04Wooooo000Dooooo`05o`000?ooooooooooooooool0
00001_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo02gooooo0ol0001Tooooo`03
o`000?oooooooooo03Kooooo00?o0000ooooooooool0BOooool001Cooooo00Go0000oooooooooooo
ooooo`000006ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0:Oooool3o`0006So
oooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`18ooooo`005?ooool01Ol@413ooooo
oooooooooooo410@00Kooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Uooooo`?o
0000K?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo04Oooooo000Dooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool2o`0002kooooo00?o0000ooooooooool08Oooool3o`0006oo
oooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`16ooooo`005?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Nooooo`;o
0000Loooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo04Gooooo000Oooooo`03o`00
0?oooooooooo02oooooo00?o0000ooooooooool06_ooool3o`0007Kooooo00?o0000ooooooooool0
=_ooool00ol0003oooooooooo`15ooooo`007_ooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo01Kooooo0ol0001jooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0A?oo
ool001kooooo0_l0000cooooo`03o`000?oooooooooo01;ooooo0ol0001nooooo`03o`000?oooooo
oooo03Kooooo0_l00014ooooo`007_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo
00kooooo0ol00022ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooool00000A?ooool001ko
oooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0;ooooo`;o0000QOooool00ol0003o
ooooooooo`0fooooo`03o`000?oooooooooo04;ooooo000Nooooo`03o`000?oooooooooo03Gooooo
00?o0000ooooooooool01oooool3o`0008Sooooo00?o0000ooooooooool0=_ooool00ol0003ooooo
ooooo`11ooooo`007_ooool2o`0003Oooooo00?o0000ooooooooool00oooool3o`0008cooooo00?o
0000ooooooooool0=_ooool00ol0003oooooooooo`10ooooo`007_ooool00ol0003oooooooooo`0g
ooooo`03o`000?oooooo000000;o0000T?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooo
oooo03oooooo000Nooooo`03o`000?oooooooooo03Kooooo0ol0002Dooooo`03o`000?oooooooooo
03Gooooo00?o0000ooooooooool0?oooool001kooooo0_l0000eooooo`;o00000oooool00ol0003o
ooooooooo`2Booooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool02Oooool2o`000003
oa0@4?oooooooooo033ooooo000Mooooo`03o`000?oooooooooo03;ooooo0ol00006ooooo`03o`00
0?oooooooooo097ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo037ooooo0002ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo
00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo02oooooo0ol0000:ooooo`03
o`000?oooooooooo097ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`05ooooo`Go
0000<_ooool000;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo
<S8booooo`04ooooo`03o`000?oooooooooo02cooooo0ol0000>ooooo`03o`000?oooooooooo097o
oooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`05ooooo`04odA4A?oMgMgoooooo`00
03?ooooo0002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03oooo
o`;o0000:_ooool3o`0001;ooooo00?o0000ooooooooool0TOooool00ol0003oooooooooo`0eoooo
o`03o`000?oooooooooo00Cooooo00CogMgMoeEEEOoooooo0000<oooool000;ooooo00Go0000oooo
ooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool09oooool2
o`0001Kooooo00?o0000ooooooooool0TOooool00ol0003oooooooooo`0eooooo`03o`000?oooooo
oooo00Cooooo00?oMgMgolc<c?l00000<oooool000;ooooo00Go0000ooooooooooooooooo`00000<
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Tooooo`?o00006Ooo
ool00ol0003oooooooooo`2Aooooo`03o`000?oooooooooo03Cooooo0_l00005ooooo`03onk^k_m4
A4Co000003?ooooo0002ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo027ooooo0ol0000Mooooo`03o`000?oooooooooo093ooooo00?o
0000ooooooooool0<oooool01?l0003oooooooooool00005ooooo`03ogMgMol0003ooooo03;ooooo
0002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`;o0000
7oooool3o`00027ooooo00?o0000ooooooooool0T?ooool00ol0003oooooooooo`0eooooo`03o`00
0?oooooooooo03Sooooo0002ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo
00?o0000ooooooooool07?ooool3o`0002Gooooo00?o0000ooooooooool0T?ooool00ol0003ooooo
ooooo`0eooooo`03o`000?oooooooooo03Oooooo000Looooo`03o`000?oooooooooo01Wooooo0ol0
000Yooooo`03o`000?oooooooooo093ooooo00?o0000ooooooooool0=Oooool00ol0003ooooooooo
o`0fooooo`007?ooool00ol0003oooooooooo`0Gooooo`;o0000;Oooool00ol0003oooooooooo`2@
ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0=Oooool001cooooo0_l0000Eoooo
o`?o0000<?ooool00ol0003oooooooooo`2@ooooo`03o`000?oooooooooo03Cooooo00?o0000oooo
ooooool0=Oooool001cooooo00?o0000ooooooooool04Oooool3o`0003Cooooo00?o0000oooooooo
ool0Soooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo03Cooooo000Looooo`03o`00
0?oooooooooo00kooooo0ol0000hooooo`03o`000?oooooooooo08oooooo00?o0000ooooooooool0
=Oooool00ol0003oooooooooo`0cooooo`007?ooool00ol0003oooooooooo`0;ooooo`?o0000??oo
ool00ol0003oooooooooo`2?ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0<_oo
ool001cooooo0_l0000:ooooo`;o0000@?ooool00ol0003oooooooooo`2?ooooo`03o`000?oooooo
oooo03Cooooo00?o0000ooooooooool0<_ooool001_ooooo0_l00008ooooo`?o0000@oooool00ol0
003oooooooooo`2?ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0<Oooool001_o
oooo00?o0000ooooooooool01?ooool3o`0004Oooooo00?o0000ooooooooool0Soooool00ol0003o
ooooooooo`0cooooo`;o0000<_ooool001_ooooo00Co0000oooooooooooooooo0ol0001;ooooo`03
o`000?oooooooooo08kooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0_ooooo`00
6oooool4o`0004oooooo00?o0000ooooooooool0Q_ooool00oooV@3oooooooooo`05ooooo`03o`00
0?oooooooooo03Cooooo00?o0000ooooooooool0;oooool001_ooooo0_l0001Booooo`03o`000?oo
oooooooo08Gooooo00?ooiT0ooooooooool01_ooool00ol0003oooooooooo`0dooooo`03o`000?oo
oooooooo02kooooo000Aooooo`Co000000?o410@ooooooooool01Oooool00ol0003oooooooooo`1@
ooooo`03o`000?oooooooooo08?ooooo00?ooiT0ooooooooool02?ooool00ol0003oooooooooo`0d
ooooo`03o`000?oooooooooo02gooooo000Cooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool0D?ooool00ol0003oooooooooo`21ooooo`03oonI0?oooooooooo00[ooooo00?o0000oooo
ooooool0=?ooool00ol0003oooooooooo`0/ooooo`004oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo053ooooo00?o0000ooooooooool0Ooooool2oonI00gooooo00?o0000oooooooo
ool0<oooool00ol0003oooooooooo`0/ooooo`004oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo053ooooo00?o0000ooooooooool0OOooool2oonI00kooooo00?o0000ooooooooool0
=?ooool00ol0003oooooooooo`0[ooooo`004oooool00ol0003oooooooooo`0;ooooo`03o`000?oo
oooooooo053ooooo00?o0000ooooooooool0Noooool2oonI013ooooo00?o0000ooooooooool0=?oo
ool00ol0003oooooooooo`0Zooooo`004oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooo
oooo053ooooo00?o0000ooooooooool0NOooool00oooV@3ooooooonI000Aooooo`03o`000?oooooo
oooo03Cooooo00?o0000ooooooooool0:Oooool001?ooooo00?o0000ooooooooool03Oooool00ol0
003oooooooooo`1@ooooo`03o`000?oooooooooo07Kooooo0_ooV@000ooooooooiT0ooooo`0Boooo
o`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0:?ooool0017ooooo00?oEEEEofIVI_l0
00004?ooool00ol0003oooooooooo`1@ooooo`03o`000?oooooooooo07?ooooo0_ooV@02ooooo`03
oonI0?oooooooooo00cooooo00?oc?l0ooooooooool01?ooool00ol0003oooooooooo`0cooooo`03
o`000?oooooooooo02Sooooo000Uooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0
L?ooool2oonI00?ooooo00?ooiT0ooooooooool03?ooool2olco00Oooooo00?o0000ooooooooool0
<_ooool2o`0002Wooooo000Vooooo`;o0000DOooool00ol0003oooooooooo`1^ooooo`03oonI0?oo
oooooooo00?ooooo00?ooiT0ooooooooool02oooool2olco00Sooooo00?o0000ooooooooool0=?oo
ool00ol0003oooooooooo`0Vooooo`00:?ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooo
oooo06cooooo0_ooV@05ooooo`03oonI0?oooooooooo00_ooooo0_o<o`0:ooooo`03o`000?oooooo
oooo03Cooooo00?o0000ooooooooool09Oooool002Wooooo00?o0000ooooooooool0C_ooool00ol0
003oooooooooo`1Yooooo`;ooiT01_ooool00oooV@3oooooooooo`0;ooooo`03olco0?ooooooc?l0
00_ooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Uooooo`00:_ooool00ol0003o
ooooooooo`1>ooooo`03o`000?oooooooooo06Kooooo0_ooV@07ooooo`03oonI0?oooooooooo00_o
oooo00?oc?l0ooooooo<o`003Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02Co
oooo000[ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0H_ooool3oonI00Sooooo
00?ooiT0ooooooooool02oooool00oo<o`3oooooolco000?ooooo`03o`000?oooooooooo03?ooooo
00?o0000ooooooooool08oooool002cooooo00?o0000ooooooooool0C_ooool00ol0003ooooooooo
o`1Nooooo`?ooiT02oooool00oooV@3oooooooooo`0:ooooo`04olco0?ooooooooooolco013ooooo
00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Rooooo`00;Oooool00ol0003ooooooooo
o`1>ooooo`03o`000?oooooooooo05_ooooo0_ooV@0=ooooo`03oonI0?oooooooooo00[ooooo00Co
c?l0ooooooooooooc?l04Oooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo02;ooooo
000^ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0Eoooool3oonI00kooooo00?o
oiT0ooooooooool02Oooool2olco00;ooooo00?oc?l0ooooooooool02oooool00olco`3ooooooooo
o`03ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool08Oooool002oooooo00?o0000
ooooooooool0C_ooool00ol0003oooooooooo`1Aooooo`GooiT03oooool2oonI00_ooooo00Goc?l0
ooooooooooooooooolco000>ooooo`03oc?o0?oooooooooo00;ooooo0_ooV@000ol0003ooiT0oonI
000cooooo`03o`000?oooooooooo023ooooo000`ooooo`03o`000?oooooooooo04kooooo00?o0000
ooooooooool0=oooool:oonI00Sooooo1oooV@0Cooooo`03oonI0?oooooooooo00Wooooo0_o<o`03
ooooo`03olco0?oooooooooo00Wooooo0oooV@000olco`3ooiT0oonI0003oonI00?ooooo00?o0000
ooooooooool0<oooool00ol0003oooooooooo`0Oooooo`00<Oooool2o`0004oooooo00?o0000oooo
ooooool0??ooool<oonI01Wooooo00?ooiT0ooooooooool02?ooool2olco00Cooooo00?oc?l0oooo
ooooool00_ooool8oonI00;ooooo00?o<ol0ooooooooool02?ooool00ol0003oooooooooo`0boooo
o`;o00008?ooool003?ooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`16ooooo`_o
oiT03_ooool00oooV@3oooooooooo`02ooooo`KooiT000?oc?l0oonI0?ooV@000oooV@000oo<o`3o
oiT0oonI0003oonI00Wooooo0_lco`0;ooooo`03o`000?oooooooooo037ooooo0_l0000Pooooo`00
=?ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo053ooooo4oooV@04ooooo`;oc?l0
1_ooool00oo<o`3oooooooooo`0;ooooo`;o<ol03?ooool00ol0003oooooooooo`0cooooo`03o`00
0?oooooooooo01gooooo000eooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0F_oo
ool2oonI00Sooooo0_o<o`07ooooo`03olco0?oooooooooo00_ooooo0_lco`0>ooooo`03o`000?oo
oooooooo03?ooooo00?o0000ooooooooool07?ooool003Kooooo00?o0000ooooooooool0COooool0
0ol0003oooooooooo`1Hooooo`03oonI0?oooooooooo00Oooooo00?oc?l0ooooooooool01_ooool0
0oo<o`3oooooooooo`0;ooooo`03oc?o0?oooooo<ol000oooooo00?o0000ooooooooool0<_ooool0
0ol0003oooooooooo`0Looooo`00=oooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo
05Kooooo00?ooiT0ooooooooool01_ooool2olco00Sooooo00?oc?l0ooooooooool02oooool00olc
o`3ooooooc?o000=ooooo`05o`3oI_ooooooooooooooool00000=?ooool00ol0003oooooooooo`0K
ooooo`00>?ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo05Cooooo00?ooiT0oooo
ooooool01?ooool3olco00Wooooo00?oc?l0ooooooooool02oooool00olco`3ooooooc?o000>oooo
o`03o`3oI_oooooooooo00;ooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`07oooo
o`05onk^k_lb<S;o0000oa0@4?o<c<`03_ooool003Wooooo00?o0000ooooooooool0COooool00ol0
003oooooooooo`1Aooooo`;ooiT01?ooool3olco00_ooooo00?oc?l0ooooooooool02oooool00olc
o`3ooooooc?o000>ooooo`03o`3oI_oooooooooo00Cooooo00?o0000ooooooooool0<_ooool00ol0
003oooooooooo`06ooooo`05oeEEEOmgMgOooooooiRHV?lQ8B403_ooool003[ooooo00?o0000oooo
ooooool0COooool00ol0003oooooooooo`1?ooooo`04oonI0?ooooooooooooooo`?oc?l03?ooool2
olco00cooooo0_lco`000ooooooo<ol0ooooo`0=ooooo`;o0?mV1_ooool00ol0003oooooooooo`0c
ooooo`03o`000?oooooooooo00Gooooo00Go0000ooooooooooooooooo`00000>ooooo`00>oooool0
0ol0003oooooooooo`1=ooooo`03o`000?oooooooooo04gooooo00?ooiT0ooooooo<o`000_o<o`0>
ooooo`03olco0?oooooooooo00[ooooo0_lco`03ooooo`03oc?o0?oooooooooo00_ooooo0_l0ofH8
ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool01Oooool01Ol0003oV9RHoooooonH
V9So8B4Q00kooooo000looooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0B?ooool6
olco013ooooo00?oc?l0ooooooooool02Oooool2oc?o00Cooooo00?o<ol0ooooooooool02oooool2
o`3oIPGoc?l01Oooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo00Cooooo00Go0000
oeEEEOl0003o410@olc<c00>ooooo`00?Oooool2o`0004kooooo00?o0000ooooooooool0:Oooool<
olco00Wooooo2Oo<o`02ooooo`03oonI0?oooooooooo00oooooo0_o<o`0:ooooo`;o<ol01Oooool0
0olco`3oooooooooo`05ooooo`Koc?l000?o0?mVolco0?l0ofH02oooool00ol0003oooooooooo`0b
ooooo`;o00001?ooool00omEEEGoQhN7ooooo`0@ooooo`00?oooool00ol0003oooooooooo`1<oooo
o`03o`000?oooooooooo02kooooo3oo<o`09ooooo`;ooiT04Oooool00oo<o`3oooooooooo`09oooo
o`03oc?o0?oooooooooo00Cooooo00?o<ol0olco0?o<o`001_o<o`05ooooo`03o`3oI_oooooo0?mV
00gooooo00?o0000ooooooooool0;oooool2o`000003ooooool0003ooooo00?ooooo00?ogMgMoa0@
4?nHV9P04?ooool0043ooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0hooooo`go
c?l04_ooool00oo<o`3oooooolco0008olco00;o<ol01_o<o`000olco`3oc?l0ooooo`0;ooooo`04
o`3oI_ooooooooooo`3oIPkooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`03oooo
o`04olc<c?m4A4Co0000oa0@40kooooo0011ooooo`03o`000?oooooooooo04cooooo00?o0000oooo
ooooool0@?ooool2oonI00;ooooo5?o<o`07ooooo`;o<ol02?ooool00olco`3oooooooooo`0:oooo
o`04o`3oI_ooooooooooo`3oIPgooooo00?o0?ooooooool00000=?ooool00ol0003oooooooooo`0D
ooooo`00@_ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo03kooooo00?ooiT0oooo
ooooool04Oooool2olco00Sooooo0_lco`09ooooo`03oc?o0?oooooooooo00[ooooo00Co0?mVoooo
oooooooo0?mV3_ooool01?l0ooooooooooooool0000dooooo`03o`000?oooooooooo01?ooooo0013
ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0>oooool2oonI01?ooooo00?oc?l0
ooooooooool01Oooool3oc?o00[ooooo00?o<ol0ooooooooool02_ooool01?l0ofKoooooooooool0
ofH>ooooo`03o`3ooooooooooooo00;ooooo00?o0000ooooooooool0<_ooool00ol0003ooooooooo
o`0Booooo`00A?ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo03Sooooo0_ooV@0D
ooooo`03olco0?oooooooooo00?ooooo0olco`0<ooooo`03oc?o0?oooooooooo00[ooooo00Co0?mV
oooooooooooo0?mV3_ooool00ol0ooooooooooooo`04ooooo`03o`000?oooooooooo037ooooo00?o
0000ooooooooool04_ooool004Gooooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0e
ooooo`;ooiT05?ooool2olco00;ooooo1?lco`0=ooooo`;o<ol02oooool2o`3oIP;ooooo00?o0?mV
ooooooooool02oooool2o`3oo`Sooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0A
ooooo`00A_ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo03;ooooo0_ooV@0Eoooo
o`03olco0?lco`3o<ol000;o<ol04?ooool00olco`3oooooooooo`09ooooo`;o0?mV0oooool00ol0
ofKoooooooooo`0;ooooo`03o`3ooooooooo0?oo00Wooooo00?o0000ooooooooool0<Oooool00ol0
003oooooooooo`0@ooooo`00Aoooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo033o
oooo00?ooiT0ooooooooool04oooool3oc?o01?ooooo00?o<ol0ooooooooool02Oooool00ol0ofKo
ooooooooo`02ooooo`03o`3oI_oooooooooo00_ooooo00?o0?ooooooool0ool02_ooool00ol0003o
ooooooooo`0booooo`03o`000?oooooooooo00oooooo0018ooooo`;o0000COooool00ol0003ooooo
ooooo`0]ooooo`;ooiT04Oooool5oc?o0003olco0?oooooooooo017ooooo0_lco`0:ooooo`;o0?mV
1?ooool00ol0ofKoooooooooo`0;ooooo`03o`3ooooooooo0?oo00cooooo00?o0000ooooooooool0
<Oooool00ol0003oooooooooo`0?ooooo`00B_ooool00ol0003oooooooooo`1;ooooo`03o`000?oo
oooooooo02_ooooo00?ooiT0ooooooooool02oooool6oc?o00?ooooo0_o<o`0Cooooo`03oc?o0?oo
oooooooo00Sooooo0_l0ofH5ooooo`03o`3oI_oooooooooo00_ooooo00Go0?oooc?o0?lco`3o0?oo
oc?o000<ooooo`03o`000?oooooooooo037ooooo0_l0000?ooooo`00Boooool00ol0003ooooooooo
o`1;ooooo`03o`000?oooooooooo01[ooooo3olco`09ooooo`Ko<ol01oooool2olco01Cooooo00?o
<ol0ooooooooool01oooool2o`3oIPKooooo00?o0?mVooooooooool00oooool8oc?o0004o`3ooooo
ooooooooo`3oo`gooooo00?o06Koooooool00000<_ooool2o`0000oooooo001<ooooo`03o`000?oo
oooooooo04_ooooo00?o0000ooooooooool08?oooolAoc?o00_ooooo0_o<o`0Dooooo`;o<ol02?oo
ool2o`3oIPGooooo0_lco`000ol0ofKo<ol0oc?o0004oc?o00Oooooo00Co0?oooooooooooooo0?oo
3_ooool01?l0I_ooooooooooool0000cooooo`03o`000?oooooooooo00cooooo001=ooooo`03o`00
0?oooooooooo04_ooooo00?o0000ooooooooool0:oooool=oc?o0003ooooooo<o`3oc?l001?ooooo
3?lco`000ol0ofKo<ol0oc?o0005oc?o0003ooooool0ofKooooo00cooooo00Co0?oooooooooooooo
0?oo3_ooool00ol0I_ooooooooooo`02ooooo`03o`000?oooooooooo037ooooo00?o0000oooooooo
ool02oooool004kooooo00?o0000ooooooooool0Boooool00ol0003oooooooooo`0fooooo`03olco
0?lco`3o<ol001Ko<ol02?ooool2o`3oIPSooooo00?o0?mVooooooooool02oooool01?l0oooooooo
ooooool0ool>ooooo`;o06Ko1?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00_o
oooo001?ooooo`03o`000?oooooooooo04_ooooo00?o0000ooooooooool0=?ooool00oo<o`3ooooo
ooooo`0Dooooo`03oc?o0?oooooooooo00Gooooo0ol0ofH8ooooo`;o0?mV3Oooool01?l0oooooooo
ooooool0ool?ooooo`03o`1Voooooooooooo00Cooooo00?o0000ooooooooool0<Oooool00ol0003o
ooooooooo`0:ooooo`00D?ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo037ooooo
0_o<o`0Fooooo`03oc?o0?oooooooooo00?ooooo0ol0ofH:ooooo`03o`3oI_oooooooooo00_ooooo
0_l0ool2ooooo`03o`3ooooooooooooo00cooooo0_l0I_l8ooooo`03o`000?oooooooooo037ooooo
00?o0000ooooooooool02Oooool0057ooooo00?o0000ooooooooool0Boooool00ol0003ooooooooo
o`0^ooooo`;oc?l05_ooool2oc?o00;ooooo1?l0ofH<ooooo`03o`3oI_oooooooooo00[ooooo0_l0
ool3ooooo`03o`3ooooooooooooo00cooooo00?o06Koooooool0I_l02Oooool00ol0003ooooooooo
o`0aooooo`03o`000?oooooooooo00Sooooo001Booooo`03o`000?oooooooooo04_ooooo00?o0000
ooooooooool0:oooool2olco01Oooooo00?o<ol0ooooool0ofH00_l0ofH>ooooo`;o0?mV2oooool2
o`3oo`Gooooo00?o0?ooooooooooool02oooool00ol0I_ooooooo`1Vo`0;ooooo`03o`000?oooooo
oooo033ooooo00?o0000ooooooooool02?ooool005?ooooo0_l0001<ooooo`03o`000?oooooooooo
02Sooooo0_o<o`0Gooooo`Co0?mV4?ooool00ol0ofKoooooooooo`0:ooooo`03o`3ooooooooooooo
00Cooooo00?o0?ooooooooooool02oooool01?l0I_ooooooooooool0I_l<ooooo`03o`000?oooooo
oooo033ooooo00?o0000ooooooooool01oooool005Gooooo00?o0000ooooooooool0B_ooool00ol0
003oooooooooo`0Vooooo`03olco0?oooooooooo01Cooooo0ol0ofH00olco`3oooooooooo`0@oooo
o`03o`3oI_oooooooooo00Wooooo0_l0ool6ooooo`03o`3ooooooooooooo00_ooooo00Co06Kooooo
oooooooo06Ko3Oooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Kooooo001Foooo
o`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0=oooool5o`3oIP;o<ol04_ooool2o`3o
IP[ooooo0_l0ool7ooooo`03o`3ooooooooooooo00Oooooo0ol0ofH2o`1Vo`;ooooo00?o06Kooooo
ooooool03?ooool00olc0?oo0000ooooo`0`ooooo`?o00001oooool005Oooooo00?o0000oooooooo
ool0B_ooool00ol0003oooooooooo`0_ooooo`Oo0?mV0oooool2oc?o01?ooooo00?o0?mVoooooooo
ool02?ooool2o`3oo`Sooooo00Co0?oooooooooooooooooo1ol0ofH2ooooo`05o`1Voooooooooooo
ooooool0I_l03_ooool01?lc0?ooooooooooool0000]ooooo`?o00000_ooool00ol0003ooooooooo
o`05ooooo`00F?ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo00cooooo4?l0ofH;
ooooo`Oo0?mV2Oooool00olco`3oooooooooo`0Booooo`03o`3oI_oooooooooo00Oooooo0_l0ool7
ooooo`;o0?mV00?o0?ooo`3oI_l0ofH00_l0ofH8ooooo`05o`1Vooooooooooooooooool0I_l03_oo
ool00olc0?ooooooooooo`02ooooo`03o`000?oooooooooo02Oooooo0ol00005ooooo`03o`000?oo
oooooooo00Gooooo001Iooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool04_oooolD
o`3oIPkooooo0_lco`0Cooooo`;o0?mV2Oooool00ol0ooooooooooooo`07o`3oIP03ooooool0oooo
oooo00_ooooo00Go06Koooooooooooooooooo`1Vo`0>ooooo`03oc<0oooooooooooo00Cooooo00?o
0000ooooooooool08_ooool4o`0000Sooooo00?o0000ooooooooool01Oooool005[ooooo00?o0000
ooooooooool0B_ooool00ol0003oooooooooo`0Mooooo`ko0?mV1_ooool2oc?o00oooooo3ol0ofH2
o`3oo`?o0?mV1_ooool2o`3oo`cooooo00Go06Koooooooooooooooooo`1Vo`0=ooooo`?o<`3o1ooo
ool00ol0003oooooooooo`0Nooooo`?o00003?ooool00ol0003oooooooooo`05ooooo`00Foooool0
0ol0003oooooooooo`1:ooooo`03o`000?oooooooooo02[ooooo5ol0ofH4ooooo`03o`3oI_oooooo
oooo00Gooooo0ol0ool:ooooo`03o`3ooooooooooooo00[ooooo0_l0I_l3ooooo`03o`1Voooooooo
oooo00_ooooo00?o<`3ooooooolc0?l02?ooool00ol0003oooooooooo`0Jooooo`Co00003oooool0
0ol0003oooooooooo`05ooooo`00G?ooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo
02_ooooo0_lco`0Eooooo`;o0?mV1Oooool3o`3oo`cooooo00?o0?ooooooooooool02Oooool2o`1V
o`Cooooo00?o06Koooooooooool02oooool00olc0?oooooooc<0o`0:ooooo`03o`000?oooooooooo
01Kooooo0ol0000Dooooo`03o`000?oooooooooo00Cooooo001Mooooo`03o`000?oooooooooo04[o
oooo00?o0000ooooooooool0:Oooool00olco`3oooooooooo`0Dooooo`03o`3oI_oooooooooo00;o
oooo0ol0ool=ooooo`;o0?oo2_ooool2o`1Vo`Gooooo00?o06Koooooooooool02oooool01?lc0?oo
oooooooooolc0?l;ooooo`03o`000?oooooooooo01;ooooo0ol0000Gooooo`03o`000?oooooooooo
00Cooooo001Nooooo`;o0000Boooool00ol0003oooooooooo`0Vooooo`;o<ol05_ooool00ol0ofKo
ooooo`3oo`03o`3oo`oooooo00?o0?ooooooooooool02Oooool00ol0I_ooooooooooo`04ooooo`03
o`1Voooooooooooo00_ooooo00Co<`3ooooooooooooo<`3o3Oooool00ol0003oc03oooooo`0=oooo
o`Co00006_ooool00ol0003oooooooooo`04ooooo`00H?ooool00ol0003oooooooooo`19ooooo`03
o`000?oooooooooo02?ooooo0_lco`0Fooooo`04o`3oI_l0oooo0?ooo`3ooa7ooooo0_l0ool:oooo
o`;o06Ko1_ooool00ol0I_ooooooooooo`0;ooooo`04oc<0oooooooooooooc<0o`oooooo00?o0000
ooooooooool02Oooool3o`0001kooooo00?o0000ooooooooool01?ooool0067ooooo00?o0000oooo
ooooool0BOooool00ol0003oooooooooo`0Qooooo`03oc?o0?oooooooooo01Cooooo0ol0oolCoooo
o`03o`3ooooooooooooo00Sooooo0_l0I_l7ooooo`03o`1Voooooooooooo00_ooooo00Co<`3ooooo
oooooooo<`3o3oooool00oo<0?ooooooo`000006ooooo`Co00008Oooool00ol0003oooooooooo`04
ooooo`00H_ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo03Cooooo0ol0oolEoooo
o`03o`3ooooooooooooo00Oooooo0_l0I_l8ooooo`03o`1Voooooooooooo00_ooooo00Co<`3ooooo
oooooooo<`3o3oooool01?o<0?ooooooooooool00003ooooo`?o00009Oooool00ol0003ooooooooo
o`04ooooo`00Hoooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo02gooooo1_l0ool2
o`3oIQCooooo0_l0ool8ooooo`;o06Ko2Oooool00ol0I_ooooooooooo`04ooooo`Go0?oo0_ooool0
1?lc0?oooooooooooolc0?l@ooooo`04ol`0ooooooooooooooooo`?o0000:?ooool00ol0003ooooo
ooooo`04ooooo`00I?ooool00ol0003oooooooooo`19ooooo`03o`000?oooooo0?oo00Co0?oo8?oo
ool8o`3oo`Cooooo0_l0ofHEooooo`03o`3ooooooooooooo00Oooooo00?o06Koooooooooool02?oo
ool00ol0I_oo0?ooo`3oo`05o`3oo`Kooooo00Co<`3ooooooooooooo<`3o4?ooool00oo<0?oo0000
o`000002o`000003ooooool0003ooooo02Sooooo00?o0000ooooooooool01?ooool006Gooooo00?o
0000ooooooooool0BOooool00ol0003oooooooooo`02ooooo`ko0?oo3?ooool7o`3oo`[ooooo0_l0
ofHFooooo`03o`3ooooooooooooo00Kooooo0_l0I_l4ooooo`Ko0?oo00?o06Koo`3oooooool02ooo
ool01?lc0?oooooooooooolc0?l?ooooo`?oc03o1_ooool00ol0003oooooooooo`0Vooooo`03o`00
0?oooooooooo00Cooooo001Vooooo`03o`000?oooooooooo04Wooooo00?o0000ooooooooool01ooo
oolDo`3ooa3ooooo00?o0?mVooooooooool05?ooool2o`3oo`Oooooo0_l0I_l6o`3oo`Cooooo00?o
06Koooooooooool03?ooool01?lc0?oooooooooooolc0?l<ooooo`?o000000?oc03oooooooo<0?l0
2?ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooooooo00Cooooo001Wooooo`03o`000?oo
oooooooo04Wooooo00?o0000ooooooooool04?ooool?o`3oo`Wooooo0_l0ofH<oooooa7o0?oo0ol0
I_l00ol0ooooooooooooo`08ooooo`03o`1Voooooooooooo00_ooooo0_lc0?l2ooooo`03oc<0oooo
oooooooo00Sooooo0ol00002ooooo`03ol`0ooooooooc03o00[ooooo00?o0000ooooooooool09Ooo
ool00ol0003oooooooooo`03ooooo`00J?ooool00ol0003oooooooooo`19ooooo`03o`000?oooooo
oooo01kooooo5ol0ool8ooooo`;o0?oo1?ooool3o`1Vo`cooooo0_l0I_l<ooooo`;o<`3o0oooool0
0olc0?ooooooooooo`06ooooo`?o00001?ooool00oo<0?oooooool`0o`0;ooooo`04o`000?oooooo
ooooool0VBCooooo00?o0000ooooooooool00oooool006Wooooo00?o0000ooooooooool0BOooool0
0ol0003oooooooooo`0Rooooo`;o0?mV5oooool01?l0ooooooooooooooooool3o`1Vo`kooooo00?o
06Koooooooooool02_ooool2oc<0o`Cooooo00?o<`3oooooooooool00oooool4o`0000Gooooo0_o<
0?l00oooooooc03oooooo`0<ooooo`03o`000?ooooooo`2I02Cooooo00?o0000ooooooooool00ooo
ool006[ooooo0_l0001:ooooo`03o`000?oooooooooo023ooooo00?o0?mVooooooooool05_ooool0
0ol0ooooooooo`1Vo`02o`1Vo`oooooo0_l0I_l;ooooo`;o<`3o1Oooool01?lc0?oooooooooooooo
ool3o`0000Sooooo00Coc03oooooooooooooc03o3oooool00ol0003oooooooooo`0Sooooo`03o`00
0?oooooooooo00?ooooo001/ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool07Ooo
ool2o`3oIQOooooo00Co0?ooo`1Vool0I_oo06Ko4Oooool00ol0I_ooooooooooo`09ooooo`;o<`3o
1_ooool00olc0?oo0000o`000002o`0000[ooooo00Coc03oooooooooooooc03o3oooool00ooo09Wo
ooooo`00000Tooooo`03o`000?oooooooooo00?ooooo001]ooooo`03o`000?oooooooooo04Sooooo
00?o0000ooooooooool06oooool00ol0ofKoooooooooo`0Eooooo`?o06Ko4oooool00ol0I_oooooo
ooooo`08ooooo`;o<`3o1_ooool00ol0003o<`3oo`00000=ooooo`04ol`0oooooooooooool`0o`oo
oooo00Goo`2Iooooooooooooooooo`00000Sooooo`03o`000?oooooooooo00?ooooo001^ooooo`03
o`000?oooooooooo04Sooooo00?o0000ooooooooool0;oooool3o`1VoaCooooo0_l0I_l9ooooo`;o
<`3o1Oooool3o`000003oc<0oooooooooooo00_ooooo0_o<0?l2ooooo`03ol`0oooooooooooo00go
oooo0_oo09T4ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool00oooool006oooooo
00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0[ooooo`?o06Ko00?o0?ooooooooooool0
4oooool00ol0I_ooooooooooo`07ooooo`;o<`3o0oooool4o`000003oooooolc0?oo<`3o00gooooo
00Goc03ooooooooooooooooool`0o`0>ooooo`?oo`2I1Oooool00ol0003oooooooooo`0Pooooo`03
o`000?oooooooooo00?ooooo001`ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0
9?ooool6o`1Vo`;o0?oo5_ooool00ol0I_ooooooooooo`06ooooo`;o<`3o0_ooool3o`0000Cooooo
00?o<`3oooooooooool00_ooool5o`1Vo`Gooooo00Goc03ooooooooooooooooool`0o`0>ooooo`03
ool0VOooooooo`2I00Oooooo00?o0000ooooooooool07oooool00ol0003oooooooooo`03ooooo`00
LOooool00ol0003oooooooooo`0kooooo`Ko06Ko1oooool00ol0003oooooooooo`0Jooooo`Wo06Ko
1?ooool2o`3ooaKooooo0_l0I_l7ooooo`;o<`3o1?l00005ooooo`Oo06Ko2Oooool01Oo<0?oooooo
ooooooooooooc03o00kooooo00?oo`2Ioooooooo09T02Oooool00ol0003oooooooooo`0Nooooo`03
o`000?oooooooooo00?ooooo001booooo`03o`000?oooooooooo03kooooo4Ol0I_l=ooooo`So06Ko
2oooool2o`3ooaOooooo00?o06Koooooooooool01Oooool2oc<0o`;o000000?oooooo`1Vool0I_l0
1_l0I_l>ooooo`;oc03o0oooool00oo<0?ooooooooooo`0<ooooo`03ool0VOooooooo`2I00_ooooo
00?o0000ooooooooool07_ooool00ol0003oooooooooo`02ooooo`00Loooool00ol0003ooooooooo
o`14oooooaOo06Ko4Oooool2o`3ooaOooooo0_l0I_l5ooooo`?o<`3o1Ol0I_l6ooooo`03oc<0oooo
oooooooo00_ooooo0_o<0?l4ooooo`03ol`0oooooooooooo00_ooooo0_oo09T00oooooooo`2Ioooo
o`0<ooooo`03o`000?ooooooo`0001gooooo00?o0000ooooooooool00_ooool007Cooooo00?o0000
ooooooooool0B?ooool00ol0003oooooooooo`03ooooo`oo06Ko3?ooool2o`3oo`_ooooo4_l0I_l3
oc<0o`03o`1Voooooooooooo00Wooooo0_lc0?l<ooooo`;oc03o1Oooool00oo<0?ooooooooooo`0;
ooooo`04ool0VOooooooooooool0V@oooooo00?o0000ool00?ooool07?ooool00ol0003ooooooooo
o`02ooooo`00MOooool2o`0004Wooooo00?o0000ooooooooool04OoooolIo`1Vo`cooooo00?o06Ko
ooooooooool00olc0?l>ooooo`03oc<0oooooooooooo00[ooooo0_o<0?l6ooooo`03ol`0oooooooo
oooo00_ooooo00Coo`2Iooooooooooooo`2I4?ooool00ol0003oooooooooo`0Looooo`03o`000?oo
oooooooo00;ooooo001gooooo`03o`000?oooooooooo04Oooooo00?o0000ooooooooool06?ooool2
o`3ooaWooooo00?o06Kooc<0oolc0?l00_lc0?l?ooooo`;o<`3o2oooool2ol`0o`Oooooo00?oc03o
ooooooooool02oooool01?oo09Wooooooooooooo09T@ooooo`03ool00?oooooo000001gooooo00?o
0000ooooooooool00_ooool007Sooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0F
ooooo`03o`3ooooooooooooo01Oooooo0olc0?lBooooo`03oc<0oooooooooooo00Wooooo0_o<0?l8
ooooo`03ol`0oooooooooooo00_ooooo00Coo`2Iooooooooooooo`2I4?ooool01Ooo003ooooooooo
oooooooo000001cooooo00?o0000ooooooooool00_ooool007Wooooo00?o0000ooooooooool0Aooo
ool00ol0003oooooooooo`0[ooooo`Co<`3o5?ooool00olc0?ooooooooooo`08ooooo`;oc03o2Ooo
ool00oo<0?ooooooooooo`0:ooooo`;oo`2I0_ooool00ooo09Woooooooooo`0>ooooo`;oo`001?oo
ool00ol0003oooooooooo`0Iooooo`03o`000?oooooooooo00;ooooo001jooooo`03o`000?oooooo
oooo04Oooooo00?o0000ooooooooool09oooool3oc<0o`;o06Ko5?ooool2oc<0o`Wooooo0_o<0?l9
ooooo`;oc03o3?ooool01Ooo09Woooooooooooooooooo`2I00oooooo0ooo0006ooooo`03o`000?oo
oooooooo01Sooooo00?o0000ooooooooool00_ooool007_ooooo00?o0000ooooooooool0Aoooool0
0ol0003oooooooooo`0Sooooo`?o<`3o00?oooooo`1Vool0I_l05Oooool00olc0?ooooooooooo`07
ooooo`;oc03o2_ooool00oo<0?ooooooooooo`0;ooooo`05ool0VOoooooooooooooooooo09T03ooo
ool00ooo003oooooool00008ooooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool00_oo
ool007cooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Kooooo`Oo<`3o0_ooool2
o`1VoaGooooo0_lc0?l8ooooo`;oc03o2_ooool2ol`0o`gooooo00Goo`2Iooooooooooooooooool0
V@0?ooooo`03ool00?ooooooo`0000Wooooo00?o0000ooooooooool05oooool00ol0003ooooooooo
o`02ooooo`00OOooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo017ooooo2Olc0?l3
o`0000Gooooo00?o06Koooooooooool05?ooool00olc0?ooooooooooo`06ooooo`;oc03o2oooool0
0oo<0?ooooooooooo`05oc<0o`Kooooo0_oo09T3ooooo`03ool0VOoooooooooo00gooooo00?oo`00
oooooooo00002oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo007ooooo001noooo
o`03o`000?oooooooooo02cooooo1_lc0?lEooooo`03o`000?oooooooooo00Oooooo2Olc0?l6oooo
o`?o00001_ooool2o`1VoaKooooo00?o<`3oooooooooool01Oooool2ol`0o`Sooooo2?lc0?l9oooo
o`;oo`2I1?ooool00ooo09Woooooooooo`0=ooooo`03ool00?ooooooo`0000gooooo00?o0000oooo
ooooool05_ooool00ol0003oooooooooo`01ooooo`00Ooooool00ol0003oooooooooo`0_ooooob7o
<`3o2oooool4o`0000Oooooo0_l0I_lFooooo`;o<`3o1Oooool3ol`0o`;ooooo2?lc0?l2ooooo`03
ol`0oooooooooooo00[ooooo0_oo09T5ooooo`03ool0VOoooooooooo00cooooo0_oo00000ooooooo
o`00ooooo`0>ooooo`03o`000?oooooooooo01Gooooo00?o0000ooooooooool00Oooool0083ooooo
0_l0000fooooo`_o<`3o1oooool00ol0003oooooooooo`0=ooooo`?o00002Oooool2o`1VoaOooooo
00?o<`3oooooooooool00_ooool3ol`0o`Go<`3o2Oooool00oo<0?ooooooooooo`09ooooo`;oo`2I
1_ooool00ooo09Woooooooooo`0<ooooo`04ool00?ooooooooooool0017ooooo00?o0000oooooooo
ool05?ooool00ol0003oooooooooo`01ooooo`00P_ooool00ol0003oooooooooo`0noooooa3o<`3o
0oooool4o`0000[ooooo0_l0I_l7oooooaCo<`3o0oo<0?l?ooooo`;oc03o2_ooool2ool0V@Oooooo
00?oo`2Iooooooooool03?ooool01?oo003ooooooooooooo000Cooooo`03o`000?oooooooooo01?o
oooo00?o0000ooooooooool00Oooool008?ooooo00?o0000ooooooooool0A_ooool00ol0003ooooo
ooooo`04oooooa[o<`3o3_ooool2oc<0o`04ooooooo<0?ooc03ool`0oa7ooooo00?oc03ooooooooo
ool02?ooool2ool0V@Sooooo00?oo`2Iooooooooool03?ooool01?oo003ooooooooooooo000Doooo
o`03o`000?oooooooooo01?ooooo00?o0000ooooooooool00Oooool008Cooooo00?o0000oooooooo
ool0A_ooool00ol0003oooooooooo`03o`0000kooooo00?o06Koooooooooool05Oooool00olc0?oo
c03ool`0o`02ol`0oa;ooooo0_o<0?l9ooooo`;oo`2I2Oooool00ooo09Woooooooooo`0;ooooo`;o
o`000_ooool00ooo003oooooooooo`0Dooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool00Oooool008Gooooo00?o0000ooooooooool0A_ooool2o`0002Oooooo0oo<0?lEooooo`03ol`0
oooooooooooo00Sooooo00?oo`2Iooooooooool01oooool2ool0V@gooooo00Goo`00oooooooooooo
ooooool0000Hooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool00Oooool008Kooooo
00?o0000ooooooooool0AOooool00ol0003oooooooooo`0Sooooo`?oc03o5_ooool2ol`0o`Wooooo
0_oo09T9ooooo`03ool0VOoooooooooo00cooooo00Goo`00ooooooooooooooooool0000Jooooo`03
o`000?oooooooooo013ooooo00?o0000ooooooooool00Oooool008Oooooo00?o0000ooooooooool0
A?ooool00ol0003oooooooooo`0Pooooo`?oc03o00?o<`3oooooooooool05Oooool00oo<0?oooooo
ooooo`07ooooo`;oo`2I2Oooool2ool0V@kooooo00Goo`00ooooooooooooooooool0000Looooo`03
o`000?oooooooooo00oooooo00?o0000ooooooooool00Oooool008Sooooo00?o0000ooooooooool0
@oooool00ol0003oooooooooo`0Mooooo`?oc03o0_lc0?lGooooo`;oc03o2?ooool2ool0V@[ooooo
00?oo`2Iooooooooool03Oooool01Ooo003oooooooooooooooooo`0001kooooo00?o0000oooooooo
ool03oooool1o`00007ooooo0Oooool008Wooooo00?o0000ooooooooool0@_ooool00ol0003ooooo
ooooo`0Fooooo`Ooc03o00?ooooooc<0oolc0?l06?ooool00oo<0?ooooooooooo`06ooooo`;oo`2I
2_ooool2ool0V@?oc03o2oooool2ool000?ooooo00?oo`00ooooooooool07Oooool00ol0003ooooo
ooooo`0?ooooo`7o00000Oooool1ooooo`00R_ooool00ol0003oooooooooo`11ooooo`03o`000?oo
oooooooo00cooooo2_o<0?l6ooooo`;o<`3o6Oooool00oo<0?ooooooooooo`05ooooo`;oo`2I1_oo
ool5ol`0o`03ool0VOo<0?oooooo00cooooo0_oo0004ooooo`03ool00?oooooooooo01oooooo00?o
0000ooooooooool03_ooool1o`00007ooooo0Oooool008_ooooo0_l0000Nooooo`Soc03o6oooool0
0ol0003oooooooooo`02ooooo`[oc03o3_ooool2oc<0oaWooooo0_o<0?l5ooooo`?oo`2I00?ooooo
ol`0ooo<0?l01Oo<0?l4ooooo`03ool0VOoooooooooo00_ooooo0_oo0005ooooo`03ool00?oooooo
oooo027ooooo00?o0000ooooooooool03Oooool1o`00007ooooo0Oooool008gooooo00?o0000oooo
ooooool08OoooolRol`0oaKooooo0_lc0?lJooooo`03ol`0oooooooooooo00;ooooo0ooo09T4ol`0
o`Wooooo0_oo09T<ooooo`;oo`001_ooool00ooo003oooooooooo`0Sooooo`03o`000?oooooooooo
00cooooo0Ol00001ooooo`7ooooo002>ooooo`03o`000?oooooooooo02kooooo2oo<0?l4ooooo`03
o`000?oooooooooo01Kooooo0_lc0?lJooooo`?oc03o1?oo09T00oo<0?ooooooooooo`0<ooooo`03
ool0VOoooooooooo00[ooooo0_oo0007ooooo`03ool00?oooooooooo02Gooooo00?o0000oooooooo
ool02oooool1o`00007ooooo0Oooool008oooooo00?o0000ooooooooool0>?ooool;ol`0oa7ooooo
00?o<`3oooooooooool01OoooolEol`0o`?oo`2I4Oooool2ool0V@_ooooo0_oo0008ooooo`03ool0
0?oooooooooo02Oooooo00?o0000ooooooooool02_ooool1o`00007ooooo0Oooool0093ooooo00?o
0000ooooooooool0>oooool00ol0003oooooooooo`04oooooaWoc03o4Oooool4ool0VA?ooooo00?o
o`2Iooooooooool02Oooool2ool000Sooooo0_oo000Zooooo`03o`000?oooooooooo00[ooooo0Ol0
0001ooooo`7ooooo002Aooooo`03o`000?oooooooooo03[ooooo00?o0000ooooooooool0:_ooool4
ool0VAGooooo0_oo09T;ooooo`03ool00?oooooooooo00Oooooo00?oo`00ooooooooool0:oooool0
0ol0003oooooooooo`09ooooo`7o00000Oooool1ooooo`00T_ooool00ol0003oooooooooo`0ioooo
o`03o`000?oooooooooo02Oooooo0ooo09T2ol`0oaKooooo00?oo`2Iooooooooool02Oooool2ool0
00Sooooo0_oo000_ooooo`03o`000?oooooooooo00Sooooo0Ol00001ooooo`7ooooo002Cooooo`03
o`000?oooooooooo03Sooooo00?o0000ooooooooool08oooool4ool0V@03ooooooo<0?ooc03o01Ko
oooo0_oo09T:ooooo`;oo`002Oooool00ooo003oooooooooo`0`ooooo`03o`000?oooooooooo00So
oooo0Ol00001ooooo`00U?ooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo023ooooo
0ooo09T3ooooo`;oc03o5oooool00ooo09Woooooooooo`08ooooo`;oo`002Oooool2ool003Cooooo
00?o0000ooooooooool01oooool1o`00007ooooo002Eooooo`03o`000?oooooooooo03Kooooo00?o
0000ooooooooool06_ooool6ool0V@Cooooo0_o<0?lHooooo`03ool0VOoooooooooo00Oooooo0_oo
0009ooooo`;oo`00=oooool00ol0003oooooooooo`06ooooo`7o00000Oooool009Kooooo00?o0000
ooooooooool0=Oooool00ol0003oooooooooo`0Booooo`Soo`2I2?ooool2ol`0oaSooooo0_oo09T8
ooooo`;oo`002?ooool2ool0V@03ool00?oo09Woo`2I03Oooooo00?o0000ooooooooool01_ooool1
o`00007ooooo002Gooooo`;o00004?ooool4ool0VB7ooooo00?o0000ooooooooool02Oooool9ool0
V@kooooo0_o<0?lIooooo`03ool0VOoooooooooo00Kooooo0_oo00000oooooooo`2Iool0V@07ool0
V@;oo`00>oooool00ol0003oooooooooo`05ooooo`7o00000Oooool009Wooooo00?o0000oooooooo
ool04Oooool7ool0VA[ooooo00Co0000oooooooooooooooo2?oo09TEooooo`;oc03o6Oooool2ool0
V@?ooooo0ooo09T3ool000?oo`2I2?ooool00ooo003oooooooooo`0looooo`03o`000?oooooooooo
00Cooooo0Ol00001ooooo`00V_ooool00ol0003oooooooooo`0Eooooob3oo`2I6oooool2ol`0oaOo
oooo2?oo09T4ool000cooooo0_oo0010ooooo`03o`000?oooooooooo00?ooooo0Ol00001ooooo`00
Voooool00ol0003oooooooooo`0Oooooo`coo`2I1Oooool00ol0003oooooooooo`0Kooooo`03ol`0
oooooooooooo00Wooooo4?oo09T3ooooo`?oo`003oooool00ooo003oooooooooo`11ooooo`03o`00
0?oooooooooo00;ooooo0Ol00001ooooo`00W?ooool00ol0003oooooooooo`0Zooooo`_oo`2I3ooo
oolEool0V@cooooo0_oo09T00oooooooo`00ool00002ool0013ooooo0_oo0015ooooo`05o`000?oo
ooooooooooooool000000Oooool009gooooo00?o0000ooooooooool0;_ooool00ol0003ooooooooo
o`03ooooo`ooo`2I7oooool00ooo09Woo`00ool00002ool001?ooooo00?oo`00ooooooooool0AOoo
ool01Ol0003ooooooooooooooooo0000007ooooo002Nooooo`03o`000?oooooooooo02gooooo00?o
0000ooooooooool0;_ooool4ool001Gooooo0_oo0019ooooo`04o`000?ooooooooooooooo`7o0000
002Oooooo`03o`000?oooooooooo02cooooo00?o0000ooooooooool0:_ooool4ool00003ool0VOoo
oooooooo01Cooooo0_oo001<ooooo`03o`000?oooooooooo007o0000002Pooooo`03o`000?oooooo
oooo02_ooooo00?o0000ooooooooool09oooool3ool00003oooooooo09Woo`2I01Oooooo00?oo`00
ooooooooool0COooool1o`00007ooooo0Ol000000:7ooooo00?o0000ooooooooool0:_ooool00ol0
003oooooooooo`0Sooooo`Coo`000_ooool2ool0VAOooooo0_oo001Aooooo`;o0000002Rooooo`;o
0000:_ooool00ol0003oooooooooo`0Mooooo`Koo`001?ooool2ool0VASooooo00?oo`00oooooooo
ool0D?ooool3o`000000Y?ooool00ol0003oooooooooo`0Wooooo`03o`000?oooooooooo01Cooooo
2Ooo0008ooooo`;oo`2I6?ooool2ool0017ooooo1Ooo000iooooo`Co00000oooool00:Gooooo00?o
0000ooooooooool01_oo000Pooooo`03o`000?oooooooooo00_ooooo2Ooo000?ooooo`;oo`2I6?oo
ool2ool000[ooooo2Ooo000kooooo`?o00001oooool00:Kooooo00?o0000ooooooooool00ooooolF
ool000cooooo00?o0000ooooooooool00_ooool9ool001Kooooo0_oo09THooooo`;oo`000oooool9
ool0043ooooo1?l0000:ooooo`00Yoooool00ol0003oooooooooo`08ooooo`coo`001?oooolAool0
01kooooo00?oo`2Iooooooooool05?ooool9ool004Gooooo1?l0000>ooooo`00Z?ooool00ol0003o
ooooooooo`0Coooooa?oo`007OoooolLool004Wooooo0ol0000Booooo`00ZOooool00ol0003ooooo
ooooo`0Rooooo`03o`000?oooooooooo01goo`006?ooool2ool004Oooooo1?l0000Eooooo`00Z_oo
ool00ol0003oooooooooo`0Qooooo`03o`000?oooooooooo03;ooooo0ooo0015ooooo`Co00006Ooo
ool00:_ooooo00?o0000ooooooooool08Oooool00ol0003oooooooooo`0_ooooo`;oo`00A?ooool4
o`0001gooooo002/ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0;Oooool2ool0
04?ooooo0ol0000Qooooo`00[Oooool2o`00023ooooo00?o0000ooooooooool0:oooool2ool0047o
oooo1?l0000Tooooo`00[oooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo02Wooooo
0_oo000oooooo`Co0000:?ooool00;3ooooo00?o0000ooooooooool07?ooool00ol0003ooooooooo
o`0Wooooo`;oo`00?_ooool3o`0002cooooo002aooooo`03o`000?oooooooooo01_ooooo00?o0000
ooooooooool09Oooool2ool003cooooo1?l0000_ooooo`00/_ooool00ol0003oooooooooo`0Joooo
o`03o`000?oooooooooo02Cooooo00?oo`00ooooooooool0>?ooool4o`0003?ooooo002cooooo`03
o`000?oooooooooo01Wooooo00?o0000ooooooooool0G?ooool3o`0003Oooooo002dooooo`03o`00
0?oooooooooo01Sooooo00?o0000ooooooooool0F?ooool4o`0003[ooooo002eooooo`03o`000?oo
oooooooo01Oooooo00?o0000ooooooooool0E?ooool4o`0003kooooo002fooooo`03o`000?oooooo
oooo01Kooooo00?o0000ooooooooool0D?ooool4o`0004;ooooo002gooooo`03o`000?oooooooooo
01Gooooo00?o0000ooooooooool0COooool3o`0004Kooooo002hooooo`;o00005Oooool00ol0003o
ooooooooo`19ooooo`Co0000BOooool00;[ooooo00?o0000ooooooooool04_ooool00ol0003ooooo
ooooo`15ooooo`Co0000COooool00;_ooooo00?o0000ooooooooool04Oooool00ol0003ooooooooo
o`12ooooo`?o0000DOooool00;cooooo00?o0000ooooooooool04?ooool00ol0003oooooooooo`0n
ooooo`Co0000E?ooool00;gooooo00?o0000ooooooooool03oooool00ol0003oooooooooo`0joooo
o`Co0000F?ooool00;kooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`0fooooo`Co
0000G?ooool00;oooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0cooooo`?o0000
H?ooool00<3ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0_ooooo`Co0000Hooo
ool00<7ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0[ooooo`Co0000Ioooool0
0<;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0Xooooo`?o0000Joooool00<?o
oooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0Tooooo`Co0000K_ooool00<Cooooo
0_l00009ooooo`03o`000?oooooooooo023ooooo1?l0001booooo`00a_ooool00ol0003ooooooooo
o`06ooooo`03o`000?oooooooooo01gooooo0ol0001fooooo`00aoooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo01Wooooo1?l0001iooooo`00b?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo01Gooooo1?l0001mooooo`00bOooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo017ooooo1?l00021ooooo`00b_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00kooooo0ol00025ooooo`00boooool01Ol0003ooooooooooooooooo000000cooooo
1?l00028ooooo`00c?ooool01?l0003oooooooooool00008ooooo`Co0000S?ooool00<gooooo00?o
0000ooooool000001Oooool3o`00093ooooo003>ooooo`;o000000?oooooo`000?l000000_l0002C
ooooo`00coooool2o`0009Oooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003o
ooooofWooooo003oooooofWooooo0000\
\>"],
  ImageRangeCache->{{{0, 359}, {330.375, 0}} -> {-0.0771432, -0.0315529, \
0.00350368, 0.00350368}}],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .92059 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
1.11022e-16 1.0763 -0.0263982 1.0763 [
[.01694 .18568 -11.9631 -9 ]
[.01694 .18568 .03693 0 ]
[.13793 .13897 -11.619 -9 ]
[.13793 .13897 .38095 0 ]
[.26292 .09073 -5.63752 -9 ]
[.26292 .09073 .36248 0 ]
[.39212 .04087 -5.46552 -9 ]
[.39212 .04087 .53448 0 ]
[.52574 -0.01069 -5.29351 -9 ]
[.52574 -0.01069 .70649 0 ]
[.58272 .04263 0 -6.19654 ]
[.58272 .04263 6 2.80346 ]
[.71715 .21863 0 -6.07114 ]
[.71715 .21863 6 2.92886 ]
[.83675 .37523 0 -5.963 ]
[.83675 .37523 6 3.037 ]
[.94385 .51546 0 -5.8688 ]
[.94385 .51546 6 3.1312 ]
[.01386 .20006 -12 -2.76892 ]
[.01386 .20006 0 6.23108 ]
[.00748 .25499 -24 -2.80073 ]
[.00748 .25499 0 6.19927 ]
[.00093 .31131 -6 -2.83339 ]
[.00093 .31131 0 6.16661 ]
[-0.00579 .36907 -18 -2.86695 ]
[-0.00579 .36907 0 6.13305 ]
[-0.01268 .42831 -6 -2.90143 ]
[-0.01268 .42831 0 6.09857 ]
[ 0 0 0 0 ]
[ 1 .92059 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.02642 .19522 m
.53391 0 L
s
.02642 .19522 m
.03116 .2 L
s
[(-2)] .01694 .18568 .99384 1 Mshowa
.14712 .14879 m
.15172 .1537 L
s
[(-1)] .13793 .13897 .93651 1 Mshowa
.2718 .10083 m
.27624 .10588 L
s
[(0)] .26292 .09073 .87917 1 Mshowa
.40066 .05126 m
.40493 .05646 L
s
[(1)] .39212 .04087 .82184 1 Mshowa
.53391 0 m
.538 .00534 L
s
[(2)] .52574 -0.01069 .7645 1 Mshowa
.125 Mabswid
.05025 .18606 m
.05308 .18894 L
s
.07424 .17683 m
.07705 .17973 L
s
.09837 .16755 m
.10117 .17046 L
s
.12267 .1582 m
.12545 .16113 L
s
.17173 .13933 m
.17447 .14229 L
s
.19651 .1298 m
.19923 .13278 L
s
.22144 .1202 m
.22414 .1232 L
s
.24654 .11055 m
.24922 .11356 L
s
.29723 .09105 m
.29988 .0941 L
s
.32283 .0812 m
.32546 .08427 L
s
.3486 .07129 m
.35121 .07437 L
s
.37455 .06131 m
.37713 .06441 L
s
.42695 .04115 m
.4295 .04428 L
s
.45342 .03096 m
.45594 .03412 L
s
.48007 .02071 m
.48257 .02388 L
s
.5069 .01039 m
.50938 .01358 L
s
.25 Mabswid
.53391 0 m
.9804 .58403 L
s
.57014 .04738 m
.56384 .04975 L
s
[(0)] .58272 .04263 -1 .37701 Mshowa
.70445 .22307 m
.6981 .22529 L
s
[(2)] .71715 .21863 -1 .34914 Mshowa
.82396 .37939 m
.81756 .38147 L
s
[(4)] .83675 .37523 -1 .32511 Mshowa
.93098 .51938 m
.92454 .52134 L
s
[(6)] .94385 .51546 -1 .30418 Mshowa
.125 Mabswid
.60525 .09331 m
.60147 .09471 L
s
.63931 .13786 m
.63552 .13924 L
s
.67236 .1811 m
.66856 .18245 L
s
.73562 .26383 m
.7318 .26514 L
s
.7659 .30345 m
.76207 .30473 L
s
.79534 .34195 m
.7915 .34322 L
s
.85181 .41581 m
.84796 .41704 L
s
.87891 .45126 m
.87506 .45247 L
s
.90529 .48577 m
.90143 .48696 L
s
.95601 .55212 m
.95214 .55328 L
s
.25 Mabswid
.02642 .19522 m
0 .42381 L
s
.02642 .19522 m
.0327 .19281 L
s
[(-1)] .01386 .20006 1 -0.38468 Mshowa
.02006 .25024 m
.02635 .24786 L
s
[(-0.5)] .00748 .25499 1 -0.37762 Mshowa
.01354 .30664 m
.01985 .3043 L
s
[(0)] .00093 .31131 1 -0.37036 Mshowa
.00686 .36448 m
.01318 .36218 L
s
[(0.5)] -0.00579 .36907 1 -0.3629 Mshowa
0 .42381 m
.00634 .42156 L
s
[(1)] -0.01268 .42831 1 -0.35524 Mshowa
.125 Mabswid
.02516 .20612 m
.02893 .20468 L
s
.0239 .21707 m
.02767 .21563 L
s
.02262 .22807 m
.0264 .22664 L
s
.02135 .23913 m
.02512 .2377 L
s
.01877 .26141 m
.02255 .25999 L
s
.01747 .27263 m
.02125 .27122 L
s
.01617 .28391 m
.01995 .2825 L
s
.01486 .29525 m
.01864 .29384 L
s
.01222 .31809 m
.01601 .3167 L
s
.01089 .3296 m
.01468 .32821 L
s
.00955 .34117 m
.01334 .33978 L
s
.00821 .35279 m
.012 .35141 L
s
.0055 .37622 m
.0093 .37485 L
s
.00414 .38803 m
.00793 .38666 L
s
.00276 .39989 m
.00656 .39853 L
s
.00139 .41182 m
.00519 .41047 L
s
.25 Mabswid
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.54154 .92059 L
s
.54154 .92059 m
.5414 .7134 L
s
.5414 .7134 m
.02642 .19522 L
s
.53391 0 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.53391 0 m
.02642 .19522 L
s
.5414 .7134 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.54154 .92059 L
s
.54154 .92059 m
.5414 .7134 L
s
0 0 m
1 0 L
1 .92059 L
0 .92059 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.6767 .84913 m
.76093 .8091 L
s
1 0 .6 r
.66067 .81726 m
.74172 .77806 L
s
.8 0 1 r
.64462 .78539 m
.72251 .74705 L
s
.2 0 1 r
.62856 .7535 m
.70331 .71607 L
s
0 .4 1 r
.6125 .7216 m
.68412 .68511 L
s
0 1 1 r
.59642 .68968 m
.66495 .65417 L
s
0 1 .4 r
.58034 .65775 m
.64579 .62326 L
s
.2 1 0 r
.56425 .6258 m
.62665 .59237 L
s
.8 1 0 r
.54815 .59384 m
.60753 .5615 L
s
1 .6 0 r
.53205 .56186 m
.58841 .53066 L
s
1 0 0 r
.57185 .82862 m
.70425 .82469 L
s
.45747 .82079 m
.57185 .82862 L
s
1 0 .6 r
.57293 .79341 m
.70055 .78957 L
s
.46294 .78576 m
.57293 .79341 L
s
1 0 0 r
.70425 .82469 m
.81516 .81133 L
s
.8 0 1 r
.57406 .75809 m
.69687 .75433 L
s
.46847 .75063 m
.57406 .75809 L
s
1 0 0 r
.54506 .82131 m
.45335 .81933 L
s
.65666 .80886 m
.54506 .82131 L
s
1 0 .6 r
.70055 .78957 m
.80781 .77643 L
s
1 0 0 r
.44284 .81883 m
.45747 .82079 L
s
.44202 .81807 m
.45335 .81933 L
s
.2 0 1 r
.57519 .72266 m
.69318 .71899 L
s
.47401 .7154 m
.57519 .72266 L
s
.8 0 1 r
.69687 .75433 m
.80045 .74145 L
s
1 0 .6 r
.54322 .78599 m
.45722 .78411 L
s
.64796 .77413 m
.54322 .78599 L
s
.42585 .78071 m
.46294 .78576 L
s
1 .6 0 r
.58841 .53066 m
.64234 .48847 L
s
.8 1 0 r
.60753 .5615 m
.66494 .51739 L
s
1 0 .6 r
.4257 .78057 m
.45722 .78411 L
s
.2 1 0 r
.62665 .59237 m
.68759 .54638 L
s
.2 0 1 r
.69318 .71899 m
.79307 .70637 L
s
0 .4 1 r
.57632 .68712 m
.68947 .68354 L
s
.47957 .68007 m
.57632 .68712 L
s
.8 0 1 r
.42754 .74497 m
.46847 .75063 L
s
0 1 .4 r
.64579 .62326 m
.7103 .57546 L
s
.8 0 1 r
.54137 .75057 m
.46111 .74879 L
s
.63923 .73931 m
.54137 .75057 L
s
0 1 1 r
.66495 .65417 m
.73308 .60461 L
s
0 .4 1 r
.68412 .68511 m
.75592 .63384 L
s
.8 0 1 r
.46111 .74879 m
.42754 .74497 L
s
.2 0 1 r
.70331 .71607 m
.77882 .66315 L
s
0 .4 1 r
.68947 .68354 m
.78567 .67119 L
s
.2 0 1 r
.43438 .70983 m
.47401 .7154 L
s
0 1 1 r
.57746 .65146 m
.68576 .64798 L
s
.48515 .64464 m
.57746 .65146 L
s
.8 0 1 r
.72251 .74705 m
.80178 .69254 L
s
.2 0 1 r
.53952 .71503 m
.46502 .71336 L
s
.63048 .70441 m
.53952 .71503 L
s
1 0 .6 r
.74172 .77806 m
.8248 .72201 L
s
1 0 0 r
.76093 .8091 m
.84786 .75158 L
s
.2 0 1 r
.46502 .71336 m
.43438 .70983 L
s
1 0 0 r
.76503 .77867 m
.65666 .80886 L
s
0 .4 1 r
.44124 .67459 m
.47957 .68007 L
s
0 1 1 r
.68576 .64798 m
.77825 .63593 L
s
0 1 .4 r
.57861 .61569 m
.68204 .61231 L
s
.49075 .6091 m
.57861 .61569 L
s
0 .4 1 r
.53766 .67939 m
.46893 .67782 L
s
.62171 .66942 m
.53766 .67939 L
s
1 0 .6 r
.74948 .74537 m
.64796 .77413 L
s
0 .4 1 r
.46893 .67782 m
.44124 .67459 L
s
0 1 1 r
.44811 .63926 m
.48515 .64464 L
s
0 1 .4 r
.68204 .61231 m
.77081 .60056 L
s
.2 1 0 r
.57975 .57981 m
.6783 .57653 L
s
.49636 .57346 m
.57975 .57981 L
s
0 1 1 r
.5358 .64363 m
.47286 .64218 L
s
.61292 .63434 m
.5358 .64363 L
s
.8 0 1 r
.73393 .71205 m
.63923 .73931 L
s
0 1 1 r
.47286 .64218 m
.44811 .63926 L
s
0 1 .4 r
.45501 .60383 m
.49075 .6091 L
s
.2 1 0 r
.6783 .57653 m
.76335 .56511 L
s
.2 0 1 r
.71837 .6787 m
.63048 .70441 L
s
.8 1 0 r
.5809 .54381 m
.67455 .54065 L
s
.50198 .53772 m
.5809 .54381 L
s
0 1 .4 r
.53393 .60775 m
.4768 .60642 L
s
.6041 .59918 m
.53393 .60775 L
s
.4768 .60642 m
.45501 .60383 L
s
.2 1 0 r
.46192 .5683 m
.49636 .57346 L
s
0 .4 1 r
.70279 .64532 m
.62171 .66942 L
s
.8 1 0 r
.67455 .54065 m
.75588 .52956 L
s
1 .6 0 r
.58206 .5077 m
.67079 .50465 L
s
.50763 .50187 m
.58206 .5077 L
s
.2 1 0 r
.53205 .57176 m
.48075 .57056 L
s
.59526 .56392 m
.53205 .57176 L
s
.48075 .57056 m
.46192 .5683 L
s
0 1 1 r
.6872 .61191 m
.61292 .63434 L
s
.8 1 0 r
.46886 .53267 m
.50198 .53772 L
s
1 .6 0 r
.67079 .50465 m
.74838 .49391 L
s
.8 1 0 r
.53017 .53566 m
.48471 .53458 L
s
.58641 .52858 m
.53017 .53566 L
s
0 1 .4 r
.67159 .57848 m
.6041 .59918 L
s
.8 1 0 r
.48471 .53458 m
.46886 .53267 L
s
1 .6 0 r
.47581 .49694 m
.50763 .50187 L
s
.2 1 0 r
.65597 .54502 m
.59526 .56392 L
s
1 .6 0 r
.52828 .49945 m
.48869 .49849 L
s
.57753 .49316 m
.52828 .49945 L
s
.48869 .49849 m
.47581 .49694 L
s
.8 1 0 r
.64034 .51153 m
.58641 .52858 L
s
1 .6 0 r
.6247 .47802 m
.57753 .49316 L
s
.64234 .48847 m
.67718 .44716 L
s
1 0 0 r
.85309 .73475 m
.76503 .77867 L
s
1 0 .6 r
.83169 .70363 m
.74948 .74537 L
s
.8 0 1 r
.81032 .67257 m
.73393 .71205 L
s
.8 1 0 r
.66494 .51739 m
.7024 .47392 L
s
.2 0 1 r
.78899 .64155 m
.71837 .6787 L
s
0 .4 1 r
.7677 .61058 m
.70279 .64532 L
s
0 1 1 r
.74644 .57966 m
.6872 .61191 L
s
.2 1 0 r
.68759 .54638 m
.72774 .5008 L
s
0 1 .4 r
.72521 .54879 m
.67159 .57848 L
s
.2 1 0 r
.70401 .51797 m
.65597 .54502 L
s
.8 1 0 r
.68285 .48719 m
.64034 .51153 L
s
0 1 .4 r
.7103 .57546 m
.7532 .5278 L
s
1 .6 0 r
.66172 .45647 m
.6247 .47802 L
s
0 1 1 r
.73308 .60461 m
.77878 .55494 L
s
0 .4 1 r
.75592 .63384 m
.80448 .5822 L
s
.2 0 1 r
.77882 .66315 m
.83031 .6096 L
s
.8 0 1 r
.80178 .69254 m
.85626 .63713 L
s
1 0 .6 r
.8248 .72201 m
.88233 .66479 L
s
1 0 0 r
.84786 .75158 m
.90851 .69261 L
s
1 .6 0 r
.68351 .43541 m
.66172 .45647 L
s
.8 1 0 r
.70814 .46321 m
.68285 .48719 L
s
.2 1 0 r
.73287 .49113 m
.70401 .51797 L
s
0 1 .4 r
.7577 .51916 m
.72521 .54879 L
s
0 1 1 r
.78264 .5473 m
.74644 .57966 L
s
1 .6 0 r
.67718 .44716 m
.68889 .42779 L
s
0 .4 1 r
.80767 .57556 m
.7677 .61058 L
s
.2 0 1 r
.8328 .60393 m
.78899 .64155 L
s
.8 0 1 r
.85804 .63241 m
.81032 .67257 L
s
.8 1 0 r
.7024 .47392 m
.71485 .45388 L
s
1 0 .6 r
.88338 .66101 m
.83169 .70363 L
s
1 0 0 r
.90882 .68974 m
.85309 .73475 L
s
1 .6 0 r
.68889 .42779 m
.68351 .43541 L
s
.2 1 0 r
.72774 .5008 m
.74094 .48011 L
s
.8 1 0 r
.71485 .45388 m
.70814 .46321 L
s
0 1 .4 r
.7532 .5278 m
.76717 .50648 L
s
.2 1 0 r
.74094 .48011 m
.73287 .49113 L
s
0 1 1 r
.77878 .55494 m
.79355 .533 L
s
0 1 .4 r
.76717 .50648 m
.7577 .51916 L
s
0 .4 1 r
.80448 .5822 m
.82007 .55966 L
s
0 1 1 r
.79355 .533 m
.78264 .5473 L
s
.2 0 1 r
.83031 .6096 m
.84673 .58647 L
s
0 .4 1 r
.82007 .55966 m
.80767 .57556 L
s
.2 0 1 r
.84673 .58647 m
.8328 .60393 L
s
.8 0 1 r
.85626 .63713 m
.87354 .61343 L
s
.87354 .61343 m
.85804 .63241 L
s
1 0 .6 r
.89828 .6435 m
.88233 .66479 L
s
.89815 .64334 m
.88338 .66101 L
s
1 0 0 r
.91489 .68431 m
.90851 .69261 L
s
.91419 .68346 m
.90882 .68974 L
s
0 g
.25 Mabswid
.53391 0 m
.9804 .58403 L
s
.9804 .58403 m
1 .79743 L
s
1 .79743 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.02642 .19522 m
0 .42381 L
s
0 .42381 m
.53368 .23423 L
s
.53368 .23423 m
.53391 0 L
s
.53391 0 m
.02642 .19522 L
s
.02642 .19522 m
.53391 0 L
s
.02642 .19522 m
.03116 .2 L
s
[(-2)] .01694 .18568 .99384 1 Mshowa
.14712 .14879 m
.15172 .1537 L
s
[(-1)] .13793 .13897 .93651 1 Mshowa
.2718 .10083 m
.27624 .10588 L
s
[(0)] .26292 .09073 .87917 1 Mshowa
.40066 .05126 m
.40493 .05646 L
s
[(1)] .39212 .04087 .82184 1 Mshowa
.53391 0 m
.538 .00534 L
s
[(2)] .52574 -0.01069 .7645 1 Mshowa
.125 Mabswid
.05025 .18606 m
.05308 .18894 L
s
.07424 .17683 m
.07705 .17973 L
s
.09837 .16755 m
.10117 .17046 L
s
.12267 .1582 m
.12545 .16113 L
s
.17173 .13933 m
.17447 .14229 L
s
.19651 .1298 m
.19923 .13278 L
s
.22144 .1202 m
.22414 .1232 L
s
.24654 .11055 m
.24922 .11356 L
s
.29723 .09105 m
.29988 .0941 L
s
.32283 .0812 m
.32546 .08427 L
s
.3486 .07129 m
.35121 .07437 L
s
.37455 .06131 m
.37713 .06441 L
s
.42695 .04115 m
.4295 .04428 L
s
.45342 .03096 m
.45594 .03412 L
s
.48007 .02071 m
.48257 .02388 L
s
.5069 .01039 m
.50938 .01358 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 265.125},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001Bb000`400?l00000o`00003ooooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooooomY
ooooo`00oooooomYooooo`00oooooomYooooo`00`oooool5o`000:3ooooo0033ooooo`05oiRHV?lQ
8B7ok^k^oooooom4A4@0X?ooool00<Cooooo00?oV9RHob4Q8Oo^k^h0XOooool00<Gooooo00?oV9RH
ob4Q8Oo^k^h0X?ooool00<Kooooo00?oMgMgofIVI_ooool0Woooool00<Oooooo00?o0000oooooooo
ool0W_ooool00<?ooooo00Go0000okZj^_ooooooV9RHoa0@402Pooooo`00`oooool01OnHV9So410@
o`000?lQ8B7oc<c<0:3ooooo003oooooofWooooo003oooooofWooooo003oooooofWooooo003ooooo
ofWooooo003;ooooo`;o0000Voooool00<Sooooo0ol000000ooooooo0000ooooo`2Jooooo`00a_oo
ool2o`0000Cooooo0_l0002Jooooo`00`oooool3o`0000Kooooo00?o0000ooooool00000VOooool0
0<3ooooo1?l00008ooooo`04o`000?ooooooooooo`0009Sooooo002Hooooo`Co000000?o410@oooo
ooooool07oooool2o`0000Cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0002H
ooooo`00V_ooool00ol0003oooooooooo`0Nooooo`?o00003_ooool01Ol0003ooooooooooooooooo
000009Oooooo002Jooooo`03o`000?oooooooooo01cooooo0_l0000Aooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0U?ooool009[ooooo00?o0000ooooooooool06Oooool3o`0000;o
oooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo09?o
oooo002Jooooo`03o`000?oooooooooo01Kooooo0ol0000Fooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool02?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^08Kooooo002Jooooo`03o`00
0?oooooooooo01Cooooo0_l0000Iooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1oooool01OmgMgOoV9RHoooooonHV9SoMgMg08Kooooo002Jooooo`03o`000?oooooooooo017ooooo
0ol000000ooooooo0000ooooo`0Hooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1_ooool01Ol@413ooooooooooooooooo410@08Kooooo002Hooooo`03oeEEEOmVIVKo0000017ooooo
0_l0000Nooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool01Ol0003ooooo
oooooooooooo000008Kooooo002Yooooo`?o00008?ooool00ol0003oooooooooo`07ooooo`03o`00
0?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000026ooooo`00Yoooool3o`0002;ooooo
00?o0000ooooooooool01oooool00ol0003oooooooooo`04ooooo`05oa0@4?ooooooooooooooool@
4100Q_ooool00:Cooooo0ol00002ooooo`03o`000?oooooooooo023ooooo00?o0000ooooooooool0
2?ooool00ol0003oooooooooo`03ooooo`05ogMgMonHV9SooooooiRHV?mgMgL0Q_ooool00:7ooooo
0ol0000Xooooo`03o`000?oooooooooo00Sooooo0_l00004ooooo`05onk^k_lb<S;o0000oc8b<_o^
k^h0Q_ooool009oooooo0_l0000[ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo
0000S_ooool009cooooo0ol000000ooooooo0000ooooo`0Zooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0S?ooool009[ooooo0_l00005ooooo`03o`000?oooooooooo02Sooooo00?o
0000ooooooooool02oooool00ol0003oooooooooo`2;ooooo`00Uoooool3o`0003;ooooo00?o0000
ooooooooool03?ooool00ol0003oooooooooo`2:ooooo`00K?ooool01Oo^k^ko<S8bo`000?lb<S;o
k^k^02?ooooo0ol000000ooooooo0000ooooo`0booooo`03o`000?oooooooooo00gooooo00?o0000
ooooooooool0ROooool006cooooo00GoMgMgoiRHV?ooooooV9RHogMgM`0Qooooo`;o0000>?ooool0
0ol0003oooooooooo`0=ooooo`03o`000?oooooooooo08Wooooo001/ooooo`05oa0@4?oooooooooo
ooooool@41007_ooool3o`0003[ooooo00?o0000ooooooooool03_ooool00ol0003oooooooooo`28
ooooo`00K?ooool01Ol0003ooooooooooooooooo000001cooooo0ol0000looooo`03o`000?oooooo
oooo00oooooo00?o0000ooooooooool0Qoooool006cooooo00Go0000ooooooooooooooooo`00000I
ooooo`?o00000_ooool00ol0003oooooooooo`0jooooo`03o`000?oooooooooo013ooooo00?o0000
ooooooooool0Q_ooool006cooooo00Go410@oooooooooooooooooa0@400Gooooo`;o0000@_ooool0
0ol0003oooooooooo`0@ooooo`03o`000?oooooooooo08Kooooo001/ooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL05?ooool3o`0004Cooooo00?o0000ooooooooool04Oooool00ol0003oooooooooo`25
ooooo`00K?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^017ooooo0ol00002ooooo`03o`000?oooooo
oooo04;ooooo00?o0000ooooooooool04_ooool00ol0003oooooooooo`24ooooo`00P?ooool2o`00
04[ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`23ooooo`00OOooool3o`0004co
oooo00?o0000ooooooooool05?ooool00ol0003oooooooooo`22ooooo`00Noooool2o`000003oooo
ool0003ooooo04cooooo00?o0000ooooooooool05?ooool2o`0008?ooooo001hooooo`?o0000DOoo
ool00ol0003oooooooooo`0Cooooo`03o`000?oooooo000008?ooooo001eooooo`?o0000E?ooool0
0ol0003oooooooooo`0Fooooo`03o`000?oooooooooo083ooooo001cooooo`Co0000EOooool00ol0
003oooooooooo`0Gooooo`03o`000?oooooooooo07oooooo001`ooooo`?o00001?ooool00ol0003o
ooooooooo`1Booooo`03o`000?oooooooooo01Oooooo00?o0000ooooooooool0Ooooool006kooooo
0_l0001Looooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0O_ooool004?ooooo1?l0
00000ol@413oooooooooo`0Qooooo`?o0000G_ooool00ol0003oooooooooo`0Iooooo`03o`000?oo
oooooooo07gooooo0015ooooo`03o`000?oooooooooo023ooooo0ol00003ooooo`03o`000?oooooo
oooo05_ooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`1looooo`00>_ooool6o`00
00Gooooo00?o0000ooooooooool07_ooool2o`0006Cooooo00?o0000ooooooooool06_ooool00ol0
003oooooooooo`1looooo`00AOooool00ol0003oooooooooo`0Kooooo`?o0000I_ooool00ol0003o
ooooooooo`0Kooooo`03o`000?oooooooooo07_ooooo0015ooooo`03o`000?oooooooooo01Wooooo
0_l00002ooooo`03o`000?oooooooooo06Cooooo00?o0000ooooooooool07?ooool00ol0003ooooo
ooooo`1jooooo`00AOooool00ol0003oooooooooo`0Fooooo`?o0000Joooool00ol0003ooooooooo
o`0Mooooo`03o`000?oooooooooo07Wooooo0015ooooo`03o`000?oooooooooo01Cooooo0_l0001^
ooooo`03o`000?oooooooooo01gooooo00?o0000ooooooooool0NOooool004?ooooo00?oEEEEofIV
I_l000004oooool3o`000003ooooool0003ooooo06gooooo00?o0000ooooooooool07_ooool00ol0
003oooooooooo`1hooooo`00E_ooool3o`0007?ooooo00?o0000ooooooooool07oooool00ol0003o
ooooooooo`1gooooo`00E?ooool2o`0007Kooooo00?o0000ooooooooool07oooool2o`0007Sooooo
001Aooooo`?o000000?oooooo`000?ooool0MOooool00ol0003oooooooooo`0Pooooo`03o`000?oo
oooooooo07Kooooo001?ooooo`;o0000Noooool00ol0003oooooooooo`0Qooooo`03o`000?oooooo
oooo07Gooooo001<ooooo`?o0000OOooool00ol0003oooooooooo`0Rooooo`03o`000?oooooooooo
07Cooooo0019ooooo`Co0000Ooooool00ol0003oooooooooo`0Sooooo`03o`000?oooooooooo07?o
oooo0017ooooo`;o00001?ooool00ol0003oooooooooo`1looooo`03o`000?oooooooooo02Cooooo
00?o0000ooooooooool0L_ooool004Cooooo0ol00025ooooo`03o`000?oooooooooo02Cooooo00?o
0000ooooooooool0L_ooool001[ooooo1Ol0000Sooooo`?o0000Qoooool00ol0003oooooooooo`0U
ooooo`03o`000?oooooooooo077ooooo000Jooooo`05oiRHV?lQ8B7ok^k^oooooom4A4@08?ooool3
o`0000?ooooo00?o0000ooooooooool0Q?ooool00ol0003oooooooooo`0Vooooo`03o`000?oooooo
oooo073ooooo000Booooo`Ko00000oooool00onHV9So8B4Qonk^kP0Oooooo`;o0000SOooool00ol0
003oooooooooo`0Wooooo`03o`000?oooooooooo06oooooo000Looooo`03oiRHV?lQ8B7ok^k^01_o
oooo0ol0002?ooooo`03o`000?oooooooooo02Oooooo00?o0000ooooooooool0Koooool001gooooo
00?oMgMgofIVI_ooool05oooool3o`0000?ooooo00?o0000ooooooooool0S?ooool00ol0003ooooo
ooooo`0Xooooo`03o`000?oooooooooo06kooooo000Nooooo`03o`000?oooooooooo01Cooooo0_l0
002Eooooo`03o`000?oooooooooo02Wooooo00?o0000ooooooooool0KOooool001[ooooo00Go0000
okZj^_ooooooV9RHoa0@400Cooooo`?o0000Uoooool00ol0003oooooooooo`0Zooooo`03o`000?oo
oooooooo06cooooo000Jooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`04Oooool2o`0000?ooooo00?o
0000ooooooooool0U?ooool00ol0003oooooooooo`0Zooooo`;o0000KOooool002gooooo0ol0002L
ooooo`03o`000?oooooooooo02[ooooo0_l0001]ooooo`00:_ooool3o`0009oooooo00?o0000oooo
ooooool0;?ooool00ol0003oooooooooo`1Zooooo`00:?ooool2o`0000?ooooo00?o0000oooooooo
ool0W?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo06Wooooo000Uooooo`?o0000
Y?ooool00ol0003oooooooooo`0]ooooo`03o`000?oooooooooo06Wooooo000Tooooo`03o`000?oo
oooooooo0:Gooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`1Xooooo`006_ooool4
o`000003oa0@4?oooooooooo00?ooooo0_l0002Vooooo`03o`000?oooooooooo02oooooo00?o0000
ooooooooool0Ioooool001cooooo00?o0000ooooooooool01Oooool2o`000:Kooooo00?o0000oooo
ooooool0<?ooool00ol0003oooooooooo`1Vooooo`004Oooool6o`0000Gooooo00?o0000oooooooo
ool01?ooool4o`000:Gooooo00?o0000ooooooooool0<?ooool00ol0003oooooooooo`08ooooo`Go
0000FOooool001cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool0002Tooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool01oooool01OnHV9So8B4Qonk^k_ooooooA4A4
05Wooooo000Looooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`2Qooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool01oooool00onHV9So
8B4Qonk^kP1Jooooo`007?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0X?ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo00Oooooo
00?oV9RHob4Q8Oo^k^h0FOooool001cooooo00?o0000ooooooooool01?ooool2o`0000Gooooo00?o
0000ooooooooool0Woooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo00Oooooo00?o
MgMgofIVI_ooool0F?ooool001[ooooo00?oEEEEofIVI_l000001_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo09kooooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`08
ooooo`03o`000?oooooooooo05Oooooo000Sooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0WOooool00ol0003oooooooooo`0eooooo`;o00001?ooool01Ol0003o^[ZjoooooonHV9So
410@05Wooooo000Sooooo`;o00002?ooool00ol0003oooooooooo`2Looooo`03o`000?oooooooooo
03?ooooo0_l000000ooooooo0000ooooo`03ooooo`05oiRHV?l@413o0000ob4Q8Oo<c<`0FOooool0
02?ooooo00?o0000ooooooooool02?ooool00ol0003oooooooooo`2Kooooo`03o`000?oooooooooo
03Oooooo00?o0000ooooooooool0Goooool002?ooooo00?o0000ooooooooool02Oooool00ol0003o
ooooooooo`2Jooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0Goooool002?ooooo
00?o0000ooooooooool02_ooool00ol0003oooooooooo`2Hooooo`;o0000>_ooool00ol0003ooooo
ooooo`1Nooooo`008_ooool2o`0000gooooo00?o0000ooooooooool0U?ooool3o`000003ooooool0
003ooooo03[ooooo00?o0000ooooooooool0GOooool002;ooooo00?o0000ooooooooool03Oooool0
0ol0003oooooooooo`2@ooooo`?o00001Oooool00ol0003oooooooooo`0iooooo`03o`000?oooooo
oooo05cooooo000Rooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0S?ooool3o`00
00Wooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1Looooo`008_ooool3o`0000oo
oooo00?o0000ooooooooool0R?ooool3o`0000gooooo00?o0000ooooooooool0>?ooool00ol0003o
ooooooooo`1Kooooo`008_ooool00ol0003oooooooooo`0@ooooo`03o`000?oooooooooo08Gooooo
0_l0000Aooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0F_ooool002;ooooo00?o
0000ooooooooool04Oooool00ol0003oooooooooo`21ooooo`?o00005?ooool00ol0003ooooooooo
o`0hooooo`03o`000?oooooooooo05Wooooo0007ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Ooo
ool2ob4Q8@Gooooo00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo01;ooooo
00?o0000ooooooooool0OOooool3o`0001Oooooo00?o0000ooooooooool0>?ooool00ol0003ooooo
ooooo`1Iooooo`001oooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMg
Molb<S;ooooo00Cooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`1iooooo`?o0000
6oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo05Sooooo0005o`0000;ooooo00Go
410@oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
5Oooool00ol0003oooooooooo`1eooooo`?o00007oooool00ol0003oooooooooo`0hooooo`03o`00
0?oooooooooo05Oooooo0007ooooo`05o`000?ooooooooooooooool000003oooool00omgMgOo<S8b
ooooo`03ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool0LOooool3o`0002?ooooo
00?o0000ooooooooool0=oooool2o`0005Sooooo0007ooooo`05o`000?ooooooooooooooool00000
3?ooool01Ol0003o8B4Qo`000?lb<S;oc<c<00Cooooo00?o0000ooooooooool05oooool00ol0003o
ooooooooo`1^ooooo`;o00009oooool00ol0003oooooooooo`0hooooo`03o`000?oooooooooo05Go
oooo0007ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003oooooooooo`06ooooo`;o
00006Oooool00ol0003oooooooooo`1Zooooo`?o0000:_ooool00ol0003oooooooooo`0gooooo`03
o`000?oooooooooo05Gooooo0007ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo01Wooooo00?o0000ooooooooool0I_ooool3o`0002go
oooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1Dooooo`001oooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00cooooo1?l00005ooooo`03o`000?oooooooooo01[ooooo00?o0000oooooooo
ool0H_ooool3o`00037ooooo00?o0000ooooooooool0>?ooool00ol0003oooooooooo`1Cooooo`00
8Oooool00ol0003oooooooooo`0Kooooo`03o`000?oooooooooo05kooooo0ol0000eooooo`03o`00
0?oooooooooo03Sooooo00?o0000ooooooooool0D_ooool0023ooooo0ol0000Mooooo`03o`000?oo
oooooooo05_ooooo0_l0000iooooo`03o`000?oooooooooo03Oooooo00?o0000ooooooooool0D_oo
ool0027ooooo00?o0000ooooooooool07Oooool00ol0003oooooooooo`1Gooooo`?o0000??ooool0
0ol0003oooooooooo`0gooooo`03o`000?oooooooooo057ooooo000Pooooo`03o`000?oooooooooo
01oooooo00?o0000ooooooooool0Doooool3o`00043ooooo00?o0000ooooooooool0=oooool00ol0
003oooooooooo`1@ooooo`008?ooool00ol0003oooooooooo`0Pooooo`03o`000?oooooooooo04oo
oooo0ol00013ooooo`03o`000?oooooooooo03Sooooo00?o0000ooooooooool0Coooool0023ooooo
0_l0000Rooooo`03o`000?oooooooooo04_ooooo0ol00017ooooo`03o`000?oooooooooo03Oooooo
00?o0000ooooooooool0Coooool0023ooooo00?o0000ooooooooool08_ooool00ol0003ooooooooo
o`18ooooo`;o0000Boooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo04kooooo000P
ooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool0A?ooool3o`0004kooooo00?o0000
ooooooooool0=oooool00ol0003oooooooooo`1=ooooo`008?ooool3o`0002Cooooo00?o0000oooo
ooooool0@?ooool3o`0005;ooooo00?o0000ooooooooool0=_ooool2o`0004kooooo000Pooooo`03
o`000?oooooooooo02Gooooo00?o0000ooooooooool0??ooool3o`0005Kooooo00?o0000oooooooo
ool0=_ooool00ol0003oooooooooo`1<ooooo`005?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Oo
oooo00?o0000ooooooooool09_ooool00ol0003oooooooooo`0hooooo`?o0000FOooool00ol0003o
ooooooooo`0gooooo`03o`000?oooooooooo04_ooooo000Dooooo`05ogMgMonHV9SooooooiRHV?mg
MgL01_ooool00ol0003oooooooooo`0Xooooo`03o`000?oooooooooo03Gooooo0_l0001Mooooo`03
o`000?oooooooooo03Oooooo00?o0000ooooooooool0B_ooool001Cooooo00Go410@oooooooooooo
oooooa0@4006ooooo`;o0000:_ooool00ol0003oooooooooo`0aooooo`?o0000H?ooool00ol0003o
ooooooooo`0gooooo`03o`000?oooooooooo04Wooooo000Dooooo`05o`000?ooooooooooooooool0
00001_ooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo02gooooo0ol0001Tooooo`03
o`000?oooooooooo03Kooooo00?o0000ooooooooool0BOooool001Cooooo00Go0000oooooooooooo
ooooo`000006ooooo`03o`000?oooooooooo02_ooooo00?o0000ooooooooool0:Oooool3o`0006So
oooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`18ooooo`005?ooool01Ol@413ooooo
oooooooooooo410@00Kooooo00?o0000ooooooooool0;?ooool00ol0003oooooooooo`0Uooooo`?o
0000K?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo04Oooooo000Dooooo`05ogMg
MonHV9SooooooiRHV?mgMgL01_ooool2o`0002kooooo00?o0000ooooooooool08Oooool3o`0006oo
oooo00?o0000ooooooooool0=oooool00ol0003oooooooooo`16ooooo`005?ooool01Oo^k^ko<S8b
o`000?lb<S;ok^k^00Kooooo00?o0000ooooooooool0;_ooool00ol0003oooooooooo`0Nooooo`;o
0000Loooool00ol0003oooooooooo`0gooooo`03o`000?oooooooooo04Gooooo000Oooooo`03o`00
0?oooooooooo02oooooo00?o0000ooooooooool06_ooool3o`0007Kooooo00?o0000ooooooooool0
=_ooool00ol0003oooooooooo`15ooooo`007_ooool00ol0003oooooooooo`0aooooo`03o`000?oo
oooooooo01Kooooo0ol0001jooooo`03o`000?oooooooooo03Kooooo00?o0000ooooooooool0A?oo
ool001kooooo0_l0000cooooo`03o`000?oooooooooo01;ooooo0ol0001nooooo`03o`000?oooooo
oooo03Kooooo0_l00014ooooo`007_ooool00ol0003oooooooooo`0cooooo`03o`000?oooooooooo
00kooooo0ol00022ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooool00000A?ooool001ko
oooo00?o0000ooooooooool0=?ooool00ol0003oooooooooo`0;ooooo`;o0000QOooool00ol0003o
ooooooooo`0fooooo`03o`000?oooooooooo04;ooooo000Nooooo`03o`000?oooooooooo03Gooooo
00?o0000ooooooooool01oooool3o`0008Sooooo00?o0000ooooooooool0=_ooool00ol0003ooooo
ooooo`11ooooo`007_ooool2o`0003Oooooo00?o0000ooooooooool00oooool3o`0008cooooo00?o
0000ooooooooool0=_ooool00ol0003oooooooooo`10ooooo`007_ooool00ol0003oooooooooo`0g
ooooo`03o`000?oooooo000000;o0000T?ooool00ol0003oooooooooo`0fooooo`03o`000?oooooo
oooo03oooooo000Nooooo`03o`000?oooooooooo03Kooooo0ol0002Dooooo`03o`000?oooooooooo
03Gooooo00?o0000ooooooooool0?oooool001kooooo0_l0000eooooo`;o00000oooool00ol0003o
ooooooooo`2Booooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool02Oooool2o`000003
oa0@4?oooooooooo033ooooo000Mooooo`03o`000?oooooooooo03;ooooo0ol00006ooooo`03o`00
0?oooooooooo097ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo037ooooo0002ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h01Oooool2ob4Q8@Gooooo
00GoA4A4o`000?l0003o<S8bomgMg@05ooooo`03o`000?oooooooooo02oooooo0ol0000:ooooo`03
o`000?oooooooooo097ooooo00?o0000ooooooooool0=_ooool00ol0003oooooooooo`05ooooo`Go
0000<_ooool000;ooooo00GoMgMgoiRHV?ooooooV9RHogMgM`05ooooo`;o8B4Q2?ooool00omgMgOo
<S8booooo`04ooooo`03o`000?oooooooooo02cooooo0ol0000>ooooo`03o`000?oooooooooo097o
oooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`05ooooo`04odA4A?oMgMgoooooo`00
03?ooooo0002ooooo`05oa0@4?ooooooooooooooool@41004?ooool00ol0003oooooooooo`03oooo
o`;o0000:_ooool3o`0001;ooooo00?o0000ooooooooool0TOooool00ol0003oooooooooo`0eoooo
o`03o`000?oooooooooo00Cooooo00CogMgMoeEEEOoooooo0000<oooool000;ooooo00Go0000oooo
ooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo00Cooooo00?o0000ooooooooool09oooool2
o`0001Kooooo00?o0000ooooooooool0TOooool00ol0003oooooooooo`0eooooo`03o`000?oooooo
oooo00Cooooo00?oMgMgolc<c?l00000<oooool000;ooooo00Go0000ooooooooooooooooo`00000<
ooooo`05o`000?lQ8B7o0000oc8b<_o<c<`01Oooool00ol0003oooooooooo`0Tooooo`?o00006Ooo
ool00ol0003oooooooooo`2Aooooo`03o`000?oooooooooo03Cooooo0_l00005ooooo`03onk^k_m4
A4Co000003?ooooo0002ooooo`05oa0@4?ooooooooooooooool@41003?ooool00ol0003ooooooooo
o`07ooooo`03o`000?oooooooooo027ooooo0ol0000Mooooo`03o`000?oooooooooo093ooooo00?o
0000ooooooooool0<oooool01?l0003oooooooooool00005ooooo`03ogMgMol0003ooooo03;ooooo
0002ooooo`05ogMgMonHV9SooooooiRHV?mgMgL03?ooool00ol0003oooooooooo`07ooooo`;o0000
7oooool3o`00027ooooo00?o0000ooooooooool0T?ooool00ol0003oooooooooo`0eooooo`03o`00
0?oooooooooo03Sooooo0002ooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4o`0000Gooooo
00?o0000ooooooooool07?ooool3o`0002Gooooo00?o0000ooooooooool0T?ooool00ol0003ooooo
ooooo`0eooooo`03o`000?oooooooooo03Oooooo000Looooo`03o`000?oooooooooo01Wooooo0ol0
000Yooooo`03o`000?oooooooooo093ooooo00?o0000ooooooooool0=Oooool00ol0003ooooooooo
o`0fooooo`007?ooool00ol0003oooooooooo`0Gooooo`;o0000;Oooool00ol0003oooooooooo`2@
ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0=Oooool001cooooo0_l0000Eoooo
o`?o0000<?ooool00ol0003oooooooooo`2@ooooo`03o`000?oooooooooo03Cooooo00?o0000oooo
ooooool0=Oooool001cooooo00?o0000ooooooooool04Oooool3o`0003Cooooo00?o0000oooooooo
ool0Soooool00ol0003oooooooooo`0eooooo`03o`000?oooooooooo03Cooooo000Looooo`03o`00
0?oooooooooo00kooooo0ol0000hooooo`03o`000?oooooooooo08oooooo00?o0000ooooooooool0
=Oooool00ol0003oooooooooo`0cooooo`007?ooool00ol0003oooooooooo`0;ooooo`?o0000??oo
ool00ol0003oooooooooo`2?ooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0<_oo
ool001cooooo0_l0000:ooooo`;o0000@?ooool00ol0003oooooooooo`2?ooooo`03o`000?oooooo
oooo03Cooooo00?o0000ooooooooool0<_ooool001_ooooo0_l00008ooooo`?o0000@oooool00ol0
003oooooooooo`2?ooooo`03o`000?oooooooooo03Cooooo00?o0000ooooooooool0<Oooool001_o
oooo00?o0000ooooooooool01?ooool3o`0004Oooooo00?o0000ooooooooool0Soooool00ol0003o
ooooooooo`0cooooo`;o0000<_ooool001_ooooo00Co0000oooooooooooooooo0ol0001;ooooo`03
o`000?oooooooooo08kooooo00?o0000ooooooooool0=Oooool00ol0003oooooooooo`0_ooooo`00
6oooool4o`0004oooooo00?o0000ooooooooool0S_ooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo02oooooo000Kooooo`;o0000D_ooool00ol0003oooooooooo`2>ooooo`03o`000?oo
oooooooo03Cooooo00?o0000ooooooooool0;_ooool0017ooooo1?l000000ol@413oooooooooo`05
ooooo`03o`000?oooooooooo053ooooo00?o0000ooooooooool0S?ooool00oooV@3oooooo`00000f
ooooo`03o`000?oooooooooo02gooooo000Cooooo`03o`000?oooooooooo00Sooooo00?o0000oooo
ooooool0D?ooool00ol0003oooooooooo`2;ooooo`04oonI0?ooooooooooo`0003Kooooo00?o0000
ooooooooool0;?ooool001?ooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`1@oooo
o`03o`000?oooooooooo08Sooooo0_ooV@04ooooo`03o`000?oooooooooo03?ooooo00?o0000oooo
ooooool0;?ooool001?ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1@ooooo`03
o`000?oooooooooo08Kooooo0_ooV@05ooooo`03o`000?oooooooooo03Cooooo00?o0000oooooooo
ool0:oooool001?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1@ooooo`03o`00
0?oooooooooo08Cooooo00?ooiT0ooooooooV@001_ooool00ol0003oooooooooo`0dooooo`03o`00
0?oooooooooo02[ooooo000Cooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0D?oo
ool00ol0003oooooooooo`22ooooo`03oonI0?oooooooiT000Sooooo00?o0000ooooooooool0=?oo
ool00ol0003oooooooooo`0Yooooo`004oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooo
oooo053ooooo00?o0000ooooooooool0P?ooool00oooV@3ooooooonI000:ooooo`03o`000?oooooo
oooo03Cooooo00?o0000ooooooooool0:?ooool0017ooooo00?oEEEEofIVI_l000004?ooool00ol0
003oooooooooo`1@ooooo`03o`000?oooooooooo07kooooo00CooiT0oooooooooooooiT02oooool0
0ol0003oooooooooo`0cooooo`03o`000?oooooooooo02Sooooo000Uooooo`03o`000?oooooooooo
053ooooo00?o0000ooooooooool0O?ooool01?ooV@3oooooooooooooV@0=ooooo`03o`000?oooooo
oooo03;ooooo0_l0000Yooooo`009_ooool2o`00057ooooo00?o0000ooooooooool0NOooool2oonI
00;ooooo00?ooiT0ooooooooool03?ooool00ol0003oooooooooo`0dooooo`03o`000?oooooooooo
02Kooooo000Xooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0N?ooool01OooV@3o
oooooooooooooooooiT000oooooo00?oc?l0o`000?ooool0=Oooool00ol0003oooooooooo`0Uoooo
o`00:Oooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo07Gooooo0_ooV@03ooooo`03
oonI0?oooooooooo00gooooo00Coc?l0oooooooooooo0000=Oooool00ol0003oooooooooo`0Uoooo
o`00:_ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo07?ooooo00?ooiT0oooooooo
ool00oooool00oooV@3oooooooooo`0;ooooo`;oc?l01?ooool00ol0003oooooooooo`0cooooo`03
o`000?oooooooooo02Cooooo000[ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0
L?ooool2oonI00Gooooo00?ooiT0ooooooooool02oooool00oo<o`3oooooolco0005ooooo`03o`00
0?oooooooooo03?ooooo00?o0000ooooooooool08oooool002cooooo00?o0000ooooooooool0C_oo
ool00ol0003oooooooooo`1^ooooo`03oonI0?oooooooooo00Cooooo00?ooiT0ooooooooool02ooo
ool00oo<o`3oooooolco0007ooooo`03o`000?oooooooooo03?ooooo00?o0000ooooooooool08_oo
ool002gooooo00?o0000ooooooooool0C_ooool00ol0003oooooooooo`1[ooooo`;ooiT01_ooool0
0oooV@3oooooooooo`0;ooooo`03olco0?ooooooc?l000Sooooo00?o0000ooooooooool0<oooool0
0ol0003oooooooooo`0Rooooo`00;_ooool00ol0003oooooooooo`1>ooooo`03o`000?oooooooooo
06Wooooo00?ooiT0ooooooooool01_ooool00oooV@3oooooooooo`0:ooooo`04olco0?oooooooooo
olco00Wooooo00?o0000ooooooooool0<oooool00ol0003oooooooooo`0Qooooo`00;oooool00ol0
003oooooooooo`1>ooooo`03o`000?oooooooooo06Gooooo0oooV@08ooooo`03oonI0?oooooooooo
00[ooooo00Coc?l0ooooooooooooc?l02oooool00ol0003ooooooc?o000cooooo`03o`000?oooooo
oooo023ooooo000`ooooo`03o`000?oooooooooo04kooooo00?o0000ooooooooool0HOooool3oonI
00[ooooo00?ooiT0ooooooooool02_ooool01?o<o`3oooooooooooo<o`0=ooooo`03o`000?lco`3o
oooo03?ooooo00?o0000ooooooooool07oooool0037ooooo0_l0001?ooooo`03o`000?oooooooooo
05gooooo0oooV@0<ooooo`03oonI0?oooooooooo00[ooooo00Coc?l0ooooooooooooc?l03_ooool0
0olco`3o0000ooooo`0cooooo`;o00008?ooool003?ooooo00?o0000ooooooooool0COooool00ol0
003oooooooooo`1Iooooo`?ooiT03Oooool2oonI00_ooooo0_o<o`02ooooo`03olco0?oooooooooo
00cooooo00Co<ol0oooooooooooo0000<oooool2o`00023ooooo000dooooo`03o`000?oooooooooo
04gooooo00?o0000ooooooooool0EOooool3oonI00oooooo00?ooiT0ooooooooool02Oooool2olco
00?ooooo00?oc?l0ooooooooool02oooool2oc?o00?ooooo00?o0000ooooooooool0<oooool00ol0
003oooooooooo`0Mooooo`00=Oooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo04ko
oooo1_ooV@0Aooooo`03oonI0?oooooooooo00Wooooo00?oc?l0ooooooooool00_ooool00oo<o`3o
ooooooooo`0;ooooo`03oc?o0?oooooo<ol000CooiT000?o0000ooooooooool0<oooool00ol0003o
ooooooooo`0Looooo`00=_ooool00ol0003oooooooooo`1=ooooo`03o`000?oooooooooo033ooooo
3?ooV@09ooooo`SooiT05Oooool2oonI00[ooooo0_o<o`04ooooo`03olco0?oooooooooo00Kooooo
1OooV@001?lco`3ooiT0oc?o0?ooV@05ooooo`03o`000?oooooooooo03;ooooo00?o0000oooooooo
ool07?ooool003Oooooo00?o0000ooooooooool0COooool00ol0003oooooooooo`0eooooo`oooiT0
7?ooool00oooV@3oooooooooo`08ooooo`;oc?l01_ooool00oo<o`3ooiT0oonI0006oonI00Cooooo
00?o<ol0oooooolco`002?ooool00ol0003oooooooooo`0booooo`03o`000?oooooooooo01_ooooo
000hooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0?oooool=oonI01;ooooo00?o
oiT0ooooooooV@001oooV@02olco00OooiT000?oc?l0ooooooooool02_ooool01?lco`3ooooooooo
oolco`09ooooo`03o`000?oooooooooo03;ooooo00?o0000ooooooooool01oooool01Oo^k^ko<S8b
o`000?l@413oc<c<00kooooo000iooooo`03o`000?oooooooooo04gooooo00?o0000ooooooooool0
BooooolDoonI00Oooooo00?oc?l0ooooooooool01_ooool00oo<o`3oooooooooo`0:ooooo`04oc?o
0?oooooooooooc?o00_ooooo00?o0000ooooool0ofH0<_ooool00ol0003oooooooooo`06ooooo`05
oeEEEOmgMgOooooooiRHV?lQ8B403_ooool003[ooooo00?o0000ooooooooool0COooool00ol0003o
ooooooooo`1Iooooo`;ooiT02?ooool2olco00Sooooo00?oc?l0ooooooooool02_ooool01?lco`3o
oooooooooolco`0<ooooo`03o`000?oooooo0?mV03?ooooo00?o0000ooooooooool01Oooool01Ol0
003ooooooooooooooooo000000kooooo000kooooo`03o`000?oooooooooo04gooooo00?o0000oooo
ooooool0Eoooool00oooV@3oooooooooo`05ooooo`?oc?l02Oooool00oo<o`3oooooooooo`0:oooo
o`04oc?o0?oooooooooooc?o00kooooo00?o0000ooooooooool0<_ooool00ol0003oooooooooo`05
ooooo`05o`000?nHV9SooooooiRHV?lQ8B403_ooool003cooooo00?o0000ooooooooool0COooool0
0ol0003oooooooooo`1Eooooo`03oonI0?oooooooooo00?ooooo0oo<o`0;ooooo`03olco0?oooooo
oooo00[ooooo00Co<ol0oooooooooooo<ol03_ooool2o`3oIP03o`000?oooooooooo03;ooooo00?o
0000ooooooooool01?ooool01Ol0003oEEEEo`000?l@413oc<c<00kooooo000mooooo`;o0000C_oo
ool00ol0003oooooooooo`1Booooo`;ooiT00_ooool4olco00cooooo0_o<o`0;ooooo`;o<ol00_oo
ool00olco`3oooooooooo`0;ooooo`?o0?mV0_ooool00ol0003oooooooooo`0booooo`;o00001?oo
ool00omEEEGoQhN7ooooo`0@ooooo`00?oooool00ol0003oooooooooo`1<ooooo`03o`000?oooooo
oooo053ooooo00?ooiT0olco0?o<o`000_o<o`0?ooooo`03olco0?oooooooooo00Wooooo0_lco`03
ooooo`03oc?o0?oooooooooo00_ooooo00?o0?mVooooool0ofH01?ooool00ol0003oooooooooo`0_
ooooo`;o000000?oooooo`000?ooool00oooool00ooMgMgo410@oiRHV00@ooooo`00@?ooool00ol0
003oooooooooo`1<ooooo`03o`000?oooooooooo04gooooo0oo<o`0Booooo`03olco0?oooooooooo
00Wooooo00?o<ol0ooooooooool00_ooool00olco`3oooooooooo`0;ooooo`04o`3oI_oooooooooo
o`3oIPGooooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`03ooooo`04olc<c?m4A4Co
0000oa0@40kooooo0011ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool0Aoooool5
olco0003oonI0?oooooooooo013ooooo0_o<o`0:ooooo`;o<ol01Oooool00olco`3oooooooooo`0:
ooooo`04o`3oI_ooooooooooo`3oIPKooooo00?o0000ooooooooool0<_ooool00ol0003ooooooooo
o`0Dooooo`00@_ooool00ol0003oooooooooo`1<ooooo`03o`000?oooooooooo043ooooo1_o<o`03
ooooo`;ooiT04_ooool00oo<o`3oooooooooo`08ooooo`;o<ol01_ooool00olco`3oooooooooo`0:
ooooo`06o`3oI_o<o`3oc?l0olco0?l0ofKoc?l01_ooool00ol0003oooooooooo`0booooo`03o`00
0?oooooooooo01?ooooo0013ooooo`03o`000?oooooooooo04cooooo00?o0000ooooooooool08Ooo
ool?olco00Wooooo1_o<o`07ooooo`;ooiT04oooool00oo<o`3oooooooooo`07ooooo`;o<ol01ooo
ool00olco`3oooooooooo`03ooooo`Ooc?l000Go0?mVolco0?ooooooooooo`3oIP09ooooo`05o`00
0?ooooooooooooooool0ool0<?ooool00ol0003oooooooooo`0Booooo`00A?ooool00ol0003ooooo
ooooo`1<ooooo`03o`000?oooooooooo02Oooooo4Oo<o`0;ooooo`;ooiT04oooool2olco00Sooooo
0_lco`06ooooo`;oc?l000?o<ol0olco0?o<o`001?o<o`06ooooo`05o`3oI_ooooooooooooooool0
ofH02oooool01?l0003oooooooooool0ool`ooooo`03o`000?oooooooooo01;ooooo0015ooooo`03
o`000?oooooooooo04cooooo00?o0000ooooooooool0<_ooool=olco0003ooooooooV@3ooiT001?o
oooo2oo<o`000olco`3oc?l0olco0006olco0003oooooolco`3ooooo00_ooooo00Go0?mVoooooooo
ooooooooo`3oIP0=ooooo`03o`000?l0oooooooo037ooooo00?o0000ooooooooool04Oooool004Ko
oooo00?o0000ooooooooool0C?ooool00ol0003oooooooooo`0mooooo`03oonI0?o<o`3oc?l001Go
c?l02?ooool2oc?o00Wooooo00?o<ol0ooooooooool02_ooool01Ol0ofKooooooooooooooooo0?mV
00kooooo00?o0?ooo`000?ooool0<_ooool00ol0003oooooooooo`0@ooooo`00Aoooool00ol0003o
ooooooooo`1<ooooo`03o`000?oooooooooo03_ooooo00?ooiT0ooooooooool04oooool00oo<o`3o
ooooooooo`05ooooo`?o<ol02Oooool2oc?o00cooooo00Go0?mVooooooooooooooooo`3oIP0>oooo
o`03o`3ooooooooo000003Cooooo00?o0000ooooooooool03oooool004Sooooo0_l0001=ooooo`03
o`000?oooooooooo03Sooooo0_ooV@0Eooooo`03olco0?oooooooooo00?ooooo0olco`0;ooooo`03
oc?o0?oooooooooo00[ooooo0_l0ofH3ooooo`03o`3oI_oooooooooo00_ooooo0ol0ool2ooooo`03
o`000?oooooooooo037ooooo00?o0000ooooooooool03oooool004[ooooo00?o0000ooooooooool0
Boooool00ol0003oooooooooo`0eooooo`;ooiT05Oooool2olco00?ooooo0olco`0=ooooo`03oc?o
0?oooooooooo00Wooooo0_l0ofH4ooooo`03o`3oI_oooooooooo00_ooooo00?o0?ooooooool0ool0
1?ooool00ol0003oooooooooo`0aooooo`;o00003oooool004_ooooo00?o0000ooooooooool0Booo
ool00ol0003oooooooooo`0booooo`;ooiT05_ooool00oo<o`3ooooooc?o0003oc?o00kooooo0_lc
o`0;ooooo`03o`3oI_oooooooooo00?ooooo00?o0?mVooooooooool02oooool00ol0ooooooooo`3o
o`06ooooo`03o`000?oooooooooo033ooooo0_l0000?ooooo`00C?ooool00ol0003oooooooooo`1;
ooooo`03o`000?oooooooooo02oooooo0_ooV@0Gooooo`?o<ol04Oooool00olco`3oooooooooo`09
ooooo`;o0?mV1Oooool00ol0ofKoooooooooo`0;ooooo`04o`3oooooooooooooo`3oo`Oooooo00?o
0000ooooooooool0<Oooool00ol0003oooooooooo`0<ooooo`00COooool00ol0003oooooooooo`1;
ooooo`03o`000?oooooooooo02gooooo00?ooiT0ooooooooool05?ooool3oc?o01?ooooo00?o<ol0
ooooooooool02?ooool2o`3oIPKooooo00?o0?mVooooooooool02oooool01?l0ooooooooooooool0
ool9ooooo`03o`000?oooooooooo00;ooooo00?o06Koooooooooool0;?ooool00ol0003ooooooooo
o`0;ooooo`00C_ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo03kooooo1Olco`00
0oo<o`3oooooooooo`0Aooooo`;o<ol02_ooool00ol0ofKoooooooooo`05ooooo`03o`3oI_oooooo
oooo00Sooooo0_lco`02o`3oo`;ooooo00?o0?ooooooooooool02?ooool00ol0003oooooooooo`02
ooooo`03o`1Voooooooooooo02cooooo00?o0000ooooooooool02oooool004oooooo00?o0000oooo
ooooool0Boooool00ol0003oooooooooo`0fooooo`Oo<ol00oooool00oo<o`3oooooooooo`0Boooo
o`03oc?o0?oooooooooo00Sooooo0_l0ofH7ooooo`03o`3oI_oooooooooo00;ooooo1olco`000ooo
oooo0?ooooooo`02ooooo`03o`3ooooooooooooo00[ooooo00Co0000oooooooooooo06Ko<?ooool0
0ol0003oooooooooo`0:ooooo`00D?ooool00ol0003oooooooooo`1;ooooo`03o`000?oooooooooo
01?ooooo4?lco`0;ooooo`Oo<ol02?ooool2olco01Cooooo00?o<ol0ooooooooool01oooool2o`3o
IPOooooo00?o<ol0o`3oI_lco`001?lco`07ooooo`05o`3oooooooooooooooooool0ool03_ooool0
0ol0003o06Koooooo`0aooooo`03o`000?oooooooooo00Wooooo001Aooooo`03o`000?oooooooooo
04_ooooo00?o0000ooooooooool06OoooolDoc?o00gooooo0_o<o`0Dooooo`;o<ol02Oooool00ol0
ofKoooooooooo`07oc?o0003o`3oI_oooooooooo00[ooooo00Go0?ooooooooooooooooooo`3oo`0?
ooooo`03o`1Vool0003ooooo03;ooooo00?o0000ooooooooool02?ooool005;ooooo00?o0000oooo
ooooool0Boooool00ol0003oooooooooo`0Uooooo`go<ol01Oooool2olco013ooooo3olco`02o`3o
IP?o<ol01Oooool2o`3oIPcooooo00Go0?ooooooooooooooooooo`3oo`0>ooooo`?o06Ko00?ooooo
o`000?ooool0<Oooool00ol0003oooooooooo`08ooooo`00Doooool2o`0004cooooo00?o0000oooo
ooooool0<OoooolGoc?o00Cooooo00?o<ol0ooooooooool01Oooool3o`3oIPWooooo00?o0?mVoooo
ooooool02_ooool2o`3oo`?ooooo00?o0?ooooooooooool03?ooool00ol0I_ooooooo`1Vo`03oooo
o`03o`000?oooooooooo033ooooo00?o0000ooooooooool01oooool005Gooooo00?o0000oooooooo
ool0B_ooool00ol0003oooooooooo`0booooo`;oc?l05Oooool2oc?o00Gooooo0ol0ofH;ooooo`03
o`3oI_oooooooooo00Wooooo0_l0ool4ooooo`03o`3ooooooooooooo00cooooo00?o06Koooooool0
I_l01?ooool00ol0003oooooooooo`0aooooo`03o`000?oooooooooo00Kooooo001Fooooo`03o`00
0?oooooooooo04[ooooo00?o0000ooooooooool0;oooool2olco01Kooooo00?o<ol0ooooooooool0
0_ooool3o`3oIPcooooo0_l0ofH;ooooo`03o`3ooooooooooooo00Cooooo00?o0?ooooooooooool0
2oooool01?l0I_ooooooooooool0I_l5ooooo`03o`000?oooooooooo02oooooo0ol00007ooooo`00
Eoooool00ol0003oooooooooo`1:ooooo`03o`000?oooooooooo02gooooo00?oc?l0ooooooooool0
5Oooool00olco`3oooooo`3oIP03o`3oIPkooooo00?o0?mVooooooooool02Oooool2o`3oo`Kooooo
00?o0?ooooooooooool02oooool01?l0I_ooooooooooool0I_l7ooooo`03o`000?oooooooooo00Co
oooo00?o<`3oooooooooool09?ooool3o`0000;ooooo00?o0000ooooooooool01Oooool005Sooooo
00?o0000ooooooooool0B_ooool00ol0003oooooooooo`0Zooooo`;oc?l05_ooool01?lco`3o0?mV
o`3oI_l0ofHAooooo`03o`3oI_oooooooooo00Sooooo0_l0ool7ooooo`03o`3ooooooooooooo00_o
oooo00Co06Kooooooooooooo06Ko2Oooool00ol0003oooooooooo`02ooooo`;o<`3o8oooool3o`00
00Gooooo00?o0000ooooooooool01Oooool005Wooooo00?o0000ooooooooool0B_ooool00ol0003o
ooooooooo`0Xooooo`03olco0?oooooooooo01Cooooo0ol0ofHBooooo`;o0?mV2Oooool2o`3oo`So
oooo00?o0?ooooooooooool02_ooool2o`1Vo`;ooooo00?o06Koooooooooool02Oooool00ol0003o
ooooooooo`02oc<0ob3ooooo1?l00008ooooo`03o`000?oooooooooo00Gooooo001Jooooo`03o`00
0?oooooooooo04[ooooo00?o0000ooooooooool0>oooool3o`3oIQCooooo00?o0?mVooooooooool0
2?ooool00ol0ooooooooooooo`07ooooo`03o`3ooooooooooooo00[ooooo00Go06Kooooooooooooo
ooooo`1Vo`0=ooooo`03o`000?lc0?oo<`3o01kooooo0ol0000<ooooo`03o`000?oooooooooo00Go
oooo001Kooooo`03o`000?oooooooooo04[ooooo00?o0000ooooooooool0=?ooool6o`3oIP;o<ol0
5?ooool00ol0ofKoooooooooo`07ooooo`;o0?oo2Oooool00ol0ooooooooooooo`04ooooo`Go0?mV
00?oooooo`1Vooooool00_ooool00ol0I_ooooooooooo`0<ooooo`03o`000?lc0?oooooo01[ooooo
1?l0000?ooooo`03o`000?oooooooooo00Gooooo001Looooo`03o`000?oooooooooo04[ooooo00?o
0000ooooooooool01_ooool5o`3oIR3ooooo2?l0ofH4ooooo`;o<ol05Oooool00ol0ofKooooooooo
o`06ooooo`;o0?oo2_ooool00ol0oooo0?mVo`3oIP05o`3oIPGooooo00Go06Kooooooooooooooooo
o`1Vo`0=ooooo`?o<`3o00?o0000ooooooooool05_ooool3o`0001Cooooo00?o0000ooooooooool0
1?ooool005gooooo00?o0000ooooooooool0B_ooool00ol0003oooooooooo`09ooooo`ko0?mV3?oo
ool7o`3oIP[ooooo0_lco`0Eooooo`;o0?mV2?ooool00ol0ooooooooooooo`03ooooo`Ko0?mV00?o
0?ooo`3oI_ooool02_ooool01Ol0I_oooooooooooooooooo06Ko00gooooo00?o<`3ooooooolc0?l0
0_ooool00ol0003oooooooooo`0Booooo`?o00005oooool00ol0003oooooooooo`04ooooo`00G_oo
ool2o`0004_ooooo00?o0000ooooooooool03_oooolDo`3oIQ3ooooo00?o<ol0ooooooooool05?oo
ool00ol0ofKoooooooooo`06ooooo`;o0?oo1_l0ofH4ooooo`03o`3ooooooooooooo00_ooooo00Go
06Koooooooooooooooooo`1Vo`0=ooooo`03oc<0oooooooo<`3o00Cooooo00?o0000ooooooooool0
3Oooool4o`0001[ooooo00?o0000ooooooooool01?ooool0063ooooo00?o0000ooooooooool0BOoo
ool00ol0003oooooooooo`0Gooooo`oo0?mV2Oooool2oc?o00cooooo4Ol0ofH3o`3oo`03o`3oI_oo
oooooooo00Oooooo0_l0ool<ooooo`;o06Ko0oooool00ol0I_ooooooooooo`0;ooooo`04oc<0oooo
oooooooooc<0o`Gooooo00?o0000ooooooooool01_ooool00oo<0?ooooooooooo`03o`0001kooooo
00?o0000ooooooooool01?ooool0067ooooo00?o0000ooooooooool0BOooool00ol0003ooooooooo
o`0UoooooaOo0?mV2?ooool2o`3oIPCooooo0ol0ool<ooooo`03o`3ooooooooooooo00[ooooo0_l0
I_l4ooooo`03o`1Voooooooooooo00_ooooo00Co<`3ooooooooooooo<`3o1oooool00ol0003ooooo
ooooo`04ooooo`04o`000?o<0?oo0000o`00027ooooo00?o0000ooooooooool01?ooool006;ooooo
00?o0000ooooooooool0BOooool00ol0003oooooooooo`0Yooooo`;o<ol05oooool00ol0ofKooooo
ooooo`04o`3oo`kooooo00?o0?ooooooooooool02Oooool2o`1Vo`Gooooo00?o06Koooooooooool0
2oooool01?lc0?oooooooooooolc0?l8ooooo`04o`000?ooooooooooooooo`?o000000?oc03ooooo
ooooool08_ooool00ol0003oooooooooo`04ooooo`00Hoooool00ol0003oooooooooo`19ooooo`03
o`000?oooooooooo02Oooooo00?o<ol0ooooooooool05_ooool4o`3ooa3ooooo0_l0ool:ooooo`;o
06Ko1_ooool00ol0I_ooooooooooo`0;ooooo`04oc<0oooooooooooooc<0o`[ooooo0ol00002oooo
o`03ol`0oooooooooooo02?ooooo00?o0000ooooooooool01?ooool006Cooooo00?o0000oooooooo
ool0BOooool00ol0003oooooooooo`0Tooooo`;o<ol05_ooool3o`3ooa?ooooo00?o0?oooooooooo
ool02?ooool2o`1Vo`Oooooo00?o06Koooooooooool02oooool01?lc0?oooooooooooolc0?l7oooo
o`Co000000Goooooo`000?oooooooooool`0o`0Vooooo`03o`000?oooooooooo00Cooooo001Uoooo
o`03o`000?oooooooooo04Wooooo00?o0000ooooooooool08_ooool00olco`3oooooooooo`0Boooo
o`Co0?oo00?o0?mVooooooooool04Oooool2o`3oo`Wooooo0_l0I_l8ooooo`03o`1Voooooooooooo
00_ooooo00Co<`3ooooooooooooo<`3o1Oooool3o`0000Kooooo00?o0000ol`0ooo<0?l09_ooool0
0ol0003oooooooooo`04ooooo`00I_ooool00ol0003oooooooooo`19ooooo`03o`000?oooooooooo
03?ooooo0ol0ool00ooooooo0?mVo`3oIP0Dooooo`03o`3ooooooooooooo00Sooooo00?o06Kooooo
ooooool01oooool00ol0I_ooooooooooo`0;ooooo`04oc<0oooooooooooooc<0o`;ooooo1?l00009
ooooo`03ol`0ool0003ooooo02Kooooo00?o0000ooooooooool01?ooool006Oooooo00?o0000oooo
ooooool0BOooool00ol0003oooooooooo`0/ooooo`Ko0?oo0_ooool2o`3oIQCooooo0_l0ool9oooo
o`;o06Ko2?ooool2o`1Vo`gooooo00Co<`3ooooooooooooo<`3o0ol0000;ooooo`?oc03o00?ooooo
o`000?ooool09_ooool00ol0003oooooooooo`03ooooo`00J?ooool00ol0003oooooooooo`19oooo
o`03o`000?oooooooooo02;ooooo2Ol0ool6ooooo`;o0?mV5Oooool00ol0ooooooooooooo`07oooo
o`;o06Ko2Oooool00ol0I_ooooooooooo`02ooooo`Go0?oo1Oooool01Olc0?ooooooo`000?lc0?oo
000000gooooo00?oc03oooooooo<0?l00_ooool00ol0003oooooooooo`0Uooooo`03o`000?oooooo
oooo00?ooooo001Yooooo`03o`000?oooooooooo04Cooooo1Ol0ool00ol0003oooooooooo`0Ioooo
o`So0?oo3Oooool2o`3oIQGooooo0_l0ool8ooooo`;o06Ko2?ooool8o`3oo`Sooooo00Go0000oc<0
ool0003o0000oc<0o`0>ooooo`04ol`0oooooooooooool`0o`?ooooo00?o0000ooooooooool09?oo
ool00ol0003oooooooooo`03ooooo`00J_ooool2o`0004Sooooo7Ol0oolCooooo`;o0?mV5_ooool0
0ol0ooooooooooooo`06ooooo`;o06Ko0oooool7o`3oo`03o`1Voooooooooooo00[ooooo0_l00002
oc<0o`;ooooo00?o<`3oooooooooool03?ooool01?o<0?ooooooooooooo<0?l5ooooo`03o`000?oo
oooooooo00Kooooo00?oo`2Iooooooooool06_ooool00ol0003oooooooooo`03ooooo`00K?ooool0
0ol0003oooooooooo`18ooooo`03o`000?oooooooooo00_o0?oo7Oooool2o`3oIQOooooo00?o0?oo
ooooooooool01?ooool3o`1Vo`Go0?oo1_ooool00ol0I_ooooooooooo`07ooooo`Co00000_lc0?l3
ooooo`03oc<0oooooooooooo00cooooo00Coc03oooooooooooooc03o1oooool00ol0003ooooooooo
o`05ooooo`03ool0VOoooooooooo01[ooooo00?o0000ooooooooool00oooool006gooooo00?o0000
ooooooooool0B?ooool00ol0003oooooooooo`0:ooooo`oo0?oo3?ooool2o`3oIP[ooooo4ol0ool3
o`1Vo`cooooo0_l0I_l7ooooo`?o00000_ooool2oc<0o`Cooooo00?o<`3oooooooooool03?ooool0
1?o<0?ooooooooooooo<0?l9ooooo`03o`000?oooooooooo00?ooooo00?oo`2Iooooooooool06ooo
ool00ol0003oooooooooo`03ooooo`00K_ooool00ol0003oooooooooo`18ooooo`03o`000?oooooo
oooo01Sooooo6?l0ool<ooooo`04o`3oooooooooooooooooo`?o06Ko3_ooool00ol0I_oooooooooo
o`04ooooo`?o00000oooool2oc<0o`Gooooo00?o<`3oooooooooool02oooool2ol`0o`;ooooo00?o
c03oooooooooool02Oooool01Ol0003oooooooooooooooooo`2I01kooooo00?o0000ooooooooool0
0oooool006oooooo00?o0000ooooooooool0B?ooool00ol0003oooooooooo`0Oooooo`;o0?mV6?oo
ool2o`3oo`Co06Ko3oooool2o`1Vo`?ooooo1?l00004ooooo`;o<`3o1_ooool00olc0?oooooooooo
o`0;ooooo`05ol`0ooooooooooooooooooo<0?l03?ooool01?l0003ooooooooooooo09TOooooo`03
o`000?oooooooooo00?ooooo001`ooooo`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0
7Oooool00ol0ofKoooooooooo`0Fooooo`04o`3oool0I_oo06Koo`1Voa;ooooo00?o06Kooooooooo
ool00ol00006ooooo`;o<`3o1oooool00olc0?ooooooooooo`0;ooooo`05ol`0oooooooooooooooo
ooo<0?l03_ooool00ol0003oo`2Iooooo`0Oooooo`03o`000?oooooooooo00?ooooo001aooooo`03
o`000?oooooooooo04Sooooo00?o0000ooooooooool0<_ooool4o`1VoaCooooo00Co06Koo`000?l0
003o00001oooool2oc<0o`Sooooo00?o<`3oooooooooool02oooool01Oo<0?oooooooooooooooooo
c03o00kooooo0_oo09T00ol0003oooooooooo`0Nooooo`03o`000?oooooooooo00?ooooo001boooo
o`03o`000?oooooooooo04Sooooo00?o0000ooooooooool0;_ooool3o`1Vo`03o`3ooooooooooooo
01;ooooo00?o0000o`1Vool0I_l02Oooool2oc<0o`Sooooo0_lc0?l=ooooo`05ol`0oooooooooooo
ooooooo<0?l03_ooool2ool0V@;ooooo00?o0000ooooooooool07_ooool00ol0003oooooooooo`02
ooooo`00Loooool00ol0003oooooooooo`18ooooo`03o`000?oooooooooo02[ooooo0ol0I_l00ooo
oooo0?ooo`3oo`0Booooo`?o000000?o06Koooooooooool01oooool2oc<0o`Wooooo00?o<`3ooooo
ooooool03?ooool01Oo<0?ooooooooooooooooooc03o00kooooo0_oo09T4ooooo`03o`000?oooooo
oooo01gooooo00?o0000ooooooooool00_ooool007Cooooo00?o0000ooooooooool0B?ooool00ol0
003oooooooooo`0Rooooo`Oo06Ko0_ooool2o`3ooa3ooooo1?l000000ooooooo06Koo`1Vo`08oooo
o`;o<`3o2Oooool2oc<0o`kooooo00Goc03ooooooooooooooooool`0o`0>ooooo`;oo`2I1_ooool0
0ol0003oooooooooo`0Looooo`03o`000?oooooooooo00;ooooo001eooooo`;o0000BOooool00ol0
003oooooooooo`0Hooooo`Wo06Ko1oooool2o`3oo`oooooo0ol00004ooooo`03o`1Voooooooooooo
00Kooooo0_lc0?l:ooooo`03oc<0oooooooooooo00Go06Ko1oooool2ol`0o`?ooooo00?oc03ooooo
ooooool03?ooool2ool0V@Oooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`02oooo
o`00Moooool00ol0003oooooooooo`0cooooo`Ko06Ko3_ooool00ol0003oooooooooo`0>ooooo`Wo
06Ko3_ooool2o`3oo`gooooo1?l00006ooooo`03o`1Voooooooooooo00Gooooo0_lc0?l7ooooo`So
06Ko2_ooool2ol`0o`Cooooo00?oc03oooooooooool02oooool3ool0V@Wooooo00?o0000oooooooo
ool06oooool00ol0003oooooooooo`02ooooo`00N?ooool00ol0003oooooooooo`0fooooob7o06Ko
5Oooool2o`3oo`cooooo0ol00008ooooo`;o06Ko1Oooool3oc<0o`;ooooo1ol0I_l2ooooo`03oc<0
oooooooooooo00_ooooo0_o<0?l5ooooo`03ol`0oooooooooooo00_ooooo00?oo`2Ioooooooo09T0
2oooool00ol0003oooooooooo`0Jooooo`03o`000?oooooooooo00;ooooo001iooooo`03o`000?oo
oooooooo03cooooo2ol0I_l00ol0003oooooooooo`0Pooooo`03o`3ooooooooooooo00Wooooo0ol0
000:ooooo`03o`1Voooooooooooo00;ooooo0olc0?l5o`1Vo`Oooooo0_lc0?l<ooooo`;oc03o1_oo
ool00oo<0?ooooooooooo`0;ooooo`03ool0VOooooooo`2I00gooooo00?o0000ooooooooool06Ooo
ool00ol0003oooooooooo`02ooooo`00N_ooool00ol0003oooooooooo`16oooooa3o06Ko4Oooool2
o`3oo`Oooooo5?l0I_l3oc<0o`kooooo00?o<`3oooooooooool02_ooool2ol`0o`Oooooo00?oc03o
ooooooooool02oooool00ooo09Woooooool0V@0?ooooo`03o`000?ooooooo`0001Sooooo00?o0000
ooooooooool00_ooool007_ooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0;oooo
oa[o06Ko00?o0000ooooooooool02oooool2o`1Vo`04oooooolc0?oo<`3ooc<0o`oooooo0_lc0?l;
ooooo`;oc03o2?ooool00oo<0?ooooooooooo`0:ooooo`;oo`2I00?oooooool0VOooool04?ooool0
0ol0003oo`00ooooo`0Gooooo`03o`000?oooooooooo00;ooooo001looooo`03o`000?oooooooooo
04Oooooo00?o0000ooooooooool06?ooool00ol0ooooooooooooo`03ooooo`Co00003_ooool00ol0
I_oo<`3ooc<0o`02oc<0oa7ooooo00?o<`3oooooooooool02Oooool2ol`0o`Wooooo00?oc03ooooo
ooooool02_ooool01?oo09Wooooooooooooo09T@ooooo`;oo`0000?o0000ooooooooool05oooool0
0ol0003oooooooooo`02ooooo`00OOooool00ol0003oooooooooo`17ooooo`03o`000?oooooooooo
01[ooooo0ol0000@ooooo`?o<`3o5?ooool00olc0?ooooooooooo`08ooooo`;oc03o2Oooool2ol`0
o`cooooo00Coo`2Iooooooooooooo`2I4?ooool3ool00003ooooool0003ooooo01Sooooo00?o0000
ooooooooool00Oooool007kooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Foooo
o`?o00004?ooool3oc<0oaGooooo0_lc0?l9ooooo`;oc03o2_ooool00oo<0?ooooooooooo`0;oooo
o`04ool0VOooooooooooool0VA3ooooo0_oo0004ooooo`03o`000?oooooooooo01Kooooo00?o0000
ooooooooool00Oooool007oooooo00?o0000ooooooooool0Aoooool00ol0003oooooooooo`0Aoooo
o`Co00004?ooool3oc<0o`03o`1Voooooooooooo01Cooooo00?o<`3oooooooooool01oooool2ol`0
o`[ooooo0_o<0?l=ooooo`04ool0VOooooooooooool0VA3ooooo0_oo0006ooooo`03o`000?oooooo
oooo01Gooooo00?o0000ooooooooool00Oooool0083ooooo0_l00018ooooo`03o`000?oooooooooo
00gooooo0ol0000Aooooo`?o<`3o0_l0I_lFooooo`;o<`3o2?ooool2ol`0o`_ooooo00?oc03ooooo
ooooool02oooool2ool0V@;ooooo00?oo`2Iooooooooool03_ooool2ool000Sooooo00?o0000oooo
ooooool05?ooool00ol0003oooooooooo`01ooooo`00P_ooool00ol0003oooooooooo`16ooooo`03
o`000?oooooooooo00Sooooo1?l0000=ooooo`Oo<`3o00?oooooo`1Vool0I_l05oooool00olc0?oo
ooooooooo`06ooooo`;oc03o2oooool2ol`0o`?o<`3o2Oooool2ool0V@?ooooo00?oo`2Ioooooooo
ool03Oooool3ool000[ooooo00?o0000ooooooooool04oooool00ol0003oooooooooo`01ooooo`00
Poooool00ol0003oooooooooo`0Uooooo`Co<`3o7Oooool00ol0003oooooooooo`04ooooo`?o0000
1oooool:oc<0o`Kooooo0_l0I_lGooooo`;o<`3o1oooool2ol`0o`Gooooo1olc0?l00oo<0?oooooo
ooooo`0:ooooo`;oo`2I1?ooool00ooo09Woooooooooo`0=ooooo`03ool00?ooooooo`0000_ooooo
00?o0000ooooooooool04oooool00ol0003oooooooooo`01ooooo`00Q?ooool00ol0003ooooooooo
o`0Xooooo`Oo<`3o5oooool00ol0003oooooooooo`03o`0000[o<`3o3_ooool2o`1VoaSooooo00?o
<`3oooooooooool01?ooool3ol`0o`Oo<`3o1_ooool00oo<0?ooooooooooo`09ooooo`;oo`2I1Ooo
ool00ooo09Woooooooooo`0=ooooo`03ool00?ooooooo`0000gooooo00?o0000ooooooooool04_oo
ool00ol0003oooooooooo`01ooooo`00QOooool00ol0003oooooooooo`0/oooooaoo<`3o5_ooool2
o`1VoaSooooo1_lc0?l3ol`0o`03oc<0oooooooooooo00_ooooo0_o<0?l:ooooo`;oo`2I1_ooool0
0ooo09Woooooooooo`0=ooooo`03ool00?ooooooo`0000oooooo00?o0000ooooooooool04Oooool0
0ol0003oooooooooo`01ooooo`00Q_ooool00ol0003oooooooooo`0fooooo`_o<`3o1?ooool00ol0
003oooooooooo`0Fooooo`;o06Ko3_ooool>oc<0o`Coc03o4?ooool00oo<0?ooooooooooo`08oooo
o`;oo`2I1oooool00ooo09Woooooooooo`0=ooooo`03ool00?ooooooo`00017ooooo00?o0000oooo
ooooool04?ooool00ol0003oooooooooo`01ooooo`00Qoooool00ol0003oooooooooo`10ooooo`_o
<`3o3ooooolCoc<0o`Sooooo0_lc0?l01?ooooooc03ool`0ooo<0?lBooooo`;oc03o2Oooool2ool0
V@Oooooo0_oo09T>ooooo`;oo`0000?oooooool00?ooool04_ooool00ol0003oooooooooo`0?oooo
o`03o`000?oooooooooo007ooooo0028ooooo`03o`000?oooooooooo04?ooooo00?o0000oooooooo
ool01?ooool?oc<0oaWooooo00?o<`3ool`0ooo<0?l00_o<0?lDooooo`03ol`0oooooooooooo00Oo
oooo0_oo09T8ooooo`03ool0VOoooooooooo00gooooo00Coo`00ooooooooooooo`005Oooool00ol0
003oooooooooo`0?ooooo`7o00000Oooool1ooooo`00ROooool00ol0003oooooooooo`12ooooo`03
o`000?oooooooooo02[ooooo0oo<0?lFooooo`;oc03o2?ooool2ool0V@Sooooo0_oo09T?ooooo`04
ool00?ooooooooooool001Kooooo00?o0000ooooooooool03oooool1o`00007ooooo0Oooool008[o
oooo00?o0000ooooooooool0@Oooool00ol0003oooooooooo`0Wooooo`?oc03o6?ooool00oo<0?oo
ooooooooo`06ooooo`;oo`2I2Oooool00ooo09Woooooooooo`0>ooooo`04ool00?ooooooooooool0
01Sooooo00?o0000ooooooooool03_ooool1o`00007ooooo0Oooool008_ooooo0_l00011ooooo`03
o`000?oooooooooo02?ooooo1?o<0?l00olc0?ooooooooooo`0Fooooo`;oc03o1oooool2ool0V@[o
oooo00?oo`2Iooooooooool03_ooool01?oo003ooooooooooooo000Jooooo`03o`000?oooooooooo
00gooooo0Ol00001ooooo`7ooooo002=ooooo`03o`000?oooooooooo03kooooo00?o0000oooooooo
ool08?ooool3ol`0o`;ooooo00?o<`3oooooooooool05oooool00oo<0?ooooooooooo`05ooooo`;o
o`2I2_ooool2ool0V@oooooo0_oo0002ooooo`03ool00?oooooooooo01[ooooo00?o0000oooooooo
ool03?ooool1o`00007ooooo0Oooool008kooooo00?o0000ooooooooool0?Oooool00ol0003ooooo
ooooo`0Jooooo`Koc03o0oooool2oc<0oaWooooo00?oc03oooooooooool01?ooool2ool0V@_ooooo
00?oo`2Iooooooooool03Oooool2ool000?ooooo00?oo`00ooooooooool07?ooool00ol0003ooooo
ooooo`0;ooooo`7o00000Oooool1ooooo`00Soooool00ol0003oooooooooo`0looooo`03o`000?oo
oooooooo01;ooooo2?o<0?l7ooooo`;o<`3o6Oooool2ol`0o`Gooooo0_oo09T:ooooo`03ol`0oooo
09Woo`2I00;oc03o3?ooool2ool000Cooooo00?oo`00ooooooooool07_ooool00ol0003ooooooooo
o`0:ooooo`7o00000Oooool1ooooo`00T?ooool00ol0003oooooooooo`0Fooooo`Ooc03o7_ooool0
0ol0003oooooooooo`09ooooo`Woc03o3Oooool2oc<0oa[ooooo00?oc03oooooooooool00_ooool3
ool0V@?ooooo2Oo<0?l00ooo09Woooooooooo`0<ooooo`;oo`001Oooool00ooo003oooooooooo`0O
ooooo`03o`000?oooooooooo00[ooooo0Ol00001ooooo`7ooooo002Aooooo`03o`000?oooooooooo
01Wooooo5Oo<0?l<ooooo`04o`000?ooooooooooooooo`Soc03o5?ooool2oc<0oa[ooooo0_o<0?l2
ooooo`?oo`2I1_o<0?l7ooooo`;oo`2I3Oooool2ool000Kooooo00?oo`00ooooooooool08Oooool0
0ol0003oooooooooo`09ooooo`7o00000Oooool1ooooo`00T_ooool00ol0003oooooooooo`0Ooooo
o`coc03o0_ooool@ol`0oa[ooooo0_lc0?lHooooo`Goc03o0ooo09T00oo<0?ooooooooooo`0<oooo
o`03ool0VOoooooooooo00_ooooo0_oo0006ooooo`;oo`009Oooool00ol0003oooooooooo`08oooo
o`7o00000Oooool1ooooo`00Toooool00ol0003oooooooooo`0Zoooooa7oc03o6_ooool00olc0?oo
ooooooooo`0Iol`0o`Coo`2I4Oooool00ooo09Woooooooooo`0:ooooo`;oo`001oooool00ooo003o
ooooooooo`0Vooooo`03o`000?oooooooooo00Sooooo0Ol00001ooooo`00U?ooool00ol0003ooooo
ooooo`0gooooo`03o`000?oooooooooo01goc03o5Oooool01?o<0?ooo`2Iool0VOoo09TCooooo`;o
o`2I2_ooool3ool000Oooooo0_oo000Zooooo`03o`000?oooooooooo00Oooooo0Ol00001ooooo`00
UOooool00ol0003oooooooooo`0fooooo`03o`000?oooooooooo033ooooo0ooo09TEooooo`03ool0
VOoooooooooo00Sooooo0_oo0009ooooo`03ool00?oooooooooo02_ooooo00?o0000ooooooooool0
1_ooool1o`00007ooooo002Fooooo`03o`000?oooooooooo03Gooooo00?o0000ooooooooool0;Ooo
ool3ool0VAKooooo0_oo09T9ooooo`;oo`002Oooool2ool002kooooo00?o0000ooooooooool01_oo
ool1o`00007ooooo002Gooooo`;o0000=Oooool00ol0003oooooooooo`0Yooooo`Coo`2I00?oc03o
ooooooooool05Oooool00ooo09Woooooooooo`07ooooo`;oo`002_ooool00ooo003oooooooooo`0_
ooooo`03o`000?oooooooooo00Gooooo0Ol00001ooooo`00VOooool00ol0003oooooooooo`0boooo
o`03o`000?oooooooooo02Kooooo0ooo09T00oooooooc03ool`0o`0Hooooo`03ool0VOoooooooooo
00Kooooo0_oo000:ooooo`;oo`00<oooool00ol0003oooooooooo`04ooooo`7o00000Oooool009[o
oooo00?o0000ooooooooool0<Oooool00ol0003oooooooooo`0Sooooo`?oo`2I0_ooool2ol`0oaSo
oooo0_oo09T7ooooo`;oo`002oooool00ooo003oooooooooo`0dooooo`03o`000?oooooooooo00?o
oooo0Ol00001ooooo`00Voooool00ol0003oooooooooo`0`ooooo`03o`000?oooooooooo01gooooo
1_oo09T2ooooo`?oc03o6Oooool00ooo09Woooooooooo`05ooooo`;oo`001oooool4ool0V@;oo`00
>?ooool00ol0003oooooooooo`02ooooo`7o00000Oooool009cooooo00?o0000ooooooooool0;ooo
ool00ol0003oooooooooo`0Dooooo`Woo`2I1_ooool2ol`0oa[ooooo0_oo09T5ooooo`?oo`000_oo
ool7ool0V@;ooooo0_oo000kooooo`05o`000?ooooooooooooooool000000Oooool009gooooo00?o
0000ooooooooool02?ooool7ool0VAoooooo00?o0000ooooooooool02oooool9ool0V@gooooo0_o<
0?lJooooo`;oo`2I1?ooool3ool000Goo`2I2?ooool00ooo003oooooooooo`0kooooo`05o`000?oo
ooooooooooooool000000Oooool009kooooo00?o0000ooooooooool02ooooolFool0V@cooooo00?o
0000ooooooooool00_ooool9ool0VAGooooo00?oc03oooooooooool06?ooool4ool0V@Coo`0000?o
o`2Iooooooooool02oooool2ool003oooooo00Co0000oooooooooooooooo0Ol0000009oooooo00?o
0000ooooooooool04?ooool<ool0V@Cooooo4Ooo09Tdooooo`Goo`2I1?oo000Aooooo`03ool00?oo
oooooooo043ooooo00?o0000ooooooooool00Ol000000:3ooooo00?o0000ooooooooool06ooooolC
ool0VAgooooo6Ooo09T00oooooooo`2Iool00002ool001?ooooo0_oo0014ooooo`7o00000Oooool1
o`000000XOooool00ol0003oooooooooo`0Zooooo`03o`000?oooooooooo01goo`2I5oooool4ool0
01Gooooo00?oo`00ooooooooool0AOooool2o`000000X_ooool2o`0002[ooooo00?o0000oooooooo
ool0<Oooool3ool00003ool0VOoooooooooo01Cooooo0_oo0017ooooo`?o0000002Tooooo`03o`00
0?oooooooooo02Oooooo00?o0000ooooooooool0;Oooool4ool00003ool0VOoooooooooo01Kooooo
00?oo`00ooooooooool0@oooool4o`0000?ooooo002Uooooo`03o`000?oooooooooo02Kooooo00?o
0000ooooooooool0:Oooool4ool00003oooooooo09Woo`2I01Sooooo0_oo0013ooooo`?o00001ooo
ool00:Kooooo00?o0000ooooooooool09Oooool00ol0003oooooooooo`0Vooooo`?oo`000oooool2
ool0VAWooooo00?oo`00ooooooooool0?oooool4o`0000[ooooo002Wooooo`03o`000?oooooooooo
02Cooooo00?o0000ooooooooool07oooool7ool000Cooooo0_oo09TIooooo`;oo`00?_ooool4o`00
00kooooo002Xooooo`03o`000?oooooooooo02?ooooo00?o0000ooooooooool05_ooool9ool000Wo
oooo0_oo09TIooooo`;oo`003_ooool6ool002Wooooo0ol0000Booooo`00ZOooool00ol0003ooooo
ooooo`0Rooooo`03o`000?oooooooooo00gooooo2Ooo000@ooooo`;oo`2I6Oooool2ool000Oooooo
2Ooo000[ooooo`Co00005Oooool00:[ooooo00Co0000oooooooooooooooo0ooo000Mooooo`03o`00
0?oooooooooo00Cooooo2Ooo000Hooooo`03ool0VOoooooooooo01Oooooo2ooo000`ooooo`Co0000
6Oooool00:_ooooo00?o0000ooooooooool09ooo000dooooo`Woo`00=Oooool4o`0001gooooo002/
ooooo`03o`000?oooooooooo00_ooooo3Ooo0008ooooo`03o`000?oooooooooo02Oooooo4?oo0003
ooooo`;oo`00=_ooool3o`00027ooooo002]ooooo`;o00006?ooool=ool0013ooooo5Ooo000Aoooo
o`;oo`00=?ooool4o`0002Cooooo002_ooooo`03o`000?oooooooooo01gooooo00?o0000oooooooo
ool00_ooool@ool002Cooooo0_oo000booooo`Co0000:?ooool00;3ooooo00?o0000ooooooooool0
7?ooool00ol0003oooooooooo`0dooooo`;oo`00<Oooool3o`0002cooooo002aooooo`03o`000?oo
oooooooo01_ooooo00?o0000ooooooooool0<_ooool2ool002oooooo1?l0000_ooooo`00/_ooool0
0ol0003oooooooooo`0Jooooo`03o`000?oooooooooo033ooooo0_oo000]ooooo`Co0000<oooool0
0;?ooooo00?o0000ooooooooool06Oooool00ol0003oooooooooo`0^ooooo`;oo`00;?ooool3o`00
03Oooooo002dooooo`03o`000?oooooooooo01Sooooo00?o0000ooooooooool0;?ooool2ool002[o
oooo1?l0000jooooo`00]Oooool00ol0003oooooooooo`0Gooooo`03o`000?oooooooooo02[ooooo
0_oo000Xooooo`Co0000?_ooool00;Kooooo00?o0000ooooooooool05_ooool00ol0003ooooooooo
o`0Yooooo`03ool00?oooooooooo02Cooooo1?l00012ooooo`00]oooool00ol0003oooooooooo`0E
ooooo`03o`000?oooooooooo04gooooo0ol00016ooooo`00^?ooool2o`0001Gooooo00?o0000oooo
ooooool0BOooool4o`0004Wooooo002jooooo`03o`000?oooooooooo01;ooooo00?o0000oooooooo
ool0AOooool4o`0004gooooo002kooooo`03o`000?oooooooooo017ooooo00?o0000ooooooooool0
@_ooool3o`00057ooooo002looooo`03o`000?oooooooooo013ooooo00?o0000ooooooooool0?_oo
ool4o`0005Cooooo002mooooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool0>_ooool4
o`0005Sooooo002nooooo`03o`000?oooooooooo00kooooo00?o0000ooooooooool0=_ooool4o`00
05cooooo002oooooo`03o`000?oooooooooo00gooooo00?o0000ooooooooool0<oooool3o`00063o
oooo0030ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool0;oooool4o`0006?ooooo
0031ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0:oooool4o`0006Oooooo0032
ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0:?ooool3o`0006_ooooo0033oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool09?ooool4o`0006kooooo0034ooooo`;o
00002Oooool00ol0003oooooooooo`0Pooooo`Co0000L_ooool00<Kooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`0Mooooo`?o0000M_ooool00<Oooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`0Iooooo`Co0000NOooool00<Sooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`0Eooooo`Co0000OOooool00<Wooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`0Aooooo`Co0000POooool00<[ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0>ooooo`?o0000QOooool00<_ooooo00Go0000ooooooooooooooooo`00000<ooooo`Co
0000R?ooool00<cooooo00Co0000oooooooooooo00002?ooool4o`0008cooooo003=ooooo`03o`00
0?oooooo000000Gooooo0ol0002@ooooo`00c_ooool2o`000003ooooool0003o000000;o0000Tooo
ool00<oooooo0_l0002Gooooo`00oooooomYooooo`00oooooomYooooo`00oooooomYooooo`00oooo
oomYooooo`00oooooomYooooo`00\
\>"],
  ImageRangeCache->{{{0, 359}, {330.375, 0}} -> {-0.0771432, -0.0315529, \
0.00350368, 0.00350368}}]
}, Closed]]
}, Open  ]],

Cell[TextData[{
  "Now contours of constant phase are bent inward and cross, forming folds in \
the phase surface. These folds are perhaps easiest to understand when viewed \
in Fig. ",
  ButtonBox["5.12",
    ButtonData:>"Fig. 5.12",
    ButtonStyle->"Hyperlink"],
  ", which like Cell ",
  ButtonBox["5.44",
    ButtonData:>"Cell 5.44",
    ButtonStyle->"Hyperlink"],
  "  displays a single constant phase contour (in red) at several \
evenly-spaced times,  along with ray trajectories (in black). Here, however, \
we increase the number of rays."
}], "Text"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 2 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.5 0.295436 0.047619 0.324101 [
[.05685 .03512 -12 -9 ]
[.05685 .03512 12 0 ]
[.20456 .03512 -6 -9 ]
[.20456 .03512 6 0 ]
[.35228 .03512 -12 -9 ]
[.35228 .03512 12 0 ]
[.64772 .03512 -9 -9 ]
[.64772 .03512 9 0 ]
[.79544 .03512 -3 -9 ]
[.79544 .03512 3 0 ]
[.94315 .03512 -9 -9 ]
[.94315 .03512 9 0 ]
[1.025 .04762 0 -6 ]
[1.025 .04762 10 6 ]
[.4875 .37172 -6 -4.5 ]
[.4875 .37172 0 4.5 ]
[.4875 .69582 -6 -4.5 ]
[.4875 .69582 0 4.5 ]
[.4875 1.01992 -6 -4.5 ]
[.4875 1.01992 0 4.5 ]
[.4875 1.34402 -6 -4.5 ]
[.4875 1.34402 0 4.5 ]
[.4875 1.66812 -6 -4.5 ]
[.4875 1.66812 0 4.5 ]
[.4875 1.99222 -6 -4.5 ]
[.4875 1.99222 0 4.5 ]
[.5 2.025 -5 0 ]
[.5 2.025 5 12 ]
[ 0 0 0 0 ]
[ 1 2 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.05685 .04762 m
.05685 .05387 L
s
[(-1.5)] .05685 .03512 0 1 Mshowa
.20456 .04762 m
.20456 .05387 L
s
[(-1)] .20456 .03512 0 1 Mshowa
.35228 .04762 m
.35228 .05387 L
s
[(-0.5)] .35228 .03512 0 1 Mshowa
.64772 .04762 m
.64772 .05387 L
s
[(0.5)] .64772 .03512 0 1 Mshowa
.79544 .04762 m
.79544 .05387 L
s
[(1)] .79544 .03512 0 1 Mshowa
.94315 .04762 m
.94315 .05387 L
s
[(1.5)] .94315 .03512 0 1 Mshowa
.125 Mabswid
.08639 .04762 m
.08639 .05137 L
s
.11593 .04762 m
.11593 .05137 L
s
.14548 .04762 m
.14548 .05137 L
s
.17502 .04762 m
.17502 .05137 L
s
.23411 .04762 m
.23411 .05137 L
s
.26365 .04762 m
.26365 .05137 L
s
.2932 .04762 m
.2932 .05137 L
s
.32274 .04762 m
.32274 .05137 L
s
.38183 .04762 m
.38183 .05137 L
s
.41137 .04762 m
.41137 .05137 L
s
.44091 .04762 m
.44091 .05137 L
s
.47046 .04762 m
.47046 .05137 L
s
.52954 .04762 m
.52954 .05137 L
s
.55909 .04762 m
.55909 .05137 L
s
.58863 .04762 m
.58863 .05137 L
s
.61817 .04762 m
.61817 .05137 L
s
.67726 .04762 m
.67726 .05137 L
s
.7068 .04762 m
.7068 .05137 L
s
.73635 .04762 m
.73635 .05137 L
s
.76589 .04762 m
.76589 .05137 L
s
.82498 .04762 m
.82498 .05137 L
s
.85452 .04762 m
.85452 .05137 L
s
.88407 .04762 m
.88407 .05137 L
s
.91361 .04762 m
.91361 .05137 L
s
.0273 .04762 m
.0273 .05137 L
s
.9727 .04762 m
.9727 .05137 L
s
.25 Mabswid
0 .04762 m
1 .04762 L
s
gsave
1.025 .04762 -61 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(x) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.5 .37172 m
.50625 .37172 L
s
[(1)] .4875 .37172 1 0 Mshowa
.5 .69582 m
.50625 .69582 L
s
[(2)] .4875 .69582 1 0 Mshowa
.5 1.01992 m
.50625 1.01992 L
s
[(3)] .4875 1.01992 1 0 Mshowa
.5 1.34402 m
.50625 1.34402 L
s
[(4)] .4875 1.34402 1 0 Mshowa
.5 1.66812 m
.50625 1.66812 L
s
[(5)] .4875 1.66812 1 0 Mshowa
.5 1.99222 m
.50625 1.99222 L
s
[(6)] .4875 1.99222 1 0 Mshowa
.125 Mabswid
.5 .11244 m
.50375 .11244 L
s
.5 .17726 m
.50375 .17726 L
s
.5 .24208 m
.50375 .24208 L
s
.5 .3069 m
.50375 .3069 L
s
.5 .43654 m
.50375 .43654 L
s
.5 .50136 m
.50375 .50136 L
s
.5 .56618 m
.50375 .56618 L
s
.5 .631 m
.50375 .631 L
s
.5 .76064 m
.50375 .76064 L
s
.5 .82546 m
.50375 .82546 L
s
.5 .89028 m
.50375 .89028 L
s
.5 .9551 m
.50375 .9551 L
s
.5 1.08474 m
.50375 1.08474 L
s
.5 1.14956 m
.50375 1.14956 L
s
.5 1.21438 m
.50375 1.21438 L
s
.5 1.2792 m
.50375 1.2792 L
s
.5 1.40884 m
.50375 1.40884 L
s
.5 1.47366 m
.50375 1.47366 L
s
.5 1.53848 m
.50375 1.53848 L
s
.5 1.6033 m
.50375 1.6033 L
s
.5 1.73294 m
.50375 1.73294 L
s
.5 1.79776 m
.50375 1.79776 L
s
.5 1.86258 m
.50375 1.86258 L
s
.5 1.9274 m
.50375 1.9274 L
s
.25 Mabswid
.5 0 m
.5 2 L
s
gsave
.5 2.025 -66 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(y) show
69.000 13.000 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 0 m
1 0 L
1 2 L
0 2 L
closepath
clip
newpath
.5 Mabswid
.05685 .04762 m
.05685 .05002 L
.05685 .0522 L
.05685 .05472 L
.05685 .05711 L
.05685 .05916 L
.05685 .06135 L
.05685 .06374 L
.05685 .06595 L
.05685 .07055 L
.05685 .07309 L
.05685 .0755 L
.05685 .07834 L
.05685 .08093 L
.05685 .08602 L
.05685 .09088 L
.05685 .09606 L
.05685 .09858 L
.05685 .10095 L
.05685 .10307 L
.05685 .10538 L
.05685 .11073 L
.05685 .11638 L
.05685 .12121 L
.05685 .12395 L
.05685 .12651 L
.05685 .12928 L
.05685 .13185 L
.05685 .13766 L
.05685 .14278 L
.05685 .14537 L
.05685 .14684 L
.05685 .14822 L
.05685 .15287 L
.05685 .1552 L
.05685 .15775 L
.05685 .16053 L
.05685 .16311 L
.05685 .16549 L
.05685 .16803 L
.05685 .17378 L
.05685 .17681 L
.05685 .17847 L
.05685 .18002 L
.05685 .18138 L
.05685 .18283 L
.05685 .18592 L
.05685 .19135 L
.05685 .19407 L
.05685 .19703 L
Mistroke
.05685 .19983 L
.05685 .20242 L
.05685 .20497 L
.05685 .20734 L
.05685 .20982 L
.05685 .21254 L
.05685 .21516 L
.05685 .21662 L
.05685 .21796 L
.05685 .22294 L
.05685 .22832 L
.05685 .23116 L
.05685 .23271 L
.05685 .23417 L
.05685 .23676 L
.05685 .23961 L
.05685 .24463 L
.05685 .24945 L
.05685 .25208 L
.05685 .25452 L
.05685 .25909 L
.05685 .26151 L
.05685 .26408 L
.05685 .26867 L
.05685 .27283 L
.05685 .28298 L
.05685 .29254 L
.05685 .30203 L
.05685 .30741 L
.05685 .31244 L
.05685 .32259 L
.05685 .32829 L
.05685 .33349 L
.05685 .34275 L
.05685 .34764 L
.05685 .35284 L
.05685 .35736 L
.05685 .36236 L
.05685 .37119 L
.05685 .3812 L
.05685 .38624 L
.05685 .39176 L
.05685 .40153 L
.05685 .41063 L
.05685 .42139 L
.05686 .43118 L
.05686 .44247 L
.05687 .45314 L
.05688 .46254 L
.05689 .47289 L
Mistroke
.05691 .48369 L
.05693 .49378 L
.05696 .50319 L
.05699 .51179 L
.05708 .53107 L
.05715 .54066 L
.05723 .55085 L
.05744 .56909 L
.05761 .5802 L
.0578 .59061 L
.05826 .60994 L
.05887 .62895 L
.0597 .64886 L
.06173 .68416 L
.06476 .72145 L
.06845 .75628 L
.07885 .83133 L
.09249 .91306 L
.10653 .99275 L
.12017 1.06958 L
.13469 1.15136 L
.14868 1.23009 L
.16213 1.30579 L
.17645 1.3864 L
.19023 1.46397 L
.20489 1.54646 L
.219 1.62591 L
.23258 1.70233 L
.24703 1.78366 L
.26094 1.86195 L
.27572 1.94516 L
.277 1.95238 L
Mfstroke
.07162 .04762 m
.07162 .05002 L
.07162 .0522 L
.07162 .05472 L
.07162 .05711 L
.07162 .05916 L
.07162 .06135 L
.07162 .06374 L
.07162 .06595 L
.07162 .07055 L
.07162 .07309 L
.07162 .0755 L
.07162 .07834 L
.07162 .08093 L
.07162 .08602 L
.07162 .09088 L
.07162 .09355 L
.07162 .09606 L
.07162 .09841 L
.07162 .10095 L
.07162 .10538 L
.07162 .11073 L
.07162 .11365 L
.07162 .11638 L
.07162 .11891 L
.07162 .12121 L
.07162 .12376 L
.07162 .12651 L
.07162 .13184 L
.07162 .13476 L
.07162 .13619 L
.07162 .1375 L
.07162 .13982 L
.07162 .14233 L
.07162 .14767 L
.07162 .14901 L
.07162 .15044 L
.07162 .15302 L
.07162 .15888 L
.07162 .16041 L
.07162 .16206 L
.07162 .16362 L
.07162 .16507 L
.07162 .1678 L
.07162 .17069 L
.07162 .17565 L
.07162 .18098 L
.07162 .18356 L
.07162 .18602 L
.07162 .18822 L
Mistroke
.07162 .19062 L
.07162 .19351 L
.07162 .19613 L
.07162 .20199 L
.07162 .20702 L
.07162 .20969 L
.07162 .21254 L
.07162 .21524 L
.07162 .21771 L
.07162 .22252 L
.07162 .22794 L
.07162 .23306 L
.07162 .23778 L
.07162 .24221 L
.07162 .24683 L
.07162 .25192 L
.07162 .25702 L
.07162 .26251 L
.07162 .26719 L
.07162 .2723 L
.07162 .27523 L
.07162 .27794 L
.07162 .28387 L
.07162 .28938 L
.07162 .29445 L
.07162 .29948 L
.07162 .30201 L
.07162 .3048 L
.07162 .316 L
.07162 .32106 L
.07162 .3265 L
.07162 .33162 L
.07162 .33631 L
.07162 .34564 L
.07162 .35091 L
.07162 .3558 L
.07162 .36476 L
.07162 .36928 L
.07162 .37428 L
.07162 .38429 L
.07162 .38933 L
.07162 .39485 L
.07162 .40462 L
.07162 .41372 L
.07163 .42448 L
.07163 .43426 L
.07164 .44555 L
.07165 .45621 L
.07166 .46561 L
.07167 .47595 L
Mistroke
.0717 .48673 L
.07172 .49681 L
.07175 .5062 L
.07179 .51477 L
.07191 .53399 L
.07199 .54355 L
.0721 .55369 L
.07235 .57183 L
.07255 .58286 L
.07278 .59319 L
.07332 .61235 L
.07403 .63116 L
.07499 .65083 L
.07732 .68565 L
.08077 .72238 L
.08496 .7567 L
.09679 .83074 L
.11252 .91166 L
.12882 .99075 L
.14471 1.06706 L
.16162 1.14827 L
.17791 1.22647 L
.19357 1.30166 L
.21025 1.38172 L
.2263 1.45877 L
.24337 1.5407 L
.2598 1.61961 L
.27561 1.69551 L
.29244 1.77628 L
.30864 1.85404 L
.32585 1.93669 L
.32672 1.94084 L
Mfstroke
.08639 .04762 m
.08639 .05002 L
.08639 .0522 L
.08639 .05472 L
.08639 .05711 L
.08639 .05931 L
.08639 .06135 L
.08639 .06595 L
.08639 .06837 L
.08639 .07098 L
.08639 .07344 L
.08639 .07569 L
.08639 .08061 L
.08639 .08602 L
.08639 .08851 L
.08639 .09117 L
.08639 .09367 L
.08639 .09594 L
.08639 .10152 L
.08639 .10678 L
.08639 .10918 L
.08639 .11171 L
.08639 .11625 L
.08639 .11878 L
.08639 .12114 L
.08639 .12393 L
.08639 .12651 L
.08639 .1291 L
.08639 .1304 L
.08639 .13185 L
.08639 .13485 L
.08639 .13766 L
.08639 .14317 L
.08639 .14558 L
.08639 .14822 L
.08639 .15063 L
.08639 .15287 L
.08639 .15775 L
.08639 .16031 L
.08639 .16272 L
.08639 .16406 L
.08639 .1655 L
.08639 .16803 L
.08639 .16936 L
.08639 .17079 L
.08639 .17338 L
.08639 .17928 L
.08639 .18539 L
.08639 .19119 L
.08639 .19652 L
Mistroke
.08639 .19799 L
.08639 .19954 L
.08639 .20101 L
.08639 .20234 L
.08639 .20487 L
.08639 .2076 L
.08639 .21254 L
.08639 .23365 L
.08639 .24395 L
.08639 .24845 L
.08639 .25333 L
.08639 .25842 L
.08639 .26324 L
.08639 .27386 L
.08639 .27954 L
.08639 .2824 L
.08639 .28556 L
.08639 .29072 L
.08639 .29637 L
.08639 .30124 L
.08639 .30644 L
.08639 .31193 L
.08639 .31703 L
.08639 .32213 L
.08639 .32695 L
.08639 .33127 L
.08639 .33595 L
.08639 .34152 L
.08639 .34673 L
.08639 .35216 L
.08639 .35813 L
.08639 .36798 L
.08639 .37351 L
.08639 .37855 L
.08639 .38834 L
.08639 .39329 L
.08639 .39875 L
.0864 .40839 L
.0864 .41745 L
.0864 .42806 L
.08641 .4378 L
.08642 .44848 L
.08643 .45972 L
.08644 .46987 L
.08646 .47908 L
.08649 .4897 L
.08652 .49971 L
.08656 .50895 L
.0866 .51746 L
.08675 .5366 L
Mistroke
.08684 .5459 L
.08696 .55585 L
.08726 .57371 L
.08749 .58451 L
.08776 .59471 L
.08838 .61368 L
.08917 .63193 L
.09024 .65117 L
.09283 .68531 L
.09706 .72469 L
.10232 .76181 L
.11579 .83413 L
.13371 .91346 L
.15236 .9911 L
.17054 1.06603 L
.18992 1.14582 L
.20858 1.22263 L
.22841 1.30427 L
.24752 1.38292 L
.2659 1.45859 L
.28546 1.53909 L
.30429 1.6166 L
.32239 1.69112 L
.34167 1.77048 L
.36022 1.84685 L
.37957 1.92651 L
Mfstroke
.10116 .04762 m
.10116 .05002 L
.10116 .0522 L
.10116 .05472 L
.10116 .05711 L
.10116 .06135 L
.10116 .06595 L
.10116 .07638 L
.10116 .08602 L
.10116 .10692 L
.10116 .11715 L
.10116 .12162 L
.10116 .12651 L
.10116 .12905 L
.10116 .13141 L
.10116 .13367 L
.10116 .13608 L
.10116 .13886 L
.10116 .14148 L
.10116 .14638 L
.10116 .16827 L
.10116 .18979 L
.10116 .20156 L
.10116 .21254 L
.10116 .21738 L
.10116 .22197 L
.10116 .22726 L
.10116 .23208 L
.10116 .23467 L
.10116 .23598 L
.10116 .23742 L
.10116 .24236 L
.10116 .24819 L
.10116 .25074 L
.10116 .25353 L
.10116 .2581 L
.10116 .26058 L
.10116 .2629 L
.10116 .26778 L
.10116 .27299 L
.10116 .28256 L
.10116 .29125 L
.10116 .30115 L
.10116 .30614 L
.10116 .31163 L
.10116 .31631 L
.10116 .32134 L
.10116 .33042 L
.10116 .33587 L
.10116 .34181 L
Mistroke
.10116 .34741 L
.10116 .35261 L
.10116 .36243 L
.10116 .36791 L
.10116 .37288 L
.10116 .38286 L
.10117 .38789 L
.10117 .39339 L
.10117 .40314 L
.10117 .41223 L
.10117 .42297 L
.10118 .43275 L
.10119 .44402 L
.1012 .45467 L
.10121 .46403 L
.10123 .47433 L
.10126 .48507 L
.10129 .49512 L
.10133 .50446 L
.10138 .51299 L
.10152 .53212 L
.10162 .54157 L
.10175 .55161 L
.10206 .56954 L
.1023 .58042 L
.10258 .59059 L
.10324 .60943 L
.10408 .6278 L
.10522 .64696 L
.10796 .68074 L
.11199 .71613 L
.11689 .74913 L
.13111 .82026 L
.15096 .89858 L
.17229 .97573 L
.19328 1.05037 L
.21568 1.12986 L
.23725 1.2064 L
.25798 1.27998 L
.28006 1.35834 L
.30131 1.43375 L
.32391 1.51394 L
.34568 1.59117 L
.36661 1.66545 L
.38889 1.74451 L
.41033 1.82061 L
.43313 1.9015 L
.43523 1.90895 L
Mfstroke
.11593 .04762 m
.11593 .05002 L
.11593 .0522 L
.11593 .05472 L
.11593 .05711 L
.11593 .06135 L
.11593 .06595 L
.11593 .07638 L
.11593 .08602 L
.11593 .10692 L
.11593 .11715 L
.11593 .12162 L
.11593 .12651 L
.11593 .12905 L
.11593 .13141 L
.11593 .13367 L
.11593 .13608 L
.11593 .13886 L
.11593 .14148 L
.11593 .14638 L
.11593 .16827 L
.11593 .18979 L
.11593 .21254 L
.11593 .22197 L
.11593 .23208 L
.11593 .23789 L
.11593 .24318 L
.11593 .24856 L
.11593 .25353 L
.11593 .26281 L
.11593 .26771 L
.11593 .2729 L
.11593 .2774 L
.11593 .28163 L
.11593 .28626 L
.11593 .29125 L
.11593 .29615 L
.11593 .30138 L
.11593 .3059 L
.11593 .31079 L
.11593 .31656 L
.11593 .32199 L
.11593 .33217 L
.11593 .33735 L
.11593 .34306 L
.11593 .34901 L
.11593 .35458 L
.11594 .36454 L
.11594 .37014 L
.11594 .37524 L
Mistroke
.11594 .385 L
.11594 .39045 L
.11594 .39539 L
.11594 .40501 L
.11594 .41406 L
.11595 .42465 L
.11595 .43437 L
.11596 .44504 L
.11598 .45628 L
.11599 .46638 L
.11601 .47556 L
.11604 .48613 L
.11608 .49611 L
.11613 .5053 L
.11618 .51377 L
.11635 .53282 L
.11646 .54202 L
.1166 .55186 L
.11694 .56951 L
.1172 .57964 L
.11751 .59019 L
.11823 .60882 L
.11913 .62663 L
.12034 .64534 L
.12326 .67839 L
.128 .71618 L
.13393 .75169 L
.14955 .8207 L
.17155 .89692 L
.19546 .97218 L
.2191 1.04506 L
.24435 1.12273 L
.26866 1.1975 L
.29451 1.27698 L
.3194 1.35355 L
.34335 1.4272 L
.36883 1.50556 L
.39337 1.58102 L
.41696 1.65355 L
.44208 1.73081 L
.46625 1.80515 L
.49196 1.8842 L
.49313 1.88782 L
Mfstroke
.13071 .04762 m
.13071 .05002 L
.13071 .0522 L
.13071 .05472 L
.13071 .05711 L
.13071 .06135 L
.13071 .06595 L
.13071 .07638 L
.13071 .08602 L
.13071 .10692 L
.13071 .11715 L
.13071 .12162 L
.13071 .12651 L
.13071 .12905 L
.13071 .13141 L
.13071 .13367 L
.13071 .13608 L
.13071 .13886 L
.13071 .14148 L
.13071 .14638 L
.13071 .16827 L
.13071 .18979 L
.13071 .21254 L
.13071 .22197 L
.13071 .23208 L
.13071 .23789 L
.13071 .24318 L
.13071 .2485 L
.13071 .25353 L
.13071 .25808 L
.13071 .26292 L
.13071 .26705 L
.13071 .2716 L
.13071 .27648 L
.13071 .27904 L
.13071 .28174 L
.13071 .2867 L
.13071 .29125 L
.13071 .30146 L
.13071 .30629 L
.13071 .31074 L
.13071 .31588 L
.13071 .32145 L
.13071 .32667 L
.13071 .33156 L
.13071 .34023 L
.13071 .34483 L
.13071 .34977 L
.13071 .35494 L
.13071 .35985 L
Mistroke
.13071 .36906 L
.13071 .37436 L
.13071 .37935 L
.13071 .38867 L
.13071 .3939 L
.13071 .39871 L
.13071 .40954 L
.13072 .41825 L
.13072 .42779 L
.13073 .43774 L
.13074 .44701 L
.13075 .45721 L
.13078 .46828 L
.1308 .4787 L
.13084 .48831 L
.13088 .49694 L
.13093 .50641 L
.131 .51627 L
.13108 .52547 L
.13133 .5449 L
.1315 .55458 L
.13172 .56506 L
.13223 .58342 L
.13286 .6002 L
.13384 .6197 L
.13501 .63773 L
.13795 .6707 L
.14236 .70545 L
.14769 .73715 L
.16368 .80568 L
.18495 .87408 L
.21175 .94926 L
.23892 1.02254 L
.26805 1.10062 L
.29612 1.17585 L
.32313 1.24822 L
.35187 1.32522 L
.37953 1.39935 L
.40613 1.47063 L
.43446 1.54653 L
.46172 1.61958 L
.49071 1.69725 L
.51863 1.77207 L
.54548 1.84402 L
.55252 1.86288 L
Mfstroke
.14548 .04762 m
.14548 .05002 L
.14548 .0522 L
.14548 .05472 L
.14548 .05711 L
.14548 .06135 L
.14548 .06595 L
.14548 .07638 L
.14548 .08602 L
.14548 .10692 L
.14548 .11715 L
.14548 .12162 L
.14548 .12651 L
.14548 .12905 L
.14548 .13141 L
.14548 .13367 L
.14548 .13608 L
.14548 .13886 L
.14548 .14148 L
.14548 .14638 L
.14548 .16827 L
.14548 .18979 L
.14548 .21254 L
.14548 .22197 L
.14548 .23208 L
.14548 .23789 L
.14548 .24318 L
.14548 .24856 L
.14548 .25353 L
.14548 .26281 L
.14548 .26771 L
.14548 .2729 L
.14548 .28163 L
.14548 .28659 L
.14548 .29125 L
.14548 .29622 L
.14548 .30084 L
.14548 .30633 L
.14548 .31133 L
.14548 .31658 L
.14548 .32154 L
.14548 .32685 L
.14548 .33246 L
.14548 .33695 L
.14548 .34189 L
.14548 .35059 L
.14548 .35548 L
.14548 .36074 L
.14548 .37024 L
.14548 .37543 L
Mistroke
.14548 .38096 L
.14548 .39091 L
.14548 .397 L
.14549 .40273 L
.14549 .40794 L
.14549 .41343 L
.14549 .42369 L
.1455 .43311 L
.14551 .44323 L
.14553 .45432 L
.14555 .46498 L
.14557 .47504 L
.14561 .48404 L
.14565 .4938 L
.14571 .50437 L
.1458 .51552 L
.14589 .52499 L
.14602 .53537 L
.14617 .545 L
.14637 .55506 L
.14681 .57279 L
.14747 .59152 L
.14844 .61155 L
.14962 .63006 L
.15095 .64654 L
.15488 .68257 L
.1598 .71489 L
.16673 .74966 L
.18594 .81936 L
.21133 .88935 L
.23972 .95865 L
.2713 1.03321 L
.30191 1.10512 L
.33447 1.18157 L
.36584 1.25522 L
.39601 1.32606 L
.42812 1.40145 L
.45903 1.47402 L
.48875 1.5438 L
.52039 1.61811 L
.55085 1.68962 L
.58324 1.76566 L
.61239 1.83412 L
Mfstroke
.16025 .04762 m
.16025 .05002 L
.16025 .0522 L
.16025 .05472 L
.16025 .05711 L
.16025 .06135 L
.16025 .06595 L
.16025 .07638 L
.16025 .08602 L
.16025 .10692 L
.16025 .11715 L
.16025 .12162 L
.16025 .12651 L
.16025 .12905 L
.16025 .13141 L
.16025 .13367 L
.16025 .13608 L
.16025 .13886 L
.16025 .14148 L
.16025 .14638 L
.16025 .16827 L
.16025 .18979 L
.16025 .21254 L
.16025 .22197 L
.16025 .23208 L
.16025 .23789 L
.16025 .24318 L
.16025 .24856 L
.16025 .25353 L
.16025 .26281 L
.16025 .26771 L
.16025 .2729 L
.16025 .28163 L
.16025 .29125 L
.16025 .29605 L
.16025 .30129 L
.16025 .30677 L
.16025 .31186 L
.16025 .32099 L
.16025 .32611 L
.16025 .33075 L
.16025 .34126 L
.16025 .34719 L
.16025 .35266 L
.16025 .3627 L
.16025 .36776 L
.16025 .37333 L
.16025 .37842 L
.16025 .38396 L
.16025 .38885 L
Mistroke
.16026 .39406 L
.16026 .40388 L
.16026 .41299 L
.16026 .41852 L
.16027 .42449 L
.16028 .43531 L
.16029 .44582 L
.16031 .45546 L
.16033 .46501 L
.16036 .4752 L
.16039 .48479 L
.16044 .49349 L
.1605 .50366 L
.16059 .51465 L
.16071 .52495 L
.16083 .53441 L
.16098 .54344 L
.16118 .55308 L
.16164 .57028 L
.16238 .59029 L
.16329 .60818 L
.16443 .62562 L
.16573 .64147 L
.16961 .67641 L
.17486 .71003 L
.18102 .74022 L
.1996 .806 L
.2249 .87188 L
.25776 .94446 L
.29168 1.01539 L
.3247 1.08381 L
.35991 1.15668 L
.39379 1.22682 L
.42982 1.30138 L
.46452 1.3732 L
.4979 1.4423 L
.53342 1.51581 L
.56762 1.58659 L
.6005 1.65464 L
.63551 1.72711 L
.6692 1.79685 L
.67158 1.80178 L
Mfstroke
.17502 .04762 m
.17502 .05002 L
.17502 .0522 L
.17502 .05472 L
.17502 .05711 L
.17502 .06135 L
.17502 .06595 L
.17502 .07638 L
.17502 .08602 L
.17502 .10692 L
.17502 .11715 L
.17502 .12162 L
.17502 .12651 L
.17502 .12905 L
.17502 .13141 L
.17502 .13367 L
.17502 .13608 L
.17502 .13886 L
.17502 .14148 L
.17502 .14638 L
.17502 .16827 L
.17502 .18979 L
.17502 .21254 L
.17502 .22197 L
.17502 .23208 L
.17502 .24318 L
.17502 .24814 L
.17502 .25353 L
.17502 .2588 L
.17502 .26367 L
.17502 .26823 L
.17502 .27326 L
.17502 .27776 L
.17502 .28199 L
.17502 .29125 L
.17502 .29622 L
.17502 .30084 L
.17502 .30591 L
.17502 .31133 L
.17502 .31702 L
.17502 .3224 L
.17502 .32723 L
.17502 .33246 L
.17502 .34201 L
.17502 .34682 L
.17502 .35211 L
.17502 .35663 L
.17502 .36148 L
.17502 .37023 L
.17502 .37543 L
Mistroke
.17502 .38096 L
.17503 .3909 L
.17503 .39699 L
.17503 .40272 L
.17503 .40792 L
.17503 .41341 L
.17504 .42366 L
.17505 .43307 L
.17506 .44319 L
.17508 .45426 L
.17511 .46489 L
.17514 .47492 L
.17517 .48389 L
.17523 .4936 L
.1753 .5041 L
.1754 .51518 L
.17551 .52456 L
.17567 .53482 L
.17584 .54433 L
.17606 .55423 L
.17657 .57164 L
.17732 .58994 L
.17838 .60939 L
.17967 .62728 L
.1811 .64312 L
.18525 .67754 L
.19034 .70818 L
.19746 .74094 L
.2174 .80625 L
.24502 .87181 L
.27781 .93704 L
.31562 1.00754 L
.35265 1.07565 L
.39208 1.1481 L
.43008 1.21789 L
.46663 1.28503 L
.50552 1.35646 L
.54296 1.42524 L
.57895 1.49136 L
.61729 1.56178 L
.65418 1.62955 L
.69341 1.70161 L
.72873 1.76648 L
Mfstroke
.18979 .04762 m
.18979 .05002 L
.18979 .0522 L
.18979 .05472 L
.18979 .05711 L
.18979 .06135 L
.18979 .06595 L
.18979 .07638 L
.18979 .08602 L
.18979 .10692 L
.18979 .11715 L
.18979 .12162 L
.18979 .12651 L
.18979 .12905 L
.18979 .13141 L
.18979 .13367 L
.18979 .13608 L
.18979 .13886 L
.18979 .14148 L
.18979 .14638 L
.18979 .16827 L
.18979 .18979 L
.18979 .21254 L
.18979 .22197 L
.18979 .23208 L
.18979 .23789 L
.18979 .24318 L
.18979 .24856 L
.18979 .25353 L
.18979 .25803 L
.18979 .26281 L
.18979 .26802 L
.18979 .2729 L
.18979 .2771 L
.18979 .28163 L
.18979 .29125 L
.18979 .29615 L
.18979 .30138 L
.18979 .30631 L
.18979 .31079 L
.18979 .31607 L
.18979 .32179 L
.18979 .32719 L
.18979 .33217 L
.18979 .34213 L
.18979 .34779 L
.18979 .35309 L
.18979 .36377 L
.1898 .36976 L
.1898 .37523 L
Mistroke
.1898 .38499 L
.1898 .39044 L
.1898 .39537 L
.1898 .40498 L
.18981 .41401 L
.18982 .42459 L
.18982 .43429 L
.18984 .44492 L
.18986 .45611 L
.18989 .46615 L
.18992 .47527 L
.18997 .48574 L
.19003 .4956 L
.1901 .50466 L
.19018 .51298 L
.19043 .53159 L
.1906 .54052 L
.19081 .55004 L
.1913 .56695 L
.19209 .58655 L
.19305 .60396 L
.19424 .62085 L
.19558 .63613 L
.19951 .66956 L
.20475 .70144 L
.21083 .72986 L
.22923 .79134 L
.25531 .85274 L
.29156 .92057 L
.33094 .98714 L
.36996 1.0515 L
.41168 1.12009 L
.45186 1.1861 L
.49457 1.25629 L
.53572 1.32389 L
.5753 1.38893 L
.61741 1.45813 L
.65796 1.52475 L
.69694 1.5888 L
.73846 1.65702 L
.77841 1.72266 L
.78242 1.72927 L
Mfstroke
.20456 .04762 m
.20456 .05002 L
.20456 .0522 L
.20456 .05472 L
.20456 .05711 L
.20456 .06135 L
.20456 .06595 L
.20456 .07638 L
.20456 .08602 L
.20456 .10692 L
.20456 .11715 L
.20456 .12162 L
.20456 .12651 L
.20456 .12905 L
.20456 .13141 L
.20456 .13367 L
.20456 .13608 L
.20456 .13886 L
.20456 .14148 L
.20456 .14638 L
.20456 .16827 L
.20456 .18979 L
.20456 .21254 L
.20456 .22197 L
.20456 .23208 L
.20456 .23789 L
.20456 .24318 L
.20456 .24856 L
.20456 .25353 L
.20456 .25803 L
.20456 .26281 L
.20456 .26802 L
.20456 .2729 L
.20456 .2771 L
.20456 .28163 L
.20456 .29125 L
.20456 .29615 L
.20456 .30138 L
.20456 .30631 L
.20456 .31079 L
.20456 .31607 L
.20456 .32179 L
.20456 .32715 L
.20456 .33217 L
.20457 .33735 L
.20457 .34305 L
.20457 .34861 L
.20457 .35458 L
.20457 .36011 L
.20457 .36537 L
Mistroke
.20457 .37523 L
.20457 .38053 L
.20457 .38552 L
.20457 .39483 L
.20457 .40006 L
.20458 .40486 L
.20458 .41568 L
.20459 .42436 L
.2046 .43387 L
.20461 .44379 L
.20463 .45301 L
.20466 .46314 L
.2047 .47411 L
.20475 .48442 L
.20481 .49389 L
.20487 .50236 L
.20497 .51164 L
.20523 .53018 L
.20541 .5396 L
.20564 .54938 L
.20616 .56652 L
.20692 .58446 L
.208 .60343 L
.20928 .62078 L
.21069 .63606 L
.21474 .669 L
.21964 .69805 L
.22642 .72887 L
.23443 .75771 L
.24543 .78978 L
.27283 .85073 L
.31017 .91548 L
.3513 .9789 L
.39673 1.04668 L
.44076 1.11204 L
.48313 1.17492 L
.52822 1.24182 L
.57163 1.30624 L
.61337 1.36816 L
.65782 1.43412 L
.70059 1.49758 L
.74608 1.56507 L
.78989 1.63008 L
.83133 1.69156 L
Mfstroke
.21934 .04762 m
.21934 .05002 L
.21934 .0522 L
.21934 .05472 L
.21934 .05711 L
.21934 .06135 L
.21934 .06595 L
.21934 .07638 L
.21934 .08602 L
.21934 .10692 L
.21934 .11715 L
.21934 .12162 L
.21934 .12651 L
.21934 .12905 L
.21934 .13141 L
.21934 .13367 L
.21934 .13608 L
.21934 .13886 L
.21934 .14148 L
.21934 .14638 L
.21934 .16827 L
.21934 .18979 L
.21934 .21254 L
.21934 .22197 L
.21934 .23208 L
.21934 .23789 L
.21934 .24318 L
.21934 .24856 L
.21934 .25353 L
.21934 .25803 L
.21934 .26281 L
.21934 .26802 L
.21934 .2729 L
.21934 .2771 L
.21934 .28163 L
.21934 .28665 L
.21934 .29125 L
.21934 .29623 L
.21934 .30093 L
.21934 .30635 L
.21934 .31127 L
.21934 .3202 L
.21934 .32524 L
.21934 .32989 L
.21934 .33966 L
.21934 .34522 L
.21934 .35041 L
.21934 .36089 L
.21934 .36677 L
.21934 .37214 L
Mistroke
.21934 .38189 L
.21934 .38734 L
.21934 .39227 L
.21935 .40188 L
.21935 .41091 L
.21936 .42147 L
.21937 .43117 L
.21938 .44179 L
.21941 .45297 L
.21943 .46299 L
.21947 .47208 L
.21952 .48252 L
.21958 .49234 L
.21966 .50136 L
.21974 .50962 L
.22 .52807 L
.22017 .53691 L
.22039 .5463 L
.2209 .56294 L
.2217 .58212 L
.22266 .59908 L
.22385 .61544 L
.22517 .63017 L
.22897 .66217 L
.23395 .6924 L
.23966 .71916 L
.24765 .74893 L
.25682 .77658 L
.28173 .83375 L
.3171 .89465 L
.35801 .95437 L
.40453 1.01836 L
.44997 1.08005 L
.49835 1.14564 L
.54497 1.20884 L
.58981 1.26962 L
.63752 1.3343 L
.68346 1.39657 L
.72762 1.45644 L
.77465 1.5202 L
.81991 1.58155 L
.86804 1.6468 L
.87421 1.65516 L
Mfstroke
.23411 .04762 m
.23411 .05002 L
.23411 .0522 L
.23411 .05472 L
.23411 .05711 L
.23411 .06135 L
.23411 .06595 L
.23411 .07638 L
.23411 .08602 L
.23411 .10692 L
.23411 .11715 L
.23411 .12162 L
.23411 .12651 L
.23411 .12905 L
.23411 .13141 L
.23411 .13367 L
.23411 .13608 L
.23411 .13886 L
.23411 .14148 L
.23411 .14638 L
.23411 .16827 L
.23411 .18979 L
.23411 .21254 L
.23411 .22197 L
.23411 .23208 L
.23411 .23789 L
.23411 .24318 L
.23411 .24856 L
.23411 .25353 L
.23411 .25803 L
.23411 .26281 L
.23411 .26802 L
.23411 .2729 L
.23411 .27745 L
.23411 .28163 L
.23411 .28626 L
.23411 .29125 L
.23411 .30093 L
.23411 .30635 L
.23411 .31127 L
.23411 .31586 L
.23411 .32085 L
.23411 .32989 L
.23411 .33497 L
.23411 .34057 L
.23411 .34641 L
.23411 .35187 L
.23411 .36164 L
.23411 .36712 L
.23411 .37213 L
Mistroke
.23411 .38189 L
.23411 .38733 L
.23412 .39226 L
.23412 .40187 L
.23412 .4109 L
.23413 .42146 L
.23414 .43115 L
.23416 .44176 L
.23418 .45292 L
.23421 .46293 L
.23425 .472 L
.2343 .48242 L
.23437 .49221 L
.23444 .50119 L
.23453 .50942 L
.23481 .52776 L
.23498 .53652 L
.23521 .54583 L
.23572 .5623 L
.23654 .58123 L
.23751 .59792 L
.24 .62841 L
.2418 .64484 L
.24374 .65966 L
.24856 .68908 L
.25406 .71504 L
.26171 .74388 L
.27048 .77063 L
.29444 .82595 L
.32931 .88502 L
.37089 .94295 L
.41913 1.00496 L
.46657 1.06474 L
.51715 1.1283 L
.56589 1.18954 L
.61277 1.24844 L
.66266 1.31111 L
.71068 1.37146 L
.75686 1.42947 L
.80604 1.49125 L
.85336 1.5507 L
.90368 1.61393 L
.91013 1.62203 L
Mfstroke
.24888 .04762 m
.24888 .05002 L
.24888 .0522 L
.24888 .05472 L
.24888 .05711 L
.24888 .06135 L
.24888 .06595 L
.24888 .07638 L
.24888 .08602 L
.24888 .10692 L
.24888 .11715 L
.24888 .12162 L
.24888 .12651 L
.24888 .12905 L
.24888 .13141 L
.24888 .13367 L
.24888 .13608 L
.24888 .13886 L
.24888 .14148 L
.24888 .14638 L
.24888 .16827 L
.24888 .18979 L
.24888 .21254 L
.24888 .22197 L
.24888 .23208 L
.24888 .23789 L
.24888 .24318 L
.24888 .24856 L
.24888 .25353 L
.24888 .25803 L
.24888 .26281 L
.24888 .2729 L
.24888 .2771 L
.24888 .28163 L
.24888 .28659 L
.24888 .29125 L
.24888 .29615 L
.24888 .30138 L
.24888 .31079 L
.24888 .31655 L
.24888 .32199 L
.24888 .33217 L
.24888 .33739 L
.24888 .34292 L
.24888 .35283 L
.24888 .35834 L
.24888 .3635 L
.24888 .36958 L
.24888 .37522 L
.24889 .38538 L
Mistroke
.24889 .39073 L
.24889 .39644 L
.24889 .40188 L
.24889 .40699 L
.2489 .41654 L
.24891 .42596 L
.24892 .43461 L
.24894 .44408 L
.24896 .45404 L
.24899 .46403 L
.24903 .47308 L
.24909 .48346 L
.24916 .49321 L
.24934 .51032 L
.24947 .51983 L
.24962 .52852 L
.25004 .54641 L
.25057 .56266 L
.25134 .57988 L
.25239 .59769 L
.25354 .61306 L
.25504 .62923 L
.25883 .66016 L
.26337 .68753 L
.26943 .71589 L
.27662 .74265 L
.28636 .7719 L
.31152 .82806 L
.34876 .88815 L
.39356 .94703 L
.4404 1.00382 L
.4913 1.06433 L
.54044 1.12257 L
.59271 1.18449 L
.64305 1.24414 L
.69148 1.30151 L
.74301 1.36256 L
.79262 1.42135 L
.84032 1.47786 L
.89112 1.53804 L
.93844 1.5941 L
Mfstroke
.26365 .04762 m
.26365 .05002 L
.26365 .0522 L
.26365 .05472 L
.26365 .05711 L
.26365 .06135 L
.26365 .06595 L
.26365 .07638 L
.26365 .08602 L
.26365 .10692 L
.26365 .11715 L
.26365 .12162 L
.26365 .12651 L
.26365 .12905 L
.26365 .13141 L
.26365 .13367 L
.26365 .13608 L
.26365 .13886 L
.26365 .14148 L
.26365 .14638 L
.26365 .16827 L
.26365 .18979 L
.26365 .21254 L
.26365 .22197 L
.26365 .23208 L
.26365 .23789 L
.26365 .24318 L
.26365 .24856 L
.26365 .25353 L
.26365 .25803 L
.26365 .26281 L
.26365 .2729 L
.26365 .2771 L
.26365 .28162 L
.26365 .28659 L
.26365 .29125 L
.26365 .29615 L
.26365 .30137 L
.26365 .31079 L
.26365 .31655 L
.26365 .32199 L
.26365 .33217 L
.26365 .33739 L
.26365 .34292 L
.26365 .35283 L
.26365 .35834 L
.26365 .36349 L
.26366 .36958 L
.26366 .37522 L
.26366 .38537 L
Mistroke
.26366 .39073 L
.26366 .39643 L
.26366 .40187 L
.26367 .40698 L
.26367 .41652 L
.26368 .42594 L
.26369 .43459 L
.26371 .44405 L
.26374 .45399 L
.26377 .46396 L
.26381 .47299 L
.26387 .48334 L
.26394 .49306 L
.26412 .51009 L
.26426 .51955 L
.26441 .52817 L
.26484 .5459 L
.26537 .56198 L
.26613 .57897 L
.26717 .59649 L
.26975 .62742 L
.27137 .64212 L
.2734 .65765 L
.27813 .6865 L
.28346 .71188 L
.29819 .76297 L
.30803 .78871 L
.32124 .81738 L
.35634 .87607 L
.40031 .93391 L
.44752 .9897 L
.49934 1.04911 L
.54949 1.10631 L
.60283 1.16711 L
.65421 1.22568 L
.70364 1.28203 L
.75623 1.34198 L
.80686 1.3997 L
.85554 1.45519 L
.90739 1.51429 L
.95728 1.57116 L
.95885 1.57295 L
Mfstroke
.27842 .04762 m
.27842 .05002 L
.27842 .0522 L
.27842 .05472 L
.27842 .05711 L
.27842 .06135 L
.27842 .06595 L
.27842 .07638 L
.27842 .08602 L
.27842 .10692 L
.27842 .11715 L
.27842 .12162 L
.27842 .12651 L
.27842 .12905 L
.27842 .13141 L
.27842 .13367 L
.27842 .13608 L
.27842 .13886 L
.27842 .14148 L
.27842 .14638 L
.27842 .16827 L
.27842 .18979 L
.27842 .21254 L
.27842 .22197 L
.27842 .23208 L
.27842 .23789 L
.27842 .24318 L
.27842 .24856 L
.27842 .25353 L
.27842 .25803 L
.27842 .26281 L
.27842 .2729 L
.27842 .2771 L
.27842 .28162 L
.27842 .28659 L
.27842 .29125 L
.27842 .29615 L
.27842 .30137 L
.27842 .31079 L
.27842 .31655 L
.27842 .32199 L
.27842 .33217 L
.27842 .33739 L
.27842 .34292 L
.27843 .35283 L
.27843 .35834 L
.27843 .36349 L
.27843 .36958 L
.27843 .37522 L
.27843 .38537 L
Mistroke
.27843 .39072 L
.27843 .39642 L
.27844 .40186 L
.27844 .40697 L
.27845 .41651 L
.27846 .42592 L
.27847 .43456 L
.27848 .44401 L
.27851 .45394 L
.27854 .46389 L
.27858 .4729 L
.27864 .48323 L
.27872 .4929 L
.2789 .50986 L
.27904 .51926 L
.2792 .52782 L
.27962 .5454 L
.28015 .5613 L
.2809 .57806 L
.28191 .59531 L
.28441 .62566 L
.28596 .64004 L
.28789 .65521 L
.29236 .68335 L
.29735 .70805 L
.31105 .7577 L
.32019 .78273 L
.3325 .81069 L
.36577 .86835 L
.40872 .92563 L
.45583 .98098 L
.50798 1.03992 L
.55853 1.09666 L
.61232 1.15699 L
.66414 1.2151 L
.71399 1.271 L
.76702 1.33047 L
.81809 1.38774 L
.86718 1.44279 L
.91946 1.50143 L
.96978 1.55785 L
.97136 1.55962 L
Mfstroke
.2932 .04762 m
.2932 .05002 L
.2932 .0522 L
.2932 .05472 L
.2932 .05711 L
.2932 .06135 L
.2932 .06595 L
.2932 .07638 L
.2932 .08602 L
.2932 .10692 L
.2932 .11715 L
.2932 .12162 L
.2932 .12651 L
.2932 .12905 L
.2932 .13141 L
.2932 .13367 L
.2932 .13608 L
.2932 .13886 L
.2932 .14148 L
.2932 .14638 L
.2932 .16827 L
.2932 .18979 L
.2932 .21254 L
.2932 .22197 L
.2932 .23208 L
.2932 .23789 L
.2932 .24318 L
.2932 .24856 L
.2932 .25353 L
.2932 .25803 L
.2932 .26281 L
.2932 .2729 L
.2932 .2771 L
.2932 .28162 L
.2932 .28659 L
.2932 .29125 L
.2932 .29615 L
.2932 .30137 L
.2932 .30589 L
.2932 .31079 L
.2932 .31655 L
.2932 .32199 L
.2932 .33217 L
.2932 .33735 L
.2932 .34305 L
.2932 .349 L
.2932 .35457 L
.2932 .36452 L
.2932 .37011 L
.2932 .37521 L
Mistroke
.2932 .38496 L
.2932 .3904 L
.29321 .39532 L
.29321 .40491 L
.29322 .41393 L
.29323 .42446 L
.29324 .43411 L
.29326 .44468 L
.29329 .45577 L
.29332 .46569 L
.29337 .47466 L
.29343 .48494 L
.29351 .49456 L
.2937 .51139 L
.29385 .52071 L
.29401 .52918 L
.29444 .54654 L
.29497 .56221 L
.29572 .57868 L
.29672 .59559 L
.29914 .62527 L
.30247 .65411 L
.30637 .67961 L
.31074 .70254 L
.32319 .75085 L
.33251 .77796 L
.34355 .80444 L
.37248 .85778 L
.41505 .91706 L
.46331 .97474 L
.51201 1.03028 L
.56433 1.08943 L
.61475 1.14636 L
.66836 1.20688 L
.72 1.26518 L
.76967 1.32127 L
.82252 1.38094 L
.87341 1.43839 L
.92233 1.49363 L
.97444 1.55246 L
.97619 1.55443 L
Mfstroke
.30797 .04762 m
.30797 .05002 L
.30797 .0522 L
.30797 .05472 L
.30797 .05711 L
.30797 .06135 L
.30797 .06595 L
.30797 .07638 L
.30797 .08602 L
.30797 .10692 L
.30797 .11715 L
.30797 .12162 L
.30797 .12651 L
.30797 .12905 L
.30797 .13141 L
.30797 .13367 L
.30797 .13608 L
.30797 .13886 L
.30797 .14148 L
.30797 .14638 L
.30797 .16827 L
.30797 .18979 L
.30797 .21254 L
.30797 .22197 L
.30797 .23208 L
.30797 .23789 L
.30797 .24318 L
.30797 .24856 L
.30797 .25353 L
.30797 .25803 L
.30797 .26281 L
.30797 .2729 L
.30797 .2771 L
.30797 .28162 L
.30797 .28659 L
.30797 .29125 L
.30797 .29615 L
.30797 .30137 L
.30797 .30589 L
.30797 .31079 L
.30797 .31655 L
.30797 .32199 L
.30797 .33216 L
.30797 .33735 L
.30797 .34305 L
.30797 .349 L
.30797 .35457 L
.30797 .36452 L
.30797 .37011 L
.30797 .37521 L
Mistroke
.30797 .38495 L
.30798 .39039 L
.30798 .39532 L
.30798 .4049 L
.30799 .41391 L
.308 .42444 L
.30801 .43409 L
.30803 .44464 L
.30806 .45571 L
.3081 .46561 L
.30814 .47457 L
.3082 .48481 L
.30828 .4944 L
.30847 .51115 L
.30861 .5204 L
.30877 .52882 L
.30919 .54602 L
.30972 .56152 L
.31044 .57777 L
.31139 .59443 L
.31369 .62359 L
.31681 .65184 L
.32043 .67678 L
.32447 .69916 L
.33588 .74626 L
.34438 .77272 L
.35447 .79863 L
.38124 .85133 L
.42176 .91078 L
.46878 .96913 L
.51663 1.02543 L
.56815 1.08541 L
.61779 1.14315 L
.67058 1.20453 L
.72143 1.26366 L
.77035 1.32054 L
.82239 1.38106 L
.87251 1.43933 L
.92068 1.49535 L
.97199 1.55501 L
.97372 1.55702 L
Mfstroke
.32274 .04762 m
.32274 .05002 L
.32274 .0522 L
.32274 .05472 L
.32274 .05711 L
.32274 .06135 L
.32274 .06595 L
.32274 .07638 L
.32274 .08602 L
.32274 .10692 L
.32274 .11715 L
.32274 .12162 L
.32274 .12651 L
.32274 .12905 L
.32274 .13141 L
.32274 .13367 L
.32274 .13608 L
.32274 .13886 L
.32274 .14148 L
.32274 .14638 L
.32274 .15689 L
.32274 .16827 L
.32274 .18937 L
.32274 .19511 L
.32274 .20055 L
.32274 .20682 L
.32274 .20959 L
.32274 .21254 L
.32274 .21503 L
.32274 .21778 L
.32274 .22262 L
.32274 .2279 L
.32274 .23067 L
.32274 .23359 L
.32274 .23888 L
.32274 .24373 L
.32274 .25325 L
.32274 .25839 L
.32274 .26389 L
.32274 .26908 L
.32274 .27379 L
.32274 .27934 L
.32274 .28535 L
.32274 .29102 L
.32274 .29626 L
.32274 .3058 L
.32274 .31116 L
.32274 .31605 L
.32274 .32059 L
.32274 .32555 L
Mistroke
.32274 .33456 L
.32274 .34012 L
.32274 .34515 L
.32274 .35057 L
.32274 .35642 L
.32274 .36186 L
.32274 .36685 L
.32274 .37199 L
.32274 .37667 L
.32275 .38627 L
.32275 .39155 L
.32275 .39654 L
.32275 .40541 L
.32276 .41502 L
.32277 .42005 L
.32277 .42558 L
.32279 .43674 L
.32281 .44704 L
.32283 .45664 L
.32287 .466 L
.32292 .47614 L
.32299 .48661 L
.32307 .49623 L
.32327 .51315 L
.32341 .5224 L
.32357 .53063 L
.32402 .54821 L
.32455 .5637 L
.32528 .57991 L
.32621 .59618 L
.32837 .62397 L
.33089 .64801 L
.33429 .67317 L
.338 .69528 L
.34296 .71955 L
.34854 .74213 L
.36378 .78922 L
.38799 .84197 L
.42199 .8968 L
.46728 .95721 L
.51445 1.01586 L
.56542 1.07834 L
.61461 1.13852 L
.66192 1.19641 L
.71228 1.25802 L
.76076 1.31733 L
.81228 1.38036 L
.86192 1.44109 L
.90967 1.49952 L
.96048 1.56168 L
Mistroke
.96437 1.56644 L
Mfstroke
.33751 .04762 m
.33751 .05002 L
.33751 .0522 L
.33751 .05472 L
.33751 .05711 L
.33751 .06135 L
.33751 .06595 L
.33751 .07638 L
.33751 .08602 L
.33751 .10692 L
.33751 .11715 L
.33751 .12162 L
.33751 .12651 L
.33751 .12905 L
.33751 .13141 L
.33751 .13367 L
.33751 .13608 L
.33751 .13886 L
.33751 .14148 L
.33751 .14638 L
.33751 .15689 L
.33751 .16827 L
.33751 .18937 L
.33751 .19212 L
.33751 .19511 L
.33751 .19794 L
.33751 .20055 L
.33751 .20682 L
.33751 .20977 L
.33751 .21121 L
.33751 .21254 L
.33751 .21487 L
.33751 .21739 L
.33751 .22275 L
.33751 .22793 L
.33751 .23067 L
.33751 .23359 L
.33751 .23855 L
.33751 .24317 L
.33751 .25325 L
.33751 .25881 L
.33751 .26484 L
.33751 .27053 L
.33751 .27578 L
.33751 .28573 L
.33751 .29074 L
.33751 .29626 L
.33751 .30135 L
.33751 .3069 L
.33751 .3118 L
Mistroke
.33751 .31701 L
.33751 .32217 L
.33751 .32684 L
.33751 .33596 L
.33751 .34146 L
.33751 .34652 L
.33751 .35207 L
.33751 .35792 L
.33751 .36778 L
.33751 .37336 L
.33752 .37857 L
.33752 .3888 L
.33752 .39457 L
.33752 .3999 L
.33753 .40966 L
.33753 .41458 L
.33754 .42 L
.33755 .42933 L
.33756 .43933 L
.33758 .44873 L
.33761 .4573 L
.33764 .46672 L
.33769 .47668 L
.33775 .48599 L
.33782 .49434 L
.33791 .50405 L
.33804 .51438 L
.3382 .52387 L
.33837 .53257 L
.33878 .54902 L
.33937 .56623 L
.34009 .58214 L
.34101 .59832 L
.34326 .6275 L
.34594 .65299 L
.35264 .69818 L
.35711 .72085 L
.36292 .7452 L
.37727 .7912 L
.40126 .84552 L
.43543 .90283 L
.48065 .96639 L
.52731 1.02829 L
.5727 1.08793 L
.62107 1.15142 L
.66763 1.21254 L
.71713 1.27751 L
.76481 1.34009 L
.81069 1.40031 L
.85949 1.46436 L
Mistroke
.90649 1.52604 L
.94864 1.58137 L
Mfstroke
.35228 .04762 m
.35228 .05002 L
.35228 .0522 L
.35228 .05472 L
.35228 .05711 L
.35228 .06135 L
.35228 .06595 L
.35228 .07638 L
.35228 .08602 L
.35228 .10692 L
.35228 .11715 L
.35228 .12162 L
.35228 .12651 L
.35228 .12905 L
.35228 .13141 L
.35228 .13367 L
.35228 .13608 L
.35228 .13886 L
.35228 .14148 L
.35228 .14638 L
.35228 .15689 L
.35228 .16827 L
.35228 .18937 L
.35228 .19234 L
.35228 .19515 L
.35228 .1984 L
.35228 .20135 L
.35228 .20678 L
.35228 .20975 L
.35228 .2112 L
.35228 .21254 L
.35228 .21486 L
.35228 .21735 L
.35228 .22267 L
.35228 .22752 L
.35228 .23204 L
.35228 .23697 L
.35228 .23958 L
.35228 .24237 L
.35228 .25325 L
.35228 .25881 L
.35228 .26484 L
.35228 .27053 L
.35228 .27578 L
.35228 .28573 L
.35228 .29074 L
.35228 .29626 L
.35228 .30135 L
.35228 .3069 L
.35228 .3118 L
Mistroke
.35228 .31701 L
.35228 .32217 L
.35228 .32684 L
.35228 .33596 L
.35228 .34146 L
.35228 .34652 L
.35228 .35196 L
.35228 .35792 L
.35229 .36797 L
.35229 .37346 L
.35229 .37857 L
.35229 .38879 L
.35229 .39456 L
.35229 .39989 L
.3523 .40965 L
.3523 .41457 L
.35231 .41999 L
.35232 .42931 L
.35233 .4393 L
.35235 .44869 L
.35238 .45724 L
.35241 .46665 L
.35245 .47659 L
.35251 .48587 L
.35258 .49419 L
.35267 .50385 L
.35279 .51413 L
.3531 .5322 L
.35349 .54851 L
.35404 .56555 L
.35476 .58237 L
.35556 .59723 L
.35753 .62483 L
.35975 .64808 L
.36269 .67251 L
.36594 .69433 L
.37439 .73758 L
.38731 .78431 L
.40677 .83441 L
.43838 .8942 L
.47778 .95547 L
.52348 1.02187 L
.5682 1.08604 L
.61126 1.14777 L
.65711 1.21349 L
.70125 1.27674 L
.74815 1.34398 L
.79335 1.40875 L
.83683 1.47107 L
.88308 1.53736 L
Mistroke
.92702 1.60034 L
Mfstroke
.36705 .04762 m
.36705 .05002 L
.36705 .0522 L
.36705 .05472 L
.36705 .05711 L
.36705 .06135 L
.36705 .06595 L
.36705 .07638 L
.36705 .08602 L
.36705 .10692 L
.36705 .11715 L
.36705 .12162 L
.36705 .12651 L
.36705 .12905 L
.36705 .13141 L
.36705 .13367 L
.36705 .13608 L
.36705 .13886 L
.36705 .14148 L
.36705 .14638 L
.36705 .15689 L
.36705 .16827 L
.36705 .18937 L
.36705 .19515 L
.36705 .1984 L
.36705 .20135 L
.36705 .20716 L
.36705 .20972 L
.36705 .21117 L
.36705 .21254 L
.36705 .21739 L
.36705 .22255 L
.36705 .22823 L
.36705 .23072 L
.36705 .23344 L
.36705 .23809 L
.36705 .24298 L
.36705 .2483 L
.36705 .25325 L
.36705 .26414 L
.36705 .2693 L
.36705 .27404 L
.36705 .27953 L
.36705 .28547 L
.36705 .29071 L
.36705 .29626 L
.36705 .30142 L
.36705 .30633 L
.36705 .31552 L
.36705 .32066 L
Mistroke
.36705 .32542 L
.36705 .33065 L
.36705 .33622 L
.36705 .34107 L
.36706 .34632 L
.36706 .35095 L
.36706 .35582 L
.36706 .36024 L
.36706 .36507 L
.36706 .37357 L
.36706 .3787 L
.36706 .38427 L
.36706 .38919 L
.36706 .39439 L
.36707 .40423 L
.36707 .4133 L
.36708 .42369 L
.36709 .4334 L
.36711 .444 L
.36714 .45533 L
.36717 .46516 L
.36721 .47422 L
.36726 .48404 L
.36733 .49438 L
.36743 .50508 L
.36755 .51496 L
.36784 .53286 L
.36822 .54942 L
.36873 .56604 L
.36926 .57951 L
.36994 .59358 L
.37161 .61995 L
.37382 .64591 L
.37653 .67058 L
.37959 .6931 L
.38715 .73559 L
.39925 .78354 L
.41795 .83585 L
.44558 .89306 L
.48385 .95873 L
.52403 1.02343 L
.56739 1.09252 L
.60921 1.15908 L
.64943 1.22309 L
.69223 1.29123 L
.73344 1.35681 L
.77724 1.42652 L
.81944 1.49369 L
.86003 1.5583 L
.89998 1.62189 L
Mistroke
Mfstroke
.38183 .04762 m
.38183 .05002 L
.38183 .0522 L
.38183 .05472 L
.38183 .05711 L
.38183 .06135 L
.38183 .06595 L
.38183 .07638 L
.38183 .08602 L
.38183 .10692 L
.38183 .11715 L
.38183 .12162 L
.38183 .12651 L
.38183 .12905 L
.38183 .13141 L
.38183 .13367 L
.38183 .13608 L
.38183 .13886 L
.38183 .14148 L
.38183 .14638 L
.38183 .15689 L
.38183 .16827 L
.38183 .17845 L
.38183 .18406 L
.38183 .18937 L
.38183 .19237 L
.38183 .19564 L
.38183 .20135 L
.38183 .20667 L
.38183 .20813 L
.38183 .2097 L
.38183 .21118 L
.38183 .21254 L
.38183 .22279 L
.38183 .22799 L
.38183 .23369 L
.38183 .23862 L
.38183 .24322 L
.38183 .25325 L
.38183 .25885 L
.38183 .26414 L
.38183 .26889 L
.38183 .27404 L
.38183 .27966 L
.38183 .2856 L
.38183 .29068 L
.38183 .29626 L
.38183 .30135 L
.38183 .3069 L
.38183 .31214 L
Mistroke
.38183 .317 L
.38183 .32618 L
.38183 .33131 L
.38183 .33596 L
.38183 .34652 L
.38183 .35246 L
.38183 .35792 L
.38183 .36797 L
.38183 .37302 L
.38183 .37856 L
.38183 .38369 L
.38183 .38926 L
.38183 .39417 L
.38184 .39937 L
.38184 .40919 L
.38185 .41825 L
.38186 .42862 L
.38187 .43829 L
.38189 .44885 L
.38192 .46013 L
.38195 .46991 L
.38199 .47889 L
.38205 .48863 L
.38212 .49886 L
.38222 .50942 L
.38234 .51916 L
.38263 .53674 L
.383 .55298 L
.38349 .56922 L
.38463 .59611 L
.38617 .62201 L
.38792 .64434 L
.39265 .68815 L
.39596 .71122 L
.39974 .73326 L
.40956 .77755 L
.42633 .83128 L
.45208 .89151 L
.48484 .95498 L
.52313 1.02461 L
.56056 1.09194 L
.60042 1.16359 L
.63881 1.23259 L
.67573 1.29895 L
.71503 1.36959 L
.75286 1.43758 L
.79307 1.50985 L
.83181 1.57947 L
.86805 1.64462 L
Mfstroke
.3966 .04762 m
.3966 .05002 L
.3966 .0522 L
.3966 .05472 L
.3966 .05711 L
.3966 .06135 L
.3966 .06595 L
.3966 .07638 L
.3966 .08602 L
.3966 .10692 L
.3966 .11715 L
.3966 .12162 L
.3966 .12651 L
.3966 .12905 L
.3966 .13141 L
.3966 .13367 L
.3966 .13608 L
.3966 .13886 L
.3966 .14148 L
.3966 .14638 L
.3966 .15689 L
.3966 .16827 L
.3966 .17948 L
.3966 .18561 L
.3966 .1886 L
.3966 .19132 L
.3966 .19621 L
.3966 .20144 L
.3966 .20671 L
.3966 .20816 L
.3966 .20972 L
.3966 .21119 L
.3966 .21254 L
.3966 .22235 L
.3966 .22733 L
.3966 .23278 L
.3966 .23751 L
.3966 .2419 L
.3966 .25151 L
.3966 .25703 L
.3966 .26224 L
.3966 .26693 L
.3966 .272 L
.3966 .27753 L
.3966 .28339 L
.3966 .28839 L
.3966 .29389 L
.3966 .29899 L
.3966 .30454 L
.3966 .30943 L
Mistroke
.3966 .31464 L
.3966 .3198 L
.3966 .32448 L
.3966 .33359 L
.3966 .3391 L
.3966 .34415 L
.3966 .34959 L
.3966 .35556 L
.3966 .3656 L
.3966 .37109 L
.3966 .3762 L
.3966 .38642 L
.3966 .39219 L
.39661 .39751 L
.39661 .40727 L
.39661 .41219 L
.39662 .4176 L
.39662 .42691 L
.39664 .4369 L
.39665 .44627 L
.39667 .4548 L
.39669 .46418 L
.39673 .47408 L
.39677 .48332 L
.39682 .49159 L
.39689 .50119 L
.39698 .51137 L
.39721 .52923 L
.39749 .54529 L
.3979 .562 L
.39842 .57842 L
.39899 .59289 L
.40038 .61961 L
.40191 .64201 L
.40392 .66546 L
.40611 .68631 L
.4117 .72748 L
.42011 .77197 L
.43289 .82062 L
.45488 .88181 L
.48434 .94819 L
.51948 1.02177 L
.55398 1.09314 L
.5872 1.16181 L
.62256 1.23491 L
.6566 1.30527 L
.69278 1.38005 L
.72764 1.45211 L
.76118 1.52142 L
.79686 1.59516 L
Mistroke
.83121 1.66617 L
.83176 1.6673 L
Mfstroke
.41137 .04762 m
.41137 .05002 L
.41137 .0522 L
.41137 .05472 L
.41137 .05711 L
.41137 .06135 L
.41137 .06595 L
.41137 .07638 L
.41137 .08602 L
.41137 .10692 L
.41137 .11715 L
.41137 .12162 L
.41137 .12651 L
.41137 .12905 L
.41137 .13141 L
.41137 .13367 L
.41137 .13608 L
.41137 .13886 L
.41137 .14148 L
.41137 .14638 L
.41137 .15689 L
.41137 .16827 L
.41137 .17948 L
.41137 .18561 L
.41137 .1886 L
.41137 .19132 L
.41137 .19621 L
.41137 .20144 L
.41137 .20398 L
.41137 .20671 L
.41137 .20828 L
.41137 .20972 L
.41137 .21254 L
.41137 .22235 L
.41137 .22733 L
.41137 .23278 L
.41137 .23751 L
.41137 .2419 L
.41137 .25151 L
.41137 .25703 L
.41137 .26224 L
.41137 .26693 L
.41137 .272 L
.41137 .27753 L
.41137 .28339 L
.41137 .28839 L
.41137 .29389 L
.41137 .29899 L
.41137 .30454 L
.41137 .30978 L
Mistroke
.41137 .31464 L
.41137 .32382 L
.41137 .32895 L
.41137 .33359 L
.41137 .34415 L
.41137 .3501 L
.41137 .35555 L
.41137 .3656 L
.41137 .37066 L
.41137 .3762 L
.41137 .38133 L
.41137 .3869 L
.41138 .3918 L
.41138 .39701 L
.41138 .40683 L
.41139 .41589 L
.41139 .42625 L
.4114 .43593 L
.41142 .44648 L
.41144 .45776 L
.41146 .46752 L
.41149 .4765 L
.41154 .48622 L
.41159 .49643 L
.41167 .50696 L
.41176 .51666 L
.41198 .53416 L
.41226 .55029 L
.41263 .56639 L
.41349 .59297 L
.41464 .61847 L
.41593 .64039 L
.4194 .68322 L
.4218 .70569 L
.42453 .72712 L
.43154 .77015 L
.44355 .82287 L
.46264 .8839 L
.48803 .95057 L
.51823 1.02476 L
.5478 1.09665 L
.57929 1.17315 L
.60961 1.24683 L
.63878 1.31768 L
.66983 1.3931 L
.69971 1.4657 L
.73147 1.54286 L
.76207 1.61721 L
.79151 1.68873 L
.79159 1.68892 L
Mistroke
Mfstroke
.42614 .04762 m
.42614 .05002 L
.42614 .0522 L
.42614 .05472 L
.42614 .05711 L
.42614 .06135 L
.42614 .06595 L
.42614 .07638 L
.42614 .08602 L
.42614 .10692 L
.42614 .11715 L
.42614 .12162 L
.42614 .12651 L
.42614 .12905 L
.42614 .13141 L
.42614 .13367 L
.42614 .13608 L
.42614 .13886 L
.42614 .14148 L
.42614 .14638 L
.42614 .16827 L
.42614 .17861 L
.42614 .18426 L
.42614 .18568 L
.42614 .18702 L
.42614 .18953 L
.42614 .19229 L
.42614 .19525 L
.42614 .20152 L
.42614 .20408 L
.42614 .20548 L
.42614 .2068 L
.42614 .20821 L
.42614 .20978 L
.42614 .21254 L
.42614 .22294 L
.42614 .22801 L
.42614 .23261 L
.42614 .23749 L
.42614 .24271 L
.42614 .25375 L
.42614 .25828 L
.42614 .26307 L
.42614 .26833 L
.42614 .27318 L
.42614 .27739 L
.42614 .28192 L
.42614 .28688 L
.42614 .29153 L
.42614 .29673 L
Mistroke
.42614 .30226 L
.42614 .30705 L
.42614 .31221 L
.42614 .31831 L
.42614 .32404 L
.42614 .32963 L
.42614 .33475 L
.42614 .34428 L
.42614 .34968 L
.42614 .35471 L
.42614 .36487 L
.42614 .37056 L
.42614 .37574 L
.42615 .38556 L
.42615 .39051 L
.42615 .39596 L
.42615 .40557 L
.42615 .41457 L
.42616 .42511 L
.42617 .43471 L
.42618 .4452 L
.4262 .45614 L
.42622 .46599 L
.42624 .47484 L
.42628 .48492 L
.42632 .49427 L
.42643 .5105 L
.4265 .51938 L
.42659 .52738 L
.4268 .54371 L
.42705 .55819 L
.42738 .57321 L
.42781 .58839 L
.42883 .61605 L
.43 .63993 L
.43284 .68168 L
.43467 .70239 L
.43699 .7245 L
.4426 .76633 L
.45213 .81761 L
.46738 .87752 L
.49064 .95154 L
.51597 1.02668 L
.54073 1.09947 L
.56713 1.17699 L
.59253 1.25162 L
.61954 1.33093 L
.64555 1.40734 L
.67058 1.48086 L
.69721 1.55907 L
Mistroke
.72285 1.63437 L
.7475 1.70678 L
.74811 1.70857 L
Mfstroke
.44091 .04762 m
.44091 .05002 L
.44091 .0522 L
.44091 .05472 L
.44091 .05711 L
.44091 .06135 L
.44091 .06595 L
.44091 .07638 L
.44091 .08602 L
.44091 .10692 L
.44091 .11715 L
.44091 .12162 L
.44091 .12651 L
.44091 .12905 L
.44091 .13141 L
.44091 .13367 L
.44091 .13608 L
.44091 .13886 L
.44091 .14148 L
.44091 .14638 L
.44091 .16827 L
.44091 .17861 L
.44091 .18134 L
.44091 .18426 L
.44091 .18702 L
.44091 .18953 L
.44091 .19525 L
.44091 .20152 L
.44091 .20423 L
.44091 .20566 L
.44091 .20718 L
.44091 .2085 L
.44091 .20996 L
.44091 .21254 L
.44091 .22258 L
.44091 .22805 L
.44091 .23315 L
.44091 .23751 L
.44091 .24217 L
.44091 .25204 L
.44091 .25755 L
.44091 .26352 L
.44091 .26916 L
.44091 .27435 L
.44091 .27944 L
.44091 .2842 L
.44091 .28916 L
.44091 .29462 L
.44091 .2999 L
.44091 .30479 L
Mistroke
.44091 .31016 L
.44091 .31587 L
.44091 .32132 L
.44091 .32645 L
.44091 .33112 L
.44091 .33604 L
.44091 .34056 L
.44091 .34551 L
.44091 .35421 L
.44091 .35912 L
.44091 .36437 L
.44092 .37383 L
.44092 .37907 L
.44092 .38462 L
.44092 .39458 L
.44092 .4001 L
.44092 .40527 L
.44092 .41101 L
.44092 .41703 L
.44093 .42723 L
.44094 .43652 L
.44095 .44647 L
.44096 .45725 L
.44098 .46764 L
.441 .47731 L
.44103 .48588 L
.44107 .49502 L
.44111 .50481 L
.44118 .51492 L
.44132 .53237 L
.44151 .54795 L
.44175 .56375 L
.44231 .58997 L
.44269 .60339 L
.44314 .61724 L
.4441 .6408 L
.44517 .66208 L
.44655 .68464 L
.44981 .72554 L
.45473 .77017 L
.46237 .82019 L
.47605 .88569 L
.4947 .95918 L
.51458 1.03323 L
.53602 1.11253 L
.55668 1.18889 L
.57863 1.27006 L
.59978 1.34826 L
.62014 1.42349 L
.64179 1.50353 L
Mistroke
.66263 1.58059 L
.68268 1.65469 L
.70184 1.72555 L
Mfstroke
.45568 .04762 m
.45568 .05002 L
.45568 .0522 L
.45568 .05472 L
.45568 .05711 L
.45568 .06135 L
.45568 .06595 L
.45568 .07638 L
.45568 .08602 L
.45568 .10692 L
.45568 .11715 L
.45568 .12162 L
.45568 .12651 L
.45568 .12905 L
.45568 .13141 L
.45568 .13367 L
.45568 .13608 L
.45568 .13886 L
.45568 .14148 L
.45568 .14638 L
.45568 .16827 L
.45568 .17861 L
.45568 .18134 L
.45568 .18426 L
.45568 .18702 L
.45568 .18953 L
.45568 .19525 L
.45568 .20152 L
.45568 .20423 L
.45568 .20566 L
.45568 .20718 L
.45568 .2085 L
.45568 .20996 L
.45568 .21254 L
.45568 .22258 L
.45568 .22805 L
.45568 .23315 L
.45568 .23751 L
.45568 .24217 L
.45568 .25204 L
.45568 .25755 L
.45568 .26352 L
.45568 .26916 L
.45568 .27435 L
.45568 .27944 L
.45568 .2842 L
.45568 .28916 L
.45568 .29462 L
.45568 .2999 L
.45568 .30479 L
Mistroke
.45568 .31016 L
.45568 .31587 L
.45568 .32132 L
.45568 .32645 L
.45568 .33112 L
.45568 .33604 L
.45569 .34056 L
.45569 .34551 L
.45569 .35421 L
.45569 .35912 L
.45569 .36437 L
.45569 .37383 L
.45569 .37907 L
.45569 .38462 L
.45569 .39458 L
.45569 .4001 L
.45569 .40527 L
.45569 .411 L
.45569 .41702 L
.4557 .42722 L
.4557 .43651 L
.45571 .44645 L
.45572 .45723 L
.45574 .4676 L
.45575 .47727 L
.45577 .48583 L
.4558 .49495 L
.45584 .50472 L
.45589 .51481 L
.456 .53221 L
.45614 .54774 L
.45632 .56348 L
.45674 .58958 L
.45737 .6167 L
.45808 .64013 L
.45979 .68116 L
.46227 .72333 L
.46578 .76645 L
.47115 .81449 L
.48076 .87764 L
.49423 .94967 L
.51046 1.03091 L
.52637 1.10981 L
.54168 1.18572 L
.55798 1.26651 L
.57366 1.34429 L
.59034 1.42696 L
.6064 1.5066 L
.62186 1.58322 L
.6383 1.66474 L
Mistroke
.65334 1.73932 L
Mfstroke
.47046 .04762 m
.47046 .05002 L
.47046 .0522 L
.47046 .05472 L
.47046 .05711 L
.47046 .06135 L
.47046 .06595 L
.47046 .07638 L
.47046 .08602 L
.47046 .10692 L
.47046 .11715 L
.47046 .12651 L
.47046 .12885 L
.47046 .13141 L
.47046 .13383 L
.47046 .13608 L
.47046 .13869 L
.47046 .14106 L
.47046 .14638 L
.47046 .16827 L
.47046 .17922 L
.47046 .1822 L
.47046 .18498 L
.47046 .18638 L
.47046 .18788 L
.47046 .19106 L
.47046 .19691 L
.47046 .20225 L
.47046 .20478 L
.47046 .20611 L
.47046 .20753 L
.47046 .21013 L
.47046 .21254 L
.47046 .22186 L
.47046 .23167 L
.47046 .23681 L
.47046 .24243 L
.47046 .25229 L
.47046 .2571 L
.47046 .26164 L
.47046 .26688 L
.47046 .27163 L
.47046 .28026 L
.47046 .28513 L
.47046 .28962 L
.47046 .29916 L
.47046 .30451 L
.47046 .30941 L
.47046 .31395 L
.47046 .31891 L
Mistroke
.47046 .32792 L
.47046 .33348 L
.47046 .33851 L
.47046 .34431 L
.47046 .34977 L
.47046 .35951 L
.47046 .36498 L
.47046 .37002 L
.47046 .37961 L
.47046 .38499 L
.47046 .38988 L
.47046 .39938 L
.47046 .40834 L
.47046 .41875 L
.47047 .42833 L
.47047 .43879 L
.47048 .44982 L
.47048 .45948 L
.47049 .46825 L
.4705 .47777 L
.47052 .48762 L
.47056 .50384 L
.47059 .51276 L
.47062 .52087 L
.4707 .53874 L
.47081 .55463 L
.47093 .56812 L
.47108 .58192 L
.47144 .60809 L
.47192 .63315 L
.47299 .67416 L
.47367 .69423 L
.47454 .71573 L
.47685 .76032 L
.48044 .81007 L
.48629 .86933 L
.49561 .94523 L
.506 1.02366 L
.51619 1.09981 L
.52705 1.18096 L
.53751 1.25905 L
.54863 1.34209 L
.55933 1.42207 L
.56963 1.49899 L
.58059 1.58087 L
.59115 1.65968 L
.60236 1.74345 L
.60316 1.74944 L
Mfstroke
.48523 .04762 m
.48523 .05002 L
.48523 .0522 L
.48523 .05472 L
.48523 .05711 L
.48523 .06135 L
.48523 .06595 L
.48523 .07638 L
.48523 .08602 L
.48523 .10692 L
.48523 .11715 L
.48523 .12651 L
.48523 .12885 L
.48523 .13141 L
.48523 .13383 L
.48523 .13608 L
.48523 .13869 L
.48523 .14106 L
.48523 .14638 L
.48523 .16827 L
.48523 .17922 L
.48523 .1822 L
.48523 .18498 L
.48523 .18638 L
.48523 .18788 L
.48523 .19106 L
.48523 .19691 L
.48523 .20225 L
.48523 .20478 L
.48523 .20611 L
.48523 .20753 L
.48523 .21013 L
.48523 .21254 L
.48523 .22186 L
.48523 .23167 L
.48523 .23681 L
.48523 .24243 L
.48523 .25229 L
.48523 .2571 L
.48523 .26164 L
.48523 .26688 L
.48523 .27163 L
.48523 .28026 L
.48523 .28513 L
.48523 .28962 L
.48523 .29916 L
.48523 .30451 L
.48523 .30941 L
.48523 .31395 L
.48523 .31891 L
Mistroke
.48523 .32792 L
.48523 .33348 L
.48523 .33851 L
.48523 .34431 L
.48523 .34977 L
.48523 .35951 L
.48523 .36498 L
.48523 .37001 L
.48523 .37961 L
.48523 .38499 L
.48523 .38988 L
.48523 .39937 L
.48523 .40834 L
.48523 .41875 L
.48523 .42833 L
.48523 .43879 L
.48524 .44981 L
.48524 .45947 L
.48525 .46824 L
.48525 .47775 L
.48526 .4876 L
.48528 .5038 L
.48529 .51272 L
.48531 .52081 L
.48535 .53866 L
.48541 .55453 L
.48547 .56799 L
.48554 .58177 L
.48572 .60788 L
.48596 .63288 L
.4865 .67378 L
.48727 .71522 L
.48833 .75691 L
.49015 .80804 L
.49318 .86964 L
.49756 .94127 L
.50297 1.02329 L
.5083 1.10314 L
.51343 1.17994 L
.51889 1.26175 L
.52414 1.34046 L
.52973 1.42417 L
.53512 1.5048 L
.54029 1.58234 L
.5458 1.66487 L
.55111 1.74431 L
.55186 1.75562 L
Mfstroke
.5 .04762 m
.5 .05002 L
.5 .0522 L
.5 .05472 L
.5 .05711 L
.5 .06135 L
.5 .06595 L
.5 .07638 L
.5 .08602 L
.5 .10692 L
.5 .11715 L
.5 .12651 L
.5 .12885 L
.5 .13141 L
.5 .13383 L
.5 .13608 L
.5 .13869 L
.5 .14106 L
.5 .14638 L
.5 .16827 L
.5 .17922 L
.5 .1822 L
.5 .18498 L
.5 .18638 L
.5 .18788 L
.5 .19106 L
.5 .19691 L
.5 .20225 L
.5 .20478 L
.5 .20611 L
.5 .20753 L
.5 .21013 L
.5 .21254 L
.5 .22186 L
.5 .23167 L
.5 .23681 L
.5 .24243 L
.5 .25229 L
.5 .2571 L
.5 .26164 L
.5 .26688 L
.5 .27163 L
.5 .28026 L
.5 .28513 L
.5 .28962 L
.5 .29916 L
.5 .30451 L
.5 .30941 L
.5 .31395 L
.5 .31891 L
Mistroke
.5 .32792 L
.5 .33348 L
.5 .33851 L
.5 .34431 L
.5 .34977 L
.5 .35951 L
.5 .36498 L
.5 .37001 L
.5 .37961 L
.5 .38499 L
.5 .38988 L
.5 .39937 L
.5 .40834 L
.5 .41875 L
.5 .42832 L
.5 .43878 L
.5 .4498 L
.5 .45947 L
.5 .46823 L
.5 .47774 L
.5 .48759 L
.5 .50379 L
.5 .5127 L
.5 .5208 L
.5 .53864 L
.5 .5545 L
.5 .56795 L
.5 .58172 L
.5 .60781 L
.5 .63279 L
.5 .67365 L
.5 .71506 L
.5 .7567 L
.5 .8078 L
.5 .86941 L
.5 .94118 L
.5 1.02341 L
.5 1.10347 L
.5 1.18048 L
.5 1.26251 L
.5 1.34143 L
.5 1.42537 L
.5 1.50621 L
.5 1.58395 L
.5 1.66671 L
.5 1.74637 L
.5 1.7577 L
Mfstroke
.51477 .04762 m
.51477 .05002 L
.51477 .0522 L
.51477 .05472 L
.51477 .05711 L
.51477 .06135 L
.51477 .06595 L
.51477 .07638 L
.51477 .08602 L
.51477 .10692 L
.51477 .11715 L
.51477 .12651 L
.51477 .12885 L
.51477 .13141 L
.51477 .13383 L
.51477 .13608 L
.51477 .13869 L
.51477 .14106 L
.51477 .14638 L
.51477 .16827 L
.51477 .17922 L
.51477 .1822 L
.51477 .18498 L
.51477 .18638 L
.51477 .18788 L
.51477 .19106 L
.51477 .19691 L
.51477 .20225 L
.51477 .20478 L
.51477 .20611 L
.51477 .20753 L
.51477 .21013 L
.51477 .21254 L
.51477 .22186 L
.51477 .23167 L
.51477 .23681 L
.51477 .24243 L
.51477 .25229 L
.51477 .2571 L
.51477 .26164 L
.51477 .26688 L
.51477 .27163 L
.51477 .28026 L
.51477 .28513 L
.51477 .28962 L
.51477 .29916 L
.51477 .30451 L
.51477 .30941 L
.51477 .31395 L
.51477 .31891 L
Mistroke
.51477 .32792 L
.51477 .33348 L
.51477 .33851 L
.51477 .34431 L
.51477 .34977 L
.51477 .35951 L
.51477 .36498 L
.51477 .37001 L
.51477 .37961 L
.51477 .38499 L
.51477 .38988 L
.51477 .39937 L
.51477 .40834 L
.51477 .41875 L
.51477 .42833 L
.51477 .43879 L
.51476 .44981 L
.51476 .45947 L
.51475 .46824 L
.51475 .47775 L
.51474 .4876 L
.51472 .5038 L
.51471 .51272 L
.51469 .52081 L
.51465 .53866 L
.51459 .55453 L
.51453 .56799 L
.51446 .58177 L
.51428 .60788 L
.51404 .63288 L
.5135 .67378 L
.51273 .71522 L
.51167 .75691 L
.50985 .80804 L
.50682 .86964 L
.50244 .94127 L
.49703 1.02329 L
.4917 1.10314 L
.48657 1.17994 L
.48111 1.26175 L
.47586 1.34046 L
.47027 1.42417 L
.46488 1.5048 L
.45971 1.58234 L
.4542 1.66487 L
.44889 1.74431 L
.44814 1.75562 L
Mfstroke
.52954 .04762 m
.52954 .05002 L
.52954 .0522 L
.52954 .05472 L
.52954 .05711 L
.52954 .06135 L
.52954 .06595 L
.52954 .07638 L
.52954 .08602 L
.52954 .10692 L
.52954 .11715 L
.52954 .12651 L
.52954 .12885 L
.52954 .13141 L
.52954 .13383 L
.52954 .13608 L
.52954 .13869 L
.52954 .14106 L
.52954 .14638 L
.52954 .16827 L
.52954 .17922 L
.52954 .1822 L
.52954 .18498 L
.52954 .18638 L
.52954 .18788 L
.52954 .19106 L
.52954 .19691 L
.52954 .20225 L
.52954 .20478 L
.52954 .20611 L
.52954 .20753 L
.52954 .21013 L
.52954 .21254 L
.52954 .22186 L
.52954 .23167 L
.52954 .23681 L
.52954 .24243 L
.52954 .25229 L
.52954 .2571 L
.52954 .26164 L
.52954 .26688 L
.52954 .27163 L
.52954 .28026 L
.52954 .28513 L
.52954 .28962 L
.52954 .29916 L
.52954 .30451 L
.52954 .30941 L
.52954 .31395 L
.52954 .31891 L
Mistroke
.52954 .32792 L
.52954 .33348 L
.52954 .33851 L
.52954 .34431 L
.52954 .34977 L
.52954 .35951 L
.52954 .36498 L
.52954 .37002 L
.52954 .37961 L
.52954 .38499 L
.52954 .38988 L
.52954 .39938 L
.52954 .40834 L
.52954 .41875 L
.52953 .42833 L
.52953 .43879 L
.52952 .44982 L
.52952 .45948 L
.52951 .46825 L
.5295 .47777 L
.52948 .48762 L
.52944 .50384 L
.52941 .51276 L
.52938 .52087 L
.5293 .53874 L
.52919 .55463 L
.52907 .56812 L
.52892 .58192 L
.52856 .60809 L
.52808 .63315 L
.52701 .67416 L
.52633 .69423 L
.52546 .71573 L
.52315 .76032 L
.51956 .81007 L
.51371 .86933 L
.50439 .94523 L
.494 1.02366 L
.48381 1.09981 L
.47295 1.18096 L
.46249 1.25905 L
.45137 1.34209 L
.44067 1.42207 L
.43037 1.49899 L
.41941 1.58087 L
.40885 1.65968 L
.39764 1.74345 L
.39684 1.74944 L
Mfstroke
.54432 .04762 m
.54432 .05002 L
.54432 .0522 L
.54432 .05472 L
.54432 .05711 L
.54432 .06135 L
.54432 .06595 L
.54432 .07638 L
.54432 .08602 L
.54432 .10692 L
.54432 .11715 L
.54432 .12162 L
.54432 .12651 L
.54432 .12905 L
.54432 .13141 L
.54432 .13367 L
.54432 .13608 L
.54432 .13886 L
.54432 .14148 L
.54432 .14638 L
.54432 .16827 L
.54432 .17861 L
.54432 .18134 L
.54432 .18426 L
.54432 .18702 L
.54432 .18953 L
.54432 .19525 L
.54432 .20152 L
.54432 .20423 L
.54432 .20566 L
.54432 .20718 L
.54432 .2085 L
.54432 .20996 L
.54432 .21254 L
.54432 .22258 L
.54432 .22805 L
.54432 .23315 L
.54432 .23751 L
.54432 .24217 L
.54432 .25204 L
.54432 .25755 L
.54432 .26352 L
.54432 .26916 L
.54432 .27435 L
.54432 .27944 L
.54432 .2842 L
.54432 .28916 L
.54432 .29462 L
.54432 .2999 L
.54432 .30479 L
Mistroke
.54432 .31016 L
.54432 .31587 L
.54432 .32132 L
.54432 .32645 L
.54432 .33112 L
.54432 .33604 L
.54431 .34056 L
.54431 .34551 L
.54431 .35421 L
.54431 .35912 L
.54431 .36437 L
.54431 .37383 L
.54431 .37907 L
.54431 .38462 L
.54431 .39458 L
.54431 .4001 L
.54431 .40527 L
.54431 .411 L
.54431 .41702 L
.5443 .42722 L
.5443 .43651 L
.54429 .44645 L
.54428 .45723 L
.54426 .4676 L
.54425 .47727 L
.54423 .48583 L
.5442 .49495 L
.54416 .50472 L
.54411 .51481 L
.544 .53221 L
.54386 .54774 L
.54368 .56348 L
.54326 .58958 L
.54263 .6167 L
.54192 .64013 L
.54021 .68116 L
.53773 .72333 L
.53422 .76645 L
.52885 .81449 L
.51924 .87764 L
.50577 .94967 L
.48954 1.03091 L
.47363 1.10981 L
.45832 1.18572 L
.44202 1.26651 L
.42634 1.34429 L
.40966 1.42696 L
.3936 1.5066 L
.37814 1.58322 L
.3617 1.66474 L
Mistroke
.34666 1.73932 L
Mfstroke
.55909 .04762 m
.55909 .05002 L
.55909 .0522 L
.55909 .05472 L
.55909 .05711 L
.55909 .06135 L
.55909 .06595 L
.55909 .07638 L
.55909 .08602 L
.55909 .10692 L
.55909 .11715 L
.55909 .12162 L
.55909 .12651 L
.55909 .12905 L
.55909 .13141 L
.55909 .13367 L
.55909 .13608 L
.55909 .13886 L
.55909 .14148 L
.55909 .14638 L
.55909 .16827 L
.55909 .17861 L
.55909 .18134 L
.55909 .18426 L
.55909 .18702 L
.55909 .18953 L
.55909 .19525 L
.55909 .20152 L
.55909 .20423 L
.55909 .20566 L
.55909 .20718 L
.55909 .2085 L
.55909 .20996 L
.55909 .21254 L
.55909 .22258 L
.55909 .22805 L
.55909 .23315 L
.55909 .23751 L
.55909 .24217 L
.55909 .25204 L
.55909 .25755 L
.55909 .26352 L
.55909 .26916 L
.55909 .27435 L
.55909 .27944 L
.55909 .2842 L
.55909 .28916 L
.55909 .29462 L
.55909 .2999 L
.55909 .30479 L
Mistroke
.55909 .31016 L
.55909 .31587 L
.55909 .32132 L
.55909 .32645 L
.55909 .33112 L
.55909 .33604 L
.55909 .34056 L
.55909 .34551 L
.55909 .35421 L
.55909 .35912 L
.55909 .36437 L
.55908 .37383 L
.55908 .37907 L
.55908 .38462 L
.55908 .39458 L
.55908 .4001 L
.55908 .40527 L
.55908 .41101 L
.55908 .41703 L
.55907 .42723 L
.55906 .43652 L
.55905 .44647 L
.55904 .45725 L
.55902 .46764 L
.559 .47731 L
.55897 .48588 L
.55893 .49502 L
.55889 .50481 L
.55882 .51492 L
.55868 .53237 L
.55849 .54795 L
.55825 .56375 L
.55769 .58997 L
.55731 .60339 L
.55686 .61724 L
.5559 .6408 L
.55483 .66208 L
.55345 .68464 L
.55019 .72554 L
.54527 .77017 L
.53763 .82019 L
.52395 .88569 L
.5053 .95918 L
.48542 1.03323 L
.46398 1.11253 L
.44332 1.18889 L
.42137 1.27006 L
.40022 1.34826 L
.37986 1.42349 L
.35821 1.50353 L
Mistroke
.33737 1.58059 L
.31732 1.65469 L
.29816 1.72555 L
Mfstroke
.57386 .04762 m
.57386 .05002 L
.57386 .0522 L
.57386 .05472 L
.57386 .05711 L
.57386 .06135 L
.57386 .06595 L
.57386 .07638 L
.57386 .08602 L
.57386 .10692 L
.57386 .11715 L
.57386 .12162 L
.57386 .12651 L
.57386 .12905 L
.57386 .13141 L
.57386 .13367 L
.57386 .13608 L
.57386 .13886 L
.57386 .14148 L
.57386 .14638 L
.57386 .16827 L
.57386 .17861 L
.57386 .18426 L
.57386 .18568 L
.57386 .18702 L
.57386 .18953 L
.57386 .19229 L
.57386 .19525 L
.57386 .20152 L
.57386 .20408 L
.57386 .20548 L
.57386 .2068 L
.57386 .20821 L
.57386 .20978 L
.57386 .21254 L
.57386 .22294 L
.57386 .22801 L
.57386 .23261 L
.57386 .23749 L
.57386 .24271 L
.57386 .25375 L
.57386 .25828 L
.57386 .26307 L
.57386 .26833 L
.57386 .27318 L
.57386 .27739 L
.57386 .28192 L
.57386 .28688 L
.57386 .29153 L
.57386 .29673 L
Mistroke
.57386 .30226 L
.57386 .30705 L
.57386 .31221 L
.57386 .31831 L
.57386 .32404 L
.57386 .32963 L
.57386 .33475 L
.57386 .34428 L
.57386 .34968 L
.57386 .35471 L
.57386 .36487 L
.57386 .37056 L
.57386 .37574 L
.57385 .38556 L
.57385 .39051 L
.57385 .39596 L
.57385 .40557 L
.57385 .41457 L
.57384 .42511 L
.57383 .43471 L
.57382 .4452 L
.5738 .45614 L
.57378 .46599 L
.57376 .47484 L
.57372 .48492 L
.57368 .49427 L
.57357 .5105 L
.5735 .51938 L
.57341 .52738 L
.5732 .54371 L
.57295 .55819 L
.57262 .57321 L
.57219 .58839 L
.57117 .61605 L
.57 .63993 L
.56716 .68168 L
.56533 .70239 L
.56301 .7245 L
.5574 .76633 L
.54787 .81761 L
.53262 .87752 L
.50936 .95154 L
.48403 1.02668 L
.45927 1.09947 L
.43287 1.17699 L
.40747 1.25162 L
.38046 1.33093 L
.35445 1.40734 L
.32942 1.48086 L
.30279 1.55907 L
Mistroke
.27715 1.63437 L
.2525 1.70678 L
.25189 1.70857 L
Mfstroke
.58863 .04762 m
.58863 .05002 L
.58863 .0522 L
.58863 .05472 L
.58863 .05711 L
.58863 .06135 L
.58863 .06595 L
.58863 .07638 L
.58863 .08602 L
.58863 .10692 L
.58863 .11715 L
.58863 .12162 L
.58863 .12651 L
.58863 .12905 L
.58863 .13141 L
.58863 .13367 L
.58863 .13608 L
.58863 .13886 L
.58863 .14148 L
.58863 .14638 L
.58863 .15689 L
.58863 .16827 L
.58863 .17948 L
.58863 .18561 L
.58863 .1886 L
.58863 .19132 L
.58863 .19621 L
.58863 .20144 L
.58863 .20398 L
.58863 .20671 L
.58863 .20828 L
.58863 .20972 L
.58863 .21254 L
.58863 .22235 L
.58863 .22733 L
.58863 .23278 L
.58863 .23751 L
.58863 .2419 L
.58863 .25151 L
.58863 .25703 L
.58863 .26224 L
.58863 .26693 L
.58863 .272 L
.58863 .27753 L
.58863 .28339 L
.58863 .28839 L
.58863 .29389 L
.58863 .29899 L
.58863 .30454 L
.58863 .30978 L
Mistroke
.58863 .31464 L
.58863 .32382 L
.58863 .32895 L
.58863 .33359 L
.58863 .34415 L
.58863 .3501 L
.58863 .35555 L
.58863 .3656 L
.58863 .37066 L
.58863 .3762 L
.58863 .38133 L
.58863 .3869 L
.58862 .3918 L
.58862 .39701 L
.58862 .40683 L
.58861 .41589 L
.58861 .42625 L
.5886 .43593 L
.58858 .44648 L
.58856 .45776 L
.58854 .46752 L
.58851 .4765 L
.58846 .48622 L
.58841 .49643 L
.58833 .50696 L
.58824 .51666 L
.58802 .53416 L
.58774 .55029 L
.58737 .56639 L
.58651 .59297 L
.58536 .61847 L
.58407 .64039 L
.5806 .68322 L
.5782 .70569 L
.57547 .72712 L
.56846 .77015 L
.55645 .82287 L
.53736 .8839 L
.51197 .95057 L
.48177 1.02476 L
.4522 1.09665 L
.42071 1.17315 L
.39039 1.24683 L
.36122 1.31768 L
.33017 1.3931 L
.30029 1.4657 L
.26853 1.54286 L
.23793 1.61721 L
.20849 1.68873 L
.20841 1.68892 L
Mistroke
Mfstroke
.6034 .04762 m
.6034 .05002 L
.6034 .0522 L
.6034 .05472 L
.6034 .05711 L
.6034 .06135 L
.6034 .06595 L
.6034 .07638 L
.6034 .08602 L
.6034 .10692 L
.6034 .11715 L
.6034 .12162 L
.6034 .12651 L
.6034 .12905 L
.6034 .13141 L
.6034 .13367 L
.6034 .13608 L
.6034 .13886 L
.6034 .14148 L
.6034 .14638 L
.6034 .15689 L
.6034 .16827 L
.6034 .17948 L
.6034 .18561 L
.6034 .1886 L
.6034 .19132 L
.6034 .19621 L
.6034 .20144 L
.6034 .20671 L
.6034 .20816 L
.6034 .20972 L
.6034 .21119 L
.6034 .21254 L
.6034 .22235 L
.6034 .22733 L
.6034 .23278 L
.6034 .23751 L
.6034 .2419 L
.6034 .25151 L
.6034 .25703 L
.6034 .26224 L
.6034 .26693 L
.6034 .272 L
.6034 .27753 L
.6034 .28339 L
.6034 .28839 L
.6034 .29389 L
.6034 .29899 L
.6034 .30454 L
.6034 .30943 L
Mistroke
.6034 .31464 L
.6034 .3198 L
.6034 .32448 L
.6034 .33359 L
.6034 .3391 L
.6034 .34415 L
.6034 .34959 L
.6034 .35556 L
.6034 .3656 L
.6034 .37109 L
.6034 .3762 L
.6034 .38642 L
.6034 .39219 L
.60339 .39751 L
.60339 .40727 L
.60339 .41219 L
.60338 .4176 L
.60338 .42691 L
.60336 .4369 L
.60335 .44627 L
.60333 .4548 L
.60331 .46418 L
.60327 .47408 L
.60323 .48332 L
.60318 .49159 L
.60311 .50119 L
.60302 .51137 L
.60279 .52923 L
.60251 .54529 L
.6021 .562 L
.60158 .57842 L
.60101 .59289 L
.59962 .61961 L
.59809 .64201 L
.59608 .66546 L
.59389 .68631 L
.5883 .72748 L
.57989 .77197 L
.56711 .82062 L
.54512 .88181 L
.51566 .94819 L
.48052 1.02177 L
.44602 1.09314 L
.4128 1.16181 L
.37744 1.23491 L
.3434 1.30527 L
.30722 1.38005 L
.27236 1.45211 L
.23882 1.52142 L
.20314 1.59516 L
Mistroke
.16879 1.66617 L
.16824 1.6673 L
Mfstroke
.61817 .04762 m
.61817 .05002 L
.61817 .0522 L
.61817 .05472 L
.61817 .05711 L
.61817 .06135 L
.61817 .06595 L
.61817 .07638 L
.61817 .08602 L
.61817 .10692 L
.61817 .11715 L
.61817 .12162 L
.61817 .12651 L
.61817 .12905 L
.61817 .13141 L
.61817 .13367 L
.61817 .13608 L
.61817 .13886 L
.61817 .14148 L
.61817 .14638 L
.61817 .15689 L
.61817 .16827 L
.61817 .17845 L
.61817 .18406 L
.61817 .18937 L
.61817 .19237 L
.61817 .19564 L
.61817 .20135 L
.61817 .20667 L
.61817 .20813 L
.61817 .2097 L
.61817 .21118 L
.61817 .21254 L
.61817 .22279 L
.61817 .22799 L
.61817 .23369 L
.61817 .23862 L
.61817 .24322 L
.61817 .25325 L
.61817 .25885 L
.61817 .26414 L
.61817 .26889 L
.61817 .27404 L
.61817 .27966 L
.61817 .2856 L
.61817 .29068 L
.61817 .29626 L
.61817 .30135 L
.61817 .3069 L
.61817 .31214 L
Mistroke
.61817 .317 L
.61817 .32618 L
.61817 .33131 L
.61817 .33596 L
.61817 .34652 L
.61817 .35246 L
.61817 .35792 L
.61817 .36797 L
.61817 .37302 L
.61817 .37856 L
.61817 .38369 L
.61817 .38926 L
.61817 .39417 L
.61816 .39937 L
.61816 .40919 L
.61815 .41825 L
.61814 .42862 L
.61813 .43829 L
.61811 .44885 L
.61808 .46013 L
.61805 .46991 L
.61801 .47889 L
.61795 .48863 L
.61788 .49886 L
.61778 .50942 L
.61766 .51916 L
.61737 .53674 L
.617 .55298 L
.61651 .56922 L
.61537 .59611 L
.61383 .62201 L
.61208 .64434 L
.60735 .68815 L
.60404 .71122 L
.60026 .73326 L
.59044 .77755 L
.57367 .83128 L
.54792 .89151 L
.51516 .95498 L
.47687 1.02461 L
.43944 1.09194 L
.39958 1.16359 L
.36119 1.23259 L
.32427 1.29895 L
.28497 1.36959 L
.24714 1.43758 L
.20693 1.50985 L
.16819 1.57947 L
.13195 1.64462 L
Mfstroke
.63295 .04762 m
.63295 .05002 L
.63295 .0522 L
.63295 .05472 L
.63295 .05711 L
.63295 .06135 L
.63295 .06595 L
.63295 .07638 L
.63295 .08602 L
.63295 .10692 L
.63295 .11715 L
.63295 .12162 L
.63295 .12651 L
.63295 .12905 L
.63295 .13141 L
.63295 .13367 L
.63295 .13608 L
.63295 .13886 L
.63295 .14148 L
.63295 .14638 L
.63295 .15689 L
.63295 .16827 L
.63295 .18937 L
.63295 .19515 L
.63295 .1984 L
.63295 .20135 L
.63295 .20716 L
.63295 .20972 L
.63295 .21117 L
.63295 .21254 L
.63295 .21739 L
.63295 .22255 L
.63295 .22823 L
.63295 .23072 L
.63295 .23344 L
.63295 .23809 L
.63295 .24298 L
.63295 .2483 L
.63295 .25325 L
.63295 .26414 L
.63295 .2693 L
.63295 .27404 L
.63295 .27953 L
.63295 .28547 L
.63295 .29071 L
.63295 .29626 L
.63295 .30142 L
.63295 .30633 L
.63295 .31552 L
.63295 .32066 L
Mistroke
.63295 .32542 L
.63295 .33065 L
.63295 .33622 L
.63295 .34107 L
.63294 .34632 L
.63294 .35095 L
.63294 .35582 L
.63294 .36024 L
.63294 .36507 L
.63294 .37357 L
.63294 .3787 L
.63294 .38427 L
.63294 .38919 L
.63294 .39439 L
.63293 .40423 L
.63293 .4133 L
.63292 .42369 L
.63291 .4334 L
.63289 .444 L
.63286 .45533 L
.63283 .46516 L
.63279 .47422 L
.63274 .48404 L
.63267 .49438 L
.63257 .50508 L
.63245 .51496 L
.63216 .53286 L
.63178 .54942 L
.63127 .56604 L
.63074 .57951 L
.63006 .59358 L
.62839 .61995 L
.62618 .64591 L
.62347 .67058 L
.62041 .6931 L
.61285 .73559 L
.60075 .78354 L
.58205 .83585 L
.55442 .89306 L
.51615 .95873 L
.47597 1.02343 L
.43261 1.09252 L
.39079 1.15908 L
.35057 1.22309 L
.30777 1.29123 L
.26656 1.35681 L
.22276 1.42652 L
.18056 1.49369 L
.13997 1.5583 L
.10002 1.62189 L
Mistroke
Mfstroke
.64772 .04762 m
.64772 .05002 L
.64772 .0522 L
.64772 .05472 L
.64772 .05711 L
.64772 .06135 L
.64772 .06595 L
.64772 .07638 L
.64772 .08602 L
.64772 .10692 L
.64772 .11715 L
.64772 .12162 L
.64772 .12651 L
.64772 .12905 L
.64772 .13141 L
.64772 .13367 L
.64772 .13608 L
.64772 .13886 L
.64772 .14148 L
.64772 .14638 L
.64772 .15689 L
.64772 .16827 L
.64772 .18937 L
.64772 .19234 L
.64772 .19515 L
.64772 .1984 L
.64772 .20135 L
.64772 .20678 L
.64772 .20975 L
.64772 .2112 L
.64772 .21254 L
.64772 .21486 L
.64772 .21735 L
.64772 .22267 L
.64772 .22752 L
.64772 .23204 L
.64772 .23697 L
.64772 .23958 L
.64772 .24237 L
.64772 .25325 L
.64772 .25881 L
.64772 .26484 L
.64772 .27053 L
.64772 .27578 L
.64772 .28573 L
.64772 .29074 L
.64772 .29626 L
.64772 .30135 L
.64772 .3069 L
.64772 .3118 L
Mistroke
.64772 .31701 L
.64772 .32217 L
.64772 .32684 L
.64772 .33596 L
.64772 .34146 L
.64772 .34652 L
.64772 .35196 L
.64772 .35792 L
.64771 .36797 L
.64771 .37346 L
.64771 .37857 L
.64771 .38879 L
.64771 .39456 L
.64771 .39989 L
.6477 .40965 L
.6477 .41457 L
.64769 .41999 L
.64768 .42931 L
.64767 .4393 L
.64765 .44869 L
.64762 .45724 L
.64759 .46665 L
.64755 .47659 L
.64749 .48587 L
.64742 .49419 L
.64733 .50385 L
.64721 .51413 L
.6469 .5322 L
.64651 .54851 L
.64596 .56555 L
.64524 .58237 L
.64444 .59723 L
.64247 .62483 L
.64025 .64808 L
.63731 .67251 L
.63406 .69433 L
.62561 .73758 L
.61269 .78431 L
.59323 .83441 L
.56162 .8942 L
.52222 .95547 L
.47652 1.02187 L
.4318 1.08604 L
.38874 1.14777 L
.34289 1.21349 L
.29875 1.27674 L
.25185 1.34398 L
.20665 1.40875 L
.16317 1.47107 L
.11692 1.53736 L
Mistroke
.07298 1.60034 L
Mfstroke
.66249 .04762 m
.66249 .05002 L
.66249 .0522 L
.66249 .05472 L
.66249 .05711 L
.66249 .06135 L
.66249 .06595 L
.66249 .07638 L
.66249 .08602 L
.66249 .10692 L
.66249 .11715 L
.66249 .12162 L
.66249 .12651 L
.66249 .12905 L
.66249 .13141 L
.66249 .13367 L
.66249 .13608 L
.66249 .13886 L
.66249 .14148 L
.66249 .14638 L
.66249 .15689 L
.66249 .16827 L
.66249 .18937 L
.66249 .19212 L
.66249 .19511 L
.66249 .19794 L
.66249 .20055 L
.66249 .20682 L
.66249 .20977 L
.66249 .21121 L
.66249 .21254 L
.66249 .21487 L
.66249 .21739 L
.66249 .22275 L
.66249 .22793 L
.66249 .23067 L
.66249 .23359 L
.66249 .23855 L
.66249 .24317 L
.66249 .25325 L
.66249 .25881 L
.66249 .26484 L
.66249 .27053 L
.66249 .27578 L
.66249 .28573 L
.66249 .29074 L
.66249 .29626 L
.66249 .30135 L
.66249 .3069 L
.66249 .3118 L
Mistroke
.66249 .31701 L
.66249 .32217 L
.66249 .32684 L
.66249 .33596 L
.66249 .34146 L
.66249 .34652 L
.66249 .35207 L
.66249 .35792 L
.66249 .36778 L
.66249 .37336 L
.66248 .37857 L
.66248 .3888 L
.66248 .39457 L
.66248 .3999 L
.66247 .40966 L
.66247 .41458 L
.66246 .42 L
.66245 .42933 L
.66244 .43933 L
.66242 .44873 L
.66239 .4573 L
.66236 .46672 L
.66231 .47668 L
.66225 .48599 L
.66218 .49434 L
.66209 .50405 L
.66196 .51438 L
.6618 .52387 L
.66163 .53257 L
.66122 .54902 L
.66063 .56623 L
.65991 .58214 L
.65899 .59832 L
.65674 .6275 L
.65406 .65299 L
.64736 .69818 L
.64289 .72085 L
.63708 .7452 L
.62273 .7912 L
.59874 .84552 L
.56457 .90283 L
.51935 .96639 L
.47269 1.02829 L
.4273 1.08793 L
.37893 1.15142 L
.33237 1.21254 L
.28287 1.27751 L
.23519 1.34009 L
.18931 1.40031 L
.14051 1.46436 L
Mistroke
.09351 1.52604 L
.05136 1.58137 L
Mfstroke
.67726 .04762 m
.67726 .05002 L
.67726 .0522 L
.67726 .05472 L
.67726 .05711 L
.67726 .06135 L
.67726 .06595 L
.67726 .07638 L
.67726 .08602 L
.67726 .10692 L
.67726 .11715 L
.67726 .12162 L
.67726 .12651 L
.67726 .12905 L
.67726 .13141 L
.67726 .13367 L
.67726 .13608 L
.67726 .13886 L
.67726 .14148 L
.67726 .14638 L
.67726 .15689 L
.67726 .16827 L
.67726 .18937 L
.67726 .19511 L
.67726 .20055 L
.67726 .20682 L
.67726 .20959 L
.67726 .21254 L
.67726 .21503 L
.67726 .21778 L
.67726 .22262 L
.67726 .2279 L
.67726 .23067 L
.67726 .23359 L
.67726 .23888 L
.67726 .24373 L
.67726 .25325 L
.67726 .25839 L
.67726 .26389 L
.67726 .26908 L
.67726 .27379 L
.67726 .27934 L
.67726 .28535 L
.67726 .29102 L
.67726 .29626 L
.67726 .3058 L
.67726 .31116 L
.67726 .31605 L
.67726 .32059 L
.67726 .32555 L
Mistroke
.67726 .33456 L
.67726 .34012 L
.67726 .34515 L
.67726 .35057 L
.67726 .35642 L
.67726 .36186 L
.67726 .36685 L
.67726 .37199 L
.67726 .37667 L
.67725 .38627 L
.67725 .39155 L
.67725 .39654 L
.67725 .40541 L
.67724 .41502 L
.67723 .42005 L
.67723 .42558 L
.67721 .43674 L
.67719 .44704 L
.67717 .45664 L
.67713 .466 L
.67708 .47614 L
.67701 .48661 L
.67693 .49623 L
.67673 .51315 L
.67659 .5224 L
.67643 .53063 L
.67598 .54821 L
.67545 .5637 L
.67472 .57991 L
.67379 .59618 L
.67163 .62397 L
.66911 .64801 L
.66571 .67317 L
.662 .69528 L
.65704 .71955 L
.65146 .74213 L
.63622 .78922 L
.61201 .84197 L
.57801 .8968 L
.53272 .95721 L
.48555 1.01586 L
.43458 1.07834 L
.38539 1.13852 L
.33808 1.19641 L
.28772 1.25802 L
.23924 1.31733 L
.18772 1.38036 L
.13808 1.44109 L
.09033 1.49952 L
.03952 1.56168 L
Mistroke
.03563 1.56644 L
Mfstroke
.69203 .04762 m
.69203 .05002 L
.69203 .0522 L
.69203 .05472 L
.69203 .05711 L
.69203 .06135 L
.69203 .06595 L
.69203 .07638 L
.69203 .08602 L
.69203 .10692 L
.69203 .11715 L
.69203 .12162 L
.69203 .12651 L
.69203 .12905 L
.69203 .13141 L
.69203 .13367 L
.69203 .13608 L
.69203 .13886 L
.69203 .14148 L
.69203 .14638 L
.69203 .16827 L
.69203 .18979 L
.69203 .21254 L
.69203 .22197 L
.69203 .23208 L
.69203 .23789 L
.69203 .24318 L
.69203 .24856 L
.69203 .25353 L
.69203 .25803 L
.69203 .26281 L
.69203 .2729 L
.69203 .2771 L
.69203 .28162 L
.69203 .28659 L
.69203 .29125 L
.69203 .29615 L
.69203 .30137 L
.69203 .30589 L
.69203 .31079 L
.69203 .31655 L
.69203 .32199 L
.69203 .33216 L
.69203 .33735 L
.69203 .34305 L
.69203 .349 L
.69203 .35457 L
.69203 .36452 L
.69203 .37011 L
.69203 .37521 L
Mistroke
.69203 .38495 L
.69202 .39039 L
.69202 .39532 L
.69202 .4049 L
.69201 .41391 L
.692 .42444 L
.69199 .43409 L
.69197 .44464 L
.69194 .45571 L
.6919 .46561 L
.69186 .47457 L
.6918 .48481 L
.69172 .4944 L
.69153 .51115 L
.69139 .5204 L
.69123 .52882 L
.69081 .54602 L
.69028 .56152 L
.68956 .57777 L
.68861 .59443 L
.68631 .62359 L
.68319 .65184 L
.67957 .67678 L
.67553 .69916 L
.66412 .74626 L
.65562 .77272 L
.64553 .79863 L
.61876 .85133 L
.57824 .91078 L
.53122 .96913 L
.48337 1.02543 L
.43185 1.08541 L
.38221 1.14315 L
.32942 1.20453 L
.27857 1.26366 L
.22965 1.32054 L
.17761 1.38106 L
.12749 1.43933 L
.07932 1.49535 L
.02801 1.55501 L
.02628 1.55702 L
Mfstroke
.7068 .04762 m
.7068 .05002 L
.7068 .0522 L
.7068 .05472 L
.7068 .05711 L
.7068 .06135 L
.7068 .06595 L
.7068 .07638 L
.7068 .08602 L
.7068 .10692 L
.7068 .11715 L
.7068 .12162 L
.7068 .12651 L
.7068 .12905 L
.7068 .13141 L
.7068 .13367 L
.7068 .13608 L
.7068 .13886 L
.7068 .14148 L
.7068 .14638 L
.7068 .16827 L
.7068 .18979 L
.7068 .21254 L
.7068 .22197 L
.7068 .23208 L
.7068 .23789 L
.7068 .24318 L
.7068 .24856 L
.7068 .25353 L
.7068 .25803 L
.7068 .26281 L
.7068 .2729 L
.7068 .2771 L
.7068 .28162 L
.7068 .28659 L
.7068 .29125 L
.7068 .29615 L
.7068 .30137 L
.7068 .30589 L
.7068 .31079 L
.7068 .31655 L
.7068 .32199 L
.7068 .33217 L
.7068 .33735 L
.7068 .34305 L
.7068 .349 L
.7068 .35457 L
.7068 .36452 L
.7068 .37011 L
.7068 .37521 L
Mistroke
.7068 .38496 L
.7068 .3904 L
.70679 .39532 L
.70679 .40491 L
.70678 .41393 L
.70677 .42446 L
.70676 .43411 L
.70674 .44468 L
.70671 .45577 L
.70668 .46569 L
.70663 .47466 L
.70657 .48494 L
.70649 .49456 L
.7063 .51139 L
.70615 .52071 L
.70599 .52918 L
.70556 .54654 L
.70503 .56221 L
.70428 .57868 L
.70328 .59559 L
.70086 .62527 L
.69753 .65411 L
.69363 .67961 L
.68926 .70254 L
.67681 .75085 L
.66749 .77796 L
.65645 .80444 L
.62752 .85778 L
.58495 .91706 L
.53669 .97474 L
.48799 1.03028 L
.43567 1.08943 L
.38525 1.14636 L
.33164 1.20688 L
.28 1.26518 L
.23033 1.32127 L
.17748 1.38094 L
.12659 1.43839 L
.07767 1.49363 L
.02556 1.55246 L
.02381 1.55443 L
Mfstroke
.72158 .04762 m
.72158 .05002 L
.72158 .0522 L
.72158 .05472 L
.72158 .05711 L
.72158 .06135 L
.72158 .06595 L
.72158 .07638 L
.72158 .08602 L
.72158 .10692 L
.72158 .11715 L
.72158 .12162 L
.72158 .12651 L
.72158 .12905 L
.72158 .13141 L
.72158 .13367 L
.72158 .13608 L
.72158 .13886 L
.72158 .14148 L
.72158 .14638 L
.72158 .16827 L
.72158 .18979 L
.72158 .21254 L
.72158 .22197 L
.72158 .23208 L
.72158 .23789 L
.72158 .24318 L
.72158 .24856 L
.72158 .25353 L
.72158 .25803 L
.72158 .26281 L
.72158 .2729 L
.72158 .2771 L
.72158 .28162 L
.72158 .28659 L
.72158 .29125 L
.72158 .29615 L
.72158 .30137 L
.72158 .31079 L
.72158 .31655 L
.72158 .32199 L
.72158 .33217 L
.72158 .33739 L
.72158 .34292 L
.72157 .35283 L
.72157 .35834 L
.72157 .36349 L
.72157 .36958 L
.72157 .37522 L
.72157 .38537 L
Mistroke
.72157 .39072 L
.72157 .39642 L
.72156 .40186 L
.72156 .40697 L
.72155 .41651 L
.72154 .42592 L
.72153 .43456 L
.72152 .44401 L
.72149 .45394 L
.72146 .46389 L
.72142 .4729 L
.72136 .48323 L
.72128 .4929 L
.7211 .50986 L
.72096 .51926 L
.7208 .52782 L
.72038 .5454 L
.71985 .5613 L
.7191 .57806 L
.71809 .59531 L
.71559 .62566 L
.71404 .64004 L
.71211 .65521 L
.70764 .68335 L
.70265 .70805 L
.68895 .7577 L
.67981 .78273 L
.6675 .81069 L
.63423 .86835 L
.59128 .92563 L
.54417 .98098 L
.49202 1.03992 L
.44147 1.09666 L
.38768 1.15699 L
.33586 1.2151 L
.28601 1.271 L
.23298 1.33047 L
.18191 1.38774 L
.13282 1.44279 L
.08054 1.50143 L
.03022 1.55785 L
.02864 1.55962 L
Mfstroke
.73635 .04762 m
.73635 .05002 L
.73635 .0522 L
.73635 .05472 L
.73635 .05711 L
.73635 .06135 L
.73635 .06595 L
.73635 .07638 L
.73635 .08602 L
.73635 .10692 L
.73635 .11715 L
.73635 .12162 L
.73635 .12651 L
.73635 .12905 L
.73635 .13141 L
.73635 .13367 L
.73635 .13608 L
.73635 .13886 L
.73635 .14148 L
.73635 .14638 L
.73635 .16827 L
.73635 .18979 L
.73635 .21254 L
.73635 .22197 L
.73635 .23208 L
.73635 .23789 L
.73635 .24318 L
.73635 .24856 L
.73635 .25353 L
.73635 .25803 L
.73635 .26281 L
.73635 .2729 L
.73635 .2771 L
.73635 .28162 L
.73635 .28659 L
.73635 .29125 L
.73635 .29615 L
.73635 .30137 L
.73635 .31079 L
.73635 .31655 L
.73635 .32199 L
.73635 .33217 L
.73635 .33739 L
.73635 .34292 L
.73635 .35283 L
.73635 .35834 L
.73635 .36349 L
.73634 .36958 L
.73634 .37522 L
.73634 .38537 L
Mistroke
.73634 .39073 L
.73634 .39643 L
.73634 .40187 L
.73633 .40698 L
.73633 .41652 L
.73632 .42594 L
.73631 .43459 L
.73629 .44405 L
.73626 .45399 L
.73623 .46396 L
.73619 .47299 L
.73613 .48334 L
.73606 .49306 L
.73588 .51009 L
.73574 .51955 L
.73559 .52817 L
.73516 .5459 L
.73463 .56198 L
.73387 .57897 L
.73283 .59649 L
.73025 .62742 L
.72863 .64212 L
.7266 .65765 L
.72187 .6865 L
.71654 .71188 L
.70181 .76297 L
.69197 .78871 L
.67876 .81738 L
.64366 .87607 L
.59969 .93391 L
.55248 .9897 L
.50066 1.04911 L
.45051 1.10631 L
.39717 1.16711 L
.34579 1.22568 L
.29636 1.28203 L
.24377 1.34198 L
.19314 1.3997 L
.14446 1.45519 L
.09261 1.51429 L
.04272 1.57116 L
.04115 1.57295 L
Mfstroke
.75112 .04762 m
.75112 .05002 L
.75112 .0522 L
.75112 .05472 L
.75112 .05711 L
.75112 .06135 L
.75112 .06595 L
.75112 .07638 L
.75112 .08602 L
.75112 .10692 L
.75112 .11715 L
.75112 .12162 L
.75112 .12651 L
.75112 .12905 L
.75112 .13141 L
.75112 .13367 L
.75112 .13608 L
.75112 .13886 L
.75112 .14148 L
.75112 .14638 L
.75112 .16827 L
.75112 .18979 L
.75112 .21254 L
.75112 .22197 L
.75112 .23208 L
.75112 .23789 L
.75112 .24318 L
.75112 .24856 L
.75112 .25353 L
.75112 .25803 L
.75112 .26281 L
.75112 .2729 L
.75112 .2771 L
.75112 .28163 L
.75112 .28659 L
.75112 .29125 L
.75112 .29615 L
.75112 .30138 L
.75112 .31079 L
.75112 .31655 L
.75112 .32199 L
.75112 .33217 L
.75112 .33739 L
.75112 .34292 L
.75112 .35283 L
.75112 .35834 L
.75112 .3635 L
.75112 .36958 L
.75112 .37522 L
.75111 .38538 L
Mistroke
.75111 .39073 L
.75111 .39644 L
.75111 .40188 L
.75111 .40699 L
.7511 .41654 L
.75109 .42596 L
.75108 .43461 L
.75106 .44408 L
.75104 .45404 L
.75101 .46403 L
.75097 .47308 L
.75091 .48346 L
.75084 .49321 L
.75066 .51032 L
.75053 .51983 L
.75038 .52852 L
.74996 .54641 L
.74943 .56266 L
.74866 .57988 L
.74761 .59769 L
.74646 .61306 L
.74496 .62923 L
.74117 .66016 L
.73663 .68753 L
.73057 .71589 L
.72338 .74265 L
.71364 .7719 L
.68848 .82806 L
.65124 .88815 L
.60644 .94703 L
.5596 1.00382 L
.5087 1.06433 L
.45956 1.12257 L
.40729 1.18449 L
.35695 1.24414 L
.30852 1.30151 L
.25699 1.36256 L
.20738 1.42135 L
.15968 1.47786 L
.10888 1.53804 L
.06156 1.5941 L
Mfstroke
.76589 .04762 m
.76589 .05002 L
.76589 .0522 L
.76589 .05472 L
.76589 .05711 L
.76589 .06135 L
.76589 .06595 L
.76589 .07638 L
.76589 .08602 L
.76589 .10692 L
.76589 .11715 L
.76589 .12162 L
.76589 .12651 L
.76589 .12905 L
.76589 .13141 L
.76589 .13367 L
.76589 .13608 L
.76589 .13886 L
.76589 .14148 L
.76589 .14638 L
.76589 .16827 L
.76589 .18979 L
.76589 .21254 L
.76589 .22197 L
.76589 .23208 L
.76589 .23789 L
.76589 .24318 L
.76589 .24856 L
.76589 .25353 L
.76589 .25803 L
.76589 .26281 L
.76589 .26802 L
.76589 .2729 L
.76589 .27745 L
.76589 .28163 L
.76589 .28626 L
.76589 .29125 L
.76589 .30093 L
.76589 .30635 L
.76589 .31127 L
.76589 .31586 L
.76589 .32085 L
.76589 .32989 L
.76589 .33497 L
.76589 .34057 L
.76589 .34641 L
.76589 .35187 L
.76589 .36164 L
.76589 .36712 L
.76589 .37213 L
Mistroke
.76589 .38189 L
.76589 .38733 L
.76588 .39226 L
.76588 .40187 L
.76588 .4109 L
.76587 .42146 L
.76586 .43115 L
.76584 .44176 L
.76582 .45292 L
.76579 .46293 L
.76575 .472 L
.7657 .48242 L
.76563 .49221 L
.76556 .50119 L
.76547 .50942 L
.76519 .52776 L
.76502 .53652 L
.76479 .54583 L
.76428 .5623 L
.76346 .58123 L
.76249 .59792 L
.76 .62841 L
.7582 .64484 L
.75626 .65966 L
.75144 .68908 L
.74594 .71504 L
.73829 .74388 L
.72952 .77063 L
.70556 .82595 L
.67069 .88502 L
.62911 .94295 L
.58087 1.00496 L
.53343 1.06474 L
.48285 1.1283 L
.43411 1.18954 L
.38723 1.24844 L
.33734 1.31111 L
.28932 1.37146 L
.24314 1.42947 L
.19396 1.49125 L
.14664 1.5507 L
.09632 1.61393 L
.08987 1.62203 L
Mfstroke
.78066 .04762 m
.78066 .05002 L
.78066 .0522 L
.78066 .05472 L
.78066 .05711 L
.78066 .06135 L
.78066 .06595 L
.78066 .07638 L
.78066 .08602 L
.78066 .10692 L
.78066 .11715 L
.78066 .12162 L
.78066 .12651 L
.78066 .12905 L
.78066 .13141 L
.78066 .13367 L
.78066 .13608 L
.78066 .13886 L
.78066 .14148 L
.78066 .14638 L
.78066 .16827 L
.78066 .18979 L
.78066 .21254 L
.78066 .22197 L
.78066 .23208 L
.78066 .23789 L
.78066 .24318 L
.78066 .24856 L
.78066 .25353 L
.78066 .25803 L
.78066 .26281 L
.78066 .26802 L
.78066 .2729 L
.78066 .2771 L
.78066 .28163 L
.78066 .28665 L
.78066 .29125 L
.78066 .29623 L
.78066 .30093 L
.78066 .30635 L
.78066 .31127 L
.78066 .3202 L
.78066 .32524 L
.78066 .32989 L
.78066 .33966 L
.78066 .34522 L
.78066 .35041 L
.78066 .36089 L
.78066 .36677 L
.78066 .37214 L
Mistroke
.78066 .38189 L
.78066 .38734 L
.78066 .39227 L
.78065 .40188 L
.78065 .41091 L
.78064 .42147 L
.78063 .43117 L
.78062 .44179 L
.78059 .45297 L
.78057 .46299 L
.78053 .47208 L
.78048 .48252 L
.78042 .49234 L
.78034 .50136 L
.78026 .50962 L
.78 .52807 L
.77983 .53691 L
.77961 .5463 L
.7791 .56294 L
.7783 .58212 L
.77734 .59908 L
.77615 .61544 L
.77483 .63017 L
.77103 .66217 L
.76605 .6924 L
.76034 .71916 L
.75235 .74893 L
.74318 .77658 L
.71827 .83375 L
.6829 .89465 L
.64199 .95437 L
.59547 1.01836 L
.55003 1.08005 L
.50165 1.14564 L
.45503 1.20884 L
.41019 1.26962 L
.36248 1.3343 L
.31654 1.39657 L
.27238 1.45644 L
.22535 1.5202 L
.18009 1.58155 L
.13196 1.6468 L
.12579 1.65516 L
Mfstroke
.79544 .04762 m
.79544 .05002 L
.79544 .0522 L
.79544 .05472 L
.79544 .05711 L
.79544 .06135 L
.79544 .06595 L
.79544 .07638 L
.79544 .08602 L
.79544 .10692 L
.79544 .11715 L
.79544 .12162 L
.79544 .12651 L
.79544 .12905 L
.79544 .13141 L
.79544 .13367 L
.79544 .13608 L
.79544 .13886 L
.79544 .14148 L
.79544 .14638 L
.79544 .16827 L
.79544 .18979 L
.79544 .21254 L
.79544 .22197 L
.79544 .23208 L
.79544 .23789 L
.79544 .24318 L
.79544 .24856 L
.79544 .25353 L
.79544 .25803 L
.79544 .26281 L
.79544 .26802 L
.79544 .2729 L
.79544 .2771 L
.79544 .28163 L
.79544 .29125 L
.79544 .29615 L
.79544 .30138 L
.79544 .30631 L
.79544 .31079 L
.79544 .31607 L
.79544 .32179 L
.79544 .32715 L
.79544 .33217 L
.79543 .33735 L
.79543 .34305 L
.79543 .34861 L
.79543 .35458 L
.79543 .36011 L
.79543 .36537 L
Mistroke
.79543 .37523 L
.79543 .38053 L
.79543 .38552 L
.79543 .39483 L
.79543 .40006 L
.79542 .40486 L
.79542 .41568 L
.79541 .42436 L
.7954 .43387 L
.79539 .44379 L
.79537 .45301 L
.79534 .46314 L
.7953 .47411 L
.79525 .48442 L
.79519 .49389 L
.79513 .50236 L
.79503 .51164 L
.79477 .53018 L
.79459 .5396 L
.79436 .54938 L
.79384 .56652 L
.79308 .58446 L
.792 .60343 L
.79072 .62078 L
.78931 .63606 L
.78526 .669 L
.78036 .69805 L
.77358 .72887 L
.76557 .75771 L
.75457 .78978 L
.72717 .85073 L
.68983 .91548 L
.6487 .9789 L
.60327 1.04668 L
.55924 1.11204 L
.51687 1.17492 L
.47178 1.24182 L
.42837 1.30624 L
.38663 1.36816 L
.34218 1.43412 L
.29941 1.49758 L
.25392 1.56507 L
.21011 1.63008 L
.16867 1.69156 L
Mfstroke
.81021 .04762 m
.81021 .05002 L
.81021 .0522 L
.81021 .05472 L
.81021 .05711 L
.81021 .06135 L
.81021 .06595 L
.81021 .07638 L
.81021 .08602 L
.81021 .10692 L
.81021 .11715 L
.81021 .12162 L
.81021 .12651 L
.81021 .12905 L
.81021 .13141 L
.81021 .13367 L
.81021 .13608 L
.81021 .13886 L
.81021 .14148 L
.81021 .14638 L
.81021 .16827 L
.81021 .18979 L
.81021 .21254 L
.81021 .22197 L
.81021 .23208 L
.81021 .23789 L
.81021 .24318 L
.81021 .24856 L
.81021 .25353 L
.81021 .25803 L
.81021 .26281 L
.81021 .26802 L
.81021 .2729 L
.81021 .2771 L
.81021 .28163 L
.81021 .29125 L
.81021 .29615 L
.81021 .30138 L
.81021 .30631 L
.81021 .31079 L
.81021 .31607 L
.81021 .32179 L
.81021 .32719 L
.81021 .33217 L
.81021 .34213 L
.81021 .34779 L
.81021 .35309 L
.81021 .36377 L
.8102 .36976 L
.8102 .37523 L
Mistroke
.8102 .38499 L
.8102 .39044 L
.8102 .39537 L
.8102 .40498 L
.81019 .41401 L
.81018 .42459 L
.81018 .43429 L
.81016 .44492 L
.81014 .45611 L
.81011 .46615 L
.81008 .47527 L
.81003 .48574 L
.80997 .4956 L
.8099 .50466 L
.80982 .51298 L
.80957 .53159 L
.8094 .54052 L
.80919 .55004 L
.8087 .56695 L
.80791 .58655 L
.80695 .60396 L
.80576 .62085 L
.80442 .63613 L
.80049 .66956 L
.79525 .70144 L
.78917 .72986 L
.77077 .79134 L
.74469 .85274 L
.70844 .92057 L
.66906 .98714 L
.63004 1.0515 L
.58832 1.12009 L
.54814 1.1861 L
.50543 1.25629 L
.46428 1.32389 L
.4247 1.38893 L
.38259 1.45813 L
.34204 1.52475 L
.30306 1.5888 L
.26154 1.65702 L
.22159 1.72266 L
.21758 1.72927 L
Mfstroke
.82498 .04762 m
.82498 .05002 L
.82498 .0522 L
.82498 .05472 L
.82498 .05711 L
.82498 .06135 L
.82498 .06595 L
.82498 .07638 L
.82498 .08602 L
.82498 .10692 L
.82498 .11715 L
.82498 .12162 L
.82498 .12651 L
.82498 .12905 L
.82498 .13141 L
.82498 .13367 L
.82498 .13608 L
.82498 .13886 L
.82498 .14148 L
.82498 .14638 L
.82498 .16827 L
.82498 .18979 L
.82498 .21254 L
.82498 .22197 L
.82498 .23208 L
.82498 .24318 L
.82498 .24814 L
.82498 .25353 L
.82498 .2588 L
.82498 .26367 L
.82498 .26823 L
.82498 .27326 L
.82498 .27776 L
.82498 .28199 L
.82498 .29125 L
.82498 .29622 L
.82498 .30084 L
.82498 .30591 L
.82498 .31133 L
.82498 .31702 L
.82498 .3224 L
.82498 .32723 L
.82498 .33246 L
.82498 .34201 L
.82498 .34682 L
.82498 .35211 L
.82498 .35663 L
.82498 .36148 L
.82498 .37023 L
.82498 .37543 L
Mistroke
.82498 .38096 L
.82497 .3909 L
.82497 .39699 L
.82497 .40272 L
.82497 .40792 L
.82497 .41341 L
.82496 .42366 L
.82495 .43307 L
.82494 .44319 L
.82492 .45426 L
.82489 .46489 L
.82486 .47492 L
.82483 .48389 L
.82477 .4936 L
.8247 .5041 L
.8246 .51518 L
.82449 .52456 L
.82433 .53482 L
.82416 .54433 L
.82394 .55423 L
.82343 .57164 L
.82268 .58994 L
.82162 .60939 L
.82033 .62728 L
.8189 .64312 L
.81475 .67754 L
.80966 .70818 L
.80254 .74094 L
.7826 .80625 L
.75498 .87181 L
.72219 .93704 L
.68438 1.00754 L
.64735 1.07565 L
.60792 1.1481 L
.56992 1.21789 L
.53337 1.28503 L
.49448 1.35646 L
.45704 1.42524 L
.42105 1.49136 L
.38271 1.56178 L
.34582 1.62955 L
.30659 1.70161 L
.27127 1.76648 L
Mfstroke
.83975 .04762 m
.83975 .05002 L
.83975 .0522 L
.83975 .05472 L
.83975 .05711 L
.83975 .06135 L
.83975 .06595 L
.83975 .07638 L
.83975 .08602 L
.83975 .10692 L
.83975 .11715 L
.83975 .12162 L
.83975 .12651 L
.83975 .12905 L
.83975 .13141 L
.83975 .13367 L
.83975 .13608 L
.83975 .13886 L
.83975 .14148 L
.83975 .14638 L
.83975 .16827 L
.83975 .18979 L
.83975 .21254 L
.83975 .22197 L
.83975 .23208 L
.83975 .23789 L
.83975 .24318 L
.83975 .24856 L
.83975 .25353 L
.83975 .26281 L
.83975 .26771 L
.83975 .2729 L
.83975 .28163 L
.83975 .29125 L
.83975 .29605 L
.83975 .30129 L
.83975 .30677 L
.83975 .31186 L
.83975 .32099 L
.83975 .32611 L
.83975 .33075 L
.83975 .34126 L
.83975 .34719 L
.83975 .35266 L
.83975 .3627 L
.83975 .36776 L
.83975 .37333 L
.83975 .37842 L
.83975 .38396 L
.83975 .38885 L
Mistroke
.83974 .39406 L
.83974 .40388 L
.83974 .41299 L
.83974 .41852 L
.83973 .42449 L
.83972 .43531 L
.83971 .44582 L
.83969 .45546 L
.83967 .46501 L
.83964 .4752 L
.83961 .48479 L
.83956 .49349 L
.8395 .50366 L
.83941 .51465 L
.83929 .52495 L
.83917 .53441 L
.83902 .54344 L
.83882 .55308 L
.83836 .57028 L
.83762 .59029 L
.83671 .60818 L
.83557 .62562 L
.83427 .64147 L
.83039 .67641 L
.82514 .71003 L
.81898 .74022 L
.8004 .806 L
.7751 .87188 L
.74224 .94446 L
.70832 1.01539 L
.6753 1.08381 L
.64009 1.15668 L
.60621 1.22682 L
.57018 1.30138 L
.53548 1.3732 L
.5021 1.4423 L
.46658 1.51581 L
.43238 1.58659 L
.3995 1.65464 L
.36449 1.72711 L
.3308 1.79685 L
.32842 1.80178 L
Mfstroke
.85452 .04762 m
.85452 .05002 L
.85452 .0522 L
.85452 .05472 L
.85452 .05711 L
.85452 .06135 L
.85452 .06595 L
.85452 .07638 L
.85452 .08602 L
.85452 .10692 L
.85452 .11715 L
.85452 .12162 L
.85452 .12651 L
.85452 .12905 L
.85452 .13141 L
.85452 .13367 L
.85452 .13608 L
.85452 .13886 L
.85452 .14148 L
.85452 .14638 L
.85452 .16827 L
.85452 .18979 L
.85452 .21254 L
.85452 .22197 L
.85452 .23208 L
.85452 .23789 L
.85452 .24318 L
.85452 .24856 L
.85452 .25353 L
.85452 .26281 L
.85452 .26771 L
.85452 .2729 L
.85452 .28163 L
.85452 .28659 L
.85452 .29125 L
.85452 .29622 L
.85452 .30084 L
.85452 .30633 L
.85452 .31133 L
.85452 .31658 L
.85452 .32154 L
.85452 .32685 L
.85452 .33246 L
.85452 .33695 L
.85452 .34189 L
.85452 .35059 L
.85452 .35548 L
.85452 .36074 L
.85452 .37024 L
.85452 .37543 L
Mistroke
.85452 .38096 L
.85452 .39091 L
.85452 .397 L
.85451 .40273 L
.85451 .40794 L
.85451 .41343 L
.85451 .42369 L
.8545 .43311 L
.85449 .44323 L
.85447 .45432 L
.85445 .46498 L
.85443 .47504 L
.85439 .48404 L
.85435 .4938 L
.85429 .50437 L
.8542 .51552 L
.85411 .52499 L
.85398 .53537 L
.85383 .545 L
.85363 .55506 L
.85319 .57279 L
.85253 .59152 L
.85156 .61155 L
.85038 .63006 L
.84905 .64654 L
.84512 .68257 L
.8402 .71489 L
.83327 .74966 L
.81406 .81936 L
.78867 .88935 L
.76028 .95865 L
.7287 1.03321 L
.69809 1.10512 L
.66553 1.18157 L
.63416 1.25522 L
.60399 1.32606 L
.57188 1.40145 L
.54097 1.47402 L
.51125 1.5438 L
.47961 1.61811 L
.44915 1.68962 L
.41676 1.76566 L
.38761 1.83412 L
Mfstroke
.86929 .04762 m
.86929 .05002 L
.86929 .0522 L
.86929 .05472 L
.86929 .05711 L
.86929 .06135 L
.86929 .06595 L
.86929 .07638 L
.86929 .08602 L
.86929 .10692 L
.86929 .11715 L
.86929 .12162 L
.86929 .12651 L
.86929 .12905 L
.86929 .13141 L
.86929 .13367 L
.86929 .13608 L
.86929 .13886 L
.86929 .14148 L
.86929 .14638 L
.86929 .16827 L
.86929 .18979 L
.86929 .21254 L
.86929 .22197 L
.86929 .23208 L
.86929 .23789 L
.86929 .24318 L
.86929 .2485 L
.86929 .25353 L
.86929 .25808 L
.86929 .26292 L
.86929 .26705 L
.86929 .2716 L
.86929 .27648 L
.86929 .27904 L
.86929 .28174 L
.86929 .2867 L
.86929 .29125 L
.86929 .30146 L
.86929 .30629 L
.86929 .31074 L
.86929 .31588 L
.86929 .32145 L
.86929 .32667 L
.86929 .33156 L
.86929 .34023 L
.86929 .34483 L
.86929 .34977 L
.86929 .35494 L
.86929 .35985 L
Mistroke
.86929 .36906 L
.86929 .37436 L
.86929 .37935 L
.86929 .38867 L
.86929 .3939 L
.86929 .39871 L
.86929 .40954 L
.86928 .41825 L
.86928 .42779 L
.86927 .43774 L
.86926 .44701 L
.86925 .45721 L
.86922 .46828 L
.8692 .4787 L
.86916 .48831 L
.86912 .49694 L
.86907 .50641 L
.869 .51627 L
.86892 .52547 L
.86867 .5449 L
.8685 .55458 L
.86828 .56506 L
.86777 .58342 L
.86714 .6002 L
.86616 .6197 L
.86499 .63773 L
.86205 .6707 L
.85764 .70545 L
.85231 .73715 L
.83632 .80568 L
.81505 .87408 L
.78825 .94926 L
.76108 1.02254 L
.73195 1.10062 L
.70388 1.17585 L
.67687 1.24822 L
.64813 1.32522 L
.62047 1.39935 L
.59387 1.47063 L
.56554 1.54653 L
.53828 1.61958 L
.50929 1.69725 L
.48137 1.77207 L
.45452 1.84402 L
.44748 1.86288 L
Mfstroke
.88407 .04762 m
.88407 .05002 L
.88407 .0522 L
.88407 .05472 L
.88407 .05711 L
.88407 .06135 L
.88407 .06595 L
.88407 .07638 L
.88407 .08602 L
.88407 .10692 L
.88407 .11715 L
.88407 .12162 L
.88407 .12651 L
.88407 .12905 L
.88407 .13141 L
.88407 .13367 L
.88407 .13608 L
.88407 .13886 L
.88407 .14148 L
.88407 .14638 L
.88407 .16827 L
.88407 .18979 L
.88407 .21254 L
.88407 .22197 L
.88407 .23208 L
.88407 .23789 L
.88407 .24318 L
.88407 .24856 L
.88407 .25353 L
.88407 .26281 L
.88407 .26771 L
.88407 .2729 L
.88407 .2774 L
.88407 .28163 L
.88407 .28626 L
.88407 .29125 L
.88407 .29615 L
.88407 .30138 L
.88407 .3059 L
.88407 .31079 L
.88407 .31656 L
.88407 .32199 L
.88407 .33217 L
.88407 .33735 L
.88407 .34306 L
.88407 .34901 L
.88407 .35458 L
.88406 .36454 L
.88406 .37014 L
.88406 .37524 L
Mistroke
.88406 .385 L
.88406 .39045 L
.88406 .39539 L
.88406 .40501 L
.88406 .41406 L
.88405 .42465 L
.88405 .43437 L
.88404 .44504 L
.88402 .45628 L
.88401 .46638 L
.88399 .47556 L
.88396 .48613 L
.88392 .49611 L
.88387 .5053 L
.88382 .51377 L
.88365 .53282 L
.88354 .54202 L
.8834 .55186 L
.88306 .56951 L
.8828 .57964 L
.88249 .59019 L
.88177 .60882 L
.88087 .62663 L
.87966 .64534 L
.87674 .67839 L
.872 .71618 L
.86607 .75169 L
.85045 .8207 L
.82845 .89692 L
.80454 .97218 L
.7809 1.04506 L
.75565 1.12273 L
.73134 1.1975 L
.70549 1.27698 L
.6806 1.35355 L
.65665 1.4272 L
.63117 1.50556 L
.60663 1.58102 L
.58304 1.65355 L
.55792 1.73081 L
.53375 1.80515 L
.50804 1.8842 L
.50687 1.88782 L
Mfstroke
.89884 .04762 m
.89884 .05002 L
.89884 .0522 L
.89884 .05472 L
.89884 .05711 L
.89884 .06135 L
.89884 .06595 L
.89884 .07638 L
.89884 .08602 L
.89884 .10692 L
.89884 .11715 L
.89884 .12162 L
.89884 .12651 L
.89884 .12905 L
.89884 .13141 L
.89884 .13367 L
.89884 .13608 L
.89884 .13886 L
.89884 .14148 L
.89884 .14638 L
.89884 .16827 L
.89884 .18979 L
.89884 .20156 L
.89884 .21254 L
.89884 .21738 L
.89884 .22197 L
.89884 .22726 L
.89884 .23208 L
.89884 .23467 L
.89884 .23598 L
.89884 .23742 L
.89884 .24236 L
.89884 .24819 L
.89884 .25074 L
.89884 .25353 L
.89884 .2581 L
.89884 .26058 L
.89884 .2629 L
.89884 .26778 L
.89884 .27299 L
.89884 .28256 L
.89884 .29125 L
.89884 .30115 L
.89884 .30614 L
.89884 .31163 L
.89884 .31631 L
.89884 .32134 L
.89884 .33042 L
.89884 .33587 L
.89884 .34181 L
Mistroke
.89884 .34741 L
.89884 .35261 L
.89884 .36243 L
.89884 .36791 L
.89884 .37288 L
.89884 .38286 L
.89883 .38789 L
.89883 .39339 L
.89883 .40314 L
.89883 .41223 L
.89883 .42297 L
.89882 .43275 L
.89881 .44402 L
.8988 .45467 L
.89879 .46403 L
.89877 .47433 L
.89874 .48507 L
.89871 .49512 L
.89867 .50446 L
.89862 .51299 L
.89848 .53212 L
.89838 .54157 L
.89825 .55161 L
.89794 .56954 L
.8977 .58042 L
.89742 .59059 L
.89676 .60943 L
.89592 .6278 L
.89478 .64696 L
.89204 .68074 L
.88801 .71613 L
.88311 .74913 L
.86889 .82026 L
.84904 .89858 L
.82771 .97573 L
.80672 1.05037 L
.78432 1.12986 L
.76275 1.2064 L
.74202 1.27998 L
.71994 1.35834 L
.69869 1.43375 L
.67609 1.51394 L
.65432 1.59117 L
.63339 1.66545 L
.61111 1.74451 L
.58967 1.82061 L
.56687 1.9015 L
.56477 1.90895 L
Mfstroke
.91361 .04762 m
.91361 .05002 L
.91361 .0522 L
.91361 .05472 L
.91361 .05711 L
.91361 .05931 L
.91361 .06135 L
.91361 .06595 L
.91361 .06837 L
.91361 .07098 L
.91361 .07344 L
.91361 .07569 L
.91361 .08061 L
.91361 .08602 L
.91361 .08851 L
.91361 .09117 L
.91361 .09367 L
.91361 .09594 L
.91361 .10152 L
.91361 .10678 L
.91361 .10918 L
.91361 .11171 L
.91361 .11625 L
.91361 .11878 L
.91361 .12114 L
.91361 .12393 L
.91361 .12651 L
.91361 .1291 L
.91361 .1304 L
.91361 .13185 L
.91361 .13485 L
.91361 .13766 L
.91361 .14317 L
.91361 .14558 L
.91361 .14822 L
.91361 .15063 L
.91361 .15287 L
.91361 .15775 L
.91361 .16031 L
.91361 .16272 L
.91361 .16406 L
.91361 .1655 L
.91361 .16803 L
.91361 .16936 L
.91361 .17079 L
.91361 .17338 L
.91361 .17928 L
.91361 .18539 L
.91361 .19119 L
.91361 .19652 L
Mistroke
.91361 .19799 L
.91361 .19954 L
.91361 .20101 L
.91361 .20234 L
.91361 .20487 L
.91361 .2076 L
.91361 .21254 L
.91361 .23365 L
.91361 .24395 L
.91361 .24845 L
.91361 .25333 L
.91361 .25842 L
.91361 .26324 L
.91361 .27386 L
.91361 .27954 L
.91361 .2824 L
.91361 .28556 L
.91361 .29072 L
.91361 .29637 L
.91361 .30124 L
.91361 .30644 L
.91361 .31193 L
.91361 .31703 L
.91361 .32213 L
.91361 .32695 L
.91361 .33127 L
.91361 .33595 L
.91361 .34152 L
.91361 .34673 L
.91361 .35216 L
.91361 .35813 L
.91361 .36798 L
.91361 .37351 L
.91361 .37855 L
.91361 .38834 L
.91361 .39329 L
.91361 .39875 L
.9136 .40839 L
.9136 .41745 L
.9136 .42806 L
.91359 .4378 L
.91358 .44848 L
.91357 .45972 L
.91356 .46987 L
.91354 .47908 L
.91351 .4897 L
.91348 .49971 L
.91344 .50895 L
.9134 .51746 L
.91325 .5366 L
Mistroke
.91316 .5459 L
.91304 .55585 L
.91274 .57371 L
.91251 .58451 L
.91224 .59471 L
.91162 .61368 L
.91083 .63193 L
.90976 .65117 L
.90717 .68531 L
.90294 .72469 L
.89768 .76181 L
.88421 .83413 L
.86629 .91346 L
.84764 .9911 L
.82946 1.06603 L
.81008 1.14582 L
.79142 1.22263 L
.77159 1.30427 L
.75248 1.38292 L
.7341 1.45859 L
.71454 1.53909 L
.69571 1.6166 L
.67761 1.69112 L
.65833 1.77048 L
.63978 1.84685 L
.62043 1.92651 L
Mfstroke
.92838 .04762 m
.92838 .05002 L
.92838 .0522 L
.92838 .05472 L
.92838 .05711 L
.92838 .05916 L
.92838 .06135 L
.92838 .06374 L
.92838 .06595 L
.92838 .07055 L
.92838 .07309 L
.92838 .0755 L
.92838 .07834 L
.92838 .08093 L
.92838 .08602 L
.92838 .09088 L
.92838 .09355 L
.92838 .09606 L
.92838 .09841 L
.92838 .10095 L
.92838 .10538 L
.92838 .11073 L
.92838 .11365 L
.92838 .11638 L
.92838 .11891 L
.92838 .12121 L
.92838 .12376 L
.92838 .12651 L
.92838 .13184 L
.92838 .13476 L
.92838 .13619 L
.92838 .1375 L
.92838 .13982 L
.92838 .14233 L
.92838 .14767 L
.92838 .14901 L
.92838 .15044 L
.92838 .15302 L
.92838 .15888 L
.92838 .16041 L
.92838 .16206 L
.92838 .16362 L
.92838 .16507 L
.92838 .1678 L
.92838 .17069 L
.92838 .17565 L
.92838 .18098 L
.92838 .18356 L
.92838 .18602 L
.92838 .18822 L
Mistroke
.92838 .19062 L
.92838 .19351 L
.92838 .19613 L
.92838 .20199 L
.92838 .20702 L
.92838 .20969 L
.92838 .21254 L
.92838 .21524 L
.92838 .21771 L
.92838 .22252 L
.92838 .22794 L
.92838 .23306 L
.92838 .23778 L
.92838 .24221 L
.92838 .24683 L
.92838 .25192 L
.92838 .25702 L
.92838 .26251 L
.92838 .26719 L
.92838 .2723 L
.92838 .27523 L
.92838 .27794 L
.92838 .28387 L
.92838 .28938 L
.92838 .29445 L
.92838 .29948 L
.92838 .30201 L
.92838 .3048 L
.92838 .316 L
.92838 .32106 L
.92838 .3265 L
.92838 .33162 L
.92838 .33631 L
.92838 .34564 L
.92838 .35091 L
.92838 .3558 L
.92838 .36476 L
.92838 .36928 L
.92838 .37428 L
.92838 .38429 L
.92838 .38933 L
.92838 .39485 L
.92838 .40462 L
.92838 .41372 L
.92837 .42448 L
.92837 .43426 L
.92836 .44555 L
.92835 .45621 L
.92834 .46561 L
.92833 .47595 L
Mistroke
.9283 .48673 L
.92828 .49681 L
.92825 .5062 L
.92821 .51477 L
.92809 .53399 L
.92801 .54355 L
.9279 .55369 L
.92765 .57183 L
.92745 .58286 L
.92722 .59319 L
.92668 .61235 L
.92597 .63116 L
.92501 .65083 L
.92268 .68565 L
.91923 .72238 L
.91504 .7567 L
.90321 .83074 L
.88748 .91166 L
.87118 .99075 L
.85529 1.06706 L
.83838 1.14827 L
.82209 1.22647 L
.80643 1.30166 L
.78975 1.38172 L
.7737 1.45877 L
.75663 1.5407 L
.7402 1.61961 L
.72439 1.69551 L
.70756 1.77628 L
.69136 1.85404 L
.67415 1.93669 L
.67328 1.94084 L
Mfstroke
.94315 .04762 m
.94315 .05002 L
.94315 .0522 L
.94315 .05472 L
.94315 .05711 L
.94315 .05916 L
.94315 .06135 L
.94315 .06374 L
.94315 .06595 L
.94315 .07055 L
.94315 .07309 L
.94315 .0755 L
.94315 .07834 L
.94315 .08093 L
.94315 .08602 L
.94315 .09088 L
.94315 .09606 L
.94315 .09858 L
.94315 .10095 L
.94315 .10307 L
.94315 .10538 L
.94315 .11073 L
.94315 .11638 L
.94315 .12121 L
.94315 .12395 L
.94315 .12651 L
.94315 .12928 L
.94315 .13185 L
.94315 .13766 L
.94315 .14278 L
.94315 .14537 L
.94315 .14684 L
.94315 .14822 L
.94315 .15287 L
.94315 .1552 L
.94315 .15775 L
.94315 .16053 L
.94315 .16311 L
.94315 .16549 L
.94315 .16803 L
.94315 .17378 L
.94315 .17681 L
.94315 .17847 L
.94315 .18002 L
.94315 .18138 L
.94315 .18283 L
.94315 .18592 L
.94315 .19135 L
.94315 .19407 L
.94315 .19703 L
Mistroke
.94315 .19983 L
.94315 .20242 L
.94315 .20497 L
.94315 .20734 L
.94315 .20982 L
.94315 .21254 L
.94315 .21516 L
.94315 .21662 L
.94315 .21796 L
.94315 .22294 L
.94315 .22832 L
.94315 .23116 L
.94315 .23271 L
.94315 .23417 L
.94315 .23676 L
.94315 .23961 L
.94315 .24463 L
.94315 .24945 L
.94315 .25208 L
.94315 .25452 L
.94315 .25909 L
.94315 .26151 L
.94315 .26408 L
.94315 .26867 L
.94315 .27283 L
.94315 .28298 L
.94315 .29254 L
.94315 .30203 L
.94315 .30741 L
.94315 .31244 L
.94315 .32259 L
.94315 .32829 L
.94315 .33349 L
.94315 .34275 L
.94315 .34764 L
.94315 .35284 L
.94315 .35736 L
.94315 .36236 L
.94315 .37119 L
.94315 .3812 L
.94315 .38624 L
.94315 .39176 L
.94315 .40153 L
.94315 .41063 L
.94315 .42139 L
.94314 .43118 L
.94314 .44247 L
.94313 .45314 L
.94312 .46254 L
.94311 .47289 L
Mistroke
.94309 .48369 L
.94307 .49378 L
.94304 .50319 L
.94301 .51179 L
.94292 .53107 L
.94285 .54066 L
.94277 .55085 L
.94256 .56909 L
.94239 .5802 L
.9422 .59061 L
.94174 .60994 L
.94113 .62895 L
.9403 .64886 L
.93827 .68416 L
.93524 .72145 L
.93155 .75628 L
.92115 .83133 L
.90751 .91306 L
.89347 .99275 L
.87983 1.06958 L
.86531 1.15136 L
.85132 1.23009 L
.83787 1.30579 L
.82355 1.3864 L
.80977 1.46397 L
.79511 1.54646 L
.781 1.62591 L
.76742 1.70233 L
.75297 1.78366 L
.73906 1.86195 L
.72428 1.94516 L
.723 1.95238 L
Mfstroke
1 0 0 r
.01 w
.05685 .04762 m
.07162 .04762 L
.08639 .04762 L
.10116 .04762 L
.11593 .04762 L
.13071 .04762 L
.14548 .04762 L
.16025 .04762 L
.17502 .04762 L
.18979 .04762 L
.20456 .04762 L
.21934 .04762 L
.23411 .04762 L
.24888 .04762 L
.26365 .04762 L
.27842 .04762 L
.2932 .04762 L
.30797 .04762 L
.32274 .04762 L
.33751 .04762 L
.35228 .04762 L
.36705 .04762 L
.38183 .04762 L
.3966 .04762 L
.41137 .04762 L
.42614 .04762 L
.44091 .04762 L
.45568 .04762 L
.47046 .04762 L
.48523 .04762 L
.5 .04762 L
.51477 .04762 L
.52954 .04762 L
.54432 .04762 L
.55909 .04762 L
.57386 .04762 L
.58863 .04762 L
.6034 .04762 L
.61817 .04762 L
.63295 .04762 L
.64772 .04762 L
.66249 .04762 L
.67726 .04762 L
.69203 .04762 L
.7068 .04762 L
.72158 .04762 L
.73635 .04762 L
.75112 .04762 L
.76589 .04762 L
.78066 .04762 L
Mistroke
.79544 .04762 L
.81021 .04762 L
.82498 .04762 L
.83975 .04762 L
.85452 .04762 L
.86929 .04762 L
.88407 .04762 L
.89884 .04762 L
.91361 .04762 L
.92838 .04762 L
.94315 .04762 L
Mfstroke
.05685 .37172 m
.07162 .37171 L
.08639 .37171 L
.10116 .37171 L
.11594 .37171 L
.13071 .37171 L
.14548 .37171 L
.16025 .37171 L
.17502 .3717 L
.1898 .3717 L
.20457 .3717 L
.21934 .3717 L
.23411 .3717 L
.24888 .37169 L
.26366 .37169 L
.27843 .37169 L
.2932 .37168 L
.30797 .37168 L
.32274 .37168 L
.33751 .37168 L
.35229 .37167 L
.36706 .37167 L
.38183 .37167 L
.3966 .37167 L
.41137 .37166 L
.42614 .37166 L
.44091 .37166 L
.45569 .37166 L
.47046 .37166 L
.48523 .37166 L
.5 .37166 L
.51477 .37166 L
.52954 .37166 L
.54431 .37166 L
.55909 .37166 L
.57386 .37166 L
.58863 .37166 L
.6034 .37167 L
.61817 .37167 L
.63294 .37167 L
.64771 .37167 L
.66249 .37168 L
.67726 .37168 L
.69203 .37168 L
.7068 .37168 L
.72157 .37169 L
.73634 .37169 L
.75112 .37169 L
.76589 .3717 L
.78066 .3717 L
Mistroke
.79543 .3717 L
.8102 .3717 L
.82498 .3717 L
.83975 .37171 L
.85452 .37171 L
.86929 .37171 L
.88406 .37171 L
.89884 .37171 L
.91361 .37171 L
.92838 .37171 L
.94315 .37172 L
Mfstroke
.06201 .68812 m
.07741 .68671 L
.09282 .68514 L
.10822 .68339 L
.12359 .68147 L
.13892 .6794 L
.1542 .67719 L
.1694 .67485 L
.18453 .67242 L
.19956 .66991 L
.2145 .66735 L
.22935 .66477 L
.2441 .6622 L
.25876 .65965 L
.27333 .65715 L
.28783 .65473 L
.30225 .65239 L
.3166 .65016 L
.3309 .64805 L
.34514 .64608 L
.35934 .64425 L
.37351 .64257 L
.38763 .64105 L
.40173 .63969 L
.41581 .63851 L
.42987 .63751 L
.44391 .63668 L
.45795 .63603 L
.47197 .63557 L
.48599 .63529 L
.5 .6352 L
.51401 .63529 L
.52803 .63557 L
.54205 .63603 L
.55609 .63668 L
.57013 .63751 L
.58419 .63851 L
.59827 .63969 L
.61237 .64105 L
.62649 .64257 L
.64066 .64425 L
.65486 .64608 L
.6691 .64805 L
.6834 .65016 L
.69775 .65239 L
.71217 .65473 L
.72667 .65715 L
.74124 .65965 L
.7559 .6622 L
.77065 .66477 L
Mistroke
.7855 .66735 L
.80044 .66991 L
.81547 .67242 L
.8306 .67485 L
.8458 .67719 L
.86108 .6794 L
.87641 .68147 L
.89178 .68339 L
.90718 .68514 L
.92259 .68671 L
.93799 .68812 L
Mfstroke
.10747 .99805 m
.12929 .993 L
.15137 .98703 L
.17351 .98008 L
.19544 .97212 L
.21689 .9632 L
.23752 .95343 L
.25706 .94297 L
.27523 .93211 L
.29187 .92112 L
.30695 .9103 L
.32052 .89991 L
.33274 .89012 L
.34382 .88103 L
.35401 .87266 L
.36352 .86498 L
.37257 .85794 L
.38133 .85148 L
.38994 .84556 L
.3985 .84013 L
.40711 .83516 L
.4158 .83065 L
.42463 .82659 L
.43361 .82299 L
.44275 .81984 L
.45203 .81716 L
.46145 .81495 L
.47099 .81323 L
.48061 .81199 L
.49029 .81125 L
.5 .811 L
.50971 .81125 L
.51939 .81199 L
.52901 .81323 L
.53855 .81495 L
.54797 .81716 L
.55725 .81984 L
.56639 .82299 L
.57537 .82659 L
.5842 .83065 L
.59289 .83516 L
.6015 .84013 L
.61006 .84556 L
.61867 .85148 L
.62743 .85794 L
.63648 .86498 L
.64599 .87266 L
.65618 .88103 L
.66726 .89012 L
.67948 .89991 L
Mistroke
.69305 .9103 L
.70813 .92112 L
.72477 .93211 L
.74294 .94297 L
.76248 .95343 L
.78311 .9632 L
.80456 .97212 L
.82649 .98008 L
.84863 .98703 L
.87071 .993 L
.89253 .99805 L
Mfstroke
.16397 1.31615 m
.19509 1.30893 L
.22742 1.30016 L
.26071 1.28966 L
.29461 1.2773 L
.32865 1.26301 L
.36228 1.24686 L
.39487 1.22905 L
.42577 1.20997 L
.45434 1.19017 L
.48005 1.17035 L
.50251 1.15128 L
.5215 1.13377 L
.53699 1.11848 L
.54913 1.1059 L
.55817 1.09626 L
.56444 1.08955 L
.56825 1.08553 L
.56992 1.08384 L
.56972 1.08402 L
.5679 1.08561 L
.56466 1.08818 L
.56022 1.09134 L
.55476 1.09475 L
.54842 1.09816 L
.54137 1.10134 L
.53375 1.10414 L
.52569 1.10643 L
.5173 1.10812 L
.5087 1.10915 L
.5 1.1095 L
.4913 1.10915 L
.4827 1.10812 L
.47431 1.10643 L
.46625 1.10414 L
.45863 1.10134 L
.45158 1.09816 L
.44524 1.09475 L
.43978 1.09134 L
.43534 1.08818 L
.4321 1.08561 L
.43028 1.08402 L
.43008 1.08384 L
.43175 1.08553 L
.43556 1.08955 L
.44183 1.09626 L
.45087 1.1059 L
.46301 1.11848 L
.4785 1.13377 L
.49749 1.15128 L
Mistroke
.51995 1.17035 L
.54566 1.19017 L
.57423 1.20997 L
.60513 1.22905 L
.63772 1.24686 L
.67135 1.26301 L
.70539 1.2773 L
.73929 1.28966 L
.77258 1.30016 L
.80491 1.30893 L
.83603 1.31615 L
Mfstroke
.22049 1.63427 m
.2609 1.62489 L
.30349 1.61333 L
.34797 1.5993 L
.39387 1.58256 L
.44058 1.56295 L
.48734 1.54049 L
.53323 1.51541 L
.57725 1.48823 L
.61838 1.45972 L
.65569 1.43096 L
.68836 1.40322 L
.71581 1.3779 L
.73771 1.35629 L
.75399 1.33942 L
.76476 1.32794 L
.77031 1.32199 L
.77098 1.32127 L
.76714 1.32514 L
.75918 1.33269 L
.74745 1.34297 L
.73232 1.35503 L
.71414 1.36798 L
.69326 1.38103 L
.67 1.39354 L
.64474 1.40495 L
.6178 1.41485 L
.58951 1.42287 L
.56023 1.42878 L
.53028 1.43239 L
.5 1.4336 L
.46972 1.43239 L
.43977 1.42878 L
.41049 1.42287 L
.3822 1.41485 L
.35526 1.40495 L
.33 1.39354 L
.30674 1.38103 L
.28586 1.36798 L
.26768 1.35503 L
.25255 1.34297 L
.24082 1.33269 L
.23286 1.32514 L
.22902 1.32127 L
.22969 1.32199 L
.23524 1.32794 L
.24601 1.33942 L
.26229 1.35629 L
.28419 1.3779 L
.31164 1.40322 L
Mistroke
.34431 1.43096 L
.38162 1.45972 L
.42275 1.48823 L
.46677 1.51541 L
.51266 1.54049 L
.55942 1.56295 L
.60613 1.58256 L
.65203 1.5993 L
.69651 1.61333 L
.7391 1.62489 L
.77951 1.63427 L
Mfstroke
.277 1.95238 m
.32672 1.94084 L
.37957 1.92651 L
.43523 1.90895 L
.49313 1.88782 L
.55252 1.86288 L
.61239 1.83412 L
.67158 1.80178 L
.72873 1.76648 L
.78242 1.72927 L
.83133 1.69156 L
.87421 1.65516 L
.91013 1.62203 L
.93844 1.5941 L
.95885 1.57295 L
.97136 1.55962 L
.97619 1.55443 L
.97372 1.55702 L
.96437 1.56644 L
.94864 1.58137 L
.92702 1.60034 L
.89998 1.62189 L
.86805 1.64462 L
.83176 1.6673 L
.79159 1.68892 L
.74811 1.70857 L
.70184 1.72555 L
.65334 1.73932 L
.60316 1.74944 L
.55186 1.75562 L
.5 1.7577 L
.44814 1.75562 L
.39684 1.74944 L
.34666 1.73932 L
.29816 1.72555 L
.25189 1.70857 L
.20841 1.68892 L
.16824 1.6673 L
.13195 1.64462 L
.10002 1.62189 L
.07298 1.60034 L
.05136 1.58137 L
.03563 1.56644 L
.02628 1.55702 L
.02381 1.55443 L
.02864 1.55962 L
.04115 1.57295 L
.06156 1.5941 L
.08987 1.62203 L
.12579 1.65516 L
Mistroke
.16867 1.69156 L
.21758 1.72927 L
.27127 1.76648 L
.32842 1.80178 L
.38761 1.83412 L
.44748 1.86288 L
.50687 1.88782 L
.56477 1.90895 L
.62043 1.92651 L
.67328 1.94084 L
.723 1.95238 L
Mfstroke
% End of Graphics
MathPictureEnd
\
\>"], "Picture",
  ImageSize->{224, 448},
  ImageMargins->{{43, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004H0002<2000`400?l00000o`00003ooooooolI
ooooo`00oooooolIooooo`00oooooolIooooo`00oooooolIooooo`00oooooolIooooo`00oooooolI
ooooo`00oooooolIooooo`00oooooolIooooo`00oooooolIooooo`00oooooolIooooo`00oooooolI
ooooo`002Oooool4o`000003oa0@4?oooooooooo00;ooooo0_lQ8B45ooooo`05odA4A?l0003o0000
oc8b<_oMgMd06Oooool4o`000003oa0@4?oooooooooo01Kooooo00Gok^k^oc8b<_l0003o<S8bonk^
kP05ooooo`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo00?o0000ooooooooool0
6?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00Gooooo0_lQ8B45ooooo`05odA4A?l0003o0000oc8b
<_oMgMd06Oooool4o`000003oa0@4?oooooooooo01Sooooo1?l000000ol@413oooooooooo`02oooo
o`;o8B4Q1Oooool01Om4A4Co0000o`000?lb<S;ogMgM01Sooooo000;ooooo`03o`000?oooooooooo
00Cooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo01[ooooo00?o0000ooooooooool06?ooool01Omg
MgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb<S;ooooo01Oooooo00?o0000
ooooooooool06?ooool01OmgMgOoV9RHoooooonHV9SoMgMg00Gooooo0_lQ8B48ooooo`03ogMgMolb
<S;ooooo01[ooooo00?o0000ooooooooool07?ooool00ol0003oooooooooo`04ooooo`;o8B4Q2?oo
ool00omgMgOo<S8booooo`0Gooooo`001_l00005ooooo`03o`000?oooooooooo00oooooo00?o0000
ooooooooool03_ooool6o`0000Gooooo00?o0000ooooooooool04?ooool6o`0000;ooooo00Go410@
oooooooooooooooooa0@400@ooooo`03o`000?oooooooooo01Kooooo00?o0000ooooooooool06?oo
ool01Ol@413ooooooooooooooooo410@013ooooo00?o0000ooooooooool06Oooool00ol0003ooooo
ooooo`0Looooo`03o`000?oooooooooo00oooooo00?o0000ooooooooool05_ooool000_ooooo00?o
0000ooooooooool03_ooool00omgMgOo<S8booooo`0Jooooo`03o`000?oooooooooo01Sooooo00Go
0000ooooooooooooooooo`00000?ooooo`03ogMgMolb<S;ooooo01Oooooo00?o0000ooooooooool0
6?ooool01Ol0003ooooooooooooooooo000000oooooo00?oMgMgoc8b<_ooool06_ooool00ol0003o
ooooooooo`0Looooo`03o`000?oooooooooo00kooooo00?oMgMgoc8b<_ooool05oooool000_ooooo
00?o0000ooooooooool02oooool01Ol0003o8B4Qo`000?lb<S;oc<c<01_ooooo00?o0000oooooooo
ool06?ooool01Ol0003ooooooooooooooooo000000cooooo00Go0000ob4Q8Ol0003o<S8bolc<c00H
ooooo`03o`000?oooooooooo01Sooooo00Go0000ooooooooooooooooo`00000<ooooo`05o`000?lQ
8B7o0000oc8b<_o<c<`06oooool00ol0003oooooooooo`0Looooo`03o`000?oooooooooo00_ooooo
00Go0000ob4Q8Ol0003o<S8bolc<c00Hooooo`002oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo01gooooo00?o0000ooooooooool06?ooool01Ol@413ooooooooooooooooo410@00co
oooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Hooooo`05oa0@4?oooooooooooooo
ool@41003?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01cooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`0Jooooo`002oooool00ol0003oooooooooo`0;ooooo`03
o`000?oooooooooo01gooooo00?o0000ooooooooool06?ooool01OmgMgOoV9RHoooooonHV9SoMgMg
00cooooo00?o0000ooooooooool06_ooool00ol0003oooooooooo`0Hooooo`05ogMgMonHV9Sooooo
oiRHV?mgMgL03?ooool00ol0003oooooooooo`0Mooooo`03o`000?oooooooooo01cooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0Jooooo`002Oooool00omEEEGoIVIVo`00000=oooo
o`Co00006_ooool00omEEEGoIVIVo`00000Jooooo`05onk^k_lb<S;o0000oc8b<_o^k^h03?ooool4
o`0001Wooooo00?o0000ooooooooool06?ooool01Oo^k^ko<S8bo`000?lb<S;ok^k^00cooooo1?l0
000Jooooo`03oeEEEOmVIVKo000001cooooo00?oEEEEofIVI_l000003Oooool4o`0001Wooooo0022
ooooo`03o`000?oooooooooo09?ooooo0022ooooo`03o`000?oooooooooo08Wooooo0_l00002oooo
o`;o00001?ooool008;ooooo00?o0000ooooooooool0ROooool01_o^k^ko8B4QohN7Qonj^[[o0000
omgMg@Cooooo0022ooooo`03o`000?oooooooooo08[ooooo00CogMgMo`000?l@413oc<c<1Oooool0
00ko0000j?oo000?o`0000[ooooo00Cok^k^ob4Q8Ol@413ok^k^1Oooool000Oooooo00?o0000oooo
ooooool01?oooooXool000Kooooo00?o0000ooooooooool04?ooool01?lQ8B7oMgMgogMgMolb<S85
ooooo`003oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooo
ooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00000oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooooooo
o`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
0oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool05_ooool2o`00
00;ooooo0_l00004ooooo`003oooool01?l0003oooooooooool00003ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo0000
0oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003oooo
o`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04
o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooooooo
ool08?ooool000oooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003o
ooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?o
oooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooo
ooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo023ooooo
000?ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo
00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003
ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo0000
0oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003oooo
o`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0Pooooo`003oooool0
1?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0
003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003o
ooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000?ooooo00?o0000ooooooooool08?ooool000oooooo00Co0000oooo
oooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooo
oooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo
00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`03o`000?oooooooooo023ooooo000?ooooo`04o`000?ooooooooooo`00
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000ooo
ool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool0
1?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00000oooool00ol0003oooooooooo`0Pooooo`003oooool01?l0003oooooooooool00003ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000
oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`00
0?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooo
oooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo
00?o0000ooooooooool08?ooool000oooooo00Co0000oooooooooooo00000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooooooo
o`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
0oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`00
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000ooo
ool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oo
oooooooo023ooooo000?ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co
0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000
oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0P
ooooo`003oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooo
ooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00000oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooooooo
o`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
0oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool08?ooool000oo
oooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo
00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co
0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo023ooooo000?ooooo`04o`00
0?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oo
ooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool000000oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooo
ooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`0Pooooo`003oooool01?l0003ooooooooo
ool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool0
0003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?o
oooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00?o0000ooooooooool08?ooool000oooooo00Co0000oooooooooooo00000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04
o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`00
0?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooooooo023ooooo000?ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooo
ooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooooooo
ool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
00?ooooo0_l000000ooooooo0000ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03
o`000?oooooooooo023ooooo000?ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool0
0003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?o
oooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo
00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooo
ooooo`0Pooooo`003oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`00
0?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oo
ooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool000000oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool08?oo
ool000oooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooooooo
ool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool0
0003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?o
oooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo023ooooo000?oooo
o`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04
o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`00
0?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0Pooooo`003oooool01?l0003o
ooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?o
oooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooo
ooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooooooo
ool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooooooool08?ooool000oooooo00Co0000oooooooooooo
00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003
ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo0000
0oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003oooo
o`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000003ooooo`03o`000?oooooooooo023ooooo000?ooooo`04o`000?ooooooooooo`0000?ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0
003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003o
ooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?o
oooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000ooo
ool00ol0003oooooooooo`0Pooooo`003oooool01?l0003oooooooooool00003ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooo
oooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo
00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003
ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooooooool08?ooool000oooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool0
1?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0
003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo
023ooooo000?ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`00
0?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooo
oooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooo
oooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0Pooooo`00
3oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`00
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000ooo
ool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool0
1?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool08?ooool000oooooo00Co
0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000
oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`00
0?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooo
oooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`000003ooooo`03o`000?oooooooooo023ooooo000?ooooo`04o`000?oooooo
ooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00000oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooooooo
o`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
0oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`00
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000000oooool00ol0003oooooooooo`0Pooooo`003oooool01?l0003oooooooooool00003
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo
00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co
0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool08?ooool000oooooo00Co0000oooooooooooo00000oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oo
ooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool000000oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooo
ooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00000oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03
o`000?oooooooooo023ooooo000?ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool0
0003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?o
oooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo
00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooo
ooooo`0Pooooo`003oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`00
0?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`;o000000?o
ooooo`000?ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0P
ooooo`003oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooo
ooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00000oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooooooo
o`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
0oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool08?ooool000oo
oooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo
00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co
0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo023ooooo000?ooooo`04o`00
0?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oo
ooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool000000oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooo
ooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`0Pooooo`003oooool01?l0003ooooooooo
ool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool0
0003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?o
oooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00?o0000ooooooooool08?ooool000oooooo00Co0000oooooooooooo00000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04
o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`00
0?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooooooo023ooooo000?ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooo
ooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooooooo
ool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool00ol0
003oooooooooo`0Pooooo`003oooool01?l0003oooooooooool00003ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo0000
0oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003oooo
o`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04
o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooooooo
ool08?ooool000oooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003o
ooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?o
oooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooo
ooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo023ooooo
000?ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo
00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003
ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo0000
0oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003oooo
o`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0Pooooo`003oooool0
1?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0
003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003o
ooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000?ooooo00?o0000ooooooooool08?ooool000oooooo00Co0000oooo
oooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooo
oooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo
00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`03o`000?oooooooooo023ooooo000?ooooo`04o`000?ooooooooooo`00
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000ooo
ool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool0
1?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00000oooool00ol0003oooooooooo`0Pooooo`003oooool01?l0003oooooooooool00003ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000
oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`00
0?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooo
oooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo
00?o0000ooooooooool08?ooool000oooooo00Co0000oooooooooooo00000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooooooo
o`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
0oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`00
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000ooo
ool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oo
oooooooo023ooooo000?ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co
0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000
oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0P
ooooo`003oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooo
ooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00000oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`;o000000?oooooo`00
0?ooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0Pooooo`00
3oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`00
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000ooo
ool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool0
1?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool08?ooool000oooooo00Co
0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000
oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`00
0?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooo
oooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`000003ooooo`03o`000?oooooooooo023ooooo000?ooooo`04o`000?oooooo
ooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00000oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooooooo
o`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
0oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`00
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000000oooool00ol0003oooooooooo`0Pooooo`003oooool01?l0003oooooooooool00003
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo
00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co
0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool08?ooool000oooooo00Co0000oooooooooooo00000oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oo
ooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool000000oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooo
ooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00000oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03
o`000?oooooooooo023ooooo000?ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool0
0003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?o
oooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo
00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooo
ooooo`0Pooooo`003oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`00
0?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oo
ooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool000000oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool08?oo
ool000oooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooooooo
ool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool0
0003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?o
oooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo023ooooo000?oooo
o`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04
o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`00
0?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0Pooooo`003oooool01?l0003o
ooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?o
oooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooo
ooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooooooo
ool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooooooool08?ooool000oooooo00Co0000oooooooooooo
00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003
ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo0000
0oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003oooo
o`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000003ooooo`03o`000?oooooooooo023ooooo000?ooooo`04o`000?ooooooooooo`0000?ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0
003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003o
ooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?o
oooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000ooo
ool00ol0003oooooooooo`0Pooooo`003oooool01?l0003oooooooooool00003ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooo
oooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo
00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003
ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooooooool08?ooool000oooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool0
1?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0
003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo
023ooooo000?ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`00
0?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooo
oooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooo
oooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0Pooooo`00
3oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`00
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000ooo
ool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool0
1?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool08?ooool000oooooo00Co
0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000
oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000000oooool2o`000003ooooool0003ooooo00;ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003o
ooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000?ooooo00?o0000ooooooooool08?ooool000oooooo00Co0000oooo
oooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooo
oooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo
00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`03o`000?oooooooooo023ooooo000?ooooo`04o`000?ooooooooooo`00
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000ooo
ool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool0
1?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00000oooool00ol0003oooooooooo`0Pooooo`003oooool01?l0003oooooooooool00003ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000
oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`00
0?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooo
oooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo
00?o0000ooooooooool08?ooool000oooooo00Co0000oooooooooooo00000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooooooo
o`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
0oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`00
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000ooo
ool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oo
oooooooo023ooooo000?ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co
0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000
oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0P
ooooo`003oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooo
ooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00000oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooooooo
o`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
0oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool08?ooool000oo
oooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo
00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co
0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo023ooooo000?ooooo`04o`00
0?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oo
ooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool000000oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooo
ooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`0Pooooo`003oooool01?l0003ooooooooo
ool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool0
0003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?o
oooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00?o0000ooooooooool08?ooool000oooooo00Co0000oooooooooooo00000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04
o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`00
0?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooooooo023ooooo000?ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooo
ooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooooooo
ool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool00ol0
003oooooooooo`0Pooooo`003oooool01?l0003oooooooooool00003ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo0000
0oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003oooo
o`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04
o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooooooo
ool08?ooool000oooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003o
ooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?o
oooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooo
ooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo023ooooo
000?ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo
00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003
ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo0000
0oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003oooo
o`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0Pooooo`003oooool0
1?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0
003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo000000?ooooo00Co0000oooooooooooo00000oooool01_l0003ooooooooooooooooo0000
ooooo`Co000000?o410@ooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooo
oooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`03o`000?oooooooooo023ooooo000?ooooo`04o`000?oooooooooo
o`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
0oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`00
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000ooo
ool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooooooo`0Pooooo`003_oooooXool002;ooooo000>ooooonSoo`00
8_ooool000oooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?o
oooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooo
ooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooooooo
ool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo023ooooo000?
ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo0000
0oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003oooo
o`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04
o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0Pooooo`003oooool01?l0
003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003o
ooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?o
oooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooo
ooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000?ooooo00?o0000ooooooooool08?ooool000oooooo00Co0000oooooooo
oooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo
00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003
ooooo`04o`000?ooooooooooo`0000?ooooo00Wo0000ooooooooooooooooo`000?ooooooEEEEofIV
I_l000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooooooo
o`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
0oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000002;ooooo000?ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooo
ooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooooooo
ool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool00ol0
003oooooooooo`0Pooooo`003oooool01?l0003oooooooooool00003ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo0000
0oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003oooo
o`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04
o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooooooo
ool08?ooool000oooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003o
ooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?o
oooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooo
ooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo023ooooo
000?ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo
00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003
ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo0000
0oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003oooo
o`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0Pooooo`003oooool0
1?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0
003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003o
ooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000?ooooo00?o0000ooooooooool08?ooool000oooooo00Co0000oooo
oooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooo
oooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo
00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003
ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooooooo`0Pooooo`003oooool01?l0003oooooooooool00003oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co
0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000
oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`00
0?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooo
oooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03
o`000?oooooooooo023ooooo000?ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool0
0003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?o
oooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo
00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0
8?ooool000oooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?o
oooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooo
ooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooooooo
ool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0Pooooo`003oooool0
1?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0
003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003o
ooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`03o`000?oooooooooo023ooooo000?ooooo`04o`000?oooooooooo
o`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
0oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`00
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000ooo
ool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool0
1?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool08?ooool000oooooo00Co0000oooooooooooo00000oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oo
ooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool000000oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooo
ooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00000oooool2o`000003ooooool0003ooooo00;ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooo
oooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`00
0?oooooooooo023ooooo000?ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo
00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co
0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool08?oo
ool000oooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooooooo
ool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool0
0003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?o
oooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0Pooooo`003oooool01?l0
003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003o
ooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?o
oooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooo
ooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`03o`000?oooooooooo023ooooo000?ooooo`04o`000?ooooooooooo`00
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000ooo
ool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool0
1?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0
003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
0002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?o
oooo00?o0000ooooooooool08?ooool000oooooo00Co0000oooooooooooo00000oooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooo
ooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00000oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooooooo
o`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
0oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`00
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooo
ooooo`0Pooooo`003oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`00
0?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oo
ooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool000000oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo023ooooo000?
ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo0000
0oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003oooo
o`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04
o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000?ooooo00?o0000ooooooooool08?ooool000oooooo00Co0000oooo
oooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooo
oooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo
00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003
ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooooooo`0Pooooo`003oooool01?l0003oooooooooool00003oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co
0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000
oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`00
0?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooo
oooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003o
ooooooooo`0Pooooo`003oooool01?l0003oooooooooool00003ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04
o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`00
0?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oo
ooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0Pooooo`003ooo
ool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool0
1?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0
003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000000oooool00ol0003oooooooooo`0Pooooo`003oooool01?l0003oooooooooool0
0003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?o
oooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo
00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co
0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool0
0ol0003oooooooooo`0Pooooo`003oooool01?l0003oooooooooool00003ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo
00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003
ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo0000
0oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003oooo
o`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04
o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0Poooo
o`003oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooooooo
o`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
0oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`00
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000ooo
ool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000000oooool00ol0003oooooooooo`0Pooooo`003oooool01?l0003ooooo
ooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooooooo
ool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool0
0003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?o
oooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
0oooool00ol0003oooooooooo`0Pooooo`003oooool01?l0003oooooooooool00003ooooo`05o`00
0?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooo
oooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooo
oooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo
00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003
ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`0Pooooo`003oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oo
ooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo0_l00000
0ooooooo0000ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003o
ooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool08?ooool000oo
oooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003o
ooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?o
oooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooo
ooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo023ooooo000?ooooo`04o`00
0?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo
00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003
ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo0000
0oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003oooo
o`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`0Pooooo`003oooool01?l0003ooooooooo
ool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0
003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003o
ooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00?o0000ooooooooool08?ooool000oooooo00Co0000oooooooooooo00000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04
o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooo
oooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo
00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooooooo023ooooo000?ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooo
ooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo0000
0oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooooooo023ooooo000?ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooooooo
ool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03
o`000?oooooooooo023ooooo000?ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool0
0003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?o
oooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`00
0?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooo
ooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo
00?o0000ooooooooool08?ooool000oooooo00Co0000oooooooooooo00000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
0_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooo
oooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`03o`000?oooooooooo023ooooo000?ooooo`04o`000?ooooooooooo`0000?ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo
00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`03o`000?oooooooooo023ooooo000?ooooo`04o`000?oooooooooo
o`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co
0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`00
0?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooo
ooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0Pooooo`003oooool01?l0003o
ooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003
ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo023ooooo000?ooooo`04o`00
0?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool000000oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool08?ooool000oooooo00Co
0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00000oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo0000
0oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo023ooooo000?
ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000
oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0P
ooooo`003oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ooooool08?ooool000oooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oo
ooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?o
oooo00?o0000ooooooooool08?ooool000oooooo00Go0000ooooooooooooooooo`000002ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000003ooooo`;o000000?oooooo`000?ooool00_ooool01Ol0003ooooo
oooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0
003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`03o`000?oooooooooo023ooooo000?ooooo`05o`000?ooooooooooooooool000000_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?oo
ooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04
o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool08?ooool000oooooo00Go0000ooooooooooooooooo`000002
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?oooooo
ooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`03o`000?oooooooooo023ooooo000?ooooo`05o`000?oooooooooooooo
ool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo0000
0oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0
003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
0002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000000oooool00ol0003oooooooooo`0Pooooo`003oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003o
ooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool0
0003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05
o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo023ooooo000?ooooo`05o`000?oo
ooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`00
0?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooooooo
o`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo
00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool08Oooool000oooooo00Go0000
ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co
0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooo
oooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003o
oooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000;ooooo00?o0000ooooooooool08Oooool000oooooo00Go0000oooo
ooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000
oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo
00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002oooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00000oooool01?l0003oooooooooool0000Sooooo`003oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003
ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`00
0?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?oooooooooo
ooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool00000
0oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00000_ooool00ol0003oooooooooo`0Qooooo`003oooool01Ol0003ooooooooooooooooo000000?o
oooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`00
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go
0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000002ooooo`03o`000?oooooooooo027ooooo000?ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo
00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002
ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`00
0?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?oooooooooo
ooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooo
ooooo`0000?ooooo00?o0000ooooooooool08Oooool000oooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00_ooool01?l0003ooooooooo
ool00003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co
0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooo
oooo00000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000;o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Go0000ooooooooooooooooo`00000Sooooo`003oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000ooooooooooooooooo`00
0003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo
000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
0_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0
003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oo
ooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
0002ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`00
0?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo000000;ooooo00Go0000ooooooooooooooooo`00000Sooooo`003oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo
00;ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool0
00000oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool0
1?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooo
oooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo
000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
0_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003oooo
o`04o`000?ooooooooooo`0000Cooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
0002ooooo`05o`000?ooooooooooooooool000008oooool000oooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool0
00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002
ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`00
0?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooo
oooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo0000
0oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002oooo
o`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00_ooool01?l0
003oooooooooool00003ooooo`03o`000?oooooooooo027ooooo000?ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooo
oooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`00
0?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooooooo
o`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
0_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`03o`000?oooooooooo027ooooo000?ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo
000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
0_ooool01Ol0003ooooooooooooooooo000000?ooooo0_l000000ooooooo0000ooooo`02ooooo`05
o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000
oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo
00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooo
oooooooo000000?ooooo00?o0000ooooooooool08Oooool000oooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00000oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooo
oooooooo00000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooooooooooooooo
o`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooo
oooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;o
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003ooooo`05o`000?oooooooooo
ooooool000000oooool00ol0003oooooooooo`0Qooooo`003oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooo
ooooo`00037oo`0000?oooooo`000?ooool00_ooool01?l0003oooooooooool00004ooooo`04o`00
0?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooooooo
o`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000004oooo
o`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`0Qooooo`003oooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
0002ooooo`05o`000?ooooooooooooooool000001?ooool01?l0003oooooooooool00003ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000
oooooooooooo00000oooool00ol0003oo`00ool00015ool00003ooooool0003ooooo00;ooooo00Go
0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000008oooool000oooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool0
1Ol0003ooooooooooooooooo000000Cooooo00Co0000oooooooooooo00000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oo003oo`00
017oo`000_ooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003o
oooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo
o`0001?oo`0000Goooooo`000?ooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go
0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000?ooooo00?o0000ooooooooool08Oooool000oooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oo`00ool0000>ool000;ooooo00Go
0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooo
oooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?o
oooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000
oooooooo00003ooo00000ooooooo0000ooooo`02ooooo`05o`000?ooooooooooooooool000000_oo
ool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000oooooooooooo
ooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
0oooool00ol0003oooooooooo`0Qooooo`003oooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`00000<ool000;ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooo
oooo000000;ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool0
00000oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000_ooool0
1Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01?l0003ooooo
ooooool00003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000oooooooo00002ooo00001Ooooooo0000oooooooooooo000000?ooooo00?o
0000ooooooooool00_ooool01?l0003oooooooooool00004ooooo`05o`000?ooooooooooooooool0
00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo
00?o0000ooooooooool08Oooool000oooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
00?ooooo00Go0000ooooooooooooooooo`000004ooooo`04o`000?ooooooooooo`0000?ooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oo003oo`0000[oo`000_ooool01Ol0003ooooo
oooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo
000000?ooooo00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0
003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01?l0003ooooooooo
ool00003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?ooooooo`0000coo`0000Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`00000Sooooo`003oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`000003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001?ooool01?l0
003oooooooooool00004ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooooooooooo
o`00000=ool00003ooooool0003ooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`04
o`000?ooooooooooo`0000Cooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool0
0002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;o
oooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool0
1?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooooooo
ooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000;ooooo00Ko0000ooooooooooooooooo`000?ooool<ool00003ooooool0003ooooo00;ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo027ooooo
000?ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Co
oooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`000003ooooo`04o`000?ooooooooooooooo`goo`000_ooool01Ol0003ooooooooo
oooooooo000000;ooooo00Go0000ooooooooooooooooo`000004ooooo`04o`000?ooooooooooo`00
00?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000ooo
ool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool000000oooool01?l0003o
ooooooooool00003ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000ooo
ool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000_ooool<ool00003oooo
ool0003ooooo00;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000002?ooooo000@ooooo`04o`000?oooooo
ooooo`0000?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool00ol0
003oo`00ool0000:ool000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooooooooooo
ooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo
000000;ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000;ooooo
00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0
003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oo
ooooooooo`0000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Go0000ooooooooooooooooo`000004ooooo`04o`000?ooooooooooo`0000?ooooo00?o
0000oooooooo00003?oo00001Ooooooo0000oooooooooooo000000?ooooo00Go0000oooooooooooo
ooooo`000004ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_ooool01Ol0
003ooooooooooooooooo000000;ooooo00?o0000ooooooooool08_ooool0013ooooo00Go0000oooo
ooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`00000<ool000;ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000001?ooool01?l0003oooooooooool0
0003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?o
oooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000_ooool0
1?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooo
oooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oooooooooo
ooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo0000
0oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooool0000<ool00005o`000?ooooooooooooooool0
00001?ooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000002Cooooo000@ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00000Aool000;o
oooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooooooooooo
o`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000_oo
ool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000002ooooo`05
o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000
ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo
00000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003
ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000?ooooo00?o0000oooooooo00003ooo0002ooooo`04o`000?ooooooooooo`0000?o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000009?ooool0
013ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000ooo
ool00ol0003oo`00ool0000;ool000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooo
ooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`00
00?ooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool00003ooooo`04o`000?oo
ooooooooo`0000?ooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool00003oooo
o`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooo
oooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`00
00?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03
o`000?oooooooooo00coo`0000?oooooo`000?ooool00_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`00000Tooooo`004?ooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ool00?oo00002ooo0002ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooo
oooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool00003
ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000oooool01?l0003ooooo
ooooool00003ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000oooool0
1?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooo
oooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo
000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?ooooooo`0000coo`0000?oooooo`000?ooool00_ooool01Ol0003ooooooooooooooooo
000002Cooooo000?oooooa?oo`000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooo
ooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000oooool01?l0003ooooooooo
ool00003ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000oooool00ol0
003oooooooooo`05o`0000;ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo
ooooo`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool0
00000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00001?ooool0
1?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooo
ooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
1?ooool00ol0003oo`00ool0000Aool002Cooooo000?ooooo`_oo`000_ooool01Ol0003ooooooooo
oooooooo000000Cooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo0000
00Cooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Go
0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000oooooooo
ooooooooo`000002ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool0
00000_ooool01Ol0003o8B4Qonk^k_oooooo000000;ooooo00Go0000ooooooooooooooooo`000002
ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`00
0?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooo
oooooooo00000oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00_oo
ool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Ko0000oooooooooooo
ooooo`000?ooool;ool002Cooooo000@ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0004ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000ooooooooooooooooo`000003ooooo`04
o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooooooooooo
ooooo`000002ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo
000000?ooooo00Co0000oooooooooooo00000_ooool01Ol0003oV9RHob4Q8Oo^k^ko000000;ooooo
00Co0000oooooooooooooooo0_l000001Ooooooo0000oooooooooooo000000?ooooo00Go0000oooo
ooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooo
oooooooo000000;ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo0000
00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00001?ooool01Ol0003o
oooooooooooooooo000000;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
0oooool00ol0003oooooooooo`0Rooooo`004?ooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00001?ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00004ooooo`04
o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oooooo
ooooooooool000000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooooooooooo
ooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000oooooonHV9So8B4Qo`000002
ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00003ooooo`05o`00
0?ooooooooooooooool000000_ooool01?l0003oooooooooool00003ooooo`05o`000?oooooooooo
ooooool000000_ooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool00000
0_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooooooo02;ooooo000@ooooo`05o`000?ooooooooooooooool000000oooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05
o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000;ooooo00Go0000ooooooooooooooooo`000002ooooo`08o`000?ooooooooooooooool0003o
ooooogMgMol00002ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool0
0002ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000_ooool01Ol0003ooooo
oooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oooooooooo
ooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo0000
0oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000001?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00;ooooo
00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo02;ooooo000Aooooo`05o`00
0?ooooooooooooooool000000_ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000001?ooool01?l0003oooooooooool00003ooooo`05
o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00003ooooo`05o`000?oooooo
ooooooooool000000oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo
00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo
00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooo
ooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooo
oooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`00
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03
o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`0Rooooo`004Oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000004ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool0
0003ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooo
ooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo00Ko0000oooooooooooooooo
o`000?ooool2o`000003oooooonHV9So000000;ooooo00Go0000ooooooooooooooooo`000002oooo
o`04o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oo
ooooooooo`0000;ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`00
00Cooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooo
oooooooo000000Cooooo00Go0000ooooooooooooooooo`00000Tooooo`004Oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04
o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooo
ooooooooool000000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooooooooooo
ooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo00Oo0000ooooooooooooooooo`000?oo
ooooV9RH00;o000000Go8B4Qo`000?ooooooooooo`000003ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000
oooooooooooo00000oooool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool0
00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000000oooool01?l0003oooooooooool00004ooooo`05o`00
0?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ooooool00_ooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000001?oo
ool01Ol0003ooooooooooooooooo000002Cooooo000Aooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo
00001?ooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000oooool0
1?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooo
oooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooooooo
o`0000;ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooo
ooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo0000
0oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooo
oooo000000Cooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_ooool01Ol0
003ooooooooooooooooo000002Cooooo000Aooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04
o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooo
ooooo`0000;ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;o
oooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000
ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooooooo
ooooo`000002ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`00
0?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooo
ooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000009?ooool0017ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooooooooooo
o`000002ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000002ooooo`05
o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000
ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo00Co0000oooooooooooo
00000_ooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000?o
oooo00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000
ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003ooooo
ooooool00004ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooo
oooo000002Cooooo000Aooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo000000Cooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00001?ooool01?l0003ooooo
ooooool00003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000002
ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`05o`00
0?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`05o`000?oooooooooo
ooooool000000_ooool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool00000
0_ooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000
ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`000003ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo0000
02Cooooo000Aooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000Cooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
0oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooo
ooooo`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool0
00000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01Ol0003ooooo
oooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo
000000;ooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo
000000;ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool00000
0_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0
8_ooool0017ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oo
ooooooooooooool000001?ooool01?l0003oooooooooool00003ooooo`05o`000?oooooooooooooo
ool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000_oo
ool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01Ol0003o
oooooooooooooooo000000;ooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`000002ooooo`04
o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool0
0003ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000Cooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool00000
1?ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000004oooo
o`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0Rooooo`004_ooool01Ol0
003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool0
00001?ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00_ooool01Ol0
003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0003ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000_ooool01Ol0003o
oooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?oooooo
ooooo`0000;ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00003ooooo`03o`000?oooooo
000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo
00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Co
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000001?ooool0
1Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool08oooool001;ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000ooo
ool01?l0003oooooooooool00004ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooo
oooo00000oooool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool000000ooo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00003ooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooo
00000oooool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool000000_ooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooooooooooo
o`000003ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000000oooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooooooo
ooooo`00000Uooooo`004_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000004ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooo
oooooooo000000;ooooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002oooo
o`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo0000
00?ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000Cooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00000Uooooo`004_ooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`00
0?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000
ooooooooool00_ooool01?l0003oooooooooool00004ooooo`04o`000?ooooooooooo`0000;ooooo
00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000oooo
ooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000oooooooooooooooo
o`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
0_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000oooool01?l0
003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000003ooooo`05o`00
0?ooooooooooooooool000001?ooool00ol0003oooooooooo`0Sooooo`004_ooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oooooooooo
ooooool000000oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001?oo
ool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000;ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00003oooo
o`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000_ooool01Ol0003ooooooooo
oooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo0000
00;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002oooo
o`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00002ooooo`05o`000?oo
ooooooooooooool000000_ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?o
oooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool0
1Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`00
0?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooo
ooooooooooooo`000004ooooo`03o`000?oooooooooo02?ooooo000Booooo`05o`000?oooooooooo
ooooool000000oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000ooo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo0000
00?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Co
0000oooooooooooo00000oooool01?l0003oooooooooool00002ooooo`05o`000?oooooooooooooo
ool000000_ooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooooooo`02o`000005ooooool0003oooooooooool0
00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000
oooooooooooo00000oooool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool0
00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00000oooool0
1Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00004ooooo`05o`000?oooooooooo
ooooool000001?ooool00ol0003oooooooooo`0Sooooo`004_ooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0
003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oo
ooooooooooooool000000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002oooo
o`03o`000?oooooo000000?ooooo00?o0000ooooool000000oooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooooooooooo
o`000004ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000
ooooooooool08oooool001;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00004ooooo`05o`000?ooooooooooooooool000000_ooool00ol0
003oooooooooo`02ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00000ooo
ool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooo
oooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co
0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo000000?o
oooo00?o0000ooooool000000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooo
oooooooo00000oooool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003oooo
o`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooooooo
ooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0Soooo
o`004_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooo
oooo000000?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo
00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0
003oooooooooool00003ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo0000
0_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo000000?ooooo00?o0000ooooool0
00000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool0
1Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`00
0?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000?ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo02Co
oooo000Booooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`03
o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooool000000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo000000?ooooo00?o
0000ooooool000000_ooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oooooooooo
ooooool000001?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000ooo
ool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool09?ooool001?ooooo00Go
0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`000003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool00000
0_ooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000002oooo
o`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0
003oooooooooool00002ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool01?l0003ooooo
ooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool0
1?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooo
ooooool00003ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo
000000?ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool00000
1?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000oooooooo
ooooooooo`000004ooooo`03o`000?oooooooooo02Cooooo000Cooooo`05o`000?oooooooooooooo
ool000000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0003ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000?o
oooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000
oooooooooooo00000oooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`0000?o
oooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`000002ooooo`04o`000?oooooooooo
o`0000;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oooooo000000;ooooo
00Ko0000oooooooooooo0000ooooool00002ooooo`05o`000?ooooooooooooooool000000_ooool0
1?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000oooooooooooo
ooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo
000000?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool0
0_ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004oooo
o`03o`000?oooooooooo02Cooooo000Cooooo`05o`000?ooooooooooooooool000000oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000004
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
00000oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000000_ooool0
1ol0003ooooooooooooooooo0000ooooool000000_ooool01?l0003oooooooooool00003ooooo`04
o`000?ooooooooooo`0000;ooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oo
oooo000000;ooooo00?o0000ooooool000000_ooool01_l0003oooooooooool0003oooooo`0000?o
oooo00?o0000ooooool000000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool00000
0oooool01?l0003oooooooooool00004ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000oooo
ooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo02Co
oooo000Cooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo0000
00Cooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooo
oooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`000?oooooooooo
o`0000?ooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool00002ooooo`04o`00
0?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01_l0003oooooooooool0003o
ooooo`0000?ooooo00?o0000ooooool000000_ooool00ol0003oooooo`000002ooooo`06o`000?oo
ooooooooo`000?oooooo00000oooool00ol0003oooooo`000002ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool00002ooooo`05o`000?oo
ooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooooooo
ooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Tooooo`004oooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000001?ooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`00
0004ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`06
o`000?ooooooooooo`000?oooooo00000_ooool00ol0003oooooo`000002ooooo`06o`000?oooooo
ooooo`000?oooooo00000_ooool01?l0003oooooooooool00002ooooo`04o`000?ooooooooooo`00
00;ooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000?ooooo00Co0000oooooooooooo00001?ooool01Ol0003ooooooooooooooooo0000
00?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000004ooooo`03
o`000?oooooooooo02Gooooo000Cooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`000004ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001?ooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooo
oooo000000Cooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00000oooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000
ooooool000000_ooool01?l0003oooooooooool00003ooooo`06o`000?ooooooooooo`000?oooooo
00000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo000000;ooooo00?o0000oooo
ool000000_ooool01_l0003oooooooooool0003oooooo`0000;ooooo00?o0000ooooool000000_oo
ool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003o
ooooooooool00002ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003ooooooooooooo
oooo000000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo
00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`000004ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0Uooooo`004oooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooooooo
o`02ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooo
ooooooooooooo`000004ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo0000
0oooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooo
oooooooo00000_ooool01_l0003oooooooooool0003oooooo`0000;ooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooo`000002ooooo`03o`000?oooooo000000;ooooo00Ko0000oooooooo
oooo0000ooooool00002ooooo`03o`000?oooooo000000;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000oooooooo
ooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo
00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooooooo
ool00_ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004
ooooo`03o`000?oooooooooo02Gooooo000Cooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0004ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`00
0?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000oooo
ooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooooooo
ool00003ooooo`03o`000?oooooo000000;ooooo00Co0000oooooooooooo00000_ooool01_l0003o
ooooooooool0003oooooo`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`00
0002ooooo`03o`000?oooooo000000;ooooo00?o0000ooooool000000_ooool01_l0003ooooooooo
ool0003oooooo`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000ooooooooooooooooo`000003ooooo`04o`00
0?ooooooooooo`0000Cooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`02ooooo`05o`000?oooooo
ooooooooool000001?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool00000
1?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool09Oooool001?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
00001?ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool00_ooool01Ol0
003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooo
oooo00000oooool01?l0003oooooooooool00003ooooo`06o`000?ooooooooooo`000?oooooo0000
0_ooool01?l0003oooooooooool00002ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool0
0ol0003oo`00ool0000<ool00004o`000?ooooooooooo`0000;ooooo00?o0000ooooool000000_oo
ool01?l0003oooooooooool00002ooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooo
00000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000001?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
00001?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool09Oooool001Co
oooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000001?ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooo
oooooooo000000Cooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000_oo
ool01?l0003oooooooooool00002ooooo`03o`000?oooooo000000;ooooo00Co0000oooooooooooo
00006?oo00001?l0003oooooooooool00002ooooo`03o`000?oooooo000000;ooooo00Co0000oooo
oooooooo00000_ooool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool00000
0oooool01Ol0003ooooooooooooooooo000000?ooooo00Co0000oooooooooooo00001?ooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`03ooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool09Oooool001Cooooo00Go0000ooooooooooooooooo`000004ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Co
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooo
ooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooo
oooooooo000000?ooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo0000
00;ooooo00?o0000ooooool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooo
oooo00Woo`0000Coooooo`000?oooooo00000_ooool00ol0003oooooo`000002ooooo`03o`000?oo
003oo`0000Koo`0000Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`04
o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool0
0003ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Co
oooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`0Uooooo`005?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001?oo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000Cooooo00Co0000oooooooooooo00000oooool01?l0003oooooooooool00002ooooo`06o`00
0?ooooooooooo`000?oooooo00000_ooool00ol0003oo`00ool00007ool00004ooooool0003ooooo
o`0000;ooooo00?o0000ooooool000000_ooool00ol0003oooooo`000002ooooo`06o`000?oooooo
0000ooooool0003ooooo2?oo00001ooooooo0000oooooooooooo0000ooooool000000_ooool01ol0
003ooooooooooooooooo0000ooooool000000oooool01?l0003oooooooooool00004ooooo`05o`00
0?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooo
ooooooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0004ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`00
0?ooooooooooooooool000001?ooool00ol0003oooooooooo`0Vooooo`005?ooool00ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000
ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool000000oooool01?l0003ooooo
ooooool00003ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooo`000002oooo
o`03o`000?oo003oo`0000Koo`0000Ooooooo`000?ooooooooooo`000?oooooo000000;ooooo00?o
0000ooooool000000_ooool3o`0000;ooooo00Go0000ooooool0003oooooo`000002ooooo`03o`00
0?oo003oo`0000Koo`0000Goooooo`000?ooooooooooo`000002ooooo`04o`000?ooooooooooo`00
00;ooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000001?oo
ool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`000004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000000Gooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oooooo
ooooooooool000001?ooool00ol0003oooooooooo`0Vooooo`005?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000001?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
00000oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000oooool01?l0
003oooooooooool00003ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000ooooool0003ooooo
1Ooo0002ooooo`03o`000?oooooo000000;ooooo00?o0000ooooool000000_ooool01Ol0003ooooo
o`000?oooooo000000;ooooo00Go0000ooooool0003oooooo`000002ooooo`05o`000?oooooo0000
ooooool000000_ooool01?l0003oooooo`000?ooool6ool00004ooooool0003oooooo`0000?ooooo
00?o0000ooooool000000oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`00
0004ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Vooooo`005?oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooo
oooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?oooooooooo
ooooool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Go0000oooooooooooooooo
o`000002ooooo`03o`000?oo003oo`0000?oo`0000Goooooo`000?ooooooooooo`000002ooooo`05
o`000?oooooo0000ooooool000000_ooool01Ol0003oooooo`000?oooooo000000;ooooo00Oo0000
ooooool0003oooooo`000?oooooo000000;ooooo00Go0000ooooool0003oooooo`000002ooooo`04
o`000?ooooooooooo`0000Goo`000_ooool01?l0003oooooooooool00002ooooo`04o`000?oooooo
ooooo`0000?ooooo00Go0000ooooooooooooooooo`000004ooooo`04o`000?ooooooooooo`0000?o
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Kooooo000Dooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00Go0000
ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooo
oooooooooooo000000;ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo
00Coo`0000Ooooooo`000?ooooooooooo`000?oooooo000000;ooooo00?o0000ooooool000000_oo
ool01ol0003oooooo`000?oooooo0000ooooool000000_ooool02Ol0003oooooo`000?oooooo0000
ooooool0003oooooo`000002ooooo`03o`000?oooooo000000;ooooo00?o0000ooooool000000_oo
ool00ol0003oooooool00002ool00007o`000?ooooooooooooooool0003oooooo`000003ooooo`04
o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00004
ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Gooooo
00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0Vooooo`005?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`000004ooooo`04o`000?ooooooooooo`0000Cooooo00Co0000
oooooooooooo00000_ooool01?l0003oooooooooooooool4ool00004ooooool0003oooooo`0000;o
oooo00So0000oooooooooooo0000ooooool0003oooooo`0000;ooooo00?o0000ooooool000000_oo
ool01?l0003oooooo`000?ooool2o`0000;ooooo00Go0000ooooool0003oooooo`000002ooooo`05
o`000?oooooo0000ooooool000000_ooool01_l0003oooooooooool0003oooooo`0000Coo`0000Go
ooooo`000?ooooooooooo`000002ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000oooooooo
ooooooooo`000003ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0003ooooooooooooo
oooo000000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Cooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Kooooo
000Eooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?oooooooooooooo
ool000000oooool01Ol0003ooooooooooooooooo000000;ooooo00Ko0000ooooooooooooooooo`00
0?ooool4ool00003o`000?oooooo000000;ooooo00Ko0000oooooooooooo0000ooooool00002oooo
o`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`04o`000?oooooo0000ooooo`;o0000
0_ooool02Ol0003oooooo`000?oooooo0000ooooool0003oooooo`000002ooooo`03o`000?oooooo
000000;ooooo00Go0000oooooooooooo0000ooooo`04ool00003o`000?oooooo000000?ooooo00Co
0000oooooooooooo00000oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Co
oooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000oooo
ooooooooooooo`000004ooooo`03o`000?oooooooooo02Oooooo000Eooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00;ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000oooooooooooooooo
o`000003ooooo`04o`000?ooooooooooo`0000;ooooo00Oo0000ool00?oo003oo`00o`000?oooooo
000000;ooooo00?o0000ooooool000000_ooool00ol0003oooooo`000002ooooo`05o`000?oooooo
0000ooooool000000_ooool01_l0003oooooo`000?oooooo0000ooooo`;o00000_ooool02Ol0003o
ooooo`000?oooooo0000ooooool0003oooooo`000002ooooo`03o`000?oooooo000000;ooooo00?o
0000ooooool000000_ooool00ol0003oooooool00002ool00005ooooool0003oooooooooool00000
0_ooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000003oooo
o`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Gooooo00Go
0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0Wooooo`005Oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`05o`000?ooooooooooooooool0
00000oooool01Ol0003oooooooooool0003ooooo00Coo`0000Goooooo`000?ooooooooooo`000002
ooooo`05o`000?oooooo0000ooooool000000_ooool01ol0003oooooo`000?oooooo0000ooooool0
00000_ooool01_l0003oooooo`000?oooooo0000ooooo`;o00000_ooool02ol0003oooooo`000?oo
oooo0000ooooool0003oooooo`000?oooooo000000;ooooo00?o0000ooooool000000_ooool00ol0
003oooooo`000002ooooo`03o`000?oo003oo`0000?oo`0000Goooooo`000?ooooooooooo`000003
ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003ooooooooooooooooo000000Gooooo
00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooo
ooooooooo`000004ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`0Wooooo`005Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Ko0000ooooooooooooooooo`00
0?ooool5ool000?ooooo00So0000oooooooooooo0000ooooool0003oooooo`0000;ooooo00?o0000
ooooool000000_ooool03?l0003oooooo`000?oooooo0000ooooool0003oooooo`000?oooooo0000
ooooo`;o000000Coooooo`000?oooooooooo0_l000001?oooooo0000ooooool00002ooooo`03o`00
0?oooooo000000;ooooo00Go0000ooooool0003oooooo`000003ooooo`03o`000?ooooooo`0000Co
o`000_ooool01Ol0003ooooooooooooooooo000000Cooooo00Co0000oooooooooooo00001?ooool0
0ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool09oooool001Gooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001?oo
ool01?l0003oooooooooool00004ooooo`Coo`000_ooool01?l0003oooooooooool00002ooooo`08
o`000?ooooooooooo`000?oooooo0000ooooool00002ooooo`0>o`000?oooooo0000ooooool0003o
ooooo`000?oooooo0000ooooool0003oooooo`000?ooool2o`000004ooooool0003oooooooooo`;o
000000Koooooo`000?oooooo0000ooooool00002ooooo`03o`000?oooooo000000;ooooo00?o0000
ooooool000000_ooool01?l0003oooooooooool00002ooooo`?oo`0000?o0000ooooooooool00_oo
ool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000005ooooo`05
o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00?ooooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool09oooool001Kooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo
000000Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00?oo`0000?o
ooooo`000?ooool00_ooool01?l0003oooooooooool00002ooooo`05o`000?oooooo0000ooooool0
00000_ooool04?l0003oooooo`000?oooooo0000ooooool0003oooooo`000?oooooo0000ooooool0
003oooooo`000?ooool2o`000004ooooool0003oooooooooo`;o000000Soooooo`000?oooooo0000
ooooool0003oooooo`0000;ooooo00Go0000ooooool0003oooooo`000003ooooo`03o`000?oooooo
000000?ooooo00?o0000ool00?oo00000_oo0002ooooo`05o`000?ooooooooooooooool000000ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooooooo
o`000005ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`0Xooooo`00
5_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000004oooo
o`05o`000?ooooooooooooooool000000ooo00001?l0003oooooooooool00002ooooo`04o`000?oo
ooooooooo`0000;ooooo00[o0000oooooooooooo0000ooooool0003oooooo`000?oooooo00000_oo
ool2o`000009ooooool0003oooooo`000?oooooo0000ooooool0003ooooo00;o000000Ooooooo`00
0?oooooo0000ooooool0003ooooo00;o00000_ooool01Ol0003oooooo`000?oooooo000000;ooooo
00?o0000ooooool000000_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00Co
o`0000?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000oooo
ooooool00oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool0
1Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo02Sooooo000Fooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000
ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000000_ooool4ool00003oooo
ool0003ooooo00;ooooo00Co0000oooooooooooo00000_ooool02?l0003oooooooooool0003ooooo
o`000?oooooo00000_ooool01_l0003oooooo`000?oooooo0000ooooo`;o00000_ooool2o`000003
ooooool0003ooooo00;o000000Goooooo`000?oooooo0000ooooo`02o`000006ooooool0003ooooo
o`000?oooooo00000_ooool01Ol0003oooooo`000?oooooo000000;ooooo00Co0000oooooooooooo
00000oooool01Ol0003oooooooooool0003ooooo00?oo`000oooool01Ol0003ooooooooooooooooo
000000Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oooooo
ooooooooool000001Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Sooooo000F
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooooooool000001?oo0003ooooo`04o`000?ooooooooooo`0000?ooooo
00Co0000oooooooooooo00000_ooool01?l0003oooooo`000?l00002ooooo`06o`000?oooooo0000
ooooool0003ooooo0_l00002ooooo`;o000000?oooooo`000?ooool00_l000001Ooooooo0000oooo
ool0003ooooo00;o000000Koooooo`000?oooooo0000ooooool00002ooooo`04o`000?oooooo0000
o`0000?ooooo00?o0000ooooool000000oooool01?l0003oooooooooool00003ooooo`?oo`0000?o
ooooo`000?ooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go
0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`0Xooooo`005_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oo
ooooooooooooool000001?ooool01?l0003oooooooooooooool3ool00003ooooool0003ooooo00?o
oooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002ooooo`09o`000?oooooo
0000ooooool0003oooooo`000?oooooo000000;ooooo0_l000000ooooooo0000ooooo`02o`000003
ooooool0003ooooo00;o000000?oooooo`000?ooool00_l000000ooooooo0000o`000002ooooo`09
o`000?oooooo0000ooooool0003oooooo`000?oooooo000000;ooooo00Co0000oooooooooooo0000
0_ooool01?l0003oooooooooool00004ooooo`05o`000?oo003oo`00ool00?l000000oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000005
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0X
ooooo`005_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001Oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool0
0ol0003oooooool00002ool000?ooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool0
0002ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000ooooool0003o00000_ooool01?l0003o
ooooo`000?ooool2o`000003ooooool0003ooooo00;o000000?oooooo`000?ooool00_l000000ooo
oooo0000ooooo`02o`000007ooooool0003o0000ooooool0003oooooo`000002ooooo`04o`000?oo
oooo0000o`0000?ooooo00?o0000ooooool000000oooool00ol0003oooooo`000004ooooo`03o`00
0?oooooooooo00?oo`000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001Oooool00ol0
003oooooooooo`0Xooooo`005oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00Go0000ooooooooooooooooo`000003ool00003ooooool0003ooooo00;ooooo00Go0000oooo
ooooooooooooo`000003ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool00ol0003ooooo
ooooo`02o`000007ooooool0003oooooo`000?oooooo0000ooooo`02o`000006ooooool0003o0000
ooooool0003ooooo0_l000000ooooooo0000ooooo`03o`00000<ooooool0003oooooo`000?oooooo
0000ooooool0003oooooo`000?oooooo00000_ooool00ol0003oooooo`000003ooooo`04o`000?oo
ooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ool00003ooooool0003ooooo00;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02Wo
oooo000Gooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`04ool000;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000;o
oooo00Co0000oooooooooooo00000_ooool01Ol0003oooooooooool0003ooooo00;o00000_ooool0
1?l0003oooooo`000?ooool3o`000003ooooool0003ooooo00;o000000Ooooooo`000?l0003o0000
ooooool0003ooooo00?o000000Coooooo`000?oooooo00000_ooool01?l0003oooooo`000?l00002
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000oooool00ol0003ooooo
ooooo`02ooooo`03o`000?ooooooo`0000?oo`000oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool0:Oooool001Oooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000;oo`0000Go0000oooooooooooooooo
o`000004ooooo`05o`000?ooooooooooooooool000000_ooool01_l0003oooooooooool0003ooooo
o`0000?ooooo00Wo0000ooooool0003o0000ooooool0003oooooo`000?ooool00ol00002ooooo`?o
000000Ooooooo`000?l0003o0000ooooool0003ooooo00?o000000Ooooooo`000?oooooo0000oooo
ool0003ooooo00;o00000oooool00ol0003oooooo`000002ooooo`04o`000?ooooooooooo`0000Co
oooo00Go0000ooooooooooooooooo`000003ooooo`Coo`0000?oooooo`000?ooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo02Wooooo000Gooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooooooo1?oo0003ooooo`05o`000?ooooooooooooooool000000oooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooool000000_ooool01?l0003ooooo
o`000?l00002ooooo`05o`000?oooooo0000o`000?ooool00_l000001Ooooooo0000o`000?l0003o
oooo00?o000000Ooooooo`000?l0003o0000ooooool0003ooooo00;o00000_ooool01?l0003ooooo
o`000?l00002ooooo`03o`000?oooooo000000?ooooo00?o0000ooooool000001?ooool01Ol0003o
oooooooooooooooo000000?ooooo00?o0000ooooooooool01?oo0004ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool0:Oooool001Oooooo00?o0000ooooooooool00oooool01Ol0003o
oooooooooooooooo000000Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooool00003ool0
00Cooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00Wo0000
ooooooooooooooooo`000?oooooo0000ooooool000000oooool02Ol0003oooooo`000?l0003ooooo
o`000?oooooo0000ooooo`03o`000005ooooool0003o0000o`000?ooool00ol000000ooooooo0000
o`000002o`000007ooooool0003oooooo`000?oooooo0000ooooo`02o`0000?ooooo00?o0000oooo
ool000000_ooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool000001?oo
ool01?l0003oooooooooooooool4ool000;ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`05o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`0Yooooo`00
6?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`?oo`000_ooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000001?ooool01Ol0003ooooooooooooooooo000000;ooooo00Ko0000oooo
oooooooo0000ooooool00002ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooool00000
0ol000001?oooooo0000o`000?ooool2o`000003ooooool0003ooooo00Co000000?oooooo`000?l0
00000_ooool2o`000007ooooool0003oooooooooool0003oooooo`000002ooooo`04o`000?oooooo
ooooo`0000?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo
00?o0000oooooooo00000_oo00000ooooooo0000ooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02[ooooo
000Hooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00;ooooo0ooo0004ooooo`03o`000?oooooooooo00;ooooo00Go
0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000000_ooool01_l0003o
ooooooooool0003oooooo`0000;ooooo00Wo0000ooooool0003o0000ooooool0003oooooo`000?oo
ool00_l000001?oooooo0000o`000?ooool2o`000006ooooool0003o0000ooooool0003ooooo0_l0
00001Ooooooo0000ooooool0003ooooo00;o00000_ooool00ol0003oooooo`000003ooooo`03o`00
0?oooooo000000Cooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool01?oo0004ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo02[ooooo000Hooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?oo`0000?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`00
0?ooooooooooooooool000001?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooo0000
00;ooooo00Go0000oooooooooooo0000ooooo`02o`000003ooooool0003ooooo00Ko000000Cooooo
o`000?l0003ooooo1Ol000001_oooooo0000o`000?oooooo0000ooooo`;o00000_ooool01?l0003o
ooooooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`00
0003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool4ool000;ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00Go
0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
:_ooool001Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00;ooooo00?o0000oooooooo00000_oo00000ooooooo0000ooooo`04ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo
00Oo0000ooooooooooooooooo`000?oooooo000000;ooooo00Co0000ooooool0003ooooo0_l00000
1Ooooooo0000ooooool0003ooooo00;o000000?oooooo`000?ooool00_l000000ooooooo0000o`00
0004o`000003ooooool0003ooooo00;o000000Coooooo`000?oooooo00000_ooool01?l0003ooooo
ooooool00002ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooool00002ool0
0003ooooool0003ooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo02[ooooo000Hooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool01?l0003oooooooooooooool4ool000?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooo
oooo000000;ooooo00Ko0000oooooooooooo0000ooooool00002ooooo`05o`000?oooooo0000o`00
0?ooool00_l000001_oooooo0000o`000?oooooo0000ooooo`;o000000?oooooo`000?l000001Ol0
00000ooooooo0000ooooo`02o`0000;ooooo00?o0000ooooool000000oooool00ol0003oooooo`00
0004ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooooooo1?oo0003ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`0Zooooo`006?ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo00001?oo0005ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Co
oooo00Go0000ooooooooooooooooo`000002ooooo`06o`000?ooooooooooo`000?oooooo00000_oo
ool00ol0003oooooo`000002ooooo`Ko000000Coooooo`000?l0003ooooo1?l000001?oooooo0000
o`000?ooool3o`0000;ooooo00?o0000ooooool000000oooool00ol0003oooooo`000004ooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00;ooooo00?o0000ooooooooool00oooool4ool000;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo02[ooooo000Iooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool4ool00003ooooool0003ooooo00Cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00_ooool01?l0003oooooooooool00003ooooo`06o`000?ooooooooooo`000?oooooo00000_oo
ool3o`000004ooooool0003o0000ooooo`co000000[oooooo`000?l0003o0000ooooool0003ooooo
o`000?oooooo00000oooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool0
00001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooool00002ool00003o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`0[ooooo`006Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`04o`00
0?ooooooooooooooo`Coo`001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo00000oooool02Ol0003oooooooooool0003oooooo`000?oooooo0000
ooooo`02o`000003ooooool0003o000000oo000000Coooooo`000?oooooo00000_ooool01?l0003o
ooooooooool00002ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Coo`001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo02_ooooo000Iooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ool00?oo00000ooo00000ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001?ooool01Ol0003ooooooooooooo
oooo000000?ooooo00_o0000oooooooooooo0000ooooool0003oooooo`000?oooooo0000ooooo`02
o`000003ooooool0003o000000So000000?oooooo`000?l000000_l000001Ooooooo0000oooooooo
oooo000000;ooooo00Co0000oooooooooooo00001?ooool01Ol0003ooooooooooooooooo000000?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00_ooool6ool00003ooooool0003ooooo00Cooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool0:oooool001Wooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00_ooool5ool000;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool01Ol0003ooooooooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000002oooo
o`04o`000?ooooooooooooooo`;o00000_ooool3o`000003ooooool0003o000000go000000Kooooo
o`000?oooooo0000ooooool00002ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000oooooooo
ooooooooo`000003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo00001Ooo0004oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo02_ooooo000Iooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Goo`001Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003o
oooooooooooooooo000000;ooooo00_o0000oooooooooooo0000ooooool0003oooooo`000?oooooo
0000ooooo`0>o`000006ooooool0003oooooo`000?oooooo00000_ooool01?l0003oooooooooool0
0004ooooo`05o`000?ooooooooooooooool000001?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00?ooooo1Ooo0002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02_ooooo000Iooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`Goo`0000?o
ooooo`000?ooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000;ooooo00Oo0000oooooooooooo
0000ooooool0003ooooo00?o000000?oooooo`000?l000002ol000001Ooooooo0000o`000?oooooo
000000;ooooo00Co0000oooooooooooo00001?ooool01Ol0003ooooooooooooooooo000000Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oo003oo`0000;oo`00
00?oooooo`000?ooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool0:oooool001Wooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`03ooooo`04o`000?ooooooooooooooo`Goo`001?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000005ooooo`05o`000?oooooooooooooo
ool000000_ooool01ol0003oooooooooool0003oooooo`000?ooool03ol000000ooooooo0000o`00
0002ooooo`06o`000?ooooooooooo`000?oooooo00001?ooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000001Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`04ooooo`04o`000?oooooooooo
ooooo`Coo`001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0:oooool001[ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04oooo
o`03o`000?oo003oo`0000?oo`001_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00?ooooo00Go0000ooooooooooooooooo`000004ooooo`05o`000?ooooooooooooooool000000ooo
ool01ol0003oooooooooool0003oooooo`000?ooool00_l000000ooooooo0000o`000008o`000003
ooooool0003o000000;ooooo00Co0000oooooooooooo00000_ooool01Ol0003ooooooooooooooooo
000000Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00_ooool5ool00003ooooool0003ooooo00Gooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`0/ooooo`006_ooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00?ooooo1?oo0002ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooooooo0_l0
00000ooooooo0000o`00000;o`000005ooooool0003o0000ooooool000000_ooool01?l0003ooooo
ooooool00003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooool00003ool00003o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003o
ooooooooo`0/ooooo`006_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooooooo`Co
o`001?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooo
ooooooooo`000002ooooo`04o`000?ooooooooooooooo`;o000000Coooooo`000?l0003ooooo2?l0
00001Ooooooo0000o`000?oooooo000000;ooooo00Co0000oooooooooooo00000oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooooooo1Ooo0004oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0;?ooool001[ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01?ooool00ol0003oo`00ool00004ool00003o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000_ooool01?l0
003oooooooooooooool2o`000003ooooool0003o000000Oo000000Goooooo`000?l0003oooooo`00
0002ooooo`04o`000?ooooooooooo`0000Cooooo00Go0000ooooooooooooooooo`000004ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo1ooo00000ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02co
oooo000Jooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00;ooooo1_oo0002ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool0
00000_ooool01Ol0003oooooooooool0003ooooo00[o000000Ooooooo`000?ooooooooooo`000?oo
oooo000000;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Gooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool00oooool00ol0003oooooooooo`06ool000Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
;?ooool001[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00?ooooo00?o0000oooooooo00001Ooo0005ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooo`000002o`000003ooooool0003o000000;o000000Ooooooo`000?oo
ooooooooo`000?oooooo000000;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000000Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`Koo`0000?o
ooooo`000?ooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0;?ooool001[ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00;ooooo1ooo00000ooooooo0000ooooo`05ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00;ooooo00?o0000ooooool000000oooool2o`000003ooooool0003o000000?o000000Gooooo
o`000?l0003oooooo`000002ooooo`03o`000?oooooo000000Cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Ooo
ool00ol0003oo`00ool00005ool000Cooooo00?o0000ooooooooool00oooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo02cooooo000Kooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooool00006ool000Gooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooooooo0_l000000ooooooo0000
o`000004o`000005ooooool0003oooooooooool000000_ooool01Ol0003ooooooooooooooooo0000
00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00_ooool7ool00003ooooool0003ooooo00?ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`0]ooooo`006oooool00ol0003oooooooooo`03ooooo`03
o`000?ooooooo`0000Soo`0000?oooooo`000?ooool01Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`05
o`000?ooooooooooooooool000000_ooool01?l0003oooooooooooooool7o`000005ooooool0003o
ooooooooool000000_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0oooool00ol0003oooooool00007ool000;ooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`0]ooooo`006oooool01?l0003oooooooooooooool:ool000Cooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003o
ooooooooool0003ooooo00Co000000Goooooo`000?ooooooooooo`000002ooooo`05o`000?oooooo
ooooooooool000001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo2_oo
0003ooooo`03o`000?oooooooooo02gooooo000Kooooo`03o`000?oo003oo`0000Koo`000oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00
0004ooooo`04o`000?ooooooooooo`0000;ooooo1_l00002ooooo`04o`000?ooooooooooo`0000Co
oooo00Go0000ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool02Ooo00000ol0003oooooooooo`0]ooooo`006oooool5ool00003ooooool0003ooooo00Co
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`05o`000?oooooooooooooo
ool000001?ooool01Ol0003oooooooooool0003ooooo00Ko000000Goooooo`000?ooooooooooo`00
0004ooooo`05o`000?ooooooooooooooool000001_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00?ooooo00?o0000oooooooo00001?oo000_ooooo`006oooool2ool000Gooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00Go
0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00So00000oooool01Ol0003ooooo
oooooooooooo000000?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool2ool002oooooo000Looooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooo000000Oo00000_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`0^ooooo`007?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`05o`00
0?oooooooooooooooonHV9P00_l000000olb<S;oc<c<ooooo`0;o`0000?ooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo02kooooo000Looooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo00?ooooo00Wo0000oooooooooooo410@okZj^_l0003oMgMgoc8b<_ooool02_l00003
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0^
ooooo`007?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo3_l000000ooo
oooo0000ooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0;_ooool001go
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool00oooool01Ol0003oooooooooooooooooZJVY00ko00001?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo02oooooo000Mooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooo410@1?l000000ooooooo0000o`000004o`000004ooooool0003o0000
o`0000Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0_ooooo`007Oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`03ooooo`03o`000?oooooooooo013o00000_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo02oooooo000Mooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o410@o`000?l0
00004_l00005ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo02oooooo000Mooooo`03o`000?oooooooooo00?ooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`06o`000?oooooooooooooooonY
ZJWo410@1?l000001?oooooo0000o`000?ooool:o`0000Gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0;oooool0
01kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Cooooo00Co0000oooooooooooooooo2ol000001?oooooo0000o`000?ooool5o`0000Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool0<?ooool001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02Ol000000ooooooo0000o`000005
o`000004ooooool0003o0000o`0000;ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0<?ooool001kooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00Co0000
ooooool0003ooooo0ol000000ooooooo0000o`000008o`000003ooooool0003o000000Go00001_oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0<?oo
ool001kooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo00Cooooo5?l000001?oooooo0000ooooool00006ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`0`ooooo`007_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00ooooolIo`0000Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo033ooooo000Ooooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool01?l0003oooooooooooooool8
o`000005ooooool0003o0000o`000?ooool01?l000000ooooooo0000o`000007o`0000?ooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo037ooooo000O
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooo`000002
o`000005ooooool0003o0000o`000?ooool01Ol000000ooooooo0000o`000004o`000004ooooool0
003o0000ooooo`Go000000?oooooo`000?ooool01Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`00
0?oooooooooo037ooooo000Oooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?oo
ool3o`000003ooooool0003o000000?o000000?oooooo`000?l000000ol000000ooooooo0000o`00
0004o`000003ooooool0003o000000Oo00001_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oo
oooooooo037ooooo000Oooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool9
o`000006ooooool0003o0000ooooool0003ooooo0_l000001?oooooo0000o`000?ooool4o`000003
ooooool0003o000000?o00001_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo037o
oooo000Oooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`04ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool4o`000005oooo
ool0003oooooo`000?ooool01?l000000ooooooo0000o`000002o`000003ooooool0003o000000;o
000000?oooooo`000?ooool01ol00004ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000oooooooo
ool0<Oooool001oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01_ooool01?l0003oooooooooooooool2o`000003
ooooool0003o000000;o000000?oooooo`000?ooool01?l000000ooooooo0000o`000002o`000003
ooooool0003o000000;o000000?oooooo`000?ooool01?l000001?oooooo0000ooooool00002oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0<Oooool0023ooooo00?o0000oooooooo
ool00oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01Oooool01?l0003oo`00ool00?oo0003o`000003ooooool0003o000000;o000000Woooooo`00
0?l0003o0000ooooool0003oooooo`000?ooool00_l000000ooooooo0000ooooo`03o`000004oooo
ool0003o0000ooooo`Go00000_oo00000ooooooo0000ooooo`07ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo037o
oooo000Pooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Kooooo1?oo0005o`000005ooooool0003oooooo`000?oo
ool01?l00002ooooo`03o`000?oooooo000000?o000000Goooooo`000?oooooo0000ooooo`04o`00
00Coo`0000?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`0booooo`008?ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oo003oo`0000;oo`0000?o0000ooooool000001Ol000000ooooooo
0000o`000002o`0000;ooooo00?o0000ooooool000000ol000002?oooooo0000o`000?l0003ooooo
o`000?oooooo00001?oo00000ooooooo0000ooooo`07ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03;ooooo000P
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo0_l00005ool00007o`000?oooooo0000o`000?oooooo0000
ooooo`02o`000008ooooool0003oooooooooool0003oooooo`000?ooool2o`000003ooooool0003o
oooo00;o000000?oooooool00?oo00000ooo0002o`000003ooooool0003ooooo00Gooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool0<_ooool0023ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00oooool5o`0000Goo`000ol00002oooo
o`;o000000Coooooo`000?l0003ooooo0ol000000ooooooo0000o`000002ooooo`03o`000?oooooo
o`0000Goo`001?l000000ooooooo0000ooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo03;ooooo000Qoooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06oooo
o`04o`000?ooooooooooooooo`Ko00002Ooo0003o`000004ooooool0003o0000ooooo`?o000000?o
ooooo`000?l000002Ooo0007o`0000Cooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0<_ooool0027ooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01?l000001?oooooo0000o`000?ooool<ool00005o`000?oooooo0000o`000?ooool0
3?oo00001Ooooooo0000o`000?l0003ooooo00Co00000_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0booooo`00
8Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1_ooool5o`000006ooooool0003o0000ooooool0003ooooo0ooo00000ooooooo0000ooooo`0?ool0
0003o`000?oooooo000000?oo`0000Oo0000ooooool0003o0000ooooool0003ooooo00Co000000?o
ooooo`000?ooool01oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool0<_ooool0027ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Gooooo0_l000000ooooooo0000o`000002o`0000;ooooo0ol00003
ool000;o000000Coooooo`000?oooooo00001ooo0002ooooo`;o000000?oooooo`000?oo00000_oo
00000ooooooo0000o`000002o`000003ooooool0003o000000Go00002?ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0<oooool0027ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo1Ol00000
2?oooooo0000ooooool0003oooooo`000?oooooo00000ooo0002ooooo`?o000000Coooooo`000?l0
003ooooo0ol00002ooooo`;o000000Soooooool00?oo003oo`00ooooool0003oooooo`0000;ooooo
00?o0000ooooool000001_l00006ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
1?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`0cooooo`008Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool00oooool5o`000004ooooool0003oooooooooo`;o0000
00Coooooo`000?l0003ooooo0ooo00000ol0003oooooo`000002ooooo`06o`000?ooooooooooo`00
0?oooooo00000_ooool00ol0003oooooool00002ool0000;o`000?oooooo0000o`000?oooooo0000
ooooool0003oooooo`000?ooool01Ol00006ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000oooo
ooooool01?ooool00ol0003oooooooooo`0cooooo`008_ooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool3o`000006ooooool0003ooooooooo
ool0003ooooo0ol000001Ooooooo0000o`000?oooooo000000?oo`0000?oooooo`000?l000000_l0
0002ooooo`03o`000?oooooo000000?o00000ooo00000ooooooo0000ooooo`02o`000008ooooool0
003o0000ooooool0003oooooo`000?ooool5o`0000Cooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo03?ooooo000Rooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01oooool00ol0003oooooooooo`08o`000006ooooool0003o0000oooo
ool0003ooooo1?l000001?ooooooo`00ool00?oo0004o`0000;ooooo00?o0000ooooool000000_l0
0003ool000;ooooo1?l000000ooooooo0000ooooo`02o`0000;ooooo0ol000001?oooooo0000o`00
0?l00003ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0cooooo`008_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooool000000ol000001?oooooo0000ooooool00002ooooo`03o`000?oooooo000000;ooooo
1?l00002ooooo`?oo`0000?o0000ooooool000000_ooool01?l0003oooooo`000?l00003ool00003
o`000?oooooooooo00Co00000_ooool00ol0003oooooo`000002ooooo`03o`000?oooooo000000;o
oooo0ol000000ooooooo0000ooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000oooooooo
ool0<oooool002;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`Co0000
00Coooooo`000?oooooooooo0ol00002ooooo`05o`000?ooooooooooo`000?ooool00_l00002oooo
o`06o`000?oo003oo`00ool00?oooooo00000_ooool00ol0003oooooo`000003ool00004ooooool0
003oooooooooo`;o000000Goooooo`000?ooooooooooo`000002ooooo`07o`000?oooooo0000o`00
0?oooooo0000ooooo`05o`0000Sooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0c
ooooo`008_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo0_l000000ooo
oooo0000o`000002ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool00ol0003ooooooooo
o`02o`000004ooooool0003oooooo`0000?oo`000_l000000ooooooo0000o`000003ool00005oooo
ool0003oooooo`000?ooool00_l00002ooooo`05o`000?ooooooooooo`000?ooool00_l000001_oo
oooo0000oooooooooooo0000ooooo`?o00002?ooool00ol0003oooooooooo`06ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oo
oooooooo03Cooooo000Sooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool6
o`0000;ooooo00Ko0000ooooool0003o0000ooooool00002ooooo`05o`000?ooooooooooo`000?oo
ool00ol000000ooooooo0000ool00002ool00003ooooool0003o000000?oo`000_ooool4o`000004
ooooool0003oooooooooo`;o000000?oooooo`000?ooool00_l00002ooooo`05o`000?oooooo0000
o`000?ooool00ol00007ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0=?ooool0
02?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`Ko00000_ooool01Ol0
003oooooo`000?l0003ooooo00;o000000?oooooo`000?l000000_ooool00ol0003oooooo`000002
o`000003ooooool0003ooooo00?oo`0000Go0000ool00?oo003oo`00o`000002ooooo`06o`000?oo
oooo0000o`000?oooooo00000_ooool01Ol0003oooooo`000?l0003ooooo00?o000000Coooooo`00
0?oooooooooo1_l00005ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0=?ooool0
02?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`?o000000Coooooo`00
0?l0003o00000_ooool3o`0000;ooooo00Co0000ooooool0003o00000_ooool01Ol0003ooooooooo
oooooooo000000;ooooo00?o0000ooooool000001Ooo00001ooooooo0000oooooooooooo0000oooo
ool000000oooool01Ol0003oooooooooool0003ooooo00;o00000_ooool2o`000005ooooool0003o
ooooo`000?ooool01Ol00004ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0=?oo
ool002?ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03o`000003ooooool0003o
oooo00;o000000Goooooo`000?l0003oooooo`000002ooooo`;o000000Goooooo`000?oooooooooo
o`000002ooooo`;o00000_ooool00ol0003oooooo`000005ool00006ooooool0003oooooooooool0
003ooooo0_l00002ooooo`05o`000?ooooooooooo`000?ooool00_l00002ooooo`08o`000?oooooo
0000ooooool0003oooooo`000?ooool5o`0000;ooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`0dooooo`008oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;o0000
00[oooooo`000?l0003o0000ooooool0003oooooo`000?oooooo00000_ooool2o`000003ooooool0
003o000000;ooooo00Wo0000ooooool0003o0000ooooool0003oooooo`000?ooool00ooo00001Ooo
ooooo`00ool00?oo003o000000;ooooo0_l000001Ooooooo0000o`000?oooooo000000;ooooo00?o
0000ooooool000000_l00002ooooo`05o`000?oooooo0000o`000?ooool00ol000000ooooooo0000
o`000002o`000003ooooool0003ooooo00Oooooo00?o0000ooooooooool01oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0=?ooool002?ooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01_ooool3o`0000;ooooo00?o0000ooooool000000_ooool01?l0003ooooooooo
ool00002ooooo`04o`000?ooooooooooo`0000?ooooo00Co0000ooooool0003o00000_ooool00ol0
003oooooool00002ool000;ooooo00Co0000ool00?oo003oo`000_ooool01Ol0003oooooooooool0
003ooooo00;o00000oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;o0000
00?oooooo`000?ooool00_l000001?oooooo0000o`000?l00009ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03Go
oooo000Tooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`06ooooo`03o`000?oooooooooo00Kooooo0_l00002ooooo`03o`000?oooooo000000;ooooo
0_l000000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00;o000000Koooooo`000?oooooo
0000ooooool00002ooooo`04o`000?oo003oo`00ool000?ooooo00?o0000oooooooo00000_oo0000
1Ooooooo0000o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oooooooooo00;o00000_oo
ool01?l0003oooooo`000?l00002ooooo`05o`000?oooooo0000o`000?ooool00ol00007ooooo`03
o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03
o`000?oooooooooo03Gooooo000Tooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0
1_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Cooooo0ol000001?oooooo0000
ooooool00003ooooo`04o`000?oooooo0000o`0000;ooooo00Co0000oooooooooooooooo0_l00000
0ooooooo0000o`000002ooooo`03o`000?ooooooo`0000?oo`0000Go0000ooooooooooooooooo`00
0002ooooo`Coo`0000?o0000ooooool000000oooool01?l0003oooooo`000?l00003ooooo`;o0000
00?oooooo`000?ooool00ol00002ooooo`03o`000?oooooo000000Co00001oooool00ol0003ooooo
ooooo`07ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`0eooooo`009?ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`Go00000_ooool00ol0003ooooooooo
o`02o`000004ooooool0003oooooooooo`;o00000_ooool00ol0003oooooooooo`02o`0000?ooooo
00?o0000ool00?oo00000_oo0002o`0000?ooooo00Co0000oooooooooooo00001?oo00000ooooooo
0000ooooo`02ooooo`;o00000_ooool02?l0003oooooooooool0003oooooo`000?oooooo00000_oo
ool01?l0003oooooooooool00002ooooo`Go00001_ooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0eooooo`009?oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Ooo
ool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01ooo
ool01?l0003oooooooooooooool3o`000005ooooool0003o0000ooooool000000_ooool2o`0000;o
oooo1?l00003ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oo`00ool00?oo0004
o`0000?ooooo00?o0000ooooooooool00ol00003ool00004ooooool0003oooooooooo`;o00000_oo
ool01_l0003ooooooooooooooooo0000ooooo`;o00000oooool01Ol0003oooooooooool0003ooooo
00;o000000Coooooo`000?oooooo00001?ooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0eooooo`009?ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`03o`000007ooooool0003o0000o`000?oooooo0000ooooo`02o`0000;ooooo00Go
0000ooooool0003oooooo`000003ooooo`03o`000?oooooooooo00;o00000_ooool3ool00005oooo
ool0003oooooooooool000000oooool01?l0003oooooooooool00002ooooo`05o`000?oo003oo`00
ool00?l000000_ooool3o`0000;ooooo00Go0000oooooooooooo0000ooooo`03o`0000?ooooo00_o
0000ooooool0003oooooo`000?oooooo0000ooooool0003oooooo`000003ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooo
oooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
oooo03Kooooo000Tooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`07ooooo`Oo00000_ooool01Ol0003oooooo`000?oooooo000000;ooooo00?o0000
ooooool000000_l00002ooooo`03o`000?oooooooooo00;o000000?oooooo`000?oo00000_oo0002
ooooo`03o`000?oooooooooo00;o00000_ooool01?l0003oooooo`000?l00002ooooo`;o00000ooo
00002?oooooo0000ooooool0003oooooo`000?oooooo00000_ooool00ol0003oooooo`000002o`00
00?ooooo0_l000001?oooooo0000ooooooooool4o`000004ooooool0003oooooo`0000Wooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo03Kooooo000T
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`07
ooooo`Co000000Coooooo`000?l0003ooooo0ol000002Ooooooo0000oooooooooooo0000ooooool0
003oooooo`000003ooooo`05o`000?oooooo0000ooooool000001?oo0002ooooo`;o00000_ooool2
o`0000;ooooo00Co0000ooooool0003o00000oooool00ol0003oooooool00003ool00004ooooool0
003oooooooooo`;o00000oooool00ol0003oooooooooo`02o`0000?ooooo1?l00002ooooo`05o`00
0?oooooo0000o`000?ooool00_l00009ooooo`03o`000?oooooooooo00Kooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`0fooooo`009Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`00
0?oooooooooo00Oooooo00?o0000ooooooooool01Oooool4o`000003ooooool0003o000000;ooooo
0ol000001?oooooo0000ooooooooool2o`0000;ooooo0_l00002ooooo`04o`000?oooooo0000oooo
o`Coo`0000Co0000ooooool0003o00000oooool01?l0003oooooo`000?ooool2o`000003ooooool0
003ooooo00;ooooo0_l000000oooooooo`00ool00002ool00006o`000?ooooooooooo`000?oooooo
00000_ooool01Ol0003ooooooooooooooooo000000?ooooo1?l00002ooooo`;o000000?oooooo`00
0?l000000_l00008ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0fooooo`009Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01?ooool01Ol0003oooooo`000?l0003ooooo00;o00000_ooool2o`00
0003ooooool0003o000000;ooooo0_l00002ooooo`07o`000?oooooo0000ooooool0003oooooo`00
0004ool000;ooooo0_l000000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo00;o00000_oo
ool01_l0003ooooooooooooooooo0000ooooo`?o00001?oo0002ooooo`;o000000Coooooo`000?oo
oooo00000oooool01_l0003ooooooooooooooooo0000ooooo`;o00000_ooool2o`000003ooooool0
003o000000;o00001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool0=_ooool002Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00?ooooo00Co0000ooooool0003ooooo0ol00002ooooo`03o`000?oo
oooo000000;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`02o`0000Goo`00
0_ooool3o`000003ooooool0003ooooo00;ooooo00?o0000ooooooooool00_l00003ooooo`04o`00
0?ooooooooooooooo`Co000000?oooooool00?oo00000ooo00000ooooooo0000o`000002ooooo`04
o`000?ooooooooooooooo`;o000000?oooooo`000?l000000_ooool2o`0000;ooooo1ol00006oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`0goooo
o`009Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oooooo00?o0000oooooooo
ool00_ooool2o`000003ooooool0003o000000;o00000_ooool2o`0000;ooooo0_l000000ooooooo
0000o`000002ooooo`05o`000?ooooooooooooooool000001?oo00001?l0003oooooooooooooool3
o`000003ooooool0003ooooo00;ooooo00?o0000ooooooooool00_l00003ooooo`04o`000?oooooo
ooooooooo`Co00000oooool4ool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool00_l0
00001?oooooo0000ooooool00002ooooo`05o`000?ooooooooooo`000?ooool00_l000000ooooooo
0000o`000005ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`0gooooo`009Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Kooooo
00Co0000oooooooooooooooo1Ol000001?oooooo0000ooooooooool2o`0000?ooooo00Co0000oooo
ool0003o00000oooool00ol0003oooooooooo`04ool00003ooooool0003ooooo00?ooooo00Go0000
ooooool0003oooooo`000003ooooo`04o`000?oooooo0000ooooo`;o00000_ooool01?l0003ooooo
ooooooooool2o`000003ooooool0003ooooo00?ooooo00?o0000ool00?oo00000_oo00001?l0003o
ooooooooool00003ooooo`;o00000_ooool01Ol0003ooooooooooooooooo000000;ooooo1Ol00000
0ooooooo0000ooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0gooooo`009Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooool000001?l000000ooooooo0000o`000002ooooo`06o`000?oooooooooo
ooooool0003ooooo0ol00003ooooo`03o`000?ooooooo`0000?oo`000_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00;o00000oooool2o`0000;ooooo0ol000000ooooooo0000oooo
o`02ooooo`03o`000?oooooooooo00;o00000oooool00ol0003oooooool00003ool000;ooooo00Co
0000oooooooooooooooo0ol00002ooooo`03o`000?oooooooooo00;o000000Coooooo`000?l0003o
oooo0ol000001Ooooooo0000oooooooooooo000000Wooooo00?o0000ooooooooool01_ooool00ol0
003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0
003oooooooooo`0gooooo`009Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Oo
oooo1?l000001_oooooo0000o`000?oooooo0000ooooo`;o00000oooool00ol0003oooooooooo`03
o`0000;ooooo00?o0000ool00?oo00000_oo00001Ol0003oooooo`000?oooooo000000?ooooo0_l0
0003ooooo`04o`000?ooooooooooooooo`;o00000_ooool01Ol0003oooooo`000?oooooo000000;o
oooo0_l00003ooooo`08o`000?ooooooooooooooool0003oooooo`000?ooool4ool00004ooooool0
003oooooooooo`;o000000Goooooo`000?ooooooooooo`000002ooooo`Co000000Coooooo`000?l0
003ooooo0ol000000ooooooo0000ooooo`07ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0=oooool002Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Gooooo00?o0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`?o
000000Goooooo`000?l0003oooooo`000002ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
ool0003ooooo0_l000000oooooooo`00ool00003ool00006ooooool0003oooooo`000?oooooo0000
0_ooool2o`0000?ooooo0_l00002ooooo`;o00000oooool00ol0003oooooooooo`02o`0000;ooooo
0_l00003ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`Goo`000_ooool2o`0000;ooooo
00?o0000ooooool000000oooool2o`000003ooooool0003ooooo00;o000000?oooooo`000?l00000
0_l00008ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0>?ooool002Kooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o
0000ooooooooool01oooool00ol0003oooooooooo`06ooooo`;o000000Goooooo`000?l0003ooooo
o`000002ooooo`?o00000_ooool01Ol0003oooooo`000?oooooo000000;ooooo1?oo00000ol0003o
ooooo`000003ooooo`06o`000?ooooooooooo`000?oooooo00000oooool01Ol0003oooooo`000?oo
oooo000000Cooooo00Wo0000ooooooooooooooooo`000?oooooo0000ooooool000000oooool00ol0
003oooooo`000002ooooo`06o`000?ooooooooooooooool0003ooooo1?oo00001?l0003ooooooooo
ool00002ooooo`03o`000?oooooo000000;ooooo00Ko0000ooooool0003oooooo`000?ooool2o`00
0003ooooool0003o000000Wooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`0hoooo
o`009_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo1Ol000000ooooooo
0000ooooo`02ooooo`03o`000?oooooo000000;ooooo0_l00002ooooo`03o`000?oo003oo`0000;o
o`0000Goooooo`000?ooooooooooo`000003ooooo`03o`000?oooooo000000;ooooo00Ko0000oooo
ooooooooooooo`000?ooool3o`0000Cooooo00Co0000oooooooooooooooo0ol000000ooooooo0000
ooooo`03ooooo`05o`000?oooooo0000ooooool000001?ooool00ol0003oooooooooo`04ool0000:
ooooool0003oooooooooool0003oooooo`000?oooooo0000ooooo`;o00000_ooool01Ol0003ooooo
o`000?l0003ooooo00;o00001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Ko
oooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03So
oooo000Vooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00oooool2o`000003oooo
ool0003o000000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooo`000?l00002oooo
o`Goo`000_l00003ooooo`04o`000?ooooooooooooooo`?o00000_ooool01Ol0003ooooooooooooo
oooo000000;ooooo0_l00004ooooo`04o`000?ooooooooooooooo`;o00000_ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooo000000;o00001?ooool01?l0003oooooooooool00005ool00005
o`000?ooooooooooo`000?ooool00_l00002ooooo`;o000000Coooooo`000?oooooooooo1Ol00006
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0>?ooool002Kooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01oooool00ol0003oooooooooo`02ooooo`;o00000_ooool2o`000004ooooool0003ooooo
ooooo`;o00000oooool2o`000003oooooooo003oo`0000?oo`0000?oooooo`000?l000000oooool0
1_l0003ooooooooooooooooo0000ooooo`;o00000_ooool02Ol0003ooooooooooooooooo0000oooo
ool0003oooooo`000004ooooo`09o`000?ooooooooooooooool0003oooooo`000?oooooo000000Co
oooo00Ko0000ooooool0003o0000ooooool00003ooooo`04o`000?ooooooooooooooo`;o00001Ooo
0002ooooo`;o00000oooool01Ol0003oooooo`000?oooooo000000;ooooo00?o0000ooooooooool0
0_l00005ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0>?ooool002Oooooo00?o
0000ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooooooool01_ooool01?l0003oooooooooooooool2o`0000;ooooo00Co0000ooooool0003o
00000_ooool2o`0000Cooooo00?o0000ool00?oo00000ooo0003ooooo`03o`000?oooooo000000;o
oooo00Co0000oooooooooooooooo0_l000001?oooooo0000ooooool00004ooooo`;o00000_ooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000000_ooool2o`0000Cooooo00Co
0000ooooool0003ooooo0_l00004ooooo`05o`000?oooooo0000ooooool000000_ooool5ool00003
ooooool0003o000000?ooooo00Ko0000ooooool0003oooooo`000?ooool2o`0000;ooooo0_l00003
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0>Oooool002Oooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`02o`0000;ooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooo`000003ooooo`Goo`0000Go0000ooooooooooooooooo`000002ooooo`04o`000?oo
ooooooooo`0000?ooooo00Co0000oooooooooooooooo0_l00004ooooo`;o00000_ooool2o`0000?o
oooo00[o0000oooooooooooo0000ooooool0003oooooo`000?oooooo00000oooool2o`0000?ooooo
00?o0000ooooooooool00_ooool00ol0003oooooo`000002ooooo`04o`000?ooooooooooooooo`Go
o`0000?o0000ooooooooool00_ooool01?l0003oooooo`000?ooool2o`000004ooooool0003ooooo
ooooo`;o00000_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01Oooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Wooooo000Woooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooool000000_ooool2o`0000;ooooo0ol000001?oo
oooo0000ooooooooool5ool00003ooooool0003ooooo00;ooooo0_l00002ooooo`03o`000?oooooo
000000?ooooo0_l00003ooooo`;o00000oooool2o`0000?ooooo0_l00003ooooo`06o`000?oooooo
ooooo`000?oooooo00000_ooool2o`0000Cooooo00Co0000oooooooooooooooo0_l00003ooooo`03
o`000?oooooo000000;ooooo0_l00003ooooo`03o`000?oo003oo`0000?oo`000oooool00ol0003o
ooooooooo`02o`0000;ooooo0_l00002ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0>Oooool002Oooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool2o`0000;ooooo0_l00002ooooo`06
o`000?oooooo0000ooooool0003ooooo1Ooo00001?oooooo0000ooooool00003ooooo`03o`000?oo
oooooooo00;ooooo0_l00003ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooooooo
o`000004ooooo`03o`000?oooooo000000;ooooo00?o0000ooooool000000_ooool01Ol0003ooooo
oooooooooooo000000?ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo
ool00_ooool01ol0003ooooooooooooooooo0000ooooool000001Ooo0002ooooo`03o`000?oooooo
oooo00;o00000_ooool2o`0000;ooooo0_l00008ooooo`03o`000?oooooooooo00Kooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo03Wooooo000Woooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`06oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_l00002ooooo`04o`000?oooooo0000
ooooo`;o00001?oo00001Ol0003ooooooooooooooooo000000?ooooo0_l00004ooooo`;o00000_oo
ool2o`0000Gooooo0_l00002ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo0000
ooooo`02o`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo000000Co
oooo0_l00003ooooo`03o`000?oooooooooo00;ooooo0_l00003ooooo`04o`000?oooooooooooooo
o`Coo`000_ooool2o`000003ooooool0003o000000;ooooo0_l00002ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Kooooo00?o0000ooooooooool0>Oooool002Sooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01Oooool3o`000005
ooooool0003oooooooooool000000_ooool00ol0003oooooool00003ool000;o00001?ooool01_l0
003oooooooooool0003oooooo`0000Cooooo0_l000001?oooooo0000ooooool00004ooooo`04o`00
0?oooooo0000ooooo`;o00001?ooool01Ol0003oooooooooool0003ooooo00;o00000oooool01?l0
003oooooooooooooool2o`000004ooooool0003oooooo`0000Cooooo00Oo0000ooooool0003ooooo
o`000?oooooo000000?ooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`02ooooo`03
o`000?oo003oo`0000;oo`000_l000001?oooooo0000ooooool00002ooooo`03o`000?oooooooooo
00;o00001oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01Oooool00ol0003oooooooooo`0jooooo`00:?ooool00ol0003oooooooooo`05ooooo`03
o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`03ooooo`;o
000000?oooooo`000?l000000oooool00ol0003oooooo`000005ool00003o`000?oooooo000000?o
oooo00Ko0000ooooool0003o0000ooooool00005ooooo`?o000000?oooooo`000?ooool01?ooool0
1_l0003oooooooooool0003oooooo`0000Cooooo00Co0000oooooooooooooooo0_l00004ooooo`07
o`000?ooooooooooooooool0003oooooo`000003ooooo`03o`000?oooooooooo00;ooooo00Ko0000
ooooool0003o0000ooooool00004ooooo`06o`000?oooooo0000o`000?oooooo00001?ooool00ol0
003oo`00ool00004ool00003ooooool0003o000000?ooooo0_l000000ooooooo0000o`000005oooo
o`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05oooo
o`03o`000?oooooooooo03[ooooo000Xooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooo
oooo00000oooool00ol0003oo`00ool00004ool00004o`000?oooooo0000o`0000Cooooo00?o0000
ooooool000000_ooool00ol0003oooooooooo`03ooooo`?o000000?oooooo`000?ooool01?ooool0
1_l0003oooooooooool0003oooooo`0000Cooooo00Co0000oooooooooooooooo0_l00004ooooo`07
o`000?ooooooooooooooool0003oooooo`000003ooooo`03o`000?oooooooooo00;ooooo00Ko0000
ooooool0003o0000ooooool00004ooooo`06o`000?ooooooooooo`000?oooooo00001Oooool00ol0
003oooooool00006ool00005o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo03[ooooo000Xooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo00Ko0000oooo
oooooooo0000ooooool00007ool000;ooooo0ol00004ooooo`03o`000?oooooooooo00;o000000?o
ooooo`000?ooool00oooool01_l0003oooooo`000?l0003oooooo`0000Gooooo00Co0000ooooool0
003ooooo0_l00004ooooo`04o`000?ooooooooooooooo`;o00001?ooool01?l0003ooooooooooooo
ool2o`000005ooooool0003oooooooooool000001?ooool01?l0003oooooo`000?l00002ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`02ooooo`;o
000000?oooooo`000?ooool01ooo00000ooooooo0000o`000002ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Go
oooo00?o0000ooooooooool0>_ooool002Sooooo00?o0000ooooooooool01_ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_l000000ooooooo0000
ool00006ool000;ooooo00Ko0000oooooooooooo0000ooooool00004ooooo`04o`000?oooooo0000
ooooo`;o00001Oooool2o`0000;ooooo0_l00005ooooo`;o00000_ooool2o`0000Cooooo00Go0000
oooooooooooo0000ooooo`02o`0000?ooooo00Co0000oooooooooooooooo0_l00002ooooo`03o`00
0?oooooo000000Cooooo0_l00002ooooo`03o`000?oooooo000000Cooooo0_l000001?oooooo0000
ooooool00005ooooo`;o00000oooool00ol0003oooooool00005ool000;o000000?oooooo`000?l0
00000_ooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool01_ooool00ol0003oooooooooo`0jooooo`00:Oooool00ol0003oooooooooo`05ooooo`03o`00
0?oooooooooo00Gooooo00?o0000ooooooooool01oooool01Ol0003oooooo`000?l0003ooooo00Ko
o`0000Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo000000Gooooo0_l00002oooo
o`;o00001Oooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooool000000_ooool2
o`0000Cooooo00?o0000ooooool000000_ooool3o`0000;ooooo00Co0000oooooooooooooooo0_l0
0002ooooo`04o`000?ooooooooooo`0000Cooooo00Co0000oooooooooooooooo0_l00005ooooo`03
o`000?oooooooooo00;o00001Oooool3o`0000?ooooo00Co0000oooooooooooooooo1Ooo0002oooo
o`;o000000?oooooo`000?ooool02?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0>oooool002Wooooo00?o0000ooooooooool01Oooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Kooooo0_l00006ool00003ooooool0003o000000Co
oooo00?o0000ooooool000000_ooool00ol0003oooooooooo`02ooooo`;o00000oooool2o`0000Co
oooo0_l00003ooooo`;o00001?ooool2o`0000?ooooo00?o0000ooooool000000_ooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooo000000;ooooo00Ko0000oooooooooooo0000ooooool0
0003ooooo`03o`000?oooooo000000?ooooo0_l00003ooooo`03o`000?oooooo000000?ooooo0_l0
0003ooooo`;o00001Oooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00;ooooo00?o
0000ool00?oo00001?oo0003o`0000Sooooo00?o0000ooooooooool01_ooool00ol0003ooooooooo
o`05ooooo`03o`000?oooooooooo03_ooooo000Yooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooooooool01_ooool00ol0003oooooooooo`06ooooo`Koo`000_ooool00ol0003oooooo`000003
ooooo`05o`000?ooooooooooo`000?ooool00_l00004ooooo`03o`000?oooooooooo00;ooooo0_l0
0004ooooo`03o`000?oooooooooo00;ooooo0_l00004ooooo`;o00000oooool00ol0003oooooo`00
0002ooooo`03o`000?oooooo000000?ooooo00Ko0000oooooooooooo0000ooooool00002ooooo`03
o`000?oooooo000000?ooooo00?o0000ooooool000000oooool2o`0000Cooooo0_l00003ooooo`;o
00001?ooool00ol0003oooooooooo`02ooooo`;o000000?oooooo`000?ooool00_ooool00ol0003o
ooooooooo`03o`000003oooooooo003oo`0000Coo`0000?o0000ooooooooool01_ooool00ol0003o
ooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool0>oooool002Wooooo
00?o0000ooooooooool01Oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00?ooooo
1_oo0002o`0000?ooooo0ol00002ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool01?l0
003oooooooooool00005ooooo`03o`000?oooooo000000;ooooo0_l00004ooooo`;o00001?ooool0
0ol0003oooooooooo`02ooooo`05o`000?ooooooooooo`000?ooool00_l00004ooooo`04o`000?oo
ooooooooooooo`;o000000Goooooo`000?ooooooooooo`000004ooooo`;o00000oooool00ol0003o
ooooo`000004ooooo`07o`000?ooooooooooooooool0003oooooo`000004ooooo`09o`000?oooooo
ooooooooool0003oooooo`000?oooooo000000?ooooo00Go0000ooooool0003oooooo`000003oooo
o`03o`000?oo003oo`0000Coo`001_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool0>oooool002Wooooo00?o0000ooooooooool01_ooool00ol0003o
ooooooooo`05ooooo`03o`000?ooooooo`0000Ooo`000ol00003ooooo`;o00000_ooool01Ol0003o
ooooo`000?oooooo000000;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02
ooooo`05o`000?ooooooooooo`000?ooool00_l00004ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool00oooool01Ol0003oooooooooool0003ooooo00;o00001?ooool01?l0003o
ooooooooooooool2o`000005ooooool0003oooooooooool000001Oooool01?l0003oooooooooool0
0002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000000_ooool00ol0003ooooooooo
o`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00000_ooool00ol0003o
ooooo`000002ooooo`04o`000?ooooooooooooooo`;o00002?oo0002ooooo`03o`000?oooooooooo
00Gooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`0kooooo`00:_ooool00ol0003o
ooooooooo`05ooooo`03o`000?oooooooooo00Cooooo2?oo0002o`000003ooooool0003o000000?o
oooo0_l00003ooooo`;o000000Goooooo`000?ooooooooooo`000003ooooo`03o`000?oooooo0000
00Gooooo00Co0000oooooooooooooooo0ol00004ooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooooooool00oooool01?l0003oooooooooooooool2o`0000Gooooo00?o0000ooooooooool0
0_ooool2o`0000?ooooo00?o0000ooooooooool00oooool2o`000005ooooool0003oooooooooool0
00001Oooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool0
00000oooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo00;ooooo00Co0000oooo
oooooooooooo0_l000000ooooooo0000ool00008ool000Kooooo00?o0000ooooooooool01Oooool0
0ol0003oooooooooo`0looooo`00:_ooool00ol0003oooooooooo`05ooooo`04o`000?oooooooooo
ooooo`Ooo`000oooool2o`000003ooooool0003o000000Cooooo00?o0000ooooooooool00_ooool0
0ol0003oooooo`000003ooooo`03o`000?oooooooooo00;ooooo0_l00005ooooo`07o`000?oooooo
ooooooooool0003oooooo`000004ooooo`04o`000?ooooooooooooooo`?o00001?ooool00ol0003o
ooooooooo`02ooooo`;o00001Oooool00ol0003oooooooooo`02ooooo`;o00001?ooool00ol0003o
ooooooooo`03ooooo`;o00000oooool00ol0003oooooooooo`03ooooo`?o00000oooool00ol0003o
ooooooooo`02ooooo`?o00000oooool01ol0003ooooooooooooooooo0000ooooool000001?ooool2
o`0000?ooooo0_l000000ooooooo0000o`000002ooooo`Soo`000oooool00ol0003oooooooooo`05
ooooo`03o`000?oooooooooo03cooooo000Zooooo`03o`000?oooooooooo00Gooooo00?o0000ool0
0?oo00001Ooo00000ooooooo0000ooooo`02ooooo`Co000000?oooooo`000?l000000_ooool00ol0
003oooooooooo`03ooooo`?o00000_ooool00ol0003oooooooooo`02ooooo`;o00001Oooool01ol0
003ooooooooooooooooo0000ooooool000001Oooool01ol0003ooooooooooooooooo0000ooooool0
00001?ooool00ol0003oooooooooo`02ooooo`;o00001Oooool00ol0003oooooooooo`02ooooo`;o
00001?ooool00ol0003oooooooooo`03ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`;o
00001?ooool00ol0003oooooooooo`02ooooo`;o00001?ooool01Ol0003oooooooooool0003ooooo
00;o00001?ooool2o`000004ooooool0003o0000ooooo`;o000000?oooooo`000?ooool00_ooool0
0ol0003oooooool00006ool00003o`000?oooooooooo00Gooooo00?o0000ooooooooool0??ooool0
02[ooooo00?o0000ooooooooool02_oo0004ooooo`03o`000?oooooooooo00Co000000Koooooo`00
0?oooooo0000ooooool00005ooooo`03o`000?oooooo000000?ooooo00Oo0000oooooooooooooooo
o`000?oooooo000000Gooooo00Oo0000ooooooooooooooooo`000?oooooo000000Cooooo00?o0000
ooooooooool00_ooool2o`0000Gooooo00Oo0000ooooooooooooooooo`000?oooooo000000Gooooo
00?o0000ooooooooool00_ooool3o`0000?ooooo00?o0000ooooooooool00oooool2o`0000Cooooo
00?o0000ooooooooool00oooool2o`0000Cooooo00?o0000ooooooooool00_ooool00ol0003ooooo
o`000003ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`02ooooo`?o
000000?oooooo`000?ooool00_l000001Ooooooo0000oooooooooooo000000Cooooo2Ooo0003oooo
o`03o`000?oooooooooo03cooooo000Yooooo`_oo`002?ooool5o`000004ooooool0003ooooooooo
o`?o00001?ooool01?l0003oooooo`000?l00002ooooo`03o`000?oooooooooo00;ooooo0_l00000
0ooooooo0000ooooo`03ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_oo
ool01ol0003ooooooooooooooooo0000ooooool000001Oooool01_l0003ooooooooooooooooo0000
ooooo`;o00001?ooool01_l0003ooooooooooooooooo0000ooooo`;o00000oooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool00_ooool2o`000003oooo
ool0003ooooo00;ooooo00Ko0000ooooooooooooooooo`000?ooool2o`0000Cooooo00?o0000oooo
ooooool00_l000000ooooooo0000ooooo`03ooooo`03o`000?oooooo000000;ooooo00Go0000oooo
ool0003o0000ooooo`02o`0000Sooooo2_oo000nooooo`00:Oooool5ool000Gooooo00?o0000oooo
ooooool01_ooool4o`0000;ooooo00?o0000ooooooooool00_l00005ooooo`;o00000_ooool2o`00
00Cooooo00Go0000ooooool0003oooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooool000000oooool01?l0003oooooooooool00002ooooo`;o00001?ooool01?l0003ooooo
ooooool00002ooooo`;o00001?ooool02Ol0003ooooooooooooooooo0000ooooool0003oooooo`00
0002ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooool0003oooooo`000003ooooo`09o`00
0?ooooooooooooooool0003oooooo`000?oooooo000000?ooooo00So0000oooooooooooo0000oooo
ool0003oooooo`0000Cooooo00Oo0000ooooool0003oooooo`000?oooooo000000Cooooo0_l00002
ooooo`03o`000?oooooooooo00;o000000?oooooo`000?ooool01oooool00ol0003oooooooooo`02
ooooo`Goo`00?_ooool002_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04oooo
o`;oo`0000?o0000ooooool000000_ooool00ol0003oooooooooo`03o`0000Cooooo0_l00003oooo
o`;o00000oooool00ol0003oooooo`000002ooooo`07o`000?ooooooooooooooool0003oooooo`00
0003ooooo`03o`000?oooooo000000?ooooo00Co0000oooooooooooo00000_ooool2o`0000Cooooo
00?o0000ooooool000000oooool00ol0003oooooo`000003ooooo`04o`000?ooooooooooo`0000;o
oooo00Ko0000oooooooooooo0000ooooool00004ooooo`05o`000?oooooo0000ooooool000000ooo
ool01ol0003ooooooooooooooooo0000ooooool000000_ooool01?l0003oooooooooool00002oooo
o`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooo`000002ooooo`;o00001?oo
ool3o`0000;ooooo00Go0000oooooooooooo0000ooooo`02ool000Oooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`0mooooo`00:oooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00Cooooo0ooo00001?l0003oooooooooool00002ooooo`04o`000?oooooo0000o`0000?o
oooo0_l00004ooooo`05o`000?ooooooooooooooool000000_ooool01ol0003ooooooooooooooooo
0000ooooool000000_ooool01Ol0003ooooooooooooooooo000000;ooooo00Ko0000oooooooooooo
0000ooooool00002ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooool000000_ooool0
1Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooool000000oooool01_l0003ooooooooo
ool0003oooooo`0000?ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooooooo0_l00003ooooo`04o`00
0?ooooooooooo`0000?ooooo00?o0000ooooooooool00_ooool2o`0000?ooooo0_l000001Ooooooo
0000oooooooooooo000000;ooooo0ooo0007ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0?Oooool002_ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`04ooooo`03
o`000?oo003oo`0000;oo`0000So0000oooooooooooo0000ooooool0003oooooo`0000?ooooo00?o
0000ooooooooool00oooool2o`0000;ooooo00?o0000ooooool000001?ooool01Ol0003oooooo`00
0?oooooo000000?ooooo00Wo0000ooooooooooooooooo`000?oooooo0000ooooool000000oooool0
1?l0003oooooooooool00002ooooo`03o`000?oooooo000000?ooooo00Go0000oooooooooooooooo
o`000002ooooo`03o`000?oooooo000000?ooooo00Oo0000ooooooooooooooooo`000?oooooo0000
00;ooooo00Co0000oooooooooooo00000oooool00ol0003oooooo`000002ooooo`05o`000?oooooo
ooooooooool000000_ooool00ol0003oooooooooo`02o`0000Cooooo00?o0000ooooool000000ooo
ool00ol0003oooooooooo`03ooooo`;o00000_ooool01Ol0003oooooo`000?oooooo000000;ooooo
00Ko0000ool00?oo003oo`00ooooool00006ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool0?Oooool002_ooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02ooooo`?o
00001?oo00001?oooooo0000ooooool00002ooooo`04o`000?ooooooooooo`0000Gooooo00Go0000
ooooool0003oooooo`000002ooooo`03o`000?oooooooooo00?ooooo0ol00004ooooo`03o`000?oo
oooooooo00;ooooo0_l000000ooooooo0000ooooo`02ooooo`0:o`000?ooooooooooooooool0003o
ooooo`000?oooooo0000ooooo`?o00001?ooool01?l0003oooooo`000?l00004ooooo`09o`000?oo
ooooooooooooool0003oooooo`000?oooooo000000?ooooo00Go0000ooooooooooooooooo`000002
ooooo`;o00001?ooool01ol0003ooooooooooooooooo0000ooooool000001Oooool01?l0003ooooo
ooooool00002ooooo`;o00001Oooool01?l0003oooooooooool00002ooooo`03o`000?oooooo0000
00Coo`000_l000000ooooooo0000ooooo`03ooooo`03o`000?oooooooooo00Kooooo00?o0000oooo
ooooool0?Oooool002_ooooo00?o0000ooooooooool01_ooool01?l0003oooooooooooooool4o`00
0003oooooooo003oo`0000;oo`000_ooool01?l0003oooooooooooooool3o`0000Gooooo00Co0000
ooooool0003o00000_ooool00ol0003oooooooooo`04ooooo`03o`000?oooooo000000?ooooo00?o
0000ooooooooool00oooool3o`0000Cooooo00Ko0000ooooooooooooooooo`000?ooool2o`0000?o
oooo0_l00004ooooo`04o`000?oooooo0000o`0000Cooooo00?o0000ooooooooool00_ooool2o`00
0003ooooool0003ooooo00?ooooo00Ko0000ooooooooooooooooo`000?ooool2o`0000Cooooo00Ko
0000ooooooooooooooooo`000?ooool2o`0000Gooooo00?o0000ooooooooool00_l000000ooooooo
0000ooooo`05ooooo`;o00000oooool00ol0003oooooool00003ool00006o`000?oooooo0000o`00
0?oooooo00000oooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo03gooooo000/oooo
o`03o`000?oooooooooo00Gooooo00?o0000ooooooooool01?l00002ooooo`03o`000?ooooooo`00
00;oo`0000?o0000ooooooooool00_ooool2o`0000Gooooo00?o0000ooooooooool00_l00002oooo
o`03o`000?oooooooooo00Cooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo0_l00004oooo
o`03o`000?oooooooooo00?ooooo0_l000000ooooooo0000o`000003o`0000Gooooo0_l00005oooo
o`03o`000?oooooooooo00?ooooo0_l00005ooooo`03o`000?oooooooooo00;ooooo0_l00006oooo
o`04o`000?ooooooooooooooo`?o00001Oooool01Ol0003ooooooooooooooooo000000;ooooo00?o
0000ooooooooool00oooool2o`0000Cooooo1?oo00001?oooooo0000ooooooooool2o`000005oooo
ool0003oooooooooool000002?ooool00ol0003oooooooooo`0mooooo`00;?ooool00ol0003ooooo
ooooo`05ooooo`03o`000?oooooo000000?o00000oooool2o`0000Coo`000oooool2o`0000Kooooo
00?o0000ooooooooool00_l000000ooooooo0000ooooo`05ooooo`?o00001?ooool00ol0003ooooo
ooooo`03ooooo`;o00001?ooool00ol0003oooooooooo`03ooooo`;o000000CoooooodA4A?oMgMgo
oooo0_l00005ooooo`?o00001?ooool00ol0003oooooooooo`03ooooo`;o00001Oooool00ol0003o
ooooooooo`03ooooo`;o00001Oooool01?l0003oooooooooooooool2o`000003ooooool0003ooooo
00Cooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`04ooooo`;o00000_ooool4
ool000?o00000oooool2o`000004ooooool0003oooooo`0000Sooooo00?o0000ooooooooool0?Ooo
ool002cooooo00?o0000ooooooooool01Oooool5o`0000?ooooo00Co0000ooooool0003ooooo1?oo
00001?oooooo0000ooooool00005ooooo`08o`000?ooooooooooo`000?oooooo0000ooooool00006
ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool01?ooool2o`0000Cooooo00?o0000
ooooooooool00oooool2o`000004oooooooMgMgoEEEEooooo`;o00001Oooool2o`0000Gooooo00?o
0000ooooooooool00oooool2o`0000Gooooo00?o0000ooooooooool00oooool2o`0000Gooooo00Ko
0000ooooooooooooooooo`000?ooool2o`0000Kooooo0_l000001Ooooooo0000oooooooooooo0000
00Gooooo0ol00004ool000;ooooo00?o0000ooooool000000oooool2o`000003ooooool0003o0000
00Oooooo00?o0000ooooooooool0?_ooool002cooooo00?o0000ooooooooool01Oooool2o`000003
ooooool0003ooooo00;ooooo00Ko0000ooooool0003o0000ooooool00004ool00004ooooool0003o
ooooo`0000?ooooo00Co0000oooooooooooo00000oooool2o`0000Gooooo0_l000000ooooooo0000
ooooo`02ooooo`03o`000?oooooooooo00?ooooo0_l000000ooooooo0000ooooo`02ooooo`03o`00
0?oooooooooo00?ooooo0_l00002ooooo`04ogMgMoo<c<co0000o`0000Gooooo0_l00005ooooo`03
o`000?oooooooooo00?ooooo0_l00005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool0
00001_ooool02?l0003oooooooooool0003oooooo`000?oooooo00001Oooool2o`0000;ooooo00Co
0000oooooooooooo00000oooool00ol0003oooooo`000004ool00003ooooool0003ooooo00;o0000
00?oooooo`000?ooool00_ooool01?l0003oooooo`000?l00007ooooo`03o`000?oooooooooo03ko
oooo000/ooooo`03o`000?oooooooooo00Gooooo0ol00003ooooo`04o`000?oooooo0000ooooo`;o
00000_ooool5ool00003ooooool0003ooooo00;ooooo00?o0000ooooool000001?ooool00ol0003o
ooooooooo`04ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`02oooo
o`05o`000?oooooo0000ooooool000000oooool00ol0003oooooooooo`02ooooo`;o000000Gooooo
o`000?ooooook^k^odA4A002o`0000Cooooo00Co0000ooooool0003o00001?ooool00ol0003ooooo
ooooo`02ooooo`04o`000?oooooo0000o`0000Cooooo00?o0000ooooooooool00_ooool01?l0003o
ooooo`000?l00005ooooo`03o`000?oooooo000000?ooooo0_l00006ooooo`07o`000?oooooooooo
ooooool0003oooooo`000003ooooo`03o`000?oo003oo`0000?oo`000oooool2o`000004ooooool0
003oooooo`0000?ooooo0ol00007ooooo`03o`000?oooooooooo03kooooo000]ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooool000000oooool00ol0003oooooo`000002ooooo`05o`000?oo
ooooooooooooool000001_oo0002ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000oooooooo
ool00oooool2o`0000?ooooo00?o0000ooooool000001Oooool2o`0000;ooooo00Co0000oooooooo
oooo00001?ooool01Ol0003oooooo`000?oooooo000000;ooooo00?oMgMgo`000?l000001?ooool0
1?l0003oooooo`000?l00004ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooool0003ooooo
o`000004ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00oooool00ol0003o
ooooo`000004ooooo`03o`000?oooooooooo00?ooooo0_l00003ooooo`05o`000?ooooooooooo`00
0?ooool01_oo00000ooooooo0000ooooo`02ooooo`06o`000?ooooooooooo`000?oooooo00000ooo
ool00ol0003oooooo`000006ooooo`03o`000?oooooooooo03kooooo000]ooooo`03o`000?oooooo
oooo00;ooooo00Co0000ooooool0003o00000oooool2o`0000?ooooo0_l00002ooooo`03o`000?oo
oooo000000Goo`0000Coooooo`000?oooooo00001?ooool00ol0003oooooo`000003ooooo`;o0000
1Oooool2o`0000Cooooo00?o0000ooooool000000oooool00ol0003oooooo`000004ooooo`03o`00
0?oooooo000000;ooooo00Go0000ooooooooooooooooo`000003ooooo`06o`000?ooooooooooo`00
0?oooooo00000oooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooool000001?oo
ool01?l0003oooooooooool00003ooooo`;o00001Oooool00ol0003oooooooooo`04ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooool000000oooool00ol0003oooooo`000006ool00003o`00
0?oooooo000000;ooooo0_l00003ooooo`;o00000oooool2o`000003ooooool0003ooooo00Cooooo
00?o0000ooooooooool0?_ooool002gooooo00Ko0000ooooooooooooooooo`000?ooool3o`0000;o
oooo0_l00003ooooo`07o`000?oooooo0000ooooool0003oooooo`000002ooooo`Koo`0000?o0000
ooooooooool00oooool00ol0003oooooo`000003ooooo`;o00001Oooool2o`0000?ooooo00Co0000
oooooooooooo00000oooool00ol0003oooooo`000003ooooo`04o`000?ooooooooooo`0000;ooooo
00Go0000ooooooooooooooooo`000003ooooo`06o`000?ooooooooooo`000?oooooo00000oooool0
1Ol0003ooooooooooooooooo000000;ooooo00Co0000oooooooooooo00000oooool00ol0003ooooo
o`000004ooooo`03o`000?oooooo000000Cooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooo000000Cooooo1ooo0002ooooo`07o`000?oooooo0000ooooool0
003oooooo`000003ooooo`;o00000_ooool3o`000003ooooool0003ooooo00?ooooo00?o0000oooo
ooooool0?_ooool002gooooo00Go0000oooooooooooo0000ooooo`02o`0000;ooooo0ol00003oooo
o`03o`000?oooooooooo00;o00000_ooool01?l0003oooooooooooooool7ool000?ooooo00Co0000
oooooooooooo00000_ooool2o`0000Kooooo00?o0000ooooooooool00_ooool00ol0003oooooo`00
0005ooooo`;o00000oooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooo`0000;o
oooo00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooo`0000;ooooo00Go0000
ooooooooooooooooo`000002ooooo`07o`000?ooooooooooooooool0003oooooo`000004ooooo`03
o`000?oooooo000000Cooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00003oooo
o`03o`000?ooooooo`0000Ooo`000oooool00ol0003oooooooooo`02o`0000;ooooo00Co0000oooo
oooooooooooo0ol00002ooooo`;o000000?oooooo`000?ooool00_ooool00ol0003oooooooooo`0n
ooooo`00;Oooool01?l0003oooooo`000?ooool2o`0000?ooooo00?o0000ooooool000000_ooool0
1Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00oooool7ool000;ooooo00Co
0000oooooooooooooooo0_l000000ooooooo0000ooooo`05ooooo`;o00000_ooool01?l0003ooooo
ooooool00005ooooo`;o00000_ooool01Ol0003ooooooooooooooooo000000?ooooo00Ko0000oooo
oooooooo0000ooooool00004ooooo`07o`000?ooooooooooooooool0003oooooo`000002ooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02o`0000Kooooo00?o0000oooo
ool000000_ooool2o`0000Oooooo0_l000000ooooooo0000ooooo`02ooooo`03o`000?oo003oo`00
00;oo`0000Co0000ool00?oo003oo`001Oooool01?l0003oooooooooool00003ooooo`06o`000?oo
ooooooooo`000?oooooo00000oooool2o`000004ooooool0003oooooo`00047ooooo000^ooooo`04
o`000?oooooo0000o`0000?ooooo0ol00003ooooo`04o`000?ooooooooooooooo`;o000000?ooooo
o`000?ooool01Oooool3ool00003oooooooo003oo`0000;oo`001?ooool00ol0003oooooo`000007
ooooo`;o000000?oooooo`000?ooool00_ooool00ol0003oooooooooo`03ooooo`04o`000?oooooo
ooooo`0000Cooooo00?o0000ooooooooool00_ooool01Ol0003oooooo`000?oooooo000000Cooooo
00Wo0000ooooooooooooooooo`000?oooooo0000ooooool000001?ooool00ol0003oooooooooo`02
ooooo`04o`000?ooooooooooo`0000Kooooo00So0000oooooooooooo0000ooooool0003oooooo`00
00Oooooo0ol00002ooooo`Coo`000_ooool3ool000Oooooo0_l000001Ooooooo0000oooooooooooo
000000?ooooo0ol00003ooooo`;o000000?oooooo`000?l00000@Oooool002kooooo00?o0000oooo
ool000001?ooool2o`0000?ooooo00Ko0000ooooooooooooooooo`000?ooool2o`0000Kooooo0_l0
0003ool00003oooooooo003oo`0000;oo`000oooool00ol0003oooooo`000006ooooo`05o`000?oo
oooo0000ooooool000000_ooool00ol0003oooooooooo`04ooooo`;o000000?oooooo`000?ooool0
0_ooool00ol0003oooooooooo`03ooooo`04o`000?oooooo0000o`0000Gooooo00?o0000oooooooo
ool00_ooool2o`000003ooooool0003ooooo00Cooooo00Ko0000ooooooooooooooooo`000?ooool2
o`0000Kooooo00So0000oooooooooooo0000ooooool0003oooooo`0000Oooooo0_l00002ooooo`Co
o`000_ooool3ool000;o00001_ooool2o`000003ooooool0003ooooo00;ooooo00Co0000oooooooo
oooooooo0_l00004ooooo`04o`000?oooooo0000o`00047ooooo000]ooooo`?o00001?ooool3o`00
00;ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00Cooooo0_l00000
0ooooooo0000ool00002ool00003ooooool0003oo`0000?oo`0000Co0000ooooool0003o00001_oo
ool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Cooooo0ol00004ooooo`03o`00
0?oooooooooo00Cooooo00?o0000ooooool000001Oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooo000000Kooooo00?o0000ooooooooool00_ooool3o`0000Oooooo00Co0000oooooooooooo
00000_ooool00ol0003oooooooooo`05ooooo`;o00001?oo0002ooooo`06o`000?oo003oo`00ool0
0?l0003ooooo0_l00006ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00ol0
0004ooooo`03o`000?oooooo0000047ooooo000/ooooo`04o`000?oooooo0000o`0000?ooooo0_l0
0002ooooo`;o00000oooool01Ol0003ooooooooooooooooo000000Kooooo00Go0000oooooooooooo
ooooo`000003ool00003o`000?ooooooo`0000?oo`0000?oooooo`000?ooool01_ooool01?l0003o
ooooo`000?l00003ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooool000001?ooool00ol0
003oooooooooo`04ooooo`;o00001_ooool00ol0003oooooooooo`03ooooo`;o00001_ooool00ol0
003oooooooooo`02ooooo`?o00001oooool00ol0003oooooooooo`02o`0000;ooooo00?o0000oooo
ooooool01?ooool00ol0003oo`00ool00002ool000?ooooo0ooo00001Ol0003ooooooooooooooooo
000000Kooooo0_l00002ooooo`04o`000?ooooooooooooooo`;o00000_ooool2o`0000?ooooo1?l0
0010ooooo`00:oooool01?l0003oooooo`000?l00003ooooo`;o00000oooool2o`0000?ooooo00Ko
0000oooooooooooo0000ooooool00004ooooo`;o00000oooool00ol0003oooooool00002ool000;o
oooo00?o0000ool00?oo00000_oo0006ooooo`03o`000?oooooooooo00;o00000_ooool00ol0003o
ooooooooo`05ooooo`?o00001?ooool00ol0003oooooooooo`04ooooo`;o00001_ooool00ol0003o
ooooooooo`03ooooo`;o00001_ooool00ol0003oooooooooo`02ooooo`?o00001oooool02?l0003o
ooooooooool0003oooooo`000?oooooo00001Oooool4ool00004ooooool0003oooooooooo`?oo`00
00?oooooo`000?ooool00_ooool2o`0000Cooooo00?o0000ooooool000000oooool00ol0003ooooo
ooooo`02o`0000?ooooo0_l00003ooooo`;o000000?oooooo`000?ooool0?_ooool002[ooooo00?o
0000ooooooooool00_l00002ooooo`;o00001?ooool01Ol0003ooooooooooooooooo000000?ooooo
00?o0000ooooool000001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?oo`00
00?oooooo`000?ooool01_oo0003ooooo`03o`000?oooooo000000;ooooo00?o0000ooooool00000
1_ooool2o`000003ooooool0003ooooo00?ooooo00?o0000ooooooooool01?ooool2o`0000Kooooo
00?o0000ooooooooool00oooool2o`0000Kooooo00?o0000ooooooooool00_ooool01?l0003ooooo
o`000?l00006ooooo`03o`000?oooooo000000;ooooo00?o0000ooooool000000_ooool6ool00004
o`000?oooooo0000ooooo`?oo`0000?o0000ooooool000001?ooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0000?ooooo00Co0000oooooooooooo00001?ooool2o`0000;ooooo0ol0
00000ooooooo0000ooooo`0mooooo`00:Oooool01?l0003oooooooooool00002ooooo`04o`000?oo
oooo0000o`0000?ooooo0_l00002ooooo`05o`000?ooooooooooooooool000000_ooool01Ol0003o
oooooooooooooooo000000Gooooo00Co0000ooooool0003ooooo1?oo0002ooooo`03o`000?oo003o
o`0000Coo`0000?oooooo`000?l000000oooool00ol0003oooooo`000006ooooo`;o00000_ooool0
1Ol0003ooooooooooooooooo000000Kooooo00?o0000ooooool000001Oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooo000000Kooooo00Go0000ooooooooooooooooo`000002ooooo`;o0000
1oooool2o`0000?ooooo00?o0000oooooooo00001Ooo0002ooooo`03o`000?ooooooo`0000?oo`00
0_ooool2o`0000Gooooo00Go0000ooooooooooooooooo`000003ooooo`06o`000?oooooooooooooo
ool0003ooooo0_l00003ooooo`;o00000_ooool00ol0003oooooo`000002ooooo`03o`000?oooooo
oooo03_ooooo000Xooooo`04o`000?ooooooooooo`0000?ooooo0ol00003ooooo`03o`000?oooooo
oooo00;o00000oooool01Ol0003ooooooooooooooooo000000;ooooo0_l00006ooooo`;o00000_oo
ool4ool00005ooooool0003oooooo`000?ooool01_oo0004ooooo`03o`000?oooooooooo00Gooooo
00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00?ooooo0_l000000ooooooo
0000ooooo`04ooooo`03o`000?oooooooooo00;ooooo00Co0000ooooool0003o00001Oooool01Ol0
003ooooooooooooooooo000000?ooooo00?o0000ooooooooool01Oooool01?l0003ooooooooooooo
ool6ool000;ooooo00Co0000oooooooooooo00001?oo0003ooooo`03o`000?oooooooooo00Cooooo
0_l00002ooooo`05o`000?ooooooooooooooool000000oooool01Ol0003oooooo`000?oooooo0000
00?ooooo0_l000001Ooooooo0000oooooooooooo000000;ooooo00?o0000ooooooooool0>_ooool0
02Oooooo00Co0000oooooooooooo00001?ooool2o`0000Cooooo00?o0000ooooooooool00_l00003
ooooo`03o`000?oooooooooo00;ooooo0ol00007ooooo`04o`000?ooooooooooo`0000;ooooo0ooo
0003ooooo`03o`000?oooooooooo00Ooo`0000?oooooo`000?ooool01_ooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooo000000Gooooo00?o0000ooooool000000_ooool00ol0003ooooooooo
o`02ooooo`;o00000_ooool01_l0003oooooooooool0003oooooo`0000Gooooo00?o0000ooooool0
00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oo003oo`0000Goo`001?ooool00ol0003o
ooooooooo`03ool000;ooooo00?o0000ooooooooool00_l00006ooooo`?o00001Oooool01Ol0003o
oooooooooooooooo000000;ooooo00?o0000ooooooooool00_ooool3o`0000?ooooo00Co0000oooo
oooooooo0000>oooool002Oooooo00Co0000ooooool0003o00000oooool2o`0000Cooooo00Go0000
ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00?ooooo0ol00007ooooo`04o`000?oo
ooooooooo`0000?ooooo0ooo0002ooooo`06o`000?ooooooooooo`000?oooooo00002?oo0004oooo
o`;o00001?ooool00ol0003oooooo`000005ooooo`03o`000?oooooo000000;ooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooool000001Oooool0
0ol0003oooooo`000004ooooo`;o00000oooool8ool000;ooooo0_l00002ooooo`03o`000?oooooo
o`0000?oo`000oooool00ol0003oooooooooo`02o`0000Kooooo0ol00006ooooo`03o`000?oooooo
oooo00;o00000_ooool00ol0003oooooooooo`02ooooo`;o00001?ooool01?l0003oooooo`000?l0
000jooooo`009_ooool01?l0003oooooo`000?l00004ooooo`;o00000oooool01?l0003ooooooooo
ooooool2o`0000?ooooo00?o0000ooooooooool00oooool2o`0000Oooooo00Co0000ooooool0003o
00001?ooool01_l0003oo`00ool00?oo003oooooo`0000;ooooo0_l00004ooooo`Soo`000_l00006
ooooo`;o00001?ooool01?l0003oooooooooool00003ooooo`05o`000?ooooooooooooooool00000
0_ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool00_ooool2o`0000Ko
oooo00?o0000ool00?oo00001_oo0006ooooo`04o`000?ooooooooooo`0000Coo`0000?o0000oooo
ooooool00_ooool2o`0000;ooooo00?o0000ooooooooool01?ooool2o`0000Kooooo00Ko0000oooo
oooooooo0000ooooool00002ooooo`04o`000?ooooooooooooooo`;o00001Oooool01?l0003ooooo
o`000?l0000iooooo`009Oooool01?l0003oooooo`000?l00004ooooo`03o`000?oooooo000000?o
oooo00Co0000oooooooooooo00000_ooool00ol0003oooooo`000005ooooo`?o00001_ooool01?l0
003oooooooooool00005ooooo`03o`000?ooooooo`0000;oo`0000Coooooo`000?oooooo00001_oo
ool00ol0003oooooo`000008ool000Cooooo0_l00004ooooo`04o`000?ooooooooooo`0000?ooooo
00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool000000_ooool00ol0
003oooooooooo`02ooooo`;o00000oooool8ool00004ooooool0003oooooo`0000Kooooo0_l00000
1?ooooooo`00ool00?oo0003ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo0000
1_ooool3o`0000Kooooo00?o0000ooooool000000_ooool00ol0003oooooo`000003ooooo`03o`00
0?oooooo000000Gooooo00Co0000ooooool0003o0000>?ooool002Cooooo00Co0000ooooool0003o
00001?ooool01?l0003oooooooooool00002ooooo`05o`000?ooooooooooooooool000000_ooool2
o`0000Gooooo00Co0000ooooool0003o00001_ooool01?l0003oooooo`000?l00004ooooo`04o`00
0?ooooooooooooooo`?oo`000ol00006ooooo`03o`000?oooooo000000?ooooo2Ooo0002o`0000?o
oooo00Go0000ooooooooooooooooo`000004ooooo`06o`000?ooooooooooo`000?oooooo00001?oo
ool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ool00?oo00001ooo00001ol0003ooooo
oooooooooooo0000ooooool000001oooool01?l0003oo`00ool00?oo0004ooooo`03o`000?oooooo
oooo00;ooooo0_l000000ooooooo0000ooooo`05ooooo`;o000000?oooooo`000?ooool01Oooool2
o`0000;ooooo00Co0000oooooooooooo00000_ooool01?l0003oooooooooool00004ooooo`;o0000
00?oooooo`000?l00000=oooool002?ooooo00Go0000ooooool0003oooooo`000003ooooo`03o`00
0?oooooooooo00;ooooo0_l00003ooooo`04o`000?ooooooooooooooo`;o00001?ooool01Ol0003o
ooooo`000?oooooo000000Gooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`000?oo
oooooooo00;ooooo1?oo0007ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000ooooool0003o
oooo2ooo0003ooooo`03o`000?oooooooooo00;ooooo00Ko0000oooooooooooo0000ooooool00004
ooooo`03o`000?oooooooooo00_oo`000_ooool00ol0003oooooo`000002ooooo`04o`000?oooooo
ooooo`0000Kooooo1?oo0006ooooo`06o`000?ooooooooooo`000?oooooo00000_ooool00ol0003o
ooooooooo`03ooooo`05o`000?oooooo0000ooooool000001Oooool00ol0003oooooooooo`02oooo
o`06o`000?ooooooooooo`000?oooooo00000oooool00ol0003oooooooooo`02ooooo`;o000000?o
ooooo`000?l00000=_ooool002;ooooo00Go0000ooooool0003oooooo`000003ooooo`;o00001?oo
ool2o`0000;ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`05o`000?oo
oooo0000ooooool000001Oooool00ol0003oooooo`000002ooooo`05o`000?ooooooooooooooool0
00001Oooool4ool000Gooooo00Oo0000ooooooooooooooooo`000?oooooo000000;ooooo00?o0000
ooooooooool00ooooolSool000Kooooo00Ko0000oooooooooooo0000ooooool00003ooooo`03o`00
0?oooooooooo00;ooooo1?oo00000ol0003oooooooooo`04ooooo`04o`000?ooooooooooo`0000;o
oooo00?o0000ooooool000001Oooool01Ol0003oooooo`000?oooooo000000Gooooo0_l00004oooo
o`05o`000?oooooo0000ooooool000000oooool2o`0000Cooooo0_l000000ooooooo0000o`00000e
ooooo`008Oooool01Ol0003oooooo`000?oooooo000000Cooooo00?o0000ooooooooool00oooool0
1?l0003oooooooooool00004ooooo`03o`000?oooooo000000?ooooo00?o0000ooooool000000ooo
ool01ol0003ooooooooooooooooo0000ooooool000000oooool01?l0003oooooooooool00007oooo
o`04o`000?oo003oo`00ool000Cooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooo
oooo000000Oooooo0_l000000ooooooo0000ool0000Fool00006ooooool0003oooooo`000?oooooo
00001_ooool01Ol0003ooooooooooooooooo000000Cooooo00Co0000oooooooooooooooo0ooo0003
o`0000Kooooo00Co0000oooooooooooo00000oooool00ol0003oooooo`000003ooooo`07o`000?oo
ooooooooooooool0003oooooo`000004ooooo`03o`000?oooooo000000Cooooo00?o0000ooooool0
00001Oooool00ol0003oooooooooo`03ooooo`;o000000?oooooo`000?l00000=?ooool0027ooooo
0_l000000ooooooo0000ooooo`03ooooo`03o`000?oooooooooo00?ooooo0_l000000ooooooo0000
ooooo`04ooooo`03o`000?oooooo000000;ooooo00Co0000oooooooooooo00000oooool01?l0003o
ooooooooooooool2o`0000Cooooo00Co0000oooooooooooo00001_ooool3o`0000?oo`000oooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Sooooo0ol00005ooooo`03o`000?oo
oooooooo00Cooooo0_l00006ooooo`03o`000?oooooooooo00?ooooo0_l000000ooooooo0000oooo
o`06ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00ooo00001Ooooooo0000
o`000?oooooo000000Kooooo00?o0000ooooool000001?ooool2o`0000?ooooo00Go0000oooooooo
ooooooooo`000002ooooo`07o`000?ooooooooooooooool0003oooooo`000005ooooo`?o00001Ooo
ool00ol0003oooooooooo`03ooooo`Co0000=?ooool0023ooooo00Go0000ooooool0003oooooo`00
0003ooooo`03o`000?oooooooooo00Cooooo0ol00005ooooo`06o`000?ooooooooooo`000?oooooo
00000_ooool00ol0003oooooooooo`02ooooo`06o`000?ooooooooooo`000?oooooo00001Oooool2
o`0000Kooooo0_l00002ooooo`03o`000?oo003oo`0000;oo`0000?oooooo`000?ooool00_ooool2
o`0000;ooooo00?o0000ooooooooool01Oooool01?l0003oooooooooool00005ooooo`03o`000?oo
oooooooo00Cooooo0_l00006ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo0000
1oooool00ol0003oooooooooo`02o`0000?ooooo00?o0000ool00?oo00000_oo0002ooooo`05o`00
0?oooooo0000ooooool000001Oooool2o`0000Gooooo00?o0000ooooool000000_ooool00ol0003o
ooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001Oooool2
o`0000Kooooo00?o0000ooooooooool00_ooool2o`000003ooooool0003o000003?ooooo000Ooooo
o`05o`000?oooooo0000ooooool000000oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo
000000Kooooo00?o0000ooooooooool00_l00003ooooo`03o`000?oooooooooo00;ooooo00?o0000
ooooooooool00_l00006ooooo`;o00001_ooool2o`0000;ooooo00?o0000oooooooo00000ooo0004
ooooo`05o`000?oooooo0000ooooool000001oooool01?l0003oooooo`000?l00004ooooo`03o`00
0?oooooooooo00Gooooo0_l00007ooooo`03o`000?oooooooooo00;ooooo0_l000000ooooooo0000
ooooo`06ooooo`05o`000?oooooo0000ooooool000000oooool4ool000;ooooo00Ko0000oooooooo
oooo0000ooooool00005ooooo`;o00001_ooool2o`0000;ooooo00?o0000ooooooooool00_ooool0
1?l0003oooooooooooooool2o`0000?ooooo00?o0000ooooooooool00oooool3o`0000Kooooo00?o
0000ooooooooool00_ooool2o`000003ooooool0003o000003;ooooo000Nooooo`05o`000?oooooo
0000ooooool000000oooool2o`0000Kooooo0ol00005ooooo`03o`000?oooooooooo00;ooooo00Co
0000oooooooooooo00001_ooool3o`0000Oooooo00?o0000ooooooooool01?ooool00ol0003ooooo
o`000002ooooo`04o`000?ooooooooooooooo`?oo`000_ooool01_l0003oooooooooool0003ooooo
o`0000Oooooo00Go0000ooooool0003oooooo`000003ooooo`03o`000?oooooooooo00Gooooo0_l0
0007ooooo`09o`000?ooooooooooooooool0003oooooo`000?oooooo000000Oooooo00?o0000oooo
ool000000_ooool00ol0003oooooool00002ool000Cooooo00Co0000oooooooooooo00000_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Gooooo0ol00006ooooo`03o`000?oooooo
oooo00;o00001?ooool00ol0003oooooooooo`02ooooo`?o00001_ooool2o`0000Cooooo0_l00000
0ooooooo0000o`00000aooooo`007Oooool01Ol0003oooooo`000?oooooo000000?ooooo0_l00006
ooooo`;o00000_ooool01Ol0003ooooooooooooooooo000000Cooooo0_l000000ooooooo0000oooo
o`06ooooo`;o00002?ooool2o`0000Cooooo00?o0000ooooool000001?ooool01?l0003ooooooooo
ooooool3ool00007o`000?ooooooooooooooool0003oooooo`000007ooooo`;o00000_ooool01Ol0
003ooooooooooooooooo000000Kooooo00Co0000ooooool0003o00001_ooool01Ol0003ooooooooo
oooooooo000000;ooooo0_l00007ooooo`03o`000?oooooo000000?ooooo0ooo00000ol0003ooooo
ooooo`02ooooo`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooooooool2o`00
00Sooooo0_l00007ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00000_oo
ool2o`0000Kooooo0_l00004ooooo`;o000000?oooooo`000?l00000<?ooool001cooooo00Go0000
ooooool0003oooooo`000004ooooo`03o`000?oooooooooo00Cooooo0_l00003ooooo`05o`000?oo
ooooooooooooool000000oooool01Ol0003oooooo`000?oooooo000000Oooooo0_l00008ooooo`;o
00001?ooool00ol0003oooooo`000004ooooo`05o`000?ooooooooooooooool000001?oo0003oooo
o`03o`000?oooooooooo00Kooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooo
oooo00Cooooo00Co0000ooooool0003o00001_ooool01Ol0003ooooooooooooooooo000000?ooooo
00?o0000ooooooooool01_ooool00ol0003oooooooooo`04ool00003ooooool0003ooooo00?ooooo
00Go0000ooooooooooooooooo`000002ooooo`04o`000?ooooooooooooooo`;o00002?ooool2o`00
00Oooooo00?o0000ooooooooool00_l00004ooooo`04o`000?ooooooooooo`0000?ooooo0_l00006
ooooo`03o`000?oooooooooo00?ooooo0_l000000ooooooo0000ooooo`0_ooooo`006oooool00ol0
003oooooooooo`02o`0000Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02oooo
o`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool00_l00008ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooool000000oooool01?l0003oooooooooool00004ooooo`04o`000?oo
ooooooooo`0000;ooooo1?oo0002ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool0
0_ooool01?l0003oooooooooool00005ooooo`06o`000?ooooooooooo`000?oooooo00001Oooool0
1?l0003oooooooooool00004ooooo`;o00001oooool00ol0003oooooool00003ool00004o`000?oo
ooooooooo`0000;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000;o
oooo00?o0000ooooool000002?ooool00ol0003oooooooooo`06ooooo`05o`000?oooooo0000oooo
ool000001?ooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00_ooool01Ol0003oooooo`000?oooooo000002oooooo000Jooooo`03o`000?oooooooooo
00;o00001?ooool2o`0000Kooooo00?o0000ooooooooool00oooool01?l0003oooooooooool00002
ooooo`04o`000?ooooooooooooooo`;o00001oooool00ol0003oooooo`000007ooooo`03o`000?oo
oooo000000;ooooo00Co0000oooooooooooo00001_ooool00ol0003oooooo`000002ooooo`03o`00
0?ooooooo`0000?oo`0000?o0000ooooooooool01Oooool2o`0000Cooooo00Co0000oooooooooooo
00001Oooool01_l0003oooooooooool0003oooooo`0000Gooooo00Co0000oooooooooooo00001Ooo
ool00ol0003oooooooooo`05ooooo`Coo`000oooool00ol0003oooooo`000002ooooo`03o`000?oo
oooooooo00?ooooo00Wo0000ooooooooooooooooo`000?oooooo0000ooooool000001oooool00ol0
003oooooo`000007ooooo`;o00000oooool01ol0003ooooooooooooooooo0000ooooool000001Ooo
ool00ol0003oooooooooo`04ooooo`;o00001?ooool01Ol0003oooooo`000?oooooo000002kooooo
000Jooooo`04o`000?oooooo0000o`0000Cooooo0_l00006ooooo`03o`000?oooooooooo00Cooooo
00?o0000ooooool000000_ooool00ol0003oooooooooo`02ooooo`;o00001_ooool2o`000003oooo
ool0003ooooo00Gooooo00Oo0000ooooooooooooooooo`000?oooooo000000;ooooo00?o0000oooo
ooooool01?ooool01Ol0003oooooo`000?oooooo000000?ooooo1Ooo0006ooooo`;o00001Oooool0
0ol0003oooooo`000004ooooo`04o`000?ooooooooooooooo`;o000000?oooooo`000?ooool00ooo
ool00ol0003oooooo`000006ooooo`03o`000?oooooooooo00Cooooo1?oo0004ooooo`03o`000?oo
oooo000000;ooooo00?o0000ooooooooool00oooool01?l0003oooooooooooooool2o`0000?ooooo
00?o0000ooooooooool01?ooool01?l0003oooooo`000?l00007ooooo`03o`000?oooooooooo00;o
oooo00Co0000oooooooooooooooo0_l00006ooooo`03o`000?oooooooooo00Cooooo0_l00004oooo
o`03o`000?oooooo000000;o0000;Oooool001Wooooo00Go0000ooooool0003oooooo`000003oooo
o`;o00001_ooool2o`0000Kooooo0_l00003ooooo`07o`000?ooooooooooooooool0003oooooo`00
0006ooooo`;o000000?oooooo`000?ooool01Oooool01?l0003oooooooooooooool2o`0000?ooooo
00?o0000ooooooooool01?ooool01?l0003oooooo`000?l00006ooooo`Coo`001?ooool00ol0003o
ooooo`000005ooooo`03o`000?oooooo000000Cooooo00Go0000ooooooooooooooooo`000002oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooool000001_ooool2o`0000Cooooo0ooo0007oooo
o`;o000000?oooooo`000?ooool01Oooool00ol0003oooooooooo`02ooooo`05o`000?oooooooooo
ooooool000001_ooool01?l0003oooooo`000?l00007ooooo`;o00000oooool00ol0003ooooooooo
o`02ooooo`03o`000?oooooooooo00Cooooo0_l00006ooooo`;o00001?ooool2o`000003ooooool0
003o000002cooooo000Hooooo`05o`000?oooooo0000ooooool000000oooool2o`0000Oooooo00?o
0000ooooooooool01_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooo000000Gooooo
0_l00002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_ooool2o`0000;ooooo
00?o0000ooooooooool01_ooool3o`0000Kooooo00?o0000oooooooo00000ooo0002ooooo`03o`00
0?oooooo000000Kooooo0_l00003ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`000003ooooo`;o00001oooool2o`0000;ooooo1?oo00000ooooooo0000ooooo`05ooooo`;o
000000?oooooo`000?ooool01_ooool01Ol0003ooooooooooooooooo000000Cooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02o`0000Kooooo0_l00004ooooo`03o`000?oooooooooo
00;o00001oooool00ol0003oooooooooo`05ooooo`;o00001?ooool2o`000003ooooool0003ooooo
02_ooooo000Gooooo`05o`000?oooooo0000ooooool000000oooool00ol0003oooooo`000006oooo
o`03o`000?oooooooooo00Kooooo0_l000000ooooooo0000ooooo`03ooooo`04o`000?oooooooooo
o`0000Cooooo00?o0000ooooool000000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo
oooo00;ooooo0_l00002ooooo`03o`000?oooooooooo00Kooooo0_l00007ooooo`03o`000?oooooo
oooo00Coo`0000?o0000ooooool000001oooool2o`0000?ooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000000?ooooo0_l00007ooooo`03o`000?oooooo000000Coo`000_oo
ool00ol0003oooooooooo`05ooooo`?o00001oooool01_l0003oooooooooool0003oooooo`0000?o
oooo00?o0000ooooooooool00_ooool01ol0003ooooooooooooooooo0000ooooool000001Oooool0
0ol0003oooooo`000004ooooo`05o`000?oooooo0000ooooool000001oooool00ol0003ooooooooo
o`04ooooo`03o`000?oooooo000000?ooooo00Go0000ooooool0003oooooo`00000[ooooo`005_oo
ool00ol0003oooooooooo`02o`0000?ooooo00?o0000ooooool000001_ooool2o`0000Sooooo0ol0
0005ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooool000001?ooool00ol0003ooooo
ooooo`02ooooo`09o`000?ooooooooooooooool0003oooooo`000?oooooo000000Wooooo0_l00007
ooooo`05o`000?ooooooooooo`000?ooool01?oo00000ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo
00?o0000ooooooooool01Oooool00ol0003oo`00ool00002ool00005ooooool0003oooooooooool0
00002?ooool2o`0000Sooooo00?o0000ooooool000000_ooool01?l0003oooooooooool00004oooo
o`03o`000?oooooooooo00;ooooo00?o0000ooooool000000oooool01?l0003oooooooooool00005
ooooo`;o000000?oooooo`000?ooool01_ooool2o`0000Kooooo00?o0000ooooool000000oooool0
1Ol0003oooooo`000?oooooo000002[ooooo000Eooooo`03o`000?oooooooooo00;o00001?ooool2
o`0000Kooooo0_l00008ooooo`03o`000?oooooo000000Gooooo00?o0000ooooooooool00_ooool0
1_l0003oooooooooool0003oooooo`0000Cooooo00Go0000ooooooooooooooooo`000004ooooo`05
o`000?oooooo0000ooooool000002Oooool2o`0000Oooooo00Ko0000ooooooooooooooooo`000?oo
ool4ool000Oooooo0_l00002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`02o`0000Kooooo1Ooo00000ooooooo0000ooooo`02ooooo`03o`000?oo
oooooooo00Kooooo00?o0000ooooooooool01oooool00ol0003oooooo`000002ooooo`05o`000?oo
ooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000?ooooo
00Go0000ooooooooooooooooo`000005ooooo`04o`000?ooooooooooo`0000Oooooo0_l00006oooo
o`;o00001?ooool01Ol0003oooooo`000?oooooo000002Wooooo000Dooooo`03o`000?oooooooooo
00;o00001?ooool2o`0000Kooooo0_l00008ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000
ooooooooool00_ooool01Ol0003oooooo`000?oooooo000000Gooooo00Go0000oooooooooooooooo
o`000003ooooo`06o`000?ooooooooooo`000?oooooo00002Oooool2o`0000Oooooo00So0000oooo
ooooooooooooo`000?oooooo0000ooooo`Coo`001Oooool2o`0000;ooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;o00001Oooool4ool00004oooo
ool0003oooooo`0000?ooooo00?o0000ooooooooool01_ooool2o`0000Sooooo00?o0000ooooool0
00000oooool01?l0003oooooooooool00003ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ool000000_ooool01Ol0003ooooooooooooooooo000000Gooooo00Go0000ooooooooooooooooo`00
0007ooooo`;o00001_ooool2o`0000Cooooo00Go0000ooooool0003oooooo`00000Xooooo`005?oo
ool01?l0003oooooo`000?l00004ooooo`03o`000?oooooo000000Kooooo00?o0000ooooooooool0
1oooool01Ol0003oooooo`000?oooooo000000?ooooo00?o0000ooooooooool00oooool2o`0000;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01oooool00ol0003oooooo`000006ooooo`03o`000?oooooooooo00?o
oooo00Co0000oooooooooooooooo1Ooo0003ooooo`04o`000?oooooo0000o`0000Kooooo00?o0000
ooooooooool00oooool01?l0003oooooo`000?l00003ooooo`Coo`0000Coooooo`000?oooooooooo
0_l00004ooooo`03o`000?oooooooooo00Gooooo0_l00009ooooo`03o`000?oooooooooo00?ooooo
00Ko0000oooooooooooo0000ooooool00006ooooo`06o`000?ooooooooooo`000?oooooo00001?oo
ool01ol0003ooooooooooooooooo0000ooooool000000_ooool00ol0003oooooooooo`06ooooo`03
o`000?oooooooooo00Cooooo00?o0000ooooool000001?ooool01?l0003oooooo`000?l0000Xoooo
o`004oooool01Ol0003oooooo`000?oooooo000000?ooooo00?o0000ooooool000001_ooool2o`00
00Sooooo00?o0000ooooool000000_ooool01?l0003oooooooooool00006ooooo`04o`000?oooooo
ooooo`0000Oooooo00?o0000ooooool000000oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00Oooooo00Co0000oooooooooooo00001Oooool00ol0003oooooooooo`03ooooo`06o`00
0?ooooooooooooooool0003ooooo1?oo0002ooooo`04o`000?oooooo0000o`0000Kooooo00?o0000
ooooooooool00oooool2o`000003ooooool0003ooooo00Goo`000_ooool01?l0003oooooooooool0
0005ooooo`03o`000?oooooooooo00Cooooo00Co0000ooooool0003o00002?ooool00ol0003ooooo
ooooo`03ooooo`06o`000?ooooooooooo`000?oooooo00001oooool01?l0003oooooooooool00006
ooooo`04o`000?ooooooooooo`0000;ooooo00Co0000oooooooooooo00001oooool2o`0000Kooooo
00?o0000ooooool000000oooool00ol0003oooooooooo`02o`0002Oooooo000Booooo`03o`000?oo
oooooooo00;o00000oooool00ol0003oooooo`000006ooooo`;o00002?ooool00ol0003oooooo`00
0003ooooo`04o`000?ooooooooooo`0000Kooooo00Co0000oooooooooooo00001oooool2o`0000?o
oooo00?o0000ooooooooool00oooool00ol0003oooooooooo`06ooooo`;o00000_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000000_ooool01?l0003o
ooooooooooooool4ool00004o`000?oooooo0000o`0000Kooooo00?o0000ooooooooool01?ooool0
0ol0003oooooo`000004ool000Cooooo00?o0000ooooooooool00_l00004ooooo`03o`000?oooooo
oooo00Cooooo00Go0000ooooool0003oooooo`000007ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool00_l00007ooooo`04o`000?ooooooooooo`0000Kooooo00Co0000oooooooooooo
00000oooool01?l0003oooooooooool00007ooooo`;o00001_ooool00ol0003oooooo`000003oooo
o`05o`000?oooooo0000ooooool000009_ooool0017ooooo00?o0000ooooooooool00_l00003oooo
o`03o`000?oooooo000000Kooooo0_l00009ooooo`;o00001?ooool00ol0003oooooo`000006oooo
o`;o00000_ooool00ol0003oooooooooo`05ooooo`;o00000_ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooo000000Kooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`03oooo
o`05o`000?ooooooooooooooool000000_ooool01?l0003oooooooooool00004ooooo`Coo`0000?o
ooooo`000?l000001_ooool00ol0003oooooooooo`03ooooo`;o00001?oo0006ooooo`03o`000?oo
oooo000000;ooooo00Go0000ooooooooooooooooo`000006ooooo`05o`000?oooooo0000ooooool0
00001_ooool00ol0003oooooo`000006ooooo`04o`000?oooooo0000o`0000Oooooo00?o0000oooo
ooooool00_l00006ooooo`03o`000?oooooo000000Cooooo00?o0000ooooool000002?ooool2o`00
00Kooooo00?o0000ooooool000000oooool01Ol0003oooooo`000?oooooo000002Gooooo000@oooo
o`03o`000?oooooooooo00;o00000oooool01?l0003oooooooooool00005ooooo`03o`000?oooooo
000000Sooooo00?o0000ooooool000001?ooool00ol0003oooooo`000005ooooo`03o`000?oooooo
oooo00;o00002?ooool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooool000001_oo
ool2o`0000?ooooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000;ooooo
00?o0000ooooool000001oooool4ool00003o`000?oooooooooo00Cooooo00?o0000ooooooooool0
0oooool5ool000Sooooo0_l00002ooooo`05o`000?ooooooooooooooool000001Oooool01ol0003o
oooooooooooooooo0000ooooool000001Oooool00ol0003oooooo`000006ooooo`04o`000?oooooo
ooooo`0000Sooooo00Go0000ooooool0003oooooo`000005ooooo`03o`000?oooooo000000Cooooo
00Co0000oooooooooooo00001oooool00ol0003oooooo`000005ooooo`04o`000?ooooooooooo`00
00?ooooo00Go0000ooooool0003oooooo`00000Tooooo`003oooool00ol0003oooooooooo`02o`00
00Cooooo00?o0000ooooool000001Oooool00ol0003oooooo`000008ooooo`03o`000?oooooo0000
00Kooooo00?o0000ooooooooool00oooool01?l0003oooooooooooooool2o`0000Sooooo0_l00000
0ooooooo0000ooooo`05ooooo`03o`000?oooooo000000Gooooo00?o0000ooooool000001?ooool0
1Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_ooool2o`0000Sooooo1Ooo
0005ooooo`04o`000?ooooooooooooooo`Goo`0000?o0000ooooooooool01oooool2o`0000?ooooo
00Go0000ooooooooooooooooo`000004ooooo`07o`000?ooooooooooooooool0003oooooo`000005
ooooo`03o`000?oooooo000000Oooooo0ol00008ooooo`;o00000oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooool000002?ooool00ol0003oooooo`000005
ooooo`03o`000?oooooo000000Cooooo00Go0000ooooool0003oooooo`00000Sooooo`003_ooool0
1_l0003oooooooooool0003oooooo`0000?ooooo00?o0000ooooool000001_ooool2o`0000Wooooo
0_l00007ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`000008ooooo`04
o`000?oooooo0000o`0000Kooooo00Co0000oooooooooooo00001Oooool00ol0003oooooo`000004
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`;o00002?oo
ool00ol0003oooooool00003ool000Cooooo00?o0000ooooooooool01?oo0002ooooo`03o`000?oo
oooooooo00Oooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000Cooooo
00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooo
oooo00001oooool00ol0003oooooo`000008ooooo`05o`000?ooooooooooooooool000001Oooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooo000000Sooooo0_l00006ooooo`03o`000?oooooo
000000?ooooo00Ko0000oooooooooooo0000ooooool0000Rooooo`003Oooool01_l0003ooooooooo
ool0003oooooo`0000?ooooo00?o0000ooooool000001_ooool2o`0000Wooooo0_l00007ooooo`;o
00001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooool0
00001oooool01Ol0003ooooooooooooooooo000000?ooooo00?o0000ooooool000001Oooool01Ol0
003ooooooooooooooooo000000;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`06
ooooo`04o`000?ooooooooooooooo`Coo`000_ooool00ol0003oo`00ool00002ool00005o`000?oo
ooooooooooooool000002Oooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000?o
oooo00?o0000ooooooooool00oooool01?l0003oooooooooool00002ooooo`05o`000?oooooooooo
ooooool000001oooool3o`0000Sooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02
ooooo`;o00001oooool00ol0003oooooo`000008ooooo`;o00001_ooool00ol0003oooooo`000003
ooooo`06o`000?ooooooooooo`000?oooooo00008Oooool000cooooo0_l000001?oooooo0000oooo
ool00003ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000ooooool000002?ooool2o`0000Oo
oooo00?o0000ooooool000000oooool00ol0003oooooooooo`02ooooo`;o00002?ooool00ol0003o
ooooo`000007ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooo`000006oooo
o`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`05
ooooo`;o00001?ooool9ool00003ooooool0003ooooo00;ooooo0_l00008ooooo`03o`000?oooooo
oooo00?ooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`03ooooo`04o`000?oo
ooooooooo`0000;ooooo00Go0000ooooooooooooooooo`000007ooooo`?o00002?ooool2o`0000Co
oooo00Oo0000ooooooooooooooooo`000?oooooo000000Oooooo0_l00008ooooo`03o`000?oooooo
000000Gooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`03o`00023ooooo000;
ooooo`;o000000Coooooo`000?oooooo00000oooool01?l0003oooooooooool00005ooooo`03o`00
0?oooooo000000Sooooo00?o0000ooooool000001oooool00ol0003oooooo`000003ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooool000001_ooool01Ol0003oooooo`000?oooooo000000Go
oooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00002ooooo`03o`000?oooooooooo
00Cooooo00Ko0000oooooooooooo0000ooooool00007ooooo`;o00001_ooool2o`0000Gooooo00?o
0000ool00?oo00000ooo0002ooooo`03o`000?oooooooooo00;ooooo0_l00007ooooo`;o00001_oo
ool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00?ooooo00Oo0000oooooooooooooooo
o`000?oooooo000000Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02o`0000Oo
oooo0_l00005ooooo`06o`000?ooooooooooo`000?oooooo00001oooool00ol0003oooooo`000008
ooooo`03o`000?oooooo000000Gooooo00Co0000oooooooooooo00000oooool00ol0003ooooooooo
o`03o`0001oooooo000:ooooo`;o000000Coooooo`000?oooooo00000oooool01?l0003ooooooooo
ool00005ooooo`03o`000?oooooo000000Wooooo0_l00007ooooo`07o`000?ooooooooooooooool0
003oooooo`000004ooooo`04o`000?ooooooooooo`0000Kooooo0_l00002ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool00oooool2o`0000;ooooo00?o0000ooooooooool01Oooool0
0ol0003oooooo`000002ooooo`03o`000?oooooooooo00Gooooo0_l00005ooooo`03o`000?oooooo
000000Gooooo1ooo00000ooooooo0000ooooo`03ooooo`03o`000?oooooo000000Kooooo0_l00006
ooooo`06o`000?ooooooooooo`000?oooooo00001oooool01?l0003oooooooooooooool2o`0000Co
oooo00?o0000ooooooooool00oooool01Ol0003ooooooooooooooooo000000Kooooo00Co0000oooo
oooooooo00001?ooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00Gooooo00?o0000
ooooool000002?ooool00ol0003oooooo`000005ooooo`04o`000?ooooooooooo`0000?ooooo00?o
0000ooooooooool00ol0000Nooooo`002Oooool2o`000004ooooool0003oooooo`0000?ooooo00Co
0000oooooooooooo00001_ooool00ol0003oooooo`000008ooooo`;o00002?ooool01?l0003ooooo
ooooooooool2o`0000Gooooo00Co0000oooooooooooo00001Oooool00ol0003oooooo`000002oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool2o`0000;ooooo00?o0000oooo
ooooool01_ooool2o`000003ooooool0003ooooo00Kooooo00?o0000ooooool000001Oooool00ol0
003oooooo`000003ooooo`Goo`0000?oooooool00?oo00000ooo0004ooooo`03o`000?oooooo0000
00Kooooo00?o0000ooooool000001_ooool01Ol0003oooooo`000?oooooo000000Oooooo00Go0000
ooooooooooooooooo`000005ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooooooo
0_l00005ooooo`04o`000?ooooooooooo`0000Gooooo0_l00003ooooo`03o`000?oooooooooo00Ko
oooo0_l00008ooooo`03o`000?oooooo000000Kooooo00Co0000oooooooooooo00000oooool00ol0
003oooooooooo`03o`0001gooooo0008ooooo`;o000000Goooooo`000?ooooooooooo`000002oooo
o`04o`000?ooooooooooo`0000Kooooo00?o0000ooooool000002?ooool2o`0000Sooooo00?o0000
ooooooooool00_ooool2o`0000Cooooo00Go0000ooooooooooooooooo`000005ooooo`;o00000ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00Go0000oooooooooooooooo
o`000008ooooo`?o00002?ooool01?l0003oooooooooool00003ooooo`03o`000?oooooo000000;o
oooo1Ooo00001Ol0003oooooooooool0003ooooo00Goo`000oooool00ol0003oooooo`000004oooo
o`04o`000?ooooooooooo`0000Oooooo0ol00008ooooo`04o`000?ooooooooooooooo`;o00001Ooo
ool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00ooo
ool01Ol0003ooooooooooooooooo000000Gooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`06ooooo`;o00002?ooool00ol0003oooooo`000006ooooo`04o`000?ooooooooooo`0000;o
oooo00Co0000oooooooooooooooo0ol0000Looooo`001oooool2o`000005ooooool0003ooooooooo
ool000000oooool01?l0003oooooooooool00005ooooo`03o`000?oooooo000000Wooooo00?o0000
ooooooooool01oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00Go0000
ooooooooooooooooo`000004ooooo`;o00001Oooool01Ol0003ooooooooooooooooo000000Gooooo
00?o0000ooooool000000_ooool00ol0003oooooooooo`06ooooo`?o00002?ooool01?l0003ooooo
ooooool00003ooooo`03o`000?oooooo000000Goo`000_ooool01?l0003oooooooooool00002oooo
o`03o`000?oo003oo`0000?oo`0000Coooooo`000?oooooo00001?ooool01?l0003oooooooooool0
0007ooooo`?o00002?ooool01?l0003oooooooooooooool2o`0000Gooooo00Go0000oooooooooooo
ooooo`000006ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000005oooo
o`;o00000oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Oooooo00?o0000oooo
ool000001Oooool01?l0003oooooooooool00003ooooo`04o`000?ooooooooooooooo`?o00006ooo
ool000Gooooo0_oo00000ol0003oooooo`000002ooooo`05o`000?ooooooooooooooool000000_oo
ool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000Sooooo0_l00008ooooo`03o`00
0?oooooooooo00;ooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo00Go0000oooooooooooo
ooooo`000006ooooo`05o`000?ooooooooooooooool000001Oooool01Ol0003oooooo`000?oooooo
000000[ooooo00?o0000ooooooooool01oooool02?l0003ooooooooooooooooo0000ooooool0003o
oooo1Ooo0005ooooo`05o`000?oooooo0000ooooool000000oooool5ool000;ooooo00Co0000oooo
oooooooo00000oooool00ol0003oooooooooo`06ooooo`;o00002Oooool01_l0003oooooooooool0
003oooooo`0000Cooooo00Go0000ooooooooooooooooo`000006ooooo`;o00000_ooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo0_l00004ooooo`03o`000?oooooooooo00Ko
oooo0_l00009ooooo`03o`000?oooooo000000Gooooo00Co0000oooooooooooo00000oooool01Ol0
003ooooooooooooooooo000000;oo`006_ooool000Gooooo0ooo00001?l0003oooooooooool00003
ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00002?ooool2o`0000Wooooo
00Oo0000ooooooooooooooooo`000?oooooo000000Cooooo00?o0000ooooooooool00oooool01Ol0
003ooooooooooooooooo000000Kooooo00Co0000oooooooooooo00001Oooool01_l0003ooooooooo
ool0003oooooo`0000Wooooo0_l00009ooooo`06o`000?ooooooooooooooool0003ooooo1Ooo0007
ooooo`05o`000?oooooo0000ooooool000001Oooool5ool00004o`000?ooooooooooo`0000?ooooo
00?o0000ooooooooool01_ooool2o`0000Wooooo00?o0000ooooool000000oooool00ol0003ooooo
ooooo`02ooooo`04o`000?ooooooooooo`0000Kooooo0_l00002ooooo`03o`000?oooooooooo00?o
oooo00?o0000ooooooooool00_ooool00ol0003oooooo`000003ooooo`03o`000?oooooooooo00Oo
oooo0_l00008ooooo`04o`000?ooooooooooo`0000Gooooo00Co0000oooooooooooo00000oooool0
0ol0003oooooooooo`03ool001[ooooo0005ooooo`Coo`0000?oooooo`000?ooool00_ooool01?l0
003oooooooooool00006ooooo`03o`000?oooooo000000Wooooo00?o0000ooooooooool01oooool0
0ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01?oo
ool01?l0003oooooooooool00007ooooo`04o`000?ooooooooooo`0000Cooooo00Oo0000oooooooo
ooooooooo`000?oooooo000000Wooooo0_l00009ooooo`04o`000?ooooooooooooooo`Goo`0000?o
0000ooooooooool01_ooool01?l0003oooooo`000?l00008ooooo`Goo`0000?oooooo`000?ooool0
0_ooool00ol0003oooooooooo`06ooooo`;o00002Oooool00ol0003oooooo`000003ooooo`03o`00
0?oooooooooo00;ooooo00Co0000oooooooooooo00001oooool2o`000003ooooool0003ooooo00Go
oooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooooooo000000Wooooo00?o0000
ooooooooool01oooool01?l0003oooooooooool00005ooooo`04o`000?ooooooooooo`0000?ooooo
00?o0000ool00?oo00000_oo000Jooooo`001_ooool4ool000?ooooo00Go0000oooooooooooooooo
o`000005ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool01oooool00ol0003o
ooooooooo`02ooooo`05o`000?ooooooooooooooool000000_ooool00ol0003oooooooooo`04oooo
o`04o`000?oooooo0000o`0000Sooooo00?o0000ooooool000000oooool00ol0003oooooooooo`03
ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooool000002?ooool00ol0003oooooool00004
ool000;ooooo00?o0000ooooooooool01oooool3o`0000Sooooo00?o0000oooooooo00001?oo0003
ooooo`03o`000?oooooooooo00Kooooo0_l0000:ooooo`;o00001?ooool01ol0003ooooooooooooo
oooo0000ooooool000002?ooool01?l0003oooooo`000?l00007ooooo`03o`000?oooooo000000Co
oooo00Go0000ooooooooooooooooo`000009ooooo`03o`000?oooooooooo00Oooooo00Co0000oooo
oooooooo00001?ooool01Ol0003ooooooooooooooooo000000;ooooo1?oo000Kooooo`001oooool4
ool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool00oooool01?l0003oooooooooool0
0009ooooo`03o`000?oooooooooo00Oooooo00Go0000ooooooooooooooooo`000004ooooo`04o`00
0?ooooooooooo`0000Kooooo00Co0000ooooool0003o00002?ooool00ol0003oooooo`000003oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01oooool2o`000003ooooool0003ooooo
00Kooooo1_oo00001Ol0003ooooooooooooooooo000000Wooooo0_l00009ooooo`04o`000?oooooo
ooooooooo`Koo`0000?oooooo`000?ooool01Oooool01?l0003oooooo`000?l00009ooooo`;o0000
1Oooool01?l0003oooooooooooooool2o`0000Wooooo0ol00007ooooo`03o`000?oooooo000000Co
oooo00Go0000ooooooooooooooooo`000009ooooo`;o00002Oooool01?l0003oooooooooool00004
ooooo`05o`000?ooooooooooooooool000001?oo000Looooo`002?ooool4ool000?ooooo00?o0000
ooooooooool00oooool01?l0003oooooooooool00009ooooo`03o`000?oooooooooo00Oooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000Sooooo0_l0
0009ooooo`;o00000oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00Oooooo0_l0
00000ooooooo0000ooooo`04ooooo`Koo`0000?oooooo`000?l000000oooool00ol0003ooooooooo
o`08ooooo`03o`000?oooooooooo00Oooooo00?o0000ooooooooool00_ooool00ol0003oo`00ool0
0004ool000Kooooo00Co0000ooooool0003o00002Oooool00ol0003oooooooooo`04ooooo`04o`00
0?ooooooooooooooo`;o00002Oooool3o`0000Sooooo0_l00005ooooo`05o`000?oooooooooooooo
ool000002Oooool00ol0003oooooooooo`07ooooo`04o`000?ooooooooooo`0000Gooooo00?o0000
ooooooooool01?oo000Mooooo`002Oooool4ool00003ooooool0003ooooo00Cooooo00Co0000oooo
oooooooo00002Oooool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool000001Ooo
ool00ol0003oooooo`000007ooooo`?o00002Oooool2o`0000;ooooo00?o0000ooooooooool01?oo
ool00ol0003oooooo`000007ooooo`;o00000oooool00ol0003oooooooooo`05ool000Cooooo00?o
0000ooooool000000_ooool00ol0003oooooooooo`07ooooo`;o00002Oooool01?l0003ooooooooo
ooooool2o`0000?ooooo1Ooo0004ooooo`03o`000?oooooooooo00;o00002?ooool2o`0000Kooooo
00?o0000ooooooooool00_l00009ooooo`;o000000?oooooo`000?ooool01_ooool2o`0000Kooooo
00Co0000oooooooooooo00002_ooool00ol0003oooooooooo`07ooooo`04o`000?ooooooooooo`00
00Gooooo00?o0000ool00?oo00000_oo000Nooooo`002_ooool5ool000Gooooo00Co0000oooooooo
oooo00002?ooool2o`0000Wooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooo
oooo00Kooooo0ol0000:ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooool000001ooo
ool2o`0000?ooooo1_oo00000ooooooo0000ooooo`02ooooo`04o`000?ooooooooooo`0000;ooooo
00?o0000ooooooooool01oooool3o`0000Sooooo00Oo0000ooooooooooooooooo`000?oooooo0000
00Cooooo1_oo00001ol0003ooooooooooooooooo0000ooooool000001oooool2o`0000Kooooo00?o
0000ooooooooool00_l0000:ooooo`03o`000?oooooo000000Sooooo00?o0000ooooooooool01Ooo
ool01?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00Oooooo00Co0000oooooooooooo
00001?ooool5ool001kooooo000;ooooo`Goo`000oooool01?l0003oooooooooool00008ooooo`;o
00002_ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool01Oooool00ol0
003oooooo`00000:ooooo`;o000000?oooooo`000?ooool01_ooool00ol0003oooooo`000006oooo
o`04o`000?oooooo0000ooooo`Koo`000oooool01Ol0003ooooooooooooooooo000000?ooooo00?o
0000ooooool000002?ooool01?l0003oooooo`000?l00008ooooo`04o`000?ooooooooooo`0000;o
oooo00?o0000ooooooooool00_ooool00ol0003oooooool00006ool00004ooooool0003oooooo`00
00Oooooo0_l00007ooooo`04o`000?oooooo0000o`0000[ooooo00Co0000oooooooooooo00001ooo
ool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000[ooooo0_l00009ooooo`04o`00
0?ooooooooooo`0000;ooooo1Ooo000Oooooo`003?ooool5ool00005ooooool0003oooooooooool0
00002Oooool2o`0000Wooooo00Go0000ooooooooooooooooo`000007ooooo`;o00001_ooool01?l0
003oooooooooool0000:ooooo`?o00002?ooool01?l0003oooooooooool00005ooooo`03o`000?oo
003oo`0000Coo`001_ooool01?l0003oooooooooool00004ooooo`03o`000?oooooo000000Sooooo
00Co0000ooooool0003o00002?ooool01?l0003oooooooooool00003ooooo`05o`000?oooooooooo
ooooool000001?ooool7ool00003ooooool0003ooooo00Cooooo00?o0000ooooool000002?ooool3
o`0000[ooooo0_l00002ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000001oooool0
1?l0003oooooooooool0000:ooooo`03o`000?oooooooooo00Oooooo00Go0000oooooooooooooooo
o`000005ool0023ooooo000=ooooo`Goo`000oooool00ol0003oooooooooo`06ooooo`;o00002_oo
ool01?l0003oooooooooool00008ooooo`;o00001Oooool01?l0003oooooooooooooool2o`0000Wo
oooo0ol00007ooooo`05o`000?ooooooooooooooool000000oooool7ool000;ooooo00?o0000oooo
ooooool00oooool01?l0003oooooooooool00004ooooo`03o`000?oooooo000000Sooooo00Go0000
ooooool0003oooooo`000007ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000oooooooooooo
ooooo`000004ooooo`03o`000?oooooooooo00Ooo`001?ooool01?l0003oooooooooool00007oooo
o`;o000000?oooooo`000?ooool01oooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo
00?ooooo00?o0000ooooool000002?ooool00ol0003oooooo`00000;ooooo`03o`000?oooooooooo
00Oooooo00?o0000ooooooooool01Ooo000Qooooo`003_ooool5ool00003ooooool0003ooooo00Oo
oooo0_l0000:ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooool000001Oooool01_l0
003oooooooooool0003oooooo`0000Sooooo00Co0000ooooool0003o00001oooool01Ol0003ooooo
oooooooooooo000000Ooo`0000?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`04
o`000?ooooooooooo`0000Kooooo0_l00007ooooo`06o`000?ooooooooooo`000?oooooo00001ooo
ool00ol0003oooooo`000005ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool0
0oooool7ool00005ooooool0003oooooooooool000001oooool2o`000003ooooool0003ooooo00Oo
oooo00?o0000ooooool000000oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`00
00Oooooo00Co0000oooooooooooo00002_ooool2o`0000Wooooo00?o0000ool00?oo00000ooo000R
ooooo`003oooool6ool000Oooooo00?o0000ooooool000002_ooool01?l0003oooooooooool00008
ooooo`04o`000?ooooooooooo`0000?ooooo00Oo0000ooooooooooooooooo`000?oooooo000000So
oooo00Co0000ooooool0003o00001oooool00ol0003oooooool00006ool000;ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Kooooo0_l00007
ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool01?ooool00ol0003oooooo`00
0005ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00oooool00ol0003ooooo
ooooo`07ool00003ooooool0003ooooo00Kooooo00Go0000ooooool0003oooooo`000007ooooo`04
o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000002ooooo`03o`000?oooooo
oooo00Kooooo00?o0000ooooool000002oooool2o`0000Oooooo1_oo000Sooooo`004?ooool6ool0
00Kooooo0_l0000:ooooo`04o`000?ooooooooooo`0000Sooooo00Go0000ooooooooooooooooo`00
0002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooool000002?ooool2o`000003ooooool0
003ooooo00Gooooo1ooo0002ooooo`04o`000?ooooooooooo`0000Kooooo00Oo0000oooooooooooo
ooooo`000?oooooo000000Oooooo0_l00006ooooo`04o`000?ooooooooooooooo`;o000000?ooooo
o`000?ooool01Oooool00ol0003oooooo`000006ooooo`04o`000?ooooooooooo`0000;ooooo00?o
0000ooooooooool01?ooool01_l0003ooooooooooooooooo0000ooooo`Ooo`001_ooool01Ol0003o
ooooo`000?oooooo000000Oooooo00Co0000oooooooooooo00000oooool01Ol0003ooooooooooooo
oooo000000?ooooo00?o0000ooooooooool01_ooool00ol0003oooooo`00000:ooooo`;o00001_oo
ool5ool002Gooooo000Aooooo`Koo`001?ooool00ol0003oooooo`00000:ooooo`03o`000?oooooo
000000Wooooo00Go0000ooooooooooooooooo`000002ooooo`05o`000?ooooooooooooooool00000
0_ooool00ol0003oooooooooo`05ooooo`;o00000_ooool01?l0003oooooooooooooool7ool000;o
oooo00?o0000ooooool000000oooool00ol0003oooooooooo`04ooooo`07o`000?oooooooooooooo
ool0003oooooo`000008ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`00
0003ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01Oooool01?l0003ooooooooo
ool00002ooooo`03o`000?oooooooooo00Cooooo00Go0000ooooooooooooooooo`000002ooooo`03
o`000?ooooooo`0000Koo`000oooool00ol0003oooooooooo`02o`0000Oooooo00Go0000oooooooo
ooooooooo`000003ooooo`04o`000?ooooooooooo`0000?ooooo00?o0000ooooooooool01oooool2
o`0000_ooooo0_l00004ooooo`Goo`009_ooool001;ooooo1_oo0002ooooo`03o`000?oooooo0000
00[ooooo00?o0000ooooool000002Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooo0000
00Cooooo00Go0000ooooooooooooooooo`000006ooooo`;o00000oooool7ool000Gooooo00?o0000
ooooool000000oooool00ol0003oooooooooo`04ooooo`04o`000?ooooooooooooooo`;o00002Ooo
ool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooooooo
o`000006ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooool000000_ooool00ol0003ooooo
ooooo`05ooooo`07o`000?ooooooooooooooool0003oooooo`000004ooooo`Ooo`000oooool00ol0
003oooooo`000005ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000002
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01_ooool00ol0003oooooo`00000;
ooooo`;o00000_ooool5ool002Oooooo000Cooooo`Koo`0000?o0000ooooool000002_ooool00ol0
003oooooo`00000:ooooo`03o`000?oooooooooo00;ooooo0_l00005ooooo`05o`000?oooooooooo
ooooool000001_ooool00ol0003oooooool00006ool000;ooooo00?o0000ooooooooool00oooool2
o`0000Cooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`02o`0000Wooooo00?o0000
ooooooooool00oooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_oo
ool00ol0003oooooooooo`06ooooo`05o`000?oooooo0000ooooool000002?ooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01ooo00000ooooooo0000
o`000005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool2o`0000Gooooo
00?o0000ooooooooool01oooool00ol0003oooooo`00000:ooooo`03o`000?oooooo000000Goo`00
:?ooool001Cooooo1_oo00000ooooooo0000ooooo`09ooooo`03o`000?oooooo000000Wooooo00?o
0000ooooooooool00oooool2o`0000Cooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`02ooooo`Soo`001?ooool00ol0003oooooooooo`05ooooo`05o`000?ooooooooooooooool00000
2?ooool01?l0003oooooooooool0000:ooooo`;o00000oooool00ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool2o`0000Wooooo0_l000000ooooooo
0000ooooo`07ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool00ol0003o
ooooooooo`02ooooo`Soo`001?ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;o
oooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`07ooooo`;o00002oooool00ol0003o
o`00ool00003ool002Wooooo000Eooooo`Ooo`002Oooool00ol0003oooooo`00000:ooooo`03o`00
0?oooooooooo00?ooooo0_l00004ooooo`03o`000?oooooooooo00;ooooo00?o0000oooooooo0000
1ooo0002ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool01?ooool2o`0000?ooooo
00?o0000ooooooooool01_ooool01?l0003oooooo`000?l0000:ooooo`;o00000oooool00ol0003o
ooooooooo`03ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00_ooool2o`0000[o
oooo00?o0000ooooool000002?ooool00ol0003oooooooooo`02ooooo`;o00001Oooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Soo`0000?oooooo`000?ooool01?ooool00ol0003o
ooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool01oooool00ol0003o
ooooo`000009ooooo`Koo`00:_ooool001Kooooo1ooo0008ooooo`;o00002_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooo000000?ooooo00?o0000ooooooooool02Ooo00000ol0003ooooo
ooooo`04ooooo`05o`000?ooooooooooooooool000001_ooool2o`0000?ooooo00?o0000oooooooo
ool01oooool3o`0000Wooooo00Ko0000oooooooooooo0000ooooool00006ooooo`03o`000?oooooo
oooo00?ooooo00Ko0000oooooooooooo0000ooooool0000:ooooo`;o00002_ooool01_l0003ooooo
ooooool0003oooooo`0000Gooooo00Go0000ooooooooooooooooo`000007ooooo`Woo`000oooool0
1?l0003oooooooooooooool2o`0000Kooooo00?o0000ooooooooool01oooool2o`0000Sooooo1_oo
000[ooooo`005oooool3ool00004oooooooo003oo`00ool000Kooooo0_l0000;ooooo`03o`000?oo
oooooooo00;ooooo00Go0000oooooooooooo0000ooooo`0;ool000;ooooo00?o0000ooooooooool0
1Oooool01Ol0003ooooooooooooooooo000000Gooooo00Co0000oooooooooooo00000_ooool00ol0
003oooooooooo`07ooooo`;o00002_ooool01_l0003oooooooooool0003oooooo`0000Kooooo00?o
0000ooooooooool00oooool01_l0003oooooooooool0003oooooo`0000[ooooo0_l0000:ooooo`04
o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo
000000Oooooo00?o0000ooooooooool02ooo0002ooooo`03o`000?oooooo000000Gooooo00?o0000
ooooooooool02?ooool2o`0000Gooooo1ooo000/ooooo`006?ooool3ool00003oooooooo003oo`00
00;oo`001?ooool2o`0000[ooooo00?o0000ooooooooool00oooool00ol0003oooooool00008ool0
00?ooooo00Go0000ooooooooooooooooo`000007ooooo`04o`000?ooooooooooo`0000Kooooo00Co
0000oooooooooooo00000_ooool00ol0003oooooooooo`07ooooo`;o00002_ooool00ol0003ooooo
ooooo`02o`0000Oooooo00?o0000ooooooooool01?ooool01Ol0003oooooo`000?oooooo000000[o
oooo0_l0000:ooooo`04o`000?ooooooooooo`0000;ooooo00?o0000ooooooooool00oooool01?l0
003oooooooooool00008ooooo`04o`000?ooooooooooo`0000?ooooo2?oo00000ol0003oooooo`00
0006ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooooooool00_ooool7ool002gooooo000I
ooooo`?oo`0000?oooooool00?oo00000_oo0002ooooo`;o00002oooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00Coo`0000?o0000ooooooooool01Oooool00ol0003oooooooooo`02
o`0000Oooooo00Co0000oooooooooooo00001Oooool01ol0003ooooooooooooooooo0000ooooool0
00002_ooool2o`0000[ooooo00Go0000ooooooooooooooooo`000007ooooo`03o`000?oooooooooo
00Cooooo0_l00002ooooo`03o`000?oooooooooo00Sooooo00?o0000ooooool000002Oooool00ol0
003oooooo`000004ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00002?ooool2
o`000003ooooool0003ooooo00Oooooo0ooo0003ooooo`03o`000?oooooooooo00?ooooo00?o0000
ooooooooool02?ooool2o`000003oooooooo003oo`0000;oo`0000Coooooool00?oo003oo`00;_oo
ool001[ooooo0ooo0002ooooo`?oo`0000?oooooo`000?ooool02_ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000001oooool01?l0003oooooo`000?l0
0008ooooo`04o`000?ooooooooooo`0000Gooooo00Oo0000ooooooooooooooooo`000?oooooo0000
00[ooooo0_l0000:ooooo`05o`000?ooooooooooooooool000001oooool00ol0003oooooooooo`04
ooooo`;o00000_ooool00ol0003oooooooooo`08ooooo`03o`000?oooooo000000Wooooo00?o0000
ooooool000001?ooool00ol0003oooooooooo`02ooooo`04o`000?ooooooooooo`0000Sooooo0_l0
00000ooooooo0000ooooo`07ooooo`03o`000?oooooo000000Cooooo00?o0000ooooooooool00ooo
ool00ol0003oooooooooo`08ooooo`03o`000?oo003oo`0000;oo`0000Coooooool00?oo003oo`00
;oooool001_ooooo0ooo0002ooooo`Coo`002oooool00ol0003oooooooooo`02ooooo`03o`000?oo
oooooooo00?ooooo0_l00008ooooo`04o`000?oooooo0000o`0000Wooooo00?o0000ooooool00000
1?ooool00ol0003oooooooooo`03ooooo`;o00002Oooool00ol0003oooooo`00000:ooooo`03o`00
0?oooooooooo00;o00001oooool00ol0003oooooooooo`04ooooo`;o00000_ooool00ol0003ooooo
ooooo`08ooooo`;o000000?oooooo`000?ooool02?ooool2o`0000Gooooo00Oo0000oooooooooooo
ooooo`000?oooooo000000[ooooo0ol00009ooooo`;o00001?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Oooooo1?oo0002ooooo`?oo`00<?ooool001cooooo0ooo0002ooooo`Co
o`002Oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo0_l00009ooooo`03
o`000?oooooo000000Wooooo0_l00004ooooo`03o`000?oooooooooo00Cooooo0_l00009ooooo`;o
000000?oooooo`000?ooool02?ooool01_l0003oooooooooool0003oooooo`0000Kooooo00?o0000
ooooooooool01?ooool2o`0000?ooooo00?o0000ooooooooool01_ooool01Ol0003oooooo`000?oo
oooo000000Wooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02ooooo`;o00002_oo
ool2o`0000[ooooo0_l00005ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01Ooo
ool4ool000;ooooo0ooo000aooooo`007Oooool3ool00003ooooool0003ooooo00Coo`001oooool0
0ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool02?ooool2
o`0000[ooooo0_l00004ooooo`03o`000?oooooooooo00Cooooo0_l00008ooooo`05o`000?oooooo
0000ooooool000002Oooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooooooool01?ooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00Kooooo00?o
0000ooooool000000_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00Co
0000oooooooooooooooo0_l0000:ooooo`?o00002Oooool2o`0000Kooooo00?o0000ooooooooool0
0_ooool00ol0003oooooooooo`03ooooo`Coo`000_ooool01?l0003oo`00ool00?oo000booooo`00
7_ooool4ool000;ooooo1?oo0005ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`07ooooo`?o00002_ooool2o`0000?ooooo00?o0000ooooooooool0
1Oooool00ol0003oooooooooo`07ooooo`05o`000?oooooo0000ooooool000002Oooool00ol0003o
ooooo`000003o`000003omgMgOoooooooooo00?ooooo00?o0000ooooooooool00oooool01?l0003o
ooooooooool00002ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooool000000_ooool00ol0
003oooooooooo`06ooooo`03o`000?oooooooooo00Gooooo00Co0000oooooooooooooooo0_l0000;
ooooo`03o`000?oooooo000000Sooooo0_l00006ooooo`03o`000?oooooooooo00?ooooo00Co0000
oooooooooooooooo1?oo0002ooooo`Coo`00<oooool001oooooo1?oo0003ooooo`Coo`000oooool0
1Ol0003ooooooooooooooooo000000Oooooo0_l00009ooooo`?o00002_ooool2o`0000?ooooo00?o
0000ooooooooool01Oooool2o`0000Oooooo00Co0000oooooooooooo00000_ooool00ol0003ooooo
ooooo`06ooooo`;o00000oooool00omgMgOo0000ooooo`04ooooo`03o`000?oooooooooo00?ooooo
00Oo0000ooooooooooooooooo`000?oooooo000000Sooooo00?o0000ooooool000000oooool00ol0
003oooooooooo`04ooooo`03o`000?oooooo000000Oooooo00?o0000ooooooooool00_l0000;oooo
o`03o`000?oooooo000000Sooooo0_l00007ooooo`03o`000?oooooooooo00;ooooo00?o0000oooo
oooo00000ooo0003ooooo`Coo`00=?ooool0027ooooo0ooo0003ooooo`Coo`0000?oooooo`000?oo
ool00oooool00ol0003oooooooooo`05ooooo`;o00002?ooool00ol0003oooooo`00000;ooooo`;o
00000_ooool00ol0003oooooooooo`06ooooo`;o00001oooool01?l0003oooooooooool00002oooo
o`03o`000?oooooooooo00Kooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooo000000Oooooo00Co0000oooo
oooooooo00000oooool00ol0003oooooooooo`04ooooo`03o`000?oooooo000000Oooooo00?o0000
ooooooooool00_l0000;ooooo`04o`000?ooooooooooo`0000Oooooo0_l00008ooooo`03o`000?oo
oooooooo00;ooooo1?oo0003ooooo`?oo`00=_ooool002;ooooo1?oo0003ooooo`Coo`000oooool0
0ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Kooooo00?o0000ooooooooool00_l0
000:ooooo`;o000000?oooooo`000?ooool02?ooool2o`0000Kooooo00Go0000oooooooooooooooo
o`000002ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool00_ooool00omgMgOo0000
ooooo`04ooooo`;o00000oooool00ol0003oooooooooo`03ooooo`;o00001oooool01?l0003ooooo
ooooool00004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooool000002?ooool01?l0003o
ooooo`000?l0000:ooooo`05o`000?oooooo0000ooooool000001oooool00ol0003oooooo`000008
ooooo`03o`000?ooooooo`0000?oo`001?ooool3ool003Oooooo000Sooooo`Coo`000oooool5ool0
0003o`000?oooooooooo00Kooooo00Co0000oooooooooooo00001_ooool01Ol0003oooooo`000?oo
oooo000000[ooooo0_l000000ooooooo0000ooooo`08ooooo`;o00001_ooool01Ol0003ooooooooo
oooooooo000000?ooooo00?o0000ooooooooool01Oooool02?l0003oooooo`000?lQ8B7o0000oc8b
<_o<c<co00001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo0_l00007
ooooo`04o`000?ooooooooooo`0000Cooooo00?o0000ooooooooool00oooool00ol0003oooooo`00
0009ooooo`?o00002_ooool00ol0003oooooo`000002ooooo`03o`000?oooooooooo00Cooooo00?o
0000ooooool000002?ooool5ool000?ooooo1?oo000hooooo`009Oooool3ool000Cooooo1_oo0006
ooooo`04o`000?ooooooooooo`0000Gooooo00Ko0000oooooooooooo0000ooooool0000:ooooo`?o
00002Oooool01?l0003oooooooooool00004ooooo`05o`000?ooooooooooooooool000001?ooool0
0ol0003oooooooooo`05ooooo`03o`000?oooooo000000Cooooo00?o0000ooooooooool00_ooool0
1Ol0003ooooooooooooooooo000000Kooooo0_l00006ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool0
1oooool3o`0000[ooooo00?o0000ooooool000000oooool00ol0003oooooooooo`02ooooo`05o`00
0?ooooooooooooooool000001?ooool6ool000Cooooo1?oo000iooooo`009_ooool4ool000Cooooo
1_oo0003ooooo`05o`000?ooooooooooooooool000001?ooool01ol0003ooooooooooooooooo0000
ooooool000002Oooool01?l0003oooooo`000?l00009ooooo`04o`000?ooooooooooo`0000Cooooo
00Go0000ooooooooooooooooo`000004ooooo`03o`000?oooooooooo00Cooooo0_l000000ooooooo
0000ooooo`03ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000007oooo
o`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02oooo
o`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
000000Wooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`02ooooo`05o`000?oo
ooooooooooooool000000_ooool6ool00003ooooool0003ooooo00;ooooo0ooo000kooooo`009ooo
ool4ool000?ooooo00?o0000ooooooooool01Ooo00000ooooooo0000ooooo`02ooooo`03o`000?oo
oooooooo00;ooooo00Co0000oooooooooooo00000_ooool00ol0003oooooooooo`07ooooo`04o`00
0?oooooo0000o`0000Wooooo00Co0000oooooooooooo00000oooool00ol0003oooooooooo`02oooo
o`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool2o`000003ooooool0003o0000
00;o00000_ooool01Ol0003ooooooooooooooooo000000;ooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool0
1?l0003oooooooooool00003ooooo`03o`000?oooooooooo00Kooooo0_l000000ooooooo0000oooo
o`08ooooo`04o`000?ooooooooooo`0000?ooooo00Go0000ooooooooooooooooo`000003ooooo`03
o`000?oo003oo`0000?oo`001?ooool00ol0003oooooooooo`03ool003cooooo000Yooooo`?oo`00
00?oooooo`000?ooool01?ooool5ool000?ooooo00Go0000ooooooooooooooooo`000003ooooo`05
o`000?ooooooooooooooool000002?ooool01?l0003oooooo`000?l00009ooooo`05o`000?oooooo
ooooooooool000000_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00?ooooo00?o
0000ooooooooool00_ooool2o`0000Sooooo00Go0000ooooooooooooooooo`000002ooooo`03o`00
0?oooooooooo00Kooooo0_l00004ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool0
0oooool00ol0003oooooo`000004ooooo`03o`000?oooooooooo00Kooooo00Co0000ooooool0003o
00002?ooool01Ol0003ooooooooooooooooo000000?ooooo00Go0000ooooooooooooooooo`000002
ooooo`Goo`001oooool01?l0003oo`00ool00?oo000mooooo`00:_ooool4ool000Oooooo1Ooo0000
1Ooooooo0000oooooooooooo000000Cooooo00Go0000ooooooooooooooooo`000007ooooo`05o`00
0?oooooo0000ooooool000002Oooool01ol0003ooooooooooooooooo0000ooooool000001Oooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo0_l00008ooooo`05o`000?oooooo
ooooooooool000000_ooool00ol0003oooooooooo`06ooooo`;o00001?ooool00ol0003ooooooooo
o`03ooooo`03o`000?oooooooooo00Cooooo0_l00004ooooo`03o`000?oooooooooo00Kooooo00Go
0000ooooool0003oooooo`000007ooooo`03o`000?oooooooooo00;ooooo00Go0000oooooooooooo
ooooo`000002ooooo`03o`000?oo003oo`0000?oo`002?ooool4ool003kooooo000[ooooo`Coo`00
2?ooool6ool00003ooooool0003ooooo00;ooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`05ooooo`;o00000_ooool00ol0003oooooooooo`06ooooo`03o`000?oooooooooo00;ooooo
0_l00006ooooo`03o`000?oooooooooo00Cooooo00Ko0000oooooooooooo0000ooooool00009oooo
o`06o`000?ooooooooooo`000?oooooo00002Oooool00ol0003oooooo`000003ooooo`03o`000?oo
oooooooo00?ooooo00?o0000ooooooooool01?ooool2o`0000Cooooo00?o0000ooooooooool01_oo
ool00ol0003oooooooooo`02o`0000Oooooo00?o0000ooooooooool00_ooool00ol0003ooooooooo
o`02ooooo`Koo`002Oooool4ool003oooooo000]ooooo`?oo`002Oooool6ool000?ooooo00?o0000
ooooooooool00_ooool00ol0003oooooooooo`05ooooo`;o00000_ooool00ol0003oooooooooo`06
ooooo`03o`000?oooooooooo00;ooooo0_l00006ooooo`03o`000?oooooooooo00Cooooo00Ko0000
oooooooooooo0000ooooool00009ooooo`06o`000?ooooooooooo`000?oooooo00002Oooool00ol0
003oooooo`000003ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool01?ooool2o`00
00Cooooo00?o0000ooooooooool01_ooool00ol0003oooooooooo`02o`0000Oooooo00?o0000oooo
ooooool00_ooool00ol0003oooooooooo`06ool000[ooooo0ooo0011ooooo`00;_ooool3ool000_o
oooo1Ooo00000ooooooo0000ooooo`03ooooo`03o`000?oooooooooo00Gooooo00?o0000oooooooo
ool00_ooool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00;ooooo0_l00005ooooo`03
o`000?oooooooooo00Gooooo00Ko0000oooooooooooo0000ooooool0000:ooooo`04o`000?oooooo
0000o`0000[ooooo00?o0000ooooool000000_ooool00ol0003oooooooooo`05ooooo`03o`000?oo
oooooooo00?ooooo0_l00005ooooo`03o`000?oooooooooo00Cooooo00?o0000ooooooooool00_oo
ool00ol0003oooooooooo`05ooooo`03o`000?oooooooooo00?ooooo1Ooo00000ol0003ooooooooo
o`08ooooo`Coo`00@_ooool002oooooo0ooo000:ooooo`03o`000?ooooooo`0000Coo`001Oooool0
0ol0003oooooooooo`03ooooo`;o00001?ooool00ol0003oooooooooo`05ooooo`03o`000?oooooo
oooo00;ooooo0_l00005ooooo`03o`000?oooooooooo00Kooooo0_l00002ooooo`03o`000?oooooo
oooo00Sooooo00Co0000ooooool0003o00002oooool01Ol0003oooooo`000?oooooo000000Oooooo
00?o0000ooooooooool00oooool2o`0000Gooooo00?o0000ooooooooool01?ooool00ol0003ooooo
ooooo`02ooooo`;o00001_ooool01?l0003oooooooooooooool5ool000;ooooo00?o0000oooooooo
ool01oooool4ool004?ooooo000`ooooo`Coo`001oooool2o`0000?ooooo1_oo0002ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`07o`00
0?ooooooooooooooool0003oooooo`000005ooooo`03o`000?oooooooooo00Kooooo0_l00002oooo
o`03o`000?oooooooooo00Sooooo00Co0000ooooool0003o00002oooool01Ol0003oooooo`000?oo
oooo000000Oooooo00?o0000ooooooooool00oooool00ol0003oooooo`000004ooooo`03o`000?oo
oooooooo00Cooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oo
ooooo`0000Goo`001?ooool2o`0000Oooooo0ooo0015ooooo`00<Oooool4ool000Kooooo0_l00005
ooooo`Koo`0000?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooooooool00_ooool01?l0003oooooooooool00004ooooo`03o`000?oo
oooooooo00Kooooo00Go0000ooooooooooooooooo`00000;ooooo`;o00003?ooool01?l0003ooooo
ooooool00008ooooo`03o`000?oooooooooo00;ooooo00Co0000oooooooooooo00001?ooool00ol0
003oooooooooo`04ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool00oooool6ool0
00Kooooo00?o0000ooooool000001Oooool3ool004Kooooo000cooooo`?oo`001?ooool01?l0003o
ooooooooool00007ooooo`Goo`000oooool2o`0000Kooooo00?o0000ooooooooool00oooool01Ol0
003ooooooooooooooooo000000?ooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`06
ooooo`;o00000_ooool00ol0003oooooooooo`09ooooo`;o00003?ooool01?l0003oooooooooool0
0008ooooo`03o`000?oooooooooo00;ooooo00Go0000ooooooooooooooooo`000003ooooo`03o`00
0?oooooooooo00?ooooo00?o0000ooooooooool01?ooool2o`0000;ooooo1Ooo0008ooooo`04o`00
0?ooooooooooo`0000?ooooo1?oo0017ooooo`00=?ooool3ool000;ooooo00Go0000oooooooooooo
ooooo`000009ooooo`Koo`0000?o0000ooooooooool01Oooool00ol0003oooooooooo`03ooooo`05
o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00Kooooo0_l00002ooooo`03o`000?oooooooooo00Wooooo0_l0000<ooooo`04o`000?oooooooooo
o`0000Sooooo00?o0000ooooooooool00_ooool01Ol0003ooooooooooooooooo000000?ooooo00?o
0000ooooooooool00oooool00ol0003oooooooooo`05ooooo`Koo`002_ooool01_l0003ooooooooo
oooooooo0000ooooo`Coo`00B?ooool003Gooooo0ooo00000ooooooo0000ooooo`02ooooo`03o`00
0?oooooooooo00Wooooo1ooo0005ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo
00001?ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooool0
00000_ooool00ol0003oooooooooo`09ooooo`;o00003?ooool01Ol0003oooooo`000?oooooo0000
00Oooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`04o`000?oooooooooo
o`0000Gooooo00?o0000ooooooooool00_ooool7ool00003ooooool0003ooooo00Wooooo00Go0000
ooooooooooooooooo`000003ool004[ooooo000fooooo`Coo`000oooool00ol0003oooooooooo`09
ooooo`03o`000?oooooo000000Woo`0000?o0000ooooooooool00oooool01?l0003oooooooooool0
0005ooooo`04o`000?ooooooooooo`0000Sooooo00?o0000ooooooooool00_l0000<ooooo`;o0000
3?ooool01Ol0003oooooo`000?oooooo000000Sooooo00Co0000oooooooooooo00001Oooool01Ol0
003ooooooooooooooooo000000Cooooo2Ooo00001?oooooo0000ooooool0000;ooooo`03o`000?oo
oooooooo00Coo`00Boooool003Oooooo1?oo0002ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooool000000oooool:ool00005ooooool0003oooooooooool000001_ooool01?l0003ooooooooo
ool00007ooooo`04o`000?ooooooooooooooo`;o00003?ooool3o`0000_ooooo00?o0000ooooool0
00000_ooool00ol0003oooooooooo`05ooooo`04o`000?ooooooooooo`0000Kooooo00Co0000oooo
oooooooo00002_oo0004ooooo`03o`000?oooooo000000_ooooo00?o0000oooooooo00000ooo001<
ooooo`00>Oooool4ool00003ooooool0003ooooo00[ooooo00?o0000ooooooooool01oooool9ool0
0003o`000?oooooooooo00Cooooo00Co0000oooooooooooo00001oooool01?l0003ooooooooooooo
ool2o`0000_ooooo00Co0000ooooool0003o00002oooool2o`0000?ooooo00?o0000ooooooooool0
1Oooool01?l0003oooooooooool00006ooooo`Woo`002_ooool2o`0000[ooooo00?o0000ool00?oo
00000_oo001>ooooo`00>_ooool4ool00003o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2Oooool00ol0003oooooool00009ool000?ooooo00?o0000ooooool000001oooool00ol0003ooooo
ooooo`02ooooo`03o`000?oooooooooo00Wooooo00Co0000ooooool0003o00002oooool2o`0000?o
oooo00?o0000ooooooooool01Oooool00ol0003oooooo`000002ooooo`[oo`000_ooool00ol0003o
ooooooooo`09ooooo`;o00002_ooool4ool004oooooo000looooo`Coo`002Oooool2o`0000_ooooo
00?o0000ooooooooool00oooool:ool00003ooooool0003ooooo00Gooooo00?o0000ooooooooool0
0oooool00ol0003oooooooooo`09ooooo`04o`000?oooooo0000o`0000_ooooo0_l00004ooooo`03
o`000?oooooooooo00Cooooo00?o0000ool00?oo00002?oo00000ol0003oooooooooo`03ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool01_ooool4ool0057ooooo000mooooo`Goo`00
1oooool2o`0000cooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`[oo`00
0oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Sooooo00Ko0000oooooooooooo
0000ooooool0000:ooooo`03o`000?oooooooooo00?ooooo00?o0000ooooooooool02_oo0006oooo
o`05o`000?ooooooooooooooool000003?ooool2o`0000Kooooo1Ooo001Booooo`00?_ooool00ol0
003oo`00ool00002ool000Gooooo00?o0000ooooool000003?ooool01Ol0003ooooooooooooooooo
000000Wooooo3Ooo0002ooooo`;o00002Oooool01_l0003oooooooooool0003oooooo`0000[ooooo
00?o0000oooooooo00003?oo00000ol0003oooooooooo`07ooooo`05o`000?ooooooooooooooool0
00003?ooool00ol0003oooooo`000004ooooo`Coo`0000?oooooo`000?ooool0DOooool003oooooo
00?o0000oooooooo00000ooo0002ooooo`05o`000?ooooooooooooooool000002oooool01Ol0003o
oooooooooooooooo000000[ooooo00Co0000oooooooooooooooo;ooo0004ooooo`03o`000?oooooo
oooo00Wooooo00Co0000oooooooooooo00003?ooool01Ol0003oooooooooool0003ooooo00Coo`00
0_ooool00ol0003oooooooooo`1Aooooo`00?oooool00ol0003oooooooooo`04ool00003ooooool0
003ooooo00;ooooo00?o0000ooooooooool02Oooool01?l0003oooooooooool0000;ooooo`03o`00
0?oooooooooo00Cooooo00Co0000oooooooooooooooo8Ooo0004ooooo`03o`000?oooooooooo00Co
oooo00?o0000ooooooooool02Oooool01?l0003oooooooooool0000<ooooo`04o`000?oooooooooo
o`0000Coo`000oooool00ol0003oooooooooo`1Aooooo`00?oooool00ol0003oooooooooo`02oooo
o`Coo`000oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo000000_ooooo00?o0000oooo
ooooool00oooool00ol0003oooooooooo`07ooooo`03o`000?oooooooooo00Gooooo00Go0000oooo
ooooooooooooo`000002ooooo`03o`000?oooooooooo00Kooooo00?o0000ooooooooool01_ooool0
0ol0003oooooooooo`03ooooo`03o`000?oooooooooo00[ooooo0_l0000=ooooo`03o`000?oooooo
o`0000?oo`001Oooool00ol0003oooooooooo`1Aooooo`00?oooool00ol0003oooooooooo`03oooo
o`Coo`000_ooool00ol0003oooooooooo`0:ooooo`;o00003?ooool00ol0003oooooooooo`03oooo
o`03o`000?oooooooooo00Oooooo00?o0000ooooooooool01Oooool01Ol0003ooooooooooooooooo
000000;ooooo00?o0000ooooooooool01Oooool00ol0003oooooooooo`07ooooo`03o`000?oooooo
oooo00?ooooo00?o0000ooooooooool02_ooool2o`0000cooooo00?o0000oooooooo00000ooo0006
ooooo`03o`000?oooooooooo057ooooo000oooooo`03o`000?oooooooooo00Gooooo1?oo00000ooo
oooo0000ooooo`0:ooooo`;o00003Oooool01Ol0003ooooooooooooooooo000000[ooooo00?o0000
ooooooooool01?ooool00ol0003oooooooooo`02ooooo`05o`000?ooooooooooooooool000001_oo
ool00ol0003oooooooooo`08ooooo`05o`000?ooooooooooooooool000003_ooool00ol0003ooooo
ooooo`0:ooooo`Coo`002?ooool00ol0003oooooooooo`1Aooooo`00@?ooool00ol0003ooooooooo
o`05ooooo`Coo`0000?o0000ooooooooool02Oooool00ol0003oooooooooo`0<ooooo`05o`000?oo
ooooooooooooool000002oooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00;ooooo
00Go0000ooooooooooooooooo`000006ooooo`03o`000?oooooooooo00Sooooo00Go0000oooooooo
ooooooooo`00000>ooooo`03o`000?oooooooooo00Wooooo1?oo0008ooooo`03o`000?oooooooooo
05;ooooo0010ooooo`03o`000?oooooooooo00Oooooo1?oo000:ooooo`;o00003Oooool01?l0003o
ooooooooool0000<ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool01?l0
003oooooooooool0000=ooooo`03o`000?oooooo000000Sooooo1?oo000:ooooo`03o`000?oooooo
oooo05;ooooo0010ooooo`03o`000?oooooooooo00Sooooo1?oo0009ooooo`;o00003_ooool00ol0
003oooooo`00000<ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0
003oooooooooo`02ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool02_ooool00ol0
003oooooo`00000>ooooo`03o`000?oooooo000000Oooooo1?oo00000ol0003oooooooooo`08oooo
o`03o`000?oooooooooo05;ooooo0010ooooo`03o`000?oooooooooo00[ooooo1?oo0006ooooo`03
o`000?oooooo000000kooooo00?o0000ooooool000003Oooool01Ol0003ooooooooooooooooo0000
00Gooooo00?o0000ooooooooool00_ooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooool000003_ooool01?l0003oooooooooool00004ooooo`Coo`0000?ooooo
o`000?ooool02_ooool00ol0003oooooooooo`1Booooo`00@?ooool00ol0003oooooooooo`0:oooo
o`03o`000?oo003oo`0000;oo`001Oooool00ol0003oooooo`00000>ooooo`;o00003_ooool01?l0
003oooooooooool00006ooooo`03o`000?oooooooooo00?ooooo00Co0000oooooooooooo00003_oo
ool2o`0000kooooo00Co0000oooooooooooo00000oooool4ool000;ooooo00?o0000ooooooooool0
2Oooool00ol0003oooooooooo`1Booooo`00@Oooool00ol0003oooooooooo`09ooooo`03o`000?oo
oooooooo00Coo`000_ooool01Ol0003ooooooooooooooooo000000gooooo0_l0000>ooooo`04o`00
0?ooooooooooo`0000Kooooo00?o0000ooooooooool00oooool01?l0003oooooooooool0000>oooo
o`;o00003Oooool00ol0003oooooooooo`02ooooo`03o`000?oo003oo`0000;oo`001?ooool00ol0
003oooooooooo`09ooooo`03o`000?oooooooooo05;ooooo0011ooooo`03o`000?oooooooooo00Wo
oooo00Co0000oooooooooooooooo1?oo00000ooooooo0000ooooo`02ooooo`03o`000?oooooooooo
00_ooooo0_l0000?ooooo`03o`000?oooooo000000Kooooo0_l00004ooooo`04o`000?oooooooooo
o`0000kooooo0_l0000=ooooo`03o`000?oooooooooo00;ooooo1?oo0005ooooo`03o`000?oooooo
oooo00Sooooo00?o0000ooooooooool0Doooool0047ooooo00?o0000ooooooooool02Oooool00ol0
003oooooooooo`03ooooo`Coo`000oooool00ol0003oooooooooo`0;ooooo`;o00003oooool2o`00
00Oooooo00?o0000ooooooooool01?ooool2o`0000oooooo0_l0000=ooooo`03o`000?oooooooooo
00Coo`001_ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo05?ooooo0011ooooo`03
o`000?oooooooooo00[ooooo00?o0000ooooooooool00oooool5ool00003ooooool0003ooooo00_o
oooo00?o0000ooooool000003oooool2o`0000Oooooo00?o0000ooooooooool01?ooool2o`0000oo
oooo00?o0000ooooool000003?ooool00ol0003oo`00ool00003ool000Oooooo00?o0000oooooooo
ool02Oooool00ol0003oooooooooo`1Cooooo`00@Oooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00Gooooo1Ooo00000ol0003oooooooooo`09ooooo`03o`000?oooooo000000oooooo
0_l00007ooooo`03o`000?oooooooooo00Gooooo00?o0000ooooooooool03Oooool00ol0003ooooo
o`00000;ooooo`Goo`002Oooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo05?ooooo
0012ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool01oooool5ool000Wooooo00Go
0000ooooooooooooooooo`00000>ooooo`;o00001oooool00ol0003oooooooooo`04ooooo`;o0000
3_ooool01Ol0003ooooooooooooooooo000000Sooooo1Ooo000;ooooo`03o`000?oooooooooo00Wo
oooo00?o0000ooooooooool0Doooool004;ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`09ooooo`Coo`002?ooool01Ol0003ooooooooooooooooo000000kooooo0_l00007ooooo`03
o`000?oooooooooo00Cooooo0_l0000>ooooo`05o`000?ooooooooooooooool000001oooool4ool0
00cooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`1Cooooo`00@_ooool00ol0003o
ooooooooo`09ooooo`03o`000?oooooooooo00[ooooo00?o0000ool00?oo00000_oo0006ooooo`05
o`000?ooooooooooooooool000003Oooool01?l0003oooooooooool00006ooooo`03o`000?oooooo
oooo00Cooooo00?o0000ooooool000003Oooool01Ol0003ooooooooooooooooo000000Gooooo1?oo
00000ooooooo0000ooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0Dooo
ool004;ooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0:ooooo`03o`000?oo003o
o`0000?oo`000oooool00ol0003oooooooooo`02ooooo`03o`000?oooooooooo00_ooooo00Co0000
oooooooooooo00001_ooool00ol0003oooooooooo`03ooooo`04o`000?ooooooooooo`0000gooooo
00?o0000ooooooooool00_ooool00ol0003oooooooooo`05ool00003ooooool0003ooooo00cooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`1Dooooo`00@_ooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool01Ooo00000ooooooo0000oooo
o`04ooooo`03o`000?oooooooooo00[ooooo00Co0000oooooooooooo00001_ooool00ol0003ooooo
ooooo`03ooooo`04o`000?ooooooooooo`0000cooooo00?o0000ooooooooool00oooool00ol0003o
o`00ool00003ool000?ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`09ooooo`03
o`000?oooooooooo05Cooooo0013ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool0
2_ooool00ol0003oooooooooo`02ooooo`Goo`001Oooool00ol0003oooooooooo`09ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`03ooooo`05o`00
0?ooooooooooooooool000002oooool00ol0003oooooooooo`02ooooo`Goo`001Oooool00ol0003o
ooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0E?ooool004?ooooo
00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00Cooooo
1Ooo0003ooooo`03o`000?oooooooooo00Wooooo00?o0000ooooooooool00_ooool00ol0003ooooo
ooooo`03ooooo`03o`000?oooooooooo00?ooooo00Go0000ooooooooooooooooo`00000;ooooo`03
o`000?oooooooooo00Goo`001oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[o
oooo00?o0000ooooooooool0E?ooool004?ooooo00?o0000ooooooooool02Oooool00ol0003ooooo
ooooo`0;ooooo`03o`000?oooooooooo00Gooooo1_oo00000ooooooo0000ooooo`09ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`02ooooo`03o`00
0?oooooooooo00;ooooo00?o0000ooooooooool02?ooool00ol0003oo`00ool00004ool000Sooooo
00?o0000ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05Cooooo
0013ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`07ooooo`Koo`002Oooool00ol0003oooooooooo`04ooooo`03o`000?oooooooooo00;ooooo00?o
0000ooooooooool00_ooool00ol0003oooooooooo`03ooooo`03o`000?oooooooooo00Kooooo1_oo
000:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003ooooooooo
o`1Dooooo`00@oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00[ooooo00?o0000
ooooooooool02_ooool5ool000Oooooo00?o0000ooooooooool01?ooool00ol0003oooooooooo`02
ooooo`03o`000?oooooooooo00;ooooo00?o0000ooooooooool00oooool00ol0003oooooooooo`04
ooooo`Goo`003Oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool0E?ooool004Cooooo00?o0000ooooooooool02Oooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00cooooo1_oo0003ooooo`03o`000?oooooooooo00Gooooo00?o0000oooo
ooooool00_ooool01Ol0003ooooooooooooooooo000000Oooooo00?o0000ooooooooool01_oo0000
0ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02_ooool0
0ol0003oooooooooo`1Eooooo`00A?ooool00ol0003oooooooooo`09ooooo`03o`000?oooooooooo
00_ooooo00?o0000ooooooooool03?ooool00ol0003oo`00ool00004ool00003ooooool0003ooooo
00Oooooo00Go0000ooooooooooooooooo`000003ooooo`03o`000?oooooooooo00Gooooo00?o0000
ool00?oo00001?oo00000ooooooo0000ooooo`0=ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`1Eooooo`00A?ooool00ol0003oooooooooo`09oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool01?l0003oooooooooooooool5
ool000Sooooo00Co0000oooooooooooooooo0_l00002ooooo`03o`000?oooooooooo00Cooooo1Ooo
0004ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool00ol0003ooooooooo
o`0:ooooo`03o`000?oooooooooo05Gooooo0014ooooo`03o`000?oooooooooo00Wooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00?ooooo1Ooo0006
ooooo`05o`000?ooooooooooooooool000000oooool00ol0003oooooooooo`02ooooo`Goo`001_oo
ool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_oo
ool00ol0003oooooooooo`1Eooooo`00A?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooo
oooo00[ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`04ooooo`Goo`001Oooool0
1?l0003oooooooooool00002ooooo`04o`000?ooooooooooooooo`Goo`001oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003ooooo
ooooo`1Eooooo`00A?ooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool03?ooool00ol0003oooooooooo`06ooooo`Koo`000_ooool01?l0003ooooooooo
ool00002ooooo`03o`000?oo003oo`0000Coo`002Oooool00ol0003oooooooooo`0<ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Eooooo`00A?oo
ool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?oo
ool00ol0003oooooooooo`08ooooo`Koo`0000Go0000oooooooooooo0000ooooo`06ool000_ooooo
00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo
00?o0000ooooooooool0E_ooool004Gooooo00?o0000ooooooooool02Oooool00ol0003ooooooooo
o`0;ooooo`03o`000?oooooooooo00cooooo00?o0000ooooooooool02oooool5ool00003oooooooo
003oo`0000?oo`003_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`1Fooooo`00AOooool00ol0003oooooooooo`09
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03Oooool00ol0003oooooooooo`0<
ooooo`Ooo`003oooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo00?o0000
ooooooooool02_ooool00ol0003oooooooooo`1Fooooo`00AOooool00ol0003oooooooooo`0:oooo
o`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0<oooo
o`Soo`003_ooool00ol0003oooooooooo`0<ooooo`03o`000?oooooooooo00_ooooo00?o0000oooo
ooooool02oooool00ol0003oooooooooo`1Fooooo`00AOooool00ol0003oooooooooo`0:ooooo`03
o`000?oooooooooo00_ooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`09ooooo`Ko
o`0000?oooooool00?oo00001Ooo000;ooooo`03o`000?oooooooooo00cooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo05Kooooo0015ooooo`03o`00
0?oooooooooo00[ooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0=ooooo`03o`00
0?oooooooooo00Gooooo1ooo0003ooooo`03o`000?oooooooooo00Ooo`001oooool00ol0003ooooo
ooooo`0=ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool02_ooool00ol0003ooooo
ooooo`1Gooooo`00AOooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool03Oooool00ol0003oooooooooo`02ooooo`Ooo`001_ooool00ol0003ooooooooo
o`03ooooo`Ooo`001?ooool00ol0003oooooooooo`0=ooooo`03o`000?oooooooooo00_ooooo00?o
0000ooooooooool02_ooool00ol0003oooooooooo`1Gooooo`00AOooool00ol0003oooooooooo`0:
ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool03Oooool00ol0003oooooool00006
ool000Wooooo00?o0000ooooooooool01_ooool7ool00003ooooool0003ooooo00kooooo00?o0000
ooooooooool02oooool00ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05Oooooo0016oooo
o`03o`000?oooooooooo00Wooooo00?o0000ooooooooool03?ooool00ol0003oooooooooo`0;oooo
o`Ooo`003?ooool00ol0003oooooooooo`09ooooo`Ooo`003Oooool00ol0003oooooooooo`0<oooo
o`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0Eoooool004Kooooo00?o0000oooooooo
ool02_ooool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00Sooooo1ooo000?ooooo`03
o`000?oooooooooo00cooooo1ooo000:ooooo`03o`000?oooooooooo00_ooooo00?o0000oooooooo
ool02oooool00ol0003oooooooooo`1Gooooo`00A_ooool00ol0003oooooooooo`0:ooooo`03o`00
0?oooooooooo00_ooooo00?o0000ooooooooool01Oooool7ool001;ooooo00?o0000ooooooooool0
3oooool7ool000Oooooo00?o0000ooooooooool02oooool00ol0003oooooooooo`0;ooooo`03o`00
0?oooooooooo05Oooooo0016ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool02ooo
ool00ol0003oooooooooo`02ooooo`Ooo`005Oooool00ol0003oooooooooo`0Booooo`Ooo`001?oo
ool00ol0003oooooooooo`0;ooooo`03o`000?oooooooooo00[ooooo00?o0000ooooooooool0F?oo
ool004Kooooo00?o0000ooooooooool02_ooool00ol0003oooooooooo`0<ooooo`03o`000?oo003o
o`0000Goo`006?ooool00ol0003oooooooooo`0Eooooo`Ooo`0000?o0000ooooooooool03?ooool0
0ol0003oooooooooo`0:ooooo`03o`000?oooooooooo05Sooooo0016ooooo`03o`000?oooooooooo
00[ooooo00?o0000ooooooooool02Oooool8ool001_ooooo0_l0000Iooooo`Ooo`003?ooool00ol0
003oooooooooo`0:ooooo`03o`000?oooooooooo05Sooooo0016ooooo`03o`000?oooooooooo00_o
oooo00?o0000ooooooooool01Oooool8ool001kooooo00?o0000ooooooooool06oooool7ool000So
oooo00?o0000ooooooooool02oooool00ol0003oooooooooo`1Hooooo`00Aoooool00ol0003ooooo
ooooo`0:ooooo`03o`000?oooooooooo00;ooooo1ooo000Rooooo`03o`000?oooooooooo01kooooo
2?oo0004ooooo`03o`000?oooooooooo00_ooooo00?o0000ooooooooool0F?ooool004Oooooo00?o
0000ooooooooool02_ooool00ol0003oooooool00006ool002Gooooo00?o0000ooooooooool08Ooo
ool8ool00003ooooool0003ooooo00_ooooo00?o0000ooooooooool0FOooool004Oooooo00?o0000
ooooooooool02?ooool8ool002Sooooo00?o0000ooooooooool09Oooool8ool000[ooooo00?o0000
ooooooooool0FOooool004Oooooo00?o0000ooooooooool00oooool:ool002_ooooo00?o0000oooo
ooooool0:?ooool:ool000Gooooo00?o0000ooooooooool0FOooool004Oooooo00?o0000oooooooo
00002Ooo000_ooooo`03o`000?oooooooooo02cooooo2_oo00000ooooooo0000ooooo`1Jooooo`00
Aoooool7ool003Cooooo00?o0000ooooooooool0<Oooool7ool005_ooooo0017ooooo`?oo`00>?oo
ool00ol0003oooooooooo`0eooooo`?oo`00Foooool008;ooooo00?o0000ooooooooool0Toooool0
08;ooooo00?o0000ooooooooool0Toooool008;ooooo00?o0000ooooooooool0Toooool008;ooooo
00?o0000ooooooooool0Toooool008;ooooo00?o0000ooooooooool0Toooool008;ooooo00?o0000
ooooooooool0Toooool007Oooooo00Gok^k^oc8b<_l0003o410@olc<c006ooooo`03o`000?oooooo
oooo09?ooooo001gooooo`05oeEEEOmgMgOooooooiRHV?lQ8B401_ooool00ol0003oooooooooo`2C
ooooo`00Moooool01Ol0003ooooooooooooooooo000000Kooooo0_l0002Dooooo`00Moooool01Ol0
003oV9RHoooooonHV9So8B4Q00Kooooo00?o0000ooooooooool0Toooool007Oooooo00Go0000oeEE
EOl0003o410@olc<c006ooooo`03o`000?oooooooooo09?ooooo001gooooo`03oeEEEOn7QhOooooo
09kooooo001gooooo`03omgMgOl@413oV9RH09kooooo001hooooo`04olc<c?m4A4Co0000oa0@49co
oooo003ooooooaWooooo003ooooooaWooooo003ooooooaWooooo003ooooooaWooooo001nooooo`?o
000000?o410@ooooooooool0U?ooool0083ooooo00?o410@okZj^_ooool0UOooool0083ooooo00?o
V9RHoc8b<_ooool0UOooool0083ooooo00?ogMgMo`000?nj^[X0UOooool0083ooooo00?oEEEEogMg
Mom4A4@0UOooool007oooooo00GogMgMoa0@4?oooooo8B4QomgMg@2Dooooo`00Ooooool01OmVIVKo
QhN7oooooonHV9SoEEEE09Cooooo001nooooo`03onk^k_l0003ok^k^00;ooooo00?o0000omgMgOoo
ool0T_ooool007kooooo00Co410@o`000?l0003ooooo0_l000000ol@413oooooooooo`2Aooooo`00
oooooolIooooo`00oooooolIooooo`00oooooolIooooo`00oooooolIooooo`00oooooolIooooo`00
oooooolIooooo`00oooooolIooooo`00oooooolIooooo`00oooooolIooooo`00oooooolIooooo`00
oooooolIooooo`00oooooolIooooo`00oooooolIooooo`00\
\>"],
  ImageRangeCache->{{{0, 279}, {559, 0}} -> {-1.69545, -0.266238, 0.0162875, \
0.014847}}],

Cell["\<\
Fig. 5.12 Ray trajectories (black) and phase fronts (red) for waves \
approaching a focussing region\
\>", "Caption",
  CellTags->"Fig. 5.12"],

Cell[TextData[{
  "Rays are bent toward a focal point slightly behind the depression in phase \
speed. On the near side of the focus, the center of the phase fronts lags \
behind because the phase speed is smaller there.  This is what causes the \
rays to bend toward the focus, and is another example of Snell's law in \
action. On the far side of this focus, the phase surface becomes \
triple-valued: rays sent along the y-axis pass through the focus and are bent \
only slightly, and these rays intersect with rays that are bent in from both \
sides but that miss the focus. The region of triple-valued phase is \
delineated by ",
  StyleBox["caustics",
    FontSlant->"Italic"],
  ", where the folds in the phase surface occur.  These caustics, emanating \
upwards and to the left and right from the focal point, form the envelope of \
the refracted rays. Thus, three distinct wavefronts emanate from the \
focussing region: one propagating to the left, one to the right, and one \
spreading out symmetrically from the focus. (In a well-crafted lens, the \
first two wavefronts are eliminated by taking care in shaping the lens,  and \
by truncating the focussing region and/or blocking rays that begin at large \
distances from the lens axis, so that all rays that strike the lens pass \
through the focus.)"
}], "Text",
  CellTags->"i:132"],

Cell[TextData[{
  "\t Along the caustics, and at the focal point, analysis based on \
geometrical optics breaks down.  This is because wave energy is focussed so \
that geometrical optics would predict infinite amplitude.   The reason is \
easy to grasp intuitively.  According to Eq. ",
  ButtonBox["(5.3.16)",
    ButtonData:>"(5.3.16)",
    ButtonStyle->"Hyperlink"],
  " the energy flux becomes infinite as the distance between adjacent rays \
vanishes, and this happens along the caustics and at the focus, where \
adjacent rays touch (see Fig. ",
  ButtonBox["5.12",
    ButtonData:>"Fig. 5.12",
    ButtonStyle->"Hyperlink"],
  ")."
}], "Text"],

Cell[TextData[{
  "\t Of course, these infinite amplitudes are unphysical, and can be avoided \
if one accounts for dispersion. In particular , diffraction (that is, \
transverse dispersion) limits the size of the focal spot, and spreads the \
wave out around the caustics. The amplitude is still large in these regions, \
but is finite [",
  ButtonBox["Kay and Keller, (1954)",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  "]. We will consider full numerical solutions of a wave equation near a \
focus in Chapter ",
  ButtonBox["7",
    ButtonData:>{"Chapter7.nb", None},
    ButtonStyle->"Hyperlink"],
  "."
}], "Text",
  CellTags->"i:134"],

Cell[TextData[{
  "\tBeautiful visual effects created by caustics can be observed in many \
relatively simple optical systems. For instance, Fig. ",
  ButtonBox["5.13",
    ButtonData:>"Fig. 5.13",
    ButtonStyle->"Hyperlink"],
  " shows caustics produced by refraction of light through a water glass.  \
One can see that caustics are also formed by reflection off of the curved \
glass surfaces. Caustics were first studied by ",
  ButtonBox["Huygens",
    ButtonData:>{
      URL[ 
      "http://turnbull.dcs.st-and.ac.uk/history/Mathematicians/Huygens.html"],
       None},
    ButtonStyle->"Hyperlink"],
  " and Tschirnhaus in the late 1600's. A full discussion of their properties \
would take us too far afield. The interested reader is referred to ",
  ButtonBox["Lockwood (1967, Chapter 24)",
    ButtonData:>"refs",
    ButtonStyle->"Hyperlink"],
  ".  Also, the ",
  ButtonBox["MacTutor index of famous curves",
    ButtonData:>{
      URL[ "http://turnbull.dcs.st-and.ac.uk/history/Curves/Curves.html"], 
      None},
    ButtonStyle->"Hyperlink"],
  " allows one to interactively view reflection caustics from various \
surfaces using a web browser."
}], "Text",
  CellTags->"i:135"],

Cell[GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`4000Kc0004HB000`400?l00000o`00003ooooooooo
oooooooooooooooooooooooooooooooonOooool00?oooooooooooooooooooooooooooooooooooooo
ooWooooo003ooooooooooooooooooooooooooooooooooooooooiooooo`00oooooooooooooooooooo
oooooooooooooooooooonOooool00?ooooooooooooooooooooooooooooooooooooooooWooooo003o
oooooooooooooooooooooooooooooooooooooooiooooo`00oooooooooooooooooooooooooooooooo
oooooooonOooool00?ooooooooooooooooooooooooooooooooooooooooWooooo003ooooooooooooo
oooooooooooooooooooooooooooiooooo`00oooooooooooooooooooooooooooooooooooooooonOoo
ool00?ooooooooooooooooooooooooooooooooooooooooWooooo003ooooooooooooooooooooooooo
oooooooooooooooiooooo`00oooooooooooooooooooooooooooooooooooooooonOooool00?oooooo
ooooooooooooooooooooooooooooooooooWooooo003ooooooooooooooooooooooooooooooooooooo
oooiooooo`00oooooooooooooooooooooooooooooooooooooooonOooool00?oooooooooooooooooo
ooooooooooooooooooooooWooooo003ooooooooooooooooooooooooooooooooooooooooiooooo`00
oooooooooooooooooooooooooooooooooooooooonOooool00?oooooooooooooooooooooooooooooo
ooooooooooWooooo003ooooooooooooooooooooooooooooooooooooooooiooooo`00oooooooooooo
oooooooooooooooooooooooooooonOooool00?ooooooooooooooooooooooooooooooooooooooooWo
oooo003ooooooooooooooooooooooooooooooooooooooooiooooo`00oooooooooooooooooooooooo
oooooooooooooooonOooool00?ooooooooooooooooooooooooooooooooooooooooWooooo003ooooo
oooooooooooooooooooooooooooooooooooiooooo`00:_ooool308IJ=`80QETf0`24F3D02`21FS40
PU/b08=L<`24GC@0QEhe08IO=P27H3L0R64h08IP<`28HSD0RF<f0080RV@g00/0RF<f08QR=@26H3<0
Pe`c08EN=@27H3L0R64h08UR>@28HCP0Qf0g08IO=P0308aP>@<0Relh0P2:GSL808eR=`0908QU>`26
HcT0Qf8h08IO=P28GSH0REdf08YN=`2<GcP0Rf0e0080S64f00<0SF8g08iS>02?I3T00P2@ICX308aO
=@80SF0f0`2>HCL9091S>@0408iQ=`2?HSP0Sf8h08mR>0<0T6<i00T0TF@j095U@P2@I440SV8m08eQ
>P2=HSP0SV<h091U>02AIST0202BIc`3099U>`<0TF@j0P2@HcT809=V?009091S>P2BIC`0UFPn09Q/
?`2IKCh0V6`k09IZ>@2EJSL0VFDm0080UfHm00<0UVLm09AW?@2CJ3d00P2BJCd0102DJ3/0UFTl09EY
?02EJC`209IZ?@80Uf/n00D0VVi109U]@02IKD00V6`o09M[?P0209IZ?@0<09EY?02IKST0V6dh09Q]
>P2GJcX0UVXk09EY?02DJ3/0U6Lm099W>P2CJ3/0UFXm0`2GK3l00`2FJch0UFXm09M]>`0709M]>`08
09U^>@2JKcX0VVll09Y^?@2KKd00Vfm209a`@`2LKdD809Y`?P0409]_?P2JKSd0VVhm09Y^?@80VFdl
0P2HK3/0202MLSd0Vg0k09U^>`2GJcX0Uf/l09U]@02KKd80WG160P2IKC`00`2JKSd0Vfln09a`?`02
09ea@00409ib@@2IKC`0Vfln09a`?`80WG5000<0W70o09]_?P2IKC`00P2JL4000`2JL3h0VW4m09Ya
?@0209Ya>`80VW4i00<0WG=109ab@02KLCl00P2JL3h00`2KLCl0W79009ec@@0209mc@P<0WW910`2M
LD0209a`?`<0WG500`2NLT430:5f@`<0X7E20P2OM440202QMdD0X7I40:1d@`2QLd80Xg=30:IcA02Y
MDH0ZgM8202RMd@80:9fA@80Yg]<00@0Yg]:0:MlB@2WO4T0Yga70P2WO4D20:=iA`<0Y7Y80`2UNdT0
202UNT<0Z7e60:^0B`2ZOd`0YW]80:EiB02WNd`0ZWi?202VNdH00`2UNTD0YW]60:MlA`020:QmB009
0:MlA`2VNdH0YGY50:AiAP2UNTL0YW]80:MlB@2XODX0ZWm<0080Zh1=00H0[7Y90:YjB@2ZNTT0ZWa:
0:QmBP2WOTX20:MoB`060:=jAP2TNdL0YGa80:ImB@2WOTX0ZH1<0P2ZPDd80:YoBP80ZH1<0P2ZPDd2
0:^2CP80[8=?202]PTl90:b1CP030:j4E02]Pe<0[89@0080ZX5=00H0[8==0:f4C02^QDd0ZWm<0:^0
C@2/PDh20:f2C`030:b1CP2[P4d0ZWm<00P0[8=?202]PTl20:j2D`040:f1D02]PTl0[H9?0:b1C080
[85:202_Q5480:b1C00@0:QmB02ZOdX0[85<0:f2C@2^Pdh0[H9=0:b1C02[P4/0Z7e80:UnB@2ZOdX0
Zh1;0:YoBP2YOTT0Yga70:EjA@P0ZGi900P0[H9?0:UnB`2TNDH0Y7U60:QmBP2ZOd`0Z7e:0:IkB0P0
ZWm:00H0/7i;0:ioB`2^Od/0[7i:0:YoBP2YP4X20:N0B@80Y7Q700h0YGU80:MkBP2XO4/0ZGe<0:Yn
C@2[Odh0YGa80:V0C02[PTh0ZX5=0:ImB@2UO4P0Ygi:0:^2CPP0Zh9<00<0ZX5=0:^2CP2/Pdl00P2]
Q5001P2[PTh0ZH1<0:QoB`2XODP0ZWm:0:^0B`80[85<00<0Zh1;0:YoBP2XODP00`2XODP20:UnB@d0
ZWm:00L0Zh1;0:b1C02]PTd0[H9=0:b1C02[P4/0ZWm:00<0Zh1;0`2ZOdX20:UnB@80ZGe<00<0ZWm<
0:YoBP2ZOdP00P2[PDL00`2[PDD0[H9=0:f2C@020:b1C080Zh1;0P2ZOdX0202]PTl0[85>0:YoC02Y
OT/0Z7e:0:UnB`2ZOd`0Zh1=202]PTd30:b1C0<0[H9=0P2^Pdh01P2ZOdX0Zh1;0:^0B`2/PD`0[H9=
0:j3CP80[hA?0P2^Pdh30:f2C@<0[85<00H0ZX140:^1A`2[PDL0[85:0:f2C@2^Pe020:n3DP80[HA>
0`2^QDl30:n6D0P0[hA?0P2^Pdh30:n4C`<0/8E@00H0/XQ>0;67C@2aQdd0/8I<0:n5B`2^Q4X20:f3
B@080:n3DP2`Q5<0/HIC0;:7DP2bQe00/HM=0;26C02_QDT20;66C`040;66D@2aQU<0/HIC0;65E080
/HEF202^QE40202/PDX0[X=<0;66D@2cR5D0]8UF0;:6E@2`Q5D0[h=D102bQe@20;>8E@<0]8UF00H0
]hiJ0;J=F@2cRUH0/HQD0;27D`2_QU820;27D`080;:9E@2^QE40[8=?0:f4D02aR5@0/XUE0;27D`2/
Pdl20;:9E@<0/HQD0`2`Qe<80:n6D0060;>;CP2cRe00/h]@0;:9D@2bRE<0/HQD0P2aQeD20;>5E006
0;65E02aQeD0/8QE0:j9E@2_RUH0[XYF0P2bR5P0102aQeD0/HQD0;68E02`Qe420;27C`80/XUE0`2a
R5@30;27D`P0[XUE00P0/H]N0;6;G02`RU/0[XQG0:f8E02/Qe80ZhI?0:Z5CP<0/XMD0P2cR5D30;B9
EP030;27D`2aR5@0/hYF0080]8]G00<0/hYF0;68E02`Qe<00`2^QE420:n6DP<0/8MC202dReD00`2^
RED0/8]G0;6<F0020;:=F@050;6<F02`ReL0[XUE0:n6DP2`Qe<00`2bRED00`2`Qe<0[hIB0:f4D002
0;>:E0030;>:EP2bR5H0/XQH0080/HII00<0/HIK0:j9E@2]R5@00`2/Qe<00`2^RED0/8]G0;6<F00:
0;>:EP<0/XUE0P2aR5@20;27D`P0[hYE0P2bRE<30;68DP<0/8MA202aR5820:n6D080[XE?102]Q4h2
0;68DP80/8MA0P2_QU020:j5C`080;>;CP2bRTl0/HU>0;27C`2_QU00[XEA0:f3D@2/PU080:f4CPP0
[HA@0P2^QDd0102^QDl0[XEA0:j5D@2^Q5820:j4E080[HA@0`2^QE430:n6DP060;:9D`2aR580/8MA
0:n6D02^QDl0[8==0P2[PT`00`2/PDh0[H9?0:j3D0020:j3D0030:b1CP2ZOd`0ZGi;0080[H=A00<0
[HA@0:f4CP2]Q4`00P2]QDX00`2]QDP0[hE;0:n5B`060:n5B`030:V4C`2[QU40[8MB0080[HQC00<0
[8MB0:^6D@2YQ4l0202[PTh00`2^QE40[8=?0:^2CP020:Z1C@050:^2CP2/Pdl0[XEA0:f2C@2/PD`0
102[P4/03P2]PTd0[hA?0;25D02^Q580[H=A0:b3C`2[PT`0Zh9:0:f5BP2_Qd`0/8Q;0:j5C`2/Pdd0
Zh9<0P2ZPD/0302[PT`0[8==0:j5C`2ZP4h0Zh5?0:b3C`2^QDl0[XE=0:b4B@2[PdP0ZX950:f4CP80
[8==00D0Zh9<0:Z1B`2YP4X0ZH1:0:QoB@080:f4D0P0[8=?202[PT`0202/RE40ZhI?0:R3C02XPDX0
ZH1:0:^0B`2_PDd0/H=?0P2^Pdh30:f2C@<0[85<0P2_QU003`2^QDl0[8==0:^2C02ZPD/0ZH1:0:Qo
B@2YP4`0ZX5=0:b3C`2]Q500[XEA0:f4D02/Pdl0Zh9>0:j3CP020:f2C@080:b1C02[P4/0ZWm:0:Yo
BP2YOTT0Zh9<0:Z1B`2YP4X20:MnB0030:V0BP2ZPD/0Zh9<00<0[8=?0P2[PTh30:Z1C@80Yga700H0
Z7e80:YoBP2[P4/0[85<0:f2C@2^Pdh80:^2CPP0ZH1:0P2YOT/30:YoC0<0Zh1=0P2/Pdd0102/Pdl0
[89@0:b2D02/PU820:b1E0030:b1EP2ZPDd0ZH1<0080Z7m;00@0ZH1<0:^2CP2]Q500[hIB202[PTh8
0:YoC0060:mmB02]OTP0[Wm;0:eoC@2/PDh0Zh5?0P2[Pe830:^2CP<0[8=?0P2]Q5020:b3C`80Zh9>
0P2ZPDd40:V0C080ZX5=0P2[PTh20:b3C`80[89@0P2[PDl20:Z0CP80ZGm=00H0/Gm>0:moCP2_Odh0
[X1>0:b1CP2[PTh20:Z2CP80[8=;00@0[8==0:b3C`2/Pdl0[89@0P2/PU830:V0BP80Z7m90`2WOTP0
0`2WOSh0Yge30:QlB`020:UlDP030:YnC@2[PDL0Zh9200P0YWe700<0YW]80:MlB@2YOT/00P2[P4d0
0`2ZOd`0ZGi;0:QmBP030:MnBP<0YWe90P2UO4P30:Z1C@<0ZH1<0P2XOd/00`2/Pdl0ZX5=0:MnBP02
0:ElB0030:ImB@2XOd/0ZX5=0080ZH1:00<0Z7m90:MnB02VODL00P2UO4H0102TNdD0YWe90:ImB@2V
ODT40:MnBP80Z7m;00H0Y8160:=oA@2SOTL0XWe80:5lA`2PNdL209miB080XgY60`2TNdL30:ElB0<0
YGY70P2TNDH30:=hA@0;0:MiB02VN4L0XgM60:5gA@2PN4D0X7]70:9mB@2ROTX0Z7i<0:MmB`2UNdT0
0`2SNDL02P2TNTP0YG]90:MnBP2SNTH0WgI209ie@@2QN4@0XgY60:9iA@2PMd<20:=jA0<0XWU30`2Q
N4820:=iA`<0Y7Y80`2UNdT02`2VNdP0YGY70:AiAP2RMd@0XGI309md@@2NLd00WG8o0:1g@`2QN4@0
XWU50080Y7]700/0XWU50:5hA02PMd<0WgE50:1fAP2QMdD0XWU50:AkA`2UO4H0YWe50:MnAP080:9h
AP0409me@`2PMT@0X7I40:1fA0<0XGM500L0XWQ60:=a?02QLS`0XG8n0:5c@@2OM440WgE30080WWI5
00<0XWQ60:1fA02MLd400P2KLCl00`2LLT00WWA20:1fA0080:5gA@0609ab@02MLd40WWA209me@`2P
MT@0XWQ60P2SNDL01P2RND40XGQ00:5h@P2PMd<0WgI209id@P80WG=300<0XWQ60:5gA@2OMD<00P2N
M48209me@`030:5gA@2RN4H0WG=100L0WG=10`2QMD@20:9fA@<0XgM600T0XGI909mdA`2LLD@0VFi1
09M/?`2HKD00VFi109Y_@P2LLDH00P2LLD@00`2LLT80W79009ac?`0209ac?@P0VVhm00T0U6Tl09EZ
?@2HKD00VVm209]`@`2JKd80V6e009I[?P2HKD800P2HKD000`2IKcl0VFlm09Ya?@0209Ya>`P0UG0l
00<0V6e009I[?P2DJC`00P2BIcX00`2DJC`0UV/n09Q]@00209=Y=`0309AZ>02EJcT0UV`j0080Ufdk
00T0V6hl09Y_@P2HKD00UV/n09EZ?@2FJch0V6e009]`@`2LLD@00`2EJSd309I[?P80Uf`o202FJch8
091Z>`05095[?02BK3d0TV`m09=]?P2DKSl00P2EKd001@2FL440UFXm09=X>`2AIST0TfPk0080UFXm
00<0T6Dh08]P<`2BIcX01`2BIcX01P2DJcL0U6Xh09=Y=`2BJ3P0TFHi091U>P80Sf@j00H0Rf@m08]T
>`2<IC`0SFHk08iX>`2?JCX208mY>00G091Z>@2DKSd0TV`k091Z>`2=IcX0Rf@i08YS>P2;I3/0Rf@m
095V>`2>HcP0Rf0e08aQ=P2?I3T0T6Dj08eR=`29GS<0TVDk095V>`2@ICX0SVDi08aV>@2:ICP00P27
ICL00`28HSD0RV@g08aV>@0208iX>`0308]U>028HSD0QElb00<0RV@g0`2;ICP208aV>@0808aS=`2=
I3P0RfDh08YU>02;IST0RFLi08QX>@29JCX808aU?00308EU=P26ISL0R6Hh0080S6Lj00<0RfDh08aS
=`2;HSH00`2;ICP208aV>@<0SFLj0`2?JD8[ooooo`00:_ooool308IJ=`80QETf0`24F3D02`21FS40
PU/b08=L<`24GC@0QEhe08IO=P27H3L0R64h08IP<`28HSD0RF<f0080RV@g00/0RF<f08QR=@26H3<0
Pe`c08EN=@27H3L0R64h08UR>@28HCP0Qf0g08IO=P0308aP>@<0Relh0P2:GSL808eR=`0908QU>`26
HcT0Qf8h08IO=P28GSH0REdf08YN=`2<GcP0Rf0e0080S64f00<0SF8g08iS>02?I3T00P2@ICX308aO
=@80SF0f0`2>HCL9091S>@0408iQ=`2?HSP0Sf8h08mR>0<0T6<i00T0TF@j095U@P2@I440SV8m08eQ
>P2=HSP0SV<h091U>02AIST0202BIc`3099U>`<0TF@j0P2@HcT809=V?009091S>P2BIC`0UFPn09Q/
?`2IKCh0V6`k09IZ>@2EJSL0VFDm0080UfHm00<0UVLm09AW?@2CJ3d00P2BJCd0102DJ3/0UFTl09EY
?02EJC`209IZ?@80Uf/n00D0VVi109U]@02IKD00V6`o09M[?P0209IZ?@0<09EY?02IKST0V6dh09Q]
>P2GJcX0UVXk09EY?02DJ3/0U6Lm099W>P2CJ3/0UFXm0`2GK3l00`2FJch0UFXm09M]>`0709M]>`08
09U^>@2JKcX0VVll09Y^?@2KKd00Vfm209a`@`2LKdD809Y`?P0409]_?P2JKSd0VVhm09Y^?@80VFdl
0P2HK3/0202MLSd0Vg0k09U^>`2GJcX0Uf/l09U]@02KKd80WG160P2IKC`00`2JKSd0Vfln09a`?`02
09ea@00409ib@@2IKC`0Vfln09a`?`80WG5000<0W70o09]_?P2IKC`00P2JL4000`2JL3h0VW4m09Ya
?@0209Ya>`80VW4i00<0WG=109ab@02KLCl00P2JL3h00`2KLCl0W79009ec@@0209mc@P<0WW910`2M
LD0209a`?`<0WG500`2NLT430:5f@`<0X7E20P2OM440202QMdD0X7I40:1d@`2QLd80Xg=30:IcA02Y
MDH0ZgM8202RMd@80:9fA@80Yg]<00@0Yg]:0:MlB@2WO4T0Yga70P2WO4D20:=iA`<0Y7Y80`2UNdT0
202UNT<0Z7e60:^0B`2ZOd`0YW]80:EiB02WNd`0ZWi?202VNdH00`2UNTD0YW]60:MlA`020:QmB009
0:MlA`2VNdH0YGY50:AiAP2UNTL0YW]80:MlB@2XODX0ZWm<0080Zh1=00H0[7Y90:YjB@2ZNTT0ZWa:
0:QmBP2WOTX20:MoB`060:=jAP2TNdL0YGa80:ImB@2WOTX0ZH1<0P2ZPDd80:YoBP80ZH1<0P2ZPDd2
0:^2CP80[8=?202]PTl90:b1CP030:j4E02]Pe<0[89@0080ZX5=00H0[8==0:f4C02^QDd0ZWm<0:^0
C@2/PDh20:f2C`030:b1CP2[P4d0ZWm<00P0[8=?202]PTl20:j2D`040:f1D02]PTl0[H9?0:b1C080
[85:202_Q5480:b1C00@0:QmB02ZOdX0[85<0:f2C@2^Pdh0[H9=0:b1C02[P4/0Z7e80:UnB@2ZOdX0
Zh1;0:YoBP2YOTT0Yga70:EjA@P0ZGi900P0[H9?0:UnB`2TNDH0Y7U60:QmBP2ZOd`0Z7e:0:IkB0P0
ZWm:00H0/7i;0:ioB`2^Od/0[7i:0:YoBP2YP4X20:N0B@80Y7Q700h0YGU80:MkBP2XO4/0ZGe<0:Yn
C@2[Odh0YGa80:V0C02[PTh0ZX5=0:ImB@2UO4P0Ygi:0:^2CPP0Zh9<00<0ZX5=0:^2CP2/Pdl00P2]
Q5001P2[PTh0ZH1<0:QoB`2XODP0ZWm:0:^0B`80[85<00<0Zh1;0:YoBP2XODP00`2XODP20:UnB@d0
ZWm:00L0Zh1;0:b1C02]PTd0[H9=0:b1C02[P4/0ZWm:00<0Zh1;0`2ZOdX20:UnB@80ZGe<00<0ZWm<
0:YoBP2ZOdP00P2[PDL00`2[PDD0[H9=0:f2C@020:b1C080Zh1;0P2ZOdX0202]PTl0[85>0:YoC02Y
OT/0Z7e:0:UnB`2ZOd`0Zh1=202]PTd30:b1C0<0[H9=0P2^Pdh01P2ZOdX0Zh1;0:^0B`2/PD`0[H9=
0:j3CP80[hA?0P2^Pdh30:f2C@<0[85<00H0ZX140:^1A`2[PDL0[85:0:f2C@2^Pe020:n3DP80[HA>
0`2^QDl30:n6D0P0[hA?0P2^Pdh30:n4C`<0/8E@00H0/XQ>0;67C@2aQdd0/8I<0:n5B`2^Q4X20:f3
B@080:n3DP2`Q5<0/HIC0;:7DP2bQe00/HM=0;26C02_QDT20;66C`040;66D@2aQU<0/HIC0;65E080
/HEF202^QE40202/PDX0[X=<0;66D@2cR5D0]8UF0;:6E@2`Q5D0[h=D102bQe@20;>8E@<0]8UF00H0
]hiJ0;J=F@2cRUH0/HQD0;27D`2_QU820;27D`080;:9E@2^QE40[8=?0:f4D02aR5@0/XUE0;27D`2/
Pdl20;:9E@<0/HQD0`2`Qe<80:n6D0060;>;CP2cRe00/h]@0;:9D@2bRE<0/HQD0P2aQeD20;>5E006
0;65E02aQeD0/8QE0:j9E@2_RUH0[XYF0P2bR5P0102aQeD0/HQD0;68E02`Qe420;27C`80/XUE0`2a
R5@30;27D`P0[XUE00P0/H]N0;6;G02`RU/0[XQG0:f8E02/Qe80ZhI?0:Z5CP<0/XMD0P2cR5D30;B9
EP030;27D`2aR5@0/hYF0080]8]G00<0/hYF0;68E02`Qe<00`2^QE420:n6DP<0/8MC202dReD00`2^
RED0/8]G0;6<F0020;:=F@050;6<F02`ReL0[XUE0:n6DP2`Qe<00`2bRED00`2`Qe<0[hIB0:f4D002
0;>:E0030;>:EP2bR5H0/XQH0080/HII00<0/HIK0:j9E@2]R5@00`2/Qe<00`2^RED0/8]G0;6<F00:
0;>:EP<0/XUE0P2aR5@20;27D`P0[hYE0P2bRE<30;68DP<0/8MA202aR5820:n6D080[XE?102]Q4h2
0;68DP80/8MA0P2_QU020:j5C`080;>;CP2bRTl0/HU>0;27C`2_QU00[XEA0:f3D@2/PU080:f4CPP0
[HA@0P2^QDd0102^QDl0[XEA0:j5D@2^Q5820:j4E080[HA@0`2^QE430:n6DP060;:9D`2aR580/8MA
0:n6D02^QDl0[8==0P2[PT`00`2/PDh0[H9?0:j3D0020:j3D0030:b1CP2ZOd`0ZGi;0080[H=A00<0
[HA@0:f4CP2]Q4`00P2]QDX00`2]QDP0[hE;0:n5B`060:n5B`030:V4C`2[QU40[8MB0080[HQC00<0
[8MB0:^6D@2YQ4l0202[PTh00`2^QE40[8=?0:^2CP020:Z1C@050:^2CP2/Pdl0[XEA0:f2C@2/PD`0
102[P4/03P2]PTd0[hA?0;25D02^Q580[H=A0:b3C`2[PT`0Zh9:0:f5BP2_Qd`0/8Q;0:j5C`2/Pdd0
Zh9<0P2ZPD/0302[PT`0[8==0:j5C`2ZP4h0Zh5?0:b3C`2^QDl0[XE=0:b4B@2[PdP0ZX950:f4CP80
[8==00D0Zh9<0:Z1B`2YP4X0ZH1:0:QoB@080:f4D0P0[8=?202[PT`0202/RE40ZhI?0:R3C02XPDX0
ZH1:0:^0B`2_PDd0/H=?0P2^Pdh30:f2C@<0[85<0P2_QU003`2^QDl0[8==0:^2C02ZPD/0ZH1:0:Qo
B@2YP4`0ZX5=0:b3C`2]Q500[XEA0:f4D02/Pdl0Zh9>0:j3CP020:f2C@080:b1C02[P4/0ZWm:0:Yo
BP2YOTT0Zh9<0:Z1B`2YP4X20:MnB0030:V0BP2ZPD/0Zh9<00<0[8=?0P2[PTh30:Z1C@80Yga700H0
Z7e80:YoBP2[P4/0[85<0:f2C@2^Pdh80:^2CPP0ZH1:0P2YOT/30:YoC0<0Zh1=0P2/Pdd0102/Pdl0
[89@0:b2D02/PU820:b1E0030:b1EP2ZPDd0ZH1<0080Z7m;00@0ZH1<0:^2CP2]Q500[hIB202[PTh8
0:YoC0060:mmB02]OTP0[Wm;0:eoC@2/PDh0Zh5?0P2[Pe830:^2CP<0[8=?0P2]Q5020:b3C`80Zh9>
0P2ZPDd40:V0C080ZX5=0P2[PTh20:b3C`80[89@0P2[PDl20:Z0CP80ZGm=00H0/Gm>0:moCP2_Odh0
[X1>0:b1CP2[PTh20:Z2CP80[8=;00@0[8==0:b3C`2/Pdl0[89@0P2/PU830:V0BP80Z7m90`2WOTP0
0`2WOSh0Yge30:QlB`020:UlDP030:YnC@2[PDL0Zh9200P0YWe700<0YW]80:MlB@2YOT/00P2[P4d0
0`2ZOd`0ZGi;0:QmBP030:MnBP<0YWe90P2UO4P30:Z1C@<0ZH1<0P2XOd/00`2/Pdl0ZX5=0:MnBP02
0:ElB0030:ImB@2XOd/0ZX5=0080ZH1:00<0Z7m90:MnB02VODL00P2UO4H0102TNdD0YWe90:ImB@2V
ODT40:MnBP80Z7m;00H0Y8160:=oA@2SOTL0XWe80:5lA`2PNdL209miB080XgY60`2TNdL30:ElB0<0
YGY70P2TNDH30:=hA@0;0:MiB02VN4L0XgM60:5gA@2PN4D0X7]70:9mB@2ROTX0Z7i<0:MmB`2UNdT0
0`2SNDL02P2TNTP0YG]90:MnBP2SNTH0WgI209ie@@2QN4@0XgY60:9iA@2PMd<20:=jA0<0XWU30`2Q
N4820:=iA`<0Y7Y80`2UNdT02`2VNdP0YGY70:AiAP2RMd@0XGI309md@@2NLd00WG8o0:1g@`2QN4@0
XWU50080Y7]700/0XWU50:5hA02PMd<0WgE50:1fAP2QMdD0XWU50:AkA`2UO4H0YWe50:MnAP080:9h
AP0409me@`2PMT@0X7I40:1fA0<0XGM500L0XWQ60:=a?02QLS`0XG8n0:5c@@2OM440WgE30080WWI5
00<0XWQ60:1fA02MLd400P2KLCl00`2LLT00WWA20:1fA0080:5gA@0609ab@02MLd40WWA209me@`2P
MT@0XWQ60P2SNDL01P2RND40XGQ00:5h@P2PMd<0WgI209id@P80WG=300<0XWQ60:5gA@2OMD<00P2N
M48209me@`030:5gA@2RN4H0WG=100L0WG=10`2QMD@20:9fA@<0XgM600T0XGI909mdA`2LLD@0VFi1
09M/?`2HKD00VFi109Y_@P2LLDH00P2LLD@00`2LLT80W79009ac?`0209ac?@P0VVhm00T0U6Tl09EZ
?@2HKD00VVm209]`@`2JKd80V6e009I[?P2HKD800P2HKD000`2IKcl0VFlm09Ya?@0209Ya>`P0UG0l
00<0V6e009I[?P2DJC`00P2BIcX00`2DJC`0UV/n09Q]@00209=Y=`0309AZ>02EJcT0UV`j0080Ufdk
00T0V6hl09Y_@P2HKD00UV/n09EZ?@2FJch0V6e009]`@`2LLD@00`2EJSd309I[?P80Uf`o202FJch8
091Z>`05095[?02BK3d0TV`m09=]?P2DKSl00P2EKd001@2FL440UFXm09=X>`2AIST0TfPk0080UFXm
00<0T6Dh08]P<`2BIcX01`2BIcX01P2DJcL0U6Xh09=Y=`2BJ3P0TFHi091U>P80Sf@j00H0Rf@m08]T
>`2<IC`0SFHk08iX>`2?JCX208mY>00G091Z>@2DKSd0TV`k091Z>`2=IcX0Rf@i08YS>P2;I3/0Rf@m
095V>`2>HcP0Rf0e08aQ=P2?I3T0T6Dj08eR=`29GS<0TVDk095V>`2@ICX0SVDi08aV>@2:ICP00P27
ICL00`28HSD0RV@g08aV>@0208iX>`0308]U>028HSD0QElb00<0RV@g0`2;ICP208aV>@0808aS=`2=
I3P0RfDh08YU>02;IST0RFLi08QX>@29JCX808aU?00308EU=P26ISL0R6Hh0080S6Lj00<0RfDh08aS
=`2;HSH00`2;ICP208aV>@<0SFLj0`2?JD8[ooooo`00:_ooool308IJ=`80QETf0`24F3D01@22Fc80
Pe`c08=L<`24GC@0QEhe0080QUlf00@0Qf0g08IP<`28HSD0RF<f0P2:I3L02`29HcH0R68e08IP<`24
GC@0QUlf08QQ>029HST0RV<j08UR>@28HCP0Qf0g00<0S60i0`2;GcP208YN=`P0SF8g00P0RFHl08QU
>`28HcT0Qf0g08UO=`2:GSL0Relh08eP>@<0SF8g0`2>HcP208mT>@<0SF0f0P2>HCL308mR>0T0T6<i
102AI3X4091S>@0808mS@02>HSl0SF4l08eQ>P2=HSP0Sf@i095V>@2BIcX8099W?0<0TVDk0`2AI3X2
091S>@P0TfHl00D0TF@k099U?02DIcd0UFTl09IZ>`0209IZ>@0709I[>02IICd0UfHm09MV?@2FIcd0
U6Lm09=X?@02099Y?@80TfLj0P2DJ3/209EY?080UVXm102HK3l409M[?P0;09U^>@2HKCP0V6dj09M[
>P2FJS/0UFTl09AX>`2DIcd0TVLj09=X>`2EJSd00`2GK3l00`2FJch0UFXm09M]>`0709M]>`80V6dh
00H0VFhk09U]?02JKSl0VVi109]_@P2KKT@809Y`?P80W70o0P2KKch209Y^?@80VFdl0P2KL3/01P2I
KS/0VFdl09U]?P2IKD00Vfm209]^A080VVhm0`2KKch309a`?`0309U]?02KKch0W70o0080WG5000<0
W70o09]_?P2IKC`00P2KLD400`2KLCl0Vg8n09]b?P0209]b?080Vg8j00<0WG=109ab@02KLCl00P2J
L3h00`2KLCl0W79009ec@@0209mc@P<0WW911@2MLD0309ib@@<0Wg=20`2QMT<30:1e@P80WgA100P0
XGM50:1fA02PM4<0XG=20:=c@`2VLd@0ZGE60:]gB0P0XWM4202SMdH20:MkC0040:MkBP2WO4T0Yga9
0:MlA`80Yga50P2SNDL30:AjB0<0YG]900P0YGY30:QmAP2[P4/0ZWm<0:IkB02UNDP0Yg]<0:YnC`P0
Yga700<0YGY50:IkAP2WO4L00P2XODP00`2WO4L0YW]60:EjA@020:IkB080Yga900D0Z7e:0:UnB`2Z
Od`0ZWm<0:ajB@020:YjB@030:YlBP2XODX0Ygi:0080Ygm;0P2UO4P20:ImB@040:MnBP2XOd/0ZH1<
0:V0C0P0ZWm:0P2YP4`20:Z1C@80Zh9>0P2/Pdl80:f2C`T0[85>00<0[H=C0:b2DP2[PDl00P2YP4`0
1P2[PT`0[8=;0:f4C02ZOd`0Zh1=0:b1CP80[H9?00<0[85>0:^0C@2ZOd`0202/Pdl80:f2C`80[X9C
00@0[H5@0:f2C`2]PTl0[85<0P2/PDX80:j3D0P0[85<0100Z7e80:YoBP2/PD`0[H9=0:j3CP2]PTd0
[85<0:^0B`2YOTT0ZWm:0:^0B`2/PD`0Zh1;0:YoBP2XODP0YW]6202YOTT0202/PDh0Z7e:0:AiAP2T
NDH0Z7e:0:YoC02YOT/0Yga9202ZOdX01P2`OT/0[Wm;0:ioB`2/OTX0ZWm:0:V0BP80Yh190P2VNTT0
102WNdX0Z7a;0:UmC02YOD`20:YnC@080:ElB02YP4`0Zh9>0:Z1C@2VODT0YGa80:MnBP2[PTh80:Z1
B`030:V0C02ZPDd0Zh9>0080[8=?00H0ZX5=0:QoB`2WOTX0Z7e80:YoBP2[P4/20:b1C0030:^0B`2Z
OdX0Z7e800<0Z7e80P2YOTT=0:YoBP070:^0B`2/PD`0[H9=0:f2C@2/PD`0Zh1;0:YoBP030:^0B`<0
ZWm:0P2YOTT20:UmC0030:YoC02ZOdX0ZWm80080Zh5700<0Zh550:f2C@2]PTd00P2/PD`20:^0B`80
ZWm:00P0[H9?0:b1CP2ZOd`0ZGi;0:QmBP2YOT/0ZWm<0:^0C@P0[H9=0`2/PD`30:f2C@80[X=>0`2/
PD`30:f2C@@0[X=>0`2]PTd30:b1C0060:Z0A02[PDL0Zh570:b1BP2]PTd0[X=@0P2_Pe820:f4CP<0
[XE?0`2_QU080:n4C`80[X=>0`2_Q4l30;25D0060;:8CP2aQdd0/HM=0;26C02_QD/0[XA:0P2]PdT0
202_Pe80/8AC0;66D`2bQe80/XM@0;67C@2`QT`0[hE90P2`QDh0102`QE00/8EB0;25DP2`Q5<20;24
E@P0[XEA00P0[X=<0:n4C@2`QE00/HIC0;:7E02bQUD0/HEF0;24E@@0/XMD0P2cR5D30;B9EP040;J=
F@2eS5P0/XUE0;68E080/8MC00/0/HQD0;:9E@2cRUH0[hIB0:f4D02^QE40/XUE0;>:EP2aR5@0[HA@
0;27D`070;68E0P0/8MA00H0/h]>0;>;D02cRe00/XUA0;:9D`2aR5@20;67E@80/hED00H0/HED0;67
E@2`R5D0[XUE0:n:EP2^RUH20;:8F0040;67E@2aR5@0/HQD0;27D@80/8M?0P2bRED30;68E0<0/8MC
202^RED01P2`RUd0/8YK0:n9FP2^R5L0[HQD0:f8D`80[8M@0`2bQe@20;>8E@<0]8UF00<0/8MC0;68
E02cRUH00P2dReL00`2cRUH0/HQD0;27D`030:n6DP80/8MC0`2aR5@80;>:E0030:j9E@2`ReL0/HaH
0080/XeI00H0/HaH0;2;E`2^RED0[hIB0;27D`2bRED20;>:EP030;:9E@2aR5@0/8MC0080/hYD00<0
/hYF0;:8EP2bR5P00P2aQUT00`2aQU/0[XUE0:f8E0030:b7D`030:j9E@2`ReL0/HaH00T0/hYF0P2d
ReL20;>:EP80/XUE0P2aR5@80:n:E@80/XUC0`2aR5830;27D@P0/HQB0P2`Qe430:n6D0<0[XE?0P2a
R5820;27D@80[hI@0P2^QDl0202bRTd0/HU>0;69CP2`Qdl0[hI@0:j5D@2^Q580[H=A202]Q4h80:f4
D080[XE=00@0[XE?0:j5D@2^QE40[XAB0P2^Q5@20:f4D0<0[XEA0`2_QU820;27D@80[hI@00H0[XE?
0:f4CP2/Pdd0[8==0:f2C`2^Pe030:n4D@030:f2C`2[P4d0ZWm<0080[H=A00<0[HA@0:f4CP2]Q4`0
0P2]QDX00`2]QDP0[XA:0:j4BP060:j4BP030:V4C`2[QU40[8MB0080[HQC00<0[8MB0:^6D@2YQ4l0
202/Pdl00`2^QE40[8=?0:^2CP020:Z1C@050:^2CP2/Pdl0[XEA0:f2C@2/PD`0102[P4/03P2]PTd0
[hA?0;25D02^Q580[H=A0:b3C`2[PT`0Zh9:0:f5BP2_Qd`0/8Q;0:j5C`2/Pdd0Zh9<0P2ZPD/02`2[
PT`0[8==0:j5C`2ZP4h0Zh5?0:b3C`2^QDl0[XE=0:b4B@2[PdP0ZX9500@0Zh9<102ZPD/80:f4D0P0
[8=?202[PT`0202ZQdl0ZXE>0:V4C@2ZPd`0ZX5;0:b1C02^P4`0[h5=0P2^Pdh30:f2C@<0[85<0P2^
QDl0102]Q4h0[8==0:^2C02[PT`20:Z1B`080:V0C02ZPDd0[8=?0:f4D02^QE40[HA@0:b3C`2[PTh4
0:b1C0@0Zh1;00<0Zh9<0:Z1B`2YP4X00P2WOTP00`2YP4X0ZX5;0:^2C0030:^2CP80ZX5=0`2YP4`2
0:QmB0040:UnB@2ZOdX0Zh1;0:^0B`80[85<202[PTh80:V0BP80ZGi;0`2ZOd`30:^0C@80Zh9<00@0
Zh9>0:^1C`2[PDl0Zh5A0P2[P5<00`2[P5D0ZX5=0:V0C0020:QoB`040:V0C02[PTh0[HA@0:n6DPP0
Zh9>202ZOd`01P2_ODP0[Gi80:ioB`2]Odd0[85>0:^1C`80Zh=B0`2[PTh30:b3C`80[HA@0P2/Pdl2
0:^2CP80ZX5=102YP4`20:Z1C@80Zh9>0P2/Pdl20:b2D080Zh5?0P2ZP4h20:UoC@060;1nC@2^OTd0
[Wi=0:eoC@2[P4d0ZX5=0P2YPDd20:^2BP040:^2C02[PTh0Zh9>0:^1C`80Zh5A0`2YP4X20:QoB@<0
Ygi800<0Z7lo0:QnA02XO4/00P2YO5800`2ZOTd0ZX160:Z1@@080:ImA`030:IkB02WO4T0ZGi;0080
Zh1=00<0ZWm<0:UnB`2XODX00`2XOd/30:MnBP80YWe90`2ZPDd30:V0C080Z7m;0P2ZPDd00`2XOd/0
Ygi:0:MnBP020:MnBP030:QoB`2XOdT0Z7m900<0Ygi80`2VODL30:ImB@@0Ygi:0P2XOd/20:9nA004
0:9mAP2QO4L0XGa70:5lB080X7Y90P2SNTH30:AkA`<0YGa80`2UNTL20:AiAP<0XgQ500/0YgU80:Ih
A`2SMdH0XGM50:1hA@2PNdL0XWe90:9nBP2WOD/0YWa:0:AjB0030:9hAP0:0:=iA`2TNTP0Ygi:0:=j
AP2OMT80WWE10:5hA02SNTH0XWU50:1g@`80XgY40`2RND<30:5h@P80XgU70`2TNTP30:EkB@0;0:Ej
A`2TNDH0XgQ50:9gA02QMT<0X7E209md@@2NLd00X7M30:5hA02RNDD00P2TNdL02`2RNDD0XGQ40:1g
@`2OMDD0X7I60:5gA@2RNDD0Y7]70:ElAP2VODD0Ygi600P0XWQ6102QMdD40:1fA0060:=a?02QLS`0
XG8n0:5c@@2OM440WgE30P2NMTD20:1fA00309id@P2MLd40WG=10080WG=100<0WWA20:5gA@2QMdD0
1P2QMdD209ec@@80WWA200X0WgE30:1fA02QMdD0XGM50:9i@@2QN400XGQ20:1g@`2OMT80WWA20P2M
Ld<00`2QMdD0WgE309id@P0209ec@@80WWA200<0WgE30:5gA@2OMD<01`2OMD<30:1d@`80XGE40`2R
MTD0102OM4L0WW=609ebA@2KL4<209Y_@P80Vg1300H0W75609aaA02LLD@0W79209ab@02LLcl209ac
?@P0VVhm00<0UFXm09I[?P2HKD000`2IKT4209Q]@00609Q]@P2HKD00V6e009U_?`2IKcd0VW4m0P2J
LC/309Ia?@0509E`?02DKc/0U6lk09A_>`2CKSX00P2FJch0102EJSd0U6Tl09AY?02EJSd209I[?P80
TfTg00<0U6Xh09E[>@2FK3X00P2GKC/00`2HKS`0Uf`o09M/?`0309I[?P0309M/?`2IKT40VVm200L0
UFXm00<0U6Tl09EZ?@2EJSd01P2EJSd8099/?@@0Tfdn102DKSl0102GK3l0U6Tl099W>P2DJC`209I[
?P03095V>@2<HC@0TVLj00L0TVLj00H0U6/g09AZ>02CJCL0TVPh095V>@2@ICX208mT>P0608]T?@2;
I3/0S6Dl08eV>`2>J3/0SfTj0P2?JCP04P2@JST0TV`k091Z>@2>J3T0S6Hi08YS>02:HcX0Rf@k08]T
?@2BIc`0Sf@i08aQ=P2=HSL0T6Dj095V>`2>HcP0RUld095T>P80T6Dj00<0SVDi08aV>@2:ICP00P28
ISP00`29HcH0RfDh08eW>P0208mY?00308aV>@29HcH0QV0c00<0RV@g0`2;ICP208aV>@80SfHj00@0
SFLj08aW>P2;IST0RFLi0P28J3T808aU?00308EU=P26ISL0R6Hh0080S6Lj00<0RfDh08aS=`2;HSH0
0`2;ICP208aV>@<0SFLj0`2:I3d[ooooo`00:_ooool308IJ=`80QETf0`24F3D408AM=0@0QEhe00<0
QV0c08QR=@29HcH00P2:I3L01P29HcH0R68e08IP<`26GcH0Qf0g08UR>@80Rf@k00<0RV<j08UR>@28
HCP00`2<H3T308]O>080RUhg202=HSL0202:Icd0RFHl08UT>P29HST0RV0h08aP>@2=HCX0Sf8k0P2?
I3T308iS>0<0SF8g0P2>HCL208mR>080T6<i0P2AI3X9091S>@80U6Lm00@0TfHl099U>`2BIC/0TF@j
0P2@HcT208eQ?P0608aP>`2=HCX0SV<i091U>P2CJ3/0U6Tl202BIc`3099U>`<0TF@j0P2@HcT809=V
?009099U?02AI3/0TF@j095U>02BISL0U6Pg09IZ>@2GK3T0VFDm0080UfHm00<0UVLm09AW?@2CJ3d0
0P2BJCd3099V>@80TfLj0`2DJ3/409M[?P@0V6`o00/0VFhi09Q]>02HKCX0Uf/j09IZ>`2EJC`0U6Pk
09AW?@2BIcX0TfPk09EZ?@0309M/?`0309I[?P2EJSd0Ufdk00L0Ufdk0P2GK3L00`2GK3T0V6`k09Q/
?@0209U]@00309U/@P2JL3h0VW0n00H0VW0n0`2MLD0209a`?`<0Vfln0P2IKST01P2KL3d0Vfln09]_
@02KKd80VFe009U/@P<0W70o0`2KKch209Y^?@0309U]?02KKch0W70o0080WG5000<0W70o09]_?P2I
KC`00P2LLT800`2LLT00W7<o09ac?`0209ac?@80W7<k00<0WG=109ab@02KLCl00P2JL3h00`2KLCl0
W79009ec@@0209mc@P<0WW910`2MLD0309mc@P<0X7A30P2QMD@30:5f@`<0X7E20P2OM440202QMdD0
X7I40:1d@`2QLd80Xg=30:IcA02YMDH0ZgM8202RMd@80:EiB080Yg]<00@0Yg]:0:MlB@2WO4T0Yga7
0P2WO4D20:=iA`<0Y7Y80`2UNdT0202UNT<0Z7e60:^0B`2ZOd`0YW]80:EiB02WNd`0ZWi?202YOTT0
0`2UNTD0YW]60:MlA`020:QmB0040:MlA`2VNdH0YGY50:MlB@L0Z7e:00H0[7Y90:YjB@2ZNTT0ZWa:
0:QmBP2WOTX20:MoB`030:ImB@2WOTX0Ygi:00D0Ygi:202ZOdX20:V0C080ZX5=0P2[PTh20:b3C`P0
[H9?2@2/PDh00`2/PU80ZX1@0:UoC@020:QoB`060:V0BP2ZPDT0[8=;0:YoC02[P4d0[85>0P2]PTl0
0`2/PDh0Zh1=0:YoC0080:b3C`P0[H9?0P2^PU<0102]PE00[H9?0:f2C`2/PD`20:b1BPP0[85>202/
PD`02`2XODP0ZWm:0:b1C02]PTd0[X=>0:f2C@2/PD`0Zh1;0:YoBP2[P4/0[85<0080[H9=00<0Zh1;
0:UnB@2XODP0202YOTT01@2ZOd`0YW]80:=hA@2TNDH0Z7e:0080Zh1=00<0ZGi;0:YoBP2ZOdX01P2Z
OdX01P2`OT/0[Wm;0:ioB`2/OTX0ZWm:0:V0BP80Yh1900<0ZGe<0:YnC@2ZOTd01@2ZOTd0202UO4P0
ZH1<0:^2CP2ZPDd0YWe90:ElB02WOTX0Zh9>202YP4X02`2XOd/0ZH1<0:Z1C@2[PTh0ZX5=0:V0C02W
OTX0YGa80:QmB02ZOdX0Zh1;0080[85<00<0Zh1;0:YoBP2XODP00`2XODP20:UnB@d0ZWm:00L0Zh1;
0:b1C02]PTd0[H9=0:b1C02[P4/0ZWm:00<0Zh1;0`2ZOdX20:UnB@80ZGe<00<0ZWm<0:YoBP2ZOdP0
0P2[PDL00`2[PDD0[H9=0:f2C@020:b1C080Zh1;0P2ZOdX0202]PTl0[85>0:YoC02YOT/0Z7e:0:Un
B`2ZOd`0Zh1=202]PTd30:b1C0<0[H9=102^Pdh30:f2C@<0[85<0P2^Pdh30:f2C@<0[85<00H0ZX14
0:^1A`2[PDL0[85:0:f2C@2^Pe020:n3DP80[HA>0`2^QDl30:n6D0P0[hA?0P2^Pdh30:n4C`<0/8E@
00H0/XQ>0;67C@2aQdd0/8I<0:n5B`2^Q4X20:f3B@080:n3DP2`Q5<0/HIC0;:7DP2bQe00/HM=0;26
C02_QDT20:n4C@040:n4C`2_Q540[hAA0:n3DP80[h=D202^QE40202aQTl0/8E>0:n4C`2_Q540/8EB
0;65E02bQUL0/hMH102bQe@20;>8E@<0]8UF00<0]8]G0;>:EP2aR5@00P2`Qe<02P2aR5@0/hYF0;B;
E`2dReL0/HQD0:j5D@2`Qe<0/hYF0;F<F02bRED30:n6DP80/8MC00@0/HQD0;:9E@2cRUH0/hYF202b
RE<01P2cRdh0/h]@0;>;D02bRE40/XUC0;68E080/HME0P2cQE@01P2aQE@0/HME0;28E@2^RED0[hYF
0:j:EP80/XQH00@0/HME0;68E02aR5@0/8MA0P2`Qdl20;:9E@<0/HQD0`2`Qe<80:j9E@080:j8F`2^
R5T0[XQI0:j8E`2^RED0[XUD0:j9DP2]R5430;:7E080/hQE0`2dREH00`2`Qe<0/HQD0;>:EP020;B;
E`030;>:EP2aR5@0/8MC0080/8MC0P2aR5@20;:9E@80/hYF202aR5800`2^RED0/8]G0;6<F0020;:=
F@070;6<F02`ReL0[XUE0:n6DP2`Qe<0/XUE0;B;E`020;F<F0070;B;E`2cRUH0/hYD0;>:E02cRUH0
/XQF0;:8F0020;66F@030;66F`2^RED0[HQD00<0[8MC00<0[XUE0;2;E`2aS5P02@2cRUH30;F<F080
]8]G0`2cRUH80:n:E@80/XUC0`2aR5830;27D@/0/HQB0`2`Qe420:n6D080/HQB0P2`Qe420:n6D080
[XE?00H0/8Q;0;28C@2`R4d0/8M?0:n6D02_QU820:n5D`P0[HA>202]Q5020:j5C@040:j5C`2^QE40
[XEA0:j4DP80[XAD0P2]Q5030:j5D@<0[hIB00<0[hI@0:j5C`2^QDl01@2^QDl0202^Pe00[hAA0;25
DP2aQU<0/8EB0:n4D@2]PTl0[85>0P2]Pe400`2]Q500[HA>0:f4C0020:f5BP030:f5B02/PTP0[898
00H0[89800<0ZHA?0:^6D@2/Qe800P2]R5<00`2/Qe80ZhIA0:V4C`090:j5D@090:b3C`2[PTh0ZX5=
0:Z1C@2[PTh0[8=?0:j5D@2]PTd0[85<00@0Zh1;00h0[H9=0:n4C`2`QE00[XAB0:f3D@2/Pdl0Zh9<
0:^2BP2]QDX0[hM<0;28B`2^QDl0[8==0:^2C080ZX5;00/0Zh9<0:b3C@2^QDl0ZX1>0:^1C`2/Pdl0
[XE?0:j5C@2/Q4T0Zh=80:Z2A@040:Z1B`@0Zh9<202]Q5080:b3C`P0Zh9<00P0Z8E=0:V4C@2ZQDh0
[8E>0:f4CP2]PTd0[Gm;0:anBP80[X=>0`2]PTd30:b1C0L0[8==00T0Zh9<0:V0C02ZPDd0[8=?0:f4
D02^QE40[HA@0:b3C`2[PTh0102[P4/40:b1C0030:^2C02ZPD/0ZH1:0080Ygi800<0ZH1:0:Z1B`2[
PT`00P2ZPDd20:V0C080Z7m;0P2WOTX70:YoBP030:^0B`2[PTh0Zh9>00H0Zh9>202YP4X20:UnB`<0
ZWm<0`2[P4d20:Z1B`040:Z1C@2ZP4h0ZX1>0:Z0D080ZWmB00<0ZWmD0:Z1C@2YP4`00P2XOd/0102Y
P4`0Zh9>0:f4D02_QU880:^2CPP0ZWm<00H0[ge80:enB02^Od/0[Gm=0:b1CP2[PDl20:^3DP<0Zh9>
0`2/Pdl20:f4D080[8=?0P2[PTh20:Z1C@@0ZH1<0P2ZPDd20:^2CP80[8=?0P2/PU020:^1C`80ZX1>
0P2YOdd01P2_OD`0[Ge<0:emC02/OT`0ZWm<0:V0C080Z81<0P2ZPDT0102ZPD/0ZX5=0:Z1C@2ZP4h2
0:Z0D0<0ZH1:0P2XOdT30:MnB0030:Z1@@2ZP4H0ZWi=0080ZGaB00<0Z7a;0:QnA02XOcl0202VODL0
0`2VNdP0Yga90:UnB`020:^0C@030:YoC02YOT/0Z7e:0080ZX5=0`2YP4`30:QoB`<0ZX5=0`2YP4`3
0:QoB`@0ZH1<00<0Z7m;0:ImB@2VODT00`2VODL30:MnB080Z7m90`2VODT40:MnBP80Z7m;0P2PO480
102QO4D0XGa70:5lA`2RODT20:9lB`80XgY60`2TNdL30:ElB0<0YGY70P2TNDH30:=hA@0H0:MiB02V
N4L0XgM60:5gA@2PN4D0X7]70:9mB@2ROTX0YG]90:AjB02RN4H0XGM50:1fA02QMdD0XWQ60:=iA`2W
OTX0XgY609mf@P2NMD40XGQ40:=jAP2RNDD0X7M30P2SNT@30:9i@`<0XGQ20P2SNDL30:AjB0<0YG]9
0P2SN4D20:9gA080XGI30P2PMD800`2PMd<0XGQ40:9iA@020:AkA`0;0:9iA@2QN4@0X7M309meA@2P
MTH0XGM50:9iA@2TNdL0YGa60:ImA@2WOTH0202RN4H01@2SNDL0XWQ60:9hAP2QMdD0X7I40080WgE3
00L0WWA20:=a?02QLS`0XG8n0:5c@@2OM440WgE30080WWI500<0WWA209me@`2OMD<00P2OMD<00`2N
M480W79009ab@0080:5gA@L0WG=100L0WWA20:9i@@2QN400XGQ20:1g@`2OMT80WWA20080WG=300<0
WgE309id@P2MLd400P2KLCl209ec@@0309id@P2OMD<0X7I400L0X7I40P2NLT4209mc@P80X7A30P2Q
MD@209ebA@0709icAP2OM4L0WgA709icAP2MLTD0W75409aaAP0209aaA00309ab@P2LLT00W7<o0080
W7<m202JKSd02@2HKD00Uf`o09M/?`2FJch0Uf`o09Q]@02IKT40VVm209Q]@P0209Q]@00309U_?`2I
Kcd0VW4m0080VW4k0P2HLcl0202GLSh0UG0l09A_>`2CKSX0TVdi095/>02DJC`0UFXm102FJch01`2E
JSd0U6Tl09=Y=`2CJCL0U6Xh09E[>@2FK3X00P2GKC/0102HKS`0TfPk09AY?02FJch309M/?`80UV/n
0P2EJSd209AY?00409=X>`2BIcX0TFHi095V>@P0TfPk202CKCh409A^?`@0Tfdn00P0V6e009EZ?@2D
JC`0UFXm09Q]@02GK3l0TfPk08iS=PP0TVLj00H0U6/g09AZ>02CJCL0TVPh095V>@2@ICX208mT>P06
08]T?@2;I3/0S6Dl08eV>`2>J3/0SfTj0P2?JCP04P2@JST0SfTh08eW=P2;ICH0RV@g08UR=`2:HcX0
Rf@k08aU?P2DJCh0T6Dj08eR=`2>HcP0TFHk099W?02?I3T0S64f08mR>080SV<h00<0SVDi08aV>@2<
IcX00P2:J3X0202:I3L0S6Hi08mY?02AJch0T6Xm08iX>`2:I3L0R68e0`2:I3L308]U>080S6Hi0P2B
JCd0102?JC`0SFPk08eX>`2:J3X208QX>@P0S6Dl00<0QFDf08IV=`28ISP00P2<IcX00`2;ICP0S6<g
08]R=P0308]U>080S6Hi0`2=IcX308YT?B_ooooo000Zooooo`<0QUXg0P25FCH308AH=@0408IO=P25
GSD0QEhe08EN=@<0Q5dd00@0Pe`c08IP<`28HSD0RF<f0P2:I3L01P29HcH0R68e08IP<`27H3L0R64h
08YS>P80S6Dl00<0Rf@k08YS>P29HST00`2<H3T308]O>080RUhg202=HSL0202;J3h0RVLm08YU>`2:
HcX0Rf4i08eQ>P2>HS/0T6<l0P2@ICX00`2?I3T0SV<h08eR=`0208aQ=P0308]P=@2?HSP0T6<i0080
T6<i0P2AI3X2099U>`T0T6<i0P2FJCl0102EJ3h0U6Lm099U>`2AI3X2091S>@80S60m00H0S60k08aP
>@2>HcT0TFHk09AY?02EJSd8099W?0<0TVDk0`2AI3X2091S>@P0TfHl00T0TfHm095T>`2?HSP0Sf<f
08mS=02BISD0UFTh09M/>@2IICd00P2GISd00`2FIcd0U6Lm09=X?@02099Y?@<0TFDh0P2BIST309=W
>P0509EY?02FJSd0UVXm09M[?P2HK3l00P2IKD00302JKT40VFhi09Q]>02HKCX0Uf/j09IZ>`2EJC`0
U6Pk09AW?@2BIcX0TfPk09EZ?@<0Uf`o00<0UV/n09EZ?@2GKC/01`2GKC/209I[=P0309I[>02GJcX0
Uf/l0080V6`o00<0V6]109Y`?P2JL3h01P2JL3h309ib@@80WG500`2LL3l02@2GK3L0VFhi09]`?@2M
LD00WG5209]_@P2IKD00UfY009ib@@0209ea@00309a`?`2KKch0VVhm00<0VFdl00L0Vfln09a`?`2M
LD00WG5009a`?`2KKch0VFdl0080WG=300<0WG=109ed@02MM4000P2MM3h209ed?00309ec@@2LLT00
Vg4o0080VW0n00<0Vg4o09ab@02MLd400P2OLd8309ib@@<0WG500`2PM4<30:5eA080XWI50`2QMT<3
0:1e@P80WgA100P0XGM50:1fA02PM4<0XG=20:=c@`2VLd@0ZGE60:]gB0P0XWM4202VNTT20:MkC004
0:MkBP2WO4T0Yga90:MlA`80Yga50P2SNDL30:AjB0<0YG]900P0YGY30:QmAP2[P4/0ZWm<0:IkB02U
NDP0Yg]<0:YnC`P0ZWm:00<0YGY50:IkAP2WO4L00P2XODP00`2WO4L0YW]60:EjA@020:UnB`<0Z7e:
0`2WO4T01P2/NTT0ZWY90:YjB@2ZO4X0Z7e:0:MnBP80Ygm;0P2XOd/30:MnBP<0YWe9202ZOdX20:V0
C080ZX5=0P2[PTh20:b3C`P0[H9?2@2/PDh00`2[PE40ZGm?0:QnC0020:MnBP060:QoB@2YP4P0Zh9:
0:YoC02[P4d0[85>0P2]PTl00`2/PDh0Zh1=0:YoC0080:b3C`P0[H9?0P2^PU<0102]PE00[H9?0:f2
C`2/PD`20:b1BPP0Zh1=202/PD`01`2XODP0ZWm:0:b1C02]PTd0[X=>0:f2C@2/PD`00P2[P4/01P2/
PD`0[H9=0:j3CP2^Pdh0[85<0:YoBPT0ZGi900D0ZGi;0:EjA`2RMd@0XgQ50:QmBP020:b1CP030:Yo
C02ZOdX0ZWm:00H0ZWm:00H0/7i;0:ioB`2^Od/0[7i:0:YoBP2YP4X20:N0B@80[81?0`2[Odh30:Yn
C@080:ElB02YP4`0Zh9>0:Z1C@2VODT0YGa80:MnBP2[PTh80:MnB00;0:MnBP2XOd/0ZH1<0:Z1C@2Y
P4`0Z7m;0:ImB@2TNdL0Z7e80:YoBP2[P4/00P2/PD`00`2[P4/0ZWm:0:QmB0030:QmB080ZGi93@2Z
OdX01`2[P4/0[85<0:f2C@2]PTd0[85<0:^0B`2ZOdX00`2[P4/30:YoBP80ZGi90P2YOD`00`2ZOd`0
ZWm:0:YoB0020:^1A`030:^1A@2]PTd0[H9=0080[85<0P2[P4/20:YoBP080:f2C`2/PDh0ZWm<0:Un
B`2XODX0ZGi;0:YoC02[P4d80:f2C@<0[85<0`2]PTd20:j3CP80[hA?00<0[X=>0:f2C@2/PD`00P2[
P4/00`2ZOdX0[X=>0:j3CP030:f2C@<0[85<00H0ZX140:^1A`2[PDL0[85:0:f2C@2^Pe020:n3DP80
[HA>0`2^QDl30:n6D0P0[hA?0P2^Pdh30:n4C`<0/8E@00H0/XQ>0;67C@2aQdd0/8I<0:n5B`2^Q4X2
0:f3B@080:n3DP2`Q5<0/HIC0;:7DP2bQe00/HM=0;26C02_QDT20:f2B`040:f2C@2]PTl0[H9?0:f1
D080[H5B202^QE40202bQe00/HI?0:n4C`2]PTl0[X=@0;24D`2cQeP0]HUJ102bQe@20;>8E@<0]8UF
00<0/hYF0;:9E@2aR5@00P2`Qe<04@2bRED0]8]G0;F<F02eS5P0/XUE0:n6DP2aR5@0]8]G0;J=F@2c
RUH0/8MC0:f4D02^QE40[hIB0;27D`2aR5@0/hYF0080]8]G202cRU@01P2cRdh0/h]@0;>;D02bRE40
/XUC0;68E080/HME0P2cQE@01P2aQE@0/HME0;28E@2^RED0[hYF0:j:EP80/XQH00@0/HME0;68E02a
R5@0/8MA0P2`Qdl20;:9E@<0/HQD0`2`Qe<80:j9E@060:f7FP2]QeP0[HMH0:j8E`2^RED0[XUD0P2_
RU<30;:7E080/hQE0`2dREH00`2`Qe<0/HQD0;>:EP020;B;E`040;>:EP2aR5@0/8MC0;68E0<0/XUE
0P2cRUH20;B;E`P0/8MA00<0[XUE0;2;E`2aS5P00P2bSET01`2aS5P0/8]G0:j9E@2_QU80/8MC0;>:
EP2eS5P00`2fSET01P2eS5P0/hYD0;>:E02cRUH0/XQF0;:8F080/HII00<0/HIK0:j9E@2]R5@00`2/
Qe<00`2^RED0/8]G0;6<F0090;>:EP<0]XeI0P2eS5P30;B;E`P0[hYE0P2bRE<30;68DP<0/8MA202a
R5840;:9D`80/HQB0P2`Qe420;68DP80/8MA0P2_QU020:j5C`080:j6B@2_Qd`0[hM<0:n6CP2`Qe40
/8MC0;26E02aQeD80:f4CPP0[HA@0P2^QDd0102^QDl0[XEA0:j5D@2^Q5820:j4E080[HA@0`2^QE43
0:n6DP80[HA>0`2^QDl30:n6D0080:n4D@2`QE80/HIC0;:7E02aQU<0/8EB0:j3D02]PTl20:f3D@03
0:f4D02]Q4h0[HA<0080[HE:00<0[HE80:^1A`2[PDL01P2[PDL00`2YQ4l0ZhIA0:b7DP020:f8D`03
0:b7DP2[QU40ZHA?00P0[hIB00<0[XEA0:b3C`2[PTh00P2ZPDd01@2[PTh0[8=?0:j5D@2]PTd0[85<
00@0Zh1;00h0[H9=0:n4C`2`QE00[XAB0:f3D@2/Pdl0Zh9<0:^2BP2]QDX0[hM<0;28B`2^QDl0[8==
0:^2C080ZX5;00`0Zh9<0:b3C@2^QDl0ZX1>0:^1C`2/Pdl0[XE?0:j5C@2/Q4T0Zh=80:Z2A@2XOdT2
0:V0BP050:Z1B`2[PT`0[8==0:b3C@2]Q4h0202]Q5080:b3C`P0Zh9<00P0YX=;0:V4C@2[QTl0[XM@
0:j5C`2]PTd0[7i:0:]mB@80[X=>0`2]PTd30:b1C0<0Zh9<0`2/Pdd20:f4CP090:V0C02ZPDd0[8=?
0:f4D02^QE40[HA@0:b3C`2[PTh0ZGi90080ZWm:00P0Zh1;0:b1C02]PTd0[H9=0:j3CP2[PT`0ZX5;
0:V0BP80Ygi800@0ZH1:0:Z1B`2[PT`0ZH1<0`2XOd/20:MnBP80YWe90`2[P4/30:YoBP80ZGi9202[
PTh80:V0BP80ZGi;0`2ZOd`30:^0C@80ZH1:00@0ZH1<0:UoC@2YOdd0ZGm?0P2YOU400`2YOU<0ZX5=
0:V0C0020:QoB`040:V0C02[PTh0[HA@0:n6DPP0Zh9>202ZOd`01P2_ODP0[Gi80:ioB`2]Odd0[85>
0:^1C`80Zh=B0`2[PTh30:b3C`80[HA@0P2/Pdl20:^2CP80ZX5=102YP4`20:Z1C@80Zh9>0P2/Pdl2
0:b2D080Zh5?0P2ZP4h20:UoC@060:ekBP2[NdX0Zg]:0:YlBP2XODX0Ygi:0P2VOTX20:V0B0040:V0
BP2YP4`0ZH1<0:UoC@80ZGm?0`2YP4X20:QoB@<0Ygi800<0Zh920:^1A`2ZOTd00P2YO5800`2XO4/0
Yge30:Mn?P080:ImA`030:IkB02WO4T0ZGi;0080Zh1=00<0ZWm<0:UnB`2XODX00P2[PTh30:Z1C@<0
ZH1<0`2ZPDd30:V0C080Z7m;00<0YWe90:QoB`2ZPDd00P2[PTh0102YP4`0YWe90:AkA`2TNdD20:El
AP030:ImA`2WOTP0Z7m90080ZH1:0`2VODT40:MnBP80Z7m;0P2ONd401P2PNd@0XGa70:9mB02SOTX0
Xge<0:AnC@80XgY60`2TNdL30:ElB0<0YGY70P2TNDH30:=hA@0H0:MiB02VN4L0XgM60:5gA@2PN4D0
X7]70:9mB@2ROTX0Y7Y80:=iA`2QMdD0X7I409me@`2PMT@0XGM50:9hAP2WOTX0XgY609mf@P2NMD40
XGQ40:=jAP2RNDD0X7M30P2SNT@30:9i@`<0XGQ20P2SNDL30:AjB0<0YG]9102RMd@40:5f@`030:1g
@`2QN4@0XWU50080Y7]700/0XWU50:5hA02PMd<0WgE50:1fAP2QMdD0XWU50:AkA`2UO4H0YWe50:Mn
AP080:9hAP0>0:AjB02SNDL0XWQ60:5gA@2PMT@0WgE309id@P2MLd40Xg4l0:5b?02QLSh0XG=109md
@@2OMD<209ifA@0309ab@02NM480X7I40080XGM500<0WgE309ab@02JL3h0202QMdD309ec@@<0W790
0P2KLCl01P2RND40XGQ00:5h@P2PMd<0WgI209id@P80WG=300<0WWA209ec@@2KLCl00P2JL3h209]a
?`0309ec@@2NM480XGM500L0XGM50P2MLD0209ib@@<0Wg=200X0X7A309]`@`2LLD@0WgA70:5fB@2R
MdX0X7E809icAP2MLTD0W7560P2LLD@00`2LLT80W79009ac?`0209ac?@P0VVhm00<0VVm209Q]@02F
Jch00P2EJSd0102GK3l0VVm209aaA02HKD8209Q]@00309U_?`2IKcd0VW4m0080VW4k0P2IM4002@2G
LSh0UW4m09A_>`2BKCT0TF`h091[=`2BIcX0U6Tl09I[?P0209Q]@00309I[?P2DJC`0TVLj0080TfTg
00<0U6Xh09E[>@2FK3X00P2GKC/03`2HKS`0TFHi099W>P2EJSd0Uf`o09Q]@02GK3l0UFXm09=X>`2F
Jch0UFXm09AY?02CJ3/0TVLj091U>00208mT=`P0TVLj202DKSl01@2FL440UFm009E_@02DKSl0Tfdn
0080TV`m00T0TF/l09U^@@2FJch0UFXm09I[?P2IKT40V6e009AY?02?I3L0202BIcX01P2DJcL0U6Xh
09=Y=`2BJ3P0TFHi091U>P80Sf@j00H0Rf@m08]T>`2<IC`0SFHk08iX>`2?JCX208mY>00G091Z>@2<
ISD0RfDd08YT=@28HSD0R64f08UR>@2;I3/0S6Dn09EZ?`2AIS/0SV<h08mT>@2BIc`0TfPm091U>P2=
HSL0SV4g08eR=`2>HcP0SVDi08aV>@2<IcX00P2;JC/0202;ICP0SFLj091Z?@2BK3l0TF/n08mY?02;
ICP0RF<f0`2:I3L308]U>080S6Hi0P2DJcl0102AJch0SfXm08eX>`2:J3X208QX>@P0S6Dl00<0QFDf
08IV=`28ISP00P2<IcX00`2;ICP0S6<g08]R=P0308]U>080S6Hi0`2=IcX308mY@R_ooooo000Zoooo
o`0308EN=`24GCH0Pe`e0080PEXc00<0Pe`e08AM=P25GSL00P28G3D01029GCH0RUhg08YN=`2;GcP2
08aP>@04089K<P23G3<0QUlf08UR>@80RV<j00<0RF8i08QQ>029GCH00P2:GSL00`2;GcP0S60i08aP
>@0208eQ>P80S64f00@0Rf0e08YO=02:Gc@0REhc0P28GC801P27HSD0R68e08QR=@2:HCD0Rf0e08aO
=@80SUle00<0SV8k08eQ>P2<H3T00P2<H3T01P2>HS/0Sf<l095U?P2BIC/0TF@j08mR>0<0SF0f00<0
SV4g08mR>02>HS/01`2>HS/3091U>P<0Sf@i0`2>HcP00`2?I3T0TFHk099W?00209AY?P03099W?02A
IS/0Sf@i0080RUld00H0Rf0e08eR=`2?I3T0T6Dj095V>`2BIc`3095V>`80TVLl0`2CJ3d209EV>P03
09=W>P2BIcX0TFPj0080SfTj00<0SVXj09=W>P2CIcX03P2CIcX00`2AIS/0TVLl09AY?P0209EZ?`03
09AY?P2BIc`0TFHk0080UFTl0`2FJSd509M[?P80V6`o00@0VFe009Y^@@2JKT40Vfm2202EJcT809AX
>`0609=W>P2DJ3/0U6Pk09IZ?@2GJch0V6`o0P2IKD0909U]?080VVhm00<0Vfln09a`?`2LL3l00P2M
LD0209]a?`0409Y`?P2IKcd0VFlm09Q^?080Ufdk202JKSd00`2LL3l0Vfln09U]?00209Q/>`0309U]
?02KKch0W70o00<0VFhk0P2JKc`309]`?@T0WW=00P2MLSd00`2MLSl0WG5009ea@P0209eaA00909e`
AP2MLd40Vg4o09Y`?P2IKcd0VW0n09]a?`2MLd40WgE300P0WgA100@0WW=009md@@2OM440X7E20P2Q
MT<20:9gA0@0YGE4102TM4<00`2OM440X7E20:9gA0020:AiAP0;0:=hA@2QMT<0X7E20:=hA@2RMd@0
XGI30:9gA02SN4D0YGY70:MlB@2YOT/00P2VNd@0102VNdH0YGY70:EjA`2UNDP20:AhB@80Y7U60`2U
NTL30:IkB0080:emC@2ZNTX0Z7Q80:IfAP2WMdL0ZWY:0:inCP2aPE480:UnB`040:9g@P2TND@0YW]6
0:MlA`80Z7e800<0Yga70:IkAP2XODX01`2XODX80:UnB`P0Z7i>202YOTL80:^2CP80[81?1P2]PE00
102ZOdX0Zh1;0:^0B`2[P4/40:b1C0030:f2C@2YP4`0ZH1<00H0ZH1<0P2[PDl00`2[PTh0Zh9<0:^2
BP020:^3B0030:^3AP2/Pdd0Zh9<0080Zh9<0`2ZPD/00`2YP4X0[HA>0:f4CP030:b3C@<0Zh9<00D0
[X=>0:f2C@2]PTd0[85<0:^0B`020:YoBP030:UnB@2ZOd`0ZWm<00@0Zh1=1@2/PDh30:f2C`80[X=@
202ZOd`20:b1CP<0Zh1=0`2ZOd`80:UnB@80ZGi;0`2XODX30:MlB@030:YoC02YOT/0Yga90080Yga9
00/0ZGi;0:^0C@2/PDh0Z7i20:Z0AP2[PDL0[85:0:b1C02[P4d0ZWi=0:QlB`020:QoB@<0ZH1:0`2Z
PD/0202ZPDd0Zh9>0:f4D02]Q500[8=?0:Z1C@2XOd/0YWe90P2ZOTd00`2ZOd`0ZGi90:UnA`020:Qn
A0030:Qn@P2YP4`0ZH1<0080ZX5=0`2[PTh00`2/Pdl0Zh9>0:^2CP060:^2CPT0ZWm<402YOTT00`2/
PDh0Zh1=0:YoC0020:QmBP030:YoC02[P4d0[85>00P0Zh9<00<0[hA?0:f2C@2[P4/00P2YOTT00`2Z
OdX0Zh1;0:f2C@080:^2CP<0Zh1;0P2/PD`30:f2C@P0Zh1;00H0[H=70:f3B@2]PdT0[H9;0:f2C@2]
PTl20:f1D0P0[85<00@0[8A90:f5BP2]QDX0[HE:0P2^QT/20:n7C0<0[XE?0P2]Q4h40:b3C@070:f4
CP2_QU00/8MA0;27D@2_QU00[HA>0:b3C@080:n6CPP0[XEA0P2]Q4h30:j5C`<0[hI@202]Q5020;27
D`80[hIB00@0[XEA0:f4D02]Q500[8=?202^Q5820:^6DP090:j9E@2aS5P0/8]G0:b7D`2[QU80[HQD
0;2;E`2aR5@0/8MC00<0[XEA00<0[hIB0;68E02bRED0202]R5@20:j5D@80[hIB0P2`Qe<20;68E006
0:j6B@2^QT/0/8Q=0;68D02cRU@0]8]G0P2fS5X00`2cRUH0/XUE0;27D`020:j5D@030;27D`2bRED0
/hYF00P0[hYE0P2aS5P0102`ReL0[hYF0:n:EP2^RED20:f8E080/XQF0`2aQeD30;26E080/XUE0`2a
R5@30;27D`030;2;E`2^RED0[HQD0080[8MC00<0[HQD0:j9E@2`ReL0202cRUH20;:9D@040;68DP2a
R5@0/HQD0;26E080/8IF102eS5P70;B;E`D0/hYF0P2`Qe401P2aR580/hYD0;B;E@2eS5H0]XeG0;N>
F0P0]8]G0`2cRUH20;:9E@<0/HQD0P2eS5H20;B;E@050;>:E02bRE<0/XUC0;68DP2]Q5000P2_QU80
1P2aR5@0/hYF0;B;E`2eS5P0]8]G0;>:EP80/XUC0`2aR5840;27D@0:0;68DP2cRU@0]8]E0;B;E@2c
RU@0/HQB0;27D@2bRE<0/8MA0:n6D080[HA>00<0[hI@0;27D@2bRE<0202^RE@20;6<E@040;2;E02_
RU<0[hYC0:j9DP80[HQA00T0/XUE0;>:EP2dReL0]8]G0;:9E@2_QU80[HA@0:^2CP2]PE000P2^PU40
0`2_Pe80/8AC0;24D`020;65E080[HQC0P2/Qe80102[QU40ZXE@0:Z5D02YQ4l20:n6D0040:j5C`2]
Q4h0[HA>0:b3C@80Zh9<202]Q5080:j5D@80/8MC0P2_QU80102^QE40[HA@0:f4D02/Pdl80:Z6C0<0
[XAD0P2]Pe<30:b2DP040;25D02^Pdh0[85<0:YoBP80ZGi900<0ZWm:0:^0B`2]Q5001`2]Q5020;27
D`<0[hIB1P2^QE420:f4D0<0[8=?00L0Z8130:V1A02ZPTD0ZX950:^3AP2/Q4L0[XI90080[hM:202]
Pe400`2[PTh0[8=?0:f4D0020:j5D@040:f4D02/Pdl0Zh9>0:j5C`80[HA>00<0[8==0:^2C02[PT`0
0P2ZPD/20:^1D@040:^1C`2[PTh0Zh9>0:^2C080Zh9:0P2ZPDd20:^2CP050:b3C`2]Q500[HA@0:j5
D@2_QdX00P2^QTT00`2/Q4L0Zh=60:Z2A@020:V1A0030:j5C`2/Pdd0Zh9<0080ZX5;00H0Zh9<0:b3
C@2^QDl0Zh9>0:b3C`2^QE420:n6DP0;0:j5D@2/Pdl0Zh9>0;:7E02_Q540[85>0:f2C`2`QE80/HIC
0:j3D02[P4d0202/PD`0202VODT0Ygi:0:QoB`2ZPDd0Zh9>0:f4D02^QE40[hIB202/Pdl20:f2C@80
[85<0P2[P4/20:YoBPP0Ygi:00@0[XAD0:f3D`2]Pe<0[89B0P2[PE420:Z0D0P0[85>00@0Ygi80:Qo
B@2[PT`0[HA>0`2^QDl00`2]Q4h0ZH1:0:V0BP060:V0BP030:MnBP2XOd/0ZX5=00<0Zh9>00H0ZX5=
0:QoB`2WOTX0[XE=0:b3B`2[PT`20:Z1C@0<0:^1C`2/PU80[XAD0;27D`2^QE40[8=?0:Z1C@2YP4`0
ZX5=0:^2CP2/Pdl0Z7m;0P2YP4`0202ZPDd0Zh9>0:b3C`2/Pdl0[HA@0:b1CP2[P4d0ZWm<0P2XODX0
0`2ZOd`0Zh1=0:b1CP080:b3C`P0[H9=00<0[HA@0:^2CP2YP4`00P2WOTX04`2YP4`0Zh9>0:f4D02/
P5T0[85G0:b1EP2[PE40ZX5=0:V0BP2YP4P0ZH560:j5C`2/Pdd0ZX5=0:QnC02WODd0Yga?0:QmD02Y
OU<00P2YOdl0102YOdd0Z7m;0:QoB`2WOTP20:MnAP030:MnB02VODL0YGa60080YGa600<0Ygi80:V0
BP2ZPD/0202XOd/30:Z1C@<0ZH1<0P2XOd/20:^2CP80ZX5=00@0ZH1<0:QoB`2XOd/0Ygi:202XODX8
0:UoC`P0Zgm@202WOD/40:ElB0D0YWe90P2TNDH30:EjA`<0YW]80P2UNd/0102UNdT0YGa80:ElB02U
O4H20:ElA0040:=hA@2TNDH0Y7U60:EjA`80YW]80P2WO4T80:EkB`80YGa800@0Y7]70:=jAP2SNTH0
XWU50P2QN4@00`2MLd40WWA209me@`020:5gA@0F09me@`2NM480WG=109id@P2QMdD0Y7Y80:9hAP2O
MD<0WG=10:1fA02SNDL0X7U@0:1iCP2PNTd0X7Y90:1kAP2PNd@0X7a20:1l@02XMT<0YgE20:Id@@80
YG=000D0YWA10:Me@P2XMT<0XWQ80:5gA`030:1fAP030:9hB02TNTX0YG];0080X7M100@0XGQ20:9i
@`2TNdD0YGa60P2VODL20:1fA0040:5gA@2RN4H0Y7Y80:EkB@80YWa:202OMD<209ab@00409ec@@2N
M480WgE309me@`<0X7I400H0XGM50:9hAP2TNTP0Y7Y80:9hAP2QMdD20:1fA00;09me@`2NM480WG=1
09id@P2OMD<0XGM50:9hAP2FLCd0Ug8n09Ud@02KMT800P2LMd<0202KMT80VWE10:5fB`2QMTT0X7E8
09meA@2MLd40W7<o0P2KLS`01@2SN4D0XWM40:5f@`2OM440WG8o0080Vg0m00@0VFhk09Q]>P2NM480
WWA20P2OMD<40:1fA080X7M3102QN4@20:9iA@80WW=80`2MLTL309aaAP0409Y`?P2KLCl0Vg4o09]a
?`<0W79000<0WG=109U_?@2IKcd01P2IKcd809Y_@P0309Mb?P2HLcl0VGA00080VGA000@0Ug8n09E`
?02DKc/0VW0n0P2IKcd00`2HKS`0Ufdk09M]>`0209I/>P0;09E/>02EJcT0UV`j09M]?@2HKD00VVm4
09Y_A@2KL4H0UFm009I`@@2GLD800P2HLT<00`2FL440U6ho09=]?P0309I/>PD0UF/i0`2HJST209MY
>0<0UVPg00<0TVLj09AY?02FJch00P2GK3l00`2FJch0U6Tl099W>P0809EZ?@<0U6lk1@2EL3`309Q]
@00309M/?`2FJch0UFXm0080UFXm202BIcd509=X>`<0TVLj00H0SfDc091V=02BJ3H0TfTg09AZ>02C
JCL2099X=P07095W=@2@JS/0SVPi08]U=P29Hc@0Qf4b08QR<`0208US=00308eW>02<ISL0RfDf0080
RV@e00<0S6Hg08iX>@2?JCX00P2<IST308]U>0<0RV@g00<0Qf4d08US=P2:I3L00P2<IST00`2:I3L0
RF<f08MQ=00208YT=`<0RF<f00<0RfDh08eW>P2?JC`00P2?JCX2095[?004091Z>`2>J3T0S6Hg08YT
=@80SfTh00L0SVPi08aV>@2;I3T0RF8i08QQ>028HCX0Qf8e0080R6<f00<0RF@g08YU>02;IST00P2<
IcX208]W=`0408]V>@2;ISX0RfHl08]U?P80RfE00`2>J44[ooooo`00:_ooool00`25GSL0Q5df08=L
=@02085J<`0308=L=@24GCH0QEhg0080R5`e0P29GCH0202:GSL0Relh08]O>02;GcP0PU/b08AM=026
GcH0R64h0P29HST208QQ>00308UM=P2:GSL0RUhg0080Relh0P2<H3T0102=HCX0S64f08]P=@2;H3D2
08YO=080REhc00L0R5db08MR=@28HSD0R68e08YQ=@2;H3D0S5le0080SUle00/0SV8k08eQ>P2<H3T0
Relh08aP>@2=HCX0Sf<l095U?P2BIC/0TF@j08mR>00308eP=P0308iQ=`2?HSP0SV8k00L0SV8k2P2?
I3T02@2@ICX0TVLl09=X?@2CJ3d0TVLl091U>P2?I3T0Rf0e08aQ=P0208eR=`0408iS>02?I3T0T6Dj
095V>`<0T6Dj0P2AIS/3099W?080UFHj00<0TfLj099W>P2AJ3X00P2?JCX00`2>JSX0TfLj09=W>P0>
09=W>P03095V>`2BIc`0U6Tn0080UFXo00<0U6Tn099W?02AIS/00P2EJC`309IZ?@D0Uf/n0P2HK3l2
09U]@080VVi1202EJcT809AX>`0609=W>P2DJ3/0UFTl09IZ?@2GJch0V6`o0P2IKD0909U]?080VVhm
0P2KKch209a`?`0409ea@02KLCl0VW0n09Y`?P80VFlm0P2HKS`00`2GKC/0VVhm09Y^?@0709Y^?@07
09U]?02HK3/0V6`k09Q/>`2JKSd0W70o09ea@00209U^>`<0VVll0`2KL3d909ic@080WG8m00<0WG8o
09ea@02MLD800P2MLD@00`2ML4H0W79009]a?`0309Y`?P0309ab@02NM480WgE300/0WgA100<0X7E2
0:5f@`2QMT<00P2RMd@40:Ad@`@0YGE400T0WgA10:1e@P2RMd@0XgQ50:AiAP2SN4D0XGI30:1e@P2S
N4D00`2RMd@0102SN4D0YGY70:MlB@2YOT/20:IkA0040:IkAP2UNTL0YGY70:AhA`80Y7Q90P2TNDH3
0:EjA`<0YW]800<0[Ge=0:]kB`2XN4P00P2WMdL00`2ZNTX0[Ge=0:moC`080:UnB`040:AiA02UNTD0
Yga70:QmB080ZGi900<0Z7e80:MlA`2XODX01`2XODX80:UnB`P0Z7i>202YOTL80:^2CPD0[H5@0`2/
P4l40:b1C0D0Zh1;202YP4`20:^1C`030:^2CP2[PT`0Zh9:0080Zh=800<0Zh=60:Z1B`2ZPD/00P2Z
PD/40:^2C080[HA>0`2/Pdd30:^2C0@0[85<102[P4/;0:b1CP<0[H9?0P2^Pe080:YoC080Zh1=0`2Z
Od`30:UnB`P0ZGi90`2YOT/20:QmBP<0Yga900<0ZWm<0:UnB`2XODX00P2WO4T02`2YOT/0Zh1=0:b1
CP2XOT80ZX160:^1A`2/PDX0[85<0:^0C@2ZOTd0Z7a;0080Z7m90`2YP4X30:Z1B`030:V0C02ZPDd0
[8=?0080[8=?00<0Zh9>0:V0C02WOTX00P2ZOTd00`2ZOd`0ZGi90:UnA`020:QnA0030:Qn@P2YP4`0
ZH1<0080ZX5=302[PTh90:YoC100ZGi900<0[85>0:^0C@2ZOd`00P2XODX00`2ZOd`0Zh1=0:b1CP08
0:^2C0080:n4C`2]PTd0Zh1;0:YoBP2YOTT0ZWm:0:^0B`2/PD`80:^2CP<0ZWm:0P2[P4/30:b1C0P0
Zh1;00H0[H=70:f3B@2]PdT0[H9;0:f2C@2]PTl20:f1D0P0[85<0P2[PdP20:b4B@80[HE:0P2^QT/3
0:j5C`80[HA>102/Pdd01`2]Q4h0[hI@0;27D@2`Qe40[hI@0:f4CP2/Pdd0202_QTh80:j5D@80[HA>
0`2^QDl30:n6D0P0[HA@0P2`Qe<20:n6DP040:j5D@2]Q500[HA@0:f4D0P0[XAB0P2[QU802P2^RED0
/HaH0;2;E`2/Qe<0ZhIB0:f8E02`ReL0/HQD0;27D`2_QU820:j5D@030:n6DP2aR5@0/XUE00P0[XUE
0P2^QE420:n6DP80/8MC0P2aR5@01P2_QdX0/8Q=0;28C@2aR500/XUC0;>:EP80]8YH00<0/XUE0;68
E02`Qe<00P2_QU800`2`Qe<0/HQD0;:9E@080:n:E@<0/8]G00<0[hYF0:j9E@2^RED00P2]R5@00`2`
QU@0/HME0;67E@050;67E@80/XUE0`2aR5@30;27D`030;2;E`2^RED0[HQD0080[8MC00<0[HQD0:j9
E@2`ReL0202cRUH20;:9D@040;:9D`2aR5@0/HQD0;26E080/8IF2P2dReL60;>:EP80/HQB00@0/XUC
0;>:E02cRU@0]8]E0P2eS5H80;B;E`<0/hYF0P2bRED30;68E0030;F<EP2dReD0]8]E0080/hYD0P2b
RE<01P2aR580[HA@0:n6DP2_QU80/HQD0;>:EP<0]8]G00<0/hYF0;:9D`2bRE<00`2aR5840;27D@0:
0;68DP2cRU@0]8]E0;B;E@2cRU@0/HQB0;27D@2bRE<0/HQB0:n6D080[XE?00<0[hI@0;68DP2bRE<0
202^RE@30;2;E0030:n:D`2^RE80[XUB0080[HQA00P0/XUE0;>:EP2cRUH0/hYF0;:9E@2`Qe<0[HA@
0:b3C`<0[X9A00<0[h=B0;24D`2`Q5<00P2aQE@20:f8D`80[8MB00@0ZhIA0:Z5D02ZQE00ZXE@0`2^
QDl20:f4CP<0[8==202]Q5080:j5D@030;27D`2_QU80[hIB0080[XEA0P2]Q5000`2/Pdl0ZXI<0:Z6
C0060:Z6C0<0[XAD0P2]Pe<30:b2DP030:j3CP2]PTd0Zh1;00<0ZWm:00<0Zh1;0:b1C02]Q5001`2]
Q5020:n6DP<0[XEA0`2]Q5030:j5D@80[HA@0`2/Pdl20:Z2A`<0Zh=800@0[8A90:f5BP2^QT/0[XI;
202]Pe400`2[PTh0[HA@0:j5D@020:n6DP030:j5D@2]Q500Zh9>00<0[HA>00<0[8==0:^2C02[PT`0
0P2ZPD/20:^1D@040:^1C`2[PTh0Zh9>0:^2C080Zh9:0P2ZPDd20:^2CP050:b3C`2]Q500[HA@0:f4
D02_Qd`00P2^QT/0202]QDX0Zh=80:Z2A`2ZPTL0ZH560:f4CP2/Pdd0Zh9<0P2ZPD/01P2[PT`0[8==
0:f4CP2[PTh0[8=?0:j5D@80[hIB00/0[XEA0:b3C`2[PTh0/HIC0:j3D02[P4d0[85>0:n4D@2`QE80
[H9?0:YoC0080:^0B`80Z7m;00@0ZH1<0:Z1C@2[PTh0[8=?0P2]Q5080:b3C`80[H9=0P2/PD`20:^0
B`80ZWm:202YP4`20:f3D`80[89B0P2[PE420:Z0D0P0[85>00@0Ygi80:QoB@2[PT`0[HA>0P2^QDl2
0:f4CPP0ZH1:00<0Ygi:0:QoB`2ZPDd00`2[PTh01P2ZPDd0Z7m;0:MnBP2]Q4`0[8=;0:^2C080ZX5=
00H0Zh5?0:b2DP2]Pe<0[hIB0:j5D@2/Pdl30:Z1C@030:^2CP2/Pdl0ZX5=00<0ZX5=102[PTh00`2/
PDh0Zh1=0:YoC0020:QmBP030:YoC02[P4d0[85>00P0[8=?202]PTd00`2ZPDd0ZH1<0:QoB`030:Qo
B`080:V0C02ZPDd0[85G0:b1E`2/PEH0Zh5A0:Z0CP2ZPD/20:V0B0080:j5C`2/Pdd0ZX5=0:QnC02W
ODd0Yga?0:QmD02YOU<20:UoC`040:UoC@2XOd/0Z7m;0:MnB080Ygi600<0Z7m90:MnB02VODL00P2U
O4H00`2WOTP0ZH1:0:Z1B`080:QoB`<0ZX5=0`2YP4`20:QoB`80Zh9>0P2ZPDd0102YP4`0Z7m;0:Qo
B`2XOd/80:YoC0050:^1D@2ZP500ZX1@0:Z0D02YOdl00`2XOTh80:]oD0P0Yge;102UO4P50:ImB@80
Y7U60`2UNTL30:IkB080YG];00@0YG]90:ElB02UO4P0YGa60P2UO4@00`2SN4D0Y7U60:AiAP020:Ej
A`80YW]800<0Yga90:EkB`2UNd/01P2UNd/00`2UO4P0Y7]70:AkA`020:=jAP80XWU500@0XGQ409id
@P2OMD<0XGM50P2RN4H02`2QMdD0WgE309id@P2NM480XGM50:AjB02RN4H0WgE309ec@@2PMT@0XgU7
0080X7U>00@0X7Y=0:1jB@2PNdL0X7]40P2PO4800`2VMd<0YGI20:Ae@@020:=d@0050:Ae@@2UMT80
YWM30:9hB02QMdL00`2PMTH00`2RN4P0Y7Y:0:EkB`020:1g@@060:5h@P2RND<0XgY40:AkA@2UO4H0
YWe70P2PMT@01`2QMdD0XWQ60:=iA`2TNTP0YG]90:IlBP2QMdD00`2PMT@0102OMD<0WWA209id@P2N
M48209ab@00309ec@@2NM480WgE30080X7I400@0XGM50:1fA02QMdD0XWQ60P2SNDL01P2RN4H0XGM5
0:1fA02PMT@0WgE309id@P80WG=100L0WgE30:5gA@2RN4H0Ug8n09Qc?`2JMD40VgI20080W7M300l0
VgI209Ye@@2QMT/0XGI90:1eB02OMDD0WWA209ed@02LLcd0Vg8l0:9gA02QMT<0X7E209md@@2MLSl0
0P2LLCh0102KL3d0VVll09id@P2NM48209me@`<0X7I400<0XGM50:1g@`2PMd<01P2PMd<309icAP80
WG950`2LLD@409ab@0@0Vg4o202IKcd809Y_@P0309Mb?P2HLcl0VGA00080VGA000@0Ug8n09E`?02D
Kc/0VW0n0P2IKcd209Q^?080Ufdk0140UV`j09E/>02EJcT0UV`j09M]?@2HKD00VFi309Y_A@2KL4H0
UFm009I`@@2GLD80V79309Ma@P2FL440U6ho09=]?P0409I/>P@0UF/i00@0VF/j09QZ>@2HJST0V6Xi
0P2GJCP209IX=`0309AY?02EJSd0Uf`o0080V6e000<0Uf`o09EZ?@2DJC`0202EJSd409A_>`@0UG0l
0P2HKD0209M/?`0409I[?P2EJSd0UFXm09EZ?@P0TVLm0P2DJC`409=X>`80TVLj00H0SfDc091V=02B
J3H0TfTg09AZ>02CJCL2099X=P05095W=@2@JS/0SfTj08aV=`2:I3D00P29Hc@01@2:I3D0RfDf08iX
>@2=IcP0RfDf0080RV@e00<0RfDf08eW>02>J3T00P2<IST308]U>0<0RV@g00<0R68e08US=P2;ICP0
0P2<IST01P2;ICP0RF<f08QR=@2<IST0RfDh08YT=`80RF<f00/0RfDh08eW>P2>J3/0SVPi08mY>P2@
JS/0TF/l091Z>`2?JCX0SFLh08aV=`02091Z>@0608mY>P2=IcX0S6Dj08]T>`2:HcX0RF8k0P28HcH2
08UT=`0408YU>02;IST0S6Lj08aW>P80RfLg00@0RfHi08]V>P2;IS`0S6Ho0P2<IT4308iX@B_ooooo
000Zooooo`0308EN=`24GCH0Pe`e0080PEXc00@0Pe`e08AM=P25GSL0R5`e0`29GCH308YN=`0508]O
>023G3<0Q5dd08IO=P27H3L00`28HCP00`27H3L0RUhg08YN=`0208YN=`80Relh0P2<H3T308]P=@80
RUld0`29GS<01P27HSD0R68e08QR=@2:HCD0Rf0e08aO=@80SUle00/0SV8k08eQ>P2<H3T0Relh08aP
>@2=HCX0Sf<l091T?@2BIC/0TF@j08mR>00308eP=P0308iQ=`2?HSP0SV8k00L0SV8k0P2=HSL01@2>
HcP0Sf@i08mT>@2?I3T0T6Dj0080TFHk0P2@ICX0102AIS/0TVLl099W?02AIS/2091U>PX0SV<h0P2?
I3T2091U>P80TFHk0P2EISX00`2CIcX0TVLj095X>P0208mY>P0308iZ>P2CIcX0TfLj00h0TfLj00<0
TVLl09=X?@2DJCh00P2EJSl00`2DJCh0TfPm099W?00209EY?0<0UVXm1@2GJch309Q/?`<0VFe0202E
JcT:09AX>`0309EY?02FJSd0Uf/n0080V6`o00<0VFe009U]?02IKC`01P2IKC`409Y^?@80Vfln0P2L
L3l309Y`?P80VFlm0`2HKS`809Y^?@80V6`k00L0Uf/j09Q/>`2IKC`0Vfln09ib@@2OLd80VFhk00<0
VVll0P2KL3d209aa?PT0WW=00P2MLSd00`2MLSl0WG5009ea@P0209eaA00309e`AP2LLT00W79000<0
Vg4o00<0W79009id@P2OMD<02P2OM4430:1e@P<0XGI300D0XW910:=c@P2SLd80Y7A30:EeA0020:If
A@050:MgAP2OM440X7E20:5f@`2RMd@00P2SN4D20:9gA080XgQ50P2RMd@0102SN4D0YGY70:MlB@2X
ODX20:IkA0060:EjA@2UNTL0Y7U60:AhA`2TN4T0XgM80P2TNDH30:EjA`<0YW]800<0[Wi>0:alC02Y
NDT00P2WMdL00`2XN4P0Zg];0:alC0080:QmBP080:IkAP2WO4L0ZGi90:YoBP2[P4/0ZWm:0:UnB@2X
ODP@0:QmBPP0Z7i<202ZOdX80:^2CP040:n3DP2^PU40[X9A0:f1D080[81?0P2[Odh01@2^Pdh0[H9=
0:f2C@2/PD`0Zh1;00<0ZWm:00<0ZGi90:V0C02YP4`01P2YP4`20:^1C`030:^2CP2[PT`0Zh9:0080
Zh=800H0Zh=60:QoB@2YP4X0ZH1:0:Z1B`2[PT`20:b3C@<0[HA>0`2/Pdd30:^2C0@0Zh1;102/PD`4
0:j3D0@0[H9?0`2/PDh30:f2C`80[X=@202ZOd`30:UnB`<0Z7e:0P2WO4T80:UnB@040:YoC02YOT/0
ZGi;0:UnB`80Z7e:0P2WO4T01P2YOT/0Z7e:0:QmBP2WO4T0Z7e:0:UnB`80Zh1=00P0Z7i20:Z0AP2[
PDL0[85:0:b1C02[P4d0ZWi=0:QlB`80Z7m90`2YP4X30:Z1B`030:QoB`2YP4`0ZX5=00<0Zh9>0P2Z
PDd20:YnC@030:YoC02YOTT0ZGi70080Z7i400@0Z7i20:V0C02YP4`0ZH1<0P2ZPDd;0:^2CPT0ZWm<
402YOTT00`2/PDh0Zh1=0:YoC0020:QmBP030:YoC02[P4d0[85>00P0Zh9<00<0[X=>0:f2C@2/PD`0
0`2ZOdX00`2[P4/0[85<0:^2CP070:^2CP80Z7e80P2YOTT20:YoBPX0Zh1;00H0[8960:b2B02/PTP0
[85:0:b1C02/PDh20:b0C`P0[85<0`2ZPTL20:^3B0<0[8A90`2^QDl20:f4CP@0[8==00L0[HA>0:j5
C`2_QU00[hI@0:j5C`2]Q4h0[8==00P0[hI@202^QE420:f4CP<0[XE?0`2_QU080:f4D0<0[hIB0`2^
QE420:f4D0P0[XAB0P2[QU802P2^RED0/HaH0;2;E`2/Qe<0ZhIB0:f8E02`ReL0/HQD0;27D`2_QU82
0:j5D@030:n6DP2`Qe<0/HQD00P0[hYF0P2^QE420:n6DP80/8MC0P2aR5@01P2aRD`0/HU>0;69CP2a
R500/HQB0;:9E@80/XQF0P2aR5@0102`Qe<0[hIB0:n6DP2`Qe<20;68E0P0[XUD00@0/8]G0:n:EP2_
RUH0[hYF0`2^RED00`2]R5@0[hEC0:n5D`020;26E0040;67E@2bR5H0/hUG0;>9E`80/XUE0`2aR5@3
0;27D`030;2;E`2^RED0[HQD0080[8MC00<0[HQD0:j9E@2`ReL0202cRUH01P2cRU80/XUA0;:9D`2b
RED0/HQD0;67E@80/8IF1`2cRUH00`2dReL0/hYF0;>:EP060;>:EP80/XUC1P2cRU@80;B;E`<0/hYF
0P2bRED30;68E080]8]E0P2cRU@40;:9D`050:j5D@2_QU80[hIB0;68E02cRUH00P2dReL20;>:EP80
/XUC0`2aR5840;27D@070;68DP2cRU@0]8]E0;B;E@2cRU@0/HQB0;27D@020;68E0040;27D`2_QU80
[hIB0;27D`80/HQD202]R5<0102`Re@0[hYC0:n:D`2_RU<30:j9DP040:f8D@2bRED0/XUE0;>:EP80
/XUE00<0/8MC0:j5D@2]Q5000P2^Pe030:n4D@<0/8EB0`2/Qe830:^6D@80ZXE@0`2/Pdd20:f4CP<0
[XE?402^QE420:n6DP80[XEA102]Q5080:Z5CP<0[XAB0P2]Pe430:b2D0030:b1C02[P4/0ZWm:0080
ZWm:00<0Zh1;0:f2C@2^Pdh02`2]Q5030:b3C`80Zh9>0`2^QE420:f4D0<0[8=?00<0Zh=80:b4B@2/
Q4T01P2/Q4T80:f3D@030:f4D02^QE40[hIB0080/8MC00<0[hIB0:j5D@2]Q5000P2]Q4h30:b3C@<0
Zh9<0P2[PE40102[PDl0Zh9>0:^2CP2[PT`20:^2BP<0Zh9>0`2/Pdl20:f4D0060:n7C02^QT/0[XI;
0:f5BP2/Q4T0Zh=80P2ZPTL00`2]Q4h0[8==0:Z1B`020:V0BP030:Z1B`2/Pdd0[HA>0080[8=?102^
QE420:b3C`040;25DP2/PDh0ZWm<0:YoC080[X=@00<0[85>0:QmBP2ZOdX01`2ZOdX40:Z1C@@0Zh9>
202/Pdl20:f2C@80[85<0P2[P4/20:YoBPP0ZX5=0`2/PU030:^1C`80ZX1>202/PDh00`2WOTP0Z7m9
0:^2C0030:f4CP80[8==202ZPD/00`2XOd/0ZH1<0:Z1C@030:^2CP060:Z1C@2YP4`0Z7m;0:f4C02/
Pd/0ZX5;0P2YP4`0202ZP4h0[89B0:f3D`2^QE40[HA@0:b3C`2[PTh0ZX5=0P2[PTh00`2/Pdl0Zh9>
0:^2CP020:^2CP@0ZX5=00<0[85>0:^0C@2ZOd`00P2XODX00`2ZOd`0Zh1=0:b1CP080:b3C`P0[H9=
0P2WOTX0102XOd/0ZH1<0:V0C02XOd/20:MnBP80[85F00@0[85D0:^1D@2[PDl0ZX5=0P2ZPD/01@2^
QDl0[8==0:^2CP2YOdd0Z7i>0080Z7e@00@0ZGiC0:UoC`2YOdl0ZGm=0P2XOd/02`2WOTP0Ygi60:Mn
AP2XOdT0Ygi80:ImA`2UO4H0YWe70:MnB02YP4X0ZX5;00P0ZH1<0`2ZPDd30:V0C080Z7m;0`2ZPDd3
0:V0C080Z7m;202[P4d01P2]Pe40[89@0:^1C`2ZP4h0ZGm=0:MmB`80YWa:202ZOTd80:MnBP@0YWe9
1@2UO4P20:AiAP<0YGY70`2VNdP20:EkB`040:EkB@2UO4P0YGa80:ElAP80YGa4102TNDH20:EjA`80
YW]8202TNTP30:AkA`80XgY60`2RNDD00`2PMT@0XGM50:=iA`020:AjB00;0:=iA`2QMdD0X7I409id
@P2QMdD0Y7Y80:9hAP2OMD<0WG=10:1fA02SNDL00P2OND`0102ONDX0WgU809mjAP2ONTD209mj@`03
0:IfA@2UMD@0Y7A30080Xg=200D0Y7A30:EeA02VMTD0XWQ60:5gA@030:1fA0030:9hAP2TNTP0YG]9
0080X7M100<0XGQ20:9i@`2SNT@00P2TNdD01P2UO4H0X7I40:1fA02QMdD0XWQ60:=iA`80Y7Y800L0
YG]90:=iA`2RN4H0XGM50:1fA02OMD<0WG=100<0W7900P2MLd400`2NM480WgE30:1fA0020:5gA@03
09me@`2PMT@0XWQ60080XgU700D0XWQ60:1fA02OMD<0WgE309id@P0309ec@@0609me@`2PMT@0XWQ6
09Mb?P2IM400VWE10`2LMd<209Ye@@090:5fB`2QMTT0X7E809meA@2NM480WGA009ed?P2LLcd0X7E2
00<0WgA10`2NLd0209eb?`<0WgE30P2PMT@30:5gA@@0WgI2102NMD40102OM4L0WW=609icAP2NLdH2
09ebA@80W75400D0WWA209ec@@2MLd40W79009]a?`0209Y`?PT0VFlm202JKd800`2GLSh0V7<o09Ud
@00209Ud@00309Mb?P2EL3`0U6lk00@0VFlm0P2HKS`209M]>`0609E/>02FK3X0UV`j09M]?@2HKD00
VFi30P2JKdD00`2EKd00UW1109Ma@P0209Ma@P0309E_@02DKSl0TV`m00P0UV`j0`2GJcX209IZ>@<0
UFTh00<0UV/n09M/?`2HKD000P2IKT400`2HKD00Uf`o09I[?P0809EZ?@P0U6lk0`2GK3l209I[?P<0
UFXm202BIc`0102EJSd0U6Tl09AY?02DJC`209=X>`80TVLj00<0SfDc091V=02BJ3H00P2DJSP02P2C
JCL0TVPf099X=P2AIcD0TF/l091Z>`2>J3T0SFLh08aV=`2;ICH208aV=`04091Z>`2?JCX0S6Hg08]U
=P80RV@e00@0RfDf08aV=`2<IST0S6Hi0`2;ICP308YT=`0308US=P2:I3L0RfDh00<0RfDh00d0RV@g
08US=P2>J3/0SFLj08]U>02:I3L0RF<f08YT=`2;ICP0S6Hi08aV=`2=IcP0SVPi00<0T6Xk00X0SfTj
08iX>@2BK3/0TV`k095[?02?JC`0SVLl08aU?02;I3/0Rf@m0P28HcH00`29I3L0RVDh08]V>@0208aW
>P0908eX>`2:ISH0RVHf08YU>02;ISX0S6Lm08eW@02=Id80SVQ300<0SVQ1:oooool002[ooooo00<0
QEhg08AM=P23G3D00P21FS<00`23G3D0Q5df08EN=`0808UM=P80Q5dd00<0QEhe08IO=P27H3L00`27
H3L608YN=`80Relh202:Gc@01P27HSD0R68e08QR=@2:HCD0Rf0e08aO=@80SUle00<0SF4j08aP>@2;
GcP00P2;GcP01P2=HCX0Sf<l091T?@2BIC/0TF@j08mR>0<0SF0f00<0SV4g08mR>02>HS/01`2>HS/2
08aQ=P0508eR=`2>HcP0T6Dj091U>P2AIS/00P2BIc`2091U>P@0TFHk0P2@ICX0102AIS/0T6Dj091U
>P2?I3T208iS>0@0SF8g0P2>HcP308mT>@06091U>P2EISX0UFHj09=W>P2BIcX0TFPj0P2?JCX00`2>
JSX0TfLj09=W>P0609=W>PP0U6Pk00<0TVLl09=X?@2DJCh00P2FJd000`2DJCh0TfPm099W?00209EY
?0<0UVXm1@2GJch609Q/?`P0UF/i2`2EJC`00`2FJSd0Uf/n09M[?P0209Q/?`P0VFdl1P2JKSd209]_
?PP0VFlm202JKSd409M[>P0409U]?02LL3l0Wg=20:1d@`<0VVll0P2KL3d309aa?PT0WgA10P2MLSd0
0`2MLSl0WG5009ea@P0209eaA00309e`AP2LLT00W79000<0W79000<0WG=109id@P2NM480202OM446
0:1e@P80XGI30P2RLT40102SLd80Y7A30:EeA02VMTD20:MgAP0309md@@2PMD80XGI30080XWM40`2S
N4D0202TNDH0XgQ50:9gA02RMd@0XgQ50:AiAP2VNdP0Yga90P2UNT<0102UNTD0Y7U60:AiAP2TN4L2
0:=gB080Y7U60`2UNTL30:IkB0080:inCP2]ODd0ZWY:0:QhB02WMdL0Z7Q80:UiB@2ZNTX80:QmBP03
0:MlA`2XODP0ZWm:0080Zh1;00<0ZWm:0:UnB@2XODP0402XODX80:QoB`P0ZWm<202[PTh20:n3DP03
0:j2D@2]PE00[81?0080Zgm>00L0ZWi=0:n4C`2^Pdh0[H9=0:b1C02[P4/0ZWm:0080ZGi900<0Z7e8
0:V0C02YP4`01P2YP4`20:b2D0030:b3C`2/Pdd0[8=;0080[8A900T0[8A70:MnB02XOdT0ZH1:0:Z1
B`2[PT`0[8==0:f4CP2^QDl00P2]Q4h30:b3C@<0Zh9<00D0ZGi90:YoBP2ZOdX0Zh1;0:b1C0020:f2
C@030:j3CP2_Q540[hAA0080[hAA102^Pe030:b1CP<0[H9?0P2^Pe080:YoC0<0Z7e:0`2WO4T20:Ik
B0P0ZGi90P2ZOd`30:UnB`L0Z7e:00`0ZGi;0:YoC02ZOd`0Zh1=0:Qn@P2ZP4H0Zh570:b1BP2/PD`0
Zh1=0:YnC@2XO4/20:QoB@<0ZH1:0`2ZPD/20:MnBP030:QoB`2ZPDd0ZX5=00<0Zh9>0P2ZOTd00`2Z
Od`0ZGi90:UnA`020:QnA0030:Qn@P2XOd/0Z7m;0080ZH1<0P2ZPDd:0:^2CPT0ZWm<402YOTT00`2/
PDh0Zh1=0:YoC0020:QmBP030:YoC02[P4d0[85>00P0Zh9<0P2]PTd00`2/PD`0Zh1;0:^0B`030:^0
B`P0Zh9>0P2WO4L20:QmB0<0ZGi900<0ZWm:0:^0B`2[P4/01P2[P4/01P2/PTH0[8980:b2B02/PDX0
[85<0:b1CP80[81?202/PD`30:V1AP80ZX970`2[PdP30:j5C`80[HA>0`2/Pdd30:f4CP80[XE?0`2]
Q4h80:n6DPP0[XEA0P2]Q4h30:j5C`<0[hI@202]Q5020:n6DPH0[XEA202^Q5820:^6DP0:0:j9E@2a
S5P0/8]G0:b7D`2[QU80[HQD0;2;E`2bRED0/HQD0:n6DP<0[XEA0P2`Qe<80;2;E`80[XEA0P2_QU82
0;27D`80/HQD00H0/h]>0;>;D02bRTl0/HQ@0;68DP2`Qe<20:n5D`<0/8MC0P2_QU830;27D`P0[XUD
202^RED01P2]Pe40[XAB0:n5D`2`QU@0/HME0;>9E`80]8YH0P2bRED30;68E0<0/8MC00<0/8]G0:j9
E@2]R5@00P2/Qe<00`2]R5@0[XUE0;2;E`080;:9E@80/hYB00@0/XUC0;:9E@2bRED0/HME0P2aQeL4
0;:9E@@0/hYF00<0/XUE0;>:EP2cRUH00P2cRUH30;B;E`<0/hYD0`2bRE<20;68DPP0]8]G0`2cRUH2
0;:9E@<0/HQD0P2cRU@60;:9D`050:n6DP2`Qe<0/8MC0;:9E@2cRUH00P2dReL0102cRUH0/XUE0;:9
D`2bRE<30;68DP@0/8MA00L0/HQB0;>:E02dReD0]8]E0;>:E02aR580/8MA0080/HME102`QU@20;67
E@P0[HQC202^RE850;68E0<0/8MC1P2_Q4l20;25D080[8MB1P2[QU420:^2C0040:b3C@2]Q4h0[HA>
0:j5C`80[hI@4P2^QE460:f4D0P0ZXE@0`2^QE420:f4D0<0[8=?00P0Zh1;0:YoBP2YOTT0ZGi90:Yo
BP2/PD`0[X=>0;25D0P0[HA@0`2/Pdl30:^2CP80ZX5=0`2^QE420:f4D0<0[8=?0P2]Q4`40:b3B`<0
Zh9:202]Pe400`2]Q500[XEA0;27D`020;68E0030;27D`2^QE40[HA@00H0[8==0P2[PT`20:b2DP04
0:b2D02/Pdl0[8=?0:b3C@80[8=;0P2[PTh60:b3C`<0[XE=00<0[HA<0:b3B`2/Pd/00P2[PTX00`2]
Q4h0Zh9<0:Z1B`020:V0BP030:Z1B`2[PT`0[HA>00P0[HA@00P0[hAA0:^0C@2YOT/0ZGi;0:b1CP2]
PTl0Zh1=0:MlB@P0ZGi90`2/Pdl00`2[PTh0ZX5=0:V0C0020:V0C0P0[8=?0P2]PTd20:b1C080Zh1;
0P2ZOdX>0:^2CP80ZX5=202/PDh01P2WOTP0ZH1:0:^2C02/Pdd0[HA>0:b3C@80Zh9<202ZPD/30:V0
C0<0ZX5=0`2YP4`00`2]Q4`0Zh9:0:Z1B`020:V0C0040:Z0CP2[PE40[H=C0:f4D080[8=?0`2[PTh2
0:b3C`050:f4D02/Pdl0[8=?0:^2CP2ZPDd00P2YP4`0102XOd/0[85>0:^0C@2ZOd`20:QmBP030:Yo
C02[P4d0[85>00P0[8=?202]PTd00`2TNdL0YWe90:QoB`020:Z1C@030:QoB`2VODT0Y7]700@0[89B
0`2[PDl02@2[PTh0[HA>0:b3C@2[PTh0ZX1>0:UoC`2YOU40Z7e@0:QmDP020:UoC`040:UoC@2XOd/0
Z7m;0:MnB080Ygi600<0Z7m90:MnB02VODL00P2VODL00`2XOdT0ZX5;0:^2C0080:V0C0<0ZX5=0`2Y
P4`20:QoB`80ZX5=1P2YP4`80:b1CP060:j5D@2]Q500[8=?0:Z1C@2XOd/0Ygi:0P2UO4P80:UnB`P0
Z7m9102VODT50:ElB080Y7U60`2UNTL30:IkB080YG];00@0YG]90:ElB02UO4P0YGa60P2UO4@60:Ai
AP80YGY7402SNTH00`2RN4H0XgU70:AjB0020:EkB@0;0:AjB02SNDL0XWQ609id@P2QMdD0Y7Y80:9h
AP2OMD<0WG=10:1fA02SNDL0102ONDP309mjAP0409mjA@2UMdH0Y7I50:=eA080XWA300D0XgE40:Af
A@2UMdH0XWU50:5hA0030:1g@`040:9iA@2TNdL0YGa80:1g@@80XGQ20P2RND<20:=jA0040:AkA@2P
MT@0XGM50:5gA@80XWQ60P2SNDL20:AjB0050:=iA`2RN4H0X7I409id@P2MLd400P2KLCl209ec@@04
09id@P2OMD<0WgE30:1fA080XGM500<0WgE30:1fA02QMdD00P2SNDL0502QMdD0X7I409me@`2OMD<0
WWA209ec@@2LLT00WG=109id@P2PMT@0XGM509Ud@02JMD40VgI209ag@`2MN4@0W7M309Ye@@2IM400
XGI;0P2PMDP01@2OMDD0WgE309ie@@2NMCl0WG@n00<0WW=01P2OM44209me@`<0X7I40`2QMdD409ie
@@@0WGA00P2OMDD309idA0<0WG=300P0WgE309id@P2MLd40W79009]a?`2JL3h0VFlm09Q^?0P0VFlm
202IKT400`2GLSh0V7<o09Ud@00209Ud@00309Mb?P2EL3`0U6lk00H0VFlm0P2HKS`01P2FKCT0UV`j
09M]>`2GKCd0V6e009U^@`80VFi400<0U6ho09E_@02FL4400P2GLD80102EKd00Tfdn099/?@2EJcT4
09I/>PH0Ufdk0P2FK3X309E[>@<0V6e00P2IKT4309Q]@0P0UFXm00<0UG0l09A_>`2DKc/00P2DKc/3
09=^>P@0UV/n102EJSd809=X>`0409I[?P2EJSd0UFXm09AY?080TfPk0P2BIcX01P2?IC<0TFLe09=Y
=`2DJSP0UF/i09AZ>080TfTg00D0TVPf095[?02@JS/0T6Xk08mY>P0408iX>@06095[?02@JS/0SFLh
08]U=P2:I3D0RF<d0P2:I3D208aV>@<0RfDh1@2:I3L408]U>080RV@g00<0T6Xm08iX>`2<IST00`2:
I3L208]U>080S6Hg00<0SFLh08mY>P2?JCX00`2@JS/02@2DKSd0Tfdl099/?@2AJch0SfPm08iW?P2=
ISd0S6Dn08QS=P0208UT=`0308YU>02;IST0S6Lj0080SFPk00P0RFDe08YV=P2;IST0RfHj08eX?P2=
Id00SVQ308mYA0<0SVQ1:oooool002[ooooo00<0QEhg08AM=P23G3D00P21FS<00`23G3D0Q5df08EN
=`0408UM=P@0R5`e1@25GSD208IO=P0308MP=`2:GSL0RUhg00@0RUhg0P29GCH808YO=00608MR=@28
HSD0R68e08YQ=@2;H3D0S5le0P2>GcD02`2=HCX0S60i08]O>02:GSL0Relh08aP>@2>HS/0Sf<l099U
>`2AI3X0Sf8h00<0SF0f00<0SV4g08mR>02>HS/01`2>HS/208aQ=P0508eR=`2>HcP0T6Dj091U>P2A
IS/00P2BIc`8091U>P06099W?02AIS/0TFHk091U>P2?I3T0SV<h102=HSL208iS>0<0Sf@i00H0T6Dj
09EV>P2EISX0TfLj099W>P2AJ3X208mY>P0308iZ>P2CIcX0TfLj00H0TfLj202DJ3/00`2BIc`0U6Tn
09EZ?`0209I[@00309EZ?`2DJCh0TVLl0080UFTl0`2FJSd309M[?P80V6`o1P2GJch809E[>@T0UFTl
102FJSd309M[?PP0VFdl1P2JKSd209U]?0P0VFlm202JKSd409M[>P0409U]?02LL3l0Wg=20:1d@`80
VVll0P2KL3d209aa?P80WG8o2@2OM44209eb?@0309eb?`2MLD00WG520080WG5400D0WG1609]a?`2L
LT00W79009ec@@0409id@PP0WgA10P2QMT<60:1e@P<0Xg=200<0Y7A30:EeA02VMTD00P2VMTD209md
@@80X7E200<0XWM40:=hA@2TNDH00P2UNTL01`2TNDH0XgQ50:9gA02RMd@0Y7U60:EjA`2WO4T00P2U
NT<0102TND@0Y7U60:AiAP2SMdH20:=gB080Y7U60`2UNTL30:IkB0040:emC@2/O4`0ZWY:0:QhB080
YgM70P2XN4P80:QmBP030:QmB02YOTT0ZWm:0080Zh1;00<0ZWm:0:QmB02WO4L0402XODX80:QoB`P0
Zh1=202[PTh0102_Pe80[X9A0:j2D@2]PE020:b0C`80Zgm>00H0[hA?0:j3CP2]PTd0[85<0:^0B`2Z
OdX20:UnB@030:QmB02YP4`0ZH1<00H0ZH1<0P2/PU000`2/Pdl0[8==0:b3B`020:b4B@090:b4A`2W
OTP0Z7m90:V0BP2ZPD/0Zh9<0:b3C@2]Q4h0[XE?0080[HA>0`2/Pdd30:^2C0050:UnB@2ZOdX0ZWm:
0:^0B`2/PD`00P2]PTd00`2^Pdh0/8EB0;25DP020:n4D@80[X=@0P2]PTl30:b1CP<0[H9?0P2^Pe08
0:YoC0<0Z7e:0`2WO4T20:IkB0P0ZGi90`2ZOd`30:UnB`80Z7e:00@0Yga90:QmBP2XODX0ZGi;102Z
Od`0202XOT80ZX160:^1A`2/PDX0[85<0:^0C@2ZOTd0Z7a;0P2XOdT30:V0BP<0ZX5;0P2WOTX20:Qo
B`040:V0C02ZPDd0Zh9>0:b3C`80ZWi=00<0ZWm<0:UnB@2YOTL00P2XOT@0102XOT80Z7m;0:QoB`2X
Od/20:V0C0<0ZX5=202[PTh90:YoC100ZGi900<0[85>0:^0C@2ZOd`00P2XODX00`2ZOd`0Zh1=0:b1
CP080:^2C0D0[85<00<0Zh1;0:YoBP2ZOdX0202[PTh20:MlA`80Z7e80`2YOTT90:YoBP060:^1A@2[
PDL0Zh570:^0B@2[P4/0Zh1=0P2[Odh80:b1C0<0ZH560P2ZPTL30:^3B0<0[XE?0P2]Q4h30:b3C@<0
[HA>0P2/Pdd30:f4CQ00[XEA0P2]Q4h30:j5C`<0[hI@202]Q5060:j5D@80[hIB202^Q5820:^6DP0?
0:j9E@2aS5P0/8]G0:b7D`2[QU80[HQD0;2;E`2cRUH0/XUE0;27D`2^QE40[HA@0:j5D@2_QU80/8MC
00P0[hYF0P2^QE420:n6DP80/8MC0P2aR5@01P2cRdh0/h]@0;::C`2aR500/8MA0:n6DP80[XAB0`2_
QU820;27D`<0[hIB202^RE@40:f8E0@0[XUE00H0[H=A0:j4DP2_QE<0/8ID0;67E@2cREL20;B:F080
/XUE0`2aR5@30;27D`030;2;E`2^RED0[HQD0080[8MC00<0[HQD0:j9E@2`ReL0202bRED20;>:DP04
0;>:E02bRED0/XUE0;:8EP80/HMG0P2`Qe<20;68E080/XUE0P2cRUH30;:9E@030;>:EP2dReL0]8]G
0080]HaH0P2cRU@30;:9D`<0/HQB2`2cRUH20;:9E@<0/HQD0P2aR5860;:9D`040:n6DP2aR5@0/HQD
0;:9E@80]8]G00<0/hYF0;:9E@2aR5@00P2bRE<30;68DP@0/8MA00L0/HQB0;>:E02dReD0]8]E0;>:
E02aR580/8MA00P0/HMG202/Qe840:f8D@@0[XUB1@2`Qe<00`2aR5@0/XUE0;:9E@020;25CPH0[hA=
1P2[QU420:b7DP80Zh9<00@0[8==0:f4CP2]Q4h0[XE?0P2_QU080:n6DPP0[XEA0P2/Pdl60:f4D0P0
ZXE@0`2^QE420:f4D0<0[8=?00P0Zh1;0:YoBP2YOTT0ZGi90:YoBP2/PD`0[X=>0;25D0P0[HA@0`2/
Pdl30:^2CP80ZX5=0`2^QE420:f4D0<0[8=?0P2]Q4h40:b3C@<0Zh9<202]Pe400`2]Q500[XEA0:n6
DP020;27D`030:n6DP2^QE40[HA@0080Zh9<1P2/Pdd20:b2DP040:b2D02/Pdl0[8=?0:b3C@80[8=;
1P2/Pdl20:^2CP<0[XE?102]Q4h20:b3C@070:^2C02ZPD/0Z7m90:QoB@2ZPD/0Zh9<0:b3C@080:f4
D0080:n4D@2[P4d0ZGi;0:UnB`2/PDh0[H9?0:^0C@2WO4T80:YoBP80[HA@00@0[8=?0:^2CP2ZPDd0
ZH1<0P2XOd/80:b3C`80[H9=0P2/PD`20:^0B`80ZWm:202[PTh60:Z1C@80Zh9>202/PDh00`2XOdT0
ZH1:0:^2C0020:b3C@030:^2C02ZPD/0ZH1:00P0Zh9<00<0ZX5=0:V0C02YP4`01@2YP4`0102ZPDd0
[8=;0:^2BP2ZPD/20:QoB`030:Z0CP2[PE40[89B0080Zh9>1P2/Pdl01@2]Q500[8=?0:b3C`2[PTh0
ZX5=0080ZH1<00@0Z7m;0:b1CP2[P4d0ZWm<0P2XODX00`2ZOd`0Zh1=0:b1CP080:b3C`P0[H9=00<0
YGa80:ImB@2YP4`00P2[PTh0102YP4`0YWe90:ElB02/Pdl30:b2D0@0[89B0P2]Q4h01P2/Pdl0[89@
0:^1D@2ZOe80ZGiA0:QmDP80ZGm?00@0ZGm=0:QoB`2XOd/0Ygi80P2WOTH0202YP4X0Z7m90:MnB02V
ODL0Ygi80:QoB@2ZPD/0Zh9<2`2ZPDd30:V0C080Z7m;1P2YP4`20:Z1C@P0[85>00H0[XEA0:f4D02/
Pdl0ZX5=0:QoB`2WOTX20:ElB0P0ZGi;202XOdL20:MnBP80YWe90`2UO4P20:AkA`80Y7U60`2UNTL3
0:IkB080Y7Y:00@0Y7Y80:AkA`2TNdL0Y7]50P2TNd<60:AiAP80XgQ5402SNTH00`2RN4H0XgU70:Ek
B@020:IlBP0<0:EkB@2SNDL0XWQ609id@P2QMdD0Y7Y80:9hAP2OMD<0WG=10:1fA02SNDL0WgY50`2O
NTH409miB0030:=gB02RMTL0XGE60080X7A500D0XGE60:9fA`2SMdP0XWU50:5hA0030:1g@`030:9i
A@2TNdL0YGa800@0XGQ2102RND<40:5gA@@0XWQ600H0Y7Y80:=iA`2RN4H0X7I409id@P2MLd4209]a
?`80WG=100@0WWA209me@`2PMT@0XGM50P2RN4H00`2NM480X7I40:5gA@020:9hAP050:5gA@2PMT@0
WWA209id@P2MLd400`2LLT001P2NM480X7I40:5gA@2JMD40VgI209ag@`80WGQ400@0W7M309Ye@@2I
M400X7E:0P2PMDP00`2PMTH0WgE309mf@P0209mf@0<0WW=000<0WgA10:1e@P2PMD800P2PMD80102Q
MT<0X7I40:1fA02PMT@30:5gA@80XWQ60P2OMT8209ie@@80WGA00P2LLcl309me@`<0WWA20P2MLd40
202OMD<0WWA209ec@@2LLT00Vg4o09Y`?P2IKcd0V6hl202IKcd809U^@@0309Mb?P2HLcl0VGA00080
VGA000<0Ug8n09E`?02DKc/01P2IKcd209Y`?P0@09M^>P2GKC/0Ufdk09Q^?P2HKD00V6e209Q]@`2I
KT@0U6ho09E_@02FL440Ug5209I`@@2EKd00Tfdn095[?080UF/i0P2FK3X0102GKC/0V6hl09Q^?02H
KS`309M_?080UVhk0`2EKCX00`2IKT40V6e009Q]@00409Q]@00309U^@@2EJSd0UFXm00H0UFXm0P2E
L3`209A_>`0409=^>P2BKCT0TVdi099]>@P0UFXm202CJCT209M/?`0909I[?P2EJSd0U6Tl09=X>`2B
IcX0TFHi091V=02AIcD0TfTg0080UF/i00@0U6Xh09=Y=`2CJCL0TVPf1@2@JS/02@2?JCX0SVPi08iX
>@2AJc`0T6Xk08eW>02;ICH0RV@e08US=00208YT=@80S6Hi0`2;ICP308YT=`P0RfDh00@0T6Xm08mY
?02=IcX0RfDh0P2:I3L00`2;ICP0S6Hi08eW>00208eW>080SVPi00<0T6Xk095[?02AJc`00P2DKSd0
1P2CKCh0TF/n091Y?P2>Ich0SFHm08eV?`80RF@g00<0RVDh08]V>@2<IcX00P2=J3/01`2>JC`0RfLg
08]W=`2;IST0S6Lk08eX?P2>J4400P2>J4<308iX@B_ooooo000Zooooo`0308EN=`24GCH0Pe`e0080
PEXc00<0Pe`e08AM=P25GSL00`29GCH208QL=@<0Qe/d00<0QUlf08EN=@24GC@00P24GC@00`25GSD0
QUlf08IO=P0408YN=`80REdf0P28G3D308UN<`80RUld0`2;H3D01P27HSD0R68e08QR=@2:HCD0Rf0e
08aO=@80SUle0P2<H3T308YN=`0608aP>@2>HS/0Sf<l099U>`2AI3X0Sf8h0`2=H3H00`2>HCL0Sf8h
08iR>`0708iR>`80SF8g00D0SV<h08mT>@2?I3T0Sf@i091U>P03095V>`08091U>P2?I3T0SV<h08iS
>02?I3T0T6Dj095V>`2BIc`2095V>`03091U>P2?I3T0Sf@i00@0SV<h0P2?I3T2091U>P80TFHk0P2E
ISX00`2CIcX0TVLj095X>P0208mY>P0308iZ>P2CIcX0TfLj00H0TfLj202DJ3/00`2CJ3d0U6Tn09EZ
?`0209I[@00309EZ?`2DJCh0TfPm0080UFTl0`2FJSd309M[?P80V6`o0`2GJch309IZ?@P0UF/i402F
JSd809U]?0@0VVhm0P2IKC`209Q/>`<0V6hl0P2IKcd309Y`?PP0VVhm0P2HK3/01P2GJcX0V6`k09U]
?02KKch0WW9109mc@P<0Vg0m0P2LLCh309eb?`T0X7E20P2MLSd00`2MLSl0WG5009ea@P0209eaA005
09e`AP2KLCl0W79009ec@@2NM4800P2OMD<00`2NM480WG=109md@@0709md@@<0XGI30`2PMD8209md
@@@0YGE4102TM4<309md@@040:1e@P2QMT<0XgQ50:EjA`80YW]800d0YGY70:=hA@2RMd@0XWM40:=h
A@2UNTL0YW]80:Ej@`2TND80Y7U40:AiAP2SN4D0XgM60080XWI70P2TNDH30:EjA`<0YW]80P2ZNTX0
0`2YNDT0Z7Q80:QhB0030:QhB0P0Yga900P0Z7e80:UnB@2ZOdX0Zh1;0:YoBP2YOTT0Yga70:IkAPP0
Z7e:202WO4T80:QoB@P0Zgm>202[PTh80:f1D0050:j3CP2]PTd0[H9=0:b1C02[P4/00`2ZOdX00`2Y
OTT0ZH1<0:V0C0060:V0C080[89@00<0[8=?0:b3C@2/Pd/00P2/Q4T01P2/Q4L0Z7m90:V0BP2YP4X0
ZX5;0:^2C080[8==0`2]Q4h30:b3C@<0Zh9<102[P4/40:b1C0050;25DP2_Q540[hAA0:j3D02]PTl0
0P2/PDh0102[P4d0[85>0:b1CP2/PDh30:f2C`80[X=@202ZOd`30:UnB`<0Z7e:0P2WO4T80:UnB@80
Zh1=0P2ZOd`30:UnB`060:QmBP2WO4T0Yga90:UnB`2ZOd`0Zh1=0P2ZOd`02@2YOT/0Z7i20:Z0AP2[
PDL0[85:0:b1C02[P4d0ZWi=0:QlB`020:QoB@<0ZH1:0`2ZPD/00`2YP4`0Z7m;0:MnBP020:MnBP03
0:V0C02ZPDd0Zh9>0080ZWi=00<0ZWm<0:UnB@2YOTL00P2XOT@00`2XOT80Ygi:0:QoB`020:QoB`80
ZH1<0P2ZPDd80:^2CPT0ZWm<402YOTT00`2/PDh0Zh1=0:YoC0020:QmBP030:YoC02[P4d0[85>00P0
Zh9<00<0Zh1;0:b1C02]PTd00P2]PTd00`2[P4/0ZWm:0:UnB@080:^2CP80Z7e80P2YOTT20:YoBP80
Zh1;202ZOdX01P2[PDD0Zh570:^1A`2[P4T0Zh1;0:^0C@80Zgm>202/PD`30:Z2A`80Zh=80`2/Q4T3
0:j5C`80[HA>0`2/Pdd00`2^QDl0[HA>0:b3C@020:^2C0030:b3C@2]Q4h0[XE?00P0[XAB202^QE42
0:f4CP<0[XE?0`2_QU0:0:f4D0<0[XEA0`2_QU880:j4DP80ZhIB00/0[XUE0;6<F02`ReL0[8MC0:^6
DP2]R5@0/8]G0;B;E`2bRED0/8MC0:j5D@020:f4D0030:j5D@2_QU80[XUE00L0[XUE0P2^QE420:n6
DP80/8MC0P2aR5@01P2bRTd0/XY?0;69CP2`Qdl0/8MA0:n6DP80[XAB0P2^QE40102_QU80/8MC0;27
D`2_QU820:j5D@P0[HQC0`2/Qe<20:f8E0<0[XUE0P2_QE<20;26E0040;67E@2bR5H0/hUG0;>9E`80
/XUE0`2aR5@30;27D`030;2;E`2^RED0[HQD0080[8MC00<0[HQD0:j9E@2`ReL0202aR5@20;B;D`07
0;>:E02cRUH0/XUE0;:8EP2bR5P0/HMG0:j5D@020:n6DP030;27D`2aR5@0/XUE0080/hYF0P2aR5@0
0`2bRED0/hYF0;B;E`020;F<F0030;J=F@2aR580/HQB00@0/HQB0P2bRE<;0;>:EP80/XUE0`2aR5@2
0;27D@80/HQB102bRE<0102`Qe<0/HQD0;68E02cRUH20;B;E`030;>:EP2aR5@0/8MC0080/XUC0`2a
R5840;27D@0:0;68DP2cRU@0]8]E0;B;E@2cRU@0/HQB0;27D@2`QEP0/HII0;:7FP80/hQK00<0/XMJ
0;66F@2`QEP0202/Qe830:b7D080[HQA0`2^RE80202`Qe<0[hIB0:n6DP2_QU80/8MC0;68E02cRUH0
]8]G0`2`QT`30:n5B`80[XA:0P2ZQE030:^6D@<0[8MB0`2/Pdd20:f4CP<0[XE?202_QU880:j5D@80
Zh9>0P2/Pdl40:f4D0P0ZXEA0`2^QDl20:f4CP<0[8==00<0[85<0:^0B`2ZOdX00P2ZOdX00`2[P4/0
[H9=0:j3CP0;0:f4D0<0[8=?0P2[PTh30:j5D@80[HA@0`2/Pdl00`2[PTh0[8=?0:b3C`060:b3C`P0
[H=A00<0Zh9>0:b3C`2^QE400P2_QU800`2^QE40[8=?0:^2CP030:^2C0<0[8==0P2]Q4h20:b2DP04
0:b2D02/Pdl0[8=?0:b3C@80[8=;0P2]Q5030:b3C`<0Zh9>202^QE400`2/Pdd0Zh9<0:V0BP020:Qo
B@030:V0BP2[PT`0[8==0080[XEA102/Pdl20:j5D@040;25DP2/PDh0ZWm<0:YoC080[X=@00<0[85>
0:QmBP2[P4/01`2[P4/01@2]Q500[8=?0:b3C`2[PTh0ZX5=0080ZH1<00<0Z7m;0:b3C`2/Pdl01P2/
Pdl20:f2C@80[85<0P2[P4/20:YoBPP0ZX5=0`2YP4X30:Z1B`80Zh9<202/PDh00`2XOdT0ZH1:0:Z1
B`020:b3C@030:^2C02YP4X0Z7m900P0Zh9<00<0Zh9>0:Z1C@2YP4`00`2XOd/01P2YP4`0ZX5=0:^2
CP2/Pd/0Zh9:0:V0BP80Z7m;00H0ZGm=0:^1D@2/PU80ZH1<0:Z1C@2/Pdl30:f4D080[8=?102[PTh4
0:Z1C@030:b1CP2[P4d0ZWm<0080Z7e:00<0ZWm<0:^0C@2/PDh0202/Pdl80:f2C@030:QoB`2YP4`0
ZX5=00<0ZX5=0180ZH1<0:QoB`2[PT`0[8==0:b3C`2/PU00[H=C0:f2E@2]PUL0[X=H0:b3C@2]Q4h0
[HA@0:f3D@2/PU80ZWmB0:UnD@2WO5420:UoC`040:UoC@2XOd/0Z7m;0:MnB080Ygi600<0ZH1:0:Qo
B@2WOTP00P2WOTP00`2YP4X0ZX5;0:b3C@0;0:Z1C@<0ZH1<102XOd/30:V0C0<0ZX5=202[P4d01P2]
Q4h0[8==0:^2C02ZPD/0ZH1:0:MnB080YWe7202XODP80:V1AP040:QoB`2WOTX0Ygi:0:ImB@80YGa8
0P2TNdL00`2SNTH0Y7U60:AiAP030:EjA`<0YW]80P2TNTX0102TNTP0Y7]70:AkA`2TNdD20:Ak@`@0
Y7U60P2SN4D20:9gA0P0XWU30`2RNDD20:=jAP<0Y7]700<0XGM50:9hAP2TNTP00P2UNdT02`2TNTP0
XWQ60:5gA@2NM480XGM50:AjB02RN4H0WgE309ec@@2PMT@0XgU70080WWU200@0WWU409iiA@2NN4L0
WWQ90P2NN4/00`2RMdX0XGI90:1eB00209mdA`050:1eB02QMTT0XWM:0:9i@`2QN4800`2PMd400`2R
ND<0Y7]50:ElAP080:5h@PP0XGM500H0XgU70:9hAP2QMdD0X7I409me@`2MLd4209ab@080WWA20P2O
MD<01`2PMT@0XGM50:9hAP2RN4H0WWA209me@`2QMdD00P2RN4H0502QMdD0WgE309id@P2NM480WG=1
09ab@02KLCl0W79009ec@@2OMD<0X7I409]f@P2LMd<0WGQ409iiA@2MN4@0W7M309Ye@@2IM400X7E:
0P2PMDP00`2PMTH0X7I40:1g@`020:1g@@<0WgA11@2PMD80102QMT<0X7I40:1fA02PMT@20:5gA@<0
XWQ600D0XGQ40:1g@`2PMd<0WgI209ie@@0209ed@00309ac?`2PMd<0X7M30080WgI20`2NMD401P2M
M400WWA209ec@@2MLd40W79009]a?`80VW0n2@2IKcd809Q]@00309Mb?P2HLcl0VGA00080VGA000<0
Ug8n09E`?02DKc/0102IKcd209Y`?P80Vg4o00H0V6lk09Q^?02HKS`0V6hn09Q]@02HKD8209Q]@`03
09=]?P2DKSl0UFm00080UW1100<0U6ho099/?@2AJc`00P2EJcT0102FK3X0Ufdk09Q^?02HKS`209U_
?@<0UW4m0P2EL3`309A_>`0309U^@@2HKD00Uf`o0080UV/n00<0Uf`o09Q]@02IKT40202EJSd209E`
?00409A_>`2CKSX0TVdi099]>@80TF`h00@0TfPk09AY?02DJC`0U6Tl0`2EJSd00`2FJch0TfTg09=Y
=`0609=Y=`80V6e000T0Uf`o09EZ?@2DJC`0TfPk099W>P2AIST0T6Hd099X=P2CJCL00`2EJcT209AZ
>00409=Y=`2>J3T0SVPi08mY>P80T6Xk00L0SfTj08iX>@2=IcP0T6Xk08mY>P2<ISL0RfDf0080RV@e
00@0RfDf08aV=`2<IST0S6Hi0`2;ICP308YT=`0308eW>P2<IST0RfDh0080RV@g00H0RfDh08aV>@2=
IcX0SfTl08iX>`2<IST308]U>00408eW>P2>J3/0SfTj08iX>@<0SFLh00`0SfTj091Z>`2AJc`0U6hm
09=]?02BK3d0TF/n08mX?@2>Ich0SFHm08aU?P29I3L208YU>00308]V>@2<IcX0SFPk0080SVTl0P2=
JCT0102=J3/0SFPl08eX?P2=Id0208eW@P<0SVQ1:oooool002[ooooo00<0QEhg08AM=P23G3D00P21
FS<00`23G3D0Q5df08EN=`0308UM=P0308QL=@27Fc@0Qe/d0080QUXc00<0Qf0g08IO=P24GC@00P23
G3<01024GC@0QEhe08IO=P2;GcP208YN=`80REdf0P28G3D01027Fc@0R5db08UN<`29GS<208YO=080
Rf0e00L0S64f08MR=@28HSD0R68e08YQ=@2;H3D0S5le0080SUle00/0S60i08]O>02:GSL0REdf08YN
=`2;GcP0SF4j08iR>`2BIC/0TF@j08mR>00308eP=P0308iQ=`2?HSP0SV8k00L0SV8k2@2?I3T00`2A
IS/0T6Dj08iS>00208eR=`0308iS>02@ICX0TFHk0080TFHk102@ICX208mT>@<0T6Dj0P2AIS/3099W
?080UFHj00<0TfLj099W>P2AJ3X00P2?JCX00`2>JSX0TfLj09=W>P0609=W>PP0UFTl00<0TfPm09AY
?P2FJd000P2GK4400`2FJd00U6Tn09=X?@0209EY?0<0UVXm0`2GJch209Q/?`80Uf/n0P2FJSd209EY
?0P0UF/i202FJSd209M[?PH0UVXm202IKC`00`2KKch0VVhm09Y^?@0209U]?080V6`k00@0Uf/j09M]
>`2HKS`0V6hl0P2IKcd209Y`?P0309]a?`2JKSd0VVhm00L0VVhm00L0VFdl09Q/>`2HK3/0V6`k09Y^
?@2LL3l0WG500080Vg0m0P2LLCh409eb?`T0X7E20P2MLSd00`2MLSl0WG5009ea@P0209eaA00909e`
AP2KLCl0W79009id@P2OMD<0X7I409me@`2NM480WG=100P0WgA10P2RMd@20:5f@`040:1e@P2OM440
WgA109md@@80YgM600@0YWI50:EeA02TM4<0Xg=20P2RLT4209md@@0909ic@02OM440X7E20:=hA@2V
NdP0Yga90:IkB02UNTL0Y7U60080XWM400<0XgQ50:AiAP2UNTL00P2TND80102TND@0XgQ50:=hA@2R
MTD20:9fA`80Y7U60`2UNTL30:IkB0040:MgA`2XN4P0Z7Q80:QhB0@0ZGU9202WO4T0202WO4L0Z7e8
0:UnB@2YOTT0Z7e80:MlA`2UNTD0Y7U4202XODX80:MlB@P0Z7m7202[Oe080:^2CP060:YnC@2[Odh0
Zgm>0:b0C`2]PE00[X9A0P2_Pe840:b1C0D0Zh1;202YP4`20:f3D@030:f4D02]Q4h0[HA<0080[HE:
00<0[HE80:Z1B`2ZPD/00P2ZPD/40:^2C080[HA>0`2/Pdd30:^2C0@0[85<102[P4/01@2_Q540[X=@
0:j3D02]PTl0Zh1=0080ZWm<00@0ZGi;0:b1CP2/PDh0[85>0`2]PTl20:j3D0P0ZWm<0P2[P4d30:Yo
C0<0ZGi;202YOTT30:^0C@80ZWm<0`2YOT/00`2VNdP0Yga90:UnB`020:^0C@0;0:YoC02YOT/0Z7e:
0:Qn@P2ZP4H0Zh570:b1BP2/PD`0Zh1=0:YnC@2XO4/00P2XOdT30:V0BP<0ZX5;00<0Zh9>0:Z1C@2X
Od/00P2VODT00`2WOTX0Z7m;0:V0C0020:YnC@030:YoC02YOTT0ZGi70080Z7i400<0Z7i20:MnBP2W
OTX00`2XOd/30:V0C0P0Zh9>2@2ZOd`@0:UnB@030:b1CP2[P4d0ZWm<0080Z7e:00<0ZWm<0:^0C@2/
PDh0202[PT`0202[P4/0[85<0:f2C@2^Pdh0[H9=0:b1C02ZOdX0Z7e8202[PTh30:YoBP80Zh1;0`2/
PD`80:UnB@060:Z0A02ZP4H0ZX160:YoB02ZOdX0ZWm<0P2ZOTd80:b1C080Zh=80P2/Q4T20:f5BP80
[XI;0`2^QDl20:f4CP<0[8==00<0[XE?0:f4CP2[PT`00P2ZPD/00`2[PT`0[HA>0:j5C`080:f3D`P0
[XEA0P2]Q4h30:j5C`<0[hI@2`2]Q5000`2^QE40[hIB0:n6DP020;27D`P0[XAB0P2[QU802`2^RED0
/HaH0;2;E`2/Qe<0ZhIB0:f8E02`ReL0]8]G0;>:EP2`Qe<0[XEA0080[HA@0P2^QE480:b7D`80[XEA
0P2_QU820;27D`80/HQD00H0/8Q;0;28C@2`R4d0/8M?0;27D@2_QU820:n5D`030:f4D02^QE40[hIB
0080/8MC00<0[hIB0:j5D@2]Q500202]R5<20:^6DP80[8MC00D0[HQD0:j9E@2^RED0[XUE0;26E007
0;67E@80/XUE0`2aR5@30;27D`030;2;E`2^RED0[HQD0080[8MC00<0[HQD0:j9E@2`ReL0202aR5@2
0;B;D`040;B;E@2cRUH0/hYF0;:8EP80/XQH00D0[HA@0:j5D@2^QE40[hIB0;68E0020;:9E@070;>:
EP2`Qe<0/HQD0;:9E@2cRUH0]8]G0;F<F0020;J=F@80[hI@00@0/8MA0;68DP2aR580/XUC0P2cRU@8
0;:9E@<0/hYF0P2bRED30;68E0030:n6D02`Qe40/8MA0080/HQB0P2bRE<01@2cRU@0/HQD0;:9E@2b
RED0/hYF0080]8]G00<0/XUE0;68E02`Qe<00P2bRE<30;68DP@0/8MA00X0/HQB0;>:E02dReD0]8]E
0;>:E02aR580/8MA0;25F02aQUT0/hQK0P2dRE`00`2cR5/0/HII0;25F0080:^6D@80ZhI?0P2/Qe00
102]R540[XUB0:j9DP2^RE820:n6DP80[XEA00@0[hIB0;:9E@2dReL0]XeI0P2aQdd20;26C0040:n5
B`2^Q4X0[XA:0:j4BP<0ZXE@00<0ZhIA0:b7DP2/Qe800P2]R5<30:j5C`80[HA>0`2/Pdd80:n6DPP0
[XEA00<0ZX5=0:^2CP2[PTh00P2/Pdl20:f4D0030:j5D@2ZQ5<0ZXAC00H0ZXAC0`2^QDd20:f4C0<0
[8=;00<0[X=>0:f2C@2[P4/00`2ZOdX00`2[P4/0[85<0:f4D0070:f4D080[hIB0`2^QE430:f4D0<0
[XEA0P2]Q5030:b3C`80ZX1>0`2[PDl0102/PU00[H=A0:j4DP2^Q5880:f3D@030:V0C02ZPDd0[8=?
0080[HA@00<0[8=?0:Z1C@2YP4`00P2ZPD/20:^2C0040:b3C@2]Q4h0[HA>0:f4CP80[H=C00@0[H=A
0:f4D02]Q500[HA>0P2]Q4`30:f4D0030:b3C`2[PTh0Zh9>0080ZX5=202^Q5800`2[PT`0ZX5;0:V0
BP020:QoB@060:V0BP2ZPD/0Zh9<0:n6DP2^QE40[8=?0P2[PTh02`2/Pdl0[XEA0:n6DP2aQU<0[X=@
0:^0C@2/PDh0[hAA0;25DP2]PTl0ZWm<00P0[H9=102[PTh40:Z1C@P0[8=?0P2]PTd20:b1C080Zh1;
0P2ZOdX80:V0C080Z7m70P2YP4P20:Z1B@80Zh9:202/PDh00`2XOdT0ZH1:0:Z1B`020:^2C0030:Z1
B`2XOdT0Ygi800P0[8==00<0Zh9>0:Z1C@2XOd/00`2WOTX01P2XOd/0ZX5=0:^2CP2[PTX0ZX590:V0
BP80Z7m;00/0ZGm=0:Z0D02[PE40Z7m;0:Z1C@2/Pdl0[HA@0:j5D@2]Q500[8=?0:^2CP040:Z1C@@0
Zh9>00<0[85>0:^0C@2ZOd`00P2XODX00`2ZOd`0Zh1=0:b1CP080:b3C`P0[H9=0P2/Pdl0102[PTh0
ZX5=0:Z1C@2[PTh20:b3C`80Zh9:00@0[8==0:b2D02]Pe<0[X=H0P2^PeT0202/Pdd0[HA>0:j5D@2^
Q580[H=C0:^0D`2YOU40YgaA0P2YOdl0102YOdd0Z7m;0:QoB`2WOTP20:MnAP030:Z1B`2YP4X0Z7m9
0080Ygi800<0ZH1:0:^2C02/Pdd02`2ZPDd30:V0C0D0Z7m;00<0ZH1<0:Z1C@2ZPDd00P2[PTh80:Yo
C0050:^2BP2ZPDT0ZX590:Z1B@2YP4P00`2XOdL80:MlA@P0ZH560P2XOd/01@2WOTX0YWe90:ElB02U
O4P0Y7]70080XgY60P2TNDH30:EjA`<0YW]80P2SNDT0102SNDL0XgY60:=jAP2SNT@20:=j@P030:Ej
A`2TNDH0Y7U60080XgQ50P2RMd@00`2QMT<0XGQ00:5h@0060:5h@0030:5hA02RNDD0XWU50080XgY6
0P2TNdL0102UO4P0X7I40:5gA@2SNDL20:AjB00;0:=iA`2QMdD0X7I409id@P2QMdD0Y7Y80:9hAP2O
MD<0WG=10:1fA02SNDL00P2NNT00102NND80WWU509ihA`2NN4/209igC0030:5hBP2PMdT0WgI80080
WWE700D0WgI80:1gB@2QN4X0XWU10:5h@0030:1g?`030:9i@@2TNd<0YGa400D0XGQ20`2PMd450:5g
A@<0X7I400D0XGM50:1fA02PMT@0X7I409me@`0509id@P0309me@`2PMT@0XGM50080XWQ600@0XgU7
09id@P2OMD<0X7I40P2QMdD01P2PMT@0WgE309id@P2NM480WG=109ab@080Vg4o00D0WG=109me@`2P
MT@0W7M309ehA00309iiA@0409ag@`2JMD40VGA00:1eBP80X7E800<0X7I60:1fA02QN4@00P2QN480
0`2QMT<0X7E20:1e@P060:1e@P040:1fA02QMdD0XGM50:5gA@80XWQ60P2SNDL01@2SNTH0XWU50:9i
A@2QN4@0WgI20080WWE100@0WGA00:1g@@2PMd40X7M10P2OMT0309ie?`@0W790102KLCl809U_?@P0
V6e000<0Ug8n09Qc?`2IM4000P2IM400102GLSh0UG0l09A_>`2HKS`209U_?@80VW0n0P2KLCl01`2L
LT00V6lk09Q^?02HKS`0V6hn09Q]@02HKD800P2GK480202CKCh0U6ho09E_@02FL440UFm009A^?`2B
K3d0TF/l0P2EJcT0102FK3X0Ufdk09Q^?02IKcd209Y`?P80Ug8n0P2FLCd309E`?00409A_>`2HKD00
Uf`o09EZ?@80U6Tl00<0UFXm09M/?`2HKD00202EJSd209E`?00409A_>`2CKSX0TVdi095/>080T6/g
0`2CJ3/00`2DJC`0UFXm09EZ?@0209I[?PP0U6Xh00h0VFi109Q]@02GK3l0UV/n09AY?02CJ3/0TVLj
095V>@2AIcD0TVPf09AZ>02EJcT0UV`j09E[>@80U6Xh00`0TfTg08]U=P2<ISL0SVPi08mY>P2@JS/0
SfTj08eW>02<ISL0SVPi08eW>02;ICH208YT=@0308]U=P2=IcP0SVPi0080S6Hi0`2;ICP308YT=`03
08iX>`2=IcX0RfDh0080RV@g00H0RfDh08eW>P2>J3/0SVPk08eW>P2<IST208]U>00;08eW>P2?JC`0
T6Xm095[?02@JS/0SVPi08eW>02<ISL0SFLh08iX>@2?JCX00P2BK3/01P2AJc`0T6Xm08iW?02=ISd0
S6Dl08]T?@80RVDh00@0RfHi08aW>P2=J3/0SFPk0P2>JC`01P2@K3`0Sf/k08mZ?@2>JCd0SFPn08aV
?`80RfE00`2>J44[ooooo`00:_ooool00`25GSL0Q5df08=L=@02085J<`0308=L=@24GCH0QEhg00<0
REdf00<0R5`e08MK=026FS<00P26FS<00`27H3L0QUlf08AM=002089K<P0408=L<`25GSD0QUlf08]O
>080RUhg00<0REdf08QL=@28G3D00P27Fc@208QM<P0408UN<`2:Gc@0RUld08]P=@80S64f00H0Qf8e
08QR=@28HSD0RV4e08]P=@2<GcD208iO=@0;08aP>@2;GcP0RUhg08UM=P2:GSL0Relh08eQ>P2>HS/0
TVDk095T>P2?HSP00`2=H3H00`2>HCL0Sf8h08iR>`0708iR>`<0T6Dj0`2?I3T308iS>003095V>`2@
ICX0SV<h0080SF8g00<0SV<h091U>P2AIS/01P2@ICX5095V>`80TVLl0`2CJ3d209EV>P0309=W>P2B
IcX0TFPj0080SfTj00<0SVXj09=W>P2CIcX01P2CIcX809EY?00309=X?@2DJCh0UV]00080Ufa100<0
UV]009AY?P2CJ3d00P2EJC`309IZ?@<0Uf/n0P2HK3l209M[?P0409IZ?@2EJC`0UFTl09AX>`P0UF/i
202FJSd309M[?PD0UVXm202IKC`0102KKch0VVhm09Y^?@2IKC`209Q/>`80Uf/j0P2GKC/0102HKS`0
VFlm09U_?@2JL3h209]a?`P0VVhm00<0W70o09]_?P2IKC`00P2HK3/00`2IKC`0Vfln09a`?`0209]`
?@80W74n0`2MLSl00`2NLd00X7E20:1e@P070:1e@P80WG8m00<0WG8o09ea@02MLD800P2MLD@0102M
L4H0Vg4o09ab@02NM4830:1fA00309id@P2MLd40WgA100L0WgA10P2RMd@20:5f@`0<0:1e@P2OM440
WgA109ic@02YNDP0Z7Q70:MgAP2UMD@0Y7A30:9b@@2QLD00X70o0P2OM44209ic@0070:1e@P2SN4D0
YW]80:QmBP2VNdP0YGY70:AiAP020:9gA0030:=hA@2TNDH0YGY70080Y7U200@0XgQ30:=hA@2SN4D0
XWI50P2RMTL20:AiAP<0YGY70`2VNdP20:IfAP030:MgA`2XN4P0ZGU900<0ZWY:202WO4T0202VNdH0
Yga70:QmB02XODP0Yga70:IkAP2TND@0XWM2202XODX80:MlB@P0Z7m7202[Oe080:^2CP80ZGe<00L0
ZWi=0:b0C`2^PU40[h=B0;24D`2aQE@0ZWm:00<0Zh1;102/PD`00`2]PTd0ZH1<0:V0C0060:V0C080
[H=A00<0[HA@0:f4CP2]Q4`00P2]QDX00`2]QDP0[8==0:^2C0020:^2C0<0ZX5;00<0ZH1:0:f4CP2]
Q4h00`2/Pdd30:^2C0050:j3CP2]PTd0[H9=0:b1C02[P4/00P2ZOdX01`2YOTT0[X=@0:j3D02]PTl0
[85>0:YoC02YOT/00P2XODX30:b1CP<0[H9?0P2^Pe080:YoC080[85>0`2[P4d30:YoC0P0ZGi90`2[
P4d30:YoC080ZGi;00<0YW]80:MlB@2YOT/00`2[P4d02P2YOT/0Z7e:0:Qn@P2ZP4H0Zh570:b1BP2/
PD`0Zh1=0:YnC@2XO4/20:QoB@<0ZH1:0`2ZPD/0202]Q500Zh9>0:QoB`2VODT0YGa80:ImB@2WOTX0
Z7m;0P2ZOTd00`2ZOd`0ZGi90:UnA`020:QnA0040:Qn@P2WOTX0Ygi:0:MnBP80Z7m;0`2YP4`80:^2
CPT0ZWm<402YOTT00`2/PDh0Zh1=0:YoC0020:QmBP030:YoC02[P4d0[85>00P0Zh9<00<0ZWm:0:b1
C02]PTd00P2^Pdh00`2/PD`0ZWm:0:QmB0080:^2CP<0Zh1;0P2/PD`30:f2C@P0ZGi900H0ZX140:Z0
AP2ZP4H0ZWm80:YoBP2ZOd`20:YnC@P0[85<00@0[8A90:f5BP2]QDX0[HE:0P2^QT/20:n7C0<0[XE?
0P2]Q4h30:b3C@030:j5C`2]Q4h0Zh9<0080ZX5;00<0Zh9<0:f4CP2^QDl0202]Pe<80:j5D@80[HA>
0`2^QDl30:n6D0P0[HA@00@0[8=?0:f4D02]Q500[XEA0P2_QU820;27D`P0[XAB0P2[QU802`2^RED0
/HaH0;2;E`2/Qe<0ZhIB0:f8E02`ReL0]8]G0;>:EP2aR5@0[XEA0080[HA@0P2^QE480:^6DP80[XEA
0P2_QU820;27D`80/HQD00H0[hM:0:n7C02_Qd`0[hI>0;27D@2`Qe<20;26E0030:b3C`2]Q500[hIB
0080/HQD00<0[hIB0:f4D02/Pdl0202]R5<30:^6DP030:b7D`2]R5@0[XUE0080[XUE0P2bR5H30;67
E@<0/8ID0P2bRED30;68E0<0/8MC00<0/8]G0:j9E@2]R5@00P2/Qe<00`2]R5@0[XUE0;2;E`080;68
E080]8]C00@0]8]E0;>:EP2cRUH0/hUG0P2bR5P02@2/Pdl0[HA@0:j5D@2_QU80/8MC0;68E02bRED0
/hYF0;27D`020;68E0030;>:EP2dReL0]HaH0080]XeI00H0[HA>0:j5C`2_QU00/8MA0;68DP2cRU@2
0;B;E@P0/XUE0`2cRUH20;:9E@<0/HQD0P2_QU020;27D@050;68DP2bRE<0/XUC0;>:E02aR5@00P2b
RED01P2cRUH0]8]G0;B;E`2bRED0/HQD0;27D`80/XUC0`2aR5840;27D@0:0;68DP2cRU@0]8]E0;B;
E@2cRU@0/HQB0;27D@2`QEX0/HIK0;>8G@80]8UN00<0/hQM0;66F`2`QEX0202[QU430:^6C`030:b7
D02]R540[XUB0080[XUB00P0[hIB0:j5D@2^QE40[XEA0:n6DP2bRED0]HaH0;N>FP80/HM;0P2`QTX0
1@2_QDT0[XA80:j4B02]PdL0ZHA?0080ZXE@00<0ZhIA0:b7DP2/Qe800P2]R5<20:n6D0040:j5C`2]
Q4h0[HA>0:b3C@80Zh9<202_QU880:j5D@80ZX5=0P2[PTh0102/Pdl0[HA@0:f4D02^QE480:Z4D`<0
[XE=0P2]Q4`30:b3B`040;25D02^Pdh0[85<0:YoBP80ZGi900<0ZWm:0:^0B`2]Q5001`2]Q5020;27
D`<0[hIB1P2^QE420:f4D0<0[8=?00L0Z7i<0:UoC@2ZP4h0ZX1>0:^1C`2/PU00[XAB0080[hEC202]
Pe400`2XOd/0ZH1<0:^2CP020:b3C`030:^2CP2YP4`0Z7m;0080ZX5;0P2[PT`0102/Pdd0[HA>0:f4
CP2^QDl20:f3D`040:f3D@2]Q500[HA@0:f4CP80[HA<00@0[XEA0:f4D02]Q500[8=?0P2[PTh20:Z1
C@D0[XAB0`2_QE<00`2[PT`0ZX5;0:V0BP020:MnB0060:V0BP2ZPD/0Zh9<0:n6DP2^QE40[8=?0P2[
PTh02`2/Pdl0[XEA0:n6DP2bQe@0[hAA0:b1CP2]PTl0/8EB0;66D`2^Pe00Zh1=00P0[hA?102ZPDd4
0:^2CPP0[8=?0P2]PTd20:b1C080Zh1;0P2ZOdX80:MnBP040:MnAP2XOdL0Z7m70:V0B080ZX590P2[
PTX80:b1CP030:QoB@2YP4X0ZX5;0080Zh9<00<0ZX5;0:QoB@2WOTP0202/Pdd00`2[PTh0ZX5=0:Qo
B`030:MnBP060:QoB`2ZPDd0Zh9>0:^2BP2ZPDT0ZH1:0P2WOTX01P2YOdd0ZX1@0:^1D@2XOd/0ZH1<
0:b3C`<0[XEA00<0[8=?0:^2CP2XOd/00P2YP4`0202ZPDd0Zh9>0:b3C`2/Pdl0[HA@0:b1CP2[P4d0
ZWm<0P2XODX00`2ZOd`0Zh1=0:b1CP080:b3C`P0[H9=00<0[hIB0:f4D02[PTh00P2YP4`04`2[PTh0
[HA@0:n6DP2[PdP0Zh9:0:b3C@2]Q500[H=C0:j3F02_Q5X0[h=L0:b3C@2]Q4h0[XEA0:j4DP2]Pe<0
Zh1C0:UnD@2WO5400P2YOdl0102YOdd0Z7m;0:QoB`2WOTP20:MnAP080:Z1B`2YP4X0Z7m90:MnB02X
OdT0ZH1:0:^2C02/Pdd;0:Z1C@<0ZH1<0P2XOd/0102WOTX0Z7m;0:QoB`2YP4`20:Z1C@80Zh9>202X
ODX80:V0B0P0Yga5202YPD@0102YP4`0Z7m;0:MnBP2VODT20:ElB0030:AkA`2SNTH0XWU50080Y7U6
0`2UNTL30:IkB080XgU900@0XgU70:=jAP2SNTH0XgY40P2SNT80102UNTL0Y7U60:AiAP2SN4D20:9g
A080XGI3202QN4020:5hA0040:9iA@2SNTH0XgY60:AkA`80YGa800<0WgE30:1fA02RN4H00P2SNDL0
5P2RN4H0X7I409me@`2NM480XGM50:AjB02RN4H0WgE309ec@@2PMT@0XgU709ij?P2NNT00WWU209ii
A02NN4L0WWQ;09igC02NMdh0XGQ<0:1gB`2OMTX209ieB@0509mfBP2PMd/0XGQ<0:9i@@2QN4000`2P
Mcl00`2RND40Y7]30:ElA0040:5h@P@0X7M1102QMdD40:1fA0P0WgE30P2NM480102OMD<0X7I40:5g
A@2RN4H20:=iA`0309ec@@2OMD<0X7I40080XGM500D0X7I409me@`2MLd40WG=109ab@00309]a?`05
09ec@@2OMD<0X7I409ag@`2MN4@00`2NNDD0102LMd<0VWE109Ud@02PMDX20:1eB0030:1fAP2QMdD0
XGQ40080XGQ20P2RMd@20:5f@`030:1e@P2OM440WgA10080WgA1102QMdD20:9hAP80XgU70P2TNdL0
102SNTH0XWU50:1g@`2OMT8209ie@@<0X7M10`2OMT0209ie?`0409Y`?P2KLCl0Vg4o09]a?`<0W790
00<0WG=109U_?@2IKcd01P2IKcd809Q]@00309Mb?P2HLcl0VGA00080VGA000@0Ug8n09E`?02DKc/0
V6hl0P2IKcd00`2JL3h0Vg4o09]a?`0209ab@00609Q_>`2HKS`0V6hl09Q^?P2HKD00Ufa10P2GK480
202CKCh0U6ho09E_@02FL440UFm009A^?`2BK3d0TF/l0P2EJcT01P2FK3X0Ufdk09Q^?02IKcd0VW0n
09]a?`<0UW8n0P2ELCd309A`?00309M/?`2FJch0U6Tl0080TVLj00<0U6Tl09I[?P2GK3l0202EJSd2
09E`?00609A_>`2CKSX0TVdi095/>02@JcL0SfXf0P2BIcX0102CJ3/0U6Tl09AY?02EJSd209I[?PP0
U6/g00/0VVm209U^@@2HKD00UV/n09AY?02CJ3/0TVLj095V>@2AIcD0TVPf09AZ>00209I/>P0709E[
>@2DJSP0U6Xh09=Y=`2:I3D0RfDf08eW>00208mY>P0608iX>@2<ISL0RfDf08eW>02<ISL0RfDf0P2:
I3D00`2<ISL0SVPi08mY>P0208aV>@<0RfDh0`2:I3L00`2>J3/0SFLj08]U>00208YT=`0508]U>02=
IcX0SVPk08eW>P2<IST00P2;ICP0202<IST0SVPk091Z?@2AJch0Tfdn095[?02?JCX0SFLh0P2<ISL2
08iX>@08099/>`2AJcX0T6Xk08mY?02=IS/0S6Dl08]T>`2:Hc`208YU>00308]V>@2<IcX0SFPk0080
SVTl00T0SfXm099^?P2AKCd0T6/n08iY?@2=J3h0RfDn08YT?`29Hch00`2>J44[ooooo`00:_ooool8
08YM=P80QUlf0P25GSD208AM=080Pe`c00P0PETe089J=P23FcL0Q5`h08EM>@26GSX0Qelk08QP?0P0
QUlf202:Gc@00`27Fc@0REdf08]O>00308eQ>P80S60i202;GcP00`2?I3T0SF8g08aQ=P0208YO=00=
08aQ=P2=HSL0Sf@i099W?02@ICX0SV<h08aQ=P2;H3D0S64f08eR=`2>HcP0RfDh08YT=`0408US=P0<
08]U>02=IcX0SVPk08aP>`2=HCX0Sf<l095V?02AIS/0TFHi08mU=@2>I3@0TfPm0P2BIc`00`2AIS/0
T6Dj08mT>@0208iS>00308iR=@2?HcH0TFDh00<0TfLj00D0TVHi095U>02FICX0UF@i09AS>002099Q
=P0309AS>02EI3T0UVDj00<0TFHk0P2BIc`309=X?@<0UFXo0P2DJCh309=X?@0809]^A02JKD<0VFa2
09Q[@@2GJT00UVTo09EX?P2DIcd309=X>`80U6Tl0`2EJSd00`2HK3l0Uf/n09IZ?@0209AX>`0>09IZ
?@2GJch0V6`o09Q]>02GK3L0UV/h09AX=`2DJ3T0UVXm09M[?P2HJd40Uf/n09EY?02BIST208mS=P03
099V>@2EJC`0Uf/n0080UFXm0P2FJch209M/?`80V6e000@0Vfln09Y^?@2JKSd0VFdl0P2HK3/209M[
>P80W74l00H0Vg0m09Y^?@2JKSl0VFe009Q/?`2HJd4809Y^?@0309I[?P2HKD00Vg130080WG9500/0
VVm209I[?P2DJC`0Vfi709Y]AP2HJd80UfY009M[?P2HK3d0VFdn09Y^?@0209Q]>P80VFhk0P2JKc`2
09]`?@T0WG9500<0WgA109ic@02LLCh00`2KL3d01P2MLSl0WW=009ab@02LLT00WG=109id@P@0WgE3
0`2NLT4209mc@P<0X7A3402PMD820:9gA0040:=hA@2TNDH0Y7U60:EjA`80YW]800H0ZgU80:UiB02Y
NDP0Z7Y80:IkB02UO4P20:AlB0P0XGI3202XNDD80:EjA@030:AiAP2VNdP0Yga90080ZGi;00<0Yga9
0:IkB02TNDH0202WO4L20:IkAP80Yga700L0Z7e80:UnB@2YOTT0ZWm:0:YoC02YOT/0Yga90080YW]8
00<0Yga90:UnB`2ZOd`0202YOT/0202[Oe00ZWi?0:UmCP2XO4d0ZGe>0:YnC`2/P540[H5B202/Pdl8
0:f2C`040:QoA`2YP4P0Zh9:0:f4C080[XE=0P2]Q4`00`2/Pd/0[H9=0:f2C@060:f2C@80ZX5=0P2[
PTh0102/Pdl0[HA@0:f4D02^QE420:b0C`030:b1CP2/PD`0[85:0080[89800<0[8960:YoBP2ZOdX0
0P2[P4/20:b1C080[H9=0`2YP4`20:Z1C@<0Zh9>00H0YhA<0:R3C02XPd`0ZX=<0:^2C02/PD`20:j0
C080ZWi?0P2[Oe020:b0D@80[H5B0P2WO4L0102XODP0ZGi90:UnB@2ZOdX30:^0B`070:b1C02^Pdh0
[hA?0:n4C`2]PTd0Zh1;0:YoBP020:moC`80[Wi>00P0[Ge=0:alC02/O4`0Zg];0:EjA@2VNdH0Z7e8
0:YoBP80Zh1;00<0ZWm:0:UnB@2XODP00P2XODP20:UnB@<0ZWm:00D0ZGi90:YoBP2ZOdX0Zh1;0:b1
C0020:f2C@050:j3CP2XODX0ZGi;0:UnB`2ZOd`00P2[P4d20:b1CP80Zh9:0P2ZPDT01`2YP4P0Z7m7
0:QoA`2WOTH0[85<0:^0B`2YOTT00P2XODP00`2YOTT0Zh1;0:b1C0080:Z1B@040:f2C@2/PD`0[85<
0:b1C080Zh1;0P2ZOdX90:V0C0080:UnB`2ZOd`0[85>0:f2C`2/PDh0Zh1=0:UnB`2WO4T80:YoC0P0
ZX5=202YP4`80:^0C@P0ZWi?0`2[P4/30:YoBP80ZGi90P2/PDh20:^0C@040:YoC02YOT/0ZGi;0:Qm
BP<0ZX5;0`2YP4X20:QoB@P0Z7m;0`2/Pdl20:f4D0<0[XEA00P0/HQD0;27D`2]Q500Zh9>0:Z1C@2[
PTh0[8=?0:f4D0<0[H9=0P2^Pdh30:n4C`<0[XEA0P2]Q5030:b3C`P0[X=@0P2^Q5@0102^Q580[HA@
0:f4D02/Pdd20:b3B`80[HA@0`2^QE430:n6DPP0[hAA202^QE430;68E080/8MC0P2_QU820:j5D@@0
[hIB102`Qe<50:n4C`<0/8E@202aR5@01P2^QE40[hIB0:n6DP2`Qe<0/HQD0;:9E@80/hYF202aQeD2
0:f4D0040:j5D@2_QU80[hIB0;27D`80/HQD0`2`Qe<30;68E080/XUE0P2/Qe<20:f8E0040:j9E@2_
RUH0[hYF0;2;E`<0/HME0P2bR5H30;>9E`060:j5C@2_QTh0[hI@0;27D`2aR5@0/XQF0P2cRET30:f8
E0<0[XUE0P2_RUH20;:9E@<0/hYF0`2dReL00`2cRUH0/XUE0;27D`020;27D`030;:9E@2dReL0]HaH
00P0[hYF0`2`Qe<20:n6DP<0[XEA00P0[HQC0:b7DP2[QU40ZhIA0:b7DP2^RE@0/8]F0;6<E`P0]8]G
0P2`Qe<0102aR5@0/XUE0;:9E@2cRUH20;B;E`@0/hYB0P2bRE430;68D080/8ID00<0/8MC0;27D@2`
Qdl00P2`R4d0102`R4/0/8MC0;68E02cRUH20;B;E`060;>:EP2aR5@0/8MC0;26EP2aQeL0/hUG0P2d
ReL00`2cRU@0/HQ@0;27C`020:f9C`040:f8D@2]R5<0[HQC0:f8E080[HMF0100[H=A0;26E02dReL0
]hiH0;R?E`2fSU<0/h]@0;69C02bQe@0/HIC0;25DP2_Q540/8EB0;:7E02dREH0]X]H0P2aR5802@2`
Qe40[hI@0:j5C`2]Q4h0[8==0:^2C02_QU80[XEA0:b3C`020:^2CP040:b3C`2^QE40[hIB0:j5C`80
[hI@00D0/8MA0:n6D02^QDl0[HA>0:b3C@080:b7DPP0[HA@0P2`Qdl0102_QU00[XEA0:b3C`2[PDl2
0:Z0D0P0[8=?202]Q5030:^2CP<0[8=?0P2]Q5080:b3C`@0[XE?102]Q4h:0:f4D0@0[8=?1P2[PTh3
0:b3C`<0[HA@00L0[XEA0:n6DP2`Qe<0[hIB0:f4D02ZPDd0ZH1<00P0[H9=202/Pdd30:j5D@80[HA@
0`2/Pdl00`2_QU80[XEA0:b3C`030:Z1C@050:^2CP2/Pdl0Zh9>0:Z1C@2YP4`00P2WOTX00`2YP4`0
ZX5=0:^2CP020:f4C0040:f4CP2]Q500[HA@0:f3D@80[H=C202/P4l20:n4C`@0[X=>0P2]PTd0102^
QE40[HA@0:f4D02/Pdl20:^2CP80ZX5=202[PT`20:YoB0040:YoBP2ZOd`0ZWm<0:YnC@80ZWi?1@2Z
Od`30:^0C@80ZGi;0`2ZOd`30:^0C@P0[89@102[PTh40:Z1C@030:b3C`2]Q500[hIB0080[hIB00H0
[HA@0:^2CP2ZPDd0[8=?0:Z1C@2XOd/30:MnBP030:QoB`2ZPDd0[8=?0080ZH1<0P2ZPDd20:^2CP80
[8=?202[PTh80:f3A`P0Zh9>0`2/Pdl00`2]Q500[XEA0:n6DP020:n6DQ00[HA@202/Pdl40:Z0D0@0
Zh5A0P2ZOTl0102ZOTd0ZWm<0:YoC02ZOdX20:YoB0P0Z7m;0`2ZPD/30:V0BP80Z7m90`2YP4X20:Qo
B@<0Ygi800H0ZX1>0:UoC@2XOT`0Yge;0:IlBP2UNdT20:AjB0<0ZH1:00<0ZX5;0:^2C02/Pdd00P2/
Pdd00`2YP4P0ZX590:^2C0020:^2CP050:UoC@2WODd0YWa<0:MnBP2XOd/00P2YP4`0102XOd/0YWe9
0:AkA`2SNTH30:MlA`<0Z7e80P2YOTT20:QoB`050:MnBP2VODT0YGa80:ElB02TNdL00P2SNTH80:Ai
A0040:9iA@2QN4@0XGQ40:1g@`@0WgI2202RN4P0202RNTL0Xg]80:AlB@2TO4T0Xg]80:5iAP2OMd@0
WWI30P2PMD800`2QMT<0XWM40:=hA@020:EjA`040:IkB02TNTX0Y7Y:0:AjBP80XgU90`2RN4P0202W
ODd0YWa<0:AjB02SNTH0XWU50:=jA02TNd<0YGa4202QN4@30:AjB080XgU7202RN4H30:5gA@0509ie
@@2OMT80WgI20:1g@`2QN4@00P2RNDD00`2SNTH0Y7U60:AiAP060:AiAP030:1g@@2QN480XgY40080
YGa600<0XgY40:5h@P2PMd40202SNTH30:1dA@80XGE60`2RMTL02`2LMd00VgHo09]f@@2JMD40VG=2
09Qb@`2GLD80Ug540:5gA`2PMTH0WWA20080WGA000<0WWDo0:1g?`2RND400`2OMD<00`2PMT@0XGM5
0:9hAP020:9hAP0509mf@P2PMd<0XGQ40:9iA@2QN4@00P2OMT803P2MM400Vg8n09ebA`2NLdP0WgA9
0:1eBP2QMT/0XWM<0:=hC@2TNDh0XgU70:9hAP2PMT@0WWA20P2MLd402P2NM480WgE309]b?P2MM400
WgI20:1g@`2OMT80WGA009Ya?@2IL3`309ab@0H0WG=10P2LLT000`2KLCl0VW0n09U_?@0209Q^?0P0
VVm400@0WWA209ab@02IKcd0Ufdk0P2FK3X0102HKS`0VW0n09M]>`2GKC/209Q^?0<0VFlm00@0VW0n
09]a?`2JL3h0V6hl0P2GKC/00`2HKS`0VW0n09]a?`0209U^@@<0V6e00`2GK3l209EZ?@0409M/?`2I
KT40Vg1309aaA080WW=60P2KLS`00`2KLSh0VW0n09U_?`0209Q]@00309Q]@P2DJSP0U6Xh00H0U6Xh
00<0Ufdk09E[>@2BJ3H00P2@IS@00`2AIcD0TfTg09E[>@0809AY?003091Z>`2AJc`0Tfdn0080U6ho
00D0Tfdn095[?02@JS/0TVLj095V>@02091U>00<095V>@2EJSd0V6e009]`@`2FL3l0U6hm099/?@2@
JSd0SfPm08mX?`2AJT40TV]40P2CJ3h00`2CJ3d0TfPk09=Y>@0309=Y=`0409=Z=P2FJch0TfPk091U
>080SF8e00<0T6Dh09=X>`2FJch0202@ICX308iX>@<0SFLh0P2<ISL8095U@00308eW>P2<IST0RV@g
0080RV@g00/0S6Hi08iX>`2?JC`0TVhd095/=@2@JcH0SfTh08iX>`2=IS/0S6Dn08]T?@0409E[>`07
09=Y>@2?ICD0S68b08YP<02;IST0SFPk08iY?002091[?P0308iY?02=J3/0RfHi0080T6Xm00<0SfTl
08iX>`2>J3/00`2>J3/308aU?2_ooooo000Zooooo`P0REdf0P26GcH208EN=@80Q5dd0P23G3<308=K
=`0308AL>025GCT0QUhj0080Qelk2026GcH808YO=00308QL=@2:GSL0Relh00<0SF4j00<0Relh08YN
=`2;GcP01`2;GcP00`2>HcP0SF8g08aQ=P0208]P=@0608aQ=P2=HSL0SV<h095V>`2@ICX0SV<h0`2<
HCH0102=HSL0SV<h08]U>02:I3L408US=P0<08]U>02=IcX0SVPk08aP>`2=HCX0Sf<l095V?02AIS/0
T6Dh08mU=@2>I3@0TfPm0P2BIc`00`2AIS/0T6Dj08mT>@0208iS>00308iR=@2?HcH0TFDh00<0TfLj
00D0TVHi095U>02FICX0UF@i09AS>002099Q=P0309AS>02EI3T0UVDj00<0T6Dj0P2AIS/3099W?0P0
U6Tn00D0VVe309U/@P2IK480V6]109MZ@00209IY?`0309EX?P2DJC`0U6Tl00H0U6Tl00<0V6`o09M[
?P2FJSd00P2DJ3/03P2FJSd0Uf/n09Q/?`2HKCP0Uf`g09I[>02DJ3L0U6Pi09IZ?@2GJch0V6]109Q/
?`2FJSd0TfLj0P2AICP00`2CIcX0UVXm09Q/?`0209EZ?@80UV/n0P2GK3l209Q]@0<0VVhm00<0VFdl
09Q/>`2HK3/00P2GJcX209]`>`0309]`?@2JKSd0VVho0080VFe000<0VFa209Y^?@2JKSd01P2JKSd0
0`2GK3l0VFi109]`@`0209ebA@0;09Y_@P2GK3l0U6Tl09]^A`2JKD@0V6]209MZ@02GJch0V6`m09U]
?02JKSd0102JKc`209]`?@80W74n2@2MLTD00`2OM440WW=009aa?P0209]`?@0309aa?P2MLSl0WW=0
0080W79000<0WG=109id@P2NM4800`2OMD<309ib@@80Wg=20`2PM4<@0:1e@P80XWM40P2SN4D01@2T
NDH0YGY70:EjA`2UNTL0ZWQ70080Z7Q700<0YgU70:EjA`2TNdL00P2SNdL30:5f@`050:9gA02SN4D0
XgQ50:=hA@2TNDH0202XNDD80:EjA@030:EjA`2VNdP0Yga90080Z7e:00<0Yga90:IkB02UNTL0202W
O4L20:IkAP80Yga700L0Z7e80:UnB@2YOTT0ZGi90:YoC02YOT/0Yga90080YW]800<0Yga90:UnB`2Z
Od`0202YOT/0202[Oe00ZWi?0:UmCP2XO4d0ZGe>0:YnC`2/P540[H5B202/Pdl80:f2C`060:QoA`2Z
PDT0[8=;0:f4C02^QDd0[HA<0`2/Pd/80:f2C@80ZX5=0P2[PTh20:b3C`80[HA@0P2/P4l00`2/PDh0
[85<0:b1BP020:b2B0030:b2AP2ZOdX0ZWm:0080Zh1;0P2/PD`20:f2C@<0ZX5=0P2[PTh30:b3C`06
0:N4C02XPd`0Z8=<0:Z3C02[PT`0[85<0P2^P4`20:YnC`80Zgm@0P2/P5420:f1DP<0Z7e800<0ZGi9
0:YoBP2ZOdX00P2[P4/0202ZOdX0Zh1;0:f2C@2^Pdh0[hA?0:j3CP2/PD`0Zh1;0P2_Odl20:inCP07
0:emC@2/O4`0[7a<0:alC02VNdH0Z7e80:UnB@030:^0B`030:UnB@2XODP0Z7e80080Z7e80P2YOTT5
0:YoBP<0Zh1;0`2/PD`30:UnB`030:YoC02[P4d0Zh1=0080[85>0P2[PTX20:Z1B@070:V0B02XOdL0
Z7m70:QoA`2/PD`0Zh1;0:UnB@020:QmB0030:UnB@2[P4/0[85<00P0ZX59102/PD`20:^0B`80ZWm:
2@2YP4`00`2YOT/0ZWm<0:^0C@020:b1CP030:^0C@2YOT/0Z7e:00P0ZWm<202ZPDd80:V0C0P0Zh1=
202ZOTl30:^0B`<0ZWm:0P2YOTT20:b1CP80Zh1=0P2ZOd`20:UnB`<0ZX5;0`2YP4X20:QoB@P0Z7m;
0`2/Pdl30:f4D080[XEA00<0/HQD0:n6DP2]Q5000`2[PTh00`2/Pdl0[HA@0:f2C@020:f2C@80[X=>
0`2_Q4l30:j5D@80[HA@0`2/Pdl80:j3D080[XAD00@0[XAB0:f4D02]Q500[HA>0P2/Pd/20:f4D0<0
[XEA0`2_QU880:n4D@P0[XEA0`2aR5@20;27D`80[hIB0P2^QE440:n6DP@0/8MC1P2_Q4l20;25D0P0
/HQD0`2`Qe<30;68E080/XUE202aQeD30:n6DP80/8MC0`2aR5@30;27D`<0/HQD0P2bRED20:b7D`80
[HQD00@0[XUE0:n:EP2_RUH0[hYF0`2aQeD20;:8EP<0/hUG0P2`Qdl0102`Qe40/HQD0;68E02aQeD2
0;:8F0<0[HQD0`2^RED20:n:EP<0/XUE0P2cRUH30;B;E`030;>:EP2bRED0/HQD0080/8MC00<0/XUE
0;B;E`2eS5P0202_RUH80;27D`080:n:E@2^RE@0[HQC0:b7DP2]R5<0[XUD0;2;EP2aS5L80;B;E`03
0;27D`2aR5@0/HQD0080/XUE0P2cRUH00`2dReL0/hYB0;>:DP020;>:DP80/XUA0`2aR5020;67E@03
0;68E02aR580/HQ@0080/HU>00@0/HU<0;27D`2aR5@0/hYF0P2dReL01P2cRUH0/HQD0;27D`2`QUH0
/HMG0;>9E`80]8]G00<0/hYD0;68D02`Qdl00P2]RDl0102]R540[HQC0:f8D`2]R5@20:f7EP0:0:j4
DP2`QU@0]8]G0;N>F02gSUH0]XiC0;>;D02aRD`0/XMD0;66D`<0/8EB00<0/XMD0;B9EP2eRUL00P2a
R580102`Qe40[hI@0:j5C`2]Q4h20:b3C@030:n6DP2^QE40[8=?0080Zh9>00D0[8=?0:j5D@2_QU80
/8MA0:n6D0020:j5C`@0[HA>202[QU480:f4D0080;27C`2_QTh0[hI@0:j5D@2/Pdl0Zh5?0:^1D@2Z
P50@0:f4D0<0Zh9>0`2/Pdl20:f4D0P0[8=?1@2]Q4h30:b3C@X0[HA@102/Pdl60:^2CP<0[8=?102]
Q5020:n6DP040:j5D@2]Q500Zh9>0:V0C0P0[H9=202/Pdd20:j5D@<0[HA@0`2/Pdl00`2_QU80[XEA
0:b3C`030:Z1C@050:^2CP2/Pdl0Zh9>0:Z1C@2YP4`00P2XOd/00`2YP4`0ZX5=0:^2CP020:f4C004
0:f4CP2]Q500[HA@0:f3D@80[H=C202/P4l60:j3CP80[H9=0`2]Q5000`2/Pdl0Zh9>0:^2CP020:Z1
C@P0Zh9<0P2ZOdP0102ZOdX0ZWm<0:YoC02ZOTd20:YnC`@0ZWm<102[P4d20:UnB`<0ZWm<0`2[P4d8
0:b2D0D0Zh9>0`2ZPDd02`2/Pdl0[HA@0:j5D@2_QU80[XEA0:f4D02[PTh0ZX5=0:^2CP2ZPDd0ZH1<
00<0Z7m;00<0ZH1<0:Z1C@2[PTh00P2YP4`20:Z1C@80Zh9>0P2/Pdl80:^2CPP0[H=92`2[PTh00`2/
Pdl0[HA@0:f4D0020:j5DA00[HA@202/Pdl50:Z0D0<0Zh5A0P2ZOTl0102ZOTd0ZWm<0:YoC02ZOdX2
0:YoB0P0Z7m;0`2ZPD/30:V0BP80Z7m90`2YP4X20:QoB@<0Ygi80`2XOT`20:MmB`<0YWa:0`2YP4X0
0`2ZPD/0Zh9<0:^2C0020:b3C@030:V0B02ZPDT0Zh9<0080Zh9>00<0ZGm=0:MmC@2VO4`00P2WOTX0
1P2XOd/0ZH1<0:QoB`2WOTX0YGa80:=jAP<0Yga70P2XODP30:UnB@80Z7m;00@0Ygi:0:ImB@2UO4P0
YGa80P2TNdL00`2SNTH0Y7U40:AiA0060:AiA080XgY60P2RNDD20:5hA080X7M3202RN4P00`2QNDH0
XWY70:=kB0020:AlB@040:9jA`2PN4D0WgM40:1e@P80XGI300D0XWM40:AiAP2UNTL0YGY70:IkB008
0:=iB@030:MmC@2VO4`0Y7Y80080XWU500<0XgY40:Ak@`2UO4@0202QN4@20:AjB0<0XgU71`2RN4H4
0:5gA@<0X7M30`2QN4@20:9iA@P0Y7U600<0WgI00:1g@@2RND<00P2SNT@00`2RND<0X7M109mf@008
0:=jAP<0XGE60P2RMTL30:=gB080WGQ100<0W7M209]f@P2JM4<00P2ILd@02@2HLTD0X7I609meA@2N
M480WGA009ie@@2OMT00XGQ00:=j@P0209me@`80X7I40P2QMdD20:9hAP0309mf@P2PMd<0XGQ40080
XGQ40P2OMT80202MM400W7<o09icAP2NLdH0WgA70:1eB02QMTT0XWM:0P2SN4/01P2SNDL0XGM509me
@`2NM480WG=109id@P80WgE30P2MM40309ie@@0309ed@02KLSh0VW4m0080W7901`2MLd4209ab@003
09]a?`2JL3h0VFlm0080V6hl202JKd80102MLd40W79009Y`?P2HKS`309M]>`<0V6hl0P2IKcd209Y`
?P<0Vg4o00L0VW0n09Q^?02GKC/0Ufdk09Q^?02JL3h0Vg4o00<0VFi10P2HKD0309M/?`80UV/n00@0
Uf`o09Q]@02IKT40VVm20P2KL4<209Ya>`0609U`?02IKcd0V6hn09Q]@02GK3l0Ufa12@2DJSP209=Y
=`80TVPf00<0TfTg09AZ>02EJcT0202DJC`00`2@JS/0TF/l09=]?P0209A^?`0309=]?P2AJc`0T6Xk
00@0TfPk00`0U6Tl09EZ?@2GK3l0V6e009A^?@2BK3/0T6Xk08mY?02?J3d0SfPo095Z@@2BJd@209=X
?P0309=X?@2CJ3/0TfTi00<0TfTg00@0TfXf09EZ?@2CJ3/0T6Dh0P2>HcH00`2@ICP0TfPk09EZ?@08
091U>P<0SVPi0`2=IcP208aV=`P0T6@m00P0SFLj08aV>@2;ICP0RV@g08]U>02<IST0SVPk08mY?080
SVTb00L0SVTe08iX=`2?JC`0SfPm08mX?`2?J440TfTi00<0U6Xj00L0TVPh091V=P2=Hc<0S68b08]V
>@2<IcX0SVTl0080SfXm00<0SVTl08aW>P2;IST01@2>J3/308mY?0<0SFHm:oooool002[ooooo2028
G3D208IO=P80QEhe0P24GC@208=L<`P0QEhg2026GcH808]P=@0308YN=`2;GcP0SF4j0080SF4j00<0
Relh08YN=`28G3D0202;GcP00`2>HcP0SF8g08aQ=P0208]P=@0808aQ=P2=HSL0SV<h091U>P2?I3T0
SV<h08eR=`2<HCH208eR=`0308iS>02;ICP0RV@g00@0RF<f00`0RfDh08eW>P2>J3/0SF4l08eQ>P2?
Hc`0T6Dk095V>`2@ICP0T6Hf08mU=@2CJ3d2099W?003095V>`2@ICX0Sf@i0080SV<h00<0SV8e08mS
=P2AICP00`2CIcX01@2BIST0TFDh09IU>P2EI3T0U6<h0080TV4f00<0U6<h09ET>@2FICX00P2>HcP2
08mT>@80T6Dj0P2AIS/2099W?00409=X?@2DJCh0U6Tn09EZ?`80UV]0102HJd4409MZ@080UV/n00@0
UFXm09AY?02DJC`0TfPk0P2BIcX00`2HK3l0Uf/n09IZ?@0209AX>`0>09IZ?@2GJch0V6`o09Q]>02G
K3L0UV/h09AX=`2DJ3T0UVXm09M[?P2HJd40VFe009M[?P2DJ3/209=W>P0309AX>`2GJch0VFe00080
UFXm0P2FJch209M/?`80V6e00P2JKSd309U]?0<0V6`k0P2IKST00`2IKS/0VVhm09Y^?`0209]_@P03
09]^A02KKch0Vfln00H0Vfln00l0V6e009U^@@2LLD@0WG9509aaA02JKd80Uf`o09EZ?@2KKTD0VVe4
09Q[@@2GJch0V6`m09U]?02JKSd00P2KL3d309aa?P80WG8o0P2NLd0909aaA00309md@@2NLd00W74n
0080Vg0m00<0W74n09ic@02OM4401@2MLd400`2NM480WgE309me@`0309ib@@80Wg=20`2PM4<80:1e
@PP0XGI300@0XWM40:=hA@2SN4D0XgQ50`2TNDH01`2UNTL0Z7I50:IfA@2VMTD0YGM50:=hA@2RNDD0
0P2QNDD20:5f@`040:9gA02SN4D0YGY70:IkB080Yga9202XNDD80:EjA@030:EjA`2VNdP0Yga90080
Z7e:00<0Yga90:IkB02UNTL02`2WO4L30:QmB080ZGi900<0ZGi;0:QmBP2WO4T00P2VNdP00`2WO4T0
Z7e:0:UnB`080:YoC0080:]oCP2ZOTd0ZGe<0:QlB`2YOD`0ZWi=0:b0C`2]PE080:b3C`P0[H9?00H0
ZH1:0:Z1B`2/Pdd0[HA>0:j5C`2]Q4h20:b3C@030:^2C02]PTd0[H9=00H0[H9=0P2ZPDd30:^2CP<0
[8=?0P2/P4l00`2/PDh0[85<0:b1BP020:b2B0030:b2AP2ZOdX0ZWm:0080Zh1;0P2/PD`20:f2C@80
Zh9>0P2/Pdl20:f4D080[XEA00H0YhA<0:R3C02XPd`0ZX=<0:^2C02/PD`20:j0C080ZWi=0P2[Odh2
0:b0C`80[H5@00@0Z7e80:UnB@2YOTT0ZGi90`2ZOdX01@2[P4/0ZGi90:YoBP2/PD`0[H9=0080[X=>
0P2]PTd30:inC@<0[Ge<0P2/O4/0202YOTT0ZWm:0:^0B`2/PD`0Zh1;0:YoBP2XODP0Yga70`2XODP2
0:UnB@<0ZWm:0P2/PD`30:^0B`<0ZWm:0P2YOT/30:YoC0<0Zh1=0`2ZPD/30:V0BP80Z7m900<0Zh1;
0:YoBP2YOTT00P2XODP00`2YOTT0ZWm:0:^0B`080:Z1B`<0[85<0P2[P4/30:YoBPT0ZH1<00P0ZGi;
0:YoC02[P4d0Zh1=0:b1CP2[P4d0ZWm<0:UnB`P0ZWm<202ZPDd80:V0C0P0Zh1=202[Odh30:^0B`<0
ZWm:0P2YOTT20:b1CP<0Zh1=0`2ZOd`30:Z1B`<0ZH1:0P2XOdT80:V0C080Zh9>0P2/Pdl30:f4D004
0:j5D@2_QU80[XEA0:f4D0<0[8=?0P2]Q5030:f2C@80[X=>0`2_Q4l30:j5D@80[HA@0`2/Pdl80:j3
D080[hEE00H0[XAB0:j5D@2]Q500[HA>0:f4C02/Pd/20:f4D0<0[XEA0`2_QU880:n4D@P0[XEA0`2a
R5@20;27D`80[hIB0P2^QE440;27D`@0[hIB202_Q4l80;68E080/XUE0`2aR5@30;27D`P0/8ID102b
RED40;68E0<0/8MC0`2aR5@20;:9E@<0[HQD0`2^RED20:n:EP<0/HME0P2bR5H30;>9E`80/XUA00@0
/HQB0;68E02aR5@0/8ID0P2`QUH30:f8E0<0[XUE0P2_RUH0102aR5@0/XUE0;:9E@2bRED20;>:EP80
]8]G00H0/XUE0;68E02aR5@0/8MC0;68E02bRED20;B;E`P0[hYF0P2`Qe<0102aR5@0/XUE0;:9E@2c
RUH20;B;E`030;>>F@2aS5L0/8]F00<0[XUD00<0/8]F0;6<E`2dReL01`2dReL30;68E080/XUE0`2c
RUH40;>:E080/XUC0`2aR5820;>9E`030;>:EP2cRU@0/hYB0080/h]@00@0/h]>0;68E02bRED0/hYF
0P2dReL01P2cRUH0/XUE0;68E02`QUH0/HMG0;>9E`80]8]G00<0/hYD0;68D02`Qdl00P2]RDl0102]
R540[HQC0:f8D`2]R5@20:f7EP090:n5D`2aQeD0]8]G0;J=E`2gSUH0]HeB0;>;D02aRD`0/XMD0080
/HIC00D0/8EB0;66D`2bQe@0/hQE0;B9EP020;68DP040;27D@2_QU00[XE?0:j5C`80[HA>00<0[hIB
0:j5D@2]Q5000P2/Pdl02`2]Q500[XEA0:n6DP2bRE<0/8MA0:f4CP2[PT`0ZX5;0:b3C@2^QDl0[hI@
00P0ZHA?202]Q5020:n6CP040:j5C`2]Q500[HA@0:b2D080Zh5A202^QE480:f4D0<0Zh9>0`2/Pdl2
0:f4D0P0[8=?0`2[PT`50:b3C@X0[HA@102/Pdl60:^2CP<0[8=?0P2]Q500202/Pdl0[HA@0:j5D@2^
QE40[HA@0:b3C`2[PTh0ZX5=202]PTd80:b3C@040:j5D@2]Q500[HA@0:f4D080[8=?0P2[PTh00`2_
QU80[HA@0:b3C`030:Z1C@<0[8=?00L0Zh9>0:V0C02XOd/0Z7m;0:V0C02[PTh0[8=?0080[HA<00@0
[HA>0:f4D02]Q500[H=A0P2]Pe<80:b1CPD0[H9=0`2^Pdh20:f4D0<0[8=?0`2[PTh80:^2C080Zh19
00@0Zh1;0:^0C@2[P4d0Zgm>0P2[Oe080:^0C@80ZGi;0`2ZOd`30:^0C@P0Zh5?202[PTh02P2/Pdl0
[HA@0:j5D@2^QE40[HA@0:b3C`2[PTh0ZX5=0:^2CP2ZPDd50:V0C0040:Z1C@2[PTh0ZH1<0:V0C080
ZX5=0P2[PTh20:b3C`P0Zh9>202]PdT80:^2CP040:V0C02ZPDd0ZX5=0:Z1C@<0Zh9>6@2/Pdl80:Z0
CP80ZWi?00@0ZWi=0:YoC02ZOd`0ZWm:0P2ZOdP80:QoB`<0ZX5;0`2YP4X20:QoB@<0ZH1:0P2XOdT3
0:MnB080YWa:0P2WOD/40:QnC0<0ZH1:0P2ZPD/30:^2C00@0:QoA`2YP4P0ZX5;0:^2CP2ZPDd0ZGm=
0:MmC@2VO4`0YWe90:MnBP2XOd/0ZH1<0:QoB`2WOTX0YGa80:AkA`80Yga70P2XODP30:UnB@030:Yo
BP2XOd/0Z7m;0080Ygi:0P2VODT00`2UO4P0Y7]70:AkA`080:EjA@80Y7]700@0YGa80:AkA`2TNdL0
XgY60P2RNDD80:9hAP030:1fA02QMdD0XgU70080YG]900<0Y7Y80:=iA`2RN4H00P2QMT<00`2RMd@0
XgQ50:AiAP020:EjA`040:IkB02QMdD0XGM50:9hAP80XgU700H0Y7Y80:EkB@2UNdT0Yge=0:EkB`2T
NTP20:9iA@030:9i@`2SNT80Y7]300P0XGQ400@0Y7Y80:=iA`2SNDL0XgU70P2RN4H:0:5gA@<0XWU5
0`2QN4@20:1g@`P0XgQ500<0WWE109mf@P2PMd<00P2QN4@00`2PMd<0WgI209ie@@080:9iA@80XWI5
0P2SMdH20:AhA`80YGU80P2ONT<00`2NND@0WGQ409afA@0209]eAP0:09YdA`2MLd<0WG=309ec@@2M
M400WgI20:5h@P2SNT80Y7]309me@`<0X7I40`2QMdD01P2RN4H0WgI20:1g@`2PMd<0XGQ40:1g@`80
WgI200<0WWE109ed@02NLdH00P2OM4L04P2PMDP0XGI90:9gBP2RMdX0XgQ;0:9hAP2QMdD0WgE309id
@P2MLd40WWA209me@`2PMT@0WgI209ie@@2MM400W7<o09]b?P80W7<o00<0WGA009ec@@2MLd401`2M
Ld4209ab@00309]a?`2JL3h0VFlm0080V6hl202JKd80202JL3h0Vg4o09]a?`2KLCl0VW0n09Q^?02F
K3X0UF/i0`2JL3h209]a?`<0W79000<0Vg4o09Y`?P2HKS`00P2GKC/0102HKS`0VW0n09]a?`2JKd83
09U^@@80V6e02P2GK3l209Q_>@0309Q_>`2GKC/0Ufdm0080UV/n00<0UV]009E[>@2EJcT01P2EJcT0
102@IS@0TVPf09=Y=`2EJcT209I/>P80UF/i202EJSd00`2AJc`0TV`m09=]?P0209A^?`0309=]?P2B
K3d0TF/l0080UFXm00h0UV/n09M/?`2GK3l0Uf`o09I[?P2EJSd0T6Xi08mY>02>J3T0SVPk08iW?02@
JD00TFY1099[A080TfPn00<0TfPm09=X>`2CJCT00`2CJCL0102CJSH0UFXm09=X>`2AIST208mT=`03
095V>@2CJ3/0UFXm00P0TFHk0`2>J3T308eW>080S6Hg202>HS/04@2=IcX0S6Hi08]U>02;ICP0S6Hi
08eW>P2>J3/0SfTl08YU<02;IS80S6Lc08iX=`2?JCX0TF/n099[@02CK440TFHi00@0TVLj00<0TFHi
08mT=`2>HcH00P2<IcX0102=J3/0SVTl08iY?02=J3/208aW>P80S6Hi00<0SFLj08mY?02?JC`00`2@
JSd3091Y@2_ooooo000Zooooo`P0Qede0P26GcH208EN=@80Q5dd0P23G3<01027H3L0QUlf08IO=P26
GcH308EN=@0308AM=027H3L0Qf0g00H0Qf0g202;H3D208aP>@<0SF4j00<0Relh08UM=P27Fc@0202;
GcP208eR=`@0S64f0P2=HSL00`2?I3T0SV<h08iS>00308eR=`80SV<h00<0RfDh08YT=`29HcH00`29
HcH0102;ICP0SFLj08iX>`2=HC`208iR>`0308mT>P2@ICX0T6Dh0080T6Hf00H0TfPm099W?02BIc`0
TFHk091U>P2?I3T208iS>00308iR=@2?HcH0TFDh00<0TfLj00D0TVHi095U>02FICX0UF@i09AS>002
099Q=P0309AS>02EI3T0UVDj0080SF8g0P2>HcP308mT>@07091U>P2AIS/0TFHk099W?02CJ3d0UFXo
09I[@00209M/@@0409IY?`2GJT00UfY009MZ@0<0V6]100L0VFa209M/?`2GK3l0UV/n09EZ?@2CJ3/0
TVLj0080TFHi00<0V6`o09M[?P2FJSd00P2DJ3/03P2FJSd0Uf/n09Q/?`2HKCP0Uf`g09I[>02DJ3L0
U6Pi09IZ?@2GJch0V6]109U]@02HK3l0UVXm0P2EJC`00`2FJSd0V6`o09U]@00209EZ?@80UV/n0P2G
K3l209Q]@0H0VFdl0P2HK3/209Q]>00609U^>`2JKSd0VVho09]_@P2LL4<0W6m5202KKch00`2IKT40
VVm209aaA00209aaA00;09Y_@P2HKD00Uf`o09]^A02JKD<0VFe009Q/?@2HK3/0VFhk09]`?@2LLC`0
0`2MLSl209ic@0<0WgA12@2LLD@209ic@0<0W74n00D0WG8o09md@@2PMD80WWA209ec@@0309ab@003
09ec@@2NM480WgE300<0WW910P2OLd830:1d@`P0X7E2202QMT<80:=hA@060:Id@`2TM4<0Y7A30:=e
@`2QMT<0X7M30P2OMd<01P2QMT<0XWM40:=hA@2UNTL0YW]80:QmBP80ZWm<202XNDD80:EjA@80YW]8
102WO4T20:IkB0X0Yga71P2XODP30:QmBP80Yga90`2XODX80:YoC0080:^0C@2ZOd`0ZGi;0:QmBP2Y
OT/0ZWm<0:b1CP2]PTl80:b3C`P0[H9?00H0ZX5=0:^2CP2/Pdl0[HA@0:j5D@2]Q5020:^2CP030:Z1
C@2]PTd0[H9=00H0[H9=0P2ZPDd60:^2CP80[81?00<0[85>0:b1C02/PDX00P2/PTP00`2/PTH0ZWm:
0:YoBP020:^0B`80[85<0P2]PTd0102/Pdl0[HA@0:f4D02]Q5020:j5D@80[hIB00H0YhA<0:R3C02X
Pd`0ZX=<0:^2C02/PD`20:j0C080ZWm<0P2[P4d20:b1CP80[H9?202ZOdX20:UnB@040:YoBP2/PD`0
[H9=0:f2C@80[X=>0P2^Od/60:enBP080:YoBP2[P4/0[85<0:b1C02[P4/0ZGi90:MlA`2VNdH30:Qm
B080ZGi90`2ZOdX01@2]PTd0[85<0:b1C02[P4/0ZWm:0080ZGi900<0Z7e80:YoC02ZOd`0102ZOd`2
0:^0C@80ZX5=1P2YP4`00`2[P4/0ZWm:0:UnB@020:MlA`030:UnB@2ZOdX0Zh1;00P0ZX5=0P2/PD`2
0:^0B`80ZWm:0P2YOTT90:QoB`80ZGi;00<0ZWm<0:^0C@2[P4d00`2[P4d80:YoC0P0ZX5=202YP4`@
0:^0C@<0Zh1;0`2ZOdX20:UnB@80[85>1P2[P4d30:Z1B`<0ZH1:0P2XOdT80:V0C0<0Zh9>0P2/Pdl3
0:f4D080[XEA0P2]Q500102/Pdl0[HA@0:f4D02]Q5030:f2C@80[X=>0`2_Q4l30:j5D@80[HA@0`2/
Pdl80:j3D080[hEE00@0[hEC0:j5D@2^QE40[HA>0P2]Q4`20:f4D0<0[XEA0`2_QU880:n4D@P0[XEA
0`2aR5@20;27D`80[hIB0P2^QE440;27D`@0[hIB0`2`QE040:n4C`030:j3CP2aR5@0/HQD00H0/HQD
0P2cRUH00`2bRED0/HQD0;27D`020:n6DP030:j5D@2`QU@0/8ID00H0/8ID00D0]HaH0;B;E`2dReL0
/hYF0;:9E@020;68E0@0/8MC0`2aR5@20;:9E@80[HQD1P2^RED30;67E@80/XQF0`2cREL20;>:DP06
0;:9D`2aR5@0/8MC0:n5D`2_QED0[XAD0`2]R5@30:j9E@80[hYF0P2aR5@30;:9E@<0/hYF102aR5@0
102bRED0/hYF0;>:EP2dReL80:n:EP060;27D`2aR5@0/XUE0;>:EP2dReL0]XeI0P2gSUX00`2eT5/0
/hiI0;6<E`030:n:E@80/8]F202dReL80;:9E@@0/hYF0P2bRED30;68E080]8YH00<0]8]G0;B;E@2d
Re<00P2dS540102dS4l0/HQD0;:9E@2dReL20;F<F0060;B;E`2bRED0/HQD0;26EP2aQeL0/hUG0P2d
ReL00`2cRU@0/HQ@0;27C`020:j:D0040:j9DP2^RE@0[XUD0:j9E@80[XQG00P0/HME0;:8EP2dReL0
]HaF0;J=E@2dS540/h]@0;69C080/XMD0`2aQU<20;:7E0030;>8E@2aR580/HQB0080/8MA00@0[hI@
0:j5C`2^QDl0[XE?202^QE40202cRU@0/8MA0:b3C@2YP4X0Z7m90:^2C02^QDl0/HQB202XPdh80:f4
D0030:n6CP2^QDd0[XE?0080[HA@00<0[89@0:b2DP2[PE40202_QU880:f4D0<0Zh9>0`2/Pdl20:f4
D0P0[8=?0P2ZPD/40:^2C080[8==2P2]Q5040:b3C`H0Zh9>0`2/Pdl20:f4D0<0[8=?00<0[HA@0:b3
C`2/Pdl00P2[PTh80:f2C@P0[8==0`2]Q5020:b3C`<0Zh9>00<0[XEA0:f4D02[PTh00P2ZPDd01P2[
PTh0[8=?0:f4D02/Pdl0Zh9>0:Z1C@80Z7m;00<0ZX5=0:^2CP2/Pdl00P2]Q4`0102]Q4h0[HA@0:f4
D02]Pe420:f3D`X0[85<102]PTd20:j3CPH0[8=?0P2[PTh80:^2C080Zh1900@0Zh1;0:^0C@2[P4d0
Zgm>0P2[Oe030:b1CP@0Zh1=00<0ZWm<0:UnB`2YOT/00`2ZOd`30:^0C@P0Zh5?102[PTh40:b3C`@0
[HA@00D0[8=?0:^2CP2[PTh0ZX5=0:^2CP070:Z1C@030:^2CP2YP4`0ZH1<0080ZX5=0P2[PTh:0:b3
C`P0[H9;202[PTh80:V0C1P0[8=?102ZPDd40:V0C080ZWi?00@0ZWi=0:YoC02ZOd`0ZWm:0P2ZOdP8
0:QoB`<0ZX5;0`2YP4X20:QoB@<0ZH1:0P2XOdT30:MnB080YG]900H0YWa:0:MmB`2XOT`0ZGm=0:Z0
CP2[PDl40:V0BP@0ZX5;00<0Ygi60:QoA`2YP4X00P2ZPDd02`2YOdd0Yge=0:IlC02UO4P0YWe90:Qo
B`2YP4`0Z7m;0:MnBP2VODT0YGa800<0Z7e80`2YOTT20:YoBP80ZH1<00D0Z7m;0:MnBP2VODT0YWe9
0:ElB0020:AkA`P0YGY500<0YGa80:ImB@2WOTX00P2WOTX00`2UO4P0Y7]70:=jAP080:9iA@040:1d
@`2QMD@0XgM60:EiB080YWY900@0YGU80:AhA`2RMd@0XWM40P2SN4D0102TNDH0YGY70:EjA`2UNTL2
0:1g@`040:5hA02RNDD0Y7]70:ElB080YWe900P0YWa<0:EkB`2SNDL0XWU50:5hA02RND<0XgY20:Ak
@`P0XWU50`2SNDL20:9hAP<0XGM50`2PMT@40:5gA@060:9hAP2TNdL0XgY60:=jAP2RNDD0XGQ40P2P
Md<00`2OMT80XgQ50:=hA@060:=hA@0309id@P2OMD<0WgE300@0WgE300<0WWA20:9iA@2RNDD01P2R
NDD0102SN4D0Y7U60:AiAP2TNDH20:EjA`80YW]80P2QO4D00`2PNdH0WgY609ihA`0209egB00909af
B@2KLD40Vg5109ab@02NMD40X7M30:9i@`2SNT80Y7]300@0X7I4102QMdD209mf@P<0X7M30`2OMT80
0`2NMD40WgE509meA@020:1fAP80XGM70P2RN4P02`2QMdD0X7I409me@`2NM480WG=109id@P2PMT@0
XGM50:5hA02OMT80W7<o0080VW4m00@0Vg8n09ed@02OMT80WWA2102MLd4309ab@00609ec@@2LLT00
W79009]a?`2JL3h0VFlm0P2HKS`809Y`@00809Q^?02JL3h0W79009ab@02KLCl0VFlm09I/>P2DJSP3
09]a?`80W7900`2MLd400`2KLCl0VW0n09Q^?00209M]>`0309Q^?02JL3h0Vg4o0080VVm20`2IKT43
09Q]@00509U^@@2HKD00V6e009M/?`2EJSd00P2DJC`01P2CJ3/0UVdg09I]=`2FKCT0UV`j09I/?080
UV/n00<0UV]009E[>@2EJcT01P2EJcT0102>I380TFLe09AZ>02GKC/209Q^?00309I/>P2EJcT0UFXm
00L0UFXm0`2BK3d209=]?P<0TV`m00<0UV/n09M/?`2IKT400P2JKd800`2GK3l0U6Tl099W>P0208eW
=P0608iX>@2>J3/0SfPm091Y@02AJT40TV]40P2CJ3h00`2CJ3d0TfPk09=Y>@0309=Y=`0409=Z=P2E
JSd0TfPk099W>P80T6Dh00<0TVLj09=X>`2EJSd0202AIS/308iX>@<0SFLh0P2<ISL808eR>0@0S6Hi
00D0SFLj08iX>`2>J3/0SfTl08aV=@0208eW=P0608iX>@2?JCX0T6Xk091Z?@2AJch0Sf@i0P2@ICX5
095V>`80S6Lj102=J3/208aW>P0408YT=`2;ICP0SFLj08mY?0@0TF/n0`2BJd8[ooooo`00:_ooool8
08AM=080QUlf0P25GSD208AM=080Pe`c0`27H3D208IO=0<0QEhc2027H3L808aQ=P80S60i0`2=HCX0
0`2;GcP0REdf08MK=00808]O>080S64f102=HSL208aQ=P80SF8g1P2>HcP00`2;ICP0RV@g08US=P03
08US=P0408]U>02=IcX0SVPk08iR?@80SV8k00H0SV<i08mT>@2@ICP0T6Hf095W=`2CJ3d2099W?003
095V>`2@ICX0Sf@i0080SV<h00<0SV8e08mS=P2AICP00`2CIcX01@2BIST0TFDh09IU>P2EI3T0U6<h
0080TV4f00<0U6<h09ET>@2FICX00P2=HSL208iS>0<0Sf@i00L0T6Dj095V>`2AIS/0TVLl09=X?@2E
JSl0UV]00080Ufa100@0UVTo09MZ@02GJT00UfY00`2HJd401`2IK480Uf`o09M/?`2FJch0UFXm09=X
>`2BIcX00P2AIST00`2HK3l0Uf/n09IZ?@0209AX>`0>09IZ?@2GJch0V6`o09Q]>02GK3L0UV/h09AX
=`2DJ3T0UVXm09M[?P2HJd40V6`o09M[?P2FJSd209EY?00309IZ?@2GJch0V6`o0080UFXm0P2FJch2
09M/?`80V6e00P2HK3/609U]?080V6dh00H0VFhk09Y^?@2JKSl0Vfm209a`@`2LKdD809a`?`0309Y_
@P2KL4<0W7540080W75400<0VVm209U^@@2HKD000P2JKT401`2IKCh0V6`k09U^>`2JKc`0W74l09ic
?02MLSl00`2NLd0209md@@80X7E22@2KL4<02`2NLd00WG8o09aa?P2LLCh0WG8o09ic@02PMD80XGI3
09me@`2NM480W7900080VW0n00<0Vg4o09ec@@2NM4800`2NLT4209mc@P<0X7A3202PMD880:9gA0@0
XgQ5102RMd@01P2VM4<0Y7A30:Ad@`2SMD<0XGI30:1g@`80WgM300P0XGI30:9gA02SN4D0YGY70:Ml
B@2YOT/0ZWm<0:^0C@P0Z7U5202UNTD20:MlB@@0YW]80P2WO4T80:MlA`H0Z7e80P2WO4L00`2WO4T0
Z7e:0:QmBP040:QmBP030:MlB@2[P4d0Zh1=00L0Zh1=00L0ZWm<0:UnB`2XODX0ZGi;0:YoC02/PDh0
[H9?00P0[8=?202]PTl01P2ZPDd0Zh9>0:f4D02^QE40[HA@0:b3C`80Zh9>00<0ZX5=0:f2C@2]PTd0
1P2]PTd20:^2CPH0ZX5=0P2/P4l00`2/PDh0[85<0:b1BP020:b2B0030:b2AP2ZOdX0ZWm:0080Zh1;
0P2/PD`20:f2C@040:b3C`2]Q500[HA@0:f4D080[XEA0P2_QU801P2WQ4`0Z8=<0:R3C02ZPd`0Zh9<
0:b1C080[X1<0P2ZOd`20:^0C@80[85>0P2]PTl40:^0B`P0ZWm:00@0Zh1;0:b1C02]PTd0[X=>1P2]
OTP20:ioB@080:^0B`2/PD`0[H9=0:f2C@2/PD`0ZWm:0:QmB02VNdH30:QmB080ZGi90`2ZOdX20:b1
C0040:^0B`2ZOdX0ZWm:0:UnB@80Z7e80P2[P4d60:YoC0H0ZH1<0P2ZPDd00`2[P4/0ZGi90:QmB002
0:MlA`030:QmB02YOTT0Zh1;00P0ZH1<0`2[P4/20:YoBP<0ZGi92@2XOd/40:UnB`040:YoC02[P4d0
[85>0:b1CPP0ZWm<402YP4`80:YoC0P0[85>0`2[P4/30:YoBP80ZGi90P2[P4d60:b1CP<0ZX5;0`2Y
P4X20:QoB@X0ZX5=0P2[PTh20:b3C`80[HA@0P2/Pdl20:f4D0040:j5D@2]Q500[HA@0:f4D0<0[H9=
0P2^Pdh30:n4C`<0[XEA0P2]Q5030:b3C`P0[X=@0P2`QUH0102_QE<0[hIB0:j5D@2^QDl20:f4C080
[HA@0`2^QE430:n6DPP0[hAA202^QE430;68E080/8MC0P2_QU820:j5D@80/HQD0P2`Qe<20:n6DP80
[XEA0P2aQU420;25D0040:n4C`2^Pdh0[X=>0:j3CPP0/HQD0P2cRUH00`2bRED0/HQD0;27D`020:n6
DP030:j5D@2_QE<0[hEC00H0[hEC00D0]HaH0;B;E`2dReL0/hYF0;:9E@020;68E0@0/8MC0`2aR5@2
0;:9E@H0[XUE0P2]R5@30;67E@80/XQF0`2cREL20;>:DP060;:9D`2aR5@0/8MC0:n5D`2_QED0[XAD
0`2]R5@30:j9E@80[hYF0`2aR5@30;:9E@80/hYF00@0/8MC0;68E02aR5@0/XUE102cRUH80:n:EP80
/HQD00@0/XUE0;>:EP2eS5P0]XeI0P2gSUX00`2eT5/0/hiI0;6<E`030:n:E@80/8]F202cRUH80;:9
E@@0/hYF0P2bRED30;68E080]8YH00<0]8]G0;B;E@2dRe<00P2dS540102dS4l0/XUE0;>:EP2dReL2
0;F<F0060;B;E`2cRUH0/XUE0;26EP2aQeL0/hUG0P2dReL00`2cRU@0/HQ@0;27C`020:j:D0040:j9
DP2^RE@0[XUD0:j9E@80[XQG00P0/XQF0;>9E`2dReL0]HaF0;F<E02dS540/XY?0;::C@H0/XMD0P2a
QU<00`2aR580/8MA0;27D@020;27D@<0[hI@0P2^QE440:n6DP80[XEA00<0/hYD0;27D@2[PT`00P2X
OdT00`2ZPD/0[XE?0;27D@080:R3CPP0[HA@0P2^QDd0102]Q4h0[HA@0:f4D02]Pe420:b2DPP0[hIB
202]Q5030:^2CP<0[8=?0P2]Q5080:b3C`80ZX5;0P2[PT`20:b3C@80[HA>2P2]Q5040:b3C`H0Zh9>
0`2/Pdl20:f4D0030:b3C`2[PTh0Zh9>0080Zh9>0`2/Pdl80:f2C@P0[8==0P2]Q5020:b3C`80Zh9>
0P2ZPDd00`2]Q500[8=?0:^2CP020:Z1C@060:^2CP2]Q500[XEA0:f4D02[PTh0ZX5=0P2YP4`00`2Z
PDd0Zh9>0:f4D0020:f4C0040:f4CP2]Q500[HA@0:f3D@80[H=C202/PDX20:^0B`80[85<0P2]PTd2
0:j3CP80Zh9>1P2/Pdl80:^2C080[85:00@0[85<0:b1CP2/PDh0[81?0P2/P5430:f2C`030:b1CP2[
P4d0Zh1=0080ZWm<0P2YOT/30:YoC0<0Zh1=202ZP4h00`2ZPDd0Zh9>0:^2CP020:b3C`80[HA@00@0
[XEA0:f4D02]Q500[8=?1@2[PTh00`2ZPDd0Zh9>0:^2CP050:^2CP030:Z1C@2YP4`0ZH1<0080ZX5=
0P2[PTh:0:b3C`P0[H9=202[PTh40:V0C0@0Z7m;602/Pdl00`2[PTh0ZX5=0:Z1C@020:V0C080Z7m;
00@0Ygi:0:YnC`2ZOTl0ZWi=0P2ZOd`00`2ZOdX0ZWm80:YoB0080:QoB`<0ZX5;0`2YP4X20:QoB@<0
ZH1:0P2XOdT30:MnB0060:AjB02UNdT0YWa:0:MmB`2YOdd0ZX1>0P2/PU080:V0BP0@0:ImA@2WOTH0
Z7m90:V0C02ZPDd0ZGm=0:MmC@2VO4`0YGa80:ImB@2WOTX0Z7m;0:V0C02XOd/0YWe90:ElB080Z7e8
0`2YOTT30:YoBP80ZH1<00D0Z7m;0:MnBP2WOTX0Ygi:0:ImB@020:ElB0P0YW]600<0YGa80:MnBP2X
Od/00P2YP4`00`2WOTX0YGa80:=jAP080:9iA@040:9d@`2SMD@0YGM60:MiB080Z7Y900<0YgU80:Ih
A`2SN4D0102TNDH30:EjA`80X7M300@0XGQ40:9iA@2TNdL0YGa80P2VODT00`2VO4`0YG];0:=iA`02
0:5hA0030:5h@P2RND40XgY200P0XWU50P2SNDL20:9hAP80XGM50P2PMT@309me@`030:1fA02QMdD0
XGM50080XWQ60P2TNdL0102SNTH0XWU50:9iA@2QN4@20:1g@`P0XgQ50`2OMDD209idA0<0WgE5202R
NDD0102SN4D0Y7U60:AiAP2TNDH20:EjA`80YW]80P2RODH00`2QO4L0X7]709miB00209ihB@0709eg
BP2JL400Vg5109ec@@2OMT80XGQ40:9i@`020:=j@P@0XGM5102PMT@709mf@P80X7M3102PMT@50:5g
A@0:0:1fA02NM480WG=109id@P2OMD<0X7I40:5gA@2QN4@0WgI209ac?`80VW4m00<0Vg8n09ed@02O
MT800`2NM4800`2MLd40W79009ab@00209]a?`0609ec@@2LLT00W79009]a?`2JL3h0VFlm0P2HKS`8
09Y`?P0809Q^?02JL3h0W79009ab@02KLCl0VFlm09I/>P2DJSP309]a?`80W7900`2MLd400`2KLCl0
VW0n09Q^?00209M]>`0309Q^?02JL3h0Vg4o00<0VVm20`2IKT4209Q]@080VVm200@0V6e009M/?`2E
JSd0U6Tl0P2BIcX209I]=`0309I]>@2FK3X0UV`l0080UV/n00<0UV]009I/>P2FK3X01P2FK3X0102?
IC<0TVPf09E[>@2HKS`209U_?@0309M]>`2FK3X0UV/n00L0UV/n00<0Tfdn099/?@2BK3d0102BK3d0
2@2CKCh0Uf`o09Q]@02JKd80Vg1309U^@@2GK3l0U6Tl095V>@0208eW=P0308iX>@2?JC`0T6Tn0080
TFY100H0TFY309=X?P2CJ3h0TfPm09=X>`2CJCT309=Y=`0309=Z=P2DJC`0U6Tl00@0TVLj0P2DJC`8
099W?0<0SVPi0`2=IcP208aV=`P0SF8g0P2<IST00`2=IcX0SVPk08iX>`0308iX>`05095[?P2@JSd0
T6Xk08mY>P2>J3T00P2=IcH00`2<ISD0Sf@j08mT>P0208mT>P04091U>`2AIS`0TFHl099W?@P0S6Lj
00@0RF<f08]U>02=IcX0T6Xm0`2AJch0102@JSd0U6e409A]A02DKD@[ooooo`00:_ooool808=N=080
QUlf0P25GSD208AM=080Pe`c1@26H3<308MQ=0P0R64h202<HCH00`2:GSL0Relh08eQ>P0208eQ>P03
08]O>02:GSL0R5`e00P0Relh00<0Rf0e08aQ=P2=HSL00P2>HcP01P2=HSL0S64f08]P=@2;H3D0S64f
08iS>0<0Sf@i0P2>HcP00`2;ICP0RV@g08US=P0308US=P0408]U>02=IcX0SVPk08mS?P80SV8k00<0
SF8h08iS>02?I3L00P2AIcL01P2CJ3d0TVLl099W?02AIS/0T6Dj08mT>@80SV<h00<0SV8e08mS=P2A
ICP00`2CIcX01@2BIST0TFDh09IU>P2EI3T0U6<h0080TV4f00<0U6<h09ET>@2FICX00P2>HcP208mT
>@80T6Dj0P2AIS/2099W?00409=X?@2DJCh0U6Tn09EZ?`80UV]0102HJd4409MZ@080UV/n00@0UFXm
09AY?02DJC`0TfPk0P2BIcX00`2HK3l0Uf/n09IZ?@0209AX>`0;09IZ?@2GJch0V6`o09Q]>02GK3L0
UV/h09AX=`2DJ3T0UVXm09M[?P2HJd400`2FJSd209EY?0<0UVXm0P2EJSd209I[?P80Uf`o0P2HKD03
09Q/>`<0VFdl0P2JKSd209U^>@0309U^>`2JKSd0VVho0080Vfm200<0Vfi409a`?`2LL3l01P2LL3l4
09aaA00<09]`@`2JKd80VVm209U^@@2JKSl0VFdn09U]?02HKCX0VFhk09]`>`2MLS/0Wg@m0`2MLSl2
09ic@0<0WgA12@2KL4<02`2NLd00WG8o09aa?P2LLCh0WG8o09md@@2QMT<0XgQ50:1fA02NM480Vg4o
0080VFlm00<0VW0n09ab@02NM4800`2NLT4209mc@P<0X7A3202PMD880:9gA0<0XgQ50P2RMd@30:5f
@`060:Id@`2TM4<0Y7A30:=e@`2QMT<0X7M30P2OMd<0202RMd@0XgQ50:AiAP2UNTL0YW]80:MlB@2X
ODX0ZGi;202XNDD80:EjA@030:QmBP2WO4T0YW]80080YGY700<0YW]80:MlB@2XODX0202WO4L20:Un
B@<0Z7e80`2WO4L00`2VNdP0Yga90:QmBP020:UnB`030:QmBP2WO4T0YW]800P0Zh1=00P0Zh1;0:Yo
BP2YOTT0Z7e80:UnB@2ZOdX0[85<0:f2C@P0[8=?202]PTl01P2[PDl0[89@0:f3D@2^Q580[H=A0:b2
D080ZX1>00<0ZGm=0:f2C@2]PTd01P2]PTd20:^2CP<0ZX5=0`2YP4`20:b0C`030:b1CP2/PD`0[85:
0080[89800<0[8960:YoBP2ZOdX00P2[P4/20:b1C080[H9=0P2[PTh20:b3C`80[HA@0P2^QE401P2W
Q4`0Z8=<0:R3C02ZPd`0Zh9<0:b1C080[X1<0P2ZOdX20:^0B`80[85<0P2]PTd30:b1C080Zh1;0`2Z
OdX00`2/PD`0Zh1;0:YoBP030:YoBP040:^0B`2/PD`0[7e50:amA@<0[Gi60`2^OdL00`2ZOdX0Zh1;
0:b1C0020:f2C@030:^0B`2YOTT0Z7e800<0Z7e80P2YOTT30:YoBP040:^0B`2ZOdX0ZWm:0:YoBP@0
ZGi90`2[P4d30:YoC080ZGi;0P2XOT`30:UoC@<0ZX1>00<0ZWm:0:UnB@2XODP00P2WO4L00`2XODP0
ZGi90:YoBP080:UoC@80Zh1;0P2ZOdX30:UnB@030:QmB02WOTX0Ygi:00L0Ygi:0P2YOT/01P2XODX0
ZGi;0:UnB`2[P4d0[H9?0:j3D0P0ZWm<402YP4`80:YoC0P0[85<0`2[P4/30:YoBP80ZGi90P2[P4d3
0:b1CP<0[H9?0`2ZPD/30:V0BP80Z7m92`2ZPDd20:^2CP<0[8=?00<0Zh9>0:b3C`2]Q5000`2^QE42
0:f4D0<0[H9=0P2^Pdh30:n4C`<0[XEA0P2]Q5030:b3C`P0[X=@0P2`QUH0102`QU@0[hIB0:n6DP2^
QDl20:j5C@80[HA@0`2^QE430:n6DPP0[hAA202^QE430;68E080/8MC0P2_QU820:j5D@050;:9E@2a
R5@0/HQD0;27D`2_QU800P2^QE401`2]Q500/XMB0;66D@2aQU40/8E@0:n4C`2^Pdh00P2]PTd80;68
E080/XUE0`2aR5@30;27D`P0[hEC102bRED40;68E0<0/8MC0`2aR5@20;:9E@80[hYF0`2^RED30:f8
E0<0/HME0P2bR5H30;>9E`80/XUA00@0/HQB0;68E02aR5@0/8ID0P2`QUH30:f8E0<0[XUE0P2_RUH2
0;27D`80/HQD0`2bRED01P2cRUH0/8MC0;27D`2bRED0/hYF0;B;E`80/hYF00<0/XUE0:n:EP2_RUH0
1P2_RUH01@2aR5@0/XUE0;:9E@2cRUH0]8]G0080]HaH00@0]XeI0;>>F@2aS5L0/8]F0`2^RE@00`2`
ReH0/HaG0;>:EP0:0;>:EP80/XUE0`2aR5@40;>9E`80/XQF0`2aQeD20;>9E`030;>:EP2cRU@0/hYB
0080/h]@00@0/h]>0;:9E@2cRUH0]HaH0P2fSET01P2eS5P0/hYF0;:9E@2`QUH0/HMG0;>9E`80]8]G
00<0/hYD0;68D02`Qdl00P2^RU00102^RE80[XUD0:j9E02^RED20:j8E`80]8YH00H0]8]G0;B;E@2d
Re<0/h]@0;::C`2bRTd20;:7E0<0/hQE00<0/XMD0;25DP2_Q540202`Qe420:j5D@040:n6DP2`Qe<0
/8MC0:n6DP80[XEA00P0/HQB0:n6D02/Pdd0ZX5;0:V0BP2ZPD/0[HA>0:j5C`P0ZHA?202]Q5020:f4
C0040:f4CP2]Q500[HA@0:f3D@80[H=C402]Q5030:^2CP<0[8=?0P2]Q5080:b3C`80Zh9<0P2/Pdd0
102]Q4h0[XE?0:n6D02_QU0:0:f4D0@0[8=?1P2[PTh30:b3C`80[HA@0P2[PTh30:Z1C@030:^2CP2]
Q500[HA@00P0[H9=202/Pdd30:b3C`80Zh9>0`2ZPDd20:b3C`<0ZX5=00H0[8=?0:f4D02_QU80[HA@
0:b3C`2ZPDd20:V0C0030:Z1C@2/Pdl0[HA@0080[HA<00@0[HA>0:f4D02]Q500[H=A0P2]Pe<80:b2
B080ZWm:00@0Zh1;0:b1C02]PTd0[H9=0P2^Pdh30:^2CP<0[8=?0P2]Q5080:^2C080[85:00@0[85<
0:b1CP2/PDh0[81?0P2/P5420:j3D080[H9?00@0[85>0:^0C@2ZOd`0ZWm<0P2YOT/30:YoC0<0Zh1=
202ZP4h20:Z1C@030:^2CP2/Pdl0[HA@0080[XEA00@0[hIB0:j5D@2]Q500Zh9>0`2ZPDd20:^2CP03
0:Z1C@2[PTh0[8=?00@0[8=?00@0Zh9>0:Z1C@2YP4`0ZH1<0P2ZPDd20:^2CPX0[8=?202]PTl80:^2
CP<0ZX5=0P2YP4`30:QoBa00Zh9>202/Pdl20:^2C0030:Z1B`2YP4X0Z7m90080Ygi800@0YWe70:Yn
C`2ZOTl0ZWi=0P2ZOd`00`2ZOdX0ZWm80:YoB0080:QoB`<0ZX5;0`2YP4X20:QoB@<0ZH1:0P2XOdT3
0:MnB0050:EkB@2VO4X0Yge;0:QnC02YOdd00P2[PDl00`2/PU00ZX5;0:V0BP020:V0BP<0Z7m900@0
Ygi80:Ak@`2VODD0Ygi80P2YP4`0302YOdd0Yge=0:MmC@2TNdL0YGa80:MnBP2XOd/0ZH1<0:QoB`2W
OTX0YWe90:QmB0<0ZGi90P2ZOdX20:^0B`040:Z1C@2YP4`0ZH1<0:QoB`80Ygi:00<0YWe90:ElB02U
O4P0202VNdH0202UO4P0YWe90:QoB`2ZPDd0ZH1<0:MnBP2TNdL0XWU5202RND<00`2TM4@0YGE50:Mg
A`020:UiB@030:QhB02WMdL0YWI600P0YGY70P2QN480102RND<0XgY40:=jA02TNdD20:ElAP080:Ek
B`2TNTX0XWQ60:5hA02PMd<0XGQ20:9i@@2SNT880:9iA@<0XWQ60P2QMdD30:1fA080WWA20P2OMD<0
102PMT@0XGM50:9hAP2RN4H40:=jAP<0XWU500<0XGQ40:9gA02RMd@01P2RMd@00`2QMTT0X7E809md
A`0209icAP0309mdA`2PMDP0XGI900P0XGQ40P2RMd820:=h@`80Y7U40P2UNTD20:9mAP030:5lA`2P
NdL0WgU80080WWQ900X0WGM:09]a@@2LLT80WWA20:1g@`2QN4@0XWU30:9i@@2QN400XWQ60`2QMdD3
0:1fA00309me@`2OMT80WgI200<0WWE10P2OMT800`2QN4@0XWU50:1g@`030:1g@`@0XGQ400d0X7I4
09me@`2NM480WG=109id@P2OMD<0XGM50:9hAP2OMT80WWE109ed@02LLcl0Vg8n0080W7<o00H0WGA0
09me@`2OMD<0WWA209ec@@2LLT0209]a?`0709Y`?P2MLd40W79009ab@02KLCl0VW0n09U_?@0209Q^
?0P0VW4m00P0VW0n09]a?`2KLCl0Vg4o09Y`?P2HKS`0UV`j09E[>@<0VW0n0P2KLCl309ab@00309]a
?`2JL3h0V6hl0080Ufdk00<0V6hl09Y`?P2KLCl00P2KL4<209Y_@P<0VFi100L0V6e009]`@`2KL4<0
VFi109Q]@02FJch0UFXm0080TfPk0P2FKCL00`2FKCT0Ufdk09M]?@0209Q]@00309Q]@P2FK3X0UV`j
00H0UV`j00@0TfTg09AZ>02FK3X0Ufdk102HKS`809I[?P0309A^?`2CKCh0TV`m0080TF/l00<0TV`m
09=]?P2DKSl00P2GK3l209Q]@00<09M/?`2EJSd0U6Tl09=X>`2?JCP0T6Xi095[?02BK3l0TV]0099[
@P2AJT40TFY30P2CJ3h00`2CJ3d0TfPk09=Y>@0309=Y=`0309=Z=P2DJC`0U6Tl00@0TfPk0P2DJC`8
099W?0<0SVPi0`2=IcP208aV=`P0SV<f00<0RfDh08aV>@2>J3/00`2?JC`208iX>`0909=/@@2BJd00
TF/n08mY>P2>J3L0S6Lc08]V<P2:IC00T6@m0080Sf<l0P2>HS/01P2@I3d0TFDn099V?`2=J3/0S6Lj
08]V>@80RVDh00/0RfHi08aW>P2=J3/0RF<f08]U>02?JC`0TF/n099/?`2AJch0SfTl08iX>`0309A]
A2_ooooo000Zooooo`P0P5dc0P26GcH208EN=@80Q5dd0P23G3<208EO<080QV0a00@0Qf4b08QR<`29
Hc@0RF<d2028HCP808aQ=P0308QL=@2:GSL0Relh00<0SF4j00<0Relh08YN=`2;GcP01`2;GcP00`2;
H3D0S64f08eR=`0208iS>00=08eR=`2<HCH0Rf0e08YO=02<HCH0SV<h08mT>@2@ICX0Sf@i08iS>02=
HSL0RfDh08YT=`0408US=P0<08]U>02=IcX0SVPk091T?`2?Hc`0SV8k08eR>02=HSL0Sf@g095W=`2B
J3P0TfPm0P2BIc`00`2AIS/0T6Dj08mT>@0208iS>00308iR=@2?HcH0TFDh00<0TfLj00D0TVHi095U
>02FICX0UF@i09AS>002099Q=P0309AS>02EI3T0UVDj00<0T6Dj0P2AIS/3099W?0P0U6Tn00D0VVe3
09U/@P2IK480V6]109MZ@00209IY?`0309EX?P2DJC`0U6Tl00H0U6Tl00<0V6`o09M[?P2FJSd00P2D
J3/02`2FJSd0Uf/n09Q/?`2HKCP0Uf`g09I[>02DJ3L0U6Pi09IZ?@2GJch0V6]100P0U6Pk0P2EJSd2
09I[?P80Uf`o0P2HKD0209M[>P80V6`k00@0VFdl09Y^?@2JKSd0VVhm0P2KL3/00`2KL3d0VVhm09Y^
?`0209U]@00309U/@P2LL3l0W70o00H0W70o00<0WG9509aaA02LLD@00`2KL4<209Y_@P0809Y^?`2I
KC`0VFdl09U^>`2JKcX0W74j09id>P2PMS`309aa?P<0WG8o0P2NLd0909Y_@P0;09ic@02MLSl0W74n
09aa?P2NLd00X7E20:9gA02SN4D0XGM509me@`2KLCl00P2HKS`00`2IKcd0W79009id@P0309ib@@80
Wg=20`2PM4<80:1e@P/0XgQ500<0XWM40:5f@`2QMT<00P2PMD801P2WMD@0YGE40:EeA02TMT@0XWM4
0:5hA080X7Q40`2SN4D00`2TNDH0YGY70:EjA`020:IkB0P0Z7U5202UNTD00`2XODX0Yga90:IkB002
0:EjA`030:IkB02WO4T0Z7e:00P0Yga70`2YOTT00`2XODP0Yga70:MlA`020:IkAP030:IkB02WO4T0
ZGi;0080ZWm<00<0ZGi;0:MlB@2VNdP0202[P4d0202[P4T0ZWm80:UnA`2XODH0ZGi70:YoB02/PDX0
[H9;202/Pdl80:f2C`80[89B00@0[H=C0:j4E02]Pe<0[89B0P2ZP5000`2XOTh0[H9=0:f2C@060:f2
C@80Zh9>0P2ZPDd20:V0C080Z7m;0P2/P4l00`2/PDh0[85<0:b1BP020:b2B0030:b2AP2ZOdX0ZWm:
0080Zh1;0P2/PD`20:f2C@<0ZX5=0P2[PTh30:b3C`060:N4C02XPd`0Z8=<0:Z3C02[PT`0[85<0P2^
P4`20:YoB080Zh190P2/PDX20:f2B`80[H9=0P2/PD`0202[P4/0ZWm:0:YoBP2ZOdX0[hA?0:f2C@2[
P4/0ZGi90P2XODP00`2YOTT0ZWm:0:amA@020:amA@030:enAP2^OdL0[Wm70080[h1800<0ZGi90:Yo
BP2[P4/00`2]PTd00`2[P4/0ZWm:0:QmB0020:QmB080ZGi90`2ZOdX20:QmB0<0ZGi90`2ZOdX20:b1
CP80Zh1=00@0ZWm<0:UnB`2YOT/0ZGi;0`2XOTh00`2YOdl0ZX1@0:Z0D0020:^1D@030:YoBP2YOTT0
Yga70080YW]600<0Yga70:UnB@2ZOdX0202XOTh30:YoBP<0ZGi90P2XODP90:MnBP80ZGi;0P2XODX0
102YOT/0Zh1=0:f2C`2_Q5480:YoC0P0Z7m;202YP4`80:UnB`P0[H9;0`2[P4/30:YoBP80ZGi90P2[
P4d20:b1CP80[H9?0P2^Pe030:Z1B`<0ZH1:0P2XOdT<0:Z1C@80Zh9>0P2/Pdl00`2YP4`0Zh9>0:f4
D0030:n6DP030:j5D@2]Q500[H9=0080[H9=0P2^Pdh30:n4C`<0[XEA0P2]Q5030:b3C`P0[X=@0P2`
QUH0102`QU@0/8MC0:n6DP2_QU020:j5C@80[HA@0`2^QE430:n6DPP0[hAA202^QE430;68E080/8MC
0P2_QU820:j5D@80/XUE00@0/HQD0;27D`2_QU80[XEA0P2]Q5020;:7DP060;66D@2`QE00[hA?0:j3
CP2]PTd0[85<202aR5@30;27D`<0/HQD0P2bRED80:j4DP<0[hIB0P2`Qe<30;68E0<0/8MC0`2aR5@2
0;:9E@<0[hYF00<0[XUE0:f8E02]R5@00P2/Qe<30;67E@80/XQF0`2cREL20;27C`040;27D@2aR5@0
/HQD0;67E@80/XQH0`2]R5@30:j9E@80[hYF0`2`Qe<20;68E0<0/XUE00<0[hIB0;27D`2bRED00P2d
ReL00`2cRUH0/XUE0;68E0080:n:EPH0/XUE0P2cRUH0202_RUD0[XUD0:f8D`2/Qe80[HQC0:j9E02`
ReH0/HaG202bRED00`2dReL0/hYF0;>:EP020;:9E@80/HQD00<0/8MC0;>9F@2cRET00P2cRET20;:8
F0<0/HMG0P2aQeD00`2aR5@0/HQB0;68D0020;69CP040;69C02bRED0]8]G0;F<F080]XeI00H0]HaH
0;B;E`2bRED0/8IF0;67E`2cREL20;B;E`030;>:E02aR500/8M?0080[h]A00@0[hYC0:n:E@2_RUD0
[hYF0P2_REP20;F;F@030;B;E`2cRU@0/hYB0080/XY?00T0/XY=0;66D`2bQe@0/hQE0;B9EP2cR5D0
/XMD0;25DP2^Pe00102`Qe440;68DP030:f4D02^QE40/8MC0080/HQD00D0/8MC0:j5D@2]Q500[XE?
0:f4CP020:b3C@@0Zh9<202[QU480:f4D080[HA<00@0[HA>0:f4D02]Q500[H=A0P2]Pe<80:^2CPP0
[HA@0`2[PTh30:b3C`80[HA@202/Pdl20:b3C@060:f4CP2^QDl0[hI@0;27D@2aR580/XUC2P2]Q504
0:b3C`H0Zh9>0`2/Pdl20:f4D0080:^2CP2ZPDd0ZH1<0:QoB`2YP4`0Zh9>0:f4D02^QE480:f2C@P0
[8==0P2/Pdl20:^2CP@0ZX5=00<0[8=?0:^2CP2ZPDd00P2ZPDd01P2/Pdl0[XEA0:n6DP2]Q500[8=?
0:^2CP80ZX5=00<0Zh9>0:b3C`2]Q5000P2]Q4`0102]Q4h0[HA@0:f4D02]Pe420:f3D`P0[8980P2Y
OTT01P2ZOdX0Zh1;0:b1C02]PTd0[X=>0:n4C`80ZX5=0P2[PTh0102/Pdl0[HA@0:f4D02]Q5080:^2
C080[H9;00@0[H9=0:f2C`2]PTl0[H5@0P2]PE820:n4D@040:j3D02]PTl0[85>0:^0C@80ZWm<0P2Y
OT/30:YoC0<0Zh1=202YOdd20:Z1C@090:^2CP2/Pdl0[HA@0:j5D@2_QU80/8MC0:j5D@2]Q500Zh9>
00<0ZH1<00D0ZX5=0:^2CP2ZPDd0Zh9>0:b3C`030:f4D0030:b3C`2[PTh0ZX5=0080ZH1<0P2ZPDd2
0:^2CP80[8=?202]Q5080:f1D0P0Zh9>0P2/Pdl20:^2CP040:Z1C@2YP4`0ZH1<0:V0C100Zh9>202/
Pdl20:^2BP060:Z1B@2YP4P0Z7m70:MnAP2VODD0YGa40P2ZOTl0102ZOTd0ZWm<0:YoC02ZOdX20:Yo
B0P0Z7m;0`2ZPD/30:V0BP80Z7m90`2YP4X20:QoB@<0Ygi80P2WOD/0102XOT`0ZGm=0:UoC@2ZP4h2
0:^1C`80ZX5;0P2YP4X04P2XOdT0Ygi80:MnB02WOTP0Y7]30:ElA02WOTP0Z7m;0:V0C02YOdd0Z7i>
0:MmC@2SNTH0YGa80:MnBP2XOd/0ZH1<0:QoB`80Ygi:0`2YOTT20:YoBP<0Zh1;0P2ZPDd0102YP4`0
Z7m;0:MnBP2WOTX20:ImB@030:ElB02VNdH0YW]600H0YW]600P0XgY60:ElB02XOd/0ZX5=0:V0C02V
ODT0XgY60:5hA0P0XWU100<0YWI60:MgA`2XN4P00P2YNDT00`2WMdL0YGE50:AdA0080:EjA`P0XgY2
00<0YG];0:AjBP2RN4H00P2PMd<00`2QN480XWU10:=j@P080:=jAP80XWQ60P2QMdD40:1fA080WG=1
00@0WWA209me@`2PMT@0XGM50P2RN4H30:9iA@<0XgY60P2TNdL80:9gA0030:=hB`2RMdX0X7E80080
WgA700<0X7E80:9gBP2SN4/0202QN4@30:5f?`80XWM00`2SN4420:5lA@030:1kAP2ONTH0WWQ70080
WGM800@0W7I909ab@P2MLd<0WgE30P2QN4@00`2QN480X7Lo09mf?P020:9hAP80XGM50P2PMT@209me
@`050:1g@`2OMT80WWE109ed@02NMD400P2OMT800`2QN4@0XgY60:5h@P030:5h@P@0X7M10P2OMD<0
1P2NM480WG=109id@P2OMD<0XGM50:=iA`80WGA00`2NMD402@2MM400Vg8n09Ya?@2PMT@0WgE309id
@P2MLd40W79009]a?`0209Y`?P0609ec@@2LLT00W79009]a?`2JL3h0VFlm0P2HKS`809Ya>`0409ec
@@2LLT00VW0n09Q^?0<0Ufdk0`2HKS`209U_?@80VW0n0`2KLCl01`2JL3h0V6hl09M]>`2GKC/0V6hl
09Y`?P2KLCl00`2KL4<209Y_@P<0VFi10P2LLD@0102KL4<0VFi109Q]@02FJch209EZ?@80Ufhh00H0
V6lk09Q^?02IKcl0VFi109Y_@P2JKd@809I/>P80V6hl00H0Ufdk09I/>P2FK3X0Ufdk09Q^?02IKcd8
09I[?P0309A^?`2CKCh0TF/l0080T6Xk00<0TF/l09=]?P2DKSl00P2FJch00`2DJC`0TfPk09=X>`02
09AY?00909EZ?@2BK3/0Tfdl09A^?`2EKd80UFi309=/@`2AJT40T6U20080TfPn00<0TfPm09=X>`2C
JCT00`2CJCL00`2CJSH0U6Tl09AY?00609AY?0P0TfPm0`2>J3T308eW>080S6Hg202@ISH00`2;ICP0
S6Hi08iX>`03091Z?@0808mY?02>J3/0SfQ108mX?`2?J3d0SfTl08iX=`2>JCD208iY<P03099V?`2@
I3d0Sf<l0080SF4j00H0SV8k091T?@2AICh0SFPk08aW>P2:ICP208UT=`0608YU>02<IcX0SFPk08]U
>02=IcX0T6Xm0P2BK3l00`2@JSd0SFLj08]U>00309=/@b_ooooo000Zooooo`P0P5dc0P26GcH208EN
=@80Q5dd0P23G3<208AN;`0408EO<026H340R68c08US=080RV@e2028HCP808aQ=P0308MK=029GCH0
Relh00<0SF4j0P2<H3T808]O>00308YO=02<HCH0SF8g0080Sf@i00H0SF8g08aQ=P2:Gc@0RUld08]P
=@2>HcP3091U>P0408iS>02=HSL0RfDh08YT=`@0RF<f00`0RfDh08eW>P2>J3/0T6@o08mS?02=HCX0
SF8h08eR=`2?I3L0TFLg099X>02CJ3d2099W?003095V>`2@ICX0Sf@i0080SV<h00<0SV8e08mS=P2A
ICP00`2CIcX01@2BIST0TFDh09IU>P2EI3T0U6<h0080TV4f00<0U6<h09ET>@2FICX00`2AIS/2099W
?0<0TfPm0`2EJSl209AY?P<0TfPm00P0Vfi409Y]@`2IK480V6]109MZ@02FJCl0UFPn09AW?@<0TfPk
0P2DJC`309EZ?@0309Q/?`2GJch0UVXm0080U6Pk00/0UVXm09M[?P2HK3l0V6dh09M/=`2FJcP0U6Pg
09AX>@2FJSd0Uf/n09Q[@@0309=W>P80U6Pk0`2CIcX209EZ?@80UV/n0P2GK3l209Q]@080Uf/j0P2H
K3/0102IKC`0VVhm09Y^?@2KKch209aa?00609]`?@2JKSd0VVho09U]@02HK3l0V6]1202LL3l209eb
A@0309aaA02KL4<0Vg1300<0Vg1300P0VVhm09U]?02IKS/0VFhi09Y_>02LLCX0WgDk0:1f?0<0Vg0m
0P2LLCh309eb?`T0VVm20100WW=009eb?`2LLCh0WG8o09ic@02PMD80XWM40:AiAP2QMdD0WgE309]a
?`2HKS`0Ufdk09U_?@2LLT00WWA20`2NLT4209mc@P<0X7A3202PMD8;0:=hA@030:9gA02QMT<0X7E2
0080X7E200H0Z7I50:IfA@2VMTD0YGM50:=hA@2RNDD20:5iA@D0XgQ50`2TNDH80:QiA@P0YGY500<0
ZGi;0:MlB@2VNdP00P2TNDH00`2VNdP0Yga90:UnB`080:MlA`040:YoBP2YOTT0ZGi90:QmB080Yga7
0P2VNdH00`2VNdP0Yga90:UnB`020:YoC0030:UnB`2WO4T0YW]800P0Zh1=00P0Zh190:YoB02YOTL0
Z7e60:UnA`2ZOdP0[85:0:f2B`P0[8=?202]PTl01P2/PU80[H=C0:j4E02^Q5@0[H=C0:^1D@80ZGm?
00<0Z7i>0:f2C@2]PTd01P2]PTd20:^2CP80ZX5=00@0ZH1<0:QoB`2XOd/0Ygi:0P2/P4l00`2/PDh0
[85<0:b1BP020:b2B0030:b2AP2ZOdX0ZWm:0080Zh1;0P2/PD`20:f2C@<0ZH1<0P2ZPDd30:^2CP06
0:N4C02XPd`0Z8=<0:Z3C02[PT`0[85<0P2^P4`20:YoB080Zh190P2/PDX20:f2B`<0[H9=00<0[85<
0:^0B`2ZOdX00P2ZOdX0102aQU40[hA?0:b1C02YOTT20:MlA`80Z7e800@0Zge20:an@`2/OT<0[Gm4
0P2^P4D20:n1AP050:MlA`2YOTT0Zh1;0:f2C@2^Pdh00P2]PTd0102/PD`0Z7e80:QmB02XODP20:Un
B@<0ZWm:0P2WO4L0102XODP0ZGi90:UnB@2ZOdX20:^0B`80[85>0P2[P4d01@2ZOd`0ZGi;0:UnB`2X
ODX0Yge=0080Z7i>00<0ZGm?0:Z0D02ZP5000P2[PE400`2ZOdX0ZGi90:MlA`020:IkAP030:MlA`2Y
OTT0ZWm:00P0Z7i>0`2ZOdX20:UnB@<0Z7e82@2WOTX20:UnB`060:QmBP2WO4T0ZGi;0:^0C@2^Pe00
/8EB202ZOd`80:QoB`P0ZH1<202YOT/80:f2B`<0Zh1;0`2ZOdX20:UnB@80Zh1=0P2/PDh0102]PTl0
[X=@0:j3D02_Q5430:Z1B`<0ZH1:0P2XOdT80:Z1C@040:V0C02ZPDd0ZX5=0:Z1C@80Zh9>0P2/Pdl0
202YP4`0ZX5=0:f4D02_QU80/8MC0:n6DP2^QE40[HA@0`2]PTd20:j3CP<0[hA?0`2^QE420:f4D0<0
[8=?202^Pe001P2aQeL0/8IF0;26E02`Qe<0[hIB0:n6D080[XE=0P2]Q5030:j5D@<0[hIB202_Q548
0:j5D@<0/HQD0P2`Qe<20:n6DP80[XEA00P0/hYF0;:9E@2aR5@0/8MC0:n6DP2^QE40[HA@0:b3C`80
/XMB00<0/HIA0;25D02_Q4l00P2]PTd00`2/PD`0/HQD0;68E0060;68E0060:j5D@2_QU80[hIB0;27
D`2aR5@0/XUE0P2cRUH80:j4DP80[HA@00@0[XEA0:n6DP2_QU80/8MC0P2aR5@30;27D`<0/HQD0P2b
RED0102`ReL0[hYF0:n:EP2^RED20:f8E080[8MC0`2aQeD20;:8EP<0/hUG00H0[XE=0:n6CP2_QU00
/8MC0;68E02bR5H20;>9F@<0[HQD0`2^RED20:n:EP<0/8MC0`2aR5@20;:9E@030:n6DP2`Qe<0/XUE
00<0]8]G00<0/XUE0;68E02_RUH01`2_RUH40;:9E@<0/HQD00<0/8MC0:f8D`2/Qe800P2[QU40102/
Qe80[XUD0;2;EP2aS5L80;:9E@80]8]G00@0/hYF0;:9E@2bRED0/HQD0P2`Qe<40;>9F@80/XQH0`2a
QeL20;26E0030;27D`2`Qe40/8M?0080/8Q=00@0/8Q;0;>:EP2dReL0]HaH0P2fSET01P2eS5P0]8]G
0;>:EP2`QUH0/HMG0;>9E`80]8]G00<0/hYD0;68D02`Qdl00P2_Re40102_RU<0[hYE0:n:E@2_RUH2
0:n9F0050;J<FP2eReT0]8]G0;>:E02bRE400P2bRTl00`2bRTd0/HIC0;:7E0030;B9EP030;:7E02_
Q540[X=@00<0/8MA1@2aR5800`2]Q500[hIB0;27D`020;:9E@030;27D`2_QU80[HA@0080[8==0`2]
Q4h00`2/Pdd0ZX5;0:V0BP080:b7DPP0[HA@0P2/Pd/0102]Q4h0[HA@0:f4D02]Pe420:j4E0P0ZX5=
202]Q5030:^2CP<0[8=?0P2]Q5080:b3C`80[HA>00@0[XE?0:n6D02aR580/XUC0P2cRU@:0:f4D0@0
[8=?1P2[PTh30:b3C`80[HA@00P0Zh9>0:Z1C@2YP4`0Z7m;0:V0C02[PTh0[HA@0:n6DPP0[H9=202/
Pdd20:b3C`80Zh9>0`2ZPDd00`2YP4`0[8=?0:^2CP030:Z1C@060:b3C`2^QE40[hIB0:j5D@2/Pdl0
Zh9>0P2ZPDd00`2[PTh0[8=?0:j5D@020:f4C0040:f4CP2]Q500[HA@0:f3D@80[H=C202/PTH0202X
ODP0ZGi90:YoBP2[P4/0[85<0:f2C@2^Pdh0[hA?0P2ZPDd20:^2CP040:b3C`2]Q500[HA@0:j5D@P0
Zh9<0P2]PT/0102]PTd0[H9?0:f2C`2]PE020:f1DP060;25DP2_Q540[X=@0:f2C`2/PDh0Zh1=0P2Z
Od`20:UnB`<0ZWm<0`2[P4d80:UoC@80ZX5=00@0Zh9>0:b3C`2^QE40[hIB0P2`Qe<02`2^QE40[8=?
0:Z1C@2YP4`0Z7m;0:V0C02ZPDd0[8=?0:V0C02[PTh0[HA@00<0[XEA00<0[HA@0:^2CP2YP4`00P2Y
P4`20:Z1C@80Zh9>0P2/Pdl80:f4D0P0[H5@202[PTh20:f4D0040:b3C`2[PTh0Zh9>0:Z1C@80ZH1<
402[PTh80:b3C`80Zh9:00@0ZX590:V0B02WOTH0YWe50P2UO4@20:YnC`040:YnC@2ZOd`0ZWm<0:Yo
BP80ZWm8202XOd/30:Z1B`<0ZH1:0P2XOdT30:V0BP80Z7m90`2WOTP20:QnC0<0ZGm=0`2ZP4h20:Z1
B`040:V0BP2XOdT0Z7m90:MnB080YWe700`0XgY20:Ak@`2VODL0Z7m;0:V0C02YOdd0Z7i>0:MmC@2S
NTH0Y7]70:ImB@2XOd/20:V0C0040:QoB`2WOTX0ZGi90:UnB@<0ZWm:0`2[P4/20:Z1C@030:V0C02X
Od/0Ygi:0080Ygi:0P2VODT80:IkAP030:9iA@2TNdL0Ygi:0080ZH1<00<0YWe90:9iA@2PMd<0202R
ND40202YMTL0ZWM80:]hB@2[N4T0ZWM80:QeAP2VLd@0YG930`2VNdP50:EjA`<0Y7]30P2SNT830:9i
@@030:EkB`2TNTX0XWQ60080X7M300<0X7M10:5h@02RND40202SNTH20:9hAP80XGM50`2PMT@01`2O
MD<0W79009ec@@2NM480WgE30:1fA02QMdD00P2RN4H20:5hA0040:9iA@2SNTH0XgY60:AkA`80YGa8
202RMd@00`2UNTl0XgQ=0:5fB`020:1eBP030:5fB`2SN4d0YGY?00P0XGQ40`2PMCh20:5f?`<0XWM0
0100XGa50:1kA02PNdH0WgY609ihA`2MMdP0W7I709afB@2MLd<0WWA40:1fA02QN4@0XWU50:1g@@2N
MCd0WG@l0`2RN4H00`2QMdD0X7I409me@`0209me@`030:1g@`2OMT80WGA00080WGA00P2OMT800`2R
NDD0XgY60:5h@P030:5h@P@0X7M10140WgE309id@P2MLd40WG=109id@P2PMT@0XWQ60:=iA`2KLSh0
WGA009mf@P2PMd<0WgI209ed@02JLCd0VG0l0:1fA00209me@`0309ec@@2LLT00Vg4o0080VW0n00H0
WG=109ab@02LLT00Vg4o09Y`?P2IKcd209Q^?0P0VW4k00@0WWA209ab@02IKcd0Ufdk0P2FK3X0102H
KS`0VW0n09M]>`2GKC/209Q^?0<0VFlm00@0VW0n09]a?`2JL3h0V6hl0P2GKC/00`2HKS`0VW0n09]a
?`0309]`@`<0VVm20P2IKT4209aaA00409]`@`2JKd80VFi109Q]@080Uf`o0P2HKcT00`2HKc/0VFlm
09Y`@00209]`@`0309]`A@2FK3X0UV`j00H0UV`j00<0W79009Y`?P2GKC/00P2EJcT00`2FK3X0V6hl
09Y`?P0809I[?P0309A^?`2CKCh0TF/l0080T6Xk01<0TF/l09=]?P2DKSl0UV/n09AY?02BIcX0T6Dh
095V>@2BIcX0UFXm09M/?`2DKSd0UFln09I`@@2GLD@0UVm409A]A02AJT40T6U20080TfPn00<0TfPm
09=X>`2CJCT00`2CJCL00`2CJSH0U6Tl09AY?00609AY?0P0TfPm0`2>J3T308eW>080S6Hg202AIcL0
6`2;ICP0SFLj08mY?02@JSd0TF/n091Z?@2?JC`0SFLj08]T?@2<ICh0SFHk08iX>`2?JCP0T6/f095/
=@2BKS@0TfM2095U@02?Hch0SF4l08aP>`2=HC`0Sf<n091T?`2=J3/0S6Lj08YU>00208UT=`0;08YU
>02<IcX0SFPk08]U>02>J3/0TF/n09=]@02BK3l0T6Xm08aV>@29HcH00`2CK4<[ooooo`00:_ooool5
08=L<`<0Q5dd00<0QEhe08AM=023G3<00P21FS400`23G3<0Q5dd08EN=@0208=L<`80Q5dd0P25GSD2
08IO=P0808AM=025GSD0Qf0g08UR>@2:HcX0RF8i08MP=`26GcH808YN=`0308aP>@2;GcP0REdf0080
R5`e00<0REdf08]O>02<H3T0202;H3D00`2:Gc@0S64f08eR=`0208mT>@0308eR=`2<HCH0RUld0080
TVPh0`2AIcL3091V=PT0RV<j0P2?I3T3091U>P<0TFHk0P2DIcd0102BIC/0TF@j08mR>02>HCL208aO
=@<0TVDk0`2AI3X2091S>@0309AX>`2CIcX0TVHi0080TFDh00<0TVHi09=W>P2DJ3/00P2AICP2099V
>@80TfLj2P2DJ3/209IZ>`0309IZ?@2FJCl0UVU00080UVU200T0UVQ409]_@P2HK3l0TfLj08mS=P2>
HSD0T6@g09=W>P2EJC`00`2GJT4209Q[@P<0VFa300/0Vfm209Y^@@2IKD00V6`o09M[?P2FJSd0UFTl
09AX>`2IKT40Uf`o09EZ?@0209=X>`0509AY?02EJSd0UV/n09EYA02DJ4<00`2BIT400`2DJ4<0UVY5
09M[AP0309U]@080VVi10`2KKd8209Y^@@<0Vfm20`2LL4<02@2JLC/0Vg8l09ac?`2LLT00W79209Y_
@P2HKD00Ufa10:1d@`0209mc@P0309ib@@2MLD00WG500080W70o0`2IKC`209Y^?@<0Vfln0P2NJc`2
09m/?@090:1]?P2QKSl0XFho0:9_@02IK480VVi109]_@P2KKd00W70o0080WG8o0P2NLch309ea@0<0
WW910P2OLd801P2RMTD0XGE40:1d@`2OLd80WG5009]_?P80VVhm00P0X7E00:5f@@2RMd@0XgM60:9f
A`2PM4L0WW9509a_A@80X7E00P2QMT430:9g@P040:=h@`2PMD80XWM40:AiAP80YGY700<0Y7U60:9g
A02PMD800P2OM4420:1e@P@0XGI30`2UMDD30:IfAP80YgM7202PM4<80:EiBP040:^0C@2YOT/0Yga9
0:EjA`80Y7U600H0YW]80:MlB@2[NdX0Zg]:0:YjB@2YNDP20:QhA`80YgM6102WOD420:Qn@P80ZGm3
202XO4d01P2YOTT0ZGi70:UnA`2YOdD0ZGm30:V0@P80ZH10202YP4`20:b1BP040:b1C02/PDh0[85>
0:b0C`80[81A0100/h5@0:moCP2^OTd0Zge;0:UnB`2ZPDd0ZX9>0:b4D02`Qe<0[XEA0:b3C`2ZPDd0
ZH1<0:Z1C@2[PTh0[8=?0P2ZOTl20:]oD080[81A0`2]PE880:YoC0P0ZGe>0P2YOTT20:YoBP@0Zh1;
0`2ZP4h30:UoC@80Z7i<202XOd/@0:^2CP@0Zh1=0P2ZOd`20:UnB`050:QnC02YOdd0ZH1<0:Z1B`2[
PTX00P2/Q4T00`2]QDP0[8980:b2B0060:b2B0080:^0B`2/PD`0[H9=0:j3CP2]PTd0[85<0:YoBP2X
ODP80:UnBA00Z7e800<0Zgm>0:YnC@2XO4/00P2XO4/00`2ZOTd0[H5@0:j2D@080:V0C0<0Ygi:0P2X
Od/30:V0C0<0Zh1;0`2ZOdX20:UnB@<0Ygi:0P2XOd/40:V0C0D0ZWm:0`2[P4/20:UnB@<0ZWm:0`2[
P4/80:YoC0X0ZGi90`2ZOdX;0:^0B`80[X=>0`2]PTd30:b1C080ZH1<0P2ZPDd20:^2CP80[8=?0P2/
Pdd20:^2C080ZX5;0P2YP4X20:QoB`040:V0C02ZPDd0ZX5=0:^2CP80[8=?202]PTd80:f2C`<0[hAA
0P2^Pe0;0:f2C`<0[85>0`2]PTl20:j3D0080:n6D02^QDl0[8==0:Z1B`2YP4X0ZX5;0:b3C@2]Q4h8
0:j4E0P0[XEA0P2ZPD/0102[PT`0[8==0:j5C`2_QU020;27D@80[hI@00d0[XE?0:f4CP2/Pdd0[8==
0:j5C`2`Qe40/XUC0;B;E`2cRUH0/XUE0;68E02`Qe<0[hIB0080[XEA0`2/Q4L20:f5B0<0[XI90P2`
Qe<20:n6DP040:j5D@2]Q500[HA@0:b3C`80[HA@00H0[XEA0;27D`2bRED0/hYF0;B;E`2eS5P30:j5
D@80[HA@0`2/Pdl20:j4E0040:j4DP2_QU80/8MC0;68DP80/HQ@202aQeD00`2_QE<0/8ID0;:8EP02
0;>9E`030;:8EP2`QU@0[hEC00<0[8UC0`2]RU@20:j;E@80/XUE0`2cRUH30;B;E`P0/hYF0`2bRED0
0`2aR5@0/8MC0;27D`020:n6DP040;68E02bRED0/XUE0;>:EP80]8]G0P2eS5P00`2dReL0/hYF0;68
E0020;27D`060;68E02cRUH0]8]G0:j5D@2_QU80/HQD0P2bRED00`2aR5@0[hIB0:j5D@020;B6E003
0;:7E02aR5@0/8QD0080[XUD00@0[HYD0;27D`2`Qe<0/8MC0`2aR5@20;:9E@80/HeC00@0/8aB0:n;
D@2_Re40[XY@0P2]RDl30;F<F0040;B;E`2cRUH0/HQD0;27D`80[hIB00<0/hYF0;68E02^QE400P2/
Pdl00`2]Q500[hIB0;68E0030;>:EP80/XUE0`2aR5@20;26EP040;67E@2bRED0/XUE0;>:E080]8]C
00P0/HQD0;27D`2_QE<0[XAD0:n4E`2aQU/0/hQM0;F:H080/HaG00@0/8]F0:n:E@2_RUD0[XUD0P2]
R5<20;F8D@<0]8M@0`2cQTl80;27D@80[HA>0P2_QU00102^QDl0[8==0:Z1B`2XOdT20:^0B`80[85<
00@0[H9=0:j3CP2^Pdh0[hA?202^QE420:^2C0040:b3C@2]Q4h0[HA>0:j5C`80[hI@202/Pdd01P2^
Q4P0[XA:0:j4BP2^Pd`0[X=>0:j3D080[X9A00<0ZH1<0:^2CP2]Q5000P2_QU800`2]Q500Zh9>0:V0
C0030:b3C`80[HA@0`2^QE430:b3C@80[HA>0`2^QDl01P2aRD`0/8Q=0;28C@2`Qdl0[hI@0:n6DP80
[XAB00<0[hIB0:j5D@2/Pdl00P2[PTh00`2/Pdl0[XEA0:n6DP090:b3C`80[hI>00@0[XE=0:f4C02]
Q4`0[8=;0P2[PTX20:j3D0<0[H9?0`2/PDh80:f2C`030:N3D@2XQ580ZXID0080ZhME00<0ZXID0:R4
DP2WPe400P2/PU001P2[PTh0Zh9<0:Z1B@2ZPTL0ZH560:V1A080[XE=00@0[HA>0:f4D02]Q500[H=A
0P2/PU80202]Q4h0[8==0:^2C02[PT`0[8==0:f4CP2_QU00/HQB202/Pdd02`2_QdX0[XI;0:b4B@2Z
PDT0ZX5;0:Z1C@2[PDl0[89@0:j5D@2/Pdl0Zh9>0080ZX5=00<0Zh9>0:b3C`2^QE40202/Pdl80:V0
C0P0[HA@00H0[89@0:b2DP2/PU80Zh1C0:YoE02YOU@20:UmEP80[HA@0`2/Pdl30:^2CP080;68E02/
Pdl0Ygi:0:MnBP2ZPDd0[8=?0:^2CP2YP4`80:b3C`P0Zh9<00<0[8=;0:Z1B@2YP4X00P2XOd/03`2Y
P4`0ZX1>0:b2DP2^Q5@0[XEA0:f4D02/Pdl0Zh9>0:Z1C@2YP4`0Z7m;0:MnBP2ZPDd0Zh9>0:b3C`02
0:j5D@030:b3C`2[PTh0ZX5=00P0[8=?202[P5D80:^2CP80[81?00<0[85>0:b1C02/PDX00P2/PTP0
102/PTH0[8=;0:b3B`2/Pdd20:b3C`090:b2D02/PU80[89B0;66D`2`QE80[hAA0:j3D02/PDh0ZWm<
0080ZGi;00H0Z8130:R0A@2XP4D0Z7m70:QoB@2XOd/20:QnC0<0Ygi:0P2XOd/30:V0C0P0ZH1:0P2Z
PDT0102ZPD/0ZX5=0:V0C02YOdd20:QnCP060:Em@02UOD80YWi30:MnAP2YP4X0ZX5=0P2[PDl00`2X
ODP0Yga70:IkAP020:IkAP030:QmB02ZOdX0Zh1;00<0ZWi?00<0Zgm@0:b0D@2]PE800P2]PE80202/
PU80Zh5A0:UoC`2XOTh0Yge=0:QnCP2YOdl0ZX1@202WOTX20:ElB080YWe900D0Ygi:0:QoB`2XOd/0
ZH1<0:QoB@030:V0BP80Z7m900<0YWe70:=jA02RND<00P2TNdL20:ElB0<0YWe900T0Ygi:0:V0C02X
Od/0Ygi:0:ImB@2UO4P0Y7]70:=jAP2RNDD00P2NMCl0102PMd40XWU30:AkA@2VODL20:QoB@040:=h
@`2TND@0Y7U40:EjA@80YW]60P2WO4L80:9g@PP0XWM40P2TNDH30:=hA@<0XWM4202UO4@00`2UNDP0
Y7Q70:9fA@020:5eA0030:9fA@2TN4L0YGU80080WWA20P2OMD<40:1fA0030:Ag@02SMSl0XG@m0080
X7<l00<0XG@m0:=f?`2TMd002`2NNDD309mjAP80X7]70P2VO4X0102UNdT0Y7Y80:9hAP2QMdD20:1f
A0030:1g@`2RNDD0XgY60080Y7]700<0XgY60:9iA@2PMd<0202QN4@20:1kA`80WgY60140WWU509eh
A02LMd<0W7M30:9iA@2TNdL0YGa80:ImB@2UO4P0XgY60:5hA02OMT80XgY60:5hA02NMD40W7<o09]b
?P0209ac?`0409ed@02NMD40WgI209mf@P80X7M30`2QN4@20:9iA@070:5hA02OMT80WWE109ed@02N
MD40WgI20:1g@`0209mbB0<0WW570`2ML4H01P2IL3`0VFlm09Y`?P2JL400Vg1309]`A@80Vg16202J
LCT209]a?`<0W79000<0VW0n09Q^?02FK3X00P2LLD@0102KL4<0VVm209U^@@2HKD0209M/?`<0UFm0
0P2FL44309Ma@PP0VFi1202HKD0809Q^?080UV`j00@0Ufdk09Q^?02JL3h0Vg4o0P2LLT004`2DJ3/0
UFTl09Q/?`2JKT40Vfm209Y^@@2IKD00V6`o09I]>@2EK3P0U6/g09=Z=P2DJcL0UF`h09M^>P2HKc/0
TFHi09=X>`2EJSd00P2GK3l00`2EJSd0TfPk095V>@03091Z>`80TF/l0`2BK3d0202@ICP0TFHi09=X
>`2EJSd0Uf`o09U^@@2JKd80Vg130`2AJc`2091Z>`<0SfTj00<0UV]109AY?`2BIcd00P2AIS`0102C
J3h0UV]109I[@@2HKD<309I/>P<0UF/i0P2DJSP809EZ@080T6Xk0P2?JCX208iX>@80SFLh0P2<HC@0
102=HSD0SV<f091U>02AIST2099W>PP0UFXo00H0TfPm099W?02BIc`0TFHk091U>P2?I3T208iS>003
08eW>02<ISL0RfDf0080RV@e00l0RfDf08aV=`2=IcP0T6Xm08eW>P2;ICP0SFLj095[?P2CKD00TF/n
08iX>`29I3L0RVDh08aW>P2?JSd00P2@Jch208mZ?@<0TFa2:oooool002[ooooo1P23G3<208AM=003
08EN=@24GC@0Pe`c0080PEXa00<0Pe`c08AM=025GSD00P23G3<208AM=080QEhe0P26GcH00`24GC@0
QEhe08MP=`0308UR>@80Qf0g202:GSL00`2<H3T0Relh08UM=P0208QL=@0308UM=P2;GcP0S60i00P0
S64f00<0Rf0e08aQ=P2=HSL00P2>HcP00`2=HSL0S64f08]P=@02095W=`80T6Hf0`2?ICD00`2>I3@0
RV<j08YS>P0708YS>P80Sf@i0`2@ICX3095V>`0609=V?02BIC/0TVDk095T>P2@HcT0Sf8h0P2>HCL7
095T>P04099U>`2DJ3/0TfLj099V>@80TFDh00<0TVHi09=W>P2DJ3/00P2AICP2099V>@80TfLj2P2D
J3/209IZ>`0309IZ?@2FJCl0UVU00080UVU200@0UVQ409U]@02GJch0U6Pk0P2AICP00`2BIST0U6Pk
09IZ?@0209IY@0<0UfY10`2HJd801@2JKT40VFe009U]@02HK3l0Uf/n0080UVXm0180UFTl09Q]@02G
K3l0UFXm09AY?02CJ3/0U6Tl09EZ?@2FJch0UFU209AX@@2CId00TVHo09=W@02DJ440UVY309M[A02H
K3l309U]@080VVi10P2KKd8309Y^@@80Vfm20`2LL4<0202IL3X0VW4k09]b?P2LLT00W79209Y_@P2H
KD00Ufa10P2OLd8209ib@@0409ea@02LL3l0W70o09a`?`80VFdl0`2JKSd309]_?P80WFdm0P2NKSh0
1@2OKcl0X7100:1`@02PL400VVe30080Vfm200@0W71109ea@02NLd00WW=00P2OM3l309ea@0<0WW91
0P2OLd820:1d@`0309mc@P2NLT40WG500080W70o00T0Vfln0:1e@02QMT40XWM40:9fA@2RMTL0X7A7
09ibA@2ML4H00P2PMD020:5f@@@0XWM200<0XGI30:9gA02SN4D00P2TNDH00`2SN4D0XWM40:5f@`02
09md@@80X7E20`2QMT<0102RMd@0YGE50:EeA@2UMDD30:IfAP80YgM7202QMD@80:EiBP080:YoC02X
ODX0YW]80:EjA`2TNDH0YGY70:IkB02WO4T20:]kBP<0ZWY90`2YNDP0102VO480Yge30:Mm@`2WOD<2
0:QnA080ZGm5202XO4d20:UnB@030:UnA`2YOdD0ZGm30080ZH1200<0ZH100:V0C02YP4`01P2YP4`2
0:b1BP040:b1C02/PDh0[85>0:b0C`80[81A0100/X1?0:moCP2^OTd0[7i<0:YoC02ZPDd0ZX9>0:^3
C`2_QU80[XEA0:b3C`2ZPDd0ZH1<0:Z1C@2[PTh0[8=?0P2ZOTl20:]oD080[81A0`2]PE880:YoC0P0
ZGe>0P2YOTT20:YoBP<0Zh1;00@0[85<0:Z0CP2ZP4h0ZX1>0`2YOdd20:QnC0P0Z7m;402[PTh0102/
PDh0Zh1=0:^0C@2[P4d20:YoC080ZGi;0P2ZP4h01P2ZPDd0Zh9<0:^2BP2[PdP0[8A90:b4A`P0[898
00P0Zh1;0:b1C02]PTd0[X=>0:f2C@2/PD`0ZWm:0:QmB0P0ZGi9402XODP00`2ZOTd0ZGe<0:QlB`02
0:QlB`030:YnC@2/P4l0[X9A00P0ZH1<0`2WOTX20:QoB`<0ZH1<0`2[P4/30:YoBP80ZGi90`2WOTX2
0:QoB`@0ZH1<202ZOdX30:UnB@80ZWm:0`2[P4/80:YoC0X0ZGi90`2ZOdX;0:^0B`80[X=>0`2]PTd3
0:b1C080ZH1<0P2ZPDd20:^2CP80[8=?0P2/Pdd20:^2C080ZX5;0P2YP4X00`2YP4`0ZX5=0:Z1C@02
0:^2CP80[8=?00<0[HA@0:f2C@2]PTd01P2]PTd80:f2C`80[hAA0`2^Pe0;0:f2C`<0[85>0P2]PTl3
0:j3D0030:n6D02^QDl0[8==00<0ZX5;00<0[8==0:f4CP2^Q5@01`2^Q5@80:f4D0050:Z1B`2[PT`0
Zh9<0:b3C@2^QDl00P2_QU002P2`Qe40[hI@0:n6D02^QDl0[HA>0:b3C@2]Q4h0[XE?0;27D@2bRE<2
0;>:EP040;:9E@2aR5@0/8MC0:n6DP80[XEA0P2/Q4T30:f5BP<0[XI;0P2`Qe<20:n6DP050:j5D@2]
Q500[HA@0:f4D02^QE400P2_QU800`2`Qe<0/HQD0;:9E@020;>:EP<0/HQD0P2`Qe<30:n6DP80[XAD
00@0[hEC0:n6DP2`Qe<0/8MA0P2aR5080;:8EP030:n5D`2`QU@0/XQF0080/hUG00<0/XQF0;26E02_
QE<00`2]R5<30:j9E080[hYE0`2bRED20;>:EP<0]8]G202bRED50;68E0<0/8MC00<0/HQD0;:9E@2b
RED00P2cRUH20;B;E`040;F<F02dReL0/hYF0;68E080/8MC00H0/HQD0;>:EP2dReL0[hIB0;68E02b
RED20;>:EP030;:9E@2aR5@0[hIB0080]8ID00<0/XMD0;68E02`R5@00P2^RE@0102]RU@0/8MC0;27
D`2`Qe<20;68E0<0/XUE0P2aSE<20;2<DP040:n;D@2^RU00[XY@0:j:D0<0]HaH00T0]8]G0;>:EP2b
RED0/HQD0;27D`2_QU80/hYF0;:9E@2`Qe<00`2_QU820;27D`<0/hYF0P2bRED30;68E0030;26EP2a
QeL0/HME0080/XUE00`0/hYD0;>:DP2dRe<0/HQD0;27D`2_QE<0[hEE0:n4E`2aQUT0/hQM0;B9GP2a
S5L20;2;EP80[hYE0P2^RE@00`2]R5<0]HQA0;F8D@030;B7D0<0/hI?202`Qe402@2]Q4h0[XE?0:n6
D02`Qe40[hI@0:j5C`2/Pdd0Zh9<0:^0B`020:b1C080[H9=0P2^Pdh00`2_Q4l0[XEA0:j5D@060:j5
D@030:^2C02/Pdd0[8==0080[HA>0P2^QDl00`2_QU00[8==0:b3C@060:b3C@060:j4B02^Q4X0[XA:
0:j3C02^Pdh0[X=@0P2^PU420:^2CP040:b3C`2]Q500[HA@0:b3C`80Zh9>0`2/Pdl20:f4D0<0[XEA
0`2/Pdd30:f4CP80[XE?00H0/8Q;0;28C@2`R4d0/8M?0:n6D02_QU820:j4DP030:n6DP2^QE40[8=?
0080Zh9>00<0[8=?0:j5D@2_QU802@2/Pdl30:j5C@80[HA<0`2/Pd/20:j3D0<0[H9?0`2/PDh80:f2
C`030:R2D@2YPe80ZhED0080[8IE00<0ZhED0:V3DP2XPU400P2/PU001P2[PTh0Zh9<0:Z1B@2ZPTL0
ZH560:V1A080[HA<00@0[HA>0:f4D02]Q500[H=A0P2/PU800`2]Q4h0[8==0:^2C0020:^2C0030:f4
CP2_QU00/8MA00P0[8==00/0[hM:0:j6B`2/Q4T0ZX590:Z1B`2ZPDd0Zh5?0:b2D02^QE40[8=?0:^2
CP020:Z1C@030:^2CP2/Pdl0[XEA00P0[8=?202YP4`80:f4D080[89@00<0Zh5A0:^0D`2ZOe@00P2Y
OU@00`2YOEH0Zh9>0:b3C`060:b3C`080;27D`2/Pdl0Ygi:0:MnBP2ZPDd0[8=?0:^2CP2YP4`80:b3
C`P0Zh9<00<0Zh9:0:Z1B@2YP4X00`2YP4`00`2[PDl0[H=C0:j4E0030:b3C`030:^2CP2ZPDd0ZH1<
0080Z7m;00<0ZX5=0:^2CP2/Pdl00P2]Q5000`2/Pdl0Zh9>0:Z1C@080:b3C`P0Zh1C202[PTh20:b0
C`030:b1CP2/PD`0[85:0080[89800@0[8960:b3B`2/Pd/0[8==0P2/Pdl00`2/PU00[89B0:b2DP02
0:n4D@040:j3D02]PTl0[85>0:^0C@80ZWm<00H0Z8130:R0A@2XP4D0Z7m70:QoB@2XOd/20:QnC080
Ygi:0`2XOd/30:V0C0P0ZH1:00H0Zh9:0:Z1B@2ZPD/0ZX5=0:V0C02YOdd20:QnCP060:Mo@P2WOd@0
Ygm40:QoA`2XOdT0ZH1<0P2YOdd00`2YOTT0Z7e80:MlA`020:IkAP030:QmB02ZOdX0Zh1;00<0ZWi?
00<0Zgm@0:b0D@2/P5400P2]PE80102]Pe<0Zh5A0:UoC`2XOTh20:MmC@030:QnCP2YOdl0Ygi:00L0
Ygi:0P2UO4P20:ImB@040:MnBP2XOd/0Z7m;0:QoB`80Z7m90P2YP4X20:QoB@030:ImA`2TNdD0XWU3
0080Y7]70P2UO4P40:ImB@80Z7m;00@0Ygi:0:ImB@2UO4P0Y7]70P2SNTH0202OMT00X7M10:5h@P2R
ND<0Y7]50:ElAP2VODL0Ygi80`2TND@00`2UNTD0YW]60:IkAP020:MlA`P0XgQ3202SN4D30:AiAP80
XgQ50`2RMd@80:Ak@`030:EiB02TN4L0XWI50080XGE400<0XWI50:AhA`2UNDP00P2NM48209me@`<0
X7I400@0XGM50:Eh@@2TMd00XWDn0P2QM3d00`2RMCh0Y7M00:Eh@@0;09iiA@80WgY60`2PNdL01@2V
O4X0YG]90:EkB@2TNTP0XWQ60080XGM500@0X7I409mf@P2QN4@0XWU50P2SNTH00`2RNDD0XGQ409mf
@P080:5hA0<0WWU50`2MN4@209ag@`070:5hA02RNDD0XgY60:ElB02TNdL0XgY60:9iA@020:5hA004
0:1g@`2NMD40W7<o09ac?`80WGA000@0WWE109mf@P2OMT80WgI20P2PMd<40:5hA0080:9iA@2QN4@0
WgI209ie@@2MM400WWE109mf@P2PMd<309mcAP80WW950`2MLD@0202IL3`0VFlm09Y`?P2JL400Vg13
09]`A@2KL4H0W757202JLCT00`2IKcd0VW0n09ab@00209ab@00309Y`?P2IKcd0Ufdk0080Vg1300@0
VVm209U^@@2HKD00Uf`o0P2FJch309E_@080UW110`2GLD8809U^@@P0V6e0202HKS`01@2FK3X0Ufdk
09M]>`2HKS`0VW0n0080Vg4o00@0W79009IZ?@2GJch0VFe00P2KKd801P2JKT40VFe009Q/?`2FK3X0
UF/i09AZ>080TfTg00D0UF/i09I/>P2GKC/0TfPk09AY?00409EZ?@0309AY?02CJ3/0TF/l00L0TF/l
0P2DJC`409EZ?@80UV/n0P2DKSl209=]?P<0TV`m00<0TF/l09AY?`2CJ3h00`2CJ3h0102DJCl0UV]1
09I[@@2FJd4309I/>P<0UF/i0P2DJSP809AY?`80T6Xk0P2?JCX208iX>@80SFLh00D0S64d08eR=@2=
HSD0SV<f091U>002095V>@03099W>P2CJ3d0TfPm00H0TfPm0`2AIS/3091U>P80Sf@i00<0SVPi08eW
>02<ISL00P2;ICH03`2<ISL0SFLh08iX>@2?JC`0S6Hi08YT=`2<IST0T6Xm099/?`2?JC`0S6Hi08UT
=`2:ICP0SFPk08mZ?@02091[?P80SfXm0`2AK48[ooooo`00:_ooool808=L<`0308EN=@24GC@0Pe`c
0080PEXa00<0Pe`c08AM=025GSD00P23G3<208AM=080QEhe0P26GcH00`25GSD0QUlf08MP=`0308UR
>@80R64h202;GcP00`2<H3T0Relh08YN=`0208UM=P0308YN=`2;GcP0S60i00P0SF8g00<0Rf0e08aQ
=P2=HSL00P2>HcP00`2=HSL0S64f08]P=@0208mT=`80SV<f0`2=HSD00`2<HC@0RV<j08YS>P0708YS
>P80Sf@i0`2@ICX3095V>`D0TF@j0`2@HcT208mR>004091S>@2AI3X0TVDk099U>`80TfHl00<0U6Pk
09=W>P2BIST00P2AICP00`2BIST0TfLj09AX>`02095U>080TVHi0P2CIcX:09AX>`80UVXk00<0UVXm
09IY?`2FJD000P2FJD800`2FJ4@0UFTl09EY?00309EY?00309IZ?@2GJch0Uf/n00<0UFPn0P2FJCl3
09MZ@0@0V6`o102GJch00`2HKD00Uf`o09EZ?@0309AY?080UFXm00P0UFU209AX@@2CId00TfM009AX
@@2EJD80UVY309M[A0<0V6`o0P2IKD0309Y^@@0409U]@02JKT40VVi109Y^@@80Vfm20P2LL4<0202I
L3X0VW4k09]b?P2LLT00Vg5109Y_@P2HKD00Ufa10P2NLT4209ea@0@0W70o00@0VFdl09Y^?@2JKSd0
VVhm0P2KKch209a`?`80Wflo0`2PL4030:5a@@0509a_A@2LL4<0WG5409ea@P2NLT400P2OM4420:1e
@0<0WG500`2NLT4209mc@PP0WW9100P0X7E00:5f@@2QMT<0XWI50:5eAP2PM4L0Wg=609iaA`<0X7E0
0P2QMT430:9g@P030:5f@`2RMd@0XgQ500<0XgQ500<0XWM40:5f@`2PMD800P2PMD820:5f@`<0XWM4
0`2UMDD30:IfAP80YgM7202SMdH80:EiB0060:QmBP2WO4T0YW]80:EjA`2TNDH0YGY70P2VNdP30:Yj
B@<0Zg]:0P2/O4/30:Il@P80Yge30`2XOT@80:QlB`060:UnB`2YOTT0ZGi90:UnA`2YOdD0ZGm30P2Y
P4880:V0C080[85:00@0[85<0:b1CP2/PDh0[81?0P2/P5402`2bP4l0[gm>0:inC@2/OT`0ZWm<0:Z1
C@2ZPTh0Zh=?0:j5D@2]Q500Zh9>00<0ZX5=0P2[PTh20:YnC@80Zgm>0P2/P4l30:f1D0P0Zh1=202Z
OTd30:YoBP80Zh1;0`2/PD`30:Z0CP<0ZGm=0P2XOT`80:V0C100Zh9>0`2/PDh20:^0C@<0ZWm<0P2/
PU001P2/Pdl0Zh9<0:^2BP2[PdP0ZX970:Z2A@P0[89800P0Zh1;0:b1C02]PTd0[X=>0:f2C@2/PD`0
ZWm:0:QmB0P0ZGi9402XODP0202ZOTd0ZGe<0:UmC02XO4/0ZGe<0:YnC@2[Odh0[81?202YP4`30:Mn
BP80Z7m;0`2YP4`30:^0B`<0ZWm:0P2YOTT30:MnBP80Z7m;102YP4`80:YoBP040:QmB02YOTT0ZGi9
0:UnB@80ZWm:0P2[P4/80:YoC0X0ZGi90`2ZOdX;0:^0B`80[X=>0`2]PTd30:b1C080ZH1<0P2ZPDd2
0:^2CP80[8=?0P2/Pdd20:^2C080ZX5;0P2YP4X0102[PTh0[8=?0:b3C`2/Pdl30:f4D0030:j5D@2]
PTd0[H9=00H0[H9=202]PTl0102_Q540[X=@0:j3D02^Pe020:f2C`80[85>202]PTl20:b1CP80[H9?
0`2^Pe00102_Q540[hI@0:j5C`2/Pdd30:^2C080[8==202^Q5880:b3C`80Zh9<00@0[8==0:f4CP2]
Q4h0[XE?102_QU020:j5C`050:f4CP2^QDl0[hI@0;27D@2aR5800P2bRED20;68E0050;27D`2_QU80
[XEA0:j5D@2/Q4T00`2]QDX20:j6B`80[hM<0`2_QU830:j5D@80[HA@202aR5@20;B;E`80/hYF0`2b
RED02@2aR5@0[XAD0:n5E@2_QE<0[hIB0;27D`2`Qe40/8M?0;68D0080;>9E`030:n5D`2`QU@0/HME
0080/XQF00<0/HME0;26E02_QE<00`2]R5<30:j9E080[hYE00@0/HQD0;:9E@2bRED0/XUE0P2cRUH2
0;B;E`P0/HQD0`2`Qe<40;68E0D0/XUE0P2cRUH20;B;E`80/hYF102aR5@20;>:EP030;68E02bRED0
/hYF0080]HaH00<0/hYF0;:9E@2aR5@00P2dQU@00`2bQe@0/HQD0;28E0020:j9E0030:f:E02`Qe<0
/8MC0080/HQD0`2bRED00`2cRUH0/HaE0;2;E0020;2;E0<0[hYC00L0[XUB0;F<F02eS5P0]HaH0;B;
E`2cRUH0/XUE0080/HQD00T0/8MC0;:9E@2cRUH0/hYF0;B;E`2cRUH0/XUE0;68E02`Qe<00`2cRUH2
0;:9E@<0/HQD0P2aQeL0102aQeD0/XUE0;:9E@2cRU@20;>:DP080;68DP2`Qe40/8MC0:n5D`2`QUH0
/HII0;:7FP2cR5d30;2;EP80[hYE0`2^RE@20;>8D`<0/XMB0`2aQU480;27D@030:f4CP2^QDl0/8MA
00<0/HQB00@0/8MA0:n6D02/PD`0[85<0P2]PTd40:j3CPP0[XEA0`2/Pdd20:f4CP<0[XE?202/Pdd0
1P2^Q4P0[XA:0:j4BP2^Pd`0[X=>0:j3D080[X9A00<0[HA@0:b3C`2[PTh00`2[PTh00`2/Pdl0[HA@
0:b3C`020:b3C`80[HA@0`2^QE420:^2C080[8==0`2]Q4h01`2^QDl0/8Q;0;28C@2`R4d0[hI>0:n6
D02^QE400P2^Q5820:j5D@@0[8=?0P2^QE490:b3C`<0[8==0P2]Q4h30:j5C`80[X=@0`2]PTl30:b1
CPP0[H9?00<0Z8=?0:V4D02ZQE400P2[QU800`2ZQE40ZHA@0:R3C`020:b2D0060:^2CP2[PT`0ZX59
0:Z2A`2YPDH0ZH540P2/Pd/0102/Pdd0[8=?0:b3C`2]Pe420:f3D`080:f4CP2/Pdd0Zh9<0:Z1B`2[
PT`0[8==0:j5C`2_QU080:b3C@060:n7BP2]QDX0[8A90:Z1B@2ZPD/0ZX5=0P2/PU000`2^QE40[8=?
0:^2CP020:Z1C@030:^2CP2/Pdl0[XEA00P0[8=?202ZPDd80:b3C`060:^2CP2[PDl0Zh5?0:Z0D02Z
Oe80ZGiC0P2YOU@20:Z1C@80Zh9>00H0[8=?0:f4D02^QE40[XEA0;27D`2/Pdl20:QoB`040:^2CP2]
Q500Zh9>0:QoB`P0Zh9>202[PT`20:^2BP070:Z1B`2ZPDd0ZX5=0:Z1C@2[PDl0[H=C0:j4E0080:Z1
C@030:V0C02ZPDd0[8=?0080[HA@00<0[8=?0:Z1C@2YP4`0202/Pdl80:^0D`P0Zh9>0P2/P4l00`2/
PDh0[85<0:b1BP020:b2B0040:b2AP2/Pd/0[8=;0:b3C@80[8=?00<0[89@0:b2DP2/PU80202/PDh0
1P2YPD@0ZH560:V1AP2YP4P0ZH1:0:V0C080ZGm=00@0Ygi:0:QoB`2XOd/0Z7m;0P2YP4`20:Z1C@P0
ZX5;0P2[PTX0102[PT`0ZX5=0:Z1C@2YOdd20:UoC`060:V1A02YPDH0ZH560:QoA`2XOdT0Ygi:0P2W
OD/0202YOTT0Z7e80:MlA`2VNdH0Yga70:QmB02ZOdX0Zh1;0`2ZOTd20:]oCP<0[81?00@0[XAB0:b2
D02ZP4h0Z7i<0P2VO4X20:MmB`P0Ygi:0`2VODT30:MnBP80Z7m;00@0Ygi80:QoB@2YP4X0ZH1:0P2X
OdT00`2VODL0Y7]50:=jA0030:AkA`80YGa80`2VODT01@2XOd/0Ygi:0:MnBP2VODT0YGa80080Y7]7
00<0XgY60:9i@`2RND<00P2SNT@20:AkA@80YGa60P2TND@30:EjA@<0YW]6202UNTD90:EjA`<0Y7U6
0P2SN4D20:9gA0P0XWU300<0Y7Q70:=gAP2RMTD00P2QMD@00`2RMTD0XgM60:AhA`0309me@`80X7I4
0`2QMdD00`2TND@0XgQ30:9g@P030:9g@P030:=h@`2TND@0WWU500T0WWU50P2ONTH30:1kA`040:5l
B02UNdT0YG]90:AjB080XgU700H0XWQ60:5gA@2QMdD0WWE109mf@P2PMd<20:9iA@030:1g@`2OMT80
WWE100P0XGQ40P2KMT8309ag@`<0WGQ400@0WWE109mf@P2QN4@0XgY60P2TNdL20:=jAP0309mf@P2N
MD40WGA00080WGA00P2OMT800`2PMd<0XGQ409mf@P0209mf@P80X7M30`2QN4@02@2RNDD0XGQ409mf
@P2NMD40WGA009ie@@2OMT80X7M30:1dA`0309mcAP80WW950P2MLD@01P2JLCd0VW0n09Y`?P2KLD40
Vg1309aaAP80W757202JLC/00`2GKC/0VFlm09Y`?P0309ab@00509Y`?P2IKcd0VFi109U^@@2HKD00
0P2GK3l00`2FJch0UFXm09EZ?@0309E_@080UW110`2GLD8809Y_@PP0V6e0202HKS`209M]>`0409Q^
?02IKcd0VFlm09Y`?P80Vg4o0P2JKT402@2KKd80W71309]_@P2JKT40VFe009Q/?`2GKC/0UV`j09AZ
>00209=Y=`0609AZ>02EJcT0UV`j09I[?P2EJSd0U6Tl0P2CJ3/00`2DJC`0UFXm09I[?P0209=]?P04
099/?@2AJc`0TF/l091Z>`80SfTj00H0Uf`o09I[?P2FJch0U6Tl09=X>`2BIcX2095V>@<0UFm00P2D
KSl309=]?P80TVLl00<0U6Tn09EZ?`2EJSl00`2EJSl0102DJCh0UV`j09I/>P2FK3X309E[>@80U6Xh
202CJ3d2091Z>`80SfTj0P2>J3T208eW>080SF8e00@0SV<f08mT=`2?I3L0T6Dh0P2AIST8095V>`80
Sf@i0`2@ICX3095V>`03091Z>`2?JCX0SFLh0080S6Hg00l0SFLh08mY>P2@JS/0SFLj08YT=`28HSD0
RV@g08iX>`2@JSd0SVPk08]U>029I3L0RfHi08eX>`2?JSd00P2@Jch00`2?JSd0SVTl091[@@02091[
@B_ooooo000Zooooo`<0Q5dd1023G3<01022Fc80QEhe08AM=023G3<2085J<@0308=L<`24GC@0QEhe
0080Pe`c0P24GC@208EN=@<0QUlf0P27H3L00`28HCP0RF8i08UR>@0208UR>A00Relh202>HcP208aQ
=P@0SF8g0P2<HCH308eR=`80S64f0`2;H3D908]T>`80Sf@i0`2@ICX3095V>`80Sf8h00@0T6<i095T
>P2AI3X0TVDk0P2CIS`208iQ=`0908mR>02AI3X0TVDk09=V?02DIcd0UFPn09AX>`2CIcX0TVHi0080
TFDh00<0TVHi09=W>P2DJ3/00P2AICP2099V>@80TfLj0P2DJ3/809EY?080UFTj00<0UFTl09EX?P2E
J3l00P2EJ4401@2EId<0TfLj09AX>`2FJSd0Uf/n00@0VFe00P2DJ3/209EY?0<0UVXm00<0Uf/n09IZ
?@2GJch00P2GJch309Q/?`0409U]@02GK3l0UV/n09I[?P80UFXm0`2DJC`409AY?`0409EZ@02FJd40
UV]109M/@P<0Uf/n0P2HK3l509U]@0<0VVi10`2KKd80202IL3X0VW4k09]b?P2KLCl0Vg5109U^@@2G
K3l0UV]01@2LL3l309]_?P<0VVhm0P2KKch309a`?`D0X7910`2QLd801@2LKdD0W71309eaA02NLT<0
Wg=20080X7E20P2QMT4309ea@0<0WW910P2OLd8209a`?`80WG5000@0WW9109mc@P2OLd80X7A30P2P
MD000`2QMT<0XGE40:5eAP020:1dA`0309mbB02OM3l0Wg@o0080X7E00P2QMT420:9g@P030:5f@`2R
Md@0XWM400@0XWM400<0XGI30:1e@P2PMD800`2QMT<30:9gA0<0YGE50`2VMTH20:MgA`P0Y7Q7202U
NTL30:IkB0@0YGY700H0YW]80:UiB02ZNTT0ZWY90:]kBP2/O4/20:emC0040:inC@2VNd@0YW]40:Ik
A0<0Yga50P2XODH80:QmBP060:UmC02YOT/0ZGi;0:UnB@2YOTL0ZGm50P2YOd<80:V0C080[85:00@0
[85<0:b1CP2/PDh0[81?0P2/P5401P2aOdh0[gm>0:inC@2]Odd0Zh1=0:Z1C@80ZX9>00<0[8=?0:^2
CP2[PTh00`2ZPDd20:^2CP80ZWm<0P2[P4d20:b1CP<0[H9?202[P4d80:YoC080ZWm:0`2[P4/30:b1
C0<0ZX1>0`2YOdd20:QnC0P0ZH1<402[PTh30:b1CP<0Zh1=0P2ZOd`01@2^Q580[H=A0:f4D02/Pdd0
Zh9:0080ZX9700<0ZH540:b2B02/PTP01P2/PTP0202[P4/0[85<0:f2C@2^Pdh0[H9=0:b1C02ZOdX0
Z7e8602YOTT60:UmC080ZWi=202XOd/30:MnBP80Z7m;0`2YP4`30:^0B`<0ZWm:0P2YOTT30:MnBP80
Z7m;102YP4`30:YoBP@0ZGi90`2XODP30:UnB@<0ZWm:202YOT/:0:UnB@<0ZWm:2`2[P4/20:j3CP<0
[H9=0`2/PD`20:V0C080ZX5=0P2[PTh20:b3C`80[8==0P2[PT`20:Z1B`80ZH1:102]Q5040:j5D@P0
[H9=202]PTl30:j3D080[H9?0`2/PDh;0:f2C`<0[X=@0P2_Q5420:j5C`80[HA>102/Pdd80:f4D0P0
Zh9>00<0Zh9<0:b3C@2/Pdd00P2]Q4h20:j5C`030:n6D02^QDl0[XE?0080[XE?0P2_QU020;27D@05
0;68DP2aR5@0/HQD0;68E02`Qe<00P2_QU820:j5D@<0[HA<0P2^QDd30:n6CP80[hIB1P2^QE40102c
RUH0/XUE0;:9E@2aR5@20;27D`80[hIB102bRED20;68E080/8MC0P2_QED0102_QE<0[hIB0;27D`2`
Qe420;27C`P0/hUG00<0/8ID0;67E@2aQeD0102aQeD0102`QU@0[hMC0:n7D`2_Qe<30;28E080/HUE
0P2aR5@30;:9E@<0/hYF202`Qe<01@2_QU80/8MC0;27D`2`Qe<0/HQD00T0/XUE0P2cRUH90;:9E@07
0;>:EP2eS5P0]XeI0;J=F@2eS5P0/hYF0;:9E@020;B6E0030;:7E02aR5@0/8QD0080[XUD00@0[HYD
0;68E02aR5@0/HQD0`2bRED20;>:EPP0/8]F00@0]HaH0;B;E`2dReL0]8]G0P2cRUH20;:9E@090;68
E02bRED0/hYF0;F<F02gSUX0]XeI0;B;E`2aR5@0[hIB00<0/hYF0P2bRED30;68E080/XQH00@0/XQF
0;:9E@2bRED0/XUC0P2bRE420;68D0060;27D@2`Qe<0/8ID0;67E`2aQUT0/XMJ202_RUD20;:9E@<0
/HQD0`2`Qe<80;27D@050:j5C`2_QU00/8MA0;68DP2bRE<00`2cRU@20:f2C@H0[X=>202]Q5080:f4
CPP0[8==00H0[XA80:j4BP2^Q4X0[X=<0:j3CP2^Pe020:j2D@030:n6DP2]Q500Zh9>0080ZH1<00<0
Zh9>0:f4D02_QU800`2/Pdl20:f4D0<0[XEA0`2[PT`20:b3C@<0[HA>00H0/8Q;0;28C@2_Qd`0[hI>
0:j5C`2^QE420:f3D@P0[HA@2@2/Pdl20:^2CP040:b3C`2]Q500[HA@0:j5D@80[hIB0P2^Pe030:f2
C`<0[85>202]PTl00`2YPDd0ZX9>0:b4D0020:f5D@030:b4D02ZPTh0ZH5=0080[89@00H0Zh9>0:^2
C02ZPDT0ZX970:V1AP2YPD@20:^2BP040:b3C@2/Pdl0[8=?0:b2D080[H=C00<0[HA>0:b3C@2[PT`0
0P2ZPD/00`2[PT`0[HA>0:j5C`080:b3C@0;0:j6B@2]QDX0Zh=80:Z1B@2ZPD/0Zh9>0:b2D02]Pe40
[XEA0:b3C`2[PTh00P2ZPDd00`2[PTh0[8=?0:j5D@080:b3C`P0ZX5=202/Pdl01P2ZPD/0ZX5=0:Z1
C@2ZP4h0ZGm?0:UnD@80ZGiC00H0Z7m;0:V0C02ZPDd0Zh9>0:b3C`2^QE420:n6DP080;27D`2/Pdl0
ZH1<0:Z1C@2]Q500[XEA0:^2CP2XOd/80:^2CPP0Zh9<0P2[PTX01@2[PT`0Zh9>0:^2CP2[PTh0[89@
0080[H=C00@0Z7m;0:V0C02YP4`0ZH1<0`2ZPDd0102[PTh0ZH1<0:Z1C@2[PTh20:f4D0030:^2CP2Z
PDd0ZH1<00P0[8=?202[PE480:^2CP80[81?00<0[85>0:b1C02/PDX00P2/PTP0102/PTH0[8=;0:b3
B`2/Pdd20:b3C`030:b2D02/PU80[89B0080ZWm<0P2[P4d01@2/PDh0[H9?0:f2C`2^Pe00ZH540080
ZH5600<0ZH180:V0BP2YP4`00P2YOdd30:QoB`80ZH1<0`2ZPDd80:Z1B`80Zh9:00@0Zh9<0:Z1C@2Z
PDd0ZX1>0P2YOdl01P2[PdH0Zh=80:Z2A`2YP4P0Ygi80:ImB@80YG]900<0ZGi90:QmB02WO4L00P2W
O4L00`2YOTT0Zh1;0:b1C0040:YoC0@0Zh1=00H0[XEA0:b3C`2ZPDd0Ygi:0:ImB@2UO4P20:ImB@P0
Z7m;0P2VODT60:MnBP80Ygi800L0Z7m90:V0BP2XOdT0Z7m90:MnB02UO4H0XgY40080XgY60P2TNdL2
0:ElB080YWe90P2WOTX20:ImB@80YGa80P2TNdL20:ElAP@0Y7]50P2SNT@60:EjA@X0YW]6202VNdP2
0:EjA`<0Y7U60`2SN4D80:1g@`<0XgM60P2RMTD30:=gAP80WgE30`2PMT@30:5gA@030:AkA`2SNTH0
XgY600@0XgY600<0Y7]709iiA@2NNDD01P2NNDD309mjAP<0X7]70P2QO4P00`2UNdT0Y7Y80:AjB002
0:=iA`80XWQ600@0XGM509ed@02NMD40WgI20P2QN4@00`2OMT80WWE109ed@0080:9iA@0509Ud@02J
MD40VWE109]f@P2LMd<00P2MN4@01P2NNDD0W7<o09ed@02OMT80XGQ40:9iA@80Y7]700<0YGa809ed
@02MM4000P2NMD401@2OMT80X7M30:1g@`2QN4@0XWU50080WWE10P2OMT820:1g@`80XGQ400P0XWU5
0:5hA02OMT80WWE109ed@02NMD40WgI20:1g@`80X7A50`2OLd@309ib@`0609Ya?@2JL3h0Vg4o09]a
@@2KL4<0W7560P2LLDL809Ya?@0309I/>P2HKS`0VW0n00<0W7900P2KLCl209Q]@00409M/?`2FJch0
UFXm09EZ?@80U6Tl0`2EKd0209I`@@<0Ug52202JKd8809U^@@P0V6hl00<0Ufdk09Q^?02HKS`00P2I
Kcd209Y`?P0309]a?`2MLD@0WG540080W71300l0Vfm209Y^@@2IKD00V6`o09M]?@2FK3`0U6Xj09=Y
>@2BJ3P0TfTi09AZ>P2EJc/0V6e009I[?P2DJC`00P2BIcX00`2DJC`0UV/n09Q]@00209A^?`0409=]
?P2BK3d0T6Xk08mY>P80SVPi0P2EJSd209AY?00409=X>`2BIcX0TVLj095V>@<0Tfdn0P2BK3d3095[
?003091U>02BIcX0UFXm0080Uf`o00@0UV/n09AY?02DJC`0TVLj0`2FK3X309E[>@80U6Xh202BIcX2
091Z>`80SfTj0P2>J3T208eW>00308eR=@2>HcH0SV<f0080Sf@g0P2@ICP00`2AIST0T6Dj091U>P06
091U>P80SV<h00<0Sf@i091U>P2AIS/00P2BIc`0102CJ3d0TF/l091Z>`2>J3T208eW>00C08iX>@2@
JS/0TF/l08aV>@29HcH0Qf4d08QR=@2<IST0SVPk08aV>@29HcH0RVDh08]V>@2=J3/0SfXm091[?P2?
JSd0SVTl08eX>`0308mZ@2_ooooo000Zooooo`80QEhe0P24GC@01`23G3<0PU/b089K<P22Fc80QEhe
08AM=023G3<00P21FS400`23G3<0Q5dd08EN=@0208=L<`80Q5dd0P25GSD208IO=PD0R64h00<0RF8i
08YS>P2:HcX0202<H3T208]O>0@0S60i0P2;GcP808iS>080SF8g102<HCH208eR=`80SF8h0P2<HCL4
08]P=PT0Rf@k0P2?I3T3091U>P<0TFHk0P2?HSP0102@HcT0TF@j099U>`2CIS`209AW?@80SV4g00T0
Sf8h095T>P2BIC/0TfHl09AW?@2EJ3h0U6Pk09=W>P2BIST00P2AICP00`2BIST0TfLj09AX>`02095U
>080TVHi0P2CIcX209AX>`P0UFTl0P2EJCX00`2EJC`0UFPn09EX?`0209EX@@0509EW@`2BIST0TfLj
09EY?02GJch00P2IKD000`2JKT40VFe009EY>P0209EY>P80UVXk0`2GJc`0102FJSd0Uf/n09M[?P2G
Jch309Q/?`0309U]@02FJch0UV/n0080UV/n0P2EJSd209AY?080U6Tn00<0UFXo09I[@02FJd000`2F
Jd0309IZ?@80Uf/n0`2HK3l309U]@0<0VVi10P2KKd80202HKcT0VG0j09Ya?@2KLCl0VW1009U^@@2G
K3l0UV]00P2JKSd609]_?P80VVhm0P2KKch209a`?`80WG500`2OLd8509ib@@0509a_A@2LL4<0WG54
09ib@`2OLd800P2OM4420:1e@0<0WG500`2NLT4209mc@P0609]_?P2LL3l0W70o09ea@02NLT40Wg=2
0P2PM4<20:1e@0060:1e@P2PM4<0X7A50:1dA`2QMDP0XGA:0`2OM3l20:1e@0<0XGI100<0XWM40:5f
@`2QMT<0102QMT<0102RMd@0XGI30:5f@`2QMT<30:9gA080XgQ50`2UMDD30:IfAP80YgM7202UNDP8
0:EjA`80Y7U60P2UNTL0102VNdP0YGY70:EjA`2UNTL20:UiB0040:YjB@2[NdX0[7a;0:alB`80[Ge<
0P2UNTD30:IkAP<0Yga7202XODX01P2YODh0ZGe<0:UnB`2YOT/0ZGi90:UnA`80ZGm5202YP4`20:b1
BP040:b1C02/PDh0[85>0:b0C`80[81A00H0/7i=0:inC@2_Odh0[X1>0:b1CP2[PTh20:V1C@030:V0
C02ZPDd0ZX5=00<0Zh9>0P2ZPDd20:YoC080Zh1=0P2/PDh30:f2C`P0[85>202[P4d30:^0B`<0[85<
0P2]PTd30:Z0CP<0ZGm=0P2XOT`80:Z1CA00Zh9>0P2]PTl30:b1CP<0Zh1=0P2^Q5801P2]Q500[8==
0:b3B`2[PdP0ZX970:Z2A@P0[89800P0Zh1;0:b1C02]PTd0[X=>0:f2C@2/PD`0ZWm:0:QmB1P0ZGi9
1P2YOD`20:QlB`P0Z7m;0`2WOTX20:QoB`<0ZH1<0`2[P4/30:YoBP80ZGi90`2WOTX20:QoB`@0ZH1<
0`2ZOdX00`2YOTT0Z7e80:QmB0020:MlA`<0Z7e80`2YOTT20:YoBPP0ZGi;2P2YOTT30:YoBP<0Zh1;
202ZOdX20:j3CP<0[H9=0`2/PD`20:V0C080ZX5=0P2[PTh20:b3C`80[8==0P2[PT`20:Z1B`80ZH1:
102^QE440:f4D0P0[H9=202]PTl20:j3D080[H9?0P2/PDh20:^0C@X0[H9?0`2^Pe030:n4D@@0[XE?
0P2]Q4h20:b3C@P0[HA@202[PTh20:b3C@@0[HA>102^QDl20:n6D080/8MA0`2aR5830;27D`@0[hIB
00<0[XEA0:f4CP2]Q4h00P2^QDl20:n6D080/8MA1P2^QE420:n6DP80/hYF00<0/XUE0;68E02`Qe<0
0P2_QU800`2^QE40[hIB0:n6DP020:j5D@@0[HA@0P2`QUH0102`QU@0/8MC0:n6DP2_QU020:n6CPP0
/XQF0`2aQeD20;26E0<0/HME0`2`Qe<30;68E080/XUE0`2aR5@30;:9E@80/hYF2`2`Qe<50;68E0H0
/XUE0P2aR5@90;:9E@070;>:EP2eS5P0]XeI0;J=F@2eS5P0/hYF0;:9E@020;B6E0030;:7E02aR5@0
/8QD0080[XUD00<0[HYD0;68E02aR5@00`2bRED30;>:EP@0/8]F102aS5L50;B;E`@0/hYF00<0/XUE
0;B;E`2fSET00P2gSUX00`2eS5P0/XUE0;27D`030;>:EP80/XUE0`2aR5@20;:8F0040;:8EP2bRED0
/XUE0;:9D`80/XUA0P2aRDh0102aR500/HQB0;68E02aQeD20;26EPP0[hYE0P2aRED30;28E0<0[hMC
2`2`Qe400`2aR580/XUC0;>:E0020;B;E@80[hA?1P2^Pdh80:f4D0P0[HA>202/Pdd01P2^Q4P0[XA:
0:j4BP2^Pd`0[X=>0:j3D080[X9A00<0[hIB0:f4D02[PTh00P2YP4`00`2[PTh0[HA@0:n6DP030:b3
C`80[HA@0`2^QE420:Z1B`80Zh9<0P2/Pdd20:f4CP060:n7BP2_Qd`0[hM<0:j5C@2^QDl0[HA@0P2]
Pe480:f4D0T0[8=?0P2[PTh0102/Pdl0[HA@0:f4D02^QE420:n6DP80[X=@0`2]PTl30:b1CPP0[H9?
00<0ZX5=0:^2CP2/Pdl00P2]Q5000`2/Pdl0Zh9>0:Z1C@020:b2D0060:^2CP2[PT`0ZX590:Z2A`2Y
PDH0ZH540P2ZPDT0102[PT`0Zh9>0:b3C`2/PU020:f3D`030:j5C`2]Q4h0Zh9<0080ZX5;00<0Zh9<
0:b3C@2]Q4h0202/Pdd02`2]QDP0[8A90:^3B02ZPDT0ZX5;0:^2CP2]Pe40[XAB0:j5D@2/Pdl0Zh9>
0080ZX5=00<0Zh9>0:b3C`2^QE40202/Pdl80:^2CPP0[8=?00H0ZH180:V0BP2YP4`0ZH1<0:UoC@2Y
Odl20:UnD@060:QoB`2YP4`0ZX5=0:^2CP2/Pdl0[XEA0`2_QU801`2/Pdl0ZX5=0:^2CP2^QE40[hIB
0:^2CP2XOd/0202ZPDd80:^2C0030:Z1B@2[PTX0Zh9<0080[8=?00@0[HA@0:f3D@2]Pe<0[H=C0`2X
Od/20:V0C0<0ZX5=00<0Z7m;0:Z1C@2[PTh00P2/Pdl00`2[PTh0ZX5=0:QoB`080:b3C`P0Zh5?202[
PTh20:b0C`030:b1CP2/PD`0[85:0080[89800@0[8960:b3B`2/Pd/0[8==0P2/Pdl00`2/PU00[89B
0:b2DP020:UnB`030:YoC02[P4d0[85>0080[H9?00L0[X=@0:Z2A@2ZPTL0ZX970:Z1B@2ZPD/0ZX5=
0080ZX1>0P2XOd/20:V0C080ZX5=0P2[PTh80:^2C080[8=;00@0Zh9<0:^2CP2[PTh0ZX1>0P2ZP500
402/Q4L0Zh=80:Z2A`2YP4P0Ygi80:ImB@2UNdT0Y7Y80:YoBP2YOTT0Z7e80:MlA`2XODP0ZGi90:^0
B`2/PD`80:YoC0040:f4D02[PTh0ZH1<0:MnBP80YGa80P2VODT80:QoB`H0Ygi:0P2VODT0102VODL0
Ygi80:QoB@2YP4X20:QoB@030:MnB02UO4H0Y7]500<0XgY60P2TNdL30:ElB0@0YWe9102UO4P20:Im
A`80YGa60P2TNdD20:=jA080YW]61P2UNTD80:IkAPP0YW]80`2UNTL30:AiAP80XgQ5202PMd<00`2R
MTD0XgM60:=gAP040:=gAP040:9fA@2PMT@0X7I40:1fA0<0XGM50P2RN4H00`2RNTH0Xg]70:=kA`04
0:=kA`030:9jAP2NNDD0WWU500H0WWU50P2ONTH30:1kA`<0XGa80P2TNTP40:=iA`80XWQ600<0WGA0
09ie@@2OMT800P2QN4@00`2OMT80WWE109ed@0080:9iA@80VWE10P2KMT80302LMd<0WGQ409iiA@2N
NDD0Vg8n09ac?`2MM400WgI20:5hA02SNTH0YGa80:ImB@80WGA000<0WWE10:1g@`2PMd<0102QN4@3
09ie@@80WgI20`2PMd<0202RNDD0XGQ409mf@P2NMD40WGA009ie@@2OMT80X7M30`2PM4<309mc@P80
WW9100H0Vg8n09]a?`2KLCl0W79209aaA02LLDH209ebB0P0VW4m00<0UV`j09Q^?02JL3h00`2LLT02
09]a?`80V6e000@0Uf`o09I[?P2EJSd0UFXm0P2DJC`309E_@080UW110`2GLD8809]`@`P0VFi12P2H
KS`409U_?@80VW0n00@0WG5409a`@`2KKd80VVi1102IKD000`2GK3l0UV/n09AY?003099W>P0509=X
>`2DJC`0V6e009M/?`2DJC`00P2CJ3/00`2DJC`0Uf`o09Q]@00209A^?`0409=]?P2BK3d0T6Xk08mY
>P80SVPi0P2BIcX209=X>`0409AY?02EJSd0UFXm09I[?P<0T6Xk0P2?JCX308iX>@03091V=P2BJ3P0
UF/k0080Ufdm00@0UV`l09AZ>P2DJSX0TVPh0`2FK3X309E[>@80U6Xh202BJ3P2091Z>`80SfTj0P2>
J3T208eW>080SV<f102?I3L2091U>0P0Sf@i0P2>HcP00`2?I3T0T6Dj095V>`02099W?00409=X?@2A
Jc`0T6Xk08iX>@80SFLh00h0SVPi091Z>`2AJc`0RfDh08QR=@26H3<0R68e08aV>@2>J3/0S6Hi08US
=P2;IST0S6Lj08iY?0<0SfXm0P2=J3/308iY?b_ooooo000Zooooo`0608IO=P25GSD0QEhe08AM=023
G3<0PU/b0P21FS400`25GSD0Q5dd08=L<`02085J<@0308=L<`24GC@0QEhe0080Pe`c0P24GC@208EN
=@80QUlf00P0RF8i08QQ>028HCP0Qf0g08QQ>029HST0RV<j08]T>`P0S60i0P2;GcP0102<H3T0SF4j
08eQ>P2<H3T208]O>0P0SF8g00<0SV<h08eR=`2<HCH00P2;H3D0102<HCH0SF8g08iS>02>HS/308eQ
>P80S60i0P2;GcP908]T>`80Sf@i0`2@ICX3095V>`80T6<i00@0TF@j099U>`2BIC/0TfHl0P2DIcd2
08mR>004091S>@2AI3X0TVDk099U>`80TfHl00<0U6Pk09=W>P2BIST00P2AICP00`2BIST0TfLj09AX
>`02095U>080TVHi0P2CIcX209AX>`P0UVXm0P2DJ3T00`2DJ3/0U6Lm09AW?P0209AW@00909AV@P2C
IcX0TfLj09AX>`2EJC`0UVXm09M[?P2IKD00VVi10080UVXi0P2GJcX309Q/>`0309U]?02HK3l0V6`o
0080V6`o102GJch01`2EJSd0UV/n09I[?P2GK3l0UV/n09EZ?@2DJC`00P2CJ3/00`2DJC`0UV/n09M/
?`0209M/?`80UV/n0`2EJC`209IZ?@<0Uf/n0P2HK3l209U]@0<0VVi100T0Vfm209Q_>@2IL3X0VW4m
09Y`?P2JL400V6e009M/?`2EJSl00`2IKC`309Y^?@D0Vfln0P2LL3l309ea@0<0WG=10`2LLT0209]a
?`0509Y]@`2KKd80Vfm209a`@@2MLD000P2NLd0209md?`<0WG500`2NLT4209mc@P80W70o0P2MLD00
102NLT40Wg=209mc@P2PM4<20:1e@00709md@@2OLd80Wg=40:1dA`2RMTT0XgI<09ic?P0309md?`80
X7E00P2QMT400`2RMd@0XGI30:1e@P030:1e@P030:5f@`2RMd@0XGI30080XGI30P2RMd@30:=hA@<0
YGE50`2VMTH20:MgA`P0Y7Q7202UNTD00`2RMd@0XgQ50:AiAP030:IkB0030:EjA`2TNDH0ZGU800<0
ZGU80`2ZNTT0102[NdX0YGY70:EjA`2UNTL20:IkB0<0Yga9202XODP20:UmCP040:UmC02YOT/0ZGi;
0:UnB@80ZGi7202YP4`20:b1BP040:b1C02/PDh0[85>0:b0C`80[81A00/0[ge<0:inC@2_Odh0[h5?
0:f2C`2[PTh0ZH5=0:R0C02WOTX0Z7m;0:Z1C@030:^2CP80ZX5=0P2ZOdX20:^0B`80[85<0`2]PTd8
0:b1CP/0Zh1;0P2/PD`30:f2C@<0ZX1>0`2YOdd20:QnC0P0ZX5=402[PTh30:f2C`80[85>0`2[P4d2
0:f3D@030:f4D02]Q4h0[8=;0080[8A900<0Zh=60:b2B02/PTP01P2/PTP0202[P4/0[85<0:f2C@2^
Pdh0[H9=0:b1C02ZOdX0Z7e8202YOTT@0:YoBP080:QlB`2YOD`0ZGe<0:YnC@2YOD`0Z7a;0:MkBP2V
NTT;0:MnBP80Z7m;0`2YP4`30:^0B`<0ZWm:0P2YOTT30:MnBP80Z7m;102YP4`01P2[P4/0ZWm:0:Yo
BP2YOTT0Z7e80:MlA`80YW]60P2WO4L20:QmB0<0ZGi900<0ZWm:0:QmBP2XODX01P2XODX:0:UnB@<0
ZWm:0`2[P4/80:YoBP80[X=>0`2]PTd30:b1C080ZH1<0P2ZPDd20:^2CP80[8=?0P2/Pdd20:^2C080
ZX5;0P2YP4X0102^QE40[HA@0:f4D02]Q5030:b3C`030:^2CP2]PTd0[H9=00H0[H9=2`2]PTl20:b1
CP<0Zh1=2@2]PTl30:j3D080[hAA0P2`QE820:j5C`<0[hI@00<0[XE?0:b3C@2[PT`0202/Pdd80:f4
D0P0[HA>0P2^QDl0102_QU00/8MA0;68DP2bRE<20;68DP030;27D@2_QU80[hIB00H0[hIB0`2^QE42
0:n6DP<0/8MC0P2]Q5030:j5D@<0[hIB00@0/hYF0;:9E@2bRED0/HQD0P2`Qe<20:n6DP040:j5D@2]
Q500[HA@0:f4D080[8=?0P2[PTh0202aQeL0/8IF0;26E02`Qe<0[hIB0:n6D02_QTh0[XE=202`QU@0
0`2bR5H0/HME0;26E0020:n5D`030;26E02aQeD0/XQF00<0/HIC0`2bQe@20;>8E@80/8MC0P2aR5@3
0;:9E@030;>:EP2bRED0/XUE00T0/XUE00D0/HQD0;27D`2`Qe<0/8MC0:n6DP040;:9E@80/HQD0P2`
Qe<20;68E0@0/hYF0`2aR5@01`2bRED0/hYF0;F<F02eS5P0/hYF0;:9E@2aR5@00P2dQU@00`2bQe@0
/HQD0;28E0020:j9E0030:f:E02aR5@0/XUE0080/XUE0P2cRUH20;B;E`<0/8]G0P2aS5P30;:=F@T0
]8]G00P0/hYF0;B;E`2eS5P0]HaH0;B;E`2cRUH0/XUE0;68E0<0/hYF0P2bRED30;68E080/hUI00@0
/hUG0;:9E@2bRED0/HQB0P2aR500202aRD`0/HU>0;::C`2bRE40/XUC0;68E02_QE<0[XAB0`2^RE@2
0:n:E@<0/8]F0P2_RUH30:j9E@<0[HQD202`Qe420;68DP060;27D@2_QU00/8MA0;68DP2bRE<0/hYD
0P2`QE020:n4C`@0[X=>202/Pdl30:j5C`80[HA>2`2/Pdd01P2^Q4P0[XA:0:j4BP2^Pd`0[X=>0:j3
D080[X9A00<0[HA@0:b3C`2[PTh00`2[PTh00`2/Pdl0[HA@0:b3C`020:b3C`80[HA@0`2^QE430:Z1
B`80Zh9<0`2/Pdd0202_QdX0[hM<0:j6B`2^QDd0[HA>0:f4D02]Pe40[89@0P2/Pdl40:j5D@/0[8=?
0`2/PU020:f3D@<0[XAB0P2^Pe030:f2C`<0[85>202]PTl00`2ZOdX0Zh1;0:f2C@020:j3CP030:f2
C@2[P4/0ZWm:0080[89@00H0Zh9>0:^2C02ZPDT0ZX970:V1AP2YPD@20:V0B0040:Z1B`2[PTh0[8=?
0:b2D080[H=C00<0[XE?0:f4CP2[PT`00P2YP4X00`2ZPD/0Zh9<0:b3C@080:b3C@0;0:b4A`2/Q4T0
ZX970:Z1B@2ZPD/0[8=?0:f3D@2_QE<0[XEA0:b3C`2[PTh00P2ZPDd00`2[PTh0[8=?0:j5D@080:b3
Ca00Zh9>00P0Ygi60:QoA`2XOdT0Z7m;0:V0C02YOdd0ZGm?0:Z0D080ZX5=0P2[PTh0202/Pdl0[HA@
0:j5D@2^QE40[hIB0:b3C`2[PTh0[8=?0P2_QU800`2/Pdl0Ygi:0:Z1C@070:Z1C@P0Zh9<00<0ZX59
0:^2BP2/Pdd00P2]Q500102^QE40[XAB0:f3D`2/PU850:V0C0@0Z7m;00L0ZH1<0:^2CP2/Pdl0[8=?
0:^2CP2YP4`0Z7m;00P0[8=?402[PTh20:b0C`030:b1CP2/PD`0[85:0080[89800@0[8960:b3B`2/
Pd/0[8==0P2/Pdl00`2/PU00[89B0:b2DP020:UnB`80ZWm<00D0Zh1=0:b1CP2]PTl0[H9?0:Z2A@02
0:Z2A`030:Z1B@2ZPD/0ZX5=0080ZX1>0`2YP4`20:Z1C@<0Zh9>202[PT`20:b3B`040:b3C@2[PTh0
Zh9>0:Z0CP80ZX1@00H0Zh=60:^3B02ZPTL0ZH180:MnB02VODT20:EkB@030:YoBP2YOTT0Z7e80080
Z7e800@0ZWm:0:^0B`2]PTd0Zh1;0`2ZOdX30:UnB@090:QmB02ZPD/0ZH1:0:MnB02VODL0YGa60:Im
A`2WOTP0Z7m900P0ZH1<0P2XOd/30:MnBP<0YWe900<0YGa60:ImA`2XOdT00`2YP4X0102WOTP0YWe7
0:ElAP2RNDD30:=jAP80Y7]70P2UO4P40:ImB@@0YGa80P2VODL30:ElAP<0Y7]50`2VNdH30:EjA@80
Y7U4202UNTD80:EjA`80YW]80P2UNTL30:AiAP030:=hA@2PMT@0X7I400H0X7I400<0XGE40:9fA@2S
MdH00P2TN4L00`2SMdH0XWI50:5eA0030:1fA080XGM50`2RN4H00`2ONTH0X7]70:5lB0030:5lB003
0:1kA`2ONTH0WWU500L0WWU500@0WgY60:1kA`2PNdL0X7]70P2QO4P20:9mB@P0XgU700<0WWE109mf
@P2PMd<00P2RNDD00`2PMd<0WgI209ie@@080:9iA@0409ag@`2MN4@0WGQ409ehA0@0WWU50`2LLcl0
202MM400WgI20:5hA02SNTH0YGa809ie@@2OMT80X7M3102QN4@20:1g@`0409ed@02NMD40WWE109ie
@@80WgI20P2PMd<0202RNDD0XGQ409mf@P2NMD40WGA009ie@@2OMT80X7M30P2QMT<20:1e@P<0WgA1
00L0WW=009]b?P2KLCl0Vg4o09ab@P2LLD@0WG970080WG98202JL3h00`2GKC/0VFlm09Y`?P0309ab
@00509Y`?P2IKcd0VFi109U^@@2HKD000P2GK3l00`2FJch0UFXm09EZ?@0309E_@080UW110`2GLD88
09]`@`P0VVm2202HKS`809U_?@0609]_@P2JKT40VFe009Q/?`2GJch0V6`o0P2IKD00102GK440UV]0
09AY?P2BIc`2095V>`04099W?02CJ3d0Uf`o09I[?P@0UFXm00D0UV/n09M/?`2CKCh0Tfdn099/?@02
095[?004091Z>`2?JCX0SfTj099W>P80TfPk00<0UFXm09I[?P2GK3l00P2HKD03091Z>`80SfTj0`2>
J3T2099X=P0309AZ>02EJcT0UF/i00<0UF/i00@0U6Xh09I/>P2FK3X0UV`j0`2EJcT:09AZ>080T6Xk
0P2?JCX208iX>@80SFLh202?I3L8091U>P80Sf@i0`2@ICX3095V>`03091Z>`2?JCX0SFLh0080S6Hg
00h0SFLh08mY>P2@JS/0S6Hi08US=P27HC@0RF<f08eW>P2>J3/0S6Hi08US=P2<IcX0SFPk08iY?080
SfXm00<0SVTl08eX>`2<IcX00`2=J3h[ooooo`00:_ooool208IO=P0908EN=@24GC@0Pe`c089K<P21
FS40P5T`08EN=@24GC@0Pe`c0080PEXa00<0Pe`c08AM=025GSD00P23G3<208AM=080QEhe0P26GcH0
202:HcX0RF8i08QQ>027H3L0R64h08UR>@2;I3/0S6Dl202<H3T00`2:GSL0Relh08eQ>P0208iR>`03
08eQ>P2;GcP0RUhg00P0S64f00<0SV<h08eR=`2<HCH00P2;H3D0102<HCH0SF8g08iS>02?Hc`308iR
>`80SF4j0P2<H3T908aU?080Sf@i0`2@ICX3095V>`D0TVDk0`2CIS`7095T>P04099U>`2DJ3/0TfLj
099V>@80TFDh00<0TVHi09=W>P2DJ3/00P2AICP2099V>@80TfLj0P2DJ3/809IZ?@80U6Pi00<0U6Pk
09AW?@2DIch00P2DId002@2DIT80UFTl09AX>`2BIST0TFDh099V>@2DJ3/0Uf/n09U]@00209Q/>`80
VFdl102JKSd01@2JKT40VFe009U]@02HK3l0Uf/n0080UVXm00<0UFTl09EZ?@2EJSd00`2GK3l01P2E
JSd0TfPk099W>P2CJCT0U6Xj09I/?0<0V6hn00@0Ufdm09I/?02DJ3/0U6Pk0P2EJC`309IZ?@0409M[
?P2HK3l0V6`o09Q/?`80VFe00`2JKT40202GKSP0V6li09U`?02JL3h0VW1009Q]@02FJch0UFXo0`2H
K3/00`2IKC`0VVhm09Y^?@0409]_?P80W70o102MLD0309]c@00309Yb?`2ILCh0VG4n0080V70m00D0
V6]109U]@02IKD00VVho09]_?P0209aa?P80WG8m0`2MLD0309ib@@80Wg=20`2MLD0509ib@@080:5f
@@2PMD00WgA109ib@@2OLd@0X7A70:9fB@2TMdd209ic?P<0Wg@o0`2PMD000`2RMd@0XGI30:1e@P02
09md@@040:1e@P2QMT<0XWM40:5f@`<0XWM40P2SN4D20:AiAP<0YGE50`2VMTH20:MgA`P0XgM6202U
NT<00`2QMT<0XWM40:AiAP030:IkB0040:EjA`2TNDH0ZGU80:UiB0<0Z7Q70`2WMdH20:AhA`80YGU8
0`2VNTT00`2WNdX0Z7e60:QmAP060:QmAP80ZGe@00<0ZGe>0:UmC02YOT/00P2YOTT00`2YOTL0ZH1<
0:V0C0060:V0C080[85:00@0[85<0:b1CP2/PDh0[81?0P2/P540402_OD`0[Wi=0:moCP2_PDl0[H9?
0:^2CP2YPDd0Z81<0:ImB@2WOTX0ZH1<0:^2CP2/Pdl0Zh9>0:Z1C@2YP4`20:YoB080Zh190P2/PDX3
0:f2B`P0[H9?202[P4T0102[P4/0[85<0:b1C02/PD`20:f2C@80[X=>0`2ZP4h30:UoC@80Z7i<202Z
PDd@0:^2CP80[X=@0P2]PTl30:b1CP090:^0C@2/PU00[89@0:b3C`2]Q4h0[HA<0:f5BP2^QT/0[XI9
00P0[89800P0Zh1;0:b1C02]PTd0[X=>0:f2C@2/PD`0ZWm:0:QmB0P0ZGi9402ZOdX00`2XO4/0ZGe<
0:YnC@020:YnC@030:QlB`2VNTT0Y7Q700/0Ygi:0P2XOd/30:V0C0<0Zh1;0`2ZOdX20:UnB@<0Ygi:
0P2XOd/40:V0C0050:^0B`2ZOdX0ZWm:0:UnB@2WO4L00P2VNdH0102UNTD0Yga70:MlA`2WO4L20:Qm
B0<0ZGi9202XODX:0:UnB@<0ZWm:0`2[P4/80:UnB@80[X=>0`2]PTd30:b1C080ZH1<0P2ZPDd20:^2
CP80[8=?0P2/Pdd20:^2C080ZX5;0P2YP4X00`2]Q500[8=?0:b3C`020:^2CP80ZX5=00<0ZH1<0:f2
C@2]PTd01P2]PTd:0:f2C`80[85>102[P4d80:f2C`<0[X=@0P2_Q5430;25DP030:f4CP2^QDl0/8MA
0080/8MA00<0[XE?0:b3C@2[PT`0202/Pd/80:n6DPX0[HA>00L0[hI@0;68DP2bRE<0/hYD0;:9D`2a
R580/8MA00@0[XEA102_QU820:j4DP80[hEC102`QU@30:f4D0030:j5D@2_QU80[hIB0080/8MC1@2a
R5@60;27D`80[hIB0`2^QE420;67E`040;26E02`Qe<0[hIB0:n6D080[XE=202^Q5800`2cREL0/XQF
0;26E0020:n5D`030;26E02bR5H0/hUG00<0/hEC0`2dQU@20;F7E@<0/8MC0P2aR5@30;:9E@P0]8]G
00T0]HaH0;B;E`2cRUH0/XUE0;27D`2_QU80[XEA0:f4D02cRUH00P2bRED20;68E080/8MC00@0[hIB
0;27D`2aR5@0/hYF0P2dReL01P2cRUH0/HQD0;27D`2_QU80/HQD0;:9E@80/hYF00<0/XUE0;68E02_
QU800P2dQU@00`2bQe@0/HQD0;28E0020:j9E0040:f:E02bRED0/XUE0;:9E@80/hYF0`2dReL30;2:
F@030;6;FP2bS5/0/XaK0080/heL1P2dReL40;F<F0030;B;E`2bRED0/HQD0080/HQD0P2bRED30;>:
EP80/XUE0`2aR5@00`2dRUX0/hUI0;>9E`020;:9E@0<0;68DP2aR500/8M?0;28B`2aRD`0/XY?0;>;
D02bRE40/HQB0:n6DP2]Q500[HQC0P2^RE@20:n:E@80/8]F00<0/HaG0:n9F02_REP00`2^R5L30:f7
EPP0/8MA00<0/hYD0;68DP2`Qe400`2^QDl00`2`Qe40/HQB0;66D@020;25D080[hA?0P2^Pdh00`2]
PTd0[8=?0:b3C`060:b3C`030:n6D02^QDl0[XE?0080[HA>0P2/Pdd00`2[PT`0[8==0:b3C@060:b3
C@060:j4B02^Q4X0[XA:0:j3C02^Pdh0[X=@0P2^PU420:^2CP040:b3C`2]Q500[HA@0:b3C`80Zh9>
0`2/Pdl20:f4D0<0[XEA102ZPD/20:^2C080[8==00H0[XI90:j6B`2^QT/0[HA<0:f4CP2]Q5020:b2
D0030:^2CP2/Pdl0[XEA0080[hIB00<0[XEA0:b3C`2[PTh02@2/Pdl30:j4E080[H=C0`2/PU820:j3
D0<0[H9?0`2/PDh80:f2C`030:aoB02]P4T0[X5:0080/8=<00<0[X5:0:f0B@2/OdP00P2/PU001P2[
PTh0Zh9<0:Z1B@2ZPTL0ZH560:V1A080Z7m700T0ZH1:0:Z1C@2[PTh0[89@0:f3D`2^Q5@0[XE?0:f4
CP2[PT`00`2YP4X00`2ZPD/0Zh9<0:b3C@070:b3C@0;0:b4A`2[PdP0ZX970:Z1B@2ZPD/0[8=?0:j4
DP2_QE<0[XEA0:b3C`2[PTh00P2ZPDd00`2[PTh0[8=?0:j5D@0@0:b3C`P0Zh9>0P2WOd@01`2WOTH0
Z7m90:V0C02YOdd0ZX1>0:Z0D02[PTh01`2/Pdl0102_QU80[8=?0:^2CP2]Q5020;27D`030:b3C`2W
OTX0ZH1<00L0ZH1<202[PT`00`2ZPDT0Zh9:0:f4CP020:j5D@040:n6DP2^Q580[H=C0:b2DP80ZX5=
0P2YP4`01`2XOd/0Ygi:0:ImB@2VODT0Z7m;0:V0C02ZPDd00P2[PTh00`2ZPDd0ZH1<0:QoB`080:b3
C`P0Zh9<202[PTh20:b0C`030:b1CP2/PD`0[85:0080[89800@0[8960:b3B`2/Pd/0[8==0P2/Pdl0
0`2/PU00[89B0:b2DP040:YoC0@0Zh1=00H0ZX950:Z2A`2ZPTL0ZX590:Z1B`2ZPDd20:Z0CP80ZH1<
0P2ZPDd40:^2CPP0[8==0P2]Q4`0302/Pdd0[8=?0:^2CP2[PDl0Zh5A0:Z0D02ZPTD0ZX970:V1AP2X
OdL0Z7m90:MnBP80YWa:00<0Zh1;0:YoBP2YOTT00P2XODP00`2ZOdX0[85<0:f2C@020:^0B@80ZWm8
00@0ZGi70:QmAP2XODH0Z7e60P2WOTH30:ElA0030:MnAP2YP4P0ZX5900P0ZH1<0`2XOd/00`2WOTX0
YWe90:ImB@020:ElB0040:ElAP2VODL0Ygi80:QoB@80ZH1:00<0Z7m90:ImA`2UO4H00P2RNDD30:=j
AP<0Y7]7102UO4P40:ImB@D0YGa60`2VODL20:MlA`80YW]600@0YGY50:AiA02TND@0Y7U4202SN4<8
0:=hA@<0YW]80P2UNTL30:AiAPP0XGM700<0XGE40:9fA@2TN4L00P2UNDP0102TN4L0XWI50:5eA02P
MT@30:5gA@80XWQ60P2SNDL00`2MMdH0WWQ70:1jB@020:5kBP030:1jB@2NN4L0WGM600P0WWU50`2P
NdL20:5lB0<0XWe9202SNDL00`2OMT80XGQ40:9iA@020:=jAP030:9iA@2QN4@0WgI200P0XgY60`2P
NdL309mjAP80WWU50P2MM40209ac?`0609ed@02OMT80XWU50:=jAP2OMT80X7M30`2RNDD20:5hA004
09mf@P2MM400WGA009ed@0<0WWE10`2OMT80202RNDD0XGQ409mf@P2NMD40WGA009ie@@2OMT80X7M3
0`2QMT420:1e@0<0Wg@o00H0Vg8n09ab@02LLT00W79209ebA@2MLTL209icB@P0VW1000<0VFlm09Y`
?P2LLT000P2LLT000`2JL3h0VFlm09M]>`0209]`@`0409Y_@P2IKT40V6e009M/?`80UV/n0`2EKd02
09I`@@<0Ug52202KL4<809Y_@PP0V6hl202IKcd00`2HK3l0Uf/n09IZ?@0209EY?00709M[?P2IKD00
VVi109Q]@`2FJd40U6To099W?@03095V?004099W?@2EJSd0UV/n09M/?`80V6e000<0Uf`o09I[?P2E
JSd0202AJc`209Q]@0@0Uf`o0P2FJch0102EKd00U6ho09A^?`2DKSl209=]?P80TV`m00<0U6Xh09=Y
=`2CJCL00P2CJCL00`2DJSP0UV`j09I/>P0409I/>P<0UF/i0P2DJSP809I/>P80T6Xk0P2?JCX208iX
>@80SFLh202?I3L;095V>`<0T6Dj0P2?I3T00`2>J3T0SFLh08aV=`0208]U=P0>08aV=`2=IcP0SVPi
08eW>P2:I3L0R68e08YT=`2>J3/0T6Xm08eW>P2:I3L0S6Lj08eX>`2>JC`208mZ?@0308iY?02<IcX0
RfHi00<0SFPn:oooool002[ooooo0P26GcH00`25GSD0Q5dd08=L<`02085J<@04081I<025GSD0Q5dd
08=L<`80PEXa00<0Pe`c08AM=025GSD00P23G3<208AM=080QEhe0P26GcH00`2;I3/0RF8i08QQ>002
08MP=`0308UR>@2;I3/0SFHm00P0S60i00<0RUhg08aP>@2=HCX00P2?Hc`00`2=HCX0S60i08YN=`08
08]P=@0308mT>@2=HSL0S64f0080RUld00@0S64f08eR=`2?I3T0T6@o0`2?Hch208iR?@80SF4l2@2<
IC`208mT>@<0T6Dj0`2AIS/409=V?0L0TVDk0`2AI3X2091S>@0309AX>`2CIcX0TVHi0080TFDh00<0
TVHi09=W>P2DJ3/00P2AICP2099V>@80TfLj0P2DJ3/809IZ?@80U6Pi00<0U6Pk09AW?@2DIch00P2D
Id002@2DIT80Uf/n09AX>`2AICP0SV8e08mS=P2BIST0UVXm09U]@00209U^>`80VVll0P2KL3d209aa
?P0H09]_@P2JKT40VFe009Q/?`2GJch0UVXm09EY?02DJ3/0U6Tl09EZ?@2GK3l0V6e009M/?`2EJSd0
TfPk099W>P2CJCT0UF/k09M]?@2HKSh0VFlo09Q^?P2GKCd0UF/k0`2DJ3/209EY?0<0UVXm0`2HK3l3
09U]@080VVi100P0Ufhh09Q_>@2IL3`0VW0n09U_?`2HKD00UV/n09EZ?`80Uf/j0P2HK3/00`2IKC`0
VVhm09Y^?@0309]_?P80W70o0`2MLD001@2NLT40Vg=009Yb?`2JLSl0VG4n0080V70m0P2GKc`01@2G
JT00Uf/n09Q/?`2IKCh0VVhm0080Vg0m0P2LLC`309ea@0<0WW910P2OLd8609ib@@80WG5000P0XGI1
0:1e@02NLd00WW9109ib@`2PM4L0XgM:0:AgC@<0WW<n0P2OM3l30:1e@0030:=hA@2QMT<0WgA10080
WW=000<0WgA10:5f@`2SN4D0102RMd@20:=hA@80Y7U60`2UMDD30:IfAP80YgM7202RMTD80:Ej@`09
0:1e@P2QMT<0Y7U60:IkB02WO4T0YW]80:EjA`2TNDH0ZGU80080Z7Q700D0YgM60:IfA@2UMD@0YGE4
0:Ad@`020:AhA`80YGU8102VNTT80:QmAP80ZGe@0P2YODh0102YOD`0ZGi;0:UnB@2YOTT80:V0C080
[85:00@0[85<0:b1CP2/PDh0[81?0P2/P540402^O4/0[Wi=0:moCP2`PU00[X=@0:^2CP2YPDd0Ygm;
0:ElB02WOTX0ZH1<0:^2CP2/Pdl0Zh9>0:Z1C@2YP4`20:YoB080Zh190P2/PDX30:f2B`P0[H9?202[
P4T40:b1C080[H9=0P2^Pdh30:Z0CP<0ZGm=0P2XOT`80:Z1CA00Zh9>0P2^Pe020:f2C`@0[85>0P2[
PDl01P2/Pdl0[HA>0:f4C02^QT/0[hM<0:n7BPP0[89800P0Zh1;0:b1C02]PTd0[X=>0:f2C@2/PD`0
ZWm:0:QmB0P0ZGi9402ZOdX00`2WNdX0Z7a;0:YnC@020:YnC@030:QlB`2UNDP0Y7Q700/0Ygi:0P2X
Od/30:V0C0<0Zh1;0`2ZOdX20:UnB@<0Ygi:0P2XOd/40:V0C0060:^0B`2ZOdX0ZWm:0:QmB02WO4L0
YW]60P2UNTD30:MlA`<0Z7e80P2YOTT80:QmBPX0ZGi90`2ZOdX30:^0B`P0ZGi90P2^Pdh30:f2C@<0
[85<0P2YP4`20:Z1C@80Zh9>0P2/Pdl20:b3C@80Zh9<0P2ZPD/20:V0BP80[8=?00@0Zh9>0:Z1C@2Z
PDd0ZH1<0P2XOd/80:f2C@X0[H9?0P2/PDh30:^0C@030:YoC02]PTl0[H9?00H0[H9?0P2^Pe030:n4
D@<0/8EB00P0[HA>0:j5C`2`Qe40/HQB0;27D@2^QDl0[8==0:^2C0P0[8=;202`Qe<20:j5C`@0[HA>
0P2/Pdd20:f4CP070:n6D02aR580/hYD0;>:E02bRE<0/HQB0;27D@050:j5D@<0[hIB0P2^Q5820:n5
D`<0/8ID00D0/HME0:b3C`2]Q500[HA@0:j5D@020:n6DP@0/8MC1P2aR5@30;>:EP80/XUE0`2aR5@2
0;67E`040;67E@2`Qe<0[hIB0:j5C`80[XE=202]Pe400`2cREL0/XQF0;26E0020:n5D`030;26E02b
R5H0/hUG00<0/hEC0`2dQU@20;F7E@<0/8MC0`2aR5@20;:9E@P0]HaH00T0]XeI0;F<F02dReL0/XUE
0;27D`2^QE40[8=?0:^2CP2cRUH00P2bRED00`2aR5@0/8MC0;27D`020:n6DP030;27D`2aR5@0/hYF
0080]8]G00H0/hYF0;68E02`Qe<0[XEA0:n6DP2aR5@20;:9E@030;68E02_QU80[XEA0080]8ID00<0
/XMD0;68E02`R5@00P2^RE@00`2]RU@0/XUE0;:9E@030;>:EP<0]8]G0`2`RUT00`2aReX0/XaK0;>=
G0020;>=G0D0]8]G102eS5P01`2fSET0]8]G0;68E02_QU80[XEA0:n6DP2bRED0102cRUH20;:9E@<0
/HQD0P2dRUX0102cREL0/XUE0;:9E@2aR5820;27C`080;28BP2aRD`0/h]>0;>;D02cRU80/HQB0:j5
D@2]Q5020:f8D`040:j9E02_RUD0[hYE0;2;EP80/HaG0P2^RUP30:f9E`<0[8QF202`Qe40202cRU@0
/XUC0:n6D02]Q4h0[8==0:f4CP2^QDl0[hI@0P2aQU420;25D0040:n4C`2^Pdh0[X=>0:f2C@P0[8=?
0P2_QU00102^QDl0[HA>0:f4CP2/Pdd20:^2C0P0[8==00H0[XA80:j4BP2^Q4X0[X=<0:j3CP2^Pe02
0:j2D@030:V0C02[PTh0[HA@0080[hIB00<0[HA@0:^2CP2YP4`00`2/Pdl20:f4D0<0[XEA00@0ZH1:
0:Z1B`2ZPD/0ZX5;0P2[PT`20:b3C@060:j6B@2^QT/0[XI;0:f4C02]Q4h0[8=?0P2/PU000`2[PTh0
[8=?0:j5D@020:n6DP030:j5D@2/Pdl0Zh9>00T0[8=?0P2_QED0102^Q5@0[H=C0:f3D`2/PU820:^1
D@80[X=@0`2]PTl30:b1CPP0[H9?00<0[7m80:f0B@2^PDX00P2_PT/00`2^PDX0[H190:aoB0020:b2
D00D0:^2CP2[PT`0ZX590:Z2A`2YPDH0ZH540:MnAP2XOdL0ZH1:0:Z1C@2[PTh0[89@0:f3D`2^Q5@0
[XE?0:f4CP2[PT`0ZH1:0:QoB@2YP4X20:Z1B`P0[8==00/0[8A70:^3B02ZPTL0ZX590:Z1B`2/Pdl0
[XAB0:n5D`2^QE40[8=?0:^2CP020:Z1C@030:^2CP2/Pdl0[XEA0100[8=?202[PTh20:In@`040:Mn
AP2XOdL0Z7m90:V0C080ZX1>0P2]Q5030:b3C`<0Zh9>00P0[hIB0:b3C`2[PTh0[XEA0;68E02`Qe<0
[8=?0:MnBPP0ZH1<202[PT`00`2ZPDT0Zh9:0:f4CP030:n6DP030:n5D`2]Pe<0[89B0080Zh9>00@0
ZX5=0:V0C02WOTX0YWe90P2UO4P00`2WOTX0ZH1<0:Z1C@020:^2CP030:Z1C@2YP4`0Ygi:00P0[8=?
202[PT`80:^2CP80[81?00<0[85>0:b1C02/PDX00P2/PTP0102/PTH0[8=;0:b3B`2/Pdd20:b3C`03
0:b2D02/PU80[89B0080Zh1=1P2ZOd`01P2ZPTD0ZX970:Z2A`2ZPDT0ZX5;0:Z1C@80ZX1>0P2YP4`2
0:Z1C@<0Zh9>00<0[8=?0:b3C@2/Pdd01P2/Pdd20:f4C0040:b3C@2/Pdl0Zh9>0:^1C`80Zh5A00H0
ZH540:V1AP2XP4D0Z7m70:QoB@2XOd/20:MmB`080:^0B`2ZOdX0ZGi90:QmB02YOTT0ZWm:0:b1C02]
PTd20:^0B@040:YoB02YOTL0ZGi70:QmAP80Yga500P0YWe50:ElA02TNd<0Y7]30:ImA@2XOdL0ZX59
0:b3B`T0ZH1<0P2XOd/00`2WOTX0YWe90:ImB@020:ElB0040:AkA@2UO4H0Ygi80:QoB@80ZH1:00<0
Z7m90:MnB02VODL00`2RNDD20:=jAP<0Y7]7102UO4P40:ImB@80Y7]50P2UO4H20:ImA`80Ygi80P2W
O4L20:IkAP040:EjA@2TND@0Y7U40:=h@`P0XWM2202RMd@30:IkB0<0YGY70P2TNDH80:9hB0030:5e
A02RMTD0Y7Q70080YGU800<0Y7Q70:9fA@2QMD@0102QMdD20:9hAP80XgU700<0VgM509ahAP2NNTP0
0P2ONdT00`2NNTP0W7Q609]gA@0809iiA@80X7]70`2QO4P30:9mB@80XWQ6102SNDL20:AjB0030:1g
@`2RNDD0XgY60080Y7]700<0XgY60:9iA@2PMd<0202SNTH01@2SOTX0XWe90:9mB@2QO4P0X7]70080
WgY600/0WWU509ie@@2MM400W7<o09]b?P2LLcl0WWE10:5hA02RNDD0X7M30:5hA0020:=jAP050:9i
A@2PMd<0X7M309ie@@2LLcl00`2MM40209ie@@<0WgI200P0XWU50:5hA02OMT80WWE109ed@02NMD40
WgI20:1g@`<0XGI10`2PMD0209md?`0609ac?`2LLT00W79009ab@P2MLTD0WG970P2NLdT809Y`@080
Vg4o0`2LLT000`2JL3h0V6hl09I/>P0209aaA00409]`@`2JKd80VFi109Q]@080Uf`o0`2EKd0209I`
@@<0Ug52202KL4<809Y_@PP0V6hl0P2JL3h409U_?@80V6hl00`0UVXm09EY?02DJ3/0TfLj09AX>`2F
JSd0VFe009Y^@@2HKD<0UV]109AY?`2BIcd2091U>`80TFHl00<0TfPk09EZ?@2HKD000P2IKT400`2H
KD00UFXm09=X>`03091Z>`80TF/l0`2BK3d0202NLdH0WG9509]`@`2IKT40Uf`o09EZ?@2DJC`0TfPk
0`2ILd@209Qb@`<0Ug5200<0UVdi09A[=`2BJCD00P2AJ3@0102CJSH0UVdi09I]>@2HKc/309I/>P<0
UF/i0P2DJSP809M^>P80T6Xk0P2?JCX208iX>@80SFLh0P2@ICP408mT=`80SV<f202BIc`01P2CJ3d0
TVLl099W?02AIS/0T6Dj08mT>@80SV<h00<0SFLh08aV=`2;ICH00P2:I3D03@2;ICH0S6Hg08eW>02>
J3/0RfDh08US=P2;ICP0SfTl091Z?@2>J3/0RfDh08aW>P2=J3/00`2?JSd00`2>JC`0S6Lj08]V>@03
08aW?B_ooooo000Zooooo`80Q5`i00H0Pe/g089K=022Fc80PEX_081I;P20FRd408AM=080Pe`c0P22
Fc8308YM=P<0RE`e0P28Fc@308YM=PD0RE`e0P2<HC@0102;H3D0RUle08YN=`29GCP208QL>@P0SF8g
0`2;GcX00`2<H3/0SF4l08iR?@0208iR?@08091W<`2?IS80SfDe08iS=P2=HSP0SF4l08aP?@2<Gch8
08eR=`<0SV<h0`2?I3T5091U>P80TFHk0`2BIc`0102CJ3d0TFE0095U@02AID03091T?`80Sf<n00P0
Sf8h091S>@2AI3X0TVDk09=V?02DIcd0UFPn09IY?`80Tf@h00d0TVHi095V>@2AJ3X0SfTj091Z>`2?
Jc/0Sf<f091T=`2AICP0TVHi09=W>P2DJ3/0UFTl00@0UVXm0P2EJC`309AX>`03091S>@2BIC/0U6Lm
0080UVTo00<0UFPn09AW?@2CIS`00P2EJCP309IZ>@<0Uf/j202GKC/209=Z?00309EZ?@2FJSd0V6Tm
0080VVTn00<0W6Tn09AX>`2FJSd00`2HK3l02`2EJC`0TVHi091T=`2GJch0UVXm09EY?02DJ3/0UFTl
09IZ?@2HK3l0VFe000P0Uf`o00@0Vfln09Y^?@2JKSd0VFdl0P2HK3/209M[>P<0VFhk0P2JKc`309]`
?@P0Vfln0P2JKSd309]_?P<0W70o2@2NLT40102LL3l0VVhm09U]?02IKC`209Y^?@0B09a`?`2NLT40
W6m509eaA02NLTD0X7A50:1d@`2NLd00WG8m09aa?02QMT<0X7E209eb?`2LLCh0Vg0m09aa?P2NLd00
WgA1202QMT<0202OMd<0WWI209ee@@2LM400WGE109if@P2PN4@0XGU5202PMD8209ie?`0309mf@P2O
MD<0X7I60080X7E800L0X7E:0:QfA@2VMTD0YWI50:EgA@2SN4D0XWU50080XGU50P2TN4T30:EiBP<0
YWY;0P2WNdX01P2WO4T0Yga70:QmAP2XOT@0ZGm50:Uo@`<0XgQ50P2TNDH30:EjA`80XgQ500<0Y7U6
0:EjA`2VNdP00P2WO4T90:QmBP030:YoC02XODX0Yga90080YW]800@0Yga90:QmBP2ZOd`0Ygi:0P2X
Od/00`2YP4`0ZX5=0:Z1C@020:^2CPP0Z7i>00H0YWe50:MnAP2WOTP0ZH1<0:Z1C@2[PDl20:b2DP80
ZWi?00@0ZWi=0:YoC02ZOd`0ZWm:0P2ZOdP20:V0C0040:Z1C@2[PTh0Zh9>0:b3C`80[HA@2@2/Pdd0
102XODX0ZGi;0:UnB`2ZOd`20:^0C@80[85>202/PD`0202/PDh0Zh1=0:YoC02YOT/0ZWm<0:^0C@2]
PTl0[hAA0P2/Pdl20:^2CP80ZX5=0P2YP4`30:^0C@D0ZWm<0`2/Pdl00`2[PTh0ZX5=0:V0C0020:V0
C080[X1>00<0[85>0:^2CP2ZPTh00P2XPdh00`2WQ4h0[H9?0:f2C`030:f2C`<0[85>0P2ZPDT20:^2
BP040:b3B`2]Q4`0[HA<0:j5C@<0[8=?0P2]Q5030:j5D@80[X9A00<0[H9?0:f2C@2]PT/00P2/PTP0
1P2/PTH0[h550:n1A@2_PDH0[h180:n0BP80[h1<00L0[gm>0:b2B02/PTP0Zh570:Z0AP2XOT@0Yge3
0080YWa22@2ZOd`20:UnB`030:QmBP2WO4T0Yga90080YW]80P2WOTP00`2XOdT0ZH1:0:Z1B`020:^2
C0070:b3C@2[P4/0ZWm:0:YoBP2XODP0Yga70:IkAP020:EjA@80Yg]:00<0Yga90:MlA`2WO4D00P2W
OD<01`2WOD40Ygm20:MoA02WOd@0Z7m70:QoB@2YP4`00`2YOdd80:V0BP<0Z7e80P2YOTT30:YoBPP0
Z7m;0P2[P4d0102ZOd`0ZGi;0:UnB`2XODX20:MlB@80YWe900@0Ygi:0:QoB`2XOd/0ZH1<102ZPDd0
102YP4`0Z7m;0:QoB`2WOTX20:ImB@050:UnB`2ZOd`0ZWm<0:^0C@2/PDh00P2]PTl00`2^Pe00Zgm@
0:]oD0060:]oD0P0ZWm:00<0[X=>0:f2C@2/PD`00P2[P4/00`2/PD`0[H9=0:j3CP030:n6DP@0[XEA
00<0[HA@0:b3C`2/Pdl01P2/Pdl80:b1CP<0Zh9>0`2/Pdl40:f4D0<0[XEA0`2_QU880:j5D@040:f2
C@2/PD`0[85<0:b1C0<0Zh1;00<0ZWm:0:f4D02]Q5001P2]Q5020:j5C@040:j5C`2^QE40[XEA0:j4
DP80[XAD0`2]Q5030:j5D@<0[hIB202]Q5000`2_QU00/8MA0;:9D`020;>:E0030;68DP2_QU00[XE?
00P0/8MA00P0[H=A0:n5D`2`Qe<0/XUC0;:9D@2`R4d0[hM<0:f5B0P0/XUE202[QU820:Z5D080ZhIA
102/Qe80202`R4X0/8Q;0;69CP2bRE<0/XQF0;>8F`2dREh0]8UO0P2`ReH00`2_RUD0[XUD0:f8D`02
0:b7DP030:^6D@2bR5H0/XQF00H0/XQF00@0/HQD0;:9E@2bRED0/hYF0P2dReL20;F<F080/HQ@00@0
/HQB0;68E02aR5@0/HME0P2aQeL40;27D`@0[hIB0P2bRED30;68E0<0/8MC00H0/hQM0;>8F`2bQeX0
/XQH0;:8EP2bRED20;68DP030;67E`2cRET0]8YJ0080]H]K00<0]8YJ0;>9F@2aQeL00P2cRU801P2d
ReD0]8]G0;F<F02eReT0]H]K0;J<G080/8]F0P2aS5L30;:=F0X0/hiI202cRUH80;>:E0P0/XQF0P2_
QU80102`Qe<0/HQD0;>:EP2dReL20;F<F0080;B<C`2cRe00/HU>0:n6CP2_QU00[hIB0;26E02aQeD3
0:j9E0030:f8D`2/Qe80ZhIA0080ZhIA00D0[hYC0:j9DP2^RE@0[HQD0:b6E@020:^5EP030:Z4E`2`
Qe<0/8MC00H0/8MC202_QU000`2_QU80[XEA0:b3C`020:^2CP030:b3C`2^QE40[hIB00P0[hIB0`2[
PTh30:b3C`80[HA@00P0[8=?0:^2CP2ZPDd0ZH1<0:Z1C@2[PTh0[HA@0:j5DA00[8=?202]Q5020:b3
B`040:b3C@2/Pdl0[8=?0:b2D080[89B0P2]Pe<0102]Pe40[HA@0:f4D02]Q4h20:f4C0040:QoA`2Z
PDT0[8==0:b3C@80[XEA00H0[H=A0:b2DP2[PE40[XAD0:f3D`2[PDl20:Z1C@030:^2C02]Q4`0[XE=
00P0[8=?202[PTh0202ZPDd0Zh9>0:f4D02^QE40[HA@0:Z1C@2WOTX0YGa80`2/Pdl00`2[PTh0ZX5=
0:V0C0020:V0C0P0[8==00D0[HA>0:b3C@2/Pdd0Zh9<0:Z1B`020:V0BP030:QoB@2/Pdl0[8=?00H0
[8=?00@0ZH1:0:Z1B`2ZPD/0Zh9<0P2/Pdd20:f4CP80/8MA00@0[hI@0:j5C`2/Pdd0Zh9<0P2ZPD/8
0:^2CPP0[8=?202[PT`80:MnBP80ZX5=0P2[PTh0102/Pdl0[HA@0:f4D02^QE420:^2BP040:b3C@2]
Q500[HA@0:j4DP80[hEE0P2YOTT30:YoBP<0Zh1;0`2YP4X00`2ZPD/0Zh9<0:b3C@020:b3C@<0[8=?
0`2]Q5030:j5D@80ZH1<0P2XOd/20:MnBP80YWe9202[PTh00`2ZP500Zh5A0:b2DP020:j4E0060:b2
DP2[PE40ZX1@0:QmBP2ZOd`0[85>0P2^Pe000`2]PTl0[85>0:YoC00@0:^2CP060;26E02_QE<0[XAB
0:f3D@2[PDl0ZGm=0P2XOT`80:V0C0P0Zh1;00<0YWe90:MnBP2YP4`00`2[PTh00`2ZPDd0ZH1<0:Z1
C@030:Z1C@@0Zh9>0P2ZPDd20:QoB`040:V0C02[PTh0[HA@0:n6DPP0Zh9>0P2WOTX00`2XOd/0ZH1<
0:Z1C@020:^2CP030:b3C`2[PT`0Zh9<0080ZX5;00D0ZH1:0:QoB@2XOdT0Ygi80:V1A0020:V1AP03
0:QoA`2XOdT0Ygi:0080Yge;202YP4`80:UnB@040:V0BP2XOdT0Z7m90:MnB0<0YWe70P2UO4H30:El
B0@0Y7]700<0XgY60:MlB@2WO4T01P2WO4T0202SNCd0Y7Y00:Il@P2WO4D0Yga70:IkB02TN4L0XgM6
0`2VNdH30:EjA@80Y7U40P2SNTH30:9iA@<0XGQ400L0XgQ50:9gA02RMd@0XWM40:=hA@2UNTL0Yga9
0080ZGi;00<0Z7e:0:IkB02TNDH00P2TNDH00`2UNTL0YW]80:=hC@070:=hC@0;0:1cB@2QM4X0XWE;
0:AgC@2UN4h0YgY@0:QkD@2YO580YG];0:9hB02OMDD00P2LLT800`2OMDD0XWQ80:EkB`020:ElB004
0:AkA`2SNTH0XgY60:9iA@80XGQ400/0VGA709UeA@2JMTH0VgM509ahA02MNT@0WGY209ik@`2UO4P0
Y7]70:=jAP020:9iA@030:AkA`2VODT0Z7m;0080X7I400@0XGM50:9hAP2TNTP0YG]90P2VO4X00`2W
ODd0YG];0:5gA@0209mf@P030:5h@P2UO4@0Ygi600<0YG]90`2TNTP20:=iA`0609mf@P2PMd<0X7M3
0:5hA02RNDD0XgY60P2TNdL80:5h@P80X7M300<0XGM50:5gA`2QMTT00P2QMT/04P2PMDX0X7E;0:5h
A02RNDD0XgY60:AkA`2SNTH0XWU50:1g@`2OMT80Y7Y80:9hAP2PMT@0WgE309id@P2OMD<0X7I40:5g
A@80WGQ40P2LMd<0102KMT80VWE109Ud@02IM4020:1fA00909me@`2MLd40W79009]a?`2JL3h0VFlm
09M/?`2IKT40W7540080WG9500<0W75409U^@@2GK3l0202LLT0809U_?@80U6Tl00@0UV/n09Q]@02J
Kd80W7540P2NLdH809Ud@080WG=100@0Vg4o09Y`?P2HKS`0Ufdk0P2EJcT0102JKdD0VFi409U^A02I
KT@209Q]@`80Ufa20`2FK3X209M]>`<0V6hl102GKC/409I/>P0309Q]@02FJch0U6Tl00<0TVLj00@0
U6Tl09EZ?@2EJT00UFY00P2FJd4209M/@P80V6e300H0UF`h09I/>P2FK3X0Ufdm09M/?`2HKD8209U^
A080UG5100T0U71009=_?`2BKSh0TFdm091/?02?Jc/0UF/i09I/>P2GKC/00P2HKS`00`2GKC/0UV`j
09E[>@03091[=`80TF`h102BKCT209U^@@0609Q]@02FJch0U6Tl09=X>`2BIcX0TFHi102FKCL409M^
>00308eX<`2>JC@0SfXe0080T6/f00h0SfXe08iY=02=J3<0SfXm08mY?02=IcX0SVDi08iS>02@HcT0
Tf@j09AU>`2FJd00UFXo09=X?@80TVLl00/0TfPm09EZ?`2FJd00SfPo08iW?P2=ISd0S6Dl08YS>P28
HCP0Qf0g08IO=P0208YT=@0408]U=P2<ISL0S6Hg08eW>080SVPi202=IcX808aV>@<0R68e:oooool0
02[ooooo0P24G3T00`23FcL0Pe`e089K<P02085J;`03085K;P25GSD0Q5dd0080Q5dd0P23G3<2089K
<PP0Qe/d0P2:GSL608UM=P0808aQ=02;H3<0Rf0e08YO=@2:GSL0REdh08UM>P28G3T808eR=`80Relh
0P2<H3T208eQ>P80SV8k00P0SfHb08mU<`2?ICD0SV<f08eR>02=HCX0S60k08aP?@P0SF8g0`2>HcP4
08mT>@@0T6Dj0P2AIS/4099W?0<0TFDn0`2@I3d208mS?00608mR>02@HcT0TF@j099U>`2CIS`0U6Lm
0P2EJ3h209=T>006099V>@2AIST0TFPj08mY>P2@JS/0Sf/k0P2@I3L01@2AICP0TVHi09=W>P2DJ3/0
UFTl00@0UVXm0P2EJC`309AX>`03095T>P2BIC/0U6Lm0080UVTo00<0UFPn09AW?@2CIS`00P2EJCP3
09IZ>@<0Uf/j202GKC/01@2EK3h0U6/m09EZ?@2FJSd0V6Tm0080VFPm0140VfPm09EY?02FJSd0UVXm
09M[?P2FJSd0UFTl09AX>`2CIcX0Uf/n09IZ?@2EJC`0U6Pk09EY?02FJSd0V6`o09U]@00809M/?`03
09]_?P2JKSd0VVhm0080VFdl0P2HK3/00`2GJcX0VFhk09U^>`0309Y_?0<0Vg0m202KKch209Y^?@<0
Vfln0`2LL3l909ea@00409a`?`2KKch0VVhm09Y^?@80Vfln00d0W70o09ea@02LKdD0WG5409ibA@2O
Ld@0Wg=209ic@02MLSd0W74l09md@@2NLd00WG8o0080W74n00<0WG8o09md@@2PMD80202QMT<0202O
Md<0WWI209ee@@2LM400WGE109if@P2PN4@0XGU5202PMD8209ie?`0309mf@P2OMD<0X7I60080X7E8
00L0XGI;0:QfA@2VMTD0YWI50:EgA@2SN4D0XWU50080XGU50`2TN4T20:EiBP<0YWY;00P0YWY90:Mk
BP2WO4T0Yga70:QmAP2XOT@0ZGm50:Uo@`80XgQ50`2TNDH30:EjA`80XgQ500@0Y7U60:EjA`2VNdP0
Yga92P2XODX00`2ZOd`0Z7e:0:MlB@020:IkB0030:MlB@2XODX0ZWm<00<0Z7m;00<0ZH1<0:Z1C@2Z
PDd00P2[PTh80:QnCP060:ImA@2WOTH0Z7m90:V0C02ZPDd0Zh5?0P2/PU820:YnC`040:YnC@2ZOd`0
ZWm<0:YoBP80ZWm800<0Z7m;0:V0C02YP4`00P2ZPDd20:^2CP030:b3C`2/Pdd0[8==00L0[8==0P2Y
OT/20:YoC080Zh1=0P2/PDh80:b1C0080:b1CP2[P4d0ZWm<0:UnB`2ZOd`0Zh1=0:f2C`2_Q5420:b3
C`80Zh9>0P2ZPDd20:V0C080Zh1=1P2ZOd`20:b3C`80Zh9>0P2ZPDd20:V0C080[X1>00<0[85>0:^2
CP2ZPTh00P2XPdh00`2WQ4h0[H9?0:f2C`040:f2C`80[85>0P2ZPDT20:^2BP040:b3B`2]Q4`0[HA<
0:f4C0<0[8=?0P2]Q5030:j5D@80[X9A00<0[X=@0:f2C@2]PT/00P2/PTP01P2/PTH0[h550:n1A@2_
PDH0[h180:n0BP80[h1<00T0[gm>0:b2B02/PTP0Zh570:Z0AP2YOdD0Z7i40:Mm@`2VO4802@2ZOd`2
0:UnB`80Z7e:0P2WO4T00`2VNdP0Z7m90:QoB@030:V0BP<0ZX5;00D0Zh1;0:YoBP2ZOdX0ZGi90:Ml
A`020:IkAP060:EjA@2WNdX0Yg]:0:MlB@2WO4L0Yga50P2WOD<01`2WOD40Ygm20:MoA02WOd@0Z7m7
0:QoB@2YP4`00`2YOdd80:V0BP<0Z7e80`2YOTT20:YoBPP0Z7m;0`2ZOd`20:UnB`<0Z7e:00<0YWe9
0:MnBP2WOTX00P2XOd/20:V0C080ZX5=0P2YP4`20:QoB`80Ygi:00<0YWe90:YoC02ZOd`00`2[P4d3
0:b1CPP0Zgm@202ZOdX00`2^Pdh0[H9=0:b1C0020:^0B`030:b1C02]PTd0[X=>00H0[XEA0P2]Q508
0:b3C`P0[85>0`2[PTh30:b3C`D0[HA@0P2^QE430:n6DPP0[XEA0P2[P4/60:b1C0P0[HA@0P2^QDd0
102^QDl0[XEA0:j5D@2^Q5820:j4E0<0[HA@0`2^QE430:n6DPP0[HA@00P0[hI@0;27D@2bRE<0/hYD
0;:9D`2aR580[hI@0:j5C`P0/8MA00P0[XAB0:n5D`2`Qe<0/HQB0;68D02`R4d0[hM<0:j6B@P0/XUE
202[QU820:Z5D080ZhIA0`2/Qe802@2]R5<0/8Q;0;28C@2aR500/HQB0;:8EP2cRET0/hQK0;>8G@02
0:n:E@<0[XUD0`2]R5<80;:8EP030;68E02bRED0/XUE0080/hYF0P2dReL0102eS5P0/HQ@0;68D02a
R5820;68E0030;67E@2aQeL0/HMG00@0/8MC102_QU820;:9E@<0/HQD0`2`Qe<01P2bQe`0/XMJ0;:7
FP2bR5P0/XQF0;:9E@80/XUC00<0/HMG0;>9F@2dRUX00P2eRe/00`2dRUX0/hUI0;67E`020;>:DP04
0;B;E@2dReL0]HaH0;F;F@80]H]K0P2`ReH20;6<E`d0/XeH202cRUH80;>:E0P0/XQF00D0[hIB0;27
D`2`Qe<0/HQD0;>:EP020;B;E`090;F<F02dS4l0/h]@0;69CP2_QTh0[hI@0;27D`2aQeD0/XQF00<0
[XUD00<0[HQC0:b7DP2/Qe800P2[QU420:f8D@030:f8D`2]R5@0[8IE0080[8IG00<0[8II0;27D`2`
Qe<01P2`Qe<80:n6D0030:n6DP2^QE40[8=?0080Zh9>00<0[8=?0:j5D@2_QU80202^QE430:^2CP<0
[8=?0`2]Q5001`2/Pdl0Zh9>0:Z1C@2ZPDd0[8=?0:j5D@2_QU80402/Pdl80:f4D080[HA<00@0[HA>
0:f4D02]Q500[H=A102]Pe<0102]Pe40[HA@0:f4D02]Q4h20:f4C00<0:V0B02ZPDT0[8==0:b3C@2]
Q500[XEA0:f3D@2/PU80Zh5A0:j4E02]Pe<0Zh5?0P2ZPDd00`2[PT`0[HA<0:j5C@080:b3C`P0Zh9>
00<0ZX5=0:^2CP2/Pdl00P2/Pdl00`2[PTh0ZH1<0:V0C0030:b3C`030:^2CP2ZPDd0ZX5=0080ZH1<
2P2/Pdd30:^2C0<0ZX5;202/Pdl00`2ZPD/0Zh9<0:^2C0020:b3C@80[HA>00L0[XE?0;27D@2_QU00
[XE?0:f4CP2/Pdd0Zh9<0080ZX5;202[PTh80:b3C`P0Zh9<202YP4`20:Z1C@80Zh9>0P2/Pdl20:f4
D080[8=;00@0[8==0:f4D02]Q500[H=A0P2^Q5@40:^0B`@0ZWm:0P2YP4X20:Z1B`80Zh9<0P2/Pdd3
0:b3C`<0[HA@0`2^QE420:Z1C@80ZH1<102XOd/80:^2CP030:Z0D02[PE40[89B0080[XAD00/0[89B
0:^1D@2ZP500Z7e:0:YoC02/PDh0[H9?0:j3D02]PTl0[85>0:^0C@0@0:^2CP80[XAB00@0[H=A0:b2
D02[PDl0ZX1>0P2YOdd80:V0C0P0Zh1;00<0YWe90:MnBP2YP4`00`2[PTh00`2ZPDd0ZH1<0:Z1C@03
0:Z1C@D0Zh9>00L0ZX5=0:V0C02XOd/0ZH1<0:Z1C@2/Pdl0[HA@00P0Zh9>0P2XOd/30:V0C0<0ZX5=
00<0Zh9<0:Z1B`2ZPD/00P2YP4X20:QoB@070:MnB02YPD@0ZH560:V1AP2XOdL0Z7m90:MnBP020:Mm
B`P0ZH1<202YOTT30:QoB@040:MnB02VODL0YWe70:ImA`80YGa60`2VODT00`2UO4P0Y7]70:=jAP02
0:=jAPP0Yga900P0XgTm0:Aj@02VO480Yga50:MlA`2VNdP0Y7Q70:=gAPL0YGY500@0YW]60:=jAP2S
NTH0XgY60P2RNDD30:5hA080XgQ50P2RMd@01`2SN4D0YGY70:MlB@2YOT/0Z7e:0:MlB@2UNTL00`2S
N4D00`2TNDH0YGY70:=hB`070:=hB`80XGE800@0XWI90:=gBP2TN4/0YGU<0P2VNTd00`2TNTX0XWQ8
09meA@0209ec@`0309meA@2RN4P0Y7Y:0080YWe900@0YGa80:AkA`2RNDD0XGQ40P2PMd<01P2LMTT0
W7I709afA`2LMTD0WGQ409eh@`80WGQ100P0YGa80:AkA`2SNTH0XWU50:=jAP2TNdL0YWe90:MnBP80
XGM500@0XWQ60:=iA`2TNTP0Y7Y80P2UNdT00`2WODd0YG];0:5gA@0209mf@P030:5h@P2UO4@0Ygi6
00<0YG]90P2TNTP30:=iA`<0XGQ40`2RNDD20:=jAPP0XGQ20P2PMd<00`2QMdD0XGM70:5fB@020:5f
B@80X7E:0140XGQ40:9iA@2SNTH0Y7]70:=jAP2RNDD0X7M309mf@P2TNTP0XWQ60:1fA02OMD<0WWA2
09me@`2PMT@0XGM509iiA@0209ehA00309ag@`2KMT80VWE10080VGA00P2OMD<0102NM480WG=109ab
@02LLT0209]a?`0309U^@@2JKd80Vg130080W75400<0Vg1309Y_@P2IKT40202LLT0809U_?@0809EZ
?@2FJch0Uf`o09Q]@02JKd80Vg1309aaA02MLTD809Qc?`0909ec@@2LLT00Vg4o09Y`?P2HKS`0Ufdk
09I/>P2EJcT0VFi400<0V6e30P2GK48209I[@@80UF/i0`2FK3X809M]>`<0UV`j00P0V6e009I[?P2D
JC`0TfPk099W>P2CJ3/0U6Tl09EZ?@80UFY00P2FJd4209M/@P80V6e300H0UVdi09I/>P2FK3X0UV`l
09I[?P2FJd0209I[@@0409E_@02DKSl0U6ho09A^?`80Tfdn0P2BK3d00`2EJcT0UV`j09M]>`0209Q^
?00309M]>`2FK3X0UF/i0080T6/g0`2AK3P4099]>@0609Q]@02GK3l0Uf`o09I[?P2EJSd0U6Tl0P2C
J3/809I]=`0308eX=02>JCD0SfXf0080T6/g00h0SfXf08iY=@2=J3@0SfXm08mY?02=IcX0SVDi08iS
>02@HcT0Tf@j09AU>`2FJd00UFXo09=X?@80TVLl00<0TfPm09EZ?`2FJd000P2?J3l01P2=ISd0S6Dl
08YS>P29HST0R64h08MP=`<0RfDf00<0S6Hg08eW>02=IcP00P2>J3T808eW>P/0S6Hi:oooool002[o
oooo00D0Q5`i08=K>023FcL0Pe`e089K<P02089K<004085K;P25GSD0QEhe08EN=@80Q5dd0`23G3<2
08AH<@0408EI<P26FS<0QUXc08MK=080R5`e202;GcP208]P<`0408]P=@2:GcD0RUhg08UM>080REdj
202=HSL0102;GcP0S60i08aP>@2<H3T308eQ>P0608iR>`2?ICD0SfDe08iS=P2>HcP0SV<i0P2=HCX0
0`2=HC`0SF8g08eR=`0808eR=`80SV<h102?I3T4091U>P80TFHk0`2BIc`3095U?P<0T6@m0P2?Hc`2
091S>@80TF@j00@0TVDk09=V?02DIcd0U6Lm0P2CI3P01P2BIST0TFHi095X>P2?JCX0T6Xk08m[>`80
TFDh00@0TVHi09=W>P2DJ3/0U6Pk0P2EJC`309IZ?@80UFTl0`2DJ3/0102BIC/0TfHl09AW?@2EJ3h2
09IY?`0409EX?P2DIcd0UFTh09EY>0<0UVXi0`2GJcX809M]>`80UVdo00L0UV/n09M[?P2HJCd0V6Ll
09MV>`2IIS/0UVXm0080UFTl00d0U6Pk09EY?02FJSd0Uf/n09Q/?`2GJch0UVXm09EY?02DJ3/0UFTl
09IZ?@2HK3l0VFe000P0Uf`o102JKSd209U]?080V6`k00@0VFhk09Y_?02JKc`0VVll0P2KL3d209aa
?PP0Vfln0P2JKSd309]_?P/0W70o00<0WG5009a`?`2KKch0102KKch02`2LL3l0WG5009]^A02LL4<0
WW9509mcA02OLd80WW=009aa?02KL3/0WG8o00<0W74n00<0WG8o09ic@02PMD802@2QMT<0202PMd<0
WgI209ie@@2MM400WWE109mf@P2QN4@0XWU5202QMT<209mf@00309mf@P2PMT@0X7I60080XGI900L0
XGI;0:QfA@2VMTD0YWI50:EgA@2SN4D0XWU50080XGU500@0XgM60:AhA`2TN4L0Y7Q70P2UNDP40:Ij
B@030:IkB02WO4L0Yga50080Z7i400<0Z7i20:=hA@2TNDH00P2TNDH20:EjA`80YW]800H0XgQ50:Ai
AP2TNDH0YGY70:IkB02WO4T:0:QmBP030:YoC02XODX0Yga90080YW]800<0Yga90:QmBP2ZOd`00P2X
Od/30:V0C0<0ZX5=202XOT`20:MnAP060:QoB@2YP4`0ZX5=0:^1C`2[PE40[89B0P2ZOTl0102ZOTd0
ZWm<0:YoC02ZOdX20:YoB0040:MnBP2XOd/0Z7m;0:QoB`<0ZH1<00<0ZX5=0:b3C@2/Pdd01`2/Pdd3
0:YoC0<0Zh1=0P2/PDh80:b1C0080:b1CP2[P4d0ZWm<0:UnB`2ZOd`0Zh1=0:f2C`2_Q5420:b3C`80
Zh9>0P2ZPDd20:V0C0P0ZWm<00@0[8=?0:^2CP2[PTh0Zh9>0`2ZPDd01P2YP4`0[X1>0:j0CP2/PDh0
Zh9>0:Z2CP80Z8=>00<0YhA>0:f2C`2]PTl01P2]PTl30:^2C0<0[8==0P2]Q4h30:b3C`80[HA@0`2^
QE40202_Pe80[X9A0:j3D02^Pdh0[H9;0:f3B@2/PTP0[8960P2_PDD00`2_PDH0[h180:n0BP020:n0
C0060:moCP2/PTP0[8980:^1A`2ZP4H0ZGm50P2XOT@00`2WOD<0ZWm<0:YoC0060:YoC0@0ZGi;0P2X
ODX20:MlB@<0ZX5;0`2YP4X20:QoB@060:^0B`2ZOdX0ZWm:0:UnB@2XODP0Yga70P2VNdH20:MkBP03
0:MlB@2WO4L0Yga50080Yge300L0Yge10:Mo@P2WOd@0Ygm40:QoA`2XOdT0ZH1<00<0ZGm=202YP4X2
0:MlA`80Z7e80`2YOTT00`2ZOdX0Z7m;0:QoB`060:QoB`<0Z7e:0P2YOT/30:YoC0<0Ygi:0P2XOd/6
0:V0C080Z7m;0`2WOTX20:b1CP<0Zh1=0`2ZOd`80:]oCPP0ZWm:00<0[H9=0:b1C02[P4/00P2ZOdX0
0`2[P4/0[85<0:f2C@080:f4D0P0[8=?202/PDh30:^2CP<0[8=?0P2]Q500102/Pdl0[HA@0:f4D02]
Q5020:j5D@80[hIB202^QE420:YoBP040:^0B`2/PD`0[85<0:f2C@80[X=>202]Q5020:j5C@040:j5
C`2^QE40[XEA0:j4DP80[XAD0`2]Q5030:j5D@<0[hIB202^QE400`2_QU00/8MA0;68DP030;68DP03
0;27D@2_QU00/8MA00L0/8MA00P0[XAB0:n5D`2`Qe<0/HQB0;68D02`R4d0[hM<0:j6B@P0/HQD202[
QU830:^6D@80[8MB0`2]R5<0102`R4d0/HQ@0;68DP2aR5820;:8EP030;:8F02cR5/0[HQC0080[HQC
0`2^RE@20:n:E@P0/HME102bRED20;>:EP80]8]G0P2aR500102aR580/HQD0;68E02aQeD20;67E`@0
[hIB102`Qe<20;:9E@<0/HQD0`2`Qe<01P2bQe`0/XMJ0;:7FP2bR5P0/XQF0;:9E@80/XUC00<0/HME
0;>9E`2dRUP00P2eReT00`2dRUP0/hUG0;67E@020;>:DP040;>:E02dReL0]8]G0;F;F@80]H]K0`2`
ReH20;6<E`<0/XeH2@2`ReH80;>:EPP0/hYD202cREL20;27D`040;68E02bRED0/XUE0;>:EP80]8]G
00P0]8a?0;>;D02aRDh0/8M?0:n6D02`Qe<0/HME0;:8EP<0[XUD0P2]R5<30:b7DP80[8M@00<0[8MB
0:b7D`2]QeH00P2]QeP00`2]QeX0/8MC0;27D`060;27D`P0[hI@0P2^QE440:b3C`80[XEA202/Pdl3
0:^2CP<0[8=?0P2]Q500202^QE40[HA@0:b3C`2[PTh0[8=?0:f4D02_QU80/8MC602/Pdl20:j5C@04
0:j5C`2^QE40[XEA0:j4DP80[XAD0P2]Pe<0102^Q580[XEA0:j5D@2^QDl20:f4C0040:V0B02ZPDT0
[8==0:b3C@80[HA@00H0[H=A0:b2DP2/PU80[XAD0:f3D`2/PU020:^2CP030:b3C@2]Q4`0[XE=00P0
[8=?2P2[PTh30:Z1C@030:^2CP2/Pdl0[HA@00<0[8=?0P2[PTh30:Z1C@P0[8==0P2ZPD/30:^2C0<0
[8==202/Pdl20:b3C@<0[HA>0`2^QDl01P2_QU00[XE?0:j5C`2]Q4h0[8==0:^2C080ZX5;202[PTh8
0:b3C`P0Zh9<2P2ZPDd30:^2CP<0[8=?0P2]Q4`01P2]Q4h0[HA@0:b3C`2/PU00[89B0:^1D@80[H9=
00@0[85<0:^0B`2ZOdX0ZWm:0P2YOTT0102YP4X0ZX5;0:Z1B`2ZPD/30:^2C0040:b3C@2/Pdl0[8=?
0:b3C`<0[HA@0`2^QE420:b3C`80Zh9>0`2ZPDd00`2YP4`0Zh9>0:^2CP060:^2CP030:Z0CP2[PDl0
[89@0080[XAB00H0[89@0:^1C`2ZP4h0ZGi;0:YoC02[P4d30:f2C`030:b1CP2[P4d0Zh9>01L0Zh9>
202YP4`80:^0B`030:ImB@2WOTX0ZH1<00<0Zh9>00<0ZX5=0:V0C02[PTh00`2[PTh40:Z1C@030:f4
D02/Pdl0Zh9>00<0ZH1<00<0ZX5=0:^2CP2[PTh01`2[PTh30:Z1C@<0ZH1<0P2XOd/20:Z1B`80ZH1:
102XOdT01P2YPD@0ZH560:V1AP2XOdL0Z7m90:MnBP80Yge;202YP4`80:UnB@80Z7m9102WOTP30:Im
A`80Z7m;00@0Ygi:0:ElB02TNdL0XgY60P2RNDD80:MlB@080:Aj?P2UNd40YWa20:MlA@2WO4L0YW]8
0:EiB02TN4L20:=h@`040:AiA02UNTD0YW]60:IkAP80Yga700@0Y7]70:=jAP2SNTH0XgY60P2RNDD2
0:5hA00@0:AiAP2SN4D0XgQ50:9gA02SN4D0YGY70:MlB@2YOT/0YW]80:EjA`2SN4D0XWM40:5f@`2R
Md@0XgQ50:AiAPP0XgQ;202RMTT00`2TNTP0XWQ60:1fA00209id@P030:1fA02RN4H0Y7Y80080Ygi:
00@0YWe90:AkA`2RNDD0X7M30P2OMT801P2NN4/0WWQ909egB02MMdH0WGQ409ag@P80W7M00P2TNdL3
0:=jAP030:AkA`2VODT0Ygi:00<0XgU71@2TNTP00`2VO4`0Y7Y:0:9hAP020:1g@`030:9i@`2TNd<0
YWe50080YG]90P2TNTP30:=iA`030:9hAP2SNTH0XgY600<0XWU50`2QN4@80:9i@`80XGQ200<0X7M3
0:1fA02PMTH00P2PMDP04P2QMTT0XGI;0:5hA02RNDD0XgY60:AkA`2SNTH0XWU50:1g@`2OMT80Y7Y8
0:9hAP2PMT@0WgE309id@P2OMD<0X7I40:5gA@80WWU500<0WGQ409ag@`2KMT800P2JMD400`2IM400
WG=109ec@@0509ec@@0309ab@02LLD@0Vg1300@0VVm200<0Vg1309aaA02LLT001`2LLT0809Y`?P<0
V6e00P2IKT4309Y_@PP0Ug8n00T0WG=109ab@02KLCl0VW0n09Q^?02GKC/0UV`j09E[>@2HKD800`2G
K44209I[@080UFXo0`2DJSP209E[>@<0UV`j202GKC/00`2HKD00Uf`o09EZ?@0309AY?080UFXm0P2E
JSl209I[@080Ufa10P2HKD80202GKSX0UV`j09I/>P2EJc/0U6Tl09=X?@2CJ3h0TVLm0`2BK3d209=]
?P<0U6ho00<0UF/i09I/>P2GKC/00P2HKS`0102GKC/0UV`j09E[>@2@JcL3095/>080TVdi0`2CKSX8
09EZ?@0309I]>@2EK3P0UF`h00D0UF`h00<0SFPd08iY=@2?JSH00P2@JcL03P2?JSH0SVTe08eX=02?
JSd0SfTl08eW>P2>ICT0SV<h091S>@2CI3X0U6Dk09EZ?`2DJCh0TfPm0P2BIc`00`2CJ3d0U6Tn09EZ
?`0208mX?`0708iW?P2=ISd0Rf@k08YS>P29HST0R64h08]U=P0308aV=`<0SFLh00<0SVPi08eW>P2=
IcX03P2=IcX3091Z?B_ooooo000Zooooo`80Pe/h00<0Pe/g08=L=@23G3<00P23G3401023GC00QEhe
08EN=@25GSD308AM=080Pe`c00P0PEL_089H<023FC40Q5Xb08EK<`26G3@0Qede08QN=P<0RV0h102;
HCT01`2<HSX0RUlb08YO<P2:Gc@0RUle08YN=`2:GST00P2:GS/808eR=`@0S64g102=HSP208iS=P<0
SV<h00<0SV<i08eR>02=HSP02`2=HSL308iS>0D0Sf@i0P2@ICX2095V>`80TVLl0`2AIS`3091U>`80
Sf@j0P2@HcT2095T>P80TVDk0P2CIS`209=T>006099V>@2AIST0TFPj08mY>P2@JS/0Sf/k0P2BIST2
09=W>P80U6Pk0P2EJC`309IZ?@80UFTl0`2DJ3/00`2CIS`0U6Lm09AW?@0209EX?P<0UVTo0P2EJCP3
09IZ>@<0Uf/j202GKC/02P2HKd40Ufi009M/?`2GJch0V6Tm09MV>`2FICX0V6Dj09M[?P2EJC`309=W
>P0;09IZ?@2IKD00Vfm209M[?P2FJSd0UFTl09AX>`2EJC`0UVXm09Q/?`2IKD00202GK3l609Y^?@80
VFdl0`2JKc`209]`?@<0W74n202KKch209Y^?@<0Vfln0`2LL3l809]_?P0309ea@02LL3l0W70o00D0
W70o00T0WG5009]^A02LL4<0WG5409mcA02OLd80WG8o09aa?02KL3/00P2KL3d01P2LLCh0WG8o09ic
@02PMD80XGI30:9gA0T0XGI300L0X7E209md@@2NLd00WgA10:1e@P2RMd@0XgQ500P0XGI30P2OMT00
0`2PMd<0X7I40:1fAP020:5fB@070:5fB`2XMTD0YWI50:IfA@2UMdD0XgQ50:9iA@020:5iA@80XgQ5
0`2TNDH30:EjA`80YWY900H0YW]80:MlA`2WO4D0Yge30:QnA02XOT830:AiAP80YGY70`2VNdP20:Ai
AP030:EjA`2VNdP0Yga90080Z7e:00<0ZGi;0:QmBP2XODX01P2XODX00`2ZOd`0Z7e:0:MlB@020:Ik
B0030:MlB@2XODX0ZWm<00H0ZH1<0P2ZPDd80:QoB`80Z7m700@0Z7m90:V0C02ZPDd0ZX1>0P2[PE42
0:YnC`040:YnC@2ZOd`0ZWm<0:YoBP80ZWm8102WOTX40:QoB`T0[8==1P2[P4d20:b1CPP0[85<00P0
[85>0:^0C@2ZOd`0ZGi;0:YoC02[P4d0[H9?0:n4D@80[8=?0P2[PTh20:Z1C@80ZH1<00<0ZGi;0:Yo
C02ZOd`00P2ZOd`30:^0C@@0Zh9>102ZPDd20:j0CP030:b1CP2[PTh0ZX9>0080Z8=>00@0YhA>0:b1
CP2/PDh0[85>102]PTl00`2^Pe00Zh9>0:^2CP090:b3C`80[HA@0`2^QE420:n3DP030:j3D02^Pdh0
[X=<0080[H=900H0[H=70;22AP2`PTH0/8970;21B@2`PD/20;21C@040;20C`2/PTP0Zh570:^1A`80
ZX160P2YOdD00`2XOT@0ZWm<0:YoC0060:YoC0H0ZGi;0P2XODX01P2/Pdd0Zh9<0:^2C02ZPD/0ZH1:
0:QoB@80Ygi80`2ZOdX00`2YOTT0Z7e80:QmB0020:MlA`80Z7a;00<0Z7e:0:QmB02XODH00P2XOT@0
1`2XOT80Ygm20:MoA02WOd@0Z7m70:QoB@2YP4`00`2YOdd80:V0BP<0Yga70P2XODP30:UnB@P0Z7m;
0P2WO4T0102XODX0ZGi;0:UnB`2ZOd`20:^0CA00Z7m;00D0[H9?0:b1CP2/PDh0Zh1=0:YoC0020:Un
B`030:QmBP2[P4d0Zh1=00H0Zh1=202ZOdX00`2]PTd0Zh1;0:YoBP020:UnB@040:YoBP2[P4/0[H9=
0:^2CP@0[8=?0`2]Q5080:b3C`P0[85>0`2[PTh30:b3C`80[HA@0P2/Pdl30:f4D0<0[XEA202]Q500
202YOTT0ZWm:0:^0B`2/PD`0[H9=0:j3CP2_Q4l0/8E@202]Q5020:j5C@040:j5C`2^QE40[XEA0:j4
DP80[XAD0`2]Q5030:j5D@<0[hIB202^QE400`2^QDl0[hI@0:n6D00=0;27D@80[hEC00H0/8MC0;27
D@2`Qdl0/8Q=0:n7C02_QdX80;68E0P0ZhIB0P2[QU430:b7DP<0[HQC0`2aR5820;68E0<0/HME00H0
ZhIA0:b7DP2/Qe80[HQC0:j9E02_RUD20;2;EPP0/HME1P2bRED20;>:EP80/HQ@00@0/HQB0;68E02a
R5@0/HME0P2aQeL40:n6DP@0/8MC0P2bRED30;68E0<0/8MC00H0/HIK0;66F@2bQeX0/XQH0;:8EP2b
RED20;>:E0030;68E02cRUH0]8]G0080]HaH00<0]8]G0;>:EP2aR5@00P2bRE40102cRU@0/hYF0;B;
E`2dRUP20;F;F`80[hYE0P2`ReH20;6<E`80/XeH2@2_RUD80;>:EPP0/XUC202cREL00`2`Qe<0/HQD
0;68E0020;:9E@80/hYF00T0]8]G0;F=D02dS540/XY?0;27C`2`Qe40/8MC0;67E@2bR5H0102^RE@4
0:f8D`050:Z5CP2[QTl0ZhIA0:b7D`2]QeH00P2^R5T00`2_RE`0/8MC0;27D`060;27D`P0[hI@202]
Q5080:Z1C@<0Zh9>0`2/Pdl20:f4D0030:j5D@2]Q500[8=?0080[8=?00<0[XEA0;27D`2aR5@0602/
Pdl20:n6CP040:n6D02_QU80[hIB0:n5D`80[hEE0P2]Pe<0102_QE<0[hIB0:n6DP2_QU020:f4C004
0:Z1B@2[PTX0Zh9<0:^2C080[8=?00H0[H=A0:f3D`2]Pe<0[hEE0:f3D`2/PU020:^2CP030:b3C@2]
Q4`0[hI>0140[8=?00L0Zh9>0:V0C02XOd/0ZH1<0:b3C`2_QU80/HQD00@0[8=?102[PTh80:b3C@05
0:V0BP2ZPD/0ZX5;0:^2C02/Pdd00P2]Q4h00`2^QDl0[8=?0:b3C`060:b3C`80[HA>1`2^QDl20:f4
CP80[8==0P2[PT`00`2ZPD/0Zh9>0:^2CP060:^2CPP0[8=?202[PT`80:^2CP80ZX5=1P2[PTh20:j5
C@040:f4CP2/Pdl0[8=?0:^1C`80ZX1@00H0[hA?0:j3CP2]PTd0[85<0:^0B`2YOTT20:QmB0@0ZX5;
102[PT`30:b3C`<0[HA@0`2^QE430:f4D080[8=?2`2[PTh00`2ZPDd0Zh9>0:b3C`020:j5D@030:b3
C`2[PTh0ZX5=0080ZWm<00<0Zh1=0:b1CP2/PDh00`2/PDh@0:^2CP80ZH1:0P2ZPD/0102[PT`0[8==
0:b3C@2]Q4h80:V0C0P0Zh1;00<0YWe90:MnBP2YP4`00`2[PTh00`2ZPDd0ZH1<0:^2CP030:^2CP@0
ZX5=0P2]Q5000`2/Pdl0ZX5=0:Z1C@030:V0C0P0Zh9>00H0[8=?0:^2CP2[PTh0ZX5=0:V0C02XOd/2
0:MnBP80ZH1:1P2XOdT01P2YPD@0ZH560:V1AP2XOdL0Z7m90:MnBP80Yge;202YP4`80:UnB@L0Ygi8
0P2VODL20:V0C0060:MnBP2VODT0Y7]70:=jAP2RNDD0XGQ4202WO4T01P2UNcl0YG]10:Ek@@2VNd@0
YW]60:EjA`80YGU80P2RMd801P2SN4<0YGY50:IkAP2WO4L0Z7e80:UnB@80Y7]70`2SNTH30:9iA@0@
0:EjA`2TNDH0XgQ50:=hA@2TNDH0YGY70:MlB@2XODX0YGY70:AiAP2RMd@0XGI30:1e@P2QMT<0XWM4
0:=hA@P0XgU90P2SMdP0102RMTL0XGE60:5eAP2PM4D209mcA0030:AkA`2RNDD0XGQ40080WgI200`0
XGQ40:9iA@2TNdL0Z7m;0:MnBP2VODT0Y7]70:9iA@2PMd<0WgI209ie@@2RNDd20:5hBP030:1hA`2O
Md@0WWI20080WGHo0`2SNTH20:AkA`80YGa800@0YWe90:EkB@2UNdT0YG]90P2TNTP30:=iA`030:Ek
B`2TNTX0XWQ60080XGQ400<0XWU30:Ak@`2UO4@00`2TNTP30:=iA`80XWQ60P2TNdL00`2SNTH0XWU5
0:5hA0020:1g@`0309mf@P2SNT@0XgY400H0XgY400D0XWU10:5h@02PMd40WgI209me@`020:1fAP0B
0:5fB@2RMdX0XGQ40:9iA@2SNTH0Y7]70:=jAP2RNDD0X7M309mf@P2TNTP0XWQ60:1fA02OMD<0WWA2
09me@`2PMT@0XGM50P2NNDD0102MN4@0W7M309ag@`2KMT8209Ye@@<0W7900`2MLd4209id@P0309ic
AP2LLD@0VVm20080V6e000<0VVm209aaA02NLdH0202LLT0809Y`?P80VVm2102IKT4209Q]@0P0UG0l
00D0W79009]a?`2KLCl0VW0n09Q^?00209M]>`0309I/>P2GK3l0Uf`o0080UV/n102EJSd209=Y=`80
U6Xh0`2EJcT00`2FK3X0Ufdk09M]>`0209M]>`@0V6hl00@0V6e009M/?`2GK3l0UV/n1P2EJSd209I[
?P80Uf`o0P2HKD004`2HKc/0Ufdk09I/>P2DJSX0TfPk095V>`2@IC/0Sf@j095X>P2BJC/0TfXl09A[
?@2EK3h0UVdo09M^@02HKd40UF/i09I/>P2GKC/00P2HKS`00`2GKC/0UV`j09E[>@03095/>080TVdi
102CKSX0102CJ3/0U6Tl09AY?02EJSd209I[?P80Uf`o102EJcT409AZ>00308eW=P2>J3L0SfTh0080
T6Xi00h0SfTh08iX=`2=IcH0SfXm08mY?02=IcX0SVDi08iS>02@HcT0Tf@j09AU>`2EJSl0U6Tn099W
?080TFHk00T0TVLl09AY?P2EJSl0T6U008mX?`2>Ich0SFHm08aU?02;I3/00P2:HcX808eW>100SFLj
0`2AJch[ooooo`00:_ooool208=K>00308=K=`23G3D0Q5dd0080Q5db00<0Q5ha08IO=P26GcH00`25
GSD308AM=00607mH;`20FC00PEXa089K<P24GC@0QEhe0P26GcH208MP=`80R64h00@0RF8i08YS>P2:
HcX0RV<j0P2:Gc80102:Gc@0RUle08YN=`2:GST208YN>``0SF8g102<HCH208eR>00408iS>@2>HcP0
SV<h08iS>080SV<f202=HSL208aQ=P80SF8g0`2>HcP508mT>@80T6Dj1P2AIS/3091U>P80Sf@i0P2@
HcT4095T>P80TVDk0P2CI3P01P2BIST0TFHi095X>P2?JCX0T6Xk08m[>`80TfLj102DJ3/209EY?0<0
UVXm0P2EJC`309AX>`<0U6Lm0P2EJ3h209IY?`0309MZ@02EJCP0UFTh00<0UVXi0`2GJcX809M]>`0H
09Q_@@2GKT00Uf`o09M[?P2HJCd0UfHk09IU>P2HICX0Uf/n09IZ?@2DJ3/0TfLj09AX>`2GJch0VVi1
09a`@`2GJch0UVXm09EY?02DJ3/0UFTl09IZ?@2HK3l0VFe0202GK3l609Y^?@80Vfln0P2JKc`209]`
?@80W74n0P2MLSl809]_?P80VVhm0`2KKch309a`?`P0Vfln00<0W70o09ea@02MLD001@2MLD003`2L
L3l0VVe309a`@`2MLD@0WW9309ib@@2MLSl0W74l09Y_>P2JKc`0Vg0m09aa?P2NLd00WgA10:1e@P02
0:5f@`P0X7E200P0XgE30:9d@P2QLd40X7900:5c@@2RM480Y7I40:EgA@P0XWM40P2PMd401`2PMd<0
XGM50:5gA`2QMTT0XWM:0:9gC02XMTD00P2VMTD00`2UMdD0XgQ50:9iA@020:5iA@<0XgQ50`2TNDH2
0:EjA`80YGU800<0YW]80:IkAP2VNd@00P2WOD<00`2WOD40Y7U60:AiAP020:EjA`80YW]80P2WO4T0
1P2TNDH0YGY70:EjA`2VNdP0Yga90:QmBP80ZGi;202XODX00`2ZOd`0Z7e:0:MlB@020:IkB0030:Ml
B@2XODX0ZWm<0080ZX5=1P2YP4`80:QoB`030:QoA`2YP4P0ZH1:0080ZH1<00<0ZX1>0:Z0D02ZP500
0P2ZOTl0102ZOTd0ZWm<0:YoC02ZOdX20:YoB0@0Z7m;102WOTX90:b3C@H0[85>0P2[P4d80:b1C008
0:b1CP2[P4d0ZWm<0:UnB`2ZOd`0Zh1=0:f2C`2_Q5420:b3C`80Zh9>0P2ZPDd20:V0C0<0ZGi;00<0
ZWm<0:^0C@2[P4d00P2/PDh40:Z1C@@0Zh9>0P2^P4h00`2/PDh0Zh9>0:Z2CP020:R3CP030:N4CP2[
P4d0Zh1=0080[85>00@0[H9?0:j3D02^Pe00[X=@1P2/Pdl20:^2CP<0[8=?0P2]Q5030:j5D@80[h=B
00H0[hAA0:j3CP2^Pd`0[XA:0:f3B@2]PdL20;22AP030;22A`2`PDT0/85;0080/85=00<0/81?0:^1
A`2[PDL00P2[PDL40:Z0APP0ZWm<1P2YOT/20:YoC0060:b3C@2[PT`0Zh9<0:Z1B`2YP4X0Z7m90P2W
OTP30:YoBP@0ZGi900H0Z7e80:QlB`2XO4/0Z7e:0:QmB02XODH20:QnA0070:Qn@P2WOd80Ygm40:Mo
A02XOdL0Z7m90:V0C0030:UoC@P0ZH1:0P2VNdH20:MlA`80Z7e80P2YOTT80:QoB`80Yga900@0Z7e:
0:UnB`2YOT/0ZWm<0P2[P4d@0:QoB`80[85>00@0Zh1=0:YoC02ZOd`0ZGi;0P2XODX80:YoC0P0ZWm:
00<0[85<0:^0B`2YOTT00P2XODP00`2YOTT0Zh1;0:b1C0030:Z1C@030:^2CP2/Pdl0[8=?0080[HA@
202/Pdl80:b1CP<0Zh9>0`2/Pdl20:f4D0<0[8=?0`2]Q5020:j5D@P0[HA@0P2ZOdX0102[P4/0[85<
0:j3CP2_Q4l20;25D0P0[HA@0P2^QDd0102^QDl0[XEA0:j5D@2^Q5820:j4E0<0[HA@0`2^QE4;0:n6
DP@0[XE?00@0[hI@0;27D@2aR580/HQB202`Qe420;26E0060:n6DP2_QU00[hI>0:n7C02`R4d0/8Q;
202aR5@80:^6DP<0[8MB0`2]R5<20:j9E0<0/HME00<0/HQD0;27D`2`Qe400P2`Qe401P2[QU40[8MB
0:b7DP2]R5<0[XUD0:n:E@80/8]F202aQeD60;:9E@80/HQD0P2aR500102aR580/HQD0;68E02aQeD2
0;67E`80[XEA0P2_QU820;27D`80/HQD0P2bRED30;68E0<0/8MC00/0/8EJ0;66F@2aQUT0/XQH0;:8
EP2cRUH0/hYD0;B;E@2aR5@0/hYF0;B;E`020;F<F0030;B;E`2cRUH0/HQD0080/XUA00@0/XUC0;>:
EP2cRUH0]8YH0P2dRUX30:n:E@80/8]F0`2aS5L90:j9E0P0/hYF202bRE<80;B:F080/HQD102bRED2
0;>:EP080;F=D02dS540/XY?0;68D02`Qe40/HQD0;:8EP2cREL80:j9E0050:Z5CP2[QTl0ZhIA0:b7
D`2]QeH00P2^R5T00`2_RE`0/8MC0;27D`060;27D`P0[XE?202]Q5080:Z1C@<0Zh9>0`2/Pdl20:f4
D0080:j5D@2]Q500[8=?0:^2CP2/Pdl0[HA@0:n6DP2`Qe<H0:b3C`80[hI>00@0[hI@0:n6DP2_QU80
[hEC0P2_QED00`2/PU80[XAD0:n5D`020;68E0030:n6D02^QDd0[8=;0080Zh9:0P2[PT`00`2[PTh0
[8=?0:b2D0020:f3D`030:n5E@2^Q5@0[H=A0080Zh9>00<0[HA>0:j5C@2_QTh0402/Pdl00`2]Q500
Zh9>0:V0C0020:V0C0030:b3C`2_QU80/HQD00P0[8=?202/Pdd20:Z1B`040:^2C02/Pdd0[8==0:f4
CP80[XE?202/Pdl30:j5C`D0[HA>102/Pdd40:^2C0P0Zh9>202/Pdl80:^2C0X0Zh9>1P2ZPDd0202^
QDd0[HA<0:f4CP2/Pdl0Zh9>0:Z0CP2ZP500ZGm?0P2_Q4l01P2^Pdh0[85<0:^0B`2ZOdX0ZGi90:Qm
B0@0Zh9<102ZPD/30:b3C`<0[HA@1@2^QE420:f4D0<0[8=?2@2[PTh00`2ZPDd0Zh9>0:b3C`020:j5
D@030:b3C`2[PTh0ZX5=00D0Zh1=00<0[85>0:f2C`2]PTl0402[PTh20:QoA`030:V0B02ZPDT0Zh9:
0080[8=;00<0[HA<0:V0C02YP4`01P2YP4`80:YoBP030:ImB@2WOTX0ZH1<00<0Zh9>00@0ZX5=0:V0
C02/Pdl0[8=?0P2[PTh20:Z1C@80ZH1<0`2/Pdl20:^2CP030:V0C02XOd/0Z7m;00P0Zh9>00H0[8=?
0:^2CP2[PTh0ZX5=0:V0C02XOd/20:MnBP80Ygi81P2XOdT01P2YPD@0ZH560:V1AP2XOdL0Z7m90:Mn
BP80Yge;202YP4`80:UnB@80YWe71`2WOTP01P2YP4`0Z7m;0:MnBP2VODT0YGa80:AkA`80XgY6202W
O4T0202VO400YG]10:Ek@@2UNT<0YGY50:EjA`2UNDP0YWY90P2RMd801P2SN4<0YGY50:IkAP2WO4L0
Z7e80:UnB@<0Y7]70`2SNTH20:9iA@80YW]80`2TNDH02`2UNTL0Yga90:QmBP2UNTL0Y7U60:9gA02Q
MT<0X7E20:5f@`2RMd@0XgQ500P0XgU700D0Y7Q70:=gAP2RMTD0XGE40:1d@`0209mc@P0309ib@@2S
NTH0XgY600@0XGQ40P2SNTH20:MnBP040:ElB02TNdL0XWU50:5hA080WgI200P0XgQ=0:=hB`2RMdX0
XGM70:1fA02OMT80WgI009ie?`80XgY60P2TNdL40:ElB0040:IlBP2UNdT0YG]90:EkB@<0Y7Y800@0
XgU70:AjBP2TNTX0XWQ60P2RNDD00`2RND<0Y7]30:Ak@`020:AjB0<0XgU70`2RN4H20:AkA`030:=j
AP2RNDD0XGQ40080X7M300<0WgI20:=jA02SNT@01P2SNT@01@2SNd00XGTn0:1g?`2NMCl0WWE10080
X7I40180XGM70:=iB@2QN4@0XWU50:=jAP2TNdL0XgY60:9iA@2PMd<0WgI20:AjB02RN4H0X7I409me
@`2NM480WgE30:1fA02QMdD209mjAP0409iiA@2MN4@0W7M309]f@P80VWE10`2LLT0309ec@@80WWA2
00<0WgA709ebA@2KL4<00P2IKT400`2KL4<0WG9509mdA`0809ab@0P0Vg4o0`2JKd8209U^@@<0V6e0
202EL3`209]a?`0409Y`?P2IKcd0VFlm09Q^?080Ufdk0`2GKCd209I/?0<0UF/k0`2DJSP209E[>@@0
UV`j0P2GKC/209Q^?080VFlm00<0VW0n09Q]@02HKD000P2HKD00102GK3l0UV/n09I[?P2EJSd209E[
>`80UV`l0P2GKCd209Q^?P0C09U`?02HKS`0UV`j09AZ>P2BIcX0TFHk08mT>P2>HcT0TFHi099W>P2C
J3/0U6Tl09I[?P2GK3l0V6e009U^@@2EJcT0UV`j09M]>`0209Q^?00309M]>`2FK3X0UF/i0080TF`h
0P2BKCT209=^>P<0U6lk0P2CJ3/00`2DJC`0UFXm09I[?P0209M/?`0309Q]@02EJc/0UF/k0080U6Xj
0P2CJCT2099X>00308eW>02>J3T0SfTj0080T6Xk00h0SfTj08iX>@2=IcP0SfXm08mY?02=IcX0SVDi
08iS>02@HcT0Tf@j09AU>`2DJCh0TfPm099W?080TFHk00@0TVLl09=X?@2DJCh0T6U00P2?J3l00`2>
Ich0SFHm08eV?@0208aU?0@0SVPi102=IcP808eW>P/0SVPk:oooool002[ooooo0P23FcP00`23FcL0
Q5df08AM=00208EN<`0408EO<P26GcH0QUlf08IO=P80QEhe0`24GC@01@21G380PUdc089M<`23GS@0
Q5le0080QF0f00L0QV4g08AO=@25H3H0QF0f08IQ=`27HSP0R6<i0080RF@j0P29GS401029GS<0RUle
08YN=`2;GcX208]O?0P0SF8g00@0SV<f08eR=@2=HSD0SF8e0`2<HC@01`2;H3<0SF4l08eQ>P2=HCX0
SV<i08iS>02>HcH00P2?ICD808eR=`<0S64f0`2=HSL408iS>0<0Sf@i0P2@ICX2095V>`<0TFHi0`2@
ICP208mT=`<0T6<i1@2AI3X209=T>006099V>@2AIST0TFPj08mY>P2@JS/0Sf/k1@2DJ3/309EY?0<0
UVXm0P2EJC`309AX>`0809IY?`2EJ3h0U6Lm09AW?@2EJ3h0UVTo09MZ@02HJd4209EY>0<0UVXi0`2G
JcX809M]>`80UVdo00H0UV/n09M[?P2HJCd0V6Ll09MV>`2IIS/209M[?P<0UVXm00/0Uf/n09Q/?`2I
KD00Uf/n09IZ?@2EJC`0U6Pk09EY?02FJSd0V6`o09U]@00809M/?`@0VVhm0P2KKch209a`?`<0Vg0m
0P2LLCh309eb?`P0Vfln0P2JKSd309]_?P`0W70o00<0WG5009ib@@2NLT400`2NLT403@2MLD00W70o
09Y]@`2KKd80WG5409ib@`2NLT40WG8o09]`>`2JKcX0VVll09]`?@2MLSl00P2OM4400`2PMD80WgA1
09md@@080:1e@P080:Ad@`2SLd80XW910:5a@02RLT40Xg=20:EeA02VMTD80:9gA080X7M100<0X7M3
0:5gA@2QMdL00P2RMdX01`2RMd`0Z7I50:IfA@2VMTD0YGM50:=hA@2RNDD00P2QNDD20:9g@P80XgQ3
0`2TND@01P2UNTD0YGU80:EiB02UNTL0YW]60:IkA080Yge300@0Yge10:EjA`2UNTL0YGY70P2VNdP3
0:MlB@80YGY700<0YW]80:MlB@2XODX00P2YOT/00`2ZOd`0Z7e:0:QmBP060:QmBP030:YoC02XODX0
Yga90080YW]800<0Yga90:QmBP2ZOd`00`2ZPDd30:V0C080Z7m;202XOdT20:V0B0040:V0BP2YP4`0
ZH1<0:UoC@80ZGm?0P2ZOTl0102ZOTd0ZWm<0:YoC02ZOdX20:YoB0040:Z1C@2YP4`0ZH1<0:V0C0<0
Z7m;00<0Ygi:0:b3C@2/Pdd01`2/Pdd30:f2C`<0[85>0P2[P4d80:b1C0080:b1CP2[P4d0ZWm<0:Un
B`2ZOd`0Zh1=0:f2C`2_Q5420:b3C`80Zh9>0P2ZPDd20:V0C080Z7e:00<0ZGi;0:YoC02[P4d00P2/
PDh00`2]PTl0ZH1<0:Z1C@020:Z1C@<0Zh9>00H0[8=?0:j0CP2^P4h0[85>0:^2CP2ZPTh20:R3CP07
0:N4CP2ZOd`0Zh1=0:^0C@2/PDh0[H9?0:j3D0020:n4D@80[H=A0`2/PU030:^1C`<0[8=?0P2]Q503
0:j5D@80/8AC00<0[hAA0:n4C`2^Pd`00P2^Q4X01P2]PdL0/8960;22AP2`PTL0/8590;21B`80/85=
00<0/81?0:^1A`2[PDL01P2[PDL80:YoC0@0ZGi;0P2ZOd`20:^0C@<0ZX5;0`2YP4X20:QoB@P0ZWm:
0P2XO4/00`2XODX0Z7e80:QmAP020:QnA0070:Qn@P2WOd80Ygm40:MoA02XOdL0Z7m90:V0C0030:Uo
C@P0ZH1:0`2VNdH20:MlA`<0Z7e8202XOd/30:QmBP80ZGi;0`2ZOd`30:V0C080Z7m;1P2WOTX20:Qo
B`<0ZH1<00@0Zh1=0:YoC02ZOd`0ZWm<102YOT/@0:YoBP030:^0B`2ZOdX0Z7e80080Yga700<0Z7e8
0:YoBP2[P4/00P2XOd/00`2YP4`0ZX5=0:^2CP020:b3C`030:f4D02/Pdl0[8=?00H0[8=?202/PDh3
0:^2CP<0[8=?0P2]Q5020:^2CP80[8=?0`2]Q5000`2^QE40[8=?0:b3C`060:b3C`050:^0B`2/PD`0
[85<0:f2C@2^Pdh00P2_Q4l00`2`QE00[HA@0:f4D0060:f4D080[XE=00@0[XE?0:j5D@2^QE40[XAB
0P2^Q5@30:f4D0<0[XEA2`2_QU80202^QDl0[HA>0:f4CP2]Q4h0[XE?0;27D@2aR580/XUC202`Qe40
202aQeD0/8ID0:n6DP2^QDl0[XE=0:n7C02`R4d0/HU<202`Qe<80:^6DP<0[8MB0P2]R5<30:j9E008
0;66F@2aQeL0/HME0;26E02`Qe40[hI@0:n6CP2_Qd`30:f8D`<0[XUD0P2_RUD80;26E0@0/XUE0P2a
R5@20;27D`80/HQ@00@0/HQB0;68E02aR5@0/HME0P2aQeL01@2]Q500[XEA0:j5D@2_QU80/8MC0080
/HQD0`2bRED30;68E0<0/8MC00H0/8EJ0;25F02aQUT0/XQH0;:8EP2cRUH20;B;E@030;68DP2cRU@0
]8]E0080]HaF00T0]8]E0;>:E02aR580/HQ@0;:9D@2bRE<0/XUE0;>:EP2cREL00P2dRUX0102^RE@0
[hYE0:n:E@2_RUD20;2;EP80/HaG2@2_RUD80;>:EPP0/HQB202dRUP80;:9E@090;J>D@2dS540/h]@
0;68D02aR580/HQD0;:8EP2cREL0[HQC00<0[XUD0`2_RUD01P2`ReH0[8M@0:b7D02/Qe80[8MC0:f7
EP80[HMH00<0[HMJ0;27D`2`Qe<01P2`Qe<80:j5C`80[8=?102^QE420:b3C`P0ZX5=0`2[PTh30:b3
C`80[HA@0P2/Pdl30:Z1C@030:b3C`2^QE40[hIB0100[8=?202[PTh20:f4C0040:f4CP2]Q500[HA@
0:f3D@80[H=C00<0[89B0:j4E02`QU@00P2bRED01@2`Qe40[XE=0:b3B`2/Pd/0Zh9:0080Zh9<00P0
ZX5=0:^2CP2/PU00[H=C0:j4E02_QED0[XAD0:f3D@80[8=?00<0[HA>0:j5C@2_QTh0402/Pdl00`2]
Q500[8=?0:^2CP020:^2CP040:b3C`2^QE40[hIB0:^2CP<0[8=?0`2]Q5000`2^QE40[8==0:b3C@06
0:b3C@040:^2C02/Pdd0[8==0:b3C@@0[HA>202/Pdl20:f4CP<0[8==2`2[PT`80:^2CPP0[8=?202[
PT`80:Z1C@80Zh9>0`2ZPDd30:V0C080[8=;00@0[8==0:^2CP2[PTh0Zh5?0P2ZP5020:j3CP80[H9=
00D0[85<0:^0B`2ZOdX0ZWm:0:b3C@030:^2C0<0ZX5;00@0ZH1:0:b3C`2/Pdl0[8=?0`2]Q5030:j5
D@<0[HA@0P2/Pdl;0:^2CP030:Z1B`2[PT`0[8==0080[XE?00D0[8==0:^2C02ZPD/0[85>0:^0C@03
0:YoC0030:b1CP2]PTl0[X=@0100Zh9>0P2XP4D20:V1AP040:Z2A`2[PdP0[8A90:b4B@P0ZH1<202Z
OdX00`2VODT0Ygi:0:V0C0030:^2CP030:Z1C@2YP4`0[HA@0080[8=?00L0Zh9>0:Z1C@2YP4`0ZH1<
0:QoB`2ZPDd0Zh9>00<0[8=?00<0ZX5=0:V0C02XOd/0202[PTh30:Z1C@<0ZH1<0P2XOd/20:ImA`80
Ygi8102XOdT01P2YPD@0ZH560:V1AP2XOdL0Z7m90:MnBP80Yge;202YP4`80:UnB@<0YWe7102WOTP2
0:QoB@<0Ygi:0`2VODT20:ElB0P0Yga900P0Yge10:Il@P2UNd40Y7U20:AiA02UNTL0YWY90:MkBP80
XgQ300@0Y7U40:EjA@2VNdH0YW]60P2WO4L20:ElB080Y7]70`2SNTH0102RNDD0Z7e:0:MlB@2UNTL2
0:AiAP0;0:EjA`2WO4T0Z7e:0:IkB02UNTL0XgQ50:9gA02QMT<0XWM40:=hA@2TNDH0202SNTH20:Ai
AP040:=hA@2RMd@0XWM40:5f@`80X7E20P2SNT@40:9i@`80XgY40P2UO4P0102TNdL0XgY60:=jAP2R
NDD20:5hA0060:=fC02SMdX0XgM:0:9fA`2RMTD0XWM40P2QMT401@2RNDD0XgY60:AkA`2UO4P0YWe9
0080YGa800<0Y7]70:EkB@2UNdT01P2UNdT00`2TNTX0XgU90:=iA`020:9iA@040:=jA02SNT80Y7]3
0:AjB0<0XgU70P2RN4H20:5gA@80XgY60`2RNDD30:5hA0P0Y7]500D0Y7`o0:9j?`2OMc`0WG@l09ed
?P0209mf@P0B0:9hAP2TNTP0XGQ40:9iA@2SNTH0Y7]70:=jAP2RNDD0X7M309mf@P2TNTP0XWQ60:1f
A02OMD<0WWA209me@`2PMT@0XGM50P2ONTH0102NNDD0WGQ409ag@`2LMd<209]f@PL0WG=100@0W790
09ebA@2MLTD0W7540P2KL4<00`2LLD@0WG9509ebA@0809ab@0P0Vg4o0P2JKd8409U^@@80V6e0202G
LSh309Y`?P80VFlm0`2HKS`209U_?@80V6hl0`2GKC/00`2FK3X0UF/i09E[>@0209I/>P<0Ufdk00H0
V6hl09I/>P2FK3X0Ufdk09Q^?02IKcd209Y`?P0309]a?`2HKD00V6e000<0VFi100<0V6e009I[?P2E
JSd00P2EJcT209I/>P80Ufdk0P2HKS`04`2IL3`0V6hl09M]>`2EJc/0U6Tl099W?02AIS`0T6Dk099V
>@2CIcX0U6Pk09EY?02FJSd0Uf/n09Q/?`2IKD00UF/i09I/>P2GKC/00P2HKS`00`2GKC/0UV`j09E[
>@03099]>@80Tfhj102DKc/0102CJ3/0U6Tl09AY?02EJSd209I[?P80Uf`o0P2EJSd00`2DJC`0TfPk
099W>P02095V>@04091U>02=IcX0SVPk08mY?080T6Xm00h0SfTl08iX>`2=IcX0SfXm08mY?02=IcX0
SVDi08iS>02@HcT0Tf@j09AU>`2DJCh0TfPm095V>`80T6Dj00<0TFHk09=X?@2DJCh00P2@JD0208mX
?`80SVLn0P2=ISd308mY>P80SVPi0`2=IcP808eW>PP0SVPk0`2<IST[ooooo`00:_ooool208=K>006
08=K=`24GCH0QEhe08EN<`26Gc@0QV0c0P27H3L208IO=P<0QEhe00<0Q5dd08=P=P23H3H01023H3H2
08AQ=`06081M<`21GS@0PUle08=P=P24HCL0QF8h0P26HcT02028GC00REha08UN<`2:GcD0RUhg08]O
>P2;Gc`0S60m202=HSL208iT=080SF<c0P2<HS8208]Q<@0808aP?@2<H3/0SF4j08eR>02>HcH0SfDe
08mU<`2?IS8808eR=`@0S64f0`2=HSL408iS>0<0Sf@i0`2@ICX3095W=`<0T6Hf0P2?ICD2095T>PH0
T6<i0P2CI3P01P2BIST0TFHi095X>P2?JCX0T6Xk08m[>`H0UFTl0P2DJ3/309IZ?@80UFTl0`2DJ3/0
0`2GJT00UVTo09EX?P0209AW?@0309IY?`2HJd40VFa20080UFTh0`2FJST309M[>PP0Ufdk00D0UF`n
09A[?@2EJSd0UVXm09QY?@0209UX?@0A09]X?@2GJch0V6`o09Q/?`2IKD00V6`o09M[?P2FJSd0UFTl
09M[?P2FJSd0UFTl09AX>`2EJC`0UVXm09Q/?`2IKD00202GK3l00`2IKC`0VVhm09Y^?@0209]_?P80
W70o00<0WG5009]`?@2KL3d00P2LLCh409eb?`P0Vfln0P2JKSd309]_?P<0W70o202MLD000`2LL3l0
WG5009ib@@0209mc@P80WW9100d0WG5009a`?`2JKD<0Vfm209a`@`2MLD80WG5009aa?P2KL3/0VVlj
09aa?P2MLSl0WW=00080X7E200<0WgA109eb?`2LLCh0202OM440202TM4<0Xg=20:9b@@2QLD00XW91
0:=c@P2UMD@0YWI5202SN4D02@2PMd40XGQ20:5hA02QMdD0XWQ80:9gBP2SN4/0XgQ=0:QfA@020:If
A@030:EgA@2SN4D0XWU50080XGU50`2RMd020:=h@@<0Y7U20P2TN4L00`2UNTL0YGY50:IkA0020:Il
@P030:Mm@@2UNTL0YGY70080YW]8102WO4T20:EjA`040:IkB02WO4T0Z7e:0:UnB`80ZWm<202XODX0
0`2ZOd`0Z7e:0:MlB@020:IkB0030:MlB@2XODX0ZWm<0080Zh9>0P2ZPDd0102YP4`0Z7m;0:QoB`2X
Od/80:QoA`80ZX5900@0ZH1:0:V0C02YP4`0ZGm=0P2YOdl20:YnC`040:YnC@2ZOd`0ZWm<0:YoBP80
ZWm800<0[8=?0:^2CP2[PTh00P2ZPDd20:V0C0030:QoB`2/Pdd0[8==00L0[8==0P2^Pe020:f2C`80
[85>0P2[P4d80:b1C0080:b1CP2[P4d0ZWm<0:UnB`2ZOd`0Zh1=0:f2C`2_Q5420:b3C`80Zh9>0P2Z
PDd20:V0C0060:MlB@2XODX0ZGi;0:YoC02[P4d0[85>0P2]PTl20:V0C080ZX5=0P2[PTh20:b3C`80
[X1>00<0[85>0:^2CP2ZPTh00P2XPdh02@2WQ4h0ZWm<0:YoC02[P4d0[85>0:f2C`2^Pe00[hAA0;25
DP030:f3D`030:b2DP2[PE40Zh5A0080ZX1@0`2/Pdl20:f4D0<0[XEA0P2`Q5<00`2`QE80[hA?0:n4
C@020:j4BP060:j4B02aPdL0/H=70;63B02aPTX0/H9<0P2aPTh00`2aPE00Zh570:^1A`030:^1A`<0
[898202ZOd`00`2XODX0ZGi;0:UnB`020:YoC080Zh1=00<0[85>0:QoB@2XOdT00`2YP4X30:Z1B`P0
ZWm:0P2YOD`00`2YOT/0ZGi90:UnA`020:UoA@070:Uo@`2WOd80Ygm40:MoA02XOdL0Z7m90:V0C003
0:UoC@P0ZH1:102VNdH20:MlA`80Z7e8202XOd/30:YoC080ZGi;0`2XODX00`2ZPDd0ZH1<0:V0C002
0:QoB`80Ygi:0P2VODT20:MnBP80Z7m;0P2YP4`00`2ZPDd0Z7e:0:QmBP030:UnB`<0ZWm<202YOTL9
0:YoBP070:UnB@2WO4L0YW]60:IkAP2WO4L0ZGi90:YoBP020:MnBP060:QoB`2YP4`0ZX5=0:^2CP2/
Pdl0[HA@202/Pdl80:b1CP<0Zh9>0`2/Pdl20:f4D0<0Zh9>0P2/Pdl30:f4D0P0[8=?202^Pdh80:f4
D080[XE=00@0[XE?0:j5D@2^QE40[XAB0P2^Q5@30:f4D0<0[XEA2`2_QU80202^QDl0[HA>0:b3C@2/
Pdd0[HA>0:n6D02bRE<0/hYD202`Qe40202aQeD0/8ID0:n6DP2^QDl0[XE=0:n7C02`R4d0/HU<202`
Qe<80:^6DP040:b7DP2]R5<0[HQC0:f8D`80[XUD0P2_RUD0202aQU/0/HII0;67E`2`QU@0[hI@0:n6
CP2^QT/0[XI90P2_RUD30:j9E0<0[HQC202`QU@00`2cRUH0/XUE0;:9E@020;68E080/8MC00@0[hIB
0;68D02aR500/HQB0P2aR5@00`2aQeD0/HMG0;67E`020:f4D0040:j5D@2_QU80/8MC0;68E0@0/XUE
0`2aR5@30;27D`0;0:n4F@2`QEP0/8EH0;67E`2cREL0]8]G0;B;E@2eS5H0/HQ@0;>:DP2dRe<00P2e
S5@00`2dRe<0/hYB0;68D0020;68D0040;:9D`2bRED0/XUE0;>9E`80/hUI0P2^RE@30:n:E@`0/8]F
202cRUH80;68DPP0]8YH202bRED0202fSU40]HeB0;>;D02aR500/HQB0;:9E@2cREL0]8YH0P2]R5<2
0:j9E0040:n:E@2`ReH0/8]F0;2;EP80[HQA00<0[HQC0:f8E02/QUD00P2/QUL00`2/QUT0/8MC0;27
D`060;27D`P0[HA>00<0Zh9>0:b3C`2^QE400P2_QU800`2^QE40[8=?0:^2CP0;0:^2CP<0[8=?0P2]
Q5000`2[PTh0ZX5=0:V0C0020:QoB`030:Z1C@2/Pdl0[HA@0100[8=?202[PTh20:^2BP040:^2C02[
PTh0Zh9>0:^1C`80Zh5A00<0[89B0:j4E02aQeD00P2cRUH00`2aR580[XE=0:b3B`020:b3B`80ZX5;
0P2ZPDd01P2/PU00[XAD0:n5E@2`QUH0[hEE0:f3D@80[8=?00<0[HA>0:n6CP2`Qdl0202/Pdl:0:f4
D0<0[XEA00<0[HA@0:^2CP2[PTh00P2[PTh20:b3C`040:f4D02^QE40[XEA0:j5D@P0[8==0P2^QDl3
0:f4CP<0[8==202/Pdl00`2/Pdd0Zh9<0:^2C0020:Z1B`80ZH1:00@0Z7m90:Z1B`2ZPD/0ZX5;1@2[
PT`80:^2CPP0[8=?202[PT`80:V0C080Zh9>0P2ZPDd20:V0C080Z7m;0P2ZPDT0102ZPD/0Zh9>0:^2
CP2[PDl20:b2DP@0[H9=102/PD`20:b3C@80Zh9<0P2ZPD/20:V0BP<0[8=?0`2]Q5030:j5D@80[8=?
0`2[PTh30:Z1C@P0Zh9>00<0ZX590:^2BP2/Pd/00P2^QDd02`2/Pd/0Zh9:0:Z1B@2/PDh0Zh1=0:Yo
C02YOT/0ZWm<0:^0C@2]PTl0[hAA0100Zh9>102YPDH40:Z2A`P0ZH1<202YOTT00`2VODT0Ygi:0:V0
C0030:^2CP080:Z1C@2YP4`0[HA@0:f4D02/Pdl0Zh9>0:Z1C@2YP4`30:QoB`070:V0C02[PTh0[8=?
0:f4D02/Pdl0Zh9>0:Z1C@080:^2CP80Z7m;0`2YP4`30:Z1C@030:ElAP2VODL0YWe70080Ygi80P2X
OdT01`2YP4X0ZH540:V1AP2YPDH0Z7m70:QoB@2WOTX00P2WOD/80:V0C0P0ZGi90P2UO4H20:ImA`80
Ygi80`2XOdT20:ElB080YWe90P2WOTX20:QoB`P0Yga900P0Yge10:Il@P2TNT00XgQ10:=h@`2TNDH0
YWY90:MkBPL0YGY500@0YW]60:ElB02UO4P0YGa80P2TNdL30:=jAP070:UnB`2WO4T0YW]80:EjA`2T
NDH0YGY70:MlB@020:QmBP030:MlB@2UNTL0XgQ50080XgQ500<0Y7U60:EjA`2SNT@01`2SNT@40:Ai
A0@0XgQ3202SNT880:=jAP060:AeB`2TMDT0Y7E90:AeA`2UMdH0YGM50P2UMd<00`2QN4@0XWU50:Ak
A`030:ImB@80Y7]70P2SNDL00`2TNTP0YG]90:IlBP030:MmB`80XgU900@0XgU70:=jAP2SNTH0XgY4
0P2SNT830:=iA`80XWQ60`2QMdD30:5hA0<0XWU50P2SNTH80:ElAP050:Al?`2RNSd0WgLl09ee>P2M
M3`00P2OMT004`2RNDD0Y7]70:5hA02RNDD0XgY60:AkA`2SNTH0XWU50:1g@`2OMT80Y7Y80:9hAP2P
MT@0WgE309id@P2OMD<0X7I40:5gA@2PNdL00P2ONTH00`2NNDD0WGQ409ag@`0209]f@P80WgE300@0
WWA209ec@@2LLT00W7900P2KLCl00`2KL4<0W75409ebA@0209icAP0309ebA@2LLD@0Vg1300P0W790
202KLCl00`2HKD00VFi109U^@@0409U^@@0309Y_@P2HLcl0V7<o00H0V7<o0P2JL3h409U_?@80V6hl
0P2KLCl209Y`?P<0VFlm00<0V6hl09M]>`2GKC/00P2HKS`409U_?@80UV`j00h0Ufdk09Q^?02IKcd0
VW0n09]a?`2LLT00V6e009U^@@2JKd80Vg1309Y_@P2IKT40Uf`o09EZ?@80UF/i0P2FK3X209M]>`80
V6hl00H0VG0l09U_?@2HKS`0Ufdm09EZ?@2DJCh209=X?P0409EV>P2FIc/0UVLk09MX?080V6Tm0P2I
JSh00`2EJcT0UV`j09M]>`0209Q^?00309M]>`2FK3X0UF/i0080TVdi0P2CKSX509A_>`D0UFXm0`2F
Jch01@2EJSd0U6Tl09AY?02CJ3/0TFHi0080T6Dh00@0Sf@g08eV>`2>Ic`0SfPm0P2@JCh03P2?J3d0
SVLl08eV>`2?JSd0SfTl08eW>P2>ICT0SV<h091S>@2CI3X0U6Dk09AY?P2BIc`0TFHk0P2@ICX00`2A
IS/0TVLl09AY?P03091Y@0D0SfPo0P2@JS/208mY>P0408iX>@2=IcP0SFLh08eW>0P0SFLj202>J3/3
08eW>R_ooooo000Zooooo`80Pe/h00<0Pe/g08AM=P25GSD00P26Gc@00`26H3<0Qf0g08MP=`0208IO
=P@0QEhe00@0QV<i08ER>025HSP0QF8h0`24HCL01`23H3H0Oe`b081M<`20GC<0PUle08=P=P24HCL0
0P25HSP208QM<00408UN<`2:GcD0RUhg08]O>P80S60m202=HSL308iT=00308eS<`2<HS80Rf4a0080
Rf4a00P0S5ln08aP?@2=HC`0SF8h08iS=P2?ICD0SfHb091W<`P0SF8g00@0Rf0e08aQ=P2<HCH0S64f
0`2=HSL508iS>080Sf@i0`2@ICX3095W=`<0T6Hf0P2?ICD2095T>P@0T6<i0P2?HSP209=T>006099V
>@2AIST0TFPj08mY>P2@JS/0Sf/k0P2FJSd409EY?080U6Pk0`2FJSd209EY?0<0U6Pk00<0UfY009IY
?`2EJ3h00P2DIcd00`2FJCl0V6]109Y]@`0209EY>0<0UVXi0`2GJcX809M]>`80TfXl00<0UFXm09IZ
?@2HJCd00P2JJCh04@2LJCh0Uf/n09Q/?`2JKT40Vfm209Y^@@2GJch0U6Pk099V>@2GJch0UVXm09EY
?02DJ3/0UFTl09IZ?@2HK3l0VFe000P0Uf`o00@0VFdl09Y^?@2JKSd0Vfln0P2LL3l209ea@080Vg0m
0P2LLCh309eb?`0309ic@02KKch0Vfln00H0Vfln0P2JKSd309]_?P<0W70o202NLT400`2KKch0WG50
09mc@P020:1d@`80Wg=200d0WG5009]_?P2IK480Vfm209a`@`2MLD80WG5009aa?P2KL3/0VFhi09eb
?`2NLd00WgA10080X7E200<0WW=009aa?P2JKc`0202OM440202VM4<0YG=20:Ab@@2SLD00Y7910:Ec
@P2WMD@0Z7I5202SN4D20:5h@P070:5hA02QMdD0XWQ80:9gBP2SN4/0XgQ=0:QfA@020:IfA@030:Eg
A@2SN4D0XWU50080XGU50`2RMd030:=h@@80Y7U20P2TN4L00`2UNTL0YGY50:IkA0020:Il@P030:Il
@02UNTL0YGY70080YW]80`2WO4T01`2XODX0YGY70:IkB02VNdP0Yga90:QmBP2YOT/00P2ZOd`80:Qm
BP030:YoC02XODX0Yga90080YW]800<0Yga90:QmBP2ZOd`00P2[PTh20:Z1C@040:V0C02XOd/0Z7m;
0:MnBPP0Z7m70P2ZPDT0102ZPD/0ZH1<0:V0C02YOdd20:UoC`80ZWi?00@0ZWi=0:YoC02ZOd`0ZWm:
0P2ZOdP20:f4D0040:b3C`2[PTh0Zh9>0:Z1C@80ZH1<2@2/Pdd0102_Q540[X=@0:j3D02]PTl20:b1
CP80Zh1=202/PD`0202/PDh0Zh1=0:YoC02YOT/0ZWm<0:^0C@2]PTl0[hAA0P2/Pdl20:^2CP80ZX5=
0P2YP4`01P2WO4T0Z7e:0:QmBP2ZOd`0Zh1=0:b1CP80[H9?0`2YP4`00`2ZPDd0Zh9>0:b3C`020:b3
C`80[X1>00<0[85>0:^2CP2ZPTh00P2XPdh01P2WQ4h0ZWm<0:YoC02[P4d0[85>0:f2C`80[hAA00D0
/8EB0:j4E02]Pe<0[H=C0:b2DP020:^1D@80ZX1@0`2/Pdl20:f4D0<0[XEA0P2`Q5<01P2`QE80[hA?
0:n4C@2_QD/0[XA:0:j4B080/H=700<0/H=80;62BP2aPT`00P2aPTh00`2aPE00Zh570:^1A`020:^1
A`@0[898202ZOd`0102XODX0ZGi;0:UnB`2ZOd`20:^0C@80[85>0P2WOTP00`2XOdT0ZH1:0:Z1B`02
0:^2C0030:b3C@2ZOdX0ZWm:00<0ZWm:0`2[P4/20:UmC0030:UnB`2YOTT0ZGi70080ZGm500L0ZGm3
0:Mo@P2WOd@0Ygm40:QoA`2XOdT0ZH1<00<0ZGm=202YP4X0102UNTD0YW]60:IkAP2VNdH20:MlA`80
Z7e8202XOd/20:^0C@040:YoC02YOT/0ZGi;0:QmBP80Yga90P2ZPDd0102YP4`0Z7m;0:QoB`2WOTX4
0:ImB@040:MnBP2XOd/0Z7m;0:V0C080ZX5=0P2WO4T0102XODX0ZGi;0:UnB`2ZOd`20:^0C@P0ZGi7
2@2ZOdX03@2YOTT0Yga70:IkAP2VNdH0Yga70:UnB@2ZOdX0YWe90:MnBP2XOd/0ZH1<0:Z1C@2[PTh0
2P2/Pdl80:b1CP<0Zh9>0`2/Pdl20:f4D0<0Zh9>0`2/Pdl20:f4D0P0[8=?0`2_Q4l20:j3CP<0[H9=
202]Q5020:j5C@040:j5C`2^QE40[XEA0:j4DP80[XAD0`2]Q5030:j5D@/0[hIB0P2]Q4h01P2/Pdd0
Zh9<0:f4CP2_QU00/XUC0;B;E@P0/8MA00P0/XQF0;26E02_QU80[HA>0:f4C02_Qd`0/8Q=0;::C@P0
/8MC202[QU840:f8D`80[XUD0P2_RUD0202aQU`0/HIK0;66F@2`QU@0[hI@0:j6B`2^QTT0[XI80P2`
ReH00`2_RUD0[XUD0:f8D`020:b7DP030:^6D@2`QU@0/8ID00H0/8ID00@0/hYF0;:9E@2bRED0/HQD
0P2`Qe<20:n6DP80/HQ@00@0/HQB0;68E02aR5@0/HME0P2aQeL0202/Pdl0[HA@0:j5D@2_QU80/8MC
0;68E02bRED0/hYF0P2bRED30;68E0<0/8MC00H0[hAI0:n4E`2`QEP0/HMG0;>9E`2dReL20;F<EP03
0;68D02cRU80]8]C0080]HaD00<0]8]C0;>:DP2aR5000P2aR500102aR580/XUE0;:9E@2cREL20;>9
F@<0[XUD0P2_RUD30;2;EPT0/HaG202cRUH80;68DPP0]8YH0P2cRUH40;:9E@80/HQD00P0]XiA0;F=
DP2cRe00/XUA0;68DP2bRED0/hUG0;B:F080[HQC00@0[XUD0:n:E@2_RUD0/8]F0P2aS5L01@2_RU<0
[XUB0:j9E02]R5@0[8IE0080ZhEF00<0ZXAG0;27D`2`Qe<01P2`Qe<80:f4CP030:^2CP2/Pdl0[XEA
0080[hIB00<0[XEA0:b3C`2[PTh0202/Pdl30:^2CP<0[8=?0P2]Q5000`2YP4`0Z7m;0:MnBP020:Mn
BP030:V0C02[PTh0[8=?0100[8=?202[PTh20:Z1B@040:Z1B`2ZPDd0ZX5=0:Z0CP80ZX1@00<0Zh5A
0:j4E02aQeD00P2dReL01@2aR580[XE=0:^2BP2]Q4`0[8=;0080ZX5;00P0ZH1<0:Z1C@2/PU00[XAD
0:n5E@2`QUH0[hEE0:f3D@80[8=?00<0[HA>0:n6CP2`Qdl0202/Pdl80:f4D0030:b3C`2^QE40[hIB
0080/8MC00<0[HA@0:Z1C@2XOd/00P2[PTh0102/Pdl0[HA@0:f4D02^QE420:n6DPP0[8==0P2_QU00
102^QDl0[HA>0:f4CP2/Pdd20:^2C0P0[8=?00@0Zh9<0:Z1B`2ZPD/0ZH1:0P2XOdT20:MnB0@0ZX5;
102[PT`80:^2CPP0[8=?202[PT`80:MnBP80Zh9>0P2ZPDd0302YP4`0Z7m;0:QoB`2WOTX0Z7m70:V0
B02YP4X0ZX5=0:^2CP2/PU00[89B0:f3D`<0[85<0`2]PTd20:j3CP<0[8==00<0Zh9<0:Z1B`2YP4X0
0P2YP4X30:b3C`<0[HA@0`2^QE430:^2CP80ZX5=0`2YP4`80:^2CP030:Z1B@2[PTX0[8=;0080[XE=
00H0[8=;0:^2BP2ZPDT0[H9?0:^0C@2ZOd`20:UnB`030:^0C@2]PTl0[hAA0100Zh9>0P2ZPTD60:V1
A0P0ZH1<202YOTT00`2VODT0Ygi:0:V0C0030:^2CP0>0:Z1C@2YP4`0[XEA0:f4D02/Pdl0Zh9>0:Z1
C@2YP4`0Z7m;0:MnBP2VODT0Z7m;0:Z1C@2/Pdl20:f4D0X0Zh9>0P2WOTX00`2XOd/0ZH1<0:Z1C@02
0:^2CP030:b3C`2UO4H0YGa60080YWe700D0Ygi80:QoB@2XOdT0ZH1:0:V1A0020:V1AP030:QoA`2X
OdT0Ygi:0080Yge;202YP4`80:UnB@80YGa60P2VODL20:MnB080Z7m900T0ZH1:0:AkA`2TNdL0YGa8
0:ImB@2WOTX0Z7m;0:V0C02ZPDd0202WO4T0202WOD40YWa20:Aj@02SN440XgQ30:AiAP2VNTT0Yg]:
0`2VNdH30:EjA@80Y7U40`2UO4P30:AkA`80XgY600<0ZGi;0:QmBP2VNdP00`2UNTL01@2WO4T0Z7e:
0:UnB`2XODX0YW]800<0Y7U600<0YGY70:IkB02SNT@01`2SNT@40:AiA0@0YGY5202SNT820:5hA004
0:9iA@2SNTH0XgY60:AkA`80YGa800H0XW=90:=dB02SM4P0Y7E70:EgAP2VN4H20:MiA@0@0:5hA02R
NDD0Y7]70:ImB@2WOTX0YWe90:AkA`2SNTH0XWQ60:=iA`2TNTP0YG]90:IlBP2WOD/0Z7i<0:UoC@80
XgU900@0XgU70:=jAP2SNTH0XgY40P2SNT820:=iA`<0XWQ60`2QMdD01P2OMT80X7M30:1g@`2QN4@0
XWU50:=jAP80Y7]7202UO4H01@2UOCl0XWXm09mg>P2LM3T0W7<k0080WgI00180XWU50:ElB02QN4@0
XWU50:=jAP2TNdL0XgY60:9iA@2PMd<0WgI20:AjB02RN4H0X7I409me@`2NM480WgE30:1fA02QMdD2
0:1kA`0409mjAP2NNDD0WGQ409ag@`80VgI20P2PMT@02@2OMD<0WG=109ab@02KLCl0VW0n09U_?@2J
Kd80Vg1309icAP020:1eB00309icAP2KL4<0VVm200P0W790202KLCl00`2GK3l0V6e009Q]@00209U^
@@80VVm200<0Vg1309Ud@02IM4001P2IM4000`2JL3h0VFlm09U_?@0409U_?@0309Q^?02LLcl0W7<o
00<0Vg8n0`2JLCd209Q^?080VFlm0P2JL3h209]a?`80UV`j00@0Ufdk09Q^?02JL3h0Vg4o0P2LLT00
0`2HKD00VFi109]`@`0209]`@`0309U^@@2GK3l0UFXm0080UF`h0P2FKCT209M^>P80V6lk00H0VG0l
09U_?@2HKS`0Ufdm09M/?`2FJd0209EZ@080UVLk0`2GJ3`309QY?@0309E[>@2FK3X0Ufdk0080V6hl
00<0Ufdk09I/>P2EJcT00P2BKCT209=^>P@0U6lk00<0UG0l09I[?P2FJch01P2EJSd02`2EJSl0U6Tn
09=X?@2BIc`0TFHk091U>P2?I3T0SV<h08eV>`2>Ic`0SfPm0080T6Tn00h0SfPm08iW?02=IS/0SfXm
08mY?02=IcX0SVDi08iS>02@HcT0Tf@j09AU>`2CJ3d0TVLl095V>`80T6Dj00<0TFHk099W?02CJ3d0
1@2@JD0308mX?`<0T6Xk00<0SfTj08iX>@2=IcP00P2=IcP808eW>PP0SVPk0`2?JC`[ooooo`00:_oo
ool208UR>@0408QQ>027H3L0Qf0g08IO=P80QEhe0`28G3D308UM=P80RUhg0`25GSD308IO=P80Qf0g
00<0R5`e08UM=P2;GcP00P2<H3T00`2;GcP0REdf08QL=@0308aQ=PD0Rf0e00<0REha08YO<P2<HC@0
0P2=HSD00`2<HC@0RUlb08UN<@0808iS>0P0SV<f00P0Sf@i091U>P2BIc`0TfPm099W?02AIS/0Sf@i
08eR=`T0SV<h202@HcT00`2>HCL0Sf8h095T>P0309=V?00=099U>`2AI3X0U6Pk08mS=P2=HC@0Sf<f
09AX>`2FJSd0TfLj08mS=P2CJ3/0TVLj095V>@02091U>003095V>@2BIcX0TfPk00<0TfLj1@2DJ3/8
09AW?@04095U>02BIST0U6Pk09IZ?@80Uf/n0P2FJSd209AX>`0309EY?02FJSd0Uf/n0080V6`o00@0
VFe009Y_@P2HKD00Uf`o0P2FJch00`2GK3l0V6e009Y_@P0809Q/>`0909=X?P2DJCl0UFY009I[@@2G
K480V6e309U^A02JKdD0Vg0m0080VVll00<0VFhk09Q]>P2HKCX00P2GK3T00`2EJCP0Uf/j09Q/>`02
09Y^?@0309Q/>`2GJcX0UFTh00P0V6e00P2LLCh0102KL3d0VVll09Y_?02IKS/209Q]>PP0VFhk0P2H
KCX0102IKS/0VVll09Y_?02KL3d209aa?PP0WG8o0P2KLCl209ab@00=09ec@@2NM480WWA209id@P2O
MD<0WG=109Y`?P2GKC/0V6hl09]a?`2LLT00VW0n09I/>P0209aa?080WG8m00@0WW<n09md?`2OM3l0
X7E0202OM3l00`2TM4<0Xg=20:9b@@020:5a@0030:=c@P2UMD@0YgM600P0XWI500H0X7E20:5f@`2Q
MT<0XWM40:=hA@2TNDH20:EjA`80Yga900H0YW]80:EjA`2TNDH0XWM40:5f@`2PMD830:=h@`80Y7U4
0`2UNTD80:MlA`090:UnB@2XODP0YW]60:EjA@2TND@0YGY50:IkAP2WO4L0XWM20080XgQ300<0YGY5
0:IkAP2WO4L00P2XODP0102UNTL0YW]80:IkB02VNdP20:MlB@80Z7e:00<0[85>0:^0C@2YOT/00P2W
O4T0102XODX0ZGi;0:YoC02WOTX30:QoB`80ZH1<0P2ZPDd30:^0C@030:YoC02YOT/0Z7e:0080Z7e:
00H0[H9=0:b1C02/PD`0Zh1;0:YoBP2YOTT20:QmB080ZWm:0P2[P4/30:b1C0@0[H9=00<0[85<0:^0
B`2ZOdX00P2ZOdX20:f2C@80[X=>00D0[H9=0:YoBP2XODP0Z7e80:MlA`020:UoC`80ZX1@0P2[PE42
0:b2DPP0Zgm>0P2]PTd20:b1C080Zh1;0P2ZOdX30:f2C`030:b1CP2[P4d0ZWm<0080ZWm<202YP4X2
0:Uo@`<0ZX140`2[PDD20:QoA`<0ZH180`2ZPDT20:f4D0<0[8=?0`2[PTh20:j2D`<0[H5B0`2/P540
0`2]Q500[XEA0:n6DP020;27D`050:n6DP2]Q500[8=?0:j5C`2_QU000P2`Qe401`2_QU00[HA>0:^2
C02ZPD/0/8960;63A`2bQ4P00P2cQDT00`2aPdL0[h550:j0A0020;:1B@80/H180P2`OdL20:mnAP80
[85<00@0Zh1;0:YoBP2XODP0Yga70P2VNdH20:UoA@<0ZX160`2[PDL0102TNdD0YWe70:QoB@2YP4X2
0:Z1B`030:V0BP2XOdT0ZH1:0080ZH1:0P2XOdT30:MnB0P0YW]40`2UNTL20:IkB0@0Yga9202WOd80
102XODP0Yga70:MlA`2VNdH20:EjA@80Y7U40P2UNTL01`2VNdP0Yga90:QmBP2YOT/0ZWm<0:^0C@2V
ODD01P2WOTH00`2VODD0Ygi80:QoB@030:Z1B`040:QoB@2VODL0Y7]50:In@080YWi100<0YWi30:Mn
AP2WOTP00P2XOd/20:V0C0@0Z7m;0P2WOTX30:MlA`<0Z7e82P2YOTT20:UnB`<0ZWm<0`2[P4d20:Mo
@P80YWi100@0Ygm20:Z2A@2/Q4L0[XI9202/Pdl80:b3C@<0Zh9>0`2/Pdl20:f4D0050:QoB@2YP4X0
ZH1:0:Z1B`2[PT`00P2/Pdd0102]Q4h0Zh9<0:^2C02[PT`30:b3C@80[HA>00@0ZH540:Z2A@2ZPTD0
ZX950P2[PdH20:b4A`030:Z1C@2[PTh0[HA@0080[XEA00<0[HA@0:^2CP2ZPDd00`2/Pdl20:f4D0`0
[XEA0P2bRE40102aR580/HQD0;27D`2`QU@20;26EP80[H5@0P2^PU401P2_Pe80/8AC0;24D`2aQE@0
/HQD0;:9E@80/hYF00L0/XUE0;27D`2^QE40[HA@0;26E02_QE<0[H=A0080[89@00H0[H=A0:n5D`2`
QU@0/XUE0;27D`2_QU820:f4D0030:n6DP2`Qe<0/XUE0080ZhIB0P2/Qe<20:f8E080[XUE0`2^QE40
0`2_QU80/8MC0;68E0020;68E0<0[HA@1@2^QE40202dRe<0/hYB0;68D02_QTh0[XE=0:n6CP2aR500
/XUA0`2cRUH30;B;E`80]HaH0P2bRED30;68E0<0/8MC00H0]8]G0;>:EP2cRUH0/HQD0;27D`2_QU82
0:j5D@80/XQF0`2aQeD30;26E0060;B:CP2bRTl0/XY?0;29D02]R540[8UC0P2YR5<30;67E`80/XQH
0`2cRET30;68E080/XUE0`2cRUH80:n;D@P0]8]E0`2fS5X00`2eS5P0]8]E0;>:DP020;69CP040;28
B`2aR580/HQB0;68DP80/XUC0`2cRU@0202^QE40[hIB0;68E02bRED0/hYF0;:9E@2aR5@0/8MC0P2a
R5@00`2bRED0/hYF0;B;E`020;F<F0040;J=F@2cRU@0/hYD0;>:E080/XUC0`2aR5820;:9E@<0/hYF
0`2dReL80;>:EP030;27D`2_QU80[HA@0080[8=?00<0[XEA0;27D`2aR5@00P2_RUH30:j9E@<0[HQD
202/Pdl80:f4D080[hIB00@0[XEA0:f4D02]Q500[8=?0P2[PTh0102`Qe40[hI@0:n6D02^QDl20:f4
CP80[8==0P2^QDl00`2]Q4h0[8==0:^2C0020:Z1B`050:V0BP2^QE40[HA@0:f4D02/Pdl00P2[PTh2
0:Z1C@80[XAB00<0[XEA0:f4CP2]Q4`00P2/Q4T00`2/Q4L0[HA@0:f4D0070:f4D080[8=?00D0Zh9>
0:Z1C@2YP4`0ZH1<0:QoB`080:f4D0T0Zh9>00<0[hI@0:j5C`2]Q4h00P2/Pdd00`2]Q4h0[XE?0:n6
D0080:f4D0030:^1D@2ZP500Z7i<0080Ygi:00H0Z7m90:Z1B@2[PTX0Z7m;0:V0C02/Pdl30:j5D@05
0:b3C`2[PTh0[XE=0:j5C@2^QDl00P2]Q5000`2/PU00[89B0:b2DP020:b0F@030:b1E`2/PEH0[85D
0080[89B00@0[89@0:n6D02_QU00[XE?0P2]Q4h00`2/Pdd0Zh9<0:^2C0080:YoC0P0[8=?00@0Ygi8
0:QoB@2XOdT0ZH1:0P2ZPD/20:^2C0<0[8=?00<0Zh9>0:Z1C@2YP4`00P2YP4`20:^2CP040:b3C`2]
Q500[HA@0:j5D@80[hIB202[PTh03P2UO4P0Ygi:0:V0C02[PTh0[8=?0:^2CP2ZPDd0ZH1<0:f4D02[
PTh0ZH1<0:QoB`2WOTX0Z7m;0P2YP4`20:QoB`<0ZH1<0`2ZPDd50:YoC0<0Zh1=0P2XOd/30:V0C0<0
ZX5=0P2YP4`30:Z1C@80Zh9>1@2/Pdl00`2[PTh0ZX5=0:V0C0020:V0C080ZGi90`2ZOdX30:^0B`P0
[HA@00@0[XE?0:f4CP2]Q4h0[8==0P2[PT`20:Z1B`P0Zh9>202/PU080:YoBPP0ZH1<202ZOd`80:V0
C0P0Zh9<00h0X7]70:R3C`2bSET0^iIR0;fHI02hTel0/8]G0:^6DP2XP4<0Z8150:V1AP2YP4P0ZH1:
0:Z1C@80ZX1>202YP4`30:QmB080ZGi90`2ZOdX80:V0C0030:]oCP2ZOTd0ZGe<0080Z7a;00<0ZGe<
0:YnC@2[Odh00P2YOTT30:QmB0<0Yga72@2VODT00`2SNT80Y7]30:ImA@020:MnAP060:ImA@2TNd<0
XgY20:MlA`2VNdH0YGY50P2SN4<00`2UNTD0YW]60:MlA`080:QmAP040:=hA@2TNDH0Y7U60:EjA`80
YW]80P2WO4T80:AhA`030:V0C02VODT0XWU50080WgI200<0XWU50:ImB@2YP4`00`2UO4P30:AkA`80
XgY600<0YGa80:AkA`2SNTH00P2QN4@01`2RNDD0XgY60:AkA`2TNDH0XgQ50:1e@P2NLd000P2MLSl0
0`2OM440X7E20:IjB`020:EiBP030:=gB02RMTL0XGE60080X7A500<0YG]90:AjB02RN4H00`2PMT@0
1@2QMdD0XWQ60:AjB02SNDL0XWQ60080XGM500H0XgU70:EkB@2VO4X0XgQ30:AiA02VNdH20:MlA`03
0:IkAP2TND@0XgQ30080XgY600@0Y7]70:ElB02VODT0Ygi:0P2XOd/20:ImB@<0YGa80`2TNdL01@2T
N4T0XgM80:=gB02RMTL0XGE60080X7A500@0Wg=409id@P2PMT@0XWQ60P2TNTP01P2SNDL0XWQ60:5g
A@2VODT0YGa80:=jAP80XWU500H0XgY60:ElB02VODT0XWU10:5h@02PMd4209mf@P80X7I400P0XGM7
0:9hB02SNTH0XgY60:9iA@2QN4@0X7M309mf@P80WWE1202NNDD20:=iA`80XWQ6102QMdD0202OMD<0
WWA209ec@@2LLT00Vg4o09Y`?P2IKcd0V6hl0`2JL3h00`2KLCl0W79009ec@@0209ec@@80W7900P2K
LCl0102JL3h0VFlm09U_?@2HKS`209U_?@80VW0n102KLCl0102NM480WG=109]a?`2IKcd209Q^?00=
09U_?@2JL3h0WG=109ab@02KLCl0VFlm09Q^?02FK3X0UF/i09AZ>02LLT00Vg4o09U_?@0209M]>`03
09Q^?02IKcd0VW0n00P0UG4m00<0VFlm09Y`?P2LLT000P2NM4800`2MLd40W79009]a?`0209Y^?@<0
VFdl0`2HK3/309E[>@0309I/>P2GKC/0V6hl0080V6hl0P2EJcT209I/>P80Ufdk0P2HKS`0202LLT00
Vg4o09Y`?P2IKcd0Ufdk09E[>@2DJSP0TfTg0P2EK3H00`2EK3P0UV`j09M]?@0209Q]@00309Q]@P2B
K3d0TV`m0080Tfdn0P2DKSl209E_@0<0V6hl00<0Ufdk09I/>P2EJcT00`2EJcT01P2?I3L0T6Dh095V
>@2BIcX0U6Tl09EZ?@80UV/n00<0U6Xh09=Y=`2BJ3H00P2@IS@00`2BJ3H0TfTg09AZ>00809=X>`P0
S6Xl00<0S6Hi08iX>`2@JSd00P2BK3l01`2AJch0T6Xm08mY?02>I3@0SfDe099X>02DJSX00`2EJc/0
0`2DJSX0TF/n095[?P03091Z?@<0SfTl00H0SV<f08mT=`2AIST0TfPk09AY?02CJ3/2099W>P0309=X
?@2DJCh0UFXo0080UV]000<0UFXo09AY?P2CJ3d00`2?JCP[ooooo`00:_ooool208QQ>0<0Qf0g0`26
GcH308QL=@<0REdf0P2:GSL308EN=@<0QUlf0P27H3L00`28G3D0REdf08]O>00208aP>@0308]O>029
GCH0R5`e0080S64f1P2;H3D00`29GS40RUlb08aQ=00208eR=@0308aQ=02:Gc80REha00P0SV<h202>
HcH00`2?I3T0T6Dj095V>`02099W?003095V>`2?I3T0SV<h00T0SV<h202@HcT00`2>HCL0Sf8h095T
>P0309=V?00B099U>`2AI3X0TfLj091T=`2=HC@0Sf<f09AX>`2FJSd0TfLj091T=`2BIcX0TFHi091U
>02?I3L0T6Dh099W>P2CJ3/0UFXm0P2CIcX609AX>`P0U6Lm00<0TFDh099V>@2EJC`0102GJch00`2F
JSd0UFTl09EY?00309IZ?@<0Uf/n00<0VFi109Q]@02GK3l00P2FJch00`2GK3l0V6e009U^@@0809Q/
>`80U6To00@0UFY009I[@@2GK480V6e30P2IKT@309Y_?00309U^>`2HKCX0V6dj0080Uf`i00<0UVXi
09M[>P2IKC`00P2JKSd00`2IKC`0Uf/j09IZ>@0809Q]@0<0Vg0m0`2JKc`209U^>`P0Vg0m00<0V6dj
09U^>`2IKS/00P2JKc`209]`?@0309aa?P2MLSl0WG8o00H0WG8o0P2KLCl209ab@0<0WG=10`2NM480
202KLCl0V6hl09U_?@2MLd40WWA209]a?`2HKS`0W74l0P2MLSd209ic?P80Wg@o00<0X7E009md?`2O
M3l01P2OM3l0202TM4<0Xg=20:9b@@2QLD00XW910:=c@P2UMD@0YWI5202RMTD01P2PMD80XGI30:5f
@`2RMd@0XgQ50:AiAP80YGY70P2VNdP01P2UNTL0Y7U60:=hA@2SN4D0XWM40:5f@`80XgQ30`2TND@3
0:EjA@P0Yga700h0ZGi90:QmB02VNdH0YGY50:AiA02UNTD0YW]60:MlA`2RMd80XgQ30:AiA02UNTD0
YW]60:MlA`80Z7e8102VNdP20:MlB@80Z7e:00<0[85>0:^0C@2YOT/00`2WO4T00`2XODX0ZGi;0:Mn
BP030:MnBP80Z7m;0P2YP4`20:YoC080ZGi;0P2XODX20:MlB@<0Zh1;0`2ZOdX20:UnB@80ZWm:0P2[
P4/40:b1C080[H9=0P2/PD`20:^0B`80ZWm:0P2]PTd20:j3CP050:f2C@2[P4/0Z7e80:QmB02WO4L0
0P2YOdl20:Z0D080Zh5A0P2/PU880:b0C`80[H9=0P2/PD`20:^0B`80ZWm:0P2]PTl20:b1CP80Zh1=
0P2ZOd`80:V0BP80ZGm50`2ZP4H30:^1A`80Z7m70`2YP4P30:Z1B@80[HA@0`2/Pdl30:^2CP030:b0
D@2]PE80[H5B00D0[H5B00<0[HA@0:j5D@2_QU800P2`Qe<00`2_QU80[HA@0:b3C`020:n6D0090;27
D@2aR580/8MA0:n6D02]Q4h0Zh9<0;22AP2aPdL0/XA80080/hE900<0/H=70:n1A@2^P4@00P2`PDT2
0:n0B080[Wm70P2]OTH01@2/PD`0Zh1;0:^0B`2ZOdX0Z7e80080Yga700<0YW]60:Z0AP2ZP4H01P2Z
P4H01P2TNdD0YWe70:QoB@2YP4X0ZX5;0:V0BP80Z7m90P2YP4X20:QoB@<0Ygi800<0YWe70:MlA@2W
O4D01P2WO4D30:IkB0<0Yga90`2XODX80:In@`80Z7e80P2WO4L20:IkAP80YGY500H0Y7U60:EjA`2V
NdP0Yga90:QmBP2YOT/20:YoC080YWe5102WOTH20:ImA@0:0:MnB02XOdT0ZH1:0:Z1B`2YP4X0Z7m9
0:ImA`2TNdD0YGe00:In@@80YWi300<0Ygi60:MnB02XOd/01`2XOd/20:MnBP<0Yga70`2XODP:0:Un
B@<0ZGi;0P2ZOd`30:^0C@80Z8150P2WOd@0102XP4D0ZX970:f5BP2^QT/80:b3C`P0[8==0`2[PTh3
0:b3C`80[HA@102ZPD/70:^2C0<0[8==0P2]Q4h40:Z2A`80Zh=80P2/Q4T00`2ZPDd0Zh9>0:f4D002
0:j5D@030:f4D02[PTh0ZX5=00<0[8=?0P2]Q50<0:j5D@80/XUA00H0/HQB0;68E02`Qe<0/8ID0;26
EP2_QED20:j2D@80[h=B00@0/8AC0;65E02aQE@0/HED0P2aR5@02@2bRED0/hYF0;:9E@2aR5@0[hIB
0:f4D02`QU@0[hEC0:f3D@020:b2D0060:f3D@2_QE<0/8ID0;68E02`Qe<0[hIB0P2^QE400`2_QU80
/8MC0;68E0020:^6DP80[8MC0P2]R5@20:j9E@<0[XEA00<0[hIB0;27D`2`Qe<00P2aR5@30:j5D@@0
[hIB00@0/8MC0;B;D`2cRU80/HQ@0`2_QTh20;68D0040;68E02bRED0/XUE0;:9E@80/hYF0P2dReL0
0`2`Qe<0/HQD0;68E0050;68E0060;B;E`2cRUH0/XUE0;68E02`Qe<0[hIB0P2^QE420;:8EP<0/HME
0`2`QU@01P2cRDd0/XY?0;::C`2`RE00[HQA0:b9D`80ZHQC0`2aQeL20;:8F0<0/hUI0`2aR5@20;:9
E@<0/hYF202_Re480;B;E@<0]XaJ00H0]HaH0;B;E@2cRU80/XY?0;69CP2`R4/80;:9D`030:j5D@2_
QU80/HQD0080/hYF00<0/XUE0;68E02`Qe<00P2bRED30;>:EP<0]8]G0`2cRU@30;:9D`80/HQB00<0
]8]G0;>:EP2cRUH03@2cRUH00`2`Qe<0[hIB0:j5D@020:f4D0030:j5D@2`Qe<0/HQD0080[hYF0`2^
RED30:f8E0P0[XEA202]Q5000`2_QU80[XEA0:j5D@020:f4D080[8=?00D0Zh9>0:j5C`2^QDl0[XE?
0:f4CP020:b3C@80Zh9<0P2]Q4h30:b3C@<0Zh9<00<0[XEA0:f4D02]Q5000P2/Pdl20:^2CP060:Z1
C@2^Q580[XAB0:j5D@2]Q4h0[HA<0P2/Q4T00`2/Q4L0[HA@0:f4D0060:f4D080[8=?0`2[PTh30:Z1
C@P0[HA@2@2[PTh00`2^QDl0[HA>0:b3C@020:^2C0030:b3C@2]Q4h0[XE?00P0[HA@00<0[89B0:^1
D@2YOdd00P2XOd/01P2YP4X0Zh9:0:b3B`2XOd/0ZX5=0:b3C`<0[XEA00D0[HA@0:b3C`2^QDd0[XE=
0:j5C`020:f4D0040:b2D02/PU80[89B0:b0F@80[85G00<0[85F0:b1E02/PU800P2/PU000`2_QU00
[XE?0:j5C`020:f4CP80[8==00<0Zh9<0:YoC02ZOd`01P2ZOd`80:^2CP80Z7m90P2YP4X20:Z1B`80
Zh9<0P2/Pdl20:^2CP80ZX5=0P2YP4`20:^2CP80[8=?00@0[HA@0:j5D@2^QE40[XEA202[PTh0402V
ODT0Ygi:0:V0C02[PTh0[8=?0:^2CP2ZPDd0ZH1<0:b3C`2ZPDd0ZH1<0:QoB`2WOTX0Z7m;0:Z1C@2[
PTh20:QoB`<0ZH1<0`2ZPDd60:YoC080Zh1=00<0ZX5=0:V0C02YP4`01`2YP4`30:Z1C@80Zh9>102/
Pdl20:^2CP80ZX5=0P2YP4`20:UnB@<0ZWm:0`2[P4/80:f4D080[HA>0P2/Pdd20:^2C080ZX5;202[
PTh80:b2D0P0ZWm:202YP4`80:YoC0P0ZH1<202[PT`03P2RODT0Z8=?0;2;E`2gTUh0^9=O0;F@G02_
RUH0ZhIB0:R0@`2XP4D0ZH560:V0B02YP4X0ZX5=0P2ZP4h80:V0C0<0Z7e80P2YOTT30:YoBPP0ZH1<
00<0ZWi=0:UmC02XO4/00P2WNdX00`2XO4/0ZGe<0:YnC@020:UnB@<0Z7e80`2WO4L90:ImB@030:Ak
@`2UO4@0Ygi60080Z7m700H0Ygi60:ElA02TNd<0Yga70:IkAP2UNTD20:=h@`030:EjA@2VNdH0Yga7
00P0Z7e60`2TNDH00`2UNTL0YW]80:IkB0020:MlB@P0Y7Q700<0Ygi:0:ImB@2SNTH00P2QN4@00`2S
NTH0YWe90:MnBP030:ElB0<0Y7]70P2SNTH00`2UO4P0Y7]70:=jAP020:5hA0070:9iA@2SNTH0Y7]7
0:IkB02TNDH0XWM40:1e@P0209md@@080:1e@P2QMT<0YWY;0:EiBP2TN4T0XgM80:9fA`2QMDH20:1d
A@030:EkB@2TNTP0XWQ600<0X7I400@0XGM50:9hAP2SNDL0XWQ60`2QMdD01P2SNDL0YG]90:IlBP2S
N4<0Y7U40:IkAP80Yga700<0YW]60:AiA02SN4<00P2SNTH00`2TNdL0YGa80:ImB@020:MnBP030:Qo
B`2UO4P0YGa800<0Y7]70`2SNTH01P2UNDX0Y7Q90:=gB02RMTL0XGE60:1dA@80Wg=400/0WgE30:1f
A02RN4H0XgU70:AjB02SNDL0XWQ60:5gA@2VODT0YGa80:=jAP020:9iA@060:=jAP2UO4P0YWe90:=j
@P2QN400X7M10P2OMT820:1fA0080:5gA`2SNDT0XgY60:=jAP2RNDD0XGQ40:1g@`2OMT8209ie@@P0
WWU50P2SNDL20:9hAP<0XGM500H0X7I409id@P2NM480WG=109ab@02KLCl509Y`?P80Vg4o00@0W790
09ec@@2MLd40WG=10P2LLT0209]a?`80VW0n102IKcd209Y`?P<0Vg4o00T0W79009id@P2MLd40Vg4o
09U_?@2HKS`0VFlm09Y`?P2KLCl00P2LLT000`2KLCl0VW0n09U_?@0209Q^?00909M]>`2LLT00Vg4o
09U_?@2HKS`0Ufdk09Q^?02IKcd0VW0n00P0UW4m00<0V6hl09U_?@2KLCl00P2MLd400`2LLT00Vg4o
09Y`?P0209Y^?@<0VFdl0`2HK3/309E[>@0309I/>P2GKC/0Ufdk0080V6hl0P2EJcT209I/>P80Ufdk
0P2HKS`0202LLT00Vg4o09Y`?P2HKS`0Ufdk09E[>@2DJSP0TfTg0P2EK3H01P2EK3P0UV`j09M]?@2G
K3l0V6e009Q]@P80TV`m0P2CKCh209A^?`80UFm00P2HKS`209M]>`80UV`j0`2EJcT2095V>@04099W
>P2CJ3/0U6Tl09AY?080UFXm00<0UF/i09AZ>02CJCL00P2BJ3H00`2CJCL0U6Xh09E[>@0809=X>`P0
S6Xl00`0S6Hi08iX>`2@JSd0TF/n099/?`2AJch0T6Xm08mY?02>I3@0T6Hf099X>02DJSX209E[>`80
U6Xj0`2AJch2091Z?@<0SfTl00H0SV<f091U>02BIcX0TfPk09AY?02CJ3/2099W>P03095V>`2CJ3d0
U6Tn0080UFXo00<0U6Tn09=X?@2AIS/00`2?JCP[ooooo`00:_ooool01025GSD0QUlf08IO=P26GcH4
08MP=`<0R5`e0`29GCH208YN=`<0QEhe0`26GcH208MP=`80REdf102;GcP208UM=PP0Rf0e00<0RUld
08]P=@2<HCH00P2=HSL00`2<HCH0Rf0e08YO=00808iS>0P0SV<f00<0SV<h08mT>@2@ICX00P2AIS/0
0`2@ICX0Sf@i08mT>@0908iS>0P0T6<i00<0SV4g08mR>02AI3X00`2CIS`02`2BIC/0TF@j09=W>P2@
I3L0Sf<f091T=`2CIcX0UFTl09=W>P2AICP0T6Dh00<0Sf@g00@0T6Dh09=X>`2EJSd0Uf`o202DJ3/8
09AW?@04095U>02CIcX0UFTl09M[?P80V6`o00<0Uf/n09IZ?@2GJch00P2GJch309IZ?@80UFTl00<0
VFi109Q]@02FJch00P2EJSd00`2FJch0V6e009U^@@0809Q/>`0509AY?P2EJSl0UFXo09I[@02GK440
0P2HKD800`2IKT<0VVll09Y_?00309U^>`<0V6dj00<0Uf/j09Q/>`2IKC`00`2IKC`00`2HK3/0Uf/j
09Q]@00709Q]@0@0VVll0`2KL3d909aa?P<0VFhk0P2JKc`309]`?@P0WG8o0P2KLCl309ab@0@0WG=1
00P0WgE309ab@02JL3h0Vg4o09me@`2PMT@0WWA209Y`?P80WG8m0P2NLch409md?`P0X7E00P2SLd83
0:9b@@030:=c@P2UMD@0YWI500P0XWI500H0X7E20:5f@`2QMT<0XWM40:=hA@2TNDH20:EjA`80Y7U6
1@2SN4D00`2TNDH0XgQ30:AiA0020:AiA080YGY50P2VNdH80:MlA`030:UnB@2XODP0YW]60080Y7U4
00<0YGY50:IkAP2WO4L00P2SN4<00`2TND@0YGY50:IkAP020:MlA`040:QmB02VNdP0YW]80:IkB080
Yga90`2XODX02@2[P4d0ZWm<0:QmBP2WO4T0YW]80:MlB@2XODX0ZGi;0:ElB0030:ImB@80Ygi:0P2X
Od/30:QmBP80Yga90`2VNdP20:UnB@<0ZWm:0`2[P4/30:YoBP80Zh1;0`2/PD`0102]PTd0[85<0:b1
C02/PD`30:^0B`030:YoBP2/PD`0[H9=0080[X=>00D0[H9=0:^0B`2YOTT0ZGi90:MlA`020:UoC@80
ZX1>0P2[PDl20:b2D0P0[X=@0P2]PTd20:b1C080Zh1;0P2ZOdX0102]PTl0[85>0:b1CP2/PDh30:^0
C@030:YoC02ZPD/0ZX5;00H0ZX5;0P2YOdD30:Z0AP<0Zh570P2XOdT30:V0BP<0ZX5;0P2]Q5030:b3
C`<0Zh9>0P2[Odh20:b0C`070:f1D02^PU40[h=B0:n3DP2/Pdl0[HA@0:n6DP020;27D`030:n6DP2^
QE40[HA@0080/8MA0`2bRE<01P2`Qe40[hI@0:f4CP2`PTL0/H=80;:4B@80/hE:00<0/H=80:n1AP2^
P4D00P2`PDT20:n0B080[Wm70P2]OTH20:^0B`040:YoBP2YOTT0ZGi90:QmB080Yga70P2/PTP00`2[
PDL0ZX160:UoA@030:QnA0030:ElAP2VODL0Z7m900<0ZH1:00<0Z7m90:MnB02XOdT00P2XOdT20:Mn
B0<0YWe7202WO4L30:MlB@80Z7e:102YOT/80:In@`@0Z7e80P2WO4L20:IkAP060:AiAP2UNTL0YGY7
0:IkB02WO4T0Z7e:0P2YOT/00`2WOTP0YWe70:ImA`040:ImA`<0Ygi80`2XOdT0102WOTP0YGa60:Ak
A@2UOD020:Em@P030:ImA@2VODL0Ygi:0080Yge;1@2WOTX30:QoB`<0Yga70`2XODP:0:UnB@040:Qm
BP2YOT/0ZGi;0:UnB`80ZWm<0P2[P4d0202ZPTL0ZH560:V1AP2XP4D0ZH560:^3B02]QDX0[hM<202[
PTh80:b3C@<0Zh9>0`2/Pdl20:f4D0@0Zh9<102ZPD/30:^2C0<0[8==0P2]Q4h30:Z2A`80Zh=80`2/
Q4T00`2ZPDd0Zh9>0:b3C`020:f4D0030:b3C`2[PTh0ZX5=00<0[8=?0P2]Q50<0:j5D@80/HQ@00@0
/HQB0;27D`2`Qe<0[hEC0P2_QED20;25DP<0/HIC0`2bQe@02`2`Qe<0/HQD0;:9E@2cRUH0/XUE0;68
E02_QU80[XEA0;26E02_QE<0[XAB0080[H=A00H0[XAB0:n5D`2`QU@0/HQD0;27D`2_QU820:j5D@03
0:n6DP2`Qe<0/HQD0080ZhIB0P2/Qe<20:f8E080[XUE0`2^QE420:n6DP<0/8MC0`2_QU802P2`Qe<0
/HQD0;68E02aR5@0/XUE0;>:E02bRE<0/HQB0;27D@2_QU020;27D@030;68DP2_QU80/8MC0080/8MC
0P2aR5@20;:9E@80[hIB0P2`Qe<00`2aR5@0/XUE0;>:EP030;>:EP030;:9E@2aR5@0/8MC0080[hIB
00<0[XEA0;:9E@2bRED00`2aR5@30;27D`060;>9C@2bRTl0/HU>0;29D02^RE80[8UC0P2ZRE@30;67
E@80/XQF0`2cREL30;68E080/XUE0`2cRUH80;2;E0P0]8]E00T0]XaJ0;F;F@2eReT0]HaH0;B;E@2c
RU80/XY?0;69CP2aRD`00P2dReD0102cRU@0/XUC0;:9D`2aR5820;27D@030:j5D@2`Qe<0/HQD00<0
/hYF00<0/XUE0;68E02dReL00P2dReL30;>:EP80/XUE0P2dReD20;>:E0<0/XUC00<0/HQB0;F<F02e
S5P00P2dReL0102cRUH0/XUE0;68E02aR5@80;>:EP030;68E02`Qe<0[hIB0080[XEA00<0[hIB0;27
D`2aR5@00P2_RUH30:j9E@<0[HQD202_QU880:f4D0<0[XEA0P2]Q5030:b3C`040:f4CP2/Pdd0[8==
0:b3C@<0Zh9<00@0ZX5;0:^2C02[PT`0Zh9<0`2/Pdd20:f4CP@0[HA@0P2/Pdl20:^2CP80[XAB00<0
[XEA0:f4CP2]Q4`00P2/Q4T00`2/Q4L0[8=?0:b3C`060:b3C`80ZX5=0`2[PTh30:b3C`P0[HA@2@2[
PTh00`2]Q4h0[8==0:Z1B`020:V0BP030:Z1B`2/Pdd0[HA>00P0[HA@00<0[H=C0:b2DP2[PDl00P2[
PTh0202[PT`0[8=;0:f4C02ZPDd0Zh9>0:b3C`2]Q500[XEA0P2]Q500102/Pdl0[XE=0:j5C@2^QDl2
0:f4D0030:b2D02/PU80[89B0080[85G00<0[85F0:b1E02/PU800P2/PU00102/Pdl0[XE?0:j5C`2^
QDl20:f4CP<0[8==202[P4d80:Z1C@<0ZH1:0`2ZPD/20:^2C0040:b3C`2[PTh0Zh9>0:^2CP<0ZX5=
00<0ZH1<0:^2CP2/Pdl00P2/Pdl30:f4D0030:j5D@2[PTh0Zh9>00H0Zh9>00<0Ygi:0:QoB`2ZPDd0
0`2[PTh30:Z1C@070:V0C02XOd/0Ygi:0:QoB`2YP4`0Zh9>0:b3C`020:QoB`<0ZH1<0`2ZPDd80:Yo
C080Zh9>0P2ZPDd0102YP4`0Z7m;0:MnBP2WOTX20:V0C0<0ZX5=0P2[PTh30:b3C`<0Zh9>0`2ZPDd0
0`2YP4`0ZGi90:UnB@030:YoBP<0Zh1;202/Pdl30:b3C@<0Zh9<0P2ZPD/80:^2CPP0Zh5?202ZOdX8
0:Z1C@P0ZWm<202YP4`80:^2C00>0:AoB`2WPTh0[8MC0;2;E`2bSET0/8]G0:f8E02ZQE40Z8130:R0
A@2YPDH0ZH180:V0BP2ZPDd20:Z0CPP0ZH1<0`2XODP20:UnB@<0ZWm:202YP4`00`2YOT/0Z7e:0:Ik
B0020:EjA`030:IkB02XODX0ZGi;0080ZGi90`2XODP30:MlA`T0YWe900<0YWe70:MnB02XOdT00P2Y
P4X01P2XOdT0Ygi80:ImA`2WO4L0YW]60:EjA@80XgQ300<0YGY50:IkAP2WO4L0202WO4L20:AiAP<0
YGY70`2VNdP80:EiB0030:ElB02TNdL0Y7]700@0Y7]7102UO4P30:AkA`80XgY600<0YGa80:AkA`2R
NDD00P2QN4@02@2RNDD0Y7]70:ElB02WO4T0YW]80:AiAP2SN4D0XWM40:5f@`020:9gA080YGU800<0
Y7Q70:=gAP2RMTD00P2QMD@0102PM4<0YG]90:AjB02RN4H30:1fA00=0:5gA@2RN4H0XgU70:9hAP2Q
MdD0X7I40:5gA@2RN4H0Y7Y80:EkB@2SN4<0Y7U40:EjA@020:IkAP030:EjA@2TND@0XgQ30080XgY6
0P2TNdL0102UO4P0YWe90:MnBP2WOTX30:=jAP<0XWU50P2QN4@01P2WNdX0YWY90:EiB02SMdH0XGE4
0:1d@`80WW9100<0WgE30:1fA02RN4H00`2SNDL20:9hAP030:ImB@2UO4P0Y7]70080XgY600H0Y7]7
0:ElB02VODT0XgY20:9i@@2PMd4209mf@P80X7I400P0XWQ80:=iB@2SNTH0XgY60:9iA@2QN4@0X7M3
09mf@P80WWE1202NNDD30:9hAP80XGM50`2PMT@809ab@0<0Vg4o0P2LLT0309ec@@80W7900`2KLCl6
09Y`?P80Vg4o0`2LLT000`2NM480W79009]a?`0309U_?@0309]a?`2LLT00W79000@0W7900`2KLCl0
0`2MLd40Vg4o09Y`?P0309Q^?00309U_?@2JL3h0UW4m00L0UW4m00P0UV`j09Q^?02JL3h0Vg4o09ab
@02KLCl0VW0n09U_?@80VVhm0`2IKC`309Q/>`<0UF/i0P2FK3X309M]>`80UF/i0P2FK3X209M]>`80
V6hl00H0Vg4o09Y`?P2IKcd0V6hl09I/>P2EJcT209AZ>080UF`f00<0UF`h09I/>P2FK3`00P2GK3l0
0`2GK440TV`m099/?@0209=]?P80U6ho0P2EKd00102HKS`0Ufdk09M]>`2GKC/409I/>P0309E[>@2D
JC`0U6Tl00H0U6Tl00<0Ufdk09I/>P2EJcT00P2DJSP00`2EJcT0UV`j09M]>`0809=X>`P0SVTl00D0
SFLj08iX>`2?JC`0T6Xm095[?P02091Z?@0508mY?02?I3L0T6Dh099W>P2DJC`00P2EJSd00`2DJC`0
TfPk099/?`03095[?P80T6Xm0P2?JC`00`2?I3L0T6Dh099W>P0209AY?00609=X>`2BIcX0TFHi091U
>P2AIS/0TVLl0P2CJ3d00`2BIc`0TFHk091U>P0308mY>R_ooooo000Zooooo`80Q5dd00@0QEhe08IO
=P26GcH0Qf0g0P28HCP308QL=@<0REdf0P2:GSL308EN=@<0QUlf0P27H3L808YN=`0308YO=02;H3D0
Rf0e0080Rf0e0`2<HCH308]P=P80S64g0`2;H3H808iS>0P0SV<f0P2>HcP00`2?I3T0T6Dj091U>P03
091U>PT0SV<h202@HcT00`2>HCL0Sf8h095T>P0309=V?003099U>`2AI3X0TVHi0080TFDh00<0TVHi
09=W>P2DJ3/00P2CIcX02@2?I3L0SV<f08iS=P2?I3L0TFHi09=X>`2FJch0V6e009EY?00409AX>`<0
TfLj202DIcd0102BIST0TfLj09EY?02GJch209Q/?`80Uf/n00H0VFe009Q/?`2HK3l0Uf/n09IZ?@2E
JC`209AX>`0309U^@@2GK3l0UV/n0080UFXm00<0UV/n09M/?`2IKT40202HK3/209EZ?@80UV/n0P2G
K3l209Q]@0H0VFhk0P2HKCX209Q/>`@0VFdl0P2HK3/809Q]@080VFhk00@0VVll09]`?@2KL3d0W74n
2P2MLSl809Y_?0P0WW=00P2KLCl709ab@0080:1fA02MLd40Vg4o09ab@02PMT@0XWQ60:1fA02LLT02
09ic?PH0Wg@o202PMD030:9b@@80Xg=20P2TM4<00`2UMD@0XgM60:=gAP060:=gAP060:1e@P2QMT<0
XGI30:9gA02SN4D0Y7U60P2UNTL20:=hA@060:9gA02QMT<0XWM40:=hA@2TNDH0YGY70`2TND@20:Ej
A@<0YW]6202WO4L0202YOTT0Yga70:EjA@2TND@0XgQ30:AiA02UNTD0YW]60`2TND@00`2UNTD0YW]6
0:IkAP020:MlA`80YW]80P2WO4T20:QmBP80ZGi;00<0Zh1=0:YoC02XODX00P2VNdP00`2WO4T0Z7e:
0:UnB`030:ElB080YWe90`2WOTX80:IkB080Z7e800<0ZGi90:YoBP2[P4/00P2/PD`00`2]PTd0ZGi9
0:UnB@020:YoBP80Zh1;1P2/PD`50:^0B`050:b1C02]PTd0[X=>0:f2C@2[P4/00P2YOTT00`2XODP0
ZH1<0:V0C0020:Z1C@80Zh9>0P2/Pdl80:n4C`80[H9=0P2/PD`20:^0B`80ZWm:102/PDh40:^0C@P0
ZX5;0P2YOTL30:YoB0<0Zh190P2XOd/30:V0C0<0ZX5=0P2]Q5030:b3C`<0Zh9>00H0ZGi;0:YoC02[
P4d0[85>0:f2C`2_Q5420;25DP030:b3C`2]Q500[hIB0080/8MC00H0[hIB0:j5D@2]Q500/8MA0;68
DP2bRE<20;>:E0060;:9D`2`Qe40[hI@0;21B@2aPTX0/X=;0P2cQ4`00`2aPTX0[h180:ioA`020:n2
B@80[X580P2]P4L20:aoAP030:^0B`2ZOdX0ZWm:0080ZGi90P2XODP01`2WO4L0[H=90:b2B02[PDL0
ZX160:UoA@2WOD<00P2VO4800`2UO4H0YWe70:QoB@020:V0BP030:QoB@2WOTP0YWe700<0Ygi80P2V
ODL30:ElAPP0Z7e:00@0Yga90:QmBP2XODX0Z7e:0P2YOT/30:YoC0P0YGa4102XODP40:MlA`80Y7U6
0P2UNTL01`2VNdP0Yga90:MlB@2WO4T0Ygi:0:ImB@2UO4P00P2TNdL00`2UO4P0YWe90:MnBP040:Mn
B0040:ImA`2UO4H0YGa60:AkA@80YGe200@0YGa40:ImA`2VODT0YWa:0P2WODd20:ImB@@0Ygi:0P2X
Od/30:MlA`<0Z7e82P2YOTT20:QmBP<0ZGi;0`2ZOd`20:^2BP060:Z1B@2YP4P0ZX590:^2BP2]Q4`0
[hI>202[PTh80:b3C@<0Zh9>0`2/Pdl20:f4D0050:f4CP2/Pdd0[8==0:^2C02ZPD/00P2YP4X0102X
OdT0Zh9<0:^2C02[PT`30:b3C@80[HA>0P2ZPDT20:^2BP80[8=;0P2]Q4`00`2[PTh0[8=?0:b3C`04
0:b3C`040:^2CP2/Pdl0[8=?0:b3C`80[HA@302^QE420;68D0040;27D@2`Qe<0/8MC0:n5D`80[hEE
1@2bQe830;>8D`090:n6DP2`Qe<0/XUE0;>:EP2bRED0/HQD0;27D`2_QU80[hEC00H0[XAB00<0[hEC
0;27D`2`Qe<0102_QU820;27D`80ZhIB0P2/Qe<20:f8E080[XUE102^QE450:n6DP80/8MC00<0/HQD
0;:9E@2bRED00P2cRUH20;:9E@80/HQD102`Qe<30:j5D@80[hIB0`2`Qe<01P2]Q500[XEA0:n6DP2`
Qe<0/HQD0;>:EP80]8]G0`2bRED00`2aR5@0/8MC0;27D`020:n6DP80/XUC0`2aR5830;27D@060;:8
C02aRDh0/HU>0;29D02^RE80[HYD0P2ZRE@30;68E080/XUE0`2cRUH30;68E080/XUE0`2cRUH80;2;
EPP0]8]E0`2eReT00`2dReL0]8]E0;>:DP020;::C`070;::C@2eS5H0]HaF0;B;E@2cRU@0/HQB0;27
D@020:n6D0090:n6DP2`Qe<0/XUE0;>:EP2dReL0/hYF0;:9E@2aR5@0]XeI0080]HaH00<0]8]G0;>:
EP2bRED00P2aR5@30;B;E@80/hYD0`2bRE<01P2gSUX0]XeI0;F<F02dReL0/hYF0;68E080/8MC202c
RUH00`2bRED0/HQD0;68E0050;27D`80[hYF0`2^RED30:f8E0P0/8MC402]Q5080:^2C0060:V0BP2Z
PD/0ZX5;0:^2C02/Pdd0[HA>0P2^QDl60:f4D080[8=?0P2^Q5800`2^QE40[HA>0:f4C0020:b4B@03
0:b4A`2/Pdl0[8=?00H0[8=?00D0ZH1<0:Z1C@2ZPDd0Zh9>0:b3C`020:f4D0030:j5D@2]Q500[HA@
00H0[HA@2@2/Pdl00`2/Pdd0Zh9<0:V0BP020:QoB@030:V0BP2[PT`0[8==00P0[HA@00<0[XAD0:f3
D`2]Pe400P2]Q5000`2]Q4h0[HA<0:j5C@020:b3C`H0[HA@0P2^QDd0102^QDl0[HA@0:f4D02/PU02
0:b2DP80[85F00<0[85D0:b2DP2/PU000P2/Pdl00`2/Pdd0[HA>0:f4CP060:f4CPP0Zh1=202YP4`6
0:Z1B`80Zh9<102[PTh40:Z1C@P0[8=?202[PTh00`2YP4`0ZX5=0:Z1C@030:^2CP<0ZX5=00L0ZH1<
0:QoB`2WOTX0Z7m;0:V0C02[PTh0[8=?0080Z7m;0`2YP4`30:Z1C@<0Zh1=102ZOd`01`2YOT/0[HA@
0:b3C`2[PTh0ZX5=0:V0C02WOTX00P2VODT20:V0C0<0ZX5=0P2[PTh20:b3C`@0Zh9>102ZPDd20:Un
B@<0ZWm:0`2[P4/80:^2CPH0Zh9<0P2ZPD/80:^2CPP0Zh5?202ZOdX80:Z1C@P0ZWm<202YP4`80:^2
C0040:J1C@2WPTh0ZHA@0:Z5D@80ZhIB0P2ZQE401P2XP4<0Z8150:V1AP2YP4P0ZH1:0:Z1C@80ZX1>
202YP4`30:QmB080ZGi90`2ZOdX80:V0C0030:QmB02WO4L0YGY50080Y7U400<0YGY50:MlA`2XODP0
0P2YOTT30:QmB0<0Yga72P2WOTX02P2XOd/0ZH1<0:Z1C@2ZPDd0ZH1<0:QoB`2WOTX0Yga70:IkAP2U
NTD20:=h@`030:EjA@2VNdH0Yga700P0Yga91P2UNTL20:IkB0P0YGU800<0XgY60:AkA`2UO4P00`2U
O4P00`2TNdL0XgY60:ElB0020:ElB0<0Y7]70P2SNTH00`2TNdL0XgY60:9iA@020:5hA0030:=jAP2T
NdL0YWe90080Z7e:00@0Yga90:EjA`2TNDH0Y7U60P2SN4D30:AiAP030:=hA@2RMd@0XWM40080XGI3
00<0YG]90:AjB02RN4H00`2PMT@01@2QMdD0XWQ60:=iA`2RN4H0XGM50080X7I400<0XWQ60:AjB02U
NdT00`2TND@20:EjA@<0Y7U40P2RNDD0102SNTH0Y7]70:ElB02VODT20:MnBP<0XWU50`2QN4@20:1g
@`090:QmBP2WO4T0YGY70:AiAP2QMT<0X7E209ic@02MLSl0X7I40080XGM50P2RN4H30:=iA`030:El
B02TNdL0Y7]700@0Y7]700@0YGa80:=j@P2RND40XGQ20P2PMd<20:5gA@080:9hB02SNDT0XgY60:=j
AP2RNDD0XGQ40:1g@`2OMT8209ie@@P0WgY60P2RN4H30:5gA@<0X7I400@0Vg4o09ab@02LLT00W790
0`2MLd400`2NM480W79009ab@00209ab@0@0WG=10P2LLT0609]a?`80VW0n0`2KLCl309ab@00809ec
@@2LLT00Vg4o09Y`?P2IKcd0VW0n09ab@02MLd4209]a?`0409ab@02MLd40WG=109id@P80WgE300<0
WG=109ab@02JL3h00P2HKS`00`2IKcd0VW0n09]a?`0809Q`?@0809E[>@2GKC/0VFlm09Y`?P2KLCl0
VW0n09U_?@2HKS`209Y^?@<0VFdl0`2HK3/409E[>@@0UV`j0P2EJcT209I/>P80Ufdk0P2HKS`01P2J
L3h0VFlm09Q^?02GKC/0UV`j09E[>@80U6Xh0P2EK3H00`2EK3P0UF/i09I/?00209I[?P0309I[@02B
K3d0TV`m0080Tfdn0P2DKSl209E_@0@0Ufdk1@2FK3X209I[?P<0UFXm0`2DJC`00`2IKcd0V6hl09I/
>P0209E[>@0309I/>P2HKS`0VFlm00P0TfPk202?JC`00`2=IcX0SVPk08iX>`0208mY?0<0T6Xm00H0
Sf@i095V>`2CJ3d0U6Tn09EZ?`2DJCh209=X?@80TV`o0`2AJch3091Z?@03091U>02AIST0TfPk0080
U6Tl00H0TfPk099W>P2AIST0SV<h08mT>@2AIS/2099W?003095V>`2?I3T0SV<h00<0T6Xm:oooool0
02[ooooo00D0Pe`c08AM=024GC@0QEhe08IO=P0208MP=`0408QQ>028G3D0R5`e08QL=@<0REdf0P2:
GSL308EN=@<0QUlf0P27H3L808YN=`<0RUld00<0Rf0e08aQ=P2<HCH00P2=HSL00`2<H3T0Relh08]O
>00408]O>00308aP>@2>HcP0SV<h00H0SV<h202>HcH408iS>080Sf@i00<0T6Dj095V>`2>HcP0202>
HcP8091S>@0308iQ=`2?HSP0TF@j00<0TfHl00@0TVDk095T>P2AICP0TVHi102CIcX00`2DJ3/0UFTl
08mT=`0208iS=P0508mT=`2AIST0TfPk09I[?P2HKD000`2EJC`00`2DJ3/0TfLj09=W>P02099V>@P0
U6Lm00@0TVHi09AX>`2FJSd0V6`o0P2IKD000`2HK3l0Uf/n09U]@00209Q/?`0309M[?P2FJSd0UFTl
0080U6Pk00<0V6e009M/?`2FJch00P2DJC`00`2FJch0Uf`o09Q]@00809Q/>`@0UV`l102GKCd209Q]
>PH0VFhk202IKC`809Q]@00509U^>`2JKc`0VVll09]`?@2LLCh00P2MLSl00`2NLd00WG8o09eb?`06
09eb?`P0VVll202NLd0209ab@0L0Vg4o00P0X7I409ec@@2KLCl0WG=10:5gA@2SNDL0XGM509id@P80
X7E01P2OM3l80:5f@@80XW910P2SLd840:Ad@`P0XgM600H0X7E20:5f@`2QMT<0XWM40:=hA@2TNDH2
0:EjA`030:AiAP2SN4D0XGI30080X7E200<0XWM40:AiAP2VNdP00P2TND@20:EjA@80YW]62P2WO4L0
0`2XODP0Yga70:EjA@020:=h@`040:AiA02UNTD0YW]60:AiA0@0YGY50`2VNdH30:MlB@80Z7e:0`2Y
OT/0202[P4d0ZGi;0:MlB@2VNdP0YGY70:IkB02WO4T0Z7e:0P2UO4P20:ImB@<0Ygi:00<0Z7m;0:Ik
B02VNdP01P2VNdP20:QmB0030:UnB@2ZOdX0Zh1;0080[85<00@0[H9=0:UnB@2YOTT0ZGi90P2ZOdX7
0:^0B`@0[85<0P2[P4/30:f2C@040:b1C02ZOdX0ZWm:0:UnB@80ZH1<0P2ZPDd20:^2CP80[8=?202_
Q4d20:f2C@80[85<0P2[P4/20:YoBP@0Zh1=102/PDh80:^2C080ZGi90`2ZOdX30:^0B`80Z7m;0`2Y
P4`30:Z1C@80[HA@0`2/Pdl30:^2CP060:UnB`2ZOd`0Zh1=0:b1CP2]PTl0[hAA0P2`QE800`2[PTh0
[8=?0:j5D@030;27D`050:n6DP2^QE40[hI@0;27D@2bRE<00P2cRU@01P2bRE<0/HQB0;27D@2`PD/0
/H9<0;:3C@80/hA>00<0/H9<0:n0BP2^OdT00P2]PdT20:b2B080Zh570P2ZP4H20:YoBP@0ZGi90P2X
ODP20:b2B0090:^1A`2YOdD0Z7i40:Mm@`2VO480YG]10:ElAP2VODL0Ygi80080Z7m900<0Ygi80:El
AP2TNdD00`2VODL20:ElAP<0Y7]52`2WO4T20:QmBP@0ZGi;202TNdD40:IkAP@0Yga70`2TNDH40:Ej
A`040:IkB02WOTX0YWe90:AkA`80XgY600@0Y7]70:ImB@2WOTX0Ygi80P2VODL00`2UO4H0Y7]50:Ak
A@020:AkA@80Y7]300@0YGa60:ElB02UNdT0YWa<0P2VNdh20:ElB080YWe90P2WOTX20:QoB`<0Yga7
0`2XODP:0:UnB@<0Z7e:0`2YOT/20:YoC0030:b3C@2[PT`0ZX5;0080ZH1:00<0Zh9<0:b3C@2]Q4h0
202ZPDd80:b3C@<0Zh9>0`2/Pdl20:f4D0050:f4CP2/Pdd0[8==0:^2C02ZPD/00P2YP4X0102XOdT0
Zh9<0:^2C02[PT`30:b3C@80[HA>0`2[PT`20:b3C@<0[HA>0`2/Pdl20:^2CPH0[8=?0P2]Q50<0:j5
D@80/8M?00@0/8MA0:n6DP2_QU80[hEC0P2^Q5@30;>8D@D0/XM@00P0[hIB0;27D`2aR5@0/XUE0;>:
EP2bRED0/8MC0:n6DP<0[XAB0P2_QE<30:j4DP80[hIB102`Qe<20:n6DP80ZhIB0P2/Qe<20:f8E080
[XUE2@2^QE401@2_QU80/8MC0;68E02bRED0/hYF0080]8]G0`2bRED20;68E080/8MC00<0[hIB0:j5
D@2^QE400P2^QE420:n6DP80/8MC00H0[HA@0:j5D@2_QU80/8MC0;68E02cRUH20;B;E`030;:9E@2a
R5@0/HQD0080/HQD0`2`Qe<20;:9D@<0/HQ@0`2`Qdl01P2aQd/0/8Q=0;69CP2`RE00[XUB0:f:E080
ZhYE0`2aR5@20;:9E@<0/hYF0`2aR5@20;:9E@<0/hYF202aS5L80;>:E0<0]8YH00<0]8]G0;>:E02c
RU800P2cRe001`2bRTd0]HaF0;F<EP2dReD0/hYD0;68DP2`Qe400P2_QU000`2_QU80/8MC0;:9E@03
0;B;E`030;>:EP2bRED0]XeI0080]HaH00<0]8]G0;>:EP2bRED00P2aR5@20;F<EP80]8]E0P2cRU@2
0;:9D`060;N>FP2fSET0]HaH0;B;E`2cRUH0/HQD0P2`Qe<80;>:EP@0/XUE00@0/HQD0;27D`2`Qe<0
[hIB0P2_RUH30:j9E@<0[HQD202`Qe<@0:f4D0@0Zh9<102/Pdd01P2YP4X0ZX5;0:Z1B`2[PT`0[8==
0:f4CP80[XE?1P2]Q5020:j5D@80[XAB00<0[XEA0:f4CP2]Q4`00P2/Q4T00`2/Q4L0[8=?0:b3C`06
0:b3C`80ZX5=00@0Zh9>0:b3C`2/Pdl0[HA@0P2^QE480:f4D0T0[8=?00<0[8==0:^2C02YP4X00P2X
OdT00`2YP4X0Zh9<0:b3C@080:f4D0030:f3D`2^Q5@0[XAB0080[XEA00<0[XE?0:j5C@2]Q4`00P2^
QE460:f4D080[XE=00@0[XE?0:f4D02]Q500[89@0P2/PU820:b1E0060:b2DP2/PU00[8=?0:b3C`2/
Pdd0[8=;202]Q4h80:b1CPP0ZH1<1P2[PT`20:Z1B`@0ZX5=102[PTh40:b3C``0Zh9>00<0[8=?0:^2
CP2[PTh00`2ZPDd20:^2CP080:Z1C@2YP4`0Z7m;0:MnBP2XOd/0ZH1<0:^2CP2/Pdl20:QoB`<0ZH1<
0`2ZPDd20:b1CP80Zh1=00X0ZWm<0:UnB`2YOT/0ZGi;0:f4D02/Pdl0Zh9>0:Z1C@2YP4`0Ygi:0P2V
ODT20:V0C0<0ZX5=0P2[PTh20:b3C`@0ZX5=102[PTh20:UnB@<0ZWm:0`2[P4/80:Z1C@H0ZX5;0P2[
PT`80:^2CPP0ZX1>202ZOdX80:^2CPP0ZWm<202YP4`80:^2C0H0Yh9>0P2XPdl01P2XP4<0Z8150:V1
AP2YP4P0ZH1:0:Z1C@80ZX1>202YP4`30:QmB080ZGi90`2ZOdX80:V0C0030:QmAP2WO4D0YGY30080
Y7U200<0YGY30:MlA@2XODH00P2YOTT30:QmB0<0Yga72P2WOTX02P2XOd/0ZH1<0:Z1C@2ZPDd0ZH1<
0:QoB`2WOTX0Yga70:IkAP2UNTD20:=h@`030:EjA@2VNdH0Yga700X0YW]81P2UNTL80:IjB@030:=j
AP2TNdL0YGa800<0YGa800<0Y7]70:=jAP2UO4P00P2UO4P30:AkA`<0XgY600L0XWU50:5hA02QN4@0
XWU50:=jAP2UO4P0YWe900<0Z7e:00H0Yga90:IkB02UNTL0Y7U60:=hA@2TNDH40:=hA@<0XWM400<0
YG]90:AjB02RN4H00`2PMT@02P2QMdD0XWQ60:9hAP2QMdD0X7I409me@`2PMT@0XGM50:=iA`2UNdT3
0:AiA080XgQ30`2TND@20:9iA@040:=jAP2TNdL0Y7]70:ElB080YWe90`2RNDD30:5hA080X7M30P2W
O4T0102UNTL0Y7U60:9gA02QMT<209md@@@0XGM50P2RN4H20:=iA`<0Y7]70P2UO4P30:AkA`030:Ak
@`2SNT80XGQ20080X7M30P2QMdD0202SNDT0Y7Y:0:=jAP2SNTH0XWU50:5hA02PMd<0WgI20P2NMD48
09mjAP<0XGM50`2PMT@209me@`<0W7900P2MLd4309id@PP0WG=10P2KLCl609ab@0<0Vg4o0`2LLT03
09ec@@0709ab@02KLCl0VW0n09Y`?P2KLCl0WG=109id@P0209]a?`0409ab@02MLd40WWA209me@`80
X7I400P0WWA209ab@02JL3h0VFlm09Q^?02IKcd0VW0n09]a?`P0VFlm00P0UF/i09M]>`2IKcd0VW0n
09]a?`2JL3h0VFlm09Q^?080VVhm0`2IKC`309Q/>`X0UF/i0P2FK3X209M]>`@0V6hl0P2GKC/0102F
K3X0UF/i09E[>@2DJSP209E/=P0309E/>02EJcT0UF/k0080UFXm00<0UFXo099/?@2BK3d00P2CKCh2
09A^?`80UFm0102FK3X509M]>`80Uf`o0`2FJch309EZ?@0309U_?@2HKS`0Ufdk0080UF/i00<0Ufdk
09Q^?02IKcd0202CJ3/8095X?0<0SFLj0P2>J3/208mY?009091Z?@2@IC/0TFHl09=X?P2DJCl0UFY0
09AY?`2CJ3h0TVLm00<0TV`o0`2AJch2091Z?@03099W>P2CJ3/0U6Tl0080UFXm00H0U6Tl099W>P2A
IST0SV<h08mT>@2@ICX2095V>`03091U>P2?I3T0SV<h00<0T6Tn:oooool002[ooooo0P24GC@308EN
=@<0QUlf0`28G3D308UM=P80RUhg0`25GSD308IO=P80Qf0g0P2;GcP408UM=P80Relh0P29GS<00`2:
Gc@0Rf0e08aQ=P0208eR=`0408iS>02=HC`0S60k08]O>P80RUhi00<0Relj08aP>`2=HC`0202>HcP8
08iS=P80SF8g00H0S64f08eR=`2>HcP0Sf@i095V>`2BIc`908iS>0P0T6<i00<0SV4g08mR>02AI3X0
0`2CIS`01P2BIC/0TF@j091T=`2CIcX0UFTl09AX>`80TVHi00<0U6Pk09IZ?@2@ICP00`2?I3L0102@
ICP0TfPk09EZ?@2GK3l209IZ?@0309EY?02DJ3/0TfLj0080TVHi00<0TFDh09AW?@2DIcd01P2DIcd0
102CIcX0U6Pk09IZ?@2HK3l209U]@080V6`o0`2GJch309IZ?@80UFTl00<0V6e009M/?`2EJSd00P2D
JC`00`2EJSd0Uf`o09Q]@00809Q/>`@0UV`j102GKC/309Q]>P<0VFhk0P2JKc`00`2KKch0VVhm09U]
?00209Q/>`0309U]?02JKSd0Vfln00P0V6e00`2KL3d309aa?P80WG8o202LLCh309]`?@80VVll0`2I
KS/809ic@080W7900`2KLCl409Y`?P0809me@`2LLT00VW0n09ab@02PMT@0XgU70:5gA@2NM4820:5f
@@80X7E0102OM3l80:5f@@050:5a@02RLT40Xg=20:Ad@`2UMD@00P2TM4<00`2SLd80XgM60:=gAP06
0:=gAP060:1e@P2QMT<0XGI30:9gA02SN4D0Y7U60`2UNTL01`2TNDH0XGI309md@@2OM440XGI30:=h
A@2UNTL00`2UNTD20:IkAP/0Yga700<0Z7e80:IkAP2UNTD00`2SN4<00`2TND@0YGY50:EjA@070:Ej
A@80Yga90P2XODX30:UnB`80ZWm<00L0ZGi;0:MlB@2VNdP0YGY70:IkB02WO4T0Z7e:00<0Ygi:0P2X
Od/30:V0C0<0YW]80P2WO4T30:QmBP80ZGi90`2ZOdX30:^0B`040:QmB02YOTT0ZGi90:UnB@80ZWm:
0P2[P4/0102ZOdX0Zh1;0:^0B`2[P4/30:b1C0040:f2C@2ZOdX0Zh1;0:b1C080[H9=00@0[85<0:^0
B`2[P4/0ZWm:0P2YP4X20:Z1B`80Zh9<0P2/Pdd80:j4BP80[H9=0P2/PD`20:^0B`80ZWm:00@0ZWm<
0:^0C@2[P4d0Zh1=0`2/PDh00`2]PTl0Zh9<0:^2C0060:^2C080ZGi;0`2ZOd`30:^0C@80Z7i<0`2Y
Odd30:Z0CP80[HA@0`2/Pdl30:^2CP80Zh1;0P2/PD`02P2]PTd0[X=>0:n4C`2_Q4l0ZX5=0:b3C`2^
QE40/8MC0;68E02`Qe<20:n6DP030:f4CP2_QU00/8MA00<0/XUC0P2`Qe400`2`PDd0/H9>0;:3C`02
0;>4D0030;62CP2_P4`0[Wm;0080[8A90P2[PdP20:Z2A`80ZH56202YOTT30:Z0AP030:UoA@2XOT@0
Yge30080YWa200<0YGa60:ImA`2WOTP00P2XOdT00`2VODL0Y7]50:=jA0030:ElAP80Y7]50`2SNT@8
0:EiB0040:EjA`2VNdP0YW]80:IkB080Yga90`2XODX80:=jAP@0Y7U40P2UNTD20:IkAPP0Y7U600<0
Z7i<0:IlBP2TNTP00P2RN4H01P2TNTP0YWa:0:QnC02WOTP0YWe70:AkA@<0XgY4102TNdD00`2TNdL0
YG]90:EkB`020:IkCP050:IkD02TNdL0Y7]70:ElB02VODT00P2WOTX20:QoB`<0Yga70`2XODP:0:Un
B@80Yga90P2XODX30:UnB`090:YoC02[PTh0ZX5=0:QoB`2WOTX0Z7m;0:V0C02ZPDd0Zh9>00P0ZX5=
202/Pdd30:^2CP<0[8=?0P2]Q5040:^2C0@0ZX5;0`2[PT`30:b3C@80[HA>0P2[PTh20:b3C`<0[HA@
00@0[XEA0:f4D02/Pdl0Zh9>0P2ZPDd00`2[PTh0[8=?0:f4D0030:b3C`80[HA@302^QE420;27C`04
0;27D@2_QU80[hIB0:j4DP80[XAD0`2bR4h30;67C@80/8I<00/0[XEA0:n6DP2aR5@0/XUE0;>:EP2b
RED0/HQD0;27D`2]Pe40[XAB0:n5D`020;26E0060:n5D`2^Q580[H=A0:j5D@2_QU80/8MC0P2aR5@0
0`2`Qe<0[hIB0:j5D@020:^6DP80[8MC0P2]R5@20:j9E@040:n6DP2^QE40[XEA0:j5D@<0[HA@00T0
[8=?0:f4D02]Q500[XEA0;27D`2aR5@0/XUE0;>:EP2dReL00P2aQeD30;:8EP030;67E@2_QE<0[XAB
0080[XEA0P2_QU830;27D`030;68E02_QU80[hIB0080/8MC00@0/HQD0;:9E@2cRUH0/hYF202aR5@2
0;::C`<0/HU>0`2`R4d01P2aQd/0/8Q=0;28C@2`RE00[XUB0:f:E080[8]F0`2aR5820;:9D`<0/hYD
0`2aR5@20;:9E@<0/hYF202aS5P80;>:E0<0/hUG00<0/hYF0;>:E02cRU800P2cRe00102cRdh0]8]E
0;B;E@2cRU@20;:9D`0;0;68DP2`Qe40/8MA0;27D`2aR5@0/hYF0;B;E`2eS5P0]8]G0;>:EP2bRED0
0`2dReL30;>:EP80/XUE0`2eS5H20;B;E@<0/hYD0P2eS5P20;B;E`040;>:EP2bRED0/HQD0;68E0T0
/hYF0`2dReL0102cRUH0/HQD0;27D`2_QU820:n:EP<0[XUE0`2]R5@80:n6DPP0[HA@0`2/Pdl20:f4
D0<0[XEA0`2/Pdd20:f4CP<0[XE?0`2[PT`30:b3C@80[HA>102]Q5020:j5D@80[hIB0P2^Q5800`2^
QE40[HA>0:f4C0020:b4B@030:b4A`2[PTh0Zh9>00L0Zh9>0`2/Pdl<0:f4D0T0[8=?00<0[HA>0:b3
C@2ZPD/00P2YP4X00`2ZPD/0[8==0:f4CP080:f4D0030:b2DP2]Pe<0[XAB0080[XEA00P0[XE?0:f4
C02/Pd/0/8MC0:n6DP2^QE40[HA@0:b3C`80[HA@00@0[XEA0:j5C@2^QDd0[XE?0P2]Q5000`2/PU00
[89B0:b2DP020:b2DP040:b2D02/Pdl0[8=?0:b3C@80[8=;0`2/Pdd20:f4CP<0[XE?202/PDh80:Z1
C@<0[8==0`2[PT`20:Z1B`040:V0C02ZPDd0ZX5=0:Z1C@<0Zh9>102/Pdl20:^2CP<0ZX5=202[PTh0
0`2^QE40[HA@0:^2CP030:Z1C@80Zh9>00P0[8=?0:^2CP2YP4`0Z7m;0:MnBP2XOd/0ZH1<0:Z1C@80
Z7m;0`2YP4`30:Z1C@060:f2C`2/PDh0[85>0:^0C@2ZOd`0ZGi;0P2XODX20:^2CP80ZX5=00@0ZH1<
0:QoB`2WOTX0Ygi:0P2YP4`30:Z1C@80Zh9>0P2/Pdl0102YP4`0ZX5=0:Z1C@2ZPDd30:^2CP030:b3
C`2YOTT0ZGi900<0ZWm:0`2[P4/80:V0C0<0ZH1:0`2ZPD/20:^2C0P0Zh9>202ZP4h80:YoBPP0Zh9>
202ZOd`80:V0C0P0Zh9<00<0Z8=?0:N2CP2WPTh01@2VPDd01P2XP4<0Z8150:V1AP2YP4P0ZH1:0:Z1
C@80ZX1>202YP4`30:QmB080ZGi90`2ZOdX80:V0C0030:UoA@2XOT@0YWa20080YG]100<0YWa20:Qn
A02YOdD00P2YOTT30:QmB0<0Yga72@2WOTX00`2VO4X0Yge;0:QnC0020:UoC@060:QnC02WOD/0YWa:
0:MlA`2VNdH0YGY50P2SN4<00`2UNTD0YW]60:MlA`080:IjB@<0YW]80`2UNTL20:AiAPP0YWY900<0
YGa80:AkA`2TNdL0102TNdL40:ElB0<0Y7]70P2SNTH20:9iA@80XGQ400D0XWU50:AkA`2VODT0Ygi:
0:MlB@030:QmBP040:MlB@2UNTL0Y7U60:9gA0P0XgQ300<0YG]90:AjB02RN4H00`2PMT@03@2QMdD0
XWQ60:9hAP2QMdD0X7I409me@`2PMT@0XGM50:=iA`2TNTP0YGY50:AiA02SN4<00P2RMd80102SN4<0
Y7U40:EjA@2QN4@20:9iA@030:=jAP2TNdL0YGa80080YWe90`2SNTH30:9iA@80XGQ400H0YW]60:Ej
A@2UNTD0Y7U40:=h@`2RMd820:5f@@0;0:9hAP2QMdD0XGM50:1fA02QMdD0XWQ60:=iA`2TNTP0XgY6
0:AkA`2UO4P00P2VODT01P2UO4P0Y7]70:=jAP2TNd<0XgY20:9i@`80XGQ40P2RN4H0202SNDT0Y7Y:
0:=jAP2SNTH0XWU50:5hA02PMd<0WgI20P2NMD4809mjAP<0XGM50P2PMT@309me@`<0WWA21@2MLd40
102OMD<0WWA209id@P2NM48309ec@@0309ab@02KLCl0Vg4o00<0W7900`2MLd4309]a?`80W790102M
Ld401`2LLT00Vg4o09Y`?P2KLCl0W79009id@P2OMD<00P2KLCl0102LLT00WG=109ec@@2NM48209me
@`0309id@P2MLd40Vg4o0080VFlm00<0VW0n09]a?`2LLT00202JKSd0202FK3X0V6hl09Y`?P2KLCl0
W79009]a?`2JL3h0VFlm0P2JKSd309U]?0<0V6`k00@0UV`j09E[>@2EJcT0UF/i0`2DJSP00`2CJCL0
UF/i09E[>@0209I/>P80Ufdk0P2HKS`309M]>`80UV`j0P2EJcT01P2DJSP0UVdg09E/=P2EK3P0UF/i
09AZ>P80U6Tl00<0TfPm099/?@2BK3d00P2CKCh209A^?`80UFm000@0UF/i09I/>P2FK3X0UV`j102G
KC/0102HKS`0UV/n09I[?P2FJch509M/?`0309Q^?02GKC/0UV`j0080UF/i00<0UV`j09M]>`2HKS`0
202CJ3/8099W?00;08iX>`2=IcX0SFLj08aV>@2=IcX0SVPk08mY?02@JSd0TFDn099V?`2CId000P2E
JD800`2DJ440TVHo095U?P0209=]@080TV`o0`2AJch00`2@JSd0TfPk09AY?00309EZ?@0609AY?02B
IcX0TFHi08iS>02?I3T0TFHk0P2BIc`00`2AIS/0Sf@i08iS>003091Y@2_ooooo000Zooooo`80QUlf
0`25GSD308AM=0<0R5`e0`29GCH208YN=`<0QEhe0`26GcH208MP=`0308aP>@2;GcP0REdf0080R5`e
00T0REdf08]O>02<H3T0R5db08UN<`2:Gc@0Rf0e08aQ=P2=HSL00P2>HcP00`2=HCh0S60m08YN>`02
08UM>P0308YN>`2<H3d0SF4n00P0SV<h202>HcH0202=HSL0S64f08aQ=P2;H3D0SF8g08mT>@2AIS/0
TfPm2@2>HcP8091S>@0308iQ=`2?HSP0TF@j00<0TfHl01P0TVDk095T>P2?HcH0TfLj09IZ?@2EJC`0
TVHi095U>02DJ3/0V6`o099W>P2AIST0T6Dh08mT=`2@ICP0TVLj09=X>`2EJSd0Uf/n09IZ?@2EJC`0
U6Pk09=W>P2BIST2095U>0P0U6Lm00D0TfLj09AX>`2GJch0VFe009Y^@@0209U]@00309Q/?`2EJC`0
UFTl00<0UVXm0`2GJch00`2GK3l0UV/n09EZ?@0209AY?00309EZ?@2FJch0Uf`o00P0V6`k102GKC/4
09I/>P80Uf`i0P2HKCX01`2IKS/0VVll09Y_?02JKc`0W70o09]_?P2IKC`00P2HK3/00`2IKC`0Vfln
09a`?`0809Q]@0<0WG8o0`2LLCh:09]`?@0309aa?P2KL3d0Vg0m0080VVll0P2IKS/00`2HKCX0WgA1
09md@@0609md@@80W7900P2KLCl309Y`?P80VFlm00T0WG=109Y`?P2HKS`0Vg4o09me@`2RN4H0X7I4
09ec@@2RMd800P2QMT420:1e@080Wg@o00<0WW<n0:5f@@2QMT401P2QMT400`2PL3l0XG500:=c@P03
0:EeA080Xg=2202TN4L01P2PMD80XGI30:5f@`2RMd@0XgQ50:AiAP80YGY700<0Z7e:0:EjA`2QMT<0
0P2NLd000`2OM440XGI30:=hA@020:EjA@80YW]63@2WO4L01`2VNdH0Y7U40:=h@`2RMd80XgQ30:Ai
A02UNTD00P2VNdH60:EjA@<0Z7e:0`2YOT/30:YoC0030:QmBP2WO4T0YGY70080YGY700<0YW]80:Ml
B@2YP4`00P2YP4`30:Z1C@80Zh9>0P2WO4T20:QmBP80ZGi;0P2ZOd`30:^0B`<0ZWm:0P2YOTT20:Qm
B0<0ZGi91@2ZOdX20:^0B`80[85<0P2]PTd00`2YOTT0ZWm:0:b1C0020:f2C@040:b1C02[P4/0Zh1;
0:YoBP80ZH180P2ZPDT20:^2BP80[8=;202/PTP20:f2C@80[85<0P2[P4/20:YoBP80ZWm<0P2[P4d2
0:b1CP80[H9?202/Pdd20:UmC0<0ZWi=0`2[Odh20:QnCP<0ZGm?0`2ZP5020:f4D0<0[8=?0`2[PTh0
0`2/PDX0[H9;0:f2B`050:f2B`040:Z1C@2[PTh0[HA@0:n6DP80/HQD00P0/8MC0:n6DP2[PT`0[HA>
0:n6D02`Qe40/HQB0;27D@80[hI@00<0/85=0;62CP2bPdl00P2cQ5000`2aPTh0[h1<0:ioB`020:^4
B@80ZX=80P2YPTL20:R1APP0ZGi9202XOT@20:ImA`070:MnB02XOdT0Ygi80:ImA`2TNdD0XWU30:El
AP030:AkA@80XgY40P2RND<80:9fA`@0Y7U60P2UNTL30:IkB0P0XWQ60P2QMT420:9g@P80XgQ30P2T
ND@20:AiAPH0XgQ500<0Z7i>0:IlC02SNDT00P2QMdL02`2SNDT0YWa<0:QnCP2WOTP0YGa60:=jA02R
ND<0XGQ20:9i@`2SNT@0Y7]50080XgY600H0Y7Y80:AjBP2UNTd0YGY=0:EjC`2VNe020:=jAP060:Ak
A`2UO4P0YWe90:MnBP2XOd/0ZH1<0`2WO4L30:QmB0X0ZGi90`2WO4T20:QmBP<0ZGi;00<0ZX1>0:Uo
C@2WOD/00`2VO4X00`2XOT`0ZGm=0:V0C0070:V0C0P0[8==0`2[PTh30:b3C`80[HA@102ZPD/70:^2
C0<0[8==0P2]Q4h30:b2D0<0[H=A0P2^Q5800`2^QE40[HA@0:^2CP020:Z1C@030:^2CP2]Q500[XEA
00<0[8=?0P2]Q50<0:j5D@060;27C`2_QTh0[hI@0:n6DP2^QE40[XAB0P2]Pe<30;67C@030;26C02_
QD/0[hE;0080[XA:00H0[HA@0:n6DP2aR5@0/XUE0;>:EP2bRED20;68E0030:b2D02]Pe40[hEC0080
/8ID00H0[hEC0:f3D@2/PU00[XEA0:n6DP2`Qe<20;68E0030;27D`2_QU80[XEA0080ZhIB0P2/Qe<2
0:f8E080[XUE0P2_QU820:j5D@040:f4D02/Pdl0[8=?0:b3C`80Zh9>00h0[8=?0:j5D@2`Qe<0/HQD
0;:9E@2cRUH0/8IF0;67E`2bR5P0/hUI0;:8F02aQeL0[hEE0:j4E080[hIB0P2`Qe<30;68E0030;:9
E@2`Qe<0/HQD00H0/HQD0P2`Qe<60;68E080/XY?0`2aRDh30;28C@060;26BP2_Qd`0/8Q=0:n8C`2^
RE80[X]E0P2/ReH30;68D080/XUA0`2cRU830;68E080/XUE0`2cRUH80;6;FPP0/XUC0`2cREL01P2c
RUH0/hYD0;>:DP2cRe00]8aA0;B<C`P0/XUC00<0/8MC0;68E02cRUH00P2eS5P00`2dReL0/hYF0;:9
E@020;:9E@<0/hYF0`2dReL40;F<EP80]8]E0P2cRU@00`2dReL0/hYF0;>:EP0=0;>:EP80]8]G0P2e
S5P0102dReL0/XUE0;27D`2^QE420:n:EP<0[XUE0`2]R5@80:j5D@P0[HA@00<0Zh9>0:b3C`2/Pdl0
0P2]Q5020:j5D@030:n6DP2]Q4h0[HA>0080[XE?00@0[hI@0;27D@2`Qe40/8MA0P2]Q4h30:b3C@<0
Zh9<00<0[8=?0:f4D02]Q5000P2^QE420:n6DP060;27D`2^Q580[XAB0:j5D@2]Q4h0[HA<0P2/Q4T0
0`2/Q4L0Zh9>0:^2CP060:^2CP80[XEA0`2]Q5030:b3Ca40[HA@00<0[XE?0:f4CP2/Pdd00P2[PT`0
0`2/Pdd0[HA>0:j5C`080:f4D0030:Z0D02[PE40[H=A0080[XEA00H0[HA>0:^2BP2ZPDT0/XUE0;27
D`2^QE430:b3C`050:f4D02^QE40[XE=0:j5C@2^QDl00P2]Q500102/PU00[89B0:b2DP2/PU820:b2
D0030:b3C`2/Pdd0[8=;0080[8A900<0Zh9<0:b3C@2/Pdd00P2]Q4h20:j5C`030:n6D02]PTl0[H9?
00H0[H9?202[PTh20:f4CP80[8==0P2[PT`20:Z1B`80ZH1<0P2ZPDd20:^2CPD0[8=?00<0Zh9>0:Z1
C@2ZPDd00P2YP4`80:^2CP0>0:n6DP2^QE40[8=?0:Z1C@2YP4`0ZX5=0:^2CP2/Pdl0[hIB0:f4D02[
PTh0Z7m;0:MnBP2VODT20:MnBP80Z7m;0`2YP4`30:Z1C@80[H9?00L0[85>0:^0C@2ZOd`0ZGi;0:Qm
BP2WO4T0ZX5=00T0ZH1<0`2ZPDd20:^2CP80[8=?0P2YP4`20:Z1C@80Zh9>0P2/Pdl20:UnB@<0ZWm:
0`2[P4/80:QoB`80Z7m90P2YP4X20:Z1B`80Zh9<202[PTh80:UoC@P0ZWm:202/Pdl80:YoC0P0ZH1<
202[PT`40:R3C`0:0:N2CP2VPDd0Y7m;0:AoB`2XP4<0Z8150:V1AP2YP4P0ZH1:0:Z1C@80ZX1>202Y
P4`30:QmB080ZGi90`2ZOdX80:V0C0030:Z0AP2YOdD0Z7i40080Yge300<0Z7i40:UoA@2ZP4H00P2Y
OTT30:QmB0<0Yga72@2XOd/00`2TNTX0YG];0:MmC@020:QnCP060:MmC@2UNd/0Y7Y:0:MlA`2VNdH0
YGY50P2SN4<00`2UNTD0YW]60:MlA`080:EiBP80Yga90P2VNdP0102UNTL0Y7U60:AiAP2TNDH80:Ij
B@030:MnBP2VODT0XgY60080XGQ400<0XgY60:ImB@2WOTX00`2UO4P30:AkA`80XgY600T0XWU50:5h
A02QN4@0XGQ40:9iA@2TNdL0YWe90:QoB`2VNdP00P2WO4T01@2XODX0Yga90:EjA`2RMd@0XGI30080
XWM01P2SN4400`2UNdT0Y7Y80:9hAP030:1fA0040:5gA@2RN4H0XGM50:1fA0<0WgE300H0XGM50:9h
AP2TNTP0YGY50:AiA02RMd820:5f@@030:9g@P2TND@0YGY50080XGQ400<0XWU50:=jAP2TNdL00P2U
O4P00`2VODT0YGa80:ElB0030:AkA`<0XgY6202TND820:9hAP<0X7I400H0XWQ60:AjB02UNdT0XWU5
0:=jAP2UO4P20:ImB@060:ElB02SNTH0XWU50:ElA02TNd<0XWU30P2QN4@20:9hAP080:AjBP2UNd/0
XgY60:=jAP2RNDD0XGQ40:1g@`2OMT8209ie@@P0X7]700@0XGM50:1fA02PMT@0X7I40P2OMD<209id
@P80X7I400@0WgE309id@P2MLd40WG=10P2LLT0309me@`0309id@P2MLd40WG=10080W7900P2KLCl2
09ab@080WG=10P2NM480102KLCl0W79009ab@02LLT0209ec@@80WWA200P0WG=109ab@02KLCl0VW0n
09]a?`2MLd40WgE30:1fA0<0Vg4o1@2LLT00202NM480WG=109]a?`2JL3h0VFlm09Y`?P2KLCl0W790
202LKSd00`2HKS`0VFlm09]a?`0209ec@@0309ab@02KLCl0VW0n0080VVhm0`2IKC`309Q/>`80UV`j
0P2EJcT0102DJSP0TfTg09=Y=`2CJCL209E[>@80UV`j0P2GKC/209Q^?0@0UV`j102EJcT209I]=`03
09E/>02EJcT0U6Xj0080TfPk00<0TfPm099/?@2BK3d00P2CKCh209A^?`80UFm00P2EJcT209I/>P80
Ufdk0`2HKS`209EZ?@0309I[?P2GK3l0V6e000<0VFi100<0Ufdk09I/>P2EJcT00P2DJSP00`2EJcT0
UV`j09M]>`0809=X>`P0TVLl0100SVPk08eW>P2<IST0RfDh08aV>@2=IcX0SfTl095[?P2AICh0TVHo
09AX@@2EJD80U6Q109=W@02BISl0TFDn0`2CKD02099/?`<0TF/n0P2DJC`02@2EJSd0UV/n09EZ?@2D
JC`0TVLj091U>02?I3T0T6Dj099W?00209=X?@03099W?02@ICX0Sf@i00<0TFY1:oooool002[ooooo
00D0Qf0g08IO=P26GcH0QEhe08AM=00208=L<`04089K<P28G3D0R5`e08QL=@<0REdf0P2:GSL308EN
=@<0QUlf0P27H3L00`2<H3T0Relh08UM=P0208QL=@0408UM=P2;GcP0S60i08QM<P80REhc00<0Rf0e
08aQ=P2=HSL00P2>HcP00`2=HCh0S60m08YN>`0208UM>P0308YN>`2<H3d0SF4n00P0SV<h202>HcH0
202=HSL0S64f08]P=@2;H3D0S64f08mT>@2AIS/0TfPm2@2>HcP8091S>@0308iQ=`2?HSP0TF@j00<0
TfHl00d0TVDk095T>P2?HcH0TfLj09M[?P2FJSd0TVHi091T=`2DJ3/0V6`o09=X>`2BIcX0TFHi0080
T6Dh00@0TFHi099W>P2CJ3/0Uf/n0P2FJSd00`2DJ3/0TfLj099V>@02095U>0P0U6Lm00@0TfLj09EY
?02GJch0VFe00P2JKT401`2IKD00V6`o09AX>`2DJ3/0UFTl09IZ?@2GJch00P2HK3l0102IKD00Uf`o
09I[?P2EJSd209=X>`0309EZ?@2FJch0Uf`o00P0V6`k102GKSX409I]>@80Uf`i0P2HKCX01`2IKS/0
VVll09Y_?02KL3d0W70o09]_?P2IKC`00P2HK3/00`2IKC`0Vfln09a`?`0809Q]@00509md@@2NLd00
WW=009eb?`2LLCh00P2KL3d00`2JKc`0VFhk09U^>`0609U^>`80W74n00@0Vg0m09Y_?02JKc`0VFhk
0P2HKCX809md@@80W7900P2KLCl03@2JL3h0VFlm09U_?@2IKcd0V6hl09ab@02IKcd0Ufdk09Y`?P2O
MD<0XGM509me@`2MLd400P2RMd820:5f@@040:1e@02OM3l0Wg@o09ic?PP0XGI100P0X70o0:5a@02S
Ld80YGE40:IfA@2UMD@0Xg=20:9b@@P0Y7Q700H0X7E20:5f@`2QMT<0XWM40:=hA@2TNDH20:EjA`08
0:UnB`2VNdP0XWM409ic@02MLSl0WW=00:1e@P2RMd@20:EjA@80YW]60`2WO4L00`2XODP0Yga70:Ml
A`070:MlA`070:IkAP2TND@0XWM20:9g@P2SN4<0Y7U40:EjA@030:IkAPD0YGY50`2XODX20:UnB`@0
ZWm<00L0Z7e:0:IkB02UNTL0Y7U60:EjA`2VNdP0Yga900<0ZX5=0P2[PTh30:b3C`<0Z7e:00<0ZGi;
0:YoC02[P4d00P2[P4d01P2]PTd0[85<0:b1C02[P4/0ZWm:0:UnB@D0Z7e80P2YOTT60:YoBP030:^0
B`2/PD`0[H9=0080[H9=00<0ZGi90:YoBP2/PD`00`2]PTd20:^0B`030:YoBP2YP4P0ZH180080ZX59
0P2[PTX20:b3B`P0Zh550P2]PTd20:b1C080Zh1;0P2ZOdX30:YoC0030:^0C@2/PDh0[H9?0080[H9?
202/Pdd20:UmC0<0ZWi=0`2[Odh20:QnCP<0ZGm?0`2ZP5020:f4D0<0[8=?0`2[PTh20:j3C0<0[H9;
0`2/PDX0102YP4`0Zh9>0:f4D02_QU820;68E080/8MC00@0ZX5;0:^2C02]Q4h0[hI@0P2`Qe401@2_
QU00[XE?0;20C`2aPE00/X9A0080/h=B00<0/H5@0:moCP2^OTd00P2[Q4T20:Z3B080ZH970P2XPDH2
0:QmB0@0ZGi90P2ZOdX30:Mm@`<0Z7i40P2YOdD20:ImA`060:MnB02XOdT0Ygi80:ElAP2SNT@0XWU3
0`2TNdD20:=jA0<0XWU3202QMDH20:9gA080XgQ50P2TNDH30:EjA`P0XWQ60P2OM3l0102PMD00XGI1
0:5f@@2RMd820:=h@`030:AiAP2SN4D0XgQ50080XgQ50`2RMd@00`2XOTh0YWa<0:=iB@020:1fAP06
0:=iB@2VO4`0Z7i>0:MnB02UO4H0XgY40`2QN4801`2SNT@0Y7]50:=jAP2SNTH0Y7Y80:AjBP2UNTd0
0P2UNTl02@2UNU00XWU50:=jAP2TNdL0YGa80:ImB@2WOTX0Z7m;0:V0C0030:MlA`<0Z7e82P2YOTT3
0:MlB@<0Z7e:0P2YOT/0202YOdd0Z7i<0:IlBP2UNdT0Y7Y80:EkB@2VO4X0Yge;202YP4`80:b3C@<0
Zh9>0`2/Pdl20:f4D0050:QoB@2YP4X0ZH1:0:Z1B`2[PT`00P2/Pdd0102]Q4h0Zh9<0:^2C02[PT`3
0:b3C@80[HA>0`2/PU020:f3D@<0[XAB00<0[XEA0:f4D02[PTh00P2ZPDd00`2[PTh0[HA@0:j5D@03
0:b3C`80[HA@302^QE420:n6CP040:n6D02_QU80[XEA0:j4DP80[H=C00@0/HM;0;26BP2`QTX0[hE9
0P2^Q4P20:f3A`040:f4D02^QE40/8MC0;:9E@80/hYF00D0/XUE0;68E02/PU00[H=A0:n5D`020;26
E0060:n5D`2]Pe40[89@0:f4D02_QU80/8MC0P2bRED00`2`Qe<0[hIB0:f4D0020:^6DP80[8MC0P2]
R5@20:j9E@80[hIB00@0[XEA0:f4D02]Q500[8=?0P2[PTh02`2YP4`0ZX5=0:^2CP2]Q500[hIB0;27
D`2aR5@0/XUE0;26EP2aQeL0/XQH0080/hUI00<0/HMG0:n5E@2]Pe<00P2`Qe<20;68E0<0/XUE00<0
/hYF0;:9E@2bRED00`2aR5@60;27D`D0/HQD0P2bRTd30;69C0<0/8Q;00P0/8I:0:n7C02`R4d0[hQ?
0:j9DP2^ReD0[8]F0:f<E`<0/HQ@0P2bRE430;>:DP<0/HQD0P2bRED30;>:EPP0/H]J202bRE<30;>9
E`030;>:EP2cRU@0/hYB0080]8aA00@0]8a?0;68DP2aR580/HQB0P2bRE<30;>:E0030;27D`2aR5@0
/hYF00<0]HaH00L0]8]G0;>:EP2aR5@0/HQD0;:9E@2cRUH0]8]G0080]HaH00<0]XeI0;J=E`2eS5H0
0P2eS5H20;B;E@80/hYD0P2bRED30;>:EP<0]8]G202cRUH0202dReL0]HaH0;J=F@2fSET0]HaH0;:9
E@2`Qe<0[XEA0P2_RUH30:j9E@<0[HQD202/Pdl80:f4D080Zh9>00@0[8=?0:f4D02]Q500[XEA0P2_
QU820:j5C`040:n6D02`Qe40/8MA0;68DP80/XUC0P2^QDl00`2]Q4h0[8==0:^2C0020:Z1B`050:V0
BP2/Pdl0[HA@0:f4D02^QE400P2_QU820;27D`80[XAB00<0[XEA0:f4CP2]Q4`00P2/Q4T00`2/Q4L0
Zh9>0:^2CP060:^2CP80[hIB00@0[XEA0:f4D02]Q500[8=?0P2[PThA0:f4D0030:n6D02^QDl0[HA>
0080[8==00<0[HA>0:j5C`2_QU00202]Q5000`2YOdl0ZX1@0:b2D0020:f4D0060:b3C@2ZPDT0ZH18
0;:9E@2aR5@0[XEA0`2/Pdl01@2^QE40[hIB0:j5C@2^QDd0[XE?0080[HA@00<0[89@0:b2DP2/PU80
0P2/PU00102/Pdl0[8==0:b3B`2/Pd/20:b4B@80Zh9<00@0[8==0:f4CP2]Q4h0[XE?0P2_QU080:f2
C`P0[8=?00@0[XE?0:f4CP2]Q4h0[8==0P2[PT`20:Z1B`<0ZH1<00<0ZX5=0:^2CP2/Pdl01@2/Pdl0
0`2[PTh0ZX5=0:V0C0020:V0C0P0Zh9>00d0/8MC0:j5D@2/Pdl0ZX5=0:V0C02ZPDd0Zh9>0:b3C`2`
Qe<0[hIB0:b3C`2YP4`0YWe90080YGa800<0YWe90:QoB`2XOd/00`2YP4`30:Z1C@80[H9?00<0[85>
0:^0C@2ZOd`00P2XODX00`2WO4T0Z7m;0:QoB`030:V0C0<0ZX5=0P2YP4`30:Z1C@80Zh9>0P2/Pdl3
0:V0C0030:Z1C@2[PTh0[8=?0080[8=?0P2YOTT30:YoBP<0Zh1;202XOd/0102WOTP0Z7m90:QoB@2Y
P4X20:Z1B`80Zh9<202[PTh80:UoC@P0ZWm:202/Pdl80:YoC0P0ZH1<202[PT`20:R3C`0<0:V4D02Z
QE40Z8=?0:J1C@2TOd/0XWe90:R0@`2XP4D0ZH560:V0B02YP4X0ZX5=0P2ZP4h80:V0C0<0Z7e80P2Y
OTT30:YoBPP0ZH1<00<0Zh550:Z0A02YOd<00P2XOT800`2YOd<0ZX140:^1A@020:UnB@<0Z7e80`2W
O4L90:QoB`030:=iB@2TNTX0YWa<0080Yge=00H0YWa<0:AjBP2SNDT0Yga70:IkAP2UNTD20:=h@`03
0:EjA@2VNdH0Yga700P0YGU:0P2WO4T20:IkB0040:EjA`2TNDH0Y7U60:=hA@P0YWY900<0ZH1<0:Im
B@2RNDD00P2OMT800`2RNDD0YWe90:V0C0030:ElB0<0Y7]70P2SNTH02P2RNDD0XGQ40:1g@`2QN4@0
XWU50:AkA`2VODT0Z7m;0:EjA`2VNdP20:MlB@040:IkB02TNDH0XWM40:1e@P<0XWM01@2SN4400`2U
NdT0Y7Y80:9hAP030:1fA00=0:5gA@2RN4H0XGM50:1fA02OMD<0WWA209me@`2PMT@0XWQ60:AjB02U
NTD0Y7U40:9g@P020:5f@@030:9g@P2TND@0YGY50080XGQ400@0XWU50:=jAP2TNdL0Y7]70P2UO4P2
0:ImB@<0YGa80`2TNdL20:9g@0030:=h@@2TND80Y7U20080YGY300`0YW]40:=iA`2RN4H0X7I409me
@`2PMT@0XWQ60:AjB02UNdT0XWU50:=jAP2UO4P20:ImB@060:ElB02SNTH0XWU50:ElA02TNd<0XWU3
0P2QN4@20:9hAP080:AjBP2UNd/0XgY60:=jAP2RNDD0XGQ40:1g@`2OMT8209ie@@P0X7]7102PMT@2
09me@`80WWA20P2QMdD0102PMT@0WgE309ec@@2LLT0209]a?`80X7I400@0WgE309id@P2NM480WG=1
0P2LLT0209]a?`80W79000@0WG=109id@P2NM480WgE3102LLT0209ec@@80WWA200<0WG=109ab@02K
LCl00P2KLCl00`2MLd40WgE30:1fA00809]a?`0809id@P2MLd40Vg4o09Y`?P2IKcd0VW0n09]a?`2L
LT0809a^?@0309U_?@2JL3h0W7900080WWA200<0WG=109ab@02KLCl00P2JKSd309U]?0<0V6`k0P2F
K3X0102EJcT0U6Xh09AZ>02CJCL2099X=P80UF/i0P2FK3X209M]>`80V6hl0`2FK3X509E[>@80UVdg
00H0UF`h09AZ>02DJSX0TfPk099W>P2BIc`2099/?@80Tfdn0P2DKSl209E_@0<0UF/i00<0UV`j09M]
>`2HKS`00`2HKS`01P2DJC`0UFXm09I[?P2GK3l0V6e009Y_@P80Vg1300<0UV`j09E[>@2DJSP00P2C
JCL00`2DJSP0UF/i09I/>P0809=X>`P0TfHl00<0SVPk08eW>P2<IST00P2;ICP02`2=IcX0SfTl095[
?P2BIT40TfM209AX@`2EJD@0U6Q309=W@P2AID00T6@o00<0Tfe00`2BK3l2095[?P0;09AY?02EJSd0
UV/n09I[?P2EJSd0U6Tl099W>P2@ICP0T6Dj095V>`2CJ3d00P2DJCh00`2CJ3d0TFHk091U>P03095Z
@b_ooooo000Zooooo`P0QUlh2026GcH0202<H3T0RUhg08UM=P28G3D0REdf08YN=`2=HCX0SV8k0`29
GCH208YN=`<0Relh00H0QEhe08IO=P26GcH0R64h08UR>@2:HcX208]T>`0308]U>02:I3L0R68e0080
QV0c00<0Qf4d08US=P2:I3L00P2;H3D208aQ=P80SF8g0P2>HcP0202?HcH0SV8e08aP<`2<H3<0SF4d
08mS=P2BIST0TfLj0`2<GcD00`2=H3H0SV4g08mR>00208mR>0<0SF8e102>HcH208mT=`03095U>02B
IST0TfLj0080U6Pk00<0TfLj099V>@2AICP0102@I3L2095U>080TVHi0`2CIcX309AX>`80UFTl00P0
U6/m09=Z?02BIcX0TVHi09AU>@2FICX0V6Ll09]X?@<0TfPk0P2DJC`509EZ?@@0U6Tl0P2CJ3/02@2D
J3/0TfLj099V>@2BIST0TfLj09IZ?@2IKD00VVi109AW?@0209EY?00309IZ>`2GJcX0Uf`i0080V6dh
0P2GK3L01P2GK3T0Uf/j09IZ>`2FJSd0UFTl09EX?P<0UV/n0`2EJSd209AY?0<0VFdl00<0V6`k09M[
>P2FJST00P2FJST0202DIcd0UVXm09Q/?`2JKSl0VVhm09U^>`2HKCP0UV/f0P2FK3X209M]>`0=09Q^
?02IKcd0VFlm09Y`?P2DJ3T0UFTj09IZ>@2HKCX0Vg0m09eb?@2NLc`0Wg@m09id@P0209ec@@0509ab
@02KLCl0VW0n09Y`?P2IKcd00P2QLD00102PL3l0Wfln09i^?@2MKC`209a/>`0@09]`?@2JKc`0VFhk
09U^>`2JKc`0W74n09ic@02OM440V6`k09U]?02JKSd0W70o09ea@02OLd80X7A30:5eA080WWA20`2M
Ld4409ab@0P0WG8o0P2PMD000`2OM3l0WW<n09eb?@0209aa?00309]`>`2SM400Y7E100<0YGI200T0
XgA00:9c?`2PLCd0Y78m0:9c?@2RLcl0XG=109md@@2NM4800P2MMD@00`2OM440XGI30:9gA0020:Ai
AP030:9gA02QMT<0WgA10080Y7Q70`2SMdH30:9fA@080:9gA02SN4D0Y7U60:EjA`2TNDH0XgQ50:5f
@`2PMD820:YjB@80ZGU800L0Z7Q70:MgAP2WMdH0YWI50:EiB02TN4L0XgM60080XWI500H0Y7Q70:Ij
B@2WNdX0ZGi90:MlA`2UNTD20:=h@`030:AiA02UNTD0YW]60080YGY50P2VNdH20:MlA`80Z7e800H0
Y7U40:EjA@2VNdH0Yga70:QmB02ZOdX20:^0B`80ZGi;0`2XODX30:MlB@P0Z7m;0P2ZPDd0102YP4`0
Z7m;0:QoB`2WOTX20:ImB@040:Z1B`2YP4X0Ygi80:ElAP80Y7]500D0YGa60:ImA`2WO4T0Yga90:Qm
BP020:UnB`030:YoC02[P4d0Zh1=00X0[8=?0P2[PTh20:Z1C@<0ZH1<102/PD`40:^0B`P0[H9?202Z
Od`20:UnB`80ZWm<102[P4d01P2^PTD0[X560:j1AP2^PDP0[X5:0:j0C080[X1>202[PTh30:V0C003
0:Z1C@2[PTh0[8=?00<0[8=?0`2[PTh20:Z1C@80ZH1<00P0Z7e60:UnA`2ZOdX0Zh1=0:b1CP2]PE00
[X9C0:n3E0<0ZHA@0P2ZQE430:^6DPP0ZhIA202/Pdl30:Z1B`<0ZH1:0P2XOdT30:QmB080Yga70`2V
NdH50:QmBP<0Yga900X0XgQ50:EjA`2WO4T0Z7e:0:UnB`2XODX0YW]80:EjA`2TNdL0YGa80`2WOTX0
1P2UO4P0XWU50:5hA02RMd@0XgQ50:EjA`80YW]800H0YGY70:=hA@2RMd@0ZGi;0:QmBP2VNdP20:Ej
A`070:IkB02XODX0ZGi;0:UnB`2TNdL0XgY60:5hA00209mf@P030:5hA02SNTH0Y7]700P0X7M300H0
W7<o09ed@02MM400WgI20:1g@`2QN4@20:9iA@030:ElB02TNdL0XGQ400<0WgI200@0X7M30:5hA02S
NDL0XgU70P2RN4H40:5gA@0309mf@P2QN4@0XgY600<0YGa800<0XgY60:9iA@2RNDD00P2SNTH00`2T
NdL0YGa80:ElB0020:ImB@80Y7]50P2UO4H30:ImA`060:MnB02VODT0YWe90:ImA`2VODD0YGe20P2U
OD004@2TO3h0YGdo0:Em@02UOD80YGa60:EkB@2UNTd0YGY?0:EjD02^P4h0[Gm=0:]mB`2YNdT0Z7Y8
0:UkB@2[OD/0[7i<00P0ZH1<0P2YOdd00`2ZPDd0ZX5;0:^2BP020:^3B0030:b4A`2ZPD/0ZX5;0080
ZH1:0`2XOdT01`2WOTP0YGa40:ElA02VODL0Ygi:0:V0C02ZP4h00P2[PE400`2XOd/0ZH1<0:b3C`03
0:j5D@0:0:b3C`2[PTh0[X=>0:f2C@2[P4/0ZWm:0:^0B`2]PTd0[hA?0;25D0P0[XEA0`2[PTh50:b3
C`<0[hI@00H0[XEA0:f3D@2]Pe<0[85D0:^0D`2[P5D80:j5D@060:^2BP2/Pd/0[8=;0:j5C@2_QTh0
/8M?0P2aR5080:j5D@040:j9E02]R5<0[HQC0:f8D`<0[8MB00H0ZhIA0;68E02aR5@0/HQD0;27D`2_
QU830:j5D@040;27D`2_QU80[hIB0:j5D@80[HA@0P2/Pdl80:j5DA00/8MC0P2aR5@20;:9E@80/hYF
0P2dReL00`2`Qe40/HQB0;>:E0020;B;E@030;>:E02aR580/8MA0080/XUE0`2aR5@30;27D`P0/HQB
00<0/8MC0;68E02cRUH00P2dReL01P2cRUH0/HQD0;27D`2dRUX0/hUI0;67E@80/8MC00<0/HQB0;>:
DP2dRe<00`2aR5@20;:9E@<0/hYF202^RUH30;27D@<0/HQB0P2bRE<02@2eS5@0]8]C0;B;D`2cRU@0
/hYF0;B;E`2eReT0]heM0;V?G`020;68E0030;:9E@2cRUH0]8]G0080]HaH00<0]XeI0:b7D`2/Qe<0
0P2]R5@0102^RED0[hYF0:n:EP2`ReL20;:=F080/HaG00@0/8]F0:n:E@2_RUD0[XUD202bSET0402/
ReH0[HaG0;2<F02bSET0]8aI0;>9E`2aQeD0/8AC0;:9D@2aR500/8MA0:n6DP2`Qe<0/XQF0;F;F`2f
S5`20;6<F0040;2;E`2_RUH0[hYF0:j9E@80[HQD00/0[hIB0;27D`2aR5@0/XUE0;68E02`Qe<0[XEA
0:f4D02_Q4l0[X=>0:b1C0020:^0B`030:b1C02^Pdh0[hA?00<0[XAB0P2]Pe430:b2D0060:^2CP2/
Pdl0[8=?0:j5D@2_QU80/8MC0P2aR5@80:f4CP080:j5D@2]Q500[8=?0:^2CP2ZPDd0ZH1<0:QoB`2W
OTX20:^2CP040:b3C`2]Q500[HA@0:j5D@80[hIB00P0/8ID0:n5D`2^Q580[H=A0:b2D02[PDl0ZX1>
0:UoC@80ZX5=0P2[PTh0102/Pdl0[HA@0:f4D02]Q5020;:9E@060;68E02_QU80[HA@0:b3C`2[PTh0
ZX5=0`2^QE420:f4D0<0[8=?302[PThE0:b3C`P0[HA@0P2/Pdl20:^2CP<0ZX5=00<0ZH1<0:^2CP2[
PTh01P2[PTh80:b3C@080:n4C`2^Pdh0[H9=0:b1C02[P4/0ZWm:0:UnB@2XODP30:^2CP<0[8=?0P2]
Q5080:b1C0P0[8=?0`2YP4`00`2ZPDd0Zh9>0:b3C`020:b3C`80[8==0P2[PT`20:Z1B`80ZH1:0`2[
PTh30:b3C`@0[HA@00@0[8=?0:^2CP2YP4`0Z7m;0P2WOTX80:Il@0060:b3B`2[PTX0Zh9:0:Z1B@2Y
P4P0Z7m70P2WOTH01P2VODT0Ygi:0:QoB`2YP4`0ZX5=0:^2CP80[8=?0`2/PU820:^1D@040:Z0D02Y
Odl0ZGm?0:UoC`P0Zh9>202XOdT80:UoC`080:ImA`2WOTP0ZX5;0:^2C02/Pdd0Zh9<0:V0BP2XOdT2
0:j5C@030:f4C02/Pd/0Zh9:0080ZX5900<0ZH180:Z1B`2ZPD/01P2ZPD/20:f2B`040:f2C@2/PDh0
Zh1=0:YnC@80ZWi?00H0[85F0:b1E02/PE@0[89B0:b2D02/Pdl20:b3C@040:MnBP2XOd/0Z7m;0:V0
C080ZX5=0P2[PTh80:V0BP030:QoB@2ZPD/0Zh9<0080[HA>00<0Zh9<0:Z1B`2XOdT00`2]PTl00`2/
PDh0Zh1=0:YoC0020:YoC0P0ZGm=0P2ZP500102ZP4h0ZH1<0:V0C02YP4X20:QoA`P0Z7m900<0YGa6
0:ImA`2XOdT00`2ZPD/0102XOdT0Ygi80:QoB`2XOd/30:MnBP<0YWe900<0YGa60:ImA`2XOdT00P2Z
PD/00`2YP4X0Z7m90:MnB0030:IkAPH0YGY500<0YGa80:ImB@2XOd/00P2YP4`00`2WOTX0YWe90:Ak
A`080:AkA`80YG];0P2VO4`0102WODd0Z7i>0:QnCP2YOdl80:ImA`030:1fAP2RN4P0YG]90080Z7m;
00T0YGa60:9i@@2PMcl0Y85;0:F0B`2TOdX0YWi:0:ImB@2WO4T00P2YNdT80:EjA`80X7I600@0XGM5
0:9iA@2SNTH0Y7]50P2UO4@00`2SNT80Y7]30:Ak@`020:Ak@`060:=j@P2QN400XGQ00:9iA@2SNTH0
Y7]70P2UO4P01@2SNTH0XGQ40:1g@`2OMT80X7M300<0XGQ400<0WgI209ed@02LLcl00P2PMd<0102Q
N4@0XWU50:AkA`2UO4P20:ImB@<0XgQ500<0XWM40:5f@`2PMD800P2PMD820:9i@`030:=jA02TNdD0
YGa60080YWe700L0Ygi80:AiCP2TND`0Y7U<0:=iB@2SNDL0XWU50080XWU3102QMT<40:9gA0P0X7]6
00<0XWU10:=j@P2TNd<00P2UO4@00`2SNT80XGQ00:1g?`090:=jAP030:AhA`2SMdH0XGE40080X7A3
00`0XGE40:=gAP2TN4L0Y7I40:EgA@2TNDH0Y7]70:AlB02SOTT0Y7m:0:>0BP2IN4<309Qg@P80UgI1
0P2FMD001P2KN480W7M209ag@P2NMT80WgI20:1e@P80XWA200<0X7I409me@`2MLd400P2LLT001P2M
Ld40WgE30:1fA02OMD<0WWA209ec@@80W79000<0WWA20:1fA02QMdD00P2OLd8309ib@@<0WG50202M
M3h209ec@`0409ab@02LLcl0Vg8n09]b?080VW4i00T0Vg4o09ec@@2OMD<0X7I409me@`2MLd40VW0n
09U_?@2HKS`00P2IKcd00`2JL3h0Vg4o09]a?`0209ab@080UV`j0P2GKC/01@2HKS`0VFlm09Y`?P2J
L3h0VVm20080VFi100<0V6e009M/?`2GK3l00P2FJch0102IKcd0V6hl09I/>P2DJSP209=Y=`0P09AZ
>02EJcT0UFY009M/@P2IKT<0Vg1309ab@P2LLT00VW0n09U`?02GLSh0UW4m09A_>`2CKSX0TVdi09=^
>P2DKc/0UG0l09]`@`2JKd80VFi109M/?`2EJSd0TfPk095V>@2@ICP0TF/l099/?@2CKCh0U6ho09I`
@@2HLT<209UcA00309Y`?P2HKS`0UF/i0080U6Xh00D0UF/i09Q^?02HKS`0VW0n09U^@@0209Q]@005
09M/?`2FJch0UFXm09EZ?@2DJC`0202AJc`3099W>P<0TfPk0P2DJC`0202AIST0TfPk09EZ?@2FJch0
UFXm09=X>`2@ICP0Sf@g202=IcP809A^?`<0TV`m00<0Tfdn09A^?`2EKd000P2EKd02099/?`03095[
?P2@JSd0SfTl0080SVPk00<0SFLj08iY?`2>JCl01P2>JCl3091Z?B_ooooo000Zooooo`P0QUlh2026
GcH00`2:GSL0REdf08QL=@0208QL=@0308YN=`2<H3T0SF4j00<0REdf0P2:GSL308]O>00608EN=@26
GcH0Qf0g08QQ>029HST0RV<j0P2;I3/00`2;ICP0RF<f08QR=@0208IP<`0308MQ=029HcH0RV@g0080
Rf0e0P2<HCH208eR=`80SV<h00P0SV8e08eQ=02=HC@0S60c08eQ=02?HcH0TVHi09=W>P80S5le0P2=
H3H0102>HCL0Sf8h08mR>02?HSP308eR=@<0SV<f0`2?I3L00`2@I3L0TVHi09=W>P0209AX>`0309=W
>P2BIST0T6@g00<0TFDh0`2BIST509=W>P<0U6Pk0P2EJC`0202DJcd0TfXl099W>P2BIST0U6Di09IU
>P2HIc`0VfPm0`2CJ3/209AY?0<0UFXm202DJC`02@2DJ3/0TfLj09=W>P2CIcX0U6Pk09IZ?@2HK3l0
VVi109EX?P0209EY?00309IZ>`2GJcX0Uf`i00<0V6dh00L0Uf`g09M/>@2GJcX0UVXk09IZ?@2EJC`0
UFPn00<0UV/n0`2EJSd209AY?080VFdl0P2HK3/209M[>P80UVXi00P0U6Lm09IZ?@2HK3l0VFdn09Y^
?@2IKS/0V6dh09M/=`80UV`j0P2GKC/0102HKS`0VFlm09U_?@2IKcd209M[?00409Q/>`2JKc`0Vg0m
09eb?@80WW<l0`2LLT0309]a?`80VW0n00D0XG500:1`?`2PL3l0Wfln09i^?@0209e]?00A09a/>`2L
LCh0Vg0m09Y_?02IKS/0VVll09]`?@2MLSl0WW=009Q/>`2IKC`0VVhm09a`?`2MLD00Wg=20:1d@`2Q
MD@00P2NM48309ec@@@0W790202MLSl209md?`<0WW<n0`2MLSd03P2SM400Y7E10:Ef@P2VMd<0YGI2
0:Ae@@2RLcl0X74m0:Ab?@2RLcd0XW<o0:5c@@2OM440WWA20P2MMD@00`2PMD80XGI30:9gA0020:=h
A@030:9gA02QMT<0X7E20080Y7Q70`2SMdH30:9fA@030:5f@`2RMd@0Y7U60080YGY700<0Y7U60:9g
A02QMT<00P2ZNTT20:UiB00D0:QhA`2WMdH0YgM60:MgAP2UNDP0Y7Q70:=gAP2RMTD0XgM60:AhA`2V
NTT0Yg]:0:UnB@2WO4L0YGY50:AiA02SN4<0Y7U40:EjA@2VNdH20:EjA@80YW]60P2WO4L20:QmB080
YW]60P2WO4L01@2XODP0ZGi90:YoBP2ZOdX0Yga900L0Z7e:202XOd/00`2ZPDd0ZH1<0:V0C0020:Qo
B`80Ygi:00X0YWe90:^2C02ZPD/0Z7m90:ImA`2UO4H0YWe70:MnB02XOdT0Yga90P2XODX20:UnB`80
ZWm<00<0Zh1=0:b3C`2/Pdl0202/Pdl20:^2CP80ZX5=0`2YP4`40:b1C0@0Zh1;202]PTl80:^0C@80
ZGi;0P2ZOd`30:^0C@030:b1CP2^PDH0[X560080[X5800@0[X5:0:j0C02^P4h0[X1>202[PTh20:V0
C080ZX5=0P2[PTh20:b3C`@0Zh9>0P2ZPDd20:V0C0090:QmAP2YOTL0ZGi90:YoC02/PDh0[H5@0:f1
DP2^PU<0Z8=?00<0ZHA@0P2ZQE420:^6DPP0ZhIA202/Pdl30:Z1B`<0ZH1:0P2XOdT30:UnB@80Z7e8
0`2WO4L40:QmBP@0Yga900<0Y7U60:EjA`2WO4T00P2XODX03P2VNdP0YGY70:AiAP2SNTH0Y7]70:El
B02VODT0YGa80:=jAP2QN4@0X7M30:9gA02SN4D0Y7U60P2UNTL01P2TNDH0XgQ50:9gA02WO4T0YW]8
0:EjA`80Y7U600L0YGY70:IkB02WO4T0Yga90:=jAP2RNDD0XGQ40080WgI200<0XGQ40:9iA@2SNTH0
202PMd<01@2LLcl0WGA009ed@02NMD40X7M30080XGQ400@0XWU50:ElB02TNdL0XWU50`2PMd<0102Q
N4@0XWU50:=iA`2SNDL20:9hAP<0XGM500P0X7I409mf@P2QN4@0XgY60:AkA`2UO4P0Y7]70:=jAP<0
XWU50P2SNTH0102TNdL0YGa80:ElB02UO4P30:AkA@80YGa60`2VODL20:ElB0040:ElAP2UO4@0YGe2
0:Em@P80YGe000/0YWi10:In@`2VODD0YWe70:IlBP2VO4`0YW]>0:IkD02^P4h0[Gm=0:]mB`030:Uk
B@80Zge;202YP4`20:UoC@030:Z1C@2ZPD/0Zh9:0080Zh=800<0Zh=60:^2C02[PT`00P2ZPD/30:V0
BP070:QoB@2UO4@0YWe50:MnB02XOd/0ZH1<0:Z0CP020:^1D@080:QoB`2YP4`0Zh9>0:f4D02^QE40
[HA@0:b3C`2[PTh20:f2C@<0Zh1;00<0[H9=0:n4C`2`QE00202^QE420:^2CPH0[8=?0P2_QU00102^
QDl0[XEA0:f3D@2]Pe<20:b1E0030:^0E@2^QE40[XEA00H0[XEA00H0Zh9:0:b3B`2]Q4`0[XE=0:n6
CP2`Qdl20;68D0P0[XEA102/Qe840:f8D`80/HQD0P2`Qe<20:n6DP80[XEA0`2`Qe<00`2_QU80[XEA
0:j5D@020:f4D0P0[hIB4P2`Qe<20;68E0@0/XUE00<0/8MA0;68DP2cRU@00P2dReD00`2cRU@0/HQB
0;27D@020;:9E@<0/HQD0`2`Qe<80;68DP030;27D`2aR5@0/hYF0080]8]G00H0/hYF0;68E02`Qe<0
]8YJ0;>9F@2aQeD20;27D`030;68DP2cRU80]8]C00<0/HQD0P2bRED30;>:EPP0[hYF0`2`Qe420;68
DP<0/XUC00@0]8]C0;>:DP2cRU80/XUC0P2bRED00`2dRUP0]XaL0;N=G@020;:9E@<0/hYF0`2dReL0
0`2/Qe<0[HQD0:f8E0020:j9E@80[hYF00<0/8]G0;:=F02bSEP00P2aS5L0102`ReH0[hYE0:n:E@2_
RUD80;:=F@080:f<E`2^SEP0/HeI0;>>FP2dS5T0]8YH0;:8EP2bQUD20;:9D@060;27D@2`Qe<0/HQD
0;:8EP2dRUX0]XaL0`2`ReL20:n:EP<0[XUE00/0[hIB0;27D`2aR5@0/XUE0;68E02`Qe<0[XEA0:f4
D02_Q4l0[X=>0:b1C0020:^0B`030:b1C02^Pdh0[hA?00P0[H=A00H0Zh9>0:b3C`2]Q500[XEA0:n6
DP2`Qe<20;68E0P0[HA>0P2]Q5000`2/Pdl0Zh9>0:Z1C@030:V0C0030:^2CP2/Pdl0[8=?0080[HA@
0P2^QE402@2_QU80/8ID0;26E02_QE<0[XAB0:f3D@2/PU00Zh5?0:Z0CP030:^2CPD0[8=?00P0/HQD
0;27D`2_QU80[hIB0:j5D@2]Q500[8=?0:^2CP<0[XEA0P2]Q5030:b3C`/0Zh9>5P2/Pdl80:f4D080
[8=?0P2[PTh40:Z1C@P0Zh9>202/Pdd01@2^Pdh0[H9=0:f2C@2/PD`0Zh1;0080ZWm:00@0ZGi90:^2
CP2[PTh0Zh9>0`2/Pdl20:f4D0P0[85<202/Pdl20:V0C080ZX5=00@0Zh9>0:b3C`2/Pdl0[8=?0P2/
Pdd20:^2C080ZX5;0P2YP4X30:^2CP<0[8=?0P2]Q5001P2^QE40[HA@0:b3C`2[PTh0ZX5=0:V0C080
Z7m;202WOD<30:Z1B@<0ZH180P2XOdL30:QoB`050:V0C02ZPDd0ZX5=0:Z1C@2[PTh00P2/PU830:^1
D@80ZX1@0P2YOdl80:^2CPP0Z7m9202YOdl0202VODL0Z7m90:Z1B`2[PT`0[8==0:^2C02ZPD/0ZH1:
0P2]Q4`30:b3B`<0Zh9:202[PT`20:f2B`040:b1C02/PDh0Zh1=0:]oCP80ZWi?00H0[85F0:b1E02/
PE@0[89B0:b2D02/Pdl20:b3C@<0Z7m;00<0ZH1<0:Z1C@2ZPDd00P2[PTh90:V0BP070:Z1B`2[PT`0
[8==0:b3C@2[PT`0ZX5;0:V0BP020:f2C`80[85>00@0Zh1=0:YoC02ZOd`0ZWm<202YOdd20:Z0D004
0:Z0CP2YP4`0ZH1<0:V0BP80Z7m70P2WOTP40:QoB@80ZH1:00<0YGa60:ImA`2XOdT00P2ZPD/00`2Y
P4X0Z7m90:MnB0020:QoB`<0Ygi:0`2VODT00`2VODL0Ygi80:V0BP020:Z1B`030:QoB@2WOTP0YWe7
00@0YW]61@2UNTD00`2TNdL0YGa80:MnBP020:V0C0030:QoB`2WOTX0YWe900P0Y7]70P2UNd/20:Il
C0040:MmC@2XOTh0Z7i>0:QnCPP0YWe700<0XGM70:=iB@2VO4X00P2XOd/02`2VODL0XgY20:5h@02T
PD/0YH1;0:AoBP2VOTX0YWe90:MlB@2YNdT0Z7Y800P0YGY700H0XWQ80:=iB@2SNDL0XgY60:AkA`2T
NdD30:ElA0030:Ak@`2SNT80XgY200@0XWU100<0XWU50:=jAP2TNdL00P2UO4P00`2SNTH0XGQ40:1g
@`020:1g@`060:5hA02RNDD0XGQ409mf@P2NMD40W7<o0P2QN4@0102RNDD0XgY60:=jAP2TNdL20:El
B0<0XgQ500<0XWM40:5f@`2QMT<00P2PMD820:9i@`040:=jA02TNdD0YGa60:ImA`80Ygi800H0Y7U>
0:AiC02TND`0XgU90:=iA`2SNTH20:9i@`@0XGI3102RMd@80:1kAP030:9i@@2SNT80Y7]30080YGa4
00<0XgY20:5h@02PMcl02@2SNTH00`2UNDP0Y7Q70:=gAP020:5eA0030:=gAP2TN4L0YGU80080YWQ6
00<0Y7U60:AkA`2SNdL00P2RODP00`2QOTP0VWU409YiA00209Uh@`80V7M20P2GMT401P2KN480W7M2
09ag@P2NMT80WgI20:1e@P80XWA200<0X7I409me@`2MLd400P2LLT001P2MLd40WgE30:1fA02OMD<0
WWA209ec@@80W79000<0WWA20:1fA02QMdD00P2OLd8309ib@@<0WG50202MM3h209ec@`0409ab@02L
Lcl0Vg8n09]b?080VW4i0P2MLd4309id@P0309ab@02KLCl0VW0n00<0VFlm00<0VW0n09]a?`2KLCl0
0P2LLT0309M]>`80V6hl0`2IKcd00`2JKd80VFi109U^@@0209Q]@080Uf`o00@0UV/n09U_?@2HKS`0
UV`j0`2DJSP03@2EJcT0UV`j09EZ@02GK480VFi309Y_@P2KLD40VW0n09U_?@2HKc/0Ug8n09E`?02D
Kc/00`2BKCT0202CKSX0U6lk09U^@@2IKT40V6e009I[?P2EJSd0TfPk0P2BIcX2099/?@0309=]?P2D
KSl0UFm00080UW1100@0Ug5209Q^?02GKC/0UV`j0P2EJcT0102FK3X0Ufdk09M]>`2HKS`409M/?`@0
UV/n202AJc`3099W>P80TfPk0`2DJC`209=X>`<0U6Tl00<0TfPk095V>@2@ICP0202>J3T809=]?P<0
TV`m00<0Tfdn09A^?`2DKSl00P2EKd02099/?`03095[?P2@JSd0SfTl0080SVPk00<0SFLj08eX?P2=
J3h01P2=J3h3091Z?B_ooooo000Zooooo`P0QUlh2026GcH02029GCH0R5`e08MK=027Fc@0R5`e08UM
=P2:GSL0Relh0`29GCH208YN=`<0Relh0P26GcH00`27H3L0R64h08UR>@0208YS>P0408]T>`29HcH0
RF<f08QR=@80Qf4d00<0R68e08US=P2:I3L00P2;H3D208aQ=P80SF8g0P2>HcP0202>HSD0SF4d08eQ
=02=HC@0SV8e091T=`2AICP0TVHi0`2=H3H208iQ=`<0Sf8h0P2=HSD208iS=P@0Sf@g00@0T6Dh091T
=`2AICP0TfLj0P2DJ3/00`2CIcX0TFDh091T=`02099V>@<0TfLj0`2DJ3/309=W>P<0U6Pk0P2EJC`0
202CJS`0TVTk099W>P2BIST0U6Di09IU>P2GIS/0VVLl0`2CJ3/209AY?0<0UFXm202DJC`209AX>`80
TfLj00X0U6Pk09IZ?@2GJch0VFe009EX?P2EJC`0UVXm09IZ>`2FJST0Uf`i0P2GK3L209Q]>00309Q]
>P2GJcX0Uf/l0080UVXm00@0UVTo09I[?P2FJch0UV/n0`2EJSd209AY?00409U]?02HK3/0V6`k09Q/
>`<0Uf/j00T0UVXi09EX?P2FJSd0Uf/n09U]?P2IKC`0VFhk09Q]>02GK3L00`2GKC/309Q^?080VFlm
0P2KKd00102KKch0W74n09aa?P2MLSd209eb>`<0VW0n0`2KLCl209ab@080X70o0`2OKch309i^?@0@
09ic@02MLSl0Vg0m09Y_?02IKS/0VVll09]`?@2LLCh0VFdl09Y^?@2KKch0W70o09ea@02NLT40Wg=2
0:1d@`80WWA20`2MLd4409ab@0P0WG8o0`2MLSd309ic?P80Wg@o00h0XgA00:Ae@@2UMT80YWM30:Ef
@P2TMD40XW<o0:5b?P2ULch0Xg@n0:=d@02RM480X7E209me@`80WWI500<0X7E20:5f@`2RMd@00P2S
N4D00`2RMd@0XGI30:1e@P020:AhA`<0XgM60`2RMTD01P2OM440XGI30:=hA@2UNTL0YW]80:EjA`80
Y7U60`2YNDP30:QhA`80YgM600<0YGU80:AhA`2SMdH00P2SMdH0202UNDP0YWY90:QlB`2XODP0Yga7
0:IkAP2UNTD0Y7U40P2UNTD00`2VNdH0YGY50:EjA@020:IkAP80Yga70P2XODP00`2WO4L0Z7e80:Qm
B0050:QmB080YW]80P2WO4T0102XODX0ZGi;0:YoC02ZOd`80:QoB`<0ZH1<0P2XOd/30:MnBP080:b3
C@2[PT`0ZH1:0:QoB@2WOTP0Z7m90:V0BP2ZPD/30:QmBP80ZGi;0`2ZOd`80:^2CP80[8=?0P2[PTh2
0:Z1C@<0ZH1<102[P4/40:b1C0P0[H9?202/PDh30:YoC080Zh1=0`2/PDh01P2/PTH0[8980:b2B02/
PDX0[85<0:b1CP80[81?202[PTh0102YP4`0ZX5=0:Z1C@2ZPDd30:^2CP040:b3C`2[PTh0Zh9>0:^2
CP80ZX5=0`2YP4`20:QmAP060:UnB@2ZOd`0Zh1=0:b0C`2/P540[H5B0`2XPdl20:V4D0<0ZXEA202Z
QE080:^2CP<0ZX5;0`2YP4X20:QoB@<0ZWm:0P2YOTT30:QmB0030:UnB`2XODX0Z7e:0080Yga91@2V
NdP20:MlB@050:IkB02TNDH0XWM40:5f@`2QN4@00P2RNDD01@2SNTH0XWU50:5hA02PMd<0WgI20080
XWM400@0XgQ50:AiAP2TNDH0XgQ50P2RMd@00`2UNTL0Y7U60:9gA0020:5f@`070:9gA02TNDH0YGY7
0:EjA`2RNDD0XGQ40:1g@`0209mf@P030:1g@`2QN4@0XWU500P0WgI200H0W7<o09ed@02MM400WWE1
09mf@P2PMd<20:5hA0040:ElB02TNdL0XgY60:9iA@80XGQ400<0XWU50:=jAP2RN4H00P2RN4H20:5g
A@<0X7I400<0WgI20:1g@`2RNDD00`2SNTH40:9iA@<0XgY60`2TNdL20:=jA080Y7]50`2UO4H01P2V
ODL0XWQ60:=iA`2SNTH0Y7]50:ElA080YWi300<0Ygm20:MoA02WOTH00P2WOTP20:MmB`050:MmC@2W
O4l0Zh1=0:YoC02YOT/00`2WO4T20:QmBPP0ZH1<0P2YOdd00`2YP4`0ZX5;0:Z1B@020:^3B0030:^3
AP2/Pdd0[8==0080Zh9<0`2ZPD/01`2YP4X0YWe50:MnAP2WOTP0Z7m;0:V0C02ZP4h00P2[PE401@2Y
P4`0ZX5=0:^2CP2/Pdl0[HA@0080[8=?00T0Zh9>0:f2C@2/PD`0[85<0:^0B`2/PD`0[H9=0:j3CP2_
Q4l0202^QE480:b3C`<0[XE?00<0[XEA0:f3D@2]Pe<00P2/PE@00`2/PEH0[XEA0:j5D@060:j5D@80
[8==00<0[HA>0:j5C`2_QU000P2`Qe400`2aR580[XEA0:j5D@060:j5D@050:Z5D02[QU40ZhIA0:b7
DP2]R5<00P2^RE@00`2_RUD0/HQD0;27D`020;27D`<0[hIB00@0[XEA0;68E02aR5@0/HQD0`2`Qe<2
0:n6DQP0/8MC0P2^QE420:n6DP<0/8MC00@0/HQD0;27D@2aR580/XUC0P2cRU@00`2bRE<0/HQB0;27
D@020;:9E@<0/HQD0`2`Qe<80;68DP030;27D`2aR5@0/XUE0080/hYF00<0/XUE0;68E02`Qe<00P2c
RET0102aQeD0/HQD0;68E02aR5820;>:DP<0/HQD0P2bRED30;>:EPP0[hYF0P2`Qe420;68DP<0/XUC
00D0/hYD0;>:DP2bRE40/XUA0;68DP020;27D`030;:8EP2dRUX0]H]K00<0]8]G0`2cRUH20;:9E@80
[HQD0P2^RED40:n:EP<0/HaG0`2`ReH20:n:E@P0/XeI0100[hiI0;2?FP2bSUX0]8mK0;F=FP2eReT0
]8YH0;B8E`2cRU80/XUA0;68DP2aR5@0/XUE0;>9E`2dRUX0]H]K0`2^RED20:n:EP<0/8]G00<0[hIB
0;27D`2aR5@00P2bRED01P2`Qe<0[XEA0:f4D02_Q4l0[X=>0:f2C@80[85<00@0[H9=0:j3CP2_Q4l0
Zh5?0P2/PU001@2]Pe40[XAB0:n5D`2_QE<0/8ID0080[8=?00<0[HA@0:j5D@2_QU800P2`Qe<00`2a
R5@0[HA>0:f4CP060:f4CPP0Zh9>0`2/Pdl20:f4D0<0[XEA00H0/HME0;26E02`QU@0[hEC0:j4DP2]
Pe420:b2D0030:f4D02/Pdl0[8=?0080[8=?0`2[PTh;0:j5D@80[HA@0`2/Pdl90:^2CR<0[8=?0P2[
PTh30:Z1C@P0Zh9>202/Pdd40:b1C0@0Zh1;0`2[PTh30:b3C`80[HA@202/PD`80:b3C`<0ZX5=0P2[
PTh30:b3C`80[8==0P2[PT`20:Z1B`80ZH1:0`2[PTh30:b3C`80[HA@0P2^QE40102]Q500[8=?0:^2
CP2[PTh20:Z1C@P0ZX160P2XOdT30:V0BP<0ZX5;0`2ZPDd30:V0C080Z7m;00<0[89@0:^1C`2[PDl0
0P2[PDl30:Z0CP030:UoC@2[PTh0Zh9>00H0Zh9>202YP4X80:Z0CP030:MnB02XOdT0ZX5;00<0Zh9<
0P2ZPD/30:^2C0<0[8==2P2]Q4h02@2]PT/0[85:0:b1C02/PDh0Zh1=0:]oCP2[Oe00ZWi?0:^0E@02
0:^0D`030:^1D@2[PDl0Zh9>0080Zh9<0P2XOd/30:V0C0<0ZX5=2@2YP4X01`2ZPD/0Zh9<0:b3C@2/
Pdd0Zh9<0:Z1B`2YP4X00`2/PDh20:^0C@<0ZWm<202YOdd20:Z0D0040:Z0CP2YP4`0ZH1<0:V0BP80
Z7m70P2VODL0102WOTP0Z7m90:QoB@2YP4X20:Z1B`80YWe700<0Z7m90:V0BP2ZPD/00P2YP4X00`2X
OdT0Z7m;0:QoB`030:MnBP<0YWe900P0Z7m90:V0BP2YP4X0ZX5;0:V0BP2WOTP0YGa60:=jA0T0YW]6
00<0XgY60:AkA`2VODT01@2XOd/80:ElB0<0YWa:0`2WOD/20:QnC0P0YWe700<0XgU90:AjBP2WOD/0
0P2YP4`0102WOTP0Y7]30:=j@P2SP4X20:AoBP030:EmB@2VODT0YW]80080Z7Y8202UNTL02`2WODd0
YWa<0:IlBP2VODT0YGa80:ElAP2UO4@0Y7]30:MnB02UO4H0XWU30080X7M100H0XGQ20:=jA02UO4H0
XWU50:=jAP2TNdL20:ElB0050:=jAP2QN4@0X7M30:1g@`2QN4@00`2RNDD00`2QN4@0WgI209ed@008
0:=jAP<0XgQ50P2RMd@30:5f@`060:9i@`2SNT@0XgY40:AkA@2UO4H0YWe70P2WOTP0202UNTl0YGY=
0:AiC02TNTX0XgU70:=jAP2SNT@0XWU3102RMd@40:5f@`P0X7]600<0XWU30:=jA02TNdD00P2UO4H0
0`2SNT@0XGQ20:1g@@090:=jAP030:MkBP2UNDP0Y7Q70080XgM600<0Y7Q70:EiB02WNdX00P2XNTP0
0`2UNTL0Y7]70:9jAP020:1kAP0409mlAP2MNDD0WGU509eiA@80W7Q40`2KMd<01P2KN480W7M209ag
@P2NMT80WgI20:1e@P80XWA200<0X7I409me@`2MLd400P2LLT001P2MLd40WgE30:1fA02OMD<0WWA2
09ec@@80W79000<0WWA20:1fA02QMdD00P2OLd8309ib@@<0WG50202MM40209ec@`0409ab@02LLcl0
Vg8n09]b?080VW4i00<0WgE309id@P2LLT000`2KLCl209ab@080VFlm0`2JL3h309]a?`@0VFlm0`2H
KS`00`2GKC/0VFi109U^@@0209U^@@80V6e00P2GK3l0602IKcd0V6hl09I/>P2EJcT0U6Xh09E[>@2F
K3X0Ufdk09EZ@02FJd40Ufa109U^@@2IKcl0VFlm09Q^?02GKSX0UW4m09E`?02CKSX0TVdi095/>02B
KCT0Tfhj09A_>`<0UV/n0P2EJSd309AY?0P0Tfdn00<0UV`j09M]>`2HKS`00`2HKS`209M]>`0309I/
>P2FJch0UV/n0080UV/n102GK3l8099/?@80TVLj0P2CJ3/309AY?080UFXm00@0U6Tl09=X>`2BIcX0
TFHi0P2BIcX00`2CJ3/0SVPi08iX>@0608iX>@P0TF/l0`2BK3d209=]?P<0U6ho0P2BK3l00`2AJch0
T6Xm08mY?00208iX>`0308eW>P2<Icd0S6Lm00H0S6Lm0`2@JSd[ooooo`00:_ooool808IO>0P0QUlf
1027Fc@208QL=@0308UM=P2:GSL0REdf0080REdf0P2:GSL308]O>0<0Qf0g00<0R64h08UR>@29HST0
0P2:HcX508QR=@80RF<f00<0RV@g08]P=@2;H3D00P2<HCH208eR=`80SV<h0`2=HC@01@2>HSD0Sf<f
091T=`2AICP0TVHi00@0SV4g102?HSP308iS=P@0Sf@g0P2@ICP00`2@I3L0TFDh099V>@0209=W>P03
099V>@2AICP0T6@g0080TfLj0P2DJ3/409EY?0<0TfLj0`2DJ3/209EY?080TVTk00<0TfPk09=W>P2E
ISX00P2GIS/0102IIS/0TfPk09=X>`2CJ3/209AY?0<0UFXm0P2CJ3/409AY?080UFXm102DJ3/01@2E
JC`0UVXm09M[?P2GJch0UVTo0080UVXm00<0UVXk09IZ>@2FJcP00P2GK3L209Q]>00609Q]>P2GJcX0
Uf/l09M[?P2FJSd0UVTo0`2FJch309EZ?@80U6Tl102HK3/409M[>P0609IY?`2FJSd0Uf/n09Q/?@2H
K3/0V6dj0P2HKCP209M]>`H0V6hl0P2NLT<0102MLD00WG8o09eb?`2MLSd209aa>P0509Q^?02IKcd0
VFlm09Y`?P2KLCl00P2LLT000`2MLd40Wfln09m_?P0409m_?P80X70o00@0WgA109ic@02LLCh0VVll
0P2IKS/0202JKc`0Vg0m09Y^?@2JKSd0Vfln09a`?`2MLD00WW910P2OLd8209id@P<0WG=1102LLT08
09ic@00609]`>`2LLC`0W74l09eb?@2NLch0Wg@o0P2PMD000`2TMD40YGI20:Ig@`020:Ig@`090:Ae
@@2RLcl0XG8n0:Ec?P2SM3h0XgA00:9d@P2PMD80WgE30080WWI50P2QMT<40:9gA080XGI30P2TN4L3
0:=gAP<0XWI500@0WW=00:1e@P2SN4D0YGY70`2VNdP00`2UNTL0ZGU80:UiB0060:QhA`030:IjB@2U
NDP0Y7Q70080XgM600@0YGU80:MkBP2XO4/0Z7e80P2WO4L20:IkAPD0YGY50P2VNdH20:MlA`80Z7e8
0P2YOTT30:QmB0<0Yga700H0Y7U60:EjA`2VNdP0Yga90:QmBP2ZOd`20:^0CA00Z7m;00<0[HA>0:b3
C@2ZPD/00P2YP4X00`2ZPD/0Zh9<0:b3C@080:UnB`P0Zh9>0P2/Pdl20:^2CP80ZX5=0`2YP4`40:^0
B`@0[85<402]PTl20:YoC0<0Zh1=0`2/PDh20:b4B@040:b3B`2/Pdd0[8=?0:b2D080[89B202[PTh4
0:Z1C@H0Zh9>0P2ZPDd20:V0C080Z7m;0P2XODH0102YOTT0ZGi;0:YoC02ZOTd20:]oD0<0Yh9>0P2X
Pdl30:V4D0P0ZHA?202[PTh30:Z1B`<0ZH1:0P2XOdT20:^0B`<0ZWm:0`2YOTT0102YOT/0Z7e:0:Qm
BP2WO4T20:IkB080YGY70`2VNdP00`2UNTL0XgQ50:9gA0020:1e@P80WgI20`2PMd<209mf@P0309ie
@@2RMd@0XWM400L0XWM400H0XGI30:1e@P2OM440WgA10:1e@P2QMT<20:9gA0<0X7M30P2OMT830:1g
@`P0WWE10`2MM4000`2NMD40WgI209mf@P020:1g@`030:AkA`2SNTH0XgY600<0XWU50P2SNTH20:9h
AP<0XGM50`2PMT@0102OMT80X7M30:1g@`2QN4@:0:9iA@80XgY60P2RND<20:=jA0<0Y7]500T0YGa6
0:1fAP2QMdL0XWQ60:=jAP2TNdD0YGa40:In@`2WOd@00`2XOdT20:QoB`<0Z7i<00@0ZH1<0:QoB`2X
Od/0Ygi:102VODT80:QoB`80Z7i<00H0ZH1<0:V0BP2ZPDT0ZX970:^3B02[PdH40:b3C@80Zh9<0P2Z
PD/00`2WOTH0Z7m70:QoB@020:V0C0030:Z0CP2ZP500Zh5A0080ZX5=1P2[PTh40:b1C080[H9=0P2^
Pdh90:f4D0@0[8=?0`2[PTh30:f4CP030:f4D02]Pe40[H=C0080[H9E00<0[H9G0:f4D02]Q5002@2]
Q5000`2^QE40[hIB0:n6DP020;27D`P0[XEA00P0ZHA?0:Z5D02[QU40[8MB0:f8D`2^RE@0[hYE0;2;
EP@0/8MC102_QU830;:9E@d0/HQD402`Qe<30:f4D080[XEA0`2_QU880;68DP80/XUE0`2aR5@30;27
D`P0/HQB202aR5@20;:8F0040;:8EP2bRED0/XUE0;:9D`80/XUA0`2aR5@20;:9E@<0/hYF202aREH3
0;68DP<0/XUC0P2cRU@0102bRE40/HQ@0;68D02_QU020:n6DP040;26E02bR5P0/hUI0;J=F@80]HaH
00<0]8]G0;>:EP2bRED00P2aR5@20:j9E@H0[hYF0P2aS5L60;2;EPP0/XeI0P2aT5/01P2cSe/0]8mK
0;F=FP2fS5X0]H]I0;J:F@80/hYB00@0/hYD0;:9E@2cRUH0/hUG0P2dRUX20:f8E0040:j9E@2_RUH0
[hYF0;2;E`80/HaH00P0/8MC0;68E02bRED0/hYF0;:9E@2aR5@0[hIB0:f4D0<0[X=>0P2]PTd30:j3
CP80Zh5?00@0[89@0:f3D@2_QE<0/8ID0P2aQeD30:f4D0030:j5D@2_QU80[hIB0080/8MC202]Q4h0
102ZPDd0Zh9>0:^2CP2[PTh30:b3C`T0[HA@00<0/HME0;26E02`QU@00P2_QE<20:j4DP050:f3D@2]
Q500[HA@0:f4D02/Pdl00`2[PTh01@2ZPDd0Zh9>0:b3C`2/Pdl0[HA@0080[XEA0P2_QU830:j5D@80
[HA@0`2/Pdl90:^2CP030:f4D02/Pdl0[8=?0080[8=?0`2[PThH0:b3C`80[HA@0P2/Pdl20:^2CP80
ZX5=202/Pdl80:b3C@040:YoBP2[P4/0Zh1;0:^0B`<0[85<00@0[H9=0:^2CP2[PTh0Zh9>0`2/Pdl2
0:f4D0P0[85<202/Pdl40:^2CP@0[8=?0P2/Pdd20:^2C080ZX5;0P2YP4X30:^2CP<0[8=?0P2]Q502
0:j5D@80[HA@0P2/Pdl20:^2CPP0[85:0P2WOTX00`2XOd/0ZH1<0:Z1C@020:^2CP<0[8=?00H0Zh9>
0:Z1C@2YP4`0Z7m;0:MnBP2VODT50:^2CP@0ZX5=202[PTh80:V0BPP0ZX5=0P2YP4X20:Z1B`@0Zh9<
00H0ZH1<0:Z1C@2ZPDd0Zh9>0:b3C`2]Q5020:j5D@P0[XE?0P2/PDX0102/PD`0[85>0:^0C@2[Odh2
0:]oD0060:^0E@2[P5<0Zh1C0:^1D@2[PDl0Zh9>0P2[PT`60:V0C080ZX5=202YP4X20:Z1B`@0Zh9<
0P2ZPD/40:^0C@@0ZWm<202YOdd20:Z0D0040:Z0CP2YP4`0ZH1<0:V0BP80Z7m700@0YGa60:ImA`2W
OTP0Ygi80P2YP4X00`2ZPD/0Zh9<0:ImA`020:MnB0030:QoB@2YP4X0ZH1:0080ZH1:0P2XOd/30:Mn
BP<0YWe90P2YP4X01`2ZPD/0ZH1:0:QoB@2VODL0XgY40:9i@`2UNTD01@2VNdH30:MlA`80Y7]700@0
YGa80:MnBP2XOd/0Z7m;0P2YP4`80:ElB080YWe91P2WOTX80:ImA`030:AjBP2UNd/0Yge;0080ZH1<
00T0Ygi80:ElA02TNd<0Xh1:0:AoBP2SOTT0YGe90:ImB@2VNdP00P2XNTP80:EjA`80ZX1@00@0ZGm=
0:QoB`2VODT0YGa60P2TNd<00`2YP4`0YWe90:9iA@0209ie@@060:1g@`2TNdL0Ygi:0:9iA@2SNTH0
Y7]70P2UO4P01P2SNTH0XGQ40:1g@`2PMd<0XGQ40:9iA@80XgY600<0XWU50:1g@`2OMT800`2TNdL2
0:=jAP<0XWU5102SN4D40:9gA080XgY400<0Y7]50:ElAP2VODL00P2WOTP01`2XOdT0YGY?0:EjC@2U
NTd0Y7Y:0:AjB02SNTH00P2SNT@40:9gA0@0XGI3202PNdH00`2RNDD0XgY60:AkA`020:ElB0030:=j
AP2QN4@0X7M300T0XgY600<0Z7a;0:MkBP2UNDP00P2TN4L00`2UNDP0Yg]:0:QlB`020:UkB@060:Ik
B02TNdL0XWY609mjA@2NND@0W7U30`2ONTH209iiA@<0WGQ400H0VgQ209ag@P2LMd80WWI209mf@P2P
MD820:9d@P030:1fA02OMD<0WG=10080W79000H0WG=109me@`2PMT@0WgE309id@P2MLd4209ab@003
09id@P2PMT@0XGM50080Wg=20`2NLT4309ea@0P0WG=10P2MLd<0102LLT00W7<o09]b?P2KLS`209Ya
>@030:1fA02NM480Vg4o0080VFlm00<0VW0n09ab@02NM4801P2JL3h409]a?`0309Y`?P2IKcd0V6hl
0080Ufdk00<0UV`j09U^@@2IKT40102IKT4209Q]@00809U_?@2HKS`0Ufdk09I/>P2EJcT0UV`j09Q^
?02IKcd209I[@@0309M/@@2GK3l0Ufdm0080Ufdk00T0Ufhj09Ia?@2EL3`0Tfhj099]>@2AK3P0TVdi
09=^>P2DKc/01@2EJSd309I[?P0409A^?`2CKCh0Tfdn099/?@80TF/l0P2@JS/00`2EJcT0UV`j09U_
?@0209Y`?P0509U_?@2FK3X0UV`j09E[>@2DJC`00P2EJSd01@2FJch0Uf`o09Q]@02HKD00VFi100P0
TV`m0`2CJ3/309AY?080UFXm00<0Uf`o09EZ?@2BIcX00P2@ICP00`2AIST0TfPk09EZ?@0@08mY>P@0
TV`m102CKCh2099/?`03095[?P2@JSd0SfTl0080SVPk00<0SFLj08YU>`2:IC/01P2:IC/3091Z?B_o
oooo000Zooooo`P0QUlh2026GcH208MK=00308QL=@29GCH0REdf00H0REdf0P2:GSL308]O>00308MP
=`28HCP0R64h0080R64h0`29HST01026H3<0Qf4d08QR=@28HSD408US=P80Rf0e0P2<HCH208eR=`80
SV<h00@0S60c08eQ=02>HSD0Sf<f0P2@I3L2095U>0P0Sf8h0P2>HcH408mT=`<0T6Dh00<0Sf<f091T
=`2BIST00P2CIcX00`2BIST0T6@g08mS=P0209=W>P80U6Pk102EJC`309=W>P<0U6Pk0P2EJC`01@2A
J3X0TVTk09=X>`2DJ3/0UVLk0080UfHk00@0V6Dj09=X>`2CJ3/0TfPk0P2DJC`309EZ?@03099W>P2C
J3/0TfPk0080U6Tl0P2EJSd00`2FJch0U6Pk09AX>`0209EY?0<0UVXm00L0UFTl09MZ@02GJch0UVXm
09IZ>`2FJST0UV/h0080UV/f0P2IKST00`2HKCX0V6`k09Q/?@0209M[?P0409MZ@02FJch0UV/n09I[
?P<0UFXm0P2DJC`409M[>P@0V6`k00H0UfY009M[?P2GJch0Uf/l09M[>P2HKCX209U^>@H0V6hl0P2G
KC/209ib@`0409ib@@2MLSl0WG8o09aa?080W74j0P2HKS`0102IKcd0VW0n09Y`?P2KLCl209ab@080
WVhm0P2OKch0202PL3l0XG500:5a@02RLT40WgA109ic@02LLCh0VVll0P2IKS/00`2JKc`0Vg0m09Y^
?@0209]_?P0509a`?`2MLD00WW9109ib@@2OLd800P2NM48309ec@@@0W790202NLd001P2KL3/0W74l
09aa?02MLSd0WW<n09md?`80X7E000h0Y7E10:Ef@P2VMd<0YgQ40:Ig@`2UMT80XgA00:9c?`2VM3l0
Y7Do0:Ae@@2SMD<0XGI30:1fA080WgM60P2RMd@40:5f@`80XWM40P2TN4L30:=gAP<0XWI500@0WgA1
0:5f@`2SN4D0YGY70P2WO4T20:IkB0H0Z7Q70P2YNDP0202VNTT0YGU80:AhA`2SMdH0Y7Q70:EiB02W
NdX0ZGe<0`2XODP20:MlA`80YW]60`2UNTD20:IkAP80Yga70P2XODP20:UnB@<0Z7e80`2WO4L01P2T
NDH0YGY70:IkB02WO4T0Z7e:0:YoC080Zh1=402XOd/0202]Q4h0[8==0:Z1B`2YP4X0ZX5;0:^2C02/
Pdd0[HA>202YOT/80:Z1C@80[8=?0P2[PTh20:Z1C@<0ZH1<0P2ZOdX20:^0B`80[85<0P2]PTd@0:f2
C`<0Zh1=0`2/PDh20:f2C`80ZhA;00@0ZhA=0:^3C`2[Pe00Zh=B0P2[PU@<0:^2CPL0ZX5=0P2YP4`3
0:QoB`80Z7e600@0Z7e80:QmBP2YOT/0ZGe<0P2YODh30:J1C@80Yh9>0`2XPdl80:R3CPP0ZX5=0`2Z
PD/30:V0BP80Z7m900@0Zh1;0:YoBP2ZOdX0ZWm:0P2YOTT20:QmB080ZGi;00`0Z7e:0:MlB@2VNdP0
YGY70:AiAP2SN4D0YW]80:EjA`2TNDH0XWM40:5f@`2PMD8209md@@H0WWE10P2OMT890:5f@`060:1e
@P2NLd00WG8o09eb?`2NLd00X7E20P2QMT<00`2NMD40WgI209mf@P0409mf@PT0WWE10`2MM40409ie
@@0309mf@P2QN4@0XGQ400H0XWU50`2QMdD30:1fA080WgE3102OMT800`2PMd<0XGQ40:5hA0040:9i
A@D0XGQ400@0XGQ20:9i@`2RND<0XWU30P2SNT@20:AkA@0809mdA`2PMDP0XGM70:9hAP2SNTH0Y7]5
0:ElA02VODD30:MmB`80Ygi:0`2WOTP50:InBP030:EmB@2TO4P0Y7a800P0Z7m;0P2XOT`00`2XOd/0
ZH1:0:V0B0020:Z2A`040:Z2A@2/Pdd0[8==0:b3C@80Zh9<0`2ZPD/20:V0B0040:V0BP2YP4`0ZX5=
0:Z0CP80ZX1@0P2[PTh60:Z1C@030:^0B`2/PD`0[85<0080[H9=0`2^Pdh;0:f4D0030:b3C`2[PTh0
Zh9>0080ZX5=0`2]Q4h00`2]Q500[H=A0:f3D`020:f2E@030:f2E`2]Q500[HA@00L0[HA@102^QE43
0:n6DPP0[XEA00P0ZHA?0:Z5D02[QU40[8MB0:f8D`2^RE@0[hYE0;2;EP@0[hIB102`Qe<50;68E0<0
/XUE202aR5@@0;27D`80[8=?0P2]Q5030:j5D@030:n6DP2aR580/HQB00@0/8MA0P2aR5820;:9E@<0
/HQD0`2`Qe<80;68DP80/HQD102`Qe<20;68E080/XQH00@0/XQF0;:9E@2bRED0/XUC0P2bRE430;68
E080/XUE0`2cRUH80;:8EP80/HQB0`2bRE<30;>:E0040;:9D@2aR500/HQ@0:n6D080[XEA00@0[hEC
0;26EP2aQeL0]XeI0P2eS5P00`2dReL0/hYF0;:9E@020;68E080/8]G1P2_RUH60;2;EP80/HaG202b
SET01@2bTE`0/I1K0;>?F`2cSUX0]HeJ0080]H]I00@0]h]J0;>:DP2dRe<0]8]E0P2dReL00`2cREL0
/hUI0;>9F@020:f8E0040:j9E@2_RUH0[hYF0;2;E`80/HaH00<0/8MC0;68E02bRED00P2cRUH00`2a
R5@0[hIB0:j5D@030:j3CP80[hA?0`2^Pdh02@2[PDl0[89@0:f3D@2^Q580[hEC0;26E02aQeD0/XQF
0:f4D0040:j5D@<0[hIB202]Q4h30:^2CP80[8=?2`2]Q5040:n5D`@0[XAB1@2/Pdl30:^2CP060:Z1
C@2[PTh0Zh9>0:b3C`2]Q500[XEA0P2_QU830:j5D@80[HA@0`2/Pdl90:^2CP<0[HA@00<0[8=?0:^2
CP2[PTh00P2ZPDdH0:b3C`<0[HA@0P2/Pdl30:^2CPP0[8=?202/Pdd0102ZOdX0Zh1;0:^0B`2[P4/3
0:b1C0040:f2C@2[PTh0Zh9>0:^2CP<0[8=?0P2]Q5080:b1C100[8=?0P2/Pdd20:^2C080ZX5;0P2Y
P4X30:^2CP<0[8=?1@2]Q5030:b3C`80Zh9>202]PTd20:MnBP030:QoB`2YP4`0ZX5=0080Zh9>00T0
[8=?0:f4D02]Q500Zh9>0:Z1C@2XOd/0Ygi:0:ImB@2UO4P01@2ZPDd<0:^2CPP0ZX5;202[PTh40:Z1
B`80Zh9<0P2/Pdd01P2YP4`0ZX5=0:Z1C@2[PTh0[8=?0:f4D080[XEA202^QDl20:^0B@040:^0B`2[
P4d0[85>0:b0C`80[81A00H0ZWmD0:YoDP2ZOe80ZX1@0:Z0CP2ZPDd20:Z1B`80ZX5=1P2YP4`80:V0
BP80Zh9<102ZPD/20:^2C0P0ZWm<202YOdd20:Z0D0040:Z0CP2YP4`0ZH1<0:V0BP80Z7m70P2VODL0
102WOTP0Z7m90:QoB@2YP4X20:Z1B`@0Ygi800@0Z7m90:V0BP2YP4X0ZX5;0P2XOd/30:MnBP<0YWe9
00P0Z7m90:V0BP2YP4X0ZH1:0:QoB@2UO4H0XgY40:5h@P80YGY50P2VNdH20:MlA`<0Z7e80P2UO4P2
0:ImB@040:MnBP2XOd/0ZH1<0:V0C0P0YWe91P2WOTX20:ImB@P0YWe700<0Y7Y:0:EkB`2VO4X00P2W
OTX0102VODL0YGa40:Ak@`2ROdT20:=nB@030:AlB02UO4P0YW]80080YgU7202UNTL20:^1D@040:Z0
CP2XOd/0Ygi:0:ElAP80Y7]300<0ZH1<0:ImB@2RNDD00P2NMD401P2PMd<0Y7]70:MnBP2RNDD0XgY6
0:AkA`80YGa800H0XgY60:5hA02PMd<0X7M30:5hA02SNTH20:AkA`030:=jAP2RNDD0XGQ400<0Y7]7
0P2SNTH30:9iA@P0XgQ500H0XgY40:AkA@2TNdD0YGa60:ImA`2WOTP20:QoB@060:IkD02VNdh0YGY=
0:EkB`2TNTP0Y7]70P2SNT@20:=hA@80XWM40P2QMT<20:1e@PP0X7]600<0XWU50:=jAP2TNdL00P2U
O4P00`2SNTH0XGQ40:1g@`090:=jAP030:QlB`2WNdX0YGU80080Y7Q700/0YGU80:MkBP2XO4/0ZWa:
0:UkB@2VNdP0Y7]70:5iA@2NND@0W7M209]h@P030:5iAP80X7Q50`2OMd@01P2KN480W7M209ag@P2N
MT80WgI20:1e@P80XWA200<0X7I409me@`2MLd400P2LLT001P2MLd40WgE30:1fA02OMD<0WWA209ec
@@80W79000<0WWA20:1fA02QMdD00P2OLd8309ib@@<0WG502P2MLd<0102LLT00W7<o09]b?P2KLS`2
09Ya>@0809me@`2NM480Vg4o09U_?@2HKS`0VFlm09]a?`2MLd4209]a?`H0VW0n00H0W79009]a?`2K
LCl0VW0n09U_?@2HKS`209M]>`H0VFi10P2JKd800`2JL3h0VFlm09M]>`0209I/>P0309Q^?02IKcd0
VW0n0080V6e300<0Ufa109M/?`2GKCd00P2GKC/0102GKSX0V7<o09Mb?P2EL3`209=^>P0309A_>`2E
L3`0UW4m0080UFXm0P2FJch209M/?`80V6e00P2DKSl0102CKCh0TV`m095[?02@JS/208mY>P0309E[
>@2GKC/0VFlm0080Vg4o00D0VFlm09M]>`2GKC/0UF/i09AY?00209EZ?@0509I[?P2GK3l0V6e009Q]
@02IKT40202CKCh209=X>`<0U6Tl0`2EJSd00`2GK3l0UFXm099W>P02091U>003095V>@2CJ3/0UFXm
00P0T6Xk202?JCX8099/?@80TV`o00<0TF/n091Z?@2?JC`00P2>J3/00`2=IcX0RVDk08YU>`0608YU
>`<0T6Xm:oooool002[ooooo2026GcP808IO=P0308MK=028G3D0RUhg00<0Relh0P2:GSL308UM=P80
RUhg0`2;GcP808QQ>00408EO<P26H3<0Qf4d08US=P<0RV@g00<0RF<f08]P=@2;H3D00P2<HCH208eR
=`80SV<h00<0Relb08aP<`2>HSD00P2@I3L0102AICP0T6@g091T=`2AI3X3091S>@<0Sf8h00<0SV4g
08iS=P2?I3L00P2?I3L3091U>080TFHi00<0Sf<f091T=`2AICP00P2BIST00`2AICP0T6@g08mS=P02
099V>@<0TfLj0`2DJ3/309=W>P<0U6Pk0P2EJC`0202@IcT0TFPj09=X>`2EJC`0UfPl09MV>`2FICX0
Uf@i0`2CJ3/209AY?0<0UFXm0P2BIcX0102CJ3/0U6Tl09AY?02EJSd209I[?P80U6Pk00L0UFTl09IZ
?@2FJSd0UVXm09EY?02DJ3/0UfY00080Uf/n00<0UVXk09IZ>@2FJcP00P2EJSD209U^>@0309U^>`2H
K3/0V6`m0080Uf/n00@0UfY009I[?P2FJch0UV/n0`2EJSd209AY?00409IZ>@2GJcX0Uf/j09M[>P<0
V6`k00T0VFdl09Q[@@2GJch0UVXm09IZ>`2FJST0V6dj09U^>@2JKcX00P2IKcd309Q^?0<0Ufdk0P2M
LD80102LL3l0W74n09aa?P2LLC`209]`>@@0VFlm0`2JL3h04@2KLCl0WFdl09e]?02NKSd0X70o0:5a
@02RLT40Xg=20:Ad@`2NLd00WG8o09]`?@2JKc`0VFhk09Y_?02KL3d0W74n0080Vfln0P2LL3l209ea
@080WW910P2NM48309ec@@@0W790202NLd0309eb?@<0WW<n0P2OM3l20:Ef@P<0YgQ400T0YGI20:=d
@02RLcl0YW@o0:Ae?`2TMD40XgE30:5f@`2PMT@00P2OMdH00`2SN4D0XWM40:5f@`020:1e@P030:5f
@`2RMd@0XgQ50080Y7Q70`2SMdH30:9fA@040:5f@`2RMd@0Y7U60:IkB080Yga900@0YW]80:EjA`2W
MdH0YgM60`2XN4L30:UiB0030:MkBP2VNTT0YGU80080Y7Q700@0YWY90:QlB`2YOD`0Yga70P2XODP0
102YOTT0Z7e80:MlA`2VNdH30:EjA@80YW]60P2WO4L20:QmB0030:MlA`2XODP0Z7e800D0Z7e80P2V
NdP20:MlB@040:QmBP2YOT/0ZWm<0:YoC0P0Z7m;0`2WOTX20:QoB`<0ZH1<0P2[PT`30:V0BP030:^2
C02/Pdd0[XE?00<0ZWm<0P2YOT/30:QmBPP0ZX5=0P2/Pdl20:^2CP80ZX5=0`2YP4`01@2YOTT0ZWm:
0:YoBP2[P4/0[85<0080[H9=00<0[X=>0:f2C`2]PTl01P2]PTl80:b1CP<0Zh1=0P2/PDh30:f2C`80
ZHA=00<0ZHA?0:V4D02YPe800P2YPe@00`2YPeH0Zh9>0:^2CP060:^2CP040:b3C`2[PTh0Zh9>0:^2
CP<0ZX5=00<0ZH1<0:Z1C@2ZPDd00P2YP4`30:QoB`040:MnBP2WO4D0Z7e60:QmB080Z7e:00<0Z7a;
0:QlC@2XO4d00`2UP4`20:J1C@<0Yh9>202WPTd80:Z1C@<0ZX5;0`2YP4X20:QoB@<0ZGi90P2XODP3
0:MlA`80ZGi;00X0Z7e:0:MlB@2UNTL0Y7U60:=hA@2RMd@0Y7U60:=hA@2QMT<0X7E20`2OM4400`2P
MD80WgI209ie@@0309ed@00309ie@@2PMd<0XGQ40080XGI300@0X7E209md@@2OM440X7E20P2QMT<0
0`2PMD80WgA109ic@00209eb?`0409ic@02OM440X7E20:1e@P80WGA000@0WWE109mf@P2OMT80WWE1
4P2MM40209ie@@040:1g@`2QN4@0XGQ40:5hA080X7M30`2QMdD20:1fA0<0WgE30P2OMT8309ie@@03
09mf@P2QN4@0XWU500@0XGQ40P2PMd<209mf@P040:1g@@2QN480XGQ20:5h@P80XWU30P2SNT@02P2O
M4T0X7E80:1eB02QMdL0XWQ60:=jAP2SNT@0Y7]50:IkCP2VO4`20:IlBP80YWe700<0YWe50:In@`2S
OTT00P2TOdX01@2UP4/0Y7m:0:=nB@2RODP0XGa700P0Ygi:00T0Yge;0:QnC02XOd/0Z7m90:V0B02Y
PDH0ZX970:Z2A@2[PT`00`2ZPD/20:V0BP80Z7m90P2ZPDT0102ZPD/0ZX5=0:Z1C@2ZP4h20:Z0D005
0:b3C`2[PTh0ZX5=0:V0C02XOd/00P2YP4`0102ZPDd0ZWm:0:^0B`2]PTd30:j3CP80[H9=202/Pdl2
0:j5D@030:f4D02/Pdl0Zh9>0080ZX5=00L0ZH1<0:b3C@2/Pdd0[8==0:b3C`2]Pe40[H=C0080[X=F
00<0[X=H0:b3C`2/Pdl01P2/Pdl80:j4DPP0[XEA00D0ZXE@0:^6D@2[QU40[8MB0:f8D`020:j9E003
0:n:E@2^QE40[hIB0080[hIB0`2`Qe<00`2aR5@0[hIB0:n6DP030;27D`<0/HQD602`Qe<30:f4D080
[XEA0`2_QU820;68DP040;27D@2_QU00[hI@0;27D@80/HQB0P2bRED30;68E0<0/8MC202aR5820;68
E0040;27D`2_QU80[hIB0;27D`80/HQD0P2aQeL0102cREL0/hYF0;>:EP2cRU@20;68D0<0/HQD0P2b
RED30;>:EPP0/hMF00@0/HQB0;:9D`2bRE<0/XUC0P2cRU@20;B;E@040;>:DP2bRE40/XUA0;27D@80
[hIB00<0[hEC0;26EP2aQeL00`2dReL30;>:EP80/XUE0P2aS5P20;2;E`@0[hYF0P2_RUD30;2;EP<0
/HaG202bSET0202bTE`0/I1K0;6=F@2aS5P0/h]H0;B:F02eReT0]XYI0P2dRe<0102eS5H0]HaH0;F<
F02dRUP20;:8F0<0[XUE0P2_RUH30;2;E`030;68E02bRED0/hYF0080/hYF00H0/HQD0;27D`2^QE40
[H9=0:j3CP2_Q4l20;25D0030:n4C`2^Pdh0[H9=0080[H=A00@0[XAB0:n5D`2_QE<0/8ID0P2aQeD8
0:j5D@P0[HA>0`2]Q5050:b3C`<0[XEA0P2]Q5030:b3C`P0[H=A00D0ZX5=0:^2CP2[PTh0Zh9>0:b3
C`030:f4D0040:Z1C@2[PTh0Zh9>0:b3C`80[HA@1@2^QE420:f4D0<0[8=?2@2[PTh20:j5D@030:f4
D02/Pdl0Zh9>0080ZX5=00<0ZH1<0:b3C`2/Pdl03P2/Pdl80:^2CP040:j5D@2]Q500[HA@0:f4D080
[8=?0P2[PTh80:b3C`P0[8==102/PD`40:^0B`<0Zh9>0`2/Pdl20:f4D0P0[85<202/Pdl0102^QE40
[HA@0:f4D02]Q5030:b3C`030:^2CP2/Pdd0[8==0080Zh9<0P2ZPD/20:V0BP<0Zh9>0`2/Pdl20:f4
D0D0Zh9>0`2ZPDd80:b1CP80Z7i<0`2YOdd30:Z0CP060:f4D02/Pdl0Zh9>0:Z1C@2YP4`0Ygi:0P2V
ODT00`2YP4X0ZX5;0:Z1B`020:Z1B`<0Zh9<00<0[8==0:^2CP2[PTh01P2[PTh80:Z1B`X0Zh9<0`2Z
PD/00`2[PT`0[HA>0:j5C`030:^1C`<0[89@0P2]Pe480:f4CP090:YoB02[P4T0Zh1;0:^0C@2/PDh0
[81?0:b0D@2]PE80ZWmD0080ZWmB00<0ZX1@0:Z0CP2ZPDd00P2ZPD/30:Z1C@<0ZH1<0P2XOd/80:V0
BP030:b3C@2[PT`0ZX5;0080ZH1:00@0ZX5;0:^2C02/Pdd0Z7e:0`2YOT/30:YoC0030:^0C@2YOdd0
ZGm=00H0ZGm=0P2ZP500102ZP4h0ZH1<0:V0C02YP4X20:QoA`T0Z7m90P2WOTP00`2VODL0Ygi80:Qo
B@020:Z1B`80Z7m;0`2WOTX30:ImB@080:ImA`2WOTP0Z7m90:QoB@2WOTP0YWe70:=jA02RND<20:Ej
A@030:IkAP2WO4L0Z7e80080Z7e80P2YOTT0202XOd/0Ygi:0:ImB@2VODT0YGa80:ImB@2WOTX0Z7m;
202VODT20:QoB@<0Ygi82`2VODL20:AjBP040:EkB@2UO4P0YGa80:ElAP80Y7]300H0XWm90:=nB@2S
OTT0Y7a80:ElB02UNTL20:MiA`P0YGY70P2ZP500102YOdd0Z7m;0:ImB@2UO4H20:Ak@`030:MmB`2U
NdT0XWQ60080X7I400H0XGM50:=iA`2UNdT0XWU50:=jAP2TNdL20:ElB0060:=jAP2QN4@0X7M30:1g
@`2QN4@0XgY60P2UO4P00`2TNdL0XgY60:9iA@080:=jAP040:9gA02SN4D0XgQ50:=hA@<0Y7U600H0
YGY70:AkA@2TNdD0YGa60:ImA`2WOTP20:QoB@070:V0BP2VNe00YW]>0:IkCP2UNd/0YG]90:AkA`02
0:AkA@050:AiAP2SN4D0XgQ50:9gA02QMT<00P2PMD800`2OM440X7]60:1kAP060:1kAP030:9hAP2S
NDL0Y7Y80080YG]900<0XgU70:5gA@2PMT@02@2SNTH00`2WNdX0YGU80:AhA`020:=gAP080:AhA`2U
NDP0Yg]:0:UkB@2XNTP0YGY70:=jAP2QNDD209eh@`0409]h@P2QMdD0XGM50:5gA@80X7I40`2OMD<0
1P2KN480W7M209ag@P2NMT80WgI20:1e@P80XWA200<0X7I409me@`2MLd400P2LLT001P2MLd40WgE3
0:1fA02OMD<0WWA209ec@@80W79000<0WWA20:1fA02QMdD00P2OLd8309ib@@<0WG50202MLTD209ec
@`0409ab@02LLcl0Vg8n09]b?080VW4i00D0WG=109ab@02KLCl0VW0n09U_?@0209Y`?P@0Vg4o0`2J
L3h209U_?@0409]a?`2JL3h0VW0n09Y`?P@0VFlm102IKT4209Y_@P80Vg1301P0VW0n09U_?@2HKS`0
Ufdk09Q^?02IKcd0Vg4o09ab@02KL4H0VVm509U^@`2HKD00Ufdm09Q^?02IKcd0VG0l09Ye@@2IM400
Ug8n09Ia?@2EL3`0UW4m09Mb?P2HLcl209Q]@0<0VFi10`2JKd80102EKd00U6ho09A^?`2CKCh2099/
?@80TF/l00<0Ufdk09Q^?02IKcd00P2JL3h0102IKcd0V6hl09Q^?02GKC/409I[?P@0Uf`o202CKCh0
102CJ3/0U6Tl09AY?02DJC`209EZ?@80UV/n00D0UFXm09AY?02CJ3/0TVLj095V>@02099W>P0309=X
>`2AJc`0TF/l00H0TF/l202@JS/0102CKCh0TV`m099/?@2BK3d3095[?006091Z>`2BK3l0TV`o095[
?P2@JSd0SfTl0P2>J3/00`2=IcX0S6Lm08aW?@0608aW?@<0T6Xm:oooool002[ooooo2026GcP808IO
=P0808UM=P2:GSL0S60i08eQ>P2>HS/0SF4j08aP>@2;GcP308UM=P80RUhg0`2;GcP208UR>@H0R64h
00@0Ped`08EO<P27HC@0RV@g0P2;ICP0102:I3L0RF<f08]P=@2;H3D208aQ=P80SF8g0P2>HcP0102:
GS40S60c08iR=@2@I3L2095U>003091T=`2?HcH0TF@j0080TF@j00<0T6<i08mR>02?HSP00P2>HCL3
08mT=`<0T6Dh0`2AIST00`2>HSD0Sf<f095U>002099V>@03095U>02?HcH0SV8e00<0TFDh0`2BIST5
09=W>P<0U6Pk0P2EJC`0202@IcT0TFPj09AY?02FJSd0V6Tm09QW?02FICX0Uf@i0`2CJ3/209AY?0<0
UFXm00D0TFHi099W>P2BIcX0TfPk09EZ?@0209I[?P0409M/?`2DJ3/0UFTl09IZ?@80Uf/n00T0UVXm
09AX>`2CIcX0V6]109Q/?`2GJch0Uf/l09IZ>@2EJSL00P2EJSD209Y_>P0309U^>`2IKC`0V6`m0080
V6`o00@0UfY009I[?P2FJch0UV/n0`2EJSd209AY?080UVXi0P2GJcX209Q/>`80VFdl00P0V6]109M[
?P2FJSd0UFTj09IZ>@2GK3T0VFhi09]`>`<0VFlm00<0V6hl09M]>`2GKC/00P2FK3X209Y^?`0409Y^
?@2JKc`0Vg0m09]`>`80Vg0i0`2JL3h309U_?@80V6hl0100W6`k09e]?02NKSd0X70o0:5a@02SLd80
Y7A30:EeA02LLCh0Vg0m09Y_?02IKS/0VVll09]`?@2MLSl0WW=0102LL3l409ea@080WWA20`2MLd44
09ab@0P0WgA10P2OM3l309ic?P<0WG8m00h0YGI20:Ig@`2WN4@0Z7U50:MhA02VMd<0Y7E10:=d@02V
M3l0Y7Do0:Ae@@2SMD<0XGI30:1fA080WgM600<0XgQ50:9gA02QMT<00P2PMD800`2QMT<0XWM40:=h
A@020:AhA`<0XgM60`2RMTD00`2SN4D0Y7U60:IkB0020:MlB@030:IkB02UNTL0XgQ500<0YgM600<0
Z7Q70:UiB02YNDP00P2ZNTT0402WNdX0YWY90:EiB02TN4L0YGU80:IjB@2XO4/0ZGe<0:MlA`2XODP0
ZGi90:YoBP2YOTT0Z7e80:IkAP2TND@20:EjA@80YW]60P2WO4L20:QmB080YW]60P2WO4L01@2XODP0
ZGi90:YoBP2ZOdX0Yga900L0Z7e:202XOd/00`2VODT0Ygi:0:MnBP020:QoB`80ZH1<00X0ZX5=0:Z1
B`2YP4X0Z7m90:MnB02XOdT0ZX5;0:b3C@2]Q4h0Zh1=0P2ZOd`20:UnB`80Z7e:00<0Yga90:V0C02Y
P4`01P2YP4`20:b3C`80Zh9>0P2ZPDd30:V0C080ZGi900@0ZWm:0:^0B`2/PD`0[H9=0P2^Pdh80:f2
C`T0Zh1=0`2/PDh20:f2C`80[X=@0P2ZQE00102ZQE40ZXAC0:Z4E@2ZQ5D20:Z4E`P0Zh9>0P2/Pdl2
0:^2CP80ZX5=1@2YP4`30:QoB`80Ygi:0P2WO4D0102WO4L0Yga90:MlB@2WNdX20:MkC080Y7m;0P2U
P4`30:J1C@030:N2CP2WPTd0Yh9=00H0Yh9=202YP4`30:Z1B`<0ZH1:0P2XOdT30:MlA`80YW]60`2U
NTD02`2ZOd`0ZGi;0:QmBP2VNdP0YGY70:=hA@2RMd@0XGI30:9gA02QMT<0WgA10080WW=000<0WgA1
0:1e@P2QMT<00P2OMT8209ed@00709ie@@2OMT80XGQ40:=jAP2QMT<0X7E209md@@0209ic@00609md
@@2PMD80XGI30:5f@`2PMD80WW=00P2MLSl01`2NLd00X7E20:5f@`2QMT<0Vg8n09ac?`2NMD400P2O
MT800`2NMD40W7<o09]b?P0809ac?`P0WGA000T0VW4m09]b?P2NMD40WgI20:1g@`2OMT80WWE109ed
@02QMdD00`2PMT@209me@`80WWA200P0WgI209ie@@2MM400W7<o09ed@02NMD40X7M30:9iA@<0XGQ4
00<0X7M309mf@P2OMT800P2NMD430:1g@@80XGQ20`2RND<20:5fB`80XGI901@0XGM70:5gA@2QN4@0
XGQ40:AiCP2TND`0Y7Y:0:AjB02TNdD0Y7]30:Al@@2TO3l0XWe80:=nB@2TOdX0YH1;0:AoBP2SOTT0
XGa70:1kAPP0Ygi:0P2WOD/00`2XOd/0Z7m90:QoA`020:V1AP030:V1A02YP4X0Z7m90080Z7m90P2W
OTP20:ImA`80Zh9:00@0Zh9<0:Z1C@2ZPDd0ZX1>0P2ZP500402]Q500[8=?0:Z1C@2XOd/0Ygi:0:Qo
B`2YP4`0ZX5=0:YoBP2[P4/0[H9=0:j3CP2_Q4l0[X=>0:f2C@2/PD`80:b3C`060:n6DP2^QE40[HA@
0:b3C`2[PTh0ZX5=0P2YP4`20:^2C0040:b3C@2/Pdl0[H=A0:f3D`80[X=F00<0[hAI0:b3C`2/Pdl0
1P2/Pdl20:n5E@H0[XAD202^QE440:b7DP@0[HQC0P2^QE420:n6DP80/8MC0P2aR5@20:f4D080[XEA
00@0[hIB0;27D`2`Qe<0/8MC202_QU8@0;27D`80[XEA0`2_QU830;27D`030;:9D`2aR580[hI@0080
[XE?00<0[hI@0;68DP2bRE<00P2bRED30;68E0<0/8MC202aR5800`2bRED0/HQD0:n6DP020:j5D@06
0:n6DP2aR5@0/XUE0;26EP2aQeL0/hUG0P2dReL00`2cRU@0/HQ@0;27C`030;68E080/XUE0`2cRUH8
0;F7EP<0/XUC0P2cRU@30;B;E@040;F<E02dRe<0]8]C0;:9D`80/8MC00<0/8ID0;67E`2bR5P00P2b
RED30;>:EP<0]8]G00<0/XeI0;6<F02aS5P00P2`ReL20:n:EP050:j9E@2_RUD0[hYE0:n:E@2`ReH0
0P2aS5L20;:=F0P0/XeI0100/I1K0;2?FP2`S5P0[hYF0;69EP2bR5H0]8YH0;F9F02dRe<0]HaD0;J=
E`2gSUX0]XeI0;B:F02bR5P0/HMG0`2`ReL20:n:EP<0[XUE00/0/HQD0;:9E@2cRUH0]8]G0;>:EP2b
RED0/8MC0:n6DP2]PTd0[X=>0;25D0020;66D@030;25D02^Pdh0[H9=00H0[hEC0P2`QU@20:n6DPH0
[XEA202]Q4h20:n6DP040:j5D@2]Q500[8=?0:b3C`80Zh9>00<0[hIB0:j5D@2^QE400P2]Q5020:b3
C`030:^2CP2[PDl0Zh5?00@0Zh5?0P2/PU00202XOd/0ZH1<0:Z1C@2[PTh0[HA@0:j5D@2_QU80/8MC
0P2[PTh40:b3C`80[HA@0`2^QE420:f4D0<0[8=?2@2[PTh01P2_QU80[XEA0:f4D02/Pdl0Zh9>0:Z1
C@80ZH1<402/Pdl80:^2CP80[XEA0`2]Q5030:b3C`P0[HA@202/Pdd01@2^Pdh0[H9=0:f2C@2/PD`0
Zh1;0080ZWm:00@0ZGi90:^2CP2[PTh0Zh9>0`2/Pdl20:f4D0P0[85<202/Pdl30:j5D@030:f4D02/
Pdl0[8=?0080Zh9>0P2/Pdd20:^2C080ZX5;0P2YP4X30:^2CP<0[8=?0P2]Q5030:QoB`D0ZH1<202/
P4l30:Z0D0<0ZGm?0P2XOTh20:^2CP80ZX5=00@0ZH1<0:QoB`2XOd/0Ygi:0P2YP4P30:Z1B@80Zh9:
0P2/Pd/80:^2CPP0ZX5;202/Pd/0202/Pdd0Zh9<0:Z1B`2YP4X0ZX5;0:^2C02]Q4h0[hI@0P2]Pe<3
0:b2DP<0Zh5A202[PT`20:YoB0040:^0B`2[P4d0[85>0:b0C`80[H5B00H0ZGiC0:UnD@2YOU40ZGm?
0:UoC@2YP4`20:V0BP80Zh9>0P2ZPDd0102YP4`0Z7m;0:QoB`2XOd/80:V0BP030:b3C@2[PT`0ZX5;
0080ZH1:00<0ZX5;0:^2C02/Pdd00`2XODX00`2YOT/0ZWm<0:YoC0020:^0C@P0ZGm=0P2ZP500102Z
P4h0ZH1<0:V0C02YP4X20:QoA`040:^2C02ZPD/0ZH1:0:V0BP80Ygi800D0YWe70:ElAP2YP4X0Z7m9
0:MnB0020:ImA`030:QoB@2ZPD/0Zh9<0080Z7m;0`2WOTX30:ImB@080:AkA@2UO4H0Ygi80:QoB@2W
OTP0YWe70:ElAP2TNdD20:EjA@050:IkAP2WO4L0Z7e80:QmB02YOTT00P2ZOdX01@2[PTh0ZX5=0:Mn
BP2UO4P0Y7]70080YGa800<0YWe90:MnBP2WOTX01P2WOTX30:QoA`030:MnAP2VODD0YWe50080YGa4
202VODL20:=iB@040:9hAP2RNDD0XWU50:9i@`80XgY200H0XWm90:9mB02RODP0Y7a80:AkA`2UNTL2
0:IhAPP0YGY700H0Z7i>0:MmC@2WOD/0YWe90:ElB02UO4H20:Ak@`040:EkB`2TNTX0XgU90:=iB@@0
XWQ800<0XWU50:=jAP2TNdL00P2UO4P02@2SNTH0XGQ40:1g@`2PMd<0XWU50:AkA`2UO4P0YWe90:El
B0020:AkA`80XGQ400@0XWU50:=jAP2SNTH0Y7]70P2UO4P20:9gA080XgQ500@0Y7U60:EjA`2UNTL0
YGY70P2TNdD0102UO4H0YWe70:MnB02XOdT20:V0BP060:IkD02VNdh0YW]>0:IlC02UNdT0YGa80P2T
NdD20:AiAP040:=hA@2RMd@0XGI30:1e@P80WgA1202PNdH00`2RN4P0XgU90:AjBP020:EkB`030:=i
B@2QMdL0X7I600T0XgY600<0YGU80:AhA`2SMdH00P2QMD@00`2SMdH0Y7Q70:EiB0020:MiA`060:Ai
AP2RNDD0XGU509iiA02MN4<0W7U30P2PMT@209me@`80WWA20P2MLd401P2KN480W7M209ag@P2NMT80
WgI20:1e@P80XWA200<0X7I409me@`2MLd400P2LLT001P2MLd40WgE30:1fA02OMD<0WWA209ec@@80
W79000<0WWA20:1fA02QMdD00P2OLd8309ib@@<0WG50202MLTD209ec@`0409ab@02LLcl0Vg8n09]b
?080VW4i00P0VW0n09]a?`2LLT00W79009]a?`2JL3h0VFlm09Q^?080W7900P2KLCl00`2JL3h0VFlm
09U_?@0409U_?@80VW0n0`2KLCl00`2HKD00VFi109U^@@0209Y_@P80Vg1300<0W75409Y`?P2IKcd0
0`2HKS`03P2JL3h0W79009ec@@2NLdT0WG9809]`A@2IKT40VFlo09U_?@2JL3h0Vg8n09ehA02LMd<0
VWE10`2HLcl209Ye@@@0W754102KL4<309E_@0D0U6ho00<0VW0n09U_?@2HKS`00`2HKS`209U_?@03
09Y`?P2GK3l0Uf`o0080Uf`o102FJch809=]?P<0U6Tl0P2EJSd309I[?P80TfPk0`2DJC`00`2CJ3/0
TFHi091U>008099/?@P0TF/l0P2CKCh2099/?@04095[?02@JS/0T6Xk091Z>`80TV`o00<0TF/n091Z
?@2?JC`00P2>J3/00`2=IcX0SFPn08eX?P0608eX?P<0T6Xm:oooool002[ooooo2026GcP808IO=P03
08YN=`2;GcP0SF4j00<0Sf<l00<0SF4j08aP>@29GCH00P29GCH208YN=`<0Relh0`29HST508QQ>004
08=M<025Gc80Qf4d08YT=`80RfDh00@0RV@g08US=P2;H3D0Rf0e0P2<HCH208eR=`80SV<h00<0RUha
08aP<`2>HSD00`2AICP01@2@I3L0Sf<f099U>`2BIC/0TF@j0080T6<i00<0Sf8h08iQ=`2>HCL00P2?
I3L4091U>0<0TFHi00<0SV8e08mS=P2AICP00P2BIST00`2AICP0Sf<f08iR=@04091T=`80TFDh0P2B
IST309=W>P<0U6Pk0P2EJC`0202@IcT0TFPj09AY?02FJSd0V6Tm09QW?02FICX0Uf@i0`2CJ3/209AY
?0<0UFXm0P2AIST0102BIcX0TfPk09EZ?@2FJch209M/?`0309=W>P2EJC`0UVXm0080Uf/n00/0UVXm
09=W>P2BIST0V6]109Q/?`2GJch0Uf/l09IZ>@2EJSL0UFXe09AY=00209Y_>P0309U^>`2IKC`0V6`m
0080V6`o00@0V6]109I[?P2FJch0UV/n0`2EJSd209AY?0<0UVXi00<0Uf/j09Q/>`2IKC`00P2IKC`0
2@2IK480Uf/n09IZ?@2EJCX0UFTh09M/>@2IKST0Vg0k09Y`?P0209U_?@0309Q^?02GKC/0Ufdk0080
UV`j0P2HK3d0102IKC`0VFhk09Y_?02JKcX209]`>@80Vg4o00@0VW0n09U_?@2IKcd0V6hl0P2GKC/2
09a/>`0809i^?@2PL3l0XW910:Ad@`2UMD@0YWI509]`?@2JKc`209U^>`0409Y_?02LLCh0WW=009md
@@@0W70o102MLD0209id@P<0WG=1102LLT0809md@@80X7E000<0Wg@o09ic?P2MLSd00P2LLC`03`2K
L3/0YGI20:Ig@`2WN4@0Z7U50:MhA02VMd<0Y7E10:=d@02VM3l0Y7Do0:Ae@@2SMD<0XGI30:1fA002
09mgAP030:AiAP2RMd@0XGI30080WgA100<0XGI30:9gA02TNDH00P2TN4L30:=gAP<0XWI500<0Y7U6
0:EjA`2WO4T00P2WO4T0102UNTL0Y7U60:9gA02VMTD20:MgAP030:QhA`2YNDP0ZGU80080ZWY900/0
Yg]:0:IjB@2UNDP0Y7Q70:EiB02VNTT0Z7a;0:UmC02WO4L0Z7e80:UnB@020:YoBP030:QmB02VNdH0
Y7U40080YGY50P2VNdH20:MlA`80Z7e800H0Y7U40:EjA@2VNdH0Yga70:QmB02ZOdX20:^0B`80ZGi;
0`2XODX30:MlB@P0Z7m;0P2VODT0102WOTX0Z7m;0:QoB`2YP4`20:Z1C@080:V0BP2XOdT0Ygi80:Im
A`2WOTP0ZH1:0:^2C02/Pdd20:^0C@040:YoC02YOT/0ZGi;0:QmBP80Yga9202YP4`20:b3C`80Zh9>
0P2ZPDd30:V0C0080:QmB02YOTT0ZWm:0:^0B`2/PD`0[H9=0:j3CP2_Q4l80:f2C`P0ZWm<102/PDh2
0:f2C`80[X=@0P2YQU000`2YQE40ZHEC0:V5E@020:V4E`030:V4F02[PTh0Zh9>00H0Zh9>0`2/Pdl0
0`2[PTh0ZX5=0:V0C0050:V0C080Z7m;0`2WOTX20:MlA@040:MlA`2WO4T0YW]80:IjB@80YWY;0`2T
Od/20:F0C0<0YX5=202VPD`80:V0C0<0ZX5;0`2YP4X20:QoB@80YW]60`2UNTD30:AiA00;0:YoC02Y
OT/0Z7e:0:IkB02TNDH0XgQ50:9gA02QMT<0X7E209md@@2NLd000P2MLSl03P2OM440XGI30:9gA02P
Md<0WgI209ie@@2MM400WWE10:1g@`2RNDD0Y7]70:5f@`2PMD80WW=00P2MLSl01P2NLd00X7E20:5f
@`2QMT<0X7E209md@@80WW=000L0WgA10:1e@P2QMT<0XGI309]b?P2LLcl0WWE10080WgI200<0WWE1
09ac?`2KLSh0202LLcl509ed@0<0W7<o00P0V6lk09Ya?@2LLcl0WWE109mf@P2NMD40WGA009ac?`@0
X7I40P2OMD<209id@P0309mf@P2NMD40W7<o0080W7<o00<0WWE10:1g@`2RNDD00P2QN4@20:1g@`05
09mf@P2NMD40WWE109ed@02OMT000`2PMd420:5h@P80XWU300H0XWM=0:5fB`2QMT/0XGI90:1fAP2P
MT@20:1g@`0;0:=hCP2SN4d0XgQ;0:=iA`2SNT@0Xg]00:=k?P2SNcd0X7e70:9oB@2SP4X00P2TPD/0
0`2ROdT0X7e709ikA@080:MnBP80Yge;00<0Ygi:0:QoB@2XOdL00P2YPDH0102YPD@0Ygi80:MnB02W
OTP30:ImA`80YGa60P2[PTX0102[PT`0Zh9>0:Z1C@2ZP4h20:Z0D0030:f4D02/Pdl0ZH1<00<0Ygi:
00D0ZH1<0:Z1C@2YOTT0Zh1;0:f2C@020:n4C`030:j3CP2]PTd0[85<00P0[8=?00H0[hIB0:j5D@2^
QE40[8=?0:^2CP2ZPDd20:V0C0<0Zh9<00H0[8=?0:f3D@2]Pe<0[X=F0:n4E`2_Q5T80:b3C`<0[hEE
1@2^Q5@80:j5D@040:j9E02]R5<0[HQC0:f8D`<0[8MB00H0ZhIA0:j5D@2^QE40[XEA0:n6DP2`Qe<3
0;68E080[8=?0P2]Q500102^QE40[hIB0:n6DP2`Qe<80:j5DA00/8MC0`2_QU820;27D`<0/HQD00<0
/XUC0;27D@2_QU000P2]Q4h00`2_QU00/8MA0;:9D`020;:9E@<0/HQD0`2`Qe<80;68DP030;:9E@2`
Qe<0[hIB0080[HA@00H0[hIB0;27D`2bRED0/8IF0;67E`2cREL20;B;E`030;>:E02aR500/8M?00<0
/HQD0P2bRED30;>:EPP0]HMF0P2bRE<30;>:E0<0]8]E00L0]XeE0;F<E02eS5@0/hYD0;68E02`Qe<0
/HME0080/XQH0P2aR5@00`2bRED0/hYF0;B;E`020;F<F0030;J=F@2bSET0/XeI0080/HaH00D0/8]G
0:n:EP2_RUH0[XUE0:j9E0020:n:E@030;2;EP2aS5L0/HaG0080/XeH202bSET0402`SeX0[hiI0:j:
EP2^RED0[hMD0;67E@2cREL0]HUH0;B;D`2eS5@0]XeG0;N>FP2fSET0]8YH0;:8F02`QUH20;6<F004
0;2;E`2_RUH0[hYF0:j9E@80[HQD00<0/HQD0;:9E@2cRUH00P2dReL01P2bRED0/8MC0:n6DP2]PTd0
[X=>0;25D080/HIA00@0/8E@0:j3CP2]PTd0/HME0`2`QU@30:n5D`040:j4DP2_QU80[hIB0:n6DPD0
[XEA202]Q4h20;27D`040:n6DP2^QE40[8=?0:^2CP80ZX5=0P2_QU80102^QE40[HA@0:f4D02/Pdl2
0:^2CP80ZGm=102ZP4h20:^1C`080:ImB@2WOTX0ZH1<0:^2CP2]Q500[hIB0;27D`2aR5@60:b3C`80
Zh9>0`2^QE420:f4D0<0[8=?2@2[PTh01P2_QU80[XEA0:j5D@2/Pdl0Zh9>0:Z1C@80ZH1<402/Pdl8
0:^2CP<0[XEA0P2]Q5030:b3C`P0[HA@202/Pdd0202_Q4l0[X=>0:f2C@2/PD`0Zh1;0:YoBP2YOTT0
Z7e80`2[PTh30:b3C`80[HA@202/PD`80:b3C`80[hIB00@0[XEA0:f4D02]Q500[8=?0P2[PTh20:b3
C@80Zh9<0P2ZPD/20:V0BP<0Zh9>0`2/Pdl20:f4D0@0Ygi:102XOd/80:]oCP060:b2DP2[PE40Zh5A
0:Z0D02YOdl0Z7i>0P2WODd30:Z1C@@0ZH1<00@0Z7m;0:V0B02YP4P0ZH180P2ZPDT0102[PTX0[8=;
0:b3B`2/Pd/80:^2CPP0ZX5;202/Pd/0202]Q4h0[8==0:Z1B`2YP4X0ZX5;0:^2C02^QDl0[hI@0P2^
Q5@00`2]Pe<0[89B0:^1D@020:Z0D0030:UoC`2ZPD/0ZX5;00H0ZX5;0P2ZOdP0102ZOdX0Zh1=0:b1
CP2]PE020:f1DP060:UnD`2YOU40ZGiA0:UoC`2YOdd0ZH1<0P2YP4X20:^2CP80ZX5=00@0ZH1<0:Qo
B`2XOd/0Ygi:202YP4X00`2]Q4h0Zh9<0:Z1B`020:QoB@030:Z1B`2[PT`0[HA>0080Yga900@0Z7e:
0:UnB`2YOT/0ZWm<0P2[P4d80:UoC@80ZX1@00@0ZX1>0:V0C02YP4`0ZH1:0P2XOdL20:b3C@040:Z1
B`2YP4X0Ygi80:ImA`80Y7]500<0ZH1:0:QoB@2VODL00P2VODL00`2XOdT0ZX5;0:^2C0020:QoB`<0
Ygi:0`2VODT0202SNT@0Y7]50:ImA`2WOTP0Z7m90:MnB02VODL0YGa60P2UNTD03`2VNdH0Yga70:Qm
B02XODP0ZGi90:YoBP2[P4/0[HA@0:^2CP2XOd/0YGa80:AkA`2SNTH0Y7]70:ElB0080:MnBP040:V0
B02XOdL0Z7m70:MnAP80YWe50P2UO4@80:ImA`030:9hB02QMdL0XGM50080XGQ400@0XGQ20:5h@02R
ND40XGi80P2RODP00`2TO4P0Y7]70:EjA`020:IhAPP0YGY70P2VO4`0102UNdT0YGa80:ElB02TNdD2
0:Ak@`030:=iB@2TNTX0Y7Y:0080Y7Y:00H0XgU90:5gA`2QMdL0XWU50:=jAP2TNdL20:ElB0060:=j
AP2QN4@0X7M30:1g@`2RNDD0Y7]70`2VODT0202UO4P0Y7]70:1g@`2PMd<0XGQ40:9iA@2TNdL0YGa8
0P2VODT20:9gA0040:=hA@2TNDH0Y7U60:EjA`80YW]800H0Y7]50:ElAP2UO4H0YWe70:MnB02XOdT2
0:V0BP060:MlD@2VNdh0YW]>0:IlC02UNdT0YGa80P2TNdD0202UNTL0Y7U60:=hA@2RMd@0XGI30:1e
@P2OM440WW=0202PNdH00`2RN4P0XgU90:AjBP020:EkB`030:=iB@2QMdL0X7I600T0XgY600<0Y7Q7
0:=gAP2QMD@00P2PM4<00`2QMD@0XgM60:AhA`020:IhAP030:=hA@2RNDD0XGU50080WWU400<0WGY4
0:1d@`2OLd800P2OLd8209ib@@80WG5000H0VgQ209ag@P2LMd80WWI209mf@P2PMD820:9d@P030:1f
A02OMD<0WG=10080W79000H0WG=109me@`2PMT@0WgE309id@P2MLd4209ab@00309id@P2PMT@0XGM5
0080Wg=20`2NLT4309ea@0P0WG970P2MLd<0102LLT00W7<o09]b?P2KLS`209Ya>@0809U_?@2JL3h0
W79009id@P2MLd40Vg4o09Q^?02FK3X209ab@080Vg4o00<0VW0n09U_?@2IKcd00`2HKS`0102IKcd0
VW0n09]a?`2KLCl209ab@00409Q]@02IKT40VFi109Y_@P80Vg130P2LLD@0602JL3h0VFlm09Q^?02H
KS`0VFlm09]a?`2MLd40WWA20:1eB`2OM4X0W75609Y_@P2IKcl0VW0n09]a?`2LLcl0WWU509ehA02K
MT80VWE109Ud@02JMD40VgI209ag@`80WgA700<0WW=609ebA@2MLTD00`2LLD@609E_@080UW1100<0
W79009Y`?P2HKS`00P2FK3X01@2HKS`0VW0n09Y`?P2LLT00VFi10080V6e000D0Uf`o09I[?P2EJSd0
UFXm09AY?00809=]?P80U6Tl0`2EJSd309I[?P08095V>@2CJ3/0UFXm09I[?P2EJSd0TfPk091U>02?
I3L@099/?@80Tfdn00@0TV`m095[?02AJc`0T6Xk0P2?JCX2099/?`03095[?P2@JSd0SfTl0080SVPk
00<0SFLj08iY?`2>JCl01P2>JCl3091Z?B_ooooo000Zooooo`<0QEhe0`26GcH208MP=`80REdf00@0
RUhg08]O>02<H3T0S60i0P2=HCX208QL=@0408UM=P2:GSL0RUhg08]O>080S60i202;H3D02`2:Gc@0
Rf0e08aQ=P2<HCH0Rf0e08YO=028GC80QU/`08YO=02;H3D0SV<h0080Sf@i00/0SV<h08]P=@2:Gc@0
RUdc08]N=02<GcD0SF0f08iQ=`2?HSP0T6<i095T>P0208aO=P0308eP=`2>HCP0Sf8i0080TF@k00@0
TVDl08eQ?02=HC`0SF4l0`2>HSd208mS?P04091R?P2@Hc`0TF@m095T>`80TF@j00<0TVHi099V=`2B
ISL02P2@I3L0102AICP0TVHi09=W>P2DJ3/209EY?080T6Li0P2AJ3X0102BJC/0TfXl09=Z?02DJcd2
091U>080TFHi0P2BIcX209=X>`P0UVXi00<0TVHi09=W>P2EJC`00`2GJch00`2EJC`0U6Pk09IZ?@07
09IZ?@03099U>`2CIS`0UVTo0080UfY000<0UVTo09EX?P2CIS`00`2GJcX209Q/>`<0VFdl0P2JKSd0
1`2IKC`0Uf/j09EY>02DJ3L0TfLf099V=@2CIcH00P2DJ3L00`2EJCP0UVXi09M[>P0209Q/>a00VFdl
00<0W70o09]_?P2IKC`00P2HK3/00`2IKC`0Vfln09a`?`0809Q]>P0809U^>`2JKc`0Vg0m09aa?P2M
LSl0WW=009md@@2PMD8309ea@0<0WW910P2OLd8809md@@<0X7A30P2OLd8409ib@@0;09ic@02MLSl0
W74n09eb?`2NLd00X7E20:9gA02TNDH0WgA10:5f@`2SN4D00P2TNDH0102QMT<0WgA109eb?`2TLD82
0:9b@P030:5c@P2OLd80WWA20080WGE200<0XGI30:9gA02SN4D00P2UNTL00`2SN4D0XWM40:5f@`08
0:=hA@80YWY900@0YGU80:AhA`2TN4L0XgM60P2RMTD20:1e@P030:5f@`2RMd@0XgQ50080YGY700<0
YW]80:EjA@2UNTD01P2UNTD20:EiB080YWY90P2WNdX20:QlB`030:EjA`2WO4T0Z7e:0080ZGi;00<0
Yga90:EjA`2SN4D00P2XODX20:MlB@80YW]80P2UNTL20:Eg@`030:AiA02TNdD0Y7e60080Xgi700L0
Xh180:AkA@2UO4H0YGa60:ImA`2WOTP0Z7m90080ZH1:202XOdT20:MlB@040:QmBP2YOT/0ZGi;0:Yo
C080Zh1=0`2WOTP20:QoB@@0ZH1:00L0ZX5;0:^2C02[PT`0Zh9<0:V0BP2XOdT0YWe700P0ZWm<0P2[
PT`20:Z1B`050:V0BP2XOdT0Z7m90:QoB@2WOTP0202/P4l20:b3C@80Zh9<0P2ZPD/20:V0BP80[X=@
0P2]PTl40:b1CP<0[H9?0P2^Pe030:n4D@80ZH1<00<0ZGm=0:UoC`2YOU400P2YOU<0102YOU@0ZX5=
0:Z1C@2ZPDd30:V0C080Z7m;00<0[85>0:^0C@2YOT/00P2XODX0102YOT/0Zh1=0:b1CP2ZOd`30:Un
B`80Z7e:0P2WO4T04`2[P4T0ZGi70:MlA`2UNTL0Y7U60:AhA`2UNDX0YWY;0:=nBP2TOd/0YH1<0:J1
C@2UP4`0Y7m;0:9mB@2QO4P0YH190:J1BP2XPd`00`2YQ4d00`2WPT/0YX5:0:V0B0070:V0B080Yge=
00@0Yge;0:MnBP2WOTX0Ygi80P2WOTH01`2YP4`0Z7m;0:MnBP2VODT0YGa80:AkA`2SNTH00`2RNDD4
0:=jAP80Y7]7202JMcl00`2QN4@0X7M309ie@@0209ed@00;09ie@@2PMd<0XGQ40:5hA02QMdD0X7I4
09meA@2MLTD0W75609]`AP2JKdD02@2NM4800`2JLC/0W7<m09ie?`0209mf@00309ie?`2LLcd0VW4k
0080VGHn0P2HMCd0102GM3`0UW<k09Ic>`2ELSX309Mb>`0309Qc?02IM3d0VWDn0080VWDn202JL3h0
102OMD<0WWA209id@P2MLd4209ab@080Vg4o0P2IM400102JMD40VgI209]f@P2LMd<409ehA00409ag
@`2KMT80VgI209Ye@@80VGA00`2OMT800`2PMd<0XGQ40:9iA@020:9iA@080:AjB02SNDL0XWQ60:5g
A@2PMT@0WgE309id@P2MLd420:1g@`80WgI200@0XGQ40:=jAP2UO4P0Ygi:0P2TNdL20:ElB0<0YWe9
00<0Ygi:0:MnB02WOTP01P2WOTP80:ElAP@0YWe90P2WOTX20:QoB`030:MnBP2YP4`0ZX5=00<0[8=?
00@0Zh9>0:Z1C@2[PTh0Zh9>0P2ZPDd0102YP4`0Z7m;0:QoB`2WOTX80:Z1B`P0ZX5=0P2]Q4`0102]
Q4h0[XEA0:j5D@2_QE<20:n5E@<0/HQD00H0/8MC0:n6DP2^QE40[HA@0:b3C`2[PTh90:j5D@070:f4
D02/Pdl0Zh9>0:^2CP2]Q500[hIB0;27D`080:j5D@80[HA@0`2^QE4;0:n6DPP0/8MC0`2]Pe450:j4
DPP0/8MC0`2aR5@00`2`Qe<0[hIB0:j5D@020:j5D@P0[XUE00P0[8=?0:n6DP2aR5@0/8MC0:b3C`2[
PTh0[XEA0;68E0P0[hIB00<0[8MB0:f8D`2_RUD00P2`ReH00`2_RUD0[HQC0:b7DP030;27D`<0/HQD
0P2bRED80;:8EP040:j9E@2_RUH0[hYF0;2;E`80/HaH0P2bSET0402`Qe<0/XUE0;B;E`2fSET0]hiJ
0;J=F@2eS5P0]8]G0;27D`2aR5@0/hYF0;F<F02fSET0]HaH0;>:EP2bRED30;68E080/8MC0`2_QU80
102^QE40/HQD0;68E02aR5@20;:9E@<0/hYF0100/8a@0;2<DP2`Re@0/HaG0;:<F`2cSF00/haQ0;><
H`2cQf00/XIO0;66G02`QEX0/8EH0;67E`2cRET0]8YH0`2cRUH00`2dReL0]HaH0;J=F@020;J=F@T0
/hYF00L0/XUE0;27D`2_QU80[hIB0;27D`2bRED0/hYF00P0/HaH0P2aQeL20;26EP<0[hEE00<0[XAD
0:n6DP2_QU800P2_QU840;27D`P0/HQD202^QE420:Z0CP040:^1C`2/PU00[XAB0:n5D`80/8ID0`2/
Pdd20:f4CP<0[XE?0`2^QE420:f4D0H0[8=?00<0Zh9>0:Z1C@2YP4`00P2YP4`0102YP4X0Zh9<0:f4
CP2^QDl20:n6D0040:j5C`2]Q4h0[HA@0:f4D0<0[XEA0`2_QU880:V4D0090:YoE@2[P5D0[H9E0:f2
E@2^Q580[XE?0:f5BP2[PdH0ZX9400P0[8=?0`2[PTh30:b3C`80[HA@0`2[PE450:b2DPD0[89@0`2[
PDl30:b1CP<0[H9?0P2^Pe00202_QU80[XEA0:f4D02[PTh0ZX5=0:QoB`2WOTX0YWe92P2]Q5030:b3
C`<0Zh9>202/Pdl80:b3B`80ZX5=0P2[PTh0102/Pdl0[HA@0:f4D02^QE480:f4D0P0[85<0P2]PTl2
0:b1CP80Zh1=0P2ZOd`30:YoBP80Zh1;0`2ZOdX0202[P4d0ZWm<0:UnB`2XODX0ZGi;0:YoC02/PDh0
[H9?202ZOdX0202ZPDd0Zh9>0:f4D02]Q500[8=?0:Z1C@2XOd/0YWe91@2ZP4h20:UoC@80Z7i<00@0
YWe90:QoB`2ZPDd0[8=?0P2]Q5000`2/Pdl0Zh9>0:YnC@070:YnC@80ZWm:0P2[P4/20:b1C080[H9=
0`2ZOd`00`2[P4d0[85>0:f2C`020:f2C`<0Zh5?0`2/PU020:f3D@030:n6CP2]Q4`0ZH1:0080YWe9
00<0Z7i<0:^1D@2]Pe<00P2[QU440:Z5D080ZHA?202[PTh80:^0B`80ZH1800@0ZH1:0:V0C02YP4`0
ZGm=0P2YOdl80:^3C`P0ZGi90`2ZOdX20:UnB@<0Z7e8202YOTT40:QoB`L0Ygi:0P2XOd/30:V0C006
0:AkA`2UO4P0YGa80:ImB@2WOTX0Z7m;0P2YP4`00`2WOTX0Z7m;0:V0C0020:Z1C@070:V0C02XOd/0
Ygi:0:5h@P2RND<0XgY40:ElAP020:MnB0070:V0BP2[PT`0[8==0:n4D@2]PTl0ZWm<0:QmBP020:Ml
B@030:QmBP2YOT/0Ygi800L0Ygi8202XOdT20:AjB080YG]90P2VO4X20:MmB`030:QnC02VO4X0Y7Y8
0080XWQ600H0XgU70:AjB02UNdT0Z7i<0:IlBP2UNdT20:=iA`030:EkB@2VO4X0Z7i<00P0Ygi:00P0
Z7i<0:MmB`2UNdT0Y7Y80:EkB@2WOD/0ZGm=0:Z0CP<0YGU800<0YWY90:MkBP2XO4/00P2XO4/0202S
NTH0Y7]70:ImB@2WOTX0YWe90:ElB02RNDD0XGQ40P2UO4P0102TNdL0XgY60:=jAP2RNDD20:5hA080
Y7]700@0XgY60:9iA@2QN4@0XGQ40P2PMd<80:ElB0@0YWe90P2WOTX20:QoB`060:9hB02SNDT0XgU7
0:AkA`2UO4P0YGa60P2VODD00`2XOd/0Ygi:0:AkA`030:9iA@030:AkA`2UO4P0Ygi:00@0Ygi:0`2V
ODT0202SNDT0XWQ80:5gA@2PMd<0XGQ40:=jA02VODD0Z7m70P2SNDL30:AjB0@0YG]90P2TNDH30:Ej
A`<0YW]80P2RNDD40:=jAP80Y7]71@2OMD<30:1fA0060:MdA@2UMDD0YWI60:EgAP2TN4L0XgU70P2R
NTL809me@`80XG=200<0Wg=209id@P2MMD800P2KMT80102JMT80X7I409me@`2MLd4309]a?`0509ab
@02MLd40W70o09ea@02NLT400P2PM4<02@2NLT40WG5009a`?`2@KcX0TG0k099a?02CLSd0U7<n09Ie
@00209Mf@@80Ufdk00@0V6hl09U_?@2JL3h0VW0n0P2KLCl809Ma@P80Vg4o0P2LLT00102MLd40WWA2
09id@P2OMD<209Ya>`0309Ya?@2JL3h0VW100080VVm200P0VVm409ec@@2LLT00VW0n09U_?@2HKS`0
VFlm09Y`?P80Vg4o00H0VW0n09Q^?02GKC/0Ufdk09Q^?02JL3h309]a?`0409Y`?P2IKcd0VFlm09Q^
?080Ufdk202KLCl209ab@00609]a?`2IKcd0Ufdk09I/>P2EJcT0U6Xh0`2GK3l309Q]@0<0VFi10P2K
LCl0102JL3h0VFlm09U_?@2HKS`209M]>`80U6Xh00l0UF/i09I/>P2GKC/0V6hl09U_?@2JL3h0TVHi
099W>P2EJSd0UVdo09E_@02CKcl0TFlo091^?P2FK3X00P2EJcT00`2CJCL0TVPf095W=@02091V=0P0
U6Tl00P0UG0l09A_>`2CKSX0TVdi091[=`2?JSH0SVTe08eX=0P0T6Dj00<0SfXm08iY?02=J3/00P2=
J3/0102?JSd0TF`o099]@02=IcX308iX>`80SfTl0P2@JSd308m[>b_ooooo000Zooooo`<0QEhe0`26
GcH208MP=`<0RUhg0P2;GcP308aP>@<0REdf0P2:GSL308]O>0P0Rf0e00<0RUld08]P=@2<HCH00P2<
HCH01P2:Gc@0R5db08ML<@2;H3D0S64f08eR=`80SV<h00@0SF8g08aQ=P2;H3D0Rehd0P2<GcD01@2=
H3H0SV4g08mR>02?HSP0T6<i0080S5lf00H0SF0g08iQ>02?HST0T6<j095T>`2BIC`308eQ>P<0SV8k
0P2?Hc`0102@HSh0T6<l095T?@2AI3/2095T>P03099V>@2BISL0TVHg00X0T6@g00@0TFDh099V>@2C
IcX0U6Pk0P2EJC`2091W>@80TFPj00@0TVTk09=Z?02CJS`0TfXl0P2@ICP2095V>@80TVLj0P2CJ3/8
09IZ>@03099V>@2CIcX0UFTl0080Uf/n00<0UVXm09EY?02DJ3/0202EJC`00`2CIcX0U6Pk09IZ?@02
09M[?P0309IZ?@2EJC`0U6Pk00<0UVXi0P2GJcX309Q/>`80VFdl00@0V6`k09M[>P2FJST0UFTh0P2D
J3L309IZ>@<0Uf/j0P2HK3/@09U]?00309a`?`2KKch0VFdl0080V6`k00<0VFdl09]_?P2LL3l0202I
KS/209Y_?00609]`?@2LLCh0WG8o09ic@02OM440X7E21`2NLT400`2MLD00WgA109md@@0609md@@<0
X7A30P2OLd8409ib@@0809ic@02MLSl0WG8o09eb?`2NLd00X7E20:9gA02TNDH20:1e@P<0XGI300@0
X7E209ic@02NLd00Y7520P2RLT800`2QLd80Wg=209id@P0209ee@P030:5f@`2RMd@0XgQ50080YGY7
00<0XgQ50:9gA02QMT<0202SN4D20:EiB0<0Y7Q70`2SMdH20:1e@P060:5f@`2RMd@0XgQ50:AiAP2U
NTL0YW]8202UNTD20:EiB080YWY90P2WNdX20:QlB`080:IkB02WO4T0Z7e:0:UnB`2XODX0Yga90:Ej
A`2SN4D20:QmBP80Yga90P2VNdP20:EjA`80YGM300H0Y7U40:AkA@2TODH0Xgi70:AoB02SP4P30:Im
A`<0Ygi82P2XOdT00`2WO4T0Z7e:0:QmBP020:UnB`80ZWm<00<0Zh1=0:MnB02WOTP00`2XOdT40:V0
BP070:Z1B`2[PT`0[8==0:^2C02ZPD/0Z7m90:ImA`080:YoC080Zh9<0P2ZPD/20:V0BP<0Z7m9202/
P4l20:b3C@80Zh9<0P2ZPD/20:V0BP80[X=@0P2]PTl30:b1CP030:^0C@2/PDh0[H9?0080[H9?0P2^
Pe020:n4D@80ZH1<00@0ZGm=0:UoC`2YOU40ZGiA0P2YOU<30:Z1C@80ZH1<0`2XOd/00`2/PDh0Zh1=
0:UnB`020:QmBP030:UnB`2[P4d0[85>00<0ZWm<0P2YOT/30:QmBP080:^0B@2YOTL0Yga70:EjA`2T
NDH0Y7Q70:EiBP2VNT/20:=nBP<0YH1<00T0Xgi:0:5lB02PNdL0Xgi70:AoB02VPDX0Z8=<0:V4C@2X
Pd`00P2WPT/80:V0B080YWa<00@0YWa:0:ImB@2VODT0YWe70P2VODD01@2XOd/0Ygi:0:MnBP2VODT0
Y7]70080XgY61@2RNDD40:=jAPP0VgHo00<0X7M309mf@P2NMD400P2MM400102NMD40WgI20:1g@`2P
Md<209me@`0509idA02MLTD0W75609aaA`2KL4H02@2MLd400`2JLC/0Vg8l09ed?P0209ie?`0309ed
?P2KLS`0VW4k00<0VG@m0P2HLc`0102GLS/0UW4j09Ia>P2FLCX209Mb>`80V7<l0P2IM3d00`2JMCh0
VW0n09Y`?P0609Y`?P80WWA20P2MLd40102LLT00Vg4o09]a?`2KLCl309Ud@00309Ye@@2KMT80VgI2
00@0W7M30P2KMT8209Ye@@80VGA000<0WWE109mf@P2OMT800P2PMd<20:5hA0060:9iA@2SNDL0XWQ6
0:9hAP2QMdD0WgE30P2NM4800`2MLd40X7M30:1g@`0209mf@P040:1g@`2RNDD0Y7]70:ImB@<0Y7]7
0P2UO4P30:ImBA00YWe700@0YGa80:ImB@2VODT0YWe90P2WOTX20:QoB`030:MnBP2XOd/0ZX5=0080
[8=?00@0Zh9>0:Z1C@2YP4`0Zh9>0P2ZPDd20:V0C080Z7m;00<0Ygi:0:Z1B`2ZPD/01P2ZPD/80:Z1
C@80[HA<00@0[HA>0:j5D@2^QE40[hEC0P2_QED40:n6DP80[XEA0`2]Q5090:j5D@070:f4D02/Pdl0
Zh9>0:^2CP2]Q500[hIB0;27D`080:j5D@80[HA@0`2^QE4;0:n6DPP0/8MC202_QE<80;27D`80/HQD
0P2`Qe<20:n6DP80[XEA202^RED0202/Pdl0[hIB0;68E02`Qe<0[8=?0:^2CP2^QE40/HQD202_QU80
0`2/Qe80[HQC0:n:E@020;2;EP030:n:E@2]R5<0[8MB00<0/8MC0`2aR5@20;:9E@P0/XQF0`2_RUH0
0`2`ReL0/HaH0;6<F0020;:=F@0;0;68E02bRED0]8]G0;J=F@2gSUX0]XeI0;F<F02dReL0/8MC0;68
E02cRUH00`2eS5P20;>:EP@0/HQD0P2`Qe<30:n6DP80/HQD0`2bRED30;>:EP80/8aB00@0/HaE0;6<
F02bS5/0/XaO0P2cS640202eRF80]8UO0;:7G@2aQU/0/8EH0;67E`2bR5H0/hUG0P2cRUH20;B;E`80
]HaH0P2fSET90;>:EP070;:9E@2`Qe<0[hIB0:n6DP2`Qe<0/XUE0;>:EP080;6<F080/HMG0P2`QUH4
0:n5E@@0[hIB102`Qe<80;68E0P0[XEA0P2[PDl0102/PU00[H=A0:f3D@2^Q5820:n5D`<0[8==0P2]
Q4h30:j5C`<0[XEA0P2]Q5060:b3C`030:^2CP2ZPDd0ZX5=0080ZH1<00@0ZX5;0:^2C02]Q4h0[XE?
0P2_QU000`2^QDl0[HA>0:f4D0020:f4D080[XEA0`2_QU880:V4D0090:YoE02[P5<0[H=C0:f3D`2^
Q580[XE?0:f4C02[PdP0ZX9500P0[8=?0`2[PTh30:b3C`80[HA@0P2[PE460:b2DPH0[89@0P2[PDl3
0:b1CP<0[H9?0P2^Pe020:f4D0030:b3C`2[PTh0ZX5=0080ZH1<00<0Z7m;0:f4D02]Q500202]Q503
0:b3C`<0Zh9>202/Pdl80:b3B`80ZX5=0P2[PTh00`2/Pdl0[HA@0:f4D0090:f4D0P0[85<0P2]PTl2
0:b1CP80Zh1=0P2ZOd`80:YoBP080:^0C@2ZOd`0ZGi;0:QmBP2YOT/0ZWm<0:b1CP2]PTl80:YoBP09
0:Z1C@2[PTh0[8=?0:f4D02/Pdl0ZX5=0:QoB`2WOTX0Zh5?00@0ZX1>0P2YOdd20:QnC0040:ImB@2X
Od/0ZX5=0:b3C`80[HA@00<0[8=?0:^2CP2ZOTd01`2ZOTd20:YoBP80Zh1;0P2/PD`20:f2C@80ZWm<
0P2[P4d0102/PDh0[H9?0:f2C`2]PTl30:^1C`<0[89@0P2]Pe40202`Qdl0[XE=0:Z1B`2XOd/0Ygi:
0:UoC@2/PU80[XAD1P2ZQE020:V4C`P0Zh9>202[P4/20:V0B0040:V0BP2YP4`0ZH1<0:UoC@80ZGm?
202ZPTh80:UnB@<0ZWm:0`2YOTT20:QmB0P0ZGi90P2ZPDd20:V0C080Z7m;0P2WOTX80:QoB`80YGa8
0P2VODT0102WOTX0Z7m;0:V0C02YP4`20:QoB`@0Ygi:0P2XOd/0102SNT@0Y7]50:ElAP2VODL20:Qo
B@070:V0BP2ZPD/0Zh9<0:f2C`2/PDh0ZGi;0:MlB@020:IkB0030:MlB@2XODX0Ygi800L0Ygi8202X
OdT20:AjB080YG]90P2VO4X20:MmB`0;0:QnC02VO4X0Y7Y80:=iA`2RN4H0XgU70:AjB02UNdT0Yge;
0:IlBP2UNdT00P2TNTP00`2UNdT0YWa:0:MmB`080:MnBP80Yge;0`2UNdT00`2WOD/0ZGm=0:Z0CP02
0:EiB080YWY90P2WNdX20:QlB`080:AkA`2UO4P0YWe90:MnBP2VODT0YGa80:=jAP2QN4@30:AkA`<0
XgY60P2RNDD30:=jAP80XWU50`2QN4@80:AkA`040:ElB02VODT0YWe90:ImB@80Ygi:0P2XOd/20:Aj
BP040:AjB02TNdL0Y7]70:AkA@80Y7]300<0Z7m;0:ImB@2TNdL00`2RNDD00`2SNTH0Y7]70:MnBP02
0:MnBPD0YWe900P0XgU90:9hB02QMdD0XGQ40:9iA@2TNdD0YWe50:QoA`<0XgU70P2TNTP40:EkB@80
Y7U60`2UNTL30:IkB0H0XgY60P2TNdL409me@`@0X7I400H0YW=40:AdA02UMDD0Y7I50:9fA@2RN4H2
0:5iAPP0WgE30P2QLd800`2OLd80WWA209ee@P0209]f@P0409Yf@P2PMT@0WgE309ec@@<0Vg4o00D0
W79009ec@@2LL3l0WG5009ib@@020:1d@`0309ib@@2MLD00W70o0080Tg8m0P2DLch01@2EM3l0UWE0
09Mf@@2GMT40V6hl00<0VFlm102JL3h809Ma@P80Vg4o0P2LLT0209ec@@80WWA20P2JLC/00`2JLCd0
VW0n09Y`@00209Y_@P0409Y_A02MLd40W79009Y`?P80V6hl00H0VFlm09Y`?P2KLCl0Vg4o09Y`?P2H
KS`209M]>`0309Q^?02JL3h0Vg4o00<0VW0n0P2IKcd309Q^?0T0VW0n0P2IKcd00`2HKS`0Ufdk09I/
>P0209E[>@<0Uf`o0`2HKD0309U^@@<0VW0n00<0VFlm09Q^?02HKS`00P2GKC/0102EJcT0UV`j09I/
>P2FK3X209M]>`80V6hl00T0TVHi09=X>`2EJSd0UVdo09E_@02DL400TFlo091^?P2FK3X00P2EJcT0
1@2DJSP0TVPf095W=@2AIcD0T6Hd00P0U6Tl00H0UG0l09A_>`2CKSX0TVdi091[=`2?JSH208iY=@P0
TFHi00<0SfXm08iY?02=J3/00P2=J3/00`2?JSd0TF`o099]@00408iX>`80SfTl0P2@JSd308m[>b_o
oooo000Zooooo`<0QEhe0`26GcH208MP=`0408aP>@2;GcP0Relh08]O>0@0RUhg0`2;GcP208YN=`<0
REdf202;H3D02`2:Gc@0Rf0e08aQ=P2=HSL0S64f08]P=@29GS<0R5db08iS>02=HSL0S64f0080Rf0e
00<0S64f08eR=`2>HcP0102=H3H408iQ=`0608aO=@2=H3H0SF0f08iQ=`2?HSP0T6<i0P2AI3X308eQ
>P<0SV8k0P2?Hc`0102@HSh0T6<l095T?@2AI3/2095T>P03099V>@2BISL0TVHg00P0TFDh0P2@I3L0
102AICP0TVHi09=W>P2DJ3/209EY?0<0TVLj0`2CJ3/209AY?080T6Dh0P2AIST2099W>P80TfPk202F
JST209=W>P0309EY?02FJSd0Uf/n0080UVXm00<0UFTl09AX>`2DJ3/01`2DJ3/01@2EJC`0UVXm09IZ
?@2FJSd0UFTl0080U6Pk0P2DJ3L209EY>080UVXi2P2GJcX309U]?0<0V6`k0P2GJcX@09U]?00309a`
?`2KKch0VFdl0080V6`k00<0VFdl09]_?P2LL3l02P2KL3d0102LLCh0WG8o09ic@02NLd0209md@@80
X7A300@0Wg=209ib@@2MLD00WG500P2LL3l809md@@<0X7A30P2OLd8409ib@@80WW=00P2MLSl02@2N
Ld00X7E20:9gA02SN4D0XGI30:1e@P2OM440WW=009eb?`0209ic@00709md@@2ULT<0Xg=30:=c@`2R
M4<0X7A309me@`0209if@`030:5f@`2RMd@0XgQ50080YGY700<0XgQ50:9gA02QMT<0202RMd@0102R
MTD0XgM60:=gAP2SMdH40:AhA`060:1e@P2QMT<0XGI30:9gA02SN4D0Y7U60P2UNTL80:EjA@80YGU8
0P2VNTT20:MkBP80Z7a;00<0YW]80:MlB@2XODX00P2XODX00`2VNdP0YGY70:AiAP020:QmBP80Yga9
0P2VNdP20:EjA`080:Eg@`2VN4@0Y7U40:AkA@2TODH0Xgi70:AoB02SP4P20:QoB@<0Ygi80`2VODL8
0:QoB@<0Z7e:0P2YOT/30:YoC0040:MnB02XOdT0Z7m90:QoB@80ZH1:0P2ZPD/0202YP4X0ZX5;0:^2
C02/Pdd0Zh9<0:Z1B`2XOdT0Ygi8202ZOd`20:^2C0<0ZX5;102YP4X80:b1CP80[8==0P2[PT`20:Z1
B`80ZH1:0`2]PTl20:b1CP<0Zh1=0`2/PDh20:f2C`<0[X=@0P2YP4X00`2YP4`0ZGm=0:UoC`020:Un
D@030:UnD`2ZPDd0ZX5=0080ZH1<0`2XOd/0102WOTX0ZWm<0:YoC02YOT/20:QmBP030:UnB`2ZOd`0
ZWm<00<0Zh1=0P2ZOd`30:UnB`0;0:YoB02YOTL0Yga70:EjA`2TNDH0Y7Q70:AhB@2UNDX0XGa80:9m
B@2SOTX00P2TOd/01`2RODT0X7]709mjAP2PNdH0XWe80:AoBP2VPD`00P2XPdh20:N2C@P0Z7m90P2U
Nd/0102UNdT0YGa80:ElB02UO4H20:ElA0060:MnBP2VODT0YWe90:ElB02TNdL0XgY62P2RNDD809Ye
?P0309mf@P2NMD40WGA00080W7<o00T0WGA009ie@@2OMT80WGA009ec@@2LLT00W79209aaA02LLDH0
0P2LLDL909ab@00309U`?02JLCd0Vg8n0080W7<o00<0Vg8n09Ya?@2IL3`00P2HLch309Mb?@D0UW4l
0P2GLSd409Qc?PP0VW0n0P2MLd4209ab@0@0Vg4o0P2HLcl209Ud@0@0VWE10P2KMT8309Ye@@<0VGA0
0P2NMD4209mf@P@0X7M300H0XWQ60:5gA@2QMdD0X7I409me@`2NM48209ec@@080:1g@`2OMT80WgI2
09ie@@2OMT80XGQ40:=jAP2UO4P30:=jAP80Y7]70`2UO4P80:ElAPP0Ygi80`2UO4P20:ImB@<0Ygi:
00<0YWe90:QoB`2YP4`00`2[PTh0102ZPDd0ZH1<0:Z1C@2ZPDd20:V0C0@0Z7m;202ZPD/80:Z1C@80
[8=;00@0[8==0:f4D02]Q500[XAB0P2^Q5@50:f4D080[XEA0P2_QU890:j5D@070:f4D02/Pdl0Zh9>
0:^2CP2]Q500[hIB0;27D`080:j5D@80[HA@0`2^QE4;0:n6DPP0/8MC202aQeD80;27D`040;68E02`
Qe<0/8MC0;27D`<0[hIB00<0[XEA0:f8E02]R5@01P2]R5@0202[PTh0[hIB0;:9E@2aR5@0[HA@0:^2
CP2]Q500/8MC202_QU800`2/Qe80[HQC0:j9E0020:n:E@030:j9E02]R5<0[8MB00<0/8MC0`2aR5@2
0;:9E@P0/XQF0P2_RUH30;2;E`<0/HaH0P2bRED0102dReL0]HaH0;F<F02eS5P20;B;E`050;68E02b
RED0/hYF0;B;E`2eS5P00P2dReL0102cRUH0/XUE0;:9E@2bRED20;68E0<0/8MC00<0[hIB0;68E02b
RED00P2bRED20;>:EP80]8]G0140/8]D0;6<E@2aS5L0/HaH0;:<F`2bS5d0/XaO0;>=H02fRf40]HYP
0;>8G@2aQUT0/8IF0;67E@2bR5H0/XUE0;>:EP030;B;E`<0]HaH00<0]XeI0;>:EP2cRUH01`2cRUH0
1`2bRED0/HQD0;27D`2`Qe<0/HQD0;:9E@2cRUH0202aS5P30;67E@80/8ID0`2_QE<40;27D`@0[hIB
202`Qe<80:j5D@P0[H=A0`2/Pdd20:f4CP<0[XE?0`2^QE420:f4D0H0[8=?0P2[PTh30:Z1C@030:Z1
B`2[PT`0[HA>0080[hI@00@0[XE?0:f4CP2/Pdd0[8=?0`2]Q5020:j5D@80[hIB202YQ5002@2ZOe80
Zh5A0:b2D02/PU00[H=A0:f4CP2/Pdd0Zh9:0:Z2A`080:b3C`<0Zh9>0`2/Pdl20:f4D100[89@0`2/
PDh30:f2C`80[X=@202[PTh:0:f4D0<0[8=?0`2[PTh80:b3C`P0[8==0`2[PTh30:b3C`X0[HA@202/
PD`20:f2C`80[85>0P2[P4d20:YoC0030:^0B`2ZOdX0ZWm:00@0ZWm:00T0Zh1;0:^0C@2ZOd`0ZGi;
0:QmBP2YOT/0ZWm<0:b1CP2]PTl0202[P4/00`2ZPDd0Zh9>0:b3C`020:b3C`030:Z1C@2YP4`0Z7m;
00<0Zh5?0`2ZP4h30:UoC@040:ImB@2XOd/0ZX5=0:b3C`80[HA@00<0[8=?0:^2CP2[P4d01`2[P4d2
0:YoBP80Zh1;0P2/PD`20:f2C@<0Zh1=0P2/PDh30:f2C`<0Zh5?0`2/PU020:f3D@080;68D02_QTh0
[8==0:Z1C@2YP4`0Zh5?0:f3D`2^Q5@50:V4C`<0ZXE@202[PTh80:^0B`80ZH1800@0ZH1:0:V0C02Y
P4`0ZGm=0P2YOdl80:Z1C@P0ZWm:0P2[P4/20:YoBP<0ZGi900<0Z7e80:YoBP2ZOdX01P2ZOdX20:f4
D0040:b3C`2[PTh0ZH1<0:QoB`80Ygi:0P2ZPDd0102YP4`0Z7m;0:QoB`2WOTX20:ImB@80YGa800<0
YWe90:MnBP2XOd/00P2YP4`0102ZPDd0ZH1<0:MnBP2UO4P20:=jAP040:ElB02WOTX0ZH1<0:MnB0<0
Z7m90P2YP4X30:Z1B`040:^0C@2YOT/0Z7e:0:IkB080YGY70P2VNdP@0:MnB080Y7Y80P2UNdT20:Il
BP80Yge;00D0Ygi:0:ImB@2UO4P0Y7]70:=jAP020:AkA`040:ElB02WOD/0YWa:0:EkB@80Y7Y800<0
YG]90:IlBP2WOD/0202WOTX02@2WOD/0YWa:0:IlBP2UNdT0YWa:0:MmB`2XOT`0ZGm=0:EiB0030:Ij
B@<0Yg]:00<0Z7a;0:ElB02UO4P00`2VODT00`2UO4P0XgY60:9iA@040:=jAP<0Y7]700<0YGa80:5h
A02RNDD00P2RNDD<0:=jAP<0YGa80P2VODT30:MnBP060:MmC@2VO4`0YWa:0:ElB02TNdL0XgY40P2R
ND401@2VODT0YGa80:AkA`2SNTH0XWU50080XgY600<0Y7]70:ElB02VODT01P2VODT20:9hB0070:9h
AP2RNDD0XgY60:AkA@2VODD0Ygi60:9hAP030:=iA`<0Y7Y80P2UNdT20:AiAP<0YGY70`2VNdP50:Ak
A`<0XgY6202PMT@01P2ULT<0Xg=30:=c@`2SMD@0XGE40:1fA080X7Q5202OMD<20:5c@P0309mc@P2N
M480WGE20080VgI200@0VWI20:1fA02OMD<0WG=10`2KLCl01@2LLT00WG=109a`?`2MLD00WW910080
X7A300<0WW9109ea@02LL3l01`2HM400102IMD40Vg4o09]a?`2KLCl309Y`?P80VFlm202GLD8209]a
?`<0W7900`2MLd4209Ya>`0309Ya?@2JL3h0VW100080VVm200@0VVm409ec@@2KLCl0VW0n0`2HKS`0
102IKcd0VW0n09Y`?P2JL3h409Q^?080VW0n0`2HKS`209U_?@<0VW0n202HKS`809I/>P<0Uf`o0`2H
KD0309U^@@0409Y`?P2IKcd0VFlm09U_?@<0V6hl00@0Ufdk09Q^?02HKS`0V6hl0P2GKC/309I/>P09
09=W>P2CJ3/0UFXm09I]?`2EKd00U710095_?`2@KSh0UV`j0080UF/i00<0U6Xh09=Y=`2BJ3H00P2A
IcD809EZ?@80UG0l00@0U6lk099]>@2AK3P0SfXf0P2>JCD8095V>@0308mZ?@2>JC`0SFPk0080SFPk
00<0SfXm095/?`2BKD000`2>J3/208mY?0<0T6Xm0`2?Jc/[ooooo`00:_ooool308EN=@<0QUlf0P27
H3L01P2=HCX0S60i08aP>@2;GcP0RUhg08UM=P80R5`e0P2<H3T0102;GcP0RUhg08YN=`29GCH208QL
=@P0Rf0e00<0RUld08]P=@2<HCH00P2=HSL01P2<HCH0RUld08UN<`2?I3T0SV<h08]P=@80RUld00@0
Rf0e08iS>02?I3T0Sf8h0`2>HCL308eP=P0308aO=@2=HC@0SF4d0080SV8e00@0Sf<f091T=`2@I3L0
T6@g0`2=HSP308iS>@80Sf@j00@0T68n091S?02AI3d0TF@k0P2AI3X00`2BIST0TVHg099V=`08095U
>080T6@g00@0TFDh099V>@2CIcX0U6Pk0P2EJC`209=W>PH0U6Pk0P2@ICP2095V>@80TVLj0P2CJ3/8
09EY>00409=W>P2DJ3/0U6Pk09EY?0@0UVXm202CIcX0102EJCX0UVXk09IZ>`2FJS/209EY>P80U6Pi
0P2CIcH209AX=`<0UFTh00D0UVXi09EY>02FJST0UVXi09M[>P0209Q/>`80VFdl00H0W70o09]_?P2K
Kch0VVhm09U]?02HK3/209M[>PP0VFdl202JKSd00`2LL3l0Vfln09U]?00209Q/>`0309U]?02KKch0
W70o00P0WG8o0P2LLCh209eb?`80WW=00P2OM4420:5eA0060:1d@`2NLT40WG5009a`?`2KKch0VVhm
202OM4430:1d@`80Wg=2102NLT401`2OM440WW=009eb?`2MLSl0WW=009md@@2QMT<00P2RMd@0202P
MD80WW=009]`?@2KL3d0W74n09ic@02PMD80YG930P2SLd<00`2RM4<0X7A309me@`0209if@`030:5f
@`2RMd@0XgQ50080YGY700<0XgQ50:9gA02QMT<0202RMd@20:5eA0040:9fA@2SMdH0XgM60:AhA`80
YGU80P2QMT<20:9gA0040:=hA@2TNDH0Y7U60:AiAPP0YGY50P2UNDP20:IjB@80Yg]:0P2XO4/50:Ml
B@030:IkB02UNTL0YGY70080Z7e:0P2WO4T20:IkB080YGY70P2VN4@00`2UNTD0YGa60:EnA`020:Ao
B0060:B1B@2YP4X0ZH1:0:QoB@2WOTP0YWe70P2UO4H00`2TNdD0Z7m90:QoB@060:QoB@P0ZGi;0`2X
OdT20:V0BP@0ZX5;00L0Zh9<0:b3C@2/Pdd0[8==0:Z1B`2XOdT0Ygi800P0ZWm<0P2[PT`70:Z1B`P0
[85<0P2/Pdd20:^2C080ZX5;0P2YP4X20:f2C`<0[85>1P2[P4d20:b1CP<0[H9?0P2YP4P0102YP4X0
ZH1<0:UoC@2YOdl20:UnD@<0ZH1<0`2XOd/20:MnBP030:UnB`2XODX0Z7e:00@0Z7e:00@0ZGi;0:^0
C@2[P4d0Zh1=0P2ZOd`30:UnB`80Z7e600@0Yga70:IkB02UNTL0Y7Q70P2TN4T01`2PNdL0XGa80:9m
B@2SOTX0XWe90:5lB02ONTH00P2NNDD00`2ONTH0XWe90:AoB`040:J1C@P0YWe90P2TNTX0102TNTP0
Y7]70:AkA`2TNdD20:Ak@`80YGa80P2TNdL20:=jAP@0XWU5102QN4@20:1g@`P0Vg@m00<0WWE109ed
@02KLSh00P2JLCd0102KLSh0WGA009ie@@2JLCd209Y`?P0309]a@@2KL4<0W7560080W7572@2JL3h0
0`2HKS`0VFlm09U_?@0409U_?@0309Q^?02HL3d0V70m0080V70m102GKc`409Ia?@@0Ug8n202IKcd5
09]a?`<0VW0n202HLcl809Ud@0@0WWE1102OMT820:1fA080WgE30P2NM48209ec@@030:1g@`2OMT80
WWE10080WWE100<0X7M30:9iA@2SNTH00P2QN4@20:9iA@<0XgY600<0Y7]70:AkA@2TNdD01P2TNdD8
0:QoB@<0YGa80`2VODT20:MnBP080:ElB02WOTX0ZH1<0:Z1C@2[PTh0ZX5=0:V0C02XOd/20:V0C0H0
Z7m;202ZPD/80:Z1C@80Zh9:00@0[8==0:b3C`2/Pdl0[H=A0P2]Pe<20:Z1C@050:^2CP2/Pdl0[HA@
0:j5D@2_QU800P2`Qe<80:f4D0030:j5D@2]Q500[8=?0080Zh9>00<0[HA@0:n6DP2`Qe<02P2]Q503
0:j5D@/0[hIB202`Qe<30;>9E`@0/XQF00<0/HME0;27D`2`Qe<02P2`Qe<40:n6DPP0[HQD00P0ZX5=
0:j5D@2bRED0/HQD0:j5D@2/Pdl0[HA@0;27D`P0[hIB00<0[HQC0:j9E02^RE@0102^RE@0102]R5<0
/8MC0;27D`2`Qe<30;68E080/XUE202bR5H60;2;E`80/HaH0`2cRUH40;B;E`030;>:EP2bRED0/XUE
0080/hYF102dReL30;>:EP80/XUE0`2aR5@0102`Qe<0/XUE0;:9E@2bRED20;>:EP<0]8]G00@0/HaG
0;6<F02aS5P0/HaH102bS5/0202gS640]X]P0;B9G02bR5P0/HME0;68E02bRED0/XUC102dReL40;F<
F0P0/hYF00<0]8]G0;:9E@2aR5@00P2`Qe<00`2aR5@0/XUE0;B;E`080;6<F080/XUE0P2aR5@20;27
D`80[hIB102`Qe<40:n6DPP0/8MC202^QE430:j4DP80[H=A0`2/PU030:b3C@80[HA>0`2^QDl30:j5
D@80[HA@1`2/Pdl40:^2CP030:^2C02/Pdd0[XE?0080[hI@00<0[XE?0:f4CP2/Pdd00P2/Pdl30:f4
D0<0[XEA202ZQE40102[PDl0[89@0:b2D02/PU020:b3C`80[8==00<0Zh9<0:b3C`2/Pdl01P2/Pdl3
0:^2CP<0[8=?0`2]Q5040:b3C`<0Zh9>0`2[PDl40:b2D0040:f3D@2/PDh0[85>0:b1CP<0[H9?0P2^
Pe030:Z1C@030:^2CP2/Pdl0[HA@00`0[HA@0`2/Pdl30:^2CQ00[8=?0P2[PTh60:b3C`P0[HA@202/
PD`20:f2C`80[85>0P2[P4d20:YoC0030:b1C02[P4/0ZWm:0080ZGi900/0ZWm:0:^0B`2/PD`0Zh1=
0:YoC02YOT/0Z7e:0:UnB`2ZOd`0[85>0:f2C`080:^0B`030:Z1C@2[PTh0Zh9>0080Zh9>0`2ZPDd3
0:^1C`@0ZX1>0P2YOdd0102VODT0Z7m;0:Z1C@2/Pdl20:f4D0030:b3C`2[PTh0Zh1;00L0Zh1;0P2Z
OdX20:^0B`80[85<0P2]PTd40:b1CP@0[H9?0`2[PDl30:b2D080[H=A00P0/HQ@0:n6CP2]Q4h0[8=?
0:^2CP2/PU00[H=C0:n5E@80Z8=>102YQ4l20:Z5D0P0[8=?202[P4/20:V0B0040:V0BP2YP4`0ZH1<
0:UoC@80ZGm?202ZOd`80:YoBP<0Zh1;0P2ZOdX30:UnB@P0ZWm:00P0/8MC0:n6DP2^QE40[8=?0:Z1
C@2XOd/0Ygi:0:ImB@80Zh9>00@0ZX5=0:V0C02WOTX0YWe90`2UO4P20:ImB@030:MnBP2XOd/0ZH1<
00<0ZX5=00L0Ygi:0:=jAP2PMd<0X7M30:=jAP2WOTX0ZX5=00H0ZX5;0`2YP4X20:QmBP030:MlB@2V
NdP0YGY700<0YGY7402WOTP20:AjB080YG]90P2VO4X20:MmB`030:MnB02VODL0YWe70080YGa60`2T
NdD20:IlBP@0YG]90P2VO4X80:MnBP@0YWa:0P2WOD/20:QnC0@0YWY9102WNdX40:ImB@80YGa80P2T
NdL20:9iA@040:=jAP2TNdL0Y7]70:ElB080YWe900H0X7M30:5hA02QN4@0XWU50:=jAP2TNdL20:El
B0P0XWU50`2UO4P30:ImB@80Ygi:00P0ZGm?0:QnCP2WOD/0YGa80:=jAP2RND<0XGQ00:1g?`80Y7]7
1P2SNTH30:AkA`@0YGa800T0YWe90:9hB02RN4P0XWQ60:=jAP2TNdL0YGa60:ImA@2WOTH00P2RN4H3
0:=iA`@0Y7Y80P2TNDH30:EjA`<0YW]80P2UO4P40:AkA`80XgY60`2QMdD40:1fA00709me@`2TLD80
XW920:9b@P2QLd80X7A309me@`0209mgA0P0WgE30P2QLd800`2OLd80WWA209ee@P0209]f@P0409Yf
@P2PMT@0WgE309ec@@<0Vg4o00D0W79009ec@@2LL3l0WG5009ib@@020:1d@`0309ib@@2MLD00W70o
00<0VgI20`2JMD4209Ud@080WG=100@0W79009]a?`2KLCl0VW0n0P2IKcd809Ma@P80Vg4o1P2LLT02
09Ya>`0309Ya?@2JL3h0VW100080VVm200T0VVm409ab@02KLCl0VFlm09Q^?02GKC/0V6hl09U_?@2J
L3h0202IKcd209M]>`0409Q^?02IKcd0VFlm09Y`?P80Vg4o202FK3X209=Y=`80U6Xh00@0UF/i09I/
>P2FK3X0Ufdk0`2GK3l309Q]@0<0VFi1202HKS`0402KLCl0VW0n09U_?@2HKS`0Ufdk09I/>P2EJcT0
U6Xh09=W>P2CJ3/0UV/n09M^@02FL440U710099`@02AKcl309E[>@0309AZ>02CJCL0TfTg0080TVPf
202EJSd0202FLCd0UG0l09A_>`2CKSX0TF`h091[=`2?JSH0SVTe202BJ3P00`2?JSd0SVTl08eX>`02
08eX>`0308mZ?@2AK3l0TVe00080SVPk0P2?JC`2091Z?@80TF/n0`2?Jc/[ooooo`00:_ooool308EN
=@<0QUlf0P27H3L208aP>@0308]O>02:GSL0REdf0080R5`e00@0Qe/d08aP>@2<H3T0Relh0P2:GSL0
0`29GCH0R5`e08QL=@0808]P=@0308UN<`2:Gc@0S64f0080SF8g00H0S64f08]P=@2:Gc@0Sf@i08iS
>02;H3D208YO=00408]P=@2>HcP0Sf@i08mR>0<0SV4g0`2=H3H0102<GcD0SV8c08iR<`2>HS<408mS
=004091T=@2=HSL0SF8g08eR=`<0SV<h0P2?I3T0102@HSh0T6<l095T?@2AI3/2095T>P03099V>@2B
ISL0TVHg00P0TVHi0P2@I3L0102AICP0TVHi09=W>P2DJ3/209EY?0H0UVLk0P2EISX2091U>080TFHi
0P2BIcX209=X>`P0UFTh102DJ3/0102EJC`0UVXm09IZ?@2GJch809=W>P80Uf/j00<0UVXi09EY>02D
J3L00`2DJ3L209=W=P80U6Pg0`2EJCP01`2FJST0UFTh09IZ>@2FJST0Uf/j09Q/>`2IKC`00P2JKSd0
1P2LL3l0Vfln09]_?P2JKSd0VFdl09Q/>`80Uf/j202IKC`809Y^?@0309a`?`2KKch0VFdl0080V6`k
00<0VFdl09]_?P2LL3l02P2MLSl409ic@080WgA10P2QMD@01P2PM4<0WW9109ea@02LL3l0Vfln09Y^
?@P0WgA10`2PM4<209mc@P@0WW9100<0X7E209md@@2NLd000P2MLSl0302OM440X7E20:9gA02SN4D0
XGI309ic@02LLCh0Vg0m09eb?`2OM440X7E20:IcA080Y7A400<0XgE40:5eA02PMT@00P2OMd@00`2Q
MT<0XWM40:=hA@020:EjA`030:=hA@2RMd@0XGI300P0XGI300D0X7A30:5eA02QMD@0XWI50:=gAP02
0:AhA`040:EiB02RMd@0XWM40:9gA0@0XgQ500<0Y7U60:EjA@2UNTD01P2UNTD20:EiB080YWY90P2W
NdX20:QlB`80Z7e:00<0Yga90:IkB02VNdP00`2VNdP20:QmBP80Yga90P2VNdP20:EjA`080:IhA02W
NDD0YGY50:ElAP2UOTL0Y7m80:F0B@2TPDT20:V0BP030:QoB@2WOTP0YWe70080YGa600<0Y7]50:Qo
B@2XOdT01P2XOdT80:UnB`80Z7m90P2YP4X20:Z1B`80Zh9<00P0ZX5;0:^2C02/Pdd0[HA>0:b3C@2[
PT`0ZH1:0:QoB@P0ZWm<0P2ZPD/70:^2C0P0[85:0P2/Pdd20:^2C080ZX5;0P2YP4X30:b1CP<0Zh1=
1@2ZOd`20:^0C@<0[85>0P2YPDH0102YP4P0ZH1:0:V0C02YOdd20:UoC`80ZH1<0`2XOd/30:MnBP<0
Yga90P2XODX30:MlB@<0ZWm<0P2YOT/30:QmBP80Yga500P0Yga70:IkB02UNTL0Y7Q70:=gB02RMTL0
WgY60:1kA`<0XGa800L0WgY609iiA@2LMd<0WGM609ihA`2QNdX0Xge<0080Y7i=0P2SOD`80:ElB080
XWQ800@0XWQ60:9iA@2RNDD0XWU30P2RND440:=jAPD0XWU50P2QN4@20:1g@`80WgI200<0WWE109]b
?02KLS`01P2KLS`00`2MM400W7<o09Ya?@0209U`?00409Ya?@2LLcl0WGA009Q_>`80VFlm00D0VFlo
09Y_@P2JKd@0VVm509]`AP0909Q^?0<0Ufdm0P2FK3`;09M]?@@0UW0o102EKch:09U_?@H0VW0n102G
LSh409Ia?@P0V7<o102NMD4409ed@0@0WWA2102MLd400`2PMd<0WgI209ie@@0209ed@00309mf@P2P
Md<0XGQ400<0X7M30P2QN4@30:9iA@P0XWU3202WOTP20:AkA`<0YGa80`2VODT01`2UO4P0YWe90:Qo
B`2YP4`0ZX5=0:V0C02XOd/00`2WOTX60:QoB`P0ZH1:202YP4`20:Z1B@040:^2C02[PTh0[8=?0:b2
D080[89B0`2YP4`01P2[PTh0[8=?0:j5D@2_QU80/8MC0;68E0P0[HA@00<0[XEA0:f4D02/Pdl00P2[
PTh00`2]Q500[hIB0;27D`0:0:f4D0<0[XEA0`2_QU880:j5D@P0/8MC0`2dRUP00`2cREL0/XQF0;:8
EP020;67E@P0/8MC102_QU840;27D`P0[8MC00P0ZH1<0:j5D@2bRED0/XUE0:n6DP2/Pdl0[HA@0:n6
DPP0[XEA0`2^RE@20:f8D`<0[XUD0`2`Qe<30;68E080/XUE202bR5H20;6<F0H0/8]G0P2dReL20;>:
EP040;:9E@2cRUH0/hYF0;>:EP<0/XUE0P2cRUH20;B;E`030;F<F02dReL0/hYF00<0/hYF0P2bRED2
0;68E080/XUE0P2cRUH20;B;E`80]HaH102bS5/30;6<F0090;6<E`2gS5l0]X]N0;B:FP2bR5H0/HQD
0;:9E@2cRU@0/hYB00@0]HaH102dReL80;>:EP030;B;E`2cRUH0/XUE0080/8MC00<0/XUE0;>:EP2d
ReL0202`ReL30;:9E@80/HQD0`2`Qe<20;68E080/8MC0P2_QU820:j5D@P0[hIB202^QE430:j4DP80
[H=A0`2/PU030:b3C@80[HA>0`2^QDl30:j5D@80[HA@2`2/Pdl00`2/Pdd0[HA>0:j5C`020:n6D003
0:j5C`2/Pdd0Zh9<00<0[8=?0`2]Q5020:j5D@P0ZXEA102/Pdd20:^2CP<0[89@202/Pdl30:^2CP<0
[8=?1@2]Q5000`2/Pdl0Zh9>0:^2CP020:Z1C@80ZX1>0P2[PDl0102/PU00[H=A0:f3D@2]Pe430:b1
CP<0[H9?0P2^Pe00102YP4`0ZX5=0:^2CP2[PTh20:f4D0030:j5D@2_QU80[HA@00T0[HA@0`2/Pdl3
0:^2CQH0[8=?0P2[PTh80:f4D0P0[85<0P2]PTl20:b1CP80Zh1=0P2ZOd`00`2/PD`0Zh1;0:UnB@02
0:QmB00;0:UnB@2[P4/0[85<0:^0C@2ZOd`0ZGi;0:QmBP2YOT/0ZWm<0:b1CP2]PTl0202/PD`00`2[
PTh0ZX5=0:Z1C@020:Z1C@<0Zh9>0P2/PU040:^1C`<0ZX1>00@0YWe90:QoB`2ZPDd0[8=?0P2]Q500
0`2/Pdl0Zh9>0:b1BP070:b1BP80ZWm:0P2[P4/20:b1C080[H9=202]PTl30:^1C`<0[89@0P2]Pe40
0`2`Qdl0[hI>0:j5C`020:b3C`030:b2D02]Pe<0[XAD0080Yh9=0P2XPdh20:V4C`80ZXE@202/Pdl8
0:YoBP80ZH1800@0ZH1:0:V0C02YP4`0ZGm=0P2YOdl80:anC0P0Zh1;0P2/PD`20:^0B`80ZWm:0P2Y
OTT80:^0B`080;27D`2_QU80[XEA0:b3C`2ZPDd0Z7m;0:MnBP2VODT20:^2CP040:Z1C@2YP4`0Ygi:
0:ImB@80YGa80P2VODT00`2WOTX0Z7m;0:V0C0020:Z1C@040:^2CP2ZPDd0Ygi:0:=jAP80X7M300<0
XgY60:MnBP2ZPDd00`2[PT`00`2ZPD/0ZH1:0:V0BP020:V0BP030:QoB@2VNdP0YW]80080Yga90P2V
NdP20:EjAa00Ygi80P2TNTP20:EkB@80YWa:0P2WOD/30:MnAP80YWe50P2UO4@00`2TNd<0YG]90:Ek
B@040:IlBP80YG]9202WOTX00`2UNdT0YWa:0:IlBP020:MmB`<0Z7i<102WNdX40:IjB@80Ygi:0P2V
ODT40:ElB0050:9iA@2SNTH0XgY60:AkA`2UO4P00P2VODT01P2WOTX0XGQ40:5hA02RNDD0XgY60:Ak
A`80YGa800<0YWe90:=jAP2SNTH01P2SNTH20:AkA`<0YGa80`2VODT20:UoC`060:MmB`2UO4P0XgY6
0:5h@P2PMcl0WgHn0P2RNDD60:=jAP80XWU50P2SNTH0102TNdL0YGa80:ElB02UO4P20:9hB0040:=i
A`2TNdL0YGa80:ImA`80YWe50`2RN4H40:=iA`80Y7Y80P2TNDH30:EjA`<0YW]80P2VODT20:ElB080
Y7]70P2SNTH30:9hAP030:5gA@2PMT@0X7I40080WgE300H0Y7520:9b@P2RLT80XG=20:1d@`2OMD<2
09mgA0P0WgE30P2QLd800`2OLd80WWA209ee@P0209]f@P0409Yf@P2PMT@0WgE309ec@@<0Vg4o00D0
W79009ec@@2LL3l0WG5009ib@@020:1d@`0309ib@@2MLD00W70o00<0WGE20`2LM44209]c@080WWA2
00@0WG=109ab@02LLT00Vg4o0P2JL3h809Ma@P80W7901P2KLCl209Ya>`0309Ya?@2JL3h0VW100080
VVm200@0VVm409ab@02KLCl0VFlm0`2GKC/00`2HKS`0VFlm09U_?@0709U_?@80Ufdk00@0V6hl09U_
?@2IKcd0VW0n0P2KLCl809I/>P80TVPf00@0TfTg09AZ>02EJcT0UV`j0P2GKC/309M/?`<0V6e00`2I
KT4409M]>`@0V6hl0100W79009]a?`2JL3h0VFlm09M]>`2FK3X0UF/i09AZ>02DJ3/0U6Tl09I[?P2G
KT00UW1109Ea@@2BL400TFlo0`2EJcT409AZ>00309=Y=`2FJch0UV/n00H0UV/n0P2FLCd0102EL3`0
Tfhj099]>@2@JcL208mZ=PP0TfTg00<0SfXm08iY?02=J3/00P2=J3/00`2?JSd0TF`o099]@00308mY
?080T6Xm0`2AJch308m[>b_ooooo000Zooooo`<0QEhe0`26GcH208MP=`@0RUhg0`29GCH01028G3D0
Relh08]O>02;GcP208YN=`<0REdf202;H3D00`29GS<0RUld08aQ=P0208iS>00608eR=`2<HCH0Rf0e
08iS>02=HSL0S64f0P2;H3D00`2<HCH0SF8g08iS>00408eP=P@0SV4g202?Hc8308eR=@<0SV<f0P2?
I3L0102@HSh0T6<l095T?@2AI3/2095T>P03099V>@2BISL0TVHg00P0TVHi0P2@I3L0102AICP0TVHi
09=W>P2DJ3/209EY?080V6Ll0`2GIS/309IU>P80T6Dh0P2AIST2099W>P80TfPk202DJ3L01P2EJC`0
U6Pk09AX>`2CIcX0U6Pk09EY?080Uf/n202EJC`0102IKS/0Uf`i09I[>02DJCH209=X=@80U6Tf0P2D
J3L209EY>080UVXi0P2GJcX209IZ>@0409M[>P2HK3/0VFdl09U]?080VVhm0`2IKC`309Q/>`80Uf/j
202IKC`809]_?P0309a`?`2KKch0VFdl0080V6`k00<0VFdl09]_?P2LL3l0202MLSl509ic@0<0WgA1
0P2PM4<0102OLd80WW9109ea@02MLD0209a`?`P0WgA10`2PM4<209mc@P@0WW9100<0XGI30:1e@P2N
Ld000P2MLSl01P2NLd00X7E20:5f@`2SN4D0XWM40:1e@P<0WgA10P2PMD801P2VLd@0Y7A40:AdA02S
MD@0XGE40:1fA080WgM400<0XGI30:9gA02SN4D00P2UNTL00`2SN4D0XWM40:5f@`080:5f@`80XGE4
0`2RMTD30:=gAPP0XgQ5202UNTD20:EiB080YWY90P2WNdX20:QlB`030:UnB`2XODX0Yga900<0YGY7
00@0YW]80:MlB@2XODX0Z7e:0P2WO4T20:IkB080YGY70P2WNDD00`2VNdH0YWe70:IoB0020:F0B@03
0:F2BP2XOdT0Z7m900<0Ygi80`2VODL80:QoB@<0ZWm<0P2YOT/30:QmBP<0ZH1:0P2ZPD/50:^2C0<0
[HA>00<0Zh9<0:V0BP2XOdT0202ZOd`20:Z1B`<0Zh9<102/Pdd80:b2B080[8==0P2[PT`20:Z1B`80
ZH1:0`2/PDh20:^0C@<0ZWm<0`2YOT/20:YoC0<0Zh1=00H0ZH540:V1AP2YPDH0ZH180:V0BP2YP4`2
0:UoC@040:V0C02XOd/0Z7m;0:QoB`80Ygi:0P2VODT00`2UNTL0YW]80:MlB@020:QmBP030:MlB@2V
NdP0YGY700<0Z7e:0P2WO4T30:IkB080YW]401H0YW]60:IkB02UNTL0Y7Q70:9fA`2QMDH0WGQ409ii
A@2ONTH0X7]709mjAP2NNDD0W7M309]f@P2MMdP0WWQ90:1jB`2QNd`0XWa=0:5kC02PNT/0WgU:202S
NDL20:5gA`040:5gA@2QN4@0XGQ40:5h@P80XGQ01`2RNDD30:5hA080X7M300@0WgI209ie@@2MM400
WGA0202KL3/00`2KLSh0VW4m09U`?00209Q_>`0409U`?02JLCd0Vg8n09Q_>`80V6hl00<0V6hn09Q]
@02HKD800P2HKD<909I/>P80UV/n102DJC`209I[?P@0UVXm0P2GJch209Q/?`80UW110P2EKd0409A^
?`/0V6hl0`2IKcd209Y`?P<0UW4m0`2EL3`209A_>`80UW4m0`2GLSh309Qc?`80WWE10P2MM40409ac
?`L0WG=100@0W7900:1g@`2OMT80WGA00P2LLcl0102MM400WgI20:1g@`2NMD4309mf@P80X7M30P2Q
N4@80:5h@PP0YWe70`2TNdL20:ElB0<0YWe900L0Y7]70:ElB02WOTX0Z7m;0:V0C02XOd/0Ygi:00<0
YWe90P2WOTX40:QoB`P0ZH1:202YP4`20:V0B0060:Z1B`2ZPDd0Zh9>0:^1C`2[PE40[89B0P2YP4`2
0:Z1C@050:b3C`2]Q500[XEA0:n6DP2`Qe<0202/Pdl00`2^QE40[HA@0:b3C`020:^2CP030:f4D02_
QU80/8MC00P0[8=?0P2]Q5030:j5D@<0[hIB202^QE480;27D`80]8YH0P2cREL0102bR5H0/HME0;26
E02`QU@80;27D`040:j5D@2_QU80[hIB0:n6DP<0/8MC00<0/HQD0:b7D`2/Qe<01P2/Qe<01@2YP4`0
[XEA0;>:EP2cRUH0/8MC0080[8=?2@2^QE400`2_RUD0[XUD0:f8D`020:b7DP030:f8D`2^RE@0[hYE
00<0/8MC0`2aR5@20;:9E@P0/XQF0`2aS5P30;2;E`80[hYF00@0]HaH0;B;E`2cRUH0/XUE0P2aR5@0
102bRED0/hYF0;>:EP2cRUH30;:9E@040;>:EP2eS5P0]XeI0;F<F0@0]8]G0P2cRUH20;:9E@<0/hYF
0P2dReL30;F<F00;0;>=H02bS5l0/XaM0;:<F`2aS5P0/HaG0;6<E@2`Re@0]XaL0;F;F`2cREL00P2b
RED0102cRU@0]HaD0;J=E@2fSET30;F<F0<0]8]G2@2cRUH00`2dReL0/hYF0;:9E@020;68E0030;:9
E@2cRUH0]8]G00P0/8]G00@0/hYD0;:9D`2bRE<0/XUC0P2aR5820;27D@050;:9E@2aR5@0/HQD0;27
D`2_QU800P2^QE400`2]Q500[hIB0:n6DP060:n6DPP0[XEA202]Pe430:b3C@80[HA>0`2^QDl30:j5
D@80[HA@0`2/Pdl0102[PTh0[8=?0:b3C`2/Pdl30:f4D0040:j5D@2/Pdd0[HA>0:j5C`80[hI@00<0
[HA>0:^2C02ZPD/00P2[PTh20:b3C`<0[HA@00<0[XEA0:^6DP2[QU801P2[QU802@2]QDX0[8=;0:^2
C02[PT`0ZX5;0:Z0CP2[PDl0[89B0:f2E@080:b3C`<0Zh9>0`2/Pdl20:f4D080[XE?00<0[HA>0:b3
C@2[PT`00P2ZPD/01`2YP4X0ZGm=0:Z0CP2ZP4h0Zh5?0:b2D02]Pe400P2^Q5830:b1CP<0[H9?0P2^
Pe001@2ZPDd0Zh9>0:^2CP2/Pdl0[HA@00<0[XEA2P2]Q5030:b3C`<0Zh9>202/Pdl80:b2D080[HA@
0`2/Pdl30:^2CPP0[HA@202/PD`20:f2C`80[85>0P2[P4d20:YoC0030:f2C@2/PD`0ZGi90080Yga7
00/0ZGi90:b1C02]PTd0Zh1=0:YoC02YOT/0Z7e:0:UnB`2ZOd`0[85>0:f2C`080:b1C0030:^2CP2Z
PDd0ZH1<0080ZH1<00<0Zh9>0:b3C`2]Q5000`2/PU030:^1C`<0ZX1>00@0YWe90:QoB`2ZPDd0[8=?
0P2]Q5000`2/Pdl0Zh9>0:b2B0070:b2B080ZWm:0P2[P4/20:b1C080[H9=00@0[hAA0:j3D02^Pe00
[X=@0`2]PTl0102/PDh0Zh5?0:^1C`2[PDl30:b2D080[H=A0P2^QDd0102]Q4h0[8=?0:b3C`2/PU02
0:b2DP80YX5<00@0Yh9=0:R3CP2YQ4l0ZHA?0P2ZQE080:b3C`P0ZWm:0P2YP4P0102YP4X0ZH1<0:V0
C02YOdd20:UoC`P0[Wi=202[P4/30:b1C080Zh1;0`2ZOdX80:^0B`80[HA@00@0[8=?0:^2CP2YP4`0
Z7m;0P2WOTX20:Z1C@040:V0C02XOd/0Z7m;0:MnBP<0YWe90P2WOTX00`2XOd/0ZH1<0:Z1C@020:^2
CP030:V0C02WOTX0YGa80080XgY600@0YGa80:MnBP2YP4`0ZX5;1@2YP4X30:QoB@030:IkB02WO4T0
Z7e:0080Z7e:00<0Yga90:IkB02VNdP0202WOTP80:ImA`80Y7Y80P2UNdT20:IlBP80Yge;00/0YWi3
0:MoA02WOd@0Z8150:MoA02VOT<0YGe20:Al@@2TNTP0YG]90:IlBP020:MmB`030:IlBP2UNdT0Y7Y8
00P0Ygi:00<0Y7Y80:EkB@2WOD/00`2XOT`20:MmB`040:QlB`2WNdX0Yg]:0:MkBP<0YWY900@0YGU8
0:V0C02XOd/0YWe90`2UO4P20:ImB@<0Y7]70`2UO4P20:ImB@@0XgY60`2TNdL00`2UO4P0Y7]70:Ak
A`090:AkA`80YGa80`2VODT01P2YOdl0Z7i>0:MmB`2UO4P0XgY60:9i@`80X7Lo00D0X7M30:5hA02R
NDD0XgY60:AkA`020:=jAP030:9iA@2QN4@0XGQ40080XWU500X0XgY60:AkA`2UO4P0YGa80:5gA`2R
N4P0Y7Y80:ImB@2WOTX0Ygi80P2VODD20:5gA@80XWQ6102SNDL00`2TNTP0Y7U60:AiAP030:EjA`<0
YW]80P2WOTX0102VODT0YGa80:AkA`2TNdL20:=jAP80XgU70P2RN4H01@2QMdD0X7I409me@`2OMD<0
YG930080Xg=300<0XgE40:5eA02PMT@00P2PN4D809me@`80XG=200<0Wg=209id@P2MMD800P2KMT80
102JMT80X7I409me@`2MLd4309]a?`0509ab@02MLd40W70o09ea@02NLT400P2PM4<00`2NLT40WG50
09a`?`0709ab@00309ec@@2NM480WWA200<0WG=10`2LLT0809Ma@P80W7900`2KLCl309Y`?P80VW4k
00<0VW4m09Y`?P2JL4000P2JKd802@2JKd@0Vg4o09Y`?P2HKS`0Ufdk09I/>P2GKC/0V6hl09U_?@02
09Q^?0@0VW0n1@2HKS`209U_?@<0VW0n202FK3X209AZ>080UF/i00@0UV`j09M]>`2GKC/0V6hl0`2G
K3l309Q]@0<0VFi10`2FK3X209M]>`<0V6hl0100W79009]a?`2JL3h0VFlm09Q^?02GKC/0UV`j09E[
>@2DJ3/0U6Tl09M/?`2HKd40UW1109Ea@@2CLD40TW10202EJcT809I[?P0809Mb?P2FLCd0UG0l09A_
>`2BKCT0TF`h091[=`2?JSH809A[=`0308mZ?@2>JC`0SFPk0080SFPk00<0SfXm095/?`2BKD000P2?
JC`2091Z?@<0TF/n00@0TV`o08m[>`2?Jc/0Sf/k:oooool002[ooooo0`25GSD308IO=P80Qf0g0`28
G3D208UM=P<0RUhg0`29GCH208YN=`<0Relh202;H3D00`29GS<0RUld08aQ=P0308iS>00508eR=`2<
HCH0Rf0e08aQ=P2=HSL00P2>HcP0102=HSL0S64f08]P=@2;GS@208aO=@0508eP=P2>HCL0Sf8h08mR
>02@HcT01P2?Hc8208iR<@<0SF<c0`2>I3@208mU=@04091R?P2@Hc`0TF@m095T>`80TF@j00<0TVHi
099V=`2BISL0202BIST2091T=`04095U>02BIST0TfLj09AX>`80UFTl0`2HIc`00`2GIS/0UVDj09IU
>P0209ET>@80T6Dh0P2AIST2099W>P80TfPk202DJ3L00`2FJSd0UFTl09AX>`0209=W>P0309EY?02G
Jch0V6`o00P0Uf/n00@0VVlj09Q]>02FJcH0U6Td0`2CJ3<0102DJC@0UVXi09IZ>@2FJST209M[>PL0
V6`k102IKC`309IZ>@<0Uf/j0P2HK3/809U]?0P0Vfln00<0W70o09]_?P2IKC`00P2HK3/00`2IKC`0
Vfln09a`?`0809aa?PH0WgA10P2NLd0709ib@@0309ea@02OM440WgA100H0WgA10`2PM4<209mc@P@0
WW9100<0XGI30:1e@P2OM4400P2MLSl0102NLd00WgA10:1e@P2RMd@40:=hA@040:9gA02PMD80X7E2
0:IcA080Y7A400<0XgE40:5eA02PMT@00P2OMd@00`2QMT<0XWM40:=hA@020:EjA`030:=hA@2RMd@0
XGI300P0X7E20P2SMdH30:9fA@<0XGE41P2SN4D20:9gA0P0YGY50P2UNDP20:IjB@80Yg]:0P2XO4/0
202ZOd`0Z7e:0:IkB02UNTL0Y7U60:EjA`2VNdP0Yga90P2XODX20:MlB@80YW]80P2UNTL20:MiA@06
0:IkAP2VODL0YWm80:F0B@2VPDX0YH9:0`2VODL30:MnB0X0Z7m900<0Zh1=0:YoC02ZOd`00P2YOT/2
0:QmBP030:MlB@2YP4X0ZH1:0080ZX5;1@2[PT`01`2/Pdd0[HA>0:j5C`2]Q4h0[8==0:Z1B`2YP4X0
202ZOd`20:Z1B`80Zh9<0P2/Pdd30:f4CPP0[8980P2/Pdd20:^2C080ZX5;0P2YP4X0102/PDh0Zh1=
0:^0C@2[P4d20:YoC080ZGi;0P2XODX20:UnB`<0ZWm<00<0Zh1=0:V1A02YPD@00P2YPDH0102YP4P0
ZH1:0:V0C02YP4`30:QoB`80Ygi:0`2VODT00`2TNDH0YGY70:IkB0020:QmBP030:IkB02UNTL0Y7U6
00<0YW]80P2UNTL30:AiAP80YGY30100YW]60:MlB@2VNdP0Y7Q70:5eAP2PM4D0W7M309ehA02NNDD0
WgY609iiA@2MN4@0VgI209Ye@@2NN4T0WgU:0`2PNT/00`2NN4T0W7I709]eAP080:9hB080X7I600@0
X7I40:1g@`2PMd<0X7M10P2PMcl:0:5hA0040:1g@`2OMT80WWE109ed@080W7<o202LKSX00`2JLCd0
VG0l09Q_>`0209M^>P0909Q_>`2IL3`0VW4m09U`?02IKcd0V6hl09Q^?P2GK3l0UV]00080UFY02@2E
JcT00`2FJch0U6Tl09=X>`02099W>P0309=X>`2DJC`0UV/n0080UVLk0P2GJ3`01@2HJCd0VFXn09UZ
?P2IJSh0UW110080UFm00P2DKSl209=]?P03099/?@2HKS`0V6hl00H0V6hl0`2GKC/00`2HKS`0VFlm
09U_?@0209Y`?P80UW4m00<0UG0l09A_>`2DKc/00`2CKSX209E`?080UW4m0P2GLSh209Qc?`0309ie
@@2MM400WGA00080W7<o0P2KLSh00`2JLCd0W79009ab@00609ab@00309mf@P2NMD40WGA00080Vg8n
00@0W7<o09ie@@2OMT80WGA00`2NMD4209mf@P80X7M3202PMd480:AkA@80XgY60P2TNdL30:ElB008
0:ImB@2SNTH0Y7]70:ImB@2WOTX0Z7m;0:MnBP2VODT20:ElB080YWe90P2WOTX20:QoB`030:V0C02X
OdT0Z7m900H0Z7m9202XOd/01P2XOdL0ZH180:V0BP2YP4`0ZX5=0:Z0CP80Zh5A0`2ZPDd0102[PTh0
[8=?0:b3C`2]Q5020:j5D@P0[8=?00<0[XEA0:f4D02/Pdl00P2[PTh00`2]Q500[hIB0;27D`080:b3
C`80[HA@0`2^QE430:n6DPP0[HA@202`Qe<01@2dRUP0/hUG0;>9E`2bR5H0/8ID0080[hEC00<0[XAB
0;27D`2`Qe<01P2`Qe<20:j5D@80[hIB0P2`Qe<20;68E0P0ZhIB00L0Z7m;0:f4D02cRUH0]8]G0;27
D`2]Q500[8=?00T0[HA@00<0/8]F0:n:E@2]R5<00P2/Qe800`2]R5<0[hYE0;2;EP030;27D`<0/HQD
0P2bRED80;:8EP80/XeI0P2aS5P0202`ReL0[hYF0:n:EP2_RUH0]XeI0;B;E`2bRED0/HQD0P2`Qe<2
0;:9E@080;B;E`2cRUH0/XUE0;68E02bRED0/hYF0;F<F02fSET40;F<F080]8]G1@2cRUH20;B;E`@0
]HaH0P2cS640102bS5l0/XaK0;6<F02aS5D20;2<DP080;B:FP2cREL0/XQF0;:9E@2cRU@0]HaD0;N?
E02iTEH20;J=F@80]HaH0P2dReL:0;>:EP030;F<F02dReL0/XUE0080/HQD00<0/XUE0;B;E`2eS5P0
202_RUH20;>:DP<0/XUA0`2aR5020;:9E@040;68E02`Qe<0[hIB0:j5D@80[HA@402^QE420:^1C`04
0:b2D02]Pe40[H=A0:j4DP80[hEC0`2/Pdd20:f4CP<0[XE?0`2^QE420:f4D0<0[8=?0P2[PTh20:b3
C`060:f4D02^QE40[XEA0:j5D@2]Q4h0[XE?0P2_QU00102^QDl0[HA>0:^2C02ZPD/30:^2CP80[8=?
0`2]Q5080:^6DP090:j6B@2]QDX0Zh9:0:^2BP2ZPD/0ZX1>0:^1D@2]PUD0[X=H00P0[8=?0`2[PTh3
0:b3C`80[HA@00H0[hI>0:j5C@2]Q4`0[8=;0:^2BP2ZPDT20:V0B080ZGm=00H0ZX1>0:^1C`2/PU00
[H=A0:j4DP2_QE<30:b1CP<0[H9?0P2^Pe030:b3C`l0[HA@0`2/Pdl30:^2CPP0[8=?202/PU830:f4
D0030:b3C`2[PTh0Zh9>0080ZX5=202]Q5080:b1C080[H9?0P2/PDh20:^0C@80ZWm<00<0[X=>0:b1
C02YOTT00P2WO4L02`2YOTT0[85<0:j3CP2[P4d0ZWm<0:UnB`2XODX0ZGi;0:YoC02/PDh0[H9?00P0
[H9=00P0Zh9>0:Z1C@2YP4`0Z7m;0:V0C02[PTh0[HA@0:j5D@80[H=A0`2/PU030:^1C`050:Z0CP2V
ODT0Z7m;0:Z1C@2/Pdl00P2]Q5000`2/Pdl0Zh9>0:f3B@070:f3B@80ZWm:0P2[P4/20:b1C080[H9=
0`2_Q5400`2^Pe00[H9?0:f2C`020:b1CP<0Zh5?0`2/PU020:f3D@80[8=;00@0[8==0:^2CP2[PTh0
ZX1>0P2ZP5020:F0B`060:J1C02WPTd0Z8=>0:V4C`2ZQE00ZhIA202]Q5080:UnB@80ZH1800@0ZH1:
0:V0C02YP4`0ZGm=0P2YOdl80:moCPP0Zh1;102/PD`20:^0B`80ZWm:202[P4/20:Z1C@80ZH1<0P2X
Od/20:MnBPP0Z7m;0P2WOTX0102XOd/0ZH1<0:Z1C@2ZPDd20:^2CP80Z7m;102WOTX20:QoB`H0Ygi8
0`2XOdT0202VNdP0Yga90:UnB`2ZOd`0Zh1=0:YoC02XODX0Yga9202WOTP80:ImA`80Y7Y80P2UNdT2
0:IlBP80Yge;00/0YWi30:MoA02XP4D0ZH560:R0A@2WOd@0YGe20:=k@02TNTP0YG]90:IlBP020:Mm
B`030:IlBP2UNdT0Y7Y800P0Ygi:00P0Y7Y80:EkB@2WOD/0Z7i<0:UoC@2XOT`0Yge;0:IlBP80Z7a;
0P2WNdX20:IjB@80YGU800P0ZX5=0:QoB`2VODT0YGa80:AkA`2UO4P0YWe90:MnBP<0YWe90`2UO4P2
0:AkA`<0YGa80P2TNdL30:=jAPP0YWe90P2SNTH20:AkA`<0YGa800`0YWe90:MmC@2WODd0YWa:0:El
B02TNdL0XWU30:9i@@2QN400WWE10:1g@`2RNDD30:AkA`080:=jAP2RNDD0WgI20:1g@`2QN4@0XWU5
0:=jAP2TNdL20:ElB0080:5gA`2RN4P0YG]90:MnBP2XOd/0Ygi80:MnAP2VODD30:5gA@80XWQ6102S
NDL20:AiAP<0YGY70`2VNdP20:QoB`060:MnBP2VODT0YGa80:AkA`2SNTH0XWU50P2TNTP0102SNDL0
XWQ60:5gA@2PMT@209me@`060:IcA02TM4@0YGE50:AfA@2RMTD0XWQ60P2QNDH809me@`80XG=200<0
Wg=209id@P2MMD800P2KMT80102JMT80X7I409me@`2MLd4309]a?`0509ab@02MLd40W70o09ea@02N
LT400P2PM4<00`2NLT40WG5009a`?`0209U_?@80VW0n00<0Vg4o09ab@02MLd401@2MLd4309id@P03
09me@`2GLD80Ug5200H0Ug520P2LLT0209]a?`80VW0n0P2IKcd209Ya>`0309Ya?@2JL3h0VW100080
VVm200@0VVm409]a?`2JL3h0V6hl0P2FK3X01P2GKC/0V6hl09U_?@2GKC/0V6hl09Y`?P80Vg4o00<0
VW0n09Q^?02GKC/00`2JL3h209U_?@<0V6hl3@2GKC/309Q^?0<0Uf`o0`2HKD0309U^@@80UF/i0P2F
K3X01@2GKC/0V6hl09Q^?02HKS`0Vg4o0080VW0n00<0VFlm09Q^?02HKS`00P2GKC/0202DJ3/0UFXm
09M/?`2HKd40Ug5209Ib@P2CLD40TW10202EJcT809I[?P0609Mb?P2FLCd0UG0l09A_>`2CKSX0TF`h
0P2@JcL809E/=P0308mZ?@2>JC`0SFPk0080SFPk00<0SfXm095/?`2BKD000`2@JSd3095[?P80TV`o
0`2?Jc/[ooooo`00:_ooool308EN=@<0QUlf0P27H3L208MK=080R5`e00@0REdf08YN=`2;GcP0Relh
0P28G3D01029GCH0RUhg08YN=`2;GcP208aP>@P0Rf0e00H0REhc08YO=02<HCH0SV<h08mT>@2>HcP2
08eR=`0308YO=02;H3D0SV<h0080Sf@i00/0SV<h08]P=@2:Gc@0RUdc08]N=02<GcD0SF0f08iQ=`2?
HSP0T6<i095T>P0508mT<@<0SV<`0`2=Hc<308iT=080SfDe00@0T68n091S?02AI3d0TF@k0P2AI3X0
0`2BIST0TVHg099V=`08099V>@80T6@g00@0TFDh099V>@2CIcX0U6Pk0P2EJC`0102KJ3d0VVLl09YW
?02IIS/209QU>P80Uf@i0P2@ICP2095V>@80TVLj0P2CJ3/809AX=`0309IZ?@2EJC`0TfLj0080TfLj
00<0UFTl09M[?P2HK3l0202HK3l0102JKcX0VFhi09I[=P2CJ3<2099W<P0309=X<`2DJC@0Uf/j0080
Uf/j0P2HK3/909U]?080V6`k00H0TfLf09AX=`2DJ3L0UFTh09IZ>@2GJcX209Q/>`P0VFdl202KKch0
0`2LL3l0Vfln09U]?00209Q/>`0309U]?02KKch0W70o00P0Vg0m0P2PMD8409md@@80WW=00`2MLD03
09ib@@80Wg=2202OM4430:1d@`80Wg=2102NLT400`2QMT<0X7E209md@@0209eb?`0609ic@02OM440
X7E20:5f@`2SN4D0YGY70P2VNdP0102TNDH0XGI309md@@2VLd@20:AdA0030:=eA02QMD@0X7I40080
WgM400<0XGI30:9gA02SN4D00P2UNTL00`2SN4D0XWM40:5f@`080:1e@P050:AhA`2SMdH0XgM60:9f
A@2QMD@00P2PM4<00`2OLd80XgQ50:=hA@030:=hA@<0XWM4202UNTD20:EiB080YWY90P2WNdX20:Ql
B`030:YoC02XODX0YW]80080Y7U600<0YGY70:IkB02XODX00P2XODX20:MlB@80YW]80P2UNTL02@2W
NDD0Z7Y60:IkAP2VODL0YWm80:F0B@2VPDX0YH9:0:AkA@020:ElAP030:ImA`2WOTP0Z7m90080ZH1:
202XOdT20:^0C@040:YoC02YOT/0ZGi;0:QmBP80Yga90P2YP4X20:Z1B`<0Zh9<00T0[8==0:^2C02/
Pdd0[HA>0:j5C`2]Q4h0[8==0:Z1B`2YP4X0202ZOd`20:Z1B`80Zh9<00D0[8==0:f4CP2]Q4h0[HA>
0:j5C`080:b2AP80[8==0P2[PT`20:Z1B`80ZH1:102[P4d20:YoC080ZGi;0`2XODX20:UnB`<0ZWm<
00H0ZH530:V1A02YPD@0ZH560:V0B02YP4X20:V0C080Z7m;0`2WOTX30:ImB@030:=hA@2TNDH0YW]8
0080Z7e:00<0YW]80:AiAP2SN4D00P2UNTL20:AiAP<0XgQ500/0XWM40:Ai@P2UNT<0YW]60:MlB@2V
NdP0Y7Q70:5eAP2OLd@0W7M309ehA00309iiA@0309ag@`2KMT80VGA00080WgU<0P2PNTd0102OND`0
WGM:09YdA`2ILdH80:9hB080WgE500@0WgE309mf@P2OMT80WgI00P2OMSh40:1g@`H0XGQ400@0X7M3
09mf@P2MM400W7<o0P2KLSh809a^>P0309Ya?@2IL3`0Ufhj0080UVdi00/0Ufhj09U`?02JLCd0VW4m
09Y`?P2IKcd0Ufdm09I[?P2EJSl0U6To09=X?P0909AZ>00309EZ?`2DJCh0TVLl0080TFHk00<0TVLl
09AY?P2EJSl00P2EIS`0102FIcd0UfPn09MX?P2HJCl209UZ@0<0UFm200<0U6i109=]@02BK3l00P2B
K3l809Q^?080UV`j0P2GKC/01@2HKS`0VFlm09U_?@2JL3h0UW4m0080UG0l00<0U6lk09=^>P2CKSX0
0P2BKCT209A_>`0409E`?02FLCd0UW4m09Mb?P80V7<o0`2MM4000`2LLcl0Vg8n09Ya?@0209Ya?@@0
Vg4o102LLT000`2OMT80WWE109ac?`0209]b?P0309ac?`2MM400WWE100<0WGA00P2NMD4309mf@PP0
WgI0202SNT@20:=jAP80Y7]7102UO4P01`2SNTH0Y7]70:ImB@2WOTX0Z7m;0:MnBP2VODT00`2UO4P2
0:ImB@040:MnBP2XOd/0Z7m;0:V0C0P0Z7m9202XOd/20:QoA`060:V0BP2YP4`0ZX5=0:Z0CP2ZP500
Zh5A102[PTh30:b3C`80[HA@202/Pdl00`2^QE40[HA@0:b3C`020:^2CP030:f4D02_QU80/8MC00P0
[8=?0P2]Q5030:j5D@<0[hIB202]Q5080;27D`80/hUG00<0/XQF0;67E@2`QU@00P2^Q5800`2]Pe40
/8MC0;27D`060;27D`<0[XEA00<0[hIB0;27D`2aR5@00P2aR5@80:^6DP070:QoB`2]Q500/hYF0;B;
E`2aR5@0[HA@0:b3C`090:f4D0030;2;EP2_RUD0[HQC0080[8MB00<0[HQC0:n:E@2`ReH00`2`Qe<3
0;68E080/XUE202bR5H20;:=F@80/HaH00l0/8]G0:n:EP2_RUH0[XUE0;J=F@2eS5P0/XUE0;27D`2_
QU80/8MC0;68E02bRED0]8]G0;>:EP2bRED00P2aR5@0102cRUH0]HaH0;N>FP2fSET40;F<F080]8]G
102cRUH20;B;E`<0]HaH00T0]XeI0;><H`2cS640/heP0;:<F`2aS5L0/8]D0;2<DP2`S5000P2bR5H0
1P2aR5@0/XUC0;B;D`2fSED0^I5F0;ZBE`<0]XeI00<0]HaH0;B;E`2cRUH02P2cRUH00`2eS5P0]8]G
0;:9E@020;68E0030;:9E@2dReL0]HaH00P0[hYF0`2cRU820;:9D@<0/HQ@00P0/hYF0;:9E@2aR5@0
/8MC0:n6DP2^QE40[HA@0:b3Ca00[XEA0P2ZP4h0102[PDl0[89@0:j4DP2_QE<20;26E0<0[8==0P2]
Q4h30:j5C`<0[XEA0P2]Q5030:b3C`80Zh9>00@0[8=?0:f4D02]Q500[XEA0P2_QU80202]Q4h0[XE?
0:n6D02_QU00[XE?0:f4CP2[PT`0ZH1:0`2[PTh30:b3C`80[HA@202[QU802@2^QTP0[HE80:^3B02[
PdP0ZX5;0:Z0CP2[P5<0[H9G0:j3F@080:b3C`<0Zh9>0`2/Pdl20:f4D0060:n6CP2^QDd0[XE=0:b3
B`2[PTX0ZX590P2YP4P20:UoC@030:Z0CP2[PDl0[89@0080[XAB00@0[hEC0:b1CP2/PDh0[85>0`2]
PTl20:j3D180[HA@0`2/Pdl30:^2CPP0[8=?202/PU80102^QE40[HA@0:f4D02/Pdl20:^2CP80ZX5=
202]Q5080:b1C080[H9?0P2/PDh20:^0C@80ZWm<00<0[X=>0:b1C02YOTT00P2VNdH02`2YOTT0[85<
0:j3CP2[P4d0ZWm<0:UnB`2XODX0ZGi;0:YoC02/PDh0[H9?00P0[H9=00P0Zh9>0:Z1C@2XOd/0Z7m;
0:V0C02[PTh0[HA@0:n6DP80[H=A0`2/PU040:^1C`040:ImB@2XOd/0ZX5=0:b3C`80[HA@00<0[8=?
0:^2CP2]PdL01`2]PdL20:YoBP80Zh1;0P2/PD`20:f2C@80/8EB00@0[hAA0:j3D02^Pe00[H9?0P2/
PDh30:^1C`<0[89@0P2]Pe420:^2BP0>0:^2C02[PTh0ZX5=0:UoC@2YOdl0Z7i>0:AoBP2UP4/0YX5<
0:N2C@2XPdh0ZHA?0:Z5D02[QU480:f4D0P0ZGi90P2YP4P0102YP4X0ZH1<0:V0C02YOdd20:UoC`P0
/X1?202[P4/0102]PTd0[85<0:b1C02/PD`20:^0B`80ZWm:202[P4/40:QoB`L0Ygi:0P2XOd/30:V0
C080Ygi:00<0Z7m;0:V0C02ZPDd00P2[PTh0102/Pdl0Ygi:0:QoB`2YP4`20:Z1C@030:V0C02XOd/0
Ygi:00<0YGa600@0YWe70:MnB02WOTP0Ygi80P2XOdT00`2WO4T0Z7e:0:YoC0020:b1CP030:^0C@2Y
OT/0Z7e:00P0Ygi8202VODL20:AjB080YG]90P2VO4X20:MmB`030:In@@2WOd80Z8130080ZH5400H0
Ygm20:Em@02SNch0XgU70:EkB@2VO4X20:QnC0030:IlBP2UNdT0XgU700P0Ygi:00<0XgU70:EkB@2W
OD/00P2YOdd00`2XOT`0Yge;0:IlBP030:QlB`030:MkBP2VNTT0YGU80080YGU800L0ZX5=0:V0C02V
ODT0YGa80:AkA`2UO4P0Ygi:0080Z7m;0P2WOTX01@2VODT0YGa80:AkA`2TNdL0XgY60080YWe90P2U
O4P0102TNdL0XgY60:9iA@2RNDD80:MnBP80XgY60P2TNdL40:ElB080YWa<00@0YG]90:ElB02TNdL0
XgY40P2RND400`2NMD40WgI20:9iA@030:AkA`070:9iA@2QN4@0WgI209mf@P2PMd<0XGQ40:9iA@02
0:AkA`090:ElB02QMdL0XWQ80:EkB@2WOTX0Z7m;0:QoB@2WOTH0YWe500<0XGM5102RN4H20:=iA`80
Y7U60`2UNTL30:IkB00>0:V0C02XOd/0Ygi:0:ImB@2UO4P0Y7]70:=jAP2RNDD0YG]90:AjB02SNDL0
XWQ60:5gA@2PMT@209me@`060:MdA@2UMDD0YWI60:EgAP2TN4L0XgU70P2RNTL809me@`80XG=200<0
Wg=209id@P2MMD800P2KMT80102JMT80X7I409me@`2MLd4309]a?`0509ab@02MLd40W70o09ea@02N
LT400P2PM4<02@2NLT40WG5009a`?`2GJcX0V6`k09U]?02JKSd0Vfln09ea@00209ib@@80W7900P2M
Ld40102NM480WgE30:1fA02PMT@809Ma@P80W7900P2KLCl0102JL3h0VFlm09U_?@2HKS`209Ya>`03
09Ya?@2JL3h0VW100080VVm200@0VVm409]a?`2JL3h0V6hl0`2FK3X01@2GKC/0V6hl09M]>`2HKS`0
VW0n0080Vg4o00<0VW0n09Q^?02GKC/00P2KLCl0102JL3h0VFlm09U_?@2HKS`209M]>`P0V6hl0P2I
Kcd609Q^?0<0Uf`o0`2HKD0309U^@@<0UF/i00<0UV`j09M]>`2HKS`00P2HKS`209Y`?P<0VFlm0`2H
KS`0202DJ3/0UFXm09M/?`2HKd40Ug5209Ib@P2CLD40TW101@2EJcT309I/>PP0UV/n0P2GLSh0102F
LCd0U6lk09=^>P2AK3P2091[=`P0UF`f00<0SfXm08iY?02=J3/00P2=J3/00`2?JSd0TF`o099]@003
091Z?@80TF/n0`2BK3l308m[>b_ooooo000Zooooo`P0REdf00P0R5`e08UM=P2:GSL0RUhg08UM=P27
Fc@0QETb08=G<0<0REdf0P2:GSL308]O>00308]N=`2<GcP0S5lh0080S5lh0`2=H3T208QQ>080RF8i
0P2:HcX208]T>`80S6<g00<0SF8g08iQ=`2@HCL00P2AH3L00`2CGcL0SF8g08eR=`0408aQ=P80Rf0e
0P2<GcD0102=H3H0SV4g08mR>02?HSP2091S>@<0RVDh0P2;IST308aW>P<0TF@j00<0TVDk09=V?02C
IS`00`2DIcd00`2CIS`0TVDk091S>@0208iQ=`06091S>@2BIC/0TfHl09AW?@2BIC/0TF@j0P2@HcT0
0`2BIC/0U6Lm09IY?`0209EY?080U6Pk00@0TfLj099V>@2AICP0TFDh0`2BIc`309=X?@80U6Tn102G
JcX209IZ>@80UFTh202FJST809eZ>`0609M[?P2GJc`0UVXk09EY>02EJSL0U6Td0P2CJ340202CIcH0
V6`k09ea@02MLD00VFdl09M[>P2IKC`0W70o0P2HK3/01P2IKC`0VVhm09U]?02GJcX0UFTh09AX=`P0
UVXi00<0Uf/j09Q/>`2JKSd00`2LL3l00`2JKSd0VFdl09a`@`0709a`@`80VFdl0P2JKSd0102KKch0
W70o09a`?`2MLD0809m/?@0>0:=a@02PL3l0X70o0:1b@02NLd00WWE109ee@@2NMT80VFlm09Y`?P2K
LCl0W79009ec@@2OMD<20:1fA00309ea@02NLT40Wg=20080Wg=200<0WG5009]_?P2JKSd00`2OLCl4
0:1b@080XG=10`2NLT4209mc@P<0X7A300<0WG=109id@P2PMT@00P2QMdD03P2PMT@0WgE309id@P2R
Md80XgQ30:EjA@2VNdH0YGY50:AiA02QMT40X7E00:1`?`2SLd80YgM60P2ZNTT00`2XN4L0YGE40:=c
@P020:QiA@030:MhA02VMd<0YGI20080Y7E100<0XgA00:MgAP2WMdH00`2VMTD30:EeA0080:=hA@2R
Md@0XGI30:1e@P2QMT<0XWM40:AiAP2UNTL30:EiB0<0YWY90P2WNdX20:Ak@`80YGa40P2VODD20:Mn
APP0Z7e:0P2VNdP20:MlB@040:QmBP2YOT/0ZGi;0:UnB`P0Yge=202XOd/00`2XODX0ZGi;0:^0C@02
0:b1CP030:^0C@2YOT/0Z7e:00P0Z7m;0P2/PDh20:^0C@050:YoC02YOT/0ZGi;0:QmBP2^Q4P00P2]
PdT01@2/PDX0Zh1;0:YoC02ZOTd0ZGe<00P0ZWm:00H0Zh1F0:^0E@2[P5<0Zh5?0:b3C@2/Q4T20:f5
B0030:f5A`2[PTX0Zh9:00H0Zh9:202/Pdl80:Z0CPP0ZH1<0P2UPDd00`2TP4`0Xgm;0:9nBP020:5m
B@040:1lB02UNDP0YGU80:EiB080Y7Q70`2SMdH80:IkAPP0X7M30P2OMD<30:5gA@0309me@`2MLd40
W79000P0VgI20`2LMTL209]eAP<0VWA500<0WGM809]eAP2ILd@00`2GLD800`2ILd@0VWA509id@P0:
09id@P80WgE30`2PMT@209Ya?@0609]b?P2LLcl0Vg8n09U`?02GKSX0UVdi202HKc/809U]?0@0UV/n
102GK3l2095/>004091[=`2>JCD0SFPd08aW<`<0RfHb202DJcL8095V>@06091U>P2AIS/0TFHk099W
?02CJ3d0U6Tn0P2EJSl309=]?P80TV`m102AJc`01`2BK3d0U6ho09I`@@2FL440U6ho099/?@2AJc`0
202CKCh02`2GLD@0UW1109A^?`2CKC`0U6lk09Ia?02HLc`0VG@m09E/=P2FKCL0V6li0080VG0j00H0
V6li09I]=`2EK3H0VW0n09U_?@2HKS`209M]>`0309U_?@2KLCl0W79000P0WGA000@0Vg8n09ac?`2L
Lcl0W7<o0P2MM40209ie@@<0X7I40P2OMD<309id@P80WgHn0P2PMcl30:5h@00:0:9i@@2MM400WWE1
09mf@P2QN4@0XgY60:AkA`2UO4P0YWe90:=j@P<0XWU100@0XgY20:ElA02XOdL0ZH180`2SNTH20:Ak
A`<0YGa800/0Y7Q70:EiB02UNTL0YW]60:MlA@2XODH0Z7i40:UoA@2ZPDd0ZH1<0:MnBP020:ImB@03
0:MnBP2YP4`0ZX5=0080Z7m;0`2YP4`30:Z1C@D0Zh9:0P2/Pd/20:f4C0<0[8=?0P2]Q5030:j5D@80
[HQA00@0[8M@0:^6C`2YQ4d0Z8=<0P2WPT/0202]Q500[8=?0:Z1C@2YP4`0ZX5=0:b3C`2^QE40[hIB
0P2]Q5030:j5D@H0[hIB0`2^QE440:f4D080[XEA102_QU820;>:EP040;:9E@2aR5@0/8MC0;27D`80
[hIB202_QE<0202ZPDT0[8=;0:n6CP2bRE40/hYB0;:9D@2`Qdl0[hI>0P2_QU820:j5D@@0[HA@0P2e
S5P30;B;E`<0/hYF0P2^QE420:n6DP<0/8MC00<0/HQD0:n;D@2_Re401P2_Re480;27D@80[hUH00@0
[hYF0:n:E@2_RUD0[hYC0P2_Re420;:=F@80/HaH00@0/8]G0:n:EP2_RUH0[XUE0`2dRUP30;>9E`80
/XQF0P2`Qe<0102aR5@0/XUE0;:9E@2cRUH20;B;E`T0/hYF202cREL20;67E@030;:8EP2cREL0]8YH
0080]H]I00H0]XaJ0;R:F02hRUP0]X]H0;F<F02dS5P20;:=F0030;6>F02bSEP0/XeH00H0/XeH202c
RUH80;68E080[hIB0P2`Qe<0102aR5@0/XUE0;>:EP2cRUH20;:9E@<0/HQD0`2`Qe<00`2_RUD0[XUD
0:f8D`020:b7DP030:f8D`2_RUD0/8]F00P0[XE=00<0Zh9>0:f4D02^QE400`2`Qe<20:j5D@040:V4
C`2ZQE00ZXE@0:^6D@80[8MB0P2]R5<80:j5D@030:UoC`2[PE40[hEE0080/HMG00<0[hEE0:^1D@2Y
Odl00`2_QU830:j5D@80[HA@202]Q4h40:b1CP@0Zh1=202]Pe<20:n6DP80[XEA0P2]Q5001P2/Pdl0
Zh9>0:^2CP2^QE40[HA@0:^2CP80ZX5=00<0Zh9>0:f4D02^QE40202/Pdl40:f4D080[8=?0P2[PTh2
0:V0C080ZX5=0P2[PTh20:b3C`080:b4D02ZPTh0ZX5=0:UnB`2[OD/0[Wi=0:moCP2cPE080:n4C`P0
[X=@0P2/PU80102/PU00[8=?0:b3C`2/Pdd20:b3B`<0[8=?0P2]Q5030:j5D@060:UoC@2ZP4h0ZX1>
0:^1C`2/PU00[H=A0P2^Q5880:f4C0<0[XE=0P2]Q4`30:b3B`P0[8=?102ZPDd20:V0C080Z7m;0`2]
Pe430:b2D080Zh5?202XOd/80:Z1C@<0Zh9<0`2/Pdd20:f4CPT0[85>202/Pdl80:f1D0P0ZH1<00H0
/8MC0:n6DP2^QE40[HA@0:^2CP2YP4`20:QoB`P0[8=?0P2]PTd20:b1C080Zh1;0P2ZOdX80:^1D@<0
ZH1<00<0ZX5=0:^2CP2/Pdl00P2/Pdl20:j5D@060:b3C`2ZPDd0Z7m;0:ImB@2UO4P0Y7]7202ZOdX8
0:^3AP80Zh9:00H0ZX5;0:Z1C@2YP4`0Z7i<0:QnCP2WODd20:V0C080ZX5=0P2[PTh20:b3C`P0[85>
00<0Zh9>0:Z1C@2XOd/00P2WOTX01P2XOd/0ZX5=0:^2CP2/Pdl0Zh9>0:V0C080Ygi:00<0Z7m;0:Z1
C@2[PTh00P2/Pdl00`2[PTh0ZX5=0:V0C0020:MnBP030:ImB@2ZPDd0ZX5=00H0ZX5=00@0Yga?0:Mm
C@2WOD/0Ygi:0P2WOTH01@2WOd80Ygm10:N0?`2ZP4@0ZGm300<0Z7i200<0ZX140:^1A@2]PdL0202X
ODX0202RMd`0XgQ=0:AiCP2UNTl0YW]@0:MlD@2XOE80ZGiC0P2TNDH01P2UNTL0Yga90:UnB`2ZOd`0
Zh1=0:b1CP80YGa60`2TNdD30:=jA0<0Yge;00<0YWa:0:EkB@2TNTP00P2TNTP20:AkA`80YGa800h0
YWe90:MnBP2WOTX0Ygi:0:ElB02WOTX0ZH1<0:^2CP2/Pdl0Zh9>0:Z1C@2YP4`0ZGi70:YoB080Zh19
00@0ZWm80:QmAP2VNd@0YGY30P2SNDL20:AjB0@0YG]90`2VNdP30:EjA`80Y7U6202SNDL80:AkA`<0
Z7e:00<0ZGi;0:YoC02[P4d00P2[P4d30:AkA`030:=jAP2RNDD0XGQ40080XGQ400<0WGQ409iiA@2P
NdL00P2RODT01P2QO4P0X7]709mjAP2PMd<0XGQ40:=jAP<0YGa800P0XgY60:9iA@2QNC`0XGTn0:9j
?`2SNT80XgY40:AkA`80YG]90`2QO4L20:1kAP@0WgY50P2QOD<0102QO4D0XGa70:5lA`2QO4P20:5k
BP0409mdB@2QMT/0XgQ=0:AiCP80YGY?00D0Y7U>0:=hC@2OLd80Wg=20:1d@`020:5eA0030:9fA@2S
MdH0XgM60080WgY600@0WWU509ehA02MN4@0W7M30P2KMT820:=jAP<0XWU50`2QN4@20:9d@`030:1d
@`2PMT@0X7Q50080WgY60P2NNTH04@2ONTH0WWU509mgA02OMD<0WW910:1b@@2OLD00WgE309ec@@2K
LCl0VW0n09U_?@2JL3h0Vg4o09ab@02GLSh0UW4m0080UG0l00@0UW4m09Ud@02LMd<0WGQ40`2PMT@6
09me@`80WWA200<0WG=109ab@02LLT000P2KLCl01P2MM400W7<o09ac?`2KLSh0VW4m09U`?080V6lk
0`2JMD400`2IM400V7<o09Mb?P0209Mb?P80Vg4o00@0VW0n09U_?@2IKcd0V6hl0P2GKC/209E`?003
09Ia?@2GLSh0V7<o0080VGA000T0VWE109ebA`2MLTD0W75409]a@@2JL3h0VG0l09Q_>@2GKSP00P2L
KSd309]]?0<0VV`k0`2EJcT00`2FK3X0Ufdk09Q^?00209Q^?080Ufdk0P2HKS`509U_?@0309E`?02F
LCd0V7<o0080VGA001@0V7<o09Ia?@2EL3`0U6lh09E`>@2FLC`0Ug8n09I`?`2EKd00Tfdn099/?`2G
LD80UFm009=]?P2BK3d0TF/l099/?@2CKCh0U6ho09EZ@0<0UV]10P2GK48209Q]@`0@09Ed?`2CLSd0
TG0k08m^>@2>KCP0Sfhi091_>P2AL3/0Vg1309Y_@P2IKT40Uf`o09I[?P2DJC`0TfPk099W>P<0UV/h
00<0UFXg09AY=P2CJ3D00P2CJ3D0202@JSd0SfTl08iX>`2>J3/0SfTl095[?P2CKD00U6i10P2CKCh0
102BK3d0TF/l095[?02@JS/208mY>P<0U6Tl:oooool002[ooooo2029GCH02027Fc@0R5`e08UM=P2:
GSL0REdf08QL=@26FS<0QETb0`29GCH208YN=`<0Relh00@0RUdf08]N=`2;GSL0S5lh0P2=H3T208iQ
>P80R64h0P29HST208YS>P80Rf@k0P2<HcL00`2=HSL0SV4g091Q=`02095P=`0309=O=`2=HSL0SF8g
00H0SF8g0P2>HCL308mR>0<0T6<i0P2;ICP308aV>@<0SFLj0P2AI3X2099U>`<0TfHl0P2DIcd00`2B
IC/0TF@j08mR>00208iQ=`0;08mR>02AI3X0TVDk09=V?02BIC/0TF@j091S>@2AI3X0TVDk09AW?@2F
JCl00`2EJC`209AX>`<0TfLj0`2BIcX209=X>`<0U6Tl402FJST809][>`80Uf/n00<0UVXk09IZ>@2E
JSL00P2DJC@00`2DJC80TVHe09M[>P0209a`?`0409Q/>`2FJST0V6`k09]_?P80V6`k00H0VFdl09Y^
?@2IKC`0V6`k09IZ>@2DJ3L909M[>P0709Q/>`2JKSd0W70o09a`?`2KKch0VVhm09U]?00809]_@P80
V6`k0P2IKC`0102JKSd0Vfln09]_?P2KKch809e]?@090:5_?P2OKch0X70o09ma?`2MLSl0WGA009ad
@02MMD40VW0n0080Vg4o00L0W79009ec@@2NM480WWA209me@`2NLT40Wg=200<0X7A300<0WW9109a`
?`2KKch00`2OLCl40:1b@080XG=10`2NLT4209mc@P<0X7A300<0W79009ec@@2OMD<00`2QMdD0102P
MT@0WgE30:9g@P2RMd830:AiA0060:9g@P2PMD00Wg@o0:5a@02SLd80YWI50P2YNDP0102XN4L0YGE4
0:=c@P2XNDD20:MhA0030:Ig@`2UMT80YGI20080Y7E10P2WMdH30:IfA@<0YGE400P0YGY70:AiAP2S
N4D0XWM40:5f@`2RMd@0Y7U60:EjA`<0Y7Q70`2UNDP20:IjB@80Y7]30P2UO4@20:ImA@80Ygi6202X
ODX00`2WO4T0Z7e:0:QmBP050:QmBPP0Yge=202XOd/00`2XODX0ZGi;0:^0C@020:b1CP030:^0C@2Y
OT/0Z7e:00P0Z7m;0P2/PDh20:^0C@050:YoC02YOT/0ZGi;0:UnB`2/PTH00P2/PTP00`2/PDX0Zh1;
0:^0C@020:]oCPP0ZWm:00H0ZWmD0:^0D`2[PE40Zh5?0:b3C@2/Pd/20:f5BP030:f5B02ZPDT0ZX59
00H0ZX59202[PTh80:Z0CPP0ZH1<00H0YX5=0:F0C02UP4`0Y7m;0:=nBP2RODT20:5lB080YGU80`2T
N4L30:=gAPP0YW]60P2RNDD20:5hA080X7M30P2OMT80202NM480WgE30:1fA02QMdD0X7I409me@`2M
Ld40W790202KMT80102LMTL0VgE609]eAP2KMDH209YdA@80VG=400P0WGM809]eAP2ILd@0V79309Ma
@P2HLT<0VG=409YdA@X0WG=10P2NM48309me@`030:1fA02JLCd0Vg8n00<0W7<o00<0VW4m09Q_>`2G
KSX0202HKc/809Q/>`80UFXm1P2FJch2095/>004091[=`2?JSH0SVTe08eX=0<0S6Lc202CJCL8095V
>@80T6Dj00@0TFHk099W?02CJ3d0U6Tn0P2EJSl209=]?P80TV`m0`2AJc`0102@JS/0TF/l099/?@2D
KSl209E_@00309A^?`2BK3d0TF/l00P0Tfdn00/0UW1309E_@02DKSl0Tfdl09A_>`2EL3/0Ug8k09Qc
?02FKCL0Ufhh09Q_>@0209U`>P0509Q_>@2GKSP0UVdg09U_?@2HKS`00`2GKC/00`2IKcd0VW0n09ab
@00809ac?`<0Vg8n0P2LLcl309ed@080X7I40P2OMD<309id@P0409ec@@2OMSh0WgHn09mf?P80X7Lo
0`2QN4001P2MM400WWE109mf@P2QN4@0XWU50:AkA`80YGa800P0XgY20:9i@@2QN400XGQ00:9i@@2T
Nd<0Ygi60:QoA`<0XgY60P2TNdL30:ElB0060:AjBP2TNTP0YG]90:ElB02UO4H0YWe50P2VOT<00`2Z
PDd0ZH1<0:MnBP020:ImB@030:MnBP2YP4`0ZX5=00<0Z7m;0P2YP4`30:Z1C@80ZX590`2[PTX20:b3
B`80[HA<0`2/Pdl30:f4D080[XEA00H0[HQA0:b7D02[QTl0ZXE>0:V4C@2XPd`20:N2B`80[8=?0`2Z
PDd00`2/Pdl0[XEA0:n6DP030:f4D080[XEA1P2_QU830:j5D@@0[HA@0P2^QE430:n6DP040;27D`2b
RED0/XUE0;:9E@80/HQD0`2`Qe<80;26E0030:f4C02^QDd0[hI>00<0/HQ@00@0/8M?0:n6CP2`Qe<0
/8MC0`2_QU830:j5D@80]8]G0P2cRUH30;:9E@030;68E02^QE40[XEA0080[hIB102`Qe<80:n;D@P0
/8MA0P2_REP0102_RUH0[hYE0:n:E@2_RU<20:n;D@030;:=F@2aS5P0/HaH0080/8]G0P2_RUH0102^
RED0]8YH0;B:F02dRUP30;>9E`80/XQF0`2aR5@00`2bRED0/hYF0;>:EP020;B;E`T0/hYF302cREL4
0;B:F080^8YH00<0]X]H0;F<F02dS5P00P2bSEP00`2aSUP0/XeH0;:=F0060;:=F0P0/hYF202bRED3
0;27D`80/HQD1P2bRED20;68E0<0/8MC00<0[hYE0:j9E02]R5<00P2/Qe800`2]R5<0[hYE0;2;EP08
0:j5C@030:f4D02^QE40[hIB0080/8MC00<0[hIB0:j5D@2/Pdl00`2ZQE000`2[QU40[8MB0:b7DP02
0:f8D`P0[XEA00<0ZGm?0:^1D@2_QED00P2aQeL00`2_QED0Zh5A0:UoC`030:n6DP80[XEA0`2]Q508
0:f4CPD0[85>0`2[P4d80:f3D`80[XEA102]Q5030:b3C`030:j5D@2]Q500Zh9>0080ZX5=00<0Zh9>
0:f4D02^QE402`2/Pdl30:^2CP80ZX5=0P2YP4`20:Z1C@80Zh9>0P2/Pdl0202[Pdl0ZX9>0:Z1C@2Z
Od`0[7i<0:inC@2_Odh0/X1?202_Q4l80:j3D080[89B00@0[89@0:b3C`2/Pdl0[8==0P2/Pd/30:b3
C`80[HA@0`2^QE430:^1C`<0[89@0P2]Pe480:f4C080[XE=0`2]Q4`30:b3B`P0[8=?00@0Zh9>0:Z1
C@2ZPDd0ZX5=0P2YP4`20:QoB`<0[89@0P2[PDl30:Z0CPP0Z7m;202ZPDd30:^2C0<0[8==0P2]Q4h9
0:b1CPP0[8=?202/P4l80:V0C080[XEA00@0[HA@0:b3C`2[PTh0ZX5=0P2YP4`80:b3C`80[H9=0P2/
PD`20:^0B`80ZWm:202[PE420:V0C080ZX5=0P2[PTh20:b3C`060:j5D@2]Q500[8=?0:Z1C@2XOd/0
Ygi:0P2UO4P80:YoBPP0Zh=80P2[PTX0102ZPD/0ZX5=0:V0C02XOT`20:QnCP80ZH1<0P2ZPDd20:^2
CP80[8=?202/PDh00`2[PTh0ZX5=0:QoB`020:MnBP060:QoB`2ZPDd0Zh9>0:b3C`2ZPDd0ZH1<0P2W
OTX00`2XOd/0ZX5=0:^2CP020:b3C`060:^2CP2ZPDd0ZH1<0:QoB`2WOTX0YWe9202ZPDd20:MmC@05
0:MmB`2WOTP0Ygi60:MnAP2WOd800P2WOd400`2YOdD0Z7i40:Mm@`020:Mm@`030:UoA@2ZP4H0[898
00P0Z7e:0P2SN4/0102TND`0YGY=0:IkCP2WO4l20:QmD0060:EjA`2VNdP0YW]80:MlB@2XODX0ZGi;
0P2ZOd`30:ImA`80YGa60`2TNdD30:MmB`030:IlBP2UNdT0YG]90080Y7Y8202VODT00`2UO4P0Ygi:
0:V0C0030:^2CP050:Z1C@2YP4`0Z7e60:UnA`2ZOdP00P2[P4T00`2YOTL0Yga50:IkA0020:=iA`80
Y7Y80`2UNdT0102VO4X0YW]80:IkB02VNdP30:EjA`80Y7U6202SNDL80:AkA`<0Yga900<0Z7e:0:Un
B`2YOT/00P2ZOd`20:ElB080Y7]70P2SNTH20:9iA@0309ehA02NNDD0X7]700<0XWe900D0XGa80:1k
A`2PMd<0XGQ40:=jAP020:ElB0040:AkA`2SNTH0XWU50:5i?080XWXo00D0XgY20:=jA02TNdL0Y7Y8
0:EkB@030:5lA`80X7]6102ONTD20:1l@P040:1kA02PNdH0X7]60:1kA`80X7Y900@0X7E80:5fB@2S
N4/0Y7U<0P2UNTd00`2TND`0XgQ;0:1d@`020:5eA080XWI50P2SMdH0102TN4L0X7]709mjAP2ONTH2
09iiA@80WGQ400<0W7M30:=jAP2SNTH00`2RNDD30:5hA080XWA300D0XGE40:1fA02PN4D0WWU509mj
AP0209ijAP0:09mjAP2NNDD0WgM409me@`2OLd80X79109ma@02OMD<0WG=109ab@0<0VW0n00@0Vg4o
09ab@02HLcl0V7<o0P2GLSh0102HLcl0VWE109ag@`2NNDD809me@`<0WWA200<0WG=109ab@02LLT00
1P2KLCl409Y`?P80VWE10P2IM40209Qc?`80Ug8n0`2JL3h309U_?@80V6hl0P2EL3`00`2FLCd0Ug8n
09Qc?`0209Ud@00709Ye@@2MLTL0WG9509aaA02KLD40VW0n09U`?00209Q_>@<0W6hm0P2KKC`309Y/
>`80UF/i0P2FK3X0102GKC/0V6hl09Q^?02HKS`209I/>P<0Ufdk102HKS`00`2EL3`0UW4m09Qc?`02
09Ud@00>09Qc?`2FLCd0UG0l09A_>02EL3T0UW4l09Mb?P2FL3l0UFm009=]?P2BK3l0Ug5209E_@02D
KSl3099/?@0309=]?P2DKSl0UV]100<0UV]10P2GK48209Q]@`0809Ac?P2CLSd0TG0k08m^>@2>KCP0
Sfhi091_>P2AL3/409M/?`@0UV/n0P2FK3X209E[>@80U6Xh0P2CJCL0202@JSd0SfTl08iX>`2=IcX0
SVPk08mY?02AJch0TV`o0`2BK3d2095[?0<0T6Xk0`2DJC`[ooooo`00:_ooool808UM=P0608IJ<`27
Fc@0R5`e08UM=P2:GSL0REdf0P28G3D308UM=P80RUhg0`2;GcP208UL=@0608YM=P2<GcP0SF0i08iQ
>P2?HS/0T6<l0P28HCP208UR>@80RV<j0P2;I3/208aS=`0308eR=`2>HCL0T64g0080TF0g00<0Telg
08iS>02>HcP00P2>HcP408mT>@80TVDk0`2AI3X3091S>@0408]U>02<IST0S6Hi08aV>@80SFLj0P2>
J3/0102AI3X0TVDk099U>`2BIC/409=V?00409AW?@2@HcT0Sf8h08iQ=`80SF0f00D0SV4g08mR>02@
HcT0TfHl099U>`03095T>P0309=V?02DIcd0UFPn0080U6Pk0`2EJC`309IZ?@80TVLj0P2CJ3/309AY
?00309EZ?@2EJCP0UFTh0080UFTh00@0UVXi09M[>P2HK3/0VFdl202GJcX809][>`0C09MZ@02FJSd0
UVXm09IZ>`2EJCP0UFXg09EZ=@2DJC@0TVHe09EY>02IKC`0VVhm09M[>P2FJST0Uf/j09Q/>`2GJcX0
V6`k09U]?00209Y^?@0309Q/>`2FJST0UFTh00P0Uf/j0P2HK3/00`2JKSd0Vfln09a`?`0209]_?P03
09Y^?@2IKD00VFe000H0VFe000@0Uf/j09Q/>`2HK3/0V6`k0`2IKC`00`2JKSd0WVhn09i^?P0609i^
?P0809m]?02NKSd0WVhm09i`?P2MLSl0W7<o09]c?`2JLSh809ab@00809mc@P2PM4<0XGE40:9fA@2Q
MD@0X7A309ib@@2MLD0309eb?`@0WW=00P2OM44309ib@@80Wg=20`2PM4<0102JL3h0W79009id@P2P
MT@20:9hAP80XGM50P2QMT430:9g@P060:5f@@2OM3l0WW<n0:5a@02SLd80YWI50P2XN4L00`2WMdH0
YGE40:=c@P020:MhA0<0YWM30`2UMT820:MgAP<0YWI50`2UMD@00`2YOT/0Yga90:EjA`030:=hA@80
Y7U60P2RMTD30:=gAP<0Y7Q70P2TNdD20:ElAP80YWe70P2WOTP80:QmBP<0ZGi;102XODX00`2WO4T0
Yge;0:MmB`060:MmB`P0Z7m;00<0Z7e:0:UnB`2ZOd`00P2[P4d00`2ZOd`0ZGi;0:QmBP080:V0C0<0
Zh1=0`2ZOd`20:UnB`060:^1A@2[PDL0Zh570:^0B@2/PD`0[85>0P2/P4l80:YoBP060:YoDP2ZP500
ZX1>0:^1C`2[PT`0[8==0P2/Pd/00`2/Q4T0ZH1:0:V0BP060:V0BPP0Zh9>202ZP4h80:QoB`80YH1<
00<0Y7m;0:=nBP2RODT00P2QO4P00`2PNdL0YGU80:AhA`020:AhA`80XgM60P2RMTD80:EjA@050:El
B02TNdL0XgY60:9iA@2QN4@00P2OMT802@2NMD40WG=109id@P2OMD<0X7I409me@`2NM480W79009]a
?`0809Ye@@0409]eAP2JM4D0VWA509YdA@80VG=40P2HLT<00`2MMdP0W7I709YdA@0309UcA080VWA5
2`2LLT0209ec@@<0WWA200<0VW4m09]b?P2LLcl00P2MM4000`2KLSh0VG0l09Q_>`0809M^>PP0V6`k
202EJSd01P2BKCT0TF`h095/>02@JcL0SfXf08iY=@<0SFPd202BJ3H8095V>@80T6Dj00<0TFHk099W
?02CJ3d00P2DJCh00`2EJSl0TV`m099/?@02095[?0<0T6Xk00@0SfTj095[?02AJc`0TV`m0P2CKCh0
0`2BK3d0TF/l095[?008099/?@0;09A^@@2DKSl0Tfdn09=]?02CKSX0U6lj09Ia>P2GLS/0UVdi09M^
>P2IL3`00P2JLCd00`2IL3`0Ufhj09I]>@0209Q^?0<0UV`j00<0V6hl09Y`?P2KLCl0202KLSh309Ya
?@80Vg8n0`2LLcl209me@`80WWA20`2MLd40102LLT00WWDo09ie?`2NMCl209mf@0<0X7M100H0WGA0
09ie@@2OMT80X7M30:5hA02SNTH20:AkA`080:9i@`2QN480XGQ20:1g@@2QN480XgY40:ElAP2WOTP3
0:9iA@80XgY60`2TNdL20:IlC0040:EkB@2UO4P0YGa80:AkA@80Y7]300<0ZH1<0:QoB`2WOTX00P2V
ODT0102WOTX0Z7m;0:V0C02WOTX30:QoB`80ZH1<0P2ZPDd40:Z1B`80Zh9<0`2/Pdd20:^2CP80[8=?
0`2]Q5001`2^QE40[8M@0:^6C`2[QTl0ZXE>0:V4C@2XPd`00P2WPT/02@2/Pdl0Zh9>0:^2CP2ZPDd0
Zh9>0:b3C`2]Q500[XEA0:b3C`030:f4D080[XEA1@2_QU830:j5D@80[HA@0`2^QE420:n6DP@0/8MC
0`2aR5@40;:9E@P0/XQF00<0/XUC0;68DP2`Qe400`2^QDl00`2_QU00/8MA0;68E0020;68E0<0/8MC
0P2_QU820;:9E@80/HQD0`2`Qe<0102_QU80[XEA0:j5D@2^QE420:n6DP<0/8MC202^RE880;27D@80
[hUH00@0[hYF0:n:E@2_RUD0[hYC0P2_Re420;6<F080/8]G102_RUH30;B:F0<0/hUG0P2bR5H0102a
R5@0/XUE0;:9E@2bRED30;>:EP030;B;E`2cRUH0/hYF00L0/hYF202cREL20;F;F@<0]8YH0`2cREL2
0;R:F0030;J;F02eS5P0]8aH0080/XeH00<0/HiH0;:=F02bSEP01P2bSEP@0;>:EP@0/XUE0`2aR5@0
0`2`Qe<0/hYF0;:9E@020;:9E@80/HQD0P2`Qe<00`2`ReH0[hYE0:f8D`020:b7DP030:f8D`2^RE@0
[hYE00P0[hI@00P0[hIB0;27D`2aR5@0/HQD0;27D`2^QE40[8=?0:^2CP80ZXE@0`2[QU430:b7DPP0
[XEA00<0ZX1>0:b2D02^Q5800P2`QU@00`2^Q580[89@0:Z0CP020:n6DP80[XEA0`2]Q5000`2/Pdl0
[HA@0:f4D0060:f4D0P0[85>202]Pe400`2[PTh0[8=?0:b3C`020:b3C`D0[HA@00L0[8=?0:^2CP2Z
PDd0ZX5=0:^2CP2/Pdl0[HA@00P0[8=?0P2[PTh30:Z1C@D0ZH1<0P2ZPDd20:^2CP80[8=?00P0Zh=?
0:Z2CP2ZPDd0ZWm<0:anC02^OTd0[gm>0;:0C`P0[hA?202]PTl20:b2DP040:b2D02/Pdl0[8=?0:b3
C@80[8=;0`2/Pdl20:f4D0<0[XEA0P2]Pe430:b2D0<0Zh5?202]Q4h0102^QDl0[HA>0:f4CP2]Q4h2
0:b3C@80Zh9<202/Pdl30:^2CP80ZX5=0`2YP4`30:Z0CP80ZGm=0`2XOT`80:QoB`P0ZX5=0`2[PT`3
0:b3C@80[HA>2@2/PDh80:b3C`P0Zgm>202ZPDd80:^2CPP0[8=?0P2]PTd20:b1C080Zh1;0P2ZOdX8
0:^1C`040:V0C02ZPDd0ZX5=0:Z1C@<0Zh9>00L0[8=?0:f4D02/Pdl0Zh9>0:Z1C@2YP4`0Ygi:0080
YWe9202ZOdX80:^3B080ZX5900@0ZX5;0:V0C02YP4`0ZGm=0P2XOTh20:V0C080ZX5=0P2[PTh20:b3
C`P0[85>00<0Zh9>0:Z1C@2YP4`00P2XOd/00`2YP4`0ZX5=0:^2CP020:Z1C@070:V0C02XOd/0Z7m;
0:V0C02ZPDd0Zh9>0:b3C`020:^2CP030:Z1C@2YP4`0Z7m;0080Ygi:202ZPDd20:MmB`050:MnBP2W
OTP0Ygi60:MnAP2WOd@00P2WOd800`2XOT@0Yge30:Il@P020:Il@P030:QnA02YOdD0Zh5700P0Z7e:
00D0XgQ;0:AiC02TND`0YGY=0:IkCP020:MlC`030:QmD02XODX0Z7e:00H0Z7e:0`2XOdT20:MnB0<0
YWe70`2WOD/20:IlBP<0YG]90P2XOd/20:MnBP070:ImB@2UO4P0Y7]70:AkA`2VODT0Ygi:0:V0C003
0:Z1C@80ZH1<00<0YW]60:MlA`2YOTT00P2[P4/00`2ZOdX0ZGi90:QmB0030:AjB080YG]90`2VO4X3
0:IkB0<0YGY70P2TNDH80:AjB0P0Y7]700@0YGY70:IkB02VNdP0YW]80`2WO4T0102XODX0YWe90:Im
B@2VODT20:ElB0<0Y7]700P0WWU509mjAP2QO4P0XWe90:=nBP2RODT0XGa80:1kA`80XGQ400<0XgY6
0:AkA`2UO4P00P2TNdL01`2SNTH0XWXm0:9j?`2RNSl0XgY20:=jA02TNdL00P2TNTP30:5lA`80X7]6
102ONTD209mk@@0409mj@`2ONTD0WgY509mjAP80WgU800<0X7E80:5fB@2SN4/00P2UNTd0102TND`0
XgQ;0:9gBP2RMTD30:=gAP<0Y7Q700<0YGU80:5lB02PNdL00P2PNdL309mjAP0309iiA@2SNTH0XgY6
00<0XWU50`2QN4@01@2RM4<0XgE40:5eA02PMT@0X7Q50080WWU50P2NNTH209iiA@0309mgA02OMD<0
Wg=20080X79100P0WgE309id@P2LLT00Vg4o09Y`?P2KLCl0W79009ec@@80VWE10P2IM400102JMD40
W7M309iiA@2ONTH809me@`80WWA20`2MLd4309ab@0<0VW0n0`2KLCl209ab@00409Ye@@2IM400VGA0
09Ud@0<0V7<o00<0Ug8n09U_?@2IKcd00P2IKcd309Y`?P0609]a?`2EL3`0UG0l09Ia?@2GLSh0V7<o
0P2IM4001`2JMD40WG9709ebA@2LLD@0Vg5109Y`?P2JLCd00P2IL3X0102KKch0VVhm09Y^?@2JKSd2
09U]?080V6`k0`2FK3X209M]>`<0V6hl0`2EJcT309I/>P<0Ufdk00<0UG0l09Ia?@2GLSh00P2HLcl0
4`2GLSh0UW4m09E`?02DKcP0UG0i09Ia?02GLSh0UW0o09E_@02CKCh0TV`o09Ma@P2FL440U6ho09=]
?P2BK3d0Tfdn09A^?`2EKd000`2FJd0209M/@@<0V6e20P2ELCd0102CKc/0TVhj099^>P2BKSX209=_
>`80U6Tl00@0UFXm09I[?P2GK3l0V6e00P2IKT4309M]>`80UV`j0`2EJcT0202AJch0T6Xm08iX>`2=
IcX0S6Hi08eW>P2>J3/0SfTl0`2@JS/2095[?0<0TV`m0`2CJ3/[ooooo`00:_ooool808UM=P80QUXc
00<0Qe/d08UM=P29GCH00`2:GSL308UM=P80RUhg0`2;GcP01P28Fc@0RE`e08YM=P2;GSL0SF0i08iQ
>P80T6<l0P28HCP208UR>@80RV<j0P2;I3/208aS=`0308eR=`2>HCL0T64g0080TF0g00<0Telg08mT
>@2?I3T00P2?I3T4091U>P80U6Lm00@0TfHl099U>`2AI3X0TF@j0P2@HcT308iU>@80SfHj0`2@Ic/4
099U>`D0TfHl202>HCL5099U>`0309=V?02DIcd0U6Lm0080U6Pk0P2EJC`0102FJSd0Uf/n09Q/?`2H
K3l309=Y>@<0U6Xj0P2EJc/409AX=`0409IZ>@2HK3/0VVhm09]_?PP0Uf/j202JK3/01P2FJD00UVTo
09IY?`2FJSd0UVXk09IZ>@80UV/h00D0TVHe09AX=`2GJcX0V6`k09M[>P0309IZ>@0309M[>P2HK3/0
VFdl0080VVhm00<0VFdl09M[>P2FJST02@2HK3/209U]?00309Y^?@2KKch0Vfln0080Vfln202HK3l8
09Q/>`P0WFln00H0WF/j09a/>`2NKSd0WW0n09aa?P2KLSh209Ua?@80WG=10`2LLT0309]a?`0309mc
@P2PM4<0XWI50080XgM600<0XGE40:1d@`2OLd800`2LLcl409ed@080WWE10`2NLT4209mc@P<0X7A3
00@0VW0n09]a?`2NM480X7I40`2RN4H0102QMdD0X7E00:5f@@2QMT420:1e@080Wg@o00@0WW<n0:5a
@02SLd80YGE40P2WMdH00`2VMTD0YGE40:Ad@`020:Ef@PH0YWM30P2WMdH30:IfA@<0YGE400@0Zh1=
0:UnB`2WO4T0YGY70P2SN4D20:AiAP80XGE40`2RMTD30:=gAP80Y7]70P2UO4P20:ImB@80Ygi:202Y
OT/30:YoC0050:UnB`2XODX0Z7e:0:QmBP2WO4T0402XOd/30:UnB`80ZWm<0`2YOT/80:V0C080Zh1=
1P2ZOd`0202YOd<0ZX160:Z0AP2[P4T0[85<0:f2C`2]PE00[X9A202ZOdX30:Z0CP80Zh9>00@0Zh9<
0:b3C@2/Pdd0[8==202WOTX80:Z1C@P0ZX1>202WOTX20:InB`030:EmBP2TO4T0Xg]80080XWY700@0
XGU60:AhA`2TN4L0Y7Q70P2SMdH30:9fA@P0XgQ300X0YWe90:ElB02TNdL0XWU50:5hA02OMT80WWE1
09ed@02LLT00WG=10`2NM4800`2LLT00VW0n09U_?@0809Ud@0<0VG=40P2HLT<309Ma@P80VgE60P2J
M4D409UcA0X0VW0n0`2KLCl309ab@00309Ya?@2KLSh0W7<o0080WGA000<0W7<o09Ya?@2IL3`0202G
KSX809M[>P@0U6Tl102CJ3/2095/>080T6/g0P2?JSH308iY=@P0TFLg202AIST01P2?I3T0T6Dj091U
>P2AIS/0TVLl09=X?@80U6Tn0`2@JS/308mY>P80SVPi0P2@JS/4095[?0X0T6Xk00/0TV`o099/?@2B
K3d0TV`k09=^>P2CKST0U6lh09E`>@2FK3X0Ufdk09U_?@0209Y`?P0609U_?@2GKC/0UV`j09Q^?02G
KC/0UV`j0P2EJcT00`2GKC/0VFlm09Y`?P0809Ya?@@0VG0l0P2JLCd209]b?P<0WG=10`2LLT0209]a
?`80W7<o0P2MM40309ie@@0909mf@P2MM400WGA009ie@@2OMT80X7M30:5hA02RNDD0XgY60080XGQ4
00H0X7M309mf@P2PMd<0XGQ40:=jAP2UO4P20:5hA0<0XWU50`2SNTH0202VODl0YGa>0:EmC02TO4T0
Xg]70:9jAP2RNd@0XGY12P2WOTX30:QoB`<0ZH1<102ZPDd30:^2CP80[8=?0`2[PTh20:b3C`<0[HA@
00<0ZhI?0:Z5CP2ZQDh00P2YQ4d20:R3C0030:N2B`2[PTh0Zh9>0080Zh9>0P2/Pdl20:f4D080[8=?
0`2]Q5030:j5D@<0[hIB0`2^QE420:f4D080[XEA0`2_QU830;27D`060:n6DP2`Qe<0/8MC0;68E02b
RED0/hYF0P2dReL80;>9E`080;F<F02cRUH0/8MC0:f4D02/Pdl0[HA@0:n6DP2`Qe<40;:9E@80/HQD
1@2`Qe<20:n6DP<0[XEA0P2]Q5020:j5D@80[hIB0P2`Qe<80:j9E0P0/HQB0P2_REP0102_RUH0[hYE
0:n:E@2_RU<20:n;D@80/8]G1P2_RUH30;B:F0<0/hUG0P2bR5HA0;>:EPP0/hUG00H0]heK0;J<FP2f
S5X0]H]I0;B:F02cREL20;:8EP80^8YH00<0]X]H0;F<F02dS5P00P2bSEP00`2aSUP0/XeH0;:=F006
0;:=F0P0/hYF2P2dReL00`2cRUH0/XUE0;68E0020;27D`030:n6DP2cRUH0/hYF00<0/XUE0`2aR5@0
0`2`ReH0[hYE0:f8D`020:b7DP030:f8D`2^RE@0[hYE00P0[hIB0P2aR5@20;:9E@040;27D`2^QE40
[8=?0:Z1C@H0ZhIA0P2/Qe880:j5D@030:^2CP2/Pdl0[XEA0080[hIB00<0[XEA0:b3C`2[PTh00`2^
QE430:f4D080[8=?202]Pe440:b1CP@0[H9?202]Q5020:Z1C@80Zh9>0P2/Pdl00`2]Q500[XEA0:j5
D@030:b3C`80Zh9>2`2/Pdl20:Z1C@80ZH1<102XOd/20:V0C080ZX5=0P2[PTh20:b3C`80ZX9>00H0
ZX5=0:^0C@2]Odd0[Wi=0:moCP2aOdh80:j3CPP0[H9?0P2/PU80102/PU00[8=?0:b3C`2/Pdd20:b3
B`<0[8=?0P2]Q5030:j5D@80[XAB00<0[H=A0:b2D02[PDl00P2ZP4h00`2YOdd0[HA@0:f4D0090:f4
D080[8=?0`2[PTh80:b3C`<0Zh9>0`2ZPDd20:V0C080ZGm=0P2XOT`30:MmB`030:IlBP2XOd/0Z7m;
00H0Z7m;202ZPDd30:^2C0<0[8==0P2]Q4h90:b1CPP0[8=?202ZOTd80:Z1C@80ZH1<0P2ZPDd0102[
PTh0[8=?0:b3C`2]Q5080:b3C`80[H9=0P2/PD`20:^0B`80ZWm:202[PTh40:Z1C@H0Zh9>0P2ZPDd0
102YP4`0Z7m;0:QoB`2WOTX80:YoBPP0Zh9:0P2ZPDT0102YP4X0ZH1<0:V0C02YOdd20:UoC`80ZH1<
0P2ZPDd20:^2CP80[8=?202/PDh00`2ZPDd0ZH1<0:V0C0040:V0C0030:Z1C@2YP4`0ZH1<00<0ZH1<
0P2ZPDd30:^2CP80ZX5=00@0ZH1<0:QoB`2XOd/0Z7m;202ZPDd0102XOd/0Z7m90:QoB@2XOdT50:Qo
A`030:QmAP2WO4D0YW]40080YGY300<0Yga50:UnA`2ZOdP0202YOT/20:AjBP80YG];0P2VO4`20:Mm
C@040:YoC02YOT/0ZGi;0:QmBP80Yga90P2VNdP0102ZPD/0ZH1:0:V0BP2YP4X20:QoB@80Ygi8102W
OD/40:IlBP090:^2CP2ZPDd0ZH1<0:MnBP2VODT0Y7]70:=jAP2RNDD0Ygi:0080Z7m;0`2YP4`20:Qo
B`040:EjA`2VNdP0Z7e:0:YoC080Zh1=00@0ZWm<0:UnB`2TNTP0Y7Y80`2UNdT30:IlBP<0YW]80`2U
NTL20:AiAPP0Y7Y8202TNdL80:EjA`P0YWe900<0WWU509mjAP2QO4P00P2SOTX0102RODT0XGa80:1k
A`2QN4@20:9iA@030:=jAP2TNdL0Y7]70080Y7]700H0Xg/n0:=k@02SNd00XgY20:=jA02SNTH20:=i
A`<0XGa70P2PNdH409mjA@80WWY000@0WWU209iiA02NND@0WWU50P2NN4L00`2QMdL0XWQ80:AjBP02
0:EkB`030:AjBP2SNDT0XWQ800@0Y7Q7102UNDP40:5lB0@0X7]70P2SNTH30:9iA@<0XGQ40P2SMD@0
0`2QMD@0X7I40:1hA@0209iiA@80WGU500D0WWU509ehA02OMd@0WgE309mc@P020:5c@P080:1fA02N
M480W79009]a?`2JL3h0Vg4o09ab@02MLd4309]f@P80W7M300@0WGQ409iiA@2ONTH0WG=1102NM483
09me@`H0WG=10P2LLT0209U_?`0309Y`@02KLD40W7920080WG=300<0WWA409Ud@02IM4000P2IM404
09Qc?`80V6hl00@0VFlm09Y`?P2JL3h0Vg4o0P2LLT0209E`?00309Ia?@2GLSh0V7<o0080VGA000L0
VWE109ebA`2MLTD0W75409ab@P2KLCl0VW4m0080VW4k0P2JL3h309U_?@<0V6hl102GKC/409Q^?0@0
U6Xh0P2EJcT309I/>P0309A_>`2FLCd0Ug8n0080V7<o01<0Ug8n09Ia?@2DKc/0U6lh09E`>@2FLC`0
Ug8n09I`?`2EKd00Tfdn099/?`2HLT<0UW1109A^?`2CKCh0TV`m09=]?P2DKSl0UFm00080UV/n0P2G
K3l209Q]@080VFi10`2EL3`409A_>`0309E`?02EJSd0UV/n0080UV/n0`2GK3l00`2HKD00UVhm09I^
?@0609I^?@06099/?`2@JSd0SVPk08aV>@2;ICP0S6Hi0P2=IcX208mY>P04091Z>`2AJc`0TF/l099/
?@80Tfdn0`2CJ3/[ooooo`00:_ooool808UM=P80Qe/d0P28G3D01029GCH0RUhg08]O>02<H3T308UM
=P80RUhg0`2;GcP01P29G3D0RUdf08]N=`2<GcP0SF0i08iQ>P80Sf8k0P28HCP208UR>@80RV<j0P2;
I3/208aS=`0308eR=`2>HCL0T64g0080TF0g00<0Telg08iS>02>HcP00P2?I3T2091U>P80TFHk0P2D
Icd0102CIS`0TVDk095T>P2AI3X2091S>@80Sf@i0P2@ICX2095V>`80TVLl102CIS`5099U>`80SV4g
102?HSP208iQ=`80TF@j00<0TVDk09=V?02CIS`00`2CIS`209=W>P0309AX>`2EJC`0UVXm0080Uf/n
00<0V6`o09=Y=`2CJCL00`2DJSP309E[>@0809EY>02DJ3L0TfLf09=W=P2EJCP0Uf/j09Y^?@2LL3l@
09Q/>`0609IY@P2FJD00UVU009IY?`2GJch0Uf/l0P2GJcX0102CIcH0U6Pg09EY>02GJcX209Q/>`05
09IZ>@2DJ3L0Uf/j09Q/>`2JKSd00P2KKch00`2JKSd0VFdl09Q/>`0<09U]?00409Y^?@2KKch0Vfln
09a`?`P0V6`o102IKC`409Q/>`P0W70o00P0W6Xi09a/>`2NKSd0Wg4o09eb?`2KLSh0VG4m09Q`?0<0
W7900`2KLCl209Y`?P0309mc@P2PM4<0XGE40080XgM600<0XWI50:1d@`2OLd800`2KLcl409ad@080
WGE10`2NLT4209mc@P<0X7A300@0VW0n09ab@02NM480X7I40P2RN4H20:5gA@80XGI10P2PMD0409md
?`050:9b@@2SLd80Y7A30:EeA02VMTD00P2UMD@00`2TM4<0Y7E10:Ae@@020:Ef@P040:Ig@`2WN4@0
YgQ40:QiA@80YgM60`2VMTD30:EeA0040:^0C@2YOT/0Yga90:EjA`80XgQ50P2TNDH20:5eA0<0XWI5
0`2SMdH20:AkA`80YGa80P2VODT20:MnBPP0ZGi;0`2ZOd`50:UnBa00Z7m;0`2YOT/20:QmBP<0ZGi;
202ZPDd60:YoC080Zh1=00P0ZGm30:Z0AP2ZP4H0Zh190:b1C02]PTl0[H5@0:j2D@P0ZWm:0P2YP4X0
0`2ZPD/0ZX5=0:Z1C@040:^1C`P0Ygi:202YP4`80:UoC@P0YWe90P2VO4X00`2UNdT0Y7Y80:=iA`02
0:9hAP030:5gA@2TN4L0Y7Q70080XgM60P2RMTD20:5eA0P0XWM20P2UO4P03P2SNTH0XGQ40:1g@`2N
MD40WGA009ac?`2JL3h0Vg4o09ab@02MLd40W79009]a?`2IKcd0V6hl202HLcl209Qb@`80Ug520`2F
L4400`2EKd00VG=409UcA00309UcA00309Qb@`2GLD80Ug5200X0V6hl0P2IKcd409Y`?P0309Q_>`2I
L3`0Vg8n0080W7<o00<0Vg8n09Ya?@2IL3`0202FKCT809IZ>@0309AY?02CJ3/0TfPk0080TVLj0P2A
IST00`2@ICP0SfXf08mZ=P0208mZ=PD0SVTe402@ICP208mT>@03091U>P2AIS/0TVLl0080TfPm00<0
U6Tn08mY>P2?JCX00`2>J3T308eW>100SfTj00H0T6Xm091Z>`2AJc`0TV`k099]>@2BKCP2099]=P03
09E[>`2FK3`0Ufdm0080V6hn00H0Ufdm09I/?02EJc/0Ufdk09I/>P2EJcT209AZ>00309I/>P2HKS`0
VFlm00P0V6lk0P2GKSX209Q_>`@0VG0l0P2LLT0309]a?`<0VW0n0`2KLSh209ac?`D0WGA00P2NMD40
0`2OMT80X7M30:5hA0020:5hA0070:1g@`2OMT80WWE109ie@@2PMd<0XGQ40:9iA@020:1g@`80XGQ4
102RNDD20:=mD0060:9lC@2QNdX0XGa80:1kAP2ONTD0WgY30P2VODT40:MnBP80YWe90`2WOTX30:Qo
B`D0ZH1<0`2ZPDd30:^2CP80ZX5=0P2[PTh20:b3C`80[HA@102YQ4d40:R3C0030:Z1C@2[PTh0Zh9>
0080[8=?0`2]Q5030:b3C`<0[HA@0P2^QE430:n6DP<0[XEA0P2]Q5030:n6DP<0/8MC0P2aR5@20;27
D`030;68E02bRED0/hYF0080]8]G00<0]HaH0;>9E`2cREL01P2cREL0202eS5P0/hYF0;27D`2]Q500
[8=?0:f4D02_QU80/8MC102bRED20;68E0@0/8MC0P2_QU840:j5D@<0[HA@0P2^QE430:n6DPP0[XUD
202aR5820:n9F0040:n:EP2_RUD0[hYE0:n:D`80[h]A0P2^RED60:n:EP<0]8YH0`2cREL20;:8EP@0
]8]G3@2cRUH80;>9E`80]heK00<0]XaJ0;F;F@2dRUP00P2cREL01P2bR5H0^8YH0;R:F02fReP0]HaH
0;B<F080/XeH00<0/HiH0;:=F02bSEP01P2bSEP80;>:EPP0]8]G00H0]HaH0;B;E`2dReL0/hYF0;:9
E@2aR5@20;27D`<0/hYF0`2bRED20;68E0030;6<E`2`ReH0[XUD00<0[8MB00<0[HQC0:j9E02`Qe<0
1`2`Qe<0202aR5@0/XUE0;:9E@2bRED0/HQD0:n6DP2/Pdl0ZX5=0P2/Qe860:^6D@P0[XEA0P2/Pdl4
0:j5D@80[8=?0P2^QE430:f4D0<0[8=?202]Pe<00`2[P4d0[85>0:b1CP020:f2C`80[X=@00<0[hAA
0:f4D02]Q5001P2]Q5001P2YP4`0ZX5=0:Z1C@2ZPDd0Zh9>0:b3C`80[HA@00<0[XEA0:^2CP2/Pdl0
1@2/Pdl00`2[PTh0[8=?0:b3C`060:b3C`80ZX5=0P2YP4`40:QoB`80ZH1<0P2ZPDd20:^2CP80[8=?
0P2YPDd01P2[PTh0[85>0:j0CP2_Odh0[Wi=0;1nC@P0[X=>202]PTl20:b2DP040:b2D02/Pdl0[8=?
0:b3C@80[8=;0`2/Pdl20:f4D0<0[XEA0P2^Q5800`2]Pe40[89@0:^1C`020:Z0CP030:UoC@2]Q500
[HA@00P0[HA@0P2/Pdl20:^2CP80ZX5=2P2/Pdl30:^2CP<0ZX5=0`2XOT`30:MmB`80YWa:202XOd/8
0:V0C0<0Zh9<0`2/Pdd20:f4CPT0[85>202/Pdl80:YnC@P0Zh9>0P2XOd/00`2YP4`0ZX5=0:^2CP02
0:b3C`030:f4D02/Pdl0[8=?00H0[8=?0P2]PTd20:b1C080Zh1;0P2ZOdX<0:^2CPH0ZX5=1P2YP4`8
0:YoBPP0Zh9<0P2YP4P0102YP4X0ZH1<0:V0C02YOdd20:Z0D080ZH1<0P2ZPDd20:^2CP80[8=?202/
PDh30:V0C080ZX5=0`2YP4`0102WOTX0Z7m;0:V0C02YP4`70:Z1C@@0ZH1<00<0Z7m;0:V0C02YP4`0
1P2YP4`40:QoA`@0Z7m900T0Z7m;0:QmB02WO4L0YW]60:EjA@2VNdH0Yga70:UnB@2ZOdX0202YOT/4
0:EkB@@0YWa:0P2ZOd`00`2YOT/0Z7e:0:MlB@020:IkB0030:EjA`2ZPD/0ZX5;00<0ZH1:0`2XOdT8
0:MmB`090:b3C`2[PTh0ZX5=0:QoB`2VODT0Y7]70:=jAP2RNDD0ZH1<0080Z7m;0`2WOTX20:QoB`04
0:EjA`2VNdP0Z7e:0:YoC080Zh1=00<0ZWm<0:UnB`2UNdT00P2UNdT30:IlBP80Yge;0`2VNdP30:Ej
A`80Y7U6202UNdT80:AkA`@0YGY7102TNDH80:ImB@0809iiA@2PNdL0XWe90:=nBP2TOd/0Xgi:0:9m
B@2QO4P40:9iA@050:=jAP2TNdL0Y7]70:ElB02SNch00P2SNd000`2SNT80XgY40:=jAP020:=iA`<0
XGa70P2PNdH409mjA@80WWY000@0WWU209iiA02NND@0WWU50P2NN4L00`2RN4H0XgU70:AjB0020:Ek
B@030:AjB02RN4H0XGM500@0YGU8102TN4L40:1kA`@0XGa80P2SNTH30:9iA@<0XGQ40P2TMTD00`2R
MTD0XGM509mgA00209ehA080W7Q40P2MN4@0202NMT<0WgE30:1d@`2RM4<0XG=20:1fA02OMD<0WG=1
0P2KLCl00`2LLT00WG=109id@P0209ag@`80WGQ40`2NNDD00`2MN4@0W79009ab@00209ec@@0409id
@P2OMD<0WgE309me@`80W7901P2MLd401P2IKT40VVm209Y_@P2KL4<0W75409ebA@80WW=6102HLcl4
09Ud@00509Q^?02IKcd0VFlm09Y`?P2KLCl00P2LLT001P2MLd40UG0l09E`?02FLCd0Ug8n09Qc?`80
VGA000L0VWE109ebA`2LLD@0W75409ab@P2LLT00Vg8n0080Vg8l0`2ILCh309Q`?@80Ufll202HKS`4
09AZ>080UF/i0`2FK3X00`2DKc/0UG0l09Ia?@0209Qc?`0>09Ia?@2EL3`0U6lk09A_>02EL3T0UW4l
09Mb?P2FL3l0UFm009=]?P2BK3l0V79309Ma@P2EKd0209=]?P0309A^?`2EKd00UW1100<0Ufdm0P2H
KSh309U_?`80UVhk0P2GKc`0302HL3d0Ufll09M_?02GKc`0VVm209U^@@2HKD00Uf`o09I[?P2EJSd0
U6Tl09=X>`P0U6ho00@0TV`o095[?P2?JC`0SFLj0P2<IST01@2=IcX0SVPk08mY>P2?JCX0T6Xk0080
TF/l00<0TV`m09=]?P2CKCh00`2CJ3/[ooooo`00:_ooool808UM=P0308YN=`29GCH0R5`e0080R5`e
00<0REdf08]O>02<H3T00`29GCH208YN=`<0Relh0P2;GSL308aO>0<0SF0i0P28HCP208UR>@80RV<j
0P2;I3/208aS=`0308eR=`2>HCL0T64g0080TF0g00H0Telg08aQ=P2=HSL0SF8g08iS>02?I3T2091U
>P03095V>`2BIC/0TVDk00<0TF@j0`2@HcT3095T>P80TVDk0`2CIS`0102DIcd0TfHl09=V?02CIS`4
099U>`04095T>P2?HSP0Sf8h091S>@80TF@j00H0T6<i08mR>02?HSP0T6<i095T>P2BIC/309AW?@03
09=V?02BIC/0TfLj0080TfLj0`2DJ3/209EY?00409=Z=P2DJcL0U6/g09A[=`80UF`h0P2FKCT0202G
JcX0UVXi09AX=`2CIcH0U6Pg09IZ>@2IKC`0Vfln202HK3/809M]>`0609IXA02FJD80UVU209MZ@@2G
JT00V6`o0P2HK3d0102FJST0UFTh09EY>02GJcX209Y^?@0509M[>P2DJ3L0Uf/j09Q/>`2JKSd00`2K
Kch00`2JKSd0VFdl09Y^?@0809Y^?@80VFdl00<0V6`k09U]?02JKSd00P2LL3l809U]@0<0Vfln0P2J
KSd309U]?0P0Vg4o00P0W6Xi09a/>`2OKch0XG=109md@@2MM400VW8n09Q`?0P0Vg4o00P0WG5009ib
@@2PM4<0XGE40:9fA@2QMD@0X7A309mc@P<0VG@o102JMD0209]f@@<0WW910P2OLd830:1d@`0309ab
@02NM480WgE300<0XGM50P2OMD<01@2SN4<0XWM20:5f@@2PMD00Wg@o0080X7E000D0XGI10:9b@@2S
Ld80Xg=20:Ad@`030:EeA0070:Ad@`2RLcl0XgA00:Ae@@2UMT80YWM30:QiA@020:UjAP80YgM60`2V
MTD30:EeA0030:UnB`2WO4T0YGY700<0XgQ50P2TNDH20:9fA@<0XgM60`2TN4L20:AjB080YG]90P2V
O4X20:MmB`P0ZWm<00@0Z7e:0:UnB`2YOT/0ZGi;0P2ZOd`20:^0C@P0ZH1:202XOd/00`2ZOd`0ZGi;
0:QmBP020:MlB@030:QmBP2YOT/0ZWm<00P0ZX5=0P2YOT/30:YoC0<0Zh1=00H0Zh550:^1A`2[PDL0
Zh190:b1C02/PDh20:b0C`P0ZWm:00H0ZH560:V0B02YP4X0ZX5;0:Z0CP2[PDl20:^1D@030:^0D`2Y
Odd0ZGm=00H0ZGm=202XOd/80:UoC@P0YGa80P2VNTT00`2UNDP0Y7Q70:=gAP020:9fA@040:5eA02S
MdH0XgM60:=gAP80XWI50`2QMD@80:5f@@0:0:9iA@2QN4@0XGQ409mf@P2NMD40WGA009ac?`2KLSh0
VFlm09Y`?P<0Vg4o00<0VFlm09Q^?02FK3X0202GLSh309I`@@80UFm00`2DKSl209I`@@<0Ug5200<0
UW1109A^?`2CKCh02P2FK3X209M]>`80V6hl0P2IKcd00`2EK3P0Ufhj09U`?00309Ya?@0309U`?02H
Kc/0UVdi00L0UVdi202EJCP209=X>`03099W>P2AIST0T6Dh0080Sf@g00<0SV<f08eX=02=J3@01@2=
J3@208aW<`P0SV<h202@ICP01P2>HcP0Sf@i08mT>@2@ICX0TFHk099W?080TfPm00@0SVPi08eW>02=
IcP0SFLh0P2<ISL208]U=P0308mY>P2>J3T0SFLh0080S6Hg00<0SFLh08iX>@2?JCX0202>J3T02`2>
J3/0SfTj091Z>`2AJcX0TVdi095/=`2AK3D0T6/d099W>P2CJ3/0UFXm0080UV/n00/0UFXm09=X>`2B
IcX0UV`j09E[>@2DJSP0TfTg09AZ>02EJcT0Ufdk09Q^?00809M^>P<0UVdi0P2GKSX309Q_>`0409]a
?`2JL3h0VW0n09Y`?P80VFlm0P2HKS`0102IKcd0VW0n09Y`?P2JL3h209]a?`80W7900`2MM40209ie
@@<0WgI200<0X7I409me@`2NM4800P2MLd400`2NM480WgE30:1fA00209mf@P80X7M30`2QN4@01P2R
NDD0XGa@0:1kC`2PNdh0X7a<09mkB@80Wg]700<0Wga60:ElB02VODT0102WOTX0102VODT0YGa80:Im
B@2VODT20:MnBP<0Z7m;00<0ZH1<0:UoC@2YOdd00P2YOdd20:Z0CP<0Zh5?0`2ZPDd20:^2CP<0[8=?
202XPd`00`2YP4`0ZX5=0:b3C`030:f4D080[8=?0P2[PTh20:b3C`<0[HA@00@0[XEA0:n6DP2_QU80
[hIB0`2^QE420:f4D0<0[hIB0P2`Qe<30;68E0@0/XUE0`2cRUH00`2dReL0/XQF0;:8EP070;:8EP03
0;67E@2`QU@0[XAB0080[XAB00<0[hEC0;26E02aR5@00P2aR5@30;27D`80[hIB00@0/HQD0;27D`2`
Qe<0/8MC0P2_QU820:j5D@040:b3C`2]Q500[HA@0:f4D080[XEA0P2_QU880:f8E0P0/HQB0P2_REP0
102_RUH0[hYE0:n:E@2_RU<20:n;D@80[HQD0P2^RED40:n:EP<0]8YH0`2cREL20;:8EP<0]HaH0P2d
ReL<0;>:EPP0/hUG0`2fS5X30;F;F@80]8YH0P2hRUP00`2fReP0]HaH0;B<F0020;:=F0030;6>F02b
SEP0/XeH00H0/XeH202cRUH80;:9E@040;B;E`2cRUH0/hYF0;>:EP@0/XUE0P2dReL20;>:EP<0/XUE
00L0/HQD0;:=F02`ReH0[XUD0:b7DP2[QU40[8MB0080[HQC202`QU@20;68E0<0/XUE00<0/8MC0:j5
D@2/Pdl00`2/Qe830:^6D@80ZXE@202^QE400`2/Pdd0[HA>0:f4CP020:j5C`80[HA>00<0[8==0:j5
D@2]Q5000P2]Q5020:b3C`80Zh9>202]PUD20:^0C@030:b1CP2]PTl0[X=@0080[hAA00<0/8EB0:f4
CP2]Q4h01P2]Q4h20:Z1C@@0Zh9>0`2/Pdl00`2ZPDd0Zh9>0:b3C`020:f4D0030:b3C`2[PTh0ZX5=
00P0[8=?0P2[PTh30:Z1C@D0ZH1<0P2ZPDd20:^2CP80[8=?00P0Z81<0:V1C@2[PTh0[H9?0:n1C`2_
Odh0[Wi=0:mmC0P0[H9=202/PDh20:b2DP040:b2D02/Pdl0[8=?0:b3C@80[8=;0`2/Pdl20:f4D0<0
[XEA0P2]Pe430:b2D0<0Zh5?202]Pe430:b2D080Zh5?0`2ZP4h;0:b3C`80Zh9>0`2ZPDd30:UoC@80
Z7i<0`2WOD/80:QoB`P0ZH1<0`2[PT`30:b3C@80[HA>2@2/PDh80:b3C`P0Zgm>202[PTh20:QoB`80
ZH1<00<0ZX5=0:^2CP2/Pdl02@2/Pdl20:f2C@80[85<0P2[P4/20:YoBPP0Zh9<00@0[8=?0:^2CP2[
PTh0Zh9>0`2ZPDd00`2YP4`0Z7m;0:QoB`030:V0C0<0ZX5=202ZOdX80:^2CP80Z7m700@0ZH1:0:V0
C02YP4`0ZX1>0P2ZP5020:V0C080ZX5=0P2[PTh20:b3C`P0[85>00<0Z7m;0:V0C02ZPDd00P2[PTh0
1`2ZPDd0ZH1<0:QoB`2VODT0Ygi:0:QoB`2ZPDd00`2[PTh00`2ZPDd0ZH1<0:V0C00>0:V0C080ZH54
00D0ZH560:V0B02YP4X0ZH1:0:V0C0020:UoC@030:YoC02YOT/0Z7e:0080Yga900<0ZGi;0:^0C@2/
PDh0202ZOd`40:ElB0@0YWe900@0ZWm<0:UnB`2YOT/0Z7e:0P2WO4T20:IkB0<0ZH1:0P2XOdT30:Mn
B0040:IlBP2WOD/0Yge;0:MmB`<0Z7i<00`0ZGm=0:b3C`2[PTh0ZX5=0:QoB`2WOTX0YGa80:AkA`2S
NTH0ZX5=0:V0C02WOTX30:ImB@80Ygi:00<0YWY90:MkBP2YOD`00P2[Odh00`2ZOTd0ZGe<0:QlB`03
0:EkB@80YWa:0`2WOD/30:IkB0<0YGY70P2TNDH80:EkB@P0Y7]70`2VNdP20:EjA`<0Y7U60`2TNdL2
0:ElB0<0YWe900T0WgY60:1kA`2RODT0Xgi:0:AoB`2SOTX0XWe90:5lB02SNTH00P2RNDD00`2QN4@0
XWU50:=jAP020:ElB0060:Al?`2TO440Y7a10:=j@P2SNT@0XWU50P2RN4H30:5lA`80X7]6102ONTD2
0:1l@P040:1kA02PNdH0X7]60:1kA`80X7Y900<0XWU50:=jAP2TNdL00P2UO4P0102SNTH0XGQ40:1g
@`2UNDP30:AhA`<0XgM600<0XWI509iiA@2ONTH00P2ONTH30:1kA`030:5lB02SNTH0XgY600<0XWU5
0`2QN4@01@2UMdH0Y7I50:9fA@2QMdD0WgM40080WGQ40P2KMd<209ag@`0309if@`2OMD<0X7A30080
XWA300/0X7I409me@`2MLd40W79009]a?`2LLT00WG=109id@P2KMT80W7M309ehA00209iiA@0309eh
A02LMd<0VgI20080Vg4o00<0W79009ec@@2NM4800P2OMD<0102PMT@0W79009ab@02LLT0309ec@@80
WWA20P2KL4D309aaAP<0WG9700@0Ug8n09Qc?`2HLcl0V7<o0`2IM400102JMD40VW0n09Y`?P2JL3h3
09]a?`80W7900P2EL3`00`2FLCd0Ug8n09Qc?`0209Ud@00709Ye@@2LLDH0W75409aaA02LLT80W790
09ac?`0209ac?@80V7<o0P2GLSh309Ia?@0309E`?02JL3h0VFlm0080VFlm0`2HKS`0102GKC/0UF/i
09E[>@2EJcT309I/>P<0Ufdk00<0U6lk09E`?02FLCd00P2GLSh04`2FLCd0UG0l09A_>`2DKcP0UG0i
09Ia?02GLSh0UW0o09E_@02CKCh0TV`o09Qb@`2GLD80UFm009A^?`2CKCh0U6ho09E_@02FL4400P2G
KC/209Q^?0<0VFlm00D0VW0n09I/>P2GKC/0V6hl09U_?@0209Y`?P0:09U_?@2HKS`0W75409]`@`2I
KT40V6e009EZ?@2DJC`0TVLj095V>@<0TF`o0P2BKD0309=^@@03099/?`2AJch0SfTl00<0SVPk00<0
T6Xm095[?P2@JS/00P2@JS/2095[?0<0TV`m0`2BIcX[ooooo`00:_ooool808UM=P0308eQ>P2;GcP0
RUhg00<0R5`e00<0RUhg08]O>029GCH00P29GCH208YN=`<0Relh00D0SV4j08eP>@2=H3T0SF0i08aO
>00308]N=`80R64h0P29HST208YS>P80Rf@k0P2<HcL00`2=HSL0SV4g091Q=`02095P=`0609=O=`2:
Gc@0Rf0e08]P=@2<HCH0SV<h0P2?I3T00`2@ICX0SV4g08iQ=`0308mR>0<0T6<i0P2CI3X209AU>`@0
UFHl0P2DIcd209=V?0<0TVDk0P2AI3X00`2@HcT0TF@j09=V?00209AW?@0;09=V?02AI3X0T6<i08mR
>02AI3X0TfHl09AW?@2EJ3h0U6Lm09=V?02BIC/00`2CIcX2099V>@<0TFDh0`2DJcD209E/=P<0UVdg
00P0VVhm09Q/>`2EJCP0TVHe09=W=P2EJCP0V6`k09Y^?@P0VFdl202FKS/209IXA00D09IY@P2GJT40
V6]109Q/?`2IKD00VFdn09Q/>`2FJST0UFTh09Q/>`2LL3l0WG5009U]?02EJCP0UVXi09Q/>`2JKSd0
Vfln09a`?`2KKch209Y^?@T0Vfln00L0VVhm09U]?02HK3/0V6`k09Y^?@2LL3l0WG5000P0Vfm20`2M
LD000`2LL3l0Vfln09]_?P0209Y^?@P0VW8o00T0WF/j09i^?@2QLD00XgE30:5f@`2NMD40Vg<o09Ua
?@2HKS`00P2IKcd0202JL3h0Vg4o09ab@02LLT00WG=109]_?P2LL3l0WW910`2PM4<00`2OLd80WW91
09Ud?`0209Ud?`@0VWE00P2KMT4309ib@@80Wg=20`2PM4<00`2OMD<0X7I40:5gA@020:5gA@0;09me
@`2MLd40W7900:EjA@2TND@0XWM20:5f@@2PMD00XGI10:9g@P2SN4<00P2RLT420:=c@P80Y7A30P2U
MD@01P2QLSh0XW<o0:=d@02UMT80YgQ40:QiA@80ZW]70P2WMdH30:IfA@<0YGE400P0YGY70:AiAP2S
N4D0XWM40:5f@`2RMd@0Y7U60:EjA`<0Y7Q70`2UNDP20:IjB@80Y7Y:0P2UNd/20:IlC080Yge=202Z
Od`0202VNdP0Yga90:QmBP2YOT/0Zh1=0:b1CP2]PTl0[X=@202YP4P80:QoB`030:YoC02YOT/0Yga9
0080YW]800<0Yga90:UnB`2ZOd`0202ZPDd30:UnB`030:YoC02[P4d0Zh1=0080[85>00H0[8960:b2
B02/PTP0[85:0:^0B`2[P4d20:]oCPP0ZWm:00H0Z8130:R0A@2YP4P0ZH1:0:Z0CP2ZP5020:YoDP03
0:^0E@2ZP500ZX1@00H0ZX1@202WOTX80:QnC0P0YGa800H0Z7Y90:MiB02WNDP0YWQ70:EgAP2TMTD2
0:=eA080XgM60P2RMTD40:5eA0P0X7E00P2NMD4209ed@080W7<o0P2KLSh00`2HKS`0VFlm09Y`?P02
09Y`?P0309Q^?02GKC/0UF/i00P0UW4m0`2EKd0209A^?`@0Tfdn00L0U6ho09E_@02FL440UFm009A^
?`2BK3d0T6Xk00/0UF/i0P2FK3X309M]>`0309=Z=P2DJcL0UVdi00<0V6lk00<0Ufhj09I]>@2EK3P0
1`2EK3P809AX=`0609=X>`2BIcX0TFHi091U>02?I3L0SV<f0P2=HSD408YU<@D0RfHb202=HSP808mT
=`80SV<h00@0Sf@i091U>P2AIS/0TVLl0P2CJ3d0102=IcP0S6Hg08aV=`2<ISL208]U=P80RV@e00<0
SfTj08eW>02<ISL00P2;ICH00`2<ISL0SFLh08mY>P0808eW>00;08aV>@2=IcP0SfTj095[>P2AK3P0
TF`g08mZ<`2>JC80T6Dh095V>@2BIcX00P2CJ3/02`2BIcX0TFHi091U>02EJcT0U6Xh09=Y=`2BJ3H0
TfTg09AZ>02FK3X0Ufdk00P0UVdi0`2EK3P209I]>@<0Ufhj00@0VW0n09U_?@2IKcd0VFlm0P2HKS`2
09M]>`0409Q^?P2IKcl0VFlo09U_?`80VW100P2KLD400`2LLcl0WGA009ed@00209ed@0<0WWE100<0
X7I609meA@2MLd<00`2LLT800`2NM4@0WgE509ie@@0309mf@P80X7M30P2QN4@01P2LNDl0W7Y=09ek
CP2MNdd0WG];09imBP80WWe800<0Y7]70:ElB02WOTX00P2XOd/00`2WOTX0YGa80:AkA`030:ImB@80
Ygi:0`2XOd/30:QnCP80ZGm?0`2ZP5000`2[PE40ZX5=0:Z1C@020:Z1C@80Zh9>0P2/Pdl30:N2B`D0
Z8=<00L0ZH1<0:Z1C@2/Pdl0[HA@0:j5D@2]Q500[8=?00@0Zh9>0P2/Pdl30:f4D0<0[hIB0`2^QE42
0:f4D0040:n6DP2`Qe<0/8MC0;27D`80/HQD0P2bRED30;B;E`80/hYF0`2bRED80;26E0030:f3D`2^
Q5@0[hEE00<0/HMG00@0/8IF0:n5E@2`Qe<0/8MC0`2_QU830:j5D@040;:9E@2aR5@0/HQD0;68E080
/8MC0P2_QU820:b3C`<0[HA@0`2^QE480:f7EPP0/XUC0P2_REP0102_RUH0[hYE0:n:E@2_RU<20:n;
D@030:b7D`2]R5@0[HQD0080[XUE0P2_RUH0102`ReL0]8YH0;B:F02dRUP30;>9E`80/XQF0P2fSET2
0;F<F0030;B;E`2cRUH0/hYF00X0/hYF202cREL40;F;F@@0]XaJ0P2hRUP00`2fReP0]HaH0;B<F002
0;:=F0030;6>F02bSEP0/XeH00H0/XeH202cRUH80;27D`<0/XUE0P2cRUH60;B;E`80/hYF0`2bRED0
102bSEP0/HaG0:n:E@2]R5<20:^6D@030:b7DP2]R5<0/HMG00L0/HMG00<0[hIB0;27D`2aR5@00P2b
RED00`2aR5@0/8MC0:j5D@020:f8D`80[8MB00@0ZhIA0:Z5D02ZQE00ZXE@202^QE480:f4C0<0[HA@
0P2/Pdl30:^2CPP0[H9E0P2[P4d01P2/PDh0[H9?0:j3D02_Q540/8EB0;66D`P0[HA<0P2/Pdl40:^2
CP@0ZX5=00L0Zh9>0:f4D02^QE40[XEA0:f4D02[PTh0ZX5=00/0[8=?0`2[PTh20:Z1C@80ZH1<0P2Z
PDd20:^2CP80[8=?00P0Z81<0:V1C@2[PTh0[H9?0:n1C`2_Odh0[Wi=0:mmC0P0[H9=202/PDh20:b2
DP040:b2D02/Pdl0[8=?0:b3C@80[8=;0`2/Pdl20:f4D0<0[XEA0`2[PDl30:b2D080[H=A202]Pe<2
0:b2DP80Zh5A102ZP5080:b3C`80[HA@0P2/Pdl30:^2CP040:Z1C@2ZP4h0ZX1>0:Z0CP80ZGm=0`2X
OT`@0:QoB`<0Zh9<0`2/Pdd20:f4CPT0[85>202/Pdl80:b0C`P0[8=?102YP4`40:Z1C@P0[8=?0P2]
PTd20:b1C080Zh1;0P2ZOdX80:^2BP80[8=?0P2[PTh20:Z1C@80ZH1<00@0Ygi:0:QoB`2XOd/0ZH1<
0P2ZPDd20:^2CPP0ZWm:202[PDl20:QoA`040:QoB@2YP4`0ZX5=0:Z0CP80Zh5A0P2YP4`20:Z1C@80
Zh9>0P2/Pdl80:b1CP030:MnBP2XOd/0ZX5=0080Zh9>00L0ZX5=0:QoB`2WOTX0Y7]70:ImB@2XOd/0
Zh9>0080[8=?00<0Zh9>0:Z1C@2YP4`01@2YP4`20:Z1C@P0Z7m;0P2YPD<01@2YPD@0ZH180:V0BP2Y
P4X0ZGm=0080ZGm?00<0Zgm>0:YnC@2YOD`00P2YOD`00`2[Odh0[H5@0:j2D@080:YoC0@0YWe7102U
O4H50:QmBP<0Yga90`2XOdT20:MnB0<0YWe70P2VO4X20:MmB`050:QnC02YOdd0ZGm=0:UoC@2[PTh0
0P2ZPDd00`2XOd/0Ygi:0:ImB@020:ElB0030:^2CP2YP4`0Ygi:00<0YGa800D0YWe90:MnBP2XO4d0
ZGe>0:YnC`020:]oD0040:UmCP2WNd`0YWY;0:EkB@<0YWa:0P2WOD/20:QnC0<0YW]80`2UNTL20:Ai
APP0YG]9202TNdL20:QmBP80Yga900@0YW]80:EjA`2UNTL0YGY70P2RNDD20:=jAP80Y7]70P2UO4P0
0`2ONTH0XGa80:9mB@030:AoB`050:=nBP2RODT0Y7]70:=jAP2RNDD00P2QN4@0102SNTH0YGa80:Im
B@2UOD020:Al@@050:=j@P2SNT@0XWU50:9hAP2QMdD00`2QO4L20:1kAP@0WgY50P2ROT@0102RODH0
XWe80:9mB02RODT20:9lB`090:=jA02TNdD0YGa60:ElAP2TNdD0XgY40:5h@P2PMd40Y7Q70080XgM6
0P2RMTD20:5eA0040:1d@`2LMd<0WGQ409ehA080WWU50P2ONTH00`2PNdL0XgY60:=jAP030:9iA@<0
XGQ40P2UMdH01@2RMTD0XGM509mgA02MN4@0W7M30080VgM30P2LMd<00`2NMT<0WgE30:1d@`020:=e
A0030:5gA@2PMT@0WWA200<0W79000D0WG=109id@P2JMD40VgI209ag@`0209ehA00409ag@`2JMD40
VGA009Y`?P80Vg4o00D0W79009id@P2OMD<0WgE30:1fA00209]a?`80W79000@0WG=109id@P2NM480
WWA2102MLTP409aaA`80Ug8n0P2HLcl209Ud@080VWE10`2LLT0309]a?`80VW0n0P2EL3`00`2FLCd0
Ug8n09Qc?`0209Ud@00709Ye@@2LLDH0W75409aaA02LLT80WG=109ed@00209ed?P<0V7<o0P2GLSh3
09Ia?@<0VW0n00<0VFlm09Q^?02HKS`00P2GKC/209I/>P<0Ufdk102HKS`00`2CKSX0U6lk09Ia?@02
09Mb?P0>09Ia?@2DKc/0Tfhj09A_>02EL3T0UW4l09Mb?P2FL3l0UFm009=]?P2BK3l0VG=409Qb@`2F
L44309A^?`0309E_@02FL440V6hl0080V6hl0`2IKcd209Y`?P0409E[>@2GKC/0VFlm09Y`?P80Vg4o
0P2IKcd01@2IKT40V6e009Q]@02GK3l0UV/n0080UFXm00<0U6Tl08e[?P2=Jch00P2>K3l208m]@080
T6i100<0TV`o095[?P2@JSd00P2@JSd00`2AJch0Tfe009A^@@03099/?@80TF/l0`2@JS/3099W>R_o
oooo000Zooooo`P0REdf00P0SV8k08eQ>P2:GSL0R5`e08MK=028G3D0REdf08YN=`<0REdf0P2:GSL3
08]O>080Sf8k00H0SV4j08eP>@2<GcP0Rehg08YM=P29G3D208QQ>080RF8i0P2:HcX208]T>`80S6<g
00<0SF8g08iQ=`2@HCL00P2AH3L01`2CGcL0REhc08UN<`2:Gc@0Rf0e08eR=`2>HcP00P2?I3T208aO
=@0408eP=P2>HCL0Sf8h08mR>080T6<i0P2CI3X209AU>`<0UFHl00D0UVLm09AW?@2DIcd0U6Lm09=V
?002099U>`@0TF@j00X0TVDk09AW?@2EJ3h0UFPn09AW?@2BIC/0TF@j08mR>02AI3X0TfHl0P2EJ3h0
0`2DIcd0TfHl095T>P0209=W>P03099V>@2AICP0T6@g0080Sf<f00<0SV8e09A[=@2DJcD00`2EK3H3
09I]=`0309]_?P2IKC`0UFTh0080TVHe00<0U6Pg09M[>P2IKC`0202IKC`809I^>`0609IXAP2FJ4@0
UVQ409MZ@`2HJd80VFa20P2IKD00302JKSd0Uf/j09EY>02IKC`0WW9109mc@P2JKSd0UFTh09IZ>@2H
K3/0VVhm09]_?P80W70o00<0Vfln09Y^?@2KKch0202KKch01`2JKSd0V6`k09Q/>`2HK3/0VVhm09a`
?`2MLD00202LL4<209mc@P0409ib@@2MLD00WG5009a`?`80Vfln202JLSl0202NK3/0Wfln0:9b@@2T
MT@0XgQ50:1g@`2LM400VG4m0P2GKC/02@2HKS`0VW0n09]a?`2LLT00WG=109id@P2JKSd0Vfln09ea
@00309mc@P0309ib@@2MLD00V7Do0080V7Do102IMT0209Yg@@<0WW910P2OLd830:1d@`0;0:1fA02Q
MdD0XWQ60:9hAP2PMT@0WWA209ab@02JL3h0Yga70:EjA@2SN4<00P2QMT40102RMd80XgQ30:AiA02S
Ld820:9b@@80Xg=20P2TM4<02@2UMD@0XG8n0:5b?P2SM400YGI20:MhA02YNTH0ZW]70:]lB0020:Mg
AP<0YWI50`2UMD@0202SN4D0XWM40:5f@`2PMD80XGI30:9gA02TNDH0YGY70`2UNDP30:IjB@80Yg]:
0P2TNTX20:EkB`80YWa<0P2WODd80:YoC0080:EjA`2VNdP0Yga90:UnB`2[P4d0[H9?0:n4D@2`QE88
0:V0B0P0Z7m;00<0ZWm<0:UnB`2WO4T00P2VNdP00`2WO4T0ZGi;0:YoC0080:Z1C@040:QmBP2YOT/0
ZGi;0:YoC080Zh1=0P2/PDh0202^Q4P0[H=90:f3B@2/PDX0Zh1;0:YoC02ZOTd0ZGe<202ZOdX01P2X
P480Z8130:V1AP2YP4X0ZX1>0:YoDP80ZWmD00<0ZWmE0:^1D@2[PE401P2[PE480:MnBPP0Z7i<202T
NdL20:MiB0030:IhA`2UMdH0Y7I50080XgE400<0XWA30:=gAP2SMdH00P2RMTD30:5eA0030:1d@`2O
M3l0Wg@o00H0Wg@o202KLSh0202GKC/0V6hl09U_?@2JL3h0VFlm09Q^?02FK3X0UF/i202FLCd209E_
@080U6ho0`2CKCh0102BK3d0TF/l099/?@2CKCh209A^?`03099/?@2@JS/0SVPi00X0U6Xh0P2EJcT3
09I/>P0509M]>`2AJ3@0TVTe09A[=`2FKCT00P2GKSX00`2FKCT0UF`h09E/>00709E/>0P0U6Pg0P2B
IcX0102AIST0T6Dh08iS=P2=HSD208aQ=080R6<_1029I30308YU<@P0SF8h202?I3L208iS>00308mT
>@2@ICX0TFHk0080TVLl00@0TfPm08aV=`2<ISL0S6Hg0P2;ICH308YT=@0308iX>@2=IcP0RfDf0080
RV@e00<0RfDf08eW>02>J3T0202<ISL02`2;ICP0SFLh08mY>P2AJcX0TF`h091[=P2?JS<0SVTb08iS
>02?I3T0TFHk0080TVLl00/0TFHk08mT>@2>HcP0UF/i09AZ>02CJCL0TVPf09=Y=`2DJSP0UV`j09M]
>`0809E/>080U6/g0P2EK3P309I]>@0409M^>P2IKcd0VFlm09U_?@80V6hl0`2GKC/309Q^?P80VFlo
0`2JL40209ac?`H0WGA000<0WgE509idA02LLT800P2KLD400`2LLT80WG=309idA00209ie@@80WgI2
0`2PMd<0302QN4@0VgQ>09]hCP2LNTd0WG]=09ekB`2NODX0Wgi;09mnB@2SNTH0YGa80:ImB@80Z7m;
00<0YWe90:ElB02SNTH00`2VODT30:MnBP80Z7m;0`2XOTh20:UoC`@0ZX1@00@0ZH1<0:Z1C@2ZPDd0
ZX5=0P2[PTh20:b3C`@0Yh9;102XPd`00`2XOd/0ZX5=0:b3C`020:j5D@030:f4D02/Pdl0Zh9>00<0
Zh9>0`2/Pdl20:f4D0<0[hIB0`2^QE420:f4D0@0/8MC0P2aR5@20;:9E@80]HaH0P2dReL0102cRUH0
/XUE0;68E02aR5@80:n5D`080:Z0D02/PU80[hEE0;:8F02cRET0/XQH0;26EP2_QED20:n6DP80[XEA
102]Q500102cRUH0/XUE0;:9E@2bRED20;68E080/8MC0`2/Pdl20:f4D0<0[XEA202]QeH80;:9D`80
[hUH00@0[hYF0:n:E@2_RUD0[hYC0P2_Re420:b7D`80[HQD00@0[XUE0:n:EP2_RUH0/8]G0`2dRUP3
0;>9E`80/XQF0`2fSET00`2eS5P0]8]G0;>:EP0;0;>:EPT0/hUG0P2dRUP00`2eReT0]XaJ0;N=F`02
0;R>G080^8YH00<0]X]H0;F<F02dS5P00P2bSEP00`2aSUP0/XeH0;:=F0060;:=F0P0/hYF202_QU82
0;68E0040;:9E@2cRUH0]8]G0;B;E`80]HaH0`2dReL30;>:EP80/XUE00@0/hiI0;6<E`2_RUD0[HQC
0P2[QU420:b7DPP0/HMG00P0[XEA0:n6DP2aR5@0/XUE0;>:EP2bRED0/HQD0;27D`80[HQC0P2/Qe80
102[QU40ZXE@0:Z5D02YQ4l80:j5D@P0[HA<0P2]Q5030:b3C`<0Zh9>202]PUL20:^0C@040:b1CP2]
PTl0[hAA0;25DP80/HIC202]Q4`01P2]Q500[8=?0:b3C`2/Pdl0Zh9>0:Z1C@80ZH1<00@0Z7m;0:Z1
C@2[PTh0[HA@0P2^QE400`2]Q500Zh9>0:Z1C@080:b3C`@0[HA@0P2/Pdl20:^2CP80ZH1<0P2ZPDd2
0:^2CP80[8=?00P0Ygm;0:V1C@2[PTh0[X=@0;22D02_Odh0[Wi=0:ilB`P0[H9=202/PDh20:b2DP04
0:b2D02/Pdl0[8=?0:b3C@80[8=;0`2/Pdl20:f4D0<0[XEA00H0ZGm=0:Z0CP2ZP4h0Zh5?0:b2D02]
Pe420:j4DPP0[H=C0P2/PU820:^1D@<0ZX1@00<0ZGm?0:b3C`2/Pdl01P2/Pdl20:f4D080[8=?102[
PTh30:^1C`80ZX1>0`2YOdd@0:QoB`<0Zh9<0`2/Pdd20:f4CPT0[85>202/Pdl80:f1D0P0[8=?0P2Z
PDd60:V0C0P0[8=?0P2]PTd20:b1C080Zh1;0P2ZOdX80:^2BP<0[8=?00<0Zh9>0:Z1C@2YP4`00P2Y
P4`20:MnBP030:QoB`2YP4`0ZX5=0080Zh9>00<0[8=?0:YoBP2ZOdX01P2ZOdX80:^1C`060:MnAP2X
OdL0Z7m90:V0C02ZPDd0ZX1>0P2[PE420:V0C080ZX5=0P2[PTh20:b3C`P0[85>00<0Ygi:0:QoB`2Z
PDd00P2[PTh01`2ZPDd0Z7m;0:MnBP2TNdL0YWe90:QoB`2[PTh00P2/Pdl00`2[PTh0ZX5=0:V0C004
0:V0C0<0ZX5=202XOd/0102YPT40ZH530:V1A02YP4P20:V0C0060:UoC@2YOdl0ZGiA0:f1D02/P4l0
Zgm>0P2ZOTd00`2/P4l0[X9A0:n3DP080:YoC0@0YWe7102UO4H20:MlB@H0Z7e:0`2WOTP20:ImA`<0
YGa60P2VO4X0102WOD/0Z7i<0:QnC02YOdd20:Z0CP80ZX5=00@0ZH1<0:QoB`2XOd/0Ygi:0P2VODT0
2P2[PTh0ZH1<0:MnBP2UO4P0Y7]70:ElB02VODT0Ygi:0:UmCP2ZOTl20:]oD0040:YnC`2XO4d0YWY;
0:EiBP@0YWa:0P2WOD/20:QnC0<0YW]80`2UNTL20:AiAPP0YG]9202TNdL20:UnB`040:QmBP2WO4T0
Yga90:IkB080YGY70`2QN4@00`2RNDD0XgY60:AkA`020:AkA`0:09mjAP2QO4P0Xgi:0:AoB`2UP4`0
Y7m;0:=nBP2RODT0Y7]70:=jAP<0XGQ400T0XgY60:ElB02VODT0YGe00:Em@P2TO440XgY20:=jA02R
NDD00P2QMdD30:5lA`80X7]6102ONTD20:=oA@040:=nA`2SOTT0Xgi90:=nBP80Xge<00P0XgY40:Ak
A@2UO4H0YGa60:AkA@2SNT@0XGQ209mf@080XgM600@0XWI50:5eA02QMD@0X7A30P2OLd8209]f@P04
09ag@`2MN4@0WGQ409iiA@80WgY60P2SNTH30:9iA@<0XGQ40P2UMdH00`2SMdH0XGM509mgA00209ag
@`80VgM30P2LMd<00`2NMT<0WgE30:5eA0020:=eA0030:5gA@2PMT@0WWA20080W79000H0WG=109id
@P2OMD<0VGA009Ye@@2LMd<209ehA00309]f@P2IM400Ug8n0080VW0n00<0Vg4o09ab@02MLd400P2O
MD<00`2PMT@0Vg4o09]a?`0209ab@00409ec@@2NM480WWA209me@`80WgA:00<0WW=909ebB02LLDL0
0P2KL4H01P2JKdD0Ug8n09Mb?P2GLSh0V7<o09Ud@0<0VWE100D0WWA209ec@@2MLd40W79009]a?`02
09Y`?P0609U_?@2EL3`0UG0l09Ia?@2GLSh0V7<o0P2IM4001`2JMD40W75609aaA02LLD@0WG=309ec
@@2MM4000P2MM3h309Mc?`<0UW8n0P2ELCd209]a?`0409Y`?P2IKcd0VFlm09Q^?0@0Ufdk0P2HKS`5
09U_?@0309=^>P2DKc/0UW4m0080Ug8n00h0UW4m09A_>`2CKSX0U6lh09E`>@2FLC`0Ug8n09I`?`2E
Kd00Tfdn099/?`2ILd@0V79309I`@@80U6ho00<0UFm009I`@@2GLD800`2HKc/209U`?0<0VW4m00T0
UVXi09M[>P2JKSd0W70o09ea@02LL3l0Vfln09Y^?@2DJC`00P2EJSd01@2FJch0Uf`o09Q]@02HKD00
VFi100<0S6Xm00<0SF/n08i/?`2?KD000P2?KD02099/?`<0TF/n00<0Tfe009E_@P2GLD@00P2CKCh0
102BK3d0TF/l095[?02@JS/208mY>P<0TVLj:oooool002[ooooo0P27H3L308IO=P<0QEhe0P28GC82
08UN<`<0RUld00<0Rf0e08aQ=P2<HCH00P2=HSL0102>HcP0Sf@i08mT>@2@ICX808YO=00808QM<P2:
Gc@0SF8g08mT>@2@ICX0SV<h08aQ=P2;H3D808iQ=`0308iR=@2@I3L0TVHi0080U6Pk00<0TfLj099V
>@2AICP0202>ICT0102DIcd0TfHl09=V?02BIC/2095T>P@0T6<i102AI3X3099U>`80TFDh0P2BIST2
09=W>P80U6Pk202FJSd309UV=`0309QU=P2GI3D0UV<d0080UV<d0P2FICX0102GIS/0V6Ll09QW?02I
J3d209YY?P0309aY?P2KJ3d0VFHk0080V6Dj00<0VFHk09]X?@2LJCh00`2GJcX309IZ>@80UFTh0P2H
K3l209U]@00409M[?P2EJC`0TfLj095U>0P0UFTl00D0VVhm09U]?02IKC`0V6`k09M[>P0209IZ>@03
09EY>02IKC`0VFdl00H0VFdl0P2JKD@00`2JKD<0VVi109Y^?`0209Y^?@0709Y_?02MJS/0Vf/k09][
>`2KKC`0VFdl09Q^?00209Q`?@<0VFhk0P2JKc`309]`?@80W70o00@0Vfln09Y^?@2JKSd0VFdl0P2H
K3/00`2MLD00W70o09Y^?@0209Q/>`0309U]?02JKSd0Vfln00P0WG500P2LL3l209ea@00709ib@@2O
Ld80Wg=20:1d@`2MLD80WW930:1d@`020:5f@`030:1e@02NLc`0WG8k00T0Wg=200P0XGI30:1e@P2O
M440WW=009md@@2PMD80XWM40:=hA@<0XGI30`2PMD8209md@@80X7E20P2QMT<30:9gA0030:=hA@2R
Md@0XWM40080XWM4102QMT<20:1e@P030:5f@`2RMd@0XgQ50080YGY700<0YW]80:9fA`2RMTL01P2R
MTL80:9iA@P0XgY60P2TND@20:EjA@@0YW]60`2ZOd`20:UnB`<0Z7e:0P2XOd/30:V0C0<0ZX5=202Z
Od`20:IkAP040:MlA`2XODP0ZWm:0:^0B`80[85<0`2[P4/=0:YoBPP0ZWm<2@2/Pdl01`2[PTh0ZH1<
0:QoB`2WOTX0Z7m;0:V0C02ZPDd00P2XOdL30:MnAP@0YWe50P2/Pdl00`2[PTh0ZX5=0:V0C0020:Mn
BPT0YWe90P2UNd/0102UNdT0Y7]70:AkA`2TNdD20:=j@P040:MnBP2VODT0YWe90:ImB@80YGa80P2T
NdL01P2SNTH0XWU50:9iA@2QN4@0X7M309mf@P80WWE10`2OMT8209ie@@<0WGA0202MLd4209ea@00<
09a`?`2KKch0VFdl09Q/>`2GJcX0UVXi09U^@@2HKD00Uf`o09I[?P2EJSd0TfPk0P2BIcX309AY?080
UFXm0`2FJch209A^?`0409=]?P2BK3d0T6Xk08mY>P80SVPi00@0T6`l095]?@2AKCd0TFdm0P2BKSh2
09=_?`0308eW>P2?JC`0TF/n0080TV`o00L0TF/n08mY?02=IcX0S6Hg08eW>02@JS/0Tfdn0080U6ho
00D0Tfdn099/?@2BKSh0TVhn095]?@02091/?00308m[>`2>JSX0SVXj0080UV`j00@0UF/i09AZ>02D
JSP0TfTg0P2BJ3H209AZ>00609=Y=`2BJ3H0T6Hd08mU<`2>I380SF<a0`2=IcP208aV=`<0RfDf0P2>
J3T01@2=IcP0RfDf08YT=@29Hc@0R68c0080Qf4b0`27HC0208QR<@<0RF<b1027HC@408IP<`P0RfDh
0`2:ISH208UU=@<0R6@d00@0SF8_08iS<02>Hc00SV<`0P2?I342091U<P0308eW>02<ISL0RV@e0080
R68c00T0RV@e08aV=`2=IcP0RUlb08]P<`2>HcH0T6Dh095V>@2BIcX00P2AIST0402@ICP0TFHi09=X
>`2DJC`0UFXm09AY?02CJ3/0TVLj095[?P2@JSd0SVPk08eW>P2>J3/0SfTl099/?`2CKD0208mT=`04
091U>02AIST0TfPk09AY?080UFXm0P2AK3D3099]=P<0Tfhg202FK3X809Q^?080VG0l00<0VW4m09]b
?P2LLcl00P2MM4002@2NMD40Ug8m09Mb?@2HLch0VG@o09Ye@02KMT40W7M209eh@`0809id@P<0XWQ6
0P2SNDL30:AjB080YWe90P2UO4P0102TNdL0XgY60:=jAP2RNDD20:AkA`80YGa80`2VODT00`2WOTX0
YGa80:ElB0030:ImB@80Ygi:0P2XOd/20:QoB@<0ZH1:0`2ZPD/30:V0BP80ZX5;0`2[PT`00`2YP4`0
Zh9>0:f4D0020:j5D@030:f4D02[PTh0ZH1<0080[H=A0`2^Q5830:n5D`80/8MC0P2_QU80102^QE40
[HA@0:f4D02/Pdl40;27D`@0[hIB00@0/hUG0;:8EP2bR5H0/HME0P2`QU@20:n5D`80/XQF00@0/HME
0;26E02_QE<0[XAB0P2]Pe420:Z5D@<0ZhIB0`2/Qe<80;27D`030:j5D@2`Qe<0/HQD0080/XUE00<0
/8MC0:j5D@2/Pdl0202`Qdl80;68E0080;>9E`2aQeD0[hEC0:j4DP2]Pe40[XAB0:n5D`2`QU@30:j9
E080[hYE0`2`ReH80;:9E@<0/HME0P2bR5H30;>9E`80^8iL00<0]heK0;J<FP2eReT00P2dRUP20;>9
E`@0/XQF0P2aQeD20;26E080/XMM00<0/XML0;:7FP2bR5P00P2bR5H00`2bRED0]HaH0;F<F00F0;F<
F080/HQD00<0/XUE0;>:EP2dReL00P2eS5P02@2fSET0/hYF0;68E02_QU80[XEA0:f4D02^QE40[hIB
0;27D`080:j9E@80[HaF00<0[haF0:n:E@2aRED00P2aR5@00`2bQe@0/8MC0;27D`060;27D`030:f8
D`2/Qe80ZXE@0080ZHA?00<0ZXE@0:b7DP2]R5<0202`Qe<20;68D0040;27D@2`Qe<0[hIB0:n5D`80
[XAD202^QE480:f3D@060:j5C`2]Q4h0[HA>0:b3C@2[PT`0ZX5;0P2YP4X@0:f4D0P0[8=?00@0Zh9>
0:b3C`2^QE40[XEA0P2_QU800`2^QE40[8=?0:^2CP080:b2D080[H5B00@0[H5@0:f2C`2]PTl0[H9=
0P2]PT/80:j5D@80[H=A0`2/PU030:^1C`@0ZX1>102[PDl80:b3C`P0[H9?00P0[XEA0:f4D02]Q500
[HA@0:b3C`2[PTh0ZX5=0:V0C0P0[8=?2P2]Q4`0102]Q4h0[HA@0:f4D02]Pe420:f3D`P0[HA@0`2/
Pdl00`2[PTh0ZX5=0:V0C0020:V0C0030:YoC02[P4d0[85>0080[H9?00H0[85>0:^0C@2ZOd`0[HA@
0:^2CP2YP4`20:QoB`030:Z1C@2/Pdl0[HA@0080[XAB00<0[H=A0:b2D02[PDl00P2ZP4h00`2YOdd0
Ygi:0:MnBP060:MnBP0;0:b4A`2ZPTL0Z8150:MnAP2WOTP0Z7m;0:Z0CP2/PU00ZHI@0:Z5D02YQ4l0
0P2[Pdl0102/Pdl0[85>0:j0CP2^P4h80:UoC@060:QoB`2YP4`0ZX5=0:^2CP2/Pdl0[XEA0P2_QU80
0`2^QE40[HA@0:^2CP020:Z1C@0;0:^2CP2]Q500[XEA0:b3C`2ZPDd0ZH1<0:QoB`2YP4`0ZX5=0:b3
C`2^QE40202YP4`20:b0D@040:f1DP2^PU<0[X9C0:n3E080/8AE0`2[PTh50:b3C`030:UnB@2ZOdX0
Zh1;0080[85<00<0Zh1;0:UnB@2XODP00P2XOd/0102YP4`0ZX5=0:b3C`2]Q5020:j5D@P0[85<0P2[
PDl20:Z0CP0<0:UoC@2XOT`0Z7i<0:MmB`2VODT0Ygi:0:QoB`2ZPDd0Zh9>0:f4D02^QE40[hIB1@2[
P4d00`2/PDh0[H9?0:f2C`080:Z1B`P0ZH1<202XOd/00`2XODP0ZGi90:^0B`020:b1C0030:^0B`2Y
OTT0Z7e800P0Ygi800<0Z7m;0:V0C02[PTh00`2/Pdl00`2[PTh0ZH1<0:QoB`020:V0C0<0Z7m;00<0
ZH1<0:^2CP2/Pdl00P2YP4P0102YP4X0ZX5=0:Z1C@2YOdd20:UoC`X0Z7m;0`2WOTX30:ImB@80YGa8
0P2VODT00`2WOTX0Z7m;0:QoB`040:V0C080Z7m;0`2WOTX02@2XP480Z8130:R0A@2XOdT0Z7i<0:Qm
D02XOE80Z7eC0:QoB`020:MnBP050:ImB@2UO4P0Y7]70:AkA`2SNTH0202WOTX00`2QMT<0Y7U60:Ml
B@020:UnB`030:MlB@2TNDH0XGI300P0YWe90P2[OD`30:YlB`<0ZG]:0P2TNdL20:ElB080YWe90P2W
OTX30:ImB@D0Ygi:0P2VODD0102VODL0YWe90:ImB@2VO4X20:IlC080Y7]70P2SNTH20:9iA@80XGQ4
00H0X7I40:9hAP2TNTP0YWa:0:MmB`2VO4X20:EkB@<0XGQ41@2RNDD01@2QN4@0Y7]70:ElB02SNTH0
WgI20080WWE100<0X7M30:AkA`2TNdL00P2TNdL40:ElB0050:ImB@2WODd0YG];0:=iB@2QMdL00P2O
MDD20:1fAP040:9hAP2SNDL0XgU70:AjB080YG]90P2VO4X20:QjB@040:MiB02VN4L0YWQ70:EgAP80
Y7I500<0YWe90:ElB02SNTH00`2QN4@00`2SNTH0Y7]709ehA00209ehA080WWU50`2ONTH01P2MLd40
WWA209id@P2OMD<0X7I40:5gA@80XWQ600<0XWU509mf@P2KLSh00P2HKc/00`2LLcl0X7M30:=jAP02
09id@P<0WgE30`2PMT@00`2QMdD0X7I409id@P0209ab@00309ec@@2NM480WgE30080W7M000<0W7M2
09ag@`2LMTD00P2LMTL00`2LMTT0WWA209id@P0309ec@@<0W79000/0VW0n09I/>P2CJCL0UV`j09]a
?`2NM480Vg4o09M]>`2HKS`0VFlm09]a?`0209ab@00609]a?`2IKcd0V6hl09M/@@2HKD80VVm40P2K
L4D02@2JKd@0V6e209M/@@2IL3`0VW4m09]b?P2LLcl0WGA009mf@P020:1g@`P0VFlm00<0W79009]a
?`2KLCl00P2JL3h309U_?@80UG0l00@0UW4m09Mb?P2HLcl0V7<o0`2IM4004@2LLT00Vg4o09U_?@2G
KC/0UV`j09M]>`2IKcd0VW0n09aaA`2JKdD0UV]009AY?02DJSX0UV`j09U_?@2KLSh0VFlm0080V6hl
00D0Ufdk09I/>P2EJcT0UF/i09AZ>00809M]>`0309Q]@02IKT40Vg130080Vg1300H0VFi109M/?`2F
Jch0UF/i09I/>P2GKC/209Q^?00309M]>`2FK3X0UF/i00P0U6ho00<0UFm209A^@@2BK3l00P2BK3l0
0`2DKT40UW1309MaA00209U]@00609Q/?`2FJSd0UFTl09AX>`2CIcX0TVHi0`2;JT4[ooooo`00:_oo
ool00`25GSD0QUlf08IO=P0508IO=P80REhc0P2:Gc@208]P=@D0S64f00<0SF8g08iS>02>HcP00P2?
I3T908YO=00308]P=@2<HCH0SF8g0080SV<h00<0SF8g08aQ=P2>HCL01`2>HCL0202>HSD0Sf<f095U
>02BIST0TfLj099V>@2AICP0T6@g202>ICT00`2CIS`0TVDk099U>`02095T>P80T6<i00<0Sf8h091S
>@2@HcT0102AI3X3099U>`80TFDh0P2BIST209=W>P80U6Pk202EJC`309MW=`0309IV=P2EICD0UFDe
0080U6@d00<0UVDj09MV>`2GIS/00P2HIc`209UX?@80VVTn00L0VFPm09MV>`2FICX0UVDj09MV>`2I
J3d0VVTn00<0Uf/j0`2FJST209EY>00809M[?P2HK3l0VFe009U]@02GJch0UFTl09=W>P2BIST809EY
?0@0V6`k102GJcX809U]?080VVe400<0VVe309Y^@@2JKSl00P2JKSd01`2JKc`0WFXk09][>`2KJc/0
Vfdl09U]?02HKS`00P2HL3d209U^>`<0VVll0`2KL3d209a`?`80Vfln00L0VVhm09U]?02IKC`0VFdl
09a`?`2KKch0VFdl0080V6`k00<0VVhm09]_?P2LL3l0202MLD0209a`?`80WG5000L0WW9109mc@P2O
Ld80Wg=209ea@P2NLT<0X7A30080XGI300<0X7E009ic?02MLS/02@2OLd80202QMT<0X7E209md@@2N
Ld00WgA10:1e@P2RMd@0XgQ50`2QMT<30:1e@P80WgA10P2PMD820:5f@`P0XWM4102QMT<01@2PMD80
XGI30:5f@`2RMd@0Y7U60080YGY700<0YW]80:=gB02SMdP01P2SMdP80:9iA@P0XgY60P2TND@20:Ej
A@<0YW]600<0Yga70:YoC02ZOd`00`2YOT/30:QmBP<0Z7m;0P2YP4`30:Z1C@P0ZWm<00D0YW]60:Ml
A`2WO4L0Z7e80:YoBP020:^0B`030:b1C02[P4/0Zh1;00h0ZWm:202ZOd`90:b3C`070:^2CP2YP4`0
Ygi:0:MnBP2XOd/0ZH1<0:Z1C@020:QoA`<0Ygi6102VODD01P2/Pdl0Zh9>0:Z1C@2YP4`0Z7m;0:Mn
BP80YWe9202WOTX20:EkB`040:EkB@2TNdL0Y7]70:=jA080XgY20`2VODT20:ElB0<0Y7]70P2RNDD2
0:5hA0040:1g@`2OMT80WWE109ie@@80WgI20P2NMD4309ed@00309ac?`2LLT00W79000H0W79000D0
W70o09]_?P2KKch0VVhm09U]?00209Q/>`0409M[>P2GK3l0Uf`o09I[?P80UFXm00<0U6Tl09=X>`2C
J3/00`2DJC`209EZ?@<0UV/n0P2CKCh0102BK3d0TF/l091Z>`2?JCX208iX>@<0T6Xk0P2AJc`3099/
?@0308eW>P2>J3/0T6Xm0080TF/n00L0T6Xm08iX>`2=IcX0S6Hg08eW>02@JS/0TV`m0080Tfdn00@0
TV`m095[?02AKCd0TFdm0P2@K3`0102?Jc/0SVXj08iZ>P2>JSX209E[>@80U6Xh0P2CJCL2099X=P@0
TFLe102BJ3H208eW>080S6Hg0`2;ICH00`2:I3D0S6Hg08aV=`0208]U=P0308YT=@29Hc@0R68c0080
R68c0`27HC0208QR<@<0RF<b0`28HSD508MQ=0P0RV@g0`2;IcL208YV=P<0RFDe0P2<HS0208eS<@<0
SV@b00@0SfDc08aV=`2;ICH0RV@e0P28HS<01`2:I3D0RfDf08aV=`2;H3<0S64d08iS=P2@ICP00P2A
IST01@2@ICP0Sf@g08mT=`2@ICP0TVLj00<0U6Tl0P2BIcX00`2@JSd0SfTl08iX>`0208eW>P0308mY
?02AJch0TV`o0080T6Dh00@0TFHi099W>P2CJ3/0U6Tl0P2EJSd5099]=P<0TF`e202FK3X809M]>`06
09Q_>`2IL3`0VG0l09Ya?@2KLSh0W7<o0P2MM4001P2FLC`0Ug8m09Qc?P2IM3l0VWE009]f@@80W7M2
202NM4820:5gA@80XWQ60`2SNDL01@2TNTP0YGa80:ElB02UO4P0Y7]70080XgY60P2RNDD30:AkA`80
YGa80`2VODT30:ElB080YWe90`2WOTX0102XOd/0Z7m90:QoB@2XOdT20:V0BPH0ZX5;0P2[PT`30:b3
C@030:Z1C@2[PTh0[8=?0080[HA@00<0[8=?0:^2CP2ZPDd00`2]Pe420:j4DP<0[hEC0P2`Qe<20:n6
DP040:j5D@2]Q500[HA@0:f4D0@0/8MC102_QU820;:8EP80/HME0P2`QU@20:n5D`80/XQF00@0/HME
0;26E02_QE<0[XAB0P2]Pe420:Z5D@<0ZhIB0`2/Qe<80;27D`080:n6DP2`Qe<0/HQD0;:9E@2aR5@0
/8MC0:j5D@2/Pdl80;27C`P0/HQD00<0/hUG0;67E@2`QU@00`2^Q580102_QE<0/8ID0:j9E02^RE@3
0:n:E@<0/8]F202bRED30;67E@80/XQF0`2cREL40;J<FP@0]H]I0`2dRUP20;>9E`80/XQF0P2aQeD2
0;:7G@030;:7G02bQeX0/XQH0080/XQF00<0/XUE0;F<F02eS5P05P2eS5P40;>:EP@0]8]G00<0/hYF
0;68E02`Qe<00`2^QE400`2_QU80/8MC0:j9E@070:j9E@80[HaF00<0[haF0:n:E@2aRED00P2aR5@0
0`2bQe@0/8MC0;27D`060;27D`030:f8D`2/Qe80ZXE@0080ZHA?00<0ZXE@0:b7DP2]R5<0202`Qe<2
0;68D0040;27D@2`Qe<0[hIB0:n5D`80[XAD202^QE480:f3D@@0[HA>102/Pdd@0:f4D0P0[8=?00@0
Zh9>0:b3C`2^QE40[XEA0P2_QU800`2^QE40[8=?0:^2CP080:b2D080[H5B00@0[H5@0:f2C`2]PTl0
[H9=0P2]PT/80:f4D080[H=A0`2/PU030:^1C`<0ZX1>1@2[PDl80:b3C`P0[85>0P2]Q5030:b3C`<0
Zh9>202/Pdl:0:f4C0040:f4CP2]Q500[HA@0:f3D@80[H=C202]Q5030:b3C`030:^2CP2ZPDd0ZX5=
0080ZH1<00<0ZWm<0:^0C@2/PDh00P2]PTl02`2/PDh0Zh1=0:YoC02[PTh0ZX5=0:V0C02XOd/0ZH1<
0:^2CP2]Q500[XEA0080[XAB00@0[H=A0:b2D02[PDl0ZX1>0P2YOdd80:V0C00;0:^3AP2ZPTL0ZH56
0:QoA`2XOdT0ZH1<0:Z0CP2[PDl0ZHI@0:Z5D02YQ4l00P2[Pdl0102/Pdl0[85>0:j0CP2^P4h80:Uo
C@80ZX5=0P2[PTh00`2/Pdl0[HA@0:j5D@020:j5D@090:f4D02[PTh0ZX5=0:Z1C@2[PTh0[HA@0:j5
D@2[PTh0ZX5=00<0ZH1<00<0Zh9>0:f4D02^QE40202ZPDd30:f1DP<0[X9C0P2_Pe@40:^2CP@0[8=?
00<0ZGi90:YoBP2[P4/00P2/PD`0102[P4/0ZGi90:QmB02WOTX20:QoB`050:V0C02[PTh0[8=?0:b3
C`2]Q500202/PD`20:^1C`80ZX1>00@0ZGm=0:QnC02XOT`0Z7i<0P2XOd/0102YP4`0ZX5=0:^2CP2/
Pdl20:f4D080[85>1P2[P4d80:Z1B`P0ZH1<202XOd/00`2XODP0ZGi90:^0B`020:b1C0030:^0B`2Y
OTT0Z7e800P0Ygi800<0Ygi:0:QoB`2YP4`00`2[PTh01@2YP4`0Z7m;0:MnBP2WOTX0Z7m;0080ZH1<
102ZPDd20:V0B0040:V0BP2YP4`0ZH1<0:UoC@80ZGm?2P2XOd/30:MnBP<0YWe90P2UO4P20:ImB@04
0:MnBP2XOd/0Z7m;0:QoB`<0ZH1<0P2XOd/30:MnBP080:R0@`2XP4D0Z7m70:QoB@2XOT`0Z7i>0:Qm
D02XOE820:MnBP<0YWe90`2UO4P80:MnBP030:9gA02TNDH0Yga90080ZGi;00<0Yga90:AiAP2RMd@0
202VODT20:]mC0<0ZWa;0`2YNdX20:AkA`80YGa80P2VODT20:MnBP80YWe91P2WOTX20:ImA@040:Im
A`2VODT0YWe90:IlBP80YWa<0P2UO4P20:AkA`@0XgY600<0XWQ60:=iA`2UNdT00`2VO4X00`2UNdT0
Y7Y80:9iA@070:9iA@050:1g@`2SNTH0YWe90:ElB02QN4@00P2NMD400`2PMd<0XgY60:AkA`070:Ak
A`040:IlC02UNd/0XWQ80:5gA`80X7I600<0XGM70:9hB02SNDL00P2SNDL00`2TNTP0YG]90:EkB@02
0:IlBP<0YgU80`2VN4L20:EgAP030:ImB@2UO4P0XgY60080XGQ400<0XWU50:=jAP2TNdL0202MN4@0
1P2OMD<0X7I40:1fA02QMdD0XWQ60:=iA`80Y7Y800P0XGQ40:1g@`2MM400Vg8n09ac?`2NMD40X7M3
0:9iA@80WWA20`2OMD<30:1fA0030:5gA@2PMT@0WWA20080W79000<0WG=109id@P2OMD<00P2LMd00
0`2LMd80W7M309afA@0209afA`0409afB@2NM480WWA209id@P80WG=10`2LLT001`2KLCl0Ufdk09E[
>@2GKC/0W79009id@P2LLT000P2HKS`02P2IKcd0Vg4o09ab@02LLT00Vg4o09U_?@2HKS`0Uf`o09Q]
@02JKd8209]`@`0409Y_@P2HKD00Uf`o09Ya?@80Vg8n00D0W7<o09ed@02NMD40WWE109mf@P0809U_
?@0309ab@02KLCl0Vg4o00<0VW0n0P2IKcd309Ia?@80Ug8n102HLcl0402LLT00VW0n09Q^?02GKC/0
UV`j09M]>`2HKS`0VFlm09aaA`2IKT@0UV]009AY?02DJSX0UV`j09U_?@2KLSh209Q^?0<0Ufdk0`2F
K3X809M]>`0;09Q]@02IKT40VVm209]`@`2JKd80VFi109M/?`2FJch0UF/i09I/>P2GKC/00P2IKcd0
0`2GKC/0UV`j09E[>@0809=]?P0309A^@@2CKD00TV`o0080TF/n00<0Tfe009E_@P2FL4<00P2FJch0
102EJSd0U6Tl09AY?02CJ3/2099W>P<0RfXo:oooool002[ooooo0P24GC@208EN=@0408IO=P27H3L0
R64h08QQ>0<0Rf0e0P2<HCH308eR=`@0S64f0P2=HSL208iS>0P0Rf0e00P0SF8g08aQ=P2;H3D0Rf0e
08aQ=P2=HSL0SV<h08mT>@P0SV4g00D0SF4d08iR=@2?HcH0T6@g095U>002091T=`0308mS=P2?I3T0
Sf@i00H0Sf@i0P2AI3X3091S>@<0Sf8h0P2@HcT4095T>P<0TVDk0P2AICP2099V>@80TfLj0P2DJ3/8
09=W>P<0UfLg0P2FISH309EU=@<0UfHk0P2HIc`509UX?@@0UfHk0P2IJ3d309M[>P<0UVXi0P2EJCP2
09M[?P0609Q/?`2IKD00V6`o09IZ?@2DJ3/0TVHi202FJSd409M[>P@0V6`k202IKC`209U/@`0309U/
@P2IKD00VFdn0080VFdl00L0VFhk09eZ>`2KJc/0Vf/k09]]?02IKC`0V6hl0080V70m00@0VFhk09Y_
?02JKc`0VVll0P2KL3d209aa?P0409a`?`2KKch0Vfln09]_?P<0VVhm00<0VFdl09Y^?@2IKC`00P2I
KC`0102JKSd0Vfln09ea@02NLT4;09ea@0<0WW910P2OLd800`2MLD80WW930:1d@`020:5f@`030:1e
@02NLc`0WG8k00T0Wg=200P0XGI30:1e@P2OM440WW=009md@@2PMD80XWM40:=hA@<0XGI30`2PMD82
09md@@<0X7E20P2QMT<30:9gA0@0XGI3102RMd@20:5f@`030:9gA02SN4D0Y7U60080YGY700<0YW]8
0:EiB02UNDP01P2UNDP80:9iA@P0Y7]70`2UNTD20:IkAP<0Yga700@0ZWm<0:UnB`2YOT/0ZGi;0P2X
ODX20:MlB@040:MnBP2XOd/0Z7m;0:QoB`80ZH1<0P2ZPDd80:YoC080Yga700@0Z7e80:UnB@2YOTT0
ZWm:0P2[P4/@0:YoBPP0ZWm<202[PTh00`2/Pdl0ZX5=0:V0C0030:MnBP040:QoB`2YP4`0Z7m90:Qo
B@<0Ygi8102VODL20:Z1C@80ZH1<00@0Z7m;0:MnBP2VODT0YWe9202WOTX20:EkB`060:AjB02TNdL0
XgY60:=jA02SNT80XWU10`2UO4P20:AkA`<0XgY600H0XWU50:5hA02QN4@0X7M309mf@P2NMD4209ed
@0<0WWE10P2MM40309ac?`P0Vg4o202IKC`609EZ?@80U6Tl0`2CJ3/209AY?0<0UFXm0P2BK3d0102A
Jc`0T6Xk08mY>P2?JCX208iX>@0408eW>02>J3T0SVPi08iX>@80SfTj0P2@JS/00`2=IcX0SVPk08mY
?00308mY?00608iX>`2=IcX0S6Hg08eW>02?JCX0T6Xk0`2AJc`00`2@JS/0Sf/k08m[>`0208m[>`80
SVXj0P2=JCT209AZ>0<0TfTg0`2BJ3H01P2>I380SfDc091V=02BJ3H0TfTg09E[>@80UV`j0`2<ISL2
08]U=P<0RV@e2@29Hc@308IP<@80Qf4b0`28HS<508QR=@<0RF<f202:I3L208aX>080RfLg0`2:ISH0
0`29ICD0Rf4_08aR<00208aR<080SF<a0P2>I3800`2;ICH0RV@e08US=00208QR<`0608US=02:I3D0
RfDf08aQ=02=HSD0Sf@g0P2@ICP01P2?I3L0SV<f08eR=@2>HcH0Sf@g095V>@80TfPk00<0TVLj095V
>@2@ICP00P2>J3/308eW>P0308iX>`2@JSd0TF/n0080TFHi00@0TVLj09=X>`2DJC`0U6Tl0P2EJSd0
1@2CKST0TVdh099]>02AK3L0T6/f0080SfXe00<0SVTd09E[>@2EJcT01P2EJcT809M]>`0609M^>P2H
Kc/0V6lk09U`?02JLCd0Vg8n0P2LLcl01P2FLC`0Ug8m09Mb?@2HLch0VG@o09Ye@080VgI1202MLd42
0:1fA080XGM50`2RN4H0102SNDL0Y7]70:AkA`2TNdL30:=jAP80XWU50P2SNTH20:AkA`<0YGa800<0
YWe90:AkA`2TNdL00`2UO4P20:ImB@80Ygi:00@0Ygi80:QoB@2XOdT0Z7m90P2YP4X20:Z1B`80Zh9<
0P2/Pdd20:f4CP80[XE?00<0ZX5=0:^2CP2/Pdl00`2/Pdl00`2[PTh0ZX5=0:b3C`030:f4D080[XEA
1@2_QU830:j5D@80[HA@102_QU840;27D`<0/HME0`2`QU@20:n5D`80/XQF00@0/HME0;26E02_QE<0
[XAB0P2]Pe420:Z5D@<0ZhIB0`2/Qe<80;27D`030:n6DP2`Qe<0/HQD0080/HQD00<0[hIB0:j5D@2]
Q500202`Qe480;68E0090;>9E`2bR5H0/8ID0:n5D`2^Q580[hEC0;26E02aQeD0[XUD00<0[hYE0P2`
ReH20;6<E`P0/XUE0`2aQeD20;:8EP<0/hUG0P2dRUP30;F;F@<0]XaJ102eReT20;B:F0<0/hUG0P2c
R5h00`2cR5d0/hQK0;>9F@020;>9E`030;>:EP2eS5P0]HaH01P0]HaH0`2dReL40;>:EP070;:9E@2`
Qe<0[hIB0:j5D@2_QU80/8MC0;68E0080:j9E@80[HaF00<0[haF0:n:E@2aRED00P2aR5@00`2bQe@0
/8MC0;27D`060;27D`030:f8D`2/Qe80ZhIA0080ZXE@00<0ZhIA0:b7DP2]R5<0202`Qe<20;68D004
0;27D@2`Qe<0[hIB0:n5D`80[XAD202^QE480:f3D@040:f4CP2^QDl0[XE?0:j5C`@0[hI@402]Q508
0:b3C`040:^2CP2/Pdl0[HA@0:f4D080[XEA00<0[HA@0:b3C`2[PTh0202/PU020:f1DP040:f1D02]
PTl0[H9?0:f2C@80[H9;202[PTh20:f4D0<0[8=?0`2[PTh80:^1C`P0[8=?202[P4d50:^2CP030:b3
C`2]Q500[HA@00P0[8=?202]Q4h20:f4C0040:f4CP2]Q500[HA@0:f3D@80[H=C202]Q5030:b3C`80
Zh9>0`2ZPDd00`2ZOd`0Zh1=0:b1CP020:f2C`030:b1CP2[P4d0ZWm<00<0Z7m;00H0ZH1<0:Z1C@2/
Pdl0[XEA0:n6DP2^Q5820:f3D@030:b2D02[PDl0ZX1>0080ZGm=202ZPDd02`2[PdH0ZX970:V1AP2Y
P4P0ZH1:0:V0C02ZP4h0Zh5?0:V6D02ZQE00ZHA?0080Zh=?00@0[8=?0:b1CP2^P4h0[X1>202YOdd0
0`2[PTh0[8=?0:b3C`050:b3C`030:f4D02/Pdl0Zh9>0080ZX5=00<0Zh9>0:b3C`2]Q5000P2[PTh3
0:Z1C@030:^2CP2]Q500[XEA00P0[8=?102^PU430:f1D0030:b0C`2[PTh0Zh9>00H0Zh9>00<0Z7e8
0:UnB@2[P4/00P2/PD`0102[P4/0ZWm:0:UnB@2VODT20:MnBP050:QoB`2YP4`0ZX5=0:Z1C@2[PTh0
202/PD`30:Z1C@<0ZH1<0P2XOd/40:Z1C@@0Zh9>0P2]PTl20:b1CP040:^0C@2ZOd`0ZGi;0:QmBPP0
ZX5;202ZPDd80:V0C0030:UnB@2ZOdX0Zh1;0080[85<00<0Zh1;0:YoBP2YOTT0202WOTP00`2UO4P0
Ygi:0:QoB`030:V0C00;0:QoB`2WOTX0YGa80:AkA`2VODT0ZH1<0:^2CP2/Pdl0Zh9>0:QoB`2WOTX0
0P2YP4P0102XOdT0Z7m;0:QoB`2XOT`20:UoC`X0Z7m;0`2WOTX60:ImB@<0Ygi:0P2XOd/30:V0C080
Z7m;0`2WOTX0102XP4D0Z7m70:QoB@2XOdT20:QnC0040:QnCP2XOE00YGa80:ElB0<0YWe92`2WOTX0
0`2SN4D0YGY70:QmBP020:UnB`030:QmBP2UNTL0XgQ500P0YWe90P2YOD`30:QlB`<0Yg]:0P2TNdL2
0:ElB080YWe92P2WOTX20:ImA@040:ImA`2VODT0YWe90:IlBP80YWa<0P2WOTX20:ImB@<0YGa800T0
Y7]70:AjB02UNdT0YWa:0:MmB`2VO4X0YG]90:=iA`2RN4H0202RNDD01@2NMD40XgY60:MnBP2WOTX0
XgY600<0X7M300<0XGQ40:=jAP2SNTH01P2SNTH0202TNTP0XgU70:9hAP2QMdD0X7I40:5gA@2SNDL0
Y7Y80P2SNDL30:AjB0<0YG]9102TN4L30:EiB0060:IjB@2UO4P0YGa80:=jAP2RNDD0XGQ40P2RNDD0
1P2SNTH0WWU509ehA02MN4@0W7M309]f@P80VWE100L0VGA00:1fA02QMdD0XGM50:9hAP2SNDL0Y7Y8
0080YG]9102QN4@40:1g@`80WWA20`2OMD<30:1fA0030:5gA@2PMT@0WWA20080W79000<0WG=109id
@P2OMD<00P2LMd000`2LMd80W7M309afA@0209afA`0309afB@2OMD<0WWA20080WWA20P2MLd4309ab
@00:09Y`?P2HKS`0VFlm09ec@@2NM480W79009Y`?P2IKcd0VW0n09]a?`80W79000H0Vg4o09Y`?P2I
Kcd0V6e009U^@@2JKd8209]`@`0309Y_@P2IKT40V6e000P0W7<o202JL3h509]a?`0409Y`?P2IKcd0
VFlm09Qc?`<0Ug8n1@2FLCd01@2JL3h0VFlm09Q^?02GKC/0UV`j0080Ufdk00T0V6hl09Y_A@2HKD<0
UV]009AY?02DJSX0UV`j09U_?@2JLCd00P2FK3X309M]>`<0V6hl202GKC/02`2HKD00VFi109Y_@P2J
Kd80VFi109Q]@02GK3l0UV/n09E[>@2FK3X0V6hl0080VFlm00<0V6hl09I/>P2EJcT0202BK3d00`2B
K3l0TF/n091Z?@02091Z?@03099/?`2CKD00U6i100P0TfPk0`2=JT0[ooooo`00:_ooool01P22Fc80
Pe`c08AM=025GSD0QUlf08QQ>080RF8i0`2<HCH208eR=`<0SV<h0`2;H3D508aQ=PP0Rf0e00P0SV<h
08eR=`2;H3D0REhc08YO=02<HCH0Sf@i095V>`P0Sf8h0P2=HC@208iR=@@0Sf<f2P2@HcT608mR>080
T6<i102AI3X3099U>`80TFDh0P2BIST209=W>P80U6Pk202BIST409IX=`@0UFLf202HIc`809MX?0<0
Uf/j0`2FJST209EY>00309IZ?@2GJch0V6`o0080V6`o00<0UVXm09AX>`2CIcX0202FJSd01@2EJCP0
UVXi09IZ>@2GJcX0V6`k0080VFdl00<0VVhm09U]?02IKC`01P2IKC`209U/@`0309U/@P2IKD00VFdn
0080VFdl00L0VFhk09eZ>`2KJc/0Vf/k09]]?02IKC`0V6hl0080V70m0`2JKc`209]`?@<0W74n202K
Kch209Q/>`0609U]?02JKSd0Vfln09ea@02NLT40Wg=22P2MLD0609ib@@0309ea@P2NLT<0X7A30080
XGI300<0X7E009ic?02MLS/02@2OLd80202QMT<0X7E209md@@2NLd00WgA10:1e@P2RMd@0XgQ50`2Q
MT<30:1e@P@0WgA10P2PMD820:5f@`80XWM4102QMT<60:9gA080XgQ500@0Y7U60:EjA`2UNTL0YGY7
202VNdP80:=jAPP0Y7]70P2UNTD30:IkAP<0Yga70`2YOT/20:QmBP<0Yga90P2WOTX30:QoB`<0ZH1<
202YOT/00`2WO4L0Z7e80:QmB0020:UnB@80ZWm:00<0Zh1;0:UnB@2ZOdX00`2ZOdX30:^0B`P0ZWm:
202ZOd`90:^2CP070:Z1C@2XOd/0Ygi:0:ImB@2WOTX0Z7m;0:V0C0020:QoB`<0Ygi:102VODT20:V0
C080Z7m;00@0Ygi:0:ImB@2VODT0YWe9202WOTX20:AjBP040:AjB02SNTH0XgY60:=jA080XWU100@0
Y7]70:=jAP2SNTH0XgY60P2RNDD40:5hA0040:1g@`2OMT80WWE109ed@080W7<o0`2MM40209ac?`<0
Vg8n202JL3h309M[>P80V6`k0`2IKC`209=X>`<0U6Tl0`2EJSd2099W>P<0TfPk0`2DJC`00`2AJc`0
T6Xk091Z>`0208mY>P80SVPi00@0SFLh08eT=P2=I3H0SF@f0P2>ICL308mV>00308aV>@2=IcX0SFLj
00@0SFLj00D0S6Hi08aV=`2<ISL0SFLh08iX>@0408mY>PP0SFTi202BJ3H01@2@IS@0TFLe095W=@2B
J3H0TfTg0080U6Xh00@0UF/i08]U=P2;ICH0RfDf0P2:I3D308US=0<0Qf4b0`28HS<308US=080QElb
0`26H3<308MQ=080R68e1029HcH208YT=`P0RF<f0P2<J3P308]W=`<0RVHf102:HS4208]S<P80S6@c
0`29Hc@208QR<`<0RF<d00<0SF8e08iS=P2?I3L00P2@ICP02`2>HcH0S64d08]P<`2=HSD0SV<f091U
>02AIST0TVLj095V>@2@ICP0Sf@g00@0S6Hi0P2=IcX208iX>`80TFHi0P2BIcX02P2CJ3/0U6Tl09AY
?02DJC`0Tfhj099]>@2AK3P0T6/g08mZ=P2=J3@208aW<`P0U6Xh202FK3X209I]>@0409M^>P2HKc/0
VG0l09Ya?@80Vg8n0P2FLC`209Mb?@0409Qc?P2IM3l0VG@o09Ud?`P0W7900`2OMD<20:1fA0<0XGM5
0P2SNTH80:9iA@80XgY60`2TNdL00`2UO4P0Y7]70:AkA`030:AkA`80YGa80P2VODT20:MnB0<0Z7m9
0`2YP4X0102/Pdd0[HA>0:f4CP2]Q4h20:j5C`80[hI@00<0ZX5=0:^2CP2[PTh0102[PTh00`2ZPDd0
[8==0:b3C@030:f4CP<0[XE?0P2_QU860:j5D@@0[hIB102`Qe<60;26E080[hEC0P2bR5H0102aQeD0
/8ID0:n5D`2^Q5820:f3D@80ZXEA0`2[QU830:b7D`d0/8MC00<0[hIB0:j5D@2^QE40202`Qe<80;68
E0080;B:F02bR5H0/8ID0:n5D`2^Q580[hEC0;26E02aQeD30:n:E@80/8]F0`2aS5L80;:9E@<0/HME
0P2bR5H30;>9E`060;:8EP2cREL0/hUG0;B:F02eReT0]XaJ0P2gSE/40;J<FP80]H]I0`2dRUP20;>8
GP030;>8G@2cR5/0/hUI0080/hUG00<0/hYF0;F<F02eS5P05P2eS5P01P2gSUX0]XeI0;J=F@2eS5P0
]8]G0;>:EP80/XUE00P0]8]G0;:9E@2`Qe<0[hIB0:j5D@2_QU80/8MC0;68E0P0[hYF0P2]S5H00`2_
S5H0[hYE0;69E@020;68E0030;:7E02aR5@0/HQD00H0/HQD00<0[8MB0:^6D@2[QU40102[QU400`2/
Qe80/8MC0;27D`060;27D`80/HQ@00@0/8MA0;27D`2_QU80[hEC0P2^Q5@80:j5D@P0[H=A0P2^QDl2
0:n6D0040;27D@2aR580/XUC0;:9DaP0[HA@2@2/Pdl80:b2D080[H5B00@0[H5@0:f2C`2]PTl0[H9=
0P2]PT/80:Z1C@80[HA>0`2/Pdd30:^2C0@0[89@102[PDl80:b3C`P0Zh1=00P0Zh9>0:Z1C@2ZPDd0
ZX5=0:^2CP2/Pdl0[XEA0:n6DQ00[HA@0P2]Q4`0102]Q4h0[HA@0:f4D02]Pe420:f3D`P0[HA@102/
Pdl40:^2CP030:YoC02[P4d0[85>0080[H9?00/0[85>0:^0C@2ZOd`0YWe90:MnBP2XOd/0ZH1<0:^2
CP2]Q500[hIB0;27D`020:f3D@030:b2D02[PDl0ZX1>0080ZGm=00<0Z7i<0:^2CP2[PTh01P2[PTh0
2`2[PdH0ZX970:Z2A`2ZPDT0ZX5;0:Z1C@2ZP4h0Zh5?0:V6D02ZQE00ZHA?0080Zh=?00@0[8=?0:b1
CP2^P4h0[X1>202YOdd20:f4D0<0[8=?0`2[PTh30:b3C`80Zh9>0`2/Pdl50:^2CP030:b3C`2]Q500
[HA@00P0[HA@0P2_Q540102^Pe00[H9?0:f2C`2/PDh20:^0C@030:b3C`2[PTh0Zh9>0080Zh9>0`2Z
PDd00`2XODP0ZGi90:^0B`020:b1C0030:^0B`2ZOdX0ZGi90080YWe90P2WOTX20:QoB`80ZH1<202/
PD`20:Z1B`H0ZH1:0`2/Pdl00`2[PTh0ZX5=0:V0C0020:V0C0@0[H9?00@0Zh1=0:UnB`2WO4T0YW]8
202ZPD/80:Z1C@P0ZH1<0`2ZOdX20:^0B`<0ZWm:202XOdT00`2TNdL0YGa80:MnBP030:QoB`060:Mn
BP2UO4P0Y7]70:9iA@2UO4P0ZX5=0P2]Q5001P2[PTh0Ygi:0:ElB02ZPDT0ZH180:QoB@80Ygi:00<0
Z7i<0:UoC`2ZP5002P2XOd/30:MnBPD0YWe91P2WOTX30:V0C080Z7m;0`2WOTX30:QoB@80Z7m;0`2X
OT`01@2TNdL0YGa80:ElB02VODT0Ygi:0080Z7m;00<0ZH1<0:MnBP2WOTX01P2WOTX00`2UNTL0YW]8
0:QmBP020:YoC0030:QmBP2VNdP0YGY700P0Ygi:0P2XOT`30:MmB`<0YWa:0P2TNdL20:ElB080YWe9
0P2WOTX00`2XOd/0Ygi:0:MnBP020:MnBP<0YWe90P2VODD0102VODL0YWe90:ImB@2VO4X20:IlC0<0
Z7m;0P2WOTX30:ImB@80YWa:0`2WOD/0102UNdT0XgU70:5gA@2TNdL40:=jAP<0XWU500D0WWE10:=j
AP2XOd/0Z7m;0:AkA`030:1g@`040:5hA02SNTH0XgY60:=jAP@0XWU500<0XGQ40:AkA`2SNTH00`2Q
N4@00`2SNTH0Y7]70:ImB@060:AjB080YG]90P2RN4H0102SNDL0Y7Y80:AjB02UNdT20:IlBP040:El
B02TNdL0Y7]70:=jAP@0XWU500P0WWU509ehA02LMd<0VgI209Ye@@2IM400V7<o09Mb?P80WWA200@0
WgE30:1fA02QMdD0XWQ60P2SNDL0202PMd<0XWU50:AkA`2UO4P0Y7]70:=jAP2PMd<0WgI20P2NM483
09me@`<0X7I400<0XGM50:1fA02NM4800P2LLT000`2MLd40WWA209me@`0209]f?`0309]f@@2KMT80
VgE40080VgE600<0VgE809me@`2OMD<00`2NM48309ec@@80W7900P2KLCl309ec@@0409ab@02JL3h0
VW0n09Y`?P80Vg4o0`2JL3h809Y`@080WGA00`2LLcl309]b?PT0VW0n0P2KLCl01P2LLT00Vg4o09Y`
?P2IKcd0V6hl09Ud@080V7<o00<0Ug8n09Ia?@2EL3`00`2DKc/0102IKcd0V6hl09M]>`2GKC/409I/
>P0909Q]@`2GK480UFXo09AY?02EJc/0UV`j09Q^?02JLCd0UF/i0080UV`j00D0Ufdk09Q^?02IKcd0
VFlm09Y`?P0809Q^?0@0VFi100L0V6e009M/?`2GK3l0UV/n09I/>P2GKC/0V6hl0080VFlm00<0V6hl
09M]>`2FK3X0202@JS/5091Z?@03095[?P2BK3l0TV`o00<0TFPj0P2BJC/309=Z?0<0T6/o:oooool0
02[ooooo00H0PU/b08=L<`24GC@0QEhe08IO=P28HCP208UR>@<0S64f0P2=HSL308iS>0H0Rf0e0P2:
Gc@808aQ=P0808iS>02=HSL0Rf0e08UN<`2:Gc@0S64f08mT>@2AIS/808mR>0<0SF4d0P2>HSD208mS
=P03091T=`2BHcT0TV<i00H0TV<i0`2?HSP7091S>@@0TF@j0`2BIC/2095U>080TVHi0P2CIcX209AX
>`P0TVHi202DJ3L809QW?0P0UFTl0`2GJcX309IZ>@80UFTh00<0UFTl09IZ?@2GJch00P2HK3l00`2G
Jch0UFTl09AX>`0809M[?P0509EY>02FJST0UVXi09M[>P2HK3/00P2IKC`00`2JKSd0VFdl09U]?006
09U]?080VFa300<0VFa209U]@02IKCh00P2IKC`01`2IKS/0WFXk09][>`2KJc/0Vfdl09U]?02HKS`0
0P2HL3d209Y_?080Vg0m0P2LLCh209eb?`@0Vfln102LL3l209Q/>`0309Y^?@2KKch0WG500080WW91
00<0Wg=209ea@02MLD001P2MLD0609ib@@80WG5000<0WG5209ib@`2PM4<00P2QMT<00`2PMD00WW<l
09eb>`0909mc@P080:5f@`2PMD80WgA109ic@02OM440X7E20:9gA02SN4D30:5f@`<0X7E21@2OM442
0:1e@P<0XGI30P2PMD820:5f@`80XWM40`2SN4D40:AiAP<0YGY7202VNdP80:=jAPP0YGa80`2VNdH3
0:MlA`80Z7e80P2YOT/20:QmBP80Yga90P2VNdP30:MnBP<0Z7m;0P2YP4`80:UnB`80Z7e8102YOTT2
0:YoBP<0ZGi900<0ZWm:0:^0B`2[P4/00P2/PD`80:YoBPP0ZWm<202ZPDd00`2[PTh0ZX5=0:QoB`03
0:ImB@040:MnBP2XOd/0Z7m;0:QoB`<0Ygi:102VODT30:MnBP@0YWe92@2UO4P20:AjBP040:=iA`2S
NTH0XgY60:9i@`80XWU10`2RNDD20:5hA0D0X7M300@0WgI209ie@@2MM400W7<o0P2KLSh309ac?`80
Vg8n0`2JLCd809Q^?0<0UVXi0P2GJcX309Q/>`<0TfPk0`2DJC`209EZ?@80TFHi0P2BIcX409=X>`80
SfTj102>J3T208eW>0@0SF8e0P2>HcH208mT=`0308aV>@2;ICP0RfDh00@0RfDh00<0S6Hi08aV=`2<
ISL00`2<ISL208eW>00308iX>@2;IcL0RfLg0080RfLg102<J3P8095W=@80U6Xh00<0TfTg099X=P2A
IcD00P2@IS@0102?IC<0RV@e08YT=@2:I3D208US=0<0R68c0P25Gc0308IP<@@0Qf4b0P24GC8208EN
<`@0QUld0P27HC@208QR=@80RF<f0P2:I3L808QR=@<0RfLg0P2:ISH308UU=@<0Qf4b0`28HS<208US
=00308MQ<P28HS<0R68c00@0R68c00P0Qf4b08eR=@2>HcH0Sf@g091U>02?I3L0SV<f08aQ=080Rf0c
00<0SF8e08iS=P2@ICP00P2@ICP0102?I3L0SV<f08YT=`2:I3L208]U>0@0S6Hi00<0T6Dh095V>@2A
IST00P2AIST3099W>P80TF/j00H0T6Xi08iX=`2=IcH0S6He08]U=02:I3<809AZ>0P0UF/i0P2EK3P0
102FKCT0Ufhj09Q_>`2HKc/209U`?0<0UW4l102GLSd00`2HLch0Vg4o09]a?`0609]a?`0409ec@@2N
M480WWA209id@P80WgE30P2PMT@50:5hA0<0XWU500@0XGQ40:9iA@2RNDD0XWU50P2SNTH20:AkA`@0
XgY60`2TNdL20:ElB0<0Ygi80`2XOdT20:V0BP040:b3C@2]Q4h0[HA>0:f4CP80[XE?0P2_QU000`2[
PTh0ZX5=0:Z1C@040:Z1C@040:^2CP2/Pd/0[8=;0:b3B`<0[HA<0P2^QDd60:j5D@80[hIB0P2^QE42
0:n6DP80/8MC0P2aR5@60:n5D`80/8ID0P2bR5H0102aQeD0/8ID0:n5D`2^Q5820:f3D@80ZXEA0`2[
QU830:b7D`P0/8MC0P2aR5@00`2`Qe<0[hIB0:n6DP030:n6DPP0/8MC202aR5@00`2dRUP0/hUG0;67
E@020:n5D`030;26E02aQeD0/XQF0080[hYE0P2`ReH20;6<E`80/XeH202bRED30;67E@80/XQF0`2c
REL20;:8EP030;>9E`2dRUP0]H]I0080]XaJ00<0]heK0;J<FP2fS5X00P2fS5X20;F;F@<0]8YH0P2d
REl00`2dREh0]8UL0;B:FP020;B:F0030;B;E`2eS5P0]HaH01H0]HaH0P2gSUX00`2fSET0]HaH0;B;
E`020;>:EP040;:9E@2dReL0/hYF0;68E080[hIB00<0/8MC0;68E02bRED0202_RUH20:f<EP030:n<
EP2_RUD0/HUE0080/HQD00<0/XMD0;68E02aR5@01P2aR5@30:^6D@80[8MB0`2[QU480;27D`80/HQ@
00@0/8MA0;27D`2_QU80[hEC0P2^Q5@80:j5D@P0[H=A0P2^QDl00`2_QU00/8MA0;68DP020;:9D`03
0;>:E02]Q500[HA@01H0[HA@0P2/Pdl50:^2CP80[8=?202/PU020:f1DP040:f1D02]PTl0[H9?0:f2
C@80[H9;202ZPDd20:f4C0<0[8=;0`2[PTX00`2^Q580[H=A0:f3D@020:b2D080Zh5?00<0ZX1>0:b3
C`2/Pdl01P2/Pdl80:^0C@080:b3C`2[PTh0ZX5=0:V0C02ZPDd0[8=?0:n6DP2`Qe<@0:f4D080[HA<
00@0[HA>0:f4D02]Q500[H=A0P2]Pe<80:f4D0P0[8=?00<0ZWm<0:^0C@2/PDh00P2]PTl0302/PDh0
Zh1=0:YoC02UO4P0YWe90:QoB`2ZPDd0[8=?0:f4D02^QE40[hIB0:f3D@80[89@00<0Zh5?0:Z0CP2Y
Odd00P2XOT`80:^2CP0;0:Z2A@2[PdP0Zh=80:^2BP2[PT`0Zh9>0:^1C`2ZP4h0ZHI@0:Z5D02YQ4l0
0P2[Pdl0102/Pdl0[85>0:j0CP2^P4h80:UoC@80[HA@0`2/Pdl40:^2CPH0[8=?00D0Zh9>0:Z1C@2[
PTh0Zh9>0:b3C`040:f4D0P0[XEA00D0[hAA0:j3D02^Pe00[H9?0:b1CP020:^0C@030:YoC02/Pdl0
[8=?0080Zh9>00L0ZX5=0:V0C02YP4`0ZH1<0:MlA`2XODP0ZWm:00<0[85<00<0Zh1;0:YoBP2WOTX0
0`2WOTX40:QoB`P0[85<1P2YP4P20:Z1B@80[HA@00@0[8=?0:^2CP2ZPDd0ZH1<0P2XOd/0202[P4d0
[85>0:f2C`2]PTl0[85>0:UnB`2VNdP0Y7U6202YP4X80:^2CPP0ZX5=00<0Zh1;0:YoBP2ZOdX0102Z
OdX00`2[P4/0Z7m90:QoB@060:QoB@030:AkA`2UO4P0Ygi:00<0Z7m;00h0Ygi:0:ElB02TNdL0XWU5
0:ElB02YP4`0[8=?0:f4D02ZPDd0Ygi:0:AkA`2ZPDT0ZH180:MnB080YWe900<0Yge;0:UoC`2ZP500
2P2XOd/30:MnBP<0YWe91P2WOTX20:ImB@<0ZH1<0P2XOd/30:MnBP<0Z7i<0P2XOd/30:QoB@80YGa8
00@0YWe90:MnBP2WOTX0Z7m;0P2YP4`80:MnBP030:MlB@2XODX0ZGi;0080ZWm<00<0ZGi;0:QmBP2W
O4T0202WOTX20:MoC0<0YWi;0`2UODX20:AkA`80YGa80P2VODT20:MnBP<0Z7m;00<0Ygi:0:ImB@2V
ODT00P2UO4P20:ImA@040:ImA`2VODT0YWe90:IlBP80YWa<0P2YP4`20:QoB`<0Ygi:00<0YWe90:Il
BP2WOD/00P2XOT`0102WOD/0YG]90:=iA`2RN4H20:ElB080Y7]700H0XgY60:9iA@2RNDD0XWU509mf
@P2TNdL20:QoB`050:AkA`2PMd<0X7M30:5hA02RNDD00`2TNdL00`2SNTH0XWU50:9iA@020:5hA008
0:AkA`2SNTH0XWU50:5hA02RNDD0XgY60:ElB02VODT20:EkB@H0Y7Y800D0XGU60:9jA`2RNTL0Xg]8
0:AlB@020:EmBP030:InB`2TNdL0Y7]70080Y7]700`0XgY60:9iA@2RNDD0XGQ409iiA@2MN4@0W7M3
09]f@P2JMD40VGA009Qc?`2GLSh209]a?`80W79000L0WG=109id@P2OMD<0WgE30:5hA02RNDD0YGa8
0080YWe900<0XgY60:1g@`2MM4000P2NM48309me@`<0X7I400<0XGM50:1fA02NM4800P2LLT000`2M
Ld40WWA209me@`0209]f?`0309]f@@2KMT80VgE40080VgE600@0VgE809me@`2OMD<0WgE30`2NM482
09ec@@0409ab@02MLd40WG=109ec@@80Vg4o0P2LLT000`2KLCl0VW0n09Y`?P0409Y`?P<0Vg4o102J
L3h209]a?`<0W7<o0`2KLSh209Ya?@P0Vg4o00P0VFlm09Y`?P2LLT00WG=109ab@02JL3h0V6hl09M]
>`80V7<o00<0Ug8n09Ia?@2EL3`00`2DKc/00`2CKSX0Ufdk09M]>`0209M]>`80UV`j00X0UF/i09AZ
>02FJd40UFY009EZ?`2EJSd0UF/k09M]>`2HKS`0VG0l0P2FK3X0102GKC/0V6hl09Q^?02IKcd209Y`
?PP0V6hl0P2IKT400`2HKD00Uf`o09M/?`0309M/?`0309I/>P2GKC/0VFlm0080VW0n00<0VFlm09M]
>`2FK3X0202@JS/208mY?003091Z?@2AJch0TF/n00<0TF/n0`2@JS/2095[?0<0TV`m0`2@Jch[oooo
o`00:_ooool208AM=080QEhe00@0QUlf08MP=`28HCP0R64h0`2;H3D208aQ=P<0SF8g0P2;H3D308YO
=0<0REhc202<HCH0202=HSL0S64f08]P=@2;H3D0S64f08eR=`2>HcP0Sf@i202?HSP208mS=P<0SV8e
00<0Sf<f095U>02BIST0202CHST2091S>@<0TF@j0`2BIC/2091S>@@0TF@j0`2BIC/2095U>080TVHi
0P2CIcX209AX>`P0TfLj00@0TVPf09=Y=`2CJCL0TfTg0`2DJSP0102EJcT0VFPm09UX?@2IJ3d209QW
?0<0UfHk0P2CJ3/409EZ?@80TfPk0`2GJcX309IZ>@80UFTh00<0UFTl09IZ?@2GJch00P2HK3l00`2G
Jch0UFTl09AX>`0809M[?P@0Uf/j102HK3/809U]?080V6]200<0V6]109Q/?`2HK3d00P2HK3/01`2H
KCX0WFXk09][>`2KJc/0Vfdl09U]?02HKS`00P2HL3d309]`?@80W74n0`2MLSl309]_?P80W70o0`2M
LD00102IKC`0VVhm09]_?P2MLD0209ib@@X0WG500P2OLd8309ib@@<0WG5000<0WG5209ib@`2PM4<0
0P2QMT<00`2PMD00WW<l09eb>`0909mc@P080:5f@`2PMD80WgA109ic@02OM440X7E20:9gA02SN4D3
0:5f@`<0X7E20P2OM440102NLd00WgA109md@@2OM4420:1e@P80XGI300D0WgA10:1e@P2PMD80XGI3
0:9gA0020:=hA@030:AiAP2UNTL0YGY700H0YGY7202UNTD80:AkA`P0YGa80`2VNdH20:MlA`<0Z7e8
0`2XODX20:MlB@<0YW]80P2VODT20:MnBP<0Z7m;00<0ZH1<0:QmBP2XODX01P2XODX80:UnB@80Z7e8
00<0ZGi90:YoBP2[P4/00P2/PD`00`2]PTd0ZWm:0:YoBP060:YoBPP0ZWm<2@2ZPDd01`2YP4`0Ygi:
0:ImB@2UO4P0YWe90:MnBP2XOd/00P2XOT`30:MmB`@0YWa:00<0YWe90:ElB02UO4P01@2UO4P80:=j
AP060:AjBP2SNDT0XgU70:=jAP2RNDD0XWU30P2QN4020:5hA080X7M30`2OMT801P2NMD40WgI209mf
@P2NMD40WGA009ac?`80Vg8n00@0VW4m09]b?P2KLSh0Vg8n0P2JLCd309U`?0P0Ufdk202FJST209AY
?0H0TfPk0P2@ICP2095V>@<0TVLj00<0TfPk08eW>02=IcP01P2=IcP208eQ=080SV8e0`2?HcH00`2@
I3L0RfDh08YT=`0408US=P0508YT=`2;ICP0S6Hg08aV=`2;ICH00P2:I3D00`2;ICH0S6Hg08eW>002
08UU=@<0RVHf0`2;IcL208mU<`<0T6Hd0`2AIcD01P2DJSP0TfTg099X=P2@IS@0SfDc08eS<@80S68`
0`29Hc@208QR<`<0Qf4b2@25Gc0208=L<`80Q5dd0`25GSD01@26GcH0QElb08EO<P26H3<0Qf4d0080
R68e0P29HcH808MQ=0<0RFDe0P28I3@308MS<`<0QF0c0P26HC@308MR=@80QV0a00@0Qf4b08QR<`28
HS<0Qf4b0P26H3400`2;H3<0S64d08iS=P0208mT=`0>08iS=P2=HSD0S64d08YO<P2;H3<0SF8e08iS
=P2?I3L0SV<f08eR=@2<HC@0Qf4d08QR=@2:I3L308]U>080RV@g202?I3L01@2?JCX0SVPi08iX>@2=
IcP0S6Hg0080RfDf00<0RV@e09=Y=`2CJCL01P2CJCL809AZ>00609=Z=P2DJcL0U6/g09E/>02FKCT0
Ufhj0P2HKc/809Ia?0P0VW0n0`2LLT0209ec@@<0WWA20P2OMT820:1g@`@0XGQ400@0X7M30:5hA02Q
N4@0XGQ40P2RNDD20:=jAP@0XWU50P2SNTH30:AkA`80YWe70P2WOTP30:QoB@030:V0BP2[PT`0Zh9<
0080[8==0P2]Q4h20:j5C`030:^2CP2ZPDd0ZH1<00<0ZH1<00@0ZX5=0:^2CP2[PdP0Zh=80P2/Q4T3
0:f5BP030:j6B`2]Q500[HA@00<0[XEA0`2_QU801@2]Q500[XEA0:j5D@2_QU80/8MC0080/HQD00@0
/XUE0:j4DP2^Q580[XAB0`2_QE<20;26E080/XQF00@0/HME0;26E02_QE<0[XAB0P2]Pe420:Z5D@<0
ZhIB0`2/Qe<80;27D`030;:9E@2aR5@0/8MC00<0[XEA00<0[hIB0;27D`2`QU@01`2`QU@80;68E008
0;B:F02cREL0/HME0;26E02_QE<0/8ID0;67E@2bR5H30;2;EP80/HaG0`2bSEP80;:9E@<0/HME0P2b
R5H60;>9E`<0]8YH1P2eReT20;B:F0<0/hUG0P2dREl00`2dREh0]8UL0;B:FP020;B:F0030;B;E`2e
S5P0]HaH01H0]HaH0`2fSET30;F<F0<0]8]G00L0/hYF0;68E02`Qe<0[hIB0;27D`2aR5@0/XUE00P0
/8]G0P2]S5H00`2_S5H0[hYE0;69E@020;68E0030;:7E02aR5@0/HQD00H0/HQD00<0ZXE@0:^6D@2/
Qe800P2]R5<00`2/Qe80ZhIA0:Z5D0080;27D`80/HQ@00@0/8MA0;27D`2_QU80[hEC0P2^Q5@80:j5
D@P0[H=A102_QU030;27D@030;68DP2]Q500[HA@00h0[HA@202^QE420:b3C`80Zh9>0P2ZPDd00`2[
PTh0[8=?0:b3C`080:b2D080[H5B00@0[H5@0:f2C`2]PTl0[H9=0P2]PT/80:^2CP80[HE:0`2/Q4T3
0:^3B0060:n5D`2^Q580[XAB0:f3D@2/PU00Zh5?0P2ZP4h80:b3C`P0[H9?00P0[XEA0:b3C`2ZPDd0
Z7m;0:V0C02[PTh0[XEA0;27D`P0[XEA202]Pe420:f4C0040:f4CP2]Q500[HA@0:f3D@80[H=C202]
Q500102[PTh0[8=?0:b3C`2/Pdl30:f4D0040:j5D@2ZOd`0Zh1=0:b1CP80[H9?00P0[85>0:^0C@2Z
Od`0YWe90:MnBP2YP4`0Zh9>0:b3C`<0[HA@0P2/PU000`2[PDl0ZX1>0:UoC@020:QnC0030:MmB`2Z
PDd0ZX5=00H0ZX5=00/0ZX950:^3B02/Q4T0[8=;0:b3C@2/Pdl0Zh5?0:Z0CP2YQU00ZXE@0:V4C`02
0:^3C`040:b3C`2/PDh0[X1>0:j0CPP0ZGm=00<0Zh9>0:b3C`2/Pdl01@2/Pdl00`2ZPDd0Zh9>0:b3
C`020:f4D0070:b3C`2[PTh0ZX5=0:Z1C@2[PTh0[8=?0:f4D0020:j5D@030:f4D02/Pdl0[HA@00L0
[HA@0`2]PTd30:b1C080Zh1;0P2/Pdl0102[PTh0ZX5=0:V0C02YP4`20:QoB`060:IkAP2XODP0ZWm:
0:b1C02]PTd0[85<0P2[P4/40:QoB`@0ZH1<202/PD`20:R0A@<0ZH560`2ZPTL01@2]Q500[8=?0:b3
C`2[PTh0ZX5=0080ZH1<00T0Z7m;0:UnB`2ZOd`0[85>0:f2C`2/PDh0ZWm<0:IkB02TNDH0202YP4X8
0:^2CPP0ZX5=00<0[85<0:^0B`2ZOdX00P2YOTT00`2ZOdX0Zh1;0:b1C0080:V0BP030:ElB02WOTX0
Z7m;00<0ZH1<00h0Z7m;0:MnBP2UO4P0XgY60:ElB02XOd/0ZX5=0:^2CP2YP4`0Ygi:0:ImB@2ZPDT0
ZH180:ImA`80Y7]700<0YWa:0:UoC`2ZP5002P2XOd/30:MnBP<0YWe90P2XOd/30:MnBP<0YWe90`2Y
P4`20:QoB`<0Ygi:00@0Z7e@0:QnCP2XOT`0Z7i<0P2XOdT00`2XOdL0Z8150:ImB@030:MnBP@0Z7m;
202WOTX30:UnB`80ZWm<0`2YOT/80:MnBP80YH1<0`2TOd/30:=nBP80Y7]70P2UO4P20:ImB@80Ygi:
0P2YP4`00`2XOd/0Ygi:0:ImB@020:ElB0040:AkA`2VODD0YWe50:ImA`80YWe900<0YWa:0:IlC02V
O4`00`2XOd/20:MnBP<0YWe900<0YG]90:IlBP2WOD/00P2XOT`00`2VO4X0YG]90:=iA`020:ImB@03
0:ElB02TNdL0XgY60080XWU500H0XGQ40:9iA@2UO4P0Ygi:0:ImB@2RNDD20:1g@`040:9iA@2UO4P0
YWe90:ImB@80YGa800L0Y7]70:=jAP2RNDD0XWU50:ImA`2UO4H0XgY40080XWU300<0XgY40:AkA@2U
O4H00`2UNdT30:AjB080XgU70`2QO4P30:9mB@80Xgi:00H0XgY60:AkA`2TNdL0YGa80:AkA`2SNTH2
0:5hA00509iiA@2MN4@0WGQ409ag@`2KMT800P2JMD401`2IM400VW0n09]a?`2KLCl0W79009ec@@2N
M4800P2OMD<0202RNDD0XgY60:AkA`2UO4P0Y7]70:9iA@2OMT80WGA00P2NM48309me@`<0X7I400<0
XGM50:1fA02NM4800P2LLT000`2MLd40WWA209me@`0209Ye?P0309Ye@02JMD40VWA30080VWA500<0
VWA70:1fA02PMT@00P2OMD<309id@P0809ec@@2JL3h0W79009id@P2MLd40VFlm09Q^?02JL3h209ab
@00909]a?`2JL3h0VFlm09U_?@2JL3h0Vg4o09ab@02LLcl0Vg8n00@0VW4m00<0Vg8n09ac?`2KLSh0
1`2KLSh809]a?`0809Q^?02JL3h0W79009id@P2MLd40Vg4o09Q^?02FK3X409Ia?@@0UG0l00T0U6lk
09E[>@2FK3X0UV`j09M]>`2FK3X0UF/i09AZ>02CJCL00P2DJCl01`2DJCh0UFXm09I/?02GKC/0V6hl
09U`?02GKC/00`2HKS`409U_?@P0V6hl00<0VVm209U^@@2GK3l00`2FJch209M/?`0309M]>`2HKS`0
VFlm0080VW0n00<0VFlm09Q^?02GKC/0202BK3d00`2?JC`0T6Xm095[?P0309=]@003099/?`2AJch0
TVhn00L0TVhn0`2BK3d[ooooo`00:_ooool00`25GSD0QUlf08IO=P0508IO=P80REhc0P2:Gc@208]P
=@80S64f0P2;H3D208YO=00408UN<`28GC80R5db08QM<PP0S64f00@0RUld08]P=@2<HCH0SF8g0P2>
HcP00`2=HSL0S64f091S>@07091S>@80TFDh0`2?HcH00`2AICP0TfLj09AX>`0809=R>@03095T>P2B
IC/0TVDk0080TfHl0P2DIcd00`2EJ3h0T6<i091S>@04095T>P<0TVDk0P2AICP2099V>@80TfLj0P2D
J3/809EY?080TFTf0P2BJSL01@2CJcP0U6`i09A/>@2DK3T0VVTn0080VFPm0P2HIc`209MV>`0409IU
>P2AJ3X0TVTk09A[?@80UF`n00<0U6/m099Y>`2AJ3X00`2GJcX309IZ>@80UFTh00<0U6Pk09EY?02G
Jch00P2HK3l00`2GJch0UVXm09EY?00809M[?P@0V6`k102GJcX809U]?080V6]200<0V6]109Q/?`2H
K3d00P2HK3/01`2HKCX0WFXk09][>`2KJc/0Vfdl09U]?02HKS`00P2HL3d209]`?@80W74n102MLSl3
09]_?P0309a`?`2MLD00WG500080WW9100<0VVhm09]_?P2MLD000P2NLT400`2MLD00W70o09]_?P08
09ea@0<0Wg=200<0WW9109ea@02MLD000P2LL3l00`2MLD80WW930:1d@`020:5f@`030:1e@02NLc`0
WG8k00T0Wg=200P0XGI30:1e@P2OM440WW=009md@@2PMD80XWM40:=hA@<0XGI30`2PMD8209md@@80
WW=00`2OM4430:1e@P80WgA100@0X7E20:5f@`2RMd@0XgQ50P2TNDH80:EjA`P0XgQ1202TNdL80:El
B0040:IkAP2WO4L0Yga70:MlA`80Z7e80P2YOTT20:QmBP80Yga9102VNdP30:ImB@80Ygi:0`2XOd/8
0:QmBPP0ZGi900H0Yga70:QmB02YOTT0ZWm:0:^0B`2/PD`20:f2C@P0ZWm:202ZOd`80:V0C0030:Z1
C@2YP4`0Ygi:0080YGa800<0YWe90:MnBP2XOd/00P2XOTh30:MmC@@0YWa<0`2TNdL50:ElB0P0X7M3
0P2SNDT0102SNDL0XWU50:9iA@2QN4820:5h@080X7M30P2OMT8309ie@@0509ed@02NMD40WWE109ed
@02LLcl00P2KLSh209Ya?@0409]b?P2JLCd0VW4m09Ya?@80VG0l0P2HKc/809I/>P0509Q/>`2GJcX0
Uf/j09IZ>@2EJCP00P2DJ3L0102CIcH0UFXm09EZ?@2DJC`209=X>`04099W>P2AIST0TFHi08mT=`<0
T6Dh0P2AIST2099W>P@0S6Hg102=IcP3091Q=@80TF8f0`2BHcL00`2;ICP0RV@g08QR=@0208MQ=006
08QR=@2:I3L0RfDh08eW>02;ICH0RV@e0P28HS<00`29Hc@0RfDf08aV=`0308QT=080RFDe00<0RVHf
08]W=`2;IcL00P2>I38208mU<`80T6Hd0P2AIcD408iT<P@0SF<a00@0RF<d08QR<`28HS<0R68c0P27
HC8408IP<@0408EO<024GRl0Ped^08=M;P<0PU`]00@0PU/b08=L<`23G3<0Pe`c0P24GC@208EN=@06
089L;`23GC00Q5ha08EO<P26H3<0Qf4d0P28HSD808IP<`80Qf<c0P26HS8308EQ<@0408AP<022H3<0
PV0c089P<`80Pf4d0`24HSD00`24GRl0QEl`08MQ<P0208QR<`0708MQ<P25Gc00Q5h_08UN<@2:Gc80
S64d08iS=P0208mT=`0=08iS=P2=HSD0REha08YO<P2<HC@0SF8e08iS=P2=HSD0S64d08]P<`26H3<0
Qf4d08US=P0208]U>00308YT=`29HcH0R68e00<0SF8e1@2<HC@308aV=`D0RfDf202BJ3H809=Y=`06
099Y=@2CJSH0TfXf09A[=`2EK3P0UVdi0P2GKSX209Ia?0H0UG0k202IKcd309]a?`80W7900`2MLd42
09ie@@80WgI200@0X7M30:5hA02QN4@0XGQ40`2PMd<20:5hA0<0XWU5102QN4@20:9iA@<0XgY60`2V
ODL20:MnB0<0Z7m90`2ZPD/20:^2C0<0[8==00<0Zh9>0:Z1C@2YP4`00P2XOd/00`2YP4`0ZX5=0:^2
CP030:^3B080[8A90`2]QDX30:f4D0030:j5D@2_QU80[hIB0080/8MC0P2]Q500102^QE40[hIB0;27
D`2aR5@20;:9E@80[H=A0P2^Q5820:n5D`80/8ID0P2bR5H0102aQeD0/8ID0:n5D`2^Q5820:f3D@80
ZXEA0`2[QU830:b7D`P0/8MC00P0/hYF0;68E02_QU80[XEA0:f4D02^QE40[hIB0;27D`P0/8IF202a
R5@00`2eReT0]8YH0;:8EP030;26E0040;67E@2bR5H0/8]F0;2;EP80/HaG102bSEP80;:9E@<0/HME
0P2bR5H30;>9E`@0]8YH102cREL30;B:F080/hUG0P2bR5H20;67E@80]8UO00<0]8UN0;B9G02dRUX0
0P2dRUP00`2dReL0]HaH0;F<F00J0;F<F0@0]XeI00<0]HaH0;B;E`2bRED00`2`Qe<00`2aR5@0/XUE
0;2;E`070;2;E`80[HaF00<0[haF0:n:E@2aRED00P2aR5@00`2bQe@0/XUE0;:9E@060;:9E@030:V4
C`2ZQE00[8MB0080[HQC00<0[8MB0:Z5D02YQ4l0202`Qe<20;68D0040;27D@2`Qe<0[hIB0:n5D`80
[XAD202^QE480:f3D@@0[hI@102^QDl@0:f4D0P0[XEA00@0[HA@0:b3C`2ZPDd0ZX5=0P2YP4`00`2Z
PDd0[8=?0:f4D0080:b2D080[H5B00@0[H5@0:f2C`2]PTl0[H9=0P2]PT/80:f4D080[HE:0`2/Q4T3
0:^3B0060;26E02_QE<0[XAB0:f3D@2/PU00Zh5?0P2ZP4h80:b3C`P0[hAA00<0/8MC0:j5D@2[PTh0
0P2XOd/00`2ZPDd0[8=?0:n6DP080:j5D@P0[H=C0P2]Q4`0102]Q4h0[HA@0:f4D02]Pe420:f3D`P0
[HA@0P2[PTh20:b3C`070:f4D02^QE40[XEA0:j5D@2ZOd`0Zh1=0:b1CP020:f2C`0;0:b1CP2[P4d0
ZWm<0:MnBP2XOd/0ZX5=0:b3C`2]Q500[8=?0:^2CP2ZPDd00P2/PU00102[PDl0ZX1>0:UoC@2XOT`2
0:MmB`P0ZH1<00/0ZX950:^3B02/Q4T0[HA<0:f4CP2/Pdl0Zh5?0:Z0CP2YQU00ZXE@0:V4C`020:^3
C`040:b3C`2/PDh0[X1>0:j0CPP0ZGm=0P2ZPDd20:^2CP070:b3C`2]Q500[XEA0:j5D@2ZPDd0Zh9>
0:f4D0020:j5D@0:0:f4D02[PTh0ZX5=0:Z1C@2[PTh0[HA@0:j5D@2_QU80[XEA0:f4D0T0[8=?0`2[
P4T30:b1BP80[H9;0P2/Pdl0102[PTh0ZX5=0:V0C02XOd/20:MnBP040:IkAP2WO4L0ZGi90:^0B`80
[H9=00<0[85<0:^0B`2ZPDd01`2ZPDd80:b1C0<0Z81500<0ZH560:Z2A`2ZPTL00P2[PdP40:^2CP@0
ZX5=00<0YW]80:QmBP2[P4d00P2]PTl00`2[P4d0Yga90:EjA`080:QoB@P0[8=?202ZPDd00`2/PD`0
Zh1;0:UnB@020:QmB0030:UnB@2[P4/0[85<00P0ZH1:00<0Ygi:0:QoB`2YP4`00`2[PTh01@2YP4`0
Z7m;0:MnBP2UO4P0YWe90080Ygi:102XOd/00`2[PTX0ZH180:ElAP020:=jAP030:EkB@2YOdl0Zh5A
00X0Z7m;0`2WOTX30:ImB@<0Z7m;00<0Ygi:0:ImB@2VODT00P2UO4P30:V0C080Z7m;0`2WOTX0202X
OE80Z7e@0:QnCP2XOT`0Z7m90:QoA`2XP4D0Z8130P2YP4`30:QoB`/0Ygi:202ZOd`80:QoB`80YH1<
0`2TOd/30:=nBP80Y7]70P2UO4P20:ImB@80Ygi:00H0ZX5=0:V0C02XOd/0Ygi:0:ImB@2UO4P20:Ak
A`80YWe500@0YWe70:ImB@2VODT0YWa:0P2VO4`20:MnBP<0YWe90`2UO4P02@2TNTP0YG]90:MmB`2X
OT`0ZGm=0:QnC02WOD/0YWa:0:MnBP020:ImB@060:ElB02SNTH0XWU50:9iA@2QN4@0YWe90P2WOTX0
1@2SNTH0WgI209mf@P2OMT80Y7]70080ZH1<0P2XOd/02@2WOTX0YGa80:AkA`2TNdL0XgY60:QoA`2W
OTH0YGa40:=j@P020:9i@@040:=j@P2TNd<0YWa:0:IlBP80YG]900@0Y7Y80:=iA`2SNDL0XgU70`2S
OTX30:9mB@80XGa800<0XWU50:=jAP2TNdL00P2UO4P00`2SNTH0XGQ40:1g@`0809ehA00609id@P2O
MD<0WgE30:1fA02QMdD0XWQ60P2SNDL30:=jAP050:9iA@2QN4@0WgI209ie@@2MM4000P2NM48309me
@`<0X7I400<0XGM50:1fA02NM4800P2LLT000`2MLd40WWA209me@`0209Ye?P0309Ye@02JMD40VWA3
0080VWA500@0VWA70:1fA02PMT@0X7I40P2OMD<309id@P0;09Q^?02LLT00WWA209ab@02GKC/0UF/i
09M]>`2KLCl0W79009]a?`2IKcd00P2HKS`01P2IKcd0Vg4o09ab@02MM3h0W7<m09Ya>`80VG0j00@0
VW4k09ac?@2MM3h0V6lk0P2IL3`01@2JLCd0Vg8n09ac?`2LLcl0WGA000P0Vg4o00<0V6hl09Y`?P2L
LT000P2NM4800`2KLCl0V6hl09E[>@0309A_>`80UG0l102FLCd0402DJSP0UF/i09I/>P2GKC/0UV`j
09E[>@2CJCL0TFLe099W?@2CJ3h0U6Tn09EZ?@2FK3`0Ufdk09Q^?02HKc/209Y`?P<0VFlm0`2HKS`8
09U_?@0309Y_@P2IKT40Uf`o00<0UFXm00D0UV/n09M/?`2GKC/0V6hl09Y`?P0209]a?`0309Y`?P2H
KS`0Ufdk00P0Tfdn00<0T6Xm095[?P2CKD000P2EKd800`2DKT40Tfe0099/?`0209Ab@P0409=a@@2B
L400TW10095_?`80T6hn0`2EKC`[ooooo`00:_ooool00`25GSD0QUlf08IO=P0508IO=P80REhc0P2:
Gc@208]P=@80S64f0P2;H3D208YO=00408UN<`28GC80R5db08QM<PP0S64f00@0RUld08]P=@2<HCH0
SF8g0P2>HcP00`2=HSL0S64f091S>@07091S>@80TFDh0`2?HcH00`2AICP0TfLj09AX>`0809=R>@03
095T>P2BIC/0TVDk0080TfHl0P2DIcd00`2EJ3h0T6<i091S>@04095T>P<0TVDk0P2AICP2099V>@80
TfLj0P2DJ3/809EY?080TFTf0P2BJSL01@2CJcP0U6`i09A/>@2DK3T0VVTn0080VFPm0P2HIc`209MV
>`0409IU>P2AJ3X0TVTk09A[?@80UF`n00<0U6/m099Y>`2AJ3X00`2GJcX309IZ>@80UFTh00<0U6Pk
09EY?02GJch00P2HK3l00`2GJch0UVXm09EY?00809M[?P@0V6`k102GJcX809U]?080V6]200<0V6]1
09Q/?`2HK3d00P2HK3/01`2HKCX0WFXk09][>`2KJc/0Vfdl09U]?02HKS`00P2HL3d209]`?@80W74n
102MLSl309]_?P0309a`?`2MLD00WG500080WW9100<0VVhm09]_?P2MLD000P2NLT400`2MLD00W70o
09]_?P0809ea@0<0Wg=200<0WW9109ea@02MLD000P2LL3l00`2MLD80WW930:1d@`020:5f@`030:1e
@02NLc`0WG8k00T0Wg=200P0XGI30:1e@P2OM440WW=009md@@2PMD80XWM40:=hA@<0XGI30`2PMD82
09md@@80WW=00`2OM4430:1e@P80WgA100@0X7E20:5f@`2RMd@0XgQ50P2TNDH80:EjA`P0XgQ1202T
NdL80:ElB0040:IkAP2WO4L0Yga70:MlA`80Z7e80P2YOTT20:QmBP80Yga9102VNdP30:ImB@80Ygi:
0`2XOd/80:QmBPP0ZGi900H0Yga70:QmB02YOTT0ZWm:0:^0B`2/PD`20:f2C@P0ZWm:202ZOd`80:V0
C0030:Z1C@2YP4`0Ygi:0080YGa800<0YWe90:MnBP2XOd/00P2XOTh30:MmC@@0YWa<0`2TNdL50:El
B0P0X7M30P2SNDT0102SNDL0XWU50:9iA@2QN4820:5h@080X7M30P2OMT8309ie@@0509ed@02NMD40
WWE109ed@02LLcl00P2KLSh209Ya?@0409]b?P2JLCd0VW4m09Ya?@80VG0l0P2HKc/809I/>P0509Q/
>`2GJcX0Uf/j09IZ>@2EJCP00P2DJ3L0102CIcH0UFXm09EZ?@2DJC`209=X>`04099W>P2AIST0TFHi
08mT=`<0T6Dh0P2AIST2099W>P@0S6Hg102=IcP3091Q=@80TF8f0`2BHcL00`2;ICP0RV@g08QR=@02
08MQ=00608QR=@2:I3L0RfDh08eW>02;ICH0RV@e0P28HS<00`29Hc@0RfDf08aV=`0308QT=080RFDe
00<0RVHf08]W=`2;IcL00P2>I38208mU<`80T6Hd0P2AIcD408iT<P@0SF<a00@0RF<d08QR<`28HS<0
R68c0P27HC8408IP<@0408EO<024GRl0Ped^08=M;P<0PU`]00@0PU/b08=L<`23G3<0Pe`c0P24GC@2
08EN=@06089L;`23GC00Q5ha08EO<P26H3<0Qf4d0P28HSD808IP<`80Qf<c0P26HS8308EQ<@0408AP
<022H3<0PV0c089P<`80Pf4d0`24HSD00`24GRl0QEl`08MQ<P0208QR<`0708MQ<P25Gc00Q5h_08UN
<@2:Gc80S64d08iS=P0208mT=`0=08iS=P2=HSD0REha08YO<P2<HC@0SF8e08iS=P2=HSD0S64d08]P
<`26H3<0Qf4d08US=P0208]U>00308YT=`29HcH0R68e00<0SF8e1@2<HC@308aV=`D0RfDf202BJ3H8
09=Y=`06099Y=@2CJSH0TfXf09A[=`2EK3P0UVdi0P2GKSX209Ia?0H0UG0k202IKcd309]a?`80W790
0`2MLd4209ie@@80WgI200@0X7M30:5hA02QN4@0XGQ40`2PMd<20:5hA0<0XWU5102QN4@20:9iA@<0
XgY60`2VODL20:MnB0<0Z7m90`2ZPD/20:^2C0<0[8==00<0Zh9>0:Z1C@2YP4`00P2XOd/00`2YP4`0
ZX5=0:^2CP030:^3B080[8A90`2]QDX30:f4D0030:j5D@2_QU80[hIB0080/8MC0P2]Q500102^QE40
[hIB0;27D`2aR5@20;:9E@80[H=A0P2^Q5820:n5D`80/8ID0P2bR5H0102aQeD0/8ID0:n5D`2^Q582
0:f3D@80ZXEA0`2[QU830:b7D`P0/8MC00P0/hYF0;68E02_QU80[XEA0:f4D02^QE40[hIB0;27D`P0
/8IF202aR5@00`2eReT0]8YH0;:8EP030;26E0040;67E@2bR5H0/8]F0;2;EP80/HaG102bSEP80;:9
E@<0/HME0P2bR5H30;>9E`@0]8YH102cREL30;B:F080/hUG0P2bR5H20;67E@80]8UO00<0]8UN0;B9
G02dRUX00P2dRUP00`2dReL0]HaH0;F<F00J0;F<F0@0]XeI00<0]HaH0;B;E`2bRED00`2`Qe<00`2a
R5@0/XUE0;2;E`070;2;E`80[HaF00<0[haF0:n:E@2aRED00P2aR5@00`2bQe@0/XUE0;:9E@060;:9
E@030:V4C`2ZQE00[8MB0080[HQC00<0[8MB0:Z5D02YQ4l0202`Qe<20;68D0040;27D@2`Qe<0[hIB
0:n5D`80[XAD202^QE480:f3D@@0[hI@102^QDl@0:f4D0P0[XEA00@0[HA@0:b3C`2ZPDd0ZX5=0P2Y
P4`00`2ZPDd0[8=?0:f4D0080:b2D080[H5B00@0[H5@0:f2C`2]PTl0[H9=0P2]PT/80:f4D080[HE:
0`2/Q4T30:^3B0060;26E02_QE<0[XAB0:f3D@2/PU00Zh5?0P2ZP4h80:b3C`P0[hAA00<0/8MC0:j5
D@2[PTh00P2XOd/00`2ZPDd0[8=?0:n6DP080:j5D@P0[H=C0P2]Q4`0102]Q4h0[HA@0:f4D02]Pe42
0:f3D`P0[HA@0P2[PTh20:b3C`070:f4D02^QE40[XEA0:j5D@2ZOd`0Zh1=0:b1CP020:f2C`0;0:b1
CP2[P4d0ZWm<0:MnBP2XOd/0ZX5=0:b3C`2]Q500[8=?0:^2CP2ZPDd00P2/PU00102[PDl0ZX1>0:Uo
C@2XOT`20:MmB`P0ZH1<00/0ZX950:^3B02/Q4T0[HA<0:f4CP2/Pdl0Zh5?0:Z0CP2YQU00ZXE@0:V4
C`020:^3C`040:b3C`2/PDh0[X1>0:j0CPP0ZGm=0P2ZPDd20:^2CP070:b3C`2]Q500[XEA0:j5D@2Z
PDd0Zh9>0:f4D0020:j5D@0:0:f4D02[PTh0ZX5=0:Z1C@2[PTh0[HA@0:j5D@2_QU80[XEA0:f4D0T0
[8=?0`2[P4T30:b1BP80[H9;0P2/Pdl0102[PTh0ZX5=0:V0C02XOd/20:MnBP040:IkAP2WO4L0ZGi9
0:^0B`80[H9=00<0[85<0:^0B`2ZPDd01`2ZPDd80:b1C0<0Z81500<0ZH560:Z2A`2ZPTL00P2[PdP4
0:^2CP@0ZX5=00<0YW]80:QmBP2[P4d00P2]PTl00`2[P4d0Yga90:EjA`080:QoB@P0[8=?202ZPDd0
0`2/PD`0Zh1;0:UnB@020:QmB0030:UnB@2[P4/0[85<00P0ZH1:00<0Ygi:0:QoB`2YP4`00`2[PTh0
1@2YP4`0Z7m;0:MnBP2UO4P0YWe90080Ygi:102XOd/00`2[PTX0ZH180:ElAP020:=jAP030:EkB@2Y
Odl0Zh5A00X0Z7m;0`2WOTX30:ImB@<0Z7m;00<0Ygi:0:ImB@2VODT00P2UO4P30:V0C080Z7m;0`2W
OTX0202XOE80Z7e@0:QnCP2XOT`0Z7m90:QoA`2XP4D0Z8130P2YP4`30:QoB`/0Ygi:202ZOd`80:Qo
B`80YH1<0`2TOd/30:=nBP80Y7]70P2UO4P20:ImB@80Ygi:00H0ZX5=0:V0C02XOd/0Ygi:0:ImB@2U
O4P20:AkA`80YWe500@0YWe70:ImB@2VODT0YWa:0P2VO4`20:MnBP<0YWe90`2UO4P02@2TNTP0YG]9
0:MmB`2XOT`0ZGm=0:QnC02WOD/0YWa:0:MnBP020:ImB@060:ElB02SNTH0XWU50:9iA@2QN4@0YWe9
0P2WOTX01@2SNTH0WgI209mf@P2OMT80Y7]70080ZH1<0P2XOd/02@2WOTX0YGa80:AkA`2TNdL0XgY6
0:QoA`2WOTH0YGa40:=j@P020:9i@@040:=j@P2TNd<0YWa:0:IlBP80YG]900@0Y7Y80:=iA`2SNDL0
XgU70`2SOTX30:9mB@80XGa800<0XWU50:=jAP2TNdL00P2UO4P00`2SNTH0XGQ40:1g@`0809ehA006
09id@P2OMD<0WgE30:1fA02QMdD0XWQ60P2SNDL30:=jAP050:9iA@2QN4@0WgI209ie@@2MM4000P2N
M48309me@`<0X7I400<0XGM50:1fA02NM4800P2LLT000`2MLd40WWA209me@`0209Ye?P0309Ye@02J
MD40VWA30080VWA500@0VWA70:1fA02PMT@0X7I40P2OMD<309id@P0;09Q^?02LLT00WWA209ab@02G
KC/0UF/i09M]>`2KLCl0W79009]a?`2IKcd00P2HKS`01P2IKcd0Vg4o09ab@02MM3h0W7<m09Ya>`80
VG0j00@0VW4k09ac?@2MM3h0V6lk0P2IL3`01@2JLCd0Vg8n09ac?`2LLcl0WGA000P0Vg4o00<0V6hl
09Y`?P2LLT000P2NM4800`2KLCl0V6hl09E[>@0309A_>`80UG0l102FLCd0402DJSP0UF/i09I/>P2G
KC/0UV`j09E[>@2CJCL0TFLe099W?@2CJ3h0U6Tn09EZ?@2FK3`0Ufdk09Q^?02HKc/209Y`?P<0VFlm
0`2HKS`809U_?@0309Y_@P2IKT40Uf`o00<0UFXm00D0UV/n09M/?`2GKC/0V6hl09Y`?P0209]a?`03
09Y`?P2HKS`0Ufdk00P0Tfdn00<0T6Xm095[?P2CKD000P2EKd800`2DKT40Tfe0099/?`0209Ab@P04
09=a@@2BL400TW10095_?`80T6hn0`2EKC`[ooooo`00:_ooool208MP=`<0QUlf0`25GSD208QM<P80
REhc0`2:Gc@208]P=@80RUld00<0REhc08QM<P28GC800P27G34808aQ=P0808QM<P2:Gc@0SF8g08mT
>@2@ICX0SV<h08aQ=P2;H3D8091S>@0809=W>P2BIST0T6@g08mS=P2@I3L0TVHi09AX>`2EJC`809EQ
>@04099U>`2CIS`0TfHl09AW?@80UFPn0P2FJCl2091S>@@0TF@j0`2BIC/2095U>080TVHi0P2CIcX2
09AX>`P0UVXm0P2AJCH0102BJSL0Tf/h09=[>02DK3T209E]>P80VVTn00@0VFPm09QW?02HIc`0UfHk
0P2FICX00`2AJ3X0TVTk09A[?@0209E/?P0309A[?@2BJC/0TFPj00<0Uf/j0`2FJST209EY>00309AX
>`2EJC`0Uf/n0080V6`o00<0Uf/n09IZ?@2EJC`0202GJch01@2JKSd0VFdl09U]?02HK3/0Uf/j0080
UVXi00<0UFTh09U]?02IKC`01P2IKC`209Q[@P0309Q[@@2HK3l0V6`m0080V6`k00L0V6dj09eZ>`2K
Jc/0Vf/k09]]?02IKC`0V6hl0080V70m0P2KL3d209aa?P<0WG8o00H0WW=009]_?P2KKch0Vfln09a`
?`2MLD0309ib@@0309]_?P2LL3l0WW910080Wg=200<0WG5009]_?P2IKC`0202MLD00102PM4<0Wg=2
09mc@P2NLT4209ea@080W70o00<0WG5209ib@`2PM4<00P2QMT<00`2PMD00WW<l09eb>`0909mc@P08
0:5f@`2PMD80WgA109ic@02OM440X7E20:9gA02SN4D30:5f@`<0X7E20P2OM44309ic@080WgA10`2P
MD80202NLd00WgA10:1e@P2QMT<0XWM40:=hA@2TNDH0YGY70`2VNdP50:EjA`P0XWM0202TNdL80:El
B0@0Yga70P2XODP20:UnB@80Z7e:0P2WO4T30:IkB0040:EjA`2VODT0YWe90:ImB@<0Ygi:0P2XOd/8
0:QmBP80ZWm:102YOTT20:QmB0060:MlA`2XODP0Z7e80:YoBP2[P4/0[85<0P2]PTd80:YoBPP0ZWm<
202YP4`00`2ZPDd0ZH1<0:MnBP030:ElB0040:ImB@2WOTX0Z7i>0:QnCP<0Yge=102VO4`50:AkA`<0
YGa8202OMT820:=iB@040:9hAP2RNDD0XWU50:5h@P80XGQ00`2OMT8209ie@@<0WGA00P2NMD400`2M
M400W7<o09]b?P0209Ya?@0409U`?02JLCd0VW4m09Ya?@80VG0l0`2HKc/809E[>@0609U]?02HK3/0
Uf/j09IZ>@2DJ3L0TfLf0P2BISD209I[?P0509EZ?@2CJ3/0TVLj095V>@2@ICP00`2?I3L2091U>0<0
TFHi00<0TVLj08]U=P2;ICH0102<ISL208eW>080T64e0P2AHSH3099S=`0409=T>02;ICP0RF<f08MQ
=080QV0c00H0Qf4d08US=P2;ICP0SFLh08]U=P29Hc@208MQ<P0308QR<`2:I3D0RfDf0080Qf<c0P28
I3@01029ICD0RVHf08YV=P2;IcL208eS<@0408iT<P2?IC<0SfDc091V=080TFLe0P29Gbd0102:H2h0
Rf4_08eS<@2>I38208mU<`<0R68c0P27HC8308IP<@0608MQ<P26H340QEl`08AN;`23GBh0PE//0`20
FR/2089K=080Pe`e0`24GCH01`25GSL0PE/^085K;P22G2l0Ped`08EO<P26H3<00P27HC@808IP<`@0
QF4a0P24H30208=O;`<0PV0c0P23HC@308AR=@0308AN;`25Gc00Qf4b0080R68c00L0Qf4b08EO<024
GRl0Qe`_08UN<@2;H3<0SV<f00<0Sf@g00@0SV<f08QM<02:Gc80Rf0c0`2=HSD02`2<HC@0Rf0c08EO
<P26H3<0RF<f08YT=`2;ICP0RV@g08QR=@27HC@0S64d00@0Rf0c0`2:Gc8308YT=`<0RfDh0P2<IST8
099X=PP0TfTg0P2BJCD01`2CJSH0U6/g09E/>02EK3P0UVdi09M^>P2FLC`0102EL3/309A_>PP0VFlm
00@0VW0n09]a?`2KLCl0Vg4o0P2LLT0209ec@@0409ed@02NMD40WWE109mf@P80X7M30P2QN4@0102O
MT80X7M30:1g@`2PMd<20:5hA080XWU5102QN4@20:9iA@<0XgY60`2VODL30:MnB080Z7m90`2YP4X2
0:Z1B`<0Zh9<00<0[8=?0:Z1C@2XOd/00P2WOTX00`2XOd/0ZX5=0:b3C`030:^3AP<0[8A70P2]QDP0
102/Pdl0[HA@0:f4D02^QE420:n6DP80/8MC00T0[8=?0:f4D02^QE40[hIB0;27D`2aR5@0/XUE0;>:
EP2/PU000P2]Pe400`2^Q580[hEC0:n5D`020;26E080/XQF00@0/HME0;26E02_QE<0[XAB0P2]Pe42
0:Z5D@<0ZhIB0`2/Qe<80;27D`030;>:EP2aR5@0[hIB0080[HA@00<0[XEA0:n6DP2aR5@0202`QUH8
0;68E0030;F;F@2dRUP0/XQF0080/8ID00<0/HME0;:8EP2cREL00P2`ReH20;6<E`<0/XeH00<0/hiI
0;:9E@2bRED01P2bRED30;67E@80/XQF0`2cREL01P2fS5X0]H]I0;F;F@2dRUP0/hUG0;:8EP80/HME
00<0/hUG0;:8EP2bR5H00P2bR5H20;67E@80/8ID0P2dREl00`2dREh0]8UL0;B:FP020;B:F0030;B;
E`2eS5P0]HaH01H0]HaH00H0/hYF0;B;E`2dReL0]HaH0;J=F@2gSUX20;R?F`030;F<F02dReL0/XUE
0080/8MC00<0/HQD0;:9E@2cRUH0202`ReL20:f<EP030:n<EP2_RUD0/HUE0080/HQD00<0/XMD0;:9
E@2bRED01P2bRED00`2YQ4l0ZXE@0:b7DP020:f8D`030:b7DP2ZQE00ZHA?00P0/8MC0P2aR500102`
Qe40/8MC0:n6DP2_QE<20:j4E0P0[XEA202]Pe420;27D@030:n6D02^QDl0[HA>0080[8==00<0Zh9<
0:f4D02]Q5003P2]Q5080:j5D@040:f4D02[PTh0ZX5=0:Z1C@80Z7m;00<0ZX5=0:^2CP2]Q500202/
PU020:f1DP040:f1D02]PTl0[H9?0:f2C@80[H9;202^QE420:f5B0<0[8A70`2[PdH20;26E0040:n5
D`2^Q580[89@0:^1C`80ZX1>202/Pdl80;25DP070;:9E@2_QU80Zh9>0:QoB`2WOTX0ZH1<0:b3C`09
0:j5D@P0[H=C0P2]Q4`0102]Q4h0[HA@0:f4D02]Pe420:f3D`P0[HA@0P2[PTh0102/Pdl0[HA@0:f4
D02^QE420:n6DP030:YoC02[P4d0[85>0080[H9?00H0[85>0:^0C@2ZOd`0Z7m;0:V0C02[PTh20:f4
D0040:b3C`2ZPDd0Z7m;0:b2D080Zh5?00<0ZX1>0:UoC@2XOT`00P2WOD/80:MnBP0;0:V1A02[PdP0
[HE:0:j5C@2^QDl0[HA@0:^1C`2YOdd0ZHI@0:Z5D02YQ4l00P2[Pdl0102/Pdl0[85>0:j0CP2^P4h8
0:UoC@060:QoB`2YP4`0ZX5=0:^2CP2/Pdl0[XEA0P2_QU800`2ZPDd0Zh9>0:f4D0020:j5D@060:f4
D02[PTh0ZX5=0:Z1C@2[PTh0[HA@0`2_QU800`2]Q500[8=?0:^2CP070:^2CP050:UnA`2ZOdP0ZWm8
0:^0B@2/PDX00P2]PT/03@2^Pd`0[8=?0:b3C`2[PTh0ZX5=0:V0C02XOd/0Ygi:0:ImB@2UNTD0Yga7
0:UnB@2[P4/00P2]PTd20:b1C080[8=?102[PTh20:Z1C@P0[85<00@0Ygm20:R0@`2XP4<0ZH540P2Z
PTD20:^3AP@0ZX5=102[PTh00`2TNDH0YW]80:YoC0020:f2C`030:^0C@2XODX0YW]800P0Z7m9202/
Pdl80:Z1C@030:b1C02[P4/0ZGi90080Z7e800<0ZGi90:^0B`2/PD`0202YP4X00`2XOd/0ZH1<0:^2
CP030:b3C`040:^2CP2YP4`0Z7m;0:MnBP80YWe900P0YGa80:ImB@2WOTX0Z7m;0:V0C02[PTX0Z7m7
0:ElAP80XgY600<0YG]90:QnCP2[PE402P2XOd/30:MnBP<0YWe900@0ZH1<0:QoB`2XOd/0Ygi:0P2V
ODT20:ElB0<0ZH1<0P2XOd/30:MnBP080:QmD`2XOE80Z7e@0:QnC02XOdT0Z8150:R0@`2XP4820:Z1
C@040:V0C02XOd/0Z7m;0:MnBP80YWe9202WOTX00`2[P4d0ZWm<0:YoC0040:YoC0030:^0C@2XOd/0
Z7m;00H0Z7m;0P2TP4`30:=oB`<0XWi:0P2TNdL20:ElB080YWe90P2WOTX01P2ZPDd0ZH1<0:V0C02W
OTX0YWe90:ElB080Y7]70P2VODD0102VODL0YWe90:ImB@2VO4X20:IlC0<0YWe90P2UO4P30:AkA`04
0:=iA`2TNTP0YWa:0:QnC080ZGm=00L0Z7i<0:MmB`2WOTX0Ygi:0:ImB@2UO4P0Y7]70080XWU500H0
XGQ40:QoB`2XOd/0YWe90:5hA02MM40209ie@@070:ElB02[PTh0ZX5=0:Z1C@2YP4`0Z7m;0:MnBP02
0:ElB0050:AkA`2YP4P0Z7m70:ElA02SNT800`2RND400`2SNT80YWa:0:IlBP020:EkB@050:AjB02S
NDL0XgU70:9hAP2TP4`00P2SOd/01`2ROTX0XGe90:1lB02PO4P0Wg]70:9iA@2SNTH00`2UO4P00`2S
NTH0XGQ40:1g@`0309ehA080WWU50`2ONTH20:=iA`80Y7Y800T0YG]90:IlBP2WOD/0Yge;0:AkA`2S
NTH0XGQ40:1g@`2OMT800`2NMD4209id@P<0WgE30`2PMT@00`2QMdD0X7I409id@P0209ab@00309ec
@@2NM480WgE30080VWDn00<0VWE009Ye@@2JM4<00P2JM4D0102JM4L0X7I40:1fA02PMT@309me@`80
WWA200/0Ufdk09]a?`2NM480Vg4o09I/>P2CJCL0UV`j09Y`?P2LLT00Vg4o09U_?@0209Q^?00609U_
?@2KLCl0W79009ie?`2LLcd0Vg8l0P2IL3X00`2KLS`0W7<m09ie?`0209M^>P0609Q_>`2JLCd0Vg8n
09ac?`2MM400WWE1202KLCl0202GKC/0VW0n09ec@@2OMD<0WWA209]a?`2HKS`0UF/i0P2CKSX209A_
>`0309E`?02FLCd0Ug8n0080Ug8n00P0TfTg09AZ>02FK3X0Ufdk09I/>P2DJSP0TVPf095W=@80TVLm
00H0U6Tn09EZ?@2FK3`0Ufdk09Q^?02HKc/209]a?`0409Y`?P2IKcd0VFlm09Q^?080Ufdk202IKcd0
2`2JKd80V6e009I[?P2EJSd0U6Tl09EZ?@2FJch0V6e009M]>`2HKS`0VW0n0080Vg4o00<0VW0n09Q^
?02GKC/0202DKSl0402AJch0TV`o09A^@@2FL4<0Ug5409I`@`2DKT40Tfe009MeA@2FM4@0UG=309Ab
@P2CLD40TW10095_?`2@KSh309E]?2_ooooo000Zooooo`0308IJ<`27Fc@0REdf0080RUhg00<0REdf
08MK=026FS<01P28GC8208UN<`P0SF8g00P0RUld08]P=@2<HCH0SF8g08aQ=P2;H3D0REhc08QM<P80
RUld00T0Rf0e08eR=`2?I3T0T6Dj095V>`2BIc`0TFHk091U>P2>HcP00P2=HSL02`2>HcP0T6Dj095V
>`2@Ic<0SfDc08iT<P2=Hc<0SF8e08mT>@2AIS`0TVLm0080Sf@i0`2@ICX3095V>`0408mR>02@HcT0
T6<i095T>P80TVDk0P2CIS`909=X?@80Sf8i00<0T6<j095T>`2BIC`00P2CISd0102DIch0U6Pk09AX
>`2DJ3/209EY?0<0UVXm0`2GJch209Q/?`<0VFe00`2DJ3L209EY>0<0UVXi202EJcT209=W=P80U6Pg
0`2EJCP00`2FJST0UVhk09E]>P0409E]>P80U6`i0P2IKC`209Q/>`80Uf/j0P2FJST309I/>P80Ufdk
0`2HKS`809Y^?@<0W74n0`2KL3d:09Y_?0P0Vfln0P2JKSd309]_?P<0W70o202MLSl0202LLCh0Vg0m
09Y_?02IKS/0VVll09]`?@2MLSl0WW=0202OM440202LM400WWI20:1g@`2RMd@0Y7I40:Ad@`2SLd80
Xg500`2QMD@40:1d@`80Wg=200<0X7E20:9gA02TNDH00P2UNTL0102TNDH0XWM40:1e@P2OM44409ic
@0<0WG8o202PMD820:=gB0040:=gAP2TNDH0Y7U60:EjA@80YGY3202SN4D0202XMTD0YGE40:Ad@`2T
MT@0XgQ50:AkA`2UODT0Ygm;0`2UNDX30:IjB`80Yg]<00P0YGQ?0:EhCP2UND`0Y7Q70:AiA02SNCl0
XgTm0:=j?0P0YGY300P0ZgU80:UiB02XN4L0YWQ60:EjA`2VODT0Ygm;0:R0C080YWe91P2WOTX20:b1
CP80Zh1=00@0ZWm<0:UnB`2XODX0Z7e:0P2VNdP20:MlB@060:QmBP2YOT/0ZGi;0:YoC02YOTT0ZWm:
0P2[P4/0102ZOdX0ZGi90:MlA`2UNTD20:IkB0040:MlB@2XODX0ZWm<0:^0C@80[85>0P2ZP5020:Uo
C`80Z7i>0P2WODd80:V0C0<0XgiA0P2ROE030:5lC`T0YGa800H0Ygi:0:ImB@2VODT0YGa80:AkA`2S
NTH20:9iA@<0WWU41@2ONTD0202MN4@0WWU509iiA@2NNDD0W7M309Ud@02GLSh0UG0l202MLTD209ea
@00609a`?`2KKch0VFdl09Q/>`2GJcX0UVXi0`2GKC/509Q^?00409U^@@2GK3l0UFXm09=X>`80TFHi
00<0TVLj09=X>`2DJC`00`2EJSd0302DJC`0TVLj08mT=`2>HcH0TF`g091[=P2?JSD0SFPc08]V<@29
I2l0R6<^08MR;@P0RfDf00P0RfDh08YT=`29HcH0RF<f08YT=`2<IST0SVPk08mY?0<0RV@g1@2;ICP8
08MR=@0808EP<`24Gc80Peha089M<023GS40QF0c08MR=@29I3L808MR=@P0RElg2027HSD208AO<P04
08EP<`26HC@0QV4d08MR=@80R6<f2@23GS401P26GC40QU`b08=L<@21G380P5Xc07iK=@80O5Xe00<0
PUdc08=N=024GcD00P24GcD00`22GC<0P5/a07iI;`0208AP<080Pel_00<0PUh^085M;@20G2`00`20
G2`01021GBd0PUh^08=O;`23Gbl208AP<00308=M=P22G3D0PE/d0080PE/d00H0Pedf08AN=`26H3T0
RV@g08QR=@27HC@208EO<P0308MQ=028HSD0RV@g0080PE`b00<0PUdc08=N=024GcD00P25H3H00`26
HCL0QV8b08EQ<@0208AP<00408EQ<@26HS80R6@d08YV=PP0R68e202;Gc8208UU=@<0RVHf0`2;IcL0
1P27HRh0R6<_08UT<02:IC40RfHb08eX=080SVTe0P2?HcH00`2@I3L0TFDh099V>@0209=W>P0709AX
>`2BIc`0TVLj099W>P2BJ3P0TFLe095X=002095X<P0809=W=P2DJ3L0Uf/j09U]?02JKSd0VFdl09M[
>P2EJCP409A_>`80UG0l0P2FLCd0402DJcL0UVdi09U`?02KLSh0W7<o09]b?P2JLCd0VG0l0:5hA02P
Md<0WWE109ed@02NMD40WgI20:9iA@2SNTH50:1g@`<0XGQ40P2SNDL03P2RN4H0XGM50:1fA02QMdD0
XgU70:IlBP2WOD/0YWe90:ElB02TNdL0XgY60:AkA`2UO4P0Ygi:0P2XOd/40:V0C0<0ZX5=102[PTh4
0:Z1C@P0ZX5;0P2/Pdl20:f4D080[XEA0P2_QU830:b2D080[H=A0`2^Q5880:j9E@<0/HME00<0/8ID
0:n5D`2^Q5800P2^Q5801P2]QeX0[HMH0:f7F02]QeH0[HQD0:f8D`80[HQA102/Qe<20:^6DP80ZXEA
0P2^Q5820:n5D`80/8ID0P2aQeD30;27D`<0/HQD0P2bRED80;67E@060;:7G02bQeX0/XMJ0;:8F02b
R5H0/XUE0P2bRE<20;F7E@<0]XQF0`2gREL80;6<F0P0]8YH202cREL40;B:F0<0/hUG0P2bR5H80;2;
E`P0/hYF202dRUP0102aR5@0/XUE0;:9E@2cRUH20;B;E`80]HaH0P2bRED30;>:EP<0]8]G0P2eS5P0
102dReL0/hYF0;68E02`Qe<20:n6DP080;:9E@2aR5@0/8MC0;27D`2aR5@0/XUE0;B;E`2fSET20;B;
E`040;>:EP2bRED0/XUE0;68E080/8MC202`ReH40:n6DP@0/8MC0P2^QE40102_QU80/8MC0;27D`2a
R5@20;:9E@P0ZhIA202]Q5030:n6DP<0[XEA0P2]Q5030:b7D`<0ZhIB0P2ZQE401P2YQTh0ZXE>0:Z5
CP2/QDh0[HA>0:j3CP80/89>0100[85D0:f3D`2_QE<0/8MC0;27C`2_QdX0[HE70:b5A02[QU40[HQC
0:j9E02_RUD0[XUD0:f8D`2[QU40ZHA?0P2]Q5040:b3C`<0Zh9>0P2]Q5030:b3C`<0Zh9>00P0Ygi:
0:QoB`2YP4`0ZX5=0:^2CP2/Pdl0[HA@0:j5DA00[8=?202/PDh20:]mB`040:anC02]Odd0[Gm=0:j0
CP80[h5?202]Q500102^QE40[HA@0:f4D02/Pdl20:^2CP80ZX5=0`2^QDd20:f4C0<0[8=;0`2^QE42
0:f4D0/0[8=?202]Pe420:^2BP040:b3C@2]Q500[HA@0:j4DP80[hEE0`2[PTh30:b3C`80[HA@202/
PU020:^1C`80ZX1>00@0ZGm=0:QnC02XOT`0Yge;0P2ZP500102ZP4h0ZH1<0:V0C02YP4X20:QoA`P0
[8=?0P2_QU800`2^QE40[HA@0:f4D0020:b3C`<0Zh9>00L0ZX5=0:QoB`2XOd/0ZH1<0:^2CP2]Q500
[hIB00P0Zh9>00<0Z7m90:Z1B`2[PT`00P2]Q4h01P2[PT`0ZX5;0:QoB@2XOTh0ZX1@0:^1D@80[H=C
00<0Zh5A0:Z0D02XOTh00P2^QE440:f4D080[8=?202^QE400`2YP4P0ZX590:^2BP020:b3B`030:^2
BP2ZPDT0ZH1800<0[8==0P2]Q4h30:j5C`80[8=?0P2[PTh20:Z1C@80ZH1<0P2_QU80102^QE40[HA@
0:f4D02/Pdl20:^2CP030:n6DP2]Q500[8=?00<0ZX5=00<0Zh9>0:b3C`2ZOe@00P2ZOe800`2ZP500
ZGm=0:V0C0020:QoB@P0[85<202YP4`00`2ZQE40Z8=?0:N2CP020:F0C0030:N2CP2XPdl0ZXEA0080
ZXE@0P2YQ4l40:R3CPX0Z7m90`2YP4X30:Z1B`T0Zh9>0P2XOd/20:V0C0040:Z1C@2[PTh0Zh9>0:b3
C`P0Z7i<00<0YWY90:MkBP2YOD`00`2[Odh00`2YOD`0Z7a;0:QoB`070:QoB`040:V0C02XOd/0Z7m;
0:MnBP80YWe90P2UO4P80:QoB`030:b2DP2ZP500Z7i<0080YWe900T0Z7m90:Z1B@2/Pd/0YWi10:In
@`2WOd@0Z7m70:QoB@2YP4`00P2ZP4h30:Z1B@<0ZH180P2XOdL80:QoB`050:=j@P2TNd<0Y7]30:El
A02VODD00P2WOTH00`2XOdL0XgY40:=jA0030:AkA@<0YGa600P0XWU50:=jAP2TNdL0YWe90:QoB`2Y
P4`0ZX5=0:^2CP80Z7m;0`2WOTX30:ImB@P0Y7]70P2WOTX20:ImB@80YGa80P2TNdL20:AkA@80YGa6
0P2VODL20:MnB080Ygi:00H0YWe90:AkA`2SNTH0XWU50:5hA02PMd<40:ElAPD0YWe700@0Z7m;0:Mn
BP2UO4P0XgY60P2RNDD00`2SNTH0Y7]70:ImA`070:ImA`D0XGa70`2RODP0102WOTX0YWe90:ImB@2V
ODT20:ElB080Y7]700P0X7]60:5lA`2SOTT0Y7m:0:=nB@2RODP0X7]609iiA0@0Y7]700@0XgY60:9i
A@2RNDD0XGQ40P2QN480102QN4@0XWQ60:9hB02RN4P20:9gBP0;0:5gA@2RN4H0XgU70:AjB02SNDL0
XWQ60:1fA02OMD<0WgY309ii@P2LMd000P2KMSl00`2MN440WgY30:1kA00209me@`0309id@P2MLd40
W7900080Vg4o00<0VW0n09id@P2NM4800`2OMD<30:1fA00;09ij?P2NNT00WWU209iiA02NN4L0WWQ;
09igC02NMdh0W75409Y_@P2HKD000P2GK3l0102HKD00VVm209]`@`2EL3/209E`?00309I`?`2FL440
Ug540080Ug1500<0V6hl09U_?@2JL3h00P2KLCl00`2IKcd0Ufdk09I/>P0209E[>@0409M]>`2HKS`0
VW0n09]a?`80WG=11@2JL3h309]a?`P0VW0n2@2FLCd0202CJ3/0U6Tl09EZ?@2FJch0Uf`o09Q]@02I
KT40VVm20`2EL3`209Ia?@<0Ug8n202KLCl809UcA00809YdA@2GLD80U6ho095[?02@JS/0TV`m09E_
@02HLT<809I`@@80UF`h0P2FKCT209M^>P80V6lk202FL440102HM4@0UW9209=_?`2AKCd2091/?003
095]?@2BKSh0U6ho0080U6ho:oooool002[ooooo00<0Qe/d08UM=P2:GSL00P2;GcP00`2:GSL0REdf
08MK=00308YO=0D0REhc202=HSL00`2;H3D0S64f08eR=`0208iS>00408aQ=P2:Gc@0REhc08]P=@80
S64f00<0SF8g08iS>02?I3T00P2@ICX00`2AIS/0T6Dj08iS>00208eR=`0;08iS>02@ICX0TFHk091W
<`2?IC<0SV@b08eS<`2=HSD0Sf@i095V?02BIcd00P2?I3T3091U>P<0TFHk0`2@HcT00`2AI3X0TVDk
099U>`0209=V?0T0TfPm102AI3/4099U?0<0U6Pk0P2EJC`309IZ?@<0TfLj0P2DJ3/309EY?0<0U6Pg
0P2EJCP309IZ>@P0UF/i0P2DJ3L209EY>080UVXi0P2GJcX609I^>`80UFdj0P2IKC`209Q/>`80Uf/j
0P2FJST309M]>`80V6hl0`2IKcd809Y^?@<0W74n0`2KL3d:09Y_?0P0Vfln0P2JKSd309]_?P<0W70o
202MLSl0202LLCh0Vg0m09Y_?02IKS/0VVll09]`?@2MLSl0WW=0202OM440202LM400WWI20:1g@`2R
Md@0Y7I40:Ad@`2SLd80Xg500`2QMD@40:1d@`80Wg=200<0XGI30:9gA02SN4D00P2TNDH00`2SN4D0
XWM40:5f@`0209md@@H0WW=0202PMD820:=gB0040:=gAP2TNDH0Y7U60:EjA@80YGY3202SN4D0202X
MTD0YGE40:EeA02TMT@0XgQ50:AkA`2UODT0Ygm;0`2TN4T30:EiBP80YWY;00P0Y7M=0:AhB`2TN4T0
Y7Q70:AiA02TND80Y7Y00:Aj?PP0YGY300P0ZgU80:UiB02XN4L0YWQ60:EjA`2UO4P0YWi:0:R0C0D0
Ygi:0`2VODT30:^0C@80ZWm<0`2YOT/20:IkB080Yga900H0Z7e:0:UnB`2YOT/0ZGi;0:UnB@2ZOdX2
0:^0B`050:YoBP2YOTT0Yga70:IkAP2VNdP00P2WO4T01@2XODX0ZWm<0:^0C@2[P4d0[85>00@0Z7i>
0P2WODd20:IlC0P0ZH1<0P2UOe020:AnC`<0Xge>00<0XWa=0:ElB02UO4P01`2UO4P20:ImB@030:El
B02TNdL0XgY60080XWU500<0XGQ409iiA02NND@01@2NND@02@2ONTD0WGQ409ehA02NNDD0WGQ409ag
@`2IM400UW4m09E`?00809aaA00509]a?`2JL3h0VW0n09U_?@2HKS`00P2GKC/00`2FK3X0Ufdk09M]
>`0309M]>`<0V6hl00@0V6e009M/?`2DJC`0TVLj0P2AIST2099W>P0>09=X>`2DJC`0U6Tl09AY?02C
J3/0TFHi08mT=`2=HSD0SfXf08iY=@2=J3@0S6Lc08]V<P29I30208QS;`P0RV@e00<0RV@g08US=P28
HSD00P28HSD00`2:I3L0S6Hi08eW>P0508YT=`<0RfDh2027HSD02025H3<0Q5lb08=N<@22GC00Peha
08AO<P27HSD0R6<f2027HSD808QN=PP0Qf8e0P24Gc8208EP<`80QV4d0P27HSD908=N<@0@08IM<@26
G380Pe`a085L<P20FS<0OEXd07aJ=@1kFC@0PE`b089M<`23GS@0Q5le08=N=021G380OeX`07iI;`80
Pel_0`22GRh6085M;@<0PUh^0P23Gbl02`22G3D0PE/d081J<`1oFC80P5Xc085K=023GCH0Q5hg08QR
=@27HC@0QElb0080Q5ha00<0QElb08MQ=028HSD00P21G3801022GC<0Pehd08AO=@24GcD208EP=P08
08IR<P25HC40Q60`08=O;`24H300QV8b08QT=029ICD808QR=@P0RUlb0`28I3@208UU=@<0RVHf0P28
Hbl00`29I300RVDa08]V<P0308aW<`80SV<f00@0Sf@g091U>02AIST0TFHi0P2BIcX01P2BIc`0TVLj
099W>P2AIcL0TFLe095X=080TFPb00@0TVPf09=Y=`2DJSP0UF/i0P2FK3X0102EJcT0U6Xh09E`?02E
L3`609A_>`0409A[=`2FKCT0V6lk09Ya?@80Vg8n00X0VW4m09U`?02OMT80WWE109ed@02LLcl0WGA0
09ie@@2PMd<0XGQ40`2OMT820:1g@`80XGQ400@0XWU50:=iA`2SNDL0XWQ60`2QMdD02P2SNDL0YG]9
0:IlBP2VODT0YGa80:AkA`2SNTH0Y7]70:ElB02WOTX30:QoB`H0ZH1<202ZPDd80:Z1B`80Zh9>0P2/
Pdl40:f4D0<0[89@0P2]Pe430:j4DPP0[XUE0P2aQeD20;26E080[hEC0P2^Q5801P2]QeX0[HMH0:f7
F02]QeH0[HQD0:f8D`80[HQA00@0[HQD0:b7D`2/Qe<0[8MC0P2[QU820:Z5D@80[XAB0P2_QE<20;26
E080/HME0`2`Qe<30;68E080/XUE202aQeD01P2bQe`0/XMJ0;:7FP2bR5P0/XQF0;:9E@80/XUC0`2e
QeD20;J8EP<0]hUG202bSET80;B:F0d0/hUG102dRUP80;2;E`P0/hYF202eReT30;:9E@030;>:EP2d
ReL0]8]G0080]HaH0P2bRED30;>:EP<0]8]G0P2eS5P0202dReL0/hYF0;:9E@2aR5@0/8MC0:n6DP2b
RED0/HQD0P2`Qe<0102aR5@0/XUE0;B;E`2eS5P20;B;E`80/hYF00@0/XUE0;68E02aR5@0/HQD202`
ReH40:n6DP@0/8MC00<0[HA@0:j5D@2^QE400P2_QU820;27D`030;68E02[QU40ZhIA00H0ZhIA202]
Q5030:n6DP<0[XEA0P2]Q5030:b7D`<0ZhIB0P2ZQE401P2YQTh0ZXE>0:Z5CP2/QDh0[HA>0:j3CP80
/89>00X0[89B0:f3D`2_QE<0/8MA0;27C`2_QdX0[HE70:b4AP2/Qe80[HQC0`2^RE@00`2/Qe80ZXE@
0:V4C`040:f4D080[8=?0`2[PTh20:f4D0<0[8=?0`2[PTh20:QoB`060:V0C02ZPDd0Zh9>0:b3C`2]
Q500[XEA402/Pdl80:b1CP030:anC02]Odd0[Gm=0080[X1>0P2_PDl00`2`PU00[HA@0:f4D0090:f4
D0030:b3C`2[PTh0Zh9>0080ZX5=0`2^QDd20:f4C0<0[8=;0`2^QE420:f4D0/0[8=?202]Pe420:^2
BP040:b3C@2/Pdl0[HA@0:j4DP80[XAD0`2[PTh30:b3C`80[HA@202/PU020:^1C`80ZX1>0P2YOdd2
0:QnC080ZX1@00@0ZX1>0:V0C02YP4`0ZH1:0P2XOdL80:b3C`80[hIB00@0[XEA0:f4D02]Q500[8=?
0P2[PTh00`2ZPDd0[8=?0:^2CP030:V0C0030:Z1C@2/Pdl0[XEA00P0Zh9>00<0ZH1:0:Z1B`2[PT`0
0P2/Pdd01P2[PT`0ZX5;0:V0BP2YOdl0ZX1@0:^1D@80[89B00<0Zh5A0:Z0D02YOdl0202]Q5080:j5
D@030:V0B02ZPDT0Zh9:0080[8=;00<0Zh9:0:Z1B@2YP4P00`2/Pdd30:f4CP80[XE?0P2/Pdl20:^2
CP80ZX5=0P2YP4`20:j5D@80[HA@0P2/Pdl20:^2CP090:n6DP2]Q500Zh9>0:Z1C@2YP4`0ZX5=0:^2
CP2/Pdl0Zh1E0080ZWmB00<0ZX1@0:UoC@2YP4`00P2XOdT80:b1C0P0ZH1<00<0ZHA@0:R3C`2WPTh0
0P2VPDd00`2WPTh0Z8=?0:V4D0020:Z5D080ZHA?0`2XPdh00`2WPTd0Z7m90:QoB@080:QoB@<0ZH1:
0`2ZPD/90:^2CP80Ygi:0P2XOd/0102YP4`0ZX5=0:Z1C@2ZPDd80:QnC0030:IjB@2WNdX0ZGe<0080
Zgm>00<0ZWi=0:UmC02XO4/0202XOd/00`2YP4`0Z7m;0:QoB`020:MnBP80YWe900<0YGa80:QoB`2X
Od/01P2XOd/20:Z0D0040:UoC@2XOd/0Z7m;0:V0BP80ZX5900P0YWi10:MoA02WOd@0Z7m70:QoB@2Y
P4`0ZGm=0:Z0CP<0ZX590`2YP4P20:QoA`P0Z7m;0`2UO4@30:ImA@80Ygi6102UO4H40:AkA@80XgY6
00H0Y7]70:ImB@2XOd/0ZH1<0:Z1C@2[PTh20:QoB`<0Ygi:0`2VODT80:ElB080Ygi:0P2VODT20:El
B080Y7]70P2TNdD20:ElAP80YWe70P2WOTP20:MnBP040:ImB@2UO4P0Y7]70:AkA`80XgY6102UO4H5
0:ImA`080:MnBP2VODT0Y7]70:=jAP2RNDD0XgY60:AkA`2UO4P80:ImA`P0XGa7102VODT20:ElB080
Y7]700<0X7]60:5lA`2RODP00P2SOTT00`2RODP0X7]609mjA@030:AkA`80XgY60`2RNDD01P2QN400
XGQ20:9i@`2RNDD0XWQ60:9hB080XWM:0100XGM50:9hAP2SNDL0Y7Y80:=iA`2RN4H0X7I409me@`2O
NT<0WWU209ag@02KMSl0W7M009eh@@2ONT<0X7]40P2OMD<00`2NM480WG=109ab@00209]a?`0309Y`
?P2NM480WWA200<0WgE30`2PMT@209ei?`0409eh@@2MN4@0WGM609egBP80WGI;00T0W75409]`@`2I
KT40V6e009M/?`2HKD00VVm209]`@`2EL3/00P2EL3`00`2FL3l0UW1109MaA00209M`A@0309Q^?02I
Kcd0VW0n0080Vg4o00<0VFlm09M]>`2FK3X00P2GKC/00`2HKS`0VFlm09Y`?P0209]a?`0309ab@02J
L3h0VW0n00@0VW0n0P2KLCl809Y`?PT0UW4m0P2DJC`01P2EJSd0UV/n09M/?`2HKD00VFi109Y_@P<0
UG0l0`2FLCd209Mb?PP0Vg4o202ILd@00`2JM4D0Ug5209A^?`02095[?00309=]?P2EKd00Ug5200P0
UW110P2EJcT209I/>P80Ufdk0P2HKS`809I`@@0409Mc@`2FLT80U710095]?@80T6`l00<0TFdm099^
?P2DKSl00P2DKSl[ooooo`00:_ooool00`29GCH0RUhg08]O>00208eQ>P0408]O>02:GSL0REdf08eR
=`80S64f00<0Rf0e08YO=02:Gc@00P29GS<908eR=`0708iS>02?I3T0T6Dj08mT>@2>HcP0S64f08]P
=@0808iS>003091U>P2?I3T0SV<h0080SF8g00/0SV<h08mT>@2@ICX0T6Lc08mU<`2>I380SF<c08eR
=@2?I3T0TFHl099W?@0208mT>@<0T6Dj0`2AIS/2091S>@<0TF@j0`2BIC/9099W?080TfHl0`2BIC/3
095T>P<0U6Pk0P2EJC`309IZ?@<0Sf<f0P2@I3L3095U>0<0U6Pg0P2EJCP309IZ>@P0UF/i0`2FJST2
09M[>P<0V6`k202HKS`209U]?080V6`k0P2GJcX209IZ>@<0V6hl0P2IKcd309Y`?PP0VVhm0`2LLCh3
09]`?@X0VVll202KKch209Y^?@<0Vfln0`2LL3l809eb?`80W74n0`2JKc`00`2LLCh0WW=009md@@08
09md@@0809ad@02NMT80X7M30:9gA02TMT@0Y7A30:=c@P2SLD030:5eA0@0X7A30P2OLd800`2QMT<0
XWM40:=hA@030:=hA@030:9gA02QMT<0WgA100L0WgA1202QMT<20:=gB0040:=gAP2TNDH0Y7U60:Ej
A@80YGY3202SN4D0202XMTD0YWI50:EeA02TMT@0XgQ50:AkA`2UODT0YWi:0P2RMTD30:=gAP<0Y7Q7
00P0XWI90:=gB02SMdH0Y7Q70:EjA@2VNdH0YW]40:Mm@`P0YW]600T0[7Y90:UiB02XN4L0YWQ60:Ai
AP2UO4P0YWi:0:MoB`2YP4`00P2XOd/00`2WOTX0YWe90:ImB@020:ElB0@0ZGi;0`2ZOd`0102[P4d0
Yga90:MlB@2WO4T30:QmBP80ZGi;00<0Z7e80:UnB@2ZOdX00P2[P4/00`2YOTT0Yga70:IkAP020:Ml
B@040:QmBP2YOT/0ZGi;0:YoC080Zh1=00@0Yge;0:IlBP2VO4X0YWa:0P2UNdT20:AjB0P0Z7m;0`2U
Oe020:AnC`<0Xge>2@2TNdL20:ElB0030:AkA`2SNTH0XWU50080XGQ400<0X7M309eh@`2MN4<01P2M
N4<209ag@`0609ehA02LMd<0VgI209Ud@02FLCd0UG0l202KL4<209Q^?0d0Ufdk00D0UV`j09I[?P2E
JSd0TfPk095V>@02091U>004095V>@2BIcX0TVLj099W>P80TfPk00@0TVLj095V>@2>HcH0SF8e0P2<
Ic<208]V<P0408YU<@29I300RF@`08UT<0P0RF<d00<0R68e08MQ=026H3<00P26H3<00`27HC@0RF<f
08]U>00708YT=`0308US=P26HC@0QV4d00H0QV4d00L0Q5lb08=N<@22GC00PUd`08=N<@24Gc80QF0c
00T0QV4d2025GSD808IQ=0<0Q5lb0`25H3<208IQ=0T0Peha00H0QUda08EK<@23G340PE`b081J<`1m
FS@207]I=008081K<@21G380PUdc08=N=022GC<0PE`b07mJ<01nFBl2081K;P<0PE`_1P22GC03085L
;`80P5/^00/0P5Xc07mI<P1nF340OEL`07iH<@1oFC80PE/d089L=@25Gc80Q5ha08=M<002089L;`03
08=M<024GS40QElb0080P5/a00<0PE`b089M<`23GS@00P24GcD01025H3H0QV8b08EQ<@24H30208=O
;`0308EQ<@27Hc<0R6@d00P0Qf4d2029GS401025HC40QV8b08IR<P26HS8208MS<`80R6@d0`29I305
08YU<@0608eR=@2>HcH0SV<f08mT=`2@ICP0TFHi0P2BIcX01P2AIS/0TFHi095V>@2AIcL0TFLe095X
=080TFPb0P2BJ3H3095W=@04099X=P2DJSP0UF/i09Ia?@80UG0l00T0U6lk09=^>P2BKCT0TVdi095/
>02EK3P0UVdi09Q_>`2IL3`0102JLCd209ac?`<0Vg8n00@0W7<o09ie@@2OMT80W7<o0P2MM4001@2O
MT80X7M30:5hA02RNDD0XgY60080XgU700l0XWQ60:5gA@2QMdD0XGM50:=iA`2TNTP0YG]90:ElB02T
NdL0XgY60:9iA@2SNTH0Y7]70:ImB@2WOTX0202XOd/70:V0C0030:Z1C@2ZPD/0ZX5;00H0ZX5;0P2Y
P4`20:Z1C@<0Zh9>00@0[8=?0:b2D02/PU00[89@0P2]Pe430:j4DPP0[HQD00@0/HME0;26E02`QU@0
/8ID0`2_QE<01`2^Q580[HMJ0:f7F02]QeP0[HMF0:f8E02]R5<00P2]R5430:f8E080[8MC0`2[QU82
0:j4DP80[hEC0P2`QU@20;67E@<0/8MC0`2aR5@20;:9E@P0/HME00H0/HIK0;66F@2aQUT0/HMG0;67
E@2aR5@20;68DP040;:7E02cR5D0/hQE0;>8E@80]8UF0P2eRUL80;>>FPP0]8YH202cREL30;:8EP80
/hUG00@0]8YH0;F;F@2fS5X0]XaJ202`ReL80;>:EPP0]XaJ0P2bRED30;>:EP<0]8]G0P2bRED30;>:
EP<0]8]G0P2eS5P00`2dReL0/hYF0;:9E@020;68E0040;27D`2cRUH0/XUE0;68E080/8MC00@0/XUE
0;B;E`2eS5P0]8]G0`2cRUH30;:9E@030;68E02`ReH0/8]F00H0/8]F102`Qe<40:n6DP040:b3C`2]
Q500[HA@0:f4D0<0[XEA00<0[hIB0:b7DP2/Qe801P2/Qe880:j5D@<0[hIB0`2^QE420:f4D0<0[8MC
0`2[QU820:Z5D@060:V6CP2ZQDh0ZXE>0:b5CP2]Q4h0[X=>0P2`PTh0202/PU00[H=A0:j5D@2_QU00
[hI>0:j6B`2]QDP0[8A70P2/Qe830:f8D`040:b7DP2ZQE00ZHA?0:j5D@@0[HA@0P2/Pdl20:^2CP80
[HA@0`2/Pdl30:^2CP80ZH1<00@0ZX5=0:^2CP2/Pdl0[8=?0P2]Q50@0:b3C`T0[85>0`2]PTl30:j3
D0030:n4D@2/Pdl0[8=?00H0[8=?0P2]Q5030:b3C`<0Zh9>0`2^QDl20:f4CP<0[8==0`2^QE420:f4
D0/0[8=?202]Q500202[PTX0[8=;0:b3C@2/Pdl0[HA@0:f3D@2]Pe<0[XAD0`2[PTh30:b3C`80[HA@
202/PU020:^1C`<0ZX1>0`2YOdd20:Z0D0040:Z0CP2YP4`0ZH1<0:V0BP80Z7m7202/Pdl00`2_QU80
[XEA0:j5D@020:f4D0070:b3C`2[PTh0ZX5=0:Z1C@2]Q500[8=?0:^2CP030:Z1C@X0Zh9>00<0ZH1:
0:Z1B`2[PT`00P2/Pdd01P2[PT`0ZX5;0:V0BP2YOdd0ZX1>0:^1C`80[89@00<0Zh5?0:Z0CP2YOdd0
202]Q5080:j5D@030:V0BP2ZPD/0Zh9<0080[8==00<0Zh9<0:Z1B`2YP4X00P2[PT`20:b3C@<0[HA>
00<0[XE?0:b3C`2/Pdl00P2[PTh20:Z1C@80ZH1<0P2]Q5030:b3C`<0Zh9>00T0[XEA0:f4D02[PTh0
ZX5=0:V0C02ZPDd0Zh9>0:b3C`2[P5D00P2[P5<00`2ZP500ZX1>0:V0C0020:V0BPP0[85<202YP4`0
0`2YQ500Z8=?0:N2CP020:J1C@030:N2CP2XPdl0ZHA@00<0ZHA?0P2XPdh30:N2C@X0Z7m90`2YP4X3
0:Z1B`T0Zh9>0P2VODT30:MnBP<0Z7m;202XOT`20:MlB@030:UnB`2ZOd`0Zh1=0080ZWm<00<0ZGi;
0:QoB`2XOd/02P2XOd/20:MnBP80YWe9202XOd/00`2XOTh0ZGm?0:Z0CP020:Z1C@040:Z1B`2YP4P0
Z7m70:Mo@P80Ygm400<0Z7m70:QoB@2YP4`00P2YOdd30:Z1B`<0ZH1:0P2XOdT80:V0C0<0Ygi80`2V
ODL20:ElAP80Ygi800@0YWe70:ElAP2TNdD0Y7]50P2SNT@01P2SNTH0Y7]70:ElB02VODT0Ygi:0:V0
C080ZX5=0P2XOd/30:MnBP/0YWe90P2WOTX20:ImB@80YGa80P2TNdL20:AkA@80YGa60P2VODL20:Mn
B0030:MnBP2VODT0YWe900D0YWe9102VODL50:ElAP080:ElB02TNdL0XgY60:9iA@2SNTH0Y7]70:Im
B@2WOTX80:ImA`P0XGa70`2VODT20:ElB0<0Y7]700X0X7]60:5lA`2RODP0XWe80:=nB@2RODP0XGa7
0:1kAP2UO4P0Y7]70P2SNTH40:9iA@80XWU100@0XWU30:9iA@2RNDD0XWQ60P2RN4P02`2QMdD0XWQ6
0:=iA`2TNTP0XgU70:9hAP2PMT@0WgE309mjA@2NND@0WGQ30080W7M200<0WGQ309iiA02ONTD00P2O
MD<00`2NM480WG=109ab@00209]a?`0309Y`?P2NM480WWA200<0WgE30`2PMT@209ag@00409ag@P2L
Md<0W7I509afA`80W7I900<0WG9509aaA02JKd800`2IKT4209Y_@P0609E`>`2EL3`0UG0l09I`?`2F
L440Ug540P2GL4D00`2HKS`0VFlm09Y`?P0209]a?`0309U_?@2GKC/0UV`j00<0VFlm5@2JL3h909Ia
?@80UFXm00@0UV/n09M/?`2HKD00V6e00P2IKT4209A_>`80UG0l0`2FLCd00`2GLSh0VW0n09Y`?P06
09Y`?PT0VG=400L0Ug5209A^?`2BK3d0TF/l09=]?P2EKd00Ug5200P0UFm00P2EJcT209I/>P80Ufdk
0P2HKS`809E_@00409Mc@`2FLT80U710099^?P80TFdm0P2BKSh309A^?b_ooooo000Zooooo`0308YN
=`2;GcP0SF4j0080SV8k00<0SF4j08]O>02:GSL00P2>HcP00`2=HSL0S64f08]P=@0208YO=00308UN
<`2=HSL0SF8g00H0SF8g00<0Sf@i091U>P2AIS/00P2AIS/0102?I3T0SV<h08aQ=P2@ICX208mT>@03
08iS>02=HSL0SF8g0080S64f202>HcP0202@Ic<0SfDc08iT<P2=Hc<0SF8e08mT>@2AIS`0TVLm0P2?
I3T3091U>P<0TFHk1P2AI3X2099U>`T0TVLl00H0UFTl09AX>`2DJ3/0TfLj099V>@2AICP2091T=`<0
U6Pk0P2EJC`309IZ?@<0Sf<f0P2@I3L3095U>0<0U6Pg0P2EJCP309IZ>@P0UF/i0`2GJcX209Q/>`L0
VFdl102JKSd209U]?080V6`k0P2GJcX209IZ>@<0VFlm0`2JL3h209]a?`P0VVhm0`2LLCh309]`?@X0
VVll2P2JKSd309]_?P<0W70o2@2MLSl01P2LLCh0Vg0m09Y_?02KL3d0W74n09ic@0T0WgA100P0W7A0
09if@P2PMd<0XWM40:AfA02TM4<0Xg=20:=a@0<0XGE4102PM4<209mc@P030:5f@`2RMd@0XWM400@0
XWM400@0XGI309md@@2OM440WgA1102PMD890:5f@`80XgM800@0XgM60:AiAP2TNDH0YGY50P2UNT<8
0:AiAP080:UgAP2VMTD0YGE40:AfA02SN4D0XgY60:AlB02UODT20:5f@`<0XWM40`2SN4D20:9fA@04
0:=gAP2TNDH0YW]80:MlA`80Z7e8202VNdP0202/NTT0ZGU80:QhA`2VN4H0Y7U60:AkA`2UODT0YWi:
0P2YP4`00`2XOd/0Ygi:0:ImB@020:ElB0060:AkA`2WO4T0Yga90:QmBP2YOT/0ZWm<0P2[P4d00`2/
PDh0Yga90:MlB@060:QmBP030:QmB02YOTT0ZWm:0080Zh1;00@0ZWm:0:QmB02WO4L0Yga90P2XODX2
0:UnB`80ZWm<00@0Zh1=0:ElB02UO4P0YGa80P2TNdL30:=jAPP0Ygi:0P2WOdh30:InC@<0YGe<2@2R
NDD01P2TNdL0XgY60:=jAP2RNDD0XGQ40:1g@`80WgI200<0WGQ309ag@P2LMd800P2LMd8309]f@@08
09Ye@@2KMT80VgI209]f@P2JMD40V7<o09Ia?@2DKc/809Y_@P<0U6`i0P2EKCX309I^>`0309M]>`2F
K3X0UV`j0080UV`j0`2EJcT00`2DJC`0TfPk095V>@0308mT=`0:091U>02AIST0T6Dh091U>02AIST0
TVLj095V>@2@ICP0SV<f08aQ=0P0RF<b2028HS<00`27HC@0QV0c08EO<P0208AN<@0408EO<P27HC@0
R68e08YT=`@0RF<f0`28HSD808AO<P80Peha0`22GC0208=N<@T0Q5lb2023GS@@08AO<PT0Peha00H0
QE``08EK<@22Fc00P5/a081J<`1mFS@207]I=00307iI;`1oFS00P5/a0080PE`b00<0P5/a07iI;`1m
F2h00P1nFBd0101oFRh0P5/_085L<021G304089M<@80PE``00`0P5/_07mJ;P1nFBd0OUT]07iH<@1m
Ec00O5H_07]E;P1lERl0OEL`07mI<P20FS<3085K;P80P5X]0`21Fbh207mJ<004081K<@21G380PUdc
08=N=080Q5le00<0QF4a08AP<023Gbl00P22GRh00`23Gbl0QF4a08IR<P0808EO<PP0R5la00@0Pel_
08AP<024H300Q60`0P25HC4208IR<P80RVDa0`29I30308QS;`80S6<e00<0SF@f08iU=`2?ISP00P2@
IcT01`2AJ3X0T6Dj091U>02@ICP0T6Hf095W=@2AJ3@00P2AJ3800`2AJCH0SfLd08eU<P0208aT<@03
08mW=02AJCH0Tf/h0080UW4m00/0UG0l09=^>P2BKCT0TF`h091[=`2?JSH0UF`h09I]>@2GKSX0V6lk
09U`?00309Ya?@@0VG0l00`0VW4m09]b?P2KLSh0W7<o09Ya?@2KLSh0W7<o09ie@@2OMT80XGQ40:9i
A@2SNTH40:9hAP030:5gA@2RN4H0XWQ60080XgU700P0Y7]70:=jAP2RNDD0XGQ40:9iA@2SNTH0YGa8
0:ImB@<0Z7m;102WOTX00`2VODT0Z7m;0:QoB`020:QoB`@0ZH1<202ZPD/30:QoB`80ZH1<0`2ZPDd3
0:b2D080[H=A0`2^Q5880:f8E0@0/8ID102_QE<01P2]QeX0[HMH0:f7F02]QeH0[HQD0:f8D`80[HQA
0`2]R5@30:b7D`80ZhIB0P2^Q5820:n5D`80/8ID0P2aQeD30;27D`<0/HQD0P2bRED80;67E@060;66
F`2aQUT0/HII0;67E`2aQeD0/HQD0P2aR5820;68E0<0/XUE0`2cRUH80;B?F`P0]8YH202cREL30;67
E@060;:8EP2dRUP0]H]I0;J<FP2gSE/0^8iL202`ReL80;>:EPP0]heK1P2cRUH20;B;E`80/XUE0`2c
RUH30;B;E`030;F<F02dReL0]8]G0080/hYF0P2bRED0102aR5@0/hYF0;:9E@2aR5@20;27D`030;68
E02cRUH0]8]G00P0/hYF202`ReH40;27D`@0[hIB102/Pdl40:f4D0P0[8MB202^QE430:n6DP<0[XEA
0P2]Q5030:b7D`<0ZhIB0P2ZQE401P2YQTh0ZXE>0:Z5CP2/QDh0[HA>0:j3CP80/89>00D0[HA@0:f4
CP2]Q4h0[XE?0:j5C@030:f4C0D0[8MB00<0ZhIA0:Z5D02ZQE000P2^QE440:f4D0<0[8=?0P2]Q503
0:b3C`<0Zh9>0P2ZPDd20:^2CP80[8=?0P2]Q50@0:b3C`P0[H9?102]Q5040:j5D@h0[8=?0P2[PTh3
0:j5D@80[HA@0`2/Pdl30:j5D@80[HA@2`2/Pdl80:f4CP80[8=;00@0[8==0:b3C`2/Pdl0[89@0P2/
PU830:^2CP<0[8=?0P2]Q5080:b2D080Zh5?1P2ZP4h20:Z0D0040:Z0CP2YP4`0ZH1<0:V0BP80Z7m7
202/Pdl20:j5D@050:f4D02/Pdl0[8=?0:b3C`2[PTh00P2ZPDd20:j5D@030:f4D02[PTh0Zh9>00<0
ZX5=202[PTh20:Z1B`@0Zh9<0P2ZPD/20:Z1C@@0Zh9>0P2ZPDd20:b3C`@0[HA@0P2^QE480:f4D003
0:V0C02ZPDd0Zh9>0080[8=?00<0Zh9>0:Z1C@2YP4`00`2[PT`20:b3C@<0[HA>0P2/Pdl20:^2CP80
ZX5=0P2YP4`80:^2CP030:j5D@2]Q500Zh9>00<0ZH1<00<0ZX5=0:^2CP2[P5D00P2[P5<00`2ZP500
ZX1>0:Z1C@020:V0BPP0[85<202YP4`20:R3C`@0Yh9>0P2XPdl20:V4C`<0Z8=>0`2WPTd:0:QoB@<0
ZH1:0`2ZPD/90:^2CPH0YWe90P2WOTX80:QnC0040:MlA`2XODP0Z7e80:UnB@@0ZWm:3P2XOd/20:Mn
BPP0Z7m;00<0YWa<0:QnCP2ZP4h00P2/Pdl0102ZPD/0Z7m70:ImA@2XP4<20:R0A@030:QoA`2XOdT0
Z7m;0080Z7i<0`2ZPDd30:V0C080Z7m;2@2YP4`20:QoB`0;0:MnBP2VODT0YGa80:ElB02TNdL0ZH1:
0:QoB@2WOTP0YWe70:ElAP2SNT@00P2RND<20:AkA`060:ElB02VODT0Ygi:0:QoB`2YP4`0ZX5=0P2X
Od/30:MnBP<0YWe92P2WOTX20:ImB@80YGa80P2TNdL20:AkA@80YGa60P2VODL20:MnB080YWe90`2W
OTX30:QoB`@0YWe71@2UO4H0202TNdL0XgY60:9iA@2RNDD0XgY60:ElB02WOTX0Z7m;202VODL30:5l
A`@0X7]600<0WgY50:ImB@2VODT00P2UO4P20:AkA`80XgY60P2PNdH00`2QO4L0XWe80:9mB0030:9m
B0060:ImB@2UO4P0XgY60:9iA@2QN4@0XWU50P2SNTH04@2SNd00XWXo0:9i@@2RND<0XWU50:5hA02Q
MdD0XGM70:5gA@2RN4H0XgU70:AjB02SNDL0XWQ60:1fA02OMD<0WgY60080WWU51@2MN4@209me@`03
09id@P2MLd40W7900080Vg4o00<0VW0n09id@P2NM4800`2OMD<30:1fA00409Ye@02JMD40VWE109Ye
@@@0VWA300@0WW=609ebA@2LLD@0Vg130P2JKd8209U^@@0609E`>`2EL3`0UG0l09I`?`2FL440Ug54
0P2GL4D00`2HKS`0VFlm09Y`?P0209]a?`0309U_?@2GKC/0UV`j0080W79000@0Vg4o09Y`?P2JL3h0
VFlm0P2HKS`309]a?`@0VW0n2@2IKcd909Ia?@80UV/n0P2GK3l209Q]@080VFi10`2DKc/209E`?0<0
UW4m202IKcd809UcA00809Qb@`2GLD80UFm009=]?P2BK3d0Tfdn09E_@02FL44809A^?`80UF/k0P2F
K3`209M]?@80V6hn202EKd000`2FLT80UG5109A`@00209=_?`<0TVhn0`2DKSl[ooooo`00:_ooool0
0`2:GSL0Relh08eQ>P0208iR>`0408eQ>P2;GcP0RUhg08iS>080SF8g00<0S64f08]P=@2;H3D00P2:
Gc@808eR=`0808mT>@2@ICX0TFHk099W?02AIS/0T6Dj08iS>02=HSL2091U>P0308mT>@2>HcP0SF8g
0080S64f00<0Rf0e08eR=`2=HSL0102>HcP208eR=`08091W<`2?IC<0SV@b08eS<`2=HSD0Sf@i095V
?02BIcd208mT>@<0T6Dj0`2AIS/2099U>`H0TF@j2@2AIS/209EY>P0309AX>@2CIcP0TVHg0080TFDf
00@0T6@e09AX>`2DJ3/0U6Pk0P2EJC`309IZ?@@0TfLj0P2DJ3/209EY?0<0U6Pg0P2EJCP309IZ>@P0
UF/i0`2GJcX209Q/>`<0VFdl00<0VF/j09Y/>`2JK3/00P2KKC`209a^?@0309e_?P2IKC`0VFdl0080
V6`k0P2GJcX209IZ>@80V6hl0P2IKcd309Y`?P0309]a?`2JKSd0VVhm00H0VVhm0`2LLCh309]`?@X0
VVll2P2JKSd309]_?P<0W70o2@2MLSl01`2LLCh0Vg0m09]`?@2KL3d0WG8o09md@@2PMD80202OM440
202LM400WWI20:1g@`2RMd@0Y7I40:Ad@`2SLd80Xg500`2QMD@40:1d@`80Wg=200<0XWM40:5f@`2Q
MT<0102QMT<00`2RMd@0WgA109md@@020:1e@P030:5f@`2RMd@0XWM400T0XWM40P2SMdP0102SMdH0
Y7U60:AiAP2UNTD20:Ej@`P0Y7U600P0ZWQ70:MgAP2VMTD0Y7I40:9gA02SNTH0Xg]70:EmB@80XGI3
0`2RMd@30:=hA@080:9g@P2SN4<0Y7U40:EjA`2VNdP0Yg]:0:QlB`2YOD`80:MlB@090:ajB@2YNDP0
YgM60:EgA@2SN4D0XgY60:=kA`2TO4P0ZH1<0080Z7m;00<0Ygi:0:ImB@2VODT00P2UO4P01P2VNdP0
Yga90:MlB@2XODX0ZGi;0:YoC080Zh1=1P2XODX20:MlB@030:MlA`2XODP0ZWm:0080Zh1;00<0ZWm:
0:UnB@2XODP00P2XODX40:UnB`80ZWm<00@0YGa80:AkA`2TNdL0Y7]70P2SNTH20:9iA@P0YWe900@0
Yge;0:IlBP2VO4X0YWa:0P2UNdT20:AjB0T0XGQ40P2RNDD00`2QN4@0X7M309mf@P0209ie@@0309ed
@02LMd80W7M20080VgI100H0VWE009Ud?`2IM3l0VG@o09Qc?`2IM40209Ye@@0409Ud@02HLcl0UW4m
09A_>`P0V6e000@0T6/g095/>02AK3P0TF`h0`2BKCT01@2CKSX0UV`j09I/>P2FK3X0UF/i0080U6Xh
0P2CJCL00`2BIcX0TFHi08mT=`0308iS=P05091U>02AIST0SF8e08iS=P2?I3L00P2@ICP00`2?I3L0
SF8e08aQ=00408QR<`@0Qf4b2026H3400`27HC@0QV0c08AN<@0208=M<00308AN<@25Gc80QV0c00<0
RF<f00<0R68e08MQ=027HC@00P26H3<808=N<@H0PUd`0P21G2l808=N<@P0PUdc4023GS49089M<006
08EL<025Fc40PU/`081K<@1oFC80O5Tc0P1jF3<00`1lEbd0OEP^07iI;`02081K<@0307mJ<01mF2h0
O5L]0080OEP^00<0OUT_07mJ<020Fc400P21G382089M<`80PE`b00<0P5/a07mJ<01nFBl00P1mF2h0
201mEc00O5H_07]E;P1jE2d0NeD^07aF;`1nF340OeTb0P1oFB`4081J;@80OeT/0P1nFBl0101oFS00
P5/a085L<P22GC<208=N=00308EQ<@24H300Pel_0080PEd]00<0PUh^08=O;`24H3002024GS4808IP
<@@0Pel_0P24H30208EQ<@80RF@`0`28Hbl308MR;P0608US=02:I3D0RV@e08]U=P2<ISL0SFLh0P2>
J3T02`2>HcP0Sf@g08mT=`2@ISH0T6Hd095X=02AJ380TVTc08iY=@2<Ic<0RVDa0080RF@`00<0S6Lc
08iY=@2@JcL00P2EL3`01P2DKc/0TVdi095/>02@JcL0SfXf08iY=@<0UVdi00<0Ufhj09Q_>`2IL3`0
0P2JLCd209Q_>`80VG0l102JLCd0202IL3`0VW4m09]b?P2MM400WWE10:1g@`2QN4@0XWU50P2QMdD4
0:9hAP<0XGM500P0XgY60:9iA@2QN4@0X7M30:5hA02RNDD0Y7]70:ImB@80Z7m;0P2WOTX0102VODT0
YGa80:ElB02UO4P20:ImB@80Ygi:0P2XOd/20:V0C0P0ZH1:0P2WOTX20:QoB`<0ZH1<00@0ZX5=0:b2
D02/PU00[89@0P2]Pe430:j4DPP0[8MC102_QE<40;26E0060:f7FP2]QeP0[HMH0:f7EP2]R5@0[HQC
0P2]R5420:j9E@<0[HQD0`2/Qe<20:j4DP80[hEC0P2`QU@20;67E@<0/8MC0`2aR5@20;:9E@P0/HME
00H0/HIK0;66F@2aQUT0/HMG0;67E@2aR5@20;68DP<0/8QD0`2aRED20;::EPP0/hiJ402cREL01`2a
QeD0/XQF0;:8EP2cREL0]8YH0;F;F@2gSE/00P2hSU`80;2;E`P0/hYF202fS5X20;B;E`H0/hYF0P2b
RED30;>:EPL0]8]G102cRUH00`2dReL0/hYF0;68E0020;27D`030;68E02bRED0/hYF00@0/hYF102d
ReL80;2;EP80/HQD0P2`Qe<20:n6DP80[XEA102]Q5040:b3C`P0[HQC2`2_QU830:j5D@80[HA@0`2/
Qe<30:^6DP80ZXEA00H0ZHI>0:Z5CP2ZQDh0[8E>0:f4CP2^Pdh20;22CP<0[HA<00H0[8=;0:b3C@2]
Q4h0[HA>0:f4D02]R5<20:b7DP030:^6D@2ZQE00ZXE@0080ZXE@102^QE430:f4D080[8=?0P2]Q503
0:b3C`D0Zh9>102/Pdl20:f4D100[8=?202]PTl40:f5D@@0[8A@202/Pdl20:^2CPH0[8=?0`2^QE42
0:f4D0<0[8=?0`2^QE420:f4D0/0[8=?202]Q4`20:b3B`040:b3C@2/Pdl0Zh9>0:^1C`80Zh5A0`2[
PTh30:b3C`80[HA@202/PU020:Z0CPH0Zh5?0P2ZP500102ZP4h0ZH1<0:V0C02YP4X20:QoA`P0[8=?
0P2^QE401@2]Q500[8=?0:b3C`2[PTh0ZX5=0080ZH1<0P2^QE420:f4D0040:b3C`2[PTh0ZX5=0:V0
C0P0Zh9>0P2[PT`40:Z1B`80Zh9<0P2[PTh40:Z1C@<0Zh9>0P2/Pdl20:f4D080[XEA00<0[hIB0:f4
D02]Q5001P2]Q5000`2YP4`0ZX5=0:^2CP020:b3C`030:^2CP2ZPDd0ZH1<0080ZX5;0P2[PT`20:b3
C@80[HA>0P2/Pdl20:^2CP80ZX5=0P2YP4`80:Z1C@0>0:f4D02/Pdl0ZX5=0:V0C02XOd/0ZH1<0:Z1
C@2[PTh0[85F0:b1E02[P5<0Zh5A0:^1C`2ZPDd20:Z1B`P0[85<202YP4`20:N2CP@0Z8=?0P2WPTh3
0:R3CP<0Yh9=0P2VPD`:0:QoB@<0ZH1:0`2ZPD/90:^2CP80Ygi:1P2VODT80:QnC0@0Z7e600@0ZGi7
0:YoB02ZOdP0Zh193P2XOd/20:V0C0P0Z7m;00<0YWa<0:QnCP2ZP4h00P2/Pdl0102ZPD/0Z7m70:Im
A@2XP4<20:R0A@030:QoA`2XOdT0Z7m;0080Z7i<0`2ZPDd30:V0C080Z7m;202ZPDd20:V0C0040:Qo
B`2WOTX0Ygi:0:ImB@80YGa80P2YP4X01P2XOdT0YWe70:ElAP2TNdD0XgY40:9i@`80YGa80P2VODT0
102WOTX0Z7m;0:QoB`2YP4`20:QoB`<0Ygi:0`2VODT:0:MnBP80YWe90P2UO4P20:AkA`80Y7]50P2U
O4H20:ImA`80Ygi80P2VODT30:MnBP<0Z7m;0P2WOTP20:ImA`<0YGa60P2TNdD0202TNdL0XgY60:9i
A@2RNDD0XgY60:ElB02WOTX0Z7m;202VODL30:5lA`030:1kAP2ONTD0WgY50080WWU40`2UO4P20:Ak
A`<0XgY6102PNdH01`2QO4L0XWe80:=nB@2SOTT0YWe90:ElB02SNTH00`2QN4@04P2SNTH0Y7]70:=k
?P2SNch0Xg]00:9i@@2QN480XGQ40:1g@`2PMT@0XGM50:9hAP2SNDL0Y7Y80:=iA`2RN4H0X7I409me
@`<0WgU80P2NN4L00`2MMdH0W7I509]eA00209me@`0309id@P2MLd40W7900080Vg4o00<0VW0n09id
@P2NM4800`2OMD<30:1fA0@0VWA30`2JMD401`2JMD00WW=609icAP2NLdH0WG9509aaA02KL4<00P2I
KT401P2EL3/0UG0l09E`?02FL3l0UW1109MaA080Ug1500<0V6hl09U_?@2JL3h00P2KLCl00`2IKcd0
Ufdk09I/>P0209ec@@0409ab@02KLCl0VW0n09U_?@80V6hl0P2LLT0209]a?`0309Y`?P2IKcd0VFlm
00T0VFlm2@2FLCd209M/?`@0V6e00P2IKT4209=^>P80U6lk0P2EL3`209Ia?@P0VFlm202ILd@01@2G
LD80UW1109E_@02DKSl0Tfdn0080U6ho00<0UFm009=]?P2CKCh01P2CKCh209EZ?@80UV/n0P2GK3l2
09Q]@0P0UFm000@0U71009Ea@@2ELD40UG510P2DL40209=_?`<0U6ho:oooool002[ooooo00<0REdf
08YN=`2;GcP00P2=HCX00`2;GcP0RUhg08UM=P0808]P=@P0SF8g0P2?I3T3095V>`0408mT>@2=HSL0
S64f091U>P80Sf@i00<0SV<h08eR=`2=HSL00`2<HCH00`2=HSL0SV<h08iS>00208iS>00:08eR=`2<
HCH0T6Lc08mU<`2>I380SF<c08eR=@2?I3T0TFHl099W?@80Sf@i0`2@ICX3095V>`<0TVDk0`2AI3X2
091S>@T0TFHk0`2DJ3L309=W=P80TVHe0`2DJ3/209EY?0<0UVXm0`2EJC`209IZ?@<0Uf/n0`2DJ3L2
09EY>0<0UVXi202EJcT309IZ>@80Uf/j0`2HK3/01P2HJ3P0VFTi09UY>@2JJSX0Vf/k09a/?080WFdm
0P2IKC`209Q/>`80Uf/j0P2FJST309M]>`80V6hl0`2IKcd809Y^?@<0W74n0`2KL3d:09Y_?0P0VFdl
0P2JKSd309]_?P<0W70o202MLSl0202NLd00WG8o09aa?P2KL3d0W74n09eb?`2OM440X7E2202OM440
202LM400WWI20:1g@`2RMd@0Y7I40:Ad@`2SLd80Xg500`2QMD@40:1d@`80Wg=200<0XWM40:5f@`2P
MD800`2PMD800`2QMT<0XWM409md@@020:1e@P030:5f@`2RMd@0XgQ50080Y7U6202RMd@20:=gB004
0:=gAP2TNDH0Y7U60:EjA@80YGY3202UNTL0202[NDP0Z7Q70:IfA@2TMT@0XWM40:9iA@2SNdL0Y7a8
0P2RMd830:=h@`<0Y7U400P0Y7Y00:Ai@P2UNTD0YW]60:IjB@2WNdX0Z7a=0:QlC`P0Yg]:00P0[7Y9
0:UiB02WMdH0YGM50:=hA@2RNDD0XWY60:=kA`P0Ygi:00@0Yga90:QmBP2XODX0Z7e:1P2YOT/30:Qm
BP<0Yga900<0YW]60:MlA`2YOTT00P2[P4/00`2ZOdX0ZGi90:QmB0080:UnB`<0YGa60P2TNdD30:=j
A0P0YGa80`2UNTL20:AiAP<0XgQ52@2PMd<01P2QN4@0X7M30:1g@`2OMT80WWE109ed@080W7<o0P2K
MT40102JMD00VG@o09Qc?P2HLch209Mb?@0309Mb?P2HLcl0VGA00080VGA000<0Ug8n09E`?02DKc/0
202GK3l808m[=`80UV`j00@0UF/i09AZ>02CJCL0TfTg0P2BJ3H00`2@ICP0Sf@g08iS=P0208aQ=006
08eR=@2?I3L0T6Dh08]P<`2<HC@0SV<f0P2?I3L0102>HcH0S64d08]P<`28HSD208MQ=080QV0c0`25
Gc8808EO<00308QR=@27HC@0QElb0080Ped`00<0Q5ha08EO<P26H3<00P29HcH01028HSD0Qf4d08IP
<`26H3<208EO<PX0PE`_0`22GC000`21G2l0OeX]07mJ;@08085L;`P0OU/a2021G2l308=N<@<0PUd`
0P21G2l9089M<00608AK;`24FS00PEX_081K<@1oFC80O5Tc0P1jF3<00`1jEB/0NeH/07eH;P0307iI
;`0307eH;P1lEbd0OEL`00<0OUPa201oFC8307iH<@80OEL`00T0O5H_07]E;P1jE2d0NeD^07aF;`1n
F340OeTb07iH:`1oFB`01020FRd00`1oFB`0OUP[07eH;P0207iI;`0307mJ<020Fc40PE`b0080PUdc
00P0QF4a08AP<022GRh0PEd]081L;021GBd0PUh^08=O;`P0PU`_2024H30308=O;`80Q60`0`25HC48
08MR;P80R6@d00<0RFDe08YV=P2;IcL00P2<J3P01`2=JCT0SF8g08iS=P2>HcH0SfDe091V=02AJ3@0
0P2BJC<208]W<`<0RVHb00<0S6Pd08eY=@2>JSH00P2CKSX0102BKCT0TF`h091[=`2@JcL208mZ=P80
UVdi0P2EK3P0202FKCT0V6lk09Ya?@2KLSh0Ufhj09Q_>`2IL3`0VW4m0P2KLSh01`2JLCd0VG0l09U`
?02JLCd0Vg8n09ac?`2MM4000P2OMT80302PMd<0XGM50:5gA@2QMdD0XWQ60:=iA`2RN4H0XGM50:1f
A02OMD<0XWU50:5hA0<0X7M300@0XWU50:=jAP2UO4P0Z7m;0P2WOTX00`2VODT0YGa80:AkA`020:=j
AP060:AkA`2UO4P0YGa80:ImB@2WOTX0Z7m;0P2YP4`80:V0BP<0Z7m;0P2YP4`30:Z1C@<0[89@0P2]
Pe430:j4DPP0[8MC00@0[XAB0:n5D`2_QE<0[hEC0`2`QU@01`2aQeD0[HMJ0:f7F02]QeP0[HMF0:f8
E02]R5<00P2]R5430:j9E@80[HQD0`2/Qe<20:j4DP80[hEC0P2`QU@20;67E@<0/8MC0`2aR5@20;:9
E@P0/HME00H0/8EJ0;25F02`QEP0/8IF0;26E02`Qe<20;27D@80[HQC0P2^RE@30:n:E@030;2;EP2b
SET0/XeI00H0/XeI4`2cREL0102dRUP0]H]I0;J<FP2fS5X20;N=F`P0/8]G202cRUH80;F;F@<0]8]G
0`2cRUH40;:9E@<0/hYF2`2dReL00`2eS5P0]8]G0;:9E@020;27D`030;68E02bRED0/hYF00<0/hYF
0P2dReL30;F<F0P0/8]F00D0/XUE0;68E02aR5@0/8MC0:n6DP020:j5D@030:f4D02_QU80[XEA0080
[XEA0`2]Q5000`2/Pdl0[HQC0:f8D`060:f8D`/0[hIB0`2^QE420:f4D0<0[8MC0`2[QU820:Z5D@06
0:V6CP2ZQDh0ZXE>0:b5CP2]Q4h0[X=>0P2`PTh0302^QTT0[HE80:b4B@2[PTX0Zh9<0:b3C`2]Pe40
[XAB0:f8D`2/Qe80ZhIA0:Z5D080ZHA?00@0ZXE@0:^6D@2_QU80[hIB0`2^QE430:f4D0030:b3C`2]
Q500[HA@00<0[8=?0`2[PTh50:b3C`<0[HA@402/Pdl80:f2C`040:^6D@2ZQE00ZXE@0:Z5D0<0ZHA?
00<0Z8=>0:^2CP2[PTh02@2[PTh30:b3C`80[HA@0`2^Q5820:f3D@<0[89@0`2^QE420:f4D0/0[8=?
202]QDX20:b3B`040:b3C@2[PTh0Zh9>0:Z0CP80ZX1@0`2[PTh30:b3C`80[HA@202/PU020:Z0CP<0
Zh5?0`2/PU020:Z0D0040:Z0CP2YP4`0ZH1<0:V0BP80Z7m7202/Pdl20:f4D0<0[8=?00H0Zh9>0:Z1
C@2YP4`0ZH1<0:b3C`2]Q5030:j5D@030:b3C`2[PTh0ZX5=00P0Zh9>00<0[8==0:^2C02ZPD/00P2Y
P4X01P2ZPD/0Zh9<0:b3C@2/Pdd0Zh9<0:Z1B`80ZH1:00<0ZX5;0:^2C02/Pdd00P2[PTh0102/Pdl0
[HA@0:f4D02^QE420:n6DPP0[8=?00<0ZGm=0:Z0CP2[PDl00P2/PU000`2[PDl0ZX1>0:UoC@030:Z1
B`80Zh9<0`2/Pdd20:b3C`80Zh9>0P2ZPDd20:V0C080Z7m;0`2YP4`30:Z1C@030:f4D02/Pdl0ZX5=
00<0Z7m;0P2ZPDd01P2/PEH0[85D0:b1E02[PE40Zh5?0:Z1C@80ZX5;202/PD`80:V0C0030:J1C@2W
PTh0Z8=?0080ZHA@00<0Z8=?0:N2CP2VPDd00`2XPdh20:N2C@<0YX5<2P2XOdT30:V0BP<0ZX5;2@2[
PTh30:QoB`<0Ygi:0P2VODT80:QnC0060:UoA@2XOT@0Z7i40:Mm@`2XOT@0ZGm50P2[PDL<0:QoB`80
ZH1<0P2ZPDd80:QoB`030:QnCP2YOdl0ZX1>0080ZX5=00@0ZX5;0:V0B02XOdL0ZH540P2YPDH00`2X
OdL0Z7m90:MnBP020:MmB`<0ZX1>0`2YOdd20:QnC0P0ZX5=102XOT`30:MmB`030:IlBP2XOdT0Z7m9
0080Ygi800D0YWe70:ElAP2TNdD0Y7]50:ElB0030:ImB@030:MnBP2XOd/0Z7m;00<0Z7m;0`2WOTX;
0:ImB@80Ygi:0P2VODT20:ElB080Y7]70P2TNdD20:ElAP80YWe70P2WOTP00`2WOTX0YWe90:ImB@05
0:ImB@050:QoB@2WOTP0Ygi80:ImA`2UO4H00`2TNdD02@2SNT@0YGa80:AkA`2SNTH0XWU50:=jAP2T
NdL0YWe90:MnBP080:ImA`060:9mB02QO4L0XGa70:1kAP2ONTD0WWU40P2MN4<20:ElB080Y7]70`2S
NTH0102RNDD0X7]60:1kAP2ONTD20:1kAP060:9mB02TOdX0YH1;0:MnBP2UO4P0XWU50P2PMd<00`2Q
N4@0XgY60:ElB0020:Al?P030:=k?P2RNSl0XGQ00080X7M100T0WgI20:5gA@2RN4H0XgU70:AjB02S
NDL0XWQ60:1fA02OMD<0102ONDX0102NN4T0WGM809]eAP2JM4D209me@`0309id@P2MLd40W7900080
Vg4o00<0VW0n09id@P2NM4800`2OMD<30:1fA080W7I900@0W7I709afA@2LMd<0W7M20P2LMd0409md
A`0509ebA@2KL4<0VFi109Q]@02EL3/00P2EL3`00`2FL3l0UW1109MaA00209M`A@0309Q^?02IKcd0
VW0n0080Vg4o00<0VFlm09M]>`2FK3X00P2MLd40102LLT00Vg4o09]a?`2JL3h209U_?@0609ec@@2L
LT00W79009]a?`2JL3h0VFlm2P2HKS`909Ia?@D0V6e00`2IKT4309=^>P80U6lk0`2EL3`809Q^?0P0
VG=40P2FL4400`2EKd00U6ho09A^?`0309A^?`P0TV`m0P2EJSl209I[@080Ufa10P2HKD8809A^?`03
09=_?`2DL400UG510080UW9200<0UG5109A`@02CKcl00`2DKSl[ooooo`00:_ooool00`27Fc@0REdf
08YN=`0208]O>00308YN=`29GCH0Qe/d0080Qe`a00<0R5db08UN<`2:Gc@00P2;H3D00`2<HCH0SF8g
08eR=`0708eR=`0708iS>02?I3T0T6Dj091U>P2>HcP0S64f08]P=@0508iS>0<0SF8g00<0Rf0e08aQ
=P2>HcP00P2?I3T02`2>HcP0S64f08]P=@2@Ic<0SfDc08iT<P2=Hc<0SF8e08mT>@2AIS`0TVLm0080
Sf@i0`2@ICX3095V>`80TfHl0P2BIC/0102AI3X0T6<i091S>@2@HcT9091U>P@0TfLf102DJ3L309AX
>`80UFTl0`2FJSd309AX>`80UFTl0`2FJSd309AX=`80UFTh0`2FJST809E[>@80U6Pg0P2EJCP209IZ
>@80Uf/j0P2FISH01P2GIcL0V6Ph09UY>@2JJSX0Vf/k09a/?080VFdl0P2HK3/209M[>P80UVXi0`2E
JcT209I/>P<0Ufdk202JKSd309aa?P<0Vg0m2P2JKc`809U]?080VVhm0`2KKch309a`?`P0WG8o00P0
WW=009eb?`2LLCh0Vg0m09aa?P2MLSl0WgA10:5f@`P0WgA100P0W7A009if@P2PMd<0XWM40:AfA02T
M4<0Xg=20:=a@0<0XGE4102PM4<209mc@P030:9gA02QMT<0X7E20080WgA100T0X7E20:5f@`2RMd@0
WgA10:1e@P2QMT<0XWM40:=hA@2TNDH00P2UNTL80:=hA@80XgM800@0XgM60:AiAP2TNDH0YGY50P2U
NT<80:EjA`080:]iB02XN4L0YgM60:AfA02RMd@0XWU50:9jAP2SNdL30:Ai@P<0YGY30P2VNd@0202V
O400YWa20:IkA02VNdH0YWY90:IjB`2WNdh0YgY@202XO4d01P2]NdX0ZGU80:MgAP2UMdD0XWM40:9i
A@80XWY600H0Y7]70:ElB02UO4P0YWe90:MnBP2XOd/20:V0C0<0ZGi;0P2XODX30:MlB@<0ZGi;00<0
Z7e:0:MlB@2WO4T00P2VNdP0102VNdH0Yga70:UnB@2ZOdX20:^0B`030:YoBP2YOTT0ZGi;00L0ZGi;
0`2VODD30:ElA080Y7]3202UO4P0102UMd<0Y7I20:Af@P2TMT820:=e@@80XWA02@2OMT801P2PMd<0
WgI209mf@P2NMD40WGA009ac?`80Vg8n00H0VgI109Ye@02JMD00V7<n09Mb?@2FLC`209E`>`0309E`
?02FLCd0V7<o0080V7<o00<0Ug8n09E`?02DKc/0202FJch208i]>080SF`g00@0S6/f08]Z=@2:JC@0
RVTd0P2FK3X02@2EJcT0U6Xh09=Y=`2BJ3H0TFLe091V=02?I3L0SV<f08aQ=00208]P<`0608eR=@2>
HcH0Sf@g08YO<P2;H3<0S64d0P2>HcH02@2=HSD0S64d08]P<`29HSL0R64f08MP=@26Gc@0Q5db08=L
<@02089K<0P0Q5h_00<0RF<f08QR=@26H3<00`24GS402P25Gc80QV0c08US=P29HcH0R68e08MQ=026
H3<0QElb08AN<@23GC09081K;P07085L;`22GC00PUd`089M<020Fbh0OUT/07eH:`08081K;PP0O5/`
2020Fbh208=N<@80PUd`0P21G2l2081K;PT0PE`_0140Q5/_08AJ<021FRl0OeX`07iH<@1kF380NUPc
07UG<P1hDbT0NE@Z07]F;01mF2h0OUT_07eH;P1lEbd0NeH/07mI=00307iH<`P0OELb0`1nF3<0301o
FC@0OUPa07eG<01lERl0NeD^07aF;`1mEc00OeTb081J<`1nF2/0OeT/081J;@80PU`_00<0P5X]07mI
;01nF2/00P1mF2h207iI;`0<07mJ<020Fc40PE`b085L<P25HC40Q60`089N;P20G2`0Oe/[081L;021
GBd0PUh^2021Fbh8089P<00408=O;`24H300Q60`08AP<080QF4a0P26HS8208AO:`0408EP;026HBd0
Qf8^08MR;P80R6<_0P26I3@208MU=@0:08QV=P29IcL0RVPh08YX>02<HCH0SF8e08iS=P2?ICD0T6Hd
095X=080TVTc00D0R6Lb08UX<`2:JC@0RfXe08a[=P0208]Z=@0308YY=02@JcL0T6/g00H0T6/g00/0
UVdi09E/>02EK3P0U6/g09E/>02GKSX0VW4m09]b?P2GKSX0V6lk09Ya?@0309ac?`0309Ya?@2IL3`0
VW4m0080Vg8n0P2LLcl309ed@080X7I400X0XGM50:9hAP2SNDL0XWQ60:5gA@2OMD<0WG=10:9iA@2Q
N4@0X7M30P2OMT802@2QN4@0XgY60:AkA`2XOd/0Ygi:0:ImB@2UO4P0Y7]70:=jAP020:9iA@050:=j
AP2TNdL0Y7]70:ElB02WOTX00P2XOd/00`2YP4`0Z7m90:QoB@060:QoB@80ZH1<0`2ZPDd30:^2CP<0
[89@0P2]Pe430:j4DPP0ZhIB0P2^Q5820:n5D`80/8ID0P2aQeD01P2]QeX0[HMH0:f7F02]QeH0[HQD
0:f8D`80[HQA0P2_RUH20:j9E@<0[HQD00<0[8MC0:j4DP2^Q5800P2_QE<20;26E080/HME0`2`Qe<3
0;68E080/XUE202aQeD01P2`QEX0/8EH0;25F02`QUH0/8ID0;27D`80/8MA0`2]R5<20:j9E0<0[hYE
202`ReL80;:8EPP0/hUG1@2eReT40;J<FPP0/8]G202cRUH80;>9E`80]HaH0P2dReL00`2cRUH0/XUE
0;:9E@030;:9E@<0/hYF202dReL40;F<F0030;B;E`2bRED0/HQD0080/8MC00<0/HQD0;:9E@2cRUH0
0P2cRUH00`2dReL0]HaH0;F<F0020;J=F@P0/8]F0P2bRED0102aR5@0/8MC0:n6DP2^QE420:f4D003
0;68E02`Qe<0/8MC0080[hIB0P2^QE400`2]Q500[XUD0:j9E0060:j9E0/0[hIB0`2^QE420:f4D0<0
[8MC0`2[QU820:Z5D@060:V6CP2ZQDh0ZXE>0:b5CP2]Q4h0[X=>0P2`PTh0402^QTP0[HE70:^3AP2Z
PDT0ZX5;0:^1C`2]Pe<0[XAD0:f8D`2/Qe80ZXE@0:V4C`2XPdh0ZHA?0:Z5D02[QU440:n6DP80[XEA
1@2]Q5030:b3C`<0Zh9>1P2]Q50B0:b3C`P0[X=@00<0ZXE@0:V4C`2YQ4l00P2XPdh20:N2C@030:J1
C02[PTh0Zh9>00H0Zh9>0P2ZPDd20:^2CP040:b3C`2]Q500[HA@0:f4D0<0[XAD0P2]Pe<30:b2DP<0
[XEA0P2]Q50;0:b3C`P0[HE:0P2/Pd/0102/Pdd0Zh9>0:Z1C@2ZP4h20:UoC`<0Zh9>0`2/Pdl20:f4
D0P0[89@0P2ZP4h20:^1C`80[89@0P2]Pe420:Z0D0040:Z0CP2YP4`0ZH1<0:V0BP80Z7m7202/Pdl2
0:f4D0040:b3C`2[PTh0Zh9>0:Z1C@80ZH1<00@0Z7m;0:Z1C@2[PTh0[HA@0P2_QU800`2^QE40[HA@
0:b3C`080:^2CP030:b3C@2[PT`0ZX5;0080ZH1:00H0ZX5;0:^2C02/Pdd0[8=;0:^2BP2ZPDT20:V0
B0040:Z1B@2[PTX0[8=;0:Z1C@80Zh9>00D0[8=?0:j5D@2_QU80[hIB0;27D`080:b3C`030:UoC`2Z
P500Zh5A0080[89B00<0Zh5A0:Z0D02YOdl0102ZPD/20:^2C080[8==0P2/Pdl20:^2CP80ZX5=0P2Y
P4`20:MnBP80Z7m;0P2YP4`20:Z1C@0@0:b3C`2[PTh0ZH1<0:QoB`2WOTX0Z7m;0:V0C02ZPDd0[H9G
0:f2E@2/PE@0[89B0:^1C`2[PTh0Zh9<0:Z1B`P0[85<202YP4`00`2VPDd0Yh9>0:R3C`020:V4D004
0:R3C`2WPTh0YX5=0:R3CP<0Yh9=0P2VPD`20:F0B`X0Z7m90`2YP4X30:Z1B`T0Zh9>0`2ZPDd00`2Y
P4`0Z7m;0:QoB`020:MnBPP0Z7i<00<0ZX160:UoA@2XOT@00P2WOD<00`2YOdD0Zh570:b2B0080:Qo
B`030:MnBP2XOd/0Z7m;0080ZH1<0P2ZPDd00`2[PTh0Z7m;0:QoB`060:QoB`80ZX1@00@0ZGm=0:Qo
B`2XOd/0ZH1:0P2ZPDT0202ZPTD0ZH560:V1AP2XOdL0Z7m90:MnBP2WOD/0YWa:0`2ZP5030:UoC`80
Z7i>202ZPDd30:MmC@<0Z7i>0P2YOdl40:MnB0@0YWe70`2VODT40:MnBP<0Z7m;0`2WOTX30:ImB@P0
YGa80P2WOTX20:ImB@80YGa80P2TNdL20:AkA@80YGa60P2VODL20:MnB080Ygi:00@0YWe90:ElB02T
NdL0Y7]70P2SNTH20:QoB@030:MnB02VODL0YGa60080Y7]50P2SNT@0202WOTX0YWe90:AkA`2SNTH0
XWU50:=jAP2TNdL0YGa8202VODL01@2RODP0XGa70:5lA`2PNdH0WWU40080WGQ300@0W7M20:AkA`2T
NdL0Y7]70`2SNTH20:9iA@80X7]60P2ONTD04P2PNdH0XWe80:AoBP2VPD`0Z7m;0:ImB@2RNDD0X7M3
09mf@P2QN4@0Y7]70:ImB@2UOSd0Y7`n0:=k?@2RNSd0XGTn0:1g?`80WgI000X0XGM50:9hAP2SNDL0
Y7Y80:=iA`2RN4H0X7I409me@`2NN4T0WgU:0P2PNT/0102ONDX0WGM809YdA@2ILd@209me@`0309id
@P2MLd40W7900080Vg4o00<0VW0n09id@P2NM4800`2OMD<30:1fA080WGI;00@0WGM:09egAP2MN4@0
WGQ10P2MNCl20:1eB0070:5fB@2PMDP0WgA709aaA02IKT40V6e009E`>`0209E`?00309I`?`2FL440
Ug540080Ug1500<0V6hl09U_?@2JL3h00P2KLCl00`2IKcd0Ufdk09I/>P0309ab@0D0Vg4o0P2MLd40
1P2LLT00Vg4o09Y`?P2IKcd0V6hl09M]>`P0V6hl2@2FLCd609U^@@80V6e0102CKSX209A_>`80UG0l
202GKC/809UcA080UW110`2EKd0209A^?`0309=]?P2AJc`0TF/l00H0TF/l0P2EJT0209I[@@80Ufa2
0P2HKD<809A^?`03099^?P2DL400UG510080Ug=300<0UW9209A`@02CKcl00`2DKSl[ooooo`00:_oo
ool00`26FS<0Qe/d08UM=P0208YN=`0908UM=P27Fc@0QUXc08AI;P25FRl0QU/`08ML<@29GS<0Rf0e
0080S64f2P2=HSL308mT>@0308eR=`2;H3D0RUld0080SF8g1P2>HcP00`2:Gc@0S64f08eR=`0208mT
>@0;08eR=`2<HCH0RUld091W<`2?IC<0SV@b08eS<`2=HSD0Sf@i095V?02BIcd00P2?I3T3091U>P<0
TFHk0P2CIS`2099U>`04095T>P2@HcT0T6<i08mR>0T0T6Dj00H0TFHc099W=02BIc@0TfPe09AY=P2E
JSL209I[>0<0U6Pk0P2EJC`309IZ?@<0TVHi0P2CIcX309AX>`<0U6Pg0P2EJCP309IZ>@P0UF/i0P2C
IcH209AX=`<0UFTh00T0UVXi09IS=02GI3D0V6Df09UV=`2JIcP0VfPi09aY>P2MJS/00P2IKC`209Q/
>`80Uf/j0P2FJST309AZ>0<0UF/i0P2FK3X809Y^?@<0W74n0`2KL3d:09Y_?0P0VFdl0P2JKSd309]_
?P<0W70o202MLSl00`2NLd00WG8o09aa?P0209aa?P0309ic@02OM440XGI300P0WgA100P0W7A009if
@P2PMd<0XWM40:AfA02TM4<0Xg=20:=a@0<0XGE4102PM4<209mc@P030:=hA@2QMT<0WgA10080WW=0
00<0WgA10:5f@`2SN4D00P2PMD801P2QMT<0XWM40:=hA@2TNDH0YGY70:IkB0P0XgQ50P2SMdP0102S
MdH0Y7U60:AiAP2UNTD20:Ej@`P0YGY700P0ZgU80:QhA`2WMdH0Y7I40:9gA02RNDD0XWY60:=kA`<0
YGY30`2VNd@20:MlA@080:Qo@@2WOD40Yge30:MlA`2VNTT0YWY=0:IiC`2UN4l80:QlC@080:ekBP2Y
NDP0YgM60:EgA@2RMd@0XGQ40:5iA@2RNTH20:=jAP060:AkA`2VODT0Z7m;0:V0C02ZPDd0Zh9>0P2Z
Od`0102YOT/0Z7e:0:MlB@2WO4T20:IkB0040:YoC02YOT/0ZGi;0:QmBP80Yga90P2VNdP0102UNTD0
Yga70:UnB@2ZOdX20:^0B`040:YoBP2YOTT0ZWm<0:YoC0@0ZGi;0P2XODX30:MnAP80YWe50`2UO4@8
0:AkA`<0XgE10P2RM4030:5c?`T0WWE10P2OMT800`2NMD40WGA009ac?`0209]b?P0<09Ya?@2JMD00
VWE009Ud?`2HLch0Ug8m09Ia?02EL3/0U6lj09E`?02FLCd0Ug8n0P2HLcl00`2GLSh0UG0l09A_>`08
09EZ?@80Sfhi00L0SVdh08a[=P2;JSD0RVTd08UX<`28Ic80UV`j0080UF/i00<0TfTg099X=P2AIcD0
0P2@IS@00`2>HcH0SF8e08]P<`0208]P<`0608aQ=02>HcH0Sf@g08UN<@2:Gc80S64d0P2=HSD00`2<
HC@0Rf0c08YO<P0208UR=`0608MP=@26Gc@0Q5db089K<021FRl0P5T^2023GBh01P2:I3L0RF<f08MQ
=025Gc80Q5ha08EO<P80QV0c00H0RF<f08QR=@28HSD0QV0c08EO<P24GS4208=M<0P0P5/^00<0OeX]
081K;P22GC000P22GC000`20Fbh0OEP[07aG:P08081K;PP0O5/`2020Fbh208=N<@04089M<021G2l0
PE`_081K;P80OeX]2@21G2l01P24Fbl0Q5X`085J;`1oFS00OUPa07]H<P80NELb00@0Me8X07QC:@1k
ER`0O5L]0P1mF2h00`1lEbd0NeH/081J=@0207mI=00307iH<`1mEc80O5Ha00@0NeD`00<0O5Ha07eG
<P1nF3<00P1oFC@00`20FSD0OUPa07iH<@0307aF;`0607iH<@20FS<0PE/d07iH:`1oFB`0PE/^0P22
G2l01021Fbh0OeT/07iH:`1lEbd207eH;P0307iI;`1oFS00P5/a0080PE`b00@0QF4a08=O;`21GBd0
P5`/0P1oFb/00`20G2`0PEd]085K;P07085K;PP0PV0`0P24H30208EQ<@<0QV8b00L0Qf<c089M:@23
GRX0Q5l[08EP;027HRh0R6<_0080RF@`00H0QF<c08IT=026I3@0QfDe08QV=P29IcL208YX>00608aQ
=P2<HC@0SF8e08iT=02@IS@0TFPd0P2BJC<00`27IS40RFPc08]Z=@0208i]>00308e/=`2;JSD0RFPc
00<0SfXf0`2@JcL2095/>00;09I]>@2EK3P0U6/g09A[=`2EK3P0Ufhj09Ya?@2KLSh0Ufhj09U`?02K
LSh00P2MM4000`2LLcl0Vg8n09Ya?@0309]b?PD0W7<o0P2PMT@02@2QMdD0XgU70:=iA`2RN4H0X7I4
09id@P2LLT00XGQ40:1g@`0309mf@P030:5hA02RNDD0Y7]70080Ygi:00h0YWe90:ElB02TNdL0XgY6
0:9iA@2QN4@0XWU50:=jAP2TNdL0YGa80:ImB@2WOTX0Z7m;0:V0C0P0Z7m90`2ZPDd20:^2CP<0[8=?
0`2/PU020:f3D@<0[XAB202[QU830:j4DP030:n5D`2`QU@0/HME0080/HME00H0[HMJ0:f7F02]QeP0
[HMF0:f8E02]R5<20:f8D@80[hYF0P2^RED40:f8E080[XAB0P2_QE<20;26E080/HME0`2`Qe<30;68
E080/XUE202aQeD01P2`QEX0/8EH0;25F02`QUH0/8ID0;27D`80/8MA0`2/RE<30:f:E080[X]E202_
RUH80;:8EPP0/hUG0`2gSE/30;J<FP<0]H]I202`ReL80;>:EPP0/XQF0P2eS5P20;B;E`040;>:EP2b
RED0/XUE0;68E080/XUE0`2cRUH70;B;E`@0]HaH00@0]XeI0;B;E`2bRED0/HQD0P2`Qe<00`2aR5@0
/XUE0;>:EP020;>:EP030;B;E`2eS5P0]XeI0080]XeI202`ReH0202cRUH0/XUE0;68E02`Qe<0[hIB
0:j5D@2]Q500[8=?0P2bRED0102aR5@0/8MC0;27D`2_QU820:j5D@P0[XUD2`2_QU830:j5D@80[HA@
0`2/Qe<30:^6DP80ZXEA00H0ZHI>0:Z5CP2ZQDh0[8E>0:f4CP2^Pdh20;22CP0;0:j7AP2]QDL0Zh=6
0:Z1B@2ZPDd0Zh5?0:f3D`2^PeH0[HQC0:b7DP2ZQE000`2XPdh00`2ZQE00ZhIA0:n6DP030:n6DP<0
[XEA102]Q5030:b3C`<0Zh9>0P2^QE440:f4D180[8=?202^Pe020:R5C`040:N4CP2VPdd0YX==0:F2
C080Y85;202[PTh20:Z1C@80Zh9>00@0[8=?0:f4D02]Q500[XEA0`2^Q5@20:f3D`<0[89B0`2^QE42
0:f4D0/0[8=?202]QDP20:b3B`040:b3C@2[PTh0ZX5=0:UoC@80ZGm?0`2[PTh30:b3C`80[HA@202/
PU020:Z0CP80Zh5?00@0[89@0:f3D@2]Pe40[XAB0P2ZP500102ZP4h0ZH1<0:V0C02YP4X20:QoA`P0
[8=?0P2]Q5001@2/Pdl0Zh9>0:^2CP2ZPDd0ZH1<00<0Z7m;00L0ZX5=0:f4D02_QU80/8MC0:n6DP2^
QE40[HA@00P0Zh9>00<0[HA>0:^2C02ZPD/00P2XOdT01P2ZPD/0Zh9<0:f4CP2]Q4`0Zh9:0:Z1B@80
Z7m700<0ZX590:^2BP2]Q4`00P2ZPDd0102[PTh0[8=?0:j5D@2_QU820;27D`P0[8=?00<0ZGm?0:Z0
D02[PE400P2/PU80102[PE40ZX1@0:UoC`2YP4X30:Z1B`80Zh9<0P2/Pdd20:b3C`80Zh9>0P2ZPDd2
0:V0C080YWe900@0Ygi:0:QoB`2XOd/0ZH1<0P2ZPDd03P2/Pdl0Zh9>0:V0C02XOd/0Ygi:0:QoB`2Y
P4`0ZX5=0:f2E`2]PUD0[85D0:b2DP2[PDl0Zh9>0P2[PT`80:b1C0P0ZH1<00<0YH1<0:N2CP2XPdl0
0P2ZQE400`2XPdl0Yh9>0:F0C0040:N2C@80YX5<0P2UP4/:0:QoB@<0ZH1:0`2ZPD/90:^2CP040:b3
C`2[PTh0Zh9>0:Z1C@80ZH1<0P2XOd/80:QnC0030:Z0A02YOd<0Yge10080Yge100<0ZGm30:^1A@2/
PTH0202XOd/0102WOTX0Z7m;0:QoB`2YP4`20:Z1C@80Zh9>202XOd/00`2/PU80ZX1@0:QnC0020:Im
B@090:QoB@2ZPDT0[8=;0:Z2A@2ZPTL0ZH560:QoA`2XOdT0Ygi:0080YWa:0`2ZP5030:UoC`80Z7i>
202ZPDd20:IlC0040:MmC@2XOTh0Z7i>0:UoC`80ZX1@0`2VODL30:MnB080Z7m90`2VODT50:MnBP80
Z7m;0`2WOTX30:ImB@P0Y7]70P2WOTX20:ImB@80YGa80P2TNdL20:AkA@80YGa60P2VODL20:MnB080
Ygi:00/0YWe90:AkA`2SNTH0XWU50:5hA02PMd<0ZH1:0:QoB@2WOTP0YWe70:ElAP020:AkA@060:=j
A02RND<0Z7m;0:MnBP2UO4P0XgY60P2RNDD00`2SNTH0Y7]70:ImA`070:ImA`060:9mB02QO4L0XGa7
09mjA@2NND@0WGQ30P2LMd830:AkA`80XgY60`2RNDD20:1kAP0909mjA@2NND@0X7]60:9mB02UP4/0
Yh9=0:QoB`2VODT0XWU50080WgI201D0XGQ40:AkA`2VODT0YGhm0:Am?02TO3h0XWXm0:5i?P2PMcl0
WgHn09mf@02QMdD0XWQ60:=iA`2TNTP0XgU70:9hAP2PMT@0WgE309ihB`2OND`00P2PNTd0102OND`0
WGM:09YdA`2HLTD209me@`0309id@P2MLd40W7900080Vg4o00<0VW0n09id@P2NM4800`2OMD<30:1f
A00909igCP2NMd`0WWQ;09ihA`2NND@0WWU209ij@02NNSh0X7E800<0XGI900D0WgA709aaA02IKT40
Uf`o09E`>`0209E`?00309I`?`2FL440Ug540080Ug1500<0V6hl09U_?@2JL3h00P2KLCl00`2IKcd0
Ufdk09I/>P0409]a?`@0W7900P2MLd400`2LLT00Vg4o09Y`?P0209Q^?00309M]>`2HKS`0V6hl00H0
V6hl2@2FLCd209Y_@P@0VFi10P2HKD00102BKCT0Tfhj09=^>P2CKSX209A_>`80UG0l202GKC/809Uc
A0<0UW110P2EKd0209A^?`0309=]?P2AJc`0TF/l00H0TF/l0P2EJT0209I[@@80Ufa20P2HKD<809A^
?`03099^?P2CKcl0UW920080Ug=300<0UW9209Ea@@2CKcl00`2DKSl[ooooo`00:_ooool208YP<004
08UN<@29GS<0REhd08QM<`80R5`e0P2=GCL00`2;GSL0RUhg08UO=`0208MP=`0308IQ=`2>HCL0SV4g
0080SF0f00@0S5le08]N=02;GS@0RUdc0P2:Gc@208]P=@@0S64f00<0T6Dj08iS>02=HSL00P2<HCH0
0`2=HSL0SV<h091U>P08091U>P80Sf8i00<0Sf8h091T=`2@I3D00P2AIC@0102AIS<0SV4h08mR>@2A
I3/2099U?003095T>`2?HST0SV4h0080TVLj00@0TFHi091U>02>HcH0SF8e0P2<HC@9095U>003099V
>@2CIcX0UFTl00<0Uf/n00<0UFTl09AX>`2JKSd00P2IKC`0202HK3/0Uf/j09IZ>@2FJST0UFTh09AX
=`2FJST0Uf/j0P2HK3/00`2GJcX0UVXi09AX=`0809EY>00309IZ>@2EJCP0TfLf0080TVHe00<0TfLf
09EY>02FJST00`2DJ3/209EY?0<0UVXm202IJCT809e]?@0509eb?`2LLCh0W74n09]`?@2JKc`00P2I
KS/01P2HKCX0VFdl09U]?02IKC`0VVhm09]_?P<0W70o0`2NLch209eb?@<0W74l202JKc`809Y^?@80
VVll0P2KL3d409aa?P040:1d@`2OLd80Wg=209ib@@80WG500P2LL3l0102NLT40WG5009ea@02MLD03
09a`?`0309]_?P2OLd80Wg=200H0Wg=200/0WG5009ib@@2PM4<0XWI50:=gAP2RMTD0X7A309mc@P2N
Ld00X7E20:9gA0020:AiAP80XgQ500D0XWM40:1e@P2OMT80WgI20:1g@`020:5hA00;0:9iA@2SNTH0
XgY609ic@02OM440X7E20:5f@`2RMd@0XgQ50:AiAP2UNTL0202SN4D00`2QMT40XWM20:AiA0020:Ej
A@030:AiA02RMd80XGI100P0YGY70P2XO4/00`2XODX0Z7e80:QmAP020:QnA00:0:Qn@P2ZOdX0ZGi9
0:QmB02WO4L0YW]60:EjA@2TND@0XgQ30:=hA@80Y7U600<0YGY70:IkB02VNdP00P2WO4T80:AkA`03
0:AiAP2VNdP0Yga90080ZGi;00<0Yga90:IkB02TNDH00P2UNTD0102VNdP0YWY90:MkC02WNd`20:Ql
C`080:EjA`2VNdP0ZGi;0:^0C@2/PDh0Zh1=0:YoC02YOT/20:j3CP0A0:f2C@2[P4/0ZGi90:QmB02W
O4L0YW]60:9g@02TND80YW]40:QmAP2YOTL0Z7e60:MlA@2VNd@0Y7]70:ImB@2XOd/00P2YP4`03@2W
OTX0Y7]70:9iA@2QN4@0XWU50:AkA`2UO4P0Y7]70:=jAP2PMd<0WgI209ikA@2OO4H00`2QOTP00`2O
O4H0WGY409]h@P0209ed@0@0WWE10P2OMT800`2IKcd0VW0n09ab@00209ec@@0409ab@02JL3h0VW0n
09U_?@80VWE100<0VGA009Qc?`2GLSh00P2EL3`00`2DKc/0V6hl09M]>`0209M]>`80UV`j0P2EJcT0
1P2HLT<0Ug5209I`@@2EKd00U6ho09=]?P80TV`m0P2DJC`209=X>`@0TVLj00@0TV`m08iX>@2;ICH0
S6Hg0P2?JCX00`2<ISL0RF<d08mY>P03091Z>`0?08mY>P2<ISL0RV@e08QR<`2=ISd0S6Dl08]T>`2:
HcX0RF8i08QQ>027H3L0QUlf08QS>@26HCL0QF0f00<0Pehd00<0Q5le08EP=P23Gbl01`23Gbl208=N
=004089M<`21G380P5/a081K<@80OeX`2023GCH3085M;@80PUh^0`23Gbl01020FS<0OeTb07mI<P1o
FC8207iH<@80OEL`201nF342085K;P03081K;P1nG2h0OEd^0080O5d^00@0NUh^07aJ;01lFR`0O5X/
0P1kFB/307YH:P@0OeX`101nFBl5085J<@<0P5T`00L0PU`]085K;01oFBX0OUPY07eG:01nF2T0OeTZ
0080P5X[00<0OU@^081F<022F3800P23FC<01P21Ec40OU@^07aB;01gE2h0NEH`07aI<`80OEXd00/0
O5Tc07UF<01gE2h0NUHb07UE<@1hEBl0Me@/07MD:P1hERT0NELZ07YH:P0807aF;`D0NEH^0`1hEBd0
101gE2`0N5D]07QE;@1hEBd207UF;P80NUL_0P1hEBd207UF;P<0NUL_00@0NeP`085N=020GC<0OU/a
0P1mFS001@1nFc40P5dc085N=01nFBl0OEP^0080O5L]00@0OEP^07mJ<022GC<0Q5le0`21G2l2089M
<0<0Peha0P21G2l3089M<0<0Peha00P0QF<e08=Q<`21Gc40Oed_07iL;P20GS00PV0b08AR=080QV4d
00<0Qf8e08QS=P29I3L00P2:ICP0102;IST0QV4d08QS=P29I3L208]V>@0408UT=`28HcH0QV4d08QT
=0<0RFDe0P2:ISH208]W=`80RfDf00<0S6Hg08eW>02>J3T00P2?JCX00`2@JS/0U6Xh09AZ>00609AZ
>0P0V6hl1P2GLSh209Qc?`<0UgI100<0VGE109Ye@@2LM4400P2MLd400`2NLT40W7<o09ac?`0209ac
?`80WGA00P2NMD401P2LMd80WGQ309iiA02ONTD0XGa70:9mB080Xgi900<0XgY40:AkA@2UO4H00P2V
ODL00`2UO4H0XgY40:9i@`050:YlB080ZG]700<0Z7Y60:V0BP2ZPD/00P2ZPD/40:^2C0080:N2C@2V
PD`0YH1;0:AoBP2UP4/0YX5<0:R3CP2YQ4l:0:f4D0<0[XEA0`2_QU830;68E0030;27D`2_QU80[XEA
0080[XEA00<0/HME0;26E02^Q5800P2/PU000`2]Pe40[hEC0;26E0080:j9E@h0/HQD0P2`Qe<02@2c
RUH0/XUE0;68E02`Qe<0[hIB0:j5D@2]Q500[8=?0:j5D@020:n6DP030;27D`2aR5@0/HQD0080/XUE
202aR5@80;2:F@80[hYF0`2`ReL30;6<F0T0/XaO0P2cSUX20;:=F@80/HaH0P2`ReL30;>9E`030;B:
F02eReT0]XaJ0080]XaJ0`2aS5L30;2;EP80[hYE0P2^RE@00`2_RUD0/8]F0;6<E`020;:=F0090;>>
F@2bRED0/hYF0;F<F02fSET0]HaH0;B;E`2bRED0/8MC00P0/hYF0P2dReL0102cRUH0/XUE0;:9E@2a
R5@20;27D`P0]HaH202`ReL0102`QU@0[hEC0:n5D`2_QE<20:j4DP80[H=A00P0ZhI?0:Z5CP2YQ4d0
ZHA=0:Z5CP2/Qe00[XUB0:n:D`P0[HQD0P2^RE@20:f8D`80[8MB0P2[QU430:b7DP<0ZhIA0P2ZQE00
2`2ZOe80Zh1C0:^1D@2/PU80[H=A0:j5D@2^QDl0[hI@0:^6D@2ZQE00Z8=>0080Yh9=00<0Z8=>0:Z5
D02[QU40202/Pdl80:j5D@040;27D`2_QU80[HA@0:f4D080Zh9>00<0[8=?0:f4D02^QE400P2]Q4`3
0:b3B`<0Zh9:202YQ4l0202WOTX0Z7m;0:V0C02ZPDd0Zh9>0:b3C`2]Q500[XEA202]Q50:0:b3C`80
Zh9>0`2ZPDd0102YP4`0Zh9>0:^2CP2/Pdl20:f4D0050:j5D@2_QU80[hIB0:j5D@2]Q5000`2[PTh0
0`2]Q500[hIB0;27D`020:^2C0040:b3C@2]Q4h0[HA>0:j5C`80[hI@2`2^QE420:f4D0<0[8=?00@0
ZH1<0:^2CP2]Q500[hIB0P2`Qe<0102^QE40[HA@0:f4D02]Q5030:b3C`<0Zh9>202]Pe401P2]PUP0
[H9G0:f2E`2]PUD0[H=C0:f3D@80[HA@202[PT`80:QnC0@0Zh9>102ZPDd00`2`Qe40[hI@0:j5C`02
0:f4CP040:^2C02YP4X0Z7m90:QoB@80ZH1<00<0ZX5=0:^2CP2/Pdl00P2^QE400`2_QU80ZH1<0:Z1
C@020:Z1C@<0Zh9>00H0[8=?0:V0C02YP4`0ZH1<0:Z1C@2[PTh30:b3C`80Zh9>00@0[8=?0:f4D02]
Q500[XEA0P2_QU880:b3C`040:V0BP2ZPD/0ZX5;0:Z1B`80Zh9<0P2/Pdd20:UoC`040:UoC@2YP4`0
ZH1<0:V0BP80ZH18202/Pdl00`2ZPDd0Zh9>0:f4D0020:n6DP030:j5D@2]Q500[8=?00P0ZH1:0P2X
OdT20:V0BP@0ZX5;202/Pdl80:^2CP040:j3CP2]PTd0Zh1;0:UnB@80Z7e800D0ZGi90:YoBP2WOTX0
ZH1<0:^2CP020:f4D0030:b3C`2[PTh0ZH1<00<0ZH1<0P2XOd/30:MnBP80YGa60P2VODL01P2WOTP0
Z7m90:QoB@2YP4X0ZX5=0:V0C0<0Ygi:00L0ZH1<0:b3C`2]Q500[hI@0:j5C`2[PT`0ZX5;0080ZH1:
00<0ZX5;0:b3C@2]Q4h00`2/Pdd00`2[PT`0ZX5;0:V0BP020:V0BPP0Z7i<00<0[81A0:]oD02YOD`0
0P2WO4T00`2XODP0ZGi70:YoB0020:ElB080YWe900L0Ygi:0:QoB`2XOd/0ZH1<0:^2C02ZPD/0Z7m9
0080Ygi800H0Z7m90:Z1B`2[PT`0ZX5=0:MnBP2TNdL20:9iA@030:AkA`2WOTX0ZX5=00D0ZH180`2Z
PDT02@2/Pdl0Zh9>0:QoB`2VODT0YGa80:ImB@2WOTX0Z7m;0:MnBP020:QoB`030:V0C02ZPDd0ZX5=
0080Zh9>00<0ZH1<0:Z1C@2[PTh00P2[PTh00`2YP4`0Ygi:0:ImB@030:V0C080Z7m;0`2WOTX20:Im
A`@0YGa60P2TNdD:0:QoB`<0Ygi:0`2VODT00`2WOTX0YWe90:AkA`020:AkA`060:ElB02WOTX0Z7m;
0:ImB@2WOTX0ZH1<0P2ZPDd00`2YP4`0Ygi:0:ImB@030:ElB080YWe90`2WOTX30:ImB@80YGa8102T
NdL0102UO4P0YWe90:MnBP2WOTX20:ImB@050:ElB02TNdL0YWa:0:EkB@2TNTP00P2RN4H02`2TNTP0
YG]90:IlBP2NM480XWQ60:IlBP2UNdT0XGM50:1fA02TNTP0Z7i<0080YGa800@0Y7]70:=jAP2SNTH0
XWU51@2QN4@30:9iA@80XgY60P2PNTT0102QO4P0XGa70:5lA`2RODH20:9nA0030:=oA@2ROT@0X7a2
0080Wg]100@0X7a20:9nA02SOdD0XgTm0P2TNSh00`2UNcl0YWa00:Il@0020:Mm@@P0XgY60`2NND@3
09mjA@80X7]60P2PMT@0102OMD<0WWA209id@P2MLd4209ab@00309ehA02LMd<0VgI20080VgI200@0
WGQ409mjAP2QO4P0WgI20`2PMd<30:5hA00A0:9iA@2PMd<0WgI209ed@02KLSh0VW4m09]b?P2MM400
WWE109Q^?02IKcd0VW0n09]a?`2LLT00WG=109id@P2OMD<0102KLCl209Y`?P80VFlm202IM3l0102G
LSh0UW4m09Ia?@2FLCd209E`?080U6lk0P2LLT00102KLCl0VW0n09Q^?02GKC/209I/>PT0Ufdk00@0
VWA509Qb@`2FL440U6ho0P2BK3d209=]?P0309AY?02EJSd0UV/n0080Uf`o00@0UV/n09EZ?@2DJC`0
UFXm0P2FJch00`2GK3l0V6e009U^@@0209Y_@P0609]`@`2JKd80VVm209Q]@02GK3l0UV/n0P2EJSd0
102KMT80VGA009Mb?P2EL3`309A_>`0309E`?02EKd00U6ho00<0Tfdn00<0UFm009Ma@P2HLT<0202E
Kd000`2CKCh0UFm009Ma@P0209UcA00309Ma@P2EKd00Tfdn00P0Tg510`2FLC`[ooooo`00:_ooool3
08UN<@80REhc0P29GS@01P29GCH0SEdg08eM=`2;GSL0RUhg08UO=`80Qf0g00<0QV4g08iQ=`2>HCL0
0P2=H3H208aO=@80Rehd0P2:Gc@208]P=@<0S64f00@0SF8g091U>P2>HcP0SF8g0P2<HCH00`2=HSL0
SV<h091U>P0808mT>@80Sf8i00<0Sf8h091T=`2@I3D00P2AIC@0102AIS<0SV4h08mR>@2AI3/2099U
?003095T>`2?HST0SV4h0080TVLj00H0TFHi091U>02?I3L0SV<f08eR=@2<HC@9095U>008099V>@2C
IcX0UFTl09IZ?@2GJch0UVXm09EY?02DJ3/309Q/>`<0Uf/j0P2FJST00`2DJ3L0UVXi09M[>P0209Q/
>`0309M[>P2FJST0U6Pg00P0UFTh00<0UVXi09EY>02CIcH00P2BISD00`2CIcH0UFTh09IZ>@0209AX
>`<0UFTl0`2FJSd809UY>@P0WFdm102JKc`409U^>`80V6`k0P2IKC`209Y^?@80Vfln0`2MLSd209aa
?0<0Vg0k202JKc`809Y^?@80VVll0P2KL3d309aa?P0509eb?`2OLd80Wg=209mc@P2NLT400P2MLD04
09a`?`H0WG50202OLd800`2MLD00WW910:1d@`030:9fA@80X7A300D0WW=00:1e@P2RMd@0XgQ50:Ai
AP020:=hA@030:9gA02QMT<0WWE10080WgI20P2PMd<20:5hA0070:9iA@2OM440WgA10:1e@P2QMT<0
XWM40:=hA@020:AiAPP0XgQ500<0XGI10:9g@P2TND@00P2UNTD00`2TND@0XWM20:5f@@080:EjA`80
Z7a;00<0Z7e:0:QmB02XODH00P2XOT@01`2XOT80ZGi90:UnB@2XODP0Yga70:IkAP2UNTD00P2TND@3
0:AiAP030:EjA`2VNdP0YW]80080Yga9202TNdL00`2UNTL0YW]80:MlB@020:QmBP090:MlB@2VNdP0
YGY70:Ej@`2UNTD0YW]60:IkB02WNdX0Yg]<0080Z7a?00@0YGY70:MlB@2YOT/0ZWm<0P2[P4d20:Un
B`80[85<00<0Zh1;0:YoBP2YOTT00P2XODP02@2WO4L0XgQ10:Ai@P2VNd@0Z7e60:UnA`2XODH0Yga5
0:IkA0020:ElB0<0YWe900D0YGa80:=jAP2RNDD0XWU50:=jAP030:ElB00;0:=jAP2QN4@0X7M309mj
A@2PNdH0XGa70:9mB02QO4L0X7]609iiA02LMd800P2MM40609ie@@0309Y`?P2KLCl0W7900080WG=1
00X0W79009]a?`2KLCl0VW0n09Ye@@2IM400V7<o09Mb?P2FLCd0UG0l0P2DKc/309M]>`80UV`j0`2E
JcT209Ma@P0309I`@@2EKd00U6ho0080TV`m00<0TF/l09AY?02DJC`00P2CJ3/3099W>P03095V>@2A
Jc`0SVPi0080RfDf00@0SVPi08mY>P2<ISL0RF<d0P2=IcP01`2>J3T0SfTj08iX>@2<ISL0RV@e08QR
<`2<IC`00P2;I3/03@2:HcX0R64h08MP=`27H3L0QUlf08MR>026HCL0Q5le08=N=022GC<0Pehd08AO
=@25H3H02023Gbl01022GC<0PE`b085L<P21G384081K<@P0PE/d00@0P5`/085M;@21GBd0PEd]0P22
GRh208=O;`<0OeTb0P1nF34307eG<0P0OUPa0P20FBh00`1oFRh0OE/^07aK;P0207]L;P0307UM;P1l
FRd0O5X]0080NeT/0`1jF2/00`1iEbX0OUT_07iI;`0407iI;`80OEP^00<0PEXa081I<020FC001@20
FC000`22G2d0PE//07mI:P0307eG:0<0OeTZ0P20ES03085G<@0507mE;`1nE2h0OE<]07QE;`1iES00
101jEc402P1iES00N5D_07YF<P1iEC40N5D_07MD;01gE2X0N5HY07UG:P1jF2X807aF;`<0NEH^1@1h
EBd207MD;080N5D]0`1iERh0101jEbl0NEH^07UF;P1iERh207YG;`<0NeP`00<0P5dc07mL<P1nFc40
0P1lFBl00`1nFc40Oe`b081M<`0207eH;P80O5L]00D0OEP^07mJ<022GC<0Pehd081K;P03085L;`80
PUd`0P23GS48089M<00308=Q<`22H380PEla00<0P5h`00<0PEla089P<P25H3<00P26HC@00`27HSD0
R6<f08UT=`0208YU>00308IQ=027HSD0RF@g0080RVDh00<0RF@g08MR=@26HC@00P28I3@208UU=@<0
RVHf00L0RfLg08YT=@2;ICH0RfDf08aV=`2=IcP0SVPi0080SfTj202DJSP809M]>`@0UW4m102GLSh3
09Ie@00309Qd@02IM400Vg=00080W79000<0WG5009]b?P2LLcl00P2LLcl209ed@080WWE100D0WGQ3
09iiA02NND@0WgY50:1kAP020:5lA`040:9mB02SNT@0Y7]50:ElAP80YWe700<0YGa60:=jA02RND<0
0`2YNdL50:YlB0P0ZX5;00P0Yh9=0:J1C02UP4/0Y7m:0:F0B`2VPD`0Z8=>0:V4C`/0[HA@0P2^QE43
0:n6DP80/HQD0P2`Qe<0302_QU80[XEA0:j5D@2^QE40/HME0;26E02^Q580[H=A0:b2D02]Pe40[hEC
0;26E0P0[XUE202aR5@30;27D`D0/HQD00H0/hYF0;:9E@2aR5@0/8MC0:n6DP2^QE420:f4D0<0/8MC
00<0/HQD0;:9E@2bRED00P2cRUH80;68E0P0/8YI0P2_RUH30;2;E`<0/HaH2@2bS5d20;>>FP80/XeI
0P2aS5P20;2;E`80/hUG0P2dRUP20;F;F@80]XaJ0`2aS5L30;2;EP@0[hYE0`2`ReH30;6<E`030;:9
E@2cRUH0]8]G0080]HaH00<0]8]G0;:9E@2aR5@0202cRUH20;B;E`80/hYF00@0/XUE0;68E02aR5@0
/HQD202eS5P80;2;E`80/8ID0P2_QE<30:j4DP090:f3D@2/Qe00ZhI?0:Z5CP2YQ4d0ZXE>0:b7D02^
RE80[hYC00P0[HQD0P2^RE@20:f8D`80[8MB0P2[QU430:b7DP<0ZhIA0P2ZQE020:f2E@030:f3D`2]
Pe40[XEA0080[XE?00@0[XE=0:^6D@2ZQE00Z8=>0P2WPTd00`2XPdh0ZXE@0:^6D@080:b3C`P0[XEA
00@0/8MC0:n6DP2]Q500[HA@0P2[PTh00`2/Pdl0[HA@0:j5D@020:f4C0<0[8=;0`2[PTX80:V4C`05
0:QoB`2YP4`0ZH1<0:Z1C@2[PTh00P2/Pdl90:f4D0X0[8=?0P2[PTh40:Z1C@030:^2CP2/Pdl0[8=?
0080[HA@0P2^QE40102_QU80[XEA0:f4D02/Pdl20:^2CP040:f4D02_QU80/8MC0:^2C080[8==0P2]
Q4h20:j5C`030:n6D02^QE40[XEA00T0[XEA0P2]Q5030:b3C`080:V0C02ZPDd0[8=?0:j5D@2_QU80
[XEA0:f4D02/Pdl20:f4D0<0[8=?0`2[PTh80:f3D@80[H9G0P2]PUD0102]Pe<0[H=A0:f4D02]Q508
0:^2C0P0Z7i<102[PTh40:Z1C@80[XE?00@0[HA>0:b3C@2/Pdd0Zh9<0P2ZPD/02@2YP4X0ZH1<0:V0
C02ZPDd0Zh9>0:b3C`2]Q500[XEA0:n6DP040:^2CP@0ZX5=0P2YP4`20:Z1C@040:^2CP2/Pdl0[8=?
0:b3C`80Zh9>0P2/Pdl0102]Q500[XEA0:j5D@2^QE480:b3C`@0ZX5;0P2[PT`20:b3C@80ZX1@00@0
ZX1>0:Z1C@2ZPDd0ZX5;0P2ZPDT80:b3C`080:Z1C@2[PTh0[HA@0:j5D@2_QU80[XEA0:f4D02/Pdl8
0:V0BP80Z7m90P2YP4X30:Z1B`030:^2C02/Pdl0[8=?00H0[8=?202[PTh01P2^Pdh0[85<0:YoBP2Y
OTT0Z7e80:UnB@80ZWm:00P0Ygi:0:V0C02[PTh0[8=?0:f4D02/Pdl0Zh9>0:Z1C@<0ZH1<0`2XOd/2
0:MnBP030:ElAP2VODL0YWe70080Ygi80P2XOdT03@2YP4X0ZX5=0:V0C02XOd/0Ygi:0:QoB`2YP4`0
Zh9>0:f4D02_QU00[HA>0:^2C02ZPD/00P2YP4X00`2ZPD/0Zh9<0:b3C@020:b3C@80Zh9<00@0ZX5;
0:V0BP2YP4X0ZH1:202XOT`00`2/P540Zgm@0:UmC0020:MlB@040:QmB02YOTL0ZWm80:ElB080YWe9
0P2WOTX20:QoB`040:V0C02[PT`0ZX5;0:QoB@80Ygi800H0Z7m90:Z1B`2[PT`0ZX5=0:MnBP2TNdL2
0:9iA@030:AkA`2WOTX0ZX5=00H0ZH180P2ZPDT00`2/Pdl0ZX5=0:QoB`030:ImB@030:MnBP2XOd/0
Ygi:0080Z7m;0P2YP4`20:Z1C@030:^2CP2YP4`0ZX5=00<0Zh9>00<0ZH1<0:MnBP2VODT00`2YP4`2
0:QoB`<0Ygi:0P2WOTP60:ImA`/0Z7m;0P2WOTX30:ImB@030:MnBP2VODT0YGa80080Y7]700H0YGa8
0:MnBP2XOd/0YWe90:MnBP2YP4`20:Z1C@030:V0C02WOTX0YWe90080Y7]70`2UO4P30:ImB@<0YGa8
0P2TNdL30:=jAP030:AkA`2UO4P0YWe90080Ygi:0P2VODT01@2UO4P0Y7]70:IlBP2UNdT0Y7Y80080
XWQ600`0Y7Y80:EkB@2VO4X0WWA20:9hAP2VO4X0YG]90:5gA@2PMT@0Y7Y80:QnC02UO4P20:AkA`80
XgY60P2RNDD40:5hA080XWU50`2SNTH20:1jB@040:5lB02QO4L0XGa70:9mAP80XWi400<0Xgm50:9n
A02PO4800P2ONd400`2PO480XWi40:=oA@030:Aj@0030:Ek@@2VO480YWa20080Yge3202SNTH709mj
A@0409iiA02PMT@0WgE309me@`80WWA20P2MLd400`2LLT00W7M309]f@P0309Ye@@0309ag@`2NNDD0
WgY60080XGQ41`2PMd<00`2OMT80WGA009]b?P0209]b?P80WGA00P2IKcd0102JL3h0Vg4o09ab@02M
Ld4209id@P0409ab@02KLCl0Vg4o09]a?`80VW0n0P2IKcd809Ud?`80V7<o0P2GLSh209Ia?@80UG0l
00D0W79009]a?`2KLCl0VW0n09Q^?00209M]>`0309I/>P2HKS`0V6hl00L0V6hl00<0VG=409Ma@P2E
Kd000`2CKCh209A^?`0309AY?02EJSd0UV/n0080Uf`o00<0UV/n09EZ?@2DJC`00P2FJch209M/?`05
09Q]@02IKT40VVm209Y_@P2KL4<00P2JKd802@2IKT40Uf`o09I[?P2FJch0UFXm09]f@P2IM400Ug8n
09E`?00209A_>`80UG0l00<0UW1109E_@02DKSl00P2CKCh00`2EKd00Ug5209Qb@`0:09E_@0@0Ug52
0P2EKd03099`@0D0Tg510`2FLCd[ooooo`00:_ooool208ML<@0308QM<P29GS<0RUld00<0Rf0e0P2>
GSP00`2<GcP0Relh08YP>00208QQ>00308MR>02>HCL0SV4g00<0SF0f0`2<GcD308]P=@80S64f0`2=
HSL00`2@ICX0SV<h08eR=`0208aQ=P0308eR=`2>HcP0T6Dj00P0SF8g0P2?HST00`2?HSP0T6@g091T
=@02095U=004095V<`2?HSP0T6<i095T>P80TVDk00<0TF@j091S>@2?HSP00P2BIcX00`2AIST0T6Dh
08mT=`0208iS=P0308eR=@2AICP0TFDh00L0TFDh00@0TVHi09=W>P2DJ3/0UFTl0P2FJSd00`2EJC`0
U6Pk09IZ>@0209IZ>@<0Uf/j0P2HK3/00`2DJ3L0UVXi09M[>P0209Q/>`0309M[>P2FJST0U6Pg00P0
UFTh00<0UVXi09EY>02DJ3L00P2CIcH0102DJ3L0UFTh09IZ>@2DJ3/309EY?080UVXm0P2GJch809UY
>@P0W6`l0`2GK3T209Q]>P<0VFhk0`2GJcX209Q/>`<0VFdl0P2LLCh209]`?@80VVll0P2IKS/809Y_
?0P0Vfln0`2KL3d209aa?P<0WG8o0P2OLd8309ib@@<0WG500P2KKch0102LL3l0WG5009ea@02NLT4:
09mc@P0509ib@@2OLd80X7A30:5eA02RMTD00P2QMD@0102PM4<0WgA10:1e@P2QMT<40:=hA@030:9g
A02QMT<0WGA000<0WWE10`2OMT801P2PMd<0WgA10:1e@P2PMD80XGI30:9gA080XgQ500<0Y7U60:9g
A02RMd@01P2RMd@00`2QMT40XWM20:=h@`020:AiA0030:=h@`2RMd80XGI100P0YGY70P2WNdX00`2W
O4T0Yga70:MlA@020:Mm@`060:Mm@@2YOTT0Z7e80:QmB02WO4L0YW]60P2UNTD00`2TND@0Y7U60:Ai
AP030:EjA`<0YW]8202TNdL00`2UNTL0YW]80:MlB@020:QmBP030:MlB@2VNdP0YGY70080YGY300@0
YW]60:IkB02WO4T0Yg]:0P2XO4d0102VNdP0Yga90:QmBP2YOT/20:YoC0030:UnB`2XODX0ZGi900L0
ZGi90P2TND@0102VNdH0Yga70:MlA`2WO4L20:IkAP050:ElB02TNdL0XgY60:9iA@2QN4@00P2RNDD0
0`2SNTH0Y7]70:AkA`030:ElB0030:AkA`2RNDD0XGQ40080WgY50`2PNdH00`2ONTD0WGQ309ag@P03
09ie@@D0WGA000<0Vg4o09ab@02MLd400P2NM480102MLd40W79009ab@02KLCl209Qc?`80Ug8n00D0
UW4m09E`?02DKc/0U6lk09M]>`0309I/>P80UF/i0P2DJSP209E_@080U6ho00@0Tfdn099/?@2AJc`0
TF/l0`2CJ3/2099W>P<0TFHi00/0T6Xk08aV=`2:I3D0RfDf08iX>@2?JCX0S6Hg08QR<`29Hc@0RV@e
08]U=P0208aV=`0408]U=P29Hc@0R68c08]T>`80RV<j00<0RF8i08QQ>027H3L00P26GcH00`27HSP0
QF0f08AO=@03089M<`0308=N=024GcD0PUd`00L0PUd`0`1oFS03081K<@80PE`b201oFC80101oFRd0
P5/^081K;P20Fbh2085L;`80PUd`00@0OeTb07iH<@1nF340OUPa0P1mEc0207aF;`P0OEL`0P1oF2l0
0`1nFBl0O5T_07]J;`0207YK;`0307QK;`1kF2h0NeP^0080NUL]0`1iER`00`1hEB/0OEP^07eH;P06
07eH;PP0OUT_00<0PE/^081J;@1nF2/00`1lERT307iH:`0407mH<@1nEc00OEH_07aE;P80Ne@]00@0
O5D^07eF;`1hEBl0Me@^101fDbd02P1gE2h0N5D_07UE<@1hE300Me@^07IC:`1fDbT0MeDX07QF:@1i
EbT807]E;P0307MD;01hEBd0N5D]00D0N5D]00@0MU<[07MD;01gE2`0Me@/0P1hEBd207UF;P<0NUL_
0P1kF30307aI<@0307mL<P1nFc40OEX`0080O5T_00<0OEX`07iK<@1oG3800P1mF2h207aG;@0507eH
;P1oFS00P5/a089M<`1oFRd00`20Fbh2085L;`80PUd`0P23GS42089M<007085L;`20Fbh0OeX]07mJ
;@1oGBl0P5h`085O<@02089P<P04085O<@20GS00Oed_08AO<P80QF0c00<0QV4d08MR=@28HcH00P29
I3L00`26HC@0Qf8e08QS=P0208UT=`0408QS=P27HSD0QV4d08MS<`<0R6@d0P29ICD208YV=P80RV@e
00<0RfDf08aV=`2=IcP00P2>J3T00`2?JCX0TfTg09=Y=`0609=Y=`P0UV`j0P2DKc/209E`?080UW4m
0P2GLSh309Ed?`0309Mc?`2HLcl0VW8o0080Vg4o00@0W70o09]b?P2KLSh0Vg8n0P2LLcl309ed@0P0
WgY500P0XWU30:=jA02TNdD0YGa60:ImA`2UO4H0XgY40:9i@`@0YW]600D0Yga70:QmB02YOTT0ZWm:
0:b3C@020:^2C00=0:Z1B`2YP4X0Z7m90:QoB@2WOTP0Yh9=0:J1C02UP4/0Y7m:0:F0B`2VPD`0Z8=>
0:V4C`090:b3C`<0[HA@0P2^QE420:n6DP<0/8MC0P2_QU830:j5D@030;26E02_QE<0[XAB00<0[XAB
00<0[hEC0;26E02^RED01`2^RED80;68E080[hIB0P2`Qe<0102aR5@0/XUE0;:9E@2cRUH20;:9E@80
/HQD00@0/8MC0:n6DP2^QE40[XEA0`2bRED30;>:EP80]8]G202aR5@80;2;E`80[hYF0`2`ReL30;6<
F0T0/XaM0P2cSUX20;:=F@80/HaH0P2`ReL0102cREL0]8YH0;B:F02dRUP30;F;F@040;J<FP2aS5L0
/HaG0;6<E`<0/8]F0P2_RUD30;6<E`<0/8]F0P2_RUD0202bRED0/hYF0;B;E`2dReL0]HaH0;B;E`2c
RUH0/XUE202cRUH0102dReL0/hYF0;>:EP2cRUH30;:9E@030;68E02eS5P0]HaH00H0]HaH202`ReL0
102aQeD0/8ID0;26E02`QU@20:n5D`80[XAB00<0[HQA0:b7D02ZQDh00P2ZQDh00`2/Qe00[HQA0:n:
D`080:f8E080[XUD0P2]R5<20:b7DP80ZhIA0`2/Qe830:^6D@80ZXE@0P2`QUH0102`QU@0[hIB0:n6
DP2^QDl20:j5C@030:^6D@2ZQE00ZHA?0080Z8=>00<0ZHA?0:Z5D02[QU40202/Pdl80:j5D@040;27
D`2_QU80[HA@0:f4D080Zh9>00<0[8=?0:f4D02^QE400P2]Q4h30:b3C@<0Zh9<202YQ4l40:Z1C@@0
Zh9>202^QE4;0:b3C`80Zh9>0`2ZPDd30:b3C`80[HA@0`2^QE401P2]Q500[8=?0:b3C`2[PTh0[8=?
0:f4D080[hIB0`2/Pdd20:f4CP<0[XE?2`2^QE420:f4D0<0[8=?00<0ZH1<0:Z1C@2[PTh00`2/Pdl2
0:^2CP80[HA@0`2/Pdl30:^2CPP0[89@00H0[85F0:b1E02/PE@0[89B0:b2D02/Pdl:0:b3C@P0ZGm=
102ZPDd40:^2CPT0[8==00H0ZH1<0:Z1C@2ZPDd0Zh9>0:b3C`2]Q5020:j5D@050:f4D02/Pdl0[8=?
0:^2CP2ZPDd00P2YP4`0102XOd/0ZX5=0:Z1C@2ZPDd20:^2CP<0[8=?00@0Zh9>0:b3C`2/Pdl0[8=?
0`2]Q5000`2^QE40[8=?0:b3C`060:b3C`<0ZX5;0P2[PT`30:b3C@80[89B00@0[89@0:b3C`2/Pdl0
[8==0P2/Pd/80:b3C`030:V0C02[PTh0[8=?00<0[XEA00<0[HA@0:b3C`2YP4X02P2YP4X20:Z1B`<0
Zh9<402[PTh02`2]PTd0[85<0:YoBP2YOTT0Z7e80:UnB@2ZOdX0Zh1;0:QoB`2YP4`0ZX5=00<0[8=?
00@0Zh9>0:Z1C@2ZPDd0ZX5=0P2YP4`30:QoB`030:MnBP2VODL0YWe70080Ygi8102XOdT20:V0C0<0
Z7m;00H0ZH1<0:^2CP2/Pdl0[XE?0:f4CP2[PT`40:Z1B`D0Zh9<0P2ZPD/30:V0BPP0ZGm=00<0[81A
0:]oD02YOD`00P2WO4T00`2XODP0ZGi70:YoB0020:ImB@80Ygi:102XOd/00`2ZPD/0ZH1:0:QoB@02
0:MnB0060:QoB@2YP4X0ZX5;0:Z1C@2XOd/0YGa80P2TNdL00`2UO4P0Z7m;0:Z1C@080:V0BP030:Z1
C@2YP4`0Z7m;00<0Ygi:1P2XOd/20:V0C080ZX5=0P2YP4`30:^2CP030:V0C02XOd/0YWe900<0ZH1<
0P2XOd/30:MnBPP0Z7m9202XOd/0102YP4`0Z7m;0:QoB`2XOd/20:MnBP80YWe900<0Z7m;0:MnBP2U
O4P00P2TNdL01P2UO4P0Ygi:0:QoB`2VODT0Ygi:0:V0C080ZX5=00<0ZH1<0:MnBP2VODT00`2SNTH2
0:AkA`<0YGa80`2TNdL20:=jAP<0XWU500<0Y7]70:ElB02VODT00P2WOTX20:ImB@050:ElB02TNdL0
YWa:0:EkB@2TNTP00P2RN4H02`2TNTP0YG]90:IlBP2PMT@0XgU70:EkB@2TNTP0XWQ60:5gA@2SNDL0
YWa:00<0Y7]70P2SNTH30:9iA@80XGQ40P2RNDD30:=jAP040:AkA`2PNTT0X7Y90:5lB080XGa700H0
XWe60:9nA02ROT@0XWe60:5lA@2PNd@209mj@`030:1kA02QO4D0XWe60080Y7Y00`2UNd430:Il@PP0
XgY60P2QO4L0102PNdH0WgY509iiA02NND@209eh@`<0WgE30P2NM48309ec@@0309ag@`2KMT80VGA0
0080VGA000<0VgI209ag@`2NNDD00P2RNDD0102QN4@0X7M30:1g@`2OMT8209ie@@0509mf@P2NMD40
WGA009ac?`2KLSh00P2LLcl01P2MM400VFlm09Y`?P2JL3h0Vg4o09ab@080WG=100@0WWA209ab@02L
LT00W7900P2KLCl309Y`?PP0VG@o0`2IM40209Qc?`<0Ug8n0P2KLCl0102JL3h0VFlm09U_?@2HKS`2
09M]>`T0VW0n00<0Ug5209I`@@2DKSl00P2CKCh01P2DKSl0UFm009I`@@2EJSd0UV/n09M/?`80V6e0
00<0Uf`o09I[?P2EJSd00P2FJch00`2GK3l0V6e009U^@@0209Y_@P80Vg130P2JKd800`2IKT40V6e0
09M/?`0209I[?P0509]f@P2IM400Ug8n09E`?02DKc/00P2EL3`02@2FLCd0UW1109E_@02DKSl0Tfdn
09A^?`2EKd00Ug5209Qb@`0809E_@080Ug52102EKd0209Ma@P05099^?P2CKcl0Tflo09A`@02ELD40
0`2FLT8309E`?2_ooooo000Zooooo`0608IJ<`27G380R5dc08UN<`2:Gc@0S64d0P2=HSD208iN>003
08aO>02;GcP0RV0h0080R64h00<0Qf8h08iQ=`2>HCL01P2=H3H208]P=@<0S64f0`2=HSL00`2@ICX0
SV<h08eR=`0208aQ=P0308eR=`2>HcP0T6Dj00P0S64f0P2?HST00`2?HSP0T6@g091T=@02095U=003
095V<`2AICP0TFDh00H0TFDh00<0TVLj095V>@2AIST00P2@ICP208mT=`0308iS=P2AICP0TFDh00L0
TFDh00@0TVHi09=W>P2CIcX0U6Pk102EJC`01@2DJ3L0UFTh09EY>02FJST0Uf/j0080V6`k00@0VFdl
09AX=`2FJST0Uf/j0P2HK3/00`2GJcX0UVXi09AX=`0809EY>00309M[>P2EJCP0U6Pg0080TfLf00<0
U6Pg09EY>02GJcX00`2EJC`209IZ?@<0Uf/n202IJCT809a/?080UFXg00@0UV/h09M/>@2GK3T0V6dj
0P2IKS/809M[>P0409]_?P2JKSd0VVhm09Y^?@80VFdl0P2HK3/809Y_?0P0Vfln0P2KL3d309aa?P<0
WG8o1P2NLT4209ea@00809Y^?@2KKch0W70o09ea@02NLT40Wg=20:1d@`2QMD@:09mc@P80X7A3102Q
MD@20:1e@P030:5f@`2RMd@0XWM400@0XWM4102MM40409ie@@80X7E20P2QMT<20:9gA080XgQ5202R
Md@00`2RMd80XgQ30:=h@`040:=h@`030:9g@P2UNTL0YGY700H0YGY70P2WNdX00`2WO4T0Yga70:Ml
A@020:Mm@`030:Mm@@2XODP0Z7e80080Yga70P2VNdH20:EjA@H0YGY70P2VNdP80:AkA`80YW]8102W
O4T20:IkB080YG]100H0YW]40:IkAP2WO4T0Yga90:QlB`2XO4d20:MlB@80Z7e:00D0ZGi;0:QmBP2X
ODX0Z7e:0:IkAP020:MlA`030:QmB02YOTT0ZGi90080ZWm:0`2UNTL40:IkB0090:EjA`2VODT0Y7]7
0:5hA02OMT80WWE10:1g@`2RNDD0XgY600@0YGa80P2TNdL00`2SNTH0XWU50:5iA@030:5iA@040:1h
A02OMd<0WgM309if@P80WWE1102MM40209ac?`80W790102MLd4309ab@080Ug8n0P2FLCd01@2EL3`0
U6lk09A_>`2DKc/0UV`j00<0UF/i0P2DJSP209=Y=`<0Tfdn00<0TV`m095[?02AJc`00P2@JS/209=X
>`<0TVLj0`2AIST02`2>J3T0RfDf08QR<`2:I3D0SFLh08iX>@2<ISL0R68c08EO<027HC80R68c00<0
RV@e00@0R68c08MQ<P29HST0RF8i0P28HCP208MP=`80QUlf00<0QV4g08AO=@23GS@00`21G3800`22
GC<0Pehd085L<007085L<080OEP^00@0OUT_07mJ<01oFS00P5/a0P21G38807eG<080OUT]0`1oFRh3
081K;`0407iH<@1mEc00OEL`07eG<080O5H_2P1kEBh207iG;P0307eH;P1kF2h0NUT^0080NEX^00@0
MeX^07UF;01iER`0NEH/0`1hEB/207MD:P@0NeH/101lEbd307YG;@@0NeP^00P0O5T_07mH;@1nEb`0
O5DZ07]D:@1jDbP0Ne@Y07aE:P80OEH[00<0OUPa07aF;`1jE2d00P1gDBX01P1hDR/0NU@]07aF;`1h
EBl0MU<]07AA:`80LTlY00/0M54[07IC;@1hEBl0NEDa07MC;`1fDbd0ME8Z07EB:01fE2L0MeDX07UG
:@0807YD;@<0MU<[101gE2`00`1hEBd0MU<[07IC:`0207IC:`80Me@/0P1hEBd307YG;`80NeP`0`1l
FC4807aI;`<0O5L]0P1mF2h00`1nFBl0OeX`081K<@0207iI;0<0OeX]0`20Fbh01P24Gc80Peha089M
<021G2l0P5/^07iI;080OEP[00P0O5X/07iL;P20GS00PV0b08=Q<`21Gc40Oed_07eK;@80Peha00@0
Q5lb08EP<`26HC@0Qf8e0P28HcH208IQ=0@0Qf8e0P26HC@408MS<`80R6@d0P29ICD208US=00308YT
=@2;ICH0S6Hg0080SFLh00<0SVPi099X=P2BJ3H01P2BJ3H809E[>@80TVdi00@0Tfhj09A_>`2EL3`0
UG0l0P2FLCd309Ac?P0309Ib?P2GLSh0VG4n0080VW0n00@0Vfln09]b?P2KLSh0Vg8n0`2LLcl209ed
@0<0WgY50P2NND@309eh@`030:5h@P2RND<0Y7]50080YGa600@0Y7]50:=jA02RND<0Y7]50P2SNT@0
5@2TNdD0YGa60:MnB02YP4X0Zh9<0:b3C@2[PT`0ZX5;0:V0BP2XOdT0Ygi80:ImA`2UO4H0Yh9=0:J1
C02UP4/0Y7m:0:F0B`2VPD`0Z8=>0:V4C`0:0:b3C`<0[HA@0`2^QE440:n6DP@0[XEA1@2_QE<20;26
E0030;67E@2^RED0[XUE00H0[XUE202aR5@01P2^QE40[hIB0:n6DP2`Qe<0/HQD0;:9E@80/hYF0P2b
RED20;68E080/8MC0P2_QU820;>:EPH0]8]G202aR5@80:n:E@80[hYF0`2`ReL30;6<F0T0/XaK0P2c
SUX20;:=F@80/HaH0P2`ReL40;B:F0@0]H]I0`2aS5L30;2;EP80[hYE00H0/hiI0;:=F02bSEP0/HaG
0;2;EP2_RUD20:j9E080/XUE00<0/hYF0;B;E`2dReL00`2dReL@0;>:EPP0]HaH202`ReL40;67E@80
/8ID0P2_QE<0202^RE80[HQA0:^6C`2ZQDh0ZhI?0:b7D02]R540[XUB202]R5@20:j9E080[HQC0P2/
Qe820:^6D@<0[8MB0`2[QU420:Z5D0060;:8F02bR5H0/HQD0;27D`2`Qe40[hI>0P2^QT/00`2/Qe80
ZXE@0:V4C`020:R3CP030:V4C`2ZQE00[8MB00P0[HA@202^QE40102`Qe<0[hIB0:f4D02]Q5020:^2
CP030:b3C`2]Q500[XEA0080[HA@0`2/Pdl30:^2CPP0ZHA?00@0[8=?0:^2CP2[PTh0Zh9>0`2ZPDd0
0`2YP4`0[XEA0:j5D@060:j5D@P0[8=?0P2]Q5020:b3C`80Zh9>0P2ZPDd80:f4D0@0[8=?00@0[HA@
0:j5D@2^QE40[hIB202]Q4h80:f4D0<0[XEA0P2]Q5030:b3C`80ZH1<1P2ZPDd20:f4D0<0[8=?0`2[
PTh80:b2D080[85D00@0[89B0:b2D02/Pdl0[8==0P2/Pd/80:f4CPP0ZX1>102ZPDd40:^2CP80ZX5;
0`2[PT`0102/Pdd0[HA>0:f4CP2^QDl20:Z1C@80Zh9>00`0[8=?0:f4D02]Q500[HA@0:j5D@2]Q500
[8=?0:^2CP2ZPDd0ZH1<0:QoB`2WOTX40:^2CQ@0[8=?0P2ZPD/20:^2C080[8==0P2]Q4h20:f3D`04
0:f3D@2]Q500[HA@0:f4CP80[HA<202/Pdl00`2YP4`0ZX5=0:b3C`020:j5D@030:f4D02/Pdl0Zh9>
00X0ZH1:0`2ZPD/30:^2C100Zh9>00P0[85<0:^0B`2ZOdX0ZGi90:QmB02YOTT0Zh1;0:b1C080ZH1<
00<0ZX5=0:^2CP2[PTh00`2[PTh30:Z1C@80ZH1<0`2XOd/20:MnB0H0Z7m91P2YP4`20:Z1C@80[8==
0P2[PT`90:Z1B`@0ZH1:202YOdd00`2/P540Zgm@0:UmC0020:MlB@030:QmB02YOTL0ZWm80080Ygi:
1P2XOd/00`2ZPD/0ZH1:0:QoB@020:ImA`060:QoB@2YP4X0ZX5;0:Z1C@2XOd/0Ygi:0P2UO4P00`2W
OTX0Z7m;0:Z1C@030:Z1C@@0ZH1<00<0Z7m;0:V0C02YP4`00P2XOd/00`2WOTX0Z7m;0:QoB`070:Qo
B`80ZH1<00<0Z7m;0:V0C02ZPDd00P2[PTh00`2ZPDd0Z7m;0:MnBP030:V0C080Z7m;0`2WOTX40:V0
BP@0ZX5;202XOd/20:V0C0<0Z7m;0`2WOTX00`2YP4`0Z7m;0:ImB@030:ElB080Ygi:00<0YWe90:Mn
BP2YP4`00P2ZPDd00`2YP4`0Ygi:0:ImB@020:9iA@80XgY60`2TNdL0102UO4P0XgY60:=jAP2SNTH3
0:9iA@80XGQ400<0Y7]70:ElB02VODT00P2WOTX20:ImB@050:ElB02TNdL0YWa:0:EkB@2TNTP00P2R
N4H01P2TNTP0YG]90:IlBP2RN4H0XgU70:AjB080XgU700<0XWQ60:=iA`2TNTP0202SNTH30:9iA@<0
XgY60P2TNdL20:1jB@040:5lB02QO4L0XGa70:9mAP80XWi400<0XWe80:5lA`2PNdH00P2NND@00`2P
NdH0XGa70:9mB0060:Ej@`80YW]4202SNTH20:9mB0060:5lA`2ONTD0WWU409eh@`2LMd80VgI1202N
M4800`2LMd<0VgI209Ud@00209Qc?`0;09Ye@@2KMT80W7M30:=jAP2RNDD0XGQ40:1g@`2OMT80WWE1
09ed@02LLcl00P2NMD4209ed@0@0W7<o0P2JL3h209]a?`80W7900P2MLd4309ab@0<0Vg4o0P2JL3h8
09Ud?`<0VWE10P2IM40309Qc?`0309]a?`2JL3h0VW0n0080VFlm0P2HKS`00`2GKC/0Vg4o09]a?`07
09]a?`0309I`@@2EKd00Tfdn0080Tfdn00H0UFm009I`@@2HLT<0UFXm09M/?`2HKD0209U^@@0409Q]
@02GK3l0UFXm09I[?P80Uf`o00<0V6e009U^@@2JKd800P2KL4<309Y_@P0309U^@@2HKD00V6e00080
Uf`o00@0VWE109Ud@02GLSh0UW4m0P2EL3`0102FLCd0Ug8n09I`@@2EKd0309A^?`0309I`@@2HLT<0
VG=400P0UW1100<0VG=409Ma@P2EKd000P2CKCh01@2EKd00Ug5209UcA02BK3d0Tfdn0080U6ho0P2F
L4400`2GLD80V79309A^?@0209A^?B_ooooo000Zooooo`80Qe/f00H0R5`e08YO=@2;H3<0S68b08eS
<@2>I38208mO>@0308eP>@2<H3T0Rf4i0080RF8i00<0R6<i08eP=P2=H3H01P2>HCL308aQ=P<0SF8g
0P2>HcP00`2@ICX0SV<h08eR=`0208aQ=P0308eR=`2>HcP0T6Dj00P0S64f0P2?HST00`2?HSP0T6@g
091T=@02095U=003095V<`2BISL0TVHg00@0TFDf0P2BISL4095V>@@0T6Dh2@2AICP509=W>P0309AX
>`2EJC`0UFTl0080U6Pg00@0UFTh09IZ>@2FJST0Uf/j0P2HK3/00`2DJ3L0UVXi09M[>P0209Q/>`03
09M[>P2FJST0U6Pg00P0UFTh00<0Uf/j09IZ>@2EJCP00P2CIcH00`2EJCP0UVXi09M[>P0209EY?080
UVXm0P2GJch209Q/?`P0VFTi202LK3`209EZ=`0409I[>02GK3T0Uf`i09Q]>P80VFhk202GJcX0102K
Kd00VVho09Y^?`2JKSl209U]?P80V6`m202JKc`809a`?`<0W74n0`2MLSl209ic@080WG501P2NLT42
09]_?P0409a`?`2MLD00Wg=20:1d@`80XGE42`2OLd820:1d@`80XGE400<0XWI50:5f@`2QMT<00`2Q
MT<20:9gA080XgQ5102NMD4409ed@0@0XGI3102RMd@80:5f@`<0XgQ30P2RMd830:=h@`P0YGY70P2V
NTT00`2VNdP0YW]60:IkA0020:Il@P030:Il@02WO4L0Yga70080Yga7102VNdH20:IkB0H0YGY7202T
NdL20:MlB@@0YW]80P2WO4T20:Ek?`060:Il@P2VNd@0Yga70:MlB@2XODX0Z7a;0`2XODX40:MlB@07
0:QmBP2UNTD0YGY50:IkAP2WO4L0Z7e80:UnB@020:YoBP80YW]80P2UNTL01`2TNDH0YGY70:EjA`2U
NTL0YGa80:=jAP2PMd<00P2NMD40102OMT80XGQ40:=jAP2UO4P20:AkA`030:=jAP2RNDD0XWU500<0
XWU50P2QN4@00`2PMd<0WgI209mf@P0209mf@P80WWE10P2MM40209ac?`80Vg8n0P2LLT0409]a?`<0
W7900`2EL3`409A_>`0309=^>P2EJcT0UF/i0080U6Xh0`2CJCL0102BJ3H0TF/l095[?02AJc`4091Z
>`0408mY>P2BIcX0TVLj099W>P<0TFHi0P2@ICP02`2=IcP0RF<d08MQ<P28HS<0S6Hg08iX>@2;ICH0
R68c08AN;`26H340Qf4b00<0RF<d00<0Qf4b08IP<@27H3L00`27H3L408IO=P0308EP=P24GcD0PUdc
00<0P5/a00<0PE`b089M<`21G3801`21G38207aG;@0407eH;P1nFBl0OUT_07mJ<080P5/a201lERl3
07eH;P<0OUT_0P1oFS0207eG<080O5H_0`1kEBh907YD;@80O5D^00<0NeD^07UF;P1hEbh00P1gEbh0
0`1eF2h0N5D]07QE;@0307MD;0<0MU<[00<0N5<Y07UD:P1iE2X00P1jEB/207]F;00507aG;@1gER/0
MeH[07MF:`1hEb`00P1iF2d207YI;P0307iG;P1mERd0Ne@[0080NE8Y00L0NU<Z07]D:`1lEB`0O5D/
07eG<01kEBh0N58[0080MU0Y00H0Me4Z07UC;01kEBh0Me@^07EB;01cD2X2075>:00;07=@:P1eDR`0
Me@^07QD<01gDbl0ME8/07AA:@1dDBL0ME<V07ME:01hERP0201iDb`207AA:@80ME8Z00@0MU<[07MD
;01gE2`0Me@/0`1eDRX307IC:`80Me@/0`1iERh207YG;`<0NeP`0P1jEbd407]H;P80NUL]0P1lEbd2
07eH;P<0OUT_00@0OEP^07eH:`1mF2/0OEP[0`1nFB`207mJ;@0608=N<@22GC00PE`_081K;P1oFRd0
OEP[0P1lEbX0201jF2X0O5X/07mM;`21Gc40PV0b085O<@1oGBl0OE/]0P22GC001023GS40Q5lb08EP
<`25H3<408IQ=0@0QF0c0P26HC@308IR<P<0Qf<c0P28I3@208QR<`0308US=02:I3D0RfDf0080S6Hg
00<0SFLh095W=@2AIcD01P2AIcD809=Y=`80T6/g00H0TF`h099]>@2CKSX0U6lk09E`?02FLCd3099a
?00309A`?02EL3`0Ufll0080V6hl00<0VFdl09Ya?@2JLCd00`2KLSh309ac?`<0WWU40P2MN4<309ag
@P0609mf@02QN480XgY40:AkA@2UO4H0Y7]50P2SNT@0602SO4D0XW]40:5j@`2QNT<0Xga50:EnA`2X
PDX0ZX=<0:^2C02ZPD/0ZH1:0:QoB@2WOTP0YWe70:ElAP2TNdD0Yh9=0:J1C02UP4/0Y7m:0:F0B`2V
PD`0Z8=>0:V4C`/0[8=?0`2]Q50:0:j5D@80[XAB00<0[hEC0;26E02aQeD00`2aQeD80:j9E@P0/HQD
0P2_QU820;27D`040;68E02bRED0/XUE0;>:EP80/XUE102aR5@20;27D`H0]8]G0P2cRUH80;68E0P0
[hYE0P2_RUH30;2;E`<0/HaH2@2bSET20;>>FP80/XeI0P2aS5P20;2;E`@0]H]I102dRUP30;6<E`<0
/8]F0P2_RUD01P2cSUT0/XeH0;:=F02aS5L0/8]F0:n:E@80[XUD102bRED0102cRUH0]8]G0;F<F02e
S5P<0;>:EP@0]8]G202eS5P80;2;E`<0/XQF0`2aQeD20;26E0030:n:D`2^RE80[8M@0080ZhI?00<0
[8M@0:f8D@2^RE80202]R5@20:j9E080[HQC0P2/Qe820:^6D@<0[8MB0`2[QU420:Z5D0060;:8EP2b
RED0/HQD0;27D@2`Qdl0[hM<0P2^QTT00`2/Qe80ZhIA0:Z5D0020:R3CP030:Z5D02[QU40[8MB00P0
[HA@202^QE40102`Qe<0[hIB0:f4D02]Q5020:^2CP030:b3C`2]Q500[XEA0080[HA@0`2/Pdl30:^2
CPP0ZHA?00@0[8=?0:^2CP2[PTh0Zh9>0`2ZPDd00`2YP4`0[hIB0:n6DP060:n6DPP0[8=?0`2]Q502
0:b3C`<0Zh9>202]Q500102[PTh0[8=?0:b3C`2]Q5040:j5D@P0[HA>202]Q5030:j5D@80[HA@0`2/
Pdl01@2[PTh0ZX5=0:Z1C@2ZPDd0ZH1<00<0ZX5=0P2]Q5030:b3C`<0Zh9>202/PU020:b2DP040:b2
D02/Pdl0[8==0:b3B`80[8A9202]Q4h80:^1C`80ZH1<0P2ZPDd20:^2CP80[8=?00<0ZH1:0:Z1B`2Z
PD/00P2[PT`0102/Pdd0[HA>0:j5C`2^QDl30:^2CP@0[8=?00T0[HA@0:j5D@2]Q500[8=?0:^2CP2Z
PDd0ZH1<0:QoB`2WOTX0302/Pdl40:^2CPP0[8=?0`2[PT`20:b3C@<0[HA>0P2^Q5@0102^Q580[XEA
0:j5D@2^QDl20:j5C@P0[8=?00P0Z7m;0:Z1C@2/Pdl0[HA@0:j5D@2]Q500[8=?0:^2CPP0ZH1:0`2Z
PD/30:^2C080[8==202ZPDd80:^2CP080:b1C02[P4/0ZGi90:QmB02YOTT0ZWm:0:^0B`2/PD`50:Z1
C@030:^2CP2/Pdl0[8=?0080Zh9>0P2ZPDd20:V0C080Z7m;0P2YP4X60:QoB@80ZH1<0`2ZPDd20:V0
C0030:QoB`2[PT`0Zh9<0080Zh9<0`2ZPD/:0:V0BPP0ZX1>00<0[81A0:]oD02YOD`00P2WO4T00`2X
ODP0ZGi70:YoB0020:V0C0H0Z7m;00<0ZX5;0:QoB@2WOTP00P2VODL01P2WOTP0Z7m90:Z1B`2ZPDd0
ZH1<0:QoB`80Ygi:00<0Z7m;0:V0C02ZPDd00P2[PTh20:Z1C@040:V0C02XOd/0Z7m;0:QoB`80Ygi:
0P2XOd/00`2YP4`0Z7m;0:QoB`070:QoB`<0Ygi:00L0Z7m;0:Z1C@2[PTh0Zh9>0:Z1C@2YP4`0Z7m;
00<0ZH1<0P2XOd/30:MnBP030:QoB@2YP4X0ZH1:0080ZX5;0P2[PT`00`2/Pdd0Z7m;0:QoB`060:Qo
B`<0ZH1<0`2XOd/20:MnBP040:Z1C@2YP4`0Ygi:0:ImB@80YGa800D0YWe90:MnBP2VODT0Ygi:0:V0
C0020:Z1C@030:V0C02WOTX0YWe900<0XgY60P2TNdL30:ElB080Y7]70P2SNTH30:9iA@040:5hA02T
NdL0YGa80:ImB@80Ygi:0P2VODT01@2UO4P0Y7]70:IlBP2UNdT0Y7Y80080XWQ600H0Y7Y80:EkB@2V
O4X0Y7Y80:=iA`2RN4H20:=iA`030:AjB02SNDL0XWQ600P0XgY60P2RNDD30:=jAP<0Y7]70P2PNTT0
102QO4P0XGa70:5lA`2RODH20:9nA0030:9mB02PNdH0WgY50080WWU400<0WgY50:1kAP2RODP00P2V
NdH60:EjA@P0XgY60P2RODP01P2QO4L0WgY509iiA02MN4<0W7M209]f@@P0WWA200<0WGQ409ag@`2J
MD400P2IM4000`2JMD40VgI209ag@`020:9iA@040:5hA02PMd<0WWE109ed@080W7<o0`2NMD4209ed
@080W7<o00<0Vg8n09]a?`2KLCl00P2KLCl409ab@080WG=10`2LLT0309]a?`P0VG@o0`2JMD4209Ud
@0<0V7<o0P2JL3h409U_?@80V6hl2@2KLCl00`2FL440UFm009=]?P0209=]?P0609E_@02FL440V793
09I[?P2GK3l0VFi10P2JKd800`2IKT40Uf`o09I[?P0209M/?`0309Q]@02IKT40VVm20080Vg1300@0
W75409Y_@P2JKd80VVm2102IKT40102HKD00VWE109Ud@02GLSh309Ia?@80V7<o00P0Ug5209I`@@2E
Kd00U6ho09E_@02FL440V79309UcA0P0UW1100<0VG=409Ma@P2EKd000P2CKCh00`2EKd00Ug5209Uc
A00309E/?P0309I]?`2GKT00V6m10080V6m10`2CKCh[ooooo`00:_ooool02029G3/0REdj08UM>02:
GcD0Rf0c08aR<02=I300SF@^0P2?GcT00`2=H3T0S60i08]Q>@0208UR>@0308QS>@2=H3H0SF0f00<0
SV4g0`2?HSP308aQ=P80SF8g0`2>HcP00`2@ICX0SV<h08eR=`0208aQ=P0308eR=`2>HcP0T6Dj00P0
SF8g0P2?HST00`2?HSP0T6@g091T=@02095U=003095V<`2CIcH0TVHe00@0TFDd00<0TVHe09=W=P2A
IST01`2AIST9095U>080TfLj0`2BIST00`2CIcX0UFTl09IZ?@0409EY>0<0UVXi00@0Uf/j09AX=`2F
JST0Uf/j0P2HK3/00`2GJcX0UVXi09AX=`0809EY>00309M[>P2FJST0UFTh0080U6Pg00<0UFTh09IZ
>@2GJcX00`2FJSd209M[?P<0V6`o202IJCT809][>`<0Uf`i0P2HKCX309U^>`<0VFdl0P2HK3/309M[
>P80W7130P2KKd8209Y^@@80VFe0202JKc`809a`?`<0W74n0P2MLSl309ic@0<0WG500`2NLT4209mc
@P0509a`?`2MLD00WG5009ib@@2OLd800P2PM4<00`2QMD@0Wg=209mc@P0609mc@P80X7A30`2OLd80
1@2PM4<0XWI50:=gAP2RMd@0XGI300<0X7E20P2RMd@00`2SN4D0Y7U60:1g@`0309mf@P<0WWE100<0
WGA00:5f@`2QMT<00P2QMT<40:9gA0P0XGI300<0Y7U40:=h@`2RMd800P2QMT400`2RMd80XgQ30:Ai
A0080:EjA`80YWY900<0YW]80:IkAP2VNd@00P2VO4800`2VO400Yga70:MlA`020:MlA`@0YW]60`2V
NdP30:EjA`80Y7U6202TNdL00`2XODX0Yga90:IkB0020:EjA`030:IkB02WO4T0Z7e:0080YG`n00H0
YWa00:Il@P2WO4D0Yga70:QmB02XODX20:UnB`040:MlB@2VNdP0YW]80:IkB080Yga900D0Y7U40:Ej
A@2UNTD0YW]60:MlA`030:QmB0040:MkBP2VNTT0YGU80:AhA`80XgM600H0Y7Q70:EiB02TNdL0XgY6
0:9iA@2QN4@20:1g@`050:5hA02RNDD0Y7]70:=jAP2QN4@00`2PMd<20:5hA0030:=hA@2RMd@0X7E2
00<0WgA10P2PMD8209ie@@80WGA000L0W7<o09]b?P2JLCd0VW4m09]a?`2JL3h0VFlm0080V6hl00D0
VFlm09Y`?P2JL3h0Vg4o09A_>`0709=^>P80U6Xh0P2CJCL3099X=P03095W=@2?JCX0SfTj00H0SfTj
0`2BIcX2095V>@<0T6Dh00/0RfDf08QR<`26H340Qf4b08]U=P2=IcP0RfDf08QR<`26H340Qf4b08QR
<`0208US=00308QR<`26H340QEl`00L0QUlf00@0QEhe08AO=@23GS@0PE`b0`1oFS02085L<PP0P5Xc
0P1lEbd307eH;P<0OUT_201lERl207]E;P80O5H_0`1mEc000`1nF340O5H_07aF;`0207]E;P<0NU@]
2@1iDb`207]C;`0307YD;`1hEBl0MeD_0080MUH_00<0M5L_07MD;P1fDbd00P1fDbd207EB;080M54[
00H0MU4W07MB:01gDRP0N5<Y07UD:P1jEB/207]F;080M5DY0P1eERX01`1fEb/0MeP/07QI;@1hFBd0
OEH_07]D;@1jDb`00`1hDBX01P1iDR/0NU</07YC;01hEBd0Me@/07IC:`<0M54Y0P1eDRX207EB;004
07AA:`1cD2X0Le0Z07AA:`80ME8/00P0Me<_07IB;P1dDB/0Le0X07=@9P1dDRD0MU@W07ME9`P0N58[
0P1cD2P207AA:@0407EB:P1fDb/0Me@/07MD;0<0M54Y0P1eDRX307IC:`<0Me@/0P1hEBd307UF;P03
07QE:`1iER`0NUL]00<0NUL]00D0NEH/07QE:`1kER`0O5L]07eH;P0207iI;`0307eH;P1lEbd0NeH/
0080NeHY0P1lEbX307eH:`0607iI;021G2l0P5/^081K;P1oFRd0OUT/0P1mF2/01@1lEbX0NUPZ07]I
:`1mFbd0OU`^00@0Oed_00H0P5/^085L;`21G2l0PUd`08=N<@24Gc8208EP<`0308IQ=025H3<0Q5lb
0080Peha00<0Q5lb08EP<`26HC@00`25HC4208IR<P<0Qf<c0P27HC800`28HS<0RF<d08YT=@0208]U
=P0308aV=`2@IS@0T6Hd00H0T6Hd202BJ3H208iY=@0608mZ=P2AK3P0TVdi09=^>P2DKc/0UG0l0`2A
L3/00`2CKc/0U6lk09I^>`0209M]>`0409Q/>`2JLCd0VW4m09Ya?@80Vg8n0`2LLcl809ag@P0509ie
?`2PMd40XWU30:AkA@2UO4H00P2TNdD02P2SNT@0Xgi70:5lA@2ONT<0WWU209mj@`2RODH0YH190:N2
B`2YP4X20:QoB@0=0:MnB02VODL0YGa60:ElAP2TNdD0Yh9=0:J1C02UP4/0Y7m:0:F0B`2VPD`0Z8=>
0:V4C`0:0:^2CP80[8=?0`2]Q5000`2^QE40[8=?0:f4D0020:f4D0<0[XEA00D0[hIB0:f3D@2^Q580
[hEC0;67E@030;:8EP030;67E@2^RED0[XUE00H0[XUE402aR5@30;:9E@D0/HQD0P2dReL30;>:EP<0
/XUE202aR5@80:j9DP80[hYF0`2`ReL30;6<F0T0/XeH0P2cSUX20;:=F@80/HaH0P2`ReL0102fS5X0
]H]I0;F;F@2eReT30;B:F0040;>9E`2aS5L0/HaG0;6<E`<0/8]F0P2_RUD30;6<E`<0/8]F0P2_RUD2
0;:9E@060;68E02bRED0/XUE0;B;E`2fSET0]hiJ2`2cRUH20;B;E`/0]HaH202`ReL30;>9E`80/XQF
0`2aQeD0202`Re@0[hYC0:f8D@2/Qe00ZhI?0:b7D02]R540[XUB202]R5@20:j9E080[HQC0P2/Qe82
0:^6D@<0[8MB0`2[QU420:Z5D0060;27D`2`Qe40/8MA0:n6CP2_Qd`0[XI90P2^QTP00`2/Qe80ZhIA
0:Z5D0020:V4C`030:Z5D02[QU40[8MB0100[XEA00@0/8MC0:n6DP2]Q500[HA@0P2[PTh00`2/Pdl0
[HA@0:j5D@020:f3D@<0[89@0`2[PDl80:V4C`@0ZX5=102[PTh80:n6DPP0[8=?00@0[XEA0:f4D02]
Q500[HA@0P2/Pdl20:^2CP<0[XEA0P2]Q5030:b3C`80Zh9>00<0[HA@0:j5D@2_QU800P2^QE40102]
Q500[XE?0:j5C`2^QDl20:f4CP<0[8==202/Pdl30:j5D@80[HA@0`2/Pdl00`2]Q500[8=?0:^2CP03
0:Z1C@80Zh9>0P2]Q5030:b3C`<0Zh9>2P2[PDl00`2[PTh0Zh9<0:^2BP020:^3B0030:^3AP2^QDl0
[XE?00H0[XE?202/PU001@2XOd/0ZH1<0:V0C02ZPDd0Zh9>0080[8=?00<0[HA@0:Z1B`2ZPD/00`2[
PT`0102/Pdd0[HA>0:f4CP2^QDl80:b3C`050:f4D02/Pdl0[8=?0:^2CP2ZPDd00P2YP4`00`2XOd/0
[XEA0:f4D0020:f4D0<0[8=?00@0Zh9>0:b3C`2/Pdl0[8=?0P2[PTh30:Z1C@P0[8=?0P2[PT`20:b3
C@<0[HA>00@0[XE?0:f3D`2]Pe<0[H=A0P2]Q5000`2]Q4h0[HA<0:f4C0080:b3C`030:QoB`2YP4`0
Zh9>0080[HA@00<0[8=?0:^2CP2ZPDd0202YP4X30:Z1B`80Zh9<0`2/Pdd80:Z1C@P0Zh9>00X0Zh1;
0:YoBP2YOTT0Z7e80:UnB@2ZOdX0[85<0:f2C@2[PTh0ZX5=0`2YP4`00`2[PTh0[8=?0:f4D0030:^2
CP80ZX5=0`2YP4`20:Z1B`80ZH1:102XOdT0202YP4`0ZX5=0:Z1C@2[PTh0ZX5=0:V0C02XOd/0Ygi:
0P2ZPD/40:^2C0040:Z1B`2XOdT0Ygi80:MnB0<0Z7m90`2YP4X00`2ZPD/0ZX1>0:Z0CP060:Z0CP03
0:b0D@2[Oe00ZGe<0080Yga900<0Z7e80:UnA`2ZOdP00P2ZPDd20:V0C0@0Z7m;00<0ZH1:0:QoB@2W
OTP00P2VODL00`2WOTP0Z7m90:V0BP020:Z1C@@0ZH1<0P2ZPDd01P2/PU00Zh5?0:^1C`2ZP4h0ZGm=
0:QnC080Yge;00<0YWe90:MnBP2XOd/00`2YP4`60:QoB`80Ygi:0`2VODT00`2XOd/0ZH1<0:^2CP02
0:^2CPD0ZH1<0P2XOd/30:MnBP80Ygi800<0Z7m90:V0BP2ZPD/00P2[PT`00`2/Pdd0Z7m;0:QoB`06
0:QoB`80ZX5=0P2YP4`30:QoB`050:MnBP2/Pdl0ZX5=0:QoB`2VODT00P2UO4P01@2VODT0Ygi:0:Im
B@2WOTX0ZH1<0080ZX5=00<0ZH1<0:MnBP2VODT00P2TNdL20:ElB0<0YWe900@0Ygi:0:ElB02UO4P0
YGa80P2TNdL30:=jAP030:AkA`2UO4P0YWe90080Ygi:0P2VODT01@2UO4P0Y7]70:IlBP2UNdT0Y7Y8
0080XWQ600/0Y7Y80:EkB@2VO4X0YWa:0:=iA`2QMdD0XWQ60:AjB02UNdT0XgU70:1fA0030:9iA@80
XgY60`2TNdL0102RNDD0XgY60:=jAP2SNTH20:AkA`80YGa80P2PNTT0102QO4P0XGa70:5lA`2RODH2
0:9nA0030:5lB02PNdL0WgY60080WWU500<0WgY60:1kA`2QO4P00`2VNdP30:EjA`80Y7U6202SNTH2
0:5lA`040:1kAP2ONTD0WWU409iiA080WGQ30`2MLd4209id@P<0WgE300T0WgY609iiA@2LMd<0VgI2
09Ye@@2KMT80W7M309ehA02QN4@00P2PMd<01@2OMT80WWE109ed@02MM400W7<o0080WGA00`2NMD40
0`2MM400Vg8n09Ya?@0409]a?`@0W7900`2MLd4209ab@0<0Vg4o202IM3l309Ud@080V7<o0`2GLSh8
09U_?@T0VW0n00<0Ug5209I`@@2DKSl00P2CKCh01P2DKSl0UFm009I`@@2GK3l0V6e009Y_@P80Vg13
00@0VVm209Q]@02GK3l0Uf`o0P2HKD000`2IKT40VVm209]`@`0209aaA0P0VVm200<0VWE109Ud@02G
LSh00P2FLCd01@2GLSh0VGA009Ye@@2GLD80UW1100<0UFm000<0Ug5209Qb@`2JM4D02P2GLD8409E_
@080Ug52202GK3l3099/?b_ooooo000Zooooo`0808]N?`2;GSd0Rell08]P=P2;H3<0Rf4_08]R;02;
HRX208mO>@0308eP>@2<H3T0Rf4i0080RF8i00<0R6<i08eP=P2=H3H00P2>HCL208mR>080T6<i00@0
S64f08eR=`2=HSL0SF8g0P2>HcP208mT>@03091U>P2>HcP0SF8g0080S64f00<0SF8g08iS>02@ICX0
202?I3T208mR>@0308mR>02@I3L0T6@e0080TFDd00@0TFHc09AX=`2CIcH0TFDd0P2@I3<00`2AIC@0
TfLf09AX=`05095V>@<0TVLj2@2AICP00`2CIcX0TVHi095U>002095U>00309=W>P2EJC`0UVXm00<0
UVXi0`2EJCP309AX=`0709IZ>@2GJcX0V6`k09Q/>`2GJcX0UVXi09AX=`0809EY>00309Q/>`2GJcX0
UFTh0080U6Pg00<0UFTh09M[>P2HK3/00P2FJSd209M[?P@0V6`o202IJCT809][>`@0VVll102IKS/2
09]_?P80VVhm0P2IKC`209Q/>`<0WG540P2LL4<309]_@PP0VVll202LL3l0102LLCh0WG8o09eb?`2M
LSl209ic@080WgA10P2LL3l209ea@00309ib@@2OLd80Wg=20140Wg=200d0XGE40:1d@`2OLd80WW91
09mc@P2PM4<0XWI50:=gAP2RMd@0XGI30:1e@P2OM440X7E20080XGI300<0XgQ50:EjA`2RNDD00P2Q
N4@20:1g@`80WgI200<0WWE10:9gA02RMd@00P2RMd@40:5f@`P0X7E200<0YGY50:AiA02RMd800P2Q
MT400`2RMd80Y7U40:EjA@080:EjA`80YGU800<0YGY70:EjA@2UNT<00P2UNd400`2UNcl0YW]60:Ik
AP020:IkAP@0Yga70P2WO4T20:IkB0040:EjA`2TNDH0Y7U60:AiAPP0Y7]700<0Z7e:0:MlB@2VNdP0
0P2UNTL02@2VNdP0Yga90:QmBP2UO3`0YG`n0:Im?`2VO400Yge30:MlA@020:QmB0080:YoC02YOT/0
Yga90:EjA`2TNDH0YGY70:IkB02WO4T30:EjA@D0YW]600@0Z7a=0:IjB`2TN4T0XgM80P2RMTL20:Ah
B@80XgY60`2TNdL01P2SNTH0XGQ40:1g@`2RNDD0XGQ409mf@P<0WGA00100WgI20:1g@`2UMdD0XgE3
0:5c@@2PLT00Wg4o0:1b@02QLd40XWA209mf@P2NMD40WGA009ac?`2KLSh0VW4m0P2IL3`00`2IKcd0
V6hl09M]>`0209I/>P0409M]>`2HKS`0V6hl09U_?@<0TVdi1@2CKSX309=Y=`80TVPf0`2AIcD00`2=
IcP0SVPi08iX>@0508iX>@04099W>P2AIST0TFHi095V>@80T6Dh0P2?I3L0202:I3D0Qf4b08EO<027
HC80RfDf08eW>02;ICH0R68c0P29Hc@308YT=@0308QR<`26H340Q5h_00P0QEhe00P0Pehd089M<`20
Fc40OeX`07iI;`1oFS00P5/a085L<PP0OeTd101mF2h307aG;@0307]F;01mEc00OEL`00H0OEL`0P1j
E2l207]E<0<0O5Ha00@0OELb07]E;P1kEBh0NeD^0P1jE2d307UC;0P0N58[0P1jDRl00`1iDbl0Me<_
07ID;`0207EE;`0307=E;`1fDRh0ME4]0080ME4]0P1dD2`207=?:`80ME0V00H0MU4W07MB:01hDbT0
NE@Z07YE:`1kER`2079C9`0307=D:01dEBT0MEHZ0080MeP/00@0N5T]07aD<01jDRh0NE4]0`1gCb/0
1@1hD2`0NE4]07UA;@1cDRT0M5<Z0080ME@[00@0M5<Z07=B:@1bDBP0LE0W0P1dDB/0101eDR`0MU<]
07IC;@1eDR`207AA:`0807IB;P1eDBd0Le0Z079?9`1bCbD0Le4T07EC9P1fE2H807MA:P06075>9P1b
CbL0Le0X07AA:@1eDRX0MU<[0P1gE2`307=@:080M54Y1P1eDRX207IC:`<0Me@/00<0MU<Y07MD:P1i
ER`00P1jEbd01P1iER`0Me@Z07IC:@1kER`0O5L]07eH;P80OUT_00<0OEP^07]F;01jEB/00P1jEBP2
07]F:@<0O5LZ00<0OEP[07iI;01nFB`0101nFB`207eH:`@0NeT[00D0O5X/07iL;P20GS00PEla07mJ
;@02081K;P03085L;`22GC00Peha0080Q5lb00<0QV4d08EP<`23GS400P22GC000`23GS40QF0c08IQ
=00308AP<080QF4a0`26HS801P26H340Qf4b08MQ<P28HS<0RF<d08YT=@80RfDf202?IC<8095W=@06
08aW<`2=J3@0SVTe091[=`2AK3P0Tfhj0P2DKc/3091_>P03099^>P2CKSX0UFdj0080UV`j00<0Uf/j
09U`?02IL3`00P2JLCd309]b?P0609ac?`2IM3l0VWE009Ye@02KMT40W7M20P2MN4<01@2NND@0WG@n
09mf@02QN480XgY400<0Y7]500@0XgY40:F0B@2SOTL0X7]40P2NND800`2PNd@0Xgi70:F0B@080:Im
A`080:N2C@2VPD`0YH1;0:AoBP2UP4/0YX5<0:R3CP2YQ4l;0:^2CP80[8=?0`2]Q5030:b3C`030:f4
D02^QE40[XEA0080[hIB00@0[89@0:f3D@2`QU@0/XQF0P2cREL00`2bR5H0/HME0:j9E@070:j9E@P0
/HQD0P2cRUH00`2bRED0/HQD0;27D`020:n6DP030:j5D@2aR5@0/HQD00H0/XUE0P2cRUH20;:9E@04
0;68E02`Qe<0/8MC0;27D`P0/HQD202^RU020:n:EP<0/8]G0`2aS5P90;:=EP80/hiJ0P2bSET20;6<
F080/8]G0P2fS5X20;F;F@80]8YH0P2cREL30;6<E`<0/8]F102_RUD30;2;EP<0/HaG0P2bRED20;68
E0040;:9E@2dReL0]XeI0;R?F`/0/hYF00<0]8]G0;F<F02eS5P00P2fSET80;F<F0P0/8]G0`2dRUP2
0;>9E`<0/XQF00P0/HaE0;2;E02^RE80[8M@0:^6C`2/Qe00[HQA0:j9DPP0[HQD0P2^RE@20:f8D`80
[8MB0P2[QU430:b7DP<0ZhIA0P2ZQE020:f4CP030:f4C02]QDX0[XI90080[XI800@0[XM60:f8D`2/
Qe80ZXE@0P2YQ4l00`2ZQE00[8MB0:f8D`0@0:j5D@040;27D`2_QU80[HA@0:f4D080Zh9>00<0[8=?
0:f4D02^QE400P2]Pe<30:b2DP<0Zh5A202YQ4l01@2XOd/0ZH1<0:V0C02ZPDd0Zh9>0080[8=?00<0
[HA@0:n6DP2_QU801P2_QU880:b3C`80[XEA0`2]Q5030:b3C`030:n6DP2^QE40[XEA0080[HA@0P2/
Pdl0102[PTh0ZX5=0:^2CP2]Q5020:n6DP040:j5D@2]Q500[8=?0:n6D080[XE?0P2]Q4h20:b3C@03
0:^2C02/Pdl0[8=?00H0[8=?0`2^QE420:f4D0<0[8=?00L0/8MC0:n6DP2]Q500Zh9>0:Z1C@2[PTh0
[8=?00<0[HA@0`2/Pdl30:^2CPP0Zh5?0P2[PTh0102[PT`0Zh9:0:^3B02[PdP20:^3APP0[hI@202]
Pe420:QoB`040:V0C02ZPDd0Zh9>0:b3C`80[HA@0`2[PT`60:b3C@H0[8=?1P2[PTh40:Z1C@<0[XEA
00<0[HA@0:b3C`2/Pdl00P2[PTh30:b3C`030:^2CP2ZPDd0ZX5=0080ZH1<202/Pdl30:b3C@<0[HA>
0P2^QDl20:b2DP040:b2D02/Pdl0[8=?0:b3C@80[8=;202/Pdl0202XOd/0ZH1<0:^2CP2/Pdl0[HA@
0:b3C`2[PTh0ZX5=202YP4X0102ZPD/0Zh9<0:^2C02[PT`20:b3C@80[HA>202YP4`80:^2CP80ZWm:
00h0ZGi90:QmB02YOTT0ZWm:0:b1C02^Pdh0Zh9>0:Z1C@2YP4`0Z7m;0:V0C02ZPDd0[8=?0:j5D@@0
Zh9>0P2ZPDd20:V0C0030:^2C02ZPD/0ZX5;0080ZH1:0P2XOdT00`2WOTP0ZH1<0:Z1C@030:^2CP07
0:V0C02WOTX0YWe90:V0BP2ZPD/0Zh9<0:b3C@020:^2C0030:Z1B`2XOdT0YWe700<0Ygi800<0Z7m9
0:V0BP2YP4X00P2ZPD/80:Z0CP030:b0D@2[Oe00ZGe<0080Yga900@0Z7e80:UnA`2ZOdP0Zh9>0P2Z
PDd20:V0C080Z7m;00@0Ygi:0:V0BP2XOdT0YWe70P2UO4H00`2VODL0Z7m90:V0BP080:Z1C@80[89B
00T0Zh5A0:Z0D02YOdl0Z7i>0:MmC@2VO4`0Y7]70:ImB@2XOd/00`2ZPDd00`2YP4`0Z7m;0:V0C002
0:QoB`80Ygi:0P2VODT0102UO4P0YWe90:MnBP2YP4`30:^2CP030:Z1C@2YP4`0ZH1<0080ZH1<0P2X
Od/30:MnBP060:ElAP2VODL0Ygi80:QoB@2YP4X0ZX5;0P2[PT`80:QoB`<0ZX5=0P2YP4`30:QoB`04
0:b3C`2[PTh0ZH1<0:MnBP80YGa800D0YWe90:MnBP2VODT0Ygi:0:V0C0020:Z1C@030:V0C02WOTX0
YWe90080YWe90P2WOTX40:QoB`<0Ygi:0P2VODT30:ElB0030:AkA`2UO4P0YWe90080Ygi:0P2VODT0
1@2UO4P0Y7]70:IlBP2UNdT0Y7Y80080XWQ600`0Y7Y80:EkB@2VO4X0Z7i<0:AjB02PMT@0XGM50:Ek
B@2VO4X0XWQ609id@P2QN4@20:9iA@80XgY60P2TNdL0102UO4P0XgY60:=jAP2SNTH20:AkA`<0YGa8
0P2PNTT0102QO4P0XGa70:5lA`2RODH20:9nA0030:5kBP2PNTT0WWQ70080WGM600<0WWQ70:1jB@2Q
NdX00P2WNdX20:IjB@040:EiB02TN4L0Y7Q70:AhA`P0XgY61`2ONTD0102NND@0W79009ec@@2MLd42
09id@P80WgE300D0X7I40:5lB02PNdL0WWU509ehA00209ag@`0309ehA02NNDD0WWE100L0WWE100P0
W7<o09ed@02NMD40WgI209ie@@2MM400Vg8n09Ya?@@0W790102KLCl209id@P80WG=10`2LLT000`2K
LCl0VG@o09Ud?`0609Ud?`80V7<o0P2GLSh209Ia?@80UG0l202IKcd909Q^?00309UcA02GLD80UFm0
00<0Tfdn0P2DKSl00`2HKD00VFi109]`@`0209aaA00309]`@`2IKT40V6e00080V6e000@0VFi109Y_
@P2KL4<0Vg130P2LLD@809Y_@P0;09Ye@@2IM400Ug8n09Ia?@2GLSh0V7<o09Ud@02KMT80V79309Ma
@P2FL4400P2EKd000`2GLD80VG=409YdA@0809Ma@P80UFm0102GLD8209E_@080VFi100<0V6e009M/
?`2FJch00P2EJSd0102DJC`0TFXo095Z?`2AJSl[ooooo`00:_ooool0202<Gd80S5m008aP?@2;GcP0
Rf0c08]R;P2:HBT0RV8W0P2?GcT00`2=H3T0S60i08]Q>@0208UR>@0308QS>@2=H3H0SF0f0080SV4g
00@0Sf8h091S>@2@HcT0TF@j102=HSL208iS>080Sf@i00<0T6Dj08iS>02=HSL00P2<HCH00`2=HSL0
SV<h091U>P08091U>P80Sf8i00<0Sf8h091T=`2@I3D00P2AIC@0102AIS<0UFXg09=X=@2BIc@2091U
<P03099W=02CJ3D0UFXg00@0TFHi102BIcX9095U>00809AX>`2BIST0TFDh091T=`2AICP0TVHi09AX
>`2FJSd209M[>P0409IZ>@2EJCP0UFTh09AX=`80TfLf00<0U6Pg09IZ>@2GJcX00P2HK3/00`2GJcX0
UVXi09AX=`0809EY>00309Q/>`2GJcX0UFTh0080U6Pg00<0UFTh09M[>P2HK3/00P2FJSd209M[?P<0
V6`o00<0VFe009UY>@2IJCT01P2IJCT809][>`0509eb?`2LLCh0W74n09]`?@2JKc`00P2IKS/01P2H
KCX0W70o09a`?`2LL3l0Vfln09Y^?@<0VFdl0`2NLDL209e`AP<0W6m5202JKc`809a`?`@0WG8o0P2N
Ld0209md@@80W70o0P2MLD000`2NLT40Wg=209mc@P040:1d@`80Wg=20`2NLT4809mc@P030:5eA02P
M4<0Wg=20080WW9100H0X7A30:9fA@2TN4L0XgQ50:5f@`2PMD8209md@@80XGI300D0XgQ50:EjA`2S
NTH0XgY60:9iA@020:5hA0030:1g@`2OMT80WgI200@0XWM4102QMT<80:1e@P030:EjA@2TND@0XWM2
0080XGI100<0XWM20:AiA02UNTD0202UNTL20:EiB0030:EjA`2UNTD0YGY30080YG]100<0YG/o0:Ik
AP2VNdH00P2VNdH40:MlA`80Yga90P2VNdP0102UNTL0Y7U60:AiAP2SN4D80:AkA`030:UnB`2WO4T0
YW]80080Y7U600<0YW]80:MlB@2YOT/00P2UO3`03P2VOCl0YWa00:Mm@`2WO4D0Z7e60:QmB02[P4d0
ZGi;0:MlB@2UNTL0Y7U60:EjA`2VNdP0Yga90`2VNdH50:EjA@0K0:QlC@2WNd`0Y7Q90:9fA`2QMDH0
XWI70:=gB02TN4T0XWU50:=jAP2VODT0Ygi:0:ImB@2TNdL0XGQ409mf@P2QN4@0WgI209ed@02LLcl0
Vg8n09ac?`2MM400WgI20:EgA@2SMD<0XG=100<0Wg4o00d0XG=10:9d@P2OMT80WWE109ed@02LLcl0
Vg8n09Ya?@2IL3`0V6lk09Q^?02GKC/0UF/i0080U6Xh00@0UF/i09M]>`2GKC/0V6hl1@2BKCT309=^
>P80TfTg0P2BJ3H3095W=@03091V=02=IcP0SFLh00<0SFLh0`2>J3T4095V>@80T6Dh0P2?I3L02029
Hc@0QV0a08AN;`26H340RV@e08eW>02;ICH0R68c0P2;ICH01P2<ISL0RfDf08YT=@28HS<0QEl`08AN
;`@0Q5dd1025GSD00`23GS@0PUdc081K<@0307iI;`80P5/a201oFC@207iI;`80OEP^00@0O5L]07]F
;01jEB/0NUD[201nF34307YD;`80NeD`0`1lES4207]E;P80NU@]0`1iDb`00`1hDR/0Me4Z07MA:P06
07MA:P80NE4^00<0N58^07IB;P1eDbh00P1dE2h0101bE2h0ME4]07EA;@1eDBd207A@;0<0Ldl[0P1d
CbD0101eD2H0MU4W07QC:@1iE2X207YE:`0606mB9P1`DbL0LE@X079E:@1cERX0M5L[0P1eF2`01`1k
Dbl0NU8^07Q@;01gCb/0MThZ07M?:`1hD2`00P1iDBd00`1aD2L0Le8Y07ED:`0207IE;00607=B:@1a
D2L0KdhU07=@:P1dDB/0Me@^0P1iES002`1gE2h0M54[07=@:P1fDRh0ME4]07=@:P1bCbL0LTlU07=A
901eDbH0MU@V00P0Me4Z0P1aCRH00`1bCbL0Le0X07AA:@0207IC:`0407MD;01cD2P0Le0X07=@:080
M54Y0`1eDRX0101cD2P0M54Y07AA:@1dDBT207EB:P80MU<[00<0ME8X07MD:P1iER`00P1jEbd01P1i
ER`0Me@Z07EB:01jEB/0O5L]07eH;P80OUT_00<0OEP^07]F;01iE2X00`1jEBP207]F:@D0O5LZ0P1m
F2/407iI;00807aJ;01kFB/0NUPZ07UG:@1jF2X0OE/]081N<023HC<207mJ;@09081K;P21G2l0PUd`
089M<023GS40Q5lb08IQ=024Gc80Peha0080PE`_00<0Peha08AO<P26HC@00`24H30208EQ<@<0QV8b
0P26H3400`27HC80R68c08US=00208YT=@0308]U=P2?IC<0SfDc00H0SfDc202@IS@208aW<`0408eX
=02?JSH0TF`h099]>@80U6lk0`2?KST00`2AKCT0TVdi09A/>@0209E[>@0309IZ>@2IL3`0VG0l0080
VW4m102KLSh209Qc?P0:09Ud?`2JMD00W7M209eh@`2NND@0WgY509ed?P2NMCl0XGQ20:=jA0<0Y7]5
00@0XgY40:F2BP2SP4P0Wga40P2LND400`2NNd<0XGi60:>0B0040:ElAP<0YWe700T0Ygi80:N2C@2V
PD`0YH1;0:AoBP2UP4/0YX5<0:R3CP2YQ4l02`2[PTh30:b3C`80[HA@0P2[PTh0102/Pdl0[HA@0:f4
D02^QE420:n6DP060:^1C`2]Pe40/8ID0;:8EP2dRUP0/hUG0P2bR5H80:j9E@P0/HQD00H0]HaH0;B;
E`2cRUH0/XUE0;27D`2^QE420:f4D080/HQD102bRED20;>:EP80/XUE0P2aR5@0102`Qe<0[hIB0:n6
DP2^QE480;68E0P0[XY@0P2_RUH30;2;E`<0/HaH2@2bSEH20;>>FP80/XeI0P2aS5P20;2;E`<0]XaJ
00<0]H]I0;B:F02cREL00P2cREL30;6<E`<0/8]F0P2_RUD20:j9E0030:n:E@2`ReH0/HaG0080/XeH
00T0/hiI0;:9E@2bRED0/HQD0;27D`2bRED0]8]G0;N>FP2iT5`02`2cRUH00`2dReL0]HaH0;J=F@02
0;J=F@P0]HaH202`ReL30;B:F080/hUG0`2bR5H00`2aS5D0/8]D0:j9DP030:b7D0030:f8D@2^RE80
[HQD00L0[HQD0P2^RE@20:f8D`80[8MB0P2[QU430:b7DP<0ZhIA0P2ZQE002`2ZPD/0Zh9:0:^2BP2/
Q4T0[HE80:j6B02^QdH0[hQ70:f8D`2/Qe80ZXE@0080ZHA?00<0ZXE@0:b7DP2]R5<0402^QE40102`
Qe<0[hIB0:f4D02]Q5020:^2CP030:b3C`2]Q500[XEA0080[H=C0`2/PU830:^1D@P0ZHA?00P0Ygi:
0:QoB`2YP4`0ZX5=0:^2CP2/Pdl0[HA@0:j5D@P0[hIB202/Pdl30:j5D@80[HA@0`2/Pdl20:n6DP04
0:j5D@2]Q500[HA@0:b3C`80Zh9>00<0ZX5=0:^2CP2]Q5000`2_QU801@2]Q500[8=?0:n6D02_QU00
[XE?0080[HA>00<0[8==0:^2C02[PT`0202/Pdl30:j5D@80[HA@0`2/Pdl0202bRED0/8MC0:j5D@2/
Pdl0Zh9>0:b3C`2]Q500[XEA0P2]Q5030:b3C`<0Zh9>202[PDl20:^2CP030:^2C02[PTX0Zh=80080
Zh=600<0Zh=50:n6D02_QU001P2_QU080:f3D@080:MnBP2XOd/0ZH1<0:Z1C@2[PTh0[8=?0:f4D02^
QE470:b3C@80Zh9<1@2/Pdl30:^2CP040:V0C02ZPDd0ZX5=0:Z1C@<0Zh9>00@0[8=?0:n6DP2_QU80
[XEA0P2]Q5000`2/Pdl0Zh9>0:^2CP030:b3C`030:^2CP2ZPDd0ZH1<0080ZH1<202/Pdl30:b3C@80
[HA>0`2^QDl20:^1D@040:^1C`2[PTh0Zh9>0:^2C080Zh9:202/Pdl0202XOd/0ZH1<0:^2CP2/Pdl0
[HA@0:b3C`2[PTh0ZX5=202YP4X40:^2C080[8==0P2]Q4h80:V0C0P0Zh9>00/0ZWm:0:UnB@2XODP0
Z7e80:UnB@2[P4/0[H9=0:j3CP2/Pdl0ZX5=0:V0C0020:QoB`040:Z1C@2/Pdl0[XEA0:b3C`<0Zh9>
0P2ZPDd20:V0C080Zh9<0P2ZPD/0402YP4X0Z7m90:QoB@2WOTP0ZH1<0:Z1C@2[PTh0[8=?0:^2CP2Y
P4`0Ygi:0:ElB02XOdT0ZH1:0:^2C02/Pdd20:^2C0030:Z1B`2WOTP0YWe70080YWe700@0Ygi80:Qo
B@2XOdT0ZH1:0P2ZPD/80:Z0CP030:b0D@2[Oe00ZGe<0080Yga900<0Z7e80:UnA`2ZOdP00P2[PTh2
0:Z1C@070:V0C02XOd/0Z7m;0:MnBP2YP4X0Z7m90:ImA`020:ElAP030:ImA`2XOdT0ZH1:0080ZX5=
102[PTh20:Z1C@80[89B00<0Zh5A0:Z0D02YOdl00P2WODd02P2VO4`0Y7]70:ElB02XOd/0ZX5=0:^2
CP2ZPDd0ZH1<0:QoB`2YP4`20:QoB`030:MnBP2VODT0YWe90080YGa800<0YWe90:MnBP2YP4`00`2[
PTh00`2ZPDd0ZH1<0:V0C0020:V0C080Z7m;0`2WOTX0202TNdD0YGa60:ImA`2WOTP0Z7m90:V0BP2Z
PD/0Zh9<202XOd/30:Z1C@<0ZH1<0P2XOd/02`2]Q500Zh9>0:V0C02WOTX0YWe90:ElB02VODT0Ygi:
0:ImB@2WOTX0ZH1<0080ZX5=00<0ZH1<0:MnBP2VODT00P2WOTX20:QoB`80ZH1<0P2ZPDd30:QoB`<0
Ygi:0P2VODT00`2TNdL0YGa80:ImB@020:MnBP80YWe900D0YGa80:AkA`2VO4X0YG]90:AjB0020:9h
AP0;0:AjB02UNdT0YWa:0:QnC02TNTP0X7I40:5gA@2UNdT0YWa:0:9hAP2NM4800P2QN4@0102RNDD0
XgY60:=jAP2TNdL20:ElB080XgY60`2TNdL30:ElB080X7Y900@0XGa80:5lA`2QO4L0XWe60P2ROT@0
0`2QNdX0X7Y909ihA`0209egAP0309ihA`2PNTT0XG]:0080Yg]:0P2VNTT0102UNDP0Y7Q70:AhA`2S
MdH80:=jAP<0WWU40`2ONTD20:1kAP80W79000@0WG=109id@P2NM480WgE30P2PMT@0102SOTX0XWe9
0:1kA`2NNDD209ehA00309iiA@2ONTH0WGA00080WGA00P2NMD4309mf@P0309ac?`2MM400WWE10080
WgI200<0WGA009]b?P2IL3`0102LLT0409]a?`80WWA20P2MLd4409ab@0P0VG@o00@0Ug8n09Ia?@2F
LCd0UW4m0P2EL3`209A_>`80V6hl102IKcd209Y`?PT0Ufdk00@0VWA509Qb@`2FL440U6ho0P2BK3d2
09=]?P0309Q]@02IKT40Vg130080W75400<0Vg1309U^@@2HKD000P2HKD000`2IKT40VVm209]`@`02
09aaA00309ebA@2JKd80VVm200<0VVm20`2KL4<00`2JMD40VGA009Mb?P0209Mb?P0;09Qc?`2JMD40
VgI209Qb@`2GLD80UW1109E_@02FL440Ug5209UcA02JM4D0202GLD800`2CKCh0UFm009Ma@P0209Uc
A00;09Ma@P2EKd00Tfdn09a`@`2KKd80VVi109Q/?`2GJch0UFTl09AX>`2CIcX00`2AJSl[ooooo`00
:_ooool308IP<`80Qf4d0`28HSD308eP=P<0S5le0P2;GS@208eP=P0408iQ=`2?HSP0TF@j099U>`80
TfHl00H0Rehd08aO=@2=H3H0SV4g08mR>02AI3X2099U>`<0SV4g1@2?HSP3095T>P80T6<i0`2?HSP8
08mS=P80TVHi102CIcX2099V>@04095T>P2BIC/0UFPn09MZ@080V6]10P2GJT09099V>@08095V>@2@
ICP0T6Dh08mT=`2@ICP0TVLj09AY?02FJch309AX>`80UFTl0`2FJSd309M[?P<0UVXm0P2EJC`0102F
JSd0UFTl09EY?02DJ3/209=W>P80TVHi00<0Uf/j09Q/>`2JKSd00P2LL3l0102JKSd0V6`k09M[>P2D
J3L209EY>00309IZ>@2GJcX0Uf/j00D0V6`k0`2IKC`209Y^?@0809IY?`2EJC`0U6Pk09EY>P2FJST0
V6dj09Y_>P2LLC`209mc@P0409ib@@2MLD00WG5009a`?`80Vfln202PKCh00`2IKC`0Vfln09a`?`02
09ea@00309a`?`2KKch0VFdl00<0V6`k0`2IKC`409Y^?@<0Vfln0`2LL3l809eb?`80Vg0m00<0W74n
09eb?`2NLd000P2PMD800`2QMT<0WW=009ic@00609ic@0P0XGI30P2PMCh0102PMD00X7E20:1e@P2P
M4<20:1dA@0309md@@2PMD80XWM400@0XgQ50P2QMT<0102VNdP0YGY70:=hA@2PMD8209md@@<0X7E2
00L0XGI30:9gA02RMd@0XWM40:1e@P2NLd00WG8o0080XWI50`2TN4L00`2RMTD0X7A309mc@P080:=g
AP060:AhB@2VMdT0YWQ70:MgAP2YMdH0ZWI40P2[MT820:MhA0040:QiA@2YNTH0ZW]70:]lB080[7e9
202WO4L80:AiA0P0Y7]70P2WODd20:IlC080YG];0P2TNTX00`2VO400Yge10:Uo@`020:Z0A0030:Uo
@`2WOD40YWa00080XGQ200@0XWU30:=jA02SNT@0Y7]50P2UO4H20:QmB080ZGi900@0Z7e80:EjA@2S
N4<0XWM20P2SNTH0102RNDD0XGQ40:1g@`2OMT8209ie@@0309id@P2OMD<0WgE30080WgE30`2PMT@2
0:5hA0040:1g@`2OMT80WGA009ac?`80Vg8n00@0WG9509aaA02LLD@0W7540P2KL4<209Y_@P<0Ug8n
0P2FLCd309E`?0<0UV`j0P2EJcT409AZ>080Uf`o00@0UV/n09EZ?@2CJ3/0TVLj0P2AIST0102CJS@0
TVTc099Y<`2BJC<2095X<P80T6La00P0Tfe0095[?P2?JC`0SFLj08aV>@2=IcX0SVPk08mY?080S6Hi
0P2;ICP308YT=`0408US=P28HSD0R68e08QR=@80Qf4d0`26H3<01029I3X0QF0f085L<P21G38208EP
=P05085L<P1lEbd0PELa08=I<`22Fc@00P23GCH00`20GCD0OUdd07eL<`0407aJ;0@0OE/]00H0MEP^
07MG;P1gEbh0N5L^07UF;P1kEBh207aE;P80P5Xc00@0OUPa07eG<01kEBh0NU@]0P1hDR/307UJ;P80
N5T]0`1gF2`00`1jEc40N5D_07MD;P0207EB;00607MD;P1hEBl0NULa07I>:P1gCb/0NE4]0P1jDRh0
3@1iDBd0Mdl[07I>:P1dC2P0MDdY07A>:@1cD2X0Le4[07=C;01dE2d0LUD]07M?:`1hD2`00`1jDRh0
0`1hD2`0MThZ07A<:00207=B;`04079A;P1`Cb`0Kdh[06i=:P80KD`Y201bCbD807=C:P80Ne<_00@0
NU8^07UA;@1iDBd0N50/0`1gCb/406iA:@@0Ke8Z00@0L50Y075A:P1aDBX0LE4Z0P1bDR/207=C;0P0
Kdh[0P1fBbP00`1dC2P0LddX075>:002071>:00306m?:01dDBT0M54Y00H0M54Y0P1aDBX3079B:`<0
Le</0`1gCb/207Q@;0<0NE4]0`1gCb/207Q@;0<0NE4]00/0Me0Y07QA:P1iDR/0NU</07]D;@1lEBh0
OEH_07iG<01jEbl0NeP`07eJ<P0207mL=00307eJ<P1kF300NUL_00<0O5H_0P1mEc0307iH<@80NeP^
00H0O5T_07eJ<01nFc40Oe`b081M<`21GS@307eH;P80OUT_1@1oFS001P20Fc40PE`b08=N=024GcD0
QF0f08IQ=`P0QV4d00H0Q60`08EQ<@25HC40Qf<c08QT=029ICD208YV=P0808YO:P2;H2/0Rf0]08aP
;`2=HC80SF4d08iR=@2>HCL208aV=@0308aV=`2<IST0S6Dj0080S6Dl00<0S6Dn08aX>02<J3P00P2=
JCT308iZ>P0308m[>`2AK3P0TF`h0080TF`h0P2BKCT309=^>P0609I`@`2FL440UW1109Ma@02GLSh0
V7<n0P2HLc`01P2JLCd0Vg8n09ac?`2MM400WgI20:1g@`80XGQ40P2NMD4209ed@00409mf@P2RNDD0
YGa80:MnBPD0WgY50`2NND@30:9mAP<0XGa50P2PNd@30:MnBP80Z7m;0`2YP4`30:F0B`80YX5<0`2W
PTd50:V4C`<0Z8=>202]Q5001P2XPdl0ZXEA0:f8E02_RUH0/HaH0;2;E`80[hYF0P2bR5H20;67E@@0
/8ID00<0/XUE0;27D`2_QU800P2]Q5000`2_QU80/8MC0;:9E@0;0:f8E0<0[XUE0P2_RUH80;68E0P0
[XUD0`2aS5P50;2;E`030;6<F02_RUH0[8MC0080ZhIB00<0[XUE0;:=F@2eT5`01@2bSET20;>>FP80
]8mK00@0]I1L0;B?F`2dSe/0/hiJ0P2bSET20;6<F0P0[hYF0P2cSUX20;:=F@80/HaH0P2`ReL80;:9
E@80[HQD00@0[XUE0:n:EP2_RUH0/8]G0P2aS5P80;>:EP80/8MC00H0/HQB0;:9D@2bRTl0/h]>0;B<
C`2dS4h80;:>E0<0/HaG1@2`ReH0202cRET0/hUG0;>:EP2cRU80/h]@0;>;C@2cS4/0/ha90P2aQeL0
102aQeD0/HQD0;68E02aR5820;68D0030:n6DP2`Qe<0/XUE0080/hYF00<0/XUE0;27D`2_QU800`2^
QE400`2_QU80/8MC0;68E0020;68E0P0[XEA402[QU400`2_QTh0[XE=0:b3B`020:^2BP030:b3B`2^
QDd0[hI>00<0[XE?0P2]Q4h30:b3C@T0ZhIA202^QE400`2[PTh0ZX5=0:QoB`020:MnBP060:QoB`2Z
PDd0Zh9>0:b3C@2[PT`0ZX5;0P2YP4X00`2ZPD/0Zh9<0:b3C@080:n6DP<0[XEA0P2]Q5030:b3C`80
ZX5;0P2[PT`03@2/Pdd0[HA>0:j5C`2^QDl0/HQD0;27D`2]Q500Zh9>0:Z1C@2[PTh0[8=?0:f4D02]
PUP00P2]PUL00`2]PUD0[H=C0:f3D@020:f4D0D0[XEA0`2_QU830:f2C`80[X=@0`2_Q5400`2]Q500
[8=?0:Z1C@020:V0C0030:Z1C@2/Pdl0[HA@00/0[8=?0`2[PTh20:Z1C@/0Zh9>0`2/Pdl20:f4D003
0:R5C`2YQU00ZhQB0080[8UC00<0ZhQB0:V6D02XQDl00P2^QE40102]Q500[8=?0:^2CP2[PTh20:Z1
C@P0[8=?00<0[HA@0:j5D@2_QU800P2_QU80102^QE40[8=?0:Z1C@2YP4`80:f4D0040:j5D@2]Q500
[HA@0:b3C`80Zh9>0P2ZPDd20:f4D0060:j5D@2_QU80[HA@0:^2CP2XOd/0YWe9202/Pdl30:j5D@80
[HA@0`2/Pdl80:f3D@040:j5C@2]Q4`0[HA<0:b3B`80Zh9:0P2ZPDT20:f4C0040:f4CP2]Q500[HA@
0:f3D@80[H=C0`2^QE420:f4D0<0[8=?0`2ZPD/40:V0BP090:QoB@2YP4X0ZH1:0:Z1B`2/Pdd0[HA>
0:j5C`2_QU00/8MA0080[89@0P2[PDl20:Z0CP80ZGm=00<0Z7m90:Z1B`2[PT`00P2]Q4h02@2[PT`0
ZX5;0:QoB@2SOTT0Y7m:0:F0B`2VPD`0Yh9=0:R3CP020:V4C`P0Z8=>00P0[XEA0:f4D02/Pdl0Zh9>
0:Z1C@2YP4`0Z7m;0:MnBQ00ZH1<0P2YP4X20:Z1B`<0Zh9<0P2/Pdd01P2VODT0Ygi:0:MnBP2YP4`0
ZX5=0:^2CP<0[8=?0P2[PTh00`2ZPDd0ZH1<0:V0C0020:QoB`80Zh9>00@0ZX5=0:V0C02WOTX0YWe9
0P2UO4P80:V0C0P0Z7m;202YP4`20:UnB`80Z7e:00@0Yga90:IkB02UNTL0YGY70`2WOTX20:QoB`<0
ZH1<0P2ZPDd0102YP4`0Z7m;0:QoB`2WOTX20:ImB@80ZGm?00@0ZX1>0:Z1C@2[PTh0Zh9<0P2/Pd/8
0:UoC@80Yge=00@0Yge;0:QoB`2XOd/0ZH1:0P2YP4P00`2[PTh0ZX5=0:QoB`020:MnBP030:QoB`2Z
PDd0Zh9>00<0ZX1>0`2YOdd20:QnC0P0Z7m;0`2WOTP20:QoB@<0ZH1:0P2XOd/30:MnBPD0YWe90P2U
O4P0102TNdL0XgY60:=jAP2SNTH90:MnBPP0Z7e:0P2TNTX02P2UNdT0YGa80:ImB@2VODL0YWe50:Mn
AP2QN4@0XgY60:ElB02WOTX20:QoB`030:MnBP2VODT0XGM50080XGM51@2RN4H30:9iA@80XgY60`2T
NdL30:ElA0<0Y7]30P2SNT820:ImB@80YGa800d0Y7]70:=jAP2SNTH0XWU509eh@`2ONTD0XGa70:=n
B@2TOdX0Xgi90:9mB02QO4L0Y7]70080XgY600<0XWU50:5hA02QN4@00P2PMd<209id@P80WgE3102P
MT@00`2PMcl0XGQ00:9i@@020:Ak@`060:9i@@2QN400X7Lo0:9hAP2QMdD0WgE30P2NM480702PMT@0
XWQ60:AjB02TNdL0WgI209ac?`2MM400XGQ40:=jAP2OMT80Vg8n09Ya?@2KLSh0WWE10:1g@`2QN4@0
X7M309mf@P2NMD40X7I409me@`2MLd40Vg4o09Y`?P2KLCl0WG=109id@P2LL3l209]a?`0309Ua?P2G
LSh0UW8n0080U7<n0`2KLCl309Y`?P80VFlm0P2IKT<209Y_A0@0Vg1500H0XWM:0:5fB@2OM4L0WG95
09Y_@P2HKD0209I[?P0309EZ?@2CLSd0Tg8m00H0Tg8m00<0Ug8n09E`?02DKc/00P2CKSX01@2DKc/0
UG0l09Mb?P2HLcl0Ug8n0080UW4m00@0Ug8n09Ye@@2MN4@0WWU50`2KLCl509Y`?P80UW4m00@0Ug8n
09Qc?`2IM400VWE10P2KMT8209Ud@080V7<o01L0Ug8n09Ia?@2FLCd0UG0l09ab@02KLCl0V6hl09I/
>P2EJcT0UV`j09M]>`2HKS`0Tfe009E_@02FL440V79109Qc?`2FLC`0UG0i09=^=`2JLD<0VG1209M^
@00309E/?P0309I]?`2GKT00UW110080UW11:oooool002[ooooo0`26H3<208MQ=0<0R68e0`2=H3H3
08aO=@80Rehd0P2=H3H01P2>HCL0Sf8h091S>@2AI3X0TVDk09=V?080SF0f0P2>HCL0102?HSP0T6<i
095T>P2AI3X808mR>0<0TF@j0`2@HcT208mR>0P0Sf<f0P2CIcX4099V>@80TfLj00@0T6<i095T>P2D
Icd0UVTo0P2GJT0209IY?`T0TfLj00<0TfPk099W>P2@ICP00P2@ICP00`2BIcX0TfPk09AY?00309AX
>`80UFTl302FJSd209EY?080U6Pk0P2CIcX0102BIST0UVXi09M[>P2IKC`209Y^?@0309U]?02GJcX0
UVXi0080UFTh0P2FJST209M[>PD0V6`k0`2IKC`209Y^?@0809MZ@02FJSd0UVXm09IZ>`2GJcX0VFhk
09]`>`2MLSd309ea@00309a`?`2KKch0Vfln0080VVhm202NKSh00`2IKC`0Vfln09a`?`0209ea@003
09a`?`2KKch0VFdl00<0V6`k0P2IKC`509Y^?@<0Vfln0`2LL3l809eb?`80Vg0m00H0W74n09eb?`2N
Ld00WgA10:1e@P2QMT<809ic@0P0XGI30P2PMCh0102PMD00X7E20:1e@P2PM4<20:1dA@0509ic@02O
M440XGI30:=hA@2TNDH00P2SN4D20:9gA0040:IkB02UNTL0XWM40:1e@P80WgA10`2PMD802@2QMT<0
XWM40:9gA02RMd@0X7E209ic@02MLSl0XGE40:9fA@030:=gAP030:5eA02OLd80WW9100P0XgM60P2T
N4T01P2VN4L0YgM60:UgAP2ZMT@0ZWM20:]f@P80YgQ400<0Z7U50:UjAP2ZNdL00P2[O4P00`2/ODT0
Yga70:MlA`060:MlA`P0Y7U4202TNdL20:MmC@80YWa<0P2UNd/20:AjBP030:Ek@@2VO480Z7i40080
ZGm500@0Z7i40:Il@P2UNd40XGQ20P2RND<20:=jA080Y7]500<0YGa60:MlA`2XODP00P2XODP01@2W
O4L0YGY50:=h@`2QMT40XgY60080XWU500<0XGQ40:1g@`2OMT800P2NMD4209id@PH0WgE30P2PMd<0
1P2OMT80WWE109ed@02LLcl0Vg8n09Ya?@<0W7540P2KL4<309Y_@P80Ug8n0P2FLCd309E`?00409A_
>`2FK3X0UV`j09I/>P80UF/i102DJSP209I[?P0409EZ?@2DJC`0TfPk099W>P80TFHi0`2BJC<2095X
<P<0T6La00L0SVPk08eW>P2;ICP0RF<f08QR=@29HcH0RV@g00@0RfDh0P2:I3L308US=P80R68e0P27
HC@308IP<`0508EO<P29I3X0QF0f085L<P22GC<00P25H3H01@22GC<0OUT_085G<@22F380PU/d0080
PU`e00<0P5de07eL<`1lFc80201lFRd01P1dEbd0MUH]07IF;@1gERd0N5D]07YD;@80Ne@]0P1nF340
101mEc00O5H_07]E;P1jE2d207UC;00407UJ;P1hFBd0N5T]07QI;@80MeP/0P1fEb/00`1iES00N5D_
07IC;@0207EB;00607IC;@1hEBl0NEH`07I>:P1gCb/0N50/0P1iDBd00`1hD2`0Mdl[07I>:P0207I>
:P0307E?:P1cD2X0Le4[0080LU8[00T0L5<[07M?:`1hD2`0NE4]07YB;P1iDBd0N50/07I>:P1dC2P0
0P1cDRl0101bDBh0LE0]071?;01_CR/206i=:PP0LTlU201bDR/207YB;P80NE4]00<0N50/07M?:`1g
Cb/00P1gCb/806iA:@<0L50Y0P1aDBX3079B:`P0Kdh[00H0MT/X07A<:01dC2P0LddX075>:01`CRP2
06m?:0P0Le0Z0`1`D2T2075A:P<0LU8[0P1fCRX207M?:`<0N50/00<0NE4]07I>:P1gCb/00P1gCb/2
07Q@;080NE4]00D0Me0Y07QA:P1hDBX0NE8[07]D;@0207aE;P0407eF;`1jEbl0NeP`07aI<@80OU/c
00<0O5Ta07]H<01jEbl00`1lERl207eG<0<0OUPa00H0NUL]07]H;P1kF2h0OEX`07iK<@1oG382081M
<`0407eH;P1nFBl0OUT_07iI;`80OeX`1020Fc42085L<P04089M<`23GS@0Q5le08AO=@P0QF0c0P24
H3002`25HC40QV8b08MS<`28I3@0RFDe08YV=P29H2X0RV4[08YQ;@2;HBl0Rf4a0080S64d00H0SF8g
08aV=@2<ISD0S6Hg08aV>@2<ICX208aU?00308aU?P2<J3P0S6Ph0080SFTi102>JSX4095/>080TVdi
0`2CKSX01P2EKd80UW1109I`@@2FL3l0Ug8n09Mb?@80V7<l00D0Vg8n09ac?`2LLcl0WGA009ie@@02
09mf@P030:1g@`2NMD40WGA00080WGA000@0WgI20:9iA@2TNdL0YWe90`2ONTD509iiA0P0XGa500@0
YWe90:MnBP2WOTX0Ygi:0P2XOd/20:V0C0<0YH1;0P2VPD`30:N2C@H0ZHA?0P2XPdh80:f4D0040:V4
D02ZQE40[HQD0:n:EP80/8]G00@0[hYF0:j9E@2bR5H0/XQF0P2aQeD30;26E0040:n5D`2aR5@0/8MC
0:n6DP80[XEA00<0[hIB0;27D`2aR5@02`2]R5@30:j9E@80[hYF202aR5@80:j9E080/HaH1P2`ReL0
2@2aS5P0[hYF0:f8E02[QU80[8MC0:n:EP2bSET0]I1L0;6<F0040;:=F@80/hiJ102dSe/20;>>FP04
0;:=F@2aS5P0/HaH0;6<F0P0[hYF0P2cSUX20;:=F@80/HaH0P2`ReL80;:9E@<0[XUE00<0[hYF0;2;
E`2`ReL00P2aS5P80;>:EP80/HQD00@0/XUC0;:9D@2bRTl0/h]@0P2cRdh80;:>E080/HaG1P2`ReH0
202cRET0/hUG0;>:EP2cRU@0/h]@0;>;CP2cRdd0/ha;0P2aQeL0102aQeD0/HQD0;68E02aR5820;68
D0030:n6DP2`Qe<0/XUE0080/hYF00<0/XUE0;27D`2_QU800P2^QE420:n6DP040;27D`2aR5@0/HQD
0;68E0P0[XEA402[QU400`2_QTh0[XE=0:b3B`020:^2BP030:b3B`2^QDd0[hI>00<0[XE?0P2]Q4h3
0:b3C@T0ZhIA202^QE400`2/Pdl0Zh9>0:V0C0020:QoB`060:V0C02[PTh0[8=?0:f4CP2[PT`0ZX5;
0P2YP4X00`2ZPD/0Zh9<0:f4CP080:n6DP<0[XEA0P2]Q5030:b3C`<0Zh9<0P2/Pdd30:f4CP030;27
D`2_QU80[HA@0080Zh9>00<0[8=?0:f4D02^QE400P2]PUL20:f2E@040:f3D`2]Pe40[HA@0:f4D0H0
[XEA0P2_QU830:b3C`80[HA@102^QE401`2]Q500[8=?0:Z1C@2ZPDd0[8=?0:f4D02^QE40202/Pdl3
0:f4D0<0[8=?3@2[PTh30:b3C`80[HA@00<0ZHA?0:Z5D02/Qe800P2]R5<00`2/Qe80ZXE@0:V4C`03
0:f4D080[8=?0`2[PTh90:b3C`030:f4D02^QE40[hIB0080[hIB00<0[HA@0:^2CP2ZPDd02`2]Q500
0`2/Pdl0Zh9>0:^2CP020:Z1C@80[HA@0P2^QE40102]Q500Zh9>0:V0C02WOTX80:b3C`80[XEA0`2]
Q5030:b3C`P0[H=A00<0[XE=0:f4C02]Q4`00P2/Pd/20:^2BP040:Z1B@2]Q4`0[HA<0:f4CP80[HA@
00<0[H=A0:f3D`2]Pe<00`2^QE420:f4D0<0[8=?0P2[PT`20:Z1B`040:V0BP2XOdT0Z7m90:MnB080
ZH1:00@0ZX5;0:^2C02/Pdd0[8==0P2]Q4h20:b2D080Zh5?0P2ZP4h20:UoC@030:V0BP2ZPD/0Zh9<
0080[8==00<0Zh9<0:Z1B`2YP4X00P2TOdX0102UP4/0YX5<0:N2C@2XPdh20:V4C`P0Z8=>0P2]Q500
102/Pdl0Zh9>0:Z1C@2YP4`20:QoBa00ZH1<0P2YP4X20:Z1B`<0Zh9<0P2/Pdd01P2VODT0Ygi:0:Qo
B`2YP4`0ZX5=0:^2CP80[8=?00<0Zh9>0:Z1C@2ZPDd00P2YP4`20:QoB`030:MnBP2ZPDd0ZX5=0080
ZH1<00@0Z7m;0:MnBP2VODT0YWe9202YP4`80:QoB`P0ZH1<0`2YOT/30:QmBP80Yga9202XOd/30:V0
C0<0Z7m;0P2WOTX20:UoC`040:Z0CP2ZPDd0Zh9>0:^2C080[8=;202YOdd20:MmC@040:MmB`2XOd/0
Z7m;0:V0BP80ZH1800<0Zh9>0:Z1C@2XOd/00P2WOTX00`2XOd/0ZX5=0:^2CP030:Z0CP<0ZGm=0P2X
OT`80:QoB`<0Ygi80P2XOdT30:V0BP80Z7m;0`2WOTX30:ImB@<0YGa81@2TNdL90:MnBPP0Z7e:0P2T
NTX0102UNdT0YGa80:ImB@2VODL20:ImA@030:=jAP2TNdL0YWe900<0Ygi:00<0YWe90:ElB02RN4H0
1`2RN4H20:9iA@<0XgY60`2TNdL30:ElA0<0Y7]30P2SNT820:ImB@80YGa800L0Y7]70:=jAP2SNTH0
XgY609eh@`2ONTD0XGa700<0Xgi900<0XWe80:5lA`2SNTH00P2SNTH00`2RNDD0XGQ40:5hA0020:1g
@`80WWA20P2OMD<30:1fA0040:5gA@2PMcl0XGQ00:9i@@80XgY200H0XWU10:5h@02PMcl0XWQ60:5g
A@2PMT@209id@P0?09me@`2QMdD0XWQ60:=jAP2OMT80W7<o09ed@02QN4@0XWU509mf@P2KLSh0VW4m
09ac?`2NMD40WgI20080X7M30P2NMD400`2PMT@0WgE309ec@@0309]a?`80WG=100H0W70o09]a?`2K
LCl0VW8o09Mb?P2FLSh209Ac?P<0Vg4o0`2JL3h209U_?@80VFi10P2JKd8309]`@`0709aaA02PMDP0
X7E809icAP2LLD@0VVm209Q]@00209M/?`0309I[?P2CLSd0Tg8m00H0Tg8m00<0Ug8n09E`?02DKc/0
0P2CKSX0102DKc/0UG0l09Mb?P2GLSh309Ia?@0409Mb?P2IM400VgI209ehA080Vg4o1P2JL3h209Mb
?P80V7<o0P2IM40209Ye@@80VGA00P2HLcl01`2GLSh0UW4m09Ia?@2FLCd0Vg4o09Y`?P2HKS`00P2F
K3X03P2GKC/0V6hl09U_?@2EKd80UW1109Ma@P2HLT40V7<o09Mb?@2FLCX0UG0i09Ya@`2IL480Ufi0
0`2EK3h00`2FKCl0Ufi009I`@@0209I`@B_ooooo000Zooooo`<0QV0c0P27HC@308QR=@<0SF0f0`2<
GcD208]N=080SF0f00<0SV4g08mR>02@HcT00P2AI3X00`2BIC/0SV4g08mR>00>08mR>080TVDk0P2A
I3X3091S>@0308mR>02?HcH0Sf<f00H0Sf<f00<0UFTl09AX>`2AICP00P2@I3L01`2AICP0U6Pk09EY
?02?HSP0T6<i099U>`2DIcd00P2EJ3h209AW?@T0UFTl00<0UFXm09AY?02BIcX00P2@ICP00`2AIST0
TVLj09=X>`0309AX>`80UFTl0`2FJSd309AX>`0309EY?02FJSd0Uf/n0080V6`o102EJC`209AX>`80
TfLj00<0UFTh09IZ>@2GJcX00P2HK3/00`2GJcX0UVXi09EY>00309IZ>@<0Uf/j1@2HK3/309U]?080
VVhm00P0VFa209Q/?`2GJch0Uf/l09Q/>`2JKc`0W74l09ic?P<0Vfln0P2JKSd309U]?0P0WVhn00<0
VFdl09]_?P2LL3l00P2MLD000`2LL3l0Vfln09U]?00209Q/>`80VFdl0`2JKSd00`2KKch0VVhm09Y^
?@0309]_?P<0W70o202MLSl01P2KL3d0W74n09aa?P2MLSl0WW=009md@@80X7E2202NLd080:5f@`80
X7Dn00@0X7E00:1e@P2PMD80X7A30P2PM4D0102LLCh0WW=00:1e@P2SN4D40:AiAP050:=hA@2VNdP0
Y7U60:9gA02PMD800P2OM440102PMD80XGI30:1e@P2QMT<30:9gA0060:1e@P2NLd00WG8o09mc@P2P
M4<0XGE40P2RMTD00`2PM4<0WW9109ea@0080:=gAP80XgU900@0Y7Q70:IhAP2WMdH0ZGM40P2ZMd82
0:MhA080Z7U500@0ZGY60:YkA`2[O4P0Zga8202WO4L80:EjA@P0YGa80P2WOD/20:IlBP80YG]90P2T
NTP00`2TNT00YG]10:Il@P030:Il@P030:Ek@@2TNT00XWU30080XWU30P2SNT@30:AkA@080:IkAP2W
O4L0Yga70:QmB02WO4L0YGY50:=h@`2QMT420:9iA@040:5hA02PMd<0WgI209mf@P80WWE1202NM480
1P2OMT80WWE109ie@@2MM400W7<o09]b?P80VW4m00@0W75409]`@`2KL4<0Vg130P2JKd8209U^@@<0
UW4m0P2EL3`309A_>`<0UF/i0P2DJSP409=Y=`80UFXm00@0U6Tl09=X>`2BIcX0TVLj0P2AIST3095X
=080T6Lc0`2?IS800`2:I3L0RF<f08MQ=00308IP<`80Qf4d0`2:I3L208US=P<0R68e0`27HC@208IP
<`<0QElb00@0R6<i08EP=P23GS@0Pehd0P25H3H01@22GC<0P5/a085G<@22F380PU/d0080PU`e00@0
Oe`d07aK<P1kFS40O5T_1`1kF2h01P1dEbd0MUH]07IF;@1gERd0N5D]07YD;@80Ne@]201kEBh0101h
F2l0MeL^07MG;P1gEbh207IF;@80MED/00<0N5D_07MD;P1fDbd00P1eDR`01P1fDbd0Me@^07QE;`1d
CRT0MDlZ07MA;080N58]00<0Me4/07E?:P1dCRT00P1gCb/01P1fD2/0Le0Z079@:P1aDBX0L50Y06iA
:@80MU0[0`1gDB`0101fD2/0M4hY07==:01dDc0207=B;`03079A;P1aD2d0L4l/0080Kdh[201aCRH8
075A:P<0Me4/0P1fD2/407E?:P0306iA:@1]D2P0KE0X00D0KE0X0`1_CbP2071@:@<0LE4Z201^CBX2
07A<:00307==:01aCRP0L4hX0080KdlX00<0KE0X079?:@1bCbT01P1bCbT0101]CBH0KThW06i>9`1^
CRL206m?:080L50Y0P1dCRT207E?:P<0MU0[00@0Me4/07E?:P1eCbX0MDlZ0P1fD2/307MA;080MU0Y
00<0Me4Z07QB:`1iDb`00P1jE2d0101kEBh0NEH^07YG;`1kF30207aI<@0307]H<01jEbl0NEH^00<0
NeD^0P1lERl307eG<080NUL]00@0NeP^07aI;`1mFS00OEX`0P1nFc4207iI;`80OeX`0`20Fc49085L
<PP0Q5lb0P24H3001025HC40QV8b08MS<`27Hc<208QT=080RV4[00H0RV4]08YP;P2;HC40Rf0c08aQ
=02<HCH208]U=00308]U=P2;ICP0Rf@i0080Rf@k00@0Rf@m08aX>02<J3P0S6Ph0P2=JCT308iZ>P@0
T6/g0P2AK3P3099]>@0609A^@@2EKd00UFm009E_?P2FLCd0UW4l0P2GLS/609ac?`H0WGA000D0WgI2
0:5hA02SNTH0Y7]709eh@`0709iiA0<0WgY300<0X7]40:5lA@2RODH00P2SOTL30:ImB@80Ygi:0`2X
Od/30:AoBP80YH1;0`2VPD`80:V4C`P0[8=?00@0ZXEA0:^6DP2/Qe<0[XUE0`2_RUH0102^RED0/HME
0;67E@2aQeD20;26E0<0[hEC00<0/HQD0;27D`2_QU800P2^QE400`2_QU80/8MC0;68E00;0:f8E0<0
[XUE0P2_RUH80;68E0P0[XUD202`ReL0202bSET0/8]G0:j9E@2/Qe<0[HQD0:n:EP2bSET0]8mK102a
S5P20;:=F@D0/hiJ0P2bSET40;6<F0P0/8]G0P2cSUX20;:=F@80/HaH0P2`ReL80;>:EP040:j9E@2_
RUH0[hYF0:n:EP<0/8]G00<0/HaH0;>:EP2cRUH01P2cRUH01@2dRUP0/hUG0;>:EP2cRU@0/XUA0080
/XY?00<0/XY=0;:=EP2bSEH01P2bSEH80;2;EP80/hUG00@0/hYF0;>:E02cRU80/h]@0P2cRdh20;67
E`040;67E@2aR5@0/HQD0;68DP80/HQ@00<0[hIB0;27D`2aR5@00P2bRED00`2aR5@0/8MC0:n6DP03
0:n6DP80/8MC0`2aR5@80:j5DA00ZhIA00<0[hI@0:j5C`2]Q4h00P2/Pdd00`2]Q4h0[XE?0:n6D003
0:j5C`80[HA>0`2/Pdd90:^6D@P0[XEA00<0[HA@0:b3C`2[PTh00`2[PTh01@2/Pdl0[HA@0:f4CP2/
Pdd0ZX5;0080ZH1:00<0ZX5;0:b3C@2]Q4h0202_QU830:j5D@80[HA@0`2/Pdl40:f4CP<0[8==00<0
Zh9<0:f4D02]Q5000`2/Pdl0102]Q500[XEA0:n6DP2^PeP20:j3EP030:j4E02^Q580[XEA0080[XE?
202^QE430:b3C`80[HA@0`2^QE400`2`Qe<0[XEA0:f4D0020:b3C`030:f4D02^QE40/8MC00P0[8=?
0P2_QU830:j5D@<0[HA@2`2[PTh30:b3C`80[HA@00<0ZHA?0:Z5D02[QU400P2/Qe80102[QU40ZXE@
0:V4C`2[PTh30:b3C`@0[HA@202/Pdl00`2ZPDd0Zh9>0:f4D0030:n6DP030:j5D@2]Q500[8=?00P0
[8=?0P2]Q5030:b3C`<0Zh9>0P2]Q5001P2^QE40[HA@0:f4D02[PTh0ZH1<0:QoB`P0[8=?00@0[XEA
0:f4D02]Q500[HA@0P2/Pdl20:^2CPP0[H=A102]Q4h20:b3C@80Zh9<0P2/Pd/0102/Pdd0[8=?0:b3
C`2/PU020:b2DP<0[XEA0P2]Q5030:b3C`060:f4CP2/Pdd0Zh9<0:Z1B`2YP4X0Ygi80P2VODL00`2Y
P4X0ZX5;0:Z1B`050:Z1B`80[89@0P2[PDl20:Z0CP80ZGm=00<0ZH1:0:Z1B`2[PT`00P2/Pdd00`2[
PT`0ZX5;0:V0BP020:F0B`80YX5<00@0Yh9=0:R3CP2YQ4l0ZHA?202XPdh01@2]Q500[8=?0:b3C`2[
PTh0ZX5=0080ZH1<00<0Z7m;0:V0C02YP4`03P2YP4`20:V0BP80ZX5;0`2[PT`20:b3C@80Ygi:00<0
Z7m;0:V0C02ZPDd00P2[PTh00`2/Pdl0ZH1<0:V0C0030:QoB`<0Ygi:1@2YP4`30:QoBaP0ZH1<0`2Y
OT/30:YoC080Zh1=0P2ZPDd0102YP4`0Z7m;0:QoB`2WOTX20:ImB@@0Z7m;0`2YP4`01`2ZPDd0ZGm?
0:UoC`2ZP4h0ZX5=0:^2CP2[PT`00P2/Pd/80:UoC@80Yge=00@0Yge;0:QoB`2XOd/0ZH1:0P2YP4P0
0`2[PTh0ZX5=0:V0C0020:QoB`030:V0C02ZPDd0Zh9>00<0ZX1>0`2YOdd20:QnC0P0ZH1<0`2WOTP2
0:QoB@<0ZH1:0P2XOd/30:MnBP<0YWe90P2SNTH20:AkA`040:ElB02VODT0Ygi:0:MnBPT0YWe9202W
O4T20:AjBP040:AjB02UO4P0YGa80:ImA`80YWe500<0YGa80:ImB@2WOTX00P2WOTX00`2VODT0Y7]7
0:=jAP080:9hAP040:9iA@2SNTH0XgY60:=jAP80Y7]70P2UO4P30:ElAP<0Y7]50P2SNT@30:ElB0<0
Y7]70P2SNTH00`2NND@0WgY50:5lA`030:9mB080XGa70P2SNTH30:9iA@<0XGQ40`2OMD<20:1fA0<0
XGM500<0WgI00:1g@@2RND<00P2SNT@01`2RND<0X7M109mf@02SNDL0XWQ60:5gA@2OMD<00P2NM482
09me@`040:9iA@2OMT80WGA009ie@@80X7M300H0WWE109ac?`2KLSh0W7<o09ed@02NMD4209mf@P07
09ie@@2MM400WgE309id@P2MLd40W79009]a?`0209ab@00709ec@@2LL3l0Vg4o09]a?`2JLSl0V7<o
09Mc?`0209Ed?`<0Vg4o0`2JL3h209U_?@<0VVm20P2KL4<309aaA080WG9500<0W75409]`@`2JKd80
0`2IKT400`2HKD00UG4m09Ea?@0609Ea?@0309Mb?P2EL3`0U6lk0080Tfhj00<0U6lk09E`?02GLSh0
102EL3`0102FLCd0Ug8n09Ud@02JMD4809Y`?P0409Ye@@2IM400VGA009Ud@0<0V7<o00@0Ug8n09Qc
?`2HLcl0V7<o0`2GLSh209Ia?@0309U_?@2HKS`0Ufdk0080Ufdk00T0V6hl09Y`?P2KLCl0Ug5409Ma
@P2ILd@0VG=209Ud@02IM3l00P2GLS/01`2HLT<0Ug5209E_@02DKSl0Tfdn09A^?`2EKd00102FL44[
ooooo`00:_ooool308IP<`80Qf4d0`28HSD308eP=P<0S5le0P2;GS@00`2=H3H0SV4g08iQ=`0208mR
>080T6<i00<0TF@j091S>@2@HcT00`2?HSP308iQ=`03095T>P2@HcT0T6<i0080T6<i0`2?HSP3099U
>`80TF@j0`2@HcT8091T=`0309IZ?@2DJ3/0TFDh0080Sf<f00L0TFDh09AX>`2FJSd0Sf8h091S>@2B
IC/0TfHl0080U6Lm00<0TfHl099U>`2GJch0202GJch0102GK3l0UFXm09=X>`2AIST2091U>003095V
>@2BIcX0U6Pk0080U6Pk0P2EJC`309IZ?@80TVHi00H0TfLj09EY?02FJSd0Uf/n09Q/?`2IKD0609EY
?080U6Pk00<0UFTh09IZ>@2FJST0102FJST00`2EJCP0Uf/j09M[>P0409M[>PD0V6`k0`2IKC`209Y^
?@0809]^A02JKT40VFe009Q/?@2IKC`0Vg0m09eb?@2NLch409U]?0@0V6`k202MKch00`2IKC`0Vfln
09a`?`0209ea@00309a`?`2KKch0VFdl00<0VFdl0`2JKSd209]_?P80VVhm0`2KKch309a`?`P0WW=0
0P2LLCh209eb?`0309ic@02OM440WgA100T0WgA1202QMT<209md?@0409md?`2OM440WgA109mc@P80
Wg=400@0W74n09eb?`2PMD80XgQ51@2TNDH02P2UNTL0Y7U60:9gA02PMD80WgA10:1e@P2QMT<0XWM4
0:1e@P2QMT<30:9gA00;0:1e@P2NLd00WG8o09mc@P2PM4<0XGE40:9fA@2QMD@0X7A309ib@@2LL3l0
202SMdH01P2RNTT0XgU90:=iA`2TNDH0YWQ60:MhA080ZGM20P2VMd<0102WN4@0Z7U50:UjAP2ZNdL2
0:]lB0P0Yga7202UNTD80:ElB080Ygi:0P2VODT20:ElB080Y7]700<0XgQ10:Ai@P2TND80102TND80
0`2SN440XgY40:=jA0060:=jA0080:AiA02UNTD0YW]60:MlA`2VNdH0Y7U40:9g@P2QMT420:9iA@04
0:5hA02PMd<0WgI209ie@@80WGA00`2NM48409ec@@0409ab@02MM400W7<o09ac?`80Vg8n0P2JLCd0
0`2IL3`0Vg1309Y_@P0209Y_@P80VFi10P2HKD0309E`?080U6lk0`2CKSX309AZ>0<0TfTg0`2BJ3H0
0`2DJC`0TfPk09=X>`02099W>P80TFHi00<0T6Dh091V=02?IC<00P2?IC<208iT<P80SF<a0P28HSD6
08MQ=080RF<f0P28HSD408MQ=0<0QV0c0P25Gc8308AN<@0;08IQ=`25H3H0Q5le08=N=024GcD0Pehd
089M<`21G380PELa089H<P21FS<00P21Fc@00`1mFS80NeXa07UH;`0407]H;P@0NUL]00H0LeH/07EE
;01eEB`0MUD/07MD;01iDb`207YC;080N58[00@0NE</07YD;@1jE2d0NeD^0P1lERl307IF;`80MED^
0`1dE2d207IC;@@0ME8/0P1fDbd00`1aCRP0LTlY07AA:`0207EB;00307AA:`1bCbT0LDhX0080N50/
00<0MU0[07=@:P1aCbT00P1_CbP00`1/CbL0M54[07AA:`0207AA:`0407=@:P1bCbT0LTlY075>:080
Le8_0P1bDBh2075@;@80L4l/201`CBL8071@:P80Le0Z1`1bCbT406e@:0@0K4lW101^CRL206m?:080
L50Y201]C2T2079<9`03071=9`1_CBL0KThW0080K4lW00<0JdlW075=:@1aCBT01P1aCBT0101[Bb@0
K4`U06a<9@1/C2D206e=9P80KThW0`1aCRP2079?:@<0Le0Z0`1bCbT207=@:P<0M54[0P1dDBT207EB
:P80MU<[0P1gE2`207QE;@@0NEH^0P1hEBd207YD;@<0NeD^0`1lERl207UF;080NUL]00D0NeP^07aI
;`1lFBl0O5T_07iI;`0307mJ<080P5/a1@21G383081K<@80OeX`2023GS4308AP<00308EQ<@26HS80
QV8b0080Qf<c0P29HR/01P29HBd0RF4^08UQ<029H380RV4c08YQ=@80RfDd00<0RfDf08]U>02;I3T0
0P2;I3/00`2;I3d0RfLg08]W=`0208aX>080SFTi0P2>JSX308mZ=P<0T6/g0`2AK3P01P2CKD00Tfdn
09A^?`2DKSd0U6lk09E`>`80UG0i0`2LLcl209]b?P<0VW4m0P2LLcl209ed@00409mf@P2PMd<0XGQ4
0:9iA@<0W7M2102MN4<02@2NND@0WGQ109eh@@2NND80X7]40:5lA@2RODH0Xgi70:AoB0030:ElB080
YWe90`2WOTX20:=nB@<0Y7m:0`2UP4/30:R3CP@0ZHA?00<0ZXE@0:b3C`2/Pdl01P2/Pdl20:^6DP03
0:b7D`2]R5@0[XUE00<0[XUE0P2aQeD30;26E0<0[hEC0P2`Qe<40:n6DP80/8MC2`2]R5@30:j9E@80
[hYF202aR5@80:j9E0030:n:EP2`ReL0/8]G0080/8]G0`2aS5P00`2bSET0/HaH0:n:EP020:j9E@03
0:n:EP2aS5P0/hiJ00@0/HaH0`2bSET20;>>FPD0/HaH2`2`ReL20;>>FP80/XeI0P2aS5P20;2;E`P0
/hYF202`ReL80;:9E@80]H]K00@0]8YH0;>:EP2cRU@0/XUA0P2aRDh80;:=F0030:n:E@2`ReH0/8]F
0080/8]F0`2aS5L40;>:EP@0/hYD0P2aQeL0102aQeD0/HQD0;68E02aR5820;68D0030;27D`2aR5@0
/HQD00@0/HQD1@2`Qe<40;68E0P0[XEA402[QU480:j5D@<0[XE?0P2]Q4h30:b3C@T0ZXE@202]Q500
0`2^QE40[HA@0:f4D0040:f4D0040:j5D@2]Q4h0[8==0:^2C080ZX5;00<0Zh9<0:b3C@2]Q4h0202_
QU830:j5D@80[HA@0`2/Pdl20:n6D0030:j5C`2]Q4h0[8==0080Zh9<00<0ZX5;0:^2CP2[PTh00P2/
Pdl0102]Q500[XEA0:n6DP2`Qe<20:j3EP040:j4E02^Q580[XEA0:j5C`80[XE=0`2_QU840:j5D@04
0:f4D02[Pdl0Zh=?0:^3C`80[8A@0`2]QE400`2aR5@0/8MC0:j5D@020:f4D0030:j5D@2`Qe<0/HQD
00P0[8=?0P2`Qe<30:n6DP<0[XEA202/Pdl30:^2CP<0[8=?0P2]Q5030:b4D080[HEA0`2/Q5001P2Z
PDd0Zh9>0:^2CP2/Pdl0[HA@0:j5D@80[hIB202/Pdl00`2YP4`0ZX5=0:b3C`020:j5D@80[hIB00<0
[XEA0:f4D02/Pdl03@2/Pdl20:^2CP@0[HA@00@0[8=?0:^2CP2ZPDd0ZX5=2`2]Q5020:b3C`<0Zh9>
202]Pe460:f4D080[8=?0P2/Pd/0102/Pdd0[8=?0:b3C`2/PU020:b2DP<0[XEA0P2]Q5030:b3C`80
[HA>00H0Zh9<0:Z1B`2XOdT0Ygi80:ImA`2UO4H20:Z1B`<0ZH1:0`2XOdT20:b2D080Zh5?0P2ZP4h2
0:UoC@80ZX5;102[PT`20:Z1B`<0YX5<00<0Yh9=0:R3CP2XPdh00P2YQ4l80:R3CP80[8=?0P2[PTh2
0:Z1CA80ZH1<0P2YP4X20:Z1B`<0Zh9<0P2/Pdd30:QoB`030:V0C02ZPDd0ZX5=0080Zh9>0P2XOd/6
0:MnBP<0Z7m;0P2YP4`30:Z1CAP0ZH1<0P2YOT/20:YoC0040:^0C@2/PDh0[H9?0:f2C`80Zh9>00@0
ZX5=0:V0C02WOTX0YWe90P2UO4P20:MnBP040:QoB`2YP4`0ZH1<0:Z1C@80Zh9>0P2YOdl0102ZP4h0
ZX5=0:^2CP2[PT`20:b3B`P0ZGm=0P2WODd0102WOD/0Z7m;0:QoB`2YP4X20:V0B0030:Z1C@2YP4`0
ZH1<00@0ZH1<00@0ZX5=0:Z0CP2ZP4h0ZX1>0`2YOdd20:QnC0P0ZH1<0`2WOTP20:QoB@<0ZH1:0P2X
Od/30:MnBP<0YWe900P0XGQ40:9iA@2SNTH0Y7]70:ImB@2XOd/0ZH1<0:Z1C@T0YWe9202WO4T20:=i
B@040:AjB02TNdL0YGa80:ElAP80YWe500T0YWe90:MnBP2XOd/0Z7m;0:MnBP2UO4P0XgY60:5hA02T
NTP0102SNDL30:9hAP<0XgY60P2TNdL60:ElB0<0Y7]70P2SNTH20:ElB0H0Y7]700<0WgY50:1kAP2P
NdH00`2QO4L20:1kAPH0XWU50P2QN4@209me@`<0X7I40`2QMdD00`2OMT80X7M30:5hA0020:=jAP03
0:5hA02PMd<0WgI20080XgU700<0XGM50:1fA02NM4800P2MLd400`2LLT00X7M309mf@P0409ie@@04
09ed@02LLcl0W7<o09ac?`80WGA000@0WWE109ed@02MM400WGA00P2NM48209ec@@@0W79000H0Vfln
09]a?`2KLCl0VW8o09Qc?`2HM40209Ie@0<0Vg4o0`2JL3h209U_?@80VW100`2KLD4309ab@P@0Vg13
1@2JKd8809Ia?@0309Mb?P2EL3`0U6lk0080Tfhj00<0U6lk09E`?02GLSh00`2DKc/209E`?00409Ia
?@2GLSh0V7<o09U_?@@0VW0n0`2KLCl0202LMd<0VgI209Ye@@2IM400V7<o09Mb?P2FLCd0UG0l0P2H
Lcl609Mb?P<0Ufdk00<0V6hl09U_?@2JL3h00P2KLCl01P2ILdH0VG=409UcA02ILd80VGA009Ud?`80
VG@m00<0Ug=309Ib@P2DL4000P2CKcl00`2DL400UG5109Ib@P0309I`@B_ooooo000Zooooo`<0QV0c
0P27HC@308QR=@<0SF0f0`2<GcD208]N=0@0SV4g102?HSP2091S>@<0Sf8h0`2>HCL2099U>`80TF@j
00@0T6<i08mR>02?HSP0Sf8h0P2CIS`2099U>`80TF@j0P2@HcT8091T=`0309EY?02DJ3/0TFDh0080
T6@g00H0TFDh09AX>`2EJC`0Sf8h095T>P2BIC/209AW?@0309=V?02BIC/0TF@j00T0Uf/n00@0Uf`o
09I[?P2DJC`0TVLj0P2AIST00`2BIcX0TfPk09AX>`0209AX>`80UFTl0`2FJSd01P2AICP0TVHi09=W
>P2DJ3/0UFTl09M[?P80V6`o1P2EJC`209IZ?@<0UVXi0P2EJCP309IZ>@H0V6`k0P2GJcX309Q/>`<0
VFdl0P2JKSd0202LKdD0Vfm209U]@02IKCh0VFdl09Y_?02LLC`0WG8m202HK3/809]_?P0309U]?02K
Kch0W70o0080WG5000<0W70o09]_?P2IKC`00P2IKC`309Y^?@<0Vfln0P2JKSd309]_?P<0W70o202N
Ld0309eb?`@0WW=02@2OM4480:1e@P80Wg@m00@0Wg@o09md@@2OM440Wg=20P2OLd@0102MLSl0WW=0
0:5f@`2SN4D30:AiAP80XgQ500<0Y7U60:=hA@2QMT<00`2PMD820:9gA0030:1e@P2QMT<0XWM40080
XWM400/0X7E209ic@02MLSl0Wg=20:1d@`2QMD@0XWI50:5eA02PM4<0WW9109ea@0080:=gAP060:1j
B@2RNTT0XWY70:=jAP2TNDH0YWQ40P2WN4820:Ig@`040:MhA02XNDD0Z7U50:UjAP80ZW]7202WO4L8
0:IkAPP0YWe90P2WOTX20:ImB@80YGa80P2TNdL00`2TND@0XgQ30:=h@`040:=h@`030:AiA02SNT@0
XgY400H0XgY40P2SN4<30:EjA@030:AiA02RMd80XGI10080XGQ400@0X7M309mf@P2OMT80WWE10P2M
M40209id@P80WG=100@0W79009]a?`2KLCl0Vg4o102JLCd409U`?080VVm20P2IKT4309Q]@00409M/
?`2DKc/0U6lk09A_>`80Tfhj0`2BKCT409=Y=`80TVPf0`2AIcD2099W>P@0TFHi0P2@ICP308iT=080
SF<c0`2<HS800`28HSD0RF<f08US=P0308YT=`80RF<f1027HC@208IP<`D0QElb0P24GS4308=M<004
089M<`23GS@0Pehd08=N=0<0PE`b00@0PUdc085G<@22F380PEXc0P20FS<00`1lFC40NEP_07QG;P02
07]H<080NUL_0P1iERh207QE;@06079E:`1dE2/0M5@[07ED:`1fDb/0N58[0P1iDR/01@1fD2T0Me4Z
07QB:`1iDb`0NU@]0080NeD^00<0O5H_07EE;`1eEBl00P1dE2h307=C;@03079B;01dDB/0M54[00@0
ME8/0P1dDB/00`1_CBL0L4hX079@:P0207=A:`0<079@:P1`CRP0KddW07Q@;01gCb/0MU0[07=@:P1a
CbT0KdlX06i>9`1/CbL0Le4[0P1bD2X00`1aCbT0L4hX071>:002071>:0@0LE0]101`Cb`8071<:0P0
Kdh[1@1_CBL4071>:080KE0X0P1/CbL206]>9P80JTdU0P1/C2D206e=9P@0KThW201/BbP2071=9`03
06m=9`1^CRL0K4lW0080JdlW00<0JE0W06m;:@1_BbT01P1_BbT406];9080K4`U0P1]CBH0101^C2H0
KddW06m=9`1_CBL2071>:080LDlY0`1`CRP2075?:@<0LU0Z101cDRT407AC:P80Me@/101fDb/207MD
;080NE</0P1jE2d407]E;P0307QE:`1iER`0NEH/0080NEH/0`1jEbd0101mF2h0OUT_07iI;`1nFBl2
07mJ<0D0P5/a0`1oFS0207iI;`P0PUd`00<0Pel_08AP<024H3000P24H30308EQ<@80Qf8[00H0Qf8]
08MR;P27HC00Qf4b08IP<@26H3<208]U=00308]U=P2;ICP0Rf@i0080Rf@k00@0Rf@m08]W=`2;IcL0
RfLg0P2<J3P308eY>@<0SVTe0P2?JSH4091[=`06099/?`2BK3d0TV`m09=]?02CKSX0Tfhi0P2DKcP0
102KLSh0VW4m09Ya?@2JLCd309U`?00409Q_>`2KLSh0W7<o09ed@080WWE10`2OMT8209Ye@080VgI1
00X0W7M209eh@`2MN4<0WGQ309ag@02MN440WWU209mj@`2PNd@0XWe60P2SOTL30:AkA`80YGa80`2V
ODT20:9mB080Xgi9102TOdX20:N2C@80Z8=>00@0ZHA?0:Z5D02ZQE00ZXE@202/Pdl50:b7D`80[HQD
00@0[XUE0;26E02`QU@0/8ID0`2_QE<20:j4DP80[hIB102`Qe<20:n6DP/0[HQD0`2^RED20:n:EPP0
/HQD202^RE@30:n:EP030;2;E`2aS5P0/HaH00<0/XeI00D0/HaH0;2;E`2_RUH0[hYF0;2;E`020;6<
F0<0/8]G0`2aS5P30;:=F@80[hYF1P2`ReL80;6<F080/hiJ0P2bSET20;6<F080/8]G202dReL40;6<
F0@0/8]G202bRED0202fReh0]HYM0;F;F`2dRUP0/hYF0;:9D`2bRE40/HQ@202bSEP30:n:E@030;2;
EP2aS5L0/HaG0080/XeH102cRUH40;>9E`80/HMG00@0/HME0;68E02aR5@0/HQB0P2aR5030;68E080
/8MC2`2aR5@80:j5DA00ZhIA0P2^QE440:n6DP80[XEA0`2^QDl20:f4CP<0[8==2@2ZQE090:f4D0H0
[XEA00@0[HA@0:j5C`2]Q4h0Zh9<0P2ZPD/00`2[PT`0[HA>0:j5C`0;0:j5D@80[HA@0`2/Pdl01P2`
Qe40[hI@0:n6D02^QDl0[HA>0:b3C@80Zh9<00@0ZX5=0:^2CP2/Pdl0[HA@0P2^QE420:n6DP80[hEE
00@0[hEC0:n6DP2_QU00[hI>0P2_Qd`20;27D`80[hIB00@0[XEA0:f4D02]Q500[HA@0`2YQ4l20:Z5
D0<0ZhIA00<0/HQD0;27D`2^QE400P2]Q5000`2^QE40/8MC0;68E0080:b3C`80/8MC0`2_QU830:j5
D@P0[8=?0`2[PTh30:b3C`D0[HA@0P2/Pdl30:f4D080Zh9>00<0[8=?0:f4D02^QE400P2_QU800`2`
Qe<0[8=?0:b3C`060:b3C`030:V0C02ZPDd0[8=?0080[XEA0P2_QU800`2^QE40[HA@0:b3C`070:b3
C`80Zh9>1P2/Pdl20:f4D0030:b3C`2[PTh0Zh9>00<0Zh9>2P2]Q5020:b3C`80Zh9>0P2ZPDd80:f3
D@H0[HA@0P2^QE420:b3B`040:b3C@2/Pdl0[8=?0:b2D080[89B0`2^QE420:f4D0<0[8=?0P2/Pdd0
1P2[PT`0ZX5;0:V0BP2XOdT0Ygi80:ImA`80ZX5;0`2YP4X30:QoB@80[89@0P2[PDl20:Z0CP80ZGm=
0P2[PT`40:Z1B`80Zh9<0`2WPTd40:R3CP030:V4C`2XPdh0Z8=>00H0Z8=>102[PTh40:Z1CA00ZH1<
0P2YP4X20:Z1B`<0Zh9<0P2/Pdd00`2XOd/0ZH1<0:V0C0020:V0C0<0ZX5=0`2WOTX60:QoB`<0ZH1<
0`2ZPDd00`2[PTh0ZH1<0:V0C0060:V0C0P0ZX5=202YP4`20:UnB`80ZWm<00@0Zh1=0:b1CP2]PTl0
[H9?0P2[PTh0102ZPDd0ZH1<0:MnBP2VODT20:ElB0050:MnBP2XOd/0Z7m;0:V0C02ZPDd00P2[PTh0
1`2/Pdl0ZGm?0:UoC`2ZP4h0ZX5=0:^2CP2[PT`00P2/Pd/80:UoC@80Yge=00@0Yge;0:QoB`2XOd/0
ZH1:0P2YP4P30:V0C080ZX5=0`2YP4`30:Z0CP<0ZGm=0P2XOT`80:Z1C@<0Ygi80P2XOdT30:V0BP80
Z7m;0`2WOTX30:ImB@80XGQ400H0XgY60:ElB02WOTX0ZH1<0:Z1C@2[PTh90:ElB0P0YW]80P2SNDT0
102SNDL0Y7]70:AkA`2UO4H20:ElA0080:ImB@2WOTX0Z7m;0:QoB`2WOTX0YGa80:=jAP2QN4@20:Ek
B@80Y7Y800@0XgU70:9hAP2RN4H0XWQ60P2SNTH20:AkA`80YGa80P2VODT30:ElB0<0Y7]70P2SNTH6
0:AkA`80YGa800<0XGa70:1kAP2PNdH00`2ONTD20:1kAP80XGQ41P2RNDD30:1fA0<0XGM50P2RN4H0
0`2NMD40X7M30:5hA0020:9iA@030:5hA02PMd<0WWE10080XWQ600L0XGM50:1fA02OMD<0WG=109ab
@02KLCl0WWE10080WgI200<0WWE109ed@02LLcl01@2MM40409ac?`0409ed@02NM480WWA209id@P80
WG=10P2LLT001`2KLCl0Vfln09Y`?P2KLCl0VW8o09Ud@02IMD400P2GMT4309]a?`<0VW0n0P2IKcd3
09]a?`<0W7900P2MLd4909Y_@PP0V70m00<0Ug8n09E`?02DKc/00P2CKSX0102DKc/0UG0l09Mb?P2D
Kc/209E`?0D0UW4m0`2IKcd00`2JL3h0Vg4o09]a?`0209ab@080W7M300@0VgI209Ud@02HLcl0UW4m
0P2EL3`609Mb?P80V7<o0P2GKC/00`2HKS`0VFlm09Y`?P0309]a?`0609UcAP2ILd@0VG=409Uc@P2I
M400VG@o0P2IM3d0202GLd<0UW9209A`@02CKcl0U71009Ea@@2FLT80Ug=30`2FL44[ooooo`00:_oo
ool308IP<`80Qf4d0`28HSD308eP=P<0S5le0P2;GS@908iQ=`L0Sf8h0P2CIS`00`2BIC/0TF@j091S
>@0208mR>00408iQ=`2CIS`0TfHl09=V?080TVDk0`2AI3X8095U>080TVHi102CIcX2099V>@03095T
>P2BIC/0U6Lm0080UFPn00<0U6Lm099U>`2AI3X02@2FJSd0202FJch0UFXm09=X>`2BIcX0TFHi099W
>P2CJ3/0U6Tl0`2DJ3/209EY?0<0UVXm0P2BIST00`2CIcX0U6Pk09EY?00309IZ?@@0UFTl0P2FJSd2
09M[?P0309Q/>`2GJcX0UVXi0080UFTh00<0UVXi09M[>P2HK3/00`2IKC`309Q/>`80Uf/j0`2HK3/3
09U]?080VVhm00T0Vfi409Y^@@2IKD00V6`m09Q/>`2IKS/0VVlj09]`>`2GJcX00`2HK3/309U]?003
09Y^?@2JL3h0VW0n00H0VW0n00<0VFdl09]_?P2LL3l00P2MLD00102LL3l0Vfln09U]?02IKC`309Y^
?@80Vfln0P2LL3l209Y^?@<0Vfln0`2LL3l@09ic@100X7E20P2NLc`0102NLch0WW=009ic@02NLT42
09ib@`0509md@@2PMD80XWM40:=hA@2TNDH00P2SN4D01@2RMd@0XGI30:=hA@2RMd@0XGI30080X7E2
00D0XGI30:9gA02SN4D0X7E20:5f@`030:9gA0050:1e@P2NLd00WG8o0:5eA02RMTD00`2SMdH00`2Q
MD@0X7A309ib@@080:=gAP0609mkB@2PNTT0X7]70:9jAP2SNTH0Y7U40P2VND801P2UMT80YWM30:Ig
@`2WN4@0Z7U50:UjAP80ZW]7202WO4L80:IkAPP0YWe90P2WOTP20:ImA`80YGa60P2TNdD00`2UNTL0
Y7U60:=hA@030:=hA@030:AiAP2UNTL0Y7]50080Y7]50P2SNT@30:9i@`030:5f@@2RMd80XgQ30080
Y7U400<0XgQ30:9g@P2QMT400P2QN4@00`2PMd<0WgI209ie@@0209ed@00709ac?`2NM480WG=109ec
@@2LLT00Vg4o09Y`?P0209U_?@P0V6lk0P2IKT4209Q]@0<0Uf`o00@0UV/n09=^>P2CKSX0Tfhj0P2B
KCT3095/>00409=Y=`2BJ3H0TVPf099X=P80TFLe0`2@IS@8091U>080SF8e0P2<HC@308]P<`0608YO
<P27HC@0R68e08US=P2:I3L0RfDh0P2:I3L01029HcH0QV0c08IP<`26H3<208EO<PH0Q5ha0P23GC03
089L;`0807iI;`20Fc40PUdc085L<P1nFBl0OEP^07mJ<022GC<2085G<@06081I<P1oFC80OUPa07]H
<01gERd0MUD/0P1kF3800`1jEc40NEH`07QE;`0207MD;P0707IC;@1aE2X0Le<Z07=C:P1dDbX0ME8Z
07MA:P0207QA:P80MU0Y00@0Me4Z07QB:`1iDb`0NE</0P1jE2d307=B;`80LU4^0`1aD2d00`1bCbT0
Le0Z07AA:`0207EB;00607AA:`1cD2X0LTlY06e=9P1^CRL0L50Y0P1aDBX00`1`D2T0KThW06e=9P02
07I>:P0307A>:@1bCbT0LDlY0080KdlX00@0KE0X079B:`1aDBX0KdlX0`1^CRL206m?:0L0Kdh[00<0
KTdZ06m;:@1_BbT01P1_BbT806e<:`0406];901/C2D0K4`U06a<9@<0KDdV0P1^CRL206e@:00306a?
9`1[CRH0JTdU0080JD`T00@0J4/S06];901[Bb@0Jd/T0P1/C2D306e=9PP0JdXW0P1^C2H00`1]CBH0
JdhV06Y>9P0206Q?9P0306M@9P1^BRX0KTXZ00H0KTXZ0`1[Bb@206a<9@<0KDdV0`1/C2D206e=9PH0
KThW0P1_CbP3071@:@03075A:01bDRT0LU8Y00D0LU8Y00<0MU<[07EB:P1dDBT00P1cD2P00`1dDBT0
ME8Z07IC:`0207QB:`80NE</0`1jE2d00`1kEBh0N5D[07QE:`0607QE:`0407]F;01lEbd0O5L]07aG
;@80OEP^1`1nFBl307mJ<0P0P5/^1`23Gbl02@24H300QV<[08IS:`26Hbd0QV8^08EQ;`25HC40Q60`
08AO<P0208YT<`0308YT=@2:I3L0RV<h0080RV<j00<0RV<l08YV=P2;IcL00P2;IcL208aX>080SFTi
0`2=J3@208iY=@<0SfXf00T0T6/g091Z?@2@JS/0TF/l095[>P2BKCT0TVdh099]=P2CKSL0202HKc/0
0`2JLCd0Vg8n09ac?`0309ie@@80WGA00P2IM3l209Ye@00409]f@@2LMd80WGQ309eh@`80WGQ100<0
WWU209mj@`2PNd@00`2QO4D30:=jAP80Y7]70`2UO4P20:5lA`80XWe80`2SOTT01`2TOdX0YX5<0:N2
C@2WPTd0Z8=>0:V4C`2ZQE000P2[QU480:^2CP030:f8E02/Qe<0ZhIB00<0ZhIB00<0[8MC0:f8E02`
QU@00P2`QU@20:n5D`<0[XAB00<0[XEA0:n6DP2`Qe<00P2aR5@00`2`Qe<0[hIB0:j5D@0;0:f8E0<0
[XUE0P2_RUH80;68E0P0[XUD0P2^RED00`2_RUH0/8]G0;6<F0020;:=F@80/hiJ00<0/XeI0;6<F02a
S5P0202`ReL20;6<F0<0/XeI0`2^RED30:n:EP80/8]G202aS5P20;>>FP80/XeI0P2aS5P20;2;E`P0
]8]G0`2bSET20;6<F0<0/8]G202aR5@01P2eRUl0]HYM0;B9G02dRUX0]8YH0;>:EP80/hYD202bSET2
0:j9E0030:n:E@2`ReH0/HaG0080/XeH00L0/hiI0;>:E02cRU@0/hYF0;>9E`2cRET0/hQK0080/hQM
0P2aQeL0102aQeD0/HQD0;68E02aR5820;68D0030;:9E@2aR5@0/8MC0080[hIB00@0/8MC0;68E02b
RED0/hYF0`2bRED30;68E0030;27D`2^QE40[XEA00H0[XEA402[QU420:j4DP040:n5D`2`QU@0/8ID
0:n5D`80[XAB0`2^QDl20:f4CP<0[8==2@2YQ4l90:b3C`030:f4D02^QE40[XEA0080[XEA00D0[HA@
0:b3C`2^QDl0[HA>0:b3C@020:^2C0030:b3C@2]Q4h0[XE?00/0[XEA0P2]Q5030:b3C`040:n6D02^
QDl0[XE?0:j5C`@0[HA>00<0Zh9>0:b3C`2]Q5000`2^QE420:f4D080[hEC00<0[hIB0:n6D02_QTh0
0P2_Qd`01`2_QdX0/HQD0;27D`2`Qe<0[hIB0:j5D@2]Q5000P2/Pdl30:R5C`80ZHI@0`2ZQe400`2`
Qe<0[XEA0:f4D0020:b3C`030:f4D02^QE40/8MC00P0[8=?0P2_QU830:j5D@<0[HA@202/Pdl30:^2
CP<0[8=?0P2]Q5000`2_Q540[X=@0:f2C`020:b1CP030:f2C`2^Pe00[hAA00@0[HA@0`2^QE400`2_
QU80[8=?0:b3C`060:b3C`030:Z1C@2[PTh0[HA@00<0[hIB00<0[XEA0:f4D02/Pdl02`2[PTh30:b3
C`<0[HA@00L0[8=?0:^2CP2[PTh0ZX5=0:^2CP2/Pdl0[HA@00P0[XEA0`2/Pdl20:^2CP<0ZX5=302]
Pe420:j4DP80[hEC0P2[PTX0102[PT`0Zh9>0:^2CP2[PDl20:^1D@<0[XEA0P2]Q5030:b3C`<0ZX5;
0`2YP4X20:QoB@030:V0BP2ZPD/0ZX5;00D0ZX5;0P2/PU020:^1C`80ZX1>0P2YOdd00`2/Pdd0Zh9<
0:Z1B`020:V0BP030:Z1B`2[PT`0[8==0100Z8=>102[PTh40:Z1CA00ZH1<0P2YP4X20:Z1B`<0Zh9<
0P2/Pdd80:V0C080Z7m;0`2YP4`;0:Z1C@P0ZH1<202ZPDd80:V0C0<0ZGi;0`2ZOd`20:^0C@80ZX5=
00@0ZH1<0:QoB`2XOd/0Ygi:0P2VODT30:V0C0<0ZX5=0P2[PTh20:UoC`040:Z0CP2ZPDd0Zh9>0:^2
C080[8=;202YOdd20:MmC@040:MmB`2XOd/0Z7m;0:V0BP80ZH1800<0Z7m;0:V0C02ZPDd00P2[PTh0
0`2ZPDd0ZH1<0:QoB`030:Z0CP<0ZGm=0P2XOT`80:Z1C@<0Ygi80P2XOdT30:V0BP80Z7m;0`2WOTX3
0:ImB@80XWU500H0Y7]70:ElB02WOTX0ZH1<0:Z1C@2[PTh90:ElB0P0YW]800H0XWQ80:=iB@2SNDL0
XgY60:AkA`2TNdD20:ElA0030:ElB02VODT0Ygi:0080Ygi:00<0YWe90:AkA`2SNTH00P2VO4X00`2U
NdT0Y7Y80:=iA`020:9hAP040:5gA@2TNdL0Y7]70:AkA`80YGa80`2VODT30:EkB@<0Y7Y80P2SNDL2
0:=jAP<0Y7]70`2UO4P00`2RODP0XGa709mjA@0309iiA080WgY50`2QN4@30:9iA@80XgY60`2PMT@2
0:5gA@<0XWQ600<0WWA209me@`2QMdD00P2RN4H0102QMdD0WgE309id@P2OMD<30:1fA00;09me@`2N
M480W79009]a?`2MM400WgI20:1g@`2OMT80W7<o09Ya?@2LLcl00`2NMD40102LLcl0Vg8n09]b?P2K
LSh209ac?`80WG=10`2NM4802@2MLd40Vg4o09Y`?P2KKch0VW0n09]a?`2KLd00VWE109Ue@@0209Qg
@P<0Vg4o0`2JL3h209U_?@<0Vg8n0P2LLcl309ed@0@0VVm21@2IKT4809U_?@0309Mb?P2EL3`0U6lk
0080Tfhj00H0U6lk09E`?02GLSh0UG0l09Ia?@2GLSh209Qc?`0309Mb?P2FLCd0UG0l0080V6hl00<0
VFlm09Y`?P2KLCl00P2LLT002@2MLd40W7M309]f@P2JMD40VGA009Qc?`2GLSh0UW4m09E`?00209Ia
?@<0Ug8n0`2HLcl00`2GKC/0V6hl09Y`?P0309]a?`0809Y`?P2IKcd0VG=609UcA02GLD80Ug5009Mb
?P2GLSd209Ud?@80U7920`2BL4000`2DLT80UG=309MeA@0309I`@B_ooooo000Zooooo`<0QV0c0P27
HC@308QR=@<0SF0f0`2<GcD208]N=0D0SV4g1@2=H3H208iQ=`0508mR>02@HcT0TF@j095T>P2DIcd0
0P2CIS`01@2BIC/0T6<i08mR>02?HSP0SV4g00@0TfHl0P2BIC/2095T>PP0TFDh00<0Sf<f095U>02D
J3/00P2FJSd01P2DJ3/0TFDh08mS=P2CIS`0U6Lm09EX?P80UVTo00<0UFPn09=V?02BIC/02@2EJC`0
0`2EJSd0U6Tl099W>P02099W>P0309AY?02EJSd0Uf`o00<0U6Pk0P2EJC`309IZ?@T0U6Pk0P2EJC`2
09IZ?@80Uf/n00@0V6`o09Y^?@2IKC`0Uf/j0P2FJST00`2GJcX0VFdl09Y^?@0209Y^?@80VFdl0P2H
K3/209M[>P<0V6`k0`2IKC`209Y^?@0809Y]@`2IKD00V6`o09IZ>`2FJST0Uf`i09Q]>02IKST209Q/
>`80VFdl00@0VVhm09]_?P2KKch0Vfln202ILCh00`2IKC`0Vfln09a`?`0209ea@00309a`?`2KKch0
VFdl00<0VVhm0P2KKch309a`?`80VVhm0`2KKch309a`?`P0WgA11P2NLd0209eb?`P0X7E2202OM442
09ic?00409ic?P2NLd00WW=009ib@@80WW9300D0XGI30:9gA02SN4D0Y7U60:=hA@020:5f@`050:1e
@P2NLd00XgQ50:9gA02QMT<00P2PMD801@2QMT<0XgQ50:AiAP2PMD80XGI300<0XWM400D0X7E209ic
@02MLSl0XgM60:AhA`030:EiB0030:=gAP2RMTD0X7A300P0XgM60P2ONdT0102PNdL0XWY60:=jAP2S
NT@20:Ai@P80YGI200<0YWM30:MhA02XNDD00P2YNTH00`2ZNdL0Yga70:MlA`060:MlA`P0YW]6202W
OTX20:MnAP80YWe50P2UO4@20:Ak@`030:MkBP2VNTT0Y7Q70080XgM600@0Y7Q70:IjB@2WNdX0YGa6
0P2TNdD20:=jA080XWU300@0XGQ20:1e@02QMT40XWM20P2TND@0102SN4<0XWM20:5f@@2QN4@20:1g
@`0309mf@P2NMD40WGA00080W7<o00H0WWA209ec@@2LLT00Vg4o09Y`?P2IKcd209Q^?0H0Ufhj0P2H
Kc/309Q]@080Uf`o0`2FJch0102CKSX0TVdi099]>@2BKCT2095/>080T6/g0P2BJ3H2095W=@@0T6Hd
00<0SfDc08mT=`2?I3L00P2?I3L4091U>080S64d0P2;H3<308YO<P0508UN<@22G2l0Q5ha08IP<`27
HC@00P28HSD208IP<`<0QElb0P24GS4308=M<00408AN<@23GC00Ped`08=M<080PU`_0P21Fbh0201j
EB/0OEP^081K<@1oFS00NeH/07YE:`1mF2h0PE`b0P21Ec401`20FC80OeTb07iH<@1jEbl0MUD/07ED
:`1kEc<00P1jES801P1iEC40Me<_07IB;P1fDRh0ME4]071C:@80LU8Y00<0Le8Y07AA:@1fD2T00P1g
D2T407MA:P@0N58[0`1bDBh2075@;@<0L4l/00<0LDhX079?:@1dDB/00P1eDR`01P1dDB/0LTlY075>
:01]CBH0KThW06m?:080L50Y00<0KdlX06i>9`1]CBH00P1dC2P00`1cCBP0LDhX075?:@02071@:@09
06iA:@1bDR/0L50Y06i>9`1]CBH0K4`U06e=9P1^CRL0KdlX00@0K4/X101]C2T806i::0P0K4//00<0
JDTR06Y:8`1ZBR<00P1[Bb@01@1/C2D0KDdV06e=9P1]CBH0KE0X0080K4lW00D0JdhV06U<901XBb<0
J4/S06M:8P0306Y:8`80Jd/T0`1/C2D806]:9`0606i<9P1]CBH0KDdV06]>9P1ZCRH0J4lV0P1WD2H8
06e8:`0406];901/C2D0K4`U06a<9@80KDdV0P1^CRL306];9080K4`U1@1]CBH206i>9`<0KdlX00<0
L50Y075A:01aDBP01P1aDBP00`1eDRX0M54Y07=@:002075>9P0407=@:01dDBT0ME8Z07MA:P<0N58[
0P1iDb`207YD;@L0Me@Z00<0MU<Y07UD:P1iE2X00P1jEB/307]F;0@0O5L]00<0OEP^07iI;`1oFS00
0P20Fc4807mJ;@D0Pel_0`22GRh01@25IB`0Q6@[08AS;@23HRd0Pf8_0080PV0`00H0PEla08YT<`2:
I3<0RV@e08YT=`2:HcP208YS>P0308YS?02:ISH0RVHf00<0RfLg0`2<J3P208aW<`<0SFPd0P2>JCD2
08mZ=P0808mY?02?JCX0T6Xk091Z>@2AK3P0TF`g095/=@2BKCH209E/>00409I]>@2GKSX0V6lk09Q_
>`<0VG0l00d0VW4m09ac?`2NMD40WWE109ed@02LLcl0Vg8n09Mb?@2HLch0VG@o09Ye@02KMT40W7M2
0080WGQ3202ONT<20:9iA@80XgY60`2TNdL00`2UO4P0X7]60:5lA`020:5lA`80XWe80P2SOTT20:J1
C0060:N2C@2XPdh0ZHA?0:Z5D02[QU40[8MB202[PTh02@2^RED0[HQD0:^6DP2ZQE40ZHA@0:Z5D@2/
Qe<0[HQD0;26E0030:n5D`80[XAB0P2]Pe400`2^QE40[hIB0;27D`020;68E0030;27D`2_QU80[XEA
00/0[HQD0`2^RED20:n:EPP0/HQD202^RE@01P2]R5@0[XUE0:n:EP2`ReL0/HaH0;:=F@@0/hiJ0P2b
SET0102aS5P0/8]G0;2;E`2`ReL30:n:EP80/8]G0`2aS5P01@2bSET0[HQD0:f8E02]R5@0[XUE0080
[hYF0P2`ReL80;6<F080/hiJ0P2bSET20;6<F080/8]G202dReL20;>>FP80/XeI00@0/HaH0;2;E`2`
ReL0/8]G202aR5@20;>8G@80]8UL00@0]8YJ0;F;F@2eS5P0]HaH202bS5/01P2]R5<0[XUD0:n:E@2`
ReH0/HaG0;:=F080/hiI00P0/hYB0;>:E02cRUH0/hUG0;>8F`2cR5d0/hQN0;>7H080/HMG00@0/HME
0;68E02aR5@0/HQB0P2aR5000`2cRUH0/XUE0;27D`020:n6DP030;27D`2bRED0/hYF00<0/hYF00<0
/XUE0;68E02aR5@00P2`Qe<80:j5DA00ZhIA00<0[H=C0:j4E02`QUH00P2aQeL00`2`QUH0[XAD0:f3
D`030:j5C`80[HA>0`2/Pdd90:V4C`P0[8=?00<0ZX5=0:^2CP2]Q5000P2^QE401P2]Q500Zh9>0:Z1
C@2_QU00[XE?0:b3C@80Zh9<00<0[8==0:j5C`2_QU00202]Q5030:j5D@80[HA@0`2/Pdl30:f4CP80
[XE?0`2_QU000`2/Pdl0[HA@0:j5D@020:n6DP030:f4D02[PTh0ZX5=0080[hIB00@0[hI@0:n6CP2_
Qd`0[hM<0P2_QdX20;68E0060;27D`2_QU80[XEA0:f4D02/Pdl0Zh9>0`2VQDl20:N6D0<0Z8MA00<0
[XEA0:f4D02/Pdl00P2ZPDd00`2/Pdl0[HA@0:j5D@080:b3C`<0[HA@0`2/Pdl20:^2CPP0[HA@0`2[
PTh30:b3C`80[HA@00<0/H=A0;22D02^P4h00P2]Odd00`2^P4h0/89@0;63D@030:n6DP80[XEA0`2]
Q5090:b3C`030:f4D02^QE40[hIB0080[hIB00<0[HA@0:^2CP2ZPDd0202[PTh20:Z1C@80Zh9>00<0
[8=?0:f4D02]Q5000P2]Q5001P2/Pdl0Zh9>0:Z1C@2ZPDd0Zh9>0:f4D0T0[XEA0P2/Pdl20:^2CP@0
ZX5=202]Pe400`2/PU80[H=C0:f3D`020:j4E080[hEE00@0/8IF0:^2BP2[PTX0Zh9<0P2[PTh00`2[
PDl0Zh5A0:^1D@030:j5D@80[HA@0`2/Pdl30:QoB@050:V0BP2ZPD/0ZX5;0:Z1B`2[PT`00P2YP4X0
102ZPD/0Zh9<0:b3C@2/Pdd20:f4CP80[89@0P2[PDl20:Z0CP80ZGm=00<0[8==0:^2C02ZPD/00P2Y
P4X00`2ZPD/0Zh9<0:b3C@040:V4C``0Z8=>102ZPDd40:^2CQ00ZH1<0P2YP4X20:Z1B`<0Zh9<0P2/
Pdd20:Z1C@L0ZH1<0P2ZPDd20:^2CP80[8=?00L0[HA@0:b3C`2/Pdl0[8=?0:^2CP2ZPDd0ZH1<0080
Z7m;202YP4`80:Z1C@P0ZH1<0`2YOT/30:QmBP80Yga9202XOd/30:^2CP<0ZX5=0P2YP4`20:UoC`04
0:Z0CP2ZPDd0Zh9>0:^2C080[8=;202YOdd20:MmC@040:MmB`2XOd/0Z7m;0:V0BP80ZH1800<0Ygi:
0:QoB`2ZPDd00P2[PTh00`2ZPDd0Z7m;0:MnBP030:Z0CP<0ZGm=0P2XOT`80:Z1C@<0Ygi80P2XOdT3
0:V0BP80Z7m;0`2WOTX30:ImB@080:=jAP2TNdL0YGa80:ImB@2WOTX0Z7m;0:V0C02ZPDd90:AkA`P0
YGY70P2RN4P0102SNDL0XgY60:=jAP2TNdD20:Ak@`030:=jAP2TNdL0YWe900<0Ygi:00<0YWe90:El
B02WOD/00P2VO4X01@2UNdT0XgU70:9hAP2RN4H0XGM50080Y7]70P2UO4P40:ImB@<0YG];0`2TNTX2
0:=iB@<0XgY600<0Y7]70:ElB02UO4P00P2VODT00`2SOTT0XGa709mjA@0309eh@`0409iiA02ONTD0
X7M30:1g@`80XGQ400D0XWU50:=jAP2SNTH0XgY60:1fA0030:5gA@80XWQ60P2SNDL00`2NM4@0WgE5
0:1fAP020:5gA`060:1fAP2OMDD0WWA409ec@@2NM480WgE30P2PMT@02P2OMD<0WG=109ab@02KLSh0
WgI20:5hA02OMT80Vg8n09U`?02KLSh209mf@P0E09ie@@2LLcl0VW4m09U`?02JLCd0Vg8n09ac?`2L
LT00WG=109id@P2OMD<0WWA209ec@@2KLCl0VW0n09]_?P2JL3h0Vg4o09]c@02JMD40VWI20080VGQ3
0`2KLCl309Y`?P80VFlm00@0Vg8l09ac?@2LLcd0W7<m0P2MM3h209ie?`80Vg130P2JKd801@2IKT40
V6e009Q]@02HKD00Uf`o00P0VFlm00<0Ug8n09E`?02DKc/00P2CKSX01P2DKc/0UG0l09Mb?P2GLSh0
V7<o09Ud@080VWE100T0VGA009Mb?P2FLCd0Ufdk09Q^?02IKcd0VW0n09]a?`2LLT000P2MLd4309Ye
@@0309Ud@02HLcl0Ug8n0080Ug8n0`2FLCd00`2GLSh0V7<o09Qc?`0209Ud@00309U_?@2JL3h0Vg4o
0080W79000d0VW0n09Q^?02GKC/0V79509Ma@P2FL440UFln09E`?02FLC`0Ug8k09Qc?02CLd80TW91
0080TG5000@0TW9109=c@P2EMD@0UWI50`2FL44[ooooo`00:_ooool308IP<`80Qf4d0`28HSD308eP
=P<0S5le0P2;GS@408iQ=`@0SF0f00H0Rehd08aO=@2=H3H0SV4g08mR>02AI3X2099U>`80U6Lm00<0
TfHl099U>`2AI3X00P2?HSP00`2>HCL0U6Lm09=V?00209=V?080TVDk0P2AI3X8095U>00308eQ=02@
I3L0UFTl0080V6`o00D0UFTl091T=`2=HC@0U6Lm09EX?P0309MZ@00309IY?`2DIcd0TfHl00T0U6Pk
00P0U6Tl09=X>`2BIcX0TVLj09=X>`2EJSd0Uf`o09Q]@0<0U6Pk0P2EJC`309IZ?@80UFTl0`2DJ3/3
09=W>P0409AX>`2EJC`0UFTl09IZ?@80Uf/n0P2HK3l00`2LL3l0VVhm09Q/>`0209M[>P0409Q/>`2J
KSd0W70o09]_?P80VVhm00<0VFdl09Q/>`2HK3/00P2GJcX309Q/>`<0VFdl0P2JKSd0202IK480V6`o
09M[?P2EJCX0UFTh09I[>02GK3L0V6dh0P2IKC`209Y^?@0409]_?P2LL3l0W70o09ea@0P0VG4n00<0
VFdl09]_?P2LL3l00P2MLD000`2LL3l0Vfln09U]?00209Y^?@<0Vfln0`2LL3l209Y^?@<0Vfln0`2L
L3l809md@@D0WW=00`2MLSl80:1e@PP0WgA10P2NLc`0102NLch0WW=009ic@02NLT4209ib@`80XgQ5
0P2TNDH01`2SN4D0XGI30:5f@`2NLd00WG8o0:=hA@2RMd@00`2PMD801@2QMT<0XgQ50:AiAP2PMD80
XGI300<0XWM400/0X7E209ic@02MLSl0Y7Q70:EiB02VNTT0Yg]:0:IjB@2UNDP0XgM60:5eA0080:=g
AP0609elB@2ONdT0Wg]70:1kAP2RNTH0XgY40P2TND820:Ef@P040:Ig@`2WN4@0Z7U50:QiA@80ZGY6
202WO4L80:IkAPP0Ygi:0P2WOTH20:ImA@80YGa40P2TNd<00`2XO4/0Yg]:0:EiB0020:AhA`030:Ei
B02WNdX0Z7a;0080YGa600@0Y7]50:=jA02SNT@0XWU30P2QN4800`2OM3l0X7E00:9g@P030:=h@`04
0:5f@@2PMD00X7M30:1g@`80WgI200@0WWE109ed@02LLcl0W7<o0P2MLd401P2LLT00Vg4o09Y`?P2I
Kcd0V6hl09M]>`@0UVdi102GKSX209Q]@080Uf`o0`2FJch0102EJSd0TVdi099]>@2BKCT2095/>0<0
T6/g00@0TVPf095W=@2AIcD0TFLe0P2@IS@308mU<`80SV<f102?I3L2091U>0<0Rf0e0P2:Gc@308UN
<`0907iH:`1oFB`0PU`_08AN<@25Gc80Q5ha08=M<022G2l0QElb00<0Q5ha0P23GC02089L;`<0Ped`
0P22G2l3085K;P0I07MB:01lEbd0OeX`07iI;`1iE2X0N5<Y07]F;020Fc40P5H`085G<@20FC80OUPa
07eG<01iERh0MUD/07AC:P1kEc<0NUHb07UE<@1hE300Me<_07IB;P1eDBd0M50/071C:@02079B:@03
07=B:@1dDBT0MU0Y0080Me0Y201gDBX2079A<080LE0_0`1`Cbh0101_CRd0L4dW079?:@1cD2X207EB
;00607=@:P1bCbT0L4dW06Y=9@1[CRH0KE0X0P1^DBT00`1]D2P0JdhV06Y=9@02079:9P03079<9`1a
CRP0LDlY0080LE4Z0P1`Db/00`1^DBT0K4lW06Y=9@0206Y=9@0406a?9`1]D2P0JTTV06Y99P@0JdXW
0P1/BbP806i::PP0K4//00@0ITTQ06M:8P1WBR80J4/S0P1YC2@306Y=9@0806e@:01/CbL0JdhV06Y=
9@1YC2@0J4/S06M:8P1VBB4206U98P80JTXS0`1[Bb@00`1/C2D0JTTV06Y99P0606Y99P80KDdV00<0
JdhV06Y>9P1XCbH00P1WD2H00`1VDBH0K4LZ06a7:P0606a7:P80K4`U0P1]CBH306i>9`0306m?:01X
Bb<0JD`T0080JD`T0P1ZCBD506]>9P80K4lW0`1]D2P406mB:0@0KU4W00<0ME8Z07AA:@1bCbL00P1`
CBD00`1bCbL0M54Y07EB:P0207MA:P80N58[0`1iDb`0101jE2d0Me@Z07MD:P1gE2X507IC:@<0N5<Y
0P1iE2X507YE:`0607]F;01mF2h0OUT_07mJ<020Fc40PE`b201oFRd308=O;`D0PUh^00P0QFD/08AT
:`24Hbd0Pf8]089Q;P22H300PEl_085O<@80RV@c00<0RV@e08YT=`2:HcP00P2:HcX0102:Hc`0RVHf
08YV=P2:ISH208]W=`<0S6Ph0`2<Ic<208eX=0<0SVTe00L0SfXf08mY?02?JCX0SfTj091Z>@2@JcL0
TF`g0080TF`e00H0TfXf09A[=`2EK3P0UVdi09M^>P2IL3`209Ya?@0309U`?02JLCd0W7<o0080WWE1
00<0WGA009]b?P2JLCd00P2GLSd00`2HLch0VG@o09Ye@00209ag@P0309eh@`2PNd@0X7]400<0WgY3
0`2NND830:9iA@80XgY60`2TNdL20:1kAP80XGa70`2RODP01P2SOTT0YX5<0:J1C02WPTd0Z8=>0:V4
C`80ZhIA00<0[8MB0:^2CP2[PTh01P2[PTh00`2^RED0[HQD0:^6DP020:V4D0030:Z5D@2/Qe<0[HQD
00@0[hEC0P2^Q5820:f3D@030:f4D02_QU80/8MC0080/XUE00<0/8MC0:n6DP2]Q5002`2]R5@30:j9
E@80[hYF202aR5@80:j9E0060:f8E02^RED0[XUE0;2;E`2aS5P0/XeI1@2cSUX20;:=F@030;6<F02`
ReL0[hYF00<0[hYF0P2`ReL40;6<F080[8MC0P2]R5@0102^RED0[hYF0:n:EP2`ReL80;6<F080/hiJ
0P2bSET20;6<F080/8]G202dReL30;>>FP030;:=F@2aS5P0/8]G0080/8]G202aR5@0202bQed0/hQM
0;>8G@2dRE`0]H]K0;J<FP2fSET0]hiJ202bS5/01P2]R5<0[XUD0:j9E02`ReH0/HaG0;:=F080/hiI
00P0/hYB0;>:E02cRUH0/hUI0;>8F`2cR5h0/hMP0;>7HP80/HMG00@0/HME0;68E02aR5@0/HQB0P2a
R5000`2cRUH0/XUE0;27D`020:n6DP030;27D`2bRED0/hYF0080]8]G00@0/hYF0;:9E@2bRED0/HQD
0P2`Qe<80:j5DA00ZhIA00<0[H=C0:n5E@2`QUH00P2bR5P00`2`QUH0[hEE0:f3D`030:j5C`80[HA>
0`2/Pdd90:V4C`P0[8=?00<0ZH1<0:Z1C@2/Pdl00P2]Q5001P2/Pdl0ZX5=0:V0C02_QU00[XE?0:b3
C@80Zh9<00<0[8==0:j5C`2_QU00202]Q5030:j5D@80[HA@0`2/Pdl20:b3C@040:f4CP2^QDl0[hI@
0:n6D080/8MA00P0[HA@0:j5D@2_QU80/8MC0:n6DP2]Q500ZX5=0:V0C080[hIB00<0[hI@0:n6CP2_
Qd`00P2_QdX01P2_QdT0/HQD0;68E02`Qe<0[hIB0:j5D@80[8=?00@0Zh9>0:J5C`2VQDl0YXE?0P2W
QU030:R7D@030:f4D02/Pdl0ZX5=0080ZH1<00<0ZX5=0:b3C`2]Q5002`2/Pdl30:^2CP80ZX5=202]
Q5030:^2CP<0[8=?0P2]Q5000`2aPe40/89@0:j0CP020:eoC@030:j0CP2`PU00/H=A0080/8MC0P2_
QU800`2^QE40[HA@0:b3C`090:b3C`030:f4D02^QE40[hIB0080[hIB00@0[XEA0:b3C`2ZPDd0ZH1<
202[PTh20:Z1C@80Zh9>00`0[8=?0:f4D02]Q500[XEA0:f4D02/Pdl0ZX5=0:V0C02ZPDd0Zh9>0:f4
D02_QU880:j5D@80[8=?0P2[PTh30:Z1C@030:V0C02]Pe40[H=A00H0[H=A00@0[89B0:f3D`2]Pe<0
[XAD0P2_QED20;26EP80Zh9:00@0Zh9<0:^2CP2[PTh0Zh5?0P2[PE430:j5D@80[HA@0`2/Pdl01P2V
ODL0Ygi80:QoB@2YP4X0ZX5;0:^2C080[8==0P2YP4X01P2ZPD/0[8==0:f4CP2^QDl0[hI@0;27D@80
[89@0P2[PDl20:Z0CP80ZGm=00<0[HA>0:^2C02ZPD/00P2XOdT00`2ZPD/0Zh9<0:f4CP050:V4C`/0
Z8=>102ZPDd40:^2CQ00ZH1<0P2YP4X20:Z1B`<0Zh9<0P2/Pdd30:Z1C@D0ZH1<00@0ZX5=0:^2CP2[
PTh0[8=?0P2]Q5030:j5D@070:f4D02/Pdl0Zh9>0:Z1C@2YP4`0Z7m;0:MnBP080:V0C0P0ZX5=202Y
P4`20:UnB`80Z7e:00@0Yga90:IkB02UNTL0YGY70`2WOTX20:QoB`<0ZH1<00D0[HA@0:b3C`2/Pdl0
Zh9>0:Z1C@020:V0C0070:QoB`2YOdl0ZGm?0:Z0CP2ZPDd0Zh9>0:^2C0020:b3B`P0ZGm=0P2WODd0
102WOD/0Z7m;0:QoB`2YP4X20:V0B0030:MnBP2XOd/0ZX5=0080Zh9>00<0ZX5=0:QoB`2WOTX00`2Z
P4h30:UoC@80Z7i<202ZPDd30:MnB080Z7m90`2YP4X20:QoB`<0Ygi:0`2VODT20:ElB080YWe900@0
Ygi:0:QoB`2XOd/0ZH1<2@2TNdL80:EjA`80XWQ800@0XWQ60:=jAP2SNTH0Y7]50P2TNd<0102QN4@0
XgY60:ElB02WOTX20:QoB`070:MnBP2VODT0Yge;0:MmB`2VO4X0YG]90:AjB0020:9hAP030:5gA@2T
NdL0Y7]70080YGa80`2VODT0102WOTX0YG];0:EkB`2UNd/30:AjBP80XgU900@0XWU50:=jAP2SNTH0
Y7]70P2UO4P20:ImB@080:=nB@2QO4L0WgY509eh@`2LMd80WGQ309iiA02ONTD20:1g@`80XGQ400@0
XWU50:=jAP2SNTH0Y7]7102QMdD20:9hAP80XgU700<0WG=309meA@2PMTH00P2QMdL01P2PMTH0WgE5
09ec@`2KLCl0W79009id@P<0X7I401D0WWA209ec@@2KLSh0WgI20:9iA@2OMT80VW4m09Q_>`2KLSh0
WgI20:1g@`2NMD40W7<o09Ya?@2IL3`0VW4m09]b?P2LLcl0W79009ec@@2NM4800P2OMD<02`2MLd40
Vg4o09U_?@2KKch0VW0n09]a?`2KLd00VWE109Yf@P2IN4<0VWU400<0Vg4o0`2JL3h209U_?@@0W7<m
0P2MM3h209ie?`0509aaA02KL4<0Vg1309Y_@P2HKD000`2GK3l00`2FJch0VVhm09Y^?@0609Y^?@03
09Mb?P2EL3`0U6lk0080Tfhj00H0U6lk09E`?02GLSh0Ug8n09Ud@02JMD4209]f@P0409Ye@@2HLcl0
UW4m09M]>`80V6hl00<0VW0n09]a?`2LLT000P2MLd4409Ud@0@0V7<o00@0UG0l09Ia?@2FLCd0Ug8n
0P2HLcl209Ud@00B09Y`?P2KLCl0W79009ec@@2LLT00VW0n09M]>`2FK3X0V79509I`@@2EKd00Tfdl
09=^>P2EL3/0UW4j09Qc?02CLd80TW910P2ALD00102BLT40U7A309IfA@2GMdH309I`@B_ooooo000Z
ooooo`P0S5le202?HSP0202=HC@0SV8e091T=`2@I3L0Sf<f08eQ=02;Gc80REd`0P2@HCL01P2>HCL0
SV<h08eT>02;ICP0S6Hi08]V>@P0TVLl202?HSP8095U>00308iS>02?I3T0TFHk0080TfPm00@0TFHk
08mT>@2>HcP0T6Dh0P2AIST00`2BIcX0TfPk09AY?00209EZ?@T0TfHl0P2BI4001P2CISd0TfHl09AX
>@2EJSL0UFXe09I[=080V6`k0P2GJcX01@2FJST0UFTh09EY>02DJ3L0T6@g0080TFDh00<0TfLj09AX
>`2EJC`00P2FJSd01P2IISL0V6Ph09QX>02HJST0Uf/j09I/>P80UVhk0P2HKCP00`2HKCX0V6`k09Q/
?@0209Q/?`0609Q[@@2FJcH0UV/f09M/=`2HKCP0VFhi0P2JKcX00`2KL3/0UVXi09M[>P0209M[>P80
V6`k0P2IKC`309eZ>`<0WV/l0P2OK3d809Y^?@0409Q^?02IKcd0VFlm09Y`?P80Vg4o0P2LLT000`2M
LSl0W74n09U^>`0209Q]>P0309U^>`2JKc`0W74n00X0WG8o00H0W74n09]`?@2MLSl0WgA10:9gA02T
NDH20:9b@@<0XG500`2PL3l20:1e?P040:1e@02PMD80X7E20:1d@`80X7A50`2NLd0209md@@<0X7E2
00P0WgA109ic@02MLSl0W74n09eb?`2OM440XWM40:=hA@80WW=000<0WgA10:1e@P2QMT<00P2RMd@0
0`2SN4D0Wg=209mc@P0709mc@P80YGY7102TNDH20:=hA@P0YGE4202TNDH0202VNTT0YGU80:9fA@2Q
MD@0X7A30:5eA02SMdH0Y7Q70P2RMd00102SN440Y7U20:Ai@P2UNT<20:IkA080XWM400@0XgQ50:Ai
AP2TNDH0YGY71@2VNdP30:EjA`80Y7U6202XODP0102ZPDd0ZH1<0:QoB`2XOd/40:MnBPP0Y7]70100
Yga90:EjA`2SN4D0XGI30:1e@P2QMT<0XWM40:=hA@2ROdD0Xgm50:9nA02TOD@0Y7]30:Ej@`2WNT<0
YWU20`2RM4<20:5c@P<0X7910P2NM48209ec@@<0W79000@0Vg4o09Y`?P2JL3h0VW0n0P2IKcd309Q^
?0P0UG0i0`2EJSd209AY?0<0TfPk0P2;JS@00`2=JS@0SFPc08mW<`0208mV<P04091U<P2>J3T0SVPi
08iX>@80SFLh102<ISL00`28HcH0Qf8e08EP<`0208AO<P0:08EP<`27HSD0R6<f08IQ=`27HSP0R6<i
08UT>P28HcT0QF0f08=N=080PE`b0P22GC<01@23GS@0PUdc081K<@1nFBl0O5L]00P0PUh^0P22G3D0
0`21Fc@0P5Xc07mI<P0207iH<@0907eG<01lERT0P5X]08=M<021Fbh0O5HY07UC9P1lERT0P5X]00<0
OUHb0P1mEC4307aD<004075>:01bCbT0M54[07IC;@80Me@^00@0MU<]07EB;01gD2l0Me0_0P1fCbh3
07E>;@0507A=;01dDc00Le8_07=B;`1bDBh00P1aD2d2071?;080LU4^00<0LE0]071?;01_CR/00P1]
C2T02@1/BbP0KD`Y06i=:P1`Cb`0LE0]079A;P1aD2d0L4l/06m>:`0206]::@80K4/Z00@0KD`[06i=
;01^CB`0Kdh]0`1ZBBP00`1[BRT0K4/Z06e<:`0206e<:`80KTPT00T0KdTU071:9P1aBbL0LT`X07==
:@1dCRX0JD/Y06Q::01VB2H00P1UAbD00`1VB2H0J4XX06U;:@0806]8:00806I7:01WB2T0J4TZ06U:
:`1XBBX0IdPY06E69`1TABH206M98`80J4XT00<0JD/U06Y<9P1ZC2H00P1[CBL806]::@P0JT`Z0`1Y
BbT306Q::080IdTW201TCB@0201ZAbT0JDHX06Q59`1XABL0JDHX06Y7:@1/BB/0KT/]0`1ZC2X506U;
:@P0J4`W0P1]DBX0101/D2T0JdlX06Y>9`1ZCRL206U=9P<0K4lU0P1]D2H306iA9`P0MU0[00D0NTl/
07]@;@1iDBd0NE<^07QE;`0207QF<00607QH<@1hDBX0NE8[07QB:`1fDb/0ME@[0P1eEB`00`1cER`0
NEH^07UF;P0607UF;P0;07AC:P1fEB`0NEH^07aF;`1mEc00OEH_07iD;P1mDbd0OETY07iJ:P20G2`0
0P21GBd01P20G2`0OUXZ07eI:@1nG2h0Oed_081N<080PEla00<0Oed_07eK;@1lFR`02026H3<308EQ
<@80QV8b0`27Hc<308YV=P80RfLg0`2<J3P408aW<`80SFPd0`2>JCD00`2CJCL0UF/i09M]>`0209Q^
?00609M]>`2EJcT0TfTg09Q_>`2GKSX0UF`h0P2DJcL00`2FKCT0V6lk09U`?00309Ia?0D0UG0k0P2I
L3`00`2JLCd0Vg8n09ac?`0209ed@00509ie@@2KMT40W7M209ag@P2MN4<00P2NND@209mjA@0309eh
@`2NND@0WgY50080X7]600H0WgY509iiA02MN4<0XGa70:1kAP2ONTD209iiA0030:1kAP2RODP0Xgi9
0080Xgi:00H0Y7m;0:F0C02WPTh0Z8=?0:V4D02ZQE430:V4D080ZXEA0`2[QU800`2YQ500ZXEA0:b7
D`020:f8E0030:b7D`2ZQE40ZHA@00P0[XEA0P2^Q5820:n5D`<0/8ID00<0/HME0:^5F02[QEP01P2[
QEP20:b7D`80[HQD00@0[XUE0:n:EP2_RUH0/8]G202cREL80:n:EP80[HQD00@0[XUE0:n:EP2_RUH0
/8]G0P2aS5P20:n:EP060;2;E`2bSET0]8mK0;F@G02fTEd0]i9N2@2^RED80:j9E0030:f8E02^RED0
/8]G00<0/XeI00<0/HaH0;2;E`2_RUD01`2_RUD40;F<F080]XeI102gSUX01`2fSET0]HaH0;B;E`2c
RUH0/XUE0;68E02aS5L00P2`ReH00`2^RE@0[HQC0:b7DP020:^6D@<0]8YH0`2cREL20;:8EP060;>=
H02cSEh0/XaM0;:<F`2aS5P0/HaG0P2`Re@30;6<F0<0/8]G0P2_RUH80;:8EPP0/hYB0P2^QE400`2_
QU80/8MC0;68E0020;>:EP060;B;E`2fSEL0]XeG0;F<EP2dReD0/hYD0P2bRE<00`2aR580[HQC0:f8
D`060:f8D`P0[HQD202[QU480:f4D0030:b3B`2^QDd0[hI>0080/8M?00<0[hI>0:j5C@2/Pd/02@2/
Pdl30:^6D@80ZXE@0`2YQ4l:0:f4D0<0[8=?0`2[PTh30:j4DP030:n5D`2`QU@0/HME00@0/HME00<0
/8ID0:n5D`2^Q5800P2/PU000`2[PDl0[XEA0:j5D@040:f4D080[8=?0P2]Q5030:j5D@<0[hIB00<0
ZHA@0:Z5D@2/Qe<00P2]R5@01P2/Qe<0ZXEA0:V4D02/PU00[H=A0:j4DP80[hEC00<0[H=A0:^1C`2Z
P4h00`2YQ4l20:Z5D0<0ZhIA00P0/XQH0;26EP2^Q5@0[89B0:^1D@2ZP500Zh5A0:b2DPP0ZHA?00<0
ZX5=0:^2CP2]Q5000P2^QE400`2]Q500Zh9>0:Z1C@030:b3C`030:^2CP2ZPDd0ZH1<0080ZH1<00<0
Z7m;0:Z1C@2[PTh00P2]Q5000`2[PTh0ZX5=0:QoB`0:0:j5D@@0[HA@0P2/Pdl80:f4D0T0[8=?00<0
[XEA0:b3C`2[PTh00P2ZPDd01P2[PTh0[8=?0:j5D@2_QdX0[HE80:^3AP80ZH5400H0Zh=60:f5B02_
QdX0[XEA0:b3C`2[PTh20:Z1C@060:^2CP2/Pdl0[XEA0:^2CP2/Pdl0[XEA0P2_QU800`2^QE40[8=?
0:^2CP080:^2CP80ZH1<00<0ZX5=0:^2CP2/Pdl00P2^QE400`2_QU80[HA@0:f4D0030:j5D@<0[hIB
0P2]Q5030:b3C`<0Zh9>00<0Ygi60:QoA`2YP4P00P2[PTX00`2YP4P0Z7m70:MnAP020:Aj?P040:Il
@02XOT80ZX140:b2AP80[XA8202[PTh00`2^PU<0[81A0:YnC`020:QlC@030:UmCP2ZOTl0Zgm@0100
ZH1:0P2YP4`20:Z1C@80Zh9>0P2/Pdl80:V0C0080:QoA`2YP4P0ZH1:0:Z1C@2[PTh0[89@0:b2DP2]
Pe<80:UoC@T0[8=?00H0YGa80:MnBP2YP4`0Zh9>0:b3C`2[PTh20:Z1C@060:QoA`2YP4P0ZX5;0:^2
CP2/Pdl0[XAB0P2_QED02@2^Q5@0[H=C0:b2D02[PTh0ZX5=0:V0BP2XOdL0Ygi60:b3C`030:^2CP80
ZX5=0P2YP4`80:^2CP<0YX==0`2UPT`20:B1B`080:YoC02YOT/0ZGe<0:QlC@2WNdh0YgY@0:IiC`2V
NE080:MmB`060:EkB`2VO4`0Yge=0:QnCP2ZP500[89B0P2]Pe<80:Z0CPP0ZH1<00X0[8=;0:^2BP2X
OdT0YWe90:ElB02VO4X0Yge=0:QnCP2[PTh0[8=?0P2]Q5001`2/Pdl0Zh9>0:V0C02WOTX0ZX1>0:Qn
C02WOD/00P2VO4X02`2WOD/0ZX1>0:^1C`2[P5D0ZWmB0:QmD02WODd0Yge;0:QoB`2ZPD/0Zh9<00<0
Yge=0P2XOTh30:UoC`80ZH1800@0ZH1:0:V0C02YP4`0ZGm=0P2YOdl20:IlC0040:IlBP2VODT0YWe9
0:ImA`80YWe52@2VODT0202ONTD0XGa70:=nB@2TOdX0YH1;0:AoBP2SOTT0XWe80P2UNd/0102TNTP0
XgY60:=jAP2RND<20:5h@0<0Y7Y800<0YG]90:IlBP2WOD/00P2WOD/20:MnAP80YWe50P2UO4@20:Ak
@`<0X7]61@2QO4L20:MnAP040:MnB02WOTX0Ygi:0:MmB`80Yge=00<0YWA30:QfA@2ZN4L00P2[NDP0
0`2ZN4L0ZGM60:MeA0080:1g@`80XgQ30P2RMd830:5f@@0<0:1e@02QO4P0WgY609ehA02LMd<0VgI2
09ag@`2MN4@0WgY609me@`2PMT@0XWQ60P2SNDL00`2RN4H0X7I409me@`0209emA00609akA@2KNTD0
VWU609UgA`2HMTH0V7I8202MLd400`2GLSh0UW4m09Ia?@0209Ia?@0309Mb?P2HLcl0V7<o00<0WG=1
0P2NM48309me@`<0VWA30P2KMD@309afA@80WWE10P2MM40409ac?`P0V7<l2@2GLD002`2IKST0V6li
09Q_>`2FKS/0U6hm09=_?`2@KSh0T6i009E`?02DKc/0TVdi0080TF`h00<0TVdi09A_>`2EL3`00P2L
KSd309e_?P<0WW0o00<0VgI209Ud@02HLcl00P2FLCd02@2HLcl0VGA009]f@P2PMDX0WgA709icAP2M
Ld<0W79009]b?P0209Ya>`0809E^@`2DKD80U6e209E^@`2FKd@0VG9709aeBP2MMT/209Ud?@0309Ud
?`2IM400VG=20080VG=40140VG=609I`@@2EKd00U6ho09=]?P2DKSl0UW1109UcA02JM4D0VWHl09Ye
?P2IM3l0V79109MaA02EKT<0UFi709A]AP0309M^@2_ooooo000Zooooo`P0S5le202?HSP0202=HC@0
SV8e08mS=P2@I3L0Sf<f08iR=@2<H3<0RUha0P2@HCL01P2>HCL0SV<h08eT>02;ICP0S6Hi08]V>@P0
TFHk202?HSP8095U>00308mT>@2@ICX0TFHk0080TVLl00<0TFHk091U>P2?I3T0102BIcX409=X>`T0
TfHl00P0TVA009=V?`2CISd0U6Lm09AX>@2EJCP0UFXe09I[=P80V6`k0P2GJcX02P2FJST0UFTh09EY
>02EJCP0TFDh099V>@2CIcX0U6Pk09EY?02FJSd209M[?P0609YW>02HJ3P0V6Ph09QZ>@2GJcX0UV`j
0P2FKS/209Q]>00309Q]>P2HK3/0V6`m0080V6`o00D0V6]109M/=`2GK3L0V6dh09U^>@0209Y_>P80
Vg0k102GJcX209Q/>`80VFdl0`2KJc/209a/?0<0WFdm202JKSd309U_?@0309Y`?P2KLCl0Vg4o0080
W79000<0WG8o09]`?@2JKc`00P2HKCX00`2IKS/0Vg0m09aa?P0:09aa?P80Vg0m00@0W74n09ic@02P
MD80XWM40P2RLT430:5a@0<0X70o0P2PMCh0102PMD00X7E20:1e@P2PM4<20:1dA@<0WW=00P2OM443
0:1e@P0309md@@2NLd00WG8o0080WG8o00<0WgA10:5f@`2SN4D00P2OM4430:1e@P<0XGI32@2OLd86
0:AiAP80XgQ5202UMD@80:AiAP030:EiB02TN4L0XWI50080XGE400<0XWI50:AhA`2UNDP00P2RMd00
102SN440Y7U20:Ai@P2UNT<20:IkA080XgQ50`2TNDH30:EjA`<0YW]80`2UNTL20:AiAPP0Z7e80P2Y
P4`20:QoB`@0Ygi:202TNdL02@2VNdP0YGY70:=hA@2QMT<0X7E20:5f@`2RMd@0XgQ50:1m@`020:5m
@`030:9k@P2SNT80XgQ10080YGQ10P2RM4<20:5c@P<0X79100@0Wg5009ec@@2MLd40WG=10P2LLT03
09]a?`80VW0n0P2IKcd309Q^?00309M]>`2DKcP0U6lh00H0U6lh00@0UFXm09AY?02DJC`0U6Tl0P2C
J3/2099W>P80RfXe00<0SFTe08eX=02?Ic@00P2?IC<00`2@I3<0SVPi08iX>@0208eW>0@0S6Hg00@0
RfDf08QS=P27HSD0QF0c0P24Gc801@25H3<0Qf8e08QS=P26HCL0Qf8h0080R6<i00L0Qf8h08EP=P22
GC<0PE`b081K<@21G380PUdc0080Pehd00<0PE`b081K<@1nFBl02022GRh3081J<`<0OeTb0P1nF340
2@1lEBX0OeP]089K<020FBh0Ne@Y07UB9`1lEBX0OeP]07iF<P0307eE<@80O5@`0P1kDbl02@1bCbT0
Le0Z07EB;01fDbd0Me@^07IC;@1eDR`0M54[07EA;`0307A@;P80Ldl]0P1bCR`207=B;`80LU4^00D0
LE0]071?;01`Cb`0L4l/079A;P02075@;@08071?;01^CBX0KD`Y06e<:@1/BbP0KD`Y06i=:P1_CR/2
071?;00306m>:`1^CBX0K4/X00<0JdXY00<0K4/Z06e<:`1]C2/00P1^CB`00`1YB2L0JTTX06Y9:002
06]::@80K4/Z00@0KD`[06e99@1]BBD0KDTU0P1^BRH306m;9`0306U;:@1XBRP0ITPV0080IDLU00<0
ITPV06Q::01YBbT0201[B2P0201VAbP0IdPY06Q9:P1YBR/0J4TZ06M8:@1UARL0I4DV0`1VB2800`1W
BB<0J4XT06Q:900306U;9@P0JdXY2`1YBbT206Q::0<0IdTW201UC2@0201ZAbT0JDHX06Q59`1WA2H0
J4DW06Y7:@1/BB/0KDX/0`1XBRP406U;:@0306Y<:P1XC2L0J4`W00H0J4`W0`1[CbP306Y>9`80JDdV
00@0JdhV06a?9`1/CbL0K4lW0P1]D2P206iA:@P0Le0Z00H0N4dZ07I>:P1fCRX0MU0[07AA:`1cDB/2
07=C;080N54Z00<0N58[07IC:`1eE2/00P1dE2/00`1bEB/0N5D]07QE;@0607QE;@0307ED:`1fEB`0
NEH^0080O5H_00H0OEH_07eC;@1lDR`0O5PX07eI:@1nFRX207mK:`0607iJ:P1mFBT0O5PX07eK;@1n
G2h0Oed_0P20GS000`1oGBl0OU`^07eK;@0808EO<P0408AP<025HC40QF4a08EQ<@80QV8b0P27Hc<2
08UU=@80RVHf0`2;IcL00`2<J3P0RfHb08]V<P0308aW<`80SFPd0P2>JCD00`2BJ3H0TfTg09E[>@02
09I/>P0609E[>@2CJCL0TVPf09M^>P2FKCT0UF`h0P2DJcL00`2FKCT0V6lk09U`?00609Ia?080UG0k
0P2IL3`0102JLCd0Vg8n09ac?`2LLcl209ed@080VgI100<0W7M209eh@`2MN4<00`2NND@00`2MN4<0
WWU409mjA@020:1kAP0509mjA@2NND@0WGQ30:1kAP2ONTD00`2NND@00`2PNdH0XWe80:=nB@020:Ao
B`80YH1<00<0YX5=0:N2CP2XPdl00P2XPdl30:V4D080ZXEA0P2[QU800`2YQ500ZXEA0:b7D`020:f8
E0030:b7D`2ZQE40ZHA@00P0[XEA0P2^Q5820:n5D`@0/8ID202/QUL20:b7D`80[HQD00@0[XUE0:n:
EP2_RUH0[hYF202cREL80:n:EP80[HQD00@0[XUE0:n:EP2_RUH0/8]G0P2aS5P20;2;E`040;6<F02b
SET0/hiJ0;B?F`80]I1L2@2`ReL80;6<E`030:f8E02^RED0/8]G00<0/XeI00<0/HaH0;2;E`2_RUD0
1`2_RUD0102dReL0]HaH0;F<F02eS5P20;J=F@80]hiJ00@0]XeI0;F<F02eS5P0]HaH0P2dReL20;>:
EP80/HaG00H0/8]F0:n:E@2^RE@0[HQC0:b7DP2[QU470;>9E`070;B:F02cSF00/heN0;:<G@2bS5/0
/HaH0;6<E`020;2;E0<0/HaH0`2`ReL20:n:EPP0/XQF202cRU820:j5D@060:n6DP2`Qe<0/HQD0;:9
E@2cRUH0]8]G102cRU@40;:9D`P0[HQC202/Qe<80:^6D@P0[HA@00<0[8=;0:j5C@2_QTh00P2`Qdl0
0`2_QTh0[XE=0:b3B`090:b3C`<0ZhIA0`2ZQE020:V4C`X0[HA@0`2/Pdl30:^2CP<0[XAB00<0[hEC
0;26E02`QU@0102aQeD01P2`QU@0[hEC0:j4DP2]Pe40[89@0:^1C`80[XEA202]Q5030:j5D@<0[hIB
00<0ZHA@0:Z5D@2/Qe<00P2]R5@01P2/Qe<0ZXEA0:V4D02/PU00[H=A0:j4DP80[hEC00<0[H=A0:^1
C`2ZP4h00`2YQ4l20:Z5D0<0ZhIA00@0/XQH0;26EP2^Q5@0[89B0`2[PE400`2/PU80ZHA?0:V4C`06
0:V4C`030:Z1C@2[PTh0[HA@0080[XEA00<0[HA@0:^2CP2ZPDd00P2/Pdl20:^2CP80ZX5=0`2YP4`0
1`2ZPDd0Zh9>0:b3C`2/Pdl0Zh9>0:Z1C@2YP4`03P2]Q5020:b3C`P0[HA@2@2/Pdl00`2^QE40[8=?
0:^2CP020:Z1C@050:^2CP2/Pdl0[XEA0:f5BP2/Q4T0102[PdP01@2/Q4T0[HE:0:j5D@2/Pdl0Zh9>
0080ZX5=00H0Zh9>0:b3C`2^QE40Zh9>0:b3C`2^QE420:n6DP030:j5D@2/Pdl0Zh9>00P0[8=?00D0
ZH1<0:Z1C@2ZPDd0Zh9>0:f4D0020:j5D@040:n6DP2]Q500[HA@0:f4D080[XEA0`2_QU830:f4D080
[8=?0`2[PTh00`2XOdL0ZH180:^2BP020:b3B`030:^2BP2YP4P0Z7m70080YWa200@0Yge30:UoA@2Z
P4H0[8980P2]PdT80:^2CP080:b0D@2[Oe00ZWi?0:QlC@2YODh0ZWi?0:]oD02]PE8@0:V0BP80ZH1<
0P2ZPDd20:^2CP80[8=?202ZPDd20:Z1B@040:Z1B`2ZPDd0Zh9>0:^1C`80Zh5A202YOdd90:b3C`03
0:MnBP2XOd/0ZX5=00<0Zh9>00P0ZX5=0:V0C02ZPDT0ZX590:^2C02[PTh0[8=?0:f3D@80[XAD0P2]
Pe<01P2/PU00Zh9>0:Z1C@2YP4X0Z7m70:MnAP@0Zh9>0P2ZPDd20:V0C0P0Zh9>0`2WPTd20:J1C0<0
YH1;00P0ZWm<0:UnB`2YOD`0Z7a=0:QlC`2WNdh0YgY@0:IiC`P0ZGm=0P2WODd00`2XOTh0ZGm?0:Z0
D0020:^1D@030:b2DP2ZP4h0ZX1>00H0ZX1>202YP4`01P2/Pd/0ZX590:QoB@2WOTX0YWe90:IlBP80
Z7i>00/0ZX5=0:^2CP2/Pdl0[8=?0:^2CP2ZPDd0Z7m;0:MnBP2YOdd0Z7i<0:MmB`020:IlBP0;0:Mm
B`2YOdd0ZX1>0:^0E@2ZOe80Z7e@0:MmC@2WOD/0Z7m;0:Z1B`2[PT`00P2WODd30:QnCP<0ZGm?0P2Y
P4P0102YP4X0ZH1<0:V0C02YOdd20:UoC`80YWa<00@0YWa:0:ImB@2VODT0YWe70P2VODD90:ImB@08
09mjA@2QO4L0Xgi90:AoBP2UP4/0Y7m:0:=nB@2RODP20:EkB`040:AjB02TNdL0XgY60:9i@`80XWU1
0P2TNTP20:EkB@040:IlBP2WOD/0Yge;0:MmB`80Ygi60P2VODD20:ElA080Y7]3102QO4L40:9mB080
Ygi600@0Ygi80:MnBP2WOTX0Yge;0P2WODd00`2UMD@0YWI50:QhA`020:UiB0030:QhA`2WMdH0YWI5
00P0XGQ40P2SN4<20:9g@P@0XGI100<0XGa80:1kA`2NNDD00`2LMd<01@2MN4@0WWU50:1fA02QMdD0
XgU70080Y7Y800<0XgU70:5gA@2PMT@00P2MOD@01P2LNdD0VgY509YiAP2IMdL0V7I609QfB0P0WG=1
1P2HLcl209Ud@0<0WG=10P2NM48309me@`<0VWA30P2KMD@309afA@80WWE10P2MM40309ac?`0309]b
?P2HLc`0V7<l00H0V7<l2@2GLD002`2KL3/0VG0j09U`?02HL3d0UFln09A`@02AKcl0TFm109Ia?@2E
L3`0U6lk0080Tfhj00<0U6lk09E`?02FLCd00P2LKSd309e_?P<0WW0o00<0VWE109Ud@02HLcl00P2G
LSh02@2HLcl0VGA009Ye@@2OM4T0WgA709icAP2MLd<0W79009]b?P0209Ya>`80UFi300H0U6e209E^
@`2FKd@0VG9709aeBP2MMT/209Ud?@0309Ud?`2IM400VG=20080VG=400<0VG=609I`@@2FL4400P2D
KSl0302EKd00UW1109Qb@`2JM4D0VWDn09Ud?@2IM400V79109I`@`2EKT<0UFi509A]AP<0Ufi0:ooo
ool002[ooooo202<GcD808iQ=`80SV8e00H0Sf<f091T=`2?HcH0SV8e08eQ=02<H3<2091Q=`0608iQ
=`2>HcP0SF@h08]U>02<IST0RfHi202@ICX808mR>0P0TFDh0P2@ICX0102AIS/0TVLl099W?02AIS/2
091U>P<0TfPk0`2BIcX2095V>@T0TfHl0P2CISd00`2DIcd0U6Pk09EY>P0209EY>00409EZ=`2GJcX0
Uf/j09M[>P<0UVXi0P2EJCP01P2CIcX0U6Pk09AX>`2EJC`0UVXm09M[?P80V6`o00H0VVLh09QX>02I
JCT0V6Xi09IZ>@2FK3X209E]>P80V6dh00<0V6dj09Q/>`2HK3d00P2HK3l01P2HJd40V6dj09Q]>P2I
KS/0VVll09]`?@80W74n00@0WG8o09M[>P2GJcX0Uf/j0P2HK3/309U]?080Vf/k0P2LK3`309e]?@03
09i^?P2KKch0Vfln00H0Vfln0P2IKcd309Y`?P<0Vg4o00<0W74n09]`?@2JKc`00P2IKS/00`2JKc`0
Vg0m09aa?P0909]`?@<0VVll00@0Vg0m09eb?`2NLd00WgA10P2RLT430:5a@0<0X70o0P2PMCh0102P
MD00X7E20:1e@P2PM4<20:1dA@<0WW=00P2OM4430:1e@P80WgA10`2NLd000`2OM440X7E20:5f@`03
0:5f@`<0X7E20P2OM4490:1d@`D0XgQ50`2TNDH80:EeA0P0XgQ51@2RMTD00`2TN4L0YWY90:MkBP02
0:9g@P040:=h@`2TND@0Y7U40:EjA@80YW]600@0YW]80:EjA`2UNTL0YGY7102TNDH30:IkB0<0YGY7
0P2TNDH80:MlA`D0Z7m;00<0Ygi:0:ImB@2VODT0202TNdL00`2UNTL0Y7U60:9gA0030:5f@`80XWM4
00P0WW]309mj@`2NND80X7U20:1g@@2QMT40XgE10:9d@0<0Wg=20P2NLT4309ea@0<0W7900P2KLCl3
09Y`?P<0VFlm0P2HKS`309M]>`P0Tfhi00@0U6Tl09=X>`2CJ3/0TfPk0P2BIcX2095V>@80RVTd00<0
S6Pd08aW<`2>IS<00P2>I3800`2?Hc80SFLh08eW>00208aV=`@0RfDf00@0RV@e08MR=@26HC@0QF0c
0P24Gc801025H3<0QV4d08MR=@25H3H308IQ=`0<08EP=P23GS@0PUdc085L<P1oFS00P5/a089M<`23
GS@0Q5le08=N=022GC<0PE`b2021G2l207eG<0<0OUPa0`1oFC802@1kER`0OEP^07mJ<01mF2h0NUD[
07UD:P1jEB/0O5L]07aF<@0307]E<080NU@_0P1iDbh00`1dDB/0ME8/07IC;@0207IC;@0307EB;01c
D2X0LTlY0080M50^0P1cCbd3079>;003075=:`1bDBh0LU4^0080LE0]101`Cb`2075@;@03071?;01_
CR/0KTdZ0080KD`Y00<0K4/X06e<:@1^CBX00P1_CR/0101^CBX0K4/X06Y99P1YB2D406]::@80K4/Z
0P1]C2/206U89`80JTTX101[BRT306i::080KDTW0`1/B2H00`1XBRP0IdTW06I89P0206E79@0306I8
9P1WBBL0J4XX00P0JDPW00P0IDHW06I7:01WB2T0J4TZ06M8:@1VAbP0I4DV06=49@80I4HR0`1UAb<4
06I890P0JTTX201VB2H206U;:@80J4XX0`1WBBL00`1VB2H0ITXU06I:9@0606I:9@0306U8:@1XAbP0
IdHW0080ITDV00<0J4LX06Y9:P1[BR/00P1VB2H206M99`0406Q::01YBbT0JT`Z06Y<:PP0Id/V0`1X
C2L306U=:080JThY00@0JTdU06]>9P1[CRH0JdhV0P1/CbL206e@:0P0LTlY0P1eCBT00`1cCBP0LDhX
071>:00206i>9`0606a?9`1hDBX0N54Z07MA:P1eDRX0M5<Z0P1cDbX00`1aE2X0N5D]07QE;@0607QE
;@0307IE;01gERd0NEH^0080O5H_00H0Ne@]07aB;01kDB/0NUDX07]F:@1lEbX207eH:`0707aG:P1k
ERT0NUDX07YH:P1kFB/0OE/]07mM;`02081N<00307mM;`1nG2h0Peha00L0Peha0`24H30208EQ<@<0
QV8b0P28I3@208UU=@<0RVHf00<0RfLg08YU<@2:IC400`2;IS8208aW<`80SFPd00<0T6Hd095W=@2B
J3H00P2CJCL00`2BJ3H0TFLe091V=00209E/>0<0U6/g00<0UVdi09M^>P2HKc/0202FLC`209Q_>`03
09U`?02JLCd0Vg8n0080W7<o00@0WGA009]f@@2KMT40VgI10`2LMd8209eh@`0309ag@P2MN4<0WWU4
0080WgY500/0WWU409eh@`2LMd80X7]609mjA@2NND@0WGQ309iiA02ONTD0XGa70:9mB0080:F0C0<0
Z8=?0P2YQ5030:Z5D@030:V4D02ZQE40ZhIB0080[8MC00<0ZhIB0:Z5D@2YQ500202^QE430:j4DP80
[hEC0`2`QU@80:f7F0<0[HQD0`2^RED20:n:EPP0/hUG202_RUH20:f8E0040:j9E@2_RUH0[hYF0;2;
E`80/HaH202bSET90;6<F0P0/hiI00<0[HQD0:n:EP2`ReL00`2bSET20;2;E`P0/8]F0`2dReL20;F<
F0<0]XeI0`2cRUH20;B;E`<0]HaH0P2aS5L0102`ReH0[hYE0:j9E02^RE@20:f8D`80/HME00@0/XQF
0;>9E`2dRUP0]8YH0P2eReT01P2cSF00/heN0;:<G@2bS5/0/HaH0;6<E`80/8]D0`2aS5P30;2;E`80
[hYF202bR5H80;>:E0060:j5D@2_QU80[hIB0;27D`2aR5@0/XUE0P2cRUH40;27D@<0/HQB00<0/XUC
0:f8D`2]R5<01P2]R5<80:^6DPP0[8MB202^QE400`2/Pdd0[XE?0:n6D0020;27D@030:n6D02^QDl0
[8==00T0[8=?0P2/Qe820:^6D@<0ZXE@00<0ZHA?0:f4D02]Q500202]Q5030:b3C`<0Zh9>0`2^Q582
0:n5D`<0/8ID00H0/HME0;26E02`QU@0[hEC0:j4DP2]Pe420:b2D0<0[HA@1@2^QE420:f4D0<0[XEA
0`2_QU800`2ZQE40ZhIB0:b7D`020:f8E0060:b7D`2[QU80ZXEA0:b2D02]Pe40[XAB0P2_QE<00`2]
Pe40Zh5?0:Z0CP030:V4C`80ZXE@0`2[QU40102aQeD0/8ID0:j4DP2/PU020:^1C`80[89@202YQ4l0
0`2ZPDd0Zh9>0:b3C`020:f4D0040:b3C`2[PTh0ZX5=0:b3C`<0Zh9>0`2ZPDd20:V0C0070:Z1C@2[
PTh0[8=?0:b3C`2[PTh0ZX5=0:V0C0080:^2CPD0[8=?2`2]Q5090:b3C`030:j5D@2/Pdl0Zh9>0080
ZX5=00<0Zh9>0:b3C`2^QE400P2[PdP0102/Q4T0[HE:0:f5BP2/Q4T20:^3B0030:j5D@2/Pdl0Zh9>
0080ZX5=00H0Zh9>0:b3C`2^QE40Zh9>0:b3C`2^QE420:n6DP030:j5D@2/Pdl0Zh9>00P0[XEA0P2Z
PDd00`2[PTh0[8=?0:f4D0020:j5D@030:n6DP2/Pdl0[HA@0080[HA@0P2^QE420:n6DP040:j5D@2]
Q500[HA@0:f4D080[8=?0P2[PTh00`2ZPD/0Zh9<0:f4CP020:j5C`030:f4CP2[PT`0ZX5;00<0ZGm5
0P2ZP4H30:^1A`P0Zh9>00P0ZWi=0:UmC02YOD`0ZGe<0:YnC@2/P4l0[H5@0:j2DA00ZX5;0P2YP4`2
0:Z1C@80Zh9>0P2/Pdl80:^2CP80Zh9:00@0Zh9<0:^2CP2ZPDd0ZX1>0P2ZP5080:Z0CPT0Zh9>00/0
ZH1<0:Z1C@2[PTh0[8=?0:^2CP2ZPDd0Z7m;0:MnBP2[PTX0[8=;0:b3C@020:b3C`030:b2D02/PU80
[89B0080[89B00@0Zh5?0:Z1C@2YP4`0ZH1:0P2XOdL30:^2CP80ZX5=0`2YP4`80:^2CP80Yh9=0P2V
PD`30:F0B`090:AoBP2YOTT0ZGi90:UnB`2YOD`0Z7a=0:QlC`2WNdh0YgY@00P0ZX1>202YOdd@0:Z1
C@0@0:^2BP2ZPDT0ZH1:0:QoB`2WOTX0Yge;0:QnCP2YOdl0Z7m;0:V0C02ZPDd0Zh9>0:Z1C@2YP4`0
Ygi:0:ImB@80ZGm=00l0Z7i<0:MmB`2WOD/0Yge;0:QnC02YOdd0ZWmD0:UnD@2XOE00Yge=0:MmB`2X
Od/0ZH1:0:Z1B`2WOD/00`2XOT`20:UoC@80ZX1>0P2YP4P0102YP4X0ZH1<0:V0C02YOdd20:UoC`80
YWa<00@0YWa:0:ImB@2VODT0YWe70P2VODD90:ImB@0@09mjA@2QO4L0Xgi90:AoBP2UP4/0Y7m:0:=n
B@2RODP0YG];0:AjBP2TNTP0Y7]70:=jAP2SNT@0XgY20:9i@@<0YG]90P2VO4X30:MmB`80Ygi80P2V
ODL20:ElAP80Y7]5202SOTT20:MnAP040:MnB02WOTX0Ygi:0:MmB`80Yge=00<0YWI50:MgAP2XN4L0
0P2YNDP00`2XN4L0YgM60:IfA@080:=jAP<0XgQ30P2RMd830:5f@@030:5lB02PNdL0WWU500<0WGQ4
0P2NNDD00`2RN4H0XgU70:AjB0020:EkB@030:AjB02SNDL0XWQ60080Wga400H0WW]509eiA@2LN4H0
VgM709YfAP2JMDP809ec@@80VWE1102KMT8209Ye@@<0WG=10P2NM48309me@`<0VWE10P2KMT8309ag
@`<0WGA00P2LLcl309]b?PP0V7<n2@2HLcl02`2MLSd0Vg8l09]b?P2JLSl0Ug5009Ib@P2CLD40Tg53
09Qc?`2GLSh0UW4m0080UG0l00<0UW4m09Mb?P2HLcl00P2JKSd309]_?P<0W70o00<0VWE109Ud@02H
Lcl00P2GLSh02@2HLcl0VGA009Ye@@2NLdP0WW=609ebA@2MLd<0W79009]b?P0209Ya>`80UW130P2E
Kd80102GLD@0VG=609afB@2MMdX209Ud?@0309Ud?`2IM400VG=20080VG=400<0VG=609Ma@P2FL440
0P2EKd00302FL440Ug5209Qb@`2ILd@0VG@o09Ud@02HLcl0Ug5009I`@@2EKd80UFi309A]@P<0U6ho
:oooool002[ooooo202<GcD808iQ=`0308iR=@2?HcH0Sf<f0080Sf<f0`2>HSD2091Q=`0608iQ=`2>
HcP0SF@h08]U>02<IST0RfHi202>HcP8091S>@P0TFDh0`2AIS/2099W?0<0TFHk0P2DJC`00`2CJ3/0
TVLj095V>@02091U>00308mT=`2DIcd0U6Lm00T0U6Lm0`2EJC`309EY>P80Uf/j1P2FJST209EY?080
UVXm00D0Uf/n09Q/?`2HK3l0V6`o09]X>@0209UY>@0309QZ>@2FJST0UF/i0080UFdj0P2HKCP00`2H
KCX0V6`k09Q/?@0209Q/?`0709Q[@@2HK3/0VFdl09U]?02JKSd0Vfln09a`?`0209ea@080Uf/j0P2H
K3/209U]?080VVhm0`2KKC`309a^?@80WFln202KKch609Y`?P80Vg4o00@0Vg0m09Y_?02JKc`0VVll
0P2KL3d209aa?PP0VFhk102JKc`209]`?@0409aa?P2MLSl0XW910:9b@@<0XG500`2PL3l20:1e?P04
0:1e@02PMD80X7E20:1d@`80X7A50`2NLd0209md@@<0X7E20`2OM4400`2NLd00WgA109md@@020:1e
@P060:=hA@2RMd@0XWM40:5f@`2PMD80WgA10P2NLd090:1d@`80XWM4102SN4D20:AiAPP0YGE4202S
N4D20:5eA0060:9fA@2SMdH0Y7Q70:IjB@2WNdX0Z7a;0P2RMd@0102SN4D0Y7U60:AiAP2UNTL20:Ik
B080Yga900@0YW]80:EjA`2UNTL0Y7U60P2SN4D30:IkB0<0YGY70P2TNDH80:MlA`80Ygi:00H0Z7m;
0:V0C02XOd/0Ygi:0:ElB02TNdL80:=jAP030:=hA@2RMd@0XWM400<0XGI30P2RMd@01P2KN480W7M2
09ag@P2MMD40WWE109ic@080X7900`2MLd4209ab@0D0Vg4o0P2JL3h409U_?@<0V6hl0P2GKC/309I/
>PP0TVdi0`2BIcX2095V>@<0T6Dh0P29J3D01P2;IcD0RfDd08eU=02>I3@0SF<c08iR<`<0RfDf0`2:
I3D308US=0P0QF0c0`25H3H02@24GcD0Pehd089M<`21G380P5/a07iI;`1oFS00PE`b08=N=00208AO
=@0308=N=022GC<0OeX^00L0OeX^00H0NU@]07]E;P1kEBh0O5H_07eG<01nF34207mI<P80NEH/00<0
NUL]07UF;01hEB/00P1gE2X0101hEB/0N5D_07QE;`1hEBl207MD;P<0MU<]00P0M54[07EB;01fDbd0
MU<]07EB;01cD2X0LDhX071=9`80LU0]0P1aCb`4071>:`D0L4l/0`1_CR/2071?;080Kdh[00<0KTdZ
06e<:@1]C2T00`1]C2T206i=:P0406a;:01ZBBH0J4LT06I58P<0JTTX1@1[BRT406U89`@0JTTX00H0
KT/[06e::P1/BBT0JdPX06Y79`1YARH206Q59A00ITPV00<0I4DV06E69`1VAbP00P1WB2T00`1UARL0
Hd@U0693900606=58`<0I4HT201XAbH806A690<0J4XX0`1WBBL206I89PP0IDPV00<0ITLX06E69`1T
ABH00P1SA2D00`1TABH0ITLX06M8:@0206A6900406E79@1VB2H0IdTW06Q::080JD/Y201VBRD206E8
9P0406I99`1WBRP0IdXX06Q;:@80JD`Z0P1YBbD306Y<9P<0JddW201`CRP207E?:P06079?:@1aCbT0
KdlX06a?9`1[CRH0JThV0P1hDBX00`1gDBX0M54Y07=B:@02079B:@0306mB:01gE2`0Me@/00H0Me@/
00P0MUD/07MF;@1iERh0O5H_07]E;P1kE2d0Ne4[07Y@:P80NE@X101jEBT207UD:00607QF:01iEbT0
O5X/07iL;P1oGBl0P5h`0P1oGBl8081N<0<0Pel_0P24H30308EQ<@<0Qf<c0P28I3@308UU=@<0RF@`
0`2:IC4308]V<P<0SfDc0P2@IS@308mU<`<0TfXf0P2DJcL00`2EK3P0UVdi09M^>P0209E`>`@0UW4l
0P2GLSd209M^>P0409Q_>`2IL3`0VW4m09]b?P80W7<o102JMD0509]f@@0:09ag@P2MN4<0WgY509mj
A@2MN4<0W7M209]f@@2PNdH0WgY509iiA080WGQ300<0WgY50:5lA`2RODP00`2UP4`30:AoB`80Xgi:
0`2WPTh20:R3C`<0ZHA@00<0Z8=?0:Z5D@2[QU800P2/Qe<00`2[QU80ZXEA0:R3C`080:f4D080[H=A
0P2^Q5820:n5D`80/8ID202^R5L20:f8E0H0[XUE202bR5H80:n:EP80[HQD00@0[XUE0:n:EP2_RUH0
/8]G0P2aS5P0102dSe/0/hiJ0;>>FP2bSET20;6<F080/8]G2@2bSET80;:=F0030:j9E@2_RUH0/HaH
0080/XeI00<0/HaH0;2;E`2_RUH0202`ReH30;B;E`<0]HaH0P2fSET0202`Qe<0/HQD0;:9E@2cRUH0
]8]G0;F<F02fSET0]hiJ0`2aS5L00`2`ReH0[hYE0:n:E@020:j9E080/8ID00`0/HME0;>9E`2dRUP0
]H]I0;J<FP2gSE/0/heP0;>=GP2bS5d0/XaK0;6<F02aS5L20;2;E0<0/HaH0`2`ReL20:n:EPP0/XQF
202cRUH20:n6DP80/8MC00@0/HQD0;:9E@2bRED0/XUE0P2]Q4h0102^QDl0[hI@0;27D@2`Qe420;68
DPP0[HQC202ZQE480:b7DPP0[XEA00<0[8=?0:j5D@2_QU800P2`Qe<00`2_QU80[XEA0:b3C`090:f4
D0<0[8MB0P2[QU430:Z5D0X0[HA@0`2/Pdl30:^2CP@0[XAB102_QE<20;26E080[hEC00@0[XAB0:f3
D@2]Pe40[H=A0P2]Q5040:j5D@80[hIB0P2]Q5030:j5D@<0[hIB0`2[QU820:b7D`<0ZhIB00<0[89@
0:f3D@2^Q5800P2_QE<00`2]Pe40Zh5?0:Z0CP030:V4C`80ZXE@0`2[QU40102`Qe<0[hIB0:f4D02/
Pdl20:^2CP030:b3C`2]Q500ZHA?00L0ZHA?00<0Zh9>0:b3C`2/Pdl0102/Pdl50:^2CPH0ZX5=102[
PTh:0:Z1C@80Zh9>102/PdlC0:f4D0030:j5D@2/Pdl0Zh9>0080ZX5=00H0Zh9>0:b3C`2^QE40ZH18
0:^2BP2]Q4`20:n6CP060:f4C02[PTX0ZH180:j5D@2/Pdl0Zh9>0P2ZPDd01P2[PTh0[8=?0:j5D@2[
PTh0[8=?0:j5D@80[hIB00<0[XEA0:b3C`2[PTh0202_QU820:^2CP80[8=?00@0[HA@0:j5D@2^QE40
[XEA0P2/Pdl30:f4D0D0[XEA0`2]Q5040:b3C`070:f4D02^QE40[hIB0:n6DP2^QE40[HA@0:b3C`02
0:b1BP@0Zh190P2ZOdP80:^2CP80Z7e:00H0ZGi;0:YoC02[P4d0[H9?0:j3D02_Q54@0:Z1B`80ZH1<
0P2ZPDd20:^2CPX0[8=?00P0[HA<0:b3B`2/Pdd0Zh9>0:Z1C@2YOdd0ZGm?0:QnCPP0ZX1>2`2[PTh3
0:b3C`030:Z1C@2XOd/0YWe90080[HA<00@0[8==0:b3C`2/Pdl0Zh5?102[PE40102ZP4h0ZX5=0:V0
C02YP4X20:QoA`80Zh9>0P2ZPDd20:V0C080Z7m;202[PTh30:R0C0<0Ygm;0P2VOTX20:UnA`040:Un
B@2YOT/0ZGe<0:UmCP80Z7a?202[PDl20:^2CP80ZX5=00@0ZH1<0:QoB`2XOd/0Ygi:202ZPD/80:Z1
C@80ZX5900@0ZH1:0:V0C02XOd/0ZGm=0P2YOdl00`2VODT0Ygi:0:QoB`020:V0C0030:QoB`2VODT0
YGa80080ZGm=0P2XOT`30:MmB`090:QnC02YOU<0Z7e@0:QmD02XOTh0Z7i<0:QoB`2XOdT0ZH1:00<0
Z7m;0P2YP4`30:Z1C@80ZH1800@0ZH1:0:V0C02YP4`0ZGm=0P2YOdl20:MmC@040:MmB`2WOTX0Ygi:
0:MnB080Ygi62@2WOTX0202ONTD0XGa70:=nB@2TOdX0YH1;0:AoBP2SOTT0XWe80P2TNTX0102TNTP0
Y7]70:AkA`2TNdD20:Ak@`@0YWa:102WOD/20:MnBP80YWe90P2UO4P20:AkA`<0Y7m:102SOTT0102R
ODP0Ygi60:MnAP2WOTP20:MnBP040:MmB`2WODd0Yge=0:MiA`<0Z7Y80P2WNDL20:IhAPP0YGa80P2T
ND@20:=h@`80XWM20P2QMT420:1kA`0309mjAP2NNDD0WWU500<0WWU500<0Y7Y80:EkB@2UNdT0102U
NdT02@2TNTP0X7]40:1kA02ONTD0WWU509egAP2LMTL0VgE609]eB00809ec@@80W7M300H0WGQ409ii
A@2MN4@0W7M309]f@P2JMD4309ec@@80WWA20`2OMD<309Ye@080VgI10`2LMd8209ed@0<0W7<o0`2K
LSh809Qc?`T0V7<n00P0WW<n09ed?P2MM400Vg=009Uc@P2GLd<0UG=309EcA@80VGA0102HLcl209Ud
@080VFlm0`2JL3h309]a?`80VGA0102HLcl209Ud@00609ebA`2MLTD0WG9509ab@P2KLCl0Vg8n0P2J
LC/209Ma@P80UW1100@0Ug5209UcA02KMDH0WGM80P2IM3d00`2IM3l0VGA009Uc@P0209UcA00509Uc
AP2GLD80Ug5209Ma@P2FL4400P2GLD8209Qb@`80V79100@0Ug5009Ma@P2FL440UFm00P2EKd8309A`
@2_ooooo000Zooooo`P0S5le202=H3H308mS=P0308iR=@2?HcH0Sf<f0080T6@g0P2@HCL01P2>HCL0
SV<h08eT>02;ICP0S6Hi08]V>@P0SV<h202@HcT8095U>0<0TVLl0P2AIS/3099W?00609AY?02CJ3/0
TfPk099W>P2AIST0T6Dh0P2?I3L909AW?@80UVXk00@0UFTj09EY?02EJC`0UFTl0P2EJ3h609IZ>@80
Uf/j0`2FJSd409M[?P0709Q/?`2LJCX0VVXj09UY>@2HJST0UVXi09E[>@0209A/>@80V6dh00<0V6dj
09Q/>`2HK3d00P2HK3l01P2HJd40V6`m09Q/?@2IKCh0VVho09]_@080W71100@0WG5209Q/>`2HK3/0
V6`k0P2IKC`309Y^?@80VFdl0`2JKSd309]_?PP0W70o0P2KLCl609Y`?P0309U^>`2JKc`0Vg0m0080
W74n0`2MLSl909U^>`80VVll1@2KL3d20:9b@@<0XG500`2PL3l20:1e?P040:1e@02PMD80X7E20:1d
@`80X7A50`2NLd0209md@@<0X7E20`2OM4400`2PMD80WgA109md@@0209ic@0060:=hA@2RMd@0XWM4
0:5f@`2PMD80WgA10P2NLd090:5eA080XGI30P2RMd@20:=hA@80Y7U6202UMD@80:=hA@060:1d@`2Q
MD@0XWI50:AhA`2UNDP0YWY90P2WNdX20:9gA0040:=hA@2TNDH0Y7U60:EjA`80YW]800D0Z7e:0:Ml
B@2WO4T0YW]80:EjA`020:AiAP040:=hA@2VNdP0YW]80:IkB0<0YGY70P2TNDH80:IkAP030:ElB02W
OTX0Z7m;0080ZH1<00<0Ygi:0:ElB02SNTH0202SNTH00`2PMD80XGI30:5f@`030:9gA080XGI300H0
VWM109]f@@2JMD00W7A009ac?`2MLSl209ma?`<0Vg=00P2JLSl309Ua?P@0VFlm0P2HKS`509M]>`80
UV`j0`2EJcT8091Z>@80TFHi0P2@ICP308mT=`0908iS=P28ISH0R6Hf08YV=P2;ICH0S6<e08eR=@2<
HC@0SF4d0080RV@e0`29Hc@408QR<`80Q5lb1025H3<208AO<P80Q5le00<0Pehd089M<`21G3800`20
Fc40101mF2h0OUT_085L<P22GC<208=N=080PUdc201nFBl207UC;00307YD;@1kEBh0O5H_0080OEL`
00<0OUPa07QG;P1gERd0101fEB`0101eE2/0M5<Z07ID;P1fE2h207EC;@<0M58/00<0Le4[07AA:`1e
DR`00P1fDbd0101eDR`0Le0Z075>:01_C2H2071?;0<0Kdh[1@1^CBX706m>:`@0KTdZ0`1]C2T0201/
BbP0KD`Y06e<:@1]C2T0K4/X06U89@1WAR<0ID@Q1P1ZBBP606U89`@0J4LV0P1/BbX01P1ZBBP0JDPW
06Q79P1VAB@0ID@S06A38P80IDLU101VB2H206E79@P0I4LU00<0Hd@U06A59P1UARL00P1VAbP00`1T
ABH0HT<T06528`0206=58`L0HT@R201WARD806=58`80J4XX0`1WBBL306I89PP0IDLU00<0IDPX06A7
9`1SARH00P1QA2@00`1RABD0HdHV06A79`0206=58`0406A6901UAbD0IDLU06I89P80IdTW201VBRD2
06=6900406A79@1UB2H0IDPV06I99`80IdXX0`1XBRH306U;9`80JT`X201]CBH207IC;@0607AB;01b
DR/0Ke8Z06iB:P1]DBT0Je8Y0P1hDBX00`1fD2T0M54Y079A:002071@9`0306iA9`1fDb/0MU<[00H0
MU<[00<0ME@[07IE;01hEBd00P1kEBh00`1kE2d0Ne4[07Y@:P0207UD:P@0N5<Y0P1iE2X0101gEBL0
N5HX07]I:`1mFbd207mM;`80OU`^201mGBh3089N;P80Pel_0`24H3001025HC40QV8b08IR<P26HS82
08MS<`80R6@d1028Hbl308UT<080RVDa0`2>I38208eS<@<0SV@b00@0T6Lc095X=02BJCD0TfXf0P2E
K3P209I]>@80Tfhi0P2DKcX209E`>`80UW4l0P2FKCT0102GKSX0V6lk09U`?02JLCd209]b?PP0VG@o
00<0VWE009]f@@2MN4<00P2NND@02`2MN4<0VgI109Ye@02ONTD0WWU409eh@`2LMd80WGQ309iiA02P
NdH0XWe800<0Y7m;0`2SOTX20:9mB@<0YX5=0P2WPTh40:R3C`070:V4D02ZQE40[8MC0:b7D`2ZQE40
ZHA@0:R3C`080:f4D0<0[H=A0P2^Q5830:n5D`h0[XUE0P2]R5@80;:8EPP0[hYF0P2]R5@0102^RED0
[hYF0:n:EP2`ReL20;6<F0060;B?F`2cSUX0/hiJ0;:=F@2aS5P0/8]G0P2_RUH90;:=F@P0[XUD00<0
[hYF0;2;E`2aS5P00P2bSET00`2aS5P0[hYF0:j9E@080;6<E`80/hYF0`2dReL30;F<F0090:n6DP2`
Qe<0/HQD0;:9E@2dReL0]HaH0;J=F@2gSUX0/XeH00@0/HaG0`2`ReH20;26E00<0;67E@2cREL0]8YH
0;F;F@2fS5X0]heK0;>=H02cSEh0/XaM0;:<F`2aS5P0/HaG0P2`Re@30;6<F0<0/8]G0P2_RUH80;:8
EPP0/hYF0`2`Qe<40;68E0070;:9E@2/Pdd0[HA>0:f4CP2^QDl0[hI@0;27D@020;68DPP0[HQC202[
QU880:f8D`P0[hIB00<0[8=?0:j5D@2_QU800P2`Qe<00`2_QU80[XEA0:b3C`090:f4D080[HQC0P2/
Qe820:^6D@80ZXE@2P2]Q5030:b3C`<0Zh9>202^Q5830:n5D`@0[XAB00<0[H=A0:f4D02]Q5000P2^
QE420:n6DP80/8MC0P2]Q5030:j5D@<0[hIB00<0[8MC0:^6DP2[QU80102[QU80102/Qe<0[89@0:f3
D@2^Q5820:n5D`030:f3D@2[PDl0ZX1>00<0ZHA?0P2ZQE030:^6D@030;27D`2^QE40[HA@0080Zh9>
00<0[8=?0:f4D02^QE40202YQ4l30:b3C`80Zh9>0`2/Pdl40:Z1C@H0Zh9>102ZPDd20:^2CPX0ZX5=
0P2[PTh20:b3Ca<0[HA@00<0[XEA0:b3C`2[PTh00P2ZPDd01P2[PTh0[8=?0:j5D@2YP4X0Zh9<0:f4
CP80[hI@00H0[HA>0:^2C02YP4X0[XEA0:b3C`2[PTh20:Z1C@060:^2CP2/Pdl0[XEA0:^2CP2/Pdl0
[XEA0P2_QU800`2^QE40[8=?0:^2CP080:n6DP030:b3C`2]Q500[HA@0080[HA@0`2^QE430:b3C`<0
[HA@1@2^QE430:f4D0<0[8=?00L0[HA@0:n6DP2`Qe<0/8MC0:n6DP2]Q500[8=?00<0[H9=0P2/PD`3
0:^0B`P0Zh9>00H0Z7e:0:UnB`2ZOd`0[85>0:f2C`2^Pe020:n4DA00Zh9<0P2YP4`20:Z1C@80Zh9>
2P2/Pdl0202]Q4`0[8=;0:b3C@2[PTh0ZX5=0:UoC@2YOdl0Z7i>202[PDl90:Z1C@080:^2CP2/Pdl0
[HA@0:f4D02/Pdl0ZX5=0:QoB`2WOTX20:f4C0040:b3C@2/Pdl0[8=?0:^1C`80Zh5A0P2ZP500102Y
Odd0ZH1<0:V0C02YP4X20:QoA`<0ZX5=0P2YP4`30:QoB`P0Zh9>0P2YP4`30:QoB`<0Ygi:0P2YOdD0
102YOTL0ZGi90:UnB`2YOD`20:YnC`P0Zh5?00H0[8=?0:^2CP2[PTh0ZX5=0:V0C02XOd/20:MnBPP0
ZH18202[PTh20:V0B0090:V0BP2ZPDd0ZX5=0:Z0CP2ZP500ZGm?0:ElB02VODT0Z7m;0080ZH1<00<0
Z7m;0:MnBP2VODT0102YOdd01@2XOT`0Yge;0:IlBP2VO4X0YgaA0080Z7e@00D0Z7i>0:QnC02XOd/0
Z7m90:MnB0020:QoB`80ZH1<0P2ZPDd20:^2CP80ZH1800@0ZH1:0:V0C02YP4`0ZGm=0P2YOdl20:Mm
C@040:MmB`2WOTX0Ygi:0:MnB080Ygi62@2WOTX0202ONTD0XGa70:=nB@2TOdX0YH1;0:AoBP2SOTT0
XWe80P2TNTX0102TNTP0Y7]70:ElB02UO4H20:ElA0P0Yge;0P2WOTX20:ImB@80YGa80P2TNdL30:Ao
BP030:=nB@2RODP0XWe80080XGa70P2WOTH0102WOTP0Ygi:0:MnBP2WOD/20:MmC@030:QmBP2WO4T0
YW]80080YGY70`2TNDH80:ElB0<0Y7U40P2SN4<30:9g@P@0X7]700@0WgY609iiA@2NNDD0WGQ40`2U
NdT20:AjB0<0YG]90P2RNd@01P2QNDD0X7Q509mgAP2NMDL0WGA609edB0P0WG=100P0WGQ409iiA@2O
NTH0X7]709mjAP2MN4@0VgI209Ud@0<0WG=10P2NM48309me@`<0VWE00P2KMT4309ag@P<0W7<o0`2K
LSh209Ya?@P0Ug502@2IM3l0202NLch0WG@n09ed@02LM440VG=209QdA02ELd<0UG=50P2IM40409Ye
@@80VGA00P2HL3d309Ua?P<0VW8o0P2HLcl409Ud@080V7<o00X0W75609aaA02LLD@0Vg5109]a?`2K
LSh0Vg8l09Ya>`2ILd80V7910`2GLD000`2ILd80VgE409egAP0209Ud?@0309Ud?`2IM400VG=20080
VG=400<0VG=609Ma@P2HLT<00`2HLT<309Ma@P0309MaA02FL4<0UW110080UW110`2EKch309Ea@B_o
oooo000Zooooo`P0S5le202=H3H00`2@I3L0Sf<f08iR=@0208iR=@03091T=`2AICP0TVHi0080T64g
00H0SV4g08iS>02=I3P0RfDh08aV>@2;IST8091U>PP0TF@j202AICP209=X?@04099W?02AIS/0TFHk
099W?080TfPm0P2BIcX3095V>@<0T6Dh2@2DIcd01P2GK3T0Uf/j09IZ>@2FJS/0UFTl09EX?P80UFPo
0P2EJCP309IZ>@<0Uf/j202FJSd01P2LJCX0VVXj09YZ>P2HJST0UVXi09E[>@80Tf/h0P2HKCP00`2H
KCX0V6`k09Q/?@0209Q/?`0709Q[@@2FJSd0Uf/n09M[?P2HK3l0VFe009Y^@@0209]_@P80V6`k0P2I
KC`309Y^?@0309]_?P2HKS`0VFlm0080VFlm0P2JL3h209]a?`P0W70o0`2KLCl309Y`?P80VFlm00@0
V6dj09U^>`2KL3d0WG8o0P2NLd0209eb?`P0Vg0m00<0VVll09]`?@2LLCh00P2MLSl00`2LLCh0Vg0m
09]`?@020:9b@@<0XG500`2PL3l20:1e?P040:1e@02PMD80X7E20:1d@`80X7A50`2NLd0209md@@<0
X7E20P2OM4430:1e@P0309md@@2NLd00WG8o00<0XGI30`2PMD8209md@@T0XGE40P2PMD80102QMT<0
XWM40:=hA@2SN4D20:AiAPP0YGE4202RMd@00`2QMD@0XWI50:AhA`050:IjB@80XWI500@0XgM60:Ah
A`2TN4L0YGU80P2VNTT20:MlB@<0YW]80`2UNTL30:IkB0<0YGY70P2TNDH80:IkAP030:AkA`2VODT0
Z7m;0080ZH1<00<0Ygi:0:AkA`2RNDD0202RNDD00`2NLd00WgA10:5f@`030:9gA080XGI300H0VWI2
09Ye@@2JMD40W7A109ab@02MLD0209i`?`<0V7<o0P2GLSh309Ia?@<0V6hl0P2GKC/609I/>P80UF/i
0`2DJSP808mY>P<0Sf@g0P2>HcH308eR=@0908QV>027ICL0RF@g08YT=`2;HSH0S64f08]P=@2<GcD0
RF<d00<0R68c0P27HC8308IP<@0308=N<@24Gc80QF0c00<0QF0c00H0Q5lb08=N<@24GcD0Pehd085L
<P1oFS0207iI;`80OeX`00<0O5L]07iI;`1oFS000P21G3800`20Fc40OeX`07iI;`0807aF;`<0NE</
0`1jE2d207]E;P0807MG<01dE2d0LU8[079B:`1dE2d0MED^07=C;01`D2T307=C;080LU8[0`1aDBX0
0`1bCbT0Le0Z07AA:`0207EB;00307=@:P1bCbT0L4dW00<0KDl[0P1/CRX306]=:@<0KD`Y0`1^CBX2
06m>:`P0KD`Y0P1/BbP01P1]C2T0KTdZ06e<:@1[BRL0JDPU06M68`80JTTX0`1YB2L306Q79P80JDPW
0P1XAbH406M69@80J4TZ00@0IdPY06I7:01TABH0Hd@U0P1R@b@00`1TAR@0IDLU06I89P0306I89P03
06E79@1TAR@0HdHT00L0HdHT0P1SA2D306E69`0306=49@1Q@R<0H44R00@0Hd@U0P1R@b@306528`P0
ITDT201TAR@0101XBRP0IdTW06M99`1WBBL206I89P80IDLU201VABH0201UB2P0I4LW06959@1QA2@0
H4<S0654901RABD0HdHV201TAR@806E99080HTDU0`1SARH306A79`80ITPV0P1WBBL306Q::00306U;
:@1ZCBD0JTdU00H0JTdU0P1dDR`03P1cDb`0L5<[06mC:`1]E2/0K5<Z06]D:P1hDBX0Me0Y07I@:@1c
D2P0LE0W06m?9P1^CRD0K4lU201eDRX02`1cDRT0M5<Z07MD;01jE2d0NeD^07]D;@1lDR`0Ne4[07YD
;@1iDb`0N58[0080Me4Z00L0N58[07UC;01jE2d0MeDW07UG:@1kFB/0O5X/0080OE/]00<0O5X/07]I
:`1kG2d01`1kG2d3085M;@80PUh^0`23Gbl308AP<080QF4a0`26HS8308IQ;@80Qf8^0`28Hbl01029
I300SfDc08iT<P2=Hc4208aR<00708eS<@2>I380SfDc08iU<@2?IS80TFPd09=Z=P0409E/>080T6/f
00@0TF`g099]>02CKST0Tfhi0P2DKcX01P2EK3P0UVdi09I]>@2GKSX0V6lk09U`?080VW4m0P2IM3l2
09Qc?P@0Ug8m00<0VG@o09Ye@02LMd800P2MN4<02`2LMd80VWE009Ud?`2ONTD0WWU409eh@`2LMd80
WGQ309iiA02PNdH0XGa700D0XWe90`2SOTX30:F0C080YX5=0`2WPTh00`2XPdl0ZHA@0:Z5D@020:^6
DP030:Z5D@2YQ500Z8=?00P0[8=?00@0[89@0:f3D@2]Pe40[H=A0P2^Q5820:n5D`P0[HQC0P2_RUH3
0:j9E@<0[HQD202aQeD80:n:EP80[HQD00@0[XUE0:n:EP2_RUH0/8]G0P2aS5P20;>>FP040;:=F@2a
S5P0/8]G0;2;E`80[hYF2@2aS5P80:f8D`80/8]G0`2bSET00`2`ReL0[hYF0:f8E0080;6<E`<0/hYF
0P2dReL30;F<F0080:n6DP2`Qe<0/HQD0;:9E@2cRUH0]8]G0;F<F02fSET70;:=F0050;6<E`2aQeD0
/HME0;:8EP2cREL00P2dRUP20;F;F@060;>=H02cSEh0/XaM0;:<F`2aS5P0/HaG0P2`Re@30;6<F0<0
/8]G0P2_RUH80;:8EPP0/hUG202aR5@0102^QDl0[hI@0:n6D02_QU040;27D@P0[HQC202/Qe<80:f8
D`P0[hIB00<0[89@0:j4DP2_QE<00P2`QU@00`2_QE<0[XAB0:b2D0090:j5D@<0[HQC0P2/Qe830:^6
D@X0[HA@0`2/Pdl30:^2CP040:n5D`2^Q580[XAB0:j4DP<0[H=A00<0[89@0:j4DP2^Q5801P2^Q582
0:f4D080[XEA00@0[hIB0;27D`2aR5@0/HQD0P2]Q5030:j5D@<0[hIB00<0[HQD0:b7D`2[QU800P2Z
QE401P2[QU80[8MC0:f8E02/PU00[H=A0:j4DP80[hEC00<0[H=A0:^1C`2ZP4h00`2YQ4l20:Z5D0<0
ZhIA00<0[hI@0:j5C`2/Pdd00P2[PT`00`2/Pdd0[XE?0:n6D0080:V4C`030:f4D02/Pdl0Zh9>0080
ZX5=00@0Zh9>0:b3C`2]Q500ZH1<0`2ZPDd30:^2CP80[8=?00L0Zh9>0:Z1C@2YP4`0ZH1<0:Z1C@2[
PTh0[8=?00P0Zh9>0P2YP4`0102ZPDd0Zh9>0:b3C`2/Pdl:0:f4D0X0[XEA00L0[8=?0:^2CP2ZPDd0
ZX5=0:^2CP2/Pdl0[XEA0080Zh9>00@0[8=?0:f4D02]Q500[8=?0P2[PTh00`2^QE40[8=?0:^2CP02
0:Z1C@060:^2CP2/Pdl0[XEA0:^2CP2/Pdl0[XEA0P2_QU800`2^QE40[8=?0:^2CP0@0:j5D@80Zh9>
0P2/Pdl30:f4D0030:j5D@2_QU80[hIB0080[XEA0`2]Q500102/Pdl0Zh5?0:b2D02^Q5820:n5D`03
0:j4DP2/PU00Zh5?0080[X=@0`2]PTl30:b1CPP0Zh9>00@0ZGi90:YoBP2[P4/0[H9=0`2^Pdh00`2]
PTd0Zh9<0:^2C00>0:^2C080ZH1<0P2ZPDd20:^2CP80[8=?202[PTh20:^2BP040:^2C02[PTh0ZX5=
0:Z0CP80ZX1@202[PDl:0:Z1C@0:0:^2CP2/Pdl0[HA@0:f4D02[PTh0ZX5=0:QoB`2[PTX0[8=;0:b3
C@80[8=?00<0[89@0:b2DP2/PU800P2YOdl0102YOdd0ZH1<0:V0C02XOdT20:QoA`80ZX5=0P2YP4`3
0:QoB`030:MnBP2[PTh0Zh9>00H0Zh9>00@0ZWm<0:UnB`2YOT/0ZGi;0P2XODX20:MlB@060:Uo@`2Y
OdD0ZGm50:UnA`2ZOdX0ZWm<0P2[Odh80:Z0CP80Zh9<0P2ZPD/0102YP4X0Z7m90:QoB@2WOTP80:V1
APP0Zh9>0P2XOdL0102ZPD/0Zh9>0:^2CP2[PDl20:Z0D0080:ImB@2WOTX0ZH1<0:Z1C@2[PTh0ZX5=
0:V0C02XOd/20:UoC@80ZX1>00`0ZGm=0:MmB`2VO4X0Y7Y80:IkD02WO4l0Z7e@0:UoC`2YOdd0Z7m;
0:MnB02VODL30:V0BP80ZX5;0`2[PT`20:V0B0040:V0BP2YP4`0ZH1<0:UoC@80ZGm?0P2WODd0102W
OD/0Ygi:0:MnBP2WOTP20:MnAPT0Ygi:00P0WgY50:5lA`2SOTT0Y7m:0:F0B`2TOdX0Xgi90:9mB080
Y7Y:00@0Y7Y80:ElB02UO4P0YWe70P2VODD0102YOdd0Z7i<0:QnC02XOT`30:MmB`030:IlBP2WOD/0
Yge;0080YWa:0P2UNdT20:AjB0060:AoBP2SOTT0Xgi90:9mB02QO4L0X7]60P2ONTD20:MnAP040:Mn
B02WOTX0Ygi:0:MmB`80Yge=00@0ZH1<0:MnBP2VODT0Y7]70P2SNTH:0:AkA`040:EjA@2TND@0Y7U4
0:AiA080XgQ30P2RMd802`2ONTH0X7]70:5lB02QO4P0X7]709mjAP2NNDD0WGQ40:EkB@2TNTP0XgU7
0080XWQ600<0XgU70:AjB02UNdT00P2SNT@01P2RNDD0XGM50:1fAP2OM4L0WW=609icB0P0WG=100P0
W7M309iiA@2PNdL0XGa80:1kA`2MN4@0VWE109Qc?`<0WG=10P2NM48309me@`<0VWDn0P2KMSl309ag
@0<0W7<o0P2KLSh309Ya?@P0Ug522@2IM3d02`2NLch0WG@n09ac?`2KLd00V79109Mc@`2ELd<0U794
09Qc?`2IM400VWE10080VgI200<0VWE109Ud@02HLcl00P2FLCd309Mb?P<0V7<o00<0Ug8n09Qc?`2I
M4000P2JMD40102IM400V7<o09Mb?P2KL4D209]`@`0309]a@@2KLCl0Vg8n0080Vg8l00P0VWE109Ud
@02HLcl0Ug8n09Qc?`2IM400VgI209ag@`80VG@m00<0VG@o09Ud@02ILd800P2ILd@00`2ILdH0V793
09Qb@`0309UcA00309Qb@`2FL440UW110080UFi300<0UFm209E_@02EKch00P2EL3`0102EL3/0UWA4
09IdA02FM4@[ooooo`00:_ooool@08aO=@03091T=`2?HcH0SV8e0080SV8e00<0T6@g099V>@2CIcX0
0P2@HCL01P2>HCL0SV<h08eT>02;ICP0S6Hi08]V>@P0TFHk202AI3X8095U>00309AY?P2CJ3d0TVLl
0080TFHk00<0TVLl09=X?@2DJCh0102@ICP4095V>@T0UFPn00P0V6dh09M/=`2GJcX0UVXk09IY?`2E
J3l0UFQ109AV@P<0UFTh00<0UVXi09M[>P2GJcX00P2HK3/209EY?0H0U6Pk00H0WFXk09][>`2JJSX0
VF/j09IZ>@2DJSP209=[>080V6dh00<0V6dj09Q/>`2HK3d00P2HK3l00`2HJd40UFTl09EY?00209IZ
?@0409M[?P2HK3l0VFe009U]@0<0VFdl0`2JKSd209]_?P<0V70m0P2ILCh309Yb?`P0W70o0P2LLT02
09]a?`0809Y`?P2IKcd0VFlm09U_?@2HKCX0VFhk09]`?@2NLd0209md@@0309ic@02MLSl0W74n00P0
W74n00L0WG8o09ic@02OM440WgA109ic@02LLCh0Vg0m0080XW910`2QLD030:1`?`80X7Dn00@0X7E0
0:1e@P2PMD80X7A30P2PM4D309ic@080WgA10`2PMD800`2OM440X7E20:5f@`020:5f@`0309md@@2M
LSl0Vg0m0080WgA10`2PMD830:5f@`T0XGE40P2OM4401P2PMD80XGI30:9gA02SN4D0Y7U60:EjA`P0
YGE4202RMd@00`2SMdH0Y7Q70:IjB@020:MkBP030:IjB@2TN4L0XgM60080XWI700@0XgM80:AhB@2T
N4T0YGU:0P2VNT/20:EjA`<0YW]80`2WO4T30:IkB0<0YGY70P2TNDH80:EjA@080:=jAP2UO4P0Z7m;
0:Z1C@2YP4`0Ygi:0:=jAP2QN4@80:9iA@0909eb?`2NLd00X7E20:9gA02SN4D0XWM40:5f@`2PMD80
VWI40080VgE400<0W7A309ec@`2MLD800P2OL480102HLcl0Ug8n09Mb?P2GLSh209Ia?@80UG0l0`2G
KC/209I/>P<0UF/i00@0UV`j09E[>@2EJcT0UF/i0P2DJSP209=Y=`P0SVPi0`2>HcH208eR=@<0S64d
0P27ICP00`28HcL0RF8g08YP=P0208]P=P0308]N=@28HS<0Qf4b0080Qf4b0P26H34308EO<003089M
<023GS40QF0c0080QV4d00L0QF0c08=N<@22GC00Q5le089M<`20Fc40OUT_0080OEP^00D0OUT_07mJ
<01lEbd0OEP^07iI;`0207mJ<00307eH;P1kER`0NUD[00P0NeD`0P1jE2d307UC;0<0N58[00P0MeLa
07=C;@1`D2X0LE4[07AD;P1eEBl0LU8/06i>:0<0LU8[0P1aDBX3071@:@08071=9`1aCRP0Le0Z07AA
:`1eDR`0M54[07=@:P1bCbT306]?:P80JThY0`1YCBP306a;:00306e<:@1^CBX0KTdZ0080Kdh[201]
C2T00`1[BRL0K4/X06e<:@0206i=:P0306e<:@1/BbP0JTTV0080JTTX0P1YB2L01@1XAbH0IdHU06M6
9@1WARD0JDPW0080J4LV0P1WARD206I5900406E48`1UB2X0IDPZ06A7:@80HdHX00H0HTDW06549P1Q
A2H0HdDS06A6901VB2H206M99`0306I89P1TAR@0HdDS00P0HDLT00<0HT<T06=49@1TABH00P1TABH0
0`1R@b@0HD8S05m08@0206E6:@80I4DX00<0Hd@W06939P1R@bH00P1R@bH806E48`P0I4HT0`1WBBL2
06I89P<0IDLU201WA2P0201SBBP0HTPW06169@1NA2<0GD<R05i48`1OAB@0H4HU0P1UAbD0101TAR@0
HdDS06948P1Q@b42061280P0I4PS0P1SARP306959`<0HD@V0P1UARL206I7:0<0IdPY00<0J4TZ06Q<
901XC2@01P1XC2@01P1_CBL0KThW06m?:01]D2P0K50X06]B:@80JU<Y00P0N54Z07M@:@1eCbP0LTlW
071?9P1^CRD0KDdT06]>90P0M54Y00/0L4lV079A:01eDRX0NU@]07]E;P1lEBh0OU@^07eC;@1kEC00
NU@_07UC;P0207QB;@0607UC;P1jE2l0NeD`07QF:01iEbT0NeT[0P1lFR`00`1kFB/0NUPZ07UG:@08
07YK;080P5`/0P21GBd3089N;P@0Pel_0P24H30308EQ<@<0QF0/0P26HBd308MR;P0408QS;`2@IS@0
SfDc08eS<@80S68`00L0SF<a08mU<`2@IS@0S6<_08iU<@2@Ic<0TfXf00<0UF`h00T0U6/g08eX<`2=
J3<0SVTd08mZ=@2@JcH0TF`g099]>02CKST00P2EK3P209I]>@0409M^>P2HKc/0VG0l09U`?0<0V7<n
00<0Ug8m09Ia?02FLC`00P2EL3/00`2HLch0VG@o09]f@@0209ag@P0509]f@@2IM3l0V7<n09iiA02M
N4<00`2LMd800`2NND@0WgY50:5lA`030:1kA`030:5lB02RODT0Xgi:00@0Y7m;0P2UP4`30:J1C@80
Yh9>00L0Z8=?0:Z5D@2[QU80ZhIB0:Z5D@2XPdl0Yh9>00P0[8=?0P2/PU030:f3D@<0[XAB202/Qe03
0:n:EP030:j9E@2]R5@0[HQD0080[8MC202aQeD80:n:EP80[HQD00@0[XUE0:n:EP2_RUH0/8]G1P2a
S5P=0;2;E`P0/8]F00<0/8]G0;6<F02bSET00P2bSET00`2`ReL0[XUE0:f8E0080;6<E`80/XUE0P2c
RUH30;B;E`050;F<F02`Qe<0/HQD0;68E02bRED00P2cRUH20;B;E`D0/XeH0`2cSUT70;>9E`070;B:
F02cSF00/heN0;:<G@2bS5/0/HaH0;6<E`020;2;E0<0/HaH0`2`ReL20:n:EPP0/XQF202cRET60;68
E080/8MC102aR5840;27D@P0[HQC202^RED80:j9E0P0[hIB00<0[89B0:j4E02_QED00P2`QUH00`2_
QED0[XAD0:b2DP090:j5D@@0[HQC0P2/Qe820:^6D@X0[HA@0`2/Pdl30:^2CP80[hEC0P2^Q580102]
Pe40[89@0:b2D02/PU060:j4DP80[hEC00H0[8=?0:f4D02^QE40[hIB0;27D`2aR5@20;:9E@80[HA@
0`2^QE430:n6DP030:f8E02/Qe<0ZXEA0080ZHA@00H0ZXEA0:b7D`2]R5@0[89@0:f3D@2^Q5820:n5
D`030:f3D@2[PDl0ZX1>00<0ZHA?0P2ZQE030:^6D@030:j5C@2]Q4`0[8=;0080Zh9:00<0[HA<0:j5
C@2_QTh0202YQ4l00`2^QE40[HA@0:^2CP020:Z1C@030:^2CP2]Q500[XEA0080ZH1<0P2ZPDd20:^2
CP<0[8=?00L0Zh9>0:Z1C@2YP4`0ZH1<0:Z1C@2[PTh0[8=?00P0[HA@0P2XOd/01P2YP4`0ZX5=0:^2
CP2/Pdl0[HA@0:j5D@P0[HA@2P2^QE402@2/Pdl0Zh9>0:Z1C@2ZPDd0Zh9>0:b3C`2^QE40[H=A0:b2
D0040:^1C`050:b2D02]Pe40[XEA0:b3C`2[PTh00P2ZPDd01P2[PTh0[8=?0:j5D@2[PTh0[8=?0:j5
D@80[hIB00<0[XEA0:b3C`2[PTh0202/Pdl80:j5D@<0Zh9>0P2/Pdl30:f4D0<0[hIB0P2^QE430:f4
D0030:Z0D02[PE40[H=C0080[XAD00<0[H=C0:^1D@2ZP500102]PE040:j2D@P0Zh9>00P0ZWm80:b1
BP2]PT/0[X=<0:n4C@2]PT/0[85:0:^0BA00[8==0P2YP4`20:Z1C@80Zh9>0P2/Pdl80:Z1C@80ZX59
00@0ZX5;0:Z1C@2[PTh0Zh5?0P2[PE480:b2D0X0ZH1<00L0ZX5=0:b3C`2]Q500[XEA0:f4D02/Pdl0
Zh9>0080ZX5900@0Zh9<0:^2CP2/Pdl0[H=A0P2^Q5@20:QnCP040:QnC02XOd/0Z7m;0:QoB@80ZH18
0`2YP4`30:QoB`80Ygi:202[PTh30:]mB`80ZWa:0`2YNdT0202XOT80ZGm30:UoA@2ZP4H0ZWm80:^0
B`2[P4d0[85>202YOdd30:Z1B@D0ZH18202XP4D80:b3C`0<0:MnAP2XOdL0ZX5;0:b3C`2]Q500[89@
0:^1D@2ZP500Ygi:0:QoB`2ZPDd0Zh9>0P2/Pdl00`2[PTh0ZX5=0:UoC@030:Z0CP0<0:UoC@2WOD/0
YG]90:=iA`2UNTl0YW]>0:QmD02YOdl0ZGm=0:QoB`2VODL0YGa60P2YP4P20:Z1B@@0Zh9:0P2YP4P0
102YP4X0ZH1<0:V0C02YOdd20:UoC`80Z7i>00@0Z7i<0:QoB`2XOd/0Z7m90P2XOdL90:QoB`0809mj
A@2QO4L0Xgi90:AoBP2UP4/0Y7m:0:=nB@2RODP20:AjBP040:AjB02UO4P0YWe90:ImA`80Ygi60`2Y
Odd00`2XOT`0Yge;0:MmB`020:IlBP80Yge=0P2VO4`20:EkB`80Y7Y:0P2RODP0102QO4L0X7]609mj
A@2NND@209eh@`80Ygi600@0Ygi80:MnBP2WOTX0Yge;0P2WODd0102YPDd0Z81<0:EmB@2SNdL20:9j
AP80Xg]7202SNTH20:EjA@<0Y7U40`2SN4<02`2ONTH0X7]70:5lB02RODT0XGa80:1kA`2NNDD0WGQ4
0:AjB02SNDL0XGM50080X7I400<0XGM50:=iA`2TNTP00P2SNT@01P2RNDD0XGM50:1fAP2OM4L0WW=6
09icB0P0WG=100P0VgI209ehA02ONTH0XGa809mjAP2LMd<0V7<o09Ia?@<0WG=10P2NM48309me@`<0
VWHl0P2KMcd309ah?P0409ac?`2KLSh0Vg8n09]b?P80VW4m0P2IL3`809I`@@T0VWHl00/0WG8m09ac
?@2KLSh0VW8o09Ma@02FLT80U79209=a@`2GLSh0V7<o09Ud@00209Ye@@0309Ud@02HLcl0Ug8n0080
UW4m0`2GLSh309Qc?`0309Mb?P2HLcl0VGA00080VWE100@0VGA009Qc?`2GLSh0VVm40P2JKd800`2J
L400Vg4o09]b?P0209]b?00309]f@P2JMD40V7<o0080V7<o00<0VGA009]f@P2LMd<00P2IM3d00`2I
M3l0VGA009Uc@P0209UcA00?09UcAP2HLT<0VG=409YdA@2KMDH0VWA509Qb@`2FL440UFm009E^A`2E
KTD0UFi309E_@P2EKch0UG0l0080UG0i0`2GMdH[ooooo`00:_ooool@08aO=@08091T=`2?HcH0SV8e
08eQ=02>HSD0T6@g09=W>P2DJ3/2091Q=`0608iQ=`2>HcP0SF@h08]U>02<IST0RfHi202BIc`8095T
>PP0TFDh00<0UFXo09AY?P2BIc`00P2@ICX00`2BIc`0U6Tn09EZ?`0208iS=P0308mT=`2@ICP0TFHi
0080TVLj00<0TfPk09EX?P2EJ3h01`2EJ3h02@2HKCH0V6dh09M/>@2GJc`0UVTo09EX?`2EId<0U6I2
09AX=`0209EY>00309IZ>@2GJcX0Uf/j0080V6`k0`2DJ3/509=W>P0809eZ>`2KJc/0VVXj09U[>P2F
JST0U6Xh09=[>02BJSL209Q]>00309Q]>P2HK3/0V6`m0080V6`o00L0V6]109=V?02DIcd0U6Lm09EX
?P2FJCl0UfY00080V6]10`2IKC`209Y^?@<0Vfln0P2HL3d309Ua?P<0VW8o202LL3l209ab@080Vg4o
00P0VW0n09U_?@2IKcd0V6hl09M/>@2IKS/0W74n09ic@080WgA100<0WW=009eb?`2MLSl0202MLSl0
1`2NLd00X7E20:5f@`2PMD80WgA109eb?`2KL3d00P2RLT430:5a@0<0X70o0P2PMCh0102PMD00X7E2
0:1e@P2PM4<20:1dA@<0WW=00P2OM4430:1e@P0809md@@2PMD80XGI30:9gA02QMT<0WgA109aa?P2K
L3d209ic@00309md@@2PMD80XGI30080XWM400<0XgQ50:5eA02QMD@01`2QMD@0202NLd00WgA10:1e
@P2QMT<0XWM40:=hA@2TNDH0YGY7202UMD@80:9gA0080:AhA`2UNDP0Yg]:0:QlB`2WNdX0YWY90:=g
AP2RMTD20:9fA`040:=gB02TN4T0Y7Q90:EiBP80YWY;00D0Y7U60:EjA`2UNTL0YW]80:MlB@020:Qm
BP040:UnB`2VNdP0YW]80:IkB0<0YGY70P2TNDH80:EjA@080:=jAP2UO4P0Z7m;0:Z1C@2YP4`0Ygi:
0:=jAP2PMd<80:9iA@0909aa?P2NLd00X7E20:9gA02SN4D0XWM40:5f@`2PMD80VgM50080VgE400<0
WGE409ec@`2NLT<00P2OL48309Ib?P80UG4m0`2DL3`0102GKC/0UV`j09I/>P2FK3X209E[>@80U6Xh
0`2EJcT209AZ>0<0TfTg202=IcX208iS=P80SF8e0`2<HC@02@2;H3<0QfDh08IT=`28HcL0RF8g08YP
=P2;H3H0RUle08]N=@0308MQ<P80QV0a1025Gc000`21G2l0Peha08AO<P0208IQ=00708AO<P23GS40
PE`_08=N=022GC<0OeX`07eH;P0207aG;@0407eH;P1nFBl0O5L]07eH;P80OUT_00@0OEP^07]F;01i
E2X0Me8X201kEC001P1kEBh0NU@]07YD;@1iDb`0N58[07MA:P80MU0Y00P0MELa071B;01/CRP0KU0Z
079D;P1cEBl0L58/06]=9`80L5<[0P1_DRX306iA:@0506e@:01^BbD0L4dW079?:@1dDB/00P1eDR`0
0`1dDB/0Le0Z06]?:P0206]?:P80JThY0`1YCBP206]:9`80K4/X00@0KD`Y06i=:P1^CBX0Kdh[0`1/
BbP506e<:@0306]:9`1/BbP0KD`Y00<0Kdh[0P1]C2T0101ZBBP0JDPW06U89`1XAbH206M69@80ITDT
0`1XAbH00`1WARD0ITDT06E48`0206E48`@0HdHX0`1RABL0101QA2H0HT@R06A6901UAbD206M99`03
06E79@1TAR@0HT@R00P0GdLS00<0HD8S0693901SA2D00P1TABH0101R@b@0H44R05m08@1VAbX206E6
:@0306A5:01SA2L0Hd@W00<0HT<V201T@b8806E79@80IdTW0`1VB2H306E79@P0IT<W00@0HTXX0618
9P1NAR@0GDDS0P1LA2802P1MAB<0GTHT06I89P1VB2H0I4HT06=58`1Q@b40H48P05m17`1N@1h806A8
8`80HdHX0P1RABL0101QA2H0H4<U05m2901O@R@306E69`80ITLX0`1WB2T806M;8`0506U98P1ZBR<0
J4/S06Q<901WCRD00P1WD2H02@1WDRL0Me0Y07M@:@1eCbP0LTlW071?9P1^CRD0KDdT06Y=8`0807AA
:@0606i=901`CbH0M54Y07UC;01kEBh0OEH_0P1oEBl00`1lES40NeD`07UC;P0207QB;@0607UC;P1k
EC00O5Ha07UG:@1jF2X0NeT[0P1lFR`00`1jF2X0N5HX07ME9`0807MK:`<0P5`/0P21GBd4089N;P<0
Pel_0P24H30208EQ<@@0QF0/0P26HBd308MR;P03095W=@2?IC<0SF<a0080S68`00L0SF<a08mU<`2A
IcD0Rf8^08eT<02@Ic<0TfXf0080UF`h0P2DJcL208]V<@0408aW<P2=J3<0SfXe091[=P80TF`g00H0
U6/g09E/>02EK3P0UVdi09M^>P2HKc/209U`?080V7<n00@0Ug8m09Ia?02FLC`0UG0k0P2DKcX00`2H
Lch0VG@o09]f@@0209ag@P0;09]f@@2IM3l0V7<n09iiA02MN4<0W7M209]f@@2LMd80WGQ309mjA@2Q
O4L00P2NNDD01P2ONTH0XGa80:9mB@2SOTX0Y7m;0:F0C0<0Y7m;0P2UP4`30:J1C@030:N2CP2XPdl0
ZXEA0080ZhIB00<0ZXEA0:R3C`2WPTh0202/Pdl30:b2D080[H=A0`2^Q5880:^6C`040;2;E`2_RUH0
[hYF0:j9E@80[HQD0P2/Qe<80;67E@P0[hYF0P2]R5@0102^RED0[hYF0:n:EP2`ReL20;6<F0H0/8]G
0P2aS5P90:j9E@P0/hiI00<0/8]G0;6<F02bSET00P2bSET00`2`ReL0[XUE0:f8E0080;6<E`80/XUE
0P2cRUH40;B;E`80/HQD0`2bRED30;>:EP<0/XeH1@2cSUT30;B:F0<0/hUG0P2bR5H01P2cSF00/heN
0;:<G@2bS5/0/HaH0;6<E`80/8]D0`2aS5P30;2;E`80[hYF202bR5H80;>9F@D0/HQD0`2`Qe<01P2d
ReD0/hYD0;>:E02bRE<0/HQB0;27D@80[hI@202]R5<80;2;E`P0[XUD202_QU800`2/PU80[XAD0:n5
E@020;26EP030:n5E@2^Q5@0[89B00T0[XEA00@0[XUD0:f8D`2]R5<0[HQC0P2/Qe820:^6D@X0[HA@
0`2/Pdl30:^2CP80[hEC00@0[XAB0:f3D@2]Pe40[89@0P2[PDl50:j4DP<0[hEC00P0[8=?0:f4D02^
QE40[hIB0;27D`2aR5@0/XUE0;>:EP80[HA@0`2^QE430:n6DP030:f8E02/Qe<0ZXEA0080ZHA@00H0
ZXEA0:b7D`2]R5@0[89@0:f3D@2^Q5820:n5D`030:f3D@2[PDl0ZX1>00<0ZHA?0P2ZQE030:^6D@03
0:j5C@2]Q4`0[8=;0080Zh9:00<0[HA<0:j5C@2_QTh0202YQ4l00`2^QE40[HA@0:^2CP020:Z1C@03
0:^2CP2]Q500[XEA00<0ZH1<00<0ZX5=0:^2CP2/Pdl00P2/Pdl00`2]Q500Zh9>0:Z1C@020:QoB`03
0:Z1C@2[PTh0[HA@00P0[XEA00P0Ygi:0:QoB`2YP4`0ZX5=0:^2CP2/Pdl0[HA@0:j5D@P0[HA@2P2^
QE402P2/Pdl0Zh9>0:Z1C@2ZPDd0Zh9>0:b3C`2^QE40[hEC0:f3D@2[PDl20:UoC@060:^1C`2]Pe40
[hEC0:j5D@2/Pdl0Zh9>0P2ZPDd01P2[PTh0[8=?0:j5D@2[PTh0[8=?0:j5D@80[hIB00<0[XEA0:b3
C`2[PTh0202[PTh30:n6DPD0[XEA0`2[PTh30:b3C`80[HA@0`2_QU830:j5D@80[HA@00<0ZGm?0:Z0
D02/PU800P2]Pe<0102/PU80ZX1@0:UoC`2/P4l20:f1D080[X9A0`2_Pe880:^2CP030:b1BP2]PT/0
[X=<0080[hA=00<0[H9;0:^0B@2YOTL0402/Pdd20:V0C080ZX5=0P2[PTh20:b3C`P0ZH1<00P0Z7m7
0:V0B02YP4X0ZX5=0:^2CP2/PU00[89B0:f3D`P0[89@2@2YP4`0102XOd/0ZH1<0:^2CP2]Q5020:j5
D@080:f4D02/Pdl0Z7m70:V0B02ZPD/0Zh9>0:b3C`2^Q5820:n5E@80Yge=00@0Z7i<0:QoB`2XOd/0
Z7m90P2YP4P30:V0C080Z7m;0`2WOTX80:^2CP80Zge;0`2ZO4X30:UkB@060:Qo@@2YOd<0ZGm30:Z0
AP2[P4T0Zh1;0P2/PDh80:MmB`H0ZH180P2ZPDT80:R0@`P0[8=?00`0YWe50:QoA`2ZPD/0[8=?0:f4
D02/PU00Zh5A0:Z0D02WOTX0ZH1<0:^2CP2/Pdl20:f4D0040:b3C`2[PTh0ZGm=0:Z0CP80Zh5?00`0
ZX1>0:MmB`2TNTP0XgU70:EjC`2VNdh0Z7e@0:UoC`2YOdd0Z7m;0:ImA`2UO4H20:V0B080ZX590`2[
PTX0102/Pd/0ZH180:V0B02YP4X20:V0C0030:UoC@2YOdl0ZGm?0080Z7i>00@0Z7i<0:QoB`2XOd/0
Z7m90P2XOdL90:QoB`0809mjA@2QO4L0Xgi90:AoBP2UP4/0Y7m:0:=nB@2RODP20:AjBP040:AjB02U
O4P0YWe90:MnB080Ygi60P2ZP4h0102YOdd0Z7i<0:QnC02WOD/20:IlBP80Yge=0P2VO4`20:EkB`80
Y7Y:0P2QO4L00`2PNdH0WgY509iiA00209ag@P0409]f@@2WOTH0Ygi60:MnB080Ygi:00L0Yge;0:Mm
C@2WODd0ZX9>0:R0C02UODT0Xg]70080XWY600<0Xg]70:AlB02RNDD01`2RNDD30:EjA@80Y7U40`2S
N4<00`2ONTH0X7]70:9mB@020:9mB@060:1kA`2NNDD0WGQ40:=iA`2RN4H0X7I40P2OMD<00`2PMT@0
XWQ60:=iA`020:AiA0060:=hA@2RMTD0XGE60:1dA`2OLdH0Wg98202MLd40202KMT80WGQ409mjAP2P
NdL0WgY609ag@`2GLSh0U6lk0`2MLd4209id@P<0WgE30`2JMS`209]g?@<0W7Pn102KLSh209Ya?@80
VG0l202FL4<909Yf?00;09aa?02KLS`0VW4m09Ua?P2FL3l0UG5109=a@@2BL480UW4m09Mb?P2IM400
0P2JMD400`2IM400Ug8n09Ia?@0209Ea?@<0UW8n0`2GLcl00`2FLCd0V7<o09Ud@00209]f@P0409Ud
@02HLcl0UW4m09Y_A080VVm200<0VW1009Y`?P2KLSh00P2KLS`00`2KMT40VWE009Ud?`0209Qc?P03
09Ud?`2KMT40W7M20080VG@m00<0VG@o09Ud@02ILd800P2ILd@02@2ILdH0V79309UcA02JM4D0VgE6
09YdA@2HLT<0UW1109A^?`0209A]AP0609A]@P2EKd80UFln09E`>`2EL3T0UG4g0`2INDP[ooooo`00
:_ooool208iS>080SF8g0P2<HCH208]P=@P0SF0f0P2<GcD208eP=P80SV4g0P2?HSP808YU>00;08QS
=P2;ICP0SFLj095X?02CJ3d0TfHl09AU>`2CI3X0Sf<f091T=`2BIST00P2DJ3/00`2BIST0T6@g08mS
=P0809=V?@0808mR>02@HcT0TF@j099U>`2CIS`0U6Lm09EX?P2FJCl2091T=`04095U>02BIST0TfLj
09AX>`80UFTl2@2FJSd209Q[@@<0UfY00`2FJCl0202DJ3L0TfLf09=W=P2DJ3L0UFTh09Q/>`2KKch0
W70o0`2FJSd209EY?0<0U6Pk202EJcT209IZ>@80Uf/j0P2HK3/209U]?0P0UVXi0`2HK3/309U]?080
VVhm00<0Vg=009Yb?`2ILCh00P2GKc`00`2ILCh0VW8o09]c@00209ab@080Vg4o00@0VW0n09U_?@2I
Kcd0V6hl2P2MLSl309]`?@0309aa?P2NLd00WgA100P0Vfln00H0WVhn09m_?`2OKcl0X7100:5a@@2R
LT820:=c@`0309a`?`2MLD00Wg=200<0XGE400<0Wg=209ib@@2NLd000P2NLd0209md@@<0X7E2202O
M3l00`2SN4D0XGI309md@@0209eb?`0609md@@2QMT<0XgQ50:AhB@2RMTL0XGE40P2OM4400`2QMT40
XWM00:Ai@P0209md@@030:1e@P2RMd@0Y7U60080YGY700<0YW]80:MlB@2SN4D00P2SN4D40:9gA009
0:5f@`2TNDH0XWM409md@@2MLSl0WW=00:5f@`2TNDH0Yga90080XgQ50P2RMd@30:5f@`030:1e@P2T
NDH0Y7U600H0Y7U600H0XWM40:=hA@2SN4D0YGY70:IkB02WO4T20:QmBP040:EeA02WMdH0ZGU80:]k
BP80[7a;00X0ZWY90:UiB02UO4H0YWe70:MnB02XOdT0Ygi80:ImA`2TNdD0XWU3202TN4L80:AiA0<0
X7E20P2OM44309ic@080WWE10P2MM40309ac?`0909]b?P2LLT00W79009ab@02KLCl0VW0n09U_?@2H
KS`0Ufdk00P0VFi10P2HJST00`2FJST0U6Xh09=[>002091[=`0508m[=`2>J3T0SVPi08eW>02<ISL0
0P2;ICH208YT=@80S6Hg0P2;ICH308YT=@0308US=029HcH0RF<f0080R68e0`27HC@01026H3<0Qf8e
08MR=@27HSD208IQ=0<0QF0c00H0PUh^08=O;`23GS40Pehb08AO=@24GSL308AN>@0307eJ<01nFc40
P5dc0080PEhd00<0P5dc07iK<@1mFS000P1mERl04@1jE2d0Me@/07MF;@1gEbh0NET`07QK<@1kF300
NUL_07UF;P1hEBd0Me@/07IC:`1eDRX0M54Y07QB;@1iDbh0NU@_0080NeD`00L0NU@_07UC;P1hDRd0
KdlX071@:@1bDR/0M5@]0080MED^00@0M5@]07=C;01eC2`0MD`/0P1dBb/307=::P060799:@1bDBh0
LU4^075@;@1`Cb`0Kdh[0P1]C2T0301/BbP0I4`V06I>:01[CbX0KU0/075?;01bBbX0L4LW07569P1a
CRh0Kd`/06a9:@80JdPX00<0K4TY06m<;01aCRh0201YBbL306]=:`80JT`Z0`1[CB/00`1^AbH0KdPW
0719:0020719:00406i79P1/AB@0Jd@S06=;9`80I4XW00<0ITTW06M99`1YB2L00P1ZAbL04@1T@b80
ID@S06M69@1XAbH0IdHU06E48`1R@B00H3lN06A6901UAbD0ITPV06M99`1VB2H0IDLU06=58`1Q@b40
H44R0080HD8S0P1R@b@206=49@0406A59P1XBRP0IdTW06I89P80I4HT00@0ITPV06M99`1XBRP0ITPV
0P1UAbD00`1TAR@0HdDS06948P0206538@<0HdDS0P1TAR@406E79@<0Hd@U0P1R@b@306528`80ID@U
00@0Hd@U06=69P1QAbH0GdLU0P1NAbD0201MAB<0GdDT06579P1TAbL0IDHW06I59P1U@R@0I44S0P1U
B2P00`1TAbL0HdHV06959@0206138`0L05m28P1TARX0HT@X06129P1N@2@0GClS05i0901O@BD0H48V
05`n901N@2@0HdDY06I9:`1WBRX0IDPV06=78P1QAB00ITTY06E8:01TAbL0HdHV06A79`1UB2P0IdXZ
06Q;:`1XC2L0ITXU06E990<0HdLR00@0I4PS06E9901ZAbL0JTLW0P1[B2P406a9:@P0JD/U201[CR@5
06e<:@<0K4/X0`1`Cb`406m>:`0306i=:P1bDR/0LU8[00H0LU8[0`1hEBd207UF;P<0NUL_0100Oe/[
07iJ:P1mFBT0O5PX07YF9P1hE2@0Me<S07IB8P1kFBT0NUPX07QF9P1gEBD0N5HV07YH:01lFRX0OE/[
0P1jEbd0101kF2h0O5T_07eJ<01nFc4207mL<PP0QUd_0`25GBT00`26GRX0Qel[08MO:`0308MO:`P0
RVLa0`2;ICH208aV=`<0SFLh0100RF<d08YT<`2;IC@0S6Lc08iY=02@Jc@0TFdc099^=02AIcD0TVPf
09=Y=`2DJSP0UV`j09Q^?02IKcd0VW0n0P2DKc/0102EL3`0UW4m09Ia?@2GLSh309Qc?`<0VGA00P2J
MD4209]f@P0609Ud?`2JMD00VWE009ag@P2MN4<0WWU40P2ONTD01P2MN4@0WWU509mjAP2ONTH0X7]7
0:5lB080XWe900H0XGa80:9mB@2RODT0Xgi:0:AoB`2UP4`20:J1C@090:V0C02XOd/0Ygi:0:ImB@2W
OTX0ZX5=0:b3C`2^QE40Yh9=00<0Z8=>0P2YQ4l20:Z5D080[XEA102]Q5020:b3C`040:j:D02]RDl0
[HU?0:f9C`<0[8Q>00@0ZhM=0;2:F@2`RUT0/8]G0P2`ReH01P2`Re@0/8aB0;2<DP2`Qdl0/HQ@0;:9
D@80/hYB00<0/HQ@0:n6CP2]Q4`0202aR5@20;2:F@040;2;E`2`ReH0/8]F0;2;E080/8aB0P2eS5@0
102eS5H0]HaH0;F<F02eReT20;F;F`050:^6C`2/Qe00[8M@0:b7D02]R5400P2^RE820:n:D`80]XaL
00@0]XaJ0;F<F02dReL0/hYD0P2cRU880;2;E`80/8YK102_REX20:j8F@P0]H]I0P2]S5L00`2_ReL0
/HaH0;B<F@020;J<FP040;N;FP2gSUX0]hiJ0;J=F@80]HaH00<0]8]G0;>:EP2cRUH00P2bS5/0102b
SET0/XeH0;:=F02bSEH20;:>E0030;2;EP2aS5L0/XeH0080/XeH00/0/8]F0:n:E@2]R5<0/XeH0;6<
E`2`ReH0[hYE0;2;EP2bSEP0]I1K0;JAG0020:n:EP<0[XUE0`2]R5@80;2;E`P0/XUE00D0[hYF0:j9
E@2^RED0[HQD0:b7D`020:^6DP030:Z5D@2]R5<0[HQC00H0[HQC202_RUD80;68D0080:b8C02/R4h0
[8M@0:b7DP2[QE@0ZhEH0:Z3F02ZPeX30:n5D`<0[XAB0P2]Pe440:R4BP030:V5B`2ZQT`0ZhM=0080
ZhM=0P2`Qe<20:n6DP040:j5D@2]Q500[HA@0:b3C`80Zh9:00@0[8==0:f4D02]Q500[XAB0P2_QED2
0:n5D`040:j4DP2]Pe40[H=A0:b2D080Zh5?00H0[H9G0:f2E@2]PUD0[H=C0:f3D@2]Q5020:f4CPP0
[XEA0`2YQ5020:Z5D@<0ZhIB0`2/Qe<30:^6DP80ZXEA202]Q4h30:b2DP80[H=C0`2^Q5@80:j5D@P0
ZXE@0P2[QU440:Z5D080ZHA?0`2[QU820:Z5D@<0ZHA@202[PDl80:b3C`@0ZX1@0P2YOdl20:QnCP80
ZH1<0P2ZPDd20:^2CPX0[8=?00<0[hIB0:j5D@2]Q5000P2[PTh01@2ZPDd0Z7m;0:MnBP2VODT0Z8E?
0080ZHA?00<0[8A@0:f4D02_Q5400P2aPe401P2YP4`0ZX5=0:Z1C@2[PTh0[8=?0:f4D080[XEA102[
PTh20:b3C`80[HA@2`2[PTh30:b3C`80[HA@0P2_QU80102^QE40[HA@0:f4D02/Pdl20:^2CPP0[HA@
0P2`QE00102_Q4l0[X=>0:j3CP2]PTd20:b1C0030:b3C`2[PTh0ZH1<0080Z7m;00<0ZX5=0:b3C`2^
QE40202]Q5020:f4C0040:f4CP2]Q500[HA@0:f3D@80[H=C202[PTh20:f4D0<0[8=?0`2[PTh80:b3
C`80ZX5=00@0Zh9>0:b3C`2^QE40[hIB0P2`Qe<80:^2C0080:Z1C@2YP4`0Z7m;0:MnBP2XOd/0ZH1<
0:^2CP2/Pdl80:f4D080ZGm?00D0ZGm=0:QoB`2XOd/0Z7m;0:MnB0020:MnAP@0Zh9>0P2/Pdl20:f4
D080[8==0P2[PT`20:Z1B`80ZH1:0P2XOd/0102YP4`0ZX5=0:b3C`2]Q5020:j5D@80[8=?0P2[PTh2
0:Z1C@X0ZH1<0P2YOdd20:Z0CP80Zh5?0P2/PU050:V0B0<0ZX59202YP4`20:b3C`80Zh9>0P2ZPDd2
0:V0C080ZX5900@0ZH180:QoA`2XOdL0Ygi60P2VODD00`2^QE40[8=?0:^2CP020:Z1C@040:^2CP2/
Pdl0[XEA0:MnBP80Z7m;00<0ZH1<0:Z1C@2ZPDd00P2[PTh80:^1C`80ZX5=0`2[PTh00`2YP4`0Ygi:
0:ElB0020:EoCP040:F0C02UP4/0YH1;0:F0B@80YH5700D0Z7m;0:V0C02YP4`0ZX5=0:^2CP020:b3
C`030:f4D02YP4`0ZH1<00H0ZH1<0`2WOTX20:QoB`<0ZH1<0P2XOT`30:UoC@@0ZX1>0100ZGm=0:Qn
C02VO4X0YG]90:IlBP2XOT`0ZX1>0:^1C`2WNDL0Z7Y80:IkB02UO4P0YGe90:=nB@2TOdX0Xh1:202T
Od/20:QoB`040:MnBP2VODT0YGa80:AkA`80XgY60P2NNT00102ONT<0X7]60:1kAP2QO4P20:9lB`03
0:MnBP2XOd/0ZX5=0080Zh9>00d0Z7m;0:ElB02SNTH0YX1C0:EoD02TOTl0Xge<0:9mB@2QO4L0X7]4
09mj@`2TNTP0XgU700<0XGM500L0XgU70:EkB@2VO4X0WGA009mf@P2RNDD0YGa80080YWe900D0YGa8
0:AkA`2UNTL0YGY70:IkB0020:MlB@030:QmBP2YOT/0ZGi;00<0Y7]70P2SNTH30:9iA@<0XWQ600<0
XGM50:1fA02OMD<00P2OMD<03P2MO4L0W7]609eiA@2MN4@0WWI309ec@@2LLT00WG500:=iA`2RN4H0
XGM50:1fA02OMD<0WG=10P2LLT001@2NM480WgE309me@`2PMT@0XGM50080XWQ600@0XgU709]f@P2J
MD40VGA00P2HLcl00`2IM400VgI209ag@`0209ebA`80W7560`2KL4D01P2JKd@0VW0n09Y`?P2JL3h0
Vg4o09ab@0<0WG=10P2JMD4209Ud@080V7<o0`2GLSh209ab@080Vg4o00@0VW0n09U_?@2IKcd0V6hl
202IL3`209Qc?`0409Mb?P2FLCd0UW4m09E`?080U6lk202IM40809Ia?@0309=]?P2EKd00Ug520080
VG=400<0V79309Ma@P2FL440202JM4D209Ye@@80VGA00P2HLcl209Mb?PP0VG=40`2JM4D[ooooo`00
:_ooool208iS>080SF8g0P2<HCH208]P=@P0SV4g0P2<GcD208eP=P80SV4g0P2?HSP808]U>00;08UT
=`2;ICP0SFLj095X?02BIc`0TfHl09AU>`2CI3X0T6@g095U>02BIST00P2CIcX00`2BIST0TFDh091T
=`0809=V?@80T6<i00@0TF@j099U>`2CIS`0U6Lm0P2EJ3h01P2@I3L0TFDh095U>02BIST0TfLj09AX
>`80UFTl2@2FJSd209M[?P<0UVXm0`2EJC`0202DJ3L0TfLf09=W=P2CIcH0UFTh09Q/>`2JKSd0W70o
0`2FJSd209EY?0<0U6Pk202EJcT209IZ>@80Uf/j0P2HK3/209U]?0P0Uf/j0`2HK3/309U]?080VVhm
00<0Vg=009Yb?`2ILCh00P2GKc`00`2ILCh0VW8o09]c@00209ab@080Vg4o0P2JL3h209U_?@P0WG8o
0P2LLCh01P2KL3d0VVll09]`?@2MLSl0WgA10:1e@PP0Vfln0`2PL4030:5a@@80XW9200P0W70o09ea
@02OLd80X7A30:5eA02PM4<0Wg=209ib@@80WW=00`2OM4430:1e@PP0Wg@o0P2QMT<0102PMD80WgA1
09md@@2PMD820:5f@`030:=gB02RMTL0XGE40080X7E200@0XGI10:9g@02SN440X7E20P2QMT<0102R
Md@0XgQ50:AiAP2TNDH20:EjA`@0XWM4102QMT<00`2TNDH0XWM409md@@0209ic@0030:5f@`2TNDH0
Yga90080XgQ50P2RMd@40:5f@`P0Y7U600H0XWM40:=hA@2TNDH0YGY70:IkB02WO4T20:QmBP0@0:If
A@2WMdH0ZGU80:]kBP2/O4/0Zg]:0:YjB@2YNDP0YGa60:ImA`2WOTP0Z7m90:MnB02VODL0Y7]50:9i
@`P0Y7Q70P2UNTD20:AiA080XgQ30P2RMd820:1e@P<0WgA10`2NLd00102NMD40WGA009ed@02MM402
09ac?`80Vg8n00D0WG=109ab@02KLCl0VW0n09U_?@0309Q^?0P0VFi10P2HJST00`2EJCP0U6Xh099Z
=`02091[=`0608iZ=P2>J3T0SVPi08eW>02<ISL0RfDf0P2:I3D00`29Hc@0S6Hg08]U=P0208]U=P80
RV@e0P29Hc@308US=P80R68e0`27HC@208MR=@80QV4d0`25H3<01`24Gc80Pel_08=O;`23GS40Pehb
08=N=023GCH00`23GCP00`1mFS00OU/a07mL<P02081M<`0;07mL<P1nFc40OEX`07iG<01mERl0NeD^
07QE;@1gERd0N5P_07UI<01hFc400P1jEbl02@1iERh0N5D]07MD;01fDb/0ME8Z07AA:@1eDR`0MU<]
07QE;`0207UF<00;07QE;`1fDbd0ME8/071@:@1aDBX0Le</07AD;@1eEBh0M5@]07=C;01bDR/00P1f
CBd207E<;0<0M4/[00H0LdXZ079A;P1aD2d0LE0]071?;01^CBX206e<:@0<06a;:01WCbT0J4hY06]?
:P1/CRX0KT`Y06i::01`AbL0KdHV06m<;01^Bb/0KDXZ0P1/BBT00`1]BRX0KT/[06m<;00806U;9`P0
JT`Z00<0K4PV06e99`1^BRP00P1^BRP0101/B2H0JTHT06U58`1SBbL206A:9`0306I99`1WBBL0JDPW
0080JTLW0P1VAB@306M69@0;06I5901UA2<0I4<R06A6901UAbD0ITPV06M99`1VB2H0IDLU06=58`1Q
@b401@1R@b@306=49@0306M99`1VB2H0IDLU0080HdDS00<0IDLU06I89P1WBBL00P1VB2H0101UAbD0
I4HT06=58`1RA28206538@<0HT@R0P1SAB<406A690<0Hd@U0P1R@b@306528`80ID@U00@0Hd@U0695
9@1PARD0GdLU0P1NAbD02@1MAB<0GdDT06579P1TAbL0IDHW06I59P1U@R@0I44S06E8:00206A79`08
06=69P1QA2@0H4<S06138`1O@R80HdDY0694:01P@RH305i0900:05m19@1P@RH0G3hT05i0901RA2P0
IDPZ06I9:@1UB2H0HdLR06558080I4LW0`1RABD0301TAbL0ITTY06M::P1WBbH0ITXU06A88`1SAb80
HTHQ06=78P1TB2<0IDTT06U69P80JTLW0P1[B2P306a9:@P0JD/U201ZCBD306e<:@D0K4/X1P1_CR/2
06i=:PP0LE4Z00@0MU<[07MD;01gE2`0Me@/0P1hEBd207UF;P0607eI:@1lF2P0O5PX07]G9`1jERH0
NEDU0P1hE2@0201jF2P0NELW07QF9P1gEBD0N5HV07UG9`1kFBT0OE/[0P1jEbd00`1kF2h0O5T_07eJ
<00207iK<@0307mL<P26GBl0QUd_00H0QUd_0`25GBX208IN:`@0Qel/2029IC40102:I3D0RfDf08]U
=P2;ICH208aV=`80SFLh00P0RF<d08YT=@2;IC@0S6Lc08iY=02?JS<0T6/d095]<`80TFLe00H0TfTg
09AZ>02FK3X0Ufdk09Q^?02IKcd209A_>`80UG0l0P2FLCd209Mb?P80V7<o0P2IM40309Ye@@0909]f
@P2IM3l0VG@o09Ye@02KMT40W7M209eh@`2NND@0WgY50080WGQ400<0WWU509mjAP2PNdL00P2QO4P0
1@2RODT0XGa80:5lB02RODT0Xgi:0080Y7m;00X0YH1<0:J1C@2XOd/0Z7m;0:MnBP2VODT0Ygi:0:V0
C02/Pdl0[HA@0P2WPTd20:R3CP<0ZHA?00<0ZXE@0:f4D02]Q500102]Q5020:b3C`H0[8Q>0P2]RDl2
0;2:F@040;2;E`2`ReH0/8]F0;2;E080/8aB00<0[hI>0;27C`2aR5000P2cRU800`2bRE40/8M?0:n6
CP080;68E080/8YI00@0/8]G0;2;EP2`ReH0/8]D0P2`S5820;B;D`040;B;E@2dReL0]8]G0;B:F080
]8YJ0`2]R5420:j9DP80[hYC0P2`Re@20;J<G0040;F;F@2eS5P0]8]G0;>:E080/hYB202`ReL20;2:
F`H0[hUJ202eReT20:f<E`060:n;E`2aS5P0]8aI0;F;F@2fS5X0]h]J0P2fSET20;F<F0040;B;E`2c
RUH0/hYF0;>:EP80/XaK00@0/XeI0;:=F02bSEP0/XeF0P2bSU@02P2`ReH0/HaG0;:=F02cSUT0/XeH
0;6<E`2_RUD0[HQC0;6<E`2`ReH30:n:E@030;6<E`2cSUT0]8mJ00<0[hYF0P2^RED30:f8E0P0/8]G
202bRED20:j9E@<0[HQD0`2/Qe<80:f8D`P0[hYE202aR5001P2]RDl0[8Q>0:b7D02/Qe<0ZhED0:^5
F080ZX=H1`2^Q5800`2_QE<0ZHE;0:V5B`030:Z6C080ZhM=0P2/R4h20;27D`80[hIB00@0[XEA0:f4
D02]Q500[HA@0P2/Pd/0102/Pdd0[HA@0:f4D02^Q5820:j4E0030:n5D`2^Q580[XAB0080[H=A0P2/
PU001`2[PDl0[H9G0:f2E@2]PUD0[H=C0:f3D@2]Q5000P2]Q4h80:j5D@<0ZHA@0P2ZQE430:^6DP<0
[8MC0P2[QU830:Z5D@P0[HA>0`2/PU830:f3D`80[XAD202]Q50@0:Z5D0<0ZhIB0P2ZQE430:V4D0P0
Zh5?202/Pdl0102[PE40ZX1@0:Z0D02ZP5020:UoC`80Z7i>0P2YP4`20:Z1C@80Zh9>2P2/Pdl20:f4
D0040:b3C`2[PTh0Zh9>0:Z1C@80ZH1<00L0Z7m;0:V6D02ZQE00ZXE@0:b4D02]Q500[X=@0080/89@
0`2[PTh30:b3C`80[HA@00@0ZX5=0:^2CP2[PTh0Zh9>0P2/Pdl20:f4D0/0Zh9>0`2/Pdl20:f4D003
0:n6DP2^QE40[XEA0080[HA@0P2/Pdl00`2[PTh0[HA@0:f4D0060:f4D0030;25D02_Q4l0[hA?0080
[X=>0P2]PTd0102/PD`0[8=?0:^2CP2ZPDd20:V0C0030:Z1C@2/Pdl0[HA@00P0[HA@0P2]Q4`0102]
Q4h0[HA@0:f4D02]Pe420:f3D`P0[8=?0P2]Q5030:b3C`<0Zh9>202/Pdl20:Z1C@060:^2CP2/Pdl0
[HA@0:j5D@2_QU80/8MC202[PT`0202ZPDd0ZH1<0:QoB`2WOTX0Z7m;0:V0C02[PTh0[8=?202]Q502
0:UoC`050:UoC@2XOd/0Z7m;0:QoB`2XOdT00P2WOTH0102ZPDd0Zh9>0:^2CP2[PTh20:b3C`80[HA@
0P2/Pdd20:^2C080ZX5;0P2YP4X01P2WOTX0Z7m;0:V0C02ZPDd0Zh9>0:b3C`80[HA@0P2/Pdl20:^2
CP80ZX5=2P2YP4`20:UoC@80ZX1>0P2[PDl20:b2D0H0ZH180P2ZPDT80:V0C080[8=?0P2[PTh20:Z1
C@80ZH1<0`2YP4P30:QoA`80Ygi600<0[HA@0:b3C`2[PTh00P2ZPDd00`2[PTh0[8=?0:f4D0030:Qo
B`030:V0C02ZPDd0ZX5=0080Zh9>202[PDl00`2XOd/0ZH1<0:^2CP020:^2CP030:V0C02XOd/0YWe9
0080YGm>00@0YH1<0:F0B`2UP4/0YH190P2UPDL40:Z1C@@0Zh9>202YP4`30:MnBP80Z7m;0`2YP4`0
0`2ZP4h0ZGm=0:UoC@060:UoC@80Z7i<0`2VO4X00`2XOT`0ZX1>0:^1C`020:QjB0060:IkB02UO4P0
YGe90:=nB@2TOdX0Xh1:202TOd/20:QoB`030:MnBP2VODT0YGa80080Y7]700L0XgY609mk@@2ONd40
WgY30:1kAP2QO4L0XGa80080XWa;0P2XOd/20:V0C0050:QoB`2WOTX0YWe90:ElB02UOe800P2TOTl0
202SOD`0XWe90:5lA`2QO4D0X7]40:EkB@2TNTP0XWQ60P2QMdD01P2RN4H0Y7Y80:EkB@2RNDD0XgY6
0:AkA`80YGa800@0XgY60:5hA02PMd<0XgQ50P2TNDH00`2UNTL0YW]80:MlB@020:QmBP<0Y7]70P2S
NTH30:9iA@80XWQ60P2QMdD20:1fA080WgE300D0V7M209Uh@`2KMd<0W7M309if@`020:1fA0030:5e
A02QMdD0XGM50080X7I400@0WgE309id@P2MLd40WG=1102PMT@40:5gA@0309]f@P2JMD40VGA00080
V7<o00<0VGA009]f@P2LMd<00P2MLTD209aaA0@0Vg130P2JL3h209]a?`80W7900P2MLd4209Ye@@80
VGA00P2HLcl309Mb?P80W7900P2KLCl0102JL3h0VFlm09U_?@2IKcd809U`?080V7<o0P2GLSh0102F
LCd0UG0l09E`?02EL3`@09Ud@00309E_@02FL440V7930080VWA500<0VG=409Qb@`2GLD80202JM4D2
09Ye@@80VGA00P2HLcl209Mb?PP0V7930`2JM4D[ooooo`00:_ooool208iS>080SF8g0P2<HCH208]P
=@P0T6<i0P2<GcD208eP=P80SV4g0P2?HSP808]U>00808YU>02<IST0SFLj091W>`2BIc`0TVDk09AU
>`2CI3X2095U>004099V>@2CIcX0TfLj099V>@80TFDh202CIS`01@2@HcT0TF@j095T>P2BIC/0TfHl
0080U6Lm00D0UFPn095U>02AICP0TVHi09=W>P0209AX>`80UFTl2@2FJSd309EY?0<0U6Pk0P2CIcX0
202DJ3L0TfLf09=W=P2CIcH0UFTh09M[>P2IKC`0Vfln0`2FJSd209EY?0<0U6Pk202EJcT209IZ>@80
Uf/j0P2HK3/209U]?0/0V6`k0`2IKC`209Y^?@0309ab@02KLCl0VW0n0080V6hl00<0VW0n09]a?`2L
LT000P2LLT0309]a?`<0VW0n202MLSl0202KL3d0VVll09Y_?02JKc`0Vg0m09ic@02PMD80XWM4202K
Kch20:9b@P<0XG510`2PL400102LL3l0WG5009ib@@2OLd820:1d@`0309mc@P2NLT40WW=000<0WgA1
0P2PMD820:5f@`P0X7E200<0WgA10:1e@P2QMT<00`2QMT<01@2PMD80WgA10:=gB02RMTL0XGE40080
X7E200<0XGI10:9g@02SN4402@2SN4D00`2PMD80XGI30:5f@`050:5f@`030:AiAP2RMd@0X7E20080
WgA100<0XGI30:AiAP2VNdP00`2SN4D20:9gA0<0XGI3202TNDH20:=hA@030:AiAP2UNTL0YW]80080
Yga900@0Z7e:0:MgAP2XN4L0ZGU80`2[NdX02P2ZNTT0ZGU80:ElAP2VODL0Ygi80:QoB@2WOTP0YWe7
0:AkA@2RND<80:=gAP80YW]600L0YGY50:AiA02RMd80XGI10:1e@02OM3l0X7E200<0WgA10P2NLd02
09eb?`80WGA00P2LLcl309]b?P0909Ya?@2NM480W79009U_?@2GKC/0UV`j09M]>`2HKS`0VFlm00P0
V6e00P2GJCP00`2EJCP0TfTg099Z=`0208mZ=P0708iZ=P2>J3T0SFLh08eW>02<ISL0RfDf08YT=@02
08US=080RfDf0P2:I3D308US=00308QR<`2:I3L0RV@g0080RF<f0`28HSD01027HC@0QV4d08IQ=026
HC@208EP<`<0Q5lb0P24H3001023GS40PUda085L<P21Fc@3081J=@80OEX`00@0OU/a07mL<P1oG380
OU/a0P1mFS002020FC80OePa07aF;`1iERh0N5L^07QH;`1jFS40NE`b0P1iERh0101hEBd0Me@/07IC
:`1fDb/207EB:P0307EB;01fDbd0Me@^0080N5D_00/0Me@^07IC;@1eDR`0LE4Z079B:`1cDb`0M5@]
07=C;01bDR/0L50Y06m?:00207I?;P80MDh]0`1dCB`01P1cC2/0LE0]075@;@1`Cb`0Kdh[06i=:P80
KD`Y00H0K4/X06iB;@1]DB`0K4hZ06a;:01[BBH206a89P0406i79P1ZBBP0JdXY06a;:P80KD`[00<0
K4/Z06]::@1ZBBP0201YBbL206U;:@@0JT`Z0P1YBbT206a89P<0KTXX00@0K4PV06]79@1YAB<0Hd/W
0P1TBRL00`1VBBL0IdTW06U89`0206Y79`80J4LV00h0IdHU06I5901WARD0J4LV06U89`1ZBBP0I4HT
06E79@1VB2H0IdTW06I89P1UAbD0HdDS06538@@0Hd@U101R@b@00`1VB2H0I4HT06=58`0206948P03
06=58`1TAR@0ITPV0080ITPV00<0IDLU06A6901SAB<00P1RA28406538@80HT@R101SAB<306=49@80
HT<T0`1Q@R<206E49@040693901QA2@0GdDT05i69080GTLU00P0GDDS05m5901PARD0HdHV06A59P1U
A2D0ID8T06A18`80I4LW00<0HdHV06959@1QA2@00P1P@b<01P1O@R80HT@X06539`1P@RH0Gd4U05i0
9080Gd4U00/0H48V05`n901N@2@0HT@X06A7:@1UB2P0I4LU06968@1QAB00HTDU0654900306138`06
06959@1SARH0IDPX06M::01UB2H0I4LU0`1RAB<00`1SAR@0I4LU06Q79P0306Q79P0406U89`1ZBBP0
JTTX06]::@P0J4XV201YC2@00`1[BRL0K4/X06a;:00506a;:0P0KTdZ201aDBX307AA:@80ME8Z0`1f
Db/707YE:00907UD9`1iEbT0N5HX07QF:01gEBL0N5HX07UG:@1jF2X0NeT[0080NUL]0P1kF2h0101l
FBl0OEX`07iK<@1nFc4808=M;PD0PehZ0P24Gb/00`25H2`0QV4]08QT<00708QT<0<0RV@e0P2;ICH3
08aV=`0608US=P2:I3D0RfDf08aV=@2=J3@0SfXe0P2@Jc@2095W=@06099X=P2CJCL0UF/i09I/>P2G
KC/0V6hl0`2DKc/309E`?080UW4m00@0Ug8n09Qc?`2HLcl0V7<o0P2IM40209Ye@@80VG@o00@0VWE0
09]f@@2LMd80W7M20P2MN4<209ag@`0309ehA02NNDD0WgY60080X7]700D0XGa80:1kA`2PNdL0XGa8
0:9mB@020:=nBP80Y7m;0P2WOTX20:ImB@050:MnBP2YP4`0Zh9>0:b3C`2VPD`00`2WPTd20:R3CP80
ZHA?1@2/Pdl30:f4D080ZXE>00@0ZhI?0:b7D02/Qe00[HQA0P2^RE820:n9F0040:n:EP2_RUD0[hYE
0:n:D`80[h]A00<0[HA>0:j5C`2`Qe400P2bRE<00`2cRU@0/XUC0;:9D`080;68E080/8YI00@0/8]G
0;2;EP2`ReH0/8]D0P2`S5820;>:DP040;>:E02cRUH0/hYF0;>9E`80/hUI0`2_RUD20;2;EP@0/HaG
0P2eRe/0102eReT0]8]G0;B;E`2cRU@20;>:DPP0/8]G0`2_REX50;2:F`P0]H]I0P2]S5L00`2_ReL0
/HaH0;>;F0020;F;F@040;J:F@2dReL0]8]G0;B;E`80/hYF0`2bRED20;:<F`040;:=F@2bSEP0/XeH
0;:=EP80/XiD00P0/8]F0;6<E`2bSEP0/hiI0;:=F02aS5L0[hYE0:j9E080[hYE00L0[XUD0:f8D`2^
RE@0[hYE0;2;EP2aS5L0/8]G00<0[hYF0P2^RED20:f8E0P0/8]G202bRED20:b7D`<0[HQD0`2^RED8
0:f8D`P0[XUD202`Qe420:f8D@040:f8D`2/Qe<0[8IE0:^5EP80ZhEH0P2/Pdl0102]Q500[XEA0:n6
DP2_QU820;27D`@0ZhI?0P2/Qe030:f8D@<0[hIB0`2^QE420:f4D080[XE=00@0[XE?0:f4D02]Q500
[89@0P2/PU830:j4DP80[H=A0`2/PU001P2]PUL0[H9E0:f2E@2]Pe<0[H=A0:f4D080[HA>202^QE43
0:V4D080ZXEA0`2[QU820:b7D`80ZhIB0`2ZQE400`2YQ500[HA>0:f4CP060:f4CP80Zh5?0P2/PU03
0:f3D@030:j4DP2[PTh0Zh9>00H0Zh9>202YQ4l80:Z5D0<0ZhIB0P2ZQE430:V4D0P0Zh5?202/Pdl3
0:^1C`80ZX1>0`2YOdd20:V0C080ZX5=0P2[PTh:0:b3C`T0Zh9>00H0ZhQB0:b7DP2[QU40[8A@0:f4
D02]PTl20:j0CP80[HA@0`2/Pdl30:^2CP<0ZX5=0P2[PTh30:b3C`/0Zh9>0`2/Pdl20:f4D0<0[XEA
0P2]Q5030:b3C`P0[HA@0`2_Q4l20:j3CP<0[H9=00<0[HA@0:b3C`2[PTh00P2ZPDd0102[PTh0[8=?
0:f4D02/Pdl20:f4D080[XEA0P2]Q500102/Pdl0[HA<0:f4C02]Q4h20:f4D0030:f3D@2]Pe<0[H=C
00P0[XEA0P2]Q5030:b3C`/0Zh9>0P2ZPDd00`2[PTh0[8=?0:f4D0020:j5D@030:n6DP2[PTh0Zh9>
00H0Zh9>0P2ZPDd30:QoB`040:Z1C@2/Pdl0[HA@0:j5D@80[HA@0P2/Pdl20:f4D0050:j5D@2ZP500
ZX1@0:UoC@2YP4`00P2XOd/00`2XOdT0Z7m70:MnAP030:Z1C@80Zh9>0`2/Pdl20:b3C@80Zh9<0P2Z
PD/20:V0BP80Ygi:00@0Z7m;0:V0C02ZPDd0ZX5=0P2[PTh20:b3C`80Zh9>0P2ZPDd20:V0C0P0ZX5=
0P2YOdd20:Z0CP80Zh5?0P2/PU080:V0BPP0ZH1<0P2/Pdl20:^2CP80ZX5=0P2YP4`40:QoB@<0ZH1:
00@0ZX5;0:f4D02/Pdl0ZX5=0P2YP4`00`2ZPDd0[8=?0:f4D0020:QoB`<0ZH1<0`2ZPDd80:^1C`03
0:ImB@2XOd/0ZH1<00<0Zh9>00D0ZH1<0:QoB`2VP4l0YX1?0:J1C@020:J1C0030:J1BP2VPTP0YX98
00@0Zh9>102ZPDd80:V0C0<0Ygi:0P2XOd/30:V0C080Zh5?0P2ZP4h00`2YOdd0Z7i<0:QnC0040:Mm
B`<0YWa:00<0Z7i<0:UoC@2ZP4h00P2XNTP00`2VNdP0YWe90:EmB@020:AoBP030:>0BP2TOd/0Y7m;
00H0Y7m;0P2XOd/20:MnBP0A0:ImB@2UO4P0Y7]70:AkA`2ONd40X7a20:1kA02PNdH0XGa70:5lB02Q
NdX0XWa;0:V0C02XOd/0Ygi:0:ImB@2UO4P00P2VODT01`2WOTX0Xge@0:=mCP2SODh0Xge<0:9mB@2R
ODP00P2RODH0102VO4X0YG]90:AjB02RN4H20:5gA@80XWQ6102UO4P0102SNTH0XGQ409ie@@2MM402
0:9gA080XgQ500@0Y7U60:EjA`2VNdP0YW]80`2TNdL20:=jAP<0XWU500@0XWQ60:5gA@2QMdD0XGM5
0`2PMT@02P2OMD<0UG@o09Ie@02IMD40VgI209mgA02RN4H0XgU70:AhA`2PMT@709me@`@0XGM5102P
MT@0202LMd<0VgI209Ye@@2IM400V7<o09Ud@02KMT80W7M30`2MLTD209aaA0<0Vg1300@0VW0n09]a
?`2KLCl0Vg4o0`2LLT000`2MLd40VWE109Ye@@0209Ud@080V7<o0`2GLSh309]a?`<0VW0n0P2IKcd2
09U`?0@0VW4m0P2IL3`0102HLcl0Ug8n09Mb?P2GLSh309Ia?@0309E`?02IM400VGA000H0VGA0202L
Md<00`2GLD80V79309YdA@0309]eAPX0VWA50P2JMD4209Ud@080V7<o0P2GLSh809Ma@P<0VG=4:ooo
ool002[ooooo0P2>HcP208eR=`80S64f0P2;H3D8095T>P80S5le0P2=H3H208iQ=`80Sf8h202>ICT0
1P2;IST0SFLj08eW>P2@Ic/0TFHk099U>`80Tf@j0`2BIST209=W>P<0TVHi202CIcX2095T>P80TVDk
0P2CIS`209AW?@80TFDh00@0TVHi09=W>P2DJ3/0UFTl0P2FJSd909EY?0<0U6Pi0`2CIcP2099V=`80
U6Pg0P2CIcH0102DJ3L0UVXi09Q/>`2JKSd309IZ?@80UFTl0`2DJ3/809E[>@80UVXi0P2GJcX209Q/
>`X0VFdl0`2HK3/309U]?080VVhm00<0WG5009a`?`2KKch00P2IKC`00`2KKch0W70o09ea@00209ab
@0H0Vg4o202MLSl409Y_?00409]`?@2NLd00XGI30:9gA0P0Vfln0P2SLd<00`2RLT80XG510:1`@002
09m_?`0509i^?P2LL3l0WG5009ea@02NLT40102OLd8309md@@80X7E20`2QMT<80:1d@`0309eb?`2O
M440XGI30080XgQ500<0XGI309md@@2MLSl00P2RMTL0102QMD@0XGI30:5f@`2QMT420:9g@0040:Ej
A`2TNDH0Y7U60:=hA@<0XWM40P2QMT<40:1e@P@0XGI300<0Y7U60:9gA02QMT<00P2PMD800`2RMd@0
Y7U60:IkB0020:AiAP80XgQ50P2RMd@20:5f@`/0Y7U600<0YGY70:IkB02VNdP00P2WO4T30:UiB0@0
ZWY900T0ZGU80:ElAP2VODL0Ygi80:QoB@2WOTP0YWe70:AkA@2RND<0202SMdH0202WO4L0YW]60:Ej
A@2SN4<0XGI109md?`2NLch0WG8m0`2OM44209ic@0<0WG8o0P2LLcl209]b?P@0VW4m00P0WWA209ab
@02HKS`0UF/i09AZ>02EJcT0V6hl09U_?@P0Uf`o0P2FJ3L00`2DJ3L0TVPf095Y=P0208iY=@0408eY
=@2=IcP0SFLh08aV=`80RfDf00<0RV@e08US=029Hc@00P2:I3D208US=0@0R68c1029HcH208QR=@80
Qf4d0`25H3<208AO<P<0Peha00H0Q60`08=O;`22GC00PE``081K<@1oFC8207iH<`0307eG<P1mFS00
OEX`00H0OEX`00P0PEXc07mH<@1mEc00NEH^07QG;P1hF2l0NET`07QK<@80N5D]0P1gE2`207IC:`80
ME8Z00<0Le4[07AB;01eDbd00P1fE2h01@1eDbd0M58/07=A:`1aDBX0LU8[0080Le</00@0LU8[071@
:@1^CRL0KDdV101dD2h207=?;@80LTh/0P1`Cb`206m>:`0?06i=:P1]C2T0KD`Y06e<:@1aDbl0Ke4]
06e<:@1ZBBH0J4LT06U7901ZB2D0JdTV06I89P1WBBL0JT`Z0080K4h/00<0JT`Z06M99`1VB2H0201Y
BbL00`1WBBL0J4XX06U;:@0206Y<:P0606U;:@1XBRP0IdTW06Y89@1[BBH0K4XW0P1]BbP0101/BRL0
JTPU06U7901SBbL206A:9`0306I99`1WBBL0JDPW0080JTLW0100JTTX06U89`1WARD0ITDT06M69@1Y
B2L0K4/Z06m>;@1TAR@0IDLU06I89P1WBBL0ITPV06E79@1SAB<0HD<Q0`1TABH206=49@<0HT<T00<0
IDLU06=58`1RA2800P1Q@b40101RA280HdDS06E79@1WBBL206I89P0306E79@1TAR@0HdDS0080HT@R
0P1P@R0306538@@0HT@R0`1SA2D2069390<0HD8S0100ITDV06E49@1R@b@0H4<S05i48`1NAR@0GTLU
05m89P1LA280GdDT06169@1SARH0I4DV06E49@1U@R@0Hd0R0P1SARH206959@050654901P@b<0H4<S
06138`1Q@bL00P1P@RH305m19@80H48V00X0GClU05i0901Q@bL0HdHX06A79`1TAbD0HTHQ0655801P
@b<0Gd8R0`1N@B401P1P@b<0HD@T06=69P1VBBT0I4LW06=69P<0HD@T00@0HTDU06=69P1VB2H0ITPV
0`1UAbD00`1VB2H0J4XX06U;:@0806I89PP0J4XT0`1ZBBH406]:9`80K4/X101]C2T306i=:PP0L50Y
00@0LDhV079?9`1bCbL0LTlW0P1cD2P207AA:@80Me8V0P1hDbL0101iE2P0NUDY07YE:@1kERX407ME
:080N5HY00P0NELZ07YH:`1iER`0NEH/07YG;@1kF2h0O5T_07eJ<080OU/a2020G2`208=O;@07089N
;021GB/0PEd[085M:`23Gbd0Q60^08EQ;`0808MS<@<0RF<d0P2:I3D308]U=P0608UR=`2:I3L0RfDh
08aV=`2=IcH0SVTe0P2?JSD01P2@IS@0TFLe099X=P2CJCL0U6Xh09E[>@80UV`j202DKc/409Mb?P80
V7<o0P2IM40309Ud?`0309Ye@02KMT40VgI10080W7M20P2KMT8209ag@`0509ehA02NNDD0WgY609mj
AP2NNDD00P2ONTH00`2PNdL0XGa80:9mB@020:=nBP80YGa80P2VODT0102WOTX0Z7m;0:V0C02ZPDd4
0:J1C080Yh9=0P2XPdh20:^2CP@0[8=?0P2]Q500202XPdh0ZHA?0:Z5D02[QU40[8MB0:f8D`2^RE@0
[hYE0P2^R5L0102^RED0[XUD0:j9E02^RE820:j:D0060:f4D02^QE40[hIB0;68E02bRED0/hYF0P2d
ReL80;:9E@80/8YI00@0/8]G0;2;EP2`ReH0/8]D0P2`S5820;68D0040;68DP2aR5@0/HQD0;67E@80
/HMG0`2aS5P60;:=F@80]8YJ00@0]8YH0;B;E`2cRUH0/hYD0P2cRU880;2;E`80[hUJ102`RU/20;6;
G0P0]H]I0P2]S5L00`2_ReL0/8]G0;>;F0020;B:F0030;F9F02cRUH0/hYF0080/hYF102bRED20;:<
F`040;:=F@2bSEP0/XeH0;:=EP80/XiD00<0/HaG0;:=F02cSUT00P2cSUT00`2aS5L0[hYE0:j9E006
0:f8D`80[XUD0P2`ReL30:n:EP<0[XUE202`ReL80;:9E@050:^6DP2/Qe<0[8MC0:f8E02^RED00P2_
RUH00`2`ReL0[HQC0:f8D`060:f8D`P0[XUD202`Qe<0102]R5<0[HQD0:f8E02/Qe<20:b6E@80ZhED
0P2[PT`01P2/Pdd0[XE?0:n6D02`Qe40/HQB0;:9D`T0[HQC0P2_QU860:j5D@80[hI>00@0[XE?0:f4
D02]Q500[89@0P2[PE480:f3D@060:f2E`2]PUD0[H9E0:f3D`2]Pe40[HA@0P2]Q4h80:f4D0<0ZHA@
0P2ZQE460:^6DP<0ZXEA0P2YQ5080:f4CP<0Zh9>0P2/Pdl30:f4D0P0ZX5=2P2YQ4l40:Z5D080ZhIA
0`2[QU820:Z5D@<0ZHA@202/PU080:b3C`<0Zh9>0`2ZPDd40:V0C080ZX5=0P2[PTh:0:b3C`<0ZX5=
0P2[PTh02P2/Pdl0[HA@0:f4D02]Q500[8UC0:f8D`2/Qe80[HEA0:b3C`2/PDh20:eoC@80[XEA00<0
[HA@0:b3C`2[PTh00P2ZPDd0102YP4`0ZX5=0:Z1C@2ZPDd30:^2CP80[8=?2`2[PTh30:b3Ca80[HA@
202^Pdh00`2^QE40[HA@0:f4D0070:b3C`@0[XEA0P2/Pdl20:f4C0040:f4CP2]Q500[HA@0:f3D@80
[H=C202_QU820:f4D0<0[8=?2`2[PTh00`2ZPDd0Zh9>0:^2CP020:b3C`80[HA@00<0[XEA0:b2D02/
PU001P2/PU00202[PTh0ZX5=0:V0C02XOd/0ZH1<0:Z1C@2/Pdl0[HA@0P2^QE440:b3C`80[XEA0P2Z
P5001@2ZP4h0ZH1<0:V0C02YP4`0Z7m90080Z7m70`2ZPDd30:^2CP80[8=?0P2/Pdd20:^2C080ZX5;
0P2YP4X20:MnBP80Z7m;0P2YP4`20:Z1C@80[8=?0P2[PTh20:Z1C@80ZH1<202ZPDd20:UoC@80ZX1>
0P2[PDl20:b2D0<0ZX5=102YP4`00`2XOd/0ZH1<0:V0C0060:V0C080[8=?0P2[PTh20:Z1C@80ZH1<
0P2WOTX0102XOd/0ZH1<0:V0C02ZPDd20:^2CP030:f4D02[PTh0ZX5=0080ZH1<00<0ZX5=0:^2CP2]
Q5001P2YP4`20:Z1C@P0Zh5?00<0YGa80:MnBP2YP4`00`2[PTh20:Z1C@80YX1?00@0YX5=0:J1C02V
PD`0YX5:0P2VPTP01@2]Q500[8=?0:b3C`2[PTh0ZX5=0080ZH1<2@2XOd/30:MnBP80Z7m;0`2YP4`0
1@2]Pe40[89@0:^1C`2ZP4h0ZGm=0080Yge;1P2VO4X0102WOD/0Z7i<0:QnC02YOdd20:QjB0060:Ml
B@2VODT0YWi:0:AoBP2UP4/0Y85;202TOd/20:V0C0040:QoB`2WOTX0YWe90:ElB080Y7]70P2QOD<0
102QO4D0XGa70:5lA`2QO4P20:5kBP030:V0C02XOd/0YGa80080XgY600@0YGa80:MnBP2YP4`0XG]>
0P2RO4d02`2RO4/0Xgi:0:=nB@2SOTL0Y7m80:MmB`2VO4X0YG]90:=iA`2RN4H0XGM50080X7I40P2T
NdL20:=jAP040:9iA@2QN4@0X7M309mf@P80X7E200<0XGI30:9gA02SN4D00P2TNDH0102UNTL0Y7]7
0:AkA`2TNdL20:=jAP<0XWU5102QMdD40:1fA080UgI100<0VWI209ag@`2OMd@00P2QMdD00`2SMdH0
WWA209id@P0309me@`<0X7I400D0XgU70:9hAP2RN4H0XGM50:1fA00209me@`0409id@P2MN4@0W7M3
09Ye@@80VGA000<0VWE109]f@P2LMd<00P2NM4@209ec@`80W7920P2KLD4409]a?`@0W7900P2JMD42
09Ud@080V7<o0`2GLSh209]a?`H0VW0n0P2IL3`409]b?P80VG0l202GLSh809Ud@0P0VWE10P2JM4D0
0`2KMDH0W7I709afA`0309afA`P0VgE60P2JMD4209Ud@080V7<o0P2GLSh809E_@0<0VG=4:oooool0
02[ooooo0P2>HcP208eR=`80S64f0P2;H3D8095T>P80S5le0P2=H3H208iQ=`80Sf8h202?I3T01P2=
J3/0SVPk08eW>P2?ISX0T6Dj095T>P80Tf@j0`2CIcX2099V>@<0TfLj202CIcP4099U>`@0TfHl0P2B
IST0102CIcX0U6Pk09AX>`2EJC`209IZ?@T0UFTl0`2DJ3L309=W=P80TVHe00<0UFTh09AX=`2CIcH0
0P2CIcH00`2EJCP0Uf/j09U]?00309IZ?@80UFTl0`2DJ3/809E[>@80UVXi0P2GJcX209Q/>`X0VFdl
0`2HK3/309U]?080VVhm00<0Wg5009i`?`2MKch00P2KKC`00`2MKch0WW0o09ma@00209]a?`H0W790
202MLSl209]`?@80VVll00@0Vg0m09eb?`2PMD80XGI3202KKch20:=c@`030:9b@P2QLD40X7100080
Wflo00<0WVhn09ea@02MLD000`2MLD000`2NLT40Wg=209mc@P0209md@@80X7E20P2QMT<20:9gA0P0
XGE600<0WG8o09md@@2QMT<00P2SN4D00`2QMT<0WgA109eb?`020:5eAP040:9fA@2RMd@0XWM40:9g
@P80XGHo0P2UNTL00`2TNDH0XgQ50:9gA0030:5f@`<0X7E20P2QMT<20:9gA0@0XgQ500H0XWM40:5f
@`2RMd@0XgQ50:EjA`2VNdP30:AiAP80XgQ50`2RMd@90:AiAP@0YGY70`2VNdP30:YjB@@0ZGU800T0
ZWY90:ElAP2VODL0Ygi80:QoB@2WOTP0YWe70:AkA@2RND<0202SMdH0202VNdH0YGY50:AiA02RMd80
X7E009ic?P2MLSd0W74l0P2OM44209ic@080WG8o0P2LLCh209]b?P<0VW4m0`2IL3`0202LLT00VW0n
09Q^?02EJcT0U6Xh09E[>@2FK3X0Ufdk202FJch209EW=P0309=W=P2AIcD0T6Pe0080SFPd00L0S6Pd
08eW>02=IcP0S6Hg08]U=P2:I3D0RF<d0080R68c0P29Hc@308QR<`<0Qf4b0`28HSD208MQ=0<0QV0c
0`24Gc8208=N<@<0PUd`0P22GRh01021G2l0P5/_07iI;`1mEc0307aF<@P0O5T_00P0P5Tb07mH<@1l
ERl0NEH^07MF;@1fERd0MeL^07II;`80Me@/101fDb/207EB:P03075A:P1bDR/0Le</0080M5@]00D0
Le</079B:`1aDBX0L50Y075A:P02079B:`04075A:P1_CbP0KDdV06a<9@<0Le4^0P1bD2d3075?;003
06m>:`1^CBX0KTdZ0080KTdZ0`1]C2T0101dDRl0LDl/06i<:@1YB2D206M68`0506M99@1XBRH0I4LU
06I99`1XBbT00P1ZCB/00`1XBbT0ITTW06A79@0806Q:9P0306I89P1WBBL0JD/Y0080JT`Z00H0JD/Y
06M99`1VB2H0J4LT06U89@1[BRL206a;:00406]:9`1ZBBH0JDPU06=;9`80I4XW00<0ITTW06M99`1Y
B2L00P1ZAbL0401[BRT0JDPW06M69@1VAB@0IdHU06Y9:01]C2/0Kdh]06A6901UAbD0ITPV06M99`1V
B2H0IDLU06=58`1Q@b4406A59P@0Hd@U00<0IDLU06=58`1RA2800P1Q@b400`1RA280HdDS06E79@02
06M99`0306I89P1UAbD0I4HT0080HdDS00<0HT@R0612801Q@b400P1Q@b4206948P<0HdDS0`1SA2D2
069390<0HD8S0140ITDV06E49@1Q@R<0Gd8R05e38P1MAB<0GTLU05m89P1LA280GT@S05m5901SARH0
I4DV06A3901T@B<0Hd0R06959@04065490<0H4<S0P1O@BD606129P0605do9@1N@2@0H48V06959`1S
ARH0HdHT0P1RAR400`1O@R80GT4Q05e0800205e0800605m28P1P@b<0HTDU06E8:P1TAbT0HTDW0`1P
@bD01@1QA2H0HTDW06E89P1TAbD0HdHT0080HTDS00<0I4LU06I99`1XBbT0201UAbD806I89080J4LT
0P1YB2D00`1ZBBH0JdXW06]:9`0406]:9`0306a;:01]C2T0KD`Y0080KTdZ201_CbP2071=9@<0LDhV
0`1bCbL01P1eD2H0MU4W07IA9`1gDRP0N5<Y07UD:P80NUD[00@0ME8X07IC:@1gE2X0Me@Z101hEB/2
07UF;00407YG;@1kF2h0NeP^07aI;`80OEX`201oFb/208=O;`06089N;P20G2`0P5`/081L;022GRh0
Q60`2@25HC4308QR<`80RF<d0`2:I3D02@2:HcX0RV<h08]T>@2;ICP0S6Hg08eW=P2=J3@0SVTe091V
=002095W=@03099X=P2CJCL0TfTg0080U6Xh202CKSX309Ia?@<0Ug8n0P2HLcl00`2HLch0VG@o09Ud
?`0209Ud?`<0VWE00P2IM400102JMD40VgI209ag@`2MN4@209iiA@80WGQ400<0WWU509mjAP2PNdL0
0P2QO4P01P2RODT0XgY60:AkA`2UO4P0YWe90:MnBP<0Z7m;0`2UP4/30:J1C080Yh9=0P2ZPDd20:^2
CP80[8=?0P2]Q5020:R3CP040:V4C`2ZQE00[8MB0:f8D`80[XUD0P2]QeH0102]R5@0[HQC0:f8D`2]
R5420:f9C`80[XEA00H0[hIB0;27D`2aR5@0/hYF0;B;E`2eS5P80;:9E@80/8YI00@0/8]G0;2;EP2`
ReH0/8]D0P2`S5820;68D0040;68DP2aR5@0/HQD0;67E@80/HMG102cSE`50;:<F`80/hUI00@0/hUG
0;>:EP2cRUH0/hYD0P2cRU880;2;E`80[hUJ0P2`RU/20;6;G080/XaM202eReT20:f<E`030:n;E`2`
ReL0/XYG0080/hUG00<0]8QG0;>:EP2cRUH01P2cRUH20;:<F`040;:=F@2bSEP0/XeH0;:=EP80/XiD
00P0/HaG0;:=F02cSUT0]8mJ0;>>F@2bSEP0/8]F0:n:E@H0[HQC0P2/Qe830;2;E`<0[hYF0P2^RED8
0;2;E`P0/XUE0P2/Qe<0102]R5@0[XUE0:j9E@2_RUH20;2;E`P0[HQC202^RE@80:n6DP80[XQG0P2]
QeH0102]R5@0[8MC0:b7D`2/Qe820:^2BP060:b3B`2^QDd0[hI>0;27C`2aR500/XUA2@2]R5<60:j5
D@80[hIB0P2_QTh0102^QDl0[HA@0:f4D02/PU020:^1D@P0[H=A00H0[H9G0:f2E@2]PUD0[H=C0:f3
D@2]Q5020:f4CPP0[HA@0`2YQ5020:Z5D@D0ZhIB0`2ZQE430:V4D0P0[HA>0P2ZPDd20:^2CP80[8=?
0P2]Q5080:Z1C@P0ZHA?00<0Z8=>0:V4C`2YQ4l00P2ZQE020:^6D@040:b7DP2[QU80ZhIB0:^6DP80
ZXEA0`2YQ5080:b2D0X0[8=?0`2[PTh30:Z1C@80ZH1<0P2ZPDd20:^2CPX0[8=?00<0ZH1<0:Z1C@2[
PTh00P2[PTh20:f4D0080:j5D@2_QU80[8UC0:f8D`2/Qe80[HEA0:b3C`2/PDh20:eoC@80[XEA00<0
[HA@0:b3C`2[PTh00P2ZPDd30:V0C0<0ZX5=3P2[PTh30:b3Ca80[HA@202^Pdh30:n6DP80[XEA00H0
[HA@0:b3C`2[PTh0Zh9>0:b3C`2^QE420:n6DP030:j5D@2/Pdl0Zh9>0080[HA<00@0[HA>0:f4D02]
Q500[H=A0P2]Pe<80:n6DP80[HA@0`2/Pdl30:^2CPP0ZX5=102[PTh40:b3C`P0[89B00<0Zh9>0:Z1
C@2YP4`00P2YP4`01P2[PTh0[HA@0:j5D@2_QU80[XEA0:b3C`80Zh9>00<0[8=?0:j5D@2_QU800P2[
PE401@2ZP4h0ZX5=0:V0C02YP4`0ZH1:0080Z7m70P2YP4`30:Z1C@<0Zh9>0P2/Pdd20:^2C080ZX5;
0P2YP4X30:QoB`<0ZH1<0P2ZPDd20:b3C`80Zh9>0P2ZPDd20:V0C0P0Zh9>0P2YOdd20:Z0CP80Zh5?
0P2/PU020:^2CP80ZX5=00@0ZH1<0:QoB`2XOd/0Z7m;202YP4`20:b3C`80Zh9>0P2ZPDd20:V0C005
0:MnBP2XOd/0Z7m;0:V0C02ZPDd00P2[PTh20:b3C`070:^2CP2ZPDd0Z7m;0:QoB`2ZPDd0Zh9>0:b3
C`020:Z1C@H0ZH1<202[PDl00`2UO4P0Ygi:0:V0C0030:^2CP80ZX5=0P2WPE00102WPTh0Yh9=0:N2
C@2WPT/20:N3B@050:f4D02/Pdl0[8=?0:^2CP2ZPDd00P2YP4`90:QoB`<0Ygi:0P2XOd/30:V0C005
0:f3D@2/PU00Zh5?0:Z0CP2YOdd00P2WOD/20:IlBP80YG]900<0YWa:0:MmB`2WOD/00`2WOD/20:Uk
B@030:MlB@2WOTX0YWi:0080YH1;00<0Y85;0:AoB`2TOd/01P2TOd/20:V0C0040:QoB`2WOTX0Ygi:
0:ImB@80YGa80P2ROT@0102RODH0XWe80:5lA`2QO4P20:5kBP030:QoB`2VODT0Y7]70080XWU500@0
Y7]70:MnBP2XOd/0XG]>0P2RO4d01@2RO4/0Xgi:0:=nB@2SOTL0Y7m80080YWa:00H0YG]90:AjB02S
NDL0XGM50:1fA02OMD<30:1g@`030:5hA02RNDD0XgY60080Y7]70P2PMD820:5f@`040:9gA02SN4D0
Y7U60:AiAP<0Y7]70P2SNTH30:9iA@@0X7I4102QMdD0202LNdH0VgY509eiA@2MN4@0WWI309id@P2M
Ld40WW910P2NM48309me@`<0X7I400D0XgU70:9hAP2RN4H0XGM50:1fA00209me@`0709id@P2ONTH0
WGQ409]f@P2JMD40VGA009Ye@@0209]f@P<0WWA20P2MLd4709ab@0@0Vg4o0P2JMD4209Ud@080V7<o
0`2GLSh609Y`?P80Vg4o00<0V6lk09Ya?@2KLSh00P2MM4000`2KLSh0VW4m09Q_>`0409Mb?P@0V7<o
202IM40809Mb?P@0VgE60P2LMTL209egB0P0VgE60P2JMD4209Ud@080V7<o0P2GLSh809E_@0<0V793
:oooool002[ooooo0P2>HcP208eR=`80S64f0P2;H3D8091S>@80S5le0P2=H3H208iQ=`80Sf8h202A
I3X01P2?JSd0SfTl08eW>P2>ICT0Sf@i091S>@80Tf@j0P2DJ3/0102CIcX0TVHi099V>@2CIcX209AX
>`P0TfLf102BIC/409=V?080TVHi00<0TfLj09AX>`2EJC`00P2FJSd00`2GJch0U6Pk09AX>`0709AX
>`<0UFXg0`2DJCH209=X=@0809EY>02DJ3L0TfLf099V=@2CIcH0U6Pg09IZ>@2GJcX309IZ?@80UFTl
0`2DJ3/809E[>@80UVXi0P2GJcX209Q/>`80VFdl2`2HK3/309U]?080VVhm00<0X71009m_?`2NKSh0
0P2LK3`00`2NKSh0Wflo0:1`@00209]a?`<0W7900`2MLd4909eb?`0709aa?P2KL3d0VVll09]`?@2L
LCh0WW=009md@@0809]_?P80XW920`2QLD430:1`@080WG500`2LL3l00`2MLD00Wg=20:1d@`030:1e
@P80XGI30`2RMd@80:5eB00309md@@2PMD80XGI300<0XGI300D0X7E209md@@2PM4D0XGE60:9fA@02
0:=hA@040:9g@P2QMSl0X7Dn0:EjA`80Y7U600@0XgQ50:9gA02RMd@0XWM4102QMT<00`2RMd@0XgQ5
0:AiAP020:EjA`030:IkB02SN4D0XgQ500<0XgQ500@0Y7U60:EjA`2UNTL0YGY70`2TNDH20:=hA@80
XWM4202TNDH80:EjA`030:alB`2[NdX0ZWY900<0Z7Q700X0ZGU80:YjB@2UO4H0YWe70:MnB02XOdT0
Ygi80:ImA`2TNdD0XWU3202RMTD01P2TND@0XgQ30:9g@P2QMT40Wg@o09ic?P80WG8m0`2NLd0209eb
?`<0W74n0`2JLCd209U`?0<0V6lk00H0VFlm09Q^?02HKS`0Ufdk09I/>P2EJcT209AZ>0P0UFXm0P2D
ISD00`2BISD0T6Hd08mW=00208aW<`0308]W<`2<ISL0S6Hg0080RfDf00<0RV@e08US=028HS<01028
HS<208MQ<P<0QV0a00@0QV0c08EO<P25Gc80QElb0P24GS4208=M<0<0Peha0P22GC03085L;`80P5`/
00@0OeX]07iI;@1mF2h0O5H_0`1lES4207aI;`0407]H;P1jEbd0NUL]07]H;P80O5T_00P0OePa07iG
<01kEBh0Me@/07ED:`1dE2/0MED/07AG;@D0MU<[0`1eDRX00`1^DBT0Ke8Z071C:`02075D;006071C
:`1_DRX0KU4Y06i>9`1_CbP0L50Y0P1aDBX0101_CbP0KThW06a<9@1aD2d3071?;080Kdh[0P1^CBX8
06e<:@0807=<:`1`C2X0KTXX06]99P1YB2D0ITPT06E9901VBRD206E89P0406I99`1WBRP0IdXX06I9
9`80IDPV201XBRH00`1TAR@0ITPV06Q::00206Y<:P0606Q::01VB2H0I4HT06E78`1WBBD0J4XV0`1Z
C2P206Q:9P0606=;9`1TBRL0I4XW06I99`1WBBL0JDPW0P1ZAbL206U89`<0J4LV00/0JDPW06]::@1[
BRT0I4HT06E79@1VB2H0IdTW06I89P1UAbD0HdDS06538@0306=49@80I4DV0`1UARL00`1VB2H0I4HT
06=58`0206948P0406=58`1TAR@0ITPV06Q::080IdTW00<0ITPV06E79@1TAR@00P1SAB<306948P80
HdDS101TAR@306=49@80HT<T0`1Q@R<0401VABH0ID@U06118P1M@200Fd4P05a48P1NAbD0GdPV05a4
8P1NA2<0GdDT06959@1SA2D0I4<T06A18`1S@28806138`0305do8`1N@2@0H48V00<0HD<W0P1P@RH0
1P1M?bD0GT0T05m19@1P@bD0HD@T06958`80HTHQ0P1O@R8305e0800605m28P1QA2@0HTDU06A6:P1S
ABT0HD<W0`1O@BD206539`0806E89P1TAbD0HD@R06138@1QA280HdHT06I99`1XBbT806A59PP0IDLU
0P1WAR<206Q7900406U89@1ZBBH0JdXW06]:9`80JDPU00<0JTTV06]:9`1/BbP00P1]C2T00`1^CBX0
KThW06i>9`0606i>9`<0L4dU0P1aCRH3079?9`80MDlX0P1fD2T02@1gDBX0N58[07UC;01iDb`0M54Y
07EB:P1fDb/0Me@/07QE;@0207MD;00707IC:`1hEB/0NEH/07UF;01jEbd0NeP^07aI;`0207eJ<0P0
O5XZ0P21Gc401`20GS00OU`^07aJ;01mFbd0Oed_089P<P24HS@02024Gc8308MQ<P80R68c0`29Hc@0
202:Hc`0RV<j08]T>`2;I3T0S6Hi08aV=`2<ISD0SFLf0P2@IS@2095W=@80TVPf0P2CJCL309=^>P<0
TVdi0P2AK3P309E`?080UW4m0`2GLSh709Qc?P0609Ud?`2HLcl0V7<o09Ud@02JMD40VgI20P2LMd<0
0`2MN4@0W7M309ag@`0209ehA00809iiA@2ONTH0X7]70:1kA`2RNDD0XgY60:ElB02VODT40:MnBP<0
Y7m:0P2UP4/30:J1C080ZH1<00@0ZX5=0:^2CP2/Pdl0[8=?0P2]Q5001@2XPdl0ZHA@0:V4D02ZQE40
ZhIB0080[8MC00@0[HQD0:b6E@2/QUD0[8MC0P2/Qe80102/Qe00[8Q>0:b8CP2`QU@30:n5D`040;26
E02aQeD0/hUG0;B:F0P0/hYF0P2`RUT0102`ReL0/8]F0;2;EP2`Re@20;2<DP80/hYB00@0/hYD0;>:
EP2cRUH0/hUG0P2cRET30;>=GP80/XaM102aRe`0202aQeL0/XQH0;:8EP2bRED0/hYF0;>:E02cRU80
]8]C202`ReL20:n9FP80/8YK00@0/H]L0;:<G@2cSEh0/heN202eReT01@2^SEP0[HaG0:n;E`2`ReL0
/HUF0080/XQF00<0/XIE0;>:EP2dReL00P2dReL30;F<F0040;J=F@2bS5/0/XaK0;:=F@80/XeH00<0
/XeF0;:>E02bSU@00P2bSEP30;B?FP050;:=F02`ReH0[hYE0:f8D`2^RE@00`2_RUD00`2]R5<0[8MB
0:^6D@020;6<F080/8]G0`2_RUH00`2^RED0/8]G0;2;E`060;2;E`P0/XUE00@0[HQD0:j9E@2^RED0
[XUE102_RUH@0:f8D`P0[hEC0P2^R5/0102^R5T0[HMF0:f8E02/Qe820:b7D080[8A900@0[HE:0:j6
B`2_Qd`0[hM<0P2`R4d40:f8E080[8MC0`2[QU820:f4D0<0[XEA0`2_QU820:j5C@040:j5C`2]Q500
[HA@0:b2D080[89B0`2/PU020:f3D@<0[XAB00H0[H9G0:f2E@2]PUD0[H=C0:f3D@2]Q5020:f4CPP0
[8=?0`2YQ5020:Z5D@@0ZhIB0`2ZQE420:V4D080Z8=?202]Q4h30:Z1B`80Zh9<0`2/Pdd80:^2CPX0
Z8=>00@0ZHA?0:Z5D02ZQE00ZhIA0P2/Qe830:^6DP80ZXEA0`2YQ5080:b2D0P0[8=?0`2/Pdd20:^2
C0<0ZX5;0P2YP4`20:Z1C@80Zh9>2P2/Pdl00`2ZPDd0Zh9>0:^2CP020:b3C`0:0:f4D02^QE40[XEA
0:j5D@2[R580[8MB0:^6D@2/Q500[HA@0:f2C`80[X1>0P2]Q5030:b3C`<0Zh9>0`2YP4`20:Z1C@h0
Zh9>0`2/Pdl20:f4D0<0[8=?0P2]Q5030:j5D@P0[HA@0`2]PTd20:j3CP<0[hA?00/0[hIB0;27D`2`
Qe<0/8MC0:n6DP2^QE40[8=?0:^2CP2ZPDd0[8=?0:j5D@020;27D`030:j5D@2/Pdl0ZX5=0080[HA<
00@0[HA>0:f4D02]Q500[H=A0P2]Pe<80:j5D@80[HA@0`2/Pdl30:^2CPP0ZX5=202[PTh80:b1E00;
0:b3C`2[PTh0ZX5=0:V0C02ZPDd0Zh9>0:f4D02^QE40/8MC0:j5D@2/Pdl00P2ZPDd00`2/Pdl0[XEA
0;27D`020:^1D@050:^1C`2ZPDd0ZX5=0:Z1C@2YP4X00P2YP4P30:V0C080ZX5=0`2[PTh20:b3C@80
Zh9<0P2ZPD/20:V0BPD0ZX5=0`2[PTh20:b3C`80Zh9>0P2ZPDd20:V0C0P0Zh9>0P2YOdd20:Z0CP80
Zh5?0`2/PU020:^1C`030:Z0CP2YOdd0Z7i<0080Yge;202YP4`20:b3C`80Zh9>0P2ZPDd20:V0C0<0
ZGm=0`2ZP4h20:^1C`030:b3C`2[PTh0ZH1<0080Z7m;00<0ZH1<0:^2CP2/Pdl00`2ZPDd30:V0C080
Z7m;202[PDl00`2VODT0Z7m;0:V0C0030:^2CP050:V0C02XOd/0Yh5@0:N1D02WPTh00P2WPTd00`2W
PT/0Yh=90:N3B@040:^2CP@0ZX5=2`2WOTX20:QoB`<0ZH1<0P2[PDl20:Z0CP030:UoC@2XOT`0Z7i<
0080Yge;00D0Y7Y80:EkB@2VO4X0Yge;0:QnC0020:MmB`060:IlBP2YNdT0ZG]90:QmBP2WOTX0Ygm;
0P2UP4/00`2UPT`0Y7m;0:AoB`060:AoB`060:Z1C@2YP4`0ZH1<0:QoB`2WOTX0YWe90P2UO4P20:=o
A@040:=nA`2RODP0XWe80:5lB080XG]:0P2TNdL30:=jAP040:AkA`2VODT0YWe90:=mD080Xge>00<0
Xge<0:9mB@2RODP00P2RODH20:AjB080YG]900@0Y7Y80:9hAP2QMdD0X7I40`2NMD401P2OMT80XGQ4
0:=jAP2UO4P0YWe90:1e@P80XGI300<0XWM40:=hA@2TNDH00P2UNTL30:AkA`80XgY60`2RNDD0102O
MD<0X7I40:1fA02PMT@30:5gA@0:0:9hAP2MO4L0WGa709ijAP2MN4@0WGE209ec@@2LLT00W70o0:1f
A0L0WgE3102QMdD40:1fA0050:1kA`2NNDD0W7M309Ye@@2IM4000P2JMD400`2KMT80WgI209ie@@02
09ie@@80WGA00P2LLcl0102MLd40W79009ab@02LLT0309]a?`0309Y`?P2JMD40VWE10080VGA00P2H
Lcl309Mb?P80VFlm0`2JL3h309]a?`0309Q_>`2JLCd0W7<o0080WWE100<0W7<o09Ya?@2HKc/00`2G
LSh209Qc?`/0VGA0202EL3`209]eAP<0VWA500<0VgE609egB02NN4T0202LMTL209Ye@@80VGA00P2H
Lcl209Mb?PP0Ug520`2HLT<[ooooo`00:_ooool208iS>080SF8g0P2<HCH208]P=@P0SV4g0P2<GcD2
08eP=P80SV4g0P2?HSP809=T>P0;091[?P2?JC`0SFLj08iU>@2>HcP0T6<i09=T>P2DIC/0UFTl09AX
>`2CIcX00P2BIST00`2CIcX0U6Pk09EY?00809=W=P@0TfHl102BIC/01P2BIST0TfLj09=W>P2DJ3/0
UFTl09IZ?@80Uf/n2@2DJ3/209M/=`<0UV/f0`2EJSD00`2EJCP0U6Pg09=W=P02099V=@0309AX=`2E
JCP0Uf/j00<0UVXm0P2EJC`309AX>`P0UF/i0P2FJST209M[>P80V6`k0P2IKC`809M[>P<0V6`k0`2I
KC`209Y^?@030:1`@02OKcl0WVhn0080W6`l00<0WVhn09m_?`2PL4000P2KLCl209ab@080WG=10P2N
M48809eb?`080:1e@P2NLd00WG8o09]`?@2JKc`0Vg0m09aa?P2MLSl809]_?P<0X7100`2QLD420:9b
@P0309ea@02LL3l0Vfln0080Vfln00<0WG5009mc@P2PM4<00P2PMD820:5f@`@0XWM4202QMDP20:5f
@`040:1e@P2OM440WgA10:1e@P80XGI300<0X7A50:5eAP2RMTD00P2SN4D00`2RMd80XGHo0:1e?P05
0:=hA@@0XWM40P2SN4D0102TNDH0YGY70:IkB02WO4T20:QmBP030:9gA02SN4D0XgQ50080Y7U61@2U
NTL30:AiAP<0XgQ5202TNDH20:IkB0H0YGY70100[Ge<0:alB`2ZNTT0Z7Q70:MgAP2XN4L0ZGU80:Yj
B@2UO4H0YWe70:MnB02XOdT0Ygi80:ImA`2TNdD0XWU3202RMTD20:5f@@80X7E00P2OM3l209ic?P80
WW=00P2MLSl409aa?P<0VG0l0P2HKc/309M^>P0809E[>@2FK3X0V6hl09U_?@2HKS`0UV`j099X=P2@
IS@809AY?00809AV=@2CIC@0TFDd091V=02>IS<0S6Lc08]V<P2:IS8208aV=`0308]U=P2:I3D0RF<d
0080R68c1027HC8208IP<@<0QEl`0`23GC02089L;`<0PE/^00@0Peha089M<022GC00PUd`0P21G2l2
081K;P80OETY00@0OEP[07eH;01mF2h0OEL`0`1lES400`1lFBl0NeP^07YG;@0207UF;00807YG;@1k
F2h0O5T_07iG<01lEBh0NE</07EB:P1cDRT2079B:@03075D:P1eDRX0ME8Z00@0ME8Z0P1fDb/00`1/
D2P0KE4Y06mC:`02071D;00606mC:`1]DBT0K50X06a<9@1]CBH0KdlX0`1`D2T00`1_CbP0KThW06m>
:`0306i=:P80KD`Y0P1/BbP806e<:@80L4LW00H0KTXX06e;:01YBbL0Id/V06A:9@1RBR@206A:9`04
06=99P1RB2D0HTPU06=99P80I4XW201WBBD00`1RA280IDLU06Q::00206Y<:P0606Q::01UAbD0HT@R
06A88`1UBB@0Id/V0`1YCBP00`1XC2L0Id/V06=;9`0206A:9`0306I99`1WBBL0JDPW0080JTLW0P1X
AbH306U89`0;06Q79P1WARD0ITDT06A6901UAbD0ITPV06M99`1VB2H0IDLU06=58`1Q@b400P1Q@R<0
2@1R@b@0I4DV06E69`1VAbP0IdPY06Q9:P1WBBL0ITPV06E79@0206=58`0306E79@1VB2H0IdTW0080
J4XX00@0IdTW06I89P1UAbD0I4HT0P1SAB<306A69080IDLU101VB2H306=49@80HT<T0`1Q@R<0401W
ARL0ID@U05m08@1L?al0FT0O05]38@1NAbD0H4TW05]38@1M@b80GdDT06959@1SA2D0I4<T06=08P1R
?b4806138`0B05`n8P1N@2@0H48V06539`1RA2P0HD<W06129P1O@BD0GT0V05i0901O@BD0Gd8T0613
8`1QA280HTHQ06=78P1P@b<0Gd8R0`1N@B403P1P@b<0HD@T06=69P1SABT0HT@X06129P1O@BD0GT0T
05m19@1P@RH0HD<W06=99P1QAb@0GT@Q0P1M@b000`1PAR<0HdTV06I<:@0806=49`P0I4DV00H0ID@Q
06I58P1WAR<0J4LT06U89@1ZBBH206]:9`80J4LT00H0JDPU06Y99P1[BRL0K4/X06e<:@1^CBX806e=
9P80L4dU0P1aCRH3079?9`0307=@:01eCbX0MU0[00<0MU0[0`1gDB`0201bCbT0M54[07IC;@1gE2h0
N5D_07MD;P1fDbd0ME8/0P1hEB/00`1iER`0NUL]07]H;P0207aI;`0307eJ<01jFRT0NUXY00H0NUXY
0P21H3<01`1oGS40O5/^07YI;01kFRd0OE`_085P<`23HSD02023GS8208IP<@80Qf4b0`28HS<02@29
Hc@0RV<l08YS?02;I3/0Rf@i08]U>02;ICH0S6Hg08aV=@03091V=0D0TFLe0P2CKSX2099]>@80TF`h
0P2@JcL309A_>`80UG0l0`2FLCd509Qc?P<0Ug8m0P2GLSh00`2HLcl0VGA009Ye@@0209]f@P0309ag
@`2JMD40VgI20080W7M300P0WGQ409iiA@2ONTH0WgY60:1g@`2RNDD0Y7]70:ImB@80Ygi:00<0YWe9
0:ElB02SOTT00P2SOTT20:AoBP<0YH1;0P2XOd/01P2YP4`0ZX5=0:^2CP2/Pdl0[HA@0:j5D@P0ZXAC
0P2/QUD0102/Qe<0[8MB0:b7DP2/Qe020:b8CP030;:8F02aQeL0/8IF0080[hEE00<0/8IF0;:8F02c
RET0202cRUH20;2:F@040;2;E`2`ReH0/8]F0;2;E080/8aB0P2dRe<0102dReD0]8]G0;B;E`2dRUP2
0;B:FP<0/XaM0P2aRe`20;2:F`80[hUJ0P2aQeL0102aQeD0/XUE0;>:EP2cRU@20;B;D`P0/8]G00H0
[XQI0:n9FP2`RU/0/H]L0;:<G@2cSEh20;B>G`P0]H]I0P2^SEP00`2_ReL0/8]G0;69EP020;67E@05
0;:6E@2eS5P0]HaH0;F<F02fSET00P2gSUX20;R?F`80/XaK00@0/XeI0;:=F02bSEP0/XeF0P2bSU@0
402bSEP0/hiI0;B?FP2eT5/0]8mJ0;>>F@2aS5L0/8]F0:j9E02_RUD0/8]F0;6<E`2`ReH0[hYE0:f8
D`2[QU430;6<F080/8]G0`2_RUH80;2;E`P0/XUE0P2`ReL30:n:EP<0[XUE402]R5<80:j4E080[hQM
00H0[XQK0:j8E`2]R5@0[HQA0:f9C`2/R4h70:j6B`030:n7C02/QUD0[8IE00<0ZhED0P2ZQ5<20:V3
DP<0[HA@00<0[XEA0:n6DP2_QU800P2`Qe<20:b3B`040:b3C@2]Q500[HA@0:j4DP80[XAD00<0Zh5?
0:b2D02/PU000P2]Pe420:j4DP070:n5D`2]PUL0[H9E0:f2E@2]Pe<0[H=A0:f4D0020:f4CPP0[8=?
0`2YQ5020:Z5D@<0ZhIB0`2ZQE420:V4D0<0Z8=?202]Q4h40:Z1B@80Zh9:0P2/Pd/80:f4D0P0Z8=>
00D0Yh9=0:R3CP2XPdh0ZHA?0:^6D@020:b7DP040:f8D`2[QU80ZhIB0:^6DP80ZXEA0`2YQ5080:f3
D@P0[8=?0P2]Q4`20:b3B`<0Zh9:00<0ZX590:V0C02YP4`00P2ZPDd20:^2CPd0[8=?1P2]Q5001P2Y
QU00ZXE@0:Z5D02/Q500[HA@0:j3D080/89@0`2[PTh30:b3C`80[HA@0P2XOd/20:V0C0<0ZX5=302[
PTh30:b3C`80[HA@00<0Zh9>0:b3C`2/Pdl00P2]Q5020:j5D@030:n6DP2]Q500[HA@00H0[HA@00<0
[85<0:f2C@2]PTd00P2^Pdh20:n4C`0<0;25D02`Qe<0/HQD0;68E02bRED0/8MC0:j5D@2/Pdl0ZX5=
0:V0C02[PTh0[hIB0P2aR5@00`2_QU80Zh9>0:V0C0020:f4C0040:f4CP2]Q500[HA@0:f3D@80[H=C
202/Pdl20:f4D0<0[8=?0`2[PTh80:V0C0D0Zh9>0`2ZPDd80:f2E@0;0:b3C`2[PTh0ZX5=0:V0C02Z
PDd0Zh9>0:f4D02_QU80/HQD0:n6DP2[PTh00P2YP4`00`2[PTh0[hIB0;68E0020:^1D@050:^1C`2[
PTh0ZX5=0:Z1C@2ZPD/00P2YP4P20:QoB`80ZH1<0`2ZPDd00`2[PTh0[8==0:b3C@020:^2C080ZX5;
0P2YP4X30:f4D0L0[8=?0P2[PTh20:Z1C@80ZH1<202/Pdl20:UoC@80ZX1>0P2[PDl20:b2D080[89B
00H0Zh5A0:Z0D02YOdl0Z7i>0:MmC@2VO4`80:V0C080[8=?0P2[PTh20:Z1C@80ZH1<0`2[PE430:Z0
D080ZGm?00<0Zh9>0:Z1C@2YP4`00P2XOd/00`2YP4`0ZX5=0:^2CP020:^2CP80ZX5=00@0ZH1<0:Qo
B`2XOd/0Z7m;202[PDl00`2XOd/0ZH1<0:^2CP020:^2CP030:V0C02XOd/0YWe90080Yh5@00@0Yh9>
0:N2C@2WPTd0Yh9;0P2WPdT40:Z1C@@0Zh9>2`2WOTX20:QoB`<0ZH1<00<0ZX1>0:UoC@2YOdd01P2Y
Odd0202SNDL0Y7Y80:IlBP2WOD/0Z7i<0:MmB`2VO4X0YG]90P2ZO4X01P2XODX0Z7m;0:MoB`2UP4/0
YX5<0:F2C0P0Y7m;0P2ZPDd00`2YP4`0Z7m;0:MnBP020:ImB@070:ElB02TP4H0Y8160:=nA`2SOTT0
XWe80:5lB0020:5kBP040:5hA02RNDD0XgY60:AkA`80YGa80P2TNdL02`2UOe80Y7i?0:AnC`2SOD`0
XWe90:5lA`2QO4D0X7]40:5gA@2RN4H0Y7Y80080YG]900D0Y7Y80:9hAP2QMdD0XWU50:5hA00309mf
@P040:1g@`2RNDD0XgY60:5f@`80XWM400<0XgQ50:AiAP2UNTL00P2VNdP30:AkA`80XgY60`2RNDD2
09me@`80X7I40P2QMdD20:9hAP80VWU400<0W7Q409ag@`2NMT<00P2OMD<00`2OLd80XGM50:5gA@02
0:1fA00409me@`2NM480WG=109ec@@@0X7I4102QMdD0102QO4P0WgY609ehA02KMT8309Ye@@0309]f
@P2OMT00WgI000<0WWDo0`2MM3h209ec@@80W7900P2KLCl209Y`?P80VWE10P2IM40209Qc?`<0Ug8n
0`2IKcd00`2JL3h0Vg4o09]a?`0209ab@00309Q_>`2JLCd0WGA00080WgI200<0WGA009Ya?@2HKc/0
0`2GLSh00`2HLcl0VGA009Ud@00209Ye@@P0VGA0202HLcl00`2KMDH0VWA509UcA00209Qb@`0309Yd
A@2LMTL0WGM800P0W7I70P2JMD4209Ud@080V7<o0P2GLSh809Qb@`<0Ug52:oooool002[ooooo0P2>
HcP208eR=`80S64f0P2;H3D808eP=P80S5le0P2=H3H208iQ=`80Sf8h202CI3X02`2@Jch0T6Xm08eW
>P2=I3P0SV<h08mR>02CI3X0U6Dk09IZ?@2EJC`0TfLj0080TFDh00<0TfLj09EY?02FJSd0202CJ3D4
09=V?0@0TVDk0P2CIcX209AX>`0409EY?02FJSd0Uf/n09M[?PT0U6Pk0P2HKCP309M/=`<0UV/f00<0
UFTh09AX=`2CIcH00P2BISD00`2CIcH0UFTh09IZ>@0309IZ?@80UFTl0`2DJ3/809E[>@80UVXi0P2G
JcX209Q/>`80VFdl202FJST309Q/>`<0VFdl0P2JKSd00`2RKd00XFho0:1]?P0209i[?0030:1]?P2Q
KSl0XVm00080Vg4o0P2LLT00102MLd40WWA209id@P2OMD<809eb?`040:5f@`2PMD80WG8o09]`?@80
VVll0P2KL3d809]_?P0609i^?P2OKcl0Wflo0:1`@02QLD40XW920P2SLd<0202NLT40W70o09]_?P2J
KSd0Vfln09a`?`2NLT40X7A30P2PMD820:5f@`<0XWM400<0XgQ50:5dBP2QM4X01P2QM4X00`2SN4D0
XGI309md@@0209eb?`0609md@@2QMT<0XgQ509mcA02QMDH0XWI50P2TNDH00`2RMd80XGHo09md?@02
0:9gA0L0XgQ50P2TNDH0102UNTL0YW]80:QmBP2YOT/20:YoC0040:9gA02SN4D0XgQ50:AiAPL0YGY7
0P2TNDH30:=hA@P0Y7U60`2VNdP50:EjA`040:inC@2/O4/0ZWY90:QhA`80YgM600X0ZGU80:YjB@2U
O4H0YWe70:MnB02XOdT0Ygi80:ImA`2TNdD0XWU3202RMTD809md?`80WW=00P2MLSl309aa?P0409]`
?@2IL3`0VG0l09U`?080V6lk0`2GKSX0202BJ3H0UF/i09U_?@2KLCl0VW0n09I/>P2AIcD0SV@b202D
JC`209=U=003095U=02?IC<0SVHc0080RfHb00L0RVHb08aV=`2<ISL0RfDf08YT=@29Hc@0R68c00D0
Qf4b0P26H34308EO<004089L;`21Fbh0PE/^085K;P80P5X]0P1oFB`3089M<080PE`_0`20Fbh207]G
9`0407aG:P1lEb/0O5L]07eG<0<0OELb00<0O5T_07]H;P1iER`00P1hEB/02`1iER`0NeP^07aI;`1l
EBh0Ne@]07QB:`1cD2P0LE0W071@9`1aDBP0Ke8X0080M54Y101eDRX207IC:`0306a@:01]DBT0KU8Z
0080Ke<[00L0KU8Z06eA:@1/D2P0JTXS06];901^CRL0KdlX0080L50Y0P1_CbP306]=:@<0JT`X0P1Y
BbL306a;:0D0KD`Y00/0KT<S06i59@1`BBP0KT`Y06]=:@1XC2L0Hd/U06598`1UCBT0Hd/W06599@02
05m78`0306599@1SBbL0IDdY00P0IdTU00<0HT@R06A6901WBBL00P1ZC2X01P1WBBL0I4HT06948P1T
B2<0IDTT06M;9P<0JDdX00<0J4`W06M;9P1SBbL00P1TBRL00`1VBBL0IdTW06U89`0206Y79`0K06I5
901XAbH0JTTX06]::@1ZBBP0IdHU06A38P1R@B00I4HT06E79@1VB2H0IdTW06I89P1UAbD0HdDS0653
8@1O@240H44R06528`1SA2D0ITLX06Q9:P1YBR/0JT//06Q::01WBBL0ITPV0080I4HT00<0ITPV06M9
9`1XBRP00P1XBRP00`1WBBL0ITPV06E79@0206A6900306=58`1UAbD0IDLU00<0ITPV101WBBL306=4
9@80HT<T0`1Q@R<0401WARL0I4<T05m08@1L?al0FT0O05]38@1MAR@0H4TW05]38@1M@b80GdDT0695
9@1SA2D0I4<T06=08P1R?b4305m28PD0H4<S00<0G3hR05do8`1P@RH00`1RA2P00`1P@RH0Gd4U05i0
9P0205i0900@05m2901P@b<0HD@R06968@1SAb80HD@T06138`1O@R80GT4Q05m28P1P@b<0HTDU06=6
9P1SAB/0HT@Z0612:0<0GT0V0P1P@RP0201RBRH0H4PT05e58@1K@al0G4@P05i68P1RBRH0IDdY201R
@bH806=49@80ID@Q00<0ITDR06M68`1XAb@00P1ZBBH01`1[BRL0IdHS06Q7901YB2D0JTTV06]:9`1/
BbP00P1]C2T806e=9P<0LDhV0P1bCbL307=@:0L0MU0[00T0MDlZ079?:@1cD2X0ME8/07MD;P1hEBl0
Me@^07EB;01dDB/00P1hEB/0101iER`0NUL]07]H;P1kF2h207aI;`P0NETX0P21H3<01`1oGS40O5/^
07YI;01jFB`0OE`_085P<`23HSD02022GC4308IP<@80Qf4b0`28HS<01P2:HSh0RV<l08YS?02;I3/0
Rf@i08]U>080RfDf1@2@IS@3095W=@80Tfhj00@0TVdi095/>02AK3P0T6/g0P2?JSH309A_>`80UG0l
0`2FLCd309Qc?PD0Ug8m00H0UW4m09Mb?P2GLSh0V7<o09Ud@02JMD4209]f@P80VWE100<0VgI209ag
@`2MN4@00P2NNDD01@2ONTH0X7M30:5hA02TNdL0YWe90080Ygi:00<0YGa80:AkA`2SOTT00P2SOTT2
0:AoBP<0YH1;00P0Ygi:0:QoB`2YP4`0ZX5=0:^2CP2/Pdl0[HA@0:j5D@<0ZhED0P2ZQ5<30:V3DP80
ZhED00@0ZhIB0:^6D@2[QU40ZhI?0P2[Qdd0202dRUX0/hUI0;26EP2_QED0[XAD0:n5E@2aQeL0/XQH
202cRUH20;2:F@040;2;E`2`ReH0/8]F0;2;E080/8aB0P2eS5@0102eS5H0]HaH0;F<F02eReT20;F;
F`050;:<G`2aReh0/H]N0;6;GP2`RUd00P2_RE`20:j8F`80/8IF00@0/HME0;:9E@2bRED0/hYD0P2d
Re<80;2;E`080:j8F@2_REX0/8YK0;6;G02bS5d0/heN0;B>G`2eSf080;F;F@80[XeH00H0[h]G0:n:
EP2aREH0/HME0;26E02aQE@30;J=F@030;N>FP2hSe/0^I1L0080^I1L0P2bS5/0102bSET0/XeH0;:=
F02bSEH20;:>E00:0;:=F02cSUT0]8mJ0;F@F`2dSeX0/hiI0;6<E`2`ReH0[hYE0;2;EP80/XeH00@0
/HaG0:n:E@2]R5<0ZhIA0`2aS5P30;2;E`80[hYF202`ReL80;:9E@80/HaH00@0/8]G0:n:EP2_RUH0
[XUE0P2]R5@@0:f8D`P0[XAD00P0[hQO0:n8G@2^R5/0[XQG0:f8D`2]R540[HU?0:f9C@<0[hM:0`2^
QTT20:f5B0@0ZhED00<0ZXAC0:V3DP2XPU400P2XPU40102/Pdl0[HA@0:f4D02^QE420:n6DP80/8MC
0P2[PTX0102/Pdd0[HA@0:f4D02^Q5820:n5E@80Zh5?00@0[89@0:f3D@2]Pe40[XAB0P2_QE<01P2]
PUL0[H9E0:f2E@2]Pe<0[H=A0:f4D080[HA>202/Pdl30:V4D080ZXEA0`2[QU820:Z5D@<0ZHA@0`2X
Pdl80:f4CP040:V0B02ZPDT0ZX590:Z1B@80Zh9:0P2/Pd/80:j5D@P0Z8=>0P2WPTd0102XPdh0ZHA?
0:^6D@2/Qe820:f8D`<0ZhIB0P2ZQE430:V4D0P0[H=A202/Pdl20:f4C080[8=;102[PTX20:V0C080
ZX5=0P2[PTh:0:b3C`T0[HA@00H0Z8E?0:V4C`2YQ4l0[8A@0:f4D02_Q5420;63D@060:V0C02ZPDd0
ZX5=0:^2CP2/Pdl0[HA@0P2^QE420:QoB`80ZH1<102ZPDd;0:^2CP<0[8=?0P2]Q5020:^2CP040:b3
C`2]Q500[HA@0:j5D@80[hIB202]Q5020:b1C0040:f2C@2^Pdh0[X=>0:n4C`80/8E@00/0/8MC0;68
E02bRED0/XUE0;68E02_QU80[8=?0:Z1C@2YP4`0Zh9>0:n6DP020;68E0030:n6DP2[PTh0ZH1<0080
[HA<00@0[HA>0:f4D02]Q500[H=A0P2]Pe<80:^2CP80[HA@0`2/Pdl30:^2CPP0ZH1<102[PTh40:Z1
C@P0[H9G00<0[8=?0:^2CP2ZPDd00P2ZPDd01P2/Pdl0[HA@0:n6DP2aR5@0[hIB0:^2CP80ZH1<00L0
Zh9>0:n6DP2aR5@0[89B0:^1D@2[PDl0Zh9>0080ZX5=00<0ZX5;0:V0B02YP4P00P2XOd/20:V0C0@0
ZX5=0P2/Pdd20:^2C080ZX5;0P2YP4X40:j5D@@0[HA@0P2/Pdl20:^2CP80ZX5=0P2YP4`80:b3C`80
ZGm=0P2ZP4h20:^1C`80[89@0P2/PU800`2[PE40ZX1@0:UoC`020:MmC@030:IlC02YP4`0ZH1<00H0
ZH1<0P2/Pdl20:^2CP80ZX5=0P2YP4`01@2]Pe<0[89B0:b2DP2[PE40ZX1@0080ZGm?00@0Z7i>0:^2
CP2ZPDd0ZH1<0P2WOTX00`2YP4`0ZX5=0:^2CP020:^2CP80ZX5=00@0ZH1<0:QoB`2XOd/0Ygi:202[
PDl20:Z1C@<0Zh9>00<0ZH1<0:MnBP2UO4P00P2WPE00102WPTh0Yh9=0:N2C@2WPT/20:N3B@050:Qo
B`2YP4`0ZH1<0:Z1C@2[PTh00P2/Pdl00`2]Q500Ygi:0:MnBP090:MnBP80Z7m;0`2YP4`20:QnC0<0
ZGm=102ZP4h00`2RN4H0Y7Y80:IlBP020:QnC0030:MmB`2VO4X0Y7Y80080ZWa:00<0Z7e:0:QoB`2W
Od/00P2VPD`00`2UPT`0Y7m;0:AoB`060:AoB`80ZX5=00@0ZH1<0:QoB`2WOTX0Ygi:0P2VODT20:B0
AP040:AoB02SOTT0XWe80:5lB080XG]:00<0WWE10:1g@`2SNTH00P2VODT03P2UO4P0XgY60:9iA@2V
P5<0YGm@0:AnC`2SOD`0XWe90:5lA`2PNd@0WgY30:1fA02QMdD0XgU70`2UNdT01P2SNDL0XWQ60:Im
B@2TNdL0XWU509mf@P80WWE10P2OMT801P2RMd@0XgQ50:=hA@2TNDH0YGY70:IkB080Yga90`2TNdL2
0:=jAP<0XWU50`2OMD<00`2PMT@0XGM50:9hAP020:9hAP80UWE000`0VGE109ag@`2OMd@0XGM50:9h
AP2TN4L0XgU70:9hAP2QMdD0X7I409me@`2MLd4209ab@00509id@P2OMD<0WgE30:1fA02QMdD00P2R
N4H01@2SNDL0XGa80:1kA`2MN4@0VgI200<0VWE100@0VgI209mf@02OMT00WgI00P2NMCl309ed?P<0
WG=100<0W79009]a?`2JL3h00P2JL3h209Ye@@80VGA00P2HLcl309Mb?P0409Q^?02IKcd0VFlm09Y`
?P80Vg4o0P2LLT000`2GKSX0VW4m09ed@0020:1g@`0309ed@02JLCd0Ufhj00<0Ug8n00<0V7<o09Ud
@02JMD400P2JMD4809Ud@0P0VgI200<0VWA509UcA02HLT<00P2GLD800`2ILd@0VgE609egB00809af
A`80VWE10P2IM40209Qc?`80Ug8n202ILd@309Ma@R_ooooo000Zooooo`04095T>P2@HcT0T6<i08mR
>080SV4g0P2=H3H808iQ=`0608YQ=@2;HSH0Rf8f08aS=`2=I3P0SVDi0P2?ISX8095U>00309=W>P2B
IST0TFDh0080Sf<f00<0TFDh099V>@2CIcX00P2EJC`0102DJ3/0TfLj09=W>P2BIST2095U>0<0U6Pk
00<0TfLj099V>@2AICP00P2AICP0102DIcd0TfHl09=V?02CIS`3099U>`03095T>P2HK3l0V6`o00H0
V6`o00@0TVHi09=W>P2EJC`0UVXm0P2EJC`0102DJ3/0TFDh091T=`2EJC`209IZ?@0509M[?P2HK3l0
VFe009U]@02JKT400P2DJ3/209=W>P<0TVHi00<0TFDh09IZ?@2FJSd01P2FJSd809EY>P80UVXi0P2G
JcX209Q/>`80VFdl00D0UFTl09IZ?@2FJSd0Uf/n09Q/?`0209U]@00309Y^@@2IKCh0VFdn00H0VFdn
00<0VFdl09]_?P2MLD000P2OLd800`2NLT40WG5009a`?`0309eb?`<0WW=00P2OM44809eb?`P0WG50
0P2JKSl0102KKch0Vg0m09aa?P2LLC`209aa>P030:1e@P2NLd00WG8o0080W74n00<0WG8o09ic@02P
MD80202NM4880:9gA0P0X7E20P2PM4<20:5eA080XWI50P2SMdH409md@@80X7E20P2QMT<50:=hA@L0
XWM40`2SN4D20:AiAP80Y7U40`2UNTD30:IkAP80XGI10P2RMd801@2SN4<0Y7U40:EjA@2UNTD0XgQ5
00<0XWM40`2QMT<00`2PMD80XWM40:9gA0060:9gA0P0YGY7202SNDL00`2JKSd0WG500:5eA0020:Ah
A`040:5eA02MLD00VVhm09ec@@<0W7900P2KLCl209Y`?P0909ab@02KLCl0VW0n09U_?@2GKC/0UF/i
09AZ>02CJCL0V6hl00<0Ufdk0P2FK3X209E[>@0609AY?02CJ3/0TfPk099W>P2AIST0T6Dh0P2?I3L0
1P2AJc`0T6Xk091Z>`2?JCX0SVPi08eW>080S6Hg00@0RfDd08YT<`2:I3<0RV@c0P29Hc8208QR<@P0
QV8b2026GcH01023H3P0PEhf07mL=01mFS8207]H<080O5Ta00h0N58^07YD<01mEc80P5Xc089M<`22
GC40PE``081K;P1hFbl0NU/_07UJ;P1hEb`0N5D[07UD:P80NE8Y00D0N54X07aI<`1jEc40N5D_07IC
;@0207EB;00407IC;@1gE2h0MU0[07I@:`@0Me4/0P1hDRd3079A;P03075@;@1`Cb`0Kdh[0080Kdh[
00P0K5@^06]C;@1YDB/0J50Z06M?:@1XD2X0JE4[06YB;080JdlZ00<0KDl[06m>:`1`CR/00P1bCR`0
0`1dCB`0KTd/06i=;00206e<:`@0K4/Z0`1XBRP206M99`<0ITPV0P1WBB<306Q:90<0JD/U201WBBL0
3P1UCBT0I4`X069:9P1PB2@0GdLS0618901RBRH0Hd/W065=:01SCBP0I4`X06I99`1YB2L0JDHV0P1/
ABH0101Q@al0HdDQ06I8901YBbL306a>:P<0JddY00T0JT`X06Q:9P1WBBD0ITPT06E78`1TAR80HTDS
06=6901TAbD00P1UB2H00`1TAbD0HdHT06958`0806E69`<0IdHW0`1XAbP206U8:@P0ITPV0P1VAB82
06M68`0406Q7901YB2D0JDPU06Y99P80JDHV00D0IdHU06A6901RAB<0GdDR05i48@0205a48080G4<T
00@0GD@U05i59P1NABH0GdHW0P1PAbP00`1SAB/0HT@Z0612:00305i09P80H48X00@0Ed0N05U2801K
A280GTLU0P1OB2H00`1NAbD0GDHT05m19`0305m19`@0GT0V00<0Fd<W05a4:01NARX00P1PB2`02`1O
Ab/0GDDY05a4:01H@Al0FD8P05Y2801L@R40Gd8R06528`1S@R<0I4<T0080IT@Y00H0Hd@X0694:01O
A2L0GTDW05e69`1LABH206=69P0406959@1QA2@0HD@T06138`80Gd8R00@0H4<S0654901QA2@0HTDU
0P1SARH206A79`<0I4DV0`1SA2D206939080HD@T0`1RABD306=69P0405m17`1Q@b40I4HT06I89P80
IdTW00D0ITPV06E79@1ZC2X0J4XX06I89P0206E79@0406Q::01ZC2X0K4h/06M;9P80J4`W00<0JDdX
06Y>:@1[CbX00P1/D2/00`1^D2`0KDl[06a>:P0206a>:P0A06i@;01_DBd0LE<_07QC:@1gDRP0MU4W
07E@9P1dCbD0LdhT079=8`1aC280KThW06m?:01`D2T0LE4Z079B:`1dE2d00P1eEBh0101gE2`0N5D]
07QE;@1hEBd207UF;P80NUL_00<0MU<[07MD;01hEBd00P1iERh00`1gE2`0MU<[07AA:@0307QE:`0>
07UF;01jEbd0O5T_07eJ<01nFc40Oe`b08IP<`24GS40PE/^07mI;01nF2/0P5X]08=M<025Gc82089M
<080Peha0`24Gc800`25H3<0Qf<c08MS<`0608MS<`P0RVHf00H0SVPk08iX>@2>J3T0SVPg08mZ=P2?
JSD208mZ<`80T6/g00@0TF`h099]>@2CKSX0UG0l0P2FLCd209E`>`0309Ia>P2GLcT0V7@h0080VGDg
00@0VWLg09ac?`2MM400WgI20P2PMd<02`2OMT80WGA009ac?`2FLC`0Ug8m09Qc?P2KMT40WWU40:1k
AP2RODP0Xgi900<0WgY50P2PNdH30:5lA`080:F0B`2TOdX0XWe80:5lA`2RODP0Xgi90:J1C02WPTd2
0:J1C@80Yh9>0`2XPdl0102YQ500ZHA?0:V4C`2YQ4l20:Z5D0<0ZhIA00@0[8MB0:f8D`2]R5<0[HQC
0P2^RE@20:n:E@P0[hYF0`2^RE@20:n:E@<0/8]F0P2_RUH30;2;E`<0/HaH202cREL30:f7FP040:j8
F`2_RE`0[hUL0;2:G@80/H]N202eS5P80;6=F@80/8]D00<0/8]F0;2;E`2`RUT00P2`RU/00`2`RUd0
/8]G0;2;E`060;2;E`<0/XeI0`2cSUX20;B?F`P0/hiJ0`2eReT30;J<FP80]heK0P2dSe/20;>>FP@0
/XeI0P2dRe<0102cRU80/XUA0;:9D@2aR5020;27C`P0/XUE0`2`ReL20:n:EP/0[XUE202]R5<30:f8
E0D0[XUE202`QU@80:j9E@040;2;EP2_RUD0[hYE0:j9E080[HQC0P2/Qe850:^7C@<0[8Q>102_QU83
0:j5D@80[HA@0P2[QU420:b7DP80[HQC0P2^RE@0102cREL0/XQF0;:8EP2aQeD20;26E080[hEC0P2`
Qe<20:n6DP040:j5D@2]Q500[HA@0:b3C`80[HA<0`2/Pd/30:^2BP80[8IE00@0[8MC0:^6D@2[QU40
ZhI?0P2ZQT`20:Z1C@040:^2CP2/Pdl0[XEA0:n6DP80/8MC202^QE420:n7BP060:j6B@2/Q4L0Zh=6
0:Z2A@2YPD@0Z8130P2]Q5030:b3C`<0Zh9>202/PU880:b3C@80[8=;00@0[8==0:f4D02]Q500[XAB
0P2^Q5@80:j4DP060:b7DP2[QU40ZhIA0:V4C`2XPdh0Yh9=0P2VPD`20:V5B`040:V4C@2YQ4l0ZHA?
0:V4D080ZH=B00<0ZH1<0:Z1C@2/Pdl00P2]Q5000`2[PTh0ZH1<0:QoB`020:j2D`040:j2D@2^Pe00
[H9?0:f2C@80[85:0P2YP4X20:Z1B`80Zh9<0P2/Pdd90:f4D0070:n6DP2]Q500ZX5=0:QoB`2WOTX0
ZH1<0:^2CP090:b3C`P0[8==00H0ZH1<0:Z1C@2ZPDd0Zh9>0:b3C`2]Q5020:j5D@80ZX5=0P2[PTh0
102/Pdl0[HA@0:f4D02^QE420:^2CP040:b3C`2]Q500[HA@0:j5D@80[hIB2@2]Pe402P2/PU00Zh5?
0:^1C`2/PU00[H=A0:n5D`2aQeD0Zh9>0:b3C`2^QE420:n6DP030:j5D@2/Pdl0Zh9>00<0Zh9<0`2/
Pdd20:f4CP@0ZXE@0`2YQ4l0102XPdh0[XEA0:j5D@2^QE420:f4D0D0[8=?0P2[PTh30:Z1C@040:V0
C02[PTX0Zh9:0:^2C080Zh9>00<0Zh5?0:^1D@2[PE400P2]Pe<0102]Pe40[HA@0:f4D02]Q4h20:f4
C0<0Zh9>0`2/Pdl20:f4D0030:R3CP2WPTd0YX5<0080Y7m:00<0YX5<0:N2C@2XPdh0202^P4h00`2Y
P4`0Zh9>0:b3C`030:f4D0030:^2CP2YP4`0Ygi:0080ZH1<0P2ZPDd20:^2CP80[8=?202[PT`@0:^2
CP80ZXE@0P2YQ4l40:R3CP<0Yge;0P2XOT`30:UoC@80[8=?0P2[PTh20:Z1C@80ZH1<0`2[PTh20:Z1
C@<0ZH1<00@0[hAA0:j3D02^Pe00[H9?0P2/PDh20:^0C@80Z7m700H0ZH180:Z1B@2YP4P0Ygi60:El
A02TNd<80:b2D0080:j5D@2]Q500[8=?0:^2CP2YP4`0Z7m;0:MnBP2VODT80:^2CP060:b3B`2[PTX0
Zh9<0:^2CP2ZPDd0ZX1>0P2YOdl0402^Q5@0[H=C0:b2DP2[PE40ZX1@0:UoC`2XOTh0Yge=0:5mB`2S
OD`0YH1<0:V1C@2ZPDd0ZWm:0:]nA`2ZODH80:QoB@80YGa800@0YWe90:MnBP2YP4`0ZX5=0P2[PTh3
0:UoC@80Z7i<102WOD/00`2[PTh0ZX5=0:QoB`020:ImB@030:QoB`2ZPDd0Zh9>00<0ZH1<0P2XOd/3
0:MnBP80YX5<102UP4/20:AoBP060:J2A02VPTH0YX960:J2B02VPDX0YX5<0P2VPDd01P2ZPDT0ZH18
0:V0B02WOTH0YWe50:ElA080Y7]300<0XWM40:=hA@2UNTL00P2VNdP01P2UNTL0XgQ50:9gA02UO4P0
YWe90:QoB`80ZX5=00<0Z7m;0:ImB@2UO4P0202WOTX30:AjB080XgU70`2RN4H80:5hA0030:Ak@`2S
NT80XGQ00080X7Lo00`0XGQ00:=j@P2TNd<0WWA209me@`2QMdD0XWQ60:=iA`2RN4H0XGM50:1fA02L
Md<309ehA080WWU50P2ONTH809]f@@<0VWE10P2KMT8309ag@`80X7M30P2OMT8409ie@@D0WgE30`2P
MT@0102LMd<0VgI209]f@P2JMD4209Ud@080V7<o00<0VVm209]`@`2LLD@00P2LLD@0302JKd80VFi1
09U^@@2GK3l0UFm009I`@@2GLD80V79309UcA02JM4D0VgE609afA`80V7<o00@0VGA009Ye@@2LMd<0
WGQ40P2NNDD809ec@@P0VGA00P2MN4@01P2LMd<0VWE109Ud@02HLcl0Ug8n09Ia?@80Ug520P2HLT<2
09UcA080VWA5202MLD@209Mc@`0409Ib@P2ELD40U71009A`@080Tflo00H0WG8o09ac?`2LLcl0Vg<o
09Ud?`2HMCl209Ie?`<0VWA5:oooool002[ooooo0`2@HcT00`2?HSP0SV4g08iQ=`0208eP=PP0SV4g
0P2?ISX0102>ICT0SF@h08aS=`2;HSH208YQ=@P0TFDh00<0TfLj099V>@2AICP00P2?HcH00`2AICP0
TVHi09=W>P0309=W>P80TVHi0`2AICP209AX>`80TfLj0P2BIST2095U>0@0TVDk102CIS`809M[?P03
099V>@2CIcX0UFTl00<0UVXm00<0UFTl09AX>`2CIcX00P2FJSd309M[?P<0V6`o0P2DJ3/209=W>P@0
TVHi202EJC`809EY>P80UVXi0P2GJcX209Q/>`80VFdl102GJch409Q/?`P0VFdn00P0UVXi09Q/>`2I
KC`0Vfln09a`?`2KKch0VVhm09U]?0<0WG8o0`2NLd0209md@@P0WG8o202MLD0209Y^?`0909]_?P2K
L3d0W74n09aa?02LLCX0WG8k0:1e@P2NLd00WG8o0080W74n00<0WG8o09ic@02PMD80202NM4880:9g
A0P0XGI3102QMD@40:9fA@<0X7E20`2QMT<20:9gA0L0XgQ50P2RMd@30:AiAP030:=hA@2RMd@0XWM4
0080XGI3202UNTD30:9g@P80XgQ30`2TND@20:5f@`H0XWM4202SN4D80:EjA`80Y7Y80P2SNDL20:9h
AP80XGM500<0WG5009mc@P2QMD@00P2RMTD00`2OLd80W70o09Y^?@0409ab@080Vg4o0P2JL3h0202L
LT00Vg4o09Y`?P2HKS`0Ufdk09E[>@2DJSP0TfTg0`2GKC/209I/>P<0UF/i0P2CJ3/2099W>P04095V
>@2@ICP0Sf@g08mT=`80T6Xk00<0SfTj08iX>@2=IcP00P2<ISL0102;ICH0RV@c08YT<`2:I3<208US
<P<0R68a2026HS8808EN=@04089O=`20GCD0OU/c07aI<@80NeP`0P1lFC402@1hE300NEDa07]H<P1m
FS80OU/a07iL;`1mFbh0OE/]07=F:P0207IG:`0307MF:`1hEB/0NeH/00<0O5D/00H0NePb07YG<@1g
E2h0ME8/07AA:`1eDR`207IC;@@0M54[101eDR`00`1bDBh0LE0]075@;@02071?;080Kdh[00@0KTdZ
06eC;P1/DRd0JU0[0`1XCRT206Y@:`80K50[00<0KDl[06m>:`1`CR/00P1aCB/00`1cC2/0KTd/06i=
;00206e<:`<0K4/Z00@0JdXY06Q::01XBRP0J4XX0P1WBBL306I89P<0IdTS0P1XBR@306U;9@P0IdTW
00<0IT`Y06E;:01SBBH00`1QAb@03P1SBBH0I4XW069<9`1SBbL0I4XW06I99`1YB2L0JTLW06]79`1]
ARL0HdDQ06A68P1WBBD0JD/W0`1[CBT0101ZC2P0JD/W06U;9`1XBRH206M99@0606I8901UAb<0IDLS
06958`1SAR@0IDPV0P1VBBL00`1UB2H0HdHT06958`0806E69`P0J4LX201VB2H306M68`0306Q7901Y
B2D0JDPU0080JTTV00L0JTLW06U69P1XAbH0I4HT06958`1OAB80GT@Q0080GDDQ0P1N@bD205m49P80
H4DW0P1QARP0301SABT0HT@X06129P1O@BD0GT0T05m19@1P@RH0HD<W05Y38@1KA280GTLU06199`80
HDXX0P1PBBL205i090@0Gd4U0P1P@RH00`1J@b@0G4DV05e69`0205m8:@0305i7:01LABH0Fd@U0080
FT<Q00@0Fd<Q05e38P1O@R80H44R0P1S@R<206E3:00406939`1Q@bL0GT<V05e49P80Fd@U0`1RABD0
0`1QA2@0H4<S06138`0205m28P0306138`1QA2@0HD@T0080HTDU0P1SARH0101TAbL0I4DV06A59P1T
ABH206=49@<0HT<T0`1QA2@206959@<0HdHV00@0H48P06538@1TAR@0ITPV0P1WBBL00`1VB2H0IDLU
06Q::00206M99`0506I89P1WBBL0J4XX06U;:@1ZC2X00P1WBbH00`1XC2L0JDdX06Y>:@0206]?:P0:
06a@:`1]Cb/0K4hZ06]=:@1ZC2P0JddY06a>:P1^D2`0Ke4]07EB:080M54W00H0Le0V075>901`CB<0
L4dS06m<8P1_CbP2071@:@05075A:P1bDR/0Le</07=C;01dE2d00`1gE2`207QE;@<0NEH^00P0MU<[
07MD;01iERh0NUL_07UF;P1hEBd0Me@/07IC:`<0NEH/0P1jEbd01`1kF2h0O5T_07eJ<01mFS00Ped`
089L;`21Fbh00P20FRd00`21Fbh0PU`_089L;`02089M<080Peha1024Gc8808MS<`P0RFDe00H0SVPk
08iX>@2>J3T0SVPg08iY=@2?JSD208mZ<`80TF`h00@0TVdi09=^>P2DKc/0UG0l0P2FLCd01P2DKcX0
UG0k09E`>@2FLSP0Ug<g09Qd>080VGDg00<0W7<o09ed@02NMD400P2OMT80302NMD40WGA009ac?`2G
LSd0V7<n09Ud?`2KMT40WGQ309mjA@2PNdH0XGa709iiA0<0WgY50P2PNdH20:5lA`080:AoBP2SOTT0
XWe80:5lA`2RODP0Xgi90:F0B`2WPTd20:J1C@80Yh9>102XPdl0102XPdh0ZHA?0:V4C`2YQ4l20:Z5
D080ZhIA0P2/Qe820:f8D`<0[XUD00<0[hYE0:n:EP2_RUH01P2_RUH30:j9E080[hYE0`2`ReH20:n:
EP<0/8]G0`2aS5P80;>9E`@0[XQI00<0[hUJ0;2:F`2`RU/00P2aRe`80;F<F0P0/XeI0P2`Re@00`2`
ReH0/8]G0;2:F@020;2:F`030;2:G@2`ReL0/8]G00H0/8]G0`2bSET30;>>FP80]8mK202cSUX70;J<
FP030;F;F@2dSe/0]8mK0080/hiJ0`2bSET0102aS5P0]8]C0;>:DP2cRU820;:9D@80/HQ@00<0/8M?
0;:9E@2bRED01P2bRED30;2;E`80[hYF2`2^RED80:f8D`80[HQD1P2^RED80:n5D`P0[HQD0`2_RUD0
0`2^RE@0[HQC0:f8D`020:b7DP@0ZhM=102/R4h40:n6DP<0[XEA0P2]Q5020:^6D@80[8MB0P2]R5<2
0:j9E080/XQF0P2aQeD20;26E080[hEC0P2`Qe<20:n6DP040:j5D@2]Q500[HA@0:f4D0<0[HA<0P2/
Pd/30:^2BP80ZhED00L0ZhIB0:^6D@2[QU40ZhI?0:^7C@2/R4h0ZX5=0080Zh9>00D0[8=?0:j5D@2_
QU80[hIB0;27D`080:j5D@80[XI;00@0[HE:0:b4B@2/Q4T0Zh=80P2ZPTL20:f4D0<0[8=?0`2[PTh8
0:b2DPP0[8==0P2/Pd/0102/Pdd0[HA@0:f4D02^Q5820:j4E0P0[XAB00D0[8MB0:^6D@2[QU40ZXE@
0:R3CP020:N2C@040:J1C02YQD/0ZHE;0:V4C@80ZHA?00/0ZHA@0:V3DP2YPe80ZH1<0:Z1C@2/Pdl0
[HA@0:b3C`2[PTh0ZH1<0:QoB`020:f1DP040:f1D02/PDh0[85>0:b1C080Zh190P2YP4X20:Z1B`80
Zh9<0P2/Pdd:0:f4D0030:b3C`2[PTh0ZX5=0080ZH1<00<0ZX5=0:^2CP2/Pdl01`2/Pdl80:b3C@<0
Zh9>0`2/Pdl20:f4D080ZX5=0P2[PTh0102/Pdl0[HA@0:f4D02]Q5020:^2CP040:b3C`2]Q500[HA@
0:j5D@80[hIB2@2]Pe402P2/PU00Zh5?0:^1C`2[PDl0[H=A0:n5D`2`QU@0Zh9>0:b3C`2^QE420:n6
DP030:j5D@2/Pdl0Zh9>00<0Zh9<0P2/Pdd30:f4CPH0ZXE@0P2[QU430:j5D@80[HA@1@2/Pdl20:^2
CP@0ZX5=0P2[PTX0102[PT`0Zh9>0:^2CP2[PDl20:^1D@80[H=C00@0[H=A0:f4D02]Q500[HA>0P2]
Q4`30:^2CP<0[8=?0P2]Q5000`2XPdh0Yh9=0:J1C0020:F0B`030:J1C02WPTd0Z8=>00P0[X1>00@0
ZX5=0:^2CP2/Pdl0[HA@0P2/Pdl00`2[PTh0ZH1<0:MnBP020:V0C080ZX5=0P2[PTh20:b3C`P0Zh9<
402[PTh20:Z5D080ZHA?0`2XPdh00`2WPTd0Yge;0:MmB`030:QnC0<0ZGm=0P2/Pdl20:^2CP80ZX5=
0P2YP4`30:Z1C@80ZH1<0`2XOd/20:j3D080[H9?0P2/PDh20:^0C@80ZH1800H0ZX590:^2BP2ZPDT0
ZH180:MnAP2UO4@80:b2D080[XEA00@0[HA@0:b3C`2ZPDd0ZH1<0P2XOd/80:^2CP80Zh9:00@0Zh9<
0:^2CP2ZPDd0ZX1>0P2YOdl20:f3D`0>0:b2DP2[PE40ZX1@0:UoC`2XOTh0Yge=0:5mB`2SOD`0YH1<
0:V1C@2ZPDd0ZWm:0:]nA`2ZODH80:QoB@80YWe900@0Ygi:0:QoB`2YP4`0ZH1<0P2ZPDd30:UoC@@0
Z7i<0P2WOD/00`2ZPDd0ZH1<0:MnBP020:ImB@030:MnBP2YP4`0ZX5=0080ZH1<0`2XOd/30:MnBPP0
YH1;00H0YX940:J2AP2VPTH0YX980:J1BP2VPD`20:J1C@050:Z1B@2YP4P0ZH180:QoA`2VODD00P2U
O4@0102TNd<0XgQ50:AiAP2UNTL20:IkB0060:EjA`2TNDH0XgQ50:ElB02VODT0Ygi:0P2XOd/00`2W
OTX0YWe90:ElB0080:MnBP<0Y7Y80P2SNDL30:9hAPP0XGQ400<0Y7]30:=j@P2QN4000P2PMcl02`2Q
N400XgY20:Ak@`2NM480WgE30:5gA@2RN4H0XgU70:9hAP2QMdD0X7I400@0WGQ40P2NNDD209mjAPP0
VgI10`2JMD4209]f@P<0W7M30P2QN4@30:1g@`<0WgI21P2OMD<20:1fA00309ag@`2KMT80VgI20080
VWE10P2IM4001`2HLcl0VVm209]`@`2LLD@0WG9509aaA02KL4<00P2IKT402@2GK3l0UW1109I`@@2G
LD80V79309UcA02JM4D0VgE609afA`0309Ye@@80VgI20`2LMd<809ec@@P0VGA00P2LMd<0102KMT80
VWE109Ud@02IM40209Qc?`80Ug520P2HLT<209UcA080VWA5202LLD@0102JMTH0VGE509UeA@2IMDD4
09QdA00609ea@02LLT00W79009]c@02IM400V7A00P2FMD0309YdAB_ooooo000Zooooo`80T6<i0`2?
HSP;08iQ=`0809EZ?`2DJCh0TVLl08mT>@2<HCH0RUld08QM<P26Fc08095U>00309=W>P2BIST0TFDh
0080Sf<f00<0TFDh099V>@2CIcX0102@I3L4095U>00409AX>`2CIcX0TfLj09=W>P<0TVHi00H0TFDh
091S>@2AI3X0TF@j099U>`2CIS`209AW?@0309EX?P2EJC`0UFTl00H0UFTl00<0TVHi09=W>P2EJC`0
0`2GJch00`2HK3l0Uf/n09M[?P0209Q/?`<0Uf/n0`2FJSd309AX>`80TfLj0`2BIST809AX>`X0UVXi
0P2GJcX209Q/>`80VFdl102HK3l409M[?PP0VFdl00<0U6Pg09EY>02GJcX00`2HK3/209M[>P<0WG8o
0`2NLd0209md@@P0WG8o202MLD0209]_@00409]_?P2LLCh0W74n09eb?@80WG8k00<0X7E209ic@02M
LSl00P2LLCh00`2MLSl0WW=00:1e@P0809me@a00XWM4102RMTD40:5eA080XGI30`2RMd@<0:=hA@06
0:IkB02UNTL0YGY70:=hA@2RMd@0XGI30P2PMD820:MlA`030:IkAP2UNTD0Y7U400<0XgQ3102TNDH3
0:=hA@040:9gA02PMD80X7E20:5f@`80XWM400<0XgQ50:AiAP2TNDH0402UNTL20:EkB@0>0:AjB02S
NDL0XGM50:1fA02OMD<0WWA20:9fA@2QMD@0X7A309mc@P2NLT40WG5009a`?`2KKch309ab@080Vg4o
0`2JL3h01P2KLCl0VW0n09U_?@2HKS`0UV`j09E[>@80U6Xh00@0Ufdk09I/>P2FK3X0UV`j0P2EJcT2
09AZ>00609=X>`2BIcX0TVLj095V>@2@ICP0Sf@g0P2>HcH208mY>P0308iX>@2=IcP0S6Hg0080RfDf
0P2:I3D308US=080R68c0P27HC8808EP<`P0Q5dd00D0PEhf07mL=01mFS80NeP`07YG;`0207]H<00?
07aI<@1jES80NeLc07aI<`1mFS80OEX`07aJ;@1kFB`0NUPZ071C9`1bDbL0Le@X07IE:P1hEB/0O5L]
0080OUL^00D0OeP_07YG<@1hEBl0Me@^07EB;00307AA:`0307EB;01dDB/0M54[00H0M54[101`Cb`2
06m>:`80KTdZ00P0KU8]06eA;01[CbX0JThY06U=:01ZCRT0JdlZ06a@:`80KE4/00H0KDl[06m>:`1_
CBX0Kd/Y06i::01`BBP306e<:`80K4/Z0`1[BRT306Q::080IdTW0`1VB2H0101VB2@0IdTU06M99@1W
BBD206Q:9P80JD/W201XBRP00`1XBbT0IdXX06E89P0306A79@80IDPV00H0HDTU06989@1SBBH0ITTW
06M99`1ZBBP206a9:@0406I8901WBBD0J4XV06U;9`80JT`X00<0JD/W06Q:9P1VB2@01`1VB2@00`1T
AR@0IDLU06M99`0206Q::00306M99`1UAbD0I4HT00P0ITPV0P1[BRT0101ZBBP0JDPW06Q79P1XAbH2
06M69@P0IdTW0`1XAb@306U89@80JTTV0P1ZAbL01@1XAbH0IDLU06=6901QAb@0H4HS0080GdLS0P1Q
A2@306959@<0HdHV00`0I4HZ06=5:@1Q@bL0H48V05m19@1P@RH0HD<W0694:01MAB<0GTHT06189P1R
BRP206=;:@80HTXX0`1N@2@0201O@BD0H48V06539`1Q@bL0HT@X05]2901L@bD0GD@V0P1NABL02@1M
A2H0G4<U05]2901MAR@0G4DS05e58`1NA2<0Gd8R06118P0206918P80Hd4V00@0HD8V05m19@1M@RD0
Fd8T0P1J@b@0101RABD0HD@T0654901QA2@306138`0305m28P1QA2@0HD@T0080HD@T0P1RABD206=6
9P80I4DV0P1SA2D30693900306528`1P@b<0HD@T0080HD@T0P1RABD206=69P0406538@1RA280I4HT
06E79@@0ITPV00D0IDLU06I89P1WBBL0J4XX06U;:@0206Q::00706M99`1VBRD0Id/V06M;9P1XC2L0
JDdX06Y>:@0206]?:P0906]=:@1ZC2P0JD/W06Q:9P1YBbL0JT`X06a>:P1]Cb/0M54Y0080Le0X00<0
LTlW075>9P1`CBD00P1_C2@8075A:P<0MU<[0P1gE2`307QE;@0307MD;01hEBd0NUL_0080NeP`00<0
NUL_07QE;@1gE2`02@1jEbd00`1nFB`0OeX]085L;`02089M<003085L;`1oFRd0OUT/00<0PUd`0P23
GS4308AO<PP0QV8b2029ICD01P2=IcX0SFLh08eW>02>J3L0SVTe08mZ=@80SfXc0P2BKCT00`2CKSX0
U6lk09E`?00209Ia?@0609Mb?P2DKc/0U6lk09E`>`2FLCX0Ug<i0P2HM3P0102IMCL0W7<o09ac?`2M
M40209ie@@0409ed@02LLcl0W7<o09Ud?`80VWE000<0VgI109ag@P2MN4<01@2NND@209mjA@<0X7]6
0P2SOTT30:9mB0030:=nB@2UP4/0YX5<00<0YX5=0P2WPTh30:R3C`<0Z8=>0P2YQ4l30:Z5D0040:^6
D@2/Qe80[8MB0:b7DP80[HQC0P2^RE@80:j9E@<0[XUD0P2_RUD30;2;EP80[hYF0`2`ReL30;6<F0P0
/hUG00<0[XQI0:n9FP2_REX00P2_REX30;2:F`030;6;G02eS5P0]HaH00H0]HaH202bSET20;6<E@03
0;6<E`2aS5P0/H]J0080/H]L00<0/H]N0;6<F02aS5P01P2aS5P30;:=F@<0/hiJ0P2dSe/80;>>FP80
^8iL00@0]heK0;J<FP2eReT0]H]I0P2dRUP30;>>FP80/XeI0`2aS5P30;>:E080/XUC0`2aR5880;:9
E@<0/8]G0P2_RUH;0:j9E@P0[HQC202^RED80:j4DPP0[8MC0P2_RUD30:j9E0<0[HQC202/Qe040:n6
DP<0[XEA0P2]Q5020:^6D@80[8MB0P2]R5<20:j9E0<0/HME0`2`QU@20:n5D`<0[hIB0`2^QE420:f4
D0040:j5C`2]Q4h0[HA>0:f4CP80[8==0P2[PT`20:V3DP040:Z5D@2[QU40[8MB0:b7D080[HU?0P2[
PTh0102/Pdl0[HA@0:f4D02^QE420:n6DPP0[XEA0P2]QDX60:b4B@80[HA@0`2/Pdl30:^2CPP0[89@
202/Pdd20:b3B`040:b3C@2]Q500[HA@0:j4DP80[XAD202^Q5801P2/Qe80ZhIA0:^6D@2ZQE00ZHA?
0:R3CP80Yh9=0P2YQD/0102YQ4d0ZHA?0:V4C`2YQ5020:V3DP030:V0C02ZPDd0Zh9>0080[8=?00<0
Zh9>0:Z1C@2YP4`00P2/P540102[Odh0Zh1=0:^0C@2ZOdX20:YoB080ZH1:0P2ZPD/20:^2C080[8==
2@2]Q500202ZPDd0Zh9>0:b3C`2/Pdl0Zh9>0:Z1C@2YP4`0Z7m;202/Pdl80:b3C@80[HA@0`2/Pdl6
0:^2CP<0[8=?0P2]Q5020:^2CP040:b3C`2]Q500[HA@0:j5D@80[hIB2@2]Pe401`2/PU00Zh5?0:Z0
CP2[PDl0[89@0:j4DP2_QE<00P2/Pdl40:j5D@80[8=?0P2[PT`20:b3C@<0[HA>00H0[XE?0:V4C`2Z
QE00ZXE@0:^6D@2/Qe820:f8D`040:j9E02^QE40[XEA0:j5D@80[HA@1P2/Pdl20:^2CP<0ZX5=0P2[
PTX0102[PT`0Zh9>0:^2CP2[PDl20:^1D@030:b2DP2]Pe<0[H=A0080[XEA00<0[HA>0:f4C02/Pd/0
0`2[PTh30:b3C`80[HA@00<0ZHA?0:R3CP2VPD`00P2UP4/00`2VPD`0Z8=>0:V4C`080:b1CP030:Z1
C@2[PTh0[8=?00<0[8=?00<0ZX5=0:V0C02XOd/00P2YP4`20:Z1C@80Zh9>0P2/Pdl80:^2C100Zh9>
0`2YQ4l20:R3CP<0Yh9=00@0Yge;0:QnC02XOT`0Z7i<0P2YOdd20:Z0CP80[8=?0P2[PTh20:Z1C@D0
ZH1<0P2XOd/30:MnBP<0[H9?0`2/PDh20:^0C@080:Z1B`2[PT`0[8==0:f4CP2/Pdd0Zh9<0:V0BP2X
OdT80:b2D0050:n6DP2^QE40[XEA0:f4D02/Pdl00P2[PTh00`2ZPDd0Zh9>0:^2CP060:^2CP80Zh9:
00@0Zh9<0:Z1C@2ZPDd0ZGm=0P2YOdl20:b2D0040:^1C`2ZP4h0ZGm=0:UoC@80Z7i<00P0XGe;0:=m
C02UP4`0ZH5=0:Z1C@2ZOdX0Zgi70:YmAPP0Z7m90`2XOd/50:V0C080ZX1>0P2YOdd40:QnC0040:Mm
B`2XOd/0Ygi:0:ImB@80YGa800@0YWe90:MnBP2XOd/0ZH1<0`2XOd/20:MnBP80YWe9202UP4/01P2V
PT@0YX960:J2AP2VPTP0YX5:0:J1C080YX5=00H0ZX5;0:V0BP2YP4X0Z7m90:MnB02VODL20:ElAP03
0:AiAP2UNTL0YW]800<0YW]800D0YGY70:AiAP2TNdL0YGa80:ImB@020:MnBP030:ImB@2UO4P0Y7]7
00P0Ygi:0`2TNTP20:=iA`<0XWQ6202QN4@00`2TNdD0XgY40:9i@`020:5h@P060:9i@`2SNT@0Y7]5
09id@P2OMD<0XGM50P2SNDL00`2RN4H0XGM50:1fA00309ehA080WWU50`2ONTH809ag@P<0VWE10P2K
MT8309ag@`<0XWU50`2QN4@20:1g@`P0WgE3102KMT8209Ye@@80VGA000H0VVm209]`@`2LLD@0WG95
09aaA02KL4<209U^@@0509Q]@02GLD80Ug5209Qb@`2ILd@00P2JM4D209]eAP<0W7M30P2KMT8309Ye
@@P0WG=1202IM40709Ye@@0309Ud@02GLD80Ug520080V7930P2ILd@209YdA@P0W7540`2KMdL309ah
B080WGU900H0WG5009ab@02LLT00Vg=009Ud@02HM40209Ie@0<0VWA5:oooool002[ooooo1P2?HSP2
08iQ=`P0Sf8h00H0UFPn09AW?@2BIC/0T6<i08iQ=`2;GS@208UL<PP0T6@g00<0TfLj099V>@2AICP0
0P2?HcH0102AICP0TVHi09=W>P2=HC@208iR=@0508mS=P2@I3L0TFDh095U>02BIST0102CIcX4099V
>@0808mR>02@HcT0TF@j099U>`2CIS`0U6Lm09EX?P2FJCl909=W>P0309AX>`2EJC`0Uf/n0080V6`o
00@0VFe009Y^@@2JKT40VFe00P2HK3l01@2GJch0UVXm09EY?02EJC`0U6Pk0080UFTl0P2DJ3/209=W
>P80TVHi202CIcX809I[>080UVXi0P2GJcX209Q/>`80VFdl00D0VVi109U]@02IKD00V6`o09M[?P02
09IZ?@0309EY?02JKc`0VVll00H0VVll0P2GJcX209Q/>`@0VFdl0`2MLSl309ic@080WgA1202MLSl8
09ea@080Vfm000@0W70o09aa?P2LLCh0WG8m0P2MLS/00`2PMD80WW=009eb?`0209aa?P0309eb?`2N
Ld00X7E200P0WgE3402RMd@20:=gAP80XWI50P2QMD@20:1d@`80XWM40P2SN4D40:AiAP<0XWM41@2S
N4D00`2TNDH0XgQ50:=hA@060:=hA@060:QmB02WO4L0YW]60:EjA@2TND@0XWM20P2QMT420:IjB@03
0:EiB02TN4L0XgM60080XWI500P0XGE409md@@2PMD80XGI30:9gA02SN4D0Y7U60:EjA`T0YW]8202T
NDH0402VO4X0YG]90:AjB02RN4H0X7I409id@P2MLd40W7900:EiB02SMdH0X7A309a`?`2KKch0VVhm
09]_?P2LL3l209ab@080Vg4o0P2JL3h209U_?@0609Y`?P2IKcd0V6hl09M]>`2FK3X0UF/i0P2DJSP0
102FK3X0UF/i09E[>@2EJcT209AZ>080TfTg0P2BIcX0102AIST0T6Dh08mT=`2>HcH208eR=@80SVPi
00@0SFLh08aV=`2;ICH0RV@e0P29Hc@01029HcH0R68e08QR=@28HSD208MQ=080QV0c2024Gc<808=L
<`0307mL=01nFc<0O5Ta00<0NUL_00/0NeP`07aI<@1kFC@0NeTd07]I<`1jFC00NUT^07UH:`1hEbX0
MeLX071C9`0207=D:00307ED:@1gE2X0NUD[00<0O5D/0P1gE2h00`1fDbd0ME8/07AA:`0207=@:P03
079?:@1cDB/0Le4[00@0LU0Z0P1aCbT406m>:`@0KTdZ0100KE4/06a@:`1ZCRT0JDdX06Q<9`1YCBP0
JThY06]?:P1^DRd0KE4/06e?:`1^CBX0KT`Y06e99`1/B2H0KTLV0P1]C2/306a;:P<0JdXY0`1XBRP2
06M99`D0ITPV0`1WBBL;06Q::080IdXX0P1VBBL406E89P80HdHT00@0I4LU06I89P1XBRP0JD/Y0P1/
BbX00`1XBRH0JD/W06U;9`0206U;9`80J4XV00@0IdTU06E78`1UAb<0IDLS0P1VB2@306M99@0306Q7
9P1YB2L0JTTX0080JdXY00<0JTTX06U89`1XAbH0201WBBD206e<:@0606a;:01ZBBH0JDPU06Q7901W
AR<0ITDR201XBRP206U89@H0JTTV0P1[B2P00`1YB2L0IdTW06E89P0206989@80HDTU201SAR@00`1V
BB/0IDPZ06=6:00306549P0606959`1SARP0GT@S05i48`1OAB@0H4HU101QAbH205i18`0405m2901P
@bD0HD@V06959`80HdHX0P1M@R@205i39@80GD8T0P1L@B<0201OB2H0GTLU05m79@1OAB@0H4<S0611
8P1R@B80HD0Q0P1R@2D0101P@BD0GT0T05a1901J@B<205U28`P0H4<S1P1QA2@206959@<0Hd@U0`1R
@b@206528`80H4<S0`1QA2@306959@0306948P1SAB<0I4HT0080IDLU0`1VB2H00`1RA280I4HT06M9
9`0206U;:@0406Q::01VB2H0I4HT06E99080ITXU00<0Id/V06Q<9`1YCBP00P1ZCRT0201YBbL0J4XV
06M99@1VB2@0IdTU06Q:9P1ZC2P0JddY0P1aCbT2071>:080KddW0P1^C2H2079B:`<0LE4Z0`1`D2T4
07EB:P80MU<[0`1gE2`00`1hEBd0NUL_07]H<00207]H<080NEH^101jEbd307UF;080N5D[00<0N5HX
07YH:P1nG2h00P21Gc400`1oGBl0O5X/07UG:@02085L;`80PUd`0P23GS4208AO<PP0QF4a2028I3@0
202;ICP0S6Hg08aV=`2=IcH0SVTe08mZ=@2?JS<0T6/d0P2CKSX209A_>`80UG0l0P2FLCd209=]?006
09A_>`2EL3/0UW4j09Mc>@2GLcL0V7@h202LLcl509]f@@<0W7M20`2MN4<209iiA0<0WgY5102RODP2
0:=nB@80Y7m:0P2UP4`20:J1C@80Yh9>0P2XPdl30:N2C@80Z8=>0`2YQ4l40:^6D@80[8MB0P2]R5<8
0:j9E@<0[XUD0P2_RUD30;2;EP80[hYF0`2`ReL30;6<F0P0/hUG2@2`RUT80;F<F0P0]8aI0P2aS5D0
0`2aS5L0/HaH0;6;FP020;6;G0030;6;GP2aS5P0/HaH00H0/HaH0`2bSET30;>>FP80]8mK202cSUX2
0;V?G@060;R>G02fS5X0]H]I0;B:F02cREL0/XQF0P2cSUX30;:=F@<0/HaH402bRED30;2;E`80[hYF
0`2^RED80:n:EPP0[XUD00<0[hYF0:j9E@2^RED00P2^RED30:f8E0P0[H=A202[QU860:j9E0D0[HQC
102/Qe800`2[QU40[hIB0:n6DP020:n6DP<0[XEA0P2]Q5020:^6D@80[8MB0P2]R5<20:j9E0H0/8ID
0P2_QE<20:n6DPP0[XEA0`2]Q5030:b3C`80Z89A00L0ZHA@0:^6D@2/Qe80[HQA0:j:D02_Re40Zh9>
0080[8=?0P2]Q5020:j5D@030:n6DP2^QE40[XEA00H0[XEA0`2/Pd/30:f4C080[XE=0P2]Q5030:b3
C`<0Zh9>202/Pdl80:b3C@80[8=;00@0[8==0:f4D02]Q500[XAB0P2^Q5@80:j4DP<0ZhIA00<0ZXE@
0:V4C`2YQ4l00P2XPdh20:Z6C0040:Z5CP2ZQE00ZXE@0:Z5D@80ZXAC00<0ZH1<0:Z1C@2ZPDd01@2[
PTh20:]oD0040:YnC@2ZOd`0ZGi;0:UnB@80ZGi70P2YP4X20:Z1B`80Zh9<0P2/Pdd90:f4D0080:V0
C02ZPDd0[8=?0:j5D@2]Q500Zh9>0:QoB`2VODT80:b3C`P0[8==0P2^QE400`2]Q500[8=?0:^2CP02
0:Z1C@030:V0C02[PTh0Zh9>00H0[8=?0P2[PTh0102/Pdl0[HA@0:f4D02^QE420:n6DPT0[H=A00L0
[89@0:^1C`2ZP4h0ZX1>0:^1C`2]Pe40[XAB00P0[HA@0`2/Pdd30:f4CP80[XE?0P2YQ4l0102ZQE00
ZhIA0:f8D`2^RE@20:n:E@<0[XEA0P2]Q5030:b3C`80[HA@0P2/Pdl20:^2CP80ZX5=0P2[PTX0102[
PT`0Zh9>0:^2CP2[PDl20:^1D@80[89B00@0[XAB0:j5D@2^QE40[XE?0P2/Pd/30:^2CP<0[8=?0P2]
Q5000`2YQ4l0Z8=>0:N2C@020:F0B`030:N2C@2XPdh0ZHA?00h0Zh9>00<0ZX5=0:V0C02YP4`00P2Y
P4`20:Z1C@80Zh9>0P2/Pdl80:^2C100Zh9>0P2YQ4l30:R3CP<0Yh9=0`2XOT`20:UoC@<0ZX1>0P2/
Pdl20:^2CP80ZX5=0P2YP4`30:QoB`<0Ygi:0P2VODT60:b1CP80Zh1=00<0Zh9>0:b3C`2]Q5000P2^
QE400`2]Q500Zh9>0:Z1C@080:b2D0@0[XEA102]Q5080:^2CP80Zh9:00@0ZX5;0:Z1C@2YP4`0ZGm=
0P2XOTh20:^2CP80ZX5=0P2YP4`20:QoB`080:5mB`2SOD`0YH1<0:V1C@2ZPDd0ZWm:0:]nA`2ZODH8
0:QoB@<0ZX5=0P2YP4`30:QoB`<0ZX1>0P2YOdd40:QnC0P0YWe90`2XOd/20:MnBP<0YWe90P2TOdX4
0:F0B`80YX5<00H0YX940:J2AP2VPTH0YX980:J1BP2VPD`20:J1C@<0ZH1<00<0Z7m;0:MnBP2WOTX0
0P2VODT80:IkB0030:AkA`2UO4P0YGa800@0YGa800<0Y7]70:MnBP2WOTX01P2WOTX30:AjB080XgU7
0`2RN4H80:9iA@<0XgY60P2RNDD30:=jAP0809id@P2PMT@0XWQ60:=iA`2TNTP0XgU70:9hAP2QMdD2
09ehA080WWU50P2ONTH20:1kA`P0W7M20`2JMD4209]f@P<0W7M3102SNTH20:9iA@80XGQ40`2PMT@4
09me@`0309id@P2KMT80VgI200@0VgI20P2JMD400`2KL4<0W75409ebA@0209ebA@0409]`@`2IKT40
VFi109Q]@080V7930P2ILd@209YdA@80VgE60P2NNDD0102MN4@0W7M309Ye@@2IM40209Qc?`P0WWA2
202JMD4309Ud@0<0VWE10P2KMT8209Ma@P80V7930P2ILd@209YdA@P0Vg940P2IMDD00`2JMTH0VgM7
09ahB00209eiB@0709ijBP2NLT<0WG=309ec@`2LM4<0VWA309Ue@`0209Mf@`<0VWA5:oooool002[o
oooo0P2>HCL>08mR>003099S>@2AHSP0TF8h0080TF8h0`2@HCL8091T=`0309=W>P2BIST0TFDh0080
Sf<f00@0TFDh099V>@2CIcX0SF4d0P2>HSD0102?HcH0T6@g095U>02AICP5099V>@@0TfLj00P0Sf8h
091S>@2AI3X0TVDk09=V?02DIcd0UFPn09IY?`P0TfLj0P2DJ3/01`2EJC`0UVXm09M[?P2GJch0VFe0
09Y^@@2KKd800P2HK3l0102GJch0UVXm09IZ?@2EJC`209AX>`<0UFTl0P2DJ3/;09=W>PP0Uf`i0P2F
JST209M[>P80V6`k0P2IKC`01@2JKT40VFe009U]@02HK3l0Uf/n0080UVXm00<0UFTl09Y_?02JKc`0
1P2JKc`409]_?P80W70o0P2MLD0309eb?`<0WW=00P2OM44809eb?`P0WG500P2LL440102LL3l0WG8o
09eb?`2MLSd209ic?0030:1e@P2NLd00WG8o0080W74n00<0WG8o09ic@02PMD80202PMT@@0:9gA0@0
XWI5102QMD@20:9gA080XgQ5102TNDH20:5f@`80XWM400<0XgQ50:AiAP2TNDH00P2TNDH01P2NLd00
WgA10:1e@P2RMd@0Y7U60:EjA`80Yga90P2WO4L01`2VNdH0Y7U40:=h@`2RMd80XGI10:1e@02WNd`0
0P2VNT/00`2UNDX0Y7Q90:=gB0020:9fA`80X7E200@0XGI30:9gA02TNDH0YGY72P2VNdP80:AiAP0<
0:EkB@2TNTP0XgU70:5gA@2OMD<0WG=109ab@02KLCl0YWY90:=gAP2OLd80Vfln0P2IKC`00`2KKch0
W70o09]a?`0209]a?`80VW0n0`2IKcd209Q^?080Ufdk00@0UV`j09E[>@2EJcT0U6Xh0P2EJcT209AZ
>0<0TfTg00L0TVPf095V>@2AIST0T6Dh08mT=`2>HcH0SF8e0080S64d0P2<ISL208]U=P0408YT=@29
Hc@0R68c08QR<`80R64f0P27H3D308IO=00308EN<`23GS@0Pehd00H0Pehd2021FS400`1mFS80O5Ta
07]H<00207UF;P0A07YG;`1kF300O5Ta07]K=@1jFS@0NETb07QH;`1gF2`0MULY07EF:01eERL0M5L[
07IG:`1eERX0ME@Y07EB:01fDBL00P1gD2L02P1fCbH0ME8/07EB;01eDR`0M54[07=@:P1bCbT0LDhX
071=9`1bDR/2075A:P80L50Y0P1_CbP00`1^CRL0KD`Y06e<:@0206e<:@@0KTdZ0100KDl[06a>:P1Z
C2P0JD/W06Q:9P1YBbL0JT`X06]=:@1]DB`0K50[06a>:P1]C2T0KD/X06a89P1[AbD0KDHU0`1/BbX3
06]::@80JTTX0`1XBRP206M99`H0ITPV0`1WBBL206Q::0P0JD/Y101XBRP206M99`80ITPV0P1VAB@0
101UAbD0ITPV06Q::01XBbT206U<:P80JT`X00<0JD/W06Q:9P1XBRH00`1WBBD306I89080IdTU0`1X
BRH00`1ZAbL0JdPX06e::P0206i;:`0306e::P1[B2P0JTLW00P0IdTS0P1^CRP01P1]CBL0Jd/U06Y:
901YBB<0J4PR06M78@P0JD/Y1@1[BRL306Y99P0506a9:@1[B2P0JTTX06Q::01WBRP00P1TBRL206=;
9`P0IDLU00T0IdXZ06I9:@1TAbL0HdHV06959@1SARH0I4LW06E8:01O@R800`1N@B4205m28PD0H4<S
00<0HD@T06959@1SARH00P1SARH20654900306138`1O@R80Gd8R00<0GT4Q00P0H4TW05m89P1PB2H0
H4HU0654901Q@R<0Hd8S06918P80HT0U00@0H44U05i0901L@B@0FT4S0P1I@R<405m28P@0H4<S1P1Q
A2@206138`80Hd@U0`1R@b@306528`<0H4<S0`1QA2@206959@D0I4HT0P1UAbD02P1VB2H0HD<Q06=5
8`1VB2H0J4XX06U;:@1WBBL0IDLU06A6901TB2<206E9900306I:9@1WBbH0J4`W0080JDdX00P0J4XV
06M99@1VB2@0IDLS06I8901WBBD0JD/W06Y<:0@0KThX101]CBL3075A:P<0L50Y0P1_CbP207=@:080
M54Y101eDRX00`1fDb/0Me@/07UF;P0307]H<00307YG;`1iERh0NEH/00<0NEH/0`1hEB/207MD:P08
07AD9@1hF2T0O5`]081P<@21HC80OUh_07YJ:`1gEbP3085L;`80PUd`0`23GS4808AP<0P0Qf<c00P0
RV@g08]U=P2;ICH0S6He08iY=@2?JSD0SfXc091[=0@0Tfhj102DKc/2099/?@0609=]?02DKc/0UG0k
09Ia>P2FLSP0Ug<i202KLSh809]f@@<0W7M20P2MN4<309iiA080XGa70P2RODP40:=nB@<0YH1<0P2V
PDd30:N2CP<0YX5<0P2WPTd30:R3CP<0ZXE@0`2[QU420:b7DPP0[XUE0`2^RE@20:n:E@<0/8]F0P2_
RUH30;2;E`<0/HaH202cREL50;6<F0@0/8]G202eS5P80;F;F@80/XeF00<0/XeH0;:=F@2bS5/00P2b
S5d00`2bS5l0/XeI0;:=F@090;:=F@<0/hiJ0P2dSe/80;>>FP80^HmM00H0^8iL0;J<FP2eReT0]8YH
0;>9E`2bR5H30;:=F@<0/HaH0P2`ReL@0;:9E@<0/8]G0P2_RUH30:j9E@P0[hYF202^RE@30:n:EP03
0:j9E@2]R5@0[HQD0080[8MC202^Q5880:^6DP80[HQC2@2^RE@00`2]R5<0[8MB0:b7DP020:^6D@@0
[hIB0`2^QE420:f4D080ZhIA0P2/Qe820:f8D`80[XUD1P2_QE<20;26E0H0[XEA0P2_QU830:j5D@<0
[HA@0P2/Pdl20:R2D@060:V4D02[QU40[8MB0:f8D@2^RU00[h]A0P2/Pdl40:f4D0X0[XEA0P2/Pdd3
0:f4CP<0[XE?0P2]Q5030:b3C`<0Zh9>202/Pdl80:b3C@80[8=;00@0[8==0:f4D02]Q500[XAB0P2^
Q5@80:j4DP<0ZhIA102ZQE00102YQ4l0ZXI<0:Z6C02ZQDh20:Z5D0030:Z5D@2ZQ5<0ZXAC00<0ZH1<
0P2ZPDd00`2[PTh0[8=?0:f4D0020:]oD0040:YnC@2ZOd`0ZGi;0:UnB@80ZGi70P2YP4X20:Z1B`80
Zh9<0P2/Pdd90:f4D0080:V0C02ZPDd0[8=?0:j5D@2]Q500Zh9>0:QoB`2VODT80:b3C`P0[8==0P2^
QE400`2]Q500[8=?0:^2CP020:Z1C@030:V0C02/Pdl0[8=?00@0[8=?102[PTh0102/Pdl0[HA@0:f4
D02^QE420:n6DPP0[H=A00<0[XAB0:f3D@2[PDl00P2ZP4h00`2[PDl0[89@0:f3D@080:f4D080[8==
0`2]Q4h30:j5C`060:R3CP2YQ4l0ZXE@0:^6D@2/Qe80[XUD0P2_RUD30:j5D@80[HA@0`2/Pdl30:f4
D080[8=?0`2[PTh20:^2BP040:^2C02[PTh0Zh9>0:^1C`<0Zh5A00L0[89B0:j4DP2_QU80[hIB0:j5
C`2/Pd/0Zh9:00<0Zh9>0`2/Pdl20:f4D0030:Z5D02XPdh0Yh9=0080YX5<00<0Yh9=0:R3CP2ZQE00
202ZPTh20:b3C`030:^2CP2ZPDd0ZX5=00@0ZX5=0P2YP4`20:Z1C@80Zh9>0P2/Pdl80:^2C100Zh9>
0`2XPdh30:N2C@80YX5<0P2XOT`20:UoC@80ZX1>0P2[PDl20:b3C`80Zh9>0P2ZPDd40:V0C080Z7m;
0`2WOTX00`2VODT0Zh1=0:^0C@040:^0C@80[85>00<0ZX5=0:^2CP2]Q5000P2^QE400`2]Q500[8=?
0:^2CP080:b2D0@0[HA@102^QE480:^2CP80ZX5900@0ZX5;0:V0C02YP4`0Z7i<0P2XOTh20:Z1C@@0
ZH1<0P2XOd/0202QOD/0Xge<0:F0C02YPDd0ZX5=0:YoBP2[OTL0ZWe6202XOdT0102[PTh0ZX5=0:Z1
C@2ZPDd30:V0C0030:QoB`2[PDl0Zh5?0080ZX1>0`2YOdd20:QnC080YWe9102WOTX20:ImB@80Z7m;
0P2WOTX20:ImB@80YGa800<0Xgi90:AoBP2TOdX00P2UP4/20:J1C0070:N2C@2VPT@0YX960:J2AP2V
PTP0YX5:0:J1C0020:J1C@<0ZH1<102XOd/00`2WOTX0Yga90:MlB@060:MlB@030:ImB@2UO4P0YGa8
00@0YGa800<0YWe90:MnBP2WOTX01P2WOTX30:AjB080XgU70`2RN4H80:9iA@<0XgY60P2TNdL30:=j
AP0309me@`2PMT@0XWQ60080Y7Y800<0XgU70:9hAP2QMdD00`2NNDD209mjAP<0X7]7202MN4<309Ye
@@80VgI20`2LMd<40:=jAP80XWU50P2QN4@20:5gA@80X7I400@0WgE309id@P2NM480WWA21P2KMT82
09ag@`0609]`@`2LLD@0WG9509icAP2MLTD0W7540P2JKd800`2IKT40VG=409UcA00409YdA@80VgE6
00P0WgY609iiA@2MN4@0W7M309Ye@@2IM400V7<o09Mb?PP0WWA2202JMD4309Ud@0<0VWE10P2KMT82
09Ma@P80V7930P2ILd@209YdA@P0VG=400H0UW9209Mc@`2GLd<0V7A409UeA@2JMTH209]gA`0609ib
A@2MLTD0WG9509acA@2JM4D0VGE50P2GMDD309YdAB_ooooo000Zooooo`<0SV4g0`2?HSP2091S>@P0
Sf8h0P2?GSD01P2@GcH0TF0g099Q>02CHST0U6<j09ET>`P0Sf<f00<0TfLj099V>@2AICP00P2?HcH0
0`2AICP0TVHi09=W>P04091T=`D0TFDh0`2BIST309=W>P0609AX>`2@HcT0TF@j095T>P2BIC/0TfHl
0P2DIcd00`2EJ3h0U6Pk09AX>`0609AX>`0409EY?02DJ3/0U6Pk09AX>`80UFTl00@0UVXm09Q/?`2I
KD00Uf/n0`2FJSd409EY?00409IZ?@2EJC`0UFTl09EY?080U6Pk0P2CIcX809EY?0P0Uf`g0P2FJST2
09M[>P80V6`k0P2IKC`409Q/?`@0Uf/n202KL3/209ea@0<0W70o00<0WG5009mc@P2PM4<00`2MLSl3
09ic@080WgA1202MLSl809ea@080W71100@0W70o09eb?`2MLSl0WW<n0P2NLc`00`2PMD80WW=009eb
?`0209aa?P0309eb?`2NLd00X7E200P0X7I4202RMd@80:1e@P80X7A30P2QMD@20:9fA@80XgM60P2Q
MT<30:9gA0<0XgQ500D0X7E20:5f@`2QMT<0XWM40:=hA@020:AiAP80YGY70P2NLd001P2PMD80XWM4
0:AiAP2VNdP0Yga90:QmBP<0YGY500<0Y7U40:=h@`2RMd800P2QMT40102VNTd0YGU<0:EiC02UND`4
0:AhB`050:5f@`2RMd@0XWM40:=hA@2TNDH00P2UNTL00`2VNdP0YGY70:EjA`060:EjA`P0XgQ500H0
XgU70:9hAP2QMdD0X7I409id@P2MLd4209ab@0040:=gAP2QMD@0WW9109]_?P80VVhm00@0Vfln09a`
?`2KLCl0Vg4o0P2JL3h309U_?@0409Q^?02GKC/0Ufdk09M]>`80UV`j0P2EJcT309AZ>080TfTg0`2B
J3H01P2AIcD0T6Dh091U>02?I3L0SV<f08eR=@80S64d00H0Rf0c08]U=P2;ICH0RV@e08US=028HS<2
08MQ<P0308IP<@27H3L0Qf0g0080QUlf0`25GSD00`24GC@0PU`e089L=@06089L=@P0P5T`00<0O5Ta
07]H<01iERh00P1hEBd0201iERh0NeP`07aI<@1hFS@0MeTc07EH<01dEbd0LeHZ0P1cEbP01`1dF2P0
MEP/07IG:`1eERX0ME@Y07AA9`1eD2H00`1dCB@207=@:P0607AA:`1cD2X0LTlY075>:01_C2H0KT/U
0P1_DRX206iA:@0406e@:01/CbL0JdhV06]>9P@0K4/X0P1]C2T306i=:P0<06e<:@1[BRL0JTTV06U8
9@1ZBBH0JdXW06a;:01[CbX0JThY06]=:@1/BbP0K4XW0P1/B2H0101]ARD0K4/Z06a;:P1/BbX206]:
:@<0JTTX0`1XBRP206M99`<0ITPV0P1UARL206I7:0<0IdPY00<0J4TZ06U;:@1YBbT01P1YBbT206Y9
:0<0JdXY00<0JTTX06Q79P1WARD00P1XABD02@1XAbH0IdTW06I99`1UBbP0IT`Y06E=:@1ZC2P0JD/W
06Q:9P0306M99@0306Q:9P1YBbL0JD/W00L0JD/W00<0KDTY06i::P1_Bb/00P1`C2`00`1_Bb/0KTXZ
06e9:@0806Q;8`0506i>9`1]CBH0KDdV06a<9@1[Bb@00P1ZBR<00`1YBB80JT`Z06Y<:P0606Y<:P80
KD`Y0P1/BbP406]:9`80K4TY00<0JdXY06U;:@1XBbT00P1VC2T206E=:@80JDPU0`1XAb@306M68`03
06U<:P1WBRP0ITTW00<0I4LU00@0IDPV06I99`1Q@R<0H44R0`1O@240101P@B80HD8S06528`1SAR@7
06958`0406I89P1TAR@0HdDS06538@80H48P0P1Q@b4205m89P0606189P1QAbH0HTDU06=49@1UA2D0
I4<T0P1S@BH0101Q@RH0Gd4U05e29@1K@R@205Y390<0GT4Q0P1O@R8306138`@0HD@T0P1P@b<205m2
8P0406=49@1R@b@0HT<T06939080HD8S0P1P@B8205m28P80H4<S0`1QA2@0101RABD0ITPV06E79@1T
AR@206=58`0706A6901UAbD0ITPV06948P1SAB<0I4HT06E79@0206I89P0306E79@1TAR@0HdLR0080
I4PS00<0IDTT06I:9@1WBbH00P1XC2L0201XBRH0IdTU06I8901UAb<0ITPT06M99@1YBbL0JT`X1`1[
CBT00`1ZC2P0L50Y071@:@06071@:@<0LTlW0P1cD2P307AA:@0407=@:01eDRX0Me@/07UF;P80NUL_
00<0NEH^07QE;@1gE2X01@1gE2X307QE:`09079C901eERL0NU//07eN;`1nGc00O5d^07UJ:`1gF2T0
P5/^00<0PE`_0P22GC0208=N<@P0Pel_2026HS801P29HcH0RV@e08]U=P2<ISD0SFPd08mZ=@80T6/d
00<0TF`h099]>@2BKCT01@2BKCT0202AJch0TF/l099/?@2CKC`0U6lk09E`>`2EL3T0UW4j0P2KLSh0
102JLCd0VG0l09U`?02JLCd209]b?PD0VWE01P2KMT4209ag@P<0WGQ300<0WgY50:1kAP2RODP00`2S
OTT20:9mB0040:AoB`2UP4`0YH1<0:F0C080YX5=0P2WPTh30:F0B`80YX5<0`2WPTd30:V4C`80ZXE@
0`2[QU480:f8E0<0[XUD0P2_RUD30;2;EP80[hYF0`2`ReL30;6<F0P0/hUG102bSEP20;6<E`<0/8]F
202eS5P80;J:F@80/XeF00<0/XeH0;:=F@2bS5/00P2bS5d00`2bS5l0/XeI0;:=F@090;:=F@<0/hiJ
0P2dSe/80;>>FP80^8iL00@0]heK0;J<FP2eReT0]H]I0P2dRUP30;:=F@80/HaH0`2`ReL30;67E@80
/XQF0`2cREL80;:9E@<0/8]G0P2_RUH30:j9E@P0/8]G202^RE@20;2;E`030:n:EP2^RED0[HQD0080
[8MC00<0ZhIB0:n5D`2_QE<01P2_QE<80:b7D`<0[HQC0`2^RE@20:n:E@80[hYF0P2^RED0102]R5@0
[8MC0:^6DP2[QU840:n6DP<0[XEA0P2]Q5020:^6D@80[8MB0P2]R5<20:j9E0<0[XAB0`2_QE<20;26
E080[HA@0`2^QE430:n6DP80[hEC0P2^Q5830:f3D@070:b2D02YPe80ZH=B0:Z5D@2[QU40[8MB0:b7
D0020:f9C`P0[HA@3P2^QE440:f4D0<0[8=?0`2[PTh@0:b3C@80[8=;00@0[8==0:f4D02]Q500[XAB
0P2^Q5@80:j4DPP0ZhIA0P2[Qdd0102[QTl0ZhIA0:^6D@2[QU820:^5E0@0ZH1<00@0ZX5=0:^2CP2]
Q500[XEA0P2/P540102[Odh0Zh1=0:^0C@2ZOdX20:YoB080ZH1:0P2ZPD/20:^2C080[8==2@2]Q500
202ZPDd0Zh9>0:b3C`2/Pdl0Zh9>0:Z1C@2YP4`0Z7m;202/Pdl80:b3C@80[HA@0`2/Pdl30:^2CP80
[HA@0`2/Pdl50:^2CP040:b3C`2]Q500[HA@0:j5D@80[hIB202]Pe400`2^Q580[H=A0:^1C`020:Uo
C@030:Z0CP2[PDl0[89@0080[XEA102/Pdl20:j5D@040:b3C@2]Q4h0[HA>0:f4CP80[XE?0P2_QU02
0:R3CP040:V4C`2ZQE00ZXE@0:^6D@80[8MB0`2^QE420:f4D0<0[8=?00@0[XEA0:f4D02]Q500[HA@
0P2/Pdl20:^2CP80Zh9:00@0Zh9<0:^2CP2[PTh0Zh5?0P2[PE400`2ZP500[89B0:j4DP020;27D`03
0:j5C`2/Pd/0ZX5900<0Zh9>0`2/Pdl20:f4D0030:Z5D02YQ4l0Yh9=0080YX5<00<0Yh9=0:V4C`2Z
QE00202XPdh00`2]Q500[8=?0:^2CP040:V0C0040:Z1C@2[PTh0ZH1<0:V0C080ZX5=0P2[PTh20:b3
C`P0Zh9<402[PTh30:R3CP80Yh9=0`2VPD`30:UoC@80ZX1>0`2[PDl20:b3C`80Zh9>0P2ZPDd20:V0
C0<0ZX5=0P2YP4`30:QoB`<0ZWm<0`2[P4d20:b1CP030:UoC@2ZP4h0[89@0080[XAB00<0[H=A0:b2
D02[PDl0202/PU001@2ZPDd0Zh9>0:^2CP2/Pdl0[HA@0080[XEA00<0[hIB0:^2CP2[PTh01P2[PTh2
0:Z1B@060:V0BP2YP4`0Z7m;0:QnC02XOTh0Yge=1@2YP4X30:QoB@080:5mB`2SOD`0YH1<0:V1C@2Z
PDd0ZWm:0:]nA`2ZODH80:QoB@P0ZX5=0`2[PDl20:Z0CP@0ZGm=0P2WOTX0102XOd/0ZH1<0:V0C02X
Od/50:MnBP80YWe90`2UO4P20:=nB@040:AoBP2UP4/0YH1;0:J1C080Yh9=00H0YX940:J2AP2VPTH0
YX980:J1BP2VPD`20:J1C@P0ZGm=00<0ZGi;0:QmBP2WO4T00`2WO4T01@2XODX0ZGi;0:QoB`2WOTX0
YWe90080YGa800<0YWe90:MnBP2XOd/0202WOTX30:AjB080XgU70`2RN4H80:9iA@030:9hAP2SNDL0
Y7Y80080YG]900H0Y7Y80:=iA`2RN4H0WgE30:5gA@2RN4H30:AjB0040:=iA`2RN4H0WWU509iiA@80
WgY60`2PNdL00`2QO4P0WGQ309eh@`0609eh@`<0VWE10P2KMT8309ag@`<0XWU50`2QN4@20:1g@`06
0:9hAP2QMdD0XGM50:1fA02OMD<0WWA20P2MLd4409]f@P80W7M30P2MN4@209aaA0<0WW=600@0W754
09Y_@P2JKd80VFi11@2JM4D309]eAP80WWU500@0WGQ409ag@`2JMD40VGA00P2HLcl809me@`l0VWE1
00<0VGA009Ma@P2GLD800P2HLT<209UcA080VWA5202HM4@209Mc@`<0V7A40`2IMDD01P2NLDL0WG97
09ebA`2LLdL0VWA709UdA`80UgE70`2JM4D[ooooo`00:_ooool208eP=P80SV4g00<0Sf8h091S>@2@
HcT02@2@HcT2091O=P80TF0g00@0TV4h09=R>@2DHcX0U6<j202?HcH00`2CIcX0TVHi095U>00208mS
=P03095U>02BIST0TfLj00<0TfLj0P2BIST5095U>080TVHi0P2CIcX209AX>`@0TVDk102CIS`809EY
?00309IZ?@2EJC`0TfLj00<0TVHi00<0U6Pk09EY?02FJSd00P2DJ3/309EY?0D0UVXm0`2EJC`309AX
>`P0Uf/n202GK3D209IZ>@80Uf/j0P2HK3/209U]?0@0Uf/n102HK3l809]`>@0809]_?P2JKSd0VFdl
09Q/>`2IKC`0Vfln09a`?`2NLT4309eb?`<0WW=00P2OM44809eb?`P0WG5000H0W71109ea@P2MLD00
WG8o09ic@02NLch209md?@030:1e@P2NLd00WG8o0080W74n00<0WG8o09ic@02PMD80202PMT@80:9g
A0P0WW=00P2NLT40102OLd80XGE40:9fA@2TN4L20:EiB0<0X7E20`2QMT<20:9gA080X7E200<0XGI3
0:9gA02SN4D00P2TNDH00`2UNTL0YW]80:=hA@070:=hA@P0XgQ30`2TN4/20:EiC0<0YWY=202TNDH@
0:=hA@80X7I40P2OMD<209id@P80WG=100<0Wg=209ib@@2MLD001@2LL3l309Y`?P<0VFlm0P2HKS`4
09I/>P@0UF/i0`2CJCL2099X=P<0TFLe0P2?I3L0102>HcH0SF8e08aQ=02<HC@208]P<`80RV@e00<0
RF<d08QR<`27HC800P26H3401025Gc00QUlf08IO=P26GcH208EN=@<0Q5dd2021FcH807mH;`0307]H
<01jEbl0N5D]0080Me@/00`0NEH^07YG;`1kF300MUXc07AH<@1cEbl0LEH[075F:@1bEbP0LePY07AJ
:@1aE2P207=D:00307=B9`1dDBL0MU4W00<0MTlV00P0LDhX079?:@1cD2X0Le0Z079?:@1`CBL0KT/U
06a98`80KU8Z00@0KE4Y06a@:01[CbL0JThV0P1YCBD00`1ZBBH0JdXW06]:9`0206a;:080KD`Y00@0
KTdZ06m=:P1]BbP0K4XW0`1ZB2D02`1[BBH0K4XW06Q<9`1XC2L0JD/W06]:9`1/BRL0KDTW06a89P1^
AbH0K4/Z00<0JdXY0P1ZBBP206U89`<0J4XX0P1WBBL306I89P<0IDHY0P1VAbX306M8:`P0JD/Y00<0
JTLW06]8:01]BRX00P1]BRX03P1[B2P0JDHV06Q59@1]ARL0JdLW06Y79`1YB2L0ITTW06A:9`1SBbL0
HT`W06Y<:01YBbL0IdTU0P1VB2@00`1XBRH0JD/W06]=:@0206e?:`0406a>:P1[CBT0JddY06Y<:080
JD/W00<0KTXZ06m;:`1`C2`00P1aCBd00`1`C2`0Kd/[06i::P0806U<9080KDdV1P1/C2D806Y<:P80
KTdZ0P1]C2T0101/BbP0JdXW06]:9`1[BRL206e::P0306a;:P1ZC2X0JD`Z0080IddZ0P1WCb/206]9
9080JTPS0P1YAb8206Q68@0306Y>:@1XC2L0Id/V00<0IDTT00/0ITXU06M;9P1YB2T0J4LX06I59P1U
A2D0I4<T06E49@1WARL0J4LX06I:9@0206E9900306A88`1SAb80HTHQ0080HDDP00@0JdXW06U89@1W
AR<0I4<P0P1S@Ql0201T@b00ID@Q05i79@1NAbD0H4PV06579P1SARH0IDHW0P1WARL206E3:0040693
9`1Q@bL0GT<V05e49P80Fd@U0P1M@20205i18@0505m28P1P@b<0H4<S06138`1RABD00P1QA2@20613
8`80Gd8R00@0GT4Q0693901R@b@0HT<T0P1Q@R<306118P<0Gd8R0P1P@b<30654900:06M99`1VB2H0
I4HT06=58`1RA280HdDS06E79@1VB2H0I4HT06=58`80HT@R00@0HdDS06A6901UAbD0ITPV0P1SAb80
0`1TB2<0IDTT06I:9@0206M;9P0906Q<9`1YBbL0J4XV06M99@1VB2@0IdTU06Q:9P1ZC2P0JddY00P0
JDdX00D0KDdV06i>9`1^CRL0KdlX071@:@02075A:P04079B:`1aCRH0LDhV075>9P80LTlW0`1cD2P0
101aCRH0Le0X07EB:P1gE2`207QE;@80Me@/101eDRP00`1fDbT0Me@Z07QE:`0207UF;00407=D9@1e
ERL0N5TZ07YK;080Ne`]00@0NU//07UJ:`20Fbh0P5/^0`21G2l3089M<0P0Pel_2025HC401P28HSD0
RF<d08YT=@2;IC@0SFPd08mZ=@80T6/d102@JcL408mZ=P06091Z?@2AJch0TF/l099/?@2CKC`0U6lk
0P2EL3/00`2KLSh0VW4m09U`?00209Q_>`0309U`?02JLCd0Vg8n0080V7<n00<0VG@o09Ye@02JMD00
0P2KMT400`2LMd80VWE009Ye@00209]f@@<0W7M200T0WGQ309iiA02PNdH0XWe80:=nB@2TOdX0Xgi9
0:9mB02QO4L00P2TOd/30:F0C0<0YX5=0P2TOdX20:F0B`<0YX5<00@0Yh9=0:R3CP2XPdh0Z8=>0P2Y
Q4l30:Z5D0P0[HQD0`2^RE@20:n:E@<0/8]F0P2_RUH30;2;E`<0/HaH202cREL30;>>E`80/XeF00@0
/HaE0;2;E02`Re@0/8]D202eS5P80;R:F@80/hiG00<0/hiI0;>>FP2cSE`00P2cSEh00`2cSF00/hiJ
0;>>FP060;>>FP<0/XeI0`2cSUX20;B?F`P0/hiJ1`2fS5X00`2eReT0/XeI0;6<F0020;6<F080/8]G
0P2_RUH00`2`QUH0/HMG0;67E`020;:8F080/hUI00<0]8YJ0;:9E@2bRED01P2bRED30;2;E`80[hYF
0`2^RED80;2;E`P0[hYE00H0/HaH0;2;E`2_RUH0[XUE0:f8E02/Qe<20:^6DPP0/HME202]R5@20:b7
DP80[HQC00@0[XUD0:n:E@2_RUD0[hYE0P2`RUT0102_REP0[XQG0:f7EP2/QUD20:^5E0@0[hIB0`2^
QE420:f4D080ZhIA0P2/Qe820:f8D`80[XUD0P2]Pe420:j4DP80[hEC0P2`QU@30:f4D0030:j5D@2_
QU80[hIB0080/8MC0`2_QED20:j4E0<0[H=C0P2[QE@01P2[QU80ZhIA0:^6D@2[QTl0ZhM=0:b8CPP0
[HA@202^QE420;26E0040:n5D`2^Q580[XAB0:f3D@80[89@0P2]Q5030:b3C`<0Zh9>202/Pd/80:b3
C@80[8=;00@0[8==0:f4D02]Q500[XAB0P2^Q5@80:j4DPP0ZhIA0P2[Qdd0102[QTl0ZhIA0:^6D@2[
QU820:^5E0080:Z1C@2YP4`0Z7m;0:QoB`2YP4`0Zh9>0:j5D@2_QU820:f1DP040:f1D02/PDh0[85>
0:b1C080Zh190P2YP4X20:Z1B`80Zh9<0P2/Pdd:0:f4D0030:b3C`2[PTh0ZX5=0080ZH1<00<0ZX5=
0:^2CP2/Pdl01`2/Pdl80:b3C@<0Zh9>0`2/Pdl50:f4D0030:b3C`2[PTh0Zh9>0080ZX5=0P2[PTh0
102/Pdl0[HA@0:f4D02^QE420:n6DPP0[H=A00<0[XAB0:f3D@2[PDl00`2YOdd01@2ZP4h0Zh5?0:n6
DP2^QE40[8=?0080Zh9>00<0[8=?0:j5D@2_QU800`2]Q4h20:j5C`<0[hI@202XPdh30:j5D@80[HA@
0`2/Pdl20:j5D@<0[HA@0`2/Pdl20:^2BP040:^2C02[PTh0Zh9>0:^1C`80Zh5A00<0ZGm?0:^1D@2_
QE<00P2aR5@00`2_QU00Zh9:0:V0B0030:^2CP<0[8=?0P2]Q5000`2ZQE00ZHA?0:R3CP020:N2C@03
0:R3CP2YQ4l0ZXE@00P0Z8=>00@0[XEA0:b3C`2ZPDd0ZH1<0P2XOd/00`2YP4`0ZX5=0:^2CP020:V0
C080ZX5=0P2[PTh20:b3C`P0Zh9<402[PTh0102XPdh0Yh9=0:N2C@2WPTd20:J1C080YH1;0P2YOdd2
0:Z0CP@0Zh5?0P2/Pdl20:^2CP80ZX5=0P2YP4`30:b3C`80Zh9>0`2ZPDd20:UnB`80ZWm<0P2[P4d2
0:b1CP060:MmC@2YOdl0Zh5A0:b2DP2]Pe<0[89B0P2[PE480:b2D080Z7m;00@0ZH1<0:Z1C@2/Pdl0
[HA@0P2^QE480:^2CP80ZH1800@0ZH1:0:QoB`2XOd/0Z7i<0P2WODd60:QoA`80ZH1800P0XGe;0:=m
C02UP4`0ZH5=0:Z1C@2ZOdX0Zgi70:YmAPP0Z7m90P2XOd/00`2YP4`0ZX5=0:^2CP030:b3C`@0Zh5?
0`2ZP4h20:UoC@030:QoB`2YP4`0Zh9>0080[8=?00<0Zh9>0:V0C02XOd/00P2WOTX20:ImB@@0YGa8
00D0XWe80:=nB@2SOTT0Y7m:0:J1C0020:N2C@070:R3CP2VPT@0YX960:J2AP2VPTP0YX5:0:J1C002
0:J1C@P0ZGm?00<0ZWm<0:UnB`2XODX00P2WO4T01P2XODX0ZGi;0:YoC02ZPDd0ZH1<0:QoB`80Ygi:
00<0Z7m;0:V0C02ZPDd0202WOTX30:AjB080XgU70`2RN4H80:=jAP030:9hB02SNDT0YG];0080YWa<
00/0YG];0:=iB@2RN4P0X7I40:5gA@2SNDL0Y7Y80:EkB@2TNTP0XgU70:9hAP0309mjAP<0X7]70P2Q
O4P809eh@`<0VWE10P2KMT8309ag@`80XGQ40`2PMd<309mf@P80XWQ600L0XGM50:1fA02OMD<0WWA2
09ec@@2LLT00VWE10080VgI20P2LMd<209ehA00709iiA@2LLD@0WG9509icAP2OM4L0WW=609ebA@02
09]`@`0309Y_@P2KMDH0VgE600@0VgE60P2JM4D209ehA00409ag@`2KMT80VgI209Ye@@80VGA0202O
MD<809]f@P80W7M300@0VgI209Ye@@2IM400VGA00P2HLcl209Ma@P80V7930P2ILd@209YdA@P0UWA4
102LN4P309]gA`0709YfAP2OLTT0WW=909icB@2MLdT0VgA909YeB@0209QfB@<0VWA5:oooool002[o
oooo0P2=H3H208iQ=`0408mR>02@HcT0T6<i095T>PP0T6<i1@2DH3P309=O=`P0Sf<f00<0TfLj099V
>@2AICP00P2?HcH00`2AICP0TVHi09=W>P0209EY?00409AX>`2CIcX0TfLj099V>@D0TFDh00<0TVHi
09=W>P2DJ3/00P2DJ3/0102DIcd0TfHl09=V?02CIS`3099U>`03095T>P2FJSd0UVXm00H0UVXm00<0
Uf/n09EY?02CIcX00`2AICP00`2BIST0TfLj09AX>`0209=W>P0409AX>`2EJC`0UFTl09IZ?@80Uf/n
0`2FJSd209EY?0<0U6Pk202HK3l809M/=@80UVXi0P2GJcX209Q/>`80VFdl00D0UFTl09IZ?@2FJSd0
Uf/n09Q/?`0209U]@00309Y^@@2KL3T0Vg0i00H0Vg0i00<0V6`k09M[>P2FJST00P2EJCP00`2GJcX0
VFdl09]_?P0309eb?`<0WW=00P2OM44809eb?`P0WG500P2MLD80102MLD00WG8o09ic@02NLch209md
?@030:1e@P2NLd00WG8o0080W74n00<0WG8o09ic@02PMD80202PMT@80:9gA0P0WG8o00P0W70o09ea
@02NLT40X7A30:=gAP2UNDP0YWY90:MkBP@0WgA10P2PMD820:5f@`80X7E200<0XGI30:9gA02SN4D0
0`2UNTL02@2VNdP0Z7e:0:QmBP2VNdP0Y7U60:9gA02PMD80WW=009eb?`030:9g@P<0XgQ30P2TND@2
0:=fC0040:AgC@2UN4h0YWU?0:IiC`80YgY@0`2UNTL20:AiAP<0XgQ5202RMd@80:=hA@P0WWA20P2L
L3l409ea@080W70o0`2JL3h209U_?@<0V6hl0`2FK3X509E[>@80TfTg0P2BJ3H3095W=@06091V=02?
I3L0Sf@g08iS=P2=HSD0S64d0P2;H3<00`2:Gc80RV@e08US=00208QR<`0408MQ<P26H340QEl`08EO
<080QUlh0P25GSL308AM=P0308=L=@21FcH0PE/f00H0PE/f201nEbh00`1jEbl0NEH^07QE;@0207MD
;00A07QE;@1jEbl0NeP`07AH<@1cEc00LED]071E:P1`EBP0LULX07AI:P1eFbX0K4lS06m@901`DBD0
LU4V07EB:01hDbT00`1jDbX0201`CBL0LDhX079?:@1cD2X0LTlY071=9`1]BR@0JdPR0P1^DRX0101]
DBT0K50X06Y>9P1YCBD206Q<90<0JTTV00<0JdXW06a;:01]C2T00P1]C2T0201^C2T0KD/X06]99P1Z
B2D0JDLT06Y89@1[BBH0K4XW0P1VBRD00`1XBRH0JTTV06a:9`0206e99`0306m89`1[BRT0JdXY0080
JdXY0P1ZBBP206U89`<0J4XX0P1WBBL306I89P<0IDHY0`1VAbX206M8:`P0JD/Y00P0JTLW06]8:01]
BRX0KT/[06e::P1[B2P0JDHV06Q59@80KTLX00P0JdPX06U89`1VBBL0HTXV065;9P1OBbH0JD/W06Q:
9P<0ITPT00h0J4XV06]=:@1/CRX0L58^06mA;@1^D2`0KDl[06a>:P1[CBT0JT`X06U;9`1`BBX0LDX[
07=<;@80M4d^00<0Ld`]075::`1`BBX0201YC28406a<8`80KDdT0P1^CRD806]=:`0406m>:`1^CBX0
KTdZ06e<:@80K4/X0P1[BRL206e::P0306a;:P1[CB/0JTd[0080J4h[0P1WCb/206a:9@0406]9901Z
B2<0JTPS06U78P80J4HQ00/0JThY06U=:01WBbH0ITXU06E9901VBRD0Id/V06Q<9`1^CBh0K4//06Y9
:P0206U8:@0?06Y9:P1[BR/0K4//06Q<9`1WBbH0ITXU06A88`1SAb80HDDP06147`1O@ah0K4/X06]:
9`1XAb@0ID@Q0080I4<P00X0ID@Q06I58P1MAR@0GTLU05m79@1QAbH0I4LW06I7:01XAbP0JDPY0P1V
A2T01P1SA2P0HT@X05m49`1NABL0GDHW05a59P<0GD0P00<0GT4Q05m28P1P@b<00P1P@b<0101RABD0
HD@T0654901P@b<205m28P80GT4Q0P1R@b@306528`<0H44R0`1O@R8306138`80HD@T00<0IdTW06I8
9P1TAR@00P1RA280301SAB<0IDLU06I89P1UAbD0I4HT06538@1P@R00HD<Q06=58`1VB2H0J4XX0696
8@80HdLR00<0I4PS06E9901VBRD00P1WBbH206U;9`<0IdTU00<0JD/W06]=:@1/CRX0101XBbT406U<
:P80K4`U00H0KDdV06m?:01`D2T0LE4Z079B:`1cDb`2071=9@80LDhV0`1bCbL01@1cD2P0L4dU075>
9P1cD2P0MU<[0080Me@/0P1fDb/307=@9P0:07AA9`1fDbT0Me@Z07QE:`1iER`0NUL]079F9P1cEbL0
METY07MK:`@0N5`/0`20Fbh2085L;`<0PUd`2022GRh808EQ<@0608QR=@28HS<0RV@e08]U=02=J3@0
SVTd0P2@Jc@208mZ=P@0SVTe0P2=J3@02`2@JCh0T6Xm095[?P2BK3d0Tfdl09A_>`2DKcX0UG0k09]b
?P2JLCd0V6lk0080Ufhj00<0V6lk09Ya?@2KLSh00P2GLSd01P2HLch0VG@o09Ye@02KMT40W7M209eh
@`<0VWE00P2KMT4309ag@P0809iiA02ONTD0XWe80:=nB@2TOdX0Xgi90:5lA`2PNdH30:AoB`80YH1<
0`2VPDd30:AoBP80YH1;0`2VPD`30:R3CP80ZHA?0`2ZQE080:f8E0<0[XUD0P2_RUD30;2;EP80[hYF
0`2`ReL30;6<F0P0/hUG102cSUL00`2bSEH0/HaE0;2;E0020;2;E0P0]HaH202hRUT20;>>E`030;>>
F@2cSUX0/heL0080/heN00<0/heP0;>>FP2cSUX01P2cSUX30;:=F@<0/hiJ0P2dSe/80;>>FP<0]H]I
0`2fS5X20;N=F`@0/HaH0P2`ReL20:n:EP80/8IF00@0/HMG0;:8F02bR5P0/hUI0P2dRUX80;:9E@<0
/8]G0P2_RUH30:j9E@P0/8]G202_RUD01P2aS5P0/8]G0;2;E`2^RED0[HQD0:b7D`80ZhIB202cREL8
0:j9E@80[8MB0P2]R5<02P2^RE@0[hYE0:n:E@2`ReH0/H]J0;2:F@2_REP0[XQG0:f7EP2/QUD20:^5
E0@0[hIB0`2^QE420:f4D080ZhIA0P2/Qe820:f8D`80[XUD00@0[89@0:f3D@2]Pe40[XAB0P2_QE<2
0;26E0040:b3C`2]Q500[HA@0:j5D@80[hIB0P2`Qe<30:n5E@<0[XAD0P2]Pe<20:b6E@040:b7D`2[
QU40ZhIA0:^6C`80ZXI<0P2^QE440:f4D080[8=?202^QE401P2bR5H0/HME0;26E02_QE<0[XAB0:b2
D080Zh5?0P2]Q5030:b3C`<0Zh9>202/Pd/80:b3C@80[8=;00@0[8==0:f4D02]Q500[XAB0P2^Q5@8
0:j4DPD0ZhIA0`2/Qe820:^7C@040:^6C`2[QU40ZhIA0:^6DP80ZhED00P0ZX5=0:V0C02XOd/0Z7m;
0:V0C02[PTh0[XEA0;27D`80[X9C00@0[X9A0:j3D02]PTl0[H9=0P2/PDX20:V0BP80ZX5;0P2[PT`2
0:b3C@T0[HA@00L0[hIB0:f4D02ZPDd0Z7m;0:MnBP2YP4`0Zh9>00T0[8=?202/Pdd01P2YP4`0ZX5=
0:Z1C@2[PTh0[8=?0:f4D0<0[XEA0P2]Q5000`2/Pdl0Zh9>0:^2CP020:Z1C@80Zh9>00@0[8=?0:f4
D02]Q500[XEA0P2_QU880:f3D@060:j4DP2]Pe40Zh5?0:UoC@2XOT`0ZGm=0P2ZP4h00`2_QU80[XEA
0:b3C`020:^2CP030:b3C`2^QE40[hIB0080[HA>0`2^QDl30:n6D0<0Z8=>0P2WPTd30:J1C0<0[XEA
0P2]Q5030:b3C`<0[XEA0P2]Q5030:b3C`80Zh9:00@0Zh9<0:^2CP2[PTh0Zh5?0P2[PE400`2YOdl0
Zh5A0:n5D`020;68E0030:n6D02[PTX0ZH1800<0Zh9>0`2/Pdl20:f4D0030:^6D@2YQ4l0Z8=>0080
Yh9=00<0Z8=>0:V4C`2[QU40202WQ4h00`2^QE40[8=?0:Z1C@030:QoB`030:V0C02ZPDd0[8=?0080
ZH1<0P2ZPDd20:^2CP80[8=?202[PT`@0:^2CP@0Yh9=0P2VPD`20:F0B`80ZGm=0P2ZP4h30:^1C`03
0:b2D02/Pdl0[8=?0080Zh9>0P2ZPDd20:V0C0<0[HA@0`2/Pdl20:^2CP040:QmBP2YOT/0ZGi;0:Yo
C080Zh1=0P2/PDh0102VO4`0Z7i>0:Z0D02[PE420:b2DP030:^1D@2ZP500[89@00L0[89@00P0YWe9
0:MnBP2XOd/0ZH1<0:^2CP2/Pdl0[HA@0:j5D@P0Zh9>0P2YP4P0102YP4X0Z7m;0:QoB`2WOD/20:Mm
C@80Ygi6102XOdL20:V0B0080:5mB`2SOD`0YH1<0:V1C@2ZPDd0ZWm:0:]nA`2ZODH80:QoB@090:Mn
BP2XOd/0ZH1<0:Z1C@2[PTh0[8=?0:f4D02^QE40[89@00<0Zh5?0`2ZP4h20:UoC@030:V0C02ZPDd0
[8=?0080[HA@00<0[8=?0:Z1C@2YP4`00P2WOTX20:ImB@<0YGa800L0Y7]70:9mB02RODP0Xgi90:Ao
BP2VPD`0Yh9=0080Z8=>00H0YX940:J2AP2VPTH0YX980:J1BP2VPD`20:J1C@D0ZGm?0`2ZP5000`2[
P4d0ZWm<0:QmBP020:MlB@060:QmBP2ZOd`0Zh1=0:b3C`2[PTh0ZH1<0P2XOd/00`2YP4`0Zh9>0:b3
C`080:MnBP<0Y7Y80P2SNDL30:9hAPP0XgY600<0XWQ80:=iB@2UNd/00P2VO4`01P2UNd/0XgU90:9h
B02PMT@0XGM50:=iA`80YG]900<0Y7Y80:=iA`2RN4H00`2ONTH20:1kA`<0XGa8202MN4<309Ye@@80
VgI20`2LMd<20:1g@`80WgI2102NMD420:9hAP030:5gA@2PMT@0WgE30080WG=100D0W79009Ye@@2K
MT80VgI209ag@`0209ehA080WWU500H0W75409ebA@2NLdH0WgA709icAP2MLTD209]`@`0309Y_@P2L
MTL0W7I700@0VgE60P2JM4D209ag@`@0VgI20P2JMD4809me@`P0VgI20P2MN4@01P2LMd<0VWE109Ud
@02HLcl0Ug8n09Ia?@80Ug520P2HLT<209UcA080VWA5202FM4@20:5mC@80X7a<00D0Wg];09ijBP2M
NDT0WGU909mbB@0209icB@0309ecB@2KM4T0VWE90080V7I90`2JM4D[ooooo`00:_ooool8091T=@P0
SF@h00<0TFHk091U>P2>HcP00P2=HSL00`2>HcP0T6Dj095V>`0608iS=P80SF8e0`2?Hc8308iR<@80
SF4`00H0VfXo09YY?P2IJ3d0V6Ll09IU>P2DHcP209=R=`80TFDh0P2BIST209=W>P80U6Pk202AICP8
09AW?PT0TfLj202FJST309M[?P<0UVXm0P2EJC`0202GK3l0UFXm09=X>`2BIcX0TfPk09EZ?@2HKD00
VFi10`2FJST00`2GJcX0V6`k09U]?00509U]?080VVhm0`2KKch309Q/?`<0VFe00P2JKT400`2KKch0
VVhm09Q/>`0209M[>P0309Q/>`2JKSd0Vfln00P0VG0l00@0VFhk09Y_?02JKc`0Vg0m0P2LLCh209eb
?`80VVll0`2KL3d309aa?P080:5f@@2PMD00WW=009a`?`2LL440W71309eaA02NLDL309ic@00309eb
?`2LLCh0Vg0m0080Vg0m0P2LLCX0102MLSd0WG8o09ic@02OLd820:1dA@030:9gA02QMT<0WgA10080
WW=000<0WgA10:5f@`2RMd@00P2OM3l0102PMD00XGI10:9g@P2SN4<20:AiA00409ib@@2OLd80Wg=2
0:1d@`80XGE40P2RMTD80:=hA@P0WgE300@0X7E00:5f@@2QMT40XGI10`2RMd850:=h@`<0XWM20P2Q
MT430:9gA0<0XgQ50P2TNDH0202XODX0Yga90:EjA`2TNDH0XgQ50:AiAP2UNTL0YW]80`2UNTD20:Ai
A0<0XgQ30P2SNTH30:9iA@<0XGQ40P2TNTP20:=iA`070:9hAP2QMdD0X7I40:1fA02MLd40WWA20:1f
A0020:5gA@030:1fA02OMD<0WWA200<0W7900P2KLCl309Y`?P0409Q_>`2GKSX0Ufhj09M^>P80UVdi
0P2EK3P02@2BK3d0TF/l091Z>`2?JCX0SVPi08eW>02<ISL0RfDf091Z>`0208mY>P0308iX>@2=IcP0
S6Hg0080RfDf0P2:I3L01029HcH0R68e08IP<`25Gc8208AN<@80RV@c0P29Hc8308QR<@0408MQ<026
HCL0Q5le089M<`80P5/a00T0PE`b089M<`23GS@0PeX^089H;P20FBh0OeX`07iH<@1lFC<00P1jF3<8
07UF<0P0O58Z00<0LTlY07=@:P1dDB/00P1eDR`01P1dDB/0Le0Z079?:@1^CBX0L4l/075@;@80Le8_
00`0LE0]071?;01`Cb`0KTdZ0719:01_BbT0LDd[075?;01_CR/0K4hZ06Q<9`1WBbH206a>:P80JddY
101ZC2P0201XBRP0JD/Y06Y<:P1YBbT0J4XX06I89P1TAR@0HT@R201WBBL206U;:@0406Q::01WBBL0
IdTW06I89P80IDLU00<0IDlX06A>9`1TCRL00P1TCRL306==9P0806Y;;01WB2T0IDHW06M8:@1[C2d0
K4d^06M8:@1Q@R<806M8:`0306i=:P1]C2T0JdXW0080JTTV00<0JdXW06e<:@1^CBX0201ZBBP806U<
:P060719:P1^BRP0KTXX06i<9`1]CBH0K4lU0P1[D2<00`1[CB/0K4h/06a>;00306a>;0<0KDl]00l0
K4h/06Y<:P1YBbT0JD/Y06Y<:P1/CR`0KDl]079?9`1cD2P0M54Y07EB:P1dDBT0LTlW06m<901^Bb<0
0P1]BBD206i:9P0?06m;9`1`C2P0L4`X075=:@1/BB40KDXR071=9@1bCbL0Le0X079?9`1aCRH0L4dU
06a?9`1[CRH0JD`T0080IdXR00<0JD`T06]>9P1/CbL02@1[Bb@206e:9080KT/U00L0Kd`V071=9`1a
CRP0LDhX06e=9P1/C2D0JTXS0080J4PQ00H0JDTR06];901/C2D0ITHO06M7801YBB8306];9080JDTR
00<0IdHU06Q79P1ZBBP00`1/BbX00`1[BRT0JTTX06i=:P0206e<:@0306]:9`1ZBBH0JDPU0080J4LT
201VB2@206I89P80IDLU0`1TAR@00`1SAB<0H4<Q06138@0606138@P0G4DU00/0H4<U06549P1QA2H0
HTDW06139@1N@B<0FchP05Tl7P1SA2D0HT<T06118P0205m08@0606118P1R@b@0Hd@U06138@1QA280
HdHT0P1TAbD00`1SAR@0HTDS06548P02065490<0HTDU0`1SARH506Q7:0<0IdHW201YCBH206Q:9P80
JD/W0`1ZC2P02@1[CBT0KdTT06m9901`BRD0LD/V079<9`1dCRT0MDlZ07I@:`02071@:@H0KdlX0P1a
DBP2079B:@0407=C:P1dE2/0MED/07EE;0<0LE4X00<0LU8Y07=C:P1cDbX00`1cDbX0201aE2`0MeL`
07YJ<@1jFBh0MU@W07MB9@1kEBH0P5X[1020GS0407mM;`<0PEla1020GS002@1oGBl0QF<e08AR=022
H300PF0]085P:`22HB/0Pf8/08AT:`0208MS<`80R6@d0`29ICD00`2:ISH0S6Ph08aX>00208eY>@<0
SVXj00X0Sf/k08mZ=P2@JcL0TVdi09A_>`2EL3`0U6lk099]>@2AK3P0TVdi0P2CKSX00`2DKc/0UG0l
09Ia?@0209Mb?PP0V7<o0P2FLC`0102HLch0VWE009ag@P2NND@20:1kAP<0WgY50P2PNdH30:5lA`80
Y7]70P2UO4P30:ImB@070:MnBP2XP4<0Z8150:R0A@2YP4P0ZH1:0:Z1C@020:Z0CP050:Z6C02YQD/0
ZHE;0:R4BP2WPdT00P2VPTP0102UPDL0[XUB0:b7D02ZQDh20:R3C0030:Z5CP2/Qe00[XUB00@0/hYF
102bRED20;2;E`@0[hYF0P2^RED0102cSUX0/XeI0;:=F@2bSET20;6<F0D0/8]G0P2aS5P30;:=F@<0
/hiJ0P2bSET20;6<F080/8]G0`2cRUH00`2dReL0]HaH0;J=F@020;J=F@P0/8]F0P2_RUD30;2;EP<0
/HaG202fSET80;:=EPP0]H]I202bSEP80;2;E`0;0;>9E`2bR5H0/HME0;67E@2bR5H0]8YH0;J<FP2g
SE/0/HaH0:n:EP2]R5@00P2[QU800`2/Qe<0[HQD0:j9E@080:b7D`080:n6DP2aR5@0/hYF0;F<F02f
SET0]HaH0;B;E`2cRUH80:j9E0030;2;EP2^RE@0[HQC0080[8MB00<0[HQC0:j9E02`ReH00`2`ReH2
0:n:E@<0[XUD202`Qe<01P2_Q540[XEA0:n6DP2^QU80[HQC0:b9D`80ZhYD0P2ZQE430:^6DP@0[8MC
202]R5@00`2`QU@0[hEC0:j4DP020:b2D0030:j4DP2_QE<0/8ID00<0[XEA0P2]Q5030:b3C`P0ZhM=
202[QU80202[Qd/0ZhM=0:^6C`2[QU40ZhED0:^5F02[Q5T0ZhAK0P2/Pdl00`2]Q500[XEA0:n6DP02
0;27D`040;68E02/Qe80ZhIA0:V4C`80Z8=>00/0ZHA?0:^6D@2/Qe80[HA<0:j5C@2_QU00/8MC0:n6
DP2]Pe40ZX1@0:UoC`020:QoB`040:V0C02ZPDd0ZX5=0:^2CP80[8=?00@0[XEA0:f4D02]Q500[8=?
0P2[PTh20:Z1C@P0Zh9>00<0Zh5?0:b2D02^Q5800`2`QU@01@2_QE<0[XAB0:^2CP2/Pdl0[XEA0080
[hIB00<0[XEA0:b3C`2[PTh0202ZQE020:Z1C@80Zh9>00@0[8=?0:f4D02]Q500[XEA0P2_QTh0102^
QDd0[HA<0:f4C02/Pd/20:^2BP<0[8=?0P2]Q5030:j5D@T0[HA@2`2[PTh30:b3C`80[HA@0`2^QE42
0:f4D0/0[8=?0P2/R5H0102[QeD0ZXID0:R4DP2WPe420:J2D080Z8=?00@0ZHA@0:Z5D@2ZQE40ZhIB
0P2/Qe<00`2aR5@0/8MC0:j5D@020:f4D0050:j5D@2`Qe<0/HQD0:j3EP2]PUD00P2]Pe<01`2/PU00
[8=?0:^2C02[PT`0[hIB0:j5D@2/Pdl00P2[PTh00`2/Pdl0[XEA0:n6DP080:^2CP030:V0C02ZPDd0
[8=?0080[HA@0180[8=?0:Z1C@2YP4`0[h5=0;22CP2^Pdh0[HA>0:f6C`2[QTl0[8M@0:^8D02aR5@0
[hIB0:f4D02[PTh0ZX5=0:^2CP2]Q5020:j5D@090:f4D02/Pdl0Zh9>0:Z1C@2YP4`0Z7m;0:MnBP2/
Pdd0[HA>00<0[hI@00/0[HA>0:^2C02ZPD/0[XEA0:b3C`2ZPDd0ZH1<0:QoB`2YP4`0ZX5=0:b3C`08
0:b3B`D0ZH180`2ZPDT90:b3C@80[8=;0P2[PTX30:Z1B@030:V0B02XOdT0Z7m900H0Z7m9102[PTh2
0:b3C`80[HA@00P0[XEA0:f4D02/Pdl0Zh9>0:Z1C@2YP4`0Z7m;0:MnBP@0ZX5=102[PTh50:b3C`<0
Zh9>0P2/PU020:^1C`<0ZX1>00D0ZGm=0:n6DP2]Q500Zh9>0:V0C0020:QoB`0:0:Z1C@2[PTh0YW]@
0:MlC`2YOU40ZX1@0:Z0CP2YP4`0Ygi80:ImA`80YX5:00<0YX5<0:J1C@2VP4l00P2VP5400`2VP5<0
[8=?0:b3C`060:b3C`030:V4D02ZQE40ZhIB0080[8MC00@0ZXEA0:R3C`2WPTh0[89@0P2[PDl00`2Z
P4h0ZGm=0:QnC0020:MmB`030:Z1C@2YP4`0Z7m;0080Ygi:00<0ZH1<0:^2CP2]Q500202YP4`0202V
Pd/0Yh9;0:R3C02ZPd`0[8==0:j3CP2`PTh0/H=?202XOdT00`2XOd/0ZX5=0:^2CP020:f4D0030:^2
CP2ZPDd0Z7m;00<0ZX5=102YP4`20:QoB`80Z7i<0`2YOdd30:Z0CP060:MlD@2WO4l0Yga?0:MmC@2W
OD/0Ygi:0P2WOTP30:MmC@80Z7i>0`2YOdl20:J2D080YH5?0`2TP4h0102SOdd0Ygi:0:MnBP2WOTX2
0:QoB`H0ZH1<0P2XOd/30:MnBP/0Y7m;00<0Xgi:0:9mB@2QO4P00P2QO4P00`2WOTP0YGa60:=jA002
0:9i@`060:=jA02UO4H0Ygi80:ElB02TNdL0XGQ40P2PMd<01P2RNDD0YGa80:MnBP2QO4L0X7]609mj
A@80WWU400<0X7]60:9mB02SOTT00P2SNTH30:9iA@<0XGQ400H0WGU509iiA@2ONTH0XWY70:=iA`2U
NDP20:QjB@0H0:=_?`2TLT40YWA30:IfA@2UMdD0XgQ50:1g@`2OMT80XG]>09miBP2MMdP0VgE409]f
@P2MN4<0WgY30:5lA@2TNdL0XWU50:1g@`2OMT80WWE109mf@P2PMd<0XGQ40`2RNDD20:5hA0<0X7M3
0P2PMT@0102OMD<0WWA209id@P2MLd4209ab@00309Y`?P2KLCl0WG=10080WgE300@0WWA209ab@02L
LT00Vg4o0`2NNDD209ehA0@0W7M30P2KMT800`2JMD40VGA009Ud@00209Qc?`80VGA01P2JMD400`2L
Lcl0WGA009mf@P020:1g@`0309mf@P2MM400W7<o00P0VgI200`0WG=109ab@02KLCl0Vg4o09ab@02O
MD<0XWQ60:=iA`2NNTH0W7Q409Yf@P2IMD4209Qd@00509Ue@@2JMT80X7U@09mhC`2MMTd00P2KM4/0
1P2LMD`0WWM>09mhC`2HLcl0VWE109ehA080WgY600<0WWU509ag@`2JMD400`2IMT0[ooooo`00:_oo
ool8091T=@P0SF@h00<0TFHk091U>P2>HcP00P2=HSL00`2>HcP0T6Dj095V>`0208eR=@@0SV<f0P2?
I3L0102AIC@0T6@c091T<`2@I3<208mS<P80SV8a0P2IJ3d0102HIc`0UfHk09IU>P2EI3T209AS>080
TFDh0P2BIST209=W>P80U6Pk202AICP809=V?@T0TfLj202FJST309M[?P<0UVXm0P2EJC`209EZ?@<0
U6Tl00<0UFXm09M/?`2HKD000P2FJST209M[>P80V6`k1@2IKC`309Y^?@80Vfln0`2HK3l309U]@080
VVi100<0Vfln09Y^?@2HK3/00P2GJcX00`2HK3/0VVhm09]_?P0809U`?0<0VVll00<0Vg0m09aa?P2L
LCh00P2MLSl209Y_?0<0Vg0m0`2LLCh0202QMT40X7E009ic@02LL3l0W71109a`@`2MLD@0WW570`2N
Ld000`2MLSl0W74n09aa?P0209]`?@80WG8k00@0WG8m09ic@02NLd00Wg=20P2OLd@00`2RMd@0XGI3
09md@@0209ic@00309md@@2QMT<0XWM40080XgQ30P2RMd820:5f@@80X7E00P2OLd820:1d@`80XGE4
0P2RMTD80:=hA@P0X7I4102QMT430:9g@P80XgQ300@0YGY50:AiA02TND@0Y7U40P2SN4<20:9g@P<0
XWM40P2SN4D30:AiAP080:QmBP2WO4T0YGY70:AiAP2SN4D0Y7U60:EjA`2VNdP30:EjA@80Y7U40`2S
N4<20:=jAP<0XWU50`2QN4@20:9hAP<0XGM50`2PMT@00`2MLd40WWA209me@`020:5gA@040:1fA02N
M480WG=109ec@@<0W7900P2KLCl209Y`?P<0Ufdk0P2FK3X309E[>@05095[?02@JS/0T6Xk08mY>P2=
IcP00P2<ISL01P2;ICH0SfTj08mY>P2>J3T0SFLh08aV=`80RfDf00L0RV@e08YT=`29HcH0R68e08MQ
=026H3<0QElb0080Q5ha0`28HS4208MQ<0<0QV0_00h0QF0f08=N=021G380P5/a07mJ<020Fc40PE`b
089M<`22FBd0PUP^081I;P1nFBl0OUPa07]H<P80NUPc201iES0807aB:P03079?:@1cD2X0M54[0080
ME8/00H0M54[07=@:P1bCbT0KTdZ06m>:`1aD2d2079A;P0<075@;@1_CR/0Kdh[06i=:P1aBRT0L4`Z
079>;01aCb`0L4l/06a>:P1YCBP0J4`W0P1/CRX206]=:@<0JT`X00<0JD/W06Q::01YBbT00P1YBbT0
101XBRP0ITPV06A6901RA28806M99`0306U;:@1XBRP0J4XX0080IdTW0P1VB2H00`1UAbD0HddV06==
9P0606==9P0406U::`1WB2T0IDHW06M8:@80JT//00<0ITLX06528`1WB2/01`1WB2/00`1]C2T0K4/X
06]:9`0206Y99P0306]:9`1/BbP0KD`Y00P0JdXW201YCBP0201`BBX0KTXX06m;:@1^C2L0KThW06a?
9@1[D2<0K54T0`1^CBX606m>:`0?06i=:P1]C2T0K4/X06a;:01]C2T0KTdZ06m>:`1aCRH0LTlW07=@
:01dDBT0Le0X075>9P1_C2@0KT/S00<0KTXV00<0Kd/W071<:01`C2P00P1aCBT02`1^Bb<0Kd`T075>
9P1bCbL0Le0X079?9`1`CBD0Kd`T06i>9`1]CBH0Jd/T0080JTXS00<0Jd/T06e=9P1^CRL02@1/C2D2
06i;9@<0Kd`V0`1`CBL00`1^CRL0K4`U06];900206U98P0A06Y:8`1[Bb@0K4`U06M7801XB240JTXS
06];901/C2D0Jd/T06Y:8`1YBB80IdHS06U89@1ZBBH0K4/X06e<:@1/BbP00P1[BRL01@1]C2T0K4/X
06a;:01[BRL0JDPU0080J4LT00<0IdHS06I8901VB2@01P1VB2@306I89P80IDLU0`1TAR@806138@P0
G4DU00/0Gd8T06139@1QA2H0HTDW06549P1O@R@0GD0R05/n801SA2D0HT<T06118P0205m08@060611
8P1R@b@0Hd@U05m2801P@b40HTDS0`1TAbD00`1SAR@0HTDS0654900206549080HTDU0`1SARH306Q7
:0D0IdHW201XC2D206Q:9P80JD/W101ZC2P206e:900706i;9@1_C2H0L4dW075>:01bCbT0Le0Z071@
:@0706m?:006071@9`1aDBP0LE4X079B:@1cDbX0M5@[0P1eEB`4079B:@80Le<Z0`1dE2/0201aE2`0
MUH_07UI<01iF2d0MeDX07MB9@1kEBH0OeTZ201nG2h6081N<080Oed_00P0QF<e08=Q<`22H300PEl_
081O;021H2/0Pf8/08AS;@<0Qf<c0P28I3@308UU=@<0S6Ph0P2=JCT308iZ>P0808mZ=P2@JcL0TVdi
09=^>P2DKc/0Tfhj099]>@2AK3P2099]>@0309=^>P2DKc/0UG0l0080UW4m00<0Ug8n09Qc?`2HLcl0
1P2HLcl02@2GLSd0V7<n09Ud?`2JMD00W7M209eh@`2NND@0WgY509iiA00309mjA@80X7]60P2QO4L3
0:AkA`80YGa80`2VODT01P2XP4<0Z8150:R0A@2YP4P0ZH1:0:Z1C@80ZX1>102XQ4X40:N3B@80[8M@
00@0ZhI?0:Z5CP2ZQDh0ZhI?0P2/Qe030;:9E@D0/HQD202_RUH40;:=F@80/HaH1@2`ReL20;6<F0@0
/XeI0P2cSUX20;:=F@80/HaH0P2`ReL20;>:EP80]8]G0P2eS5P20;J=F@P0/8]F0P2_RUD30;2;EP<0
/HaG202fSET80;:=EPP0]H]I202bSEP80;2;E`80/hUG00h0/XQF0;67E@2bR5H0/hUG0;F;F@2gSE/0
/HaH0;2;E`2^RED0[HQD0:b7D`2]R5@0[XUE0:n:EPP0[HQD00<0[hIB0;68E02cRUH00`2eS5P00`2d
ReL0/hYF0:j9E0070:j9E0030:n:E@2^RE@0[HQC0080[8MB00<0[HQC0:j9E02_RUD00P2`ReH30:n:
E@<0[XUD202`Qe<01P2_Q540[XEA0:n6DP2^QU80[HQC0:b9D`80ZhYD0P2ZQE430:^6DP<0[8MC2@2]
R5@00`2`QU@0[hEC0:j4DP020:b2D0030:j4DP2_QE<0/8ID00<0[XEA0`2]Q5020:b3C`P0ZhM=202[
QU820:^7C@040:^6C`2[QU80ZhED0:^5F080ZhAI102^QE440:n6DP030:b7DP2[QU40ZHA?0080Z8=>
00H0ZHA?0:^6D@2/Qe80[HA<0:j5C@2_QU020:n6DP030:f3D@2[PE40ZGm?00<0ZX5=00<0Zh9>0:b3
C`2/Pdl01@2]Q5000`2/Pdl0Zh9>0:^2CP020:Z1C@P0Zh9>00<0Zh5?0:b2D02^Q5800P2`QU@01P2_
QE<0[XAB0:f3D@2[PTh0[8=?0:j5D@80[hIB00<0[XEA0:b3C`2[PTh0202ZQE000`2ZPDd0Zh9>0:^2
CP020:b3C`80[HA@00D0[XEA0:j5C@2^QDd0[XE=0:f4C0020:b3B`80Zh9:0`2/Pdl20:f4D0<0[XEA
2@2]Q50;0:^2CP<0[8=?0P2]Q5030:j5D@80[HA@2`2/Pdl01P2]QeH0[8IE0:^5E02ZQ5<0ZH=B0:R2
D@80Yh5@00<0Z8=?0:V4D02YQ5000P2ZQE420:^6DP040:b7D`2`Qe<0[hIB0:f4D080[8=?00h0[HA@
0:n6DP2`Qe<0[H9E0:b1E02/PU80[89@0:^2CP2[PT`0ZX5;0:Z1B@2_QU80[XEA0:b3C`80Zh9>00<0
[8=?0:j5D@2_QU80202[PTh00`2ZPDd0[8=?0:f4D0020:j5D@030:f4D02/Pdl0ZX5=0080[X1<00H0
[H9=0:b3C@2/QDh0ZXE>0:^6C`2ZQdl20:b3C`80Zh9>00@0[8=?0:j5D@2`Qe<0/HQD0P2]Q500102/
Pdl0Zh9>0:Z1C@2YP4`20:QoB`0;0:b3C@2]Q4h0[XE?0:n6D02^QDl0[HA>0:^2C02ZPD/0[XEA0:f4
D02[PTh00`2YP4`00`2ZPDd0Zh9>0:b3B`070:b3B`<0ZH181@2ZPDT90:^2C080[8=;0P2[PTX40:Z1
B@P0Z7m900@0ZX5=0:^2CP2[PTh0Zh9>0P2/Pdl40:f4D0060:b3C`2[PTh0ZX5=0:V0C02XOd/0Ygi:
102ZPDd40:^2CPH0[8=?0P2[PTh20:b2D080Zh5?102ZP4h0402^QE40[HA@0:^2CP2YP4`0Z7m;0:V0
C02ZPDd0Zh9>0:IkD02WO4l0ZGiA0:Z0D02ZP4h0ZH1<0:MnB02VODL20:J1BP030:J1C02VPDd0YX1?
0080YX1A00<0YX1C0:^2CP2[PTh01P2[PTh00`2XPdl0ZHA@0:Z5D@020:b7D`030:^6DP2YQ500Z8=?
0080[89@00@0Zh5?0:Z0CP2YOdd0Z7i<0P2WOD/0202ZPDd0ZH1<0:QoB`2WOTX0Z7m;0:V0C02[PTh0
[HA@202YP4`01P2VPd/0Yh9;0:R3C02ZPd`0[8==0:f2C@80/89>202XOdT00`2XOd/0ZH1<0:^2CP02
0:b3C`030:^2CP2YP4`0Z7m;00<0ZX5=102YP4`20:QoB`80Z7i<0`2YOdd30:Z0CP060:MlD@2WO4l0
Yga?0:MmC@2WOD/0Ygi:0P2WOTP30:MmC@80Z7i>0`2YOdl20:R2D@80Yh5@0`2VP4l00`2UOdh0Ygi:
0:MnBP030:QoB`H0ZH1<0P2XOd/30:MnBP/0Y7m;00<0Xgi:0:9mB@2RODT00P2QO4P00`2WOTP0YGa6
0:AkA@020:=jA0050:AkA@2UO4H0Ygi80:AkA`2SNTH00`2RNDD02`2SNTH0Y7]70:ElB02QO4L0X7]6
09mjA@2NND@0WgY50:1kAP2RODP0Xgi900<0XgY60P2RNDD30:5hA00609ijAP2ONTH0WgY60:9jA`2S
NDL0YGU80P2WNDP03P2RL3l0Y7910:Ad@`2TMT@0XgQ50:5hA02PMd<0WWI209ihB`2NN4T0WGM809af
A@2LMd<0WGQ30P2NND801`2TNdL0XWU50:1g@`2OMT80WWE109mf@P2PMd<0102QN4@20:1g@`<0WgI2
0`2OMD<309id@P80WG=100<0Vg4o09ab@02NM4800P2OMD<0102NM480WG=109ec@@2KLCl309ehA080
W7M31P2KMT800`2JMD40VGA009Ud@00209Qc?`80VgI2102JMD4209Ud@00309ac?`2MM400WgI20080
X7M300<0WgI209ed@02LLcl0202KMT802`2MLd40W79009ab@02LLT00WG=109me@`2QMdD0XgU709ii
A@2MN4@0VgI200<0VGA000D0VWE109]f@P2PNT/0WWQ909egB00209]eAP0809afA`2NN4T0WgU:09Ye
@@2KMT80W7M309ehA02NNDD209ehA00409ag@`2KMd<0VgM309]g@b_ooooo000Zooooo`P0Sf<f202>
HcP00`2@ICX0Sf@i08iS>00208eR=`0408iS>02?I3T0T6Dj08aQ=080SF8e00<0SV<f08mT=`2?I3L0
0P2@ICP0102CIcH0TVHe099V=@2BISD2095U=080T6@c202FICX2095U>080TVHi0P2CIcX209AX>`P0
TVHi202BIC/909=W>PP0UVXi0`2GJch309IZ?@80UFTl00D0TfPk09AY?02EJSd0UV/n09M/?`0209I[
?P0309EZ?@2FJST0Uf/j0080Uf/j0`2HK3/00`2IKC`0V6`k09Q/>`0209U]?0<0VVhm00@0Vfln09Q/
?`2HK3l0V6`o0`2IKD0209Y^@@0309]_?P2JKSd0VFdl0080V6`k00<0VFdl09Y^?@2KKch0202JLCd2
09Y_?0<0Vg0m0`2LLCh209Y_?0<0Vg0m0`2LLCh0202QMT40X7E009ic@02LL3l0W71109a`@`2MLD@0
WW570`2NLd0209eb?`<0W74n0P2OM3d02@2OM3l0WgA109ic@02NLT40WW9309ea@P2QMT<0X7E209md
@@0209ic@00309md@@2PMD80XGI30080YGY500@0Y7U40:9g@P2QMT40Wg@o0P2NLch30:1d@`<0XGE4
0P2RMTD80:9gA0P0X7I40`2QMT420:9g@P@0XgQ300@0Yga70:IkAP2VNdH0YW]60P2UNTD20:AiA080
XWM40P2SN4D30:AiAP090:EjA`2XODX0Yga90:EjA`2TNDH0XgQ50:AiAP2UNTL0YW]800<0YGY70P2T
NDH30:=hA@80XgY60`2RNDD30:5hA0@0WWA20`2OMD<0102PMT@0W79009ec@@2OMD<20:1fA00309me
@`2MLd40W79000<0WG=10P2LLT0309]a?`0409M]>`2FK3X0UV`j09I/>P80UF/i0P2DJSP01P2@JS/0
SfTj08mY>P2>J3T0SFLh08aV=`80RfDf00H0SfTj08iX>@2>J3T0SFLh08aV=`2;ICH208YT=@0608US
=P28HSD0R68e08MQ=026H3<0QElb0P24GS4208IP<@80QEl`0`24GRl01@23GBh0Pehd089M<`21G380
P5/a0080OeX`00P0P5/a085L<P22FBd0PEL]07mH;@1nFBl0OEL`07]H<P80NELb201hEBl807UB:`03
075>:01bCbT0Le0Z0080M54[00H0Le0Z079?:@1aCRP0KTdZ06m>:`1`Cb`2075@;@0<071?;01_CR/0
Kdh[06i=:P1cC2/0LDd[079>;01aCb`0L4l/06e?:`1ZCRT0JDdX0`1[CBT206Y<:0<0JD/W0P1XBRP2
06U;:@0406Q::01VB2H0I4HT06=58`P0ITPV0`1XBRP206M99`<0ITPV201SBbD0201WBBL0ITPV06E7
9@1WBBL0JD/Y06Q::01UAbD0HD<Q201XBBX00`1/BbP0JdXW06Y99P0206U89@0306Y99P1[BRL0K4/X
00P0K4/X201[CBT0201aBR/0Kd/Y071<:P1_CBP0KdlX06e@9P1/DB@0KE8U2@1`Cb`01`1_CR/0KTdZ
06e<:@1]C2T0KTdZ06m>:`1`Cb`00P1aCRH3079?9`04075>9P1_C2@0Kd`T06m<9P<0L4dW0`1aCRP0
2@1bCbT0LDhV075>9P1bCbL0Le0X079?9`1aCRH0L4dU06m<900206i>9`0406e=9P1/C2D0K4`U06e=
9P80KThW2@1_CbP2075>:0<0L4dW0`1_C2H01@1_CbP0KThW06a<9@1[Bb@0JTXS0080Jd/T00`0K4`U
06Q88@1YBB80Jd/T06a<9@1]CBH0K4`U06];901ZBR<0J4LT06Y99P1/BbP306e<:@0606a;:01[BRL0
JdXW06]:9`1ZBBH0JDPU0P1XAb@206M68`P0IdTU0P1WBBL206I89P<0IDLU00<0I4HT06548P1QA280
1P1QA28805i6900405m28P1P@b<0HD@T06959@80HD@T0P1O@R800`1SA2D0HT<T06528`0206118P07
06528`1R@b@0Hd@U05e07P1O@R00HD@R06=6900206E89P80I4LU00@0H4<S0654901QA2@0HD@T0P1R
ABD206=69P0306A59P1UARL0IDHW00D0IDHW201UBB@306Q:9P80JD/W0`1ZC2P0101/BB<0KDXT06i;
9@1_C2H2071=9`80LDhX0P1^CRL506m?:00706i>9`1_CbH0L50W071@9`1aDBP0LU8Y07=C:P0207AD
:`D0Le<Z0P1dE2/02P1eEB`0MUH]071C:`1eEBh0MeL^07QG;01gEBP0N5<V07]E9P1nF2T807aJ;0P0
Oed_00P0Pf4d089P<`21Gc40P5h^081O;021H2/0PV4/08AS;@80QV8b0P27Hc<308QT=00308UU=@2;
IcL0RfLg0080S6Ph0`2=JCT01P2>JSX0SfXf091[=`2AK3P0TVdi09=^>P80TVdi0P2AK3P2099]>@03
09=^>P2DKc/0UG0l0080UW4m202HLcl209Ud?`80VWE00P2KMT4209ag@P<0WWU40P2ONTD30:1kAP80
XgY60P2TNdL30:ElB0070:ImB@2WOd80Ygm40:MoA02XOdL0Z7m90:V0C0020:UoC@@0Yh9;102XPd`0
0`2YQ4l0ZXE@0:^6D@020:b7DP030:^6D@2ZQE00ZHA?00D0[hIB0`2`Qe<80:n:EP<0/XeI0P2aS5P7
0;2;E`80/HaH0`2bSET20;>>FP80/XeI0P2aS5P20;2;E`040;>:EP2dReL0]8]G0;B;E`<0]HaH00<0
]XeI0;2;EP2`ReH01P2`ReH20:n:E@<0/8]F0`2aS5L80;J=F@P0/XeH202eReT80;:=F0P0/HaH00d0
]8YH0;>9E`2bR5H0/HME0;:8EP2cREL0]H]I0;J<FP2bSET0/HaH0;2;E`2_RUH0[XUE0080[hYF00<0
/8]G0:n:EP2_RUH01P2_RUH00`2`Qe<0/HQD0;>:EP030;B;E`80/hYF202^RE@00`2_RUD0[XUD0:b7
DP020:^6D@040:b7DP2^RE@0[hYE0;2;EP<0[hYE0P2^RE@20:f8D`P0/8MC00H0[hAA0:j5D@2_QU80
[XIB0:f8D`2/RE<20:^:E0@0ZhIB0P2/Qe<;0:f8E0030;26E02_QE<0[XAB0080[89@00<0[XAB0:n5
D`2`QU@00P2_QU820:j5D@<0[HA@00<0[8=?0:^6C`2[QTl01P2[QTl80:^6DP80[8M@00@0[8MB0:b7
D`2/QUD0[8IG0P2/QUT20;27D`<0[hIB0`2^QE400`2/Qe80ZhIA0:Z5D0020:V4C`030:Z5D02[QU40
[8MB0080[HA<00H0[XE?0:j5D@2^QE40[H=A0:b2DP2[PE430:b3C`80[HA@0`2^QE420:f4D0<0[8=?
2`2[PTh02`2[PDl0[89@0:j4DP2_QE<0/8ID0:n5D`2^Q580[H=A0:^2CP2/Pdl0[XEA0080[hIB00<0
[XEA0:b3C`2[PTh0202ZQE020:^2CP80[8=?102]Q500102^QDl0[HA>0:f4CP2]Q4h30:b3C@040:^2
C02/Pdl0[8=?0:b3C`80[HA@0`2^QE490:f4D0/0Zh9>0`2/Pdl20:f4D0<0[XEA0P2]Q50;0:b3C`06
0:b7D`2[QU80ZhIB0:Z5D@2YQ500Z8=?0P2WPTh30:V4D080ZXEA0`2[QU800`2^QE40[HA@0:b3C`02
0:^2CP090:b3C`2]Q500[XEA0:b2DP2[PE40Zh5?0:^2CP2ZPDd0ZX5;0080ZH180P2^QE440:b3C`80
[XEA202[PTh00`2/Pdl0[HA@0:j5D@020;27D`030:j5D@2]Q500[8=?0080[Gm;00<0Zh1;0:^2C02Z
Pd`00P2YQ4d02P2XQDd0ZH1<0:V0C02ZPDd0Zh9>0:f4D02_QU80/XUE0;>:EP2]Q5020:b3C`070:^2
CP2ZPDd0ZH1<0:V0C02XOd/0[8==0:f4CP020:j5C`070:f4CP2/Pdd0Zh9<0:Z1B`2^QE40[HA@0:^2
CP030:Z1C@80Zh9>202/Pdd00`2[PT`0ZX5;0:Z1B`0>0:Z1B`<0[8==0P2[PT`30:Z1B`P0ZH1:0`2Z
PDd20:^2CPD0[8=?00@0Zh9>0:Z1C@2YP4`0ZH1<0P2XOd/20:V0C080ZX5=0P2[PTh:0:b3C`<0[89@
0P2[PDl30:Z0CP030:f4D02/Pdl0Zh9>00<0ZH1<00X0ZX5=0:^2CP2WO540Z7e@0:UnD@2ZP500ZX1>
0:V0C02XOdT0Ygi80P2VPDX00`2VPD`0YX5=0:J0C`020:J0D@030:J0D`2ZPDd0ZX5=00H0ZX5=00@0
YX5=0:N2CP2YQ500ZXEA0`2[QU801P2ZQE40[89@0:b2D02[PDl0ZX1>0:UoC@80Z7i<00T0Yge;0:Z1
C@2YP4`0ZH1<0:QoB`2YP4`0ZX5=0:^2CP2/Pdl0202YP4`01P2VPd/0Yh9;0:R3C02ZPd`0Zh9<0:f2
C@80[h5=202YP4X20:V0C0040:Z1C@2[PTh0Zh9>0:Z1C@80ZH1<0`2ZPDd40:V0C080Z7m;0P2XOT`3
0:UoC@<0ZX1>00H0YgaA0:MlC`2WO4l0Yge=0:MmB`2WOTX20:MnB0<0Yge;0P2XOT`30:UoC@80ZHA@
0P2XPdl30:N2CP030:J1C@2WOTX0Z7m;0080Z7m;0P2YP4`20:Z1C@<0ZH1<0P2XOd/30:MnBP/0Y7m;
0P2SOTX30:9mB@030:MnBP2VODT0YGa80080Y7]700H0YGa80:ImB@2WOTX0XWU50:=jAP2TNdL20:El
B0050:AkA`2SNTH0XWU50:5lA`2PNdH00`2ONTD0102QO4L0XWe80:AoBP2TNdL30:=jAP80XWU50P2Q
N4@01P2PO4P0XGa80:5lB02RNTL0XgU70:=gAP80YGM600H0XW0o0:5a@02SLd80XgE30:5f@`2PMd<2
09if@P0@09]eB02LMTL0WGM809egAP2MN4@0WGQ309ag@02KMSl0Y7]70:9iA@2PMd<0WgI209ie@@2O
MT80X7M30:5hA080X7M30P2OMT8209ie@@80WGA0102NM48309me@`040:1fA02LLT00WG=109id@P80
WgE300@0WWA209ec@@2MLd40W7900`2LMd<209]f@P<0VWE10P2KMT8309Ye@@<0VGA00P2LMd<209]f
@P0409Ye@@2IM400VGA009Qc?`80WGA0102OMT8209ed@0P0VgI20P2MLd4209ab@00>09ec@@2OMD<0
X7I40:9hAP2MN4@0W7M309Ye@@2IM400V7<o09Ud@02JMD40VgI209ii@P2MN44409ag@080WWU20P2L
Md<309]f@P0309ag@`2NNDD0WgY600<0W7Q4:oooool002[ooooo402?HSP808iS>00608aQ=02=HSD0
SF8e08iS=P2?I3L0T6Dh0P2AIST309AX=`80TfLf0`2BISD209AS>080UF@i00@0UVDj09MV>`2GIS/0
V6Ll0P2AICP2099V>@80TfLj0P2DJ3/@099V>@T0U6Pk202FJST309M[?P<0UVXm0P2EJC`00`2AIST0
TfPk09I[?P0209Q]@00309M/?`2EJSd0TfPk00@0Uf/j1`2HK3/209U]?0<0VVhm0`2HK3l309U]@080
VVi100<0W70o09Y^?@2IKC`00P2HK3/00`2IKC`0VVhm09a`?`0809Ya?@H0Vg0m0P2LLCh209Y_?0<0
Vg0m0`2LLCh0202QMT40X7E009ic@02LL3l0W71109a`@`2MLD@0WW57102NLd0409eb?`80XGHo00T0
X7E009md@@2NLd00WG5009ea@P2LL440XGI30:1e@P2OM4400P2MLSl00`2OM440X7E20:5f@`020:=h
@`80XWM20P2QMT420:1e@0H0XGE40P2RMTD80:9gA0P0XGM50P2QMT420:9g@P<0XgQ30P2TND@30:Qm
B080Yga70`2VNdH30:=hA@<0Y7U60P2UNTL0202XODX0Yga90:EjA`2TNDH0XgQ50:AiAP2UNTL0YW]8
0`2UNDP20:AhA`<0XgM60P2SNTH30:9iA@<0XGQ400H0VW0n09]a?`2KLCl0W79009ec@@2NM48209me
@`0309ab@02MLd40WWA20080WgE300<0WG=109ab@02KLCl00P2MLd4209ab@0<0Vg4o00<0VW0n09I/
?02EJc/00P2EJc/209AZ>P80TfTi0P2>J3T208eW>080S6Hg0P2;ICH01P2>J3T0SFLh08eW>02<ISL0
RfDf08YT=@80RF<d00<0R68e08MQ=027HC@00P26H3<208EO<P0408AN<@23GC00Ped`08=M<080PU`_
0`21Fbh00`21G380P5/a081K<@0207mJ<0<0OUT_00H0PEP/081F;01nEb`0OEP^07aF;`1jEc4207QF
<@P0N5D_201fD2/00`1`CBL0LDhX079?:@0207AA:`03079?:@1aCRP0L4dW0080KTdZ101_CR/306i=
:P0807A=;01bCR`0LTh/075?;01_CR/0KDl[06]?:P1ZCRT206]=:@<0JT`X0`1YBbL0201WBBL0J4XX
06U;:@1YBbT0J4XX06M99`1UAbD0I4HT201VB2H806M99`0306988`1SBB@0HdTT0080HdTT0`1TBRD2
06I8900606M99@1XBRH0J4XV06M99@1TAR80HT@P201YBbT00`1/BbP0JdXW06Y99P0206U89@0306Y9
9P1[BRL0K4/X00P0KDdW201_CbT01P1cC2d0LDd[075=:`1aCbX0L50Y06iA9`80KU<V0P1cDB`4079@
:`80LDlZ00<0Le4/079@:`1`CRT00P1_CBP00`1`CRT0LU0[07=A;002075>9P<0LTlW0P1aCRH00`1`
CBD0LDhV075>9P06079?9`80M54Y0P1cD2P0101bCbL0LDhV071=9@1_C2@2071>:0@0KddW0P1`CRP9
075A:P80Le0Z00@0LTlY075>:01`CBL0L4dW0P1_C2H0101`D2T0KdlX06i>9`1]CBH406a<9@0306U9
8P1ZBR<0K4`U0080KThW00H0KDdV06a<9@1[Bb@0JTXT06];9@1]CBL206i>:00306e=9`1/C2H0Jd/U
0080JTTV0P1YB2D0101XAb@0IdHS06M68`1WAR<806Q:9P80J4XX0P1WBBL306I89P0306E79@1SAR@0
HdHT00H0HdHT201QAb@206138@0306548P1RAB<0HTDS00<0HTDS00<0I4DV0693901Q@R<00P1P@B80
1`1Q@R<0HT<T06A59P1M@1h0GT4O06548P1SAR@00`1UB2H00`1TAbD0H4<S06138`03065490H0HTDU
101SARH00`1TAbL0HdHT06=6900606=69080IdTU0P1XBRH206U;9`80JT`X00D0JTPR06]98`1]BbD0
KT`V06m=9`0206i<9P0706e;9@1/C2D0KDdV06i>9`1_CbP0L50Y06m?:00206i>9`80KdlV0P1`D2L0
101aDBP0LU8Y07=C:P1cDbX307AD:`0>07=C:P1bDRT0Le<Z07AD:`1fERd0MeL^071C:`1cDb`0M5@[
07IE:P1gEBP0NE@W07]E9P1lERL307UG:@<0NUPZ0P1kFB/00`1mFbd0OU`^07iL;P0207iL;P<0Oed_
00P0PUle085N=020GS40Oed_07mM;@20Gb`0PV4^08=R;@80QF4a0P26HS8308MS<`0308QT=02:ISH0
RVHf0080RfLg0`2<J3P00`2=JCT0SfXf08mZ=P02091[=`@0TF`h00H0T6/g095/>02AK3P0TVdi09=^
>P2DKc/209E`?0P0V7<o0P2KMT4409Ye@080VG@o0`2MN4<209iiA0<0WgY50P2RNDD20:=jAP<0Y7]7
00L0YGa80:In@@2VOT<0Ygm40:MnAP2WOTP0Z7m;0080Z7i<00D0YH1;0:J1C02VPD`0Yh9=0:R3CP02
0:V4C`040:Z5D02WPTh0ZHA@0:^6DP80[HQD00<0ZhIB0:V4D02WPTh00`2]Q5030:j5D@80[hIB0P2^
RED40:n:EP80/8]G0P2bSET20;6<F080/8]G1@2_RUH20;2;E`80/HaH0P2bSET20;>>FP80/XeI0P2a
S5P20;2;E`@0]8]G102eS5P80;2;EP80[hYE0`2`ReH30;6<E`P0]XeI202cSUX80;F;F@P0/XeH202a
S5P0202eReT0]8YH0;:8EP2aQeD0/XQF0;>9E`2dRUP0]H]I0P2bSET20;6<F0`0/8]G00<0/HQD0;:9
E@2bRED00`2cRUH20;:9E@P0[XUD00<0[hYE0:f8D`2/Qe800P2[QU400`2/Qe80[HQC0:n:E@030:n:
E@80[XUD0`2]R5<80;27D`060:n4D@2^QE40[hIB0:j6DP2]R5<0[8UC0P2[RU@20:^6DP@0[8MC2`2]
R5@00`2`QU@0[hEC0:j4DP020:b2D0030:j4DP2_QE<0/8ID00<0[hIB0P2^QE430:f4D0P0ZhIA202[
QU80102/Qe80[8MC0:b7D`2/Qe<40:b6E@060;:9E@2aR5@0/HQD0;27D`2_QU80[XEA0P2]Q5080:^6
D@80[HA<00@0[HA>0:j5D@2]Q500[H=A0P2/PU840:j5D@@0[hIB1P2/Pdl20:^2CPP0[8=?00<0ZX1>
0:^1C`2]Pe400`2_QE<01@2^Q580[H=A0:^2CP2/Pdl0[XEA0080[hIB00<0[XEA0:b3C`2[PTh0202Z
QE020:b3C`H0[HA@2`2/Pdl20:f4D0<0[XEA2@2]Q5080:b3C`<0Zh9>0`2/Pdl20:f4D0<0[XEA0P2]
Q50;0:b3C`030:f5D@2/Q500[8A@0080Zh=?0P2ZPTh00`2YPDd0ZXEA0:Z5D@060:Z5D@030:b3C`2[
PTh0Zh9>00@0Zh9>00<0[8=?0:^1D@2[PDl00P2ZPDd0102YP4X0ZH180:V1AP2YPDH80:f4D0P0[8=?
00<0[HA@0:j5D@2`Qe<00P2aR5@00`2`Qe<0[XEA0:f4D0020:anBP030:YoBP2ZPD/0ZH9;0080Z8=<
00T0YhA<0:^2CP2[PTh0Zh9>0:b3C`2]Q500[XEA0:n6DP2`Qe<00P2/Pdl20:^2CP80ZX5=0P2YP4`4
0:f4CP040:b3C@2[PT`0Zh9<0:Z1B`80[HA@00<0[8=?0:^2CP2[PTh00`2[PTh80:f4D0<0[8=?102[
PTh00`2ZPDd0ZH1:0:V0BP070:V0BP80[HA@0P2/Pdl20:^2CP80ZX5=202YP4X30:Z1C@<0Zh9>0P2/
Pdl20:^2CP80ZX5=0P2YP4`30:QoB`80ZH1<00D0ZX5=0:^2CP2/Pdl0[8=?0:f4D0030:^2CP@0[8=?
00<0[HA@0:f3D@2]Pe400P2/PU020:^1C`80ZX1>0`2[PTh40:Z1C@070:^2CP2YOU<0ZGiA0:UnD@2Y
Odl0ZGm=0:V0C0020:V0BP80YX5:00<0YX5<0:J1C@2VP4l00P2VP5400`2VP5<0ZH1<0:V0C0060:V0
C0060:F0C02VPDd0Yh9>0:V4D02ZQE40ZhIB0P2/Qe<01P2]Pe40[89@0:b2D02[PDl0ZX1>0:UoC@80
Z7i<0`2YP4`20:Z1C@80Zh9>00<0[8=?0:V0C02YP4`01P2YP4`01P2VPd/0Yh9;0:R3C02ZPd`0Zh9<
0:b1C080[X1<202YP4X20:V0C0@0ZX5=0P2YP4`30:Z1C@@0ZH1<0P2XOd/20:QnC0<0ZGm=0`2ZP4h0
1P2XOE80Z7e@0:QmD02XOTh0Z7i<0:QoB`80Z7m90`2WOTX20:QoB`<0ZH1<102[Pdl20:Z2CP80ZH5=
0`2XOd/20:V0C0<0ZX5=0`2YP4`20:QoB`<0Ygi:202UP4`40:AoB`@0Xgi:00<0Yge;0:IlBP2VO4X0
102VO4X0102WOD/0XWU50:=jAP2VODT20:MnBP060:ElB02RNDD0X7M30:9mB02QO4L0X7]60P2ONTD0
0`2QO4L0Xgi90:AoBP020:AkA`<0XgY60`2RNDD01P2QODT0XWe90:5lB02RNTL0XgU70:=gAP80Y7I5
00H0XW910:5c@@2RM480X7E20:1g@`2OMd<209eh@`0A09QbA@2JM4D0WGM809ihA`2NNDD0WGQ309Ye
?P2HLc`0Y7]70:9iA@2PMd<0WgI209ie@@2OMT80X7M30:5hA02OMT800`2NMD4209ed@080W7<o0P2M
Ld40102NM480WgE309me@`2PMT@20:5gA@D0WWA20`2MLd40102LLT00VgI209]f@P2KMT8309Ye@@80
VGA01P2JMD4209Ud@080WGQ400<0W7M309]f@P2JMD400P2IM4000`2HLcl0WWE109ie@@0609ie@@P0
VgI2102MLd401`2NM480WgE30:1fA02PMT@0WWI309ee@P2KLd000P2JLSl00`2KLd00W7A109ee@P05
09ah>P80WGTk00T0WWXl09iiA@2LMd<0VWE109Ud@02JMD40W7M309mjAP2PNdL00`2MNDL[ooooo`00
:_ooool808mR>@P0TF8h0P2=HSL408iS>080SF8g00@0SF8e08iS=P2>HcH0Sf@g0P2@ICP2095V>@@0
U6Pg0P2CIcH2099V=@80Tf8g00<0U6<h09ET>@2FICX00P2GIS/00`2HIc`0TFDh095U>002099V>@80
TfLj0P2DJ3/809=W>PP0TVHg2@2DJ3/809IZ>@<0Uf/n0`2FJSd209EY?003095V>@2CJ3/0UV/n0080
V6e000<0Uf`o09EZ?@2CJ3/0102HK3/609M[>P80V6`k0P2IKC`209Y^?@<0V6`o0`2IKD0209Y^@@03
09a`?`2KKch0VVhm0080V6`k00<0VVhm09]_?P2LL3l0202KLSh209aa?PH0Vg0m0P2JKc`309]`?@<0
W74n00P0XGI10:1e@02NLd00W70o09a`@@2LL4<0WG5409iaA`P0WW=000H0XWM00:5f?`2QMT40X7E2
09md@@2NLT4209ea@P030:5f@`2OM440WW=00080WG8o00<0WW=009md@@2QMT<00P2NLch0102OM3l0
XGI10:9g@P2TND@20:EjA@H0XWI50P2QMD@80:5f@`P0XWQ60`2RMd820:=h@`@0Y7U4102XODP20:Ml
A`80YW]60P2SN4D30:AiAP<0YGY700P0Z7e:0:MlB@2UNTL0Y7U60:=hA@2TNDH0YGY70:IkB0<0YGU:
0P2TN4T30:=gB080XgY60`2RNDD30:5hA00609U_?@2JL3h0VW0n09]a?`2LLT00WG=10P2NM4800`2L
LT00WG=109id@P0209id@P0309ab@02JL3h0VFlm00<0Vg4o0P2JL3h309U_?@80UFXm0P2DJC`309=X
>`03099W>P2<ISL0S6Hg0080S6Hg102;ICH01P2=IcP0S6Hg08aV=`2;ICH0RV@e08US=080R68c1026
H3<408EO<P80PU/`0P21FRl4081I;P<0OeX`0P1nFBl207eH;P0907aG;@20Eb/0P5H/07eF:`1lEbd0
NeD^07UF<01hES40MeD`00P0Me@^201eCb/00`1_C2H0L4dW079?:@0207=@:P03079?:@1`CBL0Kd`V
0080KTdZ101]C2T306i=:P0607A=;01aCB/0LDd[06m=:P1]C2T0JddY0P1ZCRT306Y<:0<0JD/W0P1X
BRH00`1VB2H0IdTW06Q::00206U;:@0306M99`1VB2H0I4HT00P0ITPV201WBBL206A88`80IDTT00H0
ITXU06M;9P1WBbH0Id/V06I88P1WBB<206U;9@0406Q:901VB280IDLQ06E78@P0JT`Z00<0KD`Y06a;
:01[BRL00P1ZBBH00`1[BRL0K4/X06e<:@0806m?:0P0LDlY00H0M4d^079>;01cCbd0LU0[075A:P1`
DbT206mD9`80MU<]0P1eDR`207AA:`80Le0Z00<0ME8/07AA:`1bCbT00P1aCRP00`1bCbT0M54[07EB
;00207=@:0<0LTlW0P1cD2P00`1dDBT0M54W07AA9`0607=@9P0407IC:`1eDRX0M54Y07=@:080LTlW
0P1aCRH8079?:@T0LU8[0P1dDB/00`1cD2X0LTlY075>:002071=9`0D06m<9P1aDBX0LE4Z075A:P1`
D2T0KdlX06e=9P1/C2D0Jd/T06Y:8`1/C2D0KThW06m?:01`D2T0KdlX06i>9`1]CBH0K4`U06e=9P1^
CRL206m?:00406i>9`1/C2D0Jd/T06Y99P@0JDPU0`1XAb@806U;9`0406U;:@1XBRP0J4XX06Q::080
IdTW0P1VB2H@06A79@@0HTDS0P1SAR@206A79@0306A59P1SA2D0HT<T0080H44R00L0HT<T06=49@1T
ABH0GD0N05m2801QA280HdHT0080IDPV0P1TAbD306138`<0HD@T0P1RABD205i48`80GdDT00@0H4HU
06579P1QAbH0HDLV201RAB<306M99@80J4XV0`1YBbL00`1XB240JDTR06];900206e=9P0606a<9@1[
Bb@0JTXS06Y:8`1[Bb@0KThW0`1`D2T01P1^CRL0KDdV06i>9@1^CRD0KdlV071@9`80LE4X0P1bDRT2
07AD:`0=07=C:P1aDBP0LE4X075A:01cDbX0MED/07MG;P1`Db/0LE4Z075A:01dDbP0MeDX07YE:002
07]E9P0307ME9`1hERP0N5HX0080NELY0P1jF2X01@1kFB/0O5X/07aJ;01lFR`0OE/]0080OU`^0P1o
GBl02@20GCD0Oe`d07iK<@1nG2l0OU`^081N;P22H300Pf8_08AP<00308EQ<@80QV8b0P27Hc<01029
ICD0RVHf08YV=P2:ISH208]W=`80S6Ph00<0SfXf08iY=@2>JCD00P2?JSH2091[=`07095/>02?JSH0
T6/g091[=`2AK3P0TVdi09=^>P0209A_>`P0Ug8n0P2KMT4209Ye@080VG@o0P2HLch309ag@P80WGQ3
0`2NND@0102QN4@0XWU50:9iA@2RNDD20:=jAP80Y7]700H0YGe00:Em@P2VOT<0YWe50:MnB02WOTX2
0:MmB`050:F0B`2VPD`0YX5<0:N2C@2XPdh00P2YQ4l0102ZQE00Yh5@0:V3DP2[QE@20:f7EP030:^5
E02YPe80Yh5@0080[8=?0P2]Q5020:j5D@80[hIB00<0[HQD0:j9E@2^RED00P2_RUH20;2;E`@0/HaH
0P2`ReL70:n:EP80/8]G0`2aS5P20;>>FP80/XeI0P2aS5P20;2;E`@0]HaH102dReL80;2;EP80[hYE
0`2`ReH30;6<E`P0]XeI202cSE`80;F;F@P0/XeH202bSET0202eReT0]8YH0;>9E`2bR5H0/HME0;:8
EP2dRUP0]H]I0`2bSET20;6<F080/8]G00<0[hYF0;2;E`2`ReL01P2`ReL00`2cRUH0/XUE0;:9E@03
0;68E080/XUE2@2^RE@01`2]R5<0[8MB0:Z5D02ZQE00[8MB0:f8D`2^RE@00P2_RUD20:j9E080[HQC
0P2/Qe880;27D`060:n4D@2^QE40[hIB0:j6DP2]R5<0[8UC0P2[RU@40:b7D`<0[HQD0P2^RED80:f8
E0030;26E02_QE<0[XAB0080[89@00<0[XAB0:n5D`2`QU@00P2`Qe<20:n6DP80[XEA0P2]Q5080:^6
D@P0ZhIB102]QeH30:f8E0060:f8D`2bRED0/XUE0;68E02`Qe<0[hIB0P2^QE400`2]Q500ZhIA0:^6
D@040:b7DP80ZhIA0P2]Q4`0102]Q4h0[8=?0:f4D02]Pe420:j4E0P0[hIB0P2[PTh>0:b3C`0;0:Z0
CP2[PDl0[H=A0:j4DP2_QE<0[XAB0:f3D@2/PU00Zh9>0:b3C`2^QE400P2_QU800`2^QE40[8=?0:^2
CP080:Z5D080[XEA1P2]Q5040:^2CPL0[8=?0P2]Q5030:j5D@T0[HA@202/Pdl30:^2CP<0[8=?0P2]
Q5030:j5D@80[HA@3`2/Pdl40:^2CPP0ZXEA0`2[PTh20:b3C`<0Zh9>00H0Zh5?0:^2CP2[PTh0ZX5;
0:Z1B@2YPDH20:V1A0P0[HA@202/Pdl00`2]Q500[XEA0;27D`020;68E0030;27D`2^QE40[HA@0080
[7i:00<0ZWm:0:Z1B`2YPT/00P2XPd`02@2WQ4`0[hIB0:n6DP2_QU80[XEA0:f4D02/Pdl0Zh9>0:Z1
C@040:^2CP@0ZX5=0P2]Q4h00`2/Pdd0Zh9<0:^2C0030:^2C0@0[HA@00@0[8=?0:^2CP2[PTh0ZX5=
202]Q5020:j5D@80[HA@00@0[8=?0:^2CP2[PTh0Zh9>2@2YP4X30:f4D080[8=?0`2[PTh80:Z1B`80
ZH1<0`2ZPDd30:^2CP80ZX5=102YP4`40:QoB`040:V0C02ZPDd0Zh9>0:b3C`80[HA@0P2ZPDd20:^2
CP040:b3C`2]Q500[HA@0:f4D0<0[H=A0P2/PU030:^1C`<0ZX5=102[PTh01`2ZPDd0ZWmD0:YoDP2Y
OU40ZGm?0:UoC@2YP4`00P2ZPD/20:J1BP030:J1C02VPDd0YX1?0080YX1A00<0YX1C0:V0C02YP4`0
1P2YP4`01P2UP4`0YX5=0:J1C@2WPTh0ZHA@0:Z5D@80[8MC0P2]Pe400`2/PU00Zh5?0:Z0CP020:Uo
C@040:QnC02YP4`0ZX5=0:Z1C@80Zh9>0`2/Pdl80:V0C0060:N4C02XPd`0Yh9;0:V2B`2ZPD/0Zh1;
0P2]Od/80:Z1B`P0ZH1<0`2ZPDd40:V0C080Z7m;0P2XOT`30:UoC@<0ZX1>00H0Z7eB0:QmD02XOE00
Z7i>0:QnC02XOd/20:QoB@<0Ygi:0P2XOd/30:V0C0<0[8=?0P2[PTh30:Z1C@80Z7m;0P2YP4`20:Z1
C@80Zh9>0`2YP4`20:QoB`<0Ygi:202UP4`80:AoB`<0Yge=0P2XOTh30:MmC@0@0:=jAP2UO4P0Ygi:
0:QoB`2WOTX0YGa80:9iA@2PMd<0XWe80:5lA`2PNdH0WgY50:1kAP2QO4L0Xgi90:F0B`<0Y7]70`2S
NTH20:9iA@060:5mB@2RODT0XGa80:9jA`2SNDL0XgM60P2TMTD01P2SMD<0XGI30:5f@`2PMd<0WgM3
09iiA080WW]50140VG=609]eAP2MMdP0WgU809mjAP2MN4<0VgHo09Ud?@2TNdL0XWU50:1g@`2OMT80
WWE109mf@P2PMd<0XGQ409mf@P0309ie@@80WGA00P2LLcl01@2MLd40WWA209id@P2OMD<0X7I40080
XGM500D0XWQ60:1fA02PMT@0WgE309id@P0509ec@@80W7M30P2KMT8309Ye@@<0VGA01P2JMD4209eh
A080W7M300@0VgI209Ye@@2JMD40VGA0202NMD4809]f@P80WG=10P2NM48309me@`80WWA200L0WG=1
09ab@02KLCl0Vg4o09ab@02NM480WgE30080VWHh00<0VgLi09ah>P2MNC/00`2MNC/0202NNDD0W7M3
09Ye@@2IM400VWE109ag@`2ONTH0X7]70`2MNDT[ooooo`00:_ooool808iQ>PP0TV4h00<0S64f08eR
=`2>HcP00`2>HcP00`2=HSL0S64f091U>007091U>080U6Pg0P2CIcH3099V=@03095U=02CHSL0Tf8g
0080U6<h00@0UF@i09IU>P2GIS/0UfHk0P2AICP2099V>@80TfLj0P2DJ3/809=W>PP0U6Pg2@2DJ3/8
09IZ>@<0Uf/n0`2FJSd209EY?00509=X>`2DJC`0UFXm09I[?P2GK3l00P2FJch00`2EJSd0VFdl09Q/
>`0209Q/>`<0Uf/j00@0UVXi09M[>P2GJcX0Uf/j0P2HK3/309U]?0<0V6`o0`2IKD0209Y^@@0309a`
?`2KKch0VVhm0080VFdl00<0VVhm09]_?P2LL3l0202KLSh309aa?P<0Vg0m102JKc`309]`?@<0W74n
00T0XGI10:1e@02NLd00W70o09a`@@2LL4<0WG5409iaA`2MLSl00`2NLd0309md@@070:1e@P2QMSl0
X7Dn0:1e@02PMD80WgA109mc@P0209mcA0030:1e@P2OM440WW=00080WG8o00/0WW=009md@@2PMD80
Vg0k09aa?02NLch0X7E00:=h@`2UNTD0Yga70:QmB0030:=gAP<0XWI50P2QMD@80:5f@`P0XgU70P2R
Md820:=h@`@0Y7U400<0YGY50:QmB02XODP00P2WO4L30:IkAP030:EjA@2SN4D0Y7U60080Y7U60P2U
NTL20:IkB0080:QmBP2WO4T0YGY70:AiAP2SN4D0Y7U60:EjA`2VNdP30:EiC080Y7Q;0`2SMdX20:=j
AP<0XWU50`2QN4@309]a?`<0W7900P2MLd40202LLT00WG=109ec@@2NM480WG=109]a?`2IKcd0Ufdk
0P2IKcd209Q^?0<0Ufdk00<0UV`j09AY?P2DJCh00P2CJ3d3099W?003095V>`2;ICH0RfDf00D0RfDf
00L0RV@e08aV=`2;ICH0RfDf08YT=@29Hc@0R68c0080Qf4b2025Gc801022Fc80PEXa085J<@21FS42
081I<080OeP_0100O5L]07eH;P1nFBl0OUT_07eH;P1lEbd0NeH/07YE:`1oERX0OeD[07aE:P1kER`0
NU@]07QE;`1gEC00MU@_201gE2h8079>;00306i;9@1_C2H0LDhX0080LTlY00H0LDhX06m<9P1^BbD0
KTdZ06e<:@1/BbP206]:9`0:06a;:01]C2T0KD`Y06i=:P1cC2/0L4`Z06i::01/BRL0JdXW06U;9`80
JDdX0`1ZC2P206U;9`<0J4XV00<0IDLU06I89P1XBRP00P1YBbT00`1XBRP0ITPV06E79@0806E79@<0
ITPV0P1WBBL306Q::080ITPT00@0IdTU06Q:9P1YBbL0JD/W0P1ZC2P01@1VBB40JTdU06e@:01/CbL0
JD`T0080IdXR00<0J4/S06]=:@1[CBT01P1[CBT00`1_CR/0KTdZ06e<:@0206a;:00306e<:@1^CBX0
Kdh[00P0L50W201cD2P01P1eCRl0M50^07A@;P1cDB`0Le</075D:P80LEHY0P1jE2d0101iDb`0N58[
07MA:P1gDBX207I@:@0307QB:`1gDBX0MU0Y0080MDlX00<0MU0Y07MA:P1hDR/00P1eDRX307AA:@04
07EB:P1gE2`0Me@/07IC:@<0ME8X0`1dDBL01`1cD2H0MU<[07EB:P1dDBT0Le0X079?9`1cD2P00P1d
DBT00`1dCRT0MDlZ07I@:`0207MA;00307I@:`1eCbX0M4hY00T0LE4Z00@0M54[07=@:P1cD2X0Le0Z
101bCbT04`1bDR/0Le</07=C;01bDR/0LE4Z06m?:01]CBH0Jd/T06a<9@1]CBH0KdlX071@:@1aDBX0
L50Y06m?:01^CRL0KDdT06i>9@1_CbH00P1`D2L00`1^CRD0K4`S06];8P0806Y99PP0JT`X00@0JT`Z
06U;:@1YBbT0JD/Y0P1XBRP206M99`P0ITTW201WBBD00`1VBRD0IDTT06A88`0206=78P0606A88`1U
BB@0IDTT06A59P1SA2D0HT<T0P1Q@R<01P1R@b@0Hd@U06A59P1O@R00HD@R06958`<0I4LU0P1RAB<2
05m28P80H4<S0`1QA2@00`1RABD0G4@R05a48P0205e58`0405i6901OAbD0H4PV06189PP0HdHV00@0
ITPT06M99@1WBBD0IdTU0P1XBRH206U;9`0306E8801WBR80JD`T0080JdhV00/0JD`T06M:8P1UB200
J4PQ06Y:8`1]CBH0L50Y075A:P1`D2T0KThW06e=9P0206e=900306i>9@1_CbH0L50W0080LE4X00D0
LU8Y07=C:P1cDbX0LE4X06m?9P0206i>9@0;075A:01cDbX0MED/06mB:P1_CbP0KdlV079A9P1gEBP0
NeHY07]E9P1iDb@00P1gEBL0101hERP0NELY07YH:P1jF2X207]I:`80NUPZ00<0NeT[07aJ;01mFbd0
0P1nG2h02P1oGBl0OU/e07iK=@1mFS80OEX`07iL;`1oGBl0PV0`08=Q<@23Gbl308AP<080QF4a0P26
HS801028I3@0RFDe08UU=@29ICD208YV=P80RfLg0P2>JCD308eX=00408mZ=P2@JcL0TF`h08iY=@80
SfXf00<0T6/g095/>02BKCT00P2CKSX809Mb?P<0VWE00`2IM3l209Qc?P<0VgI10P2LMd8309eh@`04
0:1g@`2QN4@0XGQ40:5hA080XWU50P2SNTH0202TO3l0Y7a10:Em@P2UO4@0YWe70:ImB@2VO4X0Yge;
102WPTh40:R3C`030:R2D`2YPe@0ZXAE0080ZhEF00<0ZXAE0:V3E02XPU<00P2/Pdl0102]Q500[XEA
0:n6DP2_QU820;27D`80[HQD00@0[XUE0:n:EP2_RUH0/8]G102aS5P20;2;E`<0[hYF0P2^RED40:n:
EP80/8]G0P2aS5P20;>>FP80/XeI0P2aS5P20;2;E`040;J=F@2eS5P0]HaH0;F<F0<0]8]G00<0/hYF
0;2;EP2`ReH01P2`ReH20:n:E@<0/8]F0`2aS5L80;J=F@P0/heN202eReT80;:=F0P0/XeI00P0]XaJ
0;F;F@2cREL0/XQF0;67E@2bR5H0/hUG0;B:F080/8]G0`2aS5P00`2`ReL0[XUE0:f8E0080:n:EP03
0;B;E`2cRUH0/HQD00<0/8MC0P2aR5@90:j9E0060:f8D`2[QU40ZXE@0:Z5D02[QU40[HQC102^RE@2
0:f8D`<0[8MB202`Qe<01P2_Q540[XEA0:n6DP2^QU80[HQC0:b9D`80ZhYD102/Qe<20:f8E0<0[XUE
202]R5@00`2`QU@0[hEC0:j4DP020:b2D0030:j4DP2_QE<0/8ID00<0/8MC0P2_QU830:j5DA00ZhIB
0P2]QeX0102]QeP0[HMF0:f8E02]R5<20:f8D@<0/HQD0`2`Qe<20:n6DP80ZhIA00@0[8MB0:f8D`2]
R5<0[8MB0P2[QU420:f4C0070:b3C@2/Pdl0[8=?0:f3D@2^Q5@0[hEE0;27D`030:n6DP<0[XEA00@0
[HA@0:^2CP2[PTh0Zh9>0`2/Pdl20:f4D0P0[8=?00<0ZGm=0:^1C`2/PU000`2^Q5801@2]Pe40[89@
0:^2CP2/Pdl0[XEA0080[hIB00<0[XEA0:b3C`2[PTh0202ZQE020:n6DP80[XEA102]Q5030:Z0CP80
Zh5?0`2/PU030:b3C`80[HA@0`2^QE490:f4D0P0[8=?0`2[PTh30:b3C`80[HA@0`2^QE420:f4D0/0
[8=?202/PD`30:^6DP80ZXEA0`2YQ5000`2[PTh0[8=?0:f4D0020:j5D@0;0:f4D02/Pdl0Zh9>0:f4
D02]Q4h0[8==0:b3B`2[PdP0Zh=60:^3A@2ZPT@00P2/Pdl40:j5D@/0[8=?00L0[HA@0:j5D@2`Qe<0
/8MC0:j5D@2]Q500[8=?0080[Gm;00<0Zh1;0:^2C02ZPd`00P2YQ4d02@2XQDd0/HQD0;68E02`Qe<0
[hIB0:f4D02[PTh0Z7m;0:MnBP040:^2CP@0ZX5=00<0[XE?0:f4CP2[PT`00`2ZPD/20:^2C0080:b3
C`2]Q500[XEA0:j5D@2]Q500[8=?0:^2CP2ZPDd80:j4DP80[hEC0P2^Q580102]Pe40[89@0:^1C`2[
PDl90:Z1B`040:j4DP2]Pe40[H=A0:f3D@80[89@0P2[PDl80:Z1B`<0ZH1<0P2ZPDd30:^2CPD0ZH1<
0`2XOd/02@2WOTX0Z7m;0:V0C02ZPDd0Zh9>0:b3C`2]Q500[XEA0:V0C0020:Z1C@030:^2CP2/Pdl0
[HA@0080[XEA00@0[XAB0:f3D@2]Pe40[H=A0P2/PU020:^1C`030:QoB`2YP4`0ZX5=00<0[8=?00X0
Zh9>0:Z1C@2[P5D0ZWmB0:UnD@2YOdl0ZGm=0:V0C02ZPD/0Zh9<0P2VPDX00`2VPD`0YX5=0:J0C`02
0:J0D@030:J0D`2ZPDd0ZX5=00H0ZX5=0P2WPTh20:J1C@050:N2CP2YQ500ZXEA0:^6DP2^Q5800P2]
Pe400`2/PU00Zh5?0:Z0CP020:UoC@050:V0C02ZPDd0Zh9>0:b3C`2]Q5000P2/Pdl00`2[PTh0ZH1<
0:V0C0060:V0C0060:N4C02XPd`0Yh9;0:V2B`2ZPD/0ZWm:0P2/OTX80:Z1B`030:Z1C@2YP4`0Z7m;
0080Ygi:00<0Z7m;0:V0C02ZPDd00`2ZPDd40:V0C080Z7m;0P2XOT`30:UoC@<0ZX1>00H0ZGiC0:Un
D@2YOU40ZGm?0:UoC@2YP4`20:V0BP<0Ygi80P2XOdT30:V0BP040:b1C02[P4/0Zh1;0:^0B`80ZWm:
0P2YOTT30:V0C080ZX5=0`2[PTh30:V0C080Z7m;0`2WOTX80:J1C@040:=nBP2TOd/0Y7m;0:AoB`<0
YH1<00<0YX5=0:MlC`2XOE00102YOU40102XOE00Yga?0:ImB@2VODT20:MnBP070:ImB@2TNdL0XWU5
0:5hA02SOTT0XWe80:5lA`020:1kAP030:9mB02TOdX0YH1;0080YGa80P2TNdL30:=jAP070:9iA@2P
O4P0XGa80:5lB02RNTL0XgU70:=gAP020:EgAP0H0:AiAP2SNTH0XWU50:5iA@2ONTD0Wga609mnB02P
OdT0W7I909egB02NN4T0WgU809mjAP2NND@0WGQ109ag@02TNdL0XWU50:1g@`2OMT80WWE109mf@P2P
Md<0XGQ40P2PMd<209mf@P80WWE10P2MM40309me@`<0X7I40P2QMdD0102RN4H0XGM509me@`2NM484
09ec@@0409id@P2MN4@0WGQ409ehA080W7M30`2KMT8309Ud@0<0VWE10P2KMT8809ag@`80WgI2102M
M40209mf@PP0VgI20P2MLd402@2NM480WgE309me@`2OMD<0WWA209ec@@2NLT40WG5009a`?`0209]_
?P0709ea@02OLd80X7A309Qc?02IM3d0VgHo09ag@00409eh@@80W7M30`2KMT800`2LMd<0WWU509mj
AP0309agBR_ooooo000Zooooo`P0SV4j202BHCP00`2;H3D0S64f08iS>00208mT>@0508iS>02<HCH0
Rf0e09=X>`2BIcX00P2AIST0102@ICP0Sf@g08iS=P2=HSD209=W=P80TVHe0`2AIC@00`2@I3<0U6<h
09AS>00209AS>0@0UF@i0P2AICP2099V>@80TfLj2P2DJ3/809IZ>@T0UFTl202FJST309M[?P<0UVXm
0P2EJC`209EZ?@<0U6Tl00<0UFXm09M/?`2HKD000P2IKC`209Q/>`80Uf/j0P2FJST409M[>P80V6`k
0P2IKC`309Q/?`<0VFe00P2JKT400`2MLD00W70o09Y^?@0209U]?00309Y^?@2LL3l0WG5000P0Vg8n
0P2MLSl209aa?P0309]`?@2JKc`0VVll00<0VVll0`2KL3d309aa?P080:5f@@2PMD00WW=009a`?`2L
L440W71309eaA02NLDL209eb?`80WW=000@0WgA10:1e@P2PMD80X7E20P2OM3d0102OM3l0X7E20:1e
@P2QMD@20:5eAP030:1e@P2OM440WG8o0080W74n00<0WG8o09md@@2PMD800P2NLch0102OM3l0XGI1
0:9g@P2TND@20:EjA@80Y7Q70P2SMdH20:9fA@80XGE4202PMD880:AjB0<0XgQ3102TND@20:EjA@80
Yga70P2VNdH30:EjA@040:AiA02TNDH0Y7U60:AiAP80YGY70`2VNdP0202XODX0Yga90:EjA`2TNDH0
XgQ50:AiAP2UNTL0YW]80`2UND`20:AhB`<0XgM:0P2SNTH30:9iA@<0XGQ400@0WWA209ec@@2MLd40
WG=11P2LLT0209ec@@0309ab@02JL3h0V6hl00@0UV`j0P2EJcT309AZ>0<0TfPn0P2BIcd3095V?0P0
RV@e0P2;ICH00`2:I3D0RF<d08QR<`0208MQ<P0408IP<@24GS40Q5ha08AN<@D0QElb0`22Fc82085J
<@<0P5T`00h0NeH/07aG;@1mF2h0OUT_07eH;P1lEbd0NUD[07QC:@1nEBT0OU@Z07aE:P1jEB/0NU@]
07MD;P80MU@_201fDbd8071>:`0306e:901^BbD0L4dW0080LDhX00H0L4dW06i;9@1]BR@0KTdZ06e<
:@1[BRL206Y99P0=06]:9`1]C2T0KD`Y06i=:P1aBRT0KTXX06a89P1YAb@0J4LT06I8901WBbH0J4`W
06Y<:00306U;9`80J4XV0P1WBBD00`1UAbD0ITPV06M99`0206U;:@0306Q::01WBBL0ITPV00T0IDLU
0P1VB2H206M99`80J4XX00H0JD/Y06U89@1ZBBH0JTTV06]:9`1]C2T206i=:P0906m>:`1XBb<0K4lW
071C:`1_DRX0JdhV06Q;8`1YC2@0JdhV00P0K4hX00<0LE0]071?;01_CR/00P1^CBX00`1_CR/0L4l/
075@;@08075B9PP0M54W00H0MTl`07EA;`1eDBl0M58]07AD;@1bEB/2079G:P0607eF;@1lEB`0Ne@[
07YC:P1iDRT0N54X0P1gD2L00`1jDbX0NE8Y07QA:00207M@9`0;07QA:01iDRT0NU<Z07QE;@1gE2`0
MU<[07EB:P1fDb/0N5D]07YG;`1kF3000`1gEBP00`1fE2L0ME<V07EC9P0207AB9@0;07IC:`1eDRX0
Le0X079?9`1cD2P0M54Y07IC:`1gE2`0MDdY07M?:`1hD2`00P1iDBd00`1hD2`0Mdl[07E=:@09075A
:P04079?:@1cD2X0Le0Z07=@:P@0M54[0100Le</07AD;@1dE2d0M5@]079B:`1`D2T0KDdV06];901]
CBH0KThW071@:@1aDBX0LU8[075A:P1`D2T0KdlX0P1_D2@01P1`DBD0LE8V071A9@1_D2@0KDhR06]<
80P0K4/X201ZC2P306Y<:P80JD/Y0`1XBRP806M::0P0JTXT00@0JDdV06Q<9@1VBR<0I4PQ0P1SAb00
1@1TB240IDTR06E69`1TABH0HT<T0080HD8S00D0HT<T06A59P1UARL0HTDS06=6900306A79@030695
8`1P@b40Gd8P00<0Gd8R0P1P@b<30654900605U2801J@b40Fd@R05a58`1MAR@0GTLU0P1OB2H806=6
:080ITPT0`1WBBD306Q:9P0306=77`1UBB40J4`T0080JThV00/0J4`T06E98@1RAQh0ITHO06U98P1]
CBH0L50Y075A:P1`D2T0KThW06a<9@0206a<8`0306e=901^CRD0KdlV0080L50W0`1aDBP0401_CbH0
KDdT06];8P1[Bb80KThU079B:@1dE2/0Ke8Z06i>9`1/C2<0L4lT07ME:01lEbX0NeDV07QB8`1gEBL2
07QF:00507UG:@1kFB/0O5X/07aJ;01mFbd00P1iEbT03P1jF2X0NeT[07aJ;01mFbd0OU`^07mM;`1m
FCD0OEXd07aI<`1lFC40OEX`07mM<021Gc40Pf4c0`23Gbl208AP<0<0QF4a0`28I3@208UU=@<0RVHf
00<0SVTe08eX=02<Ic<00P2<Ic<00`2>JCD0T6/g095/>00208iY=@0308mZ=P2@JcL0TF`h0080TVdi
00<0Tfhj09Ia?@2FLCd01P2FLCd309Qc?PD0VG@o0P2JMD0209]f@@<0W7M200@0WGQ30:1g@`2PMd<0
X7M30P2QN4@30:9iA@060:=k?P2TO440Y7a10:Ak@`2UO4H0YGa80P2VO4X40:R2D@@0Yh5@00<0ZXAE
0:V3E02XPU<00`2XPU<0202YPe@0ZXAE0:b3C`2]Q500[XEA0:n6DP2`Qe<0/HQD0P2bRED01@2/Qe<0
[HQD0:f8E02^RED0/8]G0080/HaH00@0/XeI0;2;E`2`ReL0/8]G0`2_RUH50:j9E@<0[hYF0`2`ReL2
0;>>FP80/XeI0P2aS5P20;2;E`80]XeI0P2eS5P20;B;E`80/hYF202`ReH20:n:E@<0/8]F0`2aS5L8
0;J=F@P0]8iO202eReT80;:=F0P0/hiJ00H0]heK0;F;F@2cREL0/XQF0;67E@2bR5H20;>9E`80[XUE
0`2`ReL00`2^RED0[8MC0:^6DP080:f8E0030;F<F02cRUH0/HQD00<0[hIB00<0/8MC0;68E02^RE@0
1`2^RE@00`2]R5<0[8MB0:^6D@020:Z5D0030:^6D@2/Qe80[HQC0080[XUD0P2]R5<40:b7DPP0/8MC
00H0[hAA0:j5D@2_QU80[XIB0:f8D`2/RE<20:^:E0030:b7D`2]R5@0[HQD0080[HQD0P2^RED20:n:
EPP0[HQD00<0/8ID0:n5D`2^Q5800P2/PU000`2^Q580[hEC0;26E0040;27D`80[hIB0P2^QE480:^5
E0P0ZhIB0P2^Qe`0102^R5/0[XQG0:j9E@2^RE820:j:D0@0/8MC102aR5@00`2ZQE00ZhIA0:f8D`02
0:j9E0060:f8D`2[QU40ZXE@0:f4C02/Pd/0Zh9<0P2[PTh00`2]Pe40[hEE0;67E`020:n6DP80[XEA
00@0[HA@0:b3C`2/Pdl0[8=?0P2ZPDd20:^2CP030:b3C`2]Q500[HA@00T0[HA@00<0ZGm=0:Z0CP2/
PU000P2^Q5801P2]Pe40[89@0:^1C`2[PTh0[8=?0:j5D@80[hIB00<0[XEA0:b3C`2[PTh0202ZQE00
0`2`Qe<0[hIB0:n6DP020:j5D@80[HA@00<0[8=?0:UoC`2YOdl00P2ZP500102[PE40[89B0:b2DP2/
PU830:b3C`80[HA@0`2^QE4A0:f4D0<0Zh9>0`2/Pdl20:f4D0<0[XEA0P2]Q50;0:b3C`<0[H191@2^
PDX00`2/Qe<0ZhIB0:^6DP020:Z5D@80ZHA@00@0Z8=?0:b3C`2]Q500[hIB0P2`Qe<00`2_QU80[HA@
0:b3C`020:n6D0030:j5C@2^QT/0[HE80080[HE700@0[8E40:^2CP2/Pdl0[XEA0P2_QU800`2^QE40
[8=?0:^2CP080:f4D0030:Z1C@2/Pdl0[HA@0080[XEA00<0[HA@0:b3C`2ZPDd00P2^P4`01P2]PTd0
[8==0:b5CP2ZQDh0ZhI?0:Z7C`80[XEA0P2_QU80102^QE40[8=?0:Z1C@2YP4`40:Z1C@@0Zh9>00<0
[XE?0:f4CP2[PT`00`2YP4X02P2ZPD/0Zh9<0:b3C`2]Q500[XEA0:n6DP2^QE40[HA@0:^2CP2ZPDd8
0:j4E0060;67E`2`QUH0[hEE0:j4E02]Pe<0[89B0P2[PE490:^2C080[XAD0`2]Pe<30:b2DPP0ZX5;
0P2XOd/20:V0C0<0ZX5=00<0Zh9>0:QoB`2XOd/0102XOd/20:V0C0080:ImB@2WOTX0Z7m;0:Z1C@2[
PTh0[HA@0:j5D@2_QU820:V0C0060:Z1C@2[PTh0[8=?0:f4D02^QE40[hIB0P2^Q5830:f3D@<0[89@
0100Ygi:0:QoB`2ZPDd0[8=?0:f4D02/Pdl0Zh9>0:Z1C@2/PEH0Zh1C0:UnD@2XOTh0Z7i<0:V0C02[
PT`0[8==0P2VPDX00`2VPD`0YX5=0:J0C`020:J0D@030:J0D`2[PTh0Zh9>00H0Zh9>00<0ZHA@0:R3
C`2WPTh00P2VPDd00`2WPTh0ZHA@0:Z5D@020:j4DP040:f3D@2/PU00Zh5?0:Z0CP80ZGm=00P0Z7m;
0:Z1C@2/Pdl0[HA@0:j5D@2]Q500[8=?0:^2CPP0ZH1<00H0YhA<0:R3C02WPT/0ZH9;0:V0BP2ZOdX2
0:]mB@P0ZX5;00<0ZX5=0:V0C02WOTX00P2VODT00`2WOTX0ZH1<0:Z1C@030:Z1C@@0ZH1<0P2XOd/2
0:QnC0<0ZGm=0`2ZP4h01P2YOU<0ZGiA0:UnD@2YOdl0ZGm=0:V0C080ZH1:0`2WOTH20:QoA`<0ZH18
00@0[7m80:]nA`2[OTL0Zgi70P2ZODH20:UlA@80ZH1<0P2ZPDd40:^2CP<0ZH1<0P2XOd/30:MnBPP0
YX5=0P2SOTX20:AoB`070:F0C02VPDd0YX5=0:J1C@2WO4l0Z7e@0:YoDP020:^0D`070:YoDP2XOE00
Yga?0:V0C02XOd/0YWe90:ElB0030:=jAP090:AkA`2SOTT0XWe80:5lA`2PNdH0XGa70:9mB02TOdX0
YH1;00<0YGa80P2TNdL30:=jAP0609ijAP2ONTH0WgY60:9jA`2SNDL0YGU80P2WNDP05`2VODT0YGa8
0:=kA`2PNdH0X7e709mnB02QP4X0XX=<0:5kCP2PNT/0WgU:09ihA`2NNDD0WgY50:1kA02QO4D0Y7]7
0:9iA@2PMd<0WgI209ie@@2OMT80X7M300@0XGQ40P2PMd<309mf@P<0XGM50`2PMT@209me@`040:Aj
B02RN4H0X7I409id@P@0WG=100@0WWA209mjAP2ONTH0WgY60P2NNDD309ehA080V7<o0P2IM400202J
MD40VgI209]f@P2KMT80VGA009Ye@@2KMT80W7M30P2MN4@01@2NNDD0WgY60:1g@`2OMT80WGA00080
W7<o00<0WGA009mf@P2PMd<0202KMT800`2MLd40WWA209me@`020:1fA00509me@`2MLd40W79009ma
@02NL3l00`2MKch01`2OLD00XG=20:9d@`2FL440V79309YdA@2MMdP00P2NN4T01`2MMdP0W7I709Ye
@@2KMT80W7M309ehA02NNDD00P2MN4@0102LMd<0VgI:09]fBP2KMTX[ooooo`00:_ooool808iP?0P0
U60h00<0RUld08aQ=P2=HSL00P2?I3T00`2=HSL0S64f08YO=00209AY?00609=X>`2AIST0Sf@g08iS
=P2=HSD0S64d0P2BISD2095U=0<0T6@c00<0Sf<b09ET>@2EI3T01P2DHcP2095U>080TVHi0P2CIcX:
09AX>`P0Uf`i2@2EJC`809IZ>@<0Uf/n0`2FJSd209EY?00809M/?`2EJSd0TfPk099W>P2CJ3/0UFXm
09Q]@02IKT4309U]?00309Q/>`2GJcX0UVXi00<0UVXi0`2GJcX209Q/>`80VFdl0`2HK3l309U]@080
VVi100<0WG5009a`?`2JKSd00P2IKC`00`2JKSd0W70o09ea@00809]b?P80WG8o0P2LLCh0102KL3d0
VVll09Y_?02IKS/209Y_?0<0Vg0m0`2LLCh0202QMT40X7E009ic@02LL3l0W71109a`@`2MLD@0WW57
0P2MLSl0102NLd00WgA109md@@2PMD820:5f@`80WW<l00@0Wg@o0:1e@P2QMT<0XGE40P2RMTL00`2P
MD80WgA109eb?`0209aa?P0309eb?`2OM440X7E200@0XWM2102QMT40102UNDP0Y7Q70:AhA`2SMdH2
0:9fA@80XGE4202PMD880:AjB0<0XgQ30P2TND@40:EjA@80YW]60P2UNTD30:AiA0030:=h@`2TNDH0
Y7U600<0YGY70`2VNdP0202XODX0Yga90:EjA`2TNDH0XgQ50:AiAP2UNTL0YW]80`2UN4h20:AgC@<0
XgI<0P2SNTH30:9iA@<0XGQ400H0X7I409me@`2OMD<0WWA209ec@@2LLT0209]a?`80W7900P2MLd40
0`2KLCl0VFlm09M]>`0309E[>@80U6Xh0`2CJCL00`2BJ3H0TfPn09=X?P02099W?@<0TFHl00<0T6Dk
08US=029Hc@00P29Hc@408YT=@0608]U=P2:I3D0RV@e08US=028HS<0Qf4b0P26H34408AN<@@0QElb
00@0Pe`e089K=022Fc@0PU/d0P21FS<2081I<P0307YE:`1kER`0O5L]0080OEP^00/0NeH/07UD:P1g
DRP0OUDY07iD:P1kE2T0NUD[07UC;01gE2h0MU@_07EC;P0807IC;@P0Kd`/00<0KDXT06i;9@1`CBL0
0P1aCRP01P1`CBL0KT/U06e:901^CBX0K4/X06]:9`80JDPU00`0JdXW06a;:01/BbP0KTdZ0719:01/
B2H0JTHT06Q68`1VAB80IDLS06E9901WBbH406U;9`80J4XV0P1WBBD00`1UAbD0ITPV06M99`0206U;
:@0306Q::01WBBL0ITPV00X0IDLU00@0ITPV06M99`1WBBL0J4XX0P1YBbT01P1ZBBH0JdXW06]:9`1]
C2T0KTdZ06m>:`80L4l/00P0J4/Q06iA9`1bEB/0LE@Z06a?9@1XBb40JTdS06e@9PP0K4hX00<0Le8_
079A;P1`Cb`00P1_CR/00`1`Cb`0LU4^07=B;`08079C9`P0Me8X00H0Me0a07EA;`1eDBl0ME<^07AD
;@1cER`2079G:P0;07iG;P1mERd0O5D/07]D:`1jDbX0NE8Y07QA:01gD2L0Ne@[07YC:P1hDBP00P1g
D2L01@1hDBP0NU<Z07]D:`1jEbl0NEH^00<0Me@/00<0NEH^07aI<@1mFS800P1hERP207ME9`0?07ID
9P1eDbD0ME<U07AB901eDRX0M54Y07=@:01bCbL0Le0X07EB:P1hEBd0NEH^07I>:P1gCb/0NE4]0080
NU8^00<0NE4]07M?:`1fCRX02@1`D2T01P1aCRP0LTlY079?:@1cD2X0M54[07EB;080MU<]0P1dE2d2
07EE;P0707=C;01`D2T0KDdV06];901]CBH0KdlX071@:@03079B:`04075A:P1`D2T0Ke0T071A9@<0
LE8V00<0Ke0T06e>8P1[C2001@1]C2T306i=:PP0JddY00@0Jdd[06Y<:P1ZC2X0JT`Z0P1YBbT206Q:
:0P0IdXX201ZBR@0101/D2T0JThW06M;901TB24206=7800506A88@1UBB80IDHW06A59P1R@b@00P1Q
@R<01@1R@b@0I4DV06E69`1SAR@0I4LU0080IDPV00@0HdHT06548P1O@R00GD0N0`1O@R8306138`80
HD@T0P1I@R000`1J@b40Fd@R05a58`0205i79@0305m89P1TAbT0I4LY00H0I4LY0`1VB2@206M99@<0
J4XV00<0HdLO06E98@1XC2@00P1ZCRH02`1WBb<0I4PP06557@1VAQl0J4PQ06e=9P1`D2T0LE4Z071@
:@1^CRL0K4`U0080K4`S00@0KDdT06i>9@1_CbH0KdlV101`D2L03`1^CRD0Jd/R06U9801ZBR40KDdT
071@9`1cDbX0Ke8Z06e=9P1[Bb80L4lT07ME:01lEbX0NeDV07QB8`0207QF:00<07UG:@1jF2X0NeT[
07aJ;01mFbd0OU`^07QF:01iEbT0NUPZ07]I:`1lFR`0OE/]0P1nG2h207aH=00707]H<P1kF300OEX`
07mM<021Gc80Pf4c089N;P0308=O;`80Q60`0P25HC401027Hc<0R6@d08QT=028I3@208UU=@80RVHf
00<0SVTe08eX=02<Ic<00P2;IS80102=J3@0SfXf095/>02=J3@208iY=@0308mZ=P2@JcL0TF`h0080
TVdi202FLCd209Mb?@80V7<n0P2IM3l509Ye@080VgI10`2LMd80102OMT80X7M30:1g@`2PMd<20:5h
A080XWU500T0Xg/n0:=k@02TO440Y7]30:ElAP2UO4P0YG]90:IlBP2ZQ5<00P2YPe80202XPU40Yh5@
0:J0C`2VP4l0YGm>0:b6F@2ZQ5L0Z89E0P2VP5<00`2XPUD0ZXAG0:b6F@020:f4D0040:j5D@2_QU80
/HQD0;:9E@80/hYF0P2/Qe<0102]R5@0[XUE0;2;E`2aS5P20;:=F@<0/8]G0P2_RUH70:j9E@80[hYF
0`2`ReL20;>>FP80/XeI0P2aS5P20;2;E`<0]XeI00<0]HaH0;B;E`2cRUH00P2cRUH80;2;EP80[hYE
0`2`ReH30;6<E`P0]XeI202dSV480;F;F@P0/XeH202cSUX0102gSE/0]XaJ0;B:F02bR5H20;67E@0:
0;:8EP2cREL0[8MC0:f8E02_RUH0/8]G0:n:EP2]R5@0ZhIB0:Z5D@P0[8MC00P0]HaH0;>:EP2aR5@0
[hIB0:j5D@2_QU80/8MC0;68E0P0[XUD00<0[HQC0:b7DP2[QU400P2YQ4l00`2[QU40[8MB0:f8D`02
0:j9E080[HQC0`2/Qe800`2[QU40/8MC0;27D`060;27D`060:n4D@2^QE40[hIB0:j6DP2]R5<0[8UC
0P2[RU@50:f8E080[XUE0P2_RUH80:f8E0030;26E02_QE<0[XAB0080[89@00@0[XAB0:n5D`2`QU@0
/HQD0`2`Qe<20:n6DP80[XEA202[QE@80:^6DP090:j7GP2^Qe`0[XQK0:j8E`2^RE@0[XUB0:j:D02^
RTh0[XEA0080[hIB00<0/8MC0;68E02bRED00P2cRUH00`2ZQE00[8MB0:f8D`020:n:E@0;0:f8D`2/
Qe80ZXE@0:f4C02/Pd/0Zh9<0:Z1C@2[PTh0[H=A0;26EP2aQeL00P2^QE420:f4D0030:b3C`2[PTh0
Zh9>00<0ZX5=0P2[PTh0102/Pdl0[HA@0:f4D02^QE480:f4D00;0:UoC@2ZP4h0[89@0:f3D@2^Q580
[H=A0:b2D02[PDl0Zh9>0:b3C`2^QE400P2_QU800`2^QE40[8=?0:^2CP080:Z5D080/8MC0P2_QU80
102^QE40[HA@0:f4D02/Pdl30:UoC`030:Z0D02[PE40[89B0080[89B0`2/Pdl20:f4D0<0[XEA4@2]
Q5030:^2CP<0[8=?0P2]Q5030:j5D@80[HA@2`2/Pdl40:f0B@@0[X5:0P2/Qe<0102[QU80ZXEA0:Z5
D@2YQ5020:R3C`030:f4D02^QE40/8MC0080/HQD00T0/8MC0:j5D@2]Q500/8MA0;27C`2_QTh0[hM<
0:n7BP2^QTP00P2^QdH00`2[PTh0[8=?0:j5D@020:n6DP030:j5D@2/Pdl0Zh9>00P0[HA@00<0ZH1<
0:Z1C@2/Pdl00P2]Q5004`2/Pdl0ZX5=0:V0C02_PDd0/89>0:j3CP2]Q4h0[HI?0:^6C`2/Qe00ZhQ@
0:V0C02[PTh0[HA@0:n6DP2`Qe<0[hIB0:f4D02/Pdl0102ZPDd40:^2CP0:0:j5C`2/Pdd0ZX5;0:V0
BP2XOdT0ZH1:0:Z1B`2/Pdd0[8=?0:f4D0<0[hIB00<0[HA@0:^2CP2ZPDd0202^Q5@20;67E`030;26
EP2_QED0[XAD0080[89B00<0Zh5A0:b3C@2/Pdd01`2/Pdd30:j4E080[H=C0`2/PU880:Z1B`80Z7m;
0P2YP4`40:Z1C@80Ygi:102XOd/20:V0C0080:ImB@2WOTX0Z7m;0:Z1C@2[PTh0[HA@0:j5D@2_QU82
0:V0C0030:Z1C@2[PTh0[8=?0080[XEA00@0[hIB0:j4DP2^Q580[XAB0P2]Pe430:b2D0040:ImB@2X
Od/0ZX5=0:b3C`80[HA@00X0Zh9>0:Z1C@2]PUL0Zh1C0:YoDP2XOTh0Z7i<0:Z1C@2[PT`0[HA>0P2V
PDX00`2VPD`0YX5=0:J0C`020:J0D@030:J0D`2/Pdl0[8=?00H0[8=?00<0ZhIB0:V4D02WPTh00P2U
P4`00`2VPDd0Z8=?0:V4D0020:j4DP030:f3D@2/PU00Zh5?0080ZX1>00@0ZGm=0:QoB`2ZPDd0[8=?
0P2^QE400`2]Q500[8=?0:^2CP080:V0C0080:N4C02XPd`0Yh9;0:V2B`2YP4X0ZGi90:]mB@2ZO4P8
0:Z1B`030:Z1C@2YP4`0Ygi:0080YWe900<0Ygi:0:V0C02ZPDd00`2ZPDd40:V0C080Z7m;0P2XOT`3
0:UoC@<0ZX1>00H0ZGiC0:UnD@2YOU40ZGm?0:UoC@2YP4`20:V0BP<0Ygi60P2XOdL30:V0B0<0ZWe6
0`2YO4D20:QkA080ZH1<0P2ZPDd30:^2CP040:b3C`2YP4`0ZH1<0:V0C080Z7m;0`2WOTX80:J1C@80
Xgi:00@0Y7m;0:F0C02UP4`0YX5=0P2WPTh00`2WO540Z7eB0:YoE0020:^0E@070:YoE02XOE80YgaA
0:b3C`2YP4`0YWe90:=jAP020:9iA@0:0:AkA`2UO4P0Xgi90:9mB02QO4L0X7]60:5lA`2RODP0Y7m:
0:F0B`<0YGa80`2TNdL20:=jAP0609eiA@2NNDD0WgY60:9jA`2SNDL0YGU80P2XNTT0602XOd/0YWi:
0:EmB@2RODP0XGi80:60BP2RPd`0Y8E>0:=mD02RO4d0WgU:09ihA`2NNDD0WgY50:9mAP2SOTL0Y7]7
0:9iA@2PMd<0WgI209ie@@2OMT80X7M30:5hA0<0XWU50P2QN4@30:1g@`050:=iA`2RN4H0XWQ60:5g
A@2PMT@00P2OMD<01`2NM480YG]90:=iA`2PMT@0WWA209ab@02MLd400`2NM4830:1kA`<0WgY60P2N
NDD209Qc?`80VGA000X0VWE109]f@P2KMT80W7M309Qc?`2IM400VWE109]f@P2MN4@0WgY60P2PNdL0
0`2PMd<0WgI209ed@00209ac?`0309ed@02OMT80X7M300P0VgI200<0W79009id@P2OMD<00P2PMT@0
0`2OMD<0W79009]a?`0209i`?`0:09e_?P2LKSd0WFln09ma@02QLd80XWA309I_AP2GL4L0VW=:09ef
C@80WWM>00D0WGI=09aeC02HLcl0VWE109ehA00209mjAP0309iiA@2LMd<0VWE100<0VGA8:oooool0
02[ooooo00<0Rf0e08aQ=P2>HcP00P2?I3T00`2>HcP0S64f08]P=@0309=O>P<0U60k0P2EHC`2091T
=`<0Sf<f0`2>HSD0202BHCT0U6<k09IU?02HIc`0V6Pj09MW=`2FISH0U6@c202@I3L0202CJ3D0U6Pg
09IZ>@2GJc`0Uf/n09IY?`2DIch0TfHm0P2BIcd00`2BIc`0TVLj099X>002099X=P09099Y=@2AHSH0
Tf@h09IW>`2IJSh0Vfa009Y[?`2HJCd0UfPl00<0V6Tm0P2GJ3`309IW>`0409ER=`2EI3T0UfHk09QY
?@80UVXm00@0U6Tl099Y>`2AJ3X0U6Pg0P2EJCP00`2FJST0Uf/j09M[>P0209Q/>`80UVXi0P2GJcX3
09Q/>`0309U]?02EJC`0UFTl00<0UVXm0`2GJch809U]?00809a`?`2KKch0VVhm09Q/>`2GJcX0UFTh
09AX=`2CIcH209IZ>@0409Q/>`2IKC`0Vfln09a`?`80WW9100<0W74n09]`?@2JKc`00P2IKS/00`2K
L3d0WG8o09md@@0809eb?`0309ea@02LL3l0Vfln0080VFdl00<0Vfln09a`?`2MLD000P2NLd0209eb
?`80W74n0P2KL3d809ib@@80W74n00@0WG8o09ic@02PMD80XGI30P2RMd@809mf@P030:1g@`2OMT80
WGA00080W7<o00/0WGA009mf@P2PMd<0WGA009ie@@2OMT80X7M30:5hA02RNDD0XgY60:AkA`020:Ai
AP<0XgQ50`2RMd@20:=h@@80XWM00`2QMSl01`2PMCh0WgA10:1e@P2QMT<0XWM40:=hA@2UNTL00P2V
NdP00`2XODP0YW]60:=h@`020:5f@@80XWM200<0YGY50:IkAP2UNTL00P2UNTL20:AiAP<0XgQ5102S
NTH0102TNdL0YGa80:ImB@2WOTX60:EjA`80YW]80P2RND<00`2RNDD0XWQ60:9hB0020:9gBP040:9g
C02QMT40XGI10:5f@@<0X7E00P2OM3l0102PMT@0WgE309ab@02JL3h209Q^?080VFlm0`2KLCl209Y`
?P<0VFlm0`2IJcT209QZ>0<0UfTg00P0TV`m095[?02@JS/0SfTj08iX>@2=IcP0S6Hg08]U=P<0S6Hg
0`2;ICH208YT=@0608YU>`29I3X0RF@j08QS>@27HSP0QV4g0`25H3H208AO=@0308=N=022GC<0PE`b
0080P5/a0100Qedg08AJ=020ES00OE<]07aB;01mDbd0P5H`089H<P1fDbd0Me@^07UF<01jEc40NePb
07YG<@1iES00N5D_0P1kDbl01P1iDbh0MU<]07AB;01bDR/0LE4Z06mB:P`0L4l/0P1_CR/206i=:P06
06i@;01]Cb/0K4hZ06]=:@1ZC2P0JD/W0P1XBRH206e;:080K4XW00<0JdTV06Y89@1YAb@00P1YAb@0
0`1XBbT0IdXX06E89P0306=6900306A79@1UB2H0GdTT0080H4XU00<0HD/V069<9`1RC2L00P1SCBP0
0`1UAbD0ITPV06Q::00206U;:@0406Q::01VB2H0IDLU06Q9:P80IdPY00<0ITLX06E69`1UARL00P1T
ABH0101ZBBH0JdXW06]:9`1[BRL206a;:080KD`Y00<0Le0Z075>:01^BbD00P1[B2801P1^BbD0LDhX
07=@:P1^DRX0K50X06U=9@80Id/S00H0JThV06iB:P1`E2`0M54[07=@:P1`CBL206i;9@03071=9`1c
D2X0M54[00P0Le0X00<0LDhV079?9`1dDBT00P1fDb/00`1dDBT0LTlW075>9P08079E:@08075F:`1c
ER`0MED/07MD;01kE2d0OU8]081B;P22DRh207UF;080N5D[0`1gE2X00`1fDbT0NE@Z07QC:@0207MB
:00707QC:@1jEB/0OEP^07mJ<01nFBl0OEP^07]F;00207YE:`0607]F;01lEbd0OEP^07aG;@1jEB/0
NE@Z0P1gDRP00`1iE2X0NUD[07aG;@0807IC:@0607iH<@1lERl0NE</07MA:P1eCbP0MU0Y0P1gDBX2
07QA:00307MB:01eDRP0M5<X0080Le@X0P1aE2P207E?:00407I@:@1gDBX0N58[07QB:`80NE</0P1e
DRX00`1dDBT0Le0X079?9`02075>9P03071=9@1`DbT0L5<Y00H0L5<Y0P1`EBX306mD:@<0KU<X0P1c
D2P2079?9`04075>9P1`CBD0L4dU06m<9080JDdU00<0JTdU06a<9@1]BbD00P1^BbD0101`BRD0Ldl]
079>;01aCB/206m;:@03075=:`1bCR`0Ldl]0080KDdV0P1/C2D306];900306Y:8`1YCBD0JDdU00H0
JDdU0`1VBBT206E8:0<0I4LW0P1XBRH01P1WBBD0IDLS06A68P1SAB40HT@P06537`<0J4XV00d0IdTU
06E78`1RA200Gd4M05do6`1P@b40HD@R06=6901TAbD0IDPV06A79@1SAR@0HTDS0080Gd8R00@0H4<S
0654901QA2@0HTDU0P1SARH206I9:@80IDPX00l0I4LW06=69P1RABD0HTDU06A38P1UA2<0HdDS06=6
901RB2D0HTXV065;9P1RC2L0HTDS06A79@1VBBL00P1WBRP01P1VBBL0I4LU06958`1UAbD0ITPV06Q:
:0<0JT`Z00<0JD/Y06Q::01]Cbd00P1]Cbd206a>;0<0Jdd[0P1/ABH01`1]ARD0KdPW075;9`1cCBP0
MDlX07MB:01hDbT00P1aDBX2079B:`0D07=C;01dE2d0MED^07EE;P1cD2P0M54Y07IC:`1hEBd0NUL_
07aI<@1mFS80OU/c07EB:01fDbT0NE@Z07aE;01oEBd0PEL_08=G<024F34207iI;@80O5LZ00@0O5PX
07iJ:020G2P0PEdY0P1oGR/00`20GRh0P5h`081N<@02085N=004085N=P29H3@0RF0d08UP=080RV4e
0`2;HSH208QU:`0708UV;P2:Ic40S6Pd08eY=`2>JSP0SVXj08eX=00208iY=@0308mZ=P2@JcL0TF`h
0080TVdi00H0TFdi099^>P2BKSX0Tflk09A`?02ELCd209Ib?P<0VgHo1@2JMCh209Ye@@80VgI20P2L
Md<209ehA0<0WGTo0`2LN3h209]g?@80XGa70P2RODP30:=nB@040:AoBP2WPTh0Yh9>0:N2CP<0YX5=
0P2UP4`20:J1C@80Yh9>0`2XPdl0102YQ500ZhIB0:^6DP2/Qe<50:f8E0060:Z5D02[QU40ZhIA0:f8
D`2^RE@0[hYE0P2`ReH20:n:E@<0/8]F0`2aS5L90;6<F0P0/heN202`ReL0102eSf00]8iO0;B>G`2c
SEh20;:<G@80/H]L0P2_RUH0102`ReL0/HaH0;:=F@2cSUX20;B?F`040;2;E`2aS5P0/HaH0;6<F080
/XeI0P2cSUX80;F@G080^8mK00<0]hiJ0;J=F@2eS5P00P2dReL00`2cRUH0]XeI0;J=F@020;F<F080
]8]G0P2cRUH01P2cSUX0/XeI0;:=F@2aS5P0/8]G0:n:EP80[XUE202bS5l30;B;E`<0/hYF0P2bRED8
0:j9E0<0/8]G0P2aS5P30;:=F@P0/8aH202_RUH30:j9E@030:f8E02/Qe<0ZhIB0080ZhIB0P2]Q502
0:j5D@@0[hIB202bRED20:j9E@80[HQD0P2/Qe<00`2[QU80ZXEA0:Z5D@030:^6DP030:b7D`2]R5@0
[XUE0080[XUE00P0[8A60:b4A`2/Q4T0Zh9<0:^1C`2[P5<0ZWmD0:YoE@P0[XUD202]Q5080:j9E080
[XAB0P2_QE<20;26E080/HME01<0[h]G0:j:EP2]RED0[8QD0:^7D`2ZQU80ZHEA0:R4D02[QU80[8MC
0:f8E02^RED0[HQD0:^6DP2YQ500Yh9>0:QnC02ZP4h0[89@0080[XAB00<0[H=A0:b2D02[PDl00P2_
QU80102^QE40[HA@0:f4D02/Pdl20:^2CPP0[8=?0P2]Odd20:j0CP040:n1C`2`PU00/H=A0;63D@P0
[h5=202YQ5080:f3D@80/8MC0P2aR5@0102_QU80[HA@0:^2CP2YP4`30:^1D@@0[89B00<0[H=C0:b3
C`2/Pdl03`2/Pdl20:b2DP040:b2D02/Pdl0[8=?0:b3C@80[8=;202]Q5080:n6DP80ZX5=0P2[PTh0
102/Pdl0[HA@0:f4D02^QE480:f4D080[H5N00L0[H5J0:f2F02]PUD0[H=A0:f4D02]Q4h0/HQD00<0
/8MC0P2_QU820:j5D@P0[8==202^QE480:j4DPP0[H=A00<0/8ID0:n5D`2]Pe400P2[PDl00`2/PU00
[H=A0:j4DP080:j5D@P0ZH1:00H0[XYH0:j8E`2]QeH0[XIE0:j4E02]PE820:ioD@<0[8=?0P2]Q503
0:j5D@80[HA@0`2^QE430:n6DP080:j5D@2]Q500[8=?0:^2CP2ZPDd0ZH1<0:QoB`2WOTX90:f2C@03
0:QoB@2ZPD/0Zh9<0080[HA>00<0Zh9<0:Z1B`2XOdT0202[PTh00`2XOdT0ZX5;0:^2C0020:f4CP03
0:^2C02ZPD/0Z7m900P0Zh9>00P0Ygi:0:QoB`2YP4`0ZX5=0:^2CP2/Pdl0[HA@0:j5D@P0ZH1<00/0
[XEA0:b3C`2ZPDd0ZH1<0:QoB`2YP4`0ZX5=0:^2CP2XOdT0ZH1:0:b3C@020:f4CP090:b3C@2YP4X0
Z7m90:IkD02VNdh0Yga?0:QnCP2XOT`0ZH1<0080ZX5;0P2XOd/30:V0C0<0ZX5=0`2[PDl30:b2D080
[H=A0`2^QE420:f4D0<0[8=?0`2^QDl20:f4CP<0[8==00P0[XAB0:f3D@2/PU00Zh5?0:Z0CP2YOdd0
Z7i<0:MmB`80YH1;0P2VPD`40:N2C@060:f1DP2/P540[81?0:^0C@2ZOd`0ZGi90P2XODH80:^2C0P0
ZH1<0P2[PTh20:Z1C@050:V0C02XOd/0Z7m;0:QoB`2WOTX00P2/Pd/0102/Pdd0[8=?0:b3C`2/PU02
0:b2DP80Z7i>00@0Z7i<0:QoB`2XOd/0Z7m90P2XOdL20:]mB`030:UnB`2XOd/0Ygm;0080YH1;00@0
Y85;0:MnBP2WOTX0Ygi:0P2XOd/30:V0C0030:^2C02ZPD/0Z7m90080YWe700<0Ygi80:QoB@2YP4X0
202YP4`80:Z1C@80YH1<0`2VPDd30:N2CP040:V4C`2XPdh0Z8=>0:R3CP80Yh9=0P2VPD`30:=nB@80
XWe80`2QO4L01P2SOTX0Xge<0:=mC02SODh0Xge@0:=lD@80XgaC00P0Yh9>0:J1C@2TOd/0XWe90:1k
A`2NNDD0WGQ409ag@`80WWU400@0WgY50:1kAP2PNdH0XGa70P2RODP00`2PNdH0XGa70:=nB@020:=n
B@030:5lA`2NND@0WGQ300P0Y7]70P2UMdH00`2SMdH0XWQ60:5iAP0209mjAP0709ijAP2PNdH0WgY5
09iiA02MN4<0VgI109Ud?`0209Qc?P80WgE500<0X7I60:5gA`2RN4P00P2TNTX01`2UNd/0YGa80:Ak
A`2SNTH0XWU50:5hA02PMd<00`2OMT80302NM480WgE30:5gA@2RN4H0XGM509me@`2MLd40W79009Qc
?`2IM400VWE109]f@P80W7M300D0VgI209Ye@@2IM400VGA009Ye@@0209]f@P0309ag@`2MN4@0WGQ4
00<0WGQ10`2LMd0209]f?`<0UW4m0`2GLSh209Qc?`0309Ye@@2LMd<0WWU50080WgY600h0WGQ409Ye
@@2HLcl0Uf`o09Q]@02JKd80W75409icAP2PMDP0XGI90:9gBP2HLT<0VG=409]eAP80WGM800<0W7I7
09]eAP2JM4D00P2SMdX20:9fB@80XGE80P2PM4L309miBR_ooooo000Zooooo`0308aQ=P2=HSL0Sf@i
0080T6Dj00<0Sf@i08eR=`2<HCH00`2AGcX3099P>`80Tf4l0P2@I3L308mS=P<0SV8e00P0TV4i09AS
>`2FIC`0UfHk09QX>P2GIcL0UVHf09EU=0P0T6@g00P0TfPe09AX=`2FJST0Uf/l09M[?P2FJCl0U6Ln
09=V?@80TVLm00<0TVLl099W>P2BJ3P00P2BJ3H01@2BJCD0Tf@h09AU>@2FIc/0V6Tm00@0VFXn0`2H
JCd209MX?0<0UVLk00@0UV<h09ET>@2GIS/0UfPl0P2FJSd0102DJC`0TVTk095X>P2DJ3L209EY>080
UVXi0P2GJcX00`2HK3/0UVXi09IZ>@0209M[>P@0V6`k0P2EJC`309IZ?@<0Uf/n202IKC`209Y^?@04
09U]?02HK3/0Uf/j09IZ>@80UFTh0P2FJST02@2GJcX0VFdl09]_?P2LL3l0WG5009ib@@2LLCh0Vg0m
09Y_?00209U^>`0309]`?@2MLSl0WW=000P0WG8o00<0WG5009a`?`2KKch00P2JKSd00`2KKch0W70o
09ea@00209ic@080WG8o0P2LLCh209]`?@P0WW9100D0W74n09eb?`2MLSl0WW=00:1e@P020:5f@`03
0:9gA02OMT80WgI200H0WgI200<0X7M309mf@P2MM4000P2LLcl0102MM400WgI20:1g@`2NMD4209mf
@P050:1g@`2QN4@0XWU50:9iA@2SNTH00P2TNDH30:=hA@<0XWM40P2SN4420:9g@0@0XGHo00<0Y7U6
0:=hA@2SN4D00P2SN4D30:9gA080YGY500<0Y7U40:=h@`2RMd800P2SN4<00`2TND@0YGY50:AiAP07
0:AiAP<0XgY60P2TNdL00`2UO4P0YWe90:ImB@070:EjA`060:IkB02RND<0XWU30:9iA@2RN4H0XWQ8
0P2RMdX0102RMd`0XGI10:5f@@2QMT420:1e@0<0Wg@o00D0X7I409id@P2LLT00VW0n09U_?@0209Y`
?P<0Vg4o0P2JL3h309U_?@0309Q^?02IJcX0VF/j0080V6Xi0`2GJCP01`2FJ3L0TF/l091Z>`2?JCX0
SVPi08eW>02<ISL01@2;ICH208YT=@<0RF<d0P29I3X00`28HcT0Qf8h08IQ=`0208EP=P<0Q5le00<0
Pehd089M<`21G3800P20Fc40301oFS00QU`f08=I<`20ES00OE<]07aB;01mDbd0OeD_085G<@1gE2h0
N5D_07UF<080NULa00/0NEH`07MD;P1fDbd0NU8^07UA;@1hDRd0ME8/07=A:`1aDBX0L50Y06iA:@0;
071?;080Kdh[0P1^CBX01`1]C2T0KDl[06e?:`1/CRX0JddY06Y<:01YBbL00P1XBRH306a:9`80JdTV
101ZB2D00`1XBbT0IdXX06E89P0306=6900406A79@1UB2H0GdTT05m99080H4XU0P1QBbH2069<9`03
06E79@1VB2H0J4XX0080JD/Y00<0J4XX06I89P1UAbD00P1XBBX206M8:@0406I7:01UARL0IDHW06E6
9`<0JdXW0P1/BbP306e<:@0307=@:P1`CBL0KDXT0080JdPR00H0KDXT071=9`1cD2X0KU8Z06a@:01Y
CBD206Q<900506]?9`1^DRX0LED]07=@:P1bCbT0101aCRP00`1bCbT0Le0Z07=@:00807=@:00707AA
:@1eDRX0Me@/07MD;01eDRX0M54Y07=@:00807EF:P0807=F;01eEB`0MUD/07QE;@1kE2d0OU@^07mC
;P20DRh307UF;080N5D[0`1gE2X02`1iE2X0N5<Y07QC:@1gDRP0NE@Z07]F;01mF2h0OeX`07eH;P1l
Ebd0NeH/0080NUD[00H0O5L]07eH;P1nFBl0O5L]07]F;01iE2X207QC:@0307UD:P1kER`0O5L]00P0
Me@Z00@0OEL`07aF;`1iDb`0Me4Z0P1fD2T01`1gDBX0N58[07QA:01hDBP0Me8X07EB:01dDbP00P1c
E2P2075D:00407I@:@1gDBX0Me4Z07MA:P@0N58[0`1dDBT307=@:080LTlW201bDRT3071E:P80Ke@Y
0`1^DbP307=@:003079?9`1aCRH0LDhV0080L4dU0P1[CbL00`1/CbL0KThW06m=9`02071=9`04079<
9`1cCbd0LTh/075=:`80L4`Z00<0LDd[079>;01cCbd00`1]CBH206a<9@<0Jd/T201YCBD0101WBRX0
ITTY06I9:@1VBBT206E8:080I4LW0P1WBBD0101VB2@0IDLS06E78`1TAR8206=58@80IdTU00T0J4XV
06M99@1VB2@0I4HR06537`1O@Ad0Gd8P06138@1RAB<00`1TAbD206958`<0H4<S00<0HD@T06959@1R
ABD00P1SARH206E8:00406A79`1SARH0HdHV06959@80HD@T0P1XAbH02@1UAbD0I4LU0657901OAb<0
GTPS05e78P1SAR@0I4LU06E89P0206I99`0606E89P1TAbD0HdHT06E79@1VB2H0J4XX0`1ZC2X00`1Y
BbT0J4XX06]=:`0206]=:`D0K4h/0P1ZARH01`1[AbD0KDTW06m;9`1aCRP0Le0X07AA9`1eDRP0101b
DR/307=C;00?07AD;@1dDBT0ME8Z07IC:`1gE2`0NEH^07YG;`1kF300O5Ta07ED:@1gE2X0N5D[07]F
;01nEbh0PEL_0080Q5Pa00P0OeX`07iI;@1mF2`0OEP[07eI:@1oFbT0P5`X089N:P80Oeh[00<0Oed]
081N<020GS400P21GS@01021GSH0RF0d08UP=029H3@208YQ=@<0Rf8f00H0R6D[08QU;@29IRh0RVLa
08]W<`2<J3H208eY>@80SFPd00<0SVTe08mZ=P2@JcL00P2AK3P01P2BKCT0TFdi095]>@2BKSX0Tflk
09A`?080UG4m00<0UW8n09Ud?@2IM3d0102IM3d209Qc?080VGA00P2JMD4409]f@PP0W7Pn0`2QO4L2
0:9mB0<0Xgi92P2VPDd20:N2CP@0Z8=?0P2/Qe<20:^6DP050:b7D`2]R5@0[XUE0:j9E@2[QU400P2/
Qe801@2]R5<0[hYE0;2;EP2`ReH0/HaG0080[hYE0`2`ReH30;6<E`T0/HaH202cSEh80;2;E`80]8iO
0P2cSEh20;:<G@80/H]L0P2_RUH0102`ReL0/HaH0;:=F@2cSUX20;B?F`@0/HaH0P2bSET20;>>FPP0
]I1L0P2hSe/00`2gSUX0]XeI0;F<F0020;B;E`030;>:EP2fSET0]XeI0080]HaH0P2dReL20;>:EP@0
/HaH102`ReL80;:<G@<0]8]G0`2cRUH20;:9E@P0[XUD0`2_RUH20;2;E`<0/HaH202`ReL80:n:EP<0
[XUE00<0[HQD0:b7D`2/Qe<00P2[QU820:f4D080[XEA0`2_QU800`2`Qe<0/XUE0;:9E@060;:9E@04
0:n:EP2^RED0[XUE0:j9E@80[HQD0P2/Qe<30:^6DP80[8MC0P2]R5@20:j9E@080:j6B@2]QDX0[HA<
0:f4CP2/PU00[89B0:^0D`2[P5D80:j9E0P0[HA@202^RE@20:j4DP80[hEC0P2`QU@20;67E@80[hYF
00@0[XUE0:f8E02/Qe<0ZhIB0P2ZQE400`2[QU80[8MC0:f8E0020:f8E0060:^6DP2YQ500Z8=?0:Uo
C@2ZP4h0[89@0P2^Q580102]Pe40[89@0:^1C`2_QU820:j5D@80[HA@0P2/Pdl00`2[PTh0[8=?0:b3
C`060:b3C`<0[X1>0P2_PDl30;22D0P0[h5=202YQ5080:f3D@080:j5D@2_QU80/8MC0;27D`2_QU80
[XEA0:^2CP2ZPDd20:Z0D080Zh5A00@0[89B0:f3D`2]Pe<0[XAD4@2/Pdl20:b2DP040:b2D02/Pdl0
[8=?0:b3C@80[8=;202]Q5080:n6DP80ZX5=0P2[PTh00`2/Pdl0[HA@0:f4D0090:f4D080[H5L00@0
[H5J0:f2E`2]PUD0[H=A0P2]Q5040;27D`80[hIB0P2^QE480:b3C@P0[XEA202^Q5880:f3D@030;26
E02_QE<0[H=A00<0Zh5?00<0[89@0:f3D@2^QE401`2^QE480:Z1B`060:b8EP2]QeH0[8IE0:f5E02^
Q5@0[X9C0P2_P5830:b3C`80[HA@0`2^QE430:f4D080[XEA0`2_QU830:Z1C@@0Zh9>00<0[8=?0:f2
C@2]PTd01`2]PTd00`2YP4X0ZX5;0:^2C0020:b3C@030:^2C02ZPD/0ZH1:00P0Zh9>00<0ZH1:0:Z1
B`2[PT`00P2/Pdd00`2[PT`0ZX5;0:V0BP080:^2CP80Z7m;00@0ZH1<0:Z1C@2[PTh0[8=?0P2]Q508
0:Z1C@0;0:j5D@2/Pdl0ZX5=0:V0C02XOd/0ZH1<0:Z1C@2[PTh0ZH1:0:Z1B`2[PT`00P2/Pdd02@2[
PT`0ZX5;0:V0BP2WO540Yga?0:QmD02XOTh0Z7i<0:V0C0020:V0BP80Z7m;0`2YP4`30:Z1C@<0Zh5?
0`2/PU020:f3D@<0[XEA0P2]Q5030:b3C`80[XE?0`2]Q4h30:b3C@80[H=A00@0[89@0:^1C`2ZP4h0
ZGm=0P2XOT`20:F0B`80YX5<0`2WPTd01`2XPdh0[89B0:b2DP2[PDl0ZX5=0:V0C02XOdT00P2WOTH8
0:^2C0P0ZH1<0P2[PTh20:Z1C@030:V0C02XOd/0Z7m;0080Z7m;0P2/Pd/0102/Pdd0[8=?0:b3C`2/
PU020:b2DP80Z7i>00@0Z7i<0:QoB`2XOd/0Z7m90P2XOdL20:]mB`030:UnB`2XOd/0Ygm;0080YH1;
00@0Y85;0:MnBP2WOTX0Ygi:0P2XOd/30:V0C0040:b3C@2[PT`0ZH1:0:MnB080YWe700<0Ygi80:Qo
B@2YP4`03`2YP4`20:F0C0<0YX5=0`2WPTh40:R3CP80Yh9=0P2VPD`30:AoBP80Xgi90`2RODP20:=n
BP030:=mC02SODh0Xge@0080XgaA00X0XgaC0:F0C02TOd/0Xgi:0:9mB@2PNdL0WgY609iiA@2MN4@0
WWU40P2ONTD20:1kAP80XGa700T0XWe80:5lA`2RODP0Xgi90:AoBP2SOTT0XGa709mjA@2NND@0202S
NTH20:EgAP030:=gAP2RN4H0XGU60080WgY600D0WWY60:1kAP2ONTD0WWU409eh@`0209ag@P0:09]f
@@2JMD00WgE509meA@2PMTH0XGM70:9hB02SNDT0Y7Y:0:EkB`80Y7]700@0XgY60:9iA@2QN4@0X7M3
0`2OMT800`2NM480WgE30:5gA@020:5gA@0309me@`2MLd40W79000D0VGA000<0VWE109]f@P2KMT80
0`2JMD400`2KMT80W7M309ag@`0209ehA0<0WGQ10`2LMd0209]f?`P0V7<o00<0W7M309ehA02MN4@0
0P2MN4@03P2LMd<0VWE109Ye@@2IKT40VVm209]`@`2LLD@0WW=609mdA`2PMDP0XGI909Qb@`2ILd@0
VgE60P2MMdP00`2LMTL0VgE609YdA@020:9gBP80XGI90P2PMDP209mdA`<0WWQ9:oooool002[ooooo
00<0SV<h08mT>@2@ICX00`2@ICX00`2?I3T0SV<h095O>P02095O>P<0TV0k0P2CHC`2091T=`<0Sf<f
0`2>HSD0202CHSX0U6<k09ET>`2GIS/0UfLi09MW=`2FISH0UFDd202AICP0202CJ3D0U6Pg09EY>02F
JS/0UVXm09EX?P2DIch0TfHm0P2BIcd00`2BIc`0TVLj099X>002099X=P03099Y=@2DJ3/0U6Pk0080
TfLj00@0U6Pk09IZ?@2GJch0VFe00`2FJSd209EY?0<0U6Pk00@0UV<h09ET>@2GIS/0UfPl0P2EJC`0
0`2DJC`0TVTk099Y>`0409EY>080UVXi0P2GJcX309IZ>@80Uf/j0`2HK3/209EY?0<0UVXm0`2GJch<
09Q/>`@0Uf/j0P2FJST0202GJcX0VFdl09Y^?@2KKch0W70o09ea@02KL3d0VVll0P2IKS/00`2JKc`0
Vg0m09aa?P0909eb?`0309ib@@2MLD00Vfln0080VVhm00<0Vfln09ea@02NLT400P2NLd0209eb?`80
W74n0P2KL3d809ib@@80WG8o00@0WW=009md@@2OM440X7E20P2QMT<809mf@P030:1g@`2OMT80WWE1
0080WGA000<0WWE109mf@P2PMd<0102PMd<40:5hA080Y7U60`2SN4D30:9gA0<0XgQ30P2RMd830:5f
@@060:MlB@2VNdP0YGY70:AiAP2RMd@0X7E20P2OM4400`2RMd80XgQ30:AiA0020:EjA@80Y7U400<0
XgQ30:9g@P2RMd@00P2SN4D01@2TNDH0YGY70:IkB02VNdP0Yga90080XgY600<0Y7]70:ElB02UO4P0
0`2UO4P00`2TNDH0YGY70:EjA`030:EjA`80Y7U60P2RND<00`2RNDD0XWQ60:9hB0020:9gBP030:9g
C02QMT<0XGI30080X7E20`2OM440102NLd00WWA209ec@@2LLT0309]a?`0409ec@@2NM480VW0n09Y`
?P80VFlm0`2HKS`00`2GKC/0UVXi09IZ>@0209EY>0<0U6Pg00D0TfLf08mY>P2?JCX0SVPi08eW>002
08aV=`80RfDf0P29Hc@208QR<`<0Qf4b00H0QV0a08QS>@28HcT0Qf8h08IQ=`25H3H208AO=@0708=N
=024GcD0Pehd08=N=022GC<0PE`b081K<@0207mJ<00408=L=@20FC80OEH_07]D;@80NU</00@0O5D^
07iG<01hEBl0NEH`0P1jEc40301iES00Me@^07EB;01dDB/0N50/07M?:`1fD2/0Le0Z075?:@1_CbP0
KThW06a?9`P0Kdh[00@0L4l/06m>:`1_CR/0KTdZ101]C2T206a>:P80JddY00@0JT`X06U;9`1XBRH0
J4XV101YB2D406Y99P0406]:9`1XBbT0IdXX06E89P<0HdHT00@0I4LU06E89P1OAb<0GdLS0P1PB2@4
06599@80ITPV101XBRP206I89P80J4XX0`1WBBL306I89P0406]:9`1/BbP0K4/X06a;:080KD`Y0P1^
CBX00`1aCRP0L4dW06e:900206]88P0;06e:901`CBL0LDhX071C:`1^DBT0K4lW06Y=9@1[CRH0KE0X
071C:`1bEBd00P1bCbT0101cD2X0M54[07AA:`1cD2X2079?:@P0M54Y0P1fDb/0101gE2`0N5D]07QE
;@1gE2`207IC:`P0MEHZ00@0MED/07MF;@1hEBd0N5D]0P1lEBh0101oEBl0P5@_07YG;@1jEbd207UF
;0<0N5D[00<0Me@Z07YE:`1iE2X00P1iE2X01P1jEB/0NeH/07eH;P1nFBl0O5L]07]F;080NUD[00L0
NeH/07aG;@1nFBl0P5/a07aG;@1kER`0NUD[0080NE@Z00<0NUD[07]F;01lEbd0201gE2X0101lERl0
NeD^07YD;@1hDR/307MA:P0607QB:`1iDRT0NE8Y07QC:@1fDbT0ME@Y0P1dEBT2079E:@<0NE</0`1h
DR/207MA:P80Le0X0`1dDBT307EB:PP0Le<Z00@0LUD[075D:P1aE2X0LE@Z0P1`DbT206mB:0@0Le0X
0P1bCbL2075>9P80KE4Y00<0KU4Y071@:@1aCbT00P1bCbT0101dCRT0M50^07=?;@1aCB/2071<:P03
075=:`1cCbd0M50^0080KThW0P1]CBH306a<9@0306];901ZCBD0JTdU00H0JTdU00@0JD/Y06Q::01X
BRP0J4XX0P1WBBL206I89PD0ITPT101UAb<02P1VB2@0IdTU06Q:9P1WBBD0ITPT06A68P1RA200GT4O
06138@1QA28306=6900306958`1QA280H4<S00<0HD@T0`1RABD01`1SARH0I4LW06A79`1SARH0HTDU
0654901P@b<00P1O@R801P1[BRT0JTTX06M99`1TAbD0H4HS05e58@80FT@O00<0HdHT06A79@1UB2H0
0`1UB2H02P1TAbD0HdHT06E79@1VB2H0J4XX06U;:@1ZC2X0JD/Y06Q::01WBBL206U;:@80JT`Z00@0
Jdd[06a>;01]Cbd0KDl]0P1[AbL01`1[AbD0KDTW06i:9P1`CBL0LTlW07=@9P1dDBL00P1cDb`3079B
:`<0LE4Z0`1fDb/207MD;0<0N5D]00H0MUDZ07MF:`1iER`0O5L]07iI;`20FC0208=I<@0@081J<`1o
FS00OUT_07eH;01nFB`0Oe/[085M:`22GR`0OUdZ07mN:`1oGBd0Oed_081N<@20GC<0PEhd085N=P<0
QV0c0P27HC@308QR=@80R6D]00L0RFH`08UU<@2:IS@0RfLg08aX>02<IcX0S6Lc0080SFPd00<0SVTe
08mZ=P2@JcL00P2AK3P01P2@K3P0TFdi095]>@2BKSX0Tflk09A`?080UG4m00<0UW4l09Mb?@2GLSd0
1@2GLSd209Mb?P80V7<o0`2IM4001@2JMD40VG@m09Ud?@2JMCh0VgHo0080W7M00P2MN4420:1kAP80
XGa70`2RODP01@2SOTT0Xgi:0:=nBP2TOd/0YH1<0080YX5=0P2WPTh30:J1C@80Yh9>0`2XPdl0202]
R5@0[8MC0:Z5D@2YQ500ZXEA0:b7D`2^RED0/8]G0P2]R5<0102^RE@0[hYE0;2;EP2`ReH20;6<E`80
[hYE0`2`ReH30;6<E`T0/HaH202cSEh80;2;E`<0/heN0`2bS5d20;6;G080[hYF00@0/8]G0;6<F02b
SET0/hiJ0P2dSe/30;6<F080/XeI0`2cSUX80;F@G080^8mK00<0]hiJ0;J=F@2eS5P00P2dReL00`2c
RUH0]XeI0;J=F@020;F<F080]8]G0P2cRUH30;2;E`<0/HaH0P2bSET80;:<G@<0]8]G0`2cRUH20;:9
E@P0[XUD0`2^RED20:n:EP<0/8]G202^RED80:n:EP<0[XUE0P2]R5@30:b7D`<0[XEA0P2_QU830;27
D`P0/HQD00<0/8]G0:n:EP2_RUH00P2_RUH30:j9E@030:f8E02[QU80[8MC0080[8MC0`2]R5@00`2^
RED0/8Q=0:n6CP020:n6D080[XAB00<0[H=C0:f2E@2]R5<01`2]R5<80:j5D@P0[HQC0P2^Q5820:n5
D`80/8ID0P2aQeD01@2_RUH0[XUE0:j9E@2]R5@0[8MC0080ZhIB00d0ZXEA0:^6DP2/Qe<0[8MC0:f8
E02/Qe<0ZhIB0:Z5D@2YQ500ZX1>0:^1C`2/PU00[H=A0080[XAB00<0[H=A0:b2D02^QE400P2^QE42
0:f4D0/0[8=?102^Pe030:f2C`030:b1CP2]PTl0[H9?00H0[H9?202YQ5080:f3D@0>0:b3C`2]Q500
[hIB0;27D`2_QU80[XEA0:f4D02/Pdl0Z7i<0:UoC@2ZP4h0Zh5?0:b2D02^Q5820:n5Da40[8=?0P2/
PU80102/PU00[8=?0:b3C`2/Pdd20:b3B`P0[HA@202_QU830:^2CP<0[8=?2P2]Q5020:f2F0030:f2
E`2]PUD0[H=C0080[H=A00@0[HA@0;27D`2`Qe<0/8MC0P2_QU830:j5D@P0[8=?202^QE480:j4DPP0
[H=A00P0[hEC0:j4DP2/PU00Zh5?0:Z0CP2[PDl0[89@0:f3D@P0[XEA202ZPD/01P2ZQU80ZhIB0:^6
DP2]QE80[XAB0:n3DP80/89A0`2/Pdl20:f4D0<0[XEA00@0[8=?0:f4D02]Q500[HA@0P2^QE420:n6
DP060:MnBP2XOd/0ZH1<0:Z1C@2/Pdl0[HA@0P2_QU890:f2C@030:V0BP2ZPD/0Zh9<0080[8==00<0
Zh9<0:Z1B`2YP4X0202[PTh00`2YP4X0ZX5;0:^2C0020:b3C@030:^2C02ZPD/0ZH1:00P0Zh9>00D0
Z7m;0:V0C02YP4`0ZX5=0:^2CP020:b3C`030:f4D02/Pdl0[8=?00H0[8=?00/0[XEA0:b3C`2ZPDd0
ZH1<0:QoB`2YP4`0ZX5=0:^2CP2/Pdd0Zh9<0:Z1B`020:V0BP040:Z1B`2[PT`0[8==0:YoE080ZGiA
00<0ZGm?0:QnC02XOd/00P2XOdT20:QoB`<0ZH1<0`2ZPDd30:^1C`<0[89@0P2]Pe430:j5D@80[HA@
0`2/Pdl0102^QDl0[HA>0:f4CP2]Q4h20:b3C@80Zh9<00D0[H=A0:b2D02/PU00Zh5?0:Z0CP020:Uo
C@040:QnC02VPD`0YX5<0:J1C080Yh9=0`2XPdh20:b2DP060:^1C`2ZPDd0ZH1<0:QoB@2XOdL0Ygi6
202[PT`;0:Z1C@@0ZH1<0P2XOd/20:^2BP040:^2C02[PTh0Zh9>0:^1C`80Zh5A0P2YOdl0102YOdd0
ZH1<0:V0C02YP4X20:V0B080[7i<00<0ZWm<0:V0C02XP4`00P2VPD`0102UPT`0Ygi:0:MnBP2WOTX2
0:QoB`<0ZH1<00@0[XEA0:b3C`2ZPDd0Ygi:0P2VODT20:MnBPP0ZH1<202WOTX20:F0C0<0YX5=0`2W
PTh30:R3CP80Yh9=1@2VPD`20:F0B`80Y7m:0`2SOTT20:=nBP030:=mC02SODh0Xge@0080XgaA00D0
Xgi:0:9mB@2RODT0XWe90:5lB0030:1kA`<0WgY50P2PNdH30:5lA`80Xgi90`2TOdX00`2SOTT0XGa7
0:1kAP080:9iA@80YGM600<0XgM60:9hAP2QNDH00P2ONTH00`2NNTH0WgY509mjA@0609mjA@0609me
@`2PMT@0X7I40:5gA@2RN4H0XgU70P2TNTP20:=jAP80XWU500<0XGQ40:1g@`2OMT800P2OMT8209me
@`<0X7I400`0WgE309ec@@2LLT00VWE109Ud@02FLCd0UG0l09Ia?@2HLcl0VgI209ehA02JMD4309]f
@P<0W7M300@0WGQ409eh@`2MN4<0WGQ30`2LMd8209]f@@80W7M300@0VgI209Ye@@2IM400VGA00P2H
Lcl0102NNDD0WGQ409ag@`2KMT8209Ye@@0309]f@P2LMd<0Vg1300<0W75400L0WG9509icAP2NLdH0
WW=609Qb@`2ILd@0VgE60080WGM800<0W7I709]eAP2JM4D00P2RMdX20:5fB@80X7E80P2OM4L309af
Ab_ooooo000Zooooo`0308mT>@2@ICX0T6Dj00@0T6Dj00@0Sf@i091P>P2@H3X0T60j0`2AHC/2099R
?080T6@g0`2?HcH308iR=@80U6<k00<0UF@k09IU>P2FISP00P2FISH00`2FISD0TFDh095U>006095U
>00609AY=P2DJ3L0U6Pg09AX>@2DJ3/0U6Lm0P2DIch209=X?P0309=X?@2CJ3/0TfTi0080TfTg00@0
TfXf09EZ?@2DJC`0TVLj0P2AIST00`2DJC`0Uf`o09U^@@0309EZ?@80U6Tl0`2CJ3/0102GI3T0UVDj
09IU>P2FIc/209AX>`0309AY?02CJS`0TfXl00H0UFTh0P2FJST209EY>080UVXi0P2GJcX209Q/>`80
UFTl0`2FJSd309M[?PP0V6`k0`2FJST00`2GJcX0V6`k09U]?00209U]?00509IZ>@2GJcX0Uf/j09Q/
>`2JKSd00P2KKch0102LL3l0VFhk09U^>`2IKS/209Y_?080Vg0m00<0W74n09eb?`2MLSl01P2MLSl0
0`2NLT40WG5009a`?`0209Y^?@0309a`?`2MLD00WW910080WW=00P2MLSl209aa?P80Vg0m202NLT40
0`2MLSl0WW=009ic@00209md@@80X7E200<0XGI309mf@P2OMT801P2OMT800`2QN4@0X7M309ie@@02
09ed@00409ie@@2PMd<0XGQ40:9iA@<0XGQ40`2PMd<00`2OMT80Y7U60:AiAP030:=hA@<0XWM40P2T
NDH20:=hA@80XWM40P2QMT<20:EjA`030:AiAP2SN4D0XWM40080XGI300@0X7E209md?`2QMT40Y7U4
0P2VNdH20:EjA@080:9g@P2QMT40XWM40:9gA02SN4D0Y7U60:IkB02WO4T20:QmBP80XgY600H0YGa8
0:ImB@2VODT0YGa80:AkA`2SNTH20:AiAP060:EjA`2VNdP0YGY70:AiAP2SN4D0XWM40P2RND<00`2R
NDD0XWQ60:9hB0020:9gBP040:9gC02PM4<0X7A30:1d@`<0Wg=20P2NLT400`2MLd40W79009]a?`02
09]a?`0309ab@02NM480WgE300<0V6hl0`2GKC/209I/>P<0TfTi0`2BJ3P2095W=`80SFLh0P2<ISL2
08]U=P80RV@e0P27HC8208IP<@<0QEl`00L0Q5h_08MR>026HCL0QV4g08EP=P24GcD0Pehd0080PUdc
00H0Pehd089M<`22GC<0PE`b081K<@1oFS0207iI;`09081J<`1nF340O5H_07UC;01hDR/0NE</07YD
;@1kEBh0N5D_00<0NEH`00@0N5D_07EB;01cD2X0LDhX0P1fCRX01P1dCRT0LDhX06m=9`1^CRL0KDdV
06]>9PP0KTdZ00<0L4l/06m>:`1]C2T00`1/BbP206e<:@<0JddY00<0JT`X06U;9`1YBbL00P1XBRH2
06E78`0306I8901WBBD0J4XV00<0JD/W00@0JT`X06Q;:@1WBRP0IDPV0`1SAR@00`1TAbD0IDPV0616
8`0206168`D0HDLT201WBBL606Q:9P80IdTU00@0K4/X06e<:@1]C2T0KD`Y0P1^CBX206m>:`03075>
:01`CBL0KT/U0080K4TS00D0KT/U071=9`1aCRP0LU8[075A:P0306m?:006075A:P1cDb`0M5@]075>
:01cD2X0MU<]0P1gE2h00`1fDbd0Le0Z075>:00807IC:`0307QE;@1iERh0NEH^00@0NEH^00<0N5D]
07MF:`1gER/01P1gER/01P1hEBd0NEH^07UF;P1kEBh0O5H_07eF;`80OUL`0P1kF2h207YG;@<0NEH/
00@0N5D[07YE:`1jEB/0NUD[0P1kER`00`1lEbd0OEP^07iI;`0207]F;080NUD[00@0NeH/07eH;P1o
FS00P5/a0P1lEbd407]F;080O5L]201hEB/207]E;P0307YD;@1iDb`0N58[00<0N58[0P1jDbX00`1i
E2X0Me@Z07IE:P0207EF:P80LeHZ0P1kEBh0101jE2d0NE</07UC;01hDR/207MA:P0507=@:01dDBT0
M54Y07EB:P1fDb/00P1gE2`00`1hEBd0ME@[07ED:`0607ED:`80M5@[0`1cDbX3079B:@<0M54Y1@1c
D2P206mC:`03071C:`1bDR/0Le4[0080M54[00@0MU0[07A@;P1cCbd0LTh/0P1`C2X00`1bCR`0Ldl]
07A@;P0206m?:080KThW0`1]CBH00`1/C2D0KDdV06e=9P0606e=9P80K4/X0`1[BRL306Y99P0406E7
8`1VB2@0ITPT06I890<0IdTU00@0J4XV06A68P1UAb<0IdTU0`1XBRH01@1VB2@0IDLS05i17`1O@R00
HD@R00<0HdHT00<0HTDS06548P1RABD01`1RABD206=69P0406959@1QA2@0H4<S05m28P80GT4Q00T0
JDPW06Q79P1UAbD0HdHT06168`1NAR80G4HQ05]5801SAR@01P1TAbD0101SAR@0IDLU06I89P1XBRP2
06U;:@0306Q::01WBBL0ITPV0080IdTW00@0J4XX06U;:@1[CB/0K4h/0P1]Cbd206Y79`0706]99P1/
BRL0KD/V06m=9`1`CbH0LE0U079A9P0207=C;004079B:`1aDBX0LE4Z071@:@80KdlX1@1fDb/307EB
:P0@07IG:`1gF2`0N5L/07YG;@1nFBl0OeX`081I<023FC40P5Xc07mI<P1nFBl0OEP^07iI;@1oFRd0
PEd]08=O;`80OUdZ00<0Oed]07mM;`1oGC000P20GC<00`20GCD0Q5lb08AO<P0308EP<`<0QV4d00D0
Qf@^08QU;`28I300RFDc08UU=@0208YU>00708]V>P2;IS80S6Lc08aW<`2=J3@0SVTe08mZ=P02091[
=`0608m[=`2@K3P0T6`h095]>@2BKSX0Tflk0P2DL3`309A_>`@0UG0l102FLCd209Mb?P<0V7<o0P2G
LSd01P2HLch0VWE009]f@@2LMd80WGQ309iiA080WgY50P2PNdH30:5lA`090:9mB02QO4P0XGa80:9m
B@2TOd/0YH1<0:J1C@2WPTh0Z8=?0080YH1<0P2VPDd20:N2CP80Z8=?00<0[XUE0:b7D`2YQ5000P2X
Pdl00`2[QU80[XUE0;2;E`020:j9E080[hYE00@0/8]F0;6<E`2aS5L0/HaG0P2_RUD30;2;EP<0/HaG
2@2aS5P80;>=GPP0/8]G1P2bS5d20;6;G080[hYF00@0/8]G0;6<F02bSET0/hiJ0P2dSe/20;6<F080
/XeI0P2cSUX:0;B?F`80^8mK00<0]hiJ0;J=F@2eS5P00P2dReL00`2cRUH0]XeI0;J=F@020;F<F080
]8]G0P2cRUH20:n:EP030;2;E`2aS5P0/XeI0080/hiJ00<0]8mK0;:<F`2bS5/01P2bS5/30;B;E`<0
/hYF0P2bRED80:n:E@80[HQD0`2^RED30:n:EPP0[hMD202_RUH40:j9E@@0[HQD0P2^QE430:n6DP<0
/8MC202aR5@50;2;E`@0[hYF102/Qe<40:f8E0<0/HQB0P2`Qe<30:n5D`P0[HQC202^QE480:f8D`80
[XAB0P2_QE<20;26E080/HME0P2`R5D20:n7E080[XIC0P2]QE820:^6DP<0[8MC0P2[QU80102ZQE40
Zh5?0:b2D02/PU020:f3D@<0[XAB202]Q5080:b3C`80[hIB00<0[XEA0:f4D02/Pdl00P2[PTh00`2Z
PDd0[H=A0:f3D@060:f3D@P0ZXEA202]Pe400`2ZPDd0[8=?0:f4D0030:n6DP0:0:f4D02/Pdl0Z7m;
0:QoB`2ZPDd0Zh9>0:f4D02^QE40[hIB0;27D`P0[HA@2@2/Pdl20:b2DP040:b2D02/Pdl0[8=?0:b3
C@80[8=;202]Q5080:n6DP80Zh9>1P2/Pdl80:f4D080[H9E0`2]Pe<30:f3D@80/8MC0P2_QU820:j5
D@80[HA@202/PU080:f4D0P0[XAB202]Pe400`2_QE<0[XAB0:b2D0020:Z0CP030:^1C`2/PU00[H=A
00P0[XEA202[PT`01P2XQDl0ZHA?0:Z5D02/Q500[HA@0:n4D@80/H=A0`2/Pdl20:f4D0<0[XEA0P2/
Pdl30:f4D0<0[XEA00D0ZH1<0:Z1C@2ZPDd0Zh9>0:b3C`020:f4D0030:j5D@2]PTd0[H9=00L0[H9=
0P2ZPD/40:^2C080ZX5;202[PTh20:Z1B`@0Zh9<0P2ZPD/80:^2CP80ZH1<0P2ZPDd20:^2CP80[8=?
202]Q5002`2^QE40[8=?0:Z1C@2YP4`0Z7m;0:V0C02ZPDd0Zh9>0:f4CP2/Pdd0ZH1:0080Z7m900T0
ZH1:0:b3C@2]Q4h0Zh1E0:^0D`2ZOe80ZGm?0:UoC@2XOd/00P2WOTP20:QoB`<0ZH1<0`2ZPDd30:^1
C`<0[89@0P2]Pe430:j5D@80[HA@0`2/Pdl30:f4CP80[8==0`2[PT`20:b2D080Zh5?0P2ZP4h20:Uo
C@80YX5<0`2WPTd30:R3CP060:b4D`2[Pe80Zh=@0:Z2CP2YPDd0Z85:0P2WP4L80:^2C0X0ZX5=1`2Y
P4`20:^2BP040:^2C02[PTh0Zh9>0:^1C`80Zh5A0P2YOdl0102YOdd0ZH1<0:V0C02YP4X20:V0B080
[7i<00<0ZWm<0:V0C02XP4`00P2VPD`0102UPT`0Ygi:0:MnBP2WOTX20:QoB`<0ZH1<00@0[hEC0:f3
D@2ZP4h0Z7i<0`2VO4X00`2WOD/0ZH1<0:V0C0060:V0C0P0YWe90P2UP4`30:J1C@<0Yh9>0P2XPdh2
0:N2C@80YX5<0P2UP4/20:N2C@80YX5<0`2UP4/01`2TOdX0Xgi70:=nB@2SOTT0Xgi:0:=mC02SODh0
0P2SOE050:5lB0<0XWe9202PNdH20:=nB@<0Y7m:0P2SOTT00`2RODP0XGQ40:5hA0060:5hA080YGM6
00<0XgM60:9hAP2QNDH00P2ONTH01@2NNTH0WWU409mjA@2ONTD0X7]60080XGa70P2RODP20:1g@`80
XGQ400@0XWU50:=jAP2SNTH0XgY60`2RNDD00`2QN4@0X7M30:1g@`0309mf@P@0WgE30P2NM48209ec
@@0309]f@P2IM400UG0l0080Tfhj00<0UW4m09]f@P2NNDD0202LMd<309ehA0<0W7M30P2KMT801P2O
NTH0WWU509ehA02LMd<0VgI209Ud@080V7<o00P0WgY609iiA@2KMT80VGA009Qc?`2IM400VgI209eh
A0D0WG950`2LLD@00`2HLT<0VG=409]eAP0209egB00309afA`2KMDH0VWA50080XGQ:0P2PMdT209mf
B080WWE70`2KMDH[ooooo`00:_ooool00`2@ICX0Sf@i08mT>@0408mT>@04091U>P2>HCX0SV4j08iQ
>P<0Sf8k0P2@Hc`2091T=`<0Sf<f0`2>HSD209ET?00609ET>`2EI3T0UFDg09IV=P2GIcL0UfLf202B
IST01P2DJCH0U6Pg09=W=P2CIcP0TfLj09=V?080U6Ln0P2CJ3h00`2CJ3d0TfPk09=Y>@0209=Y=`04
09=Z=P2EK3h0U6/m095X>P80T6Li00<0TVTk09E/?P2GKT000`2DJcd209=Z?0<0TVTk00@0V6Dj09IU
>P2FICX0UFHj0P2DJ3/00`2CJ3/0TfXl09=Z?00609EY>080U6Pg0`2EJCP209IZ>@<0Uf/j0P2EJC`3
09IZ?@<0Uf/n202GJcX209EY>00409IZ>@2GJcX0V6`k09U]?080VVhm00D0UVXi09M[>P2GJcX0V6`k
09U]?00209Y^?@0409]_?P2HKCX0VFhk09U^>`80VVll0`2KL3d809eb?`0309mc@P2MLD00W70o0080
Vfln00<0W70o09ea@02OLd800P2NLd0209eb?`80W74n0P2KL3d809ib@@80WW=0102OM4420:1e@PP0
WgI200<0XGQ40:1g@`2OMT800P2NMD40102OMT80X7M30:5hA02RNDD30:5hA0<0X7M300<0WgI20:Ai
AP2TNDH00`2SN4D30:9gA0<0Y7U60P2SN4D30:9gA0060:1e@P2QMT<0XGI30:9gA02SN4D0Y7U60P2U
NTL01@2NLch0X7E00:=h@`2UNTD0YW]60080YGY501@0XgQ30:5f@@2RMd@0XgQ50:AiAP2UNTL0YW]8
0:MlB@2XODX0ZGi;0:9iA@2TNdL0YGa80:MnBP2VODT0YGa80:=jAP2RNDD0XgQ50:AiAP<0YW]800<0
Y7U60:5f@`2PMD800P2RND<00`2RNDD0XWQ60:9hB0020:9gBP030:9gC02PM4D0X7A500<0Wg=40`2N
LT<00`2LLT00Vg4o09Y`?P0209Y`?P0309]a?`2MLd40WWA20080Ufdk0`2FK3X309E[>@80TFPj0`2@
IcT308mV>080RfDf102:I3D208US=080QV0a0P25Gc0408AN;`80QF0f00<0Q5le08=N=022GC<00P21
G3801`20Fc40PUdc085L<P21G380P5/a07mJ<01nFBl00P1mF2h0101nF340OEL`07]E;P1iDb`207QB
:`80NE</00P0Me@^07QE;`1hEBl0N5D_07MD;P1eDR`0LTlY075>:080MThZ00H0M4hY075>:01_CBL0
KDdV06a<9@1ZCBD806i=:P03071?;01^CBX0K4/X0080JTTV00<0JdXW06a;:01]C2T00`1ZC2P406U;
9`0706Q:9P1SAb80I4PS06A88`1UBB@0ITXU06M;9P0306Q<9`0306Q;:@1WBRP0IDPV00<0HdHT00@0
I4LU06E89P1TAbD0I4LU1P1SAR@806M99`<0J4XT1@1YBbD206e<:@80KTdZ0`1_CR/0101`Cb`0LTlY
075>:01`CBL206m<9P05071=9`1aCRP0LTlY07AB;01cDB/00`1bD2X01P1dDR`0ME<]07ID;P1cD2X0
M54[07MD;P80NEH`00<0Me@^07AA:`1cD2X0201gE2`307YG;`80NEH^0`1jEbl807UF;080O5D^00<0
OEH_07aF;`1mEc000P1kF3000`1lFC40O5T_07]H;P0207]H;P80NUL]0P1iER`00`1kER`0O5L]07aG
;@0507eH;P0807aG;@1kER`0NUD[07YE:`1kER`0O5L]07iI;`20Fc4207aG;@@0OEP^0P1lEbd807UF
;0D0NU@]0P1iDb`01P1hDR/0Ne@[07]D:`1jEB/0N5D[07MF:`80MUL[0P1dEb/207aF;`0407]E;P1j
E2d0NU@]07UC;080N58[0P1eDRX0101fDb/0Me@/07MD;01hEBd207UF;PP0Me@/0`1eE2/307AC:P80
Le8Y1P1dDBT207EB:P80L5@/00<0LE@/07=C;01dDR`00P1eDR`0101gDB`0ME4_07=?;@1bCR`2075=
:`04079>;01cCbd0ME4_071@:@<0KdlX0P1^CRL206e=9PP0KT`V0`1^C2L306e;9P80K4XU00@0ITPT
06M99@1WBBD0IdTU0`1XBRH0301YBbL0I4HR06I8901WBBD0JD/W06Y<:01YBbL0J4XV06M99@1O@R00
H4<Q06958`<0I4LU0P1RAB<406=69P@0HTDU0P1SARH0101RABD0HD@T06138`1O@R8205i18@80I4<R
00@0HT@R06958`1PAR<0H4PT0P1OBB@00`1TAbD0HdHT06=6900406=6900906A79@1UAbD0ITPV06Q:
:01YBbT0J4XX06M99`1VB2H0IDLU0080ITPV00@0IdTW06Q::01ZC2X0Jdd[0P1/CR`206U89`0706Y9
9P1[BRL0K4`V06e=9P1^CRD0Ke0T071A9@02079B:`04075A:P1`D2T0L50Y06m?:080KThW00D0MU<[
07EB:P1eDRX0ME8Z07AA:@0307=@:080M5L[00h0MeP/07UH;@1jEbd0OEP^07iI;`1oF2l0OeTd07iH
<`1mEc00OEP^07eH;01oFRh0P5/^089M<080OUdZ00H0OU`/07mM;`1oGC00Oe`b081M<`20GCD208=N
<@80Q5lb1025H3<208MS;`0708QT<P28I3@0R6<f08QS=`29I3P0RF@j08YU<@0208]V<P0308aW<`2=
J3@0SVTe0080SfXf00H0SVXf08m[=`2?JcL0T6`h095]>@2BKSX209=_>`80TV`k0P2CKC`0102DKSd0
UFln09E_?P2EKch209E`?080UW4m0`2GLSh02P2HLcl0UW4l09Ia?02GLSd0VG@o09Ye@02KMT40W7M2
09eh@`2NND@309mjA@80X7]60P2QO4L20:1kA`060:5lB02SOTX0Y7m;0:F0C02VPDd0Yh9>0`2UP4`2
0:J1C@<0Yh9>00T0[8MC0:^6DP2YQ500Z8=?0:V4D02[QU80[HQD0:n:EP2^RE@0102_RUD30;2;EP80
[hYE0`2`ReH30;6<E`T0/8]G202cSEh80;2;E`H0/H]L0P2bS5d20:n:EP040;2;E`2aS5P0/XeI0;>>
FP80]8mK0`2bSET20;>>FP/0]8mK0P2hSe/00`2gSUX0]XeI0;F<F0020;B;E`030;>:EP2fSET0]XeI
0080]HaH0P2dReL20;>:EP060:n:EP2`ReL0/8]G0;6<F02bSET0/hiJ0P2dSe/80;:=F@<0]8]G0`2c
RUH20;:9E@P0[hYE00@0[HQD0:j9E@2^RED0[XUE0P2_RUH20;2;E`P0/8ID202_RUH80:j9E@<0[hIB
0`2`Qe<:0;68E0D0[hYF102`ReL40:f8E0@0[8MC0`2aQeD00`2aR5@0/8MC0;27D@020:n6D0P0[8MB
202_QU880:b7DP80[XAB0P2_QE<20;26E080/HME102`QU@40:n5D`H0ZhIB0P2/Qe<30:b2D080[H=A
0P2^Q5800`2_QE<0[HA@0:f4D0060:f4D0P0[8=?00H0[hMC0:j6DP2^QU80[HEA0:b4D02[Pdl20:Z2
CPP0[8AC202ZQE480:f3D@080:Z1C@2[PTh0[HA@0:j5D@2_QU80[XEA0:f4D02/Pdl20:V0C0060:Z1
C@2[PTh0[8=?0:f4D02^QE40[hIB202]Q5090:b3C`80[89B00@0[89@0:b3C`2/Pdl0[8==0P2/Pd/8
0:f4D0P0[XEA1P2/Pdl20:^2CP/0[HA@0`2]Pe420:f3D`<0[hIB0P2^QE430:f4D0P0[89B202]Q508
0:j4DPP0[H=A00P0[hEC0:f3D@2[PDl0ZX1>0:UoC@2ZP4h0Zh5?0:b2D0P0[XEA202/Pdd01P2XQDl0
ZHA?0:V4C`2/Q500[HA@0:j3D080/H=A0`2/Pdl20:f4D0<0[XEA0`2/Pdl30:f4D0@0[XEA00@0[HA@
0:b3C`2/Pdl0Zh9>0P2ZPDd90:f2C@80Zh9<102ZPD/20:^2C0P0Zh9>0P2[PT`40:Z1B`80Zh9<202[
PTh40:Z1C@@0Zh9>2@2^QE402P2/Pdl0ZX5=0:V0C02XOd/0ZH1<0:Z1C@2[PTh0[HA>0:b3C@2YP4X2
0:QoB@040:V0BP2/Pdd0[HA>0:b1EP80Zh1C00D0ZX1@0:UoC@2XOd/0Z7m90:MnB0020:QoB`<0ZH1<
0`2ZPDd30:^1C`<0[89@0P2]Pe430:j5D@80[HA@0`2/Pdl20:f4CP80[8==0P2[PT`20:Z1B`@0Zh5?
102ZP4h30:N2C@<0Z8=>0P2YQ4l20:Z4D`060:V4D02XPdh0Yh9=0:J1BP2VPTP0YH57202[PT`80:^2
CPL0ZH1<0P2ZPDd20:Z1B@040:Z1B`2ZPDd0ZX5=0:Z0CP@0ZX1@00@0ZX1>0:Z1C@2ZPDd0ZX5;0P2Z
PDT20:eoC@030:^0C@2ZPDd0ZH5=0080Yh9=00@0YX==0:MnBP2WOTX0Ygi:0P2XOd/30:V0C0040:j4
E02]Pe<0ZX1@0:QnCP80Yge=0P2XOTh80:V0C0P0YWe90P2UP4`30:J1C@<0Yh9>0`2WPTd20:J1C0<0
YH1;0P2WPTd20:J1C0<0YH1;00<0Y7m:0:=oA@2SOTL00P2SOTT0102SOTX0Xge<0:=mCP2SODh30:1k
A`050:5lB02RODT0XWe90:9mB@2SOTX0202PNdH20:=nB@<0XWe80P2SOTT00`2TOdX0XGQ40:5hA006
0:5hA080YGM600<0XgM60:9hAP2QNDH00P2ONTH01`2NNTH0WWU409mjA@2ONTD0X7]60:5lA`2RODP0
0P2SOTT30:5hA0@0XWU500@0XgY60:5hA02QN4@0XGQ41@2PMd<00`2OMT80WgE309me@`0209id@P@0
WG=100P0W7M309Ud@02FLCd0Tfhj09A_>`2GLSh0VgI209iiA@@0WGQ4102LMd<309egAP<0W7I50P2K
MD@209mjAP0909iiA@2LMd<0VgI209Ye@@2IM400V7<o09mjAP2MN4@0VWE10080V7<o00<0VGA009]f
@P2MN4@00`2NLdH0202MLTD0W75409aaA02LLD@0Vg1309Qb@`2ILd@0VgE60P2MMdP00`2LMTL0VgE6
09YdA@0209miBP80WWQ90P2MMdP209afA`<0VWA5:oooool002[ooooo00<0Sf@i08iS>02=HSL00`2=
HSL00`2>HcP0Sf@i08eQ>P0208eQ>P<0SV8k0P2?Hc`2091T=`<0Sf<f0`2>HSD0202FICd0UF@l09AS
>P2DHcP0U6@f09IV=P2GIcL0V6Pg202BIST01P2DJCH0U6Pg09=W=P2BISL0TVHi09=V?080U6Ln0P2C
J3h00`2CJ3d0TfPk09=Y>@0209=Y=`0309=Z=P2BK3d0TF/l00<0T6Xk00<0TF/l099/?@2BK3d00`2B
K3d2095[?0<0T6Xk00@0VFHk09IU>P2FICX0U6Di0P2CIcX00`2CJ3/0TfXl09A[?@0409EY>080U6Pg
0P2CIcH0102DJ3L0UFTh09EY>02EJCP209IZ>@80Uf/j0P2EJC`309IZ?@<0Uf/n202GJcX01@2EJCP0
UVXi09IZ>@2GJcX0V6`k0080VFdl00@0VVhm09M[>P2GJcX0Uf/j0P2HK3/309U]?00409M/>@2HKCX0
VFhk09Y_?080Vg0m00<0VVll09U^>`2MLSl01`2MLSl00`2OLd80WW9109a`?`0209]_?P0309a`?`2N
LT40Wg=20080WW=00P2MLSl209aa?P80Vg0m202NLT4809md@@P0WgI200<0XWU50:5hA02OMT800P2N
MD400`2OMT80XGQ40:9iA@040:1g@`@0XGQ40P2TNDH30:=hA@<0XWM400@0YGU80:AhA`2TN4L0Y7Q7
0P2SMdH20:9fA@80WgA100X0X7E20:9gA02TNDH0YGY70:IkB02WO4T0Wg@o0:1e@02QMT40XgQ3102T
ND@0102SN4<0Y7U60:AiAP2UNTL20:IkB00C0:MlB@2XODX0Z7e:0:9iA@2TNdL0YWe90:QoB`2WOTX0
YGa80:9iA@2PMd<0XgQ50:AiAP2VNdP0Yga90:IkB02SN4D0X7E209ic@0020:9i@`030:9iA@2RN4H0
XWQ80080XWM:00<0XWM<0:1dA`2OLdH00P2OLdH209ibA@80WG5400<0W79009]a?`2IKcd00P2HKS`0
102IKcd0VW0n09]a?`2FK3X309E[>@80U6Xh0P2CJCL0102>J3/0SFLj08eW>P2=IcX208aV>@80RfDh
2029Hc@308IP<@80QEl`0`24GRl01P24GcD0Pehd08=N=022GC<0PE`b081K<@80OeX`00H0PE`b081K
<@20Fc40OeX`07iI;`1mF2h207aG;@80NUL_00<0NEH^07MD;01fDb/00P1fDb/00`1eDRX0ME8/07IC
;@0207MD;P0407IC;@1dDB/0LTlY075>:080MThZ00H0M4hY079?:@1`CRP0KThW06e=9P1[CRH806e<
:@08071?;01^CBX0JdXW06U89@1XAb@0JDPU06a;:01]C2T806U;9`0406A88`1UBB@0IDTT06E990D0
ITXU00<0J4/Y06M::01UB2H00`1SAR@0101TAbD0IDPV06M99`1WBBL206I89P@0IDLU0P1XBRP406I8
9P80J4XX101YC2@206Y=9@80JdhV0P1^CBX206m>:`<0L4l/00<0LE0]07=@:P1cD2X0101bCbT207=@
:P@0ME8/0P1fDbd0101gE2h0N5D_07IC;@1gE2h407QE;`0307MD;P1fDbd0N5D]00L0N5D]00<0NeP`
07YG;`1iERh00P1hEBd00`1iERh0NUL_07]H<00807aG;@04081D;`1oEBl0OUL`07iG<080O5Ta00<0
NeXa07]K<P1mFS000`1lFBl207]H;P80NUL]00<0O5L]07eH;P1nFBl00P1oFS001P1nFBl0OEP^07aG
;@1nFBl0OEP^07]F;080NUD[00H0NeH/07eH;P1nFBl0O5L]07eH;P1nFBl207mJ<00307iI;`1mF2h0
O5L]00P0NUL]00<0NE</07YD;@1kEBh00`1kEBh01`1jE2d0NE</07aE;01lEB`0NeH/07UF;01hEb`0
0P1gF2`207EH;080O5H_0`1kEBh307YD;@0407MD;01hEBd0N5D]07QE;@@0NEH^201jE2d207MD;080
MU<[0`1eDRX307AA:@<0ME8Z0`1fDb/2071D;003075D;01cDb`0M58/0080ME8/00@0Me4/07EA;`1d
D2h0LTh/0P1aCB/0101bCR`0M50^07EA;`1aDBX3071@:@80KdlX0P1^CRL806m<9P80LDhX0P1`CBL3
06m<9P0406i;9@1YBbL0JD/W06U;9`D0J4XV00<0ITPT06M99@1YBbL00`1ZC2P01@1XBRH0IdTU0654
8P1RAB<0I4LU00<0ITTW0P1TAbD306A79`80HdHV0`1RABD206A79`0406=69P1RABD0HD@T06138`80
Gd8R0P1R@B00101Q@b40HD@R06168`1PB2@2061:9@0306A79@1SAR@0HTDS00<0HTDS00@0HdHT06A7
9@1VB2H0ITPV0`1XBRP00`1VB2H0IDLU06=58`0206I89P0406M99`1XBRP0JD/Y06U;:@80JT`Z0P1X
BRP01`1XBRH0JD/W06Y<9P1[CRH0K4lU06a?8`1]D2@00`1`D2T306m?:080KThW0P1dDBT307=@:0<0
LTlW0P1bEbX00`1cERX0MUL[07MF:`0207UF;00907]F;01mEc<0O5Hb07]E<01kEBh0NeH/07eH;01n
FBd0P5/^0080OE`Y00<0OU`/07iL;P1oGC000P1oG3800`20GCD0P5h`081N<002085O<@<0PV0b00H0
Pf4c08MS<@27Hc40Qf<c08MR=@27HSH208MR>00708MQ>P29I300RVDa08YU<@2;IS80S6Lc08eX=002
08iY=@0608eY=@2>JSH0SVXf08m[=`2@K3P0TFdi0P2BKSX2099/?@80Tfdn00@0U6ho09E_@02FL440
UW110`2FLCd209Mb?P<0V7<o00D0UW4m09Mb?P2GLSh0V7<o09Ud@00209Ye@@0309]f@P2MN4<0WWU4
0080WWU40P2ONTD20:1kAP050:1kA`2QO4P0XGa80:9mB@2SOTX00P2TOd/00`2UP4`0Y7m;0:F0C002
0:F0C080YX5=0P2WPTh0102YQ500ZXEA0:Z5D@2ZQE420:^6DP80[8MC202^RE@20:n:E@<0/8]F0`2a
S5L90;2;E`P0/heN202`ReL30;2:F`<0/H]L0P2bS5d20:n:EP040;2;E`2aS5P0/XeI0;>>FP80]8mK
0P2bSET20;>>FP<0]8mK00<0]I1L0;>>FP2cSUX01P2cSUX20;R?F`030;N>FP2fSET0]HaH0080]8]G
00<0/hYF0;J=F@2fSET00P2eS5P20;B;E`80/hYF0P2aS5P30;:=F@<0/hiJ202bSEP30;B;E`<0/hYF
0P2bRED80;2;EP<0[hYF0P2`ReL30;6<F0P0/XIE202_RUH0102]R5@0[XUE0:j9E@2^RED30:n:EP04
0;2;E`2_QU80[hIB0:n6DP80/8MC0`2aR5@80;27D`030:f8E02^RED0[XUE0080[XUE0`2_RUH00`2`
ReL0[XUE0:f8E0020:f8E0<0[8MC00<0ZhIB0;66F@2aQeL00P2`QU@20:n6D0030:n6CP2^QT/0[8MB
00L0[8MB202_QU880:b7DP80[XAB0P2_QE<20;26E080/HME102aQE@40;24D`80ZhIB0`2ZQE401@2[
QU80[HQD0:j9E@2^Q580[H=A0080[89@00@0[H=A0:j4DP2_QE<0/8ID0`2/Pdl20:f4D0<0[XEA202/
Pdl0102/Qe80ZhIA0:^6D@2[QU440:Z5D0P0ZhEF202[QU880:f3D@030:^2CP2/Pdl0[HA@0080[XEA
00<0[HA@0:^2CP2ZPDd00`2[PT`30:b3C@80[HA>202^QE490:b3C`80[89B00@0[89@0:b3C`2/Pdl0
[8==0P2/Pd/80:f4D0P0[XEA0P2]Q5030:b3C`<0Zh9>202]Q500102]QDX0[HA<0:f4CP2]Q4h20:f3
D@040:f3D`2]PUD0[hIB0:n6DP80[XEA0`2]Q5000`2/Pdl0[85D0:b1E0060:b1E0P0[8=?202^Q588
0:f3D@080:j4DP2]Pe40Zh5?0:Z0CP2YOdd0ZX1>0:^1C`2/PU080:j5D@P0[HA>00H0ZHI>0:Z5CP2Y
Q4d0ZhA=0:b3C@2]PTd20:n1C@<0[8=?0P2]Q5030:j5D@80Zh9>0P2/Pdl30:f4D0090:j5D@2aR5@0
/8MC0:n6DP2]Q500[8=?0:Z1C@2YP4`0Z7m;00T0[H9=00<0[8==0:^2C02ZPD/00P2YP4X00`2ZPD/0
Zh9<0:b3C@080:^2CP030:b3C@2[PT`0ZX5;0080ZH1:00<0ZX5;0:^2C02/Pdd0202[PTh40:Z1C@@0
Zh9>202]Q5002`2^QE40[8=?0:Z1C@2YP4`0Z7m;0:V0C02ZPDd0Zh9>0:b3C@2[PT`0ZX5;0080ZH1:
00T0ZX5;0:^2C02/Pdd0Zh1E0:^0D`2ZOe80ZX1@0:Z0CP2YP4`00P2YP4X20:QoB`<0ZH1<0`2ZPDd3
0:^1C`<0[89@0P2]Pe430:j5D@80[HA@0`2/Pdl30:b3C@80Zh9<0`2ZPD/40:^1C`@0ZX1>0`2WPTd2
0:R3CP<0ZHA?00H0ZXID0:V5D`2YQE40Z8E?0:N4CP2VPd/20:F2B0P0Zh9<202[PTh20:QoB`<0ZH1<
102ZPDd20:Z1B@040:Z1B`2ZPDd0ZX5=0:Z0CP@0ZX1@00@0ZX1>0:Z1C@2ZPDd0ZX5;0P2ZPDT20:eo
C@030:^0C@2ZPDd0ZH5=0080Yh9=00@0YX==0:MnBP2WOTX0Ygi:0P2XOd/30:V0C0030:f2E@2/PE@0
ZWmB0080Z7e@00<0ZGiA0:YoDP2[P5<0202YP4`80:MnBP80YH1<0`2VPDd30:N2CP80Yh9=0P2VPD`3
0:F0B`030:AoBP2VPD`0YX5<0080YH1;0P2TOdX20:=nB@80Xgm500@0Xgi70:=nB@2SOTT0Xgi:0P2S
OD`00`2PNdL0XGa80:5lB0020:5lB0<0XWe90`2QO4L20:1kAP<0WgY50P2QO4L30:1kAP030:5lA`2S
OTT0Y7m:00P0XgY60P2UMdH00`2SMdH0XWQ60:5iAP0209mjAP0509ijAP2NND@0WWU409mjA@2PNdH0
0P2QO4L20:9mB0P0XWU32@2PMd<00`2PMT@0WgE309ec@@0309ab@080WG=100L0VgI209Ye@@2HLcl0
UW4m09Mb?P2IM400W7M300@0WWU50P2MN4@309ag@`<0WGM80`2LMTL209]eAP80WGQ40P2LMd<01`2K
MT80VWE109Ud@02IM400WGQ409ag@`2JMD400`2IM40209Ye@@0309icAP2MLTD0WG950080WG950`2L
LD@00`2HLT<0VG=409]eAP0209egB00309afA`2KMDH0VWA50080WWY:0P2MNDT209ahB080VgM70`2K
MDH[ooooo`00:_ooool00`2>HcP0SF8g08]P=@0208YO=00308]P=@2=HSL0SV<h00<0S68j0`2=Hc/2
08iT?080T6@g0`2?HcH308iR=@0809IU?@2EI3`0U6<j09=R=`2DI3H0UFDe09MW=`2IJCP8099V>@08
09EZ=`2DJ3L0TVHe095U=P2AICP0TVDk09AW?P2EJ3l209AY?`0309AY?P2DJC`0U6Xj0080U6Xh00<0
U6/g091Z>`2AJc`00`2BK3d00`2AJc`0T6Xk08mY>P03099/?@80TF/l0`2@JS/0102IIS/0UfHk09ET
>@2DICT2099V>@0409=X>`2DJcd0UF`n09IZ>@80UFTh0P2DJ3L209=W=P03099V=@2DJ3L0U6Pg00<0
UFTh0`2FJST209EY?0<0UVXm0`2GJch809IZ>@@0Uf/j102HK3/309M[>PD0V6`k00<0UV/h09M/>@2I
KS/00P2KL3d00`2JKc`0VFhk09Q]>P0809eb?`0309mc@P2NLT40WG500080W70o00<0WG5009ib@@2O
Ld800P2NLd0209eb?`80W74n0P2KL3d809ib@@P0WgA1202OMT800`2RNDD0XGQ40:1g@`0209ie@@04
0:1g@`2QN4@0XWU509ie@@80WgI200D0X7M30:5hA02RNDD0XWU50:=jAP020:AiAP<0XgQ50`2RMd@2
0:EiBP<0Y7Q90`2SMdP30:9gA0@0XgQ500<0Y7U60:1e@02PMD000P2PMD001@2QMT40XgQ30:=h@`2U
NTD0YW]600H0YW]80P2WO4T00`2RNDD0Y7]70:MnBP020:QoB`0;0:ElB02QN4@0WgI20:9gA02TNDH0
YW]80:MlB@2VNdP0XgQ509md@@2LLCh00P2RND<00`2RNDD0XWQ60:9hB0020:9gBP040:9gC02OLdH0
Wg=609mcAP80WW950`2MLD@0102KLCl0VW0n09Q^?02FK3X209E[>@0309I/>P2GKC/0UF/i00<0U6Xh
0P2CJCL2099X=P0408eV>`2<ICX0S6Dj08aU>P80Rf@i0P2:HcP308MQ<PD0R68c0P27HC8208IP<@<0
QEl`00L0Q5h_08=N=022GC<0PUdc085L<P20Fc40OeX`0080OUT_0P20Fc400`1oFS00OUT_07eH;P02
07aG;@0607]F;01hEbh0N5L^07MF;@1fEB`0ME@[0P1dDbX0101cDRT0Le0Z07AA:`1eDR`207IC;@0;
07EB;01cD2X0LTlY07Q@;01gCb/0MU0[07=@:P1aCbT0KdlX06i>9`1/CbL0201/BbP00`1`Cb`0KD`Y
06Y99P0206M68`0306Q7901[BRL0KD`Y00@0J4XV101YBbL306A:9@80HdTT101RB2<00`1XBbT0IdXX
06E89P0306=6900406A79@1UB2H0JdXY06]::@80JTTX0P1YB2L206Q79P0306U;:@1XBRP0ITPV0080
IDLU00<0ITPV06Q::01YBbT00`1YC2@00`1ZCBD0JdhV06]>9P0206a?9`<0Kdh[0P1`Cb`3075@;@P0
ME8/0`1fDbd207MD;P<0N5D_0P1iES00101hEBl0Me@^07MD;P1hEBl207UF<0P0NEH^00<0NeP`07YG
;`1hEBd00P1gE2`00`1hEBd0NUL_07]H<00807iG;P08089D<021EC00P5H`07mH<@1lFC40O5/b07]K
<P1iG38307eJ<080O5T_0`1kF2h00`1mF2h0OUT_07mJ<002081K<@0707mJ<01mF2h0O5L]081K<@1o
FS00OEP^07]F;00207YE:`80NeH/00<0O5L]07eH;P1oFS000P20Fc400`1oFS00OEP^07aG;@0807]H
;P0807QB:`1iDb`0NeD^07aF;`1mEc00O5H_07YD;@1iDb`207eF;@0307aG;@1jEbd0NEP]0080N5T]
0P1fFBd407]E;P<0O5H_00<0OEL`07YG;`1jEbl00P1jEbl307UF;P0307QE;@1kE2d0Ne@]00H0Ne@]
0`1gE2`207IC:`<0ME8Z0P1dDBT207EB:P0407IC:`1gE2`0Me@/07MD;080Ke<[00<0L5<[079B:`1c
DB/00P1dDB/0101fD2/0ME4_07A@;P1cCbd2079>;00307=?;@1dD2h0ME4_00<0LE4Z0P1`D2T306m?
:0P0L4dW0P1bCbT2075>:0<0L4dW00@0Kd`V06]=:@1[CBT0JT`X0P1YBbL01P1XBRH0IdTU06M99@1X
BRH0JD/W06Y<:080JddY00H0JT`X06Q:9P1WBBD0HdHT06E89P1VBBL306Q;:@0406M::01VBBL0IDPX
06E8:080I4LW00@0HdHV06959@1RABD0HTDU0P1UB2P0101TAbL0HdHV06=69P1RABD206549080ID@S
00@0HT@R06548P1OAB80GTHR0P1MAb800`1TAbD0HdHT06958`0206548P0506958`1SAR@0I4LU06I8
9P1WBBL00P1XBRP0101WBBL0ITPV06A6901SAB<506M99`<0J4XX0P1WBRP0201WBbH0J4`W06Q<9@1Y
CBD0JTlT06Y?8P1[D2<0KDdV0`1^CRL406m?:080LDhV1P1bCbL01P1^ERP0L5DX071E:01bEBT0M5DY
07ED:@80Me@Z00P0Ne@c07YC<P1iDbl0N58]07UC;01jEB/0O5L]07eH;080OE`Y00<0OE/[07iL;P1n
G2l00P1oG3800`1oG3@0OUh_07mO<00207mO<080P60a0P21HC801P27Hc40Qf<c08MS<`27HSD0QV4e
08IQ=`80QV0i0P29I3000`2:IC40RfHb08aW<`0208eX=00608iY=@2=JCD0SFTe08iZ=P2?JcL0T6`h
0P2AKCT02@2BKSX0TV`m099/?@2CKCh0U6ho09E_@02FL440Ug5209Qb@`0209Mb?P<0V7<o0`2IM402
09Ma@0H0V7910`2MN4<209iiA0<0WgY50P2QO4P60:9mB@80Y7m;0`2UP4`40:J1C@070:R3C`2[QU80
[HQD0:j9E@2/Qe<0ZXEA0:R3C`080:b7DP80[hYE0`2`ReH30;6<E`T0[hYF202cSEh80;2;E`80[hUJ
0P2`RU/20;6;G080/XaM0P2_RUH0102`ReL0/HaH0;:=F@2cSUX20;B?F`<0/hiJ0`2dSe/20;F@G0P0
/hiJ0P2hSe/00`2gSUX0]XeI0;F<F0020;B;E`030;>:EP2fSET0]XeI0080]HaH0P2dReL20;>:EP@0
/hiJ102bSET80;:=EP<0]8]G0`2cRUH20;:9E@P0/8]F0`2aS5P20;:=F@<0/hiJ202fR5L80:n:EP80
[HQD0P2^RED01@2_RUH0/8]G0;2;E`2`ReL0[hIB00<0/8MC0P2aR5@20;:9E@P0/8MC00@0ZhIB0:b7
D`2/Qe<0[8MC0P2]R5@20:j9E@030:n:EP2^RED0[XUE0080[HQD0P2/Qe<20:^6DP080;25FP2`QEP0
[hEE0:n5D`2^QDl0[XE=0:j6B`2]QDP80:^6D@P0[hIB202[QU420:j4DP80[hEC0P2`QU@20;67E@@0
/XAC102cQE@02`2/Qe<0ZhIB0:Z5D@2YQ500ZXEA0:^6DP2]R5@0[hYF0:n5D`2^Q580[H=A0080[89@
00@0[XAB0;26E02aQeD0Zh9>0P2/Pdl20:f4D080[XEA00<0[hIB0:b3C`2/Pdl01P2/Pdl30:Z5D080
ZhIA0`2/Qe880:^5EPP0ZhIB202]Pe40202/Pdl0[HA@0:j5D@2^QE40[HA@0:^2CP2YP4`0Z7m;0`2]
Q4`01@2/Pd/0Zh9:0:^2BP2[PTX0ZX5900P0[XEA2@2/Pdl20:b2DP040:b2D02/Pdl0[8=?0:b3C@80
[8=;4`2]Q5000`2/Pdl0Zh9>0:^2CP020:Z1C@P0[HA@00H0[HE70:f5B02]QDX0[HA>0:f4D02]Pe42
0:f2E@<0[XEA0`2]Q5020:b3C`P0[85D202/Pdl80:j4DPP0[H=A00<0[XAB0:b2D02[PDl00`2YOdd0
0`2ZP4h0Zh5?0:j5D@070:j5D@P0[XE?00H0ZXM=0:^7C@2ZQT`0ZhA;0:b3B`2/PDX20:f0B@<0[8=?
0P2]Q5030:j5D@<0Zh9>0P2/Pdl30:f4D0030:j5D@2]Q500[HA@0080[HA@0`2/Pdl90:f2C@030:b3
C@2[PT`0ZX5;0080ZH1:00<0ZX5;0:^2C02/Pdd0202[PTh00`2/Pdd0Zh9<0:Z1B`020:V0BP030:Z1
B`2[PT`0[8==00`0Zh9>102ZPDd80:b3C`0;0:j5D@2/Pdl0ZX5=0:V0C02XOd/0ZH1<0:Z1C@2[PTh0
ZH1:0:Z1B`2[PT`00P2/Pdd02@2[PT`0ZX5;0:V0BP2YOU<0ZGiA0:YoDP2ZP500ZX1>0:^2CP020:^2
C080Z7m;0`2YP4`30:Z1C@<0Zh5?0`2/PU020:f3D@<0[XEA0P2]Q5030:b3C`80[8==0P2[PT`40:Z1
B`@0ZX1>102[PDl0102WPTd0Z8=>0:R3CP2XPdh20:V4C`80ZXE@0P2XQe@0102WQU40YXE?0:F4CP2T
Q4/20:>3B0P0Zh9<202/Pdl30:QoB`040:V0C02ZPDd0ZX5=0:Z1C@80Zh9>0P2YP4P0102YP4X0ZH1<
0:V0C02YOdd20:UoC`80ZX1@00@0ZX1>0:Z1C@2ZPDd0ZX5;0P2ZPDT20:eoC@030:^0C@2ZPDd0ZH5=
0080Yh9=00@0YX==0:MnBP2WOTX0Ygi:0P2XOd/30:V0C0080:^0D`2ZOe80ZGiA0:QmD02YOU40ZWmB
0:b1E02]PUD@0:V0C080YH1<0`2VPDd30:N2CP<0YX5<0`2UP4/50:AoBP80Xgi90`2RODP20:=o@`03
0:=oA@2SOTL0Xgi90080Xgi:00@0Xge<0:9mB@2RODT0XWe91@2QO4P00`2RODP0XGa70:5lA`020:1k
AP80WgY500T0WWU40:1kAP2ONTD0WWU409eh@`2NND@0X7]60:9mB02SOTT0202UO4P20:EgAP030:=g
AP2RN4H0XGU60080WgY600<0WWY609iiA02NND@0102ONTD20:1kAPH0XWU10P2QN40409mf@PD0X7M3
00<0X7I409me@`2MLd400`2KLCl00`2MLd40WWA209]f@P0409]f@P0309ag@`2MN4@0WGQ40080WgY6
0P2NNDD0102MN4@0W7M309ag@`2LMd<309egB0<0W7I70P2KMDH:09Ye@@<0VgI200<0VWE109Qc?`2H
Lcl00`2LLD@509ebA@0309Qb@`2ILd@0VgE60080WGM800<0W7I709]eAP2JM4D00P2LNTX209]iB@80
VWQ80P2IMdL309afAb_ooooo000Zooooo`0308eR=`2<HCH0RUld0080REhc00<0RUld08aQ=P2=HSL0
0`2<HSX308eS>`80SV@l0P2@I3L308mS=P<0SV8e00P0UfHn09ET?02DHcX0Tf8g09=S=@2EICD0UfLg
09UY>0P0TVHi00P0UFXg09=W=P2BISD0T6@e091T=`2BIC/0TfHm09EX?`80U6To00<0U6Tn09AY?02D
JSX00P2DJSP0102DJcL0SVXj08m[>`2BKSh209=_?`03095]?@2>JSX0S6Ph00<0TFdm0P2@K3`308m[
>`0409YW?02GIS/0UF@i09=T>080TVHi00@0TfPk09A[?@2EK3h0UVXi0P2EJCP00`2DJ3L0TfLf09=W
=P02099V=@<0U6Pg0P2EJCP309IZ>@80UFTl0`2FJSd309M[?PP0UVXi102HK3/809M[>P@0V6`k00<0
UFXg09M/>@2IKS/00P2KL3d00`2JKc`0VFhk09Q]>P0809eb?`030:1d@`2NLT40WG500080W70o00<0
WG5009ib@@2PM4<00P2NLd0209eb?`80W74n0P2KL3d809ib@@80X7E2102OM44209ic@0P0WgI200<0
XWU50:5hA02PMd<00P2OMT802`2PMd<0XGQ40:9iA@2MM400WWE109mf@P2PMd<0XGQ40:9iA@2SNTH0
Y7]70080Y7U60`2SN4D30:9gA0<0YGU:0P2TN4T30:=gB080YW]800/0YGY70:=hA@2RMd@0XGI30:1e
@P2OM440XGI10:1e@02OM3l0WW<n09md?`020:9g@P030:EjA@2XODP0Z7e:00<0Yga90`2VNdP04@2U
NTL0XWU50:AkA`2WOTX0ZH1<0:QoB`2UO4P0XGQ409ie@@2RMd@0Y7U60:IkB02WO4T0YW]80:=hA@2N
Ld00W74n0080XWU300<0XWU50:9hAP2RN4P00P2RMdX00`2RMd`0Wg9809mbB00309iaA`<0WG1600H0
Vg4o09Y`?P2GKC/0UF/i09AZ>02CJCL509AZ>080TfTg0`2BJ3H308]V>P80RVDi0`29I3P00`26H340
Qf4b08MQ<P0308MQ<P<0R68c0`27HC8208IP<@80QEl`0P22GC<00`21G380P5/a07mJ<00207iI;`07
07eH;P20Fc40OeX`07mJ<01nFBl0OEP^07aG;@0207]F;0<0MeH]01D0MUD/07ED:`1dDbX0Le8Y079A
:01aCRP0LTlY07AA:`1eDR`0MU<]07EB;01dDB/0Le0Z07UA;@1hD2`0MU0[07AA:`1bD2X0L50Y06m?
:01]D2P0201/BbP0201`Cb`0KD`Y06U89@1WAR<0ITDR06Q7901[BRL0KD`Y1@1XBRH306U;9`80I4`V
00@0Hd/U069:901QBB<0HDTS0`1PB2800`1XBbT0IdXX06E89P0306=6900306A79@1UB2H0KD`[0080
K4/Z00<0JdXY06Y9:01ZBBP00P1YB2L00`1YBbT0J4XX06I89P0206E79@0306I89P1XBRP0JD/Y0080
JD`R0P1ZCB<0101[CR@0K4lU06a?9@1]D2H206m>:`80L4l/0`1aD2d00`1bDBh0MU<]07MD;P0507MD
;P0407IC;@1hDRd0N58]07UC;PD0NU@_00<0O5Tc07YG<@1gE2h00P1fDbd00`1gE2h0NULa07aI<`09
07YG;`0707UF;P1gE2`0MU<[07IC:`1gE2`0NEH^07YG;`0807iG;P0908AD<022E300PUHa07mH<@1m
FS80Ne/b07UL<P1iGS<0OU/a00<0OEX`0P1lFBl207]H;P0307eH;P1nFBl0P5/a0080PE`b00L0OeX`
07eH;P1kER`0PUdc081K<@1nFBl0NeH/00<0NE@Z00@0NUD[07aG;@1nFBl0OeX`0P21G3800`1oFS00
OUT_07aG;@0807]H;P0307QB:`1iDb`0NeD^0080OEL`00<0O5H_07YD;@1iDb`00P1mERd00`1lEbd0
NUL]07UH;@0207QI;@80MUT]0P1jE2d207]E;P0407aF;`1mEc00OUPa07iH<@80O5Ta00@0NeP`07YG
;`1iERh0NEH^0P1hEBd807aE;P<0NE</0`1hDR/207MA:P0407AA:@1eDRX0ME8Z07IC:`80Me@/0P1h
EBd206iB:P0306mB:P1aDBX0LU0Z0080Le0Z00@0MDlZ07IB<01dD2h0Ldl]0P1bCR`0101cCbd0M50^
07IB<01bDR/3075A:P80L50Y0P1_CbP8079<9`<0M4hW0P1cCBH3079<9@0606e?:`1/CRX0JddY06Y<
:01YBbL0IdTU0P1VB2@0401YBbL0JT`X06]=:@1/CRX0JddY06U;9`1WBBD0ITPT06E89P1VBBL0J4/Y
06U<:P1ZCB/0JD`Z06Q;:@1WBRP306E8:00306A79`1SARH0HTDU0080HTDU0P1VBBT206E8:00?06A7
9`1SARH0HTDU06959@1YB2L0J4LV06E79@1RAB<0GT@Q05]37`1I@ah0F48M06E89P1SAR@0HD@R0080
H4<Q00D0HD@R06=6901UB2H0ITPV06M99`0206Q::00406M99`1UAbD0HdDS06948P<0J4XX0P1WBBL3
06I89P80IdXX00D0Id/V06Q<9`1XC2D0JDdU06Y?900206Y?8P80K4`U00@0KDdV06i>9`1_CbP0KdlX
0P1`D2T3071=9@03075>9P1bCbL0LTlW0080Le0X0P1]EBL00`1_E2L0L5<W07=D:00207AC:00907EB
:01jDc80NE8a07QB;P1gDB`0Me4Z07UC;01kER`0O5L]0080OE`Y00H0OE/[07iL;P1nG2l0OU/a07mL
<P1oG3@207iN;`80Oel`0`20H3402P21HC80Qf<c08MS<`26HC@0QV4e08IQ=`26H3T0QElh08EO>P28
Hbl208UT<00308YU<@2;IS80S6Lc0080SFPd00H0S6Pd08eY=@2=JCD0SVXf08m[=`2@K3P2095]>@06
099/?`2CKD00U6i109E_@P2FL4<0Ug540P2HLTD309Qc?`80VGA00`2JMD4409Qb@@80Ug500P2FL3l0
102LMd80WGQ309eh@`2MN4<209iiA080WgY5102RODT20:5lB080X7]70`2TOd/20:F0C0<0YX5=00P0
Y7m;0:N2CP2/Qe<0[hYF0;2;E`2]R5@0ZHA@0:J1C@D0ZhIA0`2ZQE020:n:E@<0/8]F0`2aS5L90:n:
EPP0/heN202`ReL0102^R5T0[hUJ0:n9FP2`RU/20;6;G080/XaM0P2_RUH0102`ReL0/HaH0;:=F@2c
SUX20;B?F`<0/hiJ0P2dSe/30;F@G0P0/hiJ0P2hSe/00`2gSUX0]XeI0;F<F0020;B;E`030;>:EP2f
SET0]XeI0080]HaH0P2dReL20;>:EP80]I1L00<0]8mK0;>>FP2bSET00P2aS5P00`2`ReL0/XeF0;:=
EP060;:=EP<0]8]G0`2cRUH20;:9E@P0/8]F0P2bSET30;>>FP<0]8mK202gREP80:n:EP80[HQD00@0
[XUE0:n:EP2_RUH0/8]G0P2aS5P40;27D`80/HQD0P2bRED80;27D`80ZXEA0P2[QU820:b7D`030:f8
E02^RED0[XUE00<0[XUE00<0[HQD0:b7D`2[QU800P2[QU80202_Q5X0[hAI0:j3EP2^Q580[HA>0:f5
BP2]QDP0[8A6202[QU480:n6DPP0ZhIA0P2^Q5820:n5D`80/8ID0P2aQeD40;:4D`@0/hED00<0[8MC
0:^6DP2YQ5000P2YQ5001P2[QU80[XUE0:n:EP2_QE<0[XAB0:f3D@80[89@00<0[XAB0;26E02bR5H0
0P2[PTh0102/Pdl0[HA@0:f4D02^QE420:n6DPP0[8=?0P2XQDl0102YQU00ZXMA0:^8DP2[R5820:b9
D`P0ZXEH202[QU880:f3D@0>0:f4D02^QE40[XEA0:j5D@2]Q500Zh9>0:QoB`2WOTX0[hI>0:j5C@2]
Q4`0[8=;0:^2BP2ZPDT20:V0B0P0[XEA2@2/Pdl20:b2DP040:b2D02/Pdl0[8=?0:b3C@80[8=;402]
Q500102^QE40[HA@0:f4D02/Pdl20:^2CP80ZX5=202]Q5001P2]QTD0[HE70:f5B02]Q4`0[HA@0:f3
D`80[H9E0`2^QE420:f4D0<0[8=?202/PEH80:b3C`P0[XAB202]Pe40202^Q580[89@0:Z0CP2YOdd0
Z7i<0:UoC@2ZP4h0Zh5?202^QE480:j5C`080:^8CP2/R4h0ZhM=0:^4B`2[PTX0Zh190:aoB02[OTL3
0:b3C`80[HA@0`2^QE430:^2CP<0[8=?0P2]Q5020:Z1C@040:^2CP2/Pdl0[XEA0:n6DP80/8MC2@2]
PTd00`2]Q4h0Zh9<0:Z1B`020:QoB@030:Z1B`2[PT`0[HA>00P0Zh9>00<0[HA>0:^2C02ZPD/00P2X
OdT00`2ZPD/0Zh9<0:f4CP0<0:^2CP@0ZX5=202[PTh02`2^QE40[8=?0:Z1C@2YP4`0Z7m;0:V0C02Z
PDd0Zh9>0:QoB@2YP4X0[8==0080[HA>00@0[8==0:V0BP2XOdT0Z7eB0P2YOU401@2ZP500Zh5?0:b3
C`2/Pdd0[HA>0080Z7m;0`2YP4`30:Z1C@<0Zh5?0`2/PU020:f3D@<0[XEA0P2]Q5030:b3C`80[8==
0P2[PT`30:Z1B`030:V0BP2ZP4h0ZX1>0080ZX1>102[PDl40:R3CP80ZHA?0P2ZQE020:R7E0060:N6
D@2VQDl0YHA>0:B4B`2TQ4T0Xh=8202[PT`80:b3C`040:MnBP2XOd/0Z7m;0:V0C0<0ZX5=0P2[PTh2
0:V0B0040:V0BP2YP4`0ZH1<0:UoC@80ZGm?0P2ZP500102ZP4h0ZX5=0:Z1C@2ZPD/20:Z1B@80[Gm=
00<0Zh1=0:Z1C@2YPDd00P2WPTd0102VPdd0Ygi:0:MnBP2WOTX20:QoB`<0ZH1<0P2YOU<20:QmDP04
0:UnD`2[P5D0[X=H0:n4F@P0ZH1<202ZPDd20:F0C0<0YX5=0`2WPTh30:J1C080YH1;0`2TOdX30:=n
B@80XWe80`2QO4L20:=o@`80Xgm500<0Xgi70:=nB@2SOTX00`2SOTX20:9mB@040:5lB02PNdL0X7]7
0:1kA`80XWe800@0XGa70:1kAP2PNdH0WgY50P2NND@00`2ONTD0WWU409ag@P0209ag@P0309iiA02Q
O4L0XWe800P0YWe90P2UMdH00`2SMdH0XWQ60:5iAP0209mjAP0309ijAP2ONTD0WWU400H0WWU41@2R
ND430:5h@0D0WgI2102PMd<02`2PMT@0WgE309ec@@2KLCl0VW0n09]a?`2MLd40WWA209Ye@@2KMT80
WGQ400<0WWU50P2MN4@309mjAP0309iiA@2MN4@0W7M30080W7M30`2MMdX309afB@80VgE80P2HLcl3
09Ud@0<0VWE100<0V7<o09Ye@@2LMd<00P2MN4@00`2JMD40V7<o09Ia?@0209]`@`80W75400L0WG95
09icAP2NLdH0WW=609Qb@`2ILd@0VgE60080WGM800<0W7I709]eAP2JM4D00P2LNTX209]iB@80VWQ8
0P2IMdL309egB2_ooooo000Zooooo`08095W=`2@ISH0SF8e08]P=@2;H3H0SF4j091T?@2AID0408mS
?080SV8k0P2=HCX208eT>00308iS>02@HcT0TV<i0080U6<j00<0UV8j091T=`2@I3L00`2AICP3099V
>@<0TfHm0`2DIch209EX?`0;09ER=`2EI3T0UfHk09QY?@2FJSd0U6Tl099Y>`2AJ3X0UV`j09E[>@2C
JCL00`2AIcD00`2BJ3H0TfTg09EY?00709EY?00609AX>`2CIcX0TfLj099V>@2AICP0T6@g0P2?HcH9
09EX?PP0UFTh0`2GJcX209Q/>`<0VFdl0`2GJcX509IZ>@0809]T>`2KIS`0VfPm09UZ?P2GK3l0Ufi0
09Ea@@2FLT8809Q/?`80VVll0`2IKS/309Q]>P0309a`?`2KKch0VFdl0080V6`k00<0VFdl09]_?P2L
L3l00P2KKch209a`?`80WG500P2NLT4209aa?P80WG8o00@0WW=009md@@2OM440X7E2102KLSh309ac
?`0409ed@02MLSl0WG8o09eb?`<0WW=00P2OM44809me@`80X7E2102OM44209ic@0P0WgE500H0Yga9
0:IkB02UNTL0Y7U60:9gA02PMD8209md@@080:Ai@P2SN440XgQ30:9gA02QMT<0X7A30:1dA@2OLd@8
0:=hA@0;0:=gAP2QMD@0Wg=209ib@@2OLd80XGE40:AhA`2VNTT0YW]80:EjA`2SN4D00P2RMd@20:=h
A@030:EjA`2VNdP0Y7U600L0Y7U60P2TNd<0102TNdD0XgY60:=jAP2RN4H20:9hB00<0:UnB@2XODP0
Z7e:0:MkBP2VNT/0YGU<0:AhB`2TMdd0Y7Y80:=iA`2PMT@0WWA20`2MLd400`2NM480WG=109ab@002
09ab@080Vg4o0P2JL3h04@2CM3d0U7<n09Ea?@2GKch0V6`o09UZ@02LJ440VfM008mT>@2@ICX0TFHk
099W?02AIS/0T6Dj08iS>02=HSL0RfDh00<0RV@g0P29HcH208QR=@0808EP<`26HC@0Qf8e08MR=@26
HC@0Q5lb089M<020Fbh808=N<@80PE/d00@0P5Xc07mI<P1nF340OEL`0P1lERl00`1nG2h0O5X/07YH
:P0207QF:00?07UG:@1jF2X0NeT[07YG<@1lFC<0NePb07MD;P1aCRP0Kd`V07=@:P1fDbd0MUDb07AC
<01aD2d0Kdh[0080KTdZ0180Kdh[071?;01`Cb`0Kdh[06a;:01[BRL0JTTV06]:9`1]C2T0KTdZ06]:
:@1/BbX0KD`[06i=;01]C2/0K4/Z06Y9:01XAbH806I89P0806U89`1XAbH0IdHU06M69@1XAbH0JTTX
06a;:P1]C2/906U;:@0306E=:`1SBbT0HDTW0080H4PV0140Hd/Y06E=:`1WCbd0M5<b071?;P1[BRT0
ITDT06A38P1VAB@0JDPW06]::@1]Cbd0Kdh]06i=;01_C2`0L4`/079;;0020799:`80LThZ0P1aCBT0
201`C2P0Kd/W06i:9P1^BRH0LT`U07==9P1fD2T0NE</0P1jE2d0201iDb`0N58[07I@;01gDBd0NE<_
07]E<@1lES80NeDa0P1jE300101fDb/0Me@/07MD;01gE2`207QE;@80NEH^201mERd807eH:`03089K
<P21FS40OUL^00<0O5D/00<0OUL^07mH;`1mF2h01`1mF2h8081K;P80OEd^00@0Oed_085L;`21G2l0
PU`_0P25G303081J;@<0PE/^0P22G2l407mH;`80OUL^0P1mERd807eG<0P0P5/^00/0OEX`07]H;P1i
ER`0N5D[07UF;01kF2h0OU/a07mL<P1iE2X0NUD[07aG;@0207iI;`0407eH;P1lEbd0NeH/07]F;0<0
O5T_1@1kF2h907eH;P0?07iI;`1oFS00P5/a07iI;`1kER`0N5<Y07IA9`1kF300NUL_07UF;P1hEBd0
Me@/07IC:`1eDRX0M54Y00<0N5<Y00<0NE@Z07YE:`1kER`00P1kER`207]A:`0407UB:`1hDR/0N58[
07IC:`80ME@[00P0NELY07ME:01dDRD0LTlU075>9P1aCRP0LDdY079>:P80N5D]00@0Me@/07IC:`1d
DBT0Le0X0P1bCbL407=@:0@0LTlW00@0MUH_07AD;@1aDBX0KdlX0P1^CRL0101_CbP0L50Y06m<9P1_
C2H4071=9`80LDhX0`1ZCRH00`1YCBD0J4`T06M;8`0206M;8`D0J4XV0`1YBbL00`1TB2<0IDTT06E9
900406E9900306A88`1XBBX0JDX[0080JT//00@0JDX[06M8:@1UARL0Hd@U201PBR<806958`P0ID@S
0`1SAR@206A79@<0IDPV2@1XCB80101TAR80ITPT06U;9`1/CRX206i@;080KDl[00P0JU8`06]A<01[
DBh0K50[06e?:@1_CbP0KddW06m>9@80LE4[00H0LU8[07=C:P1dEBT0MULY07MH:P1hFBX807]F:@80
MeP/00<0N5T]07UJ;P1jFbl00P1kG3001P1lGC40OU`^07iL;P1oGBl0P5h`085O<@80PV0b00<0Pf4c
089P<P22H3800P22H38208=Q<`80Q68d00<0Qf<c08QT=02:ISH00P2<J3P0102;IcL0RFDe08QT=02<
J3P208eY>@0308iZ>P2?Jc/0T6`l0080TFdm0P2DKSl209=]?P0<099/?@2AJc`0T6Xk091Z>`2FJST0
UV`j09M]>`2GKc`0Ug8n09Mc?`2FMD00UgI10P2IM40209Qc?`0409Mb?P2FLCd0UW4m09E`?0<0VgI2
0P2LMd<309ehA0030:5lA`2PNdH0WgY50080WWU400<0X7]60:5lA`2RODP00P2VODD20:MnAP040:Qo
A`2YP4P0ZX590:Z1B@80ZX5=00@0Zh9>0:b3C`2^QE40[hIB0P2`Qe<20:Z5D@<0ZhIB0`2/Qe<20:j:
EP<0[h]G0`2`S5P01`2`RUd0/8YK0;2:F`2`RU/0/8YI0;2;E`2`ReH00P2`Re@00`2`ReL0/HaH0;:=
F@020;>>FP030;:=F@2aS5P0/8]G00<0/HaH0`2`ReL20:n:EPP0/8YK00P0[XUB0:n:D`2aS5L0/hiJ
0;>=G02bS5d0/H]L0;2:G@P0/hiJ202fS5X80;F@G0<0/XeH0P2aS5L30;2;EPD0/hiJ0`2bSET20;B?
F`<0/hiJ0`2bSET30;B;E`<0/hYF0P2bRED80;>9E`P0/hYF00<0/XeF0;6<E@2_RU<00`2]R5400`2_
RU<0/8]D0:j9E@070:j9E@030:b8CP2]RDl0[hYC0080/HaG00<0/HaH0:n9F02^R5L0202aQeD0102^
QE40[hIB0:n6DP2_QU830;27D`030;68E02aQeD0/HME00L0/HME102_QU820:j5D@80[HA@202aR5@8
0:f7EP@0/8MC102_QU830:^6DP030:b7D`2]R5@0[XUE0080[XUE00T0Z8=>0:V4C`2ZQE00[8MB0:f8
D`2_RUD0/8]F0;6<E`2[QU800P2/Qe<00`2]R5@0[XUE0:n:EP020;2;E`060;6<E`2_RUD0[8MB0:Z5
D02XPdh0ZHA?0P2ZQE080:f3D@80Zh9>00@0[8=?0:f4D02]Q500[XEA0P2_QU820:N2C@040:R3CP2Y
Q4l0ZhIA0:b7DP80[HQC00P0[XUB0:b7D02ZQE00ZHA@0:R2D@2XPU<0ZH=D0:Z4E`P0ZhIB0`2^Q582
0:f3D@<0[89@0`2[PTh30:b3C`80[HA@0`2_QU030:j5C`80[HA>0P2ZPDd30:^2CP<0[8=?0P2ZP500
102[PE40[89B0:j4E02_QED20;26EP030:j5D@2]Q500[HA@0080[8=?0P2[PTh20:Z1C@<0ZH1<00<0
ZX5=0:^2CP2/Pdl00P2/Pdl80:f5B0030:j4DP2]Pe40[89@0080Zh5?00<0[H=A0:n5D`2`QU@00`2[
QEP20:Z4E`<0ZH=F0`2/PU020:f3D@<0[XAB0P2aR5001P2`Qe40[hIB0:j5D@2/PU00[89B0:^1D@P0
[XEA00@0ZGm=0:Z0CP2ZP4h0Zh5?0P2/PU020:f3D@040:j9E02]R5<0[HQC0:f8D`80[8MB0P2[QU42
0:R4BP060:V5B`2[Qdd0[8Q>0:f9C`2^RU00[h]A202^QE420:f4D0<0[8=?0`2[PTh20:f4C0040:b3
C@2/Pdl0[8=?0:^1C`80Zh5A0P2ZPDd0102[PTh0[8=?0:j5D@2_QU820;27D`<0ZXE@0P2YQ4l20:R3
CP030:N2C@2[PTh0Zh9>00X0Zh9>102ZPDd80:^2CP030:b3C@2[PT`0ZH1:00<0Z7m900H0ZX5;0:b3
C@2]Q4h0[XEA0:f4D02[PTh20:Z1C@030:^2CP2]Q500[XEA00P0[8=?0`2^Q5820:f3D@<0[89@00H0
[hEC0:j4DP2^Q580[89@0:^1C`2ZP4h20:UoC@P0Zh9<0`2[PTh30:b3C`@0[HA@0`2/Pdl30:^2CP05
0:f4D02/Pdl0[8=?0:^2CP2ZPDd00P2YP4`01`2XOd/0Yh=A0:R2D@2XPdl0ZX9>0:^2CP2/PD`00P2^
PDX80:V0BP<0ZH1<00<0ZX5=0:^2CP2/Pdl00P2/Pdl20:j5D@030:f4D02/Pdl0Zh9>0080ZX5=00@0
ZH1<0:Z1B`2[PT`0[HA>0P2^QDl02@2/Pdd0ZX5;0:V0BP2VODT0Z7m;0:^2CP2]Q500[hIB0:j5D@02
0:f4D0<0YX5<00<0Yh9=0:R3CP2YQ4l00P2YQ4l20:Z5D0<0ZHA?0`2XPdh0202ZPDd0[8=?0:j5D@2`
Qe<0[hIB0:b3C`2XOd/0YWe90P2/Pdl20:^2CP80ZX5=0P2YP4`01@2ZPDd0ZH1<0:QoB`2WOTX0Z7m;
0080ZH1<00<0Zh9>0:b3C`2[PTh01`2[PTh80:^1C`80Ygi:102XOd/20:V0C0<0Ygi:0P2XOd/30:V0
C080Yh9>00@0YX5=0:F0C02UP4`0Y7m;0P2SOTX20:V4C`80Z8=>0P2WPTd20:J1C0P0Z7m;0`2SOTT3
0:AoBP80YH1;0P2[PT`20:Z1B`040:V0BP2XOdT0Z7m90:MnB080Yh9>00h0YX5=0:AoB`2SOTX0XWe9
0:5lB02PNdL0ZWmD0:QmD02VNdh0Y7Y:0:=iA`2TNdL0YGa60:ImA`80Z7i<00@0YWa:0:AjB02RN4H0
X7I40P2NM4880:1g@`030:5nB02PODL0WW]50080WGY400/0WW]50:1mA`2QOTP0ZWa80:UkA`2WO4T0
YWa:0:AlB`2RO4d0XG]<0:1kCP0209ehA080W7M300L0WWU50:1kA`2RODT0Y7m;0:9hAP2QMdD0WgE3
0080WWA200<0X7I40:9hAP2SNDL00`2RODP00`2QO4L0X7]609mjA@0209mjA@80XGa700@0X7]609mj
A@2MN4<0W7M2102KMT4309ag@P0709]f@@2IM3l0UW4l09E`>`2KMSl0VWDn09Ud?@0209Qc?00309Ye
?P2KMSl0W7M00080X7M100<0X7M309me@`2OMDD00P2OM4L00`2OM4T0VgI209]f@P0609]f@PP0WGM8
0P2LMd<409]f@P80VWE100P0VgA;09]dB@2JM4L0VWA309Ud?`2HLc`0V7@j09Mc=`<0WW<n0P2OM3l3
0:1e@0080:1jC@2OND`0WGM:09afB@2KMDP0W7I909egBP2NN4/309ihBB_ooooo000Zooooo`08095W
=`2@ISH0Sf@g08iS>02>HcT0Sf<l091T?@2AID0308iR>`<0SF4j0P2<H3T208eT>00308iS>02@HcT0
TV<i0080U6<j00<0UV8j091T=`2@I3L00`2AICP3099V>@<0TfHm0`2DIch209EX?`0;09IS>02EI3T0
UfHk09MX?02FJSd0U6Tl099Y>`2AJ3X0UV`j09E[>@2CJCL00`2AIcD00`2BJ3H0TfTg09EY?00709EY
?00409=W>P2BIST0TVHi099V>@@0TFDh2@2EJC`809EY>0<0UVXi0P2GJcX309Q/>`@0Uf/j102FJST0
202KIS`0VVLl09UX?@2IJSh0Uf`o09M^@02FL440UG51202HK3l00`2HKCX0VFhk09U^>`0509U^>`03
09a`?`2KKch0VFdl0080V6`k00<0VFdl09]_?P2LL3l00P2KKch209a`?`80WG500P2NLT4209aa?P80
WG8o00@0WW=009md@@2OM440WgA1202LLcl309eb?`80WW=00`2OM44809me@`80X7E21P2OM44809me
A@80YGY700@0Y7U60:=hA@2RMd@0XGI30P2PMD820:=h@@040:9g@P2RMd@0XWM40:5eA080XGE6202S
N4D20:5eA080X7A300L0XGE40:9fA@2TN4L0YGU80:IkB02UNTL0XgQ50080XWM40P2SN4D00`2UNTL0
YW]80:AiAP070:AiAP80Y7]300@0Y7]50:=jAP2SNTH0XWQ60P2RN4P20:QmB0030:MlB@2VNTT0YGU:
0080Y7Q;00D0XgI<0:=iA`2RN4H0X7I409id@P0209ab@00309ec@@2NM480W7900080W7900P2KLCl3
09Y`?P0:09Ac?@2CLSd0UG0l09M_?P2HK3l0VFY009UX@02KId00T6Dj095V>`<0TVLl00<0T6Dj08mT
>@2=HSL0102:I3L208US=P80R68e00P0QF0c08IQ=026HC@0Qf8e08IQ=024Gc80PUd`081K;PP0Peha
00H0PE/d081J<`20FS<0OeTb07iH<@1mEc0207aF;`0307aJ;@1kFB`0NELZ00<0MeDX00<0NELZ07YH
:`1hEBl00P1jEc402@1fDbd0LDhX071=9`1cD2X0Me@^07ED<@1cDRl0LE0]06m>:`0306i=:P0;06m>
:`1`Cb`0KTdZ06a;:01[BRL0JTTV06]:9`1/BbP0KD`Y06]::@1/BbX00`1]C2/00`1[BRT0JTTX06Q7
9P0806I89P0306Y9:01YB2L0J4LV0080IdHU00<0JDPW06]::@1/BbX02@1XBRP206A::@<0HdTX00`0
ID/Z06I<:`1WCB`0L4l/06i=:P1[BRL0J4LT06M68`1XAb@0JTTV06]:9`1]Cb/206m>:`03071>:`1`
C2X0LT/Z0080LdXZ0P1bCRX3075=:@<0L4`X00@0LddV07A>9`1gDBX0NE</0P1jE2d01P1iDb`0N58[
07I@;01hDRh0NU@`07]E<@80O5Hb00<0NeDa07YD<01gE2`00P1gE2`207QE;@<0NEH^201mERd807iI
;008089K<P21FS40OeP_07eF;@1lEB`0OEH]07iG;P1oF2l807eH;PP0P5/^0P1lG2d0101nG2h0PE`_
085L;`23GC0208IM<@<0P5X]0`21Fbh2089L;`80OUL^1P1oF2l807iI;`P0P5/^0P1kF2h307YG;@06
07aI;`1mFS00OU/a07UD:P1kER`0O5L]0`1nFBl00`1mF2h0O5L]07aG;@0207aI;`H0NeP^2@1mF2h3
07iI;`0:07eH;P1kER`0NUD[07UD:P1kF300NUL_07UF;P1hEBd0Me@/07IC:`80ME8Z0P1hDbT207UD
:P0407YE:`1kER`0NeH/07]F;080Ne4[00@0NE8[07QB:`1hDR/0MU<[0P1eE2/0201hERP0MeDX07EC
9P1cD2H0LTlW079?:@1cCb/0M50/0P1hEBd01P1gE2`0MU<[07EB:P1dDBT0Le0X079?9`D0Le0X0`1b
CbL0101eEBh0M5@]075A:P1_CbP206i>9`0306m?:01`D2T0L4dW00D0L4dW0P1aCRP00`1[CbL0JThV
06Y>9P0206U=9@80J4`T00@0Id/S06Q:9P1XBRH0J4XV1@1YBbL806E9900806M8:@1XBBX0JDX[06U:
:`1XBBX0ITLX06A59P1R@b@8061:8`P0HD@R201UA2<306A79@80IDPV0`1VBBL906Q<900406A68P1V
B2@0JD/W06]=:@<0KDl[0140K4hZ06UA;`1ZD2l0JU0]06a@:`1]CbT0KdlX071>:01`CbH0L50Z075A
:`1bDR/0Le<Z07AE:@1fEbT0MePZ07QI:P0807QF:@0607IG:`1gF2`0MeP/07QI;@1iFRh0NU/_0P1k
G3001P1mFbd0OU`^07iL;P1oGBl0P5h`085O<@80PV0b00@0PEla089P<P22H380PV0b0P23HC<208AR
=00308MS<`28I3@0RVHf0080RfLg00<0RVHf08UU=@28I3@00P29ICD00`2:ISH0RfLg08aX>00208eY
>@0308iZ>P2CKCh0Tfdn00<0TV`m0`2AJc`01P2FJST0UV`j09M]>`2GKc`0Ug8n09Mc?`80UWE00P2I
M40209Qc?`0409Mb?P2FLCd0UW4m09Ia?@<0VgI20P2LMd<309ehA0030:5lA`2PNdH0WgY50080WWU4
00@0WgY50:5lA`2RODP0YGa40P2VODD00`2WOTH0Z7m70:V0B0020:Z1B@80ZX5=00H0Zh9>0:b3C`2]
Q500[XEA0:n6DP2`Qe<30:Z5D@80ZhIB0`2/Qe<20:j:EP<0[h]G0`2`S5P01`2`RUd0/8YK0;2:F`2`
RU/0/8YI0;2;E`2`ReH00P2`Re@00`2_RUH0/HaH0;:=F@020;>>FP030;:=F@2aS5P0[hYF00<0/HaH
0`2`ReL20:n:EPP0/8YK00P0[hYC0;2;E02bSEP0]8mK0;B>G@2cSEh0/XaM0;6;GPP0/hiJ202fS5X8
0;B?F`80/hiI0`2bSEP30;6<E`H0/hiJ0P2bSET20;B?F`<0/hiJ0`2bSET30;B;E`<0/hYF0P2bRED0
1@2eReT0]8YH0;B:F02dRUP0/hUG00<0/XQF202cRUH00`2bSEH0/HaE0:n:D`020:f8D@030:j9DP2_
RU<0/8]D00P0[XUE00<0[HU?0:j:D02`Re@00P2aS5L00`2`ReL0[XQG0:f7EP080;67E@H0/8MC0P2_
QU890;26E0040;27D`2_QU80[hIB0:n6DP80[XEA0P2]Q5080;68E0P0[HMF102_QU840;27D`<0ZhIB
00<0[8MC0:f8E02]R5@00P2^RED0202XPdh0ZHA?0:Z5D02/Qe80[HQC0:n:E@2`ReH0/HaG0`2]R5@3
0:j9E@80[hYF00@0/8]F0:j9E02/Qe80ZXE@0P2YQ4l20:Z5D0P0[H=A00<0Zh9>0:b3C`2/Pdl00P2]
Q5020:j5D@060:n6DP2WPTd0Z8=>0:R3CP2YQ4l0ZhIA0P2/Qe802@2]R5<0[HQA0:b7D02ZQE00Z8=?
0:R2D@2XPU<0ZH=D0:Z4E`080:^6DP<0[XAB0`2]Pe420:b2D0<0Zh9>0P2/Pdl30:f4D0<0[hI@0`2^
QDl20:f4CP030:f4D02/Pdl0[8=?00D0[8=?0P2ZP5001`2[PE40[89B0:f3D`2^Q5@0[hEE0;26EP2^
QE400P2]Q5030:b3C`80Zh9>00<0ZX5=0:V0C02YP4`00P2ZPDd0102[PTh0[8=?0:b3C`2/Pdl80:f5
BP030:j4DP2]Pe40[89@0080Zh5?00<0[H=A0:n5D`2`QU@00`2[QEH20:Z4E@<0ZH=D0`2/PU030:f3
D@80[XAB00P0/HQ@0;27C`2`Qe40[hIB0:f4D02/PU00[89B0:^1D@P0[XEA0`2[PDl00`2/PU00[H=A
0:f3D@020:j4DP@0[HQC0P2/Qe820:^6D@050:V5B`2ZQT`0ZXI<0:^7C@2/R4h00P2]RDl00`2^RU00
[XEA0:j5D@060:j5D@80[HA@0`2/Pdl30:^2CP80[8=;00@0[8==0:b3C`2/Pdl0[89@0P2/PU801@2Z
PDd0Zh9>0:^2CP2/Pdl0[XEA0080[hIB00<0/8MC0:Z5D02ZQE000`2YQ4l20:R3CP030:N2C@2[PTh0
Zh9>00/0Zh9>0`2ZPDd80:b3C`030:b3C@2[PT`0ZX5;00<0ZH1:00H0ZX5;0:b3C@2]Q4h0[XEA0:f4
D02[PTh20:Z1C@030:^2CP2]Q500[XEA00P0[8=?202]Pe401P2_QE<0[XAB0:f3D@2/PU00Zh5?0:Z0
CP80ZGm=202[PT`30:^2CP80[8=?1@2]Q5030:b3C`<0Zh9>0P2/Pdl30:^2CP<0ZX5=00H0Yh=A0:R2
D@2XPdl0ZX9>0:^2CP2/PD`20:j1BPP0ZH1:0P2YP4`20:Z1C@040:^2CP2/Pdl0[8=?0:b3C`80[HA@
0`2/Pdl30:^2CP030:Z1B`2[PT`0[HA>0080[XE?00L0[8==0:^2C02YP4X0Ygi:0:V0C02[PTh0[HA@
0080[XEA0P2]Q5020:J1C080Yh9=00@0Z8=>0:V4C`2YQ4l0ZHA?0P2ZQE030:V4C`<0Z8=>00P0ZH1<
0:^2CP2^QE40/8MC0:n6DP2/Pdl0ZH1<0:ImB@80[8=?0P2[PTh20:Z1C@80ZH1<00D0ZX5=0:V0C02X
Od/0Ygi:0:QoB`020:V0C0030:^2CP2/Pdl0Zh9>00L0Zh9>202[PDl60:QoB`80ZH1<0`2WOTX20:Qo
B`<0ZH1<00<0Yh9>0:J1C@2VPDd00P2UP4`20:AoB`030:=nBP2YQ4l0ZHA?0080Z8=>0P2WPTd20:J1
C0P0Z7m;0`2SOTT30:AoBP80YH1;00<0Zh9<0:Z1B`2ZPD/00P2YP4X20:QoB@040:MnB02VPDd0YX5=
0:F0C080Y7m;00/0Xgi:0:9mB@2RODT0ZGiC0:QmD02VNdh0Y7Y:0:=iA`2TNdL0YGa60:ImA`020:Mm
B`040:IlBP2TNTP0XgU70:5gA@80X7I4202QN4@00`2RODP0XGa709mjA@0209iiA00309mjA@2QO4L0
XWe80080ZG]700P0Yga90:IlBP2TO4/0XWa=0:5kC02PNdh0WWU509ehA080W7M300L0WWU50:1kA`2R
ODT0Xgi:0:9hAP2QMdD0X7I40080WgE300<0X7I40:9hAP2SNDL00P2QO4L20:1kAP0509mjA@2NND@0
WWU409iiA02PNdH00P2ONTD00`2NND@0W7M209]f@@0209]f@@0309Ye@02KMT40W7M20080WGQ300H0
VgI109Ud?`2GLSd0UW4l09Ye?P2IM3d209Qc?00409Ud?@2KMSl0WGQ109ii@P80X7M100<0X7M309me
@`2OMDD00P2OM4L00`2NLdP0VgI209]f@P0609]f@PP0W7I70P2LMd<609]f@P80W7E:00@0VgE809]e
A02JMD40VWDn0P2IMC/209ed?P<0WWDo0`2OMT000`2ONDX0WWQ909egB00209afA`0309egB02NN4T0
X7Y;00<0WWQ9:oooool002[ooooo00P0SfDe091V=P2AIST0TVLl099W?@2AICh0T6@m08mS?P80SF4j
0`2<H3T308]O>080SF@h00<0SV<h091S>@2BHcT00P2DHcX00`2FHSX0T6@g091T=`03095U>0<0TVHi
0`2CIS`309AW?@80UFPn00H0UV<h09ET>@2GIS/0UfPl09EY?02DJC`2099Y>`0309I/>P2EJcT0TfTg
00<0TFLe00<0TVPf09=Y=`2EJC`01`2EJC`0102AICP0TVHi099V>@2BIST409=W>PT0UFTl202EJCP2
09AX=`80UFTh0P2FJST:09M[>P0809YW?02IJ3d0VFPm09UZ?P2HK3l0V6e009M^@02HKd4809Q/?`80
Uf`i0P2HKCX01`2IKS/0VVll09]`?@2KL3d0W70o09]_?P2JKSd00P2IKC`00`2JKSd0Vfln09a`?`02
09]_?P80W70o0P2MLD0209ib@@<0WG8o0`2NLd0209md@@0509mf@P2NMD40WWE109ed@02LLcl00P2K
LSh00`2JLCd0WG8o09eb?`0209ic@0<0WgA100<0X7E209me@`2OMD<01P2OMD<309md@@D0X7E2202O
MD<80:9gA080XGHo00@0XWM20:9gA02RMd@0XgM60P2SMdP80:=hA@060:1d@`2QMD@0XWI50:=gAP2T
N4L0XgM60P2RMTD20:EjA`D0XgQ50P2UNTL80:AiAP80Y7]300@0Y7]50:=jAP2SNTH0XWQ60P2RN4P2
0:MlA`030:IkB02UNDP0Y7Q90080XgM:00D0XWE;0:9hAP2QMdD0WgE309ec@@0209ab@00309ec@@2N
M480W79000<0Vg4o0P2JL3h209U_?@0609Aa>`2EL3`0U6lk09I^?@2FJch0UVTo0P2GIcl2095V>`<0
TfPm00<0TFHk08mT>@2>HcP00`2:I3L208US=P<0R68e00P0Q5lb08EP<`26HC@0QV4d08EP<`23GS40
PE`_07mJ;@P0PUd`0P20FS<0101oFC80OUPa07eG<01mEc0207aF;`0307UF;01hEB/0MU<Y00<0ME8X
0P1fDbT0301eDR`0N5D_07UF<01fDbd0LTlY075>:01dDB/0N5D_07=B;`1bDBh0L4l/06m>:`@0KTdZ
00<0Kdh[06i=:P1/BbP00`1[BRL206a;:00806Y9:01[BRT0K4/Z06e<:`1/BbX0JdXY06U89`1XAbH8
06I89P0306a;:P1[BRT0JDPW0080IdHU00<0J4LV06U89`1ZBBP02@1WBBL01@1UB2H0ITTW06M::01X
BbT0JD`Z0080J4/Y00<0IdXX06a;:01/BbP01P1[BRL01P1]Cb/0Kdh[06m>:`1`CR/0LDd[07=<:`80
M4/[0P1aCRP3079?:@<0Le0Z00@0MDlX07I@:@1gDBX0NE</0`1jE2d02P1iDb`0N58]07UC;P1kEC00
O5Ha07eG<P1lES40NeD`07YD;`1iDb`307YD;@80NeD^0P1lERl807iG;PP0OUT/00<0PU/b085J<@1o
F2l00`1nEbh00`1oF2l0P5T`07iI;`0707iI;`P0P5/^0P1kFb`0101mFbd0P5/^089M<024GS4208MN
<P<0P5X]0`21Fbh2089L;`0507eF;@1nEbh0OUL^07mH;`20FC000P21FS400`22Fc80P5/a081K<@06
081K<@P0P5/^00<0NEH/07YG;@1lFBl00`1mFS0207aI;`0307YE:`1kER`0OEP^00<0OeX`0`1mF2h8
07]H;PP0OEP^00<0OUT_07eH;P1lEbd00P1kER`00`1lEbd0OEP^07iI;`0207YG;`80NEH^00@0N5D]
07MD;01fDb/0MU<[0`1iE2X207YE:`<0NeH/0P1lDR`0101jDb`0NE</07UC;01gE2`207IE;00807QF
:01gEBP0MU@W07EB:01dDBT0ME8/07MC;`1hE30207QE;@0307MD;01fDb/0ME8Z0080M54Y00@0Le0X
07AA:@1dDBT0M54Y0P1cD2P3079?9`0407AD;@1cDb`0LE4Z071@:@@0KdlX1@1aCRP3071=9`80K4lW
0P1[CRH406Y=9@0306Y<:01YBbL0JD/W00D0JD/W0`1VBRD206E990<0ITXU00P0ITPV06M99`1XBRP0
J4XX06M99`1UAbD0HdDS06538@P0HDTS201P@b4806=58`0406A79@1UB2H0IDPV06E89P80ITTW0P1W
BRP906M;8`0406E78`1VB2@0J4XV06Y<:0@0K4hZ0100ITh/06M=;01XCR/0JdlZ06e?:@1_CbP0LDlY
075@9`1_CbT0L50Z075A:P1cDbX0M5DY07EF:01fEbT0MULX201gE2X207IG:`0307MH;01hFBd0NEX^
0080NU/_00H0Ne``07eK;@1mFbd0OU`^07mM;`20GS02085O<@04089P<P21Gc40PEla085O<@80PV0b
0`23HC<00`27Hc<0R6@d08UU=@0208YV=P0408UU=@28I3@0Qf<c08IR<P80Qf<c00<0R6@d08UU=@2:
ISH00P2;IcL2091Z>`<0TF/l0`2BK3d01P2FJST0UF/i09I/>P2GKc`0UW4m09Mc?`80UWE00`2HLcl3
09Mb?P80UW4m0`2JMD4209]f@P<0W7M300P0X7]609mjA@2NND@0WGQ309iiA02ONTD0XGa70:=nB@80
YGa600<0YWe70:MnB02XOdT00P2YP4X01P2ZPD/0ZX5=0:Z1C@2[PTh0[8=?0:f4D080[XEA00<0[hIB
0:V4D02ZQE400P2ZQE420:^6DP80[8MC0P2^RUH30:n;E`<0/8aH00L0/8YM0;2:F`2`RU/0/8YK0;2:
F@2`ReL0/8]F0080/8]D00<0[hYF0;2;E`2bSET00P2cSUX00`2bSET0/8]G0:n:EP030;6<F0<0/8]G
0P2_RUH80;6;G0080;2;E02bSEH0]8mJ0;F@G02fT5l0]HmP0;B>G`2cSF080;>>FPP0]XaJ202bSET3
0;B?FP80/hiI0`2bSEP80;>>FP80]8mK0`2cSUX30;:=F@<0]8]G0`2cRUH20;:9E@060;N=F`2fS5X0
]H]I0;B:F02cREL0/HME0P2`QU@80;>:EP80/HaG00<0[hYE0:j9E02]R5<00P2^RE@00`2_RUD0[XUE
0:j9E@060:j9E@80/8aB00H0/HaE0;6<E`2`ReH0[XUE0:f7EP2/QUD80;67E@80/XUE00@0/HQD0;27
D`2`Qe<0[hIB0P2^QE490:n5D`<0/8MC0P2_QU830:j5D@P0/HQD202]R5@01@2]Q500[XEA0:j5D@2_
QU80/8MC0080/HQD00@0/XUE0:^6DP2[QU80ZhIB0P2/Qe<30:f8E0080:V4C`2ZQE00ZhIA0:b7DP2]
R5<0[XUD0:n:E@2`ReH20:n:EP<0[XUE0`2]R5@00`2_RUD0[XUD0:b7DP020:Z5D0030:V4C`2ZQE00
ZXE@00P0[H=A0`2/Pdl20:f4D0<0[XEA0P2XPdh0102YQ4l0ZXE@0:Z5D02[QU420:b7DP080:b7D02[
QTl0ZHA?0:R3C`2WPE00Z89C0:V3E02ZQ5L80:^6DP80[hEC0P2^Q5830:f3D@030:b2D02[PTh0Zh9>
0080[8=?0`2]Q500102^QE40[hI@0:n6D02_QU030:j5C`80[HA>0P2`Qe<0102_QU80[XEA0:f4D02]
Q5020:b3C`80ZX1>00<0Zh5?0:b2D02]Pe400P2^Q5800`2_QE<0[HA@0:f4D0030:f4D080[8=?0P2[
PTh30:Z1C@80Zh9>0`2/Pdl80:f5BP030:j4DP2]Pe40[89@0080Zh5?00<0[H=A0:n5D`2`QU@00`2[
QEH20:Z4E@<0ZH=D0P2[PDl20:b2D0<0[H=A00T0[XAB0;27C`2`Qdl0[hI@0:j5D@2]Q500[89@0:b2
DP2[PE40202^QE430:f3D@<0[XAB0P2_QE<30:f8D`80[8MB0`2[QU480:b7D0P0[XEA0P2]Q5030:b3
C`<0Zh9>0P2ZPDT0102[PT`0[8=?0:f4D02^Q5820:j4E080Zh9>00@0[8=?0:f4D02]Q500[XEA0P2_
QU820:Z5D0030:V4C`2XPdh0Z8=>00<0Z8=>402[PTh80:j5D@80[8==00<0Zh9<0:Z1B`2ZPD/00P2Z
PD/01@2[PT`0[8==0:f4D02/Pdl0Zh9>0080ZX5=00<0Zh9>0:b3C`2]Q500202/Pdl01@2ZP4h0Zh5?
0:^1C`2/PU00[H=A0080[XAB00H0[hEC0:j4DP2^Q580[H=A0:b2D02[PDl20:Z0CP030:UoC@2[PT`0
Zh9<00H0Zh9<0P2[PTh20:b3C`<0[HA@00<0[XEA0:f4D02]Q5000`2/Pdl30:^2CP80ZX5=0`2[PTh3
0:b3C`060:N3D@2XPU40Z8=?0:Z2CP2[PTh0[85<0P2^PDX80:Z1B`<0ZX5=0P2[PTh30:b3C`<0Zh9>
0`2/Pdl20:f4D0030:Z1B`2[PT`0[8==0080[HA>00H0[8==0:^2C02[PT`0Z7m;0:V0C02[PTh20:f4
D0030:j5D@2]Q500[HA@00<0Yh9=0P2XPdh30:V4C`80ZXE@0`2YQ4l30:R3CP030:V0C02[PTh0[HA@
0080[XEA00<0[8=?0:V0C02WOTX00P2/Pdl20:^2CP80ZX5=0P2YP4`01@2ZPDd0ZH1<0:QoB`2WOTX0
Z7m;0080ZH1<00<0Zh9>0:b3C`2[PTh01`2[PTh80:^1C`D0ZH1<0`2XOd/30:MnBP80Z7m;0`2YP4`3
0:J1C@80YH1<0`2TOd/20:V4C`80Z8=>0P2WPTd20:J1C0P0Z7m;0`2SOTT30:AoBP80YH1;0P2ZPDd2
0:V0C0@0Z7m;0P2UP4`60:AoB`060:QmDP2XOE00YW]>0:EkB`2UNdT0YGa80P2VODL30:EkB@80Y7Y8
0`2SNDL80:AkA`030:9mB02QO4L0X7]60080WgY500<0X7]60:5lA`2RODP00P2YNdL00`2WO4T0YG]9
0:AlB`020:5kC0090:1kCP2NNDD0WWU509ehA02LMd<0WGQ409mjAP2QO4P0Xgi:0080XWQ600L0XGM5
0:1fA02PMT@0X7I40:5gA@2RN4H0WgY500<0WWU40`2MN4<01P2LMd80WWU409eh@`2MN4<0W7M209]f
@@<0VWE000<0VG@o09]f@@2LMd800P2MN4<0102LMd80VWE009Qc?P2GLSd209Ud?`80V7<n00T0VWE0
09ag@P2NND@0X7]60:5h@P2PMd40X7M30:1fA02OMDD00P2NLdH00`2NLdP0VgI209]f@P0609]f@PP0
VWA50`2KMT8509ag@`80WGM:00@0WGM809egAP2LMd<0W7M20P2KMSl0102MM400WWE109ie@@2NMD42
09mf@P80X7M300P0WGM809afA`2LMTL0VgE609afA`2NN4T0X7Y;0:5kC0<0WWQ9:oooool002[ooooo
00P0SV@d091V=P2BIcX0U6Tn09AY?`2BISl0T6@m08iR?@80S60i0P2;GcP408YN=`80SF@h00<0SV<h
091S>@2BHcT00P2DHcX00`2FHSX0T6@g091T=`03095U>0<0TVHi0`2CIcX309AX>`80UFTl00H0Uf@i
09IU>P2FICX0UVLk09AX>`2DJC`209=Z?00309I/>P2EJcT0TfTg00<0TFLe00<0TVPf09=Y=`2EJC`0
1`2EJC`2095U>003099V>@2CIcX0U6Pk0080UFTl00<0UVXm09EY>P2EJCX01`2EJCX809EY>080TfLf
0P2DJ3L309EY>080UVXi102GJcX309Q/>`80V6Tm00@0VFXn09M[?P2HK3l0V6`o0P2HKD0809Q/?`06
09EZ=`2FJcP0Uf`i09Q]>P2IKS/0Vg0m0P2LLCh:09]_?P80W70o0P2MLD0209ib@@80WG8o1P2NLd00
202QN4@0X7M309mf@P2NMD40WGA009ac?`2KLSh0VW4m0`2NLd0309md@@80X7E2202OMD<209md@@@0
X7E20P2QMT<809mf@P80X7E20P2QMT<0302RMd@0XgQ50:=hA@2TNDH0X7Dn0:5f?`2QMT40XWM40:=h
A@2TN4L0Y7Q90:EiBPP0XgQ500P0Wg=20:5eA02TN4L0YGU80:IjB@2TN4L0XWI50:1d@a40Y7U60P2T
Nd<0102TNdD0XgY60:=jAP2RN4H20:9hB080YW]600`0YGY70:AhA`2SMdP0XWI90:5eB02QM4X0XGM5
09me@`2MLd40W79009]a?`2LLT0209ec@@0409]a?`2JL3h0VW0n09Y`?P80VFlm0P2HKS`02P2FKSX0
UVhk09E]>P2EJc/0U6Tl09=X?@2DIch0TfHm095V>`2BIc`309=X?@03095V>`2@ICX0SV<h0080RV@g
0P29HcH208QR=@80Qf4d00P0Peha08AO<P25H3<0QF0c08AO<P22GC00P5/^07iI;0P0PE`_0P20FS<0
101oFC80OUPa07eG<01lERl207]E;P0407IC:@1eDRP0M54W07AA9`@0Le0V00/0LTlY07EB;01gE2h0
MU<]079?:@1aCRP0M54[07MD;P1aD2d0L4l/06m>:`0206i=:PD0KD`Y0P1/BbP406]:9`0806Y9:01[
BRT0K4/Z06e<:`1/BbX0JdXY06U89`1WARD806I89P0406e<:`1/BbX0JTTX06Q79P80IdHU00<0J4LV
06U89`1VB2H0201VB2H00`1TB2<0ITXU06U=:00206]?:P0A06Y>:@1XC2L0ITXU06Q88P1ZBR@0K4`V
06i>:01_CbT0KThX06e=9`1/C2H0KDlY06m?:@1`D2X0LDlZ079>:P1dCRX00P1fCR/2079?9`0407=@
:01dDBT0M54Y07EB:P80MU<[0P1gDBX00`1hDR/0NE</07YD;@0307YD;@0307UC;01jE2d0O5H_0080
OEL`00@0O5H_07]E;P1jE2d0Ne@]0`1lEBh207eF;`80OUL`201oF2l807mJ;@80PEXa1P20FC0807iI
;`P0PE`_00P0NUX[07]K;01mFbd0P5/^089M<024GS40Qehb08QO<`<0P5X]0`21Fbh2089L;`80OEH]
00H0OUL^081I<021FS40PU/b08=L<`24GC@8085L<0P0P5/^00<0N5D[07YG;@1mFS000P1oG3801P1n
Fc40O5T_07YG;@1kER`0O5L]07iI;`80P5/a00D0OeX`07iI;`1mF2h0OEP^07YG;@0407]H;P<0O5T_
201mF2h00`1oFS00OEP^07]F;00207YE:`0307aG;@1oFS00PE`b0080NUL_0P1iERh207QE;@80Me@/
101jEB/407]F;080O58/00@0NU</07UC;01iDb`0Me@/0P1fEB`02@1iEbT0N5HY07ID9`1fDbT0MU<[
07QE;`1iEC40NeLc07QE;@0207MD;080MU<[0P1eDRX01P1dDBT0MU<[07EB:P1eDRX0M54Y07=@:080
LTlW00@0LDhV07=C;01bDR/0LE4Z0P1`D2T306m?:080LTlY101aCRP2071=9`@0KThW101]CBH306]=
:@@0JT`X00@0JD/W06Q<9`1WBbH0ITXU0P1UBB@00`1VBRD0Id/V06Q<9`0206I89080IdTU00@0ITPT
06A68P1RA200HD<O201SBB@806138@P0HTDS0`1UB2H306I99`80IdXX2@1VBR<01@1UAb<0ITPT06M9
9@1YBbL0JT`X00<0JddY00d0I4`Z06E;:P1VC2T0JThY06a>:01_CbP0LDlY079A:01]CBL0KdlY075A
:P1cDbX0M5DY0080MEHX00<0MEHW07ED:@1eE2T01P1eE2T207EF:P0307IG:`1gF2`0N5T]0080NEX^
00H0NU/_07aJ;01lFR`0OE/]07iL;P1oGBl2081N<0@0PEla0`22H38208=Q<`D0R6@d0P27Hc<01`26
HS80Qf<c08MS<`28I3@0RFDe08YV=P2;IcL00P2<J3P208iX>@0408mY>P2@JS/0TF/l095[?080TV`m
00P0UFTh09E[>@2FK3X0UVhk09Ia?@2FLSh0UG@o09Ie@080V7<o1P2GLSh209Ud@0<0VWE10`2KMT80
202ONTD0WWU409eh@`2MN4<0WWU409mjA@2QO4L0Xgi90P2UO4P0102VODT0Ygi:0:MnBP2XOd/20:V0
C0030:Z1C@2[PTh0Zh9>0080[8=?0P2]Q5000`2^QE40ZHA@0:V4D0030:Z5D@<0ZhIB0P2^RUH30:n;
E`<0/8aH00L0/8YM0;2:F`2`RU/0/8YK0;2:F@2`ReL0/8]F0080/8]D00<0[hYF0;2;E`2aS5P00P2b
SET00`2aS5P0/8]G0:n:EP030;6<F0<0/8]G0P2_RUH80;6;G0080;:=EP2cSUL0]I1K0;JAG@2gTF00
]Y1Q0;F?H02dSV480;>>FPP0]XaJ202aS5P20;F@F`80]8mJ0`2cSUT0102bSEP0/XeI0;:=F@2bSET4
0;>>FP<0]8mK0`2cSUX30;:=F@<0]8]G0`2cRUH20;:9E@060;R>G02gSE/0]XaJ0;B:F02bR5H0/HME
0P2_QE<80;>:EP040;6<F02`ReL0/8]G0:n:EP@0[XUE202_RUH20;:>E0060;6<E@2`ReH0[hYE0:f8
E02/QUD0ZhED202aQeD0202dReL0/hYF0;:9E@2aR5@0/8MC0:n6DP2^QE40[HA@2@2^Q5830;27D`<0
[hIB0P2^QE480;68E0P0[HQC0P2]Q500102^QE40[hIB0;27D`2aR5@20;:9E@@0ZhIB102/Qe<20:Z5
D0040:^6D@2/Qe80[HQC0:j9E080[hYE0P2`ReL00`2_RUH0[XUE0:f8E0020:b7D`050:^6DP2]R5<0
[HQC0:b7DP2[QU40102ZQE080:f3D@P0[HA@00<0Z8=>0:V4C`2YQ4l00P2ZQE020:^6D@090:b7DP2[
QTl0ZXE>0:R3CP2WPTh0Yh5@0:R2D`2YPe@0ZXAG00P0ZXEA0`2_QE<20:j4DP<0[H=A0`2/Pdl30:f4
D080[XEA0`2_QU030:j5C`80[HA>0P2bRED01`2aR5@0[hIB0:j5D@2]Q500[8=?0:^2CP2ZPDd00P2[
PTh20:b3C`80[HA@00<0[XEA0:f4D02]Q5001@2]Q5020:b3C`@0Zh9>102/Pdl80:f4C0030:j4DP2]
Pe40[89@0080Zh5?00<0[H=A0:n5D`2`QU@00`2[QE@20:Z4D`<0ZH=B0`2[PDl20:b2D0<0[H=A0P2_
QTh0102^QDl0[XEA0:f4D02/PU020:b2DPP0[HA@0P2^Q5860:n5D`80[HQC0P2/Qe820:^6D@80ZXE@
0`2]R5<30:b7DP80ZhIA202^QE420:f4D0<0[8=?0`2[PTh01P2YP4P0ZX590:^2C02/Pdl0[HA@0:n5
D`80/8IF00<0Zh9>0:b3C`2/Pdl00P2]Q5020:j5D@060:n6DP2[QU40ZXE@0:V4C`2XPdh0Yh9=0P2X
Pdh00`2YQ4l0[8=?0:b3C`060:b3C`@0Zh9>102/Pdl80:n6DP030:f4CP2/Pdd0[8==00H0Zh9<0`2/
Pdl20:^2CP/0[8=?0P2YOdd0102ZP4h0Zh5?0:f3D@2^Q5820:n5D`<0[H=A00<0[89@0:^1C`2[PDl0
0P2ZP4h80:b3C@<0[8=?0`2]Q5020:j5D@80[HA@0`2/Pdl30:^2CP050:V0C02ZPDd0ZX5=0:^2CP2/
Pdl00P2]Q5001`2^QE40Z8AB0:V3DP2YQ500Zh=?0:b3C`2]PTd00P2_PT/80:Z1B`@0Zh9>102/Pdl0
1P2YP4`0ZX5=0:Z1C@2[PTh0[8=?0:f4D080[XEA00<0ZX5;0:^2C02[PT`01@2/Pdd20:Z1C@030:^2
CP2/Pdl0[HA@00<0[HA@102XPdh40:V4C`80ZXE@0`2YQ4l30:R3CP030:V0C02ZPDd0[8=?0080[HA@
00<0Zh9>0:V0C02XOd/00P2/Pdl20:^2CP80ZX5=0P2YP4`01@2ZPDd0ZH1<0:QoB`2WOTX0Z7m;0080
ZH1<00<0Zh9>0:b3C`2/Pdl01`2/Pdl80:b2D080ZX5=102YP4`20:QoB`<0Ygi:0P2XOd/30:V0C0P0
YH1<0P2YQ4l20:R3CP80Yh9=0P2VPD`80:QoB`<0Xgi90`2TOdX20:F0B`80ZGm=1P2XOT`30:AoB`<0
YH1<0P2VPDd0202WO540Yga?0:MlC`2VO4`0YWa:0:ImB@2VODL0Ygi80P2TNTP40:EkB@80YWa:202V
ODT00`2UODT0Y7a80:9jAP020:5iA@030:9jAP2TO4P0YGe90080ZG]700P0YW]80:EkB@2SNdX0XG]<
0:1jB`2ONTd0WgY609iiA@<0WGQ400@0WgY60:5lB02RODT0XgU70P2RN4H50:5gA@X0W7M20P2KMT42
09Ye@0<0VG@o0P2LMd801`2MN4<0WWU409eh@`2LMd80VWE009Qc?P2JMD400`2IM400102KMT80WGQ4
0:1kA`2QO4P20:5h@P030:1g@`2PMT@0WgE50080WW=600<0WG9709]f@P2KMT801P2KMT8809UcA080
VgI2102LMd<209ehA0@0WWQ70P2NNDD00`2MN4@0WGQ309ee@P0209ee@P80WWI30`2OMd@0202LMTD0
VgE409]eA02KMD@0W7I509miB02QNdX0Xge<0`2NN4T[ooooo`00:_ooool0202>I3@0SfDe099W>P2D
JCh0U6To099V?`2?Hc`0SV8m0P2<H3T208]O>0@0RUhg0P2=I3P00`2>HcP0T6<i099S>@0209AS>P03
09IR>P2@I3L0T6@g00<0TFDh0`2BIST309=W>0<0U6Pi0P2EJCX01P2HICX0UVDj09IU>P2EISX0U6Pk
09=X>`80TfXl00<0UV`j09E[>@2CJCL00`2AIcD00`2BJ3H0TfTg09EY?00709EY?080TVHi00@0TfLj
09AX>`2EJC`0UFTl0P2FJSdA09EY>080TfLf0P2DJ3L309EY>0<0UVXi0P2GJcX0102HK3/0VFdl09U]
?02IKC`209I[?P80Uf/n00@0V6`o09Y[?`2JJcl0VV/o202HK3l01P2EJSL0UV/h09M/>@2HKCX0VFhk
09]`?@80W74n0P2KKch409a`?`@0Vfln0P2LL3l209ea@080WW911P2NLd0209eb?`080:9iA@2QN4@0
X7M309mf@P2NMD40WGA009ac?`2KLSh209ic@0<0WgA10`2PMD8809me@`80WgA10P2PMD820:5f@`80
XWM4202OMT8209md@@030:1e@P2QMT<0XWM40080XgQ500@0Y7U60:5f?`2QMSl0XWM20P2SN4D00`2T
N4L0YGU:0:EiBP080:=hA@030:1d@`2RMTD0Y7Q70080YWY900<0Y7Q70:5eA02PM4<04@2TNDH20:Ak
@`040:AkA@2SNTH0XgY60:9hAP80XWQ80P2TND@03P2SN4D0XgM60:9fA`2QMDP0X7A70:1cB@2OMD<0
WWA209ab@02KLCl0VW0n09]a?`2LLT00WG=10P2JL3h209U_?@<0V6hl00L0Ufdk09M/>@2FJST0UF/i
09AZ>P2CJ3/0TFPl0080T6Hl00<0T6Dj095V>`2BIc`00P2BIc`00`2@ICX0Sf@i08eR=`0308US=P80
R68e0`27HC@02022GC00Peha08AO<P24Gc80Peha085L;`1oFRd0OUT/2021G2l207mI<P0407iH<@1m
Ec00OEL`07aF;`80NeD^1@1cD2P02`1bCbL0LDhV075>9P1`CBL0M54[07MD;P1fDbd0LTlY071=9`1b
CbT0ME8/00D0KTdZ0P1]C2T506a;:080JdXW0P1ZBBH00`1YB2L0JTTX06]::@0206a;:P0306Y9:01X
AbH0IdHU00P0ITPV00@0KD`[06a;:P1ZBBP0J4LV0P1WARD00`1XAbH0JDPW06M99`0806M99`0306I8
8P1XBR@0JddW0080KDlY00`0K4hX06Y<9P1XBR@0IdLP06Y:8`1]CBH0L50Y075A:P1`D2T0KThW06a<
9@1]D2P2071@:@05079@:P1cD2X0MU0[07M?:`1hD2`00P1dDBL0101eDRP0MU<Y07IC:@1gE2X207QE
:`0407YD;@1iDb`0NE</07UC;080NU@]0P1kEBh00`1kER`0O5L]07eH;P0207iI;`0307eH;P1kER`0
NUD[0080OU@^0P1oEBl3081F<003085G<@20FC00P5T`00H0P5T`2020Fbh00`20FC00PEXa085J<@03
089K<P80PEXa201oFS08085L;`80Ne//00@0OE/]081K;P22GC00Q5ha0P27GS83081J;@<0PE/^0P22
G2l207iG;P0607mH;`21FS40PU/b08=L<`24GC@0QEhe2022GC08081K;P0;07UF;01jEbd0OEX`07mL
<P20GC<0Oe`b07eJ<01kF2h0O5L]07eH;P1oFS000P21G3801020Fc40OeX`07iI;`1nFBl307YG;@03
07]H;P1lFBl0O5T_0080OEX`201mF2h0201oFS00OUT_07aG;@1jEB/0NeH/07eH;P20Fc40PUdc0P1j
Ebl407UF;P80N5D]201kER`207eC;@0407]D;@1jE2d0NU@]07QE;@80MeH]00P0NELY07QF:@1gEBP0
MU<Y07MD;01hEBl0NUHb07]G<`@0Me@/101fDb/01@1gE2`0MU<[07IC:`1eDRX0Le0X0080LTlW00<0
LDhV075A:P1aDBX00`1aDBX2071@:@0306m?:01cD2X0Le0Z0080LTlY0P1aCRP2071=9`@0KddW101`
CRP206e?:`80K4hZ00L0JddY06Y<:01ZC2P0JT`X06Y>:@1YCBP0Id/V0080IDTT00D0Id/V06U=:01Z
CRT0ITPR06M98`0206Q:900406M98`1UAb40HdDO06537@P0IDTT201QA28806168`<0I4LU0P1UB2H3
06I99`T0ITXU0`1VB2@00`1WBBD0J4XV06U;9`0206Y<:00@06=;:@1TBRT0ID/X06U=:01[CBL0KThW
071>:01aD2L0Jd/U06e=9`1`D2T0Le<Z07AE:@1dEBL0Le@V07=D9@P0LU8Y0P1dEBT00`1eERX0MUL[
07MH;00207QI;@0607UJ;P1kFB/0NeT[07aJ;01mFbd0OU`^0P1oGBl3081N<0<0PEla0`22H3801029
ICD0R6@d08QT=027Hc<408IR<P80RVHf00@0RfLg08aX>02=JCT0SVXj0P2?Jc/208eW>00308iX>@2?
JCX0T6Xk0080TF/l00L0TV`m09EY>02DJSP0UF/i09I^>`2EL3`0UW8n0080UG@o1P2GLSh409Qc?`80
VGA0102JMD4209eh@`80W7M200@0WGQ309mjA@2RODP0Xgi90P2TNdL0102UO4P0YWe90:MnBP2XOd/2
0:V0C0@0Zh9>102/Pdl30:V4D0<0ZXEA0P2[QU820:j:EP<0[h]G0`2`S5P01`2`RUd0/8YK0;2:F`2`
RU/0/8YI0;2;E`2`ReH00P2`Re@00`2^RED0[hYF0;6<F0020;:=F@030;6<F02_RUH0[XUE00<0/HaH
0`2`ReL20:n:EPP0/XaM00P0/XeF0;>>E`2eT5/0]Y5M0;NAH02fT640]HmP0;B>H@P0/hiJ202fS5X8
0;6<F0<0]8mJ0P2cSUT30;:=F080/HaH0P2bSET00`2cSUX0]8mK0;B?F`030;B?F`<0/hiJ0`2bSET3
0;B;E`<0/hYF0P2bRED01P2hSU`0]heK0;J<FP2dRUP0/XQF0;67E@80[hEC202cRUH40;2:F@040:n9
F02^R5L0[XQG0:f7EPP0[hYF00H0/hmE0;:>E02aS5D0[hYE0:j9E02]R5@20:b6E@P0/HME0P2dReL0
102cRUH0/XUE0;27D`2_QU820:j5D@T0[XAB0P2aR5@30;27D`<0[hIB202aR5@80:f8D`<0[XEA00<0
[hIB0;27D`2aR5@00P2aR5@80:^6DP050:Z5D02[QU40ZhIA0:b7DP2]R5<00P2^RE@01P2_RUD0/8]G
0;2;E`2_RUH0[XUE0:f8E080[8MC00<0ZhIB0:b7DP2/Qe800`2/Qe800`2[QU40ZXE@0:Z5D0080:f3
D@P0[HA@0P2YQ4l40:Z5D080ZhIA00P0ZXE>0:V4C@2XPdh0Yh9>0:N1D02XPU<0ZXAE0:^5F0P0ZXEA
0P2`QU@20:n5D`80[XAB0P2]Pe420:b3C`<0[HA@0`2^QE430:n6D0<0[XE?0P2]Q4h20;:9E@050;68
E02_QU80[XEA0:f4D02/Pdl01@2[PTh40:b3C`L0[HA@0P2^QE480:b3C`P0[HA>00<0[XAB0:f3D@2/
PU000P2[PDl00`2]Pe40[hEC0;26E0030:^6DP80ZXEA0`2YQ5020:Z0CP80Zh5?0P2/PU020:f3D@03
0:j5C@2]Q4`0[HA>0080[HA@00<0[89@0:b2DP2/PU80202]Q5060:n5D`80[XAB0`2/Qe820:^6D@<0
ZXE@0P2^RE@30:f8D`<0[8MB202^QE420:f4D0<0[8=?0`2[PTh20:Z1B@060:^2C02]Q500[XEA0:n5
D`2`QUH0/HMG0P2/Pdl40:f4D080[XEA00P0[8MB0:^6D@2YQ4l0Yh9=0:J1C02WPTd0ZHA?0:Z5D0P0
[8=?00<0ZX5=0:^2CP2[PTh00P2/Pdl20:f4D0030:j5D@2_QU80[hIB00H0[hIB102]Q4h20:b3C@04
0:^2C02ZPD/0ZX5;0:^2CPH0[8=?00<0Zh9>0:b3C`2/Pdl01P2/Pdl02@2XOT`0ZGm=0:Z0CP2[PDl0
[89@0:f3D@2^Q580[hEC0:f3D@040:b2D0<0Zh5?202/Pdd20:b3C`<0[HA@0`2^QE420:f4D0<0[8=?
0`2[PTh20:Z1C@040:^2CP2/Pdl0[8=?0:f4D080[XEA00H0Z8AB0:V3DP2YQ500Zh=?0:b3C`2]PTd2
0:n2B`P0Zh9<202/Pdl01P2YP4`0ZX5=0:Z1C@2[PTh0[8=?0:f4D080[XEA102[PT`20:b3C@030:f4
CP2^QDl0Zh9>00@0Zh9>00<0[8=?0:f4D02]Q500202YQ4l20:Z5D0<0ZHA?0`2XPdh20:V0C0060:^2
CP2/Pdl0[8=?0:^2CP2ZPDd0ZH1<0P2/Pdl20:^2CP80ZX5=0P2YP4`01@2ZPDd0ZH1<0:QoB`2WOTX0
Z7m;0080ZH1<00<0Zh9>0:b3C`2/Pdl01`2/Pdl80:b2D080Zh9>0P2ZPDd20:V0C080Z7m;0`2WOTX2
0:QoB`<0ZH1<202UP4`20:V4C`80Z8=>0P2WPTd20:J1C0P0Z7m;0`2SOTT30:AoBP80YH1;0P2WODd6
0:QnCP80Y7m;0`2UP4`30:J1C@060:IkD02VNdh0Yga?0:MmC@2XOT`0Ygi:0P2WOTP30:EkB@80YWa:
0`2WOD/80:MnBP030:ImB@2UO4P0Y7]70080XgY600<0Y7]70:ElB02VODT00P2XNTH00`2VNdP0Y7Y8
0:=kBP020:1jB`0409mjC@2PNdL0WgY609iiA@80WGQ400<0WWU50:1kA`2QO4P0102SNDL0102RN4H0
XGM50:1fA02PMT@409]f@@@0W7M2102KMT4509Ye@00809ag@P2MN4<0WWU409mjA@2NND@0WGQ309]f
@@2JMD0209]eA080VWA300@0W7I509ihA`2PNTT0XWa;0P2RND<01P2QN4@0X7I409meA@2NLdH0WG95
09aaAPP0VgI2202ILd@209]f@P80W7M30P2MN4@209iiA@0509iiA02NNDD0WWU509iiA@2NN4L00`2O
NDP209]eA080W7I50P2MMdH209ihA`0809ag@`2KMT80VgI209]f@P2LMd<0WgY60:5lB02SOTX309ih
BB_ooooo000Zooooo`0808iT=02?ICD0T6Dh091U>P2@IC/0T6@m08mS?02>HSd208eQ>P<0S60i0`2;
GcP208eT>00308iS>02@HcT0TV<i0080U6<j00<0UV8j091T=`2@I3L00`2AICP3099V>@<0TfLf0`2D
J3L209EY>00;09UV>`2FICX0UVDj09AU>@2CIcX0TfPk09=Z?02DJcd0UV`j09E[>@2CJCL00`2AIcD0
0`2BJ3H0TfTg09EY?00709EY?080U6Pk0`2EJC`309IZ?@T0UFXg202EJCP209AX=`80UFTh0P2FJST2
09M[>P80UVXi00@0Uf/j09Q/>`2IKC`0VFdl0P2JKSd209E/?P0309I[?P2GJch0VV/o0080VfXo00<0
WFXo09Q/?`2HK3l01P2HK3l209M/>@80V6dj00@0VFhk09Y_?02KL3d0Vg0m0P2KKch0102LL3l0WG50
09ea@02LL3l409]_?P80W70o0P2MLD0209ib@@80WgA10`2NLd0309eb?`050:9iA@2QN4@0XGQ40:1g
@`2OMT800P2NMD400`2MM400WW=009md@@0209md@@80X7E20P2QMT<809me@`80WgA10P2PMD80102Q
MT<0XWM40:=hA@2SN4D809mf@080WgA10P2PMD802P2QMT<0XWM40:=hA@2SN4D0XWM00:=h@@2SN4<0
XgQ50:AiAP2TN4L20:AhB@P0XgQ500P0XgM60:AhA`2UNDP0YGU80:AhA`2SMdH0XWI50:5eA080XgQ5
1@2UNTL20:=hA@P0Y7U60P2TNd<0102TNdD0XgY60:=jAP2RN4H20:9hB080XgQ300<0XWM40:5eA02P
M4D00P2OLdH0102NLDL0WG=109ab@02KLCl209Y`?P0309]a?`2LLT00WG=10080VFlm0P2HKS`309M]
>`0;09I/>P2GJCL0UfTh09AX=`2BJ3P0T6Li08iX>`2=IS/0S6Lk08iS>02?I3T00`2@ICX00`2>HcP0
SF8g08]P=@0208US=P80R68e0`27HC@00`26H3<0PUd`089M<00208=N<@04089M<020Fbh0OUT/07eH
:`P0P5/^0P1oFC800`1nF340OEL`07aF;`0207]E;P0807YD;@1bCbT0Le0Z07=@:P1dDB/0Le0Z079?
:@1aCRP2071=9`0:07AA:`1gE2h0MU<]079?:@1_C2H0L4dW079?:@1[BRL0K4/X06e<:@80KTdZ00<0
KD`Y06a;:01[BRL00P1[BRL306a;:00;06]:9`1YB2D0J4LT06U89`1ZBBP0JdXY06a;:P1[BRT0JTTX
06Q79P1WARD0201VB2H00`1/BbX0JdXY06U89`0206M69@0306Q79P1YB2L0JTTX00T0J4XX00<0JTXS
06];901]CBH00`1^CRL206e=9P0>06Y:8@1[Bb80KThU071@9`1aDBP0L50W06m?9P1^CRD0KU4W071@
9`1aDBP0LU4X07AA:@1gDBX207UB:`<0Me@Z0`1hEB/207UF;00307aF;`1kEBh0NU@]00<0NU@]0P1l
ERl00`1mF2h0OUT_07mJ<00207mJ<00307iI;`1lEbd0NUD[0080P5@_0P21EC03089F<@0308=G<P21
FS40PEXa00H0PEXa2021G2l01@20FC00PEXa089K<P23G3<0Q5dd0080Pe`c00<0PU/b07mJ<01oFS00
1P1oFS08089M<080OEd^00@0OU`^085L;`21G2l0Ped`0P25G303081J;@<0PE/^0P22G2l2081I<004
085J<@22Fc80Pe`c08=L<`80Q5dd2021GBd8081K;P0507]H;P1lFBl0OEX`07iK<@1oG3800P1nFc40
201mFS00OEP^07iI;`20Fc40PE`b089M<`21G380P5/a0P1oFS0207UF;00307YG;@1kF2h0O5T_0080
OEX`00<0OU/a07eH;P1mF2h01P1mF2h207mJ<00607iI;`1mF2h0OEP^07eH;P1nFBl0OeX`0`1jEbl5
07UF;P0407eH;P1lEbd0O5L]07aG;@<0NeH/00@0NUD[07eC;@1mDbd0Ne@]0P1jE2d02`1hEBd0MeH]
07MF;@1jF2X0NELZ07ME:01fDbT0MU<[07MD;P1hE300NEDa00P0Me@/00H0N5D]07MD;01fDb/0ME8Z
07AA:@1bCbL2075>9P0306m?:01`D2T0LE4Z0080LU8[00<0LE4Z071@:@1_CbP00P1dDB/0101cD2X0
LTlY075>:01aCRP4071=9`80LDhX101bCbT206i@;080KDl[00L0K4hZ06]=:@1ZC2P0JT`X06a@:`1Z
CRT0Id/V0080ITXU00<0Id/V06Y>:@1/D2/00P1XBb<206U<900406Q;8`1VBB40I4LO06=67PP0ITPT
201SAR@805m78`<0HTDS0P1SAR@306A79@T0IDPV00H0IdTU06I8901VB2@0IDLS06I8901WBBD206U;
9`0@06=;:@1UBbX0ID/X06Q<9`1ZC2H0KDdV06i<9P1_CRD0JTXT06a<9P1`D2T0Le<Z07AE:@1dEBL0
LU<U075B8`P0Ke8Z0P1cE2P00`1dEBT0MEHZ07IG:`0207MH;00607QI;@1jF2X0NUPZ07]I:`1lFR`0
OE/]0P1nG2h0101oGBl0P5h`081N<020GS02085O<@<0PV0b00@0RFDe08QT=027Hc<0QF4a0`24H300
1P25HC40RfLg08]W=`2<J3P0SFTi08iZ>P80Sf/k00<0T6`l08eW>02>J3T00P2>J3T408mY>P0809AX
=`2DJSP0UF/i09E]>P2EL3`0UG4m09Ac?P2EM3l209Ia?@<0Ug8n0`2HLcl209Mb?P80V7<o0`2IM400
2@2JMD40W7M209ag@P2KMT40W7M209eh@`2ONTD0XWe80:=nB@020:AjB0040:EkB@2VO4X0Yge;0:Mm
B`80Z7i<202[PTh20:R3C`80ZHA@0`2ZQE400`2[QU80[XYF0:j:EP030:n;E`<0/8aH00L0/8YM0;2:
F`2`RU/0/8YK0;2:F@2`ReL0/8]F0080/8]D00<0[XUE0:n:EP2`ReL00P2aS5P00`2`ReL0[hYF0:j9
E@030;6<F0<0/8]G0P2_RUH80;:<G@080;2;E02bSEH0]8mJ0;F@G02fT5l0]HmP0;B>G`2cSF080;>>
FPP0]XaJ202bSET20;>>F@80/XeH0`2aS5L01`2`ReH0/8]G0;6<F02aS5P0/XeI0;>>FP2dSe/00P2e
T5`20;B?F`<0/hiJ0`2bSET30;B;E`<0/hYF0P2bRED01P2gSE/0]XaJ0;F;F@2dRUP0/hUG0;67E@80
/8ID202cRUH01P2_REX0/8YK0;2:F`2aRe`0/8YK0:n9FP80[HMH202`ReL01P2bSU@0/HeC0;2;E02^
RE@0[HQC0:f8E080[XQG202aQeD01@2dReL0/hYF0;>:EP2bRED0/HQD0080/8MC00<0[hIB0:n5D`2_
QE<01`2_QE<30;68E080/8MC0`2_QU880;68E0P0[HQA102`Qe<40:n6DP040:b7D`2[QU80ZhIB0:^6
DP<0ZXEA00<0ZHA@0:^6D@2[QU400P2/Qe820:f8D`80[XUD0P2_RUH30:j9E@<0[HQD00@0ZXE@0:^6
D@2/Qe80[HQC0P2/Qe800`2[QU40ZXE@0:f3D@070:f3D@<0[XEA0P2]Q5030:b3C`P0ZXE@00P0ZHA=
0:R3C02WPTd0YX5=0:J0C`2XPU<0ZXAE0:^5F0P0ZHA@0`2`QU@20:n5D`<0[XAB00@0[8=?0:f4D02]
Q500[HA@0P2^QE420:n6DP<0[hI@0`2^QDl20:f4CP80/8MC00@0[hIB0:j5D@2]Q500[HA@0P2/Pdl8
0:^2C0D0[HA@0P2^QE420:n6DP040:j5D@2]Q500[HA@0:f4D0<0[8=?00<0Zh9>0:f4D02]Q5001P2]
Q5000`2^Q580[H=A0:b2D0020:^1C`030:f3D@2_QE<0/8ID00<0ZhIA0P2ZQE030:V4C`<0ZX1>0P2[
PDl30:b2D080[8=;00@0[8==0:b3C`2/Pdl0[89@0P2/PU880:b3C`80[hEC0`2^Q5830:f3D@80[8MB
0P2[QU430:Z5D0030:V4C`2]R5@0[HQD00H0[HQD202^QE420:f4D0<0[8=?0`2[PTh20:b3B`040:b3
C@2]Q500[XEA0:n5D`80/8IF202]Q500202]R5<0ZhIA0:R3CP2VPD`0YH1;0:N2C@2YQ4l0ZhIA202/
Pdl20:Z1C@030:^2CP2/Pdl0[HA@0080[XEA00<0[hIB0:j5D@2^QE401P2^QE40102]Q4h0[XE?0:j5
C`2^QDl20:f4CP060:b3C@2ZPD/0ZH1:0:Z1C@2[PTh0[8=?0P2]Q5000`2/Pdl0Zh9>0:Z1C@080:b3
C`80ZGm=00@0ZX1>0:^1C`2[PDl0[89@0P2]Pe480:b2D0P0[8==00@0[8=?0:f4D02]Q500[HA@0P2^
QE420:n6DP80[HA@0`2/Pdl40:^2CP<0[8=?102]Q5001P2XQ580ZH=B0:V4D02[Pdl0[8=?0:f2C@80
[h9;202[PT`0102^QE40[HA@0:f4D02]Q5030:b3C`@0Zh9>0`2/Pdl20:f4D00<0:^2C02ZPD/0ZX5;
0:Z1B`2[PT`0[HA>0:j5C`2_QU00[HA@0:b3C`2[PTh0ZX5=0P2[PTh00`2/Pdl0[HA@0:^6D@030:Z5
D0<0ZHA?00<0Z8=>0:Z5D02ZQE000`2YQ4l30:R3CP040:QoB`2YP4`0ZH1<0:Z1C@<0Zh9>00<0ZX5=
0:b3C`2/Pdl00P2[PTh20:Z1C@80ZH1<00D0ZX5=0:V0C02XOd/0Ygi:0:QoB`020:V0C0030:^2CP2/
Pdl0[8=?00L0[8=?202/PU020:b3C`040:^2CP2ZPDd0ZH1<0:V0C080Z7m;0`2WOTX20:QoB`<0ZH1<
0`2TOd/20:F0C0<0YX5=0P2YQ4l20:R3CP80Yh9=0P2VPD`80:QoB`<0Xgi90`2TOdX20:F0B`80YW]>
0P2WO4l40:QmD0H0YX5=0P2UP4`0202UNTl0YW]>0:MlC`2XOTh0ZGm=0:V0C02XOdT0Ygi80`2VO4X3
0:MmB`80Z7i<202VODT00`2XODX0Yga90:EjA`020:AiAP030:EjA`2WO4T0Z7e:0080Z7Y600<0YGY7
0:AjB02RNTT00P2PNT/0102NND`0X7]709mjAP2NNDD209ehA00409iiA@2PNdL0XGa80:=iA`<0Y7Y8
00@0XgU70:9hAP2PMT@0WgE30`2KMT4209ag@P<0WGQ3102LMd8509]f@@0309ag@P2MN4<0WWU40080
WgY500D0WWU409eh@`2LMd80WWQ909egB00309afA`0;09egB02ONDX0XG]<0:=jA02RND<0XGQ40:1f
A02OMDD0WG9509aaA02LLDH0202KMT8809YdA@80VgI20P2LMd<0102MN4@0WWU509mjAP2ONTH209eh
@@0409eh@`2MN4@0WWQ709ihB@80WgU<0`2KMdL209ahB0<0WGU900P0WGQ309ag@P2LMd80VgI109ag
@P2NND@0X7]60:5lA`<0WWQ9:oooool002[ooooo0P2>I3@01P2=HSD0S64f08aQ=`2=HCX0SV8k08iR
?@<0SV8k0`2=HCX208aP>@80SF@h00<0SV<h091S>@2BHcT00P2DHcX00`2FHSX0T6@g091T=`03095U
>0<0TVHi0`2CIcH309AX=`80UFTh00/0VFHk09MV>`2EI3T0U6Di099V>@2CJ3/0U6/m09E/?P2FK3X0
UF/i09=Y=`03095W=@03099X=P2CJCL0UFTl00L0UFTl0P2GJch309IZ?@<0UFTl2@2EJSD809EY>0<0
UVXi0P2GJcX309Q/>`80UVXi00@0Uf/j09Q/>`2IKC`0VVhm0P2KKch0202CKcl0U6ho09I]?`2GK3l0
VFXn09YY?P2LJCh0WFPn202HK3l00`2HKCX0VFhk09U^>`0509U^>`0309Y^?@2KKch0WG500080WW91
00<0WG5009]_?P2JKSd00P2KKch209a`?`80WG500P2NLT4309md@@0309ic@02MLSl0WG8o0080W74n
202PMd<309md@@80X7E20`2QMT<809me@`0609ic@02OM440X7E20:5f@`2RMd@0XgQ50P2TNDH809mf
?P@0X7E2102QMT<20:Ej@`040:AiA02TNDH0Y7U60:=gAP80XgM8202SN4D0102WNdX0YWY90:AhA`2S
MdH20:9fA@80XgM600<0XWM40:=hA@2UNTL00P2VNdP20:EjA`030:=hA@2RMd@0Y7U600L0Y7U60P2T
Nd<0102TNdD0XgY60:=jAP2RN4H20:9hB080XWM200<0XGI30:1d@`2OLd@00P2NLTD0102ML4H0W790
09]a?`2JL3h209U_?@0309Y`?P2LLT00WG=100<0V6hl0P2GKC/309I/>P0809UW=P2GIcL0UFLf099V
=`2?ISP0SFLj08UW>P28IST208aQ=P<0SV<h00<0S64f08YO=029GS<00`28HSD308MQ=080QV0c00<0
PE`_089M<022GC000P22GC000`20Fbh0OEP[07aG:P0807mJ;@0607mI<P1nF340OUPa07eG<01lERl0
NeD^0P1jE2d03@1bCRX0Ldl[07A@;01eDBd0M50/07=?:`1aCBT0L4`X075>:01dDB/0N5D_07IC;@1a
CRP00P1]BR@0101_C2H0JTTV06]:9`1/BbP206i=:P0=06e<:@1/BbP0JTTV06Y99P1[BRL0K4/X06e<
:@1/BbP0JdXW06U89@1WAR<0JDPW06Y9:00306]::@0306U89`1WARD0ITDT00P0ITPV00<0JTTX06U8
9`1XAbH00P1WARD00`1YB2L0JdXY06a;:P0906Y<:P0:06m=9`1^C2H0KD/U06e;9@1^C2H0KddW071>
:01aCbT0KDhR06i?8`80Ke0T00X0L54U06m@901_D2@0Ke0T06iA9@1`DBD0LE8V07=B9`1eDRP0N5<Y
0P1jDbX307YH:`<0NELZ0P1hERT00`1nF340OEL`07]E;P0207YD;@0507]E;P1lERl0OEL`07iI;@1o
FRh00`20Fbl00`1nFBd0O5L[07]F:P03085E<080PUHa0`23Ec88089K<PP0PUd`00@0OeP_085J<@23
G3<0Q5dd0P25GSD208=L<`P0P5/a2022GC0207mO<004081N<021G2l0PE`_085K;P80PeX^0`20FRd3
085K;P80PU`_2023G3<8081L:PP0P5/^00l0OU/a07eJ<01lFBl0O5T_07eJ<01nFc40Oe`b081M<`1n
FBl0OeX`085L<P22GC<0Pehd089M<`21G3800P20Fc401P1hEB/0NEH/07YG;@1kF2h0O5T_07eJ<080
OU/a201mF2h0201oFS00P5/a081K<@20Fc40OeX`07iI;`1lEbd0NeH/0P1iERh607YG;`<0OEP^00<0
O5L]07]F;01kER`00P1jEB/207iD;P0407aE;P1kEBh0NeD^07UF;P80N5L^00P0NUPZ07UG:P1gEBP0
ME8X07AA:@1eDR`0ME4]07IB;PD0Me@/0`1hEBd01P1iERh0N5D]07MD;01fDb/0M54Y079?9`80LDhV
00P0KThW06m?:01aDBX0LU8[07=C;01bDR/0L50Y06m?:080ME8/00L0M54[07=@:P1bCbT0LDhX071=
9`1_C2H0L4dW0080LDhX0P1bCbT207=@:P0707AA:`1`DRh0Ke4]06i@;01]Cb/0K4hZ06]=:@0206Y<
:00306eA;01[CbX0J4`W0080ITXU00D0J4`W06]?:P1]DB`0JD`T06Y=9@0206]>9P0406Y=9@1XBb<0
ITTQ06E880P0JDPU201UB2H805i88`0405m2801P@b40H4<Q06138@80HD@R0P1RAB<906A79`0306M9
9@1VB2@0IDLS0080I4HR01<0ITPT06Q:9P1YBbL0I4`Z06E;:P1VC2T0J4`W06U;9@1[Bb@0K4XT06a;
8P1XB280Jd/U06m?:01cDbX0M5DY07=D9P1aDR@0L54R00P0KE4Z00H0LU<W07=D:01cE2P0M5DY07EF
:P1fEb/207MH;00607UG:@1jF2X0NUPZ07]I:`1lFR`0OE/]0P1nG2h207mM;`80P5h`0`21Gc401@22
H380RVHf08QT=026HS80Q60`0080Pel_0P24H3001P28I3@0RFDe08UU=@2:ISH0RfLg08aX>080SFTi
00@0SfTj08iX>@2>J3T0SVPi102=IcP01P2DJ3L0U6Xh09E[>@2EKCX0U6lk09Ea?@80U7<n0`2FLCd0
0`2GLSh0V7<o09Qc?`0209Ud@00409Ia?@2GLSh0Ug8n09Mb?P80V7<o0P2IM40409]f@@0509eh@`2O
NTD0XWe80:AoBP2SNDT00P2TNTX00`2UNd/0YWa<0:MmC@020:QnCPD0Zh9>0`2ZPDd30:R3C`80ZHA@
0`2ZQE420:j:EP<0[h]G0`2`S5P01`2`RUd0/8YK0;2:F`2`RU/0/8YI0;2;E`2`ReH00P2`Re@00`2]
R5@0[XUE0;2;E`020;6<F0030;2;E`2^RED0[HQD00<0/HaH0`2`ReL20:n:EPP0/heN00P0[hYC0;2;
E02bSEP0]8mK0;B>G@2cSEh0/XaM0;6;GPP0/hiJ202fS5X80;B?F`80/HaG0P2`ReH40:n:E@80/8]G
00H0/HaH0;:=F@2cSUX0]8mK0;F@G02fTEd20;B?F`<0/hiJ0`2bSET30;B;E`<0/hYF0P2bRED01@2e
ReT0]8YH0;B:F02dRUP0/hUG00<0/XQF202cRUH00`2^R5T0[hUJ0;2:F`020;6;G0030:n9FP2]QeP0
[8IG00P0/8]G00<0/HeC0;2<DP2^RE800P2]R5<00`2^RED0/8YI0;6;FP080;67E@P0/XUE2@2`QU@2
0;:9E@80/HQD0`2`Qe<00`2_QU80/HQD0;68E0060;68E0P0[HU?0P2bRED0102aR5@0/8MC0:n6DP2^
QE420:f4D080[8MC0P2[QU80102ZQE40ZHA@0:V4D02YQ5040:b7DP@0[HQC0`2]R5@30:j9E@80[hYF
00<0ZHA?0:Z5D02/Qe800P2]R5<00`2/Qe80ZhIA0:Z5D0080:f3D@030:n6DP2^QE40[XEA0080[HA@
0P2/Pdl00`2[PTh0ZXE@0:Z5D0060:Z5D0080:R3C02WPT/0YX5<0:J1C@2VP4l0Z89C0:Z4E@2[QEP8
0:V4D0@0/8ID0P2_QE<20:j4DP<0[HA@0P2^QE430:n6DP<0[hI@0`2^QDl20:f4CP030:f4D02/Pdl0
[8=?00D0[8=?1@2[PTX30:Z1B@030:b3C`2]Q500[HA@00<0[XEA0P2_QU801@2`Qe<0[XEA0:j5D@2^
QE40[HA@0080[8=?0P2[PTh80:f3D@030:j4DP2]Pe40[89@0080Zh5?00<0[H=A0:n5D`2`QU@00`2[
QTl20:Z5CP<0ZHA=102ZP4h20:^1C`80[89@0P2/Pd/0102/Pdd0[8=?0:b3C`2/PU020:b2DPP0[8=?
0P2^Q5820:f3D@040:b2D02[PDl0Zh5?0:^1C`<0ZhIA0`2ZQE020:V4C`050:^5E02/QUD0[8IE0:f7
EP2^R5L00P2_REP00`2`RUT0[XEA0:j5D@060:j5D@80[HA@0`2/Pdl30:^2CP80[XE=00@0[XE?0:j5
D@2^QE40[XAB0P2^Q5@80:f4D0030:j9E02[QU40Z8=>0080YH1;00<0Yh9=0:V4C`2[QU40202]Q502
0:Z1C@060:^2CP2/Pdl0[HA@0:j5D@2_QU80/8MC202/Pdl20:j5C`80[hI@0P2^QDl01P2/Pdd0ZX5;
0:QoB@2ZPDd0Zh9>0:f4D080[XEA00<0[HA@0:^2CP2ZPDd0202/Pdl20:Z0CPP0Zh5?1P2/PU080:f4
CP<0[HA@0P2^QE430:n6DP80[HA@0`2/Pdl30:^2CP80[XEA0`2]Q5030:b3C`060:V5D`2ZQ5<0ZXEA
0:b4D02]Q500[X=>0P2`Pd`80:b3C@<0[XEA00<0[HA@0:b3C`2/Pdl00P2[PTh20:f4D0<0[8=?0`2[
PTh02`2[PT`0ZX5;0:V0BP2YP4X0ZX5;0:f4CP2_QU00/HQB0:j5D@2]Q500Zh9>0080ZX5=00<0Zh9>
0:b3C`2]Q5000`2[QU400`2ZQE00ZHA?0:V4C`020:R3CP80ZXE@0`2YQ4l30:R3CP<0Z7m;00<0ZH1<
0:Z1C@2ZPDd00P2[PTh20:b3C`80Zh9>0P2ZPDd20:V0C0050:Z1C@2YP4`0Z7m;0:MnBP2XOd/00P2Y
P4`00`2[PTh0[8=?0:f4D0070:f4D0P0[H=A0P2]Q5001@2/Pdl0Zh9>0:Z1C@2YP4`0Z7m;00@0Ygi:
0P2XOd/30:V0C0030:=nBP2TOd/0Y7m;0080YH1<0P2VPDd00`2WPTh0ZHA?0:V4C`020:R3CP80Yh9=
0P2VPD`80:QoB`<0Xgi90`2TOdX20:F0B`030:EjC@2VNdh0YW]>0080Yga?0P2XOE00102YOU40Z8=?
0:R3C`2WPTh20:J1C@090:F0C02TOd/0Y7m;0:AiCP2VNdh0Z7e@0:UoC`2ZP4h0ZX5=0080Z7m9102X
OT`40:MmB`P0YWe900<0ZWa:0:UkB@2XNTP00P2VN4H00`2XNTP0ZG]90:YlBP020:MiA@090:EjA`2S
NDL0XWY90:1jB`2ONDX0WWU<0:5lB02PNdL0WWU50080WGQ400<0WWU509mjAP2PNdL00P2TNTP20:Ek
B@040:AjB02RN4H0X7I409id@P<0W7M200<0WGQ309iiA02NND@00P2ONTD909eh@`0309ag@P2MN4<0
WgY50080X7]600/0WgY509iiA02MN4<0XG]<0:1jB`2NN4T0WGM809afA`2MMdP0WWQ909miBP020:=j
A0060:9iA@2PMT@0WWA409ebA@2LLD@0Vg15202KMT8809afA`0609Ye@@2KMT80W7M309ehA02NNDD0
WgY60P2PNdL209]g?@0409ag@02LMd<0WGM609egBP80WWM<0P2IMdL209YhB0@0VgU900<0WgY309ii
@P2MN4400P2LMd000`2MN440WWU20:1kA00309ihBB_ooooo000Zooooo`0808mU=@2=Hc<0Rf0c08UN
<`29GS@0Relh08eQ>P2?Hch408mS?080SV8k0P2=HCX208eT>00308iS>02@HcT0TV<i0080U6<j00<0
UV8j091T=`2@I3L00`2AICP3099V>@<0TfPe0`2DJCH209EZ=`0;09YW?02GIS/0UF@i09=T>02BIST0
TfPk09A[?@2EK3h0UV`j09E[>@2CJCL00`2AIcD00`2BJ3H0TfTg09EY?00709EY?080V6`o0P2GJch0
102FJSd0UFTl09AX>`2DJ3/909EZ=@P0UFTh0`2GJcX209Q/>`<0VFdl0P2FJST01P2GJcX0V6`k09U]
?02JKSd0Vfln09a`?`80Tflo00H0UVdo09M/?`2IJSh0W6Tn09eX?P2NIch809Q/?`80VVll0`2IKS/3
09Q]>P0309Y^?@2LL3l0WG500080Wg=200<0WG5009a`?`2JKSd00P2KKch209a`?`80WG500P2NLT40
102PMD80WgA109md@@2NLd0209eb?`80W74n00@0WgI20:1g@`2PMd<0X7M3102QN4@209md@@<0X7E2
0`2QMT<809me@`0809ic@02OM440X7E20:5f@`2RMd@0XgQ50:AiAP2UNTL809mf?P80XGI31P2PMD82
0:IkA0040:EjA@2TNDH0Y7U60:=gAP80XWI7202SN4D00`2YOD`0Yg]:0:AhA`020:5eA0060:9fA@2T
N4L0YGU80:9gA02SN4D0YGY70P2VNdP20:EjA`030:=hA@2RMd@0Y7U600L0Y7U60P2TNd<0102TNdD0
XgY60:=jAP2RN4H20:9hB00@0:9g@P2QMT40X7E20:1d@`2OLd@0WW9509eaA02ML4H0Vg4o09Y`?P2I
Kcd0V6hl09U_?@2JL3h0W79009ec@@80V6hl0P2GKC/309I/>P0A09E[>@2IIcH0V6Df09EW=P2BISL0
SfHh08]V>@28IST0QfHi08YO=02;H3D0S64f08eR=`2<HCH0Rf0e08UN<`28GC800`28HSD208MQ=0<0
QV0c00P0P5/^085L;`22GC00PUd`085L;`1oFRd0OEP[07aG:PP0OeX]0P1nF34207eG<00A07aF;`1k
EBh0NU@]07YD;@1bCRX0Ldl[07EA;@1fDRh0ME4]07=?:`1aCBT0L4`X075>:01eDR`0N5D_07IC;@1a
CRP00P1/BB<0101]BR@0JDPU06Y99P1/BbP206i=:P0>06e<:@1[BRL0JTTV06U89@1ZBBH0K4/X06e<
:@1/BbP0JdXW06Q7901WAR<0J4LV06U89`1ZBBP206]::@0306U89`1WARD0ITDT00P0ITPV00P0JDPW
06Q79P1WARD0IdHU06Q79P1ZBBP0K4/Z06e<:`T0Jdd[00<0LE0W06m>9@1]C2<00P1/Bb800`1^CB@0
LE0W07=B:@02071A9@80Ke0T00X0KTlS06m@901_D2@0L54U06iA9@1`DBD0LE8V07=B9`1fDbT0NE@Z
0P1kE2/207aJ;00407]I:`1jF2X0NELY07UG:@80N5HX00<0OeTb07eG<01kEBh00P1jE2d00`1kEBh0
O5H_07eG<00207mJ;@06081K;P21G2l0P5/^07iI;01lEbX0NeHY0P22E30208=E<@<0Q5Hb00<0QELc
089K<P22Fc801P22Fc88089M<00807mH;`21FS40Pe`c08EN=@26GcH0QEhe08AM=023G3<8081K<@P0
PUd`0P21HC801021Gc40PUd`081K;P20FRd2085H;0<0P5X]0`21Fbh2089L;`<0Q5dd0`23G3<2089K
<PP0Oe/Y2020Fbh03`1oG380OU/a07aI;`1jEbd0NeP^07eJ<020GC<0PUle07iI;`1oFS00PE`b089M
<`23GS@0PUdc085L<P02081K<@0607QE:`1iER`0NEH/07]H;P1lFBl0OEX`0P1nFc4807eH;P0807mJ
<020Fc40PUdc089M<`21G380OUT_07YE:`1hDbT207UF;P@0NUL_0P1kF30207iI;`0407eH;P1lEbd0
O5L]07]F;080NUD[0P1nE2h0101lEBh0NeD^07]E;P1iERh207QG;P0807]I:`1iEbX0MeDX07EB:01c
D2P0Le0Z07=?:`1dD2`407MD;0@0N5D]0P1iERh0101gE2`0MU<[07AA:@1cD2P2075>9P0306i>9`1_
CbP0LE4Z0080Le</00/0LU8[071@:@1_CbP0MU<]07EB;01dDB/0Le0Z079?:@1aCRP0L4dW06m<9P03
07==:00307A>:@1eCbX0MU0[0080MU0[0P1`DRh00`1_DBd0KU0/06e?:`0206]=:@0406Y<:01^DRd0
JdlZ06Q<9`80ITXU00<0J4`W06]?:P1^DRd00P1[CR@206a?9@0406]>901YC280IdXP06I97`P0JDPU
201VBBL805i88`80GT4O0P1O@R0406138@T0I4LW01P0J4XV06I8901UAb<0HdDQ06A68P1UAb<0IdTU
06U;9`1UCB/0IT`[06I<:@1XC2L0J4XT06Y:8`1ZB280JTTP06Q88P1[BbD0KdlX07=C:P1dEBT0Le@V
075B901_D24806a@:@80LU<W00<0Le@X07AE:@1eERX00P1fEb/01P1gF2`0NELY07UG:@1jF2X0NeT[
07aJ;080OE/]00<0OU`^07mM;`1oGBl00P20GS04085O<@0408YV=P28I3@0QV8b08=O;`80PUh^00L0
Pel_08AP<025HC40QF4a08IR<P27Hc<0R6@d0080RFDe00L0RVHf091Z>`2?JCX0SfTj08iX>@2=IcP0
S6Hg0080RfDf00H0U6Pg09=Y=`2DJSP0UFdj09A_>`2ELCd209Ac?P0409E`?02FLCd0UW4m09Mb?P80
V7<o0P2IM40209Ia?@80Ug8n0`2HLcl02@2IM400VgI109]f@@2JMD00VgI109eh@`2ONTD0XWe80:Ao
BP020:=iB@040:AjBP2UNd/0YWa<0:MmC@80Z7i>102[PTh40:Z1C@<0Z8=?0`2YQ5020:Z5D@80[XYF
0`2_ReL30;2<F0070;2:G@2`RU/0/8YK0;2:F`2`RUT0/8]G0;2;EP020;2;E0030:f8E02^RED0/8]G
0080/HaH00<0/8]G0:j9E@2]R5@00`2aS5P30;2;E`80[hYF202cSEh0202^RE80[hYC0;6<E`2cSUX0
/heL0;:<G@2aRe`0/8YM202cSUX80;J<FPP0]I1L0P2`ReH20:n:E@80[XUD0P2]R5<20;2;E`030;6<
F02bSET0/hiJ0080]I1L00<0]Y5M0;B?F`2dSe/00`2cSUX30;:=F@<0]8]G0`2cRUH20;:9E@P0/hUG
202cRUH00`2^R5/0[hUL0;6;GP020;6;GP030:n9G02]QeX0[8II00P0/8]G00<0/8aB0:n;D@2]R540
0P2]R5<00`2_RUH0/H]J0;:<F`080;67E@<0/HQD0P2bRED30;>:EPT0/HME0P2bRED20;68E0@0/8MC
202aR5@80:f9C`080;B;E`2cRUH0/XUE0;27D`2_QU80[HA@0:b3C`2[PTh20:b7D`040:^6DP2ZQE40
ZXEA0:V4D080Z8=?102/Qe840:f8D`060:^6DP2/Qe<0[8MC0:f8E02^RED0[hYF0P2`ReL0202XPdh0
ZXE@0:b7DP2]R5<0[XUD0:f8D`2[QU40ZXE@202]Pe420:n6DP040:j5D@2]Q500[HA@0:b3C`80Zh9>
0P2[QU440:Z5D080ZHA?0P2WPT/01P2VPD`0YH1<0:J0C`2XPU<0ZXAE0:^5F0P0ZHA@00@0/HME0;26
E02`QU@0/8ID0P2_QE<20:j4DP80[HA@0`2^QE430:n6DP<0[hI@0`2^QDl20:f4CP80ZX5=0`2[PTh3
0:b3C`@0Zh9:102ZPDT00`2/Pdl0[HA@0:f4D0020:j5D@80[hIB0P2`Qe<20:n6DP040:j5D@2]Q500
[HA@0:b3C`80Zh9>202]Pe400`2^Q580[H=A0:b2D0020:^1C`030:f3D@2_QE<0/8ID00<0ZhI?0P2Z
QDh30:V4C@040:UoC@2ZP4h0ZX1>0:Z0CP80Zh5?0P2/PU020:^2BP040:^2C02/Pdl0[8=?0:b2D080
[89B202/Pdl20:f3D@80[89@00@0Zh5?0:Z0CP2ZP4h0ZGm=0`2[QU420:Z5D0<0ZHA?00H0ZXAC0:^5
E02/QUD0[HMF0:j8E`2`RUT20;6;FPP0[XEA0P2]Q5030:b3C`<0Zh9>0P2_QTh0102_QU00[XEA0:j5
D@2^Q5820:f3D`80[XEA102]Q5020:b3C`080:j9E02[QU40Z8=>0:F0B`2TOdX0YX5<0:V4C`2/Qe88
0:f4D080ZX5=00@0Zh9>0:b3C`2^QE40[hIB0P2`Qe<80:^2CP040:j5C`2_QU00/8MA0;27D@80[hI@
00H0[8==0:V0BP2XOdT0ZX5=0:^2CP2]Q5020:j5D@030:f4D02[PTh0ZX5=00P0[8=?00@0[89@0:^1
C`2[PDl0Zh5?0`2ZP4h0102YOdd0Zh5?0:^1C`2[PDl50:b2D0P0[HA>0P2]Q5030:j5D@<0[hIB0P2]
Q5030:b3C`<0Zh9>0P2_QU80102^QE40[HA@0:f4D02/Pdl20:^2CP060:V5D`2ZQ5<0ZXEA0:b4D02]
Q500[X=>0P2`Pd`80:b3C@80[hIB00@0[XEA0:f4D02]Q500[8=?0P2[PTh20:j5D@030:f4D02/Pdl0
Zh9>0080ZX5=00<0ZH1<0:^2C02ZPD/00P2YP4X0302ZPD/0[HA>0:n6D02aR580[hIB0:f4D02[PTh0
ZX5=0:V0C02ZPDd0[8=?0:f4D080[8MB00@0ZhIA0:Z5D02ZQE00ZHA?0P2XPdh20:Z5D0<0ZHA?0`2X
Pdh40:QoB`030:V0C02ZPDd0Zh9>00<0[8=?0P2[PTh20:Z1C@80ZH1<00D0ZX5=0:V0C02XOd/0Ygi:
0:QoB`020:V0C0030:^2CP2/Pdl0[HA@00L0[HA@202]Pe401`2^QE40[HA@0:b3C`2[PTh0ZX5=0:V0
C02XOd/0102WOTX20:QoB`<0ZH1<0P2SOTX0102TOd/0YH1<0:F0C02VPDd20:N2CP80ZHA?0P2XPdh2
0:N2C@80YX5<202XOd/30:=nB@<0Y7m:0P2UP4/20:EjC`80YW]@00X0YgaA0:QmDP2XOE80ZGiC0:Z5
D@2YQ500Z8=?0:N2CP2VPDd0Y7m;0P2SOTX0202TNDh0YGY=0:QmD02ZP500Zh5?0:Z1C@2YP4X0Z7m9
0`2YOdd20:QnC080Yge;00<0YWa:0:ElB02UO4P01P2UO4P00`2ZO4X0ZG]90:QjB0020:MiA`030:Qj
B02YNdT0ZWa:0080YgU500<0YGY70:=iA`2RNTT00P2ONDX0102NND`0XGa80:1kA`2NNDD209ehA005
09iiA@2ONTH0X7]70:AjB02UNdT00P2VO4X0102UNdT0XWQ609me@`2NM48209ag@P0409eh@`2NND@0
WWU409mjA@80X7]60P2MN4<409iiA0<0WgY500`0W7M209eh@`2ONTD0X7]60:5lA`2PNdH0WgY509ii
A02SOE00XWa?0:1jC@2MMdX209afB@80WGM:00P0Y7]50:=jA02RNDD0X7I409idA02MLTD0W75409]`
A@P0VgI2202MMdP0402JMD40VgI209ag@`2MN4@0WWU509mjAP2PNdL0XGa809Yf>P2JMS`0VgHo09]f
@@2LMTD0WGM:09efB`2NMdh209UgB@80VWQ:0`2KND/02@2LNT`0X7]409mj@`2MN440W7M009]f?`2L
Md00WGQ109ii@P0309ihBB_ooooo000Zooooo`80SF0f0P2<GcD0102>HCL0T6<i099U>`2DIcd209=V
?080TVDk00H0TF@j091S>@2@HcT0Sf8h091T=`2?HcH208iR=@0<091T=`2BIST0UFTl09M[?P2FJD00
UFPo09EX?P2DJ3/0TfLh09=W=P2BISD0TVLd1P2DJ3/209=W>P<0U6Pk0P2EJC`309IZ?@80U6Ln00l0
U6Lm09EY?02EJCX0UFTh09IZ>@2FJcP0TfLf09EY>02GJcX0V6`k09M[>P2DJ3L0Sf<b08eQ<02DIcd0
0P2DJ3/00`2EJCX0UFTh09I[>00209I[=P0309=W=P2DJ3L0UVXi00@0V6`k00@0Uf/j09IZ>@2EJCP0
UFTh0`2FJST309M[>PP0UF/i0P2AICP00`2BIST0TfLj09AX>`0209IZ?@0309M[?P2IKcd0VFlm00H0
VFlm0P2BIcX00`2CJ3/0U6Tl09EZ?@0209M/?`0309Q]@02GKC/0Ufdk00H0Ufdk202LLcl01`2IKS/0
VVll09]`?@2LLCh0WG8o09ic@02OM4400`2PMD8409md@@80WW=000@0X7E209md@@2OM440WW=00P2M
LSl209aa?P80XGI300@0X7E209md@@2OM440WW=00P2MLSl0102IL3`0Vg8n09ie@@2RNDD40:AkA`@0
Y7U60P2SN4D20:9gA0080:1cBP2OLTP0WW9509ib@@2NLch0X7Hl0:5g>`2SNS`30:=h@`030:9g@P2Q
MT40X7E00080X7E000P0Y7Y80:9hAP2PMT@0WgE309id@P2OMD<0X7I40:5gA@<0YGY70P2TNDH30:=h
A@030:5f@`2RMd@0Y7U60080YGY700<0Y7U60:9gA02QMT<00P2RMTD00`2SMdH0Y7Q70:AhA`020:Ei
B080YWY90P2WO4T0102VNdP0YGY70:AiAP2SN4D20:9gA00309ie@@2OMT80XGQ400<0XWU500<0X7M3
09mf@P2PMd400P2PMd4209mf@0<0WWDo00H0W7M309]f@P2JMD40VGA009Qc?`2FLCd209E`?00>09E`
>`2EL3`0U6lk09=]?02BK3d0T6Xm091Y?P2?J3d0VVho09Q/?@2EJCX0TfLh095U=P2@I3D2095U=P06
08YU>029I3L0RF@g08QS=P27HSD0QV4d0P25H3<308IQ=0<0QF0c0P24Gc8207iH<@80OEL`0`1lERl0
101kEBh0OEP[07iI;01oFRd2081K;P0307iI;01lEbX0NUDX0080MUH_0`1eEBh307AD;@0607=B;`1b
DBh0LE0]071?;01^CBX0KD`Y0P1/BbP806e<:`80KdlY00H0KTdZ06e<:`1/BbX0JdX[06]9;@1ZB2`8
06M99`80HT<V0P1SA2L306A5:00306E6:@1YB2L0JDPW00<0J4LV0`1WARD03P1RABD0HdHV06A59P1W
ARL0JDHX06]6:@1/AbX0KTLZ06Y:8`1[Bb@0K4`U06i>9`1_CbP0LE4Z0P1bDR/0101cDb`0M54[07AA
:`1dDB/407=@:P04079?:@1cCb/0Ldl[07=?:`80M50/0`1eDBd0101aCR@0Le0V07EB:01hEB/407YG
;@80OEP^101lEbd207]F;0P0OeX]0P23F2d01024FBh0QEX_08EJ;`26Fc0208ML<@P0Ped`2022GC03
08=M<080PU`_0`21Fbh01021Fb`0PU`]089L;@23GBh208AN;`80QEl`00<0QF0c08=N<@21G2l00P20
Fbh00`21G2l0Peha08EP<`0807mJ;@P0Ped`2024GRd2089L;`<0Ped`0`24GS400`1mFBL0OUXX081L
:P02085M:`0;081L:P1nFRP0OETW081L:P21GB/0PUh^08=N<@23GS80PE`b07mJ<01nF3402024FS80
1024Gc80Peha08=N<@23GS42089M<0<0PE`_00@0OEP^07iI;`1nFBl0OUT_0`1oFS002@20Fc40OUT/
07iI;01oFRd0P5/^07mJ;@1mF2/0NeHY07UD9`0207aG;@<0OEP^0`1nFBl207UF;P@0NUL_0P1kF300
101hDbT0NE@Z07UD:P1iE2X207YE:`80NeH/0140N5D]07MD;01fDb/0MU<[07MD;01jEbl0OEXb07iK
<`1hFbl0NEX^07MH;01gER/0N5D[07]F;01nEbh0OeP_07iI;`0207eH;P0307]F;01jEB/0NE@Z0080
N5<Y0P1gE2`407QE;@80NEH^00<0LTlU07AA9`1eDRP00P1gE2X00`1eDRP0M54W079?9@0206aF9`06
06mD9`1_DRH0LU4V07IA9`1gD2L0NDlW201fD2T00`1]CB@0KdlV071@9`02075A:006071@9`1_CbH0
KDdT06m?:01^CRL0K4`U0P1[Bb@00`1/C2D0KThW06m?:00206];9080K4`U00D0KDdV06i>9`1_CbP0
KdlX06Y<:00306U;9`80J4XV0P1WBBD206a>:P0306]=:@1ZC2P0JD/W0080J4XV00l0IdTU06Q68`1Y
Ab@0JTPU06]99P1ZB2D0JDLT06M58P1VA240J4XX06M99`1VB2H0I4HT06948P1Q@b400P1O@Al205i1
7`0505m2801QA280HdHT06E89P1WBRP00P1XBbT00`1YCBP0J4`W06I:9@0206E9900306I:9@1XC2L0
JDdX0080J4/Q0P1YC28306Y=8`0306]>901/C2D0K4`U0080K4`U0P1]CBH206i>9`80JdlW0`1/D2P3
06eA:@@0Ke8Z0P1`Db/2075D;00607IF;@1gEbh0MeL^07UI<01jFS40Ne/b0P1lG3<0201kF2h0NUL]
07YG;@1jEbd0O5T_07mL<P22GcD0Q64g0P20GS02085O<@<0PV0b00X0Pf4c081P;`21HC00Pf4a08IR
<P28I3@0RfDf08iU=`2?ISP0R68c0P29Hc@00`2:I3D0RfDf08aV=`0208eW>00608]V<P2<Ic<0SFPd
08eX=02>JCD0SfXf0P2@JcL3095]>@80TVhj0`2CKc/509Mc@`<0V7A400X0U79409Ab@P2GLd<0VG=2
09ad@@2NMD40WWDo0:1e@02ONTH0WWU50P2LMd<0102MN4@0WgY60:9mB@2SOTX20:F1A`060:J1BP2W
PTd0Z8=>0:V4D02YPe80ZXAC0`2YQD/20:Z6C0<0ZhM=0P2[QU820:b7D`<0[HQD00D0[XUE0;6<F02`
ReL0/8]G0:n:EP020:f8E0030:j9E@2_RUH0/8]G00<0/8aH0`2_ReL20:j:EP80[h]A00<0/8]D0;2;
EP2`ReL00P2aReX00`2aRe`0/HaH0;6<F0060;6<F080/hUG0P2dRUP20;F;F@80]XaJ0P2dReD00`2e
S5P0]H]I0;J<G0020;N<G`040;R=HP2cS640/haQ0;><H@80]8eR0`2eSV<30;F@G080]8mK0`2cSUX0
0`2fTE`0]I1K0;>>F@020;:=F0030;>>F@2eT5/0]Y5L00P0/hiI0P2dSe/30;>>FP<0/XeI202`ReL8
0;6<F080]H]I0P2dRUP0102cREL0/XQF0;:8EP2aQeD20:n:E@<0[XUD0`2]R5<20:j9E@@0[hYF0P2`
ReL20;6<F0040;2;E`2_RUH0[hYF0:j9E@80[HQD202`RUd80;2;E`80[XUE1@2_RUH20;2;E`P0[hUJ
202^RE@30;68E0030;27D`2_QU80[XEA0080[XEA00<0ZHA@0:Z5D@2/Qe<00P2^RED0302/Qe<0ZXEA
0:V4D02_ReL0[XYF0:f9E@2/R5@0ZhMC0:Z6DP2YQE40Z8A@0:V4D080ZXEA00<0ZhIB0:b7D`2/Qe<0
0P2]R5@80:n:EP80/XUE0`2aR5@30;27D`050:f3D@2^Q580[XAB0:n5D`2`QU@00P2aQeD0102bR5H0
[XAB0:j4DP2^Q5820:f3D@<0[89@0`2XPdl50:V4D080[8=;00@0[8==0:f4D02]Q500[XAB0P2^Q5@8
0:n6DP80[HA<00@0[XE?0:j5D@2^QE40[hEC0P2_QED80:f4D0030:Z1C@2[PTh0[HA@0080[XEA00<0
[HA@0:^2CP2ZPDd0202/Pdl01P2bQDh0/HA=0;64C@2_PT/0[X5:0:f0B@80[7m80P2^QDl01@2_QU00
/8MA0;27D@2`Qe40/HQB0080/XUC0P2aR5@00`2`Qe<0[hIB0:j5D@020:b3C`030:^2CP2ZPDd0ZX5=
0080Zh9>00L0[8=?0:f4D02]Q500[XEA0:b3C`2]Q500[hIB0080/8MC00<0[hIB0:f4D02/Pdl0202]
Q5020:Z1B`80ZH1:00`0Zh9<0:f4CP2_QU00/HQB0:j5D@2]Q500[89@0:^1D@2[P5<0[H9G0:n4F@2`
QE/20:f3D`040:f3D@2/Pdl0[8=?0:b3C@80[8=;0P2]Q5030:j5D@<0[hIB0`2^PeP20:f2E`<0[85F
202]Q5040;27D`@0[hIB00<0/8MC0:n6DP2]Q5000P2[PTh00`2/Pdl0[HA@0:j5D@020:n5D`040:j4
DP2]Pe40[H=A0:b2D080Zh5?202[QEP00`2_QU80[XEA0:b3C`020:^2CP030:b3C`2^QE40[hIB00P0
ZHA?0P2YOdd00`2ZP4h0Zh5?0:b2D0020:j4DP040:n5D`2^QE40[XEA0:j5D@80[HA@0`2/Pdl0102Y
Odl0ZX1@0:b2D02]Q5020:j5D@030:f4CP2/Pd/0Zh9:00<0[8==0P2]Q4h30:j5C`P0Zh9>0P2/Pdl2
0:^2CP<0ZX5=00L0ZH1<0:QoB`2YP4`0ZX5=0:^2CP2/Pdl0[XEA0080[hIB0`2aR5820;27D@<0[hI@
202_Q540102^QDl0[HA>0:f4CP2/Pdd20:^2C080ZX5;0`2[PTh30:b3C`80[HA@00<0[H=A0:^1C`2Z
P4h00P2XOT`00`2ZP4h0Zh5?0:f3D@030:b2D080[H=A0`2^Q5800`2]PE00[81?0:]oCP020:YnC@03
0:]oCP2/P4l0[H5@00<0ZH1<00<0ZX5=0:^2CP2/Pdl00P2/Pdl20:n6D0040:j5C`2]Q4h0[HA>0:b3
C@80Zh9<0P2_QU80102^QE40[HA@0:f4D02/Pdl20:^2CPP0[X=H0P2]Q5030:b3C`<0Zh9>0P2[PE40
102[PDl0Zh9>0:^2CP2[PT`20:^2BP80[8=;00@0[8==0:b3C`2/Pdl0[89@0P2/PU890:V0C080Zh5A
00@0Zh5?0:b3C`2/Pdl0[8==0P2]Q4`02`2[PdD0Zh=60:^3B02[PT`0Zh5?0:^0D`2[P5D0Zh1F0:Ao
B`2UP4`0Yh9>0080Z8=?00H0Yh9>0:F0C02TOd/0[7i=0:YlB`2YNdX30:MiB0030:QjB@2YNdX0ZH1<
00L0ZH1<0`2YOdd30:Z0CP80Zh5?0P2XOT`30:UoC@<0ZX1>0`2UP4`20:AoB`<0Xgi:202WOD/80:J1
C@80ZGm?00@0ZGm=0:V0C02YP4`0ZH1:0P2YP4P00`2VODT0Ygi:0:V0C0020:Z1C@060:V0C02WOTX0
YWe90:IlC02WODd0ZGm=0P2ZPDd00`2YP4X0Ygi60:ImA@080:MnB0040:5lB02PNdL0X7]70:1kA`80
WgY60P2NNDD0102WOTX0YGa80:9iA@2PMd<209ie@@0509mf@P2PMd<0WWU409mjA@2RODP00P2TOdX0
0`2SOTT0XGa709mjA@0209mjAP0409iiA@2MN4@0WGQ409ag@`80VgI200<0VgI109eh@`2NND@00P2P
NdH0102NND@0WGQ309eh@`2KMT430:5hA0<0XWU50P2SNTH00`2LMd<0WWU50:1kA`020:5lB00>0:1k
A`2NNDD0W7M30:EiB02TN4L0XgM60:9fA@2QMD@0X7A309mc@P2NLT40X7Y;09ihB@2LMTL209YdA@03
09]eAP2LMTL0WGM800P0VWE100@0Ug8n09Qc?`2HLcl0VGA00P2JMD4209]f@PP0VgE600<0WGM809af
A`2KMDH00P2JM4D02`2LMTL0WWQ90:1jB`2MN4@0W7M309]f@P2JMD40VgI209ag@`2NNDD0WgY600<0
XgU7:oooool002[ooooo00L0SV4g08eP=P2<GcD0S5le08iQ=`2@HcT0TVDk0080TfHl0P2BIC/2095T
>P80T6<i00<0Sf8h095U>02@I3L00P2?HcH0102@I3L0TVHi09AX>`2EJC`209EX?`0609AW?@2DJ3/0
TfLh09=W=P2BISD0TVLd0`2CIcX809AX>`<0UFTl0P2FJSd209=V?@0309AW?@2DJ3/0UFTj0080UVXi
00X0Uf`i09=W=P2EJCP0Uf/j09Q/>`2GJcX0U6Pg091T<`2=HC00U6Lm0P2DJ3/00`2EJCX0UFTh09I[
>00209I[=P0309=W=P2DJ3L0UVXi00@0V6`k00@0Uf/j09IZ>@2EJCP0UFTh0`2FJST309M[>PP0UF/i
00H0TFDh099V>@2CIcX0U6Pk09EY?02FJSd209M[?PP0VFlm00D0TfPk09AY?02DJC`0UFXm09M/?`02
09Q]@00309U^@@2HKS`0V6hl00H0V6hl202LLcl209Y_?00409]`?@2LLCh0WG8o09ic@0X0WgA100<0
X7E209md@@2OM4400P2NLd0209eb?`0409aa?P2PMD80X7E20:1e@P<0WgA10P2NLd00102KLSh0W7<o
09mf@P2QN4@30:=jAP040:9iA@2SN4D0XgQ50:=hA@<0XWM40P2QMT<0202QM4X0X7A709mcA02OLd80
Wg@o0:5f?`2SNCl0Y7Xn0`2SN4<00`2RMd80XGI10:5f@@020:1e@0030:AjB02RN4H0XGM500<0WgE3
00<0X7I40:5gA@2UNTL00P2UNTL20:AiAP<0XgQ500<0XGI30:9gA02TNDH00P2UNTL0102TNDH0XWM4
0:5f@`2RMTD20:=gAP80Y7Q70`2UNDP01`2VNTT0YW]80:IkB02UNTL0Y7U60:=hA@2RMd@00P2QMT<0
0`2NMD40WgI20:5hA0020:9iA@030:5hA02PMd<0WgI20080X7M10P2OMT0309ie?`0509ed?P2JMD40
VWE109Ud@02HLcl00P2GLSh209Ia?@0609A_>P2DKc/0Tfhj099/>`2AJc`0T6Xm0P2?J3d0102HKSh0
UV`l09=Y>@2AIcL308mU=@06091V=P29I3L0RF@g08QS=P27HSD0QV4d0P25H3<01@24Gc80QV4d08EP
<`25H3<0Q5lb0080Peha0P22GC00101oFC80OUPa07iH<@1nF34207eG<080O5H_00<0O5L[07eH;01n
FBd00P1nFBd00`1lEb/0NUDY07UD:00207EE;P80M5@]0`1cDb`01@1bDR/0LE0]075@;@1`Cb`0Kdh[
0080KTdZ0P1]C2T806a;:P0606m?:@1^CRP0KTdZ06e<:`1/BbX0JdX[0P1ZB2`206Q::0@0IdTW0P1V
B2H0101R@bH0Hd@W06=49`1SA2L206A5:080IDHY0`1YB2L206Q79P<0IdHU0P1SARH00`1UARL0J4LX
06Y7:@0206a7:P0706m8:`1ZBR<0JTXS06a<9@1]CBH0KdlX071@:@02075A:P03079B:`1cD2X0Le0Z
0080Le0Z101bCbT307=?:`80M50/0`1eDBd0101cD2H0M54W07MD:P1iER`407]H;P@0OEP^101lEbd8
07mJ;@<0Q5T^00<0QEX_08IK<026Fc000P27G34808=M<0P0PUd`00@0Q5ha08=M<023GC00Ped`0P22
G2l2085K;P80PU`]0P23GBh01`24GRl0QEl`08EO<025Gc00Q5lb08=N<@22GC000P21G2l00`22GC00
Peha08AO<P08081K;PP0Ped`2024GRd2089L;`<0Ped`0`24GS400`1nFRP0P5`Z085M:`02089N;00;
085M:`20G2X0OUXX081L:P21GB/0PUh^08=N<@23GS80PE`b07mJ<01nF3402024FS83081K;P80OeX]
101nFB`407mJ<0@0OUT_00<0OEP[07iI;01oFRd00P1oFRd00`1nFB`0O5LZ07]F:@0207aG;@<0OEP^
0`1nFBl807YG;`@0NE@Z0P1jEB/207]F;00307UF;P1hEBd0Me@/0080Me@/0140NEH^07aI<@1mFS80
N5/_07UJ;P1gF2`0MeH[07QE:`1kER`0OUL^07mH;`1nFBl0OEP^07aG;@1kER`0NUD[07UD:P0207QC
:@P0Me@/00<0M54W07EB:01fDbT00P1gE2X02@1fDbT0ME8X07AA9`1/ERL0KEDW06mD9`1`DbL0Le8W
07AA9`0207M@9`P0Le0X00<0KThU06m?9P1`D2L00P1aDBP01P1`D2L0KdlV06i>9@1_CbP0KThW06a<
9@80Jd/T00<0K4`U06i>9`1_CbP00P1_CbP0101^CRL0KDdV06e=9P1/C2D206];9080JT`X0P1YBbL3
06Q:9P0606M99@1YBbL0JD/W06Q:9P1WBBD0ITPT0P1UAb<0101TAR80J4HS06U7901ZB2D206]99P0;
06U7901WAB80IT@Q06M99`1VB2H0IDLU06A6901SAB<0HT@R06538@1P@R000`1P@b40101QA280HdHT
06A79@1VBBL206M::00306U=:01XC2L0ITXU0080IDTT00<0ITXU06Q<9`1YCBP00`1XBb<206U<90<0
JTdU00@0Jd/T06a<9@1/C2D0K4`U0P1]CBH206i>9`<0JdlW0P1/D2P306eA:@0406iA:@1_DRX0Ke8Z
06mB:P80L5<[0P1aE2`207IF;@0407MG;P1hF2l0NET`07YJ<@80Ne/b0P1lFBl207]H;P0407eJ<01o
G380PEhd08=P=P80P5h`0P21Gc44089P<P08081P;`21HC00Pf4a08IR<P28I3@0RV@e08eT=P2>ICL2
08QR<`0408US=02:I3D0RfDf08aV=`80SFLh00H0S6Lc08eX=02=J3@0SVTe08mZ=P2@JcL2095/>0<0
TVhj0`2CKc/209A`?00309Ea@@2FLT80UW920080Ug=30`2HM4@02@2ELdD0UG=309QdA02JM4<0WGE2
09ie@@2OMT00X7E009iiA@0209ehA00509ag@`2MN4@0WgY60:9mB@2SOTX00P2UPDL0102VPDX0Yh9=
0:R3CP2XPdl20:V3DP<0ZHE;0`2ZQT`20:^7C@80ZhIB0P2/Qe<40:f8E0040;6<F02`ReL0/8]G0:j9
E@80[HQD00<0[XUE0:n:EP2`ReL00`2`S5P20:n;E`<0[XYF00H0[h]A0:n:D`2`Re@0/8]F0;2;E`2a
ReX20;6;G0P0/XeI0P2cREL20;B:F080]H]I0P2fS5X20;B;E@060;F<F02eReT0]XaL0;J;GP2gS5l0
]haQ0`2cS6430;B=HP80]HiS0P2eT5`30;B?F`<0/hiJ00<0]Y5L0;F@F`2cSUT00P2bSEP00`2cSUT0
]I1K0;JAG0080;>>F@80]8mK0`2cSUX30;:=F@P0/8]G202aS5P20;F;F@80]8YH00@0/hUG0;:8EP2b
R5H0/XQF0P2_RUD30:j9E0<0[HQC0P2]R5@0102^RED0[hYF0:n:EP2`ReL20;6<F0<0/8]G00<0[hYF
0:j9E@2^RED00P2]R5@80;2:F`P0/8]G0P2^RED70:n:EPP0[hUJ202^RE@30;68E0030;27D`2_QU80
[hIB0080[XEA00<0ZXEA0:^6DP2/Qe<00P2]R5@00`2/Qe<0ZhIB0:Z5D@020:n:EP040:j9E@2]R5@0
[8MC0:^6DP@0ZXEA0P2[QU820:b7D`80[HQD202_RUH20;:9E@<0/HQD0`2`Qe<20:j4DP<0[hEC0`2`
QU@80:f3D@P0ZHA@0P2/Pd/0102/Pdd0[HA@0:f4D02^Q5820:j4E0P0[hIB0P2]Q4`0102^QDl0[XEA
0:j5D@2_QE<20:n5E@P0[HA@00<0ZX5=0:^2CP2]Q5000P2^QE400`2]Q500Zh9>0:Z1C@080:b3C`06
0;:5CP2aQ4d0/8=<0:n2B`2^PDX0[H190P2/OdP00`2/Pdd0[HA>0:f4CP020:j5C`050:n6D02`Qe40
/HQB0;68DP2aR5@00P2`Qe<01@2_QU80[HA@0:b3C`2/Pdl0Zh9>0080ZX5=0P2[PTh01`2/Pdl0[HA@
0:f4D02]Q500[8=?0:f4D02_QU800P2`Qe<00`2_QU80[HA@0:b3C`080:f4D00@0:^2C02ZPD/0ZH1:
0:V0BP2[PT`0[HA>0:n6D02`Qe40[XEA0:f4D02/PU00Zh5A0:^0D`2]PUD0[hAI0;25FP80[H=C00@0
[H=A0:f4D02]Q500[XE?0P2^QDd30:f4D080[XEA0`2_QU830:j3EP<0[H9E0P2/PE@80:f4D0<0/8MC
1@2_QU800`2`Qe<0[hIB0:f4D0030:^2CP030:b3C`2]Q500[XAB0080[XAB0P2]Pe430:b2D0P0ZhEF
00<0[hIB0:j5D@2/Pdl00P2[PTh00`2/Pdl0[XEA0:n6DP080:V4C`050:UoC@2ZP4h0ZX1>0:^1C`2]
Pe400P2^Q580102_QE<0[XEA0:j5D@2^QE420:f4D0<0[8=?00<0ZX1@0:^1D@2/PU000`2^QE400`2]
Q4h0[8=;0:^2BP030:b3C@<0[HA>0P2^QDl80:^2CP80[8=?0P2[PTh60:Z1C@80Zh9>00@0[8=?0:f4
D02^QE40[XEA0P2`Qe430:n6D0<0[XE?202^Pe030:f4CP030:b3C@2[PT`0Zh9<0080ZX5;0`2[PTh2
0:b3C`<0[HA@00<0[89@0:^1C`2ZP4h00P2YOdd00`2ZP4h0Zh5?0:b2D0030:b2D0<0[H=A0P2^Q580
0`2]PE00[81?0:]oCP020:YnC@030:]oCP2/P4l0[H5@0080ZH1<0P2ZPDd20:^2CP80[8=?0`2^QDl0
0`2]Q4h0[8==0:b3C@020:^2C0<0[XEA0P2]Q5030:b3C`P0[X=F0P2]Q5030:b3C`<0Zh9>0P2[PE40
102[PDl0Zh9>0:^2CP2[PT`20:^2BP80[8=;00@0[8==0:b3C`2/Pdl0[89@0P2/PU890:V0C080Zh5A
00@0Zh5?0:b3C`2/Pdl0[8==0P2]Q4`02`2[PdH0Zh=80:^2BP2[PT`0Zh5?0:^1D@2[P5<0Zh1E0:Ao
B`2UP4`0Yh9>0080Z8=?00H0Yh9>0:F0C02TOd/0[7i=0:]mC02YNdX20:MiB0030:QjB@2YNdX0ZWa;
00P0Z7m;0`2XOT`30:UoC@80ZX1>0P2XOT`30:UoC@<0ZX1>0`2UP4`20:AoB`<0Xgi:202WOD/80:J1
C@80Z7i>00@0Z7i<0:QoB`2XOd/0Z7m90P2XOdL00`2VODT0Ygi:0:V0C0020:Z1C@060:V0C02WOTX0
YWe90:IlC02WODd0ZGm=0P2ZPDd00`2YP4X0Ygi60:ImA@080:MnB080XWe90P2QO4P20:1kA`80WgY6
00H0Ygi:0:ElB02SNTH0XGQ40:1g@`2QN4@20:9iA@80X7]60P2RODP0102SOTT0XWe80:5lA`2PNdH2
0:1kA`80WgY600L0WWU509ehA02MN4@0WGQ409ag@P2MN4<0WgY50080X7]600@0WgY509eh@`2MN4<0
W7M21`2RNDD0102QN4@0WGQ409iiA@2ONTH20:1kA`0309mjAP2NNDD0WGQ40080XgU700@0XWQ60:5g
A@2PMT@0WgE30P2NM480202ONDX0WWQ909afA`2KMDH0VWA509]eAP2LMTL0WGM8202JMD4209Ud@080
VWE10P2KMT8209ag@`P0VgE60100WgU:09egB02LMTL0VgE609YdA@2LMTL0WGM809ihB@2MN4@0W7M3
09]f@P2JMD40VgI209ag@`2NNDD0WgY60`2SNDL[ooooo`00:_ooool208iQ=`0608eP=P2<GcD0SF0f
08mR>02AI3X0TfHl0P2BIC/2095T>P@0T6<i0P2BIST01P2AICP0T6@g091T=`2AICP0TVHi09=W>P80
U6Ln00H0U6Lm09=W>P2CIcP0TfLf099V=@2BIc@2099V>@80TfLj00@0U6Pk09EY?02EJC`0UVXm0P2C
IcX209AX>`<0UFTl0180UVXm095T>`2BIC`0TfHl09AX>`2EJCX0UVXi09M[>P2HKCX0TfLf09AX=`2F
JST0Uf/j09IZ>@2DJ3L0TFDd08iR<@2DIcd209AX>`0309EY>P2EJCP0UV/h0080UV/f00<0TfLf09EY
>02FJST0102HK3/209IZ>@80UFTh0`2FJST309M[>PP0UV`j0P2CIcX209AX>`0409EY?02FJSd0Uf/n
09M[?PP0V6hl0P2FJch209M/?`0409Q]@02IKT40VVm209Y_@PP0VW0n202LLcl01@2JKc`0Vg0m09]`
?@2LLCh0WG8o0080WW=03@2OM44209ic@080WG8o102OM4430:1e@P040:5f@`2MM400WWE10:1g@`@0
XGQ400<0X7M30:9gA02RMd@00`2QMT<30:1e@P080:=gBP2RMTL0XGE40:1d@`2QMT40XWM20:Ai@P2U
Nd430:=h@`80XWM20`2QMT40202TNdL0XgY60:5hA02PMd<0WgI20:1g@`2QN4@0XWU50`2UNTL20:Ai
AP<0XgQ500<0XWM40:=hA@2TNDH00P2UNTL00`2TNDH0XgQ50:9gA0030:=gAP80Y7Q7102UNDP20:Ai
AP040:=hA@2RMd@0XWM40:5f@`80X7E200<0WWE109mf@P2QN4@00P2RNDD00`2QN4@0WgI209ie@@02
09mf@P80WWE10`2MM4000`2LLcl0Ug8n09Mb?P0609Mb?P0<09=^>@2CKSX0TVdi095[>P2@JS/0SfTl
08mX?@2>Ic`0UV/n09AY?02BIcX0Sf@g0`2>HcH01`2?I3L0RF@g08QS=P28HcH0Qf8e08IQ=025H3<0
0P24Gc802025H3<0Q5lb08=N<@22GC00PE`_081K;P1oFRd0OUT/0`1oFC8207iH<@<0OEL`00P0NUD[
07]F;01kER`0O5L]07]F;01jEB/0NE@Z07QC:@80Le</0P1bDR/3075A:P03071@:@1^CBX0KTdZ00H0
KTdZ201/BbX206i>:00606e<:@1/BbX0JdXY06Y9:P1ZB2`0JDL[0P1YBbT0101XBRP0IdTW06M99`1V
B2H206E79@80Hd@U0P1TABH306E69`0306I7:01ZBBP0JDPW0080JDPW0P1XAbH206M69@80I4LU00<0
ITPV06U89`1[B2P00P1]BBT01`1`BBX0JTXS06Y:8`1[Bb@0K4`U06i>9`1_CbP00P1`D2T00`1aDBX0
LDhX079?:@06079?:@<0M54[0P1eDR`307IC;@0407EB:01gE2X0NEH/07aI;`<0OEX`00<0O5T_07eH
;P1mF2h01P1mF2h8081K;P0408AI;P25FRl0QEX_08EJ;`<0QU/`00<0Qe`a08AN<@24GS401P24GS48
08=N<@<0Q5ha0P23GC03089L;`80Ped^0P24GRl408EO<00308AO<P23GS40PUd`00<0PUd`00<0Peha
08AO<P22GC001`22GC0808=M<0P0Q5h_0P22G2l308=M<0<0Q5ha00<0P5`/085M;@22GRh00P24H300
2`22GRh0PEd]081L;020G2X0PEd[089N;P23GS40Pehb085L<P1oFS00OUPa00P0PU/b0P1nFB`207eH
:`<0O5LZ0P1kERT01@21G380P5/a081K<@1oFS00OUT_0080OEP^00T0O5L]07]F:@1lEbX0OUT/07mJ
;@20Fbh0OeX]07iI;01mF2/00P1lEbd307eH;P<0OUT_201jEbl307UD:P80NUD[0`1kER`207YG;`0>
07UF;P1hEBd0N5D]07UF;P1jEbl0NeP`07MJ;P1hFBd0MeP/07MF:`1hEB/0NeH/07eF;@1nEbh207eH
;P0307aG;@1kER`0NUD[0080NE@Z00<0N5<Y07IC:`1fDb/00P1fDb/407EB:P80MU<Y101hEB/207IC
:@80Ke@W00H0LE@X07=D:01dDbP0ME8X07AA9`1fDBL8079?9`0306i>9@1_CbH0LE4X0080LU8Y00H0
LE4X06m?9P1^CRD0KdlX06i>9`1]CBH206a<9@0<06e=9P1^CRL0KdlX07=C;01bDR/0L50Y06i>9`1/
C2D0JTXS06U98P1XB240JddY0`1ZC2P206U;9`80J4XV00H0IdTU06I8901VB2@0IDLS06A68P1SAB42
0694800306Q7901YB2D0JTTV0080JTTV00<0J4LT06M68`1UA2400`1UAbD206A69080HdDS00<0HT@R
06=6901SAR@0101SAR@01P1TAbD0IDPV06E89P1XC2L0Id/V06I:9@80IDTT00<0ITXU06M;9P1XC2L0
0P1WBR8206Q;8`<0JD`T00@0JTdU06U<901YC2@0JD`T0P1ZCBD306]>9P0406Y>9P1[CbL0JdlW06]?
9`80K50X0P1]DBT306iA:@80Ke8Z0`1`Db/01P1eEB`0MUH]07IF;@1gEbh0N5P_07UI<080NUXa0P1n
Fc4207eJ<00407iK<@1oG380P5dc085N=0<0P5h`0P21Gc43089P<P06081P;`21HC00Pf4a08IR<P27
Hc<0RV@e0P2=I3H208QR<`0308US=02:I3D0RfDf0080S6Hg00<0SFLh08iY=@2>JCD00P2?JSH0102@
JcL0TF`h099]>@2BKCT309=_>`80U70l0`2ELCd01P2BKSh0Tflo09A`@02ELD40UW9209QdA080VGE5
00T0UWA609IdA02IMDD0VgE409if@`2PMd<0X7M10:9g@P2NND@00`2MN4<0102NND@0X7]60:5lA`2R
ODP20:B0AP060:F0B@2VPD`0Yh9=0:R3C`2XPU40ZH=B0P2XPd`20:V4C@<0ZXE>00@0ZhI?0:^6DP2[
QU80ZhIB0P2/Qe<30:f8E0040;2;E`2_RUH0[hYF0:j9E@80[HQD00<0[XUE0:n:EP2`ReL00P2`S5P2
0:n;E`<0[XYF00H0[HUE0:n:D`2_RU<0/8]F0;2;E`2`RUT20;6;G0030;6;GP2dSe/0]8mK00H0]8mK
0P2cREL20;B:F080]H]I0P2fS5X20;B;E@030;F<F02eReT0]H]K0080]X]N00<0]X]P0;:<G`2bS5l0
0P2cSF030;B>H@030;F?HP2eT5`0]8mK0080]8mK0P2cSUX20;:=F@030;F@F`2dSeX0/hiI0080/XeH
00<0/hiI0;B?FP2eT5/0202cSUT20;B?F`<0/hiJ0`2bSET80;2;E`P0/HaH0`2dRUP30;>9E`80/XQF
0P2_RUD30:j9E0<0[HQC0P2/Qe<0102]R5@0[XUE0;2;E`2aS5P20;:=F@040;2;E`2_RUH0[hYF0:n:
EP<0[XUE00<0[HQD0;2:F`2`RU/01P2`RU/80;2;E`@0[hYF1@2^RED80:j8F@P0[XUD0`2aR5@20;27
D`<0[hIB0P2[QU80102/Qe<0[HQD0:f8E02/Qe<20:^6DP050:n:EP2^RED0[XUE0:f8E02/Qe<00P2[
QU80102ZQE40ZhIB0:^6DP2[QU830:b7D`80[HQD202^RED20;:9E@<0/HQD0`2`Qe<20;26E0<0[hEC
0`2^Q5820:^1C`040:b2D02]Pe40[H=A0:j4DP80[hEC202YQ5020:b3B`040:b3C@2]Q500[HA@0:j4
DP80[XAD202_QU820:f4C0040:j5C`2^QE40[XEA0:n5D`80[hEE202]Q5000`2[PTh0[8=?0:f4D002
0:j5D@030:f4D02/Pdl0Zh9>00P0[8=?0P2_Q4l00`2^Pdh0[H9=0:b1C0020:^0B`030:YoBP2[PTh0
Zh9>00<0[8=?00@0[HA@0:j5D@2_QU80[hIB0P2`Qe<00`2_QU80[XEA0:f4D0020:b3C`@0Zh9>0`2/
Pdl20:f4D0030:b3C`2]Q500[XEA0080[hIB00<0[XEA0:f4D02/Pdl0202]Q5020:^2C00D0:Z1B`2Y
P4X0ZX5;0:b3C@2^QDl0/8MA0:j5C`2]Q4h0[8=?0:^1C`2[PE40[H9E0:n4E`2`QEX0[89B0:f3D`2]
Pe40[XEA0:n6DP2`Qe420;27C`040:b3C`2]Q500[HA@0:f4D080[XEA0P2_QU820:n4E`80[X=F0`2]
PUD00`2/PE@0[HA@0:f4D0060:f4D0T0[hIB00L0[XEA0:b3C`2[PTh0ZX5=0:^2CP2/Pdl0[HA@00<0
[89@0P2]Pe430:j4DPP0[8IG00<0[hIB0:j5D@2/Pdl00P2[PTh00`2/Pdl0[XEA0:n6DP080:V4C`80
ZX1>00<0Zh5?0:b2D02]Pe400P2^Q580102_QE<0[XEA0:j5D@2^QE420:f4D0<0[8=?00<0Zh5A0:b2
DP2]Pe400`2^QE400`2]Q4h0Zh9:0:Z1B@020:^2C080[8==0`2]Q4h00`2^QDl0Zh9>0:^2CP060:^2
CP<0[8=?0P2[PTh30:Z1C@030:^2CP2/Pdl0[8=?00D0[8=?0`2^QDl20:f4CP<0[8==202/PDh20:f4
CP<0[8==0`2[PT`20:^2CP80[8=?0`2]Q500102^QE40[89@0:^1C`2ZP4h20:UoC@030:Z0CP2[PDl0
[89@0080Zh5?0P2/PU030:f3D@040:j4DP2]PE00[81?0:]oCP80ZWi=00@0Zgm>0:b0C`2]PE00ZH1<
0`2ZPDd30:^2CP030:b3C`2^QDl0[HA>0080[HA>0`2/Pdd0102[PT`0[8=?0:b3C`2/Pdl20:f4D0<0
[XEA202^PeH20:f4D0<0[8=?0`2[PTh20:^1D@040:^1C`2[PTh0Zh9>0:^2C080Zh9:0P2/Pd/0102/
Pdd0[8=?0:b3C`2/PU020:b2DPT0ZH1<0P2[PE40102[PDl0[8=?0:b3C`2/Pdd20:f4C0040:^3B02[
PTX0Zh9<0:^2C080Zh5?00D0Zh5A0:^0D`2UP4`0YX5=0:N2CP020:R3C`060:N2CP2VPDd0YH1<0:]o
CP2YOD`0Z7a;0`2VNTT00`2WNdX0Z7a;0:MnBP070:MnBP80YWa:0`2WOD/50:QnC0<0ZGm=0`2ZP4h3
0:J1C@80YH1<0`2TOd/80:MmB`P0YX5=0P2VO4`0102VO4X0YWe90:ImB@2VODL20:ImA@030:ImB@2W
OTX0ZH1<0080ZX5=00<0ZH1<0:MnBP2VODT00P2WODd0102YOdd0ZH1<0:V0C02YP4X20:MnAPP0Ygi8
0`2SOTX20:9mB@<0XGa80P2VODT40:AkA`050:ElB02VODT0Xgi90:9mB02QO4L00P2PNdH00`2QO4L0
XWe80:9mB0030:5lB080X7]70`2ONTH00`2MN4<0WWU409mjA@0309mjA@80WWU400D0WGQ30:AkA`2T
NdL0XgY60:9iA@020:5hA080X7M300<0WGQ409iiA@2ONTH00`2ONTH00`2NNDD0WGQ40:=iA`020:9h
AP080:5gA@2PMT@0WgE309me@`2NM480WgU:09ihB@2LMTL309]eAP80W7I7202JMD4209]f@P80W7M3
102MN4@809afA`040:1jB`2ONDX0WWQ909afA`<0VgE600T0W7I709ehA02LMd<0VgI209Ye@@2KMT80
W7M309iiA@2ONTH00`2RN4H[ooooo`00:_ooool00`2?HSP0SV4g08eP=P0208eP=P0308mR>02AI3X0
TVDk0080TF@j1P2@HcT00`2CIcX0TVHi099V>@02095U>003091T=`2AICP0TFDh0080TfHm00L0TfHl
09=W>P2CIcP0TfLf099V=@2BIc@0TFDh0080TVHi00<0TfLj09AX>`2EJC`00P2FJSd309=W>P80U6Pk
0`2EJC`02P2@HcX0TF@k099U>`2CIcX0UFTj09IZ>@2GJcX0V6dj09=W=P2DJ3L309IZ>@0409AX=`2A
IC@0T6@c09AW?@80U6Pk00<0UFTj09EY>02FJcP00P2FJcH00`2DJ3L0UFTh09M[>P0309Q/>`0309M[
>P2FJST0UFTh0080UFTh0`2FJST309M[>PP0UV`j0P2DJ3/209EY?00409IZ?@2GJch0Uf/n09M[?PP0
V6hl0`2HKD000`2IKT40VVm209Y_@P0209]`@`P0Vg4o202LLcl209]`?@80W74n0P2MLSl409ic@0@0
WgA10P2PMD8609md@@@0WW=000@0WgA10:1e@P2PMD80XGI30P2RMd@50:1g@`80WgI200<0WWE10:5f
@`2QMT<00P2PMD8409md@@080:AhA`2SMdH0XWI50:5f@`2RMd@0XgQ30:EjA@2VNdH40:=h@`@0XWM2
00P0YGa60:=jA02QN480X7M109mf@02PMd40XGQ20:9i@`<0YGY70P2TNDH40:=hA@H0Y7U600<0XgQ5
0:AhA`2TN4L01`2TN4L20:=hA@040:9gA02QMT<0X7E20:1e@P80WgA10P2OMT830:5hA0030:1g@`2N
MD40WGA000<0WG=10`2LLT0209]a?`0409A_>`2EL3`0UG0l09E`?0<0UW4m00L0Ug8n095/=`2AK3P0
T6/g091Z>@2?JCX0SVPk0080SVLl00@0TVTm095X?02?ISX0S6<g0P2;HSH00`2<HcL0SF@h08QS=P02
08MR=@0308IQ=025H3<0Q5lb0080Peha00H0Q5lb08=N<@22GC00P5/^07mJ;@1nFB`207aG:P@0OeTb
0P1nF34207eG<0@0NE@Z0P1hDbT207MB:0<0LE4Z0P1`D2T306m?:080K4/X0`1]C2T306i=:PP0JdXY
0P1]CBL0201/BbP0JdXY06Y9:01YB2T0JDL[06Q6:P1ZC2X0JD/Y0P1XBRP206I89P0406E79@1TAR@0
I4HT06A69080IDLU101VB2H206Y9:0<0JDPW0`1XAbH02@1UBB@0ITXU06M99@1ZBBH0K4XW06i::01_
BbT0LDXY06Y:8`0206];900306a<9@1^CRL0KdlX0080KdlX00<0L50Y075>:01aCRP00P1aCRP4079?
:@<0ME8Z0`1fDb/207MD;00407QE:`1iER`0O5T_07iK<@80Oe`b0P1nFc4207eH;P@0OUT_0P1oFS08
085L;`P0QU/`2024GS4808=N<@<0QElb0P24GS4308=M<0D0QEl`0`26H3400`24Gc80Peha08=N<@04
08=N<@T0Q5lb2023GC0808AN<@80PU`_0`23GC0308AN<@03085L;`22GC00Q5lb0080QF0c00/0Q5lb
089M<021G2l0P5`Z085M:`22GRh0Peha08=N<P21G380OeX`07iH<@08085L<P<0OeX]0P1nFB`407eH
:`0;089M<`21G380P5/a07mJ<01nFBl0OEP^07aG;@1kER`0NUDX07aG:P1nFB`00`20Fbh207mJ;@80
O5L]0`1mF2h307iI;`80NeP`101jEbl207UF;P80NE@Z0P1jEB/207]F;080O5L]0P1kF30207YG;`@0
NEH^00H0MEP/07MH;01gF2`0N5L/07UF;01kER`207aE;0<0O5L]00<0NeH/07YE:`1jEB/00P1iE2X4
07EB:P@0M54Y201hEB/00`1_DRH0L5<W07=D:00207AE:@0307AC:01cDRL0LU4V00P0LE0W00<0KThU
071@9`1aDBP00P1bDRT01P1aDBP0L50W06i>9@1`D2T0KThW06e=9P80K4`U00<0KDdV06i>9`1`D2T0
0P1aDBX01P1`D2T0KThW06e=9P1/C2D0Jd/T06Y:8`@0JddY0P1ZC2P306U;9`80J4XV00<0IdTU06I8
901UAb<00P1TAR80201VB2@0IdTU06Q:9P1YBbL0J4XV06M99@1UAb<0I4HR201TAR@306E89P0406=6
901RAB<0HTDS06=69080I4LU00<0Id/V06I:9@1VBRD0101VBRD00`1WBbH0ITPR06I88P0206M98`<0
J4XT00@0JD/U06Q<901XC2@0J4`T0`1YCBD406Y>9P<0JdlW0`1/D2P306iA:@<0Ke8Z0P1`Db/307EE
;00307IF;@1gEbh0MeL^0080N5P_0P1oG38307iK<@<0Oe`b0P1oGBl2081N<080PEla0P22H3801P20
H2l0PF4`08=Q<@26HS80Qf<c08US=080S6<e00H0Qf4b08QR<`28HS<0RF<d08YT=@2;ICH208aV=`80
SVTe00@0SfXf091[=`2AK3P0TVdi0P2CKSX0102CKc/0U70l09A`?02DL3`209Ea?@80UW8n0100T6`l
095]?@2BKSh0U71009Ea@@2GLd<0V7A409UeA@2FM4H0UgE509UeA@2KMD@0WWI30:1g@`2QN480XWM2
0`2MN4401@2NND80WgY30:1kA02QO4D0XWe60080Xgm500@0Y7m80:F0B`2VPD`0Yh9>0P2XPU430:R3
CP80ZHA?0`2ZQE020:Z5D@80ZhIB0P2/Qe<20:f8E0040:n:EP2^RED0[XUE0:f8E080[8MC00<0[XUE
0:n:EP2aS5P00`2_ReL30:j:EP80[HUE0P2_RUD00`2`ReL0/8YI0;2:F`020;6;GP030;6:G`2eT5`0
]I1L00H0]I1L0P2cREL20;B:F080]H]I0P2fS5X20;B;E@030;F<F02eReT0]H]K0080]HYM00@0]HYO
0;:<G@2bS5d0/XaM0P2cSEh30;B>G`<0]8mK0P2cSUX30;:=F@030;F@F`2dSeX0/XeH0080/HaG00<0
/XeH0;B?FP2eT5/0202dSeX20;B?F`<0/hiJ0`2bSET80;2;E`P0/HaH0P2dRUP60;>9E`80[hYE0`2^
RE@30:f8D`080:^6DP2/Qe<0[HQD0:j9E@2`ReL0/HaH0;:=F@2cSUX80:j9E@P0[hUH2P2_RUH50:j9
E@80[HQD202^R5T80:j9E0@0/HQD102`Qe<30:b7D`80[HQD0`2/Qe<20;28E@80[hMD0P2^QU<20:f5
DPH0[8MC0P2]R5@80:j9E@80/XUE0`2aR5@30;27D`050;67E@2`QU@0/8ID0:n5D`2^Q5800P2]Pe40
1`2/PU00ZX1>0:Z0CP2[PDl0[89@0:j4DP2_QE<00P2`QU@00`2[QU80ZXEA0:Z5D@020:Z5D@<0ZHA@
0P2/Pd/0102/Pdd0[HA@0:f4D02^Q5820:j4E0P0[hIB0P2]Q4`0102^QDl0[XEA0:j5D@2_QE<20:n5
E@P0[HA@00<0Zh9>0:b3C`2]Q5000P2_QU800`2]Q500[8=?0:^2CP080:b3C`<0[HA@00<0[8=?0:^2
CP2[PTh00P2ZPDd20:UoC@040:Z0CP2[PDl0Zh5?0:b2D080[H=A00<0[XAB0:n6DP2_QU800P2^QE40
102]Q500[8=?0:b3C`2/Pdl20:^2CPH0[8=?0`2]Q5020:j5D@/0[HA@00<0[8==0:^2C02ZPD/00P2Z
PD/04`2/Pdd0[XE?0:n6D02^QDd0[HA<0:b3C@2[PTh0Zh5?0:f3D`2_Q5L0/8EH0:b2DP2]Pe<0[XAB
0:n6DP2`Qe<0/HQB0;68D02bRE400P2/Pdl30:f4D0<0[XEA0`2_QED20:j4E0<0[H=C202]Q5040:j5
D@D0[hIB00L0[XEA0:b3C`2ZPDd0ZX5=0:^2CP2/Pdl0[HA@0080Zh5?00@0[89@0:f3D@2]Pe40[XAB
0P2_QE<80:b6E@030:n6DP2^QE40[8=?0080Zh9>00<0[8=?0:j5D@2_QU80202ZQE020:^1C`80[89@
00@0[H=A0:j4DP2^Q580[XAB0`2^QE420:f4D0<0[8=?00@0[89B0:f3D`2^Q580[hIB0P2^QE400`2]
Q4h0Zh9:0:Z1B@030:^2C080[8==0`2]Q4h80:b3C`80[HA@0P2/Pdl20:^2CP80ZX5=0P2]Q5030:b3
C`<0Zh9>00@0[HA>0:b3C@2/Pdd0[8==0P2[PT`20:Z1B`P0Zh1=1P2/Pdd20:^2C0<0[8=?0`2]Q502
0:j5D@80Zh5?102ZP4h50:^1C`80[89@0`2]Pe400`2]PE00[81?0:]oCP020:YnC@030:]oCP2/P4l0
[H5@00@0ZX5=102[PTh80:b3C@80Zh9>00@0[8=?0:f4D02]Q500[XEA0P2_QU880:f3D`80[HA@0`2/
Pdl30:^2CP80Zh5A00@0Zh5?0:^2CP2[PTh0Zh9<0P2[PTX20:b3B`040:b3C@2/Pdl0[8=?0:b2D080
[89B2@2YP4`20:^1D@040:^1C`2/Pdl0[8=?0:b3C@80[HA<0`2/Pdd20:b3C`<0[89@0`2VPDd20:N2
CP<0YX5=00P0Zh5?0:UoC@2WOD/0YWa:0:EkB@2VO4X0Yge;0:QnC0P0YWe90P2UNdT30:IlBP<0Yge;
0P2XOT`30:UoC@<0ZX1>0P2WPTh30:J1C@<0YH1<202XOT`80:J1C@80YG];00@0YG]90:ElB02UO4P0
YGa60P2UO4@00`2VODT0Ygi:0:V0C0020:Z1C@030:V0C02WOTX0YWe90080Z7i>00@0Z7i<0:QoB`2X
Od/0Z7m90P2XOdL80:MnB0<0Y7m;0P2SOTX30:9mB@@0YWe90P2WOTX20:QoB`030:F0B`2SOTT0X7]6
0080WWU400<0X7]60:9mB02SOTT0102RODT40:5lB080WWU4102ONTD309iiA080YGa800L0Y7]70:9i
A@2QN4@0X7M309mf@P2NMD40WGQ400H0WWU500<0WGQ40:5iAP2QNDH00P2PN4D209mgA080WWI300<0
WWQ909egB02MMdP00P2LMTL309]eAPP0VgI20P2MN4@609iiA@P0W7I700H0XG]<0:1jB`2ONDX0WGM8
09afA`2KMDH209YdA@0809ehA02LMd<0VgI209Ye@@2KMT80W7M309iiA@2ONTH30:5gAB_ooooo000Z
ooooo`03091S>@2?HSP0SV4g0080SF0f00<0SV4g091S>@2AI3X00P2?HSP6091S>@@0TVHi0P2AICP2
091T=`80TVDl00H0TVDk099V>@2BISL0TVHe09=W=P2CJ3D2099V>@80TfLj00@0U6Pk09EY?02EJC`0
UVXm0P2BIST209=W>P80U6Pk0P2EJC`02P2@HcX0TF@k099U>`2CIcX0U6Pi09EY>02FJST0Uf`i09=W
=P2DJ3L309EY>00409AX=`2BISD0TVHe09AW?@80U6Pk00<0UFTj09EY>02FJcP00P2FJcH00`2EJCP0
UVXi09M[>P0309Q/>`0309M[>P2EJCP0U6Pg0080UFTh0`2FJST309M[>PP0Ufdk0`2FJSd409M[?P03
09Q/?`2HKS`0V6hl00H0V6hl0`2IKT4409Y_@P0309]`@`2KLCl0Vg4o00H0Vg4o202LLcl409aa?PD0
WG8o0P2NLd0209md@@80X7E200<0XGI309md@@2OM440102OM4420:1e@P0509ic@02OM440WgA10:1e
@P2QMT<00P2RMd@01@2SN4D0XGQ40:1g@`2PMd<0WgI200@0WWE10P2QMT<20:1e@P@0WgA100P0Y7U4
0:=h@`2RMd80XGI30:9gA02SMdH0YGU80:IjB@P0XgQ300<0YGa40:Ak@`2RND400P2PMcl00`2QN400
XWU10:=j@P030:EjA`80Y7U60`2SN4D00`2UNTL0Y7U60:AiAP040:AiAP030:EjA`2TN4L0Y7Q700L0
Y7Q70P2SN4D0102RMd@0XGI30:1e@P2PMD8209md@@0809mf@P2PMd<0XGQ40:5hA02PMd<0WgI209ed
@02LLcl209ab@P<0Vg510`2JL40309=^>P80U6lk0`2EL3`01P2?JSD0SVTe08iY=@2>J3L0SVPi08eW
>P80SFHk00<0SVLl08aU>P2:HcP00`28HCH00`29HSL0RV<h08MR=@0208IQ=00308EP<`24Gc80Peha
00<0PUd`00D0PE`_081K;P1oFRd0OUT/07eH:`0207aG:P0407mI<P1nF340OUPa07iH<@80OEL`0P1l
ERl00`1iDb`0N58[07QB:`0207MA:P<0MU0Y0P1aDBX2071@:@@0KdlX0P1[BRL306a;:0<0KD`Y201Z
BBP206a<9P0606]:9`1ZBBP0JDPW06Q7:01XARX0IdDY0P1YBbT0101XBRP0IdTW06M99`1VB2H406E7
9@<0ITPV0`1WBBL306Y9:0<0JDPW0P1XAbH206M;900306U;9@1/C2H0KT`W0080L4`X00@0LddY06a<
9@1/C2D0KDdV0P1^CRL0101_CbP0L50Y071@:@1`D2T2075>:080LTlY0P1cD2X207AA:`@0MU<Y0P1g
E2X207QE:`0507YG;@1kF2h0OEX`07mL<P20GC<00P1oG380101nFc40OEP^07iI;`1nFBl207mJ<080
P5/a00<0PE`b085L;`21G2l01P21G2l408ML<@@0QU/`2025Gc8808AO<P<0QV0c0P25Gc8308AN<@80
Qf4b1P26H3400`23GS40Q5lb08AO<P0408AO<P0308=N<@24Gc80Q5lb00H0Q5lb2023GC0808=L<@80
PU`_0`23GC0308AN<@03085L<022GC40Q5lc0080QF0d00/0Q5lc089M<@21G300P5`Z085M:`22GRh0
Peha08=N<P21G380OeX`07iH<@08085L<P80Peha0P22GC03085L;`80P5/^00`0PUdc085L<P20Fc40
OeX`07iI;`1mF2h0O5L]07]F;01kERT0O5LZ07iI;020Fbh2085L;`04081K;P1oFRd0O5L]07aG;@<0
OEP^0`1nFBl00`1lFC40NeP`07]H<00207YG;`80NEH^00@0N5D]07YE:`1jEB/0NUD[0P1kER`307aG
;@@0NeP`0P1jEbl207UF;P0607AG:`1fEb/0MeP/07QG;01iER`0NeH/0P1kE2/00`1lEbd0NeH/07]F
;00207]F;0<0NUD[0P1fDb/207EB:P80M54Y0P1cD2P807QE:`03079A9P1cDRL0ME@Y0080MEHZ00<0
M5DY071C9`1_DRH0201`D2L00`1_CbH0L50W075A:00207=C:P06075A:01`D2L0KdlV071@:@1_CbP0
KThW0P1/C2D00`1^CRL0KdlX071@:@0206e=9P<0KThW0`1_CbP306a>:P<0JddY0P1ZC2P01P1]Cb/0
K4hZ06a>:P1[CBT0JT`X06U;9`80J4XV00<0ITXU06M;9P1XC2L00P1XC2L00`1VBRD0I4PS06=78P08
06E79@80IdXX00P0ITTW06=6901RAB<0HD@R06958`1SAR@0I4LU06E990H0ITXU00<0IDTT06E78`1V
B2@00P1VB2@206M99@80J4XV0P1UC2<306I=90<0IdhU0`1ZCRH306]?9`80K50X0P1]D2P306iA:@<0
Ke8Z0`1dE2/407EE;00307IF;@1mFS00OEX`00H0OU/a0`1oGBl2081N<0<0PEla0P21HC001P23HC40
QF4a08IR<P28HS<0RV4c08]R=080Qf4b00<0R68c08US=02:I3D00P2;ICH01@2<ISL0SVTe08iY=@2?
JSH0T6/g0080TF`h0P2BKCT309=_>`80U70l0`2ELCd0502>JSX0Sf/k091/?02BKSh0U71009Ib@P2G
Ld<0V7A409IdAP2FM4@0VGE509]eA02NMT<0X7M30:1g@@2RMd80W7Pn09ei?`2NNT00Wg]10P2PO482
0:5m@`80XWi400@0Xgi70:AoBP2UP4/0YX5=0P2WPE020:N2C@80Z8=>0P2YQ4l20:Z5D0<0ZXEA0P2[
QU830:b7D`090:j9E@2]R5@0[HQD0:b7D`2[QU80[8MC0:j9E@2`ReL0/HaH0080[h]G0`2^RUH30:f9
E@80[hYF00<0/8YI0;2:F`2`RUd00P2aRUl00`2aRV40]I1L0;F@G0060;F@G080/hUG0P2dRUP20;F;
F@80]XaJ0P2eS5H00`2dReL0]8YH0;B:FP020;B9G0030;B9GP2aReX0/H]J0080/XaK0P2cSE`20;B>
G@80]8mK0P2cSUX20;:=F@80/HaH00<0]8mJ0;>>F@2bSEP00P2aS5L00`2bSEP0/hiI0;B?FP080;B?
FP80]8mK0`2cSUX30;:=FA00/8]G1P2cREL20;B:F080[hYE0`2^RE@30:f8D`80[8MC00@0[HQD0:j9
E@2`ReL0/HaH0P2bSET40:f8E0@0[XUE4P2_RUH30:j9E@80[HQD0P2/Qe<80:j8F@P0[XUD202aR5@3
0:f8E080[8MC0`2]R5@40;26E0@0[hEC1P2]R5@20:b7D`P0[XUE0P2bRED30;68E0<0/8MC0P2`QU@0
102_QE<0[XAB0:j4DP2]Pe420:b2D080ZX1>00@0Zh5?0:b2D02^Q580[hEC0P2`QU@20:b7D`80ZhIB
00@0ZXEA0:V4D02YQ500ZHA@0P2/Pd/0102/Pdd0[HA@0:f4D02^Q5820:j4E0P0[XEA0P2]Q4`0102^
QDl0[XEA0:j5D@2_QE<20:n5E@P0[HA@00<0Zh9>0:f4D02^QE400P2_QU800`2^QE40[HA@0:^2CP08
0:b3C`030:b4D02[Pdl0Zh=?0080Zh=?0`2ZPTh20:UoC`<0ZX1@00D0Zh5A0:b2DP2]Pe<0[H=C0:j5
D@040:f4D0T0[8=?0P2[PTh30:f4D080[8=?2`2]Q5000`2]Q4h0[8==0:^2C0020:Z1B`0;0:^2C02]
Q4h0[XE?0:j6B`2]QDX0[8=;0:^2C02[PTh0[H=A0:n5E@2`QUH00P2]Pe<0102^Q580[XEA0:n6DP2`
Qe420;27C`<0[8=?0`2]Q5020:j5D@80/8ID0P2_QE<20:j4DP80[H=A202]Q5000`2/Pdl0[HA@0:f4
D0020:j5D@80[hIB00T0/8MC0:n6DP2]Q500Zh9>0:Z1C@2YP4`0ZX5=0:^2CP2/Pdl00P2[PDl0102/
PU00[H=A0:f3D@2^Q5820:n5D`P0[HQD00<0[hIB0:j5D@2/Pdl00P2[PTh00`2/Pdl0[XEA0:n6DP08
0:Z5D0030:b2D02]Pe40[H=A0080[H=A0`2^Q5830:j5D@80[HA@0`2/Pdl00`2]Pe<0[XAD0:n5D`03
0:n6DP030:f4CP2[PTX0ZX590080ZX5;0P2[PT`20:b3C@80[HA>202/Pdl30:f4D080[8=?0`2[PTh2
0:f4D0<0[8=?0`2[PTh30:b3C@80Zh9<0`2ZPD/80:^0C@80Zh9<1P2/Pdd20:b3C`<0[HA@0`2^QE42
0:Z0CP@0Zh5?102ZP4h20:^1C`80[89@0P2]Pe400`2]PE00[81?0:]oCP020:YnC@030:]oCP2/P4l0
[H5@00@0Zh9>102ZPDd40:^2C0@0[8==0P2[PTh0102/Pdl0[HA@0:f4D02^QE420:n6DPP0[H=A0P2]
Q5030:b3C`<0Zh9>0P2[PE40102[PDl0Zh9>0:^2CP2[PT`20:^2BP80[8=;00@0[8==0:b3C`2/Pdl0
[89@0P2/PU890:V0C080Zh5A00@0Zh5?0:b3C`2/Pdl0[8==0P2]Q4`30:b2D080[8=?0`2/Pdd00`2W
PTh0YX5=0:J1C@040:J1C@090:N2CP2ZPTl0ZH5>0:MoC02VOT/0YGe:0:InB`2WOd`0Z81=00P0YWe9
0P2UNdT30:IlBP<0Yge;0P2XOT`30:UoC@<0ZX1>0P2XPdl20:N2CP@0YX5=202XOT`80:J1C@80YG];
00@0YG]90:ElB02UO4P0YGa60P2UO4@00`2VODT0Ygi:0:V0C0020:Z1C@030:V0C02WOTX0YWe90080
Z7i>00@0Z7i<0:QoB`2XOd/0Z7m90P2XOdL80:MnB0<0Y7m;0P2SOTX30:9mB@030:ImB@2WOTX0Ygi:
0080Z7m;00/0ZH1<0:QoB`2XOd/0YX5<0:AoBP2QO4L0WgY509iiA02ONTD0XGa70:=nB@080:9mB@T0
WgY50P2UO4P01`2TNdL0XWU50:5hA02PMd<0WgI209ie@@2NNDD01P2MN4@509iiA@@0WGQ4102MMdP2
09afA`80VgE6202KMT8309mjAPD0WWU5202MMdP20:5kC00>0:1jB`2ONDX0WWQ909afA`2KMDH0VWA5
09ehA02LMd<0VgI209Ye@@2KMT80W7M309iiA@2ONTH30:1fA2_ooooo000Zooooo`03091S>@2?HSP0
SV4g0080SF0f00<0SV4g091S>@2AI3X00P2>HCL208mR>0@0T6<i00P0T6@g095U>02BIST0TVHi09=W
>P2BIST0TFDh091T=`80TF@k00H0TF@j099V>@2BISL0TVHe09=W=P2CJ3D809AX>`<0TVHi0P2CIcX3
09AX>`80TVDl00<0TVDk09=W>P2CIcP00P2DJ3L00`2DJCH0TfLf09AX=`0409AX=`80TfLf00H0U6Lm
09AX>`2DJ3/0UFTj09EY>02FJcP209I[=P80UVXi102HK3/00`2FJST0UFTh09=W=P0209EY>0<0UVXi
0`2GJcX809M]>`0309M[?P2HK3l0V6`o00D0V6`o202GKC/809U^@@P0VW0n202LLcl409aa?PH0WG8o
00@0WW=009md@@2OM440X7E20P2QMT<409md@@80X7E20P2QMT<30:1e@P<0XGI30P2RMd@00`2QN4@0
X7M309mf@P0209ed@080WWE100<0WgI20:9gA02RMd@00`2QMT<30:1e@P090:=i?`2RMd00XGI10:1e
@02QMD@0XWI50:AhB@2UND`0XWM200<0XgQ30`2TND@02@2UNTD0YGe20:Al@@2RNSl0XGTn0:1h?@2Q
NCh0XWXo0:=k@0030:EjA`80Y7U60`2SN4D00`2VNdP0YGY70:AiAP020:=hA@030:AiAP2UNTL0YW]8
00<0YGU80P2TN4L40:=gAP80Y7U600@0XgQ50:9gA02RMd@0XGI30P2PMD802@2OMT80X7M30:5hA02Q
N4@0X7M309ie@@2LLcl0VW4m09]`@`0309Y_@P80VFi10P2HKD0609=^>P80TVdi00H0SFPc08eX=02=
J3@0S6He08aV=`2<IST208aU>P0308YU>`29I3X0Qf8h00<0QF0f0P27HSP01P26HC@0QF0c08EP<`24
Gc80Peha089M<080PE`_0P20Fbh307mJ;@<0OUT/00@0OEL`07aF;`1lERl0O5H_0P1kEBh207YD;@03
07YD;`1iDbh0N58]00<0MU0[0P1gDB`0101bDR/0LE4Z075A:P1aDBX2071@:@80KdlX0`1/BbP506]:
9`P0JDPW0P1[BbD01P1ZBBH0JDPW06Q79P1WARL0IdDY06I4:0P0IdTW0`1VB2@206M99@<0J4XV0P1[
BRT206Y9:0<0JDPW00T0J4LV06Q<901YCBD0JTdU06e=9P1_CBL0LDhX079?:@1dCRT00`1_CbP2071@
:@@0LE4Z0P1bCbT00`1cD2X0M54[07EB;00207IC;@0307MD;P1fDbT0Me@Z0080Me@Z0P1hEB/207UF
;00307YG;@1kF2h0OEX`00<0Oe`b00@0OU/a07eJ<01nFBl0OUT_0P1oFS001020Fc40PE`b089M<`22
GC<8089M<0<0R5db0P27G34308IK<0P0QElb2024Gc8308MQ=080QV0c0`25Gc8308QR<`<0Qf4b0P26
H3400`23GS40Q5lb08EP<`0308EP<`0308AO<P23GS40Q5lb00L0Q5lb2023GC0808=L<`80PU`_0`23
GC0308AN<@03081K<@21G380PUdc0080Q5le00/0PUdc085L<P20Fc40P5`Z085M:`22GRh0Peha08=N
<P21G380OeX`07iH<@0807mL<P<0Q5lb0P23GS44089M<005085L<P20Fc40P5/a07mJ<01nFBl00P1m
F2h0101lEbd0O5LZ07iI;01oFRd2085L;`03081K;P1oFRd0OUT/0080O5L]0`1mF2h307iI;`80O5Ta
00@0NeP`07YG;`1jEbl0NEH^0P1hEBd207YE:`80NeH/0`1lEbd0101mF2h0NEH^07YG;`1kF30207aI
<@0;07]H<01jEbl0NUL_07=F:P1fEb/0MeP/07QG;01iER`0NeH/07]D:`1jDbX0201kER`01@1hEBd0
Me@/07MD;01fDb/0ME8Z0080M54Y00<0Le0X07QE:`1hEB/0101fDbT207QE:`0807E@9P1dDBL0Me@Z
07QG;01gF2`0LeHZ06mD9`1^DbH8071C:@0306m?9P1`D2L0LU8Y0080Le<Z00H0LU8Y071@9`1_CbH0
L50Y06m?:01^CRL206e=9P0306i>9`1_CbP0L50Y0080K4`U00H0KDdV06i>9`1_CbP0L50Y075A:P1b
DR/306e?:`80K4hZ0`1[CBT206i@;080KDl[00d0K4hZ06]=:@1ZC2P0JT`X06I:9@1WBbH0J4`W06U=
:01XC2L0Id/V06E9901TB2<0IdTW0080ITPV0P1UAbD306A69080IdXX00X0IDPV06=6901QA280H4<Q
06958`1TAbD0ITTW06A88`1UBB@0ITXU0P1WBbH0101VBRD0IDTT06A88`1TAR@306E79@80ITPV0P1W
BBL306A=8`80IDhT0`1VCbD206U=9@80JThV0`1[CbL0101/D2P0KE0X06e@:01]D2P206iA:@<0Ke8Z
1@1cDbX307AD:`0307UF;01jEbd0O5T_00@0OEX`00<0O5T_07iL;P1oGBl00P1oGBl2081N<080PEla
0P21HC001`23HC40QF4a08IR<P27HC80RF0b08YQ<`26H3400P27HC800`28HS<0RF<d08YT=@0208]U
=P0608aW<`2=J3@0SFPd08iY=@2?JSH0T6/g0P2AK3P0102AKCT0TVhj099^>P2BKSX209=_>`80U70l
00H0SVXj08m[>`2@K3`0TFdm099^?P2DL40209Ea@@0;09AbA02ELd<0Ug=309Uc@P2LM440WWE109mf
@02PMD00VgLk09ah?02NNSh00P2PO4002@2QOD40X7a00:1l@02QOD<0XWi40:9mAP2SOTT0Y7m:0:F0
C0020:J0C`<0Yh9>0P2XPdl40:V4D0<0ZXEA0P2[QU820:b7D`030:f8E02/Qe<0[8MC0080ZhIB00D0
[8MC0:j9E@2`ReL0/HaH0:n;E`030:j:EP80[HUE0P2/R5@20:n9F0030;2:F`2`RUd0/8UN0080/HYQ
00<0/HYS0;B?F`2dSe/01P2dSe/20;>9E`80]8YH0P2eReT20;J<FP80]HaF00<0]8]G0;B:F02dRUX0
0P2cR5/0102cR5d0/HaH0;6<F02aS5P20;:=F@H0/hiJ0P2bSET30;6<F0030;B?FP2cSUT0/HaG0080
/8]F00<0/HaG0;>>F@2dSeX0202eT5/20;B?F`<0/hiJ0`2bSET@0;2;E`80/XQF0`2cREL30;B:F080
[hYE0`2^RE@30:f8D`<0[XUE0P2_RUH30;2;E`<0[8MC0P2]R5@30:j9E@P0[XUD202^RED20:n:EP<0
[XUE00@0[HQD0:b7D`2[QU80ZhIB202]QeP80:j9E0040;27D`2aR5@0/HQD0;68E0<0/XUE00@0/hYF
0:j9E@2^RED0[HQD0P2/Qe<00`2]R5@0[XUE0:j9E@040;65E0@0/8AC0`2^RED30:f8E080[8MC202]
R5@20;:9E@<0/HQD0`2`Qe<0102_QE<0[XAB0:j4DP2^Q5840:f3D@80Zh5?00@0[89@0:f3D@2]Pe40
[XAB0P2_QE<20:f8E0030:b7D`2[QU80ZXEA0080ZHA@00@0Z8=?0:b3B`2/Pd/0[8==0P2]Q5000`2^
Q580[XAD0:j4E0080:j5D@80[HA<00@0[XE?0:j5D@2^QE40[hEC0P2_QED80:f4D0030:b3C`2]Q500
[XEA0080[hIB00<0[XEA0:f4D02/Pdl0202/Pdl80:V4D0030:UnD@2ZOe80ZWmB0080Zh1C00@0[85D
0:f2E@2^PeH0[X=F202/Pdl20:f4D0<0[8=?0`2[PTh00`2^QE40[HA@0:b3C`020:^2CP030:b3C`2]
Q500[XEA00P0[HA@00<0[HA>0:b3C@2[PT`00P2ZPD/02`2[PT`0[HA>0:j5C`2^QTT0[HE:0:b4B@2[
PTX0Zh9<0:f4D02_QE<0/8ID0080[H=C00@0[H=A0:f4D02]Q500[HA>0P2]Q4`20:^2CP80[8=?0`2]
Q500102^QE40/8MC0;27D`2`Qe<20:n6DP<0[XEA202]Q5001P2[PTh0[8=?0:b3C`2]Q500[XEA0:n6
DP80/8MC00P0[XEA0:f4D02[PTh0ZX5=0:V0C02ZPDd0Zh9>0:b3C`<0[89@0P2]Pe430:j4DPP0[HQC
00<0[hIB0:j5D@2/Pdl00P2[PTh00`2/Pdl0[XEA0:n6DP080:^6D@P0[XAB0`2^QE420:f4D0<0[8=?
00@0[XAD0:n5E@2`QU@0/8MC0P2_QU800`2]Q4h0Zh9:0:Z1B@030:Z1B`80Zh9<0`2/Pdd80:b3C`04
0:j5D@2]Q500[HA@0:f4D080[8=?0`2[PTh70:b3C`80[HA>0P2/Pdd30:^2C0030:Z1B`2/PDh0[85>
00H0[85>0`2[PT`30:b3C@80[HA>00@0[8=?0:f4D02]Q500[HA@0P2^QE420:n6DP030:UoC@2ZP4h0
Zh5?0080[89@00<0Zh5?0:Z0CP2YOdd00`2ZP4h20:^1C`<0[89@00<0[H5@0:b0C`2[Odh00P2ZOTd0
102[Odh0[81?0:f1D02/Pdl30:^2CP<0ZX5=00@0ZH1<0:Z1B`2ZPD/0ZX5;0P2[PT`30:b3C@<0[8=?
0P2]Q5030:j5D@P0[8=?0P2]Q5030:b3C`<0Zh9>0P2[PE40102[PDl0Zh9>0:^2CP2[PT`20:^2BP80
[8=;00@0[8==0:b3C`2/Pdl0[89@0P2/PU890:V0C080Zh5A00@0Zh5?0:b3C`2/Pdl0[8==0P2]Q4`0
102/PE@0[89B0:b2D02/PU020:b3C@050:b3B`2/Q4T0Z8=?0:N2CP2VPDd00P2UP4`02`2VPDd0Yh9>
0:R3C`2YQ500Z8=?0:J1C@2UP4`0Y7m;0:F0C02VPDd0Yh9>00P0Z7m;0P2VO4X30:MmB`D0Z7i<0`2Y
Odd30:Z0CP80ZHA@0P2XPdl30:N2CP030:J1C@2YOdd0ZGm=00H0ZGm=202VPDd20:IlC0040:IlBP2V
ODT0YWe90:ImA`80YWe500<0YWe90:MnBP2YP4`00P2ZPDd00`2YP4`0Ygi:0:ImB@020:UoC`040:Mm
B`2WOTX0Ygi:0:MnB080ZH18202WOTP30:=nBP80XWe90`2QO4P20:MnBP090:QoB`2YP4`0ZH1<0:Qo
B`2WOTX0YWe90:F0B`2TOdX0XWe80080X7]600@0WgY50:1kAP2PNdH0X7]70`2QO4P30:9mB@040:=n
BP2QO4L0X7]609mjA@80WWU400@0WgY50:1kAP2PNdH0XGa70P2TNdL0102SNTH0XWU50:5hA02QN4@2
0:1g@`0309iiA@2MN4@0W7M300<0W7M300<0WGQ409iiA@2MNDD00`2MNDD409ahA00809afA`2MMdP0
WGM809ihB@2MMdP0W7I709]eAP2JM4D809ag@`80WgY60P2NNDD409ehA0P0WGM80100WgU:0:1jB`2P
NT/0X7Y;09miBP2MMdP0W7I709]eAP2MN4@0W7M309]f@P2JMD40VgI209ag@`2NNDD0WgY60`2OMD<[
ooooo`00:_ooool00`2AI3X0T6<i08iQ=`0208eP=P0408iQ=`2?HSP0T6<i08eP=P80SV4g0P2?HSP2
091S>@09095T>P2=HC@0Sf<f095U>02CIcX0U6Pk09=W>P2BIST0TFDh0080T6<j00H0TF@j095U>02B
ISL0TVHe09=W=P2CJ3D209IZ?@0309EY?02DJ3/0TfLj0080TVHi00<0TFDh099V>@2BIST00P2BIST2
09=W>P80U6Pk0P2DIch00`2CIS`0TfLj099V=`02099V=@04095V<`2CIcH0TfLf09=W=PD0U6Pg00H0
U6Lm09AX>`2DJ3/0UFTj09EY>02FJcP209I[=P0309IZ>@2GJcX0V6`k00<0V6`k00<0UVXi09AX=`2C
IcH00P2EJCP309IZ>@<0Uf/j202HKS`309U]@0D0V6`o202GKC/809Q]@0P0V6hl202LLcl409eb?`D0
W74n0P2MLSl01P2NLd00X7E20:5f@`2QMT<0XWM409ic@080WgA10P2PMD820:5f@`@0XWM40`2QMT<2
0:1e@P030:1g@`2OMT80WGA00080W7<o00<0WWE109mf@P2QN4@00`2SN4D30:9gA080XGI300P0XGLk
0:1f?02OM3d0Wg@o09mc@P2QMDH0XgM:0:AgC@80XWM20P2SN4<01`2TND@0YGY50:EjA@2UNTD0YWi3
0:Em@P2SNd000`2QNCh00`2RNSl0Xg]00:EjA`020:EjA`80Y7U60`2SN4D00`2WO4T0YW]80:AiAP02
0:=hA@040:AiAP2VNdP0Yga90:IjB@80YGU80P2TN4L30:=gAP070:9fA@2VNdP0YW]80:EjA`2TNDH0
XgQ50:9gA0020:5f@`0909mf@P2PMd<0XGQ40:5hA02OMT80WGA009]b?P2JLCd0VVm200<0VFi10P2H
KD0209M/?`0509A_>`2CKSX0Tfhj099]>@2AK3P00P2@JcL01`2?JSH0RfHa08]V<P2;IS80RfDd08]U
=P2<IST00P2<ICX00`26HcT0QF8h08=P=P03089O=@0708AQ=`25HSP0QF0c08EP<`24Gc80Peha089M
<002085L;`03081K;P1nFB`0OeX]0080OeX]0P20Fbh2085L;`<0NU@]0P1iDb`307QB:`0907]E<@1j
E300N58^07MA;@1fD2`0Me4]07QB;P1iDbl0Le</00<0LU8[0P1aDBX2071@:@80KD`Y00<0K4/X06]:
9`1ZBBH00`1YB2D806Q79P0606];9@1ZBR@0JTTV06U89`1XAbH0IdHW0P1VA2P0101TAR@0IDLU06I8
9P1VB2H206Q::00306U;:@1ZC2X0IdTS0080IdTS0P1XBR@306U;9@<0JdXY0P1ZBBP306U89`0806U=
9@1ZCRH0JdhV06i>9`1`CRP0LTlY07=@:P1eCbX2075A:P<0LU8[101cDb`207AA:`0407EB;01fDbd0
Me@^07QE;`80NEH`0P1gEBP207QF:@<0NELZ00L0NUP[07YG;@1kF2h0OEX`07iK<@1oG380OU/a0080
O5T_0P1nFBl0101oFS00P5/a085L<P22GC<208=N=0P0Peha0P29GS<208QM<P0408ML<@26Fc00QU/`
08IK<0P0QV0c2025H3<208QR=@80Qf4d0`26H3<01@25Gc80RF<d08US=029Hc@0R68c0080Qf4b0P26
H3400`23GS40Q5lb08EP<`0208IQ=00308EP<`24Gc80Peha00P0Peha2023GC08089K<P80PU`_0`23
GC0308AN<@0307iI;`20Fc40PE`b0080PUdc00/0PE`b081K<@1nFBl0P5`Z085M:`22GRh0Peha08=N
<P21G380OeX`07iH<@0807iM<P04089M<021G2l0PE`_085L;`80P5/^0`1oFRd407mJ<0@0OUT_00P0
OeX]081K;P21G2l0PUd`085L;`20Fbh0OUT/07eH:`80O5L]0`1mF2h307iI;`0507eJ<P1lFC40O5Ta
07]H<01iERh00P1hEBd0101gE2`0NeH/07]F;01kER`307aG;@80OEP^00<0Me@/07QE;@1kF3000`1m
FS802P1lFC40NeP`079E:@1eERX0MeP/07UH;@1jEbd0NeH/07YC:P1iDRT207YE:`H0NeH/00D0NUL_
07UF;P1iERh0N5D]07IC:`0207EB:P0407AA:@1gE2X0MU<Y07EB:080M54W00/0ME8X07IC:@1gE2X0
MDhU07M@9`1hEB/0NEP]07II;@1cF2/0KEDW06YD9@08075F:`03071@9`1aDBP0LU8Y0080Le<Z00H0
LU8Y075A:01`D2L0LE4Z071@:@1^CRL206e=9P0306i>9`1`D2T0LE4Z00P0KdlX0`1^D2`206e?:`D0
K4hZ00T0JddY06Y<:01YBbL0JD/W06Q:9P1WBBD0I4XU06E;9P1VC2L00P1WCBP02`1UBbH0HdTT0698
8`1YBbT0J4XX06M99`1VB2H0IDLU06A6901SAB<0HT@R0080IdXX00X0IDPV06958`1P@b40H4<Q0695
8`1UB2H0J4/Y06=78P1TB2<0ITXU0P1WBbH00`1VBRD0I4PS06=78P0306A59P80IDHW0`1VAbP2069=
8P80HdhS0`1TCb@0101UD2D0JDdU06U=9@1YCBD206Y>9P<0JdlW0P1/CbL206e@:0<0KU4Y00@0Ke8Z
07=C:P1cDbX0Le<Z1@1bDRT0101dDBL0MU<Y07UF;01kF2h307aI;`0307]H;P1nG2h0OU`^00<0Oed_
0`20GS02085Q<00408=Q<@25HC40QF4a08IP<@80RF0b0P26H3401027HC80R68c08US=02:I3D208]U
=P0608YU<@2;IS80RfHb08aW<`2=J3@0SVTe0P2?JSH4091/>080TFdi0P2BKSX208m[>`80T6`l0P2A
KCd2099^?P0<09=a@`2CLD40UW9209Ma@02JLSl0W7<o09ed?P2NLch0VWHj09ah?02NNSh0X7a00P2Q
OD40202PO400Wg/o0:5m@`2QOD<0XWe60:9mB02SOTT0Y7m;0P2UOdh40:N1D080Z89A0P2YPe820:V4
D0<0ZXEA0`2[QU800`2/Qe<0ZhIB0:^6DP020:Z5D@040:^6DP2^RED0/8]G0;6<F0<0[XYF0P2]RED3
0:b8E0060:n9F02_REX0/8YK0;2:G@2`REh0/HYQ0P2aRV<80;:=F@80/hUG0P2dRUP20;F;F@80]XaJ
0P2eS5H01P2dReL0]8YH0;>9F@2cR5/0/XMJ0;:7G0@0/HaH0P2bSET40;>>FP80/XeI102aS5P00`2d
SeX0/XeH0;6<E`020;2;EP030;6<E`2bSEP0]8mJ00P0]I1K0P2dSe/30;>>FP<0/XeI202`ReL80:n:
EP<0/XQF00<0/hUG0;B:F02dRUP00P2eReT20:n:E@<0[XUD0`2]R5<30;2;E`80[hYF0`2^RED20:^6
DP80[8MC00@0[HQD0:j9E@2^RED0[XUE202^RE880:j9E@070;2;E`2_RUH0[XUE0:j9E@2]R5@0[8MC
0:^6DP020:Z5D@P0[HMH202^RE@20;27D`80/HQD00L0/XUE0;>:EP2cRUH0/hYF0:n:EP2^RED0[HQD
0080[8MC00<0[HQD0:j9E@2_RUH0102bQ5<40;>5E080[hYF0P2^RED20:f8E080[8MC202]R5@20;:9
E@<0/HQD0`2`Qe<20:b2D0<0[H=A0`2^Q5880:f3D@050:j9E@2]R5@0[HQD0:b7D`2ZQE400P2YQ500
102XPdl0[8=;0:b3B`2/Pdd20:f4D0030:j4DP2^Q5@0[XAD00P0[HA@0P2]Q4`0102^QDl0[XEA0:j5
D@2_QE<20:n5E@P0[HA@00<0[8=?0:f4D02_QU800P2`Qe<00`2_QU80[HA@0:b3C`080:b3C`80Z89A
1P2YPe800`2ZOe80Zh1C0:^0D`020:b1E0040:f2E@2^PeH0[hAG0:n4E`P0[8=?0`2]Q5000`2/Pdl0
Zh9>0:^2CP020:Z1C@030:j5D@2]Q500Zh9>0080ZX5=00<0Zh9>0:f4D02^QE40202]Q5000`2^QDl0
[HA>0:^2C0020:Z1B`0A0:^2C02/Pdd0[HA>0:j6B@2]QDP0[8A90:^3B02[PTX0[HA>0:n6DP2`Qe<0
[XAD0:f3D`2]Pe40[8=?0:^2CP2ZPD/00P2YP4P30:^2CP80[8=?0`2]Q5040;27D@80[hI@0P2^QDl8
0:f4D0060:Z1C@2[PTh0[8=?0:f4D02^QE40[hIB0P2`Qe<00`2^QE40[8=?0:^2CP030:V0C0030:Z1
C@2[PTh0[XAB0080[XAB0P2]Pe430:b2D0P0[XUB00<0[hIB0:j5D@2/Pdl00P2[PTh00`2/Pdl0[XEA
0:n6DP080:^6D@P0[XAB0`2^QE420:f4D0<0[8=?00@0[hEE0;26EP2`QU@0/8MC0P2_QU800`2]Q4h0
Zh9:0:V0B0040:Z1B`80Zh9<0P2/Pdd80:f4D080[XEA0`2]Q5030:b3C`80ZX5=0P2[PTh0102/Pdl0
[HA@0:j5D@2^QE420:j5C`80[HA>102/Pdd80:j3D080ZX5;0P2[PT`0102/Pdd0[HA>0:f4CP2]Q4h3
0:f4D080[XEA0`2_QU800`2YOdd0ZX1>0:^1C`020:b2D0030:^1C`2ZP4h0ZGm=00@0ZX1>0P2[PDl2
0:b2D0030:f1D02/P4l0Zgm>0080ZWi=00<0Zgm>0:b0C`2]PE000P2/Pdl20:^2CP80ZX5=0P2YP4`2
0:V0BP80ZX5;00@0Zh9<0:b3C@2/Pdd0[8==0`2^QE420:f4D0<0[8=?202/Pdd20:f4D0<0[8=?0`2[
PTh20:^1D@040:^1C`2[PTh0Zh9>0:^2C080Zh9:0P2/Pd/0102/Pdd0[8=?0:b3C`2/PU020:b2DPT0
ZH1<0P2[PE40102[PDl0[8=?0:b3C`2/Pdd20:f4C00;0:f2E`2]PUD0[H=C0:f3D@2]Q4h0[HA<0:f5
BP2]QDP0Z8=?0:N2CP2UP4`00P2TOd/02`2UP4`0Yh9>0:R3C`2ZQE40ZHA@0:N2CP2VPDd0YH1<0:J1
C@2WPTh0Z8=?00P0ZX5=0`2XOT`30:UoC@80ZX1>0P2XOT`30:UoC@<0ZX1>00@0ZXEA0:V4D02YQ500
ZHA@0P2XPdl20:N2CPP0ZGm=202VPDd20:QnCP040:QnC02XOd/0Z7m;0:QoB@80Z7m700<0YWe90:Mn
BP2YP4`00P2ZPDd01P2YP4`0Ygi:0:ImB@2ZP500ZGm?0:MmB`80YWe900<0Ygi80:V0B02ZPDT0202W
OTP20:9mB@80XGa80P2PNdL209mjAP080:MnBP2XOd/0ZH1<0:V0C02XOd/0YWe90:AkA`2SNTH40:=n
B@040:9mB02PNdH0WWU409eh@`<0WgY600<0X7]70:5lB02QO4P00P2RODT00`2RODP0XGa709mjA@02
09iiA00409mjA@2QO4L0XGa70:9mB0L0XWU500@0XGQ409iiA@2MN4@0W7M30P2KMT800`2LMd<0WGQ4
09iiA@0409YiA0@0VgY50P2LMTL309ihB@0309afA`2JM4D0VG=400P0W7M30P2NNDD209ehA080W7M3
0P2KMT8909egB00?09ihB@2ONDX0XG]<0:1jB`2ONDX0WWQ909afA`2MN4@0W7M309]f@P2JMD40VgI2
09ag@`2NNDD0WgY600<0WWA2:oooool002[ooooo00<0TF@j091S>@2>HCL00P2=H3H00`2>HCL0Sf8h
091S>@0208eP=P80SV4g00P0Sf8h091S>@2@HcT0TF@j08aP<`2=HC@0T6@g09=W>P80U6Pk0100TfLj
099V>@2?HST0T6<j091S>@2AICP0TVHg099V=@2CIcH0TfPe09Q/?`2GJch0UVXm09EY?02CIcX0TFDh
0P2@I3L0102AICP0TVHi099V>@2BIST209=W>P80U6Pk00T0UVU009EX?`2DIcd0TfLj099V=`2AIC@0
T6@c091U<P2DJ3L0102CIcH0102DJ3L0UFTh09EY>02DIcd209AX>`0309EY>P2EJCP0UV/h0080UV/f
00<0UVXi09M[>P2HK3/00`2HK3/00`2FJST0U6Pg09=W=P0209EY>0<0UVXi0`2GJcX809Q^?0D0VFe0
0`2HK3l809M]>`<0V6e0102GK3l00`2FJch0Ufdk09M]>`0609M]>`P0W7<o102MLSl609aa?P0409eb
?`2NLd00X7E20:5f@`80XWM400@0WW=009md@@2OM440X7E20P2QMT<20:9gA0050:AiAP2SN4D0XgQ5
0:9gA02QMT<00P2PMD802@2OM440WgI209ie@@2LLcl0Vg8n09ac?`2NMD40X7M30:9iA@040:AiAP80
XgQ50P2RMd@0202PMcT0WgDi09id>P2NLch0WW910:1dA`2QM4X0XgI=0P2RMd80102SN4<0Y7U40:Ai
A02UNTD20:IkAP030:In@@2UOD00Xg/n0080XGTl00<0XWXm0:=k?P2TO3l00`2UNTL20:AiAP<0XgQ5
00<0Yga90:IkB02TNDH00P2SN4D00`2TNDH0YW]80:MlB@020:IjB@030:EiB02TN4L0Y7Q70080XgM6
0P2RMTD20:MlB@040:IkB02UNTL0Y7U60:=hA@80XWM400P0WgI20:1g@`2QN4@0X7M309mf@P2MM400
Vg8n09U`?0<0VFi30P2HKD8309M/@@0609E`?02DKc/0Tfhj099]>@2@JcL0SfXf0P2>JCD02`2:IC00
RVDa08YU<@2;IC@0RfDf08]U>02;I3T0S6Dj08ER>P24HCT0PUlg0080PEhf00@0PUlg08=P>024HCT0
QF0c0P24Gc800`23GS40PUd`085L;`02081K;P0607eH:`1nFB`0OeX]081K;P21G2l0PUd`0P23GS42
07UC;0<0N58[0`1gDBX02@1lES80NeDa07UC;`1gDBd0MU0/07MA;@1iDbl0NU@`07AD;@0307=C;080
LU8[0P1aDBX01P1^CBX0KD`Y06a;:01[BRL0JTTV06Q79080IdHS201XAbH206Y:900606U89@1XAbH0
IdHU06I59P1VA2P0ID<W0P1SAB<0101UAbD0ITPV06Q::01YBbT206]=:`<0IdTS0P1XBR@306U;9@<0
JdXY0`1ZBBP206U89`80JTlT00<0K4lU06m?9P1aD2L00P1cD2P00`1fD2T0Le</07=C;00207=C;0D0
M5@]0P1eDR`0101fDbd0Me@^07UF<01jEc4207]H<P0407ME9`1hERP0N5HX07QF:080NELY0P1jF2X0
0`1jEbd0NeP^07aI;`0207iK<@0307eJ<01lFBl0NeP^0080OUT_00@0OeX`081K<@22GC<0Pehd0P24
GcD808=N<@<0REhc00<0R5db08ML<@26Fc000P26Fc0808IP<`P0QF0c0`28HSD208MQ=0<0QV0c0P2:
I3D208US=00708QR<`27HC80Qf4b08IP<@22GC00Q5lb08IQ=00208MR=@0308IQ=024Gc80PUd`00P0
PUd`2023GC08089K=080PU`_0`23GC0308AN<@0307eG<01nF340P5Xc0080PE/d00/0P5Xc07iH<@1m
Ec00P5`Z085M:`22GRh0Peha08=N<P21G380OeX`07iH<@0807iM<P<0OUT/0P1mF2/407aG:P0407eH
;P1nFBl0OUT_07iI;`<0OeX`00<0P5/a081K;P21G2l00P22GC001021G2l0OeX]07eH:`1lEbX207aG
;@<0OEP^0`1nFBl207eJ<P0407aI<@1kF300NEH^07QE;@80Me@/0`1kER`207aG;@<0OEP^00@0MU<[
07MD;01jEbl0OEXb0P1nFc<02P1mFS80O5Ta075D:01eERX0MUL[07UH;@1jEbd0NUD[07YC:P1hDBP3
07YE:`D0NeH/0P1kF300101jEbl0NEH^07MD;01fDb/207EB:P0307MD:P1eDRP0M54W0080LTlU00/0
M54W07EB:01gE2X0MddU07QA:01jEB/0NEP]07II;@1cF2/0KELX06YD9@08079G;003071@9`1aDBP0
LU8Y0080M5@[00H0LU8Y075A:01`D2L0LE4Z071@:@1^CRL206e=9P0906i>9`1`D2T0LE4Z07AD;@1c
Db`0LU8[071@:@1^CRL0KDdV0080Jd/T0`1^D2`206e?:`<0K4hZ0P1YBbL00`1XBRH0IdTU06I89002
06E78`0306A68P1TC2H0IDdW00<0IThX00<0I4`V069:901QBB<00P1ZC2X01P1XBRP0IdTW06E79@1S
AB<0HT@R06538@80ITTW00X0I4LU06548P1O@R00H4<Q06=6901VBBL0JD`Z06=78P1TB2<0ITXU0P1W
BbH0101VBRD0I4PS06=78P1SA2D306A59P80IDHW0P1VAbP2069=8P80HdhS101TCb@306U=9@<0JThV
0P1[CbL206a?9`80KE0X101^DBT00`1cDbX0LU8Y079B:@02079B:@<0LE4X00H0LDhT07=@9P1gE2X0
NUL]07]H;P1lFBl207]H;P<0OU`^0P1oGBl3081N<080PF4`00@0PV0`08EQ<@25HC40QV0a0P28Gc42
08IP<@0308MQ<P28HS<0RF<d0080RV@e00L0RfDf08UT<029I300RVDa08]V<P2<Ic<0SFPd0080SVTe
0P2>JSH208m[=`80T6`h0P2AKCT8091/?00;095_@@2BL400U71009I`?`2ILCh0Vg8n09ac?@2MLSd0
VWHh09ah>P2NNS`00`2QOCl0202PO3h0Wg/m0:1l@P2QOD<0XGa50:9mB02SOTT0Y7m;0P2UOdh0102V
P4l0Yh5@0:N1D02WPE020:R2D@80ZH=B0`2YQ5020:Z5D@H0ZhIB0P2ZQE40102[QU80[XUE0;2;E`2a
S5P20:j:EP<0[HUE0`2/R5@20:n9FP030;2:G@2`REh0/8UP0080/HYS00<0/HUU0;6<F02aS5P01P2a
S5P20;>9E`80]8YH0P2eReT20;J<FP80]HaF00<0]8]G0;B:F02cRET00P2bQeX00`2aQU/0/8]F0;6<
E`020;6<E`80/XeH0P2cSUT20;>>FP80/XeI0`2aS5P0102`ReL0/hiI0;:=F02aS5L20;2;EP030;6<
E`2bSEP0/hiI00P0]I1K0P2dSe/30;>>FP<0/XeI202`ReL80:n:EP040;67E@2bR5H0/XQF0;>9E`80
]8YH0P2eReT20:n:E@<0[XUD0`2]R5<20;:=F@040;6<F02`ReL0[XUE0:f8E080[8MC0`2[QU800`2/
Qe<0[HQD0:j9E@020:j9E@P0[XUB202^RED02@2`ReL0[hYF0:j9E@2^RED0[HQD0:b7D`2[QU80ZXEA
0:V4D0080:f7F0P0[XUD0P2`Qe<0102aR5@0/XUE0;:9E@2cRUH20;B;E`030;2;E`2_RUH0[HQD0080
ZhIB00<0[HQD0:n:EP2`ReL0102bQ5<40;>5E0040;2;E`2_RUH0[hYF0:j9E@80[HQD0P2/Qe<80:f8
E080/XUE0`2aR5@30;27D`80Zh5?00@0[89@0:f3D@2]Pe40[XAB0P2_QE<30:j4DP80[H=A0`2/PU02
0:j9E@030:f8E02/Qe<0ZhIB0080ZHA@00@0Z8=?0:b3B`2/Pd/0[8==0P2]Q5000`2^Q580[XAD0:j4
E0080:f4D080[HA<00@0[XE?0:j5D@2^QE40[hEC0P2_QED80:f4D0030:b3C`2]Q500[hIB0080/8MC
00<0[hIB0:f4D02/Pdl0202/Pdl30:N3D@D0Z8AB00<0Zh1E0:b1EP2/PEH00P2]PUL0102^PeP0[hAI
0;25FP2`QEX30:^2CPD0[8=?00@0[XEA0:f4D02]Q500[8=?0P2[PTh20:Z1C@030:j5D@2]Q500Zh9>
0080ZX5=00<0Zh9>0:f4D02^QE40202]Q5000`2^QDl0[HA>0:^2C0020:Z1B`0;0:^2C02/Pdd0[HA>
0:j6B02]QDP0[8A70:^3B02[PTX0[HA>0:n6DP2`Qe<00P2^Q5@0102/PU00Zh9>0:V0C02XOdT20:Im
A@<0Zh9>0`2/Pdl20:f4D0040;68DP2`Qe40/8MA0;27D@80[hI@0P2^QDl80:f4D080ZX5=00@0Zh9>
0:b3C`2^QE40[hIB0P2`Qe<0202^QE40[8=?0:Z1C@2YP4`0Z7m;0:V0C02ZPDd0Zh9>0P2_QE<0102^
Q580[H=A0:f3D@2/PU020:^1C`P0[XUB00<0[hIB0:j5D@2/Pdl00P2[PTh00`2/Pdl0[XEA0:n6DP08
0:^6D@<0[hEC1@2^Q5830:j5D@80[HA@0`2/Pdl20;26EP080;67E@2aR5@0[hIB0:n6DP2]Q4h0Zh9:
0:V0B02YP4X30:Z1B`80Zh9<0P2/Pdd80:f4D0<0[XEA0P2]Q5030:b3C`060:QoB`2YP4`0ZX5=0:^2
CP2/Pdl0[XEA0P2_QU820:n6D080[XE?0`2]Q4h00`2/Pdd0[hAA0:n4D@060:n4D@80ZX5;0P2[PT`0
102/Pdd0[HA>0:f4CP2^QDl20:f4D0<0[XEA0`2_QU800`2XOT`0ZX1>0:^1C`020:f3D@040:^1C`2Z
P4h0Z7i<0:UoC@<0ZX1>0P2[PDl20:b2D0030:f1D02/P4l0Zgm>0080ZWi=00<0Zgm>0:b0C`2]PE00
0`2/Pdl00`2[PTh0ZX5=0:V0C0020:V0C0<0ZH1:00<0ZX5;0:^2C02/Pdd00P2/Pdd20:n6DP040:j5
D@2]Q500[HA@0:b3C`80Zh9>202/Pdd20:f4D0<0[8=?0`2[PTh20:^1D@040:^1C`2[PTh0Zh9>0:^2
C080Zh9:0P2/Pd/0102/Pdd0[8=?0:b3C`2/PU020:b2DPT0ZH1<0P2[PE40102[PDl0[8=?0:b3C`2/
Pdd20:f4C00;0:f2F02]PUL0[H9E0:f3D@2]Q4h0[HE:0:f5B02]QDL0Z8=?0:N2CP2UP4`00P2TOd/0
2`2UP4`0Yh9>0:R3C`2YQE40Z8A@0:J2CP2UPDd0Y81<0:F1C@2VPTh0Yh=?00P0Zh9>0`2YOdd30:Z0
CP80Zh5?0P2XOT`30:UoC@<0ZX1>0P2ZQE420:V4D0<0Z8=?00<0Yh9>0:UoC@2YOdd01P2YOdd80:J1
C@80ZGm?00@0ZGm=0:V0C02YP4`0ZH1:0P2YP4P00`2VODT0Ygi:0:V0C0020:Z1C@060:V0C02WOTX0
YWe90:Z0D02YOdl0Yge;0P2VODT00`2WOTP0ZH180:Z1B@080:MnB0040:5lB02PNdL0X7]70:1kA`80
WgY60P2NNDD04@2WOTX0Z7m;0:V0C02YP4`0Z7m;0:ElB02RNDD0X7M30:5lA`2SOTT0Y7m:0:F0B`2T
OdX0XGa709eh@`2KMT40WGQ40080WWU500<0WgY60:1kA`2PNdL00P2QO4P00`2RODP0XGa709mjA@02
09iiA00409mjA@2QO4L0XGa70:9mB0<0XGQ40`2RNDD20:=jAP0309mjAP2MN4@0VgI20080VWE100<0
VgI209ehA02ONTH0102JND@409]jA@0809]eAP2LMTL0WWQ909miBP2NN4T0W7I709YdA@2ILd@809ag
@`0409iiA@2MN4@0WGQ409ag@`80VgI20P2JMD4809egB00309]eAP2MMdP0WgU:0080XG]<00/0X7Y;
09miBP2NN4T0WGQ409ag@`2KMT80VWE109]f@P2LMd<0WWU509mjAP0309id@R_ooooo000Zooooo`<0
TF0e0`2BHCH209=R=`05091S>@2?HSP0Sf8h08iQ=`2=H3H00P2<GcD04@2;GS@0TVLd095U=02?Hc80
SV8c08iR=@2?HSP0TF@k099U?02>IC40SfDc091V=02AIcL0TVLj09=X?@2DJCl0UFY000<0U6Pk00<0
TfLj099V>@2AICP00`2AICP3099V>@80TfLj0P2DJ3/209M[?P0409IZ?@2EJC`0UFTl09AX>`80TfLj
00<0TVHi09=W>P2EJC`00P2FJSd00`2EJC`0TfLj099V>@0809IZ>@0409EY>02FJST0Uf/j09Q/>`80
Uf/j00<0UFTh099V=@2AIC@00P2DJ3L00`2EJCP0UVXi09M[>P0209Q/>`0409U]?02FK3X0UF/i09=Y
=`80TVPf00/0TfTg09E[>@2FK3X0Vg4o09Y`?P2HKS`0Ufdk09I/>P2GKC/0V6hl09U_?@0209EY>080
UVXi0`2GJcX409Q/>`<0VFdl0P2JKSd809Y`?P0;09I[>02GK3T0V6dj09U^>`2JKc`0Vg0m09aa?P2M
LSl0W74n09eb?`2OM4400`2QMT<00`2OM440WW=009ic@00209ic@080WgA10`2PMD830:1fA0<0WgE3
0P2NM4830:5f@`<0X7E20P2OM4400`2PM4<0XGE40:9fA@020:=gAP060:9fA@2QMD@0X7A309ie@@2P
Md<0XGQ40P2SNTH00`2QN4@0X7M309ie@@030:9gA0<0XgQ50P2TNDH20:AhB@040:AhA`2TNDH0Y7U6
0:AiA080Y7U200@0YGY70:AiAP2TNDH0XgQ50P2RMd@20:5f@`80XgQ50P2TNDH0102UNTL0YW]80:Ik
B02WO4T20:=iA`<0XWQ60`2QMdD00`2MM3`0WgHn0:1g?`020:5h@080X7Lo00L0WgHn09ed?02TNdL0
XgY60:9iA@2PMd<0WgI200<0WWE100H0WgE309id@P2MLd40Vg4o09U_?@2HKS`209I/>P0;09Mb?@2G
LSh0UW4m09E_?P2DKSl0Tfe009=/@@2BJd00TV`m08mY>P2<ISL00P29Hc@01P2;ICH0SVPi095[?02>
JC`0SFPk08]V>@<0RF@g0P2;IST0102;HCT0RV0h08YP>02:H3P208UO=`80R5hf0`22GRh2085M;@80
P5`/0140Oe/[07mC;01oDb`0OeD]081F;P1oF2l0OeX`07eJ<01nFc40Me@Z07AA9`1aCR@0Le0V07MD
:P1hEB/0MU<Y07=@9P0206m>;@06071?;P1aD2l0LU4`07=B<@1dDc80ME@c201_CRd00`1YBbT0JT`Z
06a>;00206a>;00406Y<:P1XBRP0IdTW06Q9:P80IdPY00<0ITLX06E69`1UARL00P1TABH0201XBb/0
I4LW06138`1RABD0ITTY06Q;:`1TAbL0H4<S0`1WARD306Q79P80JDPW0P1WBBD206Q:9P<0JD/W00L0
JT`X06M:8P1YBB80JTXS06a:901^BbD0L4XU0080LTXV00<0LU4X075@9`1aCRH00P1cCBH02@1fCbP0
NDlY07]A:`1eEc<0MUDb07IF<01fE2h0Me@/07QB:`0307QA:00307aG:P1kERT0NeHY0080NeHY0`1j
EBP0101kEbL0O5PX07aH:01mFBT207iJ:P80Oe/[2020Fbh02021Fc@0PE`b089M<`22GC40Peha08=O
;`23Gbd0Q60^0P23Gbl208AP<00408EQ<@26HS80QV8b08MS<`80Q5ha0P25Gc801026H3<0Qf4d08MQ
=028HSD208AN<@80QElb00@0QV0c08MQ=027HC@0R68e0P27HC@308QR=@<0RF<f0P27HC8308IP<@<0
QEl`0P2:GC<01P29G380R5/a08MJ<026FBl0QEP^08AG;@P0QEl`1025Gc8408AN<@0308IP<`24GS40
PE/^0080OeT/00T0PU`_08IP<`28HSD0PV8c085Q<P22H380Peha089M<022G2l00P23FRh307mJ<0<0
P5/a0P21G38207iN;`80OEd^00@0O5`]07]K;01jFR/0NUX[2020FRd8085L<P0708AO<P23GS40PE`_
07mJ;@1nFB`0OeX]085L;`02089M<0<0OEX`0P1lFBl307]H;P0807YE:`1kER`0OEP^07iI;`1oFS00
OUT_07eH;P1lEbd807eH;P0407aL<`1jFS40N5P_07IF;@80M5@[0P1eEB`00`1jE2d0NeD^07eG<002
07mI<P0307iH<@1lERl0NeD^00P0N5D]2P1iER`207QE:`80Me@Z0P1fDbT807QE;@0307QC:@1iE2X0
NUD[0080NeH/00<0NUD[07UD:P1hDbT00P1hEBd01@1iERh0NUL_07UF;P1gE2`0ME8Z0080M54Y0P1e
DRX00`1fDb/0Me@/07MD;00207QE;@0607AA:@1cDRT0Le8Y079B:@1`DbT0Ke@Y0P1/E2P00`1eEB`0
M5@[079B:@02075A:003079B:@1dE2/0MED/00<0LE4X0`1bDRT207=C:P<0LU8[0P1aDBX3071@:@03
06U;9`1ZC2P0K4hZ0080KDl[00H0K4hZ06Y<:01YBbL0IdXR06Q;8`1ZCBD206a?9`0306]>9P1YC2@0
J4/S00<0ITXU0P1UBB@306A88`80JTd_00X0IDPZ05m2901O@R@0HdHX06I9:`1TAbT0HD@V06958`1T
AbD0IDPV0P1VBBL0101TAbD0HTDS06138@1SBbL2069:9P0806599@1PB2@0GdLS05m78`1NAR80I4HR
06E78`1WBBD306U;9`0306M99@1VB2@0JdlZ0080JThY00P0JDdX06Q<9`1WBbH0Id/V06I:9@1]DBT0
K50X06Y>9P80JDdU00D0JThV06a@:01]DBT0KU4Y06e@:00306]>9P0606e@:01`Db/0LE@/079F9P1d
F2P0MUXZ0`1hG2`00`1fFRX0METY07IG:`0207MH;080N5T]0P1iFRh00`1jFbl0P5h^085O;`02085O
;`80PV0`0P23HC4308AO<PD0QF0c0P26ISL01028ISP0RVDh08YU>02<IST208iU>@D0T6/g0`2?JSH4
099^>P@0Tflk0P2FLCd309Mb?P<0V7<o0P2LMd<209ehA0<0WWU500@0WgY60:1kA`2PNdL0X7]70P2Q
O4P30:9mB@<0Y7m;0P2UP4`30:J1C@<0ZHA@0P2ZQE430:^6DP030:b7D`2]R5@0[HQD0080[HQD0P2^
RED20:n:EPP0[XYJ0P2_ReL20;2<F0<0/HeI00T0/XiJ0;:=F02aS5L0/8]F0:n:E@2`ReH0/HaG0;>>
F@2eT5/0202cSUX20;:=EP030;:=F02bSET0/XaK0080/XaM00@0/XaO0;JAG@2eT5`0]8mK0P2cSUX0
1P2dSe/0]I1L0;JAG@2`ReL0/HaH0;:=F@80/hiJ00<0/HaH0:n:EP2^RED00`2`RU/00`2aRe`0/XaM
0;>=GP020;>=GP030;B?FP2eT5/0]Y5L0080^9=N00<0]Y5L0;F@F`2dSeX0202dRUP30;>>FP030;:=
F@2aS5P0/8]G0080/8]G00@0[XUE0:n:EP2_RUH0/8]G0P2aS5P20;:=F@80/8]D00<0/8]F0;2;E`2`
RUT00P2`RU/0102`RUd0[HQD0:f8E02^RED20:n:EP0;0;2;E`2aS5P0/HaH0;6<F02`ReL0[XUE0:b7
D`2[QU80[8MC0:j9E@2_RUH0202[QU80102`ReL0[hYF0:n:EP2^RED20:f8E080[8MC202`Qe<90:j9
E@<0[HQD0`2^RED20:n:EP80[8MB0P2]R5<0102^RE@0[hYE0:n:E@2`ReH30;>:EP80/XUE0`2aR5@2
0:j9E@80[HQD0`2/Qe<0102[QU80/HME0;67E@2aQeD20;26E0<0[hEC202[QU480:f4D0P0[8MB202^
Q5820;26E0040:n5D`2^Q580[89@0:^1C`80ZX1>202]Q5080:f3D@P0ZXEA202]Q5000`2YQ4l0ZhIA
0:f8D`020:n:E@030:j9E02]R5<0ZhIA00P0[H=A6@2/Pdl80:f4C0050:f4D02/Pdl0[8=?0:^2CP2Z
PDd00P2YP4`00`2XOd/0[HA@0:f4D00>0:f4D080[89B00@0[89@0:b3C`2/Pdl0[8==0P2/Pd/30:b3
C`<0Zh9>0P2ZPDd0202]Q500[8=?0:^2CP2[PTh0[8=?0:j5D@2`Qe<0/HQD202]Q5020:^2CP040:b3
C`2]Q500[HA@0:j5D@80[hIB102[PTh40:Z1C@80[HA@0P2/Pdl0102[PTh0ZX5=0:Z1C@2YP4`20:b3
C`040:f4D02^QE40[hIB0:n6DP80/8MC202/Pdl01P2_RUH0/HUF0;28E@2aQeD0/HED0;>5E080]8AD
00@0/HMG0:n5E@2]Pe<0[89B0P2[PE400`2/PU80[H=C0:j3F0020:j3EP030:j4E02^Q580[XEA0080
[XE?0`2[PTh50:b3C`80/8MC0`2_QU830:j5D@040:^2CP2/Pdl0[XEA0;27D`80/HQD00D0/8MC0:j5
D@2]Q500[8=?0:^2CP030:Z1C@030:b3C`2^QE40[hIB00<0[89@0P2]Pe430:j4DPP0[HA@00<0[8=?
0:f4D02^QE400P2_QU801P2]Q500Zh9>0:Z1C@2ZPDd0Zh9>0:b3C`80[XEA00H0[8=?0:^2CP2ZPDd0
Yh9=0:R3CP2YQ4l20:^6D@030:V4C`2XPdh0Yh9=00P0Zh9:00H0Ygi:0:QoB`2YP4`0ZX5=0:b3C`2^
QE420:n6DP060:V0C02ZPDd0ZX5=0:^2CP2/Pdl0[HA@0P2^QE480:j5C`P0ZH1<00@0ZGm=0:Z0CP2Z
P4h0ZX1>0P2[PDl20:b2D080Zh9:00@0Zh9<0:^2CP2[PTh0Zh5?0P2[PE450:b3C`<0Zh9>00<0Yh9>
0:R3C`2ZQE400`2/Qe<0202ZQE40ZHA@0;27D`2`Qe<0[hIB0:j5D@2/Pdl0Zh9>0P2ZPDd00`2/PU80
Zh5A0:UoC`020:QnCP030:UoC`2[PE40[89B0080ZHA@00@0Z8=?0:N2CP2WPTh0YX5=0P2UP4`20:V4
D080Z8=?0`2WPTh20:J1C@040:UoC@2ZP4h0ZX1>0:Z0CP80Zh5?0P2/PU001P2aR5@0/8MC0:n6DP2^
QE40[8=?0:^2CP80ZX5=202XPdh00`2]Pe<0Zh5A0:Z0CP020:QoB`0;0:Z1B`2[PTX0[HA<0:MnB02X
OdT0ZH1:0:Z1B`2[PT`0[8==0:f4CP2^QDl00P2YQ5020:R3C`<0Yh9>00X0YX5=0:QnCP2YOdl0ZGm=
0:Z1C@2[PTh0[8==0:b3B`2]Q4`0Zh1E0P2[P5<00`2[PE40Zh5?0:^2CP020:^2C080ZX5=0P2[PTh0
1`2/Pdl0[HA@0:f4D02^QE40YG]90:IlBP2XOT`00P2ZP4h00`2YOdd0Z7i<0:MmB`020:=nBP040:Ao
B`2UP4`0YH1<0:J1C@80Yh9>0`2WPTd30:J1C080YH1;202ZP4h80:MnBP80[7i<00@0ZWa:0:UkB@2W
NDL0YWQ60P2TMT@20:V0C0040:QoB`2WOTX0YWe90:ImB@80YGa800H0Y7m80:=nA`2SOTL0XWe60:5l
A@2PNd@209mj@`0:0:9mB02QO4L0WgY509iiA02ONTD0XGa70:AoBP2VPD`0YGa80:ImB@80Ygi:00/0
YWe90:=jAP2QN4@0XGQ409mf@P2NLT40WWA20:1fA02QNDH0X7]709ijAP0209]jA@0809]f@P2LMd<0
WWU50:1kA`2ONTH0WGQ409Ye@@2HLcl209aeBP0309afB@2LMTL0W7I50080WGQ400<0WGQ309id@P2N
M4800`2OMD<30:1fA0P0WWU500@0Xgi:0:5lB02ONTH0WGQ40`2LMd<0102MN4@0VWE109Ye@@2JMD42
09]f@P<0W7M30P2ONT<00`2ONTD0WgY609miB00209miBP0509miC02JM4D0VgE609]eAP2LMTL00P2M
MdP209ihB@<0W7I5:oooool002[ooooo0`2AH3D3099Q=P80Tf8g0P2?HSP308iQ=`<0SF0f00T0TVLd
095U=02?Hc80SV8c08iR=@2?HSP0TF@k099U?02@Ic<00P2@IS@00`2AIcL0TVLj09=X?@0209AY?`80
U6Pk0P2CIcX2099V>@80TFDh102BIST209=W>P80U6Pk0`2FJSd209EY?0<0U6Pk00<0TVHi09=W>P2E
JC`00P2FJSd00`2EJC`0TfLj099V>@0809IZ>@0309AX=`2EJCP0Uf/j00<0Uf/j00<0UFTh09AX=`2B
ISD00P2EJCP309IZ>@<0Uf/j00<0UV`j09E[>@2CJCL00P2BJ3H01P2CJCL0UF/i09I/>P2JL3h0VFlm
09M]>`<0UV`j00<0V6hl09U_?@2EJCP00`2FJST209M[>PD0V6`k0P2IKC`309Y^?@P0VW0n0P2HKCX0
3@2IKS/0VVll09]`?@2LLCh0WG8o09ic@02LLCh0WG8o09md@@2PMD80XGI30:1e@P2OM4400`2NLd03
09md@@<0X7E20`2PMT@309me@`80WWA2102PMD840:5f@`030:1d@`2QMD@0XWI50080XgM600H0XWI5
0:5eA02PM4<0WgI20:1g@`2QN4@20:9iA@030:5hA02PMd<0WgI200<0XWM40`2SN4D20:AiAP80Y7Q9
00@0Y7Q70:AiAP2TNDH0Y7U40P2TND800`2UNTL0Y7U60:AiAP020:=hA@80XWM400<0XGI30:9gA02R
Md@00P2SN4D0102TNDH0YGY70:EjA`2UNTL30:=iA`80XWQ60`2QMdD00`2MM3`0WgHn0:1g?`020:5h
@080X7Lo00<0WgHn09ed?02RNDD00P2RNDD00`2QN4@0X7M309mf@P0209ed@080WG=100@0W79009]a
?`2IKcd0V6hl0P2GKC/01P2GLSd0UW4m09Ia?@2EKch0U6ho09=]@080TV]000<0TV`m08mY>P2<ISL0
0P29Hc@02`2;ICH0SVPi091Z>`2=J3/0S6Lj08YU>029I3L0R6<f08UT=`2:ICP0RfHi00<0RElg0P28
GSH308MM=@@0PEd]1020G2`207eA:P0307aB:P1jDbX0NUD[0080N5D[00X0N5L/07MD:P1dDBL0LDhT
07=@9P1gE2X0N5D[07IC:@1cD2H0KTd/0P1_CRd00`1aD2l0LU4`07=B<@0207AC<PP0Kdh]00P0J4XX
06U;:@1ZC2X0Jdd[06Y<:P1YBbT0IdTW06E79@<0IdPY00<0ITLX06E69`1UARL00P1TABH0201VBBT0
HdHV06138`1QA2@0IDPX06I9:@1SARH0H4<S0`1WARD206Q79P<0JDPW00@0IdTU06Q:9P1XBRH0J4XV
0P1YBbL206Y<:00;06Q;8`1ZBR<0Jd/T06e;9@1_C2H0LT`W07=;9`1dC2P0Le8Y079A:01bCbL00P1c
CBH02@1fCbP0NU0Z07]A:`1cEC40ME@a07AD;P1eDbd0MU<[07QC:@0207UB:@0307UB9`1lEbX0O5LZ
00H0NeHY00<0O5PX07eI:@1mFBT00P1nFRX207mK:`03081L;020Fbh0P5/^00H0P5/^00H0PE/d089M
<`22GC<0PUda08=N<@23Gbl208AP;P0308=O;`24H300Q60`0080QF4a0P26HS801027Hc<0Q5ha08EO
<P25Gc8208IP<`80Qf4d00@0R68e08AN<@25Gc80QElb0P26H3<208MQ=00408QR=@27HC@0Qf4d08MQ
=080R68e0`29HcH308MQ<P80QV0a0`25Gc0208UN<`0408QM<P27G340QU/`08EJ;`80Q5T^2025Gc03
08IP<`0308EO<P24GS40Ped`0080Ped`00P0Qf4d08EO<P22G2l0P5X]07mI;022G2l0QElb08MQ=080
P60a00@0PEla089M<022GC00Ped`0P24Fbl307mJ<080P5/a0`21G38307iN;`<0OEd^0P1lG2d8085K
;PP0PE`b00<0Q5lb08=N<@21G2l00`1oFRd3085L;`80OU/a0`1mFS0307aI;`0307]F;01lEbd0OUT_
00<0OeX`00<0OEP^07aG;@1mF2h01`1mF2h00`1kFc80NET`07MG;P0307EE;080MUH]00P0NE</07YD
;@1lERl0OEL`07iH<@1mEc00NeD^07YD;@P0N5D]2P1iER`207QE:`80Me@Z0P1fDbT807QE;@0307QC
:@1iE2X0NUD[0080NeH/00D0NUD[07UD:P1hDbT0Me@/07QE;@0307UF;P0407MD;01eDRX0M54Y07AA
:@80ME8Z0P1fDb/207MD;00607QE;@1cD2P0Le0X079A:01bDRT0L5<Y0P1_E2T0101]EBT0MED/07AD
:`1bDRT2075A:003079B:@1dE2/0MED/00L0LU8Y00@0LE4X075A:P1aDBX0LE4Z0P1`D2T306m?:003
06U;9`1ZC2P0K4hZ0080KDl[00H0K4hZ06Y<:01YBbL0IdXR06U<901ZCBD206a?9`0306]>9P1YC2@0
J4/S00<0ITXU0P1UBB@306A88`80JTd_00l0IDPZ06139@1P@bD0I4LY06I9:`1TAbT0HD@V06=6901T
AbD0IDPV06I99`1UB2H0I4LU06958`1P@b40101QBBD40618900806=78P1TB2<0ITXU06M;9P1XC2L0
Id/V06I:9@1UBB@306U=:0<0J4`W0P1WBbH00`1]DBT0K50X06Y>9P0206U=9@0606Y>9P1/D2P0KE4Y
06mB:P1^DBT0K4lW0P1[CRH02`1]D2P0KU4Y071C:`1bERL0M5PY07EI:P1gFb`0N5`]07MK;01fFR/0
METZ00<0MeP/1@1hFBd307eK:`80OU`/0`1oGBd408AO<P@0QF0c0P25ICH01026I3H0RF@g08UT=`2;
ICP208eT>0<0T6/g1@2?JSH5099^>P<0Tflk0`2FLCd209Mb?P<0V7<o0`2LMd<209ehA0<0WWU50`2P
NdL20:5lB0<0XWe90`2TOd/30:F0C080YX5=0`2YQ5030:Z5D@80ZhIB0`2/Qe<20:f8E0<0[XUE00<0
[hYF0:j:FP2^RUX01P2^RUX20:n;E`80/8aH102aSET0202bSEP0/HaG0;2;EP2_RUD0/8]F0;6<E`2c
SUT0]I1K202cSUX20;:=EP030;:=F02bSET0/XaK0080/XaM00@0/XaO0;F@G02dSe/0/hiJ0P2bSET0
1P2cSUX0]8mK0;F@G02aS5P0/XeI0;>>FP80]8mK00<0/XeI0;2;E`2_RUH00P2`RU/20;6;G080/XaM
0P2cSEh00`2cSUT0]8mJ0;F@F`020;JAG0030;F@F`2dSeX0/hiI00P0]H]I0P2cSUX20;:=F@80/HaH
0P2`ReL30:n:EP030;2;E`2aS5P0/HaH0080/XeI0P2`Re@00`2`ReH0/8]G0;2:F@020;2:F`040;2:
G@2^RED0[XUE0:j9E@80[hYF0`2`ReL00`2aS5P0/8]G0:j9E@030:b7D`80[XUE202[QU830:n:EP03
0:j9E@2]R5@0[HQD0080[8MC202`Qe<90:j9E@<0[HQD0`2^RED20:n:EP80[8MB0P2]R5<0102^RE@0
[hYE0:n:E@2_RUD20;>:EP<0/XUE0`2aR5@20:j9E@80[HQD102/Qe<30;26E0<0[hEC0P2^Q5880:^6
D@P0[HA@202/Qe880:j4DP80/8ID00H0[hEC0:j4DP2]Pe40[89@0:^1C`2ZP4h80:f4D0P0[H=A202Z
QE480:f4D0080:V4C`2[QU40[HQC0:j9E02_RUD0[XUD0:f8D`2/Qe880:f3DAT0[8=?202]Q4`40:^2
CP@0ZX5=402]Q5020:b2DP040:b2D02/Pdl0[8=?0:b3C@80[8=;0`2]Q5030:b3C`80Zh9>00<0[XEA
0:f4D02/Pdl00P2[PTh00`2]Q500[hIB0;27D`080:f4D0030:^2CP2/Pdl0[8=?0080[HA@0P2^QE40
0`2_QU80Zh9>0:^2CP030:^2CP<0ZX5=0P2^QE420:f4D0040:b3C`2[PTh0Zh9>0:^2CP<0[HA@0P2^
QE430:n6DPP0[XEA0P2_RUH00`2`R5D0/HME0;65E0020;>5E0050;>3D`2`QUH0[hEE0:f3D`2/PU80
0P2[PE400`2/PU80[H=C0:j3F0020:j3EP030:j4E02^Q580[XEA0080[XE?0`2[PTh40:b3C`030:f4
D02_QU80[hIB0080[XEA0`2]Q500102/Pdl0Zh9>0:b3C`2^QE440;27D`050:j5D@2]Q500[HA@0:b3
C`2[PTh00P2ZPDd00`2/Pdl0[XEA0:n6DP020:b2D0<0[H=A0`2^Q5880:f4D0030:b3C`2]Q500[XEA
0080[hIB00H0[HA@0:^2CP2ZPDd0ZX5=0:^2CP2/Pdl20:j5D@060:b3C`2[PTh0ZX5=0:N2C@2XPdh0
ZHA?0P2[QU400`2YQ4l0Z8=>0:N2C@080:^2BP80ZX5=00<0Zh9>0:b3C`2]Q5000P2^QE40102_QU80
Zh9>0:^2CP2[PTh30:b3C`80[HA@202]Q4h80:Z1C@@0ZX1>0P2[PDl20:b2D080Zh9:00@0Zh9<0:^2
CP2[PTh0Zh5?0P2[PE460:b3C`80Zh9>00<0Yh9>0:R3C`2ZQE400P2/Qe<0102[QU80ZXEA0:V4D02`
Qe<20:n6DP080:j5D@2/Pdl0Zh9>0:^2CP2ZPDd0[H=C0:b2DP2ZP5020:UoC`040:Z0D02/PU80[H=C
0:Z5D@80ZHA@0P2XPdl20:N2CP030:J1C@2YQ500ZHA@0080Z8=?0`2WPTh20:J1C@@0ZX1>0P2[PDl2
0:b2D080[8=?00@0Zh9>0:Z1C@2YP4`0ZH1<0P2XOd/80:R3CP030:f3D`2/PU80ZX1>0080ZH1<00<0
ZX5;0:b3B`2]Q4`00P2XOdT01P2YP4X0ZX5;0:^2C02/Pdd0[HA>0:j5C`80ZHA@0P2XPdl40:N2CP80
ZGm?00@0ZX1>0:Z1C@2ZPDd0Zh9<0P2[PTX01P2[P5D0Zh1C0:^0D`2[PE40Zh5?0:^2CP80Zh9<0P2Z
PDd20:^2CP80[8=?0P2]Q5000`2UNdT0YWa:0:QnC0030:Z0CP030:UoC@2XOT`0Y7m;0080Y7m;00<0
YH1<0:J1C@2VPDd00P2WPTh30:N2C@<0YX5<0P2UP4/80:UoC@P0Ygi:00H0[7i<0:]mB`2[OD/0ZWa:
0:UkB@2XNTP20:MiA`060:Z1C@2YP4`0ZH1<0:MnBP2VODT0YGa80P2TNdL20:AoB0040:=nA`2RODH0
XGa50:1kA080WgY300<0XWe80:5lA`2PNdH00P2PNdH0102QO4L0Xgi90:=nB@2UO4P20:ImB@030:Mn
BP2UO4P0XgY60080XGQ400/0WgI209ib@@2NM480X7I40:5iAP2PNdL0WWY609]jA@2JND@0W7M309eh
A00209iiA@0409ehA02LMd<0VgI209Ye@@80W7E:00<0W7I909afA`2MMdH00P2MN4@00`2MN4<0WWA2
09id@P0309me@`<0X7I4202MN4@0202PNdL0WgY609ehA02LMd<0VgI209ag@`2MN4@0WWU50`2MN4@2
09iiA@<0WgY60P2NND800`2NND@0WWU509ihA`0209ihB@0509ihB`2KMDH0VgE609]eAP2LMTL00P2M
MdP209ihB@<0W7I5:oooool002[ooooo0`2AH3D3099Q=P80Tf8g0P2=H3H308iQ=`<0Sf8h00T0TVLd
095U=02@I3<0Sf<d08mS=P2@HcT0TF@k099U?02BJCD00P2BJ3H00`2BJ3P0TVLj099W?002099W?@04
09AX>`2CIcX0TfLj09=W>P<0TVHi00@0TFDh099V>@2BIST0TVHi0P2CIcX609AX>`80UFTl0`2FJSd0
0`2CIcX0U6Pk09EY?00209IZ?@0309EY?02DJ3/0TfLj00P0UVXi00<0TfLf09AX=`2FJST0102GJcX0
0`2FJST0UFTh09M[>P0209M[>P<0UVXi0P2EJCP00`2FK3X0UF/i09AZ>00209=Y=`0;09AZ>02EJcT0
UV`j09Q^?02GKC/0UF/i09AZ>02EJcT0UV`j09M]>`2HKS`00P2FJST209M[>P<0V6`k00<0VFdl09Q/
>`2HK3/00P2IKC`309Y^?@0309]_?P2KLCl0Vg4o00H0Vg4o00H0VVll09]`?@2KL3d0W74n09eb?`2N
Ld0209md@@0409aa?P2MLSl0WW=009md@@80X7E200<0WgA109ic@02NLd000`2OM4420:1e@P80XGI3
0`2PMT@309me@`80WWA20P2OM4420:1e@P070:5f@`2RMd@0XgQ50:=hA@2PM4<0XGE40:9fA@020:=g
AP060:9fA@2QMD@0X7A309mf@P2PMd<0XGQ40P2RNDD00`2QN4@0X7M309mf@P030:9gA0<0XgQ50P2T
NDH20:AhB@040:AhA`2TNDH0Y7U60:AiA080Y7U2102TNDH20:=hA@80XWM400@0XGI30:9gA02RMd@0
XWM40`2SN4D00`2TNDH0Y7Y80:=iA`020:=iA`80XWQ60P2QMdD00`2MM3h0WgI00:1g@@020:5h@P80
X7M100@0WgI009ed?P2OMT80X7M30P2RNDD0102QN4@0WgI209ac?`2KLSh309]a?`0309Y`?P2IKcd0
VFlm0080V6hl01P0UW4l09Ia?@2EL3`0U6hm09=]?P2BK3l0TV]0095Z?`2AJc`0SfTj08aV=`2:I3D0
RF<d08]U=P2=IcP0SVPi08aW>P2;IST0RF@g08QS=P27HSD0R6<f08UT=`2:ICP308EN=@80Q5dd0`23
G3<307mJ;@<0P5/^0P21G2l207Y@:P0407QA:P1gDBX0MU0Y07AA:@80Le8Y00P0Me@/07AA:@1aCRH0
Le0X07IC:`1gE2`0ME8Z079?9`80KTd/00@0Kdh]071?;P1aD2l0LE0_0P1bDC0806i=;00806I89P1W
BBL0J4XX06Q::01WBBL0ITPV06E79@1TAR@206M8:@<0ITLX0`1UARL0201SARH0HD@T05m28P1P@b<0
HdHV06A79`1RABD0H4<S0P1WARD206Q79P<0JDPW00<0JTTX06Q:9P1XBRH00P1YBbL306Y<:00706]=
:@1ZCBD0KDdV06e=9P1_CBL0LDhX07A>:@0207I>:P0307=B:@1bDBP0LTlW0080M4hW00T0Me0Y07Y@
:P1lDR`0L58/079B;01cDb`0M5<Z07IC:@1iE2P00P1kE2T00`1kEBP0O5LZ07aG:P0607aG:P<0OUXZ
0P1oFb/3081L;0P0PE`_00P0PU`e089M<`23GS@0Pehb08AO<P24H300Q60^08EQ;`80Q60`0P25HC44
08IR<P80QElb0P26H3<408MQ=080QElb0P26H3<408MQ=00408IP<`27HC@0Qf4d08MQ=080R68e0P29
HcH01028HS<0Qf4b08MQ<P27HC8208IP<@80QEl`0P29GS<01028GC80Qe`a08IK<026Fc0208EJ;`P0
QEl`0100R68e08MQ=026H3<0QElb08AN<@23GC00PU`_085K;P28HSD0QV0c08=M<021Fbh0P5X]085K
;P23GC00Q5ha0P1nGRl01020GS00PUd`089M<024GS4208IM<@80OeX`0P20Fc43085L<P04089M<`1o
GBl0Oed_07mM;`<0P5h`0P21Gc4808=M<0P0P5/a00<0Peha089M<021G2l00`1oFRd3081K;P<0Oe`b
0P1nFc4307eJ<00707eH;P1nFBl0P5/a085L<P20Fc40OeX`07iI;`0907eH;P0307UI<01hF2l0MUH]
0080MED/00D0MUH]07MG;P1hF2l0NE</07YD;@0307]E;P0307YD;@1iDb`0NE</00P0N5D]2P1iER`2
07QE:`80Me@Z0P1fDbT807QE;@0307QC:@1iE2X0NUD[0080NeH/00H0NUD[07UD:P1hDbT0MU<[07MD
;01hEBd207UF;P0307MD;01eDRX0M54Y00@0ME8Z0P1fDb/207MD;00;07A>9`1bCbL0Le0X079A:01b
DRT0LE@Z071E:P1aER/0M5@[07=C:P1bDRT00P1aDBP00`1bDRT0Le<Z07AD:`0207AD:`0407=C:P1b
DRT0LE4X075A:080L50W0P1`D2T206m?:080KThW0P1]CBH00`1ZC2P0JddY06a>:P0206e?:`0506a>
:P1[CBT0JT`X06U<901ZCBD0101[CRH206U<90<0Id/V0P1VBRD306E99080J4/[00T0IDPX06959@1R
ABD0I4LW06E8:01TAbL0HTDU06=6901TAbD00`1UB2H00`1SAR@0HTDS06548P04061890@0HDTU00@0
HdLR06A88`1UBB@0ITXU0P1WBbH00`1VBRD0IDTT06M;9P0206M;9P<0J4`W0P1YCBP00`1/D2P0JdlW
06Y>9P0206U=9@0606Y>9P1[CbL0K50X06mB:P1^DBT0KE0X0`1/CbL01P1]D2P0KU4Y079E:@1cERX0
M5L[07EH;080MUT]00<0MEP/07AG:`1hFBd00`1hFBd407MH;080NUPZ0P1kFB/307aJ;00407eK;@23
GS40Peha08=N<@80Q5lb0P25H3<01026HC@0Pf<d08=S=024HS@208MR=@0408US=P2;HSH0Rf8f08iY
=@L0SfXf0`2AKCT2099^>P<0Tflk00@0UG0l09Ia?@2FLCd0UW4m0P2GLSh209Qc?`80VgI20P2LMd<3
09ehA00409iiA@2ONTH0WgY609mjAP80X7]70`2QO4P20:=nBP80Y7m;0`2UP4`00`2VPDd0Z8=?0:R3
C`020:V4D0<0ZXEA0P2[QU840:b7D`80[HQD0P2^RED80:j:FP<0[h]G0P2`S5P30;6=F@080;:=F02a
S5L0/8]F0:n:E@2`ReH0/HaG0;>>F@2eT5/80;>>FP80/XeF00<0/XeH0;:=F@2bS5/00P2bS5d0102b
S5l0]8mK0;>>FP2aS5P20;2;E`0<0;6<F02cSUX0]8mK0;>>FP2dSe/0]I1L0;JAG@2eT5`0]8mK0;:=
F@2`ReL0/8YK0`2aRe`30;:<G@040;>=GP2aS5L0/XeH0;>>F@80]8mJ00<0/hiI0;:=F02aS5L0202f
S5X0102cSUX0/XeI0;:=F@2bSET30;6<F0030;2;E`2_RUH0[hYF00<0/8]G0`2aS5P20;2;E0030;2;
EP2`ReL0/8YI0080/8YK00@0/8YM0;2;E`2`ReL0/8]G0P2_RUH30:j9E@050;2;E`2_RUH0[XUE0:f8
E02/Qe<00P2]R5@00`2^RED0[8MC0:b7D`060:b7D`80[hYF0`2^RED30:f8E0P0/8MC2@2^RED30:f8
E0<0[XUE0P2_RUH30:f8D`<0[XUD0P2_RUD0102cRUH0/XUE0;:9E@2bRED20;68E080/8MC0`2^RED2
0:f8E0<0[8MC0`2_QE<20:j4DP<0[H=A202[QU480:f4D0P0[8MB202^Q5820;26E0030:n5D`2^Q580
[H=A0080[89@00<0Zh5?0:f4D02]Q5001P2]Q5080:f3D@P0ZXEA202]Q5000`2ZQE00ZhIA0:b7DP03
0:j9E0030:f8D`2/Qe80[H=A00L0[H=A6@2/Pdl80:f4CP@0ZX5=102[PTh@0:f4D080[89B00@0[89@
0:b3C`2/Pdl0[8==0P2/Pd/20:n6DP<0[XEA0`2]Q5000`2`Qe<0[hIB0:f4D0020:^2CP030:b3C`2]
Q500[XEA00P0[HA@0`2/Pdl20:f4D0<0[XEA202[PTh20:n6DP<0[XEA0`2]Q500102_QU80[XEA0:j5
D@2^QE440:f4D0P0[hIB00H0[HUE0:j9E@2^RED0[hMD0;26E02`Q5<20;:4D`030;26E02_QE<0[H=A
0080Zh5?00@0[89@0:f3D@2^Q580[X=H0P2^PeH00`2^Q5@0[XAB0:j5D@020:j5C`050:Z1C@2[PTh0
Zh9>0:^2CP2/Pdl01@2]Q5020:b3C`<0Zh9>00@0ZX5=0:^2CP2/Pdl0[XEA102_QU820:j5D@090:f4
D02/Pdl0Zh9>0:Z1C@2[PTh0[8=?0:j5D@2_QU80[89@00<0[H=A0P2^Q5820:n5D`P0[HA@00<0[8=?
0:f4D02^QE400P2_QU801P2]Q500Zh9>0:Z1C@2ZPDd0Zh9>0:b3C`80[XEA00H0[8=?0:^2CP2ZPDd0
Yh9=0:R3CP2YQ4l20:^6D@030:V4C`2XPdh0Yh9=00P0Zh9<202^QE420:f4D0<0[8=?0`2[PTh80:^2
C0P0[8=?0`2ZP4h20:^1C`<0[89@0P2[PTX0102[PT`0Zh9>0:^2CP2[PDl20:^1D@P0[8=?0P2XPdl0
0`2ZQE40ZhIB0:b7D`020:^6DP040:Z5D@2_QU80[hIB0:j5D@80[HA@00H0[8=?0:^2CP2[PTh0[XAB
0:f3D@2/PU020:^1C`040:b2D02]Pe40[XAB0:^6DP<0ZXEA0`2YQ5000`2XPdl0ZHA@0:V4D0020:R3
C`<0Yh9>0P2VPDd30:Z0CP80Zh5?0`2/PU030:QoB`D0Ygi:202XPdh20:b2DP040:^1C`2ZPDd0ZX5=
0:^2C080[8=;0P2YP4X0102ZPD/0Zh9<0:b3C@2/Pdd20:f4CP<0ZHA@0P2XPdl30:N2CP80Zh5A00@0
ZX1>0:Z1C@2ZPDd0ZH1:0P2YP4P01P2[P5D0Zh1C0:^0D`2[PE40Zh5?0:^2CP80Zh9<0P2ZPDd30:^2
CP<0[8=?00T0YWa:0:MmB`2YOdd0ZX1>0:^1C`2ZP4h0ZGm=0:QnC02TOd/00`2UP4`30:J1C@040:N2
CP2WPTd0Yh9=0:N2C@<0YX5<0P2UP4/80:MmB`P0Ygi:202YOT/20:^2CP060:V0C02XOd/0YWe90:Ak
A`2SNTH0XWU50P2TOdP00`2SOTL0XWe60:5lA@020:1kA00909mj@`2QO4L0XWe80:9mB02SOTT0XWe8
0:5lA`2PNdH0WgY50080YGa800@0YWe90:ElB02TNdL0XgY60P2QN4@03P2PMd<0Wg=209me@`2QMdD0
XGU60:1kA`2NNTH0VgY509YiA02ONTH0WWU509ehA02LMd<0VgI20P2LMd<01P2MN4@0WGI;09efB`2M
MdX0WGM809egAP80WGQ400<0WGQ309id@P2NM4800`2OMD<30:1fA0P0W7M300<0WGQ409ag@`2KMT80
0P2JMD40102LMd<0WWU509mjAP2ONTH30:1kA`80XGa80P2RODT209eh@@0309eh@`2MN4@0WGM60080
WGM800<0WGM:09]eAP2KMDH00`2LMTL309egB0<0W7I7:oooool002[ooooo0`2AH3D3099Q=P80Tf8g
00D0S5le08eP=P2=H3H0SV4g08mR>002091S>@0:095T>P2CJ3D0TVHe091T<`2?Hc@0Sf<f091S>@2B
IC`0TfHm09A[=`80TfTg00D0TfTi099W>P2BIc`0TVLm095V?00409=W>PH0TVHi0P2CIcX209AX>`80
UFTl0P2CIcX0102DJ3/0UFTl09EY?02FJSd209M[?P0309AX>`2EJC`0UFTl00@0UFTl00<0U6Pk09IZ
>@2FJST01P2FJST0102CIcH0U6Pg09EY>02FJST309M[>P80V6`k00H0VFdl09Q/>`2HK3/0Uf/j09IZ
>@2EJCP209AX=`0309M]>`2FK3X0U6Xh0080TfTg00H0U6Xh09I/>P2GKC/0Ufdk09I/>P2EJcT209AZ
>00309E[>@2GKC/0V6hl0080Uf/j0P2HK3/709U]?0<0VVhm0P2KKch809]a?`0309aa?P2MLSl0WG8o
0080WW=00P2OM4401@2PMD80W74n09eb?`2MLSl0WW=000L0WgA10P2PMD830:5f@`<0X7I40`2OMD<2
09id@P80WW=000T0WgA10:5f@`2RMd@0XgQ50:AiAP2UNTL0X7A30:5eA02RMTD00P2SMdH00`2RMTD0
XGE40:1d@`020:1g@`@0XGQ40P2PMd<30:9gA0<0XgQ50P2TNDH20:AhB@040:AhA`2TNDH0Y7U60:Ai
A080Y7U21P2TNDH20:=hA@P0XWM40P2TNTP30:=iA`<0XWQ600<0WGA009mf@P2PMd<00P2QN4@20:1g
@`0509mf@P2MM400WGA009ie@@2QN4@00P2RNDD00`2OMT80W7<o09U`?00809U_?@0;09E`>`2EL3`0
U6lk09=]?02BK3d0TF/n095Z?`2@JCh0TF/l08mY>P2<ISL00`2:I3D01@2;ICH0S6Hg08]V>@2:ICP0
R6<f0080QV4d00<0Qf8e08QS=P29I3L00`22GC<2085L<P<0P5/a0`1nFBd207mJ;P<0P5/_00H0O54^
07YB;P1hDRd0Me4/07EB;01cDB/2075A:P0807MD;P1dDB/0LDhX079?:@1fDbd0Me@^07AA:`1aCRP2
06e<:`80KTd/00@0Kdh]071?;P1`Cbh0L4l^201/BbX506E79@0306A6901SAB<0HdDS00H0ITLX0P1U
ARL206138`0405m28P1P@b<0HD@T06959@80HD@T0`1XAbH306U89`80JTTX0P1YBbL206Y<:0@0JddY
00H0K4lW06m?:01_CbP0LDlY07=@:P1fD2/207Q@;00>07AC:P1cDRT0Le0X07A>9`1eCbP0Me0Y07]A
:`1mDbd0KU4Y075A:P1bDRT0M5<X07ME:01kERX207eG:P0407iH:`1lEbX0O5LZ07aG:P@0OEP[00<0
OUT/081L;020G2`00`20G2`3085M;@P0PUd`00H0Pedf08=N=024GcD0Q5lc08EP<`25HC4208EQ;`80
QF4a1P26HS8208IP<`H0Qf4d0P26H3<608MQ=080QV0c0`27HC@308QR=@80R68c0`27HC8308IP<@80
R5lc0P27GS801026GC40QE``08EL<025G30808EO<080R68e00@0Qf4d08EO<P24GS40PU`_0P21Fbh0
1029HcH0Qf4d08AN<@22G2l2081J;@0:085K;P22G2l0OEd^07eM;P1oGBl0PUd`08=N<@25Gc80Qehb
08QO<`<0P5/a0`21G382089M<`80PE`_0P22GC001023GS40Q5lb08EP<`25H3<808AN<@P0P5/a00@0
PUd`085L;`21G2l0P5/^1@1oFRd2081M<`80Oe`b0`1nFc40101mFS00OUT_07mJ<020Fc42085L<P03
081K<@1nFBl0OEP^00P0OEP^00<0N5P_07MG;P1eEB`00P1eEB`00`1gEbh0N5P_07YJ<@0207UC;080
NU@]0P1iDb`207QB:`P0N5D]2P1iER`207QE:`80Me@Z0P1fDbT807QE;@0307QC:@1iE2X0NUD[0080
NeH/00H0NUD[07UD:P1hDbT0ME8Z07IC:`1gE2`207QE;@0307MD;01eDRX0M54Y00H0ME8Z0P1fDb/0
1P1dCBH0M4hW07A>9`1cD2P0Le8Y07=C:P80LUD[00<0M5@[07=C:P1aDBP00P1`D2L00`1aDBP0Le<Z
07AD:`0207EE;00707AD:`1bDRT0LE4X071@9`1_CbH0KThU06m?:00306i>9`80KDdV0P1/C2D00`1[
CBT0K4hZ06a>:P0406a>:P0306]=:@1[CRH0JdhV00<0JdhV0P1ZCBD00`1YC2@0J4`W06Q<9`0306M;
9P<0ITXU0P1WBRP00`1VBBL0I4LU06A79@0306A79@0306=6901TAbD0I4LU00<0I4LU00@0HdHT0695
8`1RAB<0GTHR0P1OAb<01P1PB2@0HDTU069:9P1RBRH0Hd/W06578P80HTPS00<0HdTT06A:9@1TBRD0
0P1TBRD01@1UBB@0ITXU06I:9@1WBbH0J4`W0080JDdX00<0JThY06Y>9P1ZCRH01P1ZCRH206mB:P03
06iA:@1]D2P0KE0X00<0K4lW00@0LE@X079E:@1bEBT0LeHZ101dEb/307QI;@80MeP/0`1fEb/207]I
;0<0O5X]0`1mFbh2089M<080Peha00X0Q5lb08EP<`25H3<0QV4d085Q<P22HS<0Pf4c08EP<`26HC@0
Qf4d0P2:HCD308eX=0@0SVTe00H0SfXf08m[=`2@K3P0T6`h095]>@2BKSX209=_>`0309A`?02EL3`0
UG0l00<0UW4m0`2GLSh209Ye@@80VgI20`2LMd<00`2MN4@0WWU509iiA@0309mjAP<0X7]70`2SOTX2
0:AoB`<0YH1<0`2XPdl20:V4D0<0ZXEA1@2[QU820:b7D`80[HQD202^RUX20:j:EP80[h]G0P2`S5P2
0;6=F@080;:=F02aS5L0/8]F0:n:E@2`ReH0/HaG0;>>F@2eT5/80;>>FP80/hiG00<0/hiI0;>>FP2c
SE`00P2cSEh0102cSF00/hiJ0;:=F@2`ReL20:n:EP0;0;2;E`2bSET0/hiJ0;B?F`2eT5`0]Y5M0;NB
GP2fTEd0]I1L0;>>FP2bSET0102aRe`40;:<G@030:n:E@2`ReH0/XeH0080/hiI00<0/XeH0;2;EP2_
RUD0202gSE/40;:=F@@0/HaH1P2`ReL20;6<F080/8]D00<0/8]F0;2;E`2`RUT00P2`RU/0102`RUd0
/HaH0;6<F02`ReL20:n:EP030:j9E@2]R5@0[HQD0080[hYF0P2^RED40:f8E0P0[8MC1P2^RED20:f8
E0P0/8MC2@2^RED30:f8E0<0[XUE0P2_RUH20:f8D`H0[XUD0`2bRED20;68E0<0/8MC0P2_RUH20:j9
E@80[HQD0P2/Qe<0102_QE<0[XAB0:j4DP2^Q5820:f3D@80[89@202[QU480:f4D0P0[8MB202^Q580
0`2`QU@0[hEC0:n5D`020:j4DP80[H=A00<0[89@0:f4D02]Q5001P2]Q5080:f3D@P0ZXEA202]Q502
0:^6D@030:b7DP2]R5<0[HQC00<0[HQC202]Pe4@0:b3Ca40[HA@00D0Z7m;0:V0C02YP4`0ZX5=0:^2
CP020:b3Ca40[HA@0P2]Pe<0102]Pe40[HA@0:f4D02]Q4h20:f4C080/8MC0`2_QU830:j5D@040;68
E02`Qe<0[XEA0:b3C`80Zh9>00<0[8=?0:f4D02]Q5003`2]Q5040:^2CP@0[8=?1P2_QU820:j5D@06
0;27D`2_QU80[hIB0:j5D@2]Q500[8=?0P2[PTh80;27D`060:^:E@2]RED0[8QD0:f8E02_Qe@0[hEC
0P2`Q5<00`2_QU80[XEA0:b3C`020:^2CP040:b3C`2]Q500[XEA0:f2E`80[H9E00<0[H=C0:f3D@2]
Q5000P2]Q4h20:Z1C@80Zh9>00@0[8=?0:f4D02]Q500[XEA0`2[PTh20:Z1C@<0ZH1<0P2/Pdl20:f4
D0D0[XEA00<0[HA@0:b3C`2[PTh00P2[PTh00`2]Q500[hIB0;27D`030:f3D@80[XAB0`2_QE<80:f4
D0030:b3C`2]Q500[XEA0080[hIB00H0[HA@0:^2CP2ZPDd0ZX5=0:^2CP2/Pdl20:j5D@060:b3C`2[
PTh0ZX5=0:N2C@2XPdh0ZHA?0P2[QU400`2YQ4l0Z8=>0:N2C@080:b3C`040;68E02`Qe<0/8MC0:n6
DP80[XEA0P2]Q5020:j5D@030:f4D02/Pdl0Zh9>0080ZX5=00<0ZH1<0:Z1B`2ZPD/01P2ZPD/80:f4
D080ZX1>0P2[PDl20:b2D080[H=A0P2/Pd/0102/Pdd0[8=?0:b3C`2/PU020:b2DP<0Zh9>102/Pdl0
1@2]Q500Z8=?0:V4D02YQ500ZXEA00@0ZhIB00<0[hIB0:j5D@2^QE400P2]Q5020:b3C`030:^2CP2^
QE40[XEA00@0[HA@0P2^QE440:^6DP@0ZXEA0P2YQ5020:R3C`<0Yh9>0P2VPDd20:Z0CP80Zh5?0P2/
PU020:f3D@<0Z7m;0`2YP4`20:Z1C@P0Z8=>0P2/PU80102[PDl0Zh9>0:^2CP2[PT`20:b3B`80ZX5;
0P2[PT`20:b3C@80[HA>0P2ZQE420:V4D080Z8=?0P2WPTh02@2/PU80Zh5A0:^1C`2ZPDd0ZH1<0:Qo
B@2XOdL0Ygi60:^0E@020:^0D`030:^1D@2[PDl0Zh9>0080Zh9<0P2ZPDd60:^2CP030:IlBP2WOD/0
ZGm=0080Zh5?00<0ZX1>0:UoC@2XOT`0202VPDd30:N2C@<0YX5<0P2UP4/80:IlBPP0Ygi:0P2XOd/2
0:V0C00:0:Z1C@2[PTh0Zh9>0:^2CP2/Pdl0Zh9>0:Z1C@2XOd/0YWe90:AkA`80XWU500H0YH190:Ao
B02TOdP0Xgi70:9mAP2QO4D20:1kA0080:5lA`2RODP0Y7m:0:F0B`2TOdX0XGa709iiA02LMd840:Ak
A`80XgY60P2RNDD04@2QN4@0Wg=209me@`2QMdD0XGU609mjAP2MNDD0VWU409Uh@`2QO4P0X7]709eh
A02KMT80VWE109]f@P2MN4@0WgY60080WWM<00<0WWQ;09egB02MMdH00P2MN4@00`2LMd80WWA209id
@P0309me@`<0X7I42P2JMD4209Ud@00409Ye@@2LMd<0WgY60:1kA`80WWU50P2ONTH40:1kA`80W7M0
00<0W7M209ag@`2LMTD00P2LMTL00`2LMTT0W7I709afA`0409afA`80WGM80`2KMDP[ooooo`00:_oo
ool3095P=@<0TV4f0P2CHSL208eP=P0408iQ=`2?HSP0Sf8h091S>@80TF@j00T0TfPe099V=@2AIC@0
T6@e091T=`2AI3X0TVDl09=V?@2DJcL00P2DJSP00`2CJCT0TfPk099W?002099W?@@0TVHi1`2CIcX2
09AX>`<0UFTl0P2CIcX0102DJ3/0UFTl09EY?02FJSd209M[?P0309IZ?@2EJC`0UFTl00@0UFTl00<0
UVXm09IZ>@2FJST01P2FJST309EY>0<0UVXi00@0V6`k09U]?02IKC`0VFdl0P2HK3/00`2GJcX0UVXi
09EY>00209AX=`0309M]>`2FK3X0UF/i0080U6Xh00<0UF/i09I/>P2GKC/00P2FK3X01P2EJcT0U6Xh
09E[>@2FK3X0V6hl09Y`?P80V6`k0`2IKC`309Y^?@80VFdl0`2JKSd309]_?PP0W790102NLd0409md
@@D0WG8o00<0WW=009md@@2OM4400P2OM4420:1e@P80XGI30P2RMd@30:1fA0<0WgE30P2NM4801P2N
Ld00WgA10:1e@P2QMT<0XWM40:AiAP80YGY700<0X7A30:5eA02RMTD00P2SMdH00`2RMTD0XGE40:1d
@`020:5hA0@0X7M30P2QN4@30:9gA0<0XgQ50P2TNDH20:AhB@040:AhA`2TNDH0Y7U60:AiA080Y7U2
1P2TNDH20:EjA`@0XgQ5102RMd@30:AjB0<0XgU70P2RN4H00`2MM400WgI20:1g@`020:5hA080X7M3
00D0WgI209ed@02LLcl0WGA009mf@P020:1g@`0309ie@@2LLcl0VW4m00P0VFlm00`0U6lj09A_>`2C
KSX0TV`k095[?02@JSd0T6Tn08mX?@2@JS/0SfTj08eW>02;ICH408YT=@0808YU>028HcH0QV4d08EP
<`24Gc80QF0c08IQ=027HSD3085L<P80P5/a0`1oFS0207eH;P@0OUT_0P1oFS004@1mEC80NeDa07]E
<@1hE300MU@_07AD;P1bE2h0LE<]07QD<01dD2`0LDdY079>:P1eDBd0MU8^07=?:`1_BbL0K4/Z00@0
KD`[0`1^CB`806]::@80IDLU00<0I4HT06=58`1SAB<00`1SAB<206E69`H0ITLX00P0GT4Q05m28P1P
@b<0HD@T06138`1QA2@0HTDU06=69P80J4LV0`1YB2L306Y9:080JT`X0`1[CBT306a>:P0606e@:01_
CbP0L50Y079@:P1dDB/0Me4/0P1iDBd03P1eE2/0M5<Z07AA:@1eCbP0MU0Y07QA:P1lDR`0OE<]06mB
:01aDBP0Le@X07IE:P1iEbX0OEP[0P1oFBX00`20FR/0O5LZ07aG:P0207eH:`0407iI;01oFRd0OeX]
07mJ;@D0PUh^0`21GBd808=N<@0608AN=`24GcD0QF0f08EP=025H3<0QV8b0P26HS0208MS<`H0QV8b
0P28HSD608MQ=080R68e1P27HC@308IP<`<0Qf4d0P28HSD308QR<`<0Qf4b0P26H3400`26H3<0QElb
08EO<P0208EO<P<0Q5ha2025Gc003028HSD0Qf4d08IP<`25Gc80Q5ha08=M<022G2l0PE/^08QR=@27
HC@0QElb08=M<0@0PE/^0P1mGBh01P1oGBl0PUd`08=N<@25Gc80Qehb08QO<`80P5/a0`21G383089M
<`80PE`_0P22GC001023GS40Q5lb08EP<`25H3<808AN<@P0P5/a1@20Fbh0101oFRd0OUT/07iI;01n
FB`307mL<P80OU/a0`1mFS0207mJ<006081K<@21G380P5/a07mJ<01mF2h0NeH/201mF2h00`1hF2l0
MeL^07EE;00207EE;00307MG;P1hF2l0NUXa0080NeD^00<0NU@]07UC;01hDR/00`1hDR/807QE;@X0
NEH/0P1hEB/207MD:P80MU<Y201hEBd00`1hDbT0NE@Z07YE:`0207]F;00607YE:`1iE2X0N5<Y07AA
:@1eDRX0Me@/0P1hEBd00`1gE2`0MU<[07EB:P0607EB:P80M54Y00/0MddW07E>9`1eCbP0MDlX07AA
:@1dDbX0Le<Z07AD:`1cDbX0LU8Y075A:002071@9`03075A:01bDRT0Le<Z0080MED/00L0M5@[079B
:@1aDBP0L50W06m?9P1^CRD0KdlX00<0KThW0P1]CBH206a<9@0306e?:`1/CRX0K4hZ00@0K4hZ00D0
KDl[06e@:01]D2P0K4lW06]>9P0406Y=9@80JDdX0P1XC2L406M;9P80IDPV00@0ITTW06M::01VBBL0
IDPV0`1TAbD206E89P0306A79@1SAR@0HdHT00<0HdHT00D0GTHR05m78`1OAb<0H4PT06599@02069:
9P0306=;9`1QBB<0HDTS00<0HDTS00<0HTXT06=;9@1SBbD00P1UBB@0101VBRD0Id/V06M;9P1XC2L2
06U=:080JDdU101ZCRH206U=9@0306e@:01^DBT0KU4Y0080KU4Y0P1]D2P00`1/CbL0LE@Z075D:P03
075D:P03079E:`1cER`0LeH/00@0MeP/101fEb/207iK<@80Oe`b1020GC<01P20Fbh0PE`_089M<023
GS40Q5lb08EP<`80QV4d0P21HC801023HC<0QF0c08EP<`27HC@208UP=080RfHb0P2<Ic<01@2=J3@0
SVTe08iY=@2>JCD0SVXf0080Sf/g00D0T6`h099^>P2CKc/0Tflk09A`?00309E`?0<0UW4m0P2GLSh0
102IM400VWE109Ye@@2JMD4209]f@P80W7M30P2MN4@209iiA@@0WgY60P2RODT20:=nBP80Y7m;0P2U
P4`20:N2CP80Z8=?0P2YQ5060:Z5D@<0ZhIB0P2/Qe<80:j:FP<0[XYF0P2_ReL30;2<F0080;:=F02a
S5L0/8]F0:n:E@2`ReH0/HaG0;>>F@2eT5/80;>>FP80/hiG00<0/hiI0;>>FP2cSE`00P2cSEh0102c
SF00/hiJ0;:=F@2`ReL20:n:EP0;0;2;E`2bSET0/hiJ0;B?F`2eT5`0]Y5M0;NBGP2fTEd0]I1L0;>>
FP2bSET0102bS5d40;6;G0030:n:E@2`ReH0/HaG0080/hiI00<0/HaG0;2;EP2_RUD0202fS5X40;6<
F0@0/XeI0P2aS5P60;2;E`80/8]D00<0/8]F0;2;E`2`RUT00P2`RU/0102`RUd0/HaH0;6<F02`ReL2
0:n:EP030:j9E@2]R5@0[HQD00<0[hYF0P2^RED20:f8E0030:b7D`2]R5@0[HQD00P0[HQD1P2^RED8
0;27D`T0[XUE0`2]R5@30:j9E@80[hYF1P2^RE@20:f8D`80/XUE0P2aR5@20;27D`80[hIB0`2_RUH2
0:j9E@<0[HQD0`2_QE<20:j4DP<0[H=A202[QU480:f4D0P0ZhIA202^Q5840:n5D`@0[XAB202]Q508
0:f3D@P0ZXEA202]Q5050:b7DP030:f8D`2^RE@0[XUD00P0[H=A402/PdlA0:f4D0050:QoB`2YP4`0
ZH1<0:Z1C@2[PTh00P2/PdlA0:f4D080[H=C00@0[H=A0:f4D02]Q500[HA>0P2]Q4`20;27D`<0[hIB
0`2^QE40102aR5@0/8MC0:j5D@2/Pdl20:^2CP030:b3C`2]Q500[HA@00l0[HA@00<0ZX5=0:^2CP2[
PTh00P2/Pdl20:f4D0<0[XEA202_QU800`2^QE40[HA@0:b3C`020:^2CP030:Z1C@2`Qe<0/8MC00H0
/8MC00H0ZHYD0:Z9E02/R5@0ZhMC0:b7D`2^QU<20:j4DP030:j5D@2]Q500[8=?0080Zh9>00@0[8=?
0:j5D@2_QU80[H9G0P2]PUD00`2]Pe<0[H=A0:f4D0020:f4CP80ZH1<00H0ZX5=0:^2CP2/Pdl0[HA@
0:j5D@2_QU820:^2CP80ZX5=102YP4`40:b3C`<0[HA@0`2^QE401`2]Q500[8=?0:^2CP2/Pdl0[HA@
0:n6DP2`Qe<00P2]Pe420:j4DP80[hEC0P2`QU@80:f4D0030:b3C`2]Q500[XEA0080[hIB00H0[HA@
0:^2CP2ZPDd0ZX5=0:^2CP2/Pdl20:j5D@060:b3C`2[PTh0ZX5=0:N2C@2XPdh0ZHA?0P2[QU400`2Y
Q4l0Z8=>0:N2C@080:b3C`80/HQD00<0/8MC0:n6DP2^QE400P2]Q5001P2/Pdl0[XEA0:j5D@2]Q500
[8=?0:^2CP80ZX5=00<0ZH1<0:Z1B`2ZPD/01P2ZPD/80:j5D@<0Zh5?0P2/PU030:f3D@80[8=;00@0
[8==0:b3C`2/Pdl0[89@0P2/PU820:Z1C@80Zh9>00@0[8=?0:f4D02]Q500[HA@102YQ500102ZQE40
ZhIB0:^6DP2/Qe<20:j5D@@0[HA@0P2/Pdl20:f4D0@0[XEA0P2]Q5040:Z5D@@0ZhIB0P2YQ5020:R3
C`<0Yh9>0P2VPDd30:^1C`80[89@0`2]Pe420:^2CP<0[8=?0`2]Q5080:R3CP80[89B00@0[89@0:b3
C`2/Pdl0[8==0P2/Pd/20:^2C0@0[8==0P2]Q4h30:Z5D@80ZHA@0`2XPdl20:^1D@040:Z0CP2YP4`0
ZH1<0:QoB@80Ygi600H0Zh1E0:^0D`2[P5<0Zh5A0:^1C`2[PTh20:^2C080Zh9>1P2ZPDd0202VO4X0
Z7i<0:Z0CP2[PDl0[89@0:^1C`2ZP4h0ZGm=102WPTh40:J1C@<0Yh9=0`2VPD`20:F0B`P0YWa:202W
OTX01@2VOTX0Ygm;0:R0C02YPDd0ZX9>0080Zh=?00T0[8A@0:^2CP2ZPDd0ZH1<0:QoB`2VODT0Y7]7
0:=jAP2RNDD00P2UP4T00`2TOdP0Xgi70:9mAP020:5lA@090:1kA02QO4L0XWe80:AoBP2UP4/0Y7m:
0:5lA`2NND@0W7M20080Y7]700<0XgY60:9iA@2RNDD0102RNDD02`2PM4<0X7I40:5gA@2QNDH0WgY6
09eiA@2IN4<0V7M20:9mB@2PNdL0WGQ40080VgI200<0W7M309iiA@2PNdL00P2ON4d01P2OND`0WWQ9
09egAP2MN4@0W7M309ag@P80WWA20`2OMD<30:1fA0T0VWE10`2IM400102KMT80WGQ40:1kA`2RODT4
09]f@P80W7M30P2MN4@209ag@00309ag@P2LMd<0W7I50080W7I700<0W7I909egB02MMdP01P2LMTL3
09]dBB_ooooo000Zooooo`<0TF0e0`2BHCH209=R=`0408iQ=`2?HSP0Sf8h08mR>0@0T6<i00T0U6Tf
09=W=P2AIC@0T6@e091T=`2AI3X0TfHm09AW?P2CJSH00P2CJCL00`2CJCT0TfPk09AY?P0209AY?`04
095U>02BIST0TVHi099V>@<0TfLj00<0U6Pk09=W>P2CIcX00P2DJ3/309EY?00409IZ?@2DJ3/0U6Pk
09AX>`80UFTl0`2FJSd00`2GJch0UVXm09EY?00209AX>`0309EY?02FJSd0Uf/n00P0UVXi0P2GJcX0
1`2FJST0UFTh09IZ>@2FJST0Uf/j09Q/>`2IKC`00`2GJcX309IZ>@80UFTh00<0V6hl09M]>`2EJcT0
0P2DJSP0102EJcT0Ufdk09Q^?02GKC/209I/>P0509E[>@2FK3X0V6hl09Y`?P2LLT000`2IKC`209Y^
?@<0Vfln00@0VFdl09Y^?@2JKSd0VVhm0P2KKch209a`?`P0W790202NLd0209eb?`<0W74n00<0WG8o
09md@@2PMD800`2PMD820:5f@`<0XWM40`2PMT@309me@`80WWA20P2PMD80102QMT<0XWM40:=hA@2S
N4D20:AiAP030:1d@`2QMD@0XWI50080XgM600H0XWI50:5eA02PM4<0XWU50:5hA02PMd<209mf@P03
0:1g@`2QN4@0XWU500<0XWM40`2SN4D20:AiAP80Y7Q900@0Y7Q70:AiAP2TNDH0Y7U40P2TND840:Ai
AP80YGY70P2VNdP30:EjA`80Y7U60`2SN4D20:EkB@80Y7Y80`2SNDL0102RN4H0WG=109me@`2PMT@2
0:5gA@80X7I400<0WgE309ec@@2MM4001`2MM40209Y`?P80VFlm00`0V6hl09M]>`2GKC/0Ufdk09=^
>@2CKSX0TVdi095[>P2@JS/0SfTl08mX?@2>Ic`208mY>P0308eW>02;ICH0RV@e0080RF<d00T0R68c
08QS=P27HSD0QF0c08AO<P23GS40Q5lb08EP<`26HC@00`1oG38207iK<@<0OEX`0`1nF34207eG<0<0
O5H_00H0Ne@c07UE<`1iEC<0MeDb07IE<P1cEC42079F<@0807QD<P1dD2h0LDd[079>;01dD2h0ME4_
079>;01^BRP806a;:PP0JDPW00@0ITPV06E79@1TAR@0HdDS0P1RA2800`1SAB<0I4HT06E69`0206E6
9`<0ITLX0P1WB2T0101M@200H4<S06959@1RABD20654900306=69P1VBBT0J4LV00<0JDPW0P1ZBBP2
06]::@<0JddY0P1/CRX306e?:`0F06e@:01_CbP0L50Y079@:P1dDB/0Me4/07Q@;01iDBd0MUD/07ED
:`1eDRX0MU0Y07MA:P1iDR/0OE<]07iD;P1bEB/0M5DY07IG:`1hEbX0NeT[07mK:`80PE/Z00L0PU`[
07aG:P1mF2/0OEP[07iI;01oFRd0P5/^0080PE`_0`24H30208=O;`<0PUh^2024Gc801P25GcP0QF0f
08EP=P26HCD0QV4d08MS<`80Qf<a0P28I3@208MS<`@0QV8b0P29HcH208QR=@@0Qf4d0P29HcH208QR
=@@0Qf4d0P25Gc8208IP<`<0Qf4d00<0R68e08US=029Hc@00P28HS<308MQ<P0308IP<@24Gc80Q5lb
00H0Q5lb2025Gc001026H3<0QElb08EO<P25Gc8308AN<@0508=M<026H3<0QElb08AN<@23GC001022
G2l207iN;`04081N<022GC00PUd`08AN<@80QUda00@0P5/a085L<P21G380PE`b0P22GC<208=N=0<0
PU`_0`23GC0208AN<@P0Ped`201oFS001`1oFRd0P5/^081K;P21G2l0P5/^07mJ;@1nFB`00P1mF2/2
07iK<@80OEX`0`1lFBl02@1kF2h0OUT_07mJ<01oFS00P5/a07mJ<01mF2h0NeH/07UD:P0807eH;P03
07UI<01hF2l0MUH]0080MED/00L0MUH]07MG;P1hF2l0OUPa07aF;`1kEBh0NE</0080N58[0P1iDb`8
07QE;@X0NEH/0P1hEB/207MD:P80MU<Y201hEBd00`1hDbT0NE@Z07YE:`0207]F;00:07YE:`1iE2X0
N5<Y07=@:01dDBT0MU<[07MD;01hEBd0Me@/07IC:`D0ME8Z0P1dDBT207=@:080NDlY00@0Me0Y07I@
:@1fD2T0M54Y0P1cDRT00`1cDbX0LU8Y071@9`0206m?9P03071@9`1bDRT0Le<Z0080M5@[00@0Le<Z
079B:@1aDBP0LE4X0P1`D2L2071@:@80KdlX0P1^CRL206e=9P0306i@;01]Cb/0K4hZ0080JddY00L0
K4hZ06e?:`1^D2`0Ke8Z06iA:@1/CbL0JdhV00@0JTdU0P1ZCRT206U=:0<0J4`W00L0Id/V06=78P1S
Ab80ITXU06U=:01XC2L0IDTT0080HdLR00@0IDTT06I99`1UB2H0I4LU0`1RAB<00`1SAR@0I4LU0618
9003061890@0HDTU0P1PBR<305m98P03061:8`1RC2D0HddV00@0ITXU0`1WBbH00`1XC2L0J4`T06U=
9@0406Y>9P0606U=9@1XC2@0JdhV06a?9`1]D2P0KU4Y0P1_DRX0101^DBT0KE0X071C:`1`Db/306mB
:P03071C:`1bEBd0LeH^00<0MEHZ0P1fEb/307MH;0<0Oe`d0P20GCD3085N=P0607mJ;@20Fbh0PE`_
089M<024Gc80QF0c0P26HC@2089R<`0408=Q<`26HC@0QV4d08QR=@80RV4e0P2:IC4208]V<P0:08aW
<`2=J3@0SVTe08iY=@2=JCD0SVXf08m[=`2@K3P0TFdi09=_>`80U70l0P2DKc/209E`?0<0UW4m00<0
Ug8n09Qc?`2IM4000P2IM40209Ye@@80VgI20P2LMd<209ehA0<0WWU500@0WgY60:9mB@2RODT0XWe9
0P2SOTX30:AoB`<0Yh9>0P2XPdl70:V4D080ZXEA0`2[QU880:j:FP040:f9E@2^RUH0[XYF0:j:EP80
[h]G0P2`S5P0202bSEP0/HaG0;2;EP2_RUD0/8]F0;6<E`2cSUT0]I1K202cSUX20;>>E`030;>>F@2c
SUX0/heL0080/heN00@0/heP0;B?F`2cSUX0/HaH0P2`ReL0302aS5P0/hiJ0;B?F`2cSUX0]8mK0;F@
G02fTEd0]I1L0;B?F`2bSET0/8]G0;>=GP<0/XaM0`2aRe`0102`RU/0/8]F0;6<E`2bSEP20;>>F@03
0;:=F02aS5L0/8]F00P0]H]I00@0/8]G0;6<F02aS5P0/HaH0`2bSET0102cSUX0/HaH0;6<F02aS5P3
0;2;E`80[hYF0P2`Re@00`2`ReH0/8]G0;2:F@020;2:F`040;2:G@2`ReL0/8]G0;2;E`80[hYF1@2^
RED30:n:EP030:j9E@2/Qe<0ZhIB00/0[HQD0`2^RED20:n:EPP0/8MC2@2^RED30:f8E0<0[XUE0P2_
RUH20:n:E@<0[XUD0`2]R5<30;68E080/8MC0`2_QU80102`ReL0[hYF0:n:EP2_RUH20:j9E@80[HQD
00@0/HME0;26E02`QU@0/8ID0P2_QE<20:j4DPP0ZhIA202]Q5080:^6D@P0[XAB202_QE<80:f4D0P0
[H=A202ZQE480:f4D0030:f8D`2/Qe80ZhIA0080ZhIA00<0[HQC0:j9E02_RUD0202]Pe4@0:b3C`T0
[XEA202]Pe440:Z1C@@0Zh9>402]Q5020:j4E0040:j4DP2^QE40[XEA0:j5C`80[XE=0P2_QU830:j5
D@<0[HA@00<0/8MC0:n6DP2]Q5000P2[PTh00`2/Pdl0[HA@0:j5D@080:f4D0<0[XEA0P2]Q5030:b3
C`80ZX5=00<0Zh9>0:b3C`2]Q5000P2^QE40102_QU80[HA@0:f4D02]Q5030:j5D@80[hIB102]Q503
0:b3C`030:^2CP2_QU80[hIB00H0[hIB0P2YRU@0102ZRE@0ZhMC0:^7D`2[QU820:f5DP030:j5C`2]
Q4h0[8==0080Zh9<00@0[HA>0:n6D02`Qe40[85F0P2/PE@00`2/PU80[89@0:b3C`020:b3C@060:Qo
B`2YP4`0ZX5=0:^2CP2/Pdl0[XEA0P2_QU80102/Pdl0Zh9>0:^2CP2[PTh20:Z1C@80ZH1<0P2/Pdl4
0:^2CP050:b3C`2^QE40[hIB0:j5D@2]Q5000`2/Pdl00`2^QE40[hIB0;68E0030:j4DP80[hEC0`2`
QU@80:f4D0030:b3C`2]Q500[XEA0080[hIB00H0[HA@0:^2CP2ZPDd0ZX5=0:^2CP2/Pdl20:j5D@06
0:b3C`2[PTh0ZX5=0:N2C@2XPdh0ZHA?0P2[QU400`2YQ4l0Z8=>0:N2C@080:b2D0040;27D`2_QU80
[hIB0:j5D@80[HA@0P2/Pdl20:f4D0<0[8=?0`2[PTh80:^2C0P0[HA@0P2[PDl20:b2D0<0[H=A00@0
[XAB0:b3B`2/Pd/0[8==0P2/Pdl0102/PU00[89B0:b2DP2YP4`20:Z1C@030:^2CP2/Pdl0[HA@0080
[XEA00H0ZXEA0:V4D02YQ500Z8=?0:V4D02ZQE420:b7D`P0[HA@00<0Zh9<0:b3C@2]Q4h00P2^QDl0
102]Q4h0[8==0:^2C02XPdl30:V4D0<0ZXEA00<0ZhIB0:V4D02YQ5000P2XPdl30:N2CP80YX5=0P2[
PDl20:b2D0<0[H=A00<0[XAB0:j5D@2^QE400`2^QE430:f4D0P0Z8=>00<0Zh5A0:b2DP2]Pe400P2^
QE400`2]Q4h0[8=;0:^2BP050:b3C@<0[HA>00@0ZhIB0:Z5D@2ZQE40ZXEA0P2YQ5020:R3C`060:Z0
D02YOdl0ZGm=0:V0C02XOd/0Z7m90P2XOdL01P2[P5D0Zh1C0:^0D`2[PE40Zh5?0:^2CP80Zh9<0P2[
PTh30:Z1C@<0ZH1<00P0Yge;0:QnC02ZP4h0Zh5?0:b2D02[PDl0ZX1>0:UoC@<0Z8=?0P2WPTh30:J1
C@<0Yh9=0`2VPD`20:F0B`P0Yge;202WOTX01@2TOdX0YH1;0:F0B`2VPD`0Yh9=00<0Z8=>0P2YP4`0
0`2XOd/0Ygi:0:ImB@020:ElB0070:AkA`2VPDX0YH190:F0B@2TOdP0Xgi70:9mAP020:5lA@0;0:5l
A`2RODP0XWe80:=nB@2RODP0XGa70:1kAP2ONTD0Y7]70:=jAP2RNDD00P2QN4@03`2RNDD0XgY60:=j
AP2SNTH0XGE40:5gA@2RN4H0XWY709mjAP2MNDD0VGQ309Qg@P2QO4P0X7]709iiA@0309ehA080WWU5
0P2PNDh01P2OND`0WgU:09ihA`2MN4@0W7M309ag@P80WWA20`2OMD<30:1fA0T0W7M30`2KMT80102L
Md<0WgY60:5lB02RODT209Ud@080VWE10`2KMT801P2LMd<0WGQ109eh@@2MN4<0WGQ409egAP80WGM8
00@0WGM:09egB02MMdP0WGM80`2LMTL209]eAP<0VW=::oooool002[ooooo0`2AH3D3099Q=P80Tf8g
0P2AI3X3091S>@<0Sf8h00h0U6Tf09=W=P2BISD0T6@e091T=`2BIC/0TfHm09AW?P2BJCD0TVPf09=Y
=`2CJCT0U6Tl09EZ?`80UV]10P2AICP2099V>@80TfLj1@2DJ3/309EY?0D0UVXm0P2EJC`309AX>`03
09Q/?`2GJch0UFTl0080U6Pk00<0UFTl09M[?P2HK3l0202FJST0102JKSd0VFdl09M[>P2FJST209EY
>00309IZ>@2GJcX0V6`k0080UFTh0`2FJST309M[>P0309Q^?02GKC/0UV`j0080U6Xh00<0UV`j09M]
>`2HKS`00P2HKS`209M]>`0409Q^?02JL3h0WG=109id@P<0VVhm0P2KKch309a`?`<0VVhm0P2KKch3
09a`?`P0WG=11P2MLSl209aa?P0309eb?`2LLCh0Vg0m0080Vg0m00<0WG8o09md@@2PMD800P2PMD82
0:5f@`@0XWM40`2PMT@309me@`80WWA2102RMd@40:=hA@030:1d@`2QMD@0XWI50080XgM600H0XWI5
0:5eA02PM4<0XWU50:5hA02PMd<209mf@P030:1g@`2QN4@0XWU500<0XWM40`2SN4D20:AiAP80Y7Q9
00@0Y7Q70:AiAP2TNDH0Y7U40P2TND800`2SN4D0Y7U60:AiAP020:EjA`80YW]8102WO4T00`2VNdP0
YGY70:EjA`020:AiAP<0YG]90P2TNTP30:=iA`0309ec@`2OMDD0X7I60080XGM70P2PMTH01@2OMDD0
WG=309mf@P2MM400VW4m0080VG0l00<0Vg8n09ie@@2PMd<00P2KLCl0102JL3h0VFlm09M]>`2FK3X2
09E[>@0609=^>@2BKCT0TVdi095[>P2@JS/0SfTl0P2>Ic`01P2?JCX0SVPi08eW>02<ISL0RV@e08US
=080Qf4b00P0Qf8e08IQ=024Gc80Peha089M<023GS40Q5lb08EP<`<0Oehc0P1nGC8307eL<@80P5Xe
00@0OeTd07eG<P1lES40NU@_0P1iDbh207A@;P0:07=A;P1cDRl0LE<_071D;`1aEC00KeD`07QD<P1e
DBl0LDd[079>;080M50^00<0LDd[06e99`1[BRT01P1[BRT00`1ZBBP0J4LV06Q79P0606Q79P0806Q:
:01VB2H0I4HT06=58`1RA280HdDS06A6901UAbD206A59P80IDHW00`0ITLX06M8:@1WB2T0IdPY05e0
801QA2@0IDPX06A79`1RABD0HD@T06E8:01YC2`306U89`80JTTX0`1[BRT306a>:P80KDl[0`1^D2`0
1P1/CbL0KdlX06m?:01aCbT0Le0Z07I@:`80N50/00h0MeH]07IE;01fDb/0Me4Z07QB:`1jDb`0OU@^
07mE;`1eF2`0N5T[07UJ;01kFb`0OE/[081L:P80PUdY00L0PehZ07aG:P1mF2/0OUT/07mJ;@20Fbh0
PE`_0080PUd`00<0QV8b08EQ<@25HC400P24H30208=O;`03089N;P24Gc80Q5lb00H0Q5lb00H0QV0i
08IQ=`26HCL0Qf8f08MR=@28I3@208QT<P0308UU=@28I3@0R6@d0080Qf<c0P26HS801025HC40RV@g
08US=P29HcH208QR=@80Qf4d00@0QV0c08YT=`29HcH0RF<f0P28HSD208MQ=00408IP<`25Gc80QElb
08EO<P80QV0c0`27HC@308US=080R68c0`27HC84089P<P@0Pf4c2025Gc0208=M<080Q5ha0P25Gc82
08IP<`P0Ped`0P20H3401021Gc40PUd`089M<023GC0208AK;`<0PE`b0P22GC<308=N=0<0Q5/_0`23
FRh2089I;@P0PE/^201oFS001`1nFB`0OeX]081K;P21G2l0P5/^07mJ;@1mF2/00P1lEbX207aI;`80
NeP^101jEbd207eH;P80OUT_00@0OEP^07]F;01hDbT0Me8X201mF2h00`1kFc80NET`07MG;P0307EE
;080MUH]00@0P5Xc07mI<P1lERl0NU@]0P1iDb`00`1jE2d0NeD^07QE;@0707QE;@X0NEH/0P1hEB/2
07MD:P80MU<Y201hEBd00`1hDbT0NE@Z07YE:`0207]F;00607YE:`1iE2X0N5<Y079?9`1cD2P0ME8Z
0`1gE2`00`1fDb/0ME8Z07IC:`0207EB:P80M54Y0P1cD2P01P1bCbL0O50[07a@:`1jD2X0Me0Y07E?
:080LTlW00@0L4lV07=C:P1aDBP0L50W0P1_CbH00`1`D2L0LE4X07=C:P07079B:@04075A:01aDBX0
LE4Z075A:P80L50Y0`1_CbP00`1_DBd0KU0/06a>:P0206]=:@0706a>:P1^D2`0Ke4]075D;01_DRX0
KE0X06Y=9@0206U<900306Y=9@1[CRH0JdlZ00<0JThY0P1YCBP206Q<9`80HTHO00l0Id/T06]?:01Z
CRL0IDTR06967`1SAb00ITXS06M::01UB2H0HdHT06958`1QA280HTDS06=6901TAbD0101QBBD40618
900305i;8`1MBR80G4TQ0080G4TQ00<0GT/S061=9@1QCRH00`1WBbH306I:9@80IDTT00<0Id/S06Q<
901ZCRH00P1[CbL01`1ZCRH0J4`T06M;8`1XBb<0JD`T06a?9`1^DBT00`1`Db/0101_DRX0L58/06mA
:`1^D2X206e?:@0906mA:`1aDbd0LU@^079C9`1cE2P0M5DY07EF:P1fEb/0N5T]0080NEX^0P1lFC<2
07eJ=0<0OU/e00T0Oe`f07iI;01oFRd0P5/^089M<023GS40QF0c08IQ=027HSD00P23Hc@01024HS@0
Qf8e08MR=@29HcH208]R=P0608QS;`29I300RVDa08]V<P2<Ic<0SFPd0P2>JCD01P2<J3@0SFTe08iZ
=P2?JcL0TFdi09=_>`80U70l0`2DKc/209E`?0<0UW4m0`2HLcl209Ud@0<0VWE100@0VgI209ag@`2L
Md<0W7M30P2MN4@209iiA@@0XWe90P2SOTX20:AoB`@0Yh9>0P2XPdl20:V4D0@0Z8=?0P2YQ5030:Z5
D@P0[XYJ0P2]RED30:j:EP<0[h]G00P0/XeH0;6<E`2`ReH0[hYE0;2;EP2aS5L0/hiI0;F@F`P0/hiJ
0P2dSeP00`2dSeX0]8mK0;B>G@020;B>G`040;B>H@2eT5`0]8mK0;>>FP80/XeI00H0/hiJ0;B?F`2e
T5`0/HaH0;:=F@2cSUX20;B?F`030;:=F@2`ReL0[hYF0080/heN0P2bS5d20;6;G080/8YK00<0/HaG
0;:=F02cSUT00P2dSeX00`2cSUT0/XeH0;6<E`080;>9E`80/8]G0P2aS5P20;:=F@80/hiJ0P2bSET2
0;6<F0040;2;E`2_RUH0[hYF0:n:EP80/8]D00<0/8]F0;2;E`2`RUT00P2`RU/0102`RUd0[XUE0:j9
E@2^RED20:n:EP<0/8]G00P0[HQD0:j9E@2_RUH0/8]G0:n:EP2^RED0[8MC0:^6DPP0[XUE0P2/Qe<2
0:f8E0040:j9E@2_RUH0[hYF0:n:EPP0/8MC2@2^RED30:f8E0<0[XUE0P2_RUH30:n:E@030:j9E02]
R5<0[HQC0080[8MB0P2aR5@20;27D`@0[hIB0P2`ReL30:n:EP<0[XUE102bR5H20;67E@80/8ID202[
QU480:f4D0P0ZXE@202^Q5850:n5D`<0/8ID202]Q5080:f3D@P0ZXEA202]Q500202]R5<0[8MB0:^6
D@2ZQE00ZhIA0:b7DP2^RE@0/8]F202]Pe4@0:b3C`T0[XEA202]Pe<40:^2CP@0ZX5=402]Q5020:j4
E0040:j4DP2^QE40[XEA0:j5C`80[XE=0`2]Q5030:b3C`80Zh9>00<0[XEA0:f4D02/Pdl00P2[PTh0
0`2]Q500[hIB0;27D`080:f4D0030:n6DP2^QE40[XEA0080[HA@0P2/Pdl02@2[PTh0ZX5=0:Z1C@2[
PTh0[8=?0:f4D02^QE40[hIB0;27D`030:^2CP030:b3C`2]Q500[HA@0080[XEA0`2[PTh20:b3C`<0
[HA@202^QE402P2XRU@0YhUC0:R9D`2YR5<0ZXIB0:^6DP2ZQE40[8AA0:f4C02/Pd/20:^2BP050:b3
B`2]Q4`0[hI>0;27C`2/PEH00P2/PE@00`2/PU80[89@0:b3C`020:b3C@80Z7m;00L0ZH1<0:^2CP2]
Q500[XEA0:n6DP2`Qe<0[HA@00<0[8=?0P2[PTh20:Z1C@030:f4D02/Pdl0ZX5=00<0ZX5=00H0[8=?
0:j5D@2_QU80[hIB0:j5D@2]Q5020:b3C`030:j5D@2`Qe<0/HQD0080[XAB0P2_QE<40;26E0P0[HA@
00<0[8=?0:f4D02^QE400P2_QU801P2]Q500Zh9>0:Z1C@2ZPDd0Zh9>0:b3C`80[XEA00H0[8=?0:^2
CP2ZPDd0Yh9=0:R3CP2YQ4l20:^6D@030:V4C`2XPdh0Yh9=00P0[H=C0`2]Q5050:b3C`<0Zh9>0`2/
Pdl20:f4D0P0[HA>202/Pdl30:b2D0<0[H=A0P2^Q5820:f4C0040:f4CP2]Q500[HA@0:f3D@80[H=C
0P2YP4`02@2ZPDd0Zh9>0:b3C`2]Q500[XEA0:n6DP2[QU80ZXEA0:V4D0020:R3C`030:Z5D@2/Qe<0
[HQD00P0[HA@00<0ZH180:Z1B@2/Pd/00P2]Q4`0102/Pd/0ZX590:V0B02VPDd20:N2CP80Z8=?0P2Y
Q5000`2ZQE40ZHA@0:V4D0020:R3C`<0Yh9>0P2VPDd30:b2D0<0[H=A0P2^Q5820:f4D080[8=?00@0
Zh9>0:Z1C@2YP4`0ZH1<202XPdh00`2[PE40[89B0:j4DP020:n6DP030:j5C`2/Pd/0Zh9:00H0[HA>
0P2/Pdd20:^6DP<0ZXEA0`2YQ5020:MmC@040:QnC02XOd/0Z7m;0:V0BP80ZH1800H0Zh1E0:^0D`2[
P5<0Zh5A0:^1C`2[PTh20:^2C080Zh9>0P2ZPDd20:V0C080Z7m;00<0Yge;0:UoC@2ZP4h00`2/PU00
102[PDl0ZX1>0:V4D02YQ5020:R3C`040:N2CP2VPDd0YX5=0:J1C@<0Yh9=0`2VPD`20:F0B`P0ZGm=
202WOTX50:F0B`<0YX5<202WOTX20:J1BP040:F0B@2TOdP0Xgi70:9mAP80XGa500<0XWe80:5lA`2P
NdH00P2PNdH01P2QO4L0Xgi90:=nB@2SNTH0XWU50:5hA080X7M300`0XGQ40:=jAP2SNTH0Y7]70:5e
A02QMdD0XWQ60:9jA`2ONTH0W7Q409Qg@P2GMT4209mjAP<0X7]700<0WWU509ehA02LMd<00P2QNTl0
1P2PNTd0WgU:09ihA`2MN4@0W7M309ag@P80WWA20`2OMD<30:1fA0P0WGQ400P0WgY609iiA@2MN4@0
WGQ409iiA@2PNdL0XWe90:=nBP<0W7M30P2MN4@309iiA@80WWU200<0WWU409iiA@2NN4L00P2NN4T0
0`2NN4/0WWQ909ihB@0209egB00409afA`2KMDH0VgE609]eAP<0VW=::oooool002[ooooo0`2AH3D3
099Q=P80Tf8g0P2BIC/0102AI3X0T6<i091S>@2?HSP208iQ=`0>09AY=P2CIcH0TVHe095U=P2AICP0
TVDk09=V?@2DIch0TFPd095W=@2BJ3H0TfTi09EZ?@2FJd0209M/@P<0TFDh00<0TVHi09=W>P2DJ3/0
1@2DJ3/209EY?0<0UVXm0P2GJch0102FJSd0UFTl09EY?02DJ3/209=W>P0309Q/?`2GJch0UFTl0080
U6Pk00<0UFTl09M[?P2HK3l0202FJST0102LL3l0VVhm09Q/>`2FJST309EY>00709IZ>@2GJcX0U6Pg
09AX=`2EJCP0UVXi09M[>P0209Q/>`0409U]?02HKS`0Ufdk09I/>P80UF/i00<0UV`j09M]>`2HKS`0
0P2IKcd209Q^?00409Y`?P2LLT00WWA20:1fA0<0VVhm0P2KKch309a`?`80VVhm0`2KKch309a`?`P0
WG=100<0WG8o09aa?P2LLCh00`2LLCh209]`?@0709ic@02LLCh0Vg0m09Y_?02KL3d0W74n09ic@003
0:1e@P80XGI30`2RMd@0102SN4D0X7I40:1fA02PMT@309me@`80WWA20P2TNDH30:=hA@<0XWM400<0
X7A30:5eA02RMTD00P2SMdH01P2RMTD0XGE40:1d@`2SNTH0XGQ40:1g@`80WWE100<0X7M30:5hA02S
NTH00`2RMd@30:=hA@80Y7U60P2TN4T0102TN4L0Y7U60:AiAP2TND@20:Ai@P040:=hA@2TNDH0Y7U6
0:EjA`80YW]80P2WO4T20:UnB`040:QmBP2WO4T0Yga90:IkB080YGY70`2UNdT30:AjB080XgU700<0
WG=309meA@2PMTH00P2QMdL20:1fAP0509meA@2MLd<0X7M309ed@02IL3`00P2FKCT00`2JLCd0WWE1
0:9iA@0209ab@00I09Y`?P2IKcd0Ufdk09E[>@2DJSP0TfTg099]>02BKCT0TF`h091Z>@2?JCX0SVPk
08iW?02=IS/0SfTj08iX>@2=IcP0S6Hg08YT=@29Hc@0Qf4b08IP<@27HSD0QF0c08AO<P03089M<004
08=N<@24Gc80P5ld081O=080Oehc0`1nGC801`1mG340PE/f085K=P1oFC@0OELb07]E<01iDbh00P1g
DB`01P1_Bb/0KT/[06m<;01_CRd0KU0^06e@;P80K58_00@0N5@d07EA<@1aCBd0LDd]0P1dD3000`1a
CBd0KDTY06]::@0206]::@D0JTTX201XAbH00`1YBbT0IdTW06E79@0206=58`0306A6901UAbD0ITPV
0080I4DV0P1UARL01P1VAbP0IdPY06M8:@1XBBX0GD0P06959@80ITTY0P1RABD0101VBBT0Jdh^06U8
9`1YB2L306Y9:0<0JdXY0`1/CRX206e?:`<0KU0/00H0JdhV06i>9`1^CRL0L4hX079?:@1eCbX207M?
:`0>07MF;@1fEB`0MU<[07MA:P1hDR/0NU</07iD;P1oEBl0N5`]07YK;@1kG2d0OEd^07mM;@21GB/3
08=N:P80OEP[00L0OUT/07mJ;@20Fbh0PE`_089M<023GS40Qf<c0080QV8b00<0QF4a08AP<024H300
0P23Gbl808EP<`0608IP>@26HCL0QV4g08MR=P27HSD0R6@d0P28I38208UU=@80R6@d00@0Qf<c08IR
<P26HS80QF4a0P2:I3L208US=P0408QR=@27HC@0Qf4d08IP<`80RV@g0P29HcH01028HSD0Qf4d08MQ
=026H3<308EO<P<0QV0c0P27HC@308US=0<0R68c0P27HC83089P<PD0Pf4c2025Gc02089L;`0408=M
<024GS40QElb08IP<`80Qf4d0P22G2l208=M<0@0Q5ha00H0PV8c085Q<P22H380Peha089M<022G2l2
08=J;P80PE`b0`22GC<308=N=080Q5/_0P23FRh01022FBd0PEP/081G:`20Eb/8081J;@P0OeX`00<0
OEP[07mJ;@20Fbh00P21G2l0101oFRd0OEP[07]F:@1kERT207]H;P80NUL]0P1iER`207QE:`80O5L]
0P1mF2h0101kER`0NE@Z07MB:01eD2H807eH;P0407aL<`1jFS40N5P_07IF;@80M5@[0P1eEB`01022
G3D0P5Xc07eG<01kEBh207YD;@0307]E;P1lERl0N5D]00L0N5D]2P1iER`207QE:`80Me@Z0P1fDbT8
07QE;@0307QC:@1iE2X0NUD[0080NeH/00L0NUD[07UD:P1hDbT0LDhV07=@:01eDRX0MU<[0080Me@/
00<0MU<[07EB:P1fDb/00P1eDRX00`1dDBT0Le0X07=@:002079?9`0607iB;@1mDB`0Ne4[07Y@:P1f
CbP0LddV0P1`CBD00`1bDRT0LE4X071@9`0206m?9P03071@9`1aDBP0LU8Y00<0LE4X0`1bDRT207=C
:P<0LU8[0P1aDBX3071@:@0306mA;@1^D2`0K4hZ0080JddY00L0K4hZ06i@;01_DBd0LE@/071C:`1]
D2P0JTdU0080JD`T00@0JTdU06]>9P1[CbX0JdlZ0P1ZCRT306U=:00=06Q<9`1QAAh0HDDN06M;901/
D2T0JdlX06I:8`1RAQl0HdLP06I:8`1WBRP0IDPV06=6900206548P0406958`1SAR@0IDPV06=;9`80
HTXV00d0HDTU0618901OAb<0GdLS05i68P1OC2@0GDXR05a98@1KB200G4TQ05e:8P1OC2@0HDhV0080
J4`W00@0Id/V06I:9@1VBRD0IDTT0P1TB2<00`1VBR80J4`T06U=9@0206]?9`0706U=9@1XC2@0ITXR
06I98@1XBb<0JdhV06iA:@03075D;00A071C:`1`DR`0KU0Z06e?:@1/CRP0KDlY06i@:P1aDbd0LU@^
071A9@1aDRH0LU<W07AE:@1gF2`0NEX^07YK;`1kG3000`1iES0207YG<@<0NePb00P0OUT/07mJ;@20
Fbh0PE`_08=N<@25H3<0QV4d08MR=@80Q6@e00@0QF<e08QS=P28HcH0RV@g0P2<HcL208QS;`0308UT
<02:IC40RfHb0080SFPd00L0SVTe08aX=02<J3@0SVXf08m[=`2AKCT0TVhj0080U70l0`2DKc/309E`
?080UW4m00@0Ug8n09Qc?`2HLcl0V7<o0P2IM40209Ye@@80VgI20P2LMd<309ehA00309iiA@2QO4P0
XWe90080XWe90P2SOTX20:AoB`040:J1C@2WPTh0Yh9>0:N2CP80Z8=?0P2YQ5040:R3C`80ZHA@0`2Z
QE480:j:FP<0[HUE0P2^RUH30:n;E`080;:=F02aS5L0/8]F0:n:E@2`ReH0/HaG0;>>F@2eT5/80;>>
FP80]8mH00<0]8mJ0;B?F`2dSUd00P2dSUl0102dSV40]Y5M0;F@G02dSe/20;>>FP060;B?F`2eT5`0
]Y5M0;2;E`2aS5P0/XeI0P2cSUX00`2aS5P0[hYF0:j9E@030;>=GP030;:<G@2aRe`0/8YK0080/8YK
00<0/XeH0;>>F@2dSeX00P2eT5/00`2dSeX0/hiI0;:=F0080;:8EP<0/8]G00<0/HaH0;:=F@2cSUX0
0P2cSUX20;:=F@80/HaH00@0/8]G0:n:EP2_RUH0[XUE0P2`Re@00`2`ReH0/8]G0;2:F@020;2:F`04
0;2:G@2]R5@0[HQD0:j9E@80[hYF00H0/8]G0;6<F02aS5P0[HQD0:j9E@2_RUH20;2;E`030:j9E@2/
Qe<0ZXEA00P0[XUE0P2/Qe<20:f8E0040:j9E@2_RUH0[hYF0;2;E`P0/8MC2@2^RED30:f8E0<0[XUE
0P2_RUH0102`ReH0[hYE0:n:E@2^RE@20:f8D`80[8MB0P2aR5@20;27D`<0[hIB00@0[XEA0;2;E`2`
ReL0/8]G0P2_RUH30:j9E@80]8YH0P2cREL20;:8EP80/HME202[QU480:f4D0P0ZXE@202^Q5840:n5
D`@0/8ID202]Q5080:f3D@P0ZXEA202]Q5000`2^RE@0[8MB0:^6D@020:Z5D0030:b7DP2^RE@0/8]F
00P0[H=A402/Pdl90:j5D@P0[H=C00D0[HA@0:b3C`2/Pdl0Zh9>0:Z1C@020:V0C0030:QoB`2]Q500
[HA@00h0[HA@0P2^Q5@0102^Q580[XEA0:j5D@2^QDl20:j5C@<0[8=?0`2[PTh20:Z1C@080:f4D02/
Pdl0Zh9>0:^2CP2/Pdl0[XEA0;27D`2aR5@80:f4D080[hIB00@0[XEA0:f4D02]Q500[8=?0P2[PTh2
0:Z1C@040:^2CP2/Pdl0[XEA0:n6DP80/8MC00@0ZH1<0:Z1C@2ZPDd0Zh9>0P2/Pdl20:f4D080ZX5=
0P2[PTh0102/Pdl0[HA@0:j5D@2^QE480:b3C`80YhUC0P2XRE<01P2XQe80ZXIB0:Z5D@2ZQE40[HA<
0:b3B`80Zh9:00D0[8=;0:f4C02_QTh0/HQ@0:b1EP020:b1E0030:b2DP2/PU00[8=?0080[8==00T0
Ygi:0:QoB`2YP4`0Zh9>0:f4D02^QE40[hIB0;27D`2^QE400`2]Q5020:b3C`80Zh9>00@0[HA@0:b3
C`2ZPDd0ZH1<0P2ZPDd02`2/Pdl0[XEA0:n6DP2_QU80[XEA0:f4D02/Pdl0[HA@0:j5D@2`Qe<0/HQD
0080[XAB0P2_QE<30;26E0030;67E@2]Q500[HA@00H0[HA@00<0[8=?0:f4D02^QE400P2_QU801P2]
Q500Zh9>0:Z1C@2ZPDd0Zh9>0:b3C`80[XEA00H0[8=?0:^2CP2ZPDd0Yh9=0:R3CP2YQ4l20:^6D@03
0:V4C`2XPdh0Yh9=00P0[H=C1P2[PTh20:b3C`060:V0C02ZPDd0ZX5=0:^2CP2/Pdl0[HA@0P2^QE48
0:j5C`P0Zh9>0`2/PU020:f3D@<0[XAB0P2]Q4`0102]Q4h0[HA@0:f4D02]Pe420:f3D`80ZH1<00<0
ZX5=0:^2CP2/Pdl00P2^QE400`2_QU80ZhIB0:Z5D@030:R3C`030:Z5D@2/Qe<0[HQD0080[8=?102]
Q5020:j5D@030:QoA`2YP4P0Zh9:0080[8=;00<0Zh9:0:V0B02XOdL00P2UP4`0102VPDd0Yh9>0:N2
CP2XPdl40:V4D080Z8=?0`2WPTh20:J1C@<0[89@0P2]Pe430:j4DP80Zh9>00H0ZX5=0:V0C02WOTX0
YWe90:ElB02TNdL80:R3CP030:^1D@2/PU80[XAB0080[hIB00<0[XE?0:b3B`2[PTX00P2^QDl40:f4
CP80[8==0`2[QU820:Z5D@<0ZHA@0P2VO4`0102WOD/0Z7m;0:QoB`2YP4X20:Z1B@060:^0E@2[P5<0
Zh1C0:^1D@2[PDl0Zh9>0P2[PT`20:^2CP80ZX5=00`0ZH1<0:QoB`2XOd/0Ygi:0:MmB`2YOdd0Zh5?
0:b2D02]Pe40[89@0:^1C`2ZP4h30:V4D0030:R3C`2WPTh0YX5=0080YX5=0`2WPTd30:J1C080YH1;
202ZP4h80:MnBP<0Y85;1@2SP4X20:ElB080YWe900@0Ygi:0:QoB`2XOd/0ZH1<0P2VPDX00`2UP4T0
Y7m80:=nA`020:9mAP0?0:5lA@2RODP0XGa709mjA@2NND@0WgY50:5lA`2TOdX0YX5<0:=jAP2RNDD0
X7M309mf@P2PMd<0XGQ40080XgY601T0YGa80:9fA@2QMdD0XWQ60:9jA`2ONTH0W7Q409Qg@P2GMT40
WGQ409mjAP2QO4P0XWe90:5lB02ONTH0W7M309]f@P2RNe00XGY?0:1jC@2ONDX0WWQ709ehA02LMd<0
W7M20080WWA20`2OMD<30:1fA0P0WWU50P2QO4P309mjAP030:1kA`2RODT0Xgi:00<0WgY60P2PNdL3
0:5lB080WgY300<0WgY509mjAP2ONDP00P2ONDX00`2OND`0WWQ909ihB@0209egB00409afA`2KMDH0
VgE609YdA@<0VW=<:oooool002[ooooo0`2?ISX208iU>@<0SF@h202<H3<2091T=`<0TFDh0`2BIST0
2@2AI3/0TVDl09AW?P2EJ3l0UVU009EX?`2DIch0TfHm095T>P03099U>`80TfHl0P2DIcd309IZ?@<0
Uf/n0P2HK3l809IZ?@D0UFXm0`2FJch0102DJ3L0UFTh09EY>02FJST209M[>P80V6`k0`2GJcX609IZ
>A00VFdl0`2HK3l309U]@080VVi11@2IKC`309Q/>`80VFi10P2JKd80102KL4<0W75409aaA02MLTD2
09Q/>`80VFdl0P2JKSd209]_?P80WgA10`2NLd0309eb?`P0W7A000d0WW=009md@@2PMD80XGI30:9g
A02SN4D0Y7U60:EjA`2XOd/0Ygi:0:AkA`2QN4@0X7M30080WgI200<0X7M30:9iA@2RNDD01P2RNDD2
0:=gAP80XWI50P2QMD@20:1d@`80XWI500H0XWM40:=h@`2SN440XgTo0:Aj@02TNSh209md@@040:1e
@P2QMT<0XGI30:9gA080XgQ50P2UMdD20:AfA0<0XgE300@0XWA20:9iA@2RNDD0XWU50P2SNTH30:Ak
A`80XgY60`2TNdL30:ElB080YGY700<0Y7U60:=hA@2RMd@00P2QMT<00`2PMD80W7M209ag@P0309ag
@P@0WGQ300`0X7I409me@`2NM480W79009]a?`2IKcd0V6hl09M]>`2MLd40Vg4o09Q^?02EJcT209=Y
=`80U6Xh00H0TfPk099W>P2BIcX0TFHi091U>02?I3L208iS=P80SFLj00<0S6Hi08]U>02:I3L00P29
HcH01028HSD0QF0f08AO=@22GC<2081K<@03085L<P23GS@0Q5le0080PEd]00@0P5/^081K;`1oFS00
OeTb0P1oFC@03P1nFc<0O5Ta07UF;P1fDb/0ME8Z07IC:`1hEBd0NEH^07ED<@1dDc00Le8_079A;P1a
D2d0L4l/0P1_CR/01P1fCbh0Ldl]07=?;@1aCb`0Kdh[06a>:P80JThY00@0Jdd[06Y<:P1ZC2X0JT`Z
0P1YBbT206Q::080K4T[00@0JdPZ06Y7:@1ZAbT0JDHX0P1XABL0201UCBT0I4XW06989@1RAB<0HT@R
06A38P1WA2@0J4DU0`1UAbD306I89P80IdTW00@0IDPX06I9:@1VBBT0ITTY0P1WBRX206Q;:`80LDTU
00P0L4XU06m<9P1^C2H0KDdV06i>9`1/CbL0Le0X079?9`<0LDhV00L0Le0X07AA:@1fDb/0LD`R07=>
901eD2H0N5<Y00<0NE@Z00<0N5<Y07aJ;01kFB/01@1kFB/0101lFR`0P5/^081K;P20Fbh2085L;`@0
PUd`00@0P5X[089L;@24GRl0QV0a0P27HC801@26H340QEl`08EQ;`25HBl0Q60^0080Pel]00<0PUh/
085M:`21GB/00P29Hc@01028HS<0Qf4b08MQ<P26H34208EO<00808QS;P27HRd0QF0[08AO:P25H2/0
Qf8]08UT;`2;IS4208US=00408QR<`27HC80Qf4b08IP<@80QEl`2027HC@808QR<`80QV0_00<0QV0a
08MQ=027H3D00P28HCP01028HCX0QV0c08QR=@29HcH208YT=`0308US=P28HSD0QV0c00<0R68c0P27
HC8308IP<@0807eH:`1oFRd0PUd`08EP<`26HC@0QF0c08=N<@21G2l408AN<@@0QElb2026H2l8089M
<0<0Peha0`22GC02085L;`0;085K=020FS<0OeTb07iH<@1oFC80PE/d08AN=`25GcP0OUT/081K;P22
GC000P23GS400`20Fbh0OUT/07aG:P03081K;P80PE`_0`22GC02081L;080Oe/[0P1nFRX307eI:@80
NeP^00H0O5T_07eJ<01nFc40Oe`b081M<`21GS@307aI;`<0NeP^2P1jEbd207EJ;`<0M5T^0`1cF2d3
07QE:`D0NEH/00H0NUL]07UF;01hEB/0Me@Z07IC:@1dDBL207=@9P@0ME8Z0P1fDb/207MD;00507UE
<@1hE300N5D_07QE;@1gE2X00P1gEBP00`1fE2H0MUL[07IG:`0607IG:`<0MU4W0P1gDRP307QC:@08
07=C:P1bDRT0LE4X075A:01bDRT0Le<Z07EE;01gEbh2075A:004079B:@1cDbX0Le<Z07AD:`80MED/
201bCbL8075A:PP0Ke8Z00`0M5@]07=C;01bDR/0LE4Z071@:@1_CbP0KThW06e=9P1eF300LeH^075D
;01_DRX206e@:080KU4Y0P1_DRX0101^DBT0KE0X06]>9P1ZCBD206U<900806e@:01^DBT0Ke8Z06iA
:@1]D2P0JdhV06U<901WBR8406M;9P80ITXU0`1UBB@0201TC2H0Hd/U06188P1OAb40GTHP05m78@1P
B280HTXT1@1QBBD3061890P0HTXV101QBBD2069:9P80Hd/W0`1TC2P306E=:@80IThZ0P1_CR/406i=
:P80KD`Y00H0JE@U06YE9P1[EBH0K5@V06mD9`1`DbL207=D:0<0Le</0P1dE2d307EE;P0;07AD;P1f
E2l0MeD_07UF;P1mF2h0OeP]089H;P23FRh0O5da07YK;`1iFRh00P1hFBd02@1iFRh0Ne``07eN<P21
ICD0Pf@e08AU=P25ICH0QfDg08YU>00208aV>@@0QF0c1026HC@208eW>080SVPi0`2?JCX02@2@JS/0
TVhd099]=P2CKST0Tfdl09A^@@2DKD80U6e609E^A`0209E`?00309Ia?@2GLSh0V7<o0080VGA000T0
VWE109Qd>P2IMC/0VWDn09]f@@2MN4<0WgY60:1jB@2QNdX00`2RODP40:5lA`040:1kAP2SOTT0Y7m:
0:J1C080Yh9=00<0YX5<0:AoBP2SOTT0102YQ4l20:Z5D0<0ZhIA0P2[QEP01P2/QUT0[HMJ0:j8F`2_
RE`0/8YM0;6;GP80/8]D00<0/8]F0;2;E`2`RUT00P2`RU/00`2`RUd0/8]D0;2;E0020;6<E@80/XeF
0P2cSUL20;:=F@040;>>FP2dSe/0]8mK0;F@G080]Y5M202cSUX80;:=F@P0/XaO1@2cSUX30;:=F@P0
]H]I202_RUH01`2]R5@0[XUE0:n:EP2aS5P0/XeI0;B?F`2eT5`00P2fTEd01`2eT5`0]8mK0;:=F@2a
S5P0[hYF0:j9E@2]R5@00P2aS5L0102`ReH0[hYE0:n:E@2^RE@20:f8D`<0/HaH0`2`ReL20:n:EP80
/XeI0P2aS5P0102`ReL0[hYF0:n:EP2^RED30:f8E0D0[XUE202]R5<30:f8E0D0[XUE102]R5@30:j9
E@80[hYF0`2`ReL20:n:EPH0[XUE00<0[HQD0:b7D`2[QU800P2[QU880:f8E0P0/HQD00H0[HMJ0:f7
F02]QeP0[HMF0:f8E02]R5<20:f8D@080:V3EP2ZQ5L0ZhEH0:b6F@2[QEP0ZXAG0:R2E@2VP5<80:f4
D0040:V4D02ZQE40ZXEA0:^6DP80[8MC0P2]R5@80:b2D0P0[XAB00<0ZHA@0:Z5D@2/Qe<00P2]R5@0
1P2/Qe<0ZXEA0:V4D02[PE40[89B0:j4DP80[hIB00<0[XE?0:b3B`2[PTX0202^QE420:f3D@<0[89@
0`2[PDl50:j6B@<0[hM:00P0[h5@0:j0C`2ZOTd0ZGm=0:V1CP2YQ500[8MC0:b8E0D0ZHA?0`2XPdh4
0:Z5D@@0ZhIB2@2[QU480:f4D0050:j5D@2]Q500[8=?0:^2CP2ZPDd00P2[PTh00`2/Pdl0[HA@0:f4
D0060:f4D0P0/89@0`2aPe420;22D0<0[h5?202_PDd01P2UP5@0Yh5D0:N1E02ZPE<0[89B0:f1D080
/89@0`2aR5@00`2`Qe<0[hIB0:j5D@020:j5D@030:Z1C@2[PTh0[HA@0080[hIB00<0[XEA0:f4D02/
Pdl00`2^QE420:f4D0<0[8=?0`2_QU830:j5D@80[HA@00<0/8MC0:n6DP2]Q5000P2/Pdl00`2]Q500
[hIB0;27D`080:f4D0030:j9E@2/Qe<0ZXEA0080ZHA@00<0ZXEA0:b7D`2^RED0202^QDl20:j5D@@0
[HA@0P2/Pdl20:V0C0060:Z1C@2[PTh0[8=?0:f4D02^QE40[hIB202^QE420;68D0050;68DP2`Qe<0
[hIB0:n6DP2^Q5800P2^Q5@0102^QE40[HA@0:f4D02]Q5020:b3C`80Zh9>0`2^QE430:n6DP80/8MC
0P2/Pdd20:^2C0<0ZX5;00@0ZH1:0:V0C02ZPDd0Zh9>0P2/Pdl00`2[PTh0ZX5=0:V0C0020:Z5D@<0
ZHA@0`2XPdl20:Z1C@80Zh9>00<0[8=?0:f4D02]Q500102^QE420:f4D0<0[8=?0`2^P4`30:n1C@80
/89>0`2/Pd/20:f4C0<0[XE=1@2/PU030:^1C`0:0:^2CP2ZPDd0ZH1<0:QoB`2YP4`0ZX5=0:b3C`2^
QE40ZXAC0:^5E0@0[8IE00@0ZhED0:Z4D`2]Q500[HA@0`2^QE430:n6DP80[X1>00<0[85>0:b3C`2[
Pdl00P2YQ4l00`2XQDl0[8=?0:b3C`040:f4D080[XEA00T0Z8=>0:V4C`2[QU40[HQC0:j9E02]R5<0
ZhIA0:Z5D02XOd/00P2YP4`03@2ZPDd0Zh9>0:b3C`2/Pdl0[HA@0:V4D02WPTh0YX5=0:F0C02VPDd0
Yh9>0:V4D02[QU800`2YQ4l00`2XPdh0Yh9=0:J1C0030:J1C080Z8=>00@0ZHA?0:Z5D02ZQE00ZhIA
0P2/Qe880:V0C080Yh9>0P2XPdl01`2YQ500ZXEA0:Z5D@2[QU80YX5<0:R3CP2YQ4l00P2ZQE003`2X
Pdh0YX5<0:AoBP2YP4`0ZX5=0:b3C`2]Q500[XEA0:f4D02/Pdl0Zh9>0:UoC@2[PDl0[H=A0:j4DP02
0:n5D`040:j4DP2]Pe40ZX5=0:Z1C@<0ZH1<0`2XOd/0202/Qe<0ZXEA0:R3C`2VPDd0YH1<0:J1C@2W
PTh0Z8=?202XOT`00`2/Pdl0ZX5=0:QoB`020:MnBP0;0:QoB`2ZPDd0[8=?0:^6DP2YQ500Yh9>0:J1
C@2UP4`0YX5=0:N2CP2XPdl00P2SOTL00`2SOTT0Y7m;0:EoCP020:J0D@070:J0D`2SODh0Y7i?0:Eo
D02VP540Yh5B0:R2D`020:V3E0030:F0B`2TOdX0XWe80080XWe800/0Y7m:0:F0B`2WPTd0X7m90:60
BP2UPT`0Yh9=0:V1C@2YP4`0Ygi:0:MlB@030:MnBP030:ImB@2UO4P0Y7]700X0Y7]700<0XWQ60:Aj
B02VO4X00P2XOT`00`2WOD/0YG]90:AjB0020:AjB0030:=iA`2RN4H0XGM500<0X7I400L0WgE309mi
C02ONDX0WgU:09miB02ONTH0WWU40080WWU200P0W7M309ehA02PNdL0XWe90:=nBP2RODT0XGa80:1k
A`@0X7M30P2OMT8209ie@@<0W7M200<0WGQ309iiA02ONTD00P2ONTD01@2SNDL0XWQ60:9hAP2QMdD0
X7I40080WgE300T0WWA209AeAP2HN4L0WG];0:9nC02UODX0YGY70:Af@P2SM400202ONTD0102SOTL0
XGa509ii@P2LMd0209]f?`0309ag@02MN440WGM80080WGM800<0W7I709]eAP2JM4D00P2JM4D309]f
@R_ooooo000Zooooo`<0SfHj0P2>ICT308eT>0P0SF4d0P2@I3L3095U>0<0TVHi00P0TF@k099U?02D
Ich0UFPo09IY@02EJ3l0U6Ln09=V?@@0TVDk0P2CIS`209AW?@<0UFTl0`2FJSd209M[?PP0UVXm1P2E
JSd209I[?P<0UFTh00<0UVXi09M[>P2GJcX00P2HK3/209M[>PL0UVXi402IKC`309Q/?`<0VFe00P2J
KT4809U]?00309Q]@02IKT40VFi10080VVm20P2KL4<00`2LLD@0VVhm09Y^?@0209Y^?@80Vfln0P2L
L3l209md@@<0WW=00`2MLSl809ad@00609ic@02OM440X7E20:5f@`2RMd@0XgQ50P2TNDH0102UO4P0
Y7]70:9iA@2PMd<209mf@P80X7M3202QN4@20:=gAP80XWI50P2QMD@20:1d@`80XWI500L0XWM40:=h
@`2SN440XgTo0:Aj@02TNSh0X7E20080XGI30P2RMd@20:=hA@030:AiAP2UMdD0YGM50080Y7I4102S
MD<30:9iA@80XgY60`2TNdL20:=jAP<0Y7]70`2UO4P20:EjA`040:AiAP2SN4D0XWM40:5f@`80X7E2
2@2LMd8209me@`0:09ec@@2LLT00VW0n09U_?@2HKS`0Ufdk09ab@02JL3h0V6hl09E[>@<0TfTg00<0
U6Xh099W>P2BIcX00P2AIST01P2@ICP0Sf@g08iS=P2>HcH0SFLj08aV>@80RfDh00L0RV@g08US=P28
HSD0R68e08EP=P23GS@0PUdc0080P5/a00<0PE`b089M<`23GS@00P21GBd03020Fbh0P5/_07mJ<01o
FC80OeTd07iH<`1lFC40NeP`07UF;P1hEBd0Me@/07IC:`80Me@/0P1dDc003P1cDRl0LU4^075@;@1`
Cb`0Kdh[06i=:P1eCRd0Ldl]079>;01`CR/0KTdZ06]=:@1ZCRT0JDdX0`1ZC2X206U;:@<0J4XX0P1[
B2X206Y7:@80JDHX0P1XABL0201TC2P0I4XW06989@1RAB<0HT@R06E48`1WA2@0J4DU0`1UAbD306I8
9P80IdTW0`1UB2P206I9:@<0IdXZ01@0L4PT07599@1`BRD0Kd`V06m=9`1^CRL0KdlX06e@:01dDBT0
Le0X079?9`1aCRH0LTlW07=@:01eDRX0MU<[07A?9@1eD2H0Me8X07UD:P80NUD[00<0NE@Z07QC:@1l
FR`01`1lFR`2081K;P<0PE`_1022GC001020FR/0PU`]08AN;`26H34208MQ<P0308IP<@25Gc00QV8`
0080QF4_0P24H2h208=O;@04089N;028HS<0R68c08QR<`<0Qf4b0P26H3400`28Hbl0Qf8^08IQ;@02
08EP;00308IQ;@28Hbl0RF@`00<0R68c0P27HC8308IP<@P0Qf4d2028HS<208IP;`0308IP<@27HC@0
Qf0e0080R64h00@0R64j08IP<`28HSD0RF<f0P2:I3L00`29HcH0R68e08IP<`0308QR<`80Qf4b0`26
H3401020Fbh0PE`_089M<023GS4208AO<P80Peha1024GS4408EO<PP0QV0_3`22GC000`23GS40PE`b
081K<@0307mJ<003085L<P23GS@0QF0f0080P5/^0`21G2l00`20Fbh0OUT/07iI;008085L;`80P5`/
0P1oFb/207iJ:P<0OETY0P1kF2h0101lFBl0OEX`07iK<@1oG382081M<`<0O5T_0`1kF2h:07YG;@<0
MEX_0P1dFBh307=H;@80N5D[1P1iER`207QE:`80Me@Z00@0MU<Y07EB:01dDBL0M54W0`1fDb/307MD
;080N5D]0P1gDbl00`1gE2h0Me@/07QE:`0207QF:@0307QF:01fEb/0MUL[00H0MUL[201eDRP0201c
DbX0LU8Y075A:01aDBP0LU8Y07=C:P1eEB`0MUH]0`1bDRT207=C:P<0M5@[201cD2P8075A:PP0Ke8Z
0P1cDb`0101bDR/0LE4Z071@:@1_CbP206i>9`0407AG;`1cERh0L5<[06iA:@80KE0X0P1^DBT206mB
:P0706iA:@1]D2P0K4lW06]>9P1ZCBD0JD`T06e@:00306iA:@0406e@:01[CRH0JD`T06M:8P@0Id/V
0`1VBRD206E9900306A<9P1SBbD0HDTS00<0GdLQ00<0HDTS069:901RBRH00P1RBRH206599@80H4PT
00<0GdLS06599@1QBBD01P1QBBD0101PB2@0HDTU06599@1QBBD2069:9P80Hd/W00@0HTXV06=;9`1S
BbL0Hd/W0P1TC2P206E=:@@0KTdZ101]C2T206UD9@0406YD9@1/E2H0KU<V071C9`80LU<W0`1cDb`2
07AD;@<0MED^0P1dE2h02@1fE2h0NEH^07aG;@1oF2d0P5T^089I;@1lGC40Ne``07YK;`0207UJ;P0;
07YK;`1lGC40OEhb07mS<`21HS<0PV<d08AT=@26I3H0RF@g08YT=`2;ICP01@26HC@308MR=@80SFLh
0P2>J3T408mY>P80TVdf00H0TVdi09=]?02CKD00U6e209A]A02DKDH209E`?00409Ia?@2GLSh0V7<o
09Qc?`80VGA00P2HM3X01P2JMCh0VgI109eh@`2NNDD0WgU80:1jB@H0XGa70P2PNdH00`2SOTT0Y7m:
0:F0B`020:J1C0040:F0B`2TOdX0Xgi90:R3CP@0ZHA?0P2ZQE020:^6D@060:Z4E@2[QEH0[8IG0:f7
F02^R5T0[hUJ0P2`RU/20:n:D`030:n:E@2`ReL0/8YI0080/H]L00<0/XaO0;2;E02`Re@00P2aS5D2
0;:=EP80/hiG0P2bSET20;>>FP040;B?F`2eT5`0]I1L0;F@G0P0/hiJ202bSET80;:<G@H0/hiJ0P2b
SET80;F;F@P0[hYF00P0[HQD0:j9E@2_RUH0/HaH0;:=F@2dSe/0]I1L0;JAG@80]I1L00H0]8mK0;:=
F@2`ReL0[hYF0:j9E@2]R5@30;2;E`<0[hYF0P2^RED30;6<F0<0/8]G0P2_RUH00`2bSET0/HaH0;6<
F0020;2;E`80[hYF00<0[XUE0:f8E02]R5@01P2^RED80:f8D`80[HQD1P2^RED40:f8E0<0[XUE0P2_
RUH30;2;E`80[hYF1@2^RED20:f8E080[8MC0P2[QU880:f8E0P0/HQD00H0[HMJ0:f7F02]QeP0[HMF
0:f8E02]R5<20:f8D@080:Z4E@2[QEH0[8IG0:f7F02/QUL0ZhEF0:V3E02WPE880:f4D0<0ZXEA00<0
ZhIB0:b7D`2/Qe<00P2]R5@80:b2D0P0[hEC00<0ZHA@0:Z5D@2/Qe<00P2]R5@01P2/Qe<0ZXEA0:V4
D02[PE40[89B0:j4DP80[hIB00<0[XE?0:b3B`2[PTX0202^QE430:f3D@80[89@0`2[PDl80:j6B`08
0:j0C`2]Odh0Zgm>0:UoC@2YPDh0ZHA@0:b7D`2/R5@80:V4C`<0ZHA@1@2ZQE490:^6D@P0[HA@00L0
/8MC0:j5D@2/Pdl0ZX5=0:V0C02ZPDd0[8=?00T0[HA@202`PU030;63D@<0/89@0P2_PDl80:n1C@06
0:N2E@2XPUD0Z89C0:^2E02]Pe<0[X9A0P2aPe420;68E080/8MC00L0[hIB0:j5D@2^QE40[XEA0:Z1
C@2[PTh0[HA@00<0[hIB00<0[XEA0:f4D02^QE400P2^QE420:f4D0<0[8=?0`2_QU830:j5D@80[HA@
00<0/8MC0:n6DP2]Q5000P2/Pdl00`2]Q500[hIB0;27D`080:f4D0030:f8E02/Qe<0ZhIB0080ZXEA
00<0ZhIB0:b7D`2]R5@0202^QDl20:j5D@H0[HA@0`2[PTh20:b3C`<0[HA@202^QE420;68D0050;27
D@2`Qe<0[hIB0:n6DP2^Q5800P2^Q5@20:n6DP80[XEA0P2]Q5030:b3C`<0[HA@0P2^QE420:n6DP80
[8==0P2[PT`40:Z1B`030:V0C02ZPDd0[8=?0080[HA@00<0[8=?0:Z1C@2YP4`0202YQ5000`2ZPDd0
Zh9>0:^2CP020:b3C`80[HA@102^QE420:f4D0<0[8=?0`2^P4`30:n1C@80/89>0P2/Pd/30:f4C0<0
[XE=0P2]Pe440:b2D080Zh5?00<0Zh9>0:Z1C@2YP4`00P2YP4`0102[PTh0[8=?0:j5D@2/QUD60:^5
E0030:b6E@2]Q500[HA@00<0[XEA0`2_QU820:n1C`030:f2C`2/Pdl0Zh=?0080ZHA?00<0Z8E?0:f4
D02]Q5001P2]Q5000`2XPdh0ZHA?0:^6D@030:f8D`030:^6D@2ZQE00ZX5=0080ZX5=0`2[PTh20:b3
C`030:R3C`2WPTh0YX5=0080YX5=00<0Z8=?0:Z5D@2[QU800`2YQ4l0102XPdh0Yh9=0:N2C@2WPTd2
0:J1C0030:R3CP2YQ4l0ZHA?0080ZXE@0P2[QU400`2/Qe80ZX5=0:Z1C@060:Z1C@80Yh9>0P2XPdl0
602YQ500ZXEA0:Z5D@2ZQE40Yh9=0:R3CP2YQ4l0ZXE@0:V4C`2XPdh0YX5<0:AoBP2YP4`0ZX5=0:b3
C`2]Q500[XEA0:f4D02/Pdl0Zh9>0:Z0CP2[PDl0[H=A0:j4DP80[hEC00<0[XAB0:f3D@2[PTh00P2[
PTh20:Z1C@<0ZH1<00P0ZhIB0:Z5D@2XPdl0YX5=0:F0C02VPDd0Yh9>0:R3C`P0Z7i<00<0Zh9>0:Z1
C@2YP4`00P2XOd/02`2YP4`0ZX5=0:^2CP2[QU80ZHA@0:N2CP2VPDd0YH1<0:J1C@2WPTh0Z8=?0080
Y7m800H0YH1;0:F0C02VP4l0YX1A0:N1DP2WPE@20:AnC`040:EoD02VP540Yh5B0:R2D`80ZH=D00<0
YX5<0:F0B`2SOTT00P2RODP02`2SOTT0Y7m:0:J1C02POdT0XH1:0:F2C02WPTd0ZH5=0:V0C02WOTX0
Yga90080Ygi:0P2VODT20:ElB0X0Y7]700<0Y7Y80:EkB@2VO4X00P2WOD/00`2VO4X0Y7Y80:=iA`02
0:AjB0040:=iA`2RN4H0XGM50:5gA@<0X7I400H0WgU<09miBP2ONDX0WgU809mjAP2ONTD209ii@P03
09ag@`2NNDD0X7]700<0XWe900<0XGa80:1kA`2QN4@00`2PMd<209mf@P80WWE10P2LMd8209eh@`80
WWU40P2ONTD20:9hAP<0XGM50`2PMT@0202FMTL0V7Q709ajBP2RO4/0Y7a90:EjA`2TMT80XWA0202O
NTD0102RODH0XGa509ii@P2LMd0209]f?`80W7M00P2LMTL209]eAP80VWA50P2ILd@309]f@R_ooooo
000Zooooo`<0T6Dj0P2?I3T308iS>0P0Sf<f0P2@I3L3095U>0<0TVHi00P0TF@j099U>`2DIcd0UFPn
09IY?`2EJ3h0U6Lm09=V?0<0TVDk0P2CIS`309AW?@80TfLj0`2DJ3/309EY?0P0UVXm202EJSd209EY
>0<0UVXi0`2GJcX909IZ>@P0V6`k202IKC`309Q/?`<0VFe00P2JKT4809U]?0<0V6e00`2IKT4209Y_
@P0409]_?P2LL3l0W70o09a`?`80WG500P2NLT4209md@@<0WW=00`2MLSl809ed@080WgA10P2PMD80
1`2QMT<0XWM40:=hA@2SN4D0XGQ40:1g@`2OMT800P2MM4000`2NMD40X7M30:5hA0080:1g@`80XgM6
0P2RMTD20:5eA080X7A30P2RMTD01`2RMd@0XgQ30:=h@@2SNCl0Y7Y00:Aj?P2RMd@00`2SN4D30:Ai
AP040:EjA`2SN4D0XgQ50:=hA@80XWM40`2QMT<30:9iA@80XgY60`2TNdL20:=jAP<0Y7]70`2UO4P0
1P2UNTL0Y7U60:AiAP2SN4D0XWM40:5f@`80X7E22@2LMd801P2NM480WG=109ab@02KLCl0VW0n09Q^
?080Ufdk00@0VW0n09U_?@2GKC/0UF/i102CJCL2099W>P03095V>@2@ICP0Sf@g0080SV<f00<0SF8e
08]U>02;ICP00P2:I3L02029HcH0R68e08MQ=027HC@0Q5le08=N=022GC<0PE`b0P20Fc402021G380
PUdc081L;020G2`0P5/^07mJ;P1oFS00OUPa0P1nF3<207UF;P0607YG;`1iERh0N5D]07MD;01eDRX0
M54Y0P1cDRl00`1bDBh0LE0]071?;00206m>:`0706i=:P1eCRd0LTh/079>;01`CR/0KTdZ06]=:@02
06U=:00406Y<:P1YBbT0JD/Y06U;:@80J4XX0P1WBBL206U8:@<0J4LX0`1WARL0201SBbL0HdTV0698
9@1RAB<0HdDS06E48`1WA2@0J4DU0`1UAbD306I89P80IdTW00@0IDLU06I89P1VB2H0ITPV0P1WBBL2
06Q::080L4PT0140L4XU06m<9P1`CRP0L50Y075A:P1_DRX0ME8Z07AA:@1cD2P0LTlW07=@:01dDBT0
MU<[07MD;01hDbT0NE@Z07]F;00207aG;@0307]F;01jEB/0NE@Z0080O5X/101mFbd207aJ;004081K
;P21G2l0PE`_085L;`80PUd`0`23GS401021Fb`0PU`]08AN;`26H34208MQ<P80QV0a00@0Qf<c08IR
<P26HS80QV8b0`25HC400`24H300Qf4b08MQ<P0208MQ<P<0R68c00@0RF<d08UT<028Hbl0Qf8^0`26
HBd208MR;P<0QV0a0P27HC8308QR<`P0Qf4d2028HS<208IP;`0308IP<@27HC@0Qf0e0080R64h00@0
R64j08IP<`28HSD0RF<f0P2:I3L00`29HcH0R68e08IP<`0308QR<`80Qf4b0`26H3402023GS40PUd`
089M<021G2l0PUd`08=N<@24Gc80QF0c1025Gc8408AN<@P0QEl`2022GC02081K;P04085L;`22GC00
Peha08=N<@80Q5lb0P21G383081K<@06085L<P22GC<0Pehd08=N<@22GC00P5/^0`1oFRd2081K;P05
08=N<@22GC00PUd`085L;`20Fbh00P1oFRd00`1nFB`0P5/^081K;P0207mJ;@80OUT/0`1mF2/207]H
;P0407aI;`1mFS00OU/a07iK<@80Oe`b0`1lFBl307]H;PX0NUL]00@0MeX`07II;`1fFBl0MUT_0P1e
F2h207AG;@P0NEH/00<0Me@Z07IC:@1fDbT01@1fDbT207MD;0<0N5D]0`1iERh01@1eDBd0MU8^07IC
;@1gE2`0N5D[0080NELZ00<0NUPZ07IG:`1fEb/01P1fEb/207MD:P0407IC:@1eDRP0ME8X07AA9`80
Le0V00<0M5@[07=C:P1bDRT00P1aDBP00`1cDbX0MED/07IF;@0307AD:`80Le<Z0`1bDRT807EB:PP0
LE4Z201_DRX01@1cDb`0LU8[079B:`1aDBX0L50Y0080KdlX00D0KThW07=F;P1bEBd0L5<[06iA:@02
06e@:00706iA:@1_DRX0Ke8Z06mB:P1^DBT0KE0X06a?9`0206]>9P0306Y=9@1]D2P0KE0X0080KU4Y
00@0KE0X06]>9P1YC2@0J4/S0`1XC2L206M;9P<0ITXU00D0IDTT06A<9P1SBbD0HTXT06598`020618
8P0306598`1RBR@0IDdY0080I4`X00D0HTXV06599@1PB2@0GdLS05i68P0;06189080HDTU0`1RBRH0
101PB2@0HDTU06599@1QBBD2069:9P80Hd/W201[CBT206QC9P0406UB9P1[DbL0KE8W06mB:080LE4X
0`1bDR/207=C;0<0M5@]00T0LE<]07AD;P1eEBh0MeH]07YG;@1mF2`0OeP]081J;@1lGC400P1kG300
1P1jFbl0Ne``07aM<@1nGc<0Of0d07aP<080Of0a00<0PF4b08=Q<`26HC@00P28HSD208IQ=080Qf8e
0P28HcH208UT=`<0SFLh0P2>J3T308mY>P09095/=`2AK3P0TVdi099/>`2CKCh0Tfe009=/@@2DKD80
U6lk0080UG0l00<0UW4m09Mb?P2HLcl00P2IM40209Qd>P0609Ud?@2JMD00W7M209ehA02NN4L0WgU8
202PNdH00`2RODP0Xgi90:F0B`020:J1C0030:F0B`2SOTT0XWe800@0Z8=>0P2YQ4l30:Z5D0060:Z4
E@2[QEH0ZhEF0:b6E`2]QeP0[XQI0P2_REX0202/Qe00[HQA0:j9E02_RUH0/8YI0;:<G@2cSEh0/heP
0P2`ReH20;6<E`80/XeH0P2cSUT0102bSET0/hiJ0;>>FP2cSUX30;B?F`030;F@G02cSUX0/hiJ00H0
/hiJ202bSET80;:<G@P0/hiJ202eReT80;2;E`080:j9E@2_RUH0/8]G0;6<F02bSET0/hiJ0;B?F`2e
T5`20;B?F`060;>>FP2bSET0/8]G0:n:EP2^RED0[HQD102_RUH30;2;E`@0/HaH0`2`ReL20:n:EP80
/HaH0P2`ReL40:n:EPP0[XUE202]R5<80:j9E@@0[HQD0`2^RED20:n:EP<0/8]G0P2_RUH40:j9E@<0
[HQD0`2/Qe<00`2[QU80[HQD0:f8E0060:f8E0P0/8MC00H0[HMJ0:f7F02]QeP0[HMF0:f8E02]R5<2
0:f8D@030:^5EP2/QUL0[HMH0080[XQI00<0[8IG0:Z4E@2YPe@0202]Q5020:Z5D@<0ZhIB0`2/Qe<8
0:b2D0P0/8ID00<0ZXEA0:^6DP2/Qe<00P2]R5@00`2/Qe<0ZhIB0:Z5D@020:b2DP040:j4DP2^QE40
[XEA0:j5C`80[8=;202^QE40102^Q580[H=A0:f3D@2]Pe420:b2D080Zh5?202^QT/0202^P4l0[Gm>
0:]oCP2ZP4h0ZX9?0:Z5D@2[QU80ZhMC202YQ4l50:V4D0<0Z8=?2@2[QU480:b3C`030;:9E@2_QU80
Zh9>0080Z7m;00<0ZX5=0:f4D02_QU80202^QE480:j3D080/8EB0P2_Q5430:j3D0T0[H9?00H0ZHAG
0:Z4E@2ZQ5D0[HED0:j4DP2_Q5420;:4D0<0/8MC0P2_QU830:j5D@080:^2CP2/Pdl0[XEA0:n6DP2`
Qe<0[hIB0:j5D@2]Q5030:j5D@80[HA@0`2/Pdl30:n6DP<0[XEA0P2]Q5000`2_QU80[XEA0:f4D002
0:b3C`030:f4D02^QE40[hIB00P0[HA@00<0[HQD0:b7D`2[QU800`2[QU800`2/Qe<0[HQD0:j5C`07
0:j5C`<0[HA@1@2^QE440:f4D080[8=?0P2[PTh80:j5D@80/8M?00D0/8MA0:n6DP2_QU80[hIB0:j4
DP020:j4E0<0/8MC0P2_QU830:j5D@040:Z1C@2[PTh0Zh9>0:^2CP80[8=?0P2]Q5030:b3C`80Zh9>
102ZPDd01`2[PTh0[8=?0:f4D02]Q500[8=?0:^2CP2ZPDd00P2WPTh00`2XPdl0ZHA@0:Z5D@030:^6
DP80Zh9>0P2/Pdl40:f4D0<0[XEA0P2]Q5030:b3C`<0[85>0`2]PTl20:j3D0040:b3C@2]Q4h0[HA>
0:f4CP80[XE?0P2_QU00102^Q580[H=A0:f3D@2]Pe420:b2D080Zh5?00/0[8=?0:^2CP2ZPDd0ZH1<
0:Z1C@2[PTh0[HA@0:j5D@2^RED0[HQD0:Z5D@020:R3C`030:Z5D@2]R5@0[XUE0080[HA@0`2^QE43
0:n6DP80[h5?00<0[H9?0:b3C`2[Pdl00P2YQ4l00`2XQDl0[HA@0:f4D0060:f4D0030:R3CP2YQ4l0
ZhIA00<0[8MB0P2[QU430:b3C`<0Zh9>0P2ZPDd20:R3C`<0Yh9>00<0Z8=?0:Z5D@2[QU800`2YQ4l2
0:R3CP@0Yh9=0`2YQ4l20:Z5D0<0ZhIA202/Pdl30:R3C`<0ZHA@0P2ZQE400`2WPTd0Z8=>0:V4C`02
0:V4C`0>0:N2C@2VPD`0YH1;0:V0C02ZPDd0[8=?0:f4D02^QE40[HA@0:b3C`2[PTh0ZX1>0:^1C`2]
Pe420:n5D`030:j4DP2]Pe40[89@00<0[HA@0P2/Pdl30:^2CP80ZXEA00@0Z8=?0:N2CP2WPTh0Yh9>
0P2XPdl80:UoC@030:^2CP2ZPDd0ZH1<00<0ZH1<00X0ZX5=0:^2CP2[QU80ZHA@0:N2CP2VPDd0YH1<
0:J1C@2WPTh0Z8=?0P2VPDX00`2VPD`0Yh9>0:N1D0020:R2D`030:R2E@2UOe00YGm@0080YX1A00P0
Yh5B0:R2D`2YPe@0ZH=D0:R3CP2WPTd0YH1;0:=nB@80XWe800/0Xgi90:AoBP2POdT0XH1:0:F2C02W
PTd0ZH5=0:V0C02WOTX0Yga90:MnBP030:ImB@<0YGa800<0Y7]70:ElB02UO4P01P2UO4P02@2VO4X0
Yge;0:MmB`2WOD/0YWa:0:EkB@2SNDL0XWQ60:EkB@020:AjB0030:=iA`2RN4H0XGM500<0X7I400H0
WgU<09miBP2ONDX0WgU809mjAP2ONTD209mj@`0309iiA@2ONTH0X7]700<0XGa80P2PNdL30:5hA080
X7M30`2OMT80102LMd80WGQ309eh@`2MN4<309iiA00309mjA@2PMT@0X7I400<0XGM50`2RN4H0202G
MDL0VGM709ijBP2QNdX0Xg]80:=jAP2RMd80X7E0202NND@0102QO4L0WgY509iiA02LMd8209]f@@80
W7M20`2JM4D209UcA0<0V7930`2JMD4[ooooo`00:_ooool3095T>P80T6<i0`2?HSP8095U>080T6@g
0`2AICP3099V>@08095U>02BIST0U6Pk09EY?02FJSd0UFTl09AX>`2CIcX2099U>`80TfHl0P2DIcd2
09EX?P80TVHi0`2CIcX309AX>`P0UVXm0`2FJch409EZ?@0309AY?02FJST0UVXi00@0UVXi0P2GJcX0
0`2EJCP0UVXi09IZ>@0309IZ>@<0Uf/j202HK3/809U]?0<0V6`o0`2IKD0209Y^@@<0VFdl102JKSd0
0`2KKch0V6e009Q]@00409Q]@080VFi10`2MLD0209ib@@<0Wg=20P2OM44309ic@0<0WG8o2P2OM442
0:1e@P80XGI30P2RMd@00`2NMD40WGA009ac?`0209ac?`0309ie@@2PMd<0XGQ400P0WgI20P2SMdH2
0:9fA@80XGE40P2PM4<20:9fA@060:9gA02SN4<0XgQ10:=i?`2TNT00Y7Xn102TNDH40:EjA`80XgY6
0P2RNDD20:5hA080X7M30`2RNDD20:=jAP<0Y7]70P2SNTH30:AkA`<0YGa80P2TNDH00`2SN4D0XWM4
0:5f@`020:1e@P0409md@@2LMd80W7M209ag@PD0VgI100L0VWE009ab@02LLT00Vg4o09Y`?P2IKcd0
V6hl0080Ufdk00@0V6hl09M]>`2FK3X0UF/i0P2CJCL2099X=P06099W>P2AIST0TFHi091U>02?I3L0
SV<f0P2=HSD208YT=`0308US=P28HSD0Qf4d0080QV0c00D0QElb08AO=@23GS@0PUdc085L<P04081K
<@80P5`/00@0OeX]07mJ;P1oFS00OUPa0P1nF3<0201fDb/0N5D]07UF;P1jEbl0NEH^07MD;01cD2P0
LDhV0`1aD2d00`1`Cb`0Kdh[06m>:`0206i=:P0607A=;01aCB/0LDd[06m=:P1]C2T0JT`X0P1XC2L0
101YBbT0J4XX06Q::01XBRP206M99`80ITPV201UARL0201QBBD0HTPU06989@1SAR@0I4HT06I5901W
A2@0J4DU0`1UAbD306I89P80IdTW0`1XAb@206U89@<0JTTV01<0L4PT07599@1aBbH0L4dW075?:@1a
DBX0LU8[075D;01fDb/0ME8Z07AA:@1cD2P0M54Y07EB:P1gE2`0NEH^07]F;01lEbd0OEP^0080OUT_
00H0O5L]07YE:`1iE2X0O5X/07eK;@1nG2h207mM;`0307iL;P1mFbd0O5X/00<0PE`_0P22GC0408=N
<@04085K;023GBh0QEl`08MQ<P80R68c00<0Qf4b08IP<@27HSD00`27HSD408IQ=080QV0a00@0Qf4b
08QR<`28HS<0RF<d0P2:I3D01029Hc80R68a08QR<@27HC0408IP;`80QEl`00@0QV0a08MQ<P27HC80
R68c0P29Hc@808MQ=0P0R68c0P26H2l00`26H340Qf4d08MP=@0208QQ>00408QQ>P26H3<0R68e08US
=P80RV@g00<0RF<f08QR=@26H3<00`28HS<208MQ<P<0QV0a00<0QV4d08AO<P22GC000P20Fbh00`22
GC00QF0c08MR=@0408EO<P@0Q5ha2025Gc88089M<080OeX]00H0P5/^089M<023GS40Q5lb08EP<`26
HC@3085L<003081K;`21G300PE``0080PUda00<0QF0c08=N<@20Fbh00P1nFB`00`1oFRd0PE`_08=N
<@0208=N<@04089M<021G2l0OeX]07iI;080OEP[0P20Fbl207mJ;P80OUT]0`1mF2`207]H;P80O5T_
00@0OEX`07iK<@1nFc40OU/a0`1lFBl307]H;PX0NUL]0P1iFC0307QH;`<0MeL^00<0NUL]07UF;01i
ER`00P1iER`307QE:`80ME8X0`1fDbT307MD:P80N5D]0P1iERh407YG;`0807A@;01eDBd0MU<]07MD
;01hEB/0NELZ07YH:`1kFB/807IG:`80MeH[00@0MUDZ07ED:@1cDRL0LU4V0P1aD2D00`1dE2/0Le<Z
079B:@02075A:003079B:@1dE2/0MED/0080MED/00@0M5@[07=C:P1cDbX0LU8Y0P1aDBP807IC:`P0
LE4Z201_DRX2079B:`80LE4Z0P1`D2T206m?:003079E;@1aE2`0Ke8Z00<0KE0X00<0KU4Y06mB:P1_
DRX00P1^DBT206e@:080K4lW00<0JdhV06a?9`1]D2P00P1^DBT0101]D2P0K4lW06Y=9@1YC2@406Q<
9`80Id/V0`1VBRD206A<9P0306=;9@1RBR@0HTXT00<0HTXT00P0Idl[06I>:P1UCBT0Hd/W069:9P1P
B2@0GdLS05i68PP0GdLS0`1PB2@306599@80HTXV0`1OAb<2061890<0HDTU0P1XC2L406U=:080JThY
0P1WDRL0101XDBL0JE0W06a@:01]D2P2071@:@80LE4Z0`1bDR/307=C;00806mC;01aDbd0LUD]07EE
;01hEb`0NUP[07eH;01nFB`307]L<080O5da00/0OEhb07iO<`1oH3@0NUh^07aM;P1mGRl0Oel`085O
<@24Gc80QElb08IP<`0208IQ=00408MR=@28HcH0R6<f08UT=`80RVDh0P2<ISL208eW>080SVPi0P2?
JCX2091Z>@06095[>P2AJc`0TV`m099/?@2BK3l0Tfe00P2DKc/00`2EL3`0UW4m09Mb?P0209Qc?`07
09Ud@02GLcT0V7@j09Ud?@2JMD00VgI109ag@`0209egAP0309iiA02ONTD0WgY50080WgY50`2PNdH0
0`2QO4L0XWe80:AoBP020:F0B`030:AoBP2RODP0XGa700@0Yh9=0P2XPdh30:V4C`80ZXAC0P2[QE@0
102/QUD0[HMF0:f7EP2]QeH20:^6C`060:f8D`2^RED0/8YI0;:<G@2cSEh0]8iQ0P2`ReL20;6<F080
/XeI4P2cSUX80;:=F@P0/XaK0`2bSET40;>>FP030;B?F`2eReT0]H]I00H0]H]I202`ReL20:n:EP04
0;2;E`2aS5P0/XeI0;>>FP80]8mK0P2cSUX0102bSET0/HaH0;2;E`2_RUH20:j9E@80[XQG00@0[hUH
0;2:F@2`RUT0/H]J0P2bS5/30;6<F0<0/8]G0P2_RUH20;2;E`L0[hYF102^RED30:f8E0P0[HQC00<0
[hYF0:j9E@2^RED00P2^RED70:f8E0<0[XUE0P2_RUH30;2;E`80[hYF0`2^RED40:f8E0@0[8MC202]
R5@80;27D`060:f7FP2]QeP0[HMH0:f7EP2]R5@0[HQC0P2]R5400`2/QUD0[HMF0:j8E`020:n9F003
0:f7EP2[QE@0ZXAC00P0[HA@1P2[QU820:b7D`P0[89@202`QU@30:^6DP80[8MC0`2[QU820:f3D`04
0:f3D@2]Q500[HA@0:f4CP80[HA<202^QE420:j4DP<0[H=A0`2/PU030:j5C@@0[HA<00T0[8=;0:eo
CP2]Odh0Zgm>0:^1C`2[Pe00ZXEA0:^6DP2[Qe<00`2YQ4l40:Z5D0030:^6D@2YQ500ZHA@00@0Z8=?
0P2WPTh90:^6D@P0[8=?00P0/hYF0;27D`2[PTh0Z7m;0:MnBP2ZPDd0[XEA0;68E0P0[XEA202]Q503
0:n6DP80[XEA0`2]Q5080:f3D@060:Z6EP2[QEH0[8IE0:j6D`2_QU80/8E@0P2bQDh40:n6DP@0[XEA
00<0Zh9>0:b3C`2^QE400P2`Qe<00`2_QU80[XEA0:f4D0030:j5D@80[HA@0`2/Pdl30:n6DP<0[XEA
0P2]Q5000`2_QU80[XEA0:f4D0020:^2CP030:f4D02^QE40[hIB00P0[HA@00<0[HQD0:b7D`2/Qe<0
102/Qe<00`2]R5@0[XE?0:j5C`060:j5C`80[HA@102^QE420:n6DP060;27D`2_QU80[XEA0:f4D02/
Pdl0Zh9>0P2ZPDd80:f4D080[hI>00D0[hI@0:n6DP2^QE40[XEA0:j4DP020:j4E0<0/HQD0P2`Qe<3
0:n6DP<0ZH1<0P2ZPDd30:^2CP80[H=A0P2/PU020:^1C`80ZX1>00<0Zh9>0:b3C`2]Q5000P2^QE40
2@2]Q500[8=?0:^2CP2VPDd0Yh9>0:R3C`2YQ500ZXEA0:b7D`020:f8E080[8=?1P2]Q5030:j5D@80
[HA@0`2/Pdl30:^1C`<0[89@0P2]Pe430:f4D080[XEA0`2_QU80102_QE<0[XAB0:j4DP2]Pe420:b2
D080Zh5?00/0[8=?0:^2CP2ZPDd0ZH1<0:Z1C@2[PTh0[HA@0:n6DP2`ReH0[HQC0:V4C`020:J1C003
0:V4C`2]R5<0/8]F0080[HA@0`2^QE430:n6DP050;63D@2`PU00[X=@0:f4D02/Q5000P2YQ4l00`2X
QDl0[XEA0:j5D@040:f4D080[8=?0P2YQ4l20:Z5D0@0ZhIA00D0[XEA0:f4D02]Q500[8=?0:^2CP02
0:Z1C@030:V0C02XPdl0Z8=?00<0Z8=?00<0ZHA@0:Z5D@2ZQE40102YQ4l50:R3CPP0ZXE@202]Q502
0:R3C`H0ZHA@1@2XPdh03P2WPTd0YX5<0:J1C02YP4`0ZX5=0:b3C`2]Q500[XEA0:f4D02/Pdl0Zh9>
0:^1C`2/PU00[XAB0P2_QE<0102^Q580[H=A0:b2D02_QU830:j5D@80[HA@0P2/Pdl30:V4D0@0Z8=?
00<0ZHA@0:Z0CP2ZP4h01P2ZP4h00`2[PTh0ZX5=0:Z1C@040:Z1C@090:^2CP2[QU80ZHA@0:N2CP2V
PDd0YH1<0:J1C@2WPTh0Z8=?0080Z8=<00<0Z8=>0:R3C`2XPU400P2XPU<01@2XPUD0YX1A0:J0D@2V
P540Yh5B0080Z89C0P2YPe@0102ZQE00Z8=>0:J1C02TOdX20:9mB080Xgi900P0X7m90:60BP2UPT`0
Yh9=0:V1C@2YP4`0Ygi:0:MlB@@0YWe9302UO4P01P2YOdd0Z7i<0:QnC02WOD/0YG]90:AjB080XWQ6
0P2UNdT00`2TNTP0XgU70:9hAP030:5gA@090:1fA02NN4/0WWQ909ihB@2ONDP0WgY609mjA@2ONT<0
X7]40080WgY60P2PNdL0102QO4P0X7]70:1kA`2PNdL30:5hA0<0X7M30P2OMT8409eh@`@0WWU400D0
WgE30:1fA02PMT@0XGM50:9hAP020:=iA`090:AjB02IM4L0W7I709ihB@2PNTT0XWY70:5iA@2PND80
WgQ100P0WWU400<0WgY609iiA@2MN4@00P2LMd<309]f@PP0V7930`2JMD4[ooooo`00:_ooool309=T
>P80TV<i0`2AHSP8099V>@80T6@g0`2AICP3099V>@08095U=P2BISL0U6Pi09EY>P2FJS/0UFTj09AX
>@2CIcP309=V?080U6Lm0`2EJ3h2099V>@<0TfLj0`2DJ3/809IZ?@80Uf`o0P2FJch0102EJSd0U6Tl
09AY?02DJC`209M[>PH0UVXi0`2EJCP0102FJST0Uf/j09M[>P2GJcX209Q/>`P0Uf/j202IKC`309Q/
?`<0VFe00P2JKT4309U]?00309Y^?@2KKch0Vfln0080W70o1@2IKT4309Q]@00409ea@02NLT40WW91
09ib@@80Wg=20P2PM4<209md@@<0WW=00`2MLSl80:5c@@80WgA1102PMD820:5f@`80W7<o0P2KLSh0
102LLcl0WWE10:1g@`2RNDD809mf@P80XgM60P2RMTD20:5eA080X7A30P2RMTD01P2RMd@0XgQ30:=h
@@2SNCl0Y7Y00:Aj?P@0YGY7102TNDH30:9jAP80XGU50`2PN4@30:9iA@80XgY60`2TNdL20:=jAP<0
Y7]70`2UO4P01P2TNDH0XgQ50:=hA@2RMd@0XGI30:1e@P80WgA10`2LMd80102KMT40VWE009Ye@02J
MD0209Ud?`0509]a?`2JL3h0VW0n09U_?@2HKS`00P2GKC/0102FK3X0UF/i09E[>@2EJcT209AZ>003
09=Y=`2BJ3H0TFLe0080TFHi00<0T6Dh08mT=`2>HcH00P2=HSD01`2<HC@0RF<f08QR=@28HSD0Qf4d
08IP<`25Gc800P24GS4308=N=005089M<`21G380OeX`07iI;`1mF2h00P1oFb/0101oFRd0OUT]07iI
;`1nF34207eG<P0907EB:P1gE2`0N5D]07UF;P1hEBd0MU<[079?9`1`CBD0L4l/00@0Kdh[0`1^CBX0
1P1cC2/0L4`Z071<:P1^C2T0K4/X06U;9`80Id/V0P1XBRP206M99`<0ITPV00<0IDLU06=69P1SARH0
1P1SARH0201PB2@0HDLT0657901TAbD0IDLU06M69@1XABD0Id@T0`1UAbD306I89P80IdTW0P1ZB2<2
06]990<0K4XU00`0KD/V079:9P1bBRH0LT`W075>:01aCbT0LE4Z079B:`1aE2`0N5D]07MD;01fDb/2
07EB:P0607MD;01iERh0NUL_07aG;@1mF2h0OUT_0P1oFS001P1mF2h0NeH/07YE:`1lFR`0OE/]07mM
;`80P5h`00<0Oed_07eK;@1lFR`00P21G2l2089M<080Peha0`24Gc801022G2d0Ped^08EO<027HC82
08QR<`80Qf4b1026HCD408MR=P0508IP<@27HC80Qf4b08QR<`29Hc@00P2:I3D00`2;ICH0Qf4b08MQ
<P0208QR<`80Qf4b0P26H34208EO<00408IP<@27HC80Qf4b08QR<`80RF<d2027HC@808QR<`80QV0_
00<0QV0a08MQ=027H3D00P28HCP01028HCX0QV0c08QR=@29HcH208YT=`0308US=P28HSD0QV0c00<0
R68c0P27HC8308IP<@0308MR=@25H3<0Peha0080PE`_00<0PUd`08EP<`26HC@00P26H3<208EO<P80
Q5ha0P23GC0808AM<PP0PUd`0P1oFRd01P20Fbh0PUd`08=N<@24Gc80QF0c08IQ=0<0PE`_00<0PUd`
085L;`21G2l00P20Fbh01`25H3<0Q5lb085L;`1oFRd0OUT/07mJ;@21G2l00P23GS401`22GC00PE`_
081K;P1oFRd0OUT/07eH:`1lEbX00P20Fc4207mJ<080OUT_0`1mF2h00`1kF2h0O5T_07aI;`0207aI
;`<0OEX`0`1lFBl307]H;PX0NUL]0`1jFC0307UH;`80N5L^0`1jEbd00`1iER`0N5D[07QE:`0207MD
:P80ME8X0`1fDbT307MD:P80N5D]0P1iERh407YG;`0807A@;01eDBd0MU<]07MD;01hEB/0NELZ07YH
:`1kFB/:07IG:`0407EF:P1dEBT0LU<W075B9P80L54U00<0MED/07AD:`1bDRT00P1aDBP00`1bDRT0
Le<Z07AD:`0207EE;00407AD:`1cDbX0Le<Z079B:@80LE4X201fDb/8075A:PP0Ke8Z101aDBX4071@
:@08075D;01`Db/0KU4Y06e@:01/CbL0KE0X06iA:@1_DRX406iA:@@0KE0X00<0JdhV06a?9`1]D2P0
0P1^DBT00`1/CbL0JdhV06U<900306U=:080J4`W0P1WBbH206I:9@D0I4`V00X0Hd/U069:901RBR@0
J50/06M?:`1VCRX0I4`X06=;9`1QBBD0H4PT2`1OAb<3061890<0HDTU101OAb<206189080HDTU00<0
I4XU06E;9P1UBbH00P1VC2L206M=:00706Q>:@1UCbH0IDlV06M@9`1XCbL0JdlX06a>:00206i>:080
L50Y0P1aDBX4079B:`0806aC:`1_Db`0L5@/079E:`1fEb/0N5LZ07YH:`1kFB/207UJ;P0307]L<01l
GC40OEhb00<0OUlc00H0NEd]07]L;@1lGBh0OEd^07mM;`22GC0208AN<@80QF0c00@0QV4d08MR=@28
HcH0RF@g0P2:ICP308aV=`80SFLh0`2>J3T01P2?JC`0T6Xm091Z>`2@JS/0TF/l095[>P80TV`k00H0
Tfhj09A_>`2DKc/0UG0l09Ia?@2GLSh209Qc?`0609Mc>@2HM3X0V7<l09Ud?`2JMD00VWE10P2KMD@3
09eh@`0309iiA02ONTD0WgY500<0X7]600L0XGa70:=nB@2TOdX0Y7m:0:=nB@2QO4L0X7]600@0YX5<
0P2WPTd30:R3CP<0ZXEA102[QU802@2/Qe<0ZXE>0:^6C`2/Qe80[XUE0;2:F@2aRe`0/heN0;>=H002
0;2:F@80/H]J0P2bS5/20;>=G0@0/hiJ102bSET80;>>FQ00/XeI0P2aS5P20;:=F@040;>>FP2dSe/0
]8mK0;B?F`P0]H]I202aS5P01@2_RUH0/8]G0;2;E`2aS5P0/XeI0080/hiJ00@0]8mK0;:=F@2bSET0
/HaH0P2`ReL0102_RUH0[XUE0:j9E@2^R5T20:n9FP050;2:F`2aRe`0/XaM0;:<G@2cSEh00`2aS5P3
0;2;E`80[hYF0P2^RED90:n:EP030:j9E@2]R5@0[HQD0080[8MC202]R5<30:n:EP030:j9E@2]R5@0
[HQD0080[8MC102]R5@30:j9E@80[hYF0`2`ReL20:n:EP<0[XUE102/Qe<<0:f8E0P0[hIB00H0[HMJ
0:f7F02]QeP0[HMF0:f8E02]R5<20:f8D@030:b7D`2]R5@0[XUE0080[hYF00<0[HQD0:^6DP2ZQE40
202]Q5020:b7D`H0ZhIB202/PU080;26E0030:b7D`2[QU80ZhIB00@0ZhIB00@0[8MC0:f3D`2]Pe<0
[H=A0P2]Q5000`2]Q4h0[HA<0:f4C0080:j5D@<0[XAB0`2]Pe420:b2D0<0[XE?00<0[HA>0:b3C@2/
Pdd00P2[PT`0202/OTd0[Gm>0:b0C`2/PU00[8AA0:Z5D@2[QU80ZXIB0`2YQ4l00`2ZQE00ZhIA0:^6
D@020:b7DP80ZXEA0P2YQ5020:R3C`80Yh9>2@2[QU480:b3C`030;>:EP2`Qe<0[8=?0080ZH1<00<0
Zh9>0:j5D@2`Qe<0202_QU880:b4D080[hMC0P2^QU820:f5D@80[8A@202/Q5<01P2[QeD0[8IE0:b7
D`2^QU80[hI@0;25CP80/HA;202^QE401`2[PTh0[HA@0:n6DP2`Qe<0/HQD0;27D`2_QU80102^QE42
0:f4D0<0[8=?0`2_QU830:j5D@80[HA@00<0[hIB0:f4D02/Pdl00P2[PTh00`2/Pdl0[HA@0:n6DP08
0:f4D0030:b7D`2]R5@0[HQD00@0[HQD00<0[8MC0:j5C`2^QDl01P2^QDl20:f4D080[XEA0P2_QU82
0;27D`80/HQD00H0[hIB0:j5D@2/Pdl0Zh9>0:Z1C@2YP4`80:f4D080[XE=00D0[XE?0:j5D@2^QE40
[XEA0:j4DP020:j4E0<0/HQD0P2`Qe<30:n6DP@0ZH1<0P2ZPDd20:^2CP<0[H=C0P2/PU830:^1D@03
0:b3C`2]Q500[XEA0080[hIB00<0[XEA0:f4D02/Pdl00P2WPTh01P2XPdl0ZXEA0:^6DP2/Qe<0[HQD
0:j9E@80[XEA1P2]Q5030:j5D@80[HA@0`2/Pdl30:Z2D@<0Zh=B0P2/Q5<20:f4D080[XEA0P2_QU82
0;27D`80/8ID00T0[hEC0:j4DP2]Pe40[89@0:^1C`2ZP4h0[HA@0:b3C`2[PTh00P2ZPDd01P2/Pdl0
[XEA0:n6DP2`ReH0[HQC0:V4C`80YX5<00<0ZHA?0:f8D`2`ReH00P2]Q5030:j5D@<0[hIB0P2bQ580
0`2_Q540[XEA0:b4D0020:V4C`040:R5C`2_QU80[XEA0:j5D@80[HA@0P2/Pdl00`2[PTh0ZHA?0:V4
C`020:V4C`80ZXE@0P2[QU420:j5D@040:f4D02/Pdl0[8=?0:^2CP80ZX5=00@0Yh9>0:R3C`2XPdl0
ZHA@102ZQE490:V4C`P0ZXE@202^QE460:V4D080Z8=?0P2YQ4l00`2XPdh0Yh9=0:N2C@030:N2C@0;
0:V0C02ZPDd0[8=?0:f4D02^QE40[HA@0:b3C`2[PTh0[89@0:f3D@2^Q5800P2_QE<00`2^Q580[89@
0:^1C`020:n6DP<0[XEA0`2]Q5020:R3C`80ZHA@00@0ZXEA0:V4D02YQ500ZHA@202[PDl00`2ZPDd0
Zh9>0:^2CP040:^2CP090:Z1C@2[QU80ZHA@0:N2CP2VPDd0YH1<0:J1C@2WPTh0Z8=?0080Z8=<00<0
Z8=>0:R3C`2XPU400P2XPU<0102XPUD0Yh5B0:N1DP2WPE840:R2D`050:V3E02[QU40ZHA?0:J1C02T
OdX00`2SOTT02@2TOdX0X7m90:60BP2UPT`0Yh9=0:V1C@2YP4`0Ygi:0:MlB@040:ElB0`0YWe90P2Y
Odd00`2WOD/0YWa:0:AjB0020:=iA`070:9hAP2VO4X0YG]90:EkB@2TNTP0XgU70:9hAP030:5gA@06
09egBP2MMdP0WWQ909ihA`2ONTH0X7]60P2PNd@20:5lB080X7]700@0WgY60:1kA`2PNdL0X7]70P2R
NDD30:5hA0<0X7M3102NND@409eh@`80X7I400@0XGM50:9hAP2RN4H0XgU70P2TNTP0202MM4P0WWE7
09mfB02PN4L0WgY609iiA02NND80W7U1202MN4<0102LMTD0WGM609egAP2MMdH209afA@80VgE4202H
LT<309Ye@B_ooooo000Zooooo`<0U6<j0P2CHST3099Q>0P0TVHi0P2@I3L3095U>0<0TVHi00P0TFDd
099V=@2DJ3L0UFTh09IZ>@2EJCP0U6Pg09=W=P80TfHl0P2DIcd309EX?P0309IY?`2CIcX0TfLj00<0
U6Pk0`2EJC`809IZ?@0609Q]@02GK3l0Uf`o09I[?P2EJSd0U6Tl0P2CJ3/309M[>P<0UVXi0P2EJCP2
09AX=`0409EY>02FJST0Uf/j09M[>P80V6`k00<0VFdl09M[>P2GJcX01P2GJcX809U]?0<0V6`o0`2I
KD0209Y^@@0609Q/>`2IKC`0VFdl09Y^?@2KKch0W70o0P2MLD0309]`@`<0VVm20P2IKT4309ea@080
WW910`2OLd8209md@@<0WW=00`2MLSl80:=c@P<0WgA11@2PMD800`2NMD40WGA009ac?`0209ac?`03
09ie@@2PMd<0XWU500P0X7M30P2SMdH20:9fA@80XGE40P2PM4<20:9fA@070:9gA02SN4<0XgQ10:=i
?`2TNT00Y7Xn0:EjA`030:AiAP<0XgQ500<0XWM40:5lA`2PNdH00P2PNdH209mjA@80WWU40`2RNDD2
0:=jAP<0Y7]70P2SNTH30:AkA`<0YGa80P2SN4D00`2RMd@0XGI30:1e@P0209md@@0609ic@02MN4<0
W7M209ag@P2KMT40VWE00P2IM3l209Qc?P80VFlm0P2HKS`209M]>`80UV`j0P2CJCL309AZ>004099X
=P2AIcD0T6Hd095V>@80T6Dh00<0Sf@g08iS=P2=HSD00P2<HC@208MQ=00408IP<`25Gc80Q5ha08AN
<@80Ped`0`23GS@01@22GC<0PE`b07mJ<01mF2h0O5L]0080Oe/[00@0OeX]07iI;@1nFBl0OEL`0P1m
Ec8207IC:`80Me@/00@0MU<[07AA:@1bCbL0LDhV201^CBX01P1bBbX0Kd/Y06m;:@1]BbP0JdXW06Q:
9P80ITXU0P1WBBL206I89P<0IDLU00<0I4HT0654901QA2@00`1RABD306=69P0805i68P1PAR<0HDLT
06E89P1VB2H0J4LV06Q59@1WA2@306E79@<0ITPV0P1WBBL306i;9@80Kd`V0`1`CBL207E=:@0A07A>
:@1bCbT0LU0Z075A:P1bDR/0L5<[07UF;P1hEBd0Me@/07IC:`1gE2`0N5D]07YG;`1kF300NeH/07aG
;@1mF2h00P1oFS001P1nFBl0O5L]07]F;01lFR`0OU`^081N<080PV0b00<0P5h`07iL;P1lFR`00`22
GC0208=N<@@0Q5lb00@0PU`]08AN;`26H340R68c0P29Hc@00`28HS<0Qf4b08AO=@0308EP=P<0QV4g
00@0Qf8h08QR<`28HS<0R68c0`29Hc@208YT=@0508AN<@25Gc80Qf4d08QR=@29HcH00P28HSD01027
HC@0QV0a08IP<@26H34208MQ<P<0R68c2027HC@808QR<`80QV0_00<0QV0a08MQ=027H3D00P28HCP0
1028HCX0QV0c08QR=@29HcH208YT=`0308US=P28HSD0QV0c00<0R68c0P27HC8308IP<@80QV4d00@0
Q5lb08=N<@23GS40Peha0P24Gc801@27HC@0QV0c08IP<`25Gc80Q5ha0080Ped`00<0PU`_08AM=024
GC@01P24GC@8089M<080P5/^00@0PE`_089M<023GS40Peha0P24Gc82085M;@<0PUh^00L0PEd]081L
;01oFb/0Q5lb08=N<@22GC00PE`_0080P5/^00D0PE`_089M<021G2l0PE`_081K;P0207mJ;@0307iI
;01mF2/0OEP[0080P5Xc0P1oFC8207iH<@<0OEL`2`1lFBl307]H;PX0NUL]0P1lFC4207]H<0<0NUL_
00H0NEH^07]H;P1kF2h0NUL]07UF;01hEB/207MD:P0307IC:@1gE2X0MU<Y00H0MU<Y0P1gE2`307QE
;@<0NEH^00D0ME4]07IB;P1fDbd0Me@/07QE:`0207UG:P0307YH:P1fEb/0MUL[00H0MUL[0P1cERX0
101bEBT0LE@X075D:01`DbL206mB9P0307IF;@1eEB`0Le<Z0080LE4X00<0LU8Y07=C:P1dE2/00`1d
E2/207=C:P<0LU8Y201eDRX8075A:PP0Ke8Z101aDBX4071@:@03071C:`1_DRX0KE0X0080K4lW00<0
KE0X06iA:@1_DRX0201^DBT00`1ZCBD0JdhV06e@:00206iA:@0306e@:01[CRH0JTdU00@0JDdX0P1X
C2L306M;9P0=06A<9P1UCBL0IThX06I>:01UCBL0I4`V06=;9@1RBR@0J50/06M?:`1VCRX0IDdY06A<
:002069:9P0306599@1PB2@0H4PT00H0H4PT0`1OAb<2061890<0HDTU0P1OAb<2061890<0HDTU00D0
HTXV069:901RBR@0Hd/U06A<9P0206E=9`80IThX0P1TCRL0101UCBL0IddX06U=:01[CBT206e<:@80
KdlX0P1`D2T3075A:P0=079B:`1ZDbX0K5<[06eD:`1`EBX0LeHZ07IG:@1hEbX0NETZ07IG:`1gF2`0
NEX^07]L<00407eN<P0607QL;01kG2d0Ne`]07eM;P1oGBl0PUd`0P24GS4208=N<@0708AO<P25H3<0
Qf8e08QS=P29I3L0RVDh08]U=P0308aV=`80SFLh0P2>J3T0202>Ic`0SfPm08mY?02?JCX0T6Xi091[
=`2AK3P0TF`g0P2CKSX00`2DKc/0UG0l09Ia?@0209Mb?P0709Qc?`2GLcT0Ug<i09Qc?02HLch0VG@o
09Ud@00209Yd@`80VgI100<0W7M209eh@`2NND@00P2ONTD0102PNdH0WgY50:1kAP2RODP20:=nB@03
0:9mB02PNdH0WgY500@0YH1;0P2VPD`30:N2C@P0ZXE@0P2[QTl01P2/Qe80[XUE0:n9F02`RU/0/H]L
0;:<G`80/8YK0P2aRe`20;:<G@80/heN0`2cSUX20;:=F@<0/HaH202cSUX80;:=F@P0/XeH00H0/8]G
0;6<F02aS5P0/XeI0;>>FP2dSe/20;F@G0P0]H]I202aS5P20;2;E`80/HaH0P2bSET20;>>FP80/HaH
0P2`ReL20:n:EP80[XUE0`2`RUd30;6;GP80/XaO0`2aS5P30;2;E`80[hYF0P2]R5@20:j9E@@0[hYF
0P2`ReL00`2_RUH0[XUE0:f8E0020:b7D`030:^6DP2]R5<0[HQC00H0[HQC0P2`ReL00`2_RUH0[XUE
0:f8E0020:b7D`030:^6DP2]R5@0[HQD0080[HQD0`2^RED20:n:EP<0/8]G0P2_RUH30:j9E@040:^6
DP2/Qe<0[8MC0:b7D`<0[HQD00<0[XUE0:f8E02]R5@01P2]R5@80:n6DP060:f7FP2]QeP0[HMH0:f7
EP2]R5@0[HQC0P2]R5400`2[QU40[8MB0:f8D`020:j9E0030:b7DP2ZQE00ZHA?00P0[HA@0`2/Qe<3
0:^6DP80ZXEA202/PU080:j4DP030:f8E02/Qe<0ZhIB0080ZXEA00<0ZhIB0:b7D`2]R5@00P2^Q5@0
102/PU00[8=?0:b3C`2/Pdd20:j5C@P0[XEA0P2_QE<20:j4DP<0[H=A00L0[89@0:n6DP2^QE40[XEA
0:f4D02/Pdl0Zh9>0080ZX5=00T0Zge<0:anC@2/P4l0[H=A0:b4D@2[QU80ZXEA0:V5D@2XPdh00P2Y
Q4l00`2ZQE00ZhIA0:b7DP020:f8D`80[8MC00@0ZhIB0:Z5D@2YQ500ZHA@0P2XPdl90:^6D@P0Zh9>
00<0/HQD0:n6DP2^QE400`2/Pdl00`2]Q500[XEA0:n6DP070:n6DPP0ZXE@0`2]R5<20:b7DP<0ZhIA
202[QEH02@2[Qe<0[8MC0:^6D@2]QTl0[XE=0:j4BP2`PdX0/8=80:b3C`030:f4D0<0[XEA00P0[hIB
0:b3C`2]Q500[hIB0;27D`2aR5@0/8MC0:n6DP@0[XEA0P2]Q5030:b3C`<0[hIB0`2^QE420:f4D003
0:j5D@2]Q500[8=?0080Zh9>00<0[8=?0:f4D02^QE40202]Q5000`2/Qe<0[HQD0:j9E@030:j9E@03
0:f8E02/Qe<0[XE?00L0[XE?0P2]Q5020:j5D@030:n6DP2`Qe<0/HQD0080/HQD0P2`Qe<01@2^QE40
[HA@0:b3C`2[PTh0ZX5=00P0[8=?00@0[8=;0:f4C02]Q4h0[HA@0P2^QE400`2^Q580[XAD0:n5E@03
0;27D`80[hIB0`2^QE420:V0C080ZX5=0`2[PTh00`2/Pdl0[X=F0:f2E@020:f2E@80[85D0P2[P5<0
0`2]Q500[XEA0:n6DP020;27D`030:n6DP2^QE40[HA@00<0ZHA@00<0ZXEA0:^6DP2/Qe<00P2]R5@2
0:n6DP80[XEA102]Q5030:j5D@80[HA@0`2/Pdl30:R2D`<0ZH=D0P2ZQ5D30:j4DP80[hEC0`2`QU@2
0;67E@0A0;26E02^Q580[H=A0:b2D02[PDl0ZX1>0:f4D02/Pdl0Zh9>0:Z1C@2[PTh0[8=?0:j5D@2_
QU80[XUB0:f8D@2ZQDh00P2XPd`00`2ZQDh0[HQA0:j9DP020:f4D0<0[XEA0`2_QU820;>5D`030;25
DP2^QE40[8A@0080ZHA?00@0YhA>0:n6DP2_QU80[XEA0P2]Q5000`2/Pdl0Zh9>0:^2CP020:V4C`<0
Z8=>00<0ZHA?0:^6D@2/Qe80102]Q5030:b3C`050:^2CP2WPTh0Z8=?0:V4D02ZQE400P2[QU800`2Z
QE40ZHA@0:R3CP030:V4C`@0ZXE@102[QU420:Z5D0<0ZHA?202]Q5020:Z5D@<0ZHA@0`2XPdl00`2Z
QE00ZHA?0:R3CP030:J1C00=0:N2C@2XPdh0ZH1<0:Z1C@2/Pdl0[HA@0:j5D@2]Q500[8=?0:^2CP2/
PU00[H=A0:j4DP020:n5D`030:f3D@2[PDl0ZX1>00<0[XEA0P2]Q5030:b3C`040:N2CP2XPdl0ZHA@
0:Z5D@80ZhIB00<0ZXEA0:V4D02/PU001`2/PU000`2ZPDd0Zh9>0:b3C`030:b3C`0:0:^2CP2ZPDd0
ZhIB0:V4D02WPTh0YX5=0:F0C02VPDd0Yh9>0:R3C`80Z8=<00<0Z8=>0:N2CP2WPE000P2VP5400`2V
P5<0Z89C0:R2D`060:R2D`060:Z5D02XPdh0YX5<0:AoBP2SOTT0Y7m:0P2UP4/02@2POdT0XH1:0:F2
C02WPTd0ZH5=0:V0C02WOTX0Yga90:AkA`030:ElB0<0YWe900<0Ygi:0:ImB@2VODT01P2VODT0102Y
Odd0Z7i<0:IlBP2UNdT30:AjB0060:EkB@2VO4X0YWa:0:EkB@2TNTP0XgU70`2RN4H01`2QMdD0W7I9
09egB02MMdP0WWQ709mjAP2PNdH00P2QO4D00`2RODT0XGa80:1kA`0309mjAP80X7]70`2RNDD20:5h
A0<0X7M300@0WgY509iiA02NND@0WWU40`2MN4<00`2LMd80XGM50:9hAP020:9hAP@0XgU700P0Wg98
0:1dA`2OM4L0WgM609iiA@2MNT@0Vg]209Yj@@P0WGQ300<0VWA509]eAP2LMTL00P2MMdP00`2LMTL0
VgE609YdA@0309Qb@`80VG=40`2JM4D309Ud@2_ooooo000Zooooo`<0U6<j0P2CHST3099Q>0P0TFDh
0P2@I3L3095U>0<0TVHi00P0TFDd099V=@2DJ3L0UFTh09IZ>@2EJCP0U6Pg09=W=P<0U6Lm0`2EJ3h2
09IY?`<0UFTl0`2FJSd209M[?PP0UVXm0P2HKD001P2GK3l0UV/n09EZ?@2DJC`0TfPk099W>P80V6`k
0P2GJcX0202FJST0UFTh09EY>02EJCP0TfLf09AX=`2EJCP0UVXi0P2GJcX00`2HK3/0VFdl09U]?008
09IZ>@P0VFdl0`2HK3l309U]@080VVi100D0V6`k09U]?02IKC`0VVhm09a`?`0209ea@00409ib@@2N
LdH0WG9509ebA@80W7540P2KL4<0102JKd80W70o09a`?`2LL3l309ea@080WW910P2OM44309ic@0<0
WG8o202SLd820:1e@PH0WgA100<0X7M309mf@P2NMD400P2MM4000`2OMT80X7M30:5hA0080:5hA080
XgM60P2RMTD20:5eA080X7A30P2RMTD01`2RMd@0XgQ30:=h@@2SNCl0Y7Y00:Aj?P2TNDH00P2SN4D2
0:9gA080XGI300<0X7E20:5lA`2QO4L00`2PNdH309mjA@<0XWU50P2SNTH30:AkA`80XgY60`2TNdL3
0:ElB080XgQ500@0XWM40:5f@`2PMD80WgA10P2NLd001@2MN4<0W7M209ag@P2KMT40VG@o00<0V7<n
00<0Ug8m09Q^?02HKS`00`2GKC/309I/>P03095W=@2BJ3H0TfTg0080U6Xh00<0TVPf091V=02?IC<0
0P2@ICP0102?I3L0SV<f08eR=@2=HSD208aQ=080QV0c00L0QElb08AN<@23GC00Ped`089L;`21Fbh0
PUdc00<0Pehd00X0PE`b07iI;`1lEbd0NUD[07mK:`1nFRX0OUT/07iI;@1mF2h0OEL`0P1lES40101h
EBd0Me@/07EB:P1cD2P2079?9`80Le0X1P1]C2T206i=:P08075::@1_BbT0KTXX06a:9`1ZBBH0IdTU
06I:9@1UBB@306I89P80IDLU0`1TAR@205i48`80GdDT0P1PARD206579P0805e58@1OAB80HDLT06E8
9P1WBBL0J4LV06Q59@1WA2@306E79@<0ITPV0P1WBBL2071=9`80LDhX0`1bCbT05@1cD2X0N50/07M?
:`1fD2/0M54[079@:P1aDBX0L50Y06iA:@1jEbl0NEH^07QE;@1gE2`0N5D]07UF;P1kF300O5Ta07QC
:@1iE2X0O5L]07eH;P0207iI;`0507eH;P1lEbd0O5X/07iL;P21Gc400P24HS@00`21Gc40OU`^07aJ
;002089M<080Peha1@24Gc801023GBh0Q5h_08IP<@28HS<208US=00308QR<`27HC80PUdc0080Pehd
0P24GcD208EP=P0408IQ=`2:I3D0RV@e08YT=@<0RF<d0P28HS<01021FRl0Pe`a08IO=028HCH208YS
>080RF8g0`28HS<208MQ<P<0QV0a2027HC@808QR<`80QV0_00<0QV0a08MQ=027H3D00P28HCP01028
HCX0QV0c08QR=@29HcH208YT=`0308US=P28HSD0QV0c00<0R68c0P27HC8308IP<@80QF0c0P26HC@0
1025H3<0Q5lb08=N<@22GC0208MQ=00408IP<`25Gc80Q5ha08=M<080PU`_2023G3<?089M<00308=N
<@21GB/0PUh/00<0Pel]00@0PEd[07mK:@1mFBL0PUd`1023GS400`22GC00P5/^081K;P0607mJ;@80
OUT/0P20FSD207mI=080OUPc0`1mEc8407aI;`@0NeP^0`1lFBl307]H;PX0NUL]0`1lFC4207]H<0<0
NUL_00H0O5T_07]H;P1jEbd0NEH/07QE:`1gE2X207IC:@80N5D[0P1gE2X0101fDbT0ME8X07AA9`1d
DBL307IC:`<0Me@/0P1hEBd207MC;`0307MD;P1gE2`0N5D[0080N5HY00<0N5HX07IG:`1fEb/01P1f
Eb/8071E:00407IF;@1eEB`0Le<Z079B:@80LE4X00<0LU8Y07=C:P1bDRT00P1bDRT207=C:P<0M5@[
201cD2P8075A:PP0Ke8Z101`D2T4075A:P0306mB:P1^DBT0K4lW0080K4lW00<0KE0X06mB:P1`Db/0
1@1^DBT306mB:P0306Y=9@1[CRH0K4lW0080KU4Y00<0KE0X06a?9`1[CRH01@1YCBP206Q<9`80Id/V
00<0I4`V06E=9`1WCbT00P1WCbT0101UCBL0Hd/U069:901WCb/206I>:P80IDdY0`1TC2P806599@80
GTHR0P1OAb<30618900306599@1PB2@0H4PT0080HDTU0`1RBRH01`1SBbL0H4XS061:8`1QBb@0HT`U
06==9P1TCRL00P1UCbP206==9P0406A<9P1VC2L0J4`W06Y<:080K4/X00@0KThW06m?:01_CbP0KdlX
0P1`D2T2075A:P80JU<Z00`0K5<Z071E:P1bEBT0MULY07MH:P1hF2T0Le@X07AE:@1gF2`0NU/_07]L
<01lGC4207]L<00>07UM;@1kG2d0O5d^07iN;`20GS00Peha08AN<@25Gc80P5/^085L;`22GC00Peha
08EP<`27HSD208QS=P80RfDf0`2<ISL308eW>00608iW@02>Ich0SVLl08mY?02?JCP0T6/g0P2@Jc@2
09=^>P80U6lk00@0UG0l09Ia?@2GLSh0Ug8n0P2GLcT0102GLS/0V7<n09Qc?P2HLcl209Qb@@80VWE0
00T0VgI109ag@P2MN4<0WWU409mjA@2PNdH0WgY50:1kAP2QO4L00P2RODP00`2QO4L0X7]609mjA@03
0:AoBP80YH1;0`2VPD`00`2WPTd0ZXE>0:Z5CP060:V4C@050:b7D02]R540[HQC0:j9E@2^R5L00P2_
REX00`2_RE`0/8YK0;2:F`020;6;G080/XaM0P2cSEh30;>>FP030;:=F@2aS5P0/HaH0080/8]G202c
SUX80;:=F@P0/XeF0P2`ReL01P2aS5P0/XeI0;>>FP2dSe/0]I1L0;JAG@P0]H]I302aS5P40;:=F@<0
/8]G102_RUH0102^RED0/X]P0;:;H02bRf030;6:G`80/8UN0`2aS5P30;2;E`80[hYF00<0[8MC0:f8
E02]R5@00P2^RED20:n:EP070;2;E`2aS5P0/8]G0:n:EP2^RED0[HQD0:b7D`020:^6DPP0[HQC00H0
/HaH0;2;E`2_RUH0[XUE0:f8E02/Qe<20:^6DP@0[HQD0`2^RED20:n:EP<0/8]G0P2_RUH30:j9E@80
ZhIB0P2/Qe<20:f8E080[XUE202]R5@80:j5D@060:f7FP2]QeP0[HMH0:f7EP2]R5@0[HQC0P2]R540
202ZQDh0ZhI?0:b7D02]R540[8M@0:^6C`2YQ4d0Yh9;202]Q5020:f8E080[8MC00@0ZhIB0:Z5D@2Z
QE40ZXEA402/PU000`2]R5@0[8MC0:Z5D@020:V4D0060:Z5D@2/Qe<0[HQD0:n5E@2^Q5@0[89@0P2[
PTh00`2/Pdd0[XE=0:n6CP080:j5D@<0[hEC0P2^Q5830:f3D@050:n5D`2^Q580[XAB0:f3D@2[PDl0
0P2ZP4h02P2YOdd0ZWa;0:anC@2/P4l0[H=A0:f5DP2[QU80ZXEA0:R4D02XPdh20:V4C`0;0:Z5D02/
Qe80[HQC0:f8D`2^RE@0[hYF0:j9E@2]R5@0[8MC0:^6DP2ZQE400P2YQ5090:^6D@P0Zh9>00P0[XEA
0:n6DP2_QU80/8MC0:n6DP2^QE40[8=?0:^2CPP0[hIB202ZQE040:f8D`80[8MB0P2[QU480:^5EP06
0:Z7D@2[QU40ZXE>0:b5C02/Q4T0[8980P2^PDH30:b3C`030:f4D02^QE40[XEA0080[hIB00<0[8=?
0:j5D@2_QU800`2aR5@00`2`Qe<0[hIB0:j5D@020:j5D@80[HA@0`2/Pdl30:n6DP<0[XEA0P2]Q500
0`2^QE40[HA@0:^2CP020:Z1C@030:^2CP2]Q500[XEA00P0[HA@00<0[8MC0:f8E02^RED00P2_RUH0
0`2^RED0[HQD0:b7D`080:j5C`060:b3C`2]Q500[XEA0:n6DP2`Qe<0/HQD0P2bRED20;27D`040:n6
DP2^QE40[XEA0:f4D0X0[8=?0P2/Pd/01@2/Pdd0[HA@0:j5D@2^QE40[XAB0080[hEE0P2_QU820:j5
D@80[HA@0P2/Pdl20:Z1C@80Zh9>0`2/Pdl00`2]Q500[X=F0:j3EP030:f2E@<0[85D00<0[HA@0:j5
D@2`Qe<00P2aR5@00`2`Qe<0[XEA0:f4D0080:^6DP030;27D`2_QU80[hIB0080[XEA0P2]Q500102/
Pdl0[XEA0:j5D@2^QE420:f4D0<0[8=?0`2XPU<30:V3E080ZXAE0P2^Q5@20:n5E@@0/8IF00X0/XQF
0;67E@2`QU@0[hEC0:f3D@2/PU00Zh5?0:Z0CP2]Q500[8=?0`2[PTh0102]Q500[hIB0;27D`2/R4h6
0:^7C@030:b8CP2]Q500[HA@00<0[XEA0`2_QU801@2dQU@0/hEC0;66D`2_QU80[8A@0080ZHA?00H0
YhA>0;27D`2_QU80[hIB0:j5D@2/Pdl20:^2CP030:Z1C@2ZQE00ZHA?00<0Yh9=00<0ZHA?0:^6D@2/
Qe800`2/Pdl30:f4D080[XEA00P0Yh9>0:R3C`2ZQE40ZhIB0:b7D`2[QU80ZXEA0:V4D080Z8=>0P2Y
Q4l00`2ZQE00ZhIA0:^6D@020:^6D@030:b7DP2[QU40ZhIA0080ZXE@0P2YQ4l00`2XPdh0[8=?0:b3
C`060:b3C`<0ZXEA00<0ZHA@0:R3C`2XPdl00P2WPTh04P2[QU40ZHA?0:N2C@2VPD`0YH1;0:J1C02W
PTd0Z8=>0:V0C02ZPDd0[8=?0:f4D02^QE40[HA@0:b3C`2[PTh0[H=A0:j4DP80[hEC00@0[XAB0:f3
D@2[PDl0ZX1>0`2]Q5020:b3C`<0Zh9>00@0YX5=0:R3C`2ZQE40ZhIB0P2/Qe<20:Z5D@P0[H=A00<0
ZX5=0:^2CP2/Pdl00P2]Q5002`2/Pdl0Zh9>0:Z1C@2[QU80ZHA@0:N2CP2VPDd0YH1<0:J1C@2WPTh0
Z8=?0080Yh9;00H0YX5<0:J1C@2UOdh0YGm@0:AnC`2TOU440:V3E0@0Z89C00<0Z8=>0:N2C@2UP4/0
0P2TOdX02`2UP4/0Yh9=0:R3CP2POdT0XH1:0:F2C02WPTd0ZH5=0:V0C02WOTX0Yga90080Y7]70P2U
O4P20:ImB@X0Ygi:00<0Z7i<0:MmB`2UNdT00P2TNTP00`2UNdT0YWa:0:MmB`020:IlBP80YG]900<0
Y7Y80:=iA`2RN4H00P2RN4H02`2LMTT0W7I709egB02NN4L0WgY60:1kAP2QO4D0XWe60:AoB`2RODT0
X7]700<0WWU500@0WgY60:1kA`2SNTH0XgY60P2RNDD30:5hA0030:1g@`2ONTD0WgY50080WWU40P2M
N4<209ag@P80Y7Y80`2SNDL30:9hAP060:5bB02QLTH0X7A709ifA@2MN4@0VWU30P2JNd8809ag@P03
09UcA02JM4D0W7I70080WGM800<0W7I709]eAP2JM4D00P2ILd@209YdA@80VgE60P2LMTL309Ud@2_o
oooo000Zooooo`<0UV8j0P2EHCT309AP>0P0TFDh0P2@I3L3095U>0<0TVHi00P0TFHc099W=02DJCH0
UFXg09I[>02EJSL0U6Tf09=X=@<0U6Lm0P2EJ3h309IY?`<0UVXm0`2GJch209Q/?`P0UVXm0P2HKD00
0`2GK3l0UV/n09EZ?@0209=X>`03099W>P2HK3/0V6`k0080Uf/j00D0UVXi09EY>02EJCP0U6Pg09=W
=P0209AX=`0409IZ>@2GJcX0Uf/j09Q/>`80VFdl202FJST809U]?0<0V6`o0`2IKD0209Y^@@0609Q/
>`2IKC`0VFdl09]_?P2LL3l0WG500P2NLT4209mdA`80WW=600@0WG9509aaA02LLD@0Vg130`2KKch2
09a`?`<0WG500P2OM44309ic@0<0WG8o202ULd820:1e@P@0WgA10P2NLd000`2RNDD0XGQ409mf@P02
09ie@@0309mf@P2PMd<0XGQ400P0XWU50P2SMdH20:9fA@80XGE40P2PM4<20:9fA@060:9gA02SN4<0
XgQ10:=i?`2TNT00Y7Xn0P2SN4D0102RMd@0XGI30:5f@`2PMD8209md@@<0X7e70P2OO4H309ikA@<0
XWU50P2SNTH30:AkA`80XgY60`2TNdL30:ElB0060:=hA@2RMd@0XWM40:5f@`2PMD80WgA10P2NLd00
1@2MN4<0W7M209ag@P2JMD00VG@o0080V7<n0P2GLSd409M]>`@0UV`j00<0T6Hd095W=@2CJCL00P2D
JSP00`2BJ3H0T6Hd08mU<`02091U>00308mT=`2>HcH0SF8e0080S64d00L0Rf0c08IP<`25Gc80QElb
08AN<@23GC00PU`_0080PE/^00P0PUdc08=N=023GS@0Pehd085L<P1nFBl0NeH/07UD:P80OUXZ00@0
OUT/07iI;@1mF2h0OEL`0P1lES40201iERh0Me@/07AA:@1aCRH0L4dU075>9P1cD2P0M54Y0`1/BbP4
06e<:@0706i=:P1aBRT0KTXX06i::01/BRL0JTTV06M99@0206E99080ITPV0P1UAbD306A6900406=5
8`1LA280G4@R05e58`80GTHT00/0GdLU06189P1PB2H0G4@P05m58P1QAb@0IDPV06M99`1YB2L0J4DU
06M4900306E79@<0ITPV0P1WBBL307A>9`80MDlX0`1fD2T0201jDRh0NE4]07MA;01dDB/0LU0Z071@
:@1_CbP0KE0X0P1jEbl307QE;@0707YG;`1lFC40OEXb07IA9`1hDbT0NUD[07aG;@0307iI;`0407eH
;P1lFR`0Oed_089P<P80Q68d00<0PV0b07mM;`1lFR`00P22GC0208=N<@@0Q5lb00D0QF0c08=M;P24
GRl0QV0a08QR<`0208US=080R68c0P21Fc@01022G3D0Pedf08=M=P24GSL208EO>00508aV=`2;ICH0
RfDf08YT=@29Hc@00P28HS<01P27HC80OeP]085J;`25GS<0R64f08YS>080Rf@i00@0RV<h08US=029
Hc@0R68c0P27HC800`26H340QEl`08EO<00808MQ=0P0R68c0P26H2l00`26H340Qf4d08MP=@0208QQ
>00408QQ>P26H3<0R68e08US=P80RV@g00<0RF<f08QR=@26H3<00`28HS<208MQ<P<0QV0a0100Q5lb
08EP<`27HSD0R6<f08MR=@25H3<0PUd`081K;P28HSD0Qf4d08IP<`25Gc80Q5ha08=M<022G2l0PE/^
2023G3D8089M<0<0Peha0`22GC02085L;`0;085M:`22GR`0Pel]08AP;P23Gbd0PEd[07iJ:01mFBL0
P5/^089M<024Gc800P25H3<01023GS40P5/^07iI;01mF2/307iI;0<0OeX]00<0P5/^081J=@20FSD0
0P1oFC@207iH<`<0OELb0`1lFBl507]H;P<0O5T_0`1kF2h:07YG;@<0OUPa0`1mEc0207aF;`0607aI
;`1kF2h0NeP^07UF;01hEB/0Me@Z0P1fDbT01P1jEbd0NEH/07QE:`1gE2X0MU<Y07AA9`80Le0V101e
DRX207IC:`80Me@/00D0NEDa07QD<01hEBl0N5D]07MD:P0207ME:00307ID9P1fEb/0MUL[00H0MUL[
0`1_E2L2071E:0<0LEHY00@0MeL^07EE;01cDbX0LU8Y0P1aDBP01@1bDRT0Le<Z075A:01aDBP0LU8Y
0080Le<Z00<0M5@[07EE;01eEB`0201bCbL8075A:PP0Ke8Z101`D2T4075A:P0806iA:@1]D2P0K4lW
06]>9P1/CbL0KE0X06mB:P1`Db/406iA:@@0Ke8Z00<0JTdU06]>9P1/CbL00P1^DBT00`1]D2P0K4lW
06]>9P0206Y>:@<0JDdX0P1XC2L206M;9P0806A<9P1VCRP0IdlY06Q@:P1WCbT0IThX06=;9@1RBR@3
06I>:PD0IDdY201RBRH205i68P80GdLS101PB2@206599@80HTXV0`1SBbL01`1TC2P0GdTR05m98P1P
BR<0HD/T06==9P1TCRL00P1UCbP2069<9`0606A<:01UBbP0J4/Y06U;:@1[BRT0K4/Z0P1^CRL206m?
:0<0L50Y00d0LE4Z06QB:@1ZDbX0Je@Z06eE:@1aERT0LeLX07IG:@1gF2T0LE8V07=D:01fEb/0NEX^
0080Ne``0P1jFbl01P1iGBd0O5d^07aM;P1nGRl0P5h`08=N<@80QElb0P1oFRd01021G2l0PUd`08AO
<P25H3<208MR=@<0RfDf0P2<ISL308eW>00908eV?`2>Id00SVLl08iX>`2?JCP0SfXe091[=02@K380
TVdi0080Tfhj00<0U6lk09E`?02FLCd00P2GLSh209Mc>@0409Mb>`2GLSd0Ug8m09Qc?`80V79100H0
VG@o09Ye@02KMT40W7M209eh@`2NND@209mjA@0309iiA02ONTD0XGa70080XWe800<0XGa709mjA@2N
ND@0102TOdX20:F0B`<0YX5<00<0ZXE>0:V4C@2YQ4d00P2YQ4d30:R3C080[XUB00<0[XUD0:j9E@2^
R5L00P2^R5T00`2^R5/0/8YM0;2:G@020;6;GP80/XaO0P2cSF030;>>FP030;:=F@2aS5P0/8]G0080
/8]G202cSUX80;:=F@P0/XeF0P2`ReL00`2aS5P0/XeI0;>>FP020;F@G0030;JAG@2eReT0]H]I00H0
]H]I302aS5P40;:=F@030;2;E`2_RUH0[hYF00D0[hYF00D0]8eR0;><H@2cS640/X]P0;6:G`020;29
GP040:n8G@2aS5P0/HaH0;6<F0<0/8]G0P2_RUH20:b7D`80[HQD00D0[XUE0:n:EP2_RUH0/8]G0;6<
F0020;2;E`030:j9E@2]R5@0[8MC0080ZhIB202]R5<01P2aS5P0/8]G0;2;E`2^RED0[HQD0:b7D`80
ZhIB102]R5@30:j9E@80[hYF0`2`ReL20:n:EP<0[XUE0`2[QU800`2/Qe<0[HQD0:j9E@020:j9E@P0
[HQD202^QE401P2]QeX0[HMH0:f7F02]QeH0[HQD0:f8D`80[HQA00P0ZHA=0:Z5CP2[QTl0[8M@0:^6
C`2ZQDh0Z8=<0:J1BPP0[HA@0P2]R5@20:b7D`040:^6DP2ZQE40ZXEA0:V4D0P0[89@202[PDl00`2]
R5@0[8MC0:Z5D@020:V4D0060:Z5D@2/Qe<0[HQD0:n5E@2^Q5@0[89@0P2[PTh00`2/Pdd0[XE=0:n6
CP080:j5D@<0[hEC0`2^Q5820:f3D@060:n5D`2^Q580[XAB0:b2D02[PDl0ZX1>0P2YOdd02@2ZO4/0
[7i=0:b0C`2^Q580[HEB0:^6DP2ZQE40Z8A@0:R3CP020:V4C`030:^6D@2/Qe80[HQC0080[XUD0P2`
ReL0102_RUH0[XUE0:b7D`2[QU820:Z5D@T0ZhIA202[PTh0202/Pdl0[XEA0;27D`2bRED0/HQD0:n6
DP2/Pdl0ZX5=202_QU880:V6D0040:f:E02/RE<0[8UC0:b9D`80ZhQB0P2ZQe480:Z5F0080:V6D02Z
QE00ZHA=0:^4B`2[PdP0Zh550:f0A@2/P4<20:^2CP040:b3C`2]Q500[HA@0:j5D@80[hIB00P0[8=?
0:j5D@2`Qe<0/HQD0;:9E@2aR5@0/8MC0:n6DP<0[XEA0P2]Q5030:b3C`<0[hIB0`2^QE420:f4D003
0:j5D@2]Q500Zh9>0080ZX5=00<0Zh9>0:f4D02^QE40202]Q5000`2[QU80[HQD0:n:EP020;2;E`03
0:n:EP2]R5@0ZhIB00P0[XE?00P0[8=?0:f4D02^QE40[hIB0;27D`2aR5@0/XUE0;>:EP<0[hIB0`2^
QE420:f4D0P0[8=?0P2[PTX01@2/Pdd0[HA@0:f4D02]Q500[XAB0080[hEE00@0[XEA0:f4D02]Q500
[HA@0P2/Pdl40:^2CP80[8=?0`2]Q500102^QE40[X=H0:j3F02^PeP20:f2E`<0[85F00<0[XEA0:n6
DP2`Qe<00P2aR5@00`2`Qe<0[hIB0:j5D@030:b7D`<0ZhIB0P2ZQE420;27D`80[hIB00@0[XEA0:f4
D02]Q500[8=?0`2^QE420:f4D0<0[8=?0`2WPUD30:R3EP80ZHAG0P2^Q5@20:n5E@<0/8IF00`0/HMG
0;>9E`2bR5H0/HME0:n5D`2]Pe40[89@0:^1C`2ZP4h0[XEA0:f4D02/Pdl20:^2CP050:f4D02_QU80
/8MC0:Z6C02[Qdd0102/R4h0102[Qdd0ZXI<0:f4D02]Q5030:j5D@<0[hIB0P2dQU@00`2aQU<0[hIB
0:f5D@020:V4C`070:N4CP2`Qe<0/8MC0:n6DP2^QE40[8=?0:^2CP020:Z1C@080:Z5D02YQ4l0Yh9=
0:J1C02WPTd0ZHA?0:^6D@2/Qe820:^2CP040:b3C`2]Q500[HA@0:j5D@80[hIB00<0Yh9>0:R3C`2Z
QE400`2/Qe<01@2ZQE40ZHA@0:R3CP2XPdh0ZHA?0080ZXE@0P2[QU440:b7DP040:^6D@2ZQE00ZXE@
0:V4C`80Z8=>202[PTh0102[QU80ZXEA0:Z5D@2YQ5020:R3C`80Yh9>00<0ZhIA0:V4C`2WPTd00P2U
P4/03@2VPD`0Yh9=0:V4C`2YP4`0ZX5=0:b3C`2]Q500[XEA0:f4D02/Pdl0Zh9>0:f3D@2^Q5800P2_
QE<0102^Q580[H=A0:^1C`2YOdd30:b3C`80Zh9>0`2ZPDd0202VPDd0Yh9>0:Z5D@2/Qe<0[HQD0:b7
D`2[QU80ZXEA202]Pe400`2YP4`0Zh9>0:f4D0020:j5D@0;0:f4D02[PTh0ZH1<0:^6DP2YQ500Yh9>
0:J1C@2UP4`0YX5=0:N2CP2XPdl00P2VPDX00`2VPD`0YH1<0:AnC@020:=mCP030:=mD02YPe@0ZH=D
00<0ZH=D0`2XPU<0402WPTd0YX5<0:F0B`2TOdX0YH1;0:J1C02XPdh0ZHA?0:1oB@2QP4X0YH9<0:N2
C@2YPDd0ZH1<0:MnBP2WO4T30:AkA`030:ElB02VODT0Ygi:00X0Ygi:00<0Yge;0:IlBP2TNTP00P2S
NDL0102UNdT0Yge;0:UoC@2WOD/20:IlBP030:EkB@2TNTP0XgU700<0XWQ60100W7I909afA`2MMdP0
WWQ709mjAP2QO4L0XGa50:9mAP2TOd/0Xgi:0:1kA`2NNDD0WGQ409iiA@2ONTH0X7]70P2SNTH20:9i
A@@0XGQ40`2ONTD00`2NND@0WGQ309ag@P0209ag@P80YG]900@0Y7Y80:=iA`2SNDL0XWQ60P2QMdD0
202SLTT0XG9609mcAP2NMTD0VgM309Yi@`2INT40VGa2202LMd800`2HLTD0VWA709afB@0209egBP03
09afB@2KMDP0VG=600<0VWA500<0VgE609afA`2MMdP00P2MMdP309Ud@2_ooooo000Zooooo`P0TF@j
0`2?HSP2091S>@<0TF@j202CIcX209=V?00409AW?@2EJ3h0UFPn09IY?`80UfY00P2GJch0102FJSd0
UFTl09EY?02DJ3/209=W>P0@09IU>P2HIc`0VVTn09]Z?`2LJd00VfXo09UX?@2HIc`0VVTn09UX?@2G
IS/0UF@i09AS>02EI3T0UfHk09QW?0@0V6`k102GJcX309IZ>@0309M[>P2HK3/0VFdl00D0VFdl00<0
V6`k09M[>P2GJcX00`2FJST809U]?080VFhg00@0VFhi09U^>`2IKS/0VFdl0P2IKCh809U_?@80Uf/j
00@0V6`k09U]?02KKch0W70o102MLD001P2LL3l0Vfln09ea@02OLd80XWI50:AhA`80WG5200@0WG50
09eb?`2MLSl0WG8m0P2MLS/40:1e@P@0WgA10`2PMD8209md@@<0WW=0202NMD480:9gA0P0X7E2202R
NDD80:EjA`80X7M30P2QN4@00`2RNDD0XgY60:=jAP030:AkA`80YGa80P2VODT20:MnBP030:ElB02V
ODT0Ygi:0080ZH1<00T0Ygi:0:ImB@2UO4P0YW]40:Ej@`2TND80XgQ10:9g@02PMCh00P2OM3d02@2R
ND<0XGQ20:5hA02PMT@0WgE509icAP2MLTD0WG9709id@P0209ec@@0409ab@02KLCl0VW0n09Y`?P80
VFlm00H0V6lk09M^>P2GKSX0UVdi09E/>02DJcL209=Z=P0609=^>@2BKCP0TVdh095/=`2@JcH0SfXe
0P2>JC@208US=P0408QR=@27HC@0QV0c08IP<`80QElb0P23GS@2089M<`<0PE`b00H0P5/a089L=@22
G3D0PE/d081J<`1oFC8207iH<@0307eG<01gE2h0N5D_00<0NEH`00<0Me@^07AA:`1cD2X00P1eERX0
3P1dE2/0LU8[075A:`1`Cb`0Kdh[06i=;01hEc@0ME@a06m>:`1[BRL0JTTV06a;:01_CR/0LU4^0P1[
B2P00`1ZBBP0J4XX06M::00206E;:00506A<:01QBBL0H4PV06189P1OAbD00P1NAR@205e58`030694
8P1TAR@0IdTW0080JD/Y00<0ITPV06=58`1P@R00101YB2D406Q79080J4`W00<0JT`X06e<:@1_CBX0
0P1aCB/01`1dCB`0L4XS075;901bC2D0LddV07A>9`1eCbP00P1fD2T207UB:`0307YC;01kE2d0O5D^
0080OEH_00`0OUL`07]C;`1lE300OEDa07iF<P1mEC40O5@`07YB;P1iDBd0P5X]07mI;01mEbX207aF
:@0307iH:`1oFB`0PE/^0080Q5lb1023GS4208AO<P80Q5ha00@0QElb08IP<`28HSD0RF<f0`2:I3L2
08MQ=0<0R68e0`29HcH808IP<`0808QR<`29Hc@0RV@e08]U=P2:I3D0R68c08EO<024GRl208IQ=`<0
QF0f0`24GcD808IP<`80QEl`00@0QV0a08MQ<P27HC80R68c0P29Hc@00`24GRl0QEl`08QR<`0308YT
=@0:08QR<`27HC80R68a08MQ<026H340QV0c08MP=@29HST0Rf@k08aU?P80RV@e0P29Hc@01028HS<0
Qf4b08MQ<P26H34208AN;`80QEl`00L0QV0a08MQ<P27HC80R68c08eP=P2<GcD0RUdc0080RE`b00@0
RUdc08aO=@2=H3H0QF0c0P24Gc800`23GS40PUd`085L;`02081K;PP0PE/^0P21G2l3089M<0<0Peha
0P28Gc<01026H3<0QF0c08EP<`23HC<2089R<`80OeX]00@0P5/^085L;`21G2l0PUd`0P23GS400`1i
EbT0O5X/085O<@0208AR=003089P<P1mFbd0NUPZ00@0OeX`0P20Fc42085L<P0707mL<P1mFS00NeP^
07UF;01hEB/0NUL]07]H;P0207eJ<0P0NeP`0140NUL]07aI;`1oG380PEhd081M<`1mFS00NUL]07MD
:P1mDRD0OE@V07]E9P1kEbL0N5PW07IJ:01eFbP0LU/W07]H<00207YG;`0307UF;P1hEBd0N5D]0080
Me@/0P1fDb/02@1gE2`0N5D]07UF;P1jEbl0NeP`07aI<@1fERd0M5@[07=C:P02079B:@0;07=C:P1d
E2/0MUH]07=H;@1bEb`0LEH[071E:P1aER/0LUL/07AI;P1eFRl0201iERh0201aDR<0Le@U07EF9`1f
EbP0MePY07IG:01dEBH0Le@U0P1_E2T05P1aE2X0M5@[07IE;01gE2`0N5D]07YD;@1dE2/0Le<Z079B
:@1aDBP0L50W06m?9P1^CRD0KDdT07IA9`1eDRP0Me@/07ID;P1eEBl0LE<_06iB;@1]D2h206e@:080
KU4Y0`1_DRX0101`Db/0LDlY071>:01^C2H206e;9@0306i<9P1`CRP0LDlY00<0KU4Y0`1]D2P206a?
9`0307=B9`1dDbP0ME@Y0080ME@Y00H0Le8W075@9@1`Cb@0L5@/06mC:`1/D2P306Y>9P0406a@:01]
DBT0JdhV06Y=9@<0JD`T00<0JdhV06e@:01^DBT0201YCBP406U=9@<0JThV0P1[CbL02@1]DBT0K50X
06Y>9P1XC2@0Id/S06Q<901ZCRH0JdlW06E98@0206I:8P0306M;8`1XC2@0J4`T0080JDdU00<0JDdX
06Q<9`1VBRD00`1TB2<01@1VBRD0Id/V05m78@1PB280HDTS0080HTXT00H0HDTS06188P1OAb40GTHR
05m78`1RBRH306A<:003069:9P1QBBD0HD/V00L0HD/V201SBbL206E9900>06M;9P1YCBP0JdlZ06eA
;01^DRd0Ke<^06a@:`1]DB`0KU8]071D;`1aEC00LeLb07AH<`1eFC@207QC:@0:07UD:P1jEB/0NeH/
07aG;@1mF2h0OUT_07UG:@1kFB/0OE/]07mM;`80P5h`00P0Oed_07iL;P1oGBl0Oed_081N<021Gc40
PV0b08=Q<`80Q68d00T0Q68b08=Q<@22H300PV0`08AR<P26I3@0RFLg08]Y>@2>ICT00P2>ICL00`2?
IcH0SfLd091X=002091Y<P0908eX>`2=JCT0Sf/k095]>`2DL3`0UW<m09Md?02HMCd0U6lj0080UG0k
00<0Ug8m09Qc?P2IM3l00P2JMD001@2FLC`0V7<n09]f@@2NND@0X7]600<0XGa700<0WgY50:5lA`2R
ODP00`2TOdX00`2SOTT0XWe80:B0AP020:B0AP040:AoB02TOdX0Y7m:0:AoB`80YGm>102XPdl20:V4
D080ZXEA0`2^RE@20:n:E@<0/8]F00<0[8QD0:f9E@2_ReL00`2aSET01P2`S5P0[h]G0;JBHP2dT600
/HeM0:j:FP80[8QH0P2]RET80;>=GPP0/XeI0P2dSe/20;>>FP@0/XeI00<0]8mK0;:=F@2aS5P00P2_
RUH00`2aS5P0/XeI0;B?F`080;:=F@80]8mK0`2cSUX30;:=F@80/hiJ00L0/XeI0;6<F02`ReL0[hYF
0:j9E@2]R5@0[XUE0080[hYF00<0/8]G0;6<F02aS5P00P2bSET80;2;E`080;>>F@2bSEP0/8]F0:n:
E@2^RE@0[hYE0;2;EP2aS5L50:j9E@<0[HQD00@0/8]G0:n:EP2_RUH0[XUE0P2]R5@20:b7D`80ZhIB
00<0[8MC0:f8E02^RED00P2`ReL0102aS5P0/8]G0;2;E`2`ReL20:n:EP<0[XUE00@0[XUB0:n:D`2a
S5D0/HaE0P2bSEH00`2aS5D0[hYC0:j9DP080:f8D`<0ZXEA0`2[QU820:b7D`060:f7FP2]QeP0[HMH
0:f7EP2]R5@0[HQC0P2]R5430:j5D@80[hIB0`2^QE40202`QU@0[hEC0:j4DP2]Pe40[XAB0:n5D`2a
QeD0/hUG0P2/Qe<0102[QU80ZXEA0:Z5D@2YQ5020:R3C`0@0:V3E02ZQ5D0ZhEF0:b6E`2]QeP0[XQI
0:n9FP2`RU/0[XMN0:f6G@2[Q5T0ZH=F0:V3E02ZQ5<0ZhED0:f8E0P0[HQC202/PU080:b7DP80[HA@
0`2^QE430:n6DPD0ZhIB0`2/Qe<20;27D`80[hIB00@0[XEA0:f4D02]Q500[8=?202YQ5020;27D`04
0:n6DP2^QE40[8=?0:^2CP80ZX5=00@0[8=?0:f4D02]Q500[XEA0P2_QU820;27D`030:^6D@2/Qe80
[HQC0080[HQC00H0ZhIA0:V4C`2XPdh0[89@0:f3D@2_QE<30;26E0030:n5D`2]Pe40[89@00P0ZXE@
00<0[HQC0:b7DP2[QU400P2YQ4l00`2[QU40[8MB0:f8D`030:b7D`<0ZhIB0P2ZQE40102bRED0/HQD
0:n6DP2]Q5020:b3C`030:f4D02^QE40[XEA00L0[XEA00<0/8ID0:n5D`2]Pe400P2/PU000`2]Pe40
[hEC0;26E0020:f4D0<0[8=?0`2[PTh80:b2D0P0[XEA00P0[hIB0:j5D@2]Q500[8=?0:f4D02`Qe<0
/hYF0;F<F0<0[XEA0P2]Q5030:b3C`030;B:F02bR5H0[XAB0080[89@00<0[XAB0;:8EP2dRUP00`2/
Qe<30:^6DP80ZXEA0P2`QU@20:n5D`040:j4DP2]Pe40[H=A0:b2D0P0[HQC0P2`QUH0102`QU@0/8MC
0;27D`2`Qe420;27C`030;27D`2_QU80[XEA0080[8=?00H0[XEA0:n6DP2`Qe<0[HQD0:b7D`2ZQE42
0:R3C`030:V4D02ZQE40ZhIB00T0ZhIA00<0/8ID0:n5D`2]Pe400P2[PDl00`2/PU00[H=A0:j4DP08
0:f4CP060:n:E@2^RE@0[XUD0:f8D`2/Qe80ZhIA0P2ZQE000`2]R5@0[8MC0:Z5D@020:V4D0030:Z5
D@2/Qe<0[HQD0080[HQD0P2/Qe<0102[QU80ZXEA0:Z5D@2YQ5020:f8E080[8MC00X0ZhIB0:Z5D@2Z
QE40ZHA@0:Z5D@2ZQ5<0ZhED0:^5EP2[QEP0[8EJ0P2/QE`00`2]Q500Zh9>0:Z1C@020:QoB`030:Z1
C@2[PTh0[HA@00<0[8MC1@2[QU820:n5D`040:j4DP2]Pe40[H=A0:b2D080Zh5?202]Q5080:Z5D@80
[XAD00@0[XAB0:j5D@2^QE40[XE?0P2^QDd80:f3D`<0Zh5?0`2/PU020:f3D@<0Zh9>0`2/Pdl20:f4
D0<0Z8=<0`2YQ4d20:Z5CP<0ZhIB0P2ZQE430:V4D080ZX1>0P2[PDl01@2/PU00[H=A0:f3D@2]Pe40
[XAB00<0[89@0P2]Pe430:j4DP<0Z8=<0`2YQ4d20:Z5CP@0ZX5=102[PTh30:V4D0030:R3C`2WPTh0
YX5=0080YX5=00P0[85F0:^0D`2ZOe80ZGm?0:Z0CP2/Pdl0[hI@0;27D@80[XUD00L0[HQC0:b7DP2[
QU40ZXE@0:V4C`2XPdh0ZhIB00<0ZXEA0P2YQ5020:R3C`80Yh9>0P2XPdl0202YQ500ZXEA0:Z5D@2[
QU80[XUE0:b7D`2ZQE40Z8=?0P2VPDd20:N2CPP0[89@00H0[XEA0:f4D02/Pdl0Zh9>0:Z1C@2YP4`2
0:QoB`80ZX5900@0ZX5;0:Z1C@2YP4`0ZGm=0P2XOTh00`2[PE40ZX1@0:QnCP020:MmC@060:QnCP2Z
P500Zh5A0:IlBP2WOD/0ZGm=0`2[PDl01`2ZP4h0ZGm=0:N6D02WQU00Z8E?0:V4C`2ZPTh00P2[PTh0
102/PDh0XgY60:ElB02WOTX20:V0C0030:QoB`2WOTX0YWe900P0Z7i>00P0[89@0:^1C`2YOdd0Yge;
0:AjB02RN4H0X7I409me@`80Yga90P2VNdP01@2UNTL0Y7U60:AiAP2TNDH0XgQ50080VgI200@0WGQ4
09mjAP2QO4P0Xgi:0P2UP4`01@2RODT0X7]709iiA@2LMd<0VgI20080W7M30`2MN4@209iiA@0409mj
AP2PNdL0X7]70:5lB080YG]900@0XgU70:9hAP2PMT@0WWA20P2LLT000`2NNDD0WgY60:1kA`020:5l
B00309mjAP2MN4@0VgI20080VWE100<0VgI209ag@`2MN4@00P2NNDD01`2ONTH0W7=509edAP2KMDH0
VWI609]gA`2IMdL00P2INDP01P2RODT0XGa80:5lB02ONTH0WWU509ehA080W7M30`2ONDX309ihB@80
WGM80`2NND@[ooooo`00:_ooool8095T>P80Sf8h0`2@HcT3095T>PP0TfLj0P2CIS`209AW?@0509EX
?P2FJCl0UVTo09IY?`2GJch00P2FJSd209EY?080U6Pk00@0TfLj09MV>`2HIc`0VVTn0P2KJSl01P2J
JCh0VFPm09QW?02JJCh0VFPm09MV>`<0UF@i00<0UfHk09QW?02HK3/00P2HK3/509M[>P80UVXi0P2G
JcX209Q/>`@0VFdl0P2HK3/309M[>P80UVXi202IKC`209U^=`0409U^>@2IKS/0VFhk09U]?080VFdn
202IKcd209Q/>`0409U]?02JKSd0VVhm09]_?P@0W70o0P2KKch0102LL3l0WW910:1d@`2RMTD209ea
@P0409ea@02MLSl0WG8o09eb?@80WG8k1@2OM44309ic@0<0X7E20`2OM44209ic@0P0WWE1202RMd@8
0:1e@PP0XWU5202UNTL00`2PMd<0XGQ40:5hA0020:9iA@80XgY60`2TNdL20:ElB080YWe90P2WOTX0
0`2UO4P0YWe90:MnBP020:QoB`030:MnBP2VODT0YGa80080YGY30P2TND80102SN440XWM00:5f?`2Q
MSl20:5h@P060:1g@`2PMT@0WgE509icAP2MLTD0WG970P2MLd4209ab@00309]a?`2JL3h0VW0n0080
VFlm0P2GKC/00`2FK3X0UF/i09AZ>00209=Y=`06099X=P2AK3P0TF`h091[=`2?JSH0SVTe0P2=J3@0
1P2<Ic<0RF<f08US=P28HSD0Qf4d08IP<`80QElb00<0Q5ha08AO=@23GS@00P23GS@2089M<`80PE`b
00H0PU`e085K=021Fc@0P5Xc07mI<P1nF34207eG<00D07MD;P1hEBl0NEH`07YG<@1iES00Me@^07EB
;01dDB/0MEHZ07AE:@1cDbX0LU8[075A:`1_CR/0KTdZ06i=;01dDc00LU4^06m>:`1/BbP206]:9`07
06e<:@1_CR/0JdPX06]8:01ZBBP0J4XX06M::00206E;:00506A<:01RB2L0HTPW06989`1QAbH00P1P
ARD205m5900306538@1SAB<0ITPV0080J4XX00<0ITPV06948P1P@R001@1XAb@306M68`0806M;9P1X
C2L0JD/W06a;:01^C2T0L4`Z075=:`1cC2/2075;9003079<9@1cCBH0M4hW0080MU0Y00H0Me4Z07QA
:P1hDBX0NE8[07YC;01kE2d207aE;P0407eF;`1jDRh0Ne<_07eE<@80OUHb00D0OEDa07aD<01kDbl0
OeT/07iH:`0307eG:P0307mI;021Fbh0PU`_0080Q5lb1023GS4208AO<P0508AN<@25Gc80QElb08IP
<`28HSD00`29HcH0102:I3L0Qf4d08MQ=027HC@208QR=@<0RF<f2026H3<00`27HC80R68c08US=002
08YT=@0308QR<`26H340QEl`00<0QV4g0P25H3H308AO=@P0R68e00<0QEl`08IP<@26H3400P27HC82
08QR<`0B08US=025Gc00QV0a08QR<`2:I3D0RfDf08YT=@29Hc@0R68c08QR<@27HC00QV0a08IP<`27
H3D0R64h08YS>P2;I3d0RV@e0P29Hc@208QR<`80Qf4b00@0QV0a08AN;`25Gc00QEl`0P26H34208MQ
<P0408QR<`2<HCH0Rf0e08UN<`80R5db00<0REhc08]P=@2<HCH00P25H3<01024Gc80Peha089M<021
G2l2081K;PP0PE/^00<0Peha089M<022GC001@22GC0208MN<P0408EO<P24Gc80Q5lb089P<P80PF4b
00<0OeX]081K;P20Fbh00P21G2l2089M<00408=N<@1kFB/0OE/]081N<080PV0b00@0P5h`07iL;P1l
FR`0OUT_0`1oFS02081K<@80PE`b00<0OU/a07eJ<01kF2h00`1jEbd307]H;PP0NeP`00<0NUL]07aI
;`1oG3800P20GC<00`1mFS00NUL]07MD:P0207aC9@0407]E9P1hERH0N5PW07EI9`80ME/X0`1jEbl0
0`1iERh0N5D]07QE;@0207MD;080MU<[00@0Me@/07QE;@1iERh0NUL_0P1kF3000`1gEbh0MED/07AD
:`0207=C:P0;07AD:`1eEB`0MeL^07=H;@1bEb`0LEH[071E:P1aER/0LUL/07AI;P1eFRl0201iERh0
0`1bDbD0Le@V07EF:00207IG:@0307EF:01dEBL0Le@V0080L5DZ00<0LE@Z07AD:`1eE2/00P1gE2`0
1`1iDb`0Le<Z07=C:P1bDRT0LE4X071@9`1_CbH00P1^CRD0201fDBL0ME8X07IC:`1fE2h0M5@^075C
;`1^DRd0KE0^0`1]D2P206iA:@<0Ke8Z00<0LDlY071>:01^C2H00P1]BbD00`1^C2H0L4hX075?:@03
06iA:@80KE0X0`1/CbL02`1aD2D0LU4V07=B9`1dDbP0Le8W079A9P1`Cb@0KdhS06mC:`1^DRX0K50X
00<0JThV00@0JdlW06a@:01[CRH0JTdU0`1YC2@00`1[CRH0KE0X06iA:@0806U=:0@0JDdU0`1ZCRH2
06]?9`0306Y>9P1YCBD0Id/S0080IDTQ00<0ITXR06M;8`1XC2@00P1VBR8206M;8`80J4`T0P1YCBD0
2`1YCBP0J4`W06I:9@1UBB@0I4PS06E9901VBRD0Id/V05m78@1PB280HDTS0080Hd/U00/0HDTS0618
8P1OAb40GTHR0618901RBRH0Hd/W06A<:01SBbL0HTXV06599@08065;9PP0Hd/W101ZCRT406U=:006
06]?:P1/D2/0KE4/06iB;@1`E2l0LED`0P1cEc801P1eDRP0MU<Y07MD:P1hEB/0NEH/07YG;@80NeP^
00@0NELY07]I:`1mFbd0Oed_0P20GS001`1oGBl0OU`^07mM;`1oGBl0P5h`085O<@22H3800P23HC<0
0`24HS@0Pf4a08=Q<@02089P<00508AR<P26I3@0RFLg08]Y>@2>ICT00P2>ICL00`2?IcH0SfLd091X
=002091Y<P0808eX>`2>JSX0Sf/k095]>`2CKc/0UG8l09Ic>`2GM3`209A_>P0;09E`>`2FLC`0Ug8m
09Qc?P2IM3l0VWE009Ia?02HLch0VgI109iiA02PNdH00`2QO4L00`2ONTD0X7]60:9mB0020:AoBP03
0:=nB@2RODP0XGa700<0Y81600L0Y7m80:F0B`2UP4/0YX5=0:J0C`2WPE00Yh9>00<0Z8=?0P2YQ502
0:Z5D@040:f8D`2^RE@0[XUD0:j9E080[hYE0P2`ReH00`2/R5@0[HUE0:n;E`020;6=F@070;2<F02_
ReL0[XYF0;B@H02bSUh0/8aL0:j:FP020:f9F@030:j:FP2_Re/0/heN00L0/heN202bSET20;B?F`80
/hiJ0`2bSET0102aS5P0/hiJ0;:=F@2aS5P20;2;E`030;6<F02bSET0/hiJ00P0/XeI0P2dSe/30;>>
FP<0/XeI0P2cSUX0102bSET0/HaH0;2;E`2_RUH20:j9E@<0[hYF00<0/8]G0;6<F02aS5P00P2bSET8
0;2;E`030;>>F@2bSEP0/8]F0080[XUD00<0[hYE0;2;EP2aS5L01P2^RED20:f8E0<0[hYF00<0[XUE
0:f8E02]R5@00P2/Qe<01@2[QU80[8MC0:b7D`2]R5@0[hYF0080/8]G00@0/HaH0;2;E`2`ReL0/8]G
0P2_RUH30:j9E@040:j9DP2_RU<0/HaE0;6<E@80/XeF00<0/HaE0:n:D`2^RE80202]R5<30:^6DP80
[8MC0`2]R5@01P2^R5/0[XQI0:j8F@2^R5L0[XUE0:j9E080[XUB202^QE40202`QU@0[hEC0:j4DP2]
Pe40[XAB0:n5D`2aQeD0/hUG0P2/Qe<20:^6DP040:Z5D@2YQ500ZHA@0:V4D080ZXAE00@0ZhEF0:b6
E`2]QeP0[XQI0P2_REX0202_R5l0[XML0:b5FP2ZQ5L0ZH=D0:V3DP2ZQE40ZhIB202]R5<80:b2D0P0
[8MB0P2]Q5030:j5D@<0[hIB1P2[QU820:b7D`030;27D`2_QU80[hIB0080[XEA0P2]Q5000`2/Pdl0
ZHA@0:V4D0060:V4D0030:n6DP2^QE40[XEA0080[HA@0`2/Pdl30:f4D0030:j5D@2_QU80[hIB0080
/8MC00<0ZhIA0:b7DP2]R5<00P2]R5<01P2[QU40ZHA?0:R3CP2/PU00[H=A0:n5D`<0/8ID00<0[hEC
0:f3D@2/PU00202ZQE000`2]R5<0[8MB0:^6D@020:V4C`030:^6D@2/Qe80[HQC00<0[8MC0`2[QU82
0:Z5D@060;:9E@2`Qe<0[XEA0:f4D02/Pdl0[HA@0P2^QE480:n6DP030;26E02_QE<0[H=A0080[89@
00<0[H=A0:n5D`2`QU@00`2]Q5020:b3C`<0Zh9>202/PU080:j5D@80[hIB0P2^QE40102_QU80/8MC
0;68E02bRED30:j5D@<0[HA@0P2/Pdl00`2cREL0/HME0:j4DP020:b2D0030:j4DP2aQeD0/hUG00<0
[8MC0`2[QU820:Z5D@80/8ID0P2_QE<20:j4DP80[H=A202]R5<20;26EP040;26E02`Qe<0/8MC0;27
D@80/8M?00<0/8MC0:n6DP2^QE400P2/Pdl01P2^QE40[hIB0;27D`2]R5@0[8MC0:Z5D@80Z8=?00<0
ZHA@0:Z5D@2[QU802@2[QU400`2`QU@0[hEC0:f3D@020:^1C`030:b2D02]Pe40[XAB00P0[HA>0P2^
RE@20:f8D`070:b7DP2[QU40ZXE@0:Z5D02]R5@0[8MC0:Z5D@020:V4D0030:Z5D@2/Qe<0[HQD0080
[HQD0P2/Qe<01@2[QU80ZXEA0:Z5D@2ZQE40[HQD0080[8MC0P2[QU820:Z5D@060:V4D02ZQE40ZXEA
0:^5E02[QEH0ZhEH0P2/QEX0102/QE`0[HA@0:b3C`2ZPDd20:V0C0030:Z1C@2/Pdl0[HA@0080[8MC
1P2[QU800`2_QE<0[XAB0:j4DP020:f3D@80[89@00<0Zh5?0:f4D02]Q5001P2]Q5080:Z5D@80[XAD
00@0[XAB0:j5D@2^QE40[XE?0P2^QDd80:f3D`<0Zh5?0P2/PU030:f3D@<0Zh9>0`2/Pdl20:f4D0<0
Z8=<0P2YQ4d30:Z5CP<0ZhIB0P2ZQE430:V4D080ZX1>0P2[PDl00`2/PU00[H=A0:f3D@020:f3D@<0
[89@0P2]Pe430:j4DP<0Z8=<0P2YQ4d30:Z5CP<0ZX5=1@2[PTh20:V4D080Z8=?0P2WPTh20:J1C@09
0:f2E`2/PE@0Zh1C0:Z0D02ZP4h0[8=?0:j5C`2_QU00[HQC00<0[8MB00D0ZhIA0:Z5D02ZQE00ZXE@
0:Z5D@030:V4D080Z8=?0`2WPTh20:R3C`80ZHA@0P2ZQE401@2[QU80[HQD0:b7D`2ZQE40Z8=?0080
YX5=00<0Yh9>0:R3C`2/PU001`2/PU020:b3C`80Zh9>0`2ZPDd01`2YP4`0Zh9:0:Z1B@2ZPD/0ZX5=
0:V0C02YOdd00P2XOTh00`2[PE40ZX1@0:QnCP020:MmC@060:QnCP2ZP500Zh5A0:IlBP2WOD/0ZGm=
0`2[PDl01`2ZP4h0ZGm=0:N6D02WQU00Z8E?0:V4C`2ZPTh00P2[PTh0102[P4d0YGa80:ImB@2XOd/2
0:V0C0030:QoB`2VODT0YGa800P0Z7i>0P2[PDl01P2YOdd0Yge;0:EkB@2SNDL0XGM50:1fA080YWe9
0P2UO4P20:AkA`<0XgY600/0W7M309ehA02NNDD0WgY60:5lB02RODT0Xgi:0:AoB`2PNdL0WgY609ii
A@0309ag@`0409iiA@2ONTH0WGQ409ehA080WWU500X0WgY60:1kA`2PNdL0X7]70:AjB02SNDL0XWQ6
0:5gA@2PMT@0WgE30P2NM4801`2NNDD0WgY60:1kA`2QO4P0X7]709mjAP2MN4@01@2LMd<409ehA006
09edAP2NMDL0W7I709]gA`2LN4P0VWQ80P2JNTT01P2RODT0XGa80:1kA`2ONTH0WWU509ehA080W7M3
202MMdP309iiAB_ooooo000Zooooo`P0TF@j00@0Sf8h091S>@2@HcT0T6<i0P2AI3X2099U>`P0TfLj
00@0TfHl09AW?@2DIcd0U6Lm0`2EJ3h0102FJCl0UVXm09IZ?@2FJSd209EY?0<0U6Pk0P2HIc`02@2I
J3d0VVTn09YY?P2IJ3d0V6Ll09MV>`2JJCh0VFPm09MV>`0309IU>P80UfHk202GJcX0102FJST0Uf/j
09M[>P2GJcX309Q/>`80VFdl0`2HK3/409M[>P0309IZ>@2IKC`0VFdl00H0VFdl0P2IKSL0102IKST0
VFhk09U^>`2IKC`209U]?PP0VFlm202JKSd0202KKch0VVhm09Y^?@2JKSd0Vfln09ea@02NLT40Wg=2
0P2MLD80102MLD00WG8o09eb?`2MLSd209eb>`<0WG8o1@2NLd020:5f@`80X7E20`2OM4400`2NLd00
WgI209mf@P0609mf@PP0XWM4202QMT<80:9iA@P0YGY70P2QN4@20:9iA@@0XgY60P2TNdL20:ElB080
YWe90P2WOTX00`2TNdL0YGa80:MnBP020:QoB`030:MnBP2UO4P0Y7]700L0YGY500H0Y7U40:5h@P2Q
N480X7M309me@`2NM4@209ebA@0609aaAP2MLd40W79009ab@02KLCl0VW0n0P2IKcd209Q^?00609M]
>`2FK3X0UV`j09E[>@2DJSP0TfTg0P2BJ3H208iY=@80SFPd00D0S6Lc08]V<P2:IC40RVDa08US=P02
08QR=@0308MQ=026H3<0QElb0080Q5ha0`24GcD208=N=0<0PUdc0P21Fc@00`20FS<0OeTb07iH<@02
07eG<00307aF;`1hEBl0NEH`0080NULa00@0NEH`07QE;`1gE2h0MU<]0P1dEBT01P1cDbX0LE4Z071@
:P1_CR/0KTdZ06e<:`80KTdZ0P1]C2T0101/BbP0JdXW06Y99P1ZBBH206]8:00306Y9:01XBRP0IdXX
0080ID/X00@0I4`X06E8:01UB2P0IDPX0`1TAbL206=69P030612801RA280I4HT0080ITPV00<0I4HT
06948P1P@R00201WAR<0201VBRD0Id/V06Q:9P1[BRL0KD/X06m;:@1`C2X0LT/Z0P1cCBH207A>9`05
07E?:01fD2T0Me4Z07MA:P1gD2T00P1hDBX00`1iDR/0NU</07]D;@0207aE;P0407UB:`1jDb`0O5D^
07iG<080OePa00X0OUL`07eF;`1nF2/0OUP[07eG:P1nF2/0OeT/085K;P23GC00QElb0P23GS4408AO
<P80Peha0P25Gc801026H3<0Qf4d08MQ=028HSD308US=P0408IP<`27HC@0Qf4d08MQ=080R68e0P29
HcH808IP<`0308EO<026H340R68c00<0RF<d00<0R68c08MQ<P27HSP00`26HCL208EP=P80Q5le2029
HcH308IP<@80Qf4b0`28HS<00`27HC80R68c08YT=@0308]U=P80RV@e0P28HS401P26H340QV0c08IO
=028HCP0RF8i08]T?@80RF<d0P28HS<408MQ<P80QEl`0P26H34408MQ<P0308aQ=P2;H3D0REhc0080
R5db00<0REhc08]P=@2<HCH00P25H3<00`24Gc80Peha089M<002085L;`03081K;P21Fbh0PE/^00H0
PE/^0P24Gc8208=N<@04089M<021G2l0P5/^081K;P80QE``00@0Ped`089M<022GC00P5h`0P1oGc03
081K;P80PE`_0`22GC0407mM;`@0OU`^0`1nFBl207mJ<0<0P5/a1@1lFBl0101kF2h0NUL]07UF;01i
ER`807]H<00307YG;@1lFBl0OU/a0080Oe`b00/0OEX`07YG;@1hEB/0NeDX07YD9`1iE2L0MeDW07MG
:01gF2T0METY07IJ:P0207YG;`<0NEH^0`1hEBd207IC:`0407MD;01hEBd0NEH^07UF;P80NUL_00<0
N5P_07MG;P1fERd00P1dE2/01P1fERd0MeL^07QH;`1dEbd0LeH/079E:`80LE@Z00<0LeH/07EH;P1f
FBl0201hEBd207=D:00;07AE:@1eERX0MEHZ07AE:@1cE2P0LU<W079G;01aER/0LUD[07AD:`1dDbX0
0P1eDRX01P1gDBX0Le<Z079B:@1bDRT0LE4X071@9`80KdlV00T0KThU07IA9`1eDRP0MU<[07EC;@1c
Dbd0L58^06iB;@1]D2h00P1/CbL206e@:0<0KU4Y00<0Ke8Z06m?:01_CbP0101]CBH206m?:080KU4Y
0P1]D2P306a?9`0906]>9P1^CRD0KdlV071@9`1aDBP0L50W06m?9P1]CB@0K4`S0080KE4Y00@0JdlW
06Y>9P1ZCRH0JThV0P1[CbL00`1[CRH0JTdU06U<900206U<900306]>9P1]D2P0KU4Y00P0JDdX101Y
CBD306Y>9P80JdlW00<0J4`T06M;8`1UBB400`1TB20206E98@<0Id/S0`1XC2@206U=9@0406U=:01X
C2L0Id/V06I:9@80IDTT00D0ITXU06M;9P1OAb40H4PR069:900206=;9@06069:901PB280GdLQ05m7
8`1PB2@0HTXV0`1SBbL2069:9PP0H4XU201RBRH03P1^DRd0KE4/06a@:`1ZCRT0J4`W06I:9@1UBB@0
I4PS06U=:01ZCRT0JdlZ06a@:`1^DRd0Ke<^0P1`E2l01P1eDRX0MU<[07IC:`1gE2`0N5D]07UF;P80
NUL_00<0NELY07YH:P1mFbd0101oGBl00`1nG2h0Oed_07mM;`02081N<004085O<@22H380Pf4c08=Q
<`<0PV0`00H0Pf4a08AR<P26I3@0R6Hf08YX>02;ICP208]U=P0308aV=@2<Ic<0SFPc0080SFPa00H0
SfXm08m[>`2@K3`0TFdk099^>P2CL3X209Aa>@80U6lj00@0UG0k09Ia?02GLSd0Ug8m0P2HLch01@2F
LC`0V7<n09Ye@02MN4<0WgY50080X7]600@0WgY509iiA02PNdH0XGa70`2SOTT00`2RODP0XGa70:9n
A0020:=oA@040:AoB02UP4/0Yh9=0:R3C`80ZH=B0`2WPTh20:R3C`<0ZHA@0`2]R5<20:j9E0<0[hYE
00/0[8QD0:f9E@2_ReL0/8aH0;6=F@2`S5P0[h]G0:j:EP2aSEd0/8aL0:n;F`020:j:FP030:n;F`2`
S5`0/8aL00P0/XaM202bSET30;>>FP80/XeI0`2aS5P00`2cSUX0/XeI0;6<F0020;2;E`030;6<F02b
SET0/hiJ00P0/XeI0P2dSe/30;>>FP<0/XeI0P2cSUX0102bSET0/HaH0;2;E`2`ReL40:n:EP<0/8]G
0`2aS5P80;2;E`030;>>F@2aS5L0/8]F00<0[XUD00<0[hYE0;2;EP2^RED01`2^RED20:n:EP<0[XUE
0`2]R5@20:b7D`030:f8E02^RED0[hYF0080/8]G00@0/HaH0;2;E`2`ReL0/8]G0P2_RUH30:j9E@04
0:j9E02_RUD0/8]F0;2;EP80/HaG00<0/8]F0:n:E@2^RE@0202]R5<30:f8E080[XUE0`2_RUH01P2`
RUd0/8YK0;2:F`2`RUT0/8]G0;2;EP80/8]D00<0[hIB0:j5D@2^QE40102^QE402P2_QU80/8ID0:n5
D`2^Q580[H=A0:j4DP2_QE<0/HME0;>9E`2/Qe<30:^6DP<0ZXEA00H0ZHA@0:Z4E@2[QEH0ZhEF0:b6
E`2]QeP20:j8F@060:n9FP2`REh0[hQM0:f7FP2[QEH0ZH=B0P2YQ5000`2YQ4l0[HQC0:f8D`060:f8
D`P0[89@202/Qe820:f4D0<0[XEA0`2_QU880:^6DP80[hIB0P2^QE440:f4D0P0ZHA@00@0[8=?0:f4
D02]Q500[HA@0`2^QE400`2_QU80[HA@0:f4D0030:j5D@<0[hIB0P2[QU430:f8D`060:^6D@2ZQE00
Z8=>0:f3D@2^Q580[hEC0`2`QU@00`2_QE<0[XAB0:f3D@080:Z5D0030:f8D`2/Qe80ZhIA0080ZHA?
00<0ZhIA0:b7DP2]R5<00`2/Qe<30:^6DP80ZXEA00P0/HQD0;27D`2^QE40[HA@0:b3C`2]Q500[XEA
0:n6DPP0/8MC00<0/8ID0:n5D`2^Q5800P2]Pe40102^Q580[hEC0;26E02^QE430:f4D080[8=?0P2[
PTh80:b2D0P0[XEA00<0[hIB0;27D`2aR5@00P2aR5@00`2_QU80[XEA0:f4D0020:n6DP80[XEA0`2]
Q500102/Pdl0/HME0:n5D`2]Pe420:^1C`030:f3D@2_QE<0/HME00<0[8MC0`2[QU820:Z5D@80/8ID
0`2_QE<30:j4DPP0[HQC0P2`QUH0102`QU@0/8MC0;27D`2`Qe420;27C`030;27D`2_QU80[XEA0080
[8=?00H0[XEA0:n6DP2`Qe<0[HQD0:b7D`2ZQE420:R3C`030:V4D02ZQE40ZhIB00T0ZhIA00<0/8ID
0:n5D`2]Pe400P2[PDl00`2/PU00[H=A0:j4DP080:j5D@060:j9E02]R5<0[HQC0:b7DP2[QU40ZXE@
0P2YQ4l00`2]R5@0[8MC0:^6DP020:Z5D@030:^6DP2/Qe<0[HQD00<0[8MC0`2[QU820:Z5D@80[8MC
0P2[QU840:Z5D@060:Z5D02ZQE40ZhIB0:^5E02[QEH0[8II0P2/QEX20:b3C`040:^2CP2ZPDd0ZX5=
0:^2CP80[8=?202[QU830:j4DP80[H=A0`2/PU080:f4D0P0ZXEA0P2^Q5@0102^Q580[XEA0:j5D@2^
QDl20:j5C@P0[H=A0P2[PDl20:b2D0<0[H=A00@0[XAB0:^2CP2[PTh0Zh9>0`2/Pdl20:f4D080Z8=>
0P2YQ4l30:Z5D0040:^6D@2[QU80ZhIB0:^6DP80ZXEA0`2YQ5030:^1C`@0[89@0P2]Pe430:b2D080
[H=A0`2^Q5820:R3CP80ZHA?0`2ZQE000`2[QU40Zh9>0:^2CP060:^2CP040:V4D02XPdl0Z8=?0:R3
C`<0Yh9>00T0YX5=0:n4F@2^PeH0[85D0:^1D@2[PDl0Zh9>0:b3C@2]Q4h00P2ZQE030:^6D@<0[8MB
00@0ZHA@0:R3C`2XPdl0Z8=?0P2WPTh20:J1C@80Z8=?0P2YQ5040:Z5D@060:f8E02[QU80ZHA@0:N2
CP2VPDd0Yh9>0P2XPdl80:^1C`<0ZX5=0P2[PTh30:b3C`80Zh9:00@0Zh9<0:Z1C@2ZPDd0ZGm=0P2Y
Odl00`2[PDl0ZX1>0:UoC@020:QnC0060:UoC@2ZP4h0Zh5?0:IlBP2WOD/0ZGm=0`2[PDl01`2ZP4h0
ZGm=0:J5C`2VQDl0Z8E?0:R3CP2ZPTh00P2ZPDd00`2[P4d0Z7m;0:V0C0020:V0C0040:QoB`2WOTX0
YGa80:AkA`P0Yge;00P0Zh5?0:Z0CP2YOdd0Yge;0:EkB@2SNDL0XWQ60:5gA@80YWe90`2UO4P40:Ak
A`80WgY60P2PNdL20:5lB080XWe900<0WgY609iiA@2MN4@00P2LMd<00`2NNDD0X7]70:5lB00309ii
A@<0WgY60P2PNdL80:5gA@80WgY60`2PNdL00`2ONTH0WGQ409ag@`0209iiA@<0WGQ40`2LMd<01P2N
MDL0WgI809egB02LN4P0WGU909]iB@80Vg]:0P2QO4P00`2PNdL0WgY609iiA@0209ehA00409ag@`2J
M4D0VWA509]eAP80W7I700<0WGM809ihB@2NN4T00`2NNDD[ooooo`00:_ooool8095T>P<0T6<i0P2A
I3X3099U>`P0U6Pk202DIcd809EY?0D0VFPm00<0V6Ll09MV>`2GIS/00P2IJ3d209QW?0@0UfHk102F
JST809M[>PP0V6`k1@2GJcX809U]?080VVlh00@0VVlj09Y_?02JKc`0VVhm0P2JKSl809U_?@<0Vfln
0P2JKSd309U]?0@0VVhm0P2KKch01@2LL3l0WG5009ea@P2MLD80WG500080WG8o00<0WG8m09eb>`2M
LS/00P2LLCh409eb?`80WW=00`2QMT<20:1e@P<0WgA1202OMT880:9gA0P0XGI3202RNDD80:AiAP80
XWU51P2SNTH20:AkA`80YGa80P2VODT20:MnBP030:AkA`2UO4P0YWe90080Z7m;00<0YWe90:ElB02T
NdL00`2UNTL30:IkB080Yga900P0XGQ20:1g@@2PMd<0WgE309idA02MLTD0W75409aaAP80W79000<0
Vg4o09Y`?P2IKcd00P2HKS`209M]>`0609I/?02EJc/0UF/k09AZ>P2CJCT0TVPh0P2AIcL208aV=@03
08]U=02:I3<0RF<b0080R68a00@0Qf4`08QR=@28HSD0Qf4d0P26H3<00`25Gc80Q5ha08AN<@0408AO
=@80Pehd0P22GC<2081J<`0307mI<P1nF340OEL`0080O5H_00<0NeD^07QE;`1iES000`1iES0307QE
;`80Le@X00h0LU8Y071@:@1_CbT0KTdZ06e<:@1/BbX0JDPU06Y99P1/BbP0KD`Y06a;:01ZBBH0J4LT
06I58P80JTLW00<0JDPW06M99`1VBBL00P1TBRL0101SBbL0ITTY06I9:@1VBBT506E8:00305m17`1Q
@b40HdDS0080IDLU00<0I4HT06948P1Q@b400`1VAB8406M68`0906Q7901VBRD0Id/V06Q:9P1[BRL0
KD/X06m;:@1`C2X0LT/Z00<0MDlX00<0MU0Y07MA:P1gDBX00P1hDR/207M@:@0407QA:P1iDR/0NU</
07]D;@80O5D^00@0NE8Y07YC:P1mERd0OeP_0`20FC00301oF2l0OELZ07eG:P1nF2/0P5X]089L;`24
GS40QElb08IP<`22GC00Peha08AO<P80QF0c00@0Q5lb08=N<@22GC00QElb0P26H3<208MQ=0<0R68e
00<0RF<f08IP<`26H3<00`27HC@308QR=@P0Qf4d0P25Gc000`26H340Qf4b08QR<`0308US=080Qf8h
0`26HCL308EP=PP0RV@g2027HC800`29Hc@0RV@e08YT=@0308]U=P80RV@e00P0RF<b08QR<@26H340
QElb08IO=027H3L0R64h08UR>`80R68c1P27HC8208IP<@H0Qf4b00<0Rf8f08YQ=@28Gc<00P27GS80
1028Gc<0RV4e08]R=P26HC@208EP<`0308AO<P23GS40PUd`0080PE`_2022G2l01P26HC@0QF0c08AO
<P23GS40PUd`081K;P80OeX]0P24Fbl01022G2l0PE`_085L;`1oGBl207iN;`P0PE`_00P0PEla081N
<01mFbd0O5X/07]I:`1lFR`0OU`^081N<0<0OUT_0`1oFS02081K<@0307]H;P1lFBl0OEX`0080OEX`
00@0NeP^07YG;@1hEB/0N5D[201kF3000`1jEbd0O5T_07eJ<00207iK<@0407aI;`1jEbd0N5D[07YE
:@80MeDX00D0MU@W07IE:01gERT0N5LZ07UH:`0607UF;P80N5D]0P1fDb/207MD;00707QE;@1iERh0
NEH^07UF;P1iFC00N5P_07MG;P0207EE;00;07MG;P1hF2l0NET`07EE;01dE2/0Le<Z079B:@1cDbX0
M5@[07IF;@1hF2l0201hEBd507AE:@0;07=D:01bDbL0LU<W07=H;@1bEb`0LeH/07AD:`1dDbX0M54Y
07=@:01eCbP00P1bDRT2075A:080L50W0P1_CbH0201gDRP0ME8X07EB:P1dDR`0LU8/06mA;@1^DRd0
KE0^0P1[CRH206a?9`<0KE0X00<0KU4Y06a?9`1/CbL01P1/CbL306e@:0<0K4lW0P1[CRH0201ZCBD0
JdhV06a?9`1]D2P0K4lW06]>9P1YC2@0J4/S0P1[CbL606Y>9P0306]>9P1ZCBD0JD`T0080JD`T00<0
JdhV06e@:01^DBT0201YCBP406U=9@<0JThV0P1[CbL206U=9@0306Q<901WBb<0Id/S00<0Id/S1P1X
C2@206U=9@0406U=:01XC2L0J4`W06M;9P@0ITXU00<0H4PR06598`1RBR@00P1SBbD00`1RBR@0HDTS
06188P0206599@H0HTXV201PBRD8069:9P0906eA;01/D2/0JdlZ06Y>:@1XC2L0Id/V06I:9@1UBB@0
J4`W0080JDdX00D0JThY06]?:P1]DB`0KE4/06iB;@0207AB;080ME<]00P0MU@^07ME;`1gEBl0MeD_
07UG:@1jF2X0O5X/07iL;P80Oed_00P0OU`^07eK;@1nG2h0OU`^07mM;`20GS00PEla089P<P80Pf4c
0P21Gbl01022H300Pf4a08ES<`26I3@208QV=P0608UT=`29ICD0RVHf08YV=02:IS80RfPb0P2;J300
1P2?JSd0Sf/k091/?02@K3X0TFdi095^>080TVlg0`2DKcX00`2EL3/0UW4l09Ia?00209Mb?@0409Ia
?02GLSd0VWE009ag@P@0WWU400T0WGQ309mjA@2QO4L0XWe80:=nB@2RODP0XGa70:1kAP2QOD<00P2R
OT@01P2SOTL0YH1;0:N2C@2YQ500ZXAC0:^5E0<0Yh9>0`2XPdl20:V4D0<0[8MB0P2]R5<30:j9E003
0:^7D`2/R5@0[XYF00<0/8aH00<0[h]G0:j:EP2^RUX00`2^RUX0102_Re/0/8aL0;6=G@2bSUh80;:<
G@P0/XeI0P2cSUX30;:=F@<0/HaH0P2bSET40;6<F080/XeI202cSUX20;B?F`<0/hiJ0`2bSET20;>>
FP80/XeI00<0/HaH0;2;E`2`ReL01`2`ReL20;6<F0P0/8]G00P0/XeH0;6<E`2_RUD0[XUD0:f8D`2^
RE@0[hYE0;2;EP<0[HQD102^RED00`2_RUH0[XUE0:j9E@040:j9E@@0[HQD0P2^RED00`2_RUH0/8]G
0;2;E`040;2;E`80[hYF0`2^RED0102]R5@0[hYF0;2;E`2`ReL20;6<F0030;2;E`2_RUH0[HQD00P0
[XUD0P2^RED20:n:EP<0/8]G00L0/HaH0;6;GP2aRe`0/H]L0;6;FP2aS5P0/HaG0080/HaE00<0/8MC
0:n6DP2^QE400P2]Q5002`2^QE40[hIB0;27D`2`QU@0[hEC0:j4DP2]Pe40[XAB0:n5D`2aQeD0/hUG
00P0ZhIB0P2[QEH20:b6E`80[HMH0P2^R5T0202`RUd0[hUL0:f7F02/QUD0ZXEA0:V4C`2XPdh0Z8=<
202]R5<80:f3D@P0[8MB0P2]Q5030:j5D@<0[hIB0`2/Qe<40:^6DP030:Z5D@2^QE40[XEA00H0[HA@
202YQ5020:^2CP040:b3C`2]Q500[hIB0;27D`80/HQD1P2^QE420:n6DP030:Z5D02[QU40[8MB0080
[HQC00<0[8MB0:Z5D02YQ4l00`2^Q5830:n5D`<0[XAB202ZQE000`2]R5<0[8MB0:^6D@020:V4C`03
0:^6D@2/Qe80[HQC00<0[8MC0`2[QU820:Z5D@070;27D`2_QU80[XEA0:f4D02/Pdl0[HA@0:n6DP09
0;27D`030:n5D`2^Q580[XAB00@0[XAB00<0[hEC0:j5D@2^QE400`2]Q5030:b3C`P0[89@202^QE40
202`Qe<0/HQD0;:9E@2cRUH0/XUE0:n6DP2/Pdl0ZH1<0`2_QU820:j5D@<0[HA@00<0/8ID0:j4DP2]
Pe400P2[PDl00`2]Pe40[XAB0;26E0030:b7D`<0ZhIB0P2ZQE420;26E0H0[hEC202]R5<20;26EP04
0;26E02`Qe<0/8MC0;27D@80/8M?00<0/8MC0:n6DP2^QE400P2/Pdl01P2^QE40[hIB0;27D`2]R5@0
[8MC0:Z5D@80Z8=?00<0ZHA@0:Z5D@2[QU802@2[QU400`2`QU@0[hEC0:f3D@020:^1C`030:b2D02]
Pe40[XAB00P0[XAB0P2]R5<0102/Qe80ZhIA0:Z5D02YQ4l20:R3CP030:b7D`2[QU80ZhIB00@0ZhIB
0`2/Qe<80:^6DPH0ZXEA00H0ZXE>0:Z5D02[QU40ZhIB0:^5E02/QUL20:b6F@80[8=?102[PTh20:b3
C`030:Z5D@2[QU80ZhIB0080ZhIB0`2/Qe<80:f3D@P0[HA@202ZQE420:j4E0040:j4DP2^QE40[XEA
0:j5C`80[XE=202]Q5030:b2D0<0[H=A0P2^Q5830:^2CP<0[8=?0P2]Q5030:V4D0<0ZXEA1@2[QU82
0:Z5D@<0ZHA@0P2[PDl:0:b2D080[H=A0`2^Q5830:V4D0<0ZXEA0P2[QU840:b3C`@0Zh9>102XPdl4
0:N2CP060:n4F@2_Q5L0[X=F0:f3D`2/PU00Zh9>0P2[PT`01P2XPdh0ZHA?0:Z5D02[QU40[8MB0:f8
D`80[XUD0P2XPdl20:N2CP@0YX5=0P2YQ5060:Z5D@030:b7D`2[QU80ZHA@00<0Yh9>00<0Z8=?0:V4
D02[PDl01`2[PDl0202XOd/0ZH1<0:Z1C@2[PTh0[8=?0:f4D02^QE40[hIB0P2[PTX0102[PT`0ZX5=
0:Z1C@2ZP4h20:UoC`030:Z1C@2YP4`0ZH1<00@0ZH1<00@0ZX5=0:IlBP2WOD/0ZGm=0`2[PDl01`2Z
P4h0ZGm=0:J5C`2VQDl0YhA>0:R3CP2ZPTh00P2ZPDd02@2[P4d0Zh9>0:^2CP2ZPDd0ZH1<0:QoB`2V
ODT0YGa80:AkA`080:MnBP080:Z0CP2YOdd0Z7i<0:MmB`2VO4X0YG]90:AjB02SNDL20:EmB@L0Y7a8
0P2RODT40:5lB080X7]700P0WWU509ehA02LMd<0W7M309ehA02ONTH0XGa80:=nBP80WWU51P2ONTH2
09me@`040:1fA02QMdD0XWQ60:=iA`80Y7Y80`2PNdL209mjAP80WWU500L0WGQ40:1kA`2ONTH0WgY6
09iiA@2MN4@0W7M30080VgI20P2OMTP0102NN4T0WGU909ijBP2LNTX209]kBP<0X7]700<0WgY609ii
A@2NNDD00P2MN4@0202HLT<0VG=409YdA@2KMDH0W7I709egB02NN4T0WgU:0`2NN4L[ooooo`00:_oo
ool8095T>P80T6<i0P2AI3X2099U>`80TfHl202DJ3/409AW?@@0TfHl202EJC`0102JJCh0VFPm09QW
?02HIc`409MV>`@0VFPm0P2HIc`209MV>`0309AX=`2EJCP0UFTh0080UVXi0P2GJcX509Q/>`P0Uf/j
1@2HK3/809U]?080VVlh00@0VVlj09Y_?02JKc`0VVhm0P2JKSl809U_?@<0Vfln0P2JKSd409U]?080
VVhm1@2KKch209ea@P0409ea@02MLSl0WG8o09eb?@80WG8k0P2LLCh209eb?`80WW=00P2OM4420:9g
A080XGI30P2PMD8209md@@P0X7M3402RMd@80:9iA@P0Y7U60P2TNdL60:=jAP80Y7]70P2UO4P20:Im
B@80Ygi:00<0XgY60:ElB02VODT00P2WOTX00`2VODT0YGa80:=jAP030:EjA`<0YW]80P2WO4T20:1g
@@0309mf@P2NM480WG=30080W75400H0Vg1509]a?`2KLCl0VW0n09U_?@2HKS`209M]>`80UV`j00H0
UFXm09AY?02DJC`0TfPk099W>P2AIST2091U>00608]U=P2:I3D0RV@e08US=028HS<0Qf4b0P26H342
08QR=@0408MQ=026H3<0QElb08AN<@80Ped`00@0Q5le08=N=023GS@0Pehd0P22GC<2085L<P80OeTb
00<0OUPa07eG<01lERl00P1kEBh00`1jE2d0N5D_07MD;P0307MD;P<0N5D_0P1bDbL03P1aDBP0L50Y
06i>:01]C2T0K4/X06]::@1WAR<0J4LT06]:9`1]C2T0K4/X06Y99P1WAR<0ID@Q0P1ZAbL00`1YB2L0
IdTW06I99`0206A:9`0306=;9`1VAbP0ITLX00<0ITLX0`1WB2T01@1P@R00HD<Q06=58`1TAR@0IDLU
0080I4HT00<0HdDS06I58P1VAB800P1WAR<0301XAb@0JDPU06U89@1YB2D0Id/V06Q<9`1YBbL0K4/X
06i<:@1`C2X0LDd[07=<:`<0Me4Z101hDR/01P1iDb`0N54Z07QA:P1iDR/0NU</07]D;@80O5D^00D0
OEH_07UB9`1kE2T0OEH[081I;P03085J;`07081I;P1nF2/0OeT/081J;@22G2l0Q5ha08IP<`0208MQ
=003085L;`23GS40Q5lb0080QV4d00<0Q5lb08=N<@21G2l00P26H3<408MQ=0<0R68e0`26H3<308MQ
=080R68e2027HC@308EO<00308IP<@27HC80R68c0080RF<d0`27HSP308IQ=`80QF0f202:I3L808MQ
<P0308]U=P2:I3D0RV@e00<0RF<d0P2:I3D02029Hc80R68a08IP<@25Gc80QEhc08IO=P27H3L0R64j
0P26H34608MQ<P80R68c1P27HC800`29HcH0R68e08IP<`0208EO<P0308IP<`28HSD0RF<f0080QV4d
00<0QF0c08AO<P23GS400P22GC000`21G2l0PU`_089L;`06089L;`0608IQ=025H3<0Q5lb08=N<@22
GC00P5/^0P1oFRd208=J;P04085K;P20Fbh0P5/^07iL;P80OEd^2021G2l00`23HC<0P5h`07eK;@02
07YH:P0307]I:`1nG2h0Oed_0080OEP^0`1nFBl307mJ<0D0O5T_00@0NeP^07YG;@1iER`0NEH/201k
F30207]H;P0>07aI;`1mFS00O5T_07]H;P1iER`0N5D[07MF:`1fEBX0ME@Y07AC:01eDRP0Me@Z07UF
;01mF2h207QE;@H0NEH^00<0MU<[07MD;01gE2`00P1gE2`307QE;@0307UI<01hF2l0MeL^0080MED/
00H0MeL^07QH;`1iFC00MUD/07ED:`1dDbX207=B:@0307ED:`1gERd0N5L^00P0Me@/00@0MED/07AD
:`1cDbX0Le<Z101bDRT2079G;003079E:`1cDbX0Le8Y0080Le0X00<0M4hW075A:01aDBP00P1aDBP4
071@9`0907MB:01eDRP0M54Y079@:P1aDB/0Ke4]06iB;@1^DBl0JTdU00<0JdhV0P1/CbL206e@:0P0
JdlW0P1]D2P306a?9`<0JdhV00T0J4`U06U=9P1ZCRL0JdlX06Y>9`1YCBH0Id/T06I:8`1XC2@00P1Y
CBD306Y>9P80JDdU00<0JdhV06Y=9@1YC2@00P1YC2@00`1[CRH0KE0X06iA:@0806U=:0@0JDdU0`1Z
CRH206]?9`@0KE4Y00@0K50X06]?9`1[CbL0JThV1P1YCBD206Q<90D0J4`W00H0Id/V06I:9@1VBRD0
H4PR06598`1SBbD206A<9P0406=;9@1QBB<0H4PR06=;9`80HTXV0`1QBBD2069:9PP0GdTT201RBRH3
06M;9P0306Q<9`1YCBP0JDdX0080JThY0P1XC2L0101YCBP0JThY06Y>:@1[CbX206a@:`<0Le<]101d
E2h01P1eEBl0N5HX07UG:@1lFR`0OU`^07mM;`80OU`^00@0OE/]07iL;P1nG2h0Oed_0P20GS000`21
Gc40PV0b089P<P02081N;P04089P<023HC40QF<c08IT=080QfDe00H0R6<f08QT=029ICD0RFDc08YV
<P2:Ic4208YW;`0608iY?02>JSX0Sf/k08m[>@2@K3P0T6dg0P2AKSH00`2CKST0U6lj09A_>P0209A_
>P@0UG0k00<0Ug8m09Ud?`2LMd800`2MN4<02P2LMd80WGQ309iiA02PNdH0XGa70:9mB02QO4L0X7]6
09mjA@2PO4820:5m@`060:9mAP2TOdX0YX5<0:R3C`2YPe80ZXAC0P2VPDd30:N2CP<0Z8=?0`2[QU42
0:b7DP<0[HQC00d0ZhMC0:b8E02^RUH0[h]G0;2<F02_ReL0[XYF0:f9E@2/R5P0[HUI0:j:FP2_Re/0
/8aL00<0/HeM202aRe`;0;:=F@<0/HaH0P2`ReL20;6<F0@0/XeI0P2aS5P80;>>FP80]8mK0`2cSUX3
0;:=F@030;>>FP2bSET0/XeI0080/XeI1@2aS5P>0;2;E`030;:=F02aS5L0[hYE00<0[HQC00@0[XUD
0:n:E@2/Qe<0[8MC0P2]R5@0102^RED0[hYF0:n:EP2_RUH20:f8E0L0[XUE102_RUH60;2;E`80[hYF
0`2^RED0102]QeH0[XQG0:n9F02_REP20;6;FP030:n9F02^R5L0[HMF00P0[XUD0`2_RUH30;2;E`80
/HaH00H0/H]N0;6;G02aRe`0/H]J0;6<F02aS5L20;6<E@030;27D`2_QU80[HA@0080[8=?00/0[HA@
0:n6DP2`Qe<0/8ID0:n5D`2^Q580[H=A0:j4DP2_QE<0/HME0;>9E`040:^6DP@0[8MC102/QUL40:f7
F080[XQI00H0[HMF0:b7D`2[QU40ZXE@0:R3C02XQ4X80:f8D`P0[H=A202[QU420:f4D0<0[XEA0`2_
QU820:f8E080[8MC00@0ZhIB0:Z5D@2ZQE40ZXEA0P2/Pdl60:f4D0P0ZHA@0P2[PTh0102/Pdl0[XEA
0:n6DP2aR5@20;:9E@80[hIB1P2^QE400`2YQ4l0ZXE@0:b7DP020:f8D`040:b7DP2[QU40ZXE@0:n5
D`L0[XAB00<0[hEC0:Z5D02ZQE001P2ZQE000`2]R5<0[8MB0:^6D@020:V4C`030:^6D@2/Qe80[HQC
00<0[8MC0`2[QU820:Z5D@070;27D`2_QU80[HA@0:b3C`2]Q500[XEA0:n6DP090;27D`<0[XAB0P2_
QE<30:j4DP<0[XEA0`2]Q5020:b3C`P0[89@202^QE40202`Qe<0/XUE0;>:EP2cRUH0/XUE0:n6DP2[
PTh0ZH1<0P2`Qe<20:n6DP80[XEA0P2]Q5000`2_QE<0[XAB0:f3D@030:f3D@030:j4DP2_QE<0[8MC
0080[8MC0`2[QU820:Z5D@80[hEC1P2`QU@80:f8D`80/8IF00@0/8ID0;27D`2`Qe<0/8MA0P2`Qdl0
0`2`Qe<0[hIB0:j5D@020:b3C`060:j5D@2_QU80/8MC0:f8E02/Qe<0ZXEA0P2XPdl00`2YQ500ZXEA
0:^6DP090:^6D@030;26E02_QE<0[H=A0080Zh5?00<0[89@0:f3D@2^Q580202_QED20:b7DP040:^6
D@2ZQE00ZHA?0:R3CP80Yh9=0`2[QU820:b7D`T0ZhIB0P2/Qe<20:V4D0H0ZXEA00H0ZXI<0:Z5CP2[
QU40ZhIA0:^6DP2/QUD20:b6E`P0[8=?0`2ZQE400`2[QU80[8MC0:b7D`020:f8E0P0[H=A202]Q508
0:Z5D@80[XAD00@0[XAB0:j5D@2^QE40[XE?0P2^QDd80:f4D080[89@0`2]Pe430:j4DP<0Zh9>0`2/
Pdl20:f4D080ZH=B0`2ZQ5<30:^5E0<0ZhIB0P2ZQE430:V4D0L0[89@0P2[PDl30:b2D080[H=A0`2^
Q5820:V3DP<0ZXAC0`2[QE@00`2^QE40[HA@0:f4D0020:b3C`80Zh9>00<0ZX5=0:N2CP2WPTh00P2W
PTh40:R3C`060:n4F@2_Q5L0[hAG0:j4E02]Pe40[8=?0P2[PT`01P2WPTd0Z8=>0:V4C`2ZQE00[8MB
0:f8D`80[hYE0`2XPdl20:N2CP<0YX5=0P2[QU860:Z5D@030:^6DP2ZQE40Z8=?0080Yh9>00<0Z8=?
0:V4D02ZQE40202ZP4h0202XOd/0ZH1<0:Z1C@2[PTh0[HA@0:j5D@2_QU80/8MC0P2/Pd/0102[PT`0
Zh9>0:^2CP2ZP4h20:Z0D0<0ZH1<0P2ZPDd30:V0C0030:IlBP2WOD/0ZGm=00<0Zh5?0100ZX1>0:Uo
C@2UQ4h0YHA>0:N4CP2WPTd0ZH5=0:Z1C@2YP4`0ZWm<0:b3C`2[PTh0ZX5=0:QoB`2WOTX0YWe90P2U
O4P80:MnBP030:UoC@2XOT`0Z7i<0080Yge;0P2VO4X00`2UNdT0XWe80:9mB0070:=nB@80Xgi:0P2R
ODT20:5lB080X7]700P0WgY609iiA@2MN4@0WGQ409iiA@2PNdL0XWe90:=nBPH0WgY60P2NNDD209id
@P040:1fA02QMdD0XgU70:AjB080YWa:0P2PNdL209mjAP@0WWU50P2PNdL00`2ONTH0WWU509ehA002
09ag@`0409]f@P2OMTP0WgI809egB080WGU900@0W7Y:09]kBP2KNdX0X7]7102ONTH309iiA@0609Qb
@`2ILd@0VWA509]eAP2MMdP0WWQ90P2ONDX309ihBB_ooooo000Zooooo`/0TF@j0P2BIC/309=V?0P0
U6Pk0`2DIcd209=V?0<0TVDk0`2DJ3/209EY?0<0UVXm00H0VfXo09YY?P2HIc`0UfHk09IU>P2EI3T2
09IU>P80VFPm0`2JJCh0102IJ3d0UfHk09IU>P2CIcH209AX=`0309EY>02FJST0Uf/j0080V6`k00@0
VFdl09Q/>`2HK3/0V6`k0`2GJcX209IZ>@<0Uf/j102HK3/909U]?080Vg0i00@0Vg0k09]`?@2KL3d0
Vfln0P2KKd0809U_?@T0VVhm00D0Vfln09a`?`2MLD00WG5009a`?`0209]_?P80WG5200@0WG5009eb
?`2MLSl0WG8m0P2MLS/209eb?`80WW=000@0WgA10:1e@P2QMT<0XGI30`2RMd@20:5f@`<0X7E2202P
Md<@0:9gA0P0XWU5202SN4D20:ElB080Y7]7102SNTH20:AkA`80YGa80P2VODT20:MnBP030:=jAP2T
NdL0YWe90080Ygi:00<0YWe90:AkA`2SNTH01`2UNDP02@2TN4L0X7M109mf@02OMT80WWA209ec@`2L
LD@0Vg1309]`A@0209Y`?P0309U_?@2HKS`0Ufdk00<0UV`j00L0UF/i09AY?P2CJ3d0TfPm099W?02A
IS/0T6Dj0080Sf@i0P2:I3L01029HcH0R68e08MQ=027HC@208IP<`80Qf4d0P26H3<01@25Gc80Q5ha
08=M<023GC00PUdc00<0PE`b0P20Fc4207mJ<080OUPa00<0OEL`07aF;`1kEBh00P1jE2d00`1iDb`0
MU<]07EB;00207AA:`0?07EB;01fDbd0Me@^07QE;`1bDbL0LE8V071@9`1_CbP0KDdW06a;:01[BRL0
JTTX06M68`1XAb@0JTTV0080K4/X00<0JTTV06Q7901WAR<00P1YARH00`1XAbH0ITPV06E89P0206=9
9P03069:9P1VABH0ITDV00<0IdHW0`1XAbP206948P0306=58`1UAbD0IDLU00<0ITPV00H0IdHS06Q7
901XAb@0JDPU06Y99P1[BRL206a;:00806U=:01ZCRT0JddY06i=:P1`CR/0LTh/07=?;@1eCRd807UC
;080NU</00<0Ne@]07aE;P1mERl00P1nEc001@1oF340O5HY07eG:P1oFB`0PE/^0080PU`_00P0PE/^
081J;@1oFB`0PE/^08=M<025Gc80QV0c08MQ=080QV0c00<0P5/^089M<025H3<00P27HSD00`25H3<0
PUd`081K;P0908MQ=080QElb0P26H3<308MQ=0T0R68e00<0Qf4b08IP<@25Gc000P25Gc000`26H340
R68c08US=00208QS>@80Qf8h0`26HCL00`25H3H0RF<f08US=P0608US=P<0R68c0P27HC8308IP<@03
08]U=P2:I3D0R68c00<0Qf4b0P28HS<02029Hc80R68a08IP<@25Gc80Q5db08EN=@26GcH0Qf0i0P25
Gc0208IP<@@0Qf4b0P29Hc@208QR<`@0Qf4b00<0R6<f08MR=@25H3<00P24Gc801025H3<0Qf8e08QS
=P27HSD208IQ=00308EP<`24Gc80Peha0080PUd`2023GC0208AO<P80Peha00@0PUd`085L;`20Fbh0
P5/^0P24Fbl01022G2l0PE`_085L;`1oGBl207iN;`<0PUd`0P21G2l3081K;P08089P<P20GS00OE/]
07]I:`1jF2X0NeT[07aJ;01mFbd307eH;P80OUT_0`1oFS001`1nFc40OEX`07]H;P1jEbd0NEH/07YG
;@1kF2h00P1lFBl807]H<0D0NeP^00/0NUL]07UF;01iER`0MEP^07=F;01cDbX0Le8Y07AA:@1hDR/0
O5D^07iG<00307QE;@<0NEH^0P1jEbl807MD;00307QH;`1gEbh0MUH]0080M5@[00D0MUH]07MG;P1h
F2l0MU<[07EB:P0307AA:@0307IC:`1gE2`0NEH^00P0Me@/00H0MUH_07EE;P1cDb`0LU8[075A:P1`
D2T2075A:P80L5DZ00<0LE@Z07=C:P1cDRT00P1dDBT00`1eCbP0LE4X075A:002075A:0@0L50W00T0
N5<Y07EB:01cD2P0LDlY071@:P1^D2`0KU8]06iA;`1YC2@00`1ZCBD206]>9P80K4lW0P1ZCRH406a@
:080JThV00@0KE0X06a?9`1/CbL0K4lW0P1[CRH206Y=9@0<06Q<9`1YCBP0JThY06]?:P1ZCRT0JDdX
06M;9P1VBRD0ITXR06M;8`1XC2@0JDdU0P1ZCRH0101YCBD0J4`T06]>9P1ZCBD306U<900306]>9P1]
D2P0KU4Y00P0JDdX101YCBD306Y>9P80JdlW00P0KU8Z06mC:`1_Db/0L5@/06mC:`1^DRX0KE4Y06a@
:0<0JThV0`1YCBD206Q<9080J4`W0`1YCBP01P1XC2L0ITXU06E9901QBB<0HTXT06=;9@80I4`V00P0
Hd/U069:901QBB<0I4`X06=;9`1RBRH0HDTU06189080HDTU00<0HTXV05m9901OBB@01P1OBB@80659
9@0806968@1SAb80IDTT06M;9P1YCBP0JdlZ06a@:`1]DB`306U=:080JThY0`1[CbX8075C;`0407QF
:01iEbT0NeT[07eK;@80OU`^00<0OE/]07aJ;01mFbd00P1nG2h00`1oGBl0P5h`085O<@02089P<P05
07iL;020GRh0PV0`08AR<P25Hc<00`26I3@03P25HcD0QF<c08IT=026IC80QfHa08MV<027Ibh0R6P_
08aW>P2<J3P0SFTi08iZ>02?JcL0T6dg0P2AKSH709=^>@0509A_>P2EL3/0Ug8m09Ud?`2KMT400P2L
Md802P2KMT40VWE009ag@P2MN4<0WgY50:1kAP2QO4L0X7]609mjA@2NND@30:1l@P060:5lA@2RODP0
Y7m:0:F0C02VP4l0Yh5@0`2VPDd20:N2CP<0Z8=?0`2ZQE020:^6D@<0[8MB00<0ZXIB0:b8E02]RED0
0`2_ReL01P2^RUH0[HUE0:b8F02]RET0[h]K0;2<G080/HeM0P2`S5`80;6;G0/0/XeI0P2aS5P40;2;
E`070;6<F02bSET0/hiJ0;>>FP2bSET0/HaH0;2;E`080;>>FP80]8mK0`2cSUX;0;:=F@<0/HaH0`2`
ReL20:n:EPP0/8]G00T0/HaG0;2;EP2^RE@0[HQC0:b7DP2]R5<0[XUD0:n:E@2[QU800P2/Qe<00`2]
R5@0[XUE0:n:EP020;2;E`<0[HQD0`2^RED20:n:EP/0/8]G0P2_RUH30:j9E@040:f7F02^R5T0[hUJ
0:n9FP80/8YK00<0[hUJ0:j8F@2]QeP0202^RE@30:j9E@80[hYF0`2`ReL01P2`RUd0/8YK0;2:F`2`
RUT0/8]G0;2;EP80/8]D00<0/HQD0;27D`2]Q5000P2[PTh02`2]Q500/8MC0;68E02`QU@0[hEC0:j4
DP2]Pe40[XAB0:n5D`2aQeD0/hUG00<0ZhIB0P2/Qe<30:f8E0@0[8IG102]QeP0202[QE@0[8IE0:b7
D`2]R5<0[8MB0:^6C`2ZQT`0ZHE;202]R5<80:j4DPP0ZhIA0P2]Q5030:j5D@<0[hIB00H0[XUE0:f8
E02]R5@0[8MC0:^6DP2ZQE420:V4D080Zh9>0P2/Pdl40:f4D0P0ZHA@0P2/Pdl0102]Q500[XEA0;27
D`2aR5@20;:9E@<0[hIB0`2^QE420:f4D0030:R3CP2ZQE00ZhIA00<0[HQC0P2[QU400`2`QU@0[hEC
0:j4DP030:f3D@030:j4DP2_QE<0/8ID00P0ZXE@00<0[HQC0:b7DP2[QU400P2YQ4l00`2[QU40[8MB
0:f8D`030:b7D`<0ZhIB0P2ZQE40202_QU80[XEA0:f4D02/Pdl0[HA@0:j5D@2`Qe<0/HQD202^QE40
0`2]Pe40[XAB0:n5D`020;26E0030:n5D`2^Q580[H=A0080[hIB0P2^QE430:f4D0030:b3C`2/PU00
[89@00H0[89@202^QE430;:9E@050;68E02`Qe<0[XEA0:b3C`2[PTh00`2`Qe<20:n6DP<0[XEA0P2`
QU@40:n5D`80/8ID0`2/Qe<30:^6DP80ZXEA0P2_QE<30;26E0<0/HME202]R5<20;26EP040;26E02`
Qe<0/8MC0;27D@80/8M?00<0/8MC0:n6DP2^QE400P2/Pdl01P2^QE40[hIB0;27D`2]R5@0[8MC0:Z5
D@80Z8=?00<0ZHA@0:Z5D@2[QU802@2[QU400`2`QU@0[hEC0:f3D@020:^1C`030:b2D02]Pe40[XAB
00P0[hAG0P2[QU400`2ZQE00ZHA?0:R3CP020:N2C@040:J1C02ZQE40ZhIB0:b7D`80[HQD00<0[8MC
0:^6DP2ZQE400P2ZQE430:^6DP<0[8MC0P2XPdl20:V4D0@0ZXEA0P2ZQT`0102[QTl0ZhIA0:^6D@2/
Qe<20:b6E@030:^2CP2/Pdl0[HA@0080[XEA00<0[HA@0:b3C`2[PTh00P2YQ5000`2ZQE40ZhIB0:b7
D`020:f8E0040:j9E@2/PU00[89@0:b2D080[H=A0`2^Q5880:f4D0P0ZXEA0P2^Q5@0102^Q580[XEA
0:j5D@2^QDl20:j5C@P0[HA>00@0[89@0:f3D@2]Pe40[H=A0P2^Q5820:n5D`<0Zh9>0`2/Pdl20:f4
D0040:V3E02ZQ5D0ZXAE0:Z4E@80ZhEF0P2/QUL30:^6DP80ZXEA0`2YQ5020:f3D@<0[89@102[PDl3
0:b2D080[H=A0`2^Q580102YPe@0ZXAE0:Z4E@2ZQ5D20:^5EP80[8IG00H0[hIB0:j5D@2^QE40[HA@
0:b3C`2[PTh20:Z1C@040:J1C@2WPTh0Yh9>0:N2CP<0Z8=?00T0ZHA@0:f2E`2^PeH0[hAG0:n5E@2_
QE<0[XEA0:b3C@2[PT`00P2XPdh01P2YQ4l0ZhIA0:b7DP2]R5<0[XUD0:n:E@80ZXEA0P2YQ5030:R3
C`030:N2CP2/Qe<0[8MC0080ZhIB102ZQE400`2[QU80ZXEA0:R3C`020:N2CP030:R3C`2YQ500ZXEA
00P0ZX1>00P0ZH1<0:Z1C@2[PTh0[8=?0:f4D02^QE40[hIB0;27D`80[8=;00@0[8==0:^2CP2[PTh0
ZX1>0P2ZP5000`2XOdT0ZH1:0:Z1B`020:^2C0060:Z1B`2YP4X0Z7m90:IlBP2WOD/0ZGm=0`2[PDl0
1`2ZP4h0ZGm=0:F4CP2UQ4h0YhA>0:N2C@2YPDd00P2YP4`01@2ZOd`0[8=?0:^2CP2YP4`0Z7m;00<0
Ygi:00<0Z7m;0:ImA`2VODL01P2VODL30:QnC0D0Yge;0P2QOTP30:9oB@@0Xh1:0P2SOTX30:9mB@<0
XGa800P0X7]709mjAP2NNDD0WGQ409iiA@2ONTH0XGa80:9mB@80X7]70`2ONTH309iiA@0=09id@P2O
MD<0X7I40:9hAP2SNDL0YG]90:IlBP2WOD/0XGa80:1kA`2ONTH0WWU509ehA00209iiA@@0WgY60`2N
NDD209ehA080WGA600H0W7I709]gA`2LN4P0VWQ809UiB02JNTT809mjAP0509]eAP2LMTL0W7I709eg
B02NN4T00P2ONDX0102PNT/0WWQ;09ihB`2NN4/[ooooo`00:_ooool:095T>P80TVDk102CIS`809EY
?0<0U6Lm00<0TfHl099U>`2BIC/00P2AI3X00`2CIcX0U6Pk09AX>`0209EY?080UVXm00H0Uf/n09a[
@02JJCh0V6Ll09IU>P2DHcP209ET>@0309IU>P2HIc`0VFPm00<0VfXo00T0VFPm09MV>`2FICX0TVHe
09=W=P2DJ3L0UFTh09IZ>@2GJcX00P2HK3/209U]?080V6`k0P2GJcX409IZ>@80Uf/j0`2HK3/:09U]
?080Vg0i00@0Vg0k09]`?@2KL3d0Vfln0P2KKd0809U_?@80V6`k00@0VFdl09Y^?@2JKSd0Vfln0`2L
L3l01`2MLD00WW9109mc@P2OLd80WW9109a`?`2KKch00P2MLD80102MLD00WG8o09eb?`2MLSd209eb
>`80WW=000H0WgA10:1e@P2QMT<0XWM40:=hA@2TNDH40:9gA080XGI30P2PMD880:1g@`P0XWM4202S
N4D80:9iA@P0XgQ500<0YWe90:ElB02UO4P00P2TNdL20:=jAP030:9iA@2TNdL0Y7]70080YGa80P2V
ODT20:MnBP030:=jAP2TNdL0YGa80080YWe900<0YGa80:AkA`2SNTH00P2UNDX20:AhB@040:=gB02R
MTL0XGE60:5eAP80WgI000H0WWE109ec@@2LLT80W75409]`@`2KL4D209U_?@0309Q^?02GKC/0UV`j
0080UV`j0P2EJcT209=X?P03099W?@2AIS`0T6Dk0080Sf@j00L0SV<i08]T>@2:HcP0RV<h08UR=`28
HCH0Qf0e0080QUld0P27HC@00`26H3<0QElb08AN<@0208=M<004089L;`1oFS00OeX`07mJ<080OUT_
0`1mF2h01P1nF340OEL`07eG<01lERl0NeD^07YD;@80NE</0140M54[07=@:P1bCbT0LDhX079?:@1d
DB/0MU<]07MD;P1aDRH0L54U06m?9P1^CRL0K4`V06]:9`1ZBBH0JTTX06U89@0206Y99P<0JdXW0P1Z
BBH206U69P0306Q79P1VB2H0IDPV0080HdTV00<0HTXV06E2901U@R@00P1V@bD0101WA2H0J4DW06Q5
9`1XABL206A6900406E79@1VB2H0IdTW06Q::080JD/Y0P1YB2D03`1ZBBH0JdXW06a;:01]C2T0KTdZ
06m>:`1[CbX0K50[06e?:`1`Cb`0LU0]07A@;P1eDBl0Me0_07]E;P0707YD;@0607aE;P1mERl0OEH_
07iG<01oF340P5Tb0P21FS<00`1nF2T0OeTZ085K;002089L;@06085K;020FR/0OeTZ089L;`23GC00
QElb0`27HC@01@26H3<0QElb081K;P22GC00QF0c0080Qf8e00<0QF0c089M<020Fbh02@27HC@308EO
<P80QV0c0`27HC@808QR=@0308US=028HS<0QV0a0080Q5h_00<0QEl`08IP<@27HC800`28HcT208MR
>0<0QV4g2028HSD00`29Hc@0R68c08QR<`0208MQ<P80QV0a0180QEl`08YT=@29Hc@0Qf4b08EO<024
GRl0QEl`08IP<@27HC80RF<b08QR<@26H340Q5ha08AM<P24GC@0QEhe08IO>024GRl208EO<080QV0a
0P27HC801028HS<0RV@e08US=029Hc@208QR<`80Qf4b00@0QV0a08IT=P25HcD0Pf4c0P22H3800`23
HC<0QF<e08IT=P0208MR=@0408IQ=025H3<0Q5lb08=N<@80PUd`2023GC000`23GS40PUd`089M<005
089M<080QE``00@0Ped`089M<022GC00P5h`0P1oGc000`23GS40PUd`089M<002085L;`80P5/^00D0
OeX]081N<01oGBl0OU`^07eK;@0407]I:`80O5L]0P1mF2h307iI;`0807mJ<021GS@0OU/a07YG;@1g
E2X0MU<Y07UF;01lFBl207mL<PP0NeP`00<0O5T_07]H;P1kF2h00P1jEbd307UF;00807AH<01bERh0
L5<[079@:P1cD2X0NE4]07iC<020EC8207MD;080N5D]00@0NEH^07YG;`1jEbl0NUL_101gE2`407IC
:`0307MG;P1eEB`0M5@[0080Le<Z00/0M5@[07EE;01gEbh0MU<[07EB:P1dDBT0Le0X07AA:@1eDRX0
Me@/07QE;@0807IC:`0507MG<@1eEBl0Le<]075A:`1_CbT00P1`D2X01P1aDB/0KU<X06iC:01_DRP0
LU8Y07=B:@80ME8Z00<0Me4Z071@9`1`D2L00P1`D2L4075A:00807QC:@1eDRP0Le0X071>:01_CbT0
KDl[06eA;01^DBl306U<9080JTdU0`1[CRH00`1WCRD0J4lV06YA:00206]B:@0306YA:01XCbH0IdhU
00<0K4lW0P1[CRH306Y=9@0B06M=:01XCRT0JDlZ06Y@:`1YCbX0J4hY06I<9`1UBbH0I4PP06E98@1X
C2@0JDdU06Y>9P1YCBD0J4`T06M;8`1[CRH0JTdU0`1YC2@00`1[CRH0KE0X06iA:@0806U=:0@0JDdU
0`1ZCRH206]?9`0806a@:01]DBT0KU8Z06mC:`1^DRX0KE4Y06]?9`1YCBD206]?9`80JThV0P1YCBD2
06Q<900306Q<9`1YCBP0JThY0080JThY00H0J4`W06I:9@1UBB@0HDTS069:901TC2H206E=9`0606A<
9P1RBR@0HDTS06E=:@1TC2P0HTXV0`1PB2@00`1QBBD0HTXV05i88`0705i88`P0HDTU00P0HdLR06A8
8`1UBB@0Id/V06Q<9`1ZCRT0JdlZ06a@:`<0JThY0`1[CbX206a@:`80L5@_1P1_Dbh0101gEBL0NELY
07]I:`1mFbd207iL;P0707eK;@1lFR`0OE/]07eK;@1nG2h0Oed_081N<002085O<@05089P<P1mFb/0
Oed]089P<024HS800P26I3@208ES<`0608=S=024I3<0Q6@c08AT<@25IS00QFH_0P26Ibh02029I3L0
RVHf08]W=`2=JCL0Sf/g095^>02BKcL0Tg0h1@2CKST3099]>00409E`>`2GLSd0VG@o09Ye@080VgI1
00/0VWE009Ud?`2KMT40W7M209iiA02ONTD0X7]609mjA@2NND@0WGQ309mk@@020:1l@P040:1kA02Q
O4L0XGa70:9mB@80XWa;0P2UP4`20:J1C@<0Yh9>00<0Z8=?0:V4C`2YQ4l00P2ZQE030:^6D@040:b7
DP2ZQU80ZhMC0:f9E@80[h]G00H0[XYF0:f9E@2/R5@0[HUI0:j:FP2`S5`20;6=G@030;2<G02_Re/0
[XYJ00P0/8YK2@2bSET30;6<F080/8]G0P2_RUH00`2`ReL0/HaH0;:=F@020;>>FP030;:=F@2aS5P0
/8]G00X0]8mK0`2cSUX70;:=F@@0/hiJ0P2bSET20;6<F0040;2;E`2_RUH0[hYF0:n:EPP0/8]G00<0
/HaG0;2;EP2^RE@00P2/Qe800`2]R5<0[XUD0:n:E@020:^6DP060:b7D`2]R5@0[XUE0:n:EP2`ReL0
/HaH0P2/Qe<20:f8E0040:j9E@2_RUH0[hYF0:n:EP/0/8]G0P2_RUH30:j9E@040:b6E`2]QeP0[hUJ
0:n9FP80/8YK00<0[hUJ0:f7F02/QUL0202_RUD30:f8E080[XUE0`2_RUH01P2^R5/0[XQI0:j8F@2^
R5L0[XUE0:j9E080[XUB00<0/XUE0;27D`2]Q5000P2[PTh02`2]Q500/8MC0;:9E@2`QU@0[hEC0:j4
DP2]Pe40[XAB0:n5D`2aQeD0/hUG00<0ZhIB00<0[8MC0:f8E02]R5@00P2^RED40:f7F0@0[8IG00P0
Z89A0:V4D02[QU80[HQC0:f8D@2]RDl0[8Q<0:^7B`P0[HQC202^Q5880:Z5D080[HA@0`2^QE430:n6
DP80[XUE00L0[HQD0:b7D`2[QU80ZXEA0:V4D02XPdl0ZX5=0080Zh9>0P2/Pdl20:f4D0030:j5D@2Y
Q500ZHA@00H0ZHA@00@0[HA@0:j5D@2^QE40[hIB0P2`Qe<20;68E080/8MC0P2_QU801`2^QE40[HA@
0:f4D02]Q500Z8=>0:V4C`2[QU400`2]R5<01@2/Qe80ZhIA0;26E02_QE<0[H=A00<0[89@00<0[H=A
0:n5D`2`QU@0202ZQE000`2]R5<0[8MB0:^6D@020:V4C`030:^6D@2/Qe80[HQC00<0[8MC0`2[QU82
0:Z5D@80[XEA00H0[HA@0:b3C`2]Q500[XEA0;27D`2bRED80:b3C`030:b2D02]Pe40[hEC0080/8ID
00<0[hEC0:f3D@2/PU000`2_QU820:j5D@<0[HA@202/PU080:j5D@040;>:EP2bRED0/8MC0:n6DP<0
[XEA00<0[hIB0;27D`2`Qe<00P2`Qe<20:n6DP80[XEA202aQeD30:b7D`<0ZhIB0P2ZQE420:n5D`80
/8ID0P2aQeD20;:8EPP0[HQC0P2`QUH0102`QU@0/8MC0;27D`2`Qe420;27C`030;27D`2_QU80[XEA
0080[8=?00H0[XEA0:n6DP2`Qe<0[HQD0:b7D`2ZQE420:R3C`030:V4D02ZQE40ZhIB00T0ZhIA00<0
/8ID0:n5D`2]Pe400P2[PDl00`2/PU00[H=A0:j4DP080:n4E`80ZXE@00@0ZHA?0:R3CP2WPTd0Yh9=
0P2VPD`00`2YQ500ZXEA0:b7D`020:f8E0030:b7D`2ZQE40ZHA@00<0ZXEA00<0ZhIB0:b7D`2/Qe<0
0P2]R5@00`2WPTh0Z8=?0:R3C`020:V4D080ZXEA00H0ZhIB0:Z6BP2ZQTX0ZhM=0:^6C`2[QU420:b7
D`040:b6E@2[PTh0[8=?0:j5D@80[hIB00T0[XEA0:b3C`2[PTh0Z8=?0:V4D02ZQE40ZhIB0:b7D`2]
R5@00P2^RED00`2[PDl0[89@0:b2D0020:f3D@80[XAB00<0[hEC0:f4D02]Q5001P2]Q5080:Z5D@80
[XAD00@0[XAB0:j5D@2^QE40[XE?0P2^QDd80:f4C0<0[H=A0P2^Q5830:n5D`<0Zh9>0`2/Pdl20:f4
D0<0ZXAE0P2[QEH30:b6E`<0ZhIB0P2ZQE430:V4D0<0[H=A00@0[89@0:^1C`2[PDl0Zh5?0P2ZP4h3
0:b2D080[H=A0`2^Q5830:Z4E@80ZhEF0`2/QUL01P2`Qe<0[hIB0:j5D@2]Q500[8=?0:^2CP80ZX5=
0P2VPDd20:N2CP80Z8=?0P2YQ5002@2[P5D0[85D0:j3EP2`QUH0/8ID0:n6DP2^QDl0[HA>0:V4C`02
0:Z5D0030:^6D@2/Qe80[8MB0080[HQC0P2/Qe<20:^6DP<0ZXEA00@0ZHA@0:f8E02/Qe<0[8MC0P2[
QU820:Z5D@040:V4D02ZQE40ZHA@0:R3C`80Yh9>00<0Z8=?0:Z5D@2[QU80202YOdd20:^2CP80[8=?
00@0[HA@0:j5D@2^QE40[hIB0P2]Q4`02@2/Pdd0[8=?0:^2CP2[PDl0Zh5A0:Z0D02WOTH0Z7m70:Z1
B@020:^2BP060:Z1B@2XOdL0Ygi60:IlBP2WOD/0ZGm=0`2[PDl03@2ZP4h0ZGm=0:F4CP2TPdd0YX==
0:N2C@2XP4`0ZH1<0:QoB`2YOT/0Zh9>0:Z1C@2XOd/00P2WOTX00`2XOd/0ZX5=0:^2CP080:ImA@<0
Yge;102XOT`00`2YOdd0Wgi809mnB0020:1oB@80XH1:0`2RPD/50:9mB@@0Xgi:00<0XGa80:1kA`2N
NDD00P2NNDD00`2PNdL0XGa80:1kA`020:1kA`0309mjAP2NNDD0WWU50080WGQ400H0WgE30:1fA02Q
MdD0XWQ60:=iA`2UNdT20:IlBP030:9mB@2QO4P0WgY600<0WGQ40P2ONTH409iiA@@0WgY60P2KLT@0
1P2JM4D0VGE509YfAP2HMTH0UgM609QhA`80WWU51P2ONTH609miBP80X7Y;0`2NMd`[ooooo`00:_oo
ool:095T>P80TVDk0`2CIS`00`2DIcd0UFTl09EY?00609EY?0<0U6Lm00<0TfHl099U>`2AI3X00P2A
I3X209=W>P0409AX>`2EJC`0UFTl09IZ?@80Uf/n00@0W6]009YY?P2HIc`0UF@i0P2DHcP02P2EI3T0
UVDj09QW?02IJ3d0VfXo09a[@02KJSl0VFPm09MV>`2FICX2099V=@0409=W=P2DJ3L0UVXi09M[>P80
V6`k0`2IKC`00`2HK3/0Uf/j09IZ>@0509IZ>@0309M[>P2HK3/0V6`k00/0VFdl0P2KL3T0102KL3/0
Vg0m09]`?@2KKch209]_@0P0VFlm0P2GJcX0102HK3/0VFdl09]_?P2LL3l309ea@00709ib@@2PM4<0
XGE40:1d@`2OLd80WG5009]_?P0209ea@P0409ea@02MLSl0WG8o09eb?@80WG8k0P2OM440102PMD80
XGI30:=hA@2TNDH20:EjA`040:=hA@2RMd@0XWM40:9gA080XGI30P2PMD880:1g@`P0XWM4202SN4D8
0:9iA@P0XgQ50P2VODT20:ElB0040:AkA`2SNTH0XgY60:9iA@80Y7]70P2UO4P20:ImB@80Ygi:00<0
XWU50:AkA`2UO4P00P2VODT02@2UO4P0Y7]70:9iA@2VNT/0YGU:0:AhB@2SMdP0XWI70:1dA@0209mc
A080WgI000<0WWE109ec@@2LLT800P2KL4<01P2JKd@0VFlm09U_?@2HKS`0Ufdk09I/>P<0UF/i00L0
U6Xh09=X?P2BIcd0TVLm095V?02@IC/0Sf@j0080SV<i0P2;I3T01P2:HcP0RF8g08QQ=P28HCH0Qf0e
08IO=080Qf4d00@0QV0c08EO<P24GS40Ped`0P22G2l207iI;`<0OEP^0`1lEbd207eG<00307aF;`1k
EBh0NU@]0080NE</00T0N58[079?:@1aCRP0L4dW06m<9P1`CBL0LTlY07EB;01fDbd00P1`DBD01P1_
CbH0KThW06a<9P1[BRL0JTTV06U89`80JdXW0`1ZBBH00`1[BRL0K4/X06a;:00206U69P0306Q79P1V
B2H0IDPV0080HdTV00<0HTXV06A18`1T@B<00P1U@R@0101V@bD0Id@V06M49P1XABL206E79@80ITPV
00D0J4XX06U;:@1ZC2X0Jdd[06Y99P0206]:9`0306e<:@1^CBX0Kdh[0080L4l/0P1]DB`00`1_DBd0
LU4^07AB;`0207IB<00307UB<@1kEBh0NeD^00<0NeD^0`1jE2d207iG<080OePa00l0P5Tb085J<`22
Fc@0PU/d081J:`21Fb`0PU`]08=M;P22G2d0PE//07mI:P1nF2T0Ped`08EO<P26H3<00P28HSD01P27
HC@0QElb08AN<@1oFRd0PUd`08EP<`80R6<f00<0QF0c089M<01oFRd00P28HSD408MQ=0<0QV0c0`25
Gc8308IP<`80Qf4d2028HSD0202:I3D0RF<d08IP<@24GRl0Ped^08AN;`25Gc00QV0a0`28HcT308MR
>080QV4g2026H3<208US=00408QR<`27HC80Qf4b08IP<@80QEl`00<0RF<d08QR<`25Gc000`23GBh0
2P25Gc00QV0a08US<P28HS40QV0a08AN<@24GC80Q5dd08EN=@26GcP208AN;`80QEl`00@0QV0a08MQ
<P27HC80R68c0P2:I3D208US=00708QR<`27HC80Qf4b08IP<@26I3H0QF<e08=Q<`02089P<P0308=Q
<`25HcD0QV@f0080Qf8e00<0QV4d08EP<`24Gc800P23GS400`22GC00Ped`08=M<00608=M<080PE`_
0`22GC0308=N<@80QUda00@0Q5ha08=N<@23GS40PEla0P20H34208=N<@04089M<021G2l0PE`_081K
;P80OeX]0`1oGBl01@1nG2h0OE/]07]I:`1jF2X0NELY0080O5L]0P1mF2h407iI;`0308AQ=`1oG380
NEH/0080M54W00@0N5D[07eJ<021GS@0PEhd201kF300101lFBl0NeP^07]H;P1jEbd407UF;008079I
<01bERh0L5<[075?:@1dCRT0N50/07iC<022ES<207MD;080N5D]00@0NEH^07YG;`1jEbl0NeP`0`1g
E2`507IC:`0307IF;@1dE2/0Le<Z0080LU8Y00H0Le<Z07AD:`1fERd0N58[07MA:P1fD2T207E?:003
07MA:P1iDb`0NU@]00P0MU<[00@0MeLa07EE;`1cDbd0L50Z0P1_CbT02P1`D2X0LE4[06eB9`1]DRL0
Ke8X075A:01cDRT0ME8Z07IC:`1hDR/4071@9`@0LE4X00T0N5<Y07AA9`1bCbL0L4hX06i>:01]Cb/0
KE4/06mB<01XBb<00`1YC2@206Y=9@80JdhV00<0ITlU06M@9P1YDRP00P1ZDbT00`1YDRP0Ie0V06I?
9@0206a?9`<0JdhV0`1ZCBD00`1WCb/0J50/06UA;@0206UA;@0=06M?:`1VCRX0I4`X06=77`1UBB40
Id/S06U=9@1ZCRH0JDdU06Q<901WBb<0JdhV06Y=9@0306U<900306]>9P1]D2P0KU4Y00P0JDdX101Y
CBD306Y>9P80JdlW00<0J4`T06Y>9P1[CbL00P1/D2P0101ZCRH0J4`T06I:8P1/D2P206]?9`0306Y>
9P1YCBD0JDdU0080J4`T00/0Id/V06U=:01ZCRT0JdlZ06Y>:@1YCBP0Id/V06E9901QBB<0HTXT06A<
9P0206E=9`0;06A<9P1RBR@0HDTS06I>:P1TC2P0HTXV0618901OAb<0H4PT06599@1RBRH0201NB2<8
06599@0406E9901VBRD0ITXU06M;9P80J4`W0P1YCBP306]?:PD0K50[00<0L5<a06mB<01_DS000P1_
DS0306iA;`0507ME9`1hERP0NeT[07eK;@1nG2h00P1mFbd01@1lFR`0OE/]07eK;@1nG2h0Oed_0080
P5h`0P21Gc40101mFb/0Oed]089P<024HS8208IT=00@08ES<`24HS80Pf<d08=S<P24I3<0Q6@a08EV
<025IRl0QFH]08IW;P28HcH0RFDe08YV=P2<J3H0Sf/g095^>080Tg0h0`2CKST5099]>00@09E`>`2F
LC`0V7<n09Ye@02KMT40VWE009Ud?`2HLch0VgI109ag@P2NND@0WgY50:1kAP2ONTD0WWU409eh@`<0
Wg]100@0WgY309mjA@2PNdH0X7]70P2PNTT20:F0C080YX5=102WPTh30:V4C`80ZXE@0`2[QU40402Z
QU80ZhMC0:f9E@2^RUH0[h]G0:j:EP2]RED0[8QD0:f9F@2_Re/0/8aL0;:>GP2aSEd0/8aL0:j:FP2]
RET80;2:F`P0/XeI102aS5P20;2;E`<0[hYF00L0/HaH0;:=F@2dSe/0]8mK0;:=F@2aS5P0[hYF00X0
]8mK0`2cSUX60;:=F@D0/hiJ0P2bSET20;6<F0040;2;E`2_RUH0[hYF0:j9E@P0/8]G00<0/HaG0;2;
EP2^RE@00`2/Qe801`2]R5<0[XUD0:^6DP2[QU80[8MC0:f8E02^RED00P2`ReL00`2aS5P0[8MC0:b7
D`020:f8E0040:j9E@2_RUH0[hYF0;2;E`<0/HaH202`ReL20:n:EP<0[XUE00@0[8II0:f7FP2_RE`0
[hUL0P2`RUd00`2_RE`0[HMJ0:b6F@080:n:E@<0[8MC0P2]R5@30:j9E@060:f7FP2]QeP0[HMH0:f7
EP2]R5@0[HQC0P2]R5400`2bRED0/8MC0:f4D0020:Z1C@0;0:f4D02`Qe<0/XUE0;26E02_QE<0[XAB
0:f3D@2^Q580[hEC0;67E@2cREL00`2[QU800`2/Qe<0[HQD0:j9E@020:j9E@@0[HMH102/QUL0102V
PDd0Z8=?0:Z5D02]R5420:j:D0030:f9C@2/R4`0[HQC00L0[HQC202^Q5880:Z5D080[HA@0`2^QE43
0:n6DP80[XUE00<0[HQD0:b7D`2[QU800P2YQ5000`2XPdl0ZX5=0:Z1C@020:^2CP040:b3C`2]Q500
[HA@0:j5D@P0ZHA@102_QU860;27D`80[hIB00L0[XEA0:f4D02]Q500[8=?0:R3CP2YQ4l0ZhIA00<0
[HQC00D0[8MB0:^6D@2`QU@0[hEC0:f3D@030:b2D0030:f3D@2_QE<0/8ID00P0ZXE@00<0[HQC0:b7
DP2[QU400P2YQ4l00`2[QU40[8MB0:f8D`030:b7D`<0ZhIB0P2ZQE40202^QE40[HA@0:b3C`2/Pdl0
[HA@0:n6DP2aR5@0/XUE202[PTh00`2/PU00[H=A0:n5D`020;26E0030:n5D`2]Pe40[89@00<0[hIB
0`2^QE420:f4D0P0[89@202^QE402@2cRUH0/HQD0:n6DP2]Q500[8=?0:j5D@2`Qe<0/XUE0;68E003
0;27D`80[hIB0P2^QE420;:8EP@0/hUG0P2bR5H30:b7D`<0ZhIB0P2ZQE420:n5D`80/8ID00@0/HME
0;:8EP2bR5H0/hUG202]R5<20;26EP040;26E02`Qe<0/8MC0;27D@80/8M?00<0/8MC0:n6DP2^QE40
0P2/Pdl01P2^QE40[hIB0;27D`2]R5@0[8MC0:Z5D@80Z8=?00<0ZHA@0:Z5D@2[QU802@2[QU400`2`
QU@0[hEC0:f3D@020:^1C`030:b2D02]Pe40[XAB00P0[hAI0P2ZQE000`2YQ4l0Z8=>0:N2C@020:J1
C0040:F0B`2YQ500ZXEA0:b7D`80[HQD00@0[8MC0:Z5D@2YQ500ZHA@0P2ZQE400`2[QU80[8MC0:b7
D`020:f8E080Yh9>0P2XPdl0102YQ500ZXEA0:Z5D@2[QU820:Z6BP80ZhM=00L0ZhI?0:b7DP2/Qe<0
[8MC0:^2CP2/Pdl0[XEA0080[hIB00@0[XEA0:b3C`2[PTh0Z8=?0P2YQ5000`2[QU80[8MC0:f8E002
0:j9E@80Zh5?00@0[89@0:f3D@2]Pe40[XAB0P2_QE<80:f4D0P0ZXEA0P2^Q5@0102^Q580[XEA0:j5
D@2^QDl20:j5C@P0[HA<0P2]Pe430:j4DP<0[hEC0`2[PTh30:b3C`80[HA@0P2ZQ5L30:^5F0<0[8II
0`2[QU820:Z5D@<0ZHA@00@0[XAB0:f3D@2]Pe40[89@0`2[PDl20:Z0CP<0[89@0P2]Pe430:j4DP80
ZXAG0`2[QEP30:b6F@80/8MC00@0[hIB0:j5D@2/Pdl0Zh9>0P2ZPDd30:J1C@030:N2CP2XPdl0ZHA@
0080ZHA@00T0ZWmD0:^0D`2^PeH0/8IF0;67E@2`Qe<0[hI@0:j5C`2ZQE00102[QU430:b7DP80[HQD
0`2/Qe<30:^6DP80[HQD0P2/Qe<01`2[QU80ZXEA0:Z5D@2YQ500ZXEA0:V4D02XPdl00P2WPTh00`2X
Pdl0ZXEA0:^6DP080:UoC@<0[8=?0`2]Q5020:j5D@80[HA<00@0[8==0:b3C`2[PTh0Zh5?0P2[PE40
0`2WOTH0Z7m70:Z1B@020:^2BP060:Z1B@2XOdL0Ygi60:IlBP2WOD/0ZGm=0`2[PDl03@2ZP4h0ZGm=
0:B3C@2TPdd0YX==0:N2C@2XP4`0ZH1<0:QoB`2YOT/0ZX5=0:V0C02XOd/00P2WOTX00`2YP4`0Zh9>
0:f4D0080:ImA@<0Yge;0P2XOT`30:UoC@80Wgi80P2POdT01@2QP4X0XX5;0::1B`2RPD/0Xh9<0080
XGa80P2RODT20:=nBP<0Y7m;00<0Xgi:0:5lB02ONTH00P2NNDD00`2ONTH0X7]70:5lB0020:1kA`03
09mjAP2NNDD0WWU50080WGQ400D0X7I40:5gA@2QMdD0XWQ60:AjB0020:EkB@0:0:IlBP2RODT0XGa8
09mjAP2MN4@0W7M309ehA02ONTH0X7]709ag@`80WGQ400<0WWU509mjAP2PNdL00P2QO4P209Ya@`04
09UcA02HM4@0V7A409MeA@80UWI50`2NNDD509mjAP040:9lC@2QNd`0XG]<0:5kC0<0X7Y;00@0WgU:
09igC02NMd`0WWM<:oooool002[ooooo202@ICX00`2?I3L0TFHi09AY?00209M/?`0309AY?02AIST0
Sf@g0080TFDh00@0TfLj09AX>`2FJSd0Uf/n0P2IKD0209IZ?@0309EY?02DJ3/0TfLj0080TVHi00<0
TFDh09AX>`2DJ3/01P2DJ3/809EX?PP0WFXk00H0VFdl09Q/>`2HK3/0Uf/j09IZ>@2EJCP209AX=`P0
V6`k00@0U6Pg09EY>02FJST0Uf/j0P2HK3/00`2IKC`0VVhm09]_?P0209a`?`0409]_?P2JKSd0VVhm
09U]?080V6`k01T0XGE40:1d@`2MLD00Vfln09Y^?@2KKch0W70o09ea@02JKc`0Vg0m09eb?`2OM440
X7E209md@@2MLSl0W74n09ed?P2LLcd0W7<o09]a?`2JL400VFi109Q]@02HKD80X7E20080WgA100<0
WW=009eb?`2MLSl00P2LLCh0402IKS/0VVll09]`?@2LLCh0WG8o09ic@02OM440X7E209ea@02NLT40
X7A30:9fA@2SMdH0XWI50:1d@`2OLd830:1g@`<0WgI20P2NMD480:=gB080ZGM60`2XMTD30:MeA003
0:AiAP2SN4D0XgQ50080XgQ500<0Y7U60:IkB02VNdP00`2SN4D20:AiAP<0YGY7202TNDH00`2QN4@0
XgY60:ElB0020:ImB@030:AkA`2QN4@0WgI200P0YWe900T0XWU50:AkA`2UO4P0Ygi:0:ImB@2UO4P0
XgY60:5hA02SNDL00P2RN4H00`2QMdD0X7I409me@`0209id@P0;09ac?`2MM400WWE109ie@@2MM400
Vg8n09U`?02GKSX0SfXe091[=P2BKCP00P2CKST2099]>003091[=P2>JC@0T6Dh00L0T6Dh0100TVDk
091U>P2?I3T0SF@h08US=P27HSD0Q68d08=Q<`24Gc80Peha085L;`1oFRd0OUT/07mJ;@21G2l0PUd`
1P1jEbl207UF;P0607aI<`1kF380NEH`07MD;P1eDR`0Le0Z0P1aCRP506e?:`<0KU0/00<0JT`X06U;
9`1WBBD00P1VB2@01P1XBRH0JT`X06]=:@1WARL0J4LX06U8:@80JTTZ00H0J4LX06I59P1T@b@0I4DV
0693901Q@R<205m08@0306528`1R@b@0I4DV0080IdTW00@0ITPV06E79@1UAbD0I4HT0P1SAB<00`1Y
B2D0J4LT06Q7900206Q790<0IdHS00H0IdTW06Y99P1]C2T0L4hY07=@:P1eCbP207E>9@80M4hW00@0
MDlX07I@:@1hDR/0NE</0P1jE2d01P1gDB`0N58]07QB;@1iDbh0NU@_07]E<080O5Ha00H0NeHY07aG
:P1mF2/0OUT/07mJ;@21G2l2089M<00807aL;@1mGBh0PEla08AO<P25H3<0QElb08EL<024Fbl808EO
<P0308QS=P27HSD0QF0c0080Q5lb00T0QF0c08MR=@28HcH0RF<d08MQ<P25Gc00Q5h_08=M;P24GRl0
0P26H3400`27HC80Qf4d08MQ=00608MQ=080QEl`00@0QV0a08MQ<P27HC80R68c0P29Hc@0102=JCT0
RfLg08UU=@27Hc<208IR<P0808MS<`28I3@0PUd`089M<024Gc80QF0c08MR=@28HcH208YU>080Q5h_
0P25Gc001026H340Qf4b08MQ<P28HS<808]N=00408=M<024GS40Q5ha08EO<P80QV0c0P27HC@208US
=00408QR<`27HC80Qf4b08IP<@80QEl`2025HC4808IP<`03081L:P22GR`0Q60^0080QV8`00<0QF4_
08AP;P22GR`02024Gc82081K<@80OeX`0`1nFBl00`1mF2h0QE``08EL<00608EL<0P0PE`_0`22GRh5
08=O;`80PE`_0P20Fbh407mJ;@P0OU/a00L0OEX`07aI;`1kF2h0NUL]07]H;P1lFBl0OU/a0080Oe`b
0P1mFS0307aI;`<0NeP^0P1jEbd307UF;0<0N5D[2P1eEB`0101fERd0MeL^07UI<01jFS4207]K<P80
NEH^00@0N5D]07MD;01gE2`0MU<[0P1eDRX307]E;P0307YD;@1iDb`0N58[0080N58[201cDbX00`1c
ER`0LUD[071C:@0206mB:00;071C:@1bEB/0LeH/075?:@1bD2X0Le</079E;@1aEBd0KUD/06eD:`1[
E2X00P1`Db/00`1_DRX0KU4Y06e@:00206]>9P0306Y=9@1]D2P0KE0X00H0KE0X0`1^DBT306e@:080
K4lW00<0JdhV06a?9`1^DBT00P1_DRX0101^DBT0K4lW06]>9P1]D2P206a?9`0306]>9P1ZCBD0JTdU
0080JD`T00<0JDPU06Y99P1]C2T00`1_CR/01@1]C2T0K4/X06E9901VBRD0J4`W0080JDdX00<0J4`W
06I:9@1UBB@00P1XBRH01P1YBbL0JT`X06]=:@1/CRX0KDl[06i@;0P0KD`Y00<0K50[06]?:P1YCBP0
0P1WBbH00`1YCBP0JdlZ06a@:`0206]?9`0706Y>9P1XC2@0ITXR06I:8P1WBb<0JDdU06Y>9P0206]?
9`0406Y>9P1YCBD0Id/S06I:8P80IDTQ0P1]CBH0101[CRH0JDdU06I=901TCB<206=>8`@0J4`W0P1W
BbH206I:9@80IDTT0P1TB2<306=78P0306968@1OC2@0GT/S0080GT/S0`1MBR800`1LBB40GTHP05i6
800605i680P0G4HQ00<0HD<Q06=58`1UAbD00P1VB2H02`1UAbD0HdDS06948P1RCbL0HDhV069<9@1S
BbD0ID/V06U=:01[CbX0KU0/0080K54V0P1]DRL306iC:00606mD:@1cDb`0Le</07AD;@1eEBh0MUH_
0P1gEc003`1hF340OEX`07aI;`1kF2h0NUL]07]H;P1mFS00Oe`b085N=01jGRh0OEh_07iO<021HC80
Q68d08MR=@0208YT=`80Q68d0`25HcD308IT=P<0RVHf0P2;IcL308aX>003095_?`2?KCd0SF/k0080
S6Xj00<0Sfdm095_?`2CLD400P2DKc/03`2EL3`0UW4m09Qc?`2IM400VWE109]f@P2KMT40VWE009Ud
?`2HLch0VG@o09]f@@2NND@0X7]609eiA@0209ijAP0309mkA`2PO4P0XGe900<0XWi:00<0Xgi:0:Ao
B`2VPDd00`2XPdl20:J1C@040:F0C02WPTh0ZHA@0:b7D`@0[XUE0P2`ReL40:n:EP80[XUE202bS5d0
202^RED0/8]G0;:=F@2cSUX0]8mK0;>>FP2bSET0/8]G0P2dSe/20;>>FP@0/XeI00D0]8mK0;>>FP2c
SUX0/XeI0;6<F0020;2;E`030:n:EP2`ReL0/8]G00H0/8]G00<0/hiJ0;:=F@2aS5P00P2aS5P00`2c
SUX0]I1L0;JAG@020;F@G0030;B?F`2cSUX0/XeI0080/HaH00<0/8]G0;:>FP2bSUX01P2bSUX20;6<
F0040;2;E`2_RUH0[hYF0:j9E@<0[HQD00L0[XUE0;2;E`2aS5P0/HaH0;2;E`2^RED0[HQD00P0/8UN
202]RED80:n:EP80[hYE0`2`ReH30;6<E`P0/8]F102`ReL20:n:EP<0[XUE0P2dRUP0102cREL0/XQF
0;:8EP2aQeD20;26E0P0[hYF0`2]R5@30:j9E@@0[hYF0`2^RED30:f8E080ZhIA00<0[8MB0:f8D`2^
RE@00P2`ReH00`2aS5L0[XUE0:j9E@080:j9E@80[HQD0P2/Qe<20:^6DP0@0:Z5D02[QU40[HQC0:j9
E02]R5<0ZhIA0:V4C`2XPdh0ZHA?0:^6D@2]R5<0[XUD0:n:E@2^RE@0[HQC0:b7DPP0[XEA0`2_QE<3
0:j4DP80[H=A0P2`QU@30;67E@<0/XQF00<0[X9A0:n3DP2`Q5<00P2aQE@00`2`Q5<0[X9A0:f1D003
0:n5D`<0[XAB0P2]Pe420;:7FP040;66F@2`QEP0/8EH0:n4E`80[X=F0P2^Q5@0102_QE<0[hIB0;27
D`2`Qe420;68D0P0[XEA202/Pdl90:f3D@80[89@0P2]Pe401@2^Q580[hEC0:n5D`2`QU@0[8=?0080
[HA@00<0[XEA0:n6DP2_QU800P2`Qe<80:j4DPP0[XEA0P2]Q4`30:b3B`<0Zh9:202/Pdl01P2dReL0
/hYF0;:9E@2aR5@0[hIB0:j5D@80[HA@0P2^QE430:f4D0030:n6DP2aR5@0/hYF0080[H9G0`2^PeP3
0:n4F@P0/8MC0`2/Qe<30:^6DP80ZXEA00T0ZHA@0:Z5D@2[QU80[8MC0:f8E02^RED0[hYF0;2;E`2`
ReH00P2_RUD00`2^RE@0[HQC0:f8D`020:b7DP040:b2D02]Pe40[H=A0:j4DP80[hEC0P2`QU@80:^6
DP030:^6D@2/Qe80[HQC0080[XUD00<0[HQC0:b7DP2[QU400P2]Q5030:j5D@<0[hIB202^Q5890:^7
C@@0[H=A0P2^Q5820:n5D`P0[HQD00H0/HaH0:n:EP2/Qe<0ZXEA0:R3C`2YQ5020:Z5D@080:j5D@2_
QU80/8MC0:n6DP2^QE40[8=?0:Z1C@2XOd/30:^2BP@0[8=;00@0[HA<0:R3C`2XPdl0ZHA@0P2ZQE40
1P2[QU80[8MC0:b7D`2/Pdl0[HA@0:n6DP80/8MC00<0[hIB0:f4D02/Pdl0202]Q5020:Z6C0040:Z5
CP2ZQE00ZXE@0:Z5D@80ZXAC0P2]R5@20:b7D`0<0:^6DP2ZQE40ZXEA0:V4D02_QE<0/8ID0;67E@2b
R5H0/HME0:n5D`2]Pe40Zh5?0P2XPdl0102YQ500ZXEA0:Z5D@2[QU820:b7D`P0[XEA00<0ZhIB0:Z5
D@2YQ5000P2XPdl00`2YQ500ZXEA0:^6DP030:R3C`<0ZHA@0`2ZQE420:V4D0050:R3C`2WPTh0YX5=
0:J1C@2UP4`00`2YQ5020:Z5D@<0ZhIB202/QUT20:f3D`030:f3D@2]Q500[HA@0080[HA>0P2]Q4`3
0:R2E@80ZH=F0`2ZQ5L50:^6DPD0[8MC00@0ZhIB0:Z5D@2ZQE40ZHA@0P2XPdl0102YQ500ZXEA0:Z5
D@2ZQE420:^6DP80[8MC0`2/Qe030:^6C`X0ZXE>202]Q4`01P2_RUH0[XUE0:j9E@2/Qe<0ZhIB0:Z5
D@80ZHA@0`2[QU820:Z5D@<0ZHA@00<0YH1<0:J1C@2WPTh00P2XPdl00`2WPTh0YX5=0:F0C0020:V0
C0030:Z1C@2[PTh0[8=?0080[XEA00@0[hIB0;27D`2_QU80[HA@0P2/Pdl00`2]Q500[hIB0;27D`02
0:R3C`80Yh9>00@0YX5=0:F0C02UP4`0Y7m;202YP4`20:R3C`040:N2CP2VPDd0Y7m;0:=nBP80XWe9
00<0YGe00:In@@2XP4<00P2ZPTD00`2YPD@0Z8130:Mo@P030:MnBP80Z7m;0`2YP4`00`2VPD`0Yh9=
0:R3CP020:R3CP060:J1C02TOdX0Xgi90:F0C02SOTX0XWe90P2PNdL0102RODT0Xgi:0:=nBP2UP4`8
0:QmBP<0XGa70P2PNdH309mjA@0@0:5mB@2RODT0Xgi:0:AlB@2TNTP0XgM60:9d@`2QLd80WgA:09md
B@2PMDP0XGM50:9i@`2TO440Y7`o0:Em?`80X7]40`2ONT<309ii@P0809YgD@2JMdl0W7I?09efC@2N
M4X0WgA909icAP2OLdH809]f@P<0W7M300<0WGQ409iiA@2ONTH00P2ONTH809miBP<0W7M3:oooool0
02[ooooo202@ICX00`2?I3L0TFHi09AY?00209I[?P0409AY?02AIST0Sf@g099V>@80TfLj00<0U6Pk
09EY?02FJSd00P2GJch209EY?0<0U6Pk0`2CIcX809IZ?@P0UFPn202JJSX409M[>P@0UVXi202HK3/2
09EY>00609IZ>@2GJcX0V6`k09Q/>`2IKC`0VVhm102KKch209Y^?@<0VFdl00<0X7A309ib@@2LL3l0
0`2JKSd01@2KKch0W70o09U^>`2JKc`0W74n0080WW=000<0WG8o09aa?P2KL3d00P2KLS`01P2KLSh0
VW0n09Y`@02JKd80VFi109U^@`80WgA10P2NLd0209eb?`80W74n0P2JKc`02@2KL3d0W74n09eb?`2N
Ld00WgA10:1e@P2MLD00WW910:1d@`030:9fA@80X7A31`2OMT800`2PMd<0XgM80:=gB0060:=gB080
YgM60`2VMTD30:EeA0040:9gA02SN4D0Y7U60:AiAP@0YGY70P2SN4D30:AiAP<0YGY7202TNDH20:9i
A@060:=jAP2TNdL0Y7]70:AkA`2SNTH0XWU5202VODT00`2SNTH0Y7]70:ElB0020:ImB@030:AkA`2S
NTH0XGQ40080XWQ60P2QMdD0102PMT@0WgE309id@P2NM48209ac?`80WGA000L0W7<o09Ya?@2HKc/0
Ufhj091[=`2AK3P0TVdi0080Tfhj0P2AK3P00`2?JSH0SVTe091U>007091U>006091S>@2?I3T0SV<h
08]R=P28HSD0QF0c0P22H3802024Gc<0PUda081K;`1oFRh0OUT]07mJ;P20Fbl0PE``101jEbl407UF
;P0607]H<P1jEc40NEH`07MD;P1eDR`0Le0Z0P1aCRP806e?:`0306Y<:01YBbL0IdTU0080ITPT00h0
J4XV06U;9`1[CBT0IdHW06Q7:01YB2T0JTTZ06U8:@1XAbP0ITDV06A3901UARL0I4DV06939080HD8S
00<0HT<T06A59P1UARL00P1VB2H206E79@0406A6901SAB<0HdDS06=58`<0JDPU1@1XAb@0201WBBL0
JdXW06e<:@1aCbX0Le0Z07E?:01fCbH0MDhU0P1eCbP0101fD2T0Me4Z07QB:`1iDb`207YD;@80N58]
00<0NE<^07YD;`1kEC000P1lES40101mEc80OEP[07eH:`1nFB`207mJ;@0;081K;P21G2l0PE`_07aL
;@1nGRl0PEla08AO<P25H3<0QElb08IM<@25G3002025Gc800`28HcH0Qf8e08EP<`0208AO<P0608EP
<`27HSD0R6<f08QR<`27HC80QEl`0P24GRl01025Gc00QV0a08IP<@27HC8808MQ=0<0QV0a00<0Qf4b
08QR<`28HS<00P29Hc@02P28I3@0Qf<c08IR<P26HS80Qf<c08UU=@2;IcL0S6Ph08=N<@24Gc8208EP
<`80Qf8e00<0R6<f08UT=`24GRl00P25Gc0208IP<@80Qf4b00<0R68c08YO=02:Gc@01P2:Gc@308EO
<P0308IP<`27HC@0Qf4d0080R68e00<0RF<d08QR<`28HS<00P27HC8208IP<@0308EO<025HC40QF4a
00H0QF4a2026H3<02020G2X0PUh/08AP;P25HBl0QV8`08EQ;`24H2h0Pel]2024Gc82081K<@80OeX`
101nFBl808EL<0P0PE`_1021GBd4089N;P80PE`_0P20Fbh307mJ;@0307iI;01mFS00OEX`00H0OEX`
00L0OU/a07eJ<01lFBl0NeP^07YG;@1kF2h0OEX`0080OU/a0P1lFBl207]H;P<0NUL]00<0NEH/07YG
;@1jEbd00`1iER`307QE:`X0MUH]0P1gEbh0101hF2l0NET`07YJ<@1jFS4307UF;P0307QE;@1gE2`0
Me@/0080MU<[0P1iERh207QE;@0407MD;01fDb/0MU<[07IC:`P0Le<Z00<0LeH/079E:`1`DbT00P1_
DRP02`1`DbT0LUD[07=F;01`CRP0LDlY079B:`1aE2`0L5@/06eD:`1/DbX0JU<Y0080L5<[00H0Ke8Z
06iA:@1]D2P0K4lW06]>9P1ZCBD806e@:0<0KU4Y0P1]D2P306a?9`0306]>9P1/CbL0KU4Y0080Ke8Z
00<0KU4Y06a?9`1[CRH00`1/CbL00`1[CRH0JTdU06Y=9@0206U<900;06U89@1ZBBH0K4/X06i=:P1_
CR/0KTdZ06e<:@1/BbP0IDTT06I:9@1XC2L00P1YCBP00`1XC2L0ITXU06E9900206Q:9P0406U;9`1Z
C2P0JddY06a>:P80KDl[201]C2T00`1[CbX0JThY06U=:00206Q<9`0306U=:01ZCRT0JdlZ0080JThV
00P0JDdU06M;8`1VBR80Id/S06Q<901ZCRH0JdlW06a@:080JdlW00D0JThV06Q<901WBb<0Id/S06I:
8P0206e=9P0406Y=9@1YCBD0ITdT06E>9080HdhS00@0JDdX06Q<9`1XC2L0J4`W0P1WBbH206I:9@80
IDTT0P1TB2<406=78P80GDXR1P1NBb<805i680P0GTPS0100H4<Q06958`1TAbD0IDPV06I99`1UB2H0
I4LU06=6901RCbL0HDhV069<9@1SBbD0ID/V06U=:01[CbX0KU0/0`1/D2P206eA:@<0KU8Z00H0LU8[
07=C;01cDb`0M5@]07EE;P1fERl207MG<080NeP^00h0NUL]07UF;01jEbd0O5T_07iK<@1oG380Nel_
07eN;`1nGc00PF4b08=Q<`26HC@0R68e08US=P<0Q68d0P25HcD308IT=P<0RVHf0`2;IcL208aX>080
Sfdm0`2>K3`02`2?KCd0TFlo095_?`2CKSX0U6lk09E`?02FLCd0V7<o09Ud@02JMD40VgI20080VWE0
00H0VG@o09Qc?P2IM3l0VgI109iiA02ONTD309eiA@0409ijAP2ONdL0X7a80:5mB@80XWi:00L0Xgi:
0:AoB`2VPDd0Yh9>0:R3C`2WPTh0YX5=0080YH1<00@0Yh9>0:V4D02/Qe<0[HQD0P2^RED00`2]R5@0
[hYF0:n:EP020:n:EP@0[XUE202aRe`00`2^RED0[hYF0;6<F0030;>>FP040;:=F@2aS5P0]8mK0;B?
F`80/hiJ0`2bSET00`2aS5P0/XeI0;:=F@020;:=F@`0/HaH00<0/hiJ0;:=F@2aS5P00P2aS5P00`2c
SUX0]I1L0;JAG@020;B?F`<0/hiJ0`2bSET80;:>FP80/HaH0P2`ReL01`2_RUH0[XUE0:j9E@2^RED0
[HQD0:j9E@2`ReL00P2aS5P00`2`ReL0[XUE0:f8E0080;29GPP0[HUE202_RUH@0;2;EP@0/8]G0P2_
RUH30:j9E@<0/hUG0P2bR5H30;67E@P0[hYF0`2]R5@30:j9E@@0[hYF0`2^RED30:f8E080ZhIA00H0
[8MB0:f8D`2^RE@0[hYE0;2;EP2aS5L:0:j9E@80[HQD0P2/Qe<20:^6DP80ZhIA0`2]R5<02`2[QU40
ZHA?0:R3CP2YQ4l0ZhIA0:f8D`2^RE@0[hYE0:j9E02]R5<0[8MB00P0[XEA0`2_QE<30:j4DP80[H=A
0`2_QE<20;26E0<0/HME00<0[H=A0:j4DP2_QE<00P2`QU@00`2_QE<0[H=A0:b2D0030:n5D`80[XAB
0`2]Pe430;25F0030:n4E`2^PeH0[X=F0080[H9E0P2^Q5@0102_QE<0[hIB0;27D`2`Qe420;68D0P0
[XEA202/Pdl90:f3D@80Zh5?0P2/PU00102]Pe40[XAB0:j4DP2^Q5830:f4D0030:j5D@2_QU80[hIB
0080/8MC202^Q5880:j5D@<0[HA<0P2/Pd/30:^2BPP0[8=?0P2aR5@20;27D`070:n6DP2^QE40[HA@
0:f4D02_QU80[XEA0:f4D0020:b3C`030:j5D@2`Qe<0/HQD0080[H9E0`2^PeH30:n4E`P0/8MC0`2/
Qe<30:^6DP80ZXEA00H0ZHA@0:Z5D@2[QU80[8MC0:f8E02^RED20:n:EP80[hYE0P2^RE@20:f8D`80
[8MB0`2]Pe400`2^Q580[hEC0:n5D`020;26E0P0ZhIB00<0ZhIA0:b7DP2]R5<00P2^RE@00`2]R5<0
[8MB0:^6D@020:f4D0<0[XEA0`2_QU880:j4DPT0ZhM=0`2^Q5830:n5D`80/8ID202]R5@0102`ReL0
[XUE0:b7D`2ZQE420:V4D080ZXEA00P0[XEA0:n6DP2`Qe<0/8MC0:j5D@2/Pdl0ZX5=0:V0C080ZX59
0P2[PTX0102/Pd/0[HA<0:f4C02^QDd30:V4D080ZXEA0`2[QU800`2/Pdl0[HA@0:n6DP020;27D`03
0:n6DP2]Q500[8=?00P0[HA@0P2ZQT`0102ZQDh0ZXE@0:Z5D02ZQE420:Z4D`80[HQD0P2/Qe<20:^6
DP80ZXEA00P0[hEC0;26E02aQeD0/XQF0;67E@2_QE<0[H=A0:b2D0<0ZHA@0P2ZQE430:^6DPP0[XEA
00<0[HQD0:^6DP2ZQE400P2YQ5000`2ZQE40ZhIB0:f8E00:0:V4D0<0Z8=?0`2WPTh20:V4D0<0ZXEA
0`2[QU880:b6E`80[H=C00<0[H=A0:f4D02]Q5000P2]Q4h20:f4C0<0Z89C0P2YPe@30:Z4E@H0ZhIB
102/Qe<0102[QU80ZXEA0:Z5D@2YQ5040:R3C`80ZHA@0P2ZQE420:^6DP<0[8M@0`2[QTl:0:Z5CPP0
[HA<0P2]R5@0102/Qe<0ZhIB0:Z5D@2YQ5020:R3C`<0ZhIB0P2ZQE430:V4D0030:F0C02VPDd0Yh9>
0080Z8=?00<0Yh9>0:J1C@2UP4`00P2YP4`02@2ZPDd0Zh9>0:b3C`2]Q500[XEA0:n6DP2`Qe<0[hIB
0:f4D0020:b3C`030:f4D02_QU80/8MC0080Z8=?0P2WPTh20:J1C@80YH1<202YP4`20:R3C`090:N2
CP2VPDd0YH1<0:AoB`2SOTX0XWe90:MoA02XP4D0ZH560080ZX9700<0ZH560:MoA02VOT<00`2WOTX2
0:QoB`<0ZH1<00<0YX5<0:N2C@2XPdh00P2XPdh01P2VPD`0Y7m:0:=nB@2UP4`0Y7m;0:9mB@80XGa8
00@0XWe90:AoB`2TOd/0YH1<202WOTX30:5lA`<0X7]60P2ONTD0402ONdL0XGa80:9mB@2TO4T0Y7Y8
0:AhA`2SMD@0XWA309mdB@2PMDP0X7I60:5gA@2SNT@0Y7]30:Al@@2UOD020:5lA@040:1kA02ONT<0
WgY309ii@P80WGQ100P0VgQ@09YgC`2LMdd0WGI;09ieB@2OM4L0WW=609mcA0X0W7M30P2MN4@0102N
NDD0WgY609mjAP2ONTH809miBP<0W7M3:oooool002[ooooo202@ICX00`2?I3L0TFHi09=X>`0209EZ
?@0309=X>`2AIST0Sf@g00D0U6Pk0`2EJC`309=W>P<0U6Pk0P2EJC`809M[?PP0UFPn202IJCT309IZ
>@<0Uf/j2P2HK3/209IZ>@0309M[>P2HK3/0VFdl0080VFdl0P2JKSd309U]?080VVhm0`2KKch00`2M
LD00W70o09]_?P0309U]?00509Y^?@2KKch0V6dj09U^>`2JKc`00`2LLCh01`2KL3d0VVll09U`>P2I
L3X0VW4m09Y`?P2JL4000P2KL4<0102KL4D0WW=009ic@02NLd0309eb?`80W74n0P2KL3d0102LLCh0
WG8o09ic@02NLd0209md@@0509ib@@2OLd80X7A30:5eA02RMTD00P2QMD@01@2PM4<0WGA009ed@02N
MD40WgI20080X7M30P2QN4@80:=gAP80YgM60`2VMTD30:EeA0030:1e@P2RMd@0YGY70080Yga900@0
YW]80:AiAP2RMd@0XgQ50`2TNDH20:EjA`80YW]8202TNDH20:9iA@80XGQ400<0XWU50:AkA`2UO4P0
2@2VODT20:AkA`<0YGa800@0XgY60:9iA@2QN4@0XWQ60P2QMdD00`2PMT@0WgE309id@P0209ec@@08
09]b?P2LLcl0W7<o09ed@02LLcl0VW4m09Q_>`2FKCT2095/>080TVdi00D0TF`h091[=`2@JcL0SfXf
08iY=@0808mT=`0608iQ=`2<HCH0Rf0e08UP=026H3<0Peha0P20GS001@22GC<0PE`b081K<@1oFS00
OUT_0080OeX`00@0P5/a07YG;`1jEbl0NUL_0P1iERh307QE;@0807YG<@1iES00N5D_07IC;@1dDB/0
LTlY075>:01`CBL806e?:`0306Y<:01YBbL0J4XV0080IdTU00@0J4XV06U;9`1YBbL0IDHW0P1VAbP0
201WB2T0ITLX06E69`1TABH0Hd@U06I7:01UARL0I4DV0P1SA2D00`1TABH0IDHW06I7:00306A69080
HdDS0`1RA28506U89@<0JTTV00H0J4XX06]:9`1^CBX0LDlZ07AA:`1fD2T207I?9P80MU0Y00@0Me4Z
07QB:`1iDb`0NE</0P1jE2d207UC;00307YD;@1kEBh0O5H_0080OEL`00@0OUPa07mJ;@1oFRd0OeX]
1@20Fbh00`1mGBh0OUh_085O<@0208AO<P0308EO<P26GC40QUda00P0QElb0P27HSD408EP<`80Qf8e
0P27HC801026H340QEl`08EO<026H34208MQ<P0308QR<`27HC@0Qf4d00H0Qf4d00@0QV0a08MQ<P27
HC80Qf4b0`28HS<02@29Hc@0Q60`08AP<024H300QV8b08QT=02:ISH0SFTi08iZ>P0808IQ=080QEl`
0P26H34408MQ<PP0RUld0`27HC@308QR=@80RF<f0`28HS<208MQ<P<0QV0a2025HC4808IP<`03085M
;@22GRh0Pel_00<0QF4a00<0Q60`08=O;`24Gc801`24Gc83081K<@80OeX`0`1nFBl808=M<0P0PUd`
2`20Fbh207mJ;@<0OUT/201kF2h01020GC<0Oe`b07aI;`1kF2h207YG;@0307]H;P1lFBl0O5T_0080
NUL]0P1iER`307QE:`0307MD:P1jEbd0NUL]00<0NEH/0`1hEB/807QH;`D0MeL^0`1hF2l307YG;`80
NEH^1P1hEBd207MD;0<0MU<[201cDbX00`1bEB/0LE@Z071C:@0206mB:00<071C:@1aE2X0LUD[06m=
9`1`CRP0LE4Z071C:`1_Db/0Je8Y06YA:01XDBL0L5<[0P1_DRX00`1^DBT0KE0X06a?9`0206]>9PP0
KE0X0P1^DBT206e@:0<0K4lW00@0JdhV06Y=9@1[CRH0KE0X0P1^DBT00`1]D2P0JdhV06Y=9@0206a?
9`<0JdhV0`1ZCBD01@1XBRH0JD/W06Y<:01[CBT0K4hZ0080JddY00@0JT`X06I:9@1WBbH0J4`W0P1Y
CBP00`1XC2L0Id/V06I:9@0206Q:9P0406U;9`1ZC2P0JddY06]=:@80K4hZ201ZC2P206Y>:@0406U=
:01XC2L0J4`W06U=:080JThY0P1XC2@306M;8`0506Q<901YCBD0JdlW06a@:01]DBT00P1/D2P03@1[
CbL0JThV06U=9@1YCBD0J4`T06e=9P1/C2D0JTdU06U=9@1VCB@0IDhT06A?901SCR<00`1YCBP206Q<
9`<0Id/V0`1UBB@206A88`<0HdLR0P1NB240101OBB80H4XS061:8`1QBb@2069<9@P0GdLQ201OBB@0
101P@b40HTDS06A79@1VBBL406M::080HDhV00H0HT`U06=;9@1UBbH0JDdX06]?:P1]Cb/206]?9`80
K50X0`1]DBT01`1^DRX0LE4Z079B:`1bDR/0Le</07AD;@1eEBh00P1fERl207QE:`0<07MD:P1hEB/0
NEH/07YG;@1lFBl0OEX`07aP<01nGc00Of0a081P<@22H380Q5lb0P26H3<01023HC<0Q68d08AR=024
HS@208ES=@80QV@f0P29ICD208YV=P<0RfLg00@0S6Ph08iZ>P2?Jc/0TFdm0`2BKSh2095]?@0609=^
>P2DKc/0UG0l09Ia?@2GLSh0VGA00P2JMD4409Ud?`0409Ye@02KMT40WGQ309iiA0@0WGU500P0WWY6
09mkA`2PO4P0XGe90:9nBP2RODT0Xgi:0:F0C0<0Yh9>0`2UP4`00`2VPDd0ZHA@0:^6DP020:f8E080
[8MC202^RED80:n9FP030:j9E@2_RUH0/HaH00<0/XeI0P2aS5P30;>>FP80/XeI1`2aS5P40;:=F@T0
/hiJ00L0/XeI0;6<F02aS5P0/HaH0;>>FP2eT5`0]Y5M00<0/XeI0`2cSUX20;B?F`P0/HeI00@0/HaH
0;2;E`2`ReL0/8]G0`2_RUH20:j9E@070:n:EP2`ReL0/HaH0;6<F02`ReL0[hYF0:j9E@080;2:G@P0
[HUE202_RUH20;:=F0030;6<E`2`ReH0[hYE00<0[XUD202`ReH40;2;E`80[hYF0`2^RED30;67E@80
/XQF0`2cREL80:n:EP<0[HQD0`2^RED40:n:EP<0[XUE0`2]R5@01P2[QU40[8MB0:b7DP2]R5<0[XUD
0:n:E@80/8]F2P2^RED20:f8E080[8MC0P2[QU801`2[QU40[8MB0:b7DP2]R5<0[8MB0:^6D@2ZQE00
0P2YQ4l01`2[QU40[HQC0:j9E02_RUD0[XUD0:f8D`2/Qe80202^QE430:n5D`<0[XAB1@2]Pe420:j4
DP<0[hEC00<0[89@0:f3D@2_QE<00P2`QU@00`2_QE<0[XAB0:f3D@020:n5D`80[XAB0`2]Pe40102/
PU00[X=F0:j3EP2^PeH20:f2E@<0[85D0P2^Q5@0102_QE<0[hIB0;27D`2`Qe420;68D0P0[XEA202/
Pdl90:f3D@040:Z0CP2[PDl0Zh5?0:^1C`<0[89@00<0[H=A0:f4D02]Q5000`2^QE430:n6DPP0[XAB
202_QU80102^QDl0[HA>0:f4CP2]Q4h20:b3C@80Zh9<202/Pdl80:j5D@030;27D`2^QE40[HA@0080
Zh9>00<0[8=?0:f4D02^QE400P2]PUD30:j3EP<0[hAG202`Qe<30:b7D`<0ZhIB102ZQE420:^6DP04
0:b7D`2]R5@0[XUE0:j9E@<0[XUD0`2]R5<20:b7DP80[H=A0`2^Q5830:n5D`P0ZhIB00<0ZhIA0:b7
DP2]R5<00P2^RE@00`2]R5<0[8MB0:^6D@020:f4D0<0[XEA0`2_QU880:j4DPT0ZhI?0P2_QE<30;26
E0<0/HME202]R5@00`2_RUH0[XUE0:b7D`020:Z5D@050:V4D02ZQE40ZXEA0:j5D@2_QU800P2`Qe<0
2P2_QU80[HA@0:^2CP2YP4`0Z7m90:V0BP2ZPD/0Zh9<0:b3C@2^QDl20:n6D0<0ZhIB0P2ZQE430:V4
D0030:f4D02^QE40[hIB0080/8MC00<0[hIB0:j5D@2]Q500202]Q5020:^7C@040:^6C`2[QU40ZhIA
0:^6DP80ZhED0P2]R5@30:b7D`<0ZhIB0P2_QE<30;26E0030:n5D`2]Pe40[H=A00<0ZhIB0P2ZQE43
0:V4D0P0[XEA00<0[XUE0:f8E02/Qe<00P2[QU800`2/Qe<0[HQD0:j9E@030:^6DP030:Z5D@2YQ500
Z8=?0080Yh9>102XPdl30:V4D0030:Z5D@2YQ500ZXEA0080ZXEA0P2[QU820:b7D`P0[8IG0P2]Pe<0
0`2]Pe40[HA@0:f4D0020:f4CP80[HA<0`2YPe@20:Z4E@<0ZhEF202[QU820:b7D`040:^6DP2ZQE40
ZXEA0:V4D080Z8=?0`2WPTh20:R3C`<0ZHA@0`2/Qe830:^6D@X0ZXE@202]Q4h20:^6DP030:Z5D@2Y
Q500Z8=?0080Yh9>00@0YX5=0:^6DP2[QU80ZhIB0P2ZQE430:V4D0030:J1C@2WPTh0Z8=?0080ZHA@
00@0Z8=?0:N2CP2VPDd0ZH1<0P2ZPDd00`2[PTh0[8=?0:f4D0020:j5D@030:n6DP2^QE40[HA@0080
[8=?00<0[HA@0:j5D@2_QU800P2XPdl30:N2CP<0YX5=202ZPDd20:R3C`030:N2CP2VPDd0YH1<0080
Y7m;00<0Xgi:0:V1AP2ZPTL00P2[PdP0102ZPTL0Z8150:In@`2UOD830:MnBP80Z7m;0`2YP4`00`2V
PD`0Yh9=0:R3CP020:R3CP030:J1C02TOdX0Xgi90080Y7m;00@0Xgi:0:9mB@2RODT0Xgi:0`2TOd/8
0:MnBP80XWe80P2QO4L30:1kAP0F09mjA@2MNDD0WgY60:5lB02TO4T0YG]90:EiB02UMdH0Y7I50:1e
B02PMTH0XGM50:9hAP2SNT@0Y7]50:Ak@`2UOD80Xgi90:9mB02QO4L0X7]609mjA@80WGQ300T0W7M2
09]hD02KN4h0WGQ>09efB`2OMTX0WgA709meA@2PM4D0202NNDD309ehA080WWU50`2ONTH809miBP<0
WGQ4:oooool002[ooooo202?I3T00`2@ICP0TFHi09=X>`0209AY?00309=X>`2AIST0T6Dh0080UVXm
00@0UFTl09AX>`2DJ3/0TfLj0P2BIST01P2AICP0TVHi099V>@2CIcX0U6Pk09EY?080UVXm202HK3l8
09EX?PP0UVPg0P2EJCP00`2FJST0Uf/j09Q/>`0209U]?00309Y^?@2HK3/0V6`k00H0V6`k0P2GJcX2
09Q/>`<0VFdl0P2JKSd209Q/>`0409U]?02JKSd0VVhm09]_?P80W70o0`2JKSd409U]?00409Y^?@2H
KCX0V6dj09U^>`D0VVll0P2HKcT00`2IL3`0VW0n09]a@@0209aaA00309ebA`2MLSl0WG8o00@0WG8o
102LLCh209eb?`80WW=00P2OM44209mc@P80X7A3102QMD@209ac?`0609ed@02OMT80X7M30:5hA02R
NDD0XgY6202SN4D20:IhAP<0YGM50`2TMT@00`2NLd00XGI30:EjA`020:UnB`030:MlB@2SN4D0X7E2
00<0Y7U60P2UNTL30:IkB0P0Y7U600P0XgY60:5hA02PMd<0WgI20:5hA02TNdL0Ygi:0:V0C0P0YWe9
0`2UO4P00`2TNdL0XgY60:9iA@020:5hA080XGM500@0X7I409me@`2NM480WG=10P2LLT00202JLCd0
Vg8n09ac?`2LLcl0Vg8n09U`?02GKSX0UF`h0P2BK3/2095[>P03091Z>@2?JCP0SfTh0080SVPg202>
HcH01P2<GcD0Rf0e08YO=027GS80Q5ha085L;`80OU`^00@0PE`b081K<@1oFS00OeX`101nFBl207YG
;`0407UF;P1hEBd0N5D]07MD;080MU<[0P1hEBl01P1gE2h0ME8/07=@:P1bCbT0LDhX071=9`<0KDl[
101/CRX0101[CBT0JT`X06U;9`1YBbL506Q:9P<0IDPX0P1TAbL206=69P0306959@1WB2T0ITLX00D0
ITLX00<0IdPY06=58`1SAB<00P1SAB<406948P<0JTTV101[BRL01`1/BbP0JD/Y06a;:01_CR/0LU0[
07EB;01gDBX00P1gD2L00`1gDBX0N58[07QB:`0207UC;080NU@]00L0NeD^07YE:`1jEB/0NeH/07aG
;@1mF2h0OUT_0080OeX`00@0PUd`085L;`21G2l0PE`_0`20Fbh01`1oFRd0Oel`07mO<021Gc40Peha
08AO<P25Gc800P27GS8808IP<`P0QV4d1@26H3401027HC80R68c08QR<`28HS<808MQ=0P0R68c00H0
Q60`08EQ<@25HC40QV8b08QT=029ICD208]W=`80R6<f00@0Qf8e08IQ=026HC@0QF0c0P24Gc8208IP
<@H0Qf4b2029H3@208QR=@H0RF<f2027HC8808EQ<@P0QV0c0P22GC000`23GS40Q5lb08AO<P0;08AO
<P80PE`b0P20Fc4207mJ<080OUT_2021G2l8089M<0<0OeX^0`1nFBd207eH;080P5/^0`1oFRd307iI
;0P0NUL]00@0PEhd07mL<P1mFS00NUL]0`1iER`207YG;@<0N5D[0P1gE2X307IC:@80NUL]0`1iER`3
07QE:`P0NET`0`1hF2l207MG;P<0MUH]101jEbl407UF;P@0MUD/101eE2/807=C:PP0L5<Y00P0KddW
071>:01`D2T0Ke8Z06eA:@1ZDBP0J4lV06I?9@80Ke8Z0P1^DBT0101]D2P0K4lW06a?9`1/CbL;06e@
:0<0K4lW0P1[CRH00`1YC2@0JTdU06a?9`0206e@:00306a?9`1ZCBD0JD`T00H0JdhV0P1ZCBD206Q<
9`H0JDdX0`1WBbH206Q<9`<0Id/V0P1XBRH206U;9`0406Y<:01[CBT0JddY06]=:@/0JDdX0P1XC2L3
06U=:0<0ITXR00H0Id/S06Q<901YCBD0JThV06]?9`1/D2P206eA:@80K50X0P1[CbL206Y>9P80K4`U
00@0JTdU06U=9@1VCB@0IDhT0P1TCb@306U=:0<0J4`W0P1WBbH206I:9@80IDTT0P1TB2<206=78P08
05i6801OAb40H4PR06598`1RBR@0Hd/U06A<9P1UCBL806188PP0H4XU0100GT@Q05m58P1QAb@0HdTV
06E;:01VC2T0IddZ06Q>:`1QCRH0H4dU065;901RBR@0I4XU06Q<9`1ZCRT0KDl[0P1ZCRL206]?:0<0
K50Y00L0KE4Z071@:@1`D2T0LE4Z079B:`1cDb`0M5@]0080MED^0`1eDRP01P1fDbT0N5D[07UF;01j
Ebd0NeP^07eQ<@80Of0a00<0P60a085O<@23GS400P24GS4208=Q<`<0Q68d0`25HcD308UU=@80RVHf
0`2;IcL00`2=IcP0SfTj099/?@0209A^?`0309=]?P2AJc`0SfTj0080Tfhj00H0U6lk09Ia?@2GLSh0
V7<o09Ud@02JMD4309Qc?P0509Ud?`2JMD00VgI109ag@P2MN4<00`2LN4@209]g@`0709ahA02NNTH0
X7a80:5mB@2QO4P0XWe90:AoB`030:J1C@060:F0C02TOd/0YH1<0:J1C@2XPdl0ZXEA0P2/Qe<0102[
QU80ZXEA0:b7D`2/Qe<40:f8E080[XUE202]QeP20:n:EP030;2;E`2aS5P0/HaH00<0/HaH0P2cSUX3
0;:=F@<0/HaH00D0[hYF0;2;E`2`ReL0/HaH0;:=F@020;>>FPT0]8mK00<0/hiJ0;:=F@2aS5P00P2a
S5P0102cSUX0]I1L0;JAG@2`ReL20;6<F0030;:=F@2cSUX0]8mK0080]I1L202aSET80;2;E`030:j9
E@2_RUH0/HaH0080/XeI00<0/HaH0:n:EP2^RED0202`RU/80:j:EPP0[hYF00H0/hiI0;:=F02aS5L0
/8]F0:n:E@2]R5<20:b7DPP0[hYE102`ReL20:n:EP<0[XUE0P2`QU@0102aQeD0/XQF0;:8EP2cREL2
0;B:F0P0[hYF0`2]R5@30:j9E@@0[hYF0`2^RED30:f8E080[8MB0P2]R5<0102^RE@0[hYE0:n:E@2_
RUD:0:j9E@80[HQD0P2/Qe<20:^6DP@0[8MB0P2[QU420:Z5D0080:V4C`2[QU40[HQC0:j9E02_RUD0
[XUD0:f8D`2/Qe880:j5D@<0[hEC0`2^Q5820:f3D@040:^1C`2/PU00[89@0:b2D080[H=A0P2^Q580
0`2[Pe00[8AA0:j6D`020:n7E0030:j6D`2]QE80[8AA00<0[XAB0`2]Pe420:b2D0@0[85D102[P5<2
0:j4E0040:n5D`2_QU80/8MC0;27D@80/HQ@402]Q5090:f3D@P0Zh5?1P2^QE420:n6DPP0[XAB202_
QU820:j5D@<0[HA@0`2/Pdl80:f4D0040:b3C`2]Q500[HA@0:f4D0<0[XEA00D0[hIB0;27D`2_QU80
[HA@0:^2CP020:Z1C@040:^2CP2/Pdl0[H=C0:f3D`<0[XAD0`2_QED80;27D`<0[8MC0`2[QU840:Z5
D@80ZhIB0P2/Qe<20:f8E0H0[HQC0P2/Qe860:j4DP80[hEC202[QU800`2[QU40[8MB0:f8D`020:j9
E0030:f8D`2/Qe80ZhIA0080[HA@0`2^QE430:n6DPP0[XAB2@2[QU420;26E080/HME102bR5H:0:f8
E0030:b7D`2[QU80ZXEA00<0ZXEA00P0[XEA0:n6DP2`Qe<0/8MC0:n6DP2^QE40[8=?0:^2CP80Z7m;
00H0ZX5=0:^2CP2]Q500[XEA0:n6DP2`Qe<20:b7D`040:^6DP2ZQE40ZXEA0:V4D080Z8=?0`2^QE42
0:n6DP<0[XEA202]Q5020:^7C@040:^6C`2[QU40ZhIA0:^6DP80ZhED0P2]R5@60:b7D`030:j4DP2_
QE<0[hEC0080[hEC0`2^Q5820:b7D`040:^6DP2ZQE40ZXEA0:V4D080Z8=?202^QE400`2`ReL0[hYF
0:f8E0020:b7D`030:f8E02_RUH0/8]G0080[HQD00L0[8MC0:Z5D@2YQ500Z8=?0:N2CP2VPDd0Yh9>
0080Z8=?00D0ZHA@0:Z5D@2[QU80ZhIB0:b7D`030:Z5D@80ZhIB0`2/Qe<80:b6E@80[H=C00<0[H=A
0:f4D02]Q5000P2]Q4h20:f4C0<0ZXAC0`2[QE@20:b6E@<0[8MC102[QU80102ZQE40[8MC0:b7D`2[
QU820:Z5D@030:V4D02XPdl0Z8=?00<0YX5=0P2WPTh30:R3C`<0[8MC0`2[QU8:0:Z5D@P0[HA@0P2Y
Q5020:R3C`040:N2CP2VPDd0YX5=0:J1C@<0ZhIB0P2ZQE430:V4D0030:J1C@2XPdl0ZHA@0080ZXEA
00<0ZHA@0:R3C`2VPDd00P2ZPDd20:^2CP050:b3C`2]Q500[HA@0:f4D02^QE401P2]Q5000`2^QE40
Z8=?0:R3C`060:N2CPP0ZX5=00<0Z8=?0:N2CP2WPTh00P2VPDd20:F0C0090:AoB`2[PTX0Zh9:0:b3
B`2[PTX0ZX590:QoA`2UO4@0Y7]300<0Ygi:0P2XOd/30:V0C0030:J1C02WPTd0Z8=>0080Z8=>00<0
YX5<0:AoBP2SOTT00P2TOd/40:=nBP<0Y7m;202VOTX30:9mB080XGa70`2PNdH0202LN4@0WWU50:1k
A`2TO4T0YG]90:EiB02VN4L0YGM60P2QMdD00`2RN4H0XWU50:=jAP030:AkA@060:AoB`2SOTX0XWe9
0:5lB02ONTH0WWU50P2LMd<0202KN4h0VgU<09ehC02MMdX0WgI80:1fAP2OMD<0X7A3202ONTH409ii
A@@0WgY6202ONDX309ehA2_ooooo000Zooooo`P0Sf@i00<0T6Dh095V>@2BIcX00P2CJ3/00`2BIcX0
TFHi091U>00209IZ?@0409EY?02DJ3/0TfLj099V>@<0TFDh0P2BIST00`2CIcX0U6Pk09EY?00209IZ
?@P0V6`o202EJ3h809AX=`0609EY>02FJST0UVXi09M[>P2HK3/0VFdl0P2JKSd:09Q/>`D0VFdl0P2J
KSd209Q/>`0409U]?02JKSd0VVhm09]_?P80W70o0`2IKC`409Y^?@0309U]?02IKS/0VFhk00<0VFhk
00<0VVll09]`?@2KL3d00P2HKcT00`2IL3`0VW0n09]a@@0209aaA00309ebA`2LLCh0W74n00@0W74n
102MLSl409ic@080WgA10`2OLd820:1d@`80XGE400T0XWI509ac?`2LLcl0WGA009mf@P2PMd<0XGQ4
0:9iA@2SNTH0202SN4D20:AiAP<0XgQ50`2RMd@00`2NLd00XGI30:EjA`020:UnB`030:MlB@2SN4D0
X7E20080Y7U60P2UNTL20:IkB080Yga9202TNDH0202SNTH0XGQ40:1g@`2OMT80XGQ40:AkA`2WOTX0
ZH1<2@2VODT0102UO4P0Y7]70:=jAP2RNDD20:5hA0070:1g@`2PMT@0X7I409me@`2NM480WG=109ab
@00209]a?`0<09U`?02JLCd0Vg8n09]b?P2JLCd0V6lk09I]>@2DJcL0Tfdn099/?@2AJc`0T6Xk0`2>
J3T208eW>0P0SF8e00H0Rehd08YO=029GS<0QUda08=M<020Fbh207eK;@@0OeTb0P1nF3400`1mEc00
O5H_07YG;`0207UF;P0:07QE;@1fDb/0ME8Z07EB:P1dDBT0Me@^07IC;@1eDR`0M54[07=@:P80LDhX
00D0L4dW06e?:`1]Cb/0KDl[06a>:P0206]=:@80JT`X101YBbL206Q:9P0306M99@1VB2@0HdTX0080
HTPW0P1QAbH306169@80ITLX101WB2T206I7:0P0HdDS0`1[BRL00`1/BbP0KD`Y06e<:@0206i=:P06
06Y<:P1]C2T0L4l/07=A;01eDR`0N58[0P1hDBP207UC;0@0NU@]0P1kEBh207aG:`80OEP/00D0OUT]
07mJ;P20Fbl0P5/_08=N<@03089M<0<0PE`_00L0P5/^081P<@20H340PEla08=N<@24Gc80QElb0080
R5lc2026H3<808IQ=00408EO<026H340Qf4b08MQ<PD0R68c2027HC@408US=0@0R68c1028I3@208MS
<`0408IR<P25HC40RF@g08QS=P80Qf8e0P25H3<01024Gc80Peha08QR<`28HS<608MQ<PP0Qf4d1P29
HcH208QR=@P0Qf4b2025HC4808IP<`D0Pehb00<0Q5lc08EP=025H3@02024Gc83085L<P80P5/a0`1o
FS08085L;`P0Peha0`1oFS000`1nFBl0OEP^07eH;P0207aG;@<0OeX]0`1nFB`207eH:`P0NEH/00H0
P5dc07mL<P1lFBl0NUL]07UF;01hEB/307UF;080N5D[0P1gE2X407IC:@80NUL]0`1iER`307QE:`P0
NET`00@0N5P_07MG;P1gEbh0MeL^0`1fERd00`1eEB`0NEH^07UF;P0607UF;PP0M5@[201cDbX206mB
:0@0L5<Y0P1_DRP2071>:006071@:@1_DRX0KE4Y06YA:01XCbH0IDhT0`1^DBT406e@:00306a?9`1]
D2P0KE0X00P0KE0X0`1/CbL306]>9P0306Q;8`1ZCBD0JdhV0080K4lW00<0JdhV06Y=9@1XBb<00P1Z
CBD606]>9P80IddX1P1VC2L00`1XC2L0Id/V06M;9P0406M;9P0306Q<9`1XBRH0JD/W00<0JD/W0`1Z
C2P806I<9`<0J4`W0P1YCBP306Q<9`80ITXR00@0Id/S06Q<901YCBD0JDdU0`1ZCRH406a@:0@0JdlW
0P1[Bb@0101YC2@0J4`T06M>9@1VCbD206E@9@80JThY0`1YCBP306Q<9`<0ITXU0P1UBB@306A88`80
H4HQ00@0HDLR06988`1TBRD0ID/V0P1VC2L806598`P0H4XU0P1NAR801P1OAb<0HDTU06=;9`1UCBT0
IThZ06M?:`80H4dU00L0HD/T069:901TBRD0J4`W06Y>:@1/CRX0JDdX00<0JThY0P1[CbX206a@:`80
KdlX00@0L50Y075A:P1bDR/0LU8[0P1cDb`01P1bCbD0Le0V07AA9`1fDbT0N5D[07UF;080NUL]00H0
O60`07iO<01nGc00Oel`081N<022GC0208=M<0<0Pf4c0`24HS@208ES=@80R6@d0P29ICD208YV=P80
RfLg00h0SfHh091W>@2CJS`0UF`n09I]?`2EK3h0TfXl095X>P2BKCT0Tfhj09A_>`2EL3`0UW4m09Qc
?`80VGA00P2GLSd00`2HLch0VG@o09Ye@00309]f@@0309ahA02KMd<0VgM30080VGE100L0VWI209ah
A02ONdL0X7a80:1kA`2RODT0Xgi:00<0YH1<00D0Y7m;0:=nBP2TOd/0YX5=0:R3C`030:Z5D@80ZHA@
00<0ZXEA0:^6DP2[QU800P2/Qe<20:f8E0030:j9E@2]QeP0[HMH00H0[HMH102_RUH00`2`ReL0/HaH
0;6<F0040;:=F@<0/HaH0P2`ReL01@2_RUH0/8]G0;2;E`2aS5P0/XeI0080/hiJ00<0]8mK0;F@G02e
T5`01P2eT5`00`2cSUX0/XeI0;6<F0020;6<F0040;>>FP2eT5`0]Y5M0;2;E`80/HaH00<0/XeI0;>>
FP2dSe/00P2eT5`80;2<F0@0/8]G102aS5P00`2_RUH0/8]G0;6<F0020;:=F@030;6<F02`ReL0[hYF
00P0/8YI202^RUH80:n:EP80/XeH00H0/HaG0:n:E@2^RE@0[HQC0:b7DP2[QU480:n:E@@0/8]G0P2_
RUH30:j9E@80/8ID00@0/HME0;:8EP2bR5H0/hUG0P2dRUP80:n:EP<0[HQD0`2^RED40:n:EP<0[XUE
0`2]R5@30:f8D`@0[XUD00<0[hYE0:j9E@2^RED0202^RED20:f8E080[8MC0P2[QU800`2]R5<0[8MB
0:b7DP020:^6D@<0ZXE@00P0ZHA?0:^6D@2]R5<0[XUD0:n:E@2^RE@0[HQC0:b7DPP0[XEA0`2_QE<3
0:j4DP80[H=A0P2[PDl30:b2D0<0[H=A00<0Z8=?0:V4D02[QU800`2]R5@0102/Qe<0ZhIB0:j4DP2^
Q5830:f3D@<0[89@202[P5<20:j4E0040:n5D`2_QU80/8MC0;27D@80/HQ@402]Q5090:f3D@@0[89@
102[PDl20:n6DPH0[XEA202^Q5880;27D`<0[XEA0`2]Q5020:b3C`/0[HA@0P2^QE430:n6DP060;68
E02_QU80[HA@0:^2CP2ZPDd0Zh9>0P2/Pdl20:f3D@<0[XAB0`2_QE<80;27D`<0[8MC0`2[QU840:Z5
D@@0ZhIB0P2/Qe<60:b7DP80[HQC0P2_QE<60:j4DPP0ZhIB00<0ZhIA0:b7DP2]R5<00P2^RE@00`2]
R5<0[8MB0:^6D@020:f4D0<0[XEA0`2_QU880:j4DPT0ZhIA0P2`QU@20;67E@@0/XQF202]R5@50:b7
D`030:^6DP2ZQE40ZXEA0080[XEA0`2`Qe<00`2_QU80[HA@0:b3C`020:V0C0060:Z1C@2[PTh0[8=?
0:f4D02^QE40[hIB0P2/Qe<0102[QU80ZXEA0:Z5D@2YQ5020:R3C`030:n6DP2^QE40[XEA00@0[XEA
00<0[hIB0:f4D02]Q5001P2]Q5020:b8CP040:b7D02/Qe80[8MB0:b7D`80[8IE0P2/Qe<60:f8E0<0
[XAB00<0[H=A0:j4DP2^Q5800P2_QE<20:b7D`040:^6DP2ZQE40ZXEA0:V4D080Z8=?202^QE400`2`
ReL0[hYF0:j9E@020:f8E0090:j9E@2_RUH0/8]G0:j9E@2]R5@0[8MC0:^6DP2ZQE40Z8=?0080Yh9>
00D0Z8=?0:V4D02YQ500ZXEA0:^6DP020:b7D`030:f8E02ZQE40ZXEA0080ZhIB0P2/Qe<20:f8E0P0
ZhIB0P2]Pe<00`2]Pe40[HA@0:f4D0020:f4CP80[HA<102[QU820:b7D`@0[HQD0P2/Qe<0102[QU80
ZXEA0:Z5D@2ZQE420:b7D`040:^6DP2ZQE40ZXEA0:V4D080Z8=?0`2VPDd20:N2CP<0Z8=?0`2/QUD3
0:^5E0X0ZXAC202]Q5000`2XPdl0Yh9>0:N2CP020:N2CP<0YX5=0`2[QU820:Z5D@<0ZHA@00<0Yh9>
0:R3C`2ZQE400P2[QU800`2ZQE40Z8=?0:N2CP030:^2CP@0[8=?00<0[HA@0:b3C`2]Q5001@2]Q500
0`2/Pdl0Yh9>0:N2CP060:R3C`P0Zh9>102WPTh40:J1C@080:^2C02/Pdd0[8==0:b3C@2[PT`0Z7m9
0:ImA`2TNdD30:MnBP80Z7m;0`2YP4`00`2VPD`0Yh9=0:R3CP020:R3CP030:J1C02TOdX0Xgi900T0
Y7m;202TOdX20:=nB@80XWe80P2QO4L20:1kAP0909ahA02NNDD0X7]70:AlB@2UNdT0YGU80:IhA`2U
MdH0XWU30080XgY40P2SNTH30:AjB080Xge<00h0XWa;0:5kBP2PNTT0WgU809ihA`2MMdH0W7Y=09aj
C02MN4/0WWQ90:1hA`2PMT@0X7M30:5f@`P0X7]7202ONTH809miBP<0WWU5:oooool002[ooooo202>
HcP00`2@ICP0TFHi095V>@04095V>@04091U>02EJC`0UFTl09AX>`80TfLj00<0TVHi095U>02AICP0
0`2CIcX309AX>`80UFTl202GJch809EX?PP0UF/i0P2GJcX309Q/>`<0VFdl202HK3/609U]?0<0VVhm
0`2IKC`209Y^?@<0Vfln00<0V6`k09U]?02JKSd00`2LL3l0102KKch0VVhm09]`?@2JKc`309U^>`03
09]`?@2LLCh0WG8o0080VG0j00<0VW4m09Y`?P2JL4000P2KL4<0102KL4D0Vg0m09]`?@2KL3d309aa
?P80WG8o1@2NLd0309md@@80X7A30`2OLd800`2PM4<0XWI50:=gAP0209ed@00409ie@@2OMT80X7M3
0:1g@`80XGQ4202SN4<20:=jAP<0XWU50`2QN4@00`2PMD80XWM40:EjA`020:MlB@030:IkB02TNDH0
XWM400<0YGY70P2VNdP30:MlB@P0Y7U60P2RNDD20:5hA0030:9iA@2TNdL0YGa800T0YWe900@0Ygi:
0:ImB@2TNdL0XWU5102PMd<209me@`0309id@P2MLd40W7900080Vg4o00<0VW0n09Q_>`2IL3`00P2J
LCd0202IL3`0Ufhj09E/>02CJSH0U6i109=]@02AJch0SVPk1@2=IcX808aQ=00908]N=02:Gc@0REhc
08IM<@23GC00PE`_07iL;P1mFbd0OELb0080OUPc00/0OeTd07iH<`1mEc80O5Ha07]E<01jEbl0NEH^
07QE;@1gE2`0ME8Z07AA:@0207=@:080ME8/00@0M54[07=@:P1bCbT0LDhX0P1`CBL01P1^D2`0KDl[
06e?:`1/CRX0JddY06Y<:0<0JD/W0`1ZC2P02@1YBbL0IdTU06I8901UAb<0HTXX06599`1PB2H0GdLU
05i6900205m79@0406189P1UARL0IDHW06I7:080IdPY00@0ITLX06E69`1UARL0HdDS0`1TAR@306E7
9@0706I89P1[BRL0K4/X06a;:01]C2T0KTdZ06m>:`02071?;00606Y<:P1^CBX0LE0]07AB;@1fDbd0
NE</0P1iDRT807]E;P80OEP[00<0OUT/07mJ;@20Fbh00P21G2l6089M<0<0Peha0P21HC801P21Gc40
Peha08=N<@25Gc80RF0d08YQ=@P0QV0c0P25H3<408MR=@80QF0c00H0Q5h_08EO<027HC80R68c08US
=02:I3D308US=0P0Qf4d0`2:I3D208US=0<0R68c0P28I3@01P29ICD0R6@d08MS<`25HC40Q60`089N
;P80R6<f00@0Qf8e08IQ=026HC@0QF0c0P24Gc8208US=080R68c1027HC8808IQ=080RF<f0`28HSD3
08MQ=0<0QV0a0P27HC8308QR<`P0QF4a2026H3<00`24GcD0Pehd089M<`02089M<`0308AO=@25H3H0
QV4g00P0Q5lb00@0PUdc085L<P21G380PE`b0P20Fc4207mJ<0P0OU`^2023GS401P21Fc@0P5Xc081J
<`1oFC80OUPa07eG<080O5H_0`1oFRd207iI;0<0OEP[201jEbd01@1oG380OEX`07]H;P1iER`0N5D[
0080NEH/0P1jEbd0101iER`0N5D[07QE:`1hEB/207MD:P80MU<Y0P1jEbd307UF;0<0N5D[201hF2l8
07IF;@0407IC:`1gE2`0Me@/07MD;0<0N5D]00<0NEH^071C:@1aE2X00P1aE2X3079E:`0307=F;01c
DbX0Le<Z00H0Le<Z00<0KU4W06mB:01`DbT00`1`DbT02P1_DRP0KU4W075?:@1bD2X0LU8[071C:`1^
DRX0JU4X06Q?9P1VCbDA06e@:0<0K4lW0P1[CRH206Y=9@0306Q;8`1YC2@0JTdU0080JdhV00<0JTdU
06U<901XBb<00`1ZCBD306]>9P80K4lW00D0IdlY06I>:01UCBL0I4`V06=;9@0206A<9P0406E=9`1Y
CBP0J4`W06M;9P80ITXU00<0Id/V06Q<9`1YCBP0201YBbL806E=9`80Id/V00@0J4`W06U=:01YCBP0
J4`W0P1WBbH206M;8`0706Q<901YCBD0JThV06Y>9P1YCBD0J4`T06M;8`0406]?9`@0JThV00P0JTXS
06];901YC2@0J4`T06M>9@1VCbD0IE0U06IA9P<0JThY0P1YCBP306Q<9`0406M;9P1VBRD0ITXU06I:
9@80IDTT0P1TB2<01@1SAb80I4PS06A88`1UBB@0ITXU0080Id/V00<0J4`W069:901RBR@01P1RBR@8
05m990<0GDLR00h0GTPS05m9901QBbH0HddX06A>:@1PCBD0Gd`T061:8`1QBB<0HdTT06M;9P1YCBP0
K4hZ06Q;:@<0JD`Z0P1ZCB/206]>;00606e=9P1^CRL0KThW06m?:01`D2T0LE4Z0P1bDR/01@1aCR@0
LTlU07AA9`1gE2X0NEH/00<0NUL]00H0NEd]07aM;P1lGBh0OUh_07mM;`22GC0208=M<080PV0b0P23
HC<308AR=00408ES=@28I3@0R6@d08QT=080RFDe0`2:ISH0102AIST0TVLj09=X>`2DJC`209EZ?@0>
09AY?02CJ3/0TVdi099]>@2CKSX0UG0l09Ia?@2GLSh0V7<o09Ud@02EL3/0UW4l09Qc?P2JMD0309]f
@@0=09Ye@02KMd<0VWI209Yf@P2HM400Ug<o09Qd@02KMd<0WWY60:1lB02ONTH0XGa80:9mB@030:Ao
B`050:=nBP2RODT0Y7m;0:F0C02WPTh00`2YQ5001P2XPdl0Yh9>0:V4D02YQ500ZXEA0:^6DP80[8MC
0P2]R5@80:j8F@070;2;E`2_RUH0[XUE0:j9E@2_RUH0/8]G0;6<F0040;:=F@80/HaH0`2`ReL40;6<
F0@0/XeI202dSe/00`2cSUX0/XeI0;6<F0020;6<F0030;>>FP2eT5`0]Y5M00<0/XeI0`2cSUX20;B?
F`P0/8aH0`2`ReL20;6<F0<0/XeI00<0[hYF0;2;E`2bSET00P2cSUX00`2bSET0/8]G0:n:EP080;2;
E`P0[h]G202_RUH30;2;EP030:n:E@2^RE@0[HQC0080[8MB202^RE@40;2;E`80[hYF0`2^RED30;67
E@80/XQF0`2cREL80:n:EP<0[HQD0`2^RED40:n:EP<0[XUE0`2]R5@80:j9E0X0[XUE0P2]R5@20:b7
D`80ZhIB00<0[XUD0:f8D`2[QU400`2ZQE020:^6D@080:V4C`2[QU40[HQC0:j9E02_RUD0[XUD0:f8
D`2/Qe880:j5D@<0[hEC0`2^Q5820:f3D@<0[89@0P2]Pe430:j4DP060:J2CP2XQ500ZXIB0:b8E02]
RED0[8QD0P2[Qe<0102^Q580[H=A0:f3D@2]Pe420:b2D080Zh5?00@0ZWmB0:^0D`2[P5<0Zh1C0`2/
PE@01`2]PUD0[XAD0:j4E02_QE<0[hIB0;27D`2`Qe400P2aR5080:b3C`P0[XEA2@2]Pe430:j4DP80
[H=A0`2/PU030:n6DP<0[XEA0P2]Q5080:j4DPP0/8MC0P2_QE<20:j4DP<0[H=A00<0[89@0:j5D@2^
QE401P2^QE430;27D`D0[hIB00P0/HQD0;27D`2^QE40[HA@0:b3C`2]Q500[XEA0:n6DP80[HA@0`2^
QE430:n6DPP0/8MC0`2/Qe<30:^6DPD0ZXEA1@2[QU830:^6D@<0[8MB0P2]R5<30:n5D`<0[XAB0P2]
Pe480:^6DP030:^6D@2/Qe80[HQC0080[XUD00<0[HQC0:b7DP2[QU400P2]Q5030:j5D@<0[hIB202^
Q5890:^6DP80[hEC0`2`QU@30;67E@P0[HQD00@0ZXEA0:^6DP2/Qe<0[HQD0P2/Qe<01@2[QU80ZXEA
0:f4D02^QE40/8MC0080/HQD00<0/8MC0:j5D@2]Q5000`2[PDl30:b2D080[H=A0`2[QU820:Z5D@<0
ZHA@00<0/8MC0:n6DP2^QE400P2]Q5000`2^QE40[hIB0;27D`080:f4D080[8Q>00@0[8M@0:b7DP2/
Qe80[8MC0P2/QUD20:b7D`<0[HQD0`2^RED0202^Q580[H=A0:b2D02/PU00[H=A0:j4DP2_QE<0/8ID
0`2[QU820:Z5D@<0ZHA@202^QE400`2`ReL0[hYF0:f8E0020:b7D`030:f8E02_RUH0/8]G0080[HQD
00<0[8MC0:^6DP2ZQE400`2YQ500102ZQE40ZhIB0:^6DP2[QU840:b7D`<0ZhIB0P2/Qe<30:f8E0P0
ZhIA0P2]Pe<00`2]Pe40[HA@0:f4D0020:f4CP80[HA<00@0ZhIA0:b7DP2/Qe80[8MB0P2]R5<20:j9
E0060:j9E@2]R5@0[HQD0:b7D`2[QU80ZXEA0P2YQ5020:b7D`040:^6DP2ZQE40ZXEA0:V4D080Z8=?
0`2WPTh20:R3C`<0ZHA@0`2/QUL30:^5EPX0ZXAE202]Pe480:N2CP<0ZhIB0P2ZQE430:V4D0030:R3
C`2YQ500ZhIB0080[8MC00<0ZhIB0:V4D02XPdl0202/Pdl00`2[PTh0[8=?0:f4D0020:j5D@030:f4
D02/Pdl0Zh9>0080Yh9>0`2XPdl30:V4D0P0Zh9>202WPTh0202ZPDd0Zh9>0:b3C`2/Pdl0Zh9>0:V0
C02WOTX0YWe90`2WOTX20:QoB`<0ZH1<00<0YX5<0:N2C@2XPdh00P2XPdh01P2VPD`0Y7m:0:=nB@2S
OTX0Y7m;0:F0C080YX5=00@0YH1<0:AoB`2TOd/0Xgi:202SP4X30:=nB@80XWe80`2QO4L02P2MNDD0
WgY60:5lB02TO4T0YG]90:EiB02UMdH0Y7I50:Al@@2TNd<20:AkA@80Y7Y800@0Y7Y:0:AiC02RO4d0
XWa=0P2QNd`40:1jB`0809ajC02LNTX0WWY:09ihA`2PN4D0X7M30:1g@@2QMT4809mjAP040:5lB02P
NdL0X7]70:1kA`<0WgY600<0WWU509miBP2ONDX01P2ONDX309iiAB_ooooo000Zooooo`P0SV<h0P2A
IST4091U>080TFHi1@2CIcX3099V>@80UFTl0`2DJ3/309=W>PP0UVXm202EJ3h809E]>P@0VFdl302H
K3/709Y^?@80VFdl0`2KKch209Y^?@<0VFdl00<0V6`k09Y^?@2LL3l00`2NLT401@2MLD00W70o09eb
?`2LLCh0Vg0m0080VVll00<0W74n09ic@02OM4400P2KLS`01P2KLSh0VW0n09Y`@02JKd80VFi109U^
@`80VVll0P2KL3d209aa?P80WG8o1P2OM44209ic@0080:5eA02PM4<0Wg=209ib@@2OLd80X7A30:9f
A@2SMdH709mf@P030:1g@`2SN440XgQ100H0XgQ10P2RNTH30:5iA@<0X7Q400@0XWM40:=hA@2TNDH0
Y7U61P2UNTL20:IkB0@0Yga9202TNDH20:9iA@060:=jAP2TNdL0Y7]70:AkA`2SNTH0XWU5202VODT0
102XOd/0YWe90:=jAP2QN4@309mf@P050:1g@`2NM480WWA209ec@@2LLT000P2KLCl209Y`?P80V6lk
0P2IL3`0202HKc/0UVdi09A[=`2CJSH0UFi309=/@@2@JCh0SVLl102<ICX00`2=IS/0S64d08aQ=006
08aQ=00608aO=@2;H3D0RUld08MN<P24GS40PE`_0P1nG2h04@1lES80OELc07iH=01oFCD0OUPd07eG
<`1kEC40NE<_07YG;`1iERh0N5D]07IC:`1eDRX0Le0X079?9`1aCRH0M54[0080Le0Z00<0LTlY075>
:01aCRP00P1`CBL01@1^D2`0KDl[06e?:`1/CRX0JT`X0080JD/W00<0J4XV06U;9`1ZC2P00P1[CBT0
3`1ZC2P0IdTU06E78`1SAB40HT/Y06199`1NAbD0GDHT05a58`1MAR@0GTLU05m89P1SA2D0I4DV06I7
:00206M8:@0306I7:01TABH0Hd@U00<0IDLU00<0ITPV06M99`1WBBL00P1XBRP206a;:00406e<:@1^
CBX0Kdh[071?;080LE0]00P0Jdd[06m>:`1aD2d0ME<^07MD;P1iDb`0NU<Z07UB:@@0O5H_101kEBh2
07iJ:P0307mK:`20G2`0PEd]0080PUh^00@0Pel_085L;`21G2l0PUd`0P23GS402`24Gc80QF0c08EP
<`22HS<0PF4b085O<@22GC00Peha08EO<P29H3@0Rf8f00P0Qf4d00<0Q5lb08EP<`27HSD00P28HcH0
2027HSD0QF0c08AO<P23GBh0QEl`08MQ<P29Hc@0RfDf0`2:I3D00`29Hc@0Qf4d08MQ=00608MQ=080
RfDf0P2:I3D01`29Hc@0R68c08QR<`28HS<0Q60`08EQ<@27Hc<00P28I3@00`27Hc<0QV8b08EQ<@02
08MR=@@0QV4d0P25H3<00`2:I3D0RF<d08US=00208QR<`80Qf4b00<0QV0a08AR=024HS@01P24HS@2
08QR=@80Qf4d00D0QV0c08EO<P25Gc80QElb08EO<00208IP<@80Qf4b0P28HS<00`29Hc@0QF4a08EQ
<@0608EQ<@P0QV0c00P0Q5le08=N=022GC<0PE`b089M<`23GS@0QF0f08MR>0P0Q5lb0P22GC<3085L
<P<0P5/a201mGBh808=N<@80PU`g00@0PE/f081J=@1oFC@0OUPc0P1mEc80101oFRd0OUT/07iI;01n
FB`207eH:`80O5LZ201kF2h00`1lFBl0NeP^07YG;@0207QE:`0507UF;01kF2h0O5T_07aI;`1jEbd0
0`1iER`207QE:`80Me@Z0P1jEbd307UF;0<0N5D[201fERd307AD:`0307EE;01fERd0MeL^0080N5P_
0P1dDBT207EB:P0407IC:`1gE2`0Me@/07MD;0<0Ke@Y00<0L5DZ075F:`1aER/00P1bEb`807=C:P03
06e@9P1^DBL0L5<Y0080LE@Z00/0L5<Y06iA9`1]D2H0Le4[07AB;01dE2d0LUD]06mC:`1[DRT0JE0W
06M@9P0606e@:080KU4Y201]D2P306a?9`80JdhV0`1ZCBD00`1WBR80J4/S06U<900206Y=9@0306U<
901XBb<0IdXR0080JD`T0P1ZCBD03`1[CRH0K4lW06a?9`1/CbL0Ie4Z06I@:@1TCRL0HT`U065;901R
C2D0HddV06A>9`1YCBP0J4`W06I:9@0206E9900306I:9@1XC2L0JDdX00@0JD/W101XBRH806==9P03
06I:9@1WBbH0J4`W0080JDdX00<0J4`W06M;9P1VBRD00P1YCBD01`1ZCRH0JdlW06]?9`1ZCRH0J4`T
06I:8P1TB200201YCBD206Y:8`0406U<901XC2@0IdhU06I?9@80IU4V0P1[CbX206Y>:@<0JDdX00<0
J4`W06M;9P1WBbH00`1VBRD306E990P0ITXU201SBbD805i88`0305a88`1KAb80FTHQ0080FTHQ00/0
G4PS05i:9@1OBbH0H4dU05m<901PBR<0HDTS06=9901WBbH0JDdX06]=:@0306Q;:`80JD`/0`1ZCBd0
1P1/C2D0KDdV06e=9P1^CRL0KdlX071@:@80LE4Z00D0L4dS079?9@1eDRP0N5D[07YG;@0307]H;P08
07MK:`1iFR/0NU//07eM;P1oGBl0PUd`08AN<@25Gc83089P<P80Pf4c0`24HS@408QT=080RFDe0P2:
ISH00`2CJ3/0TVLj099W>P02099W>P0?09=X>`2EJSd0UFXm095/>02BKCT0Tfhj09A_>`2FLCd0Ug8n
09Qc?`2IM400U6lj09Ia?02HLch0VWE00080VgI100<0VWE009Ud?`2KMd<00P2IMD405P2FLSh0UG4m
09Ib?P2IMD40WGU50:1lB02ONTH0X7]70:9mB@2SOTX0Y7m;0:=nBP2RODT0XGa80:AoB`2UP4`0Yh9>
0:R3C`2YQ500Z8=?0:N2CP2VPDd20:R3C`040:V4D02ZQE40ZhIB0:b7D`80[HQD202_REX01`2`ReL0
[hYF0:j9E@2]R5@0[XUE0:n:EP2aS5P00P2bSET30;6<F080/8]G0P2_RUH40;:=F@@0/HaH2@2cSUX0
1`2bSET0/HaH0;6<F02aS5P0/hiJ0;F@G02fTEd00P2dSe/30;>>FP<0/XeI202_ReL30;2;E`030;6<
F02bSET0/XeI0080/hiJ00<0[hYF0;6<F02bSET00P2cSUX00`2bSET0/HaH0:n:EP080;2;E`P0[h]G
202_RUH@0:j9E0@0/8]G0P2_RUH30:j9E@<0/hUG0P2bR5H30;67E@P0[hYF0`2]R5@30:j9E@@0[hYF
0`2^RED30:f8E0H0[XUD0P2]R5<:0:j9E@80[HQD0P2/Qe<20:^6DP0@0:j9E02]R5<0ZhIA0:Z5D02Y
Q4l0ZXE@0:^6D@2/Qe80ZHA?0:^6D@2]R5<0[XUD0:n:E@2^RE@0[HQC0:b7DPP0[XEA0`2_QE<30:j4
DPD0[H=A0P2^Q5830:n5D`040:B3CP2UQ4l0YhIA0:V8D`80ZhYE00<0ZXUD0:V8D`2]Pe400P2]Pe42
0:b2D0<0Zh5?0P2[P5<20:b1E0040:f2E@2^PeH0[X=F0:j3EP80[XAD00@0[hEC0:n6DP2`Qe<0/8MA
0P2aR5080:b3C`P0[XEA2@2]Pe430;26E0030:n5D`2^Q580[XAB0080[H=A0P2`Qe<20:n6DP040:j5
D@2]Q500[HA@0:f4D0P0[XAB202aR5@30:n5E@80[XAD0`2]Pe<80:j5D@<0/hYF00<0/XUE0;68E02`
Qe<00P2_QU800`2aR5@0/8MC0:n6DP020:j5D@030;27D`2bRED0/hYF0080[HA>0`2^QDl30:n6D0P0
/8MC0`2/Qe<30:^6DP80ZXEA0P2[QU860:Z5D@80ZXE@0P2[QU420:b7DP80[HQC0P2`QU@20:n5D`04
0:j4DP2]Pe40[H=A0:f3D@P0ZhIB00<0ZhIA0:b7DP2]R5<00P2^RE@00`2]R5<0[8MB0:^6D@020:f4
D0<0[XEA0`2_QU880:j4DPT0ZhED0`2^Q5830:n5D`80/8ID202]R5@00`2YQ500ZXEA0:b7D`020:f8
E0060:b7D`2[QU80ZXEA0:f4D02^QE40/8MC0P2aR5@00`2`Qe<0[hIB0:j5D@030:f3D`050:b2DP2[
PE40Zh5A0:^1D@2ZP5000`2YQ5020:Z5D@<0ZhIB00<0/8MC0:n6DP2]Q5000P2/Pdl00`2]Q500[hIB
0;27D`080:f4D080[8Q>00@0[8M@0:b7DP2/Qe80[8MC0P2/QUD20:b7D`80[HQD0P2^RED20:n:EP80
[H=A0P2[PDl0102/PU00[H=A0:n5D`2aQeD30:V4D080ZXEA0`2[QU880:j5D@030:n:EP2^RED0[8MC
0080ZhIB00<0[8MC0:j9E@2_RUH0202[QU830:f8E0<0[8MC102[QU820:b7D`@0[HQD202ZQDh20:f3
D`030:f3D@2]Q500[HA@0080[HA>0P2]Q4`20:b7D080[HQA0`2^RE802@2_RU<0[XUE0:j9E@2]R5@0
[8MC0:^6DP2ZQE40ZHA@0:R3C`020:b7D`040:^6DP2ZQE40ZXEA0:V4D0@0Z8=?0P2YQ5020:Z5D@80
ZhIB0`2/QUL30:^5EPX0ZXAE202]Pe<40:R3C`@0ZHA@0`2[QU820:Z5D@@0ZHA@00L0ZXEA0:b7D`2]
R5@0[HQD0:b7D`2ZQE40ZHA@00H0[8=?0P2[PTh00`2ZPDd0Zh9>0:f4D0020:j5D@030:f4D02[PTh0
ZX5=0080Yh9>0P2XPdl20:V4D080ZXEA202/Pdl50:N2CP<0Z8=?00<0ZGm=0:Z0CP2[PDl00P2/PU00
0`2[PDl0ZGm=0:QnC0030:MnBP80Z7m;0`2YP4`00`2VPD`0Yh9=0:R3CP020:R3CP060:J1C02TOdX0
Xgi90:=nBP2TOd/0YX5=0P2WPTh0102VPDd0Y7m;0:AoB`2SOTX80:60BP@0Xgi90P2RODP20:5lA`0@
09mkA`2QO4P0XWe90:AlB@2TNTP0Y7Q70:=eA02RM4<0Y7`o0:Al@@2TNd<0Y7]50:AjB02TNTX0Y7U<
0:AiCP<0X7Y;0P2QNd`30:9lC@80WG];00<0WWY809mjAP2PN4@00P2QN4800`2QMSl0WWU509iiA@06
09iiA@<0XGa800<0X7]709mjAP2ONTH00P2NNDD809miBP<0WgY6:oooool002[ooooo202>HcP00`2A
IST0T6Dh091U>004091U>003095V>@2BIST0TVHi0080TVHi102CIcX209IZ?@0309EY?02DJ3/0TfLj
0080TVHi00<0TFDh09AX>`2DJ3/01P2DJ3/809EX?PP0UVhk0P2KKch00`2JKSd0VFdl09Q/>`0209M[
>P0309IZ>@2HK3/0V6`k00H0V6`k0P2KKch509Y^?@80VFdl0P2LL3l0102KKch0VVhm09Y^?@2IKC`2
09Q/>`0:09U]?02JKSd0WG5009mc@P2PM4<0Wg=209ib@@2MLD00WW=009eb?`<0Vg0m00`0WG8o09md
@@2PMD80WG@n09ac?@2LLcl0Vg4o09Y`@02IKT40V6e009Q]@P2IKS/209Y_?00309]`?@2LLCh0W74n
0080WG8o0P2PMD8409md@@80WW=000<0XGE40:1d@`2OLd800P2NLT400`2PM4<0XWI50:AhA`030:1g
@`<0WgI20P2NMD480:=h@@80XWY60`2QNDD30:1hA0030:AiAP2SN4D0XgQ50080XgQ500<0Y7U60:Ik
B02VNdP00P2UNTL20:IkB0<0Yga900<0Z7e:0:AiAP2TNDH01P2TNDH00`2QN4@0XgY60:ElB0020:Im
B@030:AkA`2QN4@0WgI200P0YWe900P0Z7m;0:ImB@2SNTH0X7M309mf@P2NMD40WgI20:1g@`80WWA2
00<0WG=109ab@02KLCl00P2JL3h00`2IKcd0Ufhj09Q_>`0209U`?00809Q_>`2FKCT0U6/g099Y=@2E
KT<0Tfa1091Y?P2=IS/308]T>@80S6Dj202;H3<0402=H3H0Rf0e08YO=028Gc<0Q5ha089M<01oGBl0
OU`^07]E<@1lES80OUPd07mI=@1nF3@0O5Hb07YD<01iDbl207UF;P0407QE;@1fDb/0M54Y07=@:080
LDhV0P1cD2X2079?:@05075>:01`CBL0L4dW071=9`1^D2`00P1]Cb/00`1[CBT0JT`X06U;9`0206Q:
9P0;06U;9`1ZC2P0JddY06]=:@1ZC2P0IdTU06E78`1SAB40HT/Y06199`1NAbD00P1LAB<01P1MAR@0
GTLU05m89P1R@b@0Hd@U06E69`80ITLX00<0IDHW06=49@1R@b@00`1VB2H00`1WBBL0J4XX06U;:@02
06U;:@0606a;:01]C2T0KD`Y06m>:`1`Cb`0LE0]0P1bDBh01P1[CB/0Kdh[079A;P1eDbh0Me@^07YD
;@80NU<Z0P1mEc0407aF;`80NeD^00H0OUXZ07mK:`20G2`0P5`/085M;@22GRh208=O;`80P5/^00h0
PE`_08=N<@24Gc80QF0c08IQ=027HSD0Pf<d089R<`21Gc40PUd`08=N<@25Gc80RV4e08]R=PP0Qf4d
00<0Q5lb08EP<`27HSD00P28HcH01`27HSD0QF0c08AO<P23GBh0QEl`08MQ<P2:I3D00P2;ICH208YT
=@0308US=027HC@0Qf4d00H0Qf4d0`2;ICH00`2:I3D0RF<d08QR<`0208QR<`0807mK:`21GBd0Q60`
08MS<`29ICD0RVHf08UU=@28I3@808IQ=080RV@e0P29Hc@01028HS<0Qf4b08MQ<P26H34808AR=080
Qf4d0P26H3<01025Gc80Q5ha08AN<@23GC0208EO<00408IP<@27HC80Qf4b08QR<`80RF<d2025HC48
08IP<`0308EO>023GCH0PU`e0080PE/d00<0Pedf08EO>027HCX02024Gc83089M<`80PE`b0`20Fc48
07eM;PP0Peha0P23GCP01P22G3L0PE/f081J=@1oFC@0OUPc07eG<P@0OUT/0P1mF2/207aG:PP0O5T_
00<0NeP^07YG;@1iER`00P1hEB/01@1jEbd0O5T_07eJ<01mFS00NeP^00<0NUL]0P1iER`207QE:`80
NUL]0`1iER`307QE:`P0MED/00P0LU8Y07=C:P1dE2/0MED/07IF;@1gEbh0N5P_07UI<0<0Le0X00<0
M54Y07EB:P1fDb/00P1fDb/206iC:00406mD:@1`EBX0L5DZ075F:`80LUL/201cDbX00`1/CbD0KU4W
06mB:002075D:P0306mB:01^DBL0K4lU0080ME<]00H0MED^07=F;P1`E2`0K5<Z06YA:01WD2H506e@
:0<0KU4Y201]D2P206a?9`<0JdhV0`1ZCBD00`1WBR80J4/S06U<900206Y=9@0306U<901XBb<0IdXR
0080JD`T0P1ZCBD01`1[CRH0K4lW06a?9`1]D2P0Ie4Z06I@:@1SCBH00`1QBb@01@1SCBH0I4hW06U=
:01XC2L0ITXU0080IDTT00<0ITXU06Q<9`1YCBP00`1YBbL506Q:9PP0HddV00<0IDTT06I:9@1XC2L0
0P1ZCRT00`1XC2L0ITXU06E9900206Y>9P0706]?9`1/D2P0K50X06Y>9P1WBb<0I4PP06967P0206M;
8`@0J4`T0P1YCBD206Y:8`0406Q;8`1XC2@0IdhU06M@9P80IU4V0P1[CbX206Y>:@@0JDdX0`1WBbH2
06I:9@<0IDTT0`1XBRH206M99@<0ITPT201SBbD805a68@0305e9901KAb80FDDP0080F4@O00<0FTHQ
05a88`1MBB@00P1OC2@01`1PBR<0HDTS06=9901WBbH0JDdX06]=:@1WBRX00`1XBb/206U<;080JTd]
0P1/C2D02`1]CBH0KThW06m?:01_CbP0L50Y075A:P1`CB<0LTlU07IC:@1iER`0NeP^0080O5T_00L0
NeP^07EI:@1hFBX0NEX[07aL;@1oGBl0PUd`0080QElb0`22H38308=Q<`80Q68d00@0Qf<c08QT=028
I3@0R6@d0P29ICD208YV=P0309IZ?@2DJ3/0TVHi0080TFDh00T0TfLj09IZ?@2HK3l0TF`h099]>@2C
KSX0U6lk09Ia?@2GLSh00P2HLcl0102DKcX0UW4l09Qc?P2JMD0209]f@@0309Ye@02IM3l0VWI20080
V7A000T0UW8n09A`?02ELCd0VGE109eiA@2ONdL0WWU50:1kA`2QO4P00`2SOTX01@2RODT0XGa80:Ao
B`2UP4`0Yh9>0080Z8=?00<0Yh9>0:J1C@2UP4`00P2WPTh0102XPdl0ZHA@0:^6DP2/Qe<20:f8E0P0
/8YK00<0/8]G0:n:EP2]R5@00P2]R5@00`2_RUH0/HaH0;:=F@040;6<F080/8]G0P2_RUH01@2dSe/0
/hiJ0;>>FP2bSET0/HaH0080/8]G00<0[hYF0;:=F@2bSET01P2bSET00`2cSUX0/XeI0;6<F0020;6<
F0030;>>FP2eT5`0]Y5M0080]I1L00<0]8mK0;>>FP2bSET00P2aS5P00`2`ReL0[h]G0:n;E`060:n;
E`<0/8]G00<0/HaH0;:=F@2cSUX00P2cSUX00`2`ReL0/HaH0;:=F@020;>>FP030;:=F@2aS5P0/8]G
00P0/8]F202_ReL80:n:EP<0[HQC0`2^RE@20:n:E@P0[XUD102`ReL20:n:EP<0[XUE0P2dRUP0102c
REL0/XQF0;:8EP2aQeD20;26E0P0[hYF0`2]R5@30:j9E@@0[hYF0`2^RED30:f8E0D0[XUD0`2]R5<:
0:j9E@80[HQD0P2/Qe<20:^6DP030:n:E@2]R5<0ZhIA0080ZHA?00/0ZXE@0:^6D@2/Qe80ZHA?0:^6
D@2]R5<0[XUD0:n:E@2^RE@0[HQC0:b7DP080:j5D@<0[hEC0`2^Q5820:f3D@<0[XAB0P2_QE<30;26
E0040:>2C@2UQ4l0YhIA0:V8D`80ZhYE0P2ZRE@20:f3D@<0[89@0`2[PDl20:b1E080[H9E00@0[X=F
0:n4E`2_Q5L0/8EH0P2^Q5@0102_QE<0[hIB0;27D`2`Qe420;68D0P0[8=?202^QE490:f3D@80/XQF
00@0/HME0;26E02`QU@0[hEC0P2^Q5820;27D`80[hIB00@0[XEA0:f4D02]Q500[8=?202^Q5880;68
E0<0[hEE0`2^Q5@20:f3D`P0[XEA00X0]XeI0;F<F02dReL0/hYF0;:9E@2aR5@0/8MC0:n6DP2aR5@0
/8MC0P2_QU80102`Qe<0/XUE0;B;E`2eS5P20:f4CP<0[XE?0`2_QU080;27D`<0[8MC0`2[QU820:Z5
D@80ZhIB102ZQE420:V4D0040:V4C`2ZQE00ZXE@0:^6D@80[8MB0P2]R5<20;26E080[hEC00@0[XAB
0:f3D@2]Pe40[89@202[QU800`2[QU40[8MB0:f8D`020:j9E0030:f8D`2/Qe80ZhIA0080[HA@0`2^
QE430:n6DPP0[XAB2@2[QE@40:f3D@80[XAB0P2_QE<80:f8E00;0:R3C`2ZQE40[8MC0:f8E02^RED0
[HQD0:^6DP2ZQE40[HA@0:j5D@2`Qe<00`2aR5@0202_QU80[XEA0:n5E@2^Q5@0[H=C0:b2DP2[PE40
ZX1@0P2YOdl20:R3C`040:V4D02ZQE40ZXEA0:^6DP80[8MC00<0/8MC0:n6DP2]Q5000P2/Pdl00`2]
Q500[hIB0;27D`080:f4D080[8Q>00@0[8M@0:b7DP2/Qe80[8MC0P2/QUD20:b7D`80[HQD00`0[XUE
0:n:EP2_RUH0/8]G0:f3D@2/PU00Zh5?0:Z0CP2[PDl0[H=A0;26E02aQeD20:R3C`040:V4D02ZQE40
ZXEA0:^6DP80[8MC202^QE400`2^RED0[HQD0:^6DP020:Z5D@030:^6DP2]R5@0[XUE0080ZXEA0`2[
QU830:b7D`050:n:EP2^RED0[XUE0:f8E02/Qe<00P2[QU800`2ZQE40ZhIB0:^6DP020:b7D`<0[HQD
00<0[XUE0:Z5CP2ZQDh01P2ZQDh20:f3D`030:f3D@2]Q500[HA@0080[HA>0P2]Q4`0102/Qe00[HQA
0:f8D@2]R5420:j9DP80[hYC0P2^RED00`2]R5@0[8MC0:^6DP020:V4D0040:R3C`2/Qe<0[8MC0:^6
DP80ZXEA00@0ZHA@0:R3C`2XPdl0ZHA@0`2ZQE420:^6DP80[8MC0`2/QUT30:^5F0X0ZXAG202]Pe<5
0:V4D0<0ZXEA0`2[QU820:Z5D@@0ZHA@00L0ZXEA0:b7D`2]R5@0[HQD0:b7D`2ZQE40ZHA@00D0[8=?
0`2[PTh00`2ZPDd0Zh9>0:f4D0020:j5D@030:f4D02[PTh0ZX5=0080Yh9>0P2XPdl0102YQ500ZXEA
0:Z5D@2[QU880:b3C`@0Yh9>102XPdl00`2XOT`0ZGm=0:^1C`030:b2D0030:^1C`2ZP4h0Ygi:0080
Ygi:0P2XOd/30:V0C0030:J1C02WPTd0Z8=>0080Z8=>00H0YX5<0:AoBP2SOTT0Xgi:0:AoB`2VPDd2
0:N2CP040:J1C@2TOd/0Y7m;0:=nBPP0XH1:00@0Y7m:0:=nB@2SOTT0Xgi90P2RODP20:5lA`0F0:5m
B@2RODT0Xgi:0:AlB@2TNTP0XgM60:9d@`2QLd80YGdo0:Em@02UOD80Y7]50:AjB02TND`0Y7U>0:Ai
C`2NN4/0WgU<0:1jC@2QNdh0XWa?0:=mD080Y7iA00P0WG];09elB@2NNTP0WgY60:1hA02QN480XGQ0
0:9g@0P0WGQ40P2RODT0102QO4P0X7]70:1kA`2ONTH209iiA@P0WgU:0`2ONTH[ooooo`00:_ooool8
09AS>PP0UVDj202DJ3/209AX=`80TfLf0`2BISD01@2AIC@0VFHk09YW?02JIc`0VfPm0080W6Tn0P2M
JSl0102CJ3/0U6Tl09AY?02EJSd209I[?P80Uf`o202GJch0102IKC`0V6`k09Q/>`2HK3/309M[>P05
09IZ>@2ILCh0V70m09Q`?@2GKc`00P2FKS/209E]>P@0VVi10P2IKD002P2HK3l0Uf/n09IZ?@2LL3l0
VVhm09Q/>`2FJST0UFTh09IZ>@2GJcX309Q/>`0409U]?02JKSd0VVhm09]_?P80W70o202KL3d00`2M
Ld40W79009Y`?P0209Q^?00309U_?@2KLCl0W7900080Vfln00<0W70o09ea@02NLT400P2PM4<0102Q
MD@0X7A309mc@P2MLD0209a`?`0309ea@02OLd80X7A30080WWE10`2OMT830:1g@`0509id@P2OMD<0
WgE30:1fA02QMdD00P2RN4H0102SNDL0XWU50:9iA@2RNDD20:5hA0<0X7M300P0WW=009md@@2PMD80
XGI30:9gA02SN4D0Y7U60:EjA`80XgY60`2TNdL60:ElB0<0Y7]70P2SNTH01`2TNDH0YGY70:IkB02W
O4T0YW]80:AiAP2QMT<00P2PMD801`2RMd@0Y7U60:EjA`2VNdP0YGY70:AiAP2RMd@00P2RNDD40:=j
AP80Y7]700`0YGa60:AkA@2SNTH0XGM50:1fAP2NLdH0WG9509aaAP2PMT@0WWA209ab@02JL3h209U_
?@0:09Y`?P2KLCl0VG0l09U`?02HKc/0UVdi09E/>02DJcL0TfXf099Y=@80U6Pk00<0TVHi095U>02?
HcH00P2=HC@208aP<`06091T=`2?HcH0SV8e08eQ=02;Gc80RUha0P29GC0308=N=080PUdc0`21G383
07eG<080O5H_0`1kEBh0201jDRh0NE4]07MA;01dDB/0LU0Z071@:@1_CbP0KE0X0`1^D2`506e?:`80
JT`Z101YBbT206Y<:PD0J4/Y0`1WBRP02`1SAB<0HT@R06538@1Q@b40HT@R06A6901VB2H0J4XX06U:
:`1XBBX0ITLX0080IDHW00<0ITLX06Q9:P1YBR/00P1TAbL01P1UB2P0IdXZ06Q;:`1YC2`0JTd]06]>
;P80KdhU0P1`CbH3075@9`06079A:01gD2L0Me0W07QA:01iDRT0NU<Z0P1kE2/207aE;080OEH]00<0
OUL^07mH;`1oF2l00P20FC0207mJ;P06081K;`22GC40Pehb08AO<`25H3@0QV4e2022GC0208US=004
08QR<`27HC80Qf4b08IP<@80QEl`0P25H2`01026HBd0Qf8^08MR;P28Hbl208UT<0<0QV0a0P27HC83
08QR<`0308eR=`2;H3D0REhc0080Qe`a00@0REhc08]P=@2;H3D0SF8g202;H3D208MQ<P80QV0a00L0
QEl`08AN;`24GRl0Ped^08QR<`29Hc@0RV@e0080RfDf00<0RV@e08US=028HS<00`28I3@308MS<`X0
QV8b2025HC4808MQ=0<0RF<f0`28HSD208MQ=0P0QV4d0P21HC801022H380QF0c08EP<`26H3<208QO
<`80PUd`0P23GS4208AO<P80QF0c00H0R6@d08MS<`26HS80QF4a08AP<023Gbl2089N;P80QF0c00@0
Peha089M<020Fbh0OeX]0P1mF2/807iN;`<0Ped`0P22G2l3085K;P0607YE:`1kER`0NeH/07aG;@1m
F2h0OUT_0P1oFS02085M:`03081L;020Fbh0P5/_0080OeX`00L0OeTb07eG<01mF2h0OEP^07eH;01m
F2/0OETY0080OETW2@1kF300201dDBL0Le0V07=@9P1dDBL0ME8X07QE:`1kF2h0O5T_201lEBh207]M
:`0407YK;01iFR`0MeP/07IF;@80MED^0`1eEB`307AD:`80Le<Z00H0JE8X06YC:@1ZDbT0Je@Z06aE
:`1]ER`206iG;@08075D;01`Db/0KU4Y06e@:01^DBT0Ke8Z079E;@1cERh2075D;004071C:`1_DRX0
KU4Y06e@:080K4lW201^DBT807=A:`0306mB:P1^DBT0K4lW0080JTdU00<0JdhV06a?9`1]D2P0201Z
Cb@806i>9@0406eB9`1/DBH0K54V06]@9@80JTlT0P1YCR<306Y=:`80JD`Z0`1XBbT806A=90P0Hd`S
00@0HTXV06=;9`1SBbL0I4`X0P1UCBT206I>:P0306==:01RC2L0H4XU0080GTPS00/0H4XU069<9`1S
CBP0IdhV06I=9@1SC2<0H4XQ05e:801MC240GdhS05i?900906A=9080H4`W00<0HT`W06A<:01UBbP0
0P1XBbT04@1YBbT0KDl[06a>:P1[CBT0JT`X06U;9`1XBRH0IdTU06I8901XD2X0JE4[06YB;01[Dbd0
JU8/06Q@:P1UCBL0I4`V00<0IDdW0`1TC2H206=;9@<0HTXT0P1SBbD306A<9P0405m78@1PB280H4PR
06188P80HDTS0P1RBR@02@1VB2@0HdLR0655801M@ah0G4@N05]57P1KB200G4TQ065;9P03061:9@<0
GdTT00<0GTPS06599@1RBRH00`1RBRH306=;9`0406=6901TAbD0IdXX06U<:P80JTd[00X0J4/Y06M:
:01WAR<0JTTV06e<:@1`Cb`0LU4^075@;@1`Cb`0Kdh[0P1_CbH00`1`D2L0LE4X079B:@0207=C:P09
07AD:`1mGRl0O5d^07]L;@1jFb`0Ne`]07eN;`20HC80PV<d0080PV0b0P21Gc401020GS00Oed_07mM
;`1nG2h208=Q<`80PV0b00D0Pf4c08ES=@27ICL0R6Hh08aX=00208eY=@0308iZ=P2?JcL0T6`h0080
TFdi0P2CIcH209AX=`0409EY>02FJST0Uf/j09M[>P80UG8l00@0UW<m09Md?P2HMCl0VGI00P2JMd40
2@2MN4@0W7M309ag@`2KMT80VWE109]f@P2LMd<0WWU509mjAP030:9mB0@0XGa700@0X7]60:N2CP2W
PTh0Yh9>102VPDd04@2UP4`0YX5=0:N2CP2XPdl0ZXEA0:b7D`2^RED0/8]G0;6<F02_RUH0[XUE0:b7
D`2[QU80ZXEA0:^6DP2/Qe<0[HQD00<0[HUE0P2^RUH30:n;E`80/8]G0P2aS5P20;:=F@80/hiJ202b
SET20;B?F0<0/hiG0`2bSEH80;>>FPP0]8iO00<0/hmK0;6=F@2`S5P00P2^RUH0102`S5P0/HeI0;>?
F`2`RUd20;2:F`030:n9F02_RUH0[XUD0080[XUB0P2cSUT20;:=F080/HaG0P2`ReH0202]R540[hYC
0;6<E@2cSUL0]8mH0;>>E`2bSEH0/HaE202`ReL00`2^RE80/8]D0;6<E@020;:=EP030;6<E@2`Re@0
[XUB0080[hYF00@0[hYE0:n:D`2_Re40[h]A0P2_Rdl20:f8E0040:j9E@2_RUH0[hYF0;2;E`80/HaH
102^R5T20:n9FP<0/8YK00H0[hUL0:n9FP2^R5T0[XQG0:j9E@2]R5<20:f8D@P0/XQF00@0]8iQ0;>=
H02`RUd0[HMJ0P2/QUT01@2]QeX0[XQK0:Z5D@2/Qe<0[hYF0080/XeI00<0[hYF0:b7D`2ZQE400P2_
RUH30:j9E@<0[HQD00<0[XQK0:n9G02aReh00P2bS5l00`2aReh0[hUL0:j8F`020:^6C`070:b7DP2/
Qe<0[HMF0:f7F02^R5T0[XQK0:^5F0020:^5EP030:^5E02[QU80[8MB0080[8M@0P2[QU820:b7D`<0
[HQD00@0[XUE0:b7D`2/Qe<0ZhIB0P2ZQE401P2YQ500Z8=?0:R3C`2XPdl0ZHA@0:^6DP80[8MC00<0
ZhIB0:V4D02XPdl01@2[QU830:b7D`080:b7D02[QTl0ZHA?0:R3C`2XPU40ZH=D0:^5EP2/QUT20:^6
DP80[8MC0`2]R5@00`2^RED0ZX5=0:V0C0020:V0C0040:Z1C@2/Pdl0[hIB0;27D`80[XUE0P2]R5@2
0:b7D`X0ZhIB102/Qe820:^6D@80ZXE@0`2YQ4l30:Z5D0<0ZhIA0P2ZQE430:^6DP<0[8MC0P2[QE@0
102[QU80ZXE@0:Z5D02YQ4d20:V5B`<0[8MB0P2]R5<30:j9E0P0/8MC202^Q5820:Z6BP040:^7C@2/
R4h0[HQA0:j9E080[hYF0`2`QU@50;67E@P0[XEA0P2ZQE430:^6DP<0[8MC0P2[QE@0102[QU80ZhIA
0:^6D@2[QTl20:^7C@P0[XAB202[QU800`2[QTl0[8M@0:f8D@020:f8D@030:^6C`2YQ4d0Z8=<00<0
ZhIA00<0[8MB0:f8D`2^RE@00P2^RE@80:f8E0080;B9GP2cR5/0/HII0:n5E@2_QE<0[hIB0;27D@2a
R5820:n:E@040:j9E02]R5<0ZhIA0:Z5D080ZHA?0P2^RE801P2]R5<0[HQD0:b6E@2/QUL0ZhEF0:^5
F080ZXEA00D0ZhIB0:b7D`2]R5@0[HQD0:j9E@020:n:EP030:f8E02/Qe<0ZhIB0080ZHA@00<0ZhIB
0:b7D`2]R5@03@2^Q5830:n5D`P0[hIB202[QU880:f3D@030:j4DP2_QE<0[hEC0080/8ID0P2aQeD0
0`2bR5H0ZhIB0:^6DP060:^6DP80[HQD00H0[XUE0:n:EP2^RED0[8MC0:Z5D@2YQ5080:^6DPP0ZHEE
00<0Yh9=0:R3CP2ZQE000`2/Qe801@2ZQE00ZHA?0:R3C`2XPdl0ZHA@0080ZXEA00@0ZhIB0:b7D`2/
Qe<0[8II0P2/QUL00`2[QE@0ZhIB0:^6D@020:Z5CP040:n6DP2`Qe<0/8MC0;68E080/XUE0P2cRUH5
0:^6D@<0[8MB0`2^RE@00`2]R5<0[8MB0:^6D@020:^6D@80[8=;00@0[8==0:f4D02]Q500[XAB0P2^
Q5@90:Z5D080ZXEA0`2[QU840:b7D`0:0:f8E02^RED0[XUE0:f8E02ZQE40Z8=?0:J1C@2]R5@0[8MC
0:Z5D@<0Z8=?00<0ZXEA0:^6DP2]Q5001`2]Q5030:b7D`D0ZhIB00<0[8MC0:^6DP2YQ5000P2XPdl0
0`2YQ500ZhIB0:b7D`080:j4DPP0ZhEH202ZQE430:^6DP80ZXEA0`2YQ5020:Z0D0040:Z0CP2ZPDd0
ZX5=0:Z1B`80ZX59202YQ4l20:J1C@80Yh9>0P2XPdl20:V4D0P0Z85F00/0ZH=B0:Z4D`2[QE@0ZhED
0:Z4D`2XPU40YX1?0:EoCP2[PDl0ZGm=0:QnC0020:MmB`030:QnC02YOdd0Zh5?00P0Z8=>202VPDd2
0:F0C0<0Y7m;102SOTX80:J1C0060:Z1C@2YP4`0Z7m;0:MnBP2VODT0YGa80P2TNdL20:1kA`<0XGa8
0`2RODT50:5lB0<0XWe90P2ONT<01P2PNdH0X7]70:1jB@2PNT/0XG]<0:5kCP80W7M000h0WGQ309eh
A02NN4L0WWQ909miBP2OND`0VWE109]f@P2LMd<0WGQ409iiA@2ONTH0X7]70:5lB080Xge>00@0XWa=
0:5kC02ONDX0WWQ90P2MMdP0202QO4P0WgY609ehA02LMd<0VgI209ag@`2MN4@0WgY60`2NN4T[oooo
o`00:_ooool809AS>PP0UVDj202DJ3/209AX=`80TfLf102BISD309QW?00309UX?@2JJCh0VVTn0080
VfXo0`2DJC`00`2EJSd0UV/n09I[?P0209M/?`P0UVXm102GJcX409Q/>`<0V70m00<0Ufll09I^>`2F
KS/00P2EKCX309Y^@@<0VFe000/0V6`o09M[?P2GJch0Vfln09Y^?@2HK3/0UVXi09EY>02FJST0Uf/j
09Q/>`0309U]?080VVhm0`2KKch809]`?@0809ec@@2LLT00VW0n09U_?@2HKS`0VFlm09]a?`2LLT02
09]_?P0909a`?`2MLD00WW9109mc@P2PM4<0XGE40:1d@`2OLd80WG500080W70o00<0WG5009mc@P2P
M4<00P2NMD4309mf@P<0X7M3102PMT@40:5gA@<0XgY60P2RNDD30:5hA080WgA100@0X7E20:5f@`2R
Md@0XgQ50P2TNDH20:=jAP<0Y7]71P2UO4P30:AkA`80XgY600<0XgQ50:AiAP2UNTL00P2VNdP02`2T
NDH0XWM40:5f@`2QMT<0XgQ50:EjA`2VNdP0Yga90:IkB02UNTL0Y7U600P0XgY60P2TNdD02P2SNTH0
XGM509meA@2NLdH0WG9509aaAP2OMD<0WWA209ab@02JL3h209U_?@80VW0n00H0V6lk09M^>P2FKCT0
UF`h09A[=`2BJCD2095X=00509=X>`2BIcX0TFHi08mT=`2>HcH00P2<HC@02P2;H3<0RUlb08iS=P2>
HcH0SF8e08]P<`2:Gc80REha08QM<027G2l208=N=080PUdc0`21G3800`20Fc40OEL`07eG<00207aF
;`<0NeD^00T0NU@]07UA;@1iDBd0Me4/07AA:`1bD2X0L50Y06m?:01]D2P00P1^D2`406e?:`80K4hZ
201YBbT406M::0@0ITTW00<0IDLU06A6901RA2800P1RA2801P1SAB<0IDLU06M99`1YBR/0J4TZ06M8
:@80ITLX00<0IdPY06Q9:P1YBR/00P1VBBT206M::P0406Q;:`1YC2`0JTd]06Y=;@<0L4lV0P1aD2L3
079A:00607M@9`1hDBP0NE8Y07UB:@1jDbX0Ne@[0P1lEB`207eF;@80OUL^00D0OeP_081I<020FC00
P5T`081K;`02085L<005089M<@23GS80Q5lc08AO<`25H3@02023GS4208EO<00408IP<@27HC80Qf4b
08QR<`80RF<d00<0QF0/08IQ;@26HBd00P27HRh208QS;`0408UT<026H340QV0a08IP<@<0Qf4b0P28
HS<208]P=@@0REhc2`2;H3D208QR<`80Qf4b00L0QV0a08EO<025Gc00QEl`08QR<`29Hc@0RV@e0080
RfDf00<0RV@e08US=028HS<00`28I3@308MS<`X0QV8b2025HC4808MQ=0<0RF<f0P28HSD308MQ=0P0
QV4d0P21HC801022H380Q5lb08EP<`26H3<208QO<`80PUd`0P23GS4208AO<P80QF0c0P27Hc<01026
HS80QF4a08AP<023Gbl2089N;P0408AO<P23GS40PUd`089M<080P5/^00<0OeX]07iI;01nGRl01`1n
GRl308=M<080PU`_0`21Fbh307eH;P80OUT_0`1oFS02085M:`03081L;020Fbh0P5/_0080OeX`00L0
OeTb07eG<01mF2h0OEP^07eH;01mF2/0OETY0080OETW2@1kF300201fDbT0ME8X07AA9`1dDBL0ME8X
07MD:P1iER`0NeP^201lEBh01P1kGB/0NU`Z07UJ:`1hFB/0MeP/07IF;@80MED^0`1eEB`207AD:`<0
Le<Z0`1/DbX306eD:`80KUD/00<0LUD]075D;01_DRX00P1^DBT0101_DRX0L5<[075D;01aE2`2071C
:`0306mB:P1^DBT0KE0X0080K4lW201^DBT8079@:P0306mB:P1^DBT0K4lW00<0JTdU00<0JdhV06a?
9`1YCBD01`1YCBD806e=9P80K50X00<0JdlW06Y>9P1ZCRH00P1YCBD00`1XC2@0JD`Z06U<:P0206Q;
:@<0IdXX00<0ITTW06A=901TCB@01P1TCB@806=<8`80HTXV0P1SBbL01`1TC2P0IDdY06E=:@1UCBT0
HT`W065;9P1PBRD00P1OBB@02`1PBRD0HD/V069<9`1WCRH0ID`T069;8P1PBR40GDXP05e<8@1NCB80
GDhS00T0I4dT0P1PC2L00`1RC2L0I4`X06E;:00206Q;:@0606U;:@1[CbX0JThY06Y>:@1YCBP0Id/V
0P1VBRD02@1UBB@0IdlY06Q@:P1YDB/0JU8/06UA:`1WCbT0IDdW06A<9P0306E=9`<0I4`V0P1SBbD3
069:9080Hd/U0`1TC2H406188P80HDTS0P1RBR@0201VB2@0HdLR0655801NA1l0G4@N05a67`1KB200
G4TQ1P1OBB@2061:9@80GdLS00@0H4PT06599@1QBBD0HTXV0P1SBbL0101SAR@0I4LU06I99`1XBbT2
06U<:P80J4/Y00@0JDPU06Y99P1/BbP0KTdZ101`Cb`2071@9`04075A:01bDRT0Le<Z07=C:P80M5@[
00T0O5d^07]L;@1jFb`0NU//07]L;@1mGRl0Of0a085R<`22H3800P21Gc42081N<080Oed_00<0OU`^
08=Q<`22H3800`22H3800`24HS@0QfDg08QV>00208aX=00308eY=@2>JSH0Sf/g0080T6`h00L0TFdi
095W=@2BJ3H0TVPf09=Y=`2DJSP0UF/i0080UV`j0P2ELS`00`2FLcd0Ug@n09Qe?`0209Uf@00409Yg
@@2LMd<0W7M309ag@`<0VWE100<0W7M309iiA@2ONTH01P2QO4L20:1kAPH0YX5=0P2UP4`01P2VPDd0
Yh9>0:R3C`2ZQE40[8MC0:j9E@80/8]G00P0[hYF0:j9E@2/Qe<0ZhIB0:Z5D@2[QU80[8MC0:f8E0<0
[HUE0P2^RUH30:n;E`80/8]G0P2aS5P20;:=F@80/hiJ202bSET20;B?F0<0/hiG0`2bSEH80;>>FPP0
]8iO00<0/XiJ0;6=F@2`S5P00P2_ReL0102`S5P0/HeI0;:>FP2`RUd20;2:F`030:n9F02_RUH0[hYE
0080[XUB0P2cSUT20;:=F080/HaG0P2`ReH0202^RE80[hYC0;6<E@2cSUL0]8mH0;>>E`2bSEH0/HaE
202`ReL00`2^RE80/8]D0;6<E@020;:=EP040;6<E@2`Re@0[XUB0:n9F080[hYF00<0[hYE0:n:D`2_
Re400P2_Rdl00`2]R5@0[XUE0:j9E@020:n:EP80/8]G00<0/HaH0:j8F@2^R5T00P2^R5T20:n9FP<0
/8YK00H0[hUL0:n9FP2_REX0[XQG0:j9E@2]R5<20:f8D@P0/XQF00@0]8iO0;:<G@2`RU/0[XQI0`2]
QeP0102^R5T0ZXEA0:b7D`2_RUH20;6<F0030:n:EP2/Qe<0ZXEA0080[hYF0`2^RED30:f8E0030:j8
F@2_REX0/H]L0080/XaM00<0/H]L0:n9FP2^R5T00P2[QTl01`2/Qe80[8MC0:f7EP2]QeP0[XQI0:j8
F`2[QEP00P2[QEH00`2[QE@0ZhIB0:^6D@020:b7D080ZhIB0P2/Qe<40:f8E080[8MC0P2[QU801`2Z
QE40ZHA@0:V4D02YQ500Z8=?0:V4D02[QU800P2/Qe<00`2[QU80ZHA@0:R3C`040:^6DP@0[8MC00P0
[8M@0:^6C`2YQ4l0Z8=?0:R2D@2YPe@0ZhEF0:b6F@80ZhIB0P2/Qe<40:f8E080Zh9>0P2ZPDd0102[
PTh0[HA@0;27D`2aR5@20:j9E@80[HQD0P2/Qe<:0:^6DP040:f8D`2/Qe80[8MB0:b7DP80ZhIA2`2Z
QE020:Z5D@<0ZhIB0`2/Qe<20:^5E0040:^6DP2ZQE00ZXE@0:Z5CP80ZHE;0`2[QU430:b7DP80[HQC
202`Qe<80:j4DP80ZXI:00H0ZhM=0:b7D02]R5<0[XUE0:n:EP2_REP20;26E0H0/HME202^QE420:Z5
D@<0ZhIB0`2/Qe<20:^5E0040:^6DP2[QU40ZhIA0:^6C`80ZhM=202^Q5880:^6DP080:^6C`2/Qe00
[HQA0:j9DP2]R540ZhI?0:V4C@2XPd`20:^6D@80[8MB0P2]R5<20:j9E0P0[HQD00h0]8UN0;>8F`2a
QUT0[hEE0:n5D`2_QU80/8MA0;68DP2`ReH0[hYE0:j9E02]R5<0[8MB0:^6D@80ZXE@0P2^RE801`2]
R5<0[HQD0:b6E@2/QUL0ZhEF0:^5F02ZQE400P2[QU80102/Qe<0[HQD0:f8E02^RED20:n:EP030:f8
E02/Qe<0ZhIB0080ZXEA00<0ZhIB0:b7D`2]R5@0402^Q5880:n6DPP0ZhIB202]Pe400`2^Q580[hEC
0:n5D`040:n5D`030;26E02[QU80ZhIB00H0ZhIB00<0[8MC0:f8E02^RED00P2^RED00`2/Qe<0ZXEA
0:V4D0080:^6DPP0ZHEE00<0Yh9=0:R3CP2ZQE000P2/Qe800`2[QU40ZXE@0:V4C`020:V4D0<0ZXEA
0`2[QU80202[QEP0ZhEF0:^5EP2[QE@0ZhIB0:^6D@2[QTl0[8M@0`2_QU800`2`Qe<0/HQD0;68E002
0;:9E@H0ZhIA0P2/Qe820:j9E080[HQC00@0[8MB0:^6D@2[QU40ZhIA0P2/Pd/0102/Pdd0[HA@0:f4
D02^Q5820:j4E0T0ZXE@0P2ZQE430:^6DP@0[8MC00l0[HQD0:j9E@2^RED0[HQD0:Z5D@2XPdl0YX5=
0:f8E02/Qe<0ZXEA0:V4D02XPdl0ZHA@0:Z5D@2[QU80202]Q5020:b7D`H0ZhIB00<0[8MC0:^6DP2Y
Q5000P2XPdl00`2YQ500ZhIB0:b7D`080:j4DPP0ZhEF202ZQE430:^6DP80ZXEA0`2YQ5020:^1D@04
0:^1C`2[PTh0Zh9>0:^2C080Zh9:202YQ4l20:J1C@80Yh9>0P2XPdl20:V4D080YWmD102WP5D20:R1
EP0;0:V3DP2ZQ5<0ZhED0:^5E02ZQ5<0ZH=B0:N1D02VP4l0[89@0:Z0CP2YOdd00P2XOT`00`2YOdd0
ZX1>0:b2D0080:R3CPP0YX5=0`2UP4`20:AoB`@0Xgi:202UP4/20:V0C0040:QoB`2WOTX0YWe90:El
B080Y7]70P2PNdL30:5lB0<0XWe91P2QO4P20:9mB@80X7]400<0X7]60:1kA`2PNTT00P2PNT/02@2P
NTd0W7M009ag@02MN4<0WGQ409ihA`2NN4T0WgU:09miC00309ag@`0309ehA02NNDD0WgY60080X7]7
00H0Xge>0:9lC@2QNd`0X7Y;09miBP2NN4T209egB0030:5lB02PNdL0WWU500<0W7M300<0WGQ409ii
A@2MMdP00P2MMdP[ooooo`00:_ooool809ET>`P0UVDj202DJ3/309AX=`80TfLf0`2BISD209QW?0<0
VFPm0`2JJCh209AY?0<0UFXm0`2FJch809EY?00509EY>02FJST0UVXi09M[>P2HK3/00P2IKC`00`2J
KSd0VFlm09U_?@0309Q^?0<0Ufdk0P2JKT400`2IKD00V6`o09Q/?`0409Q/?`80VVhm00@0V6`k09M[
>P2GJcX0Uf/j0P2HK3/309]_?P80VVhm0`2IKC`809]`?@0309ab@02KLCl0VW0n00<0VW0n00<0Vg4o
09ab@02KKch00P2LL3l00`2MLD00WW9109mc@P020:1d@`0309mc@P2NLT40WG500080W70o00<0WG50
09ib@@2OLd800P2NMD4309mf@P<0X7M3102QMdD40:1fA0<0Y7]70P2SNTH30:9iA@0509md@@2PMD80
X7E20:5f@`2RMd@00P2SN4D00`2TNDH0XgY60:=jAP030:AkA`H0YGa80`2TNdL20:=jAP030:9gA02S
N4D0Y7U600<0YGY7102TNDH00`2VNdP0Yga90:QmBP020:MlB@030:IkB02SNTH0XgY600H0XgY60P2S
NT@02P2RNDD0XGM509meA@2NLdH0WG9509aaAP2OMD<0WG=109]a?`2IKcd209Q^?00:09U_?@2JL3h0
UVdi09E/>02DJcL0TfXf095X=02@Ic<0SfHb08iU<@80TFHi00<0T6Dh08mT=`2=HSD00P2<HC@0202;
H3<0RUlb08eR=`2=HSL0S64f08YO=029GS<0Qe`a0P26Fc02089M<`80PE`b0`20Fc40101oFS00O5H_
07aF;`1lERl207]E;P<0NU@]0P1hD2`01P1fD2/0M54[079@:P1`D2T0KdlX06e@:080KU0/0P1]Cb/3
06a>:P0306]=:@1XBRP0J4XX00@0JD/Y0P1XBRP806E89P0306M99`1VB2H0I4HT00<0HdDS00D0I4HT
06E79@1ZC2X0JD/Y06M99`0206I89P0306M99`1YBbT0JT`Z00P0JT`Z0`1bCbL207=@:0<0M54Y0P1i
DRT207YC:P0407]D:`1lEB`0OEH]07eF;@80OUL^0P1oF2l4081I<0P0Peha2024Gc802022G2d0Ped^
08AN;`26H340R68c08YT=@2;ICH0S6Hg0`26HBd208MR;P<0R6<_0P25Gc0208IP<@<0Qf4b00<0R68c
08UN<`29GS<0102;H3D308UN<`P0Rf0e0P29Hc@308QR<`<0Qf4b00<0R68c08US=02:I3D00P2;ICH0
0`2:I3D0RF<d08QR<`0308QT=0<0Qf<c2P26HS8808EQ<@P0Qf4d0P29HcH208QR=@<0Qf4d00<0QV0c
08IQ=026HC@01P26HC@2085Q<P04089P<P24Gc80Q5lb08EO<P80Qehb0P22GC0208=N<@80Q5lb0P25
H3<208IR<P80QF4a00@0Q60`08=O;`22GRh0PUh^2021G2l807mM;`<0Ped`0P22G2l3085K;P80PE`b
0`20Fc4307mJ<080PEd[00<0P5`/081K;P20Fbl00P1oFS001`1oFC80OEL`07eH;P1mF2h0OEP/07eH
:`1mFBT00P1mFBL907]H<00307QE:`1gE2X0MU<Y0080ME8X00<0MU<Y07QE:`1iER`0201kEBh01P1j
G2X0NE/Y07UJ:`1hFB/0MeP/07IF;@80MED^0P1eEB`207AD:`<0Le<Z00<0LU8Y071D;01`E2`00`1_
Db/306iB:P0407=F;P1bEBd0L5<[06iA:@80KE0X0P1^DBT2071C:`0406mB:P1^DBT0KE0X06e@:080
K4lW201^DBT8071@:@0806iA:@1]D2P0JdhV06Y=9@1YC2@0JTdU06]>9P1/CbL806U=9@P0JTdU0P1Z
CRH306U=9@<0J4`T00@0IdXX06I99`1VBBL0ITTW0P1UB2H206A79@P0Hd/U201RBR@0101QBBD0HTXV
069:9P1RBRH306=;9`0406A<:01QBbH0HD/V061:9@80GdTT00P0H4XU065;9P1QBbH0ID/V06A:9@1R
BR@0H4XS05e:8P80GD/S00<0G4dT06=;9@1SBbD01`1SBbD205m;9P03065;9P1SBbL0I4XW0080IdXX
00L0J4XX06Y>:@1YCBP0JDdX06Q<9`1WBbH0ITXU0080IDTT00P0IThX06M?:@1WCbT0J50Z06M?:@1V
CRP0IDdW06A<9P<0IDdW0`1TC2H206=;9@<0HTXT0P1SBbD306A<9P<0H4PR0P1QBB<3069:900606I8
901TB2<0HTHQ05m5801NAR00GDLP0P1LBB4205e78P0405i88`1OBB@0GdTT061:9@80HD/V0P1LA200
101MAB40GdLS0618901QBBD2069:9P0606=6901TAbD0ITTW06M::01XBbT0JD`Z0P1XBbT306Q:9P05
06U;9`1ZC2P0K4hZ06i@;01`DRh00P1aDBP00`1bDRT0Le<Z07AD:`0207EE;00907IF;@1jFb`0NU//
07UJ:`1jFb`0Ne`]07aM;P1nGc00Of0a0080PEla0P20GS0407mM;`0908=Q<`22H380PEla085O<@22
H380Q68d08IT=P28ISP0RfLc0080S6Pd00<0SFTe08iZ=P2?JcL00P2@K3P2095W=@03099X=P2CJCL0
U6Xh0080UF/i00<0UV`j09Eb?02ELS`00P2FLcd01@2GM3h0V7Do09Uf@02IMT00W7M30080VgI200H0
VWE109Ud@02JMD40VgI209ehA02NNDD80:1kAPP0YH1<00H0YX5=0:N2CP2XPdl0ZXEA0:b7D`2]R5@3
0:n:EP070:j9E@2/Qe<0ZXEA0:Z5D@2[QU80[8MC0:f8E0030:f9E@80[XYF0`2_ReL20;2;E`80/HaH
0P2bSET20;>>FPP0/XeI0P2dSeX30;>>F@<0/XeH202cSUX80;>=GP030;:>FP2aSET0/8aH0080[h]G
00/0/8aH0;6=F@2bSUX0/H]N0;6;G02`RU/0/8YI0:n:EP2_RUD0[hYC0:j9DP020;>>F@80/XeH0P2a
S5L20;2;EP80[hYE00@0/HaG0;:=F02bSEP0/XeH0P2aS5L80;2;E`030:j9E02`ReH0/HaG0080/XeH
00<0/HaG0;2;EP2^RE@00P2_REP0102_RUH0[hYE0:n:E@2_RU<20:n;D@<0[XUE0P2_RUH30;2;E`@0
[XQI0P2_REX30;2:F`060;2:G@2_REX0[hUJ0:n9F02^RED0[XUD0P2]R5480;:8EP040;>=GP2aRe`0
/8YK0:j8F@80[HMH0P2^R5T00`2[QU80[8MC0:n:EP020;6<F0030:n:EP2/Qe<0ZhIB0080[hYF0`2^
RED30:f8E0030:j8F@2_REX0/8YK00<0/8YK00/0[hUJ0:j8F@2[QTl0ZhI?0:b7DP2/Qe<0[HMF0:f7
F02^R5T0[XQK0:^5F0020:^5EP030:^5E02[QU80ZhIA0080ZhI?0`2[QU820:b7D`<0[HQD00@0[8MC
0:^6DP2[QU80ZhIB0`2ZQE420:V4D0080:Z5D@2[QU80[8MC0:b7D`2[QU80ZXEA0:V4D02ZQE420:^6
DP80[8MC0`2]R5@0202/Qe00ZhI?0:Z5D02YQ500ZH=B0:Z4E@2[QEH0[8II0`2[QU820:b7D`<0[HQD
00P0[XEA0:f4D02/Pdl0[8=?0:f4D02_QU80/HQD0;:9E@80[XUE0P2]R5@20:b7D`X0ZhIB0`2]R5<2
0:b7DP<0ZhIA00<0[HQC0:b7DP2/Qe800P2[QU40102ZQE00ZHA?0:V4C`2XPdh20:Z5D@<0ZhIB0`2/
Qe<20:b6E@060:^6DP2[QU40ZXE@0:Z5CP2ZQT`0ZHE;0`2YQ4l20:Z5D0<0ZhIA202`Qe<80:j4DP80
ZXI<00@0ZhI?0:b7DP2]R5<0[XUE0P2_REP80;67E@P0[XEA0P2ZQE430:^6DP<0[8MC0P2[QE@0102[
QU80ZhIA0:^6D@2[QTl20:^7C@P0[XAB202[QU802@2[QU40[8MB0:f8D`2^RE@0[HQC0:b7DP2ZQE00
ZHA?0:^6D@030:b7DP<0[HQC00<0[XUD0:f8E02]R5@01P2]R5@0202dREh0/hQK0;66F@2_QED0[hEC
0:n6DP2`Qe40/HQB0P2`ReH0102_RUD0[XUD0:f8D`2]R5<20:b7DP80[XUB00H0[HQC0:f8E02/QUD0
[8IG0:^5EP2[QEP20:^6DP030:b7D`2]R5@0[XUE0080[XUE0P2_RUH00`2^RED0[HQD0:^6DP020:Z5
D@030:^6DP2]R5@0[XUE00P0[hEC202^Q5880:n6DPP0ZhIB202]Pe440:j4DP@0[H=A2@2[QU801`2/
Qe<0[HQD0:j9E@2^RED0[8MC0:Z5D@2YQ500202[QU880:Z6EP80Z8=>00<0ZXE@0:^6D@2/Qe800P2[
QU400`2ZQE00[8MC0:^6DP020:^6DP@0ZXEA00H0ZH=F0:V3E02ZQ5D0ZhED0:b7D`2/Qe820:f8D@<0
[XEA0`2_QU820;27D`P0ZhIA0`2]R5<20:b7DP<0ZhIA0P2/Pd/0102/Pdd0[HA@0:f4D02^Q5820:j4
E0T0ZhIA0P2ZQE430:^6DP@0[8MC0`2]R5@0202/Qe<0ZXEA0:V4D02XPdl0[HQD0:b7D`2[QU80ZXEA
0P2YQ5000`2ZQE40ZhIB0:f4D0070:f4D0P0ZhIB00<0[8MC0:^6DP2YQ5000P2XPdl00`2YQ500ZhIB
0:b7D`080:j4DPP0ZhEF202ZQE430:^6DP80ZXEA0`2YQ5020:f3D`040:f3D@2]Q500[HA@0:f4CP80
[HA<202YQ4l20:J1C@80Yh9>0P2XPdl20:V4D0050:=mD02TOU40Y7iA0:EoDP2VP5<00P2WPE@00`2X
PUD0ZHA@0:V4D0030:^6DP060:V4D02XPdl0YX5=0:f3D@2/PU00Zh5?0P2YOdd00`2[PDl0[89@0:f3
D@080:R3CPT0YX5=0`2UP4`20:AoB`<0Xgi:202SOTT20:QoB`80Ygi:00@0YWe90:ElB02TNdL0Y7]7
0P2PNdL30:5lB0<0XWe9202QO4P20:1kA0030:1kAP2PNdL0X7Y90080X7Y;00T0X7Y=09ag@02LMd00
WGQ309ehA02NN4L0WWQ909miBP2OND`0202NNDD01P2RO4d0XG]<0:5kC02PNT/0WgU:09ihB@80WGM8
00<0XGa80:1kA`2NNDD00`2MN4@209iiA@<0W7I7:oooool002[ooooo202EI3/809MV>`P0U6Pk0P2E
JCP209AX=`80TfLf0P2BISD609QY?@80VFXn1P2EJSd209I[?PP0U6Pk00P0U6Pg09EY>02FJST0Uf/j
09Q/>`2IKC`0VVhm09]_?PH0VFdl0P2HK3/209Y^@@0709Q/?`2GJch0Uf/n09M[?P2HK3l0VFe009Y^
@@0309U]?0@0V6`k00@0VFdl09a`?`2LL3l0Vfln0P2JKSd00`2IKC`0V6`k09Q/>`0809]`?@D0Vg4o
0P2LLT000`2MLd40W70o09a`?`0209ea@00409ib@@2OLd80Wg=209mc@P<0WW910P2MLD0309ib@@80
WWE10`2OMT830:1g@`050:=iA`2RN4H0XWQ60:5gA@2PMT@00P2OMD<00`2NM480YGa80:ElB0030:Ak
A`<0XgY60P2PMD820:5f@`80XWM40P2SN4D20:=jAP<0Y7]71P2UO4P30:AkA`80XgY600@0XGI30:9g
A02SN4D0Y7U60P2UNTL20:IkB0040:EjA`2VNdP0Yga90:MlB@@0Z7e:0P2TNdL40:=jAP80XWU50P2R
ND<02P2QN4@0X7I409meA@2NLdH0WG9509ebA`2NM480W79009Y`?P2HKS`209M]>`0809Q^?02IKcd0
U6/g09=Z=P2BJCD0TFPd08mV<P2>IC4208eT<00508mV>02>ICL0SVDg08eT=P2;HS@00`2:HC<01`29
H380Rf4g08YP=P29GcD0R5hd08IL<P25Fc400P24FS03081K<@<0OeX`0P1nFBl307]E;P80NU@]0`1i
Db`207M?:`0607I@:`1cD2X0LDlY071@:@1_CbP0KE0X0P1^D2`206e?:`0706a>:P1[CBT0JddY06Y<
:01VB2H0IdTW06Q::00206U;:@0306Q::01WBBL0ITPV0080HTDS0`1SAR@306A79@0406Q::01WBBL0
ITPV06E79@<0I4HT00@0HdDS06]=:@1ZC2P0J4XV0P1WBBD00`1XBRH0JT`X06]=:@0306i=:P<0KD`Y
0P1/BbP207E?:080MU0Y101gDBX207YC:P0307]D:`1lEB`0OEH]0080OUL^00<0OeP_081I<020FC00
0`20FC03085J<@<0Q60`0`23Gbl2089N;PP0QF0c00P0Ped^08AN;`25Gc00QV0a08QR<`29Hc@0RV@e
08]U=PP0Qf8^0`25Gc0208IP<@<0Qf4b00<0Qe`a08UN<`2;H3D00P2=HSL0102;H3D0REhc08UN<`27
G34808]P=@H0RF<d0`28HS<01`29Hc@0RV@e08]U=P2;ICH0RV@e08US=028HS<00`28I3@308MS<`X0
QV8b2025HC4808MQ=0<0R68e0`27HC@208IP<`P0QV4d00<0PV8c085Q<P22H3800P24Gc800`24GS40
QUda08IM<@02089M<080Peha0P24Gc8208EP<`<0QF4a00<0Q60`08=O;`23Gbl00P22GRh207mJ;@04
081K;P21G2l0PE`_089M<080Peha2021G2l308=M<080PU`_0`21Fbh01P24GcD0Pehd08=N=022GC<0
PE`b081K<@80OeX`0P21GB/00`20G2`0P5/^081K;`0207mJ<00707mI<P1mEc00OEP^07eH;P1mF2`0
OEP[07eI:@0207eI9`T0NeP`00@0NeP^07YG;@1hEB/0MU<Y0P1eDRP00`1fDbT0Me@Z07UF;P0707UF
;P0807UK:@1hFRP0N5TZ07MH:P1gF2`0MUH]07IF;`1eEBh307AD:`<0Le<Z0P1bDRT2075E;@03071D
;01_Db/0KU8Z0080KE4Y00L0K50X07=F;P1bEBd0LE@/06mB:P1^DBT0KE0X0080K4lW0P1`Db/0101_
DRX0KU4Y06e@:01/CbL206]>9PP0KU4Y201]D2P00`1^DBT0KE0X06]>9P0206U<900306Y=9@1[CRH0
K4lW0100J4`U201WBb@0101UB2H0I4LU06A79@1TAbD206=69080HTDS5P1QBBD2069:9P<0H4XU0P1O
BB@3061:9@0506A:9`1SBBH0HDTU061:9@1MBB@00P1LBR@00`1JBb@0HDTU06599@0706599@80GTXU
00<0HD/V069:9P1SBBH00P1VBBL00`1WBBL0IT`W06I<9`0206E;9P80I4XU0P1SBB@606E=9`80I4`V
0`1UCBL306A<9P80Hd/U0`1RBR@206=;9@<0I4`V0P1PB28206598`80HTXT0P1SBbD01P1VB2@0I4PS
06A88`1QAb80GdLQ05i88@80G4TQ00P0FdDP05a68@1MAb80GTPS05m9901PBRD0HD/V069<9`80FT8N
00/0G4@P05e58@1NAR80H4PT06599@1RBRH0HdHT06A79@1UB2H0ITTW06M::00306Q;:@0906Q<9`1W
BbH0ITXU06E9901WBbH0JThY06eA;01`E2l0LE4X0080LU8Y00<0Le<Z07AD:`1eEB`00P1fERd307QI
:P0507UJ:`1jFb`0Ne`]07aM;P1mGRl00P20GS0607mM;`80PV0b0P21Gc401@22H380Q68d08IT=P27
ICL0RVHb0080RfLc00<0S6Pd08eY=@2>JSH00P2?JcL2091X=@04095Y=P2BJSL0TVXg09=[>080U6`i
0P2DLC/0102ELS`0UW<m09Md?P2HMCl209Uf@00:09]f@P2JMD40VWE109Ud@02HLcl0VGA009Ye@@2L
Md<0WGQ409iiA0@0WgY50`2PNdH00`2SOTX0Y7m;0:AoB`020:AoB`<0YH1<00H0YX5=0:N2CP2XPdl0
ZHA@0:^6DP2]R5@20:j9E@080:n:EP2]R5@0ZhIB0:Z5D@2YQ500ZXEA0:^6DP2/Qe<30:f9E@80[XYF
0`2_ReL20;2;E`80/HaH0P2bSET20;>>FPP0/XeI0P2dSe/30;>>FP<0/XeI202cSUX80;>=GP80/HeI
102`S5P20;6=F@060;6;GP2aRe`0/H]L0;2:F@2`ReL0[hYE0P2_RU<20;>>F@80/XeH0P2aS5L20;2;
EP<0/8]G102aS5P90;2;E`030:j9E@2`ReL0/HaH0080/XeI00<0/HaH0;2;E`2^RED00P2_REX01P2_
REP0[hYF0:n:E@2_RUD0[hYC0:n;D@P0[hYF102^R5T20:n9FP<0/8YK00H0/8YM0;2:F`2_REX0[hUH
0:n:EP2^RE@20:j9DPP0/XQF0P2aReX00`2`RUT0[hUH0:j8E`030:j8E`030:b7D`2]R5@0[hYF0080
/8]G00<0[hYF0:f8E02/Qe<00P2_RUH30:j9E@<0[HQD0`2^R5L20:n9F0<0[XQG0P2[QTl01`2/Qe80
[8MC0:f7EP2]QeP0[XQI0:j8F`2/QUT00P2/QUL01@2[QE@0ZhIB0:^6D@2[QTl0ZXE>0080ZXEA0P2[
QU820:b7D`80[HQD202[QU800`2YQ500ZXEA0:b7D`020:f8E0040:b7D`2ZQE40ZHA@0:Z5D@80ZhIB
00<0[8MC0:f8E02]R5@00P2^RED0202]R540[8M@0:Z5D02YQ500ZH=B0:Z4E@2/QUL0[HMJ0P2ZQE42
0:^6DP80[8MC0P2]R5@00`2`Qe<0[hIB0:j5D@020:j5D@030;27D`2bRED0/hYF0080[XUE0P2]R5@2
0:b7D`X0ZhIB0`2]R5<30:b7DP80ZhIA0P2^RE@01@2]R5<0[8MB0:b7DP2ZQE00ZHA?0080Z8=>0P2Z
QE430:^6DP<0[8MC0P2/QUD0102/Qe<0ZhIA0:^6D@2ZQDh20:Z6C080Yh9=0P2XPdh30:V4C`030:Z5
D02`Qe<0/8MC00H0/8MC202^Q5801P2ZQT`0ZXE>0:^6D@2/Qe80[HQD0:j8E`80[hUJ00<0/XQF0;67
E@2aQeD00P2aQeD30;26E0P0[XEA0P2ZQE430:^6DP<0[8MC0P2[QE@0102[QU80ZhIA0:^6D@2[QTl2
0:^7C@P0[XAB2@2[QU801`2/Qe<0[HQD0:j9E@2^RED0[HQD0:^6DP2ZQE40102/Qe840:f8D`P0[HQD
00P0]8UN0;>8F`2aQUT0[hEE0:n5D`2_QU80/8MA0;68DP80/8]F0P2_RUD20:j9E080[HQC0P2^RE80
1P2]R5<0[HQD0:b6E@2/QUL0ZhEF0:^5F080ZhIB00D0[8MC0:f8E02^RED0[XUE0:n:EP020;2;E`03
0:j9E@2]R5@0[8MC0080ZXEA00<0[8MC0:f8E02^RED0202_QE<30:j4DP@0[H=A00<0[89@0:n6DP2_
QU801P2_QU880:^6DPP0[H=A0P2^Q5820:f3D@80[89@0P2[PDl80:^6DP030:Z5D@2[QU80[8MC0080
[HQD00<0[8MC0:Z5D@2YQ500202[QU880:Z6EP040:R3CP2YQ4l0ZHA?0:Z5D0@0ZhIA0P2]R5@0102/
Qe<0ZhIB0:^6DP2ZQE420:V4D0080:R2E@2XPU<0ZH=D0:^5E02/Qe<0[HQC0:j9DP2_RU<30:f4D0D0
[XEA0`2/Qe840:^6D@030:Z5D02/Qe80[8MB0080[8MB102[QU420:b3B`040:b3C@2]Q500[HA@0:j4
DP80[XAD2@2[QU420:Z5D@<0ZhIB1`2/Qe<20:^6DP030:Z5D@2YQ500[HQD0080[8MC00<0ZhIB0:Z5
D@2ZQE400P2ZQE480:f4D0030:Z5D@2[QU80ZhIB0080ZhIB102/Qe<01`2[QU80ZHA@0:R3C`2XPdl0
ZHA@0:^6DP2/Qe<0202^Q5880:^5E0P0ZXEA0`2[QU820:Z5D@<0ZHA@0P2^Q5@0102^Q580[XEA0:j5
D@2^QDl20:j5C@P0ZXE@0P2VPDd20:N2CP80Z8=?0P2YQ5020:9lC@040:=mCP2TOTl0YGm@0:J0D@80
Yh5B00/0Z8=>0:V4C`2[QU40[8MB0:^6D@2ZQE00ZHA?0:R3CP2^Q580[H=A0:b2D0020:Z0CP030:b2
D02]Pe40[XAB00P0ZHA?2P2VPDd30:F0C0@0Y7m;202RODP30:MnBP030:ImB@2UO4P0YGa80080Y7]7
0P2PNdL30:5lB0H0XWe9102QO4P02@2PNdL0XGa50:5lA@2PNdH0X7]70:1jB@2PNT/0WgU:09miC002
09ag@00709eh@`2MN4@0WWQ709ihB@2ONDX0WgU<0:1kA`0309mjAP<0WWU500@0WGQ40:5kC02PNT/0
X7Y;0P2ONDX209ihB@0409egB02PNdL0X7]709mjAPD0WWU50`2KMDH[ooooo`00:_ooool809IU?0P0
UfHk202DJ3/309EY>080U6Pg0`2CIcH209M[?PH0UVXm0P2FJch609EZ?@P0UFTl00P0U6Pg09EY>02F
JST0Uf/j09Q/>`2IKC`0VVhm09]_?P80VV`k1P2KKC`0102KKd80VFe009Q/?`2FJSd209M[?P0309Q/
?`2JKT40Vfm20080V6`k0P2IKC`0102JKSd0VFdl09U]?02IKC`209a`?`0409]_?P2JKSd0VVhm09U]
?080V6`k202KL3d209Y`?P0309]a?`2LLT00WG=100<0WG=10`2MLD0409ib@@0309mc@P2MLD00WW91
00D0WW9100<0WG5009ie@@2NMD400`2OMT830:1g@`050:=iA`2RN4H0XWQ60:5gA@2PMT@00P2OMD<0
0`2NM480YGa80:AkA`020:AkA`80XgY60P2RNDD40:5f@`@0XWM40P2SNTH30:AkA`H0YGa80`2TNdL2
0:=jAP80XWM40P2SN4D0102TNDH0YGY70:IkB02WO4T40:IkB0050:MlB@2XODX0Z7e:0:UnB`2UO4P0
0P2TNdL20:=jAP80XWU500d0XGQ40:5h@P2QN480X7M309me@`2OMDD0WW=609ebA@2MLTL0WG=109]a
?`2IKcd0Ufdk0080UV`j00P0Ufdk09Q^?02CJSH0TVTe095X=02@Ic<0SVDa08eT<080S6<_0P2;ICH0
0`2:I3D0RF<d08US=00208QR<`80Qf4b0P27H3L01P26GcH0QEhe08=L<`22Fc80PEXa081I<080OeX`
0`1nFBl307eH;P<0NU@]0P1iDb`307QB:`80MThZ00<0MDlZ079?:@1aCbT00P1`D2T01`1]D2P0Ke4]
06i@;01]Cb/0K4hZ06]=:@1ZC2P00P1YBbL00`1TAR@0ITPV06M99`0206U;:@0306M99`1VB2H0I4HT
0080HD@R0P1RAB<0101SAR@0I4LU06A79@1TAbD306Q::00306M99`1VB2H0IDLU0080I4HT00<0K4hX
06]=9`1YBbD00P1XBR@00`1YBbD0JddW06a>:002075?:P<0L4hY0`1_CBP407MA:P80N58[0P1iDb`0
1P1kE2/0O5D/07aE;01mERd0OUL^07mH;`80P5T`0P22Fc86085J<@80QF4_0`24H2h308=O;@P0QF0c
0`28HS<208MQ<P<0QV0a2027HRh208AN;`80QEl`0P26H34208MQ<P0308ML<@29GS<0Rf0e0080SF8g
00@0Rf0e08UN<`29GS<0Qe`a202;H3D208QR<`H0RF<d00<0R68c08US=02:I3D00P2;ICH00`2:I3D0
RF<d08QR<`0308QT=0<0Qf<c2P26HS8808EQ<@P0Qf4d0P28HSD308MQ=0<0QV0c2026HC@2089R<`04
089P<P24Gc80Peha08=M<080QE``0P22GC0208=N<@80Q5lb0P25H3<308AP<0@0Pel_00<0PUh^07iI
;01oFRd00P20Fbh2089M<00308=N<@24Gc80PE`_00L0PE`_0`23GC02089L;`<0PE/^0P24GcD01023
GS@0PUdc085L<P21G382081K<@80PEd[00<0P5`/081K;P20Fbl00P1oFS001`1oFC80OEL`07eH;P1m
F2h0OEP/07eH:`1mFBT00P1mFBL907]H<00507aI;`1kF2h0NEH/07IC:@1eDRP00P1fDbT00`1gE2X0
N5L^07QG;P0607QG;P80MeTW00@0MePY07MH:P1fEb/0MUH]0P1fERl207AD:`<0Le<Z0`1bDRT2079E
;@03075D;01`Db/0Ke8Z0080KU4Y00T0KE0X075D;01aE2`0L5<[06mB:P1^DBT0K4lW06]>9P1ZCBD0
0P1_DRX0101^DBT0KE0X06e@:01/CbL206]>9PP0KE0X201ZCRH0201^DBT0K4lW06Y=9@1YC2@0J4/S
06U<901ZCBD0JdhV201WBbH806E;9PP0IDTT00@0I4LU06=6901SAR@0HdHT0P1RAB<206548QH0H4PT
0P1OAb<305m99080H4XU0`1OBB@206989@0606599@1PBRD0GDTT05a:901KBB<0F4TR2@1PB2@205e9
9003061:9@1QBBD0HdTV0080IDPV00<0ITPV06=;9@1SBbD00P1SBbD4069:900306A<9P1SBbD0Hd/U
0080Hd/U0`1TC2H306E=9`<0I4`V0P1SBbD3069:9080Hd/U0`1TC2H306598`80HTXT0`1SBbD0201V
B2@0IDTT06E9901SBB@0HDTS05m98P1MBR80G4TQ0P1KAB00101LAR40GDLR05m9901PBRD2065;9P06
05Y27P1K@al0Fd<O05e58@1NAR80GdLS0P1PB2@306A79@0=06E89P1VBBL0IdXX06Q;:@1YC2X0ID/V
06A:9@1SBB@0HTPS06A:9@1WCBP0JU0[06eC;P02075A:003079B:@1cDbX0M5@[0080MED/00H0MUH]
07IG:01fEbP0MePY07QI:P1iFR/207YK;00307]L;@1nG2h0OU`^00H0Oed_00T0PV0b085O<@20GS00
P5h`085O<@23HC<0QF<e08MU=`29IC400P2:IS800`2;Ic<0S6Pd08eY=@0208iZ=P80SFPd00@0SVTe
08mZ=P2@JcL0TF`h0P2BKCT209Aa>`0409Eb?02FLcd0UW<m09Md?P80V7Do00T0VWE109Ud@02IM400
V7<o09Mb?P2HLcl0VGA009]f@P2LMd<00`2MN4<00`2NND@0WgY509mjA@020:1kAP<0XWe900<0Xgi:
0:AoB`2TOd/00P2UP4`01P2VPDd0Yh9>0:R3C`2YQ500ZXEA0:b7D`80[HQD00<0[XUE0:f8E02[QU80
0P2YQ5000`2ZQE40ZhIB0:b7D`030:f9E@80[XYF0`2_ReL20;2;E`80/HaH0P2bSET20;>>FPP0/XeI
0P2dSUd30;>=G0<0/XaK202cSUX80;>=GP80/8aH102aSET20;2<F0060;:<G`2bS5d0/H]L0;6;FP2`
ReL0/8]F0P2_RU<20;>>F@80/XeH0P2aS5L20;2;EP80/H]J0P2`RUT0102_REP0/8YI0;2:F@2`RUT8
0;2;E`030:j8E`2`RUT0/H]J0080/XaK00<0/H]J0;2:F@2^R5L00P2_RE`00`2_REX0[hUH0:n:EP02
0:n:E@030:n:D`2_RUH0[hYF00H0[hYF102^R5T20:n9FP<0/8YK00H0/8YM0;2:F`2`RU/0[hUH0:n:
EP2_RUD20:j9DPP0/XQF00@0[hYF0;2;E`2`ReL0/8]G0P2_RUH20:j9E@030:b7D`2]R5@0[XUE0080
[hYF00<0[XUE0:f8E02/Qe<00P2_RUH30:j9E@<0[HQD00<0[XUE0:f8E02]R5@0102]R5@03`2^RED0
ZhI?0:^6C`2/Qe80[8MC0:f7EP2]QeP0[XQI0:j8F`2]QeX0[HMH0:b6E`2/QUD0ZhIB0:Z5D0020:Z5
CP<0ZXEA0P2[QU830:b7D`@0ZhIB102/Qe<00`2ZQE40ZhIB0:b7D`020:f8E0030:b7D`2[QU80ZXEA
0080ZXEA00h0ZhIB0:b7D`2]R5@0[XUE0:n:EP2`ReL0[HQA0:b7D02[QU40ZXEA0:Z4D`2[QEH0[8IG
0:f7FP<0ZXEA0P2[QU830:b7D`080;68E02`Qe<0[hIB0:j5D@2_QU80/8MC0;:9E@2cRUH20:j9E@80
[HQD0P2/Qe<:0:^6DP80[XUD0`2]R5<30:b7DP030:n:E@2^RE@0[HQC0080[8MB00@0ZhIA0:Z5D02Y
Q4l0Z8=>0P2ZQE430:^6DP<0[8MC0P2]QeH0102/Qe<0[8MB0:^6D@2[QTl20:Z6C0<0Yh9=0P2XPdh3
0:V4C`P0/8MC202^Q5801P2ZQDh0ZXE@0:^6D@2/Qe<0[HMF0:j8F@80[hUL0`2bR5H00`2aQeD0/8ID
0;26E0020:n5D`P0[XEA0P2ZQE430:^6DP<0[8MC0P2[QE@0102[QU80ZhIA0:^6D@2[QTl20:^7C@P0
[XAB202[QU80202[QE@0[8IE0:f7EP2^R5L0[hUH0:j8E`2/QUD0ZhED102]R5<40:b7DPP0[HQD00P0
]8UN0;>8F`2aQUT0[hEE0:n5D`2_QU80/8MA0;68DP<0[hYE0`2^RE@20:f8D`80[XUB00H0[HQC0:f8
E02/QUD0[8IG0:^5EP2[QEP20:b7D`050:f8E02^RED0[XUE0:j9E@2_RUH00P2`ReL00`2_RUH0[HQD
0:b7D`020:^6DP030:b7D`2]R5@0[hYF00P0/8ID0`2^Q5800`2]Pe40[89@0:b2D0020:^1C`P0[XEA
202[QU8<0:f3D@@0[89@202[QU800`2YQ500ZXEA0:b7D`020:f8E0030:b7D`2[QU80ZXEA00P0ZhIB
202[QeL40:V4C`050:Z5D02[QU40ZhIA0:b7DP2^RED00P2]R5@03@2/Qe<0ZhIB0:Z5D@2ZQE40ZHA@
0:R2E@2XPU<0ZH=D0:^5E02/Qe<0[HQC0:j9DP2_RU<01@2^QE430:f4D080[HQC0P2/Qe80102[QU40
ZXE@0:Z5D02ZQE080:^6D@80[8=;00@0[8==0:f4D02]Q500[XAB0P2^Q5@90:b7DP80ZXEA0`2[QU83
0:b7D`030:f8E02/Qe<0[8MC00D0ZhIB1@2/Qe<00`2[QU80ZXEA0:Z5D@080:f4D0<0ZXEA00<0ZhIB
0:b7D`2/Qe<00P2]R5@00`2/Qe<0ZhIB0:V4D0020:R3C`030:V4D02[QU80[8MC00P0[XAB202[QU88
0:Z5D@<0ZhIB0P2ZQE430:V4D080[XAD00@0[XAB0:j5D@2^QE40[XE?0P2^QDd80:Z5D080YX5=0P2W
PTh20:R3C`80ZHA@0`2SOD`00`2TOTd0YGm>0:J0C`020:J0C`030:R3CP2YQ4l0ZhIA0080[8MB00H0
ZhIA0:Z5D02YQ4l0[XAB0:f3D@2/PU020:Z0CP030:b2D02]Pe40[XAB00P0ZHA?2`2VPDd30:F0C0<0
Y7m;202RODP30:ImB@@0YGa800<0Y7]70:1kA`2PNdL00`2QO4P30:9mB@80Xgi:0P2RODT02@2QO4P0
X7]70:1kA`2PNdL0XWe60:5lA@2QO4L0X7]70:1jB@0209miBP0909ihB`2LMd00W7M009eh@`2MN4@0
WWQ709ihB@2ONDX0WgU<00<0X7]70P2ONTH309iiA@@0WgU:102NN4T40:1kA`0409mjAP2NNDD0WWU5
09ehA0<0W7I7:oooool002[ooooo202FIC`809MV>`P0U6Pk00@0UVXi09EY>02EJCP0UFTh0P2DJ3L2
09=W=P<0UV/n0`2EJSd209AY?0<0UV/n0`2EJSd209AY?0P0UVXm00D0UFTh09IZ>@2FJST0Uf/j09Q/
>`0209U]?00409Y^?@2KJc/0Vf/k09][>`<0W6`l0P2MKCd0102KKd80VFe009M[?P2EJC`209IZ?@07
09Q/?`2KKd80WG5409M[>P2HK3/0VFdl09Y^?@0209]_?P0309Y^?@2IKC`0Vfln0080Vfln0P2JKSd3
09U]?0P0Vg0m00@0VFlm09Y`?P2KLCl0WG=10`2NM4800`2MLd40WW9109ib@@0609ib@@0309a`?`2M
LD00WW910080Wg=200<0WW9109ea@02LL3l00P2NMD4309mf@P<0X7M3102QMdD40:1fA0<0XgY60P2R
NDD30:5hA0@0XGI3102RMd@20:=jAP<0Y7]71P2UO4P30:AkA`80XgY60P2TNDH30:=hA@040:AiAP2U
NTL0YW]80:IkB080YGY700<0Y7U60:EjA`2VNdP00P2XODX20:ElB0040:AkA`2SNTH0XgY60:9iA@80
XGQ40P2PMd402`2OMT80WgE309idA02NLdH0WG9509ebA`2LLT00VW0n09Q^?02FK3X0UF/i0080UV`j
00L0Ufdk09=Z=P2BJCD0TFPd091W<`2?IS80SF@`0080S6<_0`28I3@208MS<`@0QV8b0P25GcP01024
GSL0PU`e085K=01oFC8207iH<@0407iI;`1mF2h0OEP^07eH;P80O5L]0P1kER`307UC;080N58[0`1g
DBX207E=:@0307A>:@1bCbT0LDlY0080L50Y00L0KU4Y06mA;@1^D2`0KDl[06a>:P1[CBT0JD/W0080
J4XV00<0HdDS06A6901WBBL00P1YBbT00`1WBBL0I4HT06=58`0206548P0306958`1SAR@0I4LU0080
IDPV00`0ITTW06M99`1WBBL0J4XX06U;:@1XBRP0IdTW06I89P1UAbD0KE0X06a?9`1ZCBD206U<9003
06Y=9@1/CbL0KE0X00P0LTlY0`1iDR/207YC;0<0Ne@]0P1mERd0101nEbh0OeP_081I<020FC02085J
<@<0Pe`c0`22Fc82085J<@P0Q60/2024Gc801@2:I3D0RF<d08US=028HS<0QV0a0080QEl`00@0Q5h_
08QS;`28Hbl0R6<_0P27HRh308IQ;@<0Q5h_0P25Gc0308IP<@80REhc102;H3D308UN<`P0Rf0e0`27
HC8308QR<`80RF<d00<0R68c08US=02:I3D00P2;ICH00`2:I3D0RF<d08QR<`0308QT=0<0Qf<c2P26
HS8808EQ<@P0Qf4d00@0R68e08MQ=027HC@0Qf4d0P26H3<208EO<PP0QV4d0P22HS<01022H380Peha
089M<023GC0208AK;`80PUd`0P23GS4208AO<P80QF0c2023Gbl207mJ;@04081K;P21G2l0PE`_089M
<080Peha2022G2l308=M<080PU`_0`21Fbh3089M<`<0PE`b0P20Fc42085M:`03081L;020Fbh0P5/_
0080OeX`00L0OeTb07eG<01mF2h0OEP^07eH;01mF2/0OETY0080OETW2@1kF300101lFBl0NeP^07UF
;01gE2X207IC:@0307MD:P1hEB/0MeL^00L0MeL^0P1fF2H0101fEbP0MULY07IG:`1fERd207IF;`04
07AD:`1cDbX0Le<Z07=C:P80LU8Y0P1aDBP207=C;0<0LU8[0`1aDBX206mB:P80L5<[00@0Ke8Z06e@
:01[CRH0JTdU0P1_DRX00`1^DBT0KE0X06a?9`0206]>9P0306Y=9@1]D2P0KE0X00H0KE0X201YCBD0
201]D2P0K4lW06Y=9@1YC2@0J4/S06U<901ZCBD0JdhV201VBBL8069:9P80HTDS0`1SAR@506A79@80
HdHT0`1RAB<00`1QA280GTHT05i6900605i690P0GdLU00@0H4PT05m78`1OAb<0GdLS0`1NAR80101M
AB40GTPS05i88`1OBB@2061:9@0;05m9901NB2<0GTPS06169@1QAbH0H4PV06199`1MBBH0FdTU05Y8
901GAb<02@1NAR@205a88`0305m9901PB2@0HTPU0080I4LU00<0ITPV065;901QBb@01@1QBb@00`1P
BR<0HTXT069:900306598`03069:901TC2H0IDdW00<0IDdW0`1TC2H206=;9@<0HTXT0P1SBbD306A<
9P80HDTS0P1RBR@306=;9@0:06A<9P1VB2@0IDTT06I:9@1TBRD0Hd/U065;901MBR80G4TQ05]58080
G4HQ00D0GDLR05i88`1OBB@0GdTT061:9@0305e58@<0GTHR0P1OAb<206A79@0606=6901TAbD0IDPV
06I99`1XBbT0JD`Z101RBR@01@1TC2H0IThX06Q@:P1YDB/0KdlV0080L50W00<0LE4X079B:@1cDbX0
0P1dE2/0101cE2D0MEHW07IG:01hFBX307UJ:`0307QI:P1mFbd0OE/]0080OU`^101oGBl2085O<@80
P5h`00D0PEla08=Q<`25HcD0QV@f08QT<00208UU<@0308YV<P2;Ic<0S6Pd0080SFTe0P2<J3@0102=
JCD0SVXf08m[=`2?JcL2091/>00609=`>P2DLC/0U74k09Eb?02FLcd0Ug@n0P2HMCl02@2IM400V7<o
09Qc?`2GLSh0UW4m09Mb?P2HLcl0VWE109]f@P0209]f@@0309ag@P2MN4<0WWU40080WgY500H0X7]6
0:1kA`2PNdL0XGa80:9mB@2SOTX20:AoB`060:F0C02WPTh0Yh9>0:R3C`2YQ500ZXEA0P2[QU80102/
Qe<0[XUE0:b7D`2[QU830:V4D0030:Z5D@2[QU80[HUE0080[HUE0P2^RUH30:n;E`80/8]G0P2aS5P2
0;:=F@80/hiJ202bSET20;B>G`<0/heN0`2bS5d80;>>FPP0/XaM00<0[h]G0;2<F02aSET00P2bSUX0
102aSET0/8aH0:n;E`2bS5l20;:<G@030;6;FP2aS5P0/8]F0080/8]D0P2cSUT20;:=F080/HaG0P2`
ReH0102bS5d0/H]L0;2:F`2_REX20:j8F@030:n9FP2`RU/0/8]G00L0/8]G00<0[XQI0;2:F`2aRe`0
0P2bS5d00`2aRe`0/8YK0:j8F@020:n8G@030:n9G02_REX0[hUH0080[hYF00@0[hYE0;2;E`2`ReL0
/8]G0P2_RUH30:j9E@@0[XQI0P2_REX30;2:F`080;6;GP2aRe`0/8YK0;2:F@2_RUH0[hYE0:n:D`2^
RE880;:8EP030:j9E02_RUD0/8]F0080/8]F00@0[hYE0:j9E02^RE@0[HQD1P2^RED00`2]R5@0[hYF
0:n:EP030:j9E@<0[HQD00<0[XUD0:f8D`2/Qe800P2[QU400`2/Qe80[HQC0:j9E0020:^6C`050:b7
DP2/Qe<0[HMF0:f7F02^R5T00P2^R5/20:f7F0030:b6E@2[QU80ZXE@0080ZHA=00@0ZHA@0:Z5D@2Z
QE40ZXEA0P2[QU820:b7D`<0ZhIB0P2/Qe<30:f8E0030:Z5D@2[QU80[HQD0080[XUE00<0[HQD0:^6
DP2ZQE400P2ZQE403`2[QU80[8MC0:j9E@2_RUH0/8]G0;6<F02^RE80[HQA0:^6D@2ZQE40ZXAC0:^5
EP2]QeP0[XQK0:V4D0030:Z5D@80ZhIB0P2/Qe<00`2aR5@0/8MC0:n6DP020:j5D@030:n6DP2aR5@0
/XUE0080[XUE0P2]R5@20:b7D`X0ZhIB0`2^RE@20:f8D`<0[8MB0P2^RE@01@2]R5<0[8MB0:b7DP2/
Qe80ZhIA0080ZXE@0P2ZQE430:^6DP<0[8MC0P2]QeH0102]R5@0[8MB0:b7DP2[QTl20:^7C@040:N2
C@2XPdh0Z8=>0:R3CP80ZHA?0P2ZQE080;27D`P0[XAB00H0ZXE@0:Z5D@2[QU80[8IE0:f7F02^R5/2
0:n8G@80/hUG00<0/XQF0;67E@2`QU@00P2_QE<00`2^Q580[XEA0:j5D@060:j5D@80ZXEA0`2[QU83
0:b7D`80ZhED00@0ZhIB0:^6D@2[QU40ZhI?0P2[Qdd80:j4DPP0ZhIB00<0ZXAE0:b6E`2]QeP00`2_
REX00`2]QeP0[8IG0:j9E0030:f8D`<0[8MB00<0ZhIA0:f8E02]R5@01P2]R5@0202dREh0/hQK0;66
F@2_QED0[hEC0:n6DP2`Qe40/HQB1@2]R5<30:b7DP80[XUB00H0[HQC0:f8E02/QUD0[8IG0:^5EP2[
QEP20:b7D`040:f8E02^RED0[hYF0:n:EP80/8]G00@0/HaH0:n:EP2^RED0[8MC0P2[QU800`2/Qe<0
[XUE0:n:EP080;26E0060:n5D`2^Q580[XAB0:f3D@2/PU00Zh5?0P2ZP4h80:j5D@P0ZhIB202]Pe42
0:b2D080[H=A0P2^Q5820:n5D`P0ZhIB00P0Z8=?0:V4D02[QU80[8MC0:f8E02/Qe<0ZhIB0:Z5D@P0
ZhIB202[QeL01P2ZQE00ZHA?0:V4C`2XPdh0ZHA?0:Z5D080[8MB0P2]R5@30:b7D`<0ZhIB00H0ZH=F
0:V3E02ZQ5D0ZhED0:b7D`2/Qe820:f8D@80/8MC0`2_QU830:j5D@060:j9E02]R5<0[HQC0:b7DP2[
QU40ZXE@0`2YQ4l30:Z5D0<0ZhIA00@0[8MB0:b3B`2/Pd/0[8==0P2]Q5000`2^Q580[XAD0:j4E009
0:b7DP80ZXEA0`2[QU830:b7D`030:f8E02/Qe<0ZhIB0080ZXEA00<0ZhIB0:b7D`2/Qe<00P2/Qe<3
0:f8E0030:b7D`2ZQE40ZHA@00P0[HA@0P2YQ5000`2ZQE40ZhIB0:b7D`020:f8E0040:j9E@2/Qe<0
ZhIB0:V4D080Z8=?00<0ZHA@0:^6DP2/Qe<0202^Q5880:^6D@P0ZXEA0`2[QU820:Z5D@<0ZHA@0P2]
Pe<0102]Pe40[HA@0:f4D02]Q4h20:f4C0P0ZhIA0P2VPDd20:N2CP80Z8=?0P2YQ5040:J1C@@0YH1<
00/0Z8=<0:V4C@2[QTl0[8M@0:f8D@2/Qe00ZhI?0:Z5CP2]Pe40[89@0:^1C`020:UoC@030:^1C`2/
PU00[H=A00P0ZHA?202VPDd20:N2CP80YX5=102UP4`00`2TOd/0Xgi90:=nB@060:=nB@P0YGa80P2P
NdL30:5lB0<0XWe900H0Y7m;0:=nBP2SOTX0XWe90:5lB02PNdL209mjAP80XWe600H0XGa70:1kA`2P
NTT0WgU:09ihB@2NN4/209ag@00609eh@`2MN4@0WWQ709ihB@2ONDX0WgU<1@2ONTH30:1kA`P0WWQ9
00P0WgY60:1kA`2QO4P0XGa80:1kA`2ONTH0WWU509ehA0<0WGM8:oooool002[ooooo202GISd809QW
?0P0U6Pk0P2FJST309EY>0<0U6Pg0P2FKCl209E/?P0409A[?@2CJS`0TfXl09=Z?080Uf`o0P2FJch0
102EJSd0U6Tl09AY?02DJC`809Q/?`@0Uf/j102HK3/209YZ>P80Vf/k00L0W6`l09e]?@2MKCd0WFdm
09]_@P2IKD00UVXm00<0UFTl00L0V6`o09a`@`2NLTD0UVXi09Q/>`2JKSd0Vfln0080W70o0P2JKSd3
09U]?080VVhm0`2KKch809]`?@0409Q^?02IKcd0W79009id@P80WgE300<0WWA209ec@@2NLT401@2N
LT4209ea@00309a`?`2MLD00Wg=20080X7A300<0Wg=209ea@02LL3l00P2NMD4309mf@P<0X7M3102P
MT@40:5gA@<0XGQ40P2PMd<309mf@P@0XWM4102QMT<20:=jAP<0Y7]71P2UO4P30:AkA`80XgY600<0
Yga90:IkB02TNDH00P2RMd@0302SN4D0Y7U60:EjA`2UNTL0Y7U60:=hA@2RMd@0XgQ50:AiAP2VNdP0
Z7e:0:ImB@80YGa800D0Y7]70:9iA@2QN4@0XGQ40:1g@`0209mf@00309mf@P2NM480WWA40080WW=6
00D0WG9709]a?`2JL3h0V6hl09I/>P0209E[>@80UV`j00H0U6/g09=Z=P2BJCD0TFPd08mV<P2>IC42
08eT<0@0QF<c1@24HS801P22GcT0PEhh081M=`1oG3H0OU/e07aI<`80NePb00@0OEP^07aG;@1lEbd0
O5L]0P1kER`207YE:`0407UC;01hDR/0N58[07QB:`80Me4Z0P1fD2T207A<:00307==:01aCRP0LDlY
0080L50Y00`0KU4Y06mA;@1^D2`0KDl[06a>:P1ZC2P0JD/W06Q:9P1WBBD0HD<Q06=58`1VB2H206U;
:@0306I89P1SAB<0HD<Q0080HTDS00@0HdHT06A79@1UB2H0ITTW0P1WBRP00`1UAbD0ITPV06Q::002
06Y<:P0606U;:@1XBRP0IdTW06e@:01/CbL0JdhV0P1ZCBD00`1[CRH0K4lW06e@:002075>:004079?
:@1cD2X0M54[07AA:`80ME8/0`1lDR`207eC;@<0OU@^0P1nEbh01P1oF2l0P5T`085J<@21FS40PU/b
08=L<`<0Q5dd00<0Pe`c089K<P22Fc800P21FS401@22GRX0Pel[08=O:`24H2`0QF4]0080QV8^00<0
Qf<_08=N<@23GS401P23GS4808MQ<P0308UT<028Hbl0R6<_0080Qf8^0P26HBd00`25H2`0Q5h_08AN
;`0208AN;`80QEl`0P26H34208]P=@@0REhc2`2;H3D308EO<00308IP<@27HC80Qf4b00<0R68c00L0
RF<d08YT=@2;ICH0RfDf08YT=@29Hc@0R68c00<0R6@d0`27Hc<:08IR<PP0QF4a2`27HC@208IP<`<0
QElb2026HC@2089R<`04089P<P23GS40PUd`089L;`80PeX^0P22GC0208=N<@80Q5lb0P25H3<4089N
;P@0Pel_0P20Fbh4085L;`80PUd`2024Fbl308=M<080PU`_0`21Fbh307mJ<080P5/a0`21G382085M
:`03081L;020Fbh0P5/_0080OeX`00L0OeTb07eG<01mF2h0OEP^07eH;01mF2/0OETY0080OETW2@1k
F3000`1kF2h0NUL]07QE:`0307MD:P0307UF;01jEbd0MeL^00L0MeL^0P1eEbD0101eERL0MULY07IG
:`1fERd207IF;`<0Le<Z0P1bDRT3075A:0<0LU0Z0`1cDB/207AB;00306a?9`1]D2P0KU4Y0080Ke8Z
00@0KU4Y06a?9`1[CRH0Ke8Z0P1^DBT00`1]D2P0K4lW06]>9P0206Y=9@P0K4lW201VCB@00`1]D2P0
JdhV06Y=9@0306Q;8`0306U<901ZCBD0IDPX00L0IDPX201PBBL206138`030654901RABD0HTDU0080
HdHV00<0I4LW06E89P1TAbD00P1TAbD206=69080HTDS201MA2D805i59P80GdLS0P1NAR801`1MAB40
G4@P05a4801LA200GDLR05i88`1OBB@00P1PBRD02`1OBB@0GTPS05e78P1OA2H0H4DW0617:01PBBT0
GDTX05]89`1IARD0EDDS00T0GD@U00P0FdLR05a88`1NB2<0GdLS0657901SAR@0I4LU06E79@P0GT/S
0P1QBB<205m78@0306188P1QBB<0Hd/U00@0IDdW0`1TC2H206=;9@<0HTXT0P1SBbD306A<9P<0HTXT
0`1SBbD206A<9P0806I8901VBRD0Id/V06I<9`1TC2H0HT`U05i;8`1LBB4805e78P<0H4PT0P1OAb<3
05i68P80I4LU0P1SAR@02@1TAbD0ITTW06Q;:@1YC2X0GTPQ05m98P1QBb@0HddV06A>9`0306E?:080
KThU0P1_CbH02P1`D2L0LE4X079B:@1bDRT0LU<T07=D9@1fEbP0N5TZ07UJ:`1hFBX207MH:@0307aJ
;01mFbd0OE/]0080OU`^0P1oGBl02@20GS00PEla081N<020GS00Oed_081N<022H380QF<e08IT=P02
08QT<00308UU<@2:IS80RfLc0080S6Pd00L0SFTe08UX<`2:JC@0RVTd08]Z=@2<JcH0SF`g0080SVdh
0P2CL3X00`2DLC/0UG8l09Ic?@0209Md?P0409Qe?`2HLcl0Ug8n09Mb?P<0UW4m00<0V7<o09Ud@02K
MT800P2JMD001P2KMT40W7M209eh@`2NND@0WgY50:1kAP80WgY600H0X7]70:5lB02RODT0Xgi:0:Ao
B`2UP4`20:N2CP040:R3C`2YQ500ZHA@0:Z5D@80ZhIB00P0[HQD0:b7D`2ZQE40ZHA@0:R3C`2YQ500
ZXEA0:^6DP<0[HUE0P2^RUH30:n;E`80/8]G0P2aS5P20;:=F@80/hiJ202bSET20;B>G`<0/heN0`2b
S5d80;>>FPP0/XaM00<0[h]G0;2<F02aSET00P2bSUX0102aSET0/8aH0:n;E`2bS5l20;:<G@030;:<
F`2aS5P0/HaG0080/8]D0P2cSUT20;:=F080/HaG0P2`ReH0102cSEh0/H]L0:n9FP2^R5T20:f7F080
[hUJ202`ReL00`2^R5T0/8YK0;6;G0020;:<G@040;6;G02`RU/0[XQI0:n8G`80[hQM00<0[hUL0:n9
FP2_REP00P2_RUH00`2aS5P0/8]G0;2;E`020:n:EP80[XUE00<0[HQD0:j8F@2^R5T00P2^R5T20:n9
FP<0/8YK00H0/H]N0;6;G02aRe`0/8YI0;2;E`2_RUD20:n:D`P0/XQF00<0[HQA0:j9DP2`Re@00P2a
S5D00`2`Re@0[hYC0:j9DP080:j9E@80[hYF0`2^RED30:f8E0030:j9DP2/Qe00ZhI?0080ZXE>00<0
ZhI?0:b7D02^RE800P2[QTl01@2/Qe80[8MC0:f7EP2]QeP0[XQI0080[XQK00L0[XQI0:f7F02/QUD0
ZhIB0:Z5D02YQ4d0Z8=<0080ZHA@0`2ZQE460:^6DP030:b7D`2]R5@0[HQD0080[XUE00<0ZXEA0:b7
D`2]R5@00P2^RED04`2]R5@0[8MC0:Z5D@2YQ500ZXEA0:^6DP2]R5@0[XUE0;2;E`2aS5P0/XeI0:j9
DP2]R540[8MB0:Z5D@2ZQ5<0[8IG0:f7F02^R5/00P2YQ5030:Z5D@<0ZhIB00<0/HQD0;27D`2^QE40
0P2]Q5000`2^QE40[hIB0;27D`020:j9E@80[HQD0P2/Qe<:0:^6DP80[hYE0P2^RE@30:f8D`030:b7
DP2]R5<0[HQC00L0[8MB0P2ZQE430:^6DP<0[8MC0P2]QeH0102]R5@0[HQC0:b7DP2/Qe020:^7C@@0
ZHA?0P2ZQE020:^6D@P0/8MC202^Q5820:Z5D@0<0:^5E02/QUL0[HMJ0:j7G02_R5d0[hQO0;B:F02c
REL0/XQF0;67E@2`QU@0[hEC0P2^Q5880:j5D@80ZXEA0`2[QU830:b7D`80ZhED00@0ZhIB0:^6D@2[
QU40ZhI?0P2[Qdd80:j4DPP0ZhIB00P0ZXAE0:^5EP2]QeP0[hUJ0;2:F`2_REX0[XQI0:f7F080[XUD
0P2]R5<20:b7DP80ZhIA202]R5@0202dREh0/hQK0;66F@2_QED0[hEC0:n6DP2`Qe40/HQB0`2ZQE05
0:^6D@80[XUB00L0[HQC0:f8E02/QUD0[8IG0:^5EP2[QEP0[8MC0080[HQD00@0[XUE0:n:EP2_RUH0
/8]G0P2aS5P00`2_RUH0[XUE0:f8E0020:b7D`030:f8E02^RED0[hYF00P0/HME00D0[hEC0:j4DP2^
Q580[H=A0:^1C`020:Z0CP030:UoC@2]Q500[HA@00H0[HA@202[QU880:f3D@080:^1C`2/PU00[H=A
0:j4DP2`QU@0/HME0;:8EP2cREL80:^6DP030:N2CP2XPdl0ZXEA00<0[8MC00<0ZhIB0:Z5D@2[QU80
1`2[QU880:^7E`030:^6D@2ZQE00ZHA?0080Z8=>00<0ZXE@0:b7DP2]R5<00P2[QU830:b7D`<0[HQD
00P0ZhEH0:^5EP2[QEH0ZhED0:^6DP2[QU40ZhI?0:b7D080/XUE0P2aR5@0102`Qe<0[hIB0:n6DP2_
QU820:j9E0060:f8D`2/Qe80ZhIA0:Z5D02YQ4l0Z8=>0`2YQ4l00`2ZQE00ZhIA0:^6D@020:b7DP80
[8=;00@0[8==0:f4D02]Q500[XAB0P2^Q5@90:b7DP80ZXEA0`2[QU830:b7D`030:f8E02/Qe<0ZXEA
0080ZHA@00D0ZhIB0:b7D`2^RED0[8MC0:f8E0030:j9E@030:b7D`2ZQE40ZHA@00P0[HA@00H0Z8=?
0:V4D02ZQE40ZhIB0:b7D`2]R5@20:j9E@030:b7D`2[QU80ZHA@0080Z8=?00<0ZHA@0:^6DP2/Qe<0
202^Q5880:^6C`P0ZXEA0`2[QU820:Z5D@<0ZHA@0P2[PE40102[PDl0Zh9>0:^2CP2[PT`20:^2BPP0
ZhIA0P2VPDd20:N2CP80Z8=?0P2YQ500102ZQE40ZHA@0:R3C`2XPdl20:J1C@050:F0C02TOd/0Z8A:
0:V5B`2[Qdd00`2]RDl01@2/R4h0ZhM=0:b2D02ZP4h0ZGm=0080Z7i<00<0ZGm=0:Z0CP2/PU00202Z
QE080:J1C@<0Yh9>0P2VPDd40:F0C0P0YH1;102TNdL40:ElB080X7]70`2QO4P30:9mB@80Y7m;00/0
Xgi:0:9mB@2QO4P0X7]709mjAP2NNDD0Xgi70:9mAP2RODP0XGa809miB00209ihB@0909egBP2LMd00
W7M009eh@`2MN4@0WWQ709ihB@2ONDX0WgU<0080WWU50P2ONTH0102PNdL0XGa80:9mB@2RODT309eg
B0D0WWQ900P0WgY60:1kA`2QO4P0XWe90:5lB02PNdL0WWU509ehA0<0WgU::oooool002[ooooo202G
ISd809QW?0P0U6Pk0`2FJST209EY>0<0U6Pg0P2FKCl209E/?P0409A[?@2CJS`0TfXl099Y>`80Uf`o
0P2FJch0102EJSd0U6Tl09AY?02CJ3/809U]@00409U]?02HK3/0V6`k09Q/>`<0Uf/j00<0UVXi09aY
>P2LJCX00P2MJS/0202NJc`0Wf`m09m/?@2PKCh0Vfm209U]@02FJSd0U6Pk0P2EJC`02`2HK3l0W713
09mcAP2FJST0Uf/j09Y^?@2LL3l0WG5009a`?`2KKch0VVhm0080V6`k00@0VFdl09Y^?@2JKSd0Vfln
0P2LL3l809]`?@0609M]>`2IKcd0W79009id@P2PMT@0WgE30P2NM48509ib@@<0WG5000<0W70o09ea
@02OLd800P2PM4<00`2OLd80WG5009a`?`0209ie@@<0WgI20`2PMd<01@2NM480WgE309me@`2PMT@0
XGM50080XWQ600<0XgU70:1g@`2PMd<00`2OMT8309ie@@@0XWM4102QMT<20:=jAP<0Y7]71P2UO4P3
0:AkA`80XgY600/0Z7e:0:MlB@2TNDH0XWM40:5f@`2RMd@0XgQ50:AiAP2UNTL0XgQ50:9gA0020:5f
@`030:=hA@2UNTL0Yga90080YWe900@0YGa80:AkA`2RNDD0XGQ40P2PMd<01@2OMT00WWDo09ie@@2N
M480WWA40080WW=600D0WW=809]a?`2IKcd0Ufdk09E[>@0209AZ>00:09E[>@2FK3X0UF`h09A[=`2C
JSH0TVTe091W<`2?IS80SVDa08eT<080QF<c1`24HS82085N>006081M=`1oG3H0OEXd07aI<`1kF380
NULa0`1lEbd207]F;0<0NUD[0`1hDR/207MA:P<0MU0Y0P1dC2P00`1cCBP0LDhX071>:002071@:@0<
06iA:@1_DBd0KU0/06e?:`1/CRX0JT`X06Q:9P1WBBD0ITPT06538@1SAB<0ITPV0P1YBbT02@1VB2H0
HdDS06538@1RAB<0HdHT06A79@1UB2H0ITTW06M::00206Q;:@0;06A6901UAbD0J4XX06Y<:P1[CB/0
JT`Z06U;:@1XBRP0KU4W06e@9P1[CR@00P1ZCB<02@1[CR@0KE0V06iA9`1bC2D0LddV07A>9`1eCbP0
MU0Y07QB:`0207UC;00407aB;01mDbd0OE<]07eC;@80OU@^0P1oEBl01P1nEbh0OeP_07mH;`20FC00
PEXa089K<P80Pe`c0P25GSD208AM=00:08=L<`22Fc80PU/b085J<@21GRP0PUlY08=P:P24HB/0QF8/
08MT;P80R6D_2022GC002022G2d0Ped^08AN;`26H340R68c08YT=@2;ICH0S6Hg0P29I3001028Hbl0
Qf8^08MR;P26HBd208EP;00408=M;P24GRl0Q5h_08AN;`80QEl`0P26H3400`2=HSL0Rf0e08UN<`02
08ML<@0408UN<`2;H3D0Rf0e08eR=`P0Rf0e00@0Ped^08AN;`24GRl0QEl`0P26H34208MQ<P0308QR
<`29Hc@0RV@e0080RfDf00<0RV@e08US=028HS<00`28I3@308MS<`X0QV8b2025HC4:08MQ=0<0QV0c
0`25Gc8808IQ=080PV8c00H0PV0b08=N<@22GC00PU`_08=J;P22FBd2089M<080Peha0P24Gc8208EP
<`D0PUh^0`23Gbl8085L;`P0Q5/_0`23GC02089L;`<0PE/^0P1mF2h0101nFBl0OeX`081K<@20Fc42
085L<P80PEd[00<0P5`/081K;P20Fbl00P1oFS001`1oFC80OEL`07eH;P1mF2h0OEP/07eH:`1mFBT0
0P1mFBL907]H<00307YG;@1iER`0N5D[0080Me@Z00<0N5D[07YG;@1kF2h0201eF2h207EG9@0407EF
9`1eERP0MUL[07IF;@80MUH_0P1cDbX3079B:@<0LE4X00H0L4hX075?:@1aCbT0LU0Z07=A:`1dDR`2
07EC;@0806Y=9@1[CRH0KU4Y06mB:P1`Db/0Ke8Z06e@:01/CbL206iA:@80KE0X00@0K4lW06]>9P1Z
CBD0JTdU201/CbL806A=8`0806e@:01[CRH0JD`T06Q;8`1WBR80J4/S06U<901ZCBD806E8:0P0H4TW
00@0Gd8R06138`1P@b<0HD@T0P1RABD206=69P<0IDPV0P1TAbD306=690P0GD@U201NABH0101OAb<0
GTHR05i68P1MAB4205a48080Fd<O00<0G4HQ05e78P1OBB@00P1QBbH02`1OBB@0GDLR05a68@1N@bD0
Gd@V0617:01PBBT0GDTX05Y79P1HAB@0EDDS00T0GD@U0P1KAb800`1NB2<0GdLS0657900206=69003
06E79@1MBR80GDXR0080GDXR101NBb<01`1QBB<0H4PR05m78@1NAR00GdLQ06598`1SBbD0101UCBL3
06A<9P80Hd/U0`1RBR@206=;9@<0I4`V0`1RBR@206=;9@<0I4`V00P0ITPT06I:9@1XC2L0IT`W06E=
9`1RC2D0GT/S05a98@<0GTPS0P1MAb8305a68@0606=;9`1RBRH0HTXV0618901OAb<0GTHR0P1MAB40
4@1UB2H0I4LU06958`1RAB<0HdHT06E89P1XBbT0JD`Z05]57P1NB240HD/T06A>9`1VD2T0IDlX06A>
9`1SCBH0K4`S0080KDdT00<0KThU06m?9P1`D2L00P1aDBP0101aDR<0Le@U07EF9`1gF2T207QI:P04
07MH:@1fEbP0O5X/07aJ;080OE/]00H0OU`^07mM;`1oGBl0P5h`085O<@20GS0207mM;`05081N<022
H380Q68d08IT=P27Hbl00P28I3000`29IC40RVHb08]W<`0208aX=080RFPc00@0RVTd08]Z=@2<JcH0
SF`g0P2>KCP209=`>P0409Aa>`2ELS`0UW<m09Ic?@80Ug@n00l0V7<o09Mb?P2GLSh0UW4m09E`?02F
LCd0Ug8n09Ud@02JMD40VG@o09Ye@02KMT40W7M209eh@`2NND@00P2ONTD01P2NNDD0WgY60:1kA`2Q
O4P0XWe90:=nBP80Y7m;0P2WPTh20:R3C`070:V4D02ZQE40ZXEA0:^6DP2]R5@0[8MC0:Z5D@020:R3
C`030:V4D02ZQE40ZhIB00<0[HUE0P2^RUH30:n;E`80/8]G0P2aS5P20;:=F@80/hiJ202bSET20;B>
H@<0/heP0`2bS5l80;>>FPP0/XaM00<0[XYF0;2<F02aSET00P2cSe/0102aSET0/8aH0:j:EP2cSF02
0;:<G@030;:<F`2aS5P0/HaG0080/8]D0P2cSUT20;:=F080/HaG0P2`ReH0202cSF00/XaO0:n9G02]
QeX0[8II0:f7FP2^R5/0[hUL202`ReL00`2^R5/0/8YM0;6;GP020;:<G`030;6;GP2`RUd0[XQK0080
[hQO00<0[hQM0:n9G02_REX00P2_REP0102_RUH0/HaH0;6<F02`ReL20:n:EP030:j9E@2]R5@0[HQD
00@0[XQI0P2_REX30;2:F`060;6;GP2aRe`0/H]L0;2:F@2`ReL0/8]F0P2_RU<80;:8EP030:b7D02]
R540/8]D0080/HaE00<0/8]D0:n:D`2]R5400`2^RED20:f8E0<0[XUE0P2_RUH30:j9E@<0[HQD00<0
[XUB0:b7D02ZQDh00P2YQ4d00`2ZQDh0[8M@0:j9DP020:^6C`050:b7DP2/Qe<0[HMF0:f7F02^R5T0
0P2^R5/01`2^R5T0[HMH0:b6E@2[QU80ZHA?0:V4C@2XPd`00`2YQ5020:Z5D@H0ZhIB00<0[8MC0:f8
E02^RED00P2^RED00`2[QU80[8MC0:f8E0020:j9E@0C0:f8E02/Qe<0ZhIB0:V4D02ZQE40ZhIB0:f8
E02_RUH0/8]G0;6<F02bSET0[XUB0:f8D@2/Qe80ZhIB0:^5E02/QUL0[HMH0:j8F`030:V4D080ZXEA
0`2[QU800`2`Qe<0[hIB0:f4D0020:b3C`030:f4D02^QE40[hIB0080[XUE0P2]R5@20:b7D`X0ZhIB
0P2_RUD20:j9E0@0[HQC00<0ZhIA0:b7DP2/Qe800P2/Qe830:f8D`030:j9E02ZQE40ZXEA00<0ZhIB
0`2/Qe<01P2^R5L0[HMF0:f8E02]R5<0[8MB0:b7D080ZhM=00@0ZHA?0:Z5D02ZQE00ZXE@0P2[QU42
0:b7DPP0/8MC202^Q5801P2ZQE40ZXAC0:^5E02/QUL0[HMJ0:j7G080[hQO00H0]8YH0;>9E`2cREL0
/HME0;26E02_QE<20:j4DPP0[XEA0P2ZQE430:^6DP<0[8MC0P2[QE@0102[QU80ZhIA0:^6D@2[QTl2
0:^7C@P0[XAB202[QU80102ZQ5L0ZhEH0:f7FP2_RE`20;2:G@030:n9G02^R5/0[XUD0080[XUD00<0
[HQC0:b7DP2[QU400P2[QU480:f8E0080;B9GP2cR5/0/HII0:n5E@2_QE<0[hIB0;27D@2aR5840:V4
C`@0ZXE@0P2^RE801P2]R5<0[HQD0:b6E@2/QUL0ZhEF0:^5F080[HQD0P2^RED20:n:EP060;2;E`2a
S5P0/HaH0;2;E`2^RED0[HQD0P2/Qe<00`2]R5@0[XUE0;2;E`080;67E@060:n5D`2^Q580[XAB0:b2
D02[PDl0ZX1>0P2YOdd80:f4D0P0ZhIB202]Pe420:^1C`040:f3D@2_QE<0/HME0;>9E`80]H]I202[
QU80102VPDd0Z8=?0:Z5D@2[QU820:b7D`030:^6DP2ZQE40ZhIB00L0ZhIB202[QeL00`2[QU40ZXE@
0:R3CP020:R3CP040:Z5D02/Qe80[HQC0:Z5D@80ZhIB00H0[8MC0:f8E02^RED0[XUE0:n:EP2/QUT2
0:b6E`030:^5E02[QU80ZhIA0080ZXE>0P2cRUH20;:9E@040;68E02`Qe<0/8MC0:n6DP80[XUD00<0
[HQC0:b7DP2[QU400P2YQ4l30:R3CP040:V4C`2ZQE00ZXE@0:^6D@80[8MB0P2/Pd/0102/Pdd0[HA@
0:f4D02^Q5820:j4E0T0[8MB0P2ZQE430:^6DP<0[8MC00<0[HQD0:b7D`2ZQE400P2YQ5002`2[QU80
[HQD0:j9E@2[QU80[HQD0:j9E@2_RUH0[XUE0:f8E02[QU80ZHA@00P0[HA@00H0Z8=?0:V4D02YQ500
ZhIB0:b7D`2]R5@20:j9E@030:b7D`2[QU80ZHA@0080Z8=?00<0ZHA@0:^6DP2/Qe<0202^Q5880:^6
C`P0ZXEA0`2[QU820:Z5D@<0ZHA@0P2ZP500102ZP4h0ZX5=0:Z1C@2ZPD/20:Z1B@P0ZhIA0P2VPDd2
0:N2CP80Z8=?0P2YQ5020:b7DP040:Z5D02YQ4l0Yh9=0:J1C080Y7m:00<0Z8A:0:V5B`2[Qdd00`2]
RDl01@2/R4h0ZhM=0:^1C`2YOdd0Z7i<0080Yge;00<0Z7i<0:UoC@2[PDl0202ZQE080:J1C@<0Yh9>
0`2VPDd30:F0C0P0YX5<1@2TNdL30:ElB080X7]70`2QO4P30:9mB@80Y7m;00<0Xgi:0:9mB@2QO4P0
0P2ONTH02@2NNDD0Xgi70:=nA`2RODP0XGa809miB02NN4T0WGM809egBP0209ag@00609eh@`2MN4@0
WWQ709ihB@2ONDX0WgU<0P2MN4@0102NNDD0WgY60:5lB02RODT20:=nBP@0WGM8102NN4T00`2ONTH0
X7]70:9mB@020:9mB@030:1kA`2NNDD0WGQ400<0XG]<:oooool002[ooooo00P0Sf@g091U>02BIcX0
U6Tl09EZ?@2DJC`0TVLj095V>@<0TfLj0`2DJ3/209EY?0P0U6Pk00<0TfPe09EZ=`2FJcP00P2GK3T0
1P2FJcP0TfPe099W=02AIcD0TVPf09AZ>080UV`j00<0UF/i09AZ>02CJCL00P2JKT4209U]@00409Q/
?`2GJch0UVXm09IZ?@80V6hl0P2GKC/209I/>P80UF/i0P2JKSd309U]?0<0V6`k00<0UVXi09Q/>`2L
L3l00P2NLT400`2LL3l0V6`k09IZ>@0209]`>`0409]`?@2JKSd0VVho09Y^?`80VFe000`0VFa209Q]
>P2HKCX0VFhk09]`?@2LLCh0WG8o09ic@02OM440VFhk09Y_?02LLCh209ic@00309aa?P2JKc`0VFhk
0080WW<l00@0WW<n09eb?`2LLCh0Vfln0P2KKd0409a`@`@0WG5400<0W74n09eb?`2OM4400P2PMD80
2`2OM440WG8o09aa?P2OM440X7E20:5f@`2RMd@0XGI309md@@2LLCh0Vg0m0080WgA10P2PMD840:5f
@`P0XWM400@0X7E20:5f@`2QMT<0XGI30P2RMd@20:=hA@0309ie@@2OMT80XGQ40080XgY600<0Y7]7
0:=jAP2SNTH00`2VNdP30:EjA`80Y7U6202SMdP00`2UNTL0Y7U60:9gA0020:5f@`030:9gA02TNDH0
YGY700P0XgU70P2SNTH20:9iA@<0XGQ400<0X7M309ec@@2MLd401@2NM4801@2OMD<0W79009Y`?P2G
KC/0U6Xh00<0TVPf00L0TfTg099]>02AK3P0T6/g08mY>02>J3T0S6Hi0080Rf@i0P29GcL00`27H3L0
QV4g08IQ=`0208AQ=`80Pf8g00@0Pehd089M<`21G380OeX`101nFBl207mL=P0407iK=@1lFC<0NULa
07UF<080Me@^0P1cE2P2079C9`<0LE8V00@0L54U06U;9`1ZC2P0K4hZ0P1^D2`0101]Cb/0K4hZ06]=
:@1[CBT306Y<:080JD/W0P1XBRH206]::@0406Y9:01YB2L0JDPW06Q79P80IdHU00P0JdXW06M68`1T
@b00IdHS06a;:01^CBX0JdXW06I58P80HdTT00<0IDTT06M99@1YB2D00P1[BBH03@1/B2H0Kd`/06i;
:`1/BBT0JdPX06a9:@1^Bb/0L4d]075>;P1bD2/0Le4/07EC;P1gEC000P1hES4207ME<00;07aI<@1k
F300NUL_07UF;P1jEbl0NeP`07eJ<P1nFc<0OUP[081J;@21Fbh00P22G2l00`21Fbh0P5X]07iH:`04
089L;`80Ped`0P24GS4208AO:`0408EP;026HBd0R6<_08UT<080RVDa2025H3<01P22G2l0Ped`08AN
<@25Gc80QV0c08QR=@@0RF<f00H0R68e08IP<`25Gc80Q5ha08=M<022G2l808YO<PT0Qf4b2028HS<0
0`26I3@0QF<c08=Q<@02089P<00308=Q<@25Hc<0QV@d0080R68c00@0RF<d08YT=@2:I3D0RfDf0P2<
ISL808US=00@08QT:P27HR/0QV4/08EO;P25Gc80Qf0e08UR>`2:Hc`0Q5lb08EP<`26HC@0Qf8e08IQ
=025H3<0Peha089M<0P0Q60`00P0RF@g08MR=@25H3<0Peha089M<023GS40Q5lb08EP<`<0R68e0P27
HC@308IP<`0408EP<`24Gc80Q5lb08AO<P80Peha0P22GC0208AK;`<0QE``0`26GC401P20GCD0P5dc
081M<`21Gc80PEla081N;P80P5l/00H0Peha089M<022GC00P5/^07mJ;@1nFB`207eH:`0807iI;`1o
FS00P5/a085L<P22GC<0Pehd08AO=@25H3H8089M<080OETW0P1nFRP207mK:@80P5`Z00<0O5L]07iI
;`1oFS000P21G3800`1oFS00OUT_07aG;@0807eI9`<0OEH]1P1lEB`01P1kFB/0NeT/07]I;01jEbd0
NUL_07UF<080NEDa201dE2/00`1bEBd0LE@/06mB:P0206iA:@0406mB:P1`Db/0LE@/06e@:080KU4Y
00<0Ke8Z071C:`1aE2`00P1bEBd2075D;080L5<[0`1_DRX02@1^DBT0KdlX075A:P1bDR/0Le</079B
:`1aDBX0KThW06e=9P0306i=:PD0KD`Y0P1ZDBT00`1YD2P0J4lW06M>9P0206I=9@0406E<901UAb<0
IDLS06I89080IdTU00<0J4XV06U;9`1YBbL00P1RCB82069<8`07069<9@1RC2L0HDXX065::01QB2T0
GTDV05]28`0205U08@0405]28`1NABH0HDPY05Y27P80Fd<O00<0G4@P05e58@1NAR800P1OAb<305e4
9@80G4<T0`1K@R<00`1I@240FT4R05a3900205i59P0405a3901J@B80FD0Q05Po80<0FD0Q0P1J@B82
05]28`80ET4T00<0ET4R05M38P1G@b000P1HA1l01P1HAAd0GT4O05i17`1L@Ql0Fd<O05Y47`80F4@O
00<0EdDO05Q59@1HABD01P1HABD0201LABH0Fd@U05Y3901I@R<0FT<T05a59P1NAbP0GdPY0P1PAR<2
05m58P0305i48@1M@b00GD<P0080G48O0P1LAB<205e690<0GTLU00<0GdPV05a47P1LA1h00P1MAAl3
05i6800305m78@1RB2L0HTPW0080HDLV00@0H4HU05m5901OAB@0GT@S0P1OBB@3061:9@<0HD/V00<0
HT`W065;9P1NB2<00P1LAR400`1NB2<0HD/V069<9`0806Q::0@0HT`W101SCBP205m89P0405i79@1M
AR@0GDHT05a58`80Fd@R201J@b40201UBbP0HTPU05m58P1M@b00GT@Q06989@1XCR/0Je4^0P1PBRD2
065;9P<0HT`W00H0HddX06]>901[CR@0K4lU06e@9P1^DBL206mB:007071C:@1_DRP0Ke8V071C9`1`
E2D0LEDU079F900207=H8`0807UJ:`1jFb`0O5d^07eN;`1lGBh0Ne`]07UJ:`1gF2T2085Q>P04085Q
>021HSH0PF8d089S=080PV@b00`0R5lc08UP=02:HCD0Rf8f08aS=`2=I3P0SVDi08mV>P2<I300SVHb
091X=02BJSH209=[=`08099Z=P2AJCD0TF/l099/?@2CKCh0U6ho09E_@02FL44209Ma@P<0UW4m0`2G
LSh309Qc?`<0VWE00P2KMT4309ag@P80VWI200H0W7Q409eiA@2ONdL0XGe90:9nBP2SOd/20:F0B`<0
YX5<0`2WPTd60:^6DP80[8MC0`2]RED20:j:EP<0[h]G00H0/HYA0;6:D`2aRED0/HUH0;68G02aQed2
0;67H@80/8YK0P2aRe`20;:<G@80/heN00<0]Y5M0;F@G02cSUX00P2bSET0102cSUX0]I1L0;JAG@2a
SEd20;2<G080[h]K0P2^RUX00`2_Re/0/XeI0;:=F@060;:=F@030;6<F02`ReL0[XUE0080[XUE01@0
/8]G0;>>FP2dSe/0/XeI0;6<F02`ReL0[hYF0;2;E`2aS5P0/hiJ0;B?F`2aS5P0/8]G0:n:EP2^RED0
[hYF0;2;E`2bSET0/hiJ0;>=GP<0/XaM0P2aRe`20;2:F`P0[hUJ202aReh80:j9E@080:n=D02_S580
[haD0:j;E@2^RUP0[HQK0:f8G02]R5h40:j8F@80[hUJ0`2`RU/80:n:EP080:n9G02`RU/0/H]L0;6;
FP2`ReL0[hYE0:f8D@2[QTl80:^6DP030:b6E`2]QeP0[hUJ0080/H]L00<0/8YK0:n9FP2^R5T00P2_
RUH30:j9E@<0[HQD102`ReL40:n:EP80[hYE0`2^RE@30:f8D`P0[XUE00H0Z8=?0:V4D02YQ500ZhIB
0:b7D`2]R5@20:j9E@<0[XAB00<0[hEC0;26E02aQeD00P2aQeD80:f8E0040:N2CP2YQ500ZhIB0:j9
E@<0[hYF00T0[XUE0;>>FP2bSET0/HaH0;2;E`2_RUH0[XUE0:f8E02/Qe<00P2ZQE420:^6DP@0[8MC
202[QU80202/Qe80[HQC0:n:E@2_RUD0[XUD0:b7DP2ZQE00Z8=>202ZQE020:f8E080[8MC00@0ZhIB
0:Z5D@2ZQE40ZHA@2@2[QU800`2]R5@0[8MC0:^6DP020:V4D0030:^6DP2/Qe<0[HQD00P0ZhIA0`2/
Qe<30:^6DP80ZXEA0`2_QED30:j4E080[H=C102]Pe401`2^Q580[hEC0;26E02aQeD0[hYF0:f8E02/
Qe<00P2ZQE402@2/Qe<0[HQD0:n:EP2`RU/0[hUJ0:f7F02[QEH0ZXAE0:^5EP020:b6E`P0[HMH0P2[
QU820:b7D`80[HQD0P2^RED20:b7D`H0ZhIB202/Qe<30:V4C`80ZXE@0`2[QU420:f4D0<0[XEA0`2_
QU880:j5D@P0[8MB102]R5@20:j9E@80[hYF0P2]R5400`2]R5<0[HQD0:f7EP020:f7F0030:f7FP2[
QU80ZhIB00H0ZhIB00@0ZHA?0:Z5D02ZQE00ZhIA0`2/Qe820:f8D`070:n:EP2^RED0[8MC0:^6DP2/
Qe<0[XUE0;2;E`030;6<F0040;2;E`2_RUH0[hYF0:j9E@80[HQD0P2`Qe<0102_QU80[XEA0:b3C`2[
PTh20:Z1C@060:f2B`2/Pd/0[8==0:b4D02ZQE00ZXIB0P2XQe@20:f8E0040:b7D`2[QU80ZHA@0:R3
C`80Yh9>202[QU480:j5D@80ZhIB0P2/Qe<30:f8E0070:j9E@2/QUT0[8IG0:b6E`2[QE@0ZhIB0:^6
D@020:Z5CPP0ZhIB402ZQE480:b8CP080:N2CP2YQ500ZhIB0:f8E02^RED0[HQD0:b7D`2[QU820:Z5
D080ZhIA00@0[8MB0:f8D`2^RE@0[XUD0`2/Qe830:^6D@80ZXE@1@2[QU430:b7DP030:^1C`2^Q580
/HME0080]8YH00<0/HME0:j4DP2[PDl00P2YQ4d00`2YQ4l0ZXEA0:Z4D`030:^5EP060:^5F02[QU80
ZhIB0:^6DP2/Qe<0[HQD0`2^RED00`2YQ500ZXEA0:b7D`020:f8E00;0:b7D`2ZQE40ZHA@0:Z5D@2[
QU80[HQD0:j9E@2]R5@0ZhIB0:V4D02XPdl00P2YQ4d00`2YQ4l0ZHA@0:V3DP020:V3E0070:V3EP2]
R5<0[HQD0:f8E02]QeH0[HMH0:f7FP020:f6F`P0ZhI?0P2YQ5040:Z5D@80ZhIB202ZQE400`2^R5T0
[HMH0:^5EP030:Z4E@80ZhEF0P2/Qe<0102[QU80ZXEA0:Z5D@2YQ5020:R3C`030:^6DP2ZQE40Z8=?
0080Yh9>00<0Z8=?0:Z5D@2[QU800P2`Qe<30:n6DP<0[XEA0`2VPD`20:N2C@<0Z8=>0P2ZQ5D30:V3
E0<0Z89C00P0ZhEF0:Z4E@2XPU<0Z89C0:V3E02[QEH0[HMH0:n9FPD0ZHA?0`2XPdh80:V4C`080:Yn
C@2YOdd0ZX1>0:Z2C`2YQ500ZHEA0:R7DP2YR5<20:N2CP80YX5=102UP4`01`2TOd/0ZGe<0:QnC02X
OT`0Ygm<0:F0C02TP4`00P2RPD`40:9mB@@0Xgi:00<0XWe90:5lB02ONTH00P2NNDD0102ONTH0XGa8
0:9mB@2QO4P30:9mB@<0Xgi:00H0Y7m;0:=nA`2SOTL0XWe80:9mB@2QNdX20:1jB`0409miC02QN400
XGQ00:5h@P80XGQ400<0XGM50:5gA`2QMdL00`2RODT30:5lB080X7]700P0WWU509mjAP2QO4P0XWe9
0:5lB02PNdL0WGQ409ag@`<0WWY60P2ONdL30:1lB0<0WWi=:oooool002[ooooo00<0T6Dh095V>@2C
J3/00`2EJSd209=X>`<0TfLj0P2DJ3/309EY?0P0U6Pk00<0TfLf09AX=`2FJST00P2GJcX01P2EJCP0
U6Pg099V=@2AIcD0TVPf09AZ>0<0UV`j00<0UF/i09AZ>02HK3l00P2HK3l309M[?P80UVXm0P2HKS`2
09M]>`80UV`j0P2EJcT209Y^?@<0VFdl0`2HK3/00`2FJST0V6`k09a`?`0209ib@@0309a`?`2HK3/0
UVXi0080Vg0k00@0Vg0m09Y^?@2JKSl0VVho0P2IKD001@2IK480VFhk09U^>`2JKc`0Vg0m0080W74n
0P2MLSl00`2JKc`0Vg0m09aa?P0209eb?`0309aa?P2KL3d0VVll0080WW<l00@0WG8m09eb?`2LLCh0
W70o0P2KKd0409a`@`@0WG5400<0W74n09eb?`2OM4400P2PMD801@2OM440WG8o09aa?P2OM440X7E2
00<0XGI300<0WgA109eb?`2LLCh00P2OM4420:1e@P<0XGI32@2RMd@40:5f@`80XWM40P2SN4D0102R
NDD0XGQ40:5hA02QN4@20:9iA@80XgY60`2VNdP30:EjA`80Y7U6202SMdP00`2UNTL0Y7U60:9gA002
0:5f@`030:9gA02TNDH0YGY700P0XgU700@0XgY60:9iA@2RNDD0XWU50P2QN4@20:1g@`D0WG=10`2N
M480102KLCl0VFlm09I/>P2DJSP3099X=P0909=Y=`2AK3L0TF`h091[=`2?JCP0SFLh08aV>@2;I3T0
RV<h0080RV0h00<0Qf0g08IQ=`25H3H00P23H3H2085P=@<0PE`b00D0P5/a07mJ<01nFBl0OEP^07aG
;@0207iK=@0707eJ=01kF380NULa07QE;`1gE2h0MU<]07=D:003079C9`80LE8V0P1`DBD00`1ZC2P0
JddY06e?:`0206i@;00306a>:P1[CBT0JT`X00@0JT`X0P1YBbL206Q:9P<0JTTX00<0JDPW06Q79P1X
AbH00P1WARD02@1[BRL0IdHS06E48@1WAR<0JdXW06e<:@1[BRL0IdHS06=9900206I:9@0306M99@1Z
BBH0JdTV0080KDTW00`0KddZ06i<:@1]BbP0K4XW06e;:01^C2T0L4h[079@;@1aCbX0Le4/07EC;P1g
EC0207QF<@0407ME<01fE2l0O5T_07]H;P<0NUL]00H0O5T_07eJ<01oG380P5X]085K;P22G2l208=M
<003089L;`21Fbh0P5X]00<0Ped`0`24GS4208EO<P0508AO:`25H2`0QF0/08IQ;@28Hbl00P29I300
0`2:IC40QF0c08EP<`0608EP<`80Q5ha0P25Gc801026H3<0Qf4d08QR=@28HSD208EO<P@0QV0c0P27
HC@808YO<PT0Qf4b2028HS<00`26I3@0QF<c08=Q<@02089P<00308=Q<@25Hc<0QV@d00<0R68c0P29
Hc@308YT=@P0R68c0100R6</08MR:`26HBd0QEl^08EO<P27H3D0RF8i08YS?024Gc80QF0c08IQ=027
HSD0QV4d08EP<`23GS40PUd`2025HC400`28HcH0Qf8e08EP<`0308=N<@0408AO<P25H3<0R68e08QR
=@<0Qf4d0`26H3<408AO<P80Peha0P22GC0308AK;`80QE``0`26GC401P20GCD0P5dc081M<`20GS40
P5h`081N;P80P5l/00H0Peha089M<021G2l0P5/^07mJ;@1nFB`207eH:`0607eH;P1nFBl0OeX`081K
<@21G380PUdc0P23GS@8081K;P80OETW0P1nFRP207mK:@80P5`Z00<0O5L]07eH;P1oFS000P20Fc40
0`1oFS00OEP^07aG;@0807eI9`D0OEH]101nEbh0201kFB/0NeT/07YH:`1jEbd0NEH^07UF<01iEC40
N5@`201dE2/00`1bEBd0LE@/06mB:P0306iA:@03071C:`1aE2`0KU4Y00<0Ke8Z101`Db/0101aE2`0
L5<[071C:`1`Db/206mB:P80KU4Y00<0KdlX071@:@1bDR/00P1bDR/00`1`D2T0KThW06e=9P0306e<
:@@0KTdZ00H0Kdh[06U@:01YD2P0J4lW06M>9P1VCBD206E<900506A;8`1TB2<0I4PS06A88`1UBB@0
0P1VBRD206M;9P80HTdR00<0HD/R065;901QBbH00P1PBBL0101PBBT0GdPX05a59@1I@R8205M08003
05U28P1LABD0GdPX00<0FT<Q0`1KA28205a58`0405]4901J@b<0FT<S05Y38`80FD8R0`1H@B401P1I
@R80FT<S05a59@1LABD0FT<S05U28P@0F44Q0P1I@R8305Y38`0605E08`1F@B@0ET4R05I18P1G@b80
Ed<P0P1HA1l01P1N@B40G48Q05a28@1K@b40FT<Q05Q48@80EdDQ201GA2@0201KA2D0FT<T05U28`1I
@R<0FT<T05]49@1MARL0GdPY0`1OAB@205i48`0405e38P1L@R40G48Q05a28@<0Fd@R0P1LAB<305e6
90<0G4HO0P1MAb0305i88@0306989`1QAbH0HDLV0080H4HU0P1OAB@00`1NA2<0GdTT05m99002061:
9@07065;9P1RC2L0HT`W06==:01QBbH0H4XU05m9900205i88`0305m9901PBRD0HD/V00P0IDPV1@1Q
BbH3069<9`0305m89P1NAbD0GTLU0080GDHT0P1LAB<905]48P0806=99P1QAb@0H4HS05m58P1PAR<0
HdTV06I<:@1YCb`3065;9P80HT`W0`1SCBP01P1YCBD0JThV06Y>9P1[CbL0K50X06eA:@80KU8Z0100
KU4W06mB:01_DRH0L5@U075E9@1bER@0LeLU07=H8`1hFB/0NEX/07]L;P1lGBl0Ne`^07YK;@1hFB/0
MePZ0P1oGcP01`1oGcH0P64e081Q<`20HC80P68`085S<@28Gc<00P29H3@02@2:HCD0S6<g08eT>02=
I3P0SVDi08aT<@2=IC80SfLd095Y=P02099Z=`80TFTf0P2?JCX00`2@JS/0TF/l099/?@0209A^?`03
09E_@02FLCd0UW4m0080UW4m0P2GLSh309Qc?`<0VWE00P2KMT4309ag@P80W7Q400H0WGU509mkA`2P
O4P0XGe90:9nBP2SOd/30:F0B`80YX5<0`2WPTd30:Z5D@@0ZhIB00@0[8MC0:f9E@2]RED0[HUE0`2^
RUH20:n;E`80/HYC00H0/HUF0;69F02aR5`0/HMM0;67G`2aQf420;2:F`80/H]L0P2bS5d20;>=GP03
0;JAG@2eT5`0/hiJ0080/XeI00<0/hiJ0;F@G02fTEd00P2aSEd20;2<G080[h]K0P2^RUX80;:=F@0H
0;6<F02`ReL0[hYF0:j9E@2_RUH0/HaH0;>>FP2dSe/0/XeI0;6<F02`ReL0[hYF0;2;E`2aS5P0/hiJ
0;B?F`2bSET0/HaH0:n:EP2^RED0[hYF0;2;E`2aS5P0/XeI102bS5d20;6;G080/8YK202_REX80;6;
G0P0[XUE0P2_S580102_S5@0[XYF0:j:F02]R5/20:f8G0T0[hUJ202_RUH0202_RE`0/8YK0;6;G02a
ReX0/HaH0:n:E@2]R540[8M@202[QU80202/QUL0[HMH0:n9FP2`RU/0/H]L0;2:F`2_REX0[XQI0P2_
RUH30:j9E@<0[HQD102_RUH40:j9E@80[hYF0`2^RED30:f8E0P0[XUE00H0Z8=?0:V4D02ZQE40ZhIB
0:b7D`2]R5@20:j9E@80[XAB0P2_QE<20;26E080/HME202]R5@01@2YQ500ZXEA0:b7D`2^RED0[hYF
0080[XUE00T0[HQD0;6<F02aS5P0/8]G0:n:EP2^RED0[HQD0:b7D`2[QU800P2ZQE420:^6DP<0[8MC
00<0[HQD0:^6DP2[QU801P2[QU80202/Qe80[HQC0:j9E02_RUD0[XUD0:b7DP2ZQE00ZHA?202ZQE02
0:f8E080[8MC00@0ZhIB0:Z5D@2ZQE40ZXEA2@2[QU800`2]R5@0[8MC0:^6DP020:V4D0030:^6DP2/
Qe<0[HQD00P0ZhIA0`2/Qe<30:^6DP80ZXEA0`2_QED20:j4E0<0[H=C0`2]Pe420:j4DP060:n5D`2`
QU@0/8ID0:j9E@2]R5@0[8MC0P2[QU802P2/Qe<0[HQD0:j9E@2`RU/0[hUJ0:f7F02[QEH0ZXAE0:^5
EP2/QUL90:f7F080ZhIB0P2/Qe<20:f8E080[XUE1@2[QU8;0:b7D`<0ZHA?0P2ZQE030:^6D@80[HA@
0`2^QE430:n6DPP0[XEA202/Qe80102/Qe<0[HQD0:f8E02]R5@20:j9E@80[hYF0P2]R5400`2]R5<0
[HQD0:f7EP020:f7F0030:f7FP2[QU80ZhIB00H0ZhIB0P2ZQE020:^6D@<0[8MB0P2]R5<20:j9E@<0
[8MC00<0[XUE0;2;E`2aS5P00P2`ReL30:n:EP<0[XUE00D0/8MC0:n6DP2_QU80[XEA0:b3C`020:^2
CP070:Z1C@2]PT/0[8=;0:f4CP2/Q500ZXE@0:Z6DP020:R7E080[HQD00H0[8MC0:^6DP2ZQE40ZHA@
0:R3C`2WPTh80:^6D@P0[XEA0P2[QU820:b7D`@0[HQD00H0[8II0:b6E`2/QUL0ZhED0:^6DP2[QU42
0:Z5CPP0ZhIB402ZQE480:^7C@030:R3C`2YQ500ZhIB00<0[HQD00<0[8MC0:^6DP2ZQE000P2ZQE03
0:^6D@80[8MB1`2[QU400`2/Qe80ZhIA0:^6D@040:^6D@80[8MB00<0[89@0:j4DP2aQeD00P2cREL0
0`2aQeD0[XAB0:b2D0020:V4C@030:Z5D02ZQE40ZXAC00<0ZhEF00<0ZhEH0:^6DP2[QU800P2/Qe<2
0:f8E080[XUE00<0ZHA@0:Z5D@2/Qe<00P2]R5@00`2/Qe<0ZXEA0:V4D0020:^6DP<0[HQD00<0ZhIB
0:V4D02XPdl00P2YQ4d00`2YQ4l0ZHA@0:V3DP020:V3E0070:V3EP2]R5<0[HQD0:f8E02]QeH0[HMH
0:f7FP020:f6F`P0ZhI?402ZQE450:b6E`030:^5EP2ZQ5D0ZXAE00<0ZhIB0P2ZQE430:V4D0030:^6
DP2ZQE40Z8=?0080Yh9>00<0Z8=?0:Z5D@2[QU800P2_QU830:j5D@<0[HA@0P2WPTh30:R3C`<0ZHA@
0P2ZQ5D30:V3E0<0Z89C00P0ZXAE0:V3E02XPU<0Yh5B0:R2D`2YPe@0ZhEF0:f7F0@0ZHA?102XPdh8
0:V4C`060:YnC@2YOdd0ZX1>0:Z2C`2YQ500ZHEA0P2XQe820:R3C`80Yh9>102VPDd01`2UP4`0ZGe<
0:QnC02XOT`0Ygm<0:F0C02TP4`00P2RPD`30:9mB@D0Xgi:00<0XWe90:5lB02PNdL00P2ONTH00`2P
NdL0XGa80:9mB@020:=nBPH0XWe90P2SOTL00`2RODP0XWe90:5kBP020:1jB`040:1jC@2RND40XWU1
0:9i@`80XWU500<0XWQ60:9hB02RN4P00`2RODT20:5lB0<0X7]700P0WWU509mjAP2PNdL0XGa80:1k
A`2ONTH0WGQ409]f@P<0WWY60P2ONdL30:1lB0<0WGe<:oooool002[ooooo00<0TVLj09=X>`2EJSd0
0`2FJch209EZ?@80TfLj0P2DJ3/309EY?00309IZ?@2DJ3/0U6Pk00H0U6Pk00<0TfLf09AX=`2EJCP0
0P2FJST02`2EJCP0U6Pg09=W=P2BJ3H0TfTg09E[>@2FK3X0Ufdk09I/>P2EJcT0U6Xh0080UFTl0`2F
JSd309M[?P80V6hl0P2GKC/209I/>P80UF/i0P2JKSd309U]?0<0V6`k00<0Uf/j09U]?02KKch00P2M
LD000`2KKch0VFdl09M[>P0209]`>`0409]`?@2JKSd0VVho09Y^?`80VFe000<0VFa209]`?@2KL3d0
1@2KL3d0102LLCh0Vg0m09]`?@2LLCh209eb?`0;09aa?P2KL3d0Vg0m09ic?02MLS/0WG8m09eb?`2L
LCh0W70o09a`@@2KKd00102MLD@409a`@`0309aa?P2MLSl0WW=00080WgA100D0WW=009eb?`2LLCh0
WgA10:1e@P030:5f@`0309md@@2NLd00WG8o00<0X7E20P2QMT<;0:9gA0<0XGI30P2RMd@30:=hA@03
0:ImB@2TNdL0XWU50080WgI200<0XGQ40:=jAP2TNdL00`2VNdP30:EjA`80Y7U6202TN4L00`2UNTL0
Y7U60:=hA@020:9gA0030:=hA@2TNDH0YGY700P0XgU70P2RNDD20:5hA0<0X7M300<0WgI209ab@02L
LT001P2LLT00102IKcd0V6hl09I/>P2DJSP4099X=P08091[=P2@JcL0SfXf08iX=`2<ISL0RfDh08YS
>029HSL208]Q>@0308QQ>026HCL0Q5le0080PEhd0180Oehc07iM<P1nFBl0OeX`085L<P22GC<0PE`b
07mJ<01kER`0NE@Z07eJ=01lFC<0NePb07YG<@1hEBl0Me@^07IC;@1eDR`2079B:@80LE4X0`1`D2L0
0`1_CbH0K4hZ06e?:`0206e?:`0406a>:P1[CBT0JD/W06Q:9P<0JT`X0P1YBbL306Q:9P0406Y9:01Y
B2L0JDPW06U89`<0J4LV0140IdHU06Y99P1XAb@0ITDR06M68`1ZBBH0K4/X06]:9`1YB2D0ITXU06M;
9P1XBRH0JTTV06a:9`1]BBL0KTXX0719:002071<:P<0Kd/Y00L0LDd[079>;01cCbd0LTlY07=@:P1e
DR`0Me@^0080N5D_0P1gE2h02`1oFS00OUT_07eH;P1lEbd0OEP^07iI;`20Fc40PE`b089L;`23GC00
Q5ha0080QElb00<0Q5ha08=M<022G2l00P24GS4308EO<P<0QV0c0P25H2`01026HBd0Qf8^08MR;P28
Hbl208UT<0P0QF0c00<0QElb08IP<`26H3<01@26H3<01P22G2l0Ped`08AN<@26H3<0Qf4d08US=P80
RV@g202:Gc8908MQ<PP0R68c00<0R6@d08MS<`26HS800P25HC400`26HS80Qf<c08QT=00408QR<`@0
Qf4b2026H3404028Hbh0Qf8^08IQ;@25Gbh0QEl`08MQ=029HSL0RV<h08AO<P25H3<0QV4d08MR=@26
HC@0QF0c08=N<@22GC0808IR<P0508MR=@26HC@0QF0c08AO<P23GS400P24Gc800`25H3<0R68e08MQ
=00208MQ=080QV0c0P25Gc8308AO<P80Peha0`22GC001021Fbh0PU`_089L;`22G2l208=M<080Q5ha
00H0P5de081M<`1oG380Oed`07mM;`1oGBd2081O;080PUd`00<0PE`_081K;P1oFRd00P1nFB`01P1m
F2/0O5L]07aG;@1mF2h0OUT_07mJ<080P5/a00<0PE`b07iI;01nFB`01P1nFB`207eI:@80OUXZ0P1o
Fb/2081L;080OEP^00@0OUT_07mJ<01oFS00OUT_0P1mF2h807eI:@0507]F;01lEbd0O5L]07eH;P1n
FBl0101oFS001P1jF2X0NUP[07YH:`1iER`0NEH^07QE;`80N5@`201dE2/01`1bEBd0LE@/06mB:P1^
DBT0KE0X06iA:@1_DRX00P1`Db/306mB:P@0KU4Y0P1`Db/206mB:P<0KU4Y0P1]D2P0201^DBT0Ke8Z
06mB:P1^DBT0KE0X06a?9`1[CRH0JT`X0P1[CBT00`1/CRX0KDl[06e?:`0206i@;080IdlY00@0IThX
06E=9`1TC2H0Hd/U0P1RBR@206=69080I4LU101UB2H00`1QBb80H4XQ061:8`0205m9900605i79@1N
AbL0GTLW05e69`1KA2D0F44R0P1F?b000`1H@B80Fd@U05e69`0405Y38@@0FD8P0`1H@B8205M08@<0
ESlP00<0Ed0Q05Q18P1I@R<00P1J@b@0101I@R<0F44R05M08@1H@B8305U28`80FT<T0P1KA2D0201C
?b@0E40U05A18`1D@B40ED8Q05E37`1FA200ET@N0P1K@B000`1J@R00FD8P05M3800205I4800305A4
801D@B40E44Q00H0E44Q00<0Fd@U05Y3901I@R<00P1H@B800`1J@b@0G4DV05e69`0305e58`80G4@R
101K@b4305U28080FT<Q0`1KA28305e78P80GTPS0`1OBB@206189P80GdLU101NAR@0201NB2<0GdTT
061:9@1QBbH0HT`W06==:01TCRT0IDlZ0P1NB2<0101OBB@0H4XU061:9@1OBB@205i88`P0HdHT0`1P
BRD505m990<0GTLU0P1MAR@305a58`P0GDHT0P1OAb<01P1PB2@0HDTU069:9P1RBRH0Hd/W06A<:0<0
HT`W0P1SCBP306A>:@0606Q<901YCBD0JDdU06Y>9P1[CbL0K50X0P1]DBT01P1]D2P0KU4Y06iA9`1_
DRH0L5@U075E9@80LUHT00P0MeP/07QI;@1iFRh0NEX^07YK;`1iFRh0N5T]07MH;080O5`e00@0OEdd
07eN<P1nGc40OUl`0P1oHBl208IP<`0308MQ=028HSD0RF<f0080RV@g00H0RfDh08UT<02;IS80SFPd
08mZ=P2@JcL208mZ=P0708iY=@2>J3T0SfTj08mY>P2@JS/0TF/l099/?@0209=]?P0309E`?02FLCd0
UW4m0080UW4m0P2GLSh209Qc?`<0VWE00P2KMT4309ag@P80Wg]70P2PO4P20:5mB@80XWi:00@0Y7m:
0:F0B`2UP4/0YH1;0P2VPD`20:N2C@<0ZHA@0P2ZQE430:^6DP80[8QD0P2]RED30:j:EP070:n;E`2_
RUD0[hYF0:n:EP2_REP0[hUJ0:n9G0020:n8G@80/8YK0P2aRe`20;:<G@80/heN00<0]I1L0;B?F`2c
SUX00P2bSET0102cSUX0]8mK0;F@G02`S5`30;6=G@040;2<G02_Re/0[h]K0:j:FPP0/XeI00/0/HaH
0;2;E`2`ReL0[hYF0;2;E`2aS5P0/XeI0;>>FP2bSET0/HaH0;2;E`020:n:EP060;6<F02cSUX0]8mK
0;:=F@2aS5P0/8]G0P2^RED00`2_RUH0/HaH0;:=F@030;:<G@80/H]L0`2`RU/80:n9FPP0/H]L202^
RED20:n<E0040:n<EP2^RUH0[XYH0:f9F@80[HQK0P2aRe`20;2:F`80[hUJ00<0[XQI0:f7F02]QeP0
202_RUH0202_RE`0/8YK0;6;G02bS5/0/HaH0;2;EP2^RE80[HQA202/Qe<00`2[QEH0[HMH0:j8F@03
0;2:F`040:n9FP2^R5T0[hYF0:n:EP<0[XUE2`2]R5@20:n:EP<0[XUE2`2]R5@20:V4D0030:Z5D@2[
QU80[8MC0080[HQD00<0[XUE0:j4DP2_QE<00P2_QE<30;26E0030;67E@2]R5@0[HQD00H0[HQD00<0
ZXEA0:b7D`2]R5@00P2^RED0102]R5@0[8MC0:^6DP2_RUH20:j9E@030:f8E02/Qe<0ZhIB0080ZXEA
0`2[QU820:b7D`<0[HQD202[QU800`2/Qe80[HQC0:j9E0020:j9E0030:b7DP2[QU40ZXE@00P0ZhIA
0`2/Qe<30:^6DP80ZXEA2@2/Qe<00`2]R5@0[8MC0:^6DP020:V4D0030:^6DP2/Qe<0[HQD00P0ZhIA
0`2/Qe<30:^6DP80ZXEA0P2_QE<20:j4DP<0[H=A00@0[89@0:f3D@2]Pe40[XAB1@2_QE<00`2^RED0
[HQD0:b7D`020:^6DP0:0:b7D`2]R5@0[XUE0:n9FP2^R5T0[8IG0:^5EP2ZQ5D0ZhEF0:b6E`T0[HMH
0P2[QU820:b7D`80[HQD0P2^RED0102YQ500ZXEA0:Z5D@2[QU820:b7D`80[HQD202/Qe<30:V4C`80
ZXE@0`2[QU420:f4D0<0[XEA0`2_QU880:j5D@P0[8MB0`2/Qe<20:f8E0<0[XUE0P2]R5400`2]R5<0
[HQD0:f7EP020:f7F0030:f7FP2/Qe<0[8MC00H0[8MC0`2[QU440:b7DP80[HQC00T0[XUE0:f8E02]
R5@0[8MC0:f8E02^RED0[hYF0;2;E`2]R5@00`2^RED40:n:EP80[hIB00@0[XEA0:f4D02]Q500[8=?
0P2[PTh01P2]PT/0[HA<0:f4CP2/Q500ZhIA0:Z6DP80ZHQE0P2]R5@00`2/Qe<0ZhIB0:Z5D@020:V4
D0030:R3C`2[QU40ZhIA00H0ZhIA202^QE430:^6DP80[8MC0`2]R5@01P2/QUT0[8IG0:b6E`2[QE@0
ZhIB0:^6D@80ZXE>402[QU880:Z5D@P0ZXE>00D0ZHA@0:Z5D@2[QU80[8MC0:f8E0020:b7D`040:^6
DP2ZQE00ZXE@0:Z5D0<0ZHA?0P2XPdh20:V4C`040:Z5D02[QU40[8MB0:b7DP80[HQC202[QU400`2/
PU00[XAB0;67E@020;>9E`080;67E@2^Q580[89@0:V4C@2ZQDh0ZXE@0:Z5D@2[QE@20:^5EP030:b6
E`2/QUT0ZhIB00<0[8MC0`2]R5@0102^RED0ZXEA0:^6DP2/Qe<20:f8E0040:b7D`2[QU80ZXEA0:^6
DP80[8MC00D0[HQD0:b7D`2[QU80ZXEA0:V4D0020:V4C@030:V4C`2YQ500ZH=B0080ZH=D00L0ZH=F
0:f8D`2]R5@0[HQD0:f7EP2]QeP0[HMJ0080[HIK202[QU4@0:Z5D@030:Z4E@2/QUL0[XQI0080[hUJ
00<0[8IG0:Z4E@2XPU<00`2YQ5020:Z5D@<0ZhIB00<0ZXEA0:V4D02XPdl00P2WPTh00`2XPdl0ZHA@
0:Z5D@030:f4D0<0[8=?0P2[PTh30:V4D080ZXEA0`2[QU820:Z4E@<0ZH=D102XPU<01`2WPE80YX1A
0:J0D@2VP540Z89C0:V3E02ZQ5D0202XPdh80:V4C`060:YnC@2YOdd0ZX1>0:Z2C`2YQ500Z8A@0P2W
QU420:V4D080Z8=?102WPTh01`2VPDd0ZWi=0:UoC@2YOdd0Z81=0:J1C@2UPDd00P2SPTd80:=nBP80
XWe900@0XGa80:1kA`2PNdL0XGa80P2RODT20:AoB`040:=nBP2RODT0XWe90:5lB080X7]70P2RODH0
1P2RODP0XGa80:5kBP2QNd`0X7Y;0:1jC@80Y7]300@0Y7]50:AkA`2TNdL0Y7Y80P2TNTX20:9mB@80
XGa80`2PNdL00`2ONTH0WGQ409iiA@0209mjAP0409iiA@2MN4@0W7M309]f@P<0WWY60P2ONdL30:1l
B0<0WG];:oooool002[ooooo00<0U6Tl09EZ?@2EJSd00P2FJch309M/?`<0U6Pk0`2EJC`209IZ?@P0
UFTl0P2CIcP209AX>@<0UFTj00@0U6Pi099X=P2CJCL0UF/i0P2GKC/0102FK3X0UF/i09AZ>02CIcX2
09AX>`0509EY?02FJSd0Uf/n09M[?P2HK3l00P2HKS`209M]>`80UV`j0P2EJcT209Y^?@<0VFdl102H
K3/01`2IKC`0Vfln09a`?`2LL3l0Vfln09U]?02HK3/00P2KL3/0102KL3d0VVhm09Y^?`2JKSl209U]
@00409U/@P2LLCh0W74n09aa?P<0Vg0m0P2JKc`309aa?P80WG8o0`2LLCh209eb>`0409eb?@2MLSl0
W74n09a`?`80W711102MLD@409a`@`0309eb?`2NLd00WW=000@0WW=000D0WG8o0:1e@P2PMD80X7E2
0:5f@`020:1e@P80WgA10P2PMD830:5f@`<0XWM4202SN4D20:5f@`80XWM40P2SN4D20:AiAP030:Z1
C@2WOTX0XWU50080WWE100<0WgI20:=jAP2UO4P00`2VNdP30:EjA`80Y7U6202UNTL30:AiAP80XgQ5
0`2TNDH80:=iA`80XGQ40P2PMd<409mf@P80W790102KLCl209Y`?P80UV`j00<0UF/i09=Y=`2BJ3H0
0`2AIcD01P2?JSD0SfXf08iY=@2<ISD0RfDf08US=P80R64f00D0S68j08]Q>@28HCP0QF0f08=N=002
07mL<P0:07eL<@1lFc00NeH/07iI;`21G380Pehd089M<`1nFBl0NUD[07MB:080NULa00H0NEH`07QE
;`1gE2h0MU<]07EB;01dDB/2075A:P80L50Y101_CbP206i@;00606e?:`1/CRX0JddY06U;9`1XBRH0
IdTU0P1ZC2P206U;9`80J4XV0P1WBBD806Q79P0606Y99P1XAb@0IdHS06M68`1XAb@0JTTV0P1[BRL2
06U;9`0306]:9`1]BbP0KTXX0080LDXY00<0LTTY07==:@1cCBT00P1cCBT207A>:P80MDl[00<0M4hW
07E?:01hDR/0101jE2d0301iDb`0PEX_081I;P1oF2d0OUL/07mH;@20FBh0PU/`08=L<@23GC00Q5ha
08IP<`80Qf4d00<0QV0c08AN<@23GC000P25Gc8208IP<`@0Qf4d00<0QF0/08IQ;@26HBd00P27HRh2
08QS;`0308UT<025H3<0QF0c00H0QF0c0P27HC@308IP<`<0QElb00H0Q5ha08EO<P25Gc80QV0c08MQ
=028HSD208US=PP0RUlb2@27HC8@08QR<`0508US=028HS<0R68c08MQ<P26H3400P25Gc000`24GRl0
QEl`08EO<00608EO<00308QR<@27HC00QV0_0080QEl`00/0Qf4b08US=P2:I3L0Q5lb08EP<`26HC@0
Qf8e08IQ=025H3<0Peha089M<00808MS<`0308IQ=025H3<0QF0c00<0Q5lb0P25H3<308MQ=080QV0c
0`25Gc8208AO<P80Peha0P22GC02085L;`80P5/^0`21G2l3089M<008085N=P20GC<0Oe`b07iL;`1n
G2h0Oed]081O;021H2d3085L;`03081K;P1oFRd0OeX]0080OUT/00<0NeH/07aG;@1lEbd00P1mF2h2
07iI;`0307mJ<01mF2/0OEP[00P0OEP[0P1nFB`207mJ;@80P5/^0P1mF2h407iI;`80OEP^201lEbX0
1@1iER`0NUL]07]H;P1lFBl0OEX`0080OU/a0P1oG3801P1iEbT0NELZ07UG:P1hEB/0N5D]07MD;P80
Me<_201cDbX00`1cERh0LE@/06mB:P0306e@:00706iA:@1_DRX0L5<[071C:`1_DRX0KU4Y06e@:002
06a?9`0306]>9P1_DRX0Ke8Z0080KU4Y101]D2P506a@:00806]?9`1ZCRH0JThV06Q<9`1YCBP0JThY
06]?:P1/D2/206eA;00606iB;@1TCRT0I4hY06==:01RC2L0HD/V0P1PBRD00`1OBB@0HDLV06579P06
06579P0605m9801OBB80GTPS05e78P1MAR@0G4DU0P1KA2D00`1H@bH0Ed8U05E08`0205<n8@0305E0
8`1G@RD0F4<V0080F4@S00<0Ed<R05I28@1E@B000P1D@1l00`1C?ah0E3lR05<n8@0205<n8@80DSdP
0P1A?1l205@o8P@0ED0S0P1D?b8205I19080Ed8U101H@bH2050o9@030550901A@280DD4P0080DT8P
00H0DT8N05Po801H?b00Ed0P05E1801D@B02059280030553801B?al0DSlO00H0DSlO00<0FT<T05U2
8`1H@B800P1G@2400`1H@B80FT<T05]49@0605Y38`<0FD8R0`1G@1h205Q17`<0FD8P0`1KAb@205a8
9@<0GDTV0P1NAbD605e6900;05i88`1OBB@0H4XU065;9P1SCBP0I4hY06E?:P1VD2/0G4HQ05e78P1P
BRD00P1QBbH00`1PBRD0GDLR05a68@0806168`80GdTT0`1NB2<305e78PP0GDHT201OB2H0201LAR40
GDLR061:9@1RC2L0HddX069<9`1PBRD0GdTT0`1RC2L206==:0<0I4hY0P1UC2@00`1VCBD0IdhV06Q?
9`0206U@:00706YA:@1]CbT0KE0X06iA:@1^DBL0Ke8V071D9@02075E9@0307EF:P1fEb/0MUL[00D0
MeP/0P1jFS<01P1kFc80Ne``07aM;`1mGRl0OEl]07iP;P80QF0c0P26HC@208MR=@80R6<f00@0Qf<a
08UU<`2;IcD0SFTg0P2>JSP0102=JCL0S6Pf095[?02AJc`2099/?@80Tfdn0P2DKSl309E`?0<0UW4m
0`2GLSh309Ye@080VgI10`2LMd880:5mB@80Y7m:0`2UP4/30:J1C080Yh9>00@0Z8=?0:V4D02ZQE40
ZXEA0P2[QU830:b8E080[HUE0`2^RUH30:j:F0<0[XYJ0P2^RE`20;2:F`80/H]L0P2bS5d20;>=GP03
0;F@G02dSe/0/XeI0080/HaH00@0/XeI0;B?F`2eT5`0/8aL0P2aSEd01@2bSUh0/HeM0;2<G02_Re/0
[XYJ00P0/XeI1P2aS5P20;:=F@0@0;6<F02`ReL0[hYF0:j9E@2_RUH0/8]G0;:=F@2dSe/0/hiJ0;:=
F@2`ReL0[hYF0:j9E@2_RUH0/8]G0;6<F080/XaM0P2aRe`20;2:F`X0[hUJ202aReX80:n:EP050:n<
EP2_ReL0[h]G0:j:EP2^RUP00`2]REL20;:<G@80/H]L00<0/8YK0:j8F@2]QeP00P2/QUL80:n:EP08
0:n9G02`RU/0/H]L0;:<F`2bSET0/HaG0:n:D`2^RE880:b7D`030:^5EP2/QUL0[XQI0080/8YK00<0
[hUJ0:j8F@2]QeP00P2_RUH30:j9E@<0[HQD0P2[QU840:b7D`80[HQD0P2_REP30:j8E`<0[HMF202]
R5@30:Z5D@030:^6DP2/Qe<0[8MC0080[HQD102_QE<40;26E0P0[HQD00T0[8MC0:f8E02^RED0[hYF
0:j9E@2]R5@0ZhIB0:Z5D@2]R5@00P2/Qe<20:^6DP80ZXEA00<0ZHA@0:^6DP2[QU800`2/Qe<30:f8
E0P0ZhIB00<0[8MB0:f8D`2]R5<00P2]R5<30:b7DPP0ZhIA0P2/Qe<60:^6DPT0[8MC00<0[HQD0:b7
D`2[QU800P2YQ5000`2[QU80[8MC0:f8E0080:^6D@<0[8MC0`2[QU820:Z5D@<0[XEA0`2]Q5020:b3
C`80[H=A00H0[hEC0;26E02`QU@0[hEC0:j4DP2]Pe420:f8E0@0[8MC0P2]R5@00`2_REX0[XQI0:b6
E`020:^5EP030:b6E`2]QeP0[XQI00P0[HMH0P2[QU820:b7D`80[HQD0P2^RED20:V4D0030:Z5D@2[
QU80[8MC0080[HQD00<0[XUE0:b7D`2/Qe<01P2/Qe<30:V4C`80ZXE@0`2[QU420:f4D0<0[XEA0`2_
QU880:f4D0P0[8MB0`2/Qe<30:f8E080[XUE0P2]R5400`2]R5<0[HQD0:f7EP020:f7F0030:f7FP2/
Qe<0[8MC00H0[8MC1`2/Qe820:f8D`@0[HQD0P2^RED20:n:EP80[8MC00@0[HQD0:j9E@2^RED0[hYF
0P2`ReL00`2_QU80[XEA0:j5D@020:f4D080[8=?00L0Zh9>0:j3C02]Q4`0[HA>0:f5D@2[QU40ZhMC
0080ZHQE00<0[HQD0:b7D`2/Qe<00P2[QU820:Z5D@030:V4D02[QU40ZhIA00H0ZhIA202^QE420:Z5
D@80ZhIB0P2/Qe<20:f8E0060:b6F@2/QUL0[8IG0:^5E02[QU80ZhIA0P2ZQDh@0:^6DPP0ZXEA202Y
Q4l00`2ZQE40ZhIB0:^6DP030:b7D`80ZhIB0P2ZQE020:V4C`040:R3CP2WPTd0YX5<0:J1C080Z8=>
00H0ZHA?0:^6D@2/Qe80[HQC0:j9E02_RUD30:b7DP@0ZhIA00@0ZXE@0:f3D@2_QE<0/8ID0P2bR5H0
0`2`QU@0[hEC0:f3D@020:Z5CP030:Z5D02[QU80ZhED00<0[8IG00<0[8II0:b7D`2/Qe<00P2/Qe<4
0:f8E0<0ZhIB0P2/Qe<30:^6DP@0[8MC0P2[QU820:Z5D@80ZXE>00<0ZXE@0:Z5D@2ZQ5<00P2ZQ5D0
1`2ZQ5L0[HQC0:f8E02]R5@0[HMF0:f7F02]QeX00P2]QU/:0:^6DP@0ZXEA0P2YQ5080:Z5D@030:V3
E02[QEH0[hUJ0080/H]L00<0[XQI0:V3E02VP5400P2XPdl0102YQ500ZXEA0:Z5D@2[QU820:b7D`<0
ZHA@0P2XPdl30:V4D0<0[8=?0`2[PTh20:Z1C@040:Z4D`2[QE@0ZhED0:^5E080[8IE0P2]QeH20:Z4
E@<0ZH=D0`2XPU<30:J0D@050:EoD02VP540YX1A0:J0D@2WPE800`2WPTd40:R3CPT0ZHA?00H0ZWi=
0:UoC@2ZP4h0ZH5>0:R3C`2XQ5020:J5D0@0ZHA@0P2XPdl30:N2CP060:YnC@2YOdd0ZGm=0:R0C@2V
PDd0YH5=0P2SPTd40:AoB`@0Xgi:202RODT0202UP4`0Y7m;0:=nBP2RODT0XGa80:1kA`2ONTH0WWU5
0P2RODH00`2QO4L0XGa80:5kBP020:5kC0040:5kCP2VODD0YWe50:ImA`80YWe900<0YWa:0:IlC02V
O4`00`2QO4P30:1kA`80WgY600<0WGQ409iiA@2NNDD00P2MN4@209ag@`0409]f@P2NNTH0WWY609ij
AP80Wg]70`2PO4P309ijBR_ooooo000Zooooo`@0UFXm0P2FJch209M/?`80U6Pk0`2EJC`309IZ?@P0
UFTl0`2BIST209=W>P0;09AX>`2EJC`0UVXm099X=P2DJSP0UV`j09M]>`2HKS`0Ufdk09I/>P2EJcT0
0P2DJ3/209EY?00409IZ?@2GJch0V6`o09Q/?`80V6hl0P2GKC/209I/>P80UF/i0P2JKSd309U]?0<0
V6`k0P2IKC`409]_?P80VFdl0P2KL3/0102KL3d0VVhm09Y^?`2JKSl209U]@00409U/@P2LLCh0W74n
09aa?P<0Vg0m0P2JKc`309eb?`80W74n0`2MLSl209aa>P0409aa?02LLCh0WG8o09ea@080WG520P2N
LTD209eaA080W7130P2KKd8309ic@080WG8o0`2NLd000`2QMT<0X7E20:1e@P020:1e@PH0XGI30`2R
Md@:0:=hA@<0XWM40P2SN4D30:AiAP080:Z1C@2WOTX0XgY609mf@P2NMD40X7M30:=jAP2VODT30:Ik
B0<0YGY70P2TNDH80:IkB0<0Y7U60P2UNTL30:AiAPP0XgU70P2PMd<309mf@P<0WWE10P2KLCl209Y`
?P80VFlm0P2HKS`309AZ>00309=Y=`2BJ3H0TFLe0080T6Hd00d0SVTd08eX=02<Ic<0RfDd08US=028
HSD0Qf0e08IO=02;HCT0RV0h08MP=`24GcD0PUdc0080OU/a00X0O5/`07]J;`1jEB/0OEP^081K<@22
GC<0PE`b07eH;P1iE2X0MU4W0P1gE2h207IC;@0407EB;01dDB/0M54[07=@:P80L50Z0`1_CbT306i>
:080KU0/00<0K4hZ06]=:@1YBbL00P1XBRH0101WBBD0JD/W06U;9`1YBbL206Q:9P<0IdTU101WARD4
06Q79P80JDPU00H0J4LT06M68`1WAR<0J4LT06]:9`1]C2T206a;:00606i<:@1_BbT0LT/Z079;:P1c
BRX0MT/[0P1dCRT207E?:P@0MU0[00@0ME0V07MB:01iE2X0NeH/0P1lEbd03@1kER`0NUD[08AK;`23
FRh0PUT]085H;022FBd0PeX^08EL<026GC40Ped`08EO<P26H3<00P27HC@00`26H3<0QElb08=M<002
08EO<P80QV0c1027HC@208IQ;@@0Qf8^0P28Hbl808EP<`80Qf4d0`26H3<308EO<P0608YT=`29HcH0
RF<f08QR=@27HC@0QV0c0P25Gc8808YO<PT0Qf4b2028HS<208YQ<`@0Rf8d0P2:HC<01@29Hc@0R68c
08QR<`27HC80QV0a0080QEl`00<0Q5h_08EO<025Gc001P25Gc000`28HSD0Qf4d08IP<@0208EO<00;
08MQ<029Hc80RV@c08AO<P25H3<0QV4d08MR=@26HC@0QF0c08=N<@22GC002026HS8208AO<PH0QF0c
0P27HC@208IP<`80QElb0P24GS4308=N<@80PUd`0`21G2l3081K;P<0PE`_0P22GC002@21GSH0P5dc
07iK<@1mFbh0OE/]07iL;020Gb`0PF0]085L;`04081K;P<0OeX]101lEbd407eH;PP0O5LZ0P1mF2`2
07iI;@80OeX^0P20Fbl807eH;PP0O5L[0P1iF2d207YI;P0307]J;`1lFc00O5/`0080O5/`00H0N5HX
07QF:@1hERT0Me@Z07MD;01fDbd207IB;PP0Le<Z00@0LeH^075D;01_DRX0KE0X0P1/CbL206e@:080
Ke8Z00@0KU4Y06e@:01/CbL0K4lW0P1[CRH206iA:@<0KE0X0`1/CbL206YA:00306U@9`1XCbH0J4lV
00<0J4lV0P1VC2L206M=:00406Q>:@1YCbX0JDlZ06U?:P80H4`W00<0Gd/V05i:9@1MBB@00P1LB2<0
0`1KAb80GdHW05m69`0205m69`@0GTDV00H0GDLP05e78P1LAR40Fd@R05Y38`1I@R<205Q0900305A0
9@1C?b@0DShS0080DCdR00<0DShS05<o901D@2D00P1E@R80101D@B40Dd0P058o7`1B?al2054n7P<0
DCdR0P1@?24304lk8080DShS101A?B82058n8`<0E40U0P1E@BH305I29`80CcdU00H0CchT050o8`1@
?b40D40O0551801A@Al205Ho800605@o801C@200DD4P0551801@@B00Cd8P201A?Qh0201I@R<0F44R
05M08@1F?b00EChO05Ho801H@B80FD8S0`1F@B8605M28`<0ESlM0P1G@1h305Q17`<0FDHU0P1JAbH3
05]89`80FTHS1P1KAb@205i88`0305m9901PBRD0HD/V0080HddX00@0I4hY05]5801MAb80GdTT0P1Q
BbH00`1OBB@0GDLR05]5800805i68P80GdTT0P1NB2<205e78P80G4HQ201MAR@805m89P0305U5801K
Ab80GTXU0080HDdX00<0Gd/V05e9901KAb800`1QBbH2069<9`<0HddX00H0HTXT06=;9@1SBbD0I4`V
06E=9`1VCRP206M?:@0606a>:P1/CRP0KDlY06iA:@1_DRP0Ke8V0P1`E2D307=C:P80M5@[00<0MED/
07IF;@1gEbh00P1hF3401P1iFC00NU/_07]L;P1lGBh0OEl]07iP;P@0QF0c1026HC@01026HS80R6@d
08YV=P2<J3P208eY>@0308aX>02;IcL0UFm000<0UFm0102FL44409E`?0<0UW4m0P2GLSh309Ye@080
VgI10`2LMd830:1lB0D0XGe90`2TOdX30:F0B`80YX5<00H0YH1<0:J1C@2WPTh0Z8=?0:V4D02ZQE42
0:^6DP80ZhMC0P2/R5@20:f9E@80[XYF0P2^RE`30:j:FP<0[XYH0P2`RU/20;6;G080/XaM0P2cSEh0
0`2dSe/0/hiJ0;:=F@020;6<F0060;:=F@2cSUX0]8mK0;2<G02aSEd0/XiN0P2cSel00`2aSEd0[h]K
0:f9F@0>0;:=F@<0/HaH00d0/8]G0:n:EP2^RED0[XUE0;2;E`2bSET0/hiJ0;B?F`2bSET0/8]G0:n:
EP2^RED0[hYF0080/8]G0`2aRe`20;2:F`/0[hUJ202`ReL80:n:EP<0[h]I00D0[XYH0:j:EP2]RED0
[HUE0:f:E0020;:<G@80/H]L00<0/8YK0:j8F@2]QeP00P2/QUL80:n:EP080:j8F`2_REX0/H]L0;:<
F`2bSET0/HaG0;2;E02_RU<80:f8E0080:Z4E@2/QUL0[XQI0:n9FP2`RU/0[hUJ0:j8F@2]QeP20:n:
EP<0[XUE0`2]R5@00`2ZQE40ZhIB0:^6DP020:b7D`80[HQD00<0[XUE0:n9FP2_REX00`2^R5T30:f7
F0P0[8MC00<0ZXEA0:^6DP2[QU800P2[QU830:b7D`@0/8ID102_QE<80:f8E0080:b7D`2]R5@0[XUE
0:n:EP2^RED0[HQD0:^6DP2ZQE440:^6DP@0ZXEA0`2/Qe<30:f8E080[XUE202[QU800`2]R5<0[8MB
0:b7DP020:b7DP<0[HQC202/Qe860:^6DP80[8MC2P2]R5@01`2/Qe<0ZhIB0:V4D02YQ500ZhIB0:b7
D`2]R5@0202[QU430:b7D`<0ZhIB0P2ZQE420:j5D@<0[HA@0`2/Pdl0202/PU00[XAB0:n5D`2aQeD0
/8ID0:n5D`2]Pe40[89@0P2/Qe<40:f8E080[8MC00<0[XQI0:f7F02/QUL00P2[QEH00`2/QUL0[XQI
0:n9FP080:f7F080ZhIB0P2/Qe<20:f8E080[XUE00@0ZHA@0:Z5D@2ZQE40ZhIB0P2/Qe<20:f8E0P0
ZhIB0`2YQ4l20:Z5D0<0ZhIA0P2]Q5030:j5D@<0[hIB202]Q5080:^6D@80ZhIB0`2/Qe<30:f8E080
[HQA00<0[HQC0:f8E02]QeH00P2]QeP00`2]QeX0[HQD0:f8E0060:f8E0L0[HQC0P2/Qe800`2/Qe<0
[HQD0:f8E0020:j9E@<0[hYF00D0ZhIB0:b7D`2/Qe<0[HQD0:j9E@020:n:EP030;2;E`2^QE40[XEA
00@0[HA@0P2/Pdl01P2^Pd`0[HA<0:j5C`2]QE40[8MB0:^7D`80ZXUF102/Qe<40:^6DPP0ZhIA202^
QE430:Z5D@80ZhIB0`2/Qe<01P2/QUT0[8IG0:b6E`2[QE@0ZhIB0:^6D@80ZXE>202[QU880:b7D`P0
ZXEA202ZQE020:b7D`H0ZhIB0P2ZQE020:V4C`040:R3CP2WPTd0YX5<0:J1C080Z8=>00H0ZHA?0:^6
D@2/Qe80[HQC0:j9E02_RUD20:f8D`80[8MB00L0ZhIA0:Z5D02ZQE00ZXE@0:j4DP2_QE<0/8ID0080
/HME00<0/8ID0:n5D`2^Q5800P2ZQDh00`2[QU40ZhIB0:b6E@020:b6E`030:f7F02]QeX0[HQD00<0
[HQD1@2/Qe<60:^6DP040:b7D`2]R5@0[8MC0:b7D`80ZhIB0`2ZQE420:Z5CP030:Z5D02ZQE40ZXAC
0080ZXAE00L0ZXAG0:f8D`2]R5@0[HQD0:f7EP2]QeP0[HMJ0080[HIK202[QE@00`2/Qe<0ZhIB0:^6
DP020:Z5D@80ZHA@00<0Z8=?0:Z5D@2ZQE401P2ZQE40202YPe@0[8IG0:n9FP2bS5d0/H]L0:j8F@2Z
Q5D0Yh5B0P2XPdl0102YQ500ZXEA0:Z5D@2[QU820:b7D`030:R3C`2YQ500ZHA@00@0ZHA@00@0Z8=?
0:b3C`2/Pdl0[8=?0`2[PTh20:Z1C@<0ZhEF0P2/QUL30:f7F080ZXAE0`2YPe@30:R2D`030:EoD02V
P540YX1A0080YX1A0`2UOe030:J1C0030:N2C@2XPdh0Z8=>00X0ZHA?00H0ZWi=0:Z0CP2ZP4h0ZH5>
0:N2CP2WPdl20:F4C`<0ZHA@0P2XPdl40:N2CP060:]oCP2ZP4h0ZX1>0:V1CP2WPTh0YX9>0P2TPdh0
0`2VPDd0YH1<0:F0C0020:AoB`80Xgi:00<0XWe90:=nBP2SOTX01P2SOTX20:AoB`040:=nBP2RODT0
X7]709mjAP80WWU50P2QO4D01P2QO4L0XGa80:5kBP2QNd`0XWa=0:9lC`80YWe500@0YWe70:ImB@2V
ODT0YWa:0P2VO4`20:5lB0<0X7]7102ONTH209iiA@0309ehA02LMd<0W7M30080W7M30`2NNTH209mk
A`<0X7a80`2ONd/[ooooo`00:_ooool02@2EJSd0U6Tl09AY?02CJ3/0U6Tl09EZ?@2FJch0Uf`o09AX
>`0309EY?080UVXm0P2GJch809IZ?@80TVDk0P2AI3X03@2BIC/0U6Lm09IY?`2GJT00TfTg09AZ>02F
K3X0Ufdk09Q^?02GKC/0UV`j09E[>@2FJSd00`2GJch409Q/?`80V6hl0P2GKC/209I/>P80UF/i0P2J
KSd309U]?0<0V6`k00<0VFdl09Y^?@2JKSd00P2KKch209Y^?@0509U]?02KL3/0Vg0k09]`?@2JKSd0
0P2JKSl209U]@00309U/@P2KL3d0Vg0m00D0Vg0m00@0W74n09ic@02NLd00WG8o0P2LLCh0302MLSl0
WW=009ic@02KL3T0W74j09aa?02LLCh0WG8o09ea@02MLD80WW9309mcAP80WW9500P0WG5409a`@`2K
Kd80Vfm209Y^@@2OM440WW=009eb?`80W74n00<0WG8o09ic@02OM4400P2QMT<01P2PMD80WgA10:1e
@P2QMT<0XWM40:=hA@<0XGI30P2RMd@;0:=hA@80XWM40P2SN4D30:AiAP090:EjA`2XOd/0YWe90:=j
AP2QN4@0X7M30:9iA@2TNdL0YWe900<0YW]80`2UNTL20:AiAPP0Yga700<0XgQ50:AiAP2UNTL00P2V
NdP00`2UNTL0Y7U60:=hA@080:=iA`<0WgI20P2NMD4309ed@080VW0n0P2IKcd01P2HKS`0Ufdk09I/
>P2FK3X0TFLe099X=P80TfTg0140TVPf095W=@2@IS@0SfDc08aW<P2<Ic<0RfHb08US<P28HS<0Qf4d
08IO=025GS<0RElg08QN=P25GSD0Pehd085L<P0207iK<@80O5/`00P0NeH/07eH;P1oFS00OeX`07iI
;`1lEbd0NE@Z07IA9`80ME8/0P1dDB/207=@:P80LTlY0`1_CR/206i=:P<0KD`Y00@0KDl[06a>:P1[
CBT0JD/W0P1XBRH406U;9`80J4XV0`1WBBD0101VB2@0ITDT06I5901VAB@206M69@<0J4LV00P0JDPU
06Y99P1YB2D0IdHS06E48@1VAB80JdXW06m>:`80KddZ00@0L4`Z07=<:`1cC2/0MD`/0P1gC2`00`1e
CRL0MTlX07M@:@0307UB:`80N54Z00@0NE8Y07YC:P1lEB`0OUL^0P1oF2l207iG;P0;08IK;P25FRd0
Q5T/08=H:`24FB`0QEX]08ML;`28GC00Ped`08AN<@25Gc800P26H3<00`25Gc80Q5ha08=M<00208AN
<@<0QElb0`26H3<808MR;PP0QF0c00<0QElb08IP<`26H3<01@26H3<01P2<IST0RfDh08YT=`28HSD0
Qf4d08EO<P80Q5ha202:Gc8908MQ<PP0R68c0P2;H3<0102<HC@0SF8e08eR=@2<HC@208]P<`@0R68c
1027HC8808IP<@0@08QQ=P27H3D0QV0c08EO<025Gbh0Qf8^08UT<02:IC00Q5lb08EP<`26HC@0Qf8e
08IQ=025H3<0Peha089M<0P0QF4a00<0PUd`08=N<@25H3<00`26HC@208EP<`<0QV0c0P25Gc8308AN
<@80Peha0P22GC03085L;`03081K;P1mFbd0OE/]0080OU`^0`1oGBl02@20GS00PEhf081M<`1mFS00
NeT/07]I:`1mFb/0P5l/085P;@08081K;PP0OEP^201mF2/207eH;P80OUT_0P1oFS02081K<@0307iI
;`1mF2h0O5L]0080NeH/00<0O5L]07eH;P1nFBl0201kER`907QI;@0607ME9`1gEBP0MeDX07IC:@1f
Db/0ME8/0P1eDBd8079B:@0407=F;P1bEBd0Ke8Z06e@:080JdhV0P1/CbL206e@:0<0K4lW0`1[CRH3
06e@:080K4lW0`1[CRH0101YDRP0J54W06M@9P1VCbD206E>900306I?9@1WD2H0I4`V00L0I4`V0P1M
BbL0101LBRH0FdTU05]99@1JB2@205U78`<0GDHW0`1LABH205]49@0605a68@1KA280FT<Q05U28P1H
@B80EShR0P1E?B<00`1@?bD0CchT04ln900204hm8`80CchT00@0D3lU050o8@1@?b40D3lQ0P1??R03
04hm7`80CchT0P1>?B<304dl8P0404`k8@1??R@0CSdS04dl8P80C3/Q00<0CC`R04hm8`1??R@00P1?
?R@2050o9@<0DD0V00T0DT4W04`l9@1<?2D0CCdT04dm8`1>?b80CSlP04ho7P1?@1l00P1C?R40101B
?b40D3lQ050o8@1?@24204i18@P0DSlO00<0FD8S05Q18P1F?b000P1D?Ah00`1E?Ql0ESlP05M08@04
05A18`<0ED8T0P1F@bD305Ho7@80Ed0N0`1H@Al305E59080ETHU0`1GAbH205Q68P80FDLS101JB2@3
05i88`<0GdTT0P1PBRD00`1LAR40GDLR05i88`0205m9900305i88`1MAb80G4HQ00P0GTPS0P1PBRD2
05m9900405i88`1MAb80G4HQ05a68@<0G4DS0P1MAR@;05i79@0305U78@1KBB<0GD/U0080GT`V00<0
GD/U05]98`1IAb400`1OBB@2061:9@<0HD/V0P1PBRD00`1QBbH0HT`W06==:00206A>:@0:06E?:P1[
CB/0JddY06a>:P1]CbT0KU4Y06mB:01_DRH0L5<W079B:`<0LE4Z00X0LU8[07AD;@1eEBh0MUH_07MG
<01hF340NET`07YK;`1lGBl0OEh_0P1nH2h00`22H380Pf4c08=Q<`0608=Q<`0308ES=@27ICL0RFLi
0080RVPj00<0RFLi08QV>02EKd00102EKd0309I`@@<0U6lk0P2EL3`309Ia?@0409Mb?P2JMD00VWE0
09Ye@080VgI10`2LMd8309ijAP80Wg]70P2PO4P00`2QODT0Xgi90:=nB@020:AoBP<0YH1;00T0YX5<
0:AoB`2TOd/0YH1<0:N2CP2XPdl0ZHA@0:Z5D@2[QU800`2[Qe<20:b8E0<0[HUE0P2/RUd00`2/RU`0
[8YJ0:b;F0020:b;EP030:b;E@2`RU/0/8YK0080/H]L0P2bS5d20;>=GP030;B?F`2cSUX0/HaH0080
/8]G00H0/HaH0;>>FP2dSe/0[h]K0;6=G@2cSel20;B@H0030;:>GP2_Re/0[HUI00T0/XeI0P2cSUX0
102dSe/0/hiJ0;:=F@2aS5P20;2;E`0;0:n:EP2^RED0[XUE0:j9E@2`ReL0/HaH0;>>FP2dSe/0/hiJ
0;6<F02_RUH00P2^RED0102_RUH0/8]G0;6;G02aRe`20;2:F`<0[hUJ00<0[XQI0:n9FP2_REX01P2_
REX80;2;EPP0/8]G0P2_RUd0102_Re/0[XYH0:j:EP2]RU@20:f:DP80/H]L0P2`RU/20:n9FP030:j8
F@2]QeP0[HMH00P0[hYF00P0[XQK0:n9FP2aRe`0/heL0;>>FP2bSEP0/HaE0;2;E0P0[HQD00<0ZXAE
0:^5EP2]QeP00P2_REX00`2^R5T0[HMH0:b6E`020:n:EP<0[XUE0`2]R5@20:^6DP040:b7D`2]R5@0
[HQD0:j9E@80[hYF0P2_RE`30:j8F`<0[HMJ202/Qe<80:^6DP040;67E@2`QU@0/8ID0;26E0<0[hEC
00<0[XAB0:f8E02]R5@01P2]R5@00`2ZQE40[8MC0:f8E0020:j9E@030:f8E02/Qe<0ZhIB00P0ZhIB
0`2/Qe<20:f8E0<0[XUE202[QU800`2]R5<0[8MB0:^6D@020:^6D@030:f8D`2^RE@0[hYE00P0[8MB
0P2ZQE430:^6DP<0[8MC2P2]R5@01`2/Qe<0ZhIB0:V4D02YQ500ZhIB0:b7D`2]R5@0202[QU430:b7
D`<0ZhIB0P2ZQE40102^QDl0[HA>0:f4CP2]Q4h20:b3C@80Zh9<00/0[89@0:j4DP2`QU@0/XQF0;67
E@2_QE<0[89@0:Z0CP2[QU80[8MC0:f8E0020:j9E@0;0:f8E02/Qe<0ZhIB0:f7F02/QUL0ZhEF0:Z4
E@2[QEH0[8IG0:j8F@2_REX0202]QeP20:^6DP80[8MC0P2]R5@20:j9EA00ZhIB0`2YQ4l20:Z5D0<0
ZhIA0P2]Q5030:j5D@<0[hIB202/Pdl80:^6D@<0ZhIB0P2/Qe<30:f8E080[HQA00<0[HQC0:f8E02]
QeH00P2]QeP00`2]QeX0[HQD0:f8E0060:f8E0<0[XUD102]R5<20:b7DP030:^6DP2/Qe<0[XUE00<0
[hYF0P2^RED20:b7D`<0[HQD0`2^RED80:f4D0060:n4C@2^QDd0[XE?0:j6DP2/Qe80[8QD0P2ZREH8
0:b7D`P0ZhIA202^QE40102YQ500ZXEA0:Z5D@2ZQE420:^6DP80[8MC00H0[8II0:b6E`2/QUL0ZhED
0:^6DP2[QU420:Z5CPP0ZhIB202/Qe<80:Z5D@P0ZhIB00<0[XUE0:f8E02[QU800`2ZQE420:^6DP<0
ZXE@0`2YQ4l20:R3CP80ZHA?00@0ZXE@0:^6D@2/Qe80[8MB0P2]R5<01P2^RE@0[HQC0:f8D`2/Qe80
ZhIA0:Z5D080ZHA?0P2_QE<40;26E080[hEC0P2[QTl00`2[QU40[8MC0:b6E@030:f7F0030:f7FP2^
RED0[HQD0080[HQD0`2/Qe<0102[QU80[HQD0:b7D`2[QU820:Z5D@060:^6DP2/Qe<0[HQD0:j9E@2]
R5@0ZhIB0`2ZQE420:^6DP80ZhI?00<0ZhIA0:^6DP2[QE@00P2[QEH01`2[QEP0[HQC0:f8E02]R5@0
[HMF0:f7F02]QeX00P2]QU/80:^5EP80[8MC00@0ZhIB0:Z5D@2ZQE40ZHA@0P2XPdl80:Z5D@030:^5
EP2]QeP0[hUJ0080/8YK00<0[XQI0:^5EP2YPe@00`2YQ5020:Z5D@<0ZhIB00<0Yh9>0:R3C`2YQ500
0P2ZQE400`2YQ500Z8=?0:N2CP030:f4D0<0[8=?0P2[PTh20:Z4E`80ZhEH0`2/QUT00`2]QeX0ZXAE
0:Z4E@030:V3E0<0Z89C0P2VP5401P2WPE80Z89C0:N1DP2VP540YGm@0:AnC`80YH1;0P2VPD`00`2W
PTd0Z8=>0:V4C`090:V4C`060:]oCP2ZP4h0ZX1>0:V1CP2WPTh0YX9>0P2TPdh0102XPdl0Yh9>0:N2
CP2WPTh20:J1C@<0YH1<00H0Zgm>0:Z0CP2ZP4h0ZH5>0:N2CP2VPTh20:B3CP060:N2CP2VPDd0YX5=
0:F0C02TOd/0Xgi:0P2RODT20:=nBP040:AoB`2UP4`0YH1<0:AoB`<0Xgi:0P2RODT01@2QO4P0X7]7
09mjAP2ONTH0WWU50080X7]400<0XGa70:5lB02QNdX00P2RO4d0102RO4l0YWe50:ImA@2VODL20:Im
B@040:IlBP2VO4`0YWa<0:5lB0<0X7]70P2ONTH209iiA@040:5lB02PNdL0WgY609iiA@80WGQ400<0
WWU509mjAP2NNTH00P2NNTH209mkA`<0X7a80`2QNd`[ooooo`00:_ooool0202DJC`0TfPk099W>P2A
IST0TVLj09=X>`2EJSd0UV/n0`2EJC`209IZ?@<0Uf/n202FJSd02`2BIC`0TF@k091S>P2@HcX0TF@k
09AW?P2FJD00UfY109=Y=`2EJcT0UV`j00<0V6hl00<0Ufdk09I/>P2JKT400P2JKT4309U]@080V6`o
0P2HKS`209M]>`80UV`j0P2EJcT209Y^?@<0VFdl0`2HK3/809Y^?@80Vg0k00@0Vg0m09Y^?@2JKSl0
VVho0P2IKD001@2IK480VFhk09U^>`2JKc`0Vg0m0080W74n0P2MLSl00`2OM440WW=009eb?`0209aa
?P0309eb?`2NLd00WgA10080Vg0i00@0W74l09aa?P2MLSl0WG500P2NLT<209mcAP0409ibA@2MLD@0
W71309]_@P80VVi100<0X7E209md@@2MLSl00P2LLCh0302MLSl0WgA10:1e@P2RMd@0XGI30:1e@P2O
M440X7E20:5f@`2SN4D0YGY70:5f@`<0XWM40P2SN4D:0:AiAP<0XgQ50`2TNDH20:EjA`040:AkA`2S
NTH0XgY60:=jAP80Y7]700<0YGa80:ImB@2VNdP00P2VNdP30:EjA`80Y7U6202WO4D00`2SN4D0Y7U6
0:IkB0020:MlB@030:IkB02TNDH0XgQ500P0XgU70`2NMD4209ed@0<0W7<o0P2JL3h05P2IKcd0V6hl
09M]>`2FK3X0UF/i09AZ>02@IS@0TFLe099X=P2CJCL0TVPf095W=@2?IC<0SV@b08]V<@2;IS80RVDa
08QR<@27HC80QV0c08EN<`24GC8208IL=00308=L<`22GC<0PE`b0080Oe`b0P1mG34307eH;P0507aG
;@1kER`0NUD[07UD:P1hDbT00`1cD2X3079?:@80LDhX0`1^CBX206e<:@<0K4/X00<0K4hZ06]=:@1Y
BbL00P1XBRH00`1YBbL0JT`X06]=:@0306Q:9P<0IdTU0P1VB2@206E48`80ITDT00D0IdHU06Q79P1X
AbH0J4LV06U89@0206Y99P0606M68`1T@b00ID@Q06]:9`1aD2d0L4h[0P1aCB/00`1dCB`0MD`/07Q=
;@0207U<;@0<07M=9@1iCbL0Ne4Y07aB:P1mDb/0O58Z07]A:@1jD2P0OE<Y07mE:`21Ebd0PeT_0P24
FS001023FBl0PUP^08IL;026G2`308AJ:P0608IL;028GRh0REl_089L;`23GC00Q5ha0P25Gc800`24
GS40Ped`089L;`0308=M<0<0Q5ha0P25Gc8808MR;PP0QF0c0P24GS4208EO<P0408IP<`27HC@0R68e
08QR=@80RF<f1028HSD208MQ=0P0RUlb2@27HC8808QR<`0308YO<P2;H3<0SF8e0080SV<f00<0SF8e
08]P<`2:Gc800`28HS<208US=0<0RV@e2028HS<04028HCX0Qf0g08IO=025Gc80QEl^08MR;P29I2d0
RVD^08AO<P25H3<0QV4d08MR=@26HC@0QF0c08=N<@22GC0808=O;`08085L;`23GS40QF0c08IQ=027
HSD0QV4d08EP<`24Gc8208IP<`80QElb1024GS43089M<0<0PE`_0P20Fbh307aL;@80OEd^0`1nGRl0
2022GcL0P5dc07aI;`1jF2/0NUPZ07aJ:P20Gb`0PV4^0P1oFRd6081K;P80OeX`1P1nFBl807iI;080
OEP^0P1nFBl207mJ<080P5/a00<0OUT_07eH;P1kER`00P1jEB/00`1kER`0OEP^07iI;`0807]F;006
07UJ;P1hFBd0N5T]07MH;01fEb/0MEHZ0`1dEBT01P1gEBL0MU@W07ID9`1fDbT0ME8Z07EB;080M50/
201bDRT01P1cERh0LUD]06mB:P1/CbL0JdhV06Y=9@80JdhV0P1ZCBD306]>9PH0K4lW0P1[CRH306Y=
9@0306QC:01WDRL0IE0U00<0HdhS00P0IE0U06IA9P1SCBH0HddV069<9@1QBb@0H4XS05m98P80GTPQ
0P1LBBP00`1KB2L0FTLV05U69@0205Q5900405M48`1KARL0FdHW05Y59P80FD@U0`1H@b@0201KA280
FT<Q05U28P1G@240EShR05@l8P1C>b40Dc/S201=?B<404`m80<0CChQ00@0CSlR04hn901>?R@0CShT
0P1=?B<304`l8P0304dm8`1<?280Bc/Q0080BCTO00<0Bc/Q04`l8P1=?B<00`1<?28204dm8`<0CShT
00T0BS/V04Xk901;?2D0BcdS04`n8`1<?R40C3lO04e0801B?B800P1A?B800`1??R80CSlR04do8P02
04]08PP0DSlO00<0F44R05M08@1E?Ql00`1C?1d00`1D?Ah0EChO05<o900305<o900305A09@1E@BH0
ED4V0080ET8W0`1G@1h205Q17`<0FD8P0`1B@b8205=48`<0E4DT00<0EdDQ05Q68P1HAR800P1IAb<2
05Y8900305]99@1NB2<0GTPS0080GDLR0`1LAR40101KAB00GTPS05i88`1MAb8205a68@0305e78P1N
B2<0GTPS00P0GDTT0P1RC2L01`1QBbH0H4XU05m9901NB2<0GDLR05a68@1KA2800P1LAB<205e69080
GTLU00<0GdPV05e6901MAR@01P1MAR@00`1KBB<0G4XT05a:900305a:900305]98`1JB280GDLR0080
GDLR0P1NB2<305m99080GDTV00<0GTXW05m;:01PC2T00P1QCBX02@1RCR/0JT`Z06Y<:P1[CBT0K4hX
06e@:01^DBT0KU4W06mB:002071@:P80KdlY00@0L50Z079B;01eEBl0MUH`0P1hF3401P1iFC00Ne``
07aM;`1nGc00Of4_081R<0P0PF4b00@0PV4d08=R=@25I3L0QfHi0P28IcX208MV>@03099/?@2AJc`0
TF/l00D0TF/l102DKc/209E`?0<0UW4m0`2JMD0209]f@@<0W7M20P2JMT801P2KMd<0WGU509ijAP2O
NdL0X7a80:5mB@<0Xgi90P2TOdX30:F0B`80Xgi:00H0Y7m;0:J1C@2WPTh0ZHA@0:Z5D@2[QU840:^7
D`80[8QD0P2]RED01P2[RV40ZhYO0:^:G@2[Re`0Zh]H0:^<EP80ZhaC0P2`RU/20;6;G080/XaM0P2c
SEh00`2dSe/0/XeI0;6<F0020;2;E`060;6<F02bSET0]8mK0:n;F`2aSEd0]91P0P2eTF400`2bSUh0
[h]K0:f9F@090;:=F@0C0;>>FP2dSe/0]I1L0;B?F`2bSET0/8]G0:n:EP2`ReL0[hYF0:j9E@2]R5@0
[XUE0:n:EP2aS5P0/XeI0;F@G02cSUX0/HaH0:n:EP020:j9E@80[hYF0`2`RU/30:n9FP80[XQI202_
REX80:n:D`P0/8]G0P2_RUh0102_RUd0[XYH0:j:EP2]RU820:f:D0T0[hUJ202_RUH0202^R5/0[hUJ
0;6;G02cSE`0/hiJ0;>>F@2bSEH0/HaE202^RED0202ZQ5D0ZhEF0:f7F02^R5T0[hUJ0:j8F@2]QeP0
[8IG0P2_RUH30:j9E@<0[HQD0P2/Qe<0102]R5@0[XUE0:n:EP2`ReL20;6<F080[hQM0`2^Qe`30:f6
F`P0ZhIB0P2/Qe<60:^6DP80/HME0P2`QU@20:n5D`80[XAB202]R5@01@2YQ500ZXEA0:b7D`2^RED0
[hYF0080[XUE00<0[HQD0:b7D`2/Qe<0102/Qe<20:f8E0040:b7D`2]R5@0[HQD0:f8E080[XUE0P2_
RUH80:^6DP080:f8D`2/Qe80ZhIA0:Z5D02[QU40[HQC0:n:E@2`ReH80:b7DP<0ZXEA00<0ZhIB0:b7
D`2/Qe<00P2]R5@90:j9E@030:f8E02/Qe<0ZhIB0080ZHA@00<0ZhIB0:b7D`2]R5@0202[QU430:b7
D`<0ZhIB0P2ZQE430:f4C080[8=;0`2[PTX00`2/PU00[XAB0;67E@020;:8EP060:n5D`2[PDl0ZGm=
0:^6DP2/Qe<0[HQD0P2^RED02`2]R5@0[8MC0:^6DP2]QeP0[8IG0:^5EP2ZQ5D0ZhEF0:f7F02_REX0
/8YK00P0[HMH0P2[QU820:b7D`80[HQD0`2^RED20:f8E0030:b7D`2[QU80ZXEA0080ZHA@202ZQE43
0:V4C`80ZXE@0`2[QU420:f4D0<0[XEA0`2_QU880:b3C`P0ZXE@0P2ZQE420:^6DP<0[8MC00H0[HQD
0:f8D@2]R540[HQC0:f8E02]QeH20:f7F0030:f7FP2^RED0[XUE00H0[XUE0P2_RUD20:j9E0<0[HQC
0P2/Qe80202[QU80[8MC0:j9E@2_RUH0/8]G0:n:EP2^RED0[HQD0P2^RED30:f8E0<0[8MC202]Q500
1P2_Q4d0[XE=0:n6D02^QU80[HQC0:b8E080ZXUF1@2/Qe<30:f8E0P0ZhIA202^QE420:V4D0<0ZXEA
0`2[QU801P2/QUT0[8IG0:b6E`2[QE@0ZhIB0:^6D@80ZXE>202[QU880:b7D`P0ZXEA202]QeH0202_
RUH0[HQD0:^6DP2ZQE40ZHA@0:Z5D@2[QU80[8MC0`2ZQE030:^6D@80[8MB1`2[QU402@2/Qe80[XUD
0:j9E02]R5<0[8MB0:^6D@2ZQE00ZHA?0:R3CP020;26E0@0[hEC0P2`QU@20:^6C`030:b7DP2/Qe<0
[HMF00<0[HMH00<0[HMJ0:j9E@2^RED00P2]R5@20:b7D`80ZhIB00<0[HQD0:b7D`2ZQE400P2YQ500
2`2ZQE40[8MC0:f8E02^RED0[HQD0:^6DP2ZQE40ZHA@0:Z5D@2[QU80[8MC0080ZhI?00<0ZhIA0:^6
DP2[QE@00P2[QEH01`2[QEP0[HQC0:f8E02]R5@0[HMF0:f7F02]QeX00P2]QU/80:^5EP050:f8E02/
Qe<0[8MC0:^6DP2YQ5000P2XPdl00`2WPTh0ZXEA0:Z5D@060:Z5D@D0[XQI00<0[HMH0:b6E`2/QUL0
0`2[QU820:Z5D@<0ZHA@00<0Yh9>0:R3C`2ZQE400P2[QU800`2ZQE40Z8=?0:N2CP020:n6DP<0[XEA
0`2]Q5020:V2E`80ZX=H102[Q5T20:Z4E@<0ZH=D0`2XPU<00`2WPE80Z89C0:V3E0020:V3E0030:N1
DP2UOe00Y7i?0080Y7m:00@0YH1;0:J1C02WPTd0Z8=>2P2YQ4l01P2[Odh0ZX1>0:Z0CP2YPDh0YX5=
0:F1C@80Xh9=00@0YX5=0:F0C02UP4`0YH1<0P2TOd/30:=nBP060:]oCP2ZP4h0ZX1>0:V1CP2WPTh0
YX9>0P2TPdh01P2XPdl0Yh9>0:J1C@2UP4`0Y7m;0:=nBP80XWe900<0Xgi:0:AoB`2UP4`00P2VPDd0
0`2UP4`0Y7m;0:=nBP080:1kA`80X7]400H0X7]60:5lB02RO4/0XWa=0:=mCP2SOE020:ElA0040:El
AP2UO4P0YGa80:EkB@80YG];0`2PNdL209mjAP<0WWU500P0Y7m;0:9mB@2PNdL0WgY609iiA@2ONTH0
X7]70:5lB0<0WWY60P2ONdL30:1lB0<0YGa>:oooool002[ooooo00<0TfPk099W>P2AIST00P2@ICP0
0`2BIcX0U6Tl09I[?P0209EY?0<0UVXm0`2GJch809IZ?@0A099U?02AI3/0T6<j091S>P2AI3/0TfHm
09IY@02HJd80TfTg09E[>@2GKC/0V6hl09U_?@2HKS`0Ufdk09I/>P2MLD@00P2LL4<01@2KKd80VVi1
09U]@02IKD00V6`o0080V6hl0P2GKC/209I/>P80UF/i0P2JKSd309U]?0<0V6`k202JKSd209]`>`04
09]`?@2JKSd0VVho09Y^?`80VFe000`0VFa209Q]>P2HKCX0VFhk09]`?@2LLCh0WG8o09ic@02OM440
X7E209md@@2MLSl209]`?@0309eb?`2OM440X7E20080Vg0i00@0Vg0k09aa?P2MLSl0WW910P2NLT<0
2`2PM4L0Wg=609ibA@2MLD@0W71309]_@P2JKT40VFe00:1e@P2OM440WG8o0080W74n00D0WG8o09md
@@2PMD80XWM40:5f@`0209md@@040:1e@P2RMd@0Y7U60:IkB0@0XWM40P2SN4D:0:AiAP<0XgQ50P2T
NDH30:EjA`040:5hA02RNDD0XgY60:ElB0<0YWe900@0YGa80:IkB02VNdP0YW]80`2UNTL20:AiAPP0
Z7e600<0XgQ50:AiAP2VNdP00P2WO4T00`2VNdP0Y7U60:=hA@080:=iA`<0WWE10P2MM40309ac?`0H
09Y`?P2IKcd0V6hl09M]>`2FK3X0UF/i09AZ>02CJCL0SfDc091V=02BJ3H0TfTg099X=P2AIcD0SfDc
08iT<P2;IS40RVDa08UT<028HS40QV0a08EO<P24GC80Pe`a0P24FS800`22Fc80PE`b085L<P0207mL
<P80OUdb00@0OUT_07eH;P1lEbd0NUD[0`1iE2X00`1jEB/0LTlY079?:@02079?:@@0LDhX0`1^CB`2
06e<:`<0K4/Z00<0JddY06Y<:01XBRH00P1WBBD00`1YBbL0JddY06e?:`0306Q:9P80IdTU0`1VB2@3
06E48`0306I5901WARD0J4LV0080J4LV00P0J4LT06Y99P1[BRL0IdHS06=27`1T@b00JdXW079A;P80
LDd[0140M4d/07E<;01hCBd0N4d]07U<;@1jCBh0N4hV07U?9`1kDBT0OE<[07iD;01mDb/0Ne4Y07Y@
:01oERX0P5L[08=J;P0408EL<00<08AK;`28G2d0Qe//08IJ:`25FBX0QUX[08MK;029GBh0RUh_085K
;P22G2l0Ped`0P24GS400`23GC00PU`_085K;P04089L;`80Ped`0P24GS4208QS;`@0Qf8^0P26HBd8
08EP<`06089L;`23GC00Q5ha08EO<P26H3<0R68e0P29HcH208EO<P0608IP<`28HSD0RF<f08YT=`2;
ICP0S6Hi202:Gc8908MQ<PP0R68c00<0Relb08eQ=02>HSD00P2@I3L00`2>HSD0SF4d08]O<P0208QR
<`0408US=02:I3D0RV@e08]U=P80S6Hg2029Hc@04028HCX0Qf0i08IO=025Gc80QEl^08MR;@29I2d0
RVH/08AO<P25H3<0QV4d08MR=@26HC@0QF0c08=N<@22GC08089N;P03085L;`22GC00QF0c00<0Qf8e
00@0QF0c08AO<P26H3<0QV0c0P25Gc8308AN<@0408=M<022GC00PUd`089M<080PE`_0`20Fbh307aL
;@<0OEd^0P1nGRl02022GcL0Oe`b07aI;`1jF2/0NUPZ07aJ:P1oGR/0PV4^0`1oFRd5081K;P80P5/a
1@1oFS000`1nFBl0OeX]07mJ;@0607mJ;@80OEL`0P1nF34207mI<P80P5Xc00<0OUT_07eH;P1kER`0
0P1jEB/00`1kER`0OEP^07iI;`0807]E;P80MeX^00@0MEP/07AG:`1bEBT0LE@X0`1_DRH01P1fE2H0
MU@W07ID9`1eDRP0ME8Z07AA:`80M50/201bDRT01@1cERh0LUD]06mB:P1/CbL0JdhV0080JTdU00<0
JdhV06U<901YC2@00P1ZCBD0101[CRH0K4lW06e@:01]D2P306a?9`80JdhV0`1ZCBD0201XDbP0Ie8W
06A?901SCR<0HTdR06=>8`1TCb@0IU4V0P1SCBH0101QBb@0H4XS05i88@1MAb0205]57P80FDTW00L0
F4PV05M79@1FAR@0ETHT05E58`1DA280FdHY0080FTDX00<0FD@W05Q39P1H@bH00P1G@RD02@1J@b40
FD8R05Q18@1G@240ECdQ05<k8@1B>R80DCTQ04/k8P0604`l8`0304/k8P1:>ah0BS/N0080Bc`O00@0
C3dP04dn8@1>?b80CSlR0P1??bH204hn9@<0CCdT00@0C3`S04dm901<?2<0BSXQ0P18>1l00`1:>R40
C3`S04dm900204Xj8@80Bc/R0`1<?2<01P1=?B@0BS/V04Xk9P1:>b@0BcdS04/m8P80C3hQ00D0C3lO
050l8@1@?240CSdQ04dn8@0204`n8@80BSlQ201C@2001@1H@B80Ed0Q05Dn7`1C?1d0DS/L0080Dc`M
00@0E3dN050o8`1@?b<0D3lS0P1A@2@01@1B@BD0Dd8V05=29P1D@bL0Ed0N00<0F44O0P1I@R0205Y3
8@0405118P1A@R<0DD8S05528`80DT<T0P1CA2D205E58@80ETHR00@0EdLS05Q8901HB2@0FDTU0P1N
B2<02@1MAb80G4HQ05]5801JA1l0FD<N05Q27@1PBRD0GTPS05a68@0205Y47`0305a68@1NB2<0H4XU
00P0GTXU0P1SCBP0101RC2L0HD/V05m9901NB2<205e78P80Fd@R00@0G4DS05e6901MAR@0GTLU0P1O
B2H805a58`0505]<9@1JBb@0FDXS05U:8`1HBB800`1IBR<0101KAB00G4HQ05a68@1LAR4205e78P80
GTPS00H0G4PU05e99P1MBBH0GTXW05m;:01PC2T2065=:P0606Y;;01ZC2X0Jdd[06a>:P1]CbT0KE0X
0P1^DBL0401`D2X0KdlY06i>:01^CRP0KdlY075A:`1dE2h0MUH`07QH<@1iFC80NUXa07aM<@1mGS00
Of0a081R<021Hc44085Q<P@0P60a00@0PF0c08=R=@25I3L0QfHi0P28IcX00`27IST0QVDh08eW>003
08eW>0@0S6Hg102DKc/309E`?080UW4m0`2JMD0209]f@@<0W7M200P0Ug<o09Qd@02IMD40VgM309ei
A@2ONdL0X7a80:5mB@<0Xgi90`2TOdX20:F0B`090:9mB@2SOTX0Y7m;0:F0C02WPTh0ZHA@0:Z5D@2[
QU80ZXIB00<0ZhMC0P2/R5@20:f9E@80ZhYQ00H0ZhYM0:^;G02[ReP0ZhaE0:^<D`2[SE420;2:F`80
/H]L0P2bS5d20;>=GP030;>>FP2bSET0/HaH0080/8]G00H0/HaH0;:=F@2cSUX0[h]K0;6=G@2dT602
0;JBHP030;>?G`2_Re/0[8QH00T0/XeI00X0/hiJ0;F@G02eT5`0]I1L0;>>FP2`ReL0[hYF0;2;E`2_
RUH0[XUE0P2]R5@01`2_RUH0/HaH0;:=F@2eT5`0]8mK0;6<F02_RUH00`2^RED0102_RUH0/8YK0;2:
F`2`RU/20:n9FP<0[XQI202_REX80:n:D`P0/8]G00P0[hYP0:n:GP2_RUd0[XYH0:j;E@2]RU80[HY@
0:f;CP@0[XQI0P2_REX30;2:F`P0[hYF00H0[XQK0:n9FP2aRe`0/heL0;B?F`2cSUT20;:=EPP0[XUE
00P0ZXAE0:^5EP2]QeP0[XQI0:n9FP2^R5T0[HMH0:b6E`80[hYF0`2^RED30:f8E0080:b7D`2]R5@0
[XUE0:n:EP2`ReL0/HaH0;:=F@2cSUX20:n8G@<0[XML0`2]QU/80:^6DP<0[8MC1@2[QU830;67E@03
0;26E02_QE<0[XAB0080[XAB202]R5@0102WPTh0ZHA@0:^6DP2^RED30:n:EP030:j9E@2/Qe<0[HQD
00@0[HQD0P2^RED40:f8E080[XUE0P2_RUH80:^6DP080:f8D`2/Qe80ZXE@0:Z5D02[QU40[HQC0:n:
E@2aS5L80:b7DP040:V4D02ZQE40ZXEA0:^6DP80[8MC0P2]R5@90:j9E@030:f8E02/Qe<0ZhIB0080
ZHA@00<0ZhIB0:b7D`2]R5@0202[QU430:b7D`<0ZhIB0P2ZQE420:f4C0<0[8=;0`2[PTX02`2/PU00
[XAB0;67E@2cREL0/XQF0:n5D`2[PDl0Z7i<0:Z5D@2/Qe<0[HQD0080[hYF00<0[HQD0:b7D`2ZQE40
0P2/QUL01P2[QEH0ZXAE0:^5EP2]QeP0[hUJ0;2:F`P0[HMH0P2[QU820:b7D`80[HQD0P2^RED20:n:
EP060:j9E@2/Qe<0ZXEA0:V4D02XPdl0Yh9>202ZQE430:V4C`80ZXE@0`2[QU420:f4D0<0[XEA0`2_
QU880:b3C`P0ZXE@0P2ZQE420:^6DP@0[8MC0P2]R5400`2]R5<0[HQD0:f7EP020:f7F0030:f7FP2^
RED0[XUE00H0[XUE00@0/8]F0:n:E@2_RUD0[XUD0`2]R5<20:b7DP030:Z5D@2/Qe<0[XUE0080/8]G
00@0[hYF0:j9E@2]R5@0[hYF0P2^RED01@2]R5@0[8MC0:^6DP2[QU80ZXEA0080[8=?102]Q5020:j5
D@080:n4C@2^QDd0[hI@0:j6DP2]R5<0[8QD0:Z9EP2[RUL40:b7D`@0[HQD202[QU480:j5D@<0ZHA@
0P2ZQE430:^6DP060:b6F@2/QUL0[8IG0:^5E02[QU80ZhIA0P2ZQDh80:^6DPP0[8MC202ZQE480:j8
E`030:n:EP2^RED0ZhIB00<0ZHA@00@0ZhIB0:b7D`2ZQE00ZXE@0P2[QU40102/Qe80[HQC0:j9E02^
RE@30:b7DP<0ZhIA0P2ZQE020:j9E0030:f8D`2/Qe80ZhIA0080ZHA?00<0Z8=>0;26E02`QU@0102_
QE<20;26E080ZhI?00<0[8MB0:b7D`2]QeH00`2]QeP01P2^R5/0[XUE0:j9E@2^RED0[HQD0:b7D`<0
ZhIB00<0[HQD0:b7D`2ZQE400P2YQ5001P2ZQE40[8MC0:f8E02_RUH0[HQD0:^6DP80ZHA@00<0ZXEA
0:^6DP2/Qe<00P2[QTl00`2[QU40ZhIB0:^5E0020:^5EP070:^5F02]R5<0[HQD0:f8E02]QeH0[HMH
0:f7FP020:f6F`P0ZhEH0P2]R5@0102/Qe<0ZhIB0:V4D02XPdl20:N2CPP0ZXEA00D0/8YK0:n9FP2^
R5T0[HMH0:b6E`020:f7F0040:j8F@2/Qe<0[8MC0:^6DP80ZXEA00H0ZHA@0:R3C`2XPdl0Yh9>0:R3
C`2ZQE420:^6DP030:Z5D@2XPdl0Yh9>0080/8MC0`2_QU830:j5D@80Z85F0P2YPUL30:Z3F0030:^4
F@2ZQ5D0ZXAE00<0ZH=D102XPU<03@2YPe@0ZXAE0:^5EP2ZQ5D0Z89C0:J0D@2TOTl0Xgi90:AoBP2U
P4/0YX5<0:N2C@2XPdh02P2YQ4l01P2[Odh0ZX1>0:Z0CP2XP4d0YX5=0:F1C@80Xh9=0`2TOd/30:=n
BP<0XWe900H0Zgm>0:Z0CP2ZP4h0ZH5>0:N2CP2VPTh20:B3CP80Z8=?00@0Yh9>0:J1C@2TOd/0Xgi:
0P2RODT00`2SOTX0Y7m;0:J1C@020:N2CP030:J1C@2TOd/0Xgi:00<0WgY60P2PNdL30:5lB00809mj
@`2PNd@0X7]60:5lB02RO4/0XWa=0:=mCP2SOE020:Ak@`040:AkA@2TNdL0Y7]70:AjB080Y7Y:0P2P
NdL309mjAP<0WWU500P0YH1<0:AoB`2RODT0X7]709mjAP2PNdL0XWe90:=nBP<0WWY60P2ONdL30:1l
B0<0YWe?:oooool002[ooooo00<0UFXm09AY?02CJ3/00P2BIcX01P2DJC`0UV/n09M/?`2BIST0TfLj
09EY?080Uf/n00/0UVXm09EY?02DJ3/0UV``09I/<P2FJcH0UVXi09IY?`2FJ4@0UVQ709IWB@0209MT
>@0409QU>P2IIS/0VfPm09aY?P80WFXo202FJST409U^@@80V6e00P2GK3l809IZ?@80Vfln00@0VVhm
09U]?02HK3/0V6`k0P2GJcX01P2FJS/0Uf/l09M[>P2GK3T0V6dj09Q]>080VFhg00@0Vg0m09Y_?02J
Kc`0VFhk0`2HKCX209M/>@0H09aa?P2KL3d0Vg0m09]`?@2LLCh0WW=00:1e@P2RMd@0WgDi09id>P2L
LSP0VVlh09U^>@2IKS/0VVhm09]_?P2JKcX0Vg0k09eb?@2NLch0Wg@o09ic?P2MLSd0W74l202MLSl5
09ed@0<0W7<o0`2PMD800`2QMT<0XWM40:=hA@020:=hA@P0XWM400@0YGY70:AiAP2TNDH0XgQ50P2R
Md@20:5f@`80XgY60`2RNDD30:5hA00409me@`2PMT@0XWQ60:AjB080YG]90P2TNTP80:IlBP80Z7e:
0P2WO4T30:IkB0090:EjA`2WOD/0YWa:0:AjB02SNDL0XWQ60:=iA`2TNTP0YG]90080XgY60P2RNDD3
0:5hA0050:1g@`2PMT@0X7I409me@`2NM4800P2MLd4209ab@00809a/>`2KJc/0VV`k09M[?02EJSd0
TfXn099X?P2@JCh2091[?P0408mZ?@2>JC`0SFPk08eX>`80S6Lj00@0SVXh08]W=@28I380QF4_0P24
H2h01026HS00Qf<a089L=@22G3D208=M=P05089L=@1oFC80OeTb07aF;`1jE2d00P1iES001P1jEc40
NEH`07MD;P1dDB/0LTlY071=9`P0LDhX00P0L4l^06m>;@1]C2/0K4/Z06]::@1/BbX0KD`[06i=;080
IdPY0P1VAbP406E69`80H4XU00@0HDTU06989@1SAR@0I4HT0P1VAB@206538@H0HT@R0P1WAb001P1X
B240JTXS06];901/C2D0KDdV06i>9`@0M4hY101eCbX207YE:0H0NeHY00P0NELW07YH:01kFBT0O5XZ
07eK:`1nG2`0Oed]081N;P<0QElb00<0Q5ha08=M<022G2l00P21Fbh@08EO<00308AN;`25Gc00QV0a
0080R68c00@0QV0a08EO<024GRl0QEl`0P26H3400`28HS<0RF<d08YT=@0208]U=PP0Qf4d2025Gc00
0`26H340Qf4b08US=00208YT=@0308US=027HC80QV0a00<0RF<d0P2:I3D408]U=P0308YU<@29I300
Qf8^0080QV4]00<0Qf8^08UT<02:IC400P29HcH01028HSD0Qf4d08MQ=026H3<208EO<PP0Qf4d0P2:
I3D208US=00408QR<`27HC80Qf4b08IP<@P0Relb00@0PUd`08AO<P26HC@0Qf8e0P28HcH00`27HSD0
QV4d08MQ<P0708MQ<P04081K;P21G2l0PE`_089M<080Peha0P24Gc8808EQ<@80Q60`00@0Pel_089N
;P20G2`0Oe/[0P1nFRX2085L;`<0P5/^0`1oFRd00`23GS@0PUdc07mJ<00307eH;P0307iI;`1oFS00
OEP[00<0OUT/0`1oFRd01020Fbh0OUT_07eH;P1kER`207YE:`0307]F;01mF2h0OUT_00P0NeP^201n
FBl307]H;P80NUL]0`1iER`0201aE2X0M5@[07IF;@1iF2l0NUL_07]E;P1jDb`0NE8[2@1dE2d207=C
;080LU8[101aDBX01P1fE2h0ME<]07AB;01cDB/0LU0Z075?:@80L4hX00<0KDl[06a>:P1[CBT00P1Z
C2P00`1[CBT0KDl[06mA;@0606a>:080JddW0P1/CRX0101[CBT0JD/W06M99@1VB2@206A68PP0I4XW
00P0I4`V069<9`1QBbH0GDTV05]89`1GAbH0EDHW05A59P<0F4@S0`1IAB@205Y69@D0ED0Q0`1D?b00
1P1E@R80E44Q05=0801B?al0D3dM04ll7080CS/K0P1;>b4204`l8P0504dm8`1>?R@0CclU04lo9@19
?B<00`18?28204Lk8@80ASXP4@17>b401P16>R00A3PN04<g7@13=ad0A3PN04Hj80T0Ac/Q00@0A3PN
04Di7`15>Al0ASXP0P17>b4204Pl8P0804dm8`1<?280Bc/Q04/k8@1<?280CCdS04lo9@1A@BL8050m
7`<0ED@V00h0E4<U05=2901B@B<0DD0R050o8@1??R00CCdL04lo7P1B@R40EDDT05M79P1FARD0E4@S
05=38P80DdDP0P1DAR4305E78P0305I88`1K@b40Fd<Q0080Fd<Q101LA280201M@200Fd4P05Y2801G
@b00E4@P05=5801BAR00D4LP0P1MBbL205a:9P0705]99@1JB2@0FTPT05U78`1I@R00Fd@R05m89P02
069;:@0>065::01NAbD0Fd@R05I47P1IAB00FdLR061:9@1RBRH0HdTV06A79@1SAR@0HD/V061:9@1N
B2<205e78P0305m9901QBbH0HT`W00P0GTLU201KBBD805i79@@0H4XU0P1QBbH2069<9`0I06M::P1X
Bb/0JD/Y06Y<:01]CBL0KddW075>:01aCRH0KDl]06i@;01_DBd0L58/079E;@1cER`0M5L[07EH;01c
E2P0M5DY07EF:P1gF2`0NEX^07aM<@1mGS80Of0d07aM;P0207eN;`0307iO<01oH340Of0a0080P64b
00P0R6<g08MR=P26HC@0QV8b08MS<@29IC40RfLc08eZ=0<0RVHf0P2;IcL308aX>00908eW>02?JCX0
SfTj099/?@2EKd00UW1109E_@02CKCh0TV`m0080UW4m00<0Ug8n09Qc?`2IM4000P2JMD400`2KMT80
W7M309ag@`0209ehA0<0WWU50`2ONTH00`2PNdL0XGa80:9mB@020:=nBP030:AoB`2SOd/0Y81<00D0
Y81<00D0YH5=0:N3C`2YQE40ZhMC0:f9E@020:j:EP030:f9E@2/R5@0ZXIB0080ZhMC00<0[8QD0:f9
E@2^RUH00P2_ReL40;6=G@@0/8aL202bSET80;F?H0030;>=GP2bS5d0[hUJ0080[HMH00<0[hUJ0;:<
G@2cSEh0202`ReL20:n:EP<0/8]G0`2aS5P20;2<G0040:n;F`2^RUX0[XYJ0:f9F@80[8QH0P2aRe`0
102`RU/0[hUJ0:n9FP2^R5T20:f7F0D0/XUK0`2cRU`00`2]R5@0[XUE0;2;E`030;:=F@040;6<F02`
ReL0[8IG0:b6E`80[HMH00L0[XQI0:n9FP2`RU/0/8YK0:f7F02^R5T0/8YK00<0/XaM00@0/H]L0;2:
F`2]QeX0[HMH0P2^R5T00`2_REP0[hYF0;2;EP020;6<E@80Zh]B00<0[HYB0:n:D`2aRU<00P2cRU@0
0`2dRE@0/8YK0;2:F`060;2:F`P0[XUE202^Qe`20:f6G@030:f6F`2]QeX0[HMH0080[HMF00H0[HQD
0;2;E`2`ReL0[hYF0:j9E@2]R5@20:b7D`090:^6DP2]R5@0[XQG0:j8E`2_REX0/8YM0;6:G`2aRV40
/X]R0080ZhI?00H0[8MB0:b7D`2]QeH0[HMH0:j8F@2^R5/80:^6DPP0[hEC00P0[hYE0:j9E02]R5<0
[8MB0:f8D`2^RE@0/8]F0;6<E`80ZhIB0P2/Qe<20:f8E080[XUE0P2`Qe<20:n6DP070:j5D@2]Q500
[HA@0:b3C`2[QU40[HQC0:n:E@020;2;EP030:n:E@2]R5<0ZhIA00P0[HQA202[QU830:n6DPD0[XEA
00T0ZHA?0:Z5D02[QU40[8MB0:f8D`2^RE@0[hYE0;2;EP2XQe@0102YR5D30:Z9EP070:^:E`2[PDl0
[89@0:b2D02^Q580[hEC0;26E0020;67E@80[HQC00@0[8MB0:^6D@2YQ4l0Z8=>0P2WPTd20:b7DP04
0:^6D@2ZQE00ZXE@0:V4C`80Z8=>202ZQE000`2^RED0[HQD0:^6DP020:V4D0030:Z5D@2/Qe<0[HQD
00P0ZhIB202^R5T01P2[QEP0ZhEF0:^5EP2[QE@0ZhIB0:^6D@80ZhI?0`2/Qe<30:^6DP80ZXEA0`2^
RE@20:f8D`<0[8MB0`2XPdl30:V4D080ZXEA0`2/PU020:f3D@<0[XAB0P2_QE<0102^Q580[H=A0:f3
D@2/PU020:^1C`P0ZXEA202ZQDh30:^6DP030:b7D`2]R5@0[XUE0080[XUE202[QU880:f8E0040:b7
D02^RE80/8]D0;6<E@80/8]D00<0[XUB0:^6C`2ZQDh0202]R5@00`2]R5<0[8MB0:^6D@020:V4C`03
0:^6D@2/Qe80[HQC0080ZHA@102ZQE420:^6DP030:b7D`2[QU80ZHA@0080Z8=?00@0ZHA@0:^6DP2/
Qe<0ZHA@0P2ZQE400`2[QU80[8MC0:b7D`020:f8E0030:^2BP2]Q4`0[hI>0080/HQ@00<0[hI>0:f4
C02[PTX0202ZQDh80:Z5D@030:N2CP2XPdl0ZXEA0080ZhIB00<0ZXEA0:R3C`2WPTh0202ZQE40102^
Q580[H=A0:f3D@2]Pe420:b2D080Zh5?202[QEH20:b6E@040:b7D`2/Qe80[8MB0:b7D080[8Q>202[
QU430:^6DP80[8MC0`2[QU820:b2DP060:f3D@2^QE40[hIB0;27D@2`Qdl0/HQ@0`2[QU420:Z5D0<0
ZHA?0`2/Qe<30:^6DP80ZXEA00<0[XUD0:b7DP2ZQE000P2YQ4l20:Z5D0050:b7DP2^RE@0/8ID0:n5
D`2]Pe400P2/PU00102]Pe40[hEC0;26E02YQ5020:Z5D@030:^6DP2/Qe<0[8MC0080[HQD0P2_RUH2
0;2;E`040;6<F02bSET0/XeI0;>>FPP0[8MB0P2_RUD20:j9E0@0[HQC0`2[QU820:Z5D@<0ZHA@202Z
QE420:b7D`040:^6DP2ZQE40ZXEA0:V4D080Z8=?0P2ZQE430:^6DPh0[8MC0`2[QU820:Z5D@P0[HA>
2@2[QU803`2YQ500Yh9>0:J1C@2UP4`0YX5=0:N2CP2XPdl0YH1<0:J1C@2XPdl0ZHA@0:R3C`2VPDd0
Y7m;0:=nBP020:AoBP030:F0B`2VPD`0Yh9=0080Z8=>00<0ZHA?0:J1C02WPTd00P2WPTd30:R3CP04
0:V4C`2SOTT0Y7m:0:J1C080Yh9=00<0YX5<0:AoBP2SOTT02@2UP4`80:J1C@P0XH1;0`2VPDd20:F0
C0<0Y7m;0P2SOTL00`2RODP0XWe90:5kBP020:1jB`0309miC02RNDD0XWU500@0XgY60P2TNdL30:Ek
B@<0Y7Y80P2SNDL00`2TN4L0XWI50:5eA00209mc@P090:5eA02RMTD0Y7Q709egBP2MMdP0WWQ909mi
B02QO4P0XWe80080Xgi70`2ONDX20:1jB`<0XG]<0`2SOE0[ooooo`00:_ooool00`2EJSd0U6Tl09=X
>`02099W>P0609AY?02FJch0Uf`o09=W>P2DJ3/0UVXm0P2GJch02`2FJSd0U6Pk09=W>P2FK300UV`b
09I[=P2FJST0UVTo09IY@P2FJ4H0UVQ70080UVDj00@0UfHk09QW?02HIc`0VFPm0P2JJCh809IZ>@<0
V6e00`2GK3l209I[?PP0Uf/n0`2JKSd209U]?0<0V6`k0P2GJc`0102GJcX0V6dj09Q]>P2IKST209U^
=`0309]`?@2JKc`0VVll00<0VFhk0P2HKCX00`2GK3T0Vg0m09]`?@0209Y_?00D09]`?@2MLSl0WgA1
0:5f@`2OMCT0WW@j09ab>02JKcP0VFhi09Y_?02KKch0W70o09Y_>P2KL3/0WG8m09ic?P2OM3l0WW<n
09eb?@2LLC`809ic@0P0WGA00P2PMD820:5f@`80XWM40P2SN4D80:9gA0<0Y7U600<0XgQ50:9gA02R
Md@00P2QMT<30:=jAP80XWU50`2QN4@00`2OMD<0X7I40:=iA`040:EkB@030:AjB02VO4X0YWa:00H0
YWa:0P2XODX20:MlB@@0YW]800<0Yge;0:IlBP2TNTP00P2RN4H0102SNDL0Y7Y80:EkB@2SNTH30:9i
A@80XGQ40P2PMd<20:1fA00309me@`2NM480WG=10080W79000L0Vg4o09][>P2JK3/0VF/j09M[?02E
JSd0TfXn0080T6Tn0P2?JSd00`2>JC`0SFPk08aW>P0208]V>@0508YU>027Hc40QV8`08AP;P23Gbd0
0`22GR`01P23Gbd0PE/d085K=022G3D0PE/d081J<`80OUPa00@0NeD^07UC;01hEBl0N5D_0P1iES00
0`1gE2h0ME8/079?:@09075>:00306m>;@1^CB`0K4/Z0080JTTX00<0JdXY06a;:P1]C2/00P1WB2T2
06I7:0<0IDHW00T0I4DV065;9P1PBRD0HDTU06989@1SAR@0I4HT06I5901UA2<0101UAbD406I89P08
06M7801XB240JDTR06Y:8`1/C2D0KDdV06i>9`1_CbP207A>:@<0MDlZ0`1fD2/00`1jEBP0NeHY07]F
:@0207]F:@<0O5LZ00D0NUPX07]I:@1kFBT0O5XZ07iL;00207mM;@03081N;P25Gc80QElb0080Q5ha
0P23GC02089L;a00QEl`00<0Q5h_08EO<026H3400P28HS<01026H340QEl`08AN;`25Gc0208IP<@05
08MQ<P29Hc@0RV@e08YT=@2;ICH02027HC@808EO<00308IP<@27HC80RF<d0080RV@e00<0RF<d08MQ
<P26H3400`28HS<208US=0@0RV@e00<0RVDa08UT<027HRh00P26HBd00`27HRh0RF@`08YU<@0208US
=P80R68e00@0Qf4d08IP<`26H3<0QV0c2027HC@208YT=@80RF<d00@0R68c08MQ<P27HC80Qf4b202:
Gc801P22GC00Q5lb08IQ=027HSD0R6<f08MR=@80QV4d2027HC82085L;`80PUd`0P23GS4208AO<PP0
QF4a0P24H3001P23Gbl0PUh^085M;@20G2`0Oe/[07iJ:P<0PE`_0P20Fbh307mJ;@0308AO=@22GC<0
P5/a00<0OUT_00<0OeX`081K<@1oFRd00`1oFRd407iI;00307iI;`1mF2h0NeH/0080NUD[00<0NeH/
07eH;P1nFBl0201kF2h807iI;`<0NeP^0P1jEbd307UF;008075D:P1dE2/0MUH]07QG;P1jEbl0NeD^
07YC;01iDR/907AD;@80Le</0P1bDR/3075A:P0A071@:@1eDbd0ME<]07AB;01cDB/0LU0Z075?:@1`
CRP0KddW06e?:`1/CRX0JT`X06U;9`1ZC2P0JddY06e?:`1^D2`00P1[CbP306Y>9`<0JDdV0P1ZCRT0
1P1XC2L0Id/V06E9901TB2<0HdLR06968@<0I4XY00<0HdTX06989`1RB2L00P1QAbH01P1RBRH0H4XU
05m89P1KAbH0FDHV05E59080Dd@U201G@b800`1E@240E3lP05@o800505@o800505=0801B?al0DSlO
054n7P1@?Ad00P1??1`00`1>>a/0C3`R04`l8P0204`l8P<0CCdS00<0CShT04Pl8P18?2800P18?282
04Lk8@80ASXP4@17>b401P16>R00A3PN04<g7@13=ad0A3PN04Hj80T0Ac/Q0`15>Al00`16>R00Ac/Q
04Lk8@0204Pl8P0304dm8`1<?280Bc/Q0080Bc/Q00<0CCdS04lo9@1@@2H0201@?Al205=290<0DT4S
00P0DD0R050o8@1@?b40D3lQ04lo7P1@@1l0DT8Q05=38P<0EDDT00<0E4@S05=5801CAB000P1DAR44
05E78PD0FT<Q0`1KA28205]1800405Y2801G@b00ET@P05=58080DTHP201KBBD03@1I@R00Fd@R05m8
9P1QBRP0HT/Y06199`1MAR@0Fd@R05I47P1HAR00FdLR05m9901RBRH00P1RB2D02@1SAR@0HT`W065;
9P1OBB@0GTPS05e78P1NB2<0GdTT065;9P0805i79@P0FdTU201NAbD0101OBB@0H4XU061:9@1PBRD2
065;9P80HT`W01P0ID/Z06M::P1XBbT0JT`X06e=9`1_CBL0L4dW075>9P1]Cbd0KDl[06i@;01`DR`0
LE@/079E:`1cERX0M5L[07AE:@1eERX0MUL[07QI;@1jFbl0O5da07iO<`1oH3@207aM;P80OEh_00d0
OUl`07mP<@20HC80P64b08QS=`27HSH0QV4d08IR<P27Hc40RFDa08]W<`2<JC<0R6@d0080RFDe00<0
RVHf08]W=`2<J3P00P2=JCT01@2>J3T0SfTj08mY>P2AJc`0Tfdn0080U6ho0P2CKCh209Ia?@0409Mb
?P2HLcl0VGA009Ud@080VWE10`2LMd<209ehA0<0WWU50P2ONTH0102PNdL0XGa80:9mB@2RODT20:=n
BP80Xgm;102TP4`20:F1C@040:N3C`2XQ500ZXIB0:b8E080[HUE0P2/R5@20:Z6DP040:^7D`2/R5@0
[HUE0:j:EP80[h]G0`2aSEd50;2<G0P0/XeI202cSEh00`2bS5d0/H]L0;2:F`020:n9FP030;2:F`2a
Re`0/XaM00P0/8]G0P2_RUH30;2;E`<0/HaH0P2`S5`20:n;F`040:j:FP2]RET0[HUI0:f9F@<0/8YK
0`2_REX20:j8F@H0/XUK0P2cRU`00`2]R5@0[XUE0;2;E`020;:=F@030;6<F02`ReL0[hYF00<0[HMH
0P2^R5T30:n9FP030:f7F02^R5T0/8YK00<0/XaM00@0/H]L0;2:F`2^R5/0[XQI0P2_REX00`2_REP0
[hYF0;2;EP020;2;E080Zh]B00<0[X]C0:n:D`2aRU<00P2cRU@00`2dRE@0/8YK0;2:F`060;2:F`P0
[XUE202^Qe`01P2]QUd0[HIK0:f6F`2]QeX0[HMH0:f7EP80[HQD0P2_RUH30:j9E@D0[HQD00<0[XQG
0:j8F@2^R5/00P2_R5d02@2_R5l0ZhI?0:^6C`2/Qe80[8MC0:f7EP2]QeP0[XQI0:j8F`080:^6DPP0
[hEC00<0[XUD0:f8D`2/Qe800P2[QU400`2]R5<0[hYE0;2;EP020:^6DP80[8MC0P2]R5@20:j9E@80
/8MC0P2_QU801`2^QE40[HA@0:f4D02]Q500[8MB0:f8D`2^RE@00P2_RUD00`2^RE@0[HQC0:b7DP08
0:b7D0P0ZhIB0P2_QU860:j5D@80ZXE@00<0ZhIA0:b7DP2]R5<00`2^RE@20:Z9EPL0ZHQE00H0Zh5?
0:b2D02]Pe40[XAB0:n5D`2`QU@20;67E@050:f8D`2/Qe80[8MB0:^6D@2YQ4l00P2XPdh0102WPTd0
[8MB0:^6D@2[QU420:Z5D080ZHA?00<0Z8=>0:Z5D02ZQE001P2ZQE000`2^RED0[8MC0:^6DP020:V4
D0030:Z5D@2/Qe<0[HQD00P0ZhIB202^R5T01P2[QEP0ZhEF0:^5EP2[QE@0ZhIB0:^6D@80ZhI?0`2/
Qe<20:^6DP<0ZXEA0P2]R5<30:b7DP<0ZhIA0`2XPdl20:V4D0<0ZXEA0`2/PU020:f3D@<0[XAB0P2_
QE<20:j4DP040:f3D@2/PU00[89@0:b2D0P0ZXEA202ZQDh20:^6DP80[8MC0P2]R5@20:j9E@P0[8MC
202]R5@20:j9DP@0[hYC00<0[XUB0:b7D02[QTl02@2]R5@01`2/Qe<0ZhIB0:Z5D@2ZQE40ZhIB0:b7
D`2]R5@0102ZQE440:^6DP030:b7D`2[QU80ZHA@0080Z8=?00<0ZHA@0:^6DP2/Qe<00`2ZQE400`2[
QU80[8MC0:b7D`020:f8E0030:f4C02^QDd0[hI>00<0[hI>00<0[XE=0:f4C02ZQDh01`2ZQDh80:Z5
D@030:N2CP2XPdl0ZXEA0080ZhIB00<0ZXEA0:R3C`2WPTh0202ZQE420:n5D`80[XAB0P2]Pe420:b2
D0P0ZhEF0P2/QUD0102/Qe<0[8MB0:b7DP2/Qe020:b8CPP0ZhIA202[QU820:j4E0040:j4DP2^QE40
[hIB0:n6D080[hI>0`2[QU430:Z5D080ZHA?0`2/Qe<30:^6DP80ZXEA00<0[HQC0:b7DP2[QU400P2Z
QE020:^6D@050:b7DP2]R5<0/8ID0:n5D`2]Pe400P2/PU000`2]Pe40[hEC0;26E0020:Z5D@80ZhIB
0P2/Qe<20:f8E0<0[XUE00<0[hYF0;2;E`2`ReL00P2aS5P80:b7DP80[hYE0P2^RE@30:f8D`040:b7
DP2[QU80ZhIB0:^6DP80ZXEA0`2YQ5080:Z5D@<0ZhIB0P2ZQE430:V4D100ZhIB0`2/Qe<20:^6DP<0
ZXEA202]Q4h80:Z5D@030:^6DP2YQ500Z8=?00<0YX5=00@0Yh9>0:R3C`2VPDd0YX5=0`2XPdl00`2V
PDd0Y7m;0:=nBP020:AoBP040:F0B`2VPD`0Yh9=0:R3CP80ZHA?102XPdh40:N2C@030:=nB@2TOdX0
YX5<0080Yh9=00<0YX5<0:AoBP2SOTT02@2UP4`80:J1C@P0XH1;0P2VPDd30:F0C0<0Y7m;0P2SOTL0
1P2RODP0XWe90:5kBP2QNd`0X7Y;0:1jC@H0XgY60P2TNdL30:EkB@80Y7Y8102SNDL03`2RN4H0X7I4
09me@`2OMD<0X7I40:9hAP2SNDL0WGM:09egB02NN4T0WgU80:1kA`2QO4L0XWe60:=nA`0209miBP<0
X7Y;0`2QNd`30:9lCb_ooooo000Zooooo`0309EZ?@2DJC`0TfPk0080TVLj00D0U6Tl09I[?P2GK3l0
UFTl09IZ?@0209M[?P0409IZ?@2EJC`0TVHi095U>080UV/d00H0UV/h09IZ>`2FJCl0UVU209IXA02F
J4H809QW?0P0UVXi0P2GK3l309I[?P<0UFXm202HK3l0102HK3/0VFdl09U]?02IKC`409Y^?@0609M[
?02HK3d0V6`k09Q]>P2IKS/0VFhi0P2JKcP409Y_?0<0VFhk0P2HKCX0602KL3d0VVll09U^>`2IKS/0
VVll09aa?P2NLd00WgA109me>@2MLcT0W78h09Y_>02JKcX0VVll09a`?`2MLD00Vg0m09aa?P2NLd00
WgA10:1e@P2OM440WW=009eb?`P0X7E2202MM400102PMD80XGI30:5f@`2QMT<30:9gA0030:=hA@2R
Md@0XWM400H0XWM40P2TNDH30:=hA@<0XWM400@0Y7]70:=jAP2SNTH0XgY60P2RNDD20:5hA00409me
@`2QMdD0XgU70:EkB@80YWa:00<0YG]90:AjB02VO4X01`2VO4X30:QmBP80Yga90`2VNdP00`2WOD/0
YG]90:AjB0030:9hAP040:=iA`2TNTP0XWU50:9iA@80XGQ40`2PMd<01P2OMT80WgE309me@`2NM480
WG=109ab@080Vg4o00X0VW0n09Y/>P2JK3/0Uf/j09E[>`2CJS`0T6Xm091Y?P2>JCd0SFPk0P2<IcX0
0`2;IST0RVDh08UT=`0208QS=P80P5`/00H0PEd]089N;P22GRh0PEd]081L;01oFb/407mI<P0=07eG
<01kEBh0NeD^07UC;01hDR/0ME8/07IC;@1gE2h0N5D_07MD;P1fDbd0M54[079?:@08075>:00806e<
:`1/BbX0JTTX06U89`1XAbH0JDPW06Y9:01[BRT306I7:080IDHW0`1TABH2065;9P04069:9P1RB2D0
HdHT06=58`80ID@S00D0IdTW06Q::01XBRP0J4XX06U;:@0306Y<:P0806Q88@1YBB80JTXS06];901]
CBH0KThW06m?:01`D2T307E?:080MU0Y0P1gDBX0101hDR/0NeHY07]F:@1kERT207aG:P<0OEP[00H0
OETY07iJ:P1nFRX0Oe/[081L;021GBd2089N;P80QElb00<0Q5ha08=M<023GC000`23GC0@08EO<003
08AN;`25Gc00QV0a0080R68c00@0QV0a08EO<024GRl0QEl`0P26H3400`27HC80R68c08US=00208YT
=@P0Qf4d2026H3400`27HC80R68c08US=00208YT=@0308US=028HS<0Qf4b0080QV0a0P27HC8208QR
<`<0RF<d00<0RVDa08UT<028Hbl00P27HRh01028Hbl0RF@`08YU<@29HcH308QR=@<0Qf4d00<0QV0c
08MQ=027HC@01P27HC@308US=0<0R68c0P27HC8808YO<P0308=N<@24Gc80QV4d00<0Qf8e00<0QV4d
08EP<`26H3401`26H343089M<0<0Peha0P24Gc8:08AP<00308=O;`22GRh0PEd]0080P5`/00<0Oe/[
089M<021G2l00P21G2l2081K;P80OeX]00<0Q5le08=N=021G3800`20Fc42085L<P05085L;`20Fbh0
P5/^07mJ;@1nFB`00P1mF2/0101lEbX0OUT_07eH;P1lEbd207]F;00307aG;@1mF2h0OUT_00P0NeP^
201nFBl307]H;P80NUL]0`1iER`0201bEB/0MED/07IF;@1hEbh0NEH^07YD;@1jDb`0NE8[2@1dE2d3
079B:`80LE4Z0`1`D2T207=C;003079B:`1aDBX0L50Y0080KdlX00@0KThW06a>:P1[CBT0JT`X0P1Y
BbL0101ZC2P0JddY06]=:@1ZCRT206U=:080J4`W0`1WBbH01P1XBbT0IdXX06I99`1UB2H0I4LU0695
8`80HD@R00h0Hd/Y069::01RBRP0H4PV05m79@1NAR@0GDDS05a48P1NAR80G4DS05]48P1HA2<0ET<S
05918`80D44T0P1E@R8205A18@0405=0801B?al0DChN054n7PP0DSlQ1@1>?Al304dl7P80CCdS0`1<
?28304/k8@<0B3`R0P17>b4304Hj8100Ac/Q0P16>R0404@h7P80ASXP2017>b4204Di7`<0ASXP0`17
>b40201=?B<0C3`R04/k8@1:>R00Bc/Q04`l8P1>?R@0CclU201>?Al404ln80<0D3lQ0P1A@2840551
800405928@1C@b80EDDT05I69@<0E4@P0P1EAB4305I68PP0FT<Q0P1J@R00101I@R00Ed<P05I4801D
A20205=58080F4HR00@0FDLS05Y8901KBBD0FdTU0P1LBRH00`1I@R00Fd@R05i79@0206199`0905m8
9P1MAR@0Fd@R05E67`1HAR00FTPR05a88`1OBB@0HDTU0080HDLT00@0HT`W065;9P1PBRD0GTPS0P1M
Ab8205i88`P0GTLU201KBBD805i79@<0GdTT0P1PBRD3065;9P0H06=;:@1UBbX0ID/X06Q<9`1ZC2H0
KDdV06m=9`1_CRD0K4h/06a>:P1]Cb/0Ke4[071C:`1aE2X0LUDY07=F:P1dEBT0MEHZ07MH;01iFRh0
Ne``07aM<@1mGS80OUlc0P1kG2d00`1lGBh0OEh_07iO<00207mP<@0A081Q<P26HCD0QV4e08EP<`26
HS80Qf<a08QT<02:IS80RfPb08IR<P27Hc<0R6@d08YV=P2;IcL0SFTi08iZ>P2?Jc/00`2@JS/208mY
>P04091Z>`2BK3d0U6ho09E_@080UG0l00<0UW4m09Mb?P2HLcl00P2IM4000`2JMD40VgI209]f@P02
09ag@`<0WGQ40P2NNDD209mjAP030:1kA`2QO4P0XWe90080Xgi:0`2SOd/20:B0C0<0YH5=00D0YX9>
0:R4D02ZQU80[8QD0:f9E@020:b8E0060:^7D`2ZQU80ZXIB0:^7D`2/R5@0[HUE0P2^RUH00`2_ReL0
/8aL0;2<G0060;2<G0P0/XeI202aRe`20;2:F`040;6;G02bS5d0/XaM0;6;G080/8YK202`ReL20:n:
EP<0/8]G0`2aS5P0102`S5`0[h]K0:n;F`2_Re/30:j:FP030:f9F@2_REX0[hUJ0080[hUJ0`2`RU/0
0`2aRe`0/8YK0;2:F`060;2:F`080:f8E02^RED0/8]G0;6<F02bSET0/HaH0;2;E`2_RUH40:n9FP<0
[XQI0P2]QeP00`2^R5T0/8YK0;:<G@020;:<G@030;6;G02`RU/0/H]N00<0/8YK00<0/8YI0:n:EP2_
RUD00P2_RU<0202[RU@0[8]E0:j;E@2_RUD0/XYF0;>:EP2dReL0]HYG202`RU/80:j9E@P0[XQK0P2]
QU/00`2]QeX0[HMH0:f7EP020:f8E0040:f8D`2]R5@0[HQD0:f8E0<0[XUE0P2_RUH0202]R5<0[HQD
0:f8E02]QeH0[8IG0:b6F@2/QEX0ZhAI0P2[QTl01P2/Qe80[8MC0:f7EP2]QeP0[XQI0:j8F`P0[8MC
202_QE<0202/Qe80ZhIA0:Z5D02YQ4l0ZXE@0:^6D@2]R5<0[XUD0P2[QU820:b7D`80[HQD0P2^RED3
0:n6DP<0[XEA0P2]Q5000`2/Qe80[HQC0:j9E0030:j9E0030:f8D`2/Qe80ZhIA00L0ZhIA202[QU88
0:j5D@P0[8MB0P2]RED01@2/R5@0ZhMC0:^7D`2[Qe<0ZXIB0080ZHEA0P2/PU000`2]Pe40[XAB0:n5
D`020;26E0040;67E@2/Qe80[8MB0:^6D@80ZXE@00<0ZHA?0:R3CP2XPdh00`2[QU420:Z5D0<0ZHA?
202ZQE020:b7D`060:^6DP2ZQE40ZXEA0:^6DP2/Qe<0[HQD202[QU880:f7F0060:^5F02[QEH0ZhEF
0:^5E02[QU80ZhIA0P2[QTl20:b7D`80ZhIB0`2ZQE40102YQ500ZhIA0:^6D@2[QU420:Z5D0<0ZHA?
0P2XPdl20:V4D0<0ZXEA00@0ZhIB0:b2D02/PU00[89@0P2]Pe430:j4DP040:n5D`2^Q580[XAB0:j4
DP<0[H=A00<0[89@0:^6DP2[QU801P2[QU880:^6D@040:^6DP2/Qe<0[8MC0:b7D`<0[HQD00<0[XUE
0:b7D`2/Qe<01P2/Qe<80:f8E0040;2;EP2_RUD0[XUD0:f8D`80[8MB0P2]R5<00`2^RE@0[HQD0:f8
E0060:f8E0030:j9E@2]R5@0ZhIB0080ZXEA00<0ZhIB0:f8E02^RED0202[QU800`2/Qe<0ZhIB0:Z5
D@020:V4D0030:Z5D@2[QU80[8MC0080ZXEA0`2[QU830:b7D`80[hI@00@0[XE?0:f4CP2]Q4h0[XE?
0P2_QU080:^6D@P0ZXEA00<0Z8=?0:V4D02ZQE400P2[QU800`2ZQE40ZHA@0:R3C`080:^6DP<0/8ID
0P2_QE<30:j4DPP0ZhEF0P2/QUD0102/Qe<0[8MB0:b7DP2/Qe020:b8CPP0ZhIA00<0[8MC0:^6DP2[
QU80102[QU80102/Qe<0/8IF0;26EP2_QE<20:n6DP030:j5C`2^QDd0[XE=0080[8MB0P2[QU430:Z5
D0040:V4C`2/Qe<0[8MC0:b7D`<0ZhIB0P2ZQE400`2]R5<0[8MB0:^6D@040:^6D@050:b7DP2]R5<0
/8ID0:n5D`2^Q5800P2]Pe400`2^Q580[hEC0;26E0030:^6DP<0[8MC0P2]R5@20:b7D`<0[HQD0`2^
RED80:b7DP<0[XUD0P2]R5<30:b7DP<0ZhIB0P2ZQE4>0:V4D080ZXEA0`2[QU820:f8E0030:b7D`2[
QU80ZXEA00/0ZHA@0P2/Qe<20:^6DP<0ZXEA00<0ZHA@0:f4D02]Q5001P2]Q5080:R3C`090:^6DP2Z
QE40Z8=?0:N2CP2VPDd0Yh9>0:R3C`2YQ500YX5=0080Yh9>00H0Z8=?0:N2CP2VPDd0YH1<0:AoB`2T
OdX20:F0B`030:J1C02WPTd0Z8=>0080ZHA?00D0ZXE@0:V4C`2YQ4l0Z8=>0:N2C@020:J1C0030:F0
B`2TOdX0Y7m:00@0YX5<0P2TOdX90:F0C0P0YX5=202SOd/0102VPDd0YH1<0:F0C02UP4`20:AoB`80
Xgi:0P2SOTL00`2RODP0XWe90:9lB`020:5kC0030:5kCP2TNdL0Y7]700<0Y7]70`2SNTH20:EkB@80
Y7Y80`2SNDL0102RN4H0XgU70:9hAP2QMdD20:1fA00<0:5gA@2RN4H0XgU709egBP2MMdP0WWQ909mi
B02PNdL0XGa70:5lA@2RODH0WgU:0`2PNT/20:5kC080XWa=0`2QNdh[ooooo`00:_ooool00`2EJSd0
U6Tl09=X>`02099W>P0309AY?02FJch0Uf`o0080Uf/n00`0V6`o09M[?P2FJSd0U6Pk095U>02@I3L0
UV/f09I[>02FJST0UVXk09IZ?@2FJD0209IY@P<0V6Tm0P2GJ3`309IW>`P0UVXi0P2FJch209EZ?@@0
U6Tl202IKD001P2GJcX0V6`k09Q/>`2IKC`0VVhm09]_?P80W70o00H0V6`m09U]?P2IKC`0VFhk09Y_
?02JKcX209]`>@L0VVll0P2IKS/0602KL3d0VVll09U^>`2HKCX0VFhk09]`?@2MLSl0WW=009id>02M
LcT0W78h09]`>@2JKcX0Vg0m09ea@02NLT40W70o09ea@02OLd80X7A30:5eA02PM4<0Wg=209ib@@P0
XGI30`2MM40409ie@@0309mf@P2QMT<0XGI30080XGI3302RMd@60:=hA@80XWM40P2TNdL30:=jAP<0
XWU500@0X7I40:5gA@2SNDL0YG]90P2VO4X20:EkB@P0YWa:0P2YOT/20:QmBP80Yga90P2VNdP0202V
O4X0YG]90:=iA`2RN4H0XGM50:9hAP2SNDL0Y7Y80P2QN4@20:1g@`@0WgI20P2NM480102MLd40W790
09]a?`2KLCl209Y`?P0909Q]>P2GJcX0UV`j09A/>`2AJc`0SfXm08iY?@2<JSd0RfHi0080RVDh00<0
RF@g08QS=P27HSD00P26HC@00`1mF2/0OeX]089M<00208AO<P0308=N<@21G2l0OeX]0080OUPa00<0
OEL`07aF;`1jE2d00P1iDb`207MA:P0307AA:`1eDR`0MU<]0080Me@^00<0MU<]07AA:`1cD2X0201`
CBL00`1/BbX0JTTX06U89`0306M69@0406Q79P1YB2L0ITLX06I7:0<0IDHW0`1TABH2065;9P04069:
9P1RB2D0HdHT06=58`80ID@S00@0ITPV06M99`1WBBL0J4XX0P1YBbT206Y<:P80JTXS00L0Jd/T06e=
9P1^CRL0KdlX071@:@1aDBX0ME0V0080MU4W00D0Me8X07QC:@1iE2X0NE@Z07YE:`0207]F:@80O5LZ
00@0OEP[07iI;01oFRd0OeX]0P20FR/2085K;080PU`]0P23GBh00`26H3<0QElb08AN<@0308=M<003
08AN<@25Gc80QV0a00l0QV0a00<0Q5h_08EO<026H3400P28HS<00`26H340QEl`08AN;`0308IP<@03
08MQ<P28HS<0R68c0080RF<d2027HC@808MQ<P<0R68c0P29Hc@308QR<`80QEl`0P26H34408MQ<P03
08QR<`29I300R6<_00D0R6<_00<0RF@`08QR=@28HSD01P28HSD808MQ=080RF<d1P28HS<808UP<P03
08=N<@24Gc80QV4d0080Qf8e00<0QV4d08EP<`24Gc802026H34608=N<@80Q5lb2@24H30208=O;`80
PUh^0P21GBd00`20G2`0PUd`089M<003085L;`<0P5/^00<0Pehd089M<`22GC<00`21G382089M<`0;
089M<021G2l0P5/^07mJ;@1nFB`0OEP[07aG:P1kERT0OeX`07iI;`1lEbd00P1kER`00`1lEbd0OUT_
07mJ<00807]H;PP0OUT_0`1kF2h207YG;@<0NEH/00P0M5L]07IF;@1fERd0MeH]07QE;@1iDb`0NU</
07UB:`T0Le</0P1bDR/3075A:P<0L50Y0`1_DRX00`1^DBT0KE0X06e@:00206a?9`80JT`X0P1YBbL3
06Q:9P0406U;9`1VC2T0IT`Y06E;:080I4XW00<0HdTV06989@1RB2D00P1SBBP0701RB2L0HDLV0616
9@1OAB@0GT@S05e38P1QBRX0H4TY05m8:01MARH0Fd@T05U28P1H@B40Ed0P05Y2801I@R80F44Q05E0
8@1C@280D3lS04hn901=?B<0DT4S05508P1@?b40CchP04hm7`1<>ad204/j70<0CSdQ101??R800`1@
?b<0BS/N04Xk7P0304/l7`<0C3dP0P1=?B<0101<?280Bc/Q04/k8@1:>R0204Ti7`80B3`R0P17>b42
04Hj8080ACTO4017>b4804Di7`P0Ac/Q1P16>R0204Lk8@0304dm8`1<?280Bc/Q0080BSXP00<0Bc/Q
04dm8`1>?R@0201=?Ql304`k7@0904dl7P1>?Al0CchP050o8@1A@280DT4S05=38P1B@R40D40O0080
CclN00<0DT8Q05E5901GAbH00P1E@al205I48080EdDQ0P1HAR8405Q48@P0Ed<P0`1FA2005`1DA200
ED<O05I4801GAB40F4HR05Y8901LBRH0GD/W05i<:01I@R00FT<Q05a58`1NAbD0GdPV05i79@1LAB<0
Fd@R05E7801GB240F4TR05Y88P1LB2<0GTPS0080GdLS00H0HT`W065;9P1PBRD0GdTT05i88`1MAb82
05a68@P0GTLU201KBBD805e690<0GdTT0`1PBRD2065;9P0E069::01SBbT0I4XW06E;9P1XC2D0JTdU
06e=9P1]CB@0JT`Z06]=:@1/CRX0KDlY06mB:P1`DbT0LE@X079E:@1dEBT0MEHZ07QI;@1jFbl0Ne``
00<0O5da0P1iFR/0101jFb`0O5d^07eN;`1nGc0207mP<@0A08AO<`25H3@0QF0c08IR<P27Hc40R6@`
08UU<@29IS00Q60`08EQ<@27Hc<0RFDe08]W=`2=JCT0Sf/k091/?02AJc`00P2?JCX01P2>J3T0SFLh
08iX>@2@JS/0U6ho09I`@@80U6lk00@0UG0l09Ia?@2GLSh0V7<o0P2IM40209Ye@@80VgI20`2LMd<0
1P2MN4@0WWU509iiA@2ONTH0X7]70:5lB080XWe900@0Xgi:0:9nBP2ROTX0Xgm;0P2TP4`01`2UPDd0
YX9>0:J2CP2UPDd0Yh=?0:V5D@2[Qe<00P2/R5@00`2[Qe<0ZXIB0:V5D@020:Z6DP030:^7D`2/R5@0
[HUE0080[XYF102_Re/40;2<G0P0/XeI202`RU/00`2^R5T0/8YK0;:<G@020;B>G`030;:<G@2`RU/0
[XQI00P0/8]G0P2_RUH30;2;E`<0/HaH202_Re/20:j8F@040:n9FP2`RU/0/8YK0;6;G080/XaM0`2`
S5`40:n;F`040:j:FP2/Qe<0[HQD0:n:EP<0/HaH00L0/8]G0:n:EP2aRe`0/H]L0;2:F`2_REX0[XQI
0080[HMH00@0[8IG0:f7F02^R5T0/8YK0`2bS5d0102aRe`0/8YK0;:<G`2bS5d20;6;G0030;2:F@2`
ReL0[hYE0080[XUB0P2/ReH00`2^RUH0/8]G0;::E`020;B:F0030;F9F02`RU/0/8YK00H0/8YK202_
RUH80:j8F@80[XQK00<0[XQI0:j8E`2^RED00P2^RE@01`2^RE80ZhIB0:b7D`2/Qe<0[HQD0:j9E@2_
RUH00P2`ReL01P2]R540[HQC0:b7DP2[QU80ZXAC0:Z4E@80ZH=F0P2[QTl01P2/Qe80[8MC0:f7EP2]
QeP0[XQI0:j8F`P0[8MC202_QE<00`2ZQE00ZHA?0:R3CP020:R3CP030:Z5D02[QU40[HQC0080ZhIB
0P2/Qe<20:f8E080[XUE0P2_QU860:j5D@030:b7DP2]R5<0[HQC00@0[HQC00<0[8MB0:V4D02YQ500
1P2YQ5080:^6DP030:f4D02^QE40[XEA0080[XEA0`2_QU80102]R5<0[8MB0:b7DP2/Qe830:^6D@04
0:Z5D02_RUD0[XUD0:f8D`80[8MB00@0ZhIA0:Z5D02YQ4l0Z8=>0`2]Pe400`2^Q580[hEC0:n5D`02
0;26E0030:b7DP2[QU40ZhIA0080ZXE@0P2YQ4l00`2XPdh0ZXE@0:Z5D00>0:Z5D0D0ZhIB0P2/Qe<0
0`2]R5@0ZhIB0:^6DP060:^6DPP0[HMH00H0ZhEH0:^5EP2[QEH0ZhED0:^6DP2[QU420:^6C`<0ZhIB
0`2ZQE420:V4D0040:Z5D02YQ4l0ZHA?0:V4C`80Z8=>0P2WPTd30:V4D0<0ZXEA0P2[QU830:b2D080
[H=A2`2^Q58@0:^6DP@0[8MC302]R5@80:j9E@030;:=F@2`ReL0[HQD00<0ZhIB00<0[8MC0:j9E@2`
ReL0202^RED00`2^R5L0[HMF0:b6E@020:Z4D`030:b6E@2]QeH0[XQG0080[HQD102/Qe<@0:^6DP80
[8MC00<0/HQD0:n6DP2]Q5000P2[PTh00`2]Q500[hIB0;68E0080:^6DPP0ZXEA00<0ZHA@0:Z5D@2Z
QE40102ZQE400`2YQ500ZhIB0:^6DP060:^6DP<0/HME0P2`QU@30:n5D`P0ZhEF0P2/QUD0102/Qe<0
[8MB0:b7DP2/Qe020:b8CPP0ZhIA00<0[HQD0:b7D`2[QU800P2ZQE402@2[QU80[8MC0:f8E02bR5P0
/HMG0;67E@2`Qe<0[hIB0:j5C`020:f4C0<0[8MB0P2[QU430:Z5D0<0[8MC0`2[QU820:Z5D@030:f8
D`2/Qe80[8MB00D0[8MB00<0[HQC0:n5D`2^Q5801@2^Q5800`2_QE<0[8MC0:b7D`040:b7D`80[HQD
1P2[QU820:b7D`P0[8MB0P2^RE@30:f8D`<0[8MB0`2[QU820:Z5D@/0ZHA@0P2XPdl0102YQ500ZXEA
0:Z5D@2[QU820:b7D`060:j9E@2]R5@0[8MC0:^6DP2ZQE40Z8=?0P2WPTh80:R3C`<0ZhIB0`2ZQE42
0:V4D0P0[H=A202WPTh0202/Qe<0ZXEA0:R3C`2WPTh0YX5=0:N2CP2XPdl0ZHA@102WPTh20:J1C@80
YH1<0P2UP4/00`2VPD`0Yh9=0:R3CP020:V4C`090:Z5D02[QU40ZXE@0:V4C`2XPdh0Yh9=0:J1C02U
P4/0Y7m:00P0YH1;2@2UP4`80:J1C@P0Y7m;0`2UP4`20:AoB`<0Xgi:0P2SOTL00`2RODP0XWe90:9l
B`020:9lC@030:9lC`2UO4P0YGa800@0Y7]70P2SNTH30:AjB0<0XgU70P2RN4H20:9jA`@0XGU60P2R
NTL0202MMdX0WWQ909ihB@2ONDP0WgY60:1kAP2PNd@0XGa50`2PNT/20:5kC0<0XWa=0`2OND`[oooo
o`00:_ooool00`2EJSd0U6Tl09=X>`02099W>P0309AY?02FJch0Uf`o0080Uf/n00H0V6`o09M[?P2F
JSd0U6Pk095U>02@I3L209IZ>@80UVXk00@0UVXm09IY?`2FJCl0UVTo0`2FJSd209EY?0<0U6Pk202F
JST209I[?P80UFXm102DJC`809U]@080V6`k00<0VFdl09Y^?@2KKch00P2LL3l02@2MLD00VFdn09U]
?P2JKSd0VVll09]`?@2KL3/0Vg0i09aa>P0709Y_?080Vg0m00<0W74n09]`?@2JKc`00P2IKS/04`2K
L3d0W74n09ic@02NM3P0WG<i09ab>02KL3T0Vg0k09aa?P2NLT40Wg=209a`@@2NLT<0X7A50:5eAP2R
MTL0XGE60:1dA@2OLd@0202QMT<309ed@00309ie@@2OMT80WgI20080X7M3102RMd@40:5f@`X0XWM4
1P2SN4D30:AkA`<0XgY60P2RNDD0102PMT@0XWQ60:AjB02VO4X20:MmB`030:IlBP2UNdT0YWa:00L0
YWa:0`2YOT/20:QmBP<0Yga900<0YWa:0:EkB@2SNDL00`2QMdD0102RN4H0XgU70:1g@`2PMd<309mf
@P<0WWE10P2MLd4209ab@00<09]a?`2JL3h0VFlm09U_?@2FKCT0UV`j09A/>@2AJcX0Sf/k08iY?02<
JSd0RVTl0P2:ICP01029I3L0R6<f08MR=@26HC@208EP<`0=081K;`21G300Q5lc08IQ=@27HSH0QF0d
08=N<P22GC40OUPa07eG<01lERl0NU@]07UC;00407MA:P0307=@:P1dDB/0MU<]0080Me@^00<0ME8/
07AA:`1cD2X0201`CBL0201[BRT0JTTX06Q79P1WARD0ITDT06M69@1XAbH0JDPW0`1UARL306A59P80
Hd@U0P1PBRD0101QBBD0HTPU06=6901TAR@206I59080HdDS00`0I4HT06E79@1VB2H0IdTW06Q::01Y
BbT0Jd/T06a<9@1]CBH0KThW06m?:01aDBX2079B:`0507IA9@1gDRH0Me8V07QC9`1jEBT00P1kERX0
2@1lEb/0NeHY07]F:@1lEbX0OEP[07iI;01oFRd0P5/^085L;`0408AK;@@0QE`^00P0Qf4d08EO<P24
GS40PU`_08=M<024GS40QV0c08MQ=100QV0a00<0Q5h_08EO<026H3400P28HS<00`26H340QEl`08AN
;`0308IP<@@0Qf4b00<0R68c08MQ=027HC@01P27HC@808MQ<P0308US=028HS<0R68c00@0R68c00<0
RF<d08EO<025Gc000P26H34408MQ<P0408QR<`28Hbl0R6<_08QS;`80RF@`0`28Hbl408QR=@@0RF<f
2027HC@608QR<`80RF<d2027HC800`23GS40Q5lb08EP<`0208IQ=00308EP<`23GS40PUd`00P0QV0a
1P24Gc8208=N<@`0Pel_1022GRh3089M<0<0PE`_0P20Fbh00`20Fc40PE`b085L<P03089M<`80PE`b
00/0PUd`085L;`20Fbh0OeX]07iI;01mF2/0O5LZ07]F:@1oFS00OUT_07eH;P0207aG;@0307eH;P1n
FBl0OeX`00P0NeP^201mF2h307]H;P80NUL]0`1iER`01P1fFBl0MeL^07IF;@1fEB`0Me@/07QB:`80
NE8[2@1cDb`3075A:P<0L50Y0P1_CbP00`1]DBT0K50X06a@:00206a@:0<0JdlW0`1YBbL206Q:9P03
06M99@1VB2@0IDLS0080Hd/W00@0HTXV06599@1PB2@0GdLS0P1NAR8205m69`0405i59P1MA2D0G4<T
05a39080Fd8S00T0G4LX05]69`1JABH0F4<T05I18P1D?b00DchO058m7P1G?Ql00P1E?Ql00`1B?B00
D3`Q04hm8`0204`l8`08050o8`1??R80CSdQ04dl801<>al0BcXN04Xi7@19>1`304`k8@0304dl8P1>
?B<0CSdS0080CchT0`18>Ql304Tk8080BS`Q0P1<?280101;>b40BSXP04Xj8019>Al204Ph7P<0Ac/Q
0P16>R0304Di7a00ASXP2015>Al804Hj8080Ac/Q1P16>R000`1>?R@0CCdS04/k8@0204Xj800304/k
8@1<?280CCdS00P0C3lO0`1;>Q`03P1=?1h0CSdO04ln801A@280DT4S05=2901DA2<0DT8Q05107`1>
?Qd0CclN0551801C@b80EDDT0`1F@Ql205M380<0F4@Q00<0F4HR05M58@1GAB400P1FA20205E37`03
05A27P1DA200ET@P0080ET@P101G@b001P1C@Ad0E48N05E37`1GAB40FDLS05]99@80GD/W00@0FD8P
05Y38@1KA280G4DS0P1MAR@0101LAB<0Fd@R05E98@1FB24205M88@0405U78@1KAb80GTPS05i88`@0
GdTT00@0GTPS05e78P1LAR40G4HQ201NAbD805]99@P0GDHT0P1NB2<305m990<0H4XU00h0H4TW065:
:01RBRH0I4XU06M;901XC2@0JTdU06Y=8`1YBbT0JD/W06Y<:01/CRP0KE0X06mB:080L5<W00@0LU<W
07AE:@1gF2`0NEX^0P1kG300201jFbl0NEX^07MH:@1hFBX0NEX[07YK;01lGBh0OUl`0P1oH34208=N
<P0308AO<P25HC40QV8`0080Qf<_00X0R6D_08AP<025HC40QV8b08QT=02;IcL0SFTi08iZ>P2?Jc/0
T6Xk0P2>J3T01P2=IcP0S6Hg08eW>02?JCX0Tfdn09E_@080Tfhj00@0U6lk09E`?02FLCd0Ug8n0P2H
Lcl0102IM400VWE109Ye@@2JMD4209]f@P80W7M300H0WGQ409iiA@2NNDD0WgY60:1kA`2QO4P20:9m
B@050:5mB@2ROTX0XWi:0:=oB`2UPDd00P2VPTh01@2WPdl0Y81<0:J2CP2XQ500ZXIB0080ZhMC00L0
ZXIB0:V5D@2YQE40ZHEA0:Z6DP2[Qe<0[8QD0080[HUE00@0[XYF0:f9F@2^RUX0[XYJ0P2_Re/20;2<
G0030;6=G@2bSET0/XeI00H0/XeI2@2_REX01`2aRe`0/heN0;F?H02eSf00/heN0;6;G02_REX0202`
ReL20:n:EP<0/8]G0`2aS5P40:n;F`@0/8aL00D0[XQI0:n9FP2_REX0/8YK0;6;G0020;:<G@030;>=
GP2aSEd0/HeM0080/8aL00d0[h]K0:j:FP2^RUX0[XYJ0:b7D`2]R5@0[hYF0;2;E`2aS5P0/8]G0:n:
EP2^RED0/XaM0080/H]L00<0/8YK0:n9FP2^R5T00`2]QeP00`2^R5T0/8YK0;:<G@020;:<G@030;6;
G02`RU/0/heP00<0/XaM00D0/H]J0;2;E`2_RUD0[hYC0:j9DP020:b;F0060:n;F@2`RUT0/h]J0;B:
FP2eRe/0]XYK202`RU/80:n:EPP0[XQG0P2^R5T01`2^R5L0[XUE0:j9E02^RE@0[XUB0:j:D02[QU80
0P2/Qe<00`2]R5@0[XUE0:n:EP020;2;E`080:f9C`2/Qe00[8MB0:^6D@2ZQE40ZH=B0:V3E02XPU<2
0:^6C`060:b7DP2/Qe<0[HMF0:f7F02^R5T0[XQK202]R5@80:j4DP080:Z5D02YQ4l0Z8=>0:N2C@2X
Pdh0ZHA?0:^6D@2/Qe820:^6DP80[8MC0P2]R5@20:j9E@H0[XEA0P2_QU800`2]R5<0[8MB0:b7DP04
0:b7DP030:f8D`2YPe80ZH=B00H0ZH=B202[QU830:f4D0030:j5D@2_QU80[hIB0080/8MC0`2/Qe82
0:^6D@<0ZXE@0P2`R5@01@2_Qe<0[XIB0:j6DP2/Q500Zh=?0080ZX9>00<0[H=A0:j4DP2^Q5800P2^
Q5830:n5D`80ZhIA102ZQE020:V4Ca00ZXE@00@0ZHA@0:Z5D@2[QU80ZhIB102/Qe<80:^6DPP0[8IG
00H0ZhEH0:^5EP2[QEH0ZhED0:^6DP2[QU420:^6C`80ZhIB0`2ZQE430:V4D0<0ZHA?0P2XPdh30:N2
C@80ZHA@0`2ZQE430:^6DP<0[89@0P2]Pe470:j4DP@0[hEC202/Qe<80:b6E@@0[HQD102/Qe<@0:j9
E@030;:<F`2`RUT0[HMF00<0ZhED00<0[8IE0:j8E`2`RUT0202^RED00`2_REX0[HMH0:b6E`020:^5
EP040:b6E`2]QeP0[hUJ0:n:EP80[XUE0P2]R5@20:b7D`<0ZhIB102/Qe<20:^6DP80[8MC1P2[QU80
0`2aR5@0[hIB0:f4D0020:^2CP030:f4D02_QU80/HQD00P0[8IE202ZQE400`2[QU80ZXEA0:Z5D@04
0:Z5D@030:^6DP2/Qe<0[8MC00H0[8MC0`2aQeD20;26E0<0[hEC202[QEH20:^5E0040:^6DP2[QU40
ZhIA0:^6C`80ZhM=202[QU400`2]R5@0[8MC0:Z5D@020:V4D0030:Z5D@2/Qe<0[HQD0080/XQH00H0
/HME0;27D`2_QU80[XE?0:j5C@2]Q4`20:f8D`80[8MB0P2[QU420:Z5D0<0[8MC0`2[QU820:Z5D@03
0:b7DP2]R5<0[HQC00D0[HQC00@0[8MB0:j4DP2^Q580[XAB0P2_QE<30:j4DPH0[HQD0P2/Qe<20:^6
DPH0ZXEA202[QU430:f8D`<0[8MB0P2[QU430:^6DP80ZXEA2`2YQ5020:R3C`040:V4D02ZQE40ZXEA
0:^6DP80[8MC0P2]R5@01P2/Qe<0ZXEA0:V4D02XPdl0Yh9>0:J1C@P0Z8=?0P2[QU830:Z5D@<0ZHA@
202]Pe<80:N2CP030:b7D`2[QU80ZHA@0080Yh9>00@0Z8=?0:V4D02ZQE40Z8=?0P2WPTh20:J1C@<0
YH1<00H0YH1;0:J1C02VPD`0Yh9=0:R3CP2YQ4l20:Z5D0080:^6D@2ZQE00ZHA?0:R3CP2WPTd0YX5<
0:F0B`2TOdX80:F0B`T0YH1<202VPDd80:InB`80YH1<0P2TOd/20:=nBP80XWe90P2RODH00`2SOTT0
Xgi:0:=mC0020:=mCP030:=mD02VODT0YWe90080YGa80P2TNdL20:=jAP80Y7Y80`2SNDL30:9hAP80
X7]7102QO4P20:1kA`0609ihB`2NN4T0WWQ909ihA`2ONTH0WgY50P2ONT<20:1jB`80XG]<0P2RO4d2
0:=mCP<0WgU<:oooool002[ooooo00<0UFXm09AY?02CJ3/00P2BIcX01@2DJC`0UV/n09M/?`2EJC`0
UVXm0080Uf/n00@0UVXm09EY?02BIST0TFDh202FJSd809AY?0P0UVXi0P2GK3l309I[?P<0UFXm202H
K3l409Y^?@<0Vfln00T0W70o09Y^?`2JKSl0Vfln09]`?@2LLCh0W74l09aa>P2MLS/0102JKc`309]`
?@80W74n00<0WW=009eb?`2LLCh00P2KL3d03P2LLCh0WG8o09ic@02NM3P0WG<i09ab>02KL3T0W74l
09eb?`2OLd80X7A309eaA02OLdH0X7A70`2RMTT00`2QMDP0X7A70:1e@P070:1e@P0609ac?`2MM400
WGA009ie@@2OMT80X7M30P2QN4@0102SN4D0XWM40:9gA02RMd@30:5f@`030:1e@P2RMd@0XWM400T0
XWM40`2SN4D20:AiAP80YGa80P2TNdL30:=jAP050:9iA@2QMdD0XWQ60:AjB02VO4X00P2WOD/:0:Il
BP040:YoC02YOT/0ZGi;0:UnB`80Z7e:0P2WO4T0202UNdT0Y7Y80:9hAP2QMdD0X7I40:5gA@2RN4H0
XgU70`2OMT8209ie@@<0WGA000H0WG=109ab@02LLT00Vg4o09Y`?P2IKcd209Q^?00609E]>@2DK3T0
TVdi091/>P2?Jc/0S6Xl0P2:JC`208YU>00308UT=`28HcH0Qf8e0080QV4d00<0QF0c08=N=024GcD0
0`25H3H02024GcD0Pehd08=N=01oFC80OEL`07]E;P1iDb`0N58[101gDBX00`1dDB/0ME8/07IC;@02
07IC;@0307AA:`1bCbT0LDhX00P0Kd`V00<0K4/Z06]::@1YB2L00`1WARD206U89`<0IDHW0P1TABH3
06=49@80GDLR00@0GdLS0657901TAbD0ITPV0P1YB2L206948P0>06=58`1UAbD0ITPV06M99`1XBRP0
JD/Y06a<9@1]CBH0KThW06m?:01aDBX0LU8[07=C;01dE2d207MB9@0<07QC9P1jEBP0NeHY07aG:P1m
F2/0OUT/07]F:@1lEbX0OEP[07iI;01oFRd0PE`_0P22GC0708IK;P0408ML;`27HC@0QV0c08=M<080
PU`_00<0QElb08MQ=029HcH04026H3400`24GRl0QEl`08IP<@0208QR<`0308IP<@25Gc00Q5h_00P0
QV0a2027HC@808QR<`0308YT=@29Hc@0R68c0080Qf4b00<0R68c08US=02:I3D00P26H34208MQ<P80
R68c0`29Hc@00`27HRh0R6<_08UT<00208YU<@0308UT<028Hbl0Qf8^00<0R68e0P29HcH308YT=`P0
Qf4d0P27HC8308QR<`<0RF<d2026HS800`23GS40Q5lb08EP<`0208IQ=00308AO<P22GC00PE`_00P0
QEl`0`25H3<308AO<P80Peha4023Gbl208=N<@80PUd`0`21G2l01020Fbh0OEP^07iI;`20Fc43085L
<P80P5/a00D0PE`_081K;P20Fbh0OeX]07iI;00207eH:`0407aG:P20Fc40OeX`07eH;P80O5L]00<0
OEP^07mJ<020Fc40201kF2h807eH;P<0NeP^0P1jEbd307UF;00607MJ<01hF2l0MUH]07IE;01fDb/0
N58[0P1iDR/9079B:`<0LE4Z0P1`D2T306m?:0P0JdlW00h0IdTU06Q:9P1XBRH0J4XV06M99@1UAb<0
I4HR06=58@1QBRP0H4TW05m89P1NAbD0GDHT05]48P80FT<Q0P1KA2D205Y39080FD8S0P1H@B801@1G
A2H0ET<U05E2901D@B<0Dd0R0080DChP00L0D3dO05Dl7P1D?Ah0Dc/O054l8@1?>b80CC/S0080Bc/T
0P1=?B<0101<?280Bc/Q04Xj801:>R0204Ti7`80BCTP0P1:>R40101;>b80C3`S04dm901=?B@304Hj
80D0ACTO0`1:>R0304Ti7`80B3PN0P17>b4204Hj80<0ACTO00<0A3PN04Hj8016>R003P16>R0204@h
7P@0ASXP0P14>1h804Hj80<0Ac/Q0`16>R0204Di7`0304hn901=?B<0Bc/Q0080BCTO00<0BSXP04/k
8@1<?280201:?al204`k7@0504dl7P1>?Al0CchP050o8@1B@B<00P1C@R@00`1B@R40DD4P05107`02
05107`040551801B@R40DT8Q05M07P<0F44O0P1I@R0205Y38@80ETHR00<0EDDQ05A4801C@al00P1B
@Qh01`1A@Ad0DdDP05=5801DA200ET@P05M3801I@R000P1J@R00201C@Ad0E48N05E37`1FA200F4HR
05Y8901KBBD0G4XV0P1I@R000`1J@b40Fd@R05]48P0305]48P80ETXR00T0ETPQ05I7801FAb00FDLQ
05]78P1LB2<0G4HQ05e78P1NB2<00P1OBB@00`1NB2<0GDLR05a68@0805i79@P0FdTU201LAB<305i8
8`80GdTT0`1PBRD0601MBBH0GTXW061:9@1RBR@0I4/S06M;8`1XC2@0JD`R06Q::01XBRH0JD/W06Y<
9P1/CbL0KE0V06iA9@1_DRH0L54U079C9`1eERX0N5T]07UJ;P1hFBd0MUL[07EF:P80MULX01H0N5TZ
07UJ:`1kG2d0OEh_07iO<01oH340PE``089M<@24Gc80QF4a08IR<027Hbl0QV8^08IS;@24H300QF4a
08IR<P28I3@0RVHf08aX>02=JCT0SVXj0`2=IcP01`2<ISL0SFLh08iX>@2?JCX0TF/l099/?@2BKCT0
0P2CKSX00`2DKc/0UG0l09Ia?@0209Mb?P0409Qc?`2IM400VGA009Ud@080VWE10P2KMT8209ehA003
09iiA@2ONTH0X7]70080XGa800d0XWe90:1lB02QODT0XWi:0:=oB`2UPDd0YX9>0:N3C`2XQ500Xgm;
0:F1C@2WPdl0ZHEA0080ZXIB00<0ZHEA0:R4D02XQ5000P2YQE400`2ZQU80ZhMC0:b8E0020:f9E@06
0:b8F02]RET0[HUI0:j:FP2_Re/0/8aL0P2aSEd80;:=F@P0/8YK00<0/H]L0;:<G@2cSEh00`2cSEh0
0`2bS5d0/H]L0;2;E`070;2;E`80[hYF0`2`ReL30;6<F0<0[h]K0P2`S5`30;6=G@<0/8YK0`2aRe`2
0;:<G@060;2>GP2_SEd0[heM0:j<G02]Re/0[8YJ0P2[RET00`2[QU80[HQD0:j9E@030;2;E`030:n:
EP2^RED0/H]L00<0/8YK102_REX00`2]QeP0[XQI0;2:F`030;:<G@040;6;G02`RU/0/XaO0;:<G@80
/H]L00<0/H]J0;6<F02`ReH00P2`Re@20:f;F`030:n;F`2aRe`0/hYL0080]HYM00<0]XYM0;2:F`2`
RU/01P2`RU/80;2;E`P0[XUE0P2^R5L0102^RED0[XUD0:j9E02^RE820:j:D0<0[HQD0`2^RED20:n:
EP80[8Q>00@0[8M@0:^6D@2[QU40ZhIB0P2ZQ5<20:^6C`060:b7DP2/Qe<0[HMF0:f7F02^R5T0[XQK
202]R5@80:j4DP80ZXE@0`2XPdh00`2ZQE00[8MB0:f8D`020:^6DP80[8MC0P2]R5@20:j9E@80[HA@
0`2^QE430:n6DP030:f8D`2/Qe80ZhIA00<0ZhIA00<0[8MB0:f8D`2[QEH01`2[QEH80:^6DP80[8=?
00<0[HA@0:j5D@2_QU800P2`Qe<0102aR5@0ZXE@0:Z5D02ZQE050:^6D@030;27D@2_QU00[hI@0080
[XE?00@0[HA>0:b3C@2/Pdd0Zh9<202^Q5880:Z5D0<0ZHA?0P2ZQE030:^6D@P0ZXE@00@0Z8=?0:V4
D02ZQE40[8MC0`2]R5@00`2/Qe<0ZhIB0:^6DP060:^6DPP0[8IG00H0ZhEH0:^5EP2[QEH0ZhED0:^6
DP2[QU420:^6C`040:^6DP2ZQE40ZXEA0:Z5D@80ZHA@0P2XPdl20:Z5D080ZHA?0`2XPdh00`2WPTd0
ZHA@0:Z5D@020:Z5D@80ZhIB0P2/Qe<30:b2D080[H=A1P2^Q5820:n5D`<0/8ID202/Qe<80:b6E`04
0:j9E@2]R5@0[HQD0:f8E0<0[8MC00<0ZhIB0:n:EP2_RUH01P2_RUH80:j9E@040;2:F`2_REX0[XQI
0:f7F080[8IG0P2]QeP00`2^R5T0[XUE0:j9E@060:j9E@030:n9G02^R5/0[8II0080ZhEH00<0[8II
0:j8F`2_RE`00P2`ReL0102_RUH0[XUE0:f8E02]R5@20:b7D`80ZhIB00@0[8MC0:f8E02]R5@0[8MC
0P2[QU830:b7D`<0ZhIB0P2ZQE420:n5D`040:j4DP2]Pe40[H=A0:j4DP80[hEC202/QUL80:Z5D@03
0:b7D`2[QU80ZXEA0080ZHA@00<0ZXEA0:^6DP2/Qe<0202/Qe<30;26E080[hEC0`2^Q5880:^5EP80
ZhED00@0ZhIB0:^6D@2[QU40ZhI?0P2[Qdd80:^6D@030:j9E@2]R5@0ZXEA0080Z8=?00<0ZXEA0:f8
E02^RED00P2aQeL0102aQeD0/8MC0;27D`2`Qe420:n6CP<0[HQC0P2/Qe830:^6D@<0[8MC0`2[QU82
0:Z5D@030:b7DP2]R5<0[XUD00@0[XUD00D0[HQC0:b7DP2]Pe40[XAB0:n5D`020;26E0030:n5D`2^
Q580[H=A00<0[XUE0`2]R5@20:b7D`@0ZhIB0P2ZQE420:V4D0P0ZhIA0`2]R5<20:b7DP<0ZhIA0`2[
QU820:Z5D@<0ZHA@202XPdl30:V4D080ZXEA1P2[QU800`2ZQE40ZHA@0:R3C`020:N2CPP0ZHA@00@0
ZhIB0:Z5D@2ZQE40ZXEA0P2YQ5020:R3C`P0[H9E202XPdl02`2/Qe<0ZhIB0:V4D02XPdl0Yh9>0:R3
C`2YQ500ZXEA0:V4D02XPdl0YX5=00<0YH1<0P2VPDd20:J1C0030:N2C@2XPdh0ZHA?0080ZXE@00H0
ZhIA0:Z5D02YQ4l0ZHA?0:R3CP2WPTd20:J1C0030:F0B`2VPD`0YX5<00@0Y7m:0P2VPD`90:F0C0P0
YX5=202WOD/30:AoB`80Xgi:0`2RODT20:9mAP030:=nB@2SOTX0Xge<0080Y7i?00D0Y7iA0:MnBP2W
OTX0YWe90:ElB0020:AkA`80XgY600@0Y7Y80:=iA`2SNDL0XgU70P2RN4H20:5gA@0309mkA`2PO4P0
XGe90080XWi:00@0XGe90:1lB02ONdL0WWQ;0P2NN4T00`2NN4L0WWU509iiA00209ii@P<0XG]<0P2R
O4d30:=mCP<0XG]>:oooool002[ooooo00<0UFXm09AY?02CJ3/00P2BIcX01P2DJC`0UV/n09M/?`2C
IcX0U6Pk09IZ?@80Uf/n00<0UVXm09AX>`2CIcX00`2FJCl01@2FJSd0UVXk09IZ>`2FJS/0UVXi0080
TFPj00@0TVTk09=Z?02CJS`0U6/m0P2EK3h809IZ>@<0V6e00`2GK3l209I[?PP0Uf/n0`2LL3l209]_
?P<0VVhm0P2KKd00102KKch0W74n09aa?P2MLSd209eb>`0309U^>`2JKc`0VVll00<0Vg0m0P2LLCh0
502MLSl0XGI309md@@2NLd00WG8o09aa?P2MLSl0WgA10:1e@P2NM3P0WG<i09ab>02KL3T0W74l09ic
@02PM4<0XGE409ibA@2OLdH0XGE80P2SMdX00`2RMTT0XGE80:1dA`0809ic@00509ac?`2MM400WGA0
09ie@@2PMd<00P2QN4@00`2RNDD0XgQ50:=hA@020:9gA080XGI30P2PMD880:9gA080XGI30P2RMd@0
102SN4D0Y7U60:AiAP2TNDH30:ElB080Y7]70`2SNTH01@2QMdD0XWQ60:EkB@2WOD/0Z7i<0080Yge;
2@2VO4X20:YoC0<0ZGi;0`2XODX00`2UNdT0Y7Y80:9hAP020:1fA0030:5gA@2RN4H0XgU700<0WWE1
0P2MM40309ac?`0609ab@02KLCl0Vg4o09Y`?P2IKcd0V6hl0P2GKC/01P2DK3P0TVdi095/>02?JcT0
S6Xj08][?080RFXl00H0RfHi08YU>02:ICP0RF@g08QS=P27HSD208IQ=00408AO=@23GS@0PUdc081K
<@<0OeX`00D0P5/a081J<`1oFC80O5H_07UC;00407QB:`0807UC;01fDbd0MU<]07MD;P1fDbd0ME8/
07=@:P1`CBL906m<9P0306e<:`1/BbX0JTTX0080J4LV00@0JDPW06Y9:01[BRT0IDHW0`1TABH206=4
9@80HT<T01h0FT@O05]5801MAB40H4HS06E89P1XBRP0JdXY06a;:P1TAR@0IDLU06I89P1XBRP0JD/Y
06]=:`1/CR`0KDl]06e=9P1^CRL0KdlX071@:@1bDR/0Le</07AD;@1eEBh0Me<S07QD901iEBD0NeLW
07aH:01nFRX207mK:`0607]F:@1lEbX0OEP[07mJ;@20Fbh0PUd`0P23GS4808ML;`0808QR=@26H3<0
Ped`085K;P22G2l0QElb08QR=@2;ICP@08MQ<P0308AN;`25Gc00QV0a0080R68c00<0QV0a08EO<024
GRl02026H34808MQ=0P0RF<d00<0RV@e08US=027HC800P26H3400`27HC80RF<d08YT=@0308QR<`80
RF<d102:I3D00`26HBd0Qf8^08UT<00208YU<@0308UT<027HRh0QV4]00<0R68e00<0RF<f08YT=`2:
I3L00P2;ICP808MQ=0<0Qf4b00<0R68c08US=029Hc@00P2:I3D808AR<P80Q5lb00H0QF0c08IQ=025
H3<0Q5lb089M<020Fbh808EO<080QV4d0P25H3<208AO<P80Peha2022GRh508=O;`<0Q60`0`23GS42
089M<0<0PE`_00<0NUD[07aG;@1nFBl00`20Fc400`1oFS00OUT_07mJ;@0307mJ;@@0OUT/00<0P5/a
07mJ<01nFBl00P1lEbd00`1nFBl0OeX`081K<@0807]H;PP0O5L]0`1kF2h207YG;@<0NEH/00P0N5/a
07UI<01fERd0ME@[07EB:P1gDBX0NE8[07YC;0T0LU8[00@0LE4Z071@:@1`D2T0L50Y0P1_CbP206i>
9`H0J4lV0P1YD2L03P1VB2@0IdTU06Q:9P1XBRH0IdTU06A68P1RA200H48N05i::@1MBBP0G4PW05Y6
9@1IAB@0Ed<R0P1F@R4205M28`<0ET4R0`1E@24205<o9080DShS00`0DCdR050l8@1@?240D3`Q05@j
7`1C>al0Dc/Q050j8P1?>b<0CC/U04`l9@1<>bL804Xl8@80ASLP00<0AcPQ04Pi8P19>R<00P1;?2D0
1P1<?BH0Ac/S04Hj8P16>R80ACTQ04@h8080@cLO00<0@SHN04Lg7@18>1h00P18>1h404Ti7`<0ASXP
0`15>Al204@h7Q00ACTO00<0@cLM04@h7P16>R000P17>b400`16>R00A3PN04<g7@0804Di7`80B3`R
0P17>b401`16>R00ACTO04Di7`15>Al0CShT04dm8`1;>b400`19>Al00`1:>R00Bc/Q04Xo7`0704Xo
7`80CchP0P1@?b400`1A@280DT4S05918`0205=2900305107`1A@B00DD4P0080DT8Q00<0DD4P0510
7`1??ah00P1G@1h305Q17`<0FD8P0P1EAb801P1DAR40DdDP05947`1A@ah0D48M04m17080DTHP00@0
DdDP05I4801G@b00FT8P0P1K@B0205A27P0605E37`1FA200EdDQ05Q68P1IAb<0FTPT101I@R0205Y3
8@80Fd@R00d0ED`S05A;8P1DB200E4HO05E67`1HAR00FDLQ05]78P1I@ah0FT@O05e78P1OBB@0H4XU
0080GdTT00<0GTPS05i79@1NAbD01P1NAbD805]99@P0G4DS0P1MAb8205i88`<0GdTT00H0H4XU05a:
9P1LBRH0GTXU065;901SC2<206E<8`0Q06Q=8P1WBBL0IdTU06Q:9P1YBbD0JdhV06a?9@1]D2@0KU4U
06e>8P1`DBD0Le@X07IG:`1gF2`0MUL[07=D:01aDRH0M5DV07EF9`1gF2T0NEX[07]L;@1mGRl0OUl`
07mP<@20Fbl0PE``08=N<@25HC40QV8`08IR;P25HBd0Q64[0080QV8b00@0Qf<c08QT=029ICD0RVHf
0P2;IcL01`2:I3D0RfDf08]U=P2=IcP0SVPi08mY>P2@JS/00P2?JCX2099]>@80Tfhj00@0U6lk09E`
?02FLCd0UW4m0`2HLcl209Ud@0<0VWE10P2MN4@209iiA@0@09mjAP2PNdL0XGa80:5lB02PO4P0XGe9
0:9nBP2SOd/0YH5=0:J2CP2WPdl0Z8A@0:=oB`2TP4`0YX9>0:R4D080ZHEA102XQ500102YQE40ZXIB
0:^7D`2/R5@20:f9E@060:^7E`2/R5P0[HUI0:j:FP2_Re/0/8aL0P2aSEd80;:=F@P0/H]L00<0]8iO
0;>=GP2bS5d00P2aRe`00`2bS5d0/heN0;B>G`080;2;E`80[hYF0`2`ReL30;6<F0<0[h]K00<0/8aL
0;6=G@2aSEd00P2bSUh30;:<G@<0/H]L0P2`RU/20:n?GP090:j>G@2]SE`0[8aK0:^;FP2ZRUT0ZHUH
0:^6DP2/Qe<0[XUE0080/8]G00<0[hYF0:j9E@2]R5@00`2_REX20;2:F`<0/H]L00<0[HMH0:j8F@2`
RU/00`2bS5d0102aRe`0/8YK0;2:G@2`RU/20;6;G0030;6;FP2aS5P0/XeH0080/XeF0P2]Re/00`2`
S5`0/H]L0;B;G@020;F:G@030;J:G@2`RU/0/8YK00H0/8YK202`ReL80:j9E@060:n9F02_RUH0[hYF
0:n:E@2_RU<0[h]A0P2_Rdl20:n:EP<0[XUE0`2]R5@20:^7B`030:b8CP2/Qe00[8MB0080[HQD00T0
[HMF0:^6C`2[QTl0[8MB0:b7D`2]QeH0[HMH0:j8F@2^R5/0202^RED80:f3D@030:b7DP2[QU40ZXE@
0080ZHA?00<0ZhIA0:f8D`2^RE@00P2[QU820:b7D`80[HQD0P2^RED30:f4D0030:j5D@2_QU80[hIB
0080/8MC00<0[HQC0:b7DP2[QU400P2ZQE000`2[QU40[8MB0:f8D`080:b6E`P0ZhIB00H0Zh9>0:b3
C`2]Q500[XEA0:n6DP2`Qe<20;68E080Z8=>00@0ZHA?0:Z5D02[QU40ZhIA0P2/Qe890:f4C080[hEC
1P2^Q5880:Z5D0030:R3CP2YQ4l0ZHA?0080ZXE@0P2[QU400`2/Qe80ZXE@0:Z5D0060:Z5D0040:J1
C@2XPdl0ZXEA0:f8E080[XUE00<0[HQD0:b7D`2[QU801`2[QU880:^5EP060:^5F02[QEH0ZhEF0:^5
E02[QU80ZhIA0P2[QTl30:Z5D@80ZHA@0`2XPdl20:^6D@80ZXE@102YQ4l30:Z5D@80ZhIB0`2/Qe<3
0:b2D080[H=A1P2^Q5800`2_QE<0/8ID0;26E0020;67E@P0[8MC202/QUL20:j9E@80[HQD0P2/Qe<2
0:^6DPP0/8]G202_RUH20:j8F@@0[hUJ00<0[XQI0:b6E`2[QEH0202_RUH00`2_R5d0[XML0:f6F`02
0:b5FP030:f6F`2^Qe`0[hQM0080/HaH00@0/8]G0:n:EP2^RED0[HQD0P2/Qe<00`2ZQE40ZhIB0:f8
E0020:j9E@030:f8E02[QU80ZXEA0080[HQD0P2/Qe<01P2[QU80ZXEA0:Z5D@2ZQE40[H=C0:j4E0@0
[hEE00<0[XAD0:f3D`2/QUL01`2/QUL80:Z5D@030:f8E02/Qe<0ZXEA0080ZHA@00<0ZXEA0:b7D`2]
R5@0202/Qe<20:n5D`80[XAB0P2]Pe420:b2D0P0ZhEF0P2ZQ5<0102ZQE40ZXE@0:Z5D02ZQDh20:Z6
C0P0ZhIA00<0[hYF0:f8E02ZQE400P2XPdl00`2ZQE40[HQD0:n:EP020;26EP040;26E02`Qe<0/HQD
0;68DP80/HQ@102]R5<20:b7DP80ZhIA0`2/Qe<30:^6DP80ZXEA00<0[8MB0:f8D`2^RE@00P2_RUD2
0:j9E0050:f8D`2/Qe80[89@0:f3D@2_QE<00P2`QU@00`2_QE<0[H=A0:b2D0020:n:EP80[XUE0P2]
R5@20:b7D`80[HQD0P2/Qe<0102[QU80ZXEA0:Z5D@2ZQE480:Z5D0040:f8D`2/Qe80[8MB0:b7DP80
ZhIA0P2ZQE030:^6DP80ZXEA0`2YQ5080:R3C`<0ZhIB0P2ZQE4;0:V4D0P0ZhIB0`2ZQE420:V4D0<0
Z8=?202]PUD80:Z5D@030:f8E02/Qe<0ZXEA00<0Z8=?00X0ZHA@0:Z5D@2YQ500Z8=?0:J1C@2UP4`0
Y7m;0:F0C02VPDd0Yh9>0P2VPD`0102WPTd0Z8=>0:V4C`2ZQE020:^6D@@0Z8=>1@2WPTd01`2VPD`0
Y7m:0:=nB@2SOTT0Y7m:0:J1C02WPTd02@2UP4`80:J1C@P0Yge;0P2TOd/20:=nBP@0XWe90P2RODH0
1P2SOTT0Xgi:0:AnC@2TOTl0YGm@0:EoDP80Z7m;00H0Ygi:0:ImB@2UO4P0Y7]70:=jAP2RNDD30:=i
A`80XWQ60`2QMdD00`2MO4L0WWe80:1oBP020:60B`040:1oBP2NODP0WGa709ihB`80WWQ900<0WWQ7
09iiA@2MN4<00P2MN4420:5kC080XWa=102SODh30:9lCb_ooooo000Zooooo`0309EZ?@2DJC`0TfPk
0080TVLj00H0U6Tl09I[?P2GK3l0TVHi09=W>P2EJC`209M[?P0309IZ?@2EJC`0U6Pk0080UVU000@0
UVTo09IZ?@2FJS/0UVXk0P2FJST2091W>@04095X>P2BJC/0U6/m09E/?P80UVdo202FJST409U^@@80
V6e00P2GK3l809IZ?@80WG500P2LL3l0102KKch0VVhm09U]?02IKC`209]_@00709a`?`2LLCh0WG8o
09eb?@2MLS/0WW<l09U^>`0209Y_?00409]`?@2LLCh0W74n09aa?P80WG8o00<0XWM40:5f@`2OM440
0`2NLd003@2PMD80XGI309id>02MLcT0W78h09aa>P2LLC`0WW=00:1d@`2QMD@0WW570:1cB@2QM4X0
0`2SMT`00`2RMD/0XGA:09eb?`0709eb?`0609ac?`2MM400WGA009mf@P2PMd<0XGQ40P2RNDD30:=h
A@030:9gA02QMT<0X7E20080X7E2202RMd@20:5f@`80XWM400@0XgQ50:AiAP2TNDH0YGY70`2UO4P3
0:AkA`80XgY600@0XGM50:=iA`2UNdT0Yge;0P2XOT`00`2WOD/0YWa:0:IlBP070:IlBP<0ZWm<0P2Y
OT/30:QmBP030:EkB@2TNTP0XWQ600<0X7I400<0XGM50:9hAP2NMD400P2NMD4209ed@0<0W7<o0P2K
LCl209Y`?P0=09U_?@2HKS`0Ufdk09M]>`2BKCP0TVdi091/>02=K3T0Rf/j08YZ>`29JS`0R6Tk08aW
>P0208]V>@0308YU>029I3L0R6<f0080Qf8e00@0Q5hg085K=01nF340NeD^0P1jE2d01P1kEBh0OEL`
085K=01oFC80OEL`07YD;@<0N58[00<0NE</07YD;@1gE2h00`1gE2h0101eDR`0LTlY06m<9P1]BR@8
06m<9P0306i=;01]C2/0JdXY00<0JDPW0P1[BRT406A59P80Hd@U0P1R@b@0201H@Qd0FD<N05a4801P
AR<0IDPV06U;:@1]C2/0KTd/0P1XBRP0101ZC2X0Jdd[06e?;@1_DBl2071B<00606i>9`1_CbP0L50Y
075A:P1bDR/0M5@]0P1eEBh207QD900407UE9@1kEbL0OETY07iJ:P80P5`/00P0NeHY07aG:P1mF2/0
OeX]085L;`22GC00Peha08AO<P@0REd`1028G2l02028HSD0QV0c08=M<021Fbh0PU`_08EO<P29HcH0
S6Hi4027HC800`24GRl0QEl`08IP<@0208QR<`0308IP<@25Gc00Q5h_00D0QV0a0`25Gc0808MQ=0P0
RF<d00<0RV@e08US=027HC800P26H3400`27HC80RF<d08YT=@0308US=080RV@e102;ICH00`26HBd0
Qf8^08UT<00208YU<@0308UT<027HRh0QV4]00<0R68e00<0RF<f08YT=`2;ICP00P2;ICP808MQ=004
08IP<@27HC80Qf4b08QR<`80RF<d0P2:I3D808AR<P80Q5lb00H0QF0c08IQ=025H3<0Peha085L;`20
Fbh808EO<00408MR=@26HC@0QV4d08EP<`80Q5lb0P23GS48089N;P@0Pel_1024H30308=N<@<0PUd`
0P21G2l00`1iE2X0NUD[07eH;P0307mJ<00307eH;P1lEbd0OEP[00<0OUT/0`1oFRd01020Fbh0P5/a
07mJ<01nFBl207eH;P0307iI;`1oFS00P5/a00P0NeP^201lEbd307]H;P80NUL]0`1iER`0201iG380
NET`07IF;@1eE2/0ME8Z07MA:P1iDR/0NU</2@1bDR/4071@:@80KdlX0P1^CRL306I?9@@0Ie0V00<0
J54W06E78`1VB2@00P1WBBD0301VB2@0I4HR06537`1O@Ad0GDTX05a89`1KAbH0FTHU05Q48`1F@R40
ED4P05A07`H0ED0S0P1D?b8804hm8@0605@j7`1C>b40Dc/Q054k8`1?>b<0CC/U0P1<>bL204Tk8@<0
BS`R0`1;?B<01P15=Ql0ASLP04Lh8@18>B80BCXS04Xk9080Bc`U0P16?2<01P15>b80A3XQ048h7`11
=ah0@3HM03le7080ASHL00@0AcLM04Ph7P19>Al0BCTO0P1:>R0304Hj8080ACTO0`14>1h@04Di7`03
04<g7@14>1h0ASXP0080Ac/Q00<0ASXP04@h7P13=ad02015>Al204Pl8P80Ac/Q00X0ASXP04Di7`15
>Al0A3PN04hn901=?B<0Bc/Q04Ti7`18>1h0BCTO0P1:>R0804U07`80DD0R101B@B<305=2900804hn
7@1@@1l0DT8Q05A48`1C@b80DD4P04lo7P1=?A`305Q07P80FD4O0`1J@R0205E78P0405A68@1CAB00
DD<N05127@80Cd4L00T0D4LP0596801CAB00E4@P05M3801J@R00Fd4P05e0801D@Qh00P1E@al00`1F
A200EdDQ05M58@0205Q68P0305U2801H@Al0F44O0080FD8P00l0FT<Q05]48P1KA280ETdT05A;8P1D
B200DdLO05=57P1EAQl0FDLQ05Y88P1G@A`0FD<N05a68@1NB2<00`1PBRD00`1OBB@0GTLU05i79@06
05i79@P0FdTU201LAB<205e78P80GTPS101OBB@03P1KBBD0G4XV05e9901PBR<0HT/R06=<8P1UC2<0
IDdQ06I89P1WBBD0J4XV06U;9@1ZCBD0K4lU0P1]D2@0601/CB40KTlS079C9`1eERX0MUL[07AE:@1a
DRH0Ke0T07AE9P1eERL0MULX07QI:P1jFb`0O5d^07iO<01oH340OeX^085L<023GS40QF4a08IR<026
HRh0QF4]08AQ:`80Qf<c0P28I3@208UU=@80RVHf00X0R68c08YT=@2:I3D0SFLh091Z>`2AJc`0T6Xk
08iX>@2=IcP0TF`h0P2BKCT00`2CKSX0U6lk09E`?00209Ia?@0409Mb?P2HLcl0V7<o09Qc?`80VGA0
0P2JMD401P2LMd<0WGQ409ehA02NNDD0WgY60:1kA`80XGa80P2PO4P0102ROTX0Xgm;0:F1C@2VPTh2
0:R4D0040:9nBP2TP4`0YX9>0:R4D080ZHEA00L0Z8A@0:N3C`2XQ500Z8A@0:V5D@2ZQU80ZhMC0080
[8QD00L0[HUE0:^7E`2[QeL0[8QH0:f9F@2_Re/0/8aL0080/HeM202bSET80;:<G@030;J@H@2dSUl0
/H]L0080/8YK00<0/H]L0;B>G`2fT640202`ReL20:n:EP<0/8]G0`2aS5P30:n;F`030;2<G02aSEd0
/XiN0080/XiN00D0]8iO0;>=GP2cSEh0/XaM0;6;G0020;2:F`060:n9FP2_Seh0[hmN0:j>G@2]SE`0
[8aK0P2ZRUT02@2YREP0ZhIB0:b7D`2^RED0[hYF0;2;E`2_RUH0[XUE0:f8E0020:j8F@040:n9FP2`
RU/0/H]L0;6;G080/XaM00<0[HMH0:j8F@2`RU/00`2bS5d00`2aRe`0/8YK0:n9G0030;2:F`050;6;
FP2bSET0/hiI0;>>E`2dSeP00P2]Red00`2`Reh0/H]N0;B;G`020;F:G`030;N:H02`RU/0/8YK00H0
/8YK202`ReL80:j9E080[hYF00@0[hYE0:n:D`2_Re40[h]A0P2_Rdl20;2;E`030:n:EP2^RED0[HQD
0080[8MC00L0ZhIB0:^7B`2[Qd/0[8Q>0:f9C`2^RE80[XUD0080[hYF0P2[QTl01P2/Qe80[8MC0:f7
EP2]QeP0[XQI0:j8F`P0[XUE202]Pe420:b7DP<0ZXE@00<0[8MB0:j9E02_RUD00P2[QU820:b7D`80
[HQD0P2^RED0102/Pdl0[HA@0:f4D02^QE420:n6DP80/8MC00<0[XUD0:b7DP2ZQE000P2YQ4l00`2Z
QE00[8MB0:j9E0080:f7FPP0ZhIB00H0Zh9>0:b3C`2/Pdl0[XEA0:n6DP2`Qe<20;68E080Yh9=00@0
Z8=>0:V4C`2[QU40[8MB0P2]R5<30:f2B`<0[X=<0`2_Q4d30:n5D`D0[XAB0P2YQ4l40:Z5D080ZhIA
0P2XPdh0102YQ4l0ZXE@0:Z5D02[QU420:b7DPP0ZXE@00@0YX5=0:R3C`2ZQE40[HQD0P2^RED00`2]
R5@0[8MC0:^6DP070:^6DPP0ZhEF00H0ZhEH0:^5EP2[QEH0ZhED0:^6DP2[QU420:^6C`80ZXEA0`2Y
Q5030:R3C`80[8MB0P2[QU430:Z5D0030:V4C`2ZQE40ZXEA00<0ZhIB0`2/Qe<30:b2D080[H=A1P2^
Q5800`2_QE<0/8ID0;67E@020;67E@P0[8MC202/QUT30:j9E@030:f8E02/Qe<0ZhIB0080ZhIB202`
ReL80:n:EP040:b6F@2^R5/0/8YM0;6;GP80/8YM00<0[XQK0:^5F02ZQ5L0202_RUH00`2`REh0[XML
0:f6F`020:b5FP030:f6F`2^Qe`0/8UN0080/XeI00@0/HaH0;2;E`2^RED0[HQD0P2/Qe<00`2ZQE40
[8MC0:f8E0020:n:EP030:f8E02/Qe<0ZXEA0080[HQD0P2/Qe<01`2[QU80ZXEA0:Z5D@2YQ500Zh5A
0:f3D`2_QED00P2aQeL00`2_QED0[H=C0:^1D@080:b6F@P0ZXEA00<0[HQD0:b7D`2ZQE400P2YQ500
0`2ZQE40[8MC0:f8E0080:b7D`040:j4DP2]Pe40[H=A0:f3D@80[89@0P2[PDl80:^5EP80ZXAC00@0
ZXEA0:Z5D02ZQE00ZXE>0P2ZQT`80:^6D@030:n:EP2]R5@0ZXEA0080Yh9>00T0ZXEA0:f8E02_RUH0
[XAD0:n5E@2_QE<0/8MC0;68E02bRE<00P2cRU80102^RE@0[HQC0:f8D`2]R5<20:b7DP80ZhIA0`2/
Qe<30:^6DP80ZXEA00<0ZhIA0:f8D`2_RUD00P2`ReH20:n:E@050:f8D`2[QU40[89@0:f3D@2_QE<0
0P2`QU@0102_QE<0[H=A0:b2D02`ReL20:n:EP030:j9E@2]R5@0[HQD0080[8MC00@0[XUE0:f8E02]
R5@0[8MC0P2[QU820:Z5D@P0ZXE@102/Qe820:^6D@80ZXE@0`2[QU820:Z5D@<0ZHA@202XPdl20:b7
D`040:^6DP2ZQE40ZXEA0:V4D0D0Z8=?0`2YQ5020:Z5D@P0[8MC0P2ZQE430:V4D0<0Z8=?202]PUL8
0:^6DP030:f8E02/Qe<0ZXEA0080Z8=?00H0ZHA@0:Z5D@2[QU80ZXEA0:R3C`2VPDd20:AoB`040:F0
C02VPDd0Yh9>0:J1C080Yh9=00<0Z8=>0:V4C`2ZQE000P2[QU40102VPD`0Yh9=0:N2C@2WPTd30:R3
CP040:V4C`2WPTd0YX5<0:AoBP80Xgi900<0Y7m:0:J1C02WPTd02@2UP4`80:J1C@P0Z7a;0P2TOd/2
0:=nBP<0XWe900H0XGa80:9mAP2RODH0Xgi90:=nBP2TOTd20:EoD0090:J0D`2YP4`0Z7m;0:MnBP2V
ODT0YGa80:AkA`2SNTH0XWU50080XgU70`2RN4H30:5gA@0309elA`2OOTT0X7m:0080XX5<00@0X7m:
09mnB@2MO4L0WWQ;0P2NN4T00`2NN4L0WGQ409eh@`0209eh@@80XG]<0P2RO4d30:=mCP040:AnC`2S
OE00Xge@0:=mD2_ooooo000Zoooooa00U6Pk00<0VFi109Q]@02FJch00P2EJSd00`2FJch0V6e009U^
@@0209=X=@0409AY=P2EJSL0UFXg09I[>080Uf`i00<0VFTi09YZ>P2KJc/00P2KJc/0102IJCT0UfLg
09IV=P2DJ3/209EY?00309IZ?@2GJch0Uf/n0080V6`o202JKSd309IZ>@80Uf/j0`2HK3/309]a?`D0
VW0n2@2JKc`01P2HK3/0VFdl09U]?02JKSd0Vfln09a`?`80WG500P2HK3/01P2IKC`0Vfln09a`?`2M
LD00WW9109mc@PP0Wg98202NLT402`2LL3l0WG5009ib@@2PM4<0XgM60:EiB02VNTT0Yg]:0:AhB@2R
MTL0XGE40080WgA100/0XGI10:9g@02TND80WG=109id@P2OMD<0X7I40:5gA@2RN4H0XgU70:AjB003
0:=h@`80Y7U40`2UNTD20:IkB080YGY700@0Y7U60:=hA@2RMd@0XWM40P2SNTH30:AkA`<0YGa80P2T
NdD20:ElAP<0YWe700<0Ygi80:QnC02XOT`00P2WOD/40:IlBP070:QnC02WOD/0YWa:0:AjB02RN4H0
X7I409me@`0309id@P80WG=1102LLT0209Y_@P0309U^@@2HKD00Uf`o0080UV/n00T0UFXm091Z?@2@
JSd0SVPi08eW=P2;IS80RF@_08QS;P28Hb`00`27HSD208IQ=0<0QF0c00P0Q64g08=P=P22GcD0P5dc
07mL<P1mFS00O5T_07]H;P80OePa00<0OUL`07aE;P1kE2d00P1jDb`0201iDR/0N54Z07QD<P1gDc40
MU8`07EA;`1dD2h0LTh/0P1aCB/0201gD340M50`079>;P1_C2`0K4/Z06Q::01VBBL0IDPV0P1VBBL0
0`1WBBL0JDPW06Y79`0206]79`0306e69`1U@bL0ID<W00H0ID<W00<0JDPW06Q79P1XAbH00P1XAbH3
06M69@80JDdU1P1ZCRH207E?:00A07I@:@1gDBX0N58[07QB:`1iDb`0NU@]07aG;@1oFS00Pehd08EP
=P24GcD0P5/a07]F;01hDbT0OELZ07mI;021Fbh00P24GS402`23GC00PE/^07mI;01nF2/0PE/^08AN
<@27HC@0R68e08IP<`23GC00P5X]0080R5/a0P29G380102:GC<0Rehd08]N=02<GcD208]U=P0308YT
=@29Hc@0R68c0080QV0a00<0QEl`08AP<024H3001P24H30308IP<`80Qf4d0`28HSD508IP<`<0QElb
2027HC@01P24GRl0Q5h]08EO;P25H2`0QV4/08MR:`80R6@Z00<0QV0c08EO<P24GS400P24GS400`26
H3<0R68e08US=P0908MR=@80RF<d00@0R68c08MQ<P27HC80QV0a0P25Gc0208iS=P0408eR=@2<HC@0
Rf0c08]P<`80RUlb00@0QV0a08MQ<P27HC80R68c0P29Hc@208YT=@80Qf4b0`26H34308EO<00807mK
:`22GRh0QF4a08QT=029ICD0Qf<c08AP<021GBd208IQ=0<0QF0c0`24Gc800`24H300QF4a08MS<`02
08MS<`0308EQ<@22GRh0PEd]0080QV4d00H0Qf8e08QS=P26HC@0Q5lb085L;`1oFRd408IQ=080QF0c
0P24Gc802@1oFRd0PE`_08=N<@25H3<0QV4d08EP<`24Gc80Peha089M<00308=N<@<0Q5lb00D0QF0c
081K<@21G380PE`b089M<`0208=N=080Q5le201nFBl0101kF2h0O5T_07aI;`1lFBl307eJ<00307iK
<@1kF2h0NeP^00@0NUL]0P1iER`807]I:@<0M5@[00<0MED/07IF;@1gEbh00P1gEbh3079B:`80LE4Z
0`1`D2T206mD:@D0L5DZ0P1aER/0201bDR`0LE4[071@:P1^CRP0K4`V06Y:901XB280IdLQ0P1ZCBD2
06U;9@0406Q:9P1WBBL0ITLX06I7:080GD@U00<0G4<T05]28`1J@B800P1I@2400`1H?b00E3lP05@o
800205@o8080ED0Q0P1F@B80201F?R80ECdQ054l7`1?>Qd0CCXL04`k7@1=?Ql0CSlP0P1??R0204hm
7`0404dl7P1<>ad0C3/M04/j70<0BSPR00<0BcTS04`j901=>bD00P1=>bD304Di8@80ASXR0`17>b<8
04@j8@80@3HM0P11=ah3048h7`0404<i8013=al0@cLO04<g7`<0A3PP0P15>B4204@e7P80ACHO00@0
ASLP04Lh8@17>240B3TR0P12>al00`14>Ql0ACTO04Li7`0204Ph7`0504Tg7`16>R80ACTQ04Di8@14
>2000P13=al2048f7P<0A3PN0P15>Al304Hj8009050l8`1?>b80C3/Q04Xj8018>Ql0A3TM04<h7012
>A`0@cLM0080A3PN00<0ASXP04Lk8@18?2800P19?B<00`18?B40Ac`P04Dj7P0204<h700304@i7@15
>Qh0AS/O00P0C3`R2@1C@28205E08`0405A18`1A@280D3lQ04ho8080CD0P0P1D@B4405E28P80ET<S
00/0Fd8T05a39@1MA2H0GD@V05a39@1I@280EchP05Dl7P1F?Al0FD0R05a39@0205i59`0305a39@1I
@280ESdO00P0ET@P201HAR80401IAb<0EdDQ05I4801E@al0ET@P05M58@1IAb<0FdTU05Y<9`1IBbH0
F4PT05U78`1KAb@0GdPV065::01SBbT305]99@80FTPT0`1IAb<00`1LBRH0FdTU05U78`0205M58@03
05U78`1KBBD0G4XV00P0FdTQ00<0FDTU05Q8901GAb<00P1FAR802@1HB2@0FTXV05];9`1OAQh0H4LO
0658801RBB40HdXR06E<900206I=9@0605U:8`1KBB<0G4XT05m;9P1SCBP0IDdY0P1XCR/03P1XBbT0
J4`W06U=:01ZCRL0JdlW06aA9P1/DB@0KE8U07=G:01dF2T0M5PX07EI:@1fFRP0Me`W0P1hGBH0201h
FBX0NU//07aM;P1oH340P64b07mP<@1nGc00OEh_0P23HC400`24HS80QF<c08IT=00208MU=@0E08QV
=P2<I300S6@`08aT<02=IC40SVHb091X=02AJCD0TVXf09=[=`2:Ibd0S6Ta08m/=P2BKS`0Tfi109A_
@`2DKTL0Tfe609Md?P2HMCl0VGI00080VWM100d0VGI009Qe?`2GM3h0W7M309]f@P2JMD40VGA009Ye
@@2MN4@0WgY60:5lB02ONTH0X7]70080XGa8102RODT01P2VPD`0Yh9=0:N2C@2XPdh0ZHA?0:Z5D080
ZhIA00H0Z8=>0:V4C`2YQ4l0ZhIA0:b7DP2]R5<20:j9E080ZhEH0P2/QUT30:f7FP030:j8F`2_Re/0
[h]K0080/8aL0`2aSEd0102bSUh0/hmK0;:>FP2_ReL20:j:EP030:n;E`2bSUX0/hmK00P0/HmQ202b
S5d00`2`S5`0/HeM0;:>GP020;B@H0030;:>GP2aSEd0/8aL0080[h]K0P2`S5`20;6=G@80/XiN00P0
/heN0;:<G@2`RU/0[hUJ0:j8F@2_REX0/8YK0;6;G0P0/XeI0P2^RED00`2_RUH0/8]G0;6<F0020;:=
F@030;>>FP2/Qe<0[8MC0080[HQD00D0[XUE0:n:EP2_RUH0/8]G0;>>FP030;:=F@80/HaH0P2`ReL9
0:n;E`P0[hUL202dR5L30;2;E`80[hYF2`2^RED20;67E`040;:8EP2cRUH0]8]G0;B;E@80]HaD0P2Z
QDh01P2ZQE00ZhIB0:^5E02[QEH0[8IG0:b6F@<0/8]G0P2_RUH30:j9E@080:f7F02/QUL0ZXAE0:Z4
E@2[QEH0[HMH0:n9FP2aRe`80:j9E@080;2;E`2^RED0[8MC0:^6DP2ZQE40ZhIB0:b7D`2]R5@80:f8
D`80/8]G00<0[hYF0:j9E@2]R5@00P2/Qe<00`2[QU80[hEC0:n5D`060:n5D`P0[HQC0P2^R5T20:f7
F080[8IG0P2[QEH01P2ZQ5L0ZXAE0:Z4E@2ZQ5<0ZXEA0:Z5D080ZXE>00H0[HQC0:f8E02]R5@0[HMF
0:f7F02]QeX20:f6F`80[8MC00T0ZhIB0:Z5D@2[QU80[HQD0:n:EP2`ReL0ZhYE0:Z9E02/R5@00P2]
R5@01`2^QU<0[hEC0:j4DP2_Pe80[HA@0:n6DP2`Qe<00P2bRED00`2`Qe<0[hIB0:f4D0080:Z5D@80
[8==00<0[8=?0:f3D@2]Pe<00P2^PeH0102^PeP0[XEA0:f4D02/Pdl20:^2CP030:f4D02_QU80/8MC
00<0[8MC0`2[QU820:Z5D@<0ZHA@0P2ZQE430:^6DP040:V4D02ZQE40ZXEA0:^6DP80[8MC0P2]R5@8
0:f3D@030:b7D`2[QU80ZXEA0080Z8=?00<0ZHA@0:Z5D@2[QU80202[PTh;0:^6DP80ZXEA0`2YQ502
0:Z5D080ZhIA102/Qe820:n:EP<0[XUE0`2]R5@01P2[QEP0ZhEF0:^5EP2[QE@0ZhIB0:^6D@80ZhI?
0P2]Pe420:j4DP@0[hEC1@2[QU830:b7D`80[XeH00H0[h]G0:n:EP2aREH0/HME0;26E02aQE@20:b7
D`80[HQD0P2^RED20:n:EP040;2;E`2]R5@0[HQD0:j9E@80[hYF00<0/8]G0;6<F02aS5P00P2]R5@0
102^RED0[hYF0:n:EP2`ReL20;6<F0040;2;E`2_RUH0[hYF0:j9E@80[HQD0P2/Qe<30:j9E080[hYE
0`2`ReH0202/Qe<0[HQD0:j9E@2_RUH0[XUE0:f8E02[QU80ZHA@0P2^Q5800`2]Pe40[89@0:^1C`02
0:UoC@030:QnC02ZQ5L0ZXAG00H0ZXAG0P2^Q5820:n5D`<0/8ID00<0/HME0:j9E@2^RED01P2^RED2
0:^6D@80[8MB0P2]R5<20:j9E0P0ZhIA0P2aR5801P2`Qe<0/8ID0:n5E@2_Q5L0[X=F0:j3F0P0ZhEF
00<0/HQD0;27D`2^QE400P2^QE400`2`Qe<0/XUE0;B;E`080:^6DP080:V4C@2ZQDh0ZhI?0:b7D02]
R540[XUB0:n:D`2`Re@20:b7D`80[HQD00@0[XUE0:n:EP2_RUH0/8]G0P2ZQDh00`2[QU40ZhIB0:^5
E0020:b6E`040:b6F@2]R5@0[8MC0:^6DP80ZHA@0P2[QU800`2/Qe<0[HQD0:f8E0070:f8E080[XUE
0P2]R5@20:b7D`80ZhIB0`2/Qe<30:^6DP80ZXEA00/0Z7i<0:Z0CP2]Pe40[hEC0;26E02_QE<0[XAB
0:f3D@2[QU80[8MC0:f8E0020:j9E@030:f8E02/Qe<0ZhIB00<0[8MC0`2[QU820:Z5D@<0ZhIB0P2/
Qe<30:f8E0080:R3C`2[QU80[XUE0;2;E`2_RUH0[8MC0:V4D02VPDd80:R4D080ZHA@102ZQE420:^6
DPP0ZH=D0`2/QUL30:^5EP80ZXAE00<0Z7i<0:UoC@2/PU000`2^Q5801@2/PU00Zh5?0:b7D`2/Qe<0
ZhIB0080ZXEA00<0ZHA@0:R3C`2XPdl00P2ZQE430:V4D0<0Z8=?00P0YH550:N3B@2XPd`0ZXE@0:Z4
D`2XPUD0Yh1E0:EnE@P0ZHA@00P0Z8=<0:N2B`2VPDX0YH190:AoB02SOTL0XWe60:5lA@T0YX1A00P0
Z7m;0:V0C02[PTh0[8=?0:^2CP2ZPDd0Z7m;0:ImB@80Xgi:00@0Y7m;0:F0C02UP4`0YX5=0P2WPTh3
0:J1C@80YH1<0`2TOd/20:9mB@80Xgi:00@0Y7m;0:F0C02UP4`0YX5=0P2SOTX20:9mB@040:5lB02P
NdL0X7]709mjAPP0XWe800@0XWQ60:=iA`2SNDL0Y7Y80P2UNdT20:IlBP060:EiB02TNTP0Y7Y80:=k
B02QO4P0X7a80P2NODP01P2ONTD0WgY609mjAP2PNTT0X7Y;0:5kCP80XGY?0`2RODT[ooooo`00:_oo
ool@09AX>`0309Q]@02GK3l0UFXm0080U6Tl00<0UFXm09M/?`2HKD000`2DJ3L00`2EJCP0UVXi09IZ
>@0209M[>P0809UY>@2JJSX0Vf/k09a/?02KJc/0VFTi09MW=`2FISH209EY?080UVXm0P2GJch209Q/
?`P0VVhm0P2GJcX309Q/>`<0VFdl0P2KLCl609Y`?PT0VVll0`2KKch309a`?`80WG5000D0VFdl09Y^
?@2JKSd0Vfln09a`?`0209ea@00309ib@@2OLdH0Wg=600H0Wg=62P2NLT402@2OLd80XGE40:9fA@2S
MdH0Y7Q70:EiB02SMdP0XWI70:5eA0020:1e@P030:5f@@2RMd00XgQ10080WWA200@0WgE30:1fA02Q
MdD0XWQ60P2SNDL30:=h@`80Y7U40`2UNTD01P2WO4T0YW]80:IkB02UNTL0Y7U60:=hA@80XWM40P2S
NTH30:AkA`<0YGa80P2TNdD20:ElAP@0YWe70P2XOT`20:MmB`<0YWa:00T0YG]90:IlBP2VO4X0YG]9
0:=iA`2RN4H0XGM50:1fA02OMD<00P2NM48209ec@@<0W79000L0Vg4o09Y_@P2IKT40VFi109Q]@02G
K3l0UV/n0080UFXm00P0T6Xm08mY?02>J3T0S6Hg08]U=029I300R6<^08MR;@80Qf8e0`26HC@308EP
<`06085N=020GC<0P5dc07mL<P1nFc40OEX`0P1lFBl01@1oF340OUL`07eF;`1lEBh0Ne@]0080NE8[
0P1hDBX207EA;`0407A@;P1cCbd0LTh/079>;080LDd[00P0M4d^075=;@1`C2`0KT/[06]::@1XBRP0
ITTW06E89P80ITTW00<0IdTW06U89`1ZAbL00P1[AbL00`1]ARL0IT@X06I4:00606I4:080JDPW1P1X
AbH406Y>9P@0JdlW00H0MDlX07I@:@1fD2T0Me4Z07QB:`1iDb`207YD;@0=07aG;@1nFBl0P5/a089M
<`21G380OeX`07aG;@1jEB/0OeT/081J;@21Fbh0PU`_08=M<002089L;`09085K;P1oFB`0PE/^08EO
<P27HC@0R68e08IP<`23GC00PE/^0080Qe`a0P28GC801@29GS<0RUld08YO=02:Gc@0RfDf0080RV@e
00D0RF<d08MQ<P26H340QV0a08EO<00808AP<0<0QV0c0P27HC@308QR=@H0QV0c0P25Gc8808MQ=080
QEl`00<0QEl^08IQ;@26HB`00P27HR/01027HbT0Qf4d08IP<`25Gc8208AN<@0308IP<`28HSD0RF<f
00T0Qf8e0`28HS<308MQ<P80QV0a0`2<HC@208]P<`<0RUlb00<0QV0a08MQ<P27HC800P28HS<208US
=00408YT=@27HC80Qf4b08MQ<P80QV0a0`25Gc000`20G2`0Pel_08IR<P0208UU=@0308MS<`25HC40
Pel_0080QV4d0`25H3<308AO<P0308EQ<@26HS80Qf<c0080Qf<c00D0QF4a08=O;`21GBd0QF0c08IQ
=00208MR=@0408IQ=024Gc80PE`_081K;P<0QF0c0`24Gc8208=N<@08081K;P21G2l0Peha08EP<`26
HC@0QF0c08AO<P23GS4208AO<PH0Peha00<0P5/a085L<P21G3800P22GC<208=N=00308AO=@1nFBl0
OUT_00H0OUT_0P1mFS0607aI;`H0NUL]0P1iER`807]I:@<0M5@[00<0MED/07IF;@1fERd00P1gEbh3
07=C;080LU8[0`1aDBX506mC:`@0L5@/0P1aDB/03`1_CbT0KDdW06];9@1YBB<0J4PR06M78@1YCBD0
J4`T06Q<9@1WBbH0ITTW06E8:01TAbL0I4LY05e69P0205a59@0305]4901J@b<0FD8R0080F44Q201D
?b00201E?B<0E3`R050k801>>Ql0BcXN04/l7`1<?B00C3hQ0`1<?B000`1;?1l0BS/N04Xk7P0204Tj
7@0304Ph8@19>B80BCTR0080BSXS0P1;>b@0101<?2D0ACTQ04Di8@15>B4204Hj8P<0Ac/S2014>R42
040f7@80@CLN1012>1l304<g7`<0A3PP0P15>B4204@e7P80ACHO0P16=b0204Lh8@80@S/O00<0A3XO
04Di7`17>Al00P18>1l01@19=al0ACTQ04Di8@15>B40A3PP0080@cLO0P12=Qh304@h7P80ACTO0`16
>R0204hj8@0<04/j801:>R00B3XO04Dj7P14>Ad0@cXM04<g7@14>1h0ACTO04Hj8017>b40B3`R0P19
?B<00`17?200AS/O04@i7@0204<h700304Dj7P16>al0Ac`P00P0C3`R2@1B?b4205E08`0405A18`1A
@280D3lQ04m08@80CD0P0P1C@200101D@B40ED8R05E28P1F@b<205M4900;05Y3901KA2D0Fd@U05a5
9P1J@b@0F44R05Ho801D?Ah0EChO05M08@1KA2D00P1MARL00`1KA2D0Ed0Q05Dn7`0805I480T0F4HR
00L0EdDQ05I4801FA200ET@P05Q68P1JB2@0FdTU0080F4XU00H0EdLS05U78`1JAR<0GTLU06199`1R
BRP305]99@80FTPT101IAb<01`1HAR80EdDQ05E37`1E@al0EdDQ05Q68P1IAb<0201KBB400`1HB2@0
EdLS05I68P0205I68P0305Q8901IBBD0Fd/W0080H4LO00@0HDPP06998@1SBR80HdXR0P1TBb<03P1H
BB80FdTS05a:901OBbH0HT`W06E=:@1WCBX0J4h[06U<:P1YCBP0JThY06]?:01/D2P0K54V0P1]DRD0
301cERX0LeLX07AH:@1eFBT0MUXX07ML9`1gG2D0N5dV07QI:P1iFR/0O5d^07iO<080Of0a00<0OUl`
07eN;`22H3000P23HC400`24HS80QF<c08IT=00208MU=@<0SFDb0P2>IS<03`2?Ic@0T6Pe095Y=P2A
JCH0RfP`08eZ<P2@K3P0TVhl09A_@P2DKd<0U6m509A^A`2GM3h0V7Do09Uf@00209Yg@@0509Uf@02H
MCl0Ug@n09ag@`2KMT800P2JMD40102KMT80WGQ409mjAP2PNdL209iiA@0409mjAP2PNdL0XGa80:9m
B@80Xgi:0P2VPD`00`2WPTd0Z8=>0:V4C`020:Z5D0060:^6D@2XPdh0ZHA?0:V4C`2ZQE00[8MB0P2]
R5<00`2^RE@0ZhEF0:^5EP020:b6E`@0[HMH0P2_Re/20;2<G0@0/HeM00<0/XiJ0;6=F@2`S5P00P2_
ReL00`2`S5P0/HeI0;:>FP080;6?G`P0/XaM00<0/8aL0;6=G@2bSUh00P2cSel00`2bSUh0/HeM0;2<
G0020:n;F`80/8aL0P2aSEd20;:>GP080;>=GP2bS5d0/8YK0:n9FP2^R5T0[hUJ0;2:F`2aRe`80;:=
F@80[hYF0`2`ReL30;6<F0030:b7D`2]R5@0[HQD0080[XUE0P2_RUH00`2`ReL0/XeI0;:=F@020;:=
F@80/HaH0P2`ReL90:n;E`P0[hUJ202cREL20;2;E`<0[hYF2`2^RED20;:8F0040;:8EP2cRUH0/hYF
0;B;E@80]8]C0P2[QTl00`2[QU40[8MC0:b6E@020:f7F0030:f7FP2`ReL0/8]G00<0[hYF0`2^RED0
202]QeP0[8IG0:^5EP2ZQ5D0ZhEF0:f7F02_REX0/8YK202^RED0202`ReL0[XUE0:b7D`2[QU80ZXEA
0:^6DP2/Qe<0[HQD202]R5<20:n:EP<0[XUE0`2]R5@80:n5D`P0[HQC0P2^R5T20:f7F080[8IG0P2[
QEH01P2ZQ5L0ZXAE0:Z4E@2ZQ5<0ZXEA0:Z5D080ZXE>00H0[HQC0:f8E02]R5@0[HMF0:f7F02]QeX2
0:f6F`80[8MC00H0ZhIB0:Z5D@2[QU80[8MC0:j9E@2`ReL20:Z9E00:0:b8E02]R5@0[HQD0:j6D`2_
QE<0[XAB0:n3DP2]Q500[XEA0;27D`80/HQD00<0/8MC0:j5D@2]Q500202ZQE420:b3C@030:b3C`2]
Pe40[H=C0080[X=F00@0[X=H0:j5D@2]Q500[8=?0P2[PTh00`2]Q500[hIB0;27D`030:b7D`<0ZhIB
0P2ZQE420:V4D0<0ZXEA0`2[QU830:Z5D@030:^6DP2/Qe<0[8MC0080[HQD202]Pe400`2/Qe<0ZhIB
0:Z5D@020:R3C`030:V4D02ZQE40ZhIB00P0[8=?2`2[QU830:Z5D@80ZHA@0P2ZQE020:^6D@<0[8MB
00<0[HQC0:n:EP2_RUH00`2^RED30:f8E0060:^5F02[QEH0ZhEF0:^5E02[QU80ZhIA0P2[QTl20:f3
D@80[XAB0`2_QE<00`2`QU@0ZhIB0:^6DP020:^6DP@0[8MC00D0[XeH0:f<E`2_ReL0[hYF0;69EP02
0;67E@030;65E02/Qe<0[8MC0080[HQD0P2^RED30:n:EP80[HQD0P2^RED0102_RUH0/8]G0;2;E`2`
ReL20:f8E080[XUE00@0[hYF0;2;E`2`ReL0/8]G0P2_RUH20:j9E@80[HQD0P2/Qe<30:j9E0<0[hYE
0P2`ReH0202/Qe<0[HQD0:j9E@2_RUH0[XUE0:f8E02[QU80ZHA@0P2_QE<0102^Q580[H=A0:b2D02[
PDl20:Z0CPP0ZXAE0P2^Q5820:n5D`@0/8ID202^RED20:^6D@80[8MB0P2]R5<20:j9E0P0ZhIA0P2a
R5801P2`Qe<0/8ID0:n5E@2_Q5L0[X=F0:j3F0P0ZhEF00P0/8MC0:n6DP2^QE40[HA@0:j5D@2_QU80
/HQD0;:9E@P0ZhIB0P2ZQDh0102[QTl0[8M@0:f8D@2^RE820:n:D`80[8MC0P2]R5@20:j9E@80[hYF
0P2ZQDh00`2[QU40ZhIB0:^5E0020:b6E`040:b6F@2]R5@0[8MC0:^6DP80ZHA@0P2[QU800`2/Qe<0
[HQD0:f8E0070:f8E080[XUE0P2]R5@20:b7D`80ZhIB0`2/Qe<30:^6DP80ZXEA00@0ZGm=0:Z0CP2/
PU00[XAB0P2_QE<20:j4DP030:^6DP2/Qe<0[HQD0080[XUE00<0[HQD0:b7D`2[QU800`2/Qe<30:^6
DPD0ZXEA0P2[QU830:b7D`030:V4D02[QU80[HQD0080[hYF00<0[8MC0:V4D02VPDd0202XQ5080:Z5
D@P0ZhEF0`2/QUL20:^5EP<0ZXAE00T0Z7i<0:Z0CP2/PU00[H=A0:j4DP2]Pe40[89@0:^1C`2/Qe<0
0P2[QU820:Z5D@80ZHA@00<0Z8=?0:Z5D@2ZQE400`2YQ5030:R3C`080:J2B02WPdT0Z8=<0:V4D02Y
Pe80Z89E0:N0E@2VOe@80:V4D0060:V4C@2XPd`0Yh9;0:J1BP2UP4T0Y7m80P2SOTL90:N1DP030:Qo
B`2YP4`0Zh9>0080Zh9>00<0ZX5=0:QoB`2WOTX00`2TOd/00`2UP4`0YX5=0:J1C@020:N2CP<0YX5=
0P2UP4`30:AoB`80XWe90P2SOTX20:AoB`80YH1<0P2SOTX20:9mB@040:5lB02PNdL0X7]70:1kA`P0
XGa80`2SNDL00`2TNTP0YG]90:EkB@020:IlBP060:EiB02TNTP0Y7Y80:=kB02QO4P0X7a80P2NODP0
1P2ONTD0WgY60:1kA`2PNTT0X7Y;0:5kCP80XGY?0`2RODT[ooooo`00:_ooool@09AX>`0309I[?P2E
JSd0U6Tl0080TfPk00@0U6Tl09EZ?@2FJch0U6Pg0`2EJCP309IZ>@0909M[>P2IJCT0VVXj09][>`2L
K3`0Vf/k09YZ>P2HJ3P0UfLg00<0UVXm0`2GJch209Q/?`/0VFdl0P2JKSd309]_?PP0VW0n2@2KL3d3
09ib@@<0WG502P2LL3l809mcAPP0WW910`2PM4<20:5eA0<0XWI500<0XgM80:9fA`2QMD@00P2PMD80
102QMT40XWM00:=h@@2NM48209me@`050:1fA02QMdD0XWQ60:9hAP2SNDL00`2SN4<20:AiA0<0YGY5
0P2WO4T00`2VNdP0YGY70:AiAP020:=hA@030:9gA02SNTH0XgY600<0Y7]70`2UO4P30:AkA@80YGa6
0`2VODL30:MmB`80YWa:0`2UNdT20:AjB080XgU70P2RN4H20:5gA@<0WG=10P2LLT0309]a?`80VFi1
00<0V6e009M/?`2FJch00P2EJSd02P2DJC`0SVLl08iW?02=IcX0S6Hg08YT<`29I300R6<_08MR;@27
HSD308IQ=080QF0c0P24Gc8307eJ<0D0O5T_0P1mEc000`1lERl0NU@]07UC;00207QB:`0307MA:P1f
D2T0LDd[00@0LDd[0`1`C2X01`1`BBX0KTXZ06i::P1/BBT0JTTX06Q::01WBRP00`1VBBL00`1WBBL0
JDPW06Y79`0206]79`0306e69`1VABH0ITDV00H0ITDV201YB2L206]>9P80K4lW0P1]D2P206iA:@06
07I@:@1gDBX0Me4Z07QB:`1iDb`0NU@]0P1kEBh407eH;P<0OUT_0140OeX`089L;`21Fbh0PE/^081J
;@21Fbh0PU`_08=M<024GS40P5X]089L;`25Gc80Qf4d08QR=@26H3<0Q5ha08=M<00308QM<P<0REhc
0P2:Gc@208YT=@0308US=028HS<0Qf4b0080QV0a00<0QEl`08AP<024H3001P24H30308IP<`80Qf4d
0`28HSD808IP<`P0R68e0100Qf4d08MQ<P27HC80Qf4`08IQ;@26HB`0QV4Z08EP:@27HC@0QV0c08EO
<P24GS40QElb08IP<`28HSD0RF<f2@27HSD408MQ<P<0R68c00@0RF<d08UN<@29GS40REha0`2:Gc82
08]P<`@0Qf4b0P28HS<208US=00408QR<`27HC80Qf4b08MQ<P80QV0a0P25Gc000`22GRh0Q60`08MS
<`0208YV=P0308UU=@27Hc<0QF4a0080QV4d0`25H3<308AO<P0908EQ<@26HS80QV8b08MS<`26HS80
QF4a08AP<023Gbl0QF0c00<0QV4d00@0QF0c08=N<@22GC00PE`_0P24Gc8308=N<@<0PUd`0P21G2l0
1023GS40Q5lb08AO<P24Gc8208=N<@80QF0c00@0Q5lb08=N<@23GS40PUd`0P21G2l4085L<P80PUdc
0P23GS@807iI;`80OU/a00@0OEX`07aI;`1lFBl0NeP^0P1jEbd507UF;0<0NUL]201kFB/307AD:`80
MED/0`1fERd307AD;@80Le</0`1bDR/906iB:P0>06i@;01]Cb/0K4hZ06Y<:01XBRH0ITPT06E78`1T
AR80Id/T06I:8`1VBRD0IDPV06A79@1SARH206959`0605e69`1LABH0G4DV05]49@1J@b@0FD8S0P1H
@B8205A18`0405=08P1B?b40DSlQ054n8080D3dO00<0DS`T054k8`1>>R400P1;>R000`1:>R00BS`Q
04Xl8@0204Xj8080BCTO1018>1h204Ph8@80BCTR101:>R<304@h8080ACTQ0`16>R8804<i80<0@3HM
0P11=ah3048h7`<0@cLO0`14>20204Di8@80@SHN0`13=al304@h8080@CXN00<0@cTN04@h7P16>1h0
0P17=ah00`18=Qh0ACTQ04Di8@0304@h80<0@cLO0`14>1h204Di7`<0ASXP00D0CCTP04`h7`1:>Al0
BCTO04Pj7`0204Hk7`0604Dl7`14>1h0A3PN04Di7`16>R00Ac/Q0P18?2802@19?B<0ACXN04@i7@14
>Ad0@cPL04@i7@16>al0B3dQ04Xo8`0804`l8PT0DChP0P1E@2<0101D@B<0DD0R05508P1?@24204i1
8@80DSlO00@0Dd0P05A18@1F@b<0Ed@T0P1HABD205Y3900905]49@1J@b@0FD8S05Q18P1F?b00EChO
05Ho801G@240FT<T0080G4DV00<0FT<T05M08@1F?b00201FA20:05Q68P<0EdDQ00<0F4HR05Y8901K
BBD00P1FB2<01P1FAR80F4HR05U58P1LAB<0GTLU06189P<0FdTU0P1JB2@305U78`0305Q68P1GAB40
ET@P0080ED<O00<0ET@P05M58@1HAR80201JB28205M78`<0EDDQ00<0EdLS05U99@1JBRH0201PB280
1P1HBB80FdTS05a:901NBRD0HT`W06A<:080IT`Y00H0JD`Z06Y>:@1ZCRT0JdlX06a@:01]DRL206iC
9P06075D:P1bEBT0LUDY07=G:01dF2P0METW0P1fFbH0101hFBX0NEX[07YK;01lGBh307eN;`0707aM
;P21Gbl0PV0`089P<023HC40Q68b08ES<`0208IT=0T0S6Lc00H0SFXd08iZ=P2AKCT0Tflm09Ea@@2E
L4<209A_@`0309Ic?@2GM3h0V7Do0080VGI000@0V7Do09Md?P2FLcd0VgI20`2JMD40102KMT80WGQ4
09iiA@2ONTH209ag@`0709ehA02ONTH0XGa80:=nBP2TOd/0YH1<0:F0B`020:J1C0030:N2C@2XPdh0
ZHA?0080ZXE@00H0Z8=>0:V4C`2YQ4l0ZXE@0:^6D@2/Qe820:f8D`<0ZhEF0P2/QUL30:f7F0<0[h]K
0P2`S5`30;6=G@030:n;E`2`S5P0/HeI0080/XiJ00<0/HeI0;2<F02_ReL0202bSUh80;:<G@030:n;
F`2`S5`0/XiN0080/hmO00<0/XiN0;2<G02_Re/00P2_Re/20;2<G080/HeM0P2bSUh0202cSEh0/XaM
0;2:F`2_REX0[XQI0:n9FP2`RU/0/H]L202bSET30;6<F0<0/8]G0P2_RUH20:f8E080[XUE102_RUH3
0;:=F@80/HaH0`2`ReL90:n;E`P0[hUJ202cREL0102`ReL0[hYF0:n:EP2_RUH20:j9E@80[HQD202^
RED01P2dRUX0/hUI0;>9E`2cRUH0/XUE0;:9D`80/XUA0P2]R5400`2]R5<0[XUE0:j8E`020:n9FP03
0:n9G02`ReL0[hYF0080[hYF0P2^RED20:f8E0030:f7F02/QUL0ZhEF0080ZhEF00<0[HMH0:j8F@2_
REX0202]R5@0202`ReL0[XUE0:b7D`2[QU80ZXEA0:^6DP2/Qe<0[HQD202]R5<30:f8E0<0[XUE0P2_
RUH80:n5D`P0[HQC0P2^R5T20:f7F080[8IG0P2[QEH01P2[QEP0ZhEF0:^5EP2[QE@0ZhIB0:^6D@80
ZhI?00H0[HQC0:f8E02]R5@0[HMF0:f7F02]QeX20:f6F`030:f8E02/Qe<0ZhIB0080ZXEA00<0[8MC
0:j9E@2_RUH00P2ZRE@0102/R5@0[8MC0:b7D`2^QU<20:j4DP040:n3DP2^QE40[XEA0:n6DP80/8MC
00<0[hIB0:j5D@2^QE40202ZQE420:b3C@030:b3C`2]Pe40[H=C0080[X=F00@0[X=H0:j5D@2]Q500
[8=?0P2[PTh00`2]Q500[hIB0;27D`030:b7D`<0ZhIB0P2ZQE40102YQ500ZXEA0:Z5D@2ZQE420:^6
DP80[8MC0P2ZQE430:^6DP<0[8MC202]Pe400`2/Qe<0ZhIB0:V4D0020:R3C`030:V4D02[QU80[8MC
00P0[XEA2P2/Qe<20:^6DP<0ZXEA00@0ZHA@0:^6D@2[QU40ZhIA0P2/Qe830:f8D`80[hYF0`2^RED3
0:f8E0060:b6F@2/QUL0[8IG0:b6E@2/Qe<0[8MB0P2/Qe040:j4DP80[hEC00<0/8ID0;67E@2/Qe<0
1`2/Qe<20:f<E`030:n;E`2_RUH0/HUF0080/HME00@0/XIE0:f8E02]R5@0[HQD102^RED20:n:EP04
0:f8E02^RED0[XUE0:j9E@<0[hYF00<0/8]G0:f8E02^RED00P2^RED30:n:EP040;2;E`2^RED0[XUE
0:j9E@<0[HQD0P2/Qe<20:f8D`80[XUD0`2_RUD02P2`ReH0[8MC0:f8E02^RED0[hYF0:j9E@2]R5@0
ZhIB0:V4D02aQeD20;26E0030:n5D`2^Q580[H=A0080[89@202ZQ5D30:j4DP80[hEC0`2`QU@80:f8
E080ZhIA0P2/Qe820:f8D`80[XUD202[QU420;68DP060;27D`2`QU@0[hEE0:n4E`2^PeH0[X=H202[
QEH20:j5D@<0[HA@00<0[XEA0;27D`2aR5@0202[QU801@2ZQE00ZhIA0:^6D@2/Qe80[HQC0080[XUD
00<0[hYE0:b7D`2/Qe<00`2]R5@30:j9E@80ZXE>00<0ZhIA0:^6DP2[QE@00P2/QUL0102/QUT0[HQD
0:b7D`2[QU820:V4D080ZhIB00<0[8MC0:f8E02]R5@01`2]R5@20:j9E@80[HQD0P2/Qe<20:^6DP<0
[8MC0`2[QU820:Z5D@040:UoC@2ZP4h0[89@0:j4DP<0[hEC00@0[XAB0:^6DP2/Qe<0[HQD0P2^RED0
0`2]R5@0[8MC0:^6DP030:b7D`<0ZhIB0P2ZQE430:V4D080ZXEA0`2[QU80202YQ500ZhIB0:f8E02_
RUH0[XUE0:b7D`2YQ500Yh9>202XQ5080:Z5D@X0[8IG0P2[QEH30:Z4E@040:V3E02YOdd0ZX1>0:b2
D0<0[H=A0P2/PU030:^6DP80ZXEA0`2YQ5020:Z5D@<0ZHA@0`2XPdl0202VPDX0Yh9;0:R3CP2YQ500
ZH=B0:R2D`2WPE@0YX1C202YQ5020:Z5D0030:V4C`2XPdh0Yh9=0080YX5<00<0YH1;0:R2D`2XPU<0
1`2XPU<00`2XOd/0ZH1<0:Z1C@020:^2CP040:Z1C@2YP4`0ZH1<0:AoB`<0YH1<0`2VPDd0102WPTh0
YX5=0:J1C@2VPDd20:F0C0<0Y7m;0P2RODT30:=nBP<0Y7m;0`2RODT30:5lB080X7]7202ONTH20:=i
A`<0Y7Y80`2UNdT01P2UNDP0Y7Y80:AjB02SNdP0XGa80:1lB080WWe800H0WgY50:1kA`2PNdL0X7Y9
0:5kC02QNdh20:9kD0<0XWe9:oooool002[ooooo202DJ3/809EY?080U6Tl102CJ3/209AY?0P0UVXk
00<0VFTi09YZ>P2KJc/00P2LK3`00`2KJc/0VFTi09QX>00609M[?P80V6`o202IKC`0102JKSd0Vfln
09]_?P2KKch209a`?`80WG5000<0VFlm09Y`?P2JL3h00P2JL3h309]a?`T0Vg0m00H0XGE40:1d@`2P
M4<0Wg=209ib@@2MLD0209a`?`<0WG500`2LL3l209]_?PP0Wg=4202OLd840:5eA0@0X7A30P2RMTL0
102QMD@0XGI30:5f@`2QMT420:9g@080WgE30P2PMT@20:5gA@80XWQ60`2SN4<20:AiA0<0YGY50P2W
O4T0102VNdP0YGY70:EjA`2TNDH20:=hA@80XgY60`2TNdL30:ElB080XgY40P2TNdD20:ElAP80YWe7
0P2WOD/30:IlBP<0YG]9202RN4H209ec@@<0W7900`2KLCl209Q]@00309M/?`2FJch0UFXm0080U6Tl
00H0TfPk08eV?@2<IC`0S6Dj08]U>029Hc@208QR<@0408MR;P26HC@0QV4d08IQ=080QF0c0`24Gc82
07UF;00407YG;@1kF2h0NeP^07aI;`80OEX`0P1jEbl00`1iERh0Me@/07IC:`0207EB:P0307AA:@1c
D2P0KTXX00<0KTXX0P1_BbT2071<:P0606e69`1[AbL0JdLW06]8:01ZBBP0J4XX0P1WBRP206I99`03
06M99`1YB2L0JTLW0080JdLW00<0KDHW06M69@1WARD01P1WARD306U89`@0JTTX00<0JdXY06i>9`1^
CRL00P1_CbP0101`D2T0LE4Z079B:`1bDR/207QB:`0407UC;01jE2d0NeD^07]E;P80O5H_00/0OUT_
07eH;P1kER`0NUD[07]F;01nFBl0P5/a089M<`25Gc80Ped`085K;P02081J;@0;089L;`25Gc80Qf4d
089L;`23GC00QV0c08MQ=028HSD0Qf4d08EO<P24GS400P27GS8608QO<`80RF<d0P28HS<01027HC80
QV0a08IP<@26H34808EQ<@<0QV0c0P27HC@308QR=@<0QElb1026H3<00`27HC@0R68e08QR=@0608QR
=@0:08UR=`29HcH0R68e08MQ<P26H2l0QF0/08EP:`24GbX0Qf4d08IP<`<0QElb00<0Qf4d08US=P2:
I3L02@27HSD208IP<@0408MQ<P28HS<0R68c08US=080RV@e0P27G2l01028GC00REha08YO<P2:Gc82
08]P<`H0Qf4b1028HS<308MQ<P<0QV0a00<0Q60`08IR<P28I3@00P2:ISH00`29ICD0R6@d08MS<`02
08IQ=0<0QF0c0`24Gc8608IR<P80QF4a1025H3<01024Gc80Peha089M<022GC0208=N<@80PUd`1021
G2l3089M<0@0Peha00T0PUd`08IQ=025H3<0Q5lb08=N<@22GC00PE`_081K;P1oFRd01P21G382089M
<`P0OUT_00L0Oe`b07iK<@1mFS00O5T_07]H;P1jEbd0NEH/00<0N5D[101iER`207YG;@P0NUP[101d
E2/407EE;080MED^0`1dE2d307=C;080KU8[101]DBX306a@:@0606]>;01ZCB/0JD`Z06Q;:@1VBBL0
I4LU0P1SAR@01P1SBR80HTPS06989@1QAb@0H4HU05m49P80GT<V0P1JABP0101IA2L0F4<V05M29@1F
@B@205E08`80DT4U00P0DD0T04ln8P1>?B40CC`P04`k7`1;>Qh0D3XR04hj8@80BcXP00@0BCTO04Pj
7`16>al0AS/O1@16>1d304Dg70@0AcPQ1018>B8204<g7`<0A3PP0`15>B48048h7`80?cDL0P10=Qd2
044g7P80@SPO0`13=al304@h8080ACTQ0P11=ah6048h7`80@CXN00<0@cTN04@h7P16>1h00P17=ah0
0`18=Qh0A3PP04@h800404@h8080@cLO0`14>1h204Di7`<0ASXP0P1;=ah00`1:>Al0BCTO04Pj7`02
04Ll800504Hm8015>Al0ACTO04Di7`16>R000P17>b4204Pl8P80A3TM00H0@cPL04@i7@15>Qh0Ac`P
04Xo8`1;@2@804`l8PT0D3dO0P1E@2<0101D@B<0DT4S05508P1@@B8204m28P08054n7P1B?al0Dd0P
05A18@1F@b<0Ed@T05Q59@1IARH405M28`80ET4R00D0ED0Q05@o801D?b00ED0Q05M28`0205Q39003
05M28`1E@240E3lP00P0ET@P3@1HAR800`1IAb<0FTPT05Y8900205A68@0305E58@1HAR80FDDR0080
G4DS00@0GTHT05]99@1KBBD0FdTU0P1JB2@605U78`80F4HR2`1IAb<00`1GAb<0ETHR05E58@0205A4
800305I68P1HB2@0FDTU0080GdTT0`1NB2<305e78P0>05Q98P1KBB<0FdTS05e9901QBbH0Hd/W06A:
9`1UBbP0JTd[06Y>:@1[CbX0K50Y06eA:@1]DRL206iC9P80L5<Y0P1aE2P02@1bERL0LeLW07AH9P1d
F2H0MePY07QI:P1iFR/0NU//07]L;@0307aM;P80P5h^00<0PEl_089P<023HC400P24HS800`25Hc<0
RfLe08]W=@0208]W=@<0RVHd0P29IC<0102>JSP0Sf/i095]>`2DL40209Ea@@0509A_@P2CKT40UG8l
09Ic?@2GM3h00P2IMT000`2GM3h0UW<m09Eb?00209Ud@080VWE100@0VgI209ag@`2MN4@0WWU50`2K
MT801P2MN4@0WgY60:9mB@2UP4`0YX5=0:AoBP80YH1;00<0YX5<0:N2C@2XPdh01@2YQ4l00`2ZQE00
ZhIA0:^6D@020:b7DP80ZXAC0P2[QE@20:b6E@80[HMF0P2^RUX20:n;F`80/8aL0P2aSEd00`2^RUH0
[h]G0;:>FP020;>?F`030;:>FP2_ReL0[XYF00P0/heL202bS5d00`2_Re/0/8aL0;6=G@020;>?G`03
0;6=G@2`S5`0[h]K0080[h]K0P2`S5`20;6=G@80/XiN00P0/heN0;:<G@2`RU/0[hUJ0:j8F@2_REX0
/8YK0;6;G0P0/XeI00H0/hiJ0;:=F@2bSET0/HaH0;2;E`2_RUH40:j9E@H0[hYF0P2bSET20;6<F080
/8]G0P2_RUH90:j:EPP0[hUH202aREH30:n:EP80[XUE0`2]R5@80:n:EP060;F;F`2dRUX0]8YH0;>:
EP2bRED0/HQB0P2`Qdl20:j9DP030:n:E@2_RUH0/8YI0080/8YK00@0/H]N0:n:EP2_RUH0[hYF0P2^
RED30:f8E0030:f7F02/QUL0[8IG0080[8IG0`2]QeP80:f8E0080;2;E`2^RED0[8MC0:^6DP2ZQE40
ZhIB0:b7D`2]R5@80:f8D`060:^6DP2/Qe<0[8MC0:f8E02^RED0[hYF0P2`ReL80:n5D`P0[HQC0P2^
R5T20:f7F080[8IG0P2[QEH01P2[QEP0ZhEF0:^5EP2[QE@0ZhIB0:^6D@80ZhI?00H0[HQC0:f8E02]
R5@0[HMF0:f7F02]QeX20:f6F`030:f8E02/Qe<0ZhIB0080ZXEA00<0ZhIB0:f8E02^RED00P2ZRE@0
1`2[Qe<0[8MC0:b7D`2]QE80[XAB0:f3D@2^PU400P2^QE440:n6DP80[XEA202ZQE420:b3C@030:b3
C`2]Pe40[H=C0080[X=F00@0[X=H0:j5D@2]Q500[8=?0P2[PTh00`2]Q500[hIB0;27D`030:b7D`<0
ZhIB1@2ZQE420:^6DP<0[8MC1P2[QU820:b7D`P0[H=A00<0ZhIB0:Z5D@2YQ5000P2XPdl00`2ZQE40
ZhIB0:f8E0080:n6DP/0[8MC0P2[QU830:Z5D@80ZhIA0`2/Qe830:f8D`80[hYF0`2^RED30:f8E006
0:b6F@2/QUL0[8IG0:b6E@2/Qe<0[8MB0P2/Qe020:n5D`<0[XAB00<0[hEC0;67E@2bR5H00`2]R5@4
0:b7D`060:^6DP2/ReH0[8]F0:j:EP2_RUH0/HUF0P2bR5H00`2cQeH0[HQD0:f8E00G0:j9E@H0[HQD
0P2/Qe<30:f8D`80[XUD0`2_RUD0202/Qe<0[HQD0:j9E@2_RUH0[XUE0:f8E02[QU80ZHA@0`2aQeD0
0`2`QU@0[hEC0:n5D`020:j4DPP0ZXAC0P2]Pe420:j4DP80[hEC0P2`QU@80:f8E080ZhIA0P2/Qe82
0:f8D`80[XUD202[QU420;68DP060;27D`2`QU@0[hEE0:n4E`2^PeH0[X=H202[QEH50:f4D0030:j5
D@2_QU80[hIB00X0ZhIB0P2/Qe<20:f8E080[XUE0P2/Qe<60:f8E080ZXE>00<0ZhIA0:^6DP2[QE@0
0P2/QUL0102/QUT0[HQD0:b7D`2[QU820:V4D080ZhIB00<0[8MC0:f8E02]R5@01`2]R5@20:j9E@80
[HQD0P2/Qe<20:^6DP<0[8MC0`2[QU820:Z5D@050:Z0CP2[PDl0[89@0:f3D@2^Q5800`2_QE<00`2[
QU80[8MC0:f8E0020:j9E@030:f8E02/Qe<0ZhIB00<0[8MC0`2[QU820:Z5D@80Z8=?0`2YQ5040:Z5
D@070:^6DP2]R5@0[XUE0:f8E02[QU80ZHA@0:R3C`080:V5D@80ZhIB102ZQE420:V4D0P0[HMH0`2[
QEH30:Z4E@80ZH=D0P2[PDl60:b2D0X0ZXEA0`2YQ5030:R3C`040:N2C@2WPTh0Z8=?0:R3C`80Z89A
0P2WPE080:V4D0030:^6DP2ZQE40ZXEA0080ZHA@0P2XPdl00`2WPTh0ZH=D0:V3E0070:V3E080ZH1<
00<0ZX5=0:^2CP2[PTh00`2[PTh;0:J1C@80YH1<0`2TOd/20:9mB@H0Xgi:0P2RODT60:5lB0P0WWQ7
1P2TNTP20:EkB@060:AhA`2SNDL0XgU70:9jA`2PNdL0Wg]70P2MO4L01P2PNdH0X7]70:1kA`2QNdX0
XG]<0:9lC`80XW]@0`2RODT[ooooo`00:_ooool809AX>`P0UFTl0P2CJ3/409AY?080TfPk102GJch4
09IZ?@0809UY>@2JJSX0Vf/k09a/?02MKCd0W6`l09YZ>P2IJCT609Q/?`80Uf/n202IKC`309]_?P80
W70o0`2MLD0309U_?@0309Y`?P2KLCl0Vg4o0080W7902@2LLCh01P2QMD@0X7A30:1d@`2OLd80WW91
09ea@080W70o0P2NLT4309ea@0<0W70o402OLd830:5eA080X7A30`2OLd820:5eAP040:9fA@2RMd@0
XWM40:9g@P80XGHo102PMT@40:5gA@<0XgQ30P2TND@30:EjA@80Z7e:00@0Yga90:IkB02UNTL0Y7U6
0P2SN4D20:=jAP<0Y7]70`2UO4P30:=jA080Y7]50`2UO4H30:IlBP<0YG]90P2TNTP40:9hAP@0XGM5
0`2LLT0309]a?`80VW0n0P2GK3l00`2FJch0UFXm09AY?00209=X>`09099W>P2;I3d0Rf@m08YS>P29
HSL0RF<f08QR<`27HC80Qf4`0080QV4d0P25H3<208AO<P80Peha0P1hEB/0101iER`0NUL]07]H;P1l
FBl207eJ<080N5L^00<0MeH]07IE;01dDbX00P1cDRT00`1bDBP0LE0W06e99`0206e99`<0KTXX0P1_
BbT01P1/ABH0JdLW06]79`1ZAbL0JTTX06U;:@80J4/Y0P1VBBL00`1WBBL0JDPW06Y79`0206]79`03
06e69`1XAbH0J4LV00H0J4LV0P1YB2L206Y9:00:06]::@1/BbX0K4/Z06a;:P1_CBL0L4hX075?:@1b
D2X0Le4[07AB;080ME<]0P1iDb`0101jE2d0NeD^07aF;`1mEc0207iH<@03081K<@1nFBl0O5L]0080
NeH/0100OUT_089M<`24GcD0QElb08AN<@22G2l0P5X]085K;P23GC00QV0c08QR=@24GS40QElb08IP
<`27HC@0R68e0P27HC@708IP<`80QElb00<0R68c08MQ<P27HC800P27HC8308IP<@P0QF4a0`26H3<2
08MQ=0<0R68e0P24GS4208EO<P0408IP<`27HC@0Qf4d08MQ=0P0RF<f00H0RV<j08UR=`29HSL0R68e
08MQ<P26H2l208EP;00808QR=@27HC@0QV0c08EO<P26H3<0Qf4d08US=P2:I3L908MR=@0508IP<@27
HC80Qf4b08QR<`29Hc@00P2:I3D01`2;ICH0Qe`_08QM<028GC00REha08YO<P2;H3<00P2<HC@608MQ
<P80QV0a0`28HS<308MQ<P80QV0a00<0QF4a08IR<P28I3@00`29ICD208QT=080QV4d0`25H3<308AO
<PH0QV8b0P27Hc<00`25H3<0Q5lb08AO<P0708=N<@80PUd`1021G2l208=N<@80PUd`00@0PE`_089M
<022GC00PUd`0P25H3<01024Gc80Peha085L;`20Fbh207mJ;@H0PE`b0P20Fc4807eH;P80OU/a00@0
OEX`07aI;`1jEbd0NEH/0P1hEB/207MD:P80N5D[0P1iER`:07YG;@P0M5@[00@0MED^07AD;@1dE2d0
M5@]0P1cDb`2079B:`80KE4/0P1/D2/206]?:P<0JThY00D0IddZ06I<:@1UBbP0I4XW06=99P020657
900906168`1OAb40GdLS05i68P1MAB<0G4<T05]2901K@BH0FT0U0080Ed<X00<0ET8W05E19P1D@2D0
0P1C?b@01`1B?R<0DD0V050o9@1??R@0CSdS04dl8P1;>R000P1:>Al01P1<>200BSPP04Xh8019>B00
B3XP04Di7`80@cTN0`12=Q`504<g7@@0ACTQ1014>202048f7P80@cLO1014>208044g7P<0?cDL0P10
=Qd3044g7P<0@cLO0`14>20204Di8@80@3TO1P0o>1h2044j7P0304<i7P14>1h0ASPN0080AcLN00<0
B3HN04<g7`13=al01P14>20304@h7P80ACTO0`16>R0204/g7P0304Xi7`19>Al0B3XO0080Ac`P00<0
ASdP04Di7`16>R000`16>R0304Lk8@0804Dj7P14>Ad0A3TM04@i7@15>Qh0B3dQ04Xo8`1<@BD804`l
8PT0DChP0P1E@2<0101D@B<0DT4S05918`1A@R<205138`80DSlO00@0Dd0P05A18@1F@b<0Ed@T0P1H
ABD205I38`0305E28P1D@B40E44Q00<0E44Q00<0Dd0P05A18@1E@R800P1F@b<00`1E@R80E44Q05=0
800805I480P0F4HR00@0EdDQ05Q68P1HAR80FDLS101JB2@205A68@0305I68P1HAR80FTHS0080G4DS
00@0GDDS05]99@1KBBD0FdTU0P1JB2@305U78`<0G4XV0P1MBbL305a:9PP0F4DT00<0ETHR05E58@1D
A2000P1C@al00`1EAB40EdLS05Q8900305]78P<0FTHQ0P1IAB001P1HBB80FTPR05]98`1MBB@0GdTT
06599@80HdTV00H0JD`Z06U=:01ZCRT0JdlX06a@:01/DBH206eB9@80KU4Y00@0Ke8X071C9`1aEBH0
LEDV0P1bERH307MH:@0307QI:P1iFR/0NU//0080Ne`]00H0OU`/07mM;@1oGBd0P5h^085O;`22H302
08=Q<@@0RVHf0`29ICD208QT=00608eX>`2?JSd0TFdm09=_?`2DL400Tflm0P2BKS`00`2DLC/0UG8l
09Md?P0209Qe?`0709Md?P2ELS`0U74k09Qc?`2IM400VWE109]f@P0209ag@`80WGQ400T0VgI209Ye
@@2JMD40VgI209ehA02QO4P0Y7m;0:J1C@2SOTT00P2TOdX00`2UP4/0YX5<0:N2C@020:R3CP<0ZHA?
102ZQE00102[QU40ZXEA0:Z5D@2ZQE420:^6DP<0[8MC0`2^RUX20:n;F`<0/8aL00<0[XYF0:n;E`2b
SUX00P2cSe/00`2bSUX0[h]G0:j:EP080;F=FPP0/XaM00<0[XYJ0;2<G02aSEd00P2bSUh00`2aSEd0
/8aL0:j:FP020:n;F`80/8aL0P2aSEd20;:>GP080;>=GP2bS5d0/8YK0:n9FP2^R5T0[hUJ0;2:F`2a
Re`80;:=F@060;>>FP2bSET0/XeI0;6<F02`ReL0[hYF0P2^RED20;2;E`H0[hYF0`2aS5P20;2;E`<0
[hYF2@2^RUHB0:n:EP80[XUE0P2]R5@20:b7D`P0[hYF0P2dRUX01P2cREL0/XUE0;68E02`Qe40/8M?
0:n6CP80[hYC00H0[hYE0;2;E`2`RUT0/8YK0;6;G02aReh20:n:EP80[XUE0P2]R5@20:b7D`030:b6
E`2]QeP0[HMH0080[HMH0`2/QUL80:b7D`080;2;E`2^RED0[8MC0:^6DP2ZQE40ZhIB0:b7D`2]R5@8
0:f8D`060:^6DP2/Qe<0[8MC0:f8E02^RED0[hYF0P2`ReL80:j4DPP0[HQC0P2^R5T20:f7F080[8IG
0P2[QEH01P2/QUT0[8IG0:b6E`2/QUD0[8MC0:b7DP80[8M@00H0[HQC0:f8E02]R5@0[HMF0:f7F02]
QeX20:f6F`030:f8E02/Qe<0ZXEA0080ZHA@00<0ZXEA0:^6DP2/Qe<00P2YR5<0102[Qe<0ZhIB0:^6
DP2]QE820:f3D@030:j2D@2^QE40[XEA00H0[XEA202ZQE420:b3C@030:b3C`2]Pe40[H=C0080[X=F
00@0[X=H0:j5D@2]Q500[8=?0P2[PTh00`2]Q500[hIB0;27D`030:b7D`<0ZhIB102ZQE420:^6DP80
[8MC0P2]R5@20:b7D`H0ZhIB202]Pe40202ZQE40ZHA@0:R3C`2XPdl0ZHA@0:Z5D@2/Qe<0[HQD202_
QU8:0:f8E080[8MC0P2[QU820:Z5D@<0[8MB0`2]R5<20:j9E080[hYF0`2^RED30:f8E0060:f7FP2]
QeP0[HMH0:f7EP2]R5@0[HQC0P2]R540202aQeD0/8ID0:j4DP2]Pe40[XAB0;26E02bR5H0/hUG0`2^
RED00`2]R5@0[8MC0:b7D`020:^6DP80[8]F00<0[XYF0:n:EP2aREH00P2bR5H00`2cQeH0[XUE0:j9
E@050:j9E@80[HQD102^RED40:f8E0@0[XUE102]R5@60:b7D`80[HQD0P2/Qe820:f8D`80[XUD0P2_
RUD0202/Qe<0[HQD0:j9E@2_RUH0[XUE0:f8E02[QU80ZHA@0`2aQeD40;26E0030:n5D`2ZQE40ZXEA
00H0ZXEA0`2]Pe420:j4DP<0[hEC202/Qe<20:^6D@80[8MB0P2]R5<20:j9E0P0ZhIA0P2aR5801P2`
Qe<0/8ID0:n5E@2_Q5L0[X=F0:j3F0P0ZhEF00@0[8=?0:f4D02]Q500[XEA102_QU880:^6DP@0[8IE
102]QeH20:f8E0H0[8MC0P2ZQDh00`2[QU40ZhIB0:^5E0020:b6E`040:b6F@2]R5@0[8MC0:^6DP80
ZHA@0P2[QU800`2/Qe<0[HQD0:f8E0070:f8E080[XUE0P2]R5@20:b7D`80ZhIB0`2/Qe<30:^6DP80
ZXEA0`2[PDl0202/PU00[H=A0:j4DP2_QE<0/8ID0:^6DP2/Qe<0[HQD0P2^RED00`2]R5@0[8MC0:^6
DP030:b7D`<0ZhIB0P2ZQE40102XPdl0ZHA@0:V4D02YQ5020:Z5D@<0ZhIB0P2/Qe<01@2]R5@0[8MC
0:^6DP2ZQE40ZHA@00P0ZHEA00<0[8MC0:^6DP2[QU800P2ZQE420:V4D0030:R3C`2]QeP0[HMH00H0
[HMH0P2[QEH30:Z4E@<0ZH=D00<0[H=A0:b2D02/PU000`2[PDl20:b2D0X0ZXEA0`2YQ5030:R3C`80
Z89A0P2WPE020:N2CP030:R3C`2XPdh0ZHA@00L0ZHA@102ZQ5<40:V3DPT0ZH=D102ZPDd20:^2CP03
0:b3C`2]Q500Yh9>00<0Yh9>1`2VPDd20:F0C0<0Y7m;0P2SOTX60:9mB@H0XGa80P2RODT809ihB@80
YG]91P2TNTP01P2TN4L0XgU70:=iA`2RNTL0X7]709mkA`80WGa700H0X7]60:1kA`2QO4P0XG]:0:9l
C@2RO4l20:=lD@<0XGa8:oooool002[ooooo202DJ3/809IZ?@0309=X>`2DJC`0UFXm0080UV/n00<0
UFXm09AY?02CJ3/00`2HJd4209MZ@0<0UVTo00<0V6Ph09YZ>P2KJc/00`2MKCd00`2KJc/0VVXj09U]
@00209U]@0<0V6`o0P2GJch809Q/>`80VVhm0P2KKch309a`?`0609ea@02HKS`0V6hl09U_?@2JL3h0
Vg4o0P2LLT000`2MLd40W74n09aa?P0709aa?P<0WW910`2MLD0209a`?`P0WG50202OM44<0:1d@`@0
Wg=200<0X7A50:5eAP2RMTD00P2SN4D00`2RMd80XGHo0:1e?P040:1fA0@0XGM50`2SN4<20:AiA0<0
YGY50P2XODX0102WO4T0YW]80:EjA`2UNTL20:AiAP80XgY60`2TNdL30:ElB0040:9i@`2SNT@0XgY4
0:=jA080Y7]50P2UO4H30:IlBP80YG]90`2TNTP00`2SNDL0XWQ60:9hAP020:5gA@<0X7I40`2LLT02
09]a?`<0VW0n0P2FJch00`2EJSd0U6Tl09=X>`02099W>P07095V>@29HCd0RF4m08UR>`28HCP0R64f
08MQ=00208MQ<P<0QF0c0P24Gc8308=N<@80NEH/00@0NUL]07]H;P1kF2h0O5T_0P1mFS001@1gEbh0
MUH]07EE;01dE2/0LU8Y0080LE4X00<0L50W06m?9P1^BRP01`1^BRP0201^AbP0K4PX06a8:01/BBT0
JdXY06U;:@1XBbT0JD`Z0P1VBBL00`1WBBL0JDPW06Y79`0206]79`0306e69`1YB2D0JDPU00H0JDPU
00H0JDPW06Y9:01ZBBP0JdXY06a;:P1]C2/206i=;006075>:01bCbT0Le0Z07AA:`1eDR`0Me@^0P1h
EBl01P1jE2d0NeD^07]E;P1lERl0OEL`07iH<@80OeTb00<0PUdc085L<P1oFS000P1nFBl01@20Fc40
PUdc08AO=@25Gc80Q5ha0080Ped`00H0Q5ha08EO<P26H3<0Qf4d08EO<P26H3<208MQ=0@0R68e0P26
HC@308EP<`<0Q5lb2026H34808EQ<@<0QV0c0P27HC@308QR=@0608=M<024GS40Q5ha08EO<P26H3<0
Qf4d0P28HSD808US=P0608UR>`28HCP0R64h08QQ=P27HC@0Qf4b0P27HC000`28HSD0Qf4d08IP<`02
08IP<`0308QR=@29HcH0RfDh00T0Qf8e0`28HS<308US=080RV@e0P2:Gc8308]P<`<0S64d1027HC82
08IP<@80QEl`0P29Hc@208QR<`<0Qf4b00D0QV0a08EQ<@26HS80QV8b08MS<`0308QT=00308MS<`26
HC@0QV4d00<0QF0c0`24Gc802P27Hc<0QV8b08IR<P25HC40QV8b08MS<`28I3@0RFDe08AO<P23GS44
089M<00408=N<@24Gc80Q5lb08AO<P<0Peha0`22GC001024Gc80Peha089M<021G2l2081K;P03085L
;`22GC00Q5lb0080Peha00D0PUd`085L;`20Fbh0P5/^07mJ;@04085L<P80P5/a0P1oFS0807eH;P05
07eJ<01lFBl0O5T_07]H;P1jEbd00P1iER`01@1hEB/0MU<Y07IC:@1gE2X0N5D[0080NEH/0P1jEbd8
07UF;P0407EE;01dE2/0M5@[07AD:`<0Le<Z00@0LU8Y07=C;01cDb`0Le</0P1bDR/3075A:P80K4l]
0P1[CR`00`1ZCB/0JD`Z06Q;:@0206Q;:@80Hd/Y00<0HTXX06599`1PB2H00P1OAbD02@1NAR@0G4HQ
05a58`1KA280FT<S05U28`1H@2@0F40V05Lo9@0205919`0305509P1@?bD0CchT0080CSdS00@0CC`R
04dm901=?B@0C3`S0P1;>b80101:>R40BCTP04Ti8018=R0204Ph8@0504Pi8P15>B40@cTP040i7`0o
>1h00`11=ah3048h7`80@cTP0P14>R4204<i80@0@SPO0P11=Ad2048f7P<0@cLO00<0A3PP040f7@10
=Qd01P10=Qd0100n=1/0?cDL03le700o=A`2040f7@80@CLN0`13=al304@h8080ACTQ0P10>Al303lh
7P<0?SLM0P10>Ad00`12>1d0@cLM04Dg7@0204Hf7@0404Le7@13=al0@cLO04<g7`<0A3PP0P15>B43
04@h7P80ACTO0`16>R001@1=>B00C3PO04Xi7`19>Al0B3XO0080AS/O00<0AC`O04Hj8016>R001P16
>R002017?200AS/O04Dj7P15>Qh0AS/O04Ll801:?b<0Bd0T201<?289058o8@0805@o8P1E@2<0E44S
05918`1C@R@0DT<T0554901BABD305A18@80ED8R0`1F@b<00`1DA2<0Dd<R05928@02055180030592
8@1C@b80Dd<R0080DT8Q101C@b8205928@P0ET@P201HAR80101GAB40F4HR05U78`1JB2@205]99@07
05Y8901IAb<0E4HQ05E78P1GAb<0FTPT05a89@0205e6900405e58`1KBBD0FdTU05]99@80FTPT0`1I
Ab<00`1KBBD0G4XV05e;9`0205i<:00305e;9`1LBRH0FdTU00P0Ed@T00P0EDDQ05A4801C@al0DT8N
05=37`1DA200ETHR05M78`P0F4HR00H0F4TR05Y88P1JB280G4PS05i88`1PB2@20657900806M::01W
BbH0J4`W06U=9P1ZCRH0Je0U06]@8`1/DB@206a>:00306e@:01^DBL0Ke8V0080L5@U00<0LEDU07IG
:01fEbP00P1eERL0101fEbP0N5TZ07YK;01kG2d207eK:`0307iL;01oGBd0P5h^0080PEl_00<0PV0`
08IT=P26I3H01026I3H308MU=`0;08aW>`2=J3`0SfXm095]?@2AKC/0TFdi091/>02?K3H0Tg0j09Aa
>`2FLcd00P2GM3h01`2FLcd0U74k09=`>P2GLSh0V7<o09Ud@02KMT800`2LMd<02P2KMT80W7M309]f
@P2JMD40VGA009]f@P2ONTH0Xgi:0:F0C02RODP20:=nB@030:AoBP2UP4/0YX5<0080Yh9=2@2YQ4l3
0:Z5D080ZhIA0P2/Qe80102]RET0[XYJ0:j:FP2^RUX20:n;F`80/8aL00<0[h]G0;2<F02aSET00P2b
SUX00`2aSET0/8aH0:n;E`080;F<F0P0/XaM00<0[XYJ0:n;F`2aSEd00P2bSUh00`2aSEd0[h]K0:j:
FP020:n;F`80/8aL0P2aSEd20;:>GP080;>=GP2bS5d0/8YK0:n9FP2^R5T0[hUJ0;2:F`2aRe`80;:=
F@<0/HaH0`2`ReL20:n:EP80/HaH0P2`ReL40:n:EP80/HaH0P2`ReL30:n:EP030:j9E@2]RED0[HUE
00L0[HUE202_RUD80:f9E@<0[XUE0P2]R5@30:b7D`P0/8]G0P2bR5P01P2bR5H0/XUE0;68E02aR580
/HQ@0;27C`80[XUB00<0[XUD0:n:EP2_REP00P2`RU/0102`RUd0[XUE0:j9E@2^RED20:f8E0<0[8MC
00<0[8IG0:f7F02^R5T00P2^R5T00`2/QUL0ZhEF0:Z4E@080:b7D`080;2;E`2^RED0[8MC0:^6DP2Z
QE40ZhIB0:b7D`2]R5@80:f8D`<0[HQD0`2^RED20:n:EPP0[XAB202]R5<20:j8F@80[HMH0P2/QUL2
0:^5EP060:b6F@2/QUL0[8IG0:b6E@2/Qe<0[8MB0P2/Qe001P2]R5<0[HQD0:f8E02]QeH0[HMH0:f7
FP80[HIK00<0[HQD0:b7D`2ZQE400`2YQ5001@2ZQE40ZhIB0:V8D`2YR5<0ZXIB0080ZhIB00L0[8AA
0:f3D@2]Pe40[H5@0:n6DP2^QE40[HA@0080[8=?00<0[HA@0:j5D@2_QU80202ZQE420:b3C@030:b3
C`2]Pe40[H=C0080[X=F00@0[X=H0:j5D@2]Q500[8=?0P2[PTh00`2]Q500[hIB0;27D`030:b7D`<0
ZhIB0P2ZQE430:^6DP80[8MC0`2]R5@30:b7D`<0ZhIB0P2ZQE480:f3D@80ZHA@0P2XPdl0102YQ500
ZhIB0:f8E02^RED80:j5D@/0[HQD0P2/Qe<30:^6DP<0[8MB0P2]R5<30:j9E080[hYF0`2^RED30:f8
E0060:f7FP2]QeP0[HMH0:f7EP2]R5@0[HQC0P2]R5400`2bR5H0/8ID0:j4DP020:f3D@030;26E02b
R5H0]8YH0080[hYF0P2^RED0102]R5@0[8MC0:^6DP2[QU820:^:E@030:f9E@2_RUH0/HUF0080/hUG
00<0]8QG0:n:EP2_RUH0102^RED30:f8E0<0[XUE0P2]R5@30:b7D`<0[XUE0P2]R5@30:b7D`<0ZhIB
0`2/Qe<20:f8E0<0[8MB0P2]R5<30:j9E0080:b7D`2]R5@0[XUE0:n:EP2^RED0[HQD0:^6DP2YQ508
0;26E0P0ZXE@00@0[89@0:f3D@2]Pe40[H=A0P2^Q5820:n5D`P0[8MC0P2[QU420:b7DP80[HQC0P2^
RE@80:^6D@80/HQB00H0/8MC0;26E02_QED0[hAG0:j3EP2^PeP80:^5EP040:f4D02^QE40[hIB0;27
D`80/HQD00<0/8MC0:n6DP2[QU801`2[QU840:b6E`@0[HMH0P2]R5@30:b7D`<0ZhIB0P2ZQDh00`2[
QU40ZhIB0:^5E0020:b6E`040:b6F@2]R5@0[8MC0:^6DP80ZHA@0P2[QU800`2/Qe<0[HQD0:f8E007
0:f8E080[XUE0P2]R5@20:b7D`80ZhIB0`2/Qe<30:^6DP80ZXEA00/0[89@0:^1C`2[PDl0Zh5?0:b2
D02^Q580/8ID0;67E@2[QU80[8MC0:f8E0020:j9E@030:f8E02/Qe<0ZhIB00<0[8MC0`2[QU850:Z5
D@80ZhIB202/Qe<00`2[QU80ZXEA0:Z5D@080:Z6DP80[8MC00@0ZhIB0:Z5D@2ZQE40ZHA@0P2XPdl8
0:b6E`040:^5EP2ZQ5D0ZXAE0:Z4E@80ZH=D0P2XPU<01@2^Q580[H=A0:b2D02[PDl0ZX1>0080Zh5?
00@0[89@0:V4D02YQ500ZHA@0P2ZQE430:^6DP80ZXEA0`2YQ5030:R3C`080:V3EP2XPUD0Yh5B0:J0
C`2VPDd0Yh9=0:R3C02YQ4d80:V4D0P0ZH=D2@2XPU<20:Z1C@80ZH1<00@0ZX5=0:b3C`2^QE40[hIB
0`2XPdl20:N2CPH0YX5=0P2UP4`30:AoB`80Xgi:0`2RODT30:5lB080X7]70`2QO4P30:9mB@P0WgU<
0`2UNdT30:AjB080XgU700H0XgM60:9hAP2RN4H0XGU609mjAP2NNTH209akAP060:5lA`2QO4P0XGa8
0:9lB`2RO4d0Xge@0P2SO5430:5lB2_ooooo000Zooooo`P0U6Pk202FJSd00`2DJC`0UFXm09M/?`02
09Q]@00309M/?`2EJSd0U6Tl0080VFa30P2HJd80302GJT40UVU009IY@02FJD00V6Ph09UY>@2KJc/0
WFdm09i^?P2MKCd0W6`l09][>`80VVi10P2IKD0209Q/?`80Uf/n202HK3/209U]?080VVhm102KKch0
1P2GKC/0V6hl09U_?@2JL3h0Vg4o09ab@080WG=12@2LLCh309]_?P<0W70o0P2MLD001@2KKch0W70o
09a`?`2MLD00WW910080Wg=200<0X7A309md?`2OM3l01P2OM3l80:1d@`D0Wg=20`2PM4<00`2PM4D0
XGE60:9fA@020:=hA@030:9g@P2QMSl0X7Dn00@0XGM5102PMT@30:=h@`80Y7U40`2UNTD01P2YOT/0
Z7e:0:QmBP2WO4T0YW]80:EjA`80Y7U60P2SNTH30:AkA`<0YGa80P2RND<30:=jA0<0Y7]500@0YWa:
0:EkB@2UNdT0YG]90P2TNTP20:=iA`80Y7Y800L0XgU70:5gA@2PMT@0WgE309id@P2MLd40W79000<0
Vg4o0P2JL3h209U_?@0609I[?P2EJSd0UFXm09AY?02CJ3/0TVLj0P2AIST01P28H3d0R60l08QP?028
HCX0Qf0g08MP=@80Qf4d0P25H3<208AO<P@0Peha1@1lFBl307eJ<00507IF;@1eEB`0M5@[07=C:P1a
DBP00P1`D2L206m?9P80LDd[00<0L4`Z06m;:@1^BRP00`1]BBL01P1aBR/0Kd/[06m;:`1]BRX0K4/Z
06Y<:P80JD`Z0P1VBBL00`1WBBL0JDPW06Y79`0206]79`0306e69`1ZBR@0JTXT00H0JTXT00H0JDPW
06Y9:01[BRT0K4/Z06e<:`1^CB`206m>;@80LTlY00L0Le0Z07EB;01fDbd0N5D_07UF<01jEc40NeD^
0080O5H_00<0OEL`07iH<@1oFC800P20FS<208AO=@0308=N=022GC<0PUdc00<0PUdc00@0Ped`08AN
<@25Gc80QV0c0P27HC@00`26H3<0QElb08MQ=00308MQ=080R68e0P29HcH308AR=00308=Q<`22H380
PV0b0080PEla2026H34808IR<P<0QV0c0P27HC@308QR=@80Ped`00D0Q5ha08EO<P26H3<0Qf4d08QR
=@0908US=P80Qf0i00<0Qf0g08QQ=P28HSD00P29Hc@01029Hc80RF<f08QR=@27HC@208IP<`0308QR
=@2:I3L0RfDh00T0Qf8e0`2:I3D308US=080R68c0`2>HcH208eR=@<0S64d00<0R68c08MQ<P27HC80
0P26H34208EO<00408AN;`29Hc@0RF<d08US=080R68c0`27HC8208AP<0<0QF4a0P26HS800`27Hc<0
QV4d08IQ=00308EP<`<0Q5lb00<0Qf<c08IR<P25HC400P25HC402P27Hc<0RFDe08]W=`24Gc80Peha
085L;`20Fbh0PE`_089M<024Gc8408EP<`<0Q5lb0P23GS401025H3<0Peha085L;`20Fbh207mJ;@X0
PE`_00<0PUdc085L<P21G3800P20Fc4207mJ<00307iI;`1lEbd0O5L]00H0O5L]201jEbd207EB:006
07IC:@1gE2X0N5D[07UF;01jEbd0NeP^201iES0207EE;080M5@[00@0Le<Z079B:@1bDRT0LU8Y0`1a
DBX2071@:@<0KdlX0P1/Cbl01@1[CRh0JTd]06U<;01XBb/0IdXZ0080ITTY0P1QBRX0101PBBT0GdPX
05m8:01NAbL205e69P80F4@Q00<0Ed<R05I18P1E@2<00P1D?b@01P1C?BD0CShT04hn901=?B<0C3`R
04/k8@80BSXP00<0BCTO04Tj8`19>R<01P19>R<02015=200ASDQ04Lh8`15>B<0A3TS040h8@0n=Ql0
?3HN0P0o=b02040h8@05044i8P12>R<0@SXS048j8`12>b400P11>R02040i7`80?cPN00<0?SLM040d
7011=Ad00P11=Ad2048f7P80@cLO200o=A`203hd6`<0?cDL0`10=Qd304<g7`<0A3PP0P15>B4203li
7`80?SPN0P0m=ad203`f7080@3TM00<0@SPM04<g7@15=ad00P16=Qd00`17=Ad0@SHN048f7P0204<g
7`0404@h8015>B40ACTQ04Di8@<0A3PN0P15>Al304Hj8080CSXQ00H0BcXP04Xj8018>Ql0ACXN04@i
7@13>Qd204Lk8@H0ASXP00P0BChR04Pm8@16>al0ACXN04Hk7`17?200B3dQ04Tn8PP0C3`R2@1D@B<2
05@o8P0405A18`1B@B<0Dd8T05=49@80DTDU0`1F@b<205E28P<0E44Q00<0DT<R05528@1@@B000P1?
@1l00`1@@B00DT<R05=48`0805528@P0ET@P201HAR80401GAB40F4HR05Y8901KBBD0G4XV05]99@1J
B2@0FDLS05E78P1FB2<0FDTU05a:9P1NBRL0GdPV05i79@1NAR@305]99@80FTPT0`1IAb<00`1GAB40
F4HR05U78`0205]99@0305U78`1HAR80EdDQ00P0Ed@T00P0E4@P05=37`1B@Qh0DD4M05927P1C@al0
EDDQ05I68P80ED8Q0P1F@b801@1GA2<0F4DT05U69@1IARD0F4TR0080FTPR00<0FdLR05i88`1OAb<0
0P1PAR<01P1UB2H0IDTT06I:9@1VBR<0Id/S06Q=8P80JDhQ00X0JT`X06]=:@1[CBL0K4lW06e@9P1^
DBD0Ke8V06mC901fEbP0MEHW0P1dEBH0101eERL0MePY07UJ:`1kG2d207aJ:P0307eK:`1nG2`0Oed]
0080P5h^00<0PEl_08=R=@23HSD00P23HSD00`24HcH0QF@g08IU>00208MV>@0;08]U?P2<Icd0SFPl
08mZ?@2?JcT0SVXf08eZ<P2<JC40TVli09=`>P2ELS`00P2FLcd01`2ELS`0Tg0j099_>@2FLCd0Ug8n
09Ud@02KMT800P2LMd<02P2KMT80VWE109iiA@2LMd<0VWE109Qc?`2JMD40WGQ40:5lB02SOTX20:9m
B0030:=nB@2TOdX0YH1;0080YX5<00<0Yh9=0:V4C`2YQ4l01P2YQ4l20:V4C@<0ZXE>0`2[QTl20:f9
F@<0[XYJ0`2_Re/00`2bSUX0/HeI0;2<F0020:n;E`030;2<F02aSET0/XiJ00P0]HaF202bS5d00`2^
RUX0[h]K0;2<G0020;6=G@030;2<G02_Re/0[XYJ0080[h]K0P2`S5`20;6=G@80/XiN00P0/heN0;:<
G@2`RU/0[hUJ0:j8F@2_REX0/8YK0;6;G0P0/XeI0P2_RUH30;2;E`<0/HaH00<0/XeI0;6<F02aS5P0
0P2`ReL20:n:EP040:j9E@2`ReL0/8]G0;2;E`<0[hYF0P2^RED90:f9E@P0[hYC202[RUD20:j9E@80
[HQD102/Qe<80;2;E`80/8IF00@0/8ID0;68E02aR5@0/XUC0P2bRE420:f8D@030:f8D`2^RED0[XQG
0080[hUJ00<0[hUL0:j9E@2^RED00P2]R5@40:b7D`080:b6E`2]QeP0[XQI0:n9FP2^R5T0[8IG0:Z4
E@2YPe@80:^6DP080;2;E`2^RED0[8MC0:^6DP2ZQE40ZhIB0:b7D`2]R5@80:f8D`80[hYF0`2^RED3
0:f8E0P0[H=A202]R5<20:j8F@80[HMH0P2/QUL20:^5EP060:b6F@2/QUL0[8IG0:b6E@2/Qe<0[8MB
0P2/Qe001P2]R5<0[HQD0:f8E02]QeH0[HMH0:f7FP80[HIK00H0[XUE0:b7D`2ZQE40ZHA@0:R3C`2Y
Q5020:Z5D@80Z8MB00X0ZXIB0:Z5D@2ZQE40[8AA0:f3D@2/PU00[H5@0:n6DP2^QE40[8=?0P2[PTh0
0`2/Pdl0[XEA0:n6DP080:Z5D@80[8==00<0[8=?0:f3D@2]Pe<00P2^PeH0102^PeP0[XEA0:f4D02/
Pdl20:^2CP030:f4D02_QU80/8MC00<0[8MC0`2[QU820:Z5D@80ZhIB0P2/Qe<60:f8E080[8MC00@0
ZhIB0:Z5D@2ZQE40ZXEA202]Pe40202YQ500Z8=?0:R3C`2XPdl0ZHA@0:^6DP2]R5@0[hYF202/Pdl8
0:j9E@@0[HQD0P2/Qe<20:^6DP040:b7DP2]R5<0[HQC0:f8D`80[XUD0P2_RUD20:n:EP<0[XUE0`2]
R5@01P2^R5/0[XQI0:j8F@2^R5L0[XUE0:j9E080[XUB00<0/hUG0;67E@2^Q5800P2]Pe400`2`QU@0
/hUG0;F;F@020;2;E`040:n:EP2^RED0[HQD0:b7D`80ZhIB00D0ZXUD0:^:E@2]RED0[hYF0;69EP02
0;>9E`050;F9F02_RUH0[hYF0:n:EP2^RED00`2]R5@20:b7D`<0[XUE00<0[HQD0:b7D`2/Qe<00P2[
QU830:j9E@030:f8E02/Qe<0[8MC0080ZhIB0P2ZQE420:^6DP80[8MC0P2]R5@40:b7DP80[HQC0P2^
RE@0202/Qe<0[HQD0:j9E@2_RUH0[XUE0:f8E02[QU80ZHA@102^Q5840:n5D`P0ZXE>0P2/PU030:f3
D@<0[XAB202[QU820:^6D@80[8MB0P2]R5<20:j9E0P0ZhIA0P2aR5801P2`Qe<0/8ID0:n5E@2_Q5L0
[X=F0:j3F0P0ZhEF00<0[XEA0:n6DP2aR5@00`2cRUH00`2bRED0/HQD0:^6DP070:^6DP@0[HMH102/
QUL20:f8E080[8MC0P2[QU820:Z5D@80ZXE>00<0ZhIA0:^6DP2[QE@00P2/QUL0102/QUT0[HQD0:b7
D`2[QU820:V4D080ZhIB00<0[8MC0:f8E02]R5@01`2]R5@20:j9E@80[HQD0P2/Qe<20:^6DP<0[8MC
0`2[QU820:Z5D@80[89@0P2[PDl01`2/PU00[XAB0;26E02aQeD0ZhIB0:b7D`2]R5@00P2^RED00`2]
R5@0[8MC0:^6DP030:b7D`<0ZhIB0P2ZQE430:b7D`80[HQD0`2^RED00`2]R5@0[8MC0:b7D`030:^6
DP80ZXEA202ZQU801@2]R5@0[8MC0:b7D`2[QU80ZHA@0080Z8=?00<0Yh9>0:^5EP2[QEH01P2[QEH3
0:Z4E@80ZH=D0`2XPU<00`2_QE<0[XAB0:b2D0030:Z0CP030:^1C`2/PU00Z8=?0080ZHA@0P2ZQE42
0:^6DP030:b7D`2ZQE40ZXEA00<0ZHA@0`2XPdl0202YPUL0Z85F0:N1E02VP4l0YX5=0:N2B`2XQ4X0
ZHE;202YQ5020:N1DPH0Z89C2@2WPE80202[PTh0ZX5=0:V0C02YP4`0ZX5=0:b3C`2_QU80/8MC0P2Y
Q5020:R3C`030:N2CP2VPDd0YX5=00@0YX5=0P2UP4`30:AoB`80Xgi:0P2RODT20:5lB0D0X7]700<0
XGa80:9mB@2RODT00P2SOTX80:5jC`80YWa:0P2UNdT01@2TNTP0XgU70:=iA`2SNDL0XgM60080XWQ6
00<0XGU609mjAP2NNTH00P2LNdH01P2QO4L0XGa80:9mB@2RO4/0Xge>0:=mD080XgaA0`2PNdL[oooo
o`00:_ooool809AX>`P0UVXm00<0UFXm09I[?P2HKD000P2IKT400`2HKD00UV/n09EZ?@0309U/@`03
09Q[@P2GJT40UVU00080UVU000@0V6Ph09UY>@2KJc/0WFdm0P2NKSh00`2MKCd0W6`l09]_@P0209Y^
@@0309U]@02HK3l0V6`o0080Uf/n2P2HK3/209U]?0<0VVhm00L0Vfln09M]>`2HKS`0V6hl09Y`?P2K
LCl0W7900080WG=12@2LLCh01P2HK3/0VFdl09U]?02JKSd0Vfln09a`?`80WG5000H0VVhm09]_?P2L
L3l0WG5009ib@@2PM4<20:5eA0P0Wg@o202PM4<00`2MLD00WW9109ib@@0209mc@P80X7A300@0XGE4
09mcA02QMDH0XWI50P2TNDH00`2RMd80XGHo09md?@040:5gA@@0X7I40`2SN4<20:AiA0<0YGY50P2Y
OT/0102XODX0Yga90:IkB02UNTL20:AiAP80XgY60`2TNdL30:ElB0<0XWU30P2SNT@30:AkA@@0YG]9
0P2TNTP20:=iA`080:EkB@2TNTP0XgU70:5gA@2PMT@0WWA209ec@@2LLT0409]a?`80VW0n0P2IKcd2
09EZ?@0309AY?02CJ3/0TVLj0080TFHi00H0T6Dh08QP?@28H3d0Qelk08MP>@27H3L208MP=@0308MQ
=025H3<0QF0c0080Q5lb0`23GS400`22GC00OEX`07eJ<00607eJ<080LeH/00<0LUD[075D:P1_DRP0
0P1^DBL0201]D2H0K4lU07=?;@1bCR`0LDd[071<:P1_BbT0KDTW0P1/B2H01P1cC2d0LDd]071<;01_
C2`0KD`[06Y<:P80JD`Z0P1VBBL00`1WBBL0JDPW06Y79`0206]79`0306e69`1ZBR@0JTXT00H0JTXT
0P1ZBBP01P1[BRT0K4/Z06e<:`1^CB`0Kdh]071?;P80M4hY00@0MU0[07MA;01iDbh0NeD`0P1lES42
07aF;`0307eG<01nF340OeTb0080P5Xc0140PE/d08EP=P26HCL0QV4g08EP=P24GcD0Pehd089M<`21
G380PE/^08=M<026H3<0R68e08US=P28HSD0QElb08AN<@0408MQ=00508QR=@29HcH0RF<f08YT=`25
HcD00P24HS@00`23HC<0PV0b089P<P02085O<@<0QEl`1@26H34808IR<P<0QV0c0P27HC@308QR=@80
Ped`00<0Q5ha08EO<P26H3<00P28HSD908US=P0608IN>P26GcP0Qf0i08QQ>029HSL0RF<f0P2:I3D0
2029HcH0R68e08MQ=026H3<0Qf4d08QR=@2:I3L0RfDh2@27HSD01@2<ISL0RfDf08]U=P2:I3D0RF<d
0080R68c00L0Qf4b095V>@2@ICP0T6Dh08mT=`2>HcH0SF8e0080S64d00@0R68c08MQ<P27HC80QV0a
0P25Gc0208AN;`<0RF<d0`28HS<208MQ<P<0Pel_0P24H30208EQ<@0308IR<P26HC@0QV4d00<0QF0c
0`24Gc800`28I3@0Qf<c08EQ<@0208EQ<@0608MS<`2:ISH0RfLg08AO<P23GS40PE`_0P20Fbh00`22
GC00Q5lb08EP<`0408IQ=080QF0c0P24Gc802025H3<0Q5lb085L;`1oFRd0OUT/07mJ;@20Fbh0PE`_
0`20Fbh2085L;`<0PUd`00@0PUdc085L<P21G380P5/a0P1oFS0207iI;`P0O5L]0`1iER`207YG;@<0
NeP^00P0M54W07EB:01fDbT0Me@Z07QE:`1iER`0NUL]07]H;PP0NEH`0P1eEB`0101dE2/0Le<Z07=C
:P1bDRT2075A:080L50Y0`1_CbP306i>9`0706a?;`1[CRh0JTd]06U<;01XBb/0IdXZ06I9:@0206E8
:080H4TY0P1OB2P02P1NAbL0GDHV05e69P1MARH0Ed<P05M38P1F@R40ED0Q05@o8P1D?b@205<m9@06
04dm901<?2<0Bc/R04/k8P1:>R40BCTP0P18>1l204Lh8@80B3TR1019>R<02@15=200ACHQ04Hg8P15
>B<0A3TS040h8@0m=al0>cDM03lg8002040h8@03044i8P12>R<0@SXS0080@c/T0`11>R000`10>Al0
?cPN03hg7@0203hg7@80@3@L0P11=Ad3048f7P0304<g7`0o=A`0?cDL00H0?cDL0`0n=1/203le70<0
@3HM0`13=al304@h8080ACTQ0P0n>Ql203di7P0403`h7@0k=a`0>cLL03Xf6`80@3TM00<0@SPM04<g
7@15=ad00P16=Qd00`17=Ad0@SHN048f7P0204<g7`0404@h8015>B40ACTQ04Hj8P<0A3PN0P15>Al3
04Hj8008050l8`1?>b80C3/Q04Xj8018>Ql0A3TM04<h7012>A`304Lk8@D0ASXP00P0BSlS04Tn8P17
?200AS/O04Dj7P16>al0Ac`P04Pm8@P0C3`R2@1F@bD205@o8P0405A18`1C@R@0Dd8T05=49@80DdHV
0P1HABD0101GA2@0ET<S05A18@1C@202058o7`0805938P1A@R40Cd0O04ho7P1?@1l0D44P05938P1D
AB@305528@80D44P0`1A@R4805I480P0F4HR00<0EdDQ05Q68P1JB2@00`1LBRH02P1JB2@0FDLS05E7
8P1GBB@0FTXV05i<:01OBbP0H4TW05m89P1OAbD305]99@80FTPT0`1IAb<00`1B@1`0Dd4M05E37`02
05M58@0305E37`1C@Ad0DT0L00P0ET<U00P0E4@P05=37`1B@Qh0DD4M05927P1C@al0EDDQ05I68P80
DD4O00L0DT8P05A48P1EAB<0ETHT05M79@1HB2H0F4TR0080FTPR00<0FdLR05e78P1NAR800P1PAR<0
1P1SAR@0HdLR06A88`1UBB80ITXR06M<8@80J4dP0P1ZC2P0201[CBL0K4lW06e@9P1^DBL0KU4U06mB
9P1eERL0M5DV0P1cE2D01@1dEBH0MULX07UJ:`1jFb`0NeTY0080O5XZ00<0OE/[07iL;01oGBd00P20
GRh3085P<`0A089Q=024HcH0QF@g08IU>027IST0R6Lj08US?02;ICh0S6Lk08eX>`2>JSP0SFXd08]X
<02;J2h0TVli09=`>P2ELS`00P2FLcd0502ELS`0Tg0j099_>@2EL3`0Ug8n09Ud@02LMd<0WGQ409ag
@`2KMT80VWE109mjAP2MN4@0VWE109Qc?`2IM400VgI209mjAP2RODT0XGa70P2RODP00`2SOTT0Y7m:
0:F0B`020:J1C0D0ZHA?0`2XPdh30:V4C@80ZXE>0`2[QTl30:f9F@80[XYJ0`2_Re/00`2cSe/0/XiJ
0:n;E`020:j:EP030:n;E`2bSUX0/hmK00P0]X]F202bS5d00`2]RET0[h]K0;2<G0020;6=G@030;2<
G02_Re/0[HUI0080[h]K0P2`S5`20;6=G@80/XiN00P0/heN0;:<G@2`RU/0[hUJ0:j8F@2_REX0/8YK
0;6;G0P0/XeI0P2^RED00`2_RUH0/8]G0;6<F0020;:=F@030;>>FP2bSET0/XeI0080/HaH00@0/8]G
0:n:EP2_RUH0[XUE0`2`ReL20:n:EP<0[XUE2@2]RED80:n:D`P0ZhYE0P2^RED20:f8E0<0[8MC00<0
ZhIB0;2;E`2`ReL01P2`ReL20:n5E@040;26E02`Qe<0/HQD0;:9D`80/hYB0P2/Qe000`2/Qe80[HQD
0:f7EP020:j8F@030:j8F`2^RED0[XUE0080[HQD0`2/Qe<00`2[QU80[8IG0:f7F0020:n9FP040:j8
F@2/QUL0ZXAE0:R2D`P0ZhIB00P0/8]G0:j9E@2/Qe<0ZhIB0:Z5D@2[QU80[8MC0:f8E0P0[HQC0P2`
ReL00`2_RUH0[XUE0:f8E0020:b7D`030:^6DP2]Pe40[H=A00H0[H=A202]R5<20:j8F@80[HMH0P2/
QUL20:^5EP060:b6F@2/QUL0[8IG0:b6E@2/Qe<0[8MB0P2/Qe001P2]R5<0[HQD0:f8E02]QeH0[HMH
0:f7FP80[HIK00@0[XUE0:b7D`2ZQE40ZHA@0P2XPdl01@2YQ500ZXEA0:R7DP2XQe80ZXIB0080ZXEA
00L0[8AA0:b2D02/PU00[H5@0:n6DP2^QE40[8=?0080Zh9>00<0[8=?0:j5D@2_QU80202ZQE420:b3
C@030:b3C`2]Pe40[H=C0080[X=F00@0[X=H0:j5D@2]Q500[8=?0P2[PTh00`2]Q500[hIB0;27D`03
0:b7D`<0ZhIB0P2ZQE420:^6DP80[8MC0`2]R5@00`2^RED0[HQD0:f8E0020:b7D`040:^6DP2ZQE40
ZXEA0:V4D0P0[H=A00P0ZHA@0:R3C`2WPTh0Z8=?0:V4D02[QU80[HQD0:n:EPP0Zh9>2@2^RED30:f8
E080[8MC0P2[QU840:f8D`80[XUD0P2_RUD20:n:EP<0[XUE0`2]R5@01P2^R5/0[XQI0:j8F@2^R5L0
[XUE0:j9E080[XUB00h0]8YH0;67E@2^Q580[89@0:f3D@2`QU@0/hUG0;J<FP2aS5P0/8]G0:n:EP2^
RED0[HQD0:b7D`80ZhIB0P2ZRE@01`2]RED0[hYF0;69EP2cREL0]8YH0;F9F02`ReL00P2_RUH0102^
RED0[HQD0:f8E02]R5@20:b7D`<0[XUE00<0[HQD0:b7D`2[QU800P2[QU830:j9E@030:f8E02/Qe<0
ZhIB0080ZhIB00@0ZHA@0:Z5D@2ZQE40ZhIB0P2/Qe<20:f8E0040:^6D@2/Qe80[8MB0:b7DP80[HQC
0P2^RE@0202/Qe<0[HQD0:j9E@2_RUH0[XUE0:f8E02[QU80ZHA@0`2]Pe450:j4DPP0ZXE>0`2/PU02
0:f3D@<0[XAB202[QU820:^6D@80[8MB0P2]R5<20:j9E0P0ZhIA0P2aR5801P2`Qe<0/8ID0:n5E@2_
Q5L0[X=F0:j3F0P0ZhEF00<0[hIB0;68E02cRUH00P2eS5P00`2dReL0/hYF0;68E0080:^6DP@0[HMJ
102/QUT20:f8E080[8MC00@0ZhIB0:Z5D@2ZQE40ZHA@0P2ZQDh00`2[QU40ZhIB0:^5E0020:b6E`04
0:b6F@2]R5@0[8MC0:^6DP80ZHA@0P2[QU800`2/Qe<0[HQD0:f8E0070:f8E080[XUE0P2]R5@20:b7
D`80ZhIB0`2/Qe<30:^6DP80ZXEA00/0[H=A0:b2D02[PDl0ZX1>0:^1C`2]Pe40/8ID0;:8EP2[QU80
[8MC0:f8E0020:j9E@030:f8E02/Qe<0ZhIB00<0[8MC0`2[QU820:Z5D@80[HQD0`2^RED30:n:EP03
0:f8E02/Qe<0[8MC0080ZhIB0`2ZQE480:Z6DP80[HQD00@0[8MC0:^6DP2YQ500Z8=?0P2WPTh80:V3
E080ZXAE0`2YPe@30:R2D`080;26E02^Q580[89@0:Z0CP2YOdd0ZX1>0:^1C`2/PU020:R3C`040:V4
D02ZQE40ZXEA0:^6DP80[8MC0P2ZQE430:V4D0<0Z8=?00P0ZX=J0:R1EP2WPE@0YGm>0:F0B`2WPT/0
Z8A:0:Z6BPP0ZHA@0P2VP5<50:N1E0030:R2E@2VP540YX1A00L0YX1A00P0Zh9>0:Z1C@2YP4`0ZH1<
0:Z1C@2]Q500[hIB0;68E0<0ZHA@00<0Z8=?0:N2CP2VPDd01@2VPDd20:F0C0<0Y7m;0P2SOTX20:9m
B@030:5lB02PNdL0X7]70080WgY60P2PNdL00`2QO4P0XWe90:9mB@020:=nBPP0XW]@0P2VO4X20:Ek
B@050:AjB02SNDL0XgU70:9hAP2SMdH00P2RN4H00`2QNDH0WgY609ijAP0209akAP080:5lA`2QO4P0
XWe90:9lB`2SODh0Xge@0:=lD@2TOE830:1kAb_ooooo000Zooooo`P0V6Ph0P2FJSd209M[?P80V6`o
0P2IKD02095V>@80TVLj00`0TfPk09AY?02DJC`0UFXm09Y`?P2IKcd0V6hl09M]>`2FK3X0UF/i09AZ
>02CJCL809e]?@P0VFdl0P2EJC`209IZ?@@0Uf/n202KLCl209]_@00409a`?`2LLCh0WG8o09eb?@80
WW<l00@0VFdl09Y^?@2KKch0W70o0P2MLD00302NLT40Wg=20:1d@`2QMT<0WgA109eb?`2KL3d0VVll
09]`?@2LLCh0WG8o09]`?@<0W74n0P2MLSl209ic@080XGE400@0X7A309mc@P2OLd80WW910P2MLD08
09md@@P0X7E200H0XgQ50:9gA02RMd@0X7E209md@@2NLd0209eb?`P0YWM3202TNDH02`2SNTH0YGa8
0:QoB`2ZPDd0ZH1<0:ImB@2SNTH0X7M30:9hAP2SNDL0YG]90080YWa:00l0YG]90:=iA`2RN4H0XgI<
0:9gC02SN4d0XWU=0:5kCP2QO4l0Wge?0:1nD02OMT80XGQ40:=jAP2TNdL00P2UO4P00`2TNdL0XgY6
0:5gA@020:5gA@0;0:1fA02OMD<0WWA209ec@@2LLT00Wg=209ib@@2MLD00W70o09Y^?@2IKC`00P2H
K3/0302CJ3/0U6Tl09EZ?@2EJSd0U6Tl099W>P2@ICP0SV<f08]V>@29I3L0Qf8e08AO<P<0Peha00<0
Q5lb07mI<P1oFC800P1oFC8407iH<@0307MD;P1hEBl0NULa0080NePb00P0NULa07QE;`1fDbd0Le</
079B:`1aDBX0L50Y06i>9`80K4`U00D0Jd/T06Y:8`1/B2H0KTXX06m;:@02071<:P0406i::01/B2H0
JTHT06e<:`<0K4/Z0P1[BRT206Y9:00806E=:@1WCBX0IddZ06U<:P1ZC2X0JTTX06Y79`1YARH206I7
:00?06E79@1UAb<0ITPR06Q;8`1ZCBD0JdhT06M98`1YBB<0Jd/T06i=901aCR@0ME0T07QA9P1iDbH0
Me8X0080N5<Y00<0NE@Z07YE:`1kER`00P1lEbd01P1kER`0O5L]07eH;P1oFS00PE`b089M<`80Q5le
00P0Pe`e08AM=026GcH0QUld08IP<`25Gc00Ped/089L:`80Qe`_0P28GC001029GS40RUlb08YO<P2;
H3<808MQ=0P0QV0c00<0R5db08UN<`2;H3D00P2<HCH00`2;H3D0REhc08QM<P0308EO<0<0QV0a0P27
HC8508IP<`<0QElb00<0RV@g08US=P27HC@00`25Gc802P27HC@0R68e08IP;`27HC00Qf4b08QR=@29
HSL0RF8i08YS>P2:Hc`208UN<@@0RUlb0P2;H3<02029HcH0RV@g08]U>02<IST0RfDh08YT=`28HSD0
QV0c2@24HS8308]U=P0308YT=@29Hc@0R68c0080R68c2026H34808MQ<PP0RV@g00P0R6@d08UU=@2:
ISH0RVHf08UU=@27Hc<0QF4a08AP<080R68c00<0Qf4b08IP<@25Gc000P24GRl00`23GBh0QV4d08IQ
=00308EP<`<0Q5lb00<0QV4d08AO<P23GS400P21G2l01P23GS40Q5lb08IQ=026HC@0Q5lb089M<080
P5/^00<0PE`_089M<023GS400P23GS401P22GC00P5/^07iI;01mF2/0O5LZ07]F:@P0PUd`00<0NUD[
07aG;@20Fc400P22GC<00`20Fc40O5L]07YE:`0407iI;`@0OeX`0`1lFRX307]I:@80NUPX0P1nE2h0
101mERl0O5H_07aF;`1jEbl207YI<00407UF;P1hEBd0N5D]07QE;@80Me@/0P1fDb/02@1eCbX0MU0[
07MA;01hDRd0Me4/07I@:`1dCRT0LddX079A;P0307=B;`04079A;P1_CR/0KD`Y06]:9`80KThW00@0
KThX06e=9`1/BbP0K4/Z0`1[BR/0201SAb80HD@R05e3801J@R00F44Q05I18P1G@RD0Ed@V0P1B?b40
1P1A?R00D3dO04ll7P1??1h0CS/M04dj70<0B3XO0P17>Ah304Hh7@0304`n901:?280BC/Q00<0AcTO
00P0B3XP04Tk8@11=2<0@C@S040e8`0m=B80?3DR03Xe8@80>3HQ0P0o=b@0100n=R<0?CDR03de8P0l
=24203/c80P0?CHL0P0l<QT0100m<aX0?S@K040f7@11=ah2048h7`0503le7010=Qd0@3HM044g7P12
>1l00P13>B000`14>R40@3HM040f7@02044g7P80@SPO0P13>B0204@j8@<0@cTP0`12>1l303`h7@03
03di7P0n>Ql0?c/P0080?c/P00<0AChT048k8@0m=Q`00P0j<aT0100m=Q`0@S/Q04Dn9011>B@3040h
8`80?cLR0P0n=R401P12>1l0@cTP04<i8015>b80AS`S04Lm9080B3hU0`16>R0204Di7`<0A3PN0`13
>Ah204@j7`<0AC/P00@0Ac`P04Pm8@18?B40B3dQ0P19?R8204Xo8`0404Ti7`1:>R00BSXP04/k8@80
C3`R0P1=?B<3054n8080DSlQ0`1C@2802@1D@B<0C3dN04ho801@@B80DD8S0593901A@R<0D44R04ho
800205I38`@0ED8R0`1D@B402P1E@R80Ed@T05Q59@1HABD0Ed@T05E28P1D@B40Ed@T05I38`1D@B42
05=0800605A18@1F@b<0Ed@T05E5901DA2<0DT8Q0P1A@B000`1B@R40E4@S05E5900205E28P80ET<S
00L0Ed@T05Q59@1IARH0FDHV05a:9P1KBBD0FDLS00<0EdDQ00D0F4HR05U78`1HAR80FDLS05]99@02
05a:9P0605]99@1IAb<0F4HR05]99@1JB2@0F4HR0P1GAB400`1HAR80FTPT05]99@0805U9:00305I3
8`1GA2@0F4DU0080FDHV00H0F4DU05M4901F@b<0FTLW05Q59@1E@R82058o7`0;05E28P1HABD0FTLW
05I38`1GA2@0F4DU05U69P1HABD0ET<S05=0801B?al00P1DAQl00`1EAQl0EdDO05Q47`0205Y47`0:
05]37`1KBB<0G4XT05a:8P1MC240GTdQ05m>801PCb40H50O06M;8`80J4`T00<0JDdU06Y>9P1[CbL0
0P1/D2P206]F:@0406eF:P1^ERX0L5DZ075D:P80Le<Z00H0NEX^07YK;`1jFbl0Ne``07aM<@1mGS82
07iO<`<0Pf4a00<0Q68b08ES<`26I3@00P27ICD01P28ISH0RfLe08aX=P2<J3H0SFTg08iZ>080Sf/i
00D0T6`j095]>@2AKCT0TFdi099^>P0209=_>`80U70l00@0Tfhj09E`?02GLSh0VWE10P2KMT8209Ye
@@0809Yg@@2KN480W7U309ejA02OO4H0XGi80:9oB@2SP4X20:1mA`80XGi80`2ROdT00`2SP4X0YX9>
0:J2CP030:J2CP<0Yh=?0P2ZQE030:^6D@<0[8MB102/R5@20:f9E@80[XYF202_RUD80;2<G0P0/HeM
202`ReL0102]RET0[XYJ0:j:FP2_Re/20;2<G080/HeM202`ReL00`2aS5P0/XeI0;>>FP020;F@G003
0;>>FP2bSET0/HaH00P0/hiJ0`2aRe`30;2:F`80[hUJ00H0[hUL0:n9FP2_REX0[hUH0:n:EP2_RUD2
0:n:D`T0[XUE202_RUH80:j8F`80[HQD00@0[XUE0:n:EP2_RUH0/8]G0P2aS5P02`2`ReL0/HaH0;:=
F@2aS5P0/8]G0:j9E@2/Qe<0ZXEA0;67E@2`QU@0[hEC0080[XAB00/0[hEC0;26E02aQeD0ZH=F0:^5
EP2]QeP0[hUH0:n:EP2^RE@0[HQA0:^6C`020:n:EP<0[XUE0`2]R5@02`2]QeP0[8IG0:^5EP2ZQ5D0
ZH=D0:R2D`2WPE80YX1A0:b7D`2[QU80ZXEA0080ZHA@00/0ZhIB0:f8E02_RUH0/8]G0:n:EP2^RED0
[HQD0:b7D`2[QU80ZXEA0:V4D0040:f8E0@0[8MC00T0ZhIB0:b7D`2_RUH0/HaH0;:=F@2aS5P0/8]G
0:n:EP2YQ5000P2ZQE400`2[QU80[8MC0:b7D`020:f8E0P0ZXEA0P2^RED20:f8E080[8MC0P2[QU88
0;27D`060;6<F02_RUH0[8MC0:Z5D@2XPdl0ZHA@0P2ZQE480:f8E0030:^6DP2/Qe<0[HQD00<0[XUE
00<0[HQD0:b7D`2[QU800`2]PE020:j2D@<0[h=B0P2[QTl00`2[QU40ZXEA0:Z4D`020:V3E0030:V3
EP2]Q500[HA@00H0[HA@202ZQE430:b7D`80[HQD0`2^RED00`2YQ4l0ZXE@0:b7DP020:f8D`0<0:b7
DP2ZQE00ZHA?0:n4F@2`QEP0/HII0;67E`2`QU@0[HA@0:^2C02YP4X0[XEA0P2]Q5000`2/Pdl0Zh9>
0:^2CP020:Z1C@<0[XAB0P2]Pe430:b2D0P0ZhIA00P0[8EJ0:b6F@2/QUL0ZhIB0:^6C`2[Qd/0ZhM9
0:^8B080[XUE0P2]R5@20:b7D`80ZhIB202^RED01P2^R5/0[XQI0:j8F@2^R5L0[XUE0:j9E080[XUB
202]R5@04`2bR5H0/HME0:n5D`2^Q580[hEC0;26E02bR5H0]8YH0;2;E`2_RUH0[XUE0:f8E02/Qe<0
ZhIB0:Z5D@2YQ500[hYF0:f8E02/Qe<00P2ZQE400`2/Qe<0[HQD0:n:EP020:n8G@@0/8UN0`2aRUl4
0:b7D`80ZhIB0P2ZQE480:f8E080ZXEA0`2[QU830:b7D`030:j3EP2_Q5L0/8EH0080/8EH00<0[X=F
0:b1E02[P5<00`2ZQE430:^6DP80[8MC202]R5@80:Z5D@P0[HQD202]R5420:n:EP040:j9E@2]R5@0
[HQD0:b7D`80ZhIB202ZQE400`2XPdh0ZXE@0:b7DP020:j9E0030:b7DP2ZQE00Z8=>00<0[HQD0`2^
RED40:n:EP<0[XUE0`2]R5@00`2aS5P0[XUE0:Z5D@020:N2CP030:V4D02/Qe<0[XUE00<0[HQD0P2/
Qe<30:^6DP030;:8EP2aQeD0/HME0080/HME0`2`QU@20:Z6EP80ZHEE0P2XQ5@20:N3D`80[XUE0P2]
R5@30:b7D`80ZhIB102_QE<20:j4DP80[H=A202aR5@20;27D@030;27D`2`QU@0/8IF0080/8EH00<0
/8EJ0:b8F02/R5P01P2/R5P20:f8E080[8MC00D0ZhIB0:Z5D@2ZQE40ZHA@0:j9E0020:f8D`030:b7
DP2[QU40ZXE@0080ZHA?0P2^RED20:f8E080[8MC0P2[QU830:j9E@030:f8E02/Qe<0ZhIB0080ZhIB
0P2ZQE430:^6DP<0[8MC00H0[XUE0:f8E02]R5@0[8MC0:^6DP2ZQE420:V4D0030:R3C`2YQ500ZhIB
0080[8MC00<0ZhIB0:V4D02XPdl00P2]R5@0102/Qe<0ZhIB0:V4D02XPdl20:N2CPP0ZXE@202ZQE42
0:^6C`030:Z5CP2YQ4d0Z8=<0080Yh9;00T0YX5:0:V3EP2XPU<0Yh5B0:J0C`2WPTh0ZHA?0:^6C`2]
R5400P2ZQE40102YQ500Z8=?0:J1C@2UP4`20:AoB`<0ZHA@0P2ZQE430:^6DP030:F1C@2TP4`0Xgm;
0080XWi:00@0Xgm;0:B0C02TP4`0YH5=0P2VP4l0102VPDd0YX5<0:J1C02VPDX20:J2B0<0Yh9=0`2V
PD`20:F0B`<0Y7m;0P2UP4`30:J1C@060:EoDP2UOe00Y7i?0:=mC02RODT0XGa70P2PNd@20:N2C@80
YX5<0`2UP4/01P2TOdX0XG]>0:5kCP2QNdh0XWa?0:=mD0<0Y7iA0`2QNdh20:1jC@<0WgU<0P2PNdL3
0:5lB0<0XWe900<0Xgi:0:AoB`2UP4`00P2VPDd00`2TOd/0XWe90:1kA`030:5lAB_ooooo000Zoooo
o`P0V6Ph0P2FJSd209M[?P80V6`o0P2IKD000`2AIST0TVLj099W>P0209=X>`80U6Tl00L0UFXm09Y`
?P2IKcd0V6hl09M]>`2FK3X0UF/i0080U6Xh202MKCd809U]?080UFTl0P2FJSd309M[?P0309Q/?`2K
LCl0Vg4o00H0Vg4o0P2KKd00102LL3l0W74n09eb?`2MLSd209ic?080VVhm00D0Vfln09a`?`2MLD00
WG5009ib@@0209mc@P080:1e@P2OM440WG8o09]`?@2JKc`0Vg0m09aa?P2MLSl309aa?P80WG8o0`2N
Ld000`2QMD@0X7A30:1d@`0209mc@P80WW9100<0WG5009md@@2OM4401P2OM4480:1e@P050:AiAP2S
N4D0XgQ50:9gA02PMD800P2OM4400`2NLd00YWM30:Ig@`060:Ig@`P0Y7U600<0XgY60:ElB02XOd/0
0P2YP4`01P2VODT0XgY60:5hA02RN4H0XgU70:EkB@80YWa:00T0YG]90:=iA`2RN4H0Y7Q;0:=hB`2T
ND`0XgY<0:9lC@2ROTh00P2POTh01P2OMT80XGQ40:=jAP2TNdL0YGa80:AkA`80XgY60P2QMdD00`2P
MT@0WgE309id@P0209ec@@0:09ab@02MLd40WG=109ab@02KLCl0VFlm09Q^?02GKC/0UV`j09=X>`80
U6Tl00/0UFXm09AY?02BIcX0T6Dh08iS=P2<IcX0RVDh08MR=@25H3<0Q5lb08=N<@0208AO<P80P5Xc
0P1oFC804@1nF340OEL`07eG<01lERl0N5D_07UF<01jEc40NePb07YG<@1hEBl0MU<]07EB;01dE2d0
Le</079B:`1`D2T0KdlX0080KDdV00X0K4`U06];901]BBL0KTXX06m;:@1`C2X0Kd/Y06i::01/B2H0
JTHT101/BbX206]::@80JTTX00H0IThZ06I<:@1UBbP0ITTW06M99`1XAbH206U69P0@06M8:@1VAbP0
IDLU06E78`1VB280J4/S06Y=9@1/CbD0IdTS06Y:901/C2D0KdhU079?9@1fDBD0N54V07UC9P80N5<Y
00<0NE@Z07YE:`1kER`00P1lEbd307eH;P0407iI;`1oFS00PE`b089M<`80Pehd00T0Pe`e08AM=026
GcH0Qf0e08IP<`25Gc00Q5h]089L:`27G2l00P28GC0208UN<@80RUlb00<0Rf0c08MQ=027HC@01P27
HC@808IP<`0308QM<P29GS<0Rf0e0080S64f00<0Rf0e08UN<`28GC800`25Gc0208IP<@<0Qf4b2026
H3<0202:I3L0RF<f08MQ=026H3<0QElb08IP<`27HC@0R68e0P27HC001P27HC80R68e08UR=`29HST0
RV<j08YS?0H0RUlb0P2;H3<00`29HcH0RV@g08]U>00208]U>00308US=P28HSD0QV0c00T0Q68b0P2;
ICH208YT=@0308US=028HS<0R68c00T0R68c2027HC8808US=P0808IR<P27Hc<0R6@d08UU=@28I3@0
Qf<c08EQ<@24H30208MQ<P<0QV0a0`25Gc0208IQ=0<0QF0c0`24Gc800`26HC@0QF0c08=N<@02089M
<00:08=N<@25H3<0QV4d08EP<`24Gc80PUd`085L;`20Fbh0PE`_089M<080Peha0P22GC000`21G2l0
P5/^07mJ;@0207iI;0P0PUd`00<0NeH/07eH;P21G3800P23GS@00`21G380OEP^07]F;00407iI;`@0
OeX`0`1lFRX207]I:@<0NUPX0P1nE2h0101mERl0O5H_07aF;`1jEbl207UH;`@0N5D]0P1gE2`207IC
:`0:07=@:P1dDB/0ME8/07IC;@1eDR`0M54[079?:@1aCRP0L4l/075@;@80LU4^00@0LE0]06m>:`1]
C2T0K4/X0P1]CBH00`1]CBL0K4/X06]::@0206Y9:P80JDL[00T0HTDS05i48@1L@R40FD0Q05M08@1E
@240ED8T05I39@1B?R<00P1A?B800`1@?240Cc/P04hj7`0204di7P80B3XO0P17>Ah304Hh7@0904Dg
701:>b@0BCXS04Lh8@16=b00ACHO04Hg8017>240B3TR0080@C@S00@0?c@R03de8P0l=B80>SDQ0P0h
=R400`0o=b@0?SHS03hf8`0203de8P80?3@Q00<0>c<P03df700m=Q`01P0m=Q`01P0l<QT0?C<J03hd
6`0o=A`0@3HM044g7P80@SPO1011=ah4048h7`80@3HM0P11=ah2048h7`80@cTP0P14>R4304<i80<0
@SPO0`0l>1d00`0m>Ah0?SXO03hj7`0203lk8003048k8@11>R00?SLM0080?3DK00<0?SLM044j8012
>b401010>2<203lg8P80?SHQ0P12>1l01P13>B00A3XQ04Dk8P16?2<0AcdT04Pn9@80ASXP0`15>Al3
04@h7P<0@cTN0`14>Ql204Dk8080Ac`P0P18?B4304Tn8P0404Xo8`1:>R00Bc/Q04/k8@80C3`R0P1=
?B<0101>?R@0DChP054n801A?R02058o8@@0Dd0R00<0C3dN04dn7`1?@2400`1A@R<00`1@@B80Cd0Q
05E28P0505E28P<0E44Q00X0ED8R05M4901HABD0F4DU05M4901E@R80E44Q05M4901F@b<0E44Q0P1C
@2001P1D@B40ET<S05M4901EAB@0E4@S05928@80DD4P00<0DT8Q05A48`1EAB@00`1E@R8305I38`80
Ed@T00/0G4XV05]99@1IAb<0EdDQ05I4801GAB40F4HR05U78`1HAR80FDLS05]99@0205a:9P0605]9
9@1IAb<0F4HR05]99@1JB2@0F4HR0P1GAB400`1HAR80FTPT05]99@0805U9:00305I38`1GA2@0F4DU
0080FDHV00H0F4DU05M4901F@b<0FTLW05Q59@1E@R8205=0800605E28P1HABD0FTLW05E28P1F@b<0
Ed@T0P1HABD00`1F@b<0E44Q05=0800205A68@0305E58@1GAB40F4@Q0080FT<Q00D0Fd<Q05]98`1K
BB<0G4XR05e<8@0205i=8@0705m>801PCb40Id/S06M;8`1XC2@0JDdU06Y>9P0206]?9`0706a@:01[
ERT0JeHY06aE:@1]EBT0L5DZ075D:P0207=C:P80NEX^00L0NU/_07]L<01lGC40O5da07eN<P1nGc<0
PV0`00<0Pf4a00<0Q68b08ES<`26I3@00P27ICD208YV=00408]W=@2<J3H0SVXh08m[>@80T6`j0P2@
K3P0102AKCT0TVhj099^>P2CKc/209A`?00609A_>`2FLCd0V7<o09Ye@@2KMT80VWE10P2IM400202I
MT00VWM109]h@P2LND<0WW]509mlAP2PODL0XGi80`2PODL20:5nB0<0XWm90`2UPDd20:J2CP80Yh=?
00@0Z8A@0:Z5D02ZQE00ZXE@0P2[QU430:b7DP040:^7D`2/R5@0[8QD0:b8E080[HUE0P2^RUH80:n:
EA00/8aL202`ReL30:j:FP030:n;F`2`S5`0/8aL0080/HeM202`ReL00`2aS5P0/XeI0;>>FP020;B?
F`030;>>FP2bSET0/HaH00P0/hiJ0`2aRe`30;2:F`80[hUJ00H0[hUL0:n9FP2_REX0[hUH0:n:EP2_
RUD20:n:D`T0[XUE202_RUH80:j8F@80[HQD0P2^RED00`2_RUH0/8]G0;2;E`020;2;E`<0/HaH00L0
/8]G0:j9E@2/Qe<0ZXEA0;67E@2`QU@0[hEC0080[XAB00/0[hEC0;26E02aQeD0ZXAG0:^5EP2]QeP0
[XQG0:n:EP2^RE@0[HQA0:b7D0020:n:EP<0[XUE0`2]R5@01P2^R5T0[HMH0:b6E`2[QEH0ZXAE0:V3
E080Z89C00L0[8MC0:^6DP2ZQE40ZHA@0:Z5D@2[QU80[HQD00<0[hYF00@0[XUE0:f8E02/Qe<0ZhIB
0P2ZQE440:f8E0@0[8MC00@0ZhIB0:f8E02_RUH0/8]G0P2aS5P20:n:EP<0ZXEA00<0ZhIB0:b7D`2/
Qe<00P2]R5@80:^6DP80[XUE0P2]R5@20:b7D`80ZhIB202`Qe<0102`ReL0[hYF0:b7D`2ZQE420:V4
D0030:Z5D@2[QU80[HQD00L0[HQD00<0ZXEA0:b7D`2]R5@00`2^RED00`2]R5@0[8MC0:Z5D@020:b2
D0<0[H=A0`2^Q5820:^6C`060:^6D@2ZQE40ZXAC0:Z4E@2YPe@0ZH=F202]Q5080:Z5D@<0ZhIB0P2/
Qe<30:f8E0030:V4C`2ZQE00[8MB0080[HQC00`0[8MB0:Z5D02YQ4l0[hAI0;25F02aQUT0/HMG0;26
E02]Q500Zh9<0:V0BP2^QE420:f4D080[8=?0P2[PTh0102ZPDd0[XAB0:j4DP2^Q5820:f3D@<0[89@
202[QU40202/QUT0[8IG0:^5E02[QU80ZhI?0:^7C@2[Qd/0ZhM90P2^RED20:f8E080[8MC0P2[QU88
0:j9E@060:j8F`2^R5T0[XQI0:j8E`2^RED0[XUD0P2^RE880:f8E0080;67E@2`QU@0[hEC0:j4DP2_
QE<0/HME0;>9E`2eReT20:n:EP040:j9E@2]R5@0[8MC0:^6DP80ZXEA00<0[hYF0:j9E@2/Qe<00P2[
QU800`2/Qe<0[XUE0:n:EP030:n8G@<0/8UN0`2aRUl0102]R5@0[8MC0:b7D`2/Qe<20:^6DP80ZXEA
202]R5@20:Z5D@<0ZhIB0`2/Qe<00`2^PeH0[hAG0;25F0020;25F0030:j3EP2/PE@0Zh1C00<0ZhIB
0P2/Qe<;0:f8E0P0ZXEA202]R5@80:f8D@80[XUE0P2]R5@00`2/Qe<0ZhIB0:^6DP090:^6DP030:Z5
D02[QU40[8MB00<0[8MB00<0ZhIA0:Z5D02]R5@00P2]R5@30:j9E@@0[hYF0`2^RED30:f8E0030;2;
E`2^RED0ZhIB0080Z8=?00<0ZHA@0:b7D`2^RED00P2^RED30:f8E0<0[8MC0`2bR5H00`2aQeD0/8ID
0:n5D`020:n5D`80ZhMG0P2ZQUH40:V5E@80[XUE0P2]R5@30:b7D`80ZhIB00@0/8ID0:n5D`2_QE<0
[hEC0P2^Q5820:f3D@P0/HQD0P2`Qe400`2`Qe<0/8ID0;26EP020;25F0030;25FP2/R5P0[8QH00H0
[8QH0P2]R5@20:b7D`80ZhIB0P2ZQE440:b7D`@0ZhIB0P2^RED20:f8E080[8MC0P2[QU820:j9E@80
[HQD00@0[8MC0:^6DP2[QU80ZhIB0P2ZQE430:^6DPH0[8MC0`2[QU820:Z5D@030:R3C`2YQ500ZhIB
0080[8MC00<0ZhIB0:V4D02XPdl00P2]R5@01P2/Qe<0ZhIB0:Z5D@2YQ500Z8=?0:N2CPP0ZXE@0P2Y
Q5040:Z5D@80ZhIB0P2[QTl00`2ZQDh0ZHA=0:R3C0020:N2B`0:0:J1BP2YPeH0Z89C0:N1DP2WPE00
Yh9>0:V4C`2[QTl0[8M@0:^6DP80ZXEA00D0ZHA@0:N2CP2VPDd0YX5=0:F0C0030:V4D0<0ZXEA0P2[
QU800`2WPdl0YH5=0:B0C0020:=oB`040:B0C02UPDd0YH5=0:N3C`80YX1?00@0YX5=0:J1C02VPD`0
YX5:0P2VPTP30:N2C@<0YX5<0P2UP4/20:AoB`<0YH1<0`2VPDd0202UOe80YGm@0:AnC`2SOD`0XWe9
0:5lA`2QO4D0X7]40P2VPD`20:F0B`80Y7m:0P2SOTT20:5kC080XWa=0P2SODh20:AnC`P0X7Y;0P2P
NdL30:5lB0<0XWe900<0Xgi:0:AoB`2UP4`00P2UP4`00`2SOTX0XGa80:1kA`030:1kA2_ooooo000Z
ooooo`P0UfLg0P2FJSd209M[?P80V6`o0P2IKD02099W>P80TfPk102DJC`209U_?@80V6hl00@0Ufdk
09I/>P2EJcT0UF/i202LK3`809U]?0<0UVXm0P2GJch309Q/?`P0Vg4o0P2KKd00102LL3l0W74n09eb
?`2MLSd209ic?00409Y^?@2KKch0Vfln09a`?`80WG500P2NLT40102OLd80WgA109md@@2MLSl309aa
?P80WG8o00@0W74n09eb?`2MLSl0WG8o0P2NLd0209md@@<0X7A30P2OLd8309ib@@P0X7E2202QMT<2
0:EjA`040:AiAP2SN4D0XWM40:9gA080XGI3202VMd<80:AiAP0;0:AkA`2UO4P0Ygi:0:V0C02XOd/0
YWe90:=jAP2QN4@0XgU70:AjB02UNdT00P2VO4X02@2UNdT0Y7Y80:=iA`2VNTd0YGY=0:IkCP2UO4h0
Xge>0:=oC`020:5oC`030:1g@`2QN4@0XgY600<0Y7]700H0XgY60:9iA@2QMdD0X7I409me@`2NM482
09ec@@80W79000X0WG=109ab@02KLCl0VW0n09Q^?02GKC/0UV`j09E[>@2BIcX0TfPk0P2DJC`0202C
J3/0TFHi08mT=`2=HSD0S6Lj08]V>@28HcH0QV4d0P24Gc8208EP<`80PE/d00@0P5Xc07mI<P1mEc00
O5H_0P1kEBh407YG<@0407QE;`1fDbd0M54[07=@:P80M5@]00<0Le</075A:P1`D2T00P1_CbP0101^
CRL0KDdV06e99`1^BRP306m;:@0306e99`1/B2H0JdLU00<0K4/Z0P1[BRT306Y9:00806I>:P1UBbP0
HTPU06958`1RA280ITDT06U69P1[B2P206M8:@0>06I89P1VB2@0IdTS06U<901[CRH0K4lU06U;9@1/
C2H0KDdV071?9P1cD2H0MU4U07UB9`1iDbH207UD:P0307YE:`1kER`0O5L]0080OEP^00D0OUT_07mJ
<01oFS00OeX`081K<@02085L<P80PUdc00P0Pe`e08AM=026GcH0Qf0e08MQ=026H340Q5h]08=M;080
R5d`0P29GS4408YO<PP0Qf4d2026H3<208UN<`@0Rf0e0P29GS<208EO<080QV0a0`27HC800`28HS<0
QV0c08IP<`0608IP<`0408YT=`29HcH0R68e08MQ=080QV0c00L0Qf4d08QR=@27HC00Qf4`08QR<`28
HSD0R64f0080RF8i00<0RF8k08]P<`2;H3<00`2;H3<308YO<P0808QR=@29HcH0RV@g08]U>02:I3L0
RF<f08MQ=026H3<908IR<P<0RV@e0P29Hc@308QR<`P0RF<d2028HS<808QR=@03089N;P24H300QF4a
00<0Qf<c00<0QF4a08AP<025Gc000P25Gc0308IP<@80Qf4b0P26HC@308EP<`<0Q5lb0P25H3<01024
Gc80Peha08=N<@24Gc8308EP<`0308AO<P22GC00PE`_0080PE`_4P22GC000`1mF2h0OeX`089M<`02
08AO=@03089M<`1oFS00OEP^00@0OeX`101nFBl207aJ;080NeT[0`1jF2X0101iEbT0OeD_07mE;`1m
ERl207]E;P0307UF;P1hEbh0N5L^00<0N5D]0P1gE2`307IC:`80Le0Z0`1eDR`01P1cD2X0LDhX071=
9`1[CBT0K4hZ06i@;080Ke4]00<0KDl[06a>:P1[CBT00P1ZC2H0101YBbL0J4XX06M99`1VAbP306E6
:@0905i48@1M@b80FT8P05M0801E@240Dd0R05A09@1B@BD0CchT0080CSdS00<0CC`R04`k8@1;>R00
0P1:>Al304Di7`80A3PN0`13=ad00`16>R80A3PP04<g7`03044e7@08048f7P13=al0@C@S040c8P0o
=280?CDR03/d8@0j=B4203Le80<0?SHS0P0m=B8303`d8@P0?CHL00H0?C<J03hd6`0n=1/0?cDL040f
7@11=ah6048h7`@0@CLN0P10=Qd2044g7P80@SPO0P13>B0204@j8@<0@cTP0`12>1l303`h7@80?CTN
0`0n>Ql803lh7P<0@3PS0P0o=b8303hf8@80@SPO00@0@cTP04@j8@15>b80AC/R0P16?2<01016>R00
ACTO04Di7`15>Al204@h7P80@cLM0P12>1d204<i7P<0A3XO00<0AC/P04Hk7`17?2000P17?20204Pm
8@80BChR0P1<?28304dm8`<0CShT101??R02050o8@<0DD0R00<0C3dN04dn7`1?@2400`1@@B8204m0
8@D0E44Q0`1E@R800`1C@200E44Q05I38`0205M4900605I38`1D@B40Dd0P05I38`1E@R80E44Q0P1C
@2001P1D@B40ED8R05I38`1DA2<0Dd<R05928@80DD4P00<0DT8Q05=38P1DA2<00`1E@R8305A18@80
Dd0P00/0FdTU05Y8901HAR80EdDQ05I4801GAB40F4HR05U78`1HAR80FDLS05Y8900205]99@0605Y8
901IAb<0F4HR05]99@1JB2@0FDLS0P1HAR800`1IAb<0FTPT05]99@0805Q89`0305I38`1GA2@0F4DU
0080FDHV00H0F4DU05M4901F@b<0FDHV05Q59@1E@R8205=0800605E28P1HABD0FDHV05=0801D@B40
ET<S0`1GA2@01`1F@b<0ED8R05=5801CAB00E4@P05I4801G@b000P1I@R002P1J@R00FTPT05Y8901K
BB<0G4XR05e<8@1MC200GTdQ05i=7`1VBR8206M;8`0306Q<901YCBD0JThV0080JdlW0P1ZEBP0101[
E2P0KEDY06mD:@1aE2X207=C:P80N5T]00@0NEX^07YK;`1kG300Ne``0P1lGC401`21Gbl0PV0`089P
<022H300Pf4a08AR<P25Hc<00P26I3@02028I300RFDa08YV<P2;Ic<0SFTe08m[=`2@K3P0TFdi0P2?
JcL0102@K3P0TFdi099^>P2CKc/209A`?00309Ia?@2GLSh0V7<o00<0VGA000T0V7<o09Mb?P2HMCl0
V7Do09Uf@02JMd40W7U309ejA02NNdD00`2OO4H20:1mA`<0XGi800X0XWm90:9nBP2SOd/0Xgm;0:F1
C@2VPTh0Yh=?0:R4D02YQE40ZHA?0`2ZQE020:^6D@80[8MB0`2[Qe<20:b8E0<0[HUE202^RE@80;2<
G0P0[h]K202`ReL20:j:FP<0[h]K0`2`S5`90;2;E`070;6<F02cSUX0]8mK0;B?F`2cSUX0/HaH0;2;
E`080;:=F@<0/H]L0`2`RU/20:n9FP060:n9G02_REX0[hUJ0:n9F02_RUH0[hYE0P2_RU<90:j9E@P0
[hYF202^R5T0102]R5@0[XUE0:j9E@2^RED30:n:EP<0/8]G0P2aS5P01`2`ReL0[XUE0:b7D`2[QU80
/HME0;26E02_QE<00P2^Q5802`2_QE<0/8ID0;67E@2[QEP0[8IG0:f7F02^R5L0[hYF0:j9E02^RE80
[HQA0080[hYF0`2^RED30:f8E080[hUJ00<0[XQI0:f7F02/QUL00P2[QEH02P2ZQ5D0[8MC0:^6DP2[
QU80ZXEA0:^6DP2/Qe<0[HQD0:j9E@2_RUH20:j9E@050:f8E02/Qe<0ZhIB0:^6DP2ZQE40102/Qe<4
0:f8E0040:b7D`2]R5@0[XUE0:n:EP80/8]G00@0[hYF0:j9E@2ZQE40ZXEA0`2[QU830:b7D`P0[HQD
0P2^RED20:f8E080[8MC0P2[QU880;27D`040:n:EP2^RED0[HQD0:^6DP<0ZXEA00<0ZhIB0:f8E02]
R5@01P2]R5@00`2ZQE40ZhIB0:f8E0030:j9E@040:f8E02[QU80ZXEA0:b2D0<0[H=A0P2^Q5820:n5
D`80[8M@00<0ZhIA0:^6DP2ZQ5<00P2ZQ5D00`2YPeH0[HA@0:f4D0060:f4D0P0ZXEA0P2YQ5020:Z5
D@80ZhIB0P2/Qe<00`2ZQE00ZhIA0:b7DP020:f8D`040:b7DP2[QU40ZXE@0:n4F@80/8EH00D0/8IF
0:n5D`2]Q500[8==0:^2C0040:f4D080[8=?0P2[PTh30:j4DP80[H=A0`2/PU080:^6D@040:^5EP2[
QE@0ZhIB0:^6DP80ZhI?00@0ZhM=0:^7B`2^RED0[XUE0P2]R5@20:b7D`80ZhIB202]R5@01P2]QeX0
[HMH0:f7F02]QeH0[HQD0:f8D`80[HQA202]R5@20:n5D`070:j4DP2_QE<0/8ID0;:8EP2dRUP0]H]I
0:n:EP020:j9E@050:f8E02/Qe<0ZhIB0:^6DP2ZQE400P2^RED0102]R5@0[8MC0:b7D`2]R5@20:j9
E@040:j8F`2_RE`0[hUL0:n9G0<0/8YM0P2aReh30:f8E080[8MC0`2[QU880:f8E080ZXEA0`2[QU83
0:b7D`030:j3EP2_Q5L0/8EH0080/8EH00<0[X=F0:b1E02[P5<00`2]R5@20:j9E@<0[hYF202]R5@8
0:^6DPP0[HQD202]R5<30:b7D`80ZhIB0`2ZQE480:f8E080[8MB00@0ZhIA0:Z5D02ZQE00ZhIA0P2/
Qe830:f8E0<0[XUE102_RUH30:j9E@<0[HQD00<0/8]G0:j9E@2[QU800P2YQ5000`2ZQE40[8MC0:j9
E@030:n:EP80[XUE0`2]R5@20;>9E`040;:8EP2aQeD0/8ID0:j4DP80[H=A0P2]RET20:b8F0<0ZhMG
00<0ZXIF0:j9E@2^RED00P2]R5@30:b7D`80ZhIB0`2`QU@20:n5D`<0[XAB202`Qe<20;27D@030;27
D`2`QU@0/8IF0080/8EH00<0/8EJ0:b8F02/R5P01P2/R5P20:f8E0<0[8MC1P2[QU830:b7D`80[HQD
0P2^RED20:f8E080[8MC0P2[QU830:f8E080[8MC0`2[QU820:Z5D@<0ZhIB0`2/Qe<20:Z5D@<0ZhIB
0`2/Qe<00`2YQ500ZXEA0:^6DP020:b7D`030:^6DP2ZQE40ZHA@0080[HQD00<0[8MC0:^6DP2ZQE40
0P2YQ5000`2XPdl0ZXE@0:Z5D0060:Z5D080Z8=?00@0ZHA@0:Z5D@2ZQE40ZhIB0P2/Qe<20:^6D@03
0:Z5D02YQ4l0Z8=>0080Yh9=00X0YX5<0:V3EP2XPU<0Z89C0:N1D02XPdl0ZHA?0:Z5CP2[QTl0[8MC
0P2[QU801@2ZQE40ZHA@0:R3C`2XPdl0Yh9>0080Z8=?0P2YQ5030:Z5D@040:^6DP2XQ500Yh=?0:J2
CP80YH5=00@0YX9>0:N3C`2WPdl0Z8A@0P2WPE00102WPTh0Yh9=0:N2C@2WPT/20:N3B@<0Yh9=0`2V
PD`20:F0B`040:AoB`2UP4`0YH1<0:F0C080YX5=0P2WPTh01P2UOe80YGm@0:AnC`2TOTd0Xgi:0:9m
B080XGa50`2TOdX20:=nB@<0XWe800@0XG]<0:9lC@2RO4d0XWa=0`2SODh01P2TOTl0WGM809ihB@2N
N4T0WgU:0:1jB`80XG]<00<0XWa=0:1kA`2PNdL00`2QO4P30:9mB@80Xgi:0`2TOd/00`2RODT0XGa8
0:1kA`0309iiA2_ooooo000Zooooo`P0UfLg0P2FJSd209M[?P80V6`o0P2IKD0209=X>`H0U6Tl0P2I
Kcd209Q^?080Ufdk0P2FK3X809a/?0P0VFdl0P2FJSd309M[?P<0V6`o202KLCl209]_@00409a`?`2L
LCh0WG8o09eb?@80WW<l0P2KKch209a`?`<0WG500P2NLT4309ic@0@0WG8o00<0WW=009eb?`2NLd00
0P2NLd0209md@@80X7E2202OLd880:1e@PP0XGI30P2VNdP20:EjA`040:AiAP2SN4D0XgQ50:=hA@P0
YgQ4202TNDH00`2TNdL0YWe90:MnBP020:QoB`030:ImB@2TNdL0XWU500<0Y7Y80P2UNdT30:AjB006
0:QlC@2WODd0Yge=0:InC@2TOTd0Y81>0P2RPDh00`2PMd<0XGQ40:=jAP020:AkA`070:=jAP2RNDD0
XGQ40:5gA@2PMT@0WWA209ab@00209]a?`80W79000H0Vg=009Yb?`2ILCh0V70m09I^>`2EKCX209A/
>@0>095V>@2BIcX0TfPk09=X>`2BIcX0T6Dh08iS=P2<HC@0S6Lj08]V>@28HcH0QV4d08EP<`24Gc82
08EP<`80PE/d00@0P5Xc07iH<@1mEc00NeD^0P1jE2d207]H<P0607YG<@1hEBl0MU<]07AA:`1cD2X0
LTlY0P1dE2d00`1cDb`0LU8[075A:P02071@:@0306m?:01^CRL0KTXX00@0KTXX00<0KDTW06a89P1/
B2H00P1/BbX206]::@80JTTX0P1YB2L0201UCBT0HdTV05m58P1N@Al0Gd4O06A38P1YARH0K4TY0P1X
BBX03P1WBBL0IdTU06Q:901ZCBD0K4lW06e@9P1[CBL0KThX06m?:01aD2L0M54W07MB9P1iDRL0NU@W
0P1jEB/0101kER`0O5L]07eH;P1nFBl207mJ<0P0PE`b00H0Pe`e08AM=026GcH0Qf0e08MQ=027HC82
08EO;P80REha1P2:Gc8@08MQ=0P0RUld0`26H34308MQ<P80R68c0`26H3<408MQ=00508QR=@2:I3L0
RF<f08US=P28HSD01027HC@208QR<@0608QR<`28HSD0R64f08QQ>029HST0RF8k0P2<HC@408]P<`80
RUlb00P0R68e08US=P2:I3L0RfDh08YT=`29HcH0Qf4d08EO<PT0Qf4b1029Hc@408QR<`P0RV@e2028
HS<808IP<`03081L;022GRh0Q60`00<0QV8b0P25HC401P23GBh0Q5h_08AN;`25Gc00QV0a08MQ<P80
R68c0P26HC@308EP<`<0Q5lb0P25H3<408AO<P80QF0c00<0Q5lb08=N<@23GS400P22GC05085L;`80
PUd`00@0Peha08AO<P24Gc80QF0c2021G2l00`1oFS00PE`b089M<`0208AO=@03089M<`21G380OeX`
00@0OeX`101nFBl307]I;0<0NUP[0P1iEbX207mE;`0407aE;P1kEBh0NeD^07UF;P80MeH]0P1hEBd2
07MD;080MU<[0P1eDRX02`1aCbT0LU0Z07=A:`1dDR`0Le4[079@:P1`CRP0KddW06Q<9`1YCBP0JdlZ
00<0K50[00T0JdlZ06Y>:@1WBb@0ITXU06I99`1TAbD0HdHV06959`1Q@bL00P1P@RH0201J@R00FT4R
05Q18@1E@240Dd0R050o8`1@?bD0CShT0P1<?280101;>b40BSXP04Ti7`19>Al204Ph7P<0@cTP0P12
>1l3044g7P08048g8@11=R00?c@N03hc7@0m<Q`0?S<M03ld7P10=Al2040c8P0403ld8P0l=240>c@Q
03Td8080=cDP200m=B8803df700303hd6`0o=A`0?cDL0080@3HM0P11=ah01P12>1l0A3XQ04<i8013
>B00@SPO044g7P80@3HM00<0?cDL040f7@10=Qd00P11=ah2048h7`80@cTP0P14>R4304<i80<0@SPO
100l>1d403di7P0303`e6`0m=Q`0@3TO0080@CXP00<0@3TO03df700l=A/00P10>2<203lg8P80?SHQ
0P0m=B03048h7`0304<i8014>R40A3XQ0080AC/R0`15>Al204@h7P<0@cLM0`12>1d204<i7P<0A3XO
1016>al204Ll8080B3dQ0P1=?B<604hn90<0CChO0P1>?b0204m08@80D44R0P1=?Ql00`1>?b00Cd0Q
04m08@0304m08@80Dd0P101D@B4205E28P03058o7`1C@200ED8R0080ET<S00<0ED8R05=0801B?al0
201D@B400`1DA2<0Dd<R0551800205107`030551801C@b80E4@S0080ED8R0P1D@B401`1C@200DSlO
054n7P1A?Qh0FTPT05U78`1GAB400P1FA2000`1GAB40F4HR05U78`0805U78`<0FTPT0P1IAb<305Y8
90P0EdLV00<0ET<S05M4901HABD00P1IARH01P1HABD0Ed@T05I38`1HABD0Ed@T05E28P80E44Q00<0
ED8R05M4901HABD00P1C@2000`1D@B40ED8R05I38`0305M49080DT@Q00<0Dd<Q05E28@1F@R400P1H
@B401`1I@240F4DT05U69@1IAb<0FTPR05]98@1LBb000P1MC2001P1UBB40ITXR06I:8P1WBb<0J4`T
06U=9@80JThV0P1XDbH0101ZDbL0K5@X06iC:01`DbT207=C:P0607IG:`1gF2`0MeP/07QI;@1iFRh0
NU/_0P1kG303081N;P03085O;`22H300Pf4a0080Q68b0140QF<c08IS;@27I2h0RFH`08YW<@2<JC<0
SV/e091]=`2AKSP0SFTe08iZ=P2?JcL0T6`h095]>@2BKSX0Tflk09A`?00509Qc?`0309Mb?P2FLCd0
UW4m0080Ug@n00H0V7Do09Uf@02JMd40VgQ209ai@`2MNT@209ikA@80Wga60`2PODL02@2QOTP0X7a8
0:5mB@2ROTX0Y81<0:F1C@2WPdl0Z8A@0:V5D@020:V4C`<0ZXE@0`2[QU430:^7D`<0[8QD0P2]RED8
0:j9E0P0/8aL202]RET80;2;E`H0[h]K0P2`S5`90;2;E`070;6<F02bSET0]8mK0;B?F`2bSET0/HaH
0;2;E`080;:=F@<0/H]L0`2`RU/20:n9FP060:n9G02_REX0[hUJ0:n9F02_RUH0[hYE0P2_RU<A0:n:
EPP0[XQG202^RED02`2_RUH0/8]G0;6<F02aS5P0/8]G0:n:EP2]R5@0[8MC0;67E@2`QU@0[hEC0080
[XAB00T0[hEC0;26E02aQeD0[8II0:b6E`2]QeP0[XQG0:j9E@2^RE@00P2^RE820:n:EP<0[XUE0`2]
R5@00`2`RU/0[hUJ0:n9FP020:j8F@80[HMH00@0[8IG0:^6DP2[QU80ZhIB0P2/Qe<20:f8E0<0[XUE
0P2]R5@20:b7D`80ZhIB102/Qe<60:f8E080[XUE00@0[hYF0:j9E@2^RED0[XUE1P2[QU820:b7D`X0
[XUE0P2]R5@20:b7D`80ZhIB202`Qe<20:j9E@030:f8E02/Qe<0ZhIB00<0ZhIB202]R5@00`2ZQE40
ZhIB0:b7D`030:f8E0030:b7D`2[QU80ZXEA00<0[8AA0P2]QE830:j6D`80[8M@00<0[8MB0:^6DP2[
QE@00P2ZQ5D00`2ZQ5L0[HA@0:f4D0060:f4D0P0ZXEA0P2XPdl20:V4D0<0ZXEA00@0ZhIB0:^6D@2[
QU40ZhIA0P2/Qe830:^6D@080:n4F@2_Q5L0[hAG0:n5E@2^Q580[XEA0:f4CP2/Pdd60:f4D080[8=?
0`2^Q5820:f3D@<0[89@202[QU400`2ZQE40ZhIB0:^6DP020:^6D@<0[8M@0P2^RED20:f8E080[8MC
0P2[QU880:f8E0060:f7FP2]QeP0[HMH0:f7EP2]R5@0[HQC0P2]R5480:f8E0080:f3D@2^Q580[XAB
0;26E02aQeD0/hUG0;B:F02eReT20:j9E@80[HQD0P2/Qe<20:^6DP80[XUE102]R5@20:j9E@80[XQI
102_REX30;2:F`<0[HQD0`2/Qe<20:^6DPP0[HQD0P2ZQE430:^6DP<0[8MC00<0[X=F0:n4E`2`QEP0
0P2`QEP00`2^PeH0[85D0:^0D`020:j9E@80[hYF0`2`ReL00`2aS5P0[XUE0:j9E@060:j9E@P0ZhIB
402]R5@40:^6DP@0ZXEA202^RED00`2^RE@0[8MB0:Z5D0020:R3CP030:Z5D02/Qe80[XUD00<0[HQD
0`2^RED40:n:EP<0[XUE0`2]R5@00`2`ReL0[XUE0:b7D`020:Z5D@030:^6DP2/Qe<0[HQD0080/8]G
0P2_RUH30:j9E@070:f8E02dRUP0/hUG0;:8EP2aQeD0[hEC0:j4DP020:b2D0<0[XYJ0P2]RET30:b8
F080[XUE0P2]R5@30:b7D`80ZhIB0`2`QU@30:n5D`80[XAB202`Qe<20;27D@030;27D`2`QU@0/8IF
0080/8EH00<0/8EJ0:f9F@2]RET01P2]RET20:f8E0H0[8MC0P2ZQ5<00`2[QE@0[8IE0:f7EP020:j8
E`030:n9F02^RED0[XUE0080[HQD0P2/Qe<20:^6DP@0[8MC102[QU820:Z5D@<0ZhIB0`2/Qe<20:V4
D0030:Z5D@2[QU80[8MC0080[HQD00@0[XUE0:V4D02ZQE40[8MC0P2]R5@0102/Qe<0ZXEA0:V4D02]
R5@20:b7D`80ZhIB0P2ZQE400`2YQ500ZXE@0:Z5D0060:Z5D0040:N2CP2XPdl0ZHA@0:V4D080ZhIB
00L0[8MC0:f8E02[QU80ZhIB0:Z5D@2YQ500Z8=?0080Yh9>00T0YX5=0:V3EP2YPe@0Z89C0:R2D@2X
Pdl0ZHA?0:V4C@2ZQDh00P2/Qe<20:^6DP80ZXEA0P2YQ5030:R3C`80ZHA@0`2ZQE400`2ZQU80ZHEA
0:N3C`020:J2CP040:N3C`2YQE40ZHEA0:Z6DP80Yh5@00@0Yh9>0:N2C@2WPTd0Yh9;0P2WPdT30:N2
C@<0YX5<0P2UP4/30:F0C080YX5=0`2WPTh01P2VP5<0YX1A0:EoD02TOTd0Xgi:0:9mB080XGa50`2S
OTT20:9mB0<0XGa7102RO4/40:=mC080W7I500@0WGM609ihA`2PNTT0XG]:0P2RO4/20:1kA`<0XGa8
102RODT20:=nBP80XWe90P2QO4P0102PNdL0WGQ409ehA02MN4@[ooooo`00:_ooool809MW=`80UVXm
0P2GJch209Q/?`80VFe00P2EJSd609AY?080VFlm102HKS`209M]>`P0W6`l202IKC`309M[?P<0V6`o
0P2IKD0809Y`?P80Vfm000@0W70o09aa?P2MLSl0WG8m0P2NLc`409a`?`D0WG500P2MLSl209ic@003
09md@@2NLd00WW=000<0WW=00P2OM4430:1e@P030:5f@`2OLd80Wg=200H0Wg=2202QMT<80:9gA003
0:IkB02UNTL0YGY70080YGY70`2TNDH80:MhA0P0Y7U600<0YGa80:ImB@2WOTX00P2WOTX0102UO4P0
Y7]70:=jAP2UNdT60:AjB0070:EkB@2YOD`0Z7i<0:QnC02VOT/0Y7m;0:=oB`020:60B`030:1g@`2Q
N4@0XWU50080XgY600L0XWU50:1g@`2OMT80XGM509me@`2MLd40Vg4o0080VW0n00P0Vg4o09ab@02H
Lcl0Ug8n09Ia?@2EL3`0U6lk099]>@80TF`h00h0T6Dh095V>@2BIcX0TVLj095V>@2?I3L0SF8e08aQ
=02<IcX0RVDh08MR=@25H3<0Q5lb08=N<@80Q5lb0P20FS<0101oFC80OUPa07aF;`1kEBh207YD;@06
07]H<P1jEc40N5D_07IC;@1dDB/0Le0Z0P1bCbT207=C;003079B:`1aDBX0L50Y0080L50Y0P1_CbP2
06m;:@0306i::01]BBL0KDTW00<0KDTW0`1[BRT206Y9:0<0JDPW00P0I4`X06989@1OAB80GT4O05m1
7`1T@b80JDHV06a9:@80JDX[00h0J4XX06Q:9P1YBbD0JdhV06e@:01^DBL0KDlY071@:P1aDBX0Le8Y
07EB:01hDbL0NU<X07]E:080O5L]0P1mF2h0101nFBl0OeX`081K<@20Fc48085L<P0808=L=@24GC@0
QUlf08MP=@28HSD0R68c08MQ<026H2l208]P<`H0RUlb4027HC@808YO=080QV0a0`27HC8308QR<`<0
QV0c00<0Qf4d08QR=@28HSD01`29HcH00`28HSD0Qf4d08MQ=00208US<P0308QR<`28HSD0R64f0080
R64h00<0R64j08eR=@2=HSD00P2<HC@208]P<`80RUlb00<0Qf4d08QR=@29HcH00P2:I3L00`28HSD0
QV0c08EO<P0908UP<PP0R68c202:I3D808US=0P0QV0c00<0P5`/089N;P24H3000`26HS8208EQ<@06
08=M;P24GRl0Q5h_08EO<026H340Qf4b0P28HS<208IQ=0<0QF0c0`24Gc8808EP<`@0Peha0P22GC02
085L;`06081K;P21G2l0PE`_089M<023GS40Q5lb0P25H3<8085L;`03081K<@21G380PUdc0080Pehd
00<0PUdc085L<P20Fc400P20Fc4207mJ<080OUT_0P1mF2h207]H;P<0NUL]0`1iER`207mE;`0407aE
;P1kEBh0NU@]07QE;@80MUD/0`1gE2`207IC:`<0ME8Z00<0L50Y075A:P1bDR/00P1bDR/01P1`D2T0
KThW06e=9P1TBRD0ID/V06M=:080JDlZ00T0J4hY06M=:01VC2L0HdTT06989@1QAb@0H4HU05i39@1M
@RD00`1K@2D0201G@200ESlP05@o801B?b40CchR04hm8`1<?2<0BcdS0P1:?2801019>b40B3XP04Li
7`16>1h204Dg7@<0@3PQ0P0o=b0303hf7`0303lg8P0m=B00?3@O00<0>S8M00P0>c<N03`d7`10<b80
@3<R03hc8@0l=240>S<P03Td8080=S@O200m=B8803df70@0@3HM1011=ah01@14>R40@cTP04<i8012
>1l0@CLN0080@3HM00<0?cDL040f7@10=Qd00P11=ah2048h7`80@cTP0P14>R4304<i80<0@SPO200l
>1d00`0k=1X0?CHL03lh7P02044j800303lh7P0m=Q`0>c@J00<0?cLR0P0n=R4303de8003044g7P12
>1l0@SPO0080@SPO0`13>B0204Di7`80A3PN0P13=ad2048f7080@CLL0P12>1d204<i7P80A3XO0`15
>Qh304Hk7`80Ac`P0`1>?R@504dm8`@0C3lO0P1=@20304i18@@0CChO00@0CSlP04m08@1?@240D44R
0P1B?al205=08080E44Q0P1E@R800`1A?Qh0Dd0P05A18@0205E28P0305A18@1C@200DChN0080Dd0P
101D@B4205=0800305=38P1B@R40DD4P0080D40O00<0DD4P05928@1C@b800P1E@R8205A18@0;05=0
801B?al0DChN054n7P1IAb<0F4HR05I4801E@al0ET@P05M58@1HAR800`1IAb<405Q68P80FDLS0`1J
B2@205]99@<0FTPT201FARD00`1F@b<0Ed@T05Q59@0205U69P0605Q59@1GA2@0ET<S05Q59@1GA2@0
ET<S0P1E@R800`1F@b<0Ed@T05Q59@0305=0800305A18@1E@R80ET<S0080Ed@T0P1B@b800`1C@b80
ED8R05I18P0205Q18P0:05U08P1GA2@0Ed@T05Q5901IAb<0FTPR05]98@1KBQl0G4/P06A88080IDTQ
00<0ITXR06M;8`1XC2@00P1YCBD0201VDB@0Ie8U06QA9@1ZDRH0KU<X071C:@1bDRT0Le<Z0P1eERX0
0`1fEb/0MeP/07QI;@0207UJ;P0307YK;`1nG2`0Oed]0080Oed]00<0P5h^085O;`22H3000P23HC40
2026Hbd0Qf@^08QU;`2:Ic40RfPb08eZ=02>JcD0Sf`f0P2<J3@01P2=JCD0Sf/g091/>02BKSX0Tflk
09A`?080V7<o0P2GLSh409Ia?@80Ug@n00@0V7Do09Uf@02JMd40VWM10P2KN480102MNT@0WW]509ik
A@2NNdD209mlAP80X7e700P0Wg]70:1lB02QODT0Xgm;0:B0C02VPTh0Yh=?0:R4D0<0ZHA?0`2ZQE02
0:^6D@80ZXIB0`2[Qe<30:b8E0P0[XUD202_Re/80:f9F@P0/8]G0P2`S5`60:n;F`P0/8]G00<0[hYF
0;6<F02bSET00P2cSUX00`2bSET0/HaH0:n:EP080;6<F0<0/H]L0`2`RU/20:n9FP060:n9G02_REX0
[hUJ0:n9F02_RUH0[hYE0P2_RU<A0:n:EP`0[XUE102]R5@00`2^RED0[hYF0;2;E`020;6<F0060:n:
EP2^RED0[8MC0;67E@2`QU@0[hEC0P2^Q580102_QE<0/8ID0;67E@2]QeX20:f7F0050:f7EP2^RED0
[hYE0:n:D`2`Re@00P2_RUH30:j9E@<0[HQD102_REX40:j8F@030:^6DP2/Qe<0[8MC0080[HQD0`2^
RED40:f8E0@0[8MC0P2[QU820:b7D`80[HQD1@2^RED40:f8E0030:j9E@2/Qe<0[8MC00H0ZhIB202_
RUH20:j9E@80[HQD0P2/Qe<20:^6DPP0/8MC1@2]R5@20:b7D`030:^6DP2]R5@0[HQD00H0[HQD00<0
ZHA@0:Z5D@2/Qe<00`2]R5@00`2/Qe<0ZXEA0:V4D0020:Z5D@80ZhIB0P2/Qe<20:f8E080[HQA00H0
[8MB0:b7D`2[QE@0ZhEF0:Z4E@2ZQ5L80:f4D0P0ZXEA0P2XPdl20:V4D0<0ZXEA00<0ZhIB0:b7DP2[
QU401@2[QU401`2/Qe80/8EJ0:n4E`2_Q5L0[XAD0:j4DP2^QE400P2^QDl60:f4D080[XEA0`2^Q582
0:f3D@<0[89@202[QU430:Z5CP030:^6D@2/Qe80[8MC0080[HQD0P2^RED20:f8E080[8MC0P2[QU88
0:b7D`060:b6F@2/QUL0[8IG0:b6E@2/Qe<0[8MB0P2/Qe080:f8E0050:f3D@2^Q580[hEC0;67E@2b
R5H00`2cREL40:f8E0@0[8MC202^RED30:j8E`@0[hUH0P2`RUT20:j9E@<0[HQD0`2/Qe<80:f8E080
ZXEA0`2[QU830:b7D`030:j3EP2_Q5L0/8EH0080/8EH00<0[X=F0:b1E02[P5<00`2_RUH30;2;E`80
/HaH202^RED80:b7D`P0[HQD202]QeH80:^6DPP0[hYF00<0[XUD0:b7DP2ZQE000P2XPdh00`2ZQE00
[8MB0:j9E0030:f8E0<0[XUE102_RUH30:j9E@<0[HQD00D0[hYF0:j9E@2]R5@0[8MC0:^6DP020:b7
D`040:f8E02_RUH0[hYF0:n:EP80[XUE0`2]R5@20;:8EP060;67E@2`QU@0[hEC0:j4DP2]Pe40[89@
0P2_Re/20:j:FP<0[HUI00<0[8QH0:j9E@2^RED00P2]R5@30:b7D`80ZhIB0P2aQeD30;26E0<0[hEC
202_QU820;27D@030;27D`2`QU@0/8IF0080/8EH00<0/8EJ0:f9F@2]RET01P2]RET20:b7D`H0[HQD
00H0ZXAE0:^5EP2[QEH0[8IG0:f7F02^R5T20:n9FP80[XUE0P2]R5@20:b7D`X0ZhIB0P2ZQE430:^6
DP<0[8MC0P2YQ5000`2ZQE40ZhIB0:b7D`020:f8E0040:j9E@2ZQE40ZhIB0:b7D`80[HQD00<0[8MC
0:^6DP2ZQE40102/Qe<40:^6DPP0ZXE@0P2XPdl0102YQ500ZXEA0:Z5D@2[QU820:b7D`80ZhED00<0
ZXAC0:V3DP2XPU400P2WPE001`2VP4l0ZH=F0:V3E02YPe@0ZH=B0:V4D02YQ4l00P2XPd`40:^6DP@0
ZXEA0P2WPTh20:R3C`80ZHA@0P2ZQE400`2ZQU80ZHEA0:R4D0020:N3C`040:R4D02YQE40ZHEA0:Z6
DP80Z89A00@0Z8=?0:R3CP2XPdh0Z8=<0P2XQ4X30:N2C@<0YX5<0P2UP4/20:F0C080YX5=0P2WPTh2
0:R3C`060:J0D`2VP540YGm@0:AnC@2TOd/0Xgi90P2RODH30:=nB@80XWe80`2QO4L40:=nBP@0XWe9
00P0VgI209ag@`2MN4@0WWU509mjAP2PNdL0XGa80:9mB@80X7]70`2QO4P50:9mB@80XGa8102PNdL3
09egAR_ooooo000Zooooo`P0UVHf0P2FJSd209M[?P80V6`o0P2IKD0209I[?P80UFXm102DJC`309U_
?@D0V6hl202KJc/809U]?0<0Uf/n0P2HK3l309U]@0P0VW0n0P2KKd00102LL3l0W74n09eb?`2MLSd2
09ic?0@0W70o1@2MLD00102LLCh0WG8o09ic@02OM4420:1e@P0409md@@2NLd00WgA109md@@80X7E2
0`2QMT<0102RMd@0WW9109ib@@2NLT4209mc@P<0X7A3202QMT<80:9gA0P0Y7U6202XNDD80:AiAPD0
YWe900H0YGa80:AkA`2TNdL0YWa:0:EkB@2TNTP20:=iA`040:AjB02UNdT0YWa:0:QmBP80Ygi:00<0
YGe90:=nB@2ROdT00P2OOTP00`2PMd<0XGQ40:9iA@020:=jAP0A0:5hA02OMT80WWE10:5gA@2OMD<0
Vg4o09U_?@2HKS`0VFlm09]a?`2LLT00UW8n09Ea?@2DL3`0Tflk099^>P2@K3P00P2?JcL2091U>080
TFHi00X0T6Dh08iS=P2<HC@0Rf0c08YU>028HcH0QF0c08=N<@22GC00PE`_0P22GC00101nF340OEL`
07eG<01mEc0307aF;`0707]E;P1jEc40N5D_07IC;@1dDB/0Le0Z079?:@0207=@:P04075A:P1`D2T0
L50Y071@:@<0KdlX0P1^CRL00`1`C2X0Kd/Y06i::00306a89P0406e99`1^BRP0JdXY06]::@80JTTX
0`1YB2L02@1XAbH0HTXV06989@1OAB80H4<Q06948P1VAB@0JDHV06]8:00206Y;;00>06U;:@1YBbL0
JT`V06a?9`1^DBT0Ke8X06mA:`1bDR`0LU8[07AC:P1fDbT0NE@X07]D:@1kEBP207eH;P0307iI;`1o
FS00P5/a0080PE`b00<0PUdc081K<@20Fc400P21G3803022GC<0Pehd08=N=023GS@0PU/d08AM=026
GcH0R64f08US=P28HS<0R68a08MQ<080S64d0P2;H3<408YO<PP0Qf4d2028HSD208]P=@@0REhc0P2;
H3D01026H340Qf4b08MQ<P27HC8208QR<`80RF<d00H0QElb08IP<`26H3<0Qf4d08QR=@29HcH208YT
=`80RF<f0`2:I3L00`29HcH0Qf4d08IP<`0208US<P0608US=028HSD0R64f08QQ>027H3L0Qf0i0P2>
HcH0102=HSD0S64d08]P<`2;H3<208YO<P0808MQ=028HSD0RF<f08YT=`29HcH0R68e08IP<`25Gc89
08YO<P0408IP<@27HC80Qf4b08MQ<P<0R68c4@29Hc@808QR=@03089N;P24H300QF4a00<0Qf<c00<0
QF4a08AP<025Gc000P25Gc0308IP<@80Qf4b0P26HC@308EP<`@0Q5lb00P0QF0c08IQ=027HSD0Qf8e
08IQ=025H3<0Q5lb089M<080Peha00@0Q5lb08=N<@22GC00PE`_0`20Fbh2085L;`04089M<023GS40
Peha08AO<PP0P5/^0P20Fc44085L<P80P5/a00D0PE`b081K<@20Fc40OeX`07iI;`0207eH;P0307aG
;@1kF300NUL_0080NUL_0P1iERh207QE;@80OeD_00@0O5D^07]E;P1jE2d0Me@/0P1eE2/207MD;080
MU<[0`1eDRX0601dDBT0KE0X06iA:@1_DRX0L5<[06mB:P1^DBT0K4lW06]>9P1SBbD0I4`V06I>:01W
CbT0IThX06E=9`1TC2H0Hd/U0618901OAbD0GTHT05a3901J@B<0F3hS05Lm9080ES`S0P1B?Ah01`1B
?b40CchR04ln901<?2<0BCXS04Pi8P17>b<00P16>R800`15>B40A3PP04<g7`02048f7P<0?cLR0P0n
=R4303de800803hf8`0m=B80>c<P03Xb7`0i<Ah0>S8O03/c800l=24203lb8@0403hc8@0k<b00>S<P
03Pc7`80=S@O0`0l=24203de8P<0?SHS200m=Q`8044g7P@0@SPO1011=ah2040f7@80@CLN0P12>1l2
04<i8080A3XQ0`13>B03048h7`0403di7P0l>1d0?3PM03`h7@<0>cLL00@0>SHK03/d6P0m=Q`0?cPN
0P10>Al00`0o>1h0?CHL03/d6P0203lg8P80?SHQ0`0m=B000`0l=1l0@CLN044g7P05044g7P04048h
7`14>1h0A3PN04@h7P80@cLM0`12=Q`3044g7080@SPM0`13>Ah304@i7@80ACXN0`16>al204dm8`<0
C3`R0`1;>b4204Tn7P<0BSlO0P1;@20204a18@0804ho801=?Ql0C3dN04`m7P1=?Ql0CSlP04m08@1@
@B82054n7P04058o7`1C@200E44Q05A18@80ED8R00<0DChN058o7`1C@2000P1D@B401@1C@200DSlO
054n7P1B?al0Dd0P00@0E44Q00D0Dd0P058o7`1C@b80DT8Q05107`0204lo7P0305107`1B@R40Dd<R
00<0ED8R0`1D@B4205=0800305Q68P1GAB40ED<O0080ED<O00<0EdDQ05Q68P1JB2@00P1IAb<0101H
AR80EdDQ05M58@1HAR8305U78`0705Y8901KBBD0G4XV05a:9P1KBBD0FTPT05U78`0805E5900305I3
8`1GA2@0F4DU0080FDHV00@0F4DU05M4901F@b<0Ed@T1P1F@b<00`1GA2@0ED8R05A18@0305=08003
05A18@1F@b<0Ed@T0080DD8S00<0DT4S05A18`1E@2<00P1G?b<01`1H?R<0ET<U05I38`1GA2@0Ed@S
05Q68P1IAb400P1JB2001P1SAal0I4PP06A8801UBB40ITXR06M;8`80J4`T0P1UD2<01P1WD2@0JE4U
06eB9`1_DRP0LU8Y07=C:P80M5DY0P1eERX0101fEb/0MeP/07QI;@1hFBd307eK:`0307iL;01oGBd0
P5h^0080PEl_00L0PV0`08MT;028IBd0R6D]08UV;P2:Ibl0RfP`0080S6Ta00H0RVHb08]W<`2<J3@0
SVXf091/>02AKCT209=_>`0309Qc?`2GLSh0UW4m0080UG0l00@0UW4m09Mb?P2HLcl0V7Do0P2IMT02
09Yg@@<0VgQ200@0W7U309ejA02MNT@0WGY40P2NNdD209mlAP0509mkA`2PO4P0XGe90:9nBP2SOd/0
0P2UPDd00`2VPTh0Z8=>0:R3CP020:V4C`<0ZXE@00@0ZhIA0:Z6DP2ZQU80ZXIB0P2[Qe<30:b8E0P0
[HQC402_Re/80;2;E`<0/8aL0`2_Re/20:j:FPP0/8]G00<0[hYF0;2;E`2bSET00P2cSUX00`2bSET0
/8]G0:n:EP080;6<F0<0/H]L0`2`RU/20:n9FP060:n9G02_REX0[hUJ0:n9F02_RUH0[hYE0P2_RU<9
0;2;E`P0[hYF202^RE@30:j9E@80[HQD0`2/Qe<00`2]R5@0[XUE0;2;E`020;6<F0060;2;E`2^RED0
[HQD0;67E@2`QU@0[hEC0P2^Q5802`2_QE<0/8ID0;67E@2^R5/0[XQI0:f7F02]QeH0[HQD0:n:E@2`
Re@0/HaE0080[hYF0`2^RED30:f8E0P0[XQI00D0ZhIB0:b7D`2]R5@0[XUE0:n:EP020:j9E@D0[HQD
102/Qe<01@2ZQE40ZhIB0:^6DP2/Qe<0[HQD0080[XUE0`2_RUH0102]R5@0[8MC0:b7D`2/Qe<20:f8
E0<0[8MC0`2[QU820:Z5D@X0[XUE0P2]R5@20:b7D`80ZhIB202`Qe<00`2/Qe<0[HQD0:j9E@030:j9
E@030:f8E02/Qe<0[HQD00L0[HQD00<0ZHA@0:Z5D@2[QU800`2/Qe<00`2[QU80ZXEA0:V4D0030:Z6
DP80ZhMC0`2/R5@20:f8D@030:f8D`2/Qe<0[8IE0080ZhEF00<0ZhEH0:f4D02]Q5001P2]Q5080:Z5
D@80ZHA@0P2ZQE420:^6DP80[8MC00<0[HQC0:b7DP2[QU400P2ZQE002@2[QU40[8MB0:f8D`2`QEX0
[hAG0:j3EP2]Pe<0[H=A0:j5D@020:n6D0@0[HA@0P2^QE420:n6DP<0[XAB0P2]Pe430:b2D0P0ZhIA
00P0ZHE90:V5B`2ZQDh0ZhI?0:b7D`2]R5@0[HMF0:j8F@80[XUE0P2]R5@20:b7D`80ZhIB202/Qe<0
1P2/QUT0[8IG0:b6E`2/QUD0[8MC0:b7DP80[8M@202]R5@00`2^Q580[hEC0;67E@030;:8EP80/HME
102]R5@40:b7D`030:f8E02^RED0[hYF0080/8]G00<0[hYF0:j9E@2]R5@00P2]R5@20:j9E@@0[hYF
00@0/8]G0:j9E@2^RED0[XUE0P2]R5@30:b7D`P0[HQD0P2ZQE430:^6DP<0[8MC00<0[X=F0:n4E`2`
QEP00P2`QEP00`2^PeH0[85D0:^0D`030:j9E@80[hYF0`2`ReL80:j9E@P0[8MC202]R5@80:f7F004
0:^6DP2/Qe<0[8MC0:b7D`<0[HQD2@2^RED20:b7DP040:^6D@2ZQE00ZXE@0:^6D@80[8MB0`2]R5@3
0:j9E@@0[hYF0`2^RED30:f8E0040:n:EP2^RED0[XUE0:f8E0<0[8MC00<0[HQD0:j9E@2^RED00P2]
R5@30:b7D`030:^6DP2`QU@0/8ID00<0[hEC0`2^Q5830:j:FP80[HUI0`2/R5P20:j9E@80[HQD0`2/
Qe<20:^6DP<0/HME0P2`QU@30:n5D`P0[hIB0P2`Qe400`2`Qe<0/8ID0;26EP020;25F0030;25FP2]
RET0[HUI00H0[HUI0P2/Qe<30:f8E0<0[XUE0P2/QUT30:f7FP<0[XQK0P2^RED20:f8E080[8MC0P2[
QU80102YQ500ZXEA0:Z5D@2ZQE430:^6DP030:b7D`2ZQE40ZXEA00<0ZhIB0`2/Qe<20:Z5D@<0ZhIB
0`2/Qe<00`2ZQE40ZhIB0:f8E0020:j9E@030:f8E02[QU80ZXEA00P0[8MC202ZQE080:Z5D@80ZhEF
00<0ZXAE0:V3E02XPU<00P2WPE802@2VP540ZH=F0:V3E02ZQ5D0ZXAC0:Z5D@2YQ4l0Yh9;0:J1BP04
0:Z5D@@0ZHA@0`2WPTh20:R3C`<0ZHA@00<0ZXIB0:V5D@2WPdl00P2VPTh0102WPdl0ZHEA0:V5D@2Z
QU820:R2D@040:R3C`2XPdh0Z8=>0:R3C080Z8A:0`2WPTd30:J1C080YH1;0`2VPDd20:N2CP<0Z8=?
00H0Yh5D0:J0D@2VP540YGm>0:AoB`2SOTT20:9mAP<0Y7m:0P2SOTT30:9mB0040:AoBP2SOTT0Xgi9
0:=nB@<0XWe800@0XGa709ag@P2LMd80WGQ30P2NND@00`2ONTD0X7]60:1kAP020:1kA`<0XGa8102R
ODT0102QO4P0X7]709mjAP2NNDD209mjAP040:1kA`2NN4T0WWQ909ihBB_ooooo000Zooooo`P0UVHf
0P2FJSd209M[?P80V6`o0P2IKD000`2GK3l0UV/n09I[?P0209EZ?@80U6Tl00<0TfPk09Q^?02HKS`0
1P2IKcd809][>`P0VFdl00@0Uf/n09Q/?`2HK3l0V6`o0P2IKD0209Y^@@P0VFlm0P2KKd00102LL3l0
W74n09eb?`2MLSd209ic?0@0WG501@2LL3l0102KL3d0WG8o09md@@2PMD820:5f@`80WgA10`2PMD82
0:5f@`<0XWM400<0WG5009ib@@2NLT400P2OLd820:1d@`030:5eA02QMT<0XGI300H0XGI3402SN4D8
0:QiA@P0Y7U60P2WOTX20:ImB@<0YGa800@0Y7]70:IlBP2UNdT0XgU70P2RN4H0102SNDL0YG]90:Il
BP2WO4L20:ImA`030:AmAP2QO4D0X7e50080WGe40P2QN4@03P2RNDD0XgY60:9iA@2QN4@0WgI209ed
@02QMdD0WWA209]a?`2GKC/0UV`j09Q^?02JL3h0W7900P2CLSd01`2BLC`0T6lj08m^>@2>KCP0SF`g
08a[=P2?I3L0102@ICP01`2>HcH0Rf0c08YO<P27HSD0QV4d08=N<@21G2l00P1oFRd2081K;P<0NeD^
0P1lERl207eG<00907iH<@1hEBl0MU<]07AA:`1cD2X0LTlY07=@:P1dDB/0ME8/00@0KThW1@1]CBH0
201aCB/0Kd/Y06e99`1/B2H0JdLU06a89P1]BBL0KTXX0`1ZBBP306U89`80J4LV01P0H4PT0657901Q
Ab@0I4LU06E79@1XAbH0JTLW06]8:01[C2d0JT//06U;:@1YBbL0JT`V06a?9`1^DBT0L5<Y075C;@1c
Dbd0M5@]07ED:`1gE2X0NUDY07aE:P1lERT207iI;`0307mJ<020Fc40PE`b0080PUdc00L0Pehd07mJ
<01oFS00P5/a085L<P23GS@0Q5le0080QF0f00H0PU/d08AM=026GcH0R64f08US=P29Hc@208QR<@03
08eR=@2<HC@0S64d0080Rf0c0P2:Gc800`29GS40Qf4d08MQ=00608MQ=0P0R68e00<0S64f08]P=@29
GS<00P28GC800`29GS<0Rf0e08aQ=P0308MQ<P80R68c0`29Hc@01@25Gc80QV0c08IP<`27HC@0RF<f
0080RV@g00<0RfDh08US=P2:I3L00`2;ICP00`29HcH0Qf4d08IP<`0208YT<`0308US=029HcH0R64f
0080Qf0g00/0Qf0i08mT=`2?I3L0SV<f08eR=@2<HC@0Rf0c08YO<P29GS40Qf4d08QR=@0308US=P03
08MQ=025Gc80Q5ha00T0RUlb0`26H3400`27HC80R68c08QR<`0208US=0P0R68c2029Hc@808US=P08
08IR<P27Hc<0R6@d08UU=@28I3@0Qf<c08EQ<@24H30208MQ<P<0QV0a0`25Gc0208IQ=0<0QF0c1024
Gc801`25H3<0Qf8e08QS=P28HcH0Qf8e08EP<`24Gc800P22GC0308AO<P03089M<020Fbh0OeX]00D0
P5/^0`21G2l8081K;PP0OeX`0P21G3801020Fc40OeX`07iI;`1mF2h207aG;@<0NULa0P1iES0307QE
;`06081F<01oEBl0O5D^07YD;@1iDb`0MU<[0P1dDbX307IC:`<0ME8Z0P1dDBT02P1/D2P0KE4Y06iB
:P1_Db/0KU8Z06eA:@1[CbL0JDdU06==9P1TCRL206E?:00406A>9`1RC2D0H4XS05m98P80GDHT00D0
Fd@T05U28`1G?b<0ECdS05@l8P0205<k8`09050k7P1@?Al0DCdR04ln901=?B@0BS/T04Hj8P14>280
ASXT0080ACTS00<0A3PR04<g8@12=R000P11=Al0100n>280?CLQ03dg8@0m=b4203`f8080>cDO00<0
?SLU03df900k=2800`0i<R0203/d8P80?c8Q00@0?C8P03/c800i<Ql0>3<O0P0f=1l00`0k<b00?3@Q
03`d8@0203de8P80?SHS00<0?cLT03df700m=Q`01P0m=Q`3048h7`T0@CLN1012>1l2040f7@80@CLN
0P12>1l204<i8080A3XQ0`13>B03048h7`80?CTN0P0l>1d0100k=a`0>SHK03Xf6`0j=Q/203df70@0
?SLM0P0m=Q`303hf8@<0?CDP0P0l=1l5044g7P<0@3HM0P14>1h204<g7@@0@SHL1011=a`2048h7@80
@cTN0`13>1`204@i7@<0ACXN00<0C3`R04/k8@1;>b400P1:>R0204Ti7`0404Ph7P19?Qh0BChN04Tn
7P<0BSlO0`1;@200201>?b00CChO04`m7P1;?1d0C3dN04dn7`1?@240D44R0P1@?Ad02@1A?Qh0DSlO
05=0801D@B40ED8R05I38`1@?Ad0DChN058o7`0205=08006058o7`1A?Qh0D3dM054n7P1B?al0E44Q
0P1E@R801P1D@B40DSlO054n7P1C@b80DD4P05107`80CclN00<0D40O0551801C@b800`1E@R8305I3
8`80Ed@T00L0EdDQ05I4801E@al0E48N05E37`1GAB40FDLS0080FTPT00X0FDLS05M58@1FA200ET@P
05M58@1IAb<0FTPT05U78`1JB2@0G4XV0P1MBbL00`1LBRH0FTPT05U78`0805E5900305I38`1GA2@0
F4DU0080FDHV00<0F4DU05M4901F@b<0201F@b<00`1GA2@0ET<S05A18@02058o7`0305=0801D@B40
ED8R0080D44T00<0DD0T05<o901D?b@00P1F?R@00`1G?B@0E44S05E2900205I38`0405M48`1HAR80
FDLQ05U78@80HdLO00<0I4PP06E98@1VBR800P1WBb<02`1XC2@0HdhQ06A?8P1VCb<0JE4U06aA9P1_
DRP0LU8Y07=C:P1bDbL0Le@X0080M5DY00@0MEHZ07IG:`1gF2`0MeP/0`1lFRX00`1mFb/0OU`/07mM
;@02081N;P03085O;`29IR`0RFH/00H0RFH/0P29IC40202;Ic<0SFTe08m[=`2AKCT0TVhj09=_>`2F
LCd0UG0l0P2DKc/0102EL3`0Ug8n09Ud@02JMD4209Yg@@@0VgQ21@2LND<209ejA0<0WW]500<0X7a8
0:5mB@2QODT00P2ROTX30:=oB`<0Z8=>0P2YQ4l30:Z5D080ZHEA0P2ZQU830:^7D`030:b8E02]R5<0
[HQC00H0[HQC202^RUX80;2<G0P0/8]G0P2aSEd20;2<G0040:n;F`2^RUX0[XYJ0:j:FPP0/8]G00<0
[hYF0;2;E`2aS5P00P2bSET00`2aS5P0/8]G0:n:EP080;2;E`<0/H]L0`2`RU/20:n9FP060:n9G02_
REX0[hUJ0:n9F02_RUH0[hYE0P2_RU<90;2;E`P0[hYF202^RE830:j9E@030:f8E02/Qe<0[8MC0080
ZhIB00<0[HQD0:j9E@2_RUH00P2aS5P01P2`ReL0[hYF0:j9E@2aQeD0/8ID0:n5D`80[XAB00/0[hEC
0;26E02aQeD0[hUL0:n9FP2]QeP0[HMF0:f8E02_RUD0/HaE0;:=EP020:n:EP<0[XUE0`2]R5@20:b6
E`H0[HMH00P0ZXEA0:b7D`2^RED0[hYF0;2;E`2_RUH0[XUE0:f8E0@0[8MC102]R5@20:Z5D@040:^6
DP2/Qe<0[HQD0:j9E@80[hYF00L0/8]G0:n:EP2]R5@0ZhIB0:Z5D@2[QU80[8MC00<0[HQD0P2/Qe<0
102[QU80ZXEA0:Z5D@2ZQE480:f8E080[XUE0P2]R5@20:b7D`80ZhIB202`Qe<0202[QU80[8MC0:j9
E@2_RUH0/8]G0:n:EP2]R5@0[8MC202]R5@00`2XPdl0ZHA@0:^6DP030:b7D`030:^6DP2YQ500Z8=?
0080Z8MB0P2YR5<40:Z9E080[HQA00H0[HQC0:f8E02/QUD0[8IG0:^5EP2[QEP80:f4D0P0ZXEA0`2[
QU820:b7D`<0[HQD00<0[HQC0:b7DP2ZQE000P2YQ4l0302ZQE00[8MB0:f8D`2`QEX0[hAG0:f2E@2/
PU80[89@0:j5D@2_QU00/HQB0:b3C`80[HA@0P2^QE420:n6DP040;27D`2^Q580[XAB0:j4DP80[H=A
0`2/PU080:^6D@080:R4AP2YQDT0ZXI<0:^6C`2/Qe<0[HMF0:j8F@2^R5/20:j9E@80[HQD0P2/Qe<:
0:^6DP060:^5F02[QEH0ZhEF0:^5E02[QU80ZhIA0P2[QTl80:f8E0080;26E02aQeD0/XQF0;>9E`2b
R5H0/HME0:n5D`2]Pe440:b7D`D0[HQD00H0[XUE0;2;E`2aS5P0/HaH0;2;E`2^RED40:f8E0<0[XUE
1@2_RUH20:j9E@<0[HQD00<0[8MC0:f8E02]R5@01P2]R5@20:Z5D@<0ZhIB0`2/Qe<00`2^PeH0[hAG
0;25F0020;25F0030:j3EP2/PE@0Zh1C00<0[HQD0P2^RED;0:n:EPP0[8MC202]R5@80:f7F0<0[HQD
00<0[XUE0:n:EP2_RUH00P2`ReL80:f8E0030:Z5D02[QU40[8MB00<0[8MB00<0ZhIA0:Z5D02]R5@0
0P2]R5@30:j9E@@0[hYF0`2^RED30:f8E080[hYF0P2^RED20:f8E0@0[8MC0P2[QU840:Z5D@80[H=A
0P2^Q5820:n5D`80/8ID0P2]RET30:b8F0<0ZhMG0P2^RED20:f8E0<0[8MC0P2[QU820;:8EP80/HME
0`2`QU@00`2_QE<0[XEA0:j5D@060:j5D@80/8MA00<0/8MC0;26E02`QUH00P2`QEP00`2`QEX0[XYJ
0:j:FP060:j:FP80[8MC0P2]R5@20:j9E@80[hYF102^Qe`40:f6F`80[XUE0P2]R5@20:b7D`80ZhIB
0`2YQ5000`2ZQE40ZhIB0:^6DP020:b7D`80ZXEA0`2[QU860:b7D`<0ZhIB0`2ZQE401`2/Qe<0[HQD
0:j9E@2^RED0[HQD0:b7D`2ZQE401@2/Qe<30:f8E0P0ZXE@00@0[HQD0:b7D`2[QU80ZhIB0P2YQ500
1`2XPdl0Yh9>0:^5EP2[QEH0ZXAE0:V3E02XPU<00P2WPE802@2VP540Z89E0:V3E02ZQ5D0ZhED0:Z5
D@2YQ4l0Yh9;0:F0B@080:R3C`@0Yh9>0P2XPdl20:V4D0030:V5D@2XQ500YX9>0080YH5=00@0YX9>
0:R4D02XQ500ZHEA0P2YPe80102YQ500ZHA?0:V4C`2YQ4d20:V5B`<0Yh9=0`2VPD`20:F0B`80YX5=
0P2WPTh40:R3C`080:N1E02WPE80YX1A0:EoCP2TOd/0Xgi90:=nA`2RODH20:J1C080YH1;0P2TOdX2
0:=nB@80Y7m80P2SOTL20:9mAP80XGa50P2MN44609ii@P80X7]70`2QO4P40:9mB@070:5lB02ONTH0
WWU509ehA02NNDD0WgY60:1kA`030:1jBb_ooooo000Zooooo`P0UVHf0P2FJSd209M[?P80V6`o0P2I
KD000`2GK3l0UV/n09I[?P0209EZ?@80U6Tl00<0TfPk09Q^?02HKS`01P2IKcd809][>`P0VFdl00@0
Uf/n09Q/?`2HK3l0V6`o0P2IKD0209Y^@@P0VFlm0P2KKd00102LL3l0W74n09eb?`2MLSd209ic?0@0
WG501@2LL3l0102KL3d0WG8o09md@@2PMD820:5f@`80WgA10`2PMD820:5f@`<0XWM400<0WG5009ib
@@2NLT400P2OLd820:1d@`030:5eA02QMT<0XGI300H0XGI3402SN4D80:QiA@P0Y7U60P2WOTX20:Im
B@<0YGa800@0Y7]70:IlBP2UNdT0XgU70P2RN4H0102SNDL0YG]90:IlBP2WO4L20:ImA`030:AmAP2Q
O4D0X7e50080WGe40P2QN4@03P2RNDD0XgY60:9iA@2QN4@0WgI209ed@02QMdD0WWA209]a?`2GKC/0
UV`j09Q^?02JL3h0W7900P2CLSd01`2BLC`0T6lj08m^>@2>KCP0SF`g08a[=P2?I3L0102@ICP01`2>
HcH0Rf0c08YO<P27HSD0QV4d08=N<@21G2l00P1oFRd2081K;P<0NeD^0P1lERl207eG<00907iH<@1h
EBl0MU<]07AA:`1cD2X0LTlY07=@:P1dDB/0ME8/00@0KThW1@1]CBH0201aCB/0Kd/Y06e99`1/B2H0
JdLU06a89P1]BBL0KTXX0`1ZBBP306U89`80J4LV01P0H4PT0657901QAb@0I4LU06E79@1XAbH0JTLW
06]8:01[C2d0JT//06U;:@1YBbL0JT`V06a?9`1^DBT0L5<Y075C;@1cDbd0M5@]07ED:`1gE2X0NUDY
07aE:P1lERT207iI;`0307mJ<020Fc40PE`b0080PUdc00L0Pehd07mJ<01oFS00P5/a085L<P23GS@0
Q5le0080QF0f00H0PU/d08AM=026GcH0R64f08US=P29Hc@208QR<@0308eR=@2<HC@0S64d0080Rf0c
0P2:Gc800`29GS40Qf4d08MQ=00608MQ=0P0R68e00<0S64f08]P=@29GS<00P28GC800`29GS<0Rf0e
08aQ=P0308MQ<P80R68c0`29Hc@01@25Gc80QV0c08IP<`27HC@0RF<f0080RV@g00<0RfDh08US=P2:
I3L00`2;ICP00`29HcH0Qf4d08IP<`0208YT<`0308US=029HcH0R64f0080Qf0g00/0Qf0i08mT=`2?
I3L0SV<f08eR=@2<HC@0Rf0c08YO<P29GS40Qf4d08QR=@0308US=P0308MQ=025Gc80Q5ha00T0RUlb
0`26H3400`27HC80R68c08QR<`0208US=0P0R68c2029Hc@808US=P0808IR<P27Hc<0R6@d08UU=@28
I3@0Qf<c08EQ<@24H30208MQ<P<0QV0a0`25Gc0208IQ=0<0QF0c1024Gc801`25H3<0Qf8e08QS=P28
HcH0Qf8e08EP<`24Gc800P22GC0308AO<P03089M<020Fbh0OeX]00D0P5/^0`21G2l8081K;PP0OeX`
0P21G3801020Fc40OeX`07iI;`1mF2h207aG;@<0NULa0P1iES0307QE;`06081F<01oEBl0O5D^07YD
;@1iDb`0MU<[0P1dDbX307IC:`<0ME8Z0P1dDBT02P1/D2P0KE4Y06iB:P1_Db/0KU8Z06eA:@1[CbL0
JDdU06==9P1TCRL206E?:00406A>9`1RC2D0H4XS05m98P80GDHT00D0Fd@T05U28`1G?b<0ECdS05@l
8P0205<k8`09050k7P1@?Al0DCdR04ln901=?B@0BS/T04Hj8P14>280ASXT0080ACTS00<0A3PR04<g
8@12=R000P11=Al0100n>280?CLQ03dg8@0m=b4203`f8080>cDO00<0?SLU03df900k=2800`0i<R02
03/d8P80?c8Q00@0?C8P03/c800i<Ql0>3<O0P0f=1l00`0k<b00?3@Q03`d8@0203de8P80?SHS00<0
?cLT03df700m=Q`01P0m=Q`3048h7`T0@CLN1012>1l2040f7@80@CLN0P12>1l204<i8080A3XQ0`13
>B03048h7`80?CTN0P0l>1d0100k=a`0>SHK03Xf6`0j=Q/203df70@0?SLM0P0m=Q`303hf8@<0?CDP
0P0l=1l5044g7P<0@3HM0P14>1h204<g7@@0@SHL1011=a`2048h7@80@cTN0`13>1`204@i7@<0ACXN
00<0C3`R04/k8@1;>b400P1:>R0204Ti7`0404Ph7P19?Qh0BChN04Tn7P<0BSlO0`1;@200201>?b00
CChO04`m7P1;?1d0C3dN04dn7`1?@240D44R0P1@?Ad02@1A?Qh0DSlO05=0801D@B40ED8R05I38`1@
?Ad0DChN058o7`0205=08006058o7`1A?Qh0D3dM054n7P1B?al0E44Q0P1E@R801P1D@B40DSlO054n
7P1C@b80DD4P05107`80CclN00<0D40O0551801C@b800`1E@R8305I38`80Ed@T00L0EdDQ05I4801E
@al0E48N05E37`1GAB40FDLS0080FTPT00X0FDLS05M58@1FA200ET@P05M58@1IAb<0FTPT05U78`1J
B2@0G4XV0P1MBbL00`1LBRH0FTPT05U78`0805E5900305I38`1GA2@0F4DU0080FDHV00<0F4DU05M4
901F@b<0201F@b<00`1GA2@0ET<S05A18@02058o7`0305=0801D@B40ED8R0080D44T00<0DD0T05<o
901D?b@00P1F?R@00`1G?B@0E44S05E2900205I38`0405M48`1HAR80FDLQ05U78@80HdLO00<0I4PP
06E98@1VBR800P1WBb<02`1XC2@0HdhQ06A?8P1VCb<0JE4U06aA9P1_DRP0LU8Y07=C:P1bDbL0Le@X
0080M5DY00@0MEHZ07IG:`1gF2`0MeP/0`1lFRX00`1mFb/0OU`/07mM;@02081N;P03085O;`29IR`0
RFH/00H0RFH/0P29IC40202;Ic<0SFTe08m[=`2AKCT0TVhj09=_>`2FLCd0UG0l0P2DKc/0102EL3`0
Ug8n09Ud@02JMD4209Yg@@@0VgQ21@2LND<209ejA0<0WW]500<0X7a80:5mB@2QODT00P2ROTX30:=o
B`<0Z8=>0P2YQ4l30:Z5D080ZHEA0P2ZQU830:^7D`030:b8E02]R5<0[HQC00H0[HQC202^RUX80;2<
G0P0/8]G0P2aSEd20;2<G0040:n;F`2^RUX0[XYJ0:j:FPP0/8]G00<0[hYF0;2;E`2aS5P00P2bSET0
0`2aS5P0/8]G0:n:EP080;2;E`<0/H]L0`2`RU/20:n9FP060:n9G02_REX0[hUJ0:n9F02_RUH0[hYE
0P2_RU<90;2;E`P0[hYF202^RE830:j9E@030:f8E02/Qe<0[8MC0080ZhIB00<0[HQD0:j9E@2_RUH0
0P2aS5P01P2`ReL0[hYF0:j9E@2aQeD0/8ID0:n5D`80[XAB00/0[hEC0;26E02aQeD0[hUL0:n9FP2]
QeP0[HMF0:f8E02_RUD0/HaE0;:=EP020:n:EP<0[XUE0`2]R5@20:b6E`H0[HMH00P0ZXEA0:b7D`2^
RED0[hYF0;2;E`2_RUH0[XUE0:f8E0@0[8MC102]R5@20:Z5D@040:^6DP2/Qe<0[HQD0:j9E@80[hYF
00L0/8]G0:n:EP2]R5@0ZhIB0:Z5D@2[QU80[8MC00<0[HQD0P2/Qe<0102[QU80ZXEA0:Z5D@2ZQE48
0:f8E080[XUE0P2]R5@20:b7D`80ZhIB202`Qe<0202[QU80[8MC0:j9E@2_RUH0/8]G0:n:EP2]R5@0
[8MC202]R5@00`2XPdl0ZHA@0:^6DP030:b7D`030:^6DP2YQ500Z8=?0080Z8MB0P2YR5<40:Z9E080
[HQA00H0[HQC0:f8E02/QUD0[8IG0:^5EP2[QEP80:f4D0P0ZXEA0`2[QU820:b7D`<0[HQD00<0[HQC
0:b7DP2ZQE000P2YQ4l0302ZQE00[8MB0:f8D`2`QEX0[hAG0:f2E@2/PU80[89@0:j5D@2_QU00/HQB
0:b3C`80[HA@0P2^QE420:n6DP040;27D`2^Q580[XAB0:j4DP80[H=A0`2/PU080:^6D@080:R4AP2Y
QDT0ZXI<0:^6C`2/Qe<0[HMF0:j8F@2^R5/20:j9E@80[HQD0P2/Qe<:0:^6DP060:^5F02[QEH0ZhEF
0:^5E02[QU80ZhIA0P2[QTl80:f8E0080;26E02aQeD0/XQF0;>9E`2bR5H0/HME0:n5D`2]Pe440:b7
D`D0[HQD00H0[XUE0;2;E`2aS5P0/HaH0;2;E`2^RED40:f8E0<0[XUE1@2_RUH20:j9E@<0[HQD00<0
[8MC0:f8E02]R5@01P2]R5@20:Z5D@<0ZhIB0`2/Qe<00`2^PeH0[hAG0;25F0020;25F0030:j3EP2/
PE@0Zh1C00<0[HQD0P2^RED;0:n:EPP0[8MC202]R5@80:f7F0<0[HQD00<0[XUE0:n:EP2_RUH00P2`
ReL80:f8E0030:Z5D02[QU40[8MB00<0[8MB00<0ZhIA0:Z5D02]R5@00P2]R5@30:j9E@@0[hYF0`2^
RED30:f8E080[hYF0P2^RED20:f8E0@0[8MC0P2[QU840:Z5D@80[H=A0P2^Q5820:n5D`80/8ID0P2]
RET30:b8F0<0ZhMG0P2^RED20:f8E0<0[8MC0P2[QU820;:8EP80/HME0`2`QU@00`2_QE<0[XEA0:j5
D@060:j5D@80/8MA00<0/8MC0;26E02`QUH00P2`QEP00`2`QEX0[XYJ0:j:FP060:j:FP80[8MC0P2]
R5@20:j9E@80[hYF102^Qe`40:f6F`80[XUE0P2]R5@20:b7D`80ZhIB0`2YQ5000`2ZQE40ZhIB0:^6
DP020:b7D`80ZXEA0`2[QU860:b7D`<0ZhIB0`2ZQE401`2/Qe<0[HQD0:j9E@2^RED0[HQD0:b7D`2Z
QE401@2/Qe<30:f8E0P0ZXE@00@0[HQD0:b7D`2[QU80ZhIB0P2YQ5001`2XPdl0Yh9>0:^5EP2[QEH0
ZXAE0:V3E02XPU<00P2WPE802@2VP540Z89E0:V3E02ZQ5D0ZhED0:Z5D@2YQ4l0Yh9;0:F0B@080:R3
C`@0Yh9>0P2XPdl20:V4D0030:V5D@2XQ500YX9>0080YH5=00@0YX9>0:R4D02XQ500ZHEA0P2YPe80
102YQ500ZHA?0:V4C`2YQ4d20:V5B`<0Yh9=0`2VPD`20:F0B`80YX5=0P2WPTh40:R3C`080:N1E02W
PE80YX1A0:EoCP2TOd/0Xgi90:=nA`2RODH20:J1C080YH1;0P2TOdX20:=nB@80Y7m80P2SOTL20:9m
AP80XGa50P2MN44609ii@P80X7]70`2QO4P40:9mB@070:5lB02ONTH0WWU509ehA02NNDD0WgY60:1k
A`030:1jBb_ooooo000Zooooo`P0UVHf0P2FJSd209M[?P80V6`o0P2IKD0209M/?`80UV/n00@0UFXm
09AY?02DJC`0TfPk0P2HKS`409U_?@80VW0n202KJc/809U]?0@0V6`o0P2IKD0209Y^@@P0VFlm0P2K
Kd00102LL3l0W74n09eb?`2MLSd209ic?0@0WG501@2LL3l0202KL3d0W74n09md@@2QMT<0XWM40:5f
@`2PMD80WgA10P2PMD820:5f@`<0XWM400@0XgQ509ea@02MLD00WW910P2OLd800`2PM4<0XGE40:5e
A0080:5f@`P0XgQ500<0XGI30:9gA02RMd@00P2RMd@30:=hA@P0Z7U5202TNDH20:MnBP030:ImB@2U
O4P0YGa800<0YGa800<0YWa:0:EkB@2SNDL00P2RN4H0102SNDL0YG]90:IlBP2WO4L20:ElAP030:=l
A@2PNd@0Wga40080W7a30P2QN4@0502RNDD0XgY60:9iA@2PMd<0WWE109ed@02QMdD0WWA209Y`?P2G
KC/0UV`j09M]>`2JL3h0W79009=b?@2BLC`0TG0k091_>P2?KST0SF`g0P2<JcH0302>HcH0Sf@g091U
>02@ICP0Sf@g08eR=@2;H3<0RUlb08IQ=024Gc80PUd`07mJ;@<0OUT/00L0OeX]07UC;01iDb`0NU@]
07]E;P1mEc00OUPa0080OeTb00<0MU<]07EB;01cD2X00P1bCbT00`1cD2X0ME8/07IC;@0306e=9PH0
K4`U00<0LDd[06m;:@1]BBL00P1[AbD00`1/B2H0KDTW06m;:@0306Y9:080JDPW0`1XAbH01P1OAb<0
HDLT06=99P1VBBL0J4XX06Y9:080JTLW0P1[C2d0401ZC2X0JT`X06]=9`1]D2P0Ke8Z071C:@1bE2h0
M5@^07AD;@1fEB`0N5D[07YE:@1lEBX0O5HY07iI;`1oFS02081K<@04085L<P22GC<0Pehd08=N=080
OUT_00h0P5/a085L<P23GS@0QF0f08IQ=`27HSP0PU/d08AM=026GcH0R64f08US=P29Hc@0RF<b08QR
<@80SF8e0P2<HC@0102;H3<0RUlb08YO<P29GS4808MQ=0P0R68e00<0S64f08]P=@29GS<00P28GC80
0`29GS<0Rf0e08aQ=P0208MQ<P<0R68c0`29Hc@01P25Gc80QV0c08IP<`28HSD0RF<f08YT=`80RfDh
00P0R68e08YT=`2;ICP0S6Hi08]U>02:I3L0R68e08IP<`80RV@c00<0RF<d08US=P28HCH00P27H3L0
3026GcP0T6Dh08mT=`2>HcH0SF8e08aQ=02;H3<0RUlb08UN<@26H3<0Qf4d08QR=@80RF<f00<0Qf4d
08EO<P24GS402@2;Gc8208EO<00408IP<@27HC80Qf4b08QR<`80RF<d2026H34808US=0P0RV@g00P0
R6@d08UU=@2:ISH0RVHf08UU=@27Hc<0QF4a08AP<080R68c00<0Qf4b08IP<@25Gc000P24GRl00`23
GBh0QV4d08IQ=00308EP<`@0Q5lb00l0QF0c08MR=@28HcH0R6<f08MR=@25H3<0Q5lb085L;`22GC00
Q5lb08EP<`24Gc80PUd`081K;P1oFRd00P20Fbh607mJ;@P0P5/^201nFBl02022GC<0PE`b081K<@1o
FS00OUT_07eH;P1lEbd0NeH/0P1jEc4307UF<0<0N5D_00P0P5H`07mE;`1lEBh0NU@]07UC;01fDb/0
M5<Z07=B:@<0MU<[0P1eDRX307AA:@0306a@:01]DBT0KU8Z0080KU8Z00<0K50X06]?9`1YCBD00P1T
CRL206E?:00;06==9P1QBb@0GTPQ05e7801MAR@0G4DU05Y38`1H@B80EShR05@l8P1B>R800P1A>B40
201>>ad0Cc/P04hm8@1=?B<0BcdS04Tj8`15>B<0@cLQ0P14>B<00`13>280@SLQ044f8002040e7`04
03ld7P0l=b<0?3LS03`g8`80>cHR0`0j=B40200m>2D0?3LT03Xe8P0i=240>3<P03Td8@0j=B80>cHS
0P0o<R401P0m<R00>c<P03Tb7`0h<al0=S@O03Dc7P80>c<P00@0?3@Q03de8P0m=B80?SHS0P0o=b@8
03df70@0@SPO1011=ah01@0o=A`0@3HM040f7@11=ah0@SPO0080@cTP00<0A3XQ040f7@10=Qd00P11
=ah2048h7`80@cTP0P14>R4304<i80<0@SPO0P0m>Ah0100l>1d0>cLL03/g700j=Q/203Te6P0303hg
7@0m=Q`0?CHL0080?3DK0P0m=Q`0100n=ad0?SHQ03hf8@0n=R4203de80<0?3@O0`11=ah5040f7@80
A3PN0P13=ad3048f7003044e6`10=Q/0@CLL0080@CLL0P12>1d204<i7P<0@cPL0P14>Ad304Dj7P04
04/k8@1:>R00BSXP04Ti7`80B3PN0P17=ad404Po7P80BD0O0`1:@B000`1>?b00CChO04/l7@0204/l
7@0>04dn7`1?@240D44R04ll701@?Ad0DChN058o7`1C@200E44Q05E28P1F@b<0D3dM054n7P1B?al2
05=08006058o7`1A?Qh0D3dM050m7@1B?al0Dd0P0P1E@R801P1C@200DSlO050m7@1B@R40DD4P0510
7`80CclN00<0D40O0551801B@R400P1E@R8205I38`0605M4901HABD0FDHV05U69P1FA200ED<O0P1D
@Qh00`1E@al0EdDQ05U78`0205Y8900:05Q68P1GAB40ED<O05E37`1GAB40F4HR05Y8901IAb<0FTPT
05a:9P80GD/W00<0G4XV05Y8901IAb<0201DA2<00`1F@b<0Ed@T05Q59@0205U69P0305Q59@1GA2@0
ET<S00<0ET<S0P1GA2@305I38`0805Q59@1GA2@0E44Q058o7`1A?Qh0DSlO05=0801D@B4205119003
0550901C?b@0E3lT0080EShT00X0EcdT05A09@1D@B<0ED8T05I38`1GA2<0F4HR05Q6801IAb40HTHN
0P1SAal00`1TB200IDTQ06I:8P0206M;8`80HdhQ00@0ITlS06Q@901/DBH0Ke8X0P1bDRT2079C9`03
07=D:01dEBT0MEHZ0080MUL[00<0MeP/07]I:@1lFRX00P1lFRX00`1mFb/0OU`/07mM;@02081N;P<0
RVL]00<0RFH/08QU:`28IB/00P27I2X02P28I300RFDa08YV<P2<J3@0Sf/g095]>@2BKSX0Tflk09E`
?02DKc/209=^>P0409A_>`2GLSh0VWE109ag@`80VgQ21P2LND<0102KN480W7U309ai@`2LND<209ej
A080WW]50`2QODT50:9nBP<0Z8=>0`2YQ4l20:Z5D080ZHEA0P2ZQU840:^7D`P0[HQC202^RUX80;6=
G@P0/8]G0P2aSEd20;2<G0040:n;F`2^RUX0[XYJ0:f9F@P0/8]G00<0[XUE0;2;E`2aS5P00P2bSET0
0`2aS5P0/8]G0:j9E@080;2;E`<0/H]L0`2`RU/20:n9FP060:n9G02_REX0[hUJ0:n9F02_RUH0[hYE
0P2_RU<90;2;E`P0[hYF202^RE830:j9E@030:f8E02/Qe<0ZhIB0080ZhIB00<0[HQD0:j9E@2_RUH0
0P2aS5P01P2`ReL0[hYF0:j9E@2aQeD0/8ID0:n5D`80[XAB00/0[hEC0;26E02aQeD0/8YM0:n9FP2]
QeP0[8IE0:f8E02_RUD0/HaE0;:=EP020:n:EP<0[XUE0`2]R5@20:^5EPD0[8IG00@0[HMH0:Z5D@2/
Qe<0[XUE0P2`ReL00`2_RUH0[XUE0:f8E0040:b7D`@0[HQD00l0ZHA@0:Z5D@2[QU80[8MC0:f8E02^
RED0[hYF0;2;E`2aS5P0[hYF0:f8E02[QU80ZXEA0:^6DP2/Qe<00`2]R5@20:b7D`040:^6DP2ZQE40
ZXEA0:V4D0P0[8MC0P2^RED20:f8E080[8MC0P2[QU880;27D`030:^6DP2/Qe<0[XUE0080/8]G00<0
[hYF0:f8E02/Qe<0202]R5@00`2XPdl0ZHA@0:^6DP030:b7D`030:^6DP2YQ500Z8=?0080Z8MB0P2Y
R5<30:Z9E0090:^:E@2^RE80[HQA0:f8D`2]R5@0[8IE0:b6E`2[QEH0ZhEH00P0[HA@202ZQE430:b7
D`80[HQD0`2^RED00`2]R5<0[8MB0:Z5D0020:V4C`0<0:Z5D02/Qe80[HQC0;25FP2_Q5L0[H9E0:b2
DP2/PU00[XEA0;27D@2aR580[8=?0P2]Q5000`2^QE40[hIB0:n6DP020;27D`<0[XAB0P2]Pe430:b2
D0P0ZhIA00P0Z8E50:V5A`2YQDT0ZhI?0:b7D`2]QeP0[XQK0:j7G080[XUE0P2]R5@20:b7D`X0ZhIB
00H0ZhEH0:^5EP2[QEH0ZhED0:^6DP2[QU420:^6C`P0[HQD00P0/HME0;:8EP2cREL0]8YH0;:8EP2`
QU@0[H=A0:b2D0@0[8MC1@2]R5@01`2^RED0/8]G0;6<F02aS5P0/8]G0:j9E@2]R5@00`2]R5<40:j9
E080[hYE0P2_RUH20:j9E@`0[HQD0P2ZQE430:^6DP<0[8MC00<0[X=F0:n4E`2`QEP00P2`QEP00`2^
PeH0[85D0:^0D`030:b7D`80[HQD0`2^RED80:n:EPP0[8MC202]R5@80:f7FP<0[XUE00<0[hYF0;2;
E`2aS5P00P2aS5P80:b7D`030:R3CP2ZQE00[8MB0080[XUD00<0[8MB0:Z5D02XPdh00`2]R5@30:j9
E@@0[hYF0`2^RED30:f8E0030:j9E@2_RUH0[hYF0080[XUE0P2]R5@00`2/Qe<0ZhIB0:^6DP020:Z5
D@80ZHA@0P2XPdl01P2[PDl0[89@0:f3D@2^Q580[hEC0;26E080/HME0`2/R5P20:^7E`<0ZXIF0P2^
RED20:f8E0<0[8MC0P2[QU820;:8EP80/HME102`QU@80:j5D@80/8MA00<0/8MC0;26E02`QUH00P2`
QEP00`2`QEX0[XYJ0:j:FP060:j:FP80[8MC0P2]R5@0102^RED0[hYF0:n:EP2`ReL20;29GP030:n8
G@2^Qe`0[HIK0080[8EJ00<0ZhAI0:j9E@2^RED00P2]R5@20:b7D`80ZhIB0P2XPdl0102YQ500ZXEA
0:Z5D@2[QU820:b7D`80ZXEA0`2[QU830:b7D`060:j9E@2]R5@0[HQD0:b7D`2[QU80ZXEA0P2YQ500
0`2[QU80[8MC0:f8E0020:j9E@030:f8E02/Qe<0ZhIB00@0[8MC102]R5@80:Z5D080[XUE00@0[8MC
0:^6DP2YQ500Z8=?0P2VPDd20:^5F0030:Z4E`2YPeH0Z89E0080Yh5D00T0YX1C0:R2E@2YPe@0ZhEF
0:^5E02[QU80ZHA?0:J1BP2UP4T00P2VPDd40:N2CP80Z8=?00@0YX5=0:N2CP2WPTh0Yh9>0P2XPdl2
0:V4D0030:R4D02WPdl0YH5=0080Y81<00@0YH5=0:N3C`2WPdl0Z8A@0P2YPe80102YQ500ZHA?0:V4
C`2YQ4d20:V5B`<0Yh9=0`2VPD`20:F0B`80YX5=0P2WPTh30:R3C`070:V4D02WPE@0Yh5B0:J0D@2U
Odh0Y7m;0:AoBP020:=nA`80Yh9=0P2VPD`30:F0B`060:AoBP2TOdP0Y7m80:AoB02SOTL0XWe60`2Q
O4D0102ONT<0WWU209ii@P2NND8309eh@@0309ag@02PNdL0X7]700<0XGa8102RODT01`2QO4P0WgY6
09ehA02LMd<0WGQ409mjAP2PNdL00`2QNdh[ooooo`00:_ooool309IZ>@<0Uf/j0P2HK3/209EY?0<0
UVXm0`2GJch0202KKd80VVi109U]@02HK3l0Uf/n09IZ?@2EJC`0U6Pk1@2IKS/309Q]>P80VVhm0`2K
Kch309a`?`0309Q/?`2IKD00Vfm20080W71300<0Vfm209U]@02HK3l00P2GJch209Q/?`0509U]@02J
KT40VVi109]_@P2HJd400P2IK4800`2KKT@0W6m509e`AP0209iaA`080:1Y@P2QK480XFi309m`@P2L
LT00VW8n09Ic>`2DLCT909U^>`<0WG8o0`2NLd0209md@@80XW910`2SLd830:Ad@`0609eb?`2NLd00
WW=00:1e@P2QMT<0XWM40P2SN4D30:9fA@@0XgM600@0Y7Q70:9gA02RMd@0XWM40`2SN4D20:AiAP03
0:Ej@`2TND80XWM20080XGI300<0XWI50:AhB@2UNDX0202UNTL80:IkB0030:UnB`2XODX0YW]80080
Y7U600<0YGY70:MlB@2XODX0202RNDD0202SNTH0Y7]70:ElB02VODT0YGa80:=jAP2PMd<0WgI21`2N
M480102MLd40Vg4o09]a?`2KLCl209Y`?P<0VFlm00T0U6Pk099W>P2@ICX0SV@j08aU?02=Id00SFY2
08i[A@2;ICP00`2:I3L208US=P80R68e00D0Qf8e08EP<`22GC00OeX]07eH:`0307aG:P0907iG<01m
ERl0O5D^07]D;@1jDb`0NE8[07QA:P1gD2T0N54Z0080Mdl[00<0MTh[07E<;01dBbd00P1cBRh206i=
:P<0KD`Y101/BbP0101]Cbd0K4h/06U;:@1WBBL306I89P0506M99`1]C2/0K4/Z06a;:P1[BRT00P1Z
BBP206U89`0F05m8:@1PAbT0HDPY0697:@1UB2P0IdTW06U89@1ZBBH0JD/U06a<9P1]CBL0KddX079>
:P1fD2`0N50]07UA;P1gDRP0N5<Y07UD:P1jEB/0O5L]07eH;P80OUT_0`1oFRd2081K;P<0PE`_0P25
GS<01P25Gc80QV0a08IP;`26HBd0Qf8^08MR;@<0R68c0P27HC8308IP<@80SV<f00<0SF8e08aQ=02;
H3<00P29GS401@28GC00R68a08MQ<027HC00QV0_0080QEl^0P24GRd02023HC<0Q68d08MR=@29HcH0
Rf8f08YO=029GS<0R5/a0P2<HCH608]P=@P0Qf4b00P0RF<f08QR=@27HC@0QV0c08MQ=028HSD0RV@g
08]U>0P0RF<d00`0RV@c08US<P27HC80Qf4d08QQ=P2:HcX0S6Dl08iW@02<JSX0RVPh08MU=@25Hc<2
08AR<P0308ES<`26I3@0RVDh0080RVDh0P29I3L308QS=P<0RF<d0`28HS<308MQ<P0:08]V<@29I300
R6<_08IP;`26H340Qf4d08UR=`2:HcP0RF<d08QR<`80Qf4b00@0R68c08YT=@2<ISL0SVPi202:I3D2
08UP<P0408MQ<P26HS80QV8b08AR<P80Pf<b00H0RFH`08UU<@28I300Qf<a08EQ<@24Gc8208=N<P<0
Qf8e0P26HC@308EP<`80R6<f00@0Qf8e08IQ=026HC@0QF0c0P24Gc8808EP<`<0PUd`0P21G2l3081K
;P08081M<`1oG380O5T_07]H;P1jEbd0NeP^07aI;`1nFc4807iL;PP0OU/a201kF2h207YG;@<0NEH/
0`1hEB/01P1jFS<0NETb07UI<P1hF340MeL`07IF;`80MED^00<0KU0/071B;P1aDbl00P1cEC40101b
E300LE<_071B;P1ZDbX306]D:`0<06UB:@1VCbH0Hd`S065:8@1VBB/0IDPZ0697:@1PAbP0GDHV05Y6
9@1IAB@0Ed@S0P1G?RP0101C?BH0DS`U04lk8`1;>B4304Ti8080B3`T00@0Ac/S04Hj8P14>200@cLO
0P12=Qh2048g8`<0@cPT0`14>BD303lg8P<0?SHQ0P0m=B000`0o=b80?SHQ03`d7`0203/c7P0;03`d
7`0n=R40?cLR04@i9@13>2@0@3DQ03hc7`0m<Qh0?S<O040e8@12=b<0200n<Ah803hf8@80?SLM0P0o
>1h3040i7`03044j800o>1h0?cPN00H0?cPN200n=R4303lh7P<0?SLM0P0m=Q`803de800503Td7P0j
=Al0>SDO03/f800l=b400P0m>2800`0n>B<0>C@N03Td7P0203Td7P80>SDO0P0k=R0203dh8P0403`g
8@0k=R00>SDO03Xe7`80>C@N00<0?cLR03hf8@0l=1l00P0k<ah00`0l=1l0?SHQ03lg8P03044g7P@0
@3HM00H0?cDL04@k7P13>Qd0@cXM048i7011>1/2040g6P0403lf6@16>1d0ASPM04Hh7@80AcTN0`18
>Ql504Xl8P<0BC/Q00<0B3XP04Lk8@17>b401P17>b4204hm7`<0C3/M00<0CSdO050o8@1A@2800P1E
@R8205A18@<0Dd0P00T0DSlO04`k8@1<>b40CSdS04ln901A@2H0Dd8X05A3:@1EA2X00`1=?Ql204ho
80<0Cd0Q01<0ED8Q05I38P1GA2<0F4DT05M48`1E@R40DSlN050m701B@2P0DT4W05=2:01D@bL0ED@V
05I69@1FAR@0EdLU05U5901HA2<0ET8Q0080ED4P00L0ET8Q05Q48`1IAB@0DdDN05E7801GBB80FT`U
0080FddV00<0FT`U05U;901EAB@01`1EAB@805A48`<0ET<U0P1E@R@305A18`030593901@@B80Cd0Q
0080CChO00h0Cd0Q05118P1B@b@0CC`N04hm7`1??R00D3lQ05508P1B@B<0Dd8T05A39@1F?Al0EchP
05U08P<0FT4S00D0F3lQ05Ln801OBB@0GTPS05e78P0205a68@0=05i88`1OBB@0HD/V06]=:@1XBRH0
IDLS0694801SAB40IdTU06a>:P1`DRh0M5DY07=D:002079C9`0407=D:01eERX0MeP/07QI;@<0O5LZ
01H0OEP[07mJ;@21G2l0Peha08EP<`26HC@0O5XZ085P;@28Ic@0RVTd08QW<@27Ibh0R6P]08][<029
JCP0R6Pg08QV=P29ICD0RVHf08iX>@2BJC/0U6/m0P2AKCT01P2BKSX0Tflk09A`?02ELCd0UW8n09Mc
?`D0VGE10`2HM40209]g@`80W7Q40`2MNDD01P2NNTH0X7]70:1kA`2QO4P0XWe90:=nBP80Y7m;00H0
YH1<0:F0B`2UP4/0YX5<0:N2C@2XPdh20:V4C`060:Z5D02YQ4l0ZHA?0:Z5D02[QU40[8MB0P2]R5<0
0`2^RE@0ZhIB0:^6DP020:b7D`80[HQD0P2^RED01P2^ReD0[XYF0:n;E`2_ReT0[h]K0;2;GP80/8]O
00<0/H]L0;2:F`2^R5T00P2^R5T00`2`RU/0/heN0;B>G`020:j:FP<0[h]K0`2`S5`80;6;G0P0[h]K
0P2_RUh00`2_RUd0[h]K0:n;F@020:n;E`060:n<EP2cSUX0/hiJ0;>>FP2bSET0/HaH0`2`ReL80;:<
G@80[XYF0`2]RED30:b8E0T0[8QH202`S5`20;>>FP030;:=F@2aS5P0/8]G0080[hYF00<0[XUE0:j9
E02_RUD00P2`ReH0102_RUD0[HQC0:^6D@2ZQE030:j9E@<0[HQD0P2/Qe<20:f7F0<0[8IG00<0[XQI
0;2:F`2bS5d00P2aS5P0102`ReL0[hYF0:n:EP2^RED20:f8E080[XUB0P2]R5420:b7D080ZhI?00H0
[HMJ0:f7F02]QeP0[HMF0:f8E02]R5<20:f8D@P0[HQD202^RED20:n:EP<0/8]G0`2aS5P01P2_RUh0
[XUM0:b7F`2ZQET0ZHAH0:Z5F@80ZhIJ00P0[XQK0:n9FP2`RU/0/H]J0;6<F02_RUD0[HQA0:b7D0P0
[HMJ0`2/Qe040:^6C`090:Z5CP2[QEP0[8IG0:j8F@2_REP0[hYF0:f8D`2[QTl0ZHA=0080[XUE0P2]
R5@20:b7D`80ZhIB0P2[QU440:Z5D080ZHA?00<0Yh9>0:V4D02[QU800`2/Qe<0302[QU80ZXEA0:R3
C`2[Qd/0ZhM=0:^6C`2ZQE00ZXAC0:V3EP2YPUL0ZH9I0:f8E0D0[8MC0P2[QU802`2/Pdd0[HA>0:f4
D02^Q580[hEE0:n4E`2`QEP0/8EJ0;26E02_QE<0[H=A0080Zh5?00<0[89@0:f3D@2^Q5800P2XPdl2
0:V4D0<0ZXEA00<0ZhIB0:f3D@2]Pe401P2]Pe400`2WPE@0Z89E0:Z4E`020:b6F@030:^5F02ZQ5L0
ZH=F00P0ZhIB202[QU40202ZQT`0ZhM=0:b7D02]R5<0[8MB0:^6DP2YPe80Z89A0P2ZQE430:^6DP<0
[8MC00<0ZhIB0:b7D`2]R5@00P2^RED01@2]R5@0[8MC0:^6DP2[QU40ZXE@00<0Z8=>00<0ZXE@0:b7
DP2]R5<00P2ZQE40102[QU80[8MC0:f8E02^RED20:n:EP80[XML00<0[XQK0:j8F@2^R5L00P2^RED0
0`2^RE@0[8MC0:b7D`030:f8E0<0[XUE0`2]R5@50:j9E@80[8MC0P2]R5@0202^RED0[hYF0:n:EP2`
ReL0ZXAC0:^5E02[QU80[8MB0P2]R5<00`2^RE80[XY@0:n;D@080:n9F0<0/HME00<0/8ID0:n5D`2^
Q5800P2^Q580202`ReL0[XUE0:b7D`2[QU80ZXEA0:^6DP2/Qe<0[HQD0P2_RUH30:j9E@<0[HQD0P2[
QU820:b7D`80[HQD0P2^RED20;6<F0030;2;E`2_RUH0[XUE00<0[XUE202`ReL00`2^RED0[HQD0:^6
DP020:^6DP030:b7D`2^RED0[hYF0080[H=A00@0[XAB0:n5D`2_QE<0/8ID0P2aQeD80;68E0P0ZhI?
00<0[XAB0:n5D`2`QU@00P2aQeD00`2`QU@0[hEC0:j4DP080;27D@T0[XUE0`2]R5@30:b7D`030:^6
DP2_RUH0[hYF0080[XUE102]R5@30:^5F0<0[8II0P2]QeX80:j9E0T0[8MC00<0ZHA@0:Z5D@2/Qe<0
0P2^RED00`2]R5@0[8MC0:^6DP020:j9E@80[HQD0P2/Qe<20:^6DP<0[8QD0`2]RED20:j:EP80[XUB
00<0[XUD0:j9E@2^R5L00P2^R5T0302^R5/0/8aL0:n;F`2/R5P0ZhMG0:Z6EP2[QeL0[HUI0:j:FP2[
QEP0[HMJ0:n9G080/8YM00H0[hUL0:f7FP2[QEP0ZHA@0:Z5D@2/Qe<20:f8E0030:b7D`2ZQE40ZHA@
00P0ZhEF202/Qe<30:^6DP80ZXEA0`2YQ5030:^:E@030:Z9E02YR5<0Z8MB0080Z8MB0P2XPU<0102Y
Pe@0ZXAE0:Z4E@2[QEH20:b6E`80[8MC00@0ZhIB0:Z5D@2ZQE40ZHA@0P2XPdl20;27D`040:n6DP2^
QE40[8=?0:^2CP80ZX5=0`2YPe@20:Z4E@<0ZhEF202ZQE440:N2C@80YX5<0P2UP4/80:F1C@030:^6
D@2ZQE00Z8=>0080Yh9=00@0Z8=>0:Z5D02ZQE00ZhIA0P2VPDd20:N2CP80Z8=?0P2YQ5080:F0B`06
0:J1C@2WPTh0Yh9>0:R3C`2YQ500ZXEA0P2[QU800`2TQDl0XhA>0:62C00209n0BP030:21B`2QPT`0
XX==00P0YH1<0P2RODT0102QO4P0X7]70:1kA`2ONTH209iiA@80X7]70`2ONTH309iiA@0309iiA02O
NTD0XGa70080XWe800<0XGa709mjA@2NND@00P2NNDD0102ONTH0X7]70:1kA`2QO4P20:9mB@<0X7Y;
:oooool002[ooooo0`2EJCP309IZ>@80Uf/j0P2EJC`309IZ?@<0Uf/n0P2JKT40102IKD00V6`o09M[
?P2FJSd209EY?0@0VFdl102HK3/309Y^?@80Vfln0`2LL3l00`2HK3l0VFe009]_@P0209a`@`0309]_
@P2IKD00V6`o0080Uf/n0P2HK3l01@2IKD00VVi109Y^@@2JKT40V6]10080VFa200d0VVe309a_A@2M
L4H0WG1609iaA`2PJd<0X6e209m^@`2OL480W79009Yb?P2GLS/0UG8j00T0Vg0m0`2MLSl309ic@080
WgA10`2RLT420:=c@P<0Y7A300D0WG8o09ic@02NLd00WgA10:5f@`020:9gA0060:=hA@2QMD@0XGE4
0:5eA02RMTD0XgM60`2TN4L30:9gA0<0XgQ50P2TNDH00`2UNT<0Y7U20:9g@P020:5f@`030:9fA@2T
N4T0YGU:0100YW]800P0ZGi;0:QmBP2VNdP0YGY70:AiAP2UNTL0Yga90:QmBPP0Y7]700<0XgY60:Ak
A`2UO4P00P2UO4P0102SNTH0XGQ409mf@P2OMD<409id@P<0WG=10`2KLCl209Y`?P<0VFlm00P0UFTj
09=X>`2AIST0SfHj08aU>P2<Icd0RfQ008aY@@<0RV@g0P29HcH308QR=@0508MR=P25H3@0PUda07mJ
;P1mF2`00`1lEb/01@1mERl0O5D^07aE;P1kE2d0NU</0080NE8[00L0N54Z07M@:@1gCb/0MThZ07I>
:`1eC2`0M4/]0080LdX^101/BbP506e<:@0406e?;@1[CB/0JD/Y06M99`<0ITPV00D0IdTW06]::@1[
BRT0JdXY06Y9:00206U89`80J4LV00D0H4LY0658:P1RAbT0IDPX06M99`0206Y99P0906]9901ZC2H0
K4`V06i>:01`CRT0Ldl[07I@;01hD2d0NE4^0080N5<Y00H0NE@Z07YE:`1lEbd0OEP^07iI;`1oFS02
07mJ;@80P5/^0`21G2l01P22GC00QEhc08EN<`25Gc80QV0a08IP;`80Qf8^00@0Qf8]08QR<`28HS<0
R68c0P27HC8308IP<@80SV<f00L0SF8e08aQ=02;H3<0RUlb08UN<@28GC00R68a0080Qf4`0P26H2l2
08EO;P0908AN;@24HS@0QF<e08QS=P29HcH0RV4e08YO=028GC80QeX`0080RUld102;H3D208aQ=PP0
Qf4b00<0RF<f08QR=@27HC@00P26H3<00`28HSD0RV@g08]U>00808US=00<08YT<`29Hc80R68c08MQ
=028HCH0RF8i08]T>`2=ISl0RfTi08YX>027ICD0QF<c0P24HS800`25Hc<0QV@d08UT=`0208UT=`80
R6<f0`27HSD308US=0<0R68c0`27HC802P29I2l0R6<_08MR;P26H2l0QV0a08QR=@2:HcP0Rf@i08YT
=@29Hc@308QR<`0308US=02;ICH0S6Hg00P0RV@e0P29H3801027HC80QV8b08IR<P24HS8208=S<P08
08UV<028I300R6@`08MS<@25HC40Q5lb08AO<`23GS8308MR=@80QV4d0`25H3<00`28HcH0Qf8e08MR
=@0208IQ=080QF0c00<0Q5lb08EP<`25H3<01P25H3<3089M<0<0PE`_0P20Fbh00`20GC<0Oe`b07eJ
<00307]H;P0307eJ<01nFc40OU`^00L0OU`^201nFc4807]H;P80NUL]0`1iER`307QE:`80N5Pa00<0
MeL`07IF;`1eEBh00P1dE2d0101cDb`0KU0/06mA;@1aDbl2079D<003075C;`1`DRh0Ke4]00@0JU<Z
00X0J54X06E>9@1RBb80H4TP06E8:P1RAbT0HDHX05m69`1LABD0FDDT0P1GA2<205Hm9`0505<m9P1@
?2@0CC/S04Xj8@19>B000P17>Al01P18?2@0Ac/S04Hj8P15>B40A3PP04<g7`80@SHN2012=b<303lg
8P<0?SHQ0P0m=B000`0o=b80?SHQ03`d7`0203/c7P0603`d7`0n=R40?cLR04<h9012=b<0@3DQ0`0o
=202040e8@P0?c8O200n=R4203hg7@80?cPN1010>Al803lh7PP0?SHQ0`0o>1h203hg7@<0?CHL200m
=B0203Td7P<0>SDO0`0k=R00100h<ad0>C@N03Td7P0i=1h203Xe7`80>cHP00@0?3LQ03/f800k=R00
>cHP100j=Al00`0n=R40?CDP03`d7`0203/c7P0303`d7`0m=B00?SHQ00H0@3HM0P0o=A`3048i70<0
@CPK0P10=aX204Dg7080ASPM0`17>Ah00`18>Ql0BC/Q04Tk8@0704Tk8@P0Ac/Q00P0CChQ04`m801;
?1l0BS/N04/l7`1<?B00CSlR04m08`80E44Q0P1C@203058o7`07054n7P1<>b40CC`R04hm8`1??R@0
DD0V05919`0205=2:0<0CChO0P1>?b0304m08@0305=07`1D@B00ET<R0080ET<R00@0ED8Q05=07`1A
?Qd0DClW0P1B@BL00`1C@RH0E4<U05E5900205I6900305U5901G@b80ET8Q0080ED4P00L0ET8Q05M3
8P1IAB@0Cd4L05537P1CAB00ETPS0080EdTT00<0ETPS05E78P1EAB@03`1EAB@205I39@<0ED8T0`1D
@B<00`1A@R<0D44R04m08@0204ho800904m08@1@@B80DD8S04dl7P1>?Al0CchP050o8@1A@280DT4S
0080Dd8T00<0EChO05Ho801H@B800`1J@b@01@1I@R<0F44R05m9901NB2<0GDLR0080G4HQ00d0GTPS
05m9901PBRD0J4`W06I:9@1TB2<0HdLR06A88`1WBbH0JThY06a@:`1cE2P0LU<W0080LE8V00D0LU<W
07AE:@1fEb/0N5T]07YH:P0207]I:`0307aJ;01nG2h0Oed_00<0P5h`01H0Oed]089P<025I340Q6<^
085P:P20H2L0Q6@[08QX;@29JCP0R6Pg08QV=P2:ISH0RfLg08iX>@2BJC/0TfXl091/>02AKCT0TVhj
09=_>`2DL3`0UG4m0P2FLSh409Ue@@@0V7A00P2KMd<209ahA0@0WGU50P2PNdL0102QO4P0XWe90:=n
BP2SOTX20:AoB`80YH1;00@0YX5<0:N2C@2XPdh0Z8=>0P2YQ4l01P2XPdh0ZHA?0:V4C`2ZQE00ZhIA
0:b7DP80[HQC0P2[QU820:b7D`80[HQD0P2^RED01P2^ReD0[XYF0:n;E`2_ReT0[h]K0;2;GP80/8]O
00P0/H]L0;2:F`2_REX0[XQI0:n9FP2`RU/0/XaM0;B>G`80[XYJ0`2_Re/30;2<G0P0/H]L202_Re/2
0:n:GP030:n:G@2_Re/0[h]I0080[h]G00<0[haF0;>>FP2cSUX00P2bSET0102aS5P0/8]G0;2;E`2`
ReL80;6;G0<0[XYF0P2]RED30:b8E0T0[HUI202`S5`20;:=F@030;6<F02`ReL0[hYF0080[XUE00X0
[HQD0:j9E02^RE@0[hYE0;2;EP2_RUD0[XUD0:b7DP2ZQE00/8]G0`2_RUH20:j9E@80[HQD00<0[hUJ
0:j8F@2/QUL00P2/QUL0102^R5T0[hUJ0;6;G02aS5P20;2;E`80[hYF0P2^RED00`2]R5@0[XUB0:j9
DP020:f8D@80[8M@0P2[QTl01P2]QeX0[HMH0:f7F02]QeH0[HQD0:f8D`80[HQA202]R5@80:j9E@<0
[hYF0P2`ReL30;6<F00@0:n:GP2^REd0[8MK0:Z5F@2YQ5P0ZXEI0:^6FP2/Qe/0[XQK0:n9FP2`RU/0
/H]J0;2;E`2_RUD0[HQA0:b7D0P0[HMH0P2]R5420:b7D00<0:^6C`2ZQDh0ZXE>0:V4C@2ZQ5L0ZhEF
0:f7F02^R5L0[XUE0:f8D`2/Qe00ZhI?0P2^RED20:f8E080[8MC0P2[QU820:^6D@H0ZXE@00<0Z8=?
0:V4D02[QU800`2/Qe<00`2[QU80ZXEA0:V4D0020:^7C@040:^6C`2ZQE40ZXAC0:V3EP80ZH9G1P2]
R5@20:b7D`80[HA>00T0[HA@0:j4DP2_QED0[hAG0;25F02`QEX0/8ID0:n5D`2]Pe400P2[PDl00`2/
PU00[H=A0:j4DP020:V4D080ZXEA0P2[QU820:b7D`P0[H=A00<0Yh5B0:R2D`2ZQ5D00P2/QUL00`2[
QEH0ZXAE0:V3E0080:^6DPP0ZhIA00P0ZhM=0:b8CP2]R540[XUD0:f8D`2/Qe<0ZXAC0:V3DP80ZXEA
0`2[QU830:b7D`030:^6DP2/Qe<0[HQD0080[XUE00/0[HQD0:b7D`2[QU80ZhIA0:Z5D02YQ4l0Z8=>
0:V4C`2ZQE00[8MB0:f8D`020:Z5D@040:^6DP2/Qe<0[HQD0:j9E@80[hYF0P2^Qe`00`2^R5/0[XQI
0:j8E`020:j9E@030:j9E02]R5@0[HQD00<0[XUE0`2_RUH20:f8E0H0[XUE00<0[8MC0:f8E02]R5@0
0P2^RED20:n:EP050;2;E`2/QUD0[8IE0:b7D`2/Qe800P2]R5<00`2]R540[HU?0:f9C`030:j8E`D0
[hUH0`2aQeD00`2`QU@0[hEC0:n5D`020:j4DP080;2;E`2^RED0[8MC0:^6DP2ZQE40ZhIB0:b7D`2]
R5@20:n:EP<0[XUE0`2]R5@20:^6DP80[8MC0P2]R5@20:j9E@040;6<F02`ReL0/8]G0:n:EP80[XUE
0P2]R5@80:n:EP030:j9E@2]R5@0[8MC0080ZhIB00@0[8MC0:j9E@2_RUH0[XAB0P2_QE<20;26E080
/HME00<0/XQF0;27D`2`Qe<01P2`Qe<80:b7D0030:j4DP2_QE<0/8ID0080/HME00<0/8ID0:n5D`2^
Q580202`Qe480:j9E@@0[8MC102]R5@20:n:EP80[XUE0`2]R5@00`2/Qe<0ZhEF0:^5EP050:^5EP03
0:Z4E@2^RE@0[XUD00H0[XUD2@2]R5@00`2ZQE40ZhIB0:f8E0020:n:EP030:j9E@2]R5@0[8MC0080
[XUE0P2]R5@20:b7D`80ZhIB0`2/R5@30:f9E@80[XYF0P2^RE800`2^RE@0[XUE0:j8E`020:j8F@0<
0:j8F`2`S5`0[XYJ0:b8F02[QeL0ZXIF0:^7E`2/R5P0[HUI0:b6E`2]QeP0[XQI0P2_REX01P2^R5T0
[HMH0:b6E`2YQ500ZXEA0:b7D`80[HQD00<0[8MC0:Z5D@2YQ500202[QEH80:b7D`<0ZhIB0`2ZQE42
0:V4D080ZhYE0P2ZRE@0102YR5<0Z8MB0:R7DP2XQe820:V3E0<0ZXAE0`2[QEH00`2/Qe<0ZhIB0:^6
DP020:Z5D@80ZHA@00H0Z8=?0;27D`2_QU80[hIB0:j5D@2/Pdl20:^2CP030:Z1C@2YPe@0ZH=D00<0
ZXAE0`2[QEH80:Z5D@040:R3CP2WPTd0Yh9=0:N2C@80YX5<0P2UP4/80:F1C@030:^6D@2ZQE00Z8=>
0080Yh9=00@0Z8=>0:Z5D02ZQE00ZhIA0P2VPDd20:N2CP80Z8=?0P2YQ5080:F0B`<0Z8=?0`2YQ502
0:Z5D@030:B5C`2SQ4h0XH9<0080Wh1:00<0X85;0:62C02RPdd0202UP4`20:9mB@80XGa800@0X7]7
09mjAP2ONTH0WgY60`2PNdL209mjAP@0WWU500L0WgY60:5lB02RODT0XWe90:5lB02ONTH0WWU500<0
WgY600<0X7]70:5lB02QO4P00P2RODT30:1jBb_ooooo000Zooooo`80TfLf0`2DJ3L309EY>080UFTl
0`2FJSd309M[?P0509Y^@@2IKD00VFe009Q/?`2GJch00P2FJSd00`2EJC`0V6`k09Q/>`0609Q/>`04
09U]?02JKSd0VVhm09Y^?@80Vfln0P2LL3l209U]@0@0Vfm20P2IKD0309Q/?`<0VFe00P2JKT401P2H
Jd40VFa209U/@P2JKD<0Vfi409a_A@80WG1600P0Wf]309i]@P2PKd@0X75309ib@@2LLcl0VG8k09Qa
>PT0W74n0`2MLSl309ic@080WgA100@0XG500:9b@@2RLT40XW910P2SLd820:Ad@`0609eb?`2NLd00
WW=009md@@2PMD80XGI30P2RMd@209mc@P040:1d@`2RMTD0XgM60:AhA`80YGU80`2RMd@30:=hA@80
Y7U600<0YGY30:Ai@P2SN4<00P2RMd@00`2SMdH0Y7Q90:EiBP080:MlB@P0YW]800<0Z7e:0:MlB@2V
NdP00P2UNTL00`2VNdP0Yga90:QmBP080:ElB080XgY60`2TNdL00`2SNTH0XWU50:5hA00209me@`80
WWA20P2MLd4209ab@0<0VW0n0P2IKcd309Q^?00909M[?02DJSX0TVLj08mV>P2<ICX0RVDk08QU>`29
ISh0RV@g00<0RF<f0P28HSD208MQ=00408IQ=`24GcD0PE`b07iI;`@0O5L]101jE2d407UC;00607I@
:@1eCbX0MDlZ07A>:P1cC2/0LT//0P1aBRd206Y99P0306]:9`1/BbP0KD`Y0080KD`Y0P1^CBX01@1/
CR`0JT`Z06Q::01VB2H0IDLU0080ITPV00@0IdTW06U89`1YB2L0JDPW0`1XAbH206M69@060658:@1R
AbT0HdTX06I99`1XBRP0JdXW0P1]BbH01P1[CRH0KThW06m?:01aCbT0M54[07MA;080NE4]00P0N5<Y
07UD:P1jEB/0NeH/07eH;P1nFBl0OeX`081K<@80P5/^0P21G2l3089M<00608=N<@25GS<0QEhc08IP
<`26H340Qf4`0P27HRh01028Hbh0R68c08QR<`28HS<208MQ<P<0QV0a00H0SV<f08eR=@2=HSD0S64d
08]P<`2:Gc8208UN<@@0Qf4b0P26H34208EO<00808ES=@26I3H0RF@g08US=P2:HCD0REhc08IK<026
FBl208UN<`80RUld00@0Rf0e08aQ=P2<HCH0SF8g2027HC800`28HSD0Qf4d08IP<`0208IP<`0308QR
=@29HcH0RfDh00P0RF<d0P29Hc802P28HS<0Qf4d08QQ=P29HST0RV<j08]T?@2<J3P0RfLg08UU=@28
I3@408MS<`80R6<f0P27HSD208IQ=080QF0c0`29Hc@308QR<`<0Qf4b00/0Qf8]08MR;P27HRh0Qf4`
08MQ<P29HcH0Rf@i08aU>P2<ISL0RfDf08US=00308QR<`0308US=02:I3D0RV@e00L0RV@e0P29H380
1027HC80QV8b08IR<P24HS8208=S<P0608QU;`28I300Qf<_08IR<026HS80QF0c0P24Gc<308MR=@80
QV4d0`25H3<308MR=@80QV4d2`25H3<208=N<@80PUd`0`21G2l01@20Fbh0P5dc07mL<P1nFc40OEX`
0080O5T_00<0OEX`07iK<@1nG2h01`1nG2h807eJ<0P0NeP^0P1jEbd307UF;0<0N5D[0P1fERl00`1e
EBh0M5@]07=C;002079B:`04075A:P1^D2`0Ke4]071B;P80LE<_00<0L58^06i@;01]Cb/00P1YDB/0
1P1XD2X0IdlY06E=9`1SBbD0HDTS05m78@80HDHY00`0GdHX05a59P1IA2D0ET<S05E28P1C@b80DcdV
058l9@1@?2@0CC/S04`j8P19>B0304Li7`0604Lk8`16>R80ASXR04Di8@14>200@cLO0P12=Qh2048g
8`80@CHR00@0@3DQ03ld800n<al0?S<O0`0o=b8303hf8@80?CDP00<0?cLR03hf8@0m=B000P0l=1l0
100m=B00?SHQ03lg8P10=B42044f8P05048g8`11=R80@3DQ03ld800n<al02010=B4803hf8@<0?SLM
0P0o>1h3040i7`P0?cPN200n=R4203lh7P80?SLM0`0m=Q`00`0l=A/0?3@O03`d7`0603`d7`@0>C@N
0`0h<ad0100g<Q`0>3<M03Pc7@0h<ad203Td7P<0>SDO0`0i=1h303Xe7`80>cHP00<0?SHQ03de800k
<ah00P0j<Qd00`0k<ah0?CDP03hf8@0803le700403le6P10=Q/0@3HK040f6`@0@CLL0P12=Q`204<g
7@<0A3PN00@0ACTO04@h7P14>1h0A3PN0P15>Al00`16>R00Ac/Q04Pl8P0904Pl8P0804`l8P1;>b40
BSXP04Ti7`1:>R00Bc/Q04dm8`1>?R@3050o8@80CchP0`1>?Al00`1=?280CSdS04hm8`0204ln90<0
D3lU0`1<?Ah204dn7`<0CSlP00D0CclN05107`1A@B00DT8Q05=38P0205928@070551801@?RH0DD0V
05509P1B@BD0Dd8T05A48`0205E58`0305I38`1E@R80E44Q0080Dd0P00L0E44Q05E28P1F@b<0CClJ
04i06`1@@Qd0DD<N00<0DT@O00<0DD<N05A48`1DA2<01P1DA2<805I69@0405I39@1E@R@0ED8T05E2
9080E44S0P1C@2800`1A@R<0D44R04m08@0204ho800304m08@1@@B80DD8S0080CSdO0P1??R00201@
?b40DD0R05918`1B@B<0E3dN05Ho801H@B80Fd@U0P1LABH205]49@0805i88`1MAb80G4HQ05]5801L
AR40GDLR05m9901PBRD206A88`0806E9901VBRD0Id/V06M;9P1XC2L0JDdX071C:@1_DRP206iA9`05
06mB:01aE2X0LeH/07EH;P1kFB/00P1lFR`05`1nG2h0Oed_07mM;`1nG2h0O5X/07]I:`20GS00PV0`
08=Q<@20Gb`0OE`W07aK9@20H2L0QFD/08QX=`27IcH0R6Hf08YV=P2;IcL0SVPi095X>P2BJC/0T6`h
0080TFdi00<0TVhj09=_>`2DL3`00P2ELCd809Qd@0<0VgM30P2LN4@309eiA@80WgY600<0X7]70:5l
B02RODT00P2SOTX01P2TOd/0Y7m:0:AoBP2UP4/0YX5<0:N2C@80Z8=>00H0ZHA?0:R3CP2XPdh0ZHA?
0:Z5D02[QU420:b7DP030:f8D`2[QU80ZhIB0080[8MC0P2]R5@20:j9E@060:j;E@2^RUH0[h]G0:n;
F@2_Re/0/8]N0P2`Rel20;2:F`<0[hUJ00<0/8YK0;:<G@2cSEh00P2^RUX30:n;F`<0/8aL202aRe`8
0:n;F`80[hYN00<0[hYM0:n;F`2_ReT00P2_ReL0102_S5H0/XeI0;:=F@2bSET20;6<F0<0/8]G202`
RU/0102_ReL0[XYF0:j:EP2^RUH20:f9E@80[8QD2@2_Re/80;2<G0060;6<F02`ReL0/8]G0:n:EP2^
RED0[HQD0P2/Qe<02@2]R5<0[XUD0:n:E@2`ReH0[hYE0:j9E02/Qe80ZhIA0;:=F@030;6<F080/8]G
0P2_RUH00`2aRe`0[hUJ0:j8F@030:b6E`030:j8F@2_REX0/8]G0080/8]G0P2_RUH30:j9E@80[XUD
0P2]R5<20:b7DP80ZhIA00H0[HMJ0:f7F02]QeP0[HMF0:f8E02]R5<20:f8D@P0[HQD2@2^RED30:n:
EP80/8]G0P2aS5P0402^RE`0[HQK0:^6F@2ZQEP0ZHAG0:Z5F02[QUT0[8MJ0:j8F`2_REX0/8YK0;2:
F@2`ReL0[XUD0:f8D@2[QTl80:f7F0060:n:E@2^RE@0[HQC0:b7DP2[QU40ZHA?0P2XPdh0202YPeH0
ZXAE0:b6E`2]QeH0[XUE0:j9E02^RE80[HQA0P2^RED20:f8E080[8MC0P2[QU830:Z5D0D0ZhIA00<0
ZHA@0:Z5D@2[QU800`2/Qe<00`2[QU80ZXEA0:V4D0020:^6C`040:^6D@2ZQE40ZXAC0:V3E080ZH=F
202^RED20:f4CP030:j5D@2^Q580[XAD0080[hAG00@0[hAI0;26E02_QE<0[H=A0P2[PDl00`2/PU00
[H=A0:j4DP030:^6DP80[8MC0`2]R5@80:f3D@030:N1DP2XPU<0ZXAE0080[8IG00<0ZhEF0:Z4E@2Y
Pe@0202[QU880:^6D@030:f9C`2^RU00[hYC0080[hYE00<0[HQD0:^5E02ZQ5<00P2ZQE430:^6DP<0
[8MC00<0ZhIB0:b7D`2]R5@00P2^RED01@2]R5@0[8MC0:^6DP2[QU40ZXE@0080ZHA?00@0ZXE@0:^6
D@2/Qe80[HQC0P2ZQE40102[QU80[8MC0:f8E02^RED20:n:EP80[XML00<0[XQK0:j8F@2^R5L00P2^
RED0102^RE@0[hYF0:n:EP2_RUH30;2;E`80/HaH202^RED20:f8E080[XUE102_RUH20:f7EP050:f8
E02]R5<0[8MB0:b7DP2/Qe000P2/R4h01@2/Qe<0[HQD0:f8E02^RED0[hYF00<0/8]G0`2aQeD20;26
E0<0[hEC00P0/8]G0:j9E@2/Qe<0ZhIB0:Z5D@2[QU80[8MC0:f8E080[hYF0`2^RED30:f8E080ZhIB
0P2/Qe<20:f8E080[XUE1@2_RUH00`2^RED0[HQD0:f8E0080:f8E0030:n:EP2^RED0[8MC0080ZhIB
00@0[8MC0:j9E@2_RUH0/8ID0`2aQeD30;:8EP030;>9E`2`Qe<0/8MC00H0/8MC202^RE@00`2^Q580
[hEC0;26E0020;67E@030;26E02_QE<0[XAB00P0/8MC202]R5@01@2ZQE40ZhIB0:^6DP2/Qe<0[HQD
0080[XUE00@0[hYF0:j9E@2^RED0[XUE0P2]R5@30:b7D`80ZhEF0P2ZQ5D0102YPe@0Z89C0:N1DP2W
PE880:f8D`T0[hYF00L0ZhIB0:f8E02_RUH0/8]G0;6<F02`ReL0[hYF00<0[XUE0P2]R5@20:b7D`80
ZhIB0`2/R5@30:f9E@80[XYF0P2]R5400`2]R5<0[HQD0:f7EP020:f7F0040:f7FP2_Re/0[XYJ0:b8
F0<0ZhMG0P2/R5P00`2/QUL0[HMH0:j8F@030:j8F@050:f7F02/QUL0ZXEA0:^6DP2/Qe<00P2]R5@0
0`2/Qe<0ZhIB0:Z5D@080:^5EPX0[8MC0P2[QU830:Z5D@040:V4D02/R5@0[8QD0:b8E080ZhMC0`2Z
QU80102/QUL0ZhEF0:^5EP2[QEH40:Z4E@<0ZhIB0P2ZQE430:V4D080[hIB00@0[XEA0:f4D02]Q500
[8=?0P2[PTh0102YPe@0ZXAE0:Z4E@2ZQ5D20:^5EP80[8IG202YQ5030:R3CP80Yh9=0`2VPD`80:J2
CP030:Z5D02YQ4l0Z8=>0080Yh9=00@0Z8=>0:V4C`2YQ4l0ZXE@0P2VPDd20:N2CP80Z8=?0P2YQ508
0:J1C080ZXEA0`2YQ5030:R3C`030:F4C`2TPdh0XX5<0080X7m:00<0XH1;0::1C02SPTd0202UP4`0
102RODT0XGa80:5lB02QO4P30:1kA`0309mjAP2QO4P0X7]70080X7]70P2ONTH209iiA@0309mjAP2P
NdL0XGa80080XWe900@0XGa80:1kA`2ONTH0WgY60`2PNdL30:5lB0040:9mB@2PNT/0X7Y;0:1jBb_o
oooo000Zooooo`80TVHe0`2CIcH309AX=`80UFTl0`2FJSd309M[?P80VFe00P2HK3l209M[?P80UVXm
0`2GJc`409Q/?@0309U]?P2IKC`0VFdl00<0VVhm0`2KKch809Y^@@80V6`o1P2IKD0309U/@P0309Y]
@`2KKT@0Vfi40080W6m500P0W6e309i_@`2OL4@0WW9309ib@@2MLSl0Vg8l09U`>P`0WG8o0`2NLd02
09md@@80XG500`2RLT430:=c@P<0WW=000<0WgA10:1e@P2PMD800P2QMT<209ib@@060:1d@`2QMD@0
XgM60:AhA`2UNDP0YWY90`2RMd@30:=hA@80Y7U60P2TND80102TND@0XgQ50:=hA@2TN4L20:AhB@P0
Yga93@2VNdP20:MlB@030:QmBP2VODT0YWe900H0YWe90`2SNTH00`2TNdL0XgY60:=jAP020:9iA@80
WgE300@0WWA209ec@@2MLd40W7900P2KLCl309U_?@<0V6hl0P2GKC/02@2GJcX0UF/i09=Y>@2@IcT0
S6Hi08UT>026I3L0QF8h08US=P0308QR=@80Qf4d0P26H3<01025H3H0Pehd081K<@1nFBl307aG;@03
07eH;P1fDb/0Me@/0080Me@/0`1hEBd01`1iERh0Le0X07=@:P1bCbT0LDdY071<:P1_Bb/00P1^BB`0
1@1XAb@0JDPU06Y99P1[BRL0K4/X0080KTdZ0P1_CR/01P1[CB/0JD/Y06M99`1VB2H0IDLU06I89P80
IdTW0P1XAbH606M69@0606=8:P1UB2P0ITTW06Q::01[BRL0KT`W0P1`CBL01P1]D2H0L50W075A:01c
DRT0ME8Z07QB:`80NU</00H0NE@Z07YE:`1kER`0O5L]07iI;`1oFS02081K<@<0PUd`0`23GS4208AO
<P80QUld00H0QV0c08MQ<P27HC00Qf8^08QS;`28Hbh308QR<`80Qf4b0`26H34208eR=@80S64d00@0
Rf0c08YO<P2:Gc80RUlb1P27HC@208IP<`0808IT=P27ICL0RF@g08YT=`2:HCD0REhc08IK<025F2h2
08QM<P0308UN<`2:Gc@0Rf0e0080S64f00<0SF8g08MQ<P27HC801P27HC802028HSD0Qf4d08IP<`25
Gc80QV0c08MQ=029HcH0RV@g2029Hc@01@29Hc80R68a08QR<`28HSD0R64f0080RF8i00@0RF8k08aV
=`2;ICH0RV@e0P29Hc@308QR<`0408MR=@26HC@0QV4d08IQ=080QF0c0P24Gc8308US=0<0R68c0`27
HC801P26HB`0QV4]08MR;P27HC00R68c08YT=`80Rf@i00@0SVPi08aV=`2:I3D0R68c0P27HC800`28
HS<0RF<d08YT=@0708YT=@80RF0b00@0Qf4b08IR<P26HS80Q68b0P23Hc802028IBl0Qf<_08MS;`26
HS00QV8b08EP<`25H3@0Q5lc0`27HSD208IQ=0<0QF0c2026HC@808EP<`<0Peha0P22GC03085L;`80
P5dc00<0Oe`b07iK<@1nFc400`1nFc4807iL;PP0OEX`2P1jEbd307UF;0<0N5D[0P1dE2d00`1cDb`0
LU8[075A:P02071@:@0406m?:01]Cb/0KU0/06mA;@80L58^00<0KU0/06e?:`1[CBT00P1WCb/05@1V
CRX0I4`X069:9P1PB2@0GdLS05i68P1NA2T0GD<X05]39`1H@bH0ED8T05918`1A@280D44R054k901?
>b<0CC/S04`j8P19>B00AcTO04Di7`0204@h7P0304Hj8P15>B40ACTQ0080A3PP0P13=al02@12=Qh0
@SLS048g8`11=R80?c@P03hc7`0m<Qh0?34M03/`700303lg8P<0?SHQ0P0m=B0803hf8@0303hc7`10
=B40@SLS0080@cPT00<0@CHR03hc7`0l<Ad0200o=b8803hf8@80?CHL0P0n=ad203lh7P80@3TO200o
>1h803de80<0?SLM0`0m=Q`203`e6`P0?3@O0P0i=1h0100h<ad0=c8L03Ha6`0f<A/203D`6P<0>3<M
0`0i=1h203Xe7`80=c8L00@0>3<M03Td7P0i=1h0>SDO0P0k=R000`0m=B00?3@O03Xb7@0203Ta7004
03Xb7@0l=1l0?CDP03dc6P@0?S@K0`0o=A`01@0m<aX0?S@K03hd6`0o=A`0@3HM0080@CLN00@0@SPO
040f7@10=Qd0@3HM0P11=ah3048h7`80@3HK00L0@CLL048h7@13>Ah0A3XO04Dk8016?240AcdR00P0
B3`R00<0BS`Q04Tk8018>Ql00P17>Ah00`19>b00BcdR04`n8`0204dn8@80C3dP101;?1l404dl8P@0
CSdS0P1;?1d304`m7P<0CChO00@0C3dN04dn7`1>?b00Cd0Q0P1@@B8205528`0904lm9@1??R@0D3lU
0550901B@B<0Dd<R05=38@1DA280DT4S00H0DD0R00D0DT4S04i07@1>@1d0Cd4N05127`04055380P0
Dd<R201FARD305E29080E44S0`1C@28205118P@0Cd0Q0P1@@B8204hm7`80CchP0P1@?b4205508P04
058m7P1D?b00Ed8S05U49@<0FdHW00<0FTDV05a68@1KAB000P1JA1l0201KAB00GDLR05m9901PBRD0
GT@O06168@1SBB@0ID/V0P1VC2L0101TBRD0HdTT06iB:P1]DBT206a@:00506eA:@1_Db/0LED]079F
;P1iFBX00P1jFR/03P1lG2d0OUh_07iN;`1mGBh0Ne//07YJ:`1nG2l0PV0b08MU=`27ICD0Pf8_085P
:`22HB/0Q6<]0P26ISD01P28ISH0RVHf08]W=`2=IcP0T6Li095X>P80T6`h0P2AKCT0102BKSX0Tflk
09=_>`2CKc/309Mc?`@0V7A000<0VGE109Yf@P2JMT800P2KMd<209ahA080WGU50P2NNDD0102ONTH0
X7]70:5lB02RODT20:=nBP80Xgi900@0Y7m:0:F0B`2VPD`0Yh9=0P2XPdh20:N2C@030:R3CP2YQ4l0
ZXE@0080ZhIA00<0[8MB0:^6DP2[QU800P2/Qe<20:f8E080[XUE00H0[X]E0:j:EP2_ReL0[h]I0:n;
F`2`Reh20;2;G`H0/8YK0P2aRe`20:j:FP<0[h]K0`2`S5`80;6;G0P0[h]K0P2_RUh00`2_RUd0[h]K
0:n;F@020:n;E`030:n<EP2aS5P0/HaH0080/HaH102`ReL80:j8F@80[h]G0`2^RUH30:f9E@T0/HeM
202`S5`01P2`ReL0[hYF0:n:EP2^RED0[HQD0:b7D`80ZhIB00P0[8MB0:f8D`2_RUD0/8]F0:n:E@2^
RE@0[HQC0:b7DP<0/hiJ0P2bSET30;6<F0030;:<G@2`RU/0[XQI00<0[8IG0P2]QeP80:n:EP80[XUE
0P2]R5@20:b7D`80ZhIB00H0[HMJ0:f7F02]QeP0[HMF0:f8E02]R5<20:f8D@P0[HQD2P2^RED30:n:
EP<0/8]G00<0[XYJ0:f9F@2[QeL00P2ZQUH02`2[QeL0[8QH0:f9F@2]QeX0[XQI0:n9FP2`RUT0/8]G
0:j9E02/Qe00ZhI?00P0[HMF0P2_RUH03P2]R5@0[8MC0:Z5D@2YQ500Z8=?0:N2CP2YPeH0ZH=D0:^5
EP2/QUD0[XUE0:n:E@2_RU<0/8]D0P2^RED20:f8E080[8MC0P2[QU820:Z5D0@0ZhIA0P2/Qe800`2[
QU80[8MC0:b7D`020:b7D`80ZhIB0P2ZQE401@2[QU40ZhIB0:^6DP2ZQE40ZXAC00<0ZH=B102^RED4
0:n:EP80[XE?00T0[XEA0:j4DP2^Q5@0[X=F0:n4E`2_Q5T0/8ID0:n5D`2]Pe400P2[PDl00`2/PU00
[H=A0:j4DP030:b7D`80[HQD0`2^RED80:f3D@030:N1D02XPU40ZXAC0080[8IE00<0ZhED0:Z4D`2Y
Pe80202[QU880:^6D@030:j:D02_Re40/8]D0080/8]F00<0[XUE0:f7EP2[QE@00P2ZQE430:^6DP<0
[8MC00<0ZhIB0:b7D`2]R5@00P2^RED00`2]R5@0[8MC0:^6DP040:Z5D0040:^6D@2/Qe80[8MB0:f8
D`80ZXEA00@0ZhIB0:b7D`2]R5@0[XUE0P2_RUH20:j7G0030:j8F`2^R5T0[XQG0080[XUE00@0[XUD
0;2;E`2`ReL0/8]G0`2aS5P20;:=F@030:n:EP2^RED0[XUE0080[XUE0`2]R5@20:j9E@H0[hYF00@0
[hUH0:j8E`2^RED0[HQC0P2/Qe801@2[QTl0ZhM=0:Z6C02[QU40[8MB0080[HQC0P2_RUD00`2`ReH0
/HaG0;67E@030;67E@@0/8ID00P0/8]G0:j9E@2/Qe<0ZhIB0:Z5D@2[QU80[8MC0:f8E080[hYF0`2^
RED30:f8E080ZhIB0P2/Qe<20:f8E080[XUE00<0[HQD0:j9E@2_RUH00P2_RUH00`2^RED0[HQD0:b7
D`080:b7D`030;2;E`2_RUH0[HQD00<0[8MC0P2^RED40;:8EP@0/hUG202_QU880:n:EP030:j4DP2_
QE<0/8ID0080/HME00<0/8ID0:n5D`2^Q580202`QU@80:f8E0080:V4D02ZQE40ZhIB0:b7D`2]R5@0
[XUE0:n:EP2`ReL20:j9E@<0[HQD0`2/Qe<01P2/QUD0ZhED0:Z4D`2YPe80Z89A0:J0C`80YGm>202]
R5<90;2;E`080:f8E02^RED0/8]G0;6<F02bSET0/HaH0;2;E`2_RUH20:j9E@80[HQD0P2/Qe<20:^6
DP<0[8QD0`2]RED20:j:EP80[HQA00<0[HQC0:f8E02]QeH00P2]QeP00`2]QeX0[HUI0:f9F@020:b8
F0@0ZhMG00<0[8IE0:f7EP2]QeH0102]QeH0102/QUD0ZhIB0:^6DP2[QU820:b7D`<0ZhIB202[QEH;
0:b7D`80ZhIB0`2ZQE440:b7D`@0ZhIB0P2]QeP0102/QUL0ZhEF0:^5EP2ZQ5D20:V3E0P0ZXEA00<0
[hIB0:j5D@2^QE400P2]Q5020:b3C`040:^2CP2ZQ5D0ZXAE0:Z4E@80ZhEF0`2/QUL80:V4D0<0Z8=>
0`2WPTd20:J1C0P0YX9>0`2YQ4l20:R3CP@0ZHA?0P2VPDd20:N2CP80Z8=?0P2YQ5080:N2C@80ZhIB
00<0ZXEA0:V4D02XPdl00P2WPTh0102VPDd0Yh=?0:J2CP2TP4`20:9nBP030:=oB`2TP4`0YH5=00P0
YH1<2P2QO4P30:1kA`<0WgY600<0WgU80:1jB@2RO4/00P2SOD`00`2RO4/0X7Y909miB0080:5lB0<0
X7Y;:oooool002[ooooo0P2BISD309=W=P<0U6Pg0P2EJC`309IZ?@<0Uf/n102HK3l409M[?P<0UVXm
00<0Uf/n09Q/?`2HK3l00P2IKD0309U]?0<0VVhm0P2KKch809Y^@@H0VFe00P2HK3l309U/@P@0VVe3
00T0Vfi409Y_A02KL4<0WG5409mcA02OLd80Wg4o09i`?02MKc/0302MLSl309ic@080WgA10`2QLD03
0:9b@@80Xg=20`2NLd0409md@@070:1e@P2NLT40Wg=20:1d@`2QMD@0XWI50:=gAP020:AhA`<0XWM4
0`2SN4D20:AiAP80Y7U200@0Y7U40:EjA`2UNTL0Y7Q70P2TN4T80:MlB@P0YGY700<0Y7U60:EjA`2V
NdP00P2WO4T30:QmBPP0YWe90`2SNTH00`2RNDD0XgY60:=jAP020:AkA`80WgE300@0WWA209ec@@2L
LT00Vg4o0P2JL3h409Q^?080Ufdk0P2FK3X0202GK3T0UF`h09AZ>02AJCP0S6Hg08UT=`24HS@0Pf4d
0P28HSD208MQ=0<0QV0c00D0QElb08=M=P22G3D0OeTb07eG<00307aF;`0307eG<01eE2/0MUD/0080
MUD/0`1gERd01`1hEbh0LE0W075?:@1`CRP0KddX06i<:@1]BRX00P1/BB/206Q7900306U89@1[BRL0
K4/X0080KD`Y00D0KTdZ06m>:`1YBbT0J4XX06I89P0206E79@0306I89P1WBBL0J4XX00H0IdHU0P1X
AbH01P1UB2P0IdTW06Q::01[BRL0KT`W075>:080M4hW00h0L5<W079C9`1cE2P0M5<X07IC:@1iE2X0
NU<Z07]D:`1jEB/0NeH/07aG;@1mF2h0OUT_081K<@80PE`b0P23GS4308AO<P<0QF0c0P26Gc@00`27
HC@0Qf4b08MQ<00208QS;`0408QS;P28HS<0R68c08QR<`80Qf4b0`26H34308aQ=0@0Rf0c00<0RUlb
08MP=@27H3D01027H3D208QQ=P0808ES=@26I3H0R6<f08US=P2:HCD0REhc08ML<@26FBl208QM<P80
REhc00@0RUld08]P=@2;H3D0S64f2027HC800`27HC@0QV0c08EO<P0208EO<P0308MQ=029HcH0RV@g
00P0R68c0P28HS401P28HS<0RF<f08QQ=P28HCP0Qf0g08MP>@D0S6<e0P2;HS@00`2:HC<0Qf8e08IQ
=00208IQ=080QF0c0P24Gc8308US=0<0R68c0`27HC801P26HB`0QV4]08MR;P28HS40RF<d08US=P80
RV<h00@0SVPi08aV=`2:I3D0R68c0P27HC800`28HS<0RF<d08YT=@0708YT=@80RF0b00@0Qf4b08IR
<P26HS80Q68b0P23Hc801P27I2h0Qf<_08IR;P26HS00QV8b08IQ=080QF0d0`27HSD208IQ=0<0QF0c
2026HC@808EP<`80Q5lb0P23GS42089M<080PE`_1@20GC<00`1oG380OU/a07iK<@0807iL;PP0O5T_
2P1jEbd307UF;0<0N5D[0P1cDb`00`1bDR/0LE4Z071@:@0206m?:00A06i>9`1/CRX0KDl[06i@;01_
DBd0KU0/06a>:P1ZC2P0JD/W06I>:P1UCBT0Hd/W06599@1OAb<0GTHR05e58@1LA2000P1J@RP01`1G
@RL0ED4V0550901@?b<0CSlR04`n8@1>>R800P1;>B401019>B00AcTO04@h7P13>Ah2048h7@@0A3PP
1013=al01P12=b<0@CHR040e8@0o=200?S<O03`a7@80>c0L0`0o=b8303hf8@80?CDP0P0n=R4403lg
8P80?SHQ00<0?S<O040e8@12=b<00P13>2@00`11=R80?S<O03`a7@0803hh8PP0?SHQ0`0m=Q`203hg
7@<0?cPN200n=ad803de8080?SLM0`0m=Q`303`e6`P0?3@O00D0>C@N03Pc7@0h<ad0=c8L03Ha6`02
03D`6P0303@_6@0g<Q`0=c8L00<0>3<M0`0i=1h203Ha6`0403Lb700h<ad0>3<M03Td7P80>SDO00<0
?3@O03/c7P0i<A`00P0h<1/00`0i<A`0>c<N03`d7`0303`b6@0303dc6P0n=1/0?S@K0080?cDL00D0
?34K03db700m<Q`0?S<M03ld7P02040e7`03044f800l=1d0?CDN0080?CDN0P0n=Ql203lg80<0?CHJ
00@0?SLK03lh7011>Qh0@S/O0P13?20904Hj800704Di7`14>1h0@cLM04@h7P15>Al0Ac/Q04Tm8`04
04Tk8080B3XO0P17>Ah804`k8@80BS/L0P1;?1d404`m7P<0BcdP00<0C3hQ04do8P1>@2<00P1?@B@0
1P1=>b<0CSdS04hm8`1??R80D3lQ05518080DT8P00<0CchR050o8`1@?b<0101@?b<00`1??R80DD8Q
05528@0305528@80DT<R00<0Dd@S05=38P1C@b801P1C@b8805I69@80ED8T0P1D@B<205=08P80DSlQ
0P1?@24405118P80Cd0Q0P1>?Al404ln8080D3lQ00@0DSlO05=0801F@b<0F4DU0P1IARH205Q59@80
FT@O0P1I@ah03@1JA1l0G4HQ05i88`1PBRD0Fd<M05i6801QBB<0I4`V06E=9`1TC2H0HTXT06188P1Z
DBT0101YD2P0101[DRX0KUD]06mF;P1fEbP207MH:@0D07UJ:`1kG2d0OEh_07mP<@20HC80PF8c07eJ
<025HcH0SV`o099`@P2?KCd0RVTf08IU<025I2l0QFDd08IV=@28ISH0RfLg08aX>02=IcP2091W>@<0
T6`h102AKCT01@2BKSX0UW8n09Ib?P2FLSh0Ug<o0080V7A00P2IMD4309Yf@P80VgM30`2LN4@209eh
A00409iiA@2ONTH0X7]70:5lB080XWe90P2RODP0102SOTT0Y7m:0:F0B`2VPD`20:N2C@80YX5<00<0
Yh9=0:R3CP2YQ4l00P2ZQE000`2[QU40ZhIB0:^6DP020:b7D`80[HQD0P2^RED01P2^ReD0[XYF0:n;
E`2_ReT0[h]K0;2;GP80/8]O0P2`RU/30;6;G080/8YK00<0[hUJ0:j:FP2^RUX00`2_Re/30;2<G0P0
/8YK202_Re/20:n:GP030:n:G@2_Re/0[h]I0080[h]G00<0[haF0;2;E`2`ReL01P2`ReL80:j8F@<0
[h]G0`2^RUH20:f9E@T0/HeM202_Re/01P2`ReL0[hYF0:n:EP2^RED0[HQD0:b7D`80ZhIB00P0[8MB
0:f8D`2^RE@0[hYE0;2;EP2_RUD0[HQC0:b7DP@0/hiJ0P2bSET20;6<F0030;:<G@2`RU/0[XQI00<0
[8IG0P2]QeP80:n:EP80[XQG0P2]QeH20:b6E@80ZhED00H0[HMJ0:f7F02]QeP0[HMF0:f8E02]R5<2
0:f8D@P0[HQD2`2^RED30:n:EP80/8]G00<0[HUG0:b8EP2[QeD00P2ZQU@02`2[QeD0[HUG0:j:F02]
QeX0[XQI0:n9FP2`RUT0[hYF0:j9E02/Qe00ZXE>00P0[HQD0P2^R5L01`2]QeH0[8IE0:^5E02ZQ5<0
ZH=B0:R2D@2YPeH00P2ZQ5D00`2[QE@0[HQD0:j9E0020;2;E080[XUE0P2]R5@20:b7D`80ZhIB0P2Z
QE020:^6D@80[8MB0P2]R5<00`2^RED0[HQD0:b7D`030:^6DP<0ZXEA0`2[QE@01P2ZQ5<0ZXEA0:V4
D02YQ500ZHA?0:b7D`80[HQD0P2^RED20:n:EP060;2;E`2_QU00[hI@0:j5D@2^Q580[XAD0P2^PeH0
102^PeP0/8ID0:n5D`2]Pe420:^1C`030:b2D02]Pe40[XAB00<0[8MC0P2]R5@30:j9E@P0[H=A00<0
Yh9>0:R3C`2ZQE400P2/Qe<00`2[QU80ZXEA0:V4D0080:^6DPP0ZhIA00<0[XY@0:n;D@2`Re@00P2`
ReH00`2^RED0[HMF0:^5E0020:Z5D@<0ZhIB0`2/Qe<00`2[QU80[8MC0:f8E0020:j9E@030:f8E02/
Qe<0ZhIB0080ZXE@00<0ZhIA0:b7DP2/Qe800`2/Qe820:Z5D@040:^6DP2/Qe<0[HQD0:j9E@80[hYF
0P2^Qe`00`2^R5/0[XQI0:j8E`020:j9E@040:j9E02`ReL0/8]G0;2;E`<0/HaH0P2bSET30:n:EP03
0:j9E@2]R5@0[HQD0080[8MC0P2`ReL60:n:EP040:n9F02^R5L0[XUE0:f8D`80[8MB00<0ZhI?0:^7
C@2ZQT`00`2/Qe800`2]R5<0[XUD0:n:E@020:n:E@P0/HME00P0/8]G0:j9E@2/Qe<0ZhIB0:Z5D@2[
QU80[8MC0:f8E080[hYF0`2^RED30:f8E080ZhIB0P2/Qe<20:f8E080[XUE00<0ZhIB0:b7D`2^RED0
0P2`ReL00`2_RUH0[HQD0:b7D`080:b7D`040;6<F02`ReL0[XUE0:f8E080[8MC00<0[HQD0:j9E@2c
REL00`2cREL40;:8EPP0[XEA202`RUT00`2^Q580[hEC0;26E0020;67E@030;26E02_QE<0[XAB00P0
/8IF202/Qe<0202YQ500ZXEA0:^6DP2/Qe<0[HQD0:j9E@2_RUH0/8]G0`2]R5@30:b7D`80ZhIB00H0
[8MC0:^6DP2ZQE40ZHA@0:R3C`2VPDd20:F0C0P0[8MB2@2`ReL0202]R5@0[XUE0;2;E`2aS5P0/XeI
0;6<F02`ReL0[hYF0P2^RED20:f8E080[8MC0P2[QU830:b8E0<0[HUE0P2^RUH20:b7D0030:b7DP2/
Qe<0[8IE0080[8IG00<0[8II0:b8F02/R5P00P2/R5P20:^7E`80ZXIF00<0[HQD0:b7D`2/Qe<0102/
Qe<00`2]R5@0[8MC0:^6DP050:^6DP030:b7D`2[QEH0ZhEF00H0ZhEF202[QU820:f8E080[8MC0P2[
QU820:Z5D@P0[HEB00D0[XQI0:f7F02]QeP0[8IG0:^5EP020:Z4E@030:V3E02ZQE40ZXEA00H0ZXEA
0P2^QE440:f4D080[8=?0P2ZQ5D20:^5EP80[8IG0P2]QeP80:V4D080ZHA?0`2XPdh30:N2C@P0Yh=?
00<0Z8=>0:V4C`2YQ4l01@2YQ4l00`2XPdh0YX5=0:J1C@020:N2CP80Z8=?0P2YQ5080:R3CP80ZhIB
00<0ZXEA0:V4D02XPdl00P2WPTh0102VPDd0Yh=?0:J2CP2TP4`20:9nBP030:=oB`2TP4`0YH5=00P0
YH1<102QO4P40:9mB@<0XGa80`2PNdL209mjAP030:1jB`2QNd`0XWa=0080Xge>00<0XWa=0:5kC02P
NT/0102RODT40:5lB0<0X7Y;:oooool002[ooooo0P2CIcH309AX=`<0UFTh0P2EJC`309IZ?@<0Uf/n
102HK3l409M[?P80UFPn0P2FJCl0102GJT00V6]109U/@P2IK48209Q/>`80VFdl0`2JKSd00`2KKch0
Vfm209]_@P0409U]@080Vfm20P2JKT4309U]@0<0V6`o202IK480202IL4@0VW5309ebA@2OLd@0XG=2
0:5a@02OL3`0X6hk2@2LLCh309eb?`<0WW=00P2OM4420:1`?`80XG500`2RLT400`2SLd80WW=009ic
@00609ic@0<0X7A30`2QMD@20:9fA@<0XWM40`2SN4D20:AiAP030:=h@@2TND80YGY50080YW]800<0
YGU80:AhB@2SMdP0402UNTL0102SN4D0Y7U60:IkB02WO4T40:QmBPP0YGa80P2SNTH30:9iA@090:=j
AP2TNdL0YGa80:1fA02OMD<0WWA209ec@@2KLCl0VW0n0080VFlm00@0V6hl09M]>`2GKC/0Ufdk0P2F
K3X209E[>@0809EZ=@2DJcD0TfXf095Y=P2=IcH0RFDe08AR<P23HC<208MQ=080QV0c0`25Gc801@24
GS40PU`g085K=P1oFC@0OELb00<0O5Ha00<0OELb07IF;@1fERd00P1fERd407EE;00806m?9P1_CbP0
KThW06e=9`1/BbP0JdXY06]::`1ZBBX206U89@80JTTV00<0JdXW06a;:01/BbP00P1]C2T0201XBRP0
IdTW06I89P1UAbD0I4HT06E79@1WBBL0J4XX0P1WARD306Q79P<0JDPW00H0IdTW06Y99P1[BRL0KT`W
075>:01dCRL207M@9`06079E:@1dEBT0M5DY07IE:P1gE2X0NUD[0P1kE2/01P1kER`0O5L]07eH;P1n
FBl0OeX`085L<P80PUdc00@0Q5lb08EP<`25H3<0QF0c0P26HC@208MR=@0808IO=027H3D0Qf4d08MQ
<P28HS40R6<_08UT<029I2l308QR<`80Qf4b0`26H34808]P<`@0Qf0g0P28HCP208UR>@0808=Q<`24
HS@0Qf8e08US=P2;HSH0RUld08QM<P28Fc4808UN<`P0Qf4b00P0Qf4d08IP<`25Gc80Q5ha08EO<P26
H3<0R68e08US=PP0R68c00/0Qf4`08QR<@29Hc@0RF<f08UR=`27H3L0QUlf08EN=`2;H3<0S64d08eR
=@0208iS=P0308eR=@2<HC@0Rf0c0080R6<f0P27HSD208IQ=080QF0c0`29Hc@308QR<`<0Qf4b00/0
Qf8]08QS;`29I300RV@c08US=029HcH0R64f08MP=@2<ISL0RfDf08US=00308QR<`0308US=02:I3D0
RV@e00L0RV@e0P29H3801027HC80QV8b08IR<P24HS8208=S<P0608IS;@26HRh0QV8^08IR<026HS80
QV4d0P26HCD308MR=@80QV4d1P25H3<208IQ=0<0Qf8e2025H3<308AO<P80Peha0`22GC002020GC<0
PEhd089O=@22GcD0PEhd081M<`1oG380OU/a201nG2h807aI;`P0NEH/0P1jEbd307UF;0<0N5D[0P1c
Db`00`1bDR/0LE4Z071@:@0206m?:00306i>9`1/CRX0K4hZ00<0KDl[00P0JddY06Q:9P1WBBD0I4`Z
06=;:@1QBBL0GTHT05a48P<0Fd<Q0P1F@2P0101D@2L0D3lU04ln901<?28204Xl8@0604Xh8018>1l0
B3PO04Hh7P14>1h0@SPM0`10>Ad804<g7`80@CHR00@0@3DQ03ld800n<al0?S<O0P0m<Qh303lg8P<0
?SHQ0P0m=B0203hf8@0403lg8P10>2<0@3PS03lg8P80?SHQ00P0@3DQ044f8P11=R80@SLS044f8P10
=B40?c@P03hc7`P0?3LQ200n=R40100l=A/0?CHL03df700m=Q`203hg7@80?cPN200n=ad803`d7`04
03hg7@0m=Q`0?CHL03df7080?3DK0P0k=1X803/c7P<0>3<M0`0g<Q`203Ha6`<0=c8L0P0h<ad303Td
7P80=S4K0`0g<Q`303Pc7@0303/c7P0j<Qd0>30K0080=blJ00<0>30K03Xb7@0k<ah00P0j<1L00`0k
<AP0?38I03dc6P0203hd6`0303le700m<Qh0?C8N0080?C8N0`0n<al0100o=200>c<N03/c7P0k<ah2
03`d7`<0?CDP100m=QX00`0n=a/0?cPL040i7@02044j7PP0A3PN00P0A3XQ04<i8012>1l0@CLN048h
7`13>B00AC/R04Hl8`<0ACTO0P14>1h304<g7@80BCPN0P1:>Al0101;>R00C3/Q04`k8@1<>b4204Tj
6`80BS/L0`1;?1d00`1<?Ah0BChR04Tn8P0304Pm8@0>04Tn8P1;@2@0Bd0T04`j8P1<>b40CC`R04hm
8@1??R00D40O05107P1A@Al0C3`R04dm8`1>?R@204lo9@0304hn901=?B<0C3`R0080DT<T00H0DD8S
05118P1@@B80DD8S0593901CA2D805928@P0E4@S0`1D@B<205=08P<0DSlQ00<0CSlP04m08@1@@B80
0P1A@R<00`1@@B80Cd0Q04ho800304hm7`D0CchP00<0D40O0551801C@b800P1EAB@0101DA2<0Dd<R
05928@1I@ah305Q27@0805U37P1LAR40GTPS061:9@1JA1d0G4HO05m98P1QBb@2069<9@04061:8`1O
BB80J50Z06M?:@80IThX00D0IdlY06UA:`1[Dbd0KED_075E9@02079F9P0F07=G9`1fFRX0Nel_089V
=P28K3`0S71008IS>`2>Jd40UW=909QfB@2CLD<0S6Xj08MV<`25I340Q6@c08EU=027ICD0RfLg08aX
>02=IcP0SfHh08iU=`P0T6`h0P2ELCd209Ib?P0309Mc?`2HM400VGE10080VGE10`2JMT8209]g@`80
W7Q400H0W7M309ehA02MN4@0WWU509mjAP2PNdL20:5lB0060:5lA`2RODP0XWe80:=nB@2TOdX0YH1;
0P2VPD`20:F0B`030:J1C02WPTd0Z8=>0080ZHA?00<0ZXE@0:^6DP2[QU800P2/Qe<20:f8E080[XUE
00H0[X]E0:j:EP2_ReL0[h]I0:n;F`2`Reh20;2;G`080;2:F`2aRe`0/H]L0;:<G@2aRe`0/8YK0:n9
FP2^R5T20:j:FP<0[h]K0`2`S5`80;2:F`P0[h]K0P2_RUh00`2_RUd0[h]K0:n;F@020:n;E`030:n<
EP2^RED0[hYF0080[hYF0`2`ReL00`2aS5P0/8YK0;2:F`060;2:F`80/8aH0P2_ReL30:j:EP030:f9
E@2aSEd0/HeM00L0/HeM202_Re/01P2aS5P0/8]G0;2;E`2_RUH0[XUE0:f8E080[8MC00P0ZhIA0:b7
DP2^RE@0[hYE0;2;EP2_RUD0[XUD0:f8D`80/hiJ0P2bSET30;6<F0040;2;E`2aRe`0[hUJ0:j8F@<0
[8IG00<0[XQI0:n9FP2^RED00P2^RED20:n:EP<0/8]G0P2^R5T20:f7F080[8IG0P2[QEH01P2]QeX0
[HMH0:f7F02]QeH0[HQD0:f8D`80[HQA202]R5@80:j9E@80[HQD0P2^RED30:n:EP0A0;2;E`2/R5@0
ZhMC0:Z6DP2YQE40ZXIB0:^7D`2]RED0[XYF0:b6F@2]QeP0[XQI0:n9F02_RUH0[HQC0:^6C`2ZQDh0
202]R5<30:b6E`<0ZhEF0P2ZQ5D0202/QUT0ZhEF0:^5EP2[QE@0[8MC0:f8D`2_RU<0/8]D0P2^RED2
0:f8E080[8MC0P2[QU820:Z5D080ZhIA00L0[8MB0:f8D`2^RE@0[XUD0;2;E`2^RED0[HQD0080ZhIB
0P2ZQE420:^6DP80ZhEH00@0ZhEF0:Z4D`2ZQE40ZHA?0P2YQ4d01P2ZQE40ZhIB0:^6DP2/Qe<0[HQD
0:j9E@80[hYF0P2_QU002@2_QU80[XAB0:j4E02^PeH0[H9E0:f2E`2`QU@0[hEC0:f3D@020:^1C`03
0:b2D02]Pe40[XAB00<0ZhIB0P2/Qe<30:f8E0P0[H=A00<0Yh9=0:R3CP2ZQE000P2/Qe800`2[QU40
ZXE@0:V4C`080:^6DPP0ZhIA00<0[HU?0:j:D02_RU<00P2_RUD00`2]R5@0ZhED0:Z4D`020:Z5D@<0
ZhIB0`2/Qe<00`2[QU80[8MC0:f8E0020:j9E@060:f8E02/Qe<0ZhIB0:V4C`2ZQE00[8MB0`2]R5<2
0:b7DP80ZXEA00@0ZhIB0:b7D`2]R5@0[XUE0P2_RUH20:j7G0030:j8F`2^R5T0[XQG0080[XUE00@0
[XUD0:n:EP2_RUH0[hYF0`2`ReL20;6<F080/8]G00<0[hYF0:j9E@2]R5@00P2/Qe<00`2[QU80/HaH
0;6<F0020;2;E`@0[hYF0P2]QeH01@2]R5@0[HQC0:b7DP2/Qe80[8M@0080[8Q>202]R540102`QU@0
/HME0;67E@2aQeD30;:8EP090;>9E`2`ReL0[XUE0:b7D`2[QU80ZXEA0:^6DP2/Qe<0[HQD0080[hYF
0`2^RED30:f8E080ZhIB0P2/Qe<20:f8E080[XUE00<0ZHA@0:^6DP2^RED00P2`ReL00`2_RUH0[HQD
0:^6DP080:f8E0040;>>FP2aS5P0[hYF0:f8E080[8MC00<0[HQD0:j9E@2cREL00`2bR5H30;67E@03
0;26E02]Q500[HA@00H0[HA@202_REX00`2^Q580[hEC0;26E0020;67E@030;26E02_QE<0[XAB00P0
/8EH202/Qe<01@2ZQE40ZhIB0:^6DP2/Qe<0[HQD0080[XUE00@0[hYF0:f8E02]R5@0[HQD0P2/Qe<3
0:^6DP80ZhIA0P2ZQE00102YQ4l0Z8=>0:N2C@2WPTd80:b7DPT0[hYF00L0ZhIB0:f8E02_RUH0/8]G
0;6<F02`ReL0[hYF00<0[XUE0P2]R5@20:b7D`80ZhIB0`2/R5@30:f9E@80[XYF0P2/Qe000`2/Qe80
[8MC0:b6E@020:b6E`030:b6F@2[QeL0ZhMG00<0[8QH00D0ZhMG0:V5E@2XQ5@0[HQC0:b7DP040:^6
D@050:b7DP2]R5<0[HQD0:b7D`2[QU800P2ZQE400`2[QU80[8MC0:f8E0080:^5EPP0ZhIB0`2]R5@2
0:b7D`<0ZhIB00@0[89@0:f3D@2]Pe40[H=A0`2^Q5800`2_QE<0[HMH0:f7F0030:b6E`<0ZhEF0`2Y
Q5020:Z5D@<0ZhIB202]Q5030:^5EP80[8IG0`2]QeP80:R3C`<0ZHA?0P2XPdh30:N2C@P0Yh=?00<0
Yh9=0:R3CP2YQ4l00P2ZQE00102YQ4l0Z8=>0:R3CP2WPTd20:J1C@80Yh9>0P2XPdl20:V4D0P0ZHA?
0P2ZQE430:V4D0@0Z8=?00L0Yh9>0:F0C02SOTX0Xgi:0:AoB`2UP4`0YX5=00P0YH1<0`2QO4P20:9m
B@<0Xgi:0P2RODT20:5lB0<0X7]700@0WgY60:1jC@2QNdh0Xge@0P2TOU400`2SOE00XG]>0:1jC@03
0:=nBP80XWe90`2QO4P30:1jBb_ooooo000Zooooo`<0UFTh0`2FJST209M[>P80UFTl0`2FJSd709M[
?P@0V6`o0P2DIch0102EJ3l0UVU009MZ@@2HJd8209U/@`<0V6`k0P2IKC`309Y^?@0309a`@`2KKd80
VFe00080V6`o00<0VFe009]_@P2LL4<00`2JKT400`2IKD00V6`o09Q/?`0209M[?PP0VFa200P0Ug95
09UcA02LLdD0WWA40:5c@P2QLD00XW0m0:9^?0T0Vg0m0`2MLSl309ic@080WgA10`2PL3l20:5a@0<0
XW91202NLd020:9fA@80XGE40P2PM4<209mc@P<0XWM40`2SN4D20:AiAP030:=h@@2TND80YW]60080
Yga900<0YWY90:AhB@2SMdP0202SN4D80:AiAP040:9gA02SN4D0YW]80:QmBP80ZGi;00<0Z7e:0:Ml
B@2TNdL01`2TNdL00`2SNTH0XWU50:5hA0020:5hA0090:=jAP2UO4P0Ygi:0:1fA02OMD<0WWA209ec
@@2KLCl0VFlm0080V6hl0P2GKC/209I/>P<0UF/i00T0U6Xh09=X<@2BJC<0TVTc095Y=@2=J3@0RVHd
08ES<`23HC400`26H3<208EO<P<0Q5ha00H0PE/g081J=P1nF3@0O5Hb07]E<@1lES8207eG<`0507QH
;`1gEbh0MeL^07IF;@1eEB`00P1dE2/01`1cDbX0KThU06i>9`1]CBH0K4`V06]:9`1[BRT00P1ZBBX4
06Y99PD0JdXW00<0IdTW06I89P1UAbD00P1TAR@00`1UAbD0IdTW06Q::00206Q79P80JDPW0180JTTX
06]::@1[BRT0JdXY06U89@1ZBBH0KD/V071=9`1dCRL0Me0W07QA:01kDBL0LeLX07EF:01fEbT0MeHY
07QF:@1kERX207aE:P80O5L]00L0OEP^07mJ<020Fc40PE`b089M<`23GS@0QF0c00<0QV4d0P27HSD2
08QS=P80Qf0e00<0Qf4d08QR<`28HS400P29I3001029I2l0R68c08QR<`28HS<208MQ<P<0QV0a1P2;
H3<208aQ=00308IO=P27H3L0Qf0g0080R64h0P29HST03@2:HcX0PEla089P<P26HC@0RF<f08]R=P2<
HCH0RUld08]N=02<HCH0Rf0e08YO=029GS<00P28GC800`27G340QU/`08MQ<P0708MQ<P0308MQ=026
H3<0QElb0080Q5ha00<0QV0c08QR=@29HcH02027HC804027HC00R68a08US=029HcH0RF8g08MP=`25
GSD0Q5df08YO<P2;H3<0SF8e08iS=P2?I3L0SV<f08aQ=02;H3<308UT=`80R6<f0`27HSD308US=0<0
R68c0`27HC802P29I2l0RVDa08YU<@2;IC@0RV@e08QR=@25GS<0Q5db08YT=@29Hc@308QR<`0308US
=02;ICH0S6Hg00P0RV@e0P29H3801027HC80QV8b08IR<P24HS8208=S<P0608IS;@26HRh0QV8^08IR
<026HS80QV4d0P26HCD308MR=@80QV4d0`25H3<00`24Gc80QF0c08EP<`0208IQ=080Qf8e00<0R6<f
08EP<`25H3<01P25H3<408AO<P80Peha0P22GC000`20GC<0PEhd08=P=P0208=P=P03085N=01oG380
OU/a00P0OU`^201kF2h807UF;080NUL]0`1iER`307QE:`80M5@]00<0Le</079B:`1aDBX00P1`D2T0
0`1_CbP0JddY06a>:P0206e?:`0906]=:@1YBbL0IdTU06E78`1SBR/0HTTZ05m69`1L@b@0FT4R0080
FD0Q00T0FT4R05@n9P1C?bH0DShU04ln901<?280BS`Q04Ll8016>al00P17=ah01@16>1h0@cLM048h
7@10>Ad0?cPL0080?STL0`12=Qh504<g7`P0@3DQ0`0o=b8303hf8@<0?CDP00X0?SHQ040h8`11>B@0
@CTT040h8`0n=R40?CDP04<h9012=b<0@3DQ0`0o=202040e8@P0>3HO200n=R4203`e6`<0?CHL0`0n
=ad803df70P0?3@O0`0m=Q`203`e6`<0>c@J200k<ah203Lb70<0>3<M0`0i=1h203Ha6`80=c8L0`0h
<ad00`0i=1h0=c8L03Lb700203Lb70<0=S4K00@0=C0J03Xb7@0i<A`0>30K0P0g;aX00`0h<1/0>C4L
03Xb7@0203T_5P0603X`5`0k<AP0?38I03dc6P0n=1/0?cDL0P0n<al303db7P<0?34M0`0i<ad203Xd
7P<0>cDO0`0l=aX603dh6`P0@CDK00T0@CTR040h8@0o=b00?SHO03lg8010>240@SXS04<k9014>200
0`13=al2048f7P80@CDM00H0ASDK04Lf7018=ad0BCPN04Xi7`1<>b4204dl8P0404Pi6P19>Q/0BCXK
04Tj6`80BS/L0P1;?1d00`1;@2@0BSlS04Pm8@0204Hk7`0>04Ll8018?B40BChR04/i8@1;>R00C3/Q
04dl801>?Al0CclN04lo7@1@@1h0BC/P04/m8P1<?R<204do900604`n8`1;?B80BC/P0511901>?b80
CChQ0P1;?1l00`1<?B00CSlR04m08`08055180P0DT8Q0P1D@B<205=08P@0DSlQ00<0CSlP04m08@1@
@B800P1A@R<00`1@@B80Cd0Q04ho800204ln80H0CSdO00<0D44P05528@1B@b800P1B@b800`1@@B00
CSlN04dn7@0405M1700405U37P1KAB00GTPS061:9@80FTLO00<0G4TQ05e:8P1NBb<00`1NBb<0201V
D2T0IDlX06A>9`1TCRL0IDlX06MA:P1YDb`0JeD^101]Db805@1bF2L0NV0_08M]?02CNDP0VX1?09Md
C02IMTh0VGI<09AbA@2;JC/0Q68b089P<022HBh0Pf<b08AT<`27ICD0RfLg08aX>02=IcP0SVDg08eT
=P02091/>0H0Sf/g0P2DL3`0102ELCd0UW8n09Mc?`2HM40409Ue@@<0VWI20`2KMd<209ag@`80WGQ4
00@0WWU509mjAP2PNdL0X7]70P2QO4L20:9mB0050:=nB@2TOdX0YH1;0:F0B`2TOdX00P2UP4/00`2V
PD`0Yh9=0:R3CP020:V4C`80ZhIB0P2/Qe<20:f8E080[XUE00H0[X]E0:j:EP2_ReL0[h]I0:n;F`2`
Reh20;2;G`030;2:F`2aRe`0/XaM0080/XaM00<0/8YK0:j8F@2]QeP00P2^RUX30:n;F`<0/8aL202_
REX80:n;F`80[hYN00<0[hYM0:n;F`2_ReT00P2_ReL01@2_S5H0[XUE0:j9E@2^RED0[hYF0080/8]G
0P2aS5P80;6;G0<0/8aH0P2_ReL30:j:EPT0/8aL202^RUX20;:=F@030;6<F02`ReL0[hYF0080[XUE
00L0[HQD0:Z5D02/Qe80[XUD0:n:E@2`ReH0[hYE0080[XUD0P2bSET20;6<F0<0/8]G00<0[hYF0:n9
FP2^R5T00`2/QUL0102^R5T0[hUJ0;6;G02]R5@20:j9E@80[hYF0P2`ReL00`2aS5P0[XQI0:j8F@02
0:f7F080[8IG0P2[QEH01P2]QeX0[HMH0:f7F02]QeH0[HQD0:f8D`80[HQA202]R5@80:j9E@<0[HQD
0P2^RED30:n:EP0@0:b8E02[Qe<0ZXIB0:V5D@2ZQU80[8QD0:j:EP2_ReL0[8II0:f7F02^R5T0[hUH
0:j9E@2]R5<0ZhI?0:Z5CPP0[HQA0`2ZQ5D03@2[QEH0[8IG0:b6E`2/QUL0[HMH0:j8F`2]QeP0[8IG
0:^5E02[QU80[8MB0:j9DP2_RU<00P2^RED20:f8E080[8MC0P2[QU801P2YQ4l0ZXE@0:^6D@2/Qe80
[HQC0:j9E080[hYE00<0/HaH0;2;E`2]R5@00P2[QU820:Z5D@80ZhIB0P2[Q5T0102[QEP0ZXAC0:Z5
D@2YQ4d20:V5B`80Z8=?00H0ZHA@0:Z5D@2[QU80[8MC0:f8E02^RED20;27D@030:n6DP2_QE<0[XAD
0080[H9E00@0[H9G0;26E02_QE<0[H=A0P2[PDl00`2/PU00[H=A0:j4DP020:V4D080ZXEA0P2[QU82
0:b7D`P0[H=A00<0Yh9;0:R3C02ZQDh00P2/Qe000`2[QTl0ZXE>0:V4C@080:^6DPP0ZhIA00P0ZhM=
0:b8CP2]R540[XUD0:f8D`2/Qe<0ZXAC0:V3DP80ZXEA0`2[QU830:b7D`030:^6DP2/Qe<0[HQD0080
[XUE00H0[HQD0:b7D`2[QU80ZHA?0:Z5D02/Qe830:j9E0080:f8D`2/Qe80ZXEA0:Z5D@2[QU80[8MC
0:f8E02^RED20:n:EP80[XML00<0[XQK0:j8F@2^R5L00P2^RED00`2^RE@0[HQD0:f8E0030:j9E@<0
[hYF00H0/HaH0;2;E`2_RUH0[XUE0:f8E02/Qe<20:^6DP030;:=F@2aS5P0/HaH0080/8]G0P2_RUH0
1@2^RED0[8IE0:b6E@2/Qe<0[8MB0080[HQC00<0[HQA0:f9C`2]RDl00P2_Re400`2^RU00[HU?0:b8
CP020:^7C@030:Z6C02`QU@0/8ID0080/HME00`0/XQF0;>9E`2cREL0/hUG0;2;E`2^RED0[8MC0:^6
DP2ZQE40ZhIB0:b7D`2]R5@20:n:EP<0[XUE0`2]R5@20:^6DP80[8MC0P2]R5@20:j9E@080:N2CP2Z
QE40[HQD0;2;E`2aS5P0[hYF0:f8E02[QU880:n:EP040;>>FP2bSET0/8]G0:j9E@80[8MC00<0[HQD
0:j9E@2bR5H00P2aQeD20;26E080[hEC00<0[XAB0:b3C`2/Pdl01P2/Pdl80:j8F@030:j4DP2_QE<0
/8ID0080/HME00<0/8ID0:n5D`2^Q580202`QEP80:^6DP@0[8MC1@2]R5@30:b7D`80ZhIB0P2ZQE47
0:^6C`030:Z5CP2[QU40ZhIA00H0ZhIA2@2]R5@00`2ZQE40ZhIB0:f8E0020:n:EP030:j9E@2]R5@0
[8MC0080[XUE0P2]R5@20:b7D`80ZhIB0`2/R5@30:f9E@80[XYF0P2[QTl00`2[QU40ZhIB0:^5E002
0:^5EP0<0:^5F02ZQUH0ZhMG0:b8F02]RET0[8QH0:^7E`2YQED0Yh=C0:f8D@2/Qe00ZhI?0P2ZQDh0
1P2[QTl0[8M@0:f8D@2]R5@0[8MC0:Z5D@80ZHA@00<0ZXEA0:b7D`2]R5@0202[QEH80:Z5D@@0[HQD
0P2/Qe<20:^6DP<0[89@00<0[H=A0:j4DP2^Q5800P2_QE<20:^5EP<0[8IG0`2]QeP00`2XPdl0ZHA@
0:V4D0020:Z5D@80ZhIB00<0[8MC0:f4D02]Q5001P2]Q5020:^5EP80[8IG102]QeP80:R3C`80ZXE@
0P2YQ4l30:R3CP030:N2C@2XQ500Z8A@00H0Z8A@00<0Yh9=0:R3CP2ZQE000P2[QU40102ZQE00Z8=>
0:R3CP2WPTd20:J1C@80Yh9>0P2XPdl20:V4D0P0ZXE@0`2XPdl30:V4D080ZXEA00<0ZX9?0:V1CP2W
Od`00P2UODX00`2VOT/0Ygm<0:R0C@080:F0C0<0XGa800<0XWe90:=nBP2SOTX00P2TOd/30:9mB@80
XGa80`2PNdL00`2PNDh0XW]@0:=lD@020:AmDP030:=lD@2RNe00X7U>0080Y7m;0P2SOTX0102RODT0
XGa80:5lB02QO4P30:1jBb_ooooo000Zooooo`<0UVXi0`2GJcX209Q/>`80UFTl0`2FJSd709M[?P@0
V6`o00H0TfHm09AW?P2EJ3l0UVU009MZ@@2HJd8209U/@`<0V6`k0`2IKC`209Y^?@0309a`@`2KKd80
VFe00080V6`o00@0VFe009]_@P2LL4<0Vfm20P2JKT400`2IKD00V6`o09Q/?`0209M[?PD0VFa20`2H
Jd40202GLTD0V7A409acA@2OMDD0XWA30:=a@02SKcd0Xfhl2@2IKS/309eb?`<0WW=00P2OM4430:1`
?`<0XG500P2RLT4509ic@0<0WG8o0P2SMdH01P2RMTD0XGE40:1d@`2OLd80WW9109ea@0<0XWM40`2S
N4D20:AiAP030:=h@@2TND80YW]60080Yga900<0YWY90:AhB@2SMdP0202RMd@80:AiAP040:5f@`2S
N4D0YW]80:QmBP80ZGi;00<0Z7e:0:MlB@2RNDD01`2RNDD03`2SNTH0XWU50:5hA02PMd<0XGQ40:=j
AP2VODT0Ygi:0:1fA02OMD<0WWA209ab@02KLCl0VFlm09Q^?00209M]>`<0UV`j0P2EJcT209AZ>008
095V;`2AJ300TVTc095Y=@2>JCD0RVHd08ET<@23HC4208IP<`80QElb0`24GS401`23GC00PE/g07mI
=@1nF3@0O5Hb07]E<@1lES800P1mEc<0401gFS00MUT_07EH;P1dEbd0LeH/079E:`1aE2X0L5<Y06a?
9@1/CbL0JdhV06Y<9P1YBbL0J4XX06Q9:P1WB2T306]:9`@0JTTV0P1YB2D00`1WBBL0ITPV06E79@02
06A6900306E79@1WBBL0J4XX0080JDPW0P1ZBBP03@1[BRT0K4/Z06a;:P1]C2/0JTTV06]9901]BbH0
L4dW07A>9`1gD2L0Ne4W07aB:01dF2P00P1fEbP00`1hF2T0NELY07]F:@0207aF:@0607aG;@1mF2h0
OUT_07mJ<020Fc40PUdc0P23GS@308IQ=080Qf8e0`28HcH208MP=@0308QR=@28HS<0R68a0080RF@`
00@0RF@_08QR<`28HS<0R68c0P27HC8308IP<@D0Rf0c0`2<HC@01026GcP0Qf0i08MP>@28HCX208UR
>`80RV<l00D0Oed_085O<@25H3<0R68e08]R=P0208aQ=P0708aO=@2=HSL0S64f08]P=@2:Gc@0R5db
08IK<00208EJ;`P0Qf4b00<0QV0c08EO<P24GS400P24GS400`26H3<0R68e08US=P0808MQ<P0;08MQ
<028HS40RF<d08YT=`29HSL0Qf0g08AM=023G3D0Relb08aP<`2>HSD00P2@I3L00`2?HcH0SF4d08aP
<`0308YU>080RF@g0`28HcH308US=0<0R68c0`27HC802P2:IC00RfHb08aW<`2;IC@0RV@e08MQ=024
GC80PU/`08US=028HS<208MQ<P0408QR<`2:I3D0S6Hg08iX>@P0RV@e0P29H3801027HC80QV8b08IR
<P24HS8208=S<P0608ER;025HBd0QV8^08IR<026HS80QV4d0P27HSH308MR=@80QV4d0`25H3<208AO
<P0408EP<`26HC@0QV4d08MR=@80R6<f2@25H3<308AO<P80Peha0P22GC002020GC<0PUle08=P=P24
HCL0Pf0f089O=@1oG380OU/a201nG2h807]H;PP0NEH/0P1jEbd307UF;0<0N5D[00H0MED^07AD;@1d
E2d0Le</079B:`1aDBX2071@:@80JddY0P1/CRX0201[CBT0JD/W06I8901UAb<0HdX[0658:@1NABH0
FT4R0P1H?b0205U08@0905<o9`1B?RH0CcdU04dm901:?280BC/Q04Hj8015>Al0ASHM0080ACLM00<0
@cLM044g700o>1`00`0n>A`4048f7P@0@cLO0`10=B43044f8P80@SLS0`0o=b8303hf8@<0?CDP00l0
?cLR040h8`12>RD0@SXU040h8`0o=b80?CDP04@i9@13>2@0@3DQ03hc7`0m<Qh0?S<O040e8@12=b<0
200g=Ah803hf8@<0?3DK0P0m=Q`303hg7@P0?CHL200l=1l203df70<0?3DK0`0k=1X803/c7P80=c8L
00@0>3<M03Td7P0j=Al0>SDO0P0k=R0203Ha6`80=c8L1P0h<ad203Lb700703Ha6`0e<1X0=2lI03@_
6@0j<Qd0>C4L03L_6P0203H^6@0903L_6P0i<A`0>S8M03P^5@0i;aH0>S0G03/a600l<QT0?C<J0080
?S@K00D0?c@R03hc8@0n<b40?C8P03`a7`0203/`7P0303X_7@0g<Qh0>3<O0080>3<O0P0i=20203Xe
8@@0?3PK0`0k=aX203Xf6@P0@3@J00<0@3PQ03lg800n=Ql00P0n=Ql01010>240@CTR04<k9012>1l3
044g7P80@3HM0P0o=A`02014<aT0AC@J04He6`18=ad0BSTO04`k8@1=?280CSdS0P18>AX204Tj6`<0
BS/L00D0Bc`M04]19P19?b@0AcdR04Dk800204@j7`0304Hl8@17?B80BSPP0080BcXP00<0C3/O04dl
7P1>?Qd00P1??ad00`19>b40BS`R04`n900204do9@0604`n901:?280BC/Q04`m801;?1l0BCXM0P17
>1/00`18>A`0BS/N04/l7`0@05518080E44S0P1C@283058o8@04054n801=?Ql0Cd0Q05118P80DT<T
00<0D44R04m08@1=?Ql00P1??R0404hm7`80CC`N00T0D44P05528@1A@R40DD8Q0511801>?ah0C3dL
04Xk6P1G@A`00P1F@1/01@1G@A`0F48M05]5801NB2<0GdTT00@0FdPP00@0G4TQ05e:8P1OC2@0Gd`T
0P1UCbX206A>:@0506E?:P1VD2/0JE<^06YD;`1[DB000`1ZD1l05P1_EB@0NV0_08Y`?`2JP4l0Y8YI
0:F2G02ROeL0VWM?08i[@@22H3<0O5X/07eK:`20GRh0PV8a08AT<`27ICD0S6Ph08eY>@2=IcP0SVDg
08eT=P2@K3P408m[=`<0SVXf00H0Tflk09A`?02ELCd0UW8n09Mc?`2HM40509Ue@@80VWI20`2KMd<0
1P2KMT80W7M309ag@`2MN4@0WWU509mjAP80X7]700H0X7]60:5lA`2QO4L0XWe80:=nB@2TOdX20:F0
B`80Y7m:00<0YH1;0:J1C02WPTd00P2XPdh00`2YQ4l0ZhIB0:^6DP020:b7D`80[HQD0P2^RED01P2^
ReD0[XYF0:n;E`2_ReT0[h]K0;2;GP80/8]O00P0/8YK0;6;G02bS5d0/heN0;:<G@2`RU/0[XQI0:b6
E`80[XYJ0`2_Re/30;2<G0P0[hUJ202_Re/20:n:GP030:n:G@2_Re/0[h]I0080[h]G00@0[haF0:f8
E02]R5@0[XUE0P2_RUH00`2`ReL0/HaH0;6<F0080;:<G@<0/8aH0`2_ReL20:j:EPT0[h]K202^RUX2
0;>>FP030;:=F@2aS5P0/8]G0080[hYF00D0[XUE0:Z5D02[QU40[HQC0:n:E@020;2;EP040:n:E@2^
RE@0/HaH0;6<F080/8]G0`2_RUH00`2^RED0[HMH0:f7F0030:b6E`030:j8F@2`RU/0/XaM0080[HQD
00@0[XUE0:n:EP2_RUH0/8]G0P2aS5P20:j8F`80[HMJ0P2/QUT20:^5F0060:f7FP2]QeP0[HMH0:f7
EP2]R5@0[HQC0P2]R5480:f8E0P0[XUE0`2]R5@30:j9E@80[hYF0P2[R5803P2ZQe40ZHI@0:Z7D@2/
RE<0[X]E0:n<EP2/QUT0[HMH0:j8F@2_REP0[XUE0:f8D`2[QTl0ZXE>202]R5401P2XPUD0ZH=F0:Z4
E`2[QEP0[8II0:f7FP80[XQK00P0/8YM0:j8F@2/QUL0ZXAC0:Z5D@2[QU40[HQA0:j9DP80[XUE0P2]
R5@20:b7D`80ZhIB00/0ZHA?0:Z5D02[QU40[8MB0:f8D`2^RE@0[hYE0;2;EP2bSET0/8]G0:f8E002
0:^6DP80ZXEA0180ZhIB0:b7D`2[Q5/0ZhAI0:^5F02ZQ5<0ZXE@0:V4C@2YQD/0ZHE90:J1C@2WPTh0
Z8=?0:V4D02ZQE40ZhIB0:b7D`2]R5@20;27D@030:n6DP2_QE<0[XAD0080[H9E00@0[85F0;26E02_
QE<0[H=A0P2[PDl00`2/PU00[H=A0:j4DP020:R3C`80ZHA@0`2ZQE400`2[QU80[H=A0:f3D@060:f3
D@030:N2B`2XPd`0ZXE>0080[8M@00<0ZhI?0:Z5CP2YQ4d0202[QU880:^6D@080:Z6C02[Qdd0[8M@
0:f8D`2/Qe80ZhIB0:V3DP2XPU420:Z5D@<0ZhIB0`2/Qe<00`2[QU80[8MC0:f8E0020:j9E@0;0:f8
E02/Qe<0ZhIB0:V4C`2[QU40[HQC0:j9E02_RUD0[XUD0:f8D`2[QU400P2ZQE40102[QU80[8MC0:f8
E02^RED20:n:EP80[XML00<0[XQK0:j8F@2^R5L00P2^RED00`2^RE@0[8MC0:b7D`030:f8E0<0[XUE
00H0/HaH0;2;E`2`ReL0[XUE0:f8E02/Qe<20:^6DP80/XeI0P2aS5P0202`ReL0[hYF0:n:EP2^RED0
ZXAC0:^5E02[QU80[8MB0P2]R5<02`2^RE80[XY@0:n;D@2aSE<0/8aB0:n;D@2]RDl0[8Q>0:Z6C02Y
QD/0Z8A:0080/8ID00@0/HME0;:8EP2bR5H0/hUG0P2dRUP0202`ReL0[XUE0:b7D`2[QU80ZXEA0:^6
DP2/Qe<0[HQD0P2_RUH30:j9E@<0[HQD0P2[QU820:b7D`80[HQD0P2^RED0202WPTh0ZHA@0:f8E02`
ReL0/HaH0:n:EP2/Qe<0ZXEA202`ReL0202dSe/0/XeI0;2;E`2^RED0[HQD0:b7D`2]R5@0[XUE0P2a
QeD0102`QU@0[hEC0:n5D`2^Q5820:f3D@P0[8=?202]QeX00`2^Q580[hEC0;26E0020;67E@030;26
E02_QE<0[XAB00P0/8EJ202[QU80102^RED0[HQD0:f8E02]R5@30:b7D`030:^6DP2/Qe<0[8MC0080
[8MC0P2[QU820:Z5D@<0ZhI?0`2/Qe020:f8D@P0ZhIA2@2/Qe<00`2YQ500ZXEA0:b7D`020:j9E@03
0:f8E02/Qe<0ZhIB0080[XUE0P2]R5@20:b7D`80ZhIB0`2/R5@30:f9E@80[XYF0P2[QTl00`2[QU40
ZhIB0:^5E0020:^5EP0<0:^5F02YQED0ZXIF0:b8F02]RET0[8QH0:^7E`2XQ5@0Yh=C0:j9DP2/Qe00
ZXE>0P2YQ4d01P2ZQDh0[8M@0:j9DP2]R5@0[8MC0:Z5D@80ZHA@00<0ZXEA0:b7D`2]R5@0202[QEH8
0:Z5D@040:j9E@2]R5@0[HQD0:f8E080[8MC0P2[QU820:b0C`040:f1D02^PU40[X9A0:n3DP80/8AC
00D0ZXAE0:^5EP2[QEH0[8IG0:f7F0020:j8F@040:n9FP2XPdl0Z8=?0:V4D080ZXEA00<0ZhIB0:b7
D`2/Qe<00P2/Pdl40:f4D080[XEA0P2[QEH20:b6E`<0[HMH00<0[XQI0:R3C`2XPdl01P2XPdl20:Z5
D080ZHA?102XPdh80:R4D0030:N2C@2XPdh0ZXE@0080ZhIA00@0ZXE@0:R3CP2XPdh0Yh9=0P2VPDd2
0:N2CP80Z8=?0P2YQ5080:Z5D0060:J1C@2WPTh0Yh9>0:R3C`2YQ500ZXEA0P2[QU800`2ZPTl0ZH5>
0:MoC0020:EmBP030:InB`2WOd`0Z81=00P0YH1<0`2QO4P00`2RODT0Xgi:0:AoB`020:AoB`<0XWe9
0`2QO4P20:1kA`030:5jC`2RNe00XgaA0080Y7eB00<0XgaA0:9kD02QNTl00`2TOd/00`2SOTX0XWe9
0:5lB0020:5lB0<0X7Y;:oooool002[ooooo00P0TFDh099V>@2EJC`0Uf/n09Q/?`2GJch0UVXm09EY
?0P0UF/i2`2FJST00`2GJcX0V6`k09U]?00209U]?00609U/@P2IKD00VFe009Y^?`2JKSd0Vg0m0P2K
L3/309]_?P80VVhm2`2IKC`00`2LLD@0VVm209Q]@00209I[?P0309Q]@02JKd80W75400<0WW=00P2O
M4430:1e@P030:Eb@`2SL440XVm000<0XFho00<0XVm00:=`@@2ULT<0202LLT0809ec@@80WG5000@0
WW9109mc@P2OLd80X7A30P2QMD@209md@@80X7E2102QMT<20:1e@P040:9gA02SN4D0YGY70:IkB080
Z7e:00T0YGa80:AkA`2SNTH0XWU50:=jAP2TNdL0YWe90:MnBP2TNSh00P2TNT000`2TND80Y7U40:Ai
AP020:AhA`030:=iA`2UNdT0Yge;0080ZGm=00<0Z7i<0:MmB`2VO4X00P2TNTX0102TNTP0YGa80:Im
B@2WOTP20:MnAP<0YGa80`2TNdL20:=jAP80XgU700@0XWQ60:5gA@2PMT@0WgE30P2NM48309Qc?0D0
Ug8k0P2FKCT0102EK3P0U6/g09=Z=P2CJSH2099Y=@0409=W>02BISL0Sf<d08eQ<P80S60a00H0SV8c
08mS=024HCL0Pf0f085N=01oG38207iK<@0707mL<P20GC<0Pf0h085N=P1nFc<0NeP`07UF;P0307QE
;@80MED^00@0M5@]07=C;01bDR/0LU8[0P1aDBX206a>:P<0JddY0`1ZC2P306e<:@0306a;:01[BRL0
JTTV00<0JTTV0P1/BbP206]:9`0406Y99P1YB2D0JDPU06Q79080J4`W00<0JD/W06]:9`1]BbP00P1^
BRP00`1`BBP0KE0V06e@9P0206iA9`80Ke8X0P1`DbT207QC:@0307UD:P1jEB/0NeH/0080OEP^00@0
OUT_081L;020G2`0P5`/0P21GBd3089N;PP0QV0a00H0SF8e08aQ=02:Gc80R5d`08ML;`28GC0208UN
<@0808aQ=02=HSD0SF8e08eR=@2<HC@0REha08ML;`25FRd808QR=@0808IP<@27HC80R68c08US=02:
I3D0RfDf08aV=`2=IcP208MQ<P<0QV0a0`25Gc0808IP<@P0R68e0`26H3<208MQ=0<0R68e00<0QEl`
08IP<@28HS<00P29Hc@02`28HS<0QV0a08EO<029Hc@0RV@e08]U=P2<ISL0RfDf08US=027HC80QEl`
00P0T6Dh202:I3D208]U=P80RV@e0P29Hc@308QR<`80RV@e0P29Hc@01028HS<0Qf4b08MQ<P26H348
08YT=@0808YS>029HSL0R68e08IP<@26H2l0R6<_08UT<02:IC0808QR<`P0Qf4b0P26HS8308EQ<@<0
Q60`2026H3<208IQ=080Qf8e00@0R6<f08UT=`29I3L0RVDh0`23GS43089M<080PE`_00<0OeX]085L
;`23GS400P25H3<02023GS40PE`_07mJ;@22G2l0PE/^081K;P1mFbd0Ne//0P1iFR/03`1fFRX0PEl_
081N;P1mFb/0O5XZ07]I:@1lFRX0OU`/07mM;@1dDB/0ME8/07IC;@1gE2h0N5D_07UF<00207YG<@P0
MUH_00P0Le8Y079@:P1aDBX0KU0Z06a@:`1YCb`0J4h]06M?;@80KddW00h0KDdW06U;9@1WBbH0I4XW
06=9:01QBBL0G40Z05a2:`1M@b`0G4@/05U3:`1F@RT0DT4W050o9@80BShT0P19?B<404Pl8P80@cTP
1014>R4304Dk8P0804@m8`13?280@CXP03lh7P0n=ad0?cPN044j8012>b42044g7P80@SPO00@0@cTP
04@j8@14>R40AC/R0P14>BD204<h90<0@SLS2@11=R8803de80<0?3LS0P0k=R8303Xe8@80>C@Q00<0
>SDQ03Xe7`0j=Qd00P0j=Q/0100j=QT0?c8O03lb7`0o<Ql2040c80<0@C@Q0`0j=B400`0i=200>3<O
03Lb7P0203Lb7PP0?3@Q200k<b0403Dd7`80=3<N0P0c<Qd00`0f<A/0=c8L03Xe7`0303`g8@0603Xe
7`0i=1h0<2/G038]6@0f<Ad0>C@P0P0k=R800`0j=B40>3<O03`d7`0203`d7`0303/c7P0j<Qd0>C4L
0080>C4L00<0>c<N03Xb7@0h<1/00P0f;QT00`0g;aX0>30K03Ta700803/c7P/0>c@J0`0l=A/203df
70<0@CLN00@0@3HM03le700o=A`0?S@K0P0m<aX203hd6`@0?cDL0P10=Qd803le70D0@3HM0`11=ah2
03dc6P0403hd6`0o=A`0?cDL040f7@80@CLN2013>B000`16?2<0AC/R04<i8002048h7`0304<i8015
>b80AS`S00@0AcdR1016?24204Pj7`80BC/P0`1:?2400`1;?B80CSdS04hm8`0304dl8P<0C3/Q0P18
?B401019?R80BSlS04Xo8`1;@2@:04a19@80CSlP0P1?@24305118P0905528`1DABH0Dd@U05118P1?
@240CSlP04m08@1A@R<0DT<T00P0CChO00P0ACXN04Pm8@1<@BD0Cd@X04i39`1;@2@0AS/O04<h7080
Cd8R00@0DD8S05918`1B@B<0ED8T0P1F@B@04@1F@bD0Ed@T05Q59@1IARD0FdTU05a:901MBb<0GT`T
05a89@1MBBH0H4XU06=;9@1VCBD0JThV06]?9`1]D2H0LUHV0080L5@T00X0Ke<S071D901fFRX0P6@d
08]_?`2AMDD0V7U:099cA029JS/0PF8c0P1mGRl00`21HS<0Pf@e08ES<`0208IT=00308MU=@28ISH0
RFLg0080RVPh1@2?Jc/308iZ>P0609A_>`2EL3`0UW4m09Mb?P2HLcl0VGA00P2JMD4209Ib?P0609Mc
?`2HM400VGE109Yf@P2KMd<0W7Q40P2OO4H309ikA@<0WGY40P2SP4H0102SP4P0Xh1:0:>0BP2SOd/2
0:=oC@80X7e700@0XWm90:>0BP2UPT`0YX==0P2XQDl20:V6D0<0ZXMA0`2[R5880:f9F@<0[HUE0P2^
RUH30:n;E`030;:=EP2`Re@0[hYC0080[HQA00<0[XUB0:n:D`2`Re@0202_REX30;>>FP030;:=F@2a
S5P0/8]G0080/8]G0`2`S5P30:n;E`80[XYF202_RU<80;2;E`P0[hYF2@2^QEL80:n:EP<0/8YK0P2_
REX30:j8F@<0[HQD0`2^RED20:n:EP030;F:E@2dRE@0/XMB0080/HIA00<0/XMB0;B9E02eRUD00`2]
R5@30:j9E@80[hYF0P2ZQE401P2[QU80[HQD0:n:EP2`ReL0/HaH0;:=F@P0[HQD202[QU480:b7D`P0
ZhIB202]QU/80:^6D@80[hYE0P2^RE@40:f8D`030:Z5CP2/Qe00[HQA0080[hYC00<0[HQA0:b7D02Z
QDh0202[QU880:j9E@<0[8MB0`2[QU420:Z5D080ZhIB0P2/Qe<20:f8E080[XUE00<0/8YK0:n9FP2^
R5T00P2]QeP01P2/QUL0ZhEF0:Z4E@2YPe@0ZHA@0:Z5D@80[8MC00`0ZhIB0:V4D02WPTh0YH1<0:R4
D02YQE40ZXIB0:^7D`2/R5@0[HUE0:j:EP2_ReL80:f8E0080:n:EP2`ReL0/8]G0;2;E`2_RUH0[HQD
0:Z5D@2YQ5020:N2C@040:R3CP2YQ4l0ZhIA0:b7DP80[HQC202^QE420:^6D@80[8MB0`2]R5<0102^
RE@0[hYF0:j9E@2/Qe<30:Z5D@040:^6DP2/Qe<0[XQI0:f7F0<0ZhEF00<0[HMH0:n9FP2aRe`00P2_
RUH20:j9E@<0[HQD00<0[8MC0:f4D02]Q5000P2]Q5020:j5D@80[hIB102]R5@20:j9E@80[hYF202^
R5/00`2`ReL0[XUE0:f8E0020:b7D`030:f8E02^RED0/8]G00<0[XUD0P2_RUD30;2;EPP0[hYF0P2]
RU00102]RU80[HYD0:f:E02]RED20:f9Ea40[hYF202^RED30;26E0<0/HME0P2bR5H20:n:EP<0[XUE
0`2]R5@01P2aS5L0/HaH0;2;E`2_REP0[hUJ0:j8F`80[HIK0`2]QeX30:j8F`80[hUL00@0ZhIB0:b7
D`2/Qe<0[HQD0P2^RED:0:n:EPX0[XUB00l0[HQC0:f8E02/QUD0[8IG0:^5EP2[QEP0/8]D0:n:D`2^
RE80[8M@0:Z5CP2YQ4d0Z8=<0:N2B`2^RE@00P2^RED00`2^R5L0[XQI0:j8F`020:j7G0030:n:EP2]
R5@0[8MC0080ZXEA00T0[8MC0:f8E02_RUH0/XML0;:7FP2aQUT0/HMG0;67E@2`Qe<00P2`Qe430:j8
F@030:f7F02/QUL0ZhEF0080ZhEF0`2YQ5020:Z5D@<0ZhIB00P0[HIK0:j7G02^R5/0[XQI0:f7EP2[
QU80ZHA@0:N2C@P0ZhIB0`2/Qe<30:^6DP80ZXEA0P2]R5<20:b7DP050:^6D@2ZQE00ZXE@0:Z5D02Y
Q4l00P2ZQE420:^6DP@0[8MC0P2^RED20:f8E080[8MC0P2[QU820:j8F`80[HMJ0`2/QUT0102[QEP0
[8MC0:b7D`2/Qe<30:^6DP80ZXEA00<0ZHA@0:Z5D@2/Qe<00P2]R5@00`2/Qe<0ZXEA0:V4D0020:Z4
E@<0ZhEF0`2/QUL0202[RE/0ZhUI0:b8F02/QUD0[HEB0:f4D02/Pdd0[85<0P2WPe<03P2VPU80Yh=C
0:V5E@2/R5P0/8aL0;:>GP2`ReL0[hYF0:j9E@2]R5@0[8MC0:^6DP2ZQE40ZHA@0P2]QU/00`2]QeX0
[HMH0:f7EP020:f8E0030:f8D`2/Qe<0[8MC00H0[8MC00<0ZhEH0:b6F@2/QUT00P2]QeX20:j8F`04
0:n9G02/Qe<0[8MC0:b7D`<0ZhIB102ZQE430:V4D0<0Z8=?00P0[8MC0:f8E02^RED0[hYF0:j9E@2/
Qe<0ZXEA0:R3C`80[HQC00@0[8MB0:^6D@2YQ4l0Z8=>0P2WPTd20:V4C@030:V4C`2YQ500ZH=B0080
ZH=D00@0ZH=F0:R4D02YQE40ZhMC0P2/R5@02@2[Qe<0ZHEA0:R4D02TP500ZHEE0:b8F02ZQUH0YH5A
0:B0D0020:N3D`040:^7E`2WPTh0Z8=?0:Z5D@80ZhIB00<0ZXEA0:R3C`2WPTh0102VPD`01@2XPdh0
ZXE@0:f8D`2_RUD0ZhI?0080ZXE>00<0ZHA=0:R3C02XPd`00P2WPT/00`2UO4h0YWe?0:QoD@020:V0
DP030:QoD@2VODl0Y7]=00<0XGa80P2RODT30:=nBPP0Y7m;202QODT01P2VNE00YW]A0:IkD@2UNe40
Y7eB0:=nDP80XX1C00<0X7a80:9nBP2TP4`00P2UPDd00`2TP4`0XWi:0:1lB0030:AoBb_ooooo000Z
ooooo`03095U>02CIcX0UFTl00<0Uf/n00<0UVXm09EY?02EJcT01`2EJcT:09IZ>@80Uf/j0P2HK3/2
09U]?00609U/@P2IKD00VFe009Y^?`2JKSd0Vg0m0P2KL3/309]_?P80VVhm2`2IKC`209Y_@P0409U^
@@2HKD00V6e009U^@@80VVm20`2NLd0209md@@<0X7E200<0XW920:5a@@2PL4000`2OKcl00`2PL400
XG510:9b@P0809ab@0P0WG=10P2NLT4309mc@P<0X7A30P2OM4420:1e@P<0XGI30180XWM40:1e@P2Q
MT<0XWM40:=hA@2UNTL0YW]80:MlB@2XODX0YGa80:AkA`2SNTH0XWU50:=jAP2TNdL0YWe90:MnBP2T
NSh20:Aj@0030:Ai@P2TND@0Y7U60080Y7Q700P0XgU70:EkB@2WOD/0Z7i<0:UoC@2XOT`0Yge;0:Il
BP80Y7Y:00@0YG]90:ElB02VODT0Ygi80P2WOTH30:ElB0<0Y7]70P2SNTH01P2SNDL0XWQ60:9hAP2Q
MdD0X7I409me@`80WWA20`2HLc`409Mb>`0609Ia>P2FK3X0UV`j09E[>@2DJSP0TfTg0P2BJ3H01@2A
IcD0TVPh091V=P2>I3@0S68b0080Rf4a00H0S68b08eS<`25HSP0Pf0f085N=01oG38307iK<@0607mL
<P22GcL0P5de07eJ<P1jEbl0N5D]0`1gE2`207EE;P0307AD;@1cDb`0LU8[0080LE4Z00<0L50Y06a>
:P1/CRX00`1[CBT306Y<:080KD`Y0P1/BbP00`1[BRL0JTTV06Y99P0206Y99P80K4/X0P1[BRL0101Z
BBH0JDPU06U89@1YB2D206Q<9`0;06U;9`1/BbP0KD/X06i::01_BbT0LDXY06i>9@1_CbH0L50W075A
:01bDRT00P1cDbX01`1dE2/0NE@Z07UD:P1jEB/0NeH/07aG;@1mF2h00P1nFBl2081L;080PEd]0`22
GRh00`23Gbl0QV0a08IP<@0608IP<@0:08iS=P2=HSD0Rf0c08UN<@28GC00REha08YO<P2;H3<0S64d
08eR=@80SV<f00@0SF8e08]P<`29GS40R5d`2028HSD208MQ<P0408QR<`29Hc@0RV@e08]U=P80S6Hg
0`27HC8208IP<@<0QEl`2026H34808QR=@<0QV0c0P27HC@308QR=@0308EO<026H340R68c0080RF<d
00/0R68c08IP<@25Gc00RF<d08YT=@2;ICH0S6Hg08]U=P29Hc@0Qf4b08IP<@0808mT=`P0RV@e0P2;
ICH208YT=@80RF<d0`28HS<208YT=@80RF<d00@0R68c08MQ<P27HC80Qf4b202:I3D0202:HcP0RF8g
08QR=@27HC80Qf4`08QS;`29I300RVD`2028HS<808MQ<P80QV8b0`25HC4308AP<0P0QV0c0P25H3<2
08IQ=080Qf8e0P28HcH308=N<@<0PUd`0`21G2l00`22GC00Peha08=N<@0208=N<@07089M<021G2l0
P5X]081J;@1oFRd0OE/]07]K;00207YK;00907QL;020GRh0Oed]07eK:`1lFRX0NeTY07aJ:P1mFb/0
OU`/0080MU<]0P1gE2h307QE;`0307UF<01fERl0MUH_0080MED^0P1dE2d207=C;00H079A:01bD2X0
L50Y06e?:@1[CbX0J4h[06Q>;@1VCR`0KT`V06a<9@1[BbD0J4XV06E89P1RB2L0H4PV05m69`1J@2T0
Fd4Z05Y2:P1K@b/0F48Z05E1:01A@2H0CchT0P1:?R@204Tm8`<0B3`R00<0Ac/Q04@j8@14>R401`14
>R400`14?B<0@c`R044j800303lh7P80@CXP0P11=ah2048h7`0504<i8014>R40A3XQ04@j8@14>BD0
0`13>2@2048g8`80@CHR200o=b8803de8080?3LS0P0k=R8303Xe8@0603Td800j=B80>SDR03Xe8@0j
=Al0>SHM0P0i=AX0100i=AP0?c8O03lb7`0o<Ql3040c8080@C@Q0P0j=B4203Td8080>3<O0P0g<Qh8
03`d8@P0>c<P00@0=SDP03Dd7`0e=1l0=C@O0P0d<ah203<b7@0<03Ha6`0g<Q`0>C@N03/f800l=b40
>cHP03Xe7`0i=1h0<bhJ03D`700f<Ad0>3<O100i=20203`d7`80>c<N0P0j<Qd203Ta700803/c7P0j
<Qd0>30K03L_6P0f;QT0=blJ03P`6`0i<A`803/c7P/0>c@J0`0l=A/203df7080@CLN0P10=Qd203le
7080?S@K00<0?C<J03le700o=A`03P0o=A`8040f7@0303dc6P0n=1/0?S@K0080?cDL0P10=Qd00`11
=ah0@SPO048h7`06048h7`0304Dk8P14>R40@cTP0080@SPO00<0@cTP04@j8@15>b800P15>b0404Hl
8@80AcdR0`18>Ql204Tk80<0BS`Q101;>b4404`l8P80B3dQ0P19?R80101:?b<0Bd0T04]0901;@2@8
04a19@80CSlP0P1?@24405118P0805=49@1B@b@0D44R04m08@1>?b00Cd0Q05118P1A@R<804dn7`08
04Hk7`18?B40BSlS04a19@1;@2@0BChR04Hk7`14>Ad204i18@0404m08@1A@280DD0R05A18`80ED0S
00H0ET<U05I38`1GA2@0FDHU05Y8901LBR@205e;8`0905a89@1MBBH0H4XU06=;9@1VCBD0JThV06]?
9`1]D2H0LEDV0080Ke<T0P1^DR<0301bERL0NEd^07mS=024J3T0RV/l08IW>021HS<0OEh_07]L;@1m
GRl0P64b089S=080PV0`0P23HC401024HS80QF<c08IT=026I3@308eY>@80SVXj0`2?Jc/209A_>`04
09E`?02FLCd0Ug8n09Ud@080VWE10P2FLSh0102GLcl0V7A009Ue@@2JMT8209]g@`@0WGY4102NNdD2
0:>0AP040:>0B02SP4X0Xh1:0:=oB`80Xgm=0P2PODL01P2QOTP0Xh1:0:F2C02VPdd0YhA>0:R5C`<0
ZHI@0P2ZQe430:^8DPP0[HUI0`2]RED30:j:EP80[h]G00P0/HaE0;2;E02_RU<0[XUB0:f8D@2^RE80
/8]D0;6<E@P0[hUJ0P2cSUX20;:=F@040;6<F02`ReL0/8]G0;2;E`<0/8aH0`2_ReL20:j:EPP0[hYC
202`ReL80:n:EPT0[hIH202_RUH20;2:F`<0[hUJ0`2^R5T30:f8E0<0[XUE0P2_RUH00`2dReD0/hYD
0;68DP020;27D@030;68DP2cRU@0]8]E00<0[HQD0`2^RED20:n:EP060:^6DP2/Qe<0[8MC0:f8E02^
RED0[hYF0P2`ReL80:f8E0P0ZhIA202/Qe<80:^6DPP0[HIK202[QU420:n:E@80[XUD0`2]R5<0102/
Qe80ZXE>0:^6C`2]R5420:j9DP030:f8D@2[QTl0ZXE>00P0ZhIB202^RED30:b7D`<0ZhIB0P2ZQE42
0:^6DP80[8MC0P2]R5@20:j9E@80[hUJ00D0[XQI0:f7F02]QeP0[8IG0:^5EP020:Z4E@080:Z5D@2[
QU80[8MC0:f8E02/Qe<0ZhIB0:V4D02WPTh20:V5D@040:Z6DP2[Qe<0[8QD0:f9E@80[XYF202]R5@2
0:n:EP80/8]G00D0[hYF0:f8E02ZQE40ZHA@0:N2C@020:R3CP050:V4C`2[QU40[8MB0:b7DP2]R5<0
202^QE420:^6D@80[8MB102]R5<00`2^RED0[HQD0:^6DP030:V4D00;0:Z5D@2[QU80[HMH0:b6E`2[
QEH0ZXAE0:^5EP2/QUL0[XQI0:n9FP2_RUH00`2^RED20:f8E080[8MC102_QU840:j5D@040:b7D`2]
R5@0[HQD0:f8E080[XUE0P2_RUH80:j8F`030:n:EP2^RED0[HQD0080[8MC00<0[HQD0:j9E@2_RUH0
0`2^RED20:n:EP<0/8]G202_RUH20:f:D0040:f:DP2]RU@0[HYD0:f9E@80[HUG4@2_RUH80:j9E@<0
/8ID0`2aQeD20;:8EP80[hYF0`2^RED30:f8E0080;6<E`2`ReL0/8]G0:n9F02_REX0[XQK0:j7G02]
QU/30:f7F0<0[XQI0P2_REX30:f8E0030:j9E@2_RUH0[hYF0080/8]G202_RUH:0:j9DP0?0:f8D`2]
R5@0[8IE0:b6E`2[QEH0ZhEH0;2;E02_RU<0[XUB0:b7D02[QTl0ZHA=0:R3C02WPT/0[XUD0080[XUE
00<0[XQG0:j8F@2^R5/00P2^Qe`00`2_RUH0[XUE0:b7D`020:^6DP090:b7D`2^RED0[hYF0;:7G02b
QeX0/HII0;67E`2aQeD0/8MC0080/8MA0P2^R5T20:f7F080[8IG0P2[QEH20:V4D0<0ZXEA0`2[QU82
0:j7G0060:n9G02_REX0[XQG0:b7D`2ZQE40Z8=>3`2[QU800`2/Qe<0[HQC0:f8D`020:b7DP030:^6
D@2ZQE00ZXE@0080ZXE@0P2ZQE420:^6DP<0[8MC00<0[HQD0:j9E@2^RED00P2]R5@20:b7D`80ZhIB
0P2^R5T20:f7F0@0[8IG0`2/Qe<30:^6DP80ZXEA00<0ZHA@0:Z5D@2/Qe<00P2]R5@00`2/Qe<0ZXEA
0:V4D0020:Z4E@<0ZhEF0`2/QUL0202[RE/0ZhUI0:b8F02/QUD0[HEB0:f4D02/Pdd0[H9=0P2XQ5@0
1P2WPe<0Z8AD0:V5E@2/R5P0[XYJ0;2<G080[hYF00@0[XUE0:f8E02/Qe<0ZhIB0P2ZQE420:f6F`03
0:f7FP2]QeP0[HMF0080[HQD00<0[HQC0:^6DP2[QU801P2[QU800`2[QEH0[8IG0:b6E`040:b6E`04
0:f7F02/Qe<0[8MC0:b7D`<0ZhIB1@2ZQE420:V4D0<0Z8=?00T0[8MC0:f8E02^RED0[hYF0:j9E@2/
Qe<0ZXEA0:V4D02]R5<00P2/Qe801@2[QU40ZHA?0:R3CP2XPdh0Yh9=0080ZHA=00<0ZHA?0:V4D02Y
Pe800P2YPe@0102YPeH0Z8A@0:V5D@2[Qe<20:b8E0090:^7D`2YQE40Z8A@0:F1D@2XQ5@0ZhMG0:Z6
EP2VPU80Y81@0080Yh=C00@0ZhMG0:N2CP2XPdl0ZXEA0P2[QU80102ZQE40Z8=?0:N2CP2XPdh20:N2
C@050:J1C02WPTd0ZHA?0:b7DP2]R5<00P2ZQDh20:V4C@80Z8=<0P2WPT/00`2UO4h0YWe?0:QoD@02
0:V0DP030:QoD@2WOU00YWe?00P0Xgi:202TOd/80:5mB@0;0:IiD02UNU00YW]A0:EkD@2TOE80XgiB
0:5oDP2RP5<0X7a80:5mB@2SOd/00P2TP4`00`2SOd/0XGe90:1lB0030:=nBR_ooooo000Zooooo`03
09=W>P2DJ3/0UFTl00<0UVXm0P2EJC`809I/>PP0Uf/j00@0UVXi09M[>P2GJcX0Uf/j0`2HK3/01`2I
KC`0VFa209U]@02IKD00VVho09Y^?@2KL3d00P2KL3/309]_?P80VVhm2`2IKC`00`2HKD00VFi109Y_
@P0209]`@`0309Y_@P2IKT40V6e000<0WW=00P2OM4430:1e@P030:9b@P2QLD40Wflo00<0WVhn00<0
Wflo0:5a@@2RLT80202LLT0809ec@@040:5eA02PM4<0X7A30:1d@`@0Wg=20`2PMD820:5f@`<0XWM4
0140X7E20:5f@`2RMd@0XgQ50:EjA`2VNdP0Yga90:QmBP2UO4P0Y7]70:=jAP2RNDD0XgY60:AkA`2V
ODT0Ygi:0:Aj?P020:Aj@0030:Ai@P2TND@0Y7U60080Y7Q700D0Y7Y80:EkB@2VO4X0Yge;0:QnC002
0:MmB`040:IlBP2UNd/0YG];0:EkB@80YWe900<0Ygi80:MnAP2WOTH00`2UO4P30:AkA`80XgY60P2R
N4H0102QMdD0X7I409me@`2OMD<209id@P0509Ud?`2HLch0V7<n09Qc?P2GLSd00`2FLC`209E[>@03
09AZ>02CJCL0TVPf0080TFLe00D0T6Hd091U>02?I3L0SF8e08aQ=00408]P<`0608IS>@24HCL0PEhd
07mL<P1mFS00O5T_0P1mFS001@1oG3@0OEXb07]H<01hEBd0MU<[0080ME8Z00L0MU<[07EE;P1dE2d0
M5@]07=C;01bDR/0LE4Z0080L50Y0P1/CRX306]=:@<0JT`X0`1/BbP206]:9`@0JTTV0`1[BRL306Y9
9P80JDPU0P1XC2L01P1ZC2P0K4/X06i<:@1_BbT0L4`Z079;:P80KThU00H0L50W075A:01cDbX0MED/
07IF;@1gEbh207YE:`0307]F;01lEbd0OEP^0080OUT_00@0OeX`085M;@21GBd0PEd]0P22GRh308=O
;`P0QV0a00<0Sf@g08iS=P2<HC@00P2:Gc801P2;H3<0S64d08eR=@2<HC@0SF8e08iS=P80Sf@g00<0
SV<f08aQ=02;H3<02028HSD01@27HC80R68c08QR<`29Hc@0RV@e0080RfDf00<0S6Hg08QR<`27HC80
0P27HC8208IP<@80QEl`2026H34808QR=@<0QV0c0P27HC@308QR=@80QV0a1028HS<208IP<@80RF<d
0`2:I3D00`29Hc@0Qf4b08MQ<P0808eR=@P0RV@e0P2;ICH208YT=@80RF<d0`28HS<308US=0<0R68c
0P27HC8808YT=@0808]T>@2:HcP0R68e08MQ<P27HC00R6<_08YU<@2;IS4808QR<`P0Qf4b0P26HS83
08EQ<@<0Q60`2025Gc8408AO<P80QF0c0P26HC@308=N<@<0PUd`0P21G2l00`23GS40PUd`085L;`02
081K;P03085L;`22GC00Peha0080OeT/00<0OUT/07aJ;01lG2d00P1kG2d01@1iGBd0Oed_07iL;P1m
Fbd0O5X/0080NeT[00<0O5X/07eK;@1hEBl00P1hEBl207MD;P<0MU<]00D0MUH_07EE;P1dE2d0Le</
079B:`02071@:@0I06m?:01bDBP0LDlY071@:@1]CbT0JdlZ06Q>:`1WCB`0ITh/06Y:901YBB<0ITPT
06A79@1PAR<0GTHT05a59@1KA2@0F3hW05Lo9`1H@2P0ET0X05A09`1@?bD0CCdS04`l8P0304Tm8`80
B3`R0`17>b4904@j8@0504<l8P12>b40@CXP040i7`0o>1h00P10>Al01011>R00@SPO048h7`12>1l3
04<i8080A3XQ0P13>2@2048g8`<0@CHR00<0@3DQ03hf8@0n=R401P0n=R4803`d7`<0>cHR0P0j=B43
03Td800803`g900k=R<0>cHR03Xe7`0i=A`0>CDJ03Pd6@0h=1L203db7P80?S<O0`0o=2000`10=B40
>SDQ03Td800203Td80<0>3<O00<0=c8N03`d8@0l=2401P0l=24803/c80<0=cDP0P0f=1l303Dc7P05
03Lb700h<ad0>C@N03Xe7`0k=R000P0j=Al0100i=1h0>3<O03Pc7`0g<Qh203Ha7@0403Lb7P0h<al0
>C@P03`d7`<0>c<N0`0j<Qd0100i<A`0?3@O03Xb7@0i<A`303L_6P0303P`6`0i<A`0>c<N00L0>c<N
2`0k=1X303`e6`80?CHL1010=Qd203le70<0?S@K400o=A`8040f7@<0?S@K0P0o=A`;040f7@0304@j
8@13>B00@SPO00<0@SPO00<0@cTP04@j8@13>Ah00P14>Ql00`15>b00AS`Q04Lm8P0204Lm8P80ACXN
0P16>al304Ll800504Pm8@19>Al0BCTO04Xj801;>b400P1<?28204dm8`0404Pm8@19?R80BChR04Tn
8P<0BSlS2@1;@2@304ho8080Cd0Q0`1@@B80101B@b@0DD8S05118P1?@24204ho800304m08@1@@B80
CChO00L0CChO0P18?B4304Ll8080AS/O00@0ACXN04`o7`1<?al0CChO0P1??R00501B?b40DchQ05<n
8@1E@R@0ET<S05M4901HAB@0FTPT05]98`1LBR80GD/S05a89@1MBBH0H4XU06=;9@1VCBD0JDdU06]?
9`1]D2H0Ke8V0P1^DBD206e@900506mB9P1aE2P0LeHZ07EH;01jFb`00`1iFR/0101kG2d0O5d^07iO
<020HC8207iL;00307mM;@20GRh0PEl_0080PV0`0140Pf4a08YV=P2:ISH0RfLg08aX>02>JSX0Sf/k
091/?02AKCd0TVdi09=^>P2DKc/0UG0l09Mb?P2HLcl0VGA009Ye@@0209Ib?P0409Mc?`2HM400VGE1
09Ue@@80VWI20P2KN480102LND<0WGY409ikA@2NNdD209mlAP80XWm500@0XWm70:9oB@2ROdT0XWi:
0P2ROT`20:1mA`070:5nB02SP4X0Y85;0:F2C02VPdd0YhA>0:R5C`030:V6D080ZXMA0P2[R5880:b8
F080[8QD0P2]RED30:j:EP040:n;E`2aS5L0/8]F0:n:E@80[XUD00<0[hYE0;2;EP2aS5L0202`RU/3
0;:=F@80/HaH0`2`ReL30;2<F0<0[h]G0P2^RUH80:n:E@P0/8]G202^RED90:n9FPP0[hYF00@0/8YK
0:n9FP2_REX0[hUJ0P2^R5T20:f7F0<0[HQD0`2^RED20:n:EP030;>:EP2bRED0/HQD0080/8MC00<0
/HQD0;:9E@2cRUH00`2]R5@30:j9E@80[hYF202^RED80:f8E0P0ZhIA202/Qe<80:^6DPP0[HMJ202/
Qe830:j9E080[HQC0`2/Qe820:^6D@040:b7DP2]R5<0[HQC0:b7DP80ZhIA202/Qe<80:j9E@<0[8MC
0`2[QU820:Z5D@80ZhIB0P2/Qe<20:f8E080[XUE00<0[hUJ0:j8F@2^R5T00P2]QeP01P2/QUL0ZhEF
0:^5EP2ZQ5D0[8MC0:f8E0<0[XUE00@0[8MC0:^6DP2ZQE40ZHEA0P2ZQU801@2[Qe<0[8QD0:f9E@2]
RED0[XYF00P0[HQD0P2^RED30:n:EP030:f8E02ZQE40ZHA@0080Z8=>00@0ZHA?0:Z5D02ZQE00ZhIA
0P2/Qe880:j5D@<0ZhIA0P2/Qe830:f8D`080:b7D`2[QU80ZHA@0:R3C`2WPTh0Z8=?0:V4D02ZQE42
0:^5EP<0ZXAE00<0ZhEF0:f7F02^R5T00P2^RED20:f8E0<0[8MC00H0ZhIB0;:9E@2bRED0/HQD0;27
D`2_QU830:j5D@<0[8MC0P2]R5@30:j9E@P0[XQK00<0[hYF0:j9E@2/Qe<00P2[QU800`2/Qe<0[XUE
0:n:EP030:j9E@80[hYF0`2`ReL80:n:EP80[HY@00@0[HYB0:f:E02]RU@0[HUE0P2]REL80:n:EQ40
[XUE0`2`QU@30;67E@80/XQF0P2_RUH30:j9E@<0[HQD00H0/8]F0;2;E`2`ReL0[hUH0:n9FP2^R5/2
0:j7G0<0[HMH0`2^R5T20:n9FP<0[hYF0`2`ReL20;6<F0P0[hYF202^RE@20:j9DP060:f8D`2]R5@0
[8IE0:b6E`2[QEH0ZhEH0P2_RUD01`2^RE@0[HQC0:^6D@2ZQE00ZHA?0:R3CP2^RE@00P2^RED00`2^
R5L0[XQI0:j8F`020:j7G080[XUE00@0[HQD0:b7D`2/Qe<0[HQD0P2^RED01P2bQe`0/XMJ0;66F@2a
QeL0/HME0;27D`80/8MA00@0[XQI0:f7F02]QeP0[HMH0`2/QUL00`2[QEH0ZHA@0:Z5D@020:Z5D@80
ZhIB0P2/Qe<0202^Qe`0[hQM0;2:G@2`RU/0[hUH0:f8E02[QU80ZXE@202[QU820:V4D0040:Z5D@2[
QU80[8MC0:b7D`80[HQD0`2/Qe840:^6D@80ZXE@0`2[QU820:b7D`<0[HQD0P2^RED20:f8E080[8MC
0P2[QU830:j8F@80[HMH0`2/QUL30:b7D`<0ZhIB0`2ZQE401`2[QU80[8MC0:f8E02]R5@0[8MC0:^6
DP2ZQE400P2ZQ5D30:^5EP<0[8IG00P0ZhUK0:^9F@2/R5P0[8IE0:f5DP2^QE40[HA>0:j3CP80ZXIF
0`2YQED0102ZQUH0[8QH0:f9F@2_RUH20:j9E@050:f8E02/Qe<0ZhIB0:^6DP2ZQE400P2]QU/00`2]
QeX0[HMH0:f7EP020:f8E0030:f8D`2ZQE40ZXEA00H0ZXEA102[QEH40:Z4E@<0[8MC0`2[QU820:Z5
D@040:^6DP2ZQE40ZXEA0:Z5D@80ZHA@0P2XPdl20:b7D`<0[HQD00<0[8MC0:Z5D@2ZQE400P2/Qe80
102[QU40ZXE@0:Z5D02YQ4l20:R3CP80ZHA=00<0ZHA?0:V4D02YPe800P2YPe@0102YPeH0Z8A@0:V5
D@2ZQU820:^7D`090:Z6DP2YQE40Z8A@0:J2DP2XQ5@0ZXIF0:V5E@2VPU80YH5A0080Yh=C00@0ZXIF
0:R3C`2YQ500ZXEA0P2[QU801P2ZQE40ZHA@0:R3C`2ZQE00ZHA?0:R3CP80Yh9=00<0Z8=>0:Z5D02[
QU400`2YQ4l30:R3CP80Yh9=00@0XWa=0:=mCP2UOe00YX1A0`2WPE80102VP540Yh9>0:N2CP2VPDd2
0:F0C0030:AoB`2SOTX0Xgi:00P0Xgi:202QODT01P2UN4h0YGY?0:EjC`2TNdl0Xge@0:9mD080XGmA
00<0X7a80:5mB@2ROTX00`2ROTX00`2QODT0X7a80:=nBP020:=nBR_ooooo000Zooooo`80U6Pk0P2E
JC`0102FJSd0UFTl09EY?02EJC`809I/>P`0Uf/j102HK3/01P2IK480VFe009U]@02JKSl0VVhm09]`
?@80Vg0k0`2KKch209Y^?@/0VFdl00<0Uf`o09U^@@2KL4<00P2MLTD00`2KL4<0VFi109M/?`0309ic
@080WgA10`2PMD800`2QLd80Wg5009i`?`0309e_?P0309i`?`2OLD00XG=200P0WG=1202NM4820:9f
A@040:5eA02PM4<0X7A309mc@P80WW910P2PMD830:5f@`<0XWM400D0XGI30:9gA02RMd@0XgQ50:Ej
A`020:IkB00:0:MlB@2UO4P0Y7]70:=jAP2RNDD0XgY60:AkA`2VODT0Ygi:0:Aj?P80Y7Y000<0Y7U2
0:AiA02TNDH00P2TN4L00`2TNTP0YG]90:EkB@020:IlBP<0Yge;0P2VO4`0102VO4X0YWe90:MnBP2W
OTP20:MnAP<0YGa80`2TNdL20:=jAP80XWQ600@0XGM50:1fA02OMD<0WWA20P2MLd4209Ud@080V7<o
00@0Ug8n09Ia?@2FLCd0UG0l0P2DJSX0102CJCT0TVPh095W=`2AIcL2091V=P0508iU>@2=I3P0S6<g
08]R=P2:HCD00`29H3@01026HcT0Q64g085N=01nFc4407aI;`0607eJ<P1kF300NEH^07IC:`1eDRX0
M54Y0P1eDRX207AD;@0407=C;01bDR/0LU8[075A:P80L50Y0P1/CRX306]=:@<0JT`X101[BRL506Y9
9P80JdXW1P1ZBBH01@1XC2L0JDdX06Y<:01]C2T0KddZ0080LDd[00L0M4d/06m>9@1`CbH0LE0W07=B
:@1fEB`0N5L^0080NUT`0P1lEbd207eH;P0407iI;`1oFS00OeX`07mJ<0<0PUh^0P23Gbl308AP<0P0
Qf4b00<0Sf@g08iS=P2=HSD00P2;H3<01P2<HC@0SF8e08iS=P2;H3<0SF8e08iS=P<0T6Dh0P2>HcH8
08QR=@80R68c0P29Hc@208YT=@80RfDf0P28HS<308MQ<P<0QV0a2027HC8808MQ=0<0QV0c0P27HC@3
08QR=@P0Qf4b00<0R68c08US=029Hc@00P29Hc@308QR<`P0S64d202:I3D208]U=P80RV@e0P29Hc@3
08QR<`80RF<d1P28HS<808YT=@0808]T>@2:HcP0RF<f08MQ<P27HC00RF@`08YU<@2;IS4808QR<`P0
Qf4b0P26HS8308EQ<@<0Q60`2025Gc8608=N<@80Q5lb0`23GS43089M<080PE`_00<0Q5lb089M<020
Fbh00P1nFB`02020Fbh0PUd`08AO<P1mEbX0OUP[07eH:`1lFR`0O5`]0P1lGBh00`1kGbl0OE/^07eK
;P0207aJ;@@0NeT/00h0NULa07UF<01hEBl0Me@^07IC;@1eDR`0M54[07=@:P1eEBh0M5@]07=C;01a
DBX0L50Y06i>9`80K4`U01P0LE0W071>:01_CbP0K4hX06Y>:@1WCBX0IT`[06E=:`1UAb40I4HR0695
8`1OAB80G4@R05Y38`1I@R<0Ed8S05Dm9@1F?RH0E3hV05<o9P1A@2H0CShT04Xl8@19>b0204Tm8`<0
B3`R0`17>b4204Dk8P@0A3XQ0`13>B02048k8@80@CXP1010>Al2048h7`H0@cTP0P12=b<2044f8P@0
@3DQ200l=R0803`d7`<0>SDQ0P0i=20303Pc7`80?3LT00<0>cHR03Xe7`0i=A`00P0h=1T0100g<aH0
>c<N03/c7P0k<ah203`d7`<0?CDP100i=20403Pc7`P0?3@Q200k<b0303Td80<0>3<O0P0g<Qh203Pc
7@H0>C@N00P0?3LS03Xe8@0g<Qh0=C0L03@_6`0e<1`0=c8N03Pc7`@0>c<N100j<Qd00`0l=1l0>c<N
03Ta700203L_6P0303P`6`0i<A`0>S8M00P0>c<N200l=A/303/d6P<0?3DK0P0m=Q`903le7080@3HM
100o=A`203hd6`P0?cDL0`10=Qd403le700303hd6`0o=A`0?cDL00H0?cDL200n=1/8048h7`80@SPM
00@0@cTN04@j7`15>b00AS`Q0P17?B8204<j7@80A3/N0`15?1l01`16?B00ASPM04Li7P18>Ql0BC/P
04Xl8@1<?R<00P1=?b@804Tn8PP0BSlS0P1=?Ql204ho8080Cd0Q101@@B8204m08@@0CSlP201=?Ql0
0`19?R80B3dQ04Dj7P0204<h700904@i7@16>al0Ac`P04Xm7@1;?Qh0C3dN04dl7P1>?Al0D3dO0080
DSdP0140E44S05E28P1F@b<0Ed@S05U78`1JB280FdTQ05a:8P1KAb@0G4PU05m9901RBR@0ID`T06U=
9@1ZCRH0K4lU06]>8P0206a?8`0306e@901_DRH0L5<W00<0L5<W00H0Le@U07EF9`1hFBX0Ne`]07aM
;P1mGRl207aM;P80OU`/00@0Oed]081N;P21Gbl0PV0`0P23HC402026HS80Qf<c08UU=@2;IcL0SFTi
08m[>`2@K3`0TFdm0P2AK3P01P2CKSX0U6lk09Ia?@2HLcl0VGA009Ye@@80UW8n0P2GLcl02P2HM400
VGE109Ue@@2IMD40VGI009Yg@@2KN480W7U309ejA02OO4H20:1mA`80XWm500@0XWm70:9oB@2ROdT0
XWi:0P2ROT`01@2PODL0XGi80:5nB02ROdT0Y85;0080YH9<00<0YX==0:R5C`2XQDl00`2YQU030:Z7
D@P0[8QH0`2/R5@20:f9E@<0[XYF00<0/HaH0;2;E`2_RUH00P2^RED00`2`ReL0/HaH0;>>FP080;2:
F`@0/HaH102`ReL30;2<F0<0[h]G0P2^RUH80:n:EPP0/8]G202^RED90;2<G0P0[hYF0`2_REX20:j8
F@<0[HMH0`2]R5@30:j9E@80[hYF202`R5D30:f8E0<0[XUE0P2_RUH0102`ReL0[hYF0:n:EP2^RED2
0:f8E080[8MC202]R5@80:^6D@P0[8MC202[QU880:f7F0P0[8MB0P2^RE@30:f8D`<0[8MB0P2[QU84
0:b7D`80ZhIB202/Qe<80:j9E@<0[8IE0`2[QE@20:Z4D`80ZhIB0P2/Qe<20:f8E080[XUE0P2^R5T3
0:f7F080[8IG0P2[QEH30:j9E@050:n:EP2^RED0[XUE0:j9E@2]R5@00P2ZQU820:^7D`80[8QD0P2]
RED:0:f8E0070:j9E@2_RUH0[XUE0:f8E02[QU80ZHA@0:R3CP020:V4C`80ZXE@0P2[QU400`2/Qe80
[XEA0:j5D@060:j5D@80ZXE@0P2[QU420:b7DP80[HQC00P0ZhIB0:Z5D@2XPdl0Yh9>0:J1C@2WPTh0
Z8=?0:V4D0D0ZXAE00<0ZhEF0:b6E`2/QUL00P2]R5@20:b7D`@0ZhIB00H0]8]G0;>:EP2bRED0/HQD
0;27D`2^QE420:f4D0<0[8MC0`2]R5@20:j9E@P0[XQK00<0[hYF0:f8E02/Qe<00P2[QU800`2/Qe<0
[HQD0:n:EP030:j8E`80[hUH0`2`RUT80:n:EP80[HY@00@0[HYB0:f:E02]RU@0[HUE0P2]REL80:n:
EQ40[XUE0`2`QU@30;67E@80/XQF0P2_RUH30:j9E@<0[HQD00H0[hYE0:n:EP2_RUH0[hUH0:n9FP2_
RE`20:n8G@<0[HMF0`2^R5L20:n9F080/8]G1P2aS5P80:n:EPP0[XUE0P2^RE801P2]R5<0[HQD0:b6
E@2/QUL0ZhEF0:^5F080[hYF00L0[XUE0:f8E02/Qe<0ZhIB0:Z5D@2YQ500[XUD0080[XUE00<0[XQG
0:j8F@2^R5/00P2^Qe`20:j9E@@0[HQD0P2^RED01P2bQe`0/XMJ0;66F@2aQeL0/HME0;27D`80/8MA
102]QeP40:b6E`<0ZXEA0P2[QU830:b7D`080:j7G02_R5d0/8YM0;6;G02`RUT0[XUE0:b7D`2[QU48
0:^6DP80Z8=?00H0ZHA@0:^6DP2/Qe<0[HQD0:j9E@2_RUH20:b7DPL0ZhIA0P2[QU830:b7D`<0[HQD
0P2^RED20:f8E080[8MC0P2[QU820:n9F080[XQG0P2]QeH20:b6E@<0[8MC0`2[QU820:Z5D@<0ZhIB
0P2/Qe<30:^6DP80ZXAE0`2[QEH30:b6E`080:^9F`2[RET0[8QH0:f7EP2^QU<0[XEA0:j5C`2_Q4l2
0:^7E`H0ZXIF0P2^RED20:f8E080[8MC0P2[QU820:f6F`030:f7FP2]QeP0[HMF0080[HQD00<0[HQC
0:V4D02YQ5001P2YQ5020:^5E080ZXAC0P2YPe820:R2D@<0[8MC0`2[QU820:Z5D@80ZhIB0`2ZQE43
0:V4D0030:^6DP2/Qe<0[8MC0080[8MC0`2[QU800`2/Qe80ZhIA0:^6D@020:Z5D080ZHA?00H0Z8=>
0:V4C@2YQ4d0ZHA?0:V4D02YPe820:V3E0040:V3EP2WPdl0ZHEA0:Z6DP80ZhMC00L0ZXIB0:V5D@2W
Pdl0Yh=C0:R4E02YQED0Z8AD0080Yh=C0`2XQ5@00`2XPdl0ZHA@0:Z5D@020:b7D`060:Z5D@2YQ500
Z8=?0:b7DP2[QU40ZHA?0`2WPTd00`2XPdh0ZHA?0:R3C`050:R3C`80Yh9>00D0XWi>0:=oC`2TP500
YH5A0:J2DP030:N3D`80ZXEA00D0ZHA@0:N2CP2VPDd0YH1<0:AoB`090:=nBPP0XGe900H0YGU<0:Ai
C02TND`0XgY<0:9lC@2QODd20:1nCP0309mkA`2PO4P0X7a800@0X7a800@0Wg]70:9mB@2RODT0XWe9
:oooool002[ooooo0P2FJSd209EY?00409AX>`2EJC`0UFTl09EY?0P0Ufdk302HK3/409M[>P0609U/
@P2IKD00VFe009Y^?`2JKSd0Vg0m0P2KL3/309]_?P80VVhm2`2IKC`00`2HKD00VFi109aaA00209eb
A@0309aaA02IKT40V6e000<0WW=00P2OM4430:1e@P0309ib@@2MLD00W70o00<0VVhm00<0W70o09ea
@02NLT40202MLd4809id@P050:=gAP2RMTD0XWI50:5eA02PM4<00P2OLd80102NLT40XGI30:5f@`2Q
MT<30:9gA080XgQ50P2RMd@0102SN4D0Y7U60:AiAP2UNTL20:IkB0090:ElB02TNdL0XgY60:9iA@2S
NTH0Y7]70:ImB@2WOTX0Y7Xn0080Y7Y000<0Y7U20:AiA02TNDH00P2TN4L30:AjB080YG]90P2VO4X0
102WOD/0Yge=0:MmC@2WOD/20:MnBP030:MnB02WOTH0Ygi600<0YGa80`2TNdL20:=jAP80XGM500@0
X7I409me@`2OMD<0WWA20P2MLd4209Yd@`0609Uc@P2HLT40Ug5009I`?`2EKch0U6hm0P2CJ3/2099W
>P04095V>@2@ICP0Sf@g08mT=`80RV<h0P29HSL02028HCH0Qf0e08IO=025GS<0QF8h08=P=P20GC<0
OU/a101lFBl0101lFC40NUL_07QE;@1fDb/207AA:@80ME8Z0P1dE2d0101cDb`0LU8[075A:P1`D2T2
06m?:080K4hZ0`1[CBT306Y<:0l0JTTV0P1[BRL206U=:00?06]=:@1^CBX0L4h[079>;01cCbd0MDh]
075>9P1bCbL0M54Y07IC:`1hEBd0NUL_07aI<@1mFS80OUT_00@0OeX`0`20Fc4308=O;`80Q60`0`25
HC4808MQ<P0308iS=P2=HSD0S64d0080Rf0c00H0SF8e08iS=P2?I3L0Rf0c08eR=@2>HcH3091U>080
SV<f2028HSD408US=0@0RV@e0`28HS<308MQ<P80QV0a2027HC8808MQ=0<0QV0c0P27HC@308QR=@P0
Qf4b0`28HS<00`27HC80R68c08QR<`0208US=0P0S64d202:I3D208]U=P80RV@e0P29Hc@908QR<`80
RF<d202:I3D0202<ICX0RV<h08US=P28HS<0R68a08UT<02:IC40S6Lb2028HS<808MQ<P80QV8b0`25
HC4308AP<0P0Q5ha1@23GS43089M<0<0Peha0`22GC02085L;`0308AO<P22GC00P5/^0080OUT/00P0
P5/^089M<024Gc80OELZ07iH:`1mF2/0O5X/07aL;@80O5d^00@0Nel_07aI;`1lFBl0O5T_0P1kF2h2
07YG;@0Y07UF;01jEc40NEH`07QE;`1gE2h0ME8/07AA:`1cD2X0LTlY07AD;@1cDb`0LU8[071@:@1_
CbP0KDdV06a<9@1[Bb@0L4lV06m=9`1^CRL0JddW06U=:01VC2T0ID/Z06A<:P1RAR40HD@R05i48@1L
A280FT<S05I18P1E@2<0E44S058l901C?BD0DShU050o9@1??bD0C3hS04Ll8016>al00`18?28304Lk
8@80ASXP00<0AS`S04Dk8P15>b800P14>R4204<i8080@SPO0`12>b42044j8080@3TO00<0?cPN04<i
8013>B001013>B02048h7`80@CHR0`10=B4303ld80P0>cHP200l=1l303Td8080>3<O0`0g<Qh0200l
=b@0>cHS03/f8P0j=Al0>CDL03Te6P0h=1T0>3@G0P0i<ad203Xd7P80>cDO0P0l=R0403Pc7`@0>C@P
200l=24803/c8080>c@Q0`0j<b0303Tb7`80>C@N1P0h<ad0200m>2@0>cHR03Pc7`0e<1`0=2lK03D`
700f<Ad0>3<O100j<Qd403/c7P0803de800k<ah0>C4L03P`6`0g;aX0>30K03Ta700j<Qd803/c7PP0
?3DK0`0k=1X303`e6`80?CHL2@0o=A`00`11=ah0@3HM040f7@0203le7080?S@K00<0?C<J03le700o
=A`01P0o=A`3040f7@0303le700n=1/0?S@K0080?C<J200o=A`803dc6PP0@CLN0`12>1d00`13>Ah0
A3XO04Dk800204Dk8004040i7011>Qd0@CXM044j7@80@S/N0P13?1l204@i7@0604Dj7P17?200B3dQ
04Tn8P1:?b<0Bd0T1019?R8404Pm8@P0BSlS0`1=?Ql204ho80H0Cd0Q0P1>?b0204dn7`0304`m7P1=
?Ql0CChO00H0CChO00P0BSlS04Pm8@15>Qh0@cPL048g6`14>Ad0AS/O04Pm8@80BSdM00@0C3dN04dl
7P1=?1h0D3dO0P1A?1l04@1C@280E44Q05E28P1F@b80F4HR05U78@1JB200FdTQ05]7901LB2D0GdTT
069:901UC2@0JDdU06Y>9P1/CbD0JD`R0080JdhT00<0KU4W075D:P1cER`00`1dEbd0201dEBH0MePY
07]L;@1nGc00Of0a07eN;`1kG2d0NEX[0P20GRh01021Gbl0PV0`08=Q<@24HS8208ES<`0A08AP<025
HC40Qf<c08UU=@2<J3P0SVXj091/?02AKCd0SfXf091[=`2AK3P0Tfhj09E`?02GLSh0VGA009Ye@@2F
LSh0102GLcl309Qd@080VGI000H0VWM109ai@`2MNT@0WW]509mlAP2PODL20:5nA0040:5nAP2QOTP0
XGi80:5mB@80XGe;00D0X7e70:5nB02QOTP0XWm90:>0BP020:B1B`040:F2C02XQDl0Z8E?0:R5C`<0
ZHI@0P2ZQe480:^7E`80ZhMC0P2/R5@20:f9E@80[XYF00P0/H]J0;2:F@2_REP0[XQG0:n9F02aReX0
/heL0;B>G@P0/H]L202`ReL30;2<F0<0[h]G0P2^RUH80:n9F0P0/8]G202^RED90;2<G0P0[hYF0P2_
REX20:j8F@80[HMH0P2/QUL30:f8E0<0[XUE0P2_RUH20:f7EP@0[XQG0P2]QeH30:f8E0<0[XUE0P2_
RUH20;2;E`030:n:EP2^RED0[HQD0080[8MC00<0ZhIB0:f8E02]R5@01P2]R5@80:^6DA00ZhIB202]
QeH;0:f8D`<0[8MB0P2[QU480:^5E0P0[HQD202^RED30:b6E`<0ZhEF0P2ZQ5D20:^6DP80[8MC0P2]
R5@20:j9E@D0[HMH102/QUL00`2_RUH0[XUE0:j9E@020:j9E@<0[hYF102[Qe<40:b8E0P0[HQD00<0
ZhIB0:b7D`2]R5@00P2^RED00`2]R5@0ZhIB0:Z5D@020:V4C`@0ZXE@0P2[QU480:j5D@<0ZXE@0P2[
QU430:b7DP090:^6DP2ZQE40Z8=?0:N2CP2VPDd0Yh9>0:R3C`2YQ500ZH=D0080ZXAE00<0ZhEF0:b6
E`2/QUL00P2/QUL20:b7D`<0ZhIB0`2ZQE420;>:EP060;:9E@2aR5@0[hIB0:j5D@2]Q500[8=?0P2[
QU830:b7D`<0[HQD202^R5/00`2^RED0[HQD0:b7D`020:Z5D@030:b7D`2]R5@0[XUE00<0[XQI0P2_
REX30;2:F`P0[hYF0P2]RU00102]RU80[HYD0:f:E02]RED20:f9E`P0[hYF4@2^RED30;26E0<0/HME
0P2bR5H20:n:EP<0[XUE0`2]R5@01P2_RUD0[hYF0:n:EP2_REP0[hUJ0:n9G080[hQM0`2]R5@30:j9
E@80[hYF1P2aS5P20;2;E`P0[hYF202^R5L20:j9DP070:f8D`2]R5@0[8IE0:b6E`2[QEH0ZhEH0:n9
F0020:j8E`030:f7EP2/QUD0[8IE0080ZhED00H0[XUD0:j9E@2^RED0[XQG0:j8F@2^R5/20:j7G0P0
[XUE00H0/XML0;:7FP2aQUT0/HMG0;67E@2`Qe<20;27D@@0[8IG102]QeP20:Z5D@80ZhIB0P2/Qe<2
0:f8E0080:f6F`2^Qe`0[hUL0;2:F`2`RUT0[XUE0:f8E02[QU480:^6DP80Z8=?00H0ZHA@0:^6DP2/
Qe<0[HQD0:j9E@2_RUH70:^6D@80[8MB0`2/Qe<30:f8E0@0[XUE0P2]R5@20:b7D`80ZhIB0`2_RUH2
0:j9E@<0[HQD0`2/Qe<30:^6DP80ZXEA00<0[8MC0:^6DP2[QU80102[QU800`2/Qe<0ZXAE0:Z4E@03
0:^5EP<0[8IG00P0ZhUK0:Z8F02/R5P0[HMF0:n7E02_QU80[hI@0;25D0@0ZhMG0P2ZQUH00`2YQED0
Z8AD0:f8E0030:f8E0@0[8MC0P2]QU/00`2]QeX0[HMH0:f7EP020:f8E0030:f8D`2ZQE40ZXEA00X0
ZXEA102YQ5030:b7D`<0ZhIB0P2ZQE430:^6DP<0ZXEA0P2YQ5030:^6DP030:Z5D@2[QU80ZhIB0080
[8MC0P2[QU440:Z5D080ZHA?0P2YQ4d00`2YQ4l0ZHA@0:V3DP020:V3E0040:V3EP2WPdl0Z8A@0:V5
D@80ZhMC00<0ZHEA0:R4D02WPdl00P2XQ5@20:N3D`080:R4E02YQED0Z8AD0:R4E02WPe<0Z8=?0:Z5
D@2[QU820:b7D`080:^6DP2ZQE40Z8=?0:f8D`2/Qe80ZXE@0:N2C@2VPD`20:N2C@030:R3CP2WPE00
Yh5@00@0Yh5@0P2XPU430:B0D080YH5A00<0YX9B0:N3D`2XQ5@00P2ZQE40102YQ500Z8=?0:J1C@2U
P4`20:AoB`P0XWe9202PO4P01P2TN4T0XgU90:=iB@2SNdX0XG]:0:1lBP80Wgi;00<0Wg]709ijAP2N
NTH0102NNTH0102ONdL0XGa80:5lB02QO4P[ooooo`00:_ooool00`2GJch0UVXm09EY?00309AX>`80
UFTl202GKC/809Q/>`0409U]?02HK3/0V6`k09Q/>`<0Uf/j00L0UVXi09U/@P2IKD00VFe009Y^?`2J
KSd0Vg0m0080Vg0k0`2KKch209Y^?@/0VFdl0P2JKd80102KL4<0W75409aaA02KL4<209Y_@P<0WW=0
0P2OM4430:1e@P0309ec@@2LLT00VW0n00<0VFlm00<0VW0n09ab@02MLd40202MLd4809me@`80XWI5
0`2QMD@30:1d@`<0XGI30P2RMd@60:=hA@80Y7U60`2UNTL02@2UO4P0Y7]70:=jAP2RNDD0XgY60:Ak
A`2VODT0Ygi:0:Aj?P020:Aj@0030:Ai@P2TND@0Y7U60080Y7Q70100YG]90:AjB02TNTP0XgU70:Aj
B02UNdT0YWa:0:MmB`2YOdl0Z7i>0:QnC02XOd/0Ygi:0:MnB02WOTH0YWe50`2UO4P30:AkA`80XgY6
0P2QMdD00`2PMT@0WgE309id@P0209ec@@0709ab@02KMDH0VWA509UcA02HLT<0Ug5209E_@00209A^
?`0609=X?@2BIc`0TVLl095V>`2@ICX0Sf@i0P2>HcP208MR>080R6<i00P0Qf8h08EP=P23GS@0PUdc
089O=@21GS@0Oe`b07eJ<080O5T_00H0OEX`07iK<@1lFC40NUL_07QE;@1fDb/207EB:P0407IC:`1g
E2`0Le</07=C;080LU8[00@0LE4Z071@:@1_CbP0KdlX0P1/CRX306]=:@<0JT`X00@0J4LT06U89@1Y
B2D0JDPU101ZBBH00`1[BRL0JDPU06U89@0306Y99P<0JdXW0P1YCBP01P1[CBT0Kdh[075?;01cCbd0
M50^07M@;`80MU0Y00H0N58[07UC;01kEBh0OEL`07iH<@1oFC83081K<@D0PE`b0`24H30208EQ<@<0
QV8b2028HS<00`2=HSD0S64d08]P<`0208YO<P0608aQ=02>HcH0Sf@g08aQ=02=HSD0SV<f0P2?I3L0
0`2>HcH0S64d08]P<`0808QR=@@0RF<d102:I3D208US=080R68c0`27HC800`26H340R68c08QR<`06
08QR<`/0QV0c0P27HC@308QR=@80R68c1026H34308QR<`0708MQ<P26H340QV0a08MQ<P28HS<0RF<d
08YT=@0808eR=@P0RV@e0P2;ICH208YT=@80RF<d0`28HS<208MQ<P<0R68c0`29Hc@808YT=@0808aU
>P2;I3T0RF<f08QR<`28HS40RF@`08]V<P2<Ic8808QR<`P0Qf4b0P26HS8308EQ<@<0Q60`2024GS44
08AO<P80Peha0P22GC0308=N<@<0PUd`0P21G2l00`22GC00PE`_081K;P0207mJ;@03081K;P21G2l0
PUd`0080OeT/00<0OUT/07aJ;01lG2d00P1kG2d00`1iGBd0NUL_07YG;`0307]H<00<07YG;`1hEBd0
Me@/07UF<01hEBl0Me@^07IC;@1eDR`0M54[07=@:P1bCbT0Le</0P1bDR/07@1`D2T0KdlX06i>9`1]
CBH0K4`U06m>9@1^C2H0KDdV06Y<9P1XC2L0ID/X06A::@1SBbT0GdDR05m5901MAB<0FT<S05M28`1D
@B<0DclT0550901A?B@0DShU050o9@1@@2H0CT0U04Xo8`18?B40AC`O00<0B3`R0P17>b4304Hj8080
AS`S00@0AC/R04@j8@14>R40@cTP0`12>1l2044j80<0@S/Q00<0@CXP03lh7P0n=ad00P14>R4304<i
80<0@SPO0`10=B4203ld80<0?S<O200h=Ql803/c7P<0>3<O0P0g<Qh303Ha7@80>SDR00<0>SDQ03Xe
7`0j=Qd00P0j=Q/0100j=QT0>3<M03Pc7@0h<ad203Td7P<0>SDO00@0=c8N03Pc7`0h<al0>3<O0`0i
=2000`0j=B40?3@Q03`d8@0603`d8@P0>c<P0`0l=24203/c80<0>S8O00D0>SDO03Td7P0h<ad0=c8L
03Ha6`0203Lb700403Pc7@0k=R80>C@P03Pc7`D0=S4M00@0>C4L03Xb7@0j<Qd0>S8M0`0k<ah0100l
=1l0?CDP03`d7`0j<Qd203P`6`0303Ta700j<Qd0>c<N00P0>c<N200l=A/303/d6P<0?3DK0P0m=Q`4
03hd6`80?cDL0`10=Qd2044g7P04040f7@0o=A`0?cDL03hd6`80?C<J200o=A`01P11=ah0@3HM040f
7@0o=A`0?S@K03dc6P80?38I0`10=Qd203le70<0?S@K200m<aX00`0o=A`0@3HM044g7P03044g7P03
040f7@0o=A`0@cTN00H0@cTN00<0@SPM03lh6`10>A`00P10>A`2044j7@80@S/N0P14>ah204Dl7`04
04Hm8017?R40B3lR04Po8P<0BChR0P18?B4304Ll80P0BChR00@0C3dN04dn7`1=?Ql0CChO0P1>?b02
04m08@80CChO0`1>?b000`1=?Ql0Bc`M04Xk700804dn7`0304Xo8`19?R80AS/O0080A3TM00<0ACXN
04Ll8018?B400P1;?Qh0101<?Ah0CSdO04hm7`1A?R02058m800A058o8@1C@200E44Q05E28@1GAB40
F4HP05U77`1JB200FTHS05]7901OBB@0HDTS06A;8`1XC2@0JDdU06]>901YC2@00P1ZCBD03`1]D2P0
L5<[07=F;P1eF300MUTa07MJ<P1fEbP0N5TZ07]L;@1nGc00Of0a07eN;`1jFb`0N5TZ081N;P02085O
;`03089P<023HC40Q68b0080QF<c0100Pel_08AP<026HS80R6@d08YV=P2<J3P0SVXj08m[>`2=J3@0
SVTe091[=`2BKCT0UG0l09Mb?P2HLcl0VGA0202GLcl209Yg@@80VgQ200@0W7U309ejA02NNdD0WW]5
0P2QOT@0102QOTH0XGi80:5nB02QODT20:5mB`<0XGi80P2ROdT30:>0BP80YhA>0P2XQDl30:V6D003
0:Z7D@2[QeL0ZhMG00H0ZhMG0`2[Qe<20:b8E0<0[HUE0P2`RU/20:n9FP040;2:F`2aRe`0]8iO0;F?
H0P0/H]L00@0[XUE0:n:EP2_RUH0[hYF0`2`ReL0102aS5P0/8aH0;2<F02`S5P30:n;E`80[XYF202_
REX80;2;E`P0[HQD2@2]Re/80:n:EP<0[XQI0P2]QeP30:b6E`<0[HQD0`2^RED20:n:EP030:^7E`2/
R5P0[HUI00<0[HUI00<0[8QH0:^7E`2]R5@00P2]R5@30:j9E@80[hYF00@0/8]G0:n:EP2_RUH0[XUE
0P2]R5@20:b7D`P0[HQD202[QU4@0:^6DPP0[HQD2`2]R5<20:b7DP<0ZhIA00<0[8IG0:^5EP2ZQ5D0
0P2YPe@00`2ZQ5D0ZhEF0:b6E`080:f8E0P0[XUE0`2/QUT30:^5F080ZXAG0P2[QU820:b7D`80[HQD
0P2^RED50:f7F0@0[8IG0P2^RED01P2]R5@0[8MC0:f8E02^RED0[hYF0;2;E`@0ZhMC102/R5@80:f8
E0030:Z5D@2[QU80[HQD0080[XUE00<0[8MC0:^6DP2ZQE40202ZQE080:j5D@040:V4C`2ZQE00ZXE@
0:Z5D080ZhIA0P2/Qe80302/Qe<0ZhIB0:V4D02XPdl0Yh9>0:R3C`2YQ500ZXEA0:Z4E@2[QEH0[8IG
0:f7F080[XQI00<0[HMH0:b6E`2[QU800P2[QU820:Z5D@<0ZHA@0`2`Qe<00`2_QU80[XEA0:f4D002
0:b3C`<0ZhIB0P2/Qe<30:f8E0P0[XQK00<0[XUE0:f8E02[QU800P2ZQE400`2[QU80[HQD0:j9E@03
0:j8F`80[hUL0`2`RUd80:n:EP80[HY@00@0[HYB0:f:E02]RU@0[HUE0P2]REL80:n:EPT0[HQD202^
RED30;26E0<0/HME0P2bR5H20:n:EP<0[XUE0`2]R5@01P2^RE@0[XUE0:j9E@2_REP0[hUJ0;2:G@80
/8UN0`2]R5<30:j9E080[hYE0P2aS5P30;2;E`/0[hYF202^R5T20:j9DP070:f8D`2]R5@0[8IE0:b6
E`2[QEH0ZhEH0:n9FP020:j8F@80[HMH0`2/QUL01P2^RE@0[XUE0:j9E@2^R5L0[XQI0:j8F`80[XML
00<0[HQD0:j9E@2_RUH00P2`ReL02@2_RUH0[XUE0:f8E02bQe`0/XMJ0;66F@2aQeL0/HME0;27D`02
0;27D@040:^5EP2/QUL0[8IG0:b6E`<0[HMH00@0[XQI0:^6DP2[QU80ZhIB0P2/Qe<30:f8E0080:^4
F@2/QEX0[HMJ0:j8F@2^R5L0[HQD0:b7D`2[QU480:^6DP80ZHA@00@0ZXEA0:^6DP2/Qe<0[8MC0P2]
R5@20:Z5D0<0ZhIA102/Qe830:b7D`80[HQD1@2^RED20:f8E080[8MC0P2[QU80102`ReH0[hYE0:n:
E@2_RUD20:j9E080[HQC0`2/Qe<30:^6DP80ZXEA00<0[HQD0:b7D`2[QU800P2ZQE400`2[QU80[8MC
0:f8E0020:Z4E@<0ZhEF0`2/QUL0202ZR5X0ZXQH0:b8F02]QeH0[hMD0;27D`2`Qe40/HIA0P2ZQUH0
1P2[QeL0[8QH0:^7E`2ZQUH0ZHEE0:R4E0@0[HQD102/Qe<20:f6F`030:f7FP2]QeP0[HMF0080[HQD
00<0[HQC0:^6DP2[QU801P2[QU820:V4C`80ZXE@0P2[QU420:b7DP<0[8MC0`2[QU820:Z5D@80[8MC
0P2[QU830:Z5D@030:V4D02[QU80ZXEA0080ZHA@00@0ZXEA0:^6DP2/Qe<0[HQD202ZQE020:V4C@03
0:V4C`2YQ500ZH=B0080ZH=D00@0ZH=F0:N3C`2XQ500ZHEA0P2ZQU802@2YQE40Z8A@0:N3C`2ZQUH0
Yh=C0:F1D@2VPU80ZHEE0:Z6EP020:R4E0040:J2DP2YQ500ZXEA0:^6DP80[8MC00H0ZhIB0:Z5D@2Y
Q500[HQC0:^6D@2YQ4l30:N2C@030:R3CP2YQ4l0YX1A0080YX1A0`2WPE820:R2D`80YH=C102SPE40
0`2TPU80YH=C0:V4D0020:R3C`050:N2CP2VPDd0YH1<0:F0C02TOd/0202RODT80:1lB0060:=gAP2R
N4H0XWQ60:9jA`2PNdL0X7a80P2NODP00`2NNTH0WGU509ahA00309ahA00309eiA@2NNTH0X7]70080
X7]7:oooool002[ooooo00<0VFe009M[?P2EJC`00`2CIcX00`2DJ3/0UFTl09Q^?00709Q^?0X0VFdl
0P2HK3/209M[>P80UVXi00H0VFa209U]@02IKD00VVho09Y^?@2KL3d209]`>`<0Vfln0P2JKSd;09U]
?00309ebA@2LLD@0Vg130080VVm200<0Vg1309aaA02MLTD00`2NLd0209md@@<0X7E200<0Vg=009Yb
?`2ILCh00`2HL3d00`2ILCh0VW8o09]c@00809id@PP0WgE30P2PM4<30:5eA0<0XWI500@0XGI30:9g
A02RMd@0XWM40P2SN4D20:AiAP80XgQ5102TNDH20:EjA`090:ElB02TNdL0XgY60:9iA@2SNTH0Y7]7
0:ImB@2WOTX0Y7Xn0080Y7Y000<0Y7U20:AiA02TNDH00P2TN4L0202UNdT0Y7Y80:=iA`2RN4H0XgU7
0:AjB02VO4X0Z7i<0P2YOdl0102YOdd0Z7m;0:MnBP2WOTP20:ImA@<0YGa80`2TNdL20:=jAP060:5g
A@2PMT@0X7I409me@`2NM480WG=10P2LLT0209]eAP0709YdA@2HLT<0UW1109E_@02DKSl0Tfdn099W
?@02095V?003091U>`2?I3X0SV<i0080SF8h0P24HCL02@25HSP0QV<i08ER>023H3H0P5dc07mL<P20
GC<0Oe`b07eJ<00207aI;`0907eJ<01oG380P5dc07aI<@1kF300NEH^07MD;01fDb/0Me@/0080N5D]
0P1cDb`00`1bDR/0LE4Z071@:@0206m?:00306i>9`1/CRX0K4hZ00<0JddY0`1ZC2P306Q7900406U8
9@1ZBBH0JTTV06Y99P80JdXW0`1YB2D00`1ZBBH0JdXW06]:9`0206a;:00806U=:01ZCRT0K4hZ06m>
:`1bD2d0M50^07IB<01hDC0207YC;00407]D;@1lEBh0OEH_07iG<080OePa1@22GC<3085L<P0408AP
<025HC40QF4a08EQ<@80QV8b0P27Hc<808QR<`0:08]P<`2:Gc80REha08QM<029GS40Rf0c08eR=@2>
HcH0S64d08eR=@80SV<f00@0SF8e08]P<`29GS40R5d`2028HSD408YT=@L0RF<d0P28HS<308MQ<PP0
R68c2`26H3<208MQ=0<0R68e00<0RF<d08QR<`26H3400P25Gc000`26H340R68c08US=00208MQ<P80
QEl`00@0QV0a08MQ<P29Hc@0RfDf202?I3L808YT=@80RfDf0P2:I3D208US=0<0R68c0`27HC800`28
HS<0RF<d08US=00:08YT=@0808aU>P2;I3T0RV@g08US=029Hc80RVDa08]V<P2<Ic8808QR<`P0Qf4b
0P26HS8308EQ<@<0Q60`2023GC0208IQ=080QF0c0P24Gc8508=N<@<0PUd`0P21G2l207mJ;@04081K
;P21G2l0PE`_081K;P80OeX]0P20FRd00`1oFRd0OE/]07]K;00207YK;00307QL;01hEBl0NEH`00<0
NePb00<0NEH`07MD;P1fDbd00P1gE2h207IC;@0407EB;01dDB/0M54[07=@:P80LU8[0P1aDBX2071@
:@80KdlX00P0KTdT06i<9P1/C2D0JD/U06M;9P1TBRL0I4XY069::080GTHT00l0G4DU05Y3901G@RD0
ED4V05919@1A@2H0D3lU05509P1@@2H0Cd4V04e29P1;@2@0AchQ04Hm8018?2800`17>b4204Hj8080
ACTO00D0AcdT04Hl8`16?2<0AC/R04<i8002048h7`80@CLN00P0@3TO044j8012>b40@c`R048k8@11
>R00?cPN03hg7@<0A3XQ00<0@cTP048h7`12>1l00P11=ah303ld8080?S<O0`0m<Qh803Hf7PP0>c<N
00@0>3<O03Lb7P0g<Qh0=c8N0P0f<Ad203D`700803Lb7`0h<b00>3<O03Td7P0j=Qd0>cLL03`h7@0l
>1/403Hd7@80=cDN0P0h=Ql203Lb7P80>3<O0P0i=20203Xe8@P0?3@Q200k<b0203de8P80?3@Q0`0k
<b002@0j<Ql0>cHP03Xe7`0h<ad0=S4K03D`6P0f<A/0=c8L03Pc7@0203Lb7P0603Pc7`0i=200>3<O
03Lb7P0f<Ad0=C0L0P0i<A`203Xb7@80>c<N0P0l=1l01`0m=B00?3@O03Xb7@0i<A`0>30K03Ta700j
<Qd02@0k<ah803df70<0>c@J0`0l=A/203df7080?C<J0P0n=1/203le7080@3HM00H0@CLN048h7`11
=ah0@CLN040f7@0n=1/203dc6P0303`b6@0o=A`0?cDL00H0?cDL00D0@CLN040f7@10=Qd0?cDL03dc
6P0203`b6@0403/a6011=ah0@3HM040f7@80?cDL0P0n=1/00`0m<aX0?S@K03hd6`0703hd6`0703le
7010=Qd0@CLN044g7P10=Qd0?cDL03hd6`0204@j7`0304<i7P12>1d0@CLL0080@3HK00@0?cDJ03hi
6`0n>A/0?STK0P0o>Q`3040k7@@0@c`O1014?B0304Tn8P0304Pm8@17?200Ac`P0080AS/O2018?B42
04`m7P<0CChO0`1>?b000`1;?1d0C3dN04ho800204ho800304`m7P1:>a`0BCXK00P0CChO0P1:?b<0
1019?R80B3dQ04Ll8017?20204Pm8@80C3lO00@0CChO04ln801??R00DSlQ0P1C?R401P1B?b40DSlO
05=0801E@R40ET@P05Q68080FDLO00P0FTHS05]7901NB2<0HDTS06A;8`1XC2@0JDdU06]>90@0JddW
00d0K4hX06i@:P1`DR`0LeD_07AF<01aDR<0Le@U07MH:@1jFb`0Ne`]07aM;P1kG2d0NU//0080OE/[
00@0OU`/07mM;@20GRh0P5h^0P21Gbl208AP<00408EQ<@27Hc<0RFDe08YV=P80S6Ph00P0S6Lc08eX
=02?JSH0TF`h09A_>`2FLCd0V7<o09Ud@0@0Ug<o102FLSh409]h@P@0W7U30P2POD<0102PODD0X7e7
0:1mA`2PO4P20:1lBP<0XGi81@2ROdT30:N4CP80Z8E?0`2YQU080:Z6EP@0ZhMC0P2/R5@20:f9E@80
/8YK0P2_REX0102`RU/0/XaM0;B>G`2fT6480;6;G0<0[XUE00<0[hYF0;2;E`2`ReL00P2aS5P30;2<
F0<0[h]G0P2^RUH80:n9FPP0/8]G202]R5@90:^;FPP0[hYF0P2^R5T20:f7F0@0[8IG0`2]R5@30:j9
E@80[hYF00<0Z8IF0:V7E`2[RET00P2/RUX00`2[RET0ZHMG0:R6EP030:f8E0<0[XUE0P2_RUH50:j9
E@/0[HQD202[QU480:Z5D@P0ZhIB202]R5@80:j9E0040:f8D`2/Qe80[8MB0:b7DP80ZhIA0P2ZQE00
0`2/QUL0ZhEF0:V3E0020:R2D`030:V3E02[QEH0[8IG0100[XUE0`2/QEX30:^4F@80ZX=H0P2[QU82
0:b7D`80[HQD0P2^RED50:b6E`@0[HMH00<0[HQD0:b7D`2[QU800P2[QU800`2]R5@0[hYF0;2;E`04
0:b8E0@0ZhMC202]R5@00`2YQ500ZXEA0:b7D`020:f8E0030:b7D`2[QU80ZXEA00P0ZXE@202^QE42
0:V4C`<0ZXE@0`2[QU400`2^RED0[HQD0:^6DP030:V4D0050:Z5D@2[QU80ZhEF0:b6E`2^R5T00`2`
RU/00`2_REX0[XQI0:Z5D@020:Z5D@80ZHA@0`2XPdl40:f4D0@0[8=?0P2ZQE420:^6DP<0[8MC00<0
[HQD0:j8F`2^R5/01P2^R5/00`2]R5@0[8MC0:^6DP020:Z5D@030:^6DP2/Qe<0[HQD00<0[XML0P2_
R5d30;29GPP0[hYF0P2]RU00102]RU80[HYD0:f:E02]RED20:f9E`P0[hYF2@2]R5@80:j9E@<0/8ID
0`2aQeD20;:8EP80[hYF0`2^RED30:f8E0080:f8D`2^RED0[XUE0:n9F02_REX0/8YM0;29GP2aRUl3
0:f8D@<0[XUB0P2_RU<20;2;E`80[hYF00@0[XUE0:f8E02]R5@0[HQD202_RUH80:j8F@80[XUB00H0
[HQC0:f8E02/QUD0[8IG0:^5EP2[QEP40:j8F@@0[HMH00H0[XUD0:j9E@2^RED0[XQG0:j8F@2^R5/2
0:j7G0030:f8E02^RED0/8]G0080/HaH00T0/8]G0:j9E@2]R5@0/XML0;:7FP2aQUT0/HMG0;67E@2`
Qe<00P2`Qe420:^5EP80[8IG0P2]QeP20:j8F@80ZhIB0P2/Qe<40:f8E0080:R1EP2ZPeP0ZhEH0:b6
E`2]QeH0[8MC0:Z5D@2YQ4l?0:^6DP050:b7D`2ZQE00ZXE@0:Z5D02[QU400`2/Qe820:f8D`040:b7
D`2]R5@0[HQD0:f8E080[XUE0P2_RUH20:j9E@80[HQD0P2/Qe<20:^6DP80/8]D0`2_RU<30:j9DP<0
[8MC0`2[QU820:Z5D@030:f8E02/Qe<0ZXEA0080ZHA@00<0ZXEA0:b7D`2]R5@00P2ZQ5D30:^5EP<0
[8IG00/0ZXQJ0:Z8F02/R5P0[HMF0;28E@2aR5@0/HQB0;:7DP2XQ5@0ZHEE0:^7E`020:b8F0030:^7
E`2ZQUH0ZHEE00@0[8MC102]R5@20:f6F`030:f7FP2]QeP0[HMF0080[HQD00<0[HQC0:f8E02]R5@0
1P2]R5@0202XPd`0ZHA=0:Z5CP2[QTl0[HQA0:j9DP2_RU<0/8]D0`2/Qe<30:^6DP80ZXEA0`2/Qe<2
0:^6DPD0ZXEA0P2XPdl0102YQ500ZXEA0:b7D`2^RED80:Z5D080ZHA=00<0ZHA?0:V4D02YPe800P2Y
Pe@0102YPeH0YX9>0:N3C`2YQE420:Z6DP090:V5D@2WPdl0YX9>0:^7E`2WPe<0Y81@0:J2DP2ZQUH0
ZhMG0080Z8AD00@0YH5A0:V4D02ZQE40[8MC0P2]R5@01P2/Qe<0ZXEA0:V4D02[QU40ZXE@0:R3CP80
Yh9=00<0Z8=>0:V4C`2ZQE000P2UOe020:J0D@80Yh5B0P2XPU<0102XR5L0YXIE0:B4D`2RPU420:61
D0040::2D@2SPe80YX5=0:J1C@H0YH1<202QO4P809mkA`060:9fA@2QMdD0XGM50:5iAP2ONTH0Wg]7
0P2MO4L00`2NNTH0WGU509]g@`0209Yf@P0309]g@`2MNDD0WWY600<0WgY6:oooool002[ooooo00P0
VFe009Q/?`2EJC`0TfLj099V>@2CIcX0U6Pk09EY?0P0V6hl2`2IKC`00`2HK3/0Uf/j09IZ>@0209IZ
>@0609U/@P2IKD00VFe009Y^?`2JKSd0Vg0m0P2KL3/309]_?P80VVhm2`2IKC`00`2NLdH0WG9509Y_
@P0209Q]@00309Y_@P2MLTD0WW=600<0WW=00P2OM4430:1e@P0309]c@02JLSl0VG4n00<0Ufll00<0
VG4n09Yb?`2KLd00202NM48809me@`0509mc@P2PM4<0X7A30:5eA02RMTD00P2SMdH00`2TN4L0XWM4
0:9gA0020:9gA080XgQ50P2TNDH00`2SN4D0Y7U60:AiAP040:AiAP0:0:EjA`2UO4P0Y7]70:=jAP2R
NDD0XgY60:AkA`2VODT0Ygi:0:Aj?P80Y7Y000<0Y7U20:AiA02TNDH00P2TN4L00`2UNdT0Y7Y80:=i
A`020:9hAP030:AjB02VO4X0Z7i<0080ZX1@00@0ZGm=0:QoB`2XOd/0Ygi80P2VODD30:ElB0<0Y7]7
0P2SNTH20:1fA080WgE300`0WWA209ec@@2LLT00W79009afB@2KMDP0VWA709QbA@2FL4<0UFm209A^
@@2CKD02095V?080T6Dk00h0Sf@j08iS>@2=HSP0SF8h08=P>024HCT0QF8j08IS>`25HSX0PUlg081M
=@1nFc<0OU/a07eJ<0<0O5T_00T0OU/a081M<`21GS@0OEXb07aI<@1jEbl0N5D]07MD;01hEBd00P1i
ERh207=C;004079B:`1aDBX0L50Y06m?:080KThW0P1/CRX306]=:@<0JT`X0P1WAR<00`1XAb@0JDPU
06U89@0206Y99P80JdXW00@0J4LT06U89@1YB2D0JTTV0P1[BRL206a;:00806U=:01ZCRT0K4hZ071?
;01bD2d0ME4_07IB<01iDS4307aE;P80OEH_0`1nEc0308=N=0@0PUdc00@0PE`b08EQ<@25HC40QF4a
0P26HS8308MS<`P0R68c0P29GS401`28GC00Qe`_08QM<02:Gc80S64d08eR=@2<HC@00`2=HSD0102<
HC@0REha08ML;`25FRd808QR=@@0RV@e1`29Hc@308QR<`80Qf4b2028HS<;08IP<`80Qf4d0`28HSD0
0`29Hc@0R68c08IP<@0208EO<00;08IP<@28HS<0RF<d08MQ<P26H340QEl`08AN;`25Gc00Qf4b08YT
=@2;ICH0202@ICP808YT=@80RfDf0P2:I3D208US=0<0R68c00@0QV0a08MQ<P27HC80R68c0P29Hc@:
08YT=@0808eV>`2;I3T0RV@g08US=029Hc80RVDa08]V<P2=J3<808QR<`P0Qf4b0P26HS8308EQ<@<0
Q60`2023GC0208MR=@80QV4d00<0QF0c08AO<P24Gc801023GS43089M<080PE`_00<0OEP[07mJ;@21
G2l00P23GS402021G2l0OeX]07eH:`22G2l0PE/^081K;P1mFbd0Ne//0P1iFR/0101fFRX0N5D_07UF
<01jEc4207]H<P0307UF<01gE2h0ME8/00<0MU<]0`1eDR`207AA:`P0LE4Z0100KTdT06e;9@1/C2D0
JD/U06M;9P1TBRL0HdTX069::01OAbD0GTDV05a59@1IA2D0ET<U05=29P1B@BL0D40V0P1A@2H01P1A
@BL0D48W04e29P1:@B@0B3lR04Dn8@@0Ac/Q0P16>R0204Di7`80AcdT00@0AS`S04Dk8P13>B00@SPO
0`11=ah00`10>Al0@CXP048k8@0204<l8P04044j800o>1h0?CHL04Dk8P80A3XQ00<0@cTP048h7`12
>1l00P11=ah303ld8080?S<O0`0m<Qh803Hf7PP0>c<N0`0g<Qh203Ha7@<0=C0L0P0f<Ah01`0g<Qh0
>C@N03/g7P0l>1d0?CTN03hj7@0e<a`00`0f=1d203Le7P80>3HO0`0g<Qh00`0h<al0>C@P03Xe8@02
03Xe8@P0?3@Q200k<b0203ld8P80?S<Q100m<R000`0k=R00>SDO03Lb700303D`6P0503Lb700h<ad0
=2lK03Ha7@0h<al00P0j=B400`0i=200=S4M03D`700303Ta700303Xb7@0k<ah0?3@O0080?3@O00L0
?CDP03`d7`0j<Qd0>C4L03P`6`0i<A`0>S8M00T0>c<N200m=Q`303/d6P<0?3DK0P0m=Q`303dc6P04
03hd6`0o=A`0?cDL040f7@80@CLN0P12>1l01011=ah0@3HM03hd6`0m<aX203`b6@P0?cDL00H0@CLN
040f7@10=Qd0?S@K03dc6P0l<QT203/a6080@CLN00@0@3HM03le700o=A`0?S@K0P0m<aX803hd6`03
03dc6P0n=1/0@3HM0080@CLN00`0@3HM03hd6`0m<aX0AS`Q04Dk8014>Ql0@SPM044g700o=AX0?S@I
03dc600l>AX303dj6`80?S/L0P0o?1d304@m80<0@c`O0P12>ah304Tn8P0304Pm8@17?200AS/O0080
AS/O2018?B4304`m7P80CChO0`1>?b000`1;?1d0C3dN04dn7`0204ho800304`m7P1:>a`0B3TJ00P0
CChO1@1:?b<00`19?R80B3dQ04Ll800204e0800404ho801@?b40D3lQ05=08P80E3lR0140DChP058o
7`1C@200E44P05I4801GAAl0F4HN05U77`1JAR<0FdLT05i88`1QBB<0I4/S06Q<901YCBD0JdhT06e?
:@0206]=9`0<06Y<9P1YBbD0JD/U06]=9`1]CbT0Ke4[06]<7@1]CQl0LE8S07EF9`1hFBX0NU//0P1k
G2d207UG9`0307YH:01kFBT0O5XZ0080OE/[0140OU`/08AP<025HC40QF4a08MS<`28I3@0RFDe08YV
=P2;IcL0S6Lc08eX=02>JCD0TF`h09A_>`2FLCd0V7<o09Ud@00309Mc?`D0UW8n0`2LND<309]h@P80
VWM10P2POD<0102PODD0X7e70:1mA`2PO4P20:1lBP@0XGi8102ROdT30:N4CP<0Z8E?0P2YQU080:Z6
EP040:Z6DP2[Qe<0ZhMC0:^7D`80[8QD0P2]RED20;2:G@80[hUL00@0/8YM0;:<G`2eSf80]Y1S202a
Re`20:f8E0040:j9E@2_RUH0[hYF0;2;E`80/HaH0`2`S5P30:n;E`80[XYF202_RE`80;2;E`P0[HQD
2@2ZRUT80:n:EP80[XQI0P2]QeP30:b6E`040:^5EP2]R5@0[HQD0:f8E0<0[XUE0P2_RUH00`2WQEL0
ZHMI0:Z8FP020:b:G0030:Z8FP2YQeT0YhEG00<0[HQD0`2^RED20:n:EP80[HQD1P2^RED80:f8E0P0
ZhIA202ZQE480:^6DPP0[HQC202^RE@40:b7DP80ZhIA0P2ZQE000`2/QUT0ZhEH0:V3EP020:R2E@03
0:V3EP2[QEP0[8II0100[XUE0`2/QEX30:^4F@80ZX=H0P2[QU820:b7D`80[HQD0P2^RED50:b6E`@0
[HMH00P0[8MC0:^6DP2ZQE40ZHA@0:Z5D@2/Qe<0[XUE0;2;E`@0[8QD102[Qe<80:f8E0030:V4D02Z
QE40[8MC0080[HQD00<0[8MC0:^6DP2ZQE400P2[QU440:Z5D080ZHA?202^QE430:V4C`80ZXE@0`2[
QU400`2_RUH0[XUE0:b7D`030:Z5D@050:^6DP2/Qe<0[8IG0:j8F@2`RU/00P2bS5d00`2aRe`0/8YK
0:j8F@030:Z5D@80ZHA@0`2XPdl20:Z1C@<0Zh9>0`2/Pdl20:Z5D@80ZhIB102/Qe<80:j8F`030:f8
E02/Qe<0ZhIB0080ZHA@00<0ZhIB0:b7D`2]R5@00`2^Qe`20:n8G@<0/8UN202_RUH20:f:D0040:f:
DP2]RU@0[HYD0:f9E@80[HUG202_RUH90:f8E0P0[XUE0`2`QU@30;67E@80/XQF0P2_RUH30:j9E@<0
[HQD00H0[HQC0:f8E02^RED0[hUH0:n9FP2`RUd20;6:G`<0[HQA0`2^RE820:n:D`80[hYF0P2^RED0
102]R5@0[8MC0:b7D`2[QU880:n:EPP0[XQK0P2^RE801P2]R5<0[HQD0:b6E@2/QUL0ZhEF0:^5F0D0
[XQK0`2]QeX01P2^RE@0[XUE0:j9E@2^R5L0[XQI0:j8F`80[XML00<0[HQD0:j9E@2`ReL00P2aS5P0
2@2`ReL0[XUE0:f8E02bQe`0/XMJ0;66F@2aQeL0/HME0;27D`020;27D@<0ZhEF00<0[8IG0:f7F02^
R5T00P2^R5T20:^6DP80[8MC0`2]R5@02@2^RED0Yh1E0:R1EP2ZQ5L0ZhEF0:^5E02[QU80ZHA@0:R3
CP080:^6DP<0[8MC0`2[QU820:Z5D@040:V4C`2ZQE00ZXE@0:^6D@<0[8MB0P2]R5<40:f8E080[XUE
0P2_RUH20:j9E@80[HQD0P2/Qe<20:^6DP<0/8]D0P2_RU<30:j9DP<0[8MC0`2[QU820:Z5D@030:f8
E02/Qe<0ZXEA0080ZHA@00<0ZXEA0:b7D`2]R5@00P2ZQ5D30:^5EP<0[8IG0100ZXQJ0:Z8F02/R5P0
[XQG0;28E@2aR5@0/HQB0;:7DP2VPU80Z8AD0:Z6EP2/R5P0[HUI0:b8F02[QeL0ZXIF102/Qe<40:f8
E080[HIK00<0[HMJ0:f7F02]QeH00P2]R5@00`2]R5<0[XUE0:j9E@060:j9E@80Z8=<00@0ZXE>0:b7
D02^RE80/8]D0P2bSEH30:b7D`<0ZhIB0P2ZQE430:b7D`<0ZhIB0`2ZQE401`2YQ500Z8=?0:N2CP2X
Pdl0ZXEA0:f8E02^RED00P2YQ4l40:Z5D080ZhIA0P2YQ4d00`2YQ4l0ZHA@0:V3DP020:V3E0040:V3
EP2VPTh0Yh=?0:V5D@80ZXIB00T0ZHEA0:N3C`2VPTh0ZhMG0:N3D`2TP500YH5A0:Z6EP2/R5P00P2Y
QED0102TP500ZHA@0:Z5D@2/Qe<20:f8E0060:b7D`2ZQE40ZHA@0:Z5D02YQ4l0Z8=>0P2WPTd0102X
Pdh0ZXE@0:^6D@2TOU420:EoDP030:J0D`2WPE@0Yh5D0080Z89E00@0ZXYI0:R8E`2UQE@0XX9A0P2P
P4l00`2QPE00XX9A0:=nBP030:AoB`@0YH1<202QO4P809mkA`060:9gA02QN4@0XGQ40:5iA@2ONTD0
Wga60P2MO4H00`2NNTH0W7Q409Yf@P0209Ue@@0309Yf@P2LN4@0WWY600<0WgY6:oooool002[ooooo
0P2EJC`309IZ?@<0Uf/n202HKCX809U^@@P0VFa30P2EJSd00`2FJch0Uf`o09Q]@00209Y_@P0409]`
@`2LL4<0W71309]_@P80VVi100H0VFe009Q/?`2HK3l0V6`k09U]?02JKSd209]_?P0309U]?02GJcX0
UFTh00P0WG=10`2LLcd309ed?P80WWDo00<0XgE40:9d@`2PLT400`2OLD000`2PLT40XWA30:=eA003
09eb?`80W74n0`2KL3d209ic?00409ic?P2OM440WgA10:1d@`80X7A500<0XgM60:9fA@2PM4<00P2P
M4<01P2QMD@0XgM60:AhA`2TLT40YWA30:QfA@80ZWQ700<0ZGM60:QfA@2WMD@00`2SN4D20:AiAP<0
YGY70`2SN4D20:AiAP<0YGY70P2TNDH20:EjA`@0YW]8202VODT20:MnAP040:ImA`2UO4P0Y7]70:Aj
B080XgU901P0YX5=0:AoB`2RODT0WgY609iiA@2ONTH0X7]70:5lB02TNTP0XgU70:5gA@2OMD<0WG=1
09]a?`2IKcd0V6hl09A_>`2EL3`0UW4m09Mb?P2FLCd0UG0l09=^>P2BKCT208mS=0@0T6@e0P2AICH3
08IQ=`0308EP=P24GcD0Q5le0080Pehd00P0Oe`d07iK<`1lFC40NUL_07UF;P1jEbl0O5Ta07eJ<P<0
NE@Z0P1hDbT307MB:00807YA<@1iD300Me0_07A@;P1bD2d0L4l/06m>:`1]Cb/306m>:`80KTdZ0`1]
C2T906Y<:003071=9`1_C2H0KDXT00<0K4TS00H0KT/U06m<9P1eCb/0MDl[07I@;01gDBd207QB;P80
NE<_00T0N5<V07UD9`1jEBP0O5LZ07iI;020Fbh0PUd`08=N<@22GRh00`23Gbl208AP<080QF4a2028
HS<208]P<`80S64d0P2=HSD208iS=PP0R68c00<0Rf8^08aS;`2=I3000P2>IC400`2=I300S6<_08]R
;P0808QR=@0408=M;P25Gc00Qf4b08QR<`80RF<d00L0R68c08MQ<P27H3D0Qf0e08MQ=027HC80Qf4`
0080Qf8^00@0Qf8]08EO<026H340R68c0P29Hc@00`28HS<0QV0a08EO<00808IP<@80Qf8^0`28Hbl3
08UT<0P0RV@e0P29Hc801P29Hc@0R68e08QQ=P28HCP0Qf0g08MP>@P0RfDf202:I3L908]U=P0308YT
=@29Hc@0R68c0080QV0a00<0R68c08US=02:I3D0202>HcH208]U=P80RV@e0P29Hc@208QR<`80S6Lc
0P2;IS8408YU<@<0R68c0P27HC8308IP<@0808AQ:`25HBd0QV8^08MS<@26HS80QF0c08=N<P22GC42
08AN;`80QEl`00@0QV0a08MQ<P27HC80R68c2025Gc02081K;P04085L;`22GC00Peha08=N<@80Q5lb
0P1nG2h207eK;@80O5X/0P1kFB/507]H;P<0NUL]0300NET`07YJ<@1jFS40NUXa07UI<01gEbh0MED/
07=C:P1dE2d0Le</06mB:P1]DBT0Je8Y06]D:P1[ER/0K5L/06IE:P1XEB/0JeD/06eD;01^DR/0KdlY
06i<9`1]BBD0I4`V06=;9@1QBBD0GdLU05e49@1K@R@0FD0R05Pn8`1>?b00Cd0Q05918`1E@R@0Ed8U
05Q0901G?b<0EcdR05I2:@1E@BP0DT4W04lo9@1<?R<0BChR04Ll8016?B0304Tj8`<0B3TR0P17>24:
048k8@07044j800o>1h0?SLM03lh7P10>Al0@S/Q04@m8`0803lg8P0303/f8P0j=B40>SDQ0080>SDQ
0`0i=2000`0c<A`0=C<N03Hd7`0203Le800603Hd7`0e<ah0<c4L03@_6`0g<Qh0>SDQ0P0m>2@00`0j
=B40=c8N03@_6`0803Db7`0403D`700f<Ad0=S4M03Lb7P80>3<O0P0i=20203/`6P80?34K0`0m<Q`0
0`0n<ad0=S@O03Hd7`0603Hd7`<0>3<P0P0g<Ql303Ha7PP0>34N0P0j<b001P0h<al0=C<N038a700_
<A/0;S0J02da6P80>3HQ00<0=cDP03Hd7`0e<ah00P0c<A`0100b<1/0<bhJ03@_6`0f<Ad203Pc7`03
03Lb7P0f<Ad0=C0L00P0>C4L0P0l=1l203/c7P80>S8M0P0i<A`00`0n=R40?CDP03/c7P0203Xb7@03
03/c7P0m=B00?SHQ00<0>3HO0P0i=b0303Xh8@P0?CHL2@0n=ad303`e6`80?CHL0`0n=ad803le70T0
?SLM00L0?3DK03/d6P0j<aT0>S<I03/d6P0l=A/0?SLM00P0?3@O200o=A`8040i7`80?cDL00@0@3HM
044g7P13>B00A3XQ0P15>b8804@j7`80@cLM0P14>1h304Di7`<0ASXP0P17>b4304Pl8P0404Tm8`1>
?2@0CC/S04/i8@80BSPP00/0BcTQ04`j8P1=>b<0AC/H04Lm6P1:@1d0C48O04e3801<@Ql0Bd4N04To
7008054n7@06050j8P1?>b80C3/Q04Xl8@16?B00A3dP0P11?Ql02@1<?Ah0CChO04ho801>?b00CChO
04/l7@19>Q/0AcPI058m800205<n8@0305@o8P1E@2<0ET4T0080Ed8U0P1OAbD0101PB2@0H4PR065:
8@1QBR42069;8@0306Q<9`1YCBP0JDdX0080JThY00@0JdlZ06a@:`1]DB`0KE4/0P1`DR`02`1aE2`0
LeH/07AG:`1eFBX0MUX[07MK:`1hFBX0NEX[07aM;P1nGc00Of0a0080OUl`00<0OEh_08ES=@25HcD0
1025HcD208IT=P0608eY=@2>JSH0Sf/g08m[=`2@K3P0TFdi0P2BKSX00`2CKc/0U70l09Ib?P0309Qd
@00409Mc?`2FLSh0V7Do09Qe?`80VGI000D0VWM109]h@P2LND<0W7U309]g@`0209ahA00309eiA@2N
NTH0Wg]70080X7a800H0XGa?0:5mC@2QODd0XGe;0:5mB@2QOTP20:5nAP80YH1<00@0YX5=0:N2CP2X
Pdl0ZHA@0P2ZQE440:b8F080[HUI0P2^RUX20:n;F`030:j:FP2]RET0[8QH0080ZhMG00@0ZXIF0:f7
F02^R5T0/8YK0`2bS5d00`2aRe`0/8YK0;2;E`070;2;E`0>0;2<D02`S580/8]D0;2;EP2`RUT0/8YM
0;29GP2`RF00[X]E0:j:EP2_ReL0[h]I0:n;F`2`Reh20;2;G`P0/8]G0`2]RET20:j:FP<0[h]K202_
REX20;2<G080[h]K00<0[XYJ0:f9F@2]RET00P2/R5P20:^5EP80[8IG0P2]QeP20:j8F@80ZhEH0P2/
QUT20:f7FP80[XQK00<0[8MC0:f8E02_RUH00P2`ReL00`2_RUH0[HQD0:b7D`080:j9E@80[hUJ0`2^
R5T30:f7F0P0ZhEF202]R5@30:^6DP030:b7D`2]R5@0[XUE0080[XUE0P2ZQE430:^6DP<0[8MC0`2^
R5T20:f7F0<0[8IG00P0/8]G0:j9E@2/Qe<0ZhIB0:Z5D@2[QU80[8MC0:f8E080[XUB00h0[HQC0:f8
E02/QUD0[8IG0:^5EP2[QEP0[HQD0:b7D`2ZQE00ZHA=0:V5B`2[Qdd0[HU=0:j:CP80[8IG00@0ZhEF
0:Z4E@2ZQ5D0ZH=D0P2XPU<80:^5EP80[8II00@0[HMJ0:j8F`2`RUd0/H]N0P2bS5l30:b7D`<0ZhIB
0P2ZQE420:^1C`090:b2D02^Q580[hEC0;26E02aQeD0/XQF0:b8E02]RED0[XYF0080[h]G00@0[XYF
0:f9E@2[Qe<0ZXIB0P2[QU820:b7D`80[HQD0P2^RED30:f7F0D0[XQI202[QTl@0:^6DQ00ZXEA0`2_
QE<30:j4DP80[H=A102]R5@20:j9E@80[hYF00<0ZhIB0:Z5D@2ZQE40102ZQE40102YQ500[8=?0:b3
C`2/Pdl20:f4D0<0[XEA202[QU880:f8E0060:j3F02^PeH0[X=F0:j4E02^Q580[XEA0P2^QDl80:j7
G080[XQI0P2]QeP20:b6E`80ZhEF0`2^RE850:f8D@80[HMH00@0[XQI0:n9FP2_REX0/8YK0P2aRe`3
0:j8F`030:f7FP2/QUT0[8II00<0ZhEH202^R5T00`2]R5@0[XUE0;2;E`020;6<F0030;2;E`2^RED0
[HQD00<0/8]G0P2_RUH30:j9E@030:Z5D02/Qe80[HQC0080[hYE00H0[HQC0:b7DP2ZQE00/8]D0:n:
D`2]R5420:b7D0030:f8D@2_RU<0/8]D00<0[XUE00<0[HQD0:b7D`2[QU800P2[QU820:j9DP030:j9
E02^RED0[XQG0080[XQI00<0[XQK0:n;F`2_Re/0102^RUX20:f9F@<0[hYE00<0[XUD0:f8D`2]R5<0
0P2/Qe820:f8E080[8MC00@0ZhIB0:Z5D@2ZQE40ZHA@0P2[QU820:b7D`80[HQD0P2^RED80:^5EP04
0:Z4E@2[QEH0[HMH0:n9FP80/8YK00<0[hUJ0:j8F@2^RED01`2^RED80:b7DP80[HMH00@0[8IG0:^5
EP2YPe@0Z89C0P2WPE880:Z4E@P0[8MC00@0ZhIB0:Z5D@2ZQE40ZXEA0`2YQ5020:R3C`030:f7FP2^
R5/0/8YM0080/H]N00<0/8YM0:j8F`2]QeX01@2^R5T30:f7F080ZXEA0`2[QU830:b7D`060:^5F02[
QEH0ZhEF0:^5E02[QU80ZhIA0P2[QTl20:^7C@040:^6C`2[QU40ZhIA0:^6DP80ZhED00P0ZXEA0:^6
DP2]R5@0[XUE0:f8E02[QU80ZHA@0:R3C`d0[HUE0`2/R5@30:f8G080[XUM0`2_RUh00`2_REX0[XQI
0:j8F@020:j8F@<0[HMH1@2[QU830:b7D`P0ZHEE0P2^Qe`00`2^R5/0[HMH0:b6E@020:^6DP040:^6
D@2[QU80ZhIB0:^6DP80ZXEA0`2YQ5080:Z5D0<0ZHA@0P2ZQE430:^6DP060:b7D02[QTl0ZhI?0:Z5
CP2YQ4d0Z8=<0P2WPT/30:R3C`D0ZHA@2@2ZQE420:R2D`060:R2D@2XPdh0Z8A:0:R4AP2XQDD0Z8E3
0`2[QTl20:Z5CP<0ZHA=0`2WPE800`2VP540YGm@0:AnC`020:AnC`P0Y7m:0P2VPU802@2UPE40Y81@
0:=oC`2ROTh0XGe=0:1lC02NNd<0WGY209ai@@0209]h@00309ej@P2NNd<0X7e50080Xge>00<0XWa=
0:5kC02PNT/00P2ONDX00`2NN4T0VG=409UcA00209UcA0@0VWA500P0W7I509egAP2NN4L0WWQ709eg
AP2LMTD0VWA309Qb@@<0VGE3:oooool002[ooooo0P2EJC`309IZ?@<0Uf/n202HK3/809U^@@P0VFa3
0P2EJSd01`2FJch0Uf`o09Q]@02IKT40VVm209]`@`2LL4<00P2KKd8209Y^@@80VFe000T0V6`o09Q/
>`2IKC`0VVhm09]_?P2JKSd0VFdl09M[>P2FJST0202LLT0309ac?@<0WG@n0P2NMCl00`2SMD@0XWA3
0:1b@@0309ma@0030:1b@@2RM4<0XgE400<0WW=00`2MLSl209aa?P80WW<l00T0Wg@o09md@@2PMD80
X7A30:1dA@2QMDH0XgM60:9fA@2QMD@00P2PM4<02`2QMD@0XgM60:AhA`2SLd80Y7A30:IfA@2WMdH0
Z7Q70:MgAP2VMTD0YGE400P0Y7U60P2SN4D30:AiAP<0YGY70P2TNDH20:EjA`<0YW]800<0Yga90:Im
B@2VODT01P2VODT20:MnAP040:ImA`2VODT0YWe90:EkB@80YG];00@0YH1<0:AoB`2RODT0X7]70P2O
NTH0302PNdL0XGa80:9hAP2RN4H0X7I409me@`2MLd40Vg4o09Y`?P2IKcd0UG0l09Ia?@80Ug8n00@0
UW4m09A_>`2AK3P0T6/g102>I3@408mU=@80QV4g0P25H3H03024GcD0Pehd08=N=022GC<0OU/c07aI
<@1jEbl0NEH^07QE;@1iERh0NUL_07]H<0<0Me@Z0P1fDbT307EB:080NE0`00H0Me0_07A@;P1bD2d0
L4l/06m>:`1/CRX206m>:`<0KTdZ0`1]C2T906Y<:00306m<9P1^BbD0KDXT0080K4TS00<0KT/U071=
9`1aCRP00P1eCb/00`1fD2`0Me4]07QB;P0207UC;`0907YD<01hDbH0NE@W07]F:@1mF2/0OeX]085L
;`22GC00Peha00@0Pel_0P24H30208EQ<@P0R68c0P2;H3<208aQ=080SF8e0P2>HcH808QR<`0308YP
;P2<HS00SF<a0080SV@b00<0SF<a08aR<02:H2h02029HcH00`24GRl0QEl`08MQ<P0308US=00708QR
<`27HC80Qf0e08MP=@27HC@0Qf4b08MQ<00208MR;P0408MR;@25Gc00QV0a08QR<`80RF<d00<0R68c
08IP<@25Gc002026H34208MR;P<0R6<_0`29I30808YT=@80RF<b00H0RF<d08QR=@28HCH0R64h08MP
=`27H3T808]U=PP0RV@g2@2;ICH00`2:I3D0RF<d08QR<`0208MQ<P0308QR<`29Hc@0RV@e00P0SV<f
0P2;ICH208YT=@80RF<d0P28HS<208aW<`80RfHb0`2:IC401029I300R68c08QR<`28HS<208MQ<P<0
QV0a00P0Q64[08EQ;@26HRh0Qf<a08MS<`25H3<0Pehb089M<@80Q5h_0P25Gc001026H340Qf4b08MQ
<P27HC8808EO<0<0PE`_0P22GC0308=N<@80OU`^0P1mFbd207aJ;080NeT[101lFBl407]H;P80NET`
0P1jFS40301iFC00MeL^07EE;01cDbX0MED^07AD;@1`Db/0KE4Y06YA:01ZDbT0JUDZ06]F:`80IU<Y
00H0JE<Z06]B:P1]DBX0KThX06a:9@1[BB@2065;900>05m9901NAbD0G4DU05Y3901I@R<0F40T04m0
8@1@@B80DT4S05E2901G@RD0F40T05Hn8P1F?24205A09`0605509P1??bD0C3hS04Tn8P18?B40AchQ
0`19>R<304Pi8P80AcPQ2P12>b401`11>R00?cPN03hg7@0n=ad0@3TO044j8013?280200o=b8303/f
8P0303Xe8@0i=200>3<O0080>3<O00<0<c4L03Dc7P0f=1l00P0g=B001P0f=1l0=C<N03<a700e<1`0
=c8N03Xe8@80?3LS00<0>SDQ03Lb7P0e<1`0200e<Ql00`0e<1`0=S4M03Ha7@0203Lb7P80>3<O00@0
>C@P03Ta6P0i<AX0>C4J0P0j<Q/303/c70P0=S@O0`0h<b0203Lb7`<0=S4N200h<Ah01@0j<b00>C8O
03Pc7`0e<ah0<S4L0080;c4K00H0;C4J03Pf8@0g=B00=cDP03Hd7`0d<Qd203<a7004038`6`0c;QX0
=2lK03Ha7@80>3<O00<0=c8N03Ha7@0e<1`0200i<A`203`d7`80>c<N0P0j<Qd203Ta700303hf8@0m
=B00>c<N0080>S8M00<0>c<N03de800n=R400`0h=Ql203Tg80<0>SPQ200m=Q`903hg7@<0?3DK0P0m
=Q`303hg7@P0?cDL2@0n=ad01`0l=A/0>c@J03Xc6@0j<aT0>c@J03`e6`0n=ad0200l=1l803le70P0
?cPN00D0?S@K03le700o=A`0@3HM048h7`0204<i800304@j8@14>Ql0A3XO00H0A3XO0P14>1h204Di
7`H0ASXP0P17>b4404Pl8P0;04/k8P1:>R40BCTP04Ph7`19>B00BSXQ04`l8`1=?B@0AcdJ04Pn6`1:
@1d00`1;@Ah00`1:@1d0BClL054n7@07054n7@80Cc/R00P0Bc/Q04Xl8@16?B00A3dP048m7`11?Ql0
C3dN04dn7`80CSlP00@0CChO04/l7@19>Q/0AcPI0P1B?B000`1C?R40E3lR05E08`0205I1900905M2
9@1I@R80FT<Q05]48P1MAb80H4XS069<8`1SCR<0I4lT00<0J4`W00<0JDdX06Y>:@1[CbX00P1/D2/0
3@1]DB`0Ke4[071B;01aE2`0LUD[07AG:`1eFBX0MUX[07IJ:P1gF2T0N5TZ07YK;01lGBh00P1mGRl2
07aM;P@0Q68d1025HcD208eY=@0308iZ=P2?JcL0T6`h0080TFdi0P2BKSX00`2CKc/0UG4m09Mc?`02
09Qd@00309Mc?`2FLSh0Ug@n0080V7Do00<0VGI009Yg@@2KN4800P2LND<209]g@`0409ahA02MNDD0
WWY609mkA`80X7a800H0XGa?0:5mC@2QODd0XGe;0:5mB@2QOTP20:5nAP80YH1<00<0YX5=0:N2CP2X
Pdl00P2YQ5000`2ZQE40ZhMG0:b8F0020:b8F080[HUI0P2^RUX40:f9F@@0[8QH00<0[HMH0:j8F@2`
RU/00`2bS5d00`2aRe`0/8YK0;2;E`070;2;E`80/8aB00@0/8]D0;2;E`2`RUT0/8YM0P2`REh01P2^
ReD0[XYF0:j:EP2_ReT0[h]K0;2;GP80/8]O202`ReL30:f9F@80[XYJ0`2_Re/80:n9FP80/8aL0P2_
Re/01@2^RUX0[HUI0:b8F02/R5P0ZhMG0080ZhEF0P2/QUL20:f7F080[XQI0P2[QEH20:b6E`80[HMH
0P2^R5T00`2/Qe<0[HQD0:n:EP020;2;E`030:n:EP2]R5@0[8MC00P0[XUE0P2_REX30:j8F@<0[HMH
202[QEH80:f8E080ZhIB0P2/Qe<20:f8E080[XUE0P2ZQE430:^6DP<0[8MC0`2]QeP20:b6E`<0ZhEF
00P0/8]G0:j9E@2/Qe<0ZhIB0:Z5D@2[QU80[8MC0:f8E080[XUB00l0[HQC0:f8E02/QUD0[8IG0:^5
EP2[QEP0[HMF0:b7D`2ZQE40ZHA?0:V4C@2[Qdd0[8Q<0:j:CP2/QUL00P2[QEH20:Z4E@80ZH=D00<0
Z89C0:^5EP2[QEH01P2[QEH20:b6E`040:f7F02^R5T0[hUJ0;2:F`80/H]L0`2/Qe<30:^6DP80ZXEA
0P2/PU00102]Pe40[XAB0:n5D`2_QE<20;26E0030:b8E02]RED0[XYF0080[h]G00@0[XYF0:f9E@2[
Qe<0ZXIB0P2[QU820:b7D`80[HQD0P2^RED40:f7F0@0[XQI202[QTl@0:^6DQ00ZXEA0`2_QE<20:j4
DP<0[H=A00@0[8MC0:f8E02]R5@0[HQD0P2^RED20:n:EP80ZhIB102ZQE420:V4D0<0[8=?0P2]Q503
0:j5D@P0ZhIB202]R5@01P2^PeP0[X=F0:j3EP2^Q5@0[XAB0:j5D@80[XE?202^Qe`20:j8F@80[HMH
0P2/QUL20:^5EP80[hYC1P2^RE800`2]QeP0[XQI0:j8F@020:n9FP80/8YK00D0/H]L0:j8F@2^R5T0
[XQI0:f7F0030:b6E`80ZhEF202^R5T00`2]R5@0[XUE0;2;E`020;6<F0030;2;E`2^RED0[HQD0080
/8]G0`2_RUH30:j9E@030:^6D@2/Qe80[HQC0080[XUD00H0[HQC0:b7DP2[QU40/8]D0:n:D`2]R542
0:b7D0030:f8D@2_RU<0/8]D0080[XUE0P2]R5@20:b7D`80ZhIB0P2^RE800`2^RE@0[XUE0:j8E`02
0:j8F@030:j8F`2^RUX0[XYJ00@0[XYJ0P2]RET50:j9E0<0[HQC0P2]R5@20:b7D`80ZhIB0P2ZQE42
0:^6DP80[8MC0P2]R5@20:j9E@P0ZhEF00H0ZXAE0:b6E`2^R5T0[hUJ0;2:F`2_REX20:j8F@P0[XUE
202/Qe820:f7F0060:b6E`2[QEH0ZXAE0:V3E02XPU<0Yh5B202ZQ5D:0:b7D`80ZhIB0`2ZQE420:V4
D0030:f7F02^R5T0[hUJ0080/8YK00<0[hUJ0:j8F@2]QeP01P2^R5T20:f7F080ZXEA0`2[QU830:b7
D`060:^5F02[QEH0ZhEF0:^5E02[QU80ZhIA0P2[QTl20:^7C@040:^6C`2[QU40ZhIA0:^6DP80ZhED
0P2[QU830:f8E0030:^6DP2YQ500Z8=?00h0[HUE0P2/R5@50:j9G@<0[HQL0P2_REX20:j8F@040:f7
F02/QUL0[8IG0:^5EPP0ZhIB202YQED20:j7G0030:f7FP2]QeP0[8IE0080ZhIB00@0ZhIA0:^6DP2[
QU80ZhIB0P2ZQE430:V4D0P0ZXE@00@0Z8=?0:V4D02YQ500ZHA@0P2ZQE420:^6DP80[8M@0P2[QTl0
102ZQDh0ZHA=0:R3C02XPd`70:R3C`X0ZHA@0P2YPe@01P2YQ500ZHA?0:V4C@2YQDT0ZHE70:V6AP<0
ZXE>0P2YQ4d30:R3C0030:R2D`2WPE80Yh5B0080YX1A00<0YGm@0:AnC`2TOTl0202TOd/20:J2DP04
0:F1D@2TP500Xgm?0:9nCP80XGe=00T0Wga409ik@`2LND40VgQ009ai@@2MNT80WW]30:1mA@2PNT/0
0P2ONDX00`2NN4T0WGM809afA`0209]eAP@0V793102ILd@0202JM4<0VgE409afA@2MMdH0W7I509Yd
@`2HLT40Ug500`2GLd4[ooooo`00:_ooool209EY?0<0UVXm0`2GJch809Q/>`P0V6e0202IK4801P2E
JSd0UV/n09I[?P2GK3l0V6e009U^@@80VVm20`2KKd8209Y^@@<0VFe00P2IKC`309Y^?@0309U]?02G
JcX0UVXi00P0Vg4o0`2LLcl309ed@080WWE100<0X7A309mc@P2NLT400`2MLD000`2NLT40Wg=20:1d
@`030:1e@P80WgA10`2NLd0209md?@0409md?`2PMD80X7E20:5eA080XGE600<0XgM60:9fA@2QMD@0
0P2PM4<01P2QMD@0XWI50:=gAP2SLd80Y7A30:IfA@<0YgM60P2VMTD20:IkB0040:EjA`2TNDH0Y7U6
0:=hA@80XWM400@0XgQ50:AiAP2TNDH0Y7U60P2UNTL20:IkB0<0YGY70P2VNdP30:MlB@P0YWe90P2V
ODD0102VODL0Ygi:0:MnBP2WOD/20:QnCP040:AoB`2SOTX0XWe90:1kA`<0WgY600L0X7]70:1fA02P
MT@0WgE309id@P2MLd40W7900080Vg4o00P0UW4m09Mb?P2GLSh0UW4m09E`?02BKCT0SfXf08eX=0P0
SV<f0P26HCL01025H3H0Q5le08=N=022GC<2085L<P0407]H<01jEbl0NEH^07QE;@80Me@/00<0N5D]
07UF;P1fDb/00P1fDb/207EB:P<0M54Y0P1hCbl00`1fCbh0Ldl]075?;00206m>:`0306a>:P1_CR/0
KTdZ0080KTdZ0P1]C2T206a;:0T0JT`X00P0KDXT06a98`1/BB<0K4TS06i;9@1`CBL0LTlY07AA:`80
MU0[00<0Me4/07QB;@1iDbh00P1jE2l02@1kEC00NUDX07YE:01lEbX0OEP[07mJ;@21G2l0PUd`08=N
<@0308=O;`80Q60`0`25HC4808QR<`80Rf0c0P2<HC@208eR=@80SV<f2028HS<00`2:H2h0Rf4_08eS
<@0208iT<P0308eS<@2;HBl0RV0^00P0RV@g00P0QEl`08IP<@28HS<0RF<d08YT=@29Hc@0R68c08MQ
<P80R64f00<0R68e08QR<`28HS400P28Hbl01028Hbh0QV0a08MQ<P28HS<208US=00308QR<`27HC80
QV0a00P0QV0a0P27HRh308QS;`<0RF@`202:I3D208US<P0608US=028HSD0R64f08QQ>027H3L0Qf0i
202:I3D808YT=`X0RfDf00L0RV@e08QR<`27HC80Qf4b08QR<`2:I3D0RfDf00P0SF8e0P2;ICH208YT
=@80RF<d0P28HS<308]V<P80RVDa0`29I30308QR<`80Qf4b0`26H3402025HR`0QV8^08MS;`27Hc40
Qf<c08EP<`24Gc<0PUda0`25Gc0308IP<@80Qf4b2025Gc001023GS40PUd`089M<022GC04085L;`80
OU`^0P1mFbd207aJ;080NeT[0P1nFc4207eJ<0<0O5T_0140NeP^07QH;`1iFC00NET`07YJ<@1iFC00
MeL^07EE;01cDbX0MUH_07EE;P1`Db/0KE4Y06YA:01YDRP0J5<X06UD:@0206I@:@0606M?:@1XCRT0
JDdX06U;9`1YB2D0J4LT0P1OBB803P1NB2<0GDHT05a59@1KA2D0FT<T05Y29P1?@240D44R05=2901F
@bD0Ed8U05Lo8`1F?R80ES`Q0P1B?RD01P1@?bD0CShT04`n8`1:?b<0BChR04Po8P<0Ac/S0`16>R82
04Di8@X0@CXP00L0@3TO03lh7P0n=ad0?SLM03lh7P10>Al0@CXP00P0?SHQ0P0l=b<0100k=R80>SDQ
03Td800g<Qh203Ha7@0303<a700e<ah0=S@O0080=cDP00H0=S@O03Dc7P0c<A`0=C0L03Lb7P0i=202
03/f8P0303Td800g<Qh0=C0L00P0=C8O100f<Ad203Lb7P80>3<O0P0h<1/203Ta70<0>S8M00<0>c<N
03Dc7P0e<ah01P0e<ah303Lb7`80=S4N0`0e<1d803Lb7P80>C8O00H0=c8N03@b7@0c<Qd0<38L02la
6`0^<Q/203Le800303Hd7`0e<ah0=38M0080<c4L00@0<S0K03<^6P0d;a/0=S4M0P0h<al00`0g<Qh0
=S4M03D`700803Xb7@80?3@O0P0k<ah203Xb7@80>C4L00<0?CDP03`d7`0k<ah00P0j<Qd00`0k<ah0
?3@O03de800303Xe7`80>cHP0`0l=b4A03hg7@<0?3DK0P0m=Q`303hg7@P0?cDL2@0n=ad01`0l=A/0
>c@J03Xc6@0j<aT0>c@J03`e6`0n=ad0200l=1l803le70P0?CHL00D0?C<J03hd6`0n=1/0?cDL040f
7@02044g7P03048h7`13>Ah0@cTN00H0@cTN0P15>Al204Hj80<0Ac/Q00@0B3`R04Hj8016>R00ASXP
0P17>b4304Pl8P0>04Xj8@19>B00B3PO04Ph7`19>B00BSXQ04`l8`1>?RD0Bd0P04Xo7`19?Qh0B3dM
04Ll7018?Ad204Tn7PP0CShM00H0CC`R04`l8P1;>b40BS`Q04Ll8016?B0204<l7`0904`m7P1=?Ql0
CChO04dn7`1<?Ah0BS/L04Tj6`17>1T0D3dO0080DChP00<0DSlQ05=08P1D@B<00P1E@R@0201D?Ad0
ESlO05Q17`1KAB00GdTT069<9@1UCbH0IU0W0`1WBbH00`1XC2L0JDdX06Y>:@0206]?:P0<06a@:`1^
D2X0Ke4[071C:`1aE2X0LeHZ07AH:@1eFBX0METY07EF9`1fEbP0NEX[101kG2d00`1jFb`0PV0b089P
<P0208=Q<`80Q68d0P25HcD208aX=00308eY=@2>JSH0Sf/g0080T6`h0P2AKCT00`2BKSX0U70l09Ib
?P0309Mc?`0709Ib?P2FLcd0Ug@n09Md?P2HMCl0VGI009Yg@@0209]h@P80VgM300<0W7Q409eiA@2N
NTH00P2ONdL01`2PO4P0XGa?0:5mC@2QODd0XGe;0:5mB@2QOTP00P2QOTH20:F0C080YX5=00@0Yh9>
0:R3C`2YQ500ZHA@0`2[QeL20:b8F0<0[HUI0P2[QeL30:b8F0<0[HUI00<0[HMH0:j8F@2`RU/00`2b
S5d00`2aRe`0/8YK0;2;E`070;2;E`80/8]D00@0/8]F0;2;E`2`RUT0/8YK0P2`RUd01P2]RU@0[XYF
0:j:EP2^RUP0[h]K0:n:G@80/8]O202`ReL30:f9F@80[XYJ0`2_Re/80:n9FP070;2<G02_Re/0[h]K
0:n;F`2^RUX0[HUI0:b8F0020:^7E`80ZhEF0P2/QUL20:f7F080[XQI0P2[QEH20:b6E`80[HMH0P2^
R5T00`2/Qe<0[HQD0:j9E@020:n:EP030:j9E@2]R5@0[8MC00P0[XUE0P2_REX30:j8F@<0[HMH202/
QUL80:f8E0040:^6DP2/Qe<0[8MC0:b7D`<0[HQD00<0[XUE0:Z5D@2ZQE400`2[QU830:b7D`80[8IG
0P2[QEH20:Z4E@80ZH=D00P0/8]G0:j9E@2/Qe<0ZhIB0:Z5D@2[QU80[8MC0:f8E080[XUB00T0[HQC
0:f8E02/QUD0[8IG0:^5EP2[QEP0[HMF0:b6E@2[QU800P2ZQE000`2[QTl0[8Q>0:b8CP030:^5EP80
ZXAE0`2YPe@80:^5EP80[8IG0P2]QeP0102^R5T0[hUJ0;2:F`2`RU/30:b7D`<0ZhIB0P2ZQE470:j4
DP040:n5D`2/R5@0[HUE0:j:EP80[h]G00@0[XYF0:f9E@2[Qe<0ZXIB0P2[QU820:b7D`80[HQD0P2^
RED80:f7F0P0ZhIA402[QU8@0:Z5D@80[hEC0P2^Q5830:f3D@040:b2D02/Qe<0[8MC0:b7D`80[HQD
0`2^RED30:^6DP80ZXEA0`2YQ5030:b3C`80[HA@0`2^QE480:^6DPP0[HQD00H0[X=H0:j3EP2^PeH0
[XAD0:j4DP2^QE420:j5C`P0[HMJ0P2^R5T20:f7F080[8IG0P2[QEH80;2;EP<0[XQI0P2_REX30;2:
F`<0[XQI0`2]QeP30:b6E`P0[XQI00<0[HQD0:j9E@2`ReL00P2aS5P0102`ReL0[XUE0:f8E02`ReL3
0:n:EP80[XUE0P2]R5@00`2[QU40[8MB0:f8D`020:j9E0060:f8D`2/Qe80ZhIA0;2;EP2_RUD0[XUD
0P2]R5<0102^RE@0[hYE0;2;EP2^RED30:f8E0<0[8MC00H0ZhIB0:j9DP2^RE80[XUD0:j9E@2^R5L2
0:j8F@030:j8F`2]RET0[HUI00<0[HUI0`2^RUX30:f8D`@0[XUD00<0[hYE0:f8E02]R5@00`2/Qe<5
0:^6DP80[8MC0P2]R5@20:j9E@P0[8IG00P0ZhEF0:b6E`2^R5T0[hUJ0;2:F`2_REX0[XQI0:f7F0P0
[HQD202/Qe820:f7F0030:b6E`2[QEH0ZXAE0080ZH=D00<0Z89C0:^5EP2[QEH01P2[QEH80:b7D`<0
[HQD0P2/Qe<40:^6DP030:b6E`2]QeP0[hUJ0080/8YK00<0[hUJ0:f7F02/QUL0202^R5T20:Z5D@<0
ZhIB0`2/Qe<01P2[QEP0ZhEF0:^5EP2[QE@0ZhIB0:^6D@80ZhI?0P2[Qdd0102[QTl0ZhIA0:^6D@2[
QU820:^5E0080:^6DP2/Qe<0[8MC0:f8E02/Qe<0ZhIB0:Z5D@2YQ5080:b8E0P0[HUE0P2_RUd0102^
RE`0[HQK0:b7FP2/QeX20:^6F@080;2:F`2_REX0[XQI0:f7F02/QUL0ZhEF0:Z4E@2YPe@80:^6DPP0
ZHEE0P2]QU/00`2]QeX0[8IG0:b6E@020:^6DP040:^6D@2[QU80ZhIB0:^6DP80ZXEA0`2YQ5080:V4
C`<0Z8=?0P2YQ5030:Z5D@80[HQC00<0[8MB0:^6D@2ZQE000P2YQ4l00`2XPdh0Yh9>0:N2CP060:N2
CPT0Z8=?00@0ZH=D0:V3DP2YQ500ZHA@0P2YQ4d0102YQD/0ZHE90:V4C`2YQ4l30:R3CP<0Yh9=0`2W
PE820:J0D@<0YGm@202TOd/20:F1D@80Y81@00L0Xgm?0:9nCP2QODd0XGe=09mlAP2NNdD0WGY40080
W7U300@0WGY409ikA@2OO4H0WGM80P2LMTL00`2KMDH0VWA509UcA00209Qb@`0309Ma@P2FL440UW11
00D0UW1100P0Ug5209Qb@`2ILd@0VWA509UcA02HLT<0UW1109E_@0<0UG51:oooool002[ooooo0P2E
JC`309IZ?@<0Uf/n202HK3d809Q]@0P0VFe00P2FJch209M/?`0409Q]@02IKT40VFi109U^@@P0VVi1
0`2JKSd209U]?080V6`k00<0Uf/j09Y`?P2JL3h01P2JL3h309ab@0<0WG=10P2NM4800`2OMD<0WWA2
09ab@00309]a?`0309ab@02NM480WgE30080XWM40P2QMT<30:1e@P0409md@@2PMCh0X7Dn0:1e@080
XGI300H0XWI50:9fA`2RMTL0Y7Q70:=gAP2QMD@30:1d@`80XWI500<0XgE30:AfA02TMT@00P2UMdD3
0:IhAP80Yga900@0YW]80:EjA`2SN4D0XWM40P2QMT<30:AiAP80YGY70`2VNdP20:EjA`<0YW]80`2W
O4T80:MnBP0<0:ElA02VODD0YWe70:MnBP2XOd/0ZGm=0:UoC`2ZP500Xgi:0:9mB@2QO4P0X7]70P2O
NTH209iiA@<0WWA20P2MLd4309ab@0<0Ug8n00D0UW4m09=^>P2@JcL0SFPd08]V<P0208eT>0@0S6<g
0P2;HSH02@26HCL0QF0f08EP=P23GS@0PUdc085L<P20Fc40OeX`07UF;P0207QE;@0307MD;01fDb/0
MU<[0080MU<[0`1dDR`307=A:`80LU0Z0P1fCBd01P1eCRd0LTh/071>:`1_CR/0KTdZ06a>:P<0KTdZ
0P1]C2T306a;:0T0JddY0`1/BB<01@1]BR@0Kd`V079?:@1eDR`0Me@^0080Me4Z00@0N58[07UC;01j
E2d0NU@]0P1kEBh01P1kERT0O5LZ07eH:`1nFB`0P5/^089M<080Peha0P23Gbl208AP<080QF4a0P26
HS8808QR<`80Rf0c0P2<HC@208eR=@80SV<f2028HS<00`2:H300Rf4a08aR<P0208eS<`0308aR<P2;
HC40RV0`00P0RV@g00<0QV0a08MQ<P29Hc@00P2:I3D00`29Hc@0R68c08MQ<P0208QQ=P0308QR=@28
HS<0R68a0080R6<_00@0R6<^08IP<@27HC80RF<d0P2:I3D00`29Hc@0Qf4b08IP<@0808MQ<P80Qf8^
0`28Hbl308UT<0P0RV@e0P29Hc801P29Hc@0R68e08QQ=P28HCP0Qf0g08MP>@P0RV@e202:I3L:08]U
=P0708YT=@29Hc@0Qf4b08MQ<P29Hc@0RV@e08]U=P0808eR=@80RfDf0P2:I3D208US=080R68c0P2;
IS8308YU<@<0RF@`0`28HS<208MQ<P<0QV0a00P0QF8/08IR;P27Hbl0R6@b08MS<`26HC@0Q5lc08=N
<P80QEl`1P26H34808EO<00608AO<P23GS40Peha089M<021G2l0P5/^0P1oFRd207iL;P80OE/]0P1l
FR`207]I:`80Oe`b0P1nFc401P1mFS00O5T_07aI;`1kF2h0MeL^07QH;`80NET`00X0N5P_07MG;P1e
EB`0M5@[07MG<01eEBh0LE@/06eA:@1YD2L0Ie0V0P1WDRL306I<:@0506E;:01VBBL0IDPV06A79@1S
AR@00P1KB2000`1KAb80FTHS05Y69@0205U49@0905U49`1@@B80DD8S05=2901F@bD0ET4T05Lo8`1E
?B40EC/P0080D3`S00<0CSdS04dm8`1<?R<00P1:?b<01019@2<0AS`S04Hl8`16?2<304Dk8P80A3XQ
2@11>R02040i7`0303lh7P0n=ad0?SLM00<0?SLM200m=B001P0m>2@0?3LS03/f8P0j=B40>3<O03Lb
7P80=C0L00<0<c4L03Dc7P0f=1l00P0g=B001P0f=1l0=C<N03<a700e<1`0=c8N03Pc7`80>SDQ00<0
>3<O03Lb7P0e<1`0200d<Ah603Ha7@80=c8N0P0f;a`203L`7@<0>34N00<0>C8O03@b7@0d<Qd01P0d
<Qd303Ha7P<0=C0M0P0d;a`803@b7@0503Tb7`0h<Ah0=c8N03@b7@0c<Qd00P0`<Q`00`0^<Q/0=S@O
03Hd7`0203Dc7P0703@b7@0c<A`0<c4L03<a700c;QX0=2lK03Ha7@0203Pc7`0303Lb7P0f<Ad0=C0L
00P0>S8M0P0l=1l203/c7P80>S8M0P0i<A`303`d7`80>c<N0`0l=1l303/e7`80?3HP0`0m=b4A03hg
7@<0?3DK0P0m=Q`303hg7@P0?cDL2@0n=ad01`0l=A/0>c@J03Xc6@0j<aT0>c@J03`e6`0n=ad0200l
=1l803le70P0>c@J0P0m<aX203hd6`80?cDL0P10=Qd8048h7@<0ASXP0P17>b4304Pl8P80ACTO0P16
>R0204Lk8@80B3`R00/0B3XP04Li7`16>1h0ASPN04Li7`19>b40BcdS04do9@1=@R@0Bd0R04Pm7`03
04Dj700304Ll7P19?R00C3dN00L0C3dN0P1;?B80101:?240B3dQ04Ll8017?20204Dl7`80CChO0P1<
?Ah01@1;?1d0BS/L04Tj6`18>AX0CC`N0080CSdO00<0CchP050o8@1A@2800P1B@B<0201B?Ah0DchO
05E1801HA240FdLR05i:9@1PCBD0HDhT0`1VBRD206M;9P0406Q<9`1YCBP0JThY06Y>:@80KDlY00X0
KU4Y071C:@1aE2P0LeLX07AH:@1dF2P0Le@U07EF9`1gF2T0NEX[0P1jFb`01P1iFR/0N5TZ081N<020
GS00PEla089P<P80Pf4c0P24HS@208]W<`80S6Pd00<0SFTe08iZ=P2?JcL00P2?JcL00`2AKCT0Tflk
09Ea?@0209Mc?`80UW8n0P2FLcd209Md?P0509Qe?`2IMT00VWM109Yg@@2JMT800P2KMd<00`2LN4@0
WGU509ijAP0209mkA`060:5lC`2QODd0XGe=0:5mB`2QODT0XGi80P2QOTH20:AoB`040:F0C02VPDd0
Yh9>0:R3C`80ZHA@0`2[QeL30:b8F080[HUI00H0ZHEE0:Z6EP2ZQUH0ZhMG0:b8F02]RET20:j:FP03
0:f7F02^R5T0/8YK00<0/XaM00<0/H]L0;2:F`2`ReL01`2`ReL0102`ReH0/8]G0;2;E`2`ReL40;2:
F@060:f:E02]RED0[XYF0:j:F02^RUX0[hYM0P2_RUh80:n:EP<0[HUI0P2^RUX30:n;F`P0[hUJ0P2_
Re/20:j:FP80[HUI00<0[8QH0:^7E`2[QeL00P2[QEH20:b6E`80[HMH0P2^R5T20:^5E080[8IE0P2]
QeH20:j8E`030:f8E02^RED0[XUE00@0[XUE00<0[HQD0:j9E@2^RED01P2^RED20:n9FP<0[XQI0`2]
QeP80:b6E`P0[HQD102/Qe<40:f8E080ZXEA0`2[QU830:b7D`040:^5EP2ZQ5D0ZXAE0:Z4E@80ZH=D
0P2XPU<0202`ReL0[XUE0:b7D`2[QU80ZXEA0:^6DP2/Qe<0[HQD0P2^RE802P2]R5<0[HQD0:b6E@2/
QUL0ZhEF0:^5F02]QeP0[8IG0:b6E@2[QU820:^6D@030:^6C`2[Qdd0ZXAE00L0ZXAE202[QEH00`2[
QE@0[8IE0:b6E@020:f7EP80[XQG00@0[hUH0:b7D`2/Qe<0[8MC0`2[QU820:Z5D@<0[hEC0`2^Q582
0:f3D@030:b8E02]RED0[XYF0080[h]G00@0[XYF0:f9E@2[Qe<0ZXIB0P2[QU820:b7D`80[HQD0P2^
RED00`2^R5T0[HMH0:f7F0020:f7F0<0[8IG602[QU8@0:Z5D@<0[XAB0`2]Pe420:b2D0<0[8MC0`2]
R5@20:j9E@80[8MC00@0ZhIB0:Z5D@2ZQE40ZHA@0P2XPdl30:b3C`80[HA@0`2^QE480:^6DPP0[HQD
00H0[X=H0:j3EP2^PeH0[XAD0:j4DP2^QE420:j5C`P0[HMH0P2^R5T20:f7F080[8IG0P2[QEH30;2;
E`@0/HaH00<0/XeI0:n9FP2_REX01P2_REX40:j8E`D0[HMF202^R5T00`2]R5@0[XUE0;2;E`020;6<
F0030;2;E`2^RED0[HQD00<0[hYF0P2^RED30:f8E080[8MB102]R5<20:b7DP<0[hYF0P2^RED30:n:
EP@0[HQD102/Qe<20:j9DP030:j9E02^RED0[XQG0080[XQI00<0[XQK0:b8F02/R5P0102]RET20:j:
FP050:b7DP2]R5<0[HQC0:f8D`2^RE@00`2_RUD20:f8E0H0[8MC0P2[QU820:b7D`80[HQD0P2^RED9
0:b6E`070:f7F02^R5T0[hUJ0;2:F`2_REX0[HMH0:b6E`080:f8E0P0[8MB00<0[HMH0:b6E`2/QUL0
0P2[QEH20:Z4E@030:V3E02[QEH0ZhEF00H0ZhEF202/Qe<30:j9E@80[HQD102/Qe<00`2[QE@0[8IE
0:j8E`020:n9F0030:j8E`2/QUD0ZhED00<0[HMH102^R5T00`2_REX0ZXEA0:Z5D@030:^6DP<0[8MC
00H0ZhEH0:^5EP2[QEH0ZhED0:^6DP2[QU420:^6C`80ZhM=00@0ZhI?0:^6D@2[QU40ZhIB0P2[QE@4
0:b7D`80ZhIB0P2ZQE4;0:b8E0@0[HUE00L0[XYF0:n;F`2_Re/0[XYJ0:f9F@2[QeL0ZXIF0080ZHEE
00H0/8YK0:n9FP2^R5T0[8IG0:^5EP2ZQ5D20:R2D`<0ZhIB102ZQE400`2YQ500ZHEE0:V5E@060:V5
E@80[8EJ00<0[8II0:b6E`2[QE@00P2[QU80102[QU40ZhIB0:^6DP2[QU820:Z5D@<0ZHA@202XPdh3
0:N2CP80Z8=?0`2YQ5020:f8E080[8MC00D0ZhIB0:Z5D@2YQ500ZHA@0:N2CP040:J1C@<0YH1<2@2W
PTh20:V3DP<0ZHA@0`2YQ4l30:N2CP80YX5=0`2UP4`20:J0D@H0YGm@202SOD`00`2TP500Xgm?0:=o
C`020:9nCP80XGe=00@0X7a<09mkA`2NNTH0W7Q40P2KMd<00`2LN4@0WGU509ijAP0209afA`0409]e
AP2JM4D0VG=409UcA080V79300<0UFm009A^?`2DKSl00P2DKSl309=]?P0309=]@02DKT40UFm20080
UW1300<0UFm209=]@02BK3l00`2BKD0[ooooo`00:_ooool209EY?0<0UVXm0`2GJch809Q/?`P0V6e0
202IKCh309M/?`@0V6e000<0VFi109Y^@@2JKT401P2JKT4209Y^?@80VFdl102HK3/809Y`?P<0W792
0`2MLd<209idA00309ee@P2LM440Vg=000<0VW8o00<0Vg=009ad@@2MMD800`2RMd@20:5f@`<0X7E2
0P2QMSl0102QMT40XWM40:9gA02SMdH20:=gB0080:EiB02TN4L0XWI50:1d@`2OLd80X7A30:5eA02R
MTD40:9gA080XgQ50P2TNDH20:MlB@040:IkB02UNTL0XgQ50:9gA080XGI30P2TNDH20:EjA`80YW]8
0P2WO4T30:IkB0<0Yga90P2XODX80:MnBP80YGa400@0YWe70:MnBP2XOd/0Z7i<0P2YOdl20:9mB@80
XGa800@0X7]709mjAP2NNDD0WGQ40P2NM48209ec@@80W7900P2KLCl309Ia?@0609E`?02BKCT0SfXf
08aW<`2:IC40Rf@i0P2:HcP208UR=`80R64f00L0Qf0e08IQ=`25H3H0Q5le08=N=021G380OeX`0080
OUT_00<0Me@/07QE;@1hEBd00P1gE2`207IC:`0307EB:P1bDR`0LU8/0080LU8/0P1aDB/2071@:P05
07E<;01dBb/0Ld`[075=:`1`CR/00P1^CBX00`1/CRX0KTdZ06i=:P0206e<:@80K4/X0P1[BRL906]=
:@<0K4TS00D0KDXT071=9`1cD2X0Me@^07UF<00207QC:@80NE@Z00@0NUD[07]F;01lEbd0O5L]0P1m
F2/0101nFB`0P5/^085L;`22GC0208=N<@<0Q60`0P25HC4308IR<PP0R68c0P2;H3<208aQ=080SF8e
0P2>HcH808QR<`0308UN<@2:Gc80S64d0080SF8e00<0S64d08YO<P29GS40202:I3L00`27HC80R68c
08US=00208YT=@0308US=027HC80QV0a0080RF8g00<0RF<f08US=029Hc800P29I3001029I2l0Qf4b
08QR<`29Hc@208YT=@0308US=028HS<0Qf4b00P0Qf4b0P27HRh308QS;`<0RF@`202:I3D208US<P06
08US=028HSD0R64f08QQ>027H3L0Qf0i2029Hc@808YT=`T0RfDf00<0S6Hg08YT=@29Hc@00P28HS<0
0`29Hc@0RV@e08aV=`0808aQ=080RfDf0P2:I3D208US=080R68c0`2:IC4308UT<080R6<_0`28HS<2
08MQ<P<0QV0a00P0QV<]08MS;`28I300R6@b08QT=026HC@0Q5lc08=N<PH0QV0a2P25Gc0208=N<@03
089M<021G2l0P5/^0080OeX]00<0OUT/07iL;P1nG2h00P1mFbd207aJ;080NeT[00H0P5dc07mL<P1n
Fc40OEX`07aI;`1kF2h207YG;@80MUH]0`1hF2l02@1gEbh0MED/07AD:`1gEc00MED^071C:`1/D2P0
JE0W06M@9P0206IA9P0506Q;:@1WBRP0ITTW06E89P1RB2D00`1QAb@205Y8800605U78@1IAb<0F4DT
05Q59@1GA2@0Ed@V0P1A@R<01P1C@R@0ET<U05I1901G?b<0ECdQ05@j7`80D3`S00<0CSdS04dm8`1<
?R<00P1:?b<01019@2<0A3dS04@m8`14?B<304<l8P80@S/Q2@11>R0403lh7P0403hg7@0m=Q`0?3DK
03`e6`P0?CDP0P0k=R802@0j=B40>C@P03Pc7`0g<Qh0=S4M03D`700c<A`0=C<N03Hd7`0203Le8003
03Hd7`0e<ah0<c4L0080=S4M100h<al203Ha7@P0=34N1P0f<Ad203D`700403@_6`0e<1`0=C0L03D`
7080=S4M0P0g<Qh803@b7@@0=C0M0P0d;a`203<^6`P0<c8M0P0h<Ah01`0f<Ad0=38M03<b7@0a<ad0
<38L02lc700e<ah0100d<Qd303<a700303<^6P0d;a/0=S4M0080>3<O00<0=c8N03Ha7@0e<1`0200k
<ah203`d7`80>c<N0P0j<Qd203Ta700303/c7P0l=1l0?3@O00@0?3@O00@0>c<N03`d7`0l=1l0?3@O
0P0m=B0303hf8@P0?cPN2@0n=ad303`e6`80?CHL0`0n=ad803le70T0?SLM00L0?3DK03/d6P0j<aT0
>S<I03/d6P0l=A/0?SLM00P0?3@O200o=A`803/d6P@0?S@K100o=A`8044g700404Di7`16>R00ASXP
04Hj8080Ac/Q0P18?28304Di7`80ASXP0`17>b402`16>R00ACTO04@h7P14>1h0ACTO04Hj8018?280
BShT04a19@1:?b<0Ac`P0080A3TM00<0ACXN04Hk7`18?B40201:?1l204Po8P80B3dQ00P0Ac`P04Tk
8018>Ql0B3XO04dn7`1<?Ah0Bc`M04Xk7080BCXK0P18>AX01P1<>ad0CC`N04dl7P1>?Al0CchP050o
8@80DD0R0P1D@B<01P1E@R80ET<R05M58@1HAR00FDLQ05U77`<0I4PS00@0IDTT06I:9@1WBbH0J4`W
0P1YCBP02`1[CBL0K4hX06e@:01^DBL0L5<W075E9P1bERL0LeLW07=D9@1dEBH0MePY00@0NEX[00T0
N5TZ07iL;P1nG2h0Oed_081N<021Gc40PV0b08=Q<`24HS@00P29IC40102:IS80RfLc08aX=02=JCD2
08iZ=P0408eY=@2?JcL0TVhj09A`?0@0UW8n0P2ELS`0102FLcd0Ug@n09Qe?`2HMCl209Uf@080VWI2
00<0VgM309ahA02MNDD00P2NNTH01`2ONdL0X7]>0:1lC02PO4`0X7a:0:1lB02PODL00P2PODD20:Ao
B`040:F0C02VPDd0YX5=0:N2CP80Z8=?0P2ZQUH30:^7E`<0[8QH0P2YQED00`2ZQUH0ZhMG0:b8F002
0:f9F@040:j:FP2]QeP0[XQI0;2:F`<0/XaM00<0/H]L0;2:F`2`ReL01`2`ReL40;2:F@<0/8]G00L0
/8]F0:f:E02]RED0[HUE0:j:F02^RUX0[XUL0080[hYN202_RUH30:f9F@80[XYJ0`2_Re/80:n9FP80
[h]K0P2^RUX00`2]RET0[8QH0:^7E`020:Z6EP80ZhEF0P2/QUL20:f7F080[XQI0P2[QU820:b7D`80
[HQD1@2^RED20:f8E0/0[XUE0P2_REX30:j8F@/0[HMH302]R5@40:b7D`80ZXEA0`2[QU830:b7D`04
0:^5EP2ZQ5D0ZXAE0:Z4E@80ZH=D0P2XPU<0202`ReL0[XUE0:b7D`2[QU80ZXEA0:^6DP2/Qe<0[HQD
0P2^RE801P2]R5<0[HQD0:b6E@2/QUL0ZhEF0:^5F080[8II00H0[8IG0:b6E@2[QU80ZhIA0:Z5D02Y
Q4d80:Z4E@P0ZhEF0P2[QU840:b7D`80[HQD0`2/Qe<30:^6DP80ZXEA0`2_QE<30:j4DP80[H=A00<0
[8QD0:f9E@2^RUH00P2_ReL0102^RUH0[HUE0:^7D`2ZQU820:^6DP80[8MC0P2]R5@20:j9E@80[XQI
0P2]QeP0102/QUL0ZhEF0:^5EP2[QEH80:^5E100ZhIB402ZQE420:j4DP<0[H=A0`2/PU020:^6DP<0
[8MC102]R5@20:b7D`050:^6DP2YQ500Z8=?0:R3C`2WPTh00`2/Pdl20:f4D0<0[XEA202[QU880:f8
E0060:j3F02^PeH0[X=F0:j4E02^Q580[XEA0P2^QDl80:b6E@80[XQI0P2]QeP20:b6E`80ZhEF0P2_
REP20;2:F@040;6;FP2bS5/0/XaK0;:<F`P0[hUJ2@2^RED80:j8F@030:f8E02^RED0/8]G0080/HaH
00<0/8]G0:j9E@2]R5@00P2_RUH20:j9E@80[HQD0P2/Qe<20:f8D`@0[8MB0P2]R5<30:n9F080/8YI
0`2_REP40:b7D`@0[HQD0P2^RE800`2^RE@0[XUE0:j8E`020:j8F@030:j8F`2[QeL0ZhMG0080[8QH
0P2]RET20:j:FP<0[HQC1@2^RE@20:b7D`H0[HQD0P2[QU820:b7D`80[HQD0P2^RED80:f7F0080:b6
E`2]QeP0[hUJ0;2:F`2_REX0[XQI0:f7F02/QUL80:b7D`P0ZhIA102/QUL40:^5EPP0[8IG202[QU83
0:j9E@80[HQD102/Qe<00`2ZQE40ZhIB0:f8E0020:j9E@030:f8E02[QU80ZXEA0080[8IG0P2]QeP0
102^R5T0[hUJ0:n9FP2_REX20:Z5D@<0ZhIB0`2/Qe<01P2[QEP0ZhEF0:^5EP2[QE@0ZhIB0:^6D@80
ZhI?0P2[Qdd0102[QTl0ZhIA0:^6D@2[QU820:^5E0030:f8E02/Qe<0[8MC0080ZhIB0`2ZQE4:0:^7
D`80[8QD00@0[HUE0:j:EP2^RUH0[XYF0P2^RUP0102]REL0[8QF0:Z6E02YQE<20:R4DP060:j8F@2]
QeP0[HMH0:^5EP2ZQ5D0ZH=D0P2XPU<30:^6DP030:Z5D@2YQ500ZHA@0080Z8=?202YQED20:^4F@03
0:^5F02[QEH0ZhED0080ZhIB00@0ZhIA0:^6DP2[QU80ZhIB0P2ZQE430:V4D0P0Yh9=0`2VPDd20:N2
CP<0Z8=?0P2/QUD20:^5E0040:Z4D`2YPe80Z89A0:R2D@80YX5=0P2UP4`0102TOd/0Xgi:0:=nBP2S
OTX90:J1C@<0Yh9>0`2WPE020:N1DP<0YGm>0P2TOTd30:=mC0D0Xge>0`2TOTl80:5kC0@0X7a<102O
Nd/00`2NNTP0WGU709]gA@0309Ue@`0709YfA02KMdD0WGM809egB02LMTL0VgE609YdA@0209UcA005
09Qb@`2BK3d0TV`m099/?@2AJc`00P2@JS/208mY>P0308iW?02?J3d0TFXo0080TV]000<0TFXo091Y
?P2?J3d00`2>JCd[ooooo`00:_ooool209EY?0<0UVXm0`2GJch809Q[@@P0Uf`o202IKC`809Q]@0<0
VFe00P2JKT4309]_@P0509]_?P2JKSd0VFdl09Q/>`2GJcX00P2HK3/00`2IKC`0Vg4o09]a?`0609]a
?`<0W7540`2MLTD209icAP0309]f@P2JMD40V7<o00<0Ug8n00@0V7<o09Ye@@2KMT80XWM40`2QMT<2
0:1e@P80WgA10P2RMd00102RMd80XgQ50:=hA@2TN4L20:AhB@040:IjB@2TN4L0XWI50:1d@`80Wg=2
00<0X7A30:5eA02RNDD00P2QN4@01@2PMd<0XGQ40:9iA@2SNTH0Y7]70080YW]800@0YGY70:AiAP2T
NDH0XgQ50P2RMd@30:EjA`80YW]80`2WO4T30:IkB080Yga90`2XODX80:MnBP80YGa400L0YGa60:El
B02VODT0YWa:0:IlC02WODd0X7]700<0XGa800D0X7]709iiA@2MN4@0W7M309me@`0209id@P0509ec
@@2LLT00Vg4o09Y`?P2IKcd0102DKc/0102BKCT0SfXf08aW<`2:IC4208UT>P80R6<i00h0Qf8h08IQ
=`25H3H0QF0f08IQ=`25H3H0Q5le089M<`20Fc40OUT_07eH;P1lEbd0Me@/07QE;@80NEH^00D0N5D]
07MD;01fDb/0ME8Z071B;P0306mA;@80KU0/0P1]Cb/207=::P03079;:P1`C2X0KddZ0080KTdZ00@0
K4hZ06e<:@1]C2T0KD`Y0P1/BbP306]:9`T0JddY0`1]BR@01P1^BbD0LDhX07AA:`1gE2h0NEH`07QC
:@80NE@Z00<0NUD[07]F;01lEbd00P1mF2h207mJ;@03081K;P21G2l0PUd`0080Peha00<0Q5lb08AP
<024H3000P25HC4308IR<P0308MS<`28HS<0R68c00H0R68c0P2;H3<208aQ=080SF8e0P2>HcH808QR
<`0308UN<`2:Gc@0Rf0e0080S64f00<0Rf0e08YO=029GS<02028HSD00`28HS<0RF<d08YT=@0208]U
=P0308US=027HC80QV0a0080RF8g00<0RF<f08US=029Hc800P29I3001029I2l0Qf4b08QR<`2:I3D2
08]U=P0308YT=@28HS<0Qf4b00P0R68c0P27HRh308QS;`<0RF@`202:I3D208US<P0608US=028HSD0
R64f08QQ>027H3L0Qf0i2029Hc@808YT=`T0RfDf00<0S6Hg08]U=P29Hc@00P28HS<00`29Hc@0RfDf
08aV=`0808aQ=080RfDf0P2:I3D208US=080R68c0`2:IC4208UT<0<0R6<_0`28HS<208MQ<P<0QV0a
00P0QV<]08MS;`28I300RFDc08QT=027HSD0QF0d08AO<`80Qf4b0`26H34;08EO<0@0PE`_0`20Fbh0
0`1oFRd0OU`^07iL;P0207eK;@80O5X/0P1kFB/01P1oG380OU/a07eJ<01lFBl0NeP^07UF;080N5D[
00<0M5@[07EE;01gEbh00P1hF2l02@1gEbh0MED/07AD:`1eEBh0Le</06mB:P1/D2P0J4lV06M@9P02
06MB9`0606]::`1ZBBX0ITLX06A79`1QAbH0H4PV0P1OB2H0401IBR40F4TP05Q98P1GAb<0ETHT05E5
901DA2<0Dd8T05528`1B@b@0E4<U05I39@1F@B@0EShR05@l801D>Ql2054m900304hm8`1=?B<0BcdR
0080B3dQ00@0AchQ04@m8`14?B<0A3dS0`13?282048k8@T0@3TO0P0n=ad203lh7P0403hg7@0l=A/0
>S<I03Tb60P0?3@O0P0i=20303Pc7`<0=c8N00<0<c4L03Dc7P0f=1l00P0g=B000`0f=1l0=C<N03<a
700203Ha7@@0=c8N0P0f<Ad803<`7@@0=S4M0P0e<1`203@_6`04034^6`0b;a`0<RlL038_7080<c0M
0P0d<Ah803<a700403D`7@0d;a`0=2lL03@_7080<bhK0P0b;AX8030b7080=c0M00<0=S4M03@b7@0c
<Qd00P0a<ad00`0`=1d0<c4L03<a700603<a700303<^6P0d;a/0=S4M0080>3<O00<0=c8N03Ha7@0e
<1`0200k<ah203`d7`80>c<N0P0j<Qd203Ta700303Xb7@0k<ah0?3@O0080?CDP00<0?3@O03/c7P0j
<Qd00`0n<al203ld80<0@3DQ200o>1h903hg7@<0?3DK0P0m=Q`303hg7@P0?cDL2@0n=ad01`0l=A/0
>c@J03Xc6@0j<aT0>c@J03`e6`0n=ad0200l=1l803le70P0?3DK100o=A`4040f7@P0@3HK0`14>1h2
04Di7`<0ASXP00@0A3PN04Di7`15>Al0ACTO0P16>R0204Lk8@0304Hl8@15>b00A3XO0080@cTN00H0
A3XO04Dk8016?240B3`R04Lk8@16>R0304Di7`80ASXP2017?20204Ho8P0:04Ln8@18?B40BC/P04Xj
8019>Al0BSTO04ho801<?Ah0Bc`M04Tj6`<0B3TJ00L0BCXK04Xk701;?1d0Bc`M04`m7P1=?Ql0CSlP
0080Cd0Q0P1B@BD00`1B@B<0Dd<R05=38@0205=37`0705A57P1SAb80HdLR06=78P1TB2<0IDTT06I:
9@0206M;9P0=06Q<9`1ZC2H0JddW06a?9`1]D2H0KU4U071D9@1aEBH0LEDU07AE9P1eERL0MePY07UJ
:`0207YK;00:07UJ:`1hFBX0O5X/07aJ;01mFbd0Oed_081N<021Gc40PV0b08=Q<`80R6@`00<0RFDa
08YV<P2;Ic<00P2<J3@01P2=JCD0S6Pd08iZ=P2@K3P0Tflk09Ea?@80UW8n00H0UG4m09Aa>`2DLC/0
UG8l09Ic?@2GM3h209Qe?`0709Uf@02IMD40VWI209Yf@P2KMd<0W7Q409eiA@0209ijAP060:1kCP2P
O4`0X7a<0:1lBP2PO4P0X7e70P2PODD01P2SOTX0Y7m;0:AoB`2UP4`0YX5=0:N2CP80Z8=?0`2ZQUH2
0:^7E`<0[8QH0`2ZQUH30:^7E`80[8QH00<0[HMH0:j8F@2`RU/00`2bS5d00`2aRe`0/8YK0;2;E`07
0;2;E`80/8YM00@0/8YK0;2:F@2`ReL0/8]F0P2`Re@0202/RE<0[8QD0:f9E@2]REL0[XYJ0:j9G02^
REd0[hYN202^RED30:f9F@80[XYJ0`2_Re/80:n9FP80[XYJ0`2]RET0102/R5P0ZhMG0:Z6EP2ZQUH2
0:^5EP80[8IG0P2]QeP20:j8F@80ZhIA0P2/Qe820:f8D`80[XUD00<0[hYF0:j9E@2]R5@00P2/Qe<0
0`2]R5@0[XUE0:n:EP080:j9E@80[hUJ0`2^R5T;0:f7F0P0[HQD00@0[XUE0:f8E02]R5@0[HQD0`2/
Qe<00`2[QU80ZXEA0:Z5D@030:^6DP<0[8MC0P2/QUL20:^5EP80ZXAE0P2YPe@0202`ReL0[XUE0:b7
D`2[QU80ZXEA0:^6DP2/Qe<0[HQD0P2^RE803P2]R5<0[HQD0:b6E@2/QUL0ZhEF0:^5F02/QEX0[HIK
0:f7FP2]QeP0[8IE0:Z5D@2YQ500Z8=>0`2YPe@20:Z4E@/0ZhEF202[QU430:b7D`<0ZhIB0P2ZQE47
0:j4DP040:n5D`2/R5@0[HUE0:j:EP80[h]G00@0[XYF0:f9E@2[Qe<0ZXIB0P2[QU820:b7D`80[HQD
0P2^RED20:j8F@040:f7F02/QUL0ZhEF0:^5EP80ZXAE202[QEH@0:^6DQ00ZXEA00@0[XAB0:f3D@2]
Pe40[H=A0P2/PU020:^1C`<0ZhIB0P2/Qe<30:f8E0080:j9E@2]R5@0[8MC0:^6DP2YQ500Z8=?0:N2
CP2VPDd30:b3C`80[HA@0`2^QE480:^6DPP0[HQD00H0[X=H0:j3EP2^PeH0[XAD0:j4DP2^QE420:j5
C`P0[8MC0P2^R5T20:f7F080[8IG0P2[QEH01P2]QeP0[XQI0:j8F@2_REX0/8YK0;6;G080/XaM0`2`
RU/20:n9FP<0[XQI00@0[HQC0:j9E02^RE@0[XUD102_RUD00`2`ReH0[XQI0:j8F@060:j8F@030:f8
E02^RED0/8]G0080/HaH00<0/8]G0:j9E@2]R5@00`2^RED20:f8E0<0[8MC00<0[XUD0:f8D`2/Qe80
0P2[QU401P2/Qe80[HQC0:j9E02^R5T0[hUJ0;2:F`80/H]L00@0/8YK0:n9FP2^R5T0ZhIB0`2/Qe<3
0:f8E0060:j9E@2^RE80[XUB0:j9E02^RED0[XQG0P2^R5T01@2^R5/0ZXIF0:Z6EP2[QeL0[8QH0080
[HUI0P2^RUX30:n:E@050:j9E02]R5<0[HQC0:f8D`2/Qe800P2/Qe<30:f8E0<0[XUE0P2[QU820:b7
D`80[HQD0P2^RED90:f7F0070:j8F@2_REX0/8YK0:n9FP2^R5T0[8IG0:^5EP080:b7D`P0ZhIA402/
QUL80:^6DP<0[HQD0P2/Qe<40:^6DP030:V4C`2ZQE00[8MB0080[HQC00@0[8MB0:Z5D02YQ4l0ZhEF
0P2/QUL00`2]QeP0[XQI0:n9FP020;2:F`80ZXEA0`2[QU830:b7D`060:^5F02[QEH0ZhEF0:^5E02[
QU80ZhIA0P2[QTl20:^7C@040:^6C`2[QU40ZhIA0:^6DP80ZhED00<0[XUE0:f8E02[QU800`2ZQE42
0:^6DPP0ZhMC00H0ZXIB0:^7D`2[Qe<0[8QD0:f9E@2^RUH20:n;E`80[8QD0P2[Qe<0102ZQU80ZHEA
0:R4D02XQ5020:^5EP<0ZXAE0`2YPe@01P2/Qe<0ZhIB0:^6DP2ZQE40ZHA@0:R3C`80Yh9>202YQED0
1@2YPUL0ZX=H0:Z4E`2ZQ5D0ZhED0080ZhIB00@0[8MB0:^6DP2[QU80ZhIB0P2ZQE430:V4D0P0YX5<
0`2UP4`20:J1C@<0Yh9>00H0ZhEF0:Z4E@2ZQ5D0ZH=D0:R2D`2WPE820:J0D@80YH1<00@0Y7m;0:=n
BP2RODT0XWe90P2QO4P90:AoB`060:F0B`2UP4`0YH1<0:EoCP2UOe00YGmB0P2UOU<30:=mCP<0XWa=
0P2QNd`0102ONDX0X7Y;0:1jB`2PNT/30:5kC0030:9lC@2MMdX0WGM:00H0WGM:2@2LN4P00`2KMdL0
VGE509Mc@`0209Ib@P80Ug=300H0VgE609YdA@2JM4D0VG=409Qb@`2GLD8209I`@@80T6Xk0P2?JCX0
302>J3T0SFLh08aV=`2<ISL0RV<j08]T>`2=ISd0SVLn08mX?`2>Ich0SFHm08aU?0<0RfHl:oooool0
02[ooooo0P2EJC`309IZ?@<0Uf/n202HJd8809M/?`P0VFdl1P2HKD0209M/?`0309Q/?`2IKD00VFe0
0080VVi10P2KKd80102LL4<0W70o09]_?P2IKC`309M[>P80VFdl202LLT0309aaA0<0WG950P2NLdH0
0`2KMT80VGA009Qc?`0309Mb?P0309Qc?`2IM400VgI200@0X7E20P2OM44209ic@0060:9g@02SN440
XgQ30:=hA@2TNDH0Y7Q70P2UNDX0102VNTT0YGU80:9fA@2PM4<209mc@P80X7A30P2QNDD309mg@`03
0:5iA@2SNdL0Y7a800P0Y7U60P2UNTL20:IkB0@0Yga900@0YW]80:MlB@2WO4T0Yga90P2XODX20:Un
B`P0Z7m;0P2UO4@0102TNdD0Y7]70:AkA`2SNDL20:=iB@0809mjAP2PNdL0XGa80:5lB02PNdL0WWU5
09ag@`2KMT820:1fA00709id@P2MLd40Vg4o09U_?@2HKS`0Ufdk095/>002099]>@0509=^>P2AK3P0
SfXf08eX=02<Ic<00P27I3X01026HcT0QF8h08AQ=`23H3H2089O=@80QF0f00h0Pehd085L<P1oFS00
OEP^07aG;@1kER`0N5D]07UF;P1jEbl0NeP`07YG;`1iERh0Me@/07EB:P80KU8]0P1]DB`306a@:`09
06]?:P1bBBT0LTTY075::@1_BbT0KT`Y06e<:@1^CBX0K4hZ0080KD`Y0P1/BbP406]:9`T0K4hZ00T0
L4dW06m<9P1_C2H0Kd`V075>:01dDB/0MU<]07QE;`1iE2P00P1jEBT00`1kERX0O5L[07eH;00207iI
;@80P5/^0P21G2l01022GC00Peha08AO<P24Gc8308EQ<@<0QV8b0P27Hc<808QR<`80Rf0c0P2<HC@2
08eR=@80SV<f2028HS<00`28GC<0REhd08]P=P0208aQ=`0308]P=P29GS@0R5dc00P0QV0c00<0RF<d
08YT=@2;ICH00P2;ICH00`29Hc@0Qf4b08IP<@0208UR=`0308US=P29Hc@0RF<b0080RF@`00@0RF@_
08MQ<P29Hc@0RV@e0P2;ICH00`2:I3D0RF<d08MQ<P0808QR<`80Qf8^0`28Hbl308UT<0P0RV@e0P29
Hc801P29Hc@0R68e08QQ=P28HCP0Qf0g08MP>@P0R68c202:I3L908]U=P0308aV=`2;ICH0RV@e0080
RF<d00<0RV@e08]U=P2<ISL0202;H3<208]U=P80RV@e0P29Hc@208QR<`0408YU<@29I300RF@`08UT
<080R6<_0P27HRh308QR<`80Qf4b0`26H3402026Hbd0Qf<_08QT<029IC<0RFDe08MR=@25H3@0Q5lc
0`27HC800`26H340QEl`08EO<00208AN;`P0QEl`0`1oFRd2081K;P<0PE`_0P1nG2h207eK;@80O5X/
0P1kFB/07P1nFc40OEX`07aI;`1jEbd0NEH/07MD:P1fDbT0ME8X07=C:P1eEB`0MUH]07MG;P1hF2l0
MeL^07EE;01dE2/0Le</075A:P1^DBT0JdlW06Q?9P1XDBL0J5<X06UD:@1]BRh0K4T]06Q6:P1SARP0
HDHX05m8:080GTXY0P1IC2801P1GBB80ETPS05A68`1B@b80DD8Q05118P80DT<T00H0E4<U05I39@1F
@B@0EShR05@l801C>Ah2058n9@0604ln901=?B<0BS`Q04Ll8016>al0AC`O0`13?B<3048l8P80@C/Q
2@10>Al0200m=Q`0?SLM03lh7P0o>1h0?SLM03/d6P0i<QP0=c0F200k<ah203Ha7@80=c8N0P0h<al2
03Td800303<a700e<ah0=S@O0080=cDP00<0=S@O03Dc7P0c<A`0200f<Ad803<`7@0303Lb7P0f<Ad0
=S4M0080=C0L0P0d;a/0100c;QX0<2lM030_7@0`;ad2034`7P<0<S4O200b<1/203@_7080<bhK0`0b
;AX00`0a;1T0<38L030b7006030b7080=c0M00<0=S4M03@b7@0c<Qd00P0a<ad00`0`=1d0<c4L03<a
700603<a700303<^6P0d;a/0=S4M0080>3<O00<0=c8N03Ha7@0e<1`02P0l=1l203/c7P80>S8M0P0i
<A`00`0j<Qd0>c<N03de800203hf8@0303de800k<ah0>S8M00<0?c8O0P10<b03044d8@P0?cPN2@0n
=ad303`e6`80?CHL0`0n=ad803le70T0?SLM00L0?3DK03/d6P0j<aT0>S<I03/d6P0l=A/0?SLM00P0
?3@O200o=A`803df70P0@CLN200o=AX2048f70<0@cLM1@14>1h304Di7`<0ASXP00@0Ad0T04Dn8P13
?200@CXN0P10>Ad2044j7P0504<g7`14>200ACTQ04Hj8P17>b<00P16>R800`15>B40Ac`P04Ll8006
04Ll800604A18P15@280AChQ04Ln8@19>b00BSXP0P1<>1l0101>?b00C3dN04Xk7018>AX204Lh6@07
04Pi6P19>Q/0BC`L04Tl701:?Ad0BchN04`o7`0204e0800704i18@1<?280CChQ04ho8P1@@B80DD8Q
05=58P0205A68@<0HTHQ00<0HdLR06A88`1UBB@00P1VBRD03@1WBbH0JD/U06Y<9P1[CRH0K4lU06e@
901_Db@0L5@U071D901eERL0MULX07QI:P1jFb`00P1kG2d207YK;00607YH:P1kFB/0O5X/07iL;P1o
GBl0PEla0P22H38208MS;`0308QT<029IC40RVHb0080RfLc00D0S6Pd08]W<`2<J3@0Sf/g099^>P04
09Ea?@80Tg0j00<0U74k09Eb?02FLcd00P2GM3h01`2HMCl0VGE109Ue@@2JMT80VgM309ahA02MNDD0
0P2NNTH01P2ONTd0Wg];09mkB`2ONdT0Wg]709mlAP80Wga40P2SOTX00`2TOd/0YH1<0:J1C@020:N2
CP030:R3C`2YQED0ZHEE0080ZXIF0`2[QeL00`2/R5P0ZhMG0:^7E`020:^7E`@0ZXIF00<0[HMH0:j8
F@2`RU/00`2bS5d00`2aRe`0/8YK0;2;E`070;2;E`80/8UN00@0/8YM0;2:F@2`ReL0/8]D0P2`S580
1P2/RE<0[8QD0:b8E02]REL0[HUI0:j9G080[XUM202^RED30:f9F@80[XYJ0`2_Re/80:n9FP80[XYJ
0P2]RET01@2/R5P0ZhMG0:Z6EP2ZQUH0ZHEE0080ZhEF0P2/QUL20:f7F080[XQI0P2[QTl20:b7D080
[HQA0P2^RE800`2`ReL0[hYF0:f8E0020:b7D`030:f8E02_RUH0/8]G00P0[XUE0P2_REX30:j8F@<0
[HMH202^R5T80:f8E080[XUE0P2]R5@20:b7D`80ZhIB0P2ZQE430:^6DP<0[8MC0`2]QeP20:b6E`<0
ZhEF00P0/8]G0:j9E@2/Qe<0ZhIB0:Z5D@2[QU80[8MC0:f8E080[XUB00l0[HQC0:f8E02/QUD0[8IG
0:^5EP2[QEP0[8EL0:f6F`2^Qe`0[XQK0:f7F02ZQ5<0Z8=?0:J1C@2XPU<00P2YPe@20:Z4E@80ZhEF
00<0[8IG0:^5EP2[QEH01P2[QEH40:^6C`@0ZXE>0`2/Qe<30:^6DP80ZXEA0P2/PU00102]Pe40[XAB
0:n5D`2_QE<20;26E0030:b8E02]RED0[XYF0080[h]G00@0[XYF0:f9E@2[Qe<0ZXIB0P2[QU820:b7
D`80[HQD0P2^RED20:j8F@040:f7F02/QUL0ZhEF0:Z4E@80ZH=D202[QEH@0:^6DQ00ZXEA0`2]Pe42
0:b2D0<0Zh5?0P2ZQE420:^6DP<0[8MC00T0[HQD0:j9E@2]R5@0[8MC0:^6DP2YQ500Z8=?0:N2CP2V
PDd00`2/Pdl20:f4D0<0[XEA202[QU880:f8E0060:j3F02^PeH0[X=F0:j4E02^Q580[XEA0P2^QDl8
0:^6DP80[XQI0P2]QeP20:b6E`<0ZhEF00D0[8IG0:f7F02^R5T0[hUJ0;2:F`030;6;G080/8YK0P2_
REX20:j8F@030:f7F02]R540[HQA0080[XUB0P2_RU<30;2;E0P0[XQI00<0[HQD0:j9E@2`ReL00P2a
S5P00`2`ReL0[XUE0:f8E0020:j9E@80[HQD102/Qe<00`2^RE@0[HQC0:b7DP020:^6D@060:b7DP2]
R5<0[XUD0:j8F@2_REX0/H]L0P2bS5d00`2aRe`0[hUJ0:j8F@020:^6DP80[8MC0P2]R5@20:j9E@80
[XUB00<0[XUD0:j9E@2^R5L00P2^R5T04@2^R5/0ZHEE0:V5E@2ZQUH0ZhMG0:b8F02]RET0[XYJ0:n;
F`2bSEP0/HaG0;2;EP2_RUD0[HQC0:b7DP2[QU40ZXE@0080[8MC0P2]R5@20:j9E@80[hYF0P2[QU82
0:b7D`80[HQD0P2^RED:0:j8F@060:n9FP2`RU/0[hUJ0:j8F@2/QUL0ZXAE202[QU880:Z5D0D0[8IG
0`2]QeP80:b6E`P0ZXEA0P2/Qe<20:^6DP<0ZXEA0P2YQ5000`2YQ4d0ZXE>0:^6C`020:b7D0030:^6
C`2ZQDh0ZHA=0080ZhEF00H0[8IG0:f7F02^R5T0[hUJ0;2:F`2aRe`20:Z5D@<0ZhIB0`2/Qe<01P2[
QEP0ZhEF0:^5EP2[QE@0ZhIB0:^6D@80ZhI?0P2[Qdd0102[QTl0ZhIA0:^6D@2[QU820:^5E0080:j9
E@2]R5@0ZhIB0:Z5D@2YQ500ZXEA0:^6DP2/Qe<:0:Z6DP060:^7D`2/R5@0[HUE0:j:EP2_ReL0/8aH
0`2ZQU850:V5D@<0Z89C0P2YPe@20:Z4E@060:^5EP2/Qe<0ZhIB0:^6DP2ZQE40Z8=?0P2WPTh00`2V
PDd0ZHEE0:V5E@060:V5E@80ZH9G00H0ZH=F0:Z4E@2[QE@0ZhIB0:b7D`2/Qe830:^6DP80ZXEA0`2Y
Q5080:F0B`80Y7m;0P2UP4`30:J1C@050:N2CP2XPU<0Z89C0:N1DP2VP5400P2UOe020:AnC`060:F0
C02TOd/0Y7m;0:9mB@2QO4P0X7]70P2ONTH90:=nBP80XWe800@0XWe90:9lC@2RO4l0XW]B0P2RNe@3
0:9lC@80XG]<0`2PNT/209afA`80WGM800@0WWQ909miBP2ONDX0WgU:202JLdP709UeA@80VWI600<0
V7A409Ib@P2DL4000`2CKcl01`2DL400UFm009A^?`2DKSl0Tfdn099/?@2AJc`00P2@JS/01@2?JCX0
SVPi08iX>@2=IcP0RfDf0080RV@e00@0RF<d08MP=`28HCP0RV<j0`2<IC`00`2;I3/0RV<j08UT>P02
08UT>R_ooooo000Zooooo`80UFTl0`2FJSd309M[?PP0V6]2202GK3l809U^>`D0V6e00`2GK3l209Q/
?`0409U]@02JKT40VVi109]_@P80W71300P0W70o09]_?P2IKC`0Uf/j09IZ>@2GJcX0VFdl09Y^?@P0
WG=10`2LLDH309ebA`80WW=800<0VGE109Qd@02GLcl00`2FLSh0102GLcl0V7A009Ue@@2PMD8309md
@@80WW=00P2MLSl20:=h@@040:=h@`2TNDH0Y7U60:EiB080YGU:00@0YWY90:EiB02SMdH0X7A30P2O
Ld820:1d@`080:9jAP2QNDD0WgM309if@P2OMd<0XGU50:=kA`2TO4P30:=hA@80Y7U61@2UNTL20:Ik
B0<0Yga900<0Z7e:0:MlB@2WO4T00P2WO4T20:QmBP80ZGi;202XOd/0402UO4@0Y7]30:AkA@2SNTH0
XWU50:5gA@2QMdL0X7I609mjAP2PNdL0XGa80:9mB@2QO4P0WWU509ag@`2JMD420:5gA@0>09me@`2M
Ld40VW0n09Q^?02GKC/0UV`j08mZ=P2@JcL0TF`h099]>@2AK3P0T6/g08iY=@2=J3@208MT?00408IS
>`25HSX0Pf0h089O=`80PEhf0P25H3H03`23GS@0PE`b07mJ<01mF2h0NeH/07YE:`1hEBd0NEH^07]H
<01lFC40NeP`07YG;`1gE2`0MU<[06iA;`0306e@;P80K4l]0P1[CR`20758:0030719:01_BbT0KT`Y
0080KD`Y00<0K4hZ06e<:@1]C2T00P1/BbP306]:9`0306Y99P1/CRX0K4hZ00L0K4hZ00P0LDhX071=
9`1`CBL0L4dW075>:01dDB/0MU<]07QE;`80NUDX0P1kERT01@1lEbX0OEP[07iI;01nFB`0P5/^0080
PE`_00<0PUd`08=N<@23GS400P24Gc8308EQ<@80QV8b0`27Hc<808QR<`80Rf0c0P2<HC@208eR=@80
SV<f2028HS<00`28GC<0REhd08]P=P0208aQ=`0308]P=P29GS@0R5dc00P0QElb0P2:I3D01P2;ICH0
S6Hg08]U=P29Hc@0Qf4b08IP<@80RF8g00<0RF<f08US=029Hc800P29I3001029I2l0R68c08US=02:
I3D208]U=P0308YT=@29Hc@0R68c00P0R68c0P27HRh308QS;`<0RF@`202:I3D208US<P0608US=028
HSD0R64f08QQ>027H3L0Qf0i2028HS<808YT=`T0RfDf00<0SFLh08]U=P2:I3D00P29Hc@00`2:I3D0
RfDf08eW>00808]P<`80RfDf0P2:I3D208US=080R68c1029I30208QS;`80Qf8^0`28HS<208MQ<P<0
QV0a00T0Qf@^08QT<029IC40RFDc08UU=@27HSD0QF0d08AO<`28HS<00P27HC800`26H340QEl`08EO
<00208AN;`P0QEl`0P1nFB`207mJ;@04081K;P21G2l0PUd`089M<080OU`^0P1mFbd207aJ;080NeT[
00/0OEX`07aI;`1kF2h0NEH/07MD:P1fDbT0ME8X07AA9`1cDbX0M5@[07IF;@0307MG;P0B07EE;01d
E2/0LE4Z071@:@1]D2P0JdlW06Q?9P1XDBL0JE@Y06YE:P1_BRl0K4T]06U7:`1TAbT0HDHX05m8:01N
BRT0GT/Z0P1JCB<03P1HBR<0ETPS05=58P1A@R40D44P04m08@1B@b@0Dd@U05A39@1F@bD0ET4T05Hn
8P1C>al0DcTN0P1C?bH01P1??R@0CCdS04Xl8@16>al0ACXN04<j7@<0@ShS0`11?B82040l8@T0@3TO
00P0?CHL03hg7@0o>1h0?cPN03df700k=1X0>34G03H_5@P0>c<N00H0=2lK03D`700f<Ad0=c8N03Pc
7`0i=20203Xe8@0303<a700e<ah0=S@O0080=cDP00<0=S@O03Dc7P0c<A`0200f<Ad803<`7@0403Lb
7P0f<Ad0=S4M03D`7080=2lK0P0c;QX0100_;Q`0<2lM030_7@0`;ad2034`7P80<S4O200b<1/0100d
;a`0<bhK03<^6`0c;Q/2038]6P80<B`I200_<a`203H_700603Ha7@0d<Qd0<c8M034c7@0b=1h0<CDN
0`0b<1/503<a700303<^6P0d;a/0=S4M0080>3<O00<0=c8N03Ha7@0e<1`02P0l=1l203/c7P80>S8M
0P0i<A`00`0j<Qd0>c<N03de800203hf8@0303de800k<ah0>S8M00<0?c8O0P10<b03044d8@P0?cPN
2@0n=ad303`e6`80?CHL0`0n=ad803le70T0?SLM00L0?3DK03/d6P0j<aT0>S<I03/d6P0l=A/0?SLM
00P0?3@O200o=A`803hg7@80@cTP1012>1l2044g7PP0?cDJ0`11=A/2048f70<0@cLM0`14>1h204Di
7`<0ASXP00@0B44U04Ho8`14?B40@CXN0`0o>1`01010>Ad0@3@L048f7P15>B4304Pl900304Hj8P14
>200AC/P00L0AC/P0P14@B802P15?R40AchQ04Tk801;>R00C3PO04dg7`1>?b00C3dN04Xk7018>AX2
04Lh6@0304Pi6P19>Q/0B3/K0080BC`L00<0BSdM04/n7P1<?al00P1=@2002@17=ad0BCTO04/l7`1>
?b00DD8Q05A68`1GBBH0F4XU0655800306968@0306=78P1TB2<0IDTT0080ITXU00`0J4XT06U;9@1Z
CBD0JdhT06e@901^DR<0Ke<T071D901fEbP0MePY07UJ:`1kG2d207aM;P0807]L;@1jFb`0NUPZ07YH
:P1kFB/0OE/]07mM;`20GS02089P<P0608IR;P27Hbl0Qf<_08QT<029IC40RVHb0P2;Ic<01@2:IS80
S6Pd08m[=`2BKSX0U70l00<0UG4m0P2CL3X0102DLC/0UG8l09Ic?@2FLcd209Md?P80VGE100<0VWI2
09]g@`2LN4@00P2MNDD01`2NNTH0WgY=09mkB`2ONd/0Wg]909mkA`2OO4H00P2OO4@20:=nBP040:Ao
B`2UP4`0YX5=0:J1C@80Yh9>0P2YQED20:Z6EP@0ZhMG00H0[HUI0:b8F02/R5P0ZhMG0:Z6EP2YQED2
0:R4E0030:f7F02^R5T0/8YK00<0/XaM00<0/H]L0;2:F`2`ReL01`2`ReL02@2`RF00/8UN0;2:G@2`
RUT0/8]F0;2;E02`S580/8a@0:b9D`020:b8E0030:f9E`2]RET0[HQK0080[XUM202^RED30:f9F@80
[XYJ0`2_Re/80:n9FP80[XYJ0P2]RET00`2/R5P0ZhMG0:Z6EP020:V5E@80ZhEF0P2/QUL20:f7F080
[XQI0P2[QTl20:b7D080[HQA0P2^RE800`2`ReL0[hYF0:f8E0020:b7D`030:f8E02_RUH0/8]G00P0
[XUE0P2_REX30:j8F@<0[HMH202^R5T80:f8E0<0[XUE00<0[HQD0:b7D`2[QU800P2[QU820:Z5D@<0
ZhIB0`2/Qe<30:j8F@80[HMH0`2/QUL0202`ReL0[XUE0:b7D`2[QU80ZXEA0:^6DP2/Qe<0[HQD0P2^
RE803P2]R5<0[HQD0:b6E@2/QUL0ZhEF0:^5F02/QE`0[HIM0:j7G02^R5/0[HMH0:Z4D`2XPU40YX5=
0P2XPU<0102YPe@0ZXAE0:Z4E@2[QEH20:b6E`P0ZhEF0P2[QTl40:Z5CP80ZHA=0`2/Qe<30:^6DP80
ZXEA0P2[PDl02@2/PU00[XAB0:n5D`2`QU@0/HME0;:8EP2/R5@0[HUE0:j:EP020:n;E`040:j:EP2]
RED0ZhMC0:Z6DP80ZhIB0P2/Qe<20:f8E080[XUE0P2^R5T01P2]QeP0[8IG0:^5EP2ZQ5D0ZH=D0:R2
D`P0ZhEH402[QU8@0:Z5D@80[H=A0`2/PU030:^1C`80ZXEA0P2[QU840:b7D`80[XUE00@0[8MC0:^6
DP2YQ500Z8=?0P2VPDd30:b3C`80[HA@0`2^QE480:^6DPP0[HQD00H0[X=H0:j3EP2^PeH0[XAD0:j4
DP2^QE420:j5C`P0ZhIA0P2^R5T20:f7F080[8IG0P2[QEH01P2ZQ5L0ZhEH0:^5F02]QeX0[XQK0:n9
G080/8YM0P2aRe`0102`RU/0[hUJ0:n9FP2^R5T20:f7F080[HQA00D0[XUB0:n:D`2_RU<0[hYC0;2;
E0020;6<E@P0[XQI00<0[HQD0:j9E@2`ReL00P2aS5P00`2`ReL0[XUE0:f8E0020:j9E@80[HQD0`2/
Qe<0102[QU80[hYE0:f8D`2/Qe820:Z5D0060:b7DP2]R5<0[hYE0:j8F`2_RE`0/H]N0P2bS5l00`2a
Reh0[hUL0:j8F`030:^6DP030:b7D`2]R5@0[XUE0080[XUE0P2^RE800`2^RE@0[XUE0:j8E`020:j8
F@0A0:j8F`2XQ5@0ZHEE0:Z6EP2[QeL0[8QH0:f9F@2^RUX0[h]K0;>>F@2bSEP0/HaG0:n:E@2]R5<0
ZhIA0:V4C`2XPdh00P2/Qe<20:f8E0040:j9E@2_RUH0[hYF0;2;E`80ZhIB0P2/Qe<20:f8E080[XUE
2@2^R5T01`2_REX0/8YK0;2:F`2_REX0[HMH0:^5EP2ZQ5D0202[QU880:Z5D0@0[8IG102]QeP80:b6
E`P0ZXEA00@0ZhIB0:Z5D@2ZQE40ZXEA0`2YQ5020:R3C`030:R3C02YQ4d0ZhI?0080[8M@00<0ZhI?
0:V4C@2XPd`00P2[QEH00`2/QUL0[HMH0:j8F@020;2:F`030;6;G02ZQE40ZXEA00<0ZhIB0`2/Qe<0
1P2[QEP0ZhEF0:^5EP2[QE@0ZhIB0:^6D@80ZhI?0P2[Qdd0102[QTl0ZhIA0:^6D@2[QU820:^5E003
0:n:EP2]R5@0ZhIB0080ZHA@00<0ZXEA0:^6DP2/Qe<02P2ZQU800`2[Qe<0[8QD0:f9E@020:n;E`04
0;2<F02XQDl0Z8E?0:R5C`80ZHI@0`2ZQe420:J0D@030:N1DP2XPU<0ZH=D0080ZhEF00L0[8IG0:b7
D`2[QU80ZhIB0:V4D02XPdl0Yh9>0080YX5=202YQED20:R1EP060:V3EP2ZQ5D0ZXAC0:^6DP2/Qe<0
[8MB0`2[QU820:Z5D@<0ZHA@202UP4/30:AoB`80YH1<0`2VPDd20:N1E0040:J0D`2UOe80Y7iA0:=m
D080XWa?0P2TOd/01P2SOTX0XWe90:5lB02PNdL0WgY609iiA@T0Xgi:00H0XGa50:5lA`2QO4P0XG]<
0:5jC`2QNU420:5iE@<0XG]>0P2PNTd309miC080VWA50P2KMDH0102LMTL0WGM809egB02NN4T809Qa
AP0309Ib@P2GLd<0Ug=30080Ug=30`2HM4@0102HLdH0Ug9509A_@P2BKD03095/?`06099]@02?JCX0
SfTj08iX>@2=IcP0S6Hg0P2;ICH01`2:I3D0SVPi08iX>@2=IcP0S6Hg08YT=@29Hc@00P28HS<01P25
GSL0QUlh08QQ>P2:Hc`0Rf@m08YS?080RF8k0`28HS/[ooooo`00:_ooool309M[?P<0UVXm0P2EJC`2
09Q/?`@0Uf/n0P2FJSd02@2KL4<0VVm209U^@@2GK3l0UV/n09AY?02CJ3/0TVLj09IZ>@0309M[>P80
V6`k0P2IKC`00`2JL3h0VFlm09M]>`0209M]>`0609U_?@2KLCl0W79009M]>`2IKcd0VW0n0`2LLT00
0`2KLCl0VW0n09M]>`0709M]>`0409U]?02JKSd0VVhm09]_?P80W70o0P2MLD0309ic@080WgA10`2P
MD8909ic@00609eb?`2NLd00WW=00:1e@P2QMT<0XWM42P2SN4D0102UNDP0Y7Q70:AhA`2SMdH20:9f
A@80XGE400H0XGQ20:9i@`2RND<0Y7]50:ElAP2VODL20:MnB0P0Y7Y800H0XGM50:9hAP2RN4H0Y7Y8
0:EkB@2VO4X20:MmB`P0YWa:202WO540102RN4H0XgU70:=iA`2TNTP20:EkB@80YWa:00H0W75409eb
A@2NLdH0WgA70:1eB02QMTT20:9gBP0609mf@P2NM480WG=109]a@@2IKT40V6e20P2FJd401P2AJch0
T6Xm091Z?@2?JC`0SVPk08eW>P80S6Hi00h0QV0i08MQ>P28HS/0RF<l08QR>`25GcP0Pedf085K=021
Gc40PElb07mM<01mFS00O5Ta07YG<@80N5@`0P1mEc0207iH<@0<07aF;`1jE2d0N58[07I@:@1^D2`0
KDl[06a>:P1[CBT0K4hZ06e?:`1_DBd0L58^0P1[CBT206Y<:080JD/W0P1XBRH206i=:P0606e<:@1[
BRL0JDPU06Q7901WAR<0ITDR101XC2@506U=9@0;079?9`1cD2P0M54Y07IC:`1hEBd0NUL_07]H<01l
FC40OUdb07eL<@1lFBl00P1mF2h01@1nEbh0PUP`08=I<@20Fbh0PE`_0080PUd`00@0Peha08AO<P25
H3<0QF0c2028HSD808]P<`P0RfDf0`2;ICP00`2:I3L0RF<f08QR=@0208QR=@0808UN<@2;H3<0SF8e
08iS=P2=HSD0Rf0c08QM<027G2l808US=P<0RfDh00<0RV@g08US=P28HSD00P28HSD808]P=@<0RF<b
1@28HS400`26H3<0R68e08US=P0208YT=`0308US=P28HSD0QV0c0080Qf4b0`28HS<308US=00408UN
<@2:Gc80RUlb08]P<`80S64d0P2=HSD808MS<`0@08YT=@2;ICH0S6Hg08eW>02<ISL0RfDf08US=028
HS<0S6Lb08]V<P29I300R68a08US=02;ICP0SFHk08iW?0T0S6Hg00D0RUlb08]P<`2;H3<0S64d08eR
=@0208iS=P0308mT=`2;ICH0RfDf0080RV@e0P29Hc@208QR<`0308]U=P29Hc@0R68c0080Qf4b00<0
RF<d08]U=P2=IcP02027Hc<00`2:IC40RF@`08MR;P0208EP;00308IQ;@27HRh0R6<_0080QEl`00@0
QV0a08MQ<P27HC80R68c0P29Hc@00`25Gc00QV0a08QR<`0208US=00308QR<`26H340QEl`0080OeX]
00@0P5/^085L;`21G2l0PUd`0P23GS42085M;@<0P5`/0`1oFb/208=N<@04089M<021G2l0PE`_081K
;P80OeX]0140NeLW07]I:@1mFbd0O5/^07YK;`1fFBl0LUH^071D;01bEBd0LeH^07AG;`1eF300M5L_
079E;@1_DRX0KE0X06e@;P0206iA;`0506e@;P1[CR`0IdXX06A79@1RAB<00P1QAbH0301PB2H0GTLU
05a89@1KBBD0FTPT05Q8901LAbX0FdHY05U6:01EA2H0Dd8T05528`80CT4Q101?@1l40511800604hm
8`1<?280C3`R04Xl8@17?200AC`O0P12>ah01P15>2D0A3LT04@g9013=R<0@SDR044d8@80@3<P2@0i
=2000`0h=1/0>CDL03Xe7`0203Xe8@0303Pc800g<B40=BlO00P0=S@O0P0e<a`00`0e<ah0=34N03@a
800203<`8@0703<_8`0c<240<c0O03<`7`0c<1d0<c4L03<a6P0203<a600303H`8P0e;b40=2hP0080
<bdO00<0=2hP03D_8@0f<280200a<ad02`0];aT0;c4K030b700a<ad0<38L02la6`0/;QP0:bdG034[
7@0c;Al0=2hP0080=S0R00<0=2hP03<]7`0a:ad00`0];Qh202`]7@<0:b`L0`0^;al302d^7P80;2dM
200^<1/4038_70@0<BhK00<0<B`H03<^6P0e<1`00P0g<Qh00`0f<Ad0=C0L03@_6`0203<c6`0303@b
6`0f<A/0=c4K0080>30K00H0>RlK03Ta700i<A`0>S8M03/c7P0l=1l203hf8@0603lg8P0l<b80?3<R
03`c8P0k<R40>S4P0`0i<1l0200m=Q`0?3DK03Xc6@0i<QP0>S<I03`e6`0n=ad0?cPN200m=Q`00`10
>Al0?SLM03`e6`0203Xc6@0303`e6`0n=ad0@3TO00/0?SLM0P0o>1h3040i7`04044j800o>1h0?SLM
03`e6`80>c@J00<0?3DK03hg7@0o>1h00P0m=Q`303hg7@<0?cPN200m=Q`2044g7P04040f7@0o=A`0
?cDL03hd6`80?C<J200n=ad0200m=Q`0?3DK03Xc6@0i<QP0>S<I03/d6P0m=Q`0?cPN4010=Qd8048h
7`<0@cTN0P14>Ql304Dk80P0ASXP0P18?28204Lk8@0704Hj8015>Al0ACTO04@h7P17?B80AS`Q04@j
7`0204<i7P0404@j7`16?240AcdR04A18P80A3lQ00<0A3dP04Dl7`15>Qh00P16>1d404Th7P80BSTO
0P1;>R0204Ti7`80BSXP0`1;>b401`1<?280C3hT04do901??bD0DD0T05918`1F@b<00P1HA2<06@1?
@QP0DTDK05956`1GB1l0G4XR061=9@1RC2D0HD/T06598`1QBb@0HT`U06==9P1UCbP0Ie4Z06QB:`1Z
E2d0JeD^071D;@1aEBh0LUH^07=H;@1dFB`0MU//07ML;@1gGB`00P1iFR/01P1kG2d0OEh_07mP<@21
HS<0Pf@e08AU=P80QV<[00<0Qf@^08MS;`27Hc400P28I3@01@28HcH0S6@a08iV<`2AJCH0U6`i00<0
UVhk00@0UFdj09E`>`2EL3/0UG0k0P2FLC`309Mb?@80V7A00P2IMD401@2JMT80VgM309ahA02LN4@0
WGU500@0W7Q40`2KMd<01`2NNTH0Wg]70:1lB02ROTX0Y81<0:F1C@2VPTh00`2WPdl20:R4D0040:V5
D@2ZQU80ZhMC0:^7D`80[8E>00H0ZhIA0:Z6DP2ZQU@0ZHMG0:R8E`2XR5T20:b8F080[HUI00@0[XYJ
0:n;F`2`S5`0/8aL0P2`Re@01P2`ReH0/8]G0;2:F@2`RU/0/H]L0;6;GPP0[hYF202^R5T80:f9F@P0
[XYJ0P2^Qe`00`2^R5/0[XQI0:j8E`020:j9E@030:j9E02aRe`0/H]L0080/8YK0P2_REX02@2^R5T0
[HMH0:f7F02_RE`0[hUJ0:j8F@2^R5L0[XUE0:f8D`020:f8D@030:f7F02^R5T0/8YK0080/H]L00@0
/8YK0:j8F@2]QeP0[XQI0`2]QeP20:b6E`80ZhEF00@0[XUD0:f8D`2]R5<0[HQC0`2/Qe800`2[QU40
[8MC0:b7D`020:f8E0040:j9E@2_RUH0[hYF0;2;E`<0[XUE0P2_RUH30;2;E`040:^6DP2/Qe<0[8MC
0:b7D`<0[HQD00<0[XUE0:b7D`2/Qe<00P2/Qe<20:^6DP@0ZXEA0`2[QU830:b7D`80ZXAE0`2[QEH3
0:b6E`80/8]G00<0[hYF0:j9E@2]R5@00P2/Qe<20:^6DP070:b7D`2]R5@0[HQD0:f8E02[QU80ZHA@
0:R3C`080:Z5D@030:n5D`2^Q580[89@0080Zh5?00L0[89@0:j4DP2_QE<0[XUE0:b7D`2ZQE40ZHA@
0080Z8=?00<0ZHA@0:Z5D@2/Qe<00P2/Qe<30:^6DPX0ZXEA00H0ZXE@0:Z5D@2[QU80ZhED0:^5EP2/
QUT20:b5FP030:f8E02/Qe<0ZhIB00<0ZHA@00<0ZhIB0:b7D`2]R5@0202^RED00`2]RED0[8QD0:^7
D`020:Z6DP030:^7D`2/R5@0[HUE0100ZhEF0`2[QU820:Z5D@<0ZHA@202ZQE40202ZQDh0ZHA=0:N2
B`2VPDX0Yh9;0:V4C@2[QTl0[8M@202]R5@0202XPdl0ZHA@0:^6DP2]R5@0[XUE0:f8E02[QU80ZXEA
0`2^Q5820:f3D@<0[89@00P0[8M@0:^6C`2ZQE00ZHA@0:V3DP2[QEH0[HMH0:n9G0@0[8MC102]R5@0
1P2[QU80[8MC0:b7D`2]R5@0[XUE0:n:EP80/8]G00D0[hUL0:j8F`2^R5/0[HMJ0:b6F@020:^5F003
0:Z4E`2]QeP0[HMH00h0[HMH0P2/R5P0102]RET0[XYJ0:j:FP2_Re/20;2<G0030:f7F02^R5T0[hUJ
0080/8YK00L0[XQI0:b6E`2ZQ5D0[HMH0:j8F@2`RU/0/XaM0080/heN00<0/XaM0;2:F`2_REX00P2_
RUH30:j9E@<0[HQD1@2`ReL30;6<F0P0/8ID00<0/8]F0:n:E@2]R5<00P2/Qe800`2]R5<0[hYE0;2;
EP080:j9E@040:^6DP2/Qe<0[8MC0:b7D`80[HQD0P2^RED80:f8E080[hUJ0`2`RU/30;6;G0<0[hUJ
00<0[XQI0:f7F02]QeP00P2/QUL0202dRE@0/XUC0;68E02_Qe@0[HMF0:j:FP2^S5`0[heO202/R5P0
0`2^RED0[HQD0:b7D`020:^6DP030:b7D`2]R5@0[XUE0080[8MK00L0[HQK0:j:FP2^RUP0[h]G0;2<
F02`SEL0[XUE00<0[HQD0P2/Qe<20:^6DPP0[8MC0P2XPeL00`2XPeH0Z8AD0:R4DP020:R4D0040:R5
C`2[QU80ZhIB0:^6DP80ZXEA0`2YQ5020:b7D`040:^6DP2ZQE40ZXEA0:V4D080Z8=?2@2YQ5080:^5
EP060:f9F@2]REL0[HUG0:f9E@2]RU@0[HYB0P2]RU080:j9E@80[HQD00<0[8MC0:^6DP2ZQE400P2Y
Q5000`2XPdl0Z8=>0:R3CP060:R3CP030:Z5D@2YQ500Yh9>0080Yh9>00`0ZHA@0:b7D`2]R5@0[HMH
0:b6E`2ZQ5D0ZH=D0:Z4E@2[QEH0[XQI0:n9FP2XPU<30:N1DP040:R2D`2ZQ5D0[HMH0:j8F@<0ZXAE
1@2[QEH00`2XPd`0Yh9;0:F0B@020:F0B@030:N2B`2ZQDh0ZhI?00<0ZXAE00<0ZH=D0:R2D`2WPE80
0P2WPE802`2TOdP0YH190:N2C@2XPdl0ZH=B0:R2D`2WPE80YX1C0:AnC`2UOe00YX1A00<0Z89C2P2W
PE800`2VPTh0Y81<0:9nBP020:1lB0030:5mB@2ROTX0Y81<00P0X7e500<0XWa=0:=mCP2TOTl00P2T
OTl00`2RO4d0X7Y;09miBP020:9lC@030:5kC02PNT/0WgU:0080WWQ900<0WGM809YhBP2JN4X01`2J
N4X01`2ILd@0VgE609egB02ONDX0X7Y;09miBP2NN4T00P2MMdP01`2LMTL0VWA509UcA02ILd@0VWA5
09]eAP2LMTL0202HLT<01P2HMCl0Ug@n09Md?P2ELS`0U74k09=`>P80TVli00P0TVhl09=_?@2DL3h0
Tflm099^?02@K3X0SVXh08aX=PP0TfLh00@0RV@m08US?029Hc`0RF<l0P28HS/208MQ>P80Q5ha1025
Gc8208IP<`P0Pehd0`1mG3T[ooooo`00:_ooool309M[?P<0UVXm0P2EJC`809Q/?`80VFi100<0V6e0
09M/?`2FJch00P2EJSd00`2DJC`0Uf/j09M[>P0209M[>P80V6`k0P2IKC`00`2JL3h0VFlm09Q^?002
09M]>`0;09U_?@2KLCl0W79009M]>`2IKcd0Vg4o09ab@02MLd40W79009]a?`2JL3h0202HKS`209Y^
?@80Vfln0P2LL3l209ea@0<0WW=00P2OM4430:1e@PT0WW=000H0WG8o09ic@02OM440X7E20:5f@`2R
Md@:0:=hA@<0Y7Q700<0XgM60:9fA@2RMTD00P2QMD@01P2QN480XWU30:=jA02TNdD0YGa60:ImA`80
Ygi8202TNTP01P2QMdD0XWQ60:=iA`2TNTP0YG]90:IlBP80Yge;202UNdT80:MlC`P0Y7Y80`2NLdH2
09mdA`<0X7E800P0WGA009ec@@2LLT00VW1009U^@@2HKD80Ufa209I[@@80T6Xm0P2?JC`01P2>J3/0
SFLj08aV>@2<IST0QV0i08MQ>P80R68k00d0Qf4j08EO>023GCH0PE/d085O<@20GS40Oed`07eJ<01k
F300NULa07QD<01gDbl0NeD^00<0O5H_00L0NeD^07UC;01gDBX0MDlX06mA;@1^D2`0K4hZ0080JddY
00<0K4hZ06i@;01_DBd00P1[CBT206Y<:080JD/W0P1XBRH206e<:@0406a;:01[BRL0JTTV06U89@80
J4LT0`1XC2@406U=9@80JThV0P1bCbL0101dDBT0ME8Z07MD;01iERh207]H<00307iM<P1mG340O5T_
0080OEP^00<0OeP_089H<023FC400P20Fbh00`21G2l0PUd`08=N<@0208AO<P0308EP<`28HSD0R68e
00H0R68e202;H3<808]U=P80RfDh0P2:I3L208US=P80R68e0P2<HC@308eR=@0308aQ=02:Gc80REha
00P0RF<f0P2;ICP208YT=`0408US=P28HSD0R68e08QR=@P0Rf0e0P29Hc8608QR<@0308MQ=028HSD0
RF<f0080RV@g00<0RF<f08QR=@27HC@00P27HC8308QR<`<0RF<d0P2:Gc8208]P<`80S64d0P2=HSD8
08QR<`0@08YT=@2;ICH0S6Hg08eW>02<ISL0RfDf08US=028HS<0RfHa08]V<P29I300RF<b08US=02;
ICP0SFHk08iW?0T0S6Hg0`2<HC@308eR=@80SV<f0P2;ICH208YT=@80RF<d0P28HS<0202:I3D0RF<d
08QR<`27HC80R68c08US=02;ICH0SFLh2027Hc<00`2:IC40RF@`08MR;P0208EP;00308IQ;@27HRh0
R6<_00<0QV0a0P27HC8308QR<`0308EO<026H340R68c0080RF<d00<0R68c08IP<@25Gc000P20Fbh3
085L;`<0PUd`0P21GBd3081L;0<0Oe/[0P22GC03085L;`<0P5/^00X0OETY07]I:@1lFR`0NUT/07UJ
;P1eF2h0LUH^075E;@1bEBd0LeH^0P1dEbl0101cERh0LE@/06mB:P1]D2P206a?;@0606e@;P1/Cbd0
JTd[06Q;:@1UB2H0HdHT0P1QAbH00`1PB2H0GTLU05a89@0205Y8900705Q8901JABP0FTDX05Q59`1E
A2H0Dd8T05528`0204m28P80CSlN1P1?@1l01P1=?280C3`R04/k8@1:?240Ac`P04Dl7`80@S/N0P14
=b@204<f8`04048e8P11=240@3<P040c80T0>SDQ00<0=c<J03Pd6`0i=1h00P0j=B400`0h<b00=S0P
03D_7`0803Hc8080=C<L00<0=38M03@a7P0c<1l00P0c<2401P0b;R80<RlP038_800b;ah0<RlL038`
6`80<S0I00@0<S0G03@a8P0c<240<RlP0P0a;Ql00`0b;b00<c0Q03@a8P08030b7@0302d_6P0^<1/0
<38M0080<38M00H0;S0K02`^6@0[;AP0;b`M030]7P0b;b0203<`8@03038_800`;Ah0;b`M00<0;BhN
0P0/;Ad302//70<0;RlO0P0];Qh302`]7@P0;S0K100b;a`4034^6`08038]6@0c;QX0=C0L03Ha7@0g
<Qh0=S4M03D`700d;a/203<c6`0303@b6`0f<A/0=c4K0080>30K00T0>RlK03Ta700i<A`0>S8M03/c
7P0l=1l0?CDP03hf8@0o=b800`0l<b800`0k<R40>S4P03Xa800203T`7`80?3DK0`0j<aT00`0l=A/0
?SLM03lh7P0803df7080?SLM100l=A/=03hg7@80?cPN1010>Al00`0o>1h0?SLM03`e6`0203/d6P03
03`e6`0n=ad0?cPN00<0?CHL0P0n=ad303lh7PP0?CHL00<0@CLN040f7@10=Qd00P0o=A`203hd6`03
03dc6P0n=ad0?SLM00H0?SLM00<0?CHL03`e6`0k=1X00P0j<aT00`0k=1X0?CHL03hg7@0@040f7@P0
@SPO0`13>Ah204@j7`<0AC/P2016>R0204Pl8P80Ac/Q00L0ASXP04Di7`15>Al0ACTO04Lm8P16?240
A3XO0080@cTN00@0A3XO04Hl8@17?B80@SlP0P13?R000`13?1l0AC`O04Hk7`0204Li7P@0BSXP1P19
>Al204Xj80@0Bc/Q00T0C3hT04`n8`1>?R@0DD0T05918`1E@R80Ed<R05Q48`1AA1X00P1CAQ`05P1F
Aah0FdTQ05i;8`1QBb@0HT`U06=;9@1PBR<0HD/T069<9@1TCRL0IU0Y06QB:`1YDb`0JU@]06mC;01`
E2d0LED]079G;01dFB`0MEX[07IK;01gGB`207UJ:`0607]L;@1mGRl0Of0a085R<`22Hc@0Pf@e0P26
Hb/00`26Hbd0Qf<_08MS<@0208QT=00708QS=P2=IC80SVHc095Y=P2DK3T0UFdj09I^>`0209E]>P<0
UG0k0`2FLC`209Mb?@0609Mc?`2HM400V7A009Ue@@2JMT80VgM30P2LN4@409eiA@@0W7Q400P0WWY6
09mkA`2PO4P0XWi:0:=oB`2UPDd0YX9>0:N3C`@0Z8A@0`2YQE402P2ZQU80[8E>0:b5CP2ZQE00ZXIB
0:Z6E02YQeL0Z8QG0:R8F@2[QeL20:b8F0030:f9F@2^RUX0[h]K0080/8aL0P2aS5D01P2`ReH0/8]G
0;2:F@2`RU/0[hUJ0:n9G0P0[hYF202^R5T80:f9F@P0[XYJ0P2^Qe`00`2^R5/0[XQI0:j8E`020:j9
E@030:j9E02`RU/0/8YK0080/8YK0P2_REX30:j8F@060:n9G02_REX0[XQI0:j8E`2^RED0[HQC0P2]
R5400`2]QeP0[XQI0;2:F`020;6;G0030;2:F`2^R5T0[HMH00@0[HMH0P2/QUL20:^5EP@0[8MC102]
R5@20:b7D`80[HQD0P2^RED20:n:EP<0[XUE0`2_RUH20;2;E`@0[HQD102/Qe<0102]R5@0[8MC0:b7
D`2/Qe<20:^6DP@0ZXEA0`2[QU830:b7D`80ZXAE0`2[QEH30:b6E`@0[XUE102]R5@00`2[QU80[8MC
0:f8E0020:f8E0030:^6DP2YQ500Z8=?00P0ZXEA00<0[hEC0:j4DP2/PU000P2[PDl01`2/PU00[XAB
0:n5D`2]R5@0[8MC0:Z5D@2YQ5000P2XPdl00`2YQ500ZXEA0:b7D`020:b7D`<0ZhIB2P2ZQE401P2Z
QE00ZXEA0:^6DP2[QE@0ZhEF0:b6F@80[8EJ00<0[HQD0:b7D`2[QU800`2YQ5000`2[QU80[8MC0:f8
E0080:j9E@030:f9E@2/R5@0ZhMC0080ZHEA00<0ZhMC0:b8E02]RED0402[QEH30:^6DP80ZXEA0`2Y
Q5080:Z5D@030:Z5CP2YQ4d0Yh9;0080Yh9;00<0ZHA=0:^6C`2/Qe00202/Qe<00`2XPdl0ZHA@0:^6
DP030:f8E080ZhIB0`2^Q5830:f3D@80[89@00P0[8M@0:^6C`2ZQE00ZHA@0:Z4D`2[QEH0[HMH0:j8
F`@0[8MC202]R5@40:j9E@@0[HMH102/QUL@0:f7F0030:b8F02]RET0[HUI0080[XYJ0P2_Re/0302`
S5`0[HMH0:j8F@2_REX0/8YK0:n9FP2^R5T0[8IG0:^5EP2]QeP0[XQI0;2:F`@0/XaM00<0/8YK0:n9
FP2_RUH00P2_RUH20:j9E@<0[HQD202`ReL80;26E0030;2;E`2_RUH0[HQD0080[8MC00<0[HQD0:n:
EP2`ReL0202^RED40:b7D`80[HQD0P2^RED80:f8E0<0[hUJ0P2`RU/30;6;G0D0[XQI0`2]QeP0202d
RE@0/XUC0;68E02_Qe@0[HMF0:j:FP2^S5`0[heO202/R5P00`2^RED0[HQD0:b7D`020:^6DP030:b7
D`2]R5@0[XUE0080[8MK00<0[HQK0:f9F@2^RUP00P2_ReL00`2_S5H0[HQD0:f8E0020:f8E080[8MC
0P2[QU880:b7D`80ZXEI00<0ZXEH0:Z6EP2ZQU@00P2ZQU80102ZQe40ZhIB0:^6DP2[QU820:Z5D@<0
ZHA@00<0[8MC0:^6DP2[QU800P2ZQE420:V4D0030:R3C`2YQ500ZHA@00L0ZHA@202[QEH20:b8F003
0:b8EP2/R5@0[8UC0080[8UA00<0[8U?0:f8E02]R5@01P2]R5@01P2^RED0[HQD0:f8E02/Qe<0ZhIB
0:Z5D@80ZHA@202YQ4l02`2ZQE40ZHA@0:R3C`2WPTh0Z8=?0:Z5D@2/Qe<0[HQD0:j8F@2]QeP0ZhEF
0080ZXAE00<0ZhEF0:b6E`2^R5T00P2XPU<20:N1DP040:R2D`2ZQ5D0[HMH0:j8F@@0Yh5B102XPU<0
202WPT/0YX5:0:F0B@2TOdP0YH190:N2B`2YQ4d0ZXE>0`2YPe@00`2XPU<0Yh5B0:N1DP020:J0D@08
0:AoB02VPDX0Yh9=0:R3C`2YPe80Z89C0:J0D@2UOe850:J0D@030:N1DP2XPU<0Z89C00P0YX1A00P0
Y81<0:=oB`2QODT0X7a809mkA`2PO4P0XGe90:9nBPP0Wga400P0XG]<0:9lC@2SODh0Xge>0:9lC@2Q
Nd`0WgU:09egB080XG]<00<0X7Y;09miBP2NN4T00P2MMdP00`2LMTL0VGM909UgB@0709UgB@0@09Qb
@`2JM4D0W7I709egB02NN4T0WGM809afA`2KMDH0W7I709]eAP2ILd@0V79309Ma@P2HLT<0VG=409Yd
A@P0UFm00P2FLSh0102ELCd0U70l09=_>`2BKSX2095]>@08095]>`2BKS`0TVhl099^?02AKC/0Sf/i
08eY=`2;IcD8095W=`0408US?028HS/0R68k08QR>`80Qf4j0P26H3T808EN<`P0P5dc0`1oGS/[oooo
o`00:_ooool309M[?P<0UVXm0P2EJC`409U]@0@0VVi1202GK3l309M[>P80V6`k0`2IKC`01P2IKcd0
V6hl09Q^?02GKC/0V6hl09U_?@80Vg4o00L0V6hl09U_?@2KLCl0W79009ec@@2LLT00Vg4o00T0VW0n
0`2KKch309a`?`80WG500`2NLd0209md@@<0X7E22`2NLd000`2OM440X7E20:5f@`020:9gA0030:=h
A@2RMd@0XWM400H0XWM40P2TN4L30:=gAP<0XWI50P2RNDD00`2SNTH0Y7]70:ElB0020:ImB@030:Mn
BP2TNTP0Y7Y800H0Y7Y80P2RN4H00`2SNDL0Y7Y80:EkB@020:IlBP030:MmB`2TNTP0Y7Y800H0Y7Y8
202WO4l20:IlBP030:EkB@2TNTP0XgU70080XWQ600<0XGM50:1eB02PMDP00P2OM4L409icAP0609]b
?P2JL3h0VW0n09U_?`2IKT40V6e20P2HKD<01P2@JSd0SfTl08mY?02>J3/0SFLj08aV>@80RfDh0P26
H3T208MQ>P0<08IP>@24GSL0PU`e085K=021Gc40P5ha07mM<01mFS00NeP`07UF<01hE300Me<_0P1i
Db`307YD;@0907QB:`1eCbP0M4hW075C;`1_DBd0KDl[06]=:@1ZC2P0JddY0080K4hZ0P1[CBT206Y<
:080JD/W0P1XBRH806]:9`80JD`T0P1ZCBD306]>9P80K4lW00/0LDhV079?9`1cD2P0ME8Z07MD;01i
ERh0NUL_07]H<01nGC80OE`a07eJ<00207iI;`03081I<023FC40QE/c0080P5/^0P21G2l01022GC00
Peha08AO<P24Gc8808US=PP0S64d202;ICH0102;ICP0RV@g08YT=`2:I3L308US=P0408QR=@2@ICP0
Sf@g08eR=@<0S64d0P2=HSD808US=P<0RV@g0P29HcH308QR=@P0Rf0e2028HS<00`27HC@0R68e08YT
=`0208]U>00308YT=`28HSD0Qf4d0080Qf4b0`28HS<308US=0<0Rf0c0`2<HC@208eR=@P0RF<d00T0
RV@e08]U=P2<ISL0SFLh08aV=`2;ICH0RF<d08QR<`2;IS400P2:IC401@29Hc80RV@e08]U>02<ICX0
SFHk00T0S6Hg0`2>HcH308eR=@80S64d0P2;ICH208YT=@80RF<d0P28HS<00`2:I3D0RF<d08QR<`02
08QR<`0308YT=@2;ICH0S6Hg00P0R6@d00<0RVDa08UT<027HRh00P25H2`00`26HBd0Qf8^08QS;`03
08QR<`80Qf4b0`26H3400`25Gc00QV0a08QR<`0208US=00408QR<`26H340QEl`08=N<@<0PUd`1021
G2l2085M;@<0P5`/0`1oFb/0101oFRd0P5/^081K;P20Fbh4085L;`0607mK:`1lFRX0NUPZ07QG:P1f
Eb/0M5L]0P1cEbl4079E;@04075D;01`Db/0KU4Y06e@:080JTd[00H0Jdh/06Y=:`1YC2X0J4/Y06I9
9`1UB2H206579P0305m79@1NAbD0FdLT0080FTPT00L0EdLS05Q39P1H@bH0Ed@V05A39@1C@R@0DT<T
0080D4<S201>?b001P1=>b<0Bc/R04/k8P19>b40ASXP04@j7`80@CXN00H0@cPT048g8`12=b<0@CHR
040e8@0o=20203hc7`T0>cHR00<0=c<J03Pd6`0i=1h00P0i=2000`0g<Ql0=S0P03@^7P0803Db7`80
=38K00<0=38M03<`7@0c<1l00P0b;b02038^8P80<RlP00<0<RlN038_700b<1/00P0b<1T00`0c<240
<RlP034^7`02030]7P03034^7`0b;b00<c0Q00T0;BlJ00L0;S0K02la700_<A`0;S0K02d_6P0/;QT0
:bdH0080<2dN00@0<BhO038_800b;b00<BhO0P0`;Ah302d^7P80;2dM0`0[;1`202h_7`80;BhN0`0/
;Ad00`0[;1`0;S0K02h`6`0602h`6`@0<BhK100b;a`00`0b;AT0<bhJ03D`700303Ha7@80=C0L0P0d
=1`00`0e<a`0=c8L03Pb700203Ta700703/`700i<A`0>S8M03Xb7@0k<ah0?3@O03de800203hf8@<0
?3@Q0P0k<b0303Xb7`0703`e6`0k=1X0>c@J03Xc6@0k=1X0?3DK03df700903hg7@80?3DK100n=ad2
03`e6``0?SLM0P0o>1h3040i7`0303lh7P0n=ad0?3DK0080>c@J00@0?3DK03hg7@0o>1h0?3DK0`0m
=Q`203hg7@80?cPN200m=Q`3040f7@80?cDL0`0n=1/903hg7@0503df700l=A/0>c@J03/d6P0l=A/0
0P0m=Q`@040f7@P0@SPO0`13>Ah204@j7`<0AC/P2016>R0304Lk8@<0ASXP0P15>Al00`16?240AC/P
04@j7`0204<i7P0904@j7`15>b00AS`Q040m7P11?1h0@SdO04<l7`15?1l0Ac`P0080BC/P0P1=?B<0
0`1<?280Bc/Q04Xj800604Ti7`80BSXP0`1;>b401P1;?B<0C3hS04hn901@?b<0DD0R05E28P80Ed<R
0`1EAb00:P1FAb00FDLQ05a88`1PBRD0HddX06E=:@1OBB80H4XS065;901SCBH0IDlX06MA:P1XDR/0
JE</06iB:`1_Db`0L5@/075F:`1cF2/0M5TZ07EJ:`1fG2/0N5TZ07UJ:`1jFb`0O5d^07iO<020HC80
PF8c089S=025HRX0QV<[08IS;@26HRh0Qf<a08MS<`28I3@0R6<f08]V<P2<Ic<0SVTe091[=`@0TVdi
0P2DKcX209E`>`<0UW4l00L0Ug8m09Ib?P2GLcl0Ug<o09Qd@02IMD40VWI20080VgM31`2MNDD02@2N
NTH0Wg]709mkA`2PO4P0XGe90:=oB`2TP4`0YH5=0:J2CP020:V5D@<0Z8A@0`2WPdl0202[Q4d0[8E>
0:Z5D02YQE40ZXID0:R6EP2XR5L0Z8QI0P2[QeL00`2/R5P0[HUI0:j:FP020:n;F`090;2<G02bSEH0
/HaE0;6<E`2`ReL0[hUH0:n9FP2^R5T0[XQK00P0[XUE202^R5T@0:f9F@80[XML00<0[XQK0:j8F@2^
R5L00P2^RED00`2^RE@0[XQI0:j8F@020:j8F@80[hUJ0`2`RU/01P2_RE`0[hUJ0:j8F@2^R5L0[XUE
0:f8D`80[HQA00<0[HMH0:j8F@2_REX00P2`RU/00`2_REX0[XQI0:f7F0030:f7F080[8IG0`2[QEH0
1@2ZQE40ZhIB0:^6DP2/Qe<0[HQD0080[XUE00<0[hYF0:b7D`2/Qe<00`2]R5@30:j9E@80[HQD0P2^
RED30:n:EP060;2;E`2_RUH0[XUE0:j9E@2]R5@0[8MC0P2[QU80102ZQE40[HQD0:f8E02]R5@20:b7
D`<0ZhIB0P2ZQE430:^6DP<0[8MC0P2ZQ5D30:^5EP<0[8IG0P2/Qe<30:f8E0<0[XUE0P2[QU830:f8
E0030:^6DP2ZQE40Z8=?00P0ZhIB00<0[hEC0:j4DP2/PU000P2[PDl01P2/PU00[XAB0:n5D`2]R5@0
[8MC0:Z5D@80Z8=?00<0ZHA@0:Z5D@2[QU800`2/Qe<30:^6DPX0ZXEA00H0ZXE@0:Z5D@2[QU80ZhED
0:^5EP2/QUT20:b5FP030:f8E02/Qe<0ZhIB00<0ZHA@00<0ZhIB0:b7D`2]R5@0202]R5@00`2]RED0
[8QD0:Z6DP020:V5D@030:Z6DP2/R5@0[HUE0100ZhEF0`2[QU820:Z5D@<0ZHA@202ZQE420:V4C`<0
Z8=>00<0ZHA?0:^6D@2/Qe80202[QU801@2YQ500ZXEA0:^6DP2/Qe<0[HQD0080[8MC00<0ZhIB0:n5
D`2_QE<00P2^Q5830:f3D@090:b2D02[QTl0ZhI?0:Z5D02ZQE40ZXAC0:^5EP2]QeP0[XQK00@0[HQD
102/Qe<30:j9E@<0[HQD0P2/Qe<40:b6Ea@0[HMH0`2]RET20:j:FP<0[h]K0P2^R5T30:n9FP060:j8
F@2/QUL0ZhEF0:f7F02^R5T0/8YK102aRe`20;2:F`040;2;E`2_RUH0[hYF0:n:EP80[XUE0P2]R5@8
0;2;E`P0/8ID00<0[hYF0:j9E@2]R5@00P2/Qe<00`2]R5@0[XUE0:n:EP080:j9E@<0[8MC0P2]R5@3
0:j9E@P0[HQD00@0[XQI0:n9FP2_REX0[hUJ0P2`RU/20;6;G0<0[HMH102^R5T02@2_REX0]8UD0;:9
D`2aR5@0[hMD0:f7EP2^RUX0[XaL0:n=G`080:b8F0030:j9E@2]R5@0[8MC0080ZhIB00P0[8MC0:f8
E02^RED0[8MK0:f8G02]R5/0[HUI0:j:F080[XYF00@0[haF0:f8E02]R5@0[HQD0P2/Qe<30:^6DPP0
[8MC0P2[QUX00`2[QUT0ZhMG0:^7E@020:^7D`040:^8DP2[QU80ZhIB0:^6DP80ZXEA0`2YQ5030:^6
DP80ZXEA302YQ5080:Z4E@060:b7FP2/R5P0[8QH0:b8EP2/R5@0[8UC0P2/RE480:f8E0060:n:EP2^
RED0[XUE0:f8E02/Qe<0ZhIB0P2ZQE480:V4C`0<0:Z5D@2YQ500ZHA@0:R3C`2YQ500ZXEA0:^6DP2/
Qe<0[hUJ0:j8F@2/QUL0ZhEF0`2ZQ5D00`2[QEH0ZH=D0:R2D`020:N1DP040:R2D`2ZQ5D0[8IG0:f7
F0P0YGm@0P2UP4/30:AoBP030:F0B`2WPTd0Z8=>00<0Yh5B0P2VP5430:EoD00@0:AoB02UP4T0Yh9=
0:R3C`2XPU40Yh5B0:EoD02TOU40Yh5B0:J0D@2TOTl0XWa=0:=mCP2UOe00Z89C0:Z4E@P0Y7i?00D0
XGe90:1lB02ONdL0WWY609eiA@0209ijAP0309mkA`2MNT@0WGY400H0WGY400P0WWQ909miBP2PNT/0
XG]<0:1jB`2ONDX0WGM809afA`80WgU:00<0WWQ909egB02LMTL00P2KMDH00`2JM4D0V7=609QcAP07
09QcAP0309Ma@P2HLT<0VG=400<0VWA50P2ILd@0102LMTL0VWA509Qb@`2EKd0309A^?`0309E_@02B
K3d0TV`m00H0TV`m0P2CKc/2099^>P06095]>@2@K3P0Sf/g08m[=`2>JSX0Sf/k0P2@K3`0102?Jc/0
SFTi08]W=`2:ISH808iS=P80Qf4j0P26H3T308EO>00308AN=`24GcD0Pehd00H0Pehd201nFc<307aK
>2_ooooo000Zooooo`<0Uf/n0`2FJSd209EY?0@0VVi1102KKd8309I[?P0309M/?`2HKD00VFi10080
VFi10P2GJcX209Q/>`80VFdl0P2JKSd409Q^?00709U_?@2JL3h0VW0n09]a?`2HKS`0VFlm09]a?`03
09ec@@0309ab@02KLCl0W79000L0W7901P2LL3l209ea@0<0WW=00P2OM4430:1e@PT0WW=00`2OM440
0`2PMD80XGI30:5f@`0:0:9gA0H0XgM60P2RMTD30:=iA`030:AjB02UNdT0YG]90080YWa:202TNTP3
0:=iA`030:AjB02UNdT0YG]90080YWa:202SNDL80:MmC@080:QnC02WOD/0YWa:0:AjB02RN4H0XGM5
0:1fA02OMD<20:5fB@070:1eB02OM4L0WW=609ebA@2LLD@0Vg1309Q_>`0209Q^?00309Q^?P2HKD00
V6e20080V6e30P2?JC`0102>J3/0SFLj08aV>@2;ICP208YT=`<0QV0i00/0QElh08AN=`23GCH0PU`e
085K=020GS00P5ha07iL;`1lFBl0NeP`07UF<00207MC;`0<07I@:@1gDBX0N58[07UC;01hDR/0Me4Z
07E?:01cCBH0LU@`071B;P1]Cb/0JddY0`1ZC2P306]=:@80JT`X0P1YBbL206Q:9P0406U89@1ZBBH0
JTTV06]:9`80K4/X0P1]C2T01@1[Bb@0K4`U06a<9@1]CBH0KThW00<0KdlX00`0L50Y075>9P1bCbL0
Le0X07EB:P1gE2`0NEH^07YG;`1kF300Oehc07iM<P1mFS0207mJ<003085J<@25Fc<0QU`d0080P5/^
00<0PE`_089M<023GS400P24Gc800`25H3<0RF<f08US=P0608US=PP0S64d202;ICH408YT=`@0RF<f
00P0TVLj095V>@2>HcH0S64d08]P<`2<HC@0SV<f091U>0`0RF<f1028HSD808]P=@0308MQ=028HSD0
R68e0080R68e0`29HcH00`27HC@0RF<f08YT=`0208]U>00308YT=`29HcH0Qf4d0080Qf4b0`28HS<3
08US=0H0S64d0P2=HSD808]R=00908YT=@2;ICH0S6Hg08eW>02<ISL0RfDf08US=028HS<0RVD`0080
RVDa00<0RV@c08]U=P2;ICP00P2<ICX908aV=`05091U>02?I3L0Sf@g08iS=P2=HSD00P2<HC@00`2;
H3<0RfDf08]U=P0208YT=@80RF<d0P28HS<508US=00308YT=@2;ICH0RfDf00P0R6@d00<0RVDa08UT
<027HRh00P25H2`00`26HBd0Qf8^08QS;`0208US=00408QR<`27HC80Qf4b08IP<@<0QEl`00L0QV0a
08QR<`29Hc@0RF<d08QR<`26H340QEl`0080Q5lb00@0Peha089M<022GC00PE`_0P20Fbh2085M;@<0
P5`/0`1oFb/207iI;00407mJ;@20Fbh0P5/^085L;`80PUd`00P0P5`/07aJ:P1iEbT0MUDX07AE:@1b
EB/0LeL_07EI<@<0LE@/00D0L5<[06mB:P1^DBT0KE0X06a?9`0306U<:P80J4/Y00<0IdXX06I99`1V
BBL00P1PARD01P1OAbD0GDHT05]7901JB2@0FDLS05M78`80ET4T00@0ED8T05=2901C@R@0DT<T0P1A
A2@404dn8@@0C3dP00H0C3XT04/k901:>R<0B3TR04Di8@13>B02040i7`80@3PS00@0?cLR03hf8@0m
=B00?3@O0P0k<ah903/f8P0803Hb6@0g<aX0>3<M03Td800h<al0=c8O03D_7`0c;Ad803<`7`80<c4J
00<0<c4L038_700b;ah00P0a;Ql01`0a;B40<BdR034]8@0a;B40<BhO034^7@0a;Q/00P0a;aX00`0b
<240<2hO02l]7P0202h/7@0302l]7P0`;Ql0<S0Q00P0:b`J1@0];Q`00`0/;A/0:b`J02//6P0202l]
7P@0<2hO0P0_;Ah302d^7P80;2dM0`0[;1`302d^7P<0;2dM0P0[;1`802h`6`@0<BhK100b;a`00`0c
;QX0=2lK03@_6`0203D`70<0=S4M0P0d=1`00`0e<a`0=c8L03Pb700203Ta700303/`700j<Qd0>S8M
0080>c<N00@0?3@O03de800m=B00?CDP100l=1l403/c7P@0>c@J0P0l=A/203df70P0?SLM00<0>S<I
03`e6`0n=ad00P10>Al00`0n=ad0?3DK03Xc6@0903hg7@80?CHL0P0n=ad203lh7P80@3TO00<0?cPN
03hg7@0l=A/00P0k=1X00`0l=A/0?SLM03lh7P0203`e6`<0?CHL0`0n=ad803df70P0?cDL2P0n=ad0
0`0m=Q`0?3DK03`e6`0303`e6`P0?cDL2010=Qd8048h7`<0@cTN0P14>Ql304Dk80P0ACTO0P17>b46
04Hj800304Hl8@15>b00A3XO0080@SPM0140A3XO04Dk8016?240?c`M040k7@11?1h0@c`O04Hm8018
?B40BS`Q04/m8P1>@2D0CClT04`n8`1;?B80BS`Q04Pj7`0204Li7P80B3PN0P19>Al204Xj8080Bc/Q
00H0BS`R04/m8P1=?B<0CchR050o8@1D@B4205I28@0O05I88`1EAb80EDLR05E58@1FA200FDDR05i7
9@1RBbT0IDd[05i88@1OBB80H4XS069<9@1TCRL0IDlX06MA:P1XDR/0KE4Z06iB:`1_Db/0L5DZ075F
:@1cF2T0M5TZ07AJ:@1hFBX0NEX[07YK;01kG2d0OEh_07mP<@02081Q<P80QF8Z00<0QV<]08IR;P26
HS000P27Hc<01P27HSD0RfLc08]W<`2=JCD0SVXf08m[=`<0T6`h0`2DKcX209E`>`<0UW4l0P2FLSh2
09Mc?`0409Qd@02IMD40VWI209Yf@P@0WGU5102NNTH209mkA`060:1lB02QODT0XWi:0:=oB`2TP4`0
YH5=0P2YQE40102XQ500Yh=?0:N3C`2VPTh20:F1C@80ZhA=00H0ZXE@0:V5D@2YQE<0Z8IF0:N7EP2W
QeP20:^7E`040:b8F02]RET0[HUI0:j:FP80[h]K00P0/XeF0;6<E@2aS5L0/8]G0:n9F02^R5T0[HMH
0:f7FPP0[XUE202_REX80:j:FPP0[HUI0P2^Qe`00`2^R5/0[XQI0:j8E`020:j9E@030:j9E02]QeP0
[HMH0080[XQI0P2_REX02@2`RU/0/H]L0;6;G02_RE`0[hUJ0:j8F@2^R5L0[XUE0:f8D`020:f8D@03
0:b6E`2]QeP0[hUJ0080/8YK00<0[hUJ0:f7F02/QUL00P2]QeP20:b6E`80ZhEF0P2ZQ5D0202YPe80
ZXAC0:^5E02/QUD0[HMF0:j8E`2_REP0/8YI0P2/Qe<90:f8E080[XUE0`2_RUH0202`ReL0[hYF0:j9
E@2]R5@0[8MC0:^6DP2ZQE40ZHA@0`2]R5@30:b7D`80ZhIB0P2ZQE430:^6DP<0[8MC0P2ZQ5D30:^5
EP<0[8IG00H0ZXEA0:^6DP2[QU80[8MC0:f8E02^RED20:n:EP030:Z5D@2[QU80[8MC0080[HQD00<0
[8MC0:Z5D@2YQ500202[QU800`2_QE<0[XAB0:b2D0020:^1C`060:b2D02^Q580[hEC0:b7D`2[QU80
ZHA@0P2XPdl00`2YQ500ZXEA0:^6DP030:b7D`<0ZhIB2P2ZQE401P2ZQE00ZXEA0:^6DP2[QE@0ZhEF
0:b6F@80[8EJ00<0[HQD0:b7D`2[QU800`2YQ5000`2[QU80[8MC0:f8E0080:f8E0030:b8E02[Qe<0
ZXIB0080ZHEA00<0ZXIB0:^7D`2/R5@0402[QEH30:^6DP80ZXEA0`2YQ5080:Z5D@@0ZHA@0P2ZQE42
0:^6DPP0ZHA@0P2ZQE420:^6DP@0[8MC0`2_QE<20:j4DP<0[H=A0P2ZQDh00`2ZQE00ZhIB0:^5E002
0:b6E`030:f7FP2]R5@0[HQD0080[HQD102/Qe<20:n:EP030:j9E@2]R5@0[8MC0080ZhIB00H0ZXEA
0:Z4D`2[QE@0ZhED0:b6E@2]QeH20:j8E`030:n9F02]QeP0[HMH00H0[HMH202^R5T80:j:FP<0[hUJ
0P2^R5T20:f7F0030:b6E`2^R5T0[XQI0080[hUJ1@2`RU/20;2;E`<0[hYF0`2^RED30;2;E`@0[hYF
00<0[XUE0;26E02`QU@01P2`QU@30:j8E`80[HMF0`2^R5L80:j9E@80[8MC0P2]R5@20:j9E@80[hYF
202^RED20:j8F@<0[hUJ0`2`RU/01@2/QUL0[HMH0:f7F02]QeP0[XQI00<0[hUJ00P0]8UD0;:9D`2a
R5@0[hMD0:f7EP2^RUX0[XaL0:n=G`P0[8QH00<0[XUE0:f8E02/Qe<00P2[QU800`2/Qe<0[HQD0:j9
E@020:f8G0030:f8F`2]RET0[HUG0080[HUE00<0[HYD0:f8E02]R5@00P2/Qe<20:^6DP80ZXEA202/
Qe<20:b7F`030:b7FP2/R5P0[8QF0080[8QD00@0[8UC0:^6DP2[QU80ZhIB0P2ZQE430:V4D0P0ZXEA
2@2YQ5080:V3E0060:^6FP2[QUT0ZhII0:^7E`2[QeD0ZhMC0P2[R5880:b7D`060:n:EP2^RED0[XUE
0:f8E02/Qe<0ZhIB0P2ZQE480:V4C`<0ZHA@00<0Z8=?0:V4D02YQ5000P2ZQE420:j8F@030:b6E`2[
QEH0ZH=D0080Z89C00<0Yh5B0:R2D`2WPE800P2VP540102WPE80Z89C0:Z4E@2[QEH20:J0D@@0YGm@
0P2TOTl00`2TOd/0Xgi:0:=nBP020:=nBP<0Y7m;1@2TOTl30:=mCP80Y7m800h0YX5<0:J1C@2VP4l0
YGm@0:=mCP2RO4l0Yh5B0:AnC`2QNd`0WWQ909miBP2RO4d0Yh5B0:V3E0P0X7Y;0P2MNDD00`2LN4@0
VgM309]g@`0309]g@`P0VWI200<0VWA509]eAP2LMTL00P2MMdP00`2LMTL0VWA509UcA00209afA`04
09]eAP2JM4D0VG=409UcA080V7932@2EKd8309E_@0@0UW1100D0UFm009UcA02HLT<0UFm0099/?@04
091Z>`P0TF/l00<0T6`j08m[>@2?JcT00P2>JSP208eY=`0308aX=P2;IST0S6Lj00<0SFPk00<0RfHi
08UT=`28HcH0202:HCD01025GcP0Q5hg08AN=`24GSL208=M=P80PU`e00<0PEhd081M<`20GC<00P20
GC<307mL<PP0NELa0`1fEC8[ooooo`00:_ooool309M[?P<0UVXm0P2EJC`209U]@080VVi10P2KKd82
09a`@`0409EZ?@2FJch0Uf`o09M/?`80VFi100<0VVm209]`@`2HK3/00P2HK3/209U]?0<0VVhm00@0
Ufdk09Q^?02HKS`0VFlm102JL3h0202IKcd0VW0n09ab@02MLd40WWA209ec@@2LLT00Vg4o202LLT06
09ea@080W70o0`2NLd0209md@@<0X7E22@2NLd000`2OM440X7E20:1e@P020:1e@P/0XGI30P2RMTD6
0:=gAP030:=iB@2TNTX0Y7Y:0080Y7Y:0`2UNd/80:AjB0030:=iA`2TNTP0Y7Y80080Y7Y80`2UNdT8
0:AjB0P0Yge;00H0Z7i<0:MmB`2VO4X0Y7Y80:9hAP2PMT@209id@P060:9gBP2QMTT0X7E809mdA`2M
LTD0W7540P2JKd801P2GKSX0Ufdk09M]>`2GKCd0Uf`o09M/@@80Ufa20P2>J3/0102=IcX0S6Hi08]U
>02:I3L208US=P0508IP>@25GcP0Q5hg08=M=P22G3D00`21Fc@02`20GS00Oed`07iL;`1lFBl0NUL_
07QE;`1gDbl0MU8^07E?:01fD2T0Me4Z0080N58[00L0MU0Y07E?:01dCRL0LE<_06mA;@1]Cb/0JddY
0080JD/W0P1ZC2P206]=:@80JT`X0P1YBbL206Q:9P0606U89@1ZBBH0JTTV06]:9`1/BbP0KD`Y0P1^
CBX206e;9@0306i<9P1_CBL0L4hX0080LDlY0P1bD2X04@1cD2P0M54Y07EB:P1gE2`0NEH^07YG;`1l
FC40OEXb07mN<`1nGC80OU/a07mJ<020Fc40Pe`c08MM=@28GSH0PE`_0080PUd`00<0Peha08AO<P25
H3<00P26HC@808YT=`P0SF8e202;ICH408US=P@0RV@g00P0TVLj095V>@2>HcH0S64d08]P<`2<HC@0
SV<f091U>100R68e202;H3D308MP=@0308QQ=P29HSL0RF8g0080RV<h00<0R68e08US=P2:I3L00P2<
IST00`2:I3L0RF<f08QR=@0208MQ<P<0R68c0`29Hc@608eR=@80S64d202=HSD02@2:I3D0RfDf08aV
=`2=IcP0S6Hg08]U=P29Hc@0R68c08UT;`0208YU<@0308]U=02;ICH0S6Hi0080S6Dj2@2<ISL2091U
>00408mT=`2>HcH0SV<f08eR=@80S64d0P2;ICH208YT=@80RF<d1028HS<00`29Hc@0RV@e08YT=@03
08YT=@P0RFDe00<0RVDa08UT<027HRh00P25H2`00`26HBd0Qf8^08QS;`0208US=00408QR<`27HC80
Qf4b08IP<@<0QEl`00P0QV0a08QR<`29Hc@0RF<d08QR<`26H340QEl`08EP<`80Q5lb00D0Peha089M
<021G2l0PE`_081K;P02085M;@<0P5`/0`1oFb/01@1mF2/0OUT/07iI;01oFRd0P5/^0080PE`_00h0
PUd`081L;01lFRX0NELY07ED9`1cE2P0LUD[07=G;`1dF300LE@/071C:`1_DRX0KU4Y06e@:0<0K4lW
00@0JD`Z06Q;:@1WBRP0IdXX101VBBL206169@0305i6901MAR@0FdLT0080FDLS00@0EdLS05I1901F
@B@0ED8T0P1C@R@0101B@b@0DD@T0554901=?B<204`l8P80Bc/Q0P1:>R001`19>Al0BcTU04Xi9@19
>2@0AcPS04@h8P12=b400P0o=b0203hh8P0403dg8@0l=R00>cDO03Xd7P80>C<M2@0j=B40200e<AP0
=S8I03Lb700h<al0=c8N03Ha7P0d;Qh0<bdM200b;b02038`6@03038`6`0a;Q/0<BhM0080<2dN00L0
<2`P030/8`0`;240<2`Q030/800`;Ah0<2dL0080<2dJ00<0;c0P02h_7`0/;Ad00P0[;1`00`0/;Ad0
;RlO02l`800802TZ6P80;BhN00<0;2dM02//700[;1`00`0[;1`;02d^7P80;2dM0`0[;1`202d^7P<0
;2dM0`0[;1`802d_6P80<2dJ0P0a;Q/2038_7080<c0M100d;a/203D`7080=S4M0P0e=Ad00`0f=1d0
>3<M03Tc7@0203Xb7@0403`a7@0k<ah0>c<N03/c7P@0?3@O00<0?CDP03`d7@0l=1d01P0l=1d00`0j
<aT0>c@J03/d6P0203`e6`<0?CHL200o>1h00`0j<aT0?3DK03hg7@02040i7`0303hg7@0l=A/0>S<I
00T0?SLM0`0m=Q`203hg7@@0?cPN00L0?SLM03`e6`0k=1X0>c@J03`e6`0n=ad0?cPN00<0?3DK0`0m
=Q`203hg7@P0?CHL200o=A`<03hg7@80?CHL00<0?3DK03/d6P0o=A`01`0o=A`8040f7@P0@SPO0`13
>Ah204@j7`<0AC/P2015>Al604Hj8080Ac/Q00<0AS`Q04@j7`13>Ah00P12>1d02`13>Ah0A3XO04Hl
8@0o?1d0@3/M044l7P13?1l0ASdP04Pm8@1:?240BcdR0080Bd0T00H0BSlS04Tn8P17?200AS/O04Dj
7P14>Ad304Ph7P80BCTO0`1:>R001P19>b40BS`Q04`l8P1>?B40D3lQ05=08080ED4P0140EDLT05A6
8`1DAR<0Dd<Q05E28@1G@b80G4DU05m8:01SBR/0G4HO05e7801OBB80H4XS069<9@1TCRL0IDlX06I@
:@0206a@:@0706eA:@1_E2T0L5DX075F9`1bEbP0LeTX07QI:P0207UJ:`0507]L;@1lGBh0OEh_07iO
<01oH3400P25HRX01P25HR`0QV8^08IR<026HS80Qf<c08MR=@80RfLc0P2<J3@0102=JCD0SVXf08m[
=`2@K3P209=^>@80U6lj0P2EL3/209Ia?080UG4m00@0UW8n09Mc?`2HM400V7A00P2IMD4209]g@`80
W7Q40P2MNDD209ijAP0409mkA`2PO4P0X7a80:5mB@80XWi:0P2SOd/20:R4D0040:N3C`2VPTh0YX9>
0:F1C@80Y81<0P2[Q4d01P2YQ4l0ZHEA0:V5D`2WQED0YhMF0:N7F080ZXIF00@0ZhMG0:b8F02]RET0
[XYJ0P2_Re/0202aS5D0/8]D0;2;EP2_RUH0[XQG0:j8F@2]QeP0[HMJ202^RED80:n9FPP0[XYJ202]
RET20:j7G0030:j8F`2^R5T0[XQG0080[XUE00<0[XUD0:f7F02]QeP00P2^R5T20:n9FP090;2:F`2a
Re`0/H]L0:n9G02_REX0[XQI0:j8E`2^RED0[HQC0080[HQA00<0[8IG0:f7F02^R5T00P2_REX00`2^
R5T0[HMH0:b6E`030:b6E`80ZhEF0`2ZQ5D0202YPe@0ZXAE0:^5EP2/QUL0[HMH0:j8F@2_REX0/8YK
0P2]R5@80:b7D`80[HQD0P2^RED20:n:EP080;2;E`2_RUH0[XUE0:f8E02/Qe<0ZhIB0:Z5D@2YQ502
0:j9E@<0[HQD0`2/Qe<20:Z5D@<0ZhIB0`2/Qe<20:Z4E@<0ZhEF0`2/QUL20:Z5D@030:^6DP2/Qe<0
[HQD0080[XUE00@0[hYF0:V4D02ZQE40[8MC0P2]R5@00`2/Qe<0ZhIB0:Z5D@080:b7D`030:n5D`2^
Q580[89@0080Zh5?00H0[89@0:j4DP2_QE<0ZhIB0:Z5D@2YQ5020:R3C`030:V4D02[QU80[8MC00<0
[8MC0`2[QU8:0:Z5D@060:Z5D02ZQE40ZhIB0:^5E02[QEH0[8II0P2/QEX00`2]R5@0[8MC0:^6DP03
0:V4D0030:^6DP2/Qe<0[HQD00P0[8MC00<0[8QD0:^7D`2YQE400P2XQ5000`2YQE40ZhMC0:b8E00@
0:^5EP<0ZhIB0P2ZQE430:V4D0P0ZXEA0P2YPe820:Z4D`@0ZhED202YQ5030:Z5D@80ZhIB0P2/Qe<0
0`2]R5@0/8ID0;26E0020:n5D`80[XAB0P2]Pe420:Z5CP030:^6D@2[QU80[8IE0080[8IG00<0[8II
0:j9E@2^RED00P2]R5@20:b7D`80ZhIB00H0[hYF0:j9E@2^RED0[HQD0:b7D`2[QU830:Z5D@80ZhIB
00D0[8MC0:f8E02^RED0[XUE0:n:EP080:f7F0P0[XQI202^RUX20:n9FP80[XQI102]QeP40:j8F@<0
[hUJ0P2`RU/30;2;E`<0[hYF0P2^RED30;2;E`030:n:EP2^RED0[XUE0080[HQD202`QU@00`2]QeP0
[XQI0:j8F@040:j8F@030:f7F02^RED0[XUE00H0[XUE0`2]R5@20:j9E@<0[hYF202^RED30:j8F@<0
[hUJ0P2`RU/30:f7F0D0[XQI00P0]8UD0;:9D`2aR5@0[hMD0:f7EP2^RUX0[XaL0:n=G`P0[8QH00<0
[XUE0:f8E02/Qe<00P2[QU800`2/Qe<0[HQD0:j9E@020:f8G0030:f8F`2]RET0[8QF0080[8QD00@0
[8UC0:b7D`2/Qe<0[8MC0P2[QU830:Z5D@P0ZhIB0P2/Qe/00`2/QeX0[8QH0:b8EP020:b8E0040:b9
D`2[QU80ZhIB0:^6DP80ZXEA0`2YQ5080:Z5D@T0ZHA@202XPU<01P2ZQE/0ZXEI0:Z5F@2ZQEP0ZXIF
0:Z6E080ZXIB202[QU801P2^RED0[HQD0:f8E02/Qe<0ZhIB0:Z5D@80ZHA@202WPTd20:N2CP80Z8=?
0`2WPTh02`2VPDd0ZhEF0:^5EP2ZQ5D0ZH=D0:R2D`2VP540YGm@0:AnC`2WPE80YX1A00<0Y7i?00@0
YGm@0:N1DP2XPU<0Z89C0P2WPE820:J0D@80YGm@00<0Y7i?0:5kBP2RO4/00`2RO4/30:5kBPD0XG]<
0`2RO4d0402QO4D0XWe60:=nB@2TOd/0Xge<0:5kC02ONDX0WWQ;0:AnC`2QNd`0WGM809]eAP2LMTL0
WgU:0:=mCP2VP54809egB0D0VGE100<0V7A009Mc?`2GLcl0202GLd400`2FL440Ug5209UcA00209Yd
A@0309UcA02HLT<0Ug520080VG=40P2HLT<0102GLD80UW1109E_@02EKd0909A[?`<0TV`m102AJc`0
1@2BK3d0UW1109A^?`2AJc`0SVPi00@0S6Hg202BK3d408]W=`@0RVHf00<0Qf8f08QS=`2:ICT00P2:
ICT00`29I3P0Qf8f08IQ=@0808AM<P<0PU`e0P21Fc@3081J<`<0OE`c0P1lFc800`1kFS40NUT`07YI
<00807EE;`<0MUDb:oooool002[ooooo0`2GJch309IZ?@80UFTl00D0Uf/n09Q/?`2HK3l0VFe009Y^
@@0209]_@P0609a`@`2FJch0Uf`o09M/?`2HKD00VFi10`2JKd8209Q/>`80VFdl0`2JKSd01P2KKch0
Ufdk09M]>`2IKcd0VW0n09]a?`80VW0n0P2IKcd00`2JL3h0W79009id@P0209id@PX0W7900`2NLT43
09ea@080W70o0`2NLd0209md@@<0X7E22@2NLd080:1e@PP0XGI30`2RMTD30:=gAP80Y7Q7202TND`@
0:AjB0P0YG]9202WOTX03@2WOD/0YWa:0:EkB@2SNDL0XGM50:1fA02OMD<0WWA20:5fB@2PMDP0WgA7
09icAP2MLTD00P2KL4<01`2JKd80V6lk09Q^?02GKC/0Ufdm09I[?P2FJd000P2EJT0208eW>P0308aV
>@2;ICP0RV@g0080RF<f00D0R68e08IP>@25GcP0Pedf085K=002081J<`80PE/d00H0Oed_07mM<01m
Fbh0O5T_07YG;`1hEBl207IB;P0307E?:01fD2T0N58[0080NE</00L0Me4Z07I@:@1eCbP0Ke4]06i@
;01/CRX0JT`X0080JD/W00@0JT`X06]=:@1[CBT0JddY0P1ZC2P206U;9`80J4XV0P1ZBBH0101[BRL0
K4/X06e<:@1]C2T206i=:P80KT/U00<0Kd`V075>:01bCbT00P1cD2X04P1dDB/0ME8/07EB:P1fDb/0
Me@/07UF;P1kF300OEXb07iK<`1oG3@0Oehc07iM<P1nFc40P5/a085L<P24GC@0R5hf08UO=`80Q5lb
00@0QF0c08IQ=027HSD0Qf8e0P28HcH808YT=`P0SF8e202;ICH01028HSD0RF<f08US=P29HcH308YT
=`0408]U>02@ICP0Sf@g08eR=@<0S64d0P2=HSD808QR=@0408IP<`27HC@0Qf4d08MQ=0<0R68e00<0
RF<f08]P=@2;H3D01P2;H3D208IO=P0308MP=`28HCP0RF8i0080RV<j00@0Rf@k08QR=@29HcH0RfDh
0P2<IST00`2;ICP0RF<f08QR=@0208MQ<P<0R68c0`29Hc@308iS=P<0SF8e0P2<HC@808iR=@0>08YT
=@2;ICH0S6Hg08eW>02<ISL0RfDf08US=028HS<0R6<^08UT<02;IS80S6He08aV=`2<IST208]T>@T0
S6Hg102?I3L308iS=P0308eR=@2;ICH0RfDf0080RV@e0P29Hc@208QR<`0308MQ<P28HS<0RF<d00<0
RfDf00<0RV@e08US=029ICD01`29ICD00`2:IC40RF@`08MR;P0208EP;00308IQ;@27HRh0R6<_00<0
R68c0P27HC8308IP<@0308EO<026H340R68c0080RF<d00<0R68c08IP<@25Gc000P24Gc8308=N<@<0
PUd`0P21GBd3081L;0<0Oe/[0P1nFB`307mJ;@<0P5/^00H0OUXZ07]I:@1iEbT0MUDX07AE:@1bEB/2
079F;P04071C:`1_DRX0KE0X06a?9`@0JdhV00@0JTd[06U<:P1WBRP0IDPV101TAbD0201PARD0GdDT
05i6901MAR@0FTHS05U78`1HAR80ETHR0P1G@RD0101E@R@0Dd8T05918`1@@B8204m28P80C3`S00<0
Bc/R04Xj8@19>B000P18>1l02@17=ah0BSLV04Th9P18=bD0ASLT04<f8`11=R80?cLR03hf8@0203`g
8@0303/f800j=Al0>C@N0080>3<M00<0=c8L03Pc7`0h<al01`0h<al0200d<1L0=C4H03Ha6`0g<Qh0
=S4M03D`7@0c;Ad0<R`L200a;B42034_6003034_6P0`;AX0<2dL0080;b`M00L0;b/O02lZ900_:b80
;b/R02l[800_:al0;b`M0080;b`K00<0;C0O02`_7P0Z;A`00P0Y;1/00`0Z;A`0;2lN02d`7`0802TZ
700402d^800/;Al0:b`N02X[7@80:BXL00D0:R/M02//7P0]<1l0;2lN02/^7@0202X]700302/^7@0/
;ah0;C0O00<0;BhN0P0/;Ad302//700402d^7P0/;Ad0;2dM02`]7@80:b`L0P0Z:a/802d_6P0502l/
6@0`;AX0<2dJ034^6`0b;a`00P0c<1d02@0d<Ah0=C0L03@_6`0d;a/0<bhJ03@_6`0e<1`0=S4M03Lb
7P0203De7@0303Hd7@0h<ad0>C<M0080>S8M00<0?34M03`d7`0l=1l01P0l=1l0100k=1X0?3DK03`e
6`0l=A/303df700403hg7@0i<QP0>S<I03`e6`<0?CHL0P0l=A/803lh7P80?3DK100n=ad203`e6`T0
?SLM00@0?3DK03df700m=Q`0?CHL0P0n=ad303lh7P0703hg7@0l=A/0>c@J03/d6P0l=A/0?SLM03lh
7P0203/d6P80?3DK0`0m=Q`00`0n=ad0?CHL03df700603df70<0?S@K0P0o=A`3040f7@P0?SLM0P0o
>1h01P10>Al0?cPN03hg7@0m=Q`0>c@J03Xc6@P0?S@K2010=Qd8048h7`<0@cTN0P14>Ql304Dk80P0
A3PN0P15>Al304Hj80<0Ac/Q00<0AC/P04@j7`13>Ah00P12>1d02@13>Ah0A3XO04Dk8010?Ah0@C`N
048m7`13?1l0AC`O04Ll800204Tk80<0AchQ00<0ASdP04Dl7`14>ah00P13>Qd01017=ad0B3PN04Ph
7P18>1h204Ti7`80BSXP00P0B3XP04Tk801;>b40CC`P04ln801B?al0E40O05E180<0DD8Q01H0DT8Q
05A18@1F@B80FD8S05]49@1MA2H0FdDN05a67`1MAb00GdTR065;901SCBH0I4hW06E?:01ZCRL0JdlX
06a@:01]DRL0Ke@W071E9P1aERL0LUPW0P1hFBX0101iFR/0NU//07]L;@1lGBh207eN;`80Q64Y00<0
QF8/08EQ;@26HS000P26HS800`27HSD0RVTd08YY=00308UX<`0308YY=02<JcH0SF`g00<0Tfhi0P2D
KcX309E`>`80U70l00<0UG4m09Ib?P2GLcl00P2HM4001`2IMD40V7A009Ue@@2IMD40VWI209]g@`2L
N4@00P2MNDD00`2ONdL0X7a80:1lB0020:5mB@<0XWi:0`2VPTh30:F1C@80Y81<0P2ZPd`01P2YQ4l0
Z8A@0:V5D`2WQED0YXIE0:N7F080ZXIF00@0ZhMG0:b8F02]RET0[HUI0P2^RUX20:j9DP030:j9E02^
RED0[XQG0080[XQI00<0[XQK0:f8E02]R5@01P2]R5@80;2:F`P0[h]K202/R5P20:j7G0030:j8F`2^
R5T0[XQG0080[XUE00<0[XUD0:j8F@2^R5T00P2^R5T20:n9FP<0/8YK00H0[hUL0:n9FP2^R5T0[XQG
0:j9E@2]R5<20:f8D@030:^5EP2/QUL0[XQI0080[hUJ00<0[XQI0:b6E`2[QEH00P2/QUL20:^5EP<0
ZXAE00H0ZH=D0:Z4E`2[QEP0ZhEH0:b6F@2]QeX20:j8F`030:n9G02]R5@0[HQD00<0[8MC0`2[QU83
0:b7D`80[HQD0`2^RED01@2_RUH0[XUE0:j9E@2]R5@0[8MC0080ZhIB00@0ZXEA0:j9E@2^RED0[XUE
0P2]R5@30:b7D`80ZXEA0`2[QU830:b7D`80ZXAE0`2[QEH30:b6E`<0ZhIB0`2/Qe<20:f8E0030:R3
C`2ZQE40ZhIB00<0[HQD0P2[QU880:b7D`030:n5D`2^Q580[89@0080Zh5?00H0[89@0:j4DP2_QE<0
ZhIB0:Z5D@2YQ5020:R3C`030:Z5D@2/Qe<0[HQD00<0[8MC0`2[QU8:0:Z5D@060:Z5D02ZQE40ZhIB
0:^5E02[QEH0[8II0P2/QEX00`2]R5@0[8MC0:^6DP030:V4D0030:^6DP2/Qe<0[HQD00P0[8MC00<0
ZhMC0:Z6DP2YQE400P2XQ5000`2YQE40ZXIB0:^7D`0@0:^5EP<0ZhIB0P2ZQE430:V4D0P0ZXEA00<0
Z89C0:V3E02[QEH00`2/QUL20:^5EPX0ZhIB0`2ZQE400`2[QU80[HQD0:j9E@030;26E080[hEC0`2^
Q5801@2YQ4d0ZXE>0:^6D@2/Qe<0[HMF0080[8IG00H0ZhEH0:n:EP2^RED0[XUE0:f8E02/Qe<20:^6
DP030:Z5D@2]R5@0[HQD00<0[8MC0`2[QU840:b7DP@0[HQC202]QeP80:j8F@<0[h]K0P2^RUX30:f9
F@050;2:F`2_REX0[XQI0:f7F02/QUL00P2]QeP30:j8F@@0[HMH00<0[XQI0;2:F`2aRe`00P2aS5P2
0;2;E`<0[hYF00L0[XUE0;6<F02`ReL0/8]G0:n:EP2^RED0[HQD0080[8MC202`QU@00`2/QUT0[HMJ
0:j8F`020:n9G0030:j8F`2]QeX0[8II00P0[XUE0P2]R5@20:j9E@<0[hYF00<0/8]G0:j9E@2^RED0
1P2^RED20:f7F080[XQI0`2_REX01@2`RU/0[hUJ0:n9FP2_REX0[XQI00<0[HMH00T0[8IG0;B9E02b
RE<0/HQD0:n7E02]QeH0[XYJ0:j<G02_SEl0202/R5P00`2^RED0[HQD0:b7D`020:^6DP030:b7D`2]
R5@0[XUE0080[HQL00<0[HQK0:b8F02/R5H00P2[Qe<00`2[R580[8MC0:b7D`020:^6DP<0ZXEA00<0
ZHA@0:^6DP2[QU801P2[QU820:^6FP030:^6F@2[QeL0ZhME0080ZhMC00@0ZhQB0:^6DP2[QU80ZhIB
0P2ZQE460:V4D080ZXEA0`2[QU890:V4D0P0Yh5B00H0ZH=L0:V4FP2YQ5X0ZHAH0:V4E`2YQED20:V5
D`P0ZXEA00H0[8MC0:^6DP2[QU80ZXEA0:V4D02XPdl20:N2CPP0YH1;00P0Y7m;0:F0C02UP4`0YX5=
0:F0C02TOd/0Xgi:0:9mB@80YX1A0P2WPE80302VP540Y7i?0:9lC@2QNd`0Y7i?0:=mCP2QNd`0X7Y;
0:5kC02RO4d0Xge>0:AnC`80YX1A0P2UOe00102TOTl0Xge>0:9lC@2RO4d20:1jB`<0XG]<00<0X7Y;
09ihB@2MMdP00`2NN4T209miBP<0X7Y;00/0WWU209mj@`2PNdH0X7]709miB02MMdP0VgE609YdA`2N
N4T0W7I709YdA@0209UcA00309]eAP2NN4T0X7Y;00P0VWA500P0UG4m09Ib?P2FLSh0Ug<o09Ib?P2E
LCd0U70l09=_>`P0UG5100<0TV`m09=]?P2EKd000P2GLD80102FL440UFm009A^?`2GLD8209I`@@03
09E_@02DKSl0Tfdn0080TV`m2@2AIS/00`2@JS/0SfTj08iX>@0308eW>080SVPi00@0TF/l08mY>P2=
IcP0RV@e0`29Hc@00`2:I3D0T6Xk091Z>`06091Z>`<0R6<f1@27HSD00`24GcD0QF0f08IQ=`0208MR
>00308IQ=`25H3H0Q5le00P0OeX`0`20FS<207mI<P<0OUPa0P1iFC8207QH<@0407MG<01fERl0MED^
07EE;PP0L58^0`1iF3D[ooooo`00:_ooool309M[?P<0UVXm0`2EJC`209IZ?@0509M[?P2IKD00VVi1
09Y^@@2KKd800`2HKD0509U^@@<0VFdl0`2JKSd209]_?P0309I/>P2GKC/0VFlm0080Vg4o00/0VW0n
09U_?@2HKS`0VW0n09]a?`2MLd40WWA209me@`2NM480WG=109ab@00809]a?`80Wg=20P2NLT4209ea
@080W70o0`2NLd0209md@@<0X7E22@2NLd020:5f@`h0X7E20P2QMD@20:9fA@040:=gAP2TN4L0Y7Q7
0:AhA`80YGY=1P2TND`80:AjB080YG]91P2TNTP80:MmB`P0Ygi80P2UNdT0102TNTP0XgU70:5gA@2P
MT@209me@`80WgA700@0WW=609ebA@2MLTD0W7540P2KL4<0202IL3`0VFlm09Q^?02FK3`0UFXm09AY
?P2CJ3h0TVLm0P2<IST0102;ICP0RV@g08US=P29HcH208QR=@0408IP>@24GSL0PU`e081J<`80OeTb
00d0P5Xc085K=01oGBl0OU`_07eK;P1kF2h0NEH^07MD;P1fDRh0ME4]07I@:@1gDBX0N58[0080NU@]
00H0NE</07QB:`1gDBX0KDl[06a>:P1ZC2P206U;9`0306Y<:01[CBT0KDl[0080JddY0P1ZC2P206U;
9`80J4XV101/BbP406e<:@0506i;9@1_C2H0L4dW075>:01cD2X00P1dDB/207IC;@80N5D]00@0NUL_
07aI<@1nFc<0Oe`d0P21GSH02@1oGS<0OUdb07mL<P21G380PUdc08EN=@29GcL0Rf4i08IQ=00208MR
=@0308QS=P29I3L0RVDh0080RfHi202;ICP808iS=PP0RfDf0P28HSD208US=P80RV@g0P2;ICP208aQ
=0<0SF8e00<0S64d08YO<P29GS402027HC@308IP<`0308MQ=028HSD0R68e0080RF<f202;H3D01P25
GSD0QUlf08MP=`28HCP0RF8i08YS>P80Rf@k00<0RF<f08YT=`2;ICP00P2<IST00`2;ICP0RV@g08US
=P0208MQ<P<0R68c0`29Hc@208mT=`80SV<f0P2=HSD208aQ=0P0TF8f0100RV@e08]U=P2<ISL0SFLh
08aV=`2;ICH0RF<d08QR<`28Hbh0RF@`08]V<P2<ISD0SFLh08aV>@2;I3T0RV<h2@2<ISL308iS=P<0
Sf@g0P2@ICP208]U=P80RV@e0P29Hc@208QR<`0808IP<@28HS<0RV@e08]U=P2<ISL0RfDf08YT=@29
Hc@808YV=P0308YU<@29I300Qf8^0080QF0/00<0QV4]08MR;P28Hbl00`26H34208MQ<P<0R68c00<0
QEl`08IP<@28HS<00P29Hc@00`28HS<0QV0a08EO<002089M<0<0Peha0`24Gc82085M;@<0P5`/0`1o
Fb/2081K;P<0OeX]0`1nFB`0301kEbL0NELW07YH:P1hEbX0MUL[07=F;01`E2`0Ke<[071C:`1^DBT0
K4lW06Y=9@80JD`T00H0JTdU06]>9P1/Cbd0JTd[06M::01TAbD306958`0606=6901OAB@0GdDT05i6
901LAB<0FTHS0P1HAR801`1FAR80F4<V05Q39P1F@bD0Dd8T05508P1?@2400P1=@2001P1<?2D0Bc/T
04Xj8`19>B80B3PQ04Lg8080ASHO00H0BCHU04Pg9@17=R@0ACHS048e8P11=R8203hf8@80>CLP00@0
>3HO03Le7P0f=1d0=S@M0P0e<a`903Ha7@0803<_5P0d<1L0=C0J03Ha7@0e<1`0=2lL038/700a:a/8
030/8@08034_600`;QL0<2hI030]6P0_;1/0;b`M02h[700^:Qh202hY8`0302hZ8@0^:Ql0;RXN0080
;R/L00@0;R/J02/_7P0Z;Qd0:2`K0P0W:aX00`0X;1/0:RhM02/_7P0802XZ7P0302d]8@0/;200:RXN
00<0:2PL00D0:RXN02/[7`0/<1l0:blN02T]700202P/6`0302T]700[;ah0;30O00<0;BhN0P0/;Ad3
02//70<0;2dM0P0[;1`302X[6`P0;2hI0P0_;1T0100`;AX0<BhK038_700c<1d203@a7P80=C0L0`0c
;QX00`0e<1`0=c8N03Pc7`0203De7@0303Hd7@0h<ad0>C<M0080>S8M00<0?34M03`d7`0l=1l0100l
=1l203/c7P80>c@J0P0l=A/0300m=Q`0?SLM03hg7@0n=ad0>C8H03Xc6@0l=A/0?CHL03hg7@0m=Q`0
?3DK03/d6PP0?cPN0P0n=ad403`e6`/0?SLM0P0l=A/303df70<0?SLM00<0?cPN03hg7@0l=A/00P0k
=1X00`0l=A/0?SLM03lh7P0303/d6P80?3DK2`0m=Q`00`0m<aX0?S@K03hd6`0203le7080@3HM00<0
@CLN03hg7@0n=ad01P0n=ad0200o>1h0@3TO040i7`11>R00?cPN03df700k=1X0>C8H200n=1/8040f
7@P0@SPO0`13>Ah204@j7`<0AC/P2014>1h304Di7`0304Hj8017>b40Ac/Q0080B3`R00<0AC/P04@j
7`12>1d00P11=a`01012>1d0A3XO04Dk8012?b0204<n800304<l7`15?1l0AS/O0080AcTN1012>ah4
044j7@80AcLM0`18>1h304Ti7`0904Pj8018>Ql0BSXP04`k7`1>?Al0DChN05<o7P1D@1l0C3dL0080
CChM00<0D40O05=0801E@2400P1G@2404@1G?R00FT@M05]57P1LAQl0GTPQ061:8`1RC2D0HddV06A>
9`1YCBH0JThW06]?9`1/DBH0KU<V06mD9@1`EBH0LELV0080N5TZ0P1iFR/0101jFb`0Ne`]07]L;@1l
GBh208AQ:@0308AQ:`25HBd0QF4_0080QV8b00T0QV4d08Y[=@29JS@0QfPb08IW<@27J380R6Tc08Y[
=@2;K3H0102CKST209A_>P80UG0k0P2CKc/00`2DL3`0UG4m09Ib?P0209Mc?`0709Qd@02FLSh0UW8n
09Mc?`2HM400VGE109Yf@P0209]g@`@0X7a8102QODT0102SOd/0Y81<0:B0C02TP4`40:F1C@80ZX=<
00L0Z8=>0:R4D02XQ580YhEE0:J6E@2VQUL0ZHEE0080ZXIF00<0ZhMG0:b8F02]RET00P2^RUX0202[
QTl0[8M@0:f8D`2]R5@0[XQG0:n9FP2`RU/0/H]N202]R5@80;2:F`P0[h]K202/R5P20:j7G0030:j8
F`2^R5T0[XQG0080[XUE00<0[XUD0;2:F`2`RU/00P2`RU/20:n9FP<0[XQI00H0[hUL0:n9FP2^R5T0
[XQG0:j9E@2]R5<20:f8D@030:^5EP2/QUL0[HMH0080[hUJ00<0[HMH0:b6E`2[QEH00`2[QEH30:Z4
E@80ZH=D102/QEX40:f6F`80[HQD0P2/Qe<20:^6DP80ZXEA102/Qe<20:f8E080[XUE102]R5@40:b7
D`80[hYF0P2^RED30:f8E0030:b7D`2ZQE40ZXEA00<0ZhIB0`2/Qe<20:Z4E@<0ZhEF0`2/QUL40:b7
D`@0ZhIB00<0Z8=?0:V4D02[QU800`2]R5@00`2/Qe<0ZhIB0:b7D`070:b7D`030:n5D`2^Q580[89@
0080Zh5?00D0[89@0:j4DP2_QE<0ZXEA0:V4D0020:R3C`040:V4D02ZQE40[8MC0:f8E0<0[8MC0`2[
QU8:0:Z5D@060:Z5D02ZQE40ZhIB0:^5E02[QEH0[8II0P2/QEX00`2]R5@0[8MC0:^6DP030:V4D003
0:^6DP2/Qe<0[HQD00P0ZhIB00<0ZhMC0:Z6DP2XQ5000P2WPdl00`2XQ500ZXIB0:^7D`0@0:^5EP<0
ZhIB0P2ZQE430:V4D0P0ZXEA00<0Z89C0:V3E02[QEH00`2]QeP00`2[QEH0ZXAE0:b7D`080:b7D`07
0:^6DP2ZQE40ZHA@0:Z5D@2[QU80[HQD0:j9E@040;26E080[hEC0P2^Q580202XPd`0ZHA=0:^6D@2]
R5@0[HMF0:f7F02[QEH0ZhEH0P2_RUH0102^RED0[HQD0:b7D`2[QU820:Z5D@@0ZhIB102/Qe<40:f8
D@@0[8M@202]QeP80:n9FP030;2<G02_Re/0[h]K0080[XYJ0P2]RET0102/R5P0/H]L0;2:F`2^R5T3
0:b6E`80[XQI00<0[hUJ0:j8F@2/QUL00`2/QUL00`2^R5T0/8YK0;6;G0030;6<F080/8]G0`2_RUH0
1@2aS5P0/8]G0;2;E`2_RUH0[HQD0080[8MC00<0ZhIB0;26E02`QU@01P2`QU@00`2/QEX0[HIK0:n8
G@020;29GP030:n8G@2]QU/0[8EJ00/0[XUE0`2_RUH20;2;E`P0[hYF0`2]QeP20:j8F@<0[hUJ0100
/XaM0;6;G02`RU/0[hUJ0:f7F02/QUL0ZhEF0:Z4E@2dRE@0/XUC0;68E02_Qe@0[HMF0:j:FP2^S5`0
[heO202/R5P00`2^RED0[HQD0:b7D`020:^6DP030:b7D`2]R5@0[XUE0080[HQL00H0[HQK0:b8F02[
QeD0ZhMC0:Z6DP2ZQe430:^6DP<0ZXEA0P2YQ5080:Z5D@80ZXEI00<0ZXEH0:Z6EP2ZQU@00P2ZQU80
102ZQe40ZhIB0:^6DP2[QU820:Z5D@<0ZHA@00<0Z8=?0:V4D02YQ5000P2ZQE420:^6DP030:b7D`2Y
Q500ZHA@00L0ZHA@202WPE820:R2F`030:R3F@2XPeL0Z8=F0080Z8AD00<0Z8AB0:V4D02YQ5001P2Y
Q5001P2ZQE40ZHA@0:V4D02XPdl0Yh9>0:J1C@80YH1<202RODP04`2QO4P0XWe90:=nBP2TOd/0Xgi:
0:5lB02ONTH0WWU50:1jB`2QNd`0Xge>0:AnC`2SODh0XWa=0:5kC02ONDX0XG]<0:1jB`2ONDX00P2M
MdP00`2NN4T0X7Y;0:1jB`020:5kC0040:1jB`2ONDX0WWQ909egB080W7I700P0WWQ909miBP2PNT/0
XG]<0:1jB`2NN4T0W7I709]eAP<0W7I700<0WGM809ihB@2NN4T00P2ONDX0202KMSl0W7M009eh@`2M
N4@0W7I509UcA02GLD80UW13102GLD80102HLT<0VG=409UcA02JM4D809Qb@`08099^>P2CKc/0U70l
09Ea?@2DL3`0Tflk095]>@2@K3P809=_?`0908mY>P2@JS/0TV`m09A^?`2EKd00U6ho09=]?P2BK3d0
UFm00080U6ho00<0Tfdn099/?@2AJc`00P2@JS/908iS>00708mY>P2=IcP0RfDf08YT=@29Hc@0RV@e
08]U=P0208aV=`0308]U=P29Hc@0Qf4b0080Qf4b00<0R68c08US=029Hc@01`29Hc@808EP=003085L
<P22GC<0Q5le00<0QF0f00<0Pehd089M<`1kF2h01`1kF2h307iH<@80OEL`0`1lERl207IF<00407EE
;`1dE2h0Le<]079B;080LE4[201]DB`3079A;R_ooooo000Zooooo`<0Uf/n0`2FJSd209EY?080U6Pk
00@0UFTl09IZ?@2HK3l0VFe00P2JKT4809U^@@<0VFdl0P2JKSd309]_?P0309I/>P2GKC/0VFlm00<0
Vg4o00X0VFlm09Q^?02JL3h0Vg4o09ec@@2NM480WgE309id@P2MLd40W790202JL3h0102PM4<0Wg=2
09mc@P2NLT4209ea@080W70o0`2NLd0209md@@<0X7E22@2NLd030:5f@`d0X7E20P2QMD@20:9fA@04
0:=gAP2TN4L0Y7Q70:EiB0<0YGY?1@2TNDh80:AjB0<0YG]91@2TNTP80:UoC@P0Ygi80P2TNTP0102S
NDL0XWQ60:5gA@2QMdD20:1fA080WW=60`2MLTD309aaA00609Ya?@2IKcd0V6hl09I/?02DJC`0TfPm
0P2AIS`208aV>@0308]U>02:I3L0RF<f0080R68e01@0Qf4d08IP>@24GSL0PU`e07mI<P1nF340OeTb
081J<`21Fc@0Oed_07iL;`1mFbh0NeP^07UF;P1gE2h0MU8^07EA;@1fD2T0N58[07UC;080NeD^00D0
NU@]07UC;01hDR/0K4hZ06]=:@0306U;9`0306]=:@1/CRX0KU0/0080JddY0P1ZC2P206U;9`80J4XV
1P1]C2T206a;:005071:9@1aBbH0LT`W07A>:@1eCbX00P1gDB`02P1hDRd0NE<^07UF;P1jEbl0NeP`
07eJ<P1oG3@0PEhf089O=`23H3P207mN<`0607mL<P21G380PUdc08EN=@2:H3P0Rf4i0P28HcH00`29
I3L0RVDh08]V>@0208aW>P0308eX>`2;ICP0RfDh00H0RfDh202>HcH808]U=P<0R68e00<0RF<f08YT
=`2;ICP00P2;ICP02029GS40Rf0c08eR=@2>HcH0SF8e08]P<`28GC00Qe`_2027HC@208EO<P0408IP
<`27HC@0Qf4d08QR=@80RF<f202;H3D01P25GSL0QUlh08IO>028HCX0RF8k08YS?080Rf@m00<0RF<f
08YT=`2;ICP00P2=IcX00`2;ICP0RV@g08US=P0208MQ<P<0R68c0`29Hc@0102@ICP0Sf@g08mT=`2>
HcH208eR=@80S64d202AHSH0402:I3D0RfDf08aV=`2=IcP0S6Hg08]U=P29Hc@0R68c08MR;@29I300
RfHb08eW=P2=IcP0S6Hi08]T>@2:HcP908aV=`80SF8e00@0SV<f08mT=`2?I3L0T6Dh0P2AIST208]U
=P80RV@e0P29Hc@208QR<`0308IP<@28HS<0RV@e0080S6Hg00<0RfDf08YT=@28HS<0202:ISH00`2:
IC40RF@`08MR;P0208EP;00308IQ;@27HRh0R6<_0080QEl`00@0QV0a08MQ<P27HC80R68c0P29Hc@0
0`25Gc00QV0a08QR<`0208US=00408QR<`26H340QEl`085L;`80PUd`00D0Peha08AO<P25H3<0QF0c
08IQ=002085M;@<0P5`/0`1oFb/01@21G2l0P5/^081K;P1oFRd0OUT/0080OEP[01D0O5LZ07UE9@1h
ERH0NUPZ07YI;01hFBd0LeH/06mC:`1]DBT0L5<[06iA:@1[CRH0JD`T06Q;8`1YC2@0JTdU06]>9P1]
D2h0Jdh/06M::01TAbD0101QA28205m5900305e58`1LAB<0FTHS0080F4HR00T0ETHR05U49`1IA2L0
ET<U05=2901A@280CSlP04`o7`1;?Qh00P1;>b@0101:>R<0BCTR04Lg8016=Ql204De7P0804Tf9`18
=bL0AcHV04De9@12=B@0@3DS03hf8`0m=B8203Tg800303Pf7`0g=Ah0=S@M0080=C<L00<0=38K03@_
6`0d;a/01`0d;a/0200c;aH0=30G03D`6P0f<Ad0=C0L03@_700b;1`0<B/K200_:b02030^5`03030^
6@0_;1T0;b`K0080;R/L00L0;RXN02hY9@0^:B<0;RTS02hZ8@0^:Ql0;RXN0080;R/L00<0:blN02X^
7@0X;1/00P0W:aX00`0X;1/0:RhM02/_7P0802XZ7P0;02d]8@0/;200:BTM02PX700W9a/0:2PL02TY
7@0[:al0;30O02/_7P0Y;A`00P0X;1/00`0Y;A`0:blN02``7`0302d^7P80;2dM0`0[;1`202`]7@<0
:b`L0`0Z:a/802`^6@0@02h[600_;1T0<2dJ034^6`0b;a`0<c0M03@a7P0e<Ql0=S4M03D`700c;QX0
<RdI03<^6P0e<1`0=c8N03Pc7`80=CDM00<0=S@M03Pc7@0i<ad00P0j<Qd00`0l<Ad0?3@O03`d7`03
03`d7`<0>c<N0P0k=1P0100l=AT0?CHJ03df6P0n=a/203lh700303Pa5`0j<aT0?3DK0080?SLM00<0
?CHL03`e6`0k=1X0200o>1h00`10>Al0?SLM03`e6`0203Xc6@0303`e6`0n=ad0@3TO00T0?SLM0`0l
=A/203df70<0?SLM00<0?cPN03hg7@0l=A/00P0k=1X00`0l=A/0?SLM03lh7P0303/d6P<0?3DK2P0m
=Q`203dc6P0403hd6`0o=A`0?cDL040f7@80@CLN200n=ad0200o>1h0@3TO044j8011>R00@3TO03df
700k=1X0>C8H200n=1/8040f7@P0@SPO0`13>Ah204@j7`<0AC/P2@14>1h204Di7`0304Hj8017>b40
Ac/Q0080B3`R00<0AC/P04@j7`12>1d00P11=a`01012>1d0A3XO04Dk8014@B8204@o8@0304@m8015
?1l0ACXN0080ASPM0P0o>1/3040i70<0@CXM0`17=ad204Ph7P<0BCTO00H0AcTO04Pj7`1:>R00C3/O
04hm7`1A?Qh205<o7P0A04Tj6`1;?1d0Bc`M04ln801C@280ED0S05Hn8P1D?200E3XO05U3701JA1d0
G4HO05e7801OBB80HD/T069<9@1SCBH00P1YCBH01P1ZCRH0K54V06eB9@1^Db@0Ke@U071F9@<0N5TZ
00<0NEX[07YK;01jFb`00P1kG2d208AQ:@0908AQ:`25HBd0QF4_08EQ<@26HS80QV4d08Y[=@29JS@0
QfPb0080QVLa00@0QfPb08UZ=02;K3H0TVdh0`2CKST209A_>P80UG0k0P2CKc/0102DL3`0UG4m09Ib
?P2FLSh209Mc?`80U70l00@0UG4m09Ib?P2HM400VGE10P2JMT850:1lB0<0XGe90P2ROTX0102SOd/0
Y81<0:F1C@2UPDd20:J2CP80ZX=<00H0Z8=>0:R4D02XQ580YXAD0:J6E@2VQUL20:V5E@040:Z6EP2[
QeL0[8QH0:f9F@80[XYJ0P2ZQDh01P2[QU40[HQD0:n9F02`RU/0/H]L0;:<G`P0[HQD202`RU/80:n;
F`P0[8QH0P2^Qe`00`2^R5/0[XQI0:j8E`020:j9E@030:j9E02aRe`0/H]L0080/8YK0P2_REX02@2^
R5T0[HMH0:f7F02_RE`0[hUJ0:j8F@2^R5L0[XUE0:f8D`020:f8D@030:^5EP2/QUL0[HMH0080[XQI
00<0[HMH0:b6E`2[QEH00`2[QEH20:Z4E@<0ZH=D00@0[XML0:f6F`2]QU/0[HIK0`2/QEX00`2[Q5T0
[HQD0:f8E0020:b7D`050:^6DP2ZQE40ZXEA0:V4D02[QU800`2/Qe<20:f8E080[XUE00@0ZhIB0:b7
D`2/Qe<0[8MC0`2]R5@00`2^RED0[hYF0:n:EP020:j9E@@0[HQD0P2ZQE430:^6DP<0[8MC0P2ZQ5D3
0:^5EP<0[8IG00H0[XUE0:f8E02]R5@0[8MC0:^6DP2ZQE420:V4D0030:R3C`2YQ500ZhIB00<0[HQD
00<0[8MC0:^6DP2/Qe<01`2/Qe<00`2_QE<0[XAB0:b2D0020:^1C`050:b2D02^Q580[hEC0:Z5D@2Y
Q5000P2XPdl0102YQ500ZXEA0:b7D`2^RED30:b7D`<0ZhIB2P2ZQE401P2ZQE00ZXEA0:^6DP2[QE@0
ZhEF0:b6F@80[8EJ00<0[HQD0:b7D`2[QU800`2YQ5000`2[QU80[8MC0:f8E0080:^6DP030:^7D`2Z
QU80Z8A@0080Yh=?00<0Z8A@0:Z6DP2[Qe<0402[QEH30:^6DP80ZXEA0`2YQ5080:Z5D@080:R2E@2Y
PeH0ZhEH0:f7FP2^R5/0[HMJ0:^5F02ZQ5L80:f8E0030:b7D`2[QU80ZXEA0080ZHA@00@0ZhIB0:f8
E02_RUH0/HME0`2`QU@20:n5D`80[XAB00l0Z8=<0:V4C@2[QU40[HQD0:j8E`2]QeP0ZhEF0:Z4E`2`
ReL0[hYF0:j9E@2]R5@0[8MC0:^6DP2ZQE400`2YQ5000`2ZQE40ZhIB0:b7D`020:f8E0060:j9E@2_
RU<0[XUB0:j9DP2]R540[8M@0P2[QTl00`2ZQDh0[HMH0:f7F0060:f7F0P0[hUJ0P2`S5`0102_Re/0
[XYJ0:j:FP2]RET20:b8F0070;6;G02`RU/0[XQI0:b6E`2[QEH0[8IG0:j8F@020:n9FP030:j8F@2/
QUL0ZhEF0080[8IG00<0[XQI0;2:F`2aRe`00`2aS5P30;2;E`80[hYF00H0/HaH0;2;E`2`ReL0[XUE
0:f8E02/Qe<20:^6DPP0/8ID00<0[8EJ0:f6F`2_R5d00P2`REh00`2_R5d0[HIK0:b5FP0;0:j9E@80
[hYF0`2`ReL80:n:EP<0[HMH0`2^R5T20:n9FP0@0;>=GP2bS5d0/H]L0:n9FP2]QeP0ZhEF0:V3E02X
PU<0]8UD0;:9D`2aR5@0[hMD0:f7EP2^RUX0[XaL0:n=G`P0[8QH00<0[XUE0:f8E02/Qe<00P2[QU80
0`2/Qe<0[HQD0:j9E@020:f8G0030:f8F`2/R5P0ZhME0080ZXIB00@0ZXMA0:^6DP2[QU80ZhIB0P2Z
QE430:V4D0P0ZXEA0P2XPeL00`2XPeH0Z8AD0:R4DP020:R4D0040:R5C`2[QU80ZhIB0:^6DP80ZXEA
0`2YQ5020:R3C`040:V4D02ZQE40ZXEA0:^6DP80[8MC2@2YQ5080:J0D@060:R2G@2XPU/0Z89K0:R3
F@2XPeL0Z8=F0P2XQ5@80:V4D080Z8=?00<0Yh9>0:J1C@2UP4`00P2TOd/00`2SOTX0XGa70:5lA`06
0:5lA`0;09mjAP2PNdL0XWe90:9mB@2QO4P0WgY609ehA02KMT80W7I709ihB@2PNT/00P2RO4d01P2Q
Nd`0X7Y;09ihB@2PNT/0WWQ909egB080VgE600<0W7I709egB02NN4T00P2LMTL00`2KMDH0VWA509Uc
A00209Ma@P0309I`@@2MMdX0WWQ;00<0X7Y=00<0WWQ;09]eB02JM4L00`2KMDH00`2LMTL0WGM809ih
B@0209ihB@0;09Ud?@2JMCh0VgI109]f@P2ILd80Ug5209E_@02CKD00Tfdn09A^?`2FL4400`2GLD8:
09I`@@03091/>02BKSX0Tflk0080U70l00<0TVhj091/>02>JSH0202AK3l00`2>J3T0SfTj095[?003
09=]?P03099/?@2AJc`0U6ho0080Tfdn00<0TV`m095[?02@JS/00P2?JCX908iQ=`0@08iX>@2<ISL0
RV@e08QR<`27HC80R68c08US=02:I3D0RF<d08QR<`27HC80QV0a08EO<026H340R68c08US=0P0Q5h_
0`23GS8508AO<`03081J<`21Fc@0Pedf00<0Q5hg00<0PU`e085K=01iERh01`1iERh307eG<080O5H_
0`1kEBh0201cEBl0LU@^075C;@1`DR`0Ke4[06i@:P1]CbT0K4hX201[CR`306M68b_ooooo000Zoooo
o`0409EZ?@2FJch0UV/n09I[?P80Uf`o0P2HKD0809I[@0<0V6`k0`2IKC`209Y^?@P0VW0n0`2HK3/3
09U]?080VVhm00P0VWI609UeA@2GLd<0UW9209Mc@`2HM4@0VgM709ahB0P0W70o202OLd880:9fA@80
XGI300D0X7E209md@@2OM440WgA109ic@00209eb?`0309ea@02NLT40X7A300<0XWI500<0XGE40:1d
@`2UMT801`2UMT800`2UO4P0XgY60:9iA@020:1g@`030:9iA@2SNTH0YGa800<0YW]80`2UNTL20:Ai
APP0YGa8102WO4T40:IkB080ZX1@00@0ZGm=0:QoB`2XOd/0Ygi80P2VODD40:ElB0@0YWe90P2QO4D0
0`2PNdH0WgY609ihA`0209egB00709afB@2KMDH0VgE609YdA@2ILd@0V79309Ma@P0209I`@@80UVdi
00`0UF`h09=Z=P2BJCD0TFPd091W<`2?IS80TV/d091X=02;IS40R6@`08IR<023HC42089R<`04089O
=`21GSH0OU/c07aI<@80NeP`00<0OEXb07iK<`1nFc<00P1mFS800`1lFC40NeP`07YG;`0207UF;P03
07YB;P1iDBd0Mdl[0080MThZ00<0Mdl[07UA;@1jDRh00P1^D2`0101]Cb/0K4hZ06]=:@1[CBT206Y<
:080JTTX0P1[BRT206a;:P80KD`[00d0LD`_071;;P1^BRX0K4PV06]78`1/BB<0KDXT06i;8`1dCbD0
ME0V07IA9`1gDRP0NE@Z0080NeH/00X0O5L]07eH;P1lEbX0OEP[07mJ;@22GC00Q5lb08MR=@28HcH0
RF@g0P27HC@308IP<`<0QElb202:HcP03P29Gbl0SF<c095V>@2DJCh0U6To091T?@2<H3T0REdh08eQ
=02<HC@0SF8e08eT=P2=IcP0SFTi0P2<JSX0102=IcP0S6Hg08aV=`2;ICH208YT=@80RF<d00@0TF/l
08mY>P2<ISL0RV@e1028HS<208]U=P80RV@e0P29Hc@208QR<`0408QR=@27HC@0Qf4d08MQ=080QV0c
0P25Gc800`2:I3<0RF<b08MQ<00208IP;`0308MQ<029Hc80RV@c00<0RfDh00<0RV@g08US=P28HSD0
0P28HSD808iS=P<0R68c00<0RF<d08YT=@2;ICH00P2;ICH0202=IcX0RF<f08EO<P27HC@0S6Hi08iX
>`2:I3L0QV0c0`2>HcH00`2=HSD0S64d08]P<`0508]P<`0308aQ=02=HSD0SV<f0080SV<f0P2=IcP0
102<ISL0RfDf08YT=@2:I3D208US=00308IP<@29Hc@0S6Hg0080SVPi00<0S6Hg08US=026H3402@2:
I3D02029Hc@0RfDf08eW>02?JCX0T6Xk08mY>P2>J3T0SFLh202;I3T808YT=@<0RF<d0`28HS<:08MQ
<P0308EP;026HBd0Qf8^0080RF@`00<0R6<_08MR;P26HBd00P29H38208QO<@@0Qeh`00/0RV4e08MN
<P23FRh0OeHZ07iE:@1oERX0PUT]08=J;P1kFBT0OE/[07mM;@02081N;P0307mM;@1mFb/0NeTY00@0
OE/]101lFR`03P1fF2H0MeTW07MH:@1gF2X0MEHZ07=C:P1`D2T0KdlX075@;@1`Cb`0K4hZ06Y>:@1W
CBP0IDdW0P1SCBH01P1QBRP0H4TW06199`1OB2H0GTLU05e69080G4DS00P0GdHW05i59P1MA2D0G4<T
05Y18P1I@240F3lP05Ln7`80EChN00H0DSdN054l7`1?>b00CC`R04/k8@1;>b8204Pl8P0704Hj8015
>Al0@cLM044e6`10=1X0?c<I044e9@03040d9080?c<S0P0n<R8203Pe8P0303Ld8@0f<b00=C8O0080
<c0M00<0<RlL03@a8P0d<B800P0c<245038_800403@a8P0c<240<RlP034^7`80<2dN0P0a;Ql802h_
8@0602d_900/;R<0:bdR02X/8@0Y:b00:2XO0P0W:Ah302X/8@0302T[800X:Ql09bTN00809bTN00@0
:R`Q02T[800Y:b00:B/P0P0X:Ql202LY7PP0:2XL00@0:R`Q02T[800Y:b00:B/P0P0X:Ql202LY7P03
02P[600Y;1T0:RdJ0080;2lL00<0:RdJ02T/6@0X:aP00`0Z;1h202/]7`<0;2hP200Y:ad302//7080
;2dM0`0];Qh202l]6004030^6@0a;aX0<c4L03@b7@80=C<N0P0`;aX02@0`;QT0<RdI03@]6P0g;a`0
>C4N03`a7`0k=R<0>C@Q03Lb7`0203D`7@0303Ha7P0h<b00>C@Q0080>c@J0P0l=A/303df700403hg
7@0i=AX0>CDJ03Te6P<0>SHK0P0k=a`0200l>al0>cXN03/g700k=A/0?3DK03hd6`11=Ad0@SHN0P10
=Qd0100o=A`0?S@K03dc6P0m<aX203`b6@@0@CLL0P10=Q/203le6PT0@3HM0P0m=QX203hg6`@0?cPL
0`0j>Ad203Th70<0>3LK0`0n=ad203df70<0?3DK200k=1X803/g70P0?SLM0P11>R00100o>1h0?SLM
03`e6`0k=1X203Tb600803hf8@0o=b80@3PS044i9010>2<0?SHQ03`d7`0j<Qd803hg7@08044g7P12
>1l0A3XQ04@j8@13>B00@CLN03le700m<aX3040f7@03044g7P12>1l0@cTP00X0@cTP0`14>1h204Di
7`<0ASXP00H0BSPP04Ti8019>B00B3XP04Hj8015>b0204<l8080A3XO0`13>Ah3048h7@03044g7012
>1d0A3XO0080AC/P00@0A3XO048h7@11=a`0@cLM0P14>1h00`16>R00Ac/Q04Pl8P0204Tm8`@0C3/Q
101;>R004@1??1h0DC`O054l7`1B?B00EShR05To901K@2D0GT0V05m19`1B@1`0ET@P05]99@1MBbL0
G4XV05i<:01RD2`0IeDa0080JDdU00<0JThV06]?9`1[CbL00P1/D2P03@1]DBT0KeP^075H;`1aFBd0
M5T/07IJ:`1iFR/0Ne/Z07aL:`1kG2d0O5d^07iO<020HC800P21HS<02020HC80Of0a08IR<P26HS80
Qf<c08QT=029ICD0RVHf0P2;IcL03P2;Ic<0SFTe08m[=`2BKSX0Tflk099^>P2AKCT0T6`h09]eAP2J
M4D0VG=409Qb@`2GLD80UW110P2EKd0409Ud@080VWE10P2KMT801P2NN4/0WWQ909miBP2ONDP0X7]7
0:5lA`80XWe60P2QO4P20:9mB@80Xgi:0P2TOd/0202SP4P0Y8590:B1B`2TP4`0YH5?0:F1D@2VPU80
YX5D0P2YQED30:Z6EP<0ZhMG0`2]RED20:j:EP<0[h]G00<0/HeM0:j:FP2[QeL00P2YQED00`2[QeL0
[XYJ0;6=G@020:n;E`80/8aH0`2aSET00`2bSUX0[XYF0:j:EP030:n;E`<0/8aH202/QeX30:f7F0<0
[XQI0P2_REX40;2;E`80[hYF0`2^RED80:^5EPP0[HMH202[QEH0102XPU<0ZXAE0:b6E`2^R5T20:n9
FP030:f7F02/QUL0[8QH00L0[8QH0`2[QU800`2/Qe<0[HQD0:j9E@020:j9E@<0/H]L00<0/8YK0:n9
FP2^R5T00P2^R5T01P2XPU<0ZH=D0:Z4E@2[QEH0[8IG0:f7F080[XQI202ZQ5D80:^6DP<0ZXMA00<0
ZhQB0:b9D`2]RU@00P2]RU@30:^4F@80ZX=H0`2YPULB0:^6DP@0ZXEA0P2YQ5080:^6DPP0ZHA@202[
QU820:Z5D@@0ZhIB0`2/Qe<80:^6DPd0ZHA@0`2XPdl00`2YPe@0ZXAE0:b6E`020:b6E`030:Z4E@2X
PU<0Yh5B0080YX5=00<0Yh9>0:R3C`2YQ5000P2[QU801`2/Qe<0/8ID0;26E02_QE<0[XAB0:b2D02[
PDl00P2ZP4h20:N1DP<0Z89C0`2YPe@80:^5EPP0[HMH00H0[XUE0:f8E02]R5@0[8MC0:^6DP2ZQE42
0:V4D0030:R3C`2[QU80[XUE0080/HaH00l0[XUE0:^6DP2XPdl0ZXEA0:^6DP2/Qe<0[HQD0:b7D`2Z
QE40Yh9>0:J1C@2UOe00Yh5B0:V3E02[QEH00P2/QUL0102[QEH0ZXAE0:Z6EP2ZQUH20:^7E`80[8QH
0P2]RET20:^6C`030:^6D@2[QU80ZhED0080ZhEF00<0ZhEH0:Z6EP2ZQUH00P2[QeL20:b8F080[HUI
202_RUH20:Z6EP80ZhMG0P2/R5P20:f9F@T0[XYJ00P0[hYF0;2;E`2aS5P0/HaH0;2;E`2_RUH0[HQD
0:^6DPP0[XQI202/QUL80:f7F0P0[XUE202_RUH80:f8E0P0[HMH202_RE`00`2[QEP0[8II0:j8F`02
0:n9G0060:j8F`2/QUT0ZhEH0:f8E02[QU80ZXEA0P2XPdl00`2ZQE40ZhIB0:f8E0020:f8E0040:b7
D`2[QU80ZXEA0:V4D080Z8=?00D0[HQD0:b7D`2/Qe<0ZhIB0:Z5D@020:V4D00<0:R3C`2/Pdd0Zh9<
0:^2CP2ZP4h0ZGm?0:UnD@2XOE00Z7eB0:AnC`2UOe00Yh5B0P2YPe@01`2XPU<0YX1A0:EoD02VPDd0
Yh9>0:V4D02[QU800P2/Qe<00`2[QU80ZXEA0:R3C`030:R3C`@0ZHA@202VPDX<0:AoB`80Xgi:0`2R
ODT80:=mCP080:YlB`2YNdX0YWY90:AjB02SNdP0Xgi:0:F0C02VPTh20:J1C0090:F0B`2SOTT0XGa7
0:1kAP2ONTD0WWU409]eAP2JM4D0V7930080Ug5200<0V79309YdA@2KMDH0202MN4<0102KMDH0W7I7
09afA`2MMdP209ihB@80WgU:0P2OLdH20:1dA`0509mcAP2LL4<0VVi109U]@02LLCh00`2MLSl209ic
@080WgA100@0WW9309ea@P2MLD80WG520P2LL44209]_@00@09YdA`2ILdH0VG=409Uc@P2HLcl0V7<n
09Mb?@2GLS/0V7Hi09Qe>`2GM3`0UW8n09Ea@@2DKd80Tfi4099]@`<0UVXk1@2GJc`209Ea?`0>09=_
?@2AKC/0Sf/i08eY=`2<J3H0RfLe08aX>02=JCT0Sf/k091/?02?Jc/0SFTi08]W=`2:ISH208]W=@@0
S6Pf0P2=JCL00`2>JSX0SFTi08]W=`0208YV=P0408]W=`2=JCT0SVXj08m[>`<0T6`l00P0Sf/k08aX
>02:ISH0R6@d095X?02?ISX0SF@h08]R=P80RV4e0P2;HSH0102<HcL0QUlf08QQ>02;I3/208aU?009
08]T>`28HCP0QUlf08]T>`2:HcX0R64h08MP=`26GcH0Qf0g0080R64h00<0P5Tb085J<`21FS<01@22
Fc@2089H<P03081I<P1nF340O5Ta0080NUT`00`0NET`07]N<P1kGS80OUlc07mN<`1nFc40OUT_07aG
;@1kE2/0NeTf07UG=01gEC8207EC<00307ID<@1hES<0NELd0080LE0]00@0Le8_07AC<01fEC80N5Ld
0P1iF3D01@1/DC<0Je0b06Q=;`1UBR`0I4T[0080HdPZ00D0I4T[05e49P1OARP0HDPZ06=:;00206A;
;@030699:`1QB2X0HDPZ0080HDPZ:oooool002[ooooo102FJch209M/?`80V6e0202GK44309Q/>`<0
VFdl0P2JKSd809Y`?P<0V6`k0P2IKC`309Y^?@0809YdA@2ILd@0V79309Ma@P2HLT<0VG=409]eAP2M
MdP809ea@0P0Wg=2202QMD@30:1e@P@0WgA10P2NLd000`2MLD00WW910:1d@`030:9fA@030:5eA02P
M4<0YGI200L0YGI200<0YGa80:AkA`2SNTH00P2RNDD00`2SNTH0Y7]70:ElB0030:IkB0<0YGY70P2T
NDH80:ElB0D0Yga90`2VNdP20:UoC`040:UoC@2XOd/0Ygi:0:MnB080YWe5102UO4P40:ImB@80XGa5
00L0X7]609mjAP2NN4L0WGM809afA`2LMTT0VgE60080VWA500<0VG=409Qb@`2GLD800P2FL4403P2G
KC/0UV`j09E[>@2CJCL0TVPf091V=02?IC<0SV@b099Z=P2@J3@0RfHb08MS<@26HS80Pf4a0P22HS<0
1@22GcL0PEhf07iK<`1lFC40NeP`0080O5Ta0`1mFS800`1lFC40NeP`07YG;`0207UF;P0407QE;@1j
DRh0NE4]07M?:`80MThZ00<0Mdl[07UA;@1jDRh00P1^D2`00`1]Cb/0K4hZ06]=:@0206Y<:00306U;
9`1ZBBP0JTTX0080JdXY0P1/BbX206e<:`08071;;P1_BRd0KDTY06a89P1/B2@0KDXT06m<9P1`CBD2
07E@9P0307IA9`1hDbT0NE@Z0080NeH/00X0O5L]07eH;P1mF2/0OUT/07mJ;@21G2l0Peha08EP<`26
HC@0Qf8e2026H3<808YS>00@08]Q<@2=Hc<0T6Dh099W?02CJ3h0TFDn08mS?02=HC`0SF4d08aQ=02=
HSD0SF@f08aV=`2<J3P0RfTi08aZ>P80S6Hg0P2;ICH208YT=@80RF<d00@0SfTj08eW>02;ICH0RF<d
0P28HS<01029Hc@0RV@e08]U=P2;ICH208YT=@80RF<d0P28HS<208US=P80R68e0P27HC@208IP<`03
08YT<`29Hc80Qf4`0080QV0_00<0Qf4`08US<P2:I3<00P2;ICP208YT=`80RF<f0P28HSD808iS=P80
R68c0P29Hc@0302:I3D0RfDf08]U=P2;ICH0SFLj08US=P26H3<0R68e08aV>@2=IcX0RV@g08MQ=0<0
SV<f00<0SF8e08aQ=02<HC@0102;H3<208aQ=00408eR=@2>HcH0SV<f08iS=P<0S6Hg0P2;ICH308YT
=@0308QR<`2:I3D0SFLh0080SfTj00<0SFLh08YT=@28HS<02@2:I3D00`29Hc@0RfDf08eW>00308mY
>P0308iX>@2=IcP0Rf@i00L0Rf@i202:I3D308US=0<0R68c2P27HC800`25H2`0QV4]08MR;P0208UT
<00308QS;`27HRh0QV4]0080RF0b0P28Gc4308MN<00<08IM;`29H3@0QUda08=J;P20Eb/0OeHZ081G
:`23FRh0QE``07aJ:P1mFb/0OU`/0P1oGBd00`1nG2`0OE/[07aJ:P0307eK;@<0O5X/0P1kFB/207IH
9P0?07MH:@1gF2X0MEHZ07=C:P1`D2T0KdlX06m>:`1^CBX0K4hZ06Y>:@1WCBP0IDdW06A>9`1SCBH0
HDXX0080H4TW00<0GdPV05i79@1MAR@00P1LAB<205i79`0405e69P1KA2@0FT<S05Q18@80Ed0P00P0
EChN05Dn7`1B?Ah0D3dO04dl801;>b40Bc/R04Tk8@80ASXR00@0ACTQ04@h8012=Qh0@CDM0P10=1`3
03dd8`80?3<R0`0k<R401P0h=B80=c@Q03Hc800e<Ql0=34N03<`7@80<RlL0P0d<B8203<`8@<0<RlP
0P0a;Ql5038_8003034^7`0`;Ah0;b`M00P0;RlQ0P0/;R<0100[;B80:R`Q02T[800X:Ql202LY7P80
:R`Q0P0Y:b00100X:Ql09bTN02LY7P0W:Ah402T[8080:2XO0P0W:Ah802PZ70@0:B/P0P0X:Ql202LY
7P0302P[600Y;1T0:RdJ0080:bhK00@0:RdJ02T/6@0X:aP0:B/M0`0Z;1h202/]7`80;2hP200Y:ad3
02//7080;2dM0`0];Qh01P0^;1L0;bdH030^6@0a;aX0<S0K03<a7080=38M00X0<2lJ02l^6@0_;AP0
<B`H03</6@0f;Q/0>30M03`a7`0g<Ql0=S4N100e<1d0100f<Ah0=c8O03Xc6@0j<aT203/d6P<0?3DK
00@0?CHL03Te6P0i=AX0>CDJ0P0j=Q/303/g700803/j7P0j>Ad0>SHK03Xd6P0k=1X0?S@K040d7011
=Ad303le70<0?S@K0P0m<aX01012>1d0@CLL044g7011=a`2040f6`80?cDJ2@10=Qd203df6P80?SLK
0`0o>1`01010>Ad0>STM03Xi7@0j>Ad303Th7080>3LK0`0n=ad203df70<0?3DK200k=1X803/g70P0
?SLM00@0@3TO03lh7P0n=ad0?SLM0P0l=A/0100k=1X0>S<I03hf8@0o=b83040h8`0303hf8@0l=1l0
>S8M00P0?SLM00<0@3HM044g7P13>B000P13>B000`12>1l0@3HM03hd6`02040f7@80@CLN0P12>1l:
04<i80<0A3PN0`15>Al204Hj800604Xh8019>B00BCTP04Pj8016>R00AC/P0P13?20204@j7`<0@cTN
0`12>1d00`11=a`0@SPM04@j7`0204Dk800404@j7`12>1d0@CLL04<g7@80A3PN00D0ACTO04Lk8@18
?280B3`R04Tm8`0304/k8@D0BSXP0140Cc`N050m7`1@?Al0DSdP05Hn8P1H?R<0Fd0U05a19P1N@2H0
Dd4M05M58@1KBBD0G4XV05]99@1LBRH0H4hZ06EC;`0306U=9@0;06Y>9P1[CbL0K50X06a@:01]DBT0
KEH/06mF;@1`F2`0M5T/07IJ:`1jFb`00P1lG2/01@1kG2d0OEh_07mP<@21HS<0PV<d0080PF8c00H0
P64b08IR<P26HS80Qf<c08QT=029ICD208YV=P0508]W=`2;Ic<0SFTe08m[=`2AKCT00P2BKSX00`2A
KCT0T6`h09Qb@`0309Ma@P80UW110P2EKd00102HLcl0VGA009Ud@02IM40209Ye@@80VgI200H0WGM:
09ihB@2NN4T0WgU80:1kA`2QO4L20:9mAP80XGa80P2RODT20:=nBP80Y7m;00P0Y8590:F2BP2UPT`0
YH5=0:J2D02VPU80Yh=C0:N2E@<0ZHEE0P2ZQUH30:^7E`<0[HUE0`2^RUH20:n;E`030;2<G02^RUX0
ZhMG0080ZHEE00<0ZhMG0:j:FP2`S5`00`2_ReL20;2<F0<0/HeI0`2^RUH20:n;E`<0/8aH202/QeX3
0:f7F0<0[XQI0P2_REX20;2;E`@0[hYF0`2^RED80:b6E`P0[HMH202[QEH0202YPe@0ZXAE0:b6E`2^
R5T0[hUJ0:j8F@2]QeP0[8IG202/R5P30:^6DP030:b7D`2]R5@0[HQD0080[XUE0P2`RU/20:n9FP80
[XQI0P2]QeP20:Z4E@80ZhEF0P2/QUL20:f7F0D0ZXAE0`2[QEH80:^6DP80ZXIB0P2[Qe<20:b8E080
[HUE202ZPeP80:^6DQP0ZXEA202YQ5080:^6DP80ZXEA102[QU830:b7D`P0ZhIB402YQ5000`2YPe@0
ZXAE0:^5EP020:b6E`030:Z4E@2XPU<0Yh5B0080YX5=00L0Yh9>0:R3C`2YQ500ZXEA0:^6DP2/Qe<0
/8ID0080[hEC00D0[XAB0:b2D02[PDl0Zh5?0:Z0CP020:R2D`<0ZH=D0`2ZQ5D80:^5EPP0[HMH00H0
[XUE0:f8E02]R5@0[8MC0:^6DP2ZQE430:V4D0090:^6DP2^RED0/8]G0;2;E`2^RED0ZhIB0:V4D02Z
QE40ZhIB00<0[8MC00/0ZXEA0:R3C`2VPDd0Z89C0:V3E02[QEH0[8IG0:f7F02/QUL0ZhEF0:Z4E@02
0:Z6EP80ZhMG0P2/R5P20:f9F@80ZhI?00<0ZhIA0:^6DP2[QE@00P2[QEH00`2[QEP0ZXIF0:Z6EP02
0:^7E`80[8QH0P2]RET80:n:EP80ZXIF0P2[QeL20:b8F080[HUI2@2^RUX20:n:EP060;2;E`2aS5P0
/8]G0:n:EP2]R5@0ZhIB202^R5T80:f7F0P0[XQI202]R5@80:n:EPP0[XUE402^R5T00`2/QUL0[HMH
0:j8F@020:n9FP060:j8F@2]QeP0[8IG0:f8E02/Qe<0ZXEA0P2YQ5000`2ZQE40[8MC0:f8E0020:f8
E0030:b7D`2[QU80ZXEA0080ZHA@00<0Z8=?0:^6DP2[QU800P2[QU830:Z5D@060:V4D02/Pdd0Zh9<
0:^2CP2ZP4h0ZX1@0P2YOU40102XOE80Y7i?0:EoD02WPE830:R2D`050:J0D@2UOe00YH1<0:J1C@2X
Pdl00`2ZQE400`2YQ500Z8=?0:R3C`020:R3C`@0Yh9>00<0YX5=0:AoB02TOdP01P2TOdP90:9mB@@0
Xgi:0P2RODT20:5lB0P0XWa=00T0Z7Y90:MiB02TN4L0XWQ60:9jA`2QO4P0Xgi:0:B0C02SOTX00P2R
ODT00`2QO4P0X7]709mjAP0209iiA@0309]eAP2ILd@0V7930080Ug5200<0V79309UcA02KMDH0202J
MD4209Ma@P80V79300D0VG=409YdA@2JM4D0VWA509aaA00309ebA@0409aaA02JKd80V6e009I[?P<0
Ufdk0P2HKS`309U_?@<0V6hn0P2GKCd309I/?080UFm20P2DKSl0302CKC`0Tfhj09=^>@2BKCP0U74g
09Aa>@2CL3X0Tflk099^?P2BKD00TVe1095/@PH0UF/k0P2FK3`01P2CKcd0TVhl095]>`2?JcT0SFTg
08aX=P80RVHd00<0RfLg08aX>02=JCT00P2>JSX00`2<J3P0RVHf08UU=@0808]W=@0308eY>@2;IcL0
RVHf0080RFDe00D0RVHf08]W=`2=JCT0RFDe08YV=P0208]W=`0808YV=P28I3@0QV8b08EQ<@2<HSP0
Rf4g08UO=@27GC<208IL<P<0Qedc00<0Pe`c08AM=025GSD00P26GcH01`25GSD0Q5dd08=L<`28HCP0
QUlf08AM=022Fc800P21FS42089K<PP0P5Pd00H0PEHc07mG<`1nES80OELb07YG<@1iEc4207MG<00F
07QK<@1iG380Ne/b07]K<P1kFS40NUL_07YD;@1hDR/0MU@a07EC<01cDBh0LDl/071>:`1aCb`0LU0]
07=A;P1_CR/0L4l/075@;@1bDBh0M5<`07IE<P80MeHc00@0Je0b06U><01WC2h0I4T[0`1RAbT0101S
B2X0G4DV05e69`1OB2T3065::`030619:P1OB2T0H4TZ0080H4TZ:oooool002[ooooo0`2FJch209M/
?`<0V6e0202IKT<309Q/>`<0VFdl0P2JKSd809Y`?P80V6`k0P2IKC`309Y^?@0309]_?P2ILd@0VG=4
00<0V79300<0VG=409]eAP2LMTL0402OLd880:1d@`@0WgA1102PMD80102QMT<0WG5009ib@@2PM4<3
0:9fA@030:5eA02PM4<0YGI200L0YGI20P2VODT40:AkA`80YWe90`2VNdP30:EjA`80Y7U6202UO4P8
0:MlB@080:UoC`2XOTh0Z7i<0:QoB`2WOTX0Ygi80:MnAP2VODD40:ImB@@0YGa800P0XGa50:1kA02P
NdH0WgY609ihA`2MMdP0W7I709afB@80VWA500@0VG=409Qb@`2GLD80Ug520P2FL4401P2HKS`0Ufdk
09E[>@2CJCL0TFLe08mU<`80SF<a00H0TVXf091X=@2;IS80Qf<a08EQ<@22H382089Q=004085N=P20
GCD0Oe`d07eJ<P<0O5Ta0P1mFS8207aI<@0307]H<01jEbl0NEH^0080N5D]00<0N58]07MA;01fD2/0
0P1eCbX0101fD2/0Me4/07QB;@1^D2`206e?:`0306a>:P1[CBT0JT`X0080JD/W0P1ZBBP206]::@80
K4/Z0P1]C2/0201^BB`0KDP[06e9:@1/B2H0KDTU06m<9P1aCRP0Le0X0P1fDBL00`1gDRP0NE@Z07YE
:`0207]F;00307aG;@1mF2h0OUT/0080OeX]00<0P5/^085L;`22GC000P23GS4208AN<@0308EO<P26
H3<0Qf4d00<0R68e202:I3L01@2>I3@0SfDe08mT=`2@ICX0TFHl0080TVHo00T0TVI108eQ=02<HC@0
SF8e08eT=P2<ISL0S6Ph08YX>02;JCT00`2;ICH308YT=@80RF<d00<0S6Hg08]U=P2:I3D00P28HS<0
0`29Hc@0RfDf08aV=`0208]U=P80RV@e0P29Hc@208QR<`<0RV@g0P29HcH308QR=@0308YT=@29Hc@0
R68c0080Qf4b00@0R68c08US=02:I3D0RfDh0`2:I3L308US=P0308QR=@2>HcH0SV<f00H0SV<f0`29
Hc@208YT=@<0RfDf00P0S6Hi08YT=`28HSD0RF<f08]U>02<IST0RfDh08QR=@<0SV<f0P2=HSD608aQ
=080SF8e0`2>HcH0102:I3D0RfDf08]U=P2;ICH408aV=`0308YT=@2;ICH0SVPi0080T6Xk00<0SVPi
08]U=P2:I3D02P2:I3D00`2;ICH0SFLh08iX>@0208iX>@80SFLh202;ICP808YT=@<0RF<d0`28HS<:
08MQ<P0308EP;026HBd0R6<_0080RF@`00<0R6<_08IQ;@25H2`00`26H34208EO<0<0Q5h_00<0QElb
08=M<020FRd00P1nF2/01@20FRd0PU`_08AN<@1lFRX0OE/[00@0OU`/00@0OE/[07aJ:P1mFbd0OE/]
0P1lFR`207]I:`80NUPZ0P1fF2H01P1fEbP0MULY07EF:P1bDRT0L50Y06i>9`80K4/X00L0JddY06Y>
:@1XCRT0IThX06E?:01TCRL0HDXX0080H4TW00<0GdPV05i79@1MAR@00P1LAB<01P1OB2T0GTLX05e6
9`1LABH0Fd@U05U28`80F44R0P1B?Ah01`1@?Al0CC`P04`k8@1:>R40BCXS04Pi8P13>B000P12>1l2
044g7P<0@3HM0`0k<R4203Xa80<0>C0O0P0f<b0203Db7`0403@a7P0c<1d0<RlL038_70<0<c0Q0P0b
;b04034^7`0302l/7@0a;Ql0<c0Q0080=34R00<0<RlP02l/7@0]:Q/0200];R0202/]8P80:R`Q00@0
:B/P02PZ7`0W:Ah09bTN0`0Y:b0202PZ7`<09bTN0`0Y:b0202PZ7`<09bTN200X:Q`302T[8080:2XO
0`0W:Ah00`0W:QT0:2/J02X]700202/^7@0302X]700X:aX09bXI00<0:B/M0P0Z;1h302/]7`P0:B/M
0`0[;1`202`]7@<0;BhN0P0^;1L0100_;AP0<2hI034_6P0a;aX2038`6`0802l^6@0^;AP0;bdH030[
5`0b:aP0=BdJ03L_700k<1h203<^6P0303@_6`0e<1`0=C0L0080=C0L00<0=2lK03Tb600i<QP00P0j
<aT303/d6P0303`e6`0i=AX0>CDJ0080>SHK0`0k=a`02@0l>1d0>CPL03Pg6`0i=AX0>C<I03Xc6@0m
<aX0?c<K040d700303hd6`<0?cDL0P10=Qd3048h7@80@CLL0`10=Q/9044g7P<0?SLK0P0o>1`3040i
7@80?CTN0P0l>1d303/g700403Xf6`0n=ad0?SLM03hg7@80?CHL0`0l=A/803/d6PP0>cLL200n=ad8
03df7080?SHQ0`0o=b800`0n=R40?3@O03/c7P0803hg7@0303le7010=Qd0@CLN00<0@SPO0P11=ah0
1010=Qd0@CLN044g7P11=ah3048h7`0304<i8012>1l0@SPO00H0@SPO0P13=ad204@h7P<0ACTO00L0
ASXP04Xh8019>B00BCTP04Pj8016>R00AC/P0080@c`P0P14>Ql304<i7P@0@SPM00P0@cTN04@j7`15
>b00AC/P04@j7`13>Ah0@SPM04<g7@80A3PN00<0ACTO04Hj8017>b400P18?28804Xj800704dl7P1@
?Al0D3dO054n801C?R40EShR05To900205]09@0405A27P1HAR80G4XV05a:9P80FTPT00<0GD/W065?
:`1WBb<00P1XC2@00`1YCBD0JThV06]?9`0206a@:00<06]D:P1/DbX0KUHZ079G:P1eFBX0NU//07aL
:`1mGB`0O5d^07eN;`1oH340PF8c0P22Hc@01021HS<0P64b08IR<P26HS8208MS<`0808QT=029ICD0
RVHf08YV=P2;Ic<0S6Pd08iZ=P2@K3P2095]>@80T6`h0P2CKCh309A^?`<0UFm00`2HLcl209Ud@0<0
VWE100H0W7I909egB02MMdP0WWQ709mjAP2PNdH20:5lA@80XGa80P2RODT20:=nBP80Y7m;00T0YH9:
0:J3B`2VPdd0YX9>0:N3D@2WPe<0Z8AD0:R3EP2XQ5@00`2YQED20:Z6EP80ZhMG0P2/R5@20:f9E@<0
[XYF00@0[h]G0;2<G02^RUX0ZhMG0P2ZQUH00`2[QeL0[XYJ0;2<G0020:j:EP80[h]G0`2`S5P00`2a
SET0[HUE0:j:EP020:j:EP80[h]G0P2`S5P80:b7FP<0[HMH0`2^R5T20:n9FP030;2;E`2_RUH0[hYF
0080[hYF0P2^RED20:f8E100[HMH202/QUL00`2ZQ5D0ZhEF0:b6E`030:j8F@030:f7F02/QUL0[8QH
00L0[8QH0`2[QU820:b7D`<0[HQD0`2^R5T20:f7F0<0[8IG0P2]QeP30:b6E`<0ZhEF0`2YPe@01@2Z
Q5D0ZhEF0:b6E`2/QUL0[HMH00P0ZhIB00@0ZXIB0:^7D`2[Qe<0ZhMC0`2/R5@0102]RED0Z89E0:R2
E@2YPeH20:Z4E`030:^5F02/QUT0[8II00P0ZhIB202XPdl80:Z5D@P0Z8=?202YQ5080:^6DP80ZXEA
102[QU830:b7D`P0ZhIB402YQ5001P2ZQ5D0ZhEF0:^5EP2/QUL0ZhEF0:Z4E@80Z89C00H0YX5=0:N2
CP2WPTh0Z8=?0:V4D02ZQE420:^6DP80[hEC00@0[XAB0:f3D@2]Pe40[89@0P2[PDl30:Z4E@<0ZhEF
0P2/QUL80:^5EPP0[HMH00H0[XUE0:f8E02]R5@0[8MC0:^6DP2ZQE430:V4D0070:^6DP2]R5@0[hYF
0:n:EP2]R5@0ZhIB0:V4D0020:Z5D@<0ZhIB00/0ZXEA0:V4D02XPdl0[8IG0:f7F02^R5T0[hUJ0:j8
F@2]QeP0ZhEF0:Z4E@020:Z6EP80ZhMG0P2/R5P20:f9F@80ZhI?00<0ZhIA0:^6DP2[QE@00P2[QEH0
0`2[QEP0ZXIF0:Z6EP020:^7E`80[8QH0P2]RET80:j9E@80ZXIF0P2[QeL20:b8F0/0[HUI00<0[XUE
0:n:EP2`ReL00P2`ReL00`2_RUH0[HQD0:b7D`080:j8FA00[hUJ202]R5@80:j9E@P0[hYF202^R5T8
0:f7F0030:b6E`2]QeP0[XQI0080[hUJ00<0[XQI0:f7F02/QUL00P2/Qe<40:Z5D@80[8MC00H0[HQD
0:b7D`2/Qe<0ZhIB0:Z5D@2YQ5020:R3C`<0ZHA@0`2ZQE420:^6DP80Zh9<00<0ZX5=0:Z0CP2YOdl0
0P2YOU40102YOU<0Y7i?0:EoD02VP5420:N1DP0;0:J0D@2UOe00Y7i?0:=nBP2TOd/0YX5=0:N2CP2X
Pdl0Yh9>0:J1C@2UP4`00P2WPTh0102VPDd0YH1<0:AoB`2TOd/20:=nBPP0XWe82@2PNdL20:9mB@80
XGa80`2PNdL00`2ONTH0WgU:09miBP0609miBP80Y7I500H0XGE40:1fA02OMd@0WWU50:1kA`2PO4P8
09ehA00309YdA@2ILd@0Ug520080UW1100<0Ug5209UcA02JM4D0202FLCd2099/?@80Tfdn102DKSl2
09U^@@0609Y_@P2KL4<0VVm209Q]@02FJch0U6Tl0`2BJ3H209=Y=`<0U6Xh0P2DJC`209=X>`80TVLj
0P2AIST02@2@JCh0SfPm08mY?02?JCX0SVPg08iY=@2=J3@0SFPc08eZ=00208iZ=P0508iZ>02?Jc/0
SfXm08mZ?P2@Jcl0202DJC`0202>JSX0SFTi08eY>@2;IcL0RVHf08UU=@28I3@0Qf<c0P2:ICP308]V
>@0308UT=`28HcH0Qf8e00P0RFDe00<0RVDh08UT=`28HcH00P27HSD01P28HcH0RF@g08YU>022GC00
Peha08EP<`80QV4d00P0QF0c08=N<@22GC00QEhe08=L<`21FS40OeP_07iG;P<0OeP_00<0P5T`07mI
<P1nF340101mEc001`1nF340OeTb08=M=P21Fc@0OUPa07aF;`1jE2d00P1iDb`0101jE2d0OeTd07mI
=01nF3<207aF<@<0NeD`00P0O5@`07]C;`1jE2l0N5D_07ID;P1eEBh0M5@]079E;@80LeL_00X0MEP`
07MG<01gEBl0MU<]07AA:`1eCbX0LE0_06m>;@1]C2/0JdXY101ZBBP01P1ZC2X0Jdd[06a>;01]Cbd0
Ke4_071B<080LE<a00@0Idh`06E<;P1SBR`0H4LY0`1OARP0101PAbT0FT8V05]39`1MABT305i6:P80
GDDY0`1NARX[ooooo`00:_ooool209I[?P80Uf`o0P2HKD0209U^@@P0Vg150`2HK3/309U]?080VVhm
202JL3h309U]?0<0VVhm0P2KKch409Ya@`80Vg940P2LLdD80:1d@`P0Wg=2202NLT4209ic@00509md
@@2PMD80X7E20:1e@P2QMT<00P2RMd@00`2MLD00WW910:1d@`030:9fA@030:5eA02PM4<0YGI200L0
YGI2202VODT30:IkB0<0YGY70P2TNDH80:ElB0@0Yga9102XODX20:MmC@040:MmB`2WOTX0Ygi:0:Mn
B080Ygi6102VODT40:ElB080X7]400<0WgY509iiA@2MMdH00P2LMTL01`2KMDP0VWA509YdA@2ILd@0
V79309Ma@P2FL4400P2EKd003P2HKSh0Ufdm09E[>`2CJCT0T6Hf08iT=02<HS80Rf4a095Y=P2?IcH0
RfDd08MS<`25H3<0PV0c0P21H3D01@21GSH0P5de07mL=01nFc<0OEXb00@0O5Ta0P1kF3000`1jEbl0
NEH^07QE;@0207MD;0P0M54[0P1]Cb/0101/CRX0JddY06]=:@1ZC2P206U;9`80JTTX0P1[BRT206a;
:P80KD`[0P1]B2/02`1/B2P0KDTW06m;9`1aCRP0M54[07IC:`1gDRP0N5<Y07UD:P1jEB/0NeH/0080
O5L]0P1mF2h5081K;P<0PE`_00H0Ped`08AN<@25Gc80QV0c08MQ=029HcH208YT=`P0RV@e00T0TFLg
091V=P2>HcH0SV<h08mT>P2AICh0U6Q109IZA@2=HC@00P2=HSD01@2=I3H0RfDf08]W=`29IcL0RVPh
00H0RV@e0P29Hc@00`2:I3D0RF<d08QR<`0208QR<`0308YT=@2<ISL0SFLh0080RfDf0P2:I3D208US
=080R68c0`2;ICP208YT=`@0RF<f1P28HSD00`29HcH0RV@g08YT=`0208YT=`@0RF<f202>HcH408YT
=@@0RfDf00@0RfDh08YT=`2:I3L0RV@g0`2;ICP00`2:I3L0SV<f08iS=P0208iS=PP0SF8e102>HcH0
1P29Hc@0RV@e08YT=@2;ICH0S6Hg08eW>080SVPi00<0S6Hg08eW>02?JCX00P2@JS/00`2?JCX0SFLh
08aV=`0908YT=@0308]U=P2<ISL0S6Hg00<0SFLh0P2<ISL808]U=PP0RV@e0`29Hc@308QR<`X0Qf4b
00<0QV4]08MR;P28Hbl00P29I3000`27HRh0QV4]08AO:`0208EQ<@<0Q60`0`23Gbl02@22GC00PE`_
07mJ;@1nFB`0OeX]081K;P23GS40Q5lb07aJ:P0607eK:`0607aJ:P1mFbd0O5X/07aJ;01kFB/0NUPZ
0P1iEbT04P1hERP0MELU07IH9P1fEbP0MULY07AE:@1bDRT0KdlX06i>9`1YB2D0JTTV06Y<:01ZCRT0
J4hY06M?:@1UCbP0I4hW065::080H4TW00<0GdPV05i79@1MAR@00P1LAB<205e8:`0405a7:P1JABP0
FD@W05M29@80ET4T00P0DC`O050m7`1=?200C3/Q04Xj8@19>R<0ASXR04Hj90P0?SHO0`0h<Al203L`
7P<0=RlM0P0e<Ql203@a7P0403<`7@0b;a`0<RlL038_7080<c0Q0`0b;b04034^7`0802dZ6`0`;Ah0
<c0Q03Hc900e<R<0<RlP02dZ6`0[:1T802`]7`<0:R`Q00<0:B/P02PZ7`0X:Ql00P0W:Ah402PZ7`@0
9bTN0P0Y:b0202PZ7`809bTN0P0V:1d802PZ7080:B/P0P0X:Ql202LY7P809RPM00<09bTK02PZ700Y
:ad00P0[;Al00`0Y:ad0:2XL02LY6`0302PZ7080:B/M0`0Z;1h802T[7@<0:b`L0P0/;Ad302d^7P80
;R`G0P0_;AP2030^6@80<BlJ0100;bhI02h]600^;1L0<2/G038[600e;AX0=blL03/`7P0b;AL0<bhH
03@_6@0e<1X0=S4K03D`6P0d;aT0<bhH100i<QP203Xc6@80>c@J0`0j=Q/303/g7080?3PM00P0>3LK
03Lf6P0h=1T0>38H03Tb600m<aX0?c<K044e7@80?S@K0P0o=A`01010=Qd0@CLN048h7`12>1l3048h
7@<0@CLL0P10=Q/9044g7P80?SLK0`0o>1`3040i7@<0?SPN0P0m=ad303`f70<0?SLM0P0m=Q`;03`e
6`P0>cLL200m=Q`203/d6P0403`e6`0m=Q`0?CHL03hg7@80?cPN0P0m=B0303hf8@80?CDP00<0?3@O
03hg7@0n=ad01P0n=ad203hd6`0303le7011=ah0@CLN00<0@SPO1011=ah<048h7`<0@cLM0P14>1h3
04Di7`0604Tg7`18>1l0B3PO04Li7`15>Al0A3XO0P12>al204@j7`<0@cTN0`12>1d00`13>Ah0A3XO
04@j7`0404@j7`0504<i7P14>1h0A3PN04@h7P15>Al00P16>R0204Lk8@@0B3XO1019>b004@1<?Ah0
CC`N04dl7P1>?Al0DChP05<n8@1F?R80F3hS05To901E@al0FDLS05a:9P1KBBD0F4HR05M58@1JB2@0
GT`X0080ITXR00@0Id/S06Q<901ZCRH0JdlW0P1/D2P0301XDBL0JU4X06aD:01aERT0M5PY07UJ:`1l
G2/0OEd/07]L;@1mGRl0Of0a085R<`80PV<d00P0PF8c081Q<P25HC40QF4a08IR<P27Hc<0R6@d08UU
=@80RVHf00D0RfLc08aX=02=JCD0SVXf08m[=`03091/>00608mY>P2@JS/0T6Xk099/?@2CKCh0U6ho
0P2EKd0309Qc?`<0VGA00P2JMD401P2LMTT0W7I709egB02MMdH0WWU509mjA@80X7]40P2QO4P20:9m
B@80Xgi:0P2TOd/20:J3B`030:N4CP2WPdl0Z8AB0080Z8AD00<0Z8=F0:R4E02XQ5@00`2YQED30:Z6
EP<0[8QD0P2]RED30:j:EP030:n;F`2^RUX0[8QH0080ZhMG00<0[8QH0:j:FP2_Re/00P2]RED20:j:
EP<0[h]G00<0/8aH0:f9E@2]RED00`2^RUH30:n;E`P0[HQK0`2]QeP30:j8F@80[hUJ102_RUH20:j9
E@<0[HQD202^R5T80:f7F0/0[8IG102]QeP00`2/QUL0[8QH0:b8F0060:b8F0@0ZhIB102/Qe<80:b6
E`80[hUJ00P0[XQI0:f7F02/QUL0ZhEF0:Z4E@2YPe@0Z89C0:V3E080ZXAE0P2/QUL00`2]QeP0[XQI
0:^6DP070:^6DP@0ZhME102/R5H20:N1DP040:R2D`2YPe@0ZhEF0:b6E`80[HMH202ZQE480:N2CP80
ZHA@102ZQE420:^6DPP0Yh9>202YQ50:0:Z5D@@0ZhIB0`2/Qe<80:Z5D@/0ZHA@102ZQE400`2[QU80
ZhEF0:^5EP020:^5EP040:Z4E@2YPe@0ZH=D0:R2D`80Yh9>0P2XPdl01@2YQ500ZXEA0:Z5D@2ZQE40
[hEC0080[XAB0P2]Pe420:b2D0040:^1C`2[QEH0ZhEF0:^5EP<0[8IG0P2]QeP80:^5EPP0[HMH00H0
[XUE0:f8E02]R5@0[8MC0:^6DP2ZQE430:V4D0070:^6DP2/Qe<0[XUE0:j9E@2/Qe<0ZhIB0:V4D003
0:Z5D@030:^6DP2ZQE40ZXEA0080ZHA@0P2_REX20;2:F`040:n9FP2^R5T0ZhEF0:Z4E@80ZXIF0P2[
QeL20:b8F080[HUI0P2[QTl00`2[QU40ZhIB0:^5E0020:^5EP030:^5F02ZQUH0ZXIF0080ZhMG0P2/
R5P20:f9F@P0[XUE0P2ZQUH20:^7E`80[8QH2`2]RET00`2]R5@0[XUE0:n:EP020;2;E`030:n:EP2]
R5@0[8MC00P0[XQI202`RU/80:n9FPP0[8MC202]R5@80:n:EPP0[XQI2@2[QE@0202/QUD0[HMF0:n9
F02_REP0[HMF0:b6E@2[QE@0ZhIB1P2ZQE401`2[QU80[8MC0:^6DP2[QU80ZXEA0:V4D02XPdl00P2W
PTh20:J1C@030:N2CP2XPdl0ZHA@0080ZXEA00H0ZhIB0:V0BP2YP4X0ZH1<0:UoC@2XOTh20:QmD003
0:QmDP2TOTl0Y7i?00<0Y7i?0P2SODh0102RO4d0X7]70:5lB02RODT20:AoB`030:=nBP2RODT0XGa8
0080Y7m;00@0Xgi:0:9mB@2QO4P0X7]70P2ONTH809iiA@T0WGQ40P2ONTH209iiA@@0WGQ4202KMDH2
09ma@00609ea@02LLT00Vg=009Ye@@2KMT80VWI20`2GLD000`2HLT40VG=209Uc@P0209Yd@`0309Qb
@`2FL440UFm00080U6ho00<0UFm009I`@@2HLT<0202BK3/7095[?009099/?@2CJS`0U6/m09E/?P2F
KCl0UF`n09A[?@2BJC/0T6Li0080SfLf0P2@J3L3095Y>004099Z>@2AJ3`0TFPl095X?080T6Lk0`2?
ISX208eV?@0308eV>`2<IST0S6Hg0080RfDd00H0RfHb08MS<`27Hc<0R6@d08UU=@2:ICP208aW>P03
08eX?02AJ3`0TFPl0080TFPl102@Ic/208UT=`0408QS=P27HSD0Qf8e08IQ=080QF0c1@27HSH00`26
HCD0QF0d08EP=00308MR=@<0QV4d0P25H3<00`26HCD0QF0d08EP=00408EP=00408IQ=@1oFRh0PE``
089M<@<0Q5lc00H0PUda085L<022GC<0P5/a07iI;`1lEbd207]F;080O5L]00@0OEP^07aI<`1jEc40
N5D_0P1fDbd0201hEBl0NULa07aI<`20GCL0OU/e07]H<P1gE2h0ME8/0`1dDB/01P1lF3@0NUHb07QD
<01fDRh0ME4]07A@;080ME4]01H0Me4]07I@;01dD2`0Le4/075A:`1_DB/0KU0Z06eA:P1ZD2/0Je4/
06iB;@1`DRh0LE0]071>:`1_CBX0KTXX06a=;P1[C2d0JDX[06Q9:P1VAbP0IDHW0P1TABH206I9:@04
06M::P1XBb/0JD`/06Y=;@80Jdh^00@0HTX^0659;@1NARX0G4@X0P1K@bL205a4:080Ed8W1P1H@bP3
05Y5:R_ooooo000Zooooo`<0Uf`o0P2HKD0309U^@@P0Vg150`2HK3/309U]?080VVhm202JL3h209U]
?0<0VVhm0`2KKch209Y_@P80Vg13102LLD@80:1d@`P0Wg=2202NLT40102NLd00WgA109md@@2PMD82
0:5f@`80XWM400@0XgQ509ea@02NLT40X7A30`2RMTD00`2QMD@0X7A30:Ef@P070:Ef@PP0YWe90`2V
NdP30:EjA`80Y7U6202TNdL00`2VNdP0Yga90:MlB@020:QmBP80ZGi;00L0ZWm<0:IlC02VO4`0YWa:
0:ImB@2WOTX0Ygi80080Ygi60P2WOTX20:ImB@80YGa80P2TNdL0202PNd@0WgY309mjA@2NNDD0WGM6
09afA`2KMDH0VgE80P2ILd@0102HLT<0Ug5209Ma@P2FL44209E_@00>09M/?`2FJch0U6Tl099W>P2@
ICP0SV<f08eR=@2<HC@0TFTh08mV>02:I3D0QV4d08AO<`22GcD2085P=`80P5de0P1oG3@00`1nFc<0
OEXb07aI<@0207]H<080NUL_00<0NEH^07QE;@1gE2`00P1fDb/2079@:P@0Le4[0P1bD2X206e?:`04
06a>:P1[CBT0JT`X06U;9`80J4XV0P1ZBBP206]::@80K4/Z0P1]C2/206e8:`0606e9:@1^BRP0L4`X
07=@:P1fDbd0Me@/0P1iE2X00`1jEB/0NeH/07aG;@0207aG;@80OEP^1`21G2l02@20Fbh0Q5ha08AN
<@25Gc80Qf4d08QR=@29HcH0RV@g08]U>00808YT<`09099X>02@ISH0SV<f08eR=`2>HcT0T6@m09AX
@@2FJTD0SV8e0080SF8e00<0S6<e08]U=P2:ISH00P28ISH608US=080RV@e0P28HS<208MQ<P0408QR
<`2:I3D0S6Hg08iX>@80RfDf0P2:I3D208US=080R68c0`2;ICP208YT=`<0RF<f0`28HCH208UR=`<0
R64f1029HcH408YT=`P0SV<f202;ICH00`2:I3L0RfDh08aV>@0208]U>00308YT=`2;ICP0S6Hi0100
SV<f0P2:I3D00`2;ICH0S6Hg08eW>00208iX>@0408mY>P2<ISL0SFLh08iX>@80SfTj00<0SVPi08eW
>02<ISL02@2:I3D00`2=IcP0S6Hg08aV=`0308]U=P80S6Hg202;IC@808YT=@<0RF<d0`28HS<:08MQ
<P0808MR;P28Hbl0RF@`08UT<028Hbl0Qf8^08EP;024Gb/308AP<0<0Pel_0P22GRh00`22GC00PE`_
081K;P02081K;P04085L;`23GS40Q5lb07eK:`H0O5XZ00L0OE/[07aJ;01lFR`0NeT[07YH:P1iEbT0
N5HX0080MeDW0P1eEbD03`1fEbP0MEHX07AE:@1aDBP0KdlX06e=9P1XAb@0JDPU06Y<:01ZCRT0JDlZ
06M?:@1TCRL0HddV065::00206199`0305m89P1NAbD0GDHT0080G4DS0P1KAb`0101JAR/0F4@Y05M3
:01E@BH205A09@0804lk801=?200C3/Q04/k8P19>R<0ASXT04@i8`14>BD803/e7`<0=S4N0P0e<1d3
03@_70<0<c0M100b;a`0100a;Q/0<RlP038_800b;b03034^7`<0<2dN00<0;2TJ02l/7@0c<2400P0e
<R<00`0a;Ql0;BXK02XW600802`]7`<0:B/P100X:Ql902LY7P<0:2XO0P0W:Ah302HX7@P09bTK0`0X
:Ql202LY7P<09RPM00<09RPK02PZ7@0Y:ah00P0Z;1l00`0Y:ah0:2XM02HX6`0302LY6`80:2XL2`0Y
:ad302//7080;2dM0`0];Qh302l]60<0<2hI0P0a;aX0200`;aX0;bhI02l]600a;1P0<b`I03H^6`0h
<1d0?34O0P0f<QT203Lc6P80=S8I00<0=C4H03@`5`0i<QP00P0i<QP203Xc6@<0>c@J0P0j=Q/303/g
70<0?3PM00T0>3LK03Lf6P0h=1T0>38H03Xc6@0n=1/0@CDM048f7P0n=1/00P0o=A`00`10=Qd0@CLN
048h7`0204<i8080@cTN0`12>1d3044g70T0@SPO0`0o>1`3040i7@80@CXN0P10>Al203lh7P80?SLM
0P0m=Q`303hg7@80?CHL2`0l=A/803/g70P0?CHL00@0>S<I03/d6P0l=A/0?3DK0P0n=ad0100o>1h0
@3TO03de800m=B0303`d7`80?CDP00<0?SHQ03hg7@0n=ad01P0n=ad203hd6`80?cDL00@0@3HM044g
7P12>1l0@cTP1012>1l<044g7P80@SHL0P13=ad204@h7P80ACTO00H0BCLO04Ph7`18>1l0AcTO04Di
7`14>Ql2048k7`80A3XO0`13>Ah3048h7@0304Dk8014>Ql0A3XO00@0A3XO00@0AC/P04@h7P14>1h0
A3PN1015>Al01016>R00A3TM04Dj7P15>Qh204Hk7`80Ac`P00@0B3dQ04/n7P1<?Ah0C3dN0P1>?Al0
801A?R00DchQ05Hn8P1F?R80E48N05Q68P1KBBD0FTPT05I4801E@al0F4HR05a:9P1TB200IDTQ06I:
8P1WBb<0JDdU06Y>9P1[CbL0K50X06I?9@1YD2L0Je<W06mD9`1cEbP0N5TZ07]K:P1lG2/0NU//07]L
;@1mGRl0Of0a0P20HC8207mP<@80QF4a00@0QV8b08MS<`27Hc<0R6@d0P29ICD308]W<`0=08aX=02=
JCD0SVXf08m[=`2@K3P0SFLh08iX>@2?JCX0T6Xk099/?@2CKCh0U6ho09E_@00209Mb?P<0V7<o0`2I
M4001P2KMDP0VgE609afA`2MMdH0WWU509iiA080WgY30P2QO4P20:9mB@80Xgi:0P2TOd/20:J3B`03
0:J3C@2WPdl0Yh=A0080Z8AD00@0Z8=F0:R4E02XQ5@0Z8AD0`2YQED20:Z6EP80ZhMC0P2/R5@20:f9
E@80[XYF00<0[XYJ0:f9F@2/R5P00P2[QeL0102/R5P0[HUI0:j:FP2/R5@30:f9E@80[XYF0P2_ReL3
0:f9E@<0[XYF0P2_ReL80:f8F`<0[HMH0`2^R5T20:n9FP80[hYF0`2^RED20:f8E080[8MC202^R5TC
0:f7F0@0[8IG00<0[HMH0:b8F02/R5P01P2/R5P80:^6DPP0[8IG00H0/H]L0;2:F`2_REX0[XQI0:b6
E`2[QEH20:V3E0<0ZXAE00<0ZhEF0:b6E`2]QeP00P2]QeP80:^6DP@0[8QH102[QeL20:N1D0040:R2
D@2YPe80ZhED0:b6E@80[HMF202ZQE480:N2CP030:R3C`2YQ500ZHA@0080ZXEA0P2[QU800`2/Qe<0
Yh9>0:N2CP060:N2CPP0ZHA@2P2ZQE440:^6DP<0[8MC202ZQE4;0:V4D0030:Z5D@2[QU80ZhIB0080
[8MC00@0[8IG0:^5EP2[QEH0ZXAE102YPe@30:R3C`@0ZHA@00<0ZXEA0:j4DP2^Q580102]Pe420:b2
D0<0ZhEF0`2/QUL20:f7F0P0ZhEF202]QeP01P2^RED0[HQD0:f8E02/Qe<0ZhIB0:Z5D@80ZHA@0P2Z
QE440:b7D`D0ZXEA00<0ZHA@0:Z5D@2ZQE400P2[QU80202_REX0/8YK0;6;G02aRe`0/8YK0:j8F@2/
QUL0ZXAE0P2ZQUH20:^7E`80[8QH0P2]RET20:^6C`030:^6D@2[QU80ZhED0080ZhEF00<0ZhEH0:Z6
EP2ZQUH00P2[QeL20:b8F080[HUI202^RED20:Z6EP80ZhMG0P2/R5P;0:f9F@030:^6DP2/Qe<0[XUE
0080[hYF00<0[XUE0:f8E02/Qe<0202^R5T80;2:F`P0[XQI202[QU880:b7D`P0[XUE202/QUL90:V4
D0070:Z5D@2/Qe<0[HQD0:f8E02/Qe<0ZXEA0:V4D0020:R3C`@0ZHA@0P2XPdl20:V4D0030:R3C`2W
PTh0YX5=0080YH1<00H0Y7m;0:=nBP2SOTX0Y7m;0:F0C02VPDd20:N2CP060:R3C`2VODL0YWe70:Im
B@2VO4X0YWa<0P2VNdh01@2VNe00XWa=0:9lC@2QNd`0X7Y;00@0WgU:00<0WGQ409iiA@2ONTH00P2P
NdL00`2ONTH0WGQ409ag@`020:1kA`80WgY600@0WWU509ehA02MN4@0W7M3202JM4<909Ud@00409]f
@P2JMD40VWE109Ye@@80VGA00P2HLcl809I`@@0509U[>P2JK3/0V6`k09Q^?02HL3d00P2FLCd01`2E
LCd0TF/l095[?02BK3d0Tfdn09A^?`2EKd000P2FL4400`2DKSl0Tfdn099/?@02095[?003099/?@2C
KCh0U6ho00P0SfTj1`2AJc`02P2@JS/0SFLh08iX>@2?JCX0T6Xk08mY>P2>J3T0S6Hg08]U=P2=IcP3
08iX>@80SfTj0P2@JS/3091Y?P80SfPm0`2>Ic`208eV?`0308eV?@2<ICX0S6Hi0080RfDf00T0RfDd
089M<`23GS80Q5lc08EP=027HSD0R6<f08UT=`2:ICP00`2<ICX00`2;I3T0RV<h08YS>00208UR=`P0
Q5lc00@0QF0f08AO=@24GcD0Pehd1022GC<208EP=080Q5lc00D0Pehb089M<@22GC40PUda085L<P06
089M<`04085L<P1oFS00PE`b089M<`<0Q5le0P22GC<01021Fc@0P5Xc07iH<@1lERl207]E;P<0O5H_
00<0NUPc07UG<P1fE2l00P1dDRd0201fE2l0NELb07YH<`1nG3L0O5Xe07UG<P1eDbh0Le4/0`1bD2/0
101hES<0MU@a07=A;P1aCb`206m=:P07071>:`1aCb`0L4`Z071<:P1_CBX0KD`Y06]=:@0206U=:009
06M=:01SBbT0I4`Z06I<:`1YC2`0JDX[06Y9:P1XAbP0J4DW00<0J4/]00D0IdX/06E8:P1TAbT0HdHX
06959`0306159`090656:01RAbT0HdPZ06=8:P1TBB/0G4L/05]6:`1H@bP0Ed8W0080ET4V00@0Ed8W
05Q3:01D@2L0E40W1P1C?bH305E1:2_ooooo000Zooooo`80Uf`o0P2HKD0309U^@@0309Y_@P2JKd@0
VVm400H0VVm40`2HK3/309U]?080VVhm202JL3h0102IKC`0VVhm09Y^?@2JKSd209]_?P80W70o00<0
VFe009Y^@@2LL4<00`2MLD@209a`@a00Wg=2202PM4<30:1e@P@0XGI30P2RMd@00`2MLD00WW910:1d
@`030:9fA@030:5eA02PM4<0YGI200L0YGI20P2TNdL40:ImB@80Y7]70`2VNdP30:EjA`80Y7U6202T
NdL20:IkB0030:MlB@2XODX0ZGi;0080ZWm<00@0Zh1=0:EkB`2UNd/0YG]90P2VODT0102WOTP0Ygi6
0:MnAP2XOd/20:MnBP050:ImB@2UO4P0Y7]70:AkA`2SNTH00P2ONT<00`2NND@0WGQ409afA@0209]e
AP0609YdA`2ILd@0VG=409Qb@`2GLD80UW110P2EKd004@2DKSl0U6Tn09AY?P2CJ3d0TVLl091U>P2?
I3T0SV<h08eR=`2@IcT0SVDg08YT=`26HCD0Q5le085N=P20GSP0PEli0080Oe`d00D0P5de07mL=01o
G3@0OEXb07]H<00207YG;`80NEH^00<0N5D]07MD;01fDb/00P1eDRX00`1`D2T0LE4Z079B:`03079B
:`04075A:P1`D2T0K4hZ06a>:P80JddY00@0JT`X06U;9`1XBRH0J4XV0P1ZBBP206]::@80K4/Z0P1]
C2/0201_BRd0KTT/06i::P1_BbT0L4`X07=@:P1fDbd0N5D]0`1kER`207aG;@@0OEP^1P22GC0208=N
<@<0QV0c00<0Qf4d08QR=@29HcH00P2:I3L808YU<@09099X>02@ISH0SV<f08eR=`2=HSP0SV8k091T
?@2AID00SV8e0080SF8e00<0S6<e08YT=@29ICD00P27ICD308QR<`<0RF<d0P2:I3D00`29Hc@0R68c
08MQ<P0208MQ<P0308US=02;ICH0SFLh0080RfDf0P2:I3D208US=080R68c0`2:I3L208US=P<0R68e
00<0Qf0g08QQ>029HST00P2:HcX01029HST0R64h08MP=`28HSD308US=P<0RV@g00<0RfDh08iS=P2>
HcH01P2>HcH0102=IcP0S6Hg08aV=`2<ISL308]U=P0:08YT=@29HcH0S6Hi08iX>`2=IcX0RV@g08US
=P2;ICP0SFLj08eR=@<0SV<f0`2?I3L2091U>0<0Sf@g0`2>HcH00`2=HSD0S6Hg08aV=`0208aV=`<0
SFLh00<0SVPi08aV=`2=IcP01@2=IcP00`2<ISL0RV@e08YT=@0708YT=@0308iX>@2=IcP0RfDf00<0
RV@e0P2;ICH808]V<PP0RV@e0`29Hc@308QR<`X0Qf4b0P28Hbl208UT<00408QS;`26HBd0Q5l[08=N
:P<0PV0`0P21Gbl3081N;P<0P5h`0`1oGBl2081N<00307eK:`1lFRX0NeTY00<0NeTY01/0O5XZ07eK
:`1lFR`0O5X/07]I:`1iEbT0N5HX07ME9`1fE2H0ME<U07AF901eEbD0MEHW07EF:01cE2P0LE4X06i>
9`1]CBH0J4LT06Y99P1ZC2P0JdlZ06U?:P1VCRP0HT`U061:8`1QBRP00P1PBBL00`1OB2H0GTLU05e6
900205a58`80EdH/00h0ETD[05A3:@1C@RP0DT4W05509P1@?bD0CC`R04/k8@1;>b80BCXS04Hj9014
>BD0@CTT044i9P<0>SDQ0P0i=20203Pc7`0403Lb7P0d<Ah0=34N03@a7P80<c0M100b;a`7034^6`<0
<RlP0P0a;Ql4030]7P0802h[700_;1d0<RlP03<`8@0b;b00<2dN02dZ6`0[:1T802//7PP0:2XO00@0
9BLL02HX7@0V:1d09RPM0`0W:Ah302PZ7`809bTN0`0V:1d00`0U9a`09bTK02LY6`0602LY6`80:2XO
0P0W:Ah302HX7@0402DW700V:1d09bTN02T[8080:R`Q00<0:B/P02LY7P0V:1d00`0V:1X202LY6`<0
:2XL200Y:ad302//7080;2dM0`0];Qh5034_6P<0<S0K00`0<S4L034`6`0a;aX0<bhJ03D^6`0h<1d0
>S8O03hc8@0o>b00?SXO03/g700i=AX303Lc600303Pd6@0j<aT0>c@J0080>c@J0P0l=A/203df7004
03Xf6`0k=a`0>cLL03/g7080?3PM0P0m>Ah203Pg6`0603Te6P0j=1X0?3DK03le7013=al0A3PP1011
=ah3048h7`0404<i8013>Ah0@cTN04<i7P80@SPM0`11=a`9048h7`<0?cPL0P10>Ad3044j7P<0@SPO
0P11=ah3040f7@<0?SLM0P0m=Q`;03`e6`P0>cLL200l=A/203/d6P0403`e6`0m=Q`0?CHL03hg7@80
?cPN0P0l=1l303/c7P0303`d7`0n=R40?cLR00P0?SLM00<0@3HM03le700n=1/00P0n=1/01010=Qd0
@CLN048h7`13>B03048h7`<0@CLN00<0@3HM044g7P11=ah01P11=ah3048f7080@cLM0`14>1h01P18
=Qh0AcLN04Lg7P16>1h0A3PN04<i7P80@CXN0P14>Ql304<i7P<0@SPM00<0AS`Q04Dk8014>Ql00P13
>Ah00`14>Ql0AC/P04Hl8@0804@h7P06048i7013>Qd0@cXM04@k7P15?1l0ASdP0P17?R4304/n7P04
04`m7P1>?Al0CSdO054n8080DSdP01`0DT0L05I4801IAb<0F4HR05E37`1D@Qh0EdDQ05]99@1RAQh0
HdLO06A8801VBR80J4`T06Y>9P1[CbL0K50X06I?9@1XCbH0JU8V06iC9P1aEBH0MEHW07QH9`1iFBP0
MePY07UJ:`1kG2d0OEh_0P1nGc000`1mGRl0O5d^08AP<00208EQ<@0308IR<P27Hc<0R6@d0080RFDe
0P2;Ic<208YV<P0<08]W<`2=JCD0Sf/g091/>02>J3T0SfTj091Z>`2AJc`0TV`m09=]?P2DKSl0UFm0
0`2GLSh209Qc?`<0VGA000P0VWA709YdA@2KMDH0W7I509ehA02NND@0WWU209mj@`80XGa80P2RODT2
0:=nBP80Y7m;0P2TPDT00`2UPT`0YH5=0:J2D0020:J2DP030:N2E@2WPe<0Yh=C0080Z8AD0`2YQED0
102ZQUH0ZhMC0:^7D`2[Qe<20:b8E0<0[HUE0`2]RET20:b8F0<0[HUI00@0ZhMC0:b8E02/R5@0[8QD
0P2]RED20:j:EP80[8QD0P2]RED30:j:EP030:n;E`2]R5/0[HQK00H0[HQK0`2]QeP30:j8F@80[hUJ
102^RED20:f8E0<0[8MC602]QeP00`2_REX0[XQI0:f7F0030:^5EP030:b6E`2]QeP0[8QH00L0[8QH
00@0[8MC0:^6DP2[QU80ZhIB0`2ZQE40102YQ500[8IG0:b6E`2/QUL20:f7F0<0[XQI0P2`RU/0102_
REX0[XQI0:f7F02[QEH20:Z4E@P0[8IG202[QU80102]R5/0[8MJ0:b7FP2/QeX30:^6F@040:Z5F02X
Pdl0Z8=?0:V4D080ZXEA00<0ZhIB0:b7D`2/Qe<0202YQ50:0:R3C`040:V4D02ZQE40ZXEA0:^6DP80
[8MC202XPdl@0:V4D080ZXEA102[QU830:b7Da00ZHA@00H0Z8=?0:V4D02YQ500ZXEA0:^6DP2/Qe<2
0:f8E080[8IG00<0ZXAE0:V3E02XPU<00P2YPe@00`2ZQ5D0ZHA@0:V4D0060:V4D0P0[H=A0`2ZQ5D3
0:^5EP80[8IG202[QEH80:f7F0060:j9E@2]R5@0[HQD0:b7D`2[QU80ZXEA0P2YQ5020:Z5D@@0ZhIB
102ZQE430:V4D0060:Z5D@2[QU80[8MC0:f7F02^R5T0[hUJ0P2`RU/00`2^R5T0[8IG0:^5EP020:Z6
EP80ZhMG0P2/R5P20:f9F@80ZhI?00<0ZhIA0:^6DP2[QE@00P2[QEH00`2[QEP0ZXIF0:Z6EP020:^7
E`80[8QH0P2]RET80:f8E080ZXIF0P2[QeL20:b8F080[HUI2@2/R5P00`2ZQE40ZhIB0:f8E0020:n:
EP030:j9E@2]R5@0[8MC00P0[XQI202_REX80:b6E`P0ZXEA202[QU880:b7D`P0ZXAE202WPTd00`2V
PD`0Yh9=0:V4C`020:Z5D0060:V4C`2WPTd0YX5<0:AoB`2UP4`0YX5=0P2WPTh00`2VPDd0YH1<0:Ao
B`020:J1C@030:F0C02TOd/0Xgi:0080XWe91@2QO4P30:9mB@0=0:=nBP2RND<0XWU30:9iA@2SNDL0
XgU90:=hB`2TND`0Y7U>0:1jB`2NN4T0WGM809]eAP0209YdA@80VgE600P0VWE109]f@P2LMd<0WGQ4
09ag@`2KMT80VGA009Qc?`P0VgI2202GLD8:09Ia?@<0UG0l0P2DKc/209=^>PP0TV`m00P0U6He09EW
=P2DJ3L0U6Xh09A/>@2BKCT0TF`h08m[=`80SFLj00@0SVPk08mY?02@JSd0T6Xm0P2AJch00`2@JS/0
SfTj08eW>00208aV=`0308eW>02?JCX0T6Xk00P0SFLj0P2@JS/208mY>P@0SVPi00<0R6@d08UU=@2:
ISH00P2;IcL00`2:ISH0R6@d08MS<`0308]V>@80S6Lj0`2=J3/208iY?`80SFPn0P2<Icd208]V?080
Rf<o00h0RV<l08YS>P29HSL0RF<f08US=028HS<0P5Xe085K=P22G3D0Pehd08AO<`25H3<0QV8b08MS
<`80Qf8h00@0QV4g08EP=P25H3H0Q5le0P23GS@01021G380PUdc089M<`22GC<408=N=005089L=@21
Fc@0P5Xc07mI<P1nF3400P1oFC801P20FS<0Pehd08=N=022GC<0PE`b081K<@80OeX`00@0OUT_07eG
<01nF340OeTb0P20FS<01P1oFC80OUPa07eG<01oFC80P5Xc085K=080PU`e00L0PE/d081J<`1oFC80
OEXd07aI<`1jEc40N5D_0080Me@^0`1hEBl00`1eE340M5<`07=B;`02079A;P0807=B;`1dDc00ME@a
07UH=@1gES<0M5<`079A;P1`Cb`206m>:`09071?;01cDS40LE0_06e<:`1[BRT0JTTX06]::@1]C2/0
KTd/0080JdPX00<0JTTX06M99`1VBBL00P1SBBH02@1RBRH0G4DV05e69`1OARP0HDHY06=5:@1SA2P0
I48W06=19P0206=5:@<0I4HZ00<0HdDY06539`1Q@bL00`1K@R@205a39@<0GD@V00<0Ed<Z05I2:@1D
@2L00`1B?RD205A09`03054o9`1@?RH0CS`T00<0CC/S1@1>?2@[ooooo`00:_ooool309Q]@0<0VFi1
0P2JKd8809U^@`<0V6`k0`2IKC`209Y^?@P0VW0n0`2JKSd209]_?P<0W70o00P0VV/o09a]@@2NKd<0
Wg140:1aA@2OL4@0WVm309e^@PP0WG50202OLd880:5eA0<0XWM4102QMT<20:1e@P0309ea@02NLT40
X7A300<0XWI500<0XGE40:1d@`2UMT801`2UMT800`2RNDD0XgY60:AkA`020:ElB0030:AkA`2SNTH0
XWU500<0YW]80`2UNTL20:AiAPP0XgY60P2VNdP01P2WO4T0Z7e:0:UnB`2ZOd`0Zh1=0:b1CP80Y7Y:
00@0YG]90:ElB02VODT0Ygi80P2WOTH20:QoB`040:MnBP2VODT0YGa80:AkA`80XgY60P2ONT<01`2N
ND@0WGQ409afA@2KMDH0VWA509YdA`2ILd@00P2HLT<00`2GLD80UW1109E_@00209A^?`04099W?@2A
IS`0TFHl095V?0<0T6Dk00/0Sf@j091W>`2>ICT0RF8g08EP=P23GCH0PEhh081N>020GST0OU/c07mL
=002081M=@0307mL=01mFS80NeP`00<0NEH^00<0N5D]07MD;01fDb/00P1eDRX0101dDBT0KdlX071@
:@1bDR/207=C;003079B:`1`D2T0KdlX0080K4hZ00<0JddY06Y<:01YBbL00P1XBRH00`1WBBD0JTTX
06Y9:00206]::@80K4/Z0P1]C2/0201aC2l0L4/^071<;01`C2X0LDdY07=@:P1eDR`0Me@/0`1lEbd5
07eH;P0407iI;`22GC00Peha08=N<@80Q5lb00<0QF0c08IQ=026HC@02028HSD808YU<@80T6Hf00<0
SV<f08eR=`2<HCL00P2;GcP01`2;GcX0SV8e08eR=@2=HSD0S6<e08YT=@28I3@00P26I3@208MQ<P80
R68c0P29Hc@308YT=@0608US=027HC80Qf4b08MQ<P28HS<0RV@e0`2;ICH208YT=@80RF<d0P28HS<2
08US=P80R68e0P27HC@208IP<`0308IO=P27H3L0RF8i0080RV<j00<0RF8i08MP=`26GcH00P28HSD2
08US=P80RV@g0P2;ICP808iS=P<0SFLh00<0S6Hg08]U=P2;ICH00P2:I3D02029HcH0S6Hi08mY?02>
J3/0RV@g08QR=@2;ICP0SfTl0P2=HSD208iS=P0308mT=`2@ICP0T6Dh00@0T6Dh00<0Sf@g08iS=P2>
HcH00P2=HSD308iX>@80SFLh0`2<ISL808]U=PT0RV@e00<0SfTj08eW>02;ICH00`29Hc@00`2:I3D0
RfDf08]V<P0708]V<PP0RV@e0`29Hc@308QR<`X0Qf4b00T0R6<_08UT<029I300RF@`08QS;`26HBd0
Q5l[089M:@21HC000`20H2l207mO;P80OUh]0P21HC82081P<@0707mO<01nGRl0OEd^07eM;P1mFb/0
O5XZ07]I:@0207YH:00907]I:@1lFRX0OE/[07aJ;01kFB/0NUPZ07UG:@1gEBL0MU@V0080M58T0P1d
ER@03`1eERL0M5DW07=D:01aDBP0KThW06e=9P1YB2D0JdXW06]=:@1/D2/0JDlZ06E=9`1PBR<0GTPQ
065::00206199`0305m89P1NAbD0GDHT0080G4DS0P1DA2X0101C@bT0DD4W05109P1>?R@204dm8`08
04/k8P1:>R40BCXS04Hj8P14>B<0@CTT040h9@0o>2D203Tf8`0403Pe8P0g=240=C8O03@a7P80<c0M
0`0d<al203<b7P<0<S4M0`0`;AX5034^6`04038_800a;Ql0<BhO034^7`80<2dN0`0_;1d5030]7P03
02l/7@0^:a`0;BXK00P0:R/M100W:Ah402PZ7`<09BLL00<09RPM02LY7P0W:Ah00P0X:Ql302LY7P<0
9RPM0P0U9a`802HX6P<09bTN0`0V:1d202DW700302HX7@0W:Ah0:2XO0080:B/P00<0:2XO02LY7P0V
:1d00P0U9aT202HX6P<09bTK00<0:2XL02T[7@0Y:ad01P0Y:ad302//7080;2dM0`0];Qh303@b7@D0
<c4L00`0=3<N03<b7@0c<A`0=C0L03L`7@0j<Ql0?3@Q040e8`1:AR/0AT8W040l8@0j=Q/203Pd6@03
03/g700l>1d0?3DK00<0?CHL0P0n=ad203lh7P<0>cLL0P0l>1d303di7P0803Xi7@0i>1`0>SHK03/e
6`0n=ad0@SPO04Di8@16>R8404<i80<0@SPO00<0@CLN04@j7`14>Ql00P13>Ah3048h7@03044g7013
>B00@cTP00L0@cTP00@0?cPL040i7@10>Ad0@3TM0P11>Qh2048k7`@0@cLO0P12=Qh2044e7@<0?SLM
0P0m=Q`303`e6`P0?CHL200k=a`:03`e6`@0?CHL0P0n=ad00`0l=1l0>c<N03Xb7@0203Xb7@0303`d
7`0n=R40@3PS00P0?SLM00<0@SPO044g7P0o=A`00P0m<aX00`0n=1/0?cDL040f7@0204<i8080@SPO
0P11=ah:040f7@@0@SHL0P13=ad204@h7P0604Pf7P17=ah0AcLN04Hh7P14>1h0@cTN0P11>Qh204@j
7`<0@cTN0`12>1d00`17?B80AS`Q04@j7`0204<i7P0304@j7`16?240AcdR00P0A3PN00H0?cPK040i
7011>Qd0@S/N04<l7`14?B0204Dn8@0604Pm7@19?Qh0BChN04/n7P1<?Ah0CC`N0P1@?Al00`1A?1l0
D3hJ05A27P0205M58@80E48N01H0F4HR05]99@1QAAd0HTHN06=77`1UBB40Id/S06U=9@1[CbL0K50X
06M@9P1YD2L0JU8V06eB9@1`E2D0Le@U07EE901fERD0MEHW07IG:01iFR/0NU//0P1kG2d207YK;080
Q60`00<0QF4a08IR<P27Hc<00P28I3@00`29ICD0RfLc08YV<P0208UU<@0508YV<P2<J3@0SVXf091/
>02@JS/00P2AJc`00`2BK3d0Tfdn09=]?P0209A^?`80UW4m0P2GLSh309Qc?`0909Ud@02ILdH0VG=4
09YdA@2KMD@0W7M309eh@`2MN440WWU20080XGa80P2RODT20:=nBP80Y7m;0P2ROdL00`2SP4X0Xgm;
0:B0CP020:B0D0040:F0D`2WPe<0Yh=C0:N3D`80Z8AD0`2YQED40:^7D`80[8QD0P2]RED80:f9F@<0
ZhMC0P2/R5@30:f9E@<0[8QD0P2]RED30:j:EPP0[XUL0`2]QeP30:j8F@80[hUJ0P2^RED30:f8E0@0
[8MC202/QUL80:f7F0P0[XQI00P0/8YK0:n9FP2]QeP0ZhEF0:Z4E@2[QEH0[8IG0:f7F0P0[8QH0P2/
Qe<20:^6DP040:Z5D@2YQ500ZHA@0:V4D080[HMH0P2^R5T20:n9FP80/8YK0`2_REX00`2^R5T0[HMH
0:b6E`020:b6E`060:n9FP2^R5T0[XQI0:f7F02/QUL0ZhEF0P2ZQ5D80:^6DP80[HQL0P2/Qe/20:^6
FP80ZXEI202ZQE480:V4D0P0ZXEA00D0Yh9>0:R3C`2XPdl0ZHA@0:^6DP020:b7D`030:f8E02ZQE40
ZXEA00H0ZXEA402YQ5020:Z5D@@0ZhIB0`2/Qe<@0:V4D0050:R3C`2YQ500ZHA@0:Z5D@2/Qe<00P2]
R5@0102^RED0[HMH0:b6E`2ZQ5D20:R2D`030:V3E02ZQ5D0ZhEF00H0ZHA@0P2XPdl80:f3D@80Z89C
0`2YPe@30:Z4E@P0ZhEF202]QeP01P2^RED0[HQD0:f8E02/Qe<0ZhIB0:Z5D@80ZHA@2@2ZQE403`2Y
Q500Z8=?0:R3C`2XPdl0ZXEA0:b7D`2^RED0ZXAE0:^5EP2]QeP0[XQI0:n9FP2^R5T0[HMH0:b6E`02
0:Z6EP80ZhMG0P2/R5P20:f9F@80ZhI?00<0ZhIA0:^6DP2[QE@00P2[QEH00`2[QEP0ZXIF0:Z6EP02
0:^7E`80[8QH0P2]RET80:f8E080ZXIF0P2[QeL20:b8F080[HUI2@2/R5P01P2YQ500ZhIB0:f8E02^
RED0[hYF0:j9E@80[HQD202^R5T80:f7F0P0ZXAE202YQ50@0:Z5D@P0Yh5B202VPDX00`2SOTL0Y7m8
0:J1BP020:N2B`060:J1BP2TOdP0Xgi70:5lB02RODT0Xgi:0P2UP4`0102SOTX0XWe90:5lB02SOTX2
0:9mB@030:5lB02PNdL0WgY60080WWU50`2ONTH309iiA@80WGQ40P2NMCl00`2OMT80WgE30:1fAP02
0:5fB@050:5fB`2MMdP0VgE609UcA02GLD800`2FL4402P2GLD80V7<o09Qc?`2IM400VWE109Ud@02H
Lcl0UW4m09A_>`2FLCd209Mb?P0309Qc?`2IM400VWE10080VgI2202DKSl909A_>`80TF`h0`2@JcL3
08mZ=PP0SfTj00P0T68a095S<P2AIC@0TVPf095Y=P2>JCD0SFPd08]W<`<0Rf@i1@2<ICX00`2<ISL0
RfDf08YT=@0208US=00308YT=@2;ICH0S6Hg00P0S6Dj0P2;ICH208YT=@0708US=028HS<0R68c08QR
<`22H300Pf4a08ES<`0308IT=00308AR<P23HC40Q68e0080Q68e0P25HcH308IT=`<0Qf@j0P26HcT3
08ER>00608IN>`25GCT0QEdi08EN=`24GC@0Q5db0P23GC003P20FCP0PE/g085K=P22G3D0Pehb08=N
<@24H300Q60^089O=@21GS@0P5dc07mL<P1nFc40OEX`0P1lFBl2081K<@80PE`b00`0PUdc08=N=024
GcD0Q5le085K=P1oFC@0OELb07aF<@1kEC00O5Ha07eG<P1nF3<2085L<P04081K<@1oFS00OUT_07eH
;P80O5L]00<0NU@_07aF<@1mEc800P1nF3<01@1mEc80O5Ha07YD;`1lES40OELb0080OUPc00T0OELb
07]E<01iDbh0N58]07ME<01eDbh0Le4/075?:P1`CRT00`1aCbX00`1bD2/0KD`Y06i=:P0406m>:`06
06i=:P1]C2T0LE0]071?;01^CBX0K4/X0`1[BRL0101/BbP0Kdh_06e<;@1YB2T206M69`0406U8:@1/
Bb`0KTd^06Q59`80IdHW00<0I4DV06=69P1PARD00P1OAbD0401E@2<0F40T05Y29P1L@RL0GD8W05i0
9P1N?RD0GCdT05Pm801I?R40Fd0S05e29@1N@bH0GD8U05a1901K@2<305M08@D0F44R00<0E40W05<o
9P1A?B@00`1@?2<01@1B?RD0DclV04hn9`1=?BH0Bc/T00<0BCTR00<0BSXS04/k9019>B800P19>B8[
ooooo`00:_ooool309Q]@080VFi10`2JKd8809Q]@P<0V6`k0`2IKC`209Y^?@P0VW0n0P2JKSd309]_
?P<0W70o00P0VV/o09]/@02NKd<0Wg140:1aA@2OL4@0WFi209a]@@P0W70o202OLd880:9fA@040:Ai
AP2SN4D0XgQ50:9gA080XGI30P2PMD80102OM440WG5009ib@@2PM4<30:9fA@030:5eA02PM4<0YGI2
00L0YGI200<0X7M30:9iA@2SNTH00P2UO4P00`2SNTH0XWU50:1g@`030:IkB0<0YGY70P2TNDH80:=j
AP80YW]800@0Yga90:QmBP2ZOd`0Zh1=0P2/PDh20:AjBP040:AjB02UO4P0YWe90:MnB080Ygi60100
ZH1<0:QoB`2WOTX0YWe90:ElB02TNdL0XgY60:9iA@2ONT<0WWU209iiA02MN4@0W7I509]eAP2JM4D0
VWA70P2HLT<209Ma@P0409I`@@2EKd00U6ho09A^?`D0T6Dk0`2AIS`01P2@Ic/0SV@j08UR=`25H3H0
Pedf085N>080P5hi00<0OU/c07mL=020GCD00P20GCD0101mFS80NeP`07UF;P1iERh207QE;@0307MD
;01fDb/0ME8Z0080M54Y00<0K4lW06iA:@1_DRX00P1aE2`00`1_DRX0KU4Y06a?9`0206a>:P0406]=
:@1ZC2P0JD/W06Q:9P80IdTU0P1ZBBP206]::@80K4/Z0P1]C2/0201bCC00LD`_075=;@1`C2X0LDdY
07=@:P1eDR`0MU<[1`1mF2h207iI;`06089M<023GS40Q5lb08EP<`26HC@0Qf8e0P28HcH308US=P<0
R68e0P27HC@808YU<080SfDe00L0Sf@g08iS>02<HCL0RUhg08QL=@27FcH0SV8e0080SF8e00<0S6<e
08US=028I3@00P26I3@01026H340Qf4b08MQ<P28HS<208US=0<0RV@e00L0RF<d08QR<`27HC80QV0a
08MQ<P29Hc@0RV@e0080RfDf0P2:I3D208US=080R68c00@0R68e08MQ=027HC@0Qf4d0P26H3<208EO
<P0308IO>027H3T0RF8k0080RV<l00<0RF8k08MP>@26GcP00`28HSD00`29HcH0RV@g08]U>00208]U
>0P0SV<f0P2>J3T0102=IcP0S6Hg08aV=`2;ICH208YT=@0808US=P2=IcX0T6Xm08iX>`2:I3L0R68e
08]U>02?JC`208eR=@0408iS=P2?I3L0Sf@g091U>0@0TFHi00@0T6Dh08mT=`2?I3L0SV<f0P2=HSD2
08mY>P80SVPi00<0SFLh08aV=`2;ICH00P2;ICH608YT=@0308]U=P2:I3D0RV@e00L0RV@e00P0SfTj
08eW>02;ICH0RF<d08QR<`29Hc@0RV@e08]U=PP0RfHa202:I3D308US=0<0R68c2P27HC802028Hbl0
RF@`08YU<@29I300R6<_08IQ;@24Gb/0PUdY1020H2l207mO;P80OUh]0P22HS<02@21HC80P60a07mO
<01mGBh0O5`]07]K;01nG2`0O5XZ07YH:00207UG9`0;07YH:01lFRX0OU`/07aJ;01kFB/0NUPZ07QF
:01gEBL0ME<U07AB901cDB<00P1dER@03`1eERL0M5DW07=D:01`D2L0KThW06a<9@1ZBBH0K4/X06a>
:P1/D2/0JDlZ06A<9P1OBB80G4HO065::00206199`0305m89P1NAbD0GDHT0080G4DS01H0Dd<Z0592
:@1A@BP0D40W04hn9@1=?B@0C3`S04/k8P1:>R40BC/Q04Pi8P16>R@0A3TU044i9P0o>2D0?cPV03Xg
900i=R<0>3DR03Hc800d<Ah0<c0M0P0a;Q/203Dd8080=3<O0`0c<Qh00`0b<Ad0<2dJ030]6P03030]
6P<0<BhK100a;Ql2030]7P<0;b`M0P0a;Ql00`0_;1d0;R/L02h[700202h[700302l/7@0Z:ad0:R/M
00H0:R/M1@0W:Ah302PZ7`8092HK00@09BLL02HX7@0V:1d09bTN0P0X:Ql302LY7P809RPM0`0U9a`8
02HX6P<09bTN0P0V:1d302DW700302DV7P0W:200:2TQ0080:BXR00<0:2TQ02LX800U9Qh00`0U9aT2
02HX6P<09bTK200Y:ad302//7080;2dM0`0];Qh403Dc7P@0=38M0P0e=1l03P0e<ah0=c8N03Tb7`0l
=240?SHS044f901ACC00BdLZ04<o8P0l>1/0>3@G03Te600m>A`0?c/N0`0n=ad303lh7P80@3TO0P0k
=a`303`h7@<0?CTN00P0>cXN03Xi7@0k=a`0?CLM03lh7P13>B00ASXR04Pl9080AC/R00<0A3XQ04<i
8012>1l00P11=ah00`10=Qd0A3XO04@j7`0204<i7P@0@SPM2@13>B04040i7@80@CXN0P12>al01014
>200@cLO04<g7`13=al2048f7P80@CDM0`0n=ad203df70<0?3DK200m=Q`803/g70P0?3DK200m=Q`0
200l=1l0>c<N03Xb7@0i<A`0>S8M03`d7`0n=R40@3PS200n=ad02014>R40@SPO03le700m<aX0?38I
03dc6P0n=1/0?cDL0`13>B000`12>1l0@CLN040f7@0:040f7@04044e6`12=Q`0@SHL048f7080@cLM
0P14>1h01P18=Qh0AcLN04Lg7P16>1h0A3PN04<i7P80@CXN0P14>Ql304<i7P<0@SPM00<0AcdR04Hl
8@14>Ql00P13>Ah00`14>Ql0AS`Q04Lm8P0504@h7P<0@cLM0P0o>1/01010>A`0@CXM04<l7`14?B02
04Dn8@<0B3dM0P1;?Qh01P1<?Ah0CC`N04ll7P1??1h0CS`H05907080ET@P0P1D@Qh0401HAR80G4XV
06557@1QAAd0HdLO06E98@1WBb<0JDdU06]?9`1/D2P0J54W06U@9`1ZDRH0KE8U06mC901bDb@207AD
8`0407=D9@1eERL0MePY07UJ:`80NU//00H0NEX[07QI:P24H300Q60`08EQ<@26HS8208MS<`80R6@d
00P0RfLc08YV<P29IC40R6@`08UU<@2<J3@0SVXf091/>0<0TV`m0`2CKCh209A^?`80UW4m0P2GLSh4
09Qc?`0609UcAP2ILd@0VWA509]eA02LMd<0W7M20P2MN4420:5lB080XWe90P2SOTX20:AoB`80XGi6
00<0XWm90:9nBP2ROT`00P2SOdl0102SOU40Yh=C0:N3D`2WPe<30:R4E080ZHEE00@0ZXIB0:^7D`2[
Qe<0ZhMC0P2/R5@20:f9E@030:b8F02]RET0[HUI00@0[HUI00<0[8QH0:Z6DP2[Qe<00P2[Qe<20:b8
E080[HUE0`2/R5@30:f9E@80[XYF202^RE`30:f7F0<0[XQI0P2_REX20:j9E@<0[HQD0`2/Qe<00`2[
QU80ZhEF0:^5EP060:^5EPP0[HMH202^R5T0102aRe`0[hUJ0:f7F02[QEH20:Z4E@030:b6E`2]QeP0
[8QH00L0[8QH0P2/Qe<0102[QU80ZXEA0:Z5D@2YQ5020:R3C`<0[XQI00<0[hUJ0;2:F`2aRe`00P2a
Re`00`2_REX0[XQI0:j8F@020:j8F@<0[HMH00P0/H]L0;2:F`2_REX0[HMH0:b6E`2ZQ5D0ZH=D0:R2
D`P0ZhIB0`2]R5`00`2/Qe/0ZhIJ0:Z5F@020:Z5F@<0ZhIA0P2ZQE030:V4C`P0ZHA@202[QU820:N2
CP040:R3C`2YQ500ZhIB0:b7D`80[HQD202[QU8@0:V4D080ZXEA102[QU830:b7Da00ZHA@00H0Z8=?
0:V4D02YQ500ZhIB0:b7D`2]R5@20:j9E@030:f7F02/QUL0ZXAE00<0Z89C00<0ZXAE0:^5EP2YQ500
102YQ5030:R3C`80[89@102]Pe420:j4DP80Yh5B0`2XPU<30:V3E0P0ZhEF202]QeP01P2^RED0[HQD
0:f8E02/Qe<0ZhIB0:Z5D@80ZHA@2@2ZQE402`2YQ500Z8=?0:N2CP2XPdl0ZXEA0:f8E02^RED0Z89C
0:V3E02[QEH0[HMH0080[XQI00@0[HMH0:b6E`2ZQUH0ZXIF0P2[QeL20:b8F080[HUI0P2[QTl00`2[
QU40ZhIB0:^5E0020:^5EP030:^5F02ZQUH0ZXIF0080ZhMG0P2/R5P20:f9F@P0[HQD0P2ZQUH20:^7
E`80[8QH0P2]RET90:b8F0060:V4D02ZQE40[8MC0:j9E@2_RUH0[XUE0P2]R5@80:j8F@P0[8IG202X
PU<80:V4D0P0ZXEA202XPdl80:J0D@P0YH1900<0XWe60:=nA`2TOdP00P2UP4T01P2TOdP0Xgi70:9m
AP2ONTH0X7]70:9mB@80Xgi:00@0XWe90:1kA`2ONTH0XGa80P2PNdL00`2ONTH0WWU509ehA00209ag
@`80WWU500@0WGQ409ag@`2KMT80VgI20P2JMD4209ac?@0309ed@02MLd40WWA40080WgA700D0X7E:
09]eAP2ILd@0Ug5209A^?`0209=]?P0409A^?`2EKd00UW4m09Mb?P<0V7<o00/0UW4m09A_>`2CKSX0
Tfhj09A_>`2EL3`0Ug8n09Qc?`2JMD40VgI209ag@`0809=]@0T0Tfhj0`2>JCD208eX=0<0S6Lc202>
J3T0202>H2l0Sf4`08mS<P2@IS@0T6Pe08eX=02;IS80RFDa202:HcP00`2:I3D0RF<d08MQ<P0208IP
<@0308MQ<P29Hc@0RV@e00P0S6Dj00@0Qf4b08IP<@26H340QEl`0P24GRl208=M;P03085O;`22H300
Pf4a0080QF<c00<0Q68b08=Q<@22H3000P1oGC02081N<@<0PElb00<0PV0c08=P>023H3P00P22GcL3
085N=P06081M=@21FCH0PETf081H=020FC80OeP_0P1oF2d02@1nF2/0PEXk085J>@21FcL0PU`e089M
<`22GC00Pel_08=O;@0207mL=00307iK<`1mFS80O5Ta0080NUL_00L0NEH^07mI<P20FS<0P5Xc085K
=022G3D0Pedf0080Q5hg00<0P5Xe07iH<`1lES400P1jE2l03P1kEC00O5Ha07eG<P21Fc@0P5Xc07mI
<P1nF340OEL`07aF;`1kEBh0NU@]07UC;P1jE2l0O5Ha0P1mEc800`1lES40NU@_07UC;P0207UC;P80
NU@_00P0N58]07I@:`1cCBP0LT`W079@:`1aCbX0KddX06e;9P80K4XU0`1]BbH00`1TAR@0ITPV06Q:
:00206Y<:P0606Q::01VB2H0I4HT06U;:@1XBRP0ITPV0`1TAR@206I89P0306Y;;01XBBX0IDHW0080
Hd@U01L0ITLX06Y;;01/CBh0ITDV06E49@1SA2D0HTDU05m5901NAR@0GDDS05a58`1C?R<0E3lT05Q0
9P1J@2L0FclW05`n9P1K?BD0Fc/T050f6`1B>1d0EC/P05Lm8P0205Pn8`0405Lm8P1F?240ECdQ05Dm
8@H0EShR00`0DClW04lm9@1>?2@0CC/S04`j8P1=>b<0CcdU050n9P1>?RL0C3`U04Xj8`18>24204Lg
800304Ti8P1:>R<0AcLP0080AcLP:oooool002[ooooo202IKD0809Y`?P<0VFdl0P2JKSd309]_?P03
09E[>@2GKC/0VFlm0080Vg4o00<0VFlm09M]>`2EJcT00P2GKC/01P2HKS`0VW0n09]a?`2LLT00WG=1
09id@P<0WVhm00<0Wfln0:1`?`2QLD000P2QLD000`2LL3l0WG5009ib@@020:1d@`0309ib@@2MLD00
W70o00P0Wg=20P2QMSl0102QMT40XGI30:5f@`2QMD@20:5eAP030:9fA@2QMD@0X7A300<0WW9100<0
X7A30:5eA02RMTD0202RMTL80:AhA`040:Ej@`2TND80Y7U20:Ai@P80XgQ10P2RMd020:MkC080YWY;
00@0YGU:0:AhB@2TN4T0XgM8202TNdL0102WOTX0Z7m;0:QoB`2XOd/20:V0C080ZX5=0P2[P4d20:Yo
C080ZGi;0P2XODX20:MmB`80YWa:0P2UNdT20:AjB00@0:1kAP2ONTD0WWU409ag@P2JMD00V7<n09Mb
?@2FLC`0Vg1309Y_@P2IKT40Uf`o09I[?P2DJC`0TfPk099W>P80TVTm00P0SfTl08eX>`2<IcX0RFLi
08QX>@27IcP0QF8h08IS>@80Qf@j00@0QF8h08=P=P20GC<0OU/a201kFc@807MB:0<0LDd[00<0LTh/
07=?;@1dD2h00P1dD2h0201`Cb`0Kdh[06i=:P1]C2T0K4/X06]:9`1ZBBH0JDPU0`1YCBP506Y>:@06
075>:01bCbT0LTlW07=@9P1dDRD0ME<U0P1fE2@207iI;080OEP[00`0OUT/085L;`21G2l0Q5lb08IQ
=021Fb`0PU`]08=M;P24GRl0QEl`08IP<@27HC8208QR<`<0RF<d0P2:I3D208]U=P08099V>@2@ICP0
SV<f08aS=@2:I3D0RVHf08YX>02;JCT808]U=P<0RF<d0`28HS<208MQ<PP0RfDh0`29HcH308QR=@80
Qf4d00<0R68c08US=02:I3D00P2:I3D00`28HS<0QV0a08EO<00208MQ<P<0R68c0`29Hc@02029Hc80
Qf4`08IP<@25Gc80QEhc08IO=P29HST0RV<l0`2;ICH00`2:I3D0RF<d08QR<`0208QR<`0808iS>02=
HSD0S64d08aR<P2<HS00SVDa091W<@2AJ382095V>@04091U>02?I3L0Sf@g08iS=P80SF8e00@0U6Tl
09=X>`2AIST0Sf@g0P2>HcH02P2?I3L0T6Dh091Z>`2@JS/0SfTj08iX>@2=IcP0S6Hg08]U=P2:I3D2
08iX>@0408eW>02<ISL0S6Hg08]U=P80RV@e202;IS801P2>JCD0SFPd08eX=02;IS80RVDa08UT<080
R6<_00<0SfTl08iX>`2<IST00`2:I3L208aV>@0308eW>P2;ICH0RfDf00H0RfDf0P2;I3T00`2;ICP0
RfDf08]U=00208]V<P0308]V<@29I2l0RF@_0080RF@_102:IC001026H340Qf4b08MQ<P28HS<208US
=080RV@e0P29Hc@01028HS<0Qf4b08MQ<P26H34208EO<0P0QF4a00@0PUhZ08=O:`23Gb/0Q60/0P25
HBd208IR;P0608AR<P23HC40PV0`085O;`20GRh0OU`/0P1mFb/0101kFB/0NUPZ07YH:P1jF2X207UG
:@80N5HX00P0NEH^07YG;`1lFC40OEXb07aI<@1iERh0MU<[07AA:@P0KE0T01P0Kd`/06i;:`1]C2/0
JT`Z06Q;:@1UBbP0I4XW06=;9`1LC2X0Fd/Y05U9:01HAbT0ETDY05A3:@1C@RP0DT0X04i17`1>@B40
Bd0P04Po8015?R40@chQ048l8P10?24204<h8P03048g8@11=R00@3DO0080?S<M00<0?C8L03@a7P0e
<Ql00`0e<Ql303Hc80<0<BlJ0`0`;QT202l]600403D`700d;a/0=2lK03@_6`80<bhJ0P0b;AT902/]
7`P09bTK200X:Ql0200Y:b00:2XO02HX7@0T9Q/08bDJ02@V6`0V:1d09bTN200U9Qh802@W70T09RTN
0P0U:1d00`0T9a`08bHK02<V6`02028U6PP09bTN0`0X:Q`202T[7@<0:R`N0`0Z:a/302//7080;2dM
00H0<B/K038/700b;AX0<bhJ03@_6`0e<1X203Hb6@<0<S4M0P0c<Qh303@c7`0403/a600l<QT0?38I
03`b6@80?C<J0P0n=1/01`17?B80AC/P048h7@0o=AX0?S@I03le6P11=a`00`12>1d2044g7004040f
6`0o=AX0?cDJ03hd6@80?c@N0P10=Al4044f80<0>cLJ0`0l>1/203di700403`e600n=aX0@3TL04<l
7`<0AChQ00L0A3dP04Pm8@17?200AS/O04Dj7P13>1`0@CHJ0080@3DI0P10=Q/3044g7080@SPM0P13
>Ah304Dj7P80A3TM0`13>1`00`13?b80@CdP03lk7P0203di700303hj7@0o>ah0@3`O00D0?SLK0`0o
>1`02018>240ASLP04<g7`0o>1h0?CLM03Pg6`0f=QX0=3LJ200m=QX00`0k=1X0?3DK03hg7@0203lh
7P0303hg7@0l=A/0>c@J0080?c<K00@0?S@K03`e6`0k=A/0>SHK0P0h=a/803hg7@04044j8010>Al0
@3TO040i7`80?cPN0P0n=ad803lh7P0604<i8012>1l0@SPO044g7P10=Qd0?cDL0P0n=1/@048h7`03
04Hl8@15>b00@cTN0080@SPM00<0@cTN04Dk8016?2400P15>Qh304Hk7`<0Ac`P00@0BSlS04Pm8@15
>Qh0@cPL0P12=a/00`13>1`0A3TM044f6P02044f6P03048g6`13>1`0A3TM0080A3TM2013>Ah02@17
?200B3XO04Pj7`18>Ql0BSXP04`k8@1A?B@0EClW05I0:00205=38P<0DT8Q0`1A@B00401KC2D0GD/U
05i<901OC280HTdR06A=8@1UCB40IThP06iA;`1]DB`0K50[06a@:@1]DBT0KU<X071E:01aERT207AG
:`80MEP/00T0MUT]07MJ;P1hFbl0N5/_07eO;@1nH2h0Of4_081R<021Hc400P23IC<00`24IS@0RVPh
08UW=`0408UW=`80R6Hf0P2AKCT2099^>P<0Tflk00<0U70l09=_>`2CKc/00P2DL3`0102ELCd0UW8n
09Mc?`2GLcl209Qe?`80VGI000`0VWM109]h@P2LND<0W7U309ai@@2MNT80WW]509mkA`2QOD/0Xgm?
0:B0D02UP5<30:=oB`80Y81<0`2UPDd0202UP5@0YX5E0:J1E02WPe<0Z8AB0:V5D@2ZQU80ZXMA0P2Z
QU820:^7D`80[8QD0P2]RED30:n:GP80[XUM0`2]R5`01P2]RET0[8QH0:b8F02[QeL0ZXIF0:V5E@80
Z8AD0P2[QU820:b7D`80[HQD0P2^RED80:j:FPP0ZhMG0P2]RET30:b8F080ZhMG0P2ZQUH00`2_Re/0
[XYJ0:b8F0020:Z6EP030:b8F02^RUX0[h]K0080ZXAE0`2[QEH30:b6E`030:b7FP2]R5/0[hYM0080
/8]N00<0[hYM0:f8F`2/QeX00`2/QUL30:^5EP80ZXAE202[QEH30:R3C`D0ZHA@00P0ZHA?0:^6DP2]
R5@0[XQG0:n9FP2^R5/0[HIK0:b5FP<0[h]G0P2^RUH30:f9E@030:f7F02/QUL0ZXAE0080ZH=D00H0
ZXAE0:b6E`2]QeP0ZhEF0:b6E`2]QeP20:j8F@060:f7F02/QUL0ZhEF0:V3E02ZQ5D0[8IG0P2]QeP0
0`2/QUL0ZXAE0:V3E0080:^6DP<0Z89C0`2YPe@20:Z4E@P0ZXEA0`2[QU420:Z5D0<0ZHA?0P2/Qe<0
102[QU80ZXEA0:Z5D@2YQ5020:R3C`P0ZhIB202YPe@90:Z4E@P0ZXEA0P2YPe@0102ZQ5D0ZhEF0:b6
E`2/QUL20:f7F0P0ZXAE00P0Yh5D0:V3E02/QUL0[XQG0:j9E@2[QU40Yh9;0:F0B@P0ZhIB0P2WPTh2
0:R3C`040:V4D02ZQE40ZXEA0:^6DPP0ZXAE01<0Z8=?0:V4D02[QU80[HQD0:j9E@2]R5@0ZhIB0:Z5
D@2/QUD0[HMF0:j8F@2_RE`0[hQM0:j7GP2]QUd0[8EN0:^5EP2/QUL0[HMH0080[XQI00@0[HMH0:b6
E`2[QEH0ZH=D0`2ZQ5D20:^5EP80[8IG00@0ZhEF0:Z4E@2ZQ5D0ZXAE0P2YPe@20:R2D`P0ZXAG202^
R5T20:b6E`80ZhEF0`2ZQ5D00`2YPe@0ZhIB0:^6DP060:^6DP@0ZhEH102ZQ5L80:b7D`80Yh5B00L0
Z89C0:Z4E@2[QEH0ZhEF0:b6E`2]QeP0[XQI00P0ZX=H0`2ZQE420:V4D0<0Z8=?0P2[QEH20:Z4E@<0
ZH=D00<0Z89C0:R3C02XPd`01P2XPd`80:J0D@050:^6C`2ZQDh0ZXE>0:V4C@2XPd`00P2WPT/01@2V
PDX0ZXE@0:R3CP2VPD`0Xgi90080XWe80P2SOTT0102UOe00Y7i?0:AnC`2TOTl20:=mCP80XWa=0P2S
OD`20:9lB`040:5kBP2PNTT0WgU809miB0P0WGQ300P0WWQ909miBP2PNT/0XG]<0:1jB`2ONDX0WGM8
09afA`80VG=20P2JM4<03`2KMD@0W7I509afA@2MMdH0X7Q709mgAP2MMD@0Vg=209Ua@02GKch0UVhm
09E]?02@JST0TF/j09=]?00209E_?P0309A^?@2BK3/0TF/j0080Ufln00@0UVhm09A/>`2CJcX0TVXi
0P2AJCP808mY>00408aX=P2=JCL0Sf/i095]>`80TVhl00/0TFdk091/>P2:ISH0RfLg08aX>02=JCT0
S6Ph08YV=P27Hc<0QF4a08aV>@0308]U>0<0RV@g0P29HcH208mV>P80SVDi00X0SF@h08aS=`2<HcL0
Rf8f08mT>@2>HcP0SF@h08aS=`29HcH0Qf8e0P24HS@01027HC80R68c08QR<`29Hc@208YT=@80RfDf
1028Gc4208UP<P80RV4c00T0SF8g08iS>02>ICT0SVDi08]U>027HSD0PV0b085O<@22GcL01023H3P3
08AQ>@80PUda00@0PE``081K;`20Fbl0OeX^0P1nFBd2085L<P80PUdc00@0Pehd08AO=@24GcD0QF0f
0P20FBh3085J;`<0PU/`00h0PeT_081F;01mDbT0OeD[089H;P24FS00PEL]07iD:P1lFS@0NeTc07YH
<P1hES00MU@^07EC;@80Le4[00P0PED^081D;@1mDb/0NE8Y07MB:01fDbT0N5D[07QG;0P0N5H`0`1h
EB/207MD:P<0MU<Y0P1eDBd207A@;00407=?:`1bCRX0LThZ075=:@<0N5HY00<0MeDX07ID9`1eDbH0
0P1eDbH05P1gER/0MUDZ07ED:@1dDbP0Le8W079A9P1aD2D0L4lT07=@9P1dDBL0ME8X07AA9`1cD2H0
LDhT06m<8P1]BR00JTLY06]8:P1/BB/0KDX/06a9:`1[B2X206U6:00406Q59`1TAbL0I4LW06A79`80
HdHV0`1RABD00`1M?Ql0GSlP06118P0206528`0906118P1N?b00GChO05i7:01MARL0G4DV05]49@1I
@R<0F44R0080Ed0Q0P1K@2D00`1K?bL0FclY05/o:P0205/n;00305/n;P1A?B@0DCdT00H0DCdT00T0
BcXP04hm8`1C?bH0Ed4Y05U1:@1F?RH0E3XS058f801@>bH00`1?>RD204hi9080CCPS2012=R002012
=Qh0@3HM03ld7P0k<ah0>S<P03/f8`0j=b@0>cPW0`0o=RL[ooooo`00:_ooool809U]@0P0VW0n0`2I
KC`209Y^?@<0Vfln00<0Ufdk09Q^?02IKcd00`2IKcd01P2HKS`0Ufdk09Q^?02HKS`0VFlm09Y`?P80
Vg4o0P2LLT0209i^?@80Wfln0P2PL3l20:5a@00309a`?`2MLD00WW910080X7A300<0WW9109ea@02L
L3l0202OLd820:5f?`040:5f@@2QMT<0XGI30:5eA080XGE600<0XWI50:5eA02PM4<00`2OLd800`2P
M4<0XGE40:9fA@080:5eAPP0Y7Q70P2VNd@20:Ej@`80Y7U20P2SN4420:MkC080YWY;00@0YGU:0:Ah
B@2TN4T0Y7Q9202TNdL20:ImB@80Ygi:0P2XOd/20:V0C0@0ZGi;0P2XODX20:MlB@<0YWa:1@2UNdT0
202PNdH0WgY509iiA02LMd80VWE009Qc?P2GLSd0UW4l0P2JKd801P2IKT40Uf`o09EZ?@2DJC`0TfPk
099W>P80TFPl00@0SVPk08aW>P2;IST0R6Hh0P26ISL02025HSP0QV<i08IS>@26HcT0QF8h089O=@20
GC<0OU/a0`1kFc@01@1jFS<0NETb07UI<P1iFC80N5Pa00P0ME8X0`1aCB/00`1bCR`0Ldl]07=?;@02
07A@;P0607=B;`1bDBh0LE0]071?;01_CR/0KTdZ0P1]C2T206U=:0@0JThY0P1[CbX2079?:@0607=@
:01dDBL0ME<V07ID9P1fE2@0MeDU0P1nFB`207eH:`0607mJ;@21G2l0PE`_08AO<P26HC@0PU`]0P23
GBh01@24GRl0QV0a08MQ<P27HC80R68c00@0RF<d0P2:I3D208]U=P08099V>@2@ICP0SV<f08aS=@2:
I3D0RVHf08YX>02;JCT808]U=P<0RF<d0`28HS<208MQ<PP0RfDh0`29HcH308QR=@80Qf4d00<0R68c
08US=02:I3D00P2:I3D00`28HS<0QV0a08EO<00308MQ<P80R68c0`29Hc@02029Hc80R68a08IP<@25
Gc80QEhc08MP=`28HCP0RV<l0P2;ICH208YT=@80RF<d0P28HS<02@2?I3T0SV<f08eR=@2<HS80S68`
08iU<@2@Ic40TFPb095V>@02091U>080Sf@g0P2>HcH01`2=HSD0U6Tl099W>P2@ICP0Sf@g08iS=P2?
I3L00P2@ICP2091Z>`0408mY>P2>J3T0SFLh08aV=`80RfDf0P2>J3T208eW>00408aV=`2;ICH0RfDf
08]U=PP0RfHb00H0SVTe08eX=02<Ic<0RfHb08YU<@29I30208QS;`0308mY?02>J3/0S6Hi0080RV@g
00@0RfDh08aV>@2<IST0SFLj202;ICH208aU>P0308aV>@2<ISL0S6He0080S6Lc00<0S6Lb08UT<029
I3000P29I30408YU<@<0Qf4b00<0R68c08US=029Hc@00P2:I3D00`29Hc@0R68c08QR<`0208MQ<P80
QV0a00<0QEl`08IR<P26HS801P26HS8208=O:`80Q60/00@0QF4]08IR;P26HRh0QV8^0P22H3001021
Gbl0P5h^081N;P1oGBd207iL;080O5X/0P1kFB/207YH:P80NELY0P1iERh207YG;`0407UF;P1gE2`0
ME8Z07AA:@<0KU4U0P1]D2@206a?8`0I06]>8P1^Bb/0KD`[06a;:P1YBbT0IdXX06A:9`1SBbL0HTXV
05];:@1JBRP0FDTX05M6:01EA2P0Dd8X05919`1A?bL0CT4Q04e0801:?b40B3lR04@m8@12?280@C/Q
03lk8P02040h8@0403lg800n=Ql0?CDN03`d7@80>c<L0P0d<Ah603Db7`<0<BhK0P0`;AX302l/6@<0
<RlL0P0a;Q/3030]6PT0:bdO200W:A/802PZ7`0302T[800X:Ql09RPM00<092HK0P0V:1d802DV7PP0
92LL200U:1d00`0V:Ah09BPM02DX7@0202@W70808bHK00<08RDJ02LY7P0W:Ah01P0W:Ah202LY6`<0
:2XL0`0Y:ad302X[6`80:b`L0`0/;Ad2038/700403<^6`0c;QX0=2lK03D`6P80=S8I0P0b<Ad203<b
7P<0=3<O00@0=C@P03`b6@0l<QT0?38I0P0m<aX303hd6`0404Dk8014>Ql0@SPM044g70<0@3HK00D0
@CLL048h7@12>1d0@SPM044g7002040f6`80?cDJ1P11=R02040e7`<0?CPK0P0n>A`303lj7@0503hg
6P0o>1/0@S/N04@m8015?R400P14?B001@13?1l0Ac`P04Hk7`15>Qh0A3TM0080@cPL00<0@SLK044f
6P11=a`00`11=a`2048h7@<0@cTN0`15>Qh204@i7@<0@cPL00P0@chQ044l7`0o>Qd0?STL03dh6`0n
>A`0?cXM040k7P@0?SLK100o>1`204Df7`04048f7P0o>1h0?CLM03Th7080=cLK200m=QX00`0k=1X0
?3DK03hg7@0203lh7P0303hg7@0l=A/0>c@J0080?c<K00@0?S@K03`e6`0k=A/0>SHK0P0h=a/803hg
7@@0@3TO0P0o>1h203hg7@P0?cPN0`11=ah3040f7@80?cDL4012>1l00`16?240AC/P04<i7P02048h
7@0304<i7P15>b00AS`Q00<0ACXN0P16>al304Ll800404Xo8`19?R80AS/O04@i7@80@cPL00@0A3TM
04Dj7P11=QX0@CHJ0P12=a/01013>1`0A3TM04@i7@14>Ad804<i7P0904Hk7`15>Qh0ACXN04Li7P18
>1h0BcXP04lk8P1B?RD0EClW00@0DD4P101B@R401P1JBb@0G4XT05e;8`1OC280HTdR06=<8P80IDdQ
00T0K4l]06a@:`1[CbX0JThW06]?9`1]DRL0Ke@W071E:01cERX00P1dEb/00`1eF2`0MUT]07MJ;P02
07QK;`0807aN;01mGbd0OV0^07mQ;`21Hc40PfDc08AV=025IcD308UW=`D0R6Hf0`2AKCT2099^>P<0
Tflk00H0TVhj09=_>`2CKc/0U70l09Ea?@2FLSh209Mc?`0609Md?P2HMCl0V7Do09Uf@02JMd40VgQ2
0P2LND<0202LND40WGY209ikA@2ONdL0XGe;0:9nCP2SOdl0Y7mB0`2SOd/30:B0C080YH5=0P2UP5@0
1P2VPE@0Yh=C0:R4DP2YQE40ZXIB0:Z7D@80ZXIB0P2[Qe<20:b8E080[HUE0P2_RUh30:j9G@<0[HQL
0P2]RET0102/R5P0ZhMG0:Z6EP2YQED20:R4E080ZhIB0P2/Qe<20:f8E080[XUE202^RUX80:b8F080
[HUI0`2/R5P20:^7E`80ZXIF00<0[XYJ0:f9F@2/R5P00P2[QeL00`2/R5P0[HUI0:j:FP020:Z4E@<0
ZhEF0`2/QUL00`2/QeX0[HQK0:n:G@020;2;GP030:n:G@2]R5/0[8MJ00<0[8IG0`2[QEH20:Z4E@P0
ZhEF202YQ500202YQ4l0ZhIB0:b7D`2^R5L0[XQI0:j8F`2]QU/0[8EJ0P2_ReL20:j:EP<0[HUE00@0
[8QD0:f7F02/QUL0ZXAE0P2YPe@01P2ZQ5D0[8IG0:f7F02ZQ5D0[8IG0:f7F080[XQI00H0[HMH0:b6
E`2ZQ5D0ZH=D0:Z4E@2/QUL20:f7F0030:b6E`2ZQ5D0ZH=D00P0ZhIB0`2XPU<30:V3E080ZXAE202Z
QE420:^6DP<0ZXEA0`2YQ5030:^6DP030:Z5D@2YQ500ZHA@0080Z8=?202[QU880:V3E0T0ZXAE202Z
QE430:Z4E@80ZhEF0`2/QUL80:Z4E@080:N1E02YPe@0[8IG0:j8E`2]R5@0ZhIA0:N2B`2UP4T80:^6
DP030:N2CP2XPdl0Z8=?0080ZHA@0P2ZQE400`2[QU80ZXAE0:Z4E@060:Z4E@030:R3C`2YQ500ZhIB
00<0[HQD00d0ZhIB0:Z5D@2/QUD0[HMF0:j8F@2_RE`0[hQM0:j7GP2]QUd0[8EN0:Z4E@2[QEH0[HMH
0080[XQI00<0[HMH0:^5EP2ZQ5D00P2ZQ5D20:^5EP<0[8IG00@0[HMH0:^5EP2[QEH0ZhEF0P2ZQ5D3
0:V3E100ZhEF0P2/QUL20:^5EP<0ZXAE00<0ZH=D0:^6DP2[QU801P2[QU840:^5EP@0ZXAE202[QU82
0:R2D`030:V3E02ZQ5D0ZhEF0080ZhEF0P2/QUL80:Z3F080ZXEA0`2YQ5030:R3C`<0ZH=D0P2XPU<3
0:N1DPP0Yh9;202TOTl40:AoB0<0Xgi700D0XWe60:N2CP2VPDd0Xgi:0:5lB0020:1kA`80XGa80P2S
ODh20:9lC@<0XG]<00@0X7Y;09egAP2MMdH0WGM60`2LMTD209]eA0P0W7M300<0VG=409YdA@2KMDH0
0P2KMDH00`2ILd@0V79309I`@@0209Ma@080V7910P2ILd8209Yd@`80VG5000@0V70o09I^?@2EKC`0
Tf/j0P2BJST00`2?JCP0TF/j099/>`0209A^?@0409=]?02AJcX0T6Xi09E]?080U6`k00D0Tf/j095Y
>02@J3L0T6Pg08mW=P0808iX=`0408]W=@2<J3H0SVXh08m[>@80T6`j00<0Sf/i08iZ>02:ISH00P2;
IcL01@2<J3P0RfLg08UU=@26HS80QF4a0080RV<h0`29HSL408QQ=P80Rf4g0P2:H3H03@29GcD0R5hd
08QN=028GS@0RUle08UN=028GS@0QEhc08=N<P20GS40Oed`07iM<022G2l00P23GC0208AN<@80QElb
00<0QV0c08MN<P27GS801P27GS802027G380R5dc08QN=026Gc@0Q5lc085O<P1nG2l0O5/^0`1nFcD5
07mL=P<0OU/a0P1mFS000`1lFBl0NeP^07]H;P0207]H;P80O5T_00@0OEX`07iK<@1nFc40OU/a201m
ERd02020FC00OEH]07YC:P1lEB`0OeP_085J<@1nEbh0Ne@[0`1fE2h507EC;@0807mE;`1mDbd0NE8[
07MA:P1fD2T0ME8Z07ED:`1fEB`8075A:P<0MU<[0P1eDRX307AA:@80Ldl]0P1bCR`01@1aCB/0L4`Z
071<:P1`C2X0Me@Z0080MU<Y0P1eDRP207AA9`0307=@9P1bDR/0LU8[0080LE4Z00@0L50Y06m?:01^
CRL0KThW0P1aCRP2079?:@0:075>:01_C2H0K4TS06]88P1WARL0J4LX06U8:@1ZBBX0JDPY06Q7:080
ITDV00@0ID@U06959`1RABL0HTDW0P1QA2H306139@0305Xm7`1K?R00GD0R0080GT4S00<0GD0R05/n
801J?Al00P1J@RH0101I@BD0F40T05Q0901G?b<205Hn8P0605Dm8@1E?B<0ECdS05@l901C>R@0DcXV
0P1B>2L804dk8`0804Ph7`1:>R40CS`T058n9P1C?BH0DcXT050g8@1?=1l204`j90<0BcTS0`1:>288
044d8@0803ld7P0m<Q`0>S8M03Pa7P0g<Qh0=S<P03Ld8`0h=bD303T_8b_ooooo000Zooooo`P0VFe0
202JL3h309U]?080VVhm0`2KKch00`2JL3h0VFlm09Q^?00309Q^?00309U_?@2JL3h0VW0n00H0VW0n
00<0Vg4o09i^?@2OKch00P2OKch30:1`?`040:5a@02LL3l0WG5009ib@@80X7A300<0WW9109ea@02L
L3l0202OLd820:5f?`040:5f@@2QMT<0XGI30:5eA080XGE600<0XgM60:9fA@2PM4<00`2OLd800`2P
M4<0XWI50:=gAP080:1d@`P0Y7Q70`2WO4L20:IkAP<0YGY50`2VNTT30:EiB080Y7Q7202TNdL30:El
B080YWe90`2WOTX0102XODX0Yga90:MlB@2WO4T20:IkB080YGY70`2TNTP30:EkB@80YWa:0P2ONTD0
102MN4<0VgI109Ud?`2HLch209Ia?080VFi100H0V6e009M/?`2EJSd0U6Tl09=X>`2BIcX208mV>P06
08aV>@2:ICP0RF@g08IT=P25ICH0Q6@e1025HSP01023H3H0PEhd07mL<P1nFc4207]K=00407YJ<`1i
FC80MeL`07IF;`80MED^201dDBT3075=:`80LTh/0`1cCbd207AC<00407=B;`1bDBh0LE0]075@;@80
L4l/0P1ZC2P206]=:@<0K4hZ00T0KDl[07=@:P1cD2X0M54Y07EB:01fE2L0MeDW07ME9@1hERH0101n
FB`01P20Fbh0PUd`089M<024Gc80QF0c08=M;P80Q5h_00<0QEl`08IP<@27HC800P28HS<308US=080
RV@e0`2;ICH0202BIST0T6Dh08iS=P2<HcD0RV@e08YV=P2:J3P0RfTi202;ICH308US=0<0R68c0P27
HC8808YT=`<0RF<f0`28HSD208MQ=00308QR<`29Hc@0RV@e0080RV@e00@0R68c08IP<@25Gc00QV0a
0`27HC8208QR<`80RF<d00T0RF<b08QR<@27HC80QV0c08IO=027H3L0R64h08UR>`2;ICH00`2:I3D3
08US=00908QR<`2?I3T0SV<f08eR=@2<HS80SF<a08iU<@2@Ic40TFPb00<0T6Dh0P2?I3L308iS=P08
09=X>`2BIcX0T6Dh08mT=`2>HcH0Sf@g091U>02AIST2091Z>`0408mY>P2>J3T0SFLh08eW>080S6Hg
00@0SVPi08eW>02=IcP0SFLh0`2<ISL00`2;ICH0RfHb08]V<P0608]V<P80SFPd00<0S6Lc08]V<P2:
IC400P29I3001P28Hbl0SVPk08iX>`2<IST0RfDh08YT=`<0RfDh00<0S6Hi08]U=P2;ICH01P2;ICH2
08eV>`0308eW>P2=IcP0SFLf0080SFPd00<0SFPc08YU<@2:IC400P2:IC4408UT<080Qf4b0`28HS<3
08US=0<0R68c0P27HC8308IP<@P0Qf<c1025HBd208IR;P80Qf<_1P20GRh207mM;@<0OE/]0P1lFR`3
07]I:`0407UF;P1hEBd0MU<[07EB:P@0M54Y00H0L5<Y06mB:01^DBL0KE0V06]>901ZCB<206U<8P80
K4/Z01H0JD/Y06M::01TBRL0HTXV065;9P1PBRD0FTXX05U99`1HB2L0ETDW05A39`1B@BL0DD0V050n
9P1<?al0C3hQ04Tn8016?B00@c`P040j800o>B40?SXQ0P0o=b800`0n=R40?CDP03`d7`0203/c7P03
03Xb7@0d<Ah0=34N00H0=34N0P0a;Q/2030]6P<0;b`I00<0;R/H038_700a;Q/00P0a;Q/2030]6P80
;b`I2@0Z;1h802LY6`P09bTN00<0:2XO02LY7P0V:1d00`0T9Q/202DW70P092DM200T9a`802<V6`@0
9BPM0P0T9a`202<V6`P09bTN0`0V:1X202LY6`<0:2XL0P0Z:a/202//70<0;2dM00L0;BhN038/700c
;Ad0<bhK03@_6`0e<1`0=S4K0080=c<J0`0d<Qd203Dc7P<0=S@O00@0?38I03dc6P0m<aX0?C<J0P0n
=1/203le7080@SPM0`13>Ah00`12>1d0@CLL040f6`04048h7@80@CLL0P10=Q/01@14>R40@cTP04<i
8012>1l0@CLN0080@3HM00<0?cDL040i7@10>Ad00P11>Qh3048k7`0404<l8013>Qd0A3/N04Dl7`80
ASdP00<0AC`O04@k7P13>Qd02014>Ad2044g70<0@SPM0P13>Ah204@j7`<0AS/O0P15>Qh304@i7@03
048k7`11>Qh0?cPL00<0?SLK2P0o>1`01P12=Qh0@CDM040f7@0n=ad0?CLM03`h7@80>STM200n=a/0
0`0l=A/0?CHL03hg7@0203lh7P0303hg7@0m=Q`0?3DK0080@3@L00@0?cDL03df700l=Q`0>cLL0P0i
>1`803hg7@<0@3TO0P0o>1h303hg7@P0?cPN0P0o=A`3040f7@<0@CLN4012>1l00`15>b00A3XO04<i
7P02048h7@0404<i7P14>Ql0AC/P04@i7@<0ACXN0P16>al204Ll800404]09019?R80B3dQ04Hk7`80
ACXN0P16>al3048g6`80@cPL0`14>Ad804<i7P0904<j7@13>1`0@cPL04<h7015=a`0B3PN04/j801?
>b80DCdT0080CclN00@0D40O0551801B@R40DT8Q0P1C@b804@1HB2@0FdTU05]98`1MBR80H4XQ069;
8@1TBb80I4`P06Y=:`1YCBP0J4`W06Q<9@1YCBD0Je0U06eB9@1_E2L0LUDY0080LeHZ00<0M5L[07EH
;01fFBd00P1gFRh0201jG2X0Ned[07aN;01nH2h0PF<a08=U<`24IS@0QFLe2027ICD3091/>080TFdi
1@2BKSX00`2CKc/0U70l09Ea?@0209Ib?P0609Mc?`2GM3h0Ug@n09Qe?`2IMT00VWM10P2KN4802@2L
ND<0W7U109ej@P2NNdD0Wg]70:1lBP2ROTh0Xgm?0:=nD@020:9nBP80Xgm;0`2TP4`01P2UPDd0YH1D
0:F0E02VPE@0Yh=C0:R4DP80ZHEA00<0ZXMA0:Z6DP2ZQU800P2[Qe<20:b8E080[HUE00@0[hYM0:j9
G02^RE`0[XUL0P2]R5/20:b7FP80[HUI00<0[8QH0:^7E`2ZQUH00P2YQED00`2XQ5@0ZhIB0:^6DP02
0:b7D`80[HQD0P2^RED@0:j:FP80[HUI0`2/R5P20:^7E`80ZXIF0P2]RET0102/R5P0ZhMG0:^7E`2/
R5P20:f9F@80ZXAE0`2[QEH30:b6E`030:b7FP2]R5/0[XUL0080[hYM00<0[XUL0:f8F`2/QeX00`2/
QUL30:^5EP80ZXAE202[QEH80:V4D0080:V4C`2ZQE40[8MC0:f7EP2^R5T0[HMJ0:b5FP2[Q5T30:j:
EP80[HUE0`2/R5@00`2/QUL0ZhEF0:Z4E@020:V3E0060:Z4E@2[QEH0[8IG0:Z4E@2[QEH0[HMH0P2^
R5T01P2]QeP0ZhEF0:Z4E@2YPe@0ZXAE0:^5EP80[8IG00<0ZhEF0:Z4E@2YPe@0202[QU830:R2D`<0
ZH=D0P2ZQ5D80:V4D0040:^6DP2ZQE40ZXEA0:Z5D@80ZHA@0P2XPdl0102[QU80ZXEA0:Z5D@2ZQE43
0:V4D0030:R3C`2[QU80ZhIB00H0ZhIB202YPe@90:Z4E@P0ZXEA00@0[8IG0:^5EP2[QEH0ZhEF302Z
Q5D0202XPUD0ZXAE0:b6E`2]QeH0[HQD0:^6D@2XPd`0YX5:202[QU820:R3C`80ZHA@102ZQE480:V3
E0030:R3C`2YQ500ZhIB00<0[8MC0P2[QU802`2[QE@0[8IE0:f7F02^R5/0[XML0:f6G@2/QE`0ZhAM
0:Z4E@2[QEH0[8IG0080[HMH00<0[8IG0:^5EP2ZQ5D00`2[QEH20:b6E`<0[HMH0`2/QUL20:^5EP<0
ZXAE202]QeP80:V3E0040:b6E`2[QEH0ZhEF0:^5EP80ZXAE0P2YPe@80:Z5D@<0ZhEF0P2ZQ5D30:V3
E0P0ZhIB1`2YPe@20:Z4E@P0ZH=F0P2YQ5020:R3C`80Yh9>0P2VPDd30:J0D@80YGm@0`2TOTl80:=n
B@P0XWa=102MN4<409iiA0030:=nBP2RODT0WgY600<0WGQ40P2NNDD309miBP80WWQ90`2MMdP409I`
@@<0Ug5200<0V79309Ye@@2JMD401P2JMD40202CKCh0U6ho09E_@02FL440UFm009A^?`2BK3d0T6Xk
0`2DKSl309E_@080UW110`2?JCX208iX>@80SFLh00@0S6Hg08mY>P2?JCX0T6Xk0P2AJc`00`2@JS/0
SfTj08iX>@0208mY>P0308iX>@2=IcP0S6Hg0080RfDf2@2:I3D00`28I3@0RFDe08]W=`0208eY>@03
08aX>02;IcL0RVHf00@0RF@g00@0R6<f08MR=@25H3<0Q5lb0P26HCL208EP=P@0Q5le00<0Pehd08AM
=024GC@00`23G3<3089K<P80PeTa00H0P5T`07iI;`1mF2h0NUL]07UH;@1hEb`407aG;@80OEP^0P1n
FBl01@24GC@0Pe`c08=L<`22Fc80PEXa0080P5T`00@0OeP_07mE;@1oEBd0OUL^0P1nFBl00`1kF2h0
NEP]07QG;00707YG<@0407UF<01kF300NeP`07]H<0<0NUL_0P1iERh207MD;0<0N5D]0`1iERh207YD
;@0407UC;01hDR/0Me4Z07MA:P80MU0Y00P0OEL`07YD;@1gDBX0NE</07aF;`1mEc00NeD^07QB:`80
KTdZ00@0Kdh[071?;01aD2d0LU4^0P1cDRl207UA;@0307I@:`1cD2X0LDlY0080LE4Z00<0L5<[06U;
9`1YBbL01P1YBbL0101aDBX0L50Y071@:@1`D2T206m?:080KThW00@0KD`[06a;:P1/BbX0K4/Z0`1[
BRT00`1ZBBP0LE4Z075A:P02071@:@@0KdlX1P1ZC2P206U;9`80JTTV0`1[BRL02@1YB2D0ITDR06E4
8@1Q@RH0HT<W06=4:01TABT0Hd@X06939`0206119@0305ho8`1K@BH0Fd4V00<0FT0U0`1I?b@00`1D
>Ql0EC/P05Hl8@0205Lm8P0305Hl8@1E>b00E3XO0080DShU1P1A?B@0201>>R40CCTP04`h801;=R40
BSDR04Td8`18<b80Ac4S2019>B800`13=1d0ACHO04Ph8@0204/i8`0304/f8@1:=1l0B38M0080B3LU
0P17=R@304He8`0304Dd8P0m<R00?C8P00H0?C8P00P0>RlK03L_6P0f;Q/0=2dK03<]7@0b;b00<S0Q
03<a90<0<2XN:oooool002[ooooo202IKD0809U_?@<0VFdl0P2JKSd309]_?P0309ec@@2KLCl0VFlm
0080Ufdk00<0VFlm09]a?`2MLd400`2KLCl309Y`?P80VFlm102OKch40:1`?`0309a`?`2MLD00WW91
0080X7A300<0WW9109ea@02LL3l0202OLd820:5f?`040:5f@@2QMT<0XGI30:5eA080XGE600<0XgM6
0:9fA@2QMD@00`2OLd800`2QMD@0XWI50:=gAP0809md@@P0Y7Q70`2XODX20:MlB@D0YW]81P2UNTL;
0:AkA`80YGa80`2VODT30:IkB080YGY70`2TNDH20:=iA`80Y7Y80P2UNdT20:IlBP0809mjA@2NND@0
WGQ309]f@@2IM3l0Ug8m09Ia?02EL3/209Q]@00409M/?`2FJch0UFXm09AY?080TfPk00H0SVDi08eT
>02;ICP0RF@g08QS=P25HcD208=S=080QF8h00`0Q64g08=P=P22GcD0P5dc07mL<P1nFc40Ne/d07YJ
<`1iFC80MeL`07IF;`1dE2d2079B:`P0Le4[101aCB/4079>;003079A;P1aD2d0LE0]0080L4l/0P1_
CR/00`1^CBX0K4/X06a;:00206e<:@0:06i=:P1_CR/0Kdh[071?;01dDB/0ME8/07EB:P1fDbT0MeDX
07QF:080NELW0P1nFB`00`1oFRd0P5/^085L;`0208=N<@0408AO<P25H3<0QEl`08EO<080QV0a0P27
HC8208QR<`80RF<d0P2:I3D208]U=P80S6Hg00P0TVHi091U>02>HcH0S6<e08YT=@2:ISH0RVPh08]Y
>@P0RfDf0`29Hc@308QR<`80Qf4b202:I3L308US=P<0R68e0P27HC@00`28HS<0RF<d08YT=@0208YT
=@0308QR<`26H340QEl`0080QV0a0`27HC8308QR<`80RF<b00<0R68c08QR=@27H3D00P27H3L00`28
HCX0RV@e08YT=@0208YT=@@0RF<d00P0Sf@i08iS=P2=HSD0SF<c08eS<@2?IS80TFPb099Y<`P0Sf@g
00P0TVLj095V>@2@ICP0Sf@g08iS=P2?I3L0TFHi099W>P80T6Xk0P2?JCX00`2>J3T0SFLh08eW>009
08eW>0/0S6Lc00<0RfHb08YU<@2:IC400P29I300102>J3/0SFLj08eW>P2<IST508]U>0P0RfDf0P2>
Ic`00`2>J3/0SVPi08iX=`0208iY=@0308iY=02:I3<0RV@c0080RV@c1029Hc8608QR<`80RF<d2027
HC8808QT=080QF4]1P26HRh207iL;0<0Oed]0`20GRh307iL;P80OE/]0`1lFR`03P1iERh0Me@/07AA
:@1aCRH0L4dU075>9P1cD2P0M54Y071C:`1_DRX0KU4Y06a?9`1ZCBD0JD`T0P1WBR8206U;:@0F06M:
:01TBRL0HTXV061:9@1OBB@0GDTT05U99`1HB2H0ETHU05E49P1C@RH0DD0V050o9@1??BD0BS`O04Xl
8@17?200A3XO044j800o>B40?SPR03`g8@80?3DR0P0k=240100j<b00>C8O03Tb7`0i<Ql303@a7P@0
<c0M00@0<RlL030]700`;A`0<2dL0`0_;1/202h[6P04030_7@0_;Q`0;bhL02l^7080;RdK0P0];1X9
02T[7@P09RPJ200V:1d0100W:Ah09RPM02HX7@0U9a`402@V6`P092DM200T9a`8028U6PH09BPM0P0T
9a`802LY7P809BLI0P0V:1X302LY6`0402PZ700[;1`0:b`L02//70<0;2dM0P0];Qh203<]7@0403@_
700e<1`0=S4M03Lb7080>3@K0`0g<Q`203Pc7@<0>C@N00@0?C<J03hd6`0n=1/0?S@K0P0o=A`2040f
7@0803le6P11=a`0@cTN04Dk8016?240A3XO048h7@10=Q/304<i7PD0@SPM00H0AS`Q04Dk8014>Ql0
@cTN048h7@10=Q/203le6P80@S/O0P13?20304@m8@0304Dn8P16>al0Ac`P0080B3dQ00@0Ac`P04Hk
7`14>Ad0@SLK0P13>1`204@i7@0404Dj7P16>al0AS/O04Ll8080@SPM0`13>Ah204@j7`80AC/P0P17
?20304Hk7`<0ACXN0P10>Ad203lh70@0?SLK0`10>Ad403lh700303hg6`0m=Q`0?CHL0080?SLM00@0
?CLM03hh7P0n>1h0?SPN200n=a/00`0l=A/0?CHL03lh7P02040i7`0303lh7P0m=Q`0?3DK0080@CDM
00@0@3HM03hg7@0m=ad0?3PM0P0j>Ad803hg7@80@3TO0P0o>1h203hg7@80?CHL200o>1h203hd6`03
03le7010=Qd0@CLN0080@SPO00<0@cTP048h7`12>1l03P12>1l00`15>b00A3XO048h7@02044g7003
048h7@14>Ql0AC/P0080A3TM0`15>Qh304Hk7`80BSlS00<0BChR04Pm8@17?2000`17?20404<h70@0
A3TM2013>Ah03`10>A`0@CPK044h6`10=aX0@CHJ04@f6`18>1h0BcXP04`k8@1=?A`0CShM04lo7P1@
@1l0DD4P05=38P0205A48`0605I6901HAB@0FDLS05]78P1OBB80HDXQ0P1SBR40201WBRP0ITXU06I:
9@1VBR<0Id/S06Y?901/DB@0KE8U0P1bEBT207=F:P0<07AG:`1eF2`0MUT]07II;@1hFRP0NE/Y07]M
:`1mGbd0P68`089T<P24IS@0QFLe0P25Hc<408IT=080QfDe0P2>JSH208m[=`<0T6`h00@0TFdi099^
>P2BKSX0Tflk0P2DL3`00`2ELCd0UW8n09Ib?P0209Md?P0409Qe?`2IMT00VGI009Yg@@80VgQ200P0
W7U109ej@P2NNdD0Wg]70:1lBP2QODd0XWi>0:9mD0<0XWi:0P2SOd/30:B0C0080:AoD`2UP5@0YH1C
0:J2DP2WPe40Z8A@0:V5D@2YQU020:Z6DP80ZhMC0P2/R5@20:f9E@<0[XYJ0P2]RET30:b8F0060:j:
FP2]RET0[HUI0:b8F02[QeL0ZXIF0P2YQED20:^6DP80[8MC0P2]R5@20:j9E@P0[XYJ202_Re/20:f9
F@<0[8QH0P2[QeL20:Z6EP<0[8QH0P2[QeL30:b8F080ZXAE0`2[QEH30:b6E`P0[HQK0`2/QUL30:^5
EPX0ZXAE00<0ZhIB0:Z5D@2ZQE400P2ZQE430:V4D0080:R3CP2ZQE40[8MC0:f7EP2^R5T0[HMJ0:b5
FP2[Q5T30:f9E@80[8QD0`2[Qe<00`2[QEH0ZXAE0:Z4E@040:Z4E@040:^5EP2ZQ5D0ZhEF0:b6E`80
[HMH00H0[8IG0:^5EP2ZQ5D0Z89C0:Z4E@2[QEH20:b6E`030:^5EP2ZQ5D0Z89C00P0ZhIB0`2XPU<3
0:V3E080ZXAE202YQ5030:Z4D`80ZH=B0`2XPU480:V4D0P0ZXEA202YPe@90:Z4E@P0ZXEA00H0[HMH
0:b6E`2/QUL0ZhEF0:Z4E@2YPe@20:R2D`P0ZXAE00P0ZH=F0:Z4E@2/QUL0[8IE0:b7D`2ZQE00Z8=<
0:N2B`P0ZXEA0P2YQ5060:Z5D@P0ZH=D0P2YQ5020:Z5D@@0ZhIB00/0ZXAC0:^5E02/QUL0[XQK0:j7
G02/QE`0ZhAK0:Z3G02YPe@0ZXAE0:^5EP020:b6E`030:^5EP2ZQ5D0ZH=D0080ZhEF0P2/QUL40:f7
F0<0[8IG0P2[QEH30:Z4E@P0[HMF202YPe@30:Z4E@<0ZH=D0P2XPU<80:V4D080ZXAC0P2YPe80102X
PU40Yh5@0:N1D02VP4l80:V4D0<0Z89C102WPE8:0:J0D@<0YX5=0P2UP4`30:AoB`<0XWa=0P2QNd`3
0:1jB`P0WgY6202NN4T209Qc?`0309Ud@02JMD40VgI20080W7M300@0WGQ409egAP2LMTD0VWA30`2H
LT40102ILd80VWA309]eAP2KMDH209YdA@<0VG=400<0V793099/?`2BK3l00P2CKD00102DKT40UFm2
09I`@`2FL4<809Ma@003091Z>`2AJc`0TV`m0080TV`m00<0T6Xk08mY>P2=IcP0202@JSd508YU>0<0
RfHi1@2=IcX208aV>@0408]U>029I3L0RF@g08QS=P80Qf8e0`26HC@808IP<`0308EP<`26HC@0Qf8e
0080RF@g00<0R6<f08MR=@26HC@00`26HCD01@25H3@0Q5lc08=N<P22GC40PE``0080P5dc0P1oG384
07iK<@0307eJ<020Fc40P5/a00<0P5/a0`1oFS001P21Ebl0OUL^07eH;P1lEbd0NEH/07MF:`80MEHZ
1`1gE2`02`1hEBd0OeTb07mI<P1nF340OEL`07]E;P1jE2d0NE</07QB:`1kDBT0NE8Y0080NE@Z00D0
N5D[07MF:`1fEb/0MUL[07QD<00407MC;`<0MU8^201eDbh607EC;@80MU@^0P1gDbl03P1fDRh0M50/
07=?:`1bCRX0LDdY071<:01fE2l0Le4/071>:@1bD2/0ME<^07ME<01dDRd0LDlZ101YBbT206Y<:P80
Jdd[0P1aCB/00`1_CBX0KD`Y06]=:@0206Y>:@0306Q>:@1RB2D0HTPU00H0HTPU00@0JDdX06Q<9`1X
C2L0J4`W0P1WBbH206I:9@D0I4LY0`1SARP406Q;:@@0IdXX0`1PARD306579P80HTPW00<0H4<S0654
901RABD00P1RABD00`1P@b<0GT4Q05e0800205Tm9@<0FclW00D0FCdU05Lk8`1G>b<0ESXR05<m9P03
058l9@80DC/T0P1@>R<204`h80@0CCTQ0P1<>2001019=al0BSPP04Xh801:>20404/i8@0804Ti8P18
>240AcHR04Dd8P13<R80@C0P040^800o;Al8044d8@0803`a7@0m<Qh0@3<P04<d8@14<b40A34P048_
7P13;Qd2044d8`80@3<R0`0o<R400`0n<B00=bhO03L^7`0603L^7`0803@[6P0b:aT0<2TI02hX6P0/
:1`0;2XN02`/800];B<302XW7R_ooooo000Zooooo`P0VFe0202IKcd309U]?080VVhm0`2KKch00`2N
M480W79009U_?@0209Q^?00309U_?@2LLT00WWA200<0Vg4o0`2JL3h209U_?@@0X70o102OKch00`2L
L3l0WG5009ib@@020:1d@`0309ib@@2MLD00W70o00P0Wg=20P2PMCh0102PMD00X7E20:1e@P2PM4<2
0:1dA@030:AhA`2RMTD0XGE400<0X7A300<0XGE40:9fA@2TN4L0202PMD880:AhA`<0Z7e:0P2WO4T3
0:IkB0H0YGY70P2VNdP;0:AkA`80YGa80`2VODT0102VNdP0YGY70:EjA`2UNTL20:AiAP80XgQ50P2S
NDL40:AjB080YG]90P2NND@0102LMd80VWE009Ud?`2GLSd209E`>`80Uf`o00@0UV/n09EZ?@2EJSd0
U6Tl0P2CJ3/208eT>00<08YT=`28HcH0Qf8e08AR=023Hc@0PV8c08ER>024HCL0Pf0f085N=020GC<0
Oe`b0P1nFc40201kFc@0NUXc07UI<P1gEc00MED^07=C;01bDR/0LE4Z201bDR`8075=:`80KD`Y101/
BbP206]:9`0606a:9`1]BbP0KT`Y06m=:P1`CR/0LDl/0P1bD2d207IC;@0;07MD;01hEB/0NELZ07YH
:P1jF2P0NeTY07eH:`1nFB`0OeX]085L;`22GC000P23GS4208AO<P@0Qf4b1028HS<308YT=@80RfDf
0`2<ISL0202BIST0T6Dh08iS=P2<HcD0RV@e08YV=P2:J3P0RfTi202;ICH308US=0<0R68c0P27HC8;
08US=P<0R68e0P27HC@00`28HS<0RF<d08YT=@0208YT=@0308QR<`26H340QEl`00<0QV0a0`27HC82
08QR<`80RV@c00H0RV@e08US=P29HSL0R64h08MP=`26GcP408US=0@0RV@e00P0T6Dj08mT=`2>HcH0
SF<c08iT<P2?IS80TFPb099Y<`P0Sf@g00T0TVLj095V>@2?I3L0SV<f08mT=`2@ICP0TFHi099W>P2@
JS/0102?JCX308iX>@@0SFLh102>J3T908aW<`@0RfHb0`2:IC4408eW>P0508aV>@2;ICP0RfDh08]U
>02:I3L0202;ICH208iW?00308iX>`2>J3T0SVPg0080SVTe00<0SVTd08]U=P2;ICH00P2:I3D208US
=080R68c0P29Hc@608QR<`P0Qf4b2028I3@608EQ;@80Q60/0`1nG2`307mM;@80P5h^0`1nG2h207eK
;@<0O5X/00h0N5D]07IC:`1cD2P0L4dU06m<901`CBD0LTlW07=@:01_DB/0KU0Z06e?:@1[CBL0JD/U
06Q:9080ITPR0P1VBBL05`1SBBH0HTXV061:9@1MBB@0G4PS05]98`1GAbD0ETHT05E5901C@R@0DD0T
050o9@1>?B<0CC/S04Pj7`18>R00ACTO04<i800o=b00?CLQ03`e8P0j=B40>C@P00@0>3<O0`0g<Qh2
03@a7P80<c0M00@0<RlL034^6`0a;Q/0<BhK0P0`;Ah302l/7@<0;R/L0P0];Qh202`]7@<0:b`L00<0
:R/K02PZ700X:Q`01`0X:Q`802HX6PP09RPM1@0U9a`00`0T9Q/08bDJ02<U6P0802<T70P092LL200R
9AX602DX7@809RTN200W:Ah302HX6P809bTK0`0X:Q`202//70<0;2dM0`0];Qh203@^7P0403D`7@0f
<Ad0=c8N03Pc7@80>CDL0`0i<a/203Xd70<0>cDM0P0n=1/203le70<0@3HM00@0@CLN03hd6@10=Q/0
@cTN0P16?2400`15>b00@cTN048h7@0604<i7P80A3XO00H0AchQ04Hm8015?1l0A3/N04<j7@11>1/2
040g6P80AC/P0P16?24404Lm8P0804Tk801:?240BcdR04/m8P1:?240B3XO04Hh7@14=Q/204<h7003
04@i7@15>Qh0AS/O0080Ac`P00@0B3dQ04<i7P13>Ah0@cTN0P14>Ql304Dk800304Hl8@18?B40B3dQ
0080Ac`P1016>al4048h7@80@CLL0P10=Q/3044j7P03040i7@0o>1`0?cPL0080?SLK0P0l=Q`203dg
7@0403hg7@0o>1h0?cPN03lh7PP0?cPL00<0?CHL03hg7@0o>1h00P10>Al00`0o>1h0?SLM03df7002
048f7P04044g7P0o>1h0?SPN03di7P80>cXN200n=ad303lh7P80?SLM0`0m=Q`803hg7@80?S@K00<0
?cDL040f7@11=ah00P12>1l00`13>B00@SPO048h7`0>048h7`0304@j7`13>Ah0@SPM0080@CLL00<0
@SPM04<i7P14>Ql00`14>Ad304Dj7P80AS/O00@0B3dQ04Tn8P19?R80BChR0P18?B4204Ll80P0A3TM
2013>Ah02@0n>A/0?cPK03lh6`0n=aX0@3LJ044f6P15=a`0B3PN04Xj800204dm700F04hn7@1@@1l0
DD4P05928@1C@b80E4@S05=38P1F@b<0Ed@S05U58P1MAb80GdLQ0658801RBB40IDPV06E9901TB2<0
IDTR06I:8P1YCR<0K54T06eB9@80LE@X00@0LUDY07=F:P1dEb/0M5L[0P1eF2`0201hFRP0NE/Y07]M
:`1mGbd0Of4_085S<@22I380PfDc0P23HC4208AR<P80QF<c0P26I3@308eY=@80SVXf0`2?JcL2095]
>@04099^>P2CKc/0U70l09Ea?@80UW8n0P2FLcd0102GM3h0V7Do09Uf@02JMd4209]h@P80WGY200<0
WW]509ijAP2ONdT00P2PO4`00`2QO4l0XGe90:5mB@020:9nBP80Xgm;0P2TP4`20:AoD`030:F0D`2V
PU80Yh=A0080Z8A@00<0ZHI@0:Z6DP2ZQU800P2[Qe<20:b8E080[HUE0P2^RUP20:f9E`80[8QF0P2[
QeD20:j:FP030:f9F@2/R5P0ZhMG0080ZXIF00<0ZHEE0:^6DP2[QU800P2/Qe<20:f8E080[XUE202^
RUX80:n;F`80[HUI0`2/R5P20:^7E`80ZXIF0`2[QeL20:b8F0<0ZhMG0P2ZQ5D30:^5EP<0[8IG0P2]
R5/40:b7FP80[HQK0`2/QUL30:^5EPX0ZXAE0P2/Qe<20:^6DP0<0:Z5D@2YQ500ZHA@0:V4D02XPdh0
ZHA@0:^6DP2]QeH0[HMH0:b6F@2[Q5T0ZX=H0`2/R5@20:^7D`<0ZXIB00<0ZH=D0:Z4E@2ZQ5D0102Z
Q5D20:V3E00:0:Z4E@2/QUL0[HMH0:f7F02/QUL0ZXAE0:V3E02XPU<0ZH=D0:Z4E@80[8IG00<0ZXAE
0:V3E02XPU<0202[QU830:R2D`<0ZH=D0P2ZQ5D80:V4D080ZXAE0P2YPe@20:R2D`80Yh5B102XPdl4
0:V4D0P0ZXEA202YPe@90:Z4E@P0ZXEA0P2/QUL00`2[QEH0ZXAE0:V3E0020:R2D`030:N1DP2ZQ5D0
ZXAE00H0ZXAE00P0ZXAG0:Z4E@2[QEH0[8IE0:^6DP2ZQE00Z8=<0:N2B`P0ZXEA0P2[QU860:Z5D@P0
ZH=D102YQ5020:Z5D@80ZhIB00/0ZH=B0:Z4D`2/QUL0[HMJ0:f6F`2/QE`0ZX=J0:V2F`2XPU<0ZH=D
0:Z4E@020:^5EP030:Z4E@2YPe@0Z89C0080ZXAE0P2[QEH30:b6E`040:f7F02[QEH0ZhEF0:^5EP80
ZXAE0`2YPe@80:^6DPP0ZXAE0`2XPU<20:N1DP<0YX1A202WPTh20:R3C`040:N2CP2VPDd0YH1<0:Ao
B`80Xgi:202UP4`20:EoD0@0Y7i?0`2SODh80:9lB`<0XWe90P2QO4P30:1kA`80WWQ90P2MMdP309af
A`0309]eAP2JM4<0VWA300H0VWA3202JM4D209Ma@00409Qb@@2ILd80VWA309Yd@`80VgE400<0Ug52
09I`@@2DKSl00`2CKCh00`2EKd00UW1109I`@@0209I`@@80UFm00`2DKSl2095Z?`04099[@02CK440
U6e209A]@P80UFi3202CKCh208mY>P<0TF/l00<0SfTj08eW>02<ISL01@2;I3T308YS>080R6<g0P29
I3P208YU>@80RfHj00<0RV<h08UR=`28HCH00`27H3D208IO=0@0Pehb1022GC48085J;`03085L<022
GC40Q5lc0080Q5lc00L0Pehb085L<020Fbl0PUdc085L<P20Fc40OeX`0080OUT_0P1mF2h0101kFS40
NUT`07YI<01jFC0307UH;`80N5L^1@1nF34307mI<P0607iG<01lERl0O5H_07UF;P1gERd0MED/0P1b
EB/307EC;PD0M58]00H0NeDa07YD<01iDbl0N58^07I@;01eCb/207A>:P0807QA:P1gDBX0Me4Z07EB
:P1dDbX0M5@[079E:`1cER`207IB<080ME4_00@0M50^07=?;@1cCbd0Ldl]1`1^CB`00`1_CRd0Le<]
07=C;@0607=C;@0607EB<P1dDC40Le0`079?;`1aCRh0Kd`/0P1^Bb/03P1^D2h0Jdd[06Q::01YBbT0
KDl]06i@;P1/CR`0JD/Y06M:;01VBB/0IDPZ06A7:@1SARP0HD@V0P1P@bD206U8:@0606M8:@1VBBT0
HdTX06989`1QBBL0GdPV201OB2P306579P80H4HU0`1OAB@505a19P<0GD8W0`1N@bH505m49`@0F40T
0P1I@BD205Y29P0305Ll8@1H?B80FChS0080FSlT00D0F3dR05Ll8@1F>b00DCTQ058j8P0305<k8`04
054i8@1@>200D3PP04hf7P80BSLV0P19=RD304Pe900304Ld8`15=280A3<Q00D0A3<Q00<0AC@R048c
7P12<ah00`13=1l304@e800804<h9012=b<0@CHT03ld8P0m<B40>blQ03X^8P0i;B4803T`7`0903D^
700f;ad0>2lN03/_7`0l;al0?BdN03`/7@0l:Q`0>S4R00<0>C0Q0P0h;b0203L^7`P0<b/P00P0;bLJ
02dW6@0[9AT0:2@I02LT6`0V9Q`09bPP02PY8`<09bPR:oooool002[ooooo202IKD0809Q^?0<0VFdl
0P2JKSd309]_?P0309ec@@2LLT00Vg4o0080VW0n00<0Vg4o09ab@02MLd401`2JL3h00`2KLCl0XG50
0:1`?`020:1`?`<0Wfln00@0WVhm09a`?`2MLD00WW910P2PM4<00`2NLT40WG5009a`?`0809mc@P80
X7Dn00@0X7E00:1e@P2PMD80X7A30P2PM4D00`2TN4L0XgM60:5eA0030:1d@`030:5eA02SMdH0Y7Q7
00P0XGI1202TN4L30:MkBP80YWY90`2UNDP20:AiA0<0YGY50`2VNdH80:AkA`<0YGa80P2VODT30:Mn
BP<0YW]80P2UNTL30:AiAP80YG]90P2TNTP20:=iA`80XWQ600P0WWU409eh@`2LMd80VWE009Qc?P2F
LC`0UG0k09A_>P80UV/n0P2EJSd209AY?080TfPk00H0SVDi08eT>02;ICP0RF@g08QS=P25HcD208=S
=00408ER>024HCL0PUle081M<`@0OU/a00P0NUXc07UI<P1hF340MeL`07IF;`1eEBh0M5@]07=C;0P0
Ke4]00@0LTh/075=:`1aCB/0LDd[0`1`C2X00`1_BbT0JTTV06Y99P0606Y99P0606e99`1^BRP0Kd/Y
071<:P1aCB/0Ldl]0P1dD2h01P1gE2h0N5D_07QE;@1iER`0NUP[07]I:`80O5XZ00@0OEP[07iI;020
Fbh0PUd`1@24Gc8708QR<`0308US=02:I3D0RV@e0080RfDf0`2<ISL02@2=IcP0TVHi091U>02>HcH0
S6<e08YT=@2:ISH0RVPh08]Y>@0808]U=P<0RF<d0`28HS<208MQ<P/0RF<f0`28HSD208MQ=00308QR
<`29Hc@0RV@e0080RV@e00<0R68c08IP<@25Gc000P25Gc0208IP<@<0Qf4b00X0R68c08YT<`2:I3<0
RfDf08]U>02:HcP0R64h08IO=P25GSL0R68c0`29Hc@308YT=@0908]U=P2@ICX0Sf@g08iS=P2>I3@0
SV@b091W<`2AJ380TfXd00<0SV<f0P2?I3L3091U>008095V>@2@ICP0Sf@g08iS=P2?I3L0T6Dh099W
>P2CJ3/808mY>P<0SFLh0P2>J3T308mY>PP0SFPd202;IS801P2<IST0SFLj08eW>P2>J3/0SFLj08aV
>@<0RV@g202;ICH208aU>P0308aV>@2<ISL0S6He0080S6Lc00H0S6Lb08aV>@2;ICP0RfDh08YT=`29
HcH208QR=@0408MQ=029Hc@0RF<d08US=0<0R68c0P27HC8308IP<@80Qf4b0`28HS<808IR<P80Q60/
0`23Gb/3089N:P80Oed]1P1nG2`307eK;@80O5X/0`1kFB/0101gE2`0ME8Z07AA:@1bCbL3075>9P06
079?9`1]Cb/0K4hZ06]=:@1ZC2P0JD/W0P1WBBD01P1VB2@0HdTV06=99P1QBBD0GdTT05a88`80FTPR
0140EdPQ05I6901EAB<0E4@S05918`1@?b<0CSdS04dl8P1<>R80AcTO04Hg8013=al0@CHP03de800k
=240>S<Q03Pc800303Db7`H0=34N0P0c<1d00`0b;a`0<BhK030]6P0202l/6@04030/800_:al0;b/O
02l[7`80;RXN0P0]:Ad202/]7`80:R`N0`0Y:ad00`0X:Q`09bTK02LY6`0702LY6`P09BLI200U9a`0
200T9Q/09BLL02DW700V:1d09BLL02@V6`0S9AX08R@I200S91`802@W70P08bHK100U:1d202HY7P80
9bXO200W:Ah202LY6`80:2XL0`0Y:ad00`0Z;1h0:b`L02`]7@0202`]7@80;BhN0P0^;al203D_7`06
03Ha7P0g<Qh0>3<O03Td7P0i=A`0>SHM0`0k=1X203`e6`<0?CHL0P0o=A`2040f7@<0@CLN00H0@SPO
03le6P10=Q/0@SPM04@j7`15>b0304Hl8@80@cTN0`14>Ql304Dk8080ASdP0P15?1l01014>ah0@cXM
048i7012>A`304Hj8080Ac/Q0`18?280201:>R00Bc/Q04`l8P1<?280Bc/Q04Xj8017=ad0ASHL0P14
>Ad204Dj7P0404Hk7`17?200Ac`P04Pm8@<0A3XO0P15>b0304Hl8@0304Lm8P19?R80BChR0080B3dQ
0`17?2000`16>al0A3PN04@h7P0304Di7`0304@h7P12=Q`0@CDK0080@S/O0P11>Qh02P10>Ad0?cPL
03hg6`0n=a/0>cXN03Xi7@0l>1d0?CLM03hg7@10=Qd2044e7@P0?cPL00<0?CHL03hg7@10>Al00P11
>R000`10>Al0?SLM03df700204<g7`04048h7`10>Al0?cTO03hj7`80?3/O200n=ad203lh7P80?SLM
0`0m=Q`00`0l=A/0?SLM03hg7@0603hg7@80?cDL0`10=Qd3044g7Q00@SPO00<0A3XO04<i7P11=a`0
0P10=Q/00`11=a`0@cTN04@j7`0204<h7080A3TM0`15>Qh204Hk7`0504Ll8018?B40B3dQ04Pm8@17
?2000`16>al304Dj7P<0A3TM00<0@cPL04<i7P13>Ah01P13>Ah02@0n>a`0?STK03hi6`0m>1X0?SLJ
040g6P13>1`0AcTN04Pj7`0204hn7@80CclN00d0D40O0551801B@R40DT8Q05508P1C@200ED8R05M3
8P1KA280GTHR06168@1QAb80IDPV0080I4PS00D0IDTR06M;8`1ZCb@0K54T06iC9P02071C9`03075D
:01bEBT0LeHZ0080M5L[00L0MEP/07UK:@1jG2X0Ned[07aN;01nH2h0Of4_0080P68`0P21Gbl01022
H300Pf4a08AR<P24HS8208ES<`0408]W<`2<J3@0S6Pd08aX=080SFTe0P2>JSH2095]>@04099^>P2C
Kc/0U70l09A`?080UG4m0P2FLcd0102GM3h0V7Do09Uf@02IMT0209Yg@@80WGY200<0WW]509ijAP2O
NdT00P2ONd/0102PNdh0XGe90:5mB@2QODT20:9nBP<0Xgm;00P0XgiB0:AoD`2TOe80YH5A0:J2D02W
Pdl0Z8A@0:R5C`80ZXIB0P2[Qe<20:b8E0D0[HUE0P2/R5@30:^7D`060:n;F`2^RUX0[XYJ0:f9F@2/
R5P0ZhMG0P2ZQUH20:^6DP80[8MC0P2]R5@20:j9EA00[XYJ0P2]RET30:b8F080ZhMG102ZQUH0102[
QeL0[8QH0:b8F02[QeL20:Z6EP80ZXAE0`2[QEH30:b6E`80[HQK00@0[8MJ0:^6F@2[QUT0[8MJ0P2]
R5/30:b6E`<0ZhEF0P2ZQ5D80:V3E080[HQD00<0[8MC0:^6DP2ZQE400P2YQ5002@2XPdl0Z8=>0:V4
D02[QU80[8IE0:f7F02/QUT0ZhAI0:Z3F0030:^7D`80ZXIB0`2YQE400`2XPU<0ZH=D0:Z4E@020:^5
EP060:Z4E@2YPe@0Z89C0:V3E02ZQ5D0ZhEF0P2/QUL01P2[QEH0ZXAE0:V3E02XPU<0ZH=D0:Z4E@80
ZhEF00<0ZXAE0:V3E02XPU<0202[QU830:R2D`<0ZH=D0P2ZQ5D80:R3C`<0ZH=F0P2XPUD30:N1E0<0
Yh9>0P2XPdl;0:V4D0P0ZH=D2@2ZQ5D80:Z5D@@0ZXAE0`2YPe@00`2XPU<0ZXAE0:Z4E@060:Z4E@08
0:^5F02[QEH0ZhEF0:^5E02ZQE40ZXE@0:V4C@2XPd`80:V4D080[8MC0P2[QU840:Z5D@P0Z89C0P2Y
Q5030:R3C`0>0:V4D02[QU80[8MC0:R2D@2YPe80ZhEF0:b6F@2/QEX0ZhAK0:V2F@2XPEX0Yh5B0:R2
D`2YPe@20:Z4E@030:V3E02XPU<0Yh5B0080Z89C0P2YPe@30:Z4E@040:^5EP2YPe@0ZH=D0:V3E080
Z89C0`2WPE880:R3CPP0Z89C0P2UOe020:AnC`<0Xge>00<0XWa=0:AoB`2TOd/01P2TOd/20:F0B`06
0:AoBP2RODP0XGa70:1kAP2ONTD0WWU4202QO4P209miBPL0X7Y;2P2NNDD209ehA080W7M30P2KMT82
09YdA@80VG=40`2HLT<00`2GLD80UFm009E_@00609E_@0P0Ug520`2EKd0209I`@@<0Ug5200<0TV`o
095[?P2?JC`00P2>J3/0102?JC`0T6Xm095[?P2BK3d3095[?080T6Xk0P2?JCX0102?J3l0T6U0091Y
@02@JD04095Z@@P0SVPk00<0RfDf08aV=`2=IcP00P2>J3T00`2<ISL0RV@e08US=00208MP=`80QUlf
1025GSD308AQ=`@0QF8h00D0QV<i08IO=P25GSD0Pe`c085J<@02081I<080PEXa201lFBl807aE;00<
07iI;`1oFS00P5/a085L<P20Fc40OeX`07eH;P1lEbd0OEL`07aF;`1jE2d0NE</101hDR/0101fERl0
MED^07EE;P1eEBh307AD;@80Le</0P1gE2h307QE;`<0NEH`00P0NU@_07QE;`1gE2h0ME<]07=C;01`
Db/0Ke<[06iB:P80LE0_0`1`Cbh306m>;@0507=?;`1bCRh0LTh^075=;@1`C2`00P1_Bb/02P1^BRX0
MDlZ07=@:P1aCRP0L4hX06i>9`1]D2P0KE4Y06iB:P1bCRh2075=;@03071<;01_Bb/0KTXZ0080KDTY
0`1UARL306I7:080IdPY0P1^D2`306e?:`<0K4hZ0P1^CBh206e<;@0L06a;;01[BR/0JTTZ06Y9:P1W
BRX0I4LW0654901RABD0ITTY06M::P1UB2P0HTDU06A6;01SAB/0HD<Y05m19`1M?bD0FcdS05Xl8P1I
>b40Gd0T05m19@1P@RH0GT<V05e49P1J@b@0Ed8S05I18PP0F4DW0`1J@b@205U28`<0F44R00@0E3`T
05Dm9@1E?BD0ECdU0`1F?RH00`1G?bL0E3`T05@l900205Dm9@@0EShV201@?2@00`1?=R00D3LQ054h
8P02058i8`06054h8P1?=R00CSDO04Pc7P19=1l0BSDP0P1;=R401019=1l0Ac8M04Lb7@16<A`304<a
8`<0@S0R0P11;b4203``800403/_7`0j;Qh0>RhN03/_7`80?30P200k<1h0200j=B40>C@Q03Pc800g
<B40=S0R03D_8`0d;B<0<b`R200c;Al02@0`;Ah0<BhO03<]7`0d;1l0=B/O03L[7`0h:Ql0=bTN03@^
8P0303<]8@80<R`P0P0a:al802hW7`0802/U6@0X91T09b<H02DR6@0S8a/08b@N02<U800T9R4302@V
8b_ooooo000Zooooo`P0VFe0202HKS`309U]?080VVhm0`2KKch00`2KLCl0W79009ec@@0209id@P03
09ec@@2LLT00Vg4o0080V6hl00@0VFlm09Y`?P2KLCl0Vg4o0P2LLT020:5a@080X70o0P2OKch209i^
?@0309a`?`2MLD00WW910080X7A300<0WW9109ea@02LL3l0202OLd8209md?@0409md?`2OM440WgA1
09mc@P80Wg=400<0Y7Q70:=gAP2RMTD00`2QMD@00`2RMTD0XgM60:AhA`080:=h@@P0Y7Q70P2VNT/2
0:EiBP80Y7Q90P2SMdP30:Ai@P030:Ej@`2VNd@0YW]40080Yga5202TNdL20:ImB@80Ygi:0P2XOd/2
0:V0C0<0Yga90`2VNdP20:EjA`0@0:MmB`2VO4X0YG]90:AjB02RN4H0XGM50:1fA02OMD<0WWU409eh
@`2KMT40VWE009Qc?P2FLC`0UG0k09A_>P<0UFXm102DJC`01`2CJ3/0SfHj08mV>P2<IST0RVDh08UT
=`26I3H00P24I3D01025HSP0Pf0f085N=01nFc4307eJ<00507iK<@1iFC80NETb07UI<P1hF3400P1g
Ec0207IF;`P0KU8]0P1bCR`2075=:`04071<:P1_BbT0Kd/Y06m;:@D0K4/X0`1]C2T03P1]BBL0KTXX
06m;:@1`C2X0LTh/07=?;@1dD2h0ME4_07QE;`1iES00NEH^07YG;@1kFB`0O5X/0P1mFb/0101lEbX0
OUT/085L;`23GS4308EP<`80Q5lb2029Hc@308]U=P<0S6Hg0P2=IcP0202BIST0T6Dh08iS=P2<HcD0
RV@e08YV=P2:J3P0RfTi202;ICH308US=0<0R68c0P27HC8808QR=@<0RF<f0`28HSD208MQ=00308QR
<`29Hc@0RV@e0080RV@e00<0R68c08IP<@25Gc000`25Gc0208IP<@<0Qf4b00P0RV@c08]U=02<ISL0
S6Hi08]T>@28HCP0QUlf08EN=`80R68c0P29Hc@208YT=@80RfDf00T0TFHk091U>02?I3L0SV@d08iT
<P2@Ic<0TVTc09=Z=02=HSD00P2>HcH208mT=`80T6Dh00T0TFHi091U>02@ICP0Sf@g08iS=P2?I3L0
T6Dh099W>P2DJC`0102?JCX4091Z>`<0SFLh00<0SVPi08mY>P2?JCX00P2@JS/808eX=080RVDa1P2;
IS800`2;ICP0S6Hi08eW>P0208iX>`0408aV>@2:I3L0RV@g08US=PP0RfDf0P2:HcP00`2:I3L0RV@e
08YT<`0208YU<@0708YU<02<ICX0S6Dj08]T>@2:HcP0RF8g08QQ=P0208MP=@80RV@e0P29Hc@01@28
HS<0Qf4b08MQ<P27HC80QEl`0080QV0a0P27HC8208QR<`0308US=024H300Q60`00H0Q60`0`22GRX0
0`21GBT0P5`X081L:00207mK9`80P5h^00@0Oed]07iL;01nG2`0OE/[0P1lFRX207aJ;080NeT[0P1j
F2X207UG:@80ME8Z00H0MU<[07EB:P1dDBT0Le0X075>9P1`CBD306Y<:00306U;9`1XBRH0J4XV0080
IdTU0P1QBBD03P1OBB@0GTPS05]78P1IAb40EdPQ05I7801EAB<0E4@R05=38P1A@280CchR04dl8P1<
>b40BcTQ0P15=Ql01P12=R00?c@P03`d8@0j<b40>C8P03La8@D0<S4O0`0c<R001P0d<Ah0<c0M038_
700a;Q/0<2dJ02l/6@80;R/H0`0_:b0202hZ7`<0;BTN0`0Y;Al202P/7P<09b/M2@0V:1X802DW6@P0
92HK00P08bDJ02@V6`0U9a`09RPM02DW700T9Q/08R@I024S60P08R<K200T9a`802DX7@0302@W700U
:1d09BPM00809RTN0P0W:Ql00`0X:b009bTN02LY7P0602LY7P80:B/M0P0Z;1h402/]7`<0;2dM0P0]
;Qh302h_7`80=S0P00@0=c8O03Pc7`0i=200>C@N0P0j=Qd0100k=1X0?3DK03`e6`0l=A/203df7080
?SLM0`10=Qd2044g7P<0@SPO0`11=a`01@12>1d0@cTN04Hl8@18?R<0BClT0080@cTN0P14>Ql01015
>b00AS`Q04Hl8@16?24804Dl7@80AcTO0P18>R0304Tk8@0404Xl8P19>Al0BSXP04/k8@80C3`R00<0
Bc/Q04Ti7`18>1h00P15>Qh404Hk7`80Ac`P1015>b0204Hl8@<0AcdR00@0BSlS04Tn8P19?R80BChR
0P18?B4204Ll800804Li7`18>R00BC/Q04Xl8P19>b40B3XP04Hh7P14=Q`204<l8004048k7`11>Qh0
@3TM03lh7080?SLK0P0k>al0100k>Qh0?SPN03hg7@10=1`2044b6`P0?cPL00<0?CHL03lh7P10>Al0
0P11>R000`10>Al0?cPN03df700204<g7`04048h7`10>Al0?cTO03hj7`80?3/O2`0n=ad303df7080
?3DK200m=Q`3044g7P<0@3HM0P0o=A`@048h7`0304@j7`12>1d0@CLL0080@3HK00<0@CLL048h7@14
>Ql00`13>1`204@i7@<0ACXN00P0@cPL04@i7@16>al0Ac`P04Pm8@17?200ACXN04@i7@<0AS/O00<0
ACXN04@i7@14>Ad00P13>1`804<i7P09040m7P0o?1d0?c`M03lj700o>1/0@CPK04<h7015>Qh0B3XO
00@0CclN101@@1l02@1??R00DChP05=0801F@B80FT<S05e58`1OAB80H4HS06E89P0206E9900506I:
8`1XC2@0Je0U06iC9P1`EBP00P1_DRH00`1`DbL0LE@X079E:@0207=F:P0307AG:`1kGB/0Ned[00<0
O5h/0`1mGbd01P1oGBd0P5h^085O;`22H300Pf4a08AR<P80QF<c00@0RVHb08]W<`2;Ic<0RfLc0P2<
J3@208eY=@06091/>02AKCT0TFdi099^>P2CKc/0U70l0P2ELCd01P2ELS`0UW<m09Ic?@2GM3h0V7Do
09Uf@080VWM10P2MNT801P2NNdD0WWY609ijB02NNTX0Wg];09mjC@@0XGe90P2ROTX20:=oB`80XgiB
00H0Y7mB0:F1D@2VPU00Yh=?0:R4D02XQDl20:Z6DP80ZhMC0P2/R5@40:f9E@80[8QD102[Qe<20:n;
F`040:j:FP2]RET0[8QH0:^7E`80ZXIF0P2[QU820:b7D`80[HQD0P2^RED80:j:FPP0[8QH0P2]RET3
0:b8F080ZhMG0P2ZQUH00`2YQED0ZXIF0:^7E`020:b8F0030:^7E`2ZQUH0ZHEE0080ZXAE0`2[QEH3
0:b6E`030:j9G02]R5/0ZhII0080ZXEH00<0ZhII0:f8F`2^RE`00`2/QUL30:^5EP80ZXAE202YPe@0
1@2^RED0[HQD0:f8E02/Qe<0ZXEA0080ZHA@00X0Z8=?0:N2C@2XPdl0ZXEA0:b6E@2/QUL0[8II0:^4
F@2ZPeP0ZhMC0`2ZQU820:V5D@80Z8A@00<0Yh5B0:R2D`2ZQ5D00P2[QEH01P2ZQ5D0Z89C0:N1DP2X
PU<0ZH=D0:^5EP80[8IG00H0ZhEF0:V3E02XPU<0Yh5B0:R2D`2ZQ5D20:^5EP030:Z4E@2XPU<0Yh5B
00P0ZhIB0`2XPU<30:V3E080ZXAE202XPdl20:V2E`80Z85F102WP5D20:J1C@80Yh9>00<0Z8=?0:V4
D02YQ5002@2YQ5080:V3E0T0ZXAE202ZQE430:R2D`80ZH=D2`2ZQ5D01P2[QEP0ZhEF0:^5EP2ZQ5<0
ZXEA0:V4C`80ZHA=202YQ5000`2]R5@0[8MC0:b7D`020:^6DP80ZXEA00<0ZHA@0:R2D`2XPU<01P2X
PU<00`2ZQE40ZHA@0:N2CP020:N2CP0>0:V4D02[QU80[8MC0:N1D02XPU40ZXAE0:^5F02[Q5T0ZX=J
0:R1F02WP5T0YX1A0:N1DP2YPe@20:Z4E@030:V3E02WPE80YX1A00<0YX1A0P2WPE830:R2D`<0Yh5B
0P2VP5430:EoD0P0Xgi72@2RO4d30:5kC080X7Y;0P2ONDX80:1kA`80XWe600H0X7]409mj@`2MN440
W7M009]f?`2JMCh809ehA080VWA50P2KMDH209afA`0309egB02NN4T0WWQ900P0VWE1102IM40209Qc
?`80Ug8n0P2GLD8209I`@@80UFm00P2DKSl8099/?@P0U6ho0`2AJc`3091Z>`80SfTj00<0SFHk08aU
>P2;I3T00P2:HcP00`2;I3T0SFHk08iW?00308iX>@80SFLh0`2<ISL208aU?0<0Rf@k0`2:HcX808YS
>080QV0a0`28HS<01026H340Q5h_08=M;P24GC@208=L<`80PU/b0P21FS400`20FC00Oehc07mN<`06
07iM<P04089K<P20FC00OUL^07aE;080Ne@[0P1lEB`407MF:`@0N5L/201iDRT03@1kER`0O5L]07eH
;P1nFBl0OEP^07]F;01iE2X0N5<Y07UC;P1hDRd0MDlZ07==:01bC2L00P1cCBP0101dCRT0LU8/079B
;01bDR`4075A:`80L50Z0P1^C2L00`1_CBP0L4hY071>:@03075?:P0807=?:`1bCRX0LDlZ06m?:@1/
CRP0JThW06U=9P1WCRH206]::`80JTTZ0P1YB2T206Q7:0P0K4T[00P0L4`X06i:9P1[BB@0J4PR06E7
8@1UBB80ITXS06A;8`80JTDX00H0JD@W06Q39P1W@RD0IT4T06E08`1T?b8305i09080Gd4U00<0H48V
06539`1Q@bL00P1VBRD206E9900406A88`1SAb80HdLR06=78PP0ID<X00T0GdHX05]2901I@280FT4S
05i59`1OARP0GD@V05U08P1K?bT00P1J?RP00`1I?BL0F3`V05Pl9P0205Lk9@0805Hk801G?240EcdR
05Lo8`1E@2<0DSlQ050m7`1=?1h8050o9@0405A18`1C@280Dd0R05=08P80DSlQ0P1A?R0204di8@80
CSXR00D0Cc/S050l901@?2@0D3`T04Xe800204/f8@80C3LR0P1=>2<01P1>>B@0C3XV04/i9@1;>BD0
BSPT04Tg8`80B3HR00@0AcDQ04Lb7`18<b00BC@Q0P1;=R<02@1:=B80B3<P04Pc8012;ah0@c0O04@a
8015<R40A34P04<`7`02044^7@04040]700l;R<0?2hS03`^8`80>bdR0`0j;2400`0f;R40=BdP03@/
7`0203<[7P0403@/7`0e;B00=RhQ03P_7P80=bhM00D0=RdL03D/6`0d:aX0=2/J03<Z6@0202l^7003
02h/7@0^;1l0;B/O0080;2TP00<0;2TR02dY7@0]:Ad01P0]:Ad202h/7`0302l[7`0a:al0<RXO0080
<bTO00@0=BPO02hZ8@0^:R40;RXQ0`0]:B0202`X7`P0:B@N00P0:2@K02LS6P0U8Q/08B0K020Q700Q
8b008R@Q024U90<07R@R:oooool002[ooooo202IKD0809Q^?0<0VFdl0P2JKSd309]_?P0309Y`?P2K
LCl0WWA20080X7I400<0WWA209]a?`2JL3h00P2GKC/01P2HKS`0VW0n09]a?`2LLT00WG=109id@P<0
XG5000<0X70o09m_?P2NKSd00P2NKSd00`2LL3l0WG5009ib@@020:1d@`0309ib@@2MLD00W70o00P0
Wg=20P2OM3d0102OM3l0WgA109md@@2OLd8209mcA0030:EiB02SMdH0XWI500<0XGE400<0XWI50:=g
AP2UNDP0202UNT<80:AhA`040:EiBP2TN4T0Y7Q90:AhB@80XgM80P2RMTL0102SN440Y7U20:Ai@P2U
NT<20:IkA080Yga5202TNdL0102WOTX0Z7m;0:QoB`2XOd/20:V0C080ZX5=0`2XODX20:MlB@<0YW]8
0P2XOT`0102VO4X0Y7Y80:9hAP2PMT@209id@P80WGQ300@0VgI109Ud?`2HLch0UW4l0P2DKcX00`2E
JSd0U6Tl09AY?00509AY?006091W>`2?ISX0SFLj08]V>@2:ICP0QfDg0P25ICH01025HSP0Pf0f081M
<`1nFc4207aI;`0307eJ<01nFc40NETb00@0NETb0`1hF34806iA;`80LTh/00@0LDd[071<:P1`C2X0
Kd/Y0P1^BRP406m>:`@0L4l/00P0KdPW0719:01aBRT0LT/Z07A=;01fCbh0Me0_07QA<080NEH`00X0
NUL_07]H;P1lFRd0OE/]07eK:`1nG2`0O5LZ07iI;021G2l0Q5lb0`25H3<208AO<P@0RV@e1029Hc@3
08]U=P80S6Hg0`2=IcP0202BIST0T6Dh08iS=P2<HcD0RV@e08YV=P2:J3P0RfTi202;ICH308US=0<0
R68c0P27HC8808QR=@<0RF<f0`28HSD208MQ=00308QR<`29Hc@0RV@e0080RV@e00<0R68c08IP<@25
Gc000`25Gc0308IP<@80Qf4b00P0RV@c08]U=02<ISL0S6Hi08]T>@29HST0QUlf08AM=P<0R68c00<0
RF<d08YT=@2;ICH00P2;ICH0202AIS/0T6Dh08mT=`2>I3@0SfDc091W<`2BJC<0TfXd0P2=HSD0102>
HcH0Sf@g08mT=`2@ICP2095V>@08091U>02?I3L0SV<f08iS=P2?I3L0TFHi09=X>`2DJC`308mY>PD0
T6Xk0`2=IcP00`2>J3T0SfTj091Z>`02091Z>`P0SFPd0`2:IC4508]V<P0308]U>02<IST0SVPk0080
SVPk00@0S6Hi08YT=`2:I3L0RF<f202;ICH208UR=`0308US=P29Hc@0RF<b0080RF@`00T0RF@_08eV
>`2<ICX0Rf@i08YS>029HSL0R64f08MP=@26Gc@00P2:I3D208US=00408QR<`27HC80Qf4b08IP<@80
QEl`00@0QV0a08MQ<P27HC80R68c0P29Hc@808=O;`80PEdY0P20G2P0101oFbL0OUXV07iJ9P1mFBD2
085O;`07081N;P1nG2`0OE/[07aJ:P1kFBT0NUPX07]I:`0307YH:P80NELY0P1hERP0201dDBT0ME8Z
07MD;01hEBd0Me@/07AA:@1aCRH0Kd`T201XBRP0601QBBD0H4PT05i88`1LB2<0FTPR05M88@1FAb00
EDLP05A48P1C@b40DT8Q050o8@1>?B40CC`R04/j801:>200ACHO04@e8011=Al0?c@P03/c800i<R00
>34Q03H`80<0<C0N100b<Al02@0c<R00<c0M03<`7@0b;a`0<BhK030]6P0_;1T0;R/H02dZ5`0202l[
80<0;RXO0`0]:Ah202T]7`80:2`N0`0W:ad00`0V:Q`09RPJ02HX6P0702HX6PP09BLI200T9Q/00`0R
91T092HK02DW700202HX7@0302@V6`0R91T0828G00P08R<K200T9a`802HY7P0402@W700U:1d09BPM
02HY7P809bXO0P0X:b0802LY7P80:R`N0P0[;Al202`^8080;BlQ0P0/;Ad302d^7P<0;RlO0P0f<200
1P0g<Ql0>3<O03Td800j=Al0>SHM03/g7P<0?S@I0P0o=AX3040f6`80@3HM0P11=ah3048h7`0304<i
8012>1d0@CLL0080@3HK00D0@SPM04Hl8@1:@2D0C48W04<i7P0204@j7`0304Dk8016?240AS`Q0080
AcdR0P14>aX304Dl6`<0ASdL00@0ASPN04Li7`17>Al0AcTO0P18>R0204Tk8@0304Th7P1:>Al0C3/Q
0080CC`R00<0C3/Q04/j801:>Al00P17?20604Hk7`<0AC/P0P16?24304Lm8P0304Pn8`1:?b<0BSlS
0080BChR0`18?B401017?200B3XP04Tk8@1:?28204/m8`0904Tk8@17>Al0ACLM04@m8@13?200@S/O
044j7P10>Ad0?cPL0080?SLK00P0>chQ03`l800l>al0?SPN03hg7@0o<a/0@34J044a6PP0?cPL00<0
?SLM03lh7P10>Al00P11>R000`10>Al0?cPN03hg7@0204@h800404<i8011>R00@3XP03lk8080?C`P
2`0n=ad203df70<0?3DK200m=Q`01P13>B00@SPO048h7`11=ah0@3HM03le7080?S@K4012>1l00`13
>Ah0@SPM044g7002040f6`03044g7012>1d0@cTN00<0@cPL0`14>Ad204Dj7P03048g6`13>1`0ACXN
0080Ac`P00<0AS/O04@i7@13>1`00P17?2001016>al0ACXN04Dj7P14>Ad204<h70P0@cTN00T0?chO
040m7P10?Ah0?S/L03hi6`10>A`0@cXM04Hk7`17?2000`1@@1l304lo7P80CShM00T0CSdQ050m7`1B
?b40ED0Q05U28P1LA280GdDR06168`1UB2H00P1UBB@01@1VBR<0J4`T06aA9P1_E2L0L5DX0080Ke8V
00@0L5<W075D:01bEBT0LUDY0P1cERX507aN;0<0Ned[00P0OU`/07mM;@20GRh0PEl_089P<023HC40
Q68b08ES<`<0RVHb0P2;Ic<308aX=080T6`h00@0TFdi099^>P2CKc/0U70l0P2ELCd209Eb?00409Ic
?@2GM3h0V7Do09Uf@080VWM10P2MNT800`2MNT@0WWY609ijB00209ijBP0309iiC02PO4P0XGe90080
XGe90P2ROTX20:=oB`80XgiB00<0Y7mB0:F1D@2VPU000P2WPdl00`2XQDl0ZXIB0:Z6DP020:^7D`80
[8QD0P2]RED20:f:E080[8UC0`2[R5801P2ZQe40[h]K0:n;F`2^RUX0[HUI0:b8F080ZhMG00<0ZXIF
0:^6DP2[QU800P2/Qe<20:f8E080[XUE202^RUX80:^7E`80[HUI0`2/R5P20:^7E`80ZXIF00<0Z8AD
0:V5E@2[QeL00P2]RET00`2[QeL0ZHEE0:R4E0020:Z4E@<0ZhEF0`2/QUL00`2^RE`0[8MJ0:^6F@02
0:V4E`030:^6F@2/QeX0[XUL00<0[8IG0`2[QEH20:Z4E@P0ZH=D0P2^RED00`2]R5@0[8MC0:^6DP02
0:V4D0090:R3C`2WPTd0Z8=?0:Z5D@2/QUD0[8IG0:^5F02ZPeP0ZH9G00<0ZXIB0P2YQE430:R4D003
0:N1DP2XPU<0ZXAE0080ZhEF00H0ZXAE0:R2D`2WPE80Z89C0:V3E02[QEH20:b6E`060:^5EP2YPe@0
Z89C0:N1DP2XPU<0ZXAE0P2[QEH00`2ZQ5D0Z89C0:N1DP080:^6DP<0Z89C0`2YPe@20:Z4E@P0Z8=?
0P2YPUL20:R1EP<0Yh1E00H0YWmD0:J1C@2VPDd0YX5=0:N2CP2XPdl;0:V4D0P0ZH=D2@2ZQ5D80:Z5
D@80Yh5B0P2XPU<0102YPe@0ZXAE0:^5EP2[QEH80:Z4E@060:b6F@2[QEH0ZhEF0:Z4D`2YQ500ZHA?
0P2YQ4d80:V4D080[HQD0P2/Qe<0102[QU80ZXEA0:Z5D@2YQ5080:R2D`0C0:Z5D@2YQ500Yh9>0:J1
C@2WPTh0ZHA@0:^6DP2/Qe<0Yh5@0:R2D@2ZQ5D0ZhEH0:^4F@2ZPeX0Z85H0:N0F@2VP540Yh5B0:R2
D`020:V3E0030:R2D`2WPE80YX1A00<0YGm@0`2VP5420:N1DP80YX1A0P2UOe030:AnC`030:=mCP2P
Nd@0X7]400H0X7]4202MMdP0102PNT/0WgU:09miBP2ONDX209ihB@80WGM8202NNDD20:1kA00409ii
@P2MN440VgHo09Ud?@80V7<l202KMT80102FL440Ug5209Qb@`2ILd@209YdA@0309]eAP2LMTL0WGM8
00P0Ug8m0P2GLSh309Ia?@<0UG0l0`2EKd0209A^?`<0Tfdn202@JSd809=]?P80SFLj00@0S6Hi08]U
>02;ICP0RV@g0P29HcH00`2;I3T0RV<h08UR=`0208QQ=P0308YS>02;I3T0S6Dj00<0S6Hg0P2;ICH3
08YT=@80R64j00@0Qf0i08IO>025GSL0QEhg0P24GCH808MP=@03081J:`21Fb`0PU`]0080Ped^00<0
PE//07mI:P1nF2T00P22Fc@01021FS<0P5Tb081I<P1oF34207iG<080NeXa00<0NUT`07UH;`1iF2l0
0`1hEbh01P20FC80OUL`07]D;@1iDR/0Me0Y07QA:P80NE8[101eE2/407IE;0P0Me0Y0100NU@]07]E
;P1lERl0O5H_07]E;P1iDb`0Me4Z07I@:@1fD2/0MDlZ079<9`1`BRD0KdTT071:9@1aBbH0LT`W0P1_
DB/206i@:P@0KDlY00<0K4hX06Q68@1XAR400P1YAb801@1ZB2<0JdTT06]9901/BRD0KTXV0080K4XU
00<0JTXT06M98`1UBB800P1RBB4206A5:080Hd@W00@0HT<V06529@1Q@RD0H44T0P1YARX206Y7:`@0
JdP/00T0K4PT06U78P1VA1l0Hd<M05m16`1N@Q/0GD@L05i57@1T?b800P1S?R400`1Q?1l0H3/N05lj
7@0205hi7080FS`P0P1K?B40101L?R80GClS05do8`1N@2@206138@80Gd8P00@0GT4O05e07P1M@1h0
G3lM101L?B4205dn8P80GSlS00T0FT<T05M08@1E?Ql0ESlP05Y3901KA2D0F44R05Dn7`1C>B800P1D
>R<00`1E>b@0ES`U05Lm9P0205Pn9`08058h7`1C>B00Dc/Q05@l8P1B?B80Cc/P04/j7P19>1`804Xj
8004058n8`1A?B80DCdR054m8P80D3`Q0P1?>b0204/f8@80C3LR00@0CCPS04hi901>>B@0CcXU0`17
<Ql00`18<b00BC@Q04Xe8P0204Xe8P80BCPV00@0B3LU04Lf9015=280A3<Q0P13<R000`14;ah0AC0O
04Lb8@0304Pc8P0804Ha8015<1l0?bhL040_7@11<1h0@S4O044`7P10;ad203h]6`0403d/6P0j:b@0
>R/T03X[9080>BXS0`0h:B800`0d;B<0<R/Q030Y7`0202lX7P09030Y7`0b:b40=2dS03H_7`0e;Qh0
=2dM03</700b:a/0<2TI0080;bPH00H09RLE02HW5`0V9aL09RLI02HV6P0V9Q`202HV7PP0:bTM0P0/
;2001P0]:al0;RXO030Y7`0a:1l0<RTP03<Y8080;2TP0P0[:1l302XW7P0302TV7@0X8al0:2<O00H0
:2<O00P0:2<M02HS700T8A`08B0K020Q700P8Ql082@S024U90<06R0P:oooool002[ooooo202DJC`0
2@2JKd80VFi109Q]@02GK3l0UV/n09EZ?@2DJC`0TfPk09Q[@@0209Q/?`0309U]?P2IKC`0VFhk0080
VVlj00P0V6hl09U_?@2JL3h0Vg4o09ab@02MLd40WWA209me@`80VFhi00@0VVlj09]`>`2LLC`0WG8m
0P2NLch209U_?@<0VW0n0`2KLCl00`2MLSl0WW=00:1e@P020:5f@`040:1e@P2NLd00WG8o0:1fA080
WgE300<0WG=109ab@02KLCl00P2JL3h209mf@P80X7M30P2QN4@20:9iA@80YgM6102VMTD30:EeA0<0
XgM60P2TN4L30:EiB080XWM400@0XgQ50:AiAP2TNDH0YGY70P2VNdP20:=iA`<0XWQ60`2QMdD00`2V
O4X0Y7Y80:9hAP020:5gA@030:=iA`2VO4X0Yge;00P0YWe90`2VODD30:MnAP80Z7m70P2VO4X20:Ek
B@040:AjB02SNDL0XgU70:=iA`80YGa600H0Y7]70:9hAP2QMdL0X7E809mdA`2NLdP209icAP0609md
A`2NLdH0W75409Y_@P2GK3l0UFXm0`2AJc`01@2@JS/0SfTj08mY>P2?JCX0SVPi0080S6Lj00<0RfHi
08YU>029I3L00P28HcH02`27HSD0P5dc085N=023H3H0Q64g08=P=P20GC<0OEX`07]H;P1iERh0NUL_
00<0O5Ta00<0NUL_07QE;@1gE2`00P1fEC80101eE340M5<`079A;P1aD2d2071?;00906i=:P1_CR/0
LE0]079A;P1aD2d0Kdh[06e<:@1/BbP0K4`U0080KDdV0P1^CRL206m?:009071@:@1_BbL0Kd/W071=
9`1bCbL0Le0V07EC9P1fE2L0MU@V0080OeTb0P1nF3402@1mEc00O5H_07aF;`1lERl0P5X]085K;P23
GC00QElb08MQ=00208US=P80RfDh0P2<IST308eW>P<0SVPk0`2@IS@3095W=@80TVPf202@IS@01P2B
Ic`0TFHk091U>P2?I3T0SV<h08aQ=P80Rf0e0P2;H3H00`2;H3D0Rf0c08]Q<@0208]Q;`0408]R;P29
HcH0RF<f08US=PD0R68e2029HcH308QR=@0308US=P2:I3L0RfDh0080RfDh00<0REha08]P<`2<HC@0
0P2=HSD0102<HC@0Rf0c08UN<@2;H3<308YO<P<0REha00<0R5d`08]U=P2;ICH01P2;ICH308eW>080
S6Hg0`2;ICH308iT<P80SfDc0`2@IS@308]V<P80S6Lc0`2=J3@208mT=`<0T6Dh0`2AIST808iX>@P0
SFLh2028HS<01P2=HC@0S64d08eR=@2=I3H0SFLh08eY>@<0S6Xj0P2;IST308YU>0<0RF@g202:HcP8
08UT=`D0Qf8e0`28HcH02021G2l0QV4d08UT=`27HSD0PUd`085L;`24Gc80R6<f0P28I38608MS<@<0
PE/^0`20FRd207mI;003089L;@21Fb`0OeTZ0080OELX00<0OUPY081J:`21Fb`00P1nFB`01P1mF2/0
O5LZ07]F:@1kERT0NUDX07UD9`80ME@Y00H0M5<Z079@:P1aCbX0KddZ06i<:@1^Bb/206=:8@80HdXR
01X0HdTT06989@1RB2L0HTPW05]48P1H@Al0DclN05@o801F@bD0ED@V05529@1=?R40Ac`N04Pm7`19
?R80B3`R04Hj8P13=b40@3@N03ha7P0o>2D0?SLU03df900l=BD0>S8U03Ta9P80>2lV00@0<c0Q038_
800b;b00<RlP0P0a;Ql2030]7P<0<bdQ0P0b;203034[7`/0:2XO0`0W:Ah202HX7@<09RTP0P0U:1lA
02@W7P<08bHM200Q91/0100Q91T08RDJ028U6P0R9AX202<V6`8092LL200S9Q/302@W70809BPM0`0V
:Ah00`0X:aX0:B`K02X]700202`_7P0>02X]700Y;1/0:2/J02T[7P0X:Qd09bTL02HX6`0W:A`0:2XM
02X/7`0/;R40:2XE02T[5P0[;AP202`^6@0302/]600Y:aH0:2XE00@0;b`I0P0`;AX2034^6`<0>c0J
0P0l<A/303db7080=c<F00H0>3@G03Te600j=QT0>SHI03/g6P0l>1/2048g6`0304<h7014>Ad0ACXN
0080Ac`P00<0B3dQ048i7012>A`01P12>A`01019?1`0BSdM04Xm7@1:?Ad204/n7P80C3lO00@0BcXL
04`k7@1<>ad0C3/M0P1=?1h204hm7`0604ll7P1=?1h0CC`N04`m7P1;?Qh0BChN0P18?ah204Dl6`80
ASdL0`17?Qd02018?ah0ACXN04Hk7`18?B40BSlS04]0901:?b<0B3dQ1017?2001018?B40BChR04]0
901<@BD204e29P0404Y18019@1l0BD0O04Po7P80AchM0P16?A`304Ln8@80ASdP0`15?1l02018>Ql0
AcTN04Dj7P13>Qd0@3TL03hi6`0m>1X0?3TJ0`11>B800`10>240?cLP03hf7`0203hf7`04040f6`11
=a`0@CLL044g70<0@SPM00<0@cTN040f6`11=a`00P11=a`2048h7@80@cTN2014>Ql8048h7@0603le
6P0m=QX0?CHJ03dh6`0m>A`0>cXL0P0k?1d01P12>b40@CXP040i7`0o>1h0?SLM03`e6`80>c@J2010
>Al803hg7@80@CXP0P10>Al203lh7P80?SLM4012>1l304<g7@<0A3PN0P15>Al01P19>1h0B3PN04Ph
7P17>Ah0ACXN04@k7P80@S/N2012>A`904<i7P0604<h7016>1d0ASPM04Ti7`1;>R00CSXQ0P1@>R80
2`1>@2H0CClT04hn901??R80DD0R05E28P1IAB@0FTHU05i87`1PBR40HT`S00<0I4hU00<0HT`S065;
8P1_E2L0101_E2L306iC9P80M5PX00T0METY07IJ:P1hG2`0NEd]07YN;P1kGbl0PF8c081Q<P1nGc00
0P1mGRl02`1oH340PF8c089S=029IC40RVHb08aX=02>JSH0Sf/g08iZ=P2<J3@0RfLc0080Sf/g00<0
T6`h095]>@2BKSX00P2CKc/00`2DL3`0UW4m09Ia?@0309Mb?P<0V7<o00H0V7Dm09Uf?P2IMSh0VgQ0
09ai@@2MNT8209ik@`0309eiA@2NNTH0X7a800<0XWi:00D0XGe90:1lB02ROE00XWe@0:=nD@020:Ao
DP030:F0D`2VPE@0YX5D0080ZXIB0P2[Qe<30:b8E0030:f9E@2ZQU@0ZXID0080ZhME0`2/R5H02@2]
REL0/8UN0:n8G@2_RE`0[XQI0:f7EP2]R5@0[8MC0:b7DP020:^5EP80[8IG0P2]QeP20:j8F@80[hQ?
00<0[hQA0:n7D`2_Qe@00P2_QeH00`2_QUP0[8UC0:b9D`060:b9D`80[HUI0`2/R5P20:^7E`80ZXIF
0`2ZQU@00`2[QeD0[8QF0:f9E`020:f9E`0;0:F0D`2VPE@0Yh9E0:V4E`2[QUT0[HQK0:n:G@2`Reh0
ZhII0:V4E`2XPeH00P2VPE@0102XPeH0ZHAG0:^6F@2/QUl20:b7G@030:b7F`2[QUT0ZhMG0080ZhME
00<0Z8=F0:V4E`2YQ5L0102YQ5L40:Z5F080ZHAG0`2XPeH20:N1E0040:R2E@2YPeH0ZhEH0:b6F@80
[HMJ202[QEP20:J2DP040:N3D`2XQ5@0ZXIF0:^7E`80[8QH0`2YPe@20:Z4E@<0ZhEF00<0ZhII0:Z5
F02XPeH00P2WPUD00`2XPeH0ZXEH0:^6F@080:^5EP80Yh=C0P2XQ5@30:V5E@030:Z6EP2YPe@0ZH=D
00H0ZH=D202YPeH0202/QEX0ZhAI0:Z4E`2YPe@0Z89A0:N2CP2VPDd0YX5<0P2UOe020:J0D@070:N1
DP2XPU<0Z89C0:V3E02SODh0YGm@0:N1DP020:V3E0060:R2D`2WPE80YX1A0:>1D@2TPU80YH=C0`2W
QED00`2VQ5@0YH=C0:B2DP080:V3E080YX1A00@0Yh5B0:R2D`2XPU<0ZH=D0P2ZQ5D01P2/R5P0ZhMG
0:^7E`2ZQUH0ZHEE0:R4E080Yh=C202YPe@0102ZQ5D0ZH=D0:V3E02XPU<20:N1DP80YX1A202XOE03
0:EoD080YX1A0`2WPE880:J1C080Yg]>0P2VNTd30:EiC0040:AhB`2RO4d0XG]<0:1jB`80WgU:00H0
X7Y;0:5kC02RO4d0WgY50:5lA`2SOTT20:F0B`030:=nB@2QO4L0WgY500<0X7]60P2ONTD309iiA003
09]f@@2JMD00VWE000D0VWE0202ILd800`2JM4<0VgE409afA@0209egAP0309]eA02ILd80Ug500080
V7910`2GLD0309I`?`0309UeA@2HM4@0UW920080U71000@0UG5109Ib@P2GLd<0UG510`2DL40209=_
?`80TVhn00@0TfXn09A[?`2DJcl0U6/o0`2EK40209I]@@<0TFdi0P2@K3P308m[=`0309=Z?02DJcd0
UVdo0080Ufi000@0UVdo09A[?@2CJS`0Tf`c0P2CK3D00`2CJcL0Tf/h09=[>P0209=Z?0P0Qf4b00P0
Q5h_08US=02<ISL0RV@e08EO<023GBh0QV0a08YT=@80RfDf0`2:I3D308US=00408UR=`28HCH0R64f
08QQ=P80Qf0e0P26Gc@02`26HCD0QF0d08AO<`24Gc<0QF0d08MR=P29I3P0RVDi08EN=@23G3<0P5T`
0080OUL^00<0OeP_085J<@23G3<00P20FRd00`1oFB`0OUP[07eG:P0207]E:00407YD9`1nG2l0O5X]
07]I;0<0NELZ00<0NUP[07]I;01kEc<00P1jES800`1iEC40N5@`07MC;`0207IB;P<0OE8_0P1lDBh3
07]@;@0807YD;`1iDbh0MU0[07E?:P1dCRT0MDlZ07I@:`1hDRd3079?:@80LDhX0`1`CBL306e;9P80
K4XU0`1[BB@806e::P0806]<;@1ZBb`0JDX[06M8:@1VAbP0I4DV06=49@1R@b@306A5:080Hd@W101R
@bH806E8:P<0HTDW0P1QA2H306139@P0FSlT00@0FD4U05Q0901H@2@0EclS0P1F?R8205Dm8@P0E3hV
0P1D?b800`1C?R<0DS`T054k900204li900404hg9@1B>R00DSXP058j8080Dc/Q0`1D?28305@o8P80
ED0S0`1F@B@3054l9`80D3/V0`1?>RD0101@>bH0CcXU04lj9@1>>B@204dh8`80C3LR00P0Bc8N04dd
801>>2<0CcXU04hl9P1;>b@0BCTR04Lh8@80A3PR0P13=b44048f8080>cDO0P0l=R0403dg8@03040c
8011=240@cHS0080ACPU00<0A3LT048e8P11=2400`14>28204<g8@<0@SHP0P10<2<203l_8P<0?RhQ
00L0?BdP03P`8`0h<2<0=blR03D]800d;1l0<b/N0080<RXM200d;1l9034[7@<0;RLO100]9Qh00`0/
9Ad09BDM02DU7@0>02HV7P0302X[8`0X:B409RLO008092DM00<09BHN02HW7`0X:B400`0U9Qh00`0V
9al09bPP02PY8@0202PY8@P09RPJ200S91h3028S7@808B8L0`0P8A/;01lQ7R_ooooo000Zooooo`P0
U6Tl00H0VVm209U^@@2HKD00Uf`o09I[?P2EJSd209AY?00609Q[@@2HK3l0V6`o09U]?P2IKC`0VVll
0P2JKcX209U_?@0409Y`?P2KLCl0W79009ec@@80WWA200@0WG8m09aa?02LLC`0W74l0P2KL3/209Y_
>P80VFlm0`2JL3h309]a?`0309eb?`2NLd00X7E20080XGI300T0X7E209ic@02MLSl0X7I409me@`2N
M480WG=109ab@02KLCl00P2JL3h209mf@P80X7M30P2QN4@20:9iA@80YgM6102VMTD30:EeA0<0XgM6
0P2TN4L30:EiB0030:9gA02SN4D0XgQ50080Y7U60P2UNTL0102VNdP0XgU70:=iA`2SNDL20:9hAP<0
XGM500@0YWa:0:EkB@2TNTP0XgU70P2TNTP20:IlBPP0YWe90`2VODD30:MnAP80Z7m70P2VO4X20:Ek
B@0=0:AjB02SNDL0XgU70:9hAP2UO4H0Y7]50:=jAP2RN4H0XGM709mdA`2NLdH0WW=809ebA@0309ic
AP0409aaA02IKT40Uf`o09EZ?@80TV`m00@0TF/l091Z>`2?JCX0SVPi0P2=IcP01P2<IcX0RfHi08]V
>@2:ICP0RF@g08QS=P80Qf8e0P1nFc4207mL<P0B07iK<@1lFBl0NUL]07UF;01iERh0NUL_07]H<01l
FC40NeP`07YG;`1hEBd0Me@/07IE<P1eE340M5<`07=B;`1bDBh0LE0]0P1`Cb`206m>:`<0LE0]00<0
Kdh[06e<:@1/BbP01@1^CRL306m?:008079>:P1cCb/0M54[07EB:P1gE2X0N5HY07UG:P1jF2X807iI
;`05085K;P22G2l0Ped`08EO<P27HC@00P29HcH0102;ICP0S6Hi08aV>@2<IST308eW>P<0SVPk0`2?
IC<3091V=080TFLe202@IS@3095V>`03091U>P2?I3T0SV<h0080SF8g0P2;H3H00`2;H3D0Rf0c08]Q
<@0208]Q;`0408]R;P29HcH0RF<f08US=P@0R68e00<0Qf4d08US=P29HcH01P29HcH308QR=@0308US
=P2:I3L0RV@g0080RfDh00<0REha08]P<`2<HC@00P2=HSD00`2<HC@0Rf0c08UN<@0208YO<PH0Rf0c
202;ICH308eW>080S6Hg0`2;ICH208iT<P<0SfDc0`2@IS@208]V<P<0S6Lc0`2=J3@00`2AIST0T6Dh
091U>005091U>0P0SVPi202=IcP808aV=`0608iR=@2=HSD0SV<f08iU=`2<ISL0S6Ph0`2;JCT208]V
>@<0RVDh0`29I3L808YS>0P0RF@g1P27HSD208QS=P09089M<025H3<0R6<f08MR=@23GS40PE`_08AO
<P28HcH0R6@b00@0Qf<a0`26HS03089L;`<0PE/^0P20FRd02@22G2d0PE//07mI:P1nF2T0OELX07iH
:@1oFBX0P5X[07aJ;@0207]I;00307YH:`1iEbX0N5HY0080MeDX00P0ME@Y07AC:01cDRT0LU0Z071>
:@1_CBX0KT`Y06e::P80HdXQ00<0HdXR06988`1RB2D00P1RB2L04P1RAbT0GDHT05U2801D@1l0Dd0P
05A39@1CA2L0D44T04/m8P17?1h0Ac`P04Pm8@17>b40ACTQ048f800o<Ql0?C0M03`e8P80>c@R00D0
>S<S03Ta900h<2D0>2lV03L^9@04038_8080<BhO0P0`;Ah3034]8@80<2`P0`0_:al;02PZ7`809bTN
0`0V:1d202HY80<09BPO400T9ah402<V7@P08B@K100R9AX202<V6`8092LL200S9Q/202@W70<09BPM
0`0V:Ah00`0X:aX0:B`K02X]700202`_7P0502X]700Y;1/0:2/J02T[7P0X:Qd00`0W:A`01P0Y:ah0
:R`O02`^8@0Z;1L0:bdH02`^6@80;BlJ00<0;2hI02/]600Z;1L00`0`;AX3034^6`80<RlL0P0i<AX2
03Xb6`<0>c<L00L0?3@M03Lc600h=1T0>3@I03Te6P0j=Q/0>cLL0080?3PM00H0@CHJ048g6`13>1`0
A3TM04Dj7P16>al204Ll80P0@cXM0`19>ah204Xl7`<0BcdP0`1:>ah204/l7`<0C3dP0P1<>al0101;
?1l0BS`O04Pm7`18?Al204Ln7`<0AC`M0P16?Ah304Ln7`0804Hk7`17?200BChR04Xo8`1;@2@0BSlS
04Tn8P18?B4304Ll800604Pm8@19?R80BSlS04]0901<@BD0CD8V0`19@1l00`18?ah0AchM04Ln7@02
04Hm70<0B3lR0P17?R4304Hm8080AcTN00<0ACXN04@k7P11>Qd00P10>ad0100o?1d0@SXS044i8P11
>B82040h8@80?cLP00<0?SHO048h7@12>1d01012>1d6044g7080@SPM0P13>Ah804@j7`P0@SPM0P11
=a`00`0o>1`0?STL03di700203/j700303Xk7010>Al0@3TO0080?cPN00@0?SLM03df700l=A/0?3DK
2010>Al803hg7@80@CXP0P10>Al203lh7P80?SLM4012>1l304<g7@<0A3PN0P15>Al01P19>1h0B3PN
04Ph7P17>Ah0ACXN04@k7P80@S/N2012>A`904<i7P0504<h7014>Ad0ASPM04Ph7P1;>R000P1>>R40
4@1@>R80CClU04do901>?R@0CchR050o8@1E@R80F4@S05Y69@1MAah0GdTP065;8P1SCB@0I4hU06==
901RC2<0HD/R00<0KE8U0P1^DbH306mD9`0607=G9`1dF2P0METY07IJ:P1hG2`0NEd]0P1jGRh04@20
HC80Of0a07iO<01mGRl0OUl`07mP<@21HS<0PV<d08QT<02:IS80S6Pd08eY=@2>JSH0SFTe08aX=02;
Ic<0SVXf0080Sf/g00<0T6`h095]>@2BKSX00P2CKc/309Ia?@80Ug8n0`2HLcl01@2HMCd0VGHn09Uf
?P2JMcl0W7U10080WGY200@0WW]309eiA@2NNTH0X7a80`2ROTX01@2QODT0X7a80:9nCP2ROTh0Xgm?
0080Y81@00<0YH5A0:J2DP2VPU800`2ZQU820:^7D`<0[8QD0P2ZQU@20:^7E@@0[8QF0P2_R5d01P2^
R5/0[XQI0:f7EP2]R5@0[8MC0:b7DP80ZhEF0P2/QUL20:f7F080[XQI00H0[hQ?0:n8D@2_R540[hMC
0:n7E02_QeH20:n6F0P0[8QD0P2]RET30:b8F080ZhMG0P2ZQUH30:Z6E0030:^7E@2/R5H0[8QF0080
[HUG00/0YX5D0:N2E@2XPeH0ZHAG0:^6F@2/QeX0[HQK0:j9G02[QUT0ZXEH0:V4E`020:R3EP040:V4
E`2ZQEP0ZhII0:b6G`80[8MM00<0ZhIJ0:^6F@2[QeL00P2ZQU@20:R3EP@0ZHAG1@2ZQEP20:V4E`<0
Z8=F00D0Yh5D0:R2E@2XPUD0ZH=F0:^5F0020:b6F@030:f7FP2[QEP0ZhEH00H0ZhEH00D0YX9B0:N3
D`2WPe<0Z8AD0:Z6EP020:^7E`040:b8F02YPe@0ZH=D0:V3E080ZXAE0`2[QEH00`2[QUT0ZXEH0:R3
EP020:N2E@030:R3EP2ZQEP0ZhII00P0ZhEF0P2XQ5@20:V5E@@0ZXIF202YPe@80:V3EP80ZhAI00H0
ZXAG0:V3E02XPU40Yh9>0:J1C@2UP4/30:J0D@030:N1DP2XPU<0Z89C0080ZH=D00/0Y7i?0:J0D@2W
PE80ZH=D0:Z4E@2YPe@0Z89C0:N1DP2SPE40Y89B0:J4E0030:N5E@030:J4E02UPe<0Y89B00P0ZH=D
00<0YX1A0:N1DP2WPE800P2XPU<20:V3E0040:Z4E@2[QeL0ZhMG0:Z6EP80ZHEE00<0Z8AD0:N3D`2W
Pe<02@2YPe@20:R2D`80Yh5B0P2VP5400`2UOe00Z7e@0:QmD0060:QmD0030:EoD02TOTl0Y7i?00D0
Y7i?202TOd/20:EjC@80Y7U<0`2SN4/0102RMdX0XG]<0:1jB`2ONDX209ihB@0509miBP2PNT/0XG]<
09mjAP2PNdL0102QO4P0102PNdL0WgY609mjAP2ONTH209iiA@<0WGQ400<0W7M309Ye@@2JMD400`2I
M40309Qc?`P0Ug500P2EKch309Ma@00409E_?P2CKC`0TV`k09I`?`<0UFln0P2DKSd209=]?00809=_
?`2BKSh0T6`l08m[>`2>JSX0Sf/k091/?02AKCd3099^?P80TFdm0`2@K3`208mU>`@0T6Hl0`2AIcd2
091/>080Sf/g0`2>JSH0102=JCD0SVDg08mV>02@IcT2099Y>`03091W>@2?ISP0SVDg0080SVL`00<0
SVHb08eU<P2=IC@00P2<HcD00`2<HcL0QV0c08IP<`0608IP<`0808=M<027HC@0RV@g08QR=@24GS40
PU`_08EO<P28HSD208MQ=00408IP<`25Gc80QElb08AN<@80Ped`0P24GC@208=L<`<0PU/b00`0PEXa
07mL<P1oG380OU/a07eJ<01nFc40P5dc085N=023H3H0PU/d085J<`20FC8307iG<080OePa0P1mF2`0
101lEb/0NeHZ07YE:@1iE2P207QC9`0307]H;P1jEbd0N5D[0080MU<Y00<0Me@Z07QE:`1iER`00P1e
DBl0101dD2h0Ldl]079>;01aCB/2071<:P<0MDdZ0P1dC2T307=;:008079>:P1`C2P0KTXV06e99@1/
B2@0KDTU06i:9P1_BbL306]99080JTPS0`1YAb8306U89@80J4LT0`1WAR<806U8:@0606A7:@1SARP0
HTDW06549P1O@R@0GD0R0P1L?b4305do8`80G3hR101K?B4805a1900405e29@1L@B@0G44T05a19080
Fd0S0P1J?b8805Dm8`80DchS0P1B?B80101A?240D3/P050k801@>b0804lk8`08050m7`1@?240Cc/P
04hj8@1=>B40C3LR04/f8`1:=B8304dg7`80CSPP0`1?>B40101?>b00D3`Q050l8@1@?242054m8P80
DShS0`1<>R@204/i8`<0BSPR00<0BcTS04Xh8P1:>2800P19=b4204Pf800404Le7`1:=1l0BS@O04Xe
8080BCLQ00<0AcLP04Df7`14=Ah00`11=242040c80<0?c8O0`0i<Ql203Xc80<0>c@Q0P11=2401P12
=B80@cHS048e8P10<b00?S4N03`_7080?c8O0P0n<Ah303d`7@0303`_700l;R40?2hQ0080>bdP0`0j
;1l01`0i:ah0=RhQ03D]800d;1l0<b/N038Z7@0a:A`00P0`:1/8038Z7@T0;R/L1P0[9ah202XV7@<0
9BDM3@0V9Qh0200X:B409bPP02DV7P0T9Ad08b@L02@U7@0U9Qh09RLO0`0T9Ad00`0U9Qh09RLO02HW
7`0202LX80P09BLJ200S91h3028S7@808B8L0`0P8A/;01lQ7R_ooooo000Zooooo`P0UFXm0P2IKT42
09Q]@00=09M/?`2FJch0UFXm09EZ?@2HJd40V6`o09U]@02IKCh0VVhm09Y_?02JKcX0Vg0k09U_?@02
09Y`?P0;09]a?`2LLT00WG=109ec@@2NM480X7E209md@@2NLd00WG8o09]`?@2JKc`00P2HKCX209U_
?@<0VW0n0`2KLCl00`2MLSl0WW=009md@@020:1e@P0309md@@2NLd00WG8o0080WgE300<0WWA209ec
@@2LLT000P2KLCl00`2JL3h0WgI209mf@P020:1g@`80XGQ40P2RNDD20:MgAP@0YWI50`2UMD@30:=g
AP80Y7Q70`2UNDP30:=hA@80Y7U60`2UNTL0102TNTP0XgU70:=iA`2SNDL20:9hAP80XGM500@0YG]9
0:IlBP2WOD/0Z7i<0P2WOD/00`2VO4X0YG]90:ImB@070:ImB@<0YWe70`2WOTP20:QoB@060:MmB`2V
O4X0YWa:0:EkB@2TNTP0XgU70P2RN4H20:AkA@070:=jAP2QMdD0X7I609mdA`2NLdH0WG9709aaA003
09ebA@0:09]`@`2IKT40Uf`o09EZ?@2DKSl0Tfdn099/?@2@JS/0SVPi08eW>080RfDf0P2;IST00`2:
ICP0RF@g08QS=P0208MR=@0508IQ=01nFc40OEX`07]H;P1iER`00P1hEB/207UF;00907UF;P1jEbl0
NeP`07]H<01jEbl0NEH^07QE;@1gE2`0ME@a0080M5<`00<0Le8_079A;P1aD2d00P1`Cb`0201_CR/0
L4l/071?;01aD2d0L4l/06m>:`1^CBX0KD`Y101_CbP406i>9`80MU8^00H0Me@^07UF;P1jEbd0NeT/
07aJ;@1mFbd207eH;P80OUT_00@0OeX`081K<@21G380PE`b0P23GC000`25Gc80QV0c08QR=@0208YT
=`0408]U>02<IST0S6Hi08aV>@<0SFLj0`2>J3/208eS<@<0SV@b0`2?IC<8091V=0<0TFHk1@2@ICX2
08]P=P0308]P=@2;H3<0Rf4a0080Rf4_00<0Rf8^08YT=`29HcH00P29HcH01028HSD0Qf4d08MQ=027
HC@808US=P<0R68e0P29HcH308YT=`0308UN<@2;H3<0S64d0080SF8e00@0S64d08]P<`29GS40RUlb
0P2;H3<01@2<HC@0SF8e08iS=P2>HcH0Sf@g00P0RfDf0`2=IcP208aV=`<0RfDf00@0SV@b08mU<`2?
IC<0SfDc0P2@IS@2095W=@0408]V<P2<Ic<0S6Lc08aW<`80SFPd0P2>JCD2099W>P80TFHi00@0T6Dh
08mT=`2>HcH0SV<f202>J3T808eW>0P0SVPi00H0T6@g08mT=`2?I3L0SVDg08aV=`2;IcL308UW=`80
RfHi0`2:ICP308UT=`P0RV@g2029I3L808MR=@0808=N<@25H3<0Qf8e08IQ=023GS40PUd`08AO<P27
HSD308MS<`80QV8b0`25HC4208=N<@<0PUd`1021G2l01020Fbh0OUT/07eH:`1lEbX207eH:`0707iI
;01kF2h0NUL]07YG;@1iER`0N5D[07MD:P0207IC:@0807=D:01bDbL0LE4X071@:@1_CbT0KD`Y06a;
:01/BbX2069;8P0406598`1QBBD0H4PT06189P80GdHW00P0G4PW05Q48`1D@B40DD0R05=29P1B@RP0
CClT04Tk8@80AC`O00L0AC/P04@j8@12=b40@3DQ03db7P0l<Al0=S4M0080=S4N00<0=S0P03H`8P0f
<2@00P0f;bD3038_8080<BhO0`0`;Ah3030/8080;b/O0`0^:Qh:02PZ7`809bTN0`0V:1d00`0U9a`0
9RTP02DX7`0202DX7`8092LN4`0S9Qd8028U70<08RDJ0P0S9Q/<02@W70<09BPM0P0V:Ah202LZ7`03
02P[6P0Y;1/0:RdL0080;2lN00h0:RdL02T/6`0X:aX0:R`N02T[7@0X:Q`09bTK02PZ700Y:ad0:bdO
02`^800/;QT0;BlJ02h`6`80;c4L00<0;S0K02d_6P0/;QT00P0a;Q/3038_70<0<c0M0`0j<Qd203/c
7P<0?3@O0P0h=1T0100i=AX0>SHK03/g700k=a`203`h7@0603le6P10=Q/0@3HK044g7012>1d0@cTN
0P14>Ql804<i7P80ACXN0P16>al204Ll8080B3dQ0P18>1h204Ti7`80BSXP0P1;>b401P1;>R00BSXP
04Xj8019>b00Ac`P04Hm8080A3dP0P14>ah204Dl7`<0ASdP00@0AchQ04Ll8018?B40BChR0`1;@2@2
04Xo8`<0Ac`P00<0B3dQ04Tn8P1:?b<00P1;@2@00`1<@BD0BD0O04U07`0304Po7P<0AchM0P1:@B@2
04U08`80B3lR0P17?R401@17>Ah0B3XO04Hk7`15?1l0A3dP0080@chP00<0@SlP048k8@12>b400P11
>R04040i7`80A3XO00@0@cTN048h7@12>1d0@CLL0P10=Q/3044g7080@SPM0`13>Ah804@j7`P0@SPM
00H0ACTO04@h7P13>Ah0@3TM03hi700l>1/203Th6P0303lh7P0n=ad0?SLM00D0?SLM2010>Al803hg
7@80@CXP0P10>Al203lh7P80?SLM4012>1l304<g7@<0A3PN0P15>Al01P19>1h0B3PN04Ph7P17>Ah0
ACXN04@k7P80@S/N2012>A`904<i7P06048i7014>Ad0A3TM04Li7P19>Al0BcXP0P1>>R40301=?bD0
C3hS04dm8`1>?B40D3lQ05A18@1G@b80FDDT05a67`1NB240GdTR065;90@0HT`U0P1ZCb@03`1[D2D0
K54V06iC:01_E2T0L5DZ075F:`1bERH0LeLW07AH:01eFBT0Me/[07QL;01iGBd0NUh^07mP<@0207iO
<00807eN;`1nGc00Of0a085R<`22Hc@0R6@`08UU<@2:IS8308aX=080RfLc0P2>JSH00`2?JcL0T6`h
095]>@02099^>P0309=_>`2EL3`0UW4m0080UW4m0P2GLSh209Qc?`0609Qe?`2IMT00VGI009Yg@@2K
N480W7U30P2MNT@00`2MNDD0WWY60:1lB0030:9nBP050:5mB@2PO4P0XWi>0:9nCP2SOdl00P2TP500
0`2UPE40YX9B0:J2DP020:V5D@80ZXIB0`2[Qe<0102/R5@0ZXIF0:Z6EP2ZQUH20:^7E`<0[8QH0P2^
Qe`01P2^R5/0[HMH0:f7EP2]R5@0[8MC0:b7DP80ZhEF0P2/QUL20:f7F080[XQI0P2]R5400`2]R5<0
[HQD0:f7EP020:f7F0030:f7FP2/R5@0[8QD00H0[8QD0P2]RET30:b8F080ZhMG1@2ZQUH20:^7E`<0
[8QH0`2YQ5L0102ZQEP0ZhII0:^6F@2[QUT30:b7FP@0ZXEH0P2/QeX01P2/QUl0[8MM0:^6G02[QUX0
ZXEH0:Z6EP80ZHEC0`2XPeH20:V4E`H0ZXEH0P2YQ5L30:R3EP80Z89E00@0ZH=F0:Z4E`2ZQ5L0ZhEH
0P2/QUT80:^5F080Yh=C00@0Z8AD0:V5E@2YQED0ZXIF0P2[QeL30:V3E080ZXAE0`2[QEH00`2[QUT0
ZXEH0:R3EP020:N2E@030:R3EP2ZQEP0ZhII00P0[8IG0P2YQED20:Z6EP<0ZhMG00<0[8QH0:R2D`2X
PU<01P2XPU<80:R2E@80ZX=H00<0ZH=F0:R2D`2WPE000P2VPDd0102UP4/0Yh5B0:N1DP2WPE830:R2
D`80ZH=D00<0YGm@0:J0D@2XPU<00`2YPe@20:R2D`030:J2DP2WPe<0Z8AD00<0ZHEE00<0Z8AD0:N3
D`2VPU80202YPe@20:J0D@80Yh5B102XPU<20:Z6EP030:V5E@2XQ5@0Yh=C0080YX9B00<0YH5A0:N1
DP2WPE801P2WPE830:J0D@<0YGm@0P2TOTl80:IkCP80Xge>0P2RO4d0102QNd`0X7Y;09miBP2ONDX8
0:5lB0040:=hB`2RMdX0XWM:0:9gBP80XGI90P2PMDP00`2ONDX0WWQ909afA`0209]eAP0609afA`2N
N4T0WgU:09iiA@2MN4@0W7M30P2KMT800`2LMd<0WGQ409iiA@0209ag@`80VgI20`2JMD400`2IM400
V7<o09Mb?P0209Mb?P0409Ia?@2EL3`0UG0l09E`?0P0U6ho0P2?JCX3091Z>`0308iX>@2=IcP0S6Hg
00<0TF/l0P2@JS/308mY>P0308eX>`2<IcX0RVDh00<0R6<f0P2:ICP308iY?080SFPk0`2<IcX308QQ
>0<0RF8i0`2:HcX0102=JCT0S6Ph08aX>02<J3P208]W=`80RVHf00<0QElb08IP<`28HSD00P29HcH0
2@28HSD0QV0c08EO<P27HRd0Qf8^08IQ;@25Gbh0Ped^089L;`02085J;`P0Pehd00h0P5/a089M<`24
GcD0Pehd085L<P20Fc40PUdc08AO=@22GC<0PE`b081K<@1oFS00OUT_07aG;@80NeH/0P1mEc0307aF
;`<0NeD^00T0NUL_07UF;P1hEBd0Me@/07QE;@1iERh0NeP`07aI<@1kEC000P1lES401@1mEc80O5Ha
07]E<01jE2l0NE<^0080Me@/00@0MU<[07EB:P1dDBT0M54Y0P1cD2P00`1dE2d0Le</075A:P0306m?
:080LE4Z00H0K4/Z06]::@1[BRT0JTTX06U89`1XAbH206M69@0406]79`1ZARH0JTHV06Y69P80JDDU
0P1XA2@01@1WARD0ITDT06E48`1T@b80Hd8Q0080I4<R00<0ID@S06538@1Q@b400`1P@R0305m17`80
HD@T0P1P@b<205m28P80GT4Q201P@RH0201I?b@0F3hS05Lm8P1F?240EC/P05@j7`1C>Ah0DSPM0P1C
>B83058h8@@0DCLP201A>B4305@l9080Dc/S0`1B>R8804hj8P0404Xh8019=al0BCLO04Tg7`<0B3HN
00<0AcDM04Pf8018=R001P18=R002019>1h0B3LM04Pf7P17=Al0AS@P04Db8@14<B00A34R0P14<Q`3
04Dc7@<0AS@N0`18=Qh204Tg7`<0BSPP0`16=B<204Dd8P<0A3<Q00@0AC@R04@c8@14<b40A3<Q0`13
<R002P12<Al0BC@S04Pc8P14<B00@C0N040a7P0m<1d0?S4N03db7P0l<Al303/`7P80>RlM0P0i;Q`3
03@_7080=C0M0`0f<Ah0200m<R00?S<Q03hc8@0m<R00?34O03X_7@0h;A/0=b`J0P0h;A/203L/6P80
=R/I0P0e:QP0100h;200=b/O03L[7`0g:al203HZ7P80=BTM0P0a:al00`0`:Qh0;bTM02hX700202dW
6`0302`V6P0^:1`0;RPL00H0;RPL2@0[9a/802XV7@809RHN1@0U9Ad00`0V9Qh09BDM02DU7@0602DU
7@0302HW7`0U9Qh092DM00<08R<K0P0S91`0100R8a/08b@L02<T700S91`302@U7@0302DV7P0S9AX0
8bDJ00H08bDJ200S91h3028S7@808B8L0`0P8A/801lQ7P<07R0M:oooool002[ooooo202FJch209U^
@@80V6e00P2GK3l209I[?P0609U/@P2IKD00VFe009Y^?`2JKSd0VVll0P2KL3/209Y`?P80Vg4o0P2L
LT0209ec@@0509ib@@2MLD00WG5009ea@02LL3l00`2KKch209U_?@<0VW0n0`2KLCl809ic@0<0WWA2
00<0WG=109ab@02LLT000P2KLCl209mf@P80X7M30P2QN4@20:9iA@80YgM6102VMTD30:EeA0<0XgM6
0P2TN4L30:EiB0P0Y7U60P2TNTP30:=iA`<0XWQ600<0YG]90:MmB`2YOdd00P2ZP4h00`2XOT`0YG]9
0:=iA`0;0:ImB@<0Ygi:0P2XOd/01P2XOT`0Yge;0:IlBP2UNdT0Y7Y80:9hAP80XGM50P2SNT@0202R
NDD0X7I409meA@2NLdH0WG9509aaAP2JKd80Vg130P2LLD@0302KL4<0VFi109I[?P2EJSd0UFm009A^
?`2BK3d0T6Xk08iX>@2;ICH0RV@e08US=080RVDh00<0RF@g08QS=P27HSD00P26HC@01025H3<0P5dc
07iK<@1kF2h307QE:`0307YG;@1lFBl0NUL_00<0NUL_00D0NEH^07QE;@1hEBd0Me@/07AC<00207=B
;`80LU4^0P1aD2d5071?;080Kdh[0P1^CBX3071@:@80KdlX0`1^CRL0401eDBd0MU8^07MD;P1hEBd0
NUL]07]I;01lFRd0O5X/07aG:`1mF2`0OUT]07mJ;P21G300Pehb08AO<`25H3@208EO<P0308IP<`28
HSD0RV@g0080RfDh00@0S6Hi08eW>P2<IST0S6Hi0`2=IcX308iX>`80S68`0`2=Hc4308iT<PP0SfDc
0`2@ICX2095V>`<0TVLl0P2;H3H00`2;H3D0Rf0c08]Q<@0208]Q;`0308]R;P2:I3L0RV@g0080RF<f
00@0R68e08MQ=027HC@0QV0c2029HcH408QR=@@0RF<f00<0REha08]P<`2<HC@00P2=HSD00`2<HC@0
Rf0c08UN<@0208]P<`0608aQ=02=HSD0Sf@g091U>02AIST0TVLj202;ICH308eW>080S6Hg0`2;ICH3
08mU<`80T6Hd0`2AIcD308aW<`80SFPd0`2>JCD01P2DJC`0TfPk099W>P2AIST0T6Dh08iS=P80SF8e
202>J3T808eW>0P0SVPi00H0TFDh091U>02@ICP0SVDg08aV=`2:ISH308QV=P80RfHi0`2:ICP308UT
=`P0RfDf2029I3L308QS=P@0Qf8e00D0QV4d08AO<P25H3<0QV4d08EP<`0208AO<P80QF0c0P27HSD2
08IQ=00408EP<`24Gc80Peha08=N<@80PV0b0`21Gc43081N<00307iL;`1mFbh0O5X]0080NeT/0`1j
F2/207QG;00407MF:`1fEBX0ME@Y07ED:@80M5<X0P1`DbL0301_DRP0KE0X06a>:01ZC2P0JD/W06U;
:@1QBb80H4XS061:9@1OBB@0GTLU05i79`80GDHW00P0GDPY05M4901A@280D3lS05519`1?@BH0BCdS
04@h7P80@S/O00L0@CXP03lg800m=B00>c<P03Xb7`0i<1l0<BlJ0080<BhK00<0<BhM038_800b;R80
0P0c;b@2038_8080<BhO0P0`;Ah202l/7@<0;R`O0`0]:ah202`Z7@P0:2XO0`0W:Ah302HX7@809BLL
0`0U:1l202@W7P`08bHM0`0R9A`402<V7@0302@W7P0R9A`08RDL00H08RDL0P0R9AX202<V6`8092LL
3@0U:1d202HY7P<09bXO00<0:2/J02T/6`0Z;A`00P0/;ah0300Z;A`0:B`K02P[6P0Z;A`0:B`K02P[
6P0W:QT0:2/J02T/6`0[;Qd0;C0O02h`6`H0;c4L00<0;S0K038_700b;a`00P0c<1d403@a7P0403Pa
7P0i<Ql0>C8O03Tb7`80>S<P0P0k=2401P0g<aX0>3@K03Pd6`0i=A`0>SHM03/g7P80?3PO00<0?3DK
03df700m=Q`00P0n=ad203lh7P03040i7`13>B00@cTP00H0@cTP1013>Qd204@k7P80AC`O1016>1d2
04Li7P80B3XO00H0BCTO04Pj7`18>Ql0AS/O04Dl7`13?1l2048m7`80@cXM0P14>ah304Dl7`0404Hm
8018?B40BChR04Tn8P80BSlS0`1;@2@204Ll8080B3dQ0P19?R8204Xo8`0304]09018?ah0B3lN00@0
B3lN0P17?Qd204]29@80BT4T0`19@2<02@18?b80B3XO04Pj7`17?200ASdP04Dn8@15@280AT4S04E2
8`04048k7`@0@CXN00P0AS`Q04Dk8014>Ql0@cTN048h7@11=a`0@3HK03le6P80@CLL0P12>1d204<i
7PX0A3XO2013>Ah0201:?280Ac/Q04Hj8013>Ah0?cPL03dh6`0k=aX0>SHI0P0m=Q`303hg7@<0?cPN
2010>Al803hg7@80@CXP0P10>Al203lh7P80?SLM4012>1l304<g7@<0A3PN0P15>Al01P19>1h0B3PN
04Ph7P17>Ah0ACXN04@k7P80@S/N2013>Qd904<i7P06044j7@13>Qd0@cXM04Dj7P18>Ql0BCTO0P1;
>R003P1<?R@0BcdR04`l8P1=?200CchP05=0801G@b80F4@S05]5801LAR40GDLR05m9901PBRD0HD/V
0P1RC2L0201VBR80Id/S06U=9@1[CbL0KE4Y06mC:`1`E2`0LED]0P1bERH01P1cEbL0M5PX07IJ:P1g
Fb/0N5`/07UM;@<0OEh_0P1nGc000`1oH340P64b085R<`0208QT<080RFDa102:IS8208eY=@0308iZ
=P2?JcL0T6`h0080TFdi00<0TVhj09E`?02EL3`00`2FLCd309Mb?P<0VGE100<0VWI209]g@`2KMd<0
0P2LN4@00`2MNDD0WWY60:1lB0030:9nBP050:5mB@2PO4P0XWi<0:9nC02SOdd00P2TP4h00`2UPDl0
YX9@0:J2D0020:R4D080ZHEA0`2ZQU800`2[Qe<0ZHAG0:V4E`020:Z5F080ZhII0P2/QeX20:f6F`06
0:f7FP2]QeP0[HMF0:f8E02/Qe<0[8MB0P2[QEH20:b6E`80[HMH0P2^R5T20:b9D`030:b8E02/R5H0
[8QH0080[8MJ00<0[8MK0:b8EP2/R5H01P2/R5H20:f9F@<0[8QH0P2[QeL20:Z6EP@0ZXEH1`2[QUT5
0:Z5F0P0[8MJ00P0[8IO0:^6G02[QU`0ZXEI0:V4E`2XQ5@0Z8AB0:N3D@80Yh9E00@0Z8=F0:V4E`2Y
Q5L0ZXEH0P2[QUT30:Z5F080ZHAG0`2XPeH00`2XPUD0ZH=F0:V3EP020:Z4E`80ZhEH00<0[8II0:Z4
E`2ZQ5L01P2ZQ5L00`2WPe<0Z8AD0:R4E0020:V5E@80ZXIF00@0ZhMG0:V3E02YPe@0ZH=D0P2ZQ5D3
0:^5EP030:^6F@2ZQEP0Z8=F0080Yh9E00<0Z8=F0:Z5F02[QUT0202/QUL30:Z6EP80ZhMG0`2/R5P8
0:R2D`P0Z89E0P2XPEH01P2XPUD0Yh5B0:J0C`2VPDd0YH1<0:F0B`@0Yh5B102XPU<20:J0D@030:N1
DP2XPU<0Z89C00<0Z89C00<0Yh5B0:R2D`2YPe@00P2ZQ5D0102YPe@0Z89C0:J0D@2UOe080:N1DP80
YGm@1P2VP5401P2XQ5@0Yh=C0:N3D`2VPU80YH5A0:B0D080Xgm?202TOTl50:9lC@<0XG]<202SN4/0
1P2QNd`0X7Y;09miBP2NN4T0W7I709]eAP80VWA5202LMTD0102NMDL0WGA609edAP2MM4H209acA@80
Vg9400<0VgE609YdA@2HLT<00P2GLD801P2HLT<0VWA509]eAP2JM4<0VG=209I`?`80U6hm00<0UW0o
09Uc@P2JM4<00`2GLD0209I`?`<0UFln0P2DKSd0102CKC`0TV`k099/>`2AJcX2091Z>@P0SfTl1@2;
ICP00`2:I3L0RF<f08US=P0308]U>080RV@g0`29HcH00`29I3P0R6<g08IQ=@0308AO<`80QV4e0P29
I3P208QS=`<0Qf8f00@0QV4e08AO=@24GcD0Q5le0`25H3H308IQ=`<0Qf8f0P26HCD308EP=003081K
;`21G300Pehb0080Q5lc00<0Pehb085L<020Fbl00P23Gbd01P21GBd0P5/^07iI;@1lEbd0NeD^07YD
;@P0O5Ta00<0NUL_07]H<01lFC400`1kF300201lFC40OEXb07aI<@1lFC40NeP`07UF;P1hEBd0MU<[
0P1eDRX307MC;`80MU8^0`1eDBd00`1eDbh0M58]07=A;002079@:`0607=A;01eDbh0MU@_079>;01d
D2h0MU8`0P1gDc400`1dD2h0LTh/071<:P0206m>:`0306i=:P1]C2T0KD`Y00<0K4/X00T0JTd[06U<
:P1WBRP0ITTW06E89P1VBBL0IdXX06Q;:@1TAbT00P1SARP00`1RABL0HD@V06139@0205m290<0HD8V
0P1P@BD305m09080GT0T00<0GClS05`n8P1L?R800`1L?R8305Po8@80EchP0`1F?Al0101F?R80ECdQ
05Dm8@1E?B4205@l8080Dc/O201E?B<204lk8`0404hj8P1=>B40C3PP04/g7`80BSHN0`1:=B0204Td
7`@0B3<N2015<ad304Pf8080AcDO0`16=1h804Dd8PD0?S4N0`0m<1d803l`7@80@34J00H0@34L03l`
7@0o;al0?RhN03h^7`0m;Ah303X]7080>bhM0`0l;ah0100o<1d0@34N040a7P10<Ah2044b7`80@S<P
0`0m<1l203`_7P<0>bhM0`0l;ah503/^7@0904@c8`11<200?BdM03P[6P0e:QP0=2`I03D]6P0f;a`0
=B`M00<0=2/L0P0c:Q/2038Y6P<0;R/L0P0_;1d3030]7P0303@[6P0e;1/0=B`K00D0=RdL0`0c:Q/2
038Y6P<0<BPI0`0a:Ah2030X7@<0;bLL0P0[9a`202XV6`0402TU6P0X91T0:2@I02PT6@P0:BDJ2@0W
9AT00`0W91/0:2DL02PU700202PU70<0:BHM00H09bLO02HV7P0U9Ad092@L02<S6`0T91`:02DU7@04
02@U7@0S91`08R<K028S6`@08B8J200R8a/8024S60P08b@N0`0R8ad2024R70<0824K200O8Ah301hP
7B_ooooo000Zooooo`P0Uf`o0P2IKT4409Q]@080Uf`o00H0VFa209U]@02JKT40VVho09Y^?@2KL3d2
09]`>`@0Vg4o102LLT0209U]?P0609]_@02LL440WW9309mcA02PM4D0XGE60P2IKcd309Y`?P<0Vg4o
0P2NLd0409eb?`80WW=000<0WWA209ec@@2MLd400P2MLd4309ab@080WgI20P2PMd<20:5hA080XWU5
0P2WMdH40:IfA@<0YGE40`2SMdH20:AhA`<0YGU8202TNDH30:AjB0<0XgU70P2RN4H0202VO4X0Yge;
0:UoC@2[PDl0ZX1>0:QnC02UNdT0XgU72`2VODT30:MnBP80Z7m;0P2XOT`01P2WOD/0YG]90:=iA`2R
N4H0XGM50:1fA080XWU300L0XGQ40:1fA02NM4@0WG9509aaA02KL4D0VFi10080VVm200d0Vg1309Y_
@P2HKD00UV/n09EZ?@2DKSl0Tfdn099/?@2?JCX0SFLh08]U=P29Hc@0R68c0080RF@g00<0R6<f08MR
=@26HC@00P25H3<01@24Gc80Pf0f085N=01nFc40O5T_0080NeP^00D0OEX`07mL<P1jEbl0NUL_07UF
;P0507QE;@@0LU4^1@1aD2d2071?;080Kdh[0`1^CBX4071@:@@0KdlX0P1cCb/01P1dDB/0ME8Z07MD
:P1hERT0NELZ07YH:P80OEP[00H0OeX]085L;`23GS40QF0c08IQ=027HSD208MQ=00308QR=@2:I3L0
RfDh0080S6Hi0P2=IcX208aV>@<0SFLj0`2>J3/208aR<0<0SF<a0`2>I38808mU<`@0T6Dj0`2AIS/0
1P2BIc`0Rf0f08]P=P2;H3D0Rf0c08]Q<@80Rf4_00T0Rf8^08]U>02;ICP0RV@g08US=P28HSD0Qf4d
08IP<`25Gc804028HSD00`29GS40Rf0c08aQ=00208eR=@0;08aQ=02;H3<0REha08]P<`2<HC@0SF8e
08iS=P2?I3L0T6Dh095V>@2BIcX0202;ICH308eW>080S6Hg0`2;ICH208mU<`80T6Hd0P2AIcD2099X
=P80S6Lc0P2=J3@208iY=@80SfXf00H0U6Tl09=X>`2BIcX0TFHi091U>02>HcH208eR=A00SFLh202:
I3D01P2AICP0T6Dh091U>02>ICL0S6Hg08YV=P<0R6Hf0P2;IST308YU>0<0RF@g202;IC@:08UT=`80
R6<f00@0Qf8e08IQ=026HC@0QV4d0P25H3<208AO<P0408EP<`26HC@0QF0c08AO<P80Qf8f00H0QV4e
08EP=024Gc<0Pehb089M<@21G302085Q<P<0P60a0`1oGc0307aK<00307]J;`1jFBh0NEP]0080MeH[
0P1fERd0101eEB`0M5@[07=C:P1bDRT2075A:080KU<V00`0KE8W06]?9`1ZCRL0J4`W06M;9P1WBRP0
Gd`T05i:9@1MBB@0G4PU05]79P1JABH205U49`0F05U6:01C@R@0CchR04dn8@1=?b@0BShT04Dk8P11
=ah0@3XP03li7`0n>200?3HP03Xc800h<Ah0=c0N03L`800^;AP0;RdI02l^6P0_;Q`0;bdN030^8@80
<2hR0`0a;Ql2030]7P<0;b`M100[;1h202X[7@80:BXL2P0W:Ah302HX7@<09BLL0P0U:1l202@W7P80
8bHM2`0R9A`3024T6`03028U700S9Qd08bHM008092LN200S9Qd302<V6`8092LL3@0U:1d202HY7P80
9bXO0P0X:b000`0X:aX0:B`K02X]700202`_7P0602X]700Y;1/0:2/J02/^6`0Z;AX0:B`I0P0X:aP0
100Z;AX0;2lL02d`7@0`<Qd602la7003030b7@0b;a`0<RlL0080<c0M100d<Ah303Ha7@80=c8N0`0h
<al203Ha6`0303Lb700h<ad0>C@N0080>SDO00<0>cHP03Xd700j=1`0100k=Ad203`f7PP0@CHP0`0o
>1`3040i7@80@CXN0`12=Q`304<g7@80A3PN00H0ASPN04@h7P14>1h0@cTN044j7P10>ah203lk7P04
048h7@13>Ah0@cTN04<i7P80A3XO0P15>b0404Pm8@80BChR0P1:?b<504Pm8@@0BChR0P17?Qd604Po
7P80Bd8U0P1:@B@304U08`0604Po8P18>Ql0B3XO04Ll8017?R40ASlR0P16@B<00`16@b@0@S/N048k
7P02048k7P@0@c`O0P16?2401015>b00A3XO048h7@11=a`2040f6`<0@SPM0P13>Ah;04@j7`P0@cTN
00P0C3`S04/m8`19>b40ACTO048h7@0n=a/0?3LJ03/f6@80?CHL0`0n=ad303lh7PP0@3TO200n=ad2
044j8080@3TO0P0o>1h203hg7A00@SPO0`13=ad304@h7P80ACTO00H0BCPN04Ph7P18>1h0AcTN04Dj
7P14>ah2048k7PP0@cXM2@13>Ah04010>ad0@CXM044j7@14>ah0ACXN04Li7P18>1h0BCTO04/m8`1:
?240Bc/Q04`k7`1>?Al0DSlO05I28@1G@b8205Y47`0>05]5801LAR40GTPS061:9@1QBbH0HT`W06A8
8@1UBB80Id/T06U=9P1/D2T0KU8[071D;@1aEBh2075E9@06079F9P1dF2P0METY07IJ:P1gFb/0N5`/
0P1kG2d00`1mGRl0OUl`07mP<@03081Q<P@0Qf<_0P28I30208UU<@80S6Pd00<0SFTe08iZ=P2?JcL0
0P2@K3P0102AKCT0UG0l09E`?02EL3`309Ia?@80Ug8n0`2IMD<409YfA00409]gA@2MNDD0WWY60:1l
B0<0XWi:00D0XGe90:1lB02ROTX0XWi:0:=oB`020:B0C0040:F1C@2VPTh0YX9>0:N3C`<0Z8A@0P2Y
QE420:Z6DP<0ZHAH0P2ZQET30:^6FP80[8EJ00H0[8II0:b6E`2/QUD0[8MC0:f8E02]R5<20:^5EP80
[8IG0P2]QeP20:j8F@80[8QD00<0[8QF0:b8F02/QeX00P2/Qe/00`2/Qed0[8QH0:b8F0060:b8F080
[HUI0`2/R5P20:^7E`80ZXIF202ZQET01@2/QeX0ZhII0:^6F@2[QUT0ZXEH00<0ZHAG202/QeX01P2[
QEh0ZhIL0:Z5F`2YQ5P0Z8=F0:N3D`80YX9@00D0YX5D0:N2E@2WPUD0Z8=F0:Z5F0020:^6F@040:b7
FP2ZQEP0ZXEH0:Z5F080ZHAG0`2XPeH20:V3EP@0ZXAG0P2[QEP80:Z4E`80Z8AD102YQED20:Z6EP<0
ZH=D0P2ZQ5D30:^5EP030:^6F@2ZQEP0Z8=F0080Yh9E00<0Z8=F0:Z5F02[QUT0202[QEH0102YQED0
ZXIF0:Z6EP2ZQUH20:^7E`80[8QH202WPE880:N1E0050:N0E@2VOe@0YX1C0:J0D@2VP4l00P2UP4`0
0`2UP4/0YX1A0:J0D@060:J0D@@0YGm@00@0YX1A0:N1DP2WPE80Z89C0P2XOe401`2YP580ZX5C0:Z1
D`2YP580Z7mA0:ImC`2TNdd0202TOTl70:=mCP070:9lC@2TP500Xgm?0:=oC`2ROTh0XGe=0:1lC002
09mkB`P0X7Y;00<0W7I709egB02MMdP01@2MMdP809mdA`80W7I700H0VgE609YdA@2HLT<0Ug5209I`
@@2EKd0809Ma@P<0UW110P2EKd0309A^?`0309I`@@2EKd00Tfdn0080TV`m00H0Tfdn09E_@02FL440
UFm009=]?P2AJc`208mY>P03095[?02CKCh0UFm00080TF/l0P2@JS/308mY>P0908iX>@2?JCX0SfTj
08iX>@2=IcP0S6Hg08]U=P2:I3D0RF<d00P0RF8g0P2:HcP00`29HSL0R64f08QQ=P0308QQ=P<0QEhc
0P24GC8308=L<@0308MR>025H3H0Q5le00<0PUdc00<0Pehd08AO=@23GS@00P23GS@2089M<`<0PE`b
0`22G3D308=M=P<0Q5hg00@0PE`b081K<@20Fc40P5/a0P1oFS0307iI;`0?07mJ<021G380PUdc089M
<`21G380OeX`07iI;`21G2l0P5/^07mJ;P1mF2h0NeD^07UC;P1hDRh0Me4]00P0ME<^00H0Le4/079@
:`1bD2/0Le4/07EC;P1fE2l207EC;P80MeD`00<0MU@_07EC;P1dDRd00P1bD2/00`1aCbX0Le0`07=@
<002079?;`<0LDh^00@0L4d]075@;`1`Cbh0Kdh]0P1]C2/01P1^CB`0L4l^075@;`1ZAbT0K4T[06i;
;@80Kd`^00<0KDX/06Y7:@1XABL00P1TAbL306=69P<0HTDU00<0HDHY0615:01N@bH00`1L@B@205i3
9P0605m4:@1N@bP0GT<X05e29`1L@BH0Fd0U0P1J?b@0101J@2T0FClX05To:01I?bP205Pn9`80EcdV
101F?RH0101E?BD0E3`T05@l901C>b<2054m9080D3`S0`1?>b800`1>>R40BCLO04Tg7`0204Pf7P<0
AcDM00<0AS@L04Le7`17=Al01P17=Al304Pg9@0504Lf9016=B<0AC@R04Dd8P14<b400P14<b<204<b
8P@0@S4Q00<0@C0P03ha800n<B001P0n<B0303d`7`80?2lN0`0k;Qd803/_7`D0<b`J0`0d;A/803L[
6`80>2dI0P0g;1X0100g:a/0=b/M03HZ7P0f:Qh3030X6`80<BTL0`0b:Qd303L[6`80>2`L0`0i;Ad2
03D/7@80=2/L0`0c:Q/00`0b:AX0=2/L03@[700603@[700803`^8@0j;1l0=RXL030W600^9aL0;bPH
02lY6@0^:aX302lW7080;RHK0`0]9AX202TW6`80:RPL0P0[:Ad202`Z7P0802/T500/9AD0;BHF02lX
600b:a/0=2dM03H_7`0h<B4203<[80<0<RXO0`0a:Ah202`X7@<0:bLL0`0Z9Q/202LT6`@09R<J0P0U
8QT802HS6PT08b<I0`0T91X00`0U9A/09RHL02HV700202LW7@0302PX800W9al092@L00<08R8J00<0
92@L02DU7@0T91`01`0T91`5028S6`03024R6P0P8AT0824I00@08R<K100Q8QX8020Q6@/08R<M0P0Q
8Q`3020Q6`P07b4N0`0M7a`[ooooo`00:_ooool809Q]@0<0VFi11@2HKD001P2IK480VVi109Y^@@2J
KSl0Vfln09]`?@80W74l102KLCl409ab@00809M[?P2HK3l0VVi109a`@`2NLTD0XGE80:=gBP2TN4/2
09U_?@<0VW0n0`2KLCl209ic@00409eb?`2LLCh0W74n09eb?`80WW=0202MLd4209mf@P80X7M30P2Q
N4@20:9iA@80YgM6102VMTD30:EeA0<0XgM60P2TN4L30:EiB0<0YGY70P2TNDH30:=hA@80YG]90P2T
NTP30:=iA`030:9hAP2WOD/0Z7i<0080Z7i<00@0Yge;0:EkB@2TNTP0XgU7202VODT30:IlBP<0Yge;
0P2XOT`01P2YOdd0Z7i<0:MmB`2UNdT0XgU70:9hAP80X7I40100XWU30:5h@P2PMd<0WgE309ec@`2L
LD@0Vg1309Y_A02GK3l0V6e009U^@@2JKd80VFi109Q]@02FJch0U6Tl0P2BK3d01P2@JS/0SfTj08eW
>02;ICH0RV@e08US=080R6<f00<0Qf8e08IQ=025H3<00P24Gc801@23GS40Pf0f089O=@20GC<0OU/a
00<0OEX`00@0OU/a07]H<01jEbl0N5D]0`1gE2`207QE;@P0LE0]00<0LU4^075@;@1_CR/00`1^CBX2
06m>:`<0KdlX0P1`D2T3075A:P08079>:P1cCb/0M54[07EB:P1fDbT0N5HY07UG:P1iEbT207mK:`06
085M;@22GRh0Q60`08IR<P27Hc<0R6@d0P29HcH00`2:I3L0RfDh08aV>@0208eW>P80SVPk0P2<IST3
08eW>P<0SVPk0P2=Hc4308iT<P<0SfDc202>I38808mT>@80Rf0f00<0Rf0e08]P<`2;HC400P2;HBl0
1`2;HRh0S6Hi08]U>02:I3L0RF<f08QR=@26H3<00P25Gc8808QR=@0408US=P28HSD0R68e08QR=@<0
Qf4d00@0QV0c08UN<@2;H3<0S64d0P2=HSD00`2<HC@0Rf0c08UN<@0208aQ=00408eR=@2>HcH0SV<f
08mT=`80T6Dh202;ICH308eW>080S6Hg0`2;ICH3091V=080TFLe0`2BJ3H308eX=080SVTe0`2?JSH2
099W>P80TFHi00@0T6Dh08mT=`2>HcH0SV<f402=IcP808YT=@06091T=`2?I3L0Sf@g08iU=`2<ISL0
RfLg0`29IcL208]V>@<0RVDh0`29I3L808]V<PP0RF@g00H0RVDh08UT=`29I3L0R6<f08MR=@26HC@2
08EP<`0>08MR=@24Gc80PUd`08=N<@26HC@0Qf8e08EP<`23GS40Qf8h08IQ=`25H3H0Q5le08=N=021
G382081K<@80Of0a0`1nGc0307eN;`@0Ne/b00D0NET`07MG;P1eEB`0M5@[07=F;P02079E;@03075D
;01`Db/0Ke8Z0080KU4Y0P1]DRD0701/DBH0JThV06U=9P1XC2L0Id/V06I99`1MBbD0GD/W05a:9P1K
B2L0FDHV05Q59`1G@bP0ET8W05=2901>?b80BS/N04Pj7`18?280AcdT044i8P0m=Ah0?SXQ03di800j
=Al0>3<O03Ha7@0e<1d203D_7`0602d_6@0];aX0;BlJ02d^700];Qh0;BhP0P0];B42034^7`80<2dN
0`0_;1d00`0^:a`0:R`N02T[7@0202T[7@80:2XL0P0W:A/902LY7P<09RPM0P0U9a`202@V6`<092LN
0P0S9Qd<028U708082<J0P0Q91/0100R9A`08bHM02@W7P0T9ah802<V7@808bHK0P0T9a`302DX7@`0
9RTN0P0W:Ql302P[800302P[6P0Y;1/0:RdL0080;2lN00h0:RdL02T/6`0X:aX0:bhI02X]600Y;1L0
:2/F02T/5`0Z;AP0;2lJ02d`6`0`<Qd0;c4L02h`6`80;BlJ00<0;S0K02la700`<Qd00P0a;Q/3038_
70<0<c0M00@0<BhK038_700b;a`0<RlL0P0c<1d203@a7P80=2lK0P0e<1`0100f<Ad0=c8N03Pc7`0h
<al803Pc7@P0?c@P0`0m=Q`203hg7@<0?cPN0`0o=A`2040f7@<0@CLN0P13=al01012>1l0@3TO03li
7`0n>Ql203`k7`04044g7P12>1l0@SPO048h7`80@cTP0P14>R402017?200AS/O04Hk7`15>Qh0AS/O
04Ll8018?B40BChR2@18?B4304Ln7@<0B3lN0P19@1l204Y19080BD0S0P18?b8204Ln8@80BC/P00<0
Ac`P04Hm8015?R400P14?b400`14@B80@S/N048k7P0204<l7`@0A3dP00D0AS`Q04Dk8015>b00A3XO
04<i7P02048h7@03044g7012>1d0@SPM0080@cTN0`14>Ql00`15>b00A3XO04@j7`0604@j7`P0@cTN
00H0CS`T04`l8`1;>b80B3XP04@h7P12>1d203hg6`0303lh7P0n=ad0?SLM00D0?SLM2010>Al803hg
7@80@CXP0P10>Al203lh7P80?SLM4012>1l304<g7@<0A3PN0P15>Al01P19>1h0B3PN04Ph7P17>Ah0
ACXN04@k7P80@S/N2013>Qd904<i7P0603ll7@10>ad0@3/M044j7@13>Qd0A3TM0P16>1d0201:?280
BS`Q04Xj801;>Qh0CC`N054n7P1E@B00ET8Q0`1I@R003@1J@b40G4DS05i79@1QBRP0HT/Y06=78P1T
B2<0ITXU06Q<9`1ZCRT0K50[06iB;@1_Dbh00P1`E2@02P1aEBD0LeLW07AH:01eFBT0MUXZ07MK:`1i
FR/0NU//07aM;P1nGc04081Q<P80QV8^0`25HBd00`27Hbl0R6@`08UU<@0208]W<`0308aX=02=JCD0
SVXf0080Sf/g00<0T6`h09A_>`2DKc/00P2EL3`309Ia?@0309Mb?P2IMDD0VGE500H0VGE500<0WGU5
09ijAP2PO4P00`2ROTX01@2QODT0X7a80:9oB@2ROdT0Xh1:0080Y85;00@0YH9<0:J3C@2VPdd0YX9>
0`2WPdl20:R4D080ZHEA00@0Z8=I0:V4FP2YQ5X0ZHAJ0P2ZQE/20:^6G080ZhAI00H0ZhEH0:b6E`2/
QUD0[8MC0:f8E02]R5<20:^5EP80[8IG0P2]QeP20:j8F@80ZXUF00<0ZXQH0:Z8FP2ZR5/00P2ZQed0
0`2ZQel0[8MJ0:b7FP060:b7FP80[HUI0`2/R5P20:^7E`80ZXIF00@0ZhIL0:Z5F`2ZQE/0ZXEK0`2Y
Q5X0102XPeT0ZhII0:^6F@2[QUT40:Z5F0030:V4E`2ZQEP0ZXEH00@0[8MJ0P2ZQEP0402[QEh0ZhIL
0:Z5F`2XPeL0Yh9E0:J2DP2UPDl0Y81>0:F0D`2VPE@0Yh9E0:R3EP2ZQEP0ZhII0:b7FP2]R5/30:Z5
F080ZHAG0`2XPeH80:Z4E`P0ZH=F202YQED30:V3E080ZXAE0`2[QEH00`2[QUT0ZXEH0:R3EP020:N2
E@030:R3EP2ZQEP0ZhII00P0ZH=D0`2XQ5@20:V5E@<0ZXIF202WPE880:N1E080YGiC00<0YGmB0:Eo
D02UOdh00P2UP4`00`2UP4/0YGm@0:EoD0020:AnC`@0Xge>00P0Y7i?0:=mCP2RO4d0XWa=0:=mCP2T
OTl0YGm@0:J0D@80Yga?0`2XOE00102WO4l0YGY=0:=hB`2RMdX;0:1jB`<0WgU:0P2NN4T209mkB`03
09ijBP2MNDT0W7Q80080VgM700<0VWI609]eAP2KMDH01P2KMDH209I`@@80Ug52102HLT<809Y_@P80
Ug5200@0UW1109E_@02DKSl0U6ho0P2CKCh809=]@0<0Sf/k0P2>JSX308eY>@03091Z>`2?JCX0SFLh
0080S6Hg00<0SFLh08mY>P2@JS/00P2>J3/0102=IcX0S6Hi08aV>@2=IcX208iX>`<0RV@g0P29HcH3
08QR=@80RF<f00H0R68e08IP<`25Gc80Q5ha08=M<022G2l808AM=00308MP=`26GcH0QEhe00<0Pe`c
0P24GC@307mH;`80OUL^0`1mERd00`23GCH0PE/d081J<`0307iH<@0407mI<P20FS<0OUPa07iH<@80
OEL`0P1lERl207]E;P<0NePb0`1lFC<307eJ=0<0NE<^0P1hDRd307MA;00307QE;@1iERh0NeP`0080
O5Ta00/0NeP`07UF;P1hEBd0NEH/07QE:`1gE2`0MU<]07EA;@1dD2h0Ldl]079>;P0806i=;00806a;
:P1ZBBP0J4LV06Y9:01^CB`0L4l^06i=;01/BbX306i=;0<0KD`[0P1/BbX206a;;0<0JdX[0`1ZBBX0
0`1ZBb`0J4TZ06M8:@0306E69`0406M8:@1XBBX0I48W06A29`<0ID<X00<0I48W06909@1Q?b@0201H
?R<02@1H@2P0EclW05Dm9@1D?2@0Dc/S05@l901E?BD0EShV05Q0:00205Lo9`0305Hn9P1E?BD0E3`T
0080Dc/S0`1@>bH204lj9@<0CSTT0P1;>B<304`j900304Xh8P19=b40B3HP0080BCTR0`18>24304Lg
8080?S4N0P0m<1d203`_7080>bhK200l;ah203lc8`80?S8R0P0m<B4203``8080>blS0`0j;R8403T]
8@P0=R`P0`0e:al203@Z7P<0<bTM200a:al0100Z9QX0:bLK02/W6`0[9a/302`X700302dY7@0`9QX0
<2HJ00H0<2HJ00P0<RXG038Y600b:AP0<RTJ038X700b:1h0<RPO034W7P<0:BDL0`0Z9Qd202/W7P80
<2HL0P0a9ad2038X7P80<bTO0P0_:Ad202hX70<0;BLK00@0;2HJ02hX700^:1`0;RPL0P0_:Ad3030Z
7P0803DX7`0b:1h0<BLM02hV6`0/9QX0:RHJ02TW6P0Z:1/302/T7080:R<K0`0Y8QX202DU7@809RHN
0`0W9al02@0X:200:28D02PR500Y8aD0:bDG02hX6P0b;1h0=BlQ03La8`02038[8`80<BXR0P0`:B42
02lX8080:2PN0P0W9ad302HV700302DU6`0S8a/08b<K00H08b<K200T91`9024R6P808B<H00<08R@I
02<U6P0T9Q/00P0U9a`02@0V:1d0:BTQ02LW7`0T91`08B4I020P600Q8AT08b<K02DU7@0802@T7008
028S6`0S91`08b@L02@U7@0S91`08R<K024R6P0P8AT302<T70808R<K0`0Q8QX8020Q6`/08R<M0P0Q
8Q`3020Q6`P07b4N0`0M7a`[ooooo`00:_ooool809U^@@80V6e01P2IKT401P2JKD<0VVi109Y^@@2K
Kd00Vfln09aa?P80W74l102LLT0409]a?`80VVi100@0Vfm209eaA02NLTD0X7A70P2QMDP209U_?@<0
VW0n0`2KLCl00`2OM440WW=009aa?P0209]`?@0309aa?P2NLd00WgA10080W7901P2MLd4209mf@P80
X7M30P2QN4@20:9iA@80YgM6102VMTD30:EeA0<0XgM60P2TN4L30:EiB0030:IkB02UNTL0YGY70080
Y7U60P2SN4D0102RMd@0YG]90:EkB@2UNdT20:AjB0<0XgU700@0ZGm=0:QnC02VO4X0Y7Y8102SNDL8
0:ImB@<0YWa<0`2WODd20:QnCP0C0:Z0CP2YOdd0Yge;0:EkB@2SNDL0XGM50:1fA02OMD<0XGQ20:1g
@@2OMT80WWA209ab@P2KL4<0VVm209Y_A02FJch0Uf`o09Q]@00209U^@@0309M/?`2FJch0U6Tl0080
T6Xk00@0SfTj08iX>@2=IcP0S6Hg0P2;ICH01P28HcH0Qf8e08MR=@26HC@0QF0c08AO<P80Peha00/0
OEX`07iK<@1nFc40OU/a07eJ<01kF2h0NUL]07QE:`1kF300NUL_07QE;@0307IC:`0307MD;01hEBd0
L4l/0080L4l/1@1aD2d0201bDBh0LE0]06m>:`1^CBX0KD`Y06i=:P1_CR/0L4l/0P1]CBH03P1^CRL0
L50Y075A:P1bDR/0Le</07AD;@1eDBd0MU8^07MD;P1hEBd0NUL]07]I;01lFRd0OE/]0P21GB/01022
GR`0Pel]08EQ;`26HS0208MS<@<0RfDh00<0S6Hi08eW>P2>J3/00P2>J3/00`2?JC`0S6Hi08aV>@03
08eW>P<0SVPk0`2?IC<3091V=080TFLe202>I38208mT>@80SV<h00@0SF8g08aQ=P2;H3D0Rf0e0P2;
H3H00`2;H3D0Rf0c08]Q<@0208]Q;`0908]R;P2<IST0S6Hi08]U>029HcH0Qf4d08IP<`25Gc80Q5ha
00P0Qf4d0P29HcH208QR=@0708MQ=026H3<0QV0c08IP<`29GS40Rf0c08aQ=00208eR=@0308aQ=02;
H3<0REha00P0SF8e202;ICH308eW>080S6Hg0`2;ICH2091V=080TFLe102BJ3H208eX=080SVTe102?
JSH00`2AIST0T6Dh091U>005091U>0P0S6Hg202=IcP808aV=`0608iR=@2=HSD0SV<f08iU=`2<ISL0
S6Ph0`2;JCT208]V>@<0RVDh0`29I3L808aW<`P0RF@g0P2:ICP05029I3L0R6<f08MR=@26HC@0QF0c
08AO<P28HcH0Q5lb085L;`23GS40Qf8e08QS=P25H3<0PUd`08MR>026HCL0QF0f08=N=022GC<0P5/a
0P1oFS0307eN;`<0O5d^0P1kG2d02@1jFS<0Ne/d07]K=01kFc@0NETb07MG<01dE2d0LU8[075E;P02
071D;@0306mC;01^DR/0KE4Z0080K50Y00P0Je<U06YB901YDBD0J4lV06I=9@1UBbH0I4XU06=99P80
GD/W01@0FdPW05Y79`1HABL0Ed<X05I29`1E@BP0C3dP04Ti7`15=a`0@cLM04@j8@13>b@0?cLR03/e
7`0l>R40>SPQ03Le7P0d<Qd0<RlL034^7@80<RlP00P0<38L02la700_<A`0;RlM02d^7P0/;Al0;2`P
02/[7`<0<2dN0`0_;1d202h[7080:2`M0P0W:a`302HZ6`0302DY6P0V:1d09RPM00T09RPM0P0U9a`3
02@V6`8092LN0P0S9Qd5028U70P08B@K0P0O8QT0100P8aX08B@K028U700S9Qd:02@W7P<092LL0`0U
:1d202HY7PP09bXO0P0V:Ah202LZ7`@0:2/P00<0:2/J02T/6`0Z;A`00P0/;ah01@0Z;A`0:B`K02P[
6P0[;QT0:RdH00<0:B`G00H0:bhI02d`6`0^<A`0;c4L02h`6`0];aX202`^6@0302d_6P0^<1/0;c4L
00<0<2dJ0`0a;Q/2038_70<0;RdK0P0_;Q`3030_7@80<B`I00<0<RdJ03<^6`0d;a`00P0e<1d00`0f
<Ah0=C<L03Dc700503Dc700303@b6`0l<Ad0?34M00H0?34M00@0>S@L03/e7@0k=Ad0>cDM0P0l=Qh2
03dg7`0403/c700l=1d0?3@M03`d7@80?CDN0P0n=Ql2044f800303lg800n>200?CTP0080>cTP00@0
>SXP044f8011=R00@CHP0P12=b4304<h8P0304Dj7P14>Ad0@cPL0080@cPL00<0ACXN04Ll8018?B40
1P18?B4304Ll8080ASdL0P17?Qd01018?ah0BD0O04U07`19@1l304Po8P80AchQ0`16?B0204Tk8003
04Ll8016?B00@c`O0080@SdO00@0@ChO048l7013?Ad0@cdM0P14?Qh204Do7`0304I08014>Ql0A3XO
00H0A3XO0`13>Ah304@j7`80AC/P4014>Ql01P1=>b<0C3XR04/k8P18>R00ACTO04@h7P80@SPM0P10
>Al203lh7P0403hg7@0m=Q`0?3DK03`e6`P0@3TO200n=ad2044j8080@3TO0P0o>1h203hg7A00@SPO
0`13=ad304@h7P80ACTO00H0BCPN04Ph7P18>1h0AcTN04Dj7P14>ah2048k7PP0A3/N2@13>Ah203ll
7@03040k7@11>Qd0@cXM0080A3TM00X0ASPM04Tk8@19>b00BCTO04/j7P1<>ad0DChN05A07`1F@R40
F44Q0P1G@2001@1H@B40FT<S05e69P1PBBT0HT/[0080I4PS00@0IDTT06M;9P1YCBP0JThY0P1/D2/0
1P1_Db<0L5@T075E9@1bERH0LeLW07EI:@80MUXZ00@0MePY07UJ:`1lGBh0OUl`0`20HC802P1oH340
QV8^08EQ;@24H2`0Pel[08AP;025HBd0Qf<_08UU<@2:IS8208]W<`0308aX=02=JCD0SVXf0080Sf/g
0`2DKc/209E`?0<0UW4m202IMDD00`2MNDD0WWY60:1lB0030:9nBP050:5mB@2PO4P0XWm70:9oA`2S
P4P00P2TPDT00`2UPTX0YX=;0:J3B`030:J2CP80Yh=?0`2XQ5020:R3F@<0ZHAJ0`2ZQE/20:Z3F006
0:^5F02[QEH0[8IE0:b7D`2]R5@0[HQC0P2[QEH20:b6E`80[HMH0P2^R5T01P2YREH0ZHUH0:V9F02Y
REX0ZHQK0:V8G@80ZHQO202/Qe/20:f9F@<0[8QH0P2[QeL20:Z6EP80ZhIL0P2ZQE/0102YQ5X0Z8=I
0:R3F@2XPeT50:Z5F0<0ZhII00<0Z8=F0:V4E`2ZQEP00P2[QUT02@2ZQEP0ZHAG0:R3EP2[QEh0ZXEK
0:V4FP2XPeL0YX5D0:F1D@020:=oC@080:F0D`2VPE@0Yh9E0:R3EP2ZQEP0ZhII0:b7FP2]R5/30:Z5
F080ZHAG0`2XPeH80:Z4E`P0ZH=F202YQED30:V3E080ZXAE0`2[QEH00`2[QUT0ZXEH0:R3EP020:N2
E@030:R3EP2ZQEP0ZhII00P0Yh5B0P2VPU830:N3D`<0Z8AD202VP5480:J0D`80Y7eB00H0Y7iA0:An
C`2TOTd0Y7m;0:F0C02UP4/20:=mCP030:9lC@2QNd`0XG]<00<0X7Y;00<0XWa=0:5kC02PNT/00P2O
NDX0102QNd`0Xge>0:AnC`2TND`40:EjC@040:AiC02RMdX0X7E809icAP/0WGM800<0W7I709]eAP2K
MDH00P2JM4D209]gA`0409YfAP2IMDD0V7A409Mc@`80UW92202FL442095[?080TV`m0P2CKCh209A^
?`P0UFXm1`2BK3d00`2AJc`0SfPm08mX?@0608mX?@<0R6Hf0P27ICD308IT=00308YT=@29Hc@0R68c
0080Qf4b00H0R68c08US=02:I3D0R64f08UR=`2:HcP208]T>@0308YS>029HSL0R64f00<0Q5db0P23
G343089K<080Q5db00H0PU/`085J;`1oF2d0OUL/07eF:`1lEBX9085J<@03081I<01nEbh0O5D/0080
O5D/0P1nEbh207]D:`80NU<Z0`1iDRT0101hDBP0O5Ha07]E<01iDbh207MA;00407QB;@1iDbh0NU@_
07YD;`<0NE<^0P1hDRd207MA;0<0LU0[101cDB`207AB;@<0Ld`[0P1bBbX3075::@03071>:01bD2X0
Le4[0080M58/00T0Le4[079@:P1`CRP0KdhU06m=9`1^C2H0KT`W06e;:01]BRX00P1/BB/806Q7:008
06I59P1S@R<0HD0Q06A3901YB2T0JdX[06U8:@1VABH206=28`80I4<T0P1UA2D206I59P<0Hd4V0P1R
@2D3064o900306129P1O@BD0GClS00<0FcdQ00H0G3hR05do8`1P?RD0GcdT05hl8`1M>b8205`j8@03
05dk8P1N?2<0D3PP00<0D3PP101A>B40201@>bH0CcXU04dh8`1<=b80BcHQ04`g8P1=>2<0CSTT0P1=
>B40101<>200BcLO04Xf7P1:=Qh204Te7@0404He8`15=280AC@R04Dd8P80A3<Q0P13<R000`10<Ah0
@C8O048c800204<d8@04044b7`0o<1d0?RlL03lb7`<0?S4N0P0m<1d203`_70<0=B`K0P0d:aX303<Z
6@P0<bXK0`0d;1l403<[7P03038Z7@0a:1l0<2LN0080<2LN0`0_9Qd202hU70P0;2PM0P0^:Ql202dY
7P<0;2PM00<0:bLL02TV7@0Y9Qd01P0Y9Qd202@T6P809BDK00@09RHL02LW7@0W9ad09bLM200/9QX2
02dW5`0302dW6@0^:1`0;RLM0080;RLO00@0;RLQ02<R7@0S8Qd08b8M0P0T8ah302DT7`<0;2DM0P0]
9Qh302hW7`0402/W7P0Z9Qd0:RHM02XV7@80:BDL0P0X91/202XV7@80:bLN0P0/:1l202dY800902`S
700]91d0;BHN02/W7P0Z9ah0:2PN02HV700U9a`0:2<M00<09b8L0P0V8A/202DP6P0402@S7P0U91l0
9B@O02DT7`809RDP0P0W9R4202XW6080:BHG00D0:RLH02`Y6P0^:a`0<2dN02dX8P0302`W8@80:bHP
0P0Z9Al0100W:Ah09RPM02HX7@0V:1d202DW708092HK0`0R8A`502<R7@P092<N2@0P8a`201lR5`0>
020S600Q91T08RDJ02<V6`0T9a`09BPM02XZ8P0W9al092@L020P600O7aL0820H02<S6`0T91`802<S
6`808b@L0`0U9Qh00`0S91`08B8J020Q6@0202DV7P8092DM00@08b@L028S6`0R8a/08R<K200Q8Qd8
024R70<08R<M0P0Q8Q`3020Q6`P07b4N0`0L7Q/[ooooo`00:_ooool809U^@@80V6e0102IKT4209Y_
@P0609Y]@`2JKT40Vfm209]_@02KKch0W74n0P2LLC`409ab@0@0Vg4o1P2NLDL209e`AP80VFlm0`2J
L3h309]a?`0309md@@2MLSl0W74n0080VVll00<0W74n09eb?`2OM4400`2LLT0509ec@@80WgI20P2P
Md<20:5hA080XWU50P2WMdH40:IfA@<0YGE40`2SMdH20:AhA`<0YGU80P2VNdP0102UNTL0Y7U60:Ai
AP2SN4D20:9gA0<0YG]90`2TNTP20:=iA`080:Z0CP2XOT`0Y7Y80:5gA@2PMT@0XGM50:9hAP2TNTP8
0:ImB@<0YWa<0`2WODd20:QnCP080:Z0CP2YOdd0Yge;0:EkB@2SNDL0XGM50:1fA02OMD<20:1g@@08
09mf@P2NM480W79209]`@`2JKd80VFi309EZ?@2FJch309Q]@00409M/?`2EJSd0U6Tl08mY>P<0SVPi
00@0SFLh08aV=`2<ISL0S6Hg0P27HSD00`26HC@0QF0c08AO<P0208=N<@0A089M<01hEB/0NEH/07]H
;P1lFBl0NeP^07QE:`1eDRP0Le0V07]H<01iERh0Me@/07IC:`1eDRX0MU<[07MD;01iERh0101`Cb`4
075@;@0307=B;`1aD2d0Kdh[0080KD`Y00/0KTdZ06m>:`1`Cb`0Jd/T06a<9@1]CBH0KdlX079B:`1d
E2d0MED^07IF;`0207UE<@0607YG<@1lFC40OEX`07mM<020GS40P5h`0`23Gbd01P24H2h0QF4_08IR
<026HS00Qf<a08]U>080S6Hi00@0SFLj08iX>`2>J3/0SVPk0P2?JC`208aV>@<0SFLj0`2>J3/3091V
=0<0TFLe0P2BJ3H808iT<P80Sf@i00@0SV<h08eR=`2;H3D0RUld0P29GS<208]P=P0308]P=@2;H3<0
Rf4a0080Rf4_00T0Rf8^08eW>P2<IST0RfDh08US=P27HC@0QV0c08EO<P24GS402027HC@208US=P04
08QR=@27HC@0Qf4d08IP<`80QElb00<0REha08]P<`2<HC@00P2=HSD00`2<HC@0Rf0c08UN<@0208eR
=@<0S64d0`2;H3<808]U=P<0SFLh0P2<ISL308]U=P80T6Hd0P2AIcD3099X=P0309=Y=`2=J3@0SFPd
0080SVTe0`2?JSH00`2@JcL0Sf@g08mT=`03091U>0<0TFHi202<ISL808eW>0P0T6Xk00H0SF4d08aQ
=02=HSD0SF@f08eW>02=JCT308aZ>P80RfHi0`2:ICP308UT=`P0S6Lb2029I3L208YU>00308UT=`28
HcH0Qf8e0080QF0c0140Q5lb08QS=P24Gc80PE`_089M<027HSD0RF@g08IQ=021G2l0Qf4j08IP>@25
GcP0Pedf085K=020FS<0OeTb07iH<@0307YN;P<0NEd]0P1hG2`0201hFc<0NE`d07UL=01iG3@0MeXb
07EH<01aE2`0Ke8Z0P1`E2d00`1_Db`0KU8[06eA:P0206a@:@0Y06]?:01YDb@0JE<T06QA9@1VCbD0
IDhU06=;9@1RBR@0HTXV05];9`1JBRP0FDTW05Q89`1FABL0E4<W05=2:01B@BL0BCTO04Dg7012=1X0
@CDK04<i8011>B80?SPR03Xd7P0k>B80>CLP03Hd7`0c<1d0<BhM030]700a;Ql0<RlP030d7@0`<ah0
;c8M02ha7P0/;ah0:bdO02X/7`0Y:ah00`0`;Ah202l/7@<0;R/L00@0:2`M02L[700W:a`09b/L0P0V
:Q/202DY6PX09RPM0`0U9a`302@V6`8092LN0P0S9Qd3028U70X08B@K00H07R4H01lR6@0P8aX08B@K
028U700S9Qd:02@W7P<092LL0P0U:1d302HY7PP09bXO0P0V:Ah202LZ7`<0:2/P00@0:B`Q02P[6P0Y
;1/0:RdL0P0/;ah01P0Z;A`0:B`K02P[6P0/<1T0:blH02X^5`80:BdF00H0:blH02da6P0^<Q/0;c4L
02h`6`0/;QT202X/5`0302`^6@0^<1/0;c4L00@0;b`I0P0`;AX2034^6`0402`[6@0];1X0;B`J02d/
6P80;RdK0P0_;Q`01P0_:QL0<2/H030[600a;1T0<RdJ03<^6`80=2lL0`0e<ah403@b7@0303<a700k
<1h0>c0N00H0>c0N0`0i=A`203Xf7@<0>cLN0`0k<a`203`d7@<0?CDN00H0@3DO03hf7`0n=Ql0?CLO
03`h7`0j>1l203Ti7`04040e7`11=R00@CHP044f8080@SLQ0P13>2800`14>Ad0@cPL048g6`02044f
6P0304<h7015>Qh0Ac`P00D0B3dQ1017?20204Hm7080AchM00@0B3lN04U07`19@1l0BT4P0`17?R42
04Hm80<0AC`O0P1:?2400`17?200AC`O048k7P02040k7@0603hk7013?A/0@cdK04<m6`14?Q`0AClM
0`16@1h304<i7P80A3XO0`15>b0304<i7P80A3XO0`15>b0@04@j7`0604hj8P1<>R80BcTQ04Xj8@18
>R00ACTO0P13>Ah01P12>b40@CXP040i7`0o>1h0?SLM03`e6`80>c@J2010>Al803hg7@80@CXP0P10
>Al203lh7P80?SLM4012>1l304<g7@<0A3PN0P15>Al01P19>1h0B3PN04Ph7P17>Ah0ACXN04@k7P80
@S/N2014>ah904<i7P0603dl7@0o?1d0?c`M040k7@11>Qd0@STL0P13>1`02019>b40B3XO04Ti7`1:
>Ad0C3/M050m7@1D@1l0ED4P101G@2001@1I@R80GDHV0619:@1RBb/0I4LU0080IDPV00D0IdXX06Q;
:@1YC2X0JTd[06]>;00206mC8`0:071D901bERH0LeLW07AH:01eFBT0MUXZ07IG:01hFBX0O5d^07iO
<0<0P64b00T0Of0a08IR;P25HBd0Pel[089N:P23Gb/0QF4]08MS;`28I3000P2:IS800`2;Ic<0S6Pd
08eY=@0208iZ=P0408m[=`2DKc/0U6lk09A_>`<0UG0l0P2FLCd509UdA`<0V7=600<0WGU509ijAP2P
O4P00`2ROTX01@2QODT0X7a80:9oA`2ROdL0Xh180080Y85900@0YH9:0:J3B`2VPd/0YH5=0`2VPTh2
0:N3C`80Z8A@0`2XPU/20:V3G0<0ZXAM00P0ZH9G0:Z3F02ZQ5L0ZhEF0:b6E@2/Qe<0[HQD0:f8D`80
ZhEF0P2/QUL20:f7F080[XQI0P2YREP00`2YREX0ZHQK0:V8G@020:V8G`030:V7H@2/Qe/0[8MK00H0
[8MK0P2]RET30:b8F080ZhMG0P2ZQUH20:^5GP040:Z4G@2YPe`0ZH=L0:R2F`80Yh5J0`2YQ5L00`2Z
QEP0ZhII0:^6F@020:b7FP030:J1E02XPeH0ZHAG0080ZhII00/0ZHAG0:R3EP2VPE@0ZhEN0:Z5F`2Y
Q5X0Yh9F0:J1E02TP500Xgm=0:9nC0020:F0D`040:N2E@2XPeH0ZXEH0:^6F@80[HQK0`2ZQEP20:V4
E`<0Z8=F0P2[QEP40:Z4E`X0ZH=F0P2ZQUH40:V5E@80Z8AD0`2YPe@20:Z4E@<0ZhEF00<0ZhII0:Z5
F02XPeH00P2WPUD00`2XPeH0ZXEH0:^6F@080:J0D@<0YH5A0P2VPU830:N3D`P0YX1A202VP5<20:=l
D@030:=mD02TOTl0Y7i=0080Y7m;00H0YH1;0:5kC02QNd`0XG]<0:1jB`2ONDX309ihB@080:5kC02O
NDX0WWQ909egB02NN4T0WgU:0:9lC@2SODh20:AhB`<0YGU<00@0Y7Q;0:5eB02OLdH0WG542P2KMDH2
09YdA@0409UcA02HLT<0V79309Ma@P80V7A400@0Ug=309Ib@P2FLT80UG510P2DL40809=]?P<0SVPi
00<0SfTj091Z>`2AJc`00P2AJc`809=X>`<0SfTj0P2@JS/3095[?0P0SVLl0`25Hc<208AR<P<0Pf4a
00<0Qf4b08IP<@25Gc000P24GRl01P25Gc00QV0a08MQ<P24GC80QUld08UR=`80RV<h00@0RF8g08IO
=024GC80PEX_0`20FBh207mH;@80OUL/0P21FRl0101oF2d0OUL/07aE:P1jDbP207UB9`P0OePa00<0
O5D^07YC;01hDBX00P1fCbP00`1gD2T0N54Z07UB:`0307QA:P<0Me0Y0P1fCbP0201gDB`0MDlZ07==
:01bC2L0LD/V079<9`1cCBP0M4hY0`1gDB`207I@:`<0MDlZ0P1[BB@406a:9@<0KD/V0`1_B2L306i7
9P80KDHU00<0JdTS06a:901^C2H00P1_CBL00`1^C2H0K4XT06]98`0206Q6800306Q68@1XAR<0J4DU
0080J4DW00<0J4DY06=49`1SA2L01P1SA2L0201Q@RD0GChQ05/l7`1N?b80I4DX06M8:`1TABP0H44T
0P1I>Qd01P1J>ah0Fc`O05`m801M?R40GSlR05m08`<0FS/O0P1I>Qh305Pi7@0605Tk7`1H>Qh0ESPL
05@f6P1C=AT0E3HJ0P1E=a/00`1L?2D0FSXS05Lg800205De7P0305Hf7`1H>240FSXS00<0BS@M1@1;
=Ah02@1=>2D0C3LT04Xe8P19=240B3<P04Td8@1:=B80BcHS04Pc7P0204Lb7@0304Ha7015<1/0A2lJ
0080@bhI00@0?blO03h^7P0n;Qh0?RhN0P0m;Ad203`/700303P[6P0i;1/0>bhM0080>bhM00<0>B`K
03LZ6@0e:1L00P0f;Q/203D]6P<0=2`I00@0<b/H034Z6P0a:QX0<BXJ0P0`:AT302lX60P0;bLJ0`0]
9Q`502`U6`80:R<K0P0Y8QX402PQ6@0302LP600V8aX09R<J00H09R<J0`0[:1l202XW7P<0:BHM200U
9Ad0100Q8QX08R<K028S6`0S91`202@U7@809BHN200X91T0200Z9aH0:RLH02/X6@0[9a/0:bLL02/W
7P0[9R00;2LQ0`0Q8Qd2028S7P<08b@O100Y91h202XU7`80:bHP00@0:BHM02PU700X9A`0:2DL0P0W
91/202HS6P80:2DL0P0Y9Qd0300Z9ah0:bPO02/X7`0/:B00:24I02XS6`0Z9Qd0;2PO02`Y800X:1h0
9BLL02@V6`<09b8N0P0V8Ad302DP70808b@O0P0T9B0302DV8@0502HW8P0`;200;RXN02/W6`0Y9AT0
0P0X91P202XV6P<0:B@P0P0X8al302LR7P0402HY800U:1l09BPO02DX7`8092LN0P0S9Qd3024R70D0
8R<M200S91h9024T7@0601hQ5P0O8QL082<H024T6@0R9AX08bHK0P0T9a`0200Z:R80:2PP02<S6`0P
81P07alG020P600R8QX092@L200S8a/0200S91`092DM02HW7`0W:2009RLO02@U7@0R8a/08B8J0P0V
9al0100U9Qh092DM02@U7@0S91`2028S6`P08R<N200Q8Q`3028S7@808B8L0`0P8A/801lQ7P<071hK
:oooool002[ooooo0P2LL3l209]_?P<0VVhm00H0VFdl09Q]@02HKD00V6e009M/?`2FJch309EZ?@<0
Vfm20P2JKT4309U]@00309Q/>`2IKC`0Vfln0080W70o00<0Vfln09U]?02HK3/00`2MLTD00`2LLD@0
Vg1309Y_@P0209Y_@PP0WWA2202MLSl20:1e@P0409md@@2NLd00WG8o09eb?`80W74n0P2OMD<20:1f
A080XGM50P2RN4H0102SN4d0XWM:0:9gBP2QMdL20:1fA00609mf@P2OMT00WWDo09mc@P2QMD@0YGU8
0P2XO4/00`2VNTT0XgM60:5eA0080:AiAP030:EkB@2TNTP0XGM50080X7I400<0XWQ60:EkB@2WOD/0
0P2XODX20:MlB@80YW]80P2UNTL20:=hA@80Y7U600L0YGY70:IkB02VNdP0Yga90:^1C`2ZP4h0Z7i<
0080Yge;00/0Z7i<0:Z0CP2[PDl0Ygi:0:ImB@2UO4H0Y7]30:9j?`2QNC`0X7Pk09mg>@020:1b?P06
09eb?`2KLCl0VG5009I`@@2EKd00Tfi10P2BK3d2095[?004091Z>`2?JCX0SfTj08mY>P80T6`l00@0
Sf/k08iZ>P2=JCT0SFTi0P2<J3P208QQ>00408MP=`25GSD0Q5dd089K<P80PEXa0140QE/e08=I<`1o
F340NeD^07YD;@1iERh0NEP_07YI<01fDbd0N5D_07YG<@1kF380NULa07QE;`1eDR`0Le0Z07I?;P02
07A@;P03079@;@1aD2d0KU0/0080KE4/00H0JE</06YB;01ZDR`0JU0[06a@:`1]Cb/206m>:`09075=
:@1cCb/0MU<]07QE;@1iER`0NUP[07UG:P1iEbT0OEH_0080OUL^00<0OeP]081J;@21Fb`00P22G2/3
08QN;080REl]0`2:H2h308UU<@@0RVHb0P2;Ic<8099X=PP0TFDh0`2>I38208mU<`<0T6Hd00H0RfHa
08]V<P2:IC40RV@c08US=029HcH208QQ=P0408mT>P2>HcT0SF8h08aQ=`80Rf0f0P2<HCL808YN>@03
08IP<`28HSD0RF<f0080RV@g00<0RF<f08QR=@26H3<00P2<HC@0102;H3<0RUlb08YO<P29GS4208QM
<080Qf4d0P28HSD408US=P0:08US=02:I3D0RfDf08aV=`2;ICH0RV@e08QR<`26H340T6Dh08iS=P80
S64d00@0SF8e08mT=`2BIcX0U6Tl0P2AK3P0102@JcL0SfXf08mZ=P2>JCD208eX=00608YT=@2;ICH0
RfDf08eW>02>J3T0SfTj0P2@JS/208mZ=P80T6/g00P0SfXf08eX=02:IC40RF@`08AM<P25GS<0Qf0e
08UR=`80RV<h00@0RF8g08QQ=P2=IcP0SFLh102<ISL208]U=P80SVPi00H0SFLh08aV=`2=IcP0SfTj
095[?02BK3d308iX>`<0SFLj0P2<IST208]W=`<0S6Ph102=JCT0402>JCd0RVDi08MR=@29ICD0SFTg
08m[=`2<J3@0R6D_08UV;02:Ibd0S6Ta08aY<`2<J3@0RVHd08MS<@26HS8808YV=PP0Qf8e0P21Gc42
089P<P0508=Q<`24HS@0Q68d08ES=@23HC<00`22H382085O<@80P5h`00H0P5/a07iK<@1nFc40O5/`
07]L<01hFbl207ML;`0907QK<@1gFS00MUT_07AG;@1cER`0LE@Z071C:@1_DRP0LU@R0080LE8S00<0
L54S06m@901^CRD00P1]CBH05P1^CRP0K4hX06]=:@1YC2X0IT`[06A;;01RBb/0HDX[05i:9@1MBB@0
FDLS05A48P1@@B00C3lM04Xm7@17?1`0?c`M03lk7P0m>A`0?3PM03Xf7@0h<ad203Lb7P80>3<O00@0
=c8N03Ha7@0e<1`0=C0L0P0d;a/302h_7@80;BhL0`0/;A/2030Y8@0302lX800^9al0;BHN0080:b@L
00<0:R<K02HW7`0V9al00P0U9Qh402@U7@P09BHN00@092LN02<V7@0S9Qd08bHM0P0R9A`2024T6`T0
82<J0P0Q91/4020S6P807b8I00@08B@I028U6P0R9AX08RDJ0P0S9Q/202@W7008028T5P0S9AL09BLI
02HX6P0W:A/09RPJ02DW6@0T9QP802P/7@80:RhO0P0Y;Ah402P/7@P09b/L200/;R000`0^;b40;BhP
02//7P0202X[7@0302//7P0];R00;RlQ00P0:bhM00<0;2hP02d_8@0^<2800P0_<B<01P0];b40:bdO
02T[7@0X:AL0:R/I02`]6`<0;RlM00<0;2dK02//6P0Z:a/00`0Z:a/202//7080;2dM0P0/;QP302d_
6@<0;S0J0`0d<Ah503<`7@P0=C8O0P0j<Ql203`a7`0403d`7`0o;al0@2lO040_7`80>c<N0P0l=1l4
03de8080?SLM100m=Q`203`e6`@0@SPM0P13>Ah204@j7`80AC/P00l0A3XO04<i7P12>1d0@SPM04@j
7`16?240AcdR040i7@11>Qh0@cTN04Hj8019>b40Bc/R04`l8`1=>b<00P17?B8204Hl8@0604Dk8014
>Ql0@cTN04<i7P1:?R@0BclU0P1<@2H0301:?R@0B3`R04Di7`13=ad0ASdP04Dl7`14>ah0@cXM04@k
7P15?1l0AchQ04Po8PP0ACXN00D0@S`J04<m6`13?A/0A3hL04Do7@0204I07P0304M17`12>1l0@cTP
00H0@cTP00@0ACDK04Hf7019>Al0Bc/Q0P1<?2800`1:>R00BCTO04/k8@0304Xj8080BCTO0P18>1h3
04Dk8080A3XO0`13>Ah203lk7P80?SXM0`0m>A`0100l>1/0A3XO048h7@11=a`203le6P06044g7012
>1d0A3XO03dc6010=Q/0A3XO0P17?B800`15>b00@SPM040f6`08048h7@80@CLL00H0@3HK03le6P10
=Q/0@SPM04@j7`15>b0204Pm8@0404Ll8016>al0A3TM04<h7080@SLK0P15>Al204Hj800504Lk8@18
?280B3`R04Tm8`19@2<00P18?b801@17?R40ASdP04Dl7`15?1l0A3/N00<0ACXN0`14>Ad304<h70P0
@cTN0P15>Qh304Hk7`<0Ac`P00P0DCdH058n6@1C?aX0ED4L05Q47`1JAR40FdLR05a88`80IDlZ0P1T
CRT03P1SCBP0HT`W069<9`1QBbH0IE0S06IA901XDBD0K5@X071E:P1cER`0MeL^07QH;`1dF2P0N5`/
0P1kGbl207UM;@0807eQ<@21ICD0Oed]07mM;@20GRh0PEl_089P<023HC4208AR<P80RVHb00@0RfLc
08eY=@2>JSH0T6`h0P2AKCT00`2>JSX0T6`l099^?P0309A`@003099^?P2AKCd0UgE500@0UgE50`2F
M4@60:1lC080XGe=0P2PO4`20:5mC@80XWi>0P2SOdl20:B0D0040:F1D@2VPU80Yh=C0:R4E080ZHEE
0P2YQ5L30:Z5F0<0ZhII0P2ZQEP20:^6F@<0[8MJ00<0[HQK0:Z6EP2ZQUH01P2ZQUH00`2[QUT0[8MJ
0:j9G0020:n:G@030:f8F`2[QUT0ZXEH00P0[HQK0P2[QUT30:Z5F0<0ZHAG00<0Z8=F0:^6F@2[QUT0
0P2ZQEP30:V4E`030:R3EP2ZQUH0ZHEE0080ZHEE0P2XQ5@20:N3D`090:9mD02UP5<0ZHAG0:b7FP2]
R5/0ZhII0:R3EP2VPE@0ZXID00<0ZHEC0P2XQ5820:N3D@P0Z89C1@2XPeH30:V4E`80ZXEH0P2YQ5L0
102XPeH0Yh9E0:N2E@2VPE@30:J2DP80YH5A0`2TP5080:N3D`060:F0D`2VPE@0YX5D0:N2E@2YQ5L0
ZXEH0P2[QUT00`2TOTd0YGm>0:J0C`020:R2D@060:N1D02UOdh0Y7i=0:1kAP2QO4L0XWe80P2SOTT0
0`2QO4L0WgY509iiA0080:R2D@060:B1B@2TPD/0Y85;0:=oB`2SOdd0XWi>0P2ROE030:5mB`D0XWi<
0P2QN4X20:9iB`040:=jC02TNdd0Y7]=0:ElCPP0VWI600@0X7Q709mgAP2OMdH0WgM60P2NMTD209ee
A080W7=70`2KLTH409YaA@0409]bAP2IL4@0Ufi209E/@080TfXn0P2DJcl00`2EKch0U6hm095[>P02
08mY>006095[>P2DKSd0UFln08mY>02@JST0TV`k0P2CKC`00`2BK3/0T6Xi08mY>004091U>`@0TFHl
202:H3H208]T>@80RV<h0`29HSL00`28HCH0R68e08QR=@0208QR=@H0RF<f0P28HSD408MQ=080R5/b
00H0QU/a08AJ<021FRl0OeX^07iI;@1lFRd307mJ;@80OUT/0`1mF2/807aG:P80NeD`00<0NU@_07UC
;P1hDRd00P1gDB`02@1fD2/0NE</07UC;01fDb/0M5<Z079B:@1_DRP0KU4W06eB9`02075?:@80LU0Z
00@0LDlY06m=9`1/BR@0JdTS0`1dCB`307=<:`80LT/Z00P0K4PX06e9:@1]BBT0KDTY06a8:01ZARH0
J4@T06I28PP0ITDT00H0KDTY06a8:01[AbL0JTHV06U59@1XA2@206M38`80GT4Q0P1O@R8206138`80
HD@T00X0HTDU06=3:P1TA2/0I4@[06=3:P1R@RT0GclV05`l8`1K>b80F3dR0P1I?R<00`1K@2D0G44V
05e29`0205i3:00305e29`1L@BH0Fd0U0080FSlT00<0Fd0U05a19P1M@RL00P1E@BH0101D@2D0DShS
054m8P1@?24204lk800804dg7`1>>200CcTQ054k8`1B?2@0E3hV05Do9`1F@2P804Xi9`<0ASDS0P15
=28304@c8@80ASHW00@0ACDV04@d9@14=2D0@c<T0P12<R<01013>2@0@CHR03hc7`0l<Ad403X_6`03
03/c9P0i<B@0=blR0080=BdP00<0=RhQ03L_8P0h<2<00P0f;al303D^7P<0=2dM200b:Qd8034Y7P04
02hV8`0]9B80;BDR02dU8P80;2@Q0P0[8b0802`U7@P09R<J200T9Al8028S7@807QlI0P0O81X01@0P
8A/08B8L024R700Q8Q`08R<M00808B8L0P0P8A/401lP6P<0824K00<08B8L028S7@0S91h00P0S91h3
02<R7@808R4L0`0Q81/8020Q6`809QhK00H09alL02PP7@0Y8Ah0:R8O02/S800/924202TT7P0602PS
7@0W8Q`09R4K02DP6P0T7aT08ahH1@0S8Qd302@S7PP08R<M200T91`802TT7P<09RHN00<09BDM02@T
700S8a/00P0S8a/802<R7@808R8J0`0S8a/302@T70P08b<K0`0T8ah302<R7@808R4L200Q8Q`8028Q
70P08R<K0P0P81P0100Q8AT08R8J028R6P0S8a/302@T7080820H00L08B4I02<S6`0T91`09BDM02HV
7P0W9al08R8J00808b<K00D092@L02DU7@0V9Qh09RHN02LW7`0802DU7@P092DM200U9Ad@024R7100
82<L0`0P81h[ooooo`00:_ooool209]_?P80VVhm0P2IKC`209Q/>`<0V6e000<0Uf`o09I[?P2FJch0
0P2EJSd309]_@P80VVi10`2IKD000`2HK3/0VFdl09]_?P0209a`?`0309]_?P2IKC`0V6`k0080WG95
0P2LLD@209]`@`80VVm2202NM48809eb?`<0WgA10P2NLd0309eb?`80WgE30P2PMT@20:5gA@80XWQ6
00@0XGI;0:5fB@2QMTT0XGM70P2PMT@02`2PMd<0X7M10:1g@@2OLd80XGE40:EiB02WNdX0Z7a;0:Ij
B@2SMdH0XGE400P0Y7U600<0Y7Y80:=iA`2RN4H00P2RN4H00`2SNDL0Y7Y80:EkB@020:QmBP80Yga9
0P2VNdP20:EjA`030:AiAP2UNTL0YGY70080YW]80P2WO4T0102XODX0Zh5?0:Z0CP2XOT`20:MmB`03
0:QnC02ZP4h0Zh5?0080YWe900H0YGa60:Ak@`2RNSl0XGTn0:1h>`2OMcX209ma?@0309aa?P2KLCl0
VG500080UW1100<0UG1309=]?P2CKCh00P2BK3d01@2AJc`0T6Xk091Z>`2?JCX0Sf/k0080SVXj00<0
SFTi08aX>02;IcL00P2:ISH01P28HCP0Qf0g08IO=P25GSD0Q5dd089K<P80PEXa00X0Q5Xd08=I<`1o
F340O5H_07]E;P1iERh0NEP_07YI<01fDbd0Me@^0`1hEBl0101gE2h0MU<]07EB;01gD2l207EA;`03
07=A;P1bDBh0Ke4]0080KU8]0P1ZDR`00`1ZD2/0K50[06e?:`0206m>:`06071>:`1aCBT0LThZ07EB
;01gE2`0NEH/0P1iEbX01`1hERP0OUL`07iG;P1oF2l0OeP]081J;@21Fb`00P22G2/308QN;080REl]
0`2:H2h308YU<@80RfHb102<Ic<8099X=PP0TFDh202?IC<01P2;IS40RfHb08YU<@2:I3<0RF<d08US
=P80R64f1@2=HSP00`2<HCL0Rf0f08]P=P0808YN=`0308IP<`28HSD0RF<f0080RV@g00@0RF<f08QR
=@26H3<0S64d0P2;H3<208YO<P80REha00<0R5d`08MQ=027HC@00P28HSD308US=P0:08YT=`29Hc@0
RV@e08]U=P2<ISL0RfDf08YT=@28HS<0QV0a08iS=P<0SF8e00@0SV<f091U>02BIcX0TfPk0`2?JSH0
0`2>JCD0SFPd08eX=00208aW<`0608YT=@2;ICH0S6Hg08eW>02>J3T0SfTj0P2@JS/02`29I300RVDa
08]V<P2;IS80RF@`08MR;P25H2`0Q5l[08IO=028HCH0RF8g0080Rf@i00<0RV<h08UR=`28HCH00P2=
IcP608aV=`80SVPi00H0SFLh08aV=`2=IcP0SVPi091Z>`2BK3d308iX>`<0SFLj0P2<IST208]W=`<0
S6Ph102=JCT0402>JCd0RVDi08QS=P29ICD0SFTg08iZ=P2<J3@0R6D_08QU:`29IRh0RfP`08aY<`2<
J3@0RVHd08UU=@27Hc<208]W=`80RVHf0P29ICD208QT=0P0Qf8e0P21Gc42089P<P0408=Q<`24HS@0
Q68d08AR=0@0PV0b0P21Gc42081N<006085L<P1oG380Oe`b07eL<@1lGC40NE``0P1hGC0207MJ<006
07II;`1dEbd0LUD[075D:P1`DbT0Ke8X0P1aDR<05P1`DB<0L54U06m?9P1^CRL0KDdV06e=9`1[CBL0
JddY06U=:01VC2T0I4`Z065::P1PBBX0GTTZ05a88`1JB2@0F4HR05=38@1?@1l0BchN04Ll7P16>ad2
03hj7@0603di7P0k=a`0>SHM03Pc7@0g<Qh0=S4M0P0h<b000`0g<Ql0=S4N03D`7@0203@_700403<^
6`0^;ad0;RlM02h_7@80;BhL0`0/;A/01@0^:R40;BTP02dY800/:1l0:RHM0080:BDL00<0:2@K02HW
7`0V9al00P0U9Qh302@U7@0302<T700U9Qh09BHN00H09BHN100S9Qd2028U70808B@K2@0P8aX2024T
6`H082<J100R9AX202<V6`8092LL00<08R@F02<U5`0U9aT00`0W:A/202DW6@P0:2`M0P0Z;Ql202T]
7P<0:2`M00<09b/L02P/7@0X;1d01P0X;1d802X/7P0302h_8@0];R00:b`N0080:R/M00<0:b`N02d^
800^;b40200[;Qd00`0[;Al0;2hP02d_8@0202d_8@0<02/]7`0Y:ad0:2XL02PY5`0Z:aT0;2dK02d^
700^;ad0;BhL02`]6`0[;1X0:BXJ0`0Z:a/202//7080;2dM0`0/;QT202d_6P<0;S0K0P0c<1d6038_
70P0<c0M00H0>C8O03Xb7`0j<Ql0?34O03d`7`0o;al2040_7`80>S8M0`0k<ah303`d7`P0?CHL00@0
@CLL048h7@12>1d0@SPM0P13>Ah404@j7`0<04<i7P12>1d0@SPM048h7@14>Ql0AS`Q04Lm8P10>Ad0
@CXN04<i7P15>Al0BC/Q0P1;>b80101=>b<0AS`Q04Hl8@16?24204Dk80<0A3XO0P19?B<02@1:?R@0
BclU04Xn9018?280ASXP04@h7P16?B00AC`O04@k7P0204<j7@0304Dl7`17?R40B3lR00P0AS/O0`14
?Q`304Do7@80AT0N1015>B4404@h800804Lg7@18>1h0BSXP04/k8@1<?280Bc/Q04Xj8019>Al204/k
8@80BSXP0`19>Al01018>1h0AC/P04Dk8015>b0304@j7`80@cTN0`10>ah203lj7@<0?STL00<0A3XO
04<i7P11=a`00P10=Q/02`11=a`0@cTN04@j7`0n=1T0@3HK04@j7`16?240AcdR04Dk8012>1d0@3HK
00T0@SPM00P0@CLL040f6`10=Q/0@3HK048h7@14>Ql0AC/P04Pm8@80Ac`P00D0AS/O04@i7@13>1`0
@cPL048g6`0204@h7P80ACTO0P16>R0204Lk8@<0AchQ0`16?B0204Dl7`@0ACXN0P14>Ad304<h70P0
@cTN0P15>Qh304Hk7`<0Ac`P00H0DShK05<o701D@1d0ET8O05Q48@1JAR<205a89@H0HddX0P1RC2L2
06IA900806UB9P1[DbL0Ke@Y079E:`1eEB`0MUH]07=G9`1fFRX207YN;P80N5`/00P0Nel_07mS<`1o
GBd0Oed]081N;P21Gbl0PV0`08=Q<@80Q68b0100RFDa08YV<P2;Ic<0S6Pd08iZ=P2?JcL0T6`h095]
>@2@K3`0TFdm09=_?`2DL400UG5109A`@02CKcl0TVhn0`2GMDD509IdA0<0Wg];102PO4`00`2QODd0
X7a<0:1lC0020:5mC@80XWi>0P2SOdl20:B0D0030:F1D@2VPU80Yh=C0080Z8AD00@0ZHEE0:V4E`2Y
Q5L0ZHAG0P2ZQEP30:^6F@80ZXEH0P2[QUT40:b7FPP0ZXIF00P0ZhII0:b7FP2^RE`0[hYM0:j9G02]
R5/0ZhII0:Z5F0P0[HQK0P2/QeX30:^6F@<0ZXEH00<0ZHAG0:b7FP2/QeX00P2[QUT30:Z5F0040:V4
E`2ZQUH0ZXIF0:Z6EP80ZHEE0`2XQ5@0202SOU40YX5D0:V4E`2/QeX0[HQK0:^6F@2YQ5L0Yh9E0`2Z
QU@20:V5D`<0Z8AB202XPU<50:R3EP<0ZHAG0P2ZQEP20:V4E`040:R3EP2WPUD0Yh9E0:N2E@<0Yh=C
0P2VPU830:F1D@P0Yh=C0`2VPE@20:N2E@<0Z8=F0P2UOdh01P2WPE00Z89A0:N1D02VP4l0Y7i=0:=m
C080XGa80`2SOTX00`2QO4P0WgY609iiA@080:=mC080Wga600@0Wg]709mkB@2NNTX0WWY:0P2MN4/3
09ahAPD0WGU70P2LLdD609edAPP0UG510`2JLD<209U`@P<0V6m100<0Ufe309I/@P2FK4800P2FK482
09E[@@80U6Y000@0UF]109AZ@02AIcd0SfDk0P2>I3X01@2?IC/0T6Hl08iX>@2>J3T0SFLh0080S6Hg
00H0SFLh08iX>@2>J3T0RV@e08]U=P2<ISL208eW>00408aV=`2;ICH0RV@e08YN=`L0Relh2026GcH3
08EN=@80Q5dd0`23G3<3085L<0D0PUda0`21G302081K;`<0OeX^0P20E2d01`1nE2`0Ne@[07UD:P1g
E2X0MU<Y07AC:01gE2X00`1fDbT207EB:080M54W201gE2X01P1fDRh0ME4]07EA;@1dD2`0Ldl[079>
:P80LDdY0P1`CBL01`1^C2H0K4`U06U<901XC2@0Id/S06A;8P1/BbP00`1]C2T01@1/BbP0JTTV06Q7
901VAB80JdLW00<0JTHV0P1YABD206Q49080ITDV0P1WARL0101VABH0I4<T06508@1P?b0806118P80
ITDV00H0ID@U06A3901S@R<0HT4R06508@1P?b0205Pm8080FChQ0`1J?b8205]08`0805Xn9P1K?bL0
G40X05a0:01K?bL0FCdU05Lk8`1E>B4205<k8@0405@l8P1E?B<0EShT05Lo9@80F40V00<0E3`R05<k
8@1B>R000P1A>Al00`1B>R00Dc/Q05@l8P0204hm8`0404dl8P1<>b40BcXP04Xi7`80BCPN0P1:=B00
0`1;=R40C3LR04dh8`0204hi900304lj9@16=BD0ASDU00H0ASDU0`12<B43044`8080@2lO0`0o<R82
03ha8@<0?C0P00@0?CDR03/c800i<Ah0=blL0P0f;Q/203L_700303P`8`0g;b80=BdP00<0<b/N00<0
=BdP03H^8@0d;1l00`0c:ah2038Z7@80<BTL200`:1/802lV7@<0:RDQ0P0Y920302PS7`P0:BDL200V
8aX802<T7PP08R<M0P0N7aT201lP6P<0824K100Q8Q`2020Q6`<07b0J00<07QlI01lP6P0O81X00P0P
8A/2024R70808R<M0P0S8Qd3028Q70<08B0K200P8A/01P0R7AT08ahJ02@O6`0U81`09R4M02LR7P80
:2<O00D0:2<M02LR700W8Q`09b8L02HQ6`0302DP6PP08b8M200R8ad802<S6`P0:B@N0P0V9Qh202DU
7@0402@T700S8a/08b<K02<S6`P08b8M0`0R8QX202<S6`<092@L200S8a/302@S7P808b8M0`0R8A`8
024R70P08R4L200R8a/3024Q6@03028R6P0S8a/08b<K00<092@L00D08B4I028R6P0R8QX08b<K02@T
700202DU7@0402HV7P0T91`092@L02@T70<09BDM0P0V9Qh802DU7@P092DM200U9Ad@024R710082<L
0`0P81h[ooooo`00:_ooool309U]?080V6`k0`2GJcX309Q]@080Uf`o0`2FJch309]_@P80VVi10`2I
KD000`2IKC`0VVhm09]_?P0209a`?`0409]_?P2JKSd0VFdl09ebA@<0W7540`2KL4<00`2JKd80WWA2
09id@P0609id@PT0WG8o0`2NLd0409md@@80WgE30P2PMT@20:5gA@80XWQ600@0X7E:0:1eB02PMDP0
X7I60P2QMdD01P2QN4@0XGQ20:5h@P2PM4<0XWI50:EiB080Yg]:00<0YWY90:AhA`2RMTD0202UNTL0
0`2RN4H0XgU70:AjB0020:EkB@030:AjB02SNDL0XWQ60080Z7e:0P2WO4T20:IkB080YGY70`2WO4T3
0:QmBP80ZGi;00<0ZX1>0:UoC@2WOD/00P2VO4X00`2WOD/0ZGm=0:Z0CP020:IlBP060:ElB02SNT@0
XWU10:1h?@2OMc`0WgLj0P2NL3`00`2KL3d0VW0n09Ua@00209Ma@P0709IaA02EKd00UFm009A^?`2C
KCh0TV`m095[?002091Z>`80S6Ph00<0RfLg08YV=P29ICD00P28I3@04`27Hc<0R64h08MP=`26GcH0
QEhe08=L<`22Fc80PEXa081I<023FC<0PUPb07mH<@1lERl0NeD^07UF;P1hEbh0NEP_07MD;P1fDbd0
0`1eDR`0301fDbd0N5D_07QE;`1hDC00MU8`07EA;`1dDRl0LU4^071B;P1_Dbh0KU8]06UA:`80JU0[
00<0K50[06e?:`1_CR/00P1`CR/01@1`C2P0LThZ07AA:`1fDb/0N5D[0080N5HY00L0MeDW07iG<01o
F2l0OeP_081I;P21Fbh0PU`]0080Ped/0`29Gbd208YP;P<0Rf4_0P2:IC4208]V<P@0S6Lc00<0SFPd
099X=P2BJ3H01P2BJ3H8095U>080TFLe00@0T6Hd08mU<`2?IC<0SV@b0P2=Hc401P2;IS40RfHb08YU
<@2:I3<0RF<d08US=P80R64f00P0Rf0e08aQ=P2>HcP0T6Dj08mT>@2=HSL0RUld08QM<PP0RUhg00<0
QV0c08QR=@29HcH00P2:I3L00`29HcH0R68e08IP<`0308]P<`80RUlb0`29GS4308QR=@80RF<f0`2:
I3L03029Hc@0RV@e08]U=P2<ISL0RfDf08YT=@28HS<0QV0a08]P<`2<HC@0SV<f091U>0<0TFHi00@0
T6Dh08eX=02=J3@0SFPd0P2<Ic<308]V<P80RfDf00<0S6Hg08eW>02>J3T00P2?JCX00`2@JS/0RF@`
08YU<@0208]V<P0408YU<@28Hbl0QV4]08AO:`80RfDh0`2=IcX00`2<IST0RV@g08US=P0308aV=`D0
SFLh00<0SfTj08iX>@2=IcP00P2<ISL00`2>J3T0T6Xk095[?00308iX>`<0SFLj0P2<IST208]W=`<0
S6Ph102=JCT05P2=J3`0RfHj08UT=`2:ISH0S6Pf08eY=@2;Ic<0RFH`08QU;@29IRh0RVLa08]W<`2;
IcD0RfLg08YV=P29I3L0SFTi08aX>02;IcL0RVHf08UU=@27Hc<208IR<PP0Qf8e0`22H38308=Q<`80
Q68d0`22H382085O<@<0P5h`00P0PUdc081M<`1oG380OUdb07aM<@1jGC40NEha07QM<080MUT_02@0
MEP^07AG;@1bEB/0LE@Z071C:@1_DRP0Ke<S06mC901^DR<0KE0T06a?9@1[CRH0JddW06Y<9P1ZC2P0
J4`W06M::01TBRT0HDPY05m8:@1LAbP0FdHY05Q5901GA2<0Dd<R04m08@1<?R40Ac`P04Dj7P13>Ah0
?CTL03`h7@0k=a`0>SHM03Td7P0g<Qh203Ha7P80=c8O00<0=S4N03D`7@0d;a`00P0c;Q/0100b;AX0
;BhN02d^7P0];Qh202`]7@<0:b`L0P0]:B000`0/:1l0:bLN02XV7@0202TU700402PT6`0U9Qh09BHN
02DV7P8092DM0`0S91`802@U7@<08bHM0P0R9A`3024T6``082<J1@0Q91/3028U6P808bHK0`0T9a`0
200S9AL092HH02HX6P0W:A/0:2XL02LY6`0V:1X09BLI200X;1d302T]7P80:2`M0`0W:a`802T]7PP0
:2XL00<0;BhP02`]7`0[;1h00P0Z:ad00`0[;1h0;2dO02d^800802X]700;02T[7@0Z;1h0:R`N02/]
7`0Z;1h0:B/M02PZ700W:A/0:2TI02TZ6P0[;1`00`0/;Ad202//70<0:BXJ0P0Z:a/302//700402/]
600/;QT0;2hI02`^6@80;BlJ0P0^<1/@034^6`0603Pc7`0i<Ql0>C8O03Xb7`0l<Al0?C0O0P0o;al3
03Ta70<0>S8M0P0k<ah803df70<0@CLL0P12>1d304<i7P80A3XO00l0@cTN048h7@11=a`0@SPM04<i
7P15>b00AS`Q040i7@11>Qh0@cTN04Di7`18>R00BSXQ04/k8P1<>R801014>Ql304Dk800404Hl8@17
>b40Ac/Q04Pl8P80BCdS00D0B3`R04Lk8@16>R00AC`O04@k7P0304<j7@0304Dl7`16?B00B3lR00P0
B3dQ0`18?ah304Ln7@80ASdL0`17>b401P16>R00ACTO04@h7P14>1h0@cLM04Xj8080Bc/Q00H0C3`R
04/k8@1:>R00BCTO04Ph7P1<?28304/k8@80BSXP0P19>Al204Hl8@80AC/P0`14>Ql00`13>Ah0@S/O
048k7`02044j7P<0@3TM00@0?cPL04<i7P13>Ah0@SPM0P11=a`01P12>1d0@cTN04<i7P0n=1T0@3HK
04<i7P80AS`Q00<0AC/P04<i7P11=a`02012>1d00`13>Ah0@SPM044g7002040f6`03048h7@14>Ql0
AC/P0080Ac`P00@0AS/O04Dj7P15>Qh0A3TM0P13>1`404<g7@80A3PN0P15>Al304Dl7`<0ASdP0P17
?R400`16>al0ACXN04Dj7P0204Dj7P80A3TM0P13>1`804<i7P80ACXN0`16>al304Ll80060590701C
@Ad0E48N05I4801HAR80FDLS0P1KBBD01P1OBB@0H4XU061:9@1QBbH0HT`W06==:080I4hY0P1WDRD0
101YDRH0Je<W06iC:01`DbT207=C:P04071D901dF2P0N5`/07QL;080MUXZ00P0NEd]07aP<01oGBd0
Oed]081N;P21Gbl0PV0`08=Q<@80Q68b0P29IC402@2:IS80S6Pd08eY=@2>JSH0Sf/g091/>02AKCd0
TVhn09A`@00309Ea@@80U71000<0UG=309IdA02FM4@01@2FM4@309ijBP80Wg];1@2PO4`20:5mC@80
XWi>0P2SOdl20:B0D080YH5A00D0YX9B0:N3D`2XQ5@0Z8AD0:R3EP030:V4E`80ZXEH0P2[QUT30:Z5
F080ZhII0`2/QeX80:Z6EP030:^6F@2/QeX0[HQK00<0[HQK00<0[8MJ0:^6F@2/QeX01`2/QeX20:f8
F`<0[8MJ0`2[QUT00`2ZQEP0[HQK0:f8F`020:b7FP<0ZhII00@0ZXEH0:^7E`2[QeL0ZhMG0P2ZQUH3
0:V5E@090:F0D`2WPUD0ZXEH0:b7FP2]R5/0ZhII0:V4E`2WPUD0ZhMG00<0ZXIF0P2YQED20:R4E0P0
ZH=D202XPeH20:V4E`80Z8=F102WPUD20:R4E080Yh=C0`2VPU890:F1D@80YX5D0`2UP5<30:AoDP03
0:AnC`2UOe00YX1A0080YX1A00D0Y7i?0:9lC@2PNT/0X7]70:5lB0030:9mB@030:1kA`2ONTH0WGQ4
00P0WGM800H0VWM109Yf@P2IMD40VGE309QdA02HLdH209MbAPP0UW920P2EKd800`2DKT40Tfe0099/
?`02095[?P03091Z?@2?JSd0SfXm00H0SfXm00@0TV`o095[?P2AJch0TF/n0P2@JSd208mY?080SVLn
0`2=ISd308aU?00508]T>`2<IC`0Rf@k08UR>@27H3L00P26GcH01@27H3L0R64h08AO<P25H3<0QV4d
0080Qf8e00H0QV4d08EP<`24Gc80PUd`08=N<@24Gc8208EP<`0308AO<P23GS40PUd`00P0PEXc2021
Fc@307eG<080O5H_0`1kEBh807QE;@<0MU<[0P1eDRX307AA:@0807E=:@1dC2P0LddX071=9`1^C2H0
K4`U06];901YC2@206a<9@<0Jd/T0`1ZBR<8071@:@80KD`[00<0K4/Z06]::@1ZBBP00P1YB2L01`1X
AbH0ITDT06E48`1SAB<0HD@R05i48@1LA2000P1JA1l0201RABD0HdHV06A79`1TAbL0HdHV0654901O
@R80GD0P0`1L?B4205/l80<0FS/O00P0FS`R05/m8`1L?R@0G3hT05/m8`1I>b40EcTO05Hh7PP0E3XO
0P1K?B<00`1J?280FC/Q05Pj800205Li7`0305Hh7P1?=al0CcLO00@0D3PP0`1A>B400`1?=R00D3LQ
058i8`0205<j9003054h8P1@=b40CcHP0080BSHN0P1;=al01`1<>200CCTQ04hj8P1>>R80BCDM04Lc
6`16<QX00P15<AT00`16<QX0Ac<K04Te7@0204De7P0404@d7@13<a`0@S8K048b6`80@C4J2012<Al8
03`_7`<0>B`L0P0h:a/303LZ6P@0=RXN0`0g:al0100h;200=RdL03D/6`0c:QT2038Y600603<Z6@0e
;1/0=RdL03<]8@0b;200<2XN0`0_:Ad2030Z7P80;bTM0P0^:1`302dW6`T0;2HJ200/9Ad0100X8al0
9b8N02LR7P0W8Qh202HQ7@809B0L200V8A/802<S6`P0824K200Q8Q`201hO6@<07b0J1`0P8A/201lP
6PH07QlI0P0O81X3020Q6`0402<R7@0R8A`08R4L028Q70808B0K0P0P7aX801lP6P808A`H00@08QdI
02<N6P0T7a/091lK0P0U81`202DP6P<09R4K0`0W8Q`802<R7@P08R<M200Q8AT802PS7@<09BDM0P0T
91`302<S6`P08b8M00@08B4I028R6P0R8QX08R8J0P0S8a/202@T70P08b<K0P0T8ah202<R7@<08R4L
00<08B0K020Q6`0P8A/01P0P8A/8024P6`P08R<K00@08B4I028R6P0R8QX08R8J100S8a/902@T70<0
9RHN0`0U9Ad202@T70P09BDM200T9Ad802DU7@P08R<M200Q8Q`@020S70<0820N:oooool002[ooooo
0`2HK3/209M[>P<0UVXi102HKD0409M/?`<0Vfm20P2JKT4309U]@00309U]?02JKSd0W70o0080WG50
00<0W70o09Y^?@2IKC`0102LLD@409]`@`P0WWA2202NLd001P2LLCh0WG8o09eb?`2NLd00WgA10:1e
@P80XGI30P2OMD<20:1fA080XGM50P2RN4H0102NLdP0WgA709mdA`2PMTH20:5gA@060:9iA@2RND<0
XgY40:5eA02RMTD0Y7Q70`2VNTT00`2TN4L0XgM60:EjA`070:EjA`030:9hAP2SNDL0YWa:0080Yge;
00<0YG]90:9hAP2PMT@00P2XODX20:MlB@80YW]80P2UNTL50:UnB`<0ZWm<00<0ZGm=0:QnC02VO4X0
0P2UNdT02`2VO4X0Z7i<0:UoC@2VO4`0YG];0:AjB02SNTH0XGQ20:1g?`2OMc`0WWHk0080WFlk00<0
Vg0m09Y`?P2ILD000P2GLD801`2FLD@0UW1109I`@@2EKd00U6ho099/?@2AJc`00P2@JS/01P2:ISH0
RFDe08UU=@28I3@0Qf<c08IR<P80QF4a0P27H3L01026GcH0Q5dd08=L<`21FS42081I<006089H<P21
Ec40OUL`07aF;`1kEBh0NEH^0P1gERd03P1gE2h0ME8/07=@:P1bCbT0Le0Z07EB;01hEBl0NULa07QA
<01fDS00ME4_07AB;`1cDRl0L58^0P1_Dbh01P1YCbX0K50[06a@:`1]Cb/0Kdh[075?;080LTh/00D0
L4`X075=:@1dDB/0MU<[07QE:`0207QF:@0707ME9`1oF340OeP_081I<021FRl0PU`_08=M;P0208AN
;@<0RV0^0`2;HBl208aR<0<0SFDb102>IS<208mW=0P0TfTg202AICP2099X=P04095W=@2@IS@0SV@b
08eS<@80S68`00H0RfHa08]V<P2:IC40RV@c08US=029HcH208QQ=P0808UN<@2<HC@0Sf@g099W>P2A
IST0SV<f08UN<@27G2l808YO=@0308IP<`28HSD0RF<f0080RV@g00<0RF<f08QR=@26H3<0202:Gc82
08QR=@<0RF<f0`2:I3L03029Hc@0RV@e08]U=P2<ISL0RfDf08YT=@28HS<0QV0a08YO<P2<HC@0Sf@g
095V>@80TVLj00<0T6Dh08iS=P2;IS800`2;IS8408YU<@<0S6Hg00<0SFLh08iX>@2>J3T00P2?JCX0
202>JCD0SfXf091[=`2AK3P0T6/g08iY=@2<Ic<0RfHb0P2>J3T01P2?JCX0T6Xk08mY>P2=IcP0RfDf
08US=080S6Hg102=IcP208iX>@0308mY>P2>J3T0SFLh0080S6Hg00<0SFLh08mY>P2@JS/00`2>J3/3
08eW>P80S6Hi0P2;IcL308aX>0@0SFTi00P0S6Lk08]V>P2:ICP0RfLg08]W=@2<J3@0RfLc08YW<@80
R6D_00<0RFDa08YV=02:ISH00P2;IST02@2;ISX0SFTi08eY>@2;IcL0RVHf08QT=026HS80QF4a08AP
<00808MR=@80PV0b1P23HC<2089P<P80PEla0P20GS0207mM;`06089M<`20GC<0Oe`b07iM<P1mGS80
NUda0P1iGS4207EH;P0407AG;@1cER`0LUD[075D:P80L5<Y00H0KU<T06eB9@1]DRD0K54V06]?9`1Z
CRL206U=:00H06M::01TBRL0HdTX0617:01NAbP0FTDX05Q59`1G@bP0DT8Q05508P1?@2<0BcdP04Ll
8013>Ah0@CLN03hg7@0k=a`0>SHK03Xf7@0i=1h0=c8N03Ha7P0f<200=BlO0P0f<200100e;al0=2hN
03<]7@0c;Ad2038/70<0;2dO0`0[;1h202X[7@80:bPO0P0Z9ah0100Y9Qd0:2DL02PU700X9A`202DV
7P<092DM0`0S91`802@U7@808bHM0P0R9A`2024T6`d082<J100Q91/2028U70808RDJ0P0S9Q/202@W
70809BPM00P092HH02DW6@0W:A/0:2XL02T[7@0X:Q`09bTK02HX6PP0:2`M0P0Y;Ah302P/7@<09b/L
200Z;Ql802LY6`P0:b`N200Y;1/402PZ70809bTK0P0V:1X0100X:A/0:BXL02TZ700Z:ad402//7P<0
:BXJ0`0Z:a/202//7080:b`J0`0/;A/302d^70<0;b`I100`;AX00`0a;Q/0<2dJ030]6P06030]6P80
>3<O0P0i<Ql0100j<Ql0?34O03d`7`0m<1l403P`6`80>C4L0P0j<Qd203`e6`@0?CHL0P0n=ad3044g
70<0@SPM0P13>Ah204@j7`0704<i7P12>1d0@CLL044g7013>Ah0AC/P04Hl8@02044j7P0604<i7P15
>Al0B3XP04Ti801:>R40BcTQ0P12>1d00`13>Ah0A3XO04Dk800204Hl8@0404Lm8P15>Al0ASXP04Hj
80D0Ac/Q00P0AC`O04@k7P13>Qd0@STL04<j7@14>ah0ASdP04Ln8@P0BChR00D0Bd0P04Xo7`1:?al0
BChN04Pm7@0204Ll700604Hk6`1;?B80BcdR04Xl8@19>b00B3XO0P17>Ah01`16>1d0CCdS04dm8`1=
?B<0C3`R04/k8@1:>R000P19>Al404`l8P80Bc/Q0P1:>R0304Hl8@80AC/P0`14>Ql204<l8080@S/O
0`11>Qh00`10>Ad0@cTN04<i7P04048h7@80@cTN00<0?cDJ044g7013>Ah00P15>b000`14>Ql0@cTN
048h7@0804<i7P0304@j7`13>Ah0@SPM0080@CLL00@0@SPM04@j7`15>b00Ac`P0P16>al204Dj7P80
A3TM00<0@cPL048f7012=Q`01012=Q`204<g7@0504<j7@14>ah0A3/N04Dl7`16?B000P17?R401018
?b80AS/O04Hk7`16>al304Dj7P<0A3TM2013>Ah204Dj7P<0AS/O0`17?2001P1@@1h0DD4O0592801C
@b40EDDS05M79@80F4PV00h0G4HQ05e78P1NB2<0GdTT065;9P1SCBP0I4hY06E?:P1WDRD0J5<V06UB
9P1ZDRH0KE8W06mB:080LE4X00P0KE4Q079F9P1fFRX0Me/[07EI:@1dF2P0Me/[07YN;P80Oed]00@0
P5h^085O;`22H300Pf4a0P24HS8208QT<00408UU<@2;Ic<0S6Pd08iZ=P80Sf/g0P2CKcl00`2DL400
UG5109Ea@@0309Ea@@<0U792102ELd<01@2FM4@0W7Q809ahB02MNDT0WWY:0080Wg];102PO4`20:5m
C@80XWi>102SOdl0102TP500YH5A0:J2DP2WPe<20:R4E080Z8=F0`2YQ5L30:Z5F080ZHAG0P2ZQEP2
0:^6F@80[8MJ202ZQUH00`2ZQEP0ZhII0:^6F@0=0:b7FPD0[HQK0P2/QeX20:^6F@@0[HQK0P2/QeX2
0:^6F@<0ZhMG0P2ZQUH30:V5E@030:J1E02XPeH0ZXEH0080ZhII00<0ZXEH0:R3EP2WPUD00`2ZQEP2
0:V4E`<0Z8=F202XPU<20:R3EP@0Yh9E2P2VPE@20:N3D`80YX9B0`2UPE400`2TP500Xgm?0:=oC`06
0:=oC`80Y7mB00@0XgiA0:9mD02PNdh0WgY=0P2NND`0402QNdh0XWa?0:=mD02SOE00XWa?0:1jC@2M
MdX0W7I909egAP2NN4L0WgU80:1jB@2ONDP0WWQ709afA@2JM4<809UcAP0809Ib?P2FLT00UG4o09Ea
@@2DKd80U6m309A_A@2CKT@4099]@0@0TF`o00H0T6/o08mZ?P2>JCd0SFPl08]V>P29I3P208QS=`P0
RfHj0`2;IS`208YU>`<0RF@j00<0R6<i08MR>027HSP00P27HSP208IQ=`80QF0f00/0QV4g08EP=P23
GS@0PE`b081K<@21G380PUdc08=N=01kF2h0OEX`07mL<P02085N=00607mL<P1mFS00NeP^07YG;@1k
F2h0OEX`0P1nFc400`1mFS00NeP^07YG;@0307]E<@<0NU@`0P1iDbl807ME<00407IB;P1eDBd0ME4]
07EA;@80M50/0P1cCb/3075@;@<0L4l/0P1_CR/306e<:@80K4/X0`1[BRL206Y79`0606Q79P1UAbD0
HdHT06958`1PAR<0GdDR0`1RABD2065490<0H4<S201UB2P01P1RA2P0HD<W06539`1P@RH0Gd4U05i0
9080GClS0P1J?b@00`1H?R<0EShR05<n8@02054n800304hm7`1E?B<0EShT00<0EclU00<0ECdS05<k
8@1B>R000P1?=al304hf7P<0CCDM0P1;=B001P1<=R40CCLR04`f8@1;=B00BC<N04La70P0Ac8M0P1;
=B0204Xd7`80BC<N0P18<Qd4048`70D0@c4M00H0?bhL040_7@12<Al0A3<Q04Dd8P14<b4204<b8003
03l^7010;ad0@2lM0080@C0N0P12<Al01013<R00@2lM03l^700m;1X203`[6@0403d/6P0o;Q`0@2lM
03X]7080>B`K0P0h:aX203LZ6@0503HY600h;1`0=b/K03L[6`0f:QX00P0e:AT203@X60P0<RPL0`0`
9QX202lU6@<0;R@H0P0[8QT0100/8aX0;B@K02hU700^9A`202lV7@80;RHI00P0;BDH02`T5`0]9AP0
;bLJ034Y700b:Qd0;2PM02/W7080:RHK100Y9AX0100Y9A`0:2@K02PT6`0X91/202LS6P809R8I200W
8aP802LS6P<0924L0P0S81/;028O6PP0824K200N7aT8020Q6`807QlI1`0O81X2020Q6`<07b0J2`0N
7aT3028Q70808B0K0`0P7aX801lP6P<07a`G00<081dH024N6@0Q7QT00P0R7aX01P0S7QP091lI02DP
6P0V8A/09b8L02PS7@80:B@N0`0S8Qd4028Q7003024P6`0Q8Q`08B8L00H08B8L200P81P802PS7@@0
92@L100S8a/802<R7@808B4I0`0R8QX302<S6`P08R8J0`0S8Qd3028Q70808B0K200P8A/8024P6`P0
8R<K2@0S8a/302DU7@<092@L0P0S8a/01@0X:2009bLO02LW7`0V9Qh09BDM008092@L00<08b<K02HV
7P0V9Qh01P0V9Qh802@U7@P09BDM200R8ad8024R710082<L0`0Q8Al[ooooo`00:_ooool309Q/>`80
Uf/j0`2FJST809Q]@0<0Vfm20P2JKT4309U]@00309Y^?@2KKch0W70o0080WG5000<0W70o09]_?P2J
KSd0102KL4<409aaA0P0WWA2202NLd0209eb?`0309ic@02OM440X7E20080XGI300<0XWM409me@`2O
MD<00P2PMT@20:5gA@80XWQ600@0WW=809mdA`2OM4L0X7I60P2QMdD02@2RNDD0XWU30:=jA02QMD@0
XWI50:AhA`2UNDP0YWY90:EiB0020:AhA`P0YW]800P0XgU70:EkB@2WOD/0Z7i<0:MmB`2UNdT0XWQ6
0:1fA080Z7e:0P2WO4T20:IkB080YGY71P2ZOd`20:UnB`030:QnC02WOD/0YWa:0080Y7Y800<0YWa:
0:MmB`2XOT`00P2UNTd0102TNTX0XWQ60:5hA02OMT0209ie?@80WW0l00<0W74n09Y`?P2ILD000P2G
LD801`2FLD@0Ug5209I`@@2EKd00Tfdn099/?@2@JS/00P2?JCX208QT=00408MS<`26HS80QF4a08EQ
<@80Q60`00P0Qf0g08IO=P25GSD0Q5dd089K<P21FS40P5T`07mH;`80PELa00l0OUL`07eG<01lERl0
NEH^07MF;@1fEB`0Me@^07EB;01cD2X0LDhX079?:@1dDB/0MU<]07QE;`1gD2l00P1eDBl00`1cDBh0
LU4^06mA;@0206iB;@0606]?:P1/CRX0K4hZ06m>:`1aCb`0LTh/0P1eCRd01@1aCBT0LThZ07EB;01g
E2`0NEH/0080NELZ00L0N5HX081I<P20FC00PEXa089K<023GC00Q5h_0080QEl^102;HBl208aR<080
SF<a0P2>I38308mU<`@0T6Hd202CJCL8095U>080TVPf00@0TFLe091V=02>I380SF<a0P2<HS001P2;
IS40RfHb08YU<@2:I3<0RF<d08US=P80R64f00P0REl_08aR<P2?ICD0TVPh095W=`2>I3@0REl_08MM
;@P0RUld00<0QV0c08QR=@29HcH00P2:I3L00`29HcH0R68e08IP<`0808YO<P<0RF<f0`2:I3L208]U
>00<08US=02:I3D0RfDf08aV=`2;ICH0RV@e08QR<`26H340RUlb08aQ=02?I3L0TFHi0P2BIcX00`2@
ICP0SV<f08YU<@0708YU<@0308aV=`2=IcP0SFLh0080SFLh0`2>J3T00`2>JCD0SfXf091[=`02095/
>00308mZ=P2>JCD0S6Lc0080SfTh00H0T6Xi095[>P2@JST0SVPg08aV=@2:I3<208aV=`80SFLh0P2>
J3T308mY>P0708iX>@2<ISL0RfDf08]U=P2<ISL0SFLh08iX>@0308iX>`<0SFLj0P2<IST208]W=`<0
S6Ph102=JCT03@2:ICT0RfHj08aW>P2;IcL0RfLe08YV<P2;Ic<0S6Tc08YV<P29IC40RFDc08UU=@29
I3L00P2:ICT01`2;IS`0SFTi08aX>02;IcL0RFDe08MS<`26HS800P24H30808MR=@H0Pf4c0P22H383
085O<@80P5h`0`1oGBl01P21G380Oe`b07mL<P1mG340O5da07UL<080N5d`0P1dEbd0101cER`0LUD[
079E:`1aE2X2071C:@0P06]C9@1[DbL0JU8V06U@9`1XCbL0IddX06M=:P1VC2T0HdTX06599`1PAbP0
GDHW05U49`1F@RL0DT4U05509P1=?R40C3`R04Xl8@16>R00@SPO03hf7`0m=B00>cDO03Te700h=1/0
>3<M03Lb7P0f<Ah0=BlO03D_8@0d;R0203D_8@80=2hP00@0<bdO038/7P0a:ad0<B/M100[:al202XZ
7P80:BTM00<0:2PN02LW7@0W9ad00P0W9ad302HV70<092DM0`0S91`2028S6`P08b@L0`0R9A`2024T
6`h082<J0P0Q91/2028U70808bHM0`0S9Q/202@W70<09BPM00P09BLI02HX6P0X:Q`0:B/M02X/7P0Y
:ad0:2XL02LY6`/0:2`M0`0W:a`202HZ6`P0:BdN200V:1X202X[7@@0:b`N0P0Z:ad802P[6P0302PZ
700W:A/09bTK00809RPJ0`0U9aT402PX700402TY7@0Z:Qh0:RXN02/[7`80:2TI0`0Y:QX302X[6`<0
:b`L0`0/;Ad202d^7P80;R/H0P0_;1T0100`;AX0<BhK034^6`0a;Q/802l/6@80=C<N00@0=c8N03Pa
7P0i<Ah0>C4N0P0k<1h403P`6`80>C4L0P0j<Qd00`0k=1X0?3DK03`e6`0203df7080?SLM00<0?cPN
040f6`10=Q/00`11=a`3048h7@80@cTN00L0@SPM044g7010=Q/0@CLL048h7@14>Ql0AS`Q0080@CXN
00<0@cTN04Di7`17>Al00P18>1l01`1:>200@CLL048h7@12>1d0@cTN04@j7`15>b000P16?24404Di
7`80ASXP0P17>b400`14>ah0@cXM048i7002048i700304@k7P16?B00AchQ00P0BSlS0P1=@200101<
?al0BchN04/n7P1:?Ad204Tl7080CChQ0P1<?B00201;?1l0BS/N04Xk7P19>Qd0CclU04hn901=?B<0
C3`R0P1;>b4204Xj80<0CCdS0`1<?28204/k8@80AcdR0P16?24204Dk8080A3XO00@0AS`Q04Dk8015
>b00AC/P0P14>Ql:04<i7P03040f6`11=a`0@cTN00<0A3XO2P13>Ah00`15>b00A3XO048h7@02044g
7003048h7@13>Ah0A3XO0080AS/O1015>Qh204@i7@D0@SHL0`11=A/204<j7@0404@k7P15?1l0AC`O
04Hm8080AchQ1016>al304Dj7P80A3TM2013>Ah204Dj7P<0AS/O0`17?20205107`040551801B@R40
Dd<R05E59080ETHU0P1JA1l0301LAR40GTPS061:9@1RC2L0HddX06A>:@1VDB@0Ie8U06QA9@1ZDRH0
K54V06iA9`80L50W00P0JdlO071D901fFRX0Me/[07EI:@1dF2P0METY07QL;080Oed]00@0P5h^085O
;`22H300Pf4a0P24HS8208MS;`0408QT<02:IS80RfLc08eY=@80SVXf102CKcl0102DL400UG5109Ea
@@2FLT82099`@080Tg5100X0U79209Ec@`2ELd<0UG=309YfAP2KMdL0W7Q809eiB@2NNTX0Wg];102P
O4`20:5mC@80XWi>102SOdl0102TP500YH5A0:F1D@2VPU820:N3D`<0Z8=F0`2YQ5L20:Z5F0<0ZHAG
0P2ZQEP30:^6F@P0ZXIF102ZQEP0102[QUT0[8MJ0:f8F`2]R5/80:^6F@@0[HQK0P2/QeX30:^6F@<0
[HQK0P2/QeX30:^6F@<0ZXIF0P2YQED30:R4E080Yh9E00H0Z8=F0:V4E`2YQ5L0Z8=F0:N2E@2VPE@2
0:V4F080Z8=G0`2WPUH00`2VPED0YX1A0:J0D@060:J0D@<0YX5D00<0YH1C0:AoDP2TOe802P2SOU43
0:=oC`80XWi>0`2QODd809mkB`060:1kCP2ONTd0WWU<09agBP2KMTT0VGA70P2HLdH00`2JLdP0VgA9
09aeBP0209aeBP0309YcB02HLDH0Ug150080V7930`2JM4D00`2HLT<0UW1109E_@00809I_A00609=_
?@2BKSh0TVhn099]@02AK400TFa20P2@JT<208mZ?P80SVTm00X0SFPl08aW>`2<Ic/0S6Lk08eX?P2<
Icd0RfHl08UT>P27HSP0QF0f0P23GS@808MR>00408MQ?026H3/0QV0k08IP>`80QElj0P24GST208=M
=P<0PU`e1@21Fc@02P20FS<0OUPa07eG<01lERl0OEL`07iH<@1oFC80ME<]07ME;`1jF38207]I<`06
07YH<P1gEBl0ME<]07AB;01eDbd0MU@^0P1hES00101fE2h0ME<]07AB;01dDC4207=@<080LTl_0P1a
CRh00`1`CBd0K4h/06a>;00606a>;0<0Kd`/0`1^Bb/206e::P80JD`/0P1XBb/206M::P80ITTY0`1T
AbL206=69P<0HTDU00H0HD<W06129P1N@bH0GD8U05]2901I@R<205I18P<0FD4W0P1H@2H;05Lo9@06
05Dm9@1D?2@0E3`T05<k8`1B>R80DCTQ0P1@>2001P1A>b@0D3XS04lk8`1<>R80BSXQ04Ti8080AcTO
00<0AS@P04Le8@18=R800P19=b<00`17=B40AC<O04@b7P0304<b8080@S4O0`11<1h00`0l;1d0?BdN
03h^7`0203l_800303d]7P0l;1d0>RXK00P0>B`L0P0m;Ah303`/7@<0>b/L0`0g:A`603HX6`04030W
5P0b:AP0=2/J03H]7080=bhM0P0f;A`303DY6@<0=RXJ0P0g:a/00`0h;1`0=b/K03HZ6P0203DY6@04
03HZ6P0g:a/0>2`L030V6P@0;bDI0`0^91P202hX700402dW6`0/9QX0:bDI02XT6080:B<G200/8aX2
02/R6@<0:R4H0`0Y81L202<O5P0302@P5`0U8AP09R8I00809b<J00<0:2@K02TR600X8AL00P0W81H0
100X8AL0:R<I02dV700^9ad502HS6P0302DR6@0T8AP0924H00<0924L0P0S81/3028O6PP0924H200T
8AX0100Q81/081lJ020O6P0P7aX201lN6@807QdH200N7AT801lP6`P07AhH2P0O81X701hO6@<07b0J
0`0N7aT201dN60P07QlI0P0R8A`2024P6`8081lJ0P0O7QT801hO6@0301`K5P0M71L07A`G00807A`G
0`0N7AP01P0R7AL08ahH02@O6@0U81X09b8L02PS7@80:RDO0`0S8Qd00`0R8A`08B0K024P6`02020O
6PP08B8L200P81P802LR70P08b<K200S8Qd3024Q6@<08R8J0P0S8a/8028R6P808b8M0`0R8A`3024P
6`P0824K200Q81/8028S6`@092@L1@0S8a/202HV7P<09BDM0`0T91`202PX800402LW7`0V9Qh09RHN
02DU7@8092@L200V9Qh802@U7@P09BDM200S91h8024R710082<L0`0Q8Al[ooooo`00:_ooool309U]
?080V6`k0`2GJcX0102GK3l0V6e009Q]@02HKD0309U^@@0409Y_@P2KKd80Vfm209]_@P80VVi10`2I
KD000`2JKSd0Vfln09ea@00209ib@@0409ea@02KKch0VVhm09Y_@P<0Vg130`2LLD@00`2MLTD0WWA2
09id@P0609id@PP0WW=0102OM4430:1e@P030:5f@`2OMD<0WgE30080X7I40P2QMdD20:9hAP040:1e
BP2PMDP0X7E80:1fAP80XGM500D0XGQ40:5h@P2QN480XWI50:=gAP020:AhA`@0YGU8202VNdP20:Il
BP80Yge;00@0YWa:0:AjB02RN4H0XGM50P2XODX20:MlB@80YW]80P2UNTL30:YoC0<0ZGi;0P2XODX0
0`2WOD/0YWa:0:EkB@020:AjB00K0:EkB@2VO4X0Yge;0:EjC`2TND`0XgQ;0:9hB02PMT@0WgI209ie
?`2MM3h0X78n09ma?@2MLSl0Vg4o09Ua@02FL440UFm009A_@P2FL440UFm009A^?`2BK3d0T6Xk08iX
>@2=IcP0S6Hg0080R6@d00<0Qf<c08IR<P25HC400P24H3001`23Gbl0QUlf08IO=P25GSD0Pe`c089K
<P20FC000P1oF2l0301oEBl0P5H`07iG<01mEc00O5H_07QE;@1fEB`0ME@[07IC;@1eDR`0M54[07=@
:P80LTlY00<0Le0Z07AA:`1eCRd00P1cCbd00`1aCb`0L4l/06e?:`0206a@:`0I06]=:@1]C2T0KTdZ
071>:`1bCR`0MDh]07I=;@1gCRh0Ldl[07A@;01gE2h0NEH^07]H;P1kFB`0NUP[07YH:P21FS<0PEXa
089K<P23G340Q5ha08EO<025Gbh0QV0_08]Q;`0308aR<080SF<a0P2>I380102?Hc80T6@c091T<`2@
I3<3095U=080TVHe202CJCL8095U>080TFLe00@0T6Hd08mU<`2?IC<0SV@b0P2=Hc401P2;IS40RfHb
08YU<@2:I3<0RF<d08US=P80R64f00P0Rf4_08aR<02>I380T6Hd08mU<`2=Hc40RV0^08QN;0P0RUlb
00<0QV0c08QR=@29HcH00P2:I3L00`29HcH0R68e08IP<`0308UN<@80RUlb0`2;H3<308US=P80RV@g
0`2;ICP03029Hc@0RV@e08]U=P2<ISL0RfDf08YT=@28HS<0QV0a08]P<`2<HC@0SV<f091U>0<0TFHi
00<0T6Dh08UT<02:IC400P2:IC4308]V<P0308aW<`2=IcP0SFLh00H0SFLh00<0R6<_08UT<02;IS80
0P2<Ic<01P2;IS80RF@`08QS;`2=J3@0SVTe08mZ=P80T6/g00<0SVTe08eX=02;IS800P2<ISL208eW
>00708iX>@2?JCX0T6Xk091Z>`2?JCX0SVPi08aV=`0308]U=P0308aV=`2=IcP0SVPk0080SVPk0`2=
IcX208aV>@80RfLg0`2<J3P408eY>@0@08UT>02;ISX0SFPk08aX>02:IS@0RFDa08]W<`2=JS@0S6Pf
08]W=@2:ISH0RF@g08QS=`28HcT0RF@j08YT?@80RfLg00H0RVHf08QT=027Hc<0QV8b08EQ<@24H308
08MR=@80Q68d0`23HC<3089P<P80PEla0P20GS0307mM;`0707iL;P1oFS00OEX`07eJ<01kFRl0NU/_
07MJ;P0207IK;P80LeH/0P1bEB/2075D:P80L5<Y00H0JU<W06UB:01YDRP0J54X06M?:@1VCRX206E=
:`0E0617:01NAbL0G4DV05Q39P1E@BH0DD0V04hn901=?B@0B3XP04Pi8P14>200@CHP03de800k=240
>C8P03Lb7`0g<Q`0=S4K03Ha7@0e<1d0=BlO0080=2hP00L0=2hR03D_8`0d;R80=2hR03<]8@0b;200
<B/O0080<2XN00@0:b/Q02XZ800Z:R00:RXP0P0Y:Al202PX7PP09BLL0`0T9Ad202<T70<08R<K200S
91`2028U70808B@K0`0P8aX00`0O8QT082<J020S6P09020S6P808B@K00@08RDL02<V7@0T9ah092LN
0P0S9Q/202@W70<09BPM00T09RTN02HX6P0W:A/0:B/M02X/7P0[;Al0:R`N02T[7@0X:Q`02`0X;1d2
02L[70<09RXK200X;1d802LY6`0302TZ700Z:ad0:b`N00<0:b`N00<0:R/M02TZ700W:QT01`0W:QT0
0`0Y:ad0:2XL02LY6`0302DW6@809RPJ0P0X:1h302LW7@0302PX7P0Z:R00:b/Q00<0:2TI0P0Y:QX3
02X[6`80:R/M0P0[;1h302`]7`0702d^800^:aP0;b`I02l/6@0`;AX0<BhK038_700203<`7@P0<2dJ
0P0d<ah00`0e<ah0=c8N03Pa7P0203Ta7P0403/`7P0i<A`0>C4L03Ta70<0>S8M0P0k<ah203/d6P04
03`e6`0m=Q`0?CHL03hg7@80?cPN0`10=Q/2044g70<0@SPM0P13>Ah01`12>1d0@CLL040f6`11=a`0
@SPM04@j7`15>b000P11>Qh00`13>Ah0A3PN04Hh7P0204Lg7P0304Pf7P12>1d0@cTN0080@cTN1014
>Ql204Hj80@0A3PN00X0ACTO04Hj8014>ah0@cXM048i7011>1/0@STL04<j7@15?1l0ASdP2019?R84
04dn7`<0C3dN00@0Bc`M04dl7P1=?1h0CC`N1@1>?Al00`1??bD0CShT04dm8`0304`l8P80CCdS0`1>
?R@204dm8`<0C3`R0`17?B8204Hl8@<0AC/P00@0B3`R04Lk8@17>b40Ac/Q0P16>R0204Di7`03048h
7@13>Ah0A3XO0080AC/P00@0A3XO04<i7P12>1d0@CLL0P12>1d01013>Ah0A3XO04@j7`14>Ql904<i
7P0804Hl8@15>b00@cTN048h7@11=a`0@SPM04<i7P14>Ql804Dj7P@0@cLM0P12=Q`2044e6`@0A3/N
0`15?1l01016?B00Ac`P04Ll8017?20204Hk7`<0ACXN00<0A3TM04<i7P13>Ah01P13>Ah204Dj7P<0
AS/O0`17?20204dn7`0404ho801?@240D44R05528`80DT<T01P0FD<N05Y47`1KAB00GDLR05i88`1P
BRD0HD/V069<9`1TCb80IE0S06I?8`1XD2@0Je0U06e@9P1`D2L0LE4X06]?7`1`E2@0MUXZ07QL;01f
FRX0M5PX07EI:@1gFb/207mM;@04081N;P21Gbl0PV0`08=Q<@80Q68b00H0QV8^08MS;`28I300RFDa
08YV<P2<J3@208eY=@0809=_?`2BKSh0TFdm095]?@2BKSh0Tflo09A`@02ELD42095_?`80TW1000@0
Tg5109Ab@P2ELd<0UG=30P2IMDD01@2JMTH0W7Q809eiB@2NNTX0Wg];00<0X7a<0P2QODd20:9nCP80
Xgm?00H0XWi>0:=oC`2SOdl0Y81@0:F1D@2VPU820:N3D`80Yh9E0P2XPeH30:V4E`030:Z5F02XPeH0
ZHAG0080ZHAG0P2ZQEP20:^6F@P0ZXIF00P0ZXEH0:V4E`2YQ5L0ZHAG0:Z5F02/QeX0[HQK0:j9G0P0
ZhII00<0[8MJ0:^6F@2[QUT00P2[QUT20:Z5F080ZHAG00@0[8MJ0:^6F@2[QUT0ZhII0P2ZQEP20:V4
E`<0Z8AD0P2WPe<30:J2DPD0YX5D00<0YH1C0:AoDP2TOe800`2VPEL20:F0EP<0Y7mE202SODh01P2T
Oe80XgiA0:=nD@2ROE00XGa?0:1kCP80WgY=0P2NND`209mjC@@0X7]>0`2NNTX209eiB@<0W7Q8202J
MTH02`2IM4L0V7=609QcAP2FLD@0UG1309A_@P2CKT40TVe0091Y@02AJT40Tfa30080U6e400<0Tfa3
099[@P2AJT400P2AJch309=]@003095[?P2?JC`0SVPk00P0T6U00P2=JCT0102<IcX0S6Lk08]V?02;
ICh208YT?`0608UT>P28HcT0R6<i08MR>026HCL0QF0f0P24GcD208AQ>@06089O=`21GSH0Oe`d07eJ
<P1lFC40NeP`2021Fc@307eI=`80O5Pf0`1kEcD00`1jEc40NEH`07UF<00207UF<080N5D_0`1gE2h0
2@1fDbd0ME8/07AA:`1dDB/0ME8/07IC;@1gE2h0Kdh[071?;004075@;@05071?;01_CR/0JdXW06a;
:01^CBX00P1_CR/0101^CBX0K4/X06]:9`1ZBb`206U::`0306Q9:P1WB2T0ITLX0080IDHW201SARH2
06M69`80ITDV0P1UA2D206A3900605m5:P1NA2T0GT@Y05e3:01L@RL0Fd4V1@1J@2D205To90<0F3hS
00P0EcdV05Hn9P1E?BD0DS`T050l8`1=?280C3`R04/k8@<0CC/U0`1<>R@204/i8`P0BCLQ0P17=Al0
0`16=1h0AC<M04@b700204<a6`0<048`6P17=2D0ASDU04Dd9013<b<0@3<R03hc8@0l=240>c<P03T/
700j;Ad0>bhN0P0l;al00`0k;Qh0>RdM03T/700303T]8@80>2`P0`0g:al00`0_9A/0<2HL038X7P02
03<Y7`03038X7P0`9Q`0;bDK00P0;BLK200`9Q`202hS7@@0;B8L0`0/8A/0100W8aL0:2@H02XV6P0/
:1`202dY7@0302`X700[9a/0;2HJ00L0;2HJ00<0<B/O02lY7@0^:1`00P0]9a/00`0^:1`0;bTM034[
7`0802TR6P809BDM00@092@L02<S6`0R8QX08R8J0P0Q8AT;02HQ6`809B0J0`0T7aT301lN6@<081lJ
0P0Q81/02P0U81X091lI02<N600S7QP091lI02DP6P0W8Q`0:B@N024Q6@0R8QX202<S6`04028R6P0Q
8AT0820H01lO5`<081lM0P0O7Q`301hM6`P0820H200Q81/301lP6P807QlI0`0M7QP801`L6PP07AlL
400N7aT201lP6P<07QlI100M7QP301lP6P807QlI0`0M7QP3020Q6`807b0J0`0N7aT3024P6`8081lJ
0`0O7QT801hO6@L071dG00X07AhH02<N600S7QP091lI02HQ6`0W8Q`0:2<M02TT7P0Z9Al092<N0P0S
8Qd00`0R8A`08B0K020O6P0201lN6@P0824K200Q8AT802LR7004024Q6@0R8QX08R8J028R6P<08b<K
00<092@L02<R7@0S8Qd01P0S8Qd2020P60808B4I0`0R8QX00`0S8a/08B4I024Q6@06024Q6@0402<R
7@0R8A`08R4L028Q70808B0K0P0P7aX801lP6PP081lJ200R8a/302DU7@8092@L100S8a/802DU7@@0
9bLO0`0V9Qh00`0U9Ad09RHN02HV7P0602HV7PP092DM200U9Ad802<T7PP08B8L400P8a`3028R82_o
oooo000Zooooo`80Vfln0P2JKSd209U]?080V6`k0P2GK3l209Q]@00409U^@@2JKd80VVm209Y_@P<0
Vfm20P2JKT4309U]@00309Y^?@2LL3l0WG500080WW9100<0WG5009a`?`2JKSd00P2JKd8209]`@`80
W7540P2MLTD809id@PP0WgA10`2QMT<20:1e@P<0WgA10P2OMD<20:1fA080XGM50P2RN4H0102QMT/0
XGI90:5fB@2QMdL20:1fA0030:1g@`2PMd40X7M100<0XgM60P2TN4L30:EiB0P0YW]800@0ZGm=0:Qn
C02VO4X0YG]90`2SNDL00`2TNTP0Z7e:0:QmBP020:MlB@80YW]80P2UNTL00`2ZOd`0ZGi;0:UnB`02
0:QmBP80Yga900@0YW]80:IlBP2UNdT0Y7Y80P2SNDL00`2TNTP0YG]90:IlBP020:AiCP0G0:=hB`2Q
MTT0X7I609me@`2NMD40WGA00:9d@02QLcl0WW=009]a?`2HL3l0U6ho09=]?P2AK3l0UFm009A^?`2B
K3d0T6Xk08iX>@2<ISL0RfDf08YT=@29ICD00P28I3@00`27Hc<0QV8b08EQ<@0208AP<00608IO=P25
GSD0Q5dd08=L<`21FS40P5T`0P1oF2l02@1nE2h0OeD_07iG<01mEc00O5H_07QE;@1eE2/0M5<Z07EB
;00207IC;@0J07EB;01cD2X0LDhX06m<9P1^BbD0Ld`[075=:`1`C2X0KddZ06e<:@1[CBT0JThY06U=
:01/BbP0KD`Y06m=:P1aCB/0M4d/07I=;@1gCRh0NDh^07EA;@1fDRh0NEH`07]H<01mFS0207eK;P07
07aJ;022Fc@0PU/b08=L<`24GC80QElb08EO<00208IP;`80S68`0P2=Hc4308iT<P0408mU<`2BI3<0
TV@c099T<`80TfDd102DISD809AZ>0P0TFDh202?IC<01P2;IS40RfHb08YU<@2:I3<0RF<d08US=P80
R64f1@2=Hc400`2<HS00Rf4_08]Q;`0808YP<00308IP<`28HSD0RF<f0080RV@g00@0RF<f08QR=@26
H3<0R5d`0P29GS4208YO<P80Rf0c00<0S64d08US=P2:I3L00P2:I3L208]U>080S6Hi00T0RF<d08YT
=@2;ICH0S6Hg08]U=P2:I3D0R68c08IP<@2>HcH00`2=HSD0102>HcH0T6Dh099W>P2CJ3/208YU<@80
RfHb00@0S6Lc08eX=02=J3@0SFPd0P2>J3T608eW>00308QS;`29I300RfHb0080S6Lc00H0RfHb08YU
<@29I300RfHb08aW<`2>JCD308mZ=P0808eX=02<Ic<0RfDf08aV=`2=IcP0SVPi08mY>P2@JS/2095[
?006091Z>`2>J3T0S6Hg08]U=P2:I3D0RfDf0P2<ISL308iX>`<0SFLj0P2<IST208]W=`<0S6Ph102=
JCT04028HcL0S6Lk08iY?02=JCT0RFDc08QT<02:IS80SV/e08m[>@2>JSX0RfLg08UT=`27HSH0Qf8h
08MQ>P28HS/208UU=@80R6@d0P27Hc<208IR<PP0Qf8e0`24HS@00`23HC<0PV0b089P<P02085O<@<0
P5h`0`1oGBl207iL;P0807eH;P1kF2h0NUL]07UH;@1gF2`0MEP/07AI;01cF2/3079E:`@0LE@Z01L0
L5<Y06QC:01XDbP0Ie4X06I@:@1UCbX0IDh/06A=:`1TCBd0GDHV05a59P1H@b@0ED8T0550901=?B<0
Bc/R04Tk8@15=R40@cLQ048e8P0o=280>c<P03Tb800203H`8080=C0L00@0=C0M03@^7P0d;R00=2hP
0P0c;B401P0d;B<0<b`R03</8P0b:b40<BXP030Y7`80;bPN0P0Z:R0202TY7`<0:2PN00<09bLM02@W
700T9a`01P0T9a`0100T9Ad08b@L02<T700S91`2028S6`808B8J200R8a/3024T6`<082<J0P0O8QT9
020S6P0601lR6@0P8aX08B@K028U700S9Qd092LN0P0U:1l302@W70<09BPM0P0V:Ah00`0V:1X0:2XL
02T[7@0302/]7`0302X/7P0Y:ad0:2`M00P0:2`M0`0W:a`202HZ6`809BTJ200V:Q/802PZ700302PY
6`0Y:Q`0:b`N0080;2dO00<0:b`N02TZ700X:A/0200V:AP0400Z;1h0:B/M02LY6`0V:1X09BLI02HX
6P0W:A/0:2XL02PX7P0W9ad09RHL02DU6`0V9Q`09bLM02TY7`0[:b4202LX6080:2TI0`0Y:QX0100Z
:a/0:RXN02XZ7P0Z:Qh202/[7`<0;2`P00H0;b`I030]6P0a;Q/0<RlL03<`7@0d<Ah203Db7`P0<BhK
0P0a<ad00`0c<Qd0=38M03Ha7@0203L`7@0303P`7@0j<Qd0>S8M00<0>c<N0`0l=1l01@0j<aT0>c@J
03/d6P0l=A/0?SLM0080?cPN00<0@3TO03le6P0o=AX00P10=Q/3044g70<0@SPM00L0@CLL040f6`10
=Q/0@3HK048h7@13>Ah0AC/P0080@CXN00<0@cTN04@h7P16>1h00P17=ah01018=Qh0A3XO04@j7`14
>Ql204<i7P<0@SPM00@0B3`R04Lk8@15>Al0@cLM0P12=Q`01@13=ad0A3PN04@k7P13>Qd0@STL0080
@CPK00<0@cXM04Dl7`16?B002018?B4304`m7P<0CChO0P1>?b0204hk6`0404ll701@?Ad0DChN058o
7`80Dd0P00<0CclU04hn901<?2800P1<?2800`1>?R@0CclU05519`0304lo9@80CShT0`1=?B<404Lm
8P80AS`Q0P15>b0304Xl8P80BC/Q0`18>R000`12>1d0@cTN04Dk800204Hl8@0304Dk8013>Ah0@SPM
00@0@SPM0P13>Ah:04@j7`0304Lm8P16?240A3XO00<0@SPM00<0@cTN04@j7`15>Qh01`15>Qh204Di
7`80A3PN0P13=ad2048f70<0AC`O0`14>ah204<j7@@0Ac`P0P16>al304Dj7PP0@cTN0P15>Qh304Hk
7`<0Ac`P0P1:?1l0101;?B00C3hQ04`n8@1=?b8204i08`0805U37P1JA1l0FdDP05a68@1MAb80GTPS
05m9901PBRD2069=800>06E>8P1WCb<0Je0U06iA9`1aDBP0LU8Y06]?7`1aEBD0Me/[07UM;@1gFb/0
METY07IJ:P1gFb/207mM;@04081N;P21Gbl0PV0`08=Q<@80Q68b00X0QF4]08IR;P27Hbl0R6@`08YV
<P2;Ic<0S6Pd08eY=@2AKCd0T6`l0`2?Jc/02@2AKCd0Tflo09A`@02?KCd0T6hn095_?`2BL400Tg51
09Ab@P0209Ec@`80V7A400D0VGE509]gA`2LN4P0WWY:09mkB`030:1lC080XGe=0P2ROTh20:=oC`80
XWi>00<0Xgm?0:B0D02UPE400P2VPU80102WPe<0Yh9E0:N2E@2WPUD20:R3EP<0ZHAG0P2XPeH30:V4
E`<0ZXEH202ZQUH0202ZQEP0ZHAG0:R3EP2XPeH0ZHAG0:^6F@2^RE`0[hYM2@2ZQEP40:V4E`80Z8=F
0P2WPUD0102ZQEP0ZHAG0:V4E`2YQ5L20:R3EP80Yh9E0`2VPU820:F1D@<0Y81@0`2TOe800`2SOU40
XWe@0:9mD0020:5lC`80Y7mE0P2SOU@30:9mD`030:5lDP2PNT/0X7Y;00H0X7Y;0P2QO4l01P2PNdh0
WgY=09iiC02MN4/0W7M:09]fB@80VWE800<0VgI909agBP2LMdX00`2MN4/209UeA@80V7A40`2GLd<9
09Ib@P<0TVe000<0TF`o091[?P2?JSd00P2?JSd01027H3L0R64h08YS>P2<IC`208eV?@80S6Dl00<0
RV<h08]T>@2<ICX00P2<ICX00`2:HcP0RF8g08MP=@0808MP=`80Q5lb00<0Pehb08=N=022G3D00P22
G3L01`22G3P0P5/a07mJ<01oFS00OEP^07aG;@1kER`00P1jEB/207YH<P0407UG<@1hES00MU@^07EC
;@80M58/201hDRd0101cD300LTl_079?;`1bCbl2075>;P80L4d]0P1_CBP306i<9`<0KD/V0P1/BRD0
2P1[BB@0JTPS06U78P1YAb80JTPS06a:9@1]BbH0J4LV06M69@1VAB@206E48`0606I5901WARD0J4LV
06507`1R@B00I4<R0P1UA2<00`1T@b80HT4P06507`0205m19@0305i0901M?b<0G3hR0080FS`P00<0
FC/O05Po8@1H?b401P1H?b40101M>b00G3XO05`j7`1L>Ql205/i7P80FSPM00H0E3`T05<k8`1B>R80
DCTQ050h801?=al204hf7P<0D3PP0P1?=al304hf7P0604`f8@1:=B00BC@O04Le7`15=Ah0@c@M0P10
=1`204<c8`80@S8R0`11<B400`10<200?RhN03h^7P0603h^7P0603l`7@0n;a`0?RlL03d^6`0l;AX0
>b`I0P0j:aP01P0m;280>R`Q03T[800h;200=B/O03<[7P80<B/M00<0;bDK030V700a9ad00P0c:Al0
0`0b:1h0<BLM030V700202hW7@80;BHL0`0/9A/0100[91X09R4K02LR700Y91h202XU7`0302TT7P0X
8ad09b8L00P08b<K1P0W8Q`202PS7@809R4M0P0U81`302@O6`808ahJ00P0828G024S600S9AX092HK
02DW700T9Q/08bDJ028T6@@09R<J100U8QT00`0X9A`09b@K02DR6@0202@Q600302DR6@0W91/0:2DL
00<09B0L1@0V8Ad4020R7@@07b4L200R8A`202<R7@808R4L100Q81/401lO7@<07QhL00@07AdK02@Q
700S81/08QlJ0P0Q7QT02`0R7aX0924L02DR7@0P7aX08B0K028Q700S8Qd08R4L024P6`0O7QT07A`G
00<07adN0P0N71d301dK70P081lJ200Q81`201lR6`807R4J0`0M81T00`0L7aP06adJ01/M6P0601/M
6PP06QlK400N7aT201lP6P807QlI0`0M7QP201`M5`0401lP6P0N7aT07QlI01hO6@807AhH0P0L7AL2
028S7@808B8L0P0P8A/201lP6P808B0K0P0P7aX401lN6@P07AhH0P0M81T601`O600402@O6@0U81X0
9B0J02HQ6`809b8L0P0X8ad01@0T8ah08b8M02<R7@0R8A`081lJ00807ahI00<07QdH020Q6`0P8A/0
1P0P8A/802<S6`P09R4K0`0Q8AT00`0R8QX08b<K02<S6`0202@T70P08b8M0`0P81P2024Q6@<08R8J
200Q8AT3028Q70808B0K0`0P7aX801lP6PP081lJ200R8a/202HV7P809BDM00<092@L02<S6`0S8a/0
0`0S8a/202@T700502DU7@0V9Qh09bLO02LW7`0X:2000`0V9Qh302LW7`80:2PP200W9al802@U7@P0
9BDM200S91h8024R710082<L0`0R8R0[ooooo`00:_ooool209a`?`80Vfln0`2JKSd0102IKC`0Uf`o
09M/?`2HKD0209U^@@0309Y_@P2KL4<0Vg1300<0Vfm20P2JKT4309U]@00309]_?P2LL3l0WG500080
WW9100<0WG5009a`?`2KKch00`2JKd800`2KL4<0W75409ebA@0209ebA@P0WWA2202OM4420:9gA080
XGI300@0X7E209md@@2NLd00WW=00P2OMD<20:1fA080XGM50P2RN4H0102SN4d0XWM:0:9gBP2QMdL2
0:1fA00309mf@P2OMT00WWDo00@0XgM600@0Y7Q70:EiB02UNDP0YWY9202VNdP0102/PU00ZGm=0:Il
BP2SNDL20:9hAP040:AjB02UNdT0Z7e:0:QmBP80Yga90P2VNdP20:EjA`80ZGi;0P2XODX01`2WO4T0
YW]80:IkB02UNTL0YWa:0:EkB@2TNTP00P2SNDL02@2TNTP0YG]90:IlBP2TNDl0Y7U>0:=hC@2QMTT0
X7I609id@P0209ed@00@0:Af@P2SMD40WgA109ab@02HL3l0Tfdn099/?@2@Jch0U6ho09=]?P2AJc`0
SfTj08eW>02;ICH0RF<d08QR<`80RFDe00<0R6@d08MS<`26HS800P25HC404`24H300QUlf08EN=@24
GC@0Pe`c085J<@20FC00OeP_07iG;P1nE2h0OeD_07iG<01nF340OEL`07QE;@1eE2/0Le8Y07EB;01f
Dbd00P1gE2h01@1dDB/0LDhX06e:901ZAb40LDXY0080Kd/Y00<0KT`Y06a;:01ZC2P00P1XC2L01P1/
BbP0KT`Y06i<:@1aCB/0M4d/07I=;@80NDh^0140MU8^07QD<01jEc40OEXb07iK<@1oGC00OU`_07iL
;P22Fc@0PU/b08=L<`24GC80QElb08IP<@26H2l0Qf4`08aR<00308eS<@80SV@b0P2?IC<2099T<`<0
TfDd102DISD809AZ>0P0TFDh0`2>I38208mU<`<0T6Hd00H0RfHa08]V<P2:IC40RV@c08US=029HcH2
08QQ=P0408mV<P2>IC40SF@`08aS;`80Rf8^0P2<Hbl808YP<00308IP<`28HSD0RF<f0080RV@g00<0
RF<f08QR=@26H3<00P28GC001029GS40RUlb08YO<P2;H3<208aQ=0@0RV@g0P2;ICP208aV>@0:08US
=02:I3D0RfDf08aV=`2;ICH0RV@e08QR<`26H340T6Dh08iS=P80S64d00@0SF8e08mT=`2BIcX0U6Tl
0P2;IS8208aW<`0408eX=02>JCD0SVTe08mZ=P<0SVPi1@2=IcP00`2=J3@0SfXf091[=`02099]>@07
095/>02@JcL0SfXf08UT;`2:IC00S6Lb08iY=00208mZ=@0>08iY=02=J3<0RfDf08aV=`2=IcP0SVPi
08mY>P2@JS/0TF/l099/?@2@JS/0SVPi08aV=`2;ICH208YT=@0308]U=P2<ISL0SVPk0080SVPk0`2=
IcX208aV>@80RfLg0`2<J3P408eY>@0=08QS=`2<Ic/0SfXm08eY>@29IC<0Qf<_08YV<P2>JcD0TFdm
08m[>`2<IcX0RF@h08IQ=`0208IP>@0308MQ?027Hc<0Qf<c00H0Qf<c2027HSD01025HcD0Q68d08AR
=023HC<2089P<P80PEla0`20GS0207mM;`<0OU`^00H0NeH/07UF;01iER`0N5L/07IG:`1dEb/2079G
:P03079E:`1aE2X0LE@Z00D0LE@Z01P0J5<X06QB:@1WDBP0IU0Y06E?:P1TCB/0I4d]06=<;01LABH0
FD@U05Q39P1D@2D0CchT04`l8`19>b40B3TR048f8011=240?c@P03`d8@0i<R00=S0P03D_8@0c<242
03@_6`0303@_700d;Qh0<bdO0080<bdQ0`0c;282038[8@05034Z800`:Al0;bPN02lX7P0Z:R800`0Y
:B4202PX80809bLO0`0S9Q/502@W70@08b@L0P0R8a/2024R6PP08R<K0`0Q91/2020S6P<07b8I2@0P
8aX0200O8QT082<J024T6`0R9A`08bHM02@W7P0U:1l09RTP0`0T9a`202DX7@<09RTN00P09bTK02PZ
700Z;1h0:bdO02`^800[;Al0:R`N02T[7@P0:2`M100W:a`202HZ6`X09BTJ200Y:ad00`0W:1X0:BXL
02X[7@0202`]7`0302X[7@0Y:Q`09bPJ00P09RTH00X0:bdO02X/7P0X:Q`09RPJ02DW6@0V:1X0:2XL
02T[7@0X:2009bLO0`0U9Ad00`0W9al0:BTQ02/[8`0202LX6080:2TI100Y:QX302XZ7P<0:b/O0P0/
;2001P0`;AX0<BhK038_700c<1d0=34N03Db7`80=S<P200b;a`2034c7@0403<b7@0d<Qd0=S4M03Ha
7@80=c0M0P0k<ah203`d7`@0?CDP0P0j<aT0100k=1X0?3DK03hg7@0o>1h2040i7`80?cDJ0P10=Q/4
044g7080@SPM00L0@CLL040f6`0o=AX0@3HK044g7013>Ah0AC/P0080@CXN00<0@cTN04@h7P16>1h0
0P16=Qd01@17=Ad0AC/P04Dk8014>Ql0@cTN0080@SPM0P11=a`0101:?R@0B3`R04Di7`12=Q`2044e
6`04048f7013=ad0@cXM048i70<0@CPK00<0@cXM04Dl7`16?B002017?20204`k7@0404dl7P1>?Al0
CSdO04ln8080D3lQ00H0CCXJ04hk6`1??1`0D3dM058o7`1D@B4205E28P0804hn901=?B<0C3`R04/k
8@1<?280CclU05519`1C@bT304lo9@80CShT0`1=?B<01018?R<0AcdR04Lm8P17?B8204Hl8@80AC/P
00@0BcdS04Xl8P1:?280BS`R0P19>b4204Pj8003048h7@13>Ah0AC/P0080AS`Q00<0AC/P04<i7P12
>1d01012>1d204<i7PX0A3XO00@0B3hS04Hl8@14>Ql0@cTN0P12>1d01013>Ah0A3XO04@i7@14>Ad4
04Dj7P80AS/O0P16>R0204Di7`0404@h7P13=ad0@cLM048f7080ASdP00@0AC`O04@k7P14>ah0@cXM
0P12>A`404Ll80<0AS/O0P15>Qh804<i7P80ACXN0`16>al304Ll80<0BC/N00<0BS`O04/m801;?B00
0P1<?R4205Y47`80FdDP0140G4HQ05e78P1NB2<0GTPS061;7P1QC1l0Hd`P06M?8`1[D2D0KU4W079B
:@1cDbX0JdlO075E9@1hG2`0NUh^07QL;00207IJ:P0707QL;01oGBd0Oed]081N;P21Gbl0PV0`08=Q
<@0208AR<P80QF4]00@0QV8^08QT<029IC40RfLc0P2<J3@00`2AKCd0Sf/k08iZ>P0208eY>@0308m[
>`2AKCd0Tflo0080Sfdm00<0T6hn095_?`2BL4000P2DLT80202ELd<0Ug=309QdA02IMDD0VWI609ah
B02NNTX0Wg];0`2PO4`20:5mC@80XWi>0P2SOdl20:9nCP040:=oC`2TP500YH5A0:F1D@80YX9B0`2W
PUD30:R3EP80ZHAG0`2XPeH20:V4E`<0ZXEH202ZQUH20:V4E`060:R3EP2WPUD0ZHAG0:^6F@2^RE`0
/8]N202ZQEP40:R3EP<0Yh9E0P2VPE@30:R3EP<0Yh9E0P2VPE@20:F1D@80Y81@0`2SOdl01@2ROTh0
XgiA0:=nD@2ROE00XGa?00@0X7]>0`2RO5D20:5kE0<0X7YC202NN4T209mjC@0409iiC02MN4/0W7M:
09YeB080VGA70P2HLdH209UdA`0409YeB02KMTT0VgI909agBP<0UG510P2DL40309=_?`P0U710102>
JC`308eX>`0708aW>P20FC80PU/d08EN=`27H3T0RF8k08YS?00208UR>`0308IO=027H3D0R64f0080
R64f00<0QUld08EN<`23G3402021FS<01P1mF2/0OEP/07eH;01lEbd0O5H_07]E<080NeDa00H0NE</
07QB:`1gDBX0MU0Y07E?:01dCRL207==9P0407=A:`1bD2X0LU0Z075?:@80L4hX0P1_CBL8075;9P<0
JdPZ0P1ZAbT306U6:0<0IdDP0`1VA1l406E37P0:06A27@1R@1/0HT0K06906`1S@A`0ID<N06I47`1P
@B80GSlP05`m7P80FS/L00H0G3dN05ho801P@B80EcPI05Pi6P1J>a`205/l7@0;05Xk701H>AX0EcPI
05Hk7P1E>Qd0E3TL05<h6`1B=aX0DCHI050e601?=1L0201C?1d205<d6080DS<G101A<QH204Xd7@04
04Tc7018<Q/0AS0I04D_6080A2hG1017<AX204H`6@80ABlH00H0A2lL048`7011;a/0?bhJ03d^6@0j
;QP203P]5`<0>RdM0P0i;1`303P[6`P0=bXJ0P0i;1/00`0h:aX0=bXI03HY600203DX5`0703@W5P0d
9Qd0<bHM030V700_9A/0;BDJ02/U6@0202PT600302XQ6P0[8Q/0;B@M00<0;RDN00<0;2<L02/R6`0V
8A/00P0V8A/202DP6P<091lI00<08B0K028Q700T8ah00P0U91l00`0T8ah08b8M028Q7008020Q6`80
8B0K100R8A`202<R7@808alN0P0R7Qd2024M708081`K00@07a/J01hQ600O8QT08B@K0P0R9A`0100P
8aX07b8I01hQ600S8a/4028R6P@08B4I00L0820H01hN5P0M7AD07AdE01hN5P0P81P08B4I00D0920M
0`0U8Ah801dR7PP08R4M0`0S8Qh2028Q7@<08B0L0P0P8Ql00`0O8Ah07R0M01dO700201`N6`0A01/M
6P0T81d08alL028N6`0Q7AX081`I024M6P0S7a`0920M01hO6@0O81X08B8L028S7@0Q8Q`0824K01dN
600L7AL00`0N7R0201dM7`<071`N200O81X8020Q70<07b8K0P0N8AX301dP6@P071hM200I7A`801lP
6PP07AhH0P0O81X201hO6@0501dN600L7AL071dG01`M5`0K71H0100N7aT201dN608071dG0`0S91h0
0`0R8ad08B8L020Q6`02020Q6`808B0K0P0P7aX301lN6@0301hM600M7QP07AhH00H07AhH00<07R4J
01dP6@0M81T00P0M81T301`O600302DP6P0V8A/09R4K00809R4K0`0W8Q`01P0T8ah08b8M02<R7@0Q
81/081lJ01lN6@807QdH200P8A/802@T70P09R4K0P0P81P0100Q8AT08R8J028R6P0S8a/202@T70P0
8b8M0`0P81P3024Q6@808R8J200Q8AT2028Q70<08B0K0`0P7aX801lP6PP081lJ200R8a/302HV7P03
02DU7@0T91`08b<K00<08b<K00H08R8J02<S6`0T91`09BDM02HV7P0X:20202TY8@809BDM00@09RHN
02LW7`0W9al0:2PP0P0Y:B4802LW7`P092DM200U9Ad802<T7PP08B8L400P8a`3028R82_ooooo000Z
ooooo`<0Vg4o0`2JL3h209U_?@<0VFe00P2JKT4309]_@P80W70o00@0Vfln09Y^?@2JKSd0VFdl0P2H
K3/209Y^?@0409]_?P2LL3l0WG5009ib@@80Wg=200P0WWA209ec@@2KLCl0VW0n09]a?`2MLd40WgE3
0:1fA080Wg@m00H0WW<l09eb>`2LLCX0Vg0i09Y_>02IKSL809ic@080X7E2102OM44209ic@0060:Md
A@2UMDD0YGE50:AfA@2RMTD0XGM50P2PN4D0102OMT80X7M30:1g@`2QN4@20:9iA@040:=jAP2TNdL0
Y7]70:9hAPH0XgU700<0Y7Y80:=iA`2SNDL00P2TNTP40:EkB@P0YWa:202VO4`20:ElB00>0:AkA`2S
NTH0Y7]70:ImB@2XOd/0ZH1<0:5gA@2RN4H0Y7Y80:IlBP2UNdT0XgU70:1fA02NM4820:5fB@80XWM:
00T0XGI909icAP2KL4<0VFi10:1g@`2NMD40Vg8n09Q_>`2FKCT00`2EK3P02@2@JSd0SfTl08iX>`2=
IcX0RfDh08YT=`29HcH0R68e08QS>@0208MR>00308IQ=`25H3H0Q5le0080Pehd0P20GCD00`1oG3@0
OU/c07eJ<P0207aI<@0607]H<01nFcD0OEXd07]H<P1iES00N5D_0P1iES000`1jEc40Le8_07=B;`06
07=B;`06071@9`1`D2T0L50Y071@:P1aD2d0LE0_0P1aD340201^D2h0KU0/06e?:`1]CbT0KU4Y075D
:P1dEb/0MUT]0P1mFS@0101mFS80OU/a07iL;`1nG2h207iL;008081J:`21Fb`0Ped^08IP<@29Hc@0
RfDf08eW>02?JCX308iS>080Sf@i0`2@ICX9099W>P0808i^?`2=KCh0SF/m08iY?02=IcX0SF@h08aS
=`2=HSL208eR=@0408iS=P2?I3L0Sf@g091U>080TFHi1@28HS<308US=0<0RF<f0`28HSD208MQ=0<0
Rf0c0P2:Gc8308UN<@0408QR<`27HC80Qf4b08IP<@80QEl`0P24GRl02024GC80QEhc08MQ=029Hc@0
RF<b08UT<027HRh0QV4/2027HC801028HCH0RF8g08UR=`29HSL208YS>080Rf@i0`2:IC4308]V<P80
S6Lc202?IC<208aV=`<0SFLh0`2>J3T0102CKSX0TVdi08mZ=P2=J3@208aW<`<0SFPd0P2>JCD00`2?
JSH0T6/g095/>002099]>@0;08mS?02?I3X0T6Dj091V=P2AJ3@0TVTc099Y<@2CJc00SfXf08iY=@2<
Ic<00P2:IC40102;IS80S6Lc08eX=02<Ic<408eX=0<0SVTe202?JCX01P2<Ic<0SFPd08mZ=P2@JcL0
SfXf08eX=080RfHb00@0RVDa08YT=@2:I3D0RfDf0P2<ISL00`2=IcP0SVPi08iX>@0208aV>@<0RfDh
0`2:I3L02`25Gc00QV0a08MQ<P29Hc@0RV@e08aV=`2=IcP0SVPi08MR=@26HC@0Q5lb0080Peha00<0
Q5lb08IQ=027HSD00P26I3H01025HcD0Q68d08=Q<`23HC<2089P<P0407QI;@1iFRh0O5da07mP=080
P64e0280Of0d07iO<`1kFc80NUXa07UI<01hF2l0MUH]07AD:`1cDbX0LU8Y06iC:01^DRX0KE4Y06eA
:P1/D2/0Jdh/06]>;P1ZCBd0IddZ06E;:01TBRL0IT`Y06U?;01XCR/0HdTV05i48@1KAb`0EdHZ05=2
:01>?RD0BS/T04Hj9015>R@0A3TU0P0h=BH0100f<b@0=C8S03<`8@0b;b07030]7P<0<BhO00P0;RhT
02d]8`0/;280:RXP02TY7`0W9ad09RHL02DU6`<09BHN0P0T9Ad302<T70P08RDL200Q91d301lR6`80
82<L0`0Q91d2020S6P808B@K100R9A`302@V6`<09BLL0`0V:1d802HY7P0602@V6`0U9a`09BLL02LY
7P0X:Ql0:B/P2P0Z;2401@0U:1d09RTN02HY7P0W:Ql0:2/P0080:B`Q00<0:RdR02HY800V:B00100U
:1l202@W7P<092HK0`0U9a`B02HX7@<09bTK0P0X:Q`302T[7A00:2PL00P09R/G02P[600Z;AX0;2dK
02h]6`0^:aX0;bTI02hX6080;b/R00@0;b/P02l[7`0_;1d0<2dL0P0`;AX01P0a;Q/0<bhK03@_700f
;ad0=bhM03X^7P80?2lO0P0i<ad203Xd7P<0>cDO00`0?3HP03Hb6@0g<aX0>S@L03de7P0o=1h0@3@N
03lc7@10<A`0?c<K040d7011=Ad2048f7P07044e7@10=1`0?c<K03hg7@0o>1h0@S/Q04@m8`0304Dn
900704@m8`13>Q/0@cXM04<j7@12>1d0@SPO048g8@02048g8`D0@cTN1014>Ql00`16?B00AC`O04@k
7P0204<j7@0504@k7P16?B00AchQ04<i7P14>Ql00P15>b001014>Ql0@SPM040f6`0o=AX304<h70<0
A3TM0P15>Qh2044g7080@SPM00@0@cTN04@j7`15>b00AC/P0`16>AT204Lj6P<0B3/K0100BS/L04Tj
6`18>AX0BCXK04Xk701=?Ql0D44R0593901@?Ad0DChN058o7`1C@200ED8R05M4901HABD0FDHV0`1A
@B0305928@80Dd<R00/0CD0N04i17`1?@R00Cd8P04i17`1<?ad0BSdK04Tl6P18?ah0BD0O04]28@02
04e48`0604]28@19@1l0B3lN04Po8P17?R40AC`O0P14>ah00`15?1l0AchQ04Po8P0204Ho8P0604Dn
8@14?B00@c`O048k7P11>Qd0@3TL0P19>b400`16>R00AC/P048k7`02044l7`0403lk7P16?B00ASdP
04Dl7`80A3/N00/0@cXM048i7012>A`0@c`P048k7`14>Ql0A3PN04Dg7@16=Qd0ACDL04Hd700304<g
7@<0A3PN0P15>Al804@h7Q40@cTN2011>Qh304Hh7P80AcTO0`18>R007012>ah0@c`O04Hm8018?B40
BcdR04hn901??bD0D3lU05A09@1E@2D0ET4T05U28`1K@R<0GD<R05m28P1P@b40Gd`T05m<8P1RC2<0
IDhT06M?8`1ZCb80Je0Q06eA8P1]Db80KeDT075G9P1cFBP307EK:P0I07AJ:@1hG2d0N5`]07UM;@1j
GRh0Nel]07aQ;01lHBX0OF8[089Q:`23HR`0Q6<]08IU;`27IS00RFPb08YY<`2;JS@0RVLa08]X<P2<
JC<0SFXd08m/=P2@KCL0TFhh099_>@02095a=P03099b>@2BLC/0Tg8m0080Tg8o00H0Tg5109IdA02F
M4@0UgE509QfAP2IMdL209YhB00409]iB@2QODd0XGe=0:5mC@<0X7a<0P2ONd/00`2VPU80YH5A0:=o
C`020:9nCP040:=oC`2UPE40YX9B0:B0D0<0YH5A0P2VPU820:N3D`060:J6E`2UQEH0YXAF0:N2E@2V
PE@0YX1C0P2WOU80202[QU40ZhIB0:Z5D@2ZQ5<0ZH=D0:V3EP2YPUL0Z85F202XQ5820:b8F0040:^7
E`2ZQUH0ZHEE0:V5E@80Z8AD0P2SOd/20:=oC@030:=oC`2TOe80Y7mB0080Y7mC00P0XGUE0:=kE`2U
OET0YgmK0:R0G02WOe/0YWiJ0:EmF@80Y7eD0P2SO5<0102RNe80XGYA0:1iD02PNE030:1jB@D0XG]:
102MMe8409afD@P0VW9100P0Vg5109Y`@02GKch0Tfdl095]>`2?KS/0T6ll091`?@80UVHf01H0TfLf
099X=P2?JSH0S6/f08]/=P2:K3H0U6/m09=Z?02BJC/0TFPj091W>@2?ISP0SVDg08eT=P2=HSL0SV<h
091U>P2AIS/0T6Dj08iS>02<HCH0Rf0e0P29GS@00`28GC<0Qe`b08IK<@0208EJ<00408AI;`21FS<0
PEXc085J<`80P5Tb0`1oF34307aD<080Ne<_0`1jDRh00`1dDBT0ME8Z07MD;00207QE;@0407MD;01e
DRX0M54Y07=B<@80LU4`00<0LE0_071?;P1_CRd00P1^CB`806M8;00806=5:@1RA2P0Gd4U05i0901M
?b<0GT0T05m19@1Q@bL805i09P0905Pn8`1J@2D0Fd4V05a29`1K@BH0FT0U05Lm8P1F?240D3XU00@0
DC/V0`1B?2L0101C?BP0E3LU05Hi9`1H>bT305/n;00305Xm:`1I?2X0BSPT0080BSPT0P19=b<304Pf
8P0404Pg8`17=R80AcHR04Lf8P80ASDQ0P15=202044c9P06040b9@0o<B@0?S0S03d_8P0l;R40>bdP
0P0l<b@203/b8`0403Xa8P0i<240>C0Q03P_80P0=B`M200c;2@802lX80<0:BHM0P0X9A`302LT6`P0
9R<J200S91`8024R6PP0820N200N81d801hP7`P071`J0P0J6QP0100K6aT071`J01`L6P0M7A/201hN
70P07AdK2@0L7Q/801`L6PP07ahI400M7QP801lP6P807AhH0P0N7aT201lP6P80824K00P07AhH01hO
6@0P8A/08B8L028S7@0Q8Q`0824K01lP6PP081lJ100O81X401hO6@P07b0J0P0P81h201lO7@807QhL
0P0M7A/401lP6P80824K0P0Q8Q`8024P6`@07ahI100P7aX301lN6@<07QdH0P0M71L801lP6P03020Q
6`0N7aT07AhH00<06a`F0P0M7QPI01dM6`@07b0J100N7aT2020Q6`807b0J0P0N7aT201dN6080824K
0P0O81X201hO6@807AhH0P0J6QP0100K6aT071`J01`L6P0M7A/201hN70P08B0K0P0R8A`3024P6`<0
81lJ200N7AP8028Q7080:R<M0P0Y8Q`0100X8A/09b0J02HO6@0V7aT802DU7@03024P6`0R8A`092<N
008092<N00<08R4L020O6P0O7QT0200O81X0100P8A/08B8L024R700Q8Q`2028S7@808b@N200O7ad3
01lP6P<0824K0P0Q8Q`8028Q71409BDM00H08R8H02<S6@0S8aT092@J02DU6`0V9Q`202LW7@<0:bLN
0P0Z9Qd302TU70809RHN100W9al202PX80P09BDM0`0S9Qd302@W7P809BPO0P0W9al0100V9Qh09BDM
02@T700S8a/2028R6P8092DO0P0S91h0100R8ad08B8L024R700P8A/202<T7P04028S7@0Q8Q`08B8L
020Q6`807b0J200N81d301lQ7R_ooooo000Zooooo`<0Vg4o0P2JL3h309U_?@<0VFe00P2JKT4309]_
@P0309a`?`2KKch0Vfln0080VVhm0P2IKC`01P2HK3/0VVhm09Y^?@2KKch0W70o09ea@080WW9100<0
Wg=209ec@@2MLd400`2KLCl00`2MLd40WgE30:1fA0020:9g@0040:5f?`2PMCh0Wg@m09ic?080WG8k
202NLd0809md@@060:IcA02TM4@0Y7A40:=eA02QMD@0X7I40P2OMd@30:5hA0@0XWU50P2SNTH20:9h
AP@0XgU70P2TNTP20:=iA`80Y7Y80`2UNdT90:IlBPP0YG];00X0YWe90:ElB02TNdL0XgY60:AkA`2V
ODT0Z7m;0:V0C02SNDL0Y7Y80P2UNdT0102TNTP0XgU70:9hAP2QMdD20:5fB@0;0:9gBP2QMTT0X7E8
09icAP2KL4<0VFi10:1fA02NM480Vg4o09Q^?02FK3X00`2EJcT208mY?00608iX>`2=IcX0RfDh08YT
=`29HcH0R68e0P28HcT208MR>00408IQ=`25H3H0Q5le08AO=@80P5de00@0Oe`d07iK<`1mFS80O5Ta
0P1kF300101nFcD0O5Tc07YG<@1hEBl307MD;P0307QE;`1cDRl0Le8_00H0Le8_00H0L50W071@:@1`
D2T0L50Z071?;01aD2l2075@<@08071?;P1`Cb`0Kdh[06m?:@1aDBX0Le<Z07IG:`1hFBd207eJ=004
07iK<`1nFc40OU`_07iL;P80Oed]00P0P5X[085K;023GBh0QV0a08US=02;ICH0SFLh08iX>@80SV<h
0`2?I3T3091U>PT0TVLj00P0S6`m08aZ?02;JC/0S6Lj08aV>@2>ICT0SV<h08eR=`<0SV<f0P2?I3L3
091U>0<0R68c1@29Hc@308US=P<0R68e0P27HC@308]P<`80RUlb0`29GS4308MQ<P0308IP<@25Gc00
QEl`0080Q5h_00P0Q5db08EN<`27HC@0RF<d08US<P28Hbl0Qf8^08IQ;0P0Qf4b1029HSL208YS>080
Rf@i0`2:IC4208]V<P<0S6Lc202?IC<208aV=`<0SFLh0`2>J3T01`2BKCT0T6/g08mZ=P2=J3@0S6Lc
08eX=02>JCD01@2?JSH4091[=`0;08iS>@2?I3X0Sf@i091V=P2@IS@0TFPb095X<02BJC40SfXf08iY
=@2<Ic<00P2:IC40102;IS80S6Lc08eX=02;IS8208aW<`0308eX=02>JCD0SVTe0080SfXf202?JCX2
08eX=0<0SfXf00@0SFPd08]V<P2;IS80RVDa0`2;ICH00`2<ISL0SFLh08eW>00208iX>@80S6Hi0`2;
ICP308YT=`80Qf4b00<0R68c08US=02:I3D00P2;ICH0102<ISL0Qf8e08IQ=024Gc8208=N<@0308AO
<P26HC@0Qf8e0080QV@f00<0QF<e08AR=023HC<00P22H3802@21Gc40NEX^07]L<01mGS80OUlc07mP
=01nGc<0OEhb07aM<@0207YJ<@0<07UI<01gEbh0MUH]07AD:`1cDbX0LU8Y06iC:01^DRX0KE4Y06a@
:@1[CbX0Jdh/0P1ZCBd0101WCB`0I4XY06=9:01TBRT206M=;00@06989`1M@b80EdHZ05E4:P1@@2H0
BcdS04Hj8P14>280@cPT048g8`0h=BH0=c@U03Hc900e<R<0<c0Q034^7`X0<2dN0P0];B<01P0/;280
:RXP02PX7P0W9ad09RHL02DU6`<09RLO0P0U9Qh302@U7@P08RDL200Q91d301lR6`8082<L0`0Q91d2
020S6P808B@K0`0R9A`0100S9Qd092HK02@V6`0T9Q/302DW70<09RPM200V:Ah01P0T9Q/09BLL02HX
7@0W:Ah0:2XO02T[8080:R`Q200Y:b0202HY7P<09bXO0`0X:b0602DX7`8092LN0`0T9Q/302DW7180
9RPM0`0V:1X202LY6`<0:2XL400W9a/0200W:QL0:2/H02//6P0^;A/0;b`K02h[6P0_:AT0;RPH0P0`
;2400`0`;200<BhO034^7@02034^6`06038`6`0d;a/0=2lK03H_700h<1d0>c0N0P0n<B000`11<B40
>c<N03/c7P0303`d7`<0?CDP00/0>cLL03dg7@0o>Al0@CXP04<i8013=al0A3DN04<d7@11=A/0@SHL
04<g7@0204@h7P0704<g7@12=Q`0@CDK044g7012>1d0AC/P04Lm8P0204Pn8`80AcdR00H0ACXJ04Dj
7014>A/0A3TM04@h7P14>20204<g8@D0A3TM1015>Qh00`17?200AS/O04@i7@0204<h700604Dj7P16
>al0Ac`P048h7@13>Ah0A3XO0P15>b000`13>Ah0@CLL040f6`0304<h7080A3TM0`15>Qh01013>1`0
A3TM04@i7@14>Ad404Dj7P0404Hi6@17>QX0AcXJ04Lj6P80B3/K0P19?1`03P1:>a`0BCXK04Tj6`19
>Q/0Bc`M04dn7`1@@B80DT<T04ll701@?Ad0DChN058o7`1D@B40ET<S0P1GA2@305518080DT8Q0`1C
@b800`1>@Al0Cd8P05138@0205138@0604i17`1<?ad0BchL04Xo7`1;@200C44Q0P1>@b<01P1<@B40
Bd0P04Xo7`1:?b<0BChR04Pm8@80Ac`P00T0B3dQ04Tn8P1:?b<0Ad0S04Ho8P15?R40A3dP04<l7`12
>ah00P11>Qd204Pj800304Hj8014>Ql0@S/O0080@3/N00@0?c/N04Dl7`15?1l0AC`O0P14>ah304<j
7@0504<l8012>al0A3XO04@h7P16>1h00P16=Qd01016=1`0@SHL048f7013=ad204@h7P0304Di7`16
>R00ASXP00P0A3PN4@13>Ah8044j7P<0ASPN0P17>Al304Pj800504<l7`14?B00ASdP04Pm8@1;?B80
0P1=?B<05`1??R@0DShS05<o901E@2<0F44R05]28`1M@b80GT@S06548P1NBb<0Gd`T069<8`1TCB<0
IdlS06Y?8P1[D2<0K50Q06aA8P1^Db@0LEHW07=H:@1dFBX0MEX[0080M5TZ00H0N5/_07UM;P1iGBh0
NUh^07]O;@1lHB`207eR:`80PV4/00H0Q6<^08ET;`27IS40R6Lb08UX<`2:JC@208]W<`0>08aX=02=
JCD0Sf/g091/>02AKCT0TVhj095a=P2ALCP0TW8i099a>`2CLSd0Tg8o09=a@@2DLT8209IdA00309Me
A@2HMTH0VGM70080VWQ800@0VgU909eiB@2MNDT0WGU91@2NNTX00`2SOdl0XWi>0:1lC00209mkB`03
0:1lC02ROTh0Xgm?00<0Y81@0P2UPE430:J2DP80Y8AE00L0YH=E0:N2E@2VPE@0Yh5D0:V0E02XOe<0
ZhIA0080ZXEA00<0ZXAC0:V3E02YPeH00P2XPEH80:J2D080Z8AD00<0Yh=C0:J2DP2UPE400P2TP500
0`2SOdl0Y81<0:B0C0020:B0CP0>0:F1D@2UP5<0YH1D0:F0E02UP5H0WWM>09mhC`2QNU40XgaC0:Am
E02SO5<0XW]B0:5jD@2PNT/209miBP0309ihB@2MMdP0W7I700L0VgE60`2LMTL00`2FLdT0UG9809Eb
B00209AaA`<0Tg16202BK3d03P2EK3h0TfXl08mY>P2<J3P0RfLg08UW=`29JCP0RVXi091Q=@2>HSD0
SF8e08YT=@29ICD0QfDe0P25IcD208YT=`0408US=P28HSD0Qf4d08IP<`80QElb00<0PU/b08=L<`25
GSD00P25GSD00`23G3<0PEXa081I<00207iG<080OEH_00D0O5D^07]D;@1jDb`0NU</07UC;P0307QB
;@80Me4/0P1fD2/207A=;080Ld`[0`1bBbX0101aBRT0JTXT06];9@1/C2H206e=9`0306a<9P1[BbD0
JTXT0080J4TZ00@0IdPY06I7:01VAbP0IDHW0P1TABH805i3:00305]19P1J@2D0F3hS0080ES`Q00<0
EcdR05Pn8`1I?b@0201E>b@00`1B>R80Dc/S05@l900205Dm9@0305<k8`1A>B40D3PP00<0C3LT1P1;
=R<00`17<Ql0BC@Q04/f8`0304`g900304Xe8P19=240A3<Q00<0@c8P0P12<Al2044`7P80?c0M0P0n
;a`403d^6`80>BdQ00H0>2`P03L[7`0f:Qh0=BTM03@X700c9a/203D[7`0303@Z7P0c:Ad0<bTM0080
<RPL2@0a9a/802/W7PP0:RHM0`0W91/202HS6P<09B8I200T8AP8024R70P0824K200O7ad801dO70P0
7AlN200L71X201XJ60806a/I00<071`J01dM6`0M7A/02@0M7A/901`N6`P071`J200O7QT801dN60P0
7QlI200O81X201dN60807QlI0P0O81X2020Q6`0301dN600N7aT0824K00808R<M00<08B8L020Q6`0O
81X0200P7aX401lP6P@07QlI200O81X2020P7P807alM0P0N7Q`201dM6`0401hO6@0O81X07b0J01lP
6P80824K0P0Q8Q`8024P6`<07ahI1@0P7aX301lN6@<07QdH0P0M71L901lP6P0701hO6@0M7QP071dG
01`M5`0M7QP07b0J020Q6`0I01dM6`@07b0J100N7aT2020Q6`807b0J0P0N7aT201dN6080824K0P0O
81X201hO6@807AhH0`0K6aT00`0L71X07AdK01dM6`0201hN70P08B0K0P0R8A`3024P6`<081lJ200N
7AP8028Q70<09b8L0P0V8A/302DP6PP092@L00P08B0K028Q700S8Qd092<N02<R7@0R8A`081lJ01lN
6@X07b0J0P0P8A/2024R70808R<M200O7ad301lP6P<0824K0P0Q8Q`8028Q71409BDM0P0S8aT202@T
6P0402DU6`0V9Q`09bLM02LW7@<0:bLN0`0Z9Qd202TU70809RHN1P0W9al802DU7@<08bHM0`0T9ah2
02DX7`809bLO00@09RHN02DU7@0T91`08b<K0P0R8QX202@U7`808b@N00D08R<M024R700Q8Q`08B8L
02<T7P02028S7@808B8L0P0P8A/00`0O81X07R0M01hP7@0601hP7@<07b4N:oooool002[ooooo0P2K
LCl209Y`?P<0VFlm00@0V6hl09U]@02IKD00VFe00P2JKT4309]_@P<0Vfln0P2JKSd309U]?080VVhm
0P2KKch01@2LL3l0WG5009ib@@2NLT40WG=10080W79000D0Vg4o09ab@02MLd40WWA209me@`020:Ai
A0030:=h@`2RMd80XGI10080X7E000<0Wg@o09ic@02NLd001P2NLd0809md@@060:Eb@`2SLd<0Xg=3
0:9d@`2PM4<0WgE30P2NMT<20:=jAP@0XWU50`2QN4@30:9hAP80XgU71P2TNTP20:EkB@/0YWa:202T
NTP0202VODT0YGa80:AkA`2SNTH0Y7]70:ElB02WOTX0Z7m;0P2WOD/00`2UNdT0Y7Y80:AjB0020:Aj
B00?0:EkB@2QMTT0XGI90:5fB@2PMDP0WgA709ebA@2KL4<0VFi109id@P2MLd40VW0n09M]>`2EJcT0
U6Xh0080UF/i0P2?JC`0102>J3/0S6Hi08]U>029HcH208QR=@80RF@j00<0R6<i08MR>026HCL00P25
H3H01`24GcD0P5de07mL=01oG3@0OU/c07eJ<P1lFC400P1kF300101mFS@0NePb07UF<01fDbd407AA
:`P0LU4^00H0L50W071@:@1`D2T0L50Z071?;01`Cbh2071?<008071?;P1`Cb`0L4l/071@:P1bDR/0
M5@[07IG:`1gF2`207eJ=00?07iK<`1nFc40Oed`07mM;`1oGBd0P5h^089L;@23GBh0Q5h_08IP<@29
Hc@0RfDf08aV=`2=IcP0SV<h00<0Sf@i0P2@ICX2095V>`T0TVLj0P29IcT00`2;IST0S6Hi08iU>@02
08mT>@04091S>@2@ICP0T6Dh091U>080Sf@g0`2>HcH00`2:I3D0RF<d08US=00508US=0<0RF<f0`28
HSD208MQ=0<0Rf0c0P2:Gc8308UN<@80Qf4b0`26H34308EO<080QEhc00<0Qf4d08QR<`29Hc800P28
Hbl00`27HRd0R68c08QR<`0608QR<`<0RF<f0P2:I3L308]U>080RVDa0P2;IS8308aW<`0308eX=02@
IS@0T6Hd00H0T6Hd0P2<ISL308eW>0<0SVPi00P0SfXf08iY=@2=J3@0S6Lc08eX=02>JCD0T6/g095/
>0<0T6/g0`2?JSH208iY=@80SV<h00@0SV<f08mU=@2?IC<0SfHb0P2@Ic400`2?JSH0SVTe08aW<`02
08YU<@0308]V<P2<Ic<0SFPd0080RVDa00H0RfHb08eX=02>JCD0SfXf091[=`2AK3P808mY>P0608eX
=02>JCD0SVTe08mZ=P2>JCD0SFPd0P2<Ic<00`2;IS80RfDf08aV=`0208aV=`<0SFLh00<0SVPi08aV
>@2<IST00`2;ICP308YT=`P0RF<d00<0Qf8e08IQ=025H3<00P24Gc800`25H3<0QV4d08MR=@0208ES
=@0308AR=023HC<0PV0b0080PEla00<0P5h`07aM<@1lGC400`1mGS800`1lGC40NU/_07YK;`0207UI
<00707QH;`1fERd0MED/07AD:`1cDbX0LU8Y06iC:00206eA:@0306a@:@1[CbX0JTd[0080JD`/00@0
IDd[069::01PB2H0HDTW0P1SBbT0401OAbD0FT8P05=2:01@@2H0C3`S04Pi8P13=b40@3DQ03hf8@0n
=R<0=c@U03Hc900e<R<0=34R03<`8@0a;Ql:030]7P80;2`R00H0:b/Q02XZ800X:1h09bLM02HV700U
9A/302LX80809RLO0`0U9Qh8028U70P08B@M0`0O8Q/2020S70<08B@M0`0Q91/2028U70<08bHM0`0T
9Q/302DW70<09RPM200V:Ah202DW700302HX7@0W:Ah0:2XO0080:B/P00<0:R`Q02T[800Y:b001P0Y
:b0402LZ7`<09RTN00<09BPM02@W7P0T9ah00`0T9ah302DX7`<092HK0`0U9a`B02HX7@<09BLI0P0V
:1X302LY6a009bPJ00h09bXE02T[5P0[;AP0;RdI030]6P0a;1T0<BXH030Y5`0d;R80=2hP03D_8@0e
;al0=S4N03Ha7@80=c8L00H0=C0J03La6`0h<Q`0>c<N03ld8011=24204Df8`<0?cDL0P10=Qd3044g
7P0;04<l8014?B40AcdR04Tm8`1:?280BSXQ04Ph7`18=Qh0AcLM04Ph7P1:>R000P1;>b401`1:>R00
B3PN04Lg7@14>Ad0ACXN04Pm8@19?R800P1:?b<204Tn8P80AcdJ00@0AS/K04Hk7@15>Qh0ACTO0P14
>20904Dj7P0304Ll8016>al0A3TM0080@cPL00H0A3TM04Dj7P16>al0@CLL048h7@14>Ql304Dk8004
04<i7P12>1d0@cPL04<h7080A3TM0`15>Qh504Hk7`<0ACXN00<0A3TM04Pi6P19>Q/00P19>Q/204Xk
7080Bc`M101:>a`02P1<?Ah0CSlP05118P1A@R<0CS/K04ll701@?Ad0DChN058o7`1D@B4205E28P80
DD4P0P1B@R4305=38P0305A48`1A@R40DT<R00<0Dd@S00H0DT<R0511801>?ah0Bd0P04a18@1=@R82
04i38`0604e28P1<@B40Bd0P04a19@1;@2@0BSlS0P19?R80101:?b<0Bd0T04a19@19@2<204Po8P03
04Ln8@16?B00AC`O0080A3/N0P17>Al00`15>Al0@cTN044j7P0203lj7@0403hj7@13>Qd0@cXM04<j
7@80A3/N0`15?1l2048k7`0704@j7`15>Al0ASPN04Lg7P16=Qd0AcDM044e6`02048f700504@h7P15
>Al0ASXP04Lk8@18?2802014>1hA04<i7PP0@CXN0`14>1h204Di7`<0ASXP0P15?R400`17?R40B3dQ
04Xl8@0204/k8@0G04`k8@1>?B40DCdR058o8@1F@B80FT<S05e58`1PARD0H4HS05e9901NBb<0HD/T
06=<8`1VCB@0JDhS06Y?8P1[CR80Je0S06eB9@1_E2L0LULZ07=H:`1dFB`00P1cF2/03P1iG380NE``
07YM<@1kGc00O60`07eQ;`1mHRd0OV<^085P:`22HB`0Pf8]08AS;P26IC00QfHa0P28Ic80202:IS80
RfLc08aX=02=JCD0Sf/g091/>02AKCT0TVhj0P2ALCP00`2AL3X0TW4l099a?P0209=a@@0609=a@`2E
Ld<0UG=309IdA02GMDD0V7I60P2IMdL01P2JN4P0VGE509YfAP2JMTH0VgM709ahB080WGU900@0WWY:
0:1lC02ONd/0WWY:0P2MNDT00`2NNTX0Wg];0:1lC0020:9nCP80Xgm?0`2TP5002P2UPE40XX9C0::2
D`2SPE<0YH1C0:J1E02WPE@0ZH1D0:Z1E@2YQ4l20:V4D0030:R2D@2XPU<0Yh5D0080Yh1E202SOdl2
0:=nD@030:9mD02QO4l0X7]>0080WgY=00<0WWU<09mkB@2ONdT00P2ONd/0202ONTd0WgY>09mjD02O
NU00WgUB09Ue@`2JMT@0W7Q60`2MNDL01`2LN4H0VgM509Qd@02HM400Ug<o09Ib?P2ELCd00P2DL3`0
0`2CKc/0Tfi109=^@@0609=^@@0608m]?@2>K3`0SF/k08aZ>P2;JCT0RFLg0P28ISH808QS>@0808]T
>`29HST0QV4g089O=@20Gc@0Of0d081Q=@1oHSH2089K<P04085L<P1oG380OUdb07eN<P80Nehb0P1m
FS8207aI<@0407]H<01jEbl0NEH^07UF;P80ME8/0`1fDbd0101eDR`0Le0Z079?:@1aCB/2071<:P03
06m;:@1^BRP0KDTW0080K4PV0P1ZBBP206U89`<0J4LV00@0IdHU06E49@1UA2D0ID@U0P1T@b@306=2
8`0305/n7P1L?al0GD0P0080GT4Q00<0GD0P05`o7`1K?Qh00P1I?b@0101H?R<0EcdR05Hl8@1E>b02
05@j7`P0DSTS00<0Cc/S04hj8P1<>2000`1;=al204`h80P0B3<N0P15<ad304Hd7P0304Dc7@13<A/0
@S0J0080@S4Q00D0@C0P040_7`10;al0@2lO03l^7P0203h]7@80=BdJ0`0f;Q/0100e;AX0=2`I03<[
600h:a/303LZ6P80=RTI0P0e:1P3038V5P80<BDE0`0`91@01P0^91X0;B<I02dS6@0/8QP0:b4G02XP
5P80:AlE0P0Z91P202TS5`@0:28F200Z91P802<N60P09B0J0`0R8QX2024Q6@<0820H200O7aL801hO
6@P07AhH200M7A/801XL6@P06Q`K200K6aT0100J6QP06a/I01/K6@0K6aT301`L6PT07AdK2@0L7Q/8
01`L6PP07ahI200M7QP@01lP6P807AhH0P0N7aT201lP6P80824K00<07AhH01lP6P0P8A/00`0R8ad0
0`0Q8Q`0824K020O6P07020O6P@07QlI300O81X2020P7P807alM0P0N7Q`201dM6`<07QlI0P0O81X3
020Q6a0081lJ0`0O7QT301hM60807A`G2@0O81X01`0N7aT07AhH01dN600N7aT0824K028S7@0S91h0
200M7A/901hN70P07AdK100N7aT401lP6P80824K0P0O81X201hO6@807AhH0P0P8A/201lP6P807QlI
0P0M7QP0100K6aT071`J01`L6P0L71X301dM6`0301hN700Q81/08B0K00H08B0K0P0R8A`3024P6`<0
81lJ200O7QT8028Q70@09B0J0`0V8A/00`0W8Q`08R8J028R6P06028R6P08024P6`0R8A`08b8M02<R
7@0R8A`08B0K020O6P0O7QT801lP6P<07QlI0P0O81X3020Q6`P07alM0`0O81X3020Q6`808B8L200S
8QdA02DU7@0602<S6@0T91X092@J02DU6`0V9Q`09bLM0P0X:1h202`X7`80:bLN0`0Z9Qd0100Y9A`0
9bLO02LW7`0W9al502HV7PP09BDM0`0T9Ad302DV7P809RLO0P0W9al0100V9Qh09BDM02@T700S8a/2
028R6P<08b@N0`0R8ad2024R70<08R<M0P0Q8Q`3020Q6`P07R0M0`0O8Ah[ooooo`00:_ooool309Y`
?P<0VFlm0P2HKS`309U]@080VVi10`2KKd8809Y^?@80VFdl00@0VVhm09]_?P2LL3l0WG500P2NLT44
09ab@080WG=10P2NM4830:5f@`030:1e@P2OM440WgA100`0WW=0102OM4420:1e@P060:=`@@2QLD40
XG510:1b@@2NLT40WG=10P2LM4420:AkA`040:=jAP2RNDD0XGQ40:5hA080X7M300@0WgI20:5gA@2Q
MdD0XWQ60P2SNDL00`2TNTP0YG]90:EkB@020:AjB0<0YG]92`2VO4X80:=jAP030:MnBP2VODT0YGa8
0080Y7]700H0YGa80:MnBP2XOd/0ZX1>0:QnC02UNdT20:=iA`030:AjB02VO4X0Z7i<0080X7E800X0
WgA709icAP2MLTD0Vg1309Y_@P2IKT40WG=309]a@@2IKcl0UV`l0`2DJSX02@2EJc/0SfTl08iX>`2=
IcX0S6Hi08YT=`29HcH0R68e08MQ=00208UT>P80R6<i00@0Qf8h08IQ=`25H3H0QF0f0P1oG3@00`1n
Fc<0OEXb07aI<@0207]H<00607YG;`1lFC<0NULa07MD;P1dDB/0LTlY0P1aCRP00`1bCbT0LU4^079A
;P06079A;P06071@9`1`D2T0L50Y071@:P1_CR/0Kdh]0P1_CRl0201aCRh0LDl/079@;@1cDB`0M58/
07IE;01gER/0N5L/0P1mFS@01P1nFc<0OU/a07mM<020GS00P5h^085O;`80Q5h_00@0QEl`08MQ<P29
Hc@0RfDf0P2<ISL308mT>@80T6Dj0`2AIS/909=X>`0808QS=P29I3L0RV@g08eT>02?I3T0T6<i095T
>P2CI3X2095V>@04091U>02?I3L0Sf@g08iS=P80SF8e0`2;ICH408YT=@0408US=029HcH0RF<f08US
=P<0R68e0P27HC@308]P<`80RUlb0`29GS4608IP<@80QEl`00D0QEhc08IO=026H3<0Qf4b08QR<@02
08QS;`0308QS;P28HS<0R68c00H0R68c0P29Hc@208YT=@80RfDf0P2<ISL308]V<P<0S6Lc0P2=J3@8
091V=080S6Hg0`2=IcP308iX>@80SFPd0P2<Ic<0102=J3@0SfXf099]>@2CKSX2095/>003091[=`2?
JSH0SVTe0080SFPd00<0S6Lc08iT=02>I3@00P2>I3@208iT<P0508mU<`2?IS80SfXf08iY=@2<Ic<0
0P2:IC402@2;IS80S6Lc08eX=029I300RVDa08]V<P2<Ic<0SVTe08mZ=P02095/>0P0SfTj102>JCD2
08eX=0<0S6Lc202=IcP208aV>@<0RfDh0`2:I3L308YT=@0308US=028HS<0Qf4b0080Qf4b00<0R6<f
08IQ=025H3<00P24Gc800`25H3<0QV4d08QS=P0208AR=00408=Q<`22H380PEla085O<@80P5h`00h0
OUlc07eN<P1mGS80O5da07]L<01iFRh0N5T]07MH;01hF2l0MeL^07IF;@1eEB`0M5@[07=C:P80LU8Y
00H0KE8W06eA:@1/D2P0JdlX06Y>:@1XBbT206M::P0406=<;01OB2P0G4DU05e69P80GdPX00/0Fd@T
05M0801=?B@0BS`R04Lh8@12=R00?S<O03/c800i<Ql0>C8P03Hc900203Db8`0403@a8P0b;b00<BhO
034^7`@0<2dN100_;1d01`0^:a`0:b/Q02/[8@0Z:R00:BTO02PX7P0W9ad00P0V9Q`202PY8@<09bPP
0`0V9al8028U70P082<L0`0O8Q/2020S70<08B@M0P0Q91/3028U70<08bHM0`0T9Q/302DW70<09RPM
200V:Ah302HX7@0302LY7P0X:Ql0:2XO0080:B/P200X:Ql01@0X:b009bXO02LZ7`0V:Ah09BPM0080
92LL00<08bHK02<V7@0S9Qd0100T9ah202DX7`<092HK0`0U9a`B02HX7@8092HH0`0U9aT302HX6Q00
:2TI00H0:B/E02`[5P0^;AP0<BlJ03@_6`0d;AX203@/6@80>34Q00l0>C8P03Xc800j=1h0>cDM03`f
7P0l=Q`0>S@J03`e6`0m=Q`0@CLN04@h8018>B80BSXS04/k9015=a`00`16>1d204Li7P80B3XO00/0
B3dO04Tn801<?R40CSlR04hm8@1=?200CCTN04`h7@1=?1h0CSdO050o8@0205508P06050o8@1>?Al0
CC`N04/l7@1<?Ah0CSlP0`1@@B800`1?@240CSlP04e16`0204`o700504/n701:?Ad0BC/N04Tk8018
>Ql00P1:?1l404Tk7P<0B3XM00<0BS`Q04Pj7`17>Ah00P15=a`01`16>1d0AcTN04Pj7`10=Q/0@CLL
04<i7P15>b000P16?2400`15>b00A3XO04@i7@0204@i7@<0ACXN0P16>al204/m800404Xl7`19>ah0
B3XM04Pj7@80AcTL0`1;>Q`204`k7@<0CC`N00P0BS/L04/l7@1;?1d0C3dN04dn7`1>?b00Cd0Q0511
8P80CS/K00H0Cc`L050m7@1A?Qh0DSlO05=0801D@B4305928@<0Dd<R0P1DA2<00`1C@b80E4@S05E5
900205I69@0305E5901C@b80DT8Q00<0Cd8R0P1@@b<304m28P0305129`1?@BH0CT0U0080CClT00<0
CT0U04m19P1@@RL00P1:?b<204Tn8P0404Pm8@17?200Ac`P04Ll8080AcTO00<0ACTO04<i7P11>Qh0
0P0o>Qd0100n>Qd0@STL048i7013>Qd204@k7P0304Dl7`16?B00ASdP0080@S/O00H0A3XO04Di7`17
>Al0B3PO04Lg7P18=Qh2044e6`0604<g7@14>1h0ASXP04Lk8@18?280BCdS2015>AlA04<i7PP0@CXN
0`13>Ah204@j7`<0AC/P0P16?b800`17?R40B3dQ04Xl8@0204Xj800E04/j801;?1l0CC`P04ln801D
@B40F4@S05a58`1OAbD0H4PT05a89@1LB2<0GdTT069:901TBb<0J4`T06U>8`1ZCB<0JTlR06aA901^
DbH0LEHY00<0LULZ00L0LEHY07UL<P1iG380NUda07]N<P1lH340O60`0080OF4_0P21H2d01022HBh0
Pf8_08AS<025I34208IU<P0608UU<`2:IS@0RfLe08aX=P2=JCL0Sf/i0P2@K3X2091_>@03091_>P2A
L3d0TFlo0080TW1200H0TW1309=a@@2CLD40U79209Ec@`2FM4@209MeA@0909QfAP2HM4@0V7A409Ue
A@2KMdL0W7Q809eiB@2NNTX0Wg];00P0WWY:0P2ONd/20:1lC0<0XGe=00L0XWi>09emCP2NOTl0Wge?
0:9mD02SOU40YGmB0080Z7mC00H0YH1;0:F0C02UP4`0Y7i=0:AnC`2TOU420:=lD@P0XGa?00H0X7]?
09mjCP2ONTh0WWU=09ehC02LMd/209]fBP0709Mc@`2FLT80UW5409IaA02FLDD0UW5709E`AP0209E_
B00309Ac?@2EM3h0UG@n00<0UWDo0P2EM3h01P2ALCP0T70g091`=`2?KcH0SVhe08e]=080S6`c0`2;
J3h308YW?@80RFHl00H0QfLd08IV<`25IC80Pf<`085Q;P20H2d207iN:`P0O5Xd00D0P5dg07iK=@1k
FC<0N5Pa07EH<00207EI<@0307AK<P1fES00MUH`00<0M5H`0`1cEc02071B;P80Ke4]00@0KU0/06e?
:`1]Cb/0KDl[1@1VBBT00`1UB2P0I4LW06A79`0206959`80HD@V00@0H4<U05m2901N@B<0GT4S101K
@2D205Xo9080FChS101G>b<205Hj8P80ECTQ00<0C3HN04dg7`1==al0101==al0101<=Qh0BcHQ04/f
8@1:=B0204Td7`0304Pc7P17<Qd0Ac8M00P0@C0N0P10<Ah00`0o<1d0?RlL03h_700303h_70P0>RXK
0`0g:a/203HZ6P80=BTI00@0=2PH03HZ7P0f:Qh0=BTM0P0c9a/0100b9QX0<BDI030T600_8aL202LX
60809RLG00@09BHF02@U5@0S91@08R<C0P0/8QP202/Q5`80:R0F0P0Y7aD302PR5P809b4E0`0V81@0
0`0V7aL09AhF02DN5P0202@M5@808a`D00<08Q/C024N5@0Q7QD0100Q7QD2020M50P08AhE200N6aH8
01lL5`807QlI0P0M7QP301`M5`T06a`F400K71L801/K6@P061XG200H6QT@01/K6@P071`J2@0K7AX8
01`L6PP07ahI200M7QP8020Q6`P07b0J0P0M7QP201hO6@807b0J0P0P8A/0200N7aT07b0J024R700R
8ad08b@N028S7@0Q8Q`0824K200P7aX401hO6@`07b0J0P0P81h201lO7@807QhL0P0M7A/301hO6@<0
7b0J0P0P8A/8020O6P@08B0K100P7aX301lN6@<07QdH0P0M71L901lP6P<07QlI00@07b0J028S7@0T
9Al09RLQ200M7A/901hN70P07AdK100N7aT401lP6P80824K0P0O81X201hO6@807AhH0P0P8A/201lP
6P807QlI0P0M7QP801dM6`P08B0K0P0R8A`3024P6`<081lJ200O7QT8028Q70808QlH00<08b0I02@Q
6P0U8Q/00P0V8a`00`0W91d0820H020P6006020P60@08R4L00@08B0K020O6P0P7aX07ahI200O81X3
01dN60807QlI0`0O81X801lO7@<07b0J0`0P8A/2024R70P08b8M4@0V9Qh202@T6P0402DU6`0V9Q`0
9bLM02PX7P80:BTO0`0/:1l202/W7P<0:RHM0P0W9al402HV7Pd09BDM0`0V9Qh402LW7`0402HV7P0U
9Ad092@L02<S6`808R8J0P0S91h6028S7@P08B8L200O8Ah3020R7b_ooooo000Zooooo`80VW0n0`2I
Kcd309Q^?0<0VFe00P2JKT4309]_@PP0VVhm0P2IKC`0102JKSd0Vfln09]_?P2LL3l209ea@00309]a
?`2LLT00W7900080WG=10`2NM4800`2MLSl0W74n09aa?P0209aa?P<0Vg0m202NLd000`2MLSl0WW=0
09ic@00209md@@80X7E200L0XGI30:=`@@2QLD40XG510:1b@@2NLT40WG=10080W7A10P2TNdL0102S
NTH0XWU50:5hA02QN4@20:1g@`0609mf@P2PMT@0XGM50:5gA@2RN4H0Y7Y80P2UNdT0102VO4X0YG]9
0:EkB@2UNdT30:IlBP80Yge;202VO4X80:AkA`030:QoB`2WOTX0YGa80080Y7]700H0YGa80:ImB@2W
OTX0ZX1>0:QnC02UNdT20:=iA`030:AjB02VO4X0Z7i<0080X7E800@0WW=609ebA@2KL4<0VVm20P2I
KT40202KL4<0VVm209M/?`2EJSd0U6Tl09=X>`2DJC`0UFXm0P2>J3/0102=IcX0RfDh08YT=`28HSD2
08MQ=080R6<i0P27HSP01@26HCL0QF0f08AO=@24GcD0Oe`d0080OU/c00<0OEXb07aI<@1kF3000P1j
Ebl0101jEc40N5D_07IC;@1cD2X4075>:0P0LU4^00h0LE4X071@:@1`D2T0KdlY06m>:`1^CB`0KTd^
06e<;@1aCBd0LTh/07=?;@1eDBd0MU<]07MD;080N5D[00H0O5Tc07eJ=01nFc<0Oe`b081N<@21Gc42
089P<080QV0a00@0Qf4b08QR<`29Hc@0RV@e0P2;ICH208mT>@80T6Dj0P2AIS/2099W?0T0TfPk0P29
HcH01P2<HcL0SV<h091S>@2CI3X0U6Dk09ET>`80TFHi00@0T6Dh08mT=`2?I3L0SV<f0P2=HSD208eW
>080S6Hg00@0RfDf08YT=@2:I3D0RV@e0`29HcH308QR=@80Qf4d0`2;H3<208YO<P<0REha0P25Gc06
08IP<@80QUld00<0QV0c08IP<@27HC000P28Hbl00`29I2l0RF<d08US=00608US=0<0RV@c0P2;IC@3
08aV=@80RfHb0`2<Ic<308eX=0P0TFLe0P2<ISL308eW>0<0SVPi102<Ic<01@2=J3@0T6/g09=^>P2D
Kc/0TF`h0080T6/g00<0SfXf08iY=@2=J3@00P2<Ic<01@2?IS80SfDc08mU<`2?IC<0SfDe00<0SV@d
00<0SfXf08iY=@2<Ic<00P2:IC402@2;IS80S6Lc08eX=02:IC40RfHb08aW<`2=J3@0SVTe08mZ=P02
091[=`P0SfTj00<0SfXf08iY=@2>JCD00P2=J3@408aW<`@0SVPi102=IcP208aV>@<0RfDh0`2:I3L0
102;ICH0RV@e08US=029Hc@208MQ<P0508IP<@25Gc00R6<f08MR=@26HC@00P24Gc800`26HC@0Qf8e
08QS=P0208=Q<`80PV0b00X0PEla081N<01oGBl0Oed_07iO<`1mGS80O5da07YK;`1iFRh0N5T]0P1g
F2`207IF;@0407EE;01dE2/0Le<Z07=C:P80LU8Y00X0KE8W06eA:@1/D2P0JThW06Q<9`1WBRP0ITTY
06E8:01OBR/0FdHW0P1G@R<205U49@0;05I18P1B?Ah0BCXS04Di8@12=R00?S<O03Ta7P0g<1d0=S4N
03H`800e<R<00P0d<B80100c<240<RlP034^7`0a;Ql4030]7P0302l/7@0^:a`0;R/L0080;BXK0P0Z
:R00100Y:Al0:2PN02PX7P0W9ad202HV700402PY8@0W:2009bPP02LX80809RLO0P0U9Qh8024T6`P0
82<L0`0O8Q/2020S70<08B@M0`0R9A`302<V7@8092LN0`0T9Q/302DW70<09RPM200V:Ah00`0V:1d0
9bTN02LY7P0202LY7P<0:2XO200W:Ah01@0W:Ql09RTN02HY7P0U:1d092LL00808bHK00<08RDJ028U
700R9A`00P0S9Qd202@W7P809BPO0`0T9Q/302DW71809RPM00@092HH02DW6@0U9aT09BLI0P0V:1X2
02LY6a00:R/I00d0;B`G02l]600b<1/0=S4M03Pa7P0i<Ah0>RlM03T^700l=240?CDR03de800n=Ql0
?cPN0080@CXN00L0@S/N040i7013>Qd0A3/N04Hk7`1:?240CCdS0080CchT0P1<>al204dl80<0CSdQ
00`0CchR04`m701=?Qd0CclN05107`1B?al0DC`M058k701A>Q/0ET8Q05M38P1HA2<205U5900605Q4
8`1G@b80ET8Q05=07`1D@B00ET<R0`1GA2<0201E@R40E44P05=6701BA1d0DD<L05127@1?@Ah0CSlN
0P1=?Ql404ho800304dn7`1<?Ah0C3dN0080Bc`M00/0CCdS04`l8P1:>R00B3PN04Lg7@18>1h0BCTO
04Xj8010=Q/0@SPM04@j7`0304Hl8@80AC/P0P14>Ad304Dj7P<0AS/O0P1=?Ql204`m7P0404/l7@1:
>a`0BCXK04Tj6`80C3/M0P1=?1h304hm7`0604ln801;?1d0Bc`M04`m7P1=?Ql0CSlP0`1?@24204ll
7080D3dM00@0DChN058o7`1B?al0Dd0P0P1B@R4305=38P<0E4@S00<0Dd<R05A48`1FARD00P1GAbH0
101FARD0EDDT05A48`1B@b@605528`040593901B@RP0DD4W05109P80CclU00<0D40V05519`1B@RP0
0`1<?R<404/m8P0604Xl8@18>R00B3XP04Hj8014>Ql0@S/O0P10>ah0100o>ah0@STL048i7013>Qd2
04@k7P0304Dl7`16?B00ASdP0080@S/O00`0A3XO04Di7`17>Al0B3PO04Ti801:>200@SHL04<g7@14
>1h0ACTO04Hj8017>b4204Pl8PP0ACTO4@13>Ah;044j7P80@S/O0`13?20204Dn8@0J04Ln8@17?200
BC/P04Xj8019>Al0BSTO04Xl7`1<?B00CchP0551801F@b80FTHS05i79@1OBB@0FTHU05]7901NB2<0
H4PT06=9901VBR<0Id/S06U<901YCR<0JTlT06eB9`1_E2T2075F:`80L5DZ00H0MeXb07QK<`1hFc40
NE``07YN;`1kGc0207aP<080P5h^00@0PEl_089P<022H300Pf4a0P24HS8208MS<`0?08QT=02:ISH0
RfLg08aX>02=JCT0SVXj08e/=`2>KCP0SVdj08i/?02?KCl0Sfe0091^@@2@KD<0Sfdm0080T6hn00<0
TFlo099`@02CLD400P2DLT801P2GLd<0V7A409UeA@2JMTH0W7Q809eiB@80WWY:0`2MNDT209ijBP<0
WGU90`2KMdL209ahB0<0WGU900T0V7Q909UiBP2JN4X0WGQ;09iiC02PNTd0XWU=0:=jCP2ONTD00P2O
NTH00`2NN4L0WWQ909egBP0209efB`P0WWU=0P2KMT`0102JMD/0VGA:09UdBP2HLdT209MbB00909=^
@@2BKD00TVe1099]@@2AK400TFa2091Z@`2@JTD0SfU40080Sg0j1P2>KcT01P2:JcD0RFXd08UZ=028
JC<0QfPb08IW<@80QFH`0P23HC/2089P>P80PEli0P20GSP207iO<00607aM;P1kG2d0NEX[07MH:@1f
EbP0MEHW201aDc40101eE3<0M5<b071B<01]D2h206Y@;@0406YB;P1YDbh0Ie0`06M@<0<0J4l`0`1Y
CS000`1SBR`0HTT[0699:`020699:`<0HDPZ0P1H@bP00`1G@RL0ET4V05I19P0305I19P80E3hV00@0
DcdU058l901A>b<0DC/S0P1@>R8304hj8P<0CCTQ0P1<>20204/f8`80BSDR1019=2400`11<B40@30P
040`8004040`8005044a8@0n<B40?S4Q03d`800l;al00P0k;Qh00`0j;Ad0>B`L034W6`07034W6`D0
<2PK00<0;bLJ02hV6@0^9QT0200[8QT0100[91X0:R<I02XS6@0Y8QP402PQ5`80:R<K00D0:B8J02PQ
6@0X8AT09QlG02DN5P0202@M5@807bDI00<07R@H01dS5`0L8QH00`0K8AD3024L5P<081/E0P0O6Q@2
024Q6@<0820H0`0O7aL00`0Q7QT081dH020M6002020M60<07a`G200M7QP801XK5@P071/G200J6AD3
01/L5`<06Q/F2P0I6QD@01TI5`P06QXH200G6AH801LI60`06a/I100J6QP801`L6PT06adJ200L71X8
01hM60P07AhH200P8A/801lP6P807AhH0P0N7aT201lP6P80824K00<07QlI01lP6P0Q8Q`00`0S91h0
0`0R8ad08B8L020O6P07020O6P807AhH0P0N7aT201lP6P80824K200O81X2020P7P807alM0P0N7Q`2
01dM6`807AhH0`0N7aT301lP6PP07ahI00<08b8M028Q700R8A`00P0Q81/2020O6P@07ahI0`0N7AP2
01dL5`T07b0J0`0N7aT0100O81X08R<M02@U7`0V9b4801dM6`T07alM200M7A/201dN60807QlI0P0O
81X4020Q6`807b0J0P0N7aT201dN6080824K0P0O81X201hO6@807AhH100N7Q`401dM6`P08B0K0P0R
8A`3024P6`/081lJ200R8A`01P0O7aL0820H020P600Q8AT08R8J02<S6`8092@L200P81P2028Q7003
024P6`0P7aX081lJ00<081lJ200O81X301dN60807QlI0`0O81X801lO7@<07b0J0`0P8A/2024R70P0
92<N4@0V9Qh202DU6`0402HV700W9ad0:2PN02TY7`80:RXP0P0]:B0202`X7`80:bLN0P0Z9Qd202LW
7`809RHN0P0U9Ad202@T70P09BDM0`0W91d302PU7P80:BHO0P0W9al0100V9Qh09BDM02@T700S8a/2
028R6PH08R<M0P0S91h8024R70P07b4N0`0P8Ql[ooooo`00:_ooool0102JL3h0VFlm09U_?@2IKcd2
09Q^?080Ufdk0`2IKD0209Y^@@<0Vfm20`2IKC`209Y^?@<0Vfln00H0V6`k09U]?02IKC`0VVhm09]_
?P2LL3l209ea@00309Y`?P2KLCl0WG=100<0WWA20P2MLd4809Y^?@P0WW=00P2MLSl0102NLd00WgA1
09md@@2PMD820:5f@`060:Eb@`2SLd<0Xg=30:9d@`2PM4<0WgE30P2NMT<20:=jAP@0XWU50`2QN4@0
202OMD<0X7I40:5gA@2RN4H0Y7Y80:EkB@2VO4X0Yge;0`2UNdT20:IlBP<0Yge;202VO4X80:ElAP08
0:QoB`2WOTX0YGa80:AkA`2SNTH0Y7]70:ElB02VODT20:MmB`030:EkB@2TNTP0Y7Y80080Y7Y800D0
YG]90:1eB02OM4L0WG9509]`@`0409U^@@0409U^@`2HKD80UV]009AY?P80TfPm0P2DJCh02@2>J3/0
SFLj08aV>@2;ICP0RF<f08QR=@27HC@0QV0c08MR>00208IQ=`0308EP=P24GcD0Pehd0080PUdc0P1n
Fc<00`1mFS80O5Ta07]H<00207YG;`0507UF;P1hEBl0Me@^07EB;01cD2X00P1bCbT00`1cD2X0M54[
075@;@07075@;@0>075A:01aDBX0L50Y06m?:@1^CBX0KD`[06e<;@1/Bb`0Ld`]07A=;01fCbh0N58^
07YD;`1jE2d207YE:`0607aI<`1mFS@0OU/c07mL<P20GS40PV0b0P23HC400`27HC80R68c08QR<`02
08US=0<0RV@e0`2@ICX2095V>`<0TVLl2@2CJ3/208eT>00608mT>@2AI3X0U6Dk09ET>`2FIC`0V6@l
0`2@ICP208mT=`<0SV<f0P2>J3T208eW>00408aV=`2;ICH0RV@e08YT=@<0RF<f0`28HSD208MQ=0<0
Rf0c0P2:Gc8308UN<@<0QEl`0`26H34208MQ<P0808MP=@26Gc@0QV0c08EO<026H2l0Qf8^08UT<029
I2l808US=080RVDa0P2;IS8308aW<`0308eX=02;IS80S6Lc0080S6Lc0P2=J3@208iY=@P0TFLe0P2<
ISL308eW>0<0SVPi00P0SFPd08aW<`2<Ic<0S6Lc08eX=02@JcL0TVdi09A_>`80SfXf0`2>JCD308eX
=080TFPb00@0TFPd091V=02@ISH0T6Dh0P2?I3T00`2?JSH0SVTe08aW<`0208YU<@0308]V<P2<Ic<0
SFPd0080S6Lc0`2=J3@308iY=@P0SfTj00<0T6/g08mZ=P2=J3@00`2<Ic<308eX=0<0SfTj0P2>J3T3
08eW>080S6Hi0`2;ICP308YT=`0508YT=@29Hc@0RF<d08QR<`27HC800`26H3400`28HcH0Qf8e08IQ
=00208EP<`0408IQ=027HSD0R6<f08=Q<`80PV0b00<0PEla081N<01oGBl00P1nG2h0101nGc<0O5da
07YK;`1iFRh407MH;0<0M5@[0P1cDbX3079B:@0606eB9`1/D2P0JdlW06U=9P1WBbH0ITTW0P1TAbL0
3P1MBR`0FDHX05A18`1C@280E44S05E2901B?b40Cc`N04@h8P13=b40?c@P03Xb7`0g<1d0=C0M0P0c
<1l303<`8@80<RlP100a;Ql2030]7P0302l/7@0^:a`0;BXK0080;2TJ0P0Y:Al202PX7P809bLM0P0V
9Q`302HW7`809BHN0`0T9Ad8024T6`/07b8K0P0P8a`3024T7@<08RDL0P0S9Qd302@W7P<092HK0`0U
9a`302HX7@P09RTN200W:Ah802HX7@0402DX7@0T9a`092LL02@W70@08bHK0P0Q91/0100R9A`08bHM
02@W7P0T9ah202DX7`<092HK0`0U9a`B02HX7@<09RPJ0P0W:A/302PZ7100;BlJ00H0<BlH038`6@0g
<Q`0>S@N03de800o=20203lb7`07044f8012=b40@cTP04@j7`15?1l0ASdN04Ln7`0204Po7P0504Tn
7P1:?al0CD0P04m08@1@?b400P1C@28305A18@80ED8R0`1F@b<02`1??a/0DT0L05A27P1G@b00FD8P
05Y2801J@1l0FClN05i68P1OAb<0H4PT0080HDTU00H0H4PT05m78`1NAR80G4HQ05e78P1NB2<205m9
900305i88`1MAb80G4HQ0080FDXO00H0F4TP05M88@1EAQl0E4@P05=38@1B@R0205A48`80Dd<R00<0
DT8Q0551801@@1l00P1??ah00`1A@2H0D3lU04dl8P0304/j8080C3/Q00T0@SPM04<i7P15>b00AS`Q
04Lm8P16?240AC/P04@j7`14>Ad00`15>Qh204Hk7`80Ac`P00@0CclN04hn7@1>?Qd0CShM101=?A`3
050m7`80DChP0`1B?b400`1;?1d0C3dN04dn7`0304m08@80CSlP00D0D3dM054n7P1A?Qh0DChN058o
7`0305=0800405928@1C@b80Dd<R05=38P80E4@S0P1EAB@00`1D@B40ED8R05M4900205U69P0305Q5
9@1GA2@0ET<S0080E4<U00@0Dd8T05918`1B@B<0Dd8T0P1D@bD00`1C@RP0DT4W05509P02050o9@03
05509P1B@BL0Dd8X00P0CCdS0P1:?2800`18?280AS`Q04@m8@02048m8004044m8013>Qd0@cXM04<j
7@80A3/N0`15?1l2048k7`0604@j7`15>Al0B3XP04Ti801:>R40BcTQ1015>Al204Hj8080Ac/Q2016
>R0A04<i7P/0@CXN0P12>al304<l8080A3dP00<0ASdP04Ll8019>b000P1:>R005@1;>R00BcdP04/m
801>?b00DD4P05=38@1HAR80FTHS05]78P1IAB@0FTHU05e6901OAb<0HDLT06E9901VBR<0IdTS06M;
8`1YCBD0JdlW06iB:P0406mC:`80MELa00<0MUTa07MJ<01hFbl00P1iGBh00`1jGRh0Oed_081N<002
081N<080PEla0P22H3802023GS40Q5lb08EP<`26HC@0R6<f08UT=`2:ICP0RfHi0P2:JCH00`2;JCT0
RfTk08aZ?@0208aY?`0708eZ@P2;JCT0S6Xj08aZ>P2=Jc/0SV`l08m]?@02091^?P0509A`@02ELD40
UG5109Ib@P2GLd<00P2HM4@0102IMDD0Ug=309QdA02IMDD209YfAP0309UeA@2HM4@0Ug=300<0UW92
0P2GLd<309QdA006099b@`2CLd@0U79409IaA02GLTD0V7950P2JLDD01P2GLSd0Ug8n09Mb?P2FL3l0
UW1109E_@P80UFi3202FLDL01P2DKTL0Tfe6099/A@2BK4D0TF]4091Z@`80SfU200L0T6/n091[?`2?
JSh0SfXn08mZ@02>J440SFM20080S6I200<0QFHh08AU=`22HcD00`21HS@01`22HcD0Pf@f07mP=01o
H3@0OUlc07eN<P1lGC400P1kG3001P1jFbl0N5Ld07MF<`1gES<0MUDb07ED<@80M5<`00T0Le8_075C
;@1aDbd0L58/06i@:P1]CbT0K4hX06]=9`1ZC2H0201VB2`0201WB2`0IDL[06=5:@1OA2L0GD@V05a5
9P1KARL0G4LX0P1EAB/0101FAB/0F4@[05U3:`1K@b/205a2:`P0DclW00<0Bc/T04Xj8`18>2400`17
=b0204Ph8@80AcHT00<0ASDS04Dd8P14<b400P13<R001012<Al0?c8Q03lb8@0o<R4203ha80<0?C0O
0`0l;al203/^7P<0>RdM00<0=B/Q03@Z800c:Al00P0b:1h00`0c:Al0=2XP03D[8@02038/8004034[
7`0`:Qh0;bTM02hX7080;BLK200U81X2028R6P<08b<K00<08R8J020P600O7aL0200O7QT00`0P8A/0
7b0J01dN600301`M5`807AhH0P0O7QT01@0N7AP07A`G01dL5`0M71L071/F00806aXE00<0724J01/P
6@0J7aP00`0I7QL201XO60806a/I0P0J6QP301TI5`0401PH5P0M7a`07AlL01dO708071hK0`0K7AX8
01`L6P0401XL6@0K7AX06adJ01/M6P<071hK00<07AlL01PJ5`0H6QL01P0H6QL801/K6@P06ATG0`0I
6aP201PJ5`<05aTF200H6QL@01TI6@P06QXH200H6QL801PJ6@P06QXH0`0K6aT201XJ60<06ATG200K
6aT901XL6@P071`J200N7AP801dN61007b0J0P0M7QP201hO6@807b0J0P0P8A/0200O81X0824K028S
7@0S91h092DO02<T7P0R8ad08B8L200P7aX01@0L7AL07AhH01dN600N7aT07b0J0080824K00<08B8L
01lP6P0O81X01P0O81X2020P7P807alM0P0N7Q`201dM6`<07AhH0P0N7aT301lP6PP07ahI00H092<N
02<R7@0S8Qd08R4L024P6`0P7aX501lN6@<07QdH0P0M71L901lP6P0701hO6@0M7QP07AhH01hO6@0P
8A/08R<M02<T7P0801dM6`T07alM200M7A/01@0L7AL07AhH01dN600N7aT07b0J0080824K00<08B8L
020Q6`0P8A/00P0O81X201hO6@807AhH0P0P8A/201lP6P807QlI0P0M7QP301lO7@807QhL0`0M7A/8
024P6`808R4L0`0Q81/;020O6PP08R4L00@07b0H020Q6@0P8AT0824I100Q8QX8024Q6@0302<R7@0R
8A`081lJ00<07ahI0P0P7aX801lP6P<07QlI0P0O81X3020Q6`P07alM0`0O81X3020Q6`808B8L200T
8ahA02HV7P809RHL00<09bLM02PX7P0Y:Al00P0Z:R00100[:b40;BTP02dY800]:B0202`X7`<0:bLN
0P0W9al202HV7P0402DU7@0T91`08b<K02<S6`P09BDM0`0X8ad302TT7P80:RDO0P0W9al0100V9Qh0
9BDM02@T700S8a/2028R6P808B8L0`0R8ad302<T7P<0824K0P0Q8Q`3028S7@P07b4N0`0Q8b0[oooo
o`00:_ooool309U_?@80V6hl0`2GKC/309U]@080VVi10`2KKd800`2HK3/0VFdl09U]?00209Y^?@80
Vfln00H0W70o09Q/>`2HK3/0VFdl09Y^?@2KKch209a`?`0909ea@02JL3h0Vg4o09ec@@2NM480WgE3
09id@P2MLd40W79000L0W71100<0WG5209ic@02NLd001P2NLd001@2LLCh0WG8o09eb?`2NLd00X7E2
0080XGI300L0XWM40:IcA02TM4@0Y7A40:=eA02QMD@0X7I40080WgM40`2QN4@40:9iA@80XgY600T0
WgE30:1fA02QMdD0XWQ60:AjB02UNdT0YWa:0:MmB`2UNdT00`2VO4X20:MmB`80Z7i<202VO4X80:Mn
AP0:0:V0C02XOd/0YWe90:AkA`2SNTH0Y7]70:ElB02VODT0XgU70:AjB080YG]900P0Y7Y80:=iA`2R
N4H0XGM50:1eB02OM4L0W75409U^@@<0V6e000H0VFi109Q]@`2GK480UFY009=X?P2BIcd209=X?P09
09AY?`2=IcX0SFLj08aV>@2:I3L0RF<f08QR=@27HC@0QV0c0080Q5le00@0Pehd089M<`21G380PE`b
0P20Fc4207iK<`0407eJ<P1lFC40NeP`07YG;`80NEH^00<0Me@^07IC;@1dDB/00P1cD2X00`1dDB/0
MU<]07MD;P08075@;@0>075A:01aDBX0L50Y06m?:@1^CBX0KD`[06a;;01[BR/0LdX/07E<;01hCbl0
NU8_07aD<01lEBh207]D:`0807aI<`1mFS@0OU/c07mL<P21Gc80PV0b08=Q<@24HS8508US=0<0RV@e
0P2@ICX2095V>`@0TVLl2@2DJC`01P2@Ic/0TFHk099W?02CIS`0UFHl09IU?080VFDm0`2>HcH208mT
=`<0T6Dh00H0T6Xk08mY>P2>J3T0SFLh08aV=`2;ICH208YT=@<0RF<f0`28HSD208MQ=0<0Rf0c0P2:
Gc8308UN<@80Q5h_0P25Gc003026H340Qf4b08MQ<P27HC80R64f08MP=@26H3<0QEl`08EO;P27HRh0
RF@`08YU<0P0RF<d0`2;IS8308aW<`80SFPd0`2<Ic<208eX=0<0SVTe202AIcD208aV=`<0SFLh0`2>
J3T208iY=@0608eX=02<Ic<0SFPd08mZ=P2AK3P0TVdi102=J3@408iY=@0;09A[<`2CJS80TfXd099X
=P2BJ3P0TFHk095V?02@IC/0SfXf08iY=@2<Ic<00P2:IC40102;IS80S6Lc08eX=02?JSH308iY=@04
08eX=02<Ic<0S6Lc08aW<`P0SfTj00H0T6/g08mZ=P2=J3@0S6Lc08]V<P2<Ic<208eX=00308iY=@2@
JS/0T6Xk0080SfTj00@0SVPi08eW>02=IcP0SFLh0P2<IST308]U>0<0RV@g0`28HS<508MQ<P0308UT
=`28HcH0QV4d0080QF0c00@0QV4d08QS=P29I3L0PV0b0P21Gc400`20GS00Oed_07iL;P0207eK;@06
07aM<@1kG300NEX^07MH;01fEb/0MeP/0P1hFBd307=C:P@0LU8Y01T0LE4X06eB9`1/D2P0JdlW06U=
9P1WBbH0IDPV06=69P1RABD0G4P]05M3:01B?R<0D3`Q054m8P1B?R<0Cc/P04di7P12=b40@CHR03`d
7`0h<Ah0=C0M03<`7`0c<240<S0Q00D0<RlP100a;Ql2030]7P0502l/7@0]:Q/0;2TJ02`Y6P0[:1T0
0`0X:1h402LW7@0402HV700T9Ad092DM02@U7@808b@L0`0R8a/8020S6P/07b8K0P0P8a`3024T7@04
028U700S9Qd08bHM02<V7@8092LN0P0U:1l302@V6`<09BLL0`0V:1d802HY7P80:2XO1P0W:Ah802DW
70<08RDJ0`0S9Q/202@W708082<J00H08B@K028U700S9Qd092LN02DX7`0V:B0302@V6`<09BLL4P0V
:1d302PZ7080:B/M0`0Z;1h@030b7@0>03Hb6@0g<aX0>cDM03lg8012=b40A3PR04<g8@15=R40A3PP
04Di8@16>R00Ac`P04Tn801;@20204a27`80CT@Q00<0D4<Q05528@1B@R400P1D@B40101E@240G4DS
05a58`1LAB<305e69080GTLU00/0Ed<N05U5801MAb80HDTU06=99P1VBBL0IDPV06I89P1TB2<0IDTT
06M;9P0206Q<9`0606M;9P1UBB@0I4PS069:901SBbD0I4`V0P1UCBL02`1SBbD0HTXT06598`1QD280
H4lS05m>8P1MC240G4XR05Y88P1IAb<0F4HR0080FTLV0P1IARD00`1GA2<0ET<R05E28@0205A18004
05I2:@1E@BP0DShU050l8`80Cc/R0P1@?2<00`14>Ql0AC/P04Hl8@0204Lm8P0304Dk8013>Ah0@SPM
00<0ACXN0P16>al304Ll80@0D3dL0`1A?Qd0101B?ah0DSdP058m801B?B0205<n8@<0E3lR00<0Bc`M
04dn7`1>?b000P1@@B80101?@240CSlP04dn7`1B?al405=080<0E44Q0`1C@b8205A48`<0EDDT00<0
E3lP05E08@1G@R<00`1IA2D01@1H@b@0Ed8S05Q59`1GA2H0ED8T0080E44S00H0ED8T05M49P1HABL0
E40W05<o9P1B?RD2054m9003058n9@1C?bH0E40W0080CCdS1P1>?R@204`n900304Xn9018?R<0ASlS
0080A3lR00@0@clR04Dl7`15?1l0AC`O0P14>ah304<j7@05044j7P12>al0A3XO04Hj8018>R000P1:
>R40101<>R80Ac/Q04Lk8@17>b4204Hj80<0ACTO2016>R0A04<i7PP0@CXN0`10>ah2044l7`<0@SdP
00D0@CXM048k7P14>ah0AS/O04Tk800204/k8@0E04dl8P1:?b40Bd0R04i18@1@@B00Dd<Q05I4801G
AB40FDDP05Q3901IA2D0G4DU05i6901PAR<0I4PS06E9901VB280ITXS06Q<9@1ZCRL0KE4Z00@0KU8[
00P0LU@`07=E<@1cEBl0M5L_07EH;P1fFBd0MeX^07MK;0<0Oed`1@20GS402@20Fbl0PE``089M<@23
GS80QF0d08IQ=@27HSH0R6<g08MV<`0208MU=@0308QV>028IST0RFHl0080RFHn00H0QfDe08QV=P28
ISH0RFLg08YX>02;JCT208aZ>PD0SVXj0`2?Jc/00`2>JSX0Sf/k095]?@02099^?P03095]?@2?Jc/0
SVXj0080TFdm0P2BKSh209=_?`80U71000H0SVho08e]?P2>K3h0T6/n08mZ?@2@JSd2099Y?@08091[
=P2@JcL0SfXf08mY>02>J3T0SVPk08iW?02=IS/808YU>`0608US?P28HSd0R68m08MQ?026H3/0QElj
0P24GST01`26HCD0QF0f08EP=P25H3H0Pedf089L=`21FcL00P20FCP02@1hEc@0MeHc07ED<@1cDRl0
LU4^07=B;`1dDc00ME@a07=B<`02079A<P03075@<@1`Cc00Kdh_0080KTd^0P1[BRT01P1ZBBP0JDPW
06Q79P1WARD0ITDT06E48`<0HT@X0P1Q@bL206129P0305m19@1G?B@0EcdT00H0EcdT00h0ESXR05Di
8@1B>1l0CcLM04`g701;=a`0C3PM04/j7P11>R00@cTP04@h8017=b00B3HP04Xe8080CC@P1@13<R03
04@c8@0303`a7`0k<1h0>BhL00<0=b`J00H0>BhL03X_7@0h;1`0>2`L03L[6`0f:QX203DY6@80=2PH
0`0a9a/2030V6P<0;bDI00@0;bDK02hT6P0^91X0;R@J0P0]8aT202`R600302PS7`0W8Qh09R4M0080
9B0L00<09R4M02LR7P0X8al00P0T91`0100S8a/08R8J024Q6@0Q8AT2020P60P07AdK00<06Q`I01/M
6P0L7Q/00P0M7a`00`0K7AX06A/H01PJ5`0801XL6`0301TO7@0H7Q`05Q`J00<051XH00<05Q`J01LM
6`0I6aP0100I6aP401PJ5`0301/K6@0J6QP061PF008061PF00<06ATG01/K6@0L71X00P0H71d201LK
70<05QXK00@05ATJ01HL700F71`05Q`L0`0E6a/201@J6P805aTH1P0H6QT201@J600301DK6@0F71X0
5Q`J00<05adK200E6aT801PJ5`P06A/H0`0G71P201HK5`<05AXF200F6aL801TI6`P06QXL200K6aT8
01PJ5`P061XI200J6QP301/K6@0301XJ600I6AL06ATG008061PF200K6aT901XL6@P071`J200M71L8
01dN60P07QlI200O81X201dN60807QlI0P0O81X2020Q6`0301lP6P0P8A/08R<M008092DO00<08b@N
028S7@0Q8Q`0200P7aX201`M5`0401dN600N7aT07b0J020Q6`808B8L200O81X2020P7P807alM0P0N
7Q`201dM6`8071dG0P0M7QP301hO6@0301lP6P0N7AP07QdH00H07QdH00H09B@O02@S7P0S8Qd08R4L
024P6`0P7aX501lN6@<07QdH0P0M71L901lP6P0701hO6@0M7QP071dG01`M5`0M7QP07b0J020Q6`08
01dM6`T0820N200M7A/201`M5`0401dN600N7aT07b0J020Q6`808B8L0P0P8A/201lP6P807QlI0P0M
7QP2020Q6`807b0J0P0N7aT201dN6080820N0P0O7ad0100N7Q`07AdK01dM6`0M7A/8024P6`808R4L
0`0Q81/3020O6PP08B0K200R8A`3020S6P807b8I0`0N8AP8028R6P0302<R7@0R8A`081lJ00<07QdH
00<07ahI020O6P0O81X02@0O81X2020Q6`808B8L0P0R8ad801lO7@<07b0J0`0P8A/2024R70P092<N
4@0W9al202LW7@0402PX7P0Y:Al0:RXP02XZ8080:b/Q100]:B0202`X7`80:bLN00H0:2PP02LW7`0V
9Qh09BDM02@T700S8a/2028R6PP09BDM0`0X8ad302TT7P80:RDO0P0W9al0100V9Qh09BDM02@T700S
8a/2028R6P<08B8L00<08R<M02<T7P0S91h00P0T9Al00`0O81X0824K020Q6`02024R70808R<M00<0
8b@N020R7`0P8Ql01P0P8Ql3024S82_ooooo000Zooooo`80VFlm0`2HKS`309M]>`<0VFe00P2JKT43
09]_@P80V6`k00@0VFdl09Y^?@2JKSd0Vfln0P2LL3l209Q/>`0409U]?02JKSd0Vfln09]_?P80W70o
00<0VFlm09]a?`2MLd400P2OMD<0102NM480WG=109ab@02NLT<409mcA0<0X7A5202NLd0209aa?P04
09eb?`2NLd00X7E20:5f@`80XWM400H0YgA50:EeA@2UMDD0Y7I50:9fA@2QMdD20:1hA@0409mf@P2P
Md<0X7M30:5hA080XWU500<0XgY60:AkA`2TNdL00P2OMD<0102QMdD0XWQ60:AjB02UNdT20:MmB`@0
YWa:0P2WOD/20:QnC0P0YWa:202YP4P01P2YP4`0Z7m;0:ImB@2TNdL0XgY60:AkA`80YGa800`0XGM5
0:9hAP2TNTP0YWa:0:EkB@2SNDL0X7I409id@P2PMDP0WW=609]`@`2IKT4209M/?`0609Q]@02IKT40
V6e309I[@@2DJCl0TfPn0P2BIcd0202CJ3h0U6To08eW>P2=IcX0S6Hi08YT=`29HcH0Qf4d0P26H3<2
08=N=004089M<`21G380P5/a07mJ<080OUT_00H0OU/c07eJ<P1mFS80O5Ta07]H<01jEbl207UF;P08
07IC;@1eDR`0M54[07=@:P1dDB/0MU<]07QE;`1iES08075@;@06075A:01aDBX0L50Y06m?:@1]C2T0
K4/Z0P1[BR/01P1cBR`0MD`/07Q?;`1kDc00O5@`07aE;P80Ne@[00P0O5Tc07eJ=01nFc<0Oe`b085O
<P23HC<0Q68b08ES<`@0RV@e1029Hc@2091U>P80TFHk0`2BIc`00`2CJ3d0U6Tl09AY?00709AY?080
U6Tn00<0U6Lm09IW?@2GISd00P2IICd0102JICd0SF8e08eR=@2>HcH208mT=`03091U>02AIST0TFHi
0080T6Xk00<0SfTj08iX>@2=IcP00P2;ICH0102:I3D0RF<f08US=P29HcH308QR=@80Qf4d0`2;H3<2
08YO<P<0REha0P24GRl208EO<00<08IP<@27HC80Qf4b08QR<`28HCH0Qf0e08EO<P25Gc00QEl^08MR
;P29I300RVD`2029Hc@308]V<@80S6Lb0`2=J3<208aW<`<0SFPd0`2>JCD8095W=@80S6Hg0`2=IcP3
08iX>@80SfXf0`2=J3@00`2>JCD0T6/g095/>00208]V<P0308aW<`2=J3@0SVTe0080SfXf00`0T6/g
09E]<P2EK3@0U6/e09A[=`2CJCT0TVLl099W?@2AICh0SfXf08iY=@2<Ic<208YU<@0308]V<P2<Ic<0
SFPd0080T6/g00H0SfXf08iY=@2=J3@0S6Lc08]V<P2:IC4808mY>P03095/>02?JSH0SFPd0080RfHb
00@0S6Lc08eX=02=J3@0SVTe0`2@JS/00`2?JCX0SVPi08eW>00208eW>080S6Hi0`2;ICP308YT=`P0
Qf4b00<0RF@g08QS=P26HC@00P25H3<00`26HC@0R6<f08UT=`02085O<@80P5h`00L0Oed_07iL;P1m
Fbd0OE/]07]L<01jFbl0N5T]0080MUL[00<0MeP/07QI;@1iFRh01P1bDRT2075A:00H06eB9`1/D2P0
JThV06Q<9@1VBRD0I4LU06=69P1RABD0FTT]05A39`1??R80CC`P04hm8@1??R80C3/O04Xi7@12=b<0
?SHQ03`d8@0h<Al0=BlO03<`7`0b<240<c4R100b;b05034^7`80<2dN00<0;R/L02dZ6`0/:AX00P0[
:1T00`0X:1h09bLM02LW7@0502LW7@808b@L0`0R8a/3024R6PP082<J2`0O8Q/2020S70<08B@M100S
9Qd202@W7P809BPO0`0T9Q/302DW70<09RPM200V:Ah302PZ7`D09bTN200U9a`01@0P8aP08B@I024T
6@0R9AX08bHK008092LL00T09BPM01lR6@0P8aX08B@K028U700S9Qd092LN02DX7`0V:B000`0T9Q/3
02DW71809RPM0P0Y:ad302X/7P<0:bdO400a<ad04@0h=1/0>S@L03dg7`11>B80ACXT04Hj9018>B@0
AcPS04Di7`16>R00Ac`P04Tn801;@200C48O04e3801>A200DTPT0080DdHS00<0DdDR05A48P1E@R40
0P1E@B00101NAbD0GdPV05m89P1OB2H206199`80HDXX00/0G4TQ061:8`1SCBH0IdlY06Y@:`1]DB`0
KU0/06e?:`1VBR<0Id/T06U=9P0206Y>9`0C06U=9P1WBb@0ITXS06I=9@1WCRH0J4lW06U@:01XCbL0
IdhV06E<901TBb<0I5@S06=B901RDBD0H4lS05i=8P1MBb<0G4XT05]98`0305a9:00405]89`1JAbH0
F4DT05M48`80ET<R00P0F4@[05I2:@1D@2L0DShU054m901@?2<0DCdT058n9@80AS`Q0`17?B800`15
>b00@cTN044g700204Dj7P<0AS/O0`17?20204ll6`04050m701A?Qd0DSlN058o7P80Dd0O0P1B?B02
05<n8@<0E3lR00T0ED0S04/l7@1=?Ql0Cd0Q05118P1A@R<0Cd0Q04ho801<?Ah01@1D@B4305E28P80
Dd<R0`1DA2<305E5900605<n7`1D?b00ET4R05Q3901IA2D0F4<T0P1G@R<00`1HABL0Ed@V05E29002
05A18`0605E2901GA2H0F4DW05A09`1C?bH0DCdT0P1@?2<0101A?B@0DclV05A09`1>?B<404ln90<0
D3lU00P0CT0V04do9@1;?bD0BT0U04M09016@B@0AD0S04A08`80ASdP00@0AC`O04@k7P14>ah0@cXM
0P12>A`02011>Qh0@S/O04@j7`16>R00BC/Q04Xj8@1;>b80C3XR0P19?B<01P18?280Ac/Q04Hj8015
>Al0A3PN04<g7@P0ASXP4@13>Ah8044j7P<0?c/N0P10?1l3044m8080@3TL01X0@cXM04Hk7`19>b00
Bc/Q04`l8P1>?B<0Bd0R04a18`1>@B40Cd8P0553801C@al0ET@P05I47P1G@R<0F4<T05]4901MA2D0
H4HU06=6901TB2<0ITPT06I:8`1WBb@0JThW06a@:@80KU8[0P1]DBX2075C;`04079D;P1cERh0M5L]
07AG;@80MEP/1P1oGC02081N<@0807iI;@1oFRh0P5/_085L<023GS80Q5lc08EP=026HCD208ES<`03
08ES=@26I3L0QV<i0080Qf@l00L0Qf@n08ES<`25Hc<0QV@d08MU=@28ISH0RFLg0080RVPh00@0RFDe
08QT=028I3@0R6@d1@27Hc<01`28I3@0RVHf08]W=`2;IcL0RVHf08QT=027Hc<00`2?Jc/3091/?080
TFdm00T0Rf/l08YZ>`2;JC/0S6Lj08]V>@2;ICP0SF@h08aS=`2;IS400P2;IS800`2:I3<0RV@e08US
=P0208UR=`P0PE/d0P20FSD00`1oFC@0OUPc07eG<P0207aF<@0307]E<01hDbT0N5<Y0080Me4Z00<0
MDlX07A>:@1cCBT00P1bBbX0101]CS40Jd`_06U:;@1WB2/206I7:P0306Q9;01YBRd0J4P_0080IdL^
00<0ITH]06E5;01TA2/00P1S@bX0201P@B80Gd0Q05ho801M?Ql0G3dN05/l7@1J>a`0FCXK0`1I>RH5
05Pi9@P0CCDM00P0Bc4J04X`6@17;aL0ABdE048/5011;A@0@2lE044`5P80=c4K00H0>RlK03/^6`0n
;A/0@B`K048[6`14:Q/403TY6@@0>RXJ00T0<BXH030Y5`0^9aD0;2DC02/T4P0/9A<0;RLE02lX5P0^
9QT00P0]9AP00`0/91L0:b<F02XR5@0202TQ500402PR5P0W8AD09b4E02LQ5@809R0D0P0U7a<302DN
5P8091dE0`0S71@00`0O7QX07QdI01`K5`0201/J5P0301`K5`0N7AT07ahJ00807AhH00<071dG01/L
5P0J6aD00P0I6Q@00`0H6A<06Q`K01XL6`0601XL6`0301@J600F71X05adK008061hL00<05Q`J01@J
600B61H0200F71`0200F7ah05AhM01<L6`0A6QT041TH014J6@0C71/051dL1@0E6AP201HJ6@805a/J
00T06QHG01TE5P0G4a@05a<D01PD5@0J5QL071PI01hJ6`0H7B000`0G71l201HK7P805AXM0`0@6Q/2
00lI6P<03QPI0`0B5QL401<G600401@H6@0A5aL04ALG018H60804aTI00<051XJ01DK6`0E6a/0200F
71`801HH5`P06Q`K0`0G6aX201HJ6@<05ATH200F6QT801TI6`P06QXL200K6aT801TK60P06A/J200J
6QP301/K6@0301XJ600I6AL061PF008061PF200K6aT901XL6@P071`J200M71L@01dN60P07b0J0P0M
7QP201hO6@807b0J0P0P8A/00`0O81X0824K028S7@0302@U7`0302<T7P0R8ad081lJ00L081lJ00P0
6a`F01`M5`0M7QP07QlI01lP6P0P8A/08B8L028S7@P07b0J0P0P81h201lO7@807QhL0P0M7A/201`M
5`807AhH100N7aT801hM60809B@O00@092<N02<R7@0Q81/081lJ1@0O7QT301hM60807A`G200O81X0
0`0P8A/07QlI01dN600301/L5P807AhH200M7A/9020P7PP07AdK00P06a`F01`M5`0M7QP07QlI01lP
6P0P8A/08B8L028S7@80824K0P0O81X201hO6@807AhH0P0P8A/201lP6P807QlI0P0M7QP3020P7P03
01lO7@0N7Q`07AdK00807AdK200Q81/2028Q70<08B0K0`0P7aX8024P6`P08R4L0P0Q91/0100P8aX0
7b8I01hQ600N8AP201dP5`P08b<K00P08b8M024P6`0O7QT07QdH01dL5`0N7AP07ahI024P6`P07b0J
00@0824K024R700Q8Q`08B8L0P0R8ad202<T7PP07alM0`0O81X3020Q6`808B8L200T8ahA02LW7`80
9bLM00<0:2PN02TY7`0Z:R000P0[:b400`0/;280;RXQ02dY800202dY8080;2PO0P0[9ah0200X:200
9bLO02HV7P0U9Ad092@L02<S6`0R8QX08B4I200U9Ad302XS7@<0:b@N0P0/9Al202LW7`0402HV7P0U
9Ad092@L02<S6`808R8J00@0824K024R700Q8Q`08R<M0P0S91h202@U7`807b0J00@0824K024R700Q
8Q`08R<M0P0S91h8020R7`<08B<P:oooool002[ooooo0P2FK3X0102GKC/0V6hl09Y`?P2KLCl209ab
@00409M[>P2HK3/0VVhm09a`?`80WG5000<0W70o09]_?P2IKcd01`2IKcd209Q_>`0309U`?02JLCd0
Vg8n0080W7<o00<0WGA009]^A02KKT@01P2KKT@809ib@@P0W70o202OM4480:1d@`030:=gB02TN4T0
YWY;00@0Yg]<0P2VNT/00`2PMd<0XGQ40:=jAP020:AkA`030:=jAP2QN4@0X7M30080YGY70P2VNdP3
0:MlB@050:QmBP2ZOdX0ZGi90:UnB@2XODP00P2WO4L20:IkAPP0Y7]70`2UNTL20:AiAP<0XgQ50180
X7910:5c@P2QMD@0XGM50:1hA@2MN4@0VgI209Ue@@2JKd80Vg1309aaA02MLTD0W75409Y_@P2GK3l0
UV/n09AY?02EJSd209I[?P0409AY?02BIcX0Sf@g08eR=@80S6Lm00@0RfHl08UT>P28HcT0QV4g0P25
H3H02024GcD0Pehd089M<`21G380OeX`07eH;P1lEbd0NeH/101hEBd207UF;P80NUL_201iDBd00`1/
BB<0Kd`V07=@:P0207MD;P0307=@:P1_C2H0K4TS00D0LDhX0`1bCbT01P1dCbD0ME0V07IA9`1gDRP0
N5<Y07YE:`80NeH/01P0O5X/07eK;@20Fbh0PU`_08IM<@28GC80REhc08YM<`28GR`0REl]08YP;P2<
HS00SF<a08mU<`2@IS@0TFLe091Z>`2<ISL0RF<d08aV=`2AJc`0U6ho095[?02=IcP9091Z>`80TF/l
0`2@JS/308mY>P0808eW>P2>J3/0SfTl091Z?@2?JC`0SVPk08aV>@2;ICP308mT=`0308iS=P2=HSD0
SF8e0080S64d00H0SV<f08eR=@2=HSD0S64d08]P<`2:Gc8208UN<@P0R5db00@0Ped`08AN<@24GS40
Q5ha0P25Gc8508IP<`80Qf4d0`28HSD308]P<`0308aQ=02=HSD0SV<f00<0SV<f00L0S64d08]P<`2:
Gc80Rf0c08aQ=02>HcH0T6Dh00P0S6Hg202@ICX01P2GKC/0UV`j09E[>@2DJSP0TVPf091V=080SfDc
0`2BJ3H2095W=@<0T6Hd0P2AK3P00`2?JSH0SVTe08eX=00208eX=00408iY=@2BKCT0T6/g08iY=@80
S6Lc00<0SFPd08iY=@2@JcL0202@JS/808eW>00308MV<@28Ic80RVTd00<0S6/f00@0RfXe08YY=02<
J3P0RfLg0P29ICD01@2:ISH0SFTi091/?02@K3`0TVhn0080SFTi00@0S6Ph08]W=`2;IcL0RVHf0P29
ICD01P2:ICP0RF@g08UT=`28HcH0Qf8e08IQ=080QF0c00<0Pf4c08AR=025HcD00P26I3H00`24HS@0
PV0b085O<@02089T<080PF<_1020HRh00`21FS40PU/b08AM=00208AM=00S089K<P20FC00OUL^07UD
:P1jEB/0O5H_07eG<P1mEc<0O5Dd07YC<P1hDC80LTlW07=@:01cDRT0LU8Y071C:@1^DBL0Je0U06Y?
901YCBH0J4`U06E;9P1SBbL0HDXX05i::@1MBBP0G4TY05=49`1B@bH0CT0U04Tm8`15>b80@CHP03de
7P0l=1l00P0g=2D203Hc90@0=C8S00H0>3<M03Lb7P0f<Ad0=2lL038/700a:ad202lY7@0402dZ8@0/
:B00;2TP02`Y8080:bPO0P0Z9ah202HY800302DX7`0T9ah08bHM00808RDL00@08B@K028U7P0R9Ah0
8B@M0P0P8a`00`0O8Q/07R4J01hQ6P0801lR6`08024S8P0P8Ql07R0M01dO6P0M81T07R4H01lR5`0P
8aP2024R6P808R<K100S91`802DX7@0702P[800W:Ql09BPM02<V6`0R9AX08bHK02DX7@0202HY7P03
02<V7@0T9ah09RTP00809bXQ00<09RTP02@W7P0S9Qd0200T9ah802@U7@808B<H0P0R91T402<U6P06
028T6@0S9AX08bDJ02@V6`0U9a`09RPM0P0W:Ah202DU7@0402HV7P0W9al0:2PP02PX8080:BTQ200V
:1/202HX6P809bTK0`0X:Q`02P0Y:ad0:b`L02`]7@0_;Q`0<RlN03Ha7P0h<al0>S@N03/e7`0d<Qd2
03Dc7P0303Hd7`0g=B00>3HQ0080>CLR0P0i=A`00`0j=Qd0>cLN03`h7`0203di800E03hj8@0o>B40
?cTQ044j8015>b00Ac`P04/m801<?R40CChO04Dj7015>QX0AcXJ04Pk6@1<?Q/0D40L05I47P1IAb40
FT@O05a68@1NB2<0HD/V0080HT`W00@0HD/V061:9@1RBb40HT/Q0P1SC2801@1TCB<0IDhT06E>901V
CbD0KE<R00@0K58Q0`1[DB0206eB9`80KU<X0`1_E2T0101`EBX0J58P06YD8P1/ER@306iH9P0806aF
901[EB<0JE@W06UD9`1WDRD0IU4T06A?8P1RCB02065<7`@0Gd`R1@1NBb40201TC2X0HDTW05e69P1H
@b@0E44S05919@1B@BL0DD4W101??bD404hn90<0DD0R0P1@?b4304ln80P0D3lQ0P1C?1`01`1D?Ad0
EChN05Ho7`1G@200F44Q05U28P1FAR@00P1EAB<00`1DA280Dd<Q05=38@02059280<0Dd8T0P1B@B<3
05508P0;05Hn701E?Q`0ESlM05A07@1D@Qh0Dd<O05947`1CAB00Dd4M05A27P1FA2000`1HAR800`1G
AB40ET@P05e58`0205a58`0305U58P1GAB40E4@P0080DdDP0P1@@1`0101A@Ad0DT8N05A4801EAB42
05I68P0304hm8@1??R80CchR0080CchR0`1@?b<205528@80D44P0`1?@1l0101>?ah0BD<Q04M17`15
?ad204<m6`0304@n7017@Al0BD<Q00P0AS/O00<0@cXM04@k7P15?1l00P16?B003P14>ah0@STL044h
6`13?b80@chQ044l7`11>Qh0@cTN04Di7`19>b40BS`R04Ll8016>al0A3TM0P13>1`00`14>Ad0AS/O
04Ll800304<i7P80@SPM0`11=a`01@10=Q/0AC/P04@j7`14>Ql0@cTN0080@SPM0P11=a`304<i7P03
048h7@11=a`0@3HK0080@3HK200o>ah02016>AT0BC`L04`o7`1?@R80D4<S04m28P1>@B40CD0P0P1A
@B001`1E@R80F4<T05a59P1NAbP0H4LY0697:P1QBRP00`1PBBL01@1QBRP0Hd`Z06I?;@1WD2h0JD/W
00@0JT`X0`1[CBT207AC:0<0ME@Y0`1fEBX207=F:P80M5L[00D0MEP/07II;@1fFBd0MeX^07aJ;@03
07]I;080NUP[0P1iEbX01P1jEbl0NeP`07aI<@1mFS80OU/c07mL=080P5de00<0PF8c07mP<@1mGRl0
0P1kG2d00`1lGBh0OEh_07iO<002089S=`03085R=P20HCD0Of0d0080OUlc00<0OEhb08AO=@24GcD0
1P24GcD2081J<`0707mI<P1nF340OEL`07aF;`1kEBh0NU@]07MI<`0307IH<P80MELa0P1dES0306iB
;@80KE4/0`1/D2/206m;<`0306i:<P1]BC40K4P`0080JTH^00<0JDD]06I2:P1V@RX01`1V@RX0201N
@bD0GD8T05a18`1K@280FSlQ05Tn801H?Al0Ec`N0P1F?2D205Dk90<0E3XS00<0DcTR04Pg7@18=ad0
0P17=Q`304He6`0904Dd6P0k=BL0>S@V03Tc9@0h<R@0=c4S03H`8P0e;b40=2hP0080<BlS00@0<2hR
02l]8@0_;B40;R`P0P0]:al802dZ8`P0920M200S7a`801hP6`P06adH0P0M7ah00`0L7Qd06adL01XL
6`0201PJ6@0301LI600J71/06Q`K00H06Q`K400H6A/P01HG6A405AHH400G6AP@01HH5aP05aTH200I
6aX201LI608061XI0P0I6aX201XL6`P05QPG200H61P801XJ6PP06a/I200J6QX801TK6PP071`J200K
6aT301XJ60@06a/I2P0L71X301/K6@8071`J0`0M7A/201dL6P<07QdK0`0O7Q`801lP6P0401hM600O
7QT07ahI01lN6@8081lJ0P0Q81/2028Q70<08B0K0`0P7aX201lP6P80824K100Q8Q`802@O6`P081lJ
200Q81/8020Q6`P07b0J00/06a`F01`M5`0M7QP07QlI01lP6P0P8A/08B8L028S7@0O7QT081lJ024P
6`0202<R7@03024P6`0P7aX07ahI00P07AhH0P0L7AL201dN60@07QlI200P7aX801`L6P/07AdK0P0N
7Q`201lO7@80820N0P0M7QP201hO6@807b0J2P0P8A/302<R7@808R4L0`0Q81/2020Q6`807b0J0P0N
7aT:01dN60@07b0J0P0P8A/2024R70<081lJ0`0Q81/2028Q70P07b0J200R8A`201hO6@807b0J00@0
824K024R700Q8Q`08R<M200O7ad8020P7PP0824K200O81X3020O6`808B0L0`0R8Ad202<S6`0302@T
700U9Ad09RHN0080:2PP00<0:BTQ02PS7`0X8al00P0X8al402LR7P0602DW6@0X:A/0:BXL02`Z7@0]
:Ad0;RPL0P0^9Q/00`0/91T0;2LS02`W8`0202`W8`80:bHR0P0Z9B4202lY7@80;RPL00@0;BLK02`V
6P0/9QX0:bDI200S8a/0100V8A/09b8L02LR700W8Q`202PS7@80:B@N200U9Qh302/V8080:RDO0`0Y
91h402<T7P808R<M0P0Q8Q`8028R6PP08R<M0`0T9Ad[ooooo`00:_ooool01@2FK3X0Ufdk09M]>`2H
KS`0VW0n0080Vg4o00T0W79009U]?02JKSd0W70o09ea@02NLT40WG5009a`?`2KKch0202IKcd209U`
?0<0VW4m0`2KLSh809]_@PP0WW91202MLD0809md@@P0XGE41P2TN4T01P2UNDX0YWY;0:MkC02PMd<0
XGQ40:=jAP80Y7]700<0XgY60:5hA02PMd<00P2UNTL20:IkB0@0Yga90P2YOTT20:QmB080Yga70P2V
NdH80:AkA`80YGY70`2TNDH30:=hA@0:0:1b@@2QLd80XGE40:5gA@2PN4D0WGQ409]f@P2IMD40VVm2
09]`@`80W75400D0Vg1309U^@@2GK3l0UFXm09AY?00309EZ?@0;09AY?02AIST0SV<f08eR=@2<Icd0
RfHl08YU>`29I3X0Qf8h08IQ=`25H3H00P24GcD01`23GS@0PUdc081K<@1oFS00OEP^07aG;@1kER`0
0P1iERh607QE;@P0Mdl[00<0KT/U071=9`1cD2X00P1dDB/00`1cD2X0L4dW06i;9@03075>:0D0LTlY
00P0N5<Y07UD:P1jEB/0NeH/07eH;P1nFBl0OeX`081K<@80OU`^00`0PE`_08=M<027GS80REhc08YO
=02<GcD0S68`08eS<@2>I380SfDc095W=@2BJ3H209AZ>008091Z>`2=IcP0RV@e08aV=`2AJc`0Tfdn
095[?02=IcP9091Z>`80TF/l0`2@JS/308mY>P0308aV>@2=IcX0SVPk0080SfTl00<0SFLj08]U>02:
I3L01@2>HcH308eR=@0608iS=P2=HSD0SF8e08aQ=02;H3<0RUlb0P29GS4808QM<P@0Q5ha0P25Gc84
08IP<`<0Qf4d0`28HSD208]P<`80S64d0P2=HSD208iS=P0308eR=@2<HC@0Rf0c0080Rf0c00<0SF8e
08mT=`2@ICP0202<ISL8091U>P80UF/i00<0U6Xh09=Y=`2BJ3H00P2AIcD0102@IS@0TfTg09=Y=`2C
JCL2099X=P<0TFLe00<0Tfhj095/>02>JCD00P2<Ic<02`2=J3@0SVTe08mZ=P2BKCT0T6/g08iY=@2=
J3@0S6Lc08eX=02>JCD0SfXf00P0SfTj202=IcP02@27IS40R6Lb08YY=02<JcH0SF`g08a[=P2;JSD0
RVTd08]W=`0308YV=P0508aX>02=JCT0Sf/k08m[>`2@K3`00P2=JCT0102<J3P0RfLg08]W=`2:ISH2
08UU=@@0R6<f1027HSD00`23HC<0Q68d08ES=@0208IT=P0308AR=022H380PEla0080PV@`0P21Hbl3
081R;P0Z07mQ;@20FC00PEXa08=L<`24GC@0Pe`c089K<P20FC00OeP_07QE:`1iER`0NUL_07]H<P1j
ES80N5@b07IB<01eDC40LTlY07=@:P1bD2X0LU8[06mB:P1/D2P0JThV06M>9@1XC2D0ID/V06A:9@1R
BRH0H4TW05e9:01KB2P0FTLW05529@1@@2H0CClT04Pl8P14>R40?cLP03`d7`0j=1h0=S<T0`0e<R<2
03@a8P80<c0Q0P0d<Qd01P0c<1d0<RlN030]7P0_;1d0;RXN02dY7@<0;2TP0P0[:1l302XW7P0602HY
800U:1l09BPO02@W7P0S9Qd08RDL0P0Q91/3024T7@03020S700O8Q/07b8K00807R4J200O8Q/0200Q
8b80828O01hP7@0M7aX07B0I01hQ600O8QL082<H0P0Q8QX2028S6`<08b@L00<092DM02DX7@0U:1d0
1P0U:1d00`0X:b009bXO02DX7@0302<V6`<09BPM00<08bHM02@W7P0U:1l00P0V:B000`0U:1l092LN
02<V7@0802@W7PP092DM0P0Q8aP2028T6@<08bDJ00<092HK02<U6P0S9AX00P0T9Q/0100U9a`09RPM
02LY7P0W:Ah202DU6`0302HV700W9ad0:2PN0080:BTO00<0:RXP02PX700X:1`01P0X:1`202PY6@80
:BXJ0`0Z:a/02P0[;1`0;BhN02h_7`0a<1h0<c0M03Lb7P0i<ad0>S@N03/c700e<a`203Hd7@0303Le
7P0h=Ql0>CLP0080>SPQ0P0k=Ad00`0l=Qh0?CLO03hh800203li8@80@3XR00D0@S/Q04<l8P16?240
BChR04`n8@0204ho8080Bd0P00X0CD0N04m07`1C@b40F4HR05a:901OBbH0G4HO05i88@1PBR<0HT`U
0P1TCRL0101SCBH0HT`U06A=8`1TCB<206E>900406I?9@1WD2H0Ie0V06M@9PD0KU@S0`1]Db8306mD
9`80L5DX0`1aERT00`1ZE280JeDS06eG9@0206mI9`0306iH9P1]EbD0K5HT0080K5LX00H0JeHW06UD
9@1XDb@0IU4R06E@8@1TCb0406EB:0<0I54W0P1SD2H01P1TC2P0Hd/Y05i79@1KA2@0Ed8S05E29080
E4<W00<0DD4W05109P1@@2H00P1@@2H304lo9@<0Dd0P0P1B?al3054n7PP0DSlO0P1D?Ad0101E?Qh0
ESlO05M0801H@B4205U28P<0Ed@S00<0ET<R05E28@1E@R400P1D@B0205I38`80ED8R0`1D@B401`1C
@200EclM05Ho7@1F?ad0ED4N05E37`1C@al00P1CAB000`1C@Ad0E48N05I4800305Q68P0805M58@1F
A200GDDS05a58`1KA280FDDR05M58@1EAB4205=58080DD4M00@0DT8N05=37`1DA200E4@P0P1EAB42
05919@H0Dd8V0`1A@R42051180<0Cd0O00<0BD<Q04Q28017@Al01015?ad00`16@1h0AS/O04Hk7`06
04Hk7`0304@k7P15?1l0ASdP0080ASdP00h0A3/N048i7011>1/0@clR04<n8@11?1l0@CXN04<i7P15
>Al0BC/Q04Xl8P17?200AS/O04@i7@80@cPL00<0A3TM04Hk7`17?2000`13>Ah2048h7@@0@CLL0`14
>Ql00`13>Ah0@SPM048h7@02044g70<0@cTN00<0@SPM044g7011=a`00P10=Q/8040k7P0404Li7018
>Qd0BS`O04/m80<0CClR00X0C3hQ04ho7P1?@1l0DD4P05E28P1G@R<0Fd@U05a59P1NABL0GTLU0`1M
AR@0101NAbD0H4TW069;:@1TCB/206E89P80ITTW00@0IdXX06Q;:@1XBbT0JD`Z0P1_CbP3071@:@<0
LE4Z00<0KE4Y06iB:P1^DRX00P1_Db/2071D;003075E;@1fERd0MED/0080MED/0P1dE2/207=C:P<0
MED^0P1fERl307MG<00807AG:`1cERX0LE@X071C9`1_DRH0L5<W075D:01bEBT407AG;`<0LeH^00<0
LUD]07ID;P1fE2h01P1fE2h207ID;`0607EC;P1dDRd0Le4/079@:`1aCbX0L4hY0`1[DB`306Y@:`80
JDlZ0`1SBbT3069::080HDTW00H0Gd<]05i2;01M@B/0G40Z05/o:@1J?RP205Tm9`T0ESXT00H0CSXQ
04di801<>1l0BcLN04Xf7@19=A`204Pd6`@0AC8Q0P14<B0204<`7`<0>bhK0P0j;AX303T/6@80<2`P
00L0;b/O02hZ7P0]:Ad0;2PL02/W6`0Z9QX0:RLN0080:BHM0P0X9A`202LT6`0302HS6P0V8ah09R<N
00H09R<N200R7Q/8024M6PP071hI200J71L01P0L7Qd06adL01XL6`0I6aX061XI01LI60805QPG200I
6aX@01LH6R005QLI4@0E5QP@01LI61005QPG600G6AP801TK6P805aTH0P0H6QT201TK6P806Q`K200F
61L801PH60P06QXJ200K6aT801XJ6PP06A/J200L71X801/K6@<06QXH100K6aT:01`L6P<06a/I0P0L
71X301dM6`807A`J0`0N7A/301lN70P07b0J100O7QT2020O6P808B0K0P0R8A`3024P6`<081lJ0P0N
7aT301lP6P<0824K200T7a/8020O6PP08B0K200P8A/801lP6P8071dG00@07AhH01hO6@0O81X0824K
0P0Q8Q`00`0O7QT081lJ024P6`0202<R7@03024P6`0P7aX07ahI00P07AhH0P0L7AL201dN60<07QlI
00<07b0J020O6P0P7aX01P0P7aX801`L6P/07AdK0P0N7Q`201lO7@80820N0P0M7QP201hO6@807b0J
2P0P8A/202<R7@<08R4L0`0Q81/2020Q6`807b0J0P0N7aT:01dN600401hO6@0O81X07b0J01lP6P80
824K0P0Q8Q`7024P6`03020O6P0O81X07b0J00H07b0J200R8A`201hO6@807b0J00@0824K024R700Q
8Q`08B8L400O7ad8020Q6`P07b0J0`0P7a/2024P70<08R4M00D08b<K02@T700T91`09BDM02LW7`02
02PX800302TY8@0[9R80:bHR00H0:bHR00H09RPJ02PY6`0Y:Q`0;2XM02dY7@0^:1`202hV6`0302dU
6P0]:2@0;2LS0080;2LS0P0[9R8202XU8@80;bTM0P0^:1`202dW6`80;2HJ200T91`402LR7080:2<M
0P0Y91h802HV7P<0:bHP0P0Z9Al302TT7P0402@U7`0S91h08b@N02<T7P808R<M0P0Q8Q`8028R6PP0
8b@N0`0T9Ad[ooooo`00:_ooool209M]>`0409Q^?02IKcd0VFlm09Y`?P80Vg4o00<0W70o09ea@02O
Ld800P2OLd800`2MLD00W70o09Y^?@0809Y`?P<0Vg8n0`2JLCd209U`?0P0W713202NLT4809mc@PP0
X7E2202SMdH00`2UNDP0XgM60:5eA0030:1d@`060:=gAP2VNTT0Yg]:0:5hA02RNDD0XgY60P2TNdL0
0`2SNTH0XWU50:5hA0030:EjA`80YW]80`2WO4T30:QmB0<0Yga70P2VNdH80:AkA`040:EjA`2TNDH0
Y7U60:AiAP80XgQ50P2RMd@02@2PLT40XG=20:1d@`2PMT@0WgM409ag@`2KMT80VGE109Y_@P0309]`
@`0409Y_@P2HKD00Uf`o09EZ?@@0U6Tl00X0TVLj091U>02>HcH0SF8e08]V?02:IC/0RF@j08QS>@27
HSP0QF0f0P24GcD01P23GS@0PUdc085L<P20Fc40OUT_07eH;P80O5L]00D0NUL_07UF;P1iERh0N5D]
07MD;00207IC:`0307EB:P1dCRT0M4hY00H0M4hY2P1aCRP2079?:@80Le0Z0P1dDB/207eH;P0407iI
;`20Fc40PE`b08=N=080Q5le0P20GS001P23GS40QV0c08UP=02;H3D0S64f08iQ=`80T6Hd00h0TFLe
09=Y=`2DJSP0UF/i09I/>P2GKC/0T6Xk08iX>@2<ISL0SVPi095[?02BK3d0T6Xk08iX>@T0T6Xk0P2A
Jc`3091Z>`<0SfTj00P0RfDh08aV>@2=IcX0SVPk08eW>P2<IST0RV@g08US=P<0SF8e102>HcH01`2?
I3L0SV<f08eR=@2=HSD0S64d08]P<`2:Gc800P29GS4808QM<P<0Q5ha0P25Gc8408IP<`<0Qf4d0P28
HSD208US=P0408]P<`2<HC@0S64d08aQ=0<0SF8e00<0SV<f08eR=@2=HSD00`2<HC@00`2=HSD0Sf@g
091U>00808eW>0P0TFHk202CJCL209E[>@80U6Xh0P2CJCL2099X=P0309A_>`2AK3P0SFPd0080RVDa
00H0S6Lc08mZ=P2BKCT0TF`h091[=`2?JSH308eX=00308iY=@2?JSH0SFLh00L0SFLh202>J3T0302:
IS80RfLc08eY=@2>JSH0Sf/g08iZ=P2=JCD0S6Pd08UU=@2:ISH0RfLg08eY>@@0SVXj0`2=JCT0102<
J3P0RfLg08]W=`2:ISH208UU=@<0Qf8e0`28HcH208UT=`0308=Q<`24HS@0QF<e0080QV@f00<0Q68d
089P<P21Gc400`21Hc42081R<0<0Of4_00<0OUT_07mJ<020Fc400`21G3808P20Fc40OeX`07YG;@1j
Ebd0NUL_07YG<@1hE300MU8`07A@;P1cCbl0L4hX075?:@1`D2T0Ke8Z06eA:@1YD2L0ITdT06A=8`1T
BRD0HdTT06599@1OB2H0FdLV05U69P1HABD0ED@V04do901<?R<0B3`R04Dk8P10>240?3HP03Xd7P0h
<al303<`8@80<RlP0`0a;Ql02@0a;aX0<BhK034^6`0`;A`0<2dN02l[7`0_:b00;RXO02XZ800302TY
7`80:2PN0P0W9ad202DX7`0302@W7P0S9Qd08RDL00808B@K00<082<J024T7@0P8a`00P0P8a`301lR
6`0301hQ6P0O8Q/07b8K00H07b8K00P08B<R020R7`0N81d07AlJ01hQ6P0O8QT082<H024T6@<08R<K
0P0S91`302@U7@P092LL00<09bXO02HY7P0U:1d00`0S9Q/302@W70808bHM00@092LN02DX7`0U:1l0
92LN2P0S9Qd802@U7@<08R@I0P0S9AX302@V6`808bDJ00<092HK02DW700V:1d00P0W:Ah01P0X:Ql0
9RHL02HV700W9ad0:2PN02TY7`80:RXP00<0:b/Q02X[7@0Z:ad01P0Z:ad302X[6`80:b`L0`0/;Ad2
03<b800703Db7`0g<Qh0>C8O03Xb7@0k<a`0?C8L03Td7P0203Xe7`0303/f800l=b40?CPR0080?STS
0P0n=ad00`0o>1h0@3TO044j8002048k8@0E04<l8P14?B<0A3dS04Lm8P19?R80CClR04m08@1@@B00
DT8Q05=69P1DAbD0EDHU05Q89P1JBRH0GddW06=@:01TDBT0HD/T069<9@1TCRL0IDlX00<0IU0Y00<0
IDlX06M@901XDBD00P1XDBD306UB9P0306YC9`1`ERD0L5HU0080L5HU101aEbH307=F:P80M5L[0`1e
F2`00`1/ER@0KELU06iH9P03071J:080KeTW0P1bG2d01P1aFb`0KeTZ06iH:@1]EbP0K5HW06]E9P@0
KUT^0P1]F2d306aG;00506M=:01VC2L0HTXV05m89P1KAbH00P1IARH0101GARP0ED@V05A39@1D@bD2
05=290<0DT4S0`1C@202058o7`<0DChN201B?al205Ho7@0305M07P1H@Al0FD8P0080FT<Q00<0Fd@R
05M58@1GAB400`1FA20305E37`<0Ed@T0P1F@b<305E28P0605Q07P1G@1h0Ed0N05I27`1E@al0Dd<O
0P1CAB000`1C@Ad0E48N05I4800305Q68P0305M58@1FA200GDDS0080Fd@R00D0FDDR05M58@1EAB40
E4HQ05=5800305=37`D0E4@P201FABL205938P80DD8Q0`1@@B000`1?@1l0Bd8Q04]28@0204]28@04
04U07`17?Qd0ASdL04@k6PP0Ac`P01<0A3/N04Dl7`16?B00AchQ04Hm8015?1l0@cXM048i7013?b80
@chQ048m8012>al0A3XO04Hj8019>b40BS`R04Ll8016>al0ACXN0080A3TM00<0ACXN04Hk7`17?200
1013>Ah2048h7@<0@CLL0P14>Ql304<i7P<0@SPM0`13>Ah2048h7@<0@CLL2011>Qh404Dj7P0<04Hk
7`17?200BChR04Xo8`1:?Ad0BchN04dn7`1??R00D3lQ05=08P1E@2<0ET4T0P1F@b<305E28P0;05M4
901JAbL0FdPX05a48P1MAB<0GTHT05m79@1PB2H0HDTW069::01SBbT00P1UBB@306I:9@<0Id/V0`1S
BbD206A<9P<0IDdW0`1[CbX206Y>:@<0JDdX0`1ZCB/306U<:P80J4/Y00<0HTXT06598`1PB2800`1N
AR0205m78@<0H4PT0`1QBBD2069:9PP0HdHT0P1UB2P206A79`0406=69P1RABD0HD@T06549080G4DV
0P1KA2D305Y3900405U28`1B?b40DSlQ058o8@<0DChP0P1@?Al01P17>240ASLP04Hg8015=Ql0A3DN
04<d7@80@S<L2@0o<1T203H]7P0303D/7@0d:a`0<bXK0080<RTJ00<0<BPI030W7P0`9ah00P0_9Qd4
02hU70<0:2HJ0P0W9AT302HT60809B4H00<0920G02<O5P0R7QD00P0Q7A@0100P71<07alG01lO5`0O
7aL201hN5P<07AdE200L6aH@01dL6PP06A/H200G6AH201TK6P0301PJ6@0G6AP05QPG00805ALF00<0
51HE01LI600G6AP01P0G6AQ101DF61005aTH400F61LH01LI60P06A/J0P0G6AP201PJ6@806A/J0P0J
71/801LI60P061PH200J6QX801/K6@P06QXJ200I6aX@01/K6@<06QXH100K6aT201`L6P/06a/I0P0L
71X301dM6`807A`J0`0N7A/301lN70P07b0J0`0O7QT2020O6P<08B0K0P0R8A`3024P6`<081lJ0`0M
7QP301hO6@807b0J200T7a/8020O6PP08B0K200P8A/801lP6P0501`M5`0M7QP07AhH01hO6@0O81X0
0P0P8A/0100Q8Q`07ahI020O6P0Q81/202<R7@03024P6`0P7aX07ahI00P07QlI0`0M7QP201hO6@<0
7b0J200P7aXC01dM6`807QhL0P0O7ad2020P7P807AhH0P0N7aT201lP6P80824K200O81X0100S8Qd0
8R4L028Q700R8A`2024P6`8081lJ0P0P8A/201lP6P807QlI2P0M7QP301hO6@807b0J0`0P8A/202<R
7@04028Q700Q81/081lJ020O6P807ahI200O81X8024P6`<07b0J0`0P8A/2024R70P07alM200N7Q`8
020Q6`P07b0J0`0Q81/2028Q70<08b8M0P0T91`00`0U9Ad09RHN02LW7`0202PX800302TY8@0^:B<0
;RTS00H0;RTS00H09RPJ02PY6`0Z:ad0;B/N02hZ7P0_:Ad202hV6`0402dU6P0]:280;BPR02dX8P80
;2LQ0`0[9R0202lY7@<0;RPL0`0]9a/802@T70<09b8L0P0X8ad302TT7PP09RHN0`0[9R0202XU7`<0
:B@N0`0T9Al202<T7P<08R<M200S8a/802<T7P<092DM:oooool002[ooooo00<0Ufdk09Q^?02HKS`0
0P2IKcd209Y`?P0909]a?`2OLd80Wg=20:1d@`2QMD@0X7A309ib@@2LL3l0VVhm00P0VW0n00H0WGA0
09ac?`2LLcl0Vg8n09Ya?@2IL3`209Q_>`P0W711202NLT480:5eA0P0X7E2202TN4L0102VNdP0XgQ5
0:1e@P2MLSl209ic@0040:5f@`2UNTL0Z7e:0:9iA@H0XgY600<0XWU50:AiAP2TNDH00P2UNTL20:Ik
B080Yga91P2WO4L20:IkAPP0Y7]70`2TNDH20:=hA@<0XWM400P0Wg500:5c@P2PM4<0X7I409mgA02L
Md<0VgI209Qd@0<0VVm200D0VFi109Q]@02GK3l0UV/n09EZ?@0209AY?00409=X>`2BIcX0T6Dh08mT
=`80SF8e0P2:IC/01029I3X0Qf8h08IQ=`24GcD208=N=006089M<`21G380P5/a07mJ<01nFBl0OEP^
0P1lEbd207YG;`0607UF;P1gE2`0MU<[07EB:P1dDBT0Le0X201aCRP00`1dDB/0LTlY071=9`0206m<
9P04071=9`1bCbT0M54[075>:080LTlY00<0Le0Z07AA:`1dDB/00P1eDR`207eH;P0407iI;`20Fc40
PE`b08=N=080Q5le0P22H3801P25H3<0R68e08]R=P2=HSL0SV<h091S>@80T6Hd00h0TFLe099X=P2C
JCL0U6Xh09E[>@2FK3X0T6Xk08mY>P2>J3T0SfTj091Z>`2AJc`0T6Xk08mY>P/0TF/l0`2@JS/308mY
>P0308]U>02<IST0SFLj0080SFLj00@0RfDh08US=P28HSD0S64d0`2=HSD01@2>HcH0Sf@g08mT=`2?
I3L0SV<f0080SF8e00<0S64d08]P<`2:Gc800P29GS4808UN<`80Q5ha0P25Gc8208IP<`D0Qf4d0P28
HSD308US=P@0S64d2@2=HSD00`2>HcH0Sf@g08mT=`0808eW>0P0TFHk0P2AIcD2099X=P0409=Y=`2D
JSP0U6Xh09E[>@80UV`j0P2EJcT309AZ>00409=Y=`2DKc/0TF`h08eX=080RF@`00<0S6Lc091[=`2C
KSX00P2@JcL00`2?JSH0SVTe08iY=@0308iY=@P0S6Hg202>J3T00`2<Ic<0SFPd08mZ=P02091[=`09
08mZ=P2>JCD0SFPd08QT=02:ISH0SFTi08m[>`2@K3`0SVXj0080S6Ph00@0RfLg08eY>@2=JCT0S6Ph
0P2;IcL00`2:ISH0RFDe08UU=@0208IQ=00308MR=@28HcH0RF@g0080RVDh00@0RfHi08=Q<`24HS@0
QF<e0P26I3H00`24HS@0PV0b085O<@02085R<`<0P64b0`1oH340101kF2h0O5T_07aI;`1mFS0407iK
<@80NUT^00H0NEP_07ME;`1eDbh0Le4^079@;@1aCRh206i>:00606e?:@1/D2T0JE0X06I=9@1SC2<0
HDXQ0P1PB2@03P1MAR@0FTHU05M4901C@R@0DT4S05119017>b40ASXP04@j8@10>240?3HP03Xc800h
<al0=c8O0`0a;Ql2030]7P<0;b`M00H0;RdI02h]6`0^;A/0;R`M02d[7P0]:al202dZ8@0402PZ7`0W
:Ah09bTN02LY7P809RPM0P0U9a`202@W7P0302<V7@0R9A`08B@K008082<J00<07b8I01lR6`0O8Q/0
3P0O8Q/0200Q8b80828O01lQ7P0N81/07R4J01lR6@0Q91T08RDJ0P0R8a/302<T70<092DM200T9a`0
100V:Ah09BPM02DX7@0T9a`502<V6a008bHM200T9Ad2028T6@<08bDJ0`0T9Q/01P0S9AX092HK02@V
6`0U9a`09RPM02LY7P80:2XO0P0W9a/0100X:1`0:BTM02XZ7P0Z:Qh202/[7`P0;R`M0P0^;A/202l^
70@0<2lM00H0>3DT03Pe8P0j=B40>c@Q03`d7`0l=1d203hd6`0603dg7`0n>200?SPP03li8@10>R80
@C/S0P12?2@2044j7P04048k7`13?200A3dQ04@m8@80AChR0P19?b@03P1;@2@0Cd4T05528`1C@b80
E4@S05M48`1GBRP0F4TX05Y::01LC2P0H4hX06=@:01WDBP0J58Y0P1VD2L00`1WDBP0J58Y06QB:@03
06UC:PD0JeDV0`1/ERL407=I:0@0M5XY0`1hFB/207UJ;0<0NU/]00<0KeTW071J:01`FRP00P1aFbT3
079L:P0507QP<01gGbl0Mel_07EM;@1dG2`00P1cFb/0101bFRX0Le``07=L<01cG302079K;`0<075J
;P1`FBd0KeP/06mH;01[CbL0JThW06M>9P1TC2H0HD/V05i:9`1MBBP0G4TX0P1JAbH205U69@0405Q5
901GA2<0Ed@S05I38P<0ED4P0`1D@1l205<o7PP0E40O0P1I@ah205Y47`80FdDP0P1LAR4805Q47`80
FTHU0`1IAB@305Q48`0605U17`1H@Al0FD8P05M3801FA200E4@P0P1CAB000`1C@Ad0E48N05I48003
05Q68P0305M58@1FA200G4@R0080Fd@R00<0FDDR05M58@1EAB400P1DAR4305E58@80E4@P0`1C@al4
05I69@@0EDDT0P1CA2<205938P<0DD8Q00<0D44P04a18@1>@b<00P1?A2@0101=@R80BChN04Hk6`13
>1P804Ll800304@k7P15?1l0ASdP0080AchQ00@0AC`O04<j7@12>A`0@ShQ0P12?B001@13?200AC/P
04Hj8018>R00BC/Q00P0AS/O0`14>Ql204<i7P80@SPM0P11=a`604<i7P80@SPM1013>Ah4048h7@P0
@CXN00<0A3/N04<j7@11>1/00P10=aX02013>Qd0ASdP04Po8P14>a`0AC`M04Hk7@19>ah0Bc`O0P1=
?2000`1?>b00CchR04hm8@0304dl800304ln8P1A@2@0DT4U0080DSlO00@0Dd0P05E28P1F@b<0F4DU
0P1IARH305U28080FT<Q0`1KA28405I480@0EdDQ0`1KAbH205Y69@<0FDDT00P0FdHY05Y5:01IA2L0
F4<V05M29@1F@B@0ED0S05@o8P80DChN00<0D3dM04ll701??1`00`1??1`204hk7@80Cc`N00@0D3dO
054n801B?b40DSlQ201??1h00`1@?2<0Cc/R04lk8P0204hj8@80CCTP00<0C3PO04Lg7P16=Qd00P16
=Qd204De7080A3@K0`10<A`203l`6`<0?RlJ0`0`;a/00`0_;QX0;RdI02h]6@0202d/60T0:RTE0P0T
8al00`0S8Qh08R4M028Q7@03024P70<07R0O0P0M7ah301`N7@806R0N0`0I7ad301PN70807AXC0P0L
6A8201/H4@806QL@100I6QD401PI50P05aPC400I6AT801HH5`P05ALF0`0F61L00`0E5aH051HE01@F
5@0201<E50P05ALF400C51Ha01DF62005QPG600G6AP801TK6P805aTH0P0H6QT201TK6P806Q`K200G
6AP801PH60P06QXJ200K6aT801/K6`P06A/J400K6aT301XJ60@06a/I0P0L71X;01/K6@8071`J0`0M
7A/201dL6P<07QdK0`0O7Q`801lP6P807ahI0P0P7aX2024P6`@08R4L0`0Q81/3020O6P@071dG0P0M
7QP201hO6@P09B0L400Q81/8020Q6`P07b0J0P0M7QP201hO6@807b0J0P0P8A/00`0O7QT081lJ024P
6`0202<R7@03024P6`0P7aX07ahI00P07QlI0P0M7QP301hO6@<07b0J200Q81/C01dM6`807QhL0P0O
7ad2020P7P807AhH0P0N7aT201lP6P80824K200O81X3028Q70808B0K0`0P7aX2020Q6`807b0J0P0N
7aT:01dN60<07QlI0`0O81X2020Q6`8092<N00H08b8M024P6`0P7aX07ahI01hM600M71L801lP6PP0
8B0K0P0O81X6020Q6`P07alM200N7Q`@020Q6`<08R8J0`0S8a/202@T70809BDM0P0V9Qh0100W9al0
:2PP02PX800X:20302dY80@0;RXQ00L0;b/R02HX6P0Y:Q`0:R/M02d[7P0^:Qh0;bTM0080;bLL00@0
;BDJ02dY800]:B00;BTP0`0/:1l202/W7P80;bTM1P0^:1`802DU7@809b8L0P0X8ad202TT7P80:RDO
200Y9Ql302/V8080:RDO0`0Y91h302@U7`<08b@N0P0R8ad802@T70P092DO0`0U9Qh[ooooo`00:_oo
ool209Q^?0@0VFlm0P2JL3h209mc@P060:1d@`2QMD@0X7A309ib@@2LL3l0VVhm202KLCl01P2MM400
W7<o09ac?`2KLSh0VW4m09U`?080V6lk202MLD0809ib@@P0XGE4202QMT<80:EiB0040:IkB02SN4D0
X7E209eb?`80WW=000@0XGI30:EjA`2XODX0Y7]71P2SNTH0102TNdL0Y7U60:AiAP2TNDH20:EjA`<0
YW]81P2VNdH20:MlA`P0Y7]70P2TNDH20:=hA@80XWM40P2QMT<0202OLD00X79109mc@P2PMT@0WgM4
09]f@P2JMD40V7A00P2JKd80102HKD00Uf`o09I[?P2FJch209EZ?@0609AY?02CJ3/0TVLj091U>02?
I3L0SV<f0P2=HSD208UT>P0408QS>@26HCL0QF0f08=N=080PUdc0P20Fc4207mJ<00407iI;`1mF2h0
OEP^07aG;@80NEH^00H0N5D]07IC:`1eDRX0M54Y07=@:01bCbL806m=9`0307EB;01cD2X0L4dW0080
KT/U00T0L4dW07=@:P1eDR`0LDhX079?:@1cD2X0M54[07EB;01fDbd00P1gE2h207YE:`0407]F;01m
F2h0OUT_081K<@80PE`b0P23HC<01P26HC@0RF<f08aS=`2>HcP0Sf@i095T>P80SV@b00@0SfDc091V
=02AIcD0TFLe0P2BJ3H2091Z>`80TF/l0P2?JCX2091Z>`/0TF/l0`2@JS/308mY>P0808]U>02<IST0
SFLj08iX>`2=IcX0S6Hi08YT=`29HcH308eR=@H0SV<f0P2=HSD00`2<HC@0Rf0c08YO<P0208UN<@P0
REhc0`25Gc8208IP<`D0Qf4d0P28HSD208US=P80RV@g102=HSD508aQ=080SF8e00<0SV<f08mT=`2?
I3L00P2?I3L808iX>@P0TVLl00H0T6Hd095W=@2AIcD0TVPf09=Y=`2DJSP209E[>@80UV`j0P2EJcT3
09AZ>00409=Y=`2BKCT0T6/g08aW<`80RVDa00<0SFPd095/>02CKSX01@2?JSH00`2>JCD0SFPd08eX
=00808]U=PP0SfTj00/0SfLd091X=@2BJSL0Tf/h099Z=`2AJCH0T6Pe08mW=028I3@0RVHf08eY>@02
08m[>`0408iZ>P2<J3P0S6Ph08YV=P80SFTi00@0S6Ph08]W=`2;IcL0RVHf0P29ICD01P26HC@0Qf8e
08MR=@28HcH0RF@g08YU>080RfHi00<0Pf4c08AR=025HcD00P26I3H00`24HS@0PV0b085O<@03081Q
<`<0Of0b0P1nGc4207]J;`80NUT^0P1kFRl207aK<00807UJ;P1hFBd0MUH]07AD;@1bDR`0LE0]071?
;01`Cbh206]=:@0F06]?:P1ZCRT0IddX06=;9@1OBB80GTPQ05e6901LAB<0FDDT05I38`1B@B<0D3lS
04dn8@1;?B80@SPO044g7P0n=Ql0?3@O03Xc800g<Qh0=34N03<`7`<0<2dN0`0_;1d202h[700602X[
6@0Z:a/0:R/K02X[7@0Z:Qh0:RXP0P0Z:R8202LY7P809RPM0`0U9a`01P0T9Q/08bHM02<V7@0R9A`0
8B@K020S6P807b8I00<07R4H01hQ6P0N8AX00P0N8AX<01lR6`08020R8@0P8Ql07b4N01hP6`0O8Q/0
82<J028U6P0T9a`302<T70<092DM0P0U9Qh=02@W700402<V6`0R9AX08RDJ028U6Q008RDL200T9Ad3
02<U6P<092HK0P0U9a`202@V6`0302DW700V:1d09bTN0080:2XO00<0:B/P02PY6`0X:A/00P0Y:Q`0
100Z:ad0:b`N02`]7`0/;Al8034^7@@0<RlL0P0c<1d203@a7P0603`g900l=b<0?CHS03dg8@0n=Ql0
@3HM0P11=A/2044j8003048k8@13?280A3dS0080AChT00<0ASlU04Hm8016?B000P17?R405@18?b80
BD0S04Y1901:@B@0CD8V04i39`1A@bH0Dd@U05E5901GAbD0FTLV05]7901HBRL0FTXX05];9`1OCBL0
HTlW06E?9P1WD2H0J54W06YE:P0306UD:@80JUDZ0P1[ER/206iH9`H0KELV0`1dFRT00`1eFbX0MU`[
07IL:`0207MM;0<0Ne//0`1lG2d207eM;P<0LU`Z0P1cGB/207AN;00307EO;@1lHS40O68a0080Nf4`
00@0NV0_07UO;P1iGbh0N5h]0`1eGBl0101dG2h0Le/]079J;01aFB/2071H:P0>06iA9@1^DBL0K54V
06YA:01WD2L0IDlX06==:01QCBP0H4`W05m;9P1NBRD0GDTT05a88`1KAb8205Y68@80FT<Q0P1I@R03
05Q17`0305M07P1I@R00FD8P00H0FD8P0P1LAR4405e78P80GTPS1@1LAR4305e78P80GTLU0P1MAR@4
05a58`0605]38@1J@b40FT<Q05Q48@1GAB40E4@P0P1CAB000`1C@Ad0E48N05I4800305Q68P0305M5
8@1FA200Fd<Q0080FT<Q00<0F4@Q05Q68P1FAR800P1EAb80101FAR80EDDQ05E58@1EAB4305A48004
05=37`1EAB<0E4@R05A48P80Dd<Q0P1B@R000`1A@Al0E4DT05=48`0205=48`80DT<R0P1A@R40201?
@R80D4<S05959@1BABD0D4<S04`o7`19?1`0ASTI2018?B402@15?1l0ASdP04Ln8@18?b80AchQ04Hm
8014>ah0@STL044m8002048m800304@m8@16?240ASXP0080B3XP0P16>al404Ll8080AS/O1014>Ql2
04<i7PD0@SPM5P13>Ah02012>al0@3TM03hg6`0l=AT0?CHJ03lh7011>Qh0@c`P0P10>ad00`11>Qd0
@cXM04@i7@0204Hh7@0304Lg7@19>b00B3XO00<0ASPM00T0AcTN04Tk801:?240BCXM04Xk7P1;?1l0
C3dP04dn8@1>?b800P1?@2<204`k7@80CC`N0`1>?Al0101??R00Bc`M04/l7@1;?1d504Xk700404`n
8`1;?B80BcdR04/m8P80BS`Q0P19>b00201;?B<0BS`R04Tk8@18>R00ASPN04Dg7@14=Q`0@cDK1012
=Qh01011=Ad0@3@L040d700o<a/203hb700303lc7@10=1h0@CDO0080@SHP00<0@cLQ03hc7@0n<ad0
1P0n<ad203/`7P<0>RlM0`0i;Q`0100d:aX0<bXI03<Z6@0c:QT2038Y6080<BPG0`0^9aL202dV5P<0
;2DE100T:1X402<W6@T082@F100J7R4401TM800401HN800E7Al05AdO01DM7`8051`N0P0C6ad0100E
7b0051hO01@N7`0D7Ql201<M7P804Q`M0`0I61@401PG4`0301LF4P0H61P061PH00@061PH0P0I6AT8
01LG5A005aLG200E5aH801<E500301DG5P0D5QD051HE008051HE0`0C5A@801@F5A004a@F<@0E5QPP
01HH5aP05aTH200I6aX201LI608061XI0P0I6aX201XL6`P061XI200H61P801XJ6PP06a/I200K6a/8
01TK6Q006a/I0`0J6QP401/K6@8071`J2`0K6aT201`L6P<07AdK0P0M71X301hM6`<07ahL200O81X3
020O6P808B0K1@0R8A`3024P6`<081lJ100L7AL201dN60807QlI200U81`@024P6`P0824K200O81X4
01hO6@@07b0J00<07ahI020O6P0Q81/00P0S8Qd00`0Q81/081lJ01lN6@0801lP6P<07QlI0`0O81X2
020Q6`P08B0K200N7Q`;01dM6`807QhL0P0O7ad2020P7P807AhH0P0N7aT201lP6P80824K200N7aT2
028Q70808B0K0P0P7aX201lN6@80824K0P0O81X201hO6@`07AhH0`0N7aT301lP6P8092<N00H08b8M
024P6`0P7aX07ahI01hM600M71L801lP6PP08B0K1P0P8A/201lP6PP07alM200N7Q`@020Q6`@08b<I
0P0T91X202DU6`0302HV7P0W9al09bLO00809bLO0`0X:20302XV6`0302/W700/:1d0;2PM0080;BTN
00H09bTK02TZ700Z:ad0;R`O02l[7`0_:Ad202lW700302hV6`0^:Ql0;RXO00<0;BTN0`0/:1d202hX
70H0;bTM200V9Qh302PS7@80:B@N2`0Z9Al302/V8080:RDO0`0Y91h202DV80<092DO0`0S91h802DU
7@P09BHP0`0U9Qh[ooooo`00:_ooool809U_?@0309a`?`2MLD00Wg=20080Wg=200<0WG5009a`?`2J
KSd0202KLCl309]b?P<0VW4m0P2IL3`809eb?`P0WW91202PM4<80:5f@`P0Y7Q700<0YGY50:=h@`2Q
MT400`2PMD001P2SN4<0YW]60:MlA`2UO4P0Y7]70:=jAP80XWU500@0XgY60:AkA`2UO4P0XgQ50`2T
NDH20:EjA`80YW]80`2UNTD30:IkAP80Yga7202TNdL30:=hA@80XWM40`2QMT<03P2OLD00X79109mc
@P2OMD<0WWI309]f@P2JMD40V7A009Y_@P2IKT40Uf`o09I[?P2EJSd0U6Tl0P2EJSd01@2DJC`0TVLj
091U>02>HcH0SF8e00<0S64d0P28HcT01P27HSP0QF0f08AO=@23GS@0PUdc085L<P<0OeX`0P1nFBl2
07eH;P0507aG;@1gE2`0Me@/07IC:`1eDRX00P1dDBT207=@:0P0KdlX00<0M54[079?:@1`CBL00P1_
C2H00`1`CBL0LTlY07AA:`02079?:@0607=@:P1dDB/0MU<]07MD;P1hEBl0NEH`0P1hDbT0101iE2X0
NeH/07aG;@1nFBl207mJ<009089P<P23HC<0QV4d08QR=@2<HcL0SV<h08mT>@2AI3X0SV@b00<0SfDc
00`0T6Hd095W=@2AIcD0TFLe091Z>`2BK3d0Tfdn099/?@2?JCX0SVPi08mY>P2AJc`9099/?@80TF/l
0`2@JS/308mY>P80SFLj0`2?JC`00`2=IcX0RfDh08YT=`0308mT=`0608iS=P2=HSD0SF8e08eR=@2<
HC@0SV<f0P2=HSD00`2<HC@0Rf0c08YO<P0208UN<@P0REhc0P25Gc8208IP<`<0Qf4d1028HSD208US
=P<0RV@g00@0SV<f08eR=@2=HSD0SF8e0`2<HC@01@2;H3<0S64d08eR=@2>HcH0Sf@g0080T6Dh00<0
Sf@g08iS=P2>J3T01`2>J3T8099W?080TFLe0P2BJ3H00`2CJCL0U6Xh09AZ>00309E[>@80U6Xh0P2C
JCL2099X=P0308mZ=P2>JCD0SFPd0080SFPd00D0SVTe091[=`2AK3P0SVTe08mZ=P03091[=`0308iY
=@2=J3@0S6Lc00P0S6Hg202?JCX00`2AIcD0TVPf09AZ>00209AZ>005099X=P2AIcD0SfDc08]W=`2<
J3P00P2=JCT01@2>JSX0SFTi08aX>02<J3P0RfLg0080SFTi00@0S6Ph08]W=`2;IcL0RVHf0P29ICD2
08QS=P<0RF@g0`2:ICP00`23HC<0Q68d08ES=@0208IT=P0308AR=022H380PEla00<0P64e0P1oH3@3
07iO<`0307aM<@1kG300NEX^00<0N5T]0P1iFRh02@1fFBd0M5L[079E:`1`Db/0Ke4[06i@;01_DBd0
Ke4_06Y<:P0206U<:P0F06I<:@1TC2P0H4XU05]78P1IAB00F4@S05M38P1E@R80DD0R04hm8@1;>b40
B3XO04Li7`0n<ad0>c<L03Xb7@0h<Ah0=S4M03<`7@0b<Al0<C0N034^7`<0<2dN0P0_;1d202h[7080
:B`K00@0:B/M02PZ7@0W:Ah09bPP0P0V9b4202DX7@8092LL0`0S9Q/01P0R9AX08RDL028U700Q91/0
82<J01lR6@807R4H00@07B0G01dP6@0M81T07B0I0P0N8AX;01lR6`08020R8@0O8Ah07b4N01hP6`0O
8Q/08B@K02<V6`0U:1d302<T708092DM0`0U9Qh902<V6`8092LL00@09BPM02@W700S9Q/08RDJ0P0Q
91T2028U7004024T6`0P8aX082<J024T6`X08RDL200T9Ad302<U6P8092HK0`0U9a`01P0T9Q/09BLL
02DW700V:1d09bTN02PZ7`80:B/P00H0:2TI02TZ6P0Y:QX0:R/K02//700/;Ad202d^7PP0=S4N0`0f
<Ad203Lb7P<0>3<O00H0?CPT03hh8P0o>B<0@3PQ04<i8014>1h204Li7P80AS`Q00<0AcdR04Pn8`19
?b@00P1:@2D01`1;@BH0BChR04Xo8`1:?b<0Bd0T04a19@1=@RH00P1>@bL0401BA2L0DdDX05E69`1G
AbH0FDTW05a:9P1NBRL0GTXU05Y:9P1MBbL0GddW069?9`1VD2L0J54W06U@9`1XD2@206aG:P0606]F
:@1ZEBP0JUDX06]F:@1/EbX0KEP[0`1_FBL206iH9P<0KELU0P1dFRT0101eFbX0MU`[07IL:`1gGB`2
07QN;@80O5XZ0P1mFb/207iL;080Oed]0P1eGbd307AN;00407IP;P1gHBl0N68`07iR<0<0OF4_0P1l
H2h207]O;@<0NEha00h0N5d`07IK;P1eFRd0M5T/07=H:`1bEbX0LU<T07=D9P1aEBH0L5DX06eE:@1Z
DbT0Ie4X06I@9`80IDlX00H0I4hW06==9P1QBb@0H4XS05m98P1NB24305i68P80GDDQ0`1LA20805e5
8@P0GdTR101PB28206598`80HTXT0P1QBBD206189080GdLS0P1NAR801P1MAB<0G4DS05]48P1IAB80
EdDQ05E58@80E4HQ00<0Dd4M05A27P1FA2000`1HAR800`1GAB40ET@P05Y2800205Y38@0505Q48@1H
AR80ETHR05E78P1FB2<02@1EAB4205A4800605=37`1B@Qh0DD4M05517@1@@1`0EDHU0`1DAB@205=4
8`80DT<R101B@b@0101@@B80CSlP04`m7P1;?1d804Pm8@0@04Dl7`16?B00AchQ04Po8P17?R40ASdP
04@k7P13>Qd0@3`O048m8013?R40AChR04Lm8P17>b40B3XP04Li7`80AS/O00@0Ac`P04Pm8@18?B40
Ac`P0P16>al00`15>b00A3XO04@j7`0204@j7`80@cTN1@12>1d304<i7P80A3XO00@0@SPM04<i7P13
>Ah0@cTN0`14>Ql00`15>b00A3PN04@h7P0604@h7P80@3TO00H0?cPN03hg7@0n=ad0?cPN040i7`11
>R0203`k7@0403di700n>A`0?cPL040f6`80@CDK00<0@SPO044g7P10=Qd00P0o=A`01010=Qd0@SPO
04<i8011=a`3048h7@<0@cTN00<0A3XO048f7012=Q`00`13=ad304@h7P<0@3HK0P0o=AX303hd6@80
?CDP0P0l=1l303/c7P0703Xb7@0l=240>c<P03Xb7`0i<Ah0>30M03H^6`0203D]6P0803@_700e<1d0
=C0M03Ha7P0e<1d0=2lL03<^6`0b;AX3038/7P<0<bdO0P0d;R0802l/7@P0:RHJ00@09b<J02HR6@0V
8QT09R8I0P0U8AP202@P5`<0820H0P0O7aL301hN5PP0724J2@0J7aP301PL7`D05a/N00@05a`O01HK
7P0F6ah05Q/N0P0E6Qd201@I70805a`O0P0F6ah301DJ7@0301@I700G5aL05aLG00H05aLG0P0F5aT3
01LH6P<061TK200G6AP801@E5`P05AHH200D5AL801<D5Q0051HE400C51HP01@E5a405AHH400E5aH@
01HH5aP05aTH200I6aX201LI608061XI0P0I6aX201XL6`P061XI200H61P801XJ6PP06a/I200K6a/8
01TK6PP06QXH200K6aT301XJ60@06a/I0P0L71X801XJ60<06a/I0P0L71X301dM6`807A`J0`0N7A/3
01lN70P07b0J0P0P7aX2024P6`<08R4L00<08b8M028Q700R8A`00`0Q81/3020O6P<07AhH0`0N7aT2
01lP6PP09R4M400Q81/8020Q6`P07b0J100N7aT401lP6P0301lN6@0P7aX08B0K00808b8M00<08B0K
020O6P0O7QT0200O81X301hO6@807b0J0`0P8A/8024P6`P07QhL2`0M7A/201hN70807alM0P0P81h2
01dN60807QlI0P0O81X2020Q6`P07QlI0`0Q81/2020O6P<07ahI0P0P8A/201lP6P807QlI3@0M7QP2
01hO6@<07b0J0P0S8Qd0100R8A`08B0K020O6P0P7aX201lN6@P07b0J200P7aX2024R70<0824K0`0O
81X801lO7@P0820N400P8A/0100S8aT092@J02@T6P0T91X202DU6`809RHL200X:2001P0X91P0:BDI
02TU6@0Z9QX0:bLK02`X7080;BTM00H09bTK02TZ700[;1h0;R`O02l[7`0`:Qh202lW700402hV6`0^
:Qh0;RXN02hZ7P80;BTM0`0/:1`202hX70<0;bTM0`0`:Qh802LW7`80:2<M0P0Y91h302XU7`0302/V
800]9R00;BHP00H0;BHP0`0[9R0202XU7`<0:B@N0`0U9R0202@U7`<08b@N200V9Qh802HW8@<09BHN
:oooool002[ooooo202IKcd0202IKC`0VVhm09a`?`2MLD00WW9109ea@02LL3l0Vfln202KLCl209U`
?0<0VW4m0`2KLSh809ic?PP0WW91202OLd880:5f@`P0XgM61P2TND801P2UNT<0YW]40:MlA@2VODT0
YGa80:=jAP80XWU500<0XgY60:ElB02VODT00P2SN4D30:AiAP<0YGY70P2TND@20:EjA@80YW]60P2W
O4L80:AkA`80XgQ50P2RMd@40:5f@`0=09i`?`2OLD00Wg=209me@`2NMT<0VgI209Ud@02GLcl0VVm2
09U^@@2FJch0U6Tl09=X>`0209AY?00709EZ?@2DJC`0TVLj08mT=`2=HSD0S64d08]P<`0208aQ=008
08QS>@27HSP0QV4g08EP=P23GS@0PUdc085L<P20Fc4407iI;`@0OEP^201dDBT8071@:@80LTlY101a
CRP4079?:@0>07AA:`1eDR`0Me@^07QE;`1iES00NULa07UD:P1jEB/0NeH/07aG;@1nFBl0OeX`081K
<@21G382089P<P0608EP<`28HSD0Rf8f08eR=`2>HcP0T6<i0`2BJ3H309=Y=`80U6Xh00L0SfTj09=]
?P2EKd00Tfdn08iX>@2<ISL0SfTj00X0TV`m0P2AJc`3091Z>`<0SfTj00<0SVPk08mY?02@JSd00P2A
Jch0302?JC`0SFLj08aV>@2BIcX0TFHi091U>02?I3L0SF8e08aQ=02;H3<0RUlb08iS=P80SF8e00<0
S64d08]P<`2:Gc800P29GS4808YO=0<0QV0c0`27HC@408QR=@80RF<f102:I3L208iS=P80SF8e0P2<
HC@208]P<`0808aQ=02=HSD0Sf@g091U>02AIST0T6Dh08mT=`2>HcH808iX>@P0TfPm0`2BJ3H809=Y
=`80TVPf0`2AIcD00`2<Ic<0SFPd08iY=@03091[=`80SfXf00P0SVTe08mZ=P2@JcL0TF`h091[=`2?
JSH0SFPd08]V<PP0SFLh202@JS/02`2BJ3H0TfTg09AZ>02EJcT0U6Xh099X=P2@IS@0SfDc08iZ>P2=
JCT0S6Ph00<0RfLg0P2<J3P308eY>@0408aX>02;IcL0RfLg08YV=P80RFDe102:ICP408UT=`0308=Q
<`24HS@0QF<e0080QV@f00@0Q68d089P<P21Gc40P64e0`1oH3@207iO<`80OEhb00@0OUlc07aM<@1j
Fbl0MeP/0`1fEb/02P1gF2`0LeP[075F:@1_E2T0KU8Z06eA:P1^DRd0Ke<^071C<@1XBb/206I<:`0>
06A<:P1QBRP0G4PU05Q68P1FA200Ed<R05E28P1C@200CSdO04/l7`17>Ah0A3PN04<g7@0h<1T203La
6`0303D`700b;a`0<C0N0080;RlO0`0a;Ql2030]7P<0;b`M0P0Y;Ah01P0X;1h09RTN02DX7`0T9b00
8bHO028T7`<08RPL0P0Q9a/3020V6P06028U700Q91/08B@K020S6P0O8QT07R4H0P0M81L201`O6080
7B0I00<07R4J01lR6`0O8Q/02@0O8Q/02@0P8R407b4N01lQ7P0O8A`082<L028U700T9a`09RTN02<T
700302@U7@809BHN0P0V9al802<V6`07028U6P0S9Q/092LL02DX7@0T9a`08bHK024T6@02020S6003
028U700Q91/082<J00807b8I00<082<J024T6`0R9A`0200Q91/802@U7@0402<U6P0T9Q/092HK02@V
6`809BLL0P0V:1d202DW700402HX7@0W:Ah0:2XO02PZ7`80:B/P00H0:BXH02X[6@0Z:aT0:b`J02`]
6`0];Q`202h_7@P0>34O00@0>38L03Tc7@0i<ad0>C<M0P0j=1h203/e7`0803hh8P0o=b80@3PQ04<i
8016>R00BC/P04/k8@1<?B0204Tn8P0304Xo8`1;@2@0C44U0080CD8V00L0CT<W04do8P1>@2<0CT0S
04m1901@@RD0DD<V0080DT@W01T0EDPX05I7:01GB2L0FDTX05e::@1OBbP0HT`W06==:01OCBL0HDlY
06EB:P1YDbX0Je@Z06aC:P1/E2P0KE8W06iI:P1]F2T0JeHW06YE9P1YE2D0JUDV06aG:01]F2T0L5/V
0080KeXU0P1^FB@00`1]F2<0K5LR06aG8P0207=I:00607AJ:@1eFbX0MU`[07MM;01hGRd0NEl^0P1l
FbP207eL:@<0OUdZ00@0Oeh[07QR<01gHBl0MV0^0P1eGbd00`1gHBl0NF<a07YT<P0507iP;0<0OEl[
0`1mHS<03P1lHC80NUl`07UN;`1gG2d0MU//07EJ:`1eEB@0MELU07IG:01dF2T0LULZ06iF:P1[E2X0
JU<Y0P1XDbP01P1VDBH0IE0U06=>8`1RCB80HD`Q061;80<0HTPS0P1QAb8306168@P0HDLR1`1QBb80
101PBR40HdXR06=:8P1TBb<206E<9080ITdU00@0IdhV06=9901SBB@0HdTT0P1RB2<306578P0605i6
901MAR@0G4DS05Y68`1HAR80EDDQ0P1DAR400`1C@Ad0E48N05I4800305Q68P0805M58@1FA200FT8P
05U2801J@b40F4@Q05Q68P1FAR8205I88`80Dd<O00<0E4@P05E58@1FAR800`1GAb<01P1IBBD0F4PT
05M78`1FAR80EDDQ05A48080Dd<O0`1EARD205A590<0Dd@S00<0Dd@U0593901A@R<00`1?@2420511
8PP0BChR00<0ASdP04Ln8@18?b800P18?b803P16?B00AC`O04<j7@0o>ah0@C`O04<n8@15?R80AcdR
04Lk8@17>Al0ASPN04Dj7P16>al0B3dQ0P19?R800`18?B40AS/O04Dj7P0304Dk80<0A3XO0`13>Ah2
044g7080@SPM00@0@cTN04@j7`14>Ql0A3XO0P12>1d204<i7P0404@j7`15>b00AC/P04Dk80P0ASPN
00<0?SPP03li8@0o>B400P10>R800`0o>B40?SPP03dg7`0203/k7`0903/j7P0l>1d0?CLM03df700l
=A/0?S@K03lg8P0n=R40?3@O00<0>c<N00<0?CDP03hf8@0l=Q`00P0l=Q`203/e6`<0>S@J0P0k<a`2
03`d7@@0?CDN00<0>C<K03Pb6P0h<QX00P0g<AT203H`600403D_5`0a;Q/0<BhK034^6`80<2dJ0`0_
;1T302l/7@0302h[700]:Q/0;2TJ0080;2TJ00<09RHJ02LW6`0Y:Ad00P0Y:Ad00`0W9a/09BDI02@T
600302HV70<09BDK0P0T91X8024T6@<07R4J1@0O8Q/201hO6P807AhI0`0L7AP00`0K71L06Q`I01XL
6@0301TK60<061XG0`0H6QT501TK6PT05aTH1`0H61X00`0I6A/061XI01PJ6@0201LI60<05QPG00<0
5ALF01PJ6@0H6QT00P0G6AP201HH5`805ALF0P0D5AL601DF60804A@I00<04QDJ01<F6`0C5Q/00P0D
5a`00`0E61d04aLH01<G600601<G60P04QHI200C5aX@01@E6@<051HE3@0E5aH`01@E5a405AHH400E
5aH@01HH5aP05aTH200I6aX201LI608061XI0P0I6aX201XL6`P061XI200H61P801XJ6PP06a/I200L
71`801TK6PP06QXH200K6aT301XJ60@06a/I0P0L71X801XJ60<06a/I0P0L71X301dM6`807A`J0`0N
7A/301lN70P07b0J0`0Q81/3028Q70808b8M0P0R8A`3024P6`<081lJ0P0N7aT301lP6P<0824K200V
8Ad8028Q70P08B0K200P8A/<01lP6P@07QlI00<07ahI020O6P0Q81/00P0S8Qd00`0Q81/081lJ01lN
6@08020Q6`0401hO6@0O81X07b0J01lP6P80824K0P0Q8Q`8028Q70P07QhL2`0M7A/201hN70807alM
0P0P81h201dN60807QlI0P0O81X2020Q6`P07AhH0P0Q81/2020O6P@07ahI0P0P8A/201lP6P807QlI
2P0M7QP201`M5`807AhH0`0N7aT00`0O81X08B0K024P6`05024P6`03020O6P0O81X07b0J00H07b0J
200P7aX3024R7003020Q6`0O81X07b0J00807QlI200O7ad8028R80P0824K200Q8Q`202@T60809BDI
0`0V9QX00`0W9a/0:2PP02PX800602PX800502/X6@0/:AX0;2TJ02dZ6`0_;1d00P0`;Ah01`0a;Ql0
:2XL02X[7@0[;1h0;R`O02l[7`0`:Qh00P0`:1d00`0_9a`0;b`M02l/7@0202h[70<0;BXK00<0;2TJ
02hX700^:1`00P0_:Ad2030Z7P80<B/O200X:20302TT7P<0:RDO0P0[9R0802hU80<0:bHP0P0Z9Al3
02TT7P809RLQ0P0U9R0302@U7`0302<T7P0W9al09bLO00H09bLO200W:28302HW7b_ooooo000Zoooo
o`80VW0n102IKcd209Q^?00409M[>P2HK3/0VVhm09a`?`80WG5000<0W70o09]_?P2KLCl01`2KLCl2
09Q_>`0309U`?02JLCd0Vg8n0080W7<o00<0WGA009ic?P2NLch01P2NLch@09ib@@P0XGI3202RMTD0
0`2SN440Y7U20:IkA0040:MlA@80YW]400<0YWe90:ElB02SNTH00P2RNDD00`2SNTH0YGa80:ImB@03
0:=hA@80Y7U60`2UNTL0102SN4<0Y7U40:AiA02UNTD20:IkAP80Yga7202TNdL20:=hA@80XWM40`2Q
MT<03@2PMD80WW0o09ma@02OLd80WgE309if@`2KMT80VGA009Mc?`2JKd80V6e009I[?P2DJC`00P2C
J3/01P2DJC`0UFXm09AY?02BIcX0Sf@g08aQ=080Rf0c0P2<HC@208MR>00408IQ=`24GcD0Pehd085L
<P80P5/a0`1nFBl507eH;P<0Le0X0`1dDBT207EB:PP0Ke8Z0P1aCRP4079?:@80LDhX00P0LTlY07=@
:P1dDB/0ME8/07MD;P1iES00NULa07]H<P80O5L]00h0OEP^07mJ<020Fc40PE`b089M<`23GS@0PEla
089P<P25H3<0Qf4d08YQ=@2=HSL0SV<h08mR>0@0UV`j102GKC/0202?JCX0Tfdn09I`@@2DKSl0SVPi
08aV=`2?JCX0Tfdn2@2BK3d2095[?0<0T6Xk0`2?JCX00`2@JSd0TF/n099/?`02099/?`0<091Z?@2>
J3/0SFLj09=X>`2BIcX0TFHi08mT=`2=HSD0Rf0c08UN<@28GC00SV<f0P2=HSD00`2<HC@0Rf0c08YO
<P0208UN<@P0RUld0`26H3<208MQ=0D0R68e0P29HcH308YT=`0608]U>02>HcH0SV<f08iS=P2=HSD0
S64d0`2;H3<00`2<HC@0SF8e08mT=`03095V>@0308mT=`2>HcH0SVPi00L0SVPi202CJ3d609=Y=`D0
TVPf0P2AIcD3091V=00308UT<02;IS80SfXf0080TVdi00H0TF`h08mZ=P2=J3@0SFPd08mZ=P2@JcL2
095/>00308mZ=P2=J3@0RfHb00P0SVPi202@JS/02`2DJ3L0UFTh09IZ>@2FJST0UFTh09=W=P2AIC@0
T6@c091/?02>JSX0RfLg0080RFDe00@0RfLg08eY>@2=JCT0Sf/k0P2=JCT0102<J3P0RfLg08]W=`2:
ISH208UU=@80S6Lj00<0RfHi08YU>029I3L00P28HcH01027HSD0Pf4c08AR=025HcD208IT=P0308AR
=022H380PEla00@0Oelf0P1nGSD207eM=00507iQ=@1lGc<0N5/_07EH;01cERX00P1bEBT06@1cERX0
LEHY071E:01^DbP0KE4Y06eA:P1^DRd0L5@_075D<P1UBbX0IT`[06E=:`1TC2X0H4TW05]7901GAB40
ED<O05E28P1C@200D3lQ04`m8018>Ql0ASPN048f7011=Ad00P0f<1X0100d;a/0=2lL038_7P0`;ad2
02h_7`<0<RlP0P0a;Ql3030]7P0802X^7`0Y;Al0:2`N02HY7P0T9ah08RDN024S7P0P8Qd2028X7080
8BLK0`0P9QX01P0O9AT08B@K024T6`0P8aX07b8I01hQ60807B0G00H071lF01`O600L7aP071lH01dP
6@0N8AX;01lR6`08020R8@0O8Ah07b4N01lQ700P8a`08RDL02DX7@0V:Ah402@U7@809BHN0P0V9al8
02<V6`03024T6@0S9Q/092LL00809BPM00L08bHK024T6@0O8QL07b8G028U700Q91/07b8I00807R4H
00<07b8I024T6`0R9A`0200Q91/802@U7@@092HK0P0U9a`202HX7@809BLL00<09RPM02LY7P0X:Ql0
0P0Y:b000`0Z;240:R/I02X[6@0202//6P0402`]6`0];Q`0;RlM02h_7@P0>C8O00@0>C<M03Xd7P0j
=1h0>S@N0P0k=Al203`f800803hf8@0o=b00@SLQ04@j8@17>b40BcdR04dn8@1>?b8204Xo8`0304]0
901<@BD0CD8V0080CT<W00L0Cd@X04i18@1?@R80Cd8R05138`1AA2@0DTDU0080DdHV0P1GB2T04@1I
BBP0GDXY05m;:01QCBP0I4hY06A>9`1SDB/0IU8]06UF;P1]Ebh0KeP^071H;01aER/0L5DX06iI:P1]
F2T0JeHW0080JE@U00<0JUDV06aG:01]F2T00`1_FRD00`1^FB@0KEPS06aG8P0206aG8P08079H9`1c
FBP0M5XY07EK:P1fG2/0Med/07QN;@1iGbh307iJ:080Oe/Y0`20G2X00`1iHc40N68`07IP;P0207IP
;P0307QR<01jI380O6Hd00H0OEl[0P1lGRX3089V=P04085U=@1oHc<0OF4a07aP<080NUh^0100MUHS
07MG9P1gFBL0MUXZ07AI:P1`F2X0KUHZ06]D:01[E2X0JU<Y06UB:01WD2H0ITlU06A=8`1SC280HT/Q
0`1TBRD206=990<0HTPS201SBB@00`1SCB@0HT`S069<8`02069<8`<0HD/R0P1UC2@206I=9@0406M>
9P1XCbL0J4lW06U@:080I4XU0P1SBB@306988`0706578P1OAbD0GDHT05e6901JAR<0F4HR05I68P02
05A68@0305=17@1D@Qh0ET@P00<0F4HR00<0EdDQ05I4801J@R000P1I@R000`1HA240F4HR05M78`02
05I88`0805927P1C@al0E4@P05E58@1FAR80EdLS05Q8901IBBD205a=9P0705]<9@1JBb@0FDXS05Q9
8P1GB240ETLP05I79P0305E69@80E4DT0P1CA2<00`1EA2H0Dd8T05508P0204ln8003050o8@1C@R@0
E4<U00P0BChR01<0ASdP04Ln8@18?b80BD0S04Po8P17?R40AC`O04<j7@0o>ah0@C`O04<n8@15?R80
AcdR04Lk8@17>Al0ASPN04Dj7P17?200B3dQ0080BSlS00<0B3dQ04Ll8015>Qh01015>b0204@j7`<0
@cTN0P11=a`2048h7@0404<i7P14>Ql0A3XO04Dk8080@SPM00@0@cTN04@j7`14>Ql0AC/P0P16?248
04Hh7P0303`h7`0n>R40@3`S0080@CdT00<0?c/R03`h7`0j=Qd00P0i?1l00`0j>Qh0>STM03/g7002
03/e6`0403/d6P0m=b40?3HP03Xd7P<0>C<M00P0>cDO03`f800k=ah0>SHM03Te700h=1/0=c<J03Hb
6@80=C4H0P0h<Q`203Tc7@<0>S@N00H0>cDO03D`6P0e<1X0=C0J03@_6@0c;QP3038]5`<0:R/K0P0Y
:QX302PY6@<0:2TK0`0W:1X202HW6@0801lP600P8AT08R<K02<T700R8a/08B8J01hO5`0M7QH2020Q
6`0401lP6P0N7aT07AhH01dN608071dG200H7AH301TN60@06QlI00@06b0J01/M700K7A`06adL0P0J
71/301TK6P0401HL700E6a/05A/K01DK6`8051XJ0P0C6AT401HD5`@05aDH2@0E4aH201PD4`D06ADD
00@06QHE01PG4`0H5a<061LC0P0G5Q8301HE4@<06ADB0P0H514301LC40<04Q<G100C51P01@0D5AT0
3Q4F00lB5`0?4QL041<H00804A@I0P0B5AX8010D5@P04QHI200C5aX@01@E6@@05ALF100F61L801DG
5Q005AHH800D5ALA01DF61005ALF400F61LH01LI60P06A/J0P0G6AP201PJ6@806A/J0P0J71/801PJ
6@P061PH200J6QX801/K6@P071`L200I6aX801XJ60P06a/I0`0J6QP401/K6@8071`J200J6QP301/K
6@8071`J0`0M7A/201dL6P<07QdK0`0O7Q`801lP6P<08B0K0P0R8A`302<R7@808R4L0`0Q81/3020O
6P807b0J0P0P8A/4024R70P09R4M200R8A`8024P6`P0824K300O81X401hO6@0301lN6@0P7aX08B0K
00808b8M00<08B0K020O6P0O7QT0200P8A/401lP6P80824K0P0Q8Q`8028Q70P07QhL2`0M7A/201hN
70807alM0P0P81h201dN60807QlI0P0O81X2020Q6`P07AhH0P0Q81/2020O6P<07ahI00<07QdH020Q
6`0P8A/00P0O81X201hO6@X07AhH0P0L7AL201dN60@07QlI0`0P7aX3024P6`808R4L200O81X8020O
6P04028S7@0Q8Q`08B8L020Q6`807b0J0P0N7aT801lO7@P08b<Q200P8A/8024R700402@U5`0U9QP0
9BHH02DV60809RLI0P0W:1X302TY8@D0:2PP00h0;R/L02l/7@0`;Ah0<BhO038_800c<240=34R03Db
8`0X:Q`0:R/M02//7P0_;B00<2`P030Z7P80<2PM00<0;bLL02l/7@0_;1d00P0^:a`402dZ6`80;RPL
0P0_:Ad0100`:Qh0<B/O034[7`0b;20802PX80<0:B@N0P0Z9Al302/V80P0;RDP0`0[9R0202XU7`<0
:B@N0P0V9b4202DV80@092DO200W9al802LX8P<09RLO:oooool002[ooooo0P2JKSd309]_?P<0W70o
00/0Xg1109m_?`2NKSh0W6hm09Y^?@2KLCl0W7A109if@`2NLT40W70o09]_?P0209U]?00309Y^?@2L
L3l0WG5000P0W790202KKd8809ib@@<0XGI30`2PMD8209md@@0309eb?`2NLd00X7E200<0XWM400<0
XGI30:1e@P2SN4D00P2SN4D00`2RMd@0XGI30:1e@P020:1e@P030:EjA`2SN4D0XWM400<0XGI300<0
XWM40:=hA@2UNTL00P2RMd@0102SN4D0Y7U60:AiAP2UNTL20:IkB0030:MlB@2VNdP0YGY70080XgQ5
00<0YGY70:IkB02WO4T0202VODD30:IkB0<0YGY70P2TNDH20:AjB0030:=iA`2RN4H0XGM50080X7I4
00<0WgE309ie?`2NMCl00P2MM3h309ac?@0909]b?02EL3/0U6lj09=^>@2BKCP0T6/f08mZ=@2>JC@0
SFPc0080SfHj00P0S6Hi08YU>029I3L0QV@f08EU=P24I3D0P5de085N=P80Pf0h00@0PUlg081M=@1m
FS80O5Ta1`1mFS80101lFC40Me@^07MD;P1gE2h207IC;@<0ME8/0`1^D2`206mA;@<0L58^00T0KU4Y
06m?:01^CRL0KT`V06m<9P1bC2L0M4`X07E=:@1bCbL00P1cD2P00`1dDBT0MU<[07MD;00207QE;@0@
07eG<01nFBl0OeX`081K;`22GC00Pel_08AP;P25HBl0Q68e08ES=P28HcH0RV@e08iV=@2@IS@0TFLe
099W=0D0UF/i0`2DJSP209=X?@@0U6Tn0P2EJSl01@2JKTT0V6a709EZ@02BIc`0TFLg0080TFPd00<0
TVTc09=Z<P2EJSd00P2DJC`00`2CJ3/0TVLj099W>P02095V>@80Sf@g0`2>HcH308eR=@0408]P<`2<
HC@0S64d08aQ=0<0SF8e00H0SV<f08]P=@2;H3D0Rf0e08aQ=P2=HSL308iS>0P0Rf0f0P2=HSL208aQ
=P0408]P=@2:Gc@0RUld08YO=080Q5db00H0QElb08IP<@28HS40RF@`08YU<@2;IS4808]V<P<0T6Lc
00<0TFPd099Y=@2CJSH00P2CJSH408mU<`80T6Hd0P2AIcD209UZ?P0909IZ?@2DJC`0TfXl091Z>`2?
JCX0SVXj095W=@2BJ3H0U6Xh0080UF/i00<0U6Xh099X=P2AIcD0202@Ic<8099X=P0808]V<P2=J3@0
SfXf091[=`2AK3P0T6/g08mZ=P2>JCD5091[=0<0SfXc00P0SfXf08iY=@2=J3@0S6Lc08eX=02>JCD0
T6/g099]>@P0RfDf2@2>JSX02@2;ISX0RVDi08YU>029ICD0R6@b08MS;`26HRh0QV<]08QV=P0308MU
=@80QV@d0P25Hc<808IQ=00;089O=@23H3H0Pf0f08=P=P21GS@0Oe`b07aI;`1kF2h0M5DV07EF9`1g
F2T00P1iFR/06`1hFBX0MULX07EF9`1bE2h0L5@]06mC;P1[DBh0J50/06E>;01RCRd0HDd/06M>9@1S
C280HDXQ065;901PC2L0GD/W05I68P1@@1h0Cd4T04do8P18?B40A3XO040i7`0n>200?CLO03dh8P03
03Db8`80=34R0`0c<240200`<2H0;blU02h^900/;280:RXP02PX7P0V9Q`09BDK0P0Z;2400`0Y:b00
:2XO02LY7P0202DW700902@V6`0V:Q/09RXL02DY6`0T9a`08bHM028U7P0R91l08B<N008082<L0P0O
8Q/701hQ6P<07b8K0P0P8a`8020S6P808RDJ0P0S9Q/0100T9a`09BPM02DX7@0V:Ah302@U7@D09BHN
00@092LN02<V7@0S9Qd08bHM0P0R9A`2024T6`T08B8J0`0O8QT2020S6P<08B@K0P0R8a/602<T7004
028T6@0S9AX08bDJ02<U6P8092HK0P0U9a`802HX6`809BLJ00L09RPK02LY700Y:ah0:R`O02/]800/
;R40<BlS0080<BlR00<0<BlP034`7P0a<1`00P0a<1/203Td8080>SDQ0`0k=R801`0l=b<0>S8K03Xb
6`0k<a`0?CDN03lg8010>2400P12>R<02017>b<0ASXR04Di7`15>Qh0Ac`N04Tn7P1<@Ql0CT@Q0P1A
@R<20593900405=49@1DABH0E4DV05E69`80EDHU0P1FAbH305M89`0A05Q9:01HB2@0FDTU05a=9P1N
CbH0Ge0U05mA901ND2<0GDlP065C9P1TDbL0IeHZ06UF:`1/Eb`0K5D[06aC:P1ZDBP0201^F2T806eG
:080MUL[00@0MeP/07QI;@1hFBd0NEX^0P1jFbl207UJ;P80NU/_0`1kG3000`1lGC40NV0]07YP;@06
07YP;@<0OV@[1@1mHbX307iR<080OF4_00d0O60^07]O;@1kGbd0NUh/07EK:P1dFRT0LeTX079H9`1`
ERD0KU@S06eC8P1/DR40Ie4O0080Ie4P00<0IU0Q06E>8P1UCR@00P1TCB@806A8800406U=9@1XC2@0
J4`T06Q<9080Id/S0P1VBR80101UB1h0ITTO06I97`1VBAl206M:8080J4/Q00<0JUDX06UD9`1WDRD0
0P1UD2<02`1VDB@0Ie8U06UD9`1WC1l0J4dP06Y?901[D2D0JThV06U=9P1XC2L0ITXU00<0GdPV1@1P
BBL205]5800305]48P1KA2@0Fd@U0080Fd<W00<0Fd<Y05=37`1C@al00P1DA2001`1EAB40ETHR05I6
8P1GAb<0GDXZ05a9:@1JAbL00`1IARH00`1JAbL0FdPX05U=9`0205Q<9P0305M;9@1FBR@0ETXT0080
EDTS00@0F4XU05I88`1CAB00DD<N0P1?@A`01@1@@Qd0DD<N05=38P1DA2<0EDDT0080ETHU00<0E4@S
05928@1@@1l0201<?28204M08`0304Po8P19?R80BcdR0080Bc/Q00L0C3/Q04/j801:>R00BSXP04Tk
8016>al0AC`O0080@S/N2018?B401`1;@BP0BT0W04Y09`19?bH0B3hU04Hl8`15>b800P14>R400`15
?1l0A3/N04<j7@02048i700304@k7P16?B00AchQ00P0A3XO2013>Qd00`14?B40@CXN03df6P0203Xc
5`0303`e6@0o>1`0@CXN00<0>c@J1@0l=A/203Pc7@80=c8L00@0=S4K03D`6P0d;aT0=2lI0P0d=R40
100b=1l0<38M02h`6`0/;QT202X/5`0402PY6@0Y:QX0:BXJ02TZ6P<0:R/K00L0:b`L02/^7@0[;Qd0
:R`N02T[7P0Y:b00:2TQ00809bPR0`0U9Qh202@U7@<08b@L0P0P8a`201lR6`@07R4J200J71T801XL
6`/061XI0`0G6AP201HH5`P05aTH8@0F5aT@01@E5`805QLI0`0E5QP301@E5`P04ALGD00D5ALY01DF
60P05QPG0`0E5aH201HH5`<05aTH600F61L@01LI60P06QXJ0`0J6QP301/K6@8071`J200H61H201HH
5@805aTF100H6QL801PH5Q006a/I200I6aX801XJ6P<06QXH0`0K6aT201`L6Q406a/I0`0J6QP301/K
6@8071`J0P0L7AL301dN60<07QlI00<071/F01hM600P7aX00P0R8A`00`0Q81/081lJ01hM6008028R
6P<08b<K0P0R8QX3024Q6@P08R8J200R8A`202@S7P0402<R7@0R8A`08R4L024P6`8081lJ0`0S8a/2
028R6P<08B4I200Q81/8024R70P07QdH200P8A/3020O6P<08B0K0P0R8A`0100N7AP07ahI01lN6@0O
7QT2020O6PX08B0K200O81X0100K71H071dG01`M5`0M7QP301hO6@807b0J200N7aT8024P6a007b0J
100O7QT201hM60807A`G200M7A/201dN60807QlI0`0O81X9020Q6`X07AhH0P0N7aT201lP6P80824K
00@07QdH01lN6@0O7QT07ahI0P0P7aX2024P6`P0824K0`0Q81/2028Q70<08b8M0P0S91`0100R8a/0
8B8J024R6P0P8AT201lP60808R8J0P0S8a/402@T70P09b<J0P0Y9aX202XX6`@0:bTL0`0`:Qh2034[
7`<0<R`P00<0=B/O03@Z7P0b:1`00P0a9a/02P0b:1`0=2XN03@Z7P0e:al0=BPO03<Y7`0b:1h0<BTN
030Z7P0]:Ad202`Z7@0402/T7P0/9Al0;2DO02dV8080;RLQ0P0_:2800`0U9Qh09RLO02PY8@0202X[
8`0302PY8@0V9al09BHN00P09bTK00<0;RXN02dY7@0[9a/00P0Z9QX0100/:1`0;RXN02l[7`0^:Qh2
02dY7@0302`X700[9a/0:RHJ0080:BDI00H0:b/Q02XZ800Z:R00:BTO02PX7P0W9ad202HV70P09bLM
0`0X:1h00`0Y:Al0:RXP02/[8@0202/[8@<09BDM:oooool002[ooooo0`2JKSd209]_?P<0W70o00/0
XVm009m_?`2NKSh0W6hm09]_?P2KLCl0W7A109ee@P2LL3l0Vfln09Y^?@0209U]?00309]_?P2MLD00
WW9100P0Vg4o202KKd8809ib@@<0XGI30P2PMD8309md@@0309eb?`2NLd00X7E200<0XWM400@0XGI3
0:1e@P2SN4D0XgQ50P2RMd@20:5f@`80X7E200<0YGY70:=hA@2RMd@00`2QMT<00`2RMd@0XgQ50:Ej
A`030:=hA@80Y7U60`2UNTL00`2WO4T0YW]80:EjA`020:=hA@030:EjA`2VNdP0Yga900P0YWe50`2V
NdP30:EjA`80Y7U60P2TNTP0102SNDL0XWQ60:5gA@2PMT@209me@`80WgI000@0WWDo09ed?P2LLcd0
Vg8l0P2JLC/209A_>`0<09=^>P2BKCT0T6/g08mZ=P2>JCD0SFPd08mV>P2>ICT0S6Hi08YU>029I3L0
QV@f0P24I3D2085N=P80PUlg00<0PEhf07mL=01mFS801@1lFC4407]H<080Me@^0P1fDbd307EB;004
07AA:`1]Cb/0KDl[06e?:`<0KU0/0P1_DBd0201^DBT0KThW06e=9P1]BbD0KT/U075;9P1cBbL0MDdY
0P1bCbL0101cD2P0ME8Z07IC:`1gE2`207QE;@0607iH<@1nFBl0OeX`085L<022GC00Q60`0P25HBl2
08ES=P0608QS=P2:I3D0SVHe091V=02AIcD0TfPe1P2FK3X209E[>@H0U6Tl0P2EJSd01@2HK4L0Uf]4
09AY?`2CJ3d0TVPh0080TVPf00@0TfXd09A[=@2DJC`0U6Tl0P2CJ3/2099W>P80TFHi0P2?I3L308iS
=PT0SF8e0P2<HC@208]P=@80S64f00@0SF8g08iS>02>HcP0SV<h202<HCL508aQ=P<0Rf0e00D0QEhc
08IO=026H3<0Qf4b08QR<@0208UT<00308YU<02;IS80RfHb00H0RfHb0P2@Ic<2095X=080TVTe0P2C
JSH3091V=0<0TFLe0P2BJ3H01@2IJSh0V6Tm09IZ?@2DJC`0TfXl0080T6Xk00@0SVXj095W=@2BJ3H0
U6Xh0P2EJcT00`2DJSP0TVPf095W=@08091W<`P0TVPf00P0RfHb08eX=02?JSH0T6/g095/>02@JcL0
SfXf08iY=@@0T6/d102?JS<0202?JSH0SVTe08eX=02<Ic<0SFPd08iY=@2@JcL0TVdi202=IcP908iZ
>P0808iY?@2=J3`0SFPk08aX>02;IcD0RVHb08UU<@29IS0408MU=@80QV@d0P25Hc<808IQ=080PUle
00P0Pf0f089O=@21GS@0OU/a07aI;`1jEbd0MEHX07IG:@<0N5T[00T0MULY07EF:01cE2H0LE<]071D
;@1^DRd0Je4^06Q@;01UCR`00P1QCB`0401VCbH0Hd`S05m98P1OBB@0GTXU05]99@1C@b40CShL04do
8P1;?B80AS/O048h7@0n=ad0?3HN03`f800k=R0203Db8`80=34R0`0c<2401`0b;b00;RhT02h^900]
;B<0:b/Q02XZ800X:1h00P0W9ad01@0Z;240:B/P02T[800X:Ql09RPM00809BLL00L092HK02HZ6`0U
:A/09BTK02@W700S9Qd08RDN00808B<N0P0P8a`201lR6`<07R4J00@07B0I01hQ6P0N8AX07R4J0`0O
8Q/2020S70P082<J0P0R9AX202<V6`0402@W700U:1d09BPM02DX7@@092DM100U9Qh402<V7@808RDL
0P0Q91/9024R6P807b8I0`0P8aX3024T6`03024R6P0R8a/08R<K00808R<K0`0S91`302<U6P8092HK
0`0U9a`00`0V9QX09bLK02LW6`0202PX70<0:BTM00D0:2PL02TY7@0Y:Ad0:RXN02/[7`0202`/8007
02d]8@0_;B00<2hQ030^7`0a;b00<C0N038a7@02038a7080>S@N0P0k=Al303`f800903dg8@0l=1d0
?3@M03de7P0o=b00@3PQ048j8`13>b@0A3`U0080B3`T00L0Ac/Q04Ll8019?R00Bd0P04i48@1?AB80
DT<T0080Dd@U0P1DABH205E69`0305I7:01FAbH0ETLV0080EdPW101HBBP01@1IBBD0FTXV05e>9`1O
D2L0H54V0080Ge4T00T0GU0Q065C9P1TDbL0IUDY06UF:`1[ER/0K5D[06]B:@1ZDBP0201^F2T806eG
:080MUL[0P1gF2`207QI;@D0NEX^0P1jFbl307]L<0P0NEl/1@1mHR/307aQ:P80OV8`0P1mHBl207aP
;P80Nel]00l0NUh/07IL:`1fG2/0M5XY07=I:01aEbH0L5HU06mE901^E2<0J58P06QB8@1WDB00Ie4R
06I?8`1UCR@00P1TCB@806I:8P80JDdU0P1XC2@306M;8`0406I:8P1WBR00IdXP06M:8080J4/Q0`1Y
C2800`1ZEBH0JE@U06MB8`0206IA8P0;06MB8`1XDb@0JE@U06U>7`1ZCb80Je0S06aA9P1[CbL0JThW
06Q<9`1WBbH00`1PBBL5065::080GDLR00@0G4DS05a59@1KA2D0Fd@U0P1J@RH305=37`0305A4801E
AB40EDDQ0080ETHR00<0FdPX05Y79`1IARH00P1HABD0101IARH0FTLW05a9:@1HC2H205M;9@80ETXT
0P1EBB<01@1DB280EdTT05E78P1CAB00DD<N0080D48M00X0DD<N05947`1B@R40Dd<R05A48`1EAB@0
E4@S05=38P1A@B00D40O201<?28204M08`0304U08`19?R80BcdR0080Bc/Q0P1<>b4204Xj800304Tk
8016>al0AC`O0080@S/N2018?B401P1:?RH0BCdU04Tm9@19?BD0B3`T04Lk8`80ASXR00@0ACTQ04Hm
8015?1l0A3/N0P12>A`00`13>Qd0AC`O04Hm800804@j7`P0@cXM00<0@c`P044j7P0n=a/00P0k=1P0
0`0l=AT0?cPL044j7P0803`e6`0603Td7P0h<ad0>3<M03Lb700f<A/0=C0J0P0d;aT0200b=1l0<C<N
030b7@0_<A`0;BlJ02`^6@0[;AP0:R`G100Z:a/402TZ6P80:RdL00H0:B/M02PZ7@0W:Ah09RLO02HW
8@0U9R0202@U7@<08b@L0`0R8a/2020S70807b8K0`0N8AX00`0M81T06Q`I01XL6@0601XL6@P06Q`K
2`0H6QT201LI60<05QPG200G6APQ01HG6A0051DG0P0F5aT301DF60<051DG200A5aM@01@E5bT05AHH
200F61L301DG5P805QPG0`0G6APH01HH5a005aTH200J6QX301XJ60<06a/I0P0L71X801PH5P805QPE
0P0G6AH301PJ5`0301TK600H61H061PF00H061PF400K6aT801TK6PP06QXJ0`0J6QP301/K6@8071`J
4@0K6aT301XJ60806a/I0`0L71X201`M5`<07AhH0`0N7aT0200L6aH07QdH020O6P0Q81/08R4L024P
6`0P7aX07ahI200R8QX302<S6`<08R8J0P0Q8AT8028R6PP08R4L00<092<N02<R7@0S8Qd00P0R8A`2
024P6`04020O6P0S8a/08b<K02<S6`808R8J0`0Q8AT8024P6`P08B8L200N7AP8020Q6`<081lJ0`0Q
81/2028Q70@07ahI0P0P7aX:024P6`P07b0J0P0L7AL201dN60<07QlI2P0O81X8024P6a007b0J00@0
81lJ01lN6@0O7QT07ahI0P0N7AP201dL5`P07AdK0P0M7QP201hO6@@07b0J200P8A/:01dN60807QlI
0P0O81X2020Q6`@07ahI0P0P7aX2024P6`P0824K0`0Q81/2028Q70<08b8M0P0S91`2028S6`04024R
6P0P8AT0824I020Q6@808R8J0P0S8a/302@T700302DU7@0X91/0:2@K00H0:2@K0P0Y9aX202XX6`<0
:bTL00@0;2XM030Z7P0`:Qh0<2XN0P0a:al3038/800303D[7`0d:Qh0<RPL0080<BLK00D0<RPL03@Z
7P0d:Qh0=B/O03DX7`0203<Y7`03034Y7P0`:Qh0;BTM0080;2XM0P0/9Ad202dV7P0702hW7`0_:200
;bPP02lX800W9ad0:2PN02TY7`0202XZ800302TY7`0X:1h09bLM00P0:2TK00P0;RXN02dY7@0[9a/0
:RHJ02/W6`0/:1`0;RXN02l[7`@0;2PL100[9a/302TY7`<0:2PN2P0W9ad202PX7P80:BTO0P0Z:R02
02/[8@<09RHN:oooool002[ooooo00@0VFdl09Y^?@2JKSd0VVhm0P2KKch209a`?`080:5^?`2NKSh0
WVhn09a^?@2KKch0Vg4o09]c@02LM44509Y^?@0309a`?`2NLT40Wg=200P0VW0n202KKd8809ib@@80
XGI30P2PMD8309md@@0409ic@02MLSl0WW=00:1e@P<0XWM400<0XGI30:1e@P2SN4D00`2RMd@30:5f
@`040:1e@P2UNTL0XgQ50:9gA0<0XGI300<0XWM40:=hA@2UNTL00`2UNTL20:AiAP<0XgQ500<0Yga9
0:IkB02UNTL00P2SN4D00`2UNTL0YW]80:MlB@080:ImA`<0YW]80`2UNTL20:AiAP060:AjB02SNDL0
XgU70:9hAP2QMdD0X7I40P2OMD<20:1g@`0609ie@@2MM400Vg8n09U`?02HKc/0Ufhj0P2DKc/0102C
KSX0TF`h091[=`2>JCD208eX=080SVDi00H0RfDh08UT=`28HcH0QF<e08AT=@23Hc@2085N=P06089O
=`21GSH0P5de07mL=01mFS80O5Ta0P1kF30207YG;`80NEH^0P1hEBd207IC;@80ME8/0`1dDB/0101c
D2X0JddY06]=:@1[CBT206a>:P<0KDl[00P0K4lW06e=9P1/C2D0K4XT06e:901`BRD0LTXV07=;9`80
LTlW00@0Le0X07EB:P1fDb/0N5D]0P1iERh0401nF340OeX`081K<@21G300Peha08AP<025HBl0QV8`
08ES=P26I3L0RF@g08]U=P2?IcH0TFLe099X=P2DJCH809M]>`D0UFXm0`2DJC`01@2FJd40UFY009AY
?P2CJ3/0TfTi0080TfTg00<0U6Xh09E/>02CJ3/00P2CJ3/3099W>P80TFHi0P2?I3L308iS=P<0SF8e
0P2?I3L0102>HcH0SF8e08eR=@2<HC@208]P<`<0S64f0P2=HSL;08iS>0@0S64f102=HSL208QQ=P03
08QR=@28HS<0R68a0080R6<_00<0R6<^08aW<`2<Ic<01P2<Ic<0102@Ic<0TFPd095X=02AJ3@3099Y
=@0309=Z=P2AIcD0TFLe00<0TVPf0`2CJCL209QY?@0309IZ?@2DJC`0TfXl0080T6Xk00@0Sf/k095W
=@2BJ3H0TfTg0P2DJSP00`2CJCL0TVPf095W=@08095X=0P0TVPf00P0RfHb08eX=02?JSH0T6/g095/
>02@JcL0SfXf08iY=@P0SfXe00P0SfXf08iY=@2=J3@0S6Lc08eX=02>JCD0T6/g099]>@P0SVPi2@2>
JSX2091[?`0308mZ?@2>JSX0SFTg0080S6Pd00@0RfPb08MU=@27ICD0QfDe0P26I3@308ES<`P0QF0c
0P21GS@2089O=@04081M<`1nFc40NeP^07YG;@@0N5T]00X0MUL[07AE:@1bDbL0LE8V071B;01_Db`0
KE4/06Y@;@1WCb/0I4d[0P1PC2/03@1VCRP0HD/T05i88`1KAb@0FTLV05I69@1?@1l0BCXK04Xl8@18
>Ql0@cLM03le700l=1d00P0j=1h0100i=200=34R03@a8P0d<B8203<`8@<0<RlP00<0;2`R02/[8@0[
:b400P0Z:R0302TY7`80:B/P00<0:2XO02LY7P0V:1d00P0U9a`02@0T9Q/09BTJ02DY6`0T:1X08bHK
028U700Q91d08B<N020R7@0301lR6`807R4J0`0M81T301hQ6P<07b8K0P0P8a`8024T6`<08bHK0`0T
9a`202DX7@P092DM0`0S9Qd2028U70<08B@K2@0Q8QX0100O8QT082<J020S6P0P8aX2024T6`808RDL
0P0P8AT2024R6P808R<K0P0S91`0100S9AX092HK02@V6`0T9Q/202DW70809RPM0P0V9aT01@0W:1X0
:BXL02X[7@0[;1h0;2dO00T0;BhP00H0;RXN02l/7@0`;Ah0<BhM038_700d<Qd203Dc700403/c7P0l
=1l0?3@O03`d7`80?CDP0P0n=R402011=ah0@SPO04<i8014>R40AC/R04Hl8`17?B@0B3hU0P1:?RH0
1P1:?R@0BSlS04a18`1>@b<0D4HS055790<0EDHW0`1FAbP205M8:@80EdPW0P1HBBP305U::@0605Y;
:P1KBbL0G4`X05i?:01OD2L0H54V0P1PDRD02@1PDR<0HE<V06AC9`1UE2P0Ie@Y06YE:P1[E2X0Je8Y
06YA:00806eG:0P0K5HW0`1dEb/307EH;0D0MUT]0P1gFRh307QK;`P0N5h]201kH2T307eQ;`80O60^
101kGbd01P1hGRd0Med/07IL:`1eFbX0M5XY079H9`80LELV00H0JU@R06UC8P1YDb80J58S06M@901V
CbD206E>9@P0J4`T00@0JThV06U=9@1YCBD0JDdU0P1XC2@206M;8`0406U<8P1ZCB<0JTdS06Y=8`80
JdhT0P1/CbD206]E9P0>06YD9@1YDb@0JE<T06YD9@1[EBH0K5HW06]A801/DB80KE8S06eB9@1]DRL0
JdlW06U=9P1XC2D8069<9`08065;901PBR<0GdTT05i79@1MARH0Fd@U05Y3901J@RH205927P80Dd<O
101DA200201HABD0Ed@T05I38`1F@b<0Ed@T05Q59@1KB2P0G4TY0`1GBB@305I88`<0EDLR00<0E4HQ
05=5801BA1l00P1BA1l0101CAB00E4HQ05928@1B@R4305=38P030551801@@1l0CclN00P0CCdS00L0
B44T04M08`19@2<0BSlS04/m8P1<?280Bc/Q0080C3/Q0P1;>b400`19>b00Ac`P04Dl7`0204<l7`P0
B3dQ1P17>b4304Hj800404Po8P17?R40AC`O04@k7P<0@cXM00<0A3/N04@j7`14>Ql01P14>Ql804<j
7@0304<l8011>Qh0?SLK0080?3DI00<0?CHJ03lh7011>Qh0200l=A/01P0j=Al0>C@N03Td7P0h<ad0
=c8L03Ha6`80=C0J0P0^<1/202d_6P80;2hI0P0[;AP01@0/;Ad0:b`L02//700Z:a/0:BXJ0080:2TI
00L09bPH02P[6P0X:aX09bTK02HX6`0U9a`09BHN008092DO0`0R8a/2024R6P<0824I0`0O8Q/201hQ
6P<07B0I200J71T801TK6PX061XI0P0G6AP301HH5`0301DG5P0G6AP05aTH00H05aTH8@0E5QP@01@E
5`805QLI0`0E5QP301@E5`P04ALGD00D5ALY01DF60P05QPG0`0E5aH201HH5`<05aTH600F61L@01LI
60P06QXJ0`0J6QP301/K6@8071`J200I6AL301LI5P8061XG0`0I6aP801TI5a006a/I200I6aX801XJ
6P<06QXH0`0K6aT201`L6Q406a/I0P0J6QP201/K6@<071`J00<07AdK01`M5`0L7AL00`0M7QP301hO
6@0301dL5`0N7AP07ahI00<08B0K00<081lJ01lN6@0R8QX01`0R8QX202@T70808b<K0`0R8QX00`0Q
8AT08R8J028R6P06028R6PP08R4L0`0S8Qd2028Q70<08B0K0`0S8a/2028R6P<08B4I200Q81/8024R
70P07ahI200P8A/3020O6P<08B0K0P0R8A`301lN6@8081lJ2`0Q81/801lP6P<07AhH100N7aT201lP
6PP08B8L200Q81/@01lP6P<081lJ0P0O7QT301hM60P07AdK0`0M7QP201hO6@<07b0J200P8A/801hO
6@807AhH0P0N7aT201lP6P80824K0`0O7QT2020O6P<08B0K200P8A/3024P6`808R4L0`0S8Qd0100S
91`08R<K028S6`0R8a/3024R6P04020Q6@0S8a/08b<K02<S6`8092@L0`0U9Ad802/W7P<0:bLK0P0/
:1`302dY7@<0<2XN0P0a:al3038/800303D[7`0d:Qh0<bTM0080<RPL00D0<bTM03@Z7P0d:Qh0=B/O
03HY800203<Y7`03038Z7`0`:Qh0;RXN0080;2XM0P0]9Qh202hW7`@0;bPP0P0X:1h0100Y:Al0:RXP
02XZ800Y:Al202PX7PP0:BXL0P0/:1`202/W6`0402`X700]:Ad0;RXN02l[7`<0:bLK0`0/:1`202dY
7@809bLM0`0X:1h302TY7`T0:2PN0`0Y:Al302XZ800402/[8@0X:200:2PP02PX82_ooooo000Zoooo
o`80VFdl0`2JKSd309]_?P060:1]?P2NKSh0WVhn09e_?P2KKch0Vg4o0P2KLd0209U]?080VVhm00@0
Vfln09ea@02NLT40WW91202HKS`809]_@PP0WW910`2PMD8309md@@80WW=000<0WG8o09ic@02PMD80
0`2RMd@00`2QMT<0X7E20:9gA0030:9gA0@0XGI300<0YGY70:=hA@2RMd@00`2QMT<00`2RMd@0XgQ5
0:EjA`020:IkB0040:EjA`2TNDH0Y7U60:=hA@80XWM400<0Yga90:IkB02UNTL00P2SN4D00`2UNTL0
YW]80:MlB@080:ImB@<0YW]80`2UNTL20:AiAP80XgU700<0XWQ60:5gA@2PMT@00P2OMD<04@2NM480
XGM50:1fA02NM480W79009Y`?P2GKC/0UV`j09E[>@2DKSd0Tfdl099/>`2AJcX0SfTh08iX=`2=IcH0
S6He0080SF@h00H0RV@g08QS=P27HSD0Q68d08=S=022HS<3085N=P05081M=@1oG3@0OU/c07eJ<P1l
FC400`1iERh01@1hEBd0Me@/07IC:`1fDb/0ME8Z00<0M54[0`1cD2X2079?:@80JD/W0P1ZC2P306]=
:@0906a>:P1/CbL0KDdV06];901[BB<0K4TS06m9901bBRH0Ld/W0080LTlW00@0Le0X07EB:P1gE2`0
NEH^0P1jEbl04@1oFC80P5/a085L<P22GC40Q5lb08EQ<@26HS00Qf<a08IT=`27ICP0RVDh08aV=`2@
J3L0TVPf09=Y=`2DJCH0Ufdk00@0V6hl0`2IKcd209I/?0@0UF/k0P2DJSX209=X?@80TfPk00<0U6Tl
09AZ>P2DJSX00P2EJc/6099W>P80TFHi0P2?I3L308iS=P<0SF8e00P0TFHi091U>02?I3L0SV<f08eR
=@2<HC@0Rf0c08YO<P@0SF8g102>HcP808mT=`<0S64f00D0SF8g08iS>02>HcP0SV<h08mT>@0208YS
>00308YT=`29Hc@0RF<b0080R6<_00<0R6<^08eX=02=J3@01P2=J3@4095X=0@0TVTe0P2BJ3H209=Y
=`@0U6Xh0P2GJ3`00`2EJC`0U6Tl09=Z?002095[?003091/?02BJ3H0TfTg00D0TfTg00<0TVPf095X
=02AJ3@01P2AJ3@8099X=P0708]V<P2=J3@0SfXf091[=`2AK3P0T6/g08mZ=P0408iY=@@0SfXf00T0
T6/g08mZ=P2>JCD0SFPd08aW<`2=J3@0SVTe091[=`2BKCT0202?JCX908iZ>P80SVTm00<0SFPk08aX
>02;IcD00P2:IS800`29IS00QfDe08MU=@0208IT=080QF<c0P24HS8808EP<`0U081M<`21GS@0PEhd
085N=01oG380OEX`07YG;@1iER`0NU/_07UJ;P1hFBd0MUL[07AE:@1bDbL0L54U06m@901_DB/0KE4Z
06a@:`1XCR/0IDdY069;:@1OBbX0GTXY06A=:`1PBBL0FDDT05I38`1D@bD0D44T04Xl7`15=a`0AcTO
04Dg7@10=1`0?C8L03Ta700203Pa7P0403Pc800c<240<c0Q03<`8@80<RlP0`0a;Ql302TY7`D0:RXP
0P0X:Ql202LY7P0<02HX7@0U9a`09BLL02DW700T:1T092PJ02<W6@0R9AX08B@K020S700P8Qd07b4L
0P0O8Q/301hQ6P<07B0I0`0N8AX301lR6`8082<L200Q91/202<V6`H092LL00<09BHN02@U7@0T9Ad0
0P0T9Ad302<T70808bHM0P0R9A`2024T6`8082<J2@0Q8QX3020S6P808B@K0`0R9A`201lP6004020Q
6@0Q8QX08R<K028S6`808b@L00@092HK02DW700U9a`09BLL0P0V:1d202LY7P0902PV5`0Y9aP0:RPI
02`Z6`0^;1d0<2hO034_800b<240<c4R00<0<S0Q100a;b00200`:Q`0<B/M038/700d;a`0=C0L03Lb
700h=1/0>CDL0`0m=Ah303hf7`80?cLP0P16>R001017>b40B3`R04Tm8`1:?R@204/o9@80C40X00H0
CD4W04i39`1?A2H0DDHV05989@1CBBH505M8:@<0F4TZ0`1HBBP205U::@<0FT/Z00D0G4`X05e=:@1N
CbP0Ge0W061A9P02065C9P07065C901QDbH0He8V06AC9`1VDbP0J5<X06UB:00206YA:100K5HW2P1c
F2/207AI;0<0MEX]00<0MU/^07IK;01fFb`01P1fFb`407UN:@@0NUlZ0`1lH2h607]O;@80NEl^00h0
N5h]07MM;01fG2/0ME/Z07AJ:@1cFBP0K5HT06]E901ZE2<0JE<T06QA9@1WD2H0ITlV06E>9@P0JdlW
101ZCRH206U=9@80J4`T0`1/CbD206e@9P<0KU4W0P1]EBD206aD9080KEDU0P1^ERH0201^E2<0KeDT
06mD9@1`EBH0Ke@W06eB9`1[CbL0JThV101UCbP406A>9`0806A>9@1SCB@0HT`U061:9@1OB2H0GDHV
05a59P1KA2D605=37`80E4@P0P1E@R8205A18@0405I38`1HABD0FdPX05a9:@P0EdLS101CAB0205A6
8@0305E78P1FB2<0DT8Q00<0DT8Q00@0DD4P05107`1@@1l0CclN201>?R@204Q1900304U08`1:?b<0
C3hS0080C3`R00L0CC`R04`k8@1;>b40Bc/Q04Tk8017?200ASdP0080@c`O2019?R800`17>Ah0B3XO
04Pj7`0204Pj7`<0BC/P00L0BS`Q04U08`18?b80AchQ04Dl7`14>ah0@cXM0080@STL2014>Ql804@k
7P0304<l8011>Qh0?cPL0080?CHJ00@0?SLK03lh7010>Ad0?SLM100m=Q`303`e6`80>SDO0P0i=1h0
100h<ad0=c8L03Ha6`0f<A/402/]60@0;2hI00h0;BhN02`]7@0[;1`0:R/K02TZ6P0X:AT09bPH02HW
5`0W:QT09RTH02HX6P0U9aX092HK02<T70808R<M00@08B8J020Q6@0P8AT0824I0P0O81P201hO5`80
7b8K0`0N8AX301dP6@P06Q`I200I6aX801PJ6@<05aTH0`0F61L201DG5PP05QPG8@0E5QP@01@E5`80
5QLI0`0E5QP301@E5`P04ALGD00D5ALY01DF60P05QPG0`0E5aH201HH5`<05aTH600F61L@01LI60P0
6QXJ0`0J6QP301/K6@8071`J200I6AL201LI5P<061XG0`0I6aP801TI5a006a/I200J71/801XJ6P<0
6QXH0`0K6aT201`L6Q@06a/I0`0L71X201dM6`8071dG0`0M7QP301hO6@807QdH00<07ahI020O6P0P
7aX00`0P7aX8028R6P<092@L0P0S8a/;028R6Q008R4L0`0S8a/2028R6P<08B4I200Q81/8024R70P0
7ahI200P8A/3020O6P<08B0K0P0R8A`201lN6@8081lJ0P0Q81/2028Q70P08B0K200P8A/701hO6@80
7b0J200R8ad8024P6a007b0J0`0P7aX301lN6@807QdH200M7A/201`M5`807AhH0P0N7aT201lP6PP0
824K200N7aT201dN60807QlI0P0O81X2020Q6`807ahI0P0P7aX2024P6`808R4L200P8A/3024P6`80
8R4L0`0S8Qd8028S6`808b<K0`0T91`302DU7@P0;BTP0P0]9a/302hX70<0;bTM0`0`:Qh2034[7`<0
<R`P00<0=R`P03D[7`0c:Ad00P0b:1`02P0c:Ad0=B/O03D[7`0f;200=RTP03@Z800c:Al0<RXO034[
7`0^:Qh202d[7PD0;bPN0`0`:Al302/Y7@80;2XN0`0[:Ad802/Y70<0:bLK0P0/:1`00`0]:Ad0;RXN
02l[7`0202XV6P0302/W6`0/:1`0;BTM0080;RXN00H0;b/O02HV700V9Q`09bLM02PX7P0Y:Al202XZ
800302/[8@0X:1h0:2PN00H0:2PN100Y:Al402XZ80<0:RXR:oooool002[ooooo0`2IKC`309Y^?@80
Vfln00H0WV/l09e]?@2MKCd0WFln09a`?`2KLCl209Yb?`80VFdl00@0VVhm09]_?P2LL3l0W70o0P2M
LD0809Q^?0P0Vfm2202NLT420:1e@P<0WgA10`2NLd000`2MLSl0WW=00:1e@P030:9gA0030:5f@`2P
MD80XGI300<0XGI3102RMd@00`2UNTL0XgQ50:9gA0030:5f@`030:9gA02SN4D0YGY70080YW]800@0
YGY70:AiAP2TNDH0XgQ50P2RMd@00`2WO4T0YW]80:EjA`020:=hA@030:EjA`2VNdP0Yga900P0YWe9
0`2VNdP30:EjA`80Y7U600H0XgU70:9hAP2RN4H0XGM50:1fA02OMD<209id@P080:1fAP2OMDD0WG=3
09]a@@2IKcl0UV`l09E[>`2DJSX209=]?P04099/?@2@JS/0SfTj08eW>080S6Hg0P2<HcL02`29HcH0
Qf8e08IQ=023HC<0PV8c085Q<P22GcL0PEhf081M=@1oG3@0OU/c00<0OEXb0P1iERh0101hEBd0Me@/
07IC:`1eDRX207AA:@80Le0Z0`1bCbT3075>:0<0JD/W0P1ZC2P306]=:@0P06a?9`1]CBH0K4`U06a:
901]BR@0L4XU079:9P1cBbL0LDhV079?9`1dDBT0ME8Z07QE;@1iERh0NeP`07aI<@20FS<0PE`b089M
<`23GS80QF0c08IR<P27Hc40R6@b08MU>028IST0RfHi08eW>02@J3L0TfTg09AZ>02EJSL309M]>`03
09Q^?02IKcd0VFlm0080VW0n0P2GKC/209I/>P80UF/i0P2DJSP209=Y>@0309AZ>P2DJC`0UFXm0080
UFXm0P2EJSl6095V>@80TVLj0P2?I3L308iS=P<0SF8e0P2AIST0102@ICP0Sf@g08eR=@2<HC@208]P
<`P0SV<h202@ISH508iS>0<0Sf@i0P2;I3T00`2;ICP0RV@e08YT<`0208UT<00308UT;`2>JCD0SVTe
00H0SVTe102BJCD4095X=080TVPf0P2CJCL409AZ>080UfPl00<0UFTl09AY?02CJS`00P2AJc`0102@
K3`0TfTg09=Y=`2CJCL2099X=P<0TfTg202BJCD8099X=P0808]V<P2=J3@0SfXf091[=`2AK3P0T6/g
08mZ=P2>JCD308eW=P0308iX=`2?JCP0SfTh0080T6Xi00P0SfXf08iY=@2=J3@0S6Lc08eX=02>JCD0
T6/g099]>@P0SfTj2@2>JSX208YU>@0308UT=`28I3@0Qf<a0080QV8^00@0QF8/08IT=026I3@0QV@d
0P25Hc<308AR<PP0QF0c02P0Oe`b081M<`20GC<0P5dc07iK<@1lFBl0NEH/07QE:`1kFc80NET`07MG
;P1eEB`0LU8Y071@9`1_CbH0KThU06i@:P1/D2T0JdlZ06M=:P1TC2P0HDXX05i::@1MBBP0H4//05]6
9`1D@B<0D3lS04hn901<?R<0ACTO040d7015=Ql0@c@M03lc7@0k<1`0>30M03L`7@0g<1h0=c4Q0`0b
;b02034^7`<0<2dN0`0X:1h01P0Y:Al0:RXP02XZ800Z:R00:b/Q02LY7P@09RPM0`0U9a`0200S9aP0
8bLI028V600Q91T082<J01lR6`0O8A`07R0K0`0N8AX301dP6@8071lH0`0N8AX301lR6`8082<L200R
9A`602@W70808bHK0P0U9Qh202@U7@0402<T700R8a/08R<K028S6`<08RDL0P0Q91/3020S6PT08B8J
0P0P8aX2024T6`808RDL0P0S9Qd01P0O81P0824I024R6P0R8a/08b@L02@U7@809BHN0P0U9a`202HX
7@<09bTN00P0:2XO02/X5`0/:AP0;BXI02l/6`0a;Qd0<c0O03@a80@0=C8Q0P0d<B0303<`7`80<b`L
00H0=BhL03H_700h<Q`0>S@L03/e6`0l=Q`3044g7P80@SPO0`13>B00101:?240BcdR04/m8P1<?R<2
04do9080CT0U00H0C40X04e1:@1>@RP0D4DY0556:01CB2P205=99PH0F4TZ0P1GB2T0101GB2L0F4TX
05Q9:01HBBP205U::@80FT/Z0P1MCBT01`1MCRL0GTlV05m@9@1PDRD0HE<V065C901QDbH00P1SDRH0
0`1TDBH0IU4V06QA9`0206YA:0P0JeDV201/ERL;071H:P80LET[0`1bFR`807AI;080MUXX0P1gFbT2
07QL:P80NEd[0`1jGR`607]O;@80NEl^0P1hGRd0301gGB`0MU`[07IL:`1eFbX0KUPV06eG9P1/ERD0
JeDV06UB9P1XDBL0Ie0W06I?9PP0K50X0`1[CbL306Y>9P80JDdU00@0KE0V06iA9`1^DBL0KU4W0P1_
DRP2071C:@80KeDT00<0L5HU075G9P1bF2L00`1bF2L02@1aEb@0LUPU079H9`1bEbP0LEHY06mD9`1]
DRL0Je0U06UC:P0206QB:@80Ie4X0P1VD2L02@1UCbH0Ie8W06IA9P1UCbH0HddV065;9P1OB2H0GTLW
05e69P0205E58@H0E4@P0P1E@R8205A18@0405I38`1HABD0FdPX05a9:@P0F4PT00@0DdDP05A68@1E
Ab80EDLR101FB2<205=38P0305928@1A@B00DD4P00<0DD4P201??bD204Q1900504Y1901:?b<0C3hS
04dm8`1<?2800P1=?2801@1<?280Bc/Q04Xl8@18?B40ASdP0080A3dP2019?R800`19>Qd0BS/N04Xk
7P0204Xk7P@0Bc`O00H0BD0S04Po8P18?b80AchQ04Dl7`14>ah2048i70P0A3XO2014>ah01@12>al0
@CXN040i7@0o>1`0?SLK0080?cPL00<0@3TM03lh7P0o>1h00P0n=ad0100m=Q`0?3DK03`e6`0l=A/2
03/f800403Xe7`0i=1h0>3<M03Pc7@80=c8L0P0Z;1L202/]6080;2hI0P0];aX0200];Qh0;2dM02//
700Z:a/0:BXJ02PY6@0W:1P09RLG0P0V:AP0100U9aT092HI02<U6P0S91`2028S7@<0824I0P0O81P3
01hO5`<07R4J0`0M81T201`O60P06Q`I200H6QT:01LI60<05QPG0`0E5aH801HH5b405AHH400D5AL2
01HG6@<05AHH0`0D5AL8014G5e0051DG:@0E5QP801HH5`<05ALF0P0F61L301LI61P05QPG400G6AP8
01XJ6P<06QXH0`0K6aT201`L6PP06QXH0`0H6QL301TK60806Q`I200J6QP@01/K6@P06Q`K200J6QX3
01XJ60<06a/I0P0L71XC01/K6@<071`J0`0M7A/201`M5`<07AhH0`0N7aT501lN6@03020O6P0Q81/0
8B0K00P08R8J0P0U9Ad202@T70808b<K2P0R8QX@028Q70<08b<K0P0R8QX3024Q6@P08B0K200Q8Q`8
020O6PP0824K0`0P7aX3024P6`808R4L0`0P7aX2024P6`<08R4L200Q81/8020Q6`L07b0J0P0N7aT8
028S7@P08B0K400O81X2024P6`<081lJ0`0O7QT801dM6`<071dG0P0M7QP301hO6@P0824K200O81X2
01dN60807QlI0P0O81X2020Q6`<081lJ0P0Q81/3028Q70P0824K0`0Q81/2028Q70<08b8M100R8a/4
02<T70<092@L0`0U9Ad202HV7PP0;RXQ0`0_9a`3030X7@80<BTN0`0`:Qh2034[7`<0<R`P00<0=R`P
03D[7`0d:Qh00P0c:Ad01@0d:Qh0=B/O03D[7`0f;200=RTP0080=2XP00<0<RXO034[7`0_:al00P0]
:ah2034[7`H0<2XN0`0]:Ad202`X70/0;BTM00@0:BDI02XV6P0[9a/0;2PL0P0^:Qh202l[7`0602XV
6P0[9a/0:bLK02`X700]:Ad0;RXN0P0_:al202HV700302LW7@0X:1h0:BTO0080:RXP00<0:b/Q02TY
7`0Y:Al01P0Y:Al402XZ80@0:BTO0`0Z:R8[ooooo`00:_ooool209Q/>`80VFdl0`2JKSd01`2KKch0
WFXk09a/?02MKCd0WW0o09a`?`2KLCl00P2ILCh0102JKSd0Vfln09a`?`2MLD0209a`?`0309]_?P2J
KSd0VW0n00L0VW0n202KKd8809ib@@040:1e@P2OM440WgA109md@@80WW=00`2MLSl00`2NLd00X7E2
0:9gA0020:9gA0030:5f@`2PMD80X7E200<0XGI30`2RMd@0102SN4D0YGY70:=hA@2RMd@30:5f@`03
0:9gA02SN4D0YGY700<0YGY70P2TNDH30:=hA@030:MlB@2VNdP0YGY70080XgQ500<0YGY70:IkB02W
O4T0202VO4X30:IkB0<0YGY70P2TNDH20:9hAP030:5gA@2PMT@0WgE30080WWA20140WG=109ebA@2M
LTD0Vg1309Y_@P2HKD00UV/n09EZ?@2DJC`0Tfe0099/?`2AJch0T6Xm08iX>`2=IcX0S6Hi08]U>002
08]R=P0<08QR=@26HC@0QF0c089P<P21HC80P60a089O=`21GSH0Oe`d07iK<`1mFS80O5Ta0P1mFS82
07YG;`0707UF;P1gE2`0MU<[07EB:P1dDBT0Le0X079?:@03075>:080L4dW0P1_C2H0101YBbL0JT`X
06Y<:01ZC2P206]=:@80K4hZ0200KU4Y06m?:01]CBH0KD/U06i;9@1aBbH0M4`X07E=:@1aCRH0LTlW
07AA:@1fDb/0N5D]07YG;`1lFC40OEXb085K=022GC<0Pehd08AO<`26HC@0Qf<c08QT<P29IC<0R6Hi
08UW>P2<IcX0SVPi095Y>02DJSP0UF/i09I[>080UF/i00<0UV`j09M]>`2HKS`00P2IKcd01@2JL3h0
V6lk09Q_>`2GKSX0UVdi0080UF`h0P2DJcL01@2CJSH0U6Xh09E[>@2EJc/0UFXm0080U6Tn00<0TfPn
099W?@2@ICP00P2@ICP3095V>@80TVLj0P2?I3L308iS=P<0SF8e00D0TFHi091U>02@ICP0Sf@g08iS
=P0208eR=@0308aQ=02@ICX0Sf@i0080Sf@i0`2>HcP00`2=HSL0SfDc08mU<`0608mU<`<0T6Dj0P2?
I3T308iS>080Rf@i00<0RfDh08]U=P2;IC@00P2;IS800`2;IS40SfXf08mZ=P0608mZ=P0409=Z=P2B
JCD0TVTe099Y=@<0TFPd00<0T6Lc095W=@2AIcD00`2BJ3H309=Y=`80UVLk00<0U6Pk09AY?02CJS`0
0P2BK3d0102AKCd0U6Xh09=Y=`2BJ3H2095W=@03099X=P2CJCL0U6Xh00P0TVTe202BJ3H0202;IS80
SFPd08mZ=P2@JcL0TF`h091[=`2?JSH0SVTe0P2<ISL208eW>00<08iX>@2?JCX0T6Xk091Z>`2?JSH0
SVTe08eX=02<Ic<0SFPd08iY=@2@JcL0TVdi202>J3T908iZ>P80R6<g00H0Qf8e08IR<P25HBl0QF4]
08AP;024HB/208IT=080QF<c0`24HS800`23HC40Q5lb08AO<P0608AO<P0=07iK<@1oG380Oe`b07mL
<P1mFS00NeP^07UF;01gE2X0NUXc07QH<@1fERl0Le</071@:@0206m?:00706i>9`1/CRP0JdlX06U=
:01UBbP0HTXV06199`0205a89`0@05]8:P1F@RL0CSdQ04/k8@1:?280Ac/S04<g8@0n<ad0A3DP048c
7P0n<Ah0>c0N03P`7@0g<1h0>34Q03La8@<0<BhO0P0`;Ah302l/7@<0:2PN0`0Y:Al202XZ80P09BLL
00P08RHG028V600Q9AL082<H01lR6@0N8AX07R0K01dO6P<07R4J0P0M81T301`O60<07R4J0`0O8Q/2
020S70P08RDL0P0U:1d302@W70<08bHK0P0U9Qh0100T9Ad08b@L028S6`0R8a/2024R6P808RDL0P0Q
91/3020S6P0301lR6@0Q8QX08B8J00L08B8J0`0Q91/2028U70<08bHM0P0Q8QX01P0R8a/08b@L02DV
7P0V9al09bPP02PY8@809RPM0P0W:Ah302PZ7`0702T[800`:aP0<B`I038]6P0c;Q/0=2lL03Ha7P02
03Lb7`H0=S4N0P0g<Ql203P_7P0603Ta7P0k<ah0?3@M03df700n=ad0?cPL0P15>Al204Hj80<0Ac/Q
00@0B3`R04dm8`1=?B<0CCdS0P1>?R@304lo9@0604a0:01=@BT0Cd<Y0556:P1CB2X0DdPX0P1CBBH3
05Q9:P<0EdPY0P1FAbP305I79P80EdPW0`1HBBP205a<:00>05]<9@1KC2<0G4dR05i@8`1PDRD0HE<T
065C9P1RDBD0HE0T069?901UD2D0Ie0V06U@9`1ZDBP806YD9@P0JeDV0`1_FBX306iH:@<0KELX0`1^
F2T206mI:P80L5X[201bEb`01P1cEbL0M5PX07AH:01eFBT0MUXZ07MK:`80N5`/0`1iGB/207YN;0@0
Nel]0`1hGRd207MM;0<0MU`[00H0L5XX06mI:01^F2L0K5HW06YC9`1YDRP206M@9`P0KE4Y0`1/D2P2
06]?9`<0JThV0`1^DBL206mB:0<0L5<Y00<0L5@R075E8`1cEbD00P1eFBL00`1fFRP0METW07EI9`02
07AK9@0607EK:01eFbX0LePY075F:@1^DbH0KE8W0P1[ER/206YE:P0:06UD:@1XDbP0Ie8W06MB9`1X
DbH0Ie8W06IA9P1UCbH0I4hW069<9`80HDXX0`1GAb<305I68P80EDDQ00P0F4DU05M4901F@b<0ET<S
05M4901HABD0FdPX05a9:@<0FdTU0`1LBRH205e;9`0305E78P1FB2<0EdTT0080EdTT00P0ETPS05E7
8P1DAR40EDDT05A48`1C@b80DT8Q05518080DT8Q00<0Dd<R05109P1@@2H01P1@@2H204U29@0304Y1
901;@2@0C3hS0080CCdS0P1=?28204`l8P0304Xl8@18?B40ASdP0080A3dP2019?R8404hm7`D0CC`N
0P17?R4204Po8P0404Ln8@15?1l0A3/N04<j7@P0A3XO2015?1l01012>al0@CXN044j7P10>Ad303lh
7006040i7@10>Al0@3TO03lh7P0n=ad0?CHL0P0l=A/01P0k=1X0?3LQ03`g8@0k=R00>SDO03Td7P80
>3<M00<0=c8L02`^6@0/;QT00P0/;QT402d_6P0502`]7@0[;1`0:b`L02X[6`0Y:QX00P0X:AT02@0W
:1P09bXI02LZ6@0V:1X09BLJ02@V6`0S91`08b@N028S7@02024R6P80824I0`0O81P0100N7aL07R4J
01hQ6P0N8AX201dP6@<071lH200J71T801PJ6@T05aTH0`0F61L201DG5P8051HE200E5aHa01@E5`80
5QLI0`0E5QP301@E5`P04ALGD00D5ALY01DF60P05QPG0`0E5aH201HH5`<05aTH600F61L@01LI60P0
6QXJ0`0J6QP301/K6@8071`J200J6QP301PJ5`806A/H0`0J71T801XJ61006a/I200J71/801XJ6P<0
6QXH0`0K6aT201`L6Q806a/I0`0L71X201dM6`807QhL0P0L7AL301dN60<07QlI00<081lJ01lN6@0N
7AP00P0N7AP00`0P7aX08B0K028Q7008028R6P<09BDM0P0T91`302<S6`P08R8J200R8A`3024P6`80
8R4L0`0S8Qd302<S6`808R8J0`0Q8AT8024P6`P08B8L200P7aX8020Q6`<081lJ0`0Q81/2028Q7080
81lJ0P0Q81/3028Q700302<R7@0Q81/08B0K00H08B0K2`0P8A/401lP6P807QlI200Q8Q`8024P6a00
7b0J0`0Q81/2020O6P<07ahI200M7A/0100K71H071dG01`M5`0L7AL201dN60807QlI200P8A/801lP
6P807AhH0P0N7aT201lP6P80824K0P0P7aX2024P6`<08R4L00<08b8M020Q6`0P8A/01P0P8A/3024P
6`808R4L0`0S8Qd3028S6`808b@L0`0T9Ad302@T70809BDM0`0V9Qh802dY80<0<2HL0P0a9ad3038X
7P<0<2XN0P0a:al3038/800303L]8@0f;200=2XN0080<bTM00`0=2XN03H/800f;200=bdQ03LZ8@0e
:b40=2XP03<[800a:al0;b/O02h/7`0]:ah3038/7P<0<B/M100`:Q`0100_:A/0;RPJ02hX6P0_:A/2
030Z70P0;bTM00D0:2@H02TU6@0[9a/0;BTM02hZ7P0302l[7`80;2PL0`0]:Ad302hZ7P809bLM0`0X
:1h;02TY7`0402/[8@0Z:R00:RXP02XZ80<0:BTO00@0:2PN02XZ8P0Z:R80:RXR:oooool002[ooooo
0`2HK3/209U]?0<0VVhm00H0W6Tj09][>`2MKCd0WW0o09a`?`2KLCl209Q`?@0809a`?`2MLD00WG50
09ib@@2MLD00Vfln09Q/>`2GJcX809]a?`P0Vfm2202NLT4309md@@80WW=0102MLSl00`2NLd00X7E2
0:9gA0020:9gA0040:5f@`2PMD80X7E20:1e@P80XGI30P2RMd@20:=hA@030:EjA`2SN4D0XWM400<0
XGI300<0XWM40:=hA@2UNTL00`2SN4D20:AiAP<0YGY700<0Yga90:IkB02UNTL00P2SN4D00`2UNTL0
YW]80:MlB@080:IlC0<0YW]80`2UNTL20:AiAP80XWQ600@0XGM50:1fA02OMD<0WWA20P2MLd401P2K
L4<0VVm209Y_@P2IKT40V6e009M/?`80UV/n0P2BJd00302AJSl0SfPm08iW?02=IS/0S6Dj08]T>@2;
HSH0RV4e08QR=@26HC@0QF0c089P<P80P60a00@0PUlg085N=P1oG3@0OEXb0P1lFC4207eJ<P0907aI
<@1kF300NUL_07QE;@1gE2`0ME8Z07AA:@1cD2P0LDhX00<0L4dW0P1_C2H206i;9@@0JddY0P1/CRX2
06e?:`0F071C:`1aDBX0KdlX06m=9`1`CBL0LddX07I>:P1gCb/0LDhV079?9`1dDBT0MU<[07UF;P1k
F300OEXb07iK<`22G3D0PUdc08=N=025H3@0QV4d08QT=080RFDc0P29IcX01P2<IcX0SfTj099Z>@2D
JSP0UF/i09M/>@80TfTg00H0U6Xh09E[>@2FK3X0Ufdk09Q^?02IKcd209U`>P0;09Q_>@2GKSP0UVdg
09E/=P2DJcD0TfXd09A[=@2EK3H0UV`j09I/?02EJSl00P2DJCl0102AICh0T6@o08mT=`2?I3L2091U
>080TFHi0P2BIcX208mT=`<0SV<f0`2=HSD808mT=`<0T6Dj00<0Sf@i08iS>02>HcP00P2=HSL808iT
<P0=09AY?P2CJ3d0TVLl095V>`2?I3T0SV<h08eR=`2<HCH0RF8g08YS>02:I3L0RfDf08aV=@0208eX
=00308iY=02?JSH0SfXf00H0SfXf0P2CJSH2099Y=@80TFPd0P2@Ic<3091V=0<0TFLe0P2BJ3H01@2E
ISX0UVLk09AX>`2DJC`0TfXl0080TV`m00@0TVhn09E[>@2DJSP0TVPf0P2AIcD00`2BJ3H0U6Xh09E[
>@0809=Z=PP0TVPf00P0RfHb08eX=02?JSH0T6/g095/>02@JcL0SfXf08iY=@80RfDf00@0S6Hg08eW
>02>J3T0SfTj0P2@JS/0202?JSH0SVTe08eX=02<Ic<0SFPd08iY=@2@JcL0TVdi202=IcP908iZ>P08
08]V>P2:ICT0RF@g08UU=@28I380Qf<_08IR;P26Hbd308ES<`<0Q68b0P23HC4808AO<P@0OU/a00P0
OEX`07YG;@1hEB/0MU<Y07QH<P1gEc40M5@^075A:`<0KdlY00L0L50Z06]=9`1ZCRL0J4`W06A:9`1Q
BBD0GdPV0080FdLV0140ED@Z050o9@19>B00ASLP04Di8`15>2D0@SLS03ld8P13=1l0@S<P03ha7P0k
<1h0>2lN03Pa8@0i<B@0>38T034^7`03030]7P80;b`M0P0^:a`402TY7`@0:2PN200U9a`01P0R9QL0
8BDG024U5`0P8aP07b8I01hQ6P807AlJ00@07R4J01dP6@0M81T07B0I0P0L7aP201/N5`<07R4J0`0O
8Q/2020S70P08RDL0`0U:1d00`0T9a`08bHK02<V6`02028U6P809BHN00@092DM02<T700R8a/08B8J
0P0P8AT3024T6`<082<J0P0O8QT9024R6P808B@K0P0R9A`402<V7@06028S6`0S91`092DM02HW7`0W
:200:BXR0P0Z:b<302LY7P80:2XO0`0Y:b0303D^7080=RlM0P0g<1h00`0h<Al0=BhL03D^700203H_
7@0403L`7P0h<Al0>C8P03Tb8080?CDR00L0?CDP03hf7`0n=ad0?cPN03lh7010>Ad0BS`Q00<0BcdR
0P1<?R<204do90<0CChQ0`1>?b8204m08`0604/o9`1<@2P0Cd<Y0556:P1CB2X0DdPX0P1BB2D00`1H
BBX0EdPY05M8:@0205I7:080EDHW00<0E4DV05A5901DAB@00`1EARD305I79P0@05];9`1JBRH0FDXS
05U:8@1JBb00G4hQ05i@8`1PDR<0HE<V069A9@1PCb<0HDhS06=>8`1VCbD0JE0W06YA:0P0JU@U201[
EBH206iI:P80KEPY0P1/EbP306]F9`<0K5LX0P1]F2T206iI:PP0LED]0P1bERL0101cEbP0M5PY07EI
:P1fFR/207MK;080N5`Z0P1iGB/207YN;080Nel]00@0O60^07MM;01gGB`0Med/1@1fG2/0201bG2X0
LE/Z06mI:01]EbP0Je@X06UB:01XDBP0Ie0W201/D2P306eA:@80K50X0`1[CbL206e@9P80KU4W0`1_
DRP01@1`DbT0LU@P07AF8P1fF2@0N5XV0080NU`X00/0NE/W07QJ9P1fGBD0MehV07MN:01gGBX0ME/Z
079G:01`EBH0KU<V06iI;P0206eH;@0306]F:`1ZEBX0JE@Y0080J5<X0P1WDRD01P1WDRL0IU4V06I@
9`1UCbP0IDlZ06A>:@80FTXV0P1IBBD01`1HB2@0EdLS05M78`1GAb<0FdPX05Y79`1IARH00P1HABD0
101IARH0FTLW05a9:@1MBBH205i:9`80Gd/X0P1PC2T00`1QCBX0EdTT05Q:9@0205U;9P0705Q:9@1F
B2<0E4HQ05947`1HB2L0EdLV05E5900305=38P80EDDT201@@2H204U29@0304]29@1;@2@0CClT0080
CCdS0P1>?B<01`1=?B<0C3`R04/m8P18?B40AchQ04Dn8@14?B00201:?b<01P1D@B40Dd0P05=0801C
@200DSlO054n7P80D3dM00@0Cc`L04Dl7`16?B00AchQ0P18?b800`17?R40AC`O04@k7P0804@j7`P0
AC`O0P12>al2044j7P80@3TM0P0o>1`01@11>R00@3TO040i7`0o>1h0?CHL0080?3DK00H0>c@J03dh
8P0m>280?3LQ03/f800j=Al203Td7P0303Pc7@0_<A`0;S0K00D0;S0K00<0;BlJ02X[6`0Z:a/00P0Z
:a/402TZ6P80:2/J00H09bTK02HX6`0U9a`092DM02@U7`0S91h2028S6`808B8J100P8AT0100N8AX0
7B0I01dP6@0M81T201`O60806ahG200J71T801LI60/05QPG0P0E5aH301@F5@P05ALF<@0D5AL201HG
6@<05AHH0`0D5AL8014G5e0051DG:@0E5QP801HH5`<05ALF0P0F61L301LI61P05QPG400G6AP801XJ
6P<06QXH0`0K6aT201`L6PP06a/I00@061XG01TK600I6aP06A/H0P0J71T201/M6QP06a/I200K7A`8
01XJ6P<06QXH0`0K6aT201`L6Q406a/I0`0L71X201dM6`<07QhL0P0L7AL301dN60<07QlI00P081lJ
01lN6@0N7AP07A`G01hM600O7QT08B0K02<R7@P08R8J100U9Ad202@T70808b<K200R8QX8028Q7003
020O6P0Q81/08B0K00808R4L0P0S8Qd0100T8ah08b<K02<S6`0S8a/2028R6P<08B4I200Q81/8024R
70P08B0K200P8A/3020O6P<08B0K0P0R8A`3024P6`<08R4L0P0S8Qd8024P6`X08B8L0P0P8A/301lP
6P807QlI200O81X8024P6a007b0J0P0R8A`2024P6`<081lJ00<07ahI01dM6`0M7A/01P0M7A/201/L
5P<071dG0`0M7QP@020Q6`807AhH0P0N7aT201lP6P80824K0`0Q81/3028Q70808b8M200P8A/3024P
6`808R4L0`0S8Qd3028S6`0302<T700T9Ad092DM00809BHN00@092@L02DU7@0U9Ad09BDM0P0V9Qh2
02LW7`P0;BTP00@0<2HL034W7@0a9ad0<BLM0P0b:1h203<Y7`<0<2XN0P0a:al3038/800303L]8@0f
;200=B/O0080<bTM00D0=B/O03H/800f;200=bdQ03LZ8@0203D[8@0303<[800b;200;b/O0080;R`O
0`0c;Ad00`0b;1`0<B/K034[6`02030Z6P03038[6`0a:QX0<2TI0080;bPH00<0<2TI034Z6P0b:a/0
200a:Ah01P0W8aL0:2@H02/W6`0^:Qh0;b/O030/8080;b/O100^:Qh402dY7@<0:BTO0`0X:1h202LW
7@P0:BTO0P0[:b4202XZ8080:BTO0P0X:1h302TY8B_ooooo000Zooooo`<0V6`k0`2IKC`209Y^?@0@
09aY>P2KJc/0WFdm09i`?`2MLD00Vg4o09Q`?@2GKc`0WG5009ib@@2OLd80WW9109ea@02JKSd0Uf/j
09EY>0P0W790202KKd8809ib@@80WgA10`2NLd0409eb?`0309ic@02PMD80XWM40080XWM400<0XGI3
0:1e@P2PMD800P2PMD800`2QMT<0XWM40:=hA@020:=hA@030:EjA`2SN4D0XWM400<0XGI300<0XWM4
0:=hA@2UNTL00P2RMd@0102SN4D0Y7U60:AiAP2UNTL20:IkB0030:MlB@2VNdP0YGY70080XgQ500<0
YGY70:IkB02WO4T0202VO4`30:IkB0<0YGY70P2TNDH01P2RN4H0XGM50:5gA@2PMT@0WgE309id@P80
WG=10`2IKT<209Q]@P80Ufa100L0UV]0099[@02BJd00TFXo08mX?@2>Ic`0S6Dj0080Rf@i0P2:HCD0
2P27HC@0QF0c08AO<P21Gc40P60a07mO<022GcL0PEhf07iK<`1lFC4207]H<00807eJ<P1nFc<0O5Ta
07aI<@1kF300NEH^07MD;01fDb/207AA:@<0L4dW0P1_C2H306i;9@0406]=:@1/CRX0K4hZ06a>:P80
KDl[0P1^D2`0801aE2`0LU8[071@:@1`CRP0LDhX07A>:@1gCb/0N50/075>9P1bCbL0M54Y07IC:`1i
ERh0NeP`07eJ<P1nFc<0PU`e08=N=024GcD0QF0d08MR=@28I3@0RFDc08YV=029IcX0RVPk08eX>`2?
JCX0TVXi09E[>@2FK3X0Uf`i0P2BJ3H04`2CJCL0U6Xh09E[>@2FK3X0Ufdk09Q^?02JLC/0VG0j09Q_
>@2GKSP0UVdg09E/=P2DJcD0TfXd09E/=02FKCL0Ufhj09M]?@2FJd000P2CJ3h00`2@I3l0SV8m08iS
=P0208mT=`03091U>02AIST0TFHi0080TVLj0P2?I3L308iS=P<0SF8e0`2>HcH208mT=`<0T6Dh0P2A
IS/0102@ICX0Sf@i08mT>@2>HcP208eR=`P0SF@`0100UV]009EZ?`2CJ3d0TFHk08mT>@2=HSL0S64f
08]P=@28HCH0RF8g08YT=`2;ICH0SFLf08iY=@2?JSH0SfXe202@JcL309=Z=P03099Y=@2AJ3@0T6Lc
0080T6Lc102?IC<2091V=080TFLe0P2EISX02@2DJ3/0U6Tl09=Z?02BK3d0Tfdn099^?P2EJcT0U6Xh
099X=P02095W=@03099X=P2DJSP0UF/i00P0TfXf202BJ3H03P2;IS80SFPd08mZ=P2@JcL0TF`h091[
=`2?JSH0SVTe08YT=`2;ICP0S6Hi08eW>P2>J3/0SfTl0P2@JSd0202?JSH0SVTe08eX=02<Ic<0SFPd
08iY=@2@JcL0TVdi202;ICH908iZ>P0808iY?@2=J3`0SFPk08aX>02;IcD0RVHb08UU<@29IS0308ES
<`80Q68b0`23HC4808AO<P0<07eJ<01nFc40OU/a07iK<@1lFBl0NUL]07MD:P1fDbT0MeLa07IF<01c
Dbd0L50Z0P1_CbT06P1`D2X0LE4[06]=9`1YCBH0J4`W06A:9`1QBBD0GTLU05]79P1JARD0Dd4Y04hl
9017=b00A3DN04@h8P14>BD0@SLU03de8P14=B80@S<P03ha800l<200>C0Q03Pa8@0i<B@0>C<U0`0`
;Ah202l/7@<0;R/L0P0Z:R0202TY7`0402PX7P0W9ad09bLM02LW7@<092HK1@0U9a`0200Q9AH08BDG
020T5P0O8QL07R4H01dP6@0M7aX071hI100M81T201`O60806ahG0`0N8AX301lR6`8082<L200R9A`0
100V:Ah09BPM02DX7@0T9a`202<V6`808RDJ0P0U9Qh01P0T9Ad08b@L028S6`0Q8QX0824I01lP60<0
8B@K0P0P8aX301lR6@T08B8J0P0Q91/2028U70<08bHM00T092LN02<T700T9Ad09BHN02LX800Y:R80
:R/S02//900/;BD00P0W:Ah202PZ7`<0:B/P00<0:R`Q03L`7@0g<1d01P0g<1d203</6@0603@]6P0f
;a`0=c0M03Pa7P0i<Ql0>S<P0P12=bD00`12=b<0@SLQ048h7`02048h7@03048i701<?R<0CClT0080
CClT0P1>@2D204m19P@0CSdO101??R00201:?RH0C40X04i2:01AARX0DdPZ05=8:01BB2D0DDLT0P1G
B2T205I7:00405E69`1DABH0E4DV05=49@<0Dd@S0P1DAB@305E69@0@05Y:9P1IBBD0F4TR05M87`1H
BAh0FT`O05e?8P1ODB80HE<V065@901PCb<0H4dR06=>8`1UCR@0JE0W06YA:0P0JE<T201[EBH206iI
:P0406eH:@1/EbP0K5LX06]F9`80JUDV0`1[ERL206aG:0<0KEPY201`E2`2075E9P06079F9`1cEbP0
M5PY07EI:P1fFR/0Me//0`1hG2X207UM:`0407YN;01kGbd0Nel]07aP;PD0MU`[0`1eFbX0201bG2X0
LU`[071J:@1^F2T0K5DY06YC:@1XDBP0Ie0W201/D2P306eA:@80K50X0`1[CbL306e@9P80KU4W0`1_
DRP0101bE200M5HR07MI9@1iFbL207]M:@0;07YL:01iFbL0MehV07QO9`1hGbT0MedZ07IL:`1cFBP0
L5DV06mD9@1_FRd00P1^FB`00`1/EbX0JeHY06YE:00206UD9`0606MB8`1WDRD0Ie8U06MB9`1WDBP0
Ie4Z0P1WDB`0101LC2P0Fd/W05];9`1JBRH205U99@80F4PT00<0GDXZ05a9:@1JAbL00`1IARH00`1J
AbL0FdPX05m;:00205m;:003061<:@1QCBX0HTh[0080HTh[00/0F4XU05U;9P1JC2L0FT`W05Q:9@1F
B2<0DdDP05537P1IBBP0F4PW05I69@0305A48`0305I69@1GAbH0DD4W00L0DD4W0P19@RD01@1;@RD0
Bd0T04do901>?R@0CCdS0080CSdS00D0CCdS04`l8P1;?B80B3dQ04Ln8@0204Dn8@P0BSlS0`1F@b<0
101E@R80E44Q058o7`1A?Qh2050m7@0304<j7@15?1l0AchQ0080BD0S00<0B3lR04Hm8015?1l02014
>Ql804Dl7`03044j7P12>al0@S/O0080@CXN0P10>Ad01P0o>1`0@CXP044j8010>Al0?cPN03hg7@80
?3DK00D0>c@J03dh8P0m>280?3LQ03/f800203Xe7`80>C@N00<0<C<N030b7@0`<Qd00P0_<A`202h`
6`0302d_6P0X:AT0:BXJ0080:BXJ0`0Z:a/02@0[;1`0:B`K02T/6`0X:Q`09bTL02HX7@0U9Qh09BHP
02@U7`0202<T70808R<K0`0Q8QX00`0P8AT07B0I01dP6@0201dP6@8071lH0P0K7QL801XL6@P05aTH
2P0F61L301DG5P<051HE200E5aHa01@E5`805QLI0`0E5QP301@E5`P04ALGD00D5ALY01DF60P05QPG
0`0E5aH201HH5`<05aTH600F61L@01LI60P06QXJ0`0J6QP301/K6@8071`J200K6aT401TK60806Q`I
0P0K7AXH01/K6@P06adL200J6QX301XJ60<06a/I0P0L71XA01/K6@8071`J0`0M7A/301hN708071dG
0`0M7QP301hO6@03024P6`0O7QT07QdH00807A`G00<07ahI024P6`0S8Qd0200R8QX0100V9Qh09BDM
02DU7@0U9Ad202@T70808b<K200R8QX8028Q708081lJ00@08B0K028Q700R8A`08b8M0P0T8ah302<S
6`808R8J0`0Q8AT8024P6`P08B8L200Q81/8020Q6`<081lJ0`0Q81/2028Q70<08B0K0P0R8A`302<R
7@P08B0K200Q8Q`0100R8ad08B8L024R700P8A/301lP6PX07QlI200Q81/@01lP6P808R4L0P0Q81/4
020O6PP07AdK0`0K71H201`M5`<07AhH400P8A/201dN60807QlI0P0O81X2020Q6`<08B0K0P0R8A`3
02<R7@P0824K0`0Q81/2028Q70<08b8M0`0R8a/00`0S91`092DM02DV7P0202DV7P@09BDM0P0V9Qh2
02LW7`P0;2PO100c9Qd203@W7P80=BPO0`0`:Qh2034[7`<0<R`P00<0=bdQ03H/800e:al00P0d:Qh0
1@0e:al0=R`P03H/800g;B40=bXQ0080=B/Q00<0<b/P038/800`;2000P0^;1l203@^7P80<bdM00L0
<R`L034[6`0a:a/0<2XJ03</700b:a/0<2TI0080;RLG00<0<2TI038[6`0c;1`0200a:Ah0100V8QH0
:2@H02/W6`0^:Qh2030/8080;b/O0P0`;2000`0_:al0;RXN02dY7@0202`X700702/W6`0[:b40:RXP
02XZ800Y:Al0:2PN02LW7@0202HV70P0:BTO0`0[:b400`0Z:R00:BTO02PX7P0202PX7P<0:2PP:ooo
ool002[ooooo0`2IKS/209Y_?0<0Vg0m00<0WW9109ea@02KKch00P2KKch00`2MLD00Wg=20:1d@`08
09]_?P0309Q]@02IKT40Vg130080W75400@0Vg1309U^@@2HKD00UW8n0`2GLcl209Qd@080VGE1202N
LT420:1e@0@0Wg@o0P2NLch00`2MLD80WW930:1d@`020:9gA0030:9g@P2QMSl0X7Dn00P0Y7U60P2T
N4L40:=gAP<0XWI500<0YGY70:AiAP2SN4D00P2RMd@00`2TNDH0YW]80:MlB@030:EjA`80Y7U60`2S
N4D01P2ZPDd0ZH1<0:QoB`2WOTX0YWe90:ElB080Y7]70P2UO4P0102TNdL0XgY60:=jAP2RNDD20:5h
A080X7E80P2QMTT0302OM4L0WG9509Y_@P2IKT40UW1109Ma@P2HLT<0VG=409Qb@`2EKd00Tfdn095[
?080TF/n00@0T6Xm08mY?02>J3/0SFLj0P2<IST208]R=P0608US=P27HSD0QV4d085O<@1mGBh0Ne//
0P20GCL0101oG3H0OEXd07aI<`1jEc4207UF<008081J=@1mEc80NE<^07I@:`1dCRT0MDlZ07I@:`1g
DB`306m>:`80KTdZ0`1]C2T2079A;P07075@;@1`Cb`0Kdh[06i=:P1]C2T0K4/X071C:@02079B:@03
07=B:@1dDBT0MU0Y0080Me0Y0100N5<Y07UD:P1jEB/0NeH/07eH;P1nFBl0OeX`081K<@1nEc00PEXa
08MP=`2;I3T0SFLj08]U=P29Hc80Qf4`0P2AIcD3099X=P<0TfTg0P2EJcT01P2FK3X0Ufdk09Q^?02I
Kcd0VW0n09]a?`80V6e00P2GK3l209I[?P80UFXm00D0U6ho09=]?P2BK3d0TF/l08mY>P0208eW>003
08aV=`2;ICH0SV@d00<0SV@d102?ICD3091U>P80Sf@i0`2>HcP808iS=P0308aQ=02=HSD0Sf@g0080
TFHi00<0T6Dh08mT=`2>HcH00`2BIST5095U>0P0S6Lc0P2<HS00102=Hc40SV@b091V=02AIcD2099X
=P0809E[>@2DJSP0TfTg099X=P2AIcD0T6Hd08mU<`2>I38809=W=P0309=Y=`2BJ3H0TFLe0080T6Hd
00H0TFLe099X=P2CJCL0UVdg09E/=P2CJS@2099Y<`0309=Z=02EK3H0UVdg00P0UF/i00@0SFHk08iW
?02>Ic`0SVLl0P2?J3d2091Y?P80SVTe00H0SFPd08aW<`2=J3@0SfXf095/>02BKCT8091Z>`80TFPj
00@0SfTj08iZ>P2>JSX0S6Xj0P2;JcX2091Z>`80SfTj0P2>J3T208eW>0@0SVPi102?JCX208]W=`<0
S6Ph102=JCT208]V>@80RVDh1029I3L208QT<P0608MS<`26HC@0QF0d08EP=P24GcD0Q5hg0P25GSD5
08AM=00308EN=@1hFbl0N5/_00H0MeX^01P0M5@[07=C;01^DBT0JThW06M=:01VCRX0IDh/06I?;@1T
BRT0HTXX0617:01MARL0F4<V05A18`1@?b<0CSdQ04Ll9P15>R@0@cPT040e8`0n<b40?S8R03lc9@10
=2H303Ta9080>30S0`0g;b82038[8`03034Z8P0`:B40;bPP0080;RLO00L0;BHN02X[8`0Y:R80:BXR
02PY8@0W:2009RLO00809BHN00@09BHP02@U7`0T9Al092DO0P0S91h2028S7@P07b8K00@08B@M020S
700P8a`07b8K0P0N8AX201dP6@P082<J100S9Qd202@W7P@09BPO0P0T9ah402<V7@P07b8K00P071hI
01dO6P0M81T07R4H01lR5`0P91H08BDG024U5P808B8L0P0R8ad302<T7P8092DO01408R4M02<R7P0S
8Qd092@L02DU6`0V9QX09bLK02LX6P0W:aX09BTH02<W5P0R9QD08bLF02HZ6@0Y;A`0:blN02dZ6`02
02h[7080;b`M0P0`;Ah01`0a;Ql0;2`P02`]7`0^;1l0<2dN03<]7@0c;Q/00P0e;Q/01P0f<Ad0=c8N
03Pc7`0i=200>SDQ03/f8P80?3LS0P12=Q`01013=ad0A3PN04Hj8017>b4204Pl8PD0C3`S0`1;>b80
101A@BL0D40V05109P1@@2H304lo9@0404hn901B@RP0DT8X0592:080Dd<Y0`1DA2X01P1?@bT0Cd@X
04m4:01?A2H0Cd@T04m58P80CdDQ00<0E4@S05E5901EAB@00P1FARD205M79P0605Q89`1GAb<0EdLS
05Q8901IBBD0FTXV0P1LC2P01`1MCBT0Ge0W065?9`1QCbL0HTlW06A>9`1UCBL00P1VC2L0201WBbH0
J4`W06U=:01[CbX0KE4/06mC;P1`E2l0LED`0P1WD2@00`1XDBD0JE8V06YC9`0206aE:@0806eF:P1]
EbP0KELX06eF:P1/EB/0K5D/06aD;P1[Dbd206]C;`0706eE;`1_Ec40LEXa075J<01`FBd0KeTZ06iH
:@0806mE9080Ke8V00@0L5<W075D:01aE2P0LUDY0P1cERX306iI900406mJ9@1`FbH0L5/V075L9`80
LUdX201eFbX207EK:00607IL:`1eFR/0LeP[075F:`1^DRX0K50X0P1bEbX0101aERT0L5DX071E:01_
E2L206iC9P0306mD9`1]DRD0Je0S0080JTlR00<0Je0S06eB9@1_E2L0201_E2L807YL:PP0MV4/0P1c
GB/0101bG2X0L5XX06iH9P1]EbD206]E8`80K5D/0P1[E2/306YC:P0A06UB:@1QDbH0HE8W05m@9@1M
CRD0Fd`U05U99@1GAbD0ETHT05A48P1EAB<0ETHT05M79@1IBBL0FTXX05];:@1LC2X0201MBbD0201S
BbT0HT/Y065::01NBRL0FdTU05Q8901FB2<0EDLR0`1IBBD205Q890<0EdLS0P1HB2L0101GAbH0ETHU
05E5901DA2<205=38P0805=48`1A@R40Cd0O04ho7P1=?Qd0CSlN04m07`1A@R4204a18@0404]0801:
?al0BSlO04Tn7P80B3dM00@0AS/O04Ll8017?200Ac`P0P18?B4204Tn8P0:04@n7015?ad0AClM04M1
7`18@R00Ad4O04I07P13?A/0@S`J03`h7@80?CTN00<0?SXO03lk800o>b000P10?2401013>Qd0A3/N
04@k7P15?1l204Hm8080AchQ00@0AC/P04@j7`14>Ql0A3XO0P13>Ah2048h7@@0@3TM100o>1`0100l
=AT0?CHJ03df6P0n=a/203lh7080@3TM00P0>cHH03`g6@0l>1/0>STM03Ti7`0d=Qh0<S@L02lc7080
<c4H00@0<c4J038`6`0a;aX0<BhK0P0`;A`02@0d;a/0<RlL030]6P0^;A/0:R/K02LY6`0U:A/092PJ
02PZ700202LY6`0302DW6@0T9QP08bDG00808R@F00H092PI02<W6@0S9aT08RDJ024T6`0P8a`201lQ
70@07B0I0P0L7aP201/N5`806adJ0`0J71T301TK60806Q`K0P0I6aX201PJ6@805aTH400F61L@01DF
68T051DG600E5QP301@E5`@05AHH0P0F5aT801DF61005QPG:00G6AP801TK6QP06a/I0P0I6AL201XJ
600401/K6@0L71X071`J01dM6a006a/I0`0I6aP301XL6@806adJ0P0I6AT201XJ6P0401/K6`0L71`0
71`L01dM7A406a/K200K6aT201hN700401dM6`0L71X071`J01/K6@806QXH0P0M71X301hM6`<07ahL
0P0P7aX201lN6@0:01hM600M71L07A`G01`K5P0T91`08b<K028R6P0Q8AT0820H01lO5`807QhF200R
8QX802DP6PP08b<K0P0R8QX0100S8a/092@L02HV7P0W9al202PX80@08b@L0P0R8a/2024R6P0302@W
7P0S9Qd08B@K008082<J00<08B@K02<V7@0T9ah00`0P81P3024Q6@808R8J200Q81/8028Q70<0820H
0`0Q8AT2028R6P0602HV7P0U9Ad09BDM02@T700S8a/08R8J0P0Q8AT0200O7aL0820H028R6P0U9Ad0
:2PP02XZ8P0/;2@0;RhV200R8QX9020Q6`P07b0J0P0M7QP201hO6@807b0J0P0P8A/301dN600301hO
6@0O81X0824K0080824K0`0O81X3020Q6`808B8L200P7aX301hO6@d07AhH0P0N7aT0100O81X0824K
028S7@0S91h202@U7`P08B0K200O81X8028R6PP08B@K0P0N8AP0100O8QT082<J024T6`0Q91/2028U
70<09BLL0P0V:1d302LY7P0802PT6`0Y9A`0:RHM02/W7P0Z9Qd0:BDL02LS6P0V8QT202/W6`80;2PL
0P0]:Ad202hZ7PP0;bTM0`0b:1`203<Y7@<0=2XN0P0e:1l203HY80@0=bXQ00L0>2/R03@`900c;b<0
<RhR034]8@0`;200;RXN0080;BTM200c:Ad203X/8@0H03T[800h:Ql0=bTN03HX7@0e9a`0=2HK02LU
600X9QT0:bTL02d[7P0^;1l0;B/N02`Z7@0[:A`0<2XN02lY7@0^:1`0;BLK02hX700`:Qh0<R`P03@^
8P0^:Qh0;b/O0P0`;200100_:al0;BTM02/W6`0Z9QX802dY7@P0;bTM200]:B0302DX8B_ooooo000Z
ooooo`<0VFhk0P2JKc`309]`?@80W70o0`2JKSd00`2LL3l0WW9109mc@P0809]_?P0309Q]@02IKT40
Vg130080W75400<0Vg1309U^@@2HKD00102HLcl209Ud@080VWE1202NLT4809md?`0309ea@P2NLT<0
X7A30080XWM400<0XWM20:5f?`2PMCh0202TNDH20:AhA`@0XgM60`2RMTD00`2UNTL0Y7U60:=hA@02
0:9gA0030:AiAP2VNdP0Yga900<0YGY70`2TNDH20:=hA@80ZH1<00@0Z7m;0:MnBP2VODT0YGa80P2T
NdL20:ElB0040:AkA`2SNTH0XgY60:9iA@80XGQ40P2PMDP20:5fB@0609mdA`2MLTD0VVm209U^@@2F
L440Ug520P2HLT<01@2GLD80UFm009=]?P2AJc`0TF/n0080T6Xm00<0SfTl08iX>`2=IcX00P2<IST2
08UP=00C08QR=@27HSD0QF0c085O<@1nGRl0O5`]081M=`1oG3H0OU/e07eJ=01kF380NULa07UF<01h
EBl0OELb07aF<@1jE2l0N58]07I@:`0307E?:P<0Kdh[0P1^CBX306e<:@05075@;@1`Cb`0L4l/071?
;01_CR/00`1^CBX01P1`DbT0LU8Y079B:@1cDRT0M54Y07I@:@80Me0Y0P1iE2X0101jEB/0O5L]07eH
;P1oFS02081K<@08081I<P23G3<0QUlf08YS>02;ICP0RfDf08YT<`28HS42099X=P<0TfTg0`2DJSP2
09E[>@0409I/>P2GKC/0V6hl09U_?@80VW0n0P2HKD0209M/?`80UV/n0P2EJSd01@2DKSl0Tfdn099/
?@2AJc`0SfTj0080SFLh0P2<ISL508mU=@<0T6Hf202?I3T808iS=P0308aQ=02=HSD0Sf@g0080TFHi
00<0T6Dh08mT=`2>HcH00P2BIST6095U>0P0S6Lc0P2=Hc40102>I380SfDc091V=02AIcD2099X=P06
09E[>@2DJSP0TfTg099X=P2AIcD0T6Hd0P2?IC<809=W=P0309AZ>02BJ3H0TFLe0080T6Hd00H0TFLe
099X=P2DJSP0UVdg09E/=P2CJS@2099Y<`0309=Z=02EK3H0UVdg00P0UF/i102>Ic`208mX?@80T6Tn
00<0SfXf08iY=@2=J3@00P2=J3@00`2?JSH0TF`h099]>@08091Z>`80TFPj00@0SfTj08iZ>P2>JSX0
S6Xj0P2;JcX2091Z>`80SfTj0P2>J3T208eW>0D0SVPi0`2?JCX308]W=`80S6Ph102=JCT208]V>@80
RVDh0`29I3L01P28HcH0R6@b08QT<P27Hc<0QV4d08EP=080Q5le00@0Pedf08IO=P25GSD0QEhe0P24
GC@308=L<`@0MeX^101fFBd01P1eEB`0Le</06iA:@1[CbP0IddX06I>:P80ITl]00h0Hd/Y069::01O
B2P0GDHW05Q39P1D@2D0D3lS04ln9014?2D0@c/T040h8`0n=R<0?3@Q03`c8P80?C@U0P0i<B@203P`
8`<0=blR00L0=RhQ030/8`0_:b80;b/R02hZ8@0]:B00;2PO0080:bLN0P0Y:R800`0X:B409bPP02HW
7`0202DV7P0302@U7@0T9Al092DO008092DO0P0S91h2028S7@P07b8K00<08B@M020S700P8a`00P0O
8Q/201hQ6P0301dP6@0P8aX082<J00H082<J00@08RDL02<V7@0S9Qd08bHM0P0T9ah402DX7`8092LN
0`0S9Qd00`0R9A`07b8K01lR6`0601lR6`807AlJ00L07R4J01hQ600O8QL082@F024U5`0Q9AH08B8L
00<08R<M0P0S91h302@U7`0902<R7P0S8Qd092<N02DU7@0V9Q`09bLK02LX6P0X:A/09b/J00@09RXI
00<0:2`K02T]700Z;Qd01@0_;1d3030]7P0>02`]7`0];R00;bdN034^7`0d;Qh0=BhL03H_700g;a`0
>C<M03Xd7P0k=Al0?3HP03dg8@0n>28203li8`06048f7013=ad0A3PN04Di7`16>R00Ac/Q0P18?286
04`l8`80Bc/R101??bD405109P<0DT8X0P1C@bT305A4:P0604m3:@1?A2P0Cd@X04m49P1?A2@0CdDR
0P1?AB400`1DA2<0EDDT05E5900405E5900:05I69@1FAR80ETHR05M78`1HB2@0FDTU05Y:9P1KBbL0
G4`X05i?9P80H4hV00<0HDhV06==9P1TC2H00P1UBbH806Y>:@80ITlS00H0Ie0T06QA9@1YDRH0JU<W
06]D:01/EBT206aF9`0306aE:@1[E2X0Je@[0080JU8/0P1ZDRh01`1[Dbd0KED_06mH;`1_F2h0KeP/
06eG:01/ERL0201^Db@3071C9`<0LE@X0P1bEBT306eH8`80KUTT00@0KeXU071K9P1`FbH0L5/V201e
FbX207EK:00707EK:P1eFR/0LeP[075F:`1^DRX0K50X079G:P02075F:@80L5DX0P1_E2L0101^DbH0
Ke@W06eB9@1/DB@206]@8`0306aA901]DRD0Ke@W00P0Ke@W00D0MeTW07QJ:01hFRP0N5XX07UK:@03
07YL:PP0Mf0/00H0MEl]07AN;01cGB/0LE/Y071J:01^F2H206eG9@<0K5D/0P1[E2/306YC:P0@06AC
9`1SDRH0HU4V061>9P1NC2H0G4XV05Y8901IARD0Ed@S05Q5901IARD0FTLV05]89`1LBBP0GDXY05i;
:PP0G4XT00H0HDTW06199`1OB2H0G4PU05]99@1HB2@205I88`<0FDTU0P1HB2@305M78`80F4PW00@0
EdLV05I69@1EAB@0E4@S0P1C@b800`1CA2<0DT<R0511800304ho7P0404m07`1@@B00C44Q04a18@80
Bd0P00@0BSlO04Tn7P19?Qh0BChN0`17?20204Pm8@<0BChR00@0A3hL04Do7@15?ad0Ad4O0P18@R00
1017@Al0AT0N04Do7@0o>Al2040j8080@C/Q0P12?2800`13?B<0A3/N04@k7P0204Dl7`80ASdP0P17
?R4204Hl8@80AC/P0P14>Ql204<i7PD0@3TM0`0o>1`203df6P80?SLK0P0o>1`2040i7@0803/f600l
=aT0?3PK03Xi7@0h>1h0=3HN038d700_<a`203@b6@0403<a6P0b<1/0<S0K034^6`80<2dL00H0<bhJ
034^6`0`;AX0;RdK02X[6`0X:Q`202HZ700502PZ700W:A/09bTK02HX6P0T9QP00P0S9AL01`0R91H0
92PI02<W6@0S9aT08RDJ024T6`0P8a`00P0O8A`0100N8AX07B0I01dP6@0M81T201`O60806ahG0`0K
7AX201XL6@<06A/H0P0J71/201TK6P8061XI0P0G6AP@01HH5a005AHHR@0D5ALH01DF60<051DG100E
5QP201HG6@P05AHH400F61LX01LI60P06A/J600K6aT201TI5`806QXH00@06a/I01`L6P0L71X071`J
400K6aT301TK60<06Q`I0P0K7AX201TI6@806QXJ00@06a/K01`L700L71`071`L4@0K6a/801/K6@03
01hN700M7A/07AdK008071`J0P0K6aT00`0J6QP07A`J01dL6P0301hM6`<07ahL0P0P7aX201lN6@80
7QdH0P0M71L3028R6P808B4I0`0P81P8028R6PP09B0J200S8a/01@0Q8AT08R8J028R6P0S8a/09BDM
00809RHN00<09bLO02DU7@0T91`00P0T91`202<S6`808R8J00<08bHM028U700P8aX00P0O8QT00`0P
8aX08RDL02<V7@03020P60808B4I0`0R8QX8024P6`P08R4L0`0P81P2024Q6@<08R8J0`0T91`302<S
6`808R8J0P0P81P0100R8QX092@L02HV7P0X:20202XZ8PP08R8J2@0P8A/801lP6P807AhH0P0N7aT2
01lP6P80824K0P0M7QP201hO6@807b0J0P0P8A/301lP6P<0824K0P0Q8Q`8020O6P@07QlI300M7QP2
01hO6@0601lP6P0P8A/08B8L028S7@0S91h092DO200Q81/801lP6PP08R8J200P8aX201hQ600301lR
6@0P8aX08B@K00808RDL00@08bHM02HV700V9Q`09RHL0P0W9ad302PX7P0302PT6`0Y9A`0:RHM0080
:bLN00<0:BDL02LS6P0V8QT00P0[9a/202`X7080;BTM0P0^:Qh802lY7@80<RPL0`0c:Ad303@Z7P04
03DY7@0f:Qh0=RXN03HZ7P80=b/O0`0h;20203<`8@03038_800a;Ql0<2dN00<0;b`M200c:Ad203X/
8@0403T[800h:Ql0=bTN03HX7@80=BLL00<0:BLJ02XX6`0/:Qd00`0^;1l0100]:ah0;2XM030Z7P0_
:Ad302hX7003030Z7P0b;200<bdQ0080;RXN00H0;b/O030/800_:al0;RXN02`X700Z9QX802dY7@P0
;bTM200]:B0302HY8R_ooooo000Zooooo`<0VFhk0P2JKc`309]`?@0809Y^?@2IKC`0VFdl09Q/>`2I
KC`0VVhm09]_?P2LL3l809]_?P0309U^@@2JKd80Vg130080W75400<0Vg1309Y_@P2IKT400`2HLcl2
09Ud@0<0VWE1202NLT4809md@@0309ea@P2NLT<0X7A30080XWM400<0XWM20:5f?`2PMCh0202SN4D2
0:AhA`@0XgM60`2RMTD00`2UNTL0Y7U60:=hA@020:9gA0030:AiAP2VNdP0Yga90080YW]80P2UNTL3
0:AiAP030:=hA@2XOd/0Z7m;0080Ygi:00@0YWe90:ElB02TNdL0Y7]70P2UO4P0102TNdL0XgY60:=j
AP2RNDD20:5hA080X7E80P2QMTT0102OM4L0WG9509Y_@P2IKT4209I`@@80Ug5200@0UW1109A^?`2B
K3d0TF/l0P2@JSd0102?JC`0SVPk08eW>P2=IcX208aV>@0>08IM<@27GS80QV0c08IQ=025H3<0PV0b
07mO<01mGBh0Oe`f07iK=@1mFS@0O5Tc07]H<P1iES0207QE;`@0NU@_00@0N58]07I@:`1dCRT0LddX
0`1_CR/206i=:P<0KD`Y0P1^CBX306m>:`<0L4l/00H0L5<Y079B:@1bDRT0Le8Y07AA:@1fD2T207M@
:@0>07UD:P1jEB/0NeH/07aG;@1nFBl0OeX`081K<@21G380Q5df08EN=@26GcH0R64f08US=P2:I3D2
08]U=0<0U6Xh0`2EJcT209I/>P80UF/i00@0UV`j09M]>`2HKS`0V6hl0P2IKcd209Q]@080Uf`o0P2F
Jch209EZ?@80Tfdn00<0TV`m091Z>`2?JCX00P2>J3T00`2=IcP0S6Hg095V>@02095V>@D0T6Dh00D0
S64f08eR=`2=HSL0SV<h08mT>@02091U>P03095V>`2>HcH0SV<f00H0SV<f00<0S64d08eR=@2?I3L0
0P2AIST00`2@ICP0Sf@g08iS=P08095U>0P0SFPd0P2>I380102?IC<0T6Hd095W=@2AIcD2099X=P80
U6Xh0P2CJCL0102BJ3H0TFLe091V=02@IS@809=W=P0309AZ>02CJCL0TFLe0080T6Hd00H0TFLe09=Y
=`2DJSP0UVdi09E/>02CJSH2099Y=@0309=Z=P2EK3P0UVdi00P0UF/i0`2>J3/208mY?0<0T6Xm00<0
T6/g08mZ=P2>JCD00P2=J3@00`2?JSH0TF`h099]>@08091Z>`80TFPj00@0SfTj08iZ>P2>JSX0S6Xj
0P2;JcX2091Z>`80SfTj0P2>J3T208eW>0P0SVPi00@0RVHf08]W=`2;IcL0RfLg0P2<J3P308eY>@<0
RVDh0P29I3L308QS=P0808QT<P27Hc40Qf<c08IQ=025H3@0Q5le08=N=023GCH308EP=P0508AO=@22
GC<0PE`b07mJ<01nFBl00P1gFS0207II;`80MEP^0P1dEbd01P1dE2/0Le</06mB:P1/D2T0JDlZ06M?
:`80ITl]00h0I4//065::P1OB2T0FTDX05I29`1B@BL0CclU04hn9@13>b@0@CTR03lg8P0m=B80?3@Q
03/b8@80>c8S0P0g<B<203H`8P<0=BlQ00H0=2hP02l[8P0_:b80;RXQ02dY800/:1l202/W7P0702XV
7@0Y:R80:2TQ02PY8@0W:2009RLO02DV7P0202@U7@<092DO0P0S91h3028S7@P07b8K100P8a`201lR
6`807R4J200Q91/3028U70808bHM1P0T9ah202<V7@<08RDL200O8Q/201dO6P0301hQ6P0O8QT082<H
00808BDG00<08RHG028S6`0R8a/00P0S91`302@U7@809BHN00H092<N02DT7`0U9Ad09RHL02LW6`0X
:A/202TZ6P0502P[6P0Y;1/0:RdL02/^7@0/;ah00P0[;Qd00`0Z;A`0<2dN030]7P02030]7P@0;b`M
00P0<2hQ030^7`0b;b00=BlO03L`7P0i<Ah0>C4L03`a7@80?SHQ00@0?cLR040h8`10>2<0@CTT0P12
>RD01P13=ad0A3PN04@h7P15>Al0ASXP04Lk8@80B3`R201<?2<01@1=?B<0CShT04hn901??bD0D40V
0080DD4W00@0DT8X05519`1A@BL0DD4W0P1B@RP305=3:@0604i2:01>@bL0CT<W04i39@1>@b<0CT@Q
0P1>A20405A48`@0Dd<R0P1EAB400`1FAR80EdLS05Q8900205U99@0705Y:9P1LCB@0GT`T05i<901O
C2@0HD/T069:900206=9900506Y>:@1YCBP0JDdX06Q<9`1VBRD00P1UBB@01P1TB2<0IDhR06E>8P1V
Cb<0Ie0T06QA9@80JE8V00H0JU<W06YD9@1ZE2D0JU<W06UB:01YDRT206Q@:P80J50/00D0JE4[06YB
;01/EB`0K5D[06aE:@0206]E9PP0KU<V101aE2P3071C9`0306mB9P1/ER@0K5HT0080K5HT0P1]EbD3
06iH9PP0M5XY0P1dFRL01P1eFbX0M5TZ07=H:`1aER/0KU8Z06eA:@<0LEHY0P1`EBP406mD9`0606iC
9P1]DRD0K54T06aA901]DRD0KU<V2@1_E2L207AF900607EG9@1gFBL0N5XX07UK:@1jG2X0Ned[201i
Gb`01P1gHBl0MV0^07EO;@1dGR`0LU`Z075K:@80L5XX0`1]ER`206aE:`<0Je@Z00P0IE@V06AC9`1S
DRH0HE0U05m=9@1MBbD0G4XV05]99@<0FTPT00<0FdTU05a:9P1MBbL00P1NC2P805a:900605i6901M
AR@0GDHT05]7901JB2@0F4PT0P1GBB@305U99@80F4PT0`1GAb<205Q89`0405M79P1FARD0EDDT05A4
8`80Dd<R00<0Dd@S05938P1@@B000`1?@1l20511800404a18@1;@200Bd0P04]080<0BSlO00<0BChN
04Ll8018?B400P18?B4204Tn8P80BSlS00D0AchM04Po7P18?ah0BT4P04]28@0304a38P0304]28@13
?200A3dQ0080A3dQ0`15?R801016?b<0AC`O04Dl7`15?1l304Hm8080AchQ0`17?B8204Hl8@<0AC/P
2010>Ad303hg6`<0?cPL0P10>Ad203`g6@0603`h6`0i>1`0>3PN03@f7P0b=1`0<3@M0P0e<aX0100d
<Q/0<c4L038`6`0a;Q/2030]7006038]6@0`;AX0;b`I02h]6`0[;1`0:B/M0P0X;1h01P0X:Q`09bTK
02LY6`0V:1X09BLI02@V60808bDG00H092PI02<W6@0S9aT08RDJ024T6`0P8a`201lQ70<07R4J0P0M
81T301`O600401`N6`0K7AX06adJ01/M6P806Q`I0P0I6aP201XL6`806A/J0P0H6QT201LI61005QPG
400E5QR901@E5aP05AHH0`0D5AL401DF60805QLI200E5QP@01HH5bP05aTH200I6aXH01/K6@<06QXH
0`0K6aT201`L6Q006a/I0`0I6aP301XL6@806adJ0`0J6QX301/K6`8071`L4@0K6a/801/K6@<07AdK
0P0L71X301/K6@807A`J0`0N7A/301lN708081lJ0`0O7QT301hM6080820H0P0Q8AT4028R6PP08b<K
200V8A/802@T7005020P600Q8AT08B4I028R6P0S8a/00P0T91`402DU7@8092@L0`0S8a/00`0R8a/0
8B8J020Q6@03020Q6@04024R6P0R8a/0820H020P60808B4I0`0R8QX00`0S8a/08B0K024P6`06024P
6`P08R4L0P0P81P2024Q6@<08R8J00<08b<K028R6P0R8QX00`0S8a/302@T70808B4I00<08R8J02<S
6`0T91`00P0U9Ad00`0V9Qh08R8J028R6P06028R6PT0824K200O81X201dN60807QlI0P0O81X2020Q
6`0401dN600N7aT07QlI01hO6@<07b0J00@0824K01lP6P0O81X07b0J0`0P8A/2024R70P081lJ4P0N
7aT00`0O81X0824K024R7002028S7@0302<T7P0Q81/08B0K00H08B0K200O81X8028R6PP0824I00H0
7b0H020Q6@0P8AT08B8J028S6`0S91`202@U7@<09RHL0P0W9ad302PX7P0302TU700Z9Qd0:bLN0080
:bLN00<0:BDL02PT6`0V8QT00P0[9a/202`X7080;BTM0P0^:Qh802lY7@04038X700c:Ad0<bTM03<Y
7@80=2XN0P0e:al203HZ7P80=b/O100h;200100i;B40=2hP03@^800d;R0503<]7`P0=2XN0P0i;B40
100h;200=b/O03HZ7P0f:Qh203DY7@0602dY7@0^:Qh0;b/O030/800a;B40<2`P0P0_:al0400`:Qh0
;bTM02lY7@0^:1`0;bTM030Z7P0a:al0<R`P02dY7@0^:Qh0;b/O030/800_:al0;RXN02`X700[9a/8
02dY7@P0<2XN200]:B0302TZ8R_ooooo000Zooooo`<0VFhk0P2JKc`309]`?@D0V6`k00<0VFdl09Y^
?@2JKSd0202KKch309Y_@P80Vg130`2JKd8209Yb?`80Vg=00P2LM44209ee@PX0WW91102OLd820:1d
@`0309ea@P2NLT<0X7A30080XWM400<0XWM20:5f?`2PMCh0202SN4D20:AhA`@0XgM60`2RMTD00`2U
NTL0Y7U60:=hA@020:9gA0030:AiAP2VNdP0Yga900<0YW]80P2UNTL30:AiAP<0Ygi:00<0YWe90:El
B02UO4P00P2TNdL20:ElB0040:AkA`2SNTH0XgY60:9iA@80XGQ40P2PMDP20:5fB@0409mdA`2MLTD0
VVm209U^@@<0UW1100D0UFm009A^?`2CKCh0TV`m095[?002091Z?@0408mY?02>J3/0SFLj08aV>@80
RfDh00P0Q5/_08EL<025Gc80QF0c08AO<P21Gc40Oel`07iN;`80OU/e00@0OEXd07]H<P1jEc40N5D_
0P1gE2h0201gDB`0N58]07YD;`1kEC00NU@_07MA;01dCRT0LD/V0`1_CR/206i=:P<0KD`Y00H0K4/X
06e<:@1^CBX0Kdh[071?;01aD2d2079A;P06075D:P1cDbX0Le<Z07AC:P1eDRX0Me4Z0P1hDBX02@1j
EB/0NeH/07aG;@1mF2h0OeX`081K<@21G380PUdc08MP>@0208MP=`0508MP=@28HSD0RV@e08aV=@2=
IcH00`2EJcT309I/>P80Ufdk0P2EJcT209I/>P0409M]>`2HKS`0V6hl09Q^?080V6e00P2GK3l209I[
?P80UFXm00D0Tfdn099/?@2AJc`0T6Xk08mY>P0208iX>@80SFLh0P2BIc`4095V>`80T6Dj0P2;H3D0
102<HCH0SF8g08mT>@2@ICX2095V>`P0SV<f00<0S64d08eR=@2?I3L00P2AIST0102@ICP0Sf@g08iS
=P2@I3L4095U>0<0TVHi202>JCD00`2?IC<0T6Hd091V=002095W=@80TVPf00<0TfTg09AZ>02DJSP0
0P2CJCL2099X=P80TFLe202DJ3L00`2DJSP0TfTg099X=P02095W=@06099X=P2CJCL0U6Xh09I/>P2E
JcT0TfTg0P2BJ3H00`2CJCL0UF/i09I/>P0809AZ>080SVPi0P2?JCX2091Z>`80TF/l00<0TF`h091[
=`2?JSH00P2>JCD00`2?JSH0TF`h099]>@08091Z>`80TFPj00@0SfTj08iZ>P2>JSX0S6Xj0P2;JcX2
091Z>`80SfTj0P2>J3T208eW>0@0SVPi102=IcP208YV=P<0RfLg102<J3P208YU>0<0RF@g0`28HcH2
08MS<@0608IR<P25H3<0QF0d08AO=@23GS@0Pedf0`23H3H01@22GcD0P5dc07eJ<01kF2h0NEH/0080
MUTa0P1eF3002P1dEbl0LeH^079E;@1bEBd0Le<Z07=C;01_DRX0KE4Z06U?:P1WCb/206E>;006069;
;01PBBX0FdHY05M3:01B@BL0CclU0P1=?bD02010>R80?cTQ03dg8@0l=B80>S<P03Tb800i<R80>34Q
0`0c<243038_8080<BhO0P0]:R400`0/:B00:bPO02XW7P0202TV7@0702PU700X:B409bPP02LX800V
9al09BHN02@U7@0202<T708092DO0P0S91h2028S7@808B8L200O8Q/6020S70807b8K200Q91/3028U
70<08bHM100T9ah302<V7@<08RDL200O8Q/0200M7aX07R0K01hQ6P0O8QT082<H024U5`0R9QP08RHG
0P0S9AX202@V6`D09BLL0P0V9Qh02@0W9ad0:2PL02TZ700Z:a/0:b`L02//6P0Z:a/0;2dM02h_7`02
030a8@0302l`800/;Ad0:b`L00<0<BhO0P0`;Ah302l/7@08038_800c<240=BlO03Pa7`0j<Ql0>c<N
03hc7@0o=1h2044i8P03048j8`13>b@0@c/T00<0A3`U00<0A3PN04Di7`15>Al00P16>R0204Lk8@04
04Pl8P1;>b80Bc/R04/k8P@0C3`S00T0CCdT04`l8P1=?B<0CShT04lo9@1@@2H0DD4W0592:01C@bT0
0P1@@2H305519`<0DT8X00H0CT8X04i39`1>@bL0CT<U04i38`1>A24204i48080E4@S0P1C@b820592
8@80DD4P0`1EAB400`1FAR80EdLS05M78`0205Q8900605]<8`1MBb<0GD/S05i;8`1PBR<0HDTS0P1R
B2<306I:9@80IDTT0`1TB2<306E>8P0306I?8`1WD2@0Ie0T0080J54U0P1YDb@00`1XDBD0J54W06M@
9`0206M?:@0706I>:P1WCb/0IdlY06Q@:P1XDBP0JE8X06UB9P0206UC90P0KE8U0P1bEBT0101aE2P0
L5<W071C9`1_DRH206iA9@D0JeDT101/ERD807=I:080LeTV00H0M5XY07AI:P1cF2/0LEH[06iB:P1]
DBT8071E:00306mD9`1^DbH0KU<V00@0KU<V00<0Ke@W071E:01`EBP01P1`EBP2079D8P0607AF901e
EbD0MeTW07UK:@1jG2X0Ned[201jH2d207QR<00407MQ;`1fH2h0MEl]07AN;080Led[0P1_F2`206iG
:`<0KEHZ00L0K5DY06ME9@1VE2H0IE<U06AA9P1RCbD0H4dU0080Gd/V0P1MBB@405i:9@80Gd/V201K
BB<01P1LA280Fd@R05a58`1JAR<0FDLS05Q89080EdTT0`1IBBD205Q890<0EdLS0P1HB2L0101GAbH0
ETHU05E5901DA2<205=38P80DT<R00<0DD8Q0511801@@B000`1@@B0804]0800404Pm8@19?R80BChR
04Tn8P80BSlS0P1;@2@01`19?Qh0BSlO04Xo7`1;@200CD8R04i38`1?A2@00P1@ABD204Ho8PH0Ad0S
1P16?B0204Ln8@<0B3hS0P17?B8304Hl8@@0@3TM1011>Qh603lh7080@3TM0P0m>1X03`0k=aX0>CPL
03Lg7@0d=Qh0<cDM034e7P0g=A`0=S@K03Dc700d<Qd0<c4L038_700a;Qd0<2dL034/600202l/6@03
02h]6`0/;Ad0:bdO0080:RhP0`0W:A/00`0V:1X09BLI02DW6@0202@V600602@X6@0S9aT08bLI028U
6P0Q91/082<L0P0O8A`301hQ6P<07B0I0P0L7aP201`N6`<06adJ0`0J71T201XL6`806A/J0P0H6QT2
01LI61005QPG400E5QR901@E5aP05AHH0`0D5AL401DF60805QLI200E5QP@01HH5bP05aTH200I6aXH
01/K6@806QXH5P0K6aT301TK60<06Q`I0P0K7AX201XJ6QL06a/K200K6aT801`L6P807A`J0`0N7A/3
01lN708081lJ1P0O7QT201lO5`06020P600Q8AT08R8J02<S6`0T91`09BDM200S8a/802HQ6`P092@L
0P0P81P2024Q6@808R8J0P0S8a/302LT7@<09R<L0P0U8Q/00`0R8QX08B4I024Q6@04024Q6@04028R
6P0Q8AT08B4I024Q6@<08R8J0P0S8a/@028Q70<08B4I0`0R8QX202<S6`808B4I00<08R8J02<S6`0T
91`00P0U9Ad00`0V9Qh08R8J028R6P04028R6P808B4I200R8QX9024R70P0824K0P0M7QP201hO6@80
7b0J0P0P8A/401hO6@L07b0J0`0P8A/2024R70P081lJ00<07AhH01hO6@0N7aT00P0N7aT301lP6PT0
7QlI0P0O81X2020Q6`808B8L00<08R<M024P6`0Q81/01P0Q81/8020Q6`P08R8J2P0Q8AT0100R8QX0
8b<K02<S6`0T91`202DU7@<0:2DL0P0Y9Qd302XW7P0802TU700Z9Qd0:bLN02`X7`0[9ah0:RHM02PT
6`0W8aX202/W6`80;2PL0P0]:Ad202hZ7PP0<2XN0`0c:Ad203@Z7P<0=B/O0P0g:ad203P/7PD0>BdO
0P0d;Ad303D^7P<0=RlO200d:Qh203L]8@80=R`P00@0=B/O03@Z7P0d:Qh0=2XN0P0b;20603<]8@80
<2XN0`0_:Ad2030Z7P09034[7`0/:1`0;BTM02l[7`0`;200;b/O02hZ7P0]:Ad0;2PL00P0;RXN200a
:al802hZ8@<0;2`R:oooool002[ooooo0`2IKS/209Y_?0<0Vg0m00@0UVXi09M[>P2GJcX0V6`k102I
KC`809]_?P0309]`@`2JKd80VVm200@0VVm200@0Vg1309ab@02LLT00W7900P2MLd4309id@PP0WW91
00<0WG5209ib@`2NLT<00P2OLd@20:1dA@040:5eAP2MLD80WW930:1d@`80XWM400<0XWM20:5f?`2P
MCh0202SN4D20:AhA`@0XgM60`2RMTD00`2UNTL0Y7U60:=hA@020:9gA0030:AiAP2VNdP0Yga90080
Yga90P2VNdP20:EjA`80Y7U60`2VODT40:ElB0040:AkA`2UO4P0YGa80:AkA`80XgY600<0XWU50:5h
A02QN4@00P2PMDP20:5fB@0909mdA`2MLTD0VVm209U^@@2FL440UFm009A^?`2CKCh0TV`m00<0TF/l
0P2?JC`0102>J3/0SFLj08eW>P2<IST208]U>00308=J;P24Fbl0Q5ha0080Q5lb00<0P5h`07iN;`1m
GBh00P1mFS@0101lFC<0NULa07UF<01gE2h207IC;@0807I@:`1gDB`0NE<^07YD;`1iDbh0Me4/07A>
:@1bC2L306m>:`80KTdZ0`1]C2T01P1[BRL0K4/X06e<:@1^CBX0L4l/075@;@80Le8_00H0LE@Z07=C
:P1cDbX0M5<Z07EB:P1gDBX207QA:P0@07]F;01lEbd0OEP^07iI;`20Fc40PE`b089M<`23GS@0RF8k
08UR>@28HCP0R64f08US=P2;ICH0S6He08eW=P<0UF/i0`2FK3X209M]>`0309E[>@2FK3X0UV`j0080
UV`j0`2GKC/209Q]@080Uf`o0P2FJch209EZ?@04099/?@2AJc`0TF/l091Z>`<0SfTj0P2>J3T2099W
?@80TFHl0P2@IC/208mT>P0808YO=02;H3D0S64f08eR=`2>HcP0Sf@i091U>P2AIS/808iS=P0308aQ
=02=HSD0Sf@g0080TFHi00<0T6Dh08mT=`2>HcH00`2@I3L00`2AICP0TVHi099V>@0209=W>PP0SfXf
0P2AIcD4099X=P80TfTg0P2DJSP409=Y=`80TVPf202DJ3L00`2EJcT0U6Xh099X=P02095W=@06099X
=P2DJSP0UF/i09I/?02EJc/0TfTi0P2BJ3P00`2CJCT0UF/k09I/?00809AZ>0<0SfTh0P2@JST3095[
>P03099]>@2AK3P0SfXf0080SVTe00<0SfXf091[=`2AK3P0202@JS/2095X>P0408mY>P2>JSX0SVXj
08aZ>P80Rf/j0P2@JS/208mY>P80SVPi0P2=IcP00`2?JCX0SVPi08iX>@0208eW>080S6Hg00@0RfDf
08YV=P2:ISH0RVHf0`2;IcL308aX>0<0RF@g0`28HcH208MR=@80Qf<a00L0QV8b08EP<`24Gc<0Pehd
089M<`22G3D0P5ld00<0PF0e00X0Oehc07aK<01iF2d0MeH[07IH<P1eEc40M5H`07=E;`1bE2h0LE<]
0P1`DR`03P1aDBP0LE4Z06iA:@1/D2T0JDlZ06I>:P1TCB/0Hd`Z05m:;@1LAbX0F4@Y05919@1>?R@0
BcdS0P19?BD203`h7`0603/f800j=B40>C@P03Lb7`0f<200=BlO0P0a;b03030^7`<0;bdN0P0Z:R00
0`0Y:Al0:2PN02LW7@0202HV700702DU6`0W:2009RLO02HW7`0U9Qh092DM02<T7002028S6`<08b@N
0P0R8ad3024R70P07b8K1P0P8a`2024T7@P08RDL0P0Q91/3028U70H08bHM0`0R9A`2024T6`P07b8K
0P0N81/00`0O8Q/082<J024T6@02028V600302<W600T9QT092HI00<09BLJ100V:1/202PX7P0902TY
7@0Z:ad0:b`L02`]6`0];Q`0;BlJ02h/7@0_;Ah0<S0Q0080<c4R00<0<BlP02l]7P0]:a`0100a;Ql4
030]7P80=S0P00H0>34O03Xc800m=B00@3DO048f7P13=al304Hl8`@0AcdT00<0B3hU04Hj8016>R00
0P16>R0404Lk8@80BSXQ0P1;>b80301<?2<0CCdT04dm901=?B@0C3`R04dm8`1>?R@0CclU05109P1A
@BL0DT8X05=3:@80CclU0P1@@2H405519`0604i2:01>@bL0CT<W04i39@1>@b<0CT@Q0P1>A20405=3
8P@0DT8Q00<0EDDQ05I68P1FAR800P1FAR8305M78`0605]<8`1MBb<0GD/S05i;8`1PBR<0HDTS0P1R
B2<01P1QAB00HTHQ06=78P1TB2<0ITXU06M;9P80J4`W00<0IDhR06I?8`1VCb<00P1VCb<306M@9080
J58S00D0J54U06M@9P1WD2L0IdlY06I>:00206I>:P80IThX00<0ITlV06M@9P1WD2@00P1XDR<806aA
9P05079E:@1aE2P0LE@X071C9`1_DRH00P1^DBD00`1]D2@0JeDV06]E9P0706]E9PP0LUPW00P0LELT
079H9@1cFBP0LePY079G:P1aER/0Ke<[06eA:@P0L5DX0`1_E2L2071E:0<0Ke@W201`EBP2079D8P06
07AF901eEbD0MeTW07UK:@1jG2X0Ned[201kGbd207US<@0407QR<01gHBl0Mf4_07IP;P80MEl]0`1`
FR/206mI:P<0KUPY00P0JUHT06UD9@1YE2D0Ie8U06IA9P1UCbH0I4hW06==9P@0HT`W101QBbH805a:
900605e58`1LAB<0G4DS05Y68`1JB2@0F4PT0P1HBRD305U99@80F4PT0`1GAb<205Q89`0405M79P1F
ARD0EDDT05A48`80Dd<R101B@b80101A@R40D44P0511801?@1l404]080@0C44Q0P19?R8204Xo8`<0
Bd0T00<0C44U04`o7`1=@2000P1=@2001@1>@B40D4<S0554901BABD0DdHV00<0Bd8S1@1:@B8604Ln
8@80ASdP0`18?R<204Lm8P<0AS`Q00<0?cPL040i7@10>Ad00P11>Qh2048k7`0304<l8010>Ad0@3TM
00@0@3TM0P0o>1`01@0n>A/0?CPJ03/g6P0h=a/0=SHL0080<cDM00X0<SHO03Pf7@0h=Qd0=cDN03Dc
7P0d<Qd0<RlL034^7@0`;A`0<B`H0P0_;1T00`0^;A/0;2dM02/]7`0202X^80<09bTK100V:1X01`0U
9aT092PI02<W6@0S9aT08RDJ024T6`0P8a`00P0O8A`201lR6`<07R4J0`0M81T301`N6`<06adJ0P0J
71T201XL6`806A/J0P0H6QT201LI61005QPG400E5QR901@E5aP05AHH0`0D5AL401DF60805QLI200E
5QP@01HH5bP05aTH200I6aXN01/K6@806QXH400K6aT301TK60<06Q`I0P0K7AX601/K6`806QXJ4@0K
6a/801/K6@P071`J0P0M71X301hM6`<07ahL0P0O7QT6020O6P0601hN5P0O7aL0820H024Q6@0S8a/0
92@L0P0V9Qh802@T70P09b8L200U9Ad4024Q6@@08R8J0P0Y91h302PS7@<09b8L00<08b0I02@Q6P0T
8AX0100T8AX00`0S81T08B4I024Q6@03028R6P<08b<K400R8A`2024Q6@<08R8J0`0S8a/2024Q6@03
028R6P0S8a/092@L00809BDM00<09RHN02<S6`0S8a/00P0R8QX0100Q8AT0820H020P600O7aL8028R
6PT08B8L200P8A/201dN60807QlI0P0O81X2020Q6`@07b0J100N7aT301lP6P<0824K0P0Q8Q`8020O
6P807AhH0P0N7aT0100O81X0824K020Q6`0P8A/<01lP6P@0824K200Q81/8020Q6`P08R8J200T8AX2
02<P6@0402@Q6P0U8Q/09R<L02LT7@80:2DN0`0Y9A`202XV7@<0:bLN00<0:RHM02/W7P0/:1l00P0/
:1l00`0Z9Qd0:2@K02LS6P0202/W6`80;2PL0P0]:Ad202hZ7PP0<2XN0P0c:Ad203@Z7P80=B/O0P0f
;20203P/70<0>BdM100j;Qh203H]70<0=bhM0`0h;ah803D[7`0303H^8@0e;B00=BdP0080=BdP0`0d
;1l203D]8PH0=2`Q1P0`:Qh202lY7@0802`X700]:Ad0;RXN02l[7`0`;200;b/O02dY7@0/:1`802hZ
7PP0<B/O200^:R4302l]8B_ooooo000Zooooo`<0VFhk0P2JKc`309]`?@0309IZ>@2GJcX0V6`k00<0
VVhm0P2IKC`809]_?P0309aaA02KL4<0VVm20080VFi100<0VVm209]`@`2LLD@00P2MLD0209ib@@<0
Wg=200<0X7A309ib@@2NLT401P2NLT4209eaA00409ibA@2OLdH0Wg=60:1dA`80XGE800<0WG5209ib
@`2PM4<00P2RMd@00`2RMd80XGHo0:1e?P080:9gA080Y7Q7102SMdH30:9fA@030:EjA`2TNDH0XgQ5
0080XWM400<0Y7U60:IkB02WO4T00`2WO4T20:IkB0<0YGY72P2UO4P0102TNdL0XgY60:=jAP2RNDD2
0:5hA080X7E80P2QMTT0202OM4L0WG9509Y_@P2IKT40UW1109E_@02CKCh0TF/l0P2@JS/2095[?080
SfTl00<0SVPk08eW>P2<IST00P2;ICP02@2:I3L0Q5/_08AK;`23GC00Peha089M<01oGBl0O5`]07]K
;00207aI<`0807]H<P1iES00N5D_07MD;P1fDbd0ME8/07I@:`1gDB`207QB;@0407MA;01fD2/0MDlZ
07A>:@<0Kdh[0P1^CBX306e<:@80K4/X00L0KD`Y06m>:`1`Cb`0LE0]079A;P1cDRl0LUD[0080M5@[
00<0ME@[07IC:`1hDR/00P1iDR/03P1lEbd0OEP^07iI;`1oFS00PE`b089M<`23GS@0Q5le08UR>`29
HST0RV<j08]T>@2<IST0S6Hg0P2<ISD309AZ>0<0UF/i2P2FK3X209Q]@080Uf`o0P2FJch209EZ?@<0
TF/l00<0T6Xk08mY>P2?JCX00P2?JCX00`2>J3T0TFDn095U?P02091T?@0408mS?02>HS/0SF4j08eQ
>P80Rf0e00@0S64f08eR=`2=HSL0SV<h0P2?I3T808iS=P0308aQ=02=HSD0Sf@g0080TFHi00<0T6Dh
08mT=`2>HcH00P2?HcH00`2@I3L0TFDh099V>@0209=W>P0309AX>`2@JcL0T6/g00H0T6/g202CJCL3
09AZ>0D0TfTg202DJ3L00`2EJcT0U6Xh09=Y=`02099X=P0609=Y=`2DJSP0UF/i09I[?P2EJSd0TfPk
0P2BIcX00`2CJ3/0UFXm09I[?P0809=Y=`80SfXf0P2@JcL3095/>009099]>@2CKSX0TVdi091[=`2?
JSH0SVTe08mZ=P2@JcL0TF`h00P0T6Xk0P2AJ3X0102?JCX0SVXj08iZ>P2<JSX208][>P80T6Xk0P2?
JCX208iX>@80SFLh0P2?JCX00`2>J3T0SFLh08aV=`0208]U=P0308YT=@29ICD0RFDe0080RVHf102;
IcL0102<J3P0RF@g08UT=`29I3L208QS=P<0Qf8e0P26HS002025HC40QF0c08AO<`23GS@0PUdc089L
=@1lGC40OEhb0P1oH3@02P1nGc<0Ne``07MH;01eERX0MELc07AF<P1cEC40LU@`075C;`1_DBd206i@
;00@06i>9@1^CRL0K4lW06Y>9`1WCBP0I4`X065::01PBBL0FdPZ05U5:P1B@BD0C3`R04Tk8@16>R80
ASXT04Hk9@80>3HM00L0>3HO03Pf8@0f=1l0=34N038_7P0a;Qd0;RlO00<0;BhN0P0/;Ad202//7080
:2XO00<09bTN02HX7@0U9a`00P0T9Q/01`0S9AX09RLO02DV7P0U9Qh092DM02<T700R8a/00P0Q8QX2
02<T7P808R<M0`0Q8Q`00`0P8A/07b8K01lR6`0601lR6`@082<L0P0Q91d2028U7PP08RDL0`0Q91/2
028U70H08bHM0P0R9A`3024T6`P07b8K00P07R0K01lQ700O8Q/082<J024T6@0R9QP08bLI02<W60<0
9BLI0P0V:1X402LY6`80:RXN00<0:b`N02`]7@0];Q`00P0^<1/02@0_<A/0<BhO038_800b;b00<c0Q
038_800a;Ql0<2dN02l/7@03030]7P80<BhO0`0b;b00200g<Ql0>C8P03Xc800m=B00@CHP04@h8017
>240B3XP1018?28404Tm8`P0Ac/Q00H0BCTP04Xj8@1:>R40Bc/R04`l8`1=?B@204hn9@0504dm8`1>
?R@0CShT04lo9@1@@2H00P1A@BL00`1B@RP0CShT04hn900204lo9@<0D40V00L0DD4W04e19`1=@RH0
CD8V04e2901=@R80CD<P0080CD<O0P1B@R4205=38P80E4@S0P1EAB@805M78`0605a=901NC2@0GT`T
05m<901QBb@0HTXT0P1SBB@0201RAR40HdLR06A88`1VBRD0J4`W06Y>:@1[CbX0K50[201WD2@206UC
900306UB9P1XDBL0J54X0080IdlY00T0Idl[06I>:P1VCRP0IDdW06E>9@1UCR@0Ie0T06QB8`1YDb@0
201[CbL3071C9`<0Ke8V0P1^DBD206eF:P<0K5DY0`1[E2P00`1ZDbL0LELV075G9P06075G9P08071F
8`1aEb@0LUPW07=H:@1bEbX0LEH[06mC:`1]DBT306mD9`80L5DX0`1aERT00`1_E2L0L5DX075F:@03
075F:@03071E:01_E2L0LEHY00L0LEHY0P1dER@01P1eEbD0MeTW07QJ:01iFbT0NU`Z07]M:`P0OV0^
00@0NF<a07QR<01hHS00N68`0P1gHBl207IP;P04079L;@1aFb`0LE//075K;080L5X[0P1_FBX01P1/
ER@0K5HU06]E901ZE2D0JE8V06QA9`80Ie0W0P1VCRP0101UCBL0I4`V06=;9@1SBbD2069:90P0GT`V
00H0GdLU05i79@1NAbD0G4PU05]99@1IBBD205Q:9@<0FDTU0P1HB2@305M78`80F4PW00@0EdLV05I6
9@1EAB@0E4@S0P1C@b80201A@R40DT<R05=48`1CA2<0DT<R05528@1@@B00Cd0O0`1;@20204a18@<0
CD8R0P1:?b<204]090<0C44U00<0CD8V04m08@1>?b000`1>?b001@1?@240D44R0593901CA2D0CD8R
00<0C44Q0`1;@200101:?al0B3lR04Po8P18?b8304Ln8@80ASdP0`17?B8204Hl8@<0AC/P0P0o>1`0
0`10>Ad0@CXN048k7`0204<l800404@m8@11>Qh0@CXN044j7P<0@3TM0P0o>1`01@0n>A/0?CPJ03/g
6P0g=QX0=CDK0080<cDM00L0<cLP03Xh7`0i=ah0>3HO03Hd7`0d<Qd0<c0M0080<BhM00H0<bhJ034^
6`0a;Q/0;bhL02`]7@0[;Al202T]7`P09bTK00H092PI02<W6@0S9aT08RDJ024T6`0P8a`201lQ70<0
7b8K0P0N8AX301dP6@807AlL0P0L7Q/301/M6P0301XL6@0J71/06Q`K00806A/J0P0H6QT201LI6100
5QPG400E5QR901@E5aP05AHH0`0D5AL401DF60805QLI200E5QP@01HH5bP05aTH200I6aXH01/K6@80
71`J0`0K6aT301XJ61006a/I0`0I6aP301XL6@806adJ0P0L71`301/K6`<06QXJ4@0K6a/;01/K6@80
71`J0`0M7A/201dL6P<07QdK0`0O7Q`201lN6@<081lJ0`0Q81/01@0O7aL0820H024Q6@0R8QX08b<K
00809BDM00<09RHN02@T700T91`01P0T91`802LR70P09BDM100R8QX402<S6`<0:b@N0P0Z8ad302TR
700302DP6P0V8A/09b8L00<09b8L00<09R4K02DP6P0Q8AT00`0R8QX202<S6`8092@L200S8Qd8028Q
7004024Q6@0R8QX08R8J028R6P808b<K0P0T91`2028R6P<08b<K100T91`202<S6`03028R6P0Q8AT0
8B4I0080820H200R8QX9028S7@P0824K0P0M7QP201hO6@807b0J0`0P8A/301lP6P<07QlI00@07AhH
01lP6P0O81X07b0J0`0P8A/2024R70P081lJ0P0M7QP0100N7aT07b0J020Q6`0P8A/2024R71007b0J
200Q81/8020Q6`P08R8J200W8Q`202DP6P809R4K00@09b8L02PS7@0Y91h0:B@N0`0[91`202`U7@<0
;BHN00P0:RHM02/W7P0/:1l0;BTP02`X7`0[9ah0:BDL02PT6`80:bLK0P0/:1`202dY7@80;RXN200`
:Qh303@Z7P80=B/O0`0f;20303T^7080>RlM100k<1h803X_7@P0=B/O200d;R000`0g;B<0=R`R03D[
8@0303<Y7`0403@Z800e:b40<2XN030Z7P<0<B/O00/0<2XN02hX700]9a/0:bLK02`X700^:Qh0;b/O
030/800_:al0;RXN02dY7@0802hZ7PP0<R`P200^:R43030/82_ooooo000Zooooo`<0VFhk0P2JKc`3
09]`?@0809M[>P2HK3/0VVhm09]_?P2LL3l0Vfln09Y^?@2IKC`809]_?P0309aaA02KL4<0VFi10080
V6e000<0VFi109]`@`2LLD@00`2PLT430:5c@P80XWA3202NLT401@2LL4<0WG5409eaA02NLTD0X7A7
0080XGE800@0XWI909ea@P2NLT<0X7A30P2RMd@00`2RMd80XGHo0:1e?P080:9gA080Y7Q7102SMdH3
0:9fA@030:EjA`2TNDH0XgQ50080XWM400<0Y7U60:IkB02WO4T0102WO4T20:IkB080YGY7102TNdL6
0:ElB0040:AkA`2SNTH0XgY60:9iA@80XGQ40P2PMDP20:5fB@0809mdA`2MLTD0VVm209U^@@2FL440
U6ho099/?@2@JS/208mY>P03091Z>`2AJc`0SfTl0080SVPk00<0SFLj08aV>@2;ICP00P2:I3L208EL
<00A08AN<@23GS40PE`_07eK;@1jFR/0N5PY07aI<`1kF380NULa07UF<01gE2h0MU<]07EB;01dDB/0
N58]07MA;01fD2/00`1eCbX207I@:`<0Kdh[0P1^CBX406e<:@80KTdZ00<0Kdh[071?;01`Cb`00P1a
D2d01P1bEB/0M5@[07AD:`1eE2/0MU<[07QB:`80NE8[0P1mF2h0101nFBl0P5/a085L<P23GS@208AO
=@0808QQ>P2:HcX0S6Dl08iW?02?JC`0SFLh08]U=029Hc82099X=P<0TfTg0`2DJSP409I/>P@0UF/i
0P2HKD0209M/?`80UV/n0P2EJSd00`2AJc`0T6Xk091Z>`02091Z>`@0SfTj0P2@I3d01P2?Hc`0SV8k
08eQ>P2<H3T0Relh08YN=`80S64f1P2=HSL808iS=P0308aQ=02=HSD0Sf@g0080TFHi00T0T6Dh08mT
=`2>HcH0SV8e08mS=P2@I3L0TFDh099V>@2CIcX00P2DJ3/8095/>0@0U6Xh1P2CJCL609AZ>0P0UFTh
00<0UV`j09E[>@2CJCL00P2BJ3H01P2CJCL0UF/i09I/>P2FJch0UFXm09=X>`80TVLj00<0TfPk09EZ
?@2FJch0202CJCL3091[=`<0TF`h0P2BKCT00`2DKc/0Tfhj095/>00308mZ=P03091[=`2AK3P0T6Xk
00L0T6Xk0P2AJ3X0102?JCX0SVXj08iZ>P2<JSX208][>P80T6Xk0P2?JCX208iX>@80SFLh0P2?JCX0
1P2>J3T0SFLh08aV=`2;ICH0RV@e08US=0<0RFDe0P2:ISH408]W=`0408UT=`28HcH0R6<f08QS=P80
Qf8e0P26HC@208IR<00308EQ<@24Gc80Pehb0080PUdc00T0PE/d07UJ;P1kG300OEhb07mP=01nGc<0
O5da07QI;@1fEb/00P1dES807`1cEC40LE<_071B;P1^D2`0KDl[06a>:P1[Bb80Jd/T06Y=9@1YCBH0
ID/V069:9P1NAbD0G4DS05M6:P1D@bT0CCdS04Pj8013=al0@SHP048g8`13>2@0=CDK03Hf700g=al0
=SDP03Dd7`0b<Ad0<2lM02h]6`0];Qh00`0/;Ad202//7080:R/K00H09bXO02HY7P0V:Ah09BPM02@W
700S9Q/2028U6P809BHN00<092DM02<T700R8a/00P0Q8QX0100P8AT08R<M028S7@0R8ad3024R7080
824K2@0O8Q/2020S70808B@M0P0R9Ah00`0S9Ql08RDL028U7006028U708082<J0P0Q91/3028U7080
8bHM0`0R9A`2024T6`8082<J200O8Q/201lQ7006020S700Q91/08RDJ028V600S9aT08bLH0`0V:AP2
02LZ6@@0:2/J00H0:b`N02`]7`0/;Ad0;BhN02h_7@0_<A`2030b700303<`8@0b;b00<BhO00@0;b`M
0140<2dN02h[700^:a`0;b`M034^7`0b;b00<c0Q03@a8P0e<R<0>C8O03/c800m=B00@CHP04@h8018
>B80BSXQ04/k8P0304/m8PD0BS`Q0`18?28504Lk8@80BCTP00H0BSXQ04/k8P1<?2<0CCdT04hn9@1?
?bH404lo9@@0D40V00@0CCdS04hn901>?R@0CShT0P1??bD205109P0604e19`1=@RH0CD8V04e2901=
@R80CD<P0P1=@al0201A@B00DT8Q05=38P1DA2<0ETHU05M79P1HB2L0FDTX1P1IBBD205Q8900605i?
9P1PCRH0H4hV065>9P1SCBH0I4`V0P1UBbH206Q<9`0406U=:01ZCRT0JThY06]?:P80K50[1P1YDRH2
06QA9@80JU@U00<0JU<W06UB:01YDRT00P1XD2X206Q@;00706M?:@1UCBL0IDhU06E>901WD2@0JE<T
06YD9@0806Y>9`<0KU4U0`1_DRH2071C9`@0KUL]00<0KEH/06aE:`1/EB/00P1[E2X8071F9@0906mE
8P1`ER<0LELV079G:01bEbX0LEH[06mC:`1^DRX0KU<V0080Ke@W0P1`EBP2075F:@04079G:P1_E2L0
L5DX079G:P80LeP[00<0LULZ071E:01_E2L0201aERT01@1gFBL0N5XX07QJ:01hFRP0NE/Y00<0NU`Z
201oGbh207QR<0<0Mf4_0`1fH2h0101cGB`0LU`[079L:`1bG2/2075K:P80L5XY0P1^EbD01P1]EBD0
K5@V06]C9`1[DRT0JU4X06YA:@80JE0X00@0J4lW06I=9@1UC2@0I4/S0P1SBR88065?:@0606=;:@1R
BbT0HDXX05i:9`1MBbL0FTXV0P1HBRD305U99@80F4PT0`1GAb<205Q89`0405M79P1FARD0EDDT05A4
8`80Dd<R00P0DD8Q05938P1CA2<0E4DT05=48`1B@b80D44P04m07`<0Bd0P00<0C44Q04e28P1=@R80
0P1>@b<304]09080C44U0`1=@RH0101@@B80Cd0Q04m08@1>?b0204dn7`0404ho801@@B80DD8S04m2
8080CT4O0P1=@1h204`o7@0304/n7019@2<0BD0S0080B3lR0P17?R4204Hm8080AS`Q0P15>b0204@j
7`80@cTN0P0o>1`01P10>Ad0@CXN048k7`13?200A3dQ04Dn8P80@S/O0P11>Qh2040i7@80?cPL00D0
?cXL03hi6`0j=QT0=SDI03@d6P0203<e7@0?03<g800k>B00>cTP03Tg800g=B00=C<N03<`7@0b;ah0
<BhM03D`700c<1d0<RlL030_7@0/;Ad0:R`N0080:2`N200W:A/01P0T:1T08bLI02<W6@0R9AX08B@K
020S70807b4L0P0P8a`201lR6`<07R4J00@07B0I01dO700M7a`07AlL0P0L7Q/301/M6P806Q`K0P0I
6aX201PJ6@805aTH400F61L@01DF68T051DG600E5QP301@E5`@05AHH0P0F5aT801DF61005QPG:00G
6AP801TK6QP06a/I0`0L71X00`0K6aT06QXH01XJ600201TI5a006a/I0`0I6aP301XL6@806adJ0`0L
71`00`0K6a/06QXJ01XJ6P0201TI6A406a/K200K6aT00`0J6QP06a/I01/K6@0201`L6P807AdK00<0
7QhL01dL6P0M71X00`0N7A/301lN70807ahI0P0P7aX2024P6`808R4L0P0Q8AT0100R8QX08b<K02<S
6`0T91`202DU7@P092@L200W8Q`802HV7PP092@L0P0]91l202`S7P<0:b8M00@0:R4L02HQ6`0W8Q`0
:B@N0P0Z9Al00`0Y91h09b8L02HQ6`03028R6P808b<K0`0T91`802<R7@P08R4L0`0R8QX202<S6`H0
92@L0`0S8a/2028R6P<092@L0P0S8a/;028R6PT08R<M200Q8Q`201dN60807QlI0P0O81X4020Q6`80
7b0J0P0N7aT201dN60<07b0J0`0P8A/2024R70P081lJ0P0M7QP0100N7aT07b0J020Q6`0Q8Q`2028S
7@P0824K1@0O81X301hO6@P08B0K200Q8Q`8028R6PP0:B@N0P0U81X00`0V8A/09b8L02PS7@0202TT
7P0402XU7`0/8a`0;2<L02`S7080;B@M0`0^9Ah00`0Z9Qd0:bLN02`X7`0202dY800302/W7P0Y9A`0
:2@K0080:bLK0P0/:1`202dY7@80;RXN200a:al203@Z7P80=B/O100f;20303X_6`80>c0L100l<Ad2
03ha7P0403d`7@0l;a`0>bhK03/^6`80>RdJ200e:al4038_80@0<c0Q01H0=bdS03D[8@0c:Al0<RPN
034W7@0b:1h0<bTO03@Z800_:Ad0<2XN034[7`0b;200<B/O030Z7P0^:1`0;2HJ02XV6P0/:1`0;RXN
02l[7`0`;200;b/O0P0^:Qh802l[7`P0<bdQ200_:b8302l/7B_ooooo000Zooooo`<0VFhk0P2JKc`3
09]`?@0309M[>P2IKC`0Vfln0080WG5000<0W70o09]_?P2JKSd0202KKch00`2LLD@0Vg1309U^@@02
09Q]@00309U^@@2KL4<0W75400<0X7910P2QLd830:9d@`P0WW910P2LKdD0102ML4H0WW570:1cB@2Q
M4X20:9eB`0309ea@P2NLT<0X7A30080XWM400<0XWM20:5f?`2PMCh0202RMd@20:AhA`@0XgM60`2R
MTD00`2UNTL0Y7U60:=hA@020:9gA0040:AiAP2VNdP0Yga90:QmBP<0Yga90P2VNdP20:EjA`D0Y7]7
1@2UO4P0102TNdL0XgY60:=jAP2RNDD20:5hA080X7E80P2QMTT0302OM4L0WG9509Y_@P2IKT40UW11
09A^?`2BK3d0SfTj08iX>@2?JCX0T6Xk095[?080SVPk0P2=IcX0102<IST0RfDh08YT=`2:I3L208IM
<@0608AN<@23GS40PE`_07aJ;01hF2T0MUHW0P1kF380101jEc40N5D_07MD;P1eDR`207AA:`0307UC
;P1gDB`0MDlZ0080LddX00<0M4hY07MA;01hDRd00`1_CR/206i=:P<0KD`Y00<0KTdZ06m>:`1_CR/0
0P1_CR/3071?;006079E:`1dE2/0M5@[07ED:`1fDb/0N58[0P1iDR/0401mF2h0OUT_07mJ<020Fc40
PUdc08=N=024GcD0QF0f08MP>@2:HcX0SVLn095Z?`2AJch0SVPi08YT<`28HS42095W=@<0TVPf0`2C
JCL309I/>PD0UF/i0P2HKD0209M/?`80UV/n0P2EJSd5091Z>`@0SfTj0P2?Hch0102>HSd0SF4l08]O
>P2:GST208UM>00408iS>02=HSL0SF8g08eR=`<0S64f00<0Rf0e08iS=P2>HcH01P2>HcH00`2<HC@0
SF8e08mT=`02095V>@04091U>02?I3L0SV<f08iR=@80Sf<f00<0TFDh099V>@2CIcX00P2DJ3/8095/
>080UF/i102DJSP409=Y=`@0U6Xh0P2EJcT809EY>00309I/>P2EJcT0TfTg0080TVPf00H0TfTg09E[
>@2FK3X0UV]009EZ?`2CJ3d2099W?00309=X?@2EJSl0UV]000P0TfTg0`2@JcH2095/=`<0TVdh00@0
UG0l09=^>P2AK3P0T6/g0P2?JSH00`2@JcL0TF`h091Z>`07091Z>`80TFPj00@0SfTj08iZ>P2>JSX0
S6Xj0P2;JcX2091Z>`80SfTj0P2>J3T208eW>080SfTj00@0SVPi08eW>02;ICH0RV@e0P29Hc@308UU
=@<0RVHf0`2;IcL408QS=P80Qf8e0P26HC@208IR<00908EQ<@24Gc80Pehb089M<`21G380PE/d07EH
;01gFRh0NUda0080OF0d00<0NUda07MJ;P1dEb/00P1dES@0101bE380LE<a06mA;`1]Cbd206a>;00H
06U9801YBB80J4/S06M;901TBRD0H4PT05a58`1J@b40ED@Z05919`1;>b80ACLM040d700o=1h0@3DQ
040h8`0d=1X0=CDK03Hf7P0f=B00=C@O038a7@0_;Q`0;B`J0`0[;Qd202X]70<0:B`K0P0V:Ah00`0U
:1d092LL02<V6`02028U6P07024T6@0U9Qh092DM02@U7@0S91`08R<K024R6P02020Q6@<08R<M0P0Q
8Q`3020Q6`T07b8K0P0P8a`00`0Q91d08RDN028U7P0202<V7`P08RDL0P0P8aX2024T6`P08RDL0P0Q
91/2020S6PP07b8K0P0O8A`00`0P8a`08B@K028U6P0202<W6@0402@X6@0V:AP09RTH02HY60809bXI
100X:aX202`]7`0302d^7P0^;ad0;c4L0080<38L01T0<C<K03La8`0d;R00<B/M02lY6`0^:1X0;bTK
034[7@0c;Al0;2TJ02dZ6`0^:a`0<2dN03<`8@0e<R<0=S<T03Ld9@0k<b00?3@Q03ld8011=R00ACTQ
04Tk8@1;>b80C3`R0080BcdR101:?24204Tk80@0B3`R1017>b4204Ti800304Xj8@1;>b80C3`S0080
CShU00<0CclV05519`1@@2H00P1@@2H304lo9@0304hn901=?B<0CCdS0080CShT0`1??bD01`1@@2H0
CD4W04e29P1=@RH0CD8T04e28P1=@b000P1=@al20551800405=38P1EAB@0EdLV05U9:080Fd/Z1@1J
BRH305U99@0605m@9`1QCbL0HDlW069?9`1TCRL0IDdW0P1VC2L206iB;@80KE4/00@0K50[06]?:P1Z
CRT0JThY1@1ZDbL306UB9P80JeDV00<0Je@X06YC:@1ZDbX00P1YDB/02@1YDBd0J50/06M?:@1VCRP0
IDhU06E>901WD2@0JE<T06]E9P0806Y>9`0506a?8`1]D2@0KE0T06iA9@1_DRH00P1`DbL00`1aE2P0
L5T_071I;`0206mH;P0306iG;@1]ER`0KEH/0080K5D[201`ERD0201_EB80L5HS075G9P1bEbP0LULZ
071E:P1_Db/0KU8Z0P1^DbH0101_E2L0L5DX071E:01aERT2079G:P0306mD9`1`EBP0LULZ0080LeP[
00<0LULZ071E:01_E2L0201aERT807YL:PP0Oel^0`1gHBl507IP;P<0Led[0P1bG2X3075K:@0606iG
8`1^EbD0KULU06eE9@1/E2H0K5@X0P1[DRT206YA:@0406U@:01WCRH0ITdU06A;8`80HdXR201RD2X0
1P1VCR`0I4d[06=<:P1PC2T0GT`X05Y:9P80F4XU0`1IBBD205Q890<0EdLS0P1HB2L0101GAbH0ETHU
05E5901DA2<205=38P0305528@1B@b80E4DT0080E4DT00<0DT<R0511801?@1l00`1;@2000`1<@B40
CD8R04i38`0204i38`80Bd0T0P1<@BD304e29P0;04i39`1B@B<0D3lQ050o8@1>?Al0CC`N04`k7@1=
?1h0CchP050o8@1?@R000P1>@Al00`1=@1h0C3lM04`o7@0204/n700404Y19019@2<0BD0S04Po8P80
AchQ0P16?B001015>b00A3XO04@j7`14>Ql204<i7P80@SPM0P0o>1`01010>Ad0@CXN04<l8014?B42
04Dn8P0404<l8012>al0@S/O044j7P80@3TM0P0o>1`05P0o>Q`0?STK03Xf6@0f=AT0=3@J038d700d
=Qh0=3PQ03`j8@0k>B00>SPQ03Pf8@0e<ah0<c0M038_7P0a;Qd0=c8N03@a7P0c<1d0<2lM02`]7@0Z
;1h202L[7@D09bTK0`0X:Q`01P0T:1T08bLI02<W6@0R9AX08B@K020S70807b4L0P0P8a`201lR6`@0
7R4J0`0M7a`301`N6`806adJ0P0J71/201TK6P8061XI0P0G6AP@01HH5a005AHHR@0D5ALH01DF60<0
51DG100E5QP201HG6@P05AHH400F61LX01LI60P06A/J600K6aT0100M7A/071`J01`L6P0K6aT201XJ
60806ATG400K6aT301TK60<06Q`I0P0K7AX0100M7Ad071`L01`L700K6a/201XJ6P806ATI4@0K6a/8
01/K6@806QXH00@06a/I01`L6P0L71X07AdK0P0N7Q`201dL6P<07QdK0`0O7Q`201lN6@8081lJ00@0
8B0K028Q700R8A`08b8M0P0R8QX302<S6`/092@L200W8Q`:02HV7P@09BDM0P0T91`202dT7`80;2<N
100[8Qd00`0Y8Q`0:R<M02`U7`0202dV800302`U7`0Z8ad0:B8L00808R8J0`0S8a/302@T70P08b8M
200R8A`2028R6P<08b<K0`0T91`01P0V9Qh09BDM02DU7@0T91`08b<K028R6P808B4I1`0T91`00`0S
8a/08R8J028R6P06028R6PT08R<M200Q8Q`201dN60807QlI0P0O81X5020Q6`0301lP6P0N7aT07AhH
00807AhH0`0O81X3020Q6`808B8L200P7aX201dN600601hO6@0O81X0824K024R700R8ad08b@N200P
8A/401lP6P@07QlI200Q81/8024R70P08R8J200/9Al202LP6P0402PQ6`0Y8Q`0:R<M02/T7P80;2DO
0`0/8a`202dT7@<0;RDN00<0:bLN02`X7`0]:B000P0]:B000`0[9ah0:BDL02PT6`0202/W6`80;2PL
0P0]:Ad202hZ7PP0<B/O0P0d:Qh203D[7`<0=R`P00@0=bdQ03X_6`0j;a/0>RlK0P0k<1`403`a7@06
040c800o<Ql0?S4N03d`7@0k;Q/0>RdJ0P0i;1T803D[7`<0<RlP1@0c<240100i;2<0=bXQ03DX7`0c
9Qd2038U700403@W7P0e:1l0;bTM030Z7P<0<R`P00L0<2XN02dW6`0/9QX0:RHJ02/W6`0]:Ad0;b/O
0080<2`P00<0;b/O02hZ7P0_:al01`0_:al803<]8@P0;b/R0`0`:Q`[ooooo`00:_ooool0202KL4<0
VVm209Q]@02GK3l0V6e009Y_@P2MLTD0WgA7202IKD0809Y`?PP0VG4m0P2NLT4209mc@P80X7A30P2Q
MD@209ea@0H0WW91202PMT@0202PM4<0Wg=209ib@@2NLT40Wg=20:5eA02SMdH0Y7Q70P2UMD@0102V
MTD0YgM60:MgAP2XN4L20:UiB0T0XgQ50P2QMT<30:9gA0<0XgQ50P2VNT/01`2WNdX0Z7e:0:QmBP2Y
OTT0ZGi70:QmAP2WOTX00P2VODT00`2UO4P0Y7]70:=jAP020:9iA@80YGa600h0Y7]70:9hAP2QMdL0
X7E809mdA`2NLdP0XgU70:5gA@2NM480Vg4o09Y`?P2KLCl0WG=109id@P<0TVLj1@2CJ3/208eW>004
08aV=`2:I3D0RF<d08MQ<P80QV0a00h0Qede08IL=025Fc<0Q5Xb089H<020ERh0OeD]07iD;01lES40
NULa07UF<01gEBl0MED^079E;@80L5@/0P1aCb`00`1_CR/0KDl[06]?:P0206U?:P0706Q@:P1aD2d0
LE0]071?;01_CR/0KD`Y06a;:00206]:9`80J4`W00<0JT`X06e<:@1_CBX00P1aCB/02@1dCB`0KT/S
06m<901bCbL0ME8Z07QE;@1kF300OEXb07mL=002085K;003089L;@23GBh0Q5h_0080QEl`00L0QV0a
08QR=@29HcH0RF<f08YT=`2;ICP0S6Hi0080SFLj00H0TVPf09=Y=`2CJCL0UF/i09I/>P2GKC/309Q^
?00:09M]>`2FK3X0UF/i09E[>@2FK3X0Ufdk09Q^?02JL3h0VFlm09M]>`80UV`j00<0V6hl09Y`?P2K
LCl00P2DJC`00`2CJ3/0TVLj095V>@02091U>080Sf@g0140T6Xm08eW>P2:I3L0Qf4d08IP<`28HSD0
RfDh08iX>`2<HCH0Rf0e08YO=029GS<0RUld08]P=@2=HSL0SV<h08mT=`0208iS=P0508eR=@2<HC@0
Rf0c08]P<`2:Gc800P2<HC@0102=HSD0SV<f091U>02AIST2099W>P0@095V>@2@ICP0Sf@g08iS=P2?
I3L0T6Dh099W>P2CJ3/0TfPe09AY=P2FJcP0V6dj09U^>`2HKCX0UV/h09EZ=`<0TfTg0P2DJSP309E[
>@80Tfhj0`2BKCT3095/>080U6Xh0`2EJcT309I/>PP0UF`h00H0V6hl09M]>`2GKC/0UV`j09E[>@2D
JSP209=Y=`0309Q^?02GKC/0UV`j0080UF/i00<0UV`j09M]>`2HKS`0202CJCL808mZ=P<0T6Dh00<0
TFHi099W>P2CJ3/00P2CJ3/00`2BK3d0T6Xk08mY>P0208iX>@0308mY>P2@JS/0TV`m0080TF/l0`2@
JS/308mY>P<0SFPd0P2<Ic<308]V<P<0SfHh0P2>ICL408eT=P80RfHi00@0RVDh08UT=`28HcH0Qf8e
0P26HC@208=M<003089M<020GS00Oel`0080OUl`01l0O60`07iN;`1nGC00O5/^07YI;P1hEbh0MU@^
07AB;@1cDB`0LeP]075E;@1_Db/0KE4Z06a@:`1]D2h0KU4a06mB<P1ZCRT0JD`Z06I<:@1SBbT0H4TY
05]69`1IA2L0Ed@V04a19@1:?R@0AS`Q048k8@0o>B40?CPR0080>cTT0P0e<aX00`0d<Q/0<c4L038_
7002034^7@07030]7P0^;R@0;BdS02`/8P0[:b40:RXP02TY7`0202PX7P809BHN100V9al202LX80P0
8RDL200P8aX00`0U9R408b@O024R7@02020Q7003024R7@0S91l09BHQ00P08b@L00<07b8I020S6P0R
9A`00P0S9Qd00`0R9A`082<J01lR6@08020S70P07b8K00<08B8M020Q700P8A`00P0P8A`301lP6`06
020P7P0Q8Al08R<N028S7@0S91`092DM0P0T9Q/01`0T:1L09BTH02P[6P0[;1`0;bdN030]7P0_;1d0
0P0`:Q`203Hc900703Db8`0d<B80<c0Q038_800a;Ql0<2dN02h/7`0302l]800<02h/7`0/:Qd0:RPK
02PV6@0d:Qh0=B/O03H]7P0h;b00>S4P03/c800l=1l0?CDP2014>R4304Hl8`<0AC/R0P14>R4404Pm
8@@0Ac`P00`0C3TK04dj701>>ad0D3dO058o8@1C@280E44S05E2901@ABD0CT<S04a18@1;@20204Xo
7`0404]0801<@B40CSlP04ho80@0Cd0Q0P1@@B801P1@@b40DD@R05938P1C@b80E4@S05I38`80F4<T
00<0FdTQ05a:8P1NC2@00P1OCBD00`1NC2@0G4XR05]98@02061=8P0306=>8`1TCB<0ITdT0080J4`T
00<0JTdU06M?:@1WCbT00P1XD2X0301YDB/0JU8/06YB;01[Dbd0JE4]06Q@:P1WCbT0Ie0W06M@9P1Y
DRH0JU@U06aF9`<0KeDT101^E2<02P1]Db80Je@X06aE:@1^Eb/0KeP/06iG:`1]ERX0JU<W06UB9P1U
D2D206IA9P0306QC:01YE2T0JUDZ0080JeH[00<0JdlW06eA:@1^DRX00P1`E2`00`1^DRX0KE4Y06]?
9`0206QA9`<0JE8X0`1ZDbT306mD9`80KU<V0`1]DRD00`1/DB@0KUL]06iG;@0606iG;@<0LE4X1@1b
DRT01P1/EbX0K5LX06eG:01_EbL0LELV07=G9@80MELS0P1aE2P3079E:@<0LeHZ101fEbP207MH:@X0
N5TZ1@1jGR`307UM:`0A081Q:P1oH2X0OV0Z07YO:P1hGR/0MEh/07AL;01cGB`0Nf0c07aQ=01kH3<0
NUlb07QM<01dFB`0LEHY06mD9`1cF2/00`1bEbX2075F:@80L5DX00L0Je@X06YC9`1ZDbT0JE8Y06Q@
:P1WCb/0IThZ0080ITh/00D0IDd[06A<:P1TC2X0Hd/Y069::00206599`80H54Z00<0Ge0Y05i?:01M
CRL00P1LCBH02@1KC2D0GD/U05i<9P1OCBL0H4hX05m=9`1NC2H0G4XT05]98`0405=78@@0E4PR0`1C
A2<205938P<0DD8Q0P19@b401P1<@b80CD8R04m28P1@@B80Cd0Q050o8@P0CSlN1@1?@24204ho80@0
CChO0`1>?b0304m08@D0Bd0P0`1<@B402`16@b@0AD8S048o8011?Ql0@3dN044n7`12?b00@d0Q044i
8P10>240?SHO0080?CDN00H0?cLP044i8P13>b@0@3TM044j7P12>al204<l8003044j7P0o>1`0?CHJ
00<0>SHK1@0i=AX01P0d=aP0=3LJ03@g6P0d=a`0<cDM03<e7`80<cDP00P0=3HN03<e7@0a<ad0;c4L
02`]6`0Z:a/0:2TI02LX6PH09BHN0P0T9Ad01P0T9ah08bHM02<V7@0R9A`08B@K020S6P807b8I0P0O
8Q/201hQ6P807B0I0P0L7aP201/M6P<06Q`I0`0I6aP;01LI60805QPG0`0E5aH801HG6@P05AHH0P0F
5aT301DF60<051DG200E5QP901@E5`P04ALG600D5AL8018C5BP04ALG600D5AL201DF608051DG0P0C
51H2018C5AP051DG6@0E5QP301DG5P805QPG0`0G6AP801HH5`P05aTH200H61P801LI60P06QXH200J
6QX;01/K6@8071`J1P0M7A/201`L6P<06a/I0`0J6QP301/K6@8071`J200K6aT801`L6P807QhL00@0
7AdK01`L6P0L71X06a/I0P0J6QPA01`L6P0701/K6@0J6QP06ATG01TI5`0K6aT07AdK01lO7@0901/K
6@<07AdK0P0L71X601/K6@8071`J0`0M7A/201`M5`<07AhH0`0N7aT8020O6PP08R4L0P0V8A/202LR
7080:2<M0P0Y91h802XV7@P0;2DM0P0[9AT00`0/9QX0;BLK02hX700202lY7@0A030Z7P0[9ah0:2@K
02HR6@0W8aX0:bLN02`X7`0Y9A`09R8I030Y8@0_:200;RLO02dV7P0/9Ad0:b@L02XS6`0Y8QX0200S
8a/802DP6P8092@L00@08b<K028R6P0R8QX08B4I0P0P81P3024Q6@808R8J1@0S8a/202@T70809BDM
0P0V9Qh302HQ7P809B0M0`0T7a`8028R6PT08b<K00<092DM02<T700Q8QX00P0O81P0100P8AT08B8J
028S6`0S8Qd2028Q7003024P6`0P7aX081lJ00807ahI200P7aX:01lP6P807QlI00@07AhH01`M5`0L
7AL06a`F200Q81/8020O6PP07b0J0`0P7aX3024P6`808R4L200Q8Q`00`0S8a/08R8J020P6002020P
6009028R6P0T91`09RHN02T[800Y:Al0:2PN02TV7@0X91/0:24I0080:1lH00@09R8I02LS6P0W8aX0
9b<J0P0X91/202TU700802XS6`0[91`0;BHN02lX800`:B40;bPP02dV7P0/9Ad202/W7080;2PM00@0
;BTN02hZ7`0^:Ql0;b/P0`0_9AT00`0`9QX0<BLK038X7002038X7080;2TJ00@0;bTK030X6`0a9a/0
=2PL0P0e9a`203<Y7@0603@Z7P0e:al0=bdQ03P^8P0i;b<0>S0T2@0l;ah02010=B<0?c@R03hc8@0m
<R00?34O03/`7P0j;ad0>BhL0P0n;Ql00`0l;al0>RhN03P_7P0203H_7@0703D`7@0b;R80<RhR03@^
8P0e;B80=R`R03P[8P0203T[8P80>2XQ00@0=bXQ03D[8@0d;240<bdQ0P0a;B42034[7`<0<2XN0`0_
:Ad0100]9a/0;bTM034[7`0d;R8203D_8`0303@^8P0c;B40<RPL0080<RPL0P0c:Ad303@Z7P0802hW
7@0_:1h0<BXP03</8P0d;B<0<b`R034Z800`:Al2030Z7003034[7@0b;1h0<bdO0080=2hP00@0=BlQ
02l^6@0_;QT0;bhI:oooool002[ooooo00<0VVm209U^@@2IKT400P2IKT400`2KL4<0W75409ebA@08
09U]@0P0VW0n202ILCd209ea@080WW91102OLd8509ib@@<0WG50202OMD<02@2QMD@0X7A309mc@P2N
LT40Wg=20:1d@`2RMTD0XgM60:EeA0020:IfA@80YgM60P2XN4L00`2YNDP0XgQ50:=hA@070:=hA@80
XWM40`2SN4D30:AiAP80YWY;00@0Yg]:0:MlB@2XODX0Z7e80P2XODH01P2WOTX0YWe90:ImB@2UO4P0
Y7]70:=jAP80XWU50P2UO4H0302TNdL0XWQ60:5gA`2OM4L0WW=609icB02QMdD0X7I409id@P2MLd40
W79009]a?`80W790102CJ3/2099W>P80TFHi0140SFLh08aV=`2;ICH0RV@e08QR<`27HC80QV0a08EO
<027GCD0QU`d08EK<`23FC40PUP`081F;P1oEBd0OU@/07aF<@0207UF<00307ME;`1eEBh0LUD]0080
L5@/0P1bD2d00`1`Cb`0KU0/06eA;00206Y@:`0706UA:`1aD2d0L4l/06m>:`1^CBX0KD`Y06a;:002
06]:9`80Id/V00`0JD/W06a;:01^C2T0L4`Z075=:`1cC2/0LTlW07=@:01dDBT0ME8Z07MD;01iERh2
07YG;`06085K;022G2d0PU`]08=M;P24GRl0QEl`0P26H34208US=P0308YT=`2;ICP0S6Hi0080SFLj
00L0SVPk099X=P2CJCL0U6Xh09E[>@2FK3X0Ufdk00<0V6hl00X0Ufdk09I/>P2DJSP0U6Xh09I/>P2G
KC/0V6hl09U_?@2GKC/0UV`j0P2EJcT00`2FK3X0V6hl09U_?@0209AY?00309=X>`2BIcX0TFHi0080
T6Dh0P2?I3L00`2@JSd0SFLj08YT=`0208MQ=00608US=P2;ICP0SFLj08aQ=P2;H3D0RUld0P29GS<0
0`2;H3D0SF8g08iS>00208iS=P<0SF8e0`2<HC@208eR=@0408iS=P2?I3L0Sf@g091U>0<0TFHi00X0
T6Dh08mT=`2>HcH0Sf@g091U>02BIcX0TfPk09=X=@2DJCH0UV/h0`2HKCX209I[>080TfTg0`2DJSP3
09E[>@<0U6lk0P2CKSX3099]>@@0UV`j102EJcT809E/>0<0UV`j0`2EJcT209AZ>00309Q^?02GKC/0
UV`j0080U6Xh00<0UV`j09M]>`2HKS`0202CJCL808mZ=P80T6Dh0P2AIST01`2BIcX0TfPk09=X>`2C
J3/0TV`m091Z>`2?JCX00P2>J3T00`2?JCX0T6Xk099/?@02095[?0<0T6Xk0`2?JCX308eX=0<0S6Lc
0P2;IS8208mV>0<0SVDg102=I3H01P2;IST0RVDh08YU>029I3L0R6<f08MR=@80QV4d0P27HC@00`26
HC@0Pf4c089R<`02081Q<P0R07eQ<@1nGRl0OE`_07aK;P1jFBh0N5L^07ID;P1dDRd0Le4/079G;01a
EBd0KU8Z06eA:P1/D2/0K4l]06e@<01^DC40JD`Z06M=:P1UBbX0HTTZ05i7:01JABH0Ed@V05I39@1:
?R@0B3`R04Dk8P10>Al0?CLO03/f800i=b80>SPS03Dc6P80=38K00<0<c4L038_700a;Qd00P0`;Ah2
02d]8`0602`/8P0[:b40:RXP02TY7`0X:1h09bLM0P0U9Qh602HW7`P08RDL200P8aX00`0T9B008b@O
028S7P02024R7@03028S7P0S91l092DP00P092DM00<07b8I020S6P0R9A`00P0S9Qd00`0R9A`082<J
01lR6@08020S70P07b8K0P0Q8Qd6020Q70808B4O00/08R<N02<T7P0S91`092HK02DW700U9aX092PG
02HZ6@0Y;1/0;BhN030^7`02034^7`80<R`N01P0=S<T03Db8`0d<B80<c0Q034^7`0`;Ah0;b`M02h[
700]:a`0;R`M02l]7P0`;Ql0;bdN02h/7@0/:Q/0:RPI03H/800g;B40>2lP03T`7`0k<b00?3@O03hf
8@0n=Ql804@j8@L0AC/R00<0AS`S04Pm8@18?B400`18?B4304Ll800604hk7@1??1h0D3dO054n801C
@280E44S0P1F@bD01P1AARH0Cd@T04e28P1<@B40Bd0P04a18@80CD8R201@@B801P1AA280DTDS05=4
8`1DA2<0EDDT05M49080FD@U00P0FTPP05a:8P1NC2@0GddU061>9P1OCBD0GT`T05e;8`80HTlT00<0
I4lT06I?9@1WCRD00P1ZCRH0101[CRH0IdlY06Q@:P1XD2X206UA:`80JU8/00T0Je<]06YB;P1YDB/0
J50Z06M@9`1XDBL0JE8V06]E9P1/ERL01P1_E2D206iC900306aE:@1]ERX0KeP/0080KeP/00T0KEHZ
06]D:01ZDbL0IE0U06IA9P1WDRL0J5<X06UD:@1ZEBX00P1[ER/00`1[CbL0K50X06iB:P0206mC:`03
06iB:P1/D2P0JdlW0080J54W0`1YDRP306YC:@<0Ke@W0P1^DbH406eB9@P0KEH/101aDBP4079B:@80
K5LZ00H0KELX06mG9`1aEbH0LeLU07EG9@1eEb<3075D:080LUDY0`1cERX0101eERL0MULX07IG:01f
EbP207MH:@X0N5TZ1P1jGR`207UM:`08081Q:P1oH2X0OElY07YO:P1hGR/0MEh/07AL;01cGB`307aQ
=00507]P<`1iGS40MU/^079G:P1aERT00`1cF2/2079G:P<0LEHY0P1[E2P01P1ZDbT0JE8X06QA:01W
CbT0Idl[06I>:P80ITh/00<0IDd[06A<:P1SBbT00P1RBRP00`1QBBL0H4hX061>:00305m=9`<0GT`V
00P0GD/U05i<9P1OCBL0H4hX05m=9`1NC2H0G4XT05]98`<0DdLQ1@1DB28305=48`80DT<R0`1A@R42
04U38@0604a38P1=@R80Cd8R05118P1?@240D3lQ201>?ah00`1@@B80Cd0Q04m08@0204m08@80CSlP
101=?Ql304ho80<0Cd0Q101;@20404a18@0304I18`15@280@chP0080@SdO00H0@chP04@o8@15@280
@CTR040h8@0o=b0203hf7`0;03lg8011>B80@SXS040i7@11>Qh0@S/O04<l8012>al0@CXN03lh700n
=a/0100k=a`403Xf6`0603@g600d=aX0=3LJ03@g700c=Ad0<cDO0P0c=B02038d7006030b700^<1/0
;2dK02//700Y:QX0:2TK0`0V:1d402DW700702@V6`0T9ah08bHM02<V7@0R9A`08B@K020S6P0201lR
6@807b8K0P0N8AX201dP6@8071lH0`0K7AX201XL6@<06A/H2`0G6AP201HH5`<05ALF200F5aT801DF
60805QLI0`0E5QP301@E5`P05AHH2@0D5AL8014G5aP051DG200B4aDX014G5aP051DG0P0E5QP201@E
5`804a@F0P0B4aDH01@E5aT05AHH0`0E5aH201HH5`<05aTH200F61L801LI60P061PH200G6AP801XJ
60P06QXJ2`0K6aT201`L6PH07AdK0P0L71X301/K6@<06QXH0P0K6aT301`L6PP06a/I200L71X00`0N
7Q`07AdK01dM6`0201`L6P806a/I00<06QXH01`L6P0L71X03P0L71X00`0K6aT06QXH01TI5`0201TI
5`0301/K6@0M7A/07QhL00T06a/I0`0M7A/201`L6PH06a/I0P0L71X301dM6`8071dG0`0M7QP301hO
6@P081lJ200R8A`202HQ6`809b8L0P0X8ad202TT7PP0:RHM200/9Ad202`V6P<0;BLK0`0^:1`0200[
9ah0:2@K02HR6@0W8aX0:bLN02`X7`0Y9A`09R8I0P0^9al0100]9Qh0;2DM02/T700Z8a/202TR6PP0
8b<K200U81X202@T70808b<K00<08R8J024Q6@0Q8AT00`0Q8AT3028R6PD08b<K0P0T91`202DU7@80
9RHN00@09b8O02HQ7P0V8Ah09R4N0P0U81d202@O70P08R8J2@0S8a/00`0T9Ad08b@L024R6P0201lP
6003020Q6@0Q8QX08R<K00<08R4L00<08B0K020O6P0P7aX00P0O7QT8020O6PX07b0J0P0N7aT201dN
608071dG200Q81/8020O6PP07b0J0`0P7aX2024P6`<08R4L200Q8Q`0400S8a/08R8J024Q6@0P81P0
8B4I028R6P0T91`09RHN02PZ7`0X:1h09bLM02PU700X91/0:R<K02XQ6P0Y81T302LS6P80:2@K0`0Y
9A`00`0Z8a/0:b@L02dV7P0302lX8080;BHN0`0/:1d202dY7P0402hZ7`0_:b00;b/P02lU6@80<2HJ
0P0a9a/2038X700903<Y7@0]:Q/0;BXK030Z700a:A`0<bTM03DY7@0f:1d0=bTN0080<bTM00@0=2XN
03D[7`0f;200=R`P0P0g;B4303/^7@0303`_7P0m<1l0?C0O0080?C0O00L0?S4P03ld8P0o=280?S<Q
03db800l<Al0>c0N0080>RlM0P0n;Ql01P0l;al0>RhN03P_7P0g<1h0=RlM03D`7@80<RlP00@0=2hP
03D]800f;200>2`P0P0i:b0203LY800403HY800d:R00<b/P038/8080<2`P0P0a:al3030Z7P<0;bTM
00D0;BLK02lY7@0a:al0<bdQ03D_8`0203@^8P0303<]8@0b:1`0<RPL00<0<bTM0`0d:Qh0200^9ad0
<2TO038[8@0c;280=2dS03</8P0b:b40<BXP100b;1h303<]7`0403@^800_;QX0;bhJ02l^6R_ooooo
000Zooooo`0509Q]@02IKT40VVm209]`@`2LLD@00P2KL4<00`2JKd80VFe009U]@00609U]@0P0VW0n
202JLCd209]_?P80W70o0`2MLD001@2NLT40X7A309mc@P2OLd80WW910080WG500P2LL3l809ec@@03
0:AhA`2RMTD0XGE40080Wg=200<0X7A30:5eA02RMTD00`2VMTD20:MgAP<0Z7Q72@2SN4D30:AiAP<0
YGY70P2VNdP20:IjB`040:IjB@2VNdP0YW]80:MlA`80Z7e600H0Ygi:0:ImB@2VODT0YGa80:AkA`2S
NTH20:9iA@080:ElAP2TNdD0XgY60:9hAP2PMTH0WgA709icAP2NLdP409id@P0409ec@@2KLCl0VW0n
09U_?@80UFXm00`0U6Tl099W>P2AIST0T6Dh08mT=`2>HcH0S6Hg08]U=P2:I3D0RF<d08QR<`26H342
08EO<00608AM=023G3<0PU/b085J<@1oF2l0OUL^0P1mERd01P1kEC00NEH`07QE;`1fE2h0M5@]079E
;@80L5@/0P1cDBh01`1bDBh0Ke4]06iB;@1/DRd0Je4/06YB;01`Cb`00P1_CR/00`1^CBX0KD`Y06a;
:00206]:9`80ITXU00<0J4XV06]:9`1]BbP00P1_BbT00`1bBbX0ME8Z07IC:`0307IC:`<0Me@/0P22
G2d00`23GBh0Q5h_08EO<00208IP<@0708MQ<P29HcH0RV@g08YT=`2;ICP0S6Hi08eW>P0208iX>`80
TfTg00<0U6Xh09E[>@2FK3X00P2GKC/209Q^?00:09M]>`2EJcT0U6Xh09AZ>02EJcT0Ufdk09Q^?02G
KC/0UV`j09E[>@80U6Xh00<0UF/i09I/>P2FK3X00P2DJC`00`2CJ3/0TVLj095V>@02091U>080Sf@g
00X0SfTl08eW>P2:I3L0R68e08MQ=029HcH0RfDh08eW>P2;H3D0RUld0`29GS<00`2;H3D0S64f08iS
>00208aQ=0<0SF8e0`2>HcH808mT=`0=095V>@2@ICP0Sf@g08iS=P2?I3L0T6Dh099W>P2CJ3/0U6Tf
09EZ=`2FJcP0Uf`i09Q]>P0209M/>@0309I[>02CJCL0U6Xh0080U6Xh0P2EJcT209I/>P<0UW4m0P2E
L3`309A_>`80V6hl00@0Ufdk09I/>P2EJcT0UF/i0P2DJSP809I]>@80U6Xh0`2EJcT309I/>P0309Q^
?02GKC/0UF/i0080U6Xh00<0UF/i09M]>`2HKS`0202CJCL808mZ=P<0TFHi0P2BIcX309=X>`03099/
?@2@JS/0SfTj0080SVPi00<0SfTj091Z>`2BK3d00P2AJc`3091Z>`<0SfTj0P2>JCD208eX=0<0S6Lc
00<0RfHb08eW>02<ISL00P2<ISL208]U=P<0RV@e0P2:ICP01029I3L0R6<f08MR=@27HSD208IQ=080
RfDh02H0RF@g08ES=@23Hc@0PF8c081Q<P1mHC40O5d^07]L;P1jFbd0N5T]07IF;@1dE2d0Le<]079B
;01aER/0L5@/06iB:P1/D2T0JdlZ06]>;01[CRh0K4l_06I<:@1UBbX0HTXX05i79`1JABH0Ed@V05E1
9P1C@RH0Ac/Q04Hj8P12>1l0?CDN03Xd7P0h<al0=S<P03Ld8@80=38K00<0<c4L038_700a;Qd00P0`
;Ah01P0_:al0;2`R02`/8P0[:b40:RXP02TY7`80:2PN00@09bLM02HW7`0V9al09RLO1@0U9Qh8028U
70P082<J00<092DO02<T7P0R8ad00`0R8ad00`0S91h092DO02DV7P0702DV7P0301lR6@0P8aX08B@K
00808RDL00<08B@K020S6P0O8QT0400O8Q/8024R70808R<N00d08R<M02<T700T9Q/09BLJ02HX6`0W
:A/09BTH02L[6P0[;Qd0;RlO038`8@0d<B80<c0Q0080=BlQ00/0=C8S03@a8P0c<240<BhO02l/7@0^
:a`0;BXK02`Y6P0]:Q/0;R/L030]7P02038_8003034^7`0`;Ah0;b`M0080>C0Q00H0>S4P03`d8@0m
=B80?SHQ03lg8010>24:04<i800404@j8@15>b80AS`S04Hl8`80AcdT2018?B4204ln8009050o8@1B
@B<0Dd8T05A39@1EA2H0ETDW05979`1AARH0Cd@T0080CD8R00<0CT<S04m4901@ABD0101B@b@40552
8`0605958`1CAR@0E4DT05E5901FARD0F4DU0P1JABH01P1IAb40FdTS05e;9@1OCBL0H4hX065?:@80
H4hX0P1TDBH00`1WDRL0J54W06YA:00206a@:00306iA:@1XD2X0JE4[0080JE4[0`1ZDR`02P1[Dbd0
JU8^06UA:`1XD2X0J54X06QA9`1ZDbL0JeDV06eG:01_E2L7071E:080KUL[0`1_F2`00`1^Eb/0K5DY
06]D:00206M@9P0306QA9`1YDRP0JU<Y0080Je@Z00@0K5D[06a@:01/D2P0KE4Y0P1^DRX00`1]DBT0
K50X06a@:00206QA9`<0JE8X0`1ZDbT406mD9`80KU<V0`1]DRD806]D:0P0Ke8X0P1[ER/0101/EBT0
KUHX071E9P1bERH207AF9004071C9`1aE2P0LE@X075D:080LUDY0P1cERX307EF9`80MULX0`1gF2T8
07QI:PP0NUh/00T0Of0Y07mP:P1mGbT0NUlZ07QN:`1eGR`0MEd]07=M;01lHC@00P1mHSD01@1lHC@0
NUlb07QM<01eFRd0LeP[00<0M5T/0P1cF2/3079G:P0806eG:01/ERL0K5DY06]D:P1ZDbX0JE4[06Q@
:P1XD2`206M?:`0306I>:P1UCBT0I4`X0080Hd/W00<0HTXV05e;9@1MBbD00P1MBbD305i<9P0905m=
9`1MBbD0GT`V05m=9`1PCRP0GddW05i<9P1LBR@0FdTS00P0EDLR0`1CA2<205938P<0DD8Q0P1:A280
1P1;@R40C44Q04i18@1?@240D44R05508PP0Cd0O101@@B8204m08@<0CSlP0P1=?Ql304ho80<0Cd0Q
201<@B400`16?b80AChQ04@m800204@m800604Dn8@16?b80Ad0S048k8@11>R00@3TO0P0o>1h00`10
>Al0@CXP048k8@02044j7P<0@S/O00@0@CXN03lh700n=a/0?SXO0`0m>Ah203`h7@80>cLL00H0=CPI
03Dh6`0d=aX0=3LL03<e7@0c=Al2038d7`80<38J00<0;c4K02h`6`0];Q`00P0/;Ad0100[;1h09bTN
02LY7P0W:Ah202HX7@<09BLL00H092LN02<V7@0S9Qd08RDL024T6`0P8aX201lR6@807b8K0P0N8AX2
01dP6@8071lH00@071hK01/M6P0K7AX06adJ0P0J71T201TK60P061XI0`0G6AP201HH5`<05ALF200F
5aT801DF60805QLI0`0E5QP301@E5`P05AHH2@0D5AL8014G5aP051DG200B4aDX014G5aP051DG0P0E
5QP201@E5`804a@F0P0B4aDH01@E5aT05AHH0`0E5aH201HH5`<05aTH200F61L801LI60P061PH200G
6AP801XJ60P06QXJ2`0K6aT201`L6PH07AdK0P0L71X301/K6@806QXH0P0K6aT301`L6P0301dM6`0K
6aT06a/I00H06a/I200L71X301dM6`8071`J0`0K6aT@01`L6P0801XJ600I6AL06ATG01PH5P0I6AL0
6QXH01/K6@0L71X901/K6@<07AdK0P0L71X601/K6@8071`J0`0M7A/201`M5`<07AhH0`0N7aT8020O
6PP08R4L0P0V8A/202LR7080:2<M0P0Y91h802XV7@P0;2DM0`0^:1`302dW6`80;2HJ00P0:bLN02PT
6`0V8QT09b<J02/W7P0/:1l0:BDL02HR6@80;2DM00@0:b@L02XS6`0Z8a/0:B8J0P0X8AT802@T70P0
9R4K00@092@L02<S6`0S8a/08b<K0`0R8QX2024Q6@<08R8J0P0S8a/202@T70808b<K0P0T91`202DU
7@809RHN0`0W8Qh202HQ7@<09B0L4@0S8a/00`0T9Ad08b@L024R6P0201lP6003020Q6@0Q8QX08R<K
00808R4L0`0Q81/;020O6PX07b0J0`0N7aT301dN60P08B0K200P7aX801lP6P8081lJ0P0Q81/3028Q
700302<R7@0R8ad08R<M00H08R<M0P0S8a/3028R6P0402<S6`0U9Ad09RHN02DW70809RHL00<0:2DL
02TU700[91`00P0/8a`0100W8aX0:2@K02PT6`0X91/202TU7080:RHM00D0:b@L02`U7@0]9Qh0;RLO
02lX800202hW7`0302dV7P0_:Ad0;bTM00<0<2XN0`0a:al4034W6`80<RPL0P0c:Ad202l/7@06038/
7P0c:ah0=B/O03L[7`0h:Ql0>B/P200d:Qh203T/6`0403X]700l;ah0?C0O03ha8080?c8Q00H0@3<R
03ld8P0n<b40?S<Q03db800l<Al203/`7P0603X_7@0o;b00?blP03`_7`0k;al0>2lN0P0g<1h01`0e
<1d0<c0Q03<`8@0e;b40=RhQ03L]8@0i;B400P0j;24203HX7`0403DX7`0c:Al0<RXO034[7`80;b/O
0P0a:al3030Z7P<0;bTM00H0;RPL02lY7@0a:al0<R`P03<]8@0d;R8203<]8@04038X700c:Ad0<bTM
03<Y7@80=2XN0P0e:al01@0`:Qh0<B/O038/800c;B40=2hR0080<bdQ00<0<R`P03@^800d;R000P0d
;R0303<]7`04038/7P0`;AX0<2dJ030]6R_ooooo000Zooooo`0309M/?`2IKT40Vg130080WG9500<0
W75409U^@@2HKD00202JKT4809Y`?PP0Vg0m0`2JKSd209]_?P<0W70o0P2PM4<00`2OLd80WW9109ea
@00209a`?`0309]_?P2LLT00W79000H0W79000@0YGU80:AhA`2RMTD0X7A30P2OLd800`2PM4<0XGE4
0:MgAP070:MgAPT0XgQ50`2UNTL30:IkB080Yga900T0YWY;0:EiBP2TN4L0Y7U60:EjA`2VNdH0Yga5
0:QmAP2WOTX00P2VODT00`2UO4P0Y7]70:=jAP020:9iA@80Y7]500P0XgY60:5gA@2PMTH0WgA709ic
AP2MLTL0VW0n09ab@080WWA200`0WG=109]a?`2HKS`0UV`j09I[?P2EJSd0U6Tl099W>P2@ICP0SV<f
08aQ=02;H3<208]U=P0408YT=@28HS<0Qf4b08EO<080Q5h_00H0PUdc085L<P20Fc40OeX`07iI;`1m
F2h207aG;@0607]E<01iES00N5D_07ID;P1dE2d0LE@/0P1_Db/207AB;`0707=B;`1aDbl0Ke<^06eC
;P1/DRd0Je<]06m>:`0206i=:P80KD`Y0P1/BbP02@1[BRL0IDTT06I:9@1WBBD0JTTV06a:9`1^BRP0
Kd/Y075::@0207AA:@0307EB:P1fDb/0Me@/0080N5D]00H0NEH^08=M;P23GBh0Q5h_08EO<026H342
08MQ<P0708QR<`2:I3L0RfDh08]U>02<IST0SFLj08iX>`0208mY?0<0U6Xh00<0UF/i09I/>P2FK3X0
0`2GKC/01`2FK3X0UF/i09AZ>02DJSP0UF/i09I/>P2GKC/00P2EJcT00`2DJSP0TfTg09=Y=`0309=Y
=`80U6Tl00<0TfPk099W>P2AIST00P2@ICP208mT=`0A08iX>`2=IcX0RfDh08US=P28HSD0RF<f08]U
>02<IST0Rf0e08YO=029GS<0R5db08UN<`2:Gc@0S64f08eR=`2;H3<00P2<HC@0102=HSD0SV<f08mT
=`2?I3L4091U>080Sf@g0`2>HcH0202AIST0T6Dh08mT=`2>HcH0Sf@g091U>02BIcX0TfPk0P2EJSL2
09I[>0@0Uf`i0`2DJSP209E[>@<0UV`j00@0V7<o09Mb?P2GLSh0Ug8n0P2FLCd209E`?00609Y`?P2I
Kcd0V6hl09M]>`2FK3X0U6Xh0P2CJCL809I]>@80TfTg00<0U6Xh09E[>@2FK3X00P2GKC/0102HKS`0
Ufdk09I/>P2EJcT209AZ>00309E[>@2FK3X0Ufdk00P0U6Xh202@JcL4099W>P@0TfPk00<0TV`m091Z
>`2?JCX00P2>J3T00`2?JCX0T6Xk099/?@02095[?0<0T6Xk0`2?JCX308iY=@80SFPd0`2<Ic<308]W
=`80RVHf1029ICD208YU>00408UT=`28HcH0Qf8e08IQ=080QF0c01H0RV@g08US=P27HSD0Pf4c085Q
<P1nGc00OEh_07YN;P1hG2`0Me//07IJ:`1eF2`0LeH/079E;@1aDbd0L58/06mD:@1_Db/0KE4Y06a@
:@1[CbX0JTd[0P1YC2`03P1SBbT0HDPY05i79`1IA2D0ED8T05919@1A@2H0D40V04Di8@13=al0?c@N
03Xb7@0g<1d0=C0M0P0d<B0203<a7003038_700a;Qd0<2dN0080;b/O00D0;RXO02XZ800Z:R00:RXP
02TY7`0202PX7P809bLM0P0V9al402DV7P8092DM200R9A`8020S6P0302@U7@0S91`08b@L00@08b@L
00<092DM02HW7`0V9al01P0V9al00`0N8AP082<J024T6`02028U7003024T6`0P8aX07R4H01007b8K
0`0Q8QX4028S6`0>02<T700S91h08b@N02<T700S9AX09BLJ02LY700Y:ad0:R`N02L[6P0X;1/0;2lN
030a8@0c<B8203Db8`80=S0R00`0<c0Q038_800a;Ql0<2dN02h[700/:AX0:bPI02XW600_:AT0<2XJ
03<]7@0e;al303H`800703D_7`0k<R<0?3<R03de8P0n=R<0?cLR040h8@02044j80P0@cTP0P12>1l0
1P13>B00AC/R04Hl8`17?B@0B3hU04To9P@0B3dQ1019?R801P1@@B80DD8S0593901CA2D0E4DV05E6
9`80ETLX00<0DdPX05979`1@ABD00P1?A2@00`1@ABD0DDHV05979`0405=49@@0DT<T0P1CAR@0101E
ARD0ETHU05M79P1IARH205Y59P0605U78`1JB2@0FdTU05e;9`1OCBT0HDl[0P1RD2`0201UDRL0IU<X
06QC:01YDRP0Je8Y06eA:@1^DRX0Ke8Z1@1YDB/306YB;00806YB;P1YDB/0J50Z06M@9`1XDBL0JE8V
06]E9P1/ERL306mD9`@0L5DX00<0LEHY06mH;01_F2`00P1_F2`206iG:`0306eF:P1/EBT0JE0W0080
JE0W00<0JU4X06]B:@1[DRT00P1/DbX206a@:0@0KE4Y0P1/D2P206QA9`<0JE8X0`1ZDbT3071E:080
Ke@W0P1^DbH206eB9@P0JU@U00<0Ke@Y06iC:01^DbP00P1^DbP306eB9`0606YD:`1ZEBX0K5D[06eE
:@1_E2L0LEDV0P1cE2D2071C9`<0LE@X0`1bEBT307EF9`<0MULX0P1gF2T807QI:P<0NEd[101jGR`0
2P1kGbd0OUlX07iO:@1mGbT0NUlZ07QN:`1fGbd0MEd]07AN;@1lHC@307eR=@0407aQ=01iGS40Me`_
07IK;P@0MEX]0P1dFB`207=H:`80KUPW00H0KELX06eF:P1/EB/0Je@[06YC:P1ZDR`206Q@:P80IdlY
00@0IThX06E=9`1TC2H0I4`V0P1LB2<0101MBB@0GTXU05i:9@1OBbH2061<9`0805e;9@1NC2H0GddW
061>:01OCBL0GT`V05a:901KBB<405M78`@0ETHR0`1CA2<205938P<0DD8Q00P0BdDS04Y48P1;@R40
Bd0P04e0801?@240D44R05918`P0Cd0O101@@B8304m08@80CSlP0P1=?Ql304ho80<0Cd0Q0`1=@R84
04a18@0304]08015?R40A3dP00<0AChQ00@0ASlR04M08`17@2<0@c`P0P12>al5044j7P<0@S/O0P11
>Qh2040i7@0503lh7010?240@3`Q03lk800n>Ql00P0m>Ah203`h7@0803Hi6P0e>1/0=CPK03@g700c
=Ad0<S@N038d7`0a<ah202la6@0302la6`0^<1/0;RlM0080;RlO00D0;RlQ02T[7P0Y:ah0:2XM02LY
700202HX6`809BLJ00H092LN02<V7@0S9Qd08RDL024T6`0P8aX201lR6@807b8K0P0N8AX201dP6@80
71lH0P0L7Q/301/M6P<06Q`I200H6QT301LI60805QPG0`0E5aH801HG6@P05AHH0P0F5aT301DF60<0
51DG200E5QP901@E5`P04ALG600D5AL8018C5BP04ALG600D5AL201DF608051DG0P0C51H2018C5AP0
51DG6@0E5QP301DG5P805QPG0`0G6AP801HH5`P05aTH200H61P801LI60P06QXH200J6QX;01/K6@80
71`J1P0M7A/201`L6PH06a/I0`0L71X201dM6bP071`J100I6AL201XJ60806a/I2@0L71X301dM6`80
71`J1P0K6aT201`L6P<07AdK0P0L7AL301dN60<07QlI200P7aX8028Q70809R4K0P0W8Q`202PS7@80
:B@N200Z9Qd802`U7@06030Z7P0_:Ad0;bTM02hX700]9a/0;2HJ0P0[9AT02@0[9ah0:2@K02HR6@0W
8aX0:bLN02`X7`0Y9A`09R8I02/T700202XS6`80:B8J0P0X8AT00`0W81P092@L02@T700602@T70P0
9R4K200S8a/3028R6P808b<K0`0T91`202<S6`8092@L0P0U9Ad202HV7P<0:2<M0P0W8Q`302HQ6a40
8b<K00<092DM02<T700Q8QX00P0O81P00`0P8AT08B8J028S6`06024P6`8081lJ200Q81/:01lP6PH0
7QlI400Q81/801lP6P<08B0K0`0R8A`202<R7@P08R<M100S8a/03@0T91`09BDM02DU7@0V9Qh092HK
02DU6`0V9Q`0:2DL02XV7@0]9Qh0;RDN02lV7`0X91/00`0Y9A`202XV7@80:bLN0P0/9Ad202dV7P@0
;RLO100b:Qd403<[7P@0<RPL100c:Ad2034^7`0403<]7`0e;B00=R`P03T]8@80>R`Q00@0=B/O03@Z
7P0d:Qh0=2XN0`0c:Ad01`0b:1`0>2/J03P[6P0j;A`0>bhM03d`7`0o<R400P10<b800`11=2<0?S<Q
03hc8@0203db8080?34O0P0k<1h203l_800303d`800k;al0>C0O0080=c0N00L0=S4N03@a800d<B00
=S0P03L`800h;b00>RhP0080>bdP0P0e9ah0100d9ah0<RPN034Y7P0`:Qh202hZ7P80<B/O0`0`:Qh4
02lY7@03030Z7P0a:al0<B/O00@0<R`P0`0c:Ad203@Z7P<0=B/O00@0<B/M038/7P0c;Al0<bdO100d
;R001P0g<B<0=S0R03H`8P0e;b40=2hP03<]7`80<R`N0`0b;1`[ooooo`00:_ooool00`2HKD00VFi1
09aaA00209ebA@0309]`@`2IKT40Uf`o00P0VVi1202JL3h809e_?@80VFdl0P2JKSd309]_?P0509a`
?`2PM4<0Wg=209mc@P2NLT400P2MLD0209a`?`P0W79000<0YWY90:AhA`2RMTD00`2PM4<20:5eA0P0
YgM62@2SN4D30:EjA`<0YW]80P2WO4T02@2VNT/0YGU:0:=gAP2RMd@0XgQ50:EjA@2WO4D0Z7e60:Mn
BP020:ImB@030:ElB02TNdL0XgY60080XWU501P0Y7]50:=jA02RNDD0XGM50:1fAP2NLdH0WG9509eb
A`2IKcd0VW0n09ab@02MLd40W79009U_?@2FK3X0U6Xh09I[?P2EJSd0TfPk095V>@2?I3L0S64d08YO
<P29GS4208YT=@0408US=027HC80QV0a08AN;`80Ped^0P20Fc4207mJ<00:07iI;`1mF2h0OEP^07aG
;@1jE2l0N5D_07MD;P1eDbd0M5@]075D;080Ke<[0P1dDRl01P1cDRl0LE<_06mC;P1]Dbh0K58]06]C
;@@0KD`Y101/BbP206I:9@0306Q:9P1[BRL0KD/X0080Kd/Y00T0LT/Z06m<901`CBD0LTlW07EB:P1h
EBd0NUL_07aI<@1mFS800P24GRl00`25Gc00QV0a08MQ<P0208QR<`0708US=02;ICP0S6Hi08aV>@2=
IcX0SVPk08mY?002091Z?@0309AZ>02EJcT0UF/i0080UF/i0`2FK3X00`2GKC/0UV`j09AZ>00209=Y
=`0309AZ>02FK3X0Ufdk00@0U6Xh00@0TfTg099X=P2BJ3H0TFLe0P2DJC`00`2CJ3/0TVLj095V>@02
091U>080Sf@g00D0SFLj08aV>@2;ICP0RV@g08US=P0208YT=`0308]U>02:Gc@0REhc00<0R5db00<0
RUld08aQ=P2=HSL00P2<HC@0102=HSD0SV<f08iS=P2?I3L5091U>080Sf@g0`2>HcH0202AIST0T6Dh
08mT=`2>HcH0Sf@g091U>02BIcX0TfPk0`2EJSL209I[>080Uf`i00<0V6dj09AZ>02DJSP00P2EJcT2
09I/>P80Ufdk0P2HLcl309Mb?P<0UW4m0P2JL3h01P2IKcd0Ufdk09I/>P2EJcT0U6Xh09=Y=`P0Ufhj
0P2CJCL00`2DJSP0UF/i09I/>P0209M]>`0409Q^?02GKC/0UV`j09AZ>080TfTg00<0U6Xh09I/>P2G
KC/0202DJSP8091[=`P0TfPk00<0TV`m091Z>`2?JCX00P2>J3T00`2?JCX0T6Xk099/?@02095[?0<0
T6Xk0`2?JCX208mZ=P80SVTe0P2=J3@208aW<`80RfLg0P2:ISH208UU=@<0R6@d0P29I3L01028HcH0
Qf8e08MR=@26HC@208EP<`0>08IP<`25Gc80Peha07mM;`1lG2d0NEX[07QI:P1eFBT0ME/Z07EJ:`1d
FBX0LeP[075F:`1`E2`206mC;00F06iC:01^DRX0KE4Y06a@:@1ZCRT0J4/Y06M::P1VBBT0H4TY05i7
:01H@b@0E44S04ln8P1>?B<0CShU04do9@13=b40@CDO03db7P0h<1d0=BhL03@^7P80<RlP0P0b;a`0
0`0a;Qd0<2dN02l[7`0202hZ7`0302dY800Y:Al0:2PN00<0:2PN0`0W9ad202HW7`809BHN0P0T9Ad2
02<T70P08B@K200P8aX00`0S9AX092HK02@V6`0402@V6`0302<U6P0U9Qh09BHN00H09BHN00<07R4H
01lR6@0P8aX00P0R9A`00`0P8aX07b8I01hQ600@01lR6`808B<H0P0R91T01P0S9AX092HK02@V6`0T
9Q/09BHN02@U7@8092HK00/09BLJ02PZ700[;Qd0;C0O02T]700Z;Qd0;C0O034b8P0d<R<0=C8S03@a
8P0203D_8@80<BhO00`0<2dN02l/7@0^:a`0;BXK02`Y6P0[:1T0<BXH03</6P0e;Q`0>34O03Tb800j
<b4203Tb800603dd8`0n=R<0?SHS03lg8P10>240@3TO0P11>Qh804<i8080@SPO00L0@cTP04Dk8P16
?2<0AcdT04Pn9@19?bH0Ac`P0080B3dQ0P19?R8204Xo8`0504]0901AA2@0DTDU05959@1CARH00P1D
AbL205E8:00305979`1AARH0D4DU0080Cd@T00<0DDHV05979`1CB2P00P1DABH205=49@80DT<T0P1A
@R<205=6900405A5901FARD0ETHU05U69P80FTDV0100F4DT05U69@1IARD0FdPW05e::@1OC2/0H4d/
065>;@1TDBH0IE8W06MB9`1XDBL0JU4X06a@:01]DBT0KU4Y1P1XD2X206M?:@0806Q@;01XD2X0IThX
06I?9P1VCbD0J54U06YD9@1[EBH206eB9`80KU<X00D0Ke@Y071E:P1`EBX0L5DZ06mH;00206iG:`03
06eF:P1/EBT0K5DY0080K5DY00<0JdlW06a@:01/D2P00P1/D2P306eA:@P0K50X0P1XDBL306UB:0<0
JU<Y101`EBP206mD9`<0KU<V201ZE2<206eE:@80K5@X00X0Je<W06YB9P1ZDRH0JU8V06UC;01YDbX0
Je@[06aC:P1_E2T0L5<W0P1bDbD3071C9`<0LE@X0P1bEBT207AE9P<0MEHW0`1fEbP807QI:P80N5`Z
0P1iGB/04`1jGR`0Nel]07]O;@1kGbd0OUlX07eN:01lGRP0NUlZ07UO;01fGbd0MUh^07EO;P1jGc80
Nf0c07aQ=01mHSD0O64d07YO<P1hGC000`1gG2l207IK;P@0MEX]0P1`FRP01P1_FBP0KUPY06eF:P1]
ER`0K5D[06aE;080JU<Z00@0JE8Y06QA:01WD2L0ITlV0P1UCRD01@1NB2<0GdTT05m9901PBRD0HD/V
0080HT`W00X0HddX05e;9@1NC2H0GddW061>:01OCBL0GT`V05a:901KBB<0FDTU0P1HB2@205M78`80
ETHR00@0EDDQ05=48`1CA2<0Dd@S0P1B@b8305528@0804a6901:A280Bd8Q04Xo7`1<?al0Cd0Q0511
8P1C@R@8051180<0DD8S0`1@@B8304m08@80CChO0`1>?b0304m08@<0CT<S00<0CD8R04a18@1<@B40
0P1;@20204Ln8@80B3lR0P19@2<204Po8P<0A3dP0P13?1l00`12>ah0@CXM040i7002048k7`80@CXN
1010>Ad2044m8P0<040l8@0o>b00?SXO03di7P0l>1d0>cLL03Hi6P0f>A`0=CPK03@g700c=Ad0<S@N
0P0a<ah202la6@0302la6`0_<A`0;c0N0080;c0P00L0;c0R02/]7`0Z;1h0:B/M02PZ700W:A/09RPJ
00809BLI00H092LN02<V7@0S9Qd08RDL024T6`0P8aX201lR6@807b8K0P0N8AX201dP6@8071lH0`0L
7Q/301/M6P806Q`I200I6aX301LI60805QPG0`0E5aH801HG6@P05AHH0P0F5aT301DF60<051DG200E
5QP901@E5`P04ALG600D5AL8018C5BP04ALG600D5AL201DF608051DG0P0C51H2018C5AP051DG6@0E
5QP301DG5P805QPG0`0G6AP801HH5`P05aTH200H61P801LI60P06QXH200J6QX;01/K6@8071`J1P0M
7A/201`L6PD06a/I0`0L71X301dM6bP071`J0P0I6AL00`0J6QP06a/I01/K6@0201`L6P0301/K6@0L
71X071`J00L071`J0`0M7A/201`L6PH06a/I0P0L71X301dM6`8071dG0`0M7QP301hO6@P081lJ200R
8A`202HQ6`809b8L0P0X8ad202TT7PP0:RHM200/9Ad01P0`:Qh0;bTM02lY7@0^:1`0;BLK02`V6P80
:bDI00P0:bLN02PT6`0V8QT09b<J02/W7P0/:1l0:BDL02HR6@80:R<K100Y8QX202PQ6@P09BDM200W
8Q`402<S6`@092@L0P0R8QX202<S6`8092@L0P0U9Ad202<S6`8092@L0P0U9Ad202HV7P<0:BDL0P0X
91/302LS6PP092@L2@0S8a/00`0T9Ad08b@L024R6P0201lP6003020Q6@0Q8QX08R<K008081lJ3P0Q
81/801lP6P807QlI1P0O81X@024P6`P07b0J0P0Q81/3028Q70<08b8M200S91h0100S8a/092@L02@T
700U9Ad402HV7P0802@V6`0U9A/09RHL02TV7@0[9ah0;RLO02lV7`0`9b0202TU7080:RHM0`0[9ah0
100/:1l0;2DM02`U7@0/9Ad202dV7P80;RLO00<0;bPP03D/7@0e;1d01P0e;1d403@Z7P@0<bTM0P0a
;Ql0100d;R00=BdP03L]8@0i;B4203X/8@<0=B/O0P0d:Qh303<Y7@80>2/J00@0>RdL03/^7@0m<1l0
?c8Q0P10<b800`11=2<0?C8P03db800203db80@0?34O0P10<2401P0m<200?30P03T`7`0h<Al0=c0N
03Ha7P80=34N00@0=S4N03L`7P0h;ah0>RhN0P0k;Qh203HX7`0403DX7`0c:Al0<RXO034[7`80;b/O
0P0a:al3030Z7P<0;bTM1@0`:Qh00`0a:al0<R`P038/800203<Y7@80=2XN0P0e:al203H/80@0<bdM
0P0d;Qh0100e;al0=S0P03La8`0g<B<203H`8P0403D_8@0d;R00<bdO03<]7`<0<b/N:oooool002[o
oooo00P0VVm209]`@`2KL4<0W75409]`@`2JKd80VFi109Q]@0P0Vfm2202JL3h809i^?@<0VVhm0P2K
Kch309a`?`P0WW91202MLd40202UNDP0Y7Q70:9fA@2QMD@0X7A30:5eA02RMTD0XgM60`2XN4L20:Mg
AP<0YWI52@2SN4D30:AiAP<0YGY70P2VNdP00`2VNT/0Y7Q90:9fA@020:5f@`040:=h@`2VNd@0Z7e6
0:MnBP80YWe900<0YGa80:AkA`2SNTH00P2RNDD20:=jA0070:9iA@2QMdD0WgE509icAP2MLTD0W756
09U_?@0309Y`?P0<09U_?@2GKC/0UV`j09E[>@2EJSd0U6Tl099W>P2@ICP0SV<f08aQ=02:Gc80REha
0P29Hc@01P28HS<0QV0a08EO<024GRl0Ped^089L;@<0OEX`0P1lFBl207]H;P0907YG;@1jE2l0N5D_
07MD;P1eDbd0Le</071C:`1_Db/0KU8Z0080Le4^00H0LU4^06mA;@1^DRd0K58]06]A;01ZDR`806a;
:00@06M;9P1XC2L0JD/W06a;:01^C2T0L4`Z075=:`1cC2/0KDXR06m<901aCRH0M54Y07QE;@1kF300
OU/c07mL=080QEl`00<0QV0a08MQ<P28HS<00P29Hc@01`2:I3D0S6Hi08eW>P2=IcX0SVPk08mY?02@
JSd00P2AJch809E[>@0309I/>P2EJcT0U6Xh0080TfTg00<0U6Xh09E[>@2FK3X00P2EJcT209I/>P04
09E[>@2CJCL0TFLe091V=080U6Tl00<0TfPk099W>P2AIST00P2@ICP208mT=`80S6Hi00<0RfDh08YT
=`2:I3L00`2:I3L02@2:Gc@0REhc08QM<P27G340R5db08UN<`2;H3D0S64f08eR=@0308iS=P`0Sf@g
00P0TFHi091U>02?I3L0SV<f08mT=`2@ICP0TVLj09=X>`80UV/h0`2EJSL00`2FJcP0V6dj09U^>`03
09E[>@80UV`j0`2GKC/309Mb?P80UW4m0`2EL3`209U_?@80V6hl00@0Ufdk09I/>P2EJcT0UF/i202G
KSX209AZ>0<0UF/i102FK3X01`2EJcT0U6Xh09=Y=`2CJCL0U6Xh09E[>@2FK3X0202EJcT8091[=`04
09EZ?@2DJC`0U6Tl09AY?0<0TfPk00@0TVLj099/?@2@JS/0SfTj0P2>J3T00`2?JCX0T6Xk099/?@02
095[?0<0T6Xk0`2?JCX308mZ=P80SVTe0`2=J3@308QV=P80QfDe1026I3@208UT=`0308QS=P27HSD0
QV4d0080QF0c00X0Q5lb089L;`22G2l0P5/^07aJ;01jFR/0N5TZ07MH:@1dF2P0M5XY0P1cF2T00`1b
EbX0LEH[071D;00206mC;00H06aA9P1/D2P0K50X06]?:01YCBP0IdXX06A79`1SARH0G4LX05Y59P1D
@B<0CSdQ04`k8@1:>R40BS/T04/l9@12=B80@3<P03`a7`0g;Qd0=2dM03<]7`0a;Ql0<BdQ0P0a;Qd0
0`0`;Ah0;b/O02hZ7`0202dY800302`W8@0W9ad09bLM00H09bLM0P0V9al202DV7P0402@U7@0S91`0
8R<K028S6`P08B@K200P8aX00`0S9AX092HK02DW700302DW700302@V6`0S9AX092DM00L092DM00<0
7R4H01lR6@0P8aX00P0Q91/00`0P8aX07b8I01hQ600801hQ6PP07b8K00H08B<H028T6@0R91T08bDJ
02@V6`0U9a`202HX7@0?02HW7`0U9a`092HK02@V6@0V:1X0:B`K02d`7@0`<b00:blN02``7`0^<B00
<34Q038`8@0b;b00<BhO0080<R`N200_;1d0100d;1T0=RhK03P`7@0k<b0303`d8@0703/c800n=R<0
?SHQ03hf8@0o=b00?cPN040i7@02040i70P0@SPO0P13>B001014>R40AC/R04Hl8`16?2<204Lm9080
Ac`P00<0B3dQ04Tn8P1:?b<00P1;@2@0101<@BD0D4DU05159@1@ABD205569P<0DTLW00T0DDHV0515
9@1?A2@0CT<S04m4901@ABD0DTLW05=8:01DABH00P1CA2D01@1B@b@0DD8S05118P1@@B80Cd0Q0080
DD@R00H0Dd@S05A48`1EAB@0Ed@T05Q3901IA2D205Q59@0?05M4901HABD0FDHV05]8:01MBRX0Gd`/
065>8`1RCb@0I4lT06E>901WCRD0JDdU06Y>9P1[CRH0IdlY00<0IThX0`1UCBL02@1TC2H0IThZ06E=
9`1TC2H0Hd`S06A=8`1UCR80Ie4R06QB8`0206]?9`80K50X00L0KE4Y06iB:P1_Db/0Ke<[06iG:`1]
ERX0Je@X00<0JU<W0P1[E2P806e@:00306eA:@1/D2P0JdlW0080JThV00<0JdlW06a@:01]DBT00P1X
DBL306UB:0<0JU<Y0P1aERT3071E:080Ke@W0P1^DbH806]E8`80K5DY00@0Je@X06YC9`1YDRH0JE8V
0P1XDBD0201XDRd0J58[06YB;01[DRX0KU8Z06mB:01aDRH0LU<W0P1_DRH2071C9`<0LE@X00@0LUDY
07AE9P1dEBH0M5DV0P1eERL307IG:0P0N5TZ00H0Me/Y07QL:P1hG2X0NEd[07YN;01kGbd207aP;P0;
07eN9`1mGRP0O5hX07YO:P1iGb`0Mf0^07MO;`1fH2l0N5d`07UN<@1jGc800P1kH3<00`1jGc80NEha
07ML;`0307QM<080Me`_0`1fFbh2079M:006075K:@1`FRT0KeTZ06iG:`1^Ebd0KEH/0P1[E2X00`1Z
DbT0JE8X06QA9`0206M@9P0406I?9@1RBRH0HTXV069:9P<0Hd/W0P1TC2P02@1MBbD0GT`V05m=9`1P
CRP0GddW05i<9P1LBR@0FdTS05a:9P0205]99@0305Y8901IAb<0F4HR0080EdDQ0`1CA2<205938P<0
DD8Q00P0CDLU04]58`1:@B00BChN04/n7P1>?b00DD8S05A39@P0D44P101A@R<205118P<0Cd0Q0P1=
?Ql304ho80<0Cd0Q0P1?A2@204i38`0404e28P1<@B40Bd0P04]08080BSlS0P1;@2@01@1:?b<0BChR
04Pm8@17?200A3dP00<0AChQ00T0A3dP04<l7`11>Qd0@3TL04<l8012>al0@CXN040i7@0o>1`00P10
>Ad04@11>Qh0@CdR044m8P10?240?SXO03di7P0l>1d0>cLL03Xf6`0g>Q/0=STL03Dh6`0d=a`0<cDM
038d7P0a<ah0<38M0080<38J00<0;c4K02la700_<1h00P0_<2002P0_<280;2lN02`_7P0[;Qd0:B`K
02P[6P0W:QT09RTH02DX5`0T9ah202<V7@03028U700Q91/082<J00807b8I0P0O8Q/201hQ6P807B0I
0P0L7aP201dO708071hK0`0K7AX00`0J71T06A/J01TK6P0601TK6P<05aTH0P0F61L301DG5PP05QLI
200E5QP201HG6@<05AHH0`0D5AL801DF60T051DG200A5aLH01@E5`P04Q<E:00A5aLH01@E5`805AHH
0P0D5AL201<D5P804Q<E600D5ALI01DF60<05ALF0P0F61L301LI60P05QPG200G6AP801PH60P05aTH
200J6QP801XJ6P/06a/I0P0L71X601dM6`8071`J100K6aT301`L6P807AdK0P0N7Q`801dM6`P071`J
0`0K6aT201`L6P<07AdK400L71X00`0J6QP06a/I01`L6P0301hN70h07AdK0P0L71X601/K6@8071`J
0`0M7A/201`M5`<07AhH0`0N7aT8020O6PP08R4L0P0V8A/202LR7080:2<M0P0Y91h802XV7@P0;2DM
0`0^:1`302dW6`80;2HJ00P0:bLN02PT6`0V8QT09b<J02/W7P0/:1l0:BDL02HR6@P0:R<K200U9Ad8
02LR70<08b<K0P0T91`302DU7@<08b<K0P0T91`302DU7@808b<K0P0T91`202DU7@809RHN0`0Z9Qd2
02TU70<0:2@K200T91`902<S6`0302@U7@0S91`08B8J00807b0H00<0824I024R6P0R8a/00`0P7aX3
024P6`808R4L200Q81/801lP6P807QlI0`0O81X3020Q6a008B0K200O81X0100Q81/08R4L028Q700R
8A`202<R7@8092<N200S91h00`0S8a/092@L02HV7P0302LW7`809RHN00P09BLL02HV700W9ad0:BHM
02/W7P0^9al0;bHO030W8080:RHM0P0[9ah302`X7`0302dY800]9Qh0;BHN00<0;2DM00<0;BHN02lX
800`:B40100i;Ad203P/7080=b/K100e:al203@Z7P80<bTM00H0<2dN034^7`0c;Al0=2`O03H/800h
;20203X/8@D0=B/O0`0f;20203T/6`0403X]700l;ah0?C0O03ha8080?c8Q00<0@3<R03db800m<R00
0P0m<R0403`a7`80@30Q00<0?S4Q03``800j<B000P0h<Al01`0g<Ql0=C<N03Dc7P0g<Qh0>34N03Ta
7P0k<1h00P0l;ah203LY800403HY800d:R00<b/P038/8080<2`P0P0a:al3030Z7P<0;bTM0P0a:al0
1P0`:Qh0;bTM02lY7@0`:Qh0<B/O038/80<0=2XN0P0e:al303H/800803D`7@0d;a`0=2lL03<^6`0d
;a`0=C0M03Ha7P0g<Ql303La8`<0=S0R0P0e;b4303@Z82_ooooo000Zooooo`0309ebA@2LLD@0Vg13
00@0VFi100<0VVm209]_@P2KKd801P2KKd8809Y`?PP0WVhm0P2KKch309a`?`<0WG5000H0Vfln09a`
?`2LL3l0WG5009ib@@2OLd820:1d@`P0WgE300<0XgM60:9fA@2QMD@00P2QMD@0102RMTD0Y7Q70:Ei
B02YNDP20:QhA`80YgM60P2VMTD00`2UMD@0XgQ50:=hA@070:=hA@80XWM40`2SN4D30:AiAP090:Ij
B`2TN4T0XGE409md@@2PMD80XWM20:IkA02XODH0Ygi:0080YWe900<0YGa80:AkA`2SNTH00P2RNDD2
0:=jA00:0:9iA@2PMT@0WgE509ebA@2LLD@0W75609]a?`2JL3h0V6hl09I/>P80UF/i0P2FK3X0402C
J3/0TVLj095V>@2?I3L0SF8e08aQ=02;H3<0RUlb08US=028HS<0Qf4b08IP<@24GRl0Ped^089L;@21
Fb`407]J;`@0NUT^00H0NU@_07MD;P1gE2h0ME<]07=C;01`Db/206iB:P80LU0]00<0L4l/06i@;01]
DB`00P1ZD2/0101YDB/0JdXW06]:9`1[BRL506a;:080JDdX00H0JddY06i=:P1`CR/0LTh/07=?;@1e
CRd2075>9P0707=@:01eDRX0Me@/07UF;P1kF300O5Ta08EO<00208IP<@0308MQ<P28HS<0RF<d0080
RV@e0P2=IcX00`2>J3/0SfTl091Z?@02095[?P03099/?`2FK3X0UV`j00H0UF/i00<0UV`j09E[>@2C
JCL00P2BJ3H0102CJCL0UF/i09I/>P2FK3X309M]>`0409I/>P2DJSP0TVPf091V=080U6Tl00<0TfPk
099W>P2AIST00P2@ICP208mT=`80S6Hi0`2;ICP208YT=`0408US=P2:Gc@0REhc08QM<P80Qe`a00<0
REhc08]P=@2<HCH00P2@ICP308mT=`<0SV<f0P2=HSD0102>HcH0Sf@g08mT=`2@ICP3095V>@0?091U
>02?I3L0SV<f08mT=`2@ICP0TVLj09=X>`2GK3T0UV/h09EZ=`2DJCH0UFXg09I[>02HKCX0VFhk0080
UF/i0P2FK3X409M]>`<0UW4m0P2EL3`309A_>`@0V6hl102GKC/809Q_>`<0UV`j0`2EJcT209AZ>003
09I/>P2EJcT0TfTg0080TVPf00<0TfTg09E[>@2FK3X0202EJcT8095/>0<0UFXm00<0U6Tl09=X>`2C
J3/00P2BIcX00`2BK3d0T6Xk08mY>P0208iX>@0308mY>P2@JS/0TV`m0080TF/l0`2@JS/308mY>P@0
SfXf0P2>JCD208eX=080QfLf0P26ISD508EU=00608UT=`28HcH0R6<f08MR=@26HC@0QF0c0P24Gc82
089L;`07081K;P1nG2h0O5`]07]L;@1jFb`0N5`/071I9`02071H:00606mG:@1^ERX0KE@[06eD;01/
Db/0Je0U0P1/D2P04`1[CbP0JDdX06I99`1SARH0HD@T05]6:@1GA2H0DShS04`k8@18>1l0AcPQ04Hj
8P18?2H0@SDT040c8P0l<200>2lP03D]800c;Al00P0a;B401P0a;Qd0<2dN030]7P0_:al0;RXO02dY
8080;2LQ1P0V9Q`202LW7@0602LX800V9al09BHN02@U7@0S91`08R<K0P0Q8QX@020S6P0302<U600T
9QT09BLJ00809RPK00<09BLJ02@V6@0S9AP0200R8a/00`0M81L07R4H020S6P02024T6`03020S6P0N
8AP07B0G00P07R4J200O8Q/01P0Q8aH08R@G02<U600T9QT09BLJ02HX6`809bTL00P0:2XO02HX6`0U
9aX092HH02HY600[;Q/0;c8M038e8080;C4P00D0;c8Q030a8@0a;b00<2dN02dZ6`0202hX6P80;BXK
00@0;R/L02l/7@0a;Ql0<RlP0P0c<240100g;aX0>C4L03/c7P0l=1l203de800703`d7`0k<ah0?SHQ
03hf8@0n=Ql0?SLM03hg6`0203lh6`0303li6@12>1l0@SPO00H0@SPO1`15>b802@16?2<0Ac`P04Ll
8018?B40BChR04Xo8`1;@2@0C44U04e29P0505159@<0DDHV0P1?A2@01`1>@b<0CD8R04i38`1?A2@0
DDHV05=8:01CA2D00P1B@b@01@1A@R<0Cd0Q04ho801>?b00CChO0080Cd8P00h0DD8Q05928@1C@b80
ED8R05I18P1G@R<0F4DU05M4901F@b<0ED8R05I38`1GA2@0FDHV05]8:080GT/P00<0H4/P069;8@1S
BR400P1VBR80101WBR80IDdW06A<9P1TC2H206=;9@80HTXT00T0HDTS06=;9`1SBbD0HDTS065:8@1Q
BR00Hd`P06E?801VD2400P1XC2D02@1YCBH0JThW06]?:01/D2T0KE4Z06iB:`1/EBT0Je@X06UB9P03
06M@900406UB9P1ZDbL0L50Y071@:@H0KdlX00<0KE4Y06a@:01ZCRH00P1YCBD00`1ZCRH0K50X06eA
:@0206QA9`<0JE8X0`1ZDbT3075F:@<0L5DX0`1_E2L806eH8`80JeHY00@0JUDX06UD9`1XDbH0Ie8U
0P1VDB@01P1WDB`0J58]06UA:`1ZDBT0KE4Y06iA:@80LE4X0`1_DRH2071C9`<0LE@X0P1cE2D207AE
9P<0MEHW00<0MULX07QI:P1hFBX01P1hFBX207MK:@0A07QL:P1iGB/0NUh/07]O;@1lH2h0OF4_07aM
9P1lGBL0O5hX07YO:P1iGb`0Mf0^07MO;`1fH2l0MEX]07ML;`1hGC000P1jGc800`1iGS40N5d`07ML
;`0307UN<@80N5d`0`1gG2l01P1dGbP0LehY07=N:@1bG2X0LE/Z071J:`80KeP/0P1/EB/00`1[E2X0
JU<Y06UB:00206QA9`0306M@9P1WCBX0IddZ00<0IT`Y0`1UBbP03P1MBbD0GT`V05m=9`1PCRP0GddW
05i<9P1LBR@0FdTS05i:9`1MBBH0G4PU05]7901JAR<0FDDR0P1HA24305=48`80DT<R0`1A@R40201=
AbD0BdDS04Y18019?Qh0BchN04ho801A@R<0E4<U201A@R4305939080DD8S0`1@@B800`1?@240CChO
04dn7`0304ho80<0Cd0Q0P1@ABD0101?A2@0CT<S04e28P1<@B4204]08080CT0U00L0Cd4V04i09@1=
?b@0BS`Q04Pj7`16>1d0AClO0080AT0P00P0Ad4Q04Do7`13?Ad0@C/K03li6@14?B40@c`P044j7P<0
?cPL0P11>Qh04011?B80@3`Q03lk800m>Ah0?3PM03Xf6`0i=AX0>3@I03Pk700g>Qd0=STL03@g700c
=Ad0<C<M030b7@0_<A`2034c6`06034c7@0`<Qd0;c0N02l`800^;al0;RlQ0P0]<1d01`0/;a`0:RdJ
02T/6@0W:QL09RTF02DX5@0T9ah00P0S9Qd00`0R9A`08B@K020S6P0201lR6@807b8K0P0N8AX201dP
6@8071lH0`0M7a`201`N6`<06adJ200J71/301LI60805QPG0`0E5aH801HG6@P05AHH0P0F5aT301DF
60<051DG200E5QP901@E5`P04ALG600D5AL8018C5BP04ALG600D5AL201DF608051DG0P0C51H2018C
5AP051DG6@0E5QP301DG5P805QPG0`0G6AP801HH5`P05aTH200H61P801LI60P06QXH200J6QX;01/K
6@8071`J1P0M7A/201`L6P<06a/I0`0L71X201dM6`<07QhL200M7A/801`L6P0301XJ600K6aT06a/I
008071`J0P0M7A/00`0N7Q`071`J01`L6P0?01`L6P0701dM6`0O7ad0820N024Q7`0P81h07alM01hN
700<01dM6`8071`J1P0K6aT201`L6P<07AdK0P0L7AL301dN60<07QlI200P7aX8028Q70809R4K0P0W
8Q`202PS7@80:B@N200Z9Qd802`U7@80;2HJ0`0]9a/302hX700802/W7P0X91/09R8I02LS6P0[9ah0
;2PO02TU700V8QT402/T70@0;2DM200V9Qh802LR70<08b<K00<092@L02DU7@0U9Ad00P0V9Qh202<S
6`8092@L100U9Ad202<S6`8092@L0P0U9Ad202HV7P80:bLL0P0Z9Q/302TU6P0302PT6@0T91`092@L
00H092@L2@0S8a/00`0T9Ad08b@L024R6P0201lP6003020Q6@0Q8QX08R<K00807ahI0P0P7aX00`0Q
81/08R4L028Q7009028Q70P07b0J0P0N7aT201lP6P80824K0P0Q8Q`8024P6`P08R4L200O81X3028Q
70808b8M0`0T8ah802<T7P0>02<S6`0U9Ad09bLO02PX800Y:B40:2PP02LW7`0V9Qh09RPM02LW7@0X
:1h0:RLN02/W7P0]9Qh202lV7`<0:bLN0P0/:1l302dY800802hW7`0]9Qh0;2DM02/T700/9Ad0;BHN
02lX800`:B4203`_7`80>bhN00D0>RdM03T/700i;1`0>B`L03L]8@0203H/8080=B/O0P0d:Qh01`0c
:Ad0;b`M030]7P0b;1h0<b/N03D[7`0g:al00P0i:b0203D[7`0303H/800g;B40>2hR00<0>BlS0`0k
;Qd00`0l;ah0?C0O03d`7`0203d`7`0303ha800l<Al0?34O0080?34O100m<R02040`8@0603ha8@0m
<B40>S4P03Tb800h<Al0=c8O0P0f=1d0100h<ad0>C<M03Xb7@0l<Ad203d`7@80>B/R00@0>2/R03H/
8P0e;B80=2hR0P0b;R82034[7`<0<2XN0`0_:Ad00`0b;200<B/O02lY7@0202hX700302lY7@0`:Qh0
<B/O0080=2XN0P0e:al403H/800803Ha7P0e<1d0=2lL03<^6`0d;a`0=C0M03Lb7`0i=24303H`8P<0
=c4S0P0h<R@303@Z8B_ooooo000Zooooo`0809mdA`2MLTD0VVm209Q]@02GK3l0V6e009Y_@P2KL4<8
09]_@PP0VW0n202PKSd309a`?`80WG500`2NLT4209Y^?@0609]_?P2MLD00Wg=20:1d@`2QMD@0XWI5
202PMT@20:9fA@060:5eA02PM4<0XGE40:=gAP2UNDP0Yg]:0P2YNDP0102XN4L0YgM60:MgAP2VMTD2
0:EeA0T0XgQ50P2QMT<30:9gA0<0XgQ500<0YWY;0:=gB02PM4<00P2OM440102RMd80YW]40:QmAP2W
OTX20:ImB@030:ElB02TNdL0XgY60080XWU50100XgY40:9i@`2QN4@0X7I409meA@2MLTD0W75409aa
AP2LLT00VW0n09M]>`2DJSP0TfTg09AZ>02FK3X0Ufdk0P2AIST0102@ICP0SV<f08eR=@2<HC@208]P
<`80R68c00@0Qf4b08EO<024GRl0PU`]0P21Fb`307]J;`D0NUT^00H0NE<^07MD;P1fDbd0ME<]07=C
;01`Db/206iB:P80LDl/00<0Kdh[06e?:`1[CbX00P1YCbX00`1XD2X0JdXW06]:9`0206]:9`@0K4/X
00P0JThY06]?:P1/CRX0Kdh[075?;01cCbd0M50^07I?;P<0ME8Z00D0MU<[07MD;01gE2`0Me@/07QE
;@0208IP<@0308MQ<P28HS<0RF<d0080RV@e00L0RfDf08eW>P2>J3/0SVPk08mY?02@JSd0TF/n0080
TV`o0`2FK3X509E[>@0309I/>P2EJcT0TfTg0080TVPf00D0TfTg09E[>@2FK3X0Ufdk09Q^?00209U_
?@0409M]>`2EJcT0TVPf091V=080U6Tl00<0TfPk099W>P2AIST00P2@ICP208mT=`<0S6Hi0P2;ICP2
08YT=`0308US=P29GS<0R5db00<0Qe`a00<0REhc08]P=@2<HCH00P2AIST0102@ICP0Sf@g08mT=`2>
HcH208eR=@80S64d00@0SF8e08iS=P2@ICP0TFHi0P2BIcX02`2AIST0T6Dh08mT=`2>HcH0Sf@g091U
>02BIcX0TfPk09M/>@2FJcP0UFXg0080U6Tf00<0UV/h09Q]>P2JKc`00P2EJcT209I/>P<0Ufdk00@0
V6hl09E`?02EL3`0UG0l0P2DKc/309=^>P<0Ufdk0`2HKS`209U_?@P0V6lk00H0V6hl09M]>`2GKC/0
UV`j09E[>@2DJSP209=Y=`0309I/>P2EJcT0TfTg0080TVPf00<0TfTg09E[>@2FK3X0202EJcT8095/
>080UV/n00@0UFXm09AY?02DJC`0TfPk0P2BIcX00`2BK3d0T6Xk08mY>P0208iX>@0308mY>P2@JS/0
TV`m0080TF/l0`2@JS/308mY>P04091[=`2?JSH0SfXf08mZ=P80SVTe0P2=J3@208MW=P80QVHe1025
IC@00`24I3<0R6<f08QS=P0208MR=@0408IQ=025H3<0Q5lb08AO<P80Q5ha00<0Peha085O<@1oGc00
0P1nGc002P1lH300KeTW06mI:01^F2L0KELX06eF:P1/EB/0K5D/06]D:`1[D2D206]?9`0E06]?:01X
C2L0IDPV06959@1P@b<0FDHX05I29`1??R80BCTO04Hh7P16=b00ACTS04Lk9@12=B@0@C@S03da8@0h
;b00=BdP03<]8@0a;B40<RhS0080<2dN00<0;b/O02hZ7`0]:B000P0/9b40100[9R809BDK02DU6`0U
9A/402HV700902LW7@0W:2009RLO02DV7P0T9Ad08b@L028S6`0Q8QX0824I010082<J00<08R@F02@V
600V:1X00P0W:A/00`0V:1X092HH028T5P08024R6P0301dP5`0N8AP082<J00808B@K00<082<J01hQ
600M81L0200N8AX801lR6`808R@F00P08bDG02@V600U9aT09RPJ02LY6`0X:Q`0:2XM02LY70809BLI
00@09bXI02/^6`0`<ah0<cHQ0P0^<R401@0_<R40;c0P02l]7P0^:a`0:bPI0080:bDG0140;2TJ02dZ
6`0^:a`0<2dN038_800d<B80=C8S03Hc900k<1`0?34M03hc7`0o=200@3DQ03ld800n<al0?C8N03de
800203de7P0303hg7@0n=a/0?SLJ0080?SPH2012>1l304Hl8`<0AC/R0P14>R4204Ll800404Pm8@19
?R80Bd0T04a19@80CD8V0`1>AB@504m69@80CT<S00H0CD8R04a18@1=@R80Cd@T05569P1BAbL20593
900405528`1@@B80CSlP04dn7`80C3dN0P1>@Al0101@@B00DD4P0551801D@B4205E08@0305Q59`1G
A2H0ED8T0080E44S00<0ED8T05M49P1HABL00P1KB1d00`1NBAh0GdPN06587`0206=77`0306E8801S
BbD0Hd/U0080HTXT0180HDTS06188P1PB280GdLQ069:9P1QBB<0H4PR05m87`1PBAl0HDXN06==7P1T
CQl0ITXS06M;901XC2D0JDdV06Y>9`1[CbP206a@:@0806]D:01YDRH0Ie0T06I?8`1UCR80ITlS06M@
901YDRH3071@:@D0KdlX00<0KE4Y06a@:01ZCRH00P1YCBD00`1ZCRH0K50X06eA:@0206QA9`<0JE8X
0`1ZDbT4075F:@80L5DX0`1_E2L806iI9080JeHY00h0JUDX06UD9`1XDbH0Ie8U06IA901UD2<0Ie0^
06MA;01YDBd0JU0[06eA:P1^DBT0L50W075A:0<0Ke8V0`1`DbL2075D:080Le@U0P1dEBH407EF9`P0
N5TZ0P1gFbT00`1hG2X0NEd[07YN;00207aP;P0=07eQ;`1lGBH0O5dW07]M9`1jGbX0NEl/07MP;P1g
Gbl0MV0_07AI;01eFRd0Me`_07QM<00207UN<@80Me`_0P1jGc8207UN<@<0N5d`00H0Me`_07AO:01d
GbP0LehY079L:P1aFbX2071J:`0706mH;01]ERX0K5DY06aE:@1[E2P0JU<W06UB9P0206QA9@80JDl/
00@0J4h[06M=:P1WCBX0IT`Y0P1UBbP0201MBbD0GT`V05m=9`1PCRP0GddW05i<9P1LBR@0FdTS0P1N
BRL0101MBBH0G4PU05Y68`1IAB8205Q48@<0Dd@S0P1B@b8305528@0804i89P1;AB<0BT4P04Pm7@1:
?Ad0CSlP05528`1EA2H805528@<0DT<T0P1A@R<405118P80CChO0`1>?b0304m08@0605569P1@ABD0
Cd@T04i38`1=@R80C44Q0P1;@2002P1?@BH0D48W05129`1?@BH0CClT04Xl8@16>1d0A3HK04Do7@16
@1h204M17`0L04I07P14?Q`0@C/I03li5`14?B40@c`P044j7P0o>1`0?SLK03lh7011>Qh0@S/O040l
8@0o>b00?SXO03di7P0k=a`0>CDJ03Pd6@0g<aP0>3/L03Lj7@0f>A`0=3LL03<e7@0a<ad0<38M02la
7080<S@L00l0<C<M030b7@0_<1h0;RlO02d^7P0];R00;S4N02d`7@0/;a`0:bhK02T/6@0W:QL09RTF
02DX5@0T9ah00P0S9Qd00`0R9A`08B@K020S6P0201lR6@807b8K0P0N8AX201dP6@8071lH0`0M7a`3
01`N6`806adJ200J71/301LI60805QPG0`0E5aH801HG6@P05AHH0P0F5aT301DF60<051DG200E5QP9
01@E5`P04ALG600D5AL8018C5BP04ALG600D5AL201DF608051DG0P0C51H2018C5AP051DG6@0E5QP3
01DG5P805QPG0`0G6AP801HH5`P05aTH200H61P801LI60P06QXH200J6QX;01/K6@8071`J1P0M7A/2
01`L6P<06a/I0P0L71X301dM6`<07QhL200M7A/801`L6P806QXH00@06a/I01`L6P0L71X07AdK0P0N
7Q`@01`L6P0801dM6`0N7Q`0820N028R800S8b408R8P020P7P0O7ad<01dM6`8071`J1P0K6aT201`L
6P<07AdK0P0L7AL301dN60<07QlI200P7aX8028Q70809R4K0P0W8Q`202PS7@80:B@N200Z9Qd802`U
7@80:bDI00<0;2HJ02dW6`0^:1`00P0_:Ad02@0`:Qh0:bLN02PT6`0V8QT09b<J02/W7P0/:1l0:BDL
02HR6@0402`U7@@0;BHN200V9Qh802LR70<08b<K00<092@L02DU7@0V9Qh00P0V9Qh202<S6`8092@L
0`0U9Ad00`0V9Qh08b<K02<S6`0202@T70809BDM0P0V9Qh302/W6`80:RHJ0`0Y9AT802@T70T08b<K
00<092DM02<T700Q8QX00P0O81P00`0P8AT08B8J028S6`0201lN6@8081lJ00@08B0K028Q700R8A`0
8b8M200R8A`801lP6P807QlI0P0O81X0100P8A/08B8L024R700R8ad8024P6`P08R4L200O81X2028Q
70<08b8M0`0T8ah802<T7P0302<S6`0U9Ad09bLO00<0:BTQ00P09bLO02HV7P0X:Ql0:BTO02PX7P0Z
9ah0:bLN02dV7P80;RDN0P0[9ah202`X7`<0;BTP00@0;RXQ02hW7`0]9Qh0;2DM0P0[91`00`0]9Qh0
;bPP034Z8P0203d`7`0403`_7P0k;Qd0>bhM03X]7080>B`K0`0g;B400`0f;200=B/O03@Z7P0203@Z
7P0602h[700_;1d0<B/M038Z7@0d:Qh0=RXN0P0h:Ql0200e:al0=R`P03L]8@0h;R80>BlS03X`900k
<BD0?38V2@0l;ah403`a7`@0?C8P00P0@C4R040`8@0n<B40?C4Q03Xa800i<R00>34O03Lb7`80=S@M
00@0>3<M03Tc7@0j<Qd0?34M0P0m<1d203X/8`0403T/8`0g;B<0=RhS03D_8`80<blS0P0a:al3030Z
7P<0;bTM00P0<bdQ034[7`0_:Ad0;RPL02dW6`0^:1`0<2XN034[7`80=2XN0P0e:al303H/800903L]
8@0g<Qh0=S4M03@_6`0c;QX0=2lK03Ha7@0h<al0>C@P0080=BlQ00@0=S0R03La8`0h<R@0>38T0P0i
<bD303HY8B_ooooo000Zooooo`P0VFi40`2KLSh509Ya?@80W7900P2KLCl0102JL3h0VFlm09U_?@2H
KS`809i^?@P0W7<o0`2NLT4509ea@00609Ue@@2JMD40VWE109ad@@2MLd40WW910P2PLT420:9fA`04
0:9fA@2RMd@0XWM40:9g@P80XWM000@0[Wa;0:ekBP2ZN4L0Z7I50P2WMD@20:QfA@T0XgQ50P2QMT<0
102RMd@0XgQ50:EjA`2VNdP20:MlB@P0Y7Y80`2UNdT50:AjB080XG]<00<0X7Y;09miBP2NN4T00P2M
MdP02@2LMTL0W75409aaA02MLTD0W75409Y_@P2GK3l0U6Tl099W>P0208iX>`0408eW>P2<IST0RfDh
08]U>080RV@g00`0RUha08UN<@28GC80QU`b08=L<`21Fc@0OU/e07eJ=01oG3@0OEXb07]H<01iERh2
07QE;@0707UF;P1jEbl0M5@]07AD;@1cDb`0LU8[075A:P02071@:@0406m?:01`Cb`0L4l/071?;0<0
Kdh[2P1^CBX0201_CbP0KThW06i>9`1^CRL0KdlX079B:`1dE2d0MUH_0P1kER`0101lEbd0OUT_07mJ
<021G382089M<`0608=M;P24GRl0Q5h_08EO<026H340Qf4b0P28HS<0202:IS80RfLc08aX=02>JSH0
T6`h095]>@2BKSX0Tflk202EJcT8095/>00809U^@@2DJC`0TFHi099W>P2FJch0Uf`o09AY?02?I3L9
091U>003099W?02@ICX0SV<h0080S64f00<0SV<h091U>P2BIc`00P2>HcT00`2>HcP0SV<f08iT=002
08iT<P0508iU<@2@IS@0SfDc08mU<`2>I3800P2=Hc4208aR<00<08]P<`2<HC@0SF8e08mT=`2@ICP0
TVLj09=X>`2DJC`0UV/n09AY?02BIcX0T6Dh0P2?I3L0202AIST0TVLj09QY?`2HJCd0UfPl09MX>P2G
JCP0UfTg0P2FJ3@00`2CKSX0U6lk09Ia?@0309Qc?`0309Ia?@2EL3`0VFlm00L0VFlm202JL3h209I/
>P80UF/i102DJSP0102BK3d0Tfdn09=]?P2CKCh309A^?`0709E_@02EL3/0U6lj09A_>P2CKST0TVdh
095/=`02091[=P<0UF/i0P2DJSP309=Y=`0409E`?02DKc/0U6lk09=^>P80TVdi0P2AK3P208eW>004
08iX>@2?JCX0T6Xk091Z>`80TF/l0`2BK3d2095[?0<0T6Xk0100Sf/k091/?02@K3`0T6`l08m[>`2<
J3P0RVHf08QT=02;IRl0S6L`08iY=02>JCD0SVPg08aV=`2:I3D0RF<f1@27Hc<408QT=00608QV>027
ICL0QfDg08IT=P25HcD0Q68d0P23HC<207eN<P80O5da0`1kG3001P1jFbl0METZ07EI:P1dEb/0LeH/
079E;@80L58/01l0Ke4]06]?:01ZCRL0ID/V069:9P1NAbD0FDDT05M38P1E@R80DShS04ln8P1>?B<0
BSXQ04Lh8@13=b40@3DO03ld800l;R<0>blS03X^8P0g;B40=BdP03<]7`0a;Ql0<2dN02h^900];B<0
;2`R02/[8@0Z:R00:BTO0080:2PN0P0V9al202DV7P@092DM0`0Q91d2020S70/07b8K00P0824I024R
6P0R8a/08b@L02@U7@0U9Qh09RLO02LX80P09BTJ0P0T9b000`0S9Ql08RDN024T7@0201lR6`T07R4J
00@07AhH01hO6@0N7aT07QlI0P0O81X2020Q6`80820N00@0824L024R700Q8QX08R<K0P0R91T0100[
:1T0;2TJ02`Y6P0/:AX202dZ6`80;R/L00H0;BPB02hY5@0_:QH0<2/H034[6`0a:ad2034[7`0702X]
900Z;B80:B`Q02P/7P0X;1d09b/J02L/600202H[5`80=2XP00<0=B/Q03H/8P0g;B<00P0i;bD01@0j
<2H0>C4J03Xb6`0l=1d0?SHO0080?cLP00X0?SHO03de7P11=R80@3DQ03hc7`0m<Qh0?34M03db7P0n
<al0?c@P0P0n<Q`01`0o<a/0@CDK048g6`13>1X0A3TK04Dj6P16>al00`17?20204Pm8@80BChR101=
?B<204hn9080CclU00<0Bd0T04a19@1>@bL00`1@ABT00`1?A2P0CT<W05=69P0205=69P<0DTDU0P1A
A2@0101>@2D0CClT04Xl8@18>Ql204Li7P80B3XO0`16?24204Lm8P<0B3hS00H0CS`T04lm9@1??BD0
DClW0590:01C@BT205A2:P80F44R0P1I@R<01P1J@b@0Fd@U05]49@1LABH0G44V05Y09@80FD4U00H0
ET4T05E2901B@B<0DT4S05E19P1F@RL205I39@0405M4901GA2<0F4HR05Q68P<0FTHQ0`1KAb8205a8
8`<0HdlZ0P1TD2/306EA;0<0Hd/U0P1TC2H306E=9`80JE<^00<0JE</06QB:@1WDRL00P1VDB@02@1V
DB80HddT06A>9@1UCbH0Ie4X06QB:@1ZE2/0JeD/06aF;@0906YC:PL0KE8U00@0KU<V06YC:P1YDRT0
Ie0W0P1VCbH00`1WD2L0JE8Y06YC:P0206IA900306M@901XD2@0JTlT0080K4lU00h0KThU06i?801_
D240L54R079C901dEBH0MEHW07MH:@1hFBX0L58P079D8P1eEbD0N5XX07UK:@80NU`Z00@0NE/Y07UO
9P1hGRD0MU`S0P1eFb800`1gGB@0NElV07YP9`0207]K;00607UJ:`1fFRX0ME/Z079K:@1aFRP0L5XX
0P1hF2D00`1iFBP0NUX[07]J;@0207aK<00307eL<`1iGbh0N5h]0080N5h]0P1gGB`207IL:`H0MeXb
0P1hFc<00`1cF2/0M5T/07EJ;@0207IK;P0407AI;01bEbX0L5DX075J;P80L5T]00<0KeP/06iG:`1]
ERX00P1/EBT0201TCRT0HddX069<9`1QBbH0HT`W06==:01UCbX0IU0[0`1PBR<3065;9080HT`U00H0
HD/T061:8`1PBR<0GdTR05i88@1MAb0205a67`80EdLV00@0EDDT05A48`1B@R40DD4P0P1??ah0101>
?ah0Cd0O04m07`1?@1l205118080DD8Q0`1B@R4205=38PH0E4@S00@0EDDT05I69@1FARD0EdLV0P1H
B2L805118P030593901@@B80Cd0Q0080CChO00D0Cd0Q05118P1B@b@0B48N04U37`0304Y4800404Q2
7P17@Ad0AClK04`k8@80BSXP00<0BC/P04Hk7`15?1l00P12>ah2048k7`<0@CXN0`10>Ad01P10?240
?c/P03hj7`0m>Ah0?3PM03Xf6`80>CDJ00H0?CTN03`h7@0l>1d0>cLL03Xf6`0i=AX203Pd6@80=S@K
00@0=C<L03@b7@0d<Qd0<c0M0P0b;ah01P0];1L0;B`H02/]600Y;1T0:B`K02P/7@809B/M0P0W:200
0`0V9al09BHN02@U7@0202<T7007028S6`0S9Qd08bHM028U700Q91/07b8I01hQ600201dP5`<07B0I
0`0L7aP201/N5`P06A/H0`0H6QT301LI60805QPG200F5aT801DF624051DG200B4aD8014G5`P03aDE
200A5aL801@E5`804Q<E0P0C51H201@E5`805AHH200D5AL8014G5bP051DG0P0E5QP201@E5`804a@F
0P0B4aD;01@E5`<05AHH0P0F5aT801DG5PT05QPG200G61X801HH5`<05ALF0P0F61L;01LI60P061PH
200J6QX201LG5@8061PF100I6AL@01XJ60806ATG0P0J6QP00`0K6aT071`J01dM6`0901dM6`807A`J
0`0N7A/301lN70P07QdH100N7aT201dN608071dG200M7QP801`M5`<07AdK0P0L71X301/K6@P07AdK
0P0N7Q`01@0M7A/071`J01`L6P0L71X06a/I00806QXH400L71X201dL5`807QdH100O7QT3020O6P<0
8B0K0P0R8A`302@O6@809B0J0`0V8A/202DP6P809R4K100W8Q`202dV7P@0;2DM0P0[91`802XX6`@0
;RPL100_:Ad202TU7080:2@K0`0W8aX0100V8QT0;BLK02`V6P0[9AT202XT600302`V6P0^:1`0;bTM
0080;BLG00<0;BLI02`V6P0/9A/00P0[91`02@0[91h0:b8K02XQ6P0Y8QX09b<J02DR6@0S8aT08R8H
024S6003024Q6@808R8J2`0S8a/0100R8QX092@L02HV7P0Y:B4302XZ8P0402TY8@0_:b80;b/R02hZ
8@80;BTP00<0;2PO02/W7P0[9ah00P0Y91h202PS7@809b8L0P0V8A/902<S6`0402HV7P0U9Ad09BDM
02DU7@8092@L0P0S8a/8024Q6@P08R8J00@08R<M024R700Q8Q`0824K0P0O81X201hO6@<0820H0`0Q
8AT2028R6P<091lK0P0U81`302HQ7@<07b0K0P0P8A`3024R7@P08R8J00h09bLO02HV7P0T91`08b<K
028R6P0S8a/092@L02DU7@0T9Ad09BDM02HV7P0X9Ah0:RDO02`U7`80;RDP0P0R91T00`0S9AX092HK
02DW700202LY7P0602PZ7`0]9a/0;BLK02hX700_:Ad0<2XN0P0a:al01@0b;200=B/Q03@Z800b:1h0
;bDK0080;R@J0P0_9A/8034[7@P0>2`L200j;Qh203P_7P<0=bhM100f;A`0200h;ah0?30P03ha8@11
<B80@2hP03l]7`0n:ad0@2dN0P0o;Qh00`0m;Ad0>bhM03T^700303L_70P0>C4N0`0o<R400`0n<B00
?C0O03`_7P0203`_7P0C03P]6`0k<1h0?S<Q040e8`0o=280?34O03T^700f:aT0?BdM03d]7P0j;Ad0
>2`N03D[7`0c:b00<RTP034Z800^:a`0;b`M030]7P02034^7`0302l/7@0]:Q/0;2TJ00<0;BTM1@0^
:Qh01P0e;b<0=RhS03H^8`0g;B<0>B`S03X/8`80?2/S200g;B4303H]70<0=bhM0P0h;ah303@[6R_o
oooo000Zooooo`P0VFi40P2KLSh609Ya?@80W7900P2KLCl0102JL3h0VFlm09U_?@2IKcd809i^?@P0
W7<o0P2OLd8609ib@@0609]g@`2LMd<0W7M309if@`2OMD<0X7A30P2RM4<20:9fA`040:9fA@2RMd@0
XWM40:9g@P80XWM000P0ZGU80:QhA`2VMTD0YGE40:Ad@`2UMD@0YWI50:MgAPT0XgQ500D0XGI30:9g
A02RMd@0XgQ50:EjA`020:IkB0030:MlB@2TNTP0Y7Y800H0Y7Y80P2UNdT40:AjB080XgU700H0XG]<
0:1jB`2PNT/0WgU:09ihB@2MMdP209afA`0809]`@`2LLD@0W75409]`@`2JKd80Uf`o09AY?02BIcX2
08iX>`0308eW>P2<IST0RfDh0080RV@g00L0RF<f08YN<@29GS40R5db08IL<P22Fc80P5Xc0080OEXd
00@0OU/c07aI<@1jEbl0N5D]0P1gE2`0201hEBd0NEH^07AD;@1dE2d0Le</079B:`1aDBX0L50Y0P1_
CbP3071?;080Kdh[2`1^CBX206m?:080KThW00X0L50Y079B:`1eEBh0MUH_07]F;01lEbd0OEP^07iI
;`1oFS00PE`b0P22GC<208AN;`0308EO<026H340Qf4b0080R68c00T0RF<d08aW<`2<Ic<0SFPd08mZ
=P2AK3P0TVdi09=^>P2DKc/0202EJcT8095/>00709Q]@02DJC`0TFHi099W>P2FJch0Uf`o09=X>`0:
091U>003091U>P2?I3T0SV<h00<0SV<h00L0Sf@i091U>P2>HcT0SV<i08iS>02>HcH0SV@d0080SV@b
00D0SVDa08mU<`2?IC<0SfDc08iT<P0208eS<@80S68`0P2;H3<0502<HC@0SV<f091U>02AIST0TVLj
09=X>`2EJSd0U6Tl099W>P2@ICP0Sf@g091U>02AIST0TVLj09QY?`2HJCd0UfPl09MX>P2GJCP0UfTg
0P2GJCD00`2CKSX0U6lk09Ia?@0209Qc?`0309Mb?P2FLCd0UG0l00P0VFlm202JL3h209M]>`<0UV`j
0`2EJcT409A^?`@0Tfdn00H0UG0k09A_>P2DKcX0Tfhi099]>02AK3L2091[=P<0UF/i0P2DJSP309=Y
=`<0Tfhj00<0TVdi095/>02AK3P00P2@JcL208mY>P<0T6Xk0`2AJc`3099/?@80TF/l0`2@JS/0402>
JSX0Sf/k08m[>`2@K3`0Sf/k08eY>@2;IcL0RVHf08]V;`2<Ic00SFPc08iY=@2>J3L0S6Hg08YT=@29
HcH608MS<`<0R6@d0P24HS@01`23HC<0PV0b085O<@21Gc40P5h`07mM;`1mGS800`1lGC4207]L<080
NU/_0200METZ07AG:`1cERX0LUD[075D;01`DR`0Ke4]06i@;01ZCRL0IddX06E;9P1QBBD0GDHT05Q4
8`1E@R80E44Q04ln8P1??R@0C3`R04Tk8@14>200@SHP03ld800n<al0>blS03X^8P0h;R80=RhQ03@^
800a;Ql0<2dN02l]7P80;BdS00@0;2`R02/[8@0Z:R00:BTO0P0X:1h202HW7`809BHN0`0T9Ad0100S
91`08B@M024T7@0Q91d2020S70/07b8K0P0Q8QX0100R8a/08b@L02@U7@0U9Qh202HW7`P09BTK00D0
92LP02<V7`0S9Ql08RDN020S700201lR6`T07R4J100N7aT201lP6P80824K0P0P81h00`0Q8Qd08B8L
028S6`02028T6@0302<U600/:AX0;2TJ0080;2TJ0P0]:Q/202h[7080;B/F00@0;R/H02h[6P0^:a`0
;R/L0P0^:Qh01P0W:R409bXO02LZ7`0W:ad09b/L02L[6P<09b`H00D0=2XN03D[7`0e:al0=R`P03P^
8P0203T_8`0I03X`900j<Q/0>c<L03de7P0n=Ql0?cLP03hf7`0m=Ah0?3@M03ld800n<al0?C8N03`a
7@0k<1`0?34M03hc7`0o=200?S8L03lc7@10=1`0@CDK048g6`14>A/0ACXL04Dj6P0304Ll8080B3dQ
0`19?R8304hn90<0CclU0P1@@2H0201;@2@0C44U04i39`1@ABT0DDHZ0515:@1?A2P0CT<W0`1?@B@2
04i08`<0CClR00@0CT0U04`n8`1:?240B3XO0P16>1d00`17>Ah0B3XO04Dk800204Dk80<0AS`Q0P17
?B8204Ti800604Xj8@1;>b80C3`S04dm901>?RD0CclV0P1F?b0205M08@0505Q18P1I@R<0FD8S05U2
8`1I?bH00P1G?bD00`1E@2D0DclT0550900204m08`0605<o9P1D@2D0E40U05A18`1E@R80ED8Q0P1F
A200101HA240FDDR05U58P1IAB8205Y68`80FdLT0P1MBBH205i:9`<0Gd/X00<0H4`Y061:8`1PBR<0
0P1QBb@3069<9@0506==9P1RC2L0HT`W069<9@1RC2<00P1RCB82069=8080HddT00@0I4hU06E?9P1V
D2L0Ie4X2`1XDRT406aA9P@0Je0U00<0Ie4X06I@9`1UCbH00P1TCRD0101UCbH0IU0W06MA:01TDBH2
06IA9P0306M@9P1YD2L0JdlW0080K4lW0P1_D2802`1`DB<0LE8T07=D9P1dEBL0MEHX07IG:@1`DR00
LU@R07AF901gFBL0N5XX0080NE/Y00<0N5XX07QM9P1gG2D00`1eFR<0201fFb@0N5dV07UN9`1kFb`0
NUX[07UJ:`1fFRX0ME/Z0P1bFbT01P1`FRP0NETV07UI9P1jFRT0NUX[07YI;080NeX_00<0NeXa07QN
;@1hGRd00P1hGRd207MM;080MU`[101hFc<407MJ<P0307=H:`1dFB`0MU/^0080MU/^00<0M5T/079G
:P1aERT00P1aFRh0101`FBd0KeP/06iG:`1]ERX206aE:@0306E?:01TCRL0HddV0080HT`U00<0HddV
06E?:01VD2T02P1QBb@0101PBR<0GdTR05i88@1MAb0205a67`80EdLV00H0ETHU05A48`1B@R40DD4P
05107`1??ah404m07`80D44P0P1A@R4305928@<0Dd<R1P1DA2<205E590<0ETHU201@@B800`1B@b@0
DD8S04m08@0204ho800C04m08@1A@R<0DT<T04Q27P19@al0BT@P04]58@1:A200BD<O04M17@16@1`0
C3/Q04/k8@1:>R00BC/P04Hk7`15?1l0@c`O048k7P03048k7`80@CXN0`10>Ad203hj7`80?CTN00@0
?3PM03/g700j=Q/0>SHK0P0l>1d0100k=a`0>SHK03Te6P0h=1T203Lc6080=S@K00@0=C<L03@b7@0d
<Qd0<c0M0P0b;ah01P0^;AP0;RdI02`^6@0Z;AX0:RdL02T]7P809R`N0P0W:2000`0V9al09BHN02@U
7@0202<T7006028S6`0S9Qd08RDL028U700Q91/07b8I0P0N8AP0100M81L07B0I01dP6@0M81T301`O
60806ahG200I6aP301PJ6@<05aTH0P0F61L801HG6@P05AHH8@0D5AL8018C5@P04ALG200?5AD8014G
5`P051DG0P0B4aD201<D5P8051DG0P0E5QP801@E5`P04ALG:00D5AL201DF608051DG0P0C51H2018C
5@/051DG0`0E5QP201HG6@P05ALF2@0F61L801LH6PP05QPG0`0E5aH201HH5`/05aTH200H61P801XJ
6P805aLE0P0H61H301TI5a@06QXH0P0K6aT301`L6PP07AdK0P0M71X301hM6`<07ahL200N7AP0100O
81X07QlI01hO6@0N7aT201dN608071dG200M7QP801`M5`<07AdK0P0L71X301/K6@P07AdK00<07QhL
01dM6`0M7A/00`0L71X201/K6@0301XJ600L71X071`J00h071`J0P0M71L201hM60<07ahI100P7aX3
024P6`808R4L0`0T7aT202DP6P<09R4K0P0U81X202HQ6`<09b8L00<0:2<M02dV7P0]9Qh01P0/9Ad8
02/Y70@0;RPL100_:Ad302TU7080:2@K0`0W8aX00`0]9a/0;2HJ02/U6@0202XT600302`V6P0^:1`0
;bTM0080;BLG00H0;BLI02`V6P0/9A/0;2DM02/T700[91h202/R6`0302TR6P0W8aX09B8I00808b<I
00<08B<H024Q6@0Q8AT00`0R8QX;02<S6`06028R6P0T91`09RHN02PX800Y:B40:2PP0P0W9al202dY
8080;2PO0P0[9ah202XV7@80:B@N0P0X8ad202LR70809R4K2@0S8a/402DU7@8092@L0P0S8a/8024Q
6@P08R8J00<08R<M024R700Q8Q`00P0P8A/201lP6P0401hO6@0P81P0820H020P60808B4I0`0R8QX3
02@O6`809B0L0`0V8Ad301lP6`80824L0`0Q8Qd8028R6P0302HV7P0U9Ad092@L00808b<K00@092@L
02DU7@0W9al09RPM0P0W9ad00`0Y9Qd0:bLN02dV7P0202lV7`0602<S6@0T91X09BDK02HV700W9ad0
:2PN0P0Y:Al202hX700402lY7@0`:Qh0<B/O038/8080<bdQ00@0=R`R03@Z800b:1h0<2HL0`0_9A/0
0`0`9Q`0<B/M034[7@06034[7@P0>2`L200j;Qh203P_7P<0=bhM100f;A`0200h;ah0>blO03ha8@10
<240@2hP03l]7`0o;1h0@2dN0P0o;Qh00`0m;Ad0>bhM03X_7@0303L_70P0>C4N0`0o<R400`0n<B00
?C0O03d`7`0203`_7P0303T^700k<1h0?S<Q0080?c@R00d0?34O03T^700g;1X0?BdM03d]7P0j;Ad0
>2`N03D[7`0c:b00<bXQ034Z800_;1d0<2dN00<0<BhO00<0;b`M02dZ6`0/:AX0200^:Qh203@^8P03
03D]8P0f;280>2/R0080>B/R00<0>bXR03L]8@0g;B401P0g;B4303H]7080=bhM0`0h;ah303Xa82_o
oooo000Zooooo`0309Q]@P2IKT<0VFi30080VVm40P2IKT<00`2HKD80VW4m09Ya?@0609Ya?@<0Vg4o
0`2JL3h209U_?@P0Wfln202LLcl80:1d@`0609ahA02MN4@0WGQ409mgA02PMT@0XGE40P2SMD@20:9f
A`040:9fA@2RMd@0XWM40:9g@P80XWM000P0YGE40:Ad@`2SLd80XW910:=c@P2TM4<0YWI50:MgAPT0
XgQ50P2RMd@0102SN4D0Y7U60:AiAP2UNTL20:IkB0P0Y7Y80P2UNdT20:AjB0<0XgU700H0XWQ60:1j
B`2PNT/0WgU:09ihB@2MMdP209afA`0:09]eAP2KL4<0Vg1309]`@`2JKd80V6e009I[?P2CJ3/0TVLj
08iX>`80SFLj00<0S6Hi08]U>02:I3L00P29HcH01P2:GS40REha08QM<P25Fc40PU/b081J<`80O5Tc
00@0O5Ta07YG;`1hEBd0MU<[0P1eDRX00`1fDb/0Me@/07AD;@0207=C;003079B:`1aDBX0L50Y0080
KdlX0P1`Cb`206m>:`<0KTdZ2@1]C2T04@1`D2T0KdlX06m?:01_CbP0LE4Z07=C;01eEBh0MeL`07]F
;01lEbd0OEP^07iI;`20Fc40PE`b089M<`23GS@0Q5h_0080QEl`00<0QV0a08MQ<P28HS<00P29Hc@0
1P2<Ic<0SFPd08iY=@2?JSH0T6/g099]>@80Tfhj202EJcT8095/>00709M/?`2DJC`0TVLj099W>P2D
JC`0UFXm09=X>`0:091U>00308eR=`2>HcP0Sf@i0080T6Dj00<0Sf@i08iS>02=HSL00P2>HcT00`2>
HcP0SV<f08iT=00208iT<P0308iU<@2?IC<0SfDc00<0SV@b0`2=Hc401P2:Gc80Rf0c08aQ=02=HSD0
SV<f091U>080TFHi00<0U6Tl09=X>`2BIcX00`2@ICP00`2AIST0TVLj09EX?P0209EY?00309IZ>`2F
JST0UV/h0080UV/f0P2DKc/00`2FLCd0Ug8n09Qc?`0209Mb?P0309Ia?@2IKcd0VFlm00H0VFlm202J
L3h309Q^?0<0Ufdk0P2FK3X01@2FL440UFm009E_@02DKSl0Tfdn0080TV`m00L0TF/l09E`>`2DKcX0
U6lj09=^>@2BKCP0TF`g0080T6/f0`2EJcT209AZ>0<0TfTg0`2AK3P3091[=`80SfXf0P2CKCh3099/
?@<0TF/l0`2BK3d2095[?0<0T6Xk00<0S6Ph08eY>@2>JSX00P2?Jc/02`2>JSX0SFTi08]W=`2<Ic00
SFPa08eX<`2>JCD0SFLf08aV=`2:I3D0RV@g00T0Qf<c0P21Gc42081N<00407mM;`1nG2h0OE/]07eK
;@80O5da0P1kG30307YK;`0Q07UJ;P1dEb/0LeHZ079E:`1aE2`0Ke4[06i@;01]Cb/0K4h/06M=:01U
BbH0HTXV05m89P1JARD0ET<S05A18@1A@280CSdS04`l8P1:>R40AcPQ04<g8@10=B40?3@O03/c800j
;R80>2hR03L]8@0e;B00<bdO030]7P0_;Ah0;R`M0080;2`R0P0[:b40100Z:R00:BTO02PX7P0X:1h3
02DV7P8092DM0`0S91`3024T7@8082<L2`0O8Q/01@0Q8QX08R<K028S6`0S91`092DM00809BHN00<0
9RLO02@W700T9a`01P0T9a`202<V7`03028U7P0Q91d082<L00807b8K2@0N8AX301hO6@807b0J0`0P
8A/2024R7@03024R700R8a/08R@I00808bDH00@08bDG02`Y6P0/:AX0;2TJ0P0]:Q/302h[7006030^
6@0_;1T0;R/H02dZ6@0/:AX0;2PL0P0[9a`01P0U9Qh09BLL02HX7@0W:A`0:2XL02P[6P<0:B`I0P0e
:al00`0f;200=bdQ03P^8P0203T_8`0<03X`900k<ah0?3@O03de800n=R40?CDP03`d7`0j<Qd0>C4L
03db7P0l<Ad0>c0L0P0j;a/00`0k<1`0?C8N03hc7`0203lc7@07040d7012=Q`0@cPL04@i6`15>Q`0
AS/K04Ll800304Pm8@80BChR0P1:?b<204lo9@<0D40V0`1A@BL0201<@BD0CD8V04m4:01@ABT0DDHZ
0515:@1?A2P0CT<W0`19?R8204Pm8@<0Ac`P00<0BShT04Tm8`16>R000`14>1h204Di7`<0@cTN0P14
>Ql304Dk8080ACDL00<0ASHM04Lg7P18>1l00P19>B000`1:>R40D3dO054n8002054n80<0DSlQ00@0
Dd0R058l901B?2@0DCdT0P1>?B<0301<?280BcdR04/m8P1>?2@0CSdS04ln901??R80D3lQ05107`1@
@1h0DD4O05E37`<0ET@P0P1GAB4205Q68P0405E37`1FA200ET@P05I48080EdDQ0P1HAR8305i88`<0
GdTT0P1PBRD0201J@b40Fd@R05]5801LAQl0GDLN05i97P1OBQl0GdXM201RC2D906I@:@<0Ie0V00D0
ITlU06E>901TCB<0I4dS06=<8P0206A>9`0406==9P1RC2D0HT`U06==9P80I4hW0P1SD2D00`1UD2D0
Ie0V06Q?9P0206]?9`0306e@:01]D2@0KU4U0080KU4U00P0Ke8V071C9`1`DbL0L5<W06eA8@1_Db<0
LEDU07AH:0<0METY00<0M5PX07EJ8`1eFR<00P1dFB80101eFR<0MU/T07ML9@1hGBH207YJ:`0307UJ
:`1fFRX0ME/Z0080LU/Y00T0LE/Y07YL:01jG2P0NU`Z07UJ:`1iFR`0NEX^07QI;@1hF2l00`1hGRd2
07MM;0<0MU`[0P1jGC<0101iG380N5/a07MJ<01gFS0207II;`80MEX]0`1fFbh00`1eFRd0LeP[079G
:P02075J;P03071I;@1_F2`0KUL[0080KEHZ00@0K5DY06MA:P1VD2T0I4hW0P1SCBH00`1TCRL0IU0Y
06MA:P0306==9P03069<9@1QBb@0H4XS0080GdTR0P1QBb@00`1PBR<0GdTR05i88@0205e7800905a6
7`1GAbH0EdLV05I69@1DA2<0Dd<R05928@1A@B00D40O00<0Cd0O0P1@@B0305528@80DD4P0P1B@R43
05=38PH0E4@S101C@b8805118P80DD8S00@0D44R04m08@1?@240D44R0P1A@R<00`1;@al0C4@P04e5
8@0204e58@0404]37`1:@Qh0B40L04dl8P80Bc/Q00<0BS`Q04Ll8016?B000P13?1l01013?200@S/O
048k7`12>al2044j7P80@3TM00<0?CTN03`h7@0l>1d01@0l>1d01P0k=a`0>SHK03Xf6`0i=AX0>3@I
03Lc6080=S8G0P0f=1/0100e<a`0=38M03@b7@0c<1d2038_7P06030_6P0`;a/0;BlJ02`_700/;ah0
:RhO0P0X;R0202LX800302HW7`0U9Qh092DM00808b@L00@08R<K028U700R9A`08B@K0P0P8aX00`0O
8QT07R4H01hQ600301dP6@<071lH0P0K7QL801TK60<061XI0`0G6AP201HH5`P05QLI200E5QPQ01@E
5`P04Q<E200A5aL8010F5PP04ALG200D5AL2018C5@804a@F0P0D5AL201DF60P051DG200A5aLX01@E
5`805AHH0P0D5AL201<D5P804Q<E2`0D5AL301DF60805QLI200E5aH901HH5`P05aPJ200F61L301DG
5P805QPG2`0G6AP801PH60P06QXJ0`0H61H201TI5a<06QXH100L71X301/K6@0301XJ600M7A/07AdK
00H07AdK0P0M71X301hM6`<07ahL200O7QT301lP6P807QlI4`0M7QP301dM6`8071`J0`0K6aT;01dM
6`<071`J0`0K6aT@01`L6P<07QdH0P0O7QT6020O6P<08B0K0P0R8A`302@O6@809B0J1P0V8A/202LR
70<0:2<M0`0/9Ad502dV7PP0;2PL100_:Ad402hX7080:RHM0P0Y9A`302PT6`0402LS6P0]9a/0;2HJ
02/U6@80:R@H00<0;2HJ02hX700_:Ad00P0^:1P00`0]9aT0;BLK02`U6`0202`U7@0:02/T7P0/8a`0
:b8K02XS6`0X91/09R<J02@T6P0S8aT08R@I024Q6@<08R8J0P0S8a/:02@T700302<S6`0T91`09BDM
00809RHN00<09BDM02@T700S8a/0100Z9Qd202TU7080:2@K0P0Y91h202PS7@809b8L0P0V8A/902<S
6`<09BDM0P0T91`302<S6`P08B4I200R8QX4024R7080824K0P0O81X2020P60808B4I0`0R8QX0100S
8a/091lK02@O6`0T7a/202DP70<09R4M0`0P8A/2024R70<08R<M200S8a/02@0T91`08b<K02<S6`0R
8QX08b<K02DU7@0W9al0:2PP02LY7P0202TY7`0302/X7`0]:B00;bPP0080<BPQ0P0U9A/202HV7004
02LW7@0X:1h0:BTO02TY7`80<2XN00<0<B/O038/800c;B400P0d;R801P0e;b<0=R`R03@Z800b:1h0
<2HL02lU6`80<2HL00<0<BLM038/7P0b;1h01P0b;1h803P/70P0>RhN0P0h;ah303L^7@@0=RdL00d0
=bhM03X^7P0m<200?blP040^800o;Al0@2dO044^7`10;al0?bhN03h^7P0k;Qd0>RlM0080>30M00<0
=blL03/`7P0k<1h01P0k<1h303lb8@80?S4P0`0m<1l00`0j;ad0?34O03hc8@0203ld8P0C03`a7`0j
;ad0>2dK03d]7@0m;Ah0>RdM03T]7`0f;200=2`Q03<Z8@0b:b40<B/M038/7P0c;Al0=2hP03<]7`0b
;1h0<2XL02lY6`08030Z7P80<2`P00@0<R`P03<[800d:R00=RTP0P0g:B0803H/8080=RdL0P0g;Qd3
03P_7P0403T`7`0l<b80?3<R03`c8R_ooooo000Zooooo`80V6e0102JKd8209Q]@00309U`?02JLCd0
VW4m0080VW4m0`2KLSh209]a?`H0VW0n202OKch809ac?`<0X7A3102QMD@01`2RMTD0WGU509iiA@2N
NDD0X7Q50:5gA@2RMTD00P2TMTD20:=gB0040:=gAP2SN4D0XgQ50:=h@`80XgQ100P0XG=10:1b@02O
LCl0X7900:5c@@2SMD<0YGM50:MiA`T0XgQ500<0XWM40:=hA@2SN4D00P2TNDH20:EjA`030:IkB02T
NTP0Y7Y800H0Y7Y80P2UNdT20:AjB0040:=iA`2RN4H0XWQ60:5gA@80WgU:00<0WWQ909egB02LMTL0
0P2KMDH02@2JM4D0Vg1309]`@`2JKd80V6e009I[?P2DJC`0TfPk099W>P0208eW>P0408aV>@2;ICP0
RfDh08YT=`80RF<f00H0Relb08UN<@28GC80QE/a085J<@1oFC8207]H<P0407YG;`1iERh0Me@/07EB
:P80M54Y0P1eDRX207=C;003079B:`1aDBX0L50Y0080KdlX00@0KThW06m>:`1_CR/0Kdh[0`1^CBX:
06e<:@08075A:P1`D2T0L50Y071@:@1aDBX0M5@]07IF;`1hF34207aG;@0407eH;P1oFS00P5/a089M
<`80Pehd00H0QEl`08IP<@26H340Qf4b08QR<`29Hc@208YT=@80SfLd00H0T6Pe095Y=P2BJSL0Tf/h
09A/>@2EKCX809AZ>0P0TF`h00<0UFXm09AY?02CJ3/00`2CJ3/00`2BIcX0TFHi091U>008091U>003
08]P=@2=HSL0Sf@i0080TFHk00<0Sf@i08eR=`2;H3D00P2>HcT00`2>HcP0SV<f08iT=00208iT<P03
08iU<@2>I380SV@b00@0SV@b0P2=Hc401@2:Gc80Rf0c08]P<`2<HC@0SV<f0080Sf@g00@0T6Dh099W
>P2BIcX0TVLj102AIST01`2BIcX0U6Tn09AY?02EJSd0UF/k09E[>@2EK3P00P2FKCL0102DKc/0UG0l
09E`?02FLCd409Mb?Q@0VFlm0P2HKS`209M]>`0909Ma@P2FL440UFm009A^?`2CKCh0TV`m095[?02@
JS/0UG0k0080U6lj00<0Tfhi099]>02AK3L00P2@JcH309E[>@80U6Xh0`2CJCL2091[=`H0SfXf0P2E
Kd00102DKSl0Tfdn099/?@2BK3d2095[?0<0TV`m0P2AJc`3091Z>`0808]W=`2<J3P0SVXj08m[>`2@
K3`0Sf/k08iZ>P2=JCT208eX<@0308eX<`2=J3@0S6He0080RfDf00@0RV@g08QT=028I3@0R6@d1@27
Hc<01@26HS80PV0b089P<P21Gc40P5h`0080Oed_0P1nG2h207]L<080NU/_101iFRh0801cER`0LUD[
075D;01_DB/0KDl[06a>;01ZC2X0JT//06A<:01SBbL0H4TW05]79P1GA2@0DT4S050o8@1>?b80Bc/R
04Tk8@18>B80@cLQ040e8@0l=240>C8O03Pa7`0g;B40=RhQ03D]800c;Al0<2dN02h/7@0/;Ad0:b`L
0`0[:b400`0Z:R00:BTO02TY7`0202PX7P809BHN0`0T9Ad302<T70<08B@M0P0P8a`301lR6`P082<L
0P0R8a/202<T708092DM0P0U9Qh802<V6`808RDN0P0Q91d0100P8a`07b8K01lR6`0O8Q/801hQ6P80
7QlI0P0O81X2020Q6`808B8L0P0R8ad0100R8a/08bDJ02<U600T9QT202@V6080;2TJ0P0]:Q/202h[
7080;b`M00H0<C0L030_7@0^;A/0:bTJ02XX6`0Y9a/202TV7@0702<S6`0T91X09BDK02LW6`0X:A/0
:R/K02//6P0202`]6`80=RdN0P0g;Ql01P0h;b00>C0Q03T`8@0i<240>c<P03`d8@80?CDR00L0?3@Q
03Xb7`0h<1d0=blL03`a7@0k<1`0>RlK0080>BhJ00<0>RlK03`a7@0m<Qh00P10=1h01`11=Ad0@cLM
04@i7@15>Q`0AS/M04Ll7018?B400`19?R8204Xo8`80Bd0T0P1@@2H205519`@0DT8X00<0C44U04e2
9P1?A2P00P1@ABT00`1?A2P0CT<W04e29P0304Ln8@80ASdP0`15?1l02017?B@0AS`S04@j8@12>1l0
@CLN048h7`13>B00A3XQ0P11=a`2048h7@<0@cTN00D0A3XO04Dg7@15=ad0ACLM04Hh7P0204Li7`80
B3XP1`1<>al01`1=?200CSXQ04`k8@1<>b40BSXP04Tk8016>al00P15?1l204Xj8@0404Xj801;>b40
Bc`O04`m7P80C3dL0`1A@Al2059280<0Dd<Q0P1@@1h205517`<0DT8P00@0Dd<Q05Q48@1HA240F4@Q
0P1IAB8305Y68`0905Ho7`1G@200F44O05Y47`1LAQl0GDLN05i97P1OBQl0HD/V0080H4XU0P1OBB@0
0`1NB2<0GDLR05e78P09061<9`80HDhV00@0H4dU05m<901NBb<0GDXR0P1LBB4305i:9@80GDTT0`1N
BRD2061?9006069?9@1UCbH0ITlV06Q?9`1YD2P0JdlX201/DB@0101[D240KE8S06mD9@1aERL2079G
:080LEHW101cF2<0101dFB@0MEXU07IK9P1gG2L207UI:P0307QI:P1fFRX0ME/Z0080Le`Z00T0LU`Z
07YO:P1iGRT0NEd[07QL;01gFb`0MUT]07EH;01eF2h00P1hGRd207MM;080MU`[0P1eFbX01P1kGS80
NUda07YM<@1iG300N5/_07MJ;P80MUT]0`1gG2l207IK;P80MEX]00L0M5T/079K;`1aFRh0LEX^071I
;@1_F2`0KUL[0080KEHZ00P0JE<Z06QB:@1VD2L0IDlV06A>9@1UCbH0IU0W06MA:080IDlX00L0I4hW
069<9@1QBb@0H4XS05m98P1NB240HT`U0080HD/T00<0H4XS05m98P1NB2400P1MAb001@1GAbH0ETHU
05I69@1EAB@0Dd<R0080DT8Q00<0DD4P04m07`1?@1l00P1@@B0205528@80DT<R0`1A@B0205928@<0
Dd<R00H0EDDT05A48`1DA2<0E4@S05=38P1B@R420551800305107`1A@R<0DD8S00P0DD8S101@@B82
05528`0304e3801>A240CdDR0080CdDR00@0CD<P04a27`1:@1d0CC`R0P1<?2800`1;?B80B3dQ04Ln
8@0204@m8080@c`P0`12>al3044j7P80>cLL0`0l>1d303di7P80>SHK00<0>CDJ03Pd6@0g<aP00P0f
<QL0100e<AH0=S@K03Hd6`0e<a`203@b7@0903<`7@0b;ah0<RlN034`6`0a<1`0;S0K02d`7@0]<1l0
:blP0080:BlQ0P0W:2000`0V9al09BHN02@U7@0202<T7004028S6`0R9A`08B@K024T6`8082<J0P0O
8QT0100N8AP07B0I01dP6@0M81T301`O60806ahG200J71T301PJ6@<05aTH0P0F61L801HG6@P05AHH
8@0D5AL8018C5@P04ALG200@5QH8014G5`P051DG0P0B4aD201<D5P8051DG0P0E5QP801@E5`P04ALG
:00D5AL201DF608051DG0P0C51H2018C5@/051DG0`0E5QP201HG6@P05ALF2@0F61L801HG6@P05QPG
0`0E5aH201HH5`/05aTH200H61P801XJ6P8061PF0`0I6AL301XJ61006a/I0P0N7Q`00`0M7A/071`J
01/K6@0201XJ600301TI5`0M7A/07AdK00H07AdK0P0M71X301hM6`<07ahL200O7QT301lP6P<07QlI
4P0M7QP301dM6`8071`J0`0K6aTQ01`L6P807QdH0`0O7QT6020O6P<08B0K0P0R8A`302@O6@809B0J
1@0V8A/302LR70<0:2<M0P0/9Ad402dV7P80;RLO300_:Ad402hX7080:bLN0P0Z9Qd302TU700402PT
6`0]9a/0;2HJ02/U6@80:R@H00<0;2HJ02hX700_:Ad00P0^:1P00`0^:1X0;BLK02dV700202`U7@09
02`U7`0/8a`0;2<L02/T700Y9A`09b@K02DU6`0T91X08bDJ00<08R8J0P0S8a/?02@T70808b<K00<0
8R8J024Q6@0X91/00`0X91/402LS6P80:B@N0P0X8ad202LR70809R4K2@0S8a/202DU7@8092@L0P0S
8a/B028R6PH08B8L0P0P8A/3024Q6@<08R8J0P0S8a/302@O6`809B0L0`0V8Ad3024R6P<08R<K0P0S
91`802@T700902<S6`0R8QX08R8J028R6P0S8a/09RHN02PX800Z:R80:B/N0080:RXN00<0;B/O02hZ
7`0a:R000P0b:B0202PU7080:BHM00D0:RLN02/X7`0[:1l0:bPO034[7`02038/800303<]8@0d;R80
=BlS0080=S0T00P0=R`R03D[8@0c:Al0<BLM030V700a9ad0<RPN03<Y7`P0<R`N200i;Ad803X^7P80
>2lN0`0g;Qd503H]700303T]7@0k;Qh0?RhO0080@2hP00L0@BhP044^7`10;al0@2lO03h^7P0l;ah0
>RlM00<0>30M200l;ah403lb8@@0?S4P01<0>c0N03`a7`0n<b40?c@R03hc8@0l<Al0>RlM03T^700n
;Qh0?RhO03/^7P0i;Al0=R`P03@/8@0c:R40<R/Q038Z7@0c:ah0=2`O0080=BdP00@0<b/N034Y700`
:1/0<b/P100b:Ql3034Y7P0602d[7P0^:Qh0;RXN030Z7P0a:Ah0<RPN0P0d9ah803H/80<0=bhM0`0h
;ah203T`7`<0>2lN:oooool002[ooooo00<0Ufdm09Q^?P2JL4000P2KLD400`2JL400V6hn09M]?@03
09U`?00309Ya?@2KLSh0Vg8n0080W7<o1P2JL3h209]a?`P0X70o202LLcl209mc@P80X7A300D0XGE4
0:9fA@2RMTD0XWI509eiA@0209iiA@030:1hA@2QMdD0XWI50080Y7I50P2SMdP0102SMdH0XgQ50:=h
A@2SN4<20:=h@@@0WG8o00@0WW=00:5f@`2SN4D0YGY72`2SN4D40:AiAP80YGY7202TNTP01P2VO4X0
YG]90:AjB02SNDL0XWQ60:5gA@80X7I40P2NN4T00`2MMdP0W7I709]eAP0209YdA@0709UcA02KL4<0
VVm209U^@@2GK3l0UFXm09=X>`02099W>P80SFLj00@0S6Hi08]U>02:I3L0RF<f0P28HSD01P2;Gc80
REha08QM<P25Fc40PEXa07iH<@80NULa00@0NUL_07QE;@1fDb/0M54Y0P1cD2P00`1dDBT0ME8Z07=C
;002079B:`03075A:P1`D2T0KdlX0080KThW0P1_CR/306i=:P/0KD`Y0140LU8[075A:P1aDBX0LE4Z
079B:`1eEBh0MeL`07UI<P1lEbd0OEP^07iI;`1oFS00PE`b089M<`23GS@0Q5le08IP<@0208MQ<P03
08QR<`29Hc@0RV@e0080RfDf0P2AIcD2099X=P0409=Y=`2DJSP0U6Xh09E[>@P0U6Xh202AK3P01@2C
J3/0U6Tl09AY?02CJ3/0TVLj0080TFHi00<0TVLj091U>02@ICP01`2@ICP00`2;H3D0S64f08mT>@02
091U>P0308mT>@2<HCH0Rf0e0080SV<i00<0SV<h08iS=P2>I3@00P2>I3800`2>IC40SF<a08eS<@06
08iT<P0508]P<`2<HC@0S64d08eR=@2>HcH00`2?I3L3095V>@@0TVLj00L0TFHi09=Z?P2CJS`0U6/m
09A/>`2EKCX0UFdi0080UVlh102EL3`0102FLCd0Ug8n09Mb?P2HLclD09U_?@80V6hl0P2GKC/02@2G
LD80UW1109E_@02DKSl0Tfdn099/?@2AJc`0T6Xk09E`>`0209A_>P0309=^>@2BKCP0TF`g0080T6/f
0`2EJcT209AZ>0<0TfTg1P2?JSH2091[=`80UFm000@0U6ho09=]?P2BK3d0TV`m0P2AJc`3099/?@80
TF/l0`2@JS/03@2;IcL0S6Ph08iZ>P2?Jc/0T6`l08m[>`2>JSX0SFTi08iY<P2=J340SFPc08aW<`2;
IC@00P2;ICH00`2;ICP0RFDe08UU=@0208QT=00308MS<`26HS80QV8b0080QV8b0P25HcD208AR=004
08=Q<`22H380PEla085O<@80NU/_0`1iFRh307QI;@0P079E;@1aE2`0Ke4[06e?:`1[CB/0JD/Y06Q9
:P1WB2/0HDXX06199`1LB2L0F4DU05=2901@?b<0CChQ04/m8P18>B80ACTQ04@h8P10=B40?3@Q03Tb
7`0f<Ah0=BlO03D]800d;R00<bdO030]7P0^;1d0:b`L02X]700Y;1/302XZ80@0:BTO00@0:2PN02@U
7@0T9Ad092DM0`0S91`2028S6`<08B@M0P0P8a`301lR6`P082<L100S91`402@U7@P08RDL00<08B@M
020S700P8a`00P0P8a`301lR6`P07R4J0`0O81X2020Q6`<08B8L0P0S91`0100S9AX092HK02@V6@0U
9aT202DX5`<0;BXK0P0^:a`302l/7@06034b800^;al0:b`L02PY6`0V9QX09BDK0P0V9Qh01`0U8Q/0
9R<J02LT6`0Y9a/0:bTL02d[700^;A/00P0_;Q`00`0g;Qd0>2lN03P_7P0203P_7P<0>C0O00X0>S8O
03/c800l=240?3@Q03/c800i<Ah0=blL03H^6`0k<1`0>RlK0`0i;QX00`0k<1`0?C8N03hc7`02044e
7`06048f7P13=ad0ACXN04Hk7@17?1h0B3dM0P19?R8204Xo8`<0Bd0T00<0C44U05109P1@@2H00P1A
@BL40592:00304]0901<@BD0CD8V0080CT<W00<0CD8V04]0901:?b<00`16?b<204Dn8P<0A3dQ00<0
@c/T044i8P10>2400P0n=Ql00`0o=b00@3PQ044i8P03044g7080@SPM0`13>Ah00`16>R00Ac/Q04Lk
8@0204Lk8@<0B3`R1P18>Ql204Li7P0604Ti8018>R00AcTO04Di7`13>Ah0@CXN0P0o>Qd204Lh8@04
04Li7`18>Ql0B3XM04Pj7@80BC`L0`1>?Qd204lo7PH0D40O0P1A@B0305928@80Dd0O0P1D@B0305E2
8@0905I38P1G@240Ed0Q05U28P1KA280GDLR05m98P1PBR40HD/R0080GdTT00@0GTPS05e78P1LAR40
FdDP0P1JA1l905a:9080FDTU00@0F4PT05M78`1GAb<0ETHR0P1EAB4205U78@@0FTPR0P1IAb4205]<
8`0605i<901PCBD0HddV06E=9`1VCRP0IddX201XD2@0101XD280JE4S06]C9@1]EBL206iF:00706eE
9`1/E2H0L5@R071D8P1aEB<0LeLU07AH9P0307EI9`80NETZ00<0N5TZ07IJ:P1eFbX00P1cG2X02@1b
G2X0NF0Z07QO:@1hGR/0Med/07IK;01eFRd0M5T/07AI;P0307MM;080MU`[0`1eFbX0101kGc00NUh_
07YN;`1iGBh207QL;@80Me//0P1hGC0207ML;`@0MU/^0P1bFbl00`1aFRh0L5T]06mH;00206iG:`04
06eF:P1[ER/0JUDZ06QC:0<0IU4V00P0Ie8W06QC:01VD2T0IDlX06A>9`1SCBH0HT`U061:8`80GdTR
0P1RC2D00`1QBb@0H4XS05m98P0205i88@0605e7801GAbH0ETHU05I69@1EAB@0E4@S0P1C@b80101B
@R40D44P0511801@@B0205528@<0DT<R0P1@@1l205518080DT8Q0P1C@b801P1EAB@0E4@S05A48`1D
A2<0Dd<R05928@80DD4P00<0D40O05528`1A@R<03P1A@R<00`1@@b40DD@R05958`0205958`040513
8@1>@Al0CD0N04hm8`80CCdS00<0BcdR04Tn8P18?b800P15?R4304<l80<0@S/O0P11>Qh203/g70<0
?3PM0`0m>Ah01P0k=a`0>SHK03Xf6`0i=AX0>3@I03Lc6080=S8G0P0f=1/0100e<a`0=38M03@b7@0c
<1d2038_7P06034`6`0a<1`0;S0K02d`7@0]<1l0:blP0P0Y;b4202LX800302HW7`0U9Qh092DM0080
8b@L00<08R<K024T6`0Q91/0100P8aX201lR6@<07B0I0`0L7aP201/N5`P06Q`I0`0H6QT301LI6080
5QPG200F5aT801DF624051DG200B4aDH014G5`P051DG0P0B4aD201<D5P8051DG0P0E5QP801@E5`P0
4ALG:00D5AL201DF608051DG0P0C51H2018C5@/051DG0`0E5QP201HG6@P05ALF2@0F61L801HG6@P0
5QPG0`0E5aH201HH5`/05aTH200H61P801XJ6P<06ATG0`0J6QPB01/K6@0601lO7@0N7Q`07QhL01dM
6`0L71X06a/I0P0J6QP801dM6`807A`J0`0N7A/301lN70P081lJ0P0P8A/301lP6P<07QlI200M7QP8
01hO6@<07AdK0P0L71X301/K6B4071`J0`0O7QT3020O6P808B0K0`0P7aX3024P6`808R4L0`0T7aT2
02DP6P<09R4K0`0W8Q`302PS7@80:B@N0P0/9Ad202dV7P80;RLO0P0_:208034Y7P80<2XN0P0_:Ad2
02hX7080;BLK00@0;2PO02/W7P0[9ah0:bLN0P0Z9Qd202TU700302dW6`0/9QX0:bDI0080:R@H00<0
;2HJ02hX700_:Ad00P0_:AT01P0^:1X0;RPL02dV700]9Qh0;2DM02`U7`80;B@M00H0;2DM02TU700X
9A`09RHL02DU6`0T9Q/2028R6P808b<K0P0T91`:02DU7@8092@L00<08b<K028R6P0R8QX00`0R8QX4
02HR6@@09b<J0P0Y91h202PS7@809b8L0P0V8A/902<S6`<092@L0P0S8a/C028R6PH08B8L0P0R8ad2
024Q6@<08R8J0`0S8a/302@O6`809B0L0`0V8Ad4028T6@808bDJ0P0T9Q/802DU7@0902<S6`0R8QX0
8R8J028R6P0S8a/09RHN02PX800Z:R80:B/M0080:b`N00<0;B/N02l[7`0a:al00P0c:b0302/W7P@0
;2PO00H0;BTP038/800b;200<bdQ03@^8P0e;b<203H`900403La9@0f;280=B/Q03<Y7`<0<RPN0P0d
:R0803<]7`P0>BdM200j;Qh203P_7P<0=bhM0`0f;A`03P0e;1/0=RdL03P/700j;Ad0?BdN03l]7`10
;R00@RlQ048_8011<200@2lO03l_7`0l;ah0>c0N0`0h<1d803h^7PP0?c8Q0P0m<R0303hc8@0C03db
800k<1h0>RlM03h^7P0n;Ql0>bhN03T]7`0g;B40=BdR03@[8P0c;280=2XN03D[7`0f;200=bdQ03H/
800e:al0<bTM034W6`0203D[8@80=2XP00D0<bTO038X7P0b:1h0<RPN02X[7@0202`Z7@0302dY7@0_
:Ad0<2PM0080<BLM200e:al203L^7@<0>2lN1P0i<1l[ooooo`00:_ooool00`2FK3X0V6hl09Y`?P02
09ab@00309Y`?P2HKS`0UV`j0080V6lk00<0VG0l09Ya?@2KLSh00P2LLcl00`2MM400VFlm09U_?@03
09Y`?P<0Vg4o202PL3l809ac?`0609ea@02NLT40WW9109mc@P2PM4<0XGE40P2RMTD01P2LN4@0WGQ4
09ehA02OMd@0X7I40:5eA080XgE40P2SMdP0102SMdH0XgQ50:=hA@2SN4<20:=h@@0809ie@@2MM400
W7<o09ed@02NMD40X7M30:=jAP2TNdL90:=hA@P0Y7U6202TNTP01P2VO4X0YG]90:AjB02SNDL0XWQ6
0:1fA080WgE30P2MMdP00`2LMTL0VgE609YdA@0209UcA00609Qb@`2KL4<0VVm209M/?`2EJSd0TfPk
0`2BIcX208aV>@80RfDh0100RV@g08US=P28HSD0R68e08]O<P29GS40R5db08AJ<020FC00OEL`07UF
<01hEBl0NUL_07UF;P1gE2`0ME8Z0P1dDBT207EB:P80LU8[00<0LE4Z071@:@1_CbP00P1^CRL00`1]
CBH0Kdh[06i=:P0206i=:P80KD`Y2P1/BbP0201cDb`0LU8[079B:`1bDR/0Le</07IF;`1hF340NUXc
0P1mF2h0101nFBl0P5/a085L<P23GS@208AO=@0608MQ<P28HS<0R68c08US=02:I3D0RfDf0P2<ISL0
1@2BISD0TfLf09=W=P2CIcH0U6Pg00<0UFTh202CJCL8095/>008095V>@2DJC`0UFXm09AY?02AIST0
Sf@g095V>@2CJ3/9091U>00308aQ=P2=HSL0SV<h00<0SV<h00L0SF8g08aQ=P2>HcT0SV<i08iS>02>
HcH0SV@d0080SV@b00@0SVDa08eS<@2=Hc40SF<a0`2>I38208mU<`<0SV<f0P2?I3L3091U>00308mT
=`2@ICP0TFHi00<0TfPk00P0TVLj095V>@2AJch0TF/l099/?@2BK3/0Tfhj09A_>P80UG0i00H0UW4m
09E`?02EL3`0U6lk09E`?02FLCd209Qc?`P0VFlm2`2HKS`309M]>`80UV`j00D0UW1109E_@02EKd00
U6ho09=]?P02099/?@07095[?02EL3/0U6lj09A_>P2CKST0TVdh095/=`02091[=P<0UF/i0P2DJSP3
09=Y=`80SfXf0`2@JcL3095/>080Tfdn0`2BK3d3095[?0<0TV`m0P2AJc`3091Z>`0308aX>02=JCT0
SVXj0080Sf/k00<0SVXj08eY>@2;IcL00P2>JC800`2<Ic80RfHb08YT<`0208]U=P0708aV>@2:ISH0
RFDe08UU=@28I3@0Qf<c08IR<P0308EQ<@80QV@f00@0QF<e08AR=023HC<0Pf4c0P22H38307UJ;P80
N5T]0`1gF2`2071B;00406i@;01/CR`0JD/Y06M8:@80IDHY01P0GDTX05a89`1IARH0E4<U0550901>
?R@0BcdR04Tk8@15>B<0A3PR044f8P0m=B80>C8O03Ha7P0b;ah0<BhM03<]7`0a;Ql0<2dN02h/7@0[
;1`0:B`K02P/6`0W:aX802TY7`<092DM0P0S91`3028S6`<08B@M0P0P8a`301lR6`P08B@M100S91`4
02@U7@P08B@M200O8Q/801hQ6P807b0J0P0P8A/3024R7007028S7@0T9Ad092HK02@V6`0U9aX09BLI
02HY600202HY5P80;BXK0P0^:a`302l/7@0@030]7P0_<R40;C0O02T[7@0V:1/092HK02@U7@0U9R00
9RLQ02PS7@0Y9A`0:RHM02`X7@0]:Ad0;b`M030]7080<BhM200i<Ah00`0h;ah0>C0O03Xa800203/b
8@0303T`7`0h;ah0=RdL0080>c0L00h0>RlK03T^6P0j;a/0?34M03hc7`10=B40@CDO048f8013=al0
A3PN04Hk7`17?1h0B3dO04Tn7P80BSlS0P1;@2@304a19@0304e29P1??bD0CclU00<0D40V0`1A@BL2
04Tn8P<0Bd0T00<0BChR04Pm8@16>al00`15?R@204@m8`<0@c`R00<0@CTT040h8`0n=R400P0m=B00
100n=R40?cLR040h8`11=a`3048h7@80@cTN0P14>Ql804Pn8`0404Dk8014>Ql0A3XO04@j7`<0@cTN
00L0@SPM04Di8@14>200@cTP044j800o>Al0?SXO0080>cXN00P0@cLQ04@h8P14>200A3PN04Dj7P15
>Q`0AS/M04Hk6`80BS/L0P1;?1d304`m7P0404dn7`1>?b00CSlP04ho8080Cd0Q0`1@@B8304hn7@<0
CclN0P1@@1l01P1G?b<0F44R05U28`1KA2@0GDHT05i88`80H4XS0P1MAR@205a58`0405]48P1J@b40
FT<Q05U280T0EdLS201B@b800`1C@al0E4@P05E58@0205I68P0305E58@1DA200Dd<O0080ETPQ00H0
F4TR05a:901NBRD0HD/V069<9`1TC2P306A=8`0806E>901VCbD0ITlU06I?9@1WD2H0ITlS06M@901Y
DRH306]D:080JE8V00D0KE4Q06iB8P1`E2@0LUHV07=G9`0307AH:080N5PY00<0MePY07IJ:P1eFbX0
0P1dGB/02@1cGB/0MehX07MN:01gGBX0MU`[07IK;01fFbh0MEX]07EJ;`0207MM;080MU`[0`1eFbX0
0`1dFRT0NEd]07UM;@0607UM;@0407YO<P1iGS40N5d`07ML;`80MU/^00<0Me`_07QM<01cG3000P1b
Fbl00`1aFRh0L5T]06mH;00206iG:`0406eH:`1/EbX0JUDX06QC9P80Ie8U00L0J5<V06UD9`1UCbP0
IDlX06A>9`1SCBH0HT`U00<0HD/T00H0HddV069<9@1RC2D0HD/T061:8`1OBB8205i88@<0ETHU0P1E
AB@305A48`80D44P0P1A@R4305938P0405=48`1@@1l0D40O05107`80DD4P0`1B@R4505A48`@0Dd<R
201A@R<00`1@@B80DD8S0593900205=49@030593901A@R<0D44R0080DT<R0`1DAB@0101B@b80D44P
04m07`1??R@204hn900304`n8`1:?b<0B3lR0080ASlR0P14?B4204<l80<0@S/O00<0@CXN03di7P0l
>1d0200l>1d00`0k=a`0>SHK03Te6P0203Pd6@0403Lc600f=1/0=S@K03Dc7080=38M00T0<c0M038_
7P0b;ah0<2lJ030_6`0];aX0;2lL02`_7P0Z;Ql00P0X;R0202LX800302HW7`0U9Qh092DM00808b@L
00<08R<K020S6P0P8aX01P0P8aX301dP6@<071lH0P0K7QL801XL6@<061XI0`0G6AP201HH5`P05QLI
200E5QPQ01@E5`P04Q<E600A5aL801@E5`804Q<E0P0C51H201@E5`805AHH200D5AL8014G5bP051DG
0P0E5QP201@E5`804a@F0P0B4aD;01@E5`<05AHH0P0F5aT801DG5PT05QPG200E5QP801HH5`<05ALF
0P0F61L;01LI60P061PH200J6QX301TI5`806QXH4`0K6aT0100N7Q`07AdK01dM6`0M7A/401`L6PP0
7AdK0P0M71X301hM6`<07ahL200P7aX3020Q6`807b0J0`0N7aT801dN60P07QlI0`0M7A/201`L6Ph0
6a/I0`0L71X301dM6a0071`J0`0O7QT2020O6P<08B0K0`0P7aX3024P6`808R4L0`0T7aT202DP6P<0
9R4K0`0W8Q`202PS7@<0:B@N0P0/9Ad202dV7P0402hW7`0_:200<2TQ030Y8@P0<bTO00D0<B/O030Z
7P0`:Qh0;bTM02hX700202dW6`0302`V6P0]:B00;2PO0080;2PO0P0[9ah202XV7@0302dW6`0/9QX0
:bDI0080:R@H00<0;2HJ02hX700_:Ad00P0_:AT00`0_:A/0;RPL02hW7@0202dV7P0602dV800^9Ah0
;RDN02dV7P0Z9Qd0:BHM0P0V9Q`0100U9a`08b<K02<S6`0S8a/202@T70/09BDM00<092@L02<S6`0R
8QX00P0R8QX00`0S8a/092@L02DU7@0402HR6@809b<J0P0X91/202TT7P80:2<M0P0W8Q`202HQ6`T0
8b<K0P0T91`202<S6`<08R8J00<08B4I02<S6`0S8a/01P0S8a/8028R6P@08B8L0P0R8ad202<T7P04
024Q6@0R8QX08R8J028R6P808b<K0P0T91`302@O6`809B0L0`0V8Ad0100R91T08bDJ02<U6P0S9AX2
02@V6`809BLL200V9Qh02@0T91`08b<K02<S6`0R8QX08b<K02DU7@0W9al0:2PP02T/6`0202X[6`03
02d[700^:a`0<B/M0080<RXM00<0;RLO02lX800_:2001@0_:2001P0a:al0<R`P038/800c;B40=2hR
03D_8`80=S0T00<0=R`R03D[8@0d:R000P0c:Al00`0d:R00=B/Q03H/8P0803<]7`P0>BdM200j;Qh2
03P_7P<0=bhM0`0f;A`203D/6`0703L[6`0h:a/0?2`M03l]7`11;b40@c0R048_8002044`800303l_
7`0m<1l0>c0N00<0>C4N200o;Qh0100n<B00?c8Q03lb8@0o<R43040c8P03044d8`0n<b40?S<Q0080
?S<Q0P0m<R004P0l<Al0>c0N03l_7`0n;Ql0?2lO03X^800g;B40=BdR03@[8P0c;280=RXN03L[7`0h
;200>BdQ03P/800g:al0=BTM03@X7080>2/R00<0=bXQ03HY800e:1l00P0d9ah01`0c9Qd0:B/M02X[
7@0Z:ad0;2XM02dY7@0_:Ad00P0`:1d803D[7`0403L^7@0h;ah0>2lN03P_7P80>C0O0P0j<B0303dd
8b_ooooo000Zooooo`0309E[>@2GKC/0Vg4o0080WG=100T0Vg4o09M]>`2EJcT0Ufhj09Q_>`2IL3`0
VW4m09]b?P2LLcl00P2MM40309U_?@0309Y`?P2KLCl0Vg4o0080W790202QLD0809ac?`0609]_?P2L
L3l0WG5009ib@@2OLd80X7A30P2QMD@01P2KMd<0W7M309ag@`2NMT<0WgE30:1d@`80XWA30P2TN4T0
102TN4L0Y7U60:AiAP2TND@20:Ai@P0809mg@`2NMT80WGE109ee@@2NMT80X7Q40:9jAP2SNdL90:=h
A@P0Y7U6202TNTP02@2VO4X0YG]90:AjB02SNDL0XGM50:1fA02OMD<0WWA209egB00209afA`0309]e
AP2JM4D0VG=40080V79300D0Vg1309U^@@2FJch0TfPk099W>P02095V>@06099W>P2<IST0S6Hi08]U
>02:I3L0RF<f0P28HSD03@27HC@0Relb08UN<@28GC80Q5X`081I<01lERl0N5D_07MD;P1kF300NUL_
07QE;@1fDb/00P1eDRX0201fDb/0Me@/079B:`1bDR/0LE4Z071@:@1_CbP0KThW0P1]CBH306i=:P80
KD`Y2`1/BbP207=C;00<079B:`1cDb`0M5@]07IF;`1iFC80Ne/d07eH;P1nFBl0OeX`081K<@22GC<0
Pehd0P24GcD208QR<`0308US=02:I3D0RfDf0080S6Hg00@0SFLh09EW=P2EIcH0UFLf102FJ3L00`2G
JCP0TfTg09=Y=`0609=Y=`P0TF`h00P0T6Dh09=X>`2FJch0U6Tl091U>02>HcH0T6Dh09=X>`T0T6Dh
00<0SV<h08eR=`2<HCH00P2;H3D00`2<HCH0SF8g08iS>00208iS>@0308iS>02>HcH0SV@d0080SV@b
00<0SVDa08aR<02<HS000P2=Hc40102>I380SfDc08mU<`2?IC<3091U>0@0TFHi00l0TVLj08iS=P2?
I3L0TFHi09=X>`2DJC`0TfPk099W>P2AIST0T6Xm095[?02BK3d0Tfdl09A_>`2EL3/00P2FLCX00`2G
LSh0UW4m09E`?00209A_>`0309Ia?@2HLcl0VGA000P0VFlm202HKS`209M]>`<0UV`j0`2EJcT409A^
?`@0Tfdn00H0UG0k09A_>P2DKcX0Tfhi099]>02AK3L2091[=P<0UF/i0P2DJSP309=Y=`80T6/g0P2A
K3P0102BKCT0Tfhj09=^>P2CKSX208mY>P<0T6Xk0`2AJc`3099/?@80TF/l0`2@JS/0402>JSX0Sf/k
08m[>`2@K3`0Sf/k08eY>@2;IcL0RVHf08mZ<`2>JC80S6Lb08YU<@2:I3<0RfDf08aV=`2=IcX208YV
=P0408UU=@28I3@0Qf<c08IR<P80QF4a00<0Q60`08AR=023HC<00P22H3801021Gc40P5h`07mM;`1o
GBl307QI;@80MeP/0`1fEb/0801`DR`0Ke4]06e?:`1ZC2X0J4TZ06E6:@1TABT0Hd@X05a89`1JAbL0
F4DU05=2901?@2<0BcdR04Lk8@16>R00@SLQ044f8P0n=R40>S<P03Lb7`0c<1l0<BhO02l]7P0a;Ql0
<2dN02l]7P0/;Ad0:RdL02P/6`0W:aX09B`J100X:1h402TY7`0402@U7@0S91`08b@L02<T70808R<K
0P0Q8QX3024T7@8082<L0`0O8Q/8024T7@@092DM100S91`8020R7@P07b8K200N8AX3020Q6`<08B8L
0P0R8ad01P0T9Q/09BLJ02DW6P0U9aT09RTH02HY5P809bXE0`0^:a`302l/7@80<2dN00h0;C4R02/_
800W:ad08bHK028U700S9Ql09BPQ02LY900[9R00;2PO02dY800^:Ql0;b/O030]7P<0<BhM200i<A`0
0`0f;Ah0=bhO03T`8@0303Xa8P0403T`8@0h;b00?34M03`a7@80>c0L00`0?34M03hc7`10=B40@SLS
048f8013=b40A3PP04Di7`17?200B3dO04Tn8019?Qh304]09080C44U0`1=@RH304hn90<0CclU0P1@
@2H00`16>al0Ac`P04Pm8@0204Pm8@0304Hk7`14>Ad0@cPL00<0@3XR0P0o>B4303hh800303hh8P0m
=b40?3HP0080>cDO00<0?3HP03hh8P0o>B<01013>Ah204@j7`80AC/P1P15?R8204@m8@80@c`R0P12
>b401@11>R00@3TO040i7`10>Al0@cPR0080@CTR00<0?cTQ03hj8@0k>B000P0j>R0204<f8`0304@h
8P14>200ACTO0080ACXN00<0AS/M04Li7017>A`00P18>Qd304Tk7P0404Xl7`19>ah0BC/N04Tk7P80
BS`O0`1;?B0304Xk6P80Bc`K0`1<?A`01P1F?R80EclS05M08@1I@R<0FT<S05]48P80G4HQ0P1LABD5
05]4900305Y38`1DAR<0E4HS00L0E4HS00@0BChN04Xo7`1;@200Bd0P0P1=@R801@1>@b<0Cd@T04m1
7P1@@Ql0DT@Q0080DdDR00T0DT@Q05127`1?@Ah0DDDO05=5801DAR40ETHR05Y8901LB2D00P1PBBL0
1P1OBB00H4XQ065;8P1RC2<0I4hU06E?9P80IU0W00h0I4lT06E@9@1WDRL0J5<X06UD:@1XDbP0Ie8W
06IA9P1ZCQl0K50Q06mC901bERL0LeLX07AH:@80LeLX00D0MeLX07QH:@1gF2T0MUXZ07EK:P0207AM
:`0607AN;01cG2H0Le`V07AM:@1dGB/0M5`/0P1eGBl0101eGC40MU`[07IL:`1fG2/307EK:P80M5XY
0P1gFbT0101hG2X0NEd[07YN;01kGbd207aP;P0807]P<`1jGc80N5d`07ML;`1fFbh0Me`_07QM<01i
GS4207=L<004079K;`1aFRh0L5T]06mH;080KUL[00@0KeX[06eH:@1[ERL0JE@U0`1XDb@00`1YE2D0
HddV06==9P0806==9P04069<9@1QBb@0H4XS05m98P80GTPQ0`1FARD505E590<0DD8Q0`1B@b8205=4
8`@0D40O0P1A@B0205928@@0E4@S0P1EAB@305I69@P0DT<T00<0D44R05528`1CA2D00P1DABH0301C
A2D0DD8S05118P1B@b80Dd@S05A5901EARD0E4DT05=48`1A@R40D44P050o9@80CclU00<0CClT04]0
9019@2<00P17@2<304@m8@80@c`P0`12>al203hj7`80?CTN00@0?3PM03/g700j=Q/0>SHK0P0n>Ql0
100m>Ah0?3PM03/g700j=Q/203Te6P80=S@K00@0=C<L03@b7@0d<Qd0<c0M0P0b;ah01P0^;AP0;RdI
02`^6@0Z;AX0:RdL02T]7P809R`N0P0W:2000`0V9al09BHN02@U7@0202<T7003028S6`0P8aX082<J
00H082<J0`0M81T301`O60806ahG200K7AX301PJ6@<05aTH0P0F61L801HG6@P05AHH8@0D5AL8018C
5@P04ALG200B61P8014G5`P051DG0P0B4aD201<D5P8051DG0P0E5QP801@E5`P04ALG:00D5AL201DF
608051DG0P0C51H2018C5@/051DG0`0E5QP201HG6@P05ALF2@0F61L801DF60P05QPG0`0E5aH201HH
5`/05aTH200H61P801XJ6P0401TI5`0J6QP06QXH01XJ60806a/I5@0L71X201dM6`<07QhL200M7A/2
01dL6P<07QdK0`0O7Q`8024P6`808B8L0P0P8A/301lP6P0301hO6@0M7QP07AhH00H07AhH200N7aT3
01dM6`8071`J2`0K6aT00`0J6QP06a/I01/K6@0301`L6P807AdK00<07QhL01`L6P0L71X03P0L71X0
100O7QT081lJ020O6P0P7aX2024P6`808R4L0`0P7aX3024P6`808R4L0`0T7aT202DP6P<09R4K00@0
9b8L02PS7@0X8ad0:2<M0P0Y91h202XU7`0602/T700/9Ad0;BHN02hW7`0_:200<2TQ0P0a:R8803@Z
8080<B/O00@0<2XN02lY7@0^:1`0;BLK0P0/9QX302dY8080;2PO0`0[9ah00`0]9a/0;2HJ02/U6@02
02XT600302`V6P0^:1`0;bTM0080;bTI00H0;bTK02lY7@0^9ad0;RLO02dV7P0]9R0202lV7`0302hW
7`0[9ah0:RLN00809bLM00<09RPM02<S6`0S8a/00P0T91`402DU7@P09RHN00P092@L02<S6`0R8QX0
8R8J02<S6`0U9Ad09bLO02PX80809R8I0P0W8aX202PT6`80:BDL0P0Y91h202PS7@809b8L0P0V8A/<
02<S6`<08R8J0P0Q8AT802<S6`P08R8J00<0824K024R700Q8Q`00P0R8ad202<T7P0402@U7`0R8QX0
8R8J028R6P808b<K0`0T91`302@O6`809B0L0`0V8Ad202<U608092HI0`0U9aX00`0V:1/09bLO02LW
7`0602LW7`0302HV7P0U9Ad092@L00808b<K00@092@L02DU7@0W9al0:2/H0P0Y:QP00`0/:aT0;BXI
02lY6@02034Z6P<0<BPQ1@0`9b02030Z7P04034[7`0b;200<bdQ03@^8P80=BlS00<0=R`R03D[8@0d
:R000P0c:Al00`0e:b40=R`R03L]8`0803<]7a00>RhN0P0h;ah303L^7@<0=RdL00T0=B`K03@[6P0f
:QX0=bXJ03/[700n;1h0@BlQ04@a8`12;b000P11<2000`10<200?C0O03`a7`0303Ta7PP0?bhN0P0n
<B0203lb8@04040c8P11=2<0@C@S044d8`80?c@R0P0n<b4303db800;03`a7`0o;al0?blP03`_7`0j
;R00=bdQ03D]8P0e;2<0<b`R03PZ7`0i:b000`0j;240100h:Ql0=bTN03DW700j;2<203T[8P0503PZ
8@0f:1l0=BLN03DW7P0d9Qd00P0Z;1h0100[;1h0;B/N02hZ7P0^:Qh2030Z7PP0=2XN0`0h;ah203T`
7`<0>S4P0`0l<b8[ooooo`00:_ooool00`2EK3P0Ufhj09]b?P0209ed@00409]b?P2GKSX0UF`h09M^
>P80V6lk00<0VW4m09]b?P2LLcl00P2MM400102HKS`0VFlm09U_?@2JL3h209]a?`80W790202QLD08
09ac?`0609Y^?@2KKch0Vfln09ea@02NLT40Wg=20P2PM4<01P2IMD40VWE109Ye@@2LM440WG=109ib
@@80X7910P2TN4T0102TN4L0Y7U60:AiAP2TND@20:Ai@P030:5iA@2PN4@0WgM30080WWI200<0X7Q4
0:9jAP2SNdL02@2SN4D20:EjA`@0Y7U60P2SN4D80:AjB0080:IlBP2UNdT0Y7Y80:=iA`2QMdD0WgE3
09id@P2MLd4209afA`0309]eAP2JM4D0VG=40080V79300L0Ug5209]`@`2IKT40UV/n09=X>`2AIST0
T6Dh0080TFHi0P2<IST0102;ICP0RV@g08US=P28HSD208MQ=00<08aP<`2:Gc80R5db08AJ<01oF2l0
O5H_07QE;`1gE2h0O5Ta07]H<01iERh0Me@/0P1fDb/207MD;006079B:`1aDBX0LE4Z071@:@1_CbP0
KThW0P1]CBH206i=:P<0KD`Y2`1/BbP04@1dE2d0Le</07=C;01cDb`0M5@]07MG<01iFC80Ne/d07eH
;P1nFBl0OeX`081K<@22GC<0Pehd08AO=@25H3H0R68c0080RF<d00<0RV@e08]U=P2<ISL00P2=IcP3
09EW=PD0UVPg202CJCL8095/>00808mT=`2CJ3/0UV/n09AY?02?I3L0SF8e091U>02DJC`9091U>003
091U>P2>HcP0Rf0e0080RUld00<0Rf0e08iS>02@ICX00P2>HcT00`2>HcP0SV<f08iT=00208iT<P03
08iU<@2<HS00S68`0080SF<a00D0SV@b08mU<`2?IC<0T6Hd095V>@06099W>P0509=X>`2=HSD0Sf@g
095V>@2CJ3/00P2DJC`0302BIcX0TFHi08mZ?@2@K3`0TFdm099^?02CKc/0U74k09Eb>P2FLc/0Ug8n
09Ia?@<0U6lk00<0UW4m09Qc?`2IM400202IKcd809Q^?080UV`j0P2EJcT409AZ>004099/?@2CKCh0
Tfdn09=]?P<0U6ho00L0UFm009E`>`2DKcX0U6lj09=^>@2BKCP0TF`g0080T6/f0`2EJcT209AZ>0<0
TfTg0P2AK3P2099]>@0409=^>P2DKc/0U6lk09E`?080SFLh00@0SVPi08mY>P2@JS/0T6Xk0P2AJc`3
099/?@80TF/l0`2@JS/0402?Jc/0T6`l091/?02@K3`0Sf/k08aX>02:ISH0R6@d08mZ<`2>JC80S6Lb
08YU<@2:I3<0RV@e08aV=`2=IcX208YV=P0308UU=@28I3@0Qf<c00<0QF4a00H0Q60`081N<020GS00
Oed_07iL;P1mFbd207aJ;00407]I:`1hFBd0N5T]07QI;@80MeP/0`1fEb/0801_DBd0KU0/06a>;01Z
Bb`0IdP[06E6:@1SA2P0HT<W05Y79`1IARH0ED@V05529@1=?b@0BcdS04Hj8015>B40@CHR03lg8P0m
=B80>S<Q03H`800b;ah0;bdN02h/7@0`;Ah0;bdN02h/7@0[;1`0:B`K02L[6P0U;1X092/I1@0X:1h3
02TY7`@08b@L0P0R8a/2024R6P<08B@M0P0P8a`301lR6`P08B@M100T9Ad402<T70P0828M0`0N8AX5
01lR6`P07R4J0`0P8A/2024R70<08R<M0P0U9aX0100U9aT09RPJ02HY600W:QL202LZ5@<0;R/L0P0_
;1d3030]7P0902``8@0Z;R009RXL02<V6`0R9A`08bHO02HX8`0X:RD0;bPR0080<2TQ00@0<BXP038/
800c;Al0<bdM0P0d;Qh303Xb7@D0>C4L00@0=2/L03D/7@0h;b00>C0Q0P0j<B8203T`8@0803db7P0l
<Ad0?34M03`a7@0m<Qh0?c@P048g8`13>2@204<g8@0604@h8015>Al0Ac`P04Pm7`19?R00BSlO0P1;
@2@204a19@<0CD8V00<0CT<W04dm8`1=?B<00P1=?B<204hn9080CclU0P15>Qh01P16>al0Ac`P04Hk
7`14>Ad0@SLK044f6P80>cLN0`0j=Qd303Te700303`g8`0k=R80>SDQ0080>C@P00@0>cHR03`g8`0n
>BD0@cTN0`14>Ql204Dk8080AS`Q1013?204048k7`<0@S`R00<0@C/Q040j800o>Al00P0o>Al01P11
>B80@3XR040j8P0n>R40?3XQ03/k8@80>3/P0P12=b<01P13>280@cTP04@j7`14>Ql0A3/N04Dl7`80
ASPK0`17>A`304Pj7@80ACLJ0P16>1/304Li700304Pj7@18>AX0BCXK0080BCXK0P1:>a`204/l7@06
05@l8P1D?200ECdQ05Ho801G@200Ed0N0P1H@Qd605]49080G4DU2@1BA2402`16>ad0Ac`N04Pm7`19
?R00Bd0R04e2901>@bD0Cd@V04i07@1?@Ah0DD<P0080DT@Q00<0DD<P04m17P1>@1d00P1?@ad04@1B
A1l0E4@P05Q68P1KAb@0G4PU05i79@1MAah0GTPO061:8@1QBb80HddT06E?9P1VD2L0Ie4X06A?901U
D2D0IU4V0080J5<X00L0Ie8W06IA9P1UD2D0JDdN06]?801^DR<0LEDV00<0LeLX00T0LUHW07MG:01g
EbP0MePY07IJ:P1eFbX0M5d[07EN;01dGR`00P1aG2D00`1bGBP0Led[07AN;@0207EO<00407IO<`1f
G2/0MU`[07IL:`80ME/Z0`1dFRT207IJ:00>07MK:@1iGB/0Nel]07aP;P1mHBl0OV8`07aQ=01kH3<0
N5d`07ML;`1fFbh0Me`_07UN<@1jGc8207=L<003079K;`1aFRh0L5T]0080KeP/00D0KUL[071K;01^
FBX0K5LX06UD9@0206QC9080JE@U0P1RC2D306==9P<0I4hW0P1SCBH00`1RC2D0HD/T061:8`0205m9
8P0305i88@1FARD0ETHU0080ETHU101EAB@305528@80DT<R0`1CA2<0101??ah0D40O05107`1@@1l2
05518080DT8Q0`1DA2<0101EAB@0ETHU05I69@1GAbH205Q89`P0DT<T00<0D44R05528`1CA2D00P1D
ABH00`1CA2D0DD8S05118P0205A48`<0ETHU00@0E4@S05928@1A@B00D3lU0P1??bD00`1=?b@0Bd0T
04U08`0204M08`<0A3dQ0`13?202048k7`06040l8@0o>b00?SXO03di7P0l>1d0>SHK0P0i=AX203lk
800303hj7`0m>Ah0?3PM0080>cLL00@0>SHK03Hd6`0f=1/0=C<L0P0d<Qd02@0c<1d0<RlN038_7P0]
;1L0;B`H02/]600Y;1T0:B`K02P/7@0202D[7@809bPP00<09RLO02DV7P0T9Ad00P0S91`00`0R8a/0
7b8I01lR6@04020S6P808B@K0`0M81T301`O60806ahG200K7AX301PJ6@<05aTH0P0F61L801HG6@P0
5AHH8@0D5AL8018C5@P04ALG200B61P8014G5`P051DG0P0B4aD201<D5P8051DG0P0E5QP801@E5`P0
4ALG:00D5AL201DF608051DG0P0C51H2018C5@/051DG0`0E5QP201HG6@P05ALF2@0F61L801DF60P0
5QPG0`0E5aH201HH5`/05aTH200H61P801XJ6P@06QXH0P0K6aTB01`L6P806a/I00@071`J01dM6`0N
7Q`07QhL0P0O7ad801dM6`807A`J0`0N7A/301lN70P08B0K0P0Q8Q`2020Q6`@07b0J200M7QP801hO
6@<07AdK0P0L71X;01/K6@806QXH00D06a/I01`L6P0L71X071`J01dM6`0201hN710071`J100P7aX2
024P6`808R4L0`0P7aX3024P6`808R4L0`0T7aT202DP6P<09R4K100X8ad202TT7P80:RDO00P0:b@L
02`U7@0]9Qh0;RLO02lX800`:B40<BXR038[8`P0=RTP00T0<R`P034[7`0`:Qh0;bTM02hX700]9a/0
;2HJ02/U6@0^:R400`0]:B0202`X7`80:bLN00<0;BLK02`V6P0[9AT00P0Z91P02`0/9QX0;RPL02lY
7@0`:QX0;bTI02lY6`0_:Ad0;RLM02hW7`0]9Qh0;BHP0080;bHO00<0;RLO02/W7P0Z9ah00P0W9ad0
0`0V:1d08b<K02<S6`0202@T70<09BDM2@0V9Qh02@0T91`08b<K028R6P0R8QX092@L02HV7P0Y:B40
:b/S02HR6@0202LS6P0302PT6`0Y9A`0:BDL0080:RHM0P0Y91h202PS7@809b8L0P0V8A/<02<S6`80
8R8J0`0Q8AT802<S6`P08R8J00@0824K024R700Q8Q`08R<M0P0S91h202@U7`808R8J0`0S8a/302@T
70<091lK0P0U81`302HQ7@0402<U5`0T9QP092HH02@V60809BLI0P0V:1X902LW7`0802HV7P0T91`0
8b<K028R6P0S8a/092@L02DU7@0W:QL202PY5`0302/Z600/:AP0;bTI0080<2TI1@0a:243030W8006
02lY7@0`:Qh0<2XN034[7`0b;200<bdQ0P0d;R800`0g;B<0=R`R03@Z800203@Z800303D[8@0g;B<0
>2hT00P0<bdO400j;Qh203P_7P<0=bhM0`0f;A`02@0e;1/0=2/J03DY6@0g:QX0>RXK03h/7P11;b40
A34S04<`8@02044`8003040`800m<1l0?34O00<0>C4N2010;Ah203ha800403lb8@10<b80@3<R044d
8`80@SDT0P0o=28203hc8@@0?C8P0100?blO03l_800l;al0>RhP03L]8@0f;R<0=B`S03@]8`0h:Ql0
>B/P03X/8@0k;B80>R`Q03T[800g:Ah0=BLL0P0j;2<00`0i:b80>2XQ03LY800203DW7P0703@V7@0Y
;Ah0:R`N02X/7P0[;1h0;B/N02hZ7P02030Z7PP0=2XN0P0h;ah303T`7`<0>S4P0`0f;A`[ooooo`00
:_ooool04@2HKS`0Ufdk09I/>P2FK3X0Ufdk09Y`?P2MLd40WWA209I^>`2GKc`0VW0n09a`?`2NL3l0
WVhn09a/?02MJS/0W70o0080WG5000<0WW9109mc@P2OLd800P2PM4<809eb?`80WG=10P2LLT0309]a
?`0309Y`?P2LLT00W7900080W790102KLCl0102NLT40Wg=209mc@P2PM4<20:5eA080XWI50P2VO4X0
102UNdT0Y7Y80:9hAP2QMdD20:1fA080XGE600H0XWI50:9gA02SN4D0Y7U40:Ai@P2UNT<90:=hA@80
X7A300<0XGE40:9fA@2SMdH00P2UNDP00`2VNTT0XgU70:=iA`030:AjB0<0YG]90`2PMT@01@2OMD<0
WWA209id@P2NM480WG=10080VgE600@0VWA509UcA02HLT<0Ug520P2FL440202AJc`0TV`m09=]?P2C
KCh0TV`m095[?02?JCX0SFLh0`28HcH508MR=@0808IQ=`25H3H0Q5le085L<P1nFBl0O5L]07YE:`1i
E2X507IC:`<0Me@/00P0MED/07AD;@1cDb`0LE4[071?;01^CB`0KD`]06a;;0<0JT`Z00D0JD/Y06Q:
:01VB2H0IDLU06A6900206Q:9P0306U;9`1ZC2P0JddY0080KDl[01X0KU0/07AA:@1eDRX0Me@/07UF
;P1jEbl0NEH^07QE;@1gE2`0O5L]07eH;P1nFBl0PE`b08=N=025H3H0Qf8h08QS>@27H3D0R64f08]U
>02=IcP0SfTh08mZ=P2>JCD0SVTd09EZ?`80UFXm00<0UF/k09E[>@2EK3P00P2EK3H808e/=`<0UF/i
0P2DJSP309=Y=`<0TVPf0P2AIcD3091V=0X0Sf@g102>HcH00`2?I3L0TFHi095V>@0208YO<P<0Rf0c
1@2<HC@0102=HSD0SV<f091U>02AIST2099W>P80Sf@g0`2@ICP3095V>@80Sf@g0P2@ICP4095V>@D0
UF`h0`2FKCT309Q^?080VFlm0`2JL3h809U`?080Ug8k00<0UW4l09E`?02DKSd00P2BK3d0102AJch0
Vg4o09]a?`2JL3h209U_?@0609Q^?02GKC/0Ufdk099]>@2CKSX0UG0l0P2FLCd00`2DKc/0TVdi095/
>00208iY=@80SfXf00L0T6/g095/>02AK3P0TVdi09=Y=`2EJcT0UV`j0080Ufdk00<0UV`j09E[>@2C
JCL00`2CKSX3099]>@80TF`h202EJcT2095[?0<0T6Xk0`2?JCX2095/=@03095/=`2AK3P0TF/j0080
TF/l00@0TF/n08iZ>P2=JCT0RfLg0P29ICD00`2:ISH0RfLg08aX>00208QV>080QfDg0P26I3H308ES
=@0Y08IO=P25GSD0Pehd081M<`1mG340Ne``07YK;`1gFRh0OELX07aG:P1kERT0N5HY07IE:P1dE2/0
LE@/071C:`1bDR`0JddW06M99@1UB2H0I4XY06=::`1MARH0FD8S058n9@1??R@0CS`T04Xj8`17>2<0
@cHS040e8@0o=280=cDP03Ld8@0e<Ql0=34P038_800`;200;b/P02hZ7`0`:B400P0]:B000`0/:B00
:BTO02PZ7`0202HY7P809RLO0P0U9Qh402@U7@P08B@M200P8a`2028U7004024T6`0P8aX082<J01lR
6@807R4H0`0R9A`3024T6`8082<J0`0Q91d2020S70<07b8K200L7Q/501`O60<07B0I0P0Q8Qd0300R
8ad08b@L02DW700V:1/09bTL02PZ700X9b<0:BPS02TY8@0Z:Qh0:b`L02`]6`80;BlI0P0`<Q`01P0^
;ad0;2dM02XZ7P0X:2009bHQ02HU8@808RPJ00<092PJ02HX6`0W9a/00P0Y9a/0100Z9Q/0<2dJ038_
700d<Ah203Hc800403@a7P0b;a`0<2dJ030]6P80>c<N0P0j<Qd0300i<A`0>30K03P`6`0g;aX0=b/K
03X^7P0n<R80@3@T044e9@0o<b<0?30P03X^7P80?cDL00H0?S@K03dc6P0o=A`0@CLN04@j8@16?2<2
04Hj800404Lk8@19?B<0BclU04a09P80CT8X0P1=AB002@1;@al0BT4P04Po8016?B00AC`O04Dk801;
?B80BC/P04Pj7`0204Li7P0304Pj7`19>b00BcdR0080AC/P00<0A3XO04<i7P12>1d00P11=a`01`10
=Q/0>cLL03Xf6`0j=Qd0>CDL03Pc7@0g<Qh00P0f<Ah00`0l=b40>cHP03Td7P0203Lb700303Td7P0k
=R00?3LQ0080@cLQ0P14>2801015>B<0ASXT04Hj9017>bD8044k8`04048l9P11>bD0?cTS03dg8@80
?3HP00<0?CLQ03hh8P0m=al01`0m=al303he600303lf6@10=aX0@CPK0080@CPK00@0?STL03lj7@0o
>Qd0?cXM0P10>ah2044l7`80?c/R0P10?2<4044m9080@CLN0`12>1l304<i800804@k7015?1d0ASdN
04Po8019@240Bd8S04a3901=A2D304Hm7P80AchO0`18?b0204E28@80AT4Q00<0B48R04Y18P1<@B<0
0P1>@2<00`17@2<0AChQ04<l7`02048k7P0304<l7`15?R40Ad0S00<0Ac`P00<0B3dQ04Tn8P1:?b<0
0P1:?b<0201:?b40C3hQ04e0801?@240DD4P05A1801E@Ah0ET8O0P1JAR4205]78P<0G4PS00H0GDTT
069<9`1RC2L0Hd/U06A;8`1WBb<206Q;8@0906Y;7`1XBal0JD`P06]>8P1/Cb<0KU4U071C9`1aE2P0
LUDY0080KELU00<0KUPV06mI9`1`FRP00P1aFbT01@1bG2X0L5HS075G901eFbP0MedZ00<0NEl/00<0
N5h[07EI:@1eFBT00`1eFBT407IJ:P<0METY00@0MUXZ07QL;01kGbl0O60`0P1lFc000`1jFbl0MeX^
07EJ;@02079J;003071J:`1eGc00MEl`00<0M5h_0`1cGBh00`1[E2P0K5DY06iG:`0206mH;00306iG
:`1/EBT0Je@X00D0ITlU0`1UCR@606A>9`80HddV0P1NB2<01`1MAb80G4HQ05]5801JA1l0FD<N05Q2
7@1L@RL00P1J@RH00`1H@bH0ET<U05A39@020593900805=5801BA1l0DD<N05537P1BA1l0E4HQ05I8
8`1GBB@30596800405=5801DA200E4@P05E37`80ET8O0P1C@al205A480@0EDDQ00@0DT8Q05=38P1C
@b80E4@S0P1EAB@205I69@80DT<T0`1A@R<305118P0<05M6:01D@bD0D3lQ04dl7P1<>ad0CC`N050o
8@1B@B<0Bd8U04Y19018?b80ASdP0P15?1l204Hm8080@S/O00@0@CXN040i7@0o>1`0?SLK0P0m=QX0
200o?1d0?S/L03hj7@0m>Ah0?3PO03/f800j=Al0>SDQ0P0c=Al0100b=1h0<C<M034c7@0`<Q`202la
6`<0;BlJ0P0/;QT302/]600802d`7@0[;Q/0:2/J02HX6P0U9aX09RPM02LY7P0X:B42028U70808B@K
00@082<J01lR6@0N8AP07R4H100M81T401hQ6PP06adJ0P0K7A`201XL6`@06A/J200F61L:01DF6080
51DG0P0C51H2018C5@P051DG4@0B4aD800lE5@P04ALG200E5QP801@E5a004ALG200B4aDh01@E5aP0
5AHH2@0E5aHJ01HH5`<05aTH0`0H6QT801TK60P061PH0P0H61H201TI5`806QXH4P0K6aT801`L6PP0
7QdH0`0L6aH201dL5`<07QdH200P81P2024P6`8081lJ0`0O7QT00`0N7AP081lJ020O6P06020O6PP0
7b0J0`0M7QP201`M5`<06a`F200M7QPA01`M5`P07AdK0`0N7AP00`0O7QT081lJ024P6`02024P6`@0
81lJ100O7QT0100M7AD07QhF024Q6@0T91`202DU7@0302@T700S8a/0:2@K0080:2@K0`0Y9A`202XV
7@0802PV6@0Y9aX0:bLK02hX700`:1d0<RPN03<Y7`0f:B02038V6P0403<W6`0d:1`0=RXN03L[7`80
>2`P0P0i;Ad0300h;1`0=b/K03HZ6P0e:AT0=2PH03<W5`0d;1l0<b/N034[7@0`:Q`0;BXK02/Y6P80
:2TI0P0/9QX302dW6`<0;RPL00@0;BLK02hX700^:1`0;RPL0P0_:Ad2030Z7PD0:RPK0`0[:A`202`U
7@<0:b@L0`0Z8a/00`0Y8QX0:R<K02/T700202dV7P0302/T700Z8a/0:B8J00<09RHN00<09BDM02@T
700S8a/00P0S8a/01P0R8a/08b<K02@T700V8a`0:2<M02XS7@80;2<N00P0;bPP02dV7P0[91`0:B8J
02PQ6@0Y8QX0:R<K02/T70T08b<K0`0Q8AL2028R60<08b<I200V8QT:028R6P<08b<K0`0T91`8028R
6P0402HR6@0W8aX09b<J02LS6P80:2@K0P0Y9A`202XT6080:bDI0`0/9QX902dW6`80:RHM0`0Y9A`3
02PT6`0602XT600[9AT0:bDI02dW6`0^:1`0;bTM0P0`:Qh302lY7@<0<2XN0P0a:al803<Y7@80;2TJ
00@0;BXK02h[700`;Ah0<BhO0P0b;b000`0j;R80>BdQ03L[7`0303HZ7P0303P/800i;B40>B`S00L0
>B`S00P0>RhN03T]7@0g:a/0=RXJ03L[6`0i;Ad0>blO03``8080>C4L00L0>30M03L^7@0f;Ah0=B/O
03@Z7P0c:Al0=BTI00<0=2PH00@0=BTI03L[6`0j;Qh0>blO0P0g<Qh203Pc7`80>C@P0`0j=B43044`
80<0@S4Q0P13<R80100o;Qh0@2lO040_7`10;al2044`8080@S4Q200o<a/203D_8`80=2hR0`0c;B40
0`0b;200=bXQ03LZ8@0203LZ8@80=RTP0P0e:1l803L]8@80<B/M0P0b;1h403<]7`80=RXN00<0=b/O
03P/800i;B400P0k;b<01P0l<2@0=bdQ03L]8@0h;R80>BlS03X`9080>c4U00@0?38V03P^8P0h;R80
>2hR:oooool002[ooooo0100V6hl09M]>`2GKC/0Ufdk09Q^?02JL3h0W79009id@P2FKS/0Ufll09Y`
?P2LL3l0WW0o09i^?P2LK3`0WFXk0`2LL3l00`2MLD00WW9109ib@@0209mc@PP0WG8o0P2MLd4209ab
@0@0Vg4o202LLT0309mc@P030:1d@`2QMD@0XGE40080XWI50`2TNTP20:=iA`80XWQ600L0XGM50:5e
AP2QMDH0XWI50:9gA02SN4D0XgQ30080Y7U22@2SN4D20:1d@`060:5eA02RMTD0XgM60:AhA`2UNDP0
YWY90`2SNDL20:AjB0<0YG]90P2RN4H0102QMdD0X7I409me@`2NM48209ec@@0609]eAP2JM4D0VWA5
09UcA02HLT<0Ug520P2FL440202AJc`0TV`m09=]?P2CKCh0TV`m091Z>`2>J3T0SFLh0P28HcH408MR
=@80QV4d00P0QF0f08AO=@23GS@0PE`b07mJ<01mF2h0O5L]07]F;0@0MU<[101gE2`02@1dE2/0Le</
079B:`1aDB/0L4l/06m>;@1^CBh0KD`]06a>;00206]=:`0306Y<:P1YBbT0IdTW0080ITPV00D0J4XV
06U;9`1YBbL0JT`X06a>:P0206e?:`0506i@;01dDBT0ME8Z07MD;01iERh00P1jEbl04`1iERh0N5D]
07iI;`1oFS00P5/a089M<`24GcD0QV4g08MR>028HcT0Qf0e08QQ=P2;ICP0SFLh08mY>02?JSH0SVTe
08iY=02EJSl00P2EJSd00`2EJc/0UF/i09E/>00209E/=PP0SF`g0P2EJcT309AZ>0<0TfTg0`2AIcD2
091V=0<0SfDc2@2?I3L0102=HSD0SV<f08mT=`2?I3L4091U>0@0S64d102;H3<01@2<HC@0SF8e08eR
=@2>HcH0T6Dh0080TFHi00<0TVLj08mT=`2?I3L00`2@ICP3095V>@80Sf@g0P2@ICP3095V>@03099W
>P2EK3P0UF`h0080UF`h102FKCT309Q^?080VFlm0`2JL3h809U`?080V7<l00H0Ug8m09Ia?@2EKch0
U6ho09=]?P2BK3l309Y`?P0309U_?@2HKS`0V6hl0080Ufdk00L0Tfhj09A_>`2EL3`0UW4m09E`?02D
Kc/0TVdi00<0TF`h00<0TVdi09=^>P2CKSX00P2DKc/0102EL3`0TfTg09E[>@2FK3X209M]>`0309I/
>P2EJcT0TfTg00<0Tfhj0`2BKCT2095/>0P0UF/i0P2AJc`3091Z>`<0SfTj0P2AK3D00`2AK3L0TF`h
095[>P02095[?004095[?P2>JSX0SFTi08]W=`<0RFDe00P0RVHf08]W=`29IcT0RFLi08QV>027ICL0
QV@f08ES=@<0Q68d0P25GSD01P23GS@0P5dc07eL<@1kG300NU/_07MJ;P80O5LZ01l0NELZ07MF:`1d
E2/0Le</071C:`1`DR`0Ke4[06]=:@1UBB@0HdTV06=;:@1QBRX0GDHW05I18P1@?bD0CchT04`l8`19
>R<0ACTS048e8P10=B40?c@R03Pf8@0g=240=C8O03<`7`0a;Ql0;b/O02hZ7`0]:Ah0;bPP0080;BTP
00<0;2TP02TY7`0X:Ql00P0V:Ah202HW7`809BHN0`0T9Ad00`0S91`08B@M024T7@06024T7@P082<L
0`0Q91/3020S6P807b8I0`0R9A`3024T6`8082<J0P0Q91d3020S70<07b8K200L7Q/301`O60D07B0I
00H0824L024R700R8ad08b@L02@V6`0V:1/202LY6`0A02TX8`0Y:B40:RXP02XZ7P0[;1`0;2dK02`^
6@0];aT0;S0J02h`6`0];Q`0:b`L02TY7@0X:1h09RHN02HU800S:A/00P0U:A/01@0W:A`0:2PL02/Y
7@0/:1d0;BTN0080<RlL00@0<c0M03@a7P0d<Ah0<c0M0`0b;a`303/c7P0303Xb7@0i<A`0>C4L0080
>30K00<0>2`L03/_7`0n<R800P11=BD01@0o<b<0?C4Q03/_7`10=Qd0?cDL0080?S@K00X0?cDL048h
7`14>R40AC/R04Di7`16>R00Ac/Q04Tm8`1:?R@0C40V0P1=@BL02`1<A1l0C4@P04]37`19@1l0B3lP
04Hm8015>b00A3XO04Tk8018>Ql0AcTN0080ASPM00D0AcTN04Pj7`19>b00@c`R048k8@02044j8004
040i7`0o>1h0?SLM03hg7@80>SHK00T0>CDL03Td7P0h<al0=c8O03Ha7P0f<200>cHP03Xe7`0h<ad0
0P0g<Q`00`0h<ad0>SDO03/f8002048f8080@cLQ00@0A3PR04Di8`15>B<0ACTS200o>B402010>R@0
?cTS03dg8@0l=R00>cDO03`f800m=b40?SPR200l=Qh203`e6@80?CHJ0P0n=a/203lh7080?CLM0P0n
>1h303li7`04040j800o>b80?c/R03lk8PD0?SXQ0P0o>1h2040i7`@0@CXP00P0?cPK040i7011>Qd0
@S/N04@m8015?R40ASlR04M08`<0A3dP0P15?R4304Ho8P80@ChO00X0@SlP04<n8014?B00AchQ04Pm
8@19?R80BcdR04Dn8@14?B00@c`O0P11>Qd00`13?1l0A3dP04Dn8@0204Hk7`80Ac`P00<0B3dQ04Tn
8P19?R800P19?R801`19?R00C3hQ04ho801@@1l0Dd0O05=17@1E@Ah00P1JAR<305]790<0G4PU00H0
H4`W069<9`1RC2D0Hd`S06E<8`1WBb<206Q;8@0506Q=801YCR40JTlR06]@8`1/DB@00P1^DbH01`1_
E2L0K5HU06eG9P1]EbH0KUPW06mI:01`FRT00P1aFbX0101_EB80LELT07AJ9`1fG2T407QN:`<0Me/[
1`1fFRX207EI:@0407IJ:P1hG2`0NUh^07aP<080NeX_00<0NU/_07QK;`1fFbh00P1dG2h00`1bG2d0
M5h_07AN;`0207=M;P<0LU`]00@0LE//06]D:01/EBT0KUL[0P1_F2`00`1^Eb/0K5DY06]D:00306M@
9P80ITlU0P1UCR@00`1TCB<0I4hW06A>9`0406==9P80HT`U00H0H4XU05m9901NB2<0GDLR05a68@1K
AB0205Y47`0805a39@1KA2D0FT<T05Q3901F@b<0E4@S05=48`1B@b8205=5800605947`1A@ah0DT@O
05=5801EAb80EdTT0`1CAb40101DAR40EDDQ05E58@1GAB4205M38080Dd<O0P1DA20305E58@0305I6
8P1C@b80Dd<R0080E4@S0P1EAB@205I69@<0DT<T0P1A@R<305118P0305I7:01CA2D0D44R0080C3dN
00L0CChO04m08@1A@R<0Bd8U04U08`17?R40AC`O0080A3/N00L0AC`O04Hm8012>al0@S/O044j7P10
>Ad0?cPL0080?SLK00T0?CHJ03ll7@0n>a`0?SXM03di7P0l>1l0>cHP03Xe7`0j=B400P0c=Al0100b
=1h0<C<M034c7@0`<Q`202la6`<0;BlJ0`0/;QT202/]600902/^6`0Z;AX0:2/J02HX6P0U9aX09BLL
02HX7@0V9al08bHM00808RDL00<08B@K020S6P0O8QT00P0N8AP401dP6@@07R4J200K7AX201/M7080
6Q`K0`0I6aX00`0H6QT05QPG01HH5`0601HH5`X05AHH0P0D5AL201<D5P804Q<E200D5ALA018C5@P0
3aDE200A5aL801DF60P051DG400A5aL8018C5CP051DG600E5QP901DG5QX05QPG0`0G6AP301PJ6@P0
6A/H200H61P201PH5P806ATG0P0J6QPB01/K6@P071`J200N7AP201`K5P<07A`G0`0N7AP8020P6080
8B0K0P0P7aX401lN6@P081lJ200O81X301dN60<071dG0P0K71H801dN614071dG200M7A/201hM6080
7ahI0P0P7aX2024P6`D081lJ0`0O7QT0100M7AD07alG024Q6@0S8a/302@T700402<S6`0X91/0:2@K
02PT6`<0:BDL0P0Z9Qd202TW6P0302/W6`0^:1`0<2PM0080<RPN00@0=2LN03<W6`0c9a/0=2PL0P0e
:Ad00`0f:Qh0=b/O03L[7`0203T]7@0403P/700g:a/0=RXJ03DY6@80=2PH00P0=2XN03<[7P0b:Qd0
<B/M02h[700/:Q/0:R/K02TZ6P@0;RPL100]9a/402hX7080;bTM0P0`:Qh402XX6`@0:bTL0P0/9Ad3
02/T70<0:R<K00<0:B8J02XS6`0[91`00P0]9Qh00`0[91`0:R<K02TR6P0202HV7P809BDM0P0T91`2
02<S6`06028S6`0S8a/092@L02HS700X8ad0:R<M0P0/8ah00`0^9al0;BHN02/T700302TR6P0302XS
6`0[91`08b<K00P08b<K0P0Q8AL3028R60<08b<I200V8QT:028R6P<08b<K0`0T91`8028R6P@09b<J
0P0X91/202TU7080:bDI0P0/9QX202dW6`X0;RPL0`0Z9Qd202TU70<0:2@K00H0:R@H02/U6@0/9QX0
;BLK02hX700_:Ad2030Z7P<0;bTM0`0`:Qh2034[7`P0<bTM0P0]:Q/0100^:a`0;b`M030]7P0`;Ah2
034^7`0303X^8P0i;B40=b/O0080=RXN00<0=b/O03P/800i;B40200i;B400`0j;Qh0>BdM03L[6`02
03L[6`0=03T]7@0k;al0?30P03/c7P0j<Qd0>C4N03P_7P0g;Ql0=R`P03D[7`0e:b40=RXJ03DY6@02
03@X600403DY6@0h;1`0>RhN03/_7`80>34N0P0i<Ql203Xc80<0>c@Q0`11<203048a8@80@c8R1010
;al2044`8080@S4Q2011=Ad303H^8@80=BdP0`0d;1l203HZ7PH0=b/O200d:Qh2034[7@80<R`N0`0c
;Al02@0d;R00=RXN03HZ7P0g:al0>2`P03T]8@0j;R80>blS03``900203L]8@0403P^8P0i;b<0>S0T
03X`9080>c4U0`0h;R8[ooooo`00:_ooool209Q^?080Ufdk00`0V6hl09Y`?P2KLCl0WG=109I^>`2G
Kc`0VW0n09a`?`2NL3l0WVhn09a/?02MJS/309]_?P<0W70o0P2MLD0809eb?`<0WG=10P2LLT0309]a
?`0309ab@02MLd40WG=100D0WG=10P2OLd830:1d@`<0XGE400@0XGM50:9hAP2RN4H0XWQ60`2SNDL0
102TNTP0XGE60:5eAP2RMTD20:9gA0030:=h@`2SN440XgQ100T0XgQ500H0X7A30:5eA02QMD@0XWI5
0:=gAP2TN4L20:EiB0040:9hAP2SNDL0XgU70:=iA`80Y7Y80P2UNdT01P2VO4X0YG]90:AjB02RN4H0
X7I409me@`80WG=10P2JM4D0102ILd@0V79309Ma@P2GLD8209I`@@08095[?02BK3d0Tfdn09=]?P2B
K3d0T6Xk08iX>@2<ISL208QS=P80Qf8e0`26HC@01P25H3<0PUdc089M<`21G380P5/a07mJ<080OUT_
00<0OEP^07MD;01gE2`01P1gE2`01P1bDRT0LU8[075A:P1aDB/0L4l/071?;P80Kdh_00D0KU0^06e?
;@1/CR`0Jdd[06Y<:P0306U;:@80JD/W00<0JT`X06]=:@1/CRX00P1]Cb/01@1^D2`0M54Y07EB:P1g
E2`0NEH^0080NUL_0P1iERh01P22GC<0Pehd08=N=024GcD0QF0f08IQ=`80Qf8h00T0Qf0e08QQ=P2;
ICP0SFLh08mY>02?JSH0SVTe08iY=02DJCh00P2DJC`00`2DJSX0U6Xh09A[=`0209A[=@P0Sf/g00@0
UF/i09AZ>02DJSP0U6Xh0P2CJCL2099X=P<0T6Hd0P2?IC<308iT<PT0Sf@g00<0Rf0c08eR=@2@ICP0
0P2BIcX00`2AIST0Sf@g08eR=@0208iS=P0408eR=@2<HC@0Rf0c08]P<`80RUlb0P2=HSD0102>HcH0
Sf@g08mT=`2@ICP2095V>@80Sf@g0`2@ICP3095V>@<0T6Dh0P2AIST3099W>P0309A[=`2EK3P0UF`h
0080UVdi0`2GKSX309Q^?080VFlm0`2JL3h809Ya?@80VG@m00<0V7<n09Mb?P2FL3l00P2EKd000`2D
KT40VW0n09U_?@0209U_?@<0V6hl00T0Ufdk09A_>`2EL3`0UG0l09Ia?@2EL3`0U6lk099]>@2AK3P0
0P2DKc/209E`?0@0UW4m00<0TfTg09E[>@2FK3X00P2GKC/00`2FK3X0UF/i09=Y=`0309=^>P<0TVdi
0P2AK3P809E[>@80TF/l0`2@JS/308mY>P80T6/d00<0T6/f091[=`2@JST00P2@JS/03`2@JSd0SFTi
08aX>02:ISH0RFDe08QT=029ICD0RVHf08]W=`2;JC/0RVPj08UW>@27ICL0QF<e08=Q<`02089P<P0?
085O<@25GSD0QEhe08=N=01oG380OE`a07YK;`1iFRh0MeX^07aG:P1jF2/0NELZ07IE:P1dE2/0L5<[
0080KU8[01T0KDl[06Q<9`1TAbD0HDLV0658:@1OB2T0FD@U05E08`1??R@0CCdS04`l8`18>B80A3PR
044f8P0m=B00?3@Q03Tg8P0g=240=S<P03<`7`0`;Ah0;RXN02`X7@0[9a`0;bPP0080;BTP00<0:bPO
02TY7`0W:Ah00P0V:Ah302DV7P8092DM0`0S91`8024T7@P082<L100P8aX3024T6`@08RDL0`0Q91/2
020S6P04024T7@0P8a`082<L020S70807b8K0P0N8AX801`N6`8071lH0P0M81T201hQ6P807b8K0P0P
8A/01`0Q8QX08R@I02@V6@0U9aT09RTH02LZ6@0Z:R800P0Z:R000`0[:al0:b`N02//700302`]6`0B
02//6P0Z:a/0:BXL02PX700V9Q`09BDK02DU7@0U:AX09RXK02PZ700Z:ad0;B/N030/800a;B40<bdQ
03Lb7`0f<Ah0=C0M0P0d;a`0100e<1d0=S4N03Lb7`0g<Ql403/c7P80>S8M0P0i<A`00`0j;ad0?34O
03ld8P02044f9003040e8`0n<b40?34O00@0@3HM00@0@CLN048h7`14>R40AC/R0P15>Al03016>R00
B3`R04Tm8`1:?R@0BclU04a09P1;@al0BT8N04U07`18?b00AchQ04Dk8080A3XQ00<0ACTO04@h7P12
=Q`00P11=A/00`12=Q`0A3PN04Di7`02044j8080@3TO00X0?cPN03hg7@0m=Q`0?CHL03Xf7@0i=A`0
>C@N03Pc7`0g<Qh0=S4N0P0e;al203Td800403Pc7`0g<Qh0=c8N03Pc7`80>C@P1010=B42044f8P80
@SLS200l=b40200k=R80>SDQ03Td800h<al0>C@P03Xe8@0l=b<0?CPT200k=R0303`e6`<0?CHL0P0n
=ad203Xf6`80>cLL0`0l>1d00`0m>Ah0?CPR03dh8P0203`g8@0403/f800j=Al0>C@N03Td7P<0?CDP
0`0n=R4203lg8P80>S<G00D0>c@H03df6P0n=a/0?cPL040i7@04044j7P80@S/O0`13?20203Xi6`05
03/j700m>A`0?STL040i7@12>1d00P14>1h00`13?200@S/O044j7P02040i7@03044j7P12>al0@c`P
00<0A3XO0P15>b0404Hl8@80B3dQ00<0BcdP04dn7`1??ah00P1B?ah205Q68P80FDLS0`1JB2@01P1K
BBD0Gd/X05m;:01QBbH0Hd/U06A;8`80Id/S00<0J4/Q06U>8`1YCR<00P1ZCb@206]@9@80K54V0P1[
EBH00`1/ERL0KELX06iH:@0206mI:P07071J:`1_EB@0L5HU07=I:01eFbX0MU`[07MM;00207IL:`<0
NEd]00L0N5`/07MK:`1fFRX0MUXZ07EI:@1gFb/0MUXZ0080METY00@0MUXZ07QL;01jGRh0Nel_0P1j
FBh00`1jFbl0N5/_07ML;`0207IN<00307EO<01bG2d0LU`]0080LE//0`1`FR/0101_FBX0Je@X06aE
:@1^Eb/206mH;00406iG:`1/EBT0Je@X06YC:@80JE8X00D0Ie0V06I?9@1UCR@0I4dS06=<8P0306==
9P80HT`U0P1QBb@01@1PBR<0HD/V065;9P1PBRD0GdTT0080GTPS0P1MAb801P1MA2H0Fd@U05]49@1I
A2D0Ed@T05E59080Dd@S00P0E4HQ05=5801BA1l0DD<N05947`1CAB00EDLR05I88`<0E4PR00@0EDLR
05I68P1FAR80F4HR0P1IAB8305A48080EDDQ0`1FAR8305A48`<0EDDT0P1FARD0101CA2D0DT<T0593
901B@b@205528`80D44R00<0ETLX05=49@1@@B800`1=?Ql01`1?@240DD8S04Y19018?b80ASdP04@k
7P13>Qd00P14>ah00`15?1l0@S/O048k7`02044j7P0<040i7@0o>1`0?SLK03hg6`0o?1d0?S/L03hj
7@0m>Ah0?3PO03/f800j=Al0>SDQ0P0c=Al0100b=1h0<C<M034c7@0`<Q`202la6`80;S0K0P0];aX3
02`^6@0602/]600Z;AX0:2/H02LZ6@0U9aT092HI0P0T9Q/01P0U9Qh08bHM02<V7@0R9A`08B@K020S
6P807b8I00<07R4H01hQ6P0N8AX00P0N8AX401dP6@P06Q`I0`0J71/201TK6P<061XI200F61L:01DF
608051DG0P0C51H2018C5@P051DG4@0B4aD800lE5@P04ALG400D5AL@014G5`P04a@F>00D5ALH01DF
60T05ALF6P0F61L301LI60<061XI200I6aP801TI6@8061PF0P0I6AL201XJ61806a/I200L71X801hM
600401`K5P0M71L07A`G01dL5`807QdH0P0O7QT8020P60<08B0K0P0P7aX301lN6@P081lJ200O81X2
01hO6@807AhH0`0L7AL00`0K71H07AhH01dN600G01dN60P07AdK00@07QdH01lN6@0O7QT07ahI0`0P
7aX00`0Q81/081lJ020O6P06020O6P0401hN5P0P81P08B4I02<S6`8092@L0P0S8a/302PT6`<0:BDL
0P0Z9Qd202/Y700302`X700^:1`0;bLL0080<2HL00<0<RDL03DY7@0e:Ad01P0e:Ad203T]7@0403P/
700g:a/0=RXJ03HZ6P80=BTI00P0=BTM03<Y7@0c:Ad0<RXM034[7@0_;1d0;R`M02d[7080<2XN00@0
;bTM02hX700]9a/0;BLK0P0/9QX302hX7080;bTM0`0`:Qh802`X7080;2DM0`0[91`302XS6`0302TR
6P0Z8a/0:b@L0080;BHN00@0:b@L02XS6`0Y8QX09RHN0`0U9Ad302@T700702<S6`0R8a/08b<K02@T
700V8a`0:2<M02XS7@0202`S7P0502dV7P0/9Ad0:b@L02XS6`0Y8QX00P0Z8a/00`0[91`08b<K02<S
6`0702<S6`04024Q5`0R8QP08R8H028R60808b<I0P0T91X802LS6PP08b<K0P0R8QX302<S6`<092@L
200S8a/302LS6P80:2@K0`0Y9A`302dW6`80;RPL2`0_:Ad0100[9ah0:RHM02XV7@0Z9Qd202TU7080
:2@K0P0[9AT00`0/9QX0;BLK02hX700202lY7@04030Z7P0_:Ad0;bTM02lY7@<0<2XN0P0a:al803@Z
7P<0<B/M1@0b;1h00`0j;R80>BdQ03L[7`0203HZ7P0303L[7`0i;B40>RhR00P0>BdQ0P0i;Ad303P/
700303T]7@0k;al0?30P0080?S<O00P0?C8P03``800k;b40>blS03X^8P0j;B@0=b/K03HZ6P80=BTI
00@0=RXJ03P/700j;Qh0>blO0P0i<Ah203Xb7`80>c<P0`0l=243044`80<0@S4Q0P13<R83040_7`80
@C0P0`12<B48048f7P<0>2hR0P0g;B4303H/800503DY7@0f:Qh0=RXN03L[7`0h;2000P0i;B400`0j
;R80<RPL038X7006038X70<0<R`N0P0c;Al303@^800603HZ7P0g:al0=b/O03P/800i;B40>RhR0P0k
;b<01P0f;200=bdQ03L]8@0h;R80>BlS03X`9080>c4U0`0h;R8[ooooo`00:_ooool409Q^?00<09U_
?@2JL3h0Vg4o09]a?`2FKS/0Ufll09Y`?P2LL3l0WW0o09i^?P2LK3`0WFXk0`2JKSd509]_?PP0WG8o
0P2NM48209ec@@80W7900P2KLCl409ec@@@0WWA21P2PM4<20:5eA080WgE300@0X7I40:5gA@2SNDL0
Y7Y80P2UNdT20:5eAP040:9fA@2RMd@0XWM40:9g@P80XWM02@2SN4D20:5eA080XWI500@0XgM60:Ah
A`2TN4L0Y7Q70P2RN4H30:=iA`<0Y7Y800P0Z7i<0:MmB`2VO4X0XgU70:5gA@2OMD<0WG=109ab@080
VWA500@0VG=409Qb@`2GLD80UW110P2EKd00202AJc`0TV`m09=]?P2BK3d0TF/l08mY>P2<ISL0RfDf
0P28HcH208MR=@0408IQ=025H3<0QF0c08AO<PD0P5/a0`1oFS0307QE;@@0Me@/00L0MU<[075A:01a
DBX0LE4Z075A:`1`Cb`0L4l^0080L4l`00<0Ke4_06i@;P1]Cbd00`1[CB/206a>;080JT`X0P1[CBT0
201/CRX0KDl[06e?:`1]Cb/0Le0X07EB:P1gE2`0NUL_0`1kF3000`1jEbl0QF0f08EP=P0208IQ=`<0
Qf8h00X0R6<i08MP=@28HCH0RfDh08eW>02?JCP0SfXf08iY=@2>JC@0TfPm0P2CJ3/00`2CJCT0TfTg
09=Z=P0209=Z=0P0T6/g0`2DJSP209=Y=`<0TVPf0`2?IC<308iT<P80SF<a2@2?I3L00`29GS40S64d
091U>00209AY?009099W>P2>HcH0Rf0c091U>02?I3L0SV<f08eR=@2<HC@0RUlb0080REha00<0SF8e
08iS=P2>HcH00P2?I3L2091U>003095V>@2?I3L0Sf@g00<0T6Dh0`2AIST2091U>0<0TFHi0`2BIcX0
102DJcL0UF`h09E/>02FKCT209M^>P80V6lk0`2HKS`209U_?@<0VW0n202JLCd209Ud?@0609Ud?`2H
Lcl0Ug5009Ma@P2FL440UW13202HKS`309Ia?@80UG0l00<0U6lk09=^>P2BKCT0202DKc/00`2CJCL0
UF/i09I/>P0209M]>`0309I/>P2EJcT0TfTg00<0Tfhj0`2BKCT2095/>0P0UF/i0P2AJc`3091Z>`<0
SfTj0P2@Jc@00`2@JcH0T6/g091Z>@02091Z>`04091Z?@2=JCT0S6Ph08YV=P80R6@d00T0RFDe08YV
=P2;IcL0RfTk08YX>P29IcT0QfDg08AR=022H3800P21Gc40;`20GS00QEhe08AM=022GC<0Oe`b07aK
<01jFbl0NEX^07II;@1jF2/0N5L/07MF:`1dE2/0LE@/06iB:`1[DB`0JU0[06]>;01TBRL0H4HU05i5
9P1OB2T0G4LZ05I39@1B?R<0CCdS04/m8P1:?280ACTQ048g8@0n=R40>cDO03Xc800h=R40=c@Q03Db
7`0b;ah0;b`M02`X700Z9Q/0:BDJ02lX800]:B00;2PO02/X7`0X:1h09bTN00809BPM0P0U9Qh302@U
7@<08b@L400P8a`201lR6@04020S6P0Q91/08B@K028U70808bHM0`0R9A`3024T6`8082<J0`0P8a`2
01lR6`<07R4J200L7Q/0100L7aP07B0I01dP6@0N8AX201lR6`8082<L0P0P8AT01P0Q8aP08bDH02@V
600V:AP09bXI02LZ5`<0:b/O0`0[;1h202X[6`0602TZ6P0X:AT0:2TK02LX6P0V9aT09RHJ0P0U9AT0
2`0W:QT0:2/J02X[6`0^;1d0<BhO03D_8@0f<280>30S03Xc8@0h<Al0=RlM0080=2dK00@0=RlM03Pa
7`0j<b40>S<Q0`0l=1l503/c7P0303`a7@0n<al0@3DQ0080@SLS00<0@CHR040e8@0n<al00`11=ah2
048h7`0404<i8014>R40A3XQ04@h7P80ACTO00X0ASXP04Pl8P19?B<0BCdS04Xn9019@1l0B3lN04Po
8017?R40AC/P0P14>R401013>280@SPO044g7P0o=A`203hd6`0303le7011=ah0@SPO0080?cTQ00<0
?SPP03dg7`0l=Qh00P0k=Ad01`0j=1`0>CDL03Td7P0h<al0=c8N03Ha7P0e;al00P0d;R0303Lb7`80
=S4N0`0g<Ql803`d8@P0=cDP00P0=C8O03@a7P0c<1d0<c0M03@a7P0f<b00>3DR03Tf8`P0=cDP1P0j
=1h203/e7`0403Dc6P0f=1/0=S@K03Hd6`80=cDL0P0h=Qd203/f8P0703Xe8@0i=200=c8N03Ha7@0e
<1`0=2lK03D^6`0303H_7080=c0M0P0h<Ah203@^5P0403D_5`0f<1P0=c4I03Pb6P<0>C<K0`0j=1`2
03/e7@80?3HN0P0e=A/203Hd6`0303Te700j=1`0?3@M0080?S<M0P10>Al403lh7PD0@3TO1@11>R00
1P12>al0A3XO04Dl7`17?200BS`O04`m7P80CShM0P1DA28305E58`<0ETHT00P0FdPW05a9:01MBBH0
H4XU069:901SBR80I4/R06I:8PP0IdhU0P1YDb@0101ZE2D0JeDV06aF9`1]EbP206iH:@0506mD9@1`
EBH0LEHW079G:01cF2T00P1dFBX02@1eFR/0Nel_07YN;P1jGRh0NEd]07QL;01gFb/0MUXZ07EI:@02
07MK:`0607IJ:P1eFBT0MUXZ07MK:`1iGBd0Nel_0P1iF2d00`1iFRh0N5/_07QM<00207MO<@0407MQ
<P1`FR/0L5X[071J:`80KeTZ0`1^F2T00`1[E2P0K5DY06iG:`0206mH;00;06iG:`1/EBT0Je@X06aE
:`1[E2X0JU<Y06QA9`1WD2H0IDhT06A=8`1SC2800P1SCBH2069<9@04065;901PBR<0GdTR05m98P<0
HT`W00<0HD/V061:9@1PBRD00P1OBB@01P1MA2D0G4DU05a59@1JARD0F4DT05I69080E4HS00T0EDLR
05A68@1BA1l0DD<N05947`1CAB00E4HQ05E78P1DB2800P1EBB<0101FB2<0EdLS05M78`1JB2@205]7
9080E4@P0`1EAB4305I68PH0EDDT0P1FARD205=49@<0DT<T0`1A@R<0101DAbL0DTDU05138`1>@B42
04e0800604i18@1?@R80BT4T04Po8P16?B00A3/N0P13>Qd02014>ah0AC`O04<l8013?200@S/O044j
7P10>Ad0?cPL0P0n=a/0200o?1d0?S/L03hj7@0m>Ah0?3PO03/f800j=Al0>SDQ0P0c=Al0100b=1h0
<C<M034c7@0`<Q`202la6`<0;S0K0P0];aX302`^6@0802P[600W:QL09RTH02DW6@0T9QT092HK02<U
6P0S91`202<V7@04028U700Q91/08B@K020S6P807b8I100N8AX401dP6@P06Q`I0P0J71/301TK6P<0
61XI200F61L:01DF608051DG0P0C51H2018C5@P051DG4@0B4aD800lE5@P04ALG400D5AL@014G5`P0
4a@F>00D5ALH01DF60T05ALF6P0F61L301LI60<061XI200I6aP801TI6@8061PF0P0I6AL201XJ6180
6a/I200L71X801hM60<07A`G0P0N7AP301lN6@P08B4I0P0R8A`2024P6`8081lJ0P0O7QT8024P6`P0
7b0J0`0N7aT201dN60<071dG6@0M7QP801dM6`@07ahI200P7aX4024P6`80820H00<08B4I028R6P0S
8a/00`0S8a/302PT6`<0:BDL0P0Z9Qd01@0/:Qd0:bTL02`X700^:1`0;RHK0080;bDK00@0<2<J03HZ
7P0f:Qh0=RXN0P0e:Ad303@X7080>BdM0P0h;1`0100g:a/0=RXJ03HZ6P0f:QX203HZ7P80=2XN00X0
<b/N038/7P0`;Ah0<2dN038/800a:al0<2XN02lY7@0^:1`0;2HJ0P0[9AT202hX7080;bTM0P0`:Qh2
034[7`<0;bTM100^:1`00`0]9a/0;2DM02`U7@0302/T70<0:R<K00<0:B8J02XS6`0[91`00P0]9Qh0
0`0[91`0:R<K02TR6P0402DU7@@092@L00H08R<K02<S6`0T91`09R<L02PS7@0Z8ad202`S7P0302`U
7@0[91`0:b@L00<0:R<K0P0[91`902<S6`<08R8H0P0S8aT302@T6PP09b<J200S8a/2028R6P<08b<K
0`0T91`802<S6`809b<J0P0X91/202TU7080:RHM0`0^:1`202lY7@/0<2XN0P0[9ah302XV7@<0:BDL
0`0/9QX00`0]9a/0;RPL02hX700502lY7@<0<2XN0P0a:al803@Z7P<0=2`O0P0c:ah3038Z7@80>BdQ
0`0g:al00`0h;200>RhR03/_8`0803X^80@0>BdM0P0j;Qh203/_7`80@3<P00H0@3<R03lb8P0n<2<0
?S0U03d_900m;bH203P/700603L[6`0f:QX0=b/K03P/700j;Qh0?30P0P0i<Ah203Xb7`80>c<P0`0l
=243044`80<0@S4Q0P13<R82040_7`80@C0P0P12<B4204<b8PP0@cLO0P0j<B8203T`8@<0>2lP00T0
=bhO03DY6`0e:A/0=RXL03P/7P0i;Al0>RhP03/_8@0l<280200e:al2038/7P<0<bdO0`0d;R0203L[
7`80>2`P00@0>BdQ03X^8P0j;R80>RhR0P0f;2000`0g;B40>2hR03T_8`0203X`900403/a9@0h;R80
>2hR03P^8R_ooooo000Zooooo`80V6hl0P2IKcd309Y`?P0909U_?@2FKS/0Ufll09Y`?P2LL3l0WW0o
09i^?P2LK3`0WFXk00D0Vfln0`2JKSd809eb?`<0WWA20P2MLd4309ab@080WG=10P2NM48209me@`80
X7I40P2QMD@60:1d@`80WWA200@0WgE30:5gA@2RN4H0Y7Y80P2UNdT20:9fA`040:5eA02QMT<0XGI3
0:5f@@80XGHo2@2SN4D30:9fA@@0XgM600@0Y7Q70:9hAP2RN4H0XWQ60`2SNDL20:AjB0080:QnC02W
OD/0YWa:0:=iA`2QMdD0WgE309ec@@2LLT0209UcA00409Qb@`2GLD80Ug5209I`@@80UFm00P2BK3d0
302CKCh0TV`m091Z>`2>J3T0RfDf08YT=@29I3L0R6<f08MR=@26HC@0QF0c08AO<P80Peha2020Fc43
07UF;P0307QE;@1gE2`0Me@/0080MU<[00H0LE4X075A:P1aDBX0LE4[071?;01`Cbh2071?<009071B
<01^D2h0K4h/06]=:`1ZC2X0Jdd[06e?;@1^D2h0JddY00@0K4hZ0`1]Cb/0101cD2P0ME8Z07MD;01j
Ebl307aI<@0407]H<025H3H0QV4g08IQ=`80Qf8h0`28HcT02@27H3D0R64f08]U>02=IcP0SfTh08mZ
=P2>JCD0SVTd099W?002099W>P03099X>02BJ3H0TVTe0080TVTc202BJSL209AZ>080TfTg0P2BJ3H2
095W=@80T6Hd0P2?IC<308iT<P0308eS<@2?I3L0Sf@g00L0Sf@g00<0REha08aQ=02@ICP00P2DJC`0
0`2BIcX0SV<f08]P<`02091U>00608mT=`2=HSD0S64d08]P<`2:Gc80REha0P2>HcH408mT=`80T6Dh
0P2?I3L3091U>0H0TFHi0`2BIcX209=X>`80U6/g00H0UF`h09I]>@2GKSX0V6lk09U`?02JLCd309Q^
?080VFlm0`2JL3h809]b?P0509Ud?@2HLc`0V7<n09Qc?`2HLT400P2GLD800`2GLD@0Ufdk09M]>`02
09M]>`@0V6hl0P2HLcl00`2FLCd0UG0l09A_>`0309=^>P@0TF`h102@JcL00`2CJCL0UF/i09I/>P02
09M]>`0309I/>P2EJcT0TfTg00<0Tfhj0`2BKCT2095/>0P0UF/i0P2AJc`3091Z>`<0SfTj0P2@Jc@0
0`2@JcH0T6/g091Z>@02091Z>`0?091Z?@2=JCT0RfLg08UU=@28I3@0Qf<c08QT=029ICD0RVHf08]Y
>`2:J3X0R6Hh08IT=P24HS@0PV0b0080P5h`02X0Oed_08AM=024GC@0PUdc07iK<@1lFc00NEX^07QI
;@1fFBd0NEP]07MG;P1fERd0LUD]06iB:`1[DB`0J50/06M?:`1WCB`0HTXX05e49@1KA2D0FdHY05U5
:P1C@RH0CSdS04/m8P18?B40Ac/Q04<i800o=b00?3HP03Td7P0h<al0=S@O03Db7`0d<Ah0<BhM02h[
700/:1`0:RHK02TU6P0^9al202`X7`0302XW7P0X:1h09RPM00809BPM0`0T9Ad302<T70808R<K400P
8a`01@0O8QT082<J020S6P0Q91/08RDL00808bHM00@092LN028U700R9A`08RDL0`0Q91/2020S6P80
82<L0P0O8Q/201hQ6P807B0I200L7Q/01P0L7aP07B0I01hQ6P0O8Q/082<L024T7@808RDN00h08B<H
028T6@0S9AP092HH02HY600W:QL0:2/H02T/5`0];Qh0;2dM02`]7`0[;1h0:R/M02XZ7P80:BTM0P0W
9a/0100V9QX09RLI02HW6@0V9aT202HW5`0;02X[6@0[;1X0;RdK034^7@0d;Qh0=c0P03Pa8@0j<B80
>c8Q03T`7`0g;Qd00P0e;1/0100g;Qd0>C0O03/b8@0k<R4603`d7`80?CDP00H0?S<M03ld7P11=R00
@SLQ04<h8P12=b42044f8080@SPO00<0@cTP04@j8@14>R400`14>R401@13=ad0A3PN04@h7P15>Al0
ASXP0080Ac/Q00H0B3`R04Ln7`16?Ah0ASdP04Dk8014>R4204<h8P04048g8`0o=b00?SHO03`d7@80
>c<L00@0?3@M03hf7`0o=b00?CPR0P0l=b400`0k=R00>SDO03Td7P0303Pc7@0503Pc7`0g<Qh0=S4N
03D_7`0d;R000P0c;B4303D_7`80=S0P0`0e;al803Pa7PP0<c8M00P0<C0N030_7@0`;ad0;bhL030_
7@0b<Al0=3<Q03He8`P0<c8M0`0g<Ql503Ha7P<0<S8J0P0c<a/303@d700803Td800h<al0=c8N03Ha
7@0e<1`0=2lK03<^6P0b;AT302hX6080;bTI0`0`:QX2030[5`80<B`H00D0<RdI03<^6P0c;QX0=2lK
034/6003038]6@80<bhJ0P0d;a/2030b7080<S4L00<0=38M03Ha7@0h<Ah00P0i<Ah803de7P<0?SPP
1@0m=al01P0o>Al0@3TO044j7P14>ah0AS/M04Pj7@80BS/L0`1A@B0205928@<0Dd<R0P1FARD01P1I
ARD0FdLT05i88`1PB280HDXQ06998@P0IDhU0P1WD2@0101XDBD0JE8V06YC9`1[E2P206aE:@@0Ke@W
00@0L5DX075F:@1bEbX0LeP[0`1iGBd00`1hG2`0Me/[07MK:`0207IJ:P0807QL;01gFb/0MUXZ07EI
:@1fFRX0Me/[07UM;@1jGRh207QG;00307QI;@1gFRh0Me`_0080MUh`00<0MV0a071J:`1`FR/00P1_
FBX406iH:@0306]D:01/EBT0KUL[0080KeP/0140KUL[06aE:@1[E2P0KEH/06aE:`1[E2X0JE8X06QA
9`1VCbD0IDhT06A=8`1UCbP0I4hW06==9P1RC2D0HD/T061:8`0205m98P0306==:01RC2L0HT`W0080
HT`W0`1QBbH01P1NAR@0GDHT05e6901JAR<0FDLS05M78`<0EDLR00L0E4HQ05=5801BA1l0DD<N0594
7`1DAR40EDLR00<0E4PR00@0EDLR05M78`1HB2@0FTPT0P1LB2D305E58@<0ETHR0P1GAb<605I69@80
EDDT0`1CA2D305939080DD8S00@0DTLW05569P1?A2@0CD8R0P1<@B4204e28P0404]29@19@2<0AchQ
04Dl7`80A3/N00D0AC`O04Hm8013?200@c`P048k7`02044j7P0;040i7@0o>1`0?cPL03ll7@0n>a`0
?SXM03di7P0l>1l0>cHP03Xe7`0j=B400P0c=Al0100b=1h0<C<M034c7@0`<Q`202la6`80;c4L0P0^
<1/202d_6P80;2hI0P0X:aP01P0W:QT09bTK02HX6`0T9Q/08bDJ02<T708092LN00@08bHM028U700Q
91/082<J0P0O8QT201lR6`807R4J0P0M81T201`O60P06Q`I0`0I6aX301PJ6@805aTH200F61L:01DF
608051DG0P0C51H2018C5@P051DG4@0B4aD800lE5@P04ALG200C51H801@E5a004ALG@00D5ALH01DF
60T05ALF6P0F61L301LI60<061XI200I6aP801XJ6P8061PF0P0I6AL201XJ61806a/I200L71X801hM
60807A`G0P0N7AP201lN6@8081lJ200Q8AT3028Q70808B0K0`0P7aX8024P6`X07b0J0P0N7aT201dN
608071dG200M7QPA01hO6@P07AdK100P7aX501lN6@8081lJ0P0Q81/2028Q700302<R7@0R8QX08B4I
00808B4I0P0R8QX202<S6`<0:2@K0`0Y9A`202XV7@80:bTL00<0;2PL02dW6`0^9Q/00P0^91X0100`
8aX0=RXN03HZ7P0f:Qh203DY7@<0=2PL00<0>BdM03P/700h;1`00P0h;1`303L[6`80>2XO00@0=b/O
03D[7`0d;1l0<b/N0P0b;1h2038/8006034[7`0_:Ad0;RPL02dW6`0/9QX0:bDI0`0_:Ad2030Z7P<0
<B/O0`0a:Ah00`0`:1d0;bLL02lW700202hV6`80;2DM0`0[91`302XS6`0302TR6P0Z8a/0:b@L0080
;BHN00<0:b@L02XS6`0Y8QX0100T91`402DU7@06028S6`0S8a/092@L02HS700X8ad0:R<M0P0/8ah2
02XS6`H0:b@L2@0S8a/2028R60808b<I0P0T91X202DU6`P0:2@K200T91`2028R6P<08b<K2`0T91`3
02PT6`80:BDL0`0Z9Qd302hX7080;bTM2`0`:Qh302/W7P<0:RHM0P0Y9A`00`0/9QX0;BLK02dW6`02
02dW6`<0;RPL0`0_:Ad3030Z7P80<B/O200e:al0100f;200=B/O03D[7`0e:al303@Z7P0303<Y7@0i
;B40>2`P0080=b/O00@0>2`P03T]8@0k;b<0?30T200j;Qh203T]7@80>RhN100k;al01@13=240@S<P
048b8P12<R<0@S8U0080@C0V00T0@C0X03X^7P0i;Ad0>2`L03L[6`0h;1`0>BdM03/_7`0l<2000P0k
<1h203`a7`80?C8P0`0n<b43044`80<0@S4Q0P13<R83044`8080@S4Q0`13<R8804<g7`<0?C4Q0P0l
<20303/_7`80=RXJ00H0=b/K03T]7@0j;Qh0>blO03``800m<B4803T_8`<0<bdO0`0d;R0203D_8@<0
>2`P100i;B401`0j;R80=B/O03H/800f;200=bdQ03P^8P0i;b<00P0j<2@303P^8R_ooooo000Zoooo
o`80V6hl00h0VFlm09Y`?P2JL3h0VW0n09U_?@2HKS`0UVhk09M_?02JL3h0W70o09i`?`2NKSh0W6`l
09eZ>`80WG500`2LL3l309]_?PP0WG8o00@0WgE309id@P2NM480WWA20P2MLd4209ab@080WG=100<0
WWA209me@`2PMT@00P2QMdD0102RN4H0XGE40:5eA02QMD@30:1d@`80Wg=20P2NM480102OMD<0X7I4
0:9hAP2SNDL20:AjB080XWI700@0XGE40:5f@`2QMT<0X7E00P2PMCh90:=hA@P0XgM60P2QMdD20:9h
AP<0XgU700L0Y7Y80:IlBP2UNdT0Y7Y80:9hAP2PMT@0WgE30080WG=10P2ILd@00`2HLT<0Ug5209I`
@@0209E_@00309A^?`2BK3d0TV`m0080TV`m00X0T6Xk08eW>02:I3D0RF<d08UT=`28HcH0Qf8e08IQ
=025H3<0Peha0P22GC06081K<@80OeX`0P1jEbl207UF;P0:07QE;@1gE2`0MU<[07IC:`1bDRT0LU8[
075A:P1aDB/0L4l/071?;P80Kdh_00<0Ke4_06i@;P1[CB/00P1YBbT00`1[CB/0KDl]06mA;`0806e?
:`0507=@:01eDRX0N5D]07YG;`1lFC400P1mFS801P1lFC40Q5le08AO=@25H3H0QV4g08MR>080R6<i
00X0RF@j08MP=@28HCH0RfDh08eW>02?JCP0SfXf08iY=@2>JC@0TFHk0P2AIST00`2AIcL0TFLe095X
=002095X<P/0TfTg0P2BJ3H6095W=@80T6Hd0`2?IC<908mT=`0308]P<`2=HSD0T6Dh0080TVLj00<0
TFHi08mT=`2=HSD00P2?I3L208iS=P0408eR=@2<HC@0Rf0c08]P<`X0Sf@g0`2@ICP6095V>@80TVLj
0`2CJ3/209A[=`0609E/>02FKCT0V6lk09U`?02JLCd0Vg8n0`2HKS`209U_?@<0VW0n202KLSh209Mb
>`0309Mb?@2GLSh0Ug500080Ug5200@0Ug5409I/>P2FK3X0UV`j0P2GKC/309Q^?00409Ye@@2IM400
Ug8n09E`?0@0Tfhj0`2@JcL308mZ=P80SVTe00<0TfTg09E[>@2FK3X00P2GKC/00`2FK3X0UF/i09=Y
=`0309=^>P<0TVdi0P2AK3P809E[>@80TF/l0`2@JS/308mY>P80SfXc00<0SfXe08mZ=P2?JCP00P2?
JCX03`2?JC`0S6Ph08]W=`29ICD0R6@d08MS<`28I3@0RFDe08YV=P29IcT0R6Hh08MU=`25HcD0Q68d
089P<P02085O<@0I081N<024GC@0Pe`c085L<P1nFc40NeX_07UJ;P1hFBd0MEP/07QH;`1gEc00LeH^
071D;@1[DB`0J50/06I?;@1UCR`0I4//05m8:01KA2D0F4<V05Q4:@1EA2X0D40V04`l8`0204Pm8@0F
04Dk8011>R00?CLO03Xe7`0f=1d0=C<N03@b7@0c<1d0<RlL030]700^:a`0;2PL02/W700Z9Q/0;RLO
02`X7`0[9ah0:RLN02LW7@0V:1d09BPM02@W70<092DM0P0S91`3028S6`P07b8K200P8a`3024T6`<0
8RDL0P0S9Qd3028U70<08B@K0P0P8aX301lR6`807R4J0`0M81T801`N6`807B0I00H07R4J01lR6`0Q
91d08RDN02<V7`0T9b0202@V6@0602DW6@0W:QT0:2/H02T/5`0Z;AP0:blH0P0^;ad01`0];Qh0:b`N
02XZ7P0Y:Al0:2PN02LW7`0V9Qh00P0V9Q`00`0W9a/09bPJ02LX600202PY5`0;02d/600^;AT0<2dJ
03<^6`0e;Q`0>2lN03T`7`0k;al0?30P03/_7`0j;Qh00P0i;Ad0100j;Qh0>blO03``800l<20203`d
7`<0?CDP0`0n=R42044g7P03048h7`13>B00@cTP00D0@cTP1015>b800`14>R40@cTP04<g7@0204<g
7@80A3PN0P15>Al01P16>R00AC`O04@k7P14>Ql0@cTP04<h8P80@SLS00@0@SLU03lg8P0n=R40?CDP
0P0l=1l00`0m=B00?SHQ03lg8P0203Tg8P0403Pf8@0g=B00=S@O03Hd7`80=C<N00P0=c8N03Lb7`0f
<Ah0=BlO03@^800c;B40<b`R038[8@80<bdO00@0=2hP03D_8@0e;b40=2hP0P0c;Al403D`7@80=2lL
0P0c;Q/802d_6P0302h_7`0];Qh0;2dM0080:b`L00<0;BhN02h_7`0`<B40200^<1/2038_8080<BhO
100`;Ah302d_6@80;S0J0`0_<A/303Ha7P0303D`7@0d;a`0<bhK0080<RdJ0P0Z9QX202/W6`@0;2PL
0`0]:QL01@0^:aP0;b`I02l/6@0_;1T0<2dJ0080;BXG0P0^:aP302l/6@0:030]6P0^<A`0;S4L02la
700`<Qd0<S4M03@a7P0f<Ah0=c0N03Pa7`80>S8M00@0>c<N03`d7`0l=1l0>c<N0P0j<Qd303/f8080
>SDO0`0i=1h02@0k=ah0?CLO03dg7@0o>1`0@STL04@i6`17>A`0AcXJ04/l7@0304`m7P80CChO0P1>
?b00201@@B80DD8Q05=38P1F@b80F4@Q05a68@1MAb00GTHP0P1QBb@2069<9@80HddV0P1TCRL01P1U
CR@0ITlU06I?9@1WD2H0J54W06UB:080JU<Y0P1^DbP206eB9`0406iC:01_E2T0L5DZ075F:`P0MUXZ
00<0NEd]07QL;01fFRX00P1eFBT0201gFb/0N5`/07UM;@1gER/0N5L/07MH;01eF2`0MEX]0P1cFbd0
0`1bG2d0LE//071J:`02071J:`80KeTZ0P1^F2T00`1[E2P0K5DY06iG:`0206mH;00806iG:`1/EBT0
Je@X06eF;01/EB/0Je@Z06YC:@1YDRP206M@9P0706I?9@1WDBX0IU0Y06E?:01TCRL0HT`U065;9002
061:8`L0HT`W00L0HD/V05m78`1NB2<0GTPS05]78P1JB280EdPQ0080ETPQ00P0ETPS05E78P1CAB00
DT@O05537P1BA1l0DdDP05A68@<0DTHP00H0E4HQ05I68P1GAb<0FTPT05]7901LB2D305E58@80ETHR
0`1GAb<305M79P<0ETHU0P1EAB@205A59P80Dd@U0`1B@b@01@1A@R<0D4LV05179P1?ARD0CD@S00@0
C4<R00@0CD@W04]29@19@2<0AchQ0P16?B000`17?R40B3lR04@m8@0204<l8003048k7`11>Qh0@3TM
0080?cPL00P0?c`M03hk700n>Qd0?CTN03`h7`0k=R00>SDO03Xe8@80<cDO00@0<S@N034c7@0a<ad0
<38L0P0_<A/302la7080;S0K0`0];aX0200X:aP0:B`I02T/6`0Y:ad0:2XM02HX7@0U9a`08b@L0P0T
9ah0100S9Qd08RDL024T6`0Q91/2020S6P05020S700O8Q/07b8K01hQ6P0M81T00P0L7aP00`0K7QL0
6A/H01TK600601TK60<06A/J0P0H6QT301LI60P05QPG2P0E5QP201@E5`804a@F0P0B4aD801@E5a40
4Q<E200?5AD8014G5`P04a@F200D5AL@014G5d0051DG600E5QP901DG5QX05QPG0`0G6AP301PJ6@P0
6A/H200J6QX201PH5P806ATG0P0J6QPB01/K6@P071`J2`0N7AP201lN6@<081lJ200Q8AT0100S8Qd0
8R4L028Q700R8A`2024P6`8081lJ200Q81/;01lP6P807QlI2`0M7QPA01hO6@P07AdK00@08B0K020O
6P0P7aX081lJ0`0O7QT01P0N7AP07ahI01lN6@0P7aX08B0K028Q70808b8M00<092<N02<S6`0R8QX0
0`0Q8AT00`0R8QX08b<K02<S6`0302PT6`<0:BDL0P0Z9Qd202TW6P0302XV6P0]9a/0;RHK0080;bDK
00<0<B@K03DY7@0e:Ad01P0e:Ad803P/7080?B`R00H0>R`Q03P/800e:al0<b/N038Z7@0a:ad2034[
7`80<2XN00@0;bTM02hX700]9a/0;BLK0P0_:Ad2030Z7P<0<B/O00<0<R`P03<Y7`0c:Al00P0b:1h0
100a9ad0<2HL02lU6`0_9A/202`U7@<0:b@L0`0Z8a/00`0Y8QX0:R<K02/T700202dV7P0402/T700Z
8a/0:B8J02<S6`<092@L0`0U9Ad01`0V9Qh08R<K02<S6`0T91`09R<L02PS7@0Z8ad00P0/8ah00`0X
8AT0:B8J02/T700302`U7@80:b@L2@0S8a/302<S6@8092@J0`0U9A/802PT6`P092@L0P0R8QX302<S
6`/092@L0P0X91/202TU70<0:RHM00@0:bLN02dW6`0]9a/0;BLK0P0^:1`;02lY7@80;2PO0P0[9ah3
02XV7@0302TU700]9a/0;BLK00H0;BLK0`0_:Ad3030Z7P80<B/O200e:al803L[7`0803T]8@0h;200
=b/O03L[7`0h;200>RhR03``900n<RH803/`7P0303P/700i;Ad0>blO00<0?30P0P0k;al204<b8003
04<b8P13<B<0@c4U0080@c4W00@0@RlX03``800k;al0>BdM0P0h;1`00`0i;Ad0>blO03``800203`_
7P80?C0O0P0n<B0303lb8@<0@C0P0`12<B4204<b8P80@C0P0P12<B4304<b8P0304@c8`12=Qh0@SHN
00H0@SHN00@0@3<R03lb8@0o<R40?c8Q0P0n<B0203d`7`80>2dK00@0>BhL03X_7@0k<1h0>c0N0P0l
<Al803/a9@<0<bdO0P0d;R0303D_8@P0>BdQ0P0e:al00`0f;200=bdQ03P^8P0203T_8`0403X`900h
;R80>2hR03P^8R_ooooo000Zooooo`0309Q^?02IKcd0VW0n0080Vg4o00/0VW0n09Q^?02GKC/0UVhk
09M_?02JL3h0W70o09i`?`2NKSh0W6`l09eZ>`0209mc@P80WW9100@0WG5009a`?`2LL3l0W70o202M
LSl209me@`<0WWA2102MLd4209id@P0509me@`2QMdD0XWQ60:9hAP2SNDL00P2RMTD20:5eA0040:1d
@`2OLd80Wg=209mc@P80WgE30P2PMT@0102QMdD0XWQ60:9hAP2SNDL20:9fA`040:5eA02QMT<0X7E2
0:1e@080Wg@m2@2SN4D60:=gAP80XWI50`2QMdD20:9hAP<0XgU70P2RN4H0102QMdD0X7I409me@`2N
M48209ec@@0609UcA02HLT<0V79309Ma@P2FL440UFm00P2DKSl4099/?@0<08mY>P2<ISL0RF<d08QR
<`29I3L0R6<f08MR=@26HC@0Q5lb08=N<@22GC00PE`_0`21G3800`20Fc40OeX`07mJ<00207iI;`80
NeP`00@0NUL_07UF;P1hEBd0Me@/0P1fDb/02`1dE2/0Le</079B:`1aDB/0L4l/06m>;@1^CBh0KD`]
06i@;P1/CR`0JD/Y0080IdTW00<0JT`Z06e?;@1_DBl0201]Cb/01@1cD2P0ME8Z07QE;@1kF300OEXb
0080OU/c0180OEXb081K<@21G380PUdc08AO=@26HCL0R6<i08UT>P2:IC/0Qf0e08QQ=P2;ICP0SFLh
08mY>02?JSH0SVTe08iY=02AIS/2095V>@03095W=`2AIcD0TFPd0080TFPb2P2CJCL2099X=P@0TFLe
0`2CJCL2099X=P<0TFLe2@2?I3L0102=HSD0SV<f08mT=`2?I3L4091U>0@0SV<f102=HSD:08mT=`<0
T6Dh102AIST3099W>P80TfPk0P2DJC`0202CJSH0U6/g09E/>02GKSX0V6lk09Ya?@2KLSh0W7<o0`2H
KS`209U_?@<0VW0n202KLSh209E`>@0609E`>`2EL3`0UFln09E_@02FL440UW130P2EJcT209I/>P08
09M]>`2HKS`0V6hl09Q^?02LMd<0VWE109Mb?P2EL3`309=^>P0509A_>`2CKSX0Tfhj09=^>P2BKCT0
0P2AK3P2091[=`0309=Y=`2EJcT0UV`j0080Ufdk00<0UV`j09E[>@2CJCL00`2CKSX3099]>@80TF`h
202EJcT2095[?0<0T6Xk0`2?JCX208mZ<`0308mZ=@2?JSH0SfTh0080SfTj00@0SfTl08aX>02:ISH0
RFDe0`27Hc<00`28I3@0RFDe08MU=`0208IT=P0308ES=@24HS@0Pf4c00<0PV0b0P23G3<09021G380
OEX`07]J;`1iFRh0N5T]07EH;01eF300M5L_079F;`1]Dbh0JU8^06I?;@1TCB/0HDd/069;:`1MARL0
Ed8S05E2901D@bL0Dd<Y04hn9@19>b40AchQ04Hm8012>al0?cTO03/g7P0g=Ah0=S@M03@c7P0`;QT0
<2dJ02l/6@0_;1/0;R/L02dY7@80;2PM00H0;BHN02/W7P0[9ah0:BHM02LW7@0V:1d202@W700402@U
7@0S91`08b@L02<T70808R<K0P0Q8QX801lR6`P082<L0`0S9Qd3028U70808B@K0`0R9A`3024T6`80
82<J0P0O8Q/201hQ6P@07B0I200L7Q/201dP6@0<01lR6`0P8a`08RDN02<V7`0T9b009BPQ02HX6P0W
:A/0:2/J02T/6`0[;Q/0;2lJ0P0]<AX01`0_<A/0;c4L02d^700/;Ad0:RXN02PX7P0W9al00P0V9B00
3@0V9Qh09bLM02PX700X:AT0:BXH02X/5`0Z;1H0;bhJ030]6P0a;Q/0<bhK03D^700f;A`00P0i;Ad0
0`0k;Qh0?2lO03d`800303d`800303`_7`0k;Qh0>bhN0080?3@O0P0m=B00100n=R40?cLR03lg8P0o
=b82048h7`<0@cTP0P14>R401015>b80@cTP04@j8@16?2<204Lm900304Dk8P14>R40@SPO0080@SHL
0`13=ad304@h7P80@cTN00@0@cTP048h7`12=b40@SLS0P11=R@00`0o>B<0?SPR03`f800203/e7`03
03`f800n>280?cTS0080=cHR00H0=SDQ03Dd800d<al0=3<O03<b7P0b<Ad203Ha7P0903D_7`0d;R00
<bdQ03</8P0b:b40<R/S034[7@0b;1h0=2hP0080=BlQ00<0=2hP038/7P0a:ad00P0b;ah2034^7@04
030]700_;1/0;b`K02l/6`P0:b`J00<0;RlO02`]7@0[;1`00P0Y:QX00`0Z:a/0:b`L02`]7@0802X[
6@0302h/7`0]:ah0;B/N0080;2XM0P0[:A`0100Z:1/0:bdH02/]600[;AP202`^6@<0;BlJ200d;Qh0
100/:B00;BXQ02dZ8@0]:R4202h[8P80;b`S100]:a`402h/7@80;bdN0P0`;Ql3034_8006038`8@0_
<R40;c8Q02lb8@0a<R80<c4R0P0e<R<01@0g<B<0>38T03L_6P0h<1/0>S8M0080>c<N00<0>S8M03P`
6`0g;aX00P0h=Ql203Le7P0403Hd7@0e<a`0=C<L03Dc7080>SDO00H0?3HN03hg7@11=a`0@SLK04<h
7016>1/304Li7080B3XM0`19>ah01P1;?Qh0CChO04ho7P1@@1l0E44P05I27`80FT@O00P0G4TQ05e:
8P1MBR80Gd`T061=9@1QCRH0HTlW06=@:080I4dT00<0IDhU06I?9P1WD2L00P1XDBP0101YDRT0KU8Z
06eA:@1/D2P206]?9`0306eA:@1_Db/0L5@/0080LUHV00<0LeLW07AH:01eFBT00P1fFRX02@1gFb/0
NEd]07QL;01gFb/0MUXZ07EI:@1fFRX0N5`/07UM;@0207MF:`0707IG:`1cERX0LULZ071H:P1_EbT0
KUPY079L;@03075K;080L5X[0P1_FBX00`1[E2P0K5DY06iG:`0206mH;00406iG:`1/EBT0Je@X06aE
:`80Je@Z0P1ZDbT306UB:00806UC;01XDR/0Ie4Z06I@:@1TCRL0HddV069<9@1QBb@2061:9@H0HD/V
00H0H4PR05m98P1OBB80G4TQ05]98@1HBB0205M:800605M9901EAb80DdDP05947`1A@ah0DT@O0P1C
AB0305147P0705947`1DA200EDDQ05Q68P1JAR<0FdLT05E58@0305I68P80EdLS0P1HB2@205Q89`80
EdLV0P1FARD205E590<0E4DV0P1CA2D305939080CTPV00<0CDLU04a6901;AB<00P1:A2801@19@b40
CdHY04e49`1;@RD0BD0S0080B3lR00L0BD0S04Y19014?B40A3dQ04<l8012>al0@CXN0080@3TM00T0
?cPL03ll7@0n>a`0?SXM03di7P0l>1l0>cHP03Xe7`0j=B400P0c=Al0100b=1h0<C<M034c7@0`<Q`2
02la6`@0;c4L0P0^<1/202d_6P80:RdJ00L0:bhM02/]7`0Z;1l0:2XO02HX7@0U9Qh09BPO008092LN
00<08bHM028U700Q91/00P0P8aX2020S700401lR6`0N8AX07B0I01`O60806ahG200I6aP0100I6aX0
61XI01PJ6@0H6QT201LI60X05QPG2P0E5QP201@E5`804a@F0P0B4aD801@E5a404Q<E200?5AD8014G
5`P04Q<E200D5AL@014G5`P05AHH>00D5ALH01DF60T05ALF6P0F61L301LI60<061XI200I6aP801/K
6`8061PF0P0I6AL201XJ61806a/I200L71X:01hM60807ahI100P7aX8028R6P808b8M0`0R8A`3024P
6`P08R4L300O81X201hO6@X07AhH4@0N7aT801dM6`808B0K0P0P7aX201lN6@807QdH0P0O7QT02@0P
7aX08B0K028Q700S8Qd092<N02DT7`0T91`08b<K024Q6@02020P6003024Q6@0R8QX08b<K00<0:2@K
0`0Y9A`202XV7@809bDH00H0:BDI02`V6P0^9Q/0;bDK030V700b9A`203<W6`0403@X700e:Ad0=BTM
03HZ7P80=b/O100h;1`403T]7@80@BlU00H0?RdS03X/8@0g:al0<bTM038X700`:1/4030Z7P@0;bTM
0`0`:Qh3034[7`80<R`P0P0d:R00100c:Al0<RPN034W7@0`9Q`202lU6`80;2DM0`0[91`302XS6`03
02TR6P0Z8a/0:b@L0080;BHN00<0:b@L02XS6`0Y8QX00P0S8a/202@T70809BDM0P0V9Qh01P0R8a/0
8b<K02@T700V8a`0:2<M02XS7@80;2<N00P09b0H02TR6P0[91`0;2DM02dV7P0/9Ad0:b@L02XS6`T0
8b<K0P0S8aT202@T6P@09BDK200Y9A`802@T70808R8J0`0S8a/;02@T70<0:BDL0`0Z9Qd202/W7P80
:bDI0P0/9QX202dW6`X0;RPL0`0/:1l202/W7P<0:RHM0P0^:1`602dW6`<0;bTM0`0`:Qh2034[7`P0
=B/O0P0f:1d00`0g:Ah0>2XO03T[800303X/8@0803T]8@0h;200=b/O03L[7`0i;B40>blS03da9@0n
<RH803/`700303P/700i;Ad0>blO00<0?C4Q00L0>blO03X^7P11<1h0@C0N048a8@12<280@S0T0080
@S0V00@0@RlX03da8@0l<200>RhN0P0i;Ad00`0j;Qh0>blO03``800203h^7P80?blO0P10<203044a
8@<0@C0P0`12<B4204<b8P<0@S4Q0`13<R8204@c8`P0@CDM00@0@c@Q048c8012<b00@S<P0P11<Ql2
040a7PP0>c0L200i;b<0100c;Al0=2hP03@^800d;R0203D_8@80=S0R1P0i;B4203P/8080=B/O0P0f
;200100g;B40>2hR03T_8`0i;b<303P^8R_ooooo000Zooooo`0309M]>`2IKcd0VW0n0080Vg4o00/0
VW0n09M]>`2FK3X0UVhk09M_?02JL3h0W70o09i`?`2NKSh0W6`l09eZ>`020:1d@`80Wg=200@0WW91
09ea@02MLD00W70o202MLSl309me@`80WWA2102MLd401`2NM480WgE30:1fA02QMdD0XWQ60:=iA`2T
NTP00P2RMTD20:5eA0040:1d@`2OLd80Wg=209ib@@@0X7I4102QMdD20:9fA`060:5eA02QMT<0X7E2
09md?`2OM3d0WW<l2@2SN4D50:=gAP<0XWI50`2QMdD30:9hAP80XgU70`2PMT@01@2OMD<0WWA209id
@P2NM480WG=10080V7930P2GLD80102FL440UFm009A^?`2DKSl3099/?@0C095[?02?JCX0S6Hg08US
=027HC80RF@g08QS=P27HSD0QV4d08AO<P22GC00PE`_081K;P23GS@0PUdc085L<P20Fc40OeX`07iI
;`0207eH;P0607aI<@1kF300NUL_07UF;P1hEBd0Me@/0P1fDb/02`1eEB`0M5@]07=C;01aDB/0L4l/
06i=;01]C2d0K4//06i@;P1[CB/0J4XX0080ITPV00<0JD/Y06a>;01_DBl00`1^D2`506e?:`0507=@
:01eDRX0N5D]07]H<01mFS800`1nFc<04@1nFBl0OeX`085L<P23GS@0QF0f08MR>029I3X0RVDk08MP
=@28HCH0RfDh08eW>02?JCP0SfXf08iY=@2>JC@0T6Dj0080T6Dh00<0T6Hf091V=02@Ic<00P2@Ic48
09AX=`80TfTg0P2BJ3H3095W=@04091V=02DJSP0U6Xh09AZ>0<0TfTg0P2BJ3H:08mT=`@0SV<f00<0
Sf@g095V>@2AIST00`2=HSD308iS=P80Sf@g0P2@ICP408mT=`80SV<f0P2?I3L3091U>0<0TFHi102B
IcX209=X>`80U6Tl00P0TfXf09A[=`2EK3P0Ufhj09U`?02JLCd0Vg8n09ac?`<0V6hl0P2IKcd309Y`
?PP0Vg8n0P2DKcP00`2DKcX0U6lk09A^?@0209E_@00609E_@P2EJcT0UF/i09E[>@2FK3X0Ufdk0`2H
KS`0102MN4@0VgI209Mb?P2EL3`309=^>P0409A_>`2GLSh0Ug8n09Ia?@80UG0l00H0U6lk09=^>P2C
KSX0TfTg09E[>@2FK3X209M]>`0309I/>P2EJcT0TfTg00<0Tfhj0`2BKCT2095/>0P0UF/i0P2AJc`3
091Z>`<0SfTj0P2?JS<00`2?JSD0SfXf08mY>00208mY>P0908mY?02<J3P0RVHf08QT=027Hc<0QV8b
08MS<`28I3@0RFDe00<0QF<e0P24HS@408=Q<`80Pe`c01l0PE`b07eJ<01kFRl0N5T]07MH;01eF2`0
MEP`07=G<01aEBh0KE<^06UA;@1VCbd0HTh]065=;01QBR/0FdHW05I1901E@BH0E4<Y0592:@1=?bD0
B3TR04Hm8013?1l0@S/O03li7`0k=ah0=cDN03@d700c<Qd0;R`G0080;R/H00<0;R/J02h[700]:Ad0
0P0]:Ah01P0]9Qh0:bLN02/W7P0Y9Qd09bLM02DW708092LL100S91`2028S6`808B8J200O8Q/8020S
700502DX7`0T9ah092LN02<V7@0R9A`00P0Q91/0100P8aX08RDL028U700R9A`3024T6`8082<J0P0O
8Q/201hQ6P<07B0I00<071lH01`N6`0L7Q/01P0L7Q/0200M81T07R4J01lR6`0P8a`08RDN02@W800U
:2409RTR0P0X:Q`03@0Y;1/0:bhK02`_6P0^<Q/0;c<L02lc6P0`<Q`0;c4K02h_7@0/;Ad0:RXN02PX
800V9B000P0V9B401@0W9R409bLO02PX700Y:QX0:R/I0080:bdG0P0a;aX00`0c;QX0=2dJ03D]6P02
03L/6P0403P[6P0i;1`0>bhN03d`8080?c8R00D0?C0P03/^7P0i;1`0>B`L03`d7`0203de800303hf
8@0o=b80?cLR0080@3PS1013>Ah204@j7`0:04Dk8016?240A3XQ04Dk8P17?B@0B3hU04Lm9016?2<0
A3XQ048h7`@0@SHL1013=ad2048h7@03048h7`12=b40@CHR0080@CHT00@0@CDU03lj9P0n>BD0?3LS
0P0k=R80100l=b<0?STU03lj9P0g=R8203He8@0303Dd800d<al0<c8N0080<S4M00/0=S4N03H`800e
;al0=2hP03<]8@0b:b40<R/S034Z8P0`:Qh0<B/O03<]8@0203D_8`0303<]8@0a:al0<2XN0080<BhM
0P0`;A`0100_;1/0;R/J02h[6P0]:QT802T/6@0602d_8@0[;Al0:B/M02LY6`0V:1X09bTK0P0X:Q`8
02LZ5`80;2XN00@0:bTM02XX700Z:1`0:BLK0P0X9QX302T/5`80:RdH0`0[;QT203<]7@<0=2hN0`0e
;al3034^9@80<RlV0`0c<2L602h/7@80;bdN0P0c<B8203@b8`80=C<T0P0f=2D202lc8P0:030c8P0a
=2<0<S<S03Dc900f<b@0>38T03Tc9@0f;Q/0=blL03Ta7P80>S8O00<0>C4N03L_700f;Q/00`0g=B00
0`0f=1l0=C<N03@b7@0203@b7@0803Le7P0i=1h0>SHM03`f700n=a/0@CLL048g6`13>1`204@f6@80
ACLJ0`16>1/04P17>A`0BC/N04Tl701;?1d0CShM058o7P1D@1d0ET8M05Q27@1JAR40FdLR05a88`1N
BRD0H4`W065=:01SCbX0I50[06=<8`80I4dT00<0IDhU06I?9P1WD2L00P1XDBP00`1^DRX0KE4Y06]?
9`0206Y>9P0306a@:01^DRX0Ke<[0080Ke<S00@0LEDU079F9P1dF2P0METY0P1gFb/0201jGRh0NEd]
07MK:`1fFRX0METY07IJ:P1gFb/0N5`/0P1gER/01`1eERX0LUDY071E:01^ERP0KEDW06aF9`1cGBh0
0`1bG2d2075K;080L5X[00<0Je@X06aE:@1^Eb/00P1_F2`00`1^Eb/0K5DY06]D:00306]D:PD0JU<Y
00T0JeD^06YD;@1YDb`0Ie4Z06E?:01TCRL0HddV069<9@1OBB@0101PBRD3065;9P0606188P1OBB80
GdTR05a98@1KBB40F4TP0P1GBR00101GBB@0ETPS05A68@1BA1l205537P0305947`1CAB00Cd<M0080
Cd<M00H0DD<N05=37`1DA200EdDQ05U58P1JAR<405I68P80EdLS0P1HB2@0101IBBP0F4PW05Q89`1G
AbH205I69@80EDDT0`1DABH305=49@80DT<T0`1>B2H02@1=AbD0C4HT04]58`1:A280BD<Q0517:P1?
ART0CD@W04]29@0204Y19080Bd8U0P14?B401013?200@S/O044j7P11>Qh2040i7@0803ll7@0n>a`0
?SXM03di7P0l>1l0>cHP03Xe7`0j=B4203<e7`04038d7P0a<ad0<C<M030b7080;c4K00@0<38M02la
700_<A`0;c4L0P0^<1/202d_6P0802X]6P0[;Q/0;C0O02d_8@0/;R40:R`Q02LY7P0V9al202DX7`04
02@W7P0S9Qd08RDL024T6`8082<J00P08B@M020S700O8Q/07R4J01dP6@0L7aP06ahG01XM5PP06A/H
100H6QT201LI60X05QPG2P0E5QP201@E5`804a@F0P0B4aD801@E5a404Q<E200?5AD8014G5`P04Q<E
200D5AL@014G5`P05AHH>00D5ALH01DF60T05ALF6P0F61L301LI60<061XI200I6aP801/K6`8061PF
0P0I6AL201XJ61806a/I200L71X:01hM60807ahI0`0P7aX00`0Q81/08R8J028R6P06028R6P<08b8M
0P0R8A`3024P6`P08R4L200O81X0100P8A/07b0J01lP6P0O81X201hO6@X07AhH4@0N7aT801dM6`<0
8B0K00<081lJ01lN6@0N7AP00P0N7AP201lN6@04020O6P0Q81/08b8M02@S7P809B@O00<09BDM02@T
700Q8AT00P0P81P00`0Q8AT08R8J02@T700302PT6`<0:BDL0P0Z9Qd202HT5`0602PT600[9AT0;RHK
030V700a9ad0<bHM0P0b9QX0100c9a/0=2PL03HZ7P0g:al203P/80<0>2`L1@0i;Ad02013<BL0@S0V
03l^900k;B80=b/O03DY7@0a9a/0<2HJ0`0_:Ad3030Z7P80<B/O0`0`:Qh2034[7`<0<R`P00H0=bXQ
03HY800e:1l0=2LN03<V7@0b9A`2034T6`80;2DM0`0[91`302XS6`0302TR6P0Z8a/0:b@L0080;BHN
00<0:b@L02XS6`0Y8QX00`0S8a/00`0T91`09BDM02HV7P0202HV7P06028S6`0S8a/092@L02HS700X
8ad0:R<M0P0/8ah00`0W81P0:24I02/T700302dV7P0302/T700Z8a/08b<K00P08b<K0P0S8aT202@T
6P<09BDK00<09RHL02TU700Y9A`01P0Y9A`802@T70808R8J0`0S8a/;02@T70<0:BDL0P0Z9Qd302/W
7P80:R@H0P0[9AT302`V6PT0;BLK0`0/:1l302/W7P80:RHM0`0^:1`502dW6`<0;bTM0`0`:Qh2034[
7`P0=B/O0100=BLL03HX7@0g:Ah0>2XO03T[800j;240>bdR03`^8`0i;B40>2`P03L[7`0h;200>BdQ
03/_8`0m<BD0?c<W200k<1`03@0h;1`0>BdM03/_7`0m<B40?S8R03da8@0k;al0>RhN044^7@12;ah0
@RlP048_8@12;R<00P13;bH02@13;bP0?S8R03da8@0k;al0>RhN03T]7@0j;Qh0>blO03``800203h^
7P80?blO0P10<203044a8@<0@C0P0`12<B4204<b8P<0@S4Q0P13<R8304@c8`P0?c<K0`13=242048c
80<0@C8O0`0l<Ad303/`7080>RlK200g;B4403@^8080=BlQ0P0f<28503T]8@<0>2`P00H0=2XN03D[
7`0e:al0=R`P03L]8@0h;R8203T_8`<0>2hR:oooool002[ooooo00<0V6`k09U]?02KKch00P2LL3l0
0`2KKch0VFdl09Q/>`0309]_?P80VVhm0`2IKC`309ib@@0309ea@02LL3l0Vfln0080Vfln0P2ILCh0
0`2JL3h0W70o09ma@0020:5a@@090:=`@@2NMT<0WgM40:1hA@2QNDH0X7Q509if@`2LM440VW8o00<0
WG=10P2NM48309me@`060:1cB@2PM4L0X7A70:1dA@2PM4<0X7E20P2PMD050:5eA0040:9fA@2SMdH0
XgM60:EiBP80Y7Q900<0XgM80:9fA`2RMTL00P2QMDH90:5gA@030:EgAP2TMTD0XgE40080XWA300<0
XgE40:AfA@2UMdH0202PMT@00`2OM4L0XGI90:9gBP020:=hB`030:9gBP2PMDP0WW=60080V79300h0
Ug5209E_@02DKSl0Tfdn099/?@2AJc`0Tfdn099/?@2AJc`0T6Xk08iX>@2=IcP0S6Hg08]U=P80Qf4d
0P28HSD01026H3<0Ped`081J;@1nF2/2081M=@0407mL=01mFS80O5Ta07YG;`80NEH^00T0NeD`07UF
<01hEBl0MU@^07AD;@1`Db/0Ke<[06iB:P1bDBh00`1aD2d2071?;080Kdh[0`1]C2T206a;:0<0JdXW
0P1]C2d00`1^CB`0Kdh[071@:P02075A:P0A079B:@1fE2l0N5Ha07eJ=022G3D0Q5le08EN<`26G380
QE``089J=`23FcP0Q5`h08IO>028HCP0RV<h08]T>@2<IST00P2?I3L3091U>0<0TFHi0P2CJ3/2099W
>P80TFHi0`2@ICP00`2AIST0TfPk09I[?P0209M/?`80UV/n00H0Sf@g091U>02AIST0TVLj09=X>`2E
JSd209I[?P<0T6Hd0P2?IC<308iT<PT0RF<d00@0Ped^08EO<027HC80RF<d0P2;ICH208YT=@80SFLh
00<0S6Hg08]U=P2:I3D00P29Hc@00`28HS<0S64g08aQ=`0208eR>00:08iS>@2?I3X0Sf@j091U>`2=
Hc40SV@b08mU<`2@IS@0TFLe099X=P80TfTg00@0S68`08mU<`2CJCL0UV`j0P2HKS`00`2GKC/0UV`j
09M^>P0209M^>P<0V6lk0P2IL3`01@2NMD40WGA009ed@02LLcl0Vg8n0080VW4m00@0VG0l09id@P2M
Ld40Vg4o0P2JL3h00`2KLCl0WG=109id@P0309]b?P<0VW4m0P2IL3`209E`?00409A_>`2CKSX0Tfhj
099]>@80TF`h00<0TfTg09AZ>02FK3X00P2HKS`00`2FK3X0U6Xh09=Y=`0209E^@`0309E_@P2EKd00
UFln0080UG0l00D0UG0k09=Y=`2DJSP0U6Xh09E[>@0209I/>P80Ufdk202AJch00`2?JcL0T6`h099^
>P0209=_>`04099^>P2AKCT0T6`h09=W>P80TVLj00<0TVTk091Z>`2?Jc/00P2>K3`208eY=`0608eY
>@2<IcX0S6Lk08aW?@2;IS`0RfDn0P2;IST0102:ICP0RF@g08QS=P27HSD208IQ=00307mM;@20GRh0
Pf4a00<0QF<c0P23HC401P22H300Oe/Y07mK:@1nFRX0OUT/07eH;080O5L]0240NeD^07IE:P1eE2/0
LU8Y06e@:01YCBH0ID/V06=99P1QBBD0GDHV05]4901F@B80DchQ04lk801<>b40Bc/Q04/k8P17>240
ASLP048f800o=1h0>S8M03L`7@0e;Q`0<bhK02TY7`0Z:R00;2`R02d]8`0/;280:RXP02PX7P0W9ad0
0`0W:20202HW7`<09BHN200R9Ah801lR6`P08R<K00H09BHP02@U7`0T9Al08b@N028S7@0Q8Q`2020Q
6`8082<L0P0O8Q/401hQ6P806adJ0`0L7Q/301dO7003024R7@0P8A`07QlJ00<07AhI00<07b0K020Q
700R8QX00P0S8a/00`0T91`09BDM02HV7P0202LW7`0<02h/5`0]:aH0;2XE02`Z5@0^;1L0<BlJ03Dc
7P0g=B00;blU02`/8P0Y:Al09BDK0P0T91X01`0U9A/09RHL02@[6@0T:aT09b/J02T/6`0[;1`00P0_
;Ah00`0a;Ql0=R/I03DZ600203@Y5`0503DZ600g;1X0>BhL03/`7P0k<1`00`0l<Ad203db7P<0?S<O
00<0@3@L044e7@14>2000`16>R801014>200@cLO04Xh8P1:>28204/i8`<0C3XT00L0CC/U04Dn8@15
?R40AChQ04@m8013?1l0@S/N0080@CXM00<0A3TU04<h9010=B400`0n<al00`10=B40@CHR03di7002
03di7080?3PK0`0k=aX203di7P0603`h7`0k=ah0>SDO03Td800i=240>3<P0`0`<Al4034b800A038c
8@0a<R@0;2dO02TZ700Z:ad0;RlQ02l`8P0/;Al09bPJ02T[7@0Z;1h0:bdO02`^800[;Al0:R`N02PZ
700W:A/0200/;ah07P0^<1/0;BhL02`_7P0Z;R00:B`Q02H[900T:b@092XV02Db600T<AL09S0H02H^
6@0W:aX09bXI02HX6P0W:1X072HK01lW700Q9ad092DM02TV7`0/9Al0;RDP030U8@0_9B@0<2HT038Y
900d:b80=2`O03@]7@80<R/H00@0<R`B03D_5@0h<QP0>cDK100n>1h0201>=B40C3DS04Xe8P17=2<0
@c<S03lc8`0l<b@0>c@T200i=AX0200g;1H0>2dG03X_6@0k<1X0>RlI03T^600g;1H0=BXD0P0k=1X2
03`e6`<0?CHL00@0?SLM03de7P0m=Ah0?CDN0`0l=1d303/c7004048d5`13=AP0@cDH04@f6@80ACLJ
0P16>1/204<d7`80@S<N00`0@C8M040a7010<A`0?c0K03ld7P0n<ad0?34K03/`6P0l<A/0?C8L03ld
7P11=R0203df700403hg7@0o>1h0?cPN040i7`80@CXP00`0B3PQ04Ti8P1;>b80CCdS04m08`1B@b@0
Dd@S05A5901G@b80FDDT05]79P1MBBP205i::@0J05a89`1KAbH0FdTQ05i;8`1QCRH0IDlX06Q@:P1Y
CbX0JThY06U=:01XDRT0Ie4X06M@9`1WCRH0JDdV06a>:01]CbT0L50Z06MA8P1YDB<0JU8T06eB9@1`
DbL0Le@X07ED:@1fEBX207AI;PD0LeP]00<0LUL/079K;`1cG3000P1dGC400`1cG300LEX^06mH;004
06iG:`0306mH;01`FBd0LEX^0080LEX^0P1`EBX3075F:`<0LUL/0`1aEbH00`1`ERD0KeDT06iD8`02
06iD8`0907=H;@1bEb`0LEH[06mD:@1/DBH0JTlT06U>8`1XCB80HdhS0080HddT00<0HT`U069<9`1Q
BRP00P1QBRX805m79@0805e6901KAb@0FTHS05Q68P1EAB40DdDP0596801AAAl305A4800305=5801B
AR00D4LP0080CdLP00@0CDPP05927P1C@al0EDDQ0`1GAb<00`1EAB40E4@P05I6900705I690D0EdLS
0`1FAR8805=48`0504m4901>@b<0CD8R04]0801:?al00`19?Qh204Ln8@80B3lR00H0AchQ04@k7P11
>1/0?cHI04<l8012>al2044j7P0<040i7@0o>1`0?SLK03hg6`0j=Al0>C@N03Lb700f<A/0=C0J03Ha
6`0g<Q`0>3<M100^<1X402la6`0;030_6P0`;a/0;BlJ02X]6P0Y;1/09b/L02@Z700S:A/08B@I02<V
6`0T9a`00P0U:1d00`0S9Q/08B@I01lR5`02020S6P0401lR6@0N8AP07B0G01`O5P806ahE0P0H7QX3
01LM6@<05Q`H0P0G7A/201HL6P805A/I0P0D6QP801LI60P05QLI0P0C6AT3018H60<04ALG6@0D5AL8
00lE5@P051DG0P0E5QP201@E5`804a@F2P0B4aD801<D5TP051DG400E5QP801@E5`T05AHH200E5aH3
01@F5@<05ALF2P0F61L801TK6P8061PH0P0I6AT201XJ6P806a/K0`0I6aP301XL6@806adJ200J6QP8
01/K6@P07AhH0`0K71H201`M5`/07AhH0P0N7AP201lN6@8081lJ0P0Q81/8024Q6@P09B0J200R8QX0
0`0P81P07alG01hN5P0201dM5@0301hN5P0O7aL0820H0080824K0P0O81X201hO6@807AhH200O81X9
020O6P807AhH0P0N7aT201lP6P80824K100O7QT201hM60807A`G200Q81/3020P60<08B4I0P0R8QX8
02DP6P0802HO5`0W81P0:24I02TR6P0Z8a/0:b@L02`U7@0]9Qh202hS7@80;b@N100`9Al02P0`91P0
<BDI038V6P0d:1`0=RXN03P/800i;B40>RhR03L^7@0f;A`303D/6`0303L^7@0i<1l0>S4P0080?C8P
00@0?34O03/`7P0i;Q`0>2dK0P0g;1X503LY80<0>2XQ0P0g:Ah0100f:Qh0=2XN038Z7@0a:ad202l/
7@0803D[8@0d:R00<RPN030V700_9A/0<2HL038X7P0c:Al302dV7P80;2DM0`0[91`202hW7`0402dV
7P0/9Ad0;2DM02/T7080:R<K200X8AT302PT6`P0:BDL0P0Z9Qd302/W7P80:RHM0`0Y9A`402PT6`03
02/W7P0Z9Qd0:2@K00809b<J00<0:2@K02XV7@0[9ah00P0Z9Qd302TU70H0:2@K0`0Y9A`202XV7@P0
9RHL00@0<b`T034Z8P0_:200;2DM0P0[91`02P0/9Ad0;BHN02hQ600]8aT0;bDK02lW700^:1`0:bLK
02PV6@0W9AP802hS7`80<2HL0P0a9ad0100b:1h0<bTO03<Y7`0d:R02030Z7P80;bTM0`0^:1`00`0]
9a/0;bDK030V7002030V7080<BLM0P0b:1h203DY7@<0=RXN0`0g:al803H/80<0<RdJ00<0<bhK03@_
700e<1d00P0e<1d803P/7080>blQ00@0>blO03/`7P0k<1h0>c0L0P0k<1X00`0o<R40?S4P03d`7`02
03d`7`0303lb8@11=2<0@SDT0080?3DR00<0?CDR03ld8P10<b800P12<R801013<R80@3DQ040e8@10
=B4203ld80<0?S<O00H0@c0O048a7`12<Al0@C8O03lb7`0n<al303`d7`80@3<R0`0o<R4303ha80P0
@c4U2011=24303ha7P<0?c8O0P10<b0203`a6`0403`a7@0l<Al0>c0N03/_7`80>RhP00/0?S8R03da
8@0k;al0>RhN03T]7@0j;Qh0>blO03``800f:QX0>2`L03/_7`0203da8@0403X^7P0f:QX0=2PH03L[
7`80=B/O00<0=2`O038/7P0`;Ah00P0^;1d0200d:1P0=RXJ03X^7P0n<R80?c<S03da8@0j;Qh0>2`L
0`0c<1d[ooooo`00:_ooool00`2HK3/0VFdl09]_?P0209a`?`0309]_?P2IKC`0V6`k00P0VVhm0P2N
LT4209ea@080W70o0P2KKch209Ua?P0809]a?`2LL3l0Wg500:1`@02QLD40Xg1109if@`2OMd@30:1h
A@0309if@`2LM440VW8o00<0WG=10P2NM48309me@`060:1cB@2PM4L0X7A70:1dA@2PM4<0X7E20P2P
MD00102PM4<0XGE40:5eA02QMD@20:9fA@80XgM60P2TN4T20:=gB080XWI70P2QMDH90:5gA@030:Eg
AP2TMTD0XgE40080XWA300<0XgE40:AfA@2UMdH0202PMT@00`2OM4L0X7E80:5fB@020:9gBP030:1e
B02NLdH0WG950080V79300@0Ug5209E_@02DKSl0TV`m102AJc`01`2@JS/0SfTj08eW>02<ISL0RfDf
08YT=@26H3<00`27HC@03@25Gc80Ped`081J;@1nF2/0P5de07mL=01nFc<0OEXb07]H<01jEbl0NEH^
07QE;@1kEC000P1hEBl01@1fE2h0Le</071C:`1_Db/0KU8Z00@0LE0]0P1`Cb`206m>:`<0KTdZ0P1]
C2T306a;:080K4//00`0KD`[06m>:`1`D2X0LU8[07=C;01cDbX0MU@_07QF<01kF380P5Xc089M<`24
GC8208IM<@0808AL>@24G3P0QEdi08MP>@28HCP0RF8g08YT=`2;ICP208mT=`<0T6Dh0`2AIST209=X
>`80TVLj0P2AIST2091U>00408mT=`2@ICP0TVLj09EZ?@80UV/n00<0UFXm09AY?02@ICP00P2AIST0
1@2BIcX0TfPk09AY?02DJC`0UFXm00<0T6Hd0`2?IC<208iT<PT0RV@e00@0Q5h_08IP<@28HS<0RV@e
0P2;ICH208YT=@80S6Hg0`2;ICH308YT=@0308aQ=`2=HSP0SF8h0080SV<i0P2?I3X01`2@IC/0SV@b
08iT<P2?IC<0T6Hd095W=@2BJ3H00P2CJCL0102?IC<0TFLe09=Y=`2EJcT409I/>P<0Ufhj0`2HKc/2
09U`?0@0W7<o102KLSh00`2MLd40W79009Y`?P0209U_?@0309Y`?P2LLT00WG=100<0Vg8n0`2JLCd2
09U`?00309Ia?@2EL3`0UG0l0080U6lk0P2CKSX0102BKCT0U6Xh09E[>@2FK3X209M]>`0309I/>P2E
JcT0U6Xh0080UFi300<0UFm209E_@02EKch00P2EL3`01@2EL3/0U6Xh09AZ>02DJSP0UF/i0080UV`j
0P2GKC/8095[?00308m[=`2@K3P0TVhj0080Tflk00@0TVhj095]>@2@K3P0TfLj0P2BIcX00`2BJC/0
T6Xk091/?00208i/?080SFTg00H0SFTi08aW>P2<Ic/0S6Lm08]V?02;ICh208]V>@0408YU>029I3L0
R6<f08MR=@80QV4d00<0P5h^089P<023HC400P24HS801@23HC40PV0`089P<021Gbl0OE`Y0080O5XZ
00<0NeT[07YH:`1iER`00P1iERh06`1eE2/0Le<Z075A:P1]D2P0JDdV06A:9@1QBBD0H4PT05a59@1J
@b@0ED0Q054n801<>al0BSXP04Xj8@19>b40ASLP04<g7`12=R00?S<O03Xb7`0f;ad0<bhK038/700X
:1h0:BTO02XZ800202/[8@0302TY7`0W9ad09RHL00809bPP0P0V9al302DV7P0302@U7@0Q91d08B@M
00H08B@M200O8Q/8028S6`8092DO0P0S91h0100R8ad08B8L020Q6`0P8A/2020S70807b8K0`0N8AX0
0`0M81T06adJ01/M6P0301`N6`<07AlL00<08B8M020Q700N7aX00P0M7QT00`0N7aX07b0K020Q7002
02<S6@8092@J00@09BDK02HV700W9ad09bLM100^:aP0200_;1T0<BhK03<`7@0d<Ah0:b/Q02XZ800X
:1h09RHL0`0U9A/01`0V9Q`092/I02L[6P0X;1/0:RdL02`]7@0_;Ah00P0a;Ql203H[6@<0=BXH00<0
=b`J03X_7@0k<1h00`0l<Ad203db7P@0?S<O00P0@3@L048f7P14>200ACTQ04Hj8P15>B40A3PP04<g
7`<0BCTR0P1:>R<304/k900;04Ho8P15?R40A3dP04<l7`12>ah0@CXM040i700o>1/0@SXU040h8`0n
=R400`0l=1l00`0m=B00?SHQ03di7P0203di7P80?3PM0`0k=a`0200m>Ah0?3PM03`h7`0k=R00>SDQ
03Td8@0h<b00>38R1`0`<Al0300a<R00<34S02`]7`0Y:Q`0:R/M02d^800^;b40:b`N02LX6P0W:A/0
:B/M02X/7P80:bdO00<0:R`N02T[7@0X:Q`0200[;Qd0200Y:QP0:2TG02LZ6@0V:1/092LL02<V7`0P
9Al07b@N0P0P:AH00`0P9aD08BDF024S5@02024Q5@0E028P500P9QP08RHH02<U600T91P0:2@I02XS
6@0[8QT0;B<J034W7@0c:Ad0=B`M03L^7@0i<A`0>C4J03Pa5`0h<AD0@SLI04@i6`16>ad0B3dO0080
BSlQ0P19?R00201A?240D3XR04hj8@19>B00ASLP048g8@0o=b80?SHQ200k=A/00`0m<A/0?S8L040d
7P02040d7P0303lc7@0m<A/0?30J00<0@CLN0P12>1l304<i80H0@SPO0`13>B0204Dg6P80ASPK00@0
AcTL04Pj7@18>Qd0B3XM0`16=b000`15=Ql0A3DN04@e7P0204<d7@0804@h8012=Qh0@CDM040d700o
<a/0@CDM048f7P13=al803lh7P80AcLP00X0BCTP04/k8@1=?R40Cd0Q05528@1B@b80ED4P05I28@1I
AB@0FdLV0P1LB2L205]79P0H05]98@1LBR80Gd`T06==9P1UCBL0IT`W06E;9P1VBRD0I54W06E?9P1T
CRD0IDhU06I=9@1ZCRL0KDlY06i@:P1XDR<0JE<T06YB901^DbH0L5<W07=D:01dEBT0ME@Y1@1dFBh3
07=H;@08075J;P1bFbl0Le``07AM<@1cG300LU/_071I;@1_F2`306iG:`0306mH;01`FBd0L5T]0080
LEX^0P1`EBX3075F:`<0LUL/0`1bF2L00`1aEbH0L5HU071F9@0206mE900607=H;@1bEb`0LEH[06mD
:@1]DRL0Je0U0P1YCR<206A?900306==901SCBH0HT`W0080HT/Y00<0HDXZ06189P1PB2H01P1PB2H0
201NAbD0GDHT05]7901IAb<0ETHR05A68@1CAB00DTHP0`1DA200101CAB00DTHP0517801@Ab0204m7
800305=37`1DA200ETHR0080F4PT00<0EdLS05I68P1EAB40201FAR@205Q890@0EdLS0P1FAR8805=4
8`0604m4901>@b<0CD8R04a18@1;@200BSlO0P19?Qh02@17?R40B3lR04U08`18?b80AchQ04@k7P12
>A`0@3LJ048k7`02044j7P03040i7@0o>1`0?SLK0080?CHJ00P0>SDO03Td7P0g<Q`0=S4K03D`6P0f
<A/0=c8L03Pc7@<0;S0J1@0_<A/0400`;aX0<2lK02d_6P0Z;AX0:B`K02L[700T:Q`08bTK028U6P0S
9Q/092LL02DX7@0T9a`08bHK024T6@0P8aP2020S6P0301lR6@0N8AP07B0G008071lF00@06ahE01PN
6P0H7QX061hJ0P0G7AT301HL60805adK0P0F71X201DK6@8051XH200G6AP801HG6@804aTI0`0B61P3
014G5aT051DG200?5AD801@E5`805AHH0P0D5AL201<D5PX04Q<E200C51I801@E5a005AHH200D5AL9
01DF60P05ALF0`0D5QD201DG5P/05QPG200I6aX201PH60806ATI0P0J6QX201/K6`<06A/H0`0J71T2
01/M6PP06QXH200K6aT801dN60806a`F0`0L7AL;01dN60807QdH0P0O7QT2020O6P808B0K200Q8AT8
02DP6PP08R8J0P0P81P4024Q6@80820H0P0P8A/201lP6P807QlI0P0M7QP801lP6PT081lJ0P0M7QP2
01hO6@807b0J0P0P8A/0100P7aX07ahI01lN6@0O7QT201hM60807A`G200Q81/3020P60<08B4I0P0R
8QX802DP6P<0:24I00<0:B8J02XS6`0[91`00P0/9Ad202hS7@80;b@N0`0`9Al0300a9R00<RHJ038V
6P0c9a/0=BTM03HZ7P0g:al0>2`P03T]8@0h;ah0=bhM03H]7080=B`K00<0=bhM03T`7`0j<B000P0n
<B001P0m<1l0?2lN03/^7@0j;A`0>B`K03P[6P<0=bTN1@0h:Ql203HX7@0403DY7@0c:Ad0<RXM030Z
7080;R/L00<0=B/Q03@Z800b:1h00`0`9Q`2038X7P<0;BHN0`0/9Ad202/T700302hW7`0]9Qh0;BHN
0080;2DM0P0[91`00`0Z8a/0:B8J02TR6P0602TR6P80:2@K2@0Y9A`302XV7@80:bLN0P0Z9Qd302TU
70@0:2@K00<0:bLN02XV7@0X91/00P0W8aX00`0X91/0:RHM02/W7P0302XV7@80:BDL1P0X91/202TU
70<0:RHM200V9Q`0100b:b<0<2TQ02hW7`0/9Ad202/T7080;2DM00P0;b8I02hT6P0_9A/0;bLL02hX
700[9a/0:BLJ02PV6@P0;b@N00<0<2HL034W7@0a9ad00P0b:1h203<Y7`0303@Z800`:Qh0<2XN0080
;bTM100^:1`4030V7080<BLM0P0b:1h203DY7@<0=RXN0`0g:al803H/800303</6P0d;A/0=2dK0080
=BhL0P0f;ad00`0g<1h0>2`L03P/700603P/7080>RhP00@0>blO03/`7P0l<Al0?34M0P0m<Q`00`10
<b80?c8Q03ha800203d`7`0403lb8@11=2<0@SDT03dg8@80?SHQ00<0@3DQ044d8@13=2400P14<b43
044d8@<0@3<P0P0o<Ql01P13<1l0@S4O048a7`11<Ql0?c8O03hc7`<0?3@O0P10<b8303lb8@<0?S4P
2013<BD8044d8@<0?S4N0`0o<Ql2040c800603db700l<A/0?34M03`a7`0k<1h0>blO0P0j;R004@0n
<R80?C4Q03/_7`0j;Qh0>BdM03X^7P0k;al0?30P03HZ6P0h;1`0>blO03da8@0l<200>RhN03HZ6P0d
:1P0>2`P0080=B/O00<0=2`O038/7P0`;Ah00P0^;1d0200d:1P0=b/K03X^7P0m<B40?S8R03da8@0k
;al0>BdM0`0c<1d[ooooo`00:_ooool00`2HK3/0VFdl09]_?P0209a`?`0409]_?P2IKC`0V6`k09Q/
>`80VFdl00H0VVhm09]_?P2LL3l0W70o09ea@02NLT4309ea@0<0W70o00H0Vfln09Ua?P2JLSl0Vg4o
09a`?`2OLD020:1`@0030:=`@@2OMD<0WgE300<0X7I400<0WgE309ec@@2LLT000`2MLd4209id@P<0
WgE300H0X7=90:1dA`2PM4L0X7A50:1d@`2PMD820:1e@080X7A300<0XGE40:9fA@2RMTD00`2RMTD3
0:=gAP<0XWI50P2QMD@90:5gA@030:=gAP2RMTD0XGE40080X7A300<0XGE40:9fA@2SMdH0202PMT@0
0`2NLdH0WgA709mdA`0209mdA`0909icAP2LLD@0Vg1309Qb@`2GLD80UW1109E_@02CKCh0TV`m0080
TF/l00P0T6Xk08mY>P2>J3T0SFLh08]U=P2:I3D0RF<d08QR<`<0QV0c00/0QElb08AN<@22G2l0P5X]
07mI;01oG3@0OU/c07eJ<P1lFC40NeP`07UF;P0207QE;@0807YD;`1hEBl0Me@^07EC;@1cDb`0L5<[
06mC:`1^DRX3075@;@80L4l/1P1_CR/206i=:P<0KD`Y00P0JTTZ06]::`1]C2/0Kdh[075A:`1cDb`0
MED^07IF;@80N5H`00H0NEH^07aG;@1nFBd0PU`_08IM;`27GS0208IN>P0408MP>@27H3L0R64f08QR
=@80RF<d0P2?I3L3091U>0<0TFHi0P2CJ3/2099W>P80TFHi0P2@ICP01@2=HSD0Sf@g095V>@2CJ3/0
U6Tl0080TfPk2@2BIcX2095W=@80T6Hd0`2?IC<00`2>I380S6Hg08aV=`0708aV=`0508EO<027HC80
RF<d08]U=P2<ISL00P2;ICH408YT=@<0RfDf0P2<ISL208eR=`80SV<h102?I3T208mU<`80T6Hd00D0
TFLe099X=P2CJCL0TfTg09AZ>00209=Y=`05099X=P2CJCL0U6Xh09I/>P2GKC/00`2GKSX309Q_>`80
VG0l102KLSh409ac?`80Vg4o00@0VW0n09U_?@2IKcd0VW0n0P2KLCl309]b?P<0VW4m0P2IL3`0102G
LSh0UW4m09Ia?@2FLCd309E`?00409A_>`2EJcT0UF/i09I/>P80Ufdk00<0UV`j09E[>@2EJcT00P2E
KT<00`2EKd80UFm009E_?P0209E`?00309E`>`2DJSP0U6Xh00<0UF/i0`2FK3X8099/?@03091/>02A
KCT0Tflk0080U70l00/0TVhj095]>@2@K3P0TfLj099W>P2CJ3/0TVTk095[?02@K3`0SV`l08m]?@02
08eY=`0608eY>@2<IcX0S6Lk08aW?@2;IS`0RfDn0P2;IST0102:ICP0RF@g08QS=P27HSD208IQ=006
08=Q<@24HS80Q68b08AR<P23HC40PEl_0P20GRh01`1oGBd0O5XZ07aJ:P1kFB/0NUP[07UF;01hEBd0
0P1gE2h03P1cDbX0LU8[06iA:@1ZCRL0ID/V069:9P1OB2H0GDHT05U49@1G@R<0DSlQ04dl801;>R00
BCTP0P17>242048f800403ld800k<b00=c0M03@_7080<2dL00<09bLM02PX7P0Y:Al00P0Y:Al00`0W
9ad09RHL02DU6`0302HW7`809BHN0`0T9Ad@01lR6`P08b@L0P0T9Al00`0S91h08R<M024R7002020Q
6`0401lP6P0O8Q/07b8K01lR6`807R4J0`0M81T201/M6P<071hK0`0M7a`00`0Q8Q`0824K01lP6P02
01hO6@0401lP6P0P8A/08R<M02<S6@8092@J00<09BDK02HV700W9ad00P0X:1h00`0_;1T0<2dJ034^
6`02038_7005034^6`0`;AX0;b`I02DU6`0V9Q`0100W9ad02`0V9Q`09BDK02P/6`0X;1/0:RdL02//
700^;1d0<2dN034^7`0c;Al0=b`J00<0=R/I00D0=b`J03T^700k<1h0?34O03`a7@0303db7P80?S<O
0`0o=2000`11=Ad0@SHN04@h800304Di8@80A3PP0`18>24204Ti8P<0BSXS00H0Ad0T04Ho8`14?B40
@S/O040i7@0o>1`203hg6`05040h8`0o=b80?SHQ03de800l=1l00P0m=B00100n=R40?3PM03`h7@0l
>1d203/g70<0>SHK0P0k=ah01P0j=Al0>C@P03Pc7`0g<Ql0=c4Q03H`80P0;c0P00@0;RlQ02//7P0Y
:Q`0:R/M0P0/;Al01@0Z:ad0:2TK02DW6@0W:A/0:B/M00<0:bdO2P0Z;1h202HY600;02DW6@0T9QT0
8bDJ028S6`0Q8Q`0824K024T6@0P8aP08B<H024Q5`0S81L00P0S7aH01P0U7QH09bHB02PW4`0Y9Q<0
;2LD02dV5080;bHE00H0<BDE03/a5P0m<aP0@3LJ04<j6`15?1/204Hn6P0304Hn6@1JAR<0FdLT00@0
G4PU00X0FdLT05Y68`1E@al0ED<O05517`1>?ah0BchN04Ll7P14>a`0@cXM200n=ad00`13=al0A3PP
04Di8@0304Di8@0404@h8013=al0ACTO04Di7`80ASXP0`17>b401`18?280ASXP04Hj8016>R00Ac/Q
04Pl8P19?B<00`1:?R@304/l7@80C3dN0`1=?Ql0101=?B@0C3`S04`l8`1<?2<304/k8P0504Xj8@1:
?R@0BCdS04Lk8@16>R001015>Al204@j7`0304<i7P12>1d0@CLL0080@3HK00h0?cDJ04De7P16=Ql0
AcLN04Ti7`1:>ah0C3dN04dn7@1>?ah0D3dM054n7P1D@B40ET<S05Q59@<0FDHV00P0F4TR05]98`1L
BR@0GTXU061:9@1PB2@0H4HS05m58P80H4dU00h0HD/T069:901TBRD0JDdX06]?:P1^D2`0J5<V06UD
9`1ZDbL0K5@X06iC:01`DbT0LU8Y07=C:PP0M5T^00P0KUL[06mH;01aFRh0LU/_07=L<01bFbl0LEX^
071I;@<0KUL[0P1_F2`3071I;@80L5DZ0`1aER/3079G;00407AJ:@1cFBP0LeTX07=I:0<0LUPW0140
LELV07=H;@1cF2d0LEH[071E:P1^DbP0K54V06]@9@1ZCb@0IE0S06E@9@1TCb@0I4hU06==9P1SCBP0
Hd`Z069;:@0806599@080618901OBB@0GTPS05]78P1IAb40ETLP05E7801DAQl305M58@0305E58@1D
AR40DdLQ0080DDPQ00@0D4PQ05E58@1FAR80EdLS0`1IBBD00`1HB2@0EdLS05M78`0705M78`0405U9
9@1HB2@0F4PT05Q89080EdLS0P1FAR8805=48`<0CT<S00<0CD8R04a18@1;@2000P1:?al304U08`05
04Po8P17?R40AC`O04<j7@11>1/00P10>Ad203lh700703hg6`0m=QX0?3DI03`e6@0k=R00>SDO03Pc
7@0303Ha6`80>3<M200_<A/02@0`;aX0<2lK02d_6P0Z;AX0:B`K02L[700T:Q`08bTK02<V6`0202@W
700502DX7@0T9a`08bHK028U6P0Q91T00P0P8aX201lR6@0501hQ600M81L071lF01`O5P0I7a/00`0H
7QX201LM6@805Q`H0P0G7A/201HL6P805A/I0P0D6QP801LI60P05QLI0P0C6AT3018H60<04ALG6@0D
5AL800lE5@P051DG0P0E5QP201@E5`804a@F2P0B4aD801<D5TP051DG400E5QP801@E5`T05AHH200E
5aH201@F5@805ALF0`0F61L00`0G6AP05QPG01HH5`0601HH5`P06A/J0P0H61P201TI6@806QXJ0P0K
6a/301TK60<06Q`I0P0K7AX801XJ60P06a/I200M7QP0100K71H071dG01`M5`0L7AL201dN60807QlI
200M7QP201hM60807ahI0P0P7aX2024P6`P08B4I200V8A/802<S6`03024Q6@0S8a/09BDM00809bLO
00<09BDM02<S6`0Q8AT00P0P8A/201lP6P807QlI0P0M7QP801lP6PT081lJ0P0M7QP201hO6@807b0J
0P0P8A/3020O6P807ahI0`0N7AP8020O6P<0820H0`0Q8AT2028R6PP09B0J200Z8a/302lT7P80<2DO
0`0a9R0203@X7080=BTM0P0f:Qh203L[7`0803X^7P0i;Ad0>2`L03L[6`0h;1`0>BdM03/_7`0l<202
03ha800303d`7`0l;ah0>bhM0080>RdL00<0>B`K03T[800h:Ql01P0h:Ql203HX7@0403@X700b:1`0
<2PK02lY6`80;2TJ00D0=2XP03<Y7`0b:1h0<BLM030V7002034W7@03038X7P0^9al0;RLO0080;BHN
0`0/9Ad0100[91`0;BHN02dV7P0]9Qh202`U7@<0:b@L200Y8QX802TU7080:2@K0P0Y9A`302XV7@03
02/W7P0Z9Qd0:RHM00<0:BDL100X91/00`0[9ah0:RHM02TU700202PT6`0402TU700Z9Qd0:bLN02/W
7P<0:RHM0P0Y9A`402PT6`80:BDL0`0Z9Qd00`0[9ah09RHL02HV700602HV7004030Y8@0_:200;BHN
02`U7@@0:b@L00P0;b8I02hT6P0`9Q`0<2PM02lY7@0/:1`0:BLJ02PV6@P0<2DO0P0a9ad2038X7P@0
<bTO0`0`:Qh202lY7@<0;RPL0`0`9Q`2034W7@<0<RPN0P0e:Ad303HZ7P<0=b/O200f;20403H]7080
=bhM0P0h;ah803P/700603P/7P0i;Al0>RhN03/`7P0l<Al0?S<O0P0o=1h02010<b80?c8Q03ha800m
<1l0?S4P03lb8@11=2<0@SDT0P10>2<00`12=b<0@cHS04Df8`0204He8`0304Ld8`12=B80@SDR0080
@C@Q0`10<b001`0o<Ql0@c0O048a7`12<Al0@C8O03lb7`0n<al00`0l=1l2040c8P<0?c8Q0`0n<B08
04<a8`P0@C@Q0`0n<Ah303lb7`80@3<P0P0m<Q`0100m<Qh0?34O03`a7`0k;al203/_8@0A03hb8P0m
<B40>blO03X^7P0i;Ad0>RhN03/_7`0l<200=b/K03T]7@0k;al0?C4Q03``800j;Qh0=b/K03DY6@0h
;2000P0f;2000`0d;1l0<bdO030]7P0202l]7P0803DY6@0g:a/0>RhN03da8@0n<R80?C4Q03/_7`0j
;Qh303Ha7R_ooooo000Zooooo`0309Q/>`2IKC`0Vfln0080W70o00<0Vfln09U]?02HK3/00P2HK3/0
102IKC`0VVhm09a`?`2MLD0209ib@@@0WG50102LL3l209Yb?`0309]a?`2LL3l0Wg500080X71000<0
XVm009mc@P2OLd800`2PM4<209mc@P0409ib@@2MLd40WG=109ec@@80WWA20`2OMD<01P2PLdT0X7A7
0:1dA`2PM4D0X7A30:1e@P80X7E000<0Wg=20:1d@`2QMD@00`2SMdH00`2RMTD0XGE40:9gA0050:9g
A080XGI32P2RN4H01`2QMdD0X7I409me@`2OMD<0X7I40:5gA@2RN4H0202PMT@309icAP0509ebA@2L
LD@0Vg1309]`@`2JKd800P2GLD801P2FL440U6ho09=]?P2BK3d0TF/l091Z>`80SVPi00@0SFLh08]U
=P2:I3D0R68c0P27HC8208EO<P0608AN<@23GC00PU`_085K;P20FRd0OeT/0P1nFc<0101mFS80NeP`
07YG;`1hEBd207MD;00607UC;P1gE2h0MU<]07EC;@1cDb`0L5<[0P1_Db/2075@;@80L4l/0P1_CR/2
06i=:P80L4l/0`1_CR/306i=:P0@06U8:@1ZBBX0K4/Z06m>:`1bDR`0M5@]07IF;`1gEbh0NEP_07QG
;P1hEB/0NUDY07aG:P20FR/0QUd_08UQ<080R64j00<0R64h08QQ=P28HSD00P28HS<00`28HS40Sf@g
08mT=`03091U>0<0TFHi0P2CJ3/2099W>P80TFHi0P2@ICP0102=HSD0SV<f091U>02AIST2099W>P04
095V>@2@ICP0TfPk09=X>`<0TVLj0`2AIST3095W=@80T6Hd0`2?IC<908eW>00308MQ<P28HS<0RV@e
00<0S6Hg00<0RfDf08YT=@28HS<00P29Hc@00`2:I3D0RfDf08aV=`0208eW>080SV<f1P2?I3L3091V
=003095W=@2BJ3H0TVPf0080TfTg00<0Ufdk09E[>@2CJCL00P2AIcD00`2CJCL0UF/i09M]>`0309M^
>P<0V6lk0`2IL3`209Ya?@0509]b?P2LLcl0WGA009ed@02NMD400P2JL3h409U_?@80VW0n0`2KLSh3
09Ya?@80VG0l102GLSh409Ia?@<0UV`j0P2GKC/309I/>P80UFi300<0UFm209E_@02EKch00P2EL3`0
0`2EL3/0UF/i09E[>@0409E[>@80UV`j202BK3/00`2AKCT0TVhj09=_>`0209A`?00409=_>`2AKCT0
T6`h09AX>`80TfPk00<0TfXl095[?02@K3`00P2?KCd208eY=`0608eY>@2<IcX0S6Lk08aW?@2;IS`0
RfDn0P2;IST0102:ICP0RF@g08QS=P27HSD208IQ=00608IT=025Hc<0Q68b08=Q<@21Gbl0P5h^0P1n
G2`08@1mFb/0NUX[07YJ:`1iF2/0N5L/07MF;@1eDbd0M58/07AB;@1_DRX0KU4Y06]?:01VC2L0Hd/W
05m89P1MARH0FTHU05I1901C@280CSdQ04/j8017=ah0ACHO04<g7`13=b40?c@N03hc7`0k<b00>34N
03D`7@0a;Qd0;b`M02d[700502LW7@0302HV700U9A/09BDK00<09BHN0P0T9Ad302<T70P07B0I200P
8a`802<T700602@U7`0S91h08b@N028S7@0Q8Q`0824K0P0O81X201lR6`<07R4J0`0M81T201/M6P<0
71hK0`0M7a`00`0R8a/08B8J01lP600201lP6003020Q6@0R8a/08b@L008092@H00@09BDI02HV6P0W
9a/0:2PL0P0Y:Ad02`0`;A`0<BhM03<`7`0d<B00<c0O030]700]:QT0:bPG024Q5`0S8aT09RHL0080
:BTO00<0:2PN02HV700U9A/00P0Z;A`00`0/;Ad0;R`M030]7P0203<]7`0303@/7`0g;1X0=b`J0080
>2dK00D0>BhL03X_7@0l<Al0?34O03db7P0303hc7`80?c@P0`10=B4204<g7`H0A3PP0P15=Ql204Hg
80<0AcPQ00L0B3TR04M09P15?R@0@c`R040i7`0n=ad0?CHL0080?3DK0P0m=b4603`f80<0>cLN0`0j
=Qd303Te700503Td7P0h<al0=c8N03Ha7P0f<2000P0e;b4202h_8@@0;BhP0`0/;Al00`0[;1h0:R/M
02X[7@0202X[7@0602TZ700X:A/08bDG02DW6@0X:Q`0:R`N0`0[;Al00`0Z;1h0:2XM02PZ7@0602PZ
7@0602HZ700W:A`09RPK02HV6P0U9A/09b@K0P0V8aX202LT7`0D02PS7@0[91h0;2<L02`S700]8aX0
;R@K038[4@0c;180=BhD03T_5P0k<AP0?C<J040d7011=Ad0Cd<K05557@1DB200Ed/Q05U=8`1JCR@2
05Y?8P80KU8[00h0KE4Z06a@:@1[CbP0JDdV06Q<9@1WBb@0EdPM05E8701CAQ`0DD<L04i2701;?Q/0
BSdJ04Tl6PP0@3TO0P17>Al204Pj80<0BC/Q00@0B3XP04Ti7`19>Al0BCTO0P1:>R0304/k8@<0BS/N
00H0Bc`O04`m801>?b80Cd0S0511901A@RD3055180D0DT8Q00<0Dd8V05919@1B@BD01@1B@BD01P1B
A2L0DD<V05129@1>@2<0CClR04`n8@80BcdP00P0BChR04Pm8@17?200ACXN04<h7012=a/0@CHJ040e
6@80ACDN00@0ASHM04Lg7@19>Qd0BS/L0P1;?1/02@1;>Q`0C3/M04hm7`1@?b40DT4S05A39@1EA2H0
ETDW05I88`0205M78`0305U78`1IAB80Fd@R0080Fd<Q00T0G4XT05]98`1LB2<0GTPS06599@1TBRL0
IddZ06]>;01VDbP00P1XDbP00`1ZDbT0Je8Y06eA:@0206mB:P<0LeP]101dFBh01@1eFRl0K5DY06eF
:P1_F2`0LEX^0080LU/_00<0LEX^071I;@1^Eb/00`1^Eb/406mH;080L5DZ0`1aER/3079G;0P0M5XY
00H0M5T^07=H;@1bEb`0L5DZ06mD:@1]DRL206aA9P0606IA8P1VDB@0IU4T06E@9@1UCbH0I4hW0P1T
CRT8069:900606=9901RBR@0HDTS05m98P1LBB40FTPP0P1GB1l305Q48@0405M58@1EAB40E4HQ05=7
8@80DDPQ0P1GAb<00`1HB2@0FDTU05U99@0305U99@P0F4TR00@0FTXV05U99@1IBBD0F4PT0P1GAb<2
05I68PP0Dd@S0P1>@b<204m4900404i38`1=@R80Bd0P04Xo7`<0BT4T00D0B3lR04Ln8@15?1l0A3/N
04<j7@02040i7@0403lh700n=a/0?CHJ03`e6@80>c@H00P0>cHP03Xe7`0h<ad0=c8L03Ha6`0g<Q`0
>3<M03Td7P@0<38L100_<A/0200`;aX0<2lK02d_6P0Z;AX0:B`K02L[700T:Q`08bTK1@0T9a`00`0S
9Q/08RDJ028U6P02024T6`04020S6P0O8QT07R4H01dP5`8071lF0P0I7a/301PN6P<05adI0P0G7A/2
01HL6P805A/I0P0D6QP801LI60P05QLI0P0C6AT3018H60<04ALG6@0D5AL800lE5@P051DG0P0E5QP2
01@E5`804a@F2P0B4aD801<D5TP051DG8@0E5QP;01DG5P<05QPG0P0G6AP801HH5`P06A/J0P0H61P2
01TI6@806QXJ0P0K6a/301TK60<06Q`I0P0K7AX801/K6@P071`J200M7QP301`M5`807AhH0`0N7aT8
01dN60807QdH0P0O7QT2020O6P808B0K200R8QX802HQ6`P08b<K00<08R8J02DU7@0Y:B400P0[:b<0
0`0Y:B409BDM028R6P02020Q6`807b0J0P0N7aT201dN60P07b0J2@0P7aX201dN60807QlI0P0O81X2
020Q6`<081lJ0`0O7QT201hM60P081lJ0`0P81P3024Q6@808R8J200U81X0100/9Ad0:b@L02/T700[
91`302XS6`0302TR6P0_91h0;b@N00<0<2DO0`0a9R0803HZ7P0303/^7P0j;Ad0>B`L0080>B`L00@0
>bhN03d`800n<B40@30P0P0o;al203h^7P80?BdM00@0?2`L03X/7`0j;1l0>R`O100i:ah01`0h:Qd0
=RPM03HX7@0d:1`0<BLK030X6`0^:1X00P0[:1T203<Y7`80<RPN100a9ad302hW7`80;BHN2`0/9Ad8
02XS6`0302XV7@0Y9A`0:BDL0080:BDL1P0X91/202TU70D0:RHM0`0Y9A`402PT6`0302`X7`0Z9Qd0
:BDL0080:2@K00<0:BDL02XV7@0/:1l00P0[9ah302XV7@H0:BDL0`0Z9Qd202/W7PP09bLM0P0^9al0
0`0]9Qh0;2DM02/T700302/T7008030S6P0_9A/0<BLM034Y7P0`:Qh0;BTM02XX6`0Y9aX8034W7P80
<RPN1P0c:Al2034[7`80<2XN0P0_:Ad202hX7080<2HL0P0a9ad2038X7P80<bTO0P0e:Ad303HZ7P<0
=b/O200g;B4403L^7@@0>2lN200i;Ad203P/7P0803X^7P0k<1h0?C8P03ld8010=Al0@CHP040c8P0o
<R4303ha8003040c8P12=B@0@cHU0080A3TS00<0ACTS04Lh8`18=b<00P19=b<0101;=R<0A3DR04@e
8P14=B8204<d8@<0@S<P00H0A34P04<b8013<R00@S<P040c800o=20303de8080@3<R0`0o<R4303ha
80P0@c8R2010<b0303ha7P<0?c8O0P10<b0203db700403db7P0l<Al0?34O03``8080>blQ00/0?S8R
03da8@0k;al0>RhN03T]7@0j;Qh0>blO03``800i;Ad0>RhN03/_7`0203``800403X^7P0h;1`0=RXJ
03P/8080=R`P00<0=2`O03<]7`0a;Ql00P0_;Ah0200f:QX0>2`L03/_7`0m<B40?S8R03da8@0l<200
>blO0`0i<R0[ooooo`00:_ooool00`2HK3/0VFdl09]_?P0209a`?`0;09]_?P2IKC`0V6`k09Q/>`2I
KC`0VVhm09]_?P2LL3l0WG5009ib@@2OLd80102LL3l409ea@080Vg=000<0W79009ea@02NL3l00P2O
Kcl00`2QKSl0XG=20:5c@P030:1b@@80XG=200@0XWA309ec@@2MLd40WG=10P2NM48309me@`060:1c
B@2PM4L0X7A70:1dA@2PM4<0X7E20P2PMD000`2NLT40X7A30:9fA@020:AhA`030:=gAP2RMTD0X7A3
00H0XGI30P2RMd@90:9hAP030:5iAP2PN4D0WgM40080WWI300<0WgM40:1hA@2QNDH0202OMD<209md
A`0309ebA@2LLD@0Vg1300<0VVm200H0Ug5209I`@@2EKd00U6ho09=]?P2AJc`2091Z>`0;08iX>@2=
IcP0S6Hg08]U=P29Hc@0R68c08MQ<P26H340Q5ha08=M<022G2l00P21Fbh3081J;@80OEXb00@0O5Ta
07YG;`1iERh0Me@/0P1fDb/01P1hDRd0ME8/07EB;01dDR`0Le</071C:`80Ke<[0`1`Cb`206m>:`<0
KTdZ00@0L4l/06m>:`1_CR/0Kdh[0P1^CBX206e<:@0@06Y9:P1[BR/0KD`[06m>:`1bDR`0MED^07MG
<01hF2l0NEP]07QG;01hERT0NUDX07aH:021FbX0Qel^08UQ;P80R64h00<0R64f08QR=@29Hc@00P29
Hc800`29I300Sf@g08mT=`03091U>0<0TFHi0P2CJ3/2099W>P80TFHi0P2@ICP00`2=HSD0SV<f091U
>003095V>@0308mT=`2>HcH0TVLj0080TVLj0`2AIST2091U>080TVPf0P2AIcD2091V=080SfDc2@2=
IcP00`29Hc@0RV@e08]U=P0208eW>00408aV=`2;ICH0RV@e08QR<`80RF<d00<0RV@e08]U=P2<ISL0
0P2=IcP2091V=PH0SfDe0`2AIcD4099X=P0409=Y=`2GKC/0UF/i09=Y=`80TFLe00<0TfTg09E[>@2G
KC/00`2GKSX309Q_>`<0VG0l0P2JLCd01P2KLSh0W7<o09ed@02MM400WWE109U_?@H0VW0n00@0VFlm
09]b?P2KLSh0Vg8n0`2JLCd209U`?0@0UW4m102GLSh309M]>`80UV`j0`2GKC/209E^@`0309E_@P2E
Kd00UFln0080UG0l00<0UG0k09I/>P2FK3X01P2EJcT809=^>P80Tflk00`0U70l09Ea?@2DL3`0Tflk
095]>@2?JcL0U6Pk09=X>`2DJC`0TfXl095[?02AKCd208m]?@80SFTg00H0SFTi08aW>P2<Ic/0S6Lm
08]V?02;ICh208]V>@0408YU>029I3L0R6<f08MR=@80QV4d00H0QfDe08IT=024HS80PV0`081N;P1n
G2`307eK:`0P07UJ;01hFB/0MeP/07IF;@1dE2d0LU8/075A:`1aD2d0K50Y06]?:01WCBP0Hd/W0619
9`1KAbH0FD@U05M4901C?b@0CchR04`k8@17=ah0A3DN044e7`10=Al0@3DQ03Xb7@0j<Ql0=c0M03D`
7@0a;Qd0;R`M02d[7P0Z:ad202PX7P0302LW7@0V9Q`09RHL00<09RHL0`0T9Ad202<T70<08R<K200M
81T8020S70P092DM0P0S91h00`0R8ad08B8L020Q6`0201lP6P0401hO6@0N8AX07R4J01hQ6P<07B0I
0P0L7aP201/M6P<071hK0`0M7a`0200R91T08B<H020R5`0O8AH0828G028T6@0T9Q/09BLL0P0U9QP0
100V9aT09bPJ02PY6`0Y:Q`202X[7@0<030]7P0a;Ql0<RlP03<`8@0a;Ql0;R/L02XW600X9AH08B4G
02<S6@0W9ad0:BTO0P0Z:R001`0X:1h09bLM02d^7P0];Qh0;bdN034^7`0c;Al00P0d;1l01@0f;200
>2dK03P]6`0j;ad0>c0N0080?34O0P0m<R0203hc7`80?c@P0`10=B42044f8P0304Di8@14>200A3PP
00<0@cLO0P14>203048f7P80@cLO0`14>2002015?BH0@c/T040h8@0m=Ah0?3@M03/c700l=1d0?CDN
0P0j=Al603/f80@0>SDO0P0i=1h203Pc7@0603Lb700g<Qh0=S4M03Ha7P0e;al0=2hP0P0c;B400`0]
;B40;2`P02`/800202/[7`80:RXN00D0:BTM02X[7@0Z:ad0:b`N02X[7@0302PY6`0502TZ700S9AL0
9BLI02LY6`0Y:ad00P0[;Al202X/7PP09RPM0P0Q91T0100R91T08b<I02HR5`0X8AL202TP5`0F02`S
7P0]91d0;b@N034W7@0e:Ad0>2XM03/[700l;1`0ACDD04Hg5P19>QT0CChM05528@1DAbD0EdXX05Q;
:@1SEB@0IELV06MI:P1YFb`0Jed^06]M<080JU`_00P0M5H`079D;P1`DR`0KU0Z06a>:01ZC2H0JD/U
06Q:9080E4TL00H0DTHL0514701?@A`0CClL04/m6P1;>aX8048h7`@0AcLM00@0B3PN04Ti7`1:>R00
BSXP0`1<>1d204di7P<0CSXO0P1<>AT01@1=>QX0CS/K04ll701A?Qh0DSlO0080Dd0P101FAR@405E5
8`P0ETHU0100EdPW05I79P1FAbH0EDHU05=48`1B@b80DD8Q0511801>@2<0CClR04`n8@1:?1l0B3XM
04Hh6`15=aX0A3HI0P17=b001017=ah0B3PN04Tj7@19>Q/204Xk6P0:04/j7P1<>al0C3/O04hm8@1?
?R80DD0T05=29P1D@bL0DdHS05A68`80E4@R00d0ED8Q05I28@1H@B40F44Q05Q98P1GB240FDLQ05Y6
8@1MAb80H4PT069:9P1UBbP0HU4V0080He0V00<0IU0W06QA:01YD2P00P1/D2T3075F:`03079G;01c
F2d0LeP]0080M5T^00@0Je@X06aE:@1^Eb/0L5T]0P1aFRh00`1`FBd0KeP/06iG:`0706iG:`80L5DZ
0`1aER/3079G;0@0M5XY101eFbX02@1dFBh0LeP]079G;01aER/0L5DZ06mD:@1^DbP0KE8W06QD8P02
06MB8`0306MB9@1VDBH0IU0W0080IDlX201TCB@01P1WBb@0ID`T06A;8`1RBb80H4XQ05e:8080FdXO
0`1KA280101IAB80F4HR05I68P1EAb8205A88PD0F4PT00<0FDTU05Y:9P1JBRH0201HBB8205];9`06
05Y:9P1IBBD0F4PT05M78`1FAR80EDDQ201CA2<03P1=@R80CT<S05159@1AARH0D4DU04m4901=@R80
Bd0P04a39P1;@RD0BT4T04Po8P17?R40ASdP0P15?1l2040i7@0403lh700n=a/0?CHJ03df6P80?3DI
00<0?3LQ03/f800i=1h00`0g<Q`00`0h<ad0>C@N038d7P02034c7@80<38L0P0_<A/02P0^<1X0<2lJ
030_6`0];aX0:RdJ02T/6`0W:a`092XL02<Y6`0V:Ah202DX7@0302@W700S9Q/08bHK00808bHK0P0Q
91/0100P8aX07b8I01lR6@0N8AP201dP5`<06AlK0`0H7QX201LM6@805adK0P0F71X201DK6@8051XH
200G6AP801HG6@804aTI0`0B61P3014G5aT051DG200?5AD801@E5`805AHH0P0D5AL201<D5Q804Q<E
B00D5ALQ01DF60X05ALF0`0F61L301LI60P05QPG200I6aX201PH60806ATI0P0J6QX201/K6`<06A/H
0`0J71T201/M6PP06a/I200L71X801dN608071dG0P0M7QP201hO6@807b0J200M7QP201hM60807ahI
0P0P7aX2024P6`P08R8J200W8Q`802@T7003028R6P0U9Ad0:BTQ0080;2`T00<0:BTQ02DU7@0R8QX0
0P0P8A/201lP6P807QlI0P0M7QP801lP6PT081lJ0P0M7QP201hO6@807b0J0P0P8A/2024P6`<081lJ
2`0O7QT3020P60<08B4I0P0R8QX802DP6P<0;2DM0P0[91`302XS6`<0<2DO0`0a9R02038W8@@0=RXN
100g:al0200n;Ql0?BdN03`/7@0k:a`0?2`M03d]7P0o;b00@30Q1010;al403l^7P80?2lO0P0k;Qh0
100j;Ad0>B`L03T/700i;1`203LY7P0403DY7@0b:1`0<2PK02hX6P80:bPI0`0c:Al2038X7P80<BLM
00<0<2HL02lX800_:2000P0^9al202dV7PX0;2DM200[91`302XV7@0302TU700X91/0:2@K00@09b<J
0P0X91/202TU70@0:RHM0`0Y9A`402PT6`0302`X7`0[9ah0:RHM0080:2@K00<0:RHM02/W7P0/:1l0
0`0[9ah302XV7@@0:BDL0`0Z9Qd302/W7PP09bLM100^9al202dV7P80;2DM00P0<B@K030V700b:1h0
<RXO034[7`0^:Qh0:bTL02XX6`P0<RPN0P0d:R0603<Y7`<0<B/O0P0`:Qh302lY7@<0<BLM0P0b:1h3
03<Y7`80=BTM0`0f:Qh303L[7`P0=bdQ100k;al403X^7PP0>BdM00H0>2`N03T]7`0j;Qh0?34O03hc
8@0o=202044f8008044d8`10<b80?c8Q03ha800o<R40@3<R048e9013=RD204Hj8P0604Pi8P19>B80
BSPR04Xh8P1<=b80CCLR0P16=B<204Dd8P80A3<Q0P13<R001P14<B00@c8P04<b8012<b00@3<P03ld
80<0?CDP0P10<b8303lb8@<0?S4P2013<R88040c80<0?S4N0`0o<Ql2040c8080?S<M00@0?C8N03db
800m<R00?30P0P0l<2802@0n<R80?C4Q03/_7`0j;Qh0>BdM03X^7P0k;al0?30P03X^7P0203/_7`0;
03``800k;al0>RhN03T]7@0h;1`0>BdQ03L]8@0f;200=BdP03@^800a;Ql00P0`;Ql0100h;1`0>BdM
03/_7`0l<20403da8@<0>c8Q:oooool002[ooooo00<0V6`k09U]?02KKch00P2LL3l00`2KKch0VFdl
09Q/>`0209Y^?@0409]_?P2LL3l0W70o09ea@080WW9100@0Vfln09a`?`2LL3l0W70o0`2MLD001P2N
LT40W7A109]c@02LLT00WG5009i`?`80Wflo00<0X6dn0:5a@@2QLD400`2PL4000`2QLD40Xg=30:Ad
A00309ec@@80WWA20`2OMD<01P2PLdT0X7A70:1dA`2PM4D0X7A30:1e@P80X7E000P0WG5009mc@P2R
MTD0Y7Q70:EiB02SMdH0XGE40:1d@`<0X7E00`2QMT420:9g@PT0XWQ600<0WgY609iiA@2MN4@00P2L
Md<00`2MN4@0WWU509mjAP0809me@`050:5fB@2PMDP0WW=609aaA02KL4<00`2JKd8209I`@@0609E_
@02DKSl0TV`m095[?02@JS/0SfTj0P2>J3T0102=IcP0RfDf08YT=@28HS<208MQ<P0408=M<022G2l0
PE/^081J;@80OeT/00/0P5X]085K;P1lFC40O5Ta07]H<01iERh0N5D]07MD;01fDb/0ME8Z07I@:`02
07AA:`0307=A:`1bDR/0L5<[0080Ke<[0P1`Cb`206m>:`<0KTdZ00@0KD`Y06i=:P1^CBX0KTdZ0P1]
C2T306a;:00806]::`1/Bb`0KTd/071?;01bDR`0M5@]07IF;`1gEbh207UH:`0;07YH:P1mFBT0Oe/Y
08=N:P27Gb`0RF4]08MP=@28HCH0R68e08US=029Hc800P2:IC400`2:IC00Sf@g08mT=`03091U>0<0
TFHi0P2CJ3/2099W>P80TFHi0P2@ICP00`2>HcH0Sf@g095V>@02099W>P03095V>@2?I3L0SV<f00P0
TFHi0`2BJ3H2095W=@<0T6Hd2@2<ISL00`2:I3D0RfDf08eW>00208iX>@0308eW>02;ICH0RV@e00<0
RV@e0`2;ICH208aV=`80TFLe0P2@IS@408mU<`P0TVPf00P0U6Xh09=Y=`2CJCL0TVPf09=Y=`2DJSP0
UV`j09M]>`<0Ufhj0`2HKc/209U`?0@0Vg8n102LLcl00`2JL3h0Vg4o09ab@00209ec@@0309ab@02K
LCl0VW0n00<0Vg8n0`2JLCd209U`?00409A_>`2EL3`0UG0l09E`?0<0UW4m00@0Ug8n09Q^?02HKS`0
Ufdk0P2FK3X00`2GKC/0V6hl09Q^?00209E^@`0309E_@P2EKd00UFln0080UG0l00@0UG0k09I/>P2F
K3X0UV`j0`2EJcT209AZ>0P0Tfhi0P2DL3`309Ea?@0409=_>`2@K3P0Sf/g09AX>`80U6Tl00<0TfXl
099/?@2AKCd00P2@KSh208eY=`0608eY>@2<IcX0S6Lk08aW?@2;IS`0RfDn0P2;IST0102:ICP0RF@g
08QS=P27HSD208IQ=00508MU=@25Hc<0Pf4a081N;P1oGBd0101nG2`08`1fFBd0MEP/07AG;@1bEBd0
L58/06mA;@1]Cb/0KDl]06U?:P1WCBP0I4`X065::01LB2L0F4DU05I38`1C@R@0CchT04`l8P19>B00
A3DN040d7P0n<al0>c<N03`d8@0g<1d0=RlM03@_700a;Qd0;R`M02//7P0Z:Qh0:2XM02XZ800Y:Al0
:2PN00<09RHL00<09bLM02PX7P0S91`00P0S91`2028S6`<08B8J200M81T8024T7@P092DM00H08b@N
028S7@0R8ad08B8L020Q6`0O81X201hO6@<07R4J0P0M81T301`O60806adJ0`0L7Q/301dO7008028T
6@0Q8aP0828G020R5`0Q8aP08bDJ02DW700V:1d202HW5`0302LX600X:AT0:BXJ0080:R/K00<0:b`L
030/800`;2000P0_:al0200]:Ad0:RHJ02PT600W8aL09RHL02LW7@0X:1h0:RXP0P0[:b4202XZ8005
030^7`0a;b00<RlP03@^800e;B000P0f;2001@0h;200>2dK03T^700k<1h0?C8P00<0?S<Q00<0?C8P
03ld800o=2000P10=B43044f8P80@SLS00D0ASXR04Di8@14>200@cLO048f7P0204<g7`0304@h800o
=A`0@3HM0080@3HM0P11=ah2048h7`0=04<k9P11>B@0?CDP03/c7P0j<Qd0>c<N03de800n=R40=S@M
03Le7P0h=Ql0>CLP03Xh8@0203Tg800303Pf7`0j=B40>C@P0080>C@P0P0h<al203Lb7P0603Ha7@0e
<1d0=C0M03@^7P0c;Al0<R`P0P0a:R001P0/;280:b/Q02/[8@0Z:R00:BTO02PX7P809bLM00`09bPJ
02X[7@0[;1h0:R/M02LX6P0U9QP09bPJ02TZ700T9QP09BLI02LY6`0Y:ad202X/7P0302T[7@0X:Q`0
9BHN00L09BHN02H061dF01TN5`0M7QH08AhE02DN500Y7aD0;20D02dO500c9a/0=RPK03P[6`0n;a`0
@S8K04Lf701;=a`0CCXL05e57`1NAR00H4XS065>9P1TDRX0IUL^06MJ<01YG380KUh[06mO;01`H2l0
LF0b071O<`1_GS<0KE/c06]I<@1[DC00JDl^06I<:`1SBBP0HDLV05m59080GT@S0P1<A1d01P1<@Qh0
C3lM04`m7P1<>al0CCTN04`h7`P0@cLO00T0B3LM04Lf7017=Q`0AcHL04Pg7@1:>Al0BcXP04`k8@1A
>Ad00`1B>Qh205<k7`80E3`P101C?1X00`1D?A/0EChL05Ho7@0205M07P<0FdTU0P1JB2@305U78`04
05Q68P1IAb<0FDLS05U78`<0FTPT00<0FdTU05U99@1IBBD00P1JBRH0101IBBD0EdLS05I68P1EAB42
0593900605118P1?@240CChO04/l7@1:>a`0BCXK0P1;>b@0101;>b80Bc/Q04/l7`1;?1d204/l6`80
C3`R00T0Bc/Q04`l8P1<?280CShT05109P1A@BL0DTDS05548P1A@R400P1A@B004`1D@B40ET4R05M2
8`1FB2<0EDLR05E58@1FA200F4@Q05]48P1MAR@0GdLU05Y;8P1MBb<0GT`T061=9@1TCRL0IThX06Q>
:@1YCbX00P1^DbP206mD:@07071E:P1aER/0LUL/079G;01[E2P0KEHZ06iG:`02071I;@0406mH;01^
Eb/0KEHZ06mH;0<0KUL[0`1]ERX00`1/EBT0L5DZ071E:P03075F:`<0LUL/0`1cFBP207AJ:@<0ME/Z
0P1dFBh0101cF2d0LUL/075F:`1`EBX206mD:@0606UE8P1YEB<0JEDS06QC901XDbH0Ie8W0P1WDBP8
06E>900606Y=9@1XC2@0J4`T06E<8`1SC280HD`Q0P1NBb001`1LA280Fd@R05]48P1KA280FDDR05Q6
8P1FAR800P1EAb800`1HB2@0EdLS05I68P0205I68P0305Q8901IBBD0FTXV00P0FDXQ0P1LC2P01P1K
BbL0FDTU05Q8901GAb<0ETHR05E58@P0Dd@S00<0C44Q04i38`1@ABD00P1BAbL01`1@ABD0CT<S04a1
8@1>ABP0CD@W04]29@19@2<01017?R401P12>al0@CXN044j7P10>Ad0?cPL03hg6`80?CHJ00T0?3LQ
03/f800i=1h0>3<M03Lb700h<ad0>C@N03Xe7`0c=Al00P0b=1h00`0a<ad0<38L02la6`0202h`6P0;
030_6P0`;a/0;BlJ02X]6P0Y;1/09b/L02@Z700S:A/09bXO02HY7P0U:1d00`0S9Q/202@W7006028U
700Q91/08B@K020S6P0O8QT07R4H0P0M81L201XP70806AlK0`0H7QX00`0G7AT05adK01LM6`0201HL
6P805A/I0P0D6QP801LI60P05QLI0P0C6AT3018H60<04ALG6@0D5AL800lE5@P051DG0P0E5QP201@E
5`804a@F4P0B4aE801@E5b405AHH2@0E5aH301HH5`805aTH0P0H6QT801HH5`P06A/J0P0H61P201TI
6@806QXJ0P0K6a/301TK60<06Q`I0P0K7AX801/K6@P07AdK2`0M7QP201hO6@<07b0J200M7QP201hM
60807ahI0P0P7aX2024P6`P08b<K200W8Q`802@T7003028R6P0T91`09bLO0080:2PP00<09bLO02@T
700R8QX00P0P8A/201lP6P807QlI0P0M7QP801lP6PT081lJ0P0M7QP201hO6@807b0J0P0P8A/3024P
6`8081lJ2`0O7QT3020P60<08B4I0P0R8QX802DP6PD0:b@L0`0/9Ad3030U7`80<BHP0`0b9b400`0e
:Ad0=RXN03HZ7P0203L[7`<0>2`P00<0?bdO03h/7P0m:ad00P0m:ad00`0o;Al0@2hP048`8P08044^
7`80?C0O0P0l;ah0100k;Qd0>RdL03T/6`0i;1/203T[800603L[7`0d:Qh0<BTL02lY6`0/:AX0:bPI
0P0b:1h303<Y7`03038X7P0`9Q`0;bDK00<0;bPP0P0^9al302dV7P<0:b@L0P0/9Ad302dV7PP0;2DM
0P0[9ah00`0Z9Qd0:BDL02PT6`0202LS6P0402HR6@0W8aX09b<J02LS6P80:2@K0`0Y9A`202XV7@<0
:BDL100X91/00`0/:1l0:bLN02XV7@0202TU700302XV7@0[9ah0;2PO0080;2PO0P0[9ah302XV7@80
:BDL0`0Z9Qd202/W7P80;2PO200X:1h00`0^9al0;bPP030Y8@03030Y8@80;RLO00P0<RDL034W7@0c
:Al0<b/P038/800_:al0;2XM02/Y70P0=2XN0P0e:b4203@Z80@0<bTO00@0<R`P034[7`0a:al0<B/O
0P0`:Qh202lY7@80<BLM0P0b:1h303<Y7`0303@Z800e:Ad0=BTM00<0=RXN0`0g:al803L]8@@0?C0P
0P0l;al203/^7PP0>BdM0P0j;R00200k;al0?C8P03hc8@0o=200@3DO044f8011=2<0@3<R0`0o<R40
0`11=2<0@SDT04@g9P0204Pj800404Ti801:>200BSPP04`h8080CCLP0`17=2<204Hc8P@0AC8Q0P14
<b400`13=240@C@Q040e8@0303hf8@80@3<R0`0o<R4303ha80P0@c8P200o<Ql303ha7P<0?c8O0P10
<b0203hc7@0403hc7`0m<R00?C8P03``8080?30R00P0?S8R03da8@0k;al0>RhN03T]7@0j;Qh0>blO
03``8080>blO00@0?30P03/_7`0k;al0>RhN0P0i;Ad01P0i;B40=bdQ03L]8@0e;B00=2hP034^7`80
<2hO00D0>BdM03X^7P0k;al0?30P03da8@0303hb8P<0?c<S:oooool002[ooooo00<0V6`k09U]?02K
Kch00P2LL3l00`2KKch0VFdl09Q/>`0609a`?`80WG500P2KKch209a`?`80WG500P2NLT4209ad@@08
09ab@02MLD00WW0o09m_?`2NKSh0X6dn0:5a@@2PL40309m_?`030:5a@@2SLd<0YGE500<0WG=10P2N
M48309me@`060:1cB@2PM4L0X7A70:1dA@2PM4<0X7E20P2PMD000`2MLD00Wg=20:9fA@020:EiB003
0:AhA`2QMD@0Wg=20080Wg@m0P2PMCh20:5f?`80XWM02@2SNDL00`2ONTH0WWU509ehA00209ag@`03
09ehA02NNDD0WgY600P0WWA200@0Y7U<0:9gBP2OM4L0WG950`2KL4<01`2LLD@0UW1109I`@@2EKd00
Tfdn099/?@2@JS/0102?JCX02@2>J3T0S6Hg08]U=P2:I3D0RF<d08QR<`23GC00PE/^081J;@0207iH
:`0<07mI;020FRd0PE/^07aI<@1kF300NUL_07UF;P1gE2`0MU<[07EB:P1dDBT0MU0[0P1dDB/00`1c
DB/0LU8[071C:`0206mC:`<0Kdh[0`1^CBX206e<:@<0K4/X0P1[BRL306Y99P80KTd^00`0Kdh]075@
;@1bDR`0M5@]07EE;P1eEB`0N5PY07YJ:`1mFb/0PUh^08AP;P26HBd208QP;080QV0c00H0Qf4b08US
=02:I3<0RfHb08aW<P2=J3<208mT=`<0T6Dh0`2AIST209=X>`80TVLj0P2AIST3091U>008095V>@2B
IcX0TfPk09=X>`2BIcX0T6Dh08mT=`2>HcH208mT=`05091U>02AIST0TVLj099W>P2CJ3/0102BJ3H2
095W=@80T6Hd2@2:I3D00`2;ICH0S6Hg08iX>@0208mY>P0308eW>02<ISL0RfDf0080S6Hg0`2;ICH3
08YT=@03099X=P2AIcD0TFLe0080T6Hd0P2?IC<00`2>I380TfTg09=Y=`0209=Y=`@0TVPf00@0SfDc
095W=@2CJCL0UF/i102FK3X309M^>P<0V6lk0P2IL3`409ac?`@0Vg8n00<0Vg4o09ab@02NM4800P2O
MD<00`2NM480W79009]a?`0309]b?P<0VW4m0P2IL3`00`2BKCT0Tfhj09=^>P0209A_>`80UG0l00@0
UW4m09U_?@2HKS`0Ufdk0P2FK3X00`2GKC/0V6hl09U_?@0209E^@`0309E_@P2EKd00UFln0080UG0l
00<0UG0k09M]>`2GKC/00P2FK3X0102EJcT0U6Xh09AZ>02DJSP809=^=`80UG4m0P2FLSh01@2ELCd0
Tflk091/>02?JcL0UFTl0080U6Tl00<0U6/m099/?@2BKSh00P2@KSh208eY=`0608eY>@2<IcX0S6Lk
08aW?@2;IS`0RfDn0P2;IST0102:ICP0RF@g08QS=P27HSD208IQ=00408IT=024HS80PEl_07mM;@80
OU`/0`1oGBd08`1eFRl0M5T^079F;P1`E2`0KU8[06a@:`1[CR`0JTd[06I>:P1UCBT0HT/Y05m8:01J
ABH0Ed@T05=2901B@B<0C3`S04Xj8@16=b00@CDM03db700j<Qd0>S8O03Tb7`0d;a`0<bhK030]700_
;1d0;B/N02XZ7P0X:Qd09bTN02`/8P0[:b40:BTO00809bLM00@0:2PN02TY7`0Z:R008b@L0`0R8a/2
024R6P80824I200N8AX8024T7@P09BHN0P0R8ad0100Q8Q`0824K01lP6P0O81X201hO6@0401hQ6P0M
81T07B0I01dP6@8071lH0P0K7QL201/M6P<071hK0`0M7a`0200R91L08B<F024S5P0Q8aH08R@G02@V
6@0V:1/0:2XM0P0W:1H0100X:AL0:BXH02X[6@0Z:aT202//6P0502l[800]:Ah0:bLL02TU6P0X91T0
0P0W8aP00`0X91T0;2`R02/[8@0302XZ800402/[8@0/;280;BdS038`8@80<c0Q00<0=2hP03D]800f
;2000P0h;2000`0i;Q`0>RlM03db800303ld8P80?S<Q0`10=B42044f8P@0@SLS00<0Ac/S04Hj8P14
>2000`12=Qh00`13=al0A3PP03`e6`0303df7080?SLM0P0o>1h00`10>2<0?SHQ03/c7P0203Ta7006
03/c7P0n=R40@3PS03<c6`0e=Ad0=cLO0`0i>B40100h>200=cLO03Td8@0i=24203Pc80<0=c8O00H0
=S4N03@_700d;a`0<bdM038/7P0a:al2030Y7`0702lX800[:b40:RXP02TY7`0X:1h09bLM02HV7002
02DU6`0;02HW6@0Y:Q`0;2dO02X[7@0U9QP08b@F02HW6@0Y:Q`09BLI02LY6`0X:Q`00P0Y:ad00`0X
:Q`09bTK02HX6P0802<T7P0@01/R6`0M8Q`08R<M02PU700^9A`0=2PL03TY700k:Ad0ACHQ04Ph8@1<
?280DT4S05U78`1PCBD0IE0U06QC9P80LeHZ00@0LeP[075K;01aG2d0Kel^0P1^H2l206mJ:`0;06iI
;P1]Ebh0JU@]06M@;P1SC2`0HDX[05a8;@1JAR/0ET8W05<o901@?2400`1?>b001P13?Ad0@c`O04Dl
7`17>Al0B3PQ04/f8`80Bc@T2014=Ah0201=>Ah0C3PM04/g701;=a`0C3PM04hj7`1A?B80DShS0`1I
@28205Y18`<0Fd8T101J@Qh505]37`80GTXW0P1MBBH0101LB2D0FdLT05]7901KAb@305U5800305Y6
8@1KAb80FdLR0080G4PS00<0FTPR05]98`1MBbD00P1NC2H02`1MBbD0FdTS05Y88P1EARD0E4DT05=4
8`1B@b80DD8Q0511801?@1l0CSlN0080CclX00T0CclV04hn901>?b80CSlP04ho7P1=?Qd0CT0U04do
901<?R<00P1:?2406`1<?R<0CClT04i09@1>A240CD<P04i17`1?@1l0DD4P05E28P1GA2@0FD@U05E8
9@1EAb@0DdDR05=38@1D@B00ET8Q05U28P1J@b<0EDHM05I77P1IAal0GDXR065;901SCBH0IThX06M?
:@0206]@9@0406aA9P1]DRL0KU<X06mD:@80L5DZ00<0KEHZ06iG:`1_F2`00P1_F2`00`1^Eb/0K5DY
06]D:00206mH;080KUL[00@0KEHZ06aE:@1/EBT0K5DY0P1`EBX3075F:`<0LUL/0P1aEbH2079H9`04
07=I:01dFRT0M5XY07AJ:@80M5T^00@0LeP]079G;01bEb`0LEH[0P1`EBX206YF8`0306YF901YE2D0
JE@W0080J5<X00<0J58Y06I?9@1VCbD01P1VCbD206]>9P0306U=9@1VCB@0I4dS0080HTdR00@0Gd`Q
05e58`1MAB<0GDDS0P1LAB<00`1JAR<0FDLS05M78`0205M78`0705I68P1EAB40E4@P05A4801FAR80
F4PT05U99@0805Y;800805e=:@1LC2P0Fd/W05Y:9P1HB2@0EdLS05I68P1EAB4805=48`0<04a18@1>
@b<0DDHV05=8:01DBBT0DTLW04m4901=@R80CdHY04i5:01;@RD0BD0S0P17?R4204Po8P0604@m8@13
?200@c`P048k7`11>Qh0@3TM0P0o>1`03P0m>280>cHP03Td7P0h<ad0=c8L03Pc7@0i=1h0>SDO03@f
800c=Al0<S@N034c7@0`<Q`0;c4K0P0^<1X02`0`;aX0<2lK02d_6P0Z;AX0:B`K02L[700T:Q`08bTK
02P[800W:Ql09BPM00<08bHK0P0U:1d2028U7003024T6`0P8aX07b8I00807R4H00@07B0G01XP700J
81`06R0L0P0I7a/301PN6P805adK0P0F71X201DK6@8051XH200G6AP801HG6@804aTI0`0B61P3014G
5aT051DG200?5AD801@E5`805AHH0P0D5AL201<D5PX04Q<E200A4QA801@E5a005AHH200F5aT901DF
60P05ALF0`0F61L201LI60<061XI200F61L801TK6P8061PH0P0I6AT201XJ6P806a/K0`0I6aP301XL
6@806adJ200L71X801dM6`X07AhH0P0N7aT401lP6PP07AhH0P0N7AP201lN6@8081lJ0P0Q81/802<S
6`P09b8L200T91`00`0R8QX08b<K02<S6`0402<S6`03028R6P0P8A/0824K00807b0J0P0N7aT201dN
60P07b0J2@0P7aX201dN60807QlI0P0O81X2020Q6`808R4L0P0Q81/3020O6P0301lN6@0N7AP07QdH
00H07QdH0`0P81P3024Q6@808R8J200U81X202XS6`80:b@L00D0;2DM02dV7P0^9al0;RLO030U7`03
034V8080<RLQ0P0c:28203@X700903DY7@0g:al0>2`P03T]8@0j;R80>blS040^800o;Al0?R`N0080
?B/M00<0?bdO044_8@12<2801@13;Al304@^800603lb7`0n<Ah0?C0M03`_700k;Q/0>RdJ0P0i;1T0
1P0l;R<0>bdR03T]8@0f;200<b/N030Z7080;BXK00P0<BLM038X7P0c:Al0=2XP03<Y7`0b:1h0<2HL
02lU6`@0;bPP0P0^9al202dV7P0302XS6`0[91`0:b@L0080;2DM0P0]9Qh00`0^9al0;BHN02dV7P06
02dV7P0602`X7`0[9ah0:RHM02TU700X91/09b<J0P0V8QT402LS6P80:2@K0P0Y9A`202XV7@<0:BDL
100X91/00`0]:B00;2PO02XV7@0202TU700302XV7@0/:1l0;BTP00<0;2PO0P0[9ah602XV7@80:bLN
0`0/:1l802PX7P0302lX800`:B40<R/S0080<b`T00/0<R/S034Z8P0`:B40<bHM038X7P0c:Al0<b/P
038/800_:al0;B/N02`Z7@0803D/7@0303H/8P0e:b40=B/Q0080=2XP0P0c:Al00`0b:1h0<R`P038/
8003034[7`<0<2XN0`0b:1h303<Y7`80=2XP0P0e:Ad303HZ7P<0=b/O200h;R800`11<B80@30Q040`
8@0203l_8080?RhO00<0?BdN03X^7P0j;Qh01P0j;Qh203``8P0403da8@0m<R00?S<Q03hc7`80?c@N
00<0@SDT044d8`10<b800P0o<R401011=2<0@cHU04@g9P17>Ah204Ph7P0304Th7P1;=ah0C3HN0080
CSHN1019=2<204Pc8P80Ac8Q00H0AC8Q04@c8@14<b40@c@Q044d8@10=B4303hf8@80@3<R0`0o<R43
03ha80P0@c8N200o<Ql303ha7P<0?c8O0P10<b0203ld7P0=03hc7`0n<b40?C8P03da8@0m<B<0?30R
03hb8P0m<B40>blO03X^7P0i;Ad0>RhN03/_7`0403``8080>blO0`0j;Qh0200j;R80>2hR03L]8@0f
;R40=2hP038_800a;b00<2hO0P0j;Qh00`0k;al0?30P03da8@0203hb8P0403lc8`11=2@0@C@T044d
92_ooooo000Zooooo`0309Q/>`2IKC`0Vfln0080W70o00@0Vfln09U]?02HK3/0WW910`2MLD0309a`
?`@0Vfln00<0W70o09ea@02NLT400P2NLT4209ad@@0309ec@@2MLD00WW0o0080WVhn00T0X6dn0:=`
@@2RKd00XFho0:1]?P2QKSl0Xg110:Eb@`2WM4D00`2MLd4209id@P<0WgE300H0X7=90:1dA`2PM4L0
X7A50:1d@`2PMD820:1e@00909a`?`2OLd80XWI50:EiB02VNTT0Y7Q70:5eA02OLd80WW<l0080Wg@m
00<0X7Dn0:5f?`2QMSl00P2RMd090:=iA`0309ijAP2MNDD0W7Q40080VgM300<0W7Q409eiA@2NNTH0
202NM480102UNTd0XgQ;0:1eB02MLTD209]`@`0809aaA02MLTD0UW1109E_@02DKSl0Tfdn099/?@2@
JS/208mY>P80T6Xk00T0SfTj08eW>02<ISL0RfDf08YT=@29Hc@0PU`_085K;P1oFB`00P1mEbX00`1n
F2/0P5X]085K;P0207]H<00407YG;`1hEBd0Me@/07EB:P80M54Y00H0MDlZ07=@:P1cD2X0Le4[079B
:`1`Db/206mC:`<0Kdh[0P1^CBX306e<:@80JdXW0`1ZBBH306U89@0H06m>;`1`Cc00L4l^075@;@1b
DR`0Le</07AD;@1dE2/0N5PY07YJ:`1oGBd0QF4_08MS;`28Hbh0RF4]08QQ:P25Gc80QV0c08MQ<P29
Hc80RVDa08aW<P2=J3<0SVTb0P2?I3L3091U>0<0TFHi0P2CJ3/2099W>P80TFHi0P2@ICP00`2AIST0
TVLj09=X>`0209AY?003099W>P2AIST0T6Dh0080SF8e00L0SV<f091U>02AIST0TVLj09=X>`2DJC`0
TfTg00<0TVPf0P2AIcD2091V=0T0RF<d00<0S6Hg08eW>02>J3T00P2?JCX00`2>J3T0S6Hg08]U=P02
08eW>00308aV=`2;ICH0RV@e0080RF<d00<0R68c099Y=@2BJCD00P2AJ3@0102@Ic<0SfHb08mV<P2>
IC4509=Y=`<0TVPf00@0S68`08mU<`2CJCL0UV`j0P2HKS`00`2GKC/0UV`j09M^>P0209M^>P<0V6lk
0P2IL3`01@2NMD40WGA009ed@02LLcl0Vg8n0080VW4m00@0VG0l09ab@02NM480WgE30P2QMdD00`2O
MD<0WWA209ab@00309]b?P<0VW4m0P2IL3`2095/>004099]>@2CKSX0Tfhj09A_>`80UG0l00<0VW0n
09U_?@2GKC/00P2EJcT00`2GKC/0VFlm09Y`?P0209E^@`0309E_@P2EKd00UFln0080UG0l00<0UG0k
09M]>`2GKC/00P2FK3X0102EJcT0U6Xh09AZ>02CJCL809=^=`0>09Ea?@2FLSh0UW8n09Ib?P2ELCd0
Tflk091/>02?JcL0UFTl09AY?02EJSd0U6/m099/?@2BKSh2091^?P80SFTg00H0SFTi08aW>P2<Ic/0
S6Lm08]V?02;ICh208]V>@0408YU>029I3L0R6<f08MR=@80QV4d00<0QF<c08=Q<@21Gbl00`1nG2`2
07mM;@0T081N;P1dFBh0M5T^079F;P1`E2d0KU8]06a?;@1ZCB/0JD`/06E=:@1TC2P0HDXX05e9:01I
ARH0E4<U05918`1@@B@0Bc/R04Pj8015=Ql0@3@N03`a7@0i<Ah0>34N03Pa7`0c;Q/0<R`L030]700]
:a`0:R/M02PZ7@0W:Ah09RTN02d]8`0/;280:RXP0`0X:1h00`0Z:R00:b/Q028S6`02028S6`808B8J
0`0P8AT801lR6`P08B@M200U9Qh2028S7@03024R700P8A/07b0J00807QlI00<07AhH01dP6@0M81T0
0P0M81T201`O60806ahG0P0K7AX301`N6`<07AlL0P0R91H2024S5@04028T5P0T9QP09bTK02PZ7080
9bPF00<0:2TG02TZ600Z:aT00P0[;1X01@0/;A/0;RXO02`X7@0Y9AX09R8G00809B4F00X09b<H02PT
6@0`<2H0;RhT02/[8@0Z:R00:BTO02/[8@0];B<0;blU0P0c<2400`0e;b40=RhQ03L]8@0203P/8005
03T[800i;Q`0>c0N03db800o=2800P10=B<0100o=280?S<Q040e8@10=B42044f8P<0@SLS0P13>2@0
2018?2@0ASXR04@h8012=Qh0@CDM048f7P13=al0A3PP0`0l=A/203df70<0?SLM00/0?SHS03`d8@0i
<Ah0=blL03P`7@0k<b00?cLT048j9`0c<a/0=3@L03Lg7`0303Ti8@0303Lg7`0f=Qh0>C@Q00<0>3<P
0P0g<Ql203Ha7P0603@_700c;Ad0<bdM038/7P0a:al0<2TO0P0_:20202XZ8P0302TY8@0X:2009bLO
00809BDM00T092@L02DV600Y:Q`0;2dO02X[7@0U9QP08R<E02DV600Y:Q`00P0W:A/302T[7@0302LY
6`0V:1X092HH00P08R<M02D09B/W02L/9P0];RP0<c0W03/b:@12=2T0B3HZ04Xg:@1FAR`0FTT]05m?
;P1WEBl0KU/`07MR<`1lIS@0OfXe089R<`20HC80OF4a07QQ;`1eGbd0LF0/06mO:`1/GbX0JE@W06QC
:01WDBP0I4hY06199`1KA2D0EclS05@l8P1A@BX0CShW04/k9017=b00ACDN0080A3@M00T0ACDN03hh
7P0o=b00@CHP04@e8P16<b@0B38U04Xb:01<<BP02013=1d02@1@?Al0Cc`N04hk7@1>>ad0Cc`N054n
801D@B<0ET<U05m49`030615:080HDHY0P1RAbX406578P<0H4HQ0P1OAB00101OBbH0GTXU05i:9@1M
BB@205a88`80FdLR0P1HAAd205U67P0705Y77`1KB200FdPP05a98@1JB200FdTQ05e;8`0205m=9@04
05i<901MBb<0G4XR05M79P80ETHU00<0EDDT05A48`1C@b800P1C@b820592:`040551:01A@BL0D44T
05118P80Cd0O00X0DD<Y04m19`1=?bD0BcdS04Xl8P1;?B<0C3hT04do9@1=@R80C44Q0P1>@B402@1@
@B80E4<U05Q59`1JAbT0ETTV05A7901CAB80DT8P05=07`0205A07`0905M0801@@Q/0DT<L05A57P1I
Ab40GDTT069<9`1VCRX0Idl[0080JDhS00<0JTlT06]@9@1/DBH00P1^DbP00`1_E2T0KUL[06iG:`02
06mH;00406iG:`1]ERX0JU<W06UB9P80KeP/00@0KUL[06eF:P1]ERX0K5DY0P1[E2P2071E:P<0LEH[
0`1bEb`2071F9@04075G9P1bF2L0LUPW07=I:080M5XY0P1dFBh207=H;@05079G;01aER/0LEH[075F
:`1[Eb800P1ZER<00`1ZER@0JE@U06UD9`0206QC:0P0Ie0T00H0KThU06]>901[CR@0JDhS06I>8P1T
CB42069=800705i48`1MAB<0GDDS05e58`1LAB<0FTHS05U78`0205M78`0805I68P1EAB40Dd<O0592
7P1C@al0EDDQ05M78`1HB2@805Y;800805i>:P1MCBT0G4`X05Y:9P1HB2@0EdLS05I68P1EAB4805=4
8`0304]0801>@b<0DDHV0080E4TY00L0DTLW04m4901=@R80D4LZ04i5:01;@RD0BD0S0080AchQ00P0
B3lR04U08`15?R80AChR04@m8@13?200@S/O044j7P80@3TM00<0?CPR03/f800j=Al00`0h<ad0200i
=1h0>SDO03@f800d=R00<cDO038d7P0`<Q`0;c4K0P0^<1X0400`;aX0<2lK02d_6P0Z;AX0:B`K02L[
700T:Q`08bTK02P[800W:Ql09BPM02<V6`0R9AX08bHK02DX7@0V:Ah2028U7004024T6`0P8aX07b8I
01lR6@807R4H0`0J81`301TO6`8061hJ0P0G7A/201HL6P805A/I0P0D6QP801LI60P05QLI0P0C6AT3
018H60<04ALG6@0D5AL800lE5@P051DG0P0E5QP201@E5`804a@F2P0B4aD8014B54P051DG400E5QP8
01HG6@T05AHH200E5aH201HH5`<05aTH0`0H6QT801HH5`P06A/J0P0H61P201TI6@806QXJ0P0K6a/3
01TK60<06Q`I0P0K7AX801`L6PP07AdK2P0M7QP201hO6@<07b0J00<0824K01dN600M7QP01P0M7QP2
01hM60807ahI0P0P7aX2024P6`P08b<K200W8Q`802@T7003028R6P0Q8AT0820H00<0820H00@08B4I
028R6P0P8A/0824K0P0O81X201hO6@807AhH200O81X9020O6P807AhH0P0N7aT201lP6P80824K0P0R
8A`2024P6`@081lJ200N7AP3020P60<08B4I0P0R8QX802DP6P80:B8J00@0:R<K02/T700]9Qh0;RLO
0P0_:204034V8080<RLQ0P0c:280400c9a/0=2PL03DY7@0g:al0>2`P03X^8P0k;b<0?30T044^8010
;Al0?b`N03h[7@0o;1h0@2dO048_8@13<28404<]7`@0A2hP0P0o<Ql00`0n<Ah0?C0M03`_700203X]
6P0703T/6@0m;b@0?BlT03X^8P0g;B40=2`O038/7P0202h[7003034W7@0b:1h0<bTO0080=2XP00@0
<RPN030V700^91X0<2TQ0`0_:20202hW7`80;BHN0P0Z8a/0100[91`0;2DM02`U7@0]9Qh202hW7`P0
;BHN00H0;2PO02/W7P0[9ah0:BDL02PT6`0W8aX302HR6@<09b<J0P0X91/202TU7080:RHM0`0Y9A`4
02PT6`0302dY800/:1l0:RHM0080:BDL00<0:RHM02`X7`0]:B000`0/:1l302/W7P@0:RHM0`0[9ah3
02`X7`P0:2PN00<0<2TQ034Z8P0c;2@00P0e;RH02`0d;BD0<R/S034Z8P0c9Qd0<RPN03@Z800d;240
<bdQ030/800]:ah0;2XM00P0=B`M0P0f;28203D[8@0403@Z800c:Al0<bTO038X7P<0<R`P0P0a:al3
030Z7P<0<RPN0P0c:Al303@Z8080=BTM0`0f:Qh303L[7`P0>2hR0`11<B800`10<240?blP03h^7`02
03h^7`P0>RhN0P0n<R@0100n<R80?S<Q03hc8@0n<al203hc7@08048e9011=2<0@3<R03lb8@10<b80
@C@S04<f9@14=bH204Lg7@0404Pg7@1:=Qd0BcDM04/e7@80CCDM00@0BSDT04Td8`19=2<0BC@S0P18
<b8204Lb8@0604Db8@14<b40A3<Q04<d8@11=240@3DQ0`0n=R42040c8P<0?c8Q0`0n<B0804<b7PP0
?c8O0`0n<Ah303lb7`80@3<P0P0o=1h0100n<al0?S<Q03db800m<B4203da8`0903hb8P0m<B40>blO
03X^7P0i;Ad0>RhN03/_7`0l<200?C4Q0080?30P0P0k;al303X^7P0603X^8P0h;R80=bdQ03H^8@0d
;R00<RlP0P0a;b001P0j;Qh0>blO03/_7`0l<200?C4Q03hb8P80?c<S0`11=2@[ooooo`00:_ooool5
09Y_@P<0VFi10P2IL4800`2JKd80Vfm209e^@P0209i]@P030:1]@P2NLT40WW9100H0WW9100@0W790
09]a?`2KLCl0VW0n0P2IKcd209Q^?00309i`?`2OLD00XG=20080XWA300<0XG=209ma@02NL3l0202N
LT4809md@@80Wg=20`2PM4<30:5eA080X7E20P2QMT<20:9gA080XgQ50P2RNDD20:5hA0<0X7M30P2O
MT880:5h@P80WWE10`2MM40309ac?`0N09]b?P2KLCl0VW0n09Y`@02IKT40VFi309U^A02HKD<0UF/k
09I/?02GK3l0Ufa109EZ@02AICh0SF4j08]O>P2=Hc/0S68j08UR>@27HSP0QF0f089O=@20Gc@0Oehc
08EQ<@25H3<0Q5lb089M<@21G380OeTb0P1nF3<207eG<P0307aF<@1kEC00NU@_0080NE<^00<0N58]
07=B;`1cDRl00P1bDBh3075@;@07071?;01_DBl0Ke4_06i@;P1]Cbd0Jdd[06Y<:P0206U;:@@0K4/X
101[BRL04@1/CRP0KdlY071@:@1cDRT0MU<Y07YE:@1lEBX0OELZ07mI<P1oFS00P5/a089M<@23GS40
Q60`08EQ;`26HS00Qf4b0080R68c00<0RF<d08YT=@2;ICH00P2<ISL04@2:IC40RfHb08aW<`2>JCD0
SfXf095/>02BKCT0Tfhj09I[?P2DJC`0TFHi08mT=`2>HcH0Sf@g095V>@2CJ3/0U6Tn0080TfPm00D0
TVLl095V>`2@ICX0T6Dj08mT>@08091V=P0;08]V>P2>Ic`0T6Xm09=Z?02CJCT0TFDd091R<@2>H2h0
SV<f08aQ=02:Gc800P29GS4208]P<`0308iS=P2@ICP0T6Xk0080SfTj00<0SVPi08eW>02=IcP00P2<
ISL00`2AIST0T6Dh08iS=P0208eR=@0;08iS=P2?I3L0T6Dh09=]?P2BK3d0SfTj08iX>@2=IcP0SVPi
091Z>`2AJc`0202BIcX309=Y=`80U6Xh0`2EJcT00`2FK3X0Ufdk09U_?@0309]a?`0=09U_?@2HKS`0
UW1309Qb@`2ILd@0VgE409]f@P2IM3l0V7<l09Ia>P2FLCd0V7<o09Ye@@0209ag@`0309]f@P2JMD40
VGA00080W7900P2KLCl0102JL3h0VFlm09U_?@2HKS`309Y`?P80VFlm0`2HKS`209E`>@@0UW4j0P2G
LS/309E`?00309A_>`2CKSX0TVdi0080TVdi00<0TV`m09=]?P2DKSl00P2EKd001P2DKSl0Tfdn099/
?@2EL3`0U6lk09=^>P80TVdi00H0Tfhj09A_>`2EL3`0UW4m09A_>`2BKCT2091[=`06095/>02BKCT0
Tfhj08eY=@2>JSH0Sf/g0P2AKCT01`2?JcL0SVXf08eY=@2@Jch0SfXm08eX>`2;IST00P2:ICP0202;
IST0S6Lj08UW>@28ISP0QfDg08IT=P24HS@0Pf4c0P22H3801P1nH2X0Of4[081R;P20HS00OUl`07aM
;P80NEX/01X0MePZ07EB:01eDRX0Le8Y071@:@1/CRP0JddY06U<:P1XBbT0HTPW06189P1NABH0Fd@U
05I1901B?b40CSdQ04dl8017>Ah0ASPN04<g7@10=Qd0?3@M03Tc7@0h<Ah0=S4M02//7P<0:R/M0P0Y
:Q`202PY6`80:2XL00@09bTK02HX6P0U9aT09BLI0P0T9QP3028U7P<08B@M0P0P8a`301lR6`8082<L
2`0Q91d0100T9b008bHO02<V7`0S9Ql2028U7P808B@M0P0R9Ah0100Q91d082<L01lR6`0O8Q/201hQ
6PP06adJ00H07AlN01dO700M7a`07R0K01hQ6P0N8AP201hQ5P06020Q6`0Q8Q`08R<M02@U7`0V9b40
9bPR0P0Y:R@0200T9AD09RLG02//700^;al0;c0P02h_7`0/;Ad0:R/K0P0T8ah01P0S8a/08b<I02@T
600W:1X0:R/K02`]7@80:bTJ00h0;B/L02h/7@0`;Ql0<S0Q03<a8P0d<R<0;c4K038a700d<Qd0>34N
03Xb7`0n<B00@C4Q048a8@80?C<J00@0?S@K03le700o=A`0@3HM0P11=ah00`12=1T0@cDJ04Dg7002
04Hh7@0:04Dg7013=AX0@S@I048d6@17=R@0ASDS04Df8`12=B80@3DQ03ld8080?3@O200o=20303Pc
800@03Td8@0j=B80>cHS03/f8`0l=b@0?3@M03de7P0m=b40?3LS03Tf8`0f=B<0=3<Q030a8@0`<b80
;c8Q02d`7`80;2lN00<0;C0O02lb8@0`<b800P0Z;2400`0Y:b00:2XO02LY7P0202DW700?02@V6`0Q
9AH08RHG02DY6P0W:a`0:2`M02L[700V:Q/09BTJ02@W700U:1d09RTN02LZ7`0X:b00:B`Q0080:RdR
01h09C4U01`X700H8QL07bLL02`b:00b=B`0:bhU028S6`0N9b`082DX024R900R8Ad0:24I02dS6@0b
91L0=RHG03P]4@0k<180@SDE04Tl6@1CAB00G4dT06ED:@1YF2`0MU/T07QM9P1kHR`0OVLc081[=P20
K3T207i/>P0@07YZ=`1gIc@0LV4c06aK;`1WEBd0He4]065>;@1PCBd0CT@[04e3:P1;@BP0B3hU04Dk
8P12>1l0@3HM03le70P0@3HM00P0@3LJ048g6`13>1`0ASPM04Ti7`1;>R00CSXQ04lk8P80DT<R00`0
DT8Q05A18@1G@R<0G4DV05m8:@1RBB/0FClL05a27`1PAR<0ID/X06U?;01[DBh206eC<00806UI:01X
EbT0IeHX06IE:@1UE2T0I58Z06=A:`1RD2X206iF9P0R06aD901ZDR80J50P06YB8P1]EBD0LETY07AL
;01ZES40J5@_06EA;01SCbX0HThY06A@:`1VDRd0Ie<^05m;9P1PC2L0HThY06=?:P1RCRT0HDdX05m;
9P1MBB@0H4`Y05m;:01PBBL0GdLU05i48`1N@B40GD0P05dn7`1C?ah0ED4P05M38P<0FDDT00D0Ed<R
05I28@1LB2D0FdLT05Y68`0305U58P0605Y68`1KAb@0GDh]05U::@1DAB@0D44P0P1>?ah0101?@1l0
DD8Q04`k7`1<>al204dl8080CSdQ0P1??R803P1LBBT0FdPX05M6:01CA2L0Cd4V04/o9@19?B<0AS`S
04m2801@@b40DT<R05E5901FARD0FTLW0P1LAbP206aE;080Je@[0P1ZDbX206UB:@80JeHW00@0K5LX
06eH:@1^FBX0KUTZ0P1_FR/0201WD2H0J54W06YC:@1[E2X0K5D[06]D:P1ZDbT0JE8X201`EBX2071D
;@03075E;@1aER/0LEHY0080LULX00<0LUPW07EJ;@1eFRd00P1dFB`05@1cF2/0LULZ079G:P1aERT0
L5DX06mD9`1^DbP0KE8W06]?9`1YCBH0J4`W06M;9P1XC2L0JDdX06]?:01]DBT0KU<X06eB9`1[D2<0
JTlR06M@900206I?8`0606UB9P1/EBT0Je@X06E>8P1OB1`0H4XS0P1QBb@02@1RC2D0HddV069<9@1Q
Bb@0GdTR05i88@1OCBL0GD/U05]98`0205U78@0405]98`1MBbD0GddW05a98@80GDXR00<0Gd`T061=
9@1QCRH00P1RCbL405m=9`<0GT`V00L0GD/U05a7:P1KART0FTLY05Q7:@1GARP0ETLX0080E4LW00X0
EdLV05I79P1EARD0DTDS04m58P1<A200B48N04M17@1=@R80CT<S0P1?A2@00`1>@b<0C44Q04Tn7P02
04Ll700704Ll7P15?1d0@S/N03lj7@0m>Ah0>SPO03Tg7P0203Xf6`@0>cLL0P0l>1d303<a6P80=38K
0`0e<a`0200a;1T0;b`I02h[600/:aL0:B/F02LZ5@0V:aD09BXD0P0Y;2<01P0X:b809RTP02DX7`0T
9ah08bHM028U70<082<J0P0O8QT301hQ600801lR5`0N8AH07R4H01dP6@0L7QT06adJ01XL6@0J71/2
01PN6P<05adI0`0F71P301PJ6@<05aTH0P0F61L801DG5PP04QPH4@0D5AL@018C5AP051DG200A5aL@
01@E5`@04a@F0P0B4aD2014B50P05AHH:00D5AL801DF60P05ALF6@0F61L301DG5P805QPG0`0G6AP8
01PH60805aTH0P0H6QT201TK6P806Q`K2`0J6QP301/K6@8071`J400M7QP8020O6Q407QdH0`0O7QT2
020O6P808B0K200U81X402PT6`@09b<J00H0;R4K02`Q6`0/8A/0:R4J02TR6P0V8QT202DR6@@09b<J
0P0V8QT202DQ60<09R4K0P0U81X302@O6AT08B0K200R8QX8020O6PP08B0K0P0R8QX302<S6`<092@L
00@09AhF02LP600Y8QX0:b@L0P0/9Ad01@0[91`0:R<K034[7`0`:Qh0;BLK0080;2HJ00<0;BLK030Z
7P0a:al00P0d:1`00`0e:Ad0=RXN03L[7`0203P/800:03T]8@0d:R00=B/O03L[7`0i:ah0?2`M03h]
7@0o;Q`0@2dL04@c8@80@c8P00<0@S4O044`7P11<1h00P10;ad2048a7`80@C0N0P10;ad203l^700@
040]7`0n;1h0?B/M03/[700h:a/0=RXJ03<Z6@0b:AP0>BdQ03P/800f:Qh0=BTM03@X700e:Ad0=RXN
03L[7`<0<RPN00<0<BLM030V700_9A/00P0_9A/4030V7080;bDK0P0^91X8030U7`80:B8J00@0:R<K
02/T700/9Ad0;BHN0P0^9al202LS6P809R8I00T0:2@K02XV7@0/:1l0;RXQ02`V6P0]9a/0;bTM030Z
7P0_:Ad00P0^:1`0100/9QX0:R@H02`Y6P0/:AX202dZ6`0402h[700_;1d0;b`M030]7PP0;BHP00@0
;b@P030U8@0`9B40<2DQ0P0a9R82038W8`80;2TJ0P0]:Q/0100^:a`0;b`M02l/7@0`;Ah803HZ6P06
02lY6`0`:Q`0<B/M038/7P0c;Al0=2hP0P0e;b4803HZ6P0403P[8P0g:R40=bXQ03LZ8@80=RTP0P0e
:1l00`0/:1d0;BTN02l[8002030/8@0302l[800]:Ah0;2PM00P0;R/L00H0;RPJ034Y700c:ah0=R`P
03X^8P0k;B8203h]8`80?30P00<0>blO03X^7P0i;Ad00`0i;Ad803ha7PP0>c0N00<0@2lM044`7P12
<Al00P14<b400`13<R00@C0N040_7@0804@c8@06044g7P12=Qh0@cLO04Hg8019>B80BcTS0P1>>B@0
101<>R80BcTQ04/i8@1:>20204Tg7`80B3HN0P13<a`304@d7@@0ACDN00@0?c8O040c8010<b00@C@Q
0P12=B8204<f8`0604Dk8P15>B40A3PP04Df7`15=Ah0AC<M0P16<A`2048e8P80@C@Q00@0@3<P03lb
7`0n<Ah0?S4N0P16<B0304D`7`<0A2lN00`0A34R048a8@12<B40@30P03d`7`0k<1h0>C4N03P`7@0f
:QX0>2`L03X^7P0k;al203``800:03/_7`0j;Qh0@C@Q040c800o<Ql0?C0M03/^6`0j;AX0>B`I03P[
6080?RlJ00`0?2lL03/`7P0i<Ah0>34O03Pa8@0g<B40>blQ03``8P0l<200?C8P03hc8@0o=202040e
7`<0@C@S:oooool002[ooooo1P2KL4<209Y_@P80VG1200<0VVm209]_@P2MKT800P2NKD800`2PKD80
WW9109ib@@0609ib@@0309ec@@2LLT00W7900080Vg4o0P2JL3h0102IKcd0WW0o09ma@02QLd820:9d
@`030:5c@P2OLD00WW0o00P0WW91202OM44209mc@P<0X7A30`2QMD@20:1e@P80XGI30P2RMd@20:=h
A@80XWU50P2QN4@30:1g@`80WgI2202QN48309ie@@80WGA0102LLcl01`2LLT00Vg4o09]a@@2JKd80
VVm409Y_A@2IKT@00P2FK3`01P2FJch0UFXo09=X?P2@I3d0SV8k08aP>`80S68j00l0RF8i08MR>025
H3H0PUle081O=01oGS<0Q5lb08=N<@22GC40PE`b07mI<P1nF3<0OELb07aF<P1mEc800P1lES400`1k
EC00NU@_07UC;P0207QB;@0407=B;`1bDBh0LU4^079A;P80LE0]0P1`Cb`01P1_DBl0KU0^06e?;@1/
CR`0Jdd[06Y<:P80JD/Y1@1/BbP306]:9`0>06e?:@1_CbT0LE4Z07=B:@1fDbT0NUDY07eF:`1mEbX0
OeTb07mJ<020Fc40PUda08=N<@25HC4208IR<080R68c0P29Hc@0102:I3D0RfDf08aV=`2<ISL208aW
<`0408eX=02>JCD0SfXf091[=`80TF`h00@0U6Tl09=X>`2BIcX0TFHi0P2@ICP2095V>@80TfPm0`2B
Ic`3095V>`P0T6Hf00/0SFPl08iW?02?JC`0TFPj095W=`2AIC@0TF<b091R<02?I3L0SV<f08eR=@02
08aQ=080SF8e0P2>HcH00`2?JCX0SVPi08iX>@0208eW>080S6Hg0140RfDf091U>02?I3L0SV<f08eR
=@2>HcH0Sf@g095V>@2BIcX0Tfdn095[?02?JCX0SVPi08eW>02>J3T0SfTj091Z>`08099W>P80TfTg
0`2DJSP309E[>@0309I/>P2GKC/0VFlm0080Vg4o00h0VW0n09U_?@2HKS`0Ug5409Qb@`2ILd@0VWA3
09Ye@@2IM3l0V7<l09Mb>`2FLCd0Ug8n09Ud@0<0VgI200@0VWE109Ud@02LLT00W7900P2KLCl0102J
L3h0VFlm09U_?@2IKcd309Y`?P80VFlm0`2HKS`209E`>@H0UW4j0P2EL3`209A_>`80Tfhj0P2BKCT0
0`2BK3d0Tfdn09A^?`0209E_@00609A^?`2CKCh0TV`m09E`?02DKc/0Tfhj0P2BKCT01P2CKSX0U6lk
09E`?02EL3`0U6lk099]>@80T6/g00H0TF`h099]>@2CKSX0SFTe08iZ=P2?JcL2095]>@0708m[=`2>
JSH0SFTe091[?P2?JSd0SFPk08]V>@0208YU>080RfHi00h0RFLi08QV>027ICL0QV@f08AR=023HC<0
PV0b085O<@1nH2X0Of4[07mQ;@1oHBl0OUl`07]L;P80NEX/01T0MeP/07EB:P1eDRX0LU0Z071@:@1/
CRP0JDdX06Q;:@1UBbP0HDTW06189P1MARH0FT<T05E08`1A?B80CC`P04`k8@16>1h0@cLM048f7P0o
=A`0>c<L03Tc7@0f<Ad0=C0L00@0:R/M0P0Y:Q`202PY6`80:2XM00<09bTL02HX6`0U9aX00P0T9QT0
100S9AP08RDN028U7P0R9Ah2024T7@<082<L0`0O8Q/2020S70/08B@M100S9Ql2028U7P808B@M0P0R
9Ah00`0Q91d082<L01lR6`0201hQ6P0401dP6@0L7Q/071hK01`N6`D06adJ00H071hM01dO700M7a`0
7R0K01hQ6P0O8QT201lR5`808R<M00T08b@N02DV800V9b409bPR02PY8`0Y:R@09BHF02LX600[;1`0
0P0^;al00`0/;Ad0:R/K02PY6@0202@S7P0>02<S6`0S8aT09BDI02LX6P0Z:a/0;2dM02`Z6`0]:a`0
;R`M02l]7P0`;Ql0<BlP038`8@0c<B82038a700403@b7@0h<Ah0>S8O03ha8080@C4Q0P0n=1/303le
70<0@3HM00<0@cDJ04@f6`15=a`00P16>1d01015=a`0A3HK04<e6P13=AX204He8`0304@e8P11=240
?c@P0080?3@O00<0>S@N03`d7`0l=1l01P0l=1l303Pc800303Td8@0j=B80>SDR0080>cHS00/0>c<L
03/e7`0l=R00>cHR03Pe8P0e=280<C8R02l`800^<B00;C0O02`_7P0202X]700402`_7P0]<1l0;S4P
02X/8@80:B/P00h0:2XO02HX7@0U9a`09BLL02@V6`0Q9AL08RHH02@X6P0V:Q`09b/M02HZ700U:A/0
92PJ02@W70<09BPM0`0V:Ah0:@0W:Ql092hV020W800L8a`082DN02X]9P0_<2X0;BdU02PX800U9R40
9bHQ02XV7@0_9a`0=RXJ03h]6`13<A/0B3@L04dm701@@1l0F4DT05m=9`1WE2`0KU/`07EP<`1gHS<0
OVD_07eV<P1nIc<0OVPf07aX=P1hISH0MF@f07AS=@1YFRl0IUL^065B:`1KBbL0ETHU05918`1??R80
CchT0080@CLN00<0@3HM03le700o=A`00P0n=1/00`0m<aX0@SPO048h7`0204<i8080A3XQ0P15>b80
1P16?B00B3dQ04Tn8P1<?R<0CShT05509P80E40W0P1EARD0301EAB@0F4DU05Y59P1OB2T0HT//06A;
;@1NA240H4HS06A:9`1XCR/0Je4^06eC<080KU@a00P0JeX/06YI:`1YF2`0J5L[06IE:P1TDRX0He4[
069@:P80IU<X00X0I54V069?901QCR<0HTlT06EB9`1YER/0K5T^06QD<@1WDc00IU8_0`1UDBh01@1V
DRl0Ie<`05e99P1NBRL0Gd/X0080HDdZ00<0H4`Y05i:9`1MBBH00P1QCBX00`1RBbT0HTXX06989`02
06959@030693901IAB@0FTHU0080FdLV00@0FTHU05Q48`1F@R40ED4P101JAR<01`1IAB80F4@Q05M3
801F@Ql0F4PW05I69@1B@R400P1??ah00`1@@1l0Dd<R05E5900405=08P@0E44S01P0ET<R05E28P1C
@b80DD8S04m1901<@BD0C40V04Y09@1>@Al0Cd8P05528@1DA2<0ETHU05Y79`1LAbP0GDPY065;8P1R
C2<0HddT06A>9@1VD2L0Ie4X06QB:@1YDbX206YE9P0306]F9`1/EbP0KEPY0080KUTZ00T0KeX[06QA
9`1YDRP0Je@Z06aE:`1]ER`0K5D[06]D:P1ZDbT0201`EBX2071D;@03071D;01aER/0LEHY0080LULX
00D0LUPW07EJ;@1eFRd0MEX]07AI;00207=H:`80LULZ00L0LEHW075F:@1`EBP0KU<X06eA:@1[CbP0
JThY0080JDdX00P0JThY06a@:@1]DBT0KU<X06eB9@1/DB@0Je0Q06M@9080ITlS00D0JE8V06aE:@1[
E2P0IDhR05m87003065;90<0HddV00D0HD/T05m98P1NB240G4XT05]98`0405Y88P0305]98`1LBR@0
FdPP0080G4TQ00D0GDXR05m<901PCBD0H4dU065>9P0305m=9`0305i<9P1MBbD0G4XT0080G4XT0P1K
ARL0101JAbL0EdLV05M79P1EARD205A79@0:05M79P1FAbH0EDHU05958`1?AB80C4@P04U37`18@Qh0
CD8R04i38`80Cd@T00<0CT<S04a18@19?Qh00P18?Ad01@17?1h0AC`M048k7P0o>Qd0?CTN0080>SPO
1P0k=a`203`h7@P0=38K00H0<B`I02l/6@0^:aP0;2/G02T[5P0X:aH202H[5@809bXO00@09RTN02DX
7@0U:1d092LL0P0S9Q/3020S6P807b8I0`0N8AP201lR5`0601hQ600M81T071hI01/M6P0J71T06Q`K
0P0H7QX301LM6@<05Q`H0`0H6QT301LI60805QPG200E5aH8018H614051DG400B4aDH01@E5`P04ALG
4@0D5AL301<D5P804Q<E0P0A4Q@801DF62P051DG200E5QP801DG5QT05QPG0P0E5aH301HH5`<05aTH
200H61P201LI608061XI0P0I6aX201XL6`/06QXH0`0K6aT201`L6Q007AhH200P7aX@01hM60@07ahI
0P0P7aX2024P6`P09B0J1@0X91/302LS6P0602lR700]8Q`0;B8L02/R6`0Z8a/0:2@K0P0V8aX0100X
91/09b<J02LS6P0W8aX202HR6@809B4H0`0V8A/302DP6P8091lI6@0Q81/8028R6PP081lJ200Q81/2
028R6P<08b<K0`0T91`0100U7QH09b0H02TR6P0[91`202`U7@0502/T700Z8a/0<2XN02lY7@0^:1`0
0P0]9a/00`0^:1`0;bTM030Z7P0203@X700303DY7@0f:Qh0=b/O0080>2`P00X0>BdQ03D[8@0e:al0
>2`P03T[7P0l;1d0?RdM03l^7010;A`0A3<Q0P13<R02048a7`80@C0N00<0@2lM048a7`12<Al00P11
<1h2040_7@80?bhL00H0@2dO03h/7P0m:ad0>b/L03P[6`0f:QX203<Z6@0803T]8@0h;200=RXN03DY
7@0d:1`0=BTM03HZ7P0g:al3038X7P03034W7@0`9Q`0<2HL0080;bDK00@0<BLM030V700`9Q`0<2HL
0P0_9A/202hT6PP0;R<M00@0:b@L02`U7@0/9Ad0;2DM0P0]9Qh202hW7`0:02TU700X91/09b<J02LS
6P0X91/0:BDL02`X7`0]:B00;2HJ02dW6`<0;bTM0P0^:1`00`0/9QX0:bDI02`Y6P0202dZ6`80;R/L
0P0_;1d00`0`;Ah0;RLO02hW7`0602hW7`<0<2DO0P0a9R03038W8@<0;BXK00<0;R/L02l/7@0_;1d0
0P0`;Ah803HZ6P80<BTL00@0<RXM03<[7P0d;1l0=BdP0P0f;R4803HZ6P80>2`P0P0g:al303HZ7P04
03DY7@0/:1d0;BTN02l[8080<2`Q00<0;b/P02dY7P0/:1d0200^:a`01P0e;b40=RhQ03D]800e:al0
=b/O03PZ7`80>bXP0P0l<2000`0k;al0>RhN03X^7P0303T]7@P0?S4N200k<1h0100o;Q`0@2lM048a
7`13<R0204@c8@80@S4O2014<b402011=ah0@SHN04<g7`16=b00B3PQ04Xh8P1=>2<0CSTT0`1:>200
0`19=al0B3HN04Pf7P0204Le7@@0ACDN1@14=1d3040c8003044d8@12=B80@SDR0080@cHS00T0@cTP
04@h8013=al0ACHO04De7P16=1h0B3<N04Lb7@13=R<00P12=B800`11=240@3<P03lb7`0203ha7P80
AS4P0`15<1l304@_7P0604Db8`13<R80@S4Q040`800m<1l0>c0N0P0h<1d0100e:AT0=b/K03T]7@0k
;al203da8@80?30P0P0o<Ql00`0n<Ah0?C0M03`_700203/^6`0?03X]6P10<A`0@34L03d`7@0l<Al0
>C4N03Pa7`0g<200=S0P03/_8@0l<280?30P03db800n<b40?c@P0080@3DO0`11=2<[ooooo`00:_oo
ool809aaA080VG1200<0VVm209]_@P2MKT800P2NKD800`2PKD80WG5009ea@00609ea@080WWA20`2M
Ld4309ab@00309a`?`2MLD00WW910080Wg=200<0WW9109ea@02LL3l0202NLT480:1e@P80Wg=20`2P
M4<30:5eA080X7E20P2QMT<20:9gA080XgQ50P2RNDD20:5hA0<0X7M30P2OMT880:5hA00409mf@P2N
MD40WWE109ie@@80WGA00P2LLcl03@2MM400WG=109ab@02LLT80Vg1309]`A@2KL4H0VVm509Q^?P2G
KCd0U6Tl099W?02@IC/00P2?Hc`01`2?Hch0S68j08aR>P29HST0QV4g08EP=P21GS@00P1oGS<02022
GC00PE``081K;`1oFS00OEL`07aF<@1kEC40NU@`0P1lES400`1kEC00NU@_07UC;P0207QB;@0307MA
;01bDBh0LU4^0080LE0]0`1`Cb`01`1_CR/0KU0^06e?;@1]Cbd0K4h/06]=:`1ZC2X00P1YBbT806a;
:00>06e?:@1`D2X0LE4Z07AC:P1gE2X0NeHZ07eF:`1nF2/0OeTb081K<@21G380PUda08AO<P25HC42
08IR<00608QR<`29Hc@0RF<d08YT=@2;ICH0S6Hg0P2=IcP408iY=@@0SfXf00<0TFHi099W>P2CJ3/0
0P2CJ3/00`2AIST0T6Dh08mT=`02095V>`<0TVLl0`2CJ3d8091U>00808mZ?P2?J3d0SFLj08iU=`2?
ICD0T6@c09=U=02CIC<4095V>@05091U>02?I3L0Sf@g08eR=@2<HC@00P2=IcP308aV=`<0RfDf0P2?
I3L02@2>HcH0SF8e08iS=P2@ICP0TVLj09=X>`2BK3d0TF/l08mY>P0308iX>@80SfTj202BIcX0102C
JCL0U6Xh09AZ>02DJSP209E[>@80UV`j0P2GKC/00`2IKcd0VW0n09]a?`0209Y`?P0<09U_?@2GLD@0
V79309UcA02JM4<0VWE109Ud?`2HLc`0Ug8k09Ia?@2GLSh0V7<o0`2JMD4209Ud@0<0Vg4o0`2JL3h2
09U_?@<0VW0n0P2IKcd309Q^?0<0UW4l1@2EL3/0102EL3`0U6lk09A_>`2DKc/309=^>P04099]>@2B
K3d0Tfdn09A^?`80UFm000H0U6ho09=]?P2BK3d0UG0l09A_>`2CKSX2099]>@0709=^>P2DKc/0UG0l
09A_>`2CKSX0TVdi095/>002091[=`05095/>02BKCT0SFTe08iZ=P2?JcL00P2AKCT0202?JcL0SVXf
08eY=@2@Jch0SVTl08aW>P2:ICP0RF@g0P2:ICP02@2;IST0R6Hh08QV>027ICL0QF<e08AR=023HC<0
PV0b085O<@0207iP;00407iP;P1nGc00O5d_07YK;`80N5T]01T0MeL^07AC:P1cDB/0LE4Z06e?:@1Z
CRT0IT`Y06E;:P1SBbT0GdHW05e69P1KA2D0ET4T05<o901>?B<0Bc/Q04Xj8@13=ad0@SHN040f7@0l
=1d0>C<M03Lb7P0c<1d0<RlL00<0:R/M0P0Y:Q`302PY6`809bTN00<09RPM02DW700T9Q/00P0S9AX0
0`0R91T08RDN028U7P02024T7@<082<L100O8Q/2020S70/08B@M0`0S9Ql2028U7P<08B@M00H08RDN
024T7@0Q91d082<L01lR6`0N8AX201dP6@0501hP7@0M7a`07AlL01`N6`0K7AX00`0J71T02@0K7A`0
71hK01dO700N81/07b8K024T6`0Q91T08RDJ02@U7@0202DV7P809RLO0`0W:2000`0W:1X0:BXL02//
7P0202`]7`0302X[7@0W:1X09BHH008092<N00L092@L02@T6P0V9QX0:2TK02X[6`0[;1`0;b`M0080
<2dN0P0a;Ql3038_8080=38M00@0=c8N03Pa7P0j<Ql0?C8P0P0o<R401011=ah0@3HM040f7@10=Qd4
03le7003048f7013=ad0A3PN0080ACTO00`0A3PN04<g7@12=Q`0@SHL04Df8`14=B80@SDR040e8@0m
=B00>cDO03Xd7P0i=1h803/c8080=c8O00<0>3<P03Td8@0i=2400`0i=24203Tc7@0803Td800g=240
=C@R034b8P0_<200;BlQ02/]7`0Z;1h402T[7@0702X/7P0[;Al0:B/P02T[800X:Ql09bTN02HX7@02
02DW700402@V6`0R9AX08RDJ02@W70<09BPM0P0T9a`302DW700302@V6`0S9AX08bDJ00808R@I01H0
9BLV02<U900S8b4092<O02PT8@0]:2@0<2/U03@]9`0e:QP0=b`H03h_6P16=1`0D3/P05Y18`1PABL0
IDPX06eC;P1`ES40ME`d07YQ>01oIc/0PFTk0P22JSX04020JS/0OVTj07]V>@1eHSL0Kehc06QI<01R
EB/0H58[05939P1@@B@0Bc/Q04Lg7P13<a`0@2lK03l^700n;A/203/a600;03dc6P0n=1/0@3HM044g
7P12>1l0@cTP04Dk8P16?2<0AcdT04Pn9@19?bH00P1;@BP02@1<@RT0C4<V04e29P1>@bL0DT@Y05A4
:P1FAB/0FDD/05Y6;@0205M89`0;05Q89`1KB2P0GDPY065::`1SC2d0ID`^06599@1SBbL0IThZ06UA
;@1[Dbl00P1/E3002@1[Dbl0K5/]06]J;P1YF2`0IeH[06EC:`1SDB/0HDl[061>:P0205]>:`0:05Y=
:P1HBbP0EdXW05Q;:01JCBX0GE0]061C<01QCb/0HU0/06=A;@<0I58^00H0He4]069@;01HAR80FDLS
05]99@1LBRH305e;9`0605a:9P1QCBX0HDdZ06=<:P1TC2X0ID/Z0P1WBRX06@1XBBX0HT/Y069;:@1R
BbT0H4TW05i79@1LAB<0FD8P05Q17`1KAB00GDLR05i88`1OBB@0GTPS05]5801G@A`0EClJ05I4801D
@Qh0DT0L054o6`1B@1`0E48N05M58@1IAb<00`1HABD505M49080Cc`K00`0CShM04ho801>@2<0CD8V
04i39`1=@bP0C3lM04e07P1@@B00Dd<R05E5901IARH205a7:00805Q26`1I@a`0G4HO05m98P1RC2D0
IDlX06QB:`1YDb`206QC9P0306UD9`1ZEBP0JeHY0080K5LZ00T0KEP[06UB:01ZDbT0K5D[06eF;01^
Ebd0KEH/06aE:`1[E2X0201_E2T0201_Db`0L5@]071D;01`EBX0LEHY075F9`1bEbP0LUPW0P1fFbh2
07EJ;@@0M5T/0140LeTX07=H:@1bEbP0LEHY06mD:@1^DRX0KE4Z06a@:@1ZCRL0JdlX06eA:@1^DbP0
KU<V06iC901]DR<0KE<R06QA9@0206I?8`0606UB9P1/EBT0Je@X06I?8`1PBAd0HD/T0P1RC2D01P1S
CBH0I4hW06==9P1RC2D0H4XS05m98P80FDLQ00@0FTPR05]98`1KBB<0FTPR0P1IAb4205U77`0405Y8
801KBB40G4XR05a:8P80GD/S00D0H4hX05m=9`1NC2H0GD/U05a:900205Y88P0705U78@1KARL0FTDV
05U69P1GAbH0ETHU05E69@0205=6900605Q89`1FAbH0E4DT05958`1>A240C4@P0P1:A20404i38`03
04e28P1<@B40BSlO0080BChN00L0B3dO04Hm7P13?1l0@3/N03hj7`0k>B00>SPO00D0?3PM0`0k=a`0
1@0g=Ah0=S@M03Hd7@0e<a`0=38K0080<c4J00T0<S0I038]6P0`;AX0;b`I02d/600Z;1L0:2/F02L/
5P0V:aD0200T9a`3024T6`8082<J0`0O8QT201lR5`0301hQ600M81T071hI00806adJ00<06Q`K01PN
6P0H7QX00`0G7AT301HL60<061XI0`0G6AP201HH5`P05ALF200B61PA01@E5a004Q<E600D5AL8014G
5a<051DG0P0C51H3018C5C0051DG200E5QP801DG5QT05QPG00@05ALF01HH5`0F61L05QPG0P0G6AP2
01PJ6@P061PH0P0G6AP201PJ6@806A/J0P0J71/;01XJ60<06a/I0P0L71X@01dN60P081lJ4`0O7QT2
020O6P<08B0K200V8A/802PT6`06034T7P0_91h0;b@N02dT7@0/9Ad0:BDL0P0X9A`302PT6`809b<J
0`0V8QT202LR70809R4K0`0U81X00`0T7aT08B0K024P6`0G024P6`P08R8J200P7aX8024P6`808R8J
0`0S8a/302@T700402HO5`0W81P0:B8J02/T70<0;2DM00@0:b@L02dW6`0^:1`0;bTM0P0`:Qh00`0_
:Ad0;RPL02dW6`0203@X700303DY7@0f:Qh0=b/O0080>2`P00T0>BdQ03D[8@0e:al0>2`P03X/7`0m
;Ah0?bhN03l^7011;Qd01013<R02048a7`80@C0N0P12<Al2044`7P80@2lM0P0o;Q`01P0o;1h0?R`N
03d[7@0l;1d0>B`L03L[6`80=2/J00P0>BdQ03P/800f:Qh0=BTM03@X700e:Ad0=RXN03L[7`<0<RPN
0P0a9ad3030V7004038X7P0a9ad0<2HL030V70@0;bDK200^8ad0100`:B40;bPP02lX800_:20302hW
7`0<02dV7P0[9ah0:RHM02PT6`0W8aX0:2@K02TU700Z9Qd0:bLN02`V6P0]9a/0;RPL0P0_:Ad202hX
7080;BLK0P0_:A/2030Z70@0<B/M200^9al0100`9Al0<BHP034V800a9R02038W8@80<bPR0`0`:Q`3
034[7@80<R`N200g:a/203<Y7@80=2XN00@0=B/O03H/800g;B40=bdQ200g:a/0100i;B40>2`P03P/
800h;20203L[7`80=RXN0P0`:Qh0100a:al0<R`P038/800a:al2030Z7PP0;bTK00P0?3HX03Xb9@0g
;b80=2XN03DY7@0f:1d0>BPN03XY7`D0>blO00<0>RhN03T]7@0i;Ad0200n<Ah803`a7`0403d/6P0o
;Q`0@C0N04<b8080AC@R2P14<b402@11=ah0@SHN04<g7`16=b00B3PQ04Xh8P1<=b80CCPS04Tg7`03
04Pf7P<0AcDM00D0AS@L04Lg8017=b00ASHO04De7P0204@d7@<0@c<L0P10<b03044d8@<0@SDR00H0
@CLN048f7P12=Qh0ACHO04Hf7`18=R0204Xe8080@cHS00<0@SDR044d8@10<b000P0o<Ql00`0n<Ah0
A34P04@a800304<`7`<0@RlN00H0Ac@U04Dd9014<b<0@C4Q03d`7`0k<1h203L_700503@X600f:QX0
>BdM03/_7`0m<B400P0n<R800`0m<B40?S4N03d`7@0603d`7@80@S<N00`0?c8O03`a7`0i<Ah0=c0N
03H_7`0d;Qh0>blQ03``8P0l<200?C8P03hc8@0o=202040e7`<0@C@S:oooool002[ooooo00<0W754
09ebA@2MLTD00P2MLTD309icAP80VG1200<0VVm209]_@P2MKT800P2NKD800`2PKD80WG5009ea@006
09ea@0<0WgE31@2NM4800`2LLT00WG=109ec@@0409ec@@0309ab@02OLd80Wg=200H0Wg=2202PMD82
09mc@P<0X7A30`2QMD@20:1e@P80XGI30P2RMd@20:=hA@80XWU50P2QN4@30:1g@`80WgI2202QMdD2
09mf@P<0WWE1102MM40209ec@@0309ec@`2LLD@0W7560080Vg1601P0VW1009M]?@2CJ3/0T6Dj08iS
>@2>HS/0Sf<l091T?`2<HSX0Rf4i08QQ>026HCL0Q5le085N=01oGS<0OUdb081K;`1oFS00OUT_07eG
<01kEC00NU@`07UB<@1hDC0207]E<00307YD;`1iDbh0N58]0080Me4/00<0MU0[075@;@1aD2d00P1`
Cb`406m>:`0306e?;@1/CR`0K4h/0080Jdd[0P1ZC2X00`1YBbT0K4/X06a;:00206a;:0@0KD`Y0100
KU0Z075A:`1bDR/0ME@[07QE:`1lEb/0OUL/07mI;020FS<0P5/a085L<P23GS80Q5lb08EQ<@26HS00
Qf<a0P29Hc@0102:I3D0RfDf08aV=`2=IcP208iX>@<0T6/g00<0SfXf08iY=@2=J3@00P2=J3@02@2?
I3L0TFHi09=X>`2EJSd0U6Tl09=X>`2@ICP0SV<f091U>P02095V>`05099W?02CJ3d0U6Tn09AY?P2E
JSl0202@ICX02P2@Jcl0SfPm08aV>@2<HcD0SF<c091T<`2DISD0UVPf099W>P2CJ3/209EZ?@0509AY
?02AIST0TFHi08eR=@2;H3<00P2<ISL608]U=P80Sf@g0P2>HcH0102?I3L0TFHi09=X>`2DJC`2091Z
>`80SfTj102>J3T809=X>`<0U6Xh0P2EJcT309I/>P0409M]>`2HKS`0V6hl09U_?@@0VW0n00H0V795
09Qb@`2ILd@0VG=209Ud@02IM3l209Qc?00309Ia?@2GLSh0Ug8n0080V7<o0P2IM4000`2HLcl0Vg4o
09]a?`0909Y`?P80VFlm0`2HKS`209Ia?@@0UG0l1P2DKc/409=^>P03099/?@2CKCh0U6ho0080UFm0
00H0U6ho09=]?P2BK3d0UG0l09A_>`2CKSX2099]>@0409=^>P2DKc/0UG0l09=^>P80TVdi0P2AK3P3
091[=`0308eY=@2>JSH0Sf/g0080TFdi00L0Sf/g08iZ=P2=JCD0SfXm08iY?02<IcX0RVDh0080RF@g
00P0RVDh08]V>@28ISP0QfDg08IT=P25HcD0Q68d089P<P80PEla0P1nH2h0101mGRl0O5d_07]L<01i
FRh207QH;`0707MG;P1cDb`0LU8[06i@:P1[CbX0IddZ06E;:P020699:P0@05e69`1KA2D0Ed8U05A0
9@1??R@0Bc/Q04Pj8017>Al0@CLN040f7@0m=Ah0>S@N03Lb7P0c<1d0<RlN030_7@80:R/M0P0Y:Q`2
02PY6`809bPJ0P0V:1d0100U9a`092HK02<U6P0S9AX2028T6@<08B@M0`0P8a`501lR6`8082<L2`0Q
91d202<V7`808RDN0P0Q91d2020S70808B@M00@082<L01lR6`0O8Q/07R4J0P0M81T0100O8Ah07R0M
01dO700M7a`201/M6P0:01XL6@0I6aP06adL01`N6`0M7a`07b4L020S700R9A`08bHK02@W70P09bTN
0P0Y:Ad01P0Z:Qh0:b/O02TY7@0W9a/092@H028R5P8092<N00H09BDM02HV700W9a/0:BXL02X[6`0[
;1`803<]7`<0>34N00<0>C8O03/c800k<b000P0l=242048h7`04044g7P10=Qd0@3HM03le7080?S@K
00<0@CLN048h7`13>B000P14>R402P13>B00@SPO044g7P11=ah0@SDR044d8@10=B40?CDP03/e7`0j
=1h203Pc7@P0>C8P00<0=S4N03Lb7`0h<b000P0i=2402`0h<b00=c8O03Lb7`0e<1`0=S4M03Db7`0d
<b40<C8R02h`8P0/;R00:BdO0080:2XM100W:A`202PZ7@80:2XO0P0W:Ah0100V:1d09BLL02DW700U
9a`2028U6PH08bHK0P0V9Q`0:P0U9A/092@J02<S6@0R8QP08B4G020P5P0U7b40:28T02`S900Z8Ql0
:B0K02hT6`0i;2<0@SD/04/g5P1A>QX0F40N06988`1/D2T0MEP`07aL<`20Gc@0QVHm08QX?`2:JT40
RVe308U/@025JSd0PVLj07iV=P1`GSH0KU`f06QI<P1QDbh0FD`Y0557901<@B40BD0O03lb8@0m<200
>bhN03T/7080>B/N0P0j;1l03P13>B00A3XQ04Dk8P17?B@0B3hU04Y09`1;@BP0C48Y04Pn9@19?bH0
BT0W04a2:@1>A2/0CdD/0P1AAbh01P1=A2L0Cd@X0515:@1CABX0EDD[05Q7;@80FdL^00d0EDHU05I7
9P1GAbH0FTLW05a7:01OB2T0H4TZ0699:`1QBbH0HT`W06A>:@1VD2/0Ie4/0080IU0[00T0IDlZ06QG
:`1WERX0IE@Y06=A:@1PCRP0GT`X05a9:01KB2L00P1ABRd02P1@BB`0CTLZ04i7:P1>AbX0D4T/05=<
;`1DCC00EdLU05U99`1LC2X205i>;00905e=:`1KBbT0FTXX05=38@1DA280EDDS05M79@1HB2H0FDTW
0080FTXX0P1MBBH01`1PBBL0HTXX06A::@1WBRX0J4/[06U::`1UCBT00P1TC2P0401SBbL0HTXV0659
9@1PB2@0GdLS06598`1SBbD0IThX06M?:@1VCRP0HDTS05a47P1I@A/0G4HQ05]5801I@ah205M17004
05U37P1KAB00G4HQ05a89@80FdLT0P1JAR<205U58P0I05Q48@1??AT0D3hJ04hn701=?Qd0CD0P04]0
8P1<@B<0Bd8U04/n701<?ad0CSlN0551801DA2<0F4DU05Y59P1KARL0ET8M05M37P1IAB00G4PS05m;
9P1QCBP0HdlZ06EA;00206IA9P0306MB9`1XDbP0JE@Y0080JUDZ00T0JeH[06YC:@1[E2X0KEH/06iG
;@1_F2h0KUL]06eF;01/EB/0201_E2T206mC;003071D;01`EBX0L5DX0080LEHW00<0LELV07EJ;@1e
FRd0101eFRd207AI;080ME/Z00X0M5TZ07=H:@1bEbX0LEH[071D;01_Db/0K50X06eA:@1^DbP0KU<V
0P1_E2D206mE900906UB9P1WD2@0ITlS06QA9@1/EBT0Je@X06I?8`1RBal0HT`U0080HddV00T0I4hW
06E?:01TCRL0HddV065;901PBR<0ET@N05Q6801JB2800P1LBR@00`1JB280F4HP05I47P0205I77P80
EdPO00X0F4TP05U:8@1IBR40FDXQ061>:01OCBL0GT`V05a:901KBB<0FTPR0P1HAR0205]79P0405U6
9@1GAbD0ETHT05E79080E4LT00P0F4PW05I79P1DAB@0DD@R04i48@1=AB40BdDQ04a68P<0CT<S0P1=
@R802`1<@B40Bd0P04Xo7`19?Qh0BChP04Ln7`14?B00@C`O03lk800l>R40>cTP0080?CTN100l>1d2
03/g7080>3HO00@0=cDN03Hd7@0d<Q/0<c4J0P0b<1T01P0c;Q/0<BhK030]6P0^;AT0:bdH02T/5`80
9b`F0`0S9aT202@X6P<09BTK0P0R9A`3024T6`<082<J00P082<H01lR5`0O8QT07R4J01dO6P0L7Q/0
6adJ01/M708061hJ0`0G7AT301HL60<061XI0`0G6AP:01HH5`P04QPH4@0D5AL@018C5AP051DG200A
5aLC01@E5`<04a@F0P0B4aD`01@E5`P05AHH200E5aHL01HH5`805aTH0`0H6QT801PH60805aTH0P0H
6QT201TK6P806Q`K2`0J6QP301/K6@8071`J400M7QP8020O6Q807ahI0P0P7aX2024P6`808R4L200V
8A/402PT6`@0:BDL00P0<bHP034V800`9Al0;bHO02dV7P0[9ah0:RLN02TV7@<0:2@K0`0W8aX202HR
6@<09b8L0P0V8A/302DP6PP08R4L4@0Q81/8028R6Q008B0K0P0R8QX302<S6`<092@L0P0X8AT00`0Y
8QX0:R<K02/T700302`U7@0302`V6P0]9a/0<2XN0080<B/O00<0<2XN02dW6`0/9QX00P0d:1`00`0e
:Ad0=RXN03L[7`0203P/800903T]8@0e:b40=R`P03P/800j;1l0?BdN03l^7P10;ad0@BhM00H0@c8P
1012<Al2044`7P80@2lM0P0o;Q`01P0o;1h0?R`N03d[7@0l;1d0>B`L03P/7080=B`K00P0>BdQ03P/
800f:Qh0=BTM03@X700e:Ad0=RXN03L[7`@0<RPN100a9ad00`0c:Al0<RPN030V700302lU6`80<2HL
200a9R0203</9004038[8`0a:R80;bPP02hW7`80;BHN00<0;BTP02/W7P0Z9Qd00`0X91/01@0Z9Qd0
:bLN02dW6`0]9a/0;RPL00H0;bTM0P0a:A`6038Z7@P0;bPN00@0<BLN038X7`0b:1l0<RPO0P0c:B02
03@Z8@80<RXM1P0c:ah803L[6`<0=2XN00<0=B/O03H/800f;2000P0g;B4803L[6`@0>BdO0P0h;1h2
03L[7@03038Z7@0c:ah0<b/N00@0<b/N00<0<RXM030X6`0`:1/01P0`:1/02P0m=bT0>c<V03H^8@0c
:Ad0=2PL03LY7P0l:b40?RdS03X^7P0k;al303``800303/_7`0j;Qh0>BdM00P0?c8O200l<Al01@0l
:aT0?RdK044`7P14<b40AC@R00<0ASDS2014<b402011=ah0@cLO04<g7`16=b00AcLP04Tg8@1;=R40
C3LR2017=Ad01P19>B80B3PQ04Lg8016=Ql0ACDN04<c70<0@S8K1P11=242048e8P0803le7011=Ad0
@SHN04Df7`17=b00BCLQ04`g8P1=>2<204<f8`04048e8P11=240@C@Q040c8080?c8O0P13<R03048a
7`<0@C0N00d0B3DV04He9@14<b<0@S8R03d`7`0k<1h0=blL03H^6`0d:1P0=RXJ03T]7@0l<200?S8R
0080?c<S00D0?S8R03`_700m<1d0?C0M03ha7P0203lb7`80@3<P00h0A3DP04<d7`10<b00?C8P03Ta
7P0g<1h0=BhN03@^7P0k;b40?30R03``800m<R00?S<Q03ld8080@3DO0`11=2<[ooooo`00:_ooool3
09aaA00309ebA@2NLdH0WW=60080WgA70P2IL4800`2JKd80Vfm209e^@P0209i]@P030:1]@P2LL3l0
W70o00H0W70o0P2NM48609me@`<0W7A10P2KLd0309ad@@P0Wg=2202QMT<209mc@P<0X7A30`2QMD@2
0:1e@P80XGI30P2RMd@20:=hA@80XWU50P2QN4@30:1g@`80WgI2202QMdL309mf@P<0WWE10`2MM402
09ec@@0309ab@P2LLD@0Vg150080Vg1600P0VFlo09M]?@2CJ3/0Sf@i08eR>02=HCX0SV8k08mS?P80
Rf4i00@0R64h08EP=P24GcD0P5dc0P1nGC80201oFS00OUPa07eG<01lES40NU@`07UB<@1hDC80Me0a
0P1jE2l00`1iDbh0N58]07MA;00207I@:`0307E?:P1`Cb`0L4l/00<0Kdh[0`1^CBX406]=:`@0JT`Z
00<0JdXW06a;:01/BbP00P1]C2T206i=:P0?06m>:`1_DB/0LU8/07=C;01fEB`0NEH/07eH;01oF2d0
P5X]081J<`21G380PUdc08=N<P24Gc80QV8b0080Qf<a0P2:I3D0102;ICH0S6Hg08eW>02>J3T208mY
>P80TF`h00@0T6/g08mZ=P2>JCD0SFPd0P2<Ic<0202>HcH0T6Dh09=X>`2DJC`0UFXm09=X>`2AIST0
Sf@g0P2AIS/0102BIc`0TfPm09=X?@2DJCh209EZ?`P0T6Dk00X0SfXn08iW?02<IST0S6<e08eS<`2@
I3<0UFLf09MY=`2CJ3/0U6Tl0P2FJch01@2EJSd0TVLj099W>P2>HcH0S64d00<0RfDf1@2<ISL2091U
>00608mT=`2>HcH0Sf@g095V>@2CJ3/0U6Tl102?JCX208iX>@80SFLh202CJ3/209AZ>080UF/i0P2F
K3X209M]>`@0V6hl00X0VFlm09Y`?P2JL3h0Vg4o09UcAP2ILd@0V79309Qb@@2HLcl0V7<n0P2IM3d4
09Ia?@80Ug8n0P2HLcl609Y`?P80Vg4o0`2JL3h209U_?@<0V6hl0P2FL3l209E_?P80U6hm0P2CKC`4
09=^>P@0U6lk00<0TV`m09=]?P2DKSl00P2EKd001P2DKSl0Tfdn099/?@2EL3`0U6lk09=^>P80TVdi
00<0Tfhj09A_>`2EL3`00`2BKCT2095/>080T6/g00@0SfXf08eY=@2>JSH0Sf/g0P2AKCT0202?JcL0
SVXf08eY=@2?JSd0SVTl08]V>@29I3L0R6<f0P29I3L03`2:ICP0QfDg08MU=`26I3H0Q68d08=Q<`22
H380PEla081N<01nGc00OEh_07aM;`1jFbd0NEX^07QH;`0307MG<00@075C;@1`DR`0KE4/06]>;01V
C2/0HdX[0619:P1OB2T0FD@W05M29@1D@2D0D3lS04`l8P18>R00A3PP04<g7`80?CDN00H0>S@N03Lb
7P0d<Ah0<C0N02l]7P0];Qh302TZ7080:2TK0`0W:1X202DV7P8092DM00@08b@L028S6`0Q8QX08B8J
0P0Q91d3020S70H07b8K0P0P8a`;024T7@<08RDN0P0Q91d3020S70808B@M00@082<L01lR6`0N8AX0
7B0I0P0L7aP301hP7@0301dO700L7Q/06adJ00806adJ00P071hM01dO700N81d0828M024T7@0S9Qd0
92LL02DX7@P0:2XM0`0Y:Al02`0X:1h09bLM02DU6`0R8QP08B4G02<R7@0T8ah09BDM02LW7@0X:1`0
:BXL0080:R/K200e;B0303Xb7`0603/c800j<b00>S<P03Xc800k=240@cTP0P12>1l02011=ah0@3HM
03le700o=A`0?S@K03hf7`0o=b00@3PQ0P11>B802P10>240?cLP03hf7`0n=Ql0@3DQ03ld800m=B00
?3@O03Xd7P0h<ad203Dc70P0=c4Q00<0=C0M03Ha7P0h<b000P0i=2402`0g<Ql0=S4N03@_700a;Q/0
<RlL034`7P0`<B40;S0R02`^8@0X;1h09B/O00P09RPM00<09bTN02HX7@0V:1d00P0V:1d302DW7080
8bHM1P0R9A`202LT6`809R<J0`0U8QT08@0T8AP0:QlM034S8P0e:280=BLN03HV6@0k:QP0B3HR05=1
:`1UBQd0JDhQ075D:01iGBh0PV<e08MX>@2;Jc`0S6`k08e/@`2<JT@0RFU208AW?`1kHST0Le`c06aF
;@1YDbX0EDPX05=69P1=@R@0AchQ044j7P0l=Q`0>C<K03Hb6@0303H/8P0503L]8@0j<2@0?C<W044g
:`13>R/0201<@RT01P19?bH0BT0W04]1:01=@bX0CdD/0516;@80DTP_00H0BT4T04]0901<@BD0D48W
0592:01EA2X205Q4:`0505528@1B@b80E4@S05M4901IA2D00P1KA2D0101L@bD0FdLR05a88`1NBRD3
05m;9P0:05e9901LB2<0HE0U061?901OCBD0GD/U05Y8901HAB@0Ed@T05I38`80CdP/00X0CTL[04e6
:P1=ARX0CDHZ04i7:`1@BBd0DDX^05928@1C@b80ETHU0P1HB2L0101GAbH0EDDT05=38P1B@R4205=3
8P0305A48`1FARD0EdLV0080FDTX00P0Ed<P05Q48@1KA280GTHT06579P1TAbL0IDPX06M8:@<0I4XW
0180ID/X06I<:@1WCBX0J4h[06U?;01YD2P0Je8Z06iE;@1`Ebl0KeH^06]B:P1VCBD0HdXR06Q?9`1V
CBD0I4/S0658801OAQh305i57@80H4XS00@0GdTR05e7801LAQl0FdDN0P1JA1d205I47P0>05927P1@
@Ql0CD0N04Xo7`19?Qh0AchO04/n701<?ad0CSlN05107`1B@R40ED8R05M28`1H@b@205]98`80G4XT
00D0GD/U05i<9P1OCBL0GddW06==900206A>9@0306E?9P1VD2L0Ie4X0080J58Y00<0JE8X06YC:@1/
EB/00P1^Ebd00`1]ER`0K5D[06]D:P0806mD:@80Ke</00H0Ke<[071E:P1`EBP0L5DV075F9`1aEbH2
07=H:`H0M5T/0P1fG2T0101eFbX0M5TZ07=H:`1cF2/2079G;080Ke@Y0P1_E2L0201_E2D0L5HU075G
901aEb@0Je@X06QA9@1VCb<0J54U0P1[E2P00`1WD2@0Hd`P06==9P0206A>9`0906E?:01VD2T0IDlX
06A>9`1RC2D0HD/T05M57`1HAR00FdTS0080GD/U00@0FdTS05Q6801GAAl0ETLN101GB1l305Q98080
GddW00<0GT`V05e;9@1LBR@00P1JB280101IAb40G4PU05a89@1KBBD205Q8900<05I88`1EBB<0EDTS
05U9:01FAbH0E4DT05548P1>A240CDDQ04e78`1>B2@0CT<S0P1=@R8504a18@0804Xo7`1:?b40B3lP
04@m8012?B00@3`Q03dk8P0l>R4203hj7`80?CTN0P0l>1d203/g700>03Tg800h=Ql0=cDN03Hd7@0e
<a`0=38K03<a6P0b<1T0=2lL038_700a;Q/0;bhJ02`^6@0Z;AP202P]5`<092PI0P0U:AX302HZ6`80
8bHM0P0R9A`4024T6`8082<H00<07b8I01hQ6P0M7aX00P0L7Q/00`0K7A`061hJ01PN6P0301LM6@<0
5Q`H0`0H6QT301LI60X05QPG200B61PA01@E5a004Q<E600D5AL8014G5a0051DG0P0E5QP301@E5`/0
4a@F:00D5AL801DF60P05ALF6`0F61L201LI608061XI0P0I6aX801PH60805aTH0P0H6QT201TK6P80
6Q`K2`0J6QP301/K6@8071`J400M7QPK020O6P808B0K0`0R8A`802LR700302LS6P0X91/0:2@K0080
:BDL0P0Z9Qd01`0[9ah0<bHP034V800a9R00;bHO02hW7`0[9ah00P0Z9ah202TU70<0:2@K0`0W8aX2
02PS7@809b8L0P0V8A/202DP6PP08R4L4@0Q81/8028R6Q008B0K0P0R8QX302<S6`<092@L0`0Y8QX0
200Z8a/0:b@L02`U7@0]9Qh0;RLO02`V6P0]9a/0<2XN0P0a:al00`0`:Qh0;BLK02`V6P0203@X7003
03DY7@0f:Qh0=b/O0080>2`P00T0>BdQ03H/8P0f;200>BdQ03/]800n;Ql0@2lO040_7@12;ah01P13
<R0204@c8@80@S4O0P11<1h2040_7@80?bhL00H0?b`N03h/7P0m:ad0?2`M03X]7@0i;Ad203H]7008
03T]8@0h;200=RXN03DY7@0d:1`0=BTM03HZ7P0g:al8038X7P0803@Z800c:Al0<BLM02lU6`0^91X0
;bDK034W7@0b:1h803H[9@80=2dU00@0<b`T034Z8P0`:B40;RLO0P0]9Qh0200]:B00;2PO02XV7@0Y
9A`0:2@K02TU700Z9Qd0:bLN100^:1`302lY7@04030Z7P0a:al0=2XN03@Z7PH0<bTM200`:Qh2038X
7P80<bTO0`0d:R000`0e:b40=B/O03D[7`0303D[7`<0=2XN200h;1`303L[7`@0>2`P00<0>BdQ03P/
700h;1`01P0h;1`303X^7P<0>BdM0P0h;1`303D/7@80=2/L0`0e;1d8038X700;03/e9`0i<B@0=BdP
03@Z7P0f:Qh0>R`Q040_9@13<RP0>BdM03X^7P0l<2000P0n<R800`0m<B40>blO03X^7P0803lb7`P0
?C8P00H0?B`J03l^7011<1h0A3<Q04He8`17=R@204He8`P0A3<Q00H0@SPO04<g7`13=al0ACHO04Lg
8018=R0204Xe80@0AcDM1018=Qh204Ti8P0404Ph8@16=Ql0ACDN04@d7@80@c<L00<0@S8K048e8P12
=B801P11=240200o=A`0@CDM048f7P15=Ql0B3PQ04Xh8P1=>2<0CSTT0P14=b@01013=R<0@SDR044d
8@10<b0203lb7`80@S<P0`11<Ql3040a7P0604Ld9@16=BD0A3<S048b8P0n<B00?34O0P0h<1d01P0e
:AT0=b/K03X^7P0l<200?S8R03lc8`80?S8R0P0m<1d00`0n<Ah0?c8O040c8002044d8@0?048e8P14
=B00A3DP040c800n<b40>S8O03L`7P0f;al0=2hN03/_8@0l<280?30P03db800n<b40?c@P0080@3DO
0`11=2<[ooooo`00:_ooool209Y_@P0309]`@`2LLD@0WG950080WW=600H0WgA709U`@P2IL480VVm2
09]_@P2MKT8209i]@P030:1]@P2LL3l0W70o00H0W70o0P2MLd4309id@P<0WgE300<0VgI209Ye@@2I
M4000P2HLcl00`2IM400VWE109]f@P080:1d@`P0XGI30P2OLd830:1d@`<0XGE40P2PMD820:5f@`80
XWM40P2SN4D20:9iA@80XGQ40`2PMd<209mf@PP0XGI90P2PMd<209mf@P<0WWE100L0WGA009ac?`2K
LCl0Vg4o09]a@@2JKd80VVm40080VFi401P0Ufdm09E[>`2CJ3/0TFHk08mT>P2>HS/0SF4j08eQ?02;
HCT0RV0h08MP=`25H3H0Pehd081M<`1nGC80OE`a07mI<P1nF3<0OELb07aF<P1jDc80NE8c07QA=01g
D3<207UC;P0307QB;@1gDB`0MU0[0080MDlZ00@0M4hY06m>:`1_CR/0Kdh[0P1^CBX306e<:@P0JT`Z
0P1[BRL00`1/BbP0KD`Y06i=:P0206m>:`0A071?;01`DR`0Le<]07AD;@1gERd0NUL]07iI;@20FBh0
PE/^085K=021G380PUdc08=N<P25H3<0QV8b08MS<@28I3800P2;ICH00`2<ISL0SFLh08iX>@0208mY
>P06091Z>`2AK3P0T6/g091[=`2?JSH0SVTe0P2=J3@0102<Ic<0Sf@g091U>02AIST309=X>`03099W
>P2AIST0TVLl00<0TfPm102DJCh8091T?@0908aW>`2=IS/0S6Hi08iU=`2?ICD0TFDd09EW=P2FJ3H0
TfPk00<0U6Tl00D0TfPk099W>P2BIcX0T6Dh08mT=`0208aV=`<0SFLh0`2>J3T00`2CJ3/0TVLj091U
>00208mT=`03091U>02BIcX0TfPk0080SVPi0`2?JCX00`2>J3T0S6Hg08]U=P0809=X>`<0UF/i0P2F
K3X309M]>`0609U_?@2HKS`0V6hl09M]>`2HKS`0VFlm0P2KLCl02@2JM4L0VG=409Qb@`2GLD00Ug8n
09Qc?P2IM3d0VWDn09Ia?@0209E`?00509A_>`2EL3`0UW4m09Mb?P2HLcl00P2IKcd309Y`?P<0Vg4o
0`2JL3h209U_?@<0V6hl0P2FL44209E_@00509A^?`2CKCh0TV`m099/?@2BKCT00`2CKSX309A_>`04
09E`?02BK3d0Tfdn09A^?`80UFm000H0U6ho09=]?P2BK3d0UG0l09A_>`2CKSX2099]>@0509=^>P2D
Kc/0UG0l091[=`2AK3P00P2BKCT01`2AK3P0T6/g08mZ=P2>JCD0SFTe08iZ=P2?JcL00P2AKCT01`2?
JcL0SVXf08eY=@2?JSd0SFPk08]V>@29I3L00P28HcH02029I3L0RVDh08MU=`26I3H0QF<e08AR=023
HC<0PEla0P20GS001P1nGc00OEh`07]L;P1iFRh0MeL^07MG<0<0MeLa01P0LE<_06iB;@1/Cbd0J4h]
06A;;01PBBX0G4LX05]6:@1F@bD0ED4V0550901=?B<0BC/Q04@h8012=R00@3DO03/e7`0j=1h0>3<O
03@a7P0a<1h0;BhN02`]7@0Z;1h202TZ7080:2TK0`0W:1X01`0V9aT09BHP02@U7`0T9Al08b@N028S
7@0Q8Q`00P0P8A/0100Q91d082<L020S700P8a`201lR6`807R4J0`0O8Q/2020S70/08B@M0P0R9Ah2
024T7@<082<L00<07b8K020S700P8a`00P0O8Q/0100N8AX07B0I01`O600L7aP801dO700801hP7`0O
8Ah07b4N024S7P0R9Ah08bHM02@W700U:1d202LY6`80:2XL0P0Y:ad202X/7P0>02PX800W9al09bLO
02HV7P0U9Ad08b<K028R6P0Q8AT08b8M02@S7P0V9Qh0:2PN02XZ7P0Z:ad202X[6`<0=B/O0P0f;202
03L]8@0703P^8P0n<B00?S4P03db800k<b00>S<P03Td800203Le8080@SPO0`11=ah3040f7@0303`d
7`0m=B00?SHQ0080?cLR00D0?SHQ03de800l=1l0?3@O03ld800203`d7`0303Xd7P0h<ad0=C<L0080
<c<K200c<2400`0d;a`0=S4N03Pc800203Td8@0303Lb7`0d;a`0<RdJ0080;RdK00T0;BhN02`^800[
;B00:2/P02@Z7P0S:Al092DM02DV7P0V9al00P0W:2000`0V9al09BHN02@U7@0802DW70808bHO00@0
8B@M020S700P8a`082<L0P0Q91d01P0V8QT09b<J02PT6`0Y9A`0:RHM02/W7P80;2PO01h0>BLM03l]
8@16<b80BcHQ04hi7P1F?al0HD/V06]C;@1hGR/0O68_085W=026K3T0R6hk08Q^?@26K3/0QF/j07mQ
?@1kGS`0M5Xi06]D=01PCBd0ETLX05138`1;@280?c@N03`d7@0i<A`0=RlL03<^6P0`;AX202l^7008
03L`9P0h<RH0>C<W03/e9`0o>BT0@ch[04M2;P19A2h204Y09`0404To9P18?RD0AcdT04Lm9080AS`S
0P18?RD03019?bH0Bd4X04a2:@1=@bX0CT@[04m5;017?R40B3dQ04Tn8P1=?b@0CclU05919`80ED4X
00D0Cd0O0511801C@b80ET<S05M28`0205U28`0405U08P1GAAl0FDLQ05Y88P80G4XT00<0FdTS05Y8
8P1IAb400P1LBR801P1KBB<0FTPT05Q5901GA2@0ET<S05E290<0EDLZ0`1DART305E7:P80Dd@U0`1D
ABH00`1B@b@0DD8S05118P0205=49@80DT<T00`0Dd@U05E69`1GB2T0F4TZ05I27`1G@b00FT<Q05e5
8`1OAB@0HdHV06A79`1VAbP306E9900806M;9P1YCBP0JdlZ06iB;@1_Dbh0L5@/075E;@1dF30207EI
<@0K079F;P1`E2`0KU8Z07AG;@1cER`0L5<Y06iA9`1[CR@0JD`R06Q;8@1WBR00ITlU06E>901TCB<0
HT/Q065:801OB1h0GTLM05e6701MBb<0G4XR05Q98P1DAR40D4<P04]17P19?a`0AchM0080CD0N00@0
CSlN04lo7P1@@1l0DSlO0P1D?b0305];9`0305Y:9P1IBBD0F4PT0080F4PT00H0HD/T069<9@1RC2D0
HddV06A>9`1UCbP206I@:@0806QA9`1YDRP0Je@Z06aE:`1]ER`0K5D[06]D:P1ZDbT806iC:080KU8[
00<0Ke<[06mD:@1`EBP00P1`EBH0101aEbH0LEHY075F:@1aERT3079G:P80LeP[0P1eG2H00`1eFbP0
M5XY07AI:P0207=H:`0=07=H;@1aER/0L5DX071E:01_E2D0L5HU075G901bFB<0LeXT06aE:@1YDRH0
ITlS06QA9@0206]D:00306QA9@1TCB40I4hW0080IDlX00P0IU0Y06MA:P1VD2T0IDlX06==9P1RC2D0
FTPR05]98`@0G4XT00<0FdTS05Y88P1GBR001`1GBR0205m=9`80GT`V101MBbD205m;9P0A05e;9@1K
C2D0FT/T05U;901HC2@0Ed/S05U9:01FAbH0Dd@S05138@1>A240CTHR04i8901@BRH0CT<S04e28P1<
@B400P1;@2002`1<@B40CD8R04i38`1;@200Bd0R04U08@15?R40@chQ044m8P0n?2<0?C/R0080?c/P
00@0?SXO03di7P0l>1d0?3PM0P0k=a`203Pf7`0403Le7P0f=1d0=S@M03Dc7080=38K00H0=C0M038_
700b;a`0<2lK02d_6P0[;QT202T^60P09b/J0P0T9ah202<V7@<08RDL00T08B@K024T6@0P8aP082<J
01lR6`0N81/07AlL01`N6`0L7Qd00P0H7QX301LM6@<05Q`H0`0H6QT301LI60805QPG200G6AP8018H
614051DG400B4aDH01@E5`P04ALG400D5AL301DF608051DG2`0C51HX01@E5`P05AHH200E5aHI01HH
5`<05aTH0P0H6QT301TK6PP061PH0P0G6AP201PJ6@806A/J0P0J71/;01XJ60<06a/I0P0L71X@01dN
61X081lJ0P0Q81/3028Q700302<R7@0W8Q`09b8L00H09b8L0P0W8aX00`0X91/0:BDL02XV7@0202/W
7P0702`X7`0c9R00<2DO030U7`0_9Ql0;BHN02/W7P0202TV7@<0:BDL0P0X91/302LS6P<0:2<M0P0W
8Q`302HQ6`P08b8M4@0Q81/8028R6Q008B0K0P0R8QX302<S6`<092@L100Z8a/01`0[91`0;2DM02hW
7`0_:200;BLK02hX700_:Ad00P0`:Qh00`0_:Ad0;RPL02dW6`0203@X700303DY7@0f:Qh0=b/O0080
>2`P00T0>BdQ03H/8P0g;B40>BdQ03/]800n;Ql0@2lO044`7P12;ah01013<R0204@c8@80AC@R0P12
<Al2044`7P80@2lM0P0o;Q`01P0o;1h0?R`N03h/7P0l;1d0>RdM03T]7@80=bhM00T0>BdQ03P/800f
:Qh0=BTM03@X700e:Ad0=RXN03L[7`0a9ad00`0b:1h303<Y7`0403@Z800e:b40<bTO034W7@80;R@J
00<0;bDK034W7@0c:Al0200g;2H203</9004038[8`0a:R80;bPP02hW7`80;BHN00<0;2PO02/W7P0Z
9Qd00P0Y9A`00`0Z9Qd0;2PO02dY800202hX7080;BLK00D0;RPL030Z7P0`:Qh0<R`P03<]8@0203L[
7`80=RXN100e:Ad8034[7@80<bTM0P0d:Qh303D[7`0303H/800i;B40>BdQ0080>2`P100g:al803P/
70P0>B/P200h;1`303/`7P80>RlM0`0i;Q`00`0i;Ad0>2`L03L[6`0203HZ6P0303L[6`0h;1`0>BdM
00P0=RXN00/0>C<U03P`8`0f;R40=R`P03T]8@0l;R<0@C0V04<b:00h;1`0>RhN03da8@0203lc8`03
03hb8P0l<200>RhN00P0?c8O200m<R00100o;Q`0@2lM04<b8015=28304He8`0304Dd8P14<b40A3<Q
00H0A3<Q00H0@SPO04<g7`13=al0ACHO04Hf7`17=Al204Td7`<0B3HN0P19=al304Xh8080B3PQ0P17
=b000`16=Ql0ACDN04@d7@0204@d7@<0@SDR0`11=242040c8008040f7@12=Qh0@cLO04Hg8018>240
BSPR04dh8`1>>B@204@g900404<f8`12=B80@C@Q044d8@@0@3<P0`0o<Ql303ha7P0604Hc9014<b<0
A3<S048b8P0o<R40?C8P0P0j<Ql0100h;1`0>BdM03/_7`0m<B4203hb8P0603da8@0l<200?S4N03ha
7P0o<Ql0@3<P0P11=242048e8P0>04@e8013=1l0@3<P03hc8@0k<b00>34O03L`800f<200>blQ03``
8P0l<200?C8P03hc8@0o=202040e7`<0@C@S:oooool002[ooooo0P2HKD001P2IKT40VVm209]`@`2L
LD@0WG9509icAP80VG1200<0VVm209]_@P2MKT800P2NKD800`2PKD80Vfln09]_?P0609]_?P0309]a
?`2LLT00W7900080WG=10P2NM480102OMD<0W7M309]f@P2IM40209Qc?`0309Ud@02KMT80W7M300P0
X7A3202QMT<209mc@P<0X7A30`2QMD@20:1e@P80XGI30P2RMd@20:=hA@80XWU50P2QN4@30:1g@`80
WgI2202QMTT30:1g@`80WgI20`2NMD401P2JLCd0VFlm09U_?@2IKcl0V6e009Q]@P80Ufa20P2DJSX0
1P2DJC`0TfPm095V?02>HS/0S60i08YN>@80RV0h00l0Qf0g08AO=@23GS@0P5dc07iM<P1mG340P5Xe
07mI=01nF3@0OEHe07]D=@1jDcH0NE8e07Q@=P1iDbh00P1hDRd00`1gDB`0MU0[07E?:P0207A>:@<0
KTdZ0P1]C2T306a;:0<0JD/Y1@1ZC2X206]:9`0D06a;:01]C2T0KTdZ06m>:`1`Cb`0LE0]075C;@1c
Dbd0MED^07QG;P1kF2h0OUT]085J;`21Fbh0PE/d085L<P22GC<0Q5lc08EP<`27Hc<208QT<P80S6Hg
00@0SFLh08iX>@2?JCX0SfTj0P2@JS/408mZ=P@0SVTe0P2AIST2091U>004095V>@2BIcX0TfPk09AY
?080UFXo0`2DJCh309=X?@P0T6@m00/0RF@h08]T>@2=IcX0T6Li099X>02CIcH0U6He09AV=02CJ3/0
TVLj095V>@02091U>080TFHi00<0TVLj09=X>`2=IcP00P2>J3T208mY>P80T6Xk00D0TF/l09I[?P2D
JC`0TVLj091U>00208mT=`0:091U>02AIST0SFLh08iX>@2?JCX0T6Xk08mY>P2>J3T0S6Hg08YT=@P0
U6Tl0P2EJcT209I/>P@0Ufdk00<0VW0n09U_?@2HKS`00P2GKC/04`2IKcd0Vg4o09ab@02JM4L0VG=4
09Qb@`2GLD00Ug8n09Qc?P2IM3d0VWDn09Ia?@2EL3`0U6lk09=^>P2DKc/0UG0l09Mb?P2HLcl00`2I
Kcd00`2JL3h0Vg4o09]a?`0209ab@0<0VW0n0P2IKcd309Q^?00609Ma@P2FL440UFm009A^?`2CKCh0
TV`m0P2AJc`2099]>@80Tfhj0P2DKc/209E`?003099/?@2CKCh0U6ho0080UFm000H0U6ho09=]?P2B
K3d0UG0l09A_>`2CKSX2099]>@0609=^>P2DKc/0UG0l08mZ=P2@JcL0TF`h0P2BKCT01P2@JcL0SVTe
08eX=02=JCD0SVXf08m[=`80TFdi00L0Sf/g08iZ=P2=JCD0SVTl08eX>`2;IST0RF@g0080R6<f0P29
I3L03P27ICL0QV@f08ES=@24HS@0PV0b085O<@20GS00Oed_07iO<@1lGC40NU/_07MG;P1fERl0MUH`
0P1fEC806@1gES<0Ke8`06aB;`1ZD2l0ITd^069;;01MB2T0FTLY05U6:01B@BD0DD0V04hn901;?B<0
ASXR04<g8@10=B40?c@P03Td800h<al0=C8O03<`7`0`;Ql0;2dM02X/7P0Y:ad00`0X:A/302LX6P80
9RLI00H092DP02<T7`0S91l08R<N024R7@0P8A`201lP6`<082<L0P0O8Q/301hQ6P<07b8K0P0P8a`>
024T7@<082<L0P0O8Q/2020S700301lR6`0N8AX07B0I008071lH00H06ahG01/M6P0K7AX071hK01dO
700N81d201lQ7P09020R7`0Q8b808B<P024S800R91l08RDN02<V7@0S9Q/092LL00809RTH00H09bXI
02T/6`0Z;A`0:bhM02`_7P0]<1l202HU800402DT7`0T8ah08b8M02<R7@<08R4L00D092<N02LW7`0Y
:Al0:b/O02//7P0202X[6`0803<Y7@0d:Qh0=B/O03H/800g;B40>2hR03T_8`0j<2@2044a8@0403lb
8@0l=240>S<P03Le8080=SDP0P10=Qd3044g7P<0@SPO00<0>C<M03Xd7P0k=Al00P0l=R00300k=Al0
>S@N03Tc7@0i<ad0?3@O03/e7`0j=1h0>3<M03Dc700c<a/0<C<K030b6PP0<BlP00<0<bhK03D`7@0h
<b000P0i=240100f<Ah0<RdJ030[600/:aT202//700802/]7`0Y;Al09B/O028Z7`0P:1d092DO02DV
800W:28202PY8`0302LX8P0U9R0092DO00P09BLL030092HQ02<U800Q8ah07b4L01hP6`0O8A`0828M
024S7P0U8AP09R8I02PT6`0[9ah0;RXQ034]900c;bH0=30W04`f7`1A>b<0FT8V069:9P1[DRT0Le/[
07eT;P23J340Pf`h08E^>P27LSd0Qg4o08=_?01mJCL0M68`071N;P1WCC80HTX^05Q4:@1<?R@0@cTP
03`f800g=B00=SDP03Lb7`0f<Ah0<RlN034^7`0`;R40;blS02la900`<RL203`i:P0603`i9P0l>RD0
?S`U04509014@bD0AD@U0`15>b8504@j8@80AS`S0P17?B@204Pn9@80BClV01<0AchQ04Pm8@19?R80
CClT04lo9@1A@2H0E40W05E1:01A@R40Dd@S05E5901IARH0FTDV05]49@1J@b@0FT4S05Q6801IAb40
FdTS00<0GD/U00H0G4XT05]98`1LBR@0G4XT05a:9P1KB2L205]8:080FTLY1`1MBBH205a89@0405Y<
;`1IBbh0EdT/05E7:P@0DdDX00<0EDLZ05A6:@1CABP00P1BA2L03@1CABP0EDLZ05I8:`1IAB80FTHS
05e6901OAbD0HTPW06E8:01VBBT0IdPY06U=9P1XC2D00P1WBb@01`1XC2D0JThW06a@:@1^DR/0L5@/
075E;@1bERh01@1cEbl0601kG300NU/_07UJ;P1hFBd0MeP/07IG:`1eERX0M5DY06mG:`1^ERX0KEDY
06]C9`1XD2@0IThR06E=8@1TC200HE0U061>9P1LCB@0F4XS05A88P1@AR80CT@Q04a48080CT4O00@0
Cd0O04lo7P1>?Qd0D3dM0P1@>a`205E790<0E4HS0`1CAB801P1OBB80H4XS061:8`1QBb@0HT`U06==
9P80I4hW00P0ITlU06M@9P1YDRP0JU<Y06]D:P1ZDbT0JE8X06QA9`P0KU<X0P1^DR/00`1^DRX0Ke@Y
06mD9`02071E9P03071F9@1^DbH0KU<V0080Ke@W00@0L5DX075F:@1aERT0LEHY0P1dFb<00`1dFbD0
M5XW07=I:00207=H:@80LeP[00T0LULX071E9P1`ERD0L5HS079I8`1dFb<0ME`T06eF:P1YDRH00P1W
D2@01@1ZDbL0Je@X06UB9P1UCR80IDlX0080IU0Y0`1WDBX00`1UCbP0I4hW069<9@0205i<9P0405e;
9@1LBR@0G4XT05e;9@80GT`V201GBb4205i<9P80GddW0P1PCRP2065?:@80HDhV00@0H4hV05e>9@1M
CRD0FdhT0P1JCR@05P1JBRT0ETLV05=48`1@@b40CD<P04i68P1?BBD0DD/W04i38`1=@R80Bd0P04Xo
7`1;@200C44Q04i38`1?A2@0C44Q04]08P19@240ASlR04@o8P11?B8203hl8`80@3`Q00H0?c/P03hj
7`0m>Ah0?3PM03/g700j=Q/203Le7PH0=S@M00H0=C0M03<`7@0b;a`0<C0L02h`6`0/;aX202X_6@80
:c0L00@0:RlK02T^6P0Y;QX0:2dI0P0W;1P0100U:1l092LN02@W7P0T9ah202<V7@808RDL0P0Q91T0
1P0P8aX07b8K01hP6`0M7a`071hK01`N7@8061hJ0`0G7AT301HL60<061XI0`0G6AP201HH5`P05aTH
200B61PA01@E5a004Q<E600D5AL8014G5a0051DG0P0F5aT201DF60<051DG00<04a@F018C5@0B4aD0
1P0B4aDX01@E5`P05AHH200E5aHI01HH5`805aTH0P0H6QT401TK6PP061PH0P0G6AP201PJ6@806A/J
0P0J71/;01XJ60<06a/I0P0L71X@01dN60P081lJ4`0Q81/3028Q70808b8M200W8Q`202LS6P0702PT
6`0Y9A`0:RHM02/W7P0/:1l0;BTP034T7P0202lT7P0302hU7P0/9Ad0:RHM0080:2DL0P0Z9Qd202TU
70<0:2@K00<09b<J02PS7@0X8ad00P0X8ad202LR70809R4K200S8QdA024P6`P08R8J200R8A`8024P
6`808R8J0`0S8a/302@T7080:b@L00T0:R<K02TR6P0Z8a/0;2DM02lX800`:B40<2XN02lY7@0^:1`0
0P0]9a/00`0^:1`0;bTM030Z7P0203@X700303DY7@0f:Qh0=b/O0080>2`P00X0>BdQ03L]8`0g;B40
>RhR03`^8@0o;b00@2lO044`7P12;ah0@S4O0P13<R0204@c8@80AC@R00<0ASDS048a7`12<Al00P11
<1h2040_7@80?bhL00H0?R/M03d[7@0n;1h0?BdN03/^7P0j;Qh203P_7P0803T]8@0h;200=RXN03DY
7@0d:1`0=BTM03HZ7P0g:al2034W7@80<RPN00L0<bTO03@Z800d:R00=2XP03H/8P0d:R00<BLM0080
;R@J00<0;bDK038X7P0d:R00200d:B<0100a:R80<2TQ030Y8@0_:20202hW7`80;BHN00X0:bLN02XV
7@0Y9A`0:BDL02XV7@0/:1l0;RXQ02l[8P0_:Ad0;RPL0P0]9a/01P0^:1`0<2XN030Z7P0c;B40=2hR
03T[8080>2XO0P0g:Ah203HX7@0303DW700b;1`0<R`L00H0<R`L0`0d:a`203D/7@<0=RdN0P0k;B82
03X/8@0403T[800h:Ql0>2XO03PZ7`P0>BdM100l:b4403/Z80P0>BdM0`0l<Ad203/`70<0>RlK00<0
>bhN03X]7@0i;1`00P0g:QX00`0i;1`0>RdM03/^7P0803T[800603/e9`0k<bH0>S8U03X`900k;b<0
?2hS0P0n;B<00`0g:a/0>BdM03da8@02040d900303lc8`0l<200>RhN00P0@3<P200n<b400`11<1h0
@S4O04@c8@0304He8`0304Dd8P14<b40A3<Q00L0A3<Q00H0@SPO04<g7`13=al0ACHO04Hf7`16=1h2
04Pc7P80BCLO0P1:>200101;>B40C3XR04`j8P1<>R8404Lg80D0ASHO0P13=R<2048e8P0=044d8@10
<b00@3<P040c8012>1l0@cLO04@h8016=b00B3PQ04Xh8P1<=b80CCPS04Dh9@0204@g900304<f8`12
=B80@C@Q00@0@3<P0`0o<Ql303ha7P0604@a8P13<R80@c8R048b8P10<b80?c@R0P0m=B800`0k;al0
?30P03da8@0203hb8P0303da8@0k;al0>RhN00<0@3<P1011=2403`12=B80@S<N048c7P0o<Ql0?S<Q
03/c800j<b40>C8R03Pb8P0k;b40?30R03``800m<R00?S<Q03ld8002040e7`<0@C@S:oooool002[o
oooo0P2GK3l01P2HKD00VFi109Y_@P2KL4<0W75409ebA@80VG1200<0VVm209]_@P2MKT800P2NKD80
0`2PKD80Vfln09]_?P0609]_?P0409Y`?P2KLCl0Vg4o09ab@080WG=10P2NM4800`2KMd<0VWI209Qd
@00209Mc?`0309Qd@02JMT80VgM300P0X7A3202QMT<209mc@P<0X7A30`2QMD@20:1e@P80XGI30P2R
Md@20:=hA@80XWU50P2QN4@30:1g@`80WgI2202QMT/30:1g@`<0WgI20P2NMD401P2HKc/0V6hl09Q^
?02GKCd0Uf`o09M/@@80UV]100P0TVPh09=Y>@2DJC`0U6Tn099W?@2?Hc`0Relh08QL=`80RV0h00@0
Qf0g08AO=@23GS@0Oe`b0P1mG3402020FSD0P5Xf07mI=@1mESD0O5Df07]D=`1jDSP0NE4g0P1hDRd0
0`1gDB`0MU0[07E?:P0207A>:@0407==:01^CBX0KTdZ06i=:P80KD`Y0`1/BbP406U;:@@0JT`Z0P1[
BRL0101/BbP0KD`Y06m>:`1`Cb`2075@;@0>075C;@1dE2h0MED^07QG;P1kF2h0OeX^085J;`22G2l0
PE/d089M<`23GS@0Q5lc08EP<`27Hc<208QT<P80S6Hg00<0SFLh08iX>@2?JCX00P2@JS/00`2AJc`0
SVTe08iY=@0208iY=@@0SfXf00P0TfPk095V>@2?I3L0SV<f08mT=`2AIST0U6Tl09I[?P80UV]000@0
UFXo09AY?P2DJCh0TfPm0P2BIc`8091T?`0;08MR=P2:HcP0SFLj099Y>`2DJSX0U6Pg09AV=@2BI380
TfPk095V>@2?I3L00P2>HcH2091U>00309=X>`2EJSd0SVPi0080SfTj00<0T6Xk095[?02AJc`00P2B
K3d01P2GK3l0UV/n09=X>`2AIST0Sf@g08iS=P80Sf@g00P0S6Hg08eW>02?JCX0T6Xk08mY>P2>J3T0
RfDf08YT=@P0U6Tl0P2EJcT209I/>P<0Ufdk00<0V6hl09Y`?P2IKcd00`2GKC/0502IKcd0Vg4o09ab
@02KMDP0VG=409Qb@`2FL3l0UW4m09Qc?P2IM3d0VgHo09Ia?@2EL3`0Tfhj099]>@2CKSX0UG0l09Mb
?P2HLcl0V6hl0P2IKcd00`2JL3h0Vg4o09]a?`0209ab@0<0VW0n0P2IKcd309Q^?00809MaA02FL4<0
UFm209A^@@2CKD00TV`o095[?P2@JSd3099]>@0309=^>P2DKc/0UG0l0080UG0l00<0TV`m09=]?P2D
KSl00P2EKd001P2DKSl0Tfdn099/?@2EL3`0U6lk09=^>P80TVdi00H0Tfhj09A_>`2EL3`0SfXf091[
=`2AK3P2099]>@06091[=`2>JCD0S6Lc08eY=@2>JSH0Sf/g0P2AKCT01P2?JcL0SVXf08eY=@2>JC`0
SFPk08YU>0@0R6<f00l0RF@g08IT=P26I3H0QF<e08AR=022H380PEla081N<01oGBl0OUlc07aM<@1i
FC00MeL^07EE;P1eEBl00P1fEC804@1gES<0KE<`06aB;`1YDBl0ITd^069;;01MB2/0FTLY05Q4:@1B
@BL0DD0V04hn9@1:?280ACTQ044f800o=200?3@O0080>3<O00H0=34N038a7`0^;al0:bdO02T[7@0X
;1h302PY6`809bPJ0`0V9aT202<T7`808R<N00@08B8M020Q700O81/07b0K0P0P8a`301lR6`<07R4J
0`0O8Q/2020S70h08B@M0P0P8a`301lR6`8082<L00@07b8K01hQ6P0M81T071lH0P0K7QL02@0I6aP0
6Q`I01/M6P0M7a`07R0M020R7`0Q8b008R@Q028T8`02028T8@03028T7`0R9Ah08bHM00808bHK00H0
9BPG02HY600W:QT0:B`K02/^7@0/;ah202ha800302DT7`0T8ah092<N00D08b8M00H08R4L02@S7P0W
9al0:RXP02/[7`0[;1h202X[6`0603@X700e:Ad0=RXN03P/800j;R80>blS0P0m<BD02@12<B40@C4Q
03lb8@0l=240>c@Q03Le800f=B00=3HP03le7002040f7@08044g7P12>1l0@cTP04<i8014>R40=S4M
03Lb7P0i=20203Xe8@0:03Td800g<Qh0=S4M03Ha7@0k=Al0>S@N03Td7P0h<ad0=C<L03<c6`80<38J
200a;b804`0c;Q/0=C0M03Pc800i=240>3<P03D`7@0b;AX0;bXG02TZ6P0Z:a/0:R`N02T]7`0V;200
92XP024Y7P0O9Qh092DO02HW8@0X:B<00P0Y:R@00`0X:B<09RLQ02@U7`0302@V6`D09BLL03P092HQ
02<U800P8Qd07R0K01dO6P0N81/07b4L020R7@0V7aL0:24I02/T700_:200<b`T03L`:00j<b/0?3D]
05Y3901OARL0IThX079J;P1oIC80RFld095e=P2CN3D0Qg<n08Qd@@26MD40Q79007a/>`1`HS<0IETY
05mC8`1D@2P0CC/S04@e800h<1/0<2dJ02`]7@0/<240:c4S03Pe9P0g=2D0=38U034a9@0`<RL0<S<[
03<f;@0d=c00@3l]03ln:P0m?2L0>c/Q03/l7@0l?A/0?ClJ03i06@80@cTP00@0A3XQ04Dk8P17?B@0
B3hU0P19?bH804Dk8P0604Po8P1:?b<0Bd0T04i09@1A@BL0Dd8X0P1F@RT0301DAB@0ETLV05U9:01L
BBT0GTTZ05i7:01MARL0G4<U05Q98P1JBb@0G4dV05e>9`80GTlX00L0GDhW05a=9P1NC2H0GT`V05i<
:01OC2/0Gd`/0080Gd`^00<0Gd/`06A:9@1TBRD0101TBRD206=9900506988`1RE3L0H58e05a><@1H
BRd00P1FB2/305M9;00G05I8:`1DART0DT@W05949`1CABP0E4HY05E7:P1MBBH0GTXW065::01SBbT0
ID/Z06Q;:`1YC2`0JT//06i@:P1/CRP0JT`V06Q:901WBB<0J4XT06Y<9P1[CBL0101`DbT01P1aE2X0
LeH/07EH;P1fFBl0O5/^07eL;`80OUd`101oGS40601fGS00MEd_07=K;@1aFB/0KUHX06aD9P1ZDR@0
JE4S065@9@1PCb@0GDhU05Y<9@1GBbD0E4XV05=99@1ABBD0D4<Q04m2801?@1l0CclN04dm701>>a/0
CSTJ04dh6@80CT0M0P1?@Ah0101@@Ql0DD<P0553801A@b0205m99080H4XU00`0HD/V069<9`1SCBP0
HddX06A=8`1VCbD0J54W06UB:01ZDbT0JE8X06QA9`1WD2H806iC:080KU8[00L0KU8Z06mD:@1_E2L0
Ke@U071E9P1`ERD0K54T0080KE8U00<0KU<V06mD9`1_E2L00P1`EBP207AK8`0407=J901cFBH0LeTX
07=I:0<0LePY00T0LULX075G9P1`ERD0L5HS079I8`1dFb<0MUdU06iG:`1ZDbL00P1WD2@01@1ZDbL0
Je@X06UB9P1VCb<0IDlX0080IU0Y00T0Ie4Z06QB:`1WDBX0IU0Y06A>9`1SCBH0HDlY05m=9`1MBbD0
0P1KBB<0101MBbD0GddW065?:@1ICB<405Q<8P<0Ed/Q0P1NC2H01P1OCBL0H4hX065?:@1RD2X0He4[
06AB;080He0X0140HDlW05m@9`1NCbH0GE0V05a@9P1KCbD0FTXY05M89`1CA2<0D4<Q04e3801>AR80
D4XV059<:01>@b<0CD8R04]0800204Xo7`0D04a18@1>@b<0Cd@T04a18@1<@B<0BT4R04Ho8P14?b80
@ShS03lm900n?2<0@CdR040l8@0o>b00?SXO03di7P0l>1d0>cLL03Xf6`0e<a`303Hd7@<0=cDN00L0
>3HO03Ha7P0c<1d0<c0M034`700^<1/0;2lJ0080:RlI00P0;S<O02db7P0/<Ad0:c0L02X_6`0Y;QX0
:2dI02L/60809BPO0P0T9ah302<V7@06028U700Q91T08B@I020S6P0O8Q/07R0K0P0M7a`00`0L7Qd0
61hJ01PN6P0301LM6@<05Q`H0`0H6QT301LI60805QPG200G6AP8018H614051DG400B4aDH01@E5`P0
4ALG400D5AL201HG6@805AHH100D5AL8018C5BP051DG200E5QP801DG5QT05QPG0P0G6AP201PJ6@<0
6A/J00<06Q`K01PH600H61P01P0H61P201LI608061XI0P0I6aX201XL6`/06QXH0`0K6aT201`L6Q00
7AhH200P7aXC024P6`808R4L0`0S8Qd802LR70809b<J00@0:2@K02TU700[9ah0;2PO0P0]:B001P0a
91h0;R<M02hS7@0]91d0:b@L02TU70809b@K0P0Z9Qd202TU70@0:2@K00@0:B@N02PS7@0X8ad0:2<M
0P0W8Q`202HQ6`P08b8M4@0Q81/8028R6PP08R4L200Q81/2028R6P<08b<K0`0T91`02`0/9Ad0:b@L
02XS6`0Y8QX0:R<K02`U7@0_:200<BXR034[7`0`:Qh0;BLK0080;2HJ00<0;BLK030Z7P0a:al00P0d
:1`00`0e:Ad0=RXN03L[7`0203P/800:03T]8@0g;B<0=bdQ03X^8P0l;R40?blP044`8011<1h0@c0O
048a7`80@c8P00<0A3<Q04Dd8P15=2800P16=B<2048a7`80@C0N0P10;ad203l^700603h[7@0m:ad0
?R`N03d]7P0k;Qh0>RhN0P0i<1l0200i;B40>2`P03HZ7P0e:Ad0=2PL03DY7@0f:Qh0=b/O0P0a9ad0
100b:1h0<bTO03<Y7`0d:R0203D[8@0803L]8`0d:R00<BLM02hT6P0]8aT0;bDK038X7P0e:b48030U
7`80;bPP0`0^9al302dV7P0:02XV7@0Y9A`0:BDL02TU700Z9Qd0;2PO02l[8P0`;2<0;bTM02hX7080
;BLK00D0;RPL034[7`0a:al0<bdQ03D_8`0203T[8080>2XO00@0=bTN03HX7@0f:1d0=BLL200b;1`2
03@[7080=B`M0`0f;Ah01@0g;Ql0?2hS03/]8P0k;B80>R`Q0080>B/P0P0h:Ql803T]7@D0?2/Q0`0k
:R0803T]7@<0?34M0P0k<1`303X_6`0303`_7P0k;Qd0>B`K0080=bXI00<0>B`K03/^7@0l;ah0200j
;240400n>2X0?cLZ03hf:@0m<bL0?30T03X/8@0i:1h0>2LM03L[6`0i;Ad0?C4Q040d9011=BD0?c<S
03``800j;Qh8040c80P0?S<Q00<0@S4O04<b8015=2800P16=B<00`15=280A3<Q04<b800804@c8@06
048h7`13=al0@cLO04Df7`15=Ah0AS@N0P18<ah204Xh800404/i8@1<>R80C3XR04dk8`80CS`T0`16
=Ql304Lg80<0B3PQ0P13=R<2048e8P05044d8@10<b00@3<P03lb7`13>B000P14>2000`17>240B3PQ
04Tg8@0204`g8P80ACPU00@0A3LT04<f8`12=B80@C@Q0P10<b0203ld80<0?S<O0`0m<Qh04@12;b00
@C0P048a8@12<R80@3<R040e8`0n=R<0?cLT03``800m<B40?S8R03lc8`0n<R80?30P03X^7P0i;Ad0
@SDR00L0@C@Q0P11<Qd0300o<Ql0?S<Q03`d8@0k=280>c@T03Xd900k;b40?30R03``800m<R00?S<Q
03ld8080@3DO0`11=2<[ooooo`00:_ooool02@2HK3/0VFdl09Y^?@2LL3l0WG5009mc@P2PM4<0XGE4
09U]?00209Y^?@0309]_?P2LL3l0W70o0080WG5000<0Vg=009ee@P2NMT<00P2PN4D00`2NMT<0WGE2
09]c@00809ebA@P0WWA200<0WG8o09ic@02PMD800P2QMT<00`2PMD80WW=009eb?`0209]a?`<0W790
0`2MLd4209ib@@0309mc@P2PM4<0XGE40080XWI500L0XgM609md@@2OM440X7E20:5f@`2SN4D0Y7U6
0080YGY72@2RNDD20:1g@@80XGQ200X0XWU30:=jA02SNT@0Y7]50:9hAP2QMdD0XGQ40:1g@@2OMSh0
WWDm0P2MMCX209Y[?`0609Q/?`2GK3l0Ufi009E_@02FL440UG510P2CISl00`2BICh0TF@m091S?002
08mR>`0?08iQ>P26Hc/0QV<k08ER>P23H3P0PUlg085N=P20GCD0Oe`d085N>01oG3H0O5Tc07YG<@1h
EBl0Me@^0080N5D_0P1eE3401P1dDc00LU4^075@;@1`Cb`0Kdh[06i=:P<0K4/Z0`1]C2/206i=;006
06M>;`1XCBl0J4h]06]>;01/CR`0Kdh[0P1`CRT01P1WARD0JDPU06]:9`1]CBL0KdlX06m?9P80L54U
00P0L5DX079E:@1cERX0MeP/07YI;P1mFS00P5/a085L<P80PV0b00@0Pf4c08AR=025HcD0QF<e0P26
I3H0202<IST0SFLj08mY?02AJch0TV`o095[?P2?JC`0SVPk0P2@JSd01`2?JC`0SFLj08aV>@2;ICP0
RV@g08US=P2:JC@00P2;JSD00`2<JcH0SF`g08i]>00208m^>@0M09UZ?P2HJCd0U6Pk099W>P2AJ3X0
T6Xk099/?@2BKSh0V6hn09M]?@2DJC`0TfPm099W?@2BISl0TfM009=W@P2EJT00U6To09=X?@2BIcX0
TFLg091V=02?IC<0SVDa095V>`2@ICX0Sf@i08iS>02?I3T00P2@ICX00`2BIc`0TfPm099/?@02095[
?003091Z>`2?JCX0SfTj0080SVPi0`2BIcX509=X>`80TFHi0`2BIcX309=X>`P0Sf/g202AJc`409A_
>`@0Tfhj00<0VGA009Qc?`2FLCd00P2EL3`00`2FLCd0V7<o09Ud@00809Y`?PP0Ufdk202HKS`0202F
L440U6ho099/?@2@JS/0SfTj091Z>`2AJc`0TV`m202EL3`809A_>`06095]>@2BKSX0TVhj09=_>`2D
L3`0UG4m0P2FLSh2095[?P<0T6Xm0`2?JC`2099^?P04095]?@2@K3`0Sf/k08m[>`80SVXj0P2=JCT0
102<J3P0RfLg08YV=P2:ISH208UU=@80PV<g00@0PF8f081Q=@20HCD0Of0d0P1nGc<01P1iG300N5/_
07MJ<01eF300M5H`079D<080LE<_01T0L58`06U=9P1WBb@0HTPS05m78`1LAB<0FdLV05a89`1LBBT0
B3dO04Ll7P17?200ACTO04@h8013=b40@SHP048e8P0h<B40=c0P03@^800`;200;B/O02TY7`0W9ad0
9BHN00D09bTN0`0X:Ql202@W800302<V7`0R9Ah08B@M00807b8K00<07R4J024T7@0Q91d01P0Q91d0
0`0O81P0824I028S6`0302@U7@0302<T700R8a/08B@M00L08B@M0`0Q8b02020R7`<07b4N0P0N81d2
01dO700501`N6`0K7AX06adJ01XL6@0N7R000P0N7Qh00`0N7Q`07b0K01lP6P0201lP6004024S5@0R
91H092HH02HX6P809bTK00h09RPJ02DW6@0X:AT0:R/K02d^800_;b<0;RhT02`/900X9b809B@O02<R
800T8b4092<O02DT7`809RHN0P0W9ad8030Z7PP0=34P0P0j<Ql203/c800403`d8@0m=B80?CDR03hf
8`<0@3DO1@11=R0303Pc80<0=c8O0`0f<Ah0200f<Ad0=c8N03Pc7`0i=200>3<O03Lb7P0e<1`0=2lK
0P0f<20203D_7`<0=2hN00T0<bdM02//700/;Ad0;BhN02h_7`0];Qh0;2dM02X[6`0Y:QX00`0T9Ad3
02DV7P809RLO200U:1d0200U9A/09RHL02HW7`0U:2408bHO01dR700I7a/05Q`H0P0Q8b00:`0Q8Al0
820N024O800U8B809b4S02PR900d8a/0=R@J03/X6@14;QT0D3HK05Y07`1VB280JdhV08=L<@26H3<0
RVHf08e/>@2>KcT0SW4i08e`=P2:L3D0RG51089/?@1dHCH0HeD^05E;9`19A2@0@D0R03lo8`0_<R40
;S4P02d`7`0/;ah0;C0O02ha800`<b80<C@S038d:@0c=BX0=3HY03@f:00e>2L00P0f>BH0=00f>B@0
<3<X038d:@0c=BP0=SLY03Xh:@0m>RT0@C`Y048m:P12=RH0A3TW04Hk:@17?2P0Ac`V04Hl8`14>Ql0
@cTN04Q39P17@R@0Ad0S04U08@1;@200D4<Q05958P1EAb@0CShJ054o6`1B@1`0ED4N05Q17`1K@b40
GD<R05i48`1QAAd0HTHN06A8801VBR80J4`T06Y>9P1[CbL0K50X06QF;P1WEBd0Ie@Z06UD:@1[E2P0
KUHZ075I:`1eFRd0NeHY07YE:01hDbH207IA900307MB9@1iE2L0NUDX0080NeT[00D0NUX[07UI:P1g
F2T0LeLW075G9P0206iG9@0@07EF:P1dEBT0L5<W06iC9P1ZDR@0Ie4R06I@8@1TCb00HD/R06A>9`1V
D2T0I4hY05i79@1LABD0H4TZ06A=;P<0IdPY0P1XBBX306U::`0306i@:P1]CbT0JddW0080JT`V00H0
K4hX06i@:P1_DB/0L5T]075J;P1bFbl207=L<008075J;P1^Eb/0KEHZ06eK;@1^G2h0Ked_071N<01a
Gc43079P<P0`07IV<P1gIc<0N6Lc07YV<`1iHc40MEl]07=L:P1aFRP0HdhQ069=8P1PBb00GTPO05e7
801NB2<0GdPV06199`1HBR<0EdTR05A68@1BA240DT<R0593901DABH0EDHY04Xl6@1:?AX0CD0N04i3
8`1>ABH0C4DX04]6:01:ABP0C4@P04i48@1@AR<0E4LU05M89`1KBbX0GT/[05m<;01MBBH0Gd/X06A@
:`1WE2`0J5D[06MD:P1TDBH0HTlT101ZEBP406]F:@0806AA9P1UDRL0J5<X06YC:@1/DbX0Ke<[071D
;01bEBd207AI;P0307=H;@1bEb`0LEH[0080Ke@Y00T0KU<X07EK:P1dFRT0LUPW071F9@1aEbH0LeTX
07IL:`1hGRd0101bF2L407=I:006079G;01aER/0LEH[06mD:@1^DbP0KE8W0P1/DBH00`1UCRD0I4dT
06A=900206A=900506I?9P1XDBP0Je@[06aE;01SCR400P1SCR<00`1SCB@0HddV069<9`02069;:@P0
FdTQ0P1MAb001P1NB240H4XS069<9@1SCBH0I4hW06E?:0<0GD/U1@1NC2H405I68P@0EDDQ0P1EARD0
101DAB@0Dd@S05528@1@@B0204m07`0605508P1@@B80Cd0Q04e08019?Qh0AchM0P14?Q`204<l8004
048k7`10>Ad0?cPL03df6P80?3DI0P0m=ad00`0k=a`0>3LK03Hf6P0203<f6@07034f600h=1/0=S@K
03Dc700c<Qd0<C<M02lb7@0202db7P0602T]5P0Y;1L0:B`G02T/6@0X:aX0:2XL0P0X:Qd5024T6`<0
8RDL00<08B@M01lR6`0M81T00P0K7QL00`0L7aP07B0I01lR6`0201dO700401`N6`0K7AX06adJ01XL
6@806A/H0`0H6QT301LI60805QPG200C6AL201HG6@<05AHH?00D5AL8014G5a0051DG200E5QPH01@E
5`P04ALG400D5AL@01DF60P05QLI4@0F61L801PJ6@P05QPG0P0G6AP201PJ6@806A/J0P0J71/801/K
6`P071`J200N7AP801dN60P08B4I0P0O7aL2020P6004024Q6@0R8QX08b<K02<S6`/08B4I0P0R8QX3
02<S6`809R4K0P0W8Q`202PS7@80:B@N0P0Z8a/0100[91`0;2DM02`U7@0]9Qh202hW7`04038X7P0a
9ad0<BLM034W7@<0<2HL00L0;bDK02lR6@0]8aT0;R@J02dU6P0/9QX0:RHJ0080:RPK0`0Y9aX202PV
6@<09bDH00@092DO02<T7P0S91h08b@N0P0R8ad2024R70T08B4I200T7a/2024L5P03028M5`0S7QP0
91lI00809R4K00<09b8L02TT7P0Y91h00P0X8ad202LR70809R4K200R8QX202HR6@0302LS6P0X91/0
:BDL0080:bLN00<0;2PO02dV7P0]9Qh0100/9Ad202/T7080;BXK00@0;bTK034Y700b:1`0=2PL0P0f
:1d203T]7@80>RhN0P0k;al203``8080>bTM00@0?2XL03d/700n;Ad0?bhL0P10;a/204<d8@0404@c
8@15<R40AC8Q04Ha8080Ac0P0P15<R401P14<B00@RlN044^7@10;A`0?b`K03h[6PD0?2/K0`0m;1`0
100i;1`0>2/K03P[6`0h:a/203LZ6P80=RTI00P0<BDI038V6P0c9a/0=2PL03DY7@0f:Qh0=b/O03P/
8080=bdQ00T0=R`P03@Z7P0c:Ad0<RPL034W6`0`9QX0<2HL02lU6`0]8aT00P0/8QP03P0]8aT0;bDK
030V700b:1h0<2HL02hT6P0]8aT0;R@J030V700c:Al0=B/Q02XW800Y9Ql09b@M0P0V8a`00`0X9Ah0
:RLP02/X8@03034W6`@0<RPL0P0c:Ad00`0i;b<0=R`P038X700202lU6@03030V6P0c:Ad0=B/O0080
>bhM0P0j;A`01P0i;1/0>2/J03P[6P0g:QT0?2lN03d`7`80?S4P00@0?C0O03/^7@0i;1/0>2/J0`0i
<Ah303P`7@80=blL00<0>RhN03/_7`0m<B400P0n<R800`0m<B40>blO03X^7P0303X]7@80>bhN0`0l
;al803X_7@P0>30M200j;R0803P]6`0303H`900d;R80<bdQ0080<B/O00/0<bdQ03@^8P0f<2@0=2/J
03H]700i<Ah0?3@O03de7P0m=Q`0?3DK03/d6003048b6`80@c<L0`14=1d204Ha700304<a6`12<Q/0
@C8K0080?S8J00@0?C<J04Dd8P14<b40@S4O0`10;ad00`11<1h0@S4O04Hf7`0304Hf7`@0ACDN2016
=Ql804/i8`T0A3HL2014=1d204Hd700404Le7@18=Qh0BSPP04/i8@80C3XR00/0BSTY04Th:017=RH0
AC@T04<b8P11<200@2lO03l^7P12>1l0@3HM03hd6`0203dc6P0303hd6`10=Qd0@CLN00P0A3@M00H0
@RlQ040^8010;R00?blP03`_7`0k;al203P_7P<0?c8O0P10<b03044d8@80?c8O1010<b02044d8@P0
?3@Q0`0n=R4[ooooo`00:_ooool0202HK3/0VFdl09Y^?@2LL3l0WG5009mc@P2PM4<0XGE4202KKch0
0`2JLSl0Vg=009ee@P0209if@`0309ee@P2KLd00VW8o00P0WG95202NM4800`2MLSl0WW=00:1e@P02
0:5f@`030:1e@P2NLd00WG8o0080W7900P2MLd4309id@P0609me@`2NLT40WW9109mc@P2PM4<0XGE4
0P2RMTD01`2SMdH0WW=009md@@2PMD80XGI30:9gA02SN4D00P2TNDH90:9iA@80X7M10P2QN4820:9i
@`80XgY400P0XGM70:5gA@2PMT@0WgI209ie?`2MM3`0WGDj09ad>@80Vfa000<0V6`o09M/?`2FKCl0
0P2DKSl01`2CKcl0TfM0099V?`2BISl0TFDn091T?@2?Hc`00P2>HS/01P26Hc/0QF8j08AQ>@23H3P0
PUlg081M=@80Oe`d00H0Oe`f07eJ=01kF380N5D_07MD;P1fDbd207MD;P80M5<`00@0Le8_079A;P1a
D2d0LE0]0P1`Cb`706e<:`0706a;:P1WCRl0J4d_06Q>;@1[CR`0K4h/06i=:P02071>:@0806a;:P1]
C2T0KD`Y06m?:@1`D2T0LU8Y07AE:@1eERX2079E:@0407IG:`1gF2`0NUT^07eJ<080PE`b0P22H380
0`23HC<0Q68d08ES=@0208IT=P0908MU=`2;ICP0SFLj08mY?02@JSd0TF/n091Z?@2?JC`0SVPk0080
T6Xm00@0SfTl08iX>`2>J3/0SFLj0P2<IST308a[=P<0SF`g0P2>KCP0402IJSh0V6Tm09AX>`2BIcX0
TFPj091Z>`2BK3d0TVhn09I/?02EJc/0TfPk099W?02BIcd0TVHo09=W@02DJ4<209AY?`0609=X?@2B
IcX0TFLg091V=02?IC<0SfHb0P2@ICP00`2?I3L0SV<f08mT=`02095V>@0409=X>`2DJC`0TF/l095[
?080T6Xk0P2?JCX208iX>@<0TVLj102CJ3/00`2DJC`0TVLj099W>P0309=X>`<0U6Tl202@JcL8095[
?0@0Tfhj102DKc/00`2HLcl0Ug8n09Ia?@0209E`?00309Ia?@2GLSh0V7<o00P0VW0n402HKS`0202F
L440UFm009=]?P2AJc`0T6Xk095[?02BK3d0Tfdn202EL3`809A_>`@0Tflk102DL3`3095[?080T6Xk
0`2?JCX2099^?P03095]?@2@K3`0Sf/k0080SVXj0`2=JCT00`2<J3P0RfLg08YV=P0208UU=@0608QT
=021HSH0PF8f081Q=@1oH3@0OUlc0P1mGS801`1lGC40NE``07QK;`1gFS00MEP`07=E;`1bE3000P1`
DRh03`1`DS00JDdV06E;9P1SBB@0GdLS05a58`1IAB@0F4DU05U69P17?1h0Ac`P04Hk7`15>Al0@cLO
048f8002044d8@0803L`800f;al0=2hP030/800]:al0:BTO02LW7@0U9Qh802LY7P0502@W800S9Ql0
8bHO028U7P0P8a`00P0O8Q/00`0N8AX082<L020S7006020S700301lP600P8AT08R<K00<092DM00<0
8b@L028S6`0Q91d01`0Q91d2024S80<0828O0`0O8Ah201hP7@807AlL00@071hK01/M6P0K7AX06adJ
0P0N7Qh0100N7Q`07b0K01lP6P0O81X2020Q6@03024S5@0R91H09BLI00@09bTK00T09RPJ02TZ6P0[
;1`0;BhP02l_8`0];B<0:RXR02HU800T8ah00P0S8R000`0T8al092<N02DU7@0202HV700302LW6`0_
:A/0;bTK0080<2XL0P0a:ad2038/7PP0=34P0P0j<Ql203/c8080?3@Q0P0m=B8703de7P0303hf7`0g
<Ql0=c8O00L0=c8O00P0=c8N03Pc7`0i=200>SDQ03Td800h<al0=S4M03D`70<0<c0O0P0b;ah3034^
7@0302//700/;Ad0;BhN0080;BhN00<0:b`L02X[6`0X:AT00`0T9Ad302DV7P809RLO200U:1d0A00U
9A/09RHL02HW7`0V9al09BPQ02<V7`0O91h07B8L02@T900S8b408R4O02<O700U81`0:2<M02dV7P0_
:200@2lO04@c7`1=>B40ET4T06=;:@1^EBd0N5db07iQ=@2=JCT0SF/k095_?`2ALD00SVm008IZ>P1n
I3<0NV0_06iG;P1XDR/0G4XV04m08@13>Qd0>S@J03@b6`0b<A`0<3<R02lb8@0^<B00;C0O02ha800_
<R40<C@S038e900c<bT0<c<W03@d:00d=BL0=CHV03Hg9@0f>2<0=cTT03@f:@0e=bX0=SLY03Pf9`0j
=bH0>SLT03dh9@0m>2@0A3TW04Dj:017?2P0BChX0P19?bH04018?R<0AcdR04]6:@1;A2L0BT<V04a3
901>@b<0DTDS05I89@1GBBH0EDDQ05Q68P1IAb<0G4PU05m89P1RBRP206A::@0B06M;8`1XC2@0JDdU
06Y>9P1/D2P0KE4Y06iB:P1_Db/0J5D]06MD;01XDRT0JE8X06aD:01`EBP0LULZ07EI:P1mFBT0O5PX
0`1jERH00`1lF2P0OUXZ07mK:`0307iL;00<07aL:`1jG2X0Me/Y07EK:01dFRL0LU/W07UH;@1gF2`0
MUL[07=F:P1`EBP0KEDW0P1[EBH02@1VD2L0JU@[06eG<01[EC00IU0[06A=:`1UCRh0J54a06U;:@03
06Y<:P80Jdd[0P1/CR`00`1_DB/0KU0Z06e?:@0206a>:00706e?:@1_DB/0L58/06]D:01/EBT0KUL[
071I;@02075J;P03071I;@1_F2`0KE/]0080KE/]0`1^G2h206mM;`0>06eM:P1^GR/0LV0^07IR<01h
HS40NF4a07QP<01iGRl0Leha071K<01[ER/0IU0W065;901MAb8205]48P0P05M98P1EAb00DdDP0512
7`1?@1l0CSlN04m08@1@@B80CClL04i07@1>@Al0CD8R04a39018@B@0ASlR04@o8P1:@Qh0C48O04i4
8@1BAB<0EDHU05Q89`1LBBT0GDXZ05]79P1NBRL0HTh[06EA;01WE2`0IU<Y06=@9@1RCb@306UD:@D0
JUDZ00P0I54V06EB9`1XDbP0JU<Y06aC:P1_Db/0L5@/075D;0<0LUL/0P1aER/2071E:P0306mD:@1d
FRT0LeTX0080LUPW00@0LeTX07AJ:@1eFbX0MU`[101cFBP4079H9`06079G;01aER/0L5DZ06mD:@1^
DbP0KE8W0P1/DBH03`1[E2/0JE8Y06UB:@1XDBP0ITlV06E>9@1VCbH0Ie0W06QA:01SCR40HdhS069=
8P1RC2<0HT`U065;9P02065::0P0FdTQ00H0GTPQ05m98P1OBB80H4XS065;901RC2D206==9P80GD/U
1P1NC2H305M78`0305I68P1EAB40EDDQ0080E4@P0P1DAB@0101CA2<0DT<R05938P1A@R4205118008
05508P1@@B80Cd0Q04e0801:?al0B3lN04Do7@14?Q`204<l8006048k7`10>Ad0?cPL03hg6`0m=QX0
?3DI0P0m=ad00`0k=a`0>3LK03Hf6P0203<f6@07034f600h=1/0=S@K03Dc700c<Qd0<C<M02lb7@02
02db7P0602X^5`0Z;AP0:RdH02T/6@0X:aX0:2XL0P0W:A`6024T6`808RDL00P08B@M01lR6`0M81T0
71lH01/N5`0L7aP07B0I01hQ6P807AlL00@071hK01/M6P0K7AX06Q`I0P0I6aP301PJ6@<05aTH0P0F
61L801<I5`805QLI0`0E5QPl01@E5`P04ALG400D5AL801DF61P051DG200A5aL@01@E5a005AHH200F
5aTA01HH5`P061XI200F61L201LI608061XI0P0I6aX201XL6`P06a/K200L71X801hM60P07AhH200Q
8AT3020P60808B4I0`0R8QX;024Q6@808R8J0`0S8a/202HQ6`809b8L0P0X8ad202TT7P<0:b@L0P0/
9Ad302dV7P@0<2HL100a9ad01P0`8aX0;R@J02hT6P0]9AX0;2HJ02XV6P80:RPK0`0Y9aX202PV6@<0
9bDH0P0U91l202@S7P<08b8M00<08R4L024Q6@0Q8AT01`0Q8AT802@O6`05024L5P0R7AL08QdG02<N
600U81X00P0V8A/00`0W8Q`0:B@N02TT7P0202PS7@809b8L0P0V8A/8028R6P809R8I00H09b<J02PT
6`0Y9A`0:RHM02/W7P0/:1l802`U7@80;BXK00@0;bTK034Y700b:1`0=2PL0P0f:1d203P/7080>BdM
100j;Qh203`Z7P0403d[7@0n;Ad0?bhN040_7@80@C0L0P14=B801015=280AS<R04Db8@17<R4204Pa
8@80A34P00@0@c0O048_7P12;ah0@BhM0P10;A`303d/70D0?RdM0P0i;1`203P[6`<0=bXJ00H0=RTI
03<W6`0d:1`0=2PL03DY7@0f:Qh203L[7`0603P/800e:al0=B/O03@Z7P0c:Ad0<RPL0`0a9a/00`0`
9Q`0;bDK02dS6@0202`R600302dS6@0_9A/0<2HL0080<2HL0P0_9A/01`0`9Q`0<BLM03<Y7`0d:R00
:bPO02XW7P0Y9Qd00P0X9A`00`0Z9ah0;2TP02dZ8@03034W6`80<RPL100c:Ad0200i;b<0=R`P03<Y
7@0`9QX0;bDI034W6`0c:Ad0=B/O0P0l;ah203/^7@80>RdL0P0i;1/0200l;ah0?C0O03ha800o<R40
?S4P03d`7`0k;Qd0>RdL0P0j<Ql203Ta7P0703P`7@0g;a`0=blL03H^6`0i;Ad0>RhN03``800203da
8@0303``800j;Qh0>BdM00<0>RdM0P0k;Qh303`_7`P0>RlM200h<1d803X^80P0>2dK00<0=blR03H^
8@0d;1l00P0c:ah0200d;1l0=RhQ03L_8P0f;A`0=bhM03Xb7`0l=1l0?SHO0P0n=ad00`0m=QX0@S8K
048b6`0304<c70<0A3@M0P16<A`00`14<Q`0@S8K044b6`0203hb6P0403dc6P15=280A3<Q048a7`<0
@2lM00<0@C0N048a7`16=Ql00`16=Ql404De7PP0ASHO201:>28904Dg7@P0A3@M0P17=Ad01018=Qh0
BCLO04Tg7`1:>20204/i8@80B3LU00@0AcHT04Dd8P14<b40@c8P0P11<1h02012=Qh0@CDM03lc6`0n
<QX0?c<K040d7012=Qh0@cLO2015=Ah01P12;b40@BlQ044_8@0o;b00?C0P03/_7`80>C0O0P0o<Ql3
040c80<0@C@Q1P10<b02044d8@P0?3@Q0`0n=R4[ooooo`00:_ooool02@2IKC`0VVhm09]_?P2LL3l0
WG5009ib@@2OLd80X7A309ib@@0209ea@00309a`?`2KKch0VVhm0080VFdl00<0VW0n09]a?`2LLT00
0P2MLd400`2LLT00Vg4o09Y`?P0809ebA@P0WG=10P2NLd040:1e@P80WW=00P2NM48209me@`<0X7I4
00H0XGM509ib@@2NLT40Wg=20:1d@`2QMD@20:9fA@050:=gAP2NLd00WW=009md@@2PMD800P2QMT<2
0:9gA0T0XWU50P2PMd<30:5hA0<0XWU500H0XGM70:1fAP2PMT@0WgI209ie@@2MM3h209ac>`0509a]
@@2KK400VFe009M/?`2EK3h00P2BK3d01`2@K3`0U6Q109=W@02CId00TVHo095U?P2@I3d00P2?Hc`2
08ER>P0:08AQ>@22GcL0PEhf081M=@1oG3@0OU/c07eJ=01kF380NEH`07IC;@<0ME8/00<0MU<]079A
;P1bDBh01@1bDBh01@1aD2d0Kdh]06m>;@1^CB`0KD`[0080K4/Z0P1[BRT0601VCBh0Id`^06Q>;@1Z
CB/0K4h/06i=:P1_CBP0L4hY075@;`1`Cb`0Kdh[06m?:@1aDBX0MED/07QI;@1kG300LUDY07EF:P1f
Eb/0NEP]07aI;`20Fc40PU/b08=L<`80QF0c00<0QV4d08MR=@28HcH00P29I3L0102:ICP0RfDh08aV
>@2=IcX308mY?080SVPk202@JSd2091/>0<0Sf/g0`2>JSH209QY?@0C09AX>`2CJ3/0TVTk091Z>`2B
K3d0TFdm09AZ>P2CJCT0TVLj095V>`2AIS`0TfM009AX@@2FJTD0U6To09=X?P2CJ3d0TVLj095W=`02
091V=00308mV<P2?I3L0Sf@g0080SV<f00D0T6Dh099W>P2BIcX0U6Tl09I[?P03091Z>`<0SfTj0P2>
J3T01@2AIST0TVLj099W>P2BIcX0TfPk00H0U6Tl0`2EJSd209I[?PP0TF`h202BK3d01@2AK3P0TVdi
099]>@2CKSX0U6lk0080UG0l00@0UW4m09Mb?P2FLCd0UG0l0P2DKc/00`2EL3`0UW4m09Mb?P0@09U_
?@P0Ufdk00D0UW1109E_@02DKSl0Tfdn099/?@0209=]?P0309A^?`2DKc/0U6lk00h0U6lk0`2DL3`3
09=_>`80TVhj00@0TV`m095[?02AJc`0TF/l0P2@JS/208mY>P06099^?P2AKCd0TFdm091/?02?Jc/0
SVXj0`2=JCT208aX>00308]W=`2:ISH0RFDe0080R6@d0P1oH3@0101nGc<0OEhb07aM<@1lGC4207]L
<00607QK;`1gFRh0MUT_07AG;`1bE2h0L58^0P1_DBd06@1^D2h0J4hY06I<9`1RBRH0GDHT05U5901F
@b<0ED8R05918`16?B00AC`O04@j7`13>B00@CHP040e8@0o=200?S<Q03H_7`0e;Qh0<bdO02l[7`0/
:Qh0:BTO02LW7@0V9al0200W:Ah202<V7`03028U7P0Q91d082<L00807b8K2@0N8AX00`0O81P0824I
028S6`0302@U7@0302<T700R8a/08B@M00L08B@M00@08B<P020R7`0P8Ql0828O0P0O8Ah201hP7@<0
7AlL0`0L7Q/201/M6P0601hN7P0N7Q`07alM01lP6`0P8A/0824I0P0Q8aP0100R91H08bDG02DW6@0W
:A/202PZ70809bTK00P0:b`L02`]7@0];R00;RhR02`/8P0X:20092<N028Q70808R4M00<08b8M02@T
700U9A/00P0V9QX01`0W:1X0;bTK02lY6`0`:Q`0<B/M03<]7`0d;R000P0e;b4803Lb7`80>S8O0`0k
<b0303`d8@D0>c<N0`0j<Qd203@_700403D`7@0f<Ah0=c8O03Lb7`<0>3<P00P0>3<O03Td800j=B40
>cHR03Xe8@0i=200=c8N03Ha7@<0<RlP0P0a;Ql3030]7P0302X[7@0[;1h0;2dO0080;2dO00<0:R/M
02TZ700W:1X00`0T9Ad302DV7P809RLO200T9a`202@U7@0302DV7P0V9al09RLO00809BHN02T092DM
02LS900V8R409R4M02TR6P0]9AP0<b/H03Ta6P0n=1/0DT8Q05U69@1QCb/0K5Ta07QS>022K3d0RG51
08ae@`2ALcl0TWA208mc@`2:Kd80P6Ln07=K=@1WDB`0H4TW04lk801:>Al0@c<J03/_6@0d;1T0<2XJ
02hZ7P0]:ah0<SDT034d8`0`<b80;c8Q030c8P0a=2<0<cHU03@g9P02038b9P07038c9@0c=2@0=3DS
03Dg8P0f>2<0=cTS03Hh:P0203Lh:00;03Pg9@0i=R<0>SDQ03/e7`0j=1h0AS/Y04Ll:019?RX0Bd0Z
04e3:P1=@bP00P1=A2L03P1@BBd0D4T/0558:`1BAbT0EDPX05Q9:01IBbP0G4`Z05e=:@1PCRX0HDl[
06=?;01WD2h0JE4_0P1[DC0206iB:P80Ke<[0P1`E2`2075E;@80J58Y00L0JE8X06YB9P1^DbH0LEDV
07EF:01fEbP0Oe/[0080OUXZ00@0Oe/[081L;022GRh0Q60`0`26HS8208=Q<@03085Q<01oHBl0O60^
0080NV0]00D0OUh_07eM;P1lGBh0NUh^07QN;@0207EN;00707AN;01^Eb/0LU/a07EN=01eGSD0LETc
06iF<P0206eE<`<0KU0/0`1_DBd2071B;P80LE@/101_DRX01`1`Db/0LE@/06I?8`1XDBD0JU<W06eF
:P1_F2`00P1`FBd0101aFRh0KUT/06eH:`1]F2/506aG:P0506]I:@1/FRX0L5//07=M;P1eGBl00P1g
G2l0:@1hFbl0NVDh07MR=`1bGC80K5H]06MA:P1SCBP0HDXX06199`1IBR40EdPO05A57P1A@Ad0CclM
04dm701<?1/0C3/M05517`1@@Ql0D44P04e08019?R00AC`O044j7@0o>1`0B3lN04Xo7`1;@200Cd8R
0593901EA2H0F4DW05U6:01HAB@0FTLV05i<:01QCbT0He4[069@:01QD2D0H4lT00<0Ie8W0P1XDbP3
06UD:@80IE8W00H0J5<X06UB:01[DRT0KU8Z06mC:`1`Db/206mD:@<0L5DZ0`1aER/01@1aEbH0LUPW
07=I:01dFRT0ME/Z0080M5XY00H0LeTX07EK:P1dFRT0M5XY07=I:01bF2L2075G9P06071F9@1aER/0
LEH[071E:P1_E2T0KU<X0P1]DRL01`1/DBH0L5T_06iG;@1^Ebd0Je@Z06QA9`1UCR@00`1TCB<01P1R
CB00HTdR069=8P1QBb80HD/T061:9@80H4TW201LBR88065;90P0GT`V0P1IBBD0101HB2@0EdLS05E5
8@1DA20205=37`P0DT<R0100DD0R05118P1?@240CD0P04Xo7`18?ah0AT0N04Do7@14?B40@c`P048k
7`11>Qh0?cPL03hg6`0m=QX0?3DI0P0m=ad00`0k=a`0>3LK03Hf6P0203<f6@07034f600h=1/0=S@K
03Dc700c<Qd0<C<M02lb7@0202db7P0602``6@0/;aX0:bhI02X]6P0X:aX09bTK0P0V:1/8024T6`03
020S700O8Q/07R4J00<071lH00D07B0I01hQ6P0M7a`07AlL01`N6`0201/M6P0301XL6@0I6aP06A/H
00<061XI0`0G6AP201HH5`P04aTG0P0F5aT301DF63`051DG200A5aL`01@E5`P04ALG400D5AL@01DF
60P05QLI4@0F61L801PJ6@P05QPG0P0G6AP201PJ6@806A/J0P0J71/801/K6`P071`J200N7AP801hO
6@P08B4I100R8QX3024Q6@03020P600Q8AT08B4I00T08B4I0P0R8QX302<S6`809R4K0P0W8Q`202PS
7@80:B@N0`0]9Qh202`U7@<0:b@L00D0;R@J02lU6`0_9A/0<2HL034W7@02038X7P0703<Y7`0a91/0
;bDK02lU6`0^9Q/0;BLK02XV6P0202TW6P<0:bLK0P0Z9QX302TU6@0402HV7P0U9Ad09BDM02DU7@80
92@L0P0S8a/9028R6PP091lK0P0R7AL00`0S7QP091lI02DP6P0202HQ6`0302LR700Y91h0:B@N0080
:2<M0P0W8Q`202HQ6`P08b<K00H09R8I02LS6P0W8aX0:2@K02TU700Z9Qd202/W7PP0;2DM0P0]:Q/0
100_:A/0<BTL038X700d:1`203HX7@80=RXJ0P0g:a/303P/700403T]7@0n;200?R`P03l]7`80@2lO
00<0@C0N048a7@12<Ad00P15=R<01016=B<0Ac@S04Ld8`19=2<204Xc8`D0@c0O0`12;ah8040_7`04
03X]7@0i;1`0>B`L03T/7080>2/K0P0g:QX803L[7`D0<RPL0`0a9a/00`0`9Q`0;bDK02hT6P0202dS
6@0902hT6P0_9A/0<2HL02lU6`0`9Q`0<BLM038X7P0c:Al0<RPN0080<BLM00P0;RXQ02dY800/:1l0
;2PO02dY800^:R40;b/R030/8`80<BLK0P0b:1`403<Y7@0903@Z7P0h;R80=R`P03<Y7@0a9a/0<2HJ
038X700d:Qh0=R`P00@0?C0O0P0l;ah303/^7@0303d`7`0n<B00@3<R0080@3<R00d0?S4P03d`7`0n
<b40?C8P03`a7`0k<1h0>RlM03T^700h;A/0=b`J03P/700i;Ad0>RhN0080>blO00<0>RhN03T]7@0h
;1`00`0j;Ad203/^7P<0?2lO200k<1h203X_7@@0>c0N0P0j;ad803/_7`P0>BhL00<0>2hR03L]8@0f
;2000P0e:al0200f;200=bdQ03P^8P0j;Qh0>blO03hc8@10=B40@CHP0P12>1l00`11=a`0@S8K04<c
700204<c7080A3@M0P15=Ah02`17<Qd0AS4L04@b7013<a`0@C8K03lc6`0n<QX0?C<J04Dd8P14<b40
@S4O00<0@2lM00<0@C0N048a7`15=Ah00`15=Ah<04Hf7`P0B3HP2@19>B0804De7PP0BCLO0P17=R@2
04He8`80AC@R0P14<b42040d7080?c<K00@0@3@L048f7P13=al0A3PP2017=b001P13<240@S4Q048a
8@10<200?S4P03`a7`80>S8O00@0?c8O040c8010<b00@3<P0P11=242048e8PD0@C@Q0`10<b0803hc
8@<0@3DQ:oooool002[ooooo0P2JKSd0102KKch0W70o09ea@02NLT4209mc@P090:1d@`2OLd80WW91
09a`?`2JKSd0VFdl09Q/>`2GJcX0VVhm00H0Vfln00<0VVhm09ebA@2MLTD01P2MLTD809ec@@P0WgA1
0`2PMT@20:5gA@<0XWQ60P2NLT400`2OLd80X7A30:5eA0020:9fA@030:=gAP2NLd00WW=00080WgA1
0P2PMD820:5f@`T0XWU50P2PMT@60:5gA@080:1eB02OM4L0WgE509id@P2MM400W7<o09]b?02KLSX2
09a]@@0709U]@02FJch0U6/m095[?02@JS/0SVXj09=Y@@02099X@003095W?`2@ISh0SfDm0080SV@l
0P24HCT02P23H3P0PEhf081M=@1oG3@0OU/c07eJ<P1kF380NEH`07MD;P1eDR`307AA:`0407EB;01a
D2d0LE0]075@;@<0LU4^0P1cDRl2071?;P0<06m>;@1]C2/0K4/Z06]::@1ZBBP0JDPW06I=;P1WC2h0
Idd/06Y=:`1[CB/0KTdZ0P1_CBP0401aD2l0Kdh[06e<:@1/C2H0KThW07=C:P1iFRh0O5da07EF:P1f
Eb/0N5L/07]H;P1oFS00PU/b08EK<`26G3@208MQ=00408QR=@29HcH0RV@g08YT=`80RfDh0P2<IST0
0`2=IcX0SVPk08iX>`0308iX>`80T6Xm0P2AJch4099/?`80TVdi00<0TF`h091[=`2?JSH00P2>JCD0
1P2=J3@0UfPl09MX?02EJC`0U6Tl09=Z?080TF/l00T0T6`l099X>02AIcL0T6Dh091U>P2AIS`0TfM0
09EY@P2FJTD00P2CJ3h01P2BIc`0TVLj095W=`2AIcD0T6Hd091W<`80SfDe00<0SV@d08mU=@2@ISH0
0P2CJCT00`2EJc/0Ufdm08mY>P0508mY>P80SVPi0P2AIST2099W>P0309=X>`2DJC`0U6Tl00@0UFXm
0`2FJch209M/?`P0U6`i202BK3d2095/>004099]>@2CKSX0U6lk09E`?0<0UW4m00L0UG0l09=^>P2B
KCT0TVdi09=^>P2EL3`0UW4m00P0V6hl202IKcd809M]>`80UFm01P2DKSl@09A_>`80UG4m00<0U70l
09=_>`2BKSX00P2AKCT00`2@K3P0TV`k099/>`03095[>P<0T6Xi0P2AKCd0102@K3`0Sf/k08m[>`2>
JSX208eY>@80S6Ph00@0RfLg08YV=P2:ISH0RFDe0P28I3@01P1nGc<0OEhb07eN<P1lGC40Ne``07YK
;`80NEX^0P1gFRh0101eF2h0LeH^075C;@1_DBd206e?:`0906a>;01VCRX0I4`X06199`1KAbH0ET<S
05508P1??R00CChQ0080@S/O00h0@3TO03lg800m=B00>c<P03Xb7`0j<B00=BhN03@]7@0b;1h0;b/O
02`Z7P0Y:Al0:2PN02HW7`<09bTN100V:1d00`0U9a`08RDN028U7P02024T7@04020S700O8Q/07b8K
01lR6`P07B0I00<07b0H020Q6@0R8a/00`0T9Ad00`0S91`08R<K020S7007020S70<0828O0P0O8Ah3
01hP7@807AlL1P0L7Q/0300N7Q`07b0K01lP6`0P8A/08B8J028T6@0R91L08bDH02<U5`0T9QP09RPJ
02PZ7080:B/M00T0:2XL02LY6`0/;Ad0;BhN02d^800/;200:RXP02HV7P0S8Qd00P0Q81/03@0R8A`0
8b<K02@T6P0U9AT09RHJ02LX6P0X:A/0;bTI030Z6P0a:a/0<bdM03D_7`0f<2000P0h<R8803Pa7P80
>S8O1P0k<b0303Pa7P<0=c0M0P0f;a`2038]6P0503<^6`0e<1d0=S4N03Lb7`0h<b000P0i=2400`0i
=200>SDQ03/f8P0203/f8P0303Td800h<al0=S4M0080<2hQ0P0_;B0402h/7`0302PX700Y:Ad0:RXN
0080:b/O00<0:BTM02LW6`0V9QX00`0T9Ad302DV7P809RLO200T9a`00`0T9ah092DM02<T700202<S
6@809R@H02409bDH02/S8@0/8ah0;RDL03<Z6@0l<QT0AS/K05147P1EBB40JELY06eK;@1dHS80OVXh
08Ea?`29MD80S7M208eh@`26LC`0Pfdl07]V>@1_G3@0He0_05U5:P1>?2@0BSPR03ha8@0l;al0>BdO
03H/800d;B<0<blV03<`:@0e<R/00P0c=RD3034d8`0303<f9@0e>2L0=STX0080=38U02H0<c4R03@c
8@0e=200=cHQ03Th8`0j>R80=SLU03Pg9@0h=b<0>SPS03`g8@0n>200?cLP03lh7P19?RX0BSlY04a1
:`1>A2/0D4H[0558:`1BBBX0DdX[05I<<@1FCC00Ed``05U;;P1KC2d0GDd/05e=:`1PCB`0HE4]06=A
;@1TDRh0IU8_06UB<01[Dc40KE<b06iD<`@0L5@/101_Db/206U@9`0606aA9P1^DBD0LU<U07ED9`1g
EbP0NELY0P21GB/01P22GR`0Q60^08IR<029IC<0RfLe08aX=P80S6He0P2:IS@01@27IS<0QVHc08AV
<P22Ic80PFHa0080QF@a00<0Q6@a08=U<@21IS400P20Ic402@1nIc40MEd]07MO<@1iHC<0NV8f07QO
=P1dFc<0LELb06mE<002079E;@80LeH^0`1dEbl00`1eF300M5L]07AG;@0207=F;080LUD[0P1cER`0
1P1XDBD0JE8V06YC9`1[E2P0K5DY06eF:P80KUL[00@0KeP/06eF:P1/EBT0JU<W0P1YDRH206YC9`0/
07=N;`1bGBh0LU`]075I:`1aERT0Ke@W06iA9@1]D2@0KeX]06iI;P1/Eb`0JeD/06YD;@1[EC00K5Dc
06eF=01OCR<0GTdR05]98@1HAR00ED<O058o7P1A?Qh0D3dM05=07`1@@1h0CclN04dn7`1:?1l0ACXN
04<j7@12>1d0ASdN04Pm7`19?R00C3hQ04ho8P1@?b<0DclT05A09@1C@b80EDDT05Q89P1KBbL205e>
9`0405e>9@1LCB80I4hU06A>9@80IDlV00@0IU0W06MA:01WDBP0J58Y0P1UDRL01`1XDbP0JE8X06]B
:@1]DBT0KU8Z06mB:P1/DBH00P1]DRL00`1_E2T0L5DZ075F:`02079G;00806mE901`ERD0LeTX07EK
:P1fG2/0ME/Z07=I:01aEbH207EK:P0407AJ:@1cFBP0LUPW075G9P80L5HU0`1`EBX00`1_E2T0KU<X
06iC:00206eB9`06075J;P1_F2`0KeP/06aE:@1YDRH0Ie0T0P1VCb<01`1WD2@0HdhQ06=>8`1RCB80
HD/R065;901PBRD00P1OB2H805a:8P0406==9P1RC2D0HT`U065;9080H4XS0P1OBB800`1OCBL0GT`V
05i<9P0205i<9P<0GD/U00P0Fd/W05Y:9P1IBBD0EdLS05I68P1DA200Dd<O05927P<0DD8Q0P1B@b83
05=48`0805508P1?@240Cd0Q04e0801;@200BD0O04M17`16@1h204@m8@0404<l8011>Qh0@3TM03hg
6`80?CHJ0P0m=ad00`0k=a`0>3LK03Hf6P0203<f6@07034f600h=1/0=S@K03Dc700c<Qd0<C<M02lb
7@0202db7P0802hb6`0]<1/0;2lJ02X]6P0Y;1/09bTK02HX6`0U9aX3028U70@08B@K00@082<J01lR
6`0O8Q/07R4J1@0M81T201dO700401`N6`0K7AX06adJ01XL6@806A/H0`0H6QT301LI60805QPG200C
6AL201HG6@<05AHH?00D5AL8014G5c0051DG200A5aL@01@E5a005AHH200F5aTA01HH5`P061XI200F
61L201LI608061XI0P0I6aX201XL6`P06a/K200L71X801hM60P07QlI200Q8AT202@T700302<S6`0R
8QX08B4I0080820H00<07alG028R6P0R8QX01P0R8QX3024Q6@808R8J0`0S8a/202HQ6`809b8L0P0X
8ad202TT7P80;RLO00@0;BHN02`U7@0/9Ad0:b@L0P0Z8a/03P0]8aT0;R@J02lU6`0`9Q`0<BLM038X
7P0c:Al0=2XP038U700`9Q`0;bDK02hV6`0]9a/0:bLK0P0Y9aX202hX70<0;BLK0`0/9QX402PU7080
9b@K0P0V8aX902<S6`P09B0L0P0S7QP202@O6@0402DP6P0V8A/09R4K02HQ6`80:B@N0P0X8ad202LR
70809R4K200S8a/202LS6P80:2@K00@0:BDL02XV7@0Z9Qd0:RHM0P0[91`402`U7@80;BHN0P0]:Q/0
100_:A/0<BTL038X700d:1`203HX7@<0=BTI0P0f:QX303L[6`80?bdQ00@0@2hP044`8012<B40@S4O
0P13<Qh00`14=B80ACHS04He8`0204Ld8`0404Xe901;=2@0Bc@T048_7P<0@c0O0`14<B000`15<R40
@c8R04<b8P03048a8@<0@C0P100j;Ad203T/7080>2/K0`0i;B4203P/80<0=b/O0`0`9QX2034W6`<0
<RPL00<0<BLM030V700^91X00P0]8aT0300^91X0<2HL034W7@0^91X0<2HL03<Y7`0d:R00=B/Q03<Y
7`0a9ad0;bDK030Y7`<0<BXP00@0<R/Q03</8P0d;B<0=BhT0`0b:1`403<Y7@80=2XN00<0=bdQ03D[
7`0c:Ad00P0b:1`00`0c:Ad0=B/O03H/800603ha8080?C0O00H0>bhM03d`7`0o<R40@C@S048e9011
=2<3040c8P0703lb8@0n<B00?C0O03/^7@0j;A`0>B`K03P[6P0303P/7080>BdM0`0h;1`303X]7@80
>bhN0`0l;al803/`7P80>bhM100m<1l203/^7@P0?34O200j;ad203P_80@0=bhO0P0h;b001@0m<200
?S4Q040c8P11=240@cLQ0080A3PP00@0ACTO04<c7013<a`0@c<L0P14=1d304De7P80Ac8M00<0A38L
04<c7012<a`00P0o<a/0100n=1/0AC@R04@c8@12<Al3040_7@03044`7P12<Al0ACDN00<0ACDN1016
=Ql804Lg80P0AcDO2@1<>R8804De7P<0BSPP0P19=al304Pf7PD0ASDQ0`17=R83048c700504<d7@14
=Ah0ACHO04Hg8017>2402018>2401P14<B00@c8P04<b8012<b00?c8O03hc7`80>c<N0`10<b02044d
8@D0@SDR1011=242040c80P0@3<R0`11=24[ooooo`00:_ooool01@2JKSd0Vfln09]_?P2LL3l0WG50
0080WW9100T0Wg=20:1d@`2PM4<0WW9109a`?`2JKSd0V6`k09M[>P2FJST00P2MKch409a^?@80WFln
202MLTD809ec@@P0WgA10P2PMT@20:5gA@@0XWQ60P2NLT400`2OLd80X7A30:5eA0020:9fA@040:=g
AP2OM440WgA109md@@<0X7E20P2QMT<90:9iA@80XGM71P2PMTH0202OM4T0WW=809icAP2MLd<0W790
09]b?P2JLCd0VW4k0P2KK4001`2HK3l0UFXm09=Z?02@JS/0SfTj08eY>@2@JD000P2?J3l00`2>Ich0
SFHm08aU?00208]T>`80Pf0h00/0PUlg085N=P1oG3@0OU/c07eJ<P1lFC40NEH`07QE;`1fDbd0M54[
07=@:P0207AA:`0407EB;01aD2d0LE0]075@;@<0LU4^0P1cDRl2071?;P0<06m>;@1]C2/0K4/Z06]:
:@1ZBBP0JDPW06E<;@1VBbd0Idd/06U<:P1[CB/0KD`Y0P1_CBP0401]C2/0JdXW06U89@1YBB<0Jd/T
075A:01fEb/0NU/_07MF:`1hEb`0NUL]07iI;`21FS40QE/c08MK=028G3D208YQ=@80Rf8f00@0S6<g
08eT>02>ICT0SVDi1@2>J3/00`2?JC`0T6Xm091Z?@03095[?P<0TV`o0P2CKD0209A/>@0309=[>02B
JSL0TFTf0080T6Pe00H0SfLd09MX?02GJ3`0UFTl09AY?02CJS`2095[?009091/?02AIcL0T6Hf08mT
=`2?I3T0T6Dk099V?`2DJ440UFU40080TVLm00<0TVLl099W>P2AIcL00P2AIcD00`2AJ3@0T6Hd091V
=00208mU<`05095W=@2CJCL0TfTg09E[>@2GKC/01P2>J3T208mY>P80T6Dh00H0TFHi099W>P2CJ3/0
U6Tl09EZ?@2FJch309EZ?@<0UV/n0P2GK3l809I/>PP0Tfdn0`2BKCT00`2CKSX0U6lk09E`?00309E`
?00709A_>`2BKCT0TF`h095/>02BKCT0U6lk09E`?00809M]>`P0V6hl202FK3X209=]?PH0U6ho202C
KSX809A_>`0609Ea?@2DL3`0U70l09=_>`2BKSX0TFdi0P2@K3P3099]>@<0TF`h0P2@JcL2095]?@04
091/?02?Jc/0SVXj08eY>@@0S6Ph00@0RfLg08YV=P29ICD0R6@d0P27Hc<207eN<P0407aM<@1kG300
NU/_07YK;`80NEX^00H0MeX^07II;@1dEbd0LUD]06mA:`1]Cb/206]=:@0I06Y<:P1SC2X0HT/Y05e9
:01IARH0Dd8T04ln8P1;?1l0B3XO040j800o>Al0?SPP03`f800j<b00>34N03L`7P0f;al0=2dM03</
700a:ad0;RXN02`Z7P0Y:Al0:2PN02HW7`0302LY7P0302HX7@0U9a`09BLL008092HK00<08B@M020S
700P8a`00P0P8a`301lR6`P07B0I00<07b0H020Q6@0R8a/00`0T9Ad00`0S91`08R<K020S7007020S
7080828O0P0O8Ah201hP7@807AlL1P0L7Q/201dO700601lP6`0O81X0824K024R6P0R91T08bDH0P0T
9QP0100S9AL09BLI02LY6`0Y:ad202X/7P0H02T[7@0X:Q`0;2dM02`]7@0/;Al0:RXN02PX7P0U9Ad0
8R4L024P6`0R8QX08b<K02@T6P0U9A/09bLK02PY6`0Y:QX0:R/K034/6@0b;AX0<bhK03D`7@0g<Ql0
>3<P0P0j=B8803Xb7`80>c<P1P0j<Ql303Ha7@0303D`700d;a/0=2lK0080<bhJ0P0a;1T01@0b;AX0
=2lL03D`7@0f<Ah0=c8O0080>3<P00P0>3<O03Td800j=B40>cHR03Xe8@0i=200=c8N03Ha7@@0;2`P
0P0[:al202XZ7P0802LW7@0X:1h0:BTO02XZ800Y:Al0:2PN02HV700U9A/302@U7@<09BHN0P0V9al8
02@W700C02DX8@0S9Ql08B8J020P5P0S7a<09R0B02TR4P0Z8a<0<bLK03LY700m<1d0B3XO05=58P1P
DBH0Je/Z071P;@24KcP0QG0k08Mc?P0208Qd@@0<08Ab@022L400P6hn06eO<P1UERd0FD/V04dn7`14
=Q`0?S4N03``800m<B<0=bhU0P0f;bD0<`0d<2L0=S8Y03Ld;@0j=c00>cPc03@g9P0c=RD0<SDT034d
8`0b=B@0<cHU03Dh9`0f>BP0=S<T03Db8`0d<B00=C8O03Hd7`0i=b80?3XS03hl8`0f=B00>3HQ03Xh
8@0n>R40@S`R04Dn8P19?b@0BT4T04e2;01=@bX0CT@[0516:`1BBB`0E4//05E<:`1FCB`0FDdc05U>
<P1LCS<0GDha05i=;`1NCRd0H4d/065=;01OCb/0HDl[069@;01TD2d0ITl]06Q@;P0206Y@;`80KU8Z
0P1]DBT206a@:080JdlW00h0JdhT06e@9P1`DBD0M5<X07ME:01jEBP0NeLW07eG:022GRX0Pel[08EQ
;@28I300RVHb08aX=080SVXf0P2AJCH01@2>JCD0SFTe08eY=@2;JSD0RFXd0080R6Xd0P2=JS@00`2;
JS@0RV/d08Q[<`0208I/<`0908E/<`1kHBh0Nf4`07]P<@1lHC80Nf0c07QM<P1dF300LED]0080MUT]
0`1gFRh607QK;`80MeX^00L0MUT]07EH;01dEb/0L5T]06mH;01^Eb/0K5DY0080Je@X0P1ZDbL0101`
F2`0KUHZ06aD:01ZDRH206UA9@0806YB9P1[DbL0LU/_075J;P1`F2`0KUHZ06iC:01]D2H206i>9@0I
06MB9@1VDBH0IU4V06I@9`1XDR/0JeD`06eF=01_F3H0IE8W06AA9P1SD2H0HDhV05m;9P1LB2D0FTHU
05U5901C?ah0DSlN04lo7P1>?Al0C3dP04Xl8@18?B40B3`R04Hm800204Ll800304Xl8@1<?280CC`R
0080D3`S00D0D3lQ05508P1DA2<0EdLU05U99@0205Y;900705Y;8P1PBR<0HD/T069<9@1SCBH0I4hW
06E?:00206I@:@80IE8W00`0J5<X06UB:01ZDBP0K50X06eA:@1^DBT0JTlT06]@9@1/DBH0KU<X06mD
:@1`EBX2079G;00306iD8`1`ERD0LeTX0080ME/Z00<0M5XY079H9`1`ERD00`1dFRT00`1cFBP0LUPW
075G9P02075G9P03071E:P1_E2T0Ke@Y0080Ke@Y0`1^DbP02P1]EbP0K5HW06aF9`1ZE2D0JE<T06YD
9@1[EBH0K5HW06eG:01UD2<206A?9005069<8`1QBb@0H4XU06199`1OB2H0201MBb<206==9P03069<
9@1QBb@0H4XS0080GdTR00D0GTPQ05m=9`1OCBL0GddW05i<9P0205e;9@80G4XT00P0G4`X05];9`1J
BRH0F4PT05I68P1DA200Dd<O05927P<0DD8Q0P1B@b8305=48`06050o8@1?@240Cd0Q04i18@1;@200
BT4P0P18@R002015?R80A3dQ04<l8012>al0@3TM03lh700n=a/0?CHJ0P0m=ad00`0k=a`0>3LK03Hf
6P0203<f6@07034f600h=1/0=S@K03Dc700c<Qd0<C<M02lb7@0202db7P0802lc700^<A`0;C0K02/^
6`0Y;1/09bTK02HX6`0U9aX202<V7@808RDL00@08B@K020S6P0P8aX082<J1@0N8AX00`0M81T071lH
01`O600201dO700401`N6`0K7AX06adJ01XL6@806A/H0`0H6QT301LI60805QPG200C6AL201HG6@<0
5AHH?00D5AL8014G5a0051DG200C51HH01@E5`P04ALG400D5AL@01DF60P05QLI4@0F61L801LI60P0
5QPG0P0G6AP201PJ6@806A/J0P0J71/801/K6`P071`J200N7AP801lP6PP08B4I00H09BDM02@T700T
91`08b<K028R6P0Q8AT2020P60P08R8J0`0Q8AT2028R6P<08b<K0P0V8A/202LR7080:2<M0P0Y91h2
02hW7`0402dV7P0/9Ad0;2DM02/T7080:R<K00h0;B<I02hT6P0_9A/0<2HL034W7@0b:1h0<bTO03@Z
800c9Qd0<BLM030V700_9a`0;BLK02/W6`80:BLJ0P0`:1d202lW70@0;RHK0`0Z9Q/302TU6P80:2@I
2@0T91`802DP700302@O6@0U81X09B0J00809B0J0`0V8A/202TT7P80:2<M0P0W8Q`202HQ6`P092@L
0`0X91/402TU700402XV7@0Z8a/0:b@L02/T7080;2DM0P0]9Qh01`0^9al0;BXK02dZ6`0_:A/0<BTL
038X700d:1`00P0f:1d203@X6080=BTI0`0f:QX01`0g:a/0?bdQ03l]8@10;R00@C0P048a8@12<Al0
0P13<Qh204<d8@0404Dd8P16<b80Ac@S04Xe9080Bc@T00@0@c0O04@a8014<B00A34P0`15<R401@16
<b80A3<S04@c8`14<b<0@c8R0080@S4Q0P11<20303/^7P<0>RdM0P0i;1`303T]8@80>2`P0`0g:al0
100`9QX0<BLK034W6`0a9a/4038X7003034W7@0`9Q`0;bDK0080;R@J00H0;bDK030V700a9ad0;bDK
034W7@0c:Al203D[8@0703<Y7`0`9Q`0;bDK034Y7P0b:Ql0<b/P03@/8@0203H^8`80=blT0P0b:1`3
03<Y7@@0=2XN0P0e:al01P0d:Qh0<bTM03<Y7@0d:Qh0=B/O03H/80D0?S4P0`0o<R401P0k;Qd0?C0O
03lb8@11=2<0@SDT044d8`80@3<R00T0@S8R044a8@10<200?blO03h^7P0m;Ad0?2`L03/[6`0i;Ad0
1P0h;1`0100i;Ad0>RdM03X]7@0j;Ad203/^7P<0?2lO200l<Al00`0l;1`0?RhN03l_7`02044a8@03
03l_7`0n;Qh0?2`L00P0?C8P200j;ad203X^7P@0>blO0P0j;Qh2044a8P06048b8P13=240A3DP04Hg
8017>240B3XP0P13<a`204@d7@80ACDN0P16=Ql204Lb7@0904Dc7@13<a`0@S<L040d700o<a/0?S@K
04Dd8P14<b40@S4O00<0@2lM00@0@C0N048a7`14=1d0A3@M0P15=Ah204Hf7`X0AcLP2017=Al904dk
8`P0ASHO0`1:>20204Tg7`<0B3HN0`16=Ql01@17=b00B3PQ04Ph8@18>240BCTR0080A3@M00<0ACDN
04Hf7`17=b000`17=b0804Ti8P0604Hd8015=200A3<O04<d7`10=1h0?c@N0P0m=Ah2040c8080@C@Q
0P12=B8404<f8`80@SDR0P11=242040c80P0@S8R0`13=24[ooooo`00:_ooool209]_?P80W70o0P2M
LD0209ib@@060:1d@`2OLd80WW9109a`?`2JKSd0VFdl0P2GJcX209m_?`0409i^?P2MKCd0WFdm09i^
?P80Wflo202MLTD809ab@080X7E2102NLd020:1e@P0409me@`2PMT@0X7I40:1fA080XGM50P2RN4H2
09ib@@0309mc@P2PM4<0XGE40080XWI500<0XgM60:5f@`2QMT<00`2QMT<30:9gA0T0XWU50P2QMTT3
0:1eB0<0WgA700P0WW=909ebB02MLTL0W75409]a@@2JL3h0VFlm09U`?080VFXn00L0UVXm09AY?02B
JC/0T6Xk08mY>P2>JSX0SFPn0080S6Lm00<0RfHl08YU>`29I3X00P28HcT04023H3P0PUlg085N=P20
GCD0OU/c07eJ<P1lFC40NeP`07UF<01hEBl0MU<]07EB;01dDB/0ME8/07IC;@1gE2h7079A;P05075@
;@1_CRd0Kdh]06i=;01]C2/00P1/BbX206]::@0606E<;@1VBbd0IT`[06U<:P1ZC2X0KD`Y0P1^C2L0
4@1ZBBP0JDPU06U89@1ZBR@0K4`U075A:01eERX0N5T]07UF;01jEbd0OEP^081I<024FS80Qe/d08QL
=@2:GCH0Rf0e0080S64f00<0SF8g08iS>02?I3T00P2@ICX2091Z?@<0SfTl00<0TF/n099/?`2CKD00
202AJch209AZ>0<0TfTg0`2BJ3H209IW>`0>09IZ?@2EJSd0U6/m099/?@2@JS/0Sf/k095W=`2@ISH0
Sf@g08iS>02?I3X0T6@m099V?`2CId82099W?@03099W?02BIcX0TFLg0080TFLe00H0TFPd09=Z=P2B
JCD0TFPd091W<`2AJ3@2099Y=@0309A[=`2EK3P0SFLh0080SFLh0`2>J3T208mY>P0608mT=`2@ICP0
TFHi099W>P2CJ3/0UFXm0P2FJch309AY?0<0UFXm0P2FJch809Q/>`P0Tfdn102DKc/509=^>P07099]
>@2AK3P0T6/g091[=`2AK3P0TVdi09=^>P0H09I/>P05091Z>`2AJc`0TV`m09=]?P2DKSl00P2CKCh0
0`2BK3d0Tfhj09=^>P0609=^>PP0U6lk0P2CKc/3099^>P<0TFdi0P2CKST2099]>0<0TF`g00<0T6/f
091/?02@K3`00P2?Jc/0102>JSX0SFTi08aX>02<J3P208]W=`80RVHf00@0RFDe08QT=027Hc<0Qf<c
0P1nGc<00`1mGS80O5da07]L<00207YK;`0707UJ;P1fFBd0MEP/07=F;01`Db/0KU0Z06]=:@0206U;
9`0J06Q::01NBRT0GDTX05]8:01FABL0DT4U04dm8`18>Ql0ASPN03hj8@0m>B00?3LQ03Td800g<Qh0
=C0M03<]7@0b;1`0<b`L038[6`0a:ad0;RXN02`Z7P0Y:Al0:2PN02LX800X:Ql202LY7P0302HX7@0U
9a`092HK00808bDJ200O8Q/801hQ6P0301lP600P8AT08R<K00<092DM00<08b@L028S6`0O8Q/01`0O
8Q/301lQ7P807R0M0`0M7a`201/M6P<071hK0`0M7a`201lP6P0:020Q6@0R91T08bDH02@V600U:1L0
9RTH02@V600V:1X0:2XL02X/7P80:bdO01X0:R`N02T[7@0[;1`0:b`L02X[7@0X:1`09RHL02@T700S
8Qd08R4L02@T700T91X09RHL02LW6`0Y:Q`0:b`L02`]6`0];Q`0=2lK03D`700f<Ad0=c8N03Pc7`0i
=200>SDQ03/f8PP0?34M0P0k<b0303Xb7`<0>C4N00H0=C8O03@a7P0d<Ah0<c0M038_700a;Q/2030]
6P05034/6@0b;AX0<RdJ03<^6`0d;a`00P0e<1d203Ha7P0303Lb7P0h<al0>C@P0080>C@P00<0=c8N
03Ha7@0d;a/00`0Z;24202T[80<0:2XO0P0V9Qh302PX800302HV7P0T91`08b<K00<092DM0`0U9Qh2
02HW7`P08bHK02008RLQ020U7P0Q8QX08R0D02HP4P0/8a80<bPF03LZ5`14=1X0BCXM05A48`1QCbT0
KU/`07YU=P21KCX0QG0k09AnA@2BNdD0SGQ308Ib@01mJcd0MF@i06mM=`1ZFc@0D4DW04Tn8P0n=1T0
=2`E030Y5P0`:aP0<c0Q03Ld9@<0<30T00L0<C4U038b9P0d=2P0=cDY03Pf:P0c=RD0<SDT00<0<C@S
01<0<cHU03@g9P0f>BP0>S@T03Tc8`0h<b00>3<O03Xe8@0m>280@CdT04<o9P0j>1l0>cTP040l8@14
?b80B44T04i59P1AARP0DTLW0080DDL^01@0D4H[0558:`1BBBX0E4/Z05I>:P1HD2`0FT`b05]=<P1M
CC<0Gdhb05m><01PCBd0H4`[05m;:P1LC2P0GT`X05m=:@1PC2T0Hd`Z06A<:P80IT`[101[CbL406Y>
9P0606m>9@1aD2D0ME8X07YE:@1lEbX0OUPY0P21FBP01@22GbT0Q64[08IS;@29IS00S6Tc0080SFXd
00D0SV/e095Y=@2AJCD0TFTe08mZ=@0208i[=@0308a[=@2;K3D0Rf`e0080TVdf00<0TFhf08i^=@2<
KC@00P2;KS@02@28KS<0PVLb07mT;`1lH2h0Nel_07aP<@1kGS80N5/_07EH;P0307UM;@<0NUh^0P1k
Gbl407]N<P0907YM<@1iG300MeX^07II;@1fGc<0M5da079K;`1_F2`0KEHZ0080K5DY00@0Je@X07=H
;@1aER/0KU<X0P1/DBH0101]DRL0L5DZ075F:`1ZDbT206YA:00>06a@:01_DRX0LU8[07EC;@1fE2h0
JeHY06UD:@1WDRL0IDlV06A>9`1TCRT0I4d[06E>;01XDbH206UD:@0>06UC:P1XDR/0Ie4/06E>;01T
CB/0Ed<R05I28@1D@B40D3lQ04ln8P1??bD0CT0U04m19`16?24204Lk8@0304Tk8@1:>R40BcTQ0080
CCTQ00P0C3dP04dn8@1?@240DT<R05A68`1FB2<0EdTT05Q:8`80GTPS00H0GdTT061:9@1RC2L0HddX
06A>:@1UCbX206EB9`0306MB9`1YDRP0JU4X0080K50X00`0KE0X06Y?901[D2D0K54V06eB9`1^DbP0
Ke@Y071E:P1aER/0KeDT071F9@1bF2L307=I:0H0LUPW101cFBP806mD:@<0JU@U00h0JE<T06YD9@1/
ERL0KUPY075K;01cGBh0Ie8U06MB9`1VDBH0IDlV06==9P1RC2L0HDXX06199`P0GD/S00@0HddV069<
9@1RC2D0HD/T0P1PBR<205m98P80H4hX00<0GddW05i<9P1MBbD00P1LBR@02@1KBB<0Fd/W05Y:9P1I
BBD0F4PT05M78`1FAR80EDDQ05A4800805938P06050o8@1?@240Cd0Q04i18@1<@B40Bd8Q0P19@b42
04Dn8P0404@m8@12>al0@CXN03lh7080?SLK0P0m=ad00`0k=a`0>3LK03Hf6P0203<f6@07034f600h
=1/0=S@K03Dc700c<Qd0<C<M02lb7@0202db7P0902hb6`0]<1/0;2lJ02/^6`0Z;A`0:B/M02PZ7@0W
:A`092LN00808bHM00<08RDL024T6`0P8aX00P0O8QT00`0M81T07R4J01lR6`0201lR6`0301dP6@0L
7aP06ahG00807AlL00@071hK01/M6P0K7AX06Q`I0P0I6aP301PJ6@<05aTH0P0F61L801<I5`805QLI
0`0E5QPl01@E5`P04ALG400D5AL801<D5QP051DG200A5aL@01@E5a005AHH200F5aTA01HH5`P05aTH
200F61L201LI608061XI0P0I6aX201XL6`P06a/K200L71X801hM60P07b0J200Q8AT0100T91`08b<K
02<S6`0S8a/4028R6PP08b<K0`0Q8AT2028R6P<08b<K0P0V8A/202LR7080:2<M0P0Y91h302dV7P80
;2DM0`0[91`01@0^91X0;bDK02lU6`0`9Q`0<BLM0080<RPN00L0<bTO03@W7P0b:1h0<BLM02lW700]
9a/0:bLK0080:BLJ0P0b:1h2034W7@<0<2HL00@0;bDK02dW6`0]9a/0;BLK0P0/9QX302/U6@T09BDM
200V8Ad802HQ6`80:B@N0P0X8ad202LR70809R4K200T91`802TU7080:R<K00@0:b@L02`U7@0/9Ad0
;BHN0P0^9al202dZ6`0402lY6`0a:A`0<RPL03@X7080=RPM0`0e:AT203HZ6P<0=b/K0P0n;200100o
;Al0@2lO040_7`11<1h2048a7@80@C8O00H0@c8P04Db8@16<b80BC@S04Xc8`1;=2@304Hc8PD0AC8Q
0P15=2@00`14<b<0@c8R048a8@02044`8004040_7`0l;al0?2lO03`_7`80>bhN0`0j;Ad803L[7`P0
<bTM00<0<RPN034W7@0_9A/00P0^91X01@0_9A/0<BLM038X7P0b:1h0<bTO0080=2XP00P0<bTO038X
7P0a9ad0<2HL034W6`0b:1`0=2XN03H/80@0>2hR00@0<RPL03<Y7@0c:Ad0<bTM0`0d:Qh203D[7`@0
=2XN0P0e:al00`0f;200=bdQ03d`7`0303d`7`80?S4P0P0o<R400`0k;Qd0?C0O03ha8003040c8P03
03ha800m<1l0@C0P0080@C0P0P10;al303l^7P0303/_7`0j;Qh0>BdM0080>2`L00<0>BdM03X^7P0k
;al00`0j;Ad203/^7P<0?2lO200l<Al00`0m;1`0?bhN044`800204<b8P03044`800o;Qh0?B`L00P0
?S<O200k<1h00`0k;Qd0?2lN03d`7`0203ha800303d`7`0l;ah0>bhM0080@S0R00H0@S4Q048a7`14
<al0ASHO04Ph8@19>B0304@d7@80ACDN0`16=Ql204Pc7P0304Dc7@14=1d0@S<L0080@3@L00@0?S@K
04Dd8P14<b40@S4O0`10;ad00`11<1h0@S4O04<c700204@d7@0504De7P16=Ql0AcLP04Lg8018>240
2017=b0804Pf80T0CSXR2016=Ql804Tg7`80AcLN0`18>1l304Ti8080AcDO00H0B3HP04Tg8@19=b40
B3HP04Le7`16=1h804Ph8@0604Le7`16=Ql0ASHO04@e7P12=Qh0@3HM0P0n=ad3044d8@80@SDR0`13
=R<204@g900404<f8`12=B80@C@Q044d8@80@3<P2014<b<304@c8B_ooooo000Zooooo`@0W70o102M
LD0209ib@@0309ea@02LL3l0Vfln0080VFdl00@0V6`k0:5a@@2PL400WVhn0P2MKCd00`2NKSh0X710
0:5a@@0809ebA@P0W79000<0XGI30:1e@P2NLd000P2MLSl0102NLd00X7E20:5f@`2NM48309me@`80
X7I40P2QMdD209ib@@0309mc@P2PM4<0XGE40080XWI500@0XgM60:AiAP2TNDH0Y7U61@2SN4D90:9i
A@80XGI90P2PMDP209mdA`80WW=600P0WG5:09ebB02LLDL0Vg1509Y_@P2IKcl0VFlm09Q^?080UVLk
00<0U6Pk09=X>`2BJC/00P2@JS/01`2?Jc/0RFHl08QU>`28IC/0Qf@j08IS>@25HSP00P24HCL01P22
GcL0PEhf081M=@1oG3@0OEXb07aI<@80NeP`00P0NULa07UF<01gE2h0MU<]07EB;01fDbd0Me@^07QE
;`80M5<`00@0Le8_079A;P1aD2d0LE0]0P1`Cb`706e<:`0706a;:P1UC2d0IT/]06I<:`1XBbT0JT`Z
06a;:00206i<9`0806Y9:01[BRL0K4/X06m?:@1bDR/0MED/07QI;@1iFRh207aG;@0407mH;`23FC40
QUXc08MK=080RUdf00H0S64f08eR=`2=HSL0SV<h08mT>@2@ICX2095V>`0809=]@02BK3l0TF/n091Z
?@2AJch0TV`o09A^@@2FL4<2099/?`04095[?P2@JSd0T6Xm08mY?080SVPk0`2BJ3H309=Y=`80U6Xh
0100UFHj09IW>`2FJSd0UV/n09E/?P2BK3d0T6Xk08iZ>P2BJ3P0TFLg08mT=`2>HcP0SF8h08iR>`2?
Hc`0T6@o0P2AIS`00`2AIS/0TFHi099X>002099X=P06099Y=@2FKCL0U6/e09=Z=02AJ380T6La0P2A
J380102BJC<0TfXd08aV=`2<ISL208eW>080SVPi0P2?JCX208mT=`06091U>02BIcX0U6Tl09EZ?@2F
Jch0Uf`o0P2BIcX309=X>`<0U6Tl202JK3/809=]?P80UW4m00@0UG0l09A_>`2CKSX0TVdi0P2AK3P0
0`2BKCT0TF`h091[=`0208mZ=P03091[=`2AK3P0TVdi00P0UV`j202DJSP809E[>@0808eW>02>J3T0
T6Xk099/?@2CKCh0TV`m095[?02@JS/8099]>@P0U6lk102AKCT4099^>P<0Tfhg0P2BKCH3095/=@80
T6`l00<0Sf/k08iZ>P2=JCT00P2<J3P308]W=`0308YV=P29ICD0R6@d0080Qf<c00H0QV8b07mP=01o
H3@0OUlc07eN<P1lGC4207]L<00707YK;`1fFBd0M5L[079E:`1_DRX0K4hX06Y<:00206M99@0J06I8
9P1JARD0FDHV05U69P1EA2H0DD8U04`n8`16>R00@cLM03/i800j>240>CLP03Hd7`0d<Ah0<BhM02l/
7@0^:a`0<R/K034Z6P0`:Q`0;BTM02/Y7@0Y:Al0:2PN02LX800X:Ql202LY7P0502HX7@0T9Q/08bDJ
02<U6P0R91T0200O8Q/8020S700301lP600P8AT08R<K00<092DM00<08b@L028S6`0O8Q/01`0O8Q/2
01lQ7P807R0M100M7a`301/M6P0301`N6`0M7a`07AlL00807R0M00d07b0H020Q6@0Q8aP08R@G02@V
600U:1L09bXI02LZ5`0U9aT09bTK02T[7@0[;Al0;2hP0080:bdO00L0:R`N02TZ6P0Y:QX0:2TK02LW
6`0V9Q`09BDM008092<N00T09RHL02HV6P0X:1`0:R/M02`]7@0^;ad0;c4L030b7@0g<Q`00P0h<ad2
03Td7P<0>SDO200m<A/203/c8080>S8O0P0i<Ah203P`7@0603Dd8P0d<b40=3<Q038a7`0a<1h0<2lM
0P0_;Q`2038]6PL0<bhK00P0=C0L03Ha7@0g<Qh0>3<O03Lb7P0f<Ad0=2lK038]6@<0:2/P0P0W:Ql3
02HY7P809B@O0`0W9R400`0U91l08b8M028Q700302@U7@<09BHN0P0V9al802<V6`0Q020V8P0O91h0
8B8J02HT600_:1P0>RlM04Df8@1;>b@0FTTM061?8`1/FR`0NVDf08A^?@2;M480SGI2091f@`2AMT40
Rg4n081X>01dGC<0IE4/05Y79`1@@B@0CCdS03Pa8@0f;al0<bdM030]700_;Q`0<34O03@e8`0e>2D0
<CDT0080<3@S00<0<C@Q030c800a<ah00P0`<Qd0:@0b=B@0<C@S030c8P0_<R40<3<R034d8`0c=RD0
=CPW03df9P0l=B<0>S<Q03Xc800l=R00@3XR04Do9@18@RP0A40U04E19P17@RD0Bd@W04m69`1BAbL0
E4XW05M::01DBRl0DdT^0599;01AB2T0DTTX05=;9`1ECBT0EdlZ05Q:<01JBS00G4`b05i=<@1PCBl0
GdX[0619:@1OB2P0Fd/W0080GT`X00<0Gd/X065::01SBbT00P1TBRT206]?9`H0K50X00`0LTlU07AB
9@1iE2P0OUP[089I:`25Fb/0QE/Y08IJ:@22GbL0Q64Y08MT;029IRh408]X<0<0TVTc00<0TFXc08mZ
<`2>Jc<00P2<K3<04@2;K3<0Ug0e09Ea=@2DL3@0TW0c08i^<@2<KS00RVh_08U];P2>LCT0QfTc081R
;01nH2`0P68`085R<`20HC<0OEh`00<0NUh/0P1kGbd307aP;P0<07eQ<P1nHS<0OV8c07iR<`1mHC80
Nel`07UM;P1gFb`0Mf0d07IO<`1dGC40LU/_0P1aFRh01@1bFbl0Le``07AI;P1bEb`0L5DZ0080KU<X
0140LEH[07AI;P1fFc00Je8Z06eA:P1/D2T0KDlY071@:P1cDB`0MU8^07QD<01_FRd0KEP]06UD:@1V
D2L0HddV065;9P0206199`0=06A?8P1VDB@0J5<X06YE:P1/ERd0JeD^06]E<01ZE2l0HT/[0619:@1K
ARL0ET<U05919@0205109P0704m19`17?B@0B3`T04Lk8`19>R<0BSXS04Xh8P0204`g8P0>04Pj7`19
>ah0BcdP04e0801@@b40DTDR05A88P1EBB<0Fd@R05a58`1MAR@0GdPV06199`1RBbT206=<:P80IU<X
00<0Ie8W06QA9`1YD2L00P1[CbL00`1/CbL0Je0U06]@9@0206aA9P0406eB9`1^DbP0KU<X06mD:@80
LELV0`1`ERD00`1bF2L0LeTX07AJ:@02071F9@04075G9P1bF2L0LeTX07AJ:@80ME/Z0P1^DbP606mD
:@0306aF9@1[EB@0JeDT0080JeDT00`0K5HU06mI:01aFbX0Led/06YE:01ZEBX0J5<X06MA:01UCbP0
I4hY06=<:P1RBbT805i<90D0HD/T0`1PBR<01P1QCbT0H4hX05m=9`1NC2H0GD/U05a:9080FdTS0`1I
BBD01@1HB2@0EdLS05M78`1GAb<0ETHR0080E4DT00@0Dd@S05938P1B@b80DD8Q0P1@@B001P1@?b40
Cd0Q04m08@1>@B40C44Q04a38P80BT@R0P15?R801P14?B40@c`P044j7P10>Ad0?cPL03hg6`80?CLM
00<0>cLL03Pg6`0f=QX00P0c=QT01`0a=QP0>3@K03Hd6`0e<a`0<c8M034c7@0_<Qd00P0]<Qh0200/
<1T0;2lJ02`_6P0[;Q/0:RdL02X/7P0Z;1l0:B/N0P0T9ah03P0S9Qd08RDL024T6`0P8aX07b8I01hQ
600M81T07R4J01lR6`0P8a`07b8K01hQ6P0L7aP06QdF0P0M7a`0100L7Q/06adJ01/M6P0J71T201TK
60<061XI0`0G6AP201HH5`P04aTG0P0F5aT301DF63`051DG200A5aL@01@E5`P04Q<E600D5AL8014G
5a0051DG400E5QP801HG6B405QPG0P0G6AP201PJ6@806A/J0P0J71/801/K6`P071`J200N7AP8020Q
6`P08B4I0`0R8QX202<S6`<092@L200S8a/3024Q6@808R8J0`0S8a/202HQ6`809b8L0P0X8ad202TT
7P<0:b@L0P0/9Ad302dV7P@0<2HL100a9ad02@0e:1l0<bTO038X7P0`:1d0;RPL02/W6`0Y9aX0:2HI
03<Y7`03038X7P80<BLM0P0`9Q`302lW6P80;RHI0`0]9AP902DU7@P09R4M200V8A/202TT7P80:2<M
0P0W8Q`202HQ6`P092@L1P0Y9A`202PT6`0502TR6P0Z8a/0:R<K02/T700]9Qh00P0^9al01`0_:200
;BXK02dZ6`0_:A/0<BTL038X700d:1`00P0f:1d203HZ6P<0=b/K0`0h;1`203`Z7P0403d[7@0n;Ad0
?bhN040_7@80@C0L0P0o<1d01011<1h0@c0O04@a8017<R4204Tb8P80B3DT00@0Ac@S04Hc8P16<b80
AC8Q0P14<B001P15=2@0A3<S04<b8P12<B40@C0P040_7`80?bhN0`0m<20203`_7`<0>bhN00D0<bLK
03@X700d:1`0=BTM03HZ7P0203L[7`0503P/800g;B40=bdQ03H/800e:al00P0d:Qh203<Y7@03038X
7P0a9ad0<2HL0080;R@J00L0<2HL034W7@0b:1h0=R`R03D[8@0c:Al0<RPN0080<BLM0P0b:1h0100_
9QL0<BPI03@[700f;Ah303P_800403L^7`0c:Ad0<bTM03<Y7@80=2XN100e:al303@Z7P0303D[7`0f
;200=R`P0080=bdQ0P0k;Qd203`_7P80?C0O0P0n<B00200l;ah0?C0O03ha800o<R40?S4P03d`7`0k
;Qd0>RdL0P0o;Qh2040_7`<0@C0P00@0@S4Q03da8@0l<200>RhN0P0i;Ad00`0j;Qh0?30P03da8@03
03X]7@80>bhN0`0l;al803`a7`0303d/700o;Qh0@S4Q0080A3<S00<0@S4Q03l^7P0m;1`0200o=1h8
03`a7`0303d^6`0n;a`0@34N0080@C8O00/0@34N03h_700m;Q/0@S0R044_8@10;al0@C0N048a7@15
=Ah0AcLP04Ti800204@d7@80ACDN1016=Ql204Pc7P0304Hd7P14=1d0@c@M0080@3@L00@0?cDL04Dd
8P14<b40@S4O0`10;ad02011<1h0@S4O04<c7013<a`0A3@M04De7P16=Ql0AcLP2P18>24804Xh8PT0
CcTR2017=b0204Le7@0404Pf7P19=al0BCLO04Xh8080BcTQ1P19>Al204Ph7P0804/f8@1<=b80CCPS
04dh8`1<=b80BSDP04Pc7P16<A`804Lg800604Pf8017=b00AcLP04Df7`13=al0@CLN0P0o>1h2044d
8@80@SDR1013=R<204Dh9@0604@g9013=R<0@SDR044d8@10<b00?c8O2014<b<304@c8B_ooooo000Z
ooooo`@0W70o1P2MLD0209a`?`0709]_?P2JKSd0VFdl09U]?02TLD80Xg110:5^?`020:1]?P030:5^
?`2SL440Y75200P0WG95202LLT000`2QMT<0X7E209ic@00209eb?`0409ic@02PMD80XGI309ec@@<0
WWA20P2OMD<20:1fA080WW9100<0Wg=20:1d@`2QMD@00P2RMTD00`2SMdH0YGY70:EjA`020:EjA`@0
Y7U62@2RNDD20:5fB`80X7E:00`0WgA909icB02NLdP0WG9709eaBP2LL4T0W75709]`A@2JKd80VFlo
09Q^?P2HKS`209EV>P0609=W>P2CJ3/0TVTk091Z>`2AJc`0T6`l0P27I3X00`26HcT0QF8h08AQ=`02
08=P=P0<089O=@21GSH0PEhf081M=@1oG3@0OEXb07aI<@1kF300NUL_07YG<@1iES00N5D_0P1fDbd0
0`1gE2h0N5D_07UF<00207ED<@0607AC<01bDBh0LE0]071?;01_CR/0KTdZ0`1/BbX306e<:`80KTd/
00H0I4//06I;;@1VC2/0J4/Y06Y<:P1/BbP206i<9`0606]::@1]C2T0L4l/07AD;P1gEc00NET`0P1k
G300201lEbd0OEP^07mH;`23FC40QUXc08UL=@2:GCH0SEdg0P2>HCL208mR>00B091S>@2AI3X0TVDk
099U>`2EKd80U6i1099/?`2AJch0TV`o09A^@@2FL4<0Ug5409=]@02BK3l0TF/n091Z?@2>J3/0SFLj
0P2<IST01P2AIC@0TVHe099V=@2CIcH0U6Pg09EY>080UVXi0100UFHj09IW>`2FJSd0UV/n09E/?P2B
K3d0T6Xk08iZ>P2CJCT0TVPh091U>02>HcP0SF8h08eQ>P2>HS/0Sf<n0P2AIS`00`2AIS/0TFHi099X
>002099X=P05099Y=@2HKcT0UVdg09A[=@2BJC<00`2@Ic400`2AJ380TVTc08]U=P0208aV=`0308eW
>02>J3T0SVPi0080SfTj00P0SV<f08mT=`2@ICP0TVLj09AY?02EJSd0UV/n09M/?`80TFHi0`2BIcX3
09=X>`P0Vfdl202CKCh02`2HLcl0Ug8n09Ia?@2DKc/0Tfhj095/>02@JcL0SfXf099]>@2AK3P0SfXf
0080SVTe00<0SfXf095/>02BKCT0202EJcT8099X=PP0UF/i00P0RfDf08eW>02?JCX0TF/l099/?@2A
Jc`0T6Xk08mY>PP0TVdi202DKc/208m[=`03091/>02AKCT0TVhj0080Tflk00@0U70l09=^=`2CKSL0
Tfhg0`2BKCH2095/=@80T6`l00@0Sf/k08iZ>P2=JCT0S6Ph102;IcL0102:ISH0RFDe08QT=027Hc<2
08IR<P80P64e00<0Of0d07iO<`1mGS800P1lGC401`1kG300MEP/07AG:`1bEB/0Ke8Z06a>:01YBbL0
0P1WBBD04@1UAbD0Ed@T05Q59@1FABL0Dd@W05129`1<?R@0ASXP04<g7`0k>B80>SPQ03Pf8@0f<b00
<c0O030]700^:a`0;BXK0080<BXJ00L0<2XL02dY7@0[:Ad0:BTO02PX7P0W:200:2XO00809bTN00<0
9BLL02@V6`0S9AX00P0R91T301hQ6PD07b8K200Q91d00`0O81P0824I028S6`0302@U7@0302<T700R
8a/07b8K00L07b8K0P0O8Ah201hP7@<07AlL00D071hK01XL6@0K7AX06adJ01`N6`0201dO70807R0M
00`07b0H020R5`0Q8aP08bDH02@V600V:AP09bXG02P[600U9aT09bTK02T[7@0[;Al202`^800802/]
7`0Z;1h0:2TI02LX600V9aT09RHJ02DU6`0U9Ad202DT7`0802LW6`0X:1`0:BXL02//7P0^;al0<34O
034c7P0b=1l303Td7PD0>SDO200m<A/203/c8080>S8O00`0>C4N03P`7@0h<1d0=blL03He8`0e=280
=3<Q03<b800b<Al0<C0N030_7@0_;Q`403<^6`80<RdJ0`0a;1T00`0d;a/0=C0L03Ha7@0203Ha7@04
03@_6`0b;AT0<B`H02P[8P<09bXQ0P0V:B0202DX7`0802@S7P0U91l09RDP02LV8@0V9B009B@O02<R
7@0R8A`302@U7@<09BHN0P0V9al802<V6`0N01hT800O91h08R<K02XX6`0f;al0ASTV05A4;@1LBS80
JEPR071O:@1mJC@0RG@o091iA@2DNTT0U7Q8099fAP22IS@0Nel_06aD:01NAR00CCPI040_5@0h9a<0
=2DB02dV800^:R40<blV03Hd9`0g>2P0=cXW0P0f>bD203<l9`0803<k900c>240<cLN030d6`0`<aP0
;c8G034d8`0`<b8302lb8@0T034d8`0b=B@0=3LV03lh9P0m=R@0>c@Q03/e7`0m=al0@S`T04M19`1:
A2X0BdLZ04e8:`1=B2X0CdTY0599:01DBRL0ETTW05I99P1FC340E4/^0599;01AB2T0DDPW05=;9`1E
CBP0EThY05Q8;`1IBBl0G4/a05m;<01PBbh0GTTZ05i79`1MARH0G4`X0P1NC2P00`1PC2T0HT/Y06=;
:@0206A::@<0KE4Y00<0KU8Z06mC:`1_Db/00P1`E2`0301eD2@0Me8V07aF:@22FBd0QEX]08IL;027
FbX0RE/Z089O9`23H2P0QV<[08UV;P80RVL_00<0RFH^08QU;@2AJ3800P2AJ382091Y<P0D08mZ<`2>
Jc<0S6`c08a/<`2ILSL0V74f09Ea=@2BL3<0SVha08]];`2:K2h0R6`]09Eh@02<KcL0PfD_081R;P22
I380QFLe08EV=`23I3D207YO:P80Nf0[0`1lHB`00`1mHRd0OV8b07mS<`02081T=00J07mS<`1lH300
NUh^07QL;01fGc<0MEhb07AM<@1cG300M5da07EN<P1hHCD0NF8f07II;`1dEbd0LUD[071C:@1aE2X0
M5L]07QK<@1kGS@0MUXc07AH<@1aDbd0KU0Z06i>:01^C2L2071<:00606iI;01/Eb`0JE@Y06I@9`1U
CbP0I4hY0P1TCB/01P1QBa`0Hd`P06M@901ZDbT0KEH]06iF<080KEDa00T0JU<c06M@<01PBb`0FdHY
05E19P1A@2H0CShT04hn9@17?B@00P18?2@00`19>R<0BSXS04Xh8P0204`g8P0@04Li7P18>Ql0BC/N
04`o7`1>@Al0DD@Q05=68`1EBB<0FT<Q05]48P1LAB<0GTLU05m89P1QBRP0HT/Y06=<:P80IU<X00L0
Ie8W06QA9`1YD2L0JdlW06Y>9P1[CRH0Je0U00@0K54V0`1]DRL0401cFBP0LELV06mE901^E2<0KeDT
075G9P1dFRT0ME/Z06iD8`1_EB@0L5HU079H9`1cFBP0ME/Z07IL:`1gGB`306iC:0D0Ke@Y0140KeTW
06iH9P1^F2H0KELU06aF901]EbD0KUPV071J:01aFbT0K5LZ06]F:`1ZEBX0J58Y06MA:P1UCbX0I4d[
06=<:P0805i<9080H4XS1P1QBb@01P1QCbT0H4hX061>:01NC2H0GD/U05a:9080FdTS201HB2@205E6
9@0405A5901CA2<0DD8Q05118080Cd0O00H0D3lQ04m08@1?@240CT4Q04e28P1<@b8204Y48P0804Ho
8`15?R80A3dQ04<l8011>Qh0@3TM03lh700n=a/203dg7@0303/g700h=a/0=SHJ0080<cHI00L0<CHH
03Pd6`0f=1/0=C<L03<b7@0a<ad0;c8M0080;C8N00H0:blH02/^6@0[;QT0:bhK02/^7@0[;Al202/]
808092LN00<08bHM028U700Q91/00P0O8QT0100N8AP071lH01hQ6P0O8Q/2020S700301hQ6P0L7aP0
6QdF00807AlL00@071hK01/M6P0K7AX06Q`I0P0I6aP301PJ6@<05aTH0P0F61L801<I5`805QLI0`0E
5QPl01@E5`P04ALG400D5AL8018C5AP051DG200A5aL@01@E5a005AHH200F5aTQ01HH5`805aTH0P0H
6QT201TK6P806Q`K200K6a/801`L6PP07QdH200P8A/:024Q6@04028R6P0S8a/092@L02@T70809BDM
200S8a/3024Q6@808R8J0`0S8a/202HQ6`809b8L0P0X8ad202TT7P80:R<K00@0:b@L02`U7@0/9Ad0
;BHN0P0^9al0100b:1h0<BLM034W7@0a9ad3030V700902lU6`0f:B00<bTO038X7P0`:1d0;RPL02/W
6`0Y9aX0:2HI0080=BPO0P0d9ah303<V7@04038U700_9aX0;bLJ02lW6P80;RHI0`0]9AP902HV7PP0
9R4M0`0W8Q`502HQ6`80:B@N0P0X8ad202LR70809R4K200T91`502TU70<0:2@K0P0Y8QX0100Z8a/0
:b@L02dV7P0^9al202lX8080;BXK00@0;bTK034Y700b:1`0=2PL0P0f:1d303L[6`80>2`L0`0i;Ad2
03/Y7@0403`Z700m;1`0?RdM03l^7080@2lK00H0?BhK03h_700o;Q`0@RlN04<`7`16<B0204Pa8@06
04Xg9P19=RD0B3DT04Ld8`16<b80A34P0P13<1l204@c8`0404<b8P12<B40@C0P03l^7P80?RdM0`0m
<20203`_7`<0>bhN00P0<BDI038V6P0c9a/0=2PL03DY7@0f:Qh0=b/O03P/8080>BlS00@0>2hR03L]
8@0e:al0=2XN0P0c:Ad00`0b:1h0<BLM030V700202lU6`06030V700a9ad0<RPN03P^900f;280<bTO
0P0`9Q`01`0a9ad0<bTO03@Z800`91H0<RHH03DY6`0h;1h00`0j;R000`0i;Al0<bTM03<Y7@0303@Z
7P@0=B/O00<0<bTM03@Z7P0e:al00P0f;20303L]8@80>RdL0P0k;Qd01P0l;ah0?C0O03d`7`0n<B00
?2lN03d`7`80?S4P00X0?C0O03/^7@0i;1/0>2/J03h[700o;1d0@2dN044^7`12;b00@c0Q0P14<B80
0`0n<R80?C4Q03/_7`0203X^7P0303/_7`0m<B40?S8R00<0>RdM0P0k;Qh303`_7`P0?34O00<0?BXK
040]7P13<2400P16<b@00`13<240@2dN03dZ6`0803ld7PP0?34O00<0?BhK03l`7@10<Ah00P12<b00
2`10<Ah0?c0M03d^6`12;b40@BhP040]7P10;A`0@S0L04Dc7@17=Al0BCLO0080A3@M0P15=Ah304Hf
7`0<04Lg8018<ah0B3<N04Hd7P14=1d0@c@M044e7@10=1`0?cDL04Dd8P14<b40@S4O0`10;ad02P11
<1h0@S4O048b6`13<a`0A3@M04De7P16=Ql0AcLP04Ph8@19>B8804Ph8@P0BcTS2@1>>24804Lg8080
AS@L00@0AcDM04Pf7P1:>200BcTQ0P1<>R8204/k8@0304Xj8019>Al0BCTO00<0B3PN00P0CCPS04hi
901>>B@0CSTT04`g8P19=1l0AS4L04@_6PP0ASHO00P0BCLO04Ph7`17=ah0ASPN04<g7@12>1d0@3TM
03lh7080@C@Q0P12=B8304<f8`0904@g9016>BH0ACPU04@g9013=R<0@SDR044d8@10<b00?c8O00P0
AC8S0`15<R4[ooooo`00:_ooool309]_?P0309Y^?@2IKC`0V6`k0080V6`k00<0Vfln09Y^?@2HK3/0
0P2GJcX02`2HK3/0VVhm09]_?P2JKSd0Vfln09a`?`2MLD00W70o09]_?P2IKC`0V6`k00<0X7A30P2O
Ld8309ib@@@0X7A3102OLd801P2QMD@0X7A30:1d@`2NLT40WG5009a`?`80Vfln00h0X7I40:5gA@2R
N4H0XgU70:9hAP2QMdD0WgE309id@P2NLch0Wg@o0:1e@02QMT40XWM20:AiA080YGY5202SMdH20:=i
A`@0XWQ60`2QMdD20:9i@@040:9i@`2QN4@0XGQ40:1fA080X7I600H0WG9509aaA02LLD@0Vg1309Y_
@P2IKT4209Q]@00609U/@P2GK440Ufa109E/@02BK3l0T6/n0P2=Jcd508eS>`<0S68j00D0PU`g085K
=P1oFC@0OELb07aF<@0207eG<P0307iH<`1mEC40OEDa0080O5@`101kDbl207AC:P03079B:@1`DbT0
KU<X0080K5@X00<0JU<W06]>;01[CR`01P1[CR`08P1ZCBl0JD`^06M::P1WBRP0J4/Y06Y>:@1]DBX0
KU8[06a?;@1]DB`0Ke4]07=C;@1fE2h0NEH^07YG;@1mF2h0OU`^07eK;@1mF2/0OUP[085H;024FBh0
Qe`a08UL<P26HCD0R64f08US=P2<HcD0SV@d095U=02DISD0U6Hd091Z>`2?JCX308iX>@03091Z>`2B
K3d0Tfdn00P0TF/n00H0T6Xk08mY>P2?JCX0SVPi08eW>02<ISL208]U=PP0T6Xm202BIcX03@2AIST0
TVLj09AY?02EJSd0U6Tl099W>P2?I3L0SF8e09E[>@2DJSP0TfTg099X=P2AIcD00P2@IS@0102?IC<0
SV@b08mU<`2?IC<2091V=0<0TFLe00@0TVPf095V>`2BIc`0U6Tn0P2EJSl01P2DJCh0TVLl095V>`2;
JSD0S6/f08i]>080T6lj00<0Sfhi08i]>02=K3L00P2DJSP209E[>@@0UV`j00@0UF`h09I]>@2FKCT0
UVdi0`2GKSX01P2HKc/0W79009Y`?P2FK3X0TfTg095W=@80T6Hd00D0TFLe09I/>P2DJSP0TFLe08mU
<`0208eS<@0508iT<P2?IC<0U6Tl09=X>`2BIcX00P2AIST0302BIcX0TfPk09AY?02FL440UFm0099/
?@2AJc`0T6Xk095[?02CKCh0U6ho099/?@80TF/l00<0T6Xk08mY>P2?JCX00P2>J3T408mY>P80T6Xk
0P2AJc`209A_>`80Tfhj00@0TVdi095/>02AK3P0T6/g0`2@JS/2095[?0<0TV`m202AKCd02`2BJd80
TV]0099/?`2AJcX0TF`g091[=02@K380T6``091[?P2>JC`0S6Lj0080RVDh00<0RfHi08aW>P2=J3/0
0P29Hc@05027Hc<0Pf4a085Q<01oHBl0OV0^07]O;@1oFRd0OU`_07mM<01nGC80O5`c07QK<`1dF340
LUH_07MF:`1eE2/0LE4X06a?9`1YCBH0IT`W0P1VC2T02@1UCBT0FdHW05U49`1F@bD0DT4U04hn901:
?280B3TR04Di8@0203ld7P0703db7P0k<1h0>BdM03L[7@0e:A/0=2PL02/[8@0302XZ8080:BTO0P0X
:1h0200W:2809RLQ02DV800S91h08B8L020Q6`0O81X07QlI200Q8Q`8020Q6`0302DX8@0S9Ql08B@M
00807b8K00<082<L024T7@0R9Ah0200P8a`801lR6`0601`M5`0M7QP07AhH01hO6@0O81X0824K0P0Q
8Q`02`0Q8Qd08R<N02<T7P0T9Ad09RPM02LY700X:Qd0:2XL02TY7`0Z:R00;2`R0080;BdS00<0;2`R
02XZ800X:1h00P0O9A/03P0R9A`08b@L02DU7@0W91d0:2DN02TT7P0V:Q`0:2XL02T[7@0/;Ad0<2lM
038_700e<1`0=S4M200i<Ah0100i;1/0>bhM03ha8011=2<304<f9@04048e900h<b00>3<P03Lb7`80
=S4N00/0=C0M03@_700d;a`0<c0Q038_800`;Ah0;b`M02h[700_;1d0<2dN034^7`0302`]7@H0;BhN
0P0_;Ah00`0^;1d0;B/L02`Z6`0202/Y6P0702XX6@0W:a`09RXK02DY6P0T:1T08bLH028V5`02024U
5P0601lQ4`0P8Q@0828D028T5P0S9AL092HH0P0U9aT01P0Q8Q008R<C024S5@0Q91T08RDN020U7`80
7bDS024081hB020P5P0Q8aP07R4H01TN600H7QX06R<N01lX9@0c:1H0=2TE03X/4P12<a@0DT0J06A?
901cGBh0O6Dc08]b>P2;M3h0SgQ4099lB`2AO4l0R7E;07UW?`1^G3H0F50k0559=P15?R/0>C@Q030]
700]:a`0;B/N02d^800a<bD00`0b=2H203<e9`80=3HX0P0e<BH03P0f<RH0=S<T03Ld8`0g=240>3DR
03Pf8@0/=2D0:c@S02`c8`0_<b80<SDR03Hh8`0i>bD0?3/V0P12>R<0<@15>b80B3`R04do901A@RD0
EDHY05Q7:@1EC2<0FE0Y05eD;@1MDbl0F4h[05A9:@1CB2X0E4T[05=?;01BCR/0DD/Y0599:01CB2P0
EdXZ05Q;:`1JBb`0FdLV05a89`1NBBX0GT/[05a;;@1JBbh0F4P^05I8;@1NBB`0H4P/065::`1RBBX0
HdTX06I99`1WBBL0IdTU07I8;P1gBRd0ND/Z07e=9`20Cb@0PU8R08ID8@27EB00QUlX08MP:@29HR/0
0`2:Hb`00`29HR/0R64Z08US=00208US=00308QR<`27HC80Qf4b0080QV0a0P2:IBh01@2<Ic00Sf/a
099^<P2DL380UG8b0080UG8`0100T7Pb08mf<`2>MC<0S78e08]a>029KST0R6`j08M[>@24L3h0PFdk
07iV=P1mHS<0P64c08AR=@2;ISX0SfPm0P27IS4208IU<00408ET;`24Hbh0Q6<^08=R;@80QF@_00<0
Q6<^08=R;@22HB`00P21H2/04P20GbX0Of@]07mT;@1nHb`0O64Z07]P:@1jGbP0NEhW07QM9P1jFBh0
MeH[07AE:@1`DbL0L5DX075I:`1dG2h0MV0a07QM<P<0Me`a0P1fFc0207EJ;`0:071H=01^ES80JE4]
06E=:@1TC2P0IDdY06M?:`1YDBd0K4l]06]>;080JTd[01@0Jdh/06iA;`1aE380LUDc06YB<01/E380
KEDc06YB<01TC2X0H4PV06599`1TC2X0CchP04dl7P1;>Qh0BCPN04Tg7`1:>280BcTS04dk9`80?SHQ
00/0?cLP040i7`11>R00@S/O04<l7`14?B00CSdO05508P1DA2<0F4PV05];9`0205a=9P0<05]<8`1M
CRL0H4hX06=A:@1VDbT0JUDZ06YC9`1ZDRH0JE4S06iC:01]DRL0K54V0P1[D2D00`1]DRL0Ke@Y075F
:`02075D:003079E:@1cERX0M5L[0080MEP/00@0MUT]07=H:`1aERT0Ke@W0P1]DRD00`1_E2L0LEHY
07=H:`02079E;@04079E:`1cERX0LeLX07=G9`80M5PV0`1dEBT0101bEBT0L5DX06iF:01/ERL206]F
9`06071B;01_Db`0KU8[06YA:@1WD2L0IDlV0P1QCR@206I=900F06A=8`1SCR<0H4dR05i=8@1MC200
FddP05e;8`1NC2@0GddU061>9P1OCBD0GT`T05a:8P1KBB40H4hX05m=9`1NC2H0GD/U05a:901KBB<0
FTPR05U78@<0F4XS0P1GBB8305I88@80DdLQ0P1BAR00501AAAl0D4@N04m37@1?@ad0CChG04i06`1@
@Qd0D4<P04i48@1<@b80BD<S04M18@1<?R<0BcdR04Pm8@16?B00@c`O040k7@0o>Q`0?S/L0P0m>Q/0
1`0l>1/0?3PM03/g7P0j=Al0>C@N03Td800`=Q`01`0_=A/302`_7P80:bhM0`0Z;A`202DY6P<092PI
0`0S9aP2020S6P<07b8I0`0N8AP01P0O8Q/07R4J01hQ6P0M81T071lH01/N5`806QdF0P0J71T201TK
60<061XG00<05aTF01<I5`0C6AL00`0B61H3014G5@<05aPJ0P0F5aT=01DF60<051DG0P0C51H2018C
5AP051DG200A5aL801@E5`P03aDE200A5aL8018C5BP051DG4`0E5QP201HG6@<05aPJ200E5QP801HH
5`T05aLG200H6QT801XJ6Q006QXH400L71X201`M5`<07AhH0`0N7aT0100S8a/08R8J028R6P0Q8AT2
020P60807alG200S7QP2024P7003024P6`0R8QX08R8H00808b<G00<08b@F02@O6@0T7aT01P0T7aT8
020Q6@P09R8I0`0]8aT202hT6P<0;bDK200c9Qd203<Y7@80=2XN100e:al203P/800403L[7`0f:Qh0
=2PL03<W6`80<RHJ0P0c:Ad3038X70<0<BLK0`0W91/602PU70@09b8L0P0V8A/:02DP6P<09b<J0`0V
8QT202DQ600602HR6@0W8aX09b<J02PT6`0Y9A`0:RHM0P0[9ah2030Z7P0402lY7@0^:1`0;BLK02dW
6`80;2HJ0P0/9Ad302dV7P<0;RLO0`0c9a/303@X7080=BTM00P0=2PL03<W6`0c9a/0=2PL03DY7@0h
;200>blS03``9080?RdM0`0o;Qh3040_7`80@c<L0`14=1d304De7P<0AS@N1@15<ad8048a7`0404@c
8@13<R00@c8P048a7`80@C0N0P10;ad0200l=240>S8O03L^7@0e;1d0=2XN03D[8@0f;280=bdT200l
<200100d;R80<bdQ03<]8@0c;B42038/80@0<B/O0P0b;20303<]8@0303@^8P0e:AT0=BTI00H0=BTI
0P0a:al2038/80@0<bdQ00H0=2hR03HZ700f:Q`0=b/M03P/7P0i;Al203/_8@0903``8P0k<1`0?2lL
03d`7@10<Ah0@S4O04Db8@17<R40B3<R00P0@c8P1@0l<b8303/b8@<0>S4P0P0k<R4303`c8P80>R`O
00<0>bdP03`^8@0m;b800P0n<2<0100o<B@0@C@T03ha8@0k;Qh203P[6`0303X]7@0n<B40@3<S00P0
?S4N2011=2400`0o<Ql0?S4N03d`7@0203`_700303d`7@0n<Ah0?c8O00P0?c8O00P0?bdO040^8010
;al0@C0N048a7@13<a`0A3@M04@d6`80@c@M00@0ACDN04Hd7P17=Al0BC@O0P1;=B04044g7P80@3HM
0P0o=A`0100k<1`0?34M03`a7@0l<Ad203db7P80?S<O00P0ASHO04De7P14=1d0@c<L04@d7@15=Ah0
AcLP04Ti8P80CSXR0P1=>B40101<>200BcLO04/g7`1:=Qh304Xj8@80Bc/R0`1<?2<904`h800304Xj
8@18>1l0ASHM0080A3@K00H0ACDL04Hf7@17=ah0C3XR04/i8@19=al204Pf7P0;04Tg7`1;>B40C3XR
04/g7P1<>1l0CSXQ04lk8P1>>R40CCTP04Xf7@19=A`0201>>R8304Xh8P80BCLQ0`18=R00201;>b@0
BCTR04Lg8015=Ah0A3@M04De7P16=Ql0AcLP2019=b4804Dk8P0804<k9P12>RD0@CTT040h8`0o=b80
?SHQ03de800l=1l304Tf9b_ooooo000Zooooo`80W70o0P2KKch209Y^?@80VFdl00<0Vfln09Y^?@2H
K3/00P2GJcX02`2HK3/0VVhm09]_?P2JKSd0Vfln09ea@02NLT40WG5009a`?`2KKch0VVhm00`0Wg=2
102NLT401@2QMD@0X7A30:1d@`2OLd80WG500080W70o00@0Vfln09id@P2PMT@0XGM50P2RN4H0102Q
MdD0X7I409me@`2LLC`209eb?@0509ic?P2OM3l0X7E00:1e@02QMT40202SMdH00`2QMdD0XWQ60:9h
AP060:9hAP80XGQ000@0XGQ20:1g@`2PMd<0WgE30P2OMDD01P2MLTD0W75409aaA02KL4<0VVm209U^
@@80V6e000P0V6]109M/@@2FJd00U6/o095[?P2?JSd0SF/m08aZ?0<0SF<k0`2<HSX208]Q>@0408=M
>022G3L0P5Xe07eG<P80O5Ha0P1mEc8207eE<@80O5@`0`1kDbl02@1jDRh0M58/07=A:`1bDR/0L5<[
06iB:P1/DbX0Je8Y06YC:@0806]>;00@06U<;P1XBbd0J4/[06M::01XBbT0JThY06eA:P1^DR/0K4l]
06eA;01_DBd0Le<]07ID;P1iERh0NUL]07eH;P80OE/]0100OUT/07mI;022FBd0QEX_08ML<@29G380
QV4e08QQ=P29HcH0S6<e08iT=02AIC@0U6He09AV=02@JS/0SfTj0`2>J3T00`2@JS/0TV`m09=]?P08
095[?P<0SVPi0`2=IcP208aV=`P0T6Xm202BIcX208mT=`80T6Dh00T0Sf@g08iS=P2=HSD0S64d09E[
>@2DJSP0TfTg099X=P2AIcD00P2@IS@308mU<`<0T6Hd0P2AIcD2099X=P03095V>@2BIcX0U6Tl0080
UFXm00H0U6Tl099W>P2AIST0RfXe08a[=P2>KCP3091_>P0408m^>@2>KCP0U6Xh09AZ>080UF/i0`2F
K3X00`2GKC/0Ufhj09M^>P0209M^>P@0UVdi00H0VW0n09Q^?02FK3X0TfTg099X=P2AIcD2099X=P04
09E[>@2CJCL0TFLe08mU<`80SV@b00D0SfDc091V=02DJC`0TfPk099W>P02095V>@0;099W>P2CJ3/0
U6Tl09A^?`2CKCh0TF/l091Z>`2?JCX0T6Xk095[?02BK3d00P2AJc`2091Z>`0308mY>P2>J3T0SVPi
0080SVPi0`2?JCX2091Z>`80TF/l0P2DKc/209=^>P04099]>@2AK3P0TF`h095/>080T6Xk0`2AJc`3
099/?@P0TFdm0P2BJd00102AJch0TF/j095/>02@Jc@2091/<P0308mZ?@2>JC`0S6Lj0080RVDh01T0
RfHi08aW>P2=J3/0RV@e08US=027Hc<0Q68b085Q<01nH2h0OEl]07YN;01oFRd0OU`_07mM<01nGC80
Ne/b07MJ<P1dF340LUH_07MF;@1dE2/0LE4Z06]>9P1XC2D0ID/V00<0I4`X0100FTDX05Q59`1F@RL0
DD0V04dm9019>R<0ACTQ04@h8P0m=Ah0?3@O03/c7P0i<Ah0=bhM03D/7@0c:Ad0<RPL100Z:R0202TY
7`80:2PN00P09RLQ02DV800T9Al08b@N024R700P8A/07b0J01hO6@P08B8L200P8A/00`0T9b008bHO
024T7@0201lR6`03020S700Q91d08RDN00P082<L200N8AX201dN60807QlI01X07b0J020Q6`0Q8Q`0
8B8L02<R7P0S8Qd092<N02HV7P0W9ad0:2PL02TZ700Z:ad0:RXP02/[8@0/;280;BdS02`/8P0Z:R00
:2PN02LW7@0O9AT08B@I028U6P0T9Q/09RHL02TV7@80:bLN00H0:B/M02X/7P0/;Ad0<2hO038_7P0d
<Ah203Lb7PP0>C4N00@0>bhM03d`7`0o<R40@C@S0P12=B@00`11=2<0@3<R03Lb7`0203Lb7`0303Ha
7P0e<1d0=C0M0080=2lL00P0<c0Q038_800`;Ah0;b`M02h[700_;1d0<2dN034^7`@0;BhN1@0^;al0
1P0_;Ah0;R`M02d[700]:a`0;2XK02/Y6P80:RPI0P0V:Q`01`0U:A/092PJ02<W6@0R9QP08BDG020T
5P0O8A@00P0P8QD0;@0Q8aH08bDH02@V6@0T9QT09BLJ02DV5P0U9QP092HI02@V6`0R9Ah08R@O020U
8@0P92<08B8J02<T700T9Ad08R@I020R5`0Q8aH09bTL02`^8@16=Qd0BCTO058o8@1MBBH0JeD/07YR
=027KC`0SW9008iiA02;MT40Qg=108E`@`1nJd40Lf4i06AD<01JBRH0@SXW03hg900i<R00=2hN034^
7`0b<240<c@V03Df:00202h`8P80;c4S0`0`<R@02@0a<bD0=C4V03Da9P0f<RH0=S<T03Ld8`0g=240
>3DR03Pf8@0202dd900R02lc8P0a=2<0<cHS03Hh8`0k>RD0?C`W04@l9@14?B<0AcdT04Xn901?@BH0
Dd@W05M8:@1JBB/0F4lV05]B:`1NEBh0G58^05M=:P1DBBT0E4T[05I;;@1DD2d0Ddd[059<:P1BBBP0
DdPX05I9:@1HBBX0FDX[05Y69@1LB2L0G4TY05e::P80FdX/01D0F4T/05M8:`1MARL0GTLX0658:@1T
BRT0JD`Z06a>:P1`Cb`0LE4[07e@<@1oDC00P58`08AD;027F2`0RUXZ08aM:@2=GRP0S6D^08eV;`2>
Ic000P2?J3400`2>Ic00S6D^08]T;@0408US=0@0R68c0P2:IC001@2<Ic00SfXc099^=02DL3@0UG4c
0080UG8b00H0T7Db08mc<P2>LS<0S6le08]^=P29JcD208QZ>008089/>`20JST0OVHf07mS=021HS@0
Q68e08UT>02;ISX208MV<@80QVD`0P25I2l208AS;P0608IU<025I2l0QF@_08AS;P23HRd0PV4/0P21
H2/207mT;@0407iS;01mHR/0OF8[07aQ:P80Nf0Y00P0O5/`07YI;P1fEb/0LUDY075F:@1aFB/0MEd_
07IP<@80MEX_0P1dFBh307=H;@0;079G;01bFS@0KeLa06]C;@1WCbT0IThX06M?:@1YDB/0JU8/06a@
:`1[CbX00P1ZCRT04P1[CbX0KE4/071D;`1aEC00JE4_06aD<P1]EC<0JU8`06E=:`1RBRP0Hd/Y06E=
:`1IARH0Ed@T05=08P1@?240CCTP04`h8080C3LR00h0@CTR048j8`12>b40@c`R04<l8014?B40A3dP
04Dn8@1<>ad0CSdO05928@1FARD0FDTW05Y:9P80Fd`U00/0G4dV05m=9`1RD2P0IE8X06QC:01YDRP0
JU8V06UA9@1^DbP0KE8W06aA9P0206]@9@0306eB9`1_E2T0L5DZ0080LE@X00@0LUDY07=F:P1dEb/0
M5L[0P1eF2`2075F:@@0Ke@W0P1aERT2075D;004075D:P1bEBT0LUHW079F9P80LeLU0`1dEBT0101b
EBT0L5DX06iF:01]EbP206]F9`0C075C;@1_Db`0KU8[06YA:@1XDBP0IDlV069?9@1QCR@0IdhU06I=
901UCR@0HdhS061=8P1NCB40GD`P05]=801MBb<0GT`T05m=9@02061>9P0905i<901LBR80FdTQ061>
:01OCBL0GT`V05e;9@1LBR@0FdTS0080FTPR0`1HBR<305M98P80ETPQ101BAR0305557`0905147P1@
@AX0D48M05947`1AA240CdDR04a38P19@b<0Ad4Q0080C3hS00D0BChR04Hm8013?1l0@C`N040k7@02
03hk700703dj6`0m>A`0?3PM03/g7P0j=Al0>C@N03Td8003030f70@0;cDK00@0;S@J02`_7P0/;ah0
;2lN0P0[;Qd302X]70<09BTJ0P0T:1T302<W60<082<J0P0O8QT301hQ600601lR6`0N8AX07R4J01dP
6@0L7aP06ahG0P0J7AH201XL6@806A/H100H6QL301<I5`804QPF0`0A5aD301LH6P805QLI3@0E5QP3
01@E5`804a@F0P0B4aDH01@E5`P04ALG200D5AL800lE5@P04ALG200B4aDX01@E5a<05AHH0`0F5aT2
01LH6PP05AHH200F61L901LG5`P061XI200J6QX@01XJ610071`J0P0L7AL301dN60<07QlI00<08b<K
028R6P0R8QX00P0Q8AT2020P600301lO5`0S7QP08ahH00H08ahH0P0Q81`00`0R8A`08R8J028R6002
02<S5`0302<T5P0T7aT091lI00H091lI200Q8AT802HR6@80;B<I0`0^91X302lU6`P0<bHM0P0c:Ad2
03@Z7P<0=B/O00T0=R`P03P/800h;200=b/O03HZ7P0e:Ad0=2PL03<W6`0b9QX00`0c:Ad2038X70<0
<BLK2@0X9A`0100X8ad09b8L02LR700W8Q`202HQ6`X09B0J100V8QT402LS6P0602HR6@0W8aX09b<J
02PT6`0Y9A`0:RHM0P0[9ah302hX7080;BLK0`0/9QX202`U7@<0;BHN0`0^9al303<W6`80=2PL0`0e
:Ad203@X700603<W6`0d:1`0=BTM03P/800j;R80?30T0P0n;Ad303l^7P<0@2lO0`13<a`204@d7@<0
ACDN1016=1h404Dc7@P0@S4O00<0A3<Q04<b8013<R000P12<Al2044`7P05040_7@0l=240>S8O03P_
7P0f;Ah00P0e:al00`0f;280=bdS03/_7`0703/_7`80=BdP0P0d;1l303<[7P80<RXM0`0c:ah203@/
7`80=BdP200e:AT0100b:Qd0<b/N03<[7P0c:ah303@/7`80=BdP00H0=RXL03L[7@0h;1h0>BdO03X^
800k;b4203``8P0803/`700l;a`0?C0M040a7P12<Al0A34P04Lb8@18<b8804<b80P0?3<R00@0>C0O
03Xa800j<B00>S4P0P0k<R4203`c8P@0?2hQ0`0m;b80100n<2<0?c8R03d`800k;Qh203T/700303/^
7P0o<R80@C@T00P0?S4N2011=2400`10<b00?S4N03d`7@0203`_700303d`7@0n<Ah0@3<P00P0?c8O
00P0?bdO040^8010;al0@C0N048a7@13<a`0A3@M04@d6`80@c@M00@0ACDN04Hd7P17=Al0BC@O0P1;
=B001013=al0@SHN048f7P12=Qh2044e7@80@3@L100l<Ad203db7P80?S<O00P0ASHO04De7P14=1d0
@c<L04@d7@15=Ah0AcLP04Ti8P80CSXR0P1=>B4204`h8080BcLO0P19>B0304Xj8@<0Bc/R2@1=>B40
2`1;>b80BCTP04Lg7P16=Qd0ACDL04Hf7@17=ah0B3PO04`j8P1;>B40BCLO0080B3HN00/0BCLO04/i
8@1<>R80C3PO04di801>>R40Cc/R04hj8@1=>B00BcLN04Te700804hj8P<0BSPR0`19=b4204Pf8003
04/k9019>B80AcLP00<0ACDN00<0ASHO04Lg8019=b401`19=b4804Di8@0604<k9P12>RD0@CTT040h
8`0o=b80?SHQ0P0m=B0304Ld8b_ooooo000Zooooo`<0WG500P2LL3l409]_?P0309Y^?@2IKC`0VFdl
0080VFdl00D0VVhm09]_?P2KKch0W70o09ib@@0209mc@P0409ib@@2MLD00W70o09a`?`80WG5000D0
WW9109mc@P2PM4<0X7A30:5eA00809ea@0060:5eA02PM4<0X7A309mc@P2NLT40WG500P2LL3l01@2M
Ld40WWA20:1fA02RN4H0XgU70080XWQ600<0XGM509aa?02LLC`00`2LLC`309eb?@P0XWI50P2PMT@2
0:5gA@80XWQ600<0XgU70:AjB02TNTP00P2PMcl0102OMT00WgI209ie@@2NM48209ec@`0609ebA@2L
LD@0W75409]`@`2JKd80VFi10P2HKD001P2HJd40UV]009I[@02DJcl0TF/n08mZ?@80S6Xl0`2:HcX2
08UR>@<0R64h00D0QElj08=M>020FSD0OUPc07aF<@0207]E<00407aF<@1kEC00NeD`07]E<080NU@_
0`1iDbh207=A:`03075A:P1_DRX0KE4Y0080Je8Y00<0JE8X06Y=:`1ZCB/01P1ZCB/0401YC2h0J4/]
06Q;:`1XBbT0JD`Z06]?:P1/D2T0KE4Z06a?;@1]DB`0Ke4]07=C;@1fE2h0NEH^07YG;@1mF2h207eK
;@0@07iI;020FRd0PeX^08EJ;`27G340RE`b08IQ=@28HCH0RF<f08aS=@2>I3@0TFDd09AV=@2DIS@0
T6Xk08mY>P<0SVPi00<0T6Xk099/?@2CKCh0202AJch208aV=`<0SFLh0`2>J3T8091Z?@P0TVLj00<0
Sf@g08iS=P2=HSD00`2;H3<0102<HC@0SF8e09AZ>02DJSP209=Y=`03099X=P2AIcD0TFLe00@0T6Hd
0P2AIcD3099X=P0409=Y=`2BIcX0TfPk09AY?080UFXm00/0U6Tl09=X>`2BIcX0SVXf08m[=`2AKCT0
TVhj09=_>`2BKSX0TFdi091/>00309E[>@80UV`j0`2GKC/01@2IL3`0V6lk09Q_>`2GKSX0UVdi0080
UF`h00D0U6/g09M]>`2FK3X0UF/i09AZ>00209=Y=`80U6Xh0P2BJ3H2091V=00708mU<`2@IS@0TFLe
099X=P2CJ3/0TVLj095V>@02091U>006095V>@2BIcX0TfPk099/?@2AJc`0SfTj0`2>J3T208mY>P80
T6Xk0P2?JCX708iX>@80SfTj0`2@JS/309=^>P<0TVdi0P2AK3P0102@JS/0TF/l095[?02AJc`2099/
?@80Tfdn202AKCd01P2BK3l0TF/n095[?02AJcX0T6/g091[=P80SfXc00@0SVTl08eX>`2<IcX0RfHi
0P2:ICP02`2;IST0S6Lj08]U=P2;ICH0R6@d08AR<P21HC00OV0^07aN;01iGB/0P5/^0080OU`_00/0
O5/`07YJ<@1fFC40LeL`075E;P1dE2/0LU8[06e@:01YCBH0I4XU069:9P03065::00@05M49P1F@RL0
DT4U04hn901:?280ASXR04@h8P11=R00?3@O03/c7P0j<Ql0>2lN03H]7P0d:Qh0<bTM038X7P<0:RXP
0P0Y:Al302PX7P809BHP00H092DO028S7@0Q8Q`0824K01lP6P0N7aT@020Q6`0402<V7`0R9Ah08B@M
020S70807b8K00<082<L024T7@0O8Q/01`0O8Q/801dP6@0601dN600N7aT07QlI01lP6P0P8A/08B8L
0P0R8ad202@S7P0402DU7@0W9ad0:2PL02X[7@80:b`L100/;2804P0Z:R00:2PN02HV700U9A/082<H
024T6@0S9AX09RHL02XW7P0/:1l0;RXQ030Y8@0/;R00;RlO02l`800b<Al0=C8O03Pc7`80>S@N200j
<Ql00`0l<Al0?C8P03hc8@0203ld8P0403hc8@0m<R00?C8P03Lb7`<0=S4N0`0e<1d02@0d;a`0<c0Q
038_800`;Ah0;b`M02h[700_;1d0<2dN034^7`0902l`8080:b`N0P0Z:ad0100Y:Q`0:2TK02LX6P0W
:1X202DX7@0302@W700S9Q/08RDJ00808B@I00L082<H01lQ5P0P8QL0828G024S600R91T08bDJ0080
92HK00H09RPJ02HX6`0U9aX08bDJ028S6`0Q8Q`2024R7@0P01lT800T9R409bPP02XX6`0]:1D0<R`F
03dc6P14>Ql0GdLS06E=:@1_ERh0O64f08Q/?@2ALd40UWQ409UjA02<NTX0Q79407MV>P1[G3<0HU8^
05I79P1:?Ad0@S@G034Z5`0a:QP0<2/H02l/6`0`;Ql0<C8T03@d:00e=bX302`^8080;BlQ0`0^<282
03Da9P0>03Hb9P0f<b@0=c@S03Ld8@0h=B80>3HQ034e9P0`=2<0<C@S03<d8P0g=R80>cTT03hl9@11
?2H204Q19`0704Y09@1=@RH0DT@W05I7:01JBbX0GDd/05aC:P0205iE;P0U05]A;@1FC2T0E4TY05I;
;@1JCc40EU0^05A>;01DBbX0DdPX05A79`1FAbP0EdPY05Q7:@1IA2D0FdHW05]8:01MBRX0GT/[05e:
:P1LBBT0FdPX05a48P1OAB@0HTPU06U=:01_DB/0MUH_07YH<P1lFc80QUPf08MI=@29G3D0Rehd08iR
<`2@IC80TVL`09=X<@02095/=@06099]=P2CKSL0TVdf091[=02>JC80S6L`0`28I3@408UU=@0708YV
=P29IC40RFDa08]W<`2=JS@0T6de099_=@0209=a=009099`<@2<L340Rfhb08Y]<`29K380R6Xd08IX
<P25Ic<0QFLe0080OfDd00<0P6@d089S=023Hc@00P25HcD00`27HSD0QfHa08MV<@0308IU<0<0QF@_
0P26IC000`25I2l0Q6<^08=R;@02089Q;003085P:`1oI2d0Of@]00H0Of@]00P0PF0e07mN<`1jFbl0
MUT]07AI;01cFbd0MEd_07EO<080LeP]0`1bEb`3075F:`0807AL=P1aFC<0KUH`06]C;@1YDB/0JU8/
06]C;@1/E2h406]?:P0D06a@:`1]DB`0Ke<^071D;`1XD2`0Je<_06eE<@1[Dbl0IThZ06A<:01VCRX0
J50/069?;P1PCB`0G4TY05M49P1C?b@0D3`S04di801=>B4404Lm8P@0AS`Q0100BCPL04/j7P1??R00
DT8Q05E58`1HB2@0FDTU05U:8`1JBRH0GD/W05m=9`1RCbL0IU0W06M@9P1XCbH0J50T0P1/DBH306]@
9@0306eB9`1^DbP0Ke@Y0080L5<W00<0LE@X079E:@1cERX00P1dEb/00`1eF2`0Ke@W06mD9`04075F
:@80Ke@W0P1_DRX0101`DbT0L5<W071D9@1aEBD2075E8`<0MEHZ00`0LUDY075F:@1^ERP0KELX06aG
:01[ERL0LE@/06mC:`1^DRX0Je8Y06QA9`1VDBH206=@9@0:06Q?9P1WCRD0ITlU06A?901QCR<0GdhR
05i=8@1LCR40GT`T05m=9@<0H4hV00<0GT`T05e;8`1KBB400P1OCBL205i<9P0405e;9@1LBR@0FdTS
05]98`80FD/T0P1HBR<305M98P0305I88@1BA1l0DT@O00<0DdDP0`1DAR40401EAQl0EDLR05E78P1C
AR<0D4HS04e48`19@b<0Ad4Q04do901<?R<0BChR04Ln8@14?B00@C`N040k7@0o?1d203hk700303di
700l>1d0>cLN0080>SDO00<0>C@P038f7@0b=Qd00P0a=A`2030d6`80;c<J0`0/;ah202/^7@<0:RdL
00@09RXK02DY6P0U:AX09BTJ0P0T:1T202<W6004024T6`0P8aX082<J020S6P807b8I0P0N8AP01P0O
8Q/07R4J01hQ6P0M81T071lH01/N5`806QdF0`0J71T201TK60<061XG00@051XH01<I5`0C6AL04aTG
0P0B61H2014G5@<05aPJ0P0F5aT=01DF60<051DG0P0C51H2018C5AP051DG200A5aL801@E5`P03aDE
200A5aL8018C5BP051DG400E5QP201@E5`805AHH0`0F5aT00`0G61X05AHH01DF600601DF60P05QPG
2@0G5aL801PJ6@P06QXJ400J6QP@01`L6P8071dG0`0M7QP301hO6@@08R8J0P0Q8AT2020P60P08ahH
00P08B0L028Q7@0R8A`08R8J02<S6@0S8aL092@H02@U5`P09B0J200Q8AT802LS6P0402dS6@0^91X0
;R@J02hT6P80;bDK0P0`9Q`803<V7@<0=RXN0P0g:al503P/800303L[7`0f:Qh0=BTM0080=2PL00<0
<bLK03@Z7P0c:Ad00P0c:Ad2038X7080<BLK2@0Y9A`302PS7@809b8L2`0V8A/202DQ60809R8I00D0
9b<J02PT6`0Y9A`0:BDL02HR6@0202LS6P0302PT6`0Y9A`0:RHM0080:bLN0`0[9AT302`V6P80;BLK
0P0/9Ad302dV7P<0;RLO0P0c9a/203@X70<0=BTM00<0=RXN03DY7@0d:1`00P0d:1`0100e:Ad0=b/O
03X^8P0l<2@203h]7@<0?bhN0`10;al01012<Q/0@c<L04<c7013<a`204@d7@80ACDN2016=1h<04<b
8080@S4O0P11<1h01@0n<al0?C8N03/`7P0j;Qh0>BdO0080>BdQ00<0>B`S03X^7P0j;Qh01P0j;Qh0
100g;B40=R`P03H/800f;20203D[7`@0=2XN0P0e:al303H/800303L]8@0f:QX0=RXJ00H0=RXJ0P0d
:Qh203D[7`@0=R`P00<0=bdQ03P/700h;1`00P0i;Ad01@0j;Qh0>blO03``800l<200>c0L0080?C0M
00<0@34N048a7`14<B000P17<R4804<b80P0?S<Q0`0k<1h203`a7`<0?C8P100n<B4303d`800903`_
7`0n<B40?2lO03X]7@0i;1`0>RdM03d`8010<b<0@SDU00P0?S4N2011=2400`10<b00?c8O03d`7@02
03`_700303d`7@0o<Ql0@3<P00P0?c8O00P0?bdO040^8010;al0@C0N048a7@13<a`0A3@M04@d6`80
@c@M00@0ACDN04Hd7P17=Al0BC@O0P1;=B0304<g7`80@SHN0`11=Ad303`a7@80?C8N0`0n<al02016
=Ql0ACDN04@d7@13<a`0A3@M04De7P17=b00BCTR0P1>>R8304di8@<0C3PP0`19=al204Xh80<0BcTQ
2@1>>R800`1=>b<0C3XR04Xh800304Tg7`80BSPP00<0C3XR04/i8@1:>2000P19=al00`1:>200BcTQ
04`j8P0204di80<0CSXQ00<0CCTP04/g7P1:=Qd0201>>R8204/i8`80BSPR0`19=b401018=R00BSXS
04Ti8P17=b0304Hf7`80AcLP2019=b4804@h8080A3TU0P13>2@01012=b<0@CHR040e8@10=B4304Db
8B_ooooo000Zooooo`P0WG500`2KKch209Y^?@<0Vfln00<0W70o09ea@02OLd800P2PM4<00`2OLd80
WW9109ea@00209]_?P0409a`?`2MLD00Wg=20:1d@`80XGE40P2KKch409a`?`80WG500`2PM4<00`2O
Ld80WW9109ib@@0209ea@00409]a?`2MLd40WgE30:9hAP<0XgU700@0XWQ609md?`2OM3l0Wg@o0`2N
Lch209eb?@P0XWI500@0WWA209me@`2PMT@0XGM50P2RN4H02@2TNTP0YG]90:EkB@2OMSh0WWDm09ie
?`2NMD40WGA009ec@@0209ab@P0609ebA@2LLD@0W75409]`@`2JKd80VFi10P2HKD001P2GJT00UFXo
09EZ?`2CJSh0T6Xm08iY?080RfTk00@0RF@j08QS>@28HcT0Qf8h0P26HCL208EP=P0508EO>P24GST0
PE/f07iH<`1lES400`1kEC0207UF<0<0N5D_0`1gE2h2079@:`03071@:P1^D2X0K50Y0080JU4Y00<0
JE8Y06Y=:`1ZCB/01P1ZCB/206Q;;@0>06Q;:`1YC2X0JTd[06]?:P1/D2T0KE4Z06a?;@1]DB`0Ke4]
07=C;@1fE2h0NEH^07YG;@1mF2h207eK;@0@07mJ;@21Fbh0Q5/_08IK<027G340RE`b08IQ=@28HCH0
RF<f08aS=@2>I3@0TFDd09AV=@2DIS@0T6Xk08mY>P<0SVPi00<0T6Xk099/?@2CKCh0202AJch208]U
=P0308aV=`2=IcP0SVPi0080SfTj00<0T6Xk091Z?@2@JSd01P2@JSd9099W>P07091U>02=HSD0Rf0c
08]P<`2=HSD0Sf@g095V>@0209AZ>080TfTg0`2BJ3H4095W=@80TVPf102CJCL00`2CJCT0U6Xj09AZ
>P0409AZ>P0409=Y>@2?JSH0T6/g099]>@80U6lk00<0Tfhj099]>@2AK3P00P2EJcT309I/>P<0Ufdk
00P0VW4m09U`?02HKc/0Ufhj09I]>@2EK3P0U6/g09=Z=P80UF/i0P2DJSP209E[>@80UV`j0P2AIcD0
0`2@IS@0TFLe095W=@02099X=P0409=Y=`2CJ3/0TFHi091U>080Sf@g00@0T6Dh095V>@2CJ3/0SfTj
0P2>J3T00`2=IcP0S6Hg08aV=`0208aV=`D0SVPi0`2=IcP308iX>@<0SfTj0P2@JS/209=^>PH0TVdi
0`2AJc`2099/?@<0Tfdn202AKCd3095[>P06091Z>@2@JcL0SfXf08mZ=P2?JSD0SFPk0P2<IcX208]V
>@<0RVDh00h0S6Hg08]U=P28I3@0Q68b081P;`1mGbd0Ned[07QL:P20Fbh0OU`_07eK;P1kFRl0N5P_
07AG;`80LED^00H0LE@/06mB:P1ZCRL0ID/V06599@1OB2H205i79`0A05a89`1C@RH0DT4W04lo9@1;
?B<0ASXR048g8@10=B40?CDP03Tb7`0h<Ah0=c0N03H_7`0d;1l0<b/P038Z7`0a:1l00P0Z:R0202TY
7`80:2PN0P0W9ad202@U7`0602<T7P0R8ad08B8L020Q6`0O81X07QlI200P8A/8024R7003028U7P0Q
91d08B@M008082<L2`0O8Q/801`O60807QlI00@07b0J020Q6`0Q8Q`08R<M0P0S91h0200W91d0:2DN
02TV7@0Z:1`0;2XM02d[700^;1d0;RdK0P0];B<0500/;280:RXP02PX7P0V9Q`09BDK02@T6P0R91L0
8bDH02DU6@0Y9a/0;BTN034Z800c;280=2/R030a8@0c<B80=3<Q03Hc800i=200>cDO0P0m=Ah803Xb
7`@0?3@Q00@0>c<P03Xb7`0i<Ah0>C4N200e<1d0200c<240<RlP030]7P0_;1d0;R/L02l/7@0`;Ah0
<BhO0`0`<B4402l`8080;RlO0P0Y:ah00`0X:Qd09bTL02HX6`0202DW6P0502@V6@0S9Q/08bHK02<V
6`0R9AX00P0Q91T2020S60<0828G00<08B<H028T6@0R91T00P0S9AX01P0T9a`092HK024S600P81P0
7alG024N5`808AhI02007B8N02@U7`0/:Qh0<b`J03``5P18>1L0ET<K065<8@1eFBX0OEh`08IW>02?
L440U7I409Ee@P2BLSl0T74k07Y[A01_HCX0Ge4^05959@17?1h0?cDJ03L_600b:Q<0<bhK03<]7@0a
;Qd0<BlP02l`8P0];b80;2hS02/^8`80;BlQ0`0^<28302la8`80=C4V00H0=S8V03Hc900g=2<0=c@Q
03Pe8P0h=R4203@e9@0603He8`0h=B80?3LS040j9012?2@0ACdV0P1;A2P0;`1=A2L0D4DW05E8:01J
BbX0GDh]061@;P1PEbh0H5L`05mF;`1JD2`0ED/X05A9:@1HCBl0G54c05Q?;P1FCB`0EDXZ05E8:01E
ARL0ETDW05M6:01IARP0F4DU05U69P1KB2P0GTXY069;:`1RBbT0HTXX06599@1TB240IdTS06]>9P1a
DBP0MeH[07eJ<023GS80QF0d08eN=02>GcD0SV8e091T=@2BJCD0Tf`e09E^=@2FKcH0TVlg00<0Tg0h
00@0TFhf08m/=02=JS80RfP`0`26I3@01@27ICD0R6Hf08QV=P28ISH0RFLg0080QF<c00L0QfHc08YY
=P2<JcH0SVdg08i^=@2>KS<0SFdb0080RFXc00T0R6Tb08MX<P26Ic40QFH`08AT<@23Hc00OV0^081R
<023Hc800P25IC@00`25Hc<0Pf4a089P<00208MV<@H0QVD`0P27IS400`26IC00QF@_08AS;P0208=R
;@03089Q;01oI2d0Of@]0080P6D^1021IRl02024HcP0PV4f07iO<`1iG300Me`_07AL;P1eGBl0MEl`
0`1eFRl207AI;P<0LeP]00@0MEhe07=L<`1`FC00KUL^0P1/EB`00`1]ERd0KUL^06a@:@0306a@:@0Z
06eA:P1^DR/0Ke</06mC;01YDB/0K5@^06iF<01/E2h0J50Z06I>:01XD2X0Je<]06QD;`1VDRd0Hdl/
05m;:P1KARL0F4<V05I1901D?b@0BSlO04Xo8@19?R00Ac`P04Hk7`15>Al0A3PN04<g7@17=Q`0BCPN
04/j7P1??R00DT8Q05A48P1FAR@0EdLS05M79@1JAbH0G4XV05i:9@1RC2D0IDhU0P1WCRD506]@9@03
06aA9P1]DRL0KE8W0080Ke8V00@0L5<W075D:01bEBT0LeHZ0P1dEb/00`1]DRD0Ke@W075F:@0207=H
:`03075F:@1_E2L0KE8U0080KU4Y00@0Ke8X06mB9P1_Db@0L5@T0P1`E28307EF:P0407=F:P1aERT0
KeLY06eG:080K5LX00P0LE@Z06mD:@1_E2T0K5@X06UB9P1WDRD0IE<U06AB9080J4lV00h0ITlU06E@
9@1RCb@0H4lS05m>8P1MCb80GT`T05m=9@1PCRH0HDlW061>9P1OCBD0GD/S05a:8P80GddW0P1NC2H2
05e;9@80G4XT0`1IBb@205Q:8`<0EdTR0P1C@al0101DA200EDDQ05E58@1FAR8205M78`0@05Y;901H
BRD0EdTT05A7901@AR<0CD@S04U38`18@R80CT0U04do901:?b<0B3lR04Dn8@12?Al0@C`N040m7P80
?S/L00H0?CTL03`h7@0l>1l0>cHP03Xe7`0j=B4203@f7P0403<e7@0b=1`0<S@L034c6`80<38J0`0/
;ah202/^7@<0:RdL0P0V:Q/302DY6P<092PI0P0Q91/3020S6P<07b8I00H07b8K01hQ6P0N8AX07B0I
01`O600K7QL201XM5P806adJ0P0J71T201TK608061XG0P0D6QP301<I5`<04QPF0`0G61X201HG6@d0
5AHH0`0D5AL201<D5P804Q<E600D5AL8014G5`P051DG200?5AD8014G5`P04Q<E:00D5AL@01DF60<0
51DG0P0E5QP301HG6@P05AHH200F61L901LG5`P061XI200J6QX801XJ60P06a/I400L71X201`M5`<0
7AhH0`0N7aT6028R6P808B4I200T7aT2028Q7@03028Q700S8a/08b<I008092@H00<092DG02HQ6`0V
8A/01P0V8A/802@Q6PP09b<J0`0^91X202lU6`<0<2HL200d9ah203LY7P<0>2XO0`0i:b000`0h;200
=b/O03L[7`0203HZ7P80=BTM00<0=2PL03@Z7P0d:Qh00`0c:Ad3038X700302dV7P0/9Ad0;2DM00<0
;2DM0`0[91`302PS7@<09b8L2P0V8A/202@P5`0702DQ600W8aX0:2@K02TU700Z9Qd0:bLN02HR6@02
02LS6P0302PT6`0Y9A`0:RHM0080:bLN0P0Y8aL0100Z91P0:bDI02`V6P0/9QX202dW6`80;2DM0`0]
9Qh302hW7`<0=2PL0`0e:Ad203HZ7P80=BTM0P0d:1`0100e:Ad0=b/O03T]8@0k;b<203h]7@<0?bhN
0`10;al2048b6`<0@c<L0`14=1d00`15<ad0AS@N04Hd7P0204Hd7P<0AcDO2014<b4604<b8080@S4O
00H0@3@N03lc7@0n<Ah0?C0O03`_7`0k;B0203/]8PP0>RhN100g;Ql203H]7P@0=B`M0P0f;Ah403L^
7`P0=b/K0P0e;1d203H]7PD0=bhO0P0i;Q`203X_7@0:03/`7P0l<Al0?34O03`a7`0l<Ad0?C0M03ha
7P10<Ah0@S4O04@a8080AS4P2013<R0303lb7`@0@3<P00<0@C@Q03`_700l;a`00P0m<1d303ha7P07
03lb7`11=2<0@3<R040c8P0o<R40?S4P03d`7`0203`_7P0803d`800l;al0>bhN03X]7@0l;al0?S4Q
040c8`12=BD803lb7`T0@3<P00L0?c8O03ha7P0m<1d0?C0M03ha7P0o<Ql0@3<P00P0?c8O00P0?bdO
040^8010;al0@C0N048a7@13<a`0A3@M04@d6`80@c@M00@0ACDN04Hd7P17=Al0BC@O0P1;=B0304Df
7`<0A3DN0P13=1d203`a7@80?C8N0P0n<al203ld800804Hf7`15=Ah0A3@M04<c7014=1d0ACDN04Lg
8019>B8204hj8PH0CCTQ0P1:=Qh204/g7`<0C3PP00<0CCTQ04lk8`1?>b<02@1?>b<204hj8P@0CCTQ
00<0BcTQ04Xh801:>200101:>2000`1;>B40CSXQ04hj8@0204hj8@80CCTP0P1<>1l804hj8P<0BcTS
0P1:>28304Tg8@0304Ti8P18>240B3PQ00<0AcLP0P18>24804Tg8@P0ACHO0P15>2D204@g9080@cHS
0P12=B8304Pf8R_ooooo000Zooooo`P0WG5000<0Vfln09a`?`2LL3l0102LL3l209]_?P0309a`?`2N
LT40X7A30080X7A300/0Wg=209ib@@2JKSd0Vfln09a`?`2MLD00WW9109mc@P2PM4<0XGE409Y^?@02
09]_?P80W70o0P2MLD00102NLT40X7A30:1d@`2PM4<409mc@P0509ib@@2KLCl0WG=109me@`2RN4H0
0`2SNDL0102RN4H0XgQ30:=h@`2SN4<30:9g@P80XGI1202QMD@0102NM480WgE30:1fA02QMdD20:9h
AP090:AjB02UNdT0YG]909mf?P2NMCd0WWDo09ie@@2MM400WG=10080W79200H0WG9509aaA02LLD@0
Vg1309Y_@P2IKT4209Q]@00609IY?`2DJCh0U6Tn099Y?@2?JC`0SFPk0P2:J3X208QS>@0<08MR>026
HCL0QF0f08AO=@23GS@0PUdc08EO>P23GCP0P5Xe07iH<`1lES40NeD`0P1lES4307ME;`<0MU@^0P1e
Dbd2075?;00306m>:`1]Cb/0K50[0080JDlZ00<0J50Z06Y=:`1ZCB/01P1ZCB/01P1WBR`0J4/]06U<
;01ZCB/0Jdh/06]?:P80K50Y00d0K4l]06eA;01_DBd0Le<]07ID;P1iERh0NUL]07eH;P1lFR`0OE/]
081K;P22G2l0QE``0080Qe`a00/0R5/a08IQ=@28HCH0RF<f08aS=@2>I3@0TFDd09AV=@2DIS@0T6Xk
08mY>P0308iX>@03091Z>`2BK3d0Tfdn00P0TF/n0P2;ICH00`2<ISL0SFLh08iX>@0208mY>P03091Z
>`2@JSd0T6Xm00H0T6Xm202BIcX00`2EJSd0TfPk095V>@0208mT=`03095V>@2DJC`0UV/n0080U6Xh
1@2CJCL4099X=P<0TfTg0`2DJSP00`2EJcT0U6Xh09AZ>00409AZ>00909E[>@2AJCH0Tf/h09E]>P2F
KS/0Ufll09I^>`2EKCX0U6`i00<0UV`j0`2GKC/209Q^?00809Ya?@2IL3`0V6lk09M^>P2FKCT0UF`h
09A[=`2CJSH209AZ>00709E[>@2FK3X0UV`j09I/>P2GKC/0UV`j091V=002095W=@80TVPf00H0TfTg
099X=P2BJ3H0TVLj095V>@2?I3L208iS=P0308mT=`2AIST0TVLj00@0SFLh0P2<ISL208]U=P80S6Hg
202=IcP308iX>@<0SfTj1P2BKCT209=^>P80TF/l0P2BK3d209=]?P80U6ho202AKCd0102AK3L0TF`h
091[=`2@JcL208mY>080SVPg0`2<IcX208]V>@80RVDh00l0RF@g08]U=P2:I3D0R6@d08AR<P21HC00
OV0^07aN;01iGB/0PE`_07iL;`1lFRd0NEP]07IF;@1bEBd00P1`E2d01P1^DR/0K50Y06I<9`1RBRH0
GDHT05Y69@80FD@U00T0F4DU04lo9@1>?RD0BcdS04Hj8P13>280?SHQ03`d8@0j<b000P0f<Ah01P0e
;al0=2hP038/800a:R00<2TO030Y8@<0:BTO0P0X:1h302LW7@0402<T7P0R8ad08R<M024R7080824K
0P0O81X8020Q6`P08B8L0`0Q91d2020S70807b8K00<07R4J01lR6`0O8Q/01P0O8Q/801`O60807b0J
00@0824K024R700R8ad08b@N0P0T9Al202XV7@0<02/W700/:1`0;R/L02l/6`0`;A`0<BhK02d]8`0/
;280:RXP02PX7P0V9Q`09BDK0P0T91X202DV600<02TW6P0/:1`0<B/O03@/8@0e;B80=bdS03Dd8P0f
<b80=c@Q03Td800k=Al0?CDN0P10=Qd803/c800503`e8P0k=240>S<P03Tb7`0h<Ah00`0g<1d403@_
70@0=C0M00P0<c0Q038_800`;Ah0;b`M02h[700_;1d0<2dN034^7`<0<34Q00<0;c0P02h_7`0^;al0
0`0];Qh01P0X:Ql09bTN02LY7P0V:1d09BLL02@V6`808bDJ00<08RDL024T6`0Q91/00P0Q91/3020S
6P<0824I100Q8QX0:@0R8a/07b8K01hQ6P0M7QH071`D01lJ500R6a<091/D02DL5@0R7aP0:b@J03L^
7@14=Q`0D3dL05m87P1_EB@0NEhY08]]=`2>L3`0TgE109EgA@2@M4@0RFdm081T=@1iGRl0GU<c05=:
:`16?240>c@J03La6`0e<1d0<BhM02l/7@0e<R40=S<T03Dc900c=2H0<38U02h`9@0[;RD09bdS00<0
<C<U0`0b=2H203<e9`80=C4V00H0=S8V03Hc900g=2<0=c@Q03Pe8P0h=R4203Tf9@0603/f8`0m=R<0
@3PS048j8`17?B@0BShV0P1=ART04P1@AbP0DdPX05M::01LCR/0H58_06=C;`1PEbh0HEPa061G<01K
DBd0ED/X05=8:01GC2h0Fe0b05M<;01FBb/0ETTY05E69`80ETDW01X0FDHX05]6:@1FABL0F4LY05a9
:@1RBb/0IDdY06I<9`1XC2D0JD/U075B9P1cDRL0MUDX07YH:`1oFRd0Q5h_08QP;`29HC00TF4a095S
<@2@IC80TFPb099[=02AKS@0T70e095a=P80T6de0P2AKSH0102?K3@0SFXb08]X<029IRh308EU=0D0
QVHe0P22HC@03@23Hc@0QVHg08QX=`29JCH0RFXd08UZ<`28JC80QfDe08IT=026IC80QF@a08AS<024
Hbh00P23HRd00`20G2X0Pel]08IR<00208MV<`0308IU<P22HRl0PF4^0080QVD`1P27IS4208QW<P03
08MV<@26IC00QF@_0080Q6<^00@0Pf8]081U;P20IBh0P6D^0`21IRl2089W<00508IU>P24HcP0PF8f
07aO<`1iGS400P1fGS000`1eGc00NUld07YO=00207UN<`80N5db0P1gG3401@1fGcD0M5dc079K<@1`
FBl0KeP^00<0KUL]0P1^DRX206mC:`@0L5@/00P0JU<Z06eF;@1_F2l0KEH]06UB:@1WD2L0JE8Y06aE
;080JE<Z01h0J58[06MA;01UCR`0Hd`/069;:`1QBR/0CT4N04e07@1<?ad0BC`L04Li7P14=Q`0@c@M
048c7018=Qh0BCLO04Xi7`1<>al0CchP0551801C@b80EDDS05A48`1GA2@0F4DT05]7901OBB@0HTXT
06E<901VCBD206U>8`0306Y?901[D2D0Je0U00<0Je0U0P1^DBD0101_DRH0L5<W075D:01bEBT207=F
:P0306eB9@1_E2L0LEHY0080LeP[00<0LEHY06mD9`1]DRD00P1^DBT0101_DRP0Ke8V06mC901`E2@2
071D8P<0MUL[00@0LeHZ079G:P1_EbT0KUPY0P1/EbP01P1aE2P0L5DX06mD9`1/E2H0JeDV06UD9@80
IU@T0P1YD2L0201WD2H0IE0U069?901QD2@0H4lS05i@8`1OCBD0H4hV0`1QCbL00`1OCBD0GD/S05a:
8P0205m=9`@0GT`V0P1MBbD205Y<9@80FD/T0P1HBR<205M98P80E4@P00@0EDDQ05I68P1FAR80EdLS
0P1HB2@0401LCBH0FT`W05M9901DAb@0CdDR04a38P19@b<0B48R04m19P1>@2D0Bd0T04U08`15?R40
@chP048m7`11?Ql203ll7@0603hj7@0m>Ah0?3PO03/f800j=Al0>SDQ0P0g=al0100f=Qh0=CDM03@d
700c<a/2038b6P<0;2lN0P0[;Qd302X]70<09RXK0`0U:AX202@X6@<08B@K0`0P8aX201lR6@0601lR
6`0N8AX07R4J01dP6@0L7aP06ahG0P0J7AH301/M6P806Q`I0`0I6aP301@J60<04aTG0P0B61H301LH
6P805QLI3@0E5QP301@E5`804a@F0P0B4aDH01@E5`P04ALG200D5AL800lE5@P04ALG200B4aDX01@E
5a005AHH0P0C51H201@E5`805AHH0P0F5aT801DF60P05QPG2@0G5aL801LI60P06QXJ200J6QP801/K
6A0071`J0P0L7AL301dN60<07QlI1P0R8QX202<S6`P091lI0P0R8Ad01P0S8Qd08b<K02@T6P0T91P0
9BDI02DV60P09b8L200U81X802PT6`80;R@J0P0_9A/2030V7080<BLM200d9ah303XY7`<0>bXP0P0l
:b4403L[7`@0=RXN0`0d:Qh303<Y7@80<RPL0P0_9Ql202hU7P80;B@M0`0/8a`202TT7P<0:2<M2`0W
8Q`01P0T81L09B4H02HR6@0W8aX0:2@K02XV7@80:bLN00H09R8I02LS6P0W8aX0:2@K02TU700Z9Qd2
02/W7P0602TS5`0Z91P0:R@H02/U6@0/9QX0;BLK0P0^:1`202`U7@<0;BHN0`0^9al203@X70<0=BTM
100f:Qh01`0e:Ad0=2PL03@X700e:Ad0=b/O03T]8@0j;R800P0n;Ad303l^7P<0@2lO0`12<Q/304<c
7080A3@M0P15<ad204Hd7P0404Le7`18=R00B3HP04Pf80P0AC@R1P13<R0204@c8@80@S<L00H0@S<N
044b7`10<200?blP03h^8@0m;B0803/_7`<0>RhN0`0i;Ad403P/70<0>BdM0`0j;Qh:03P/70<0>BdM
100j;Qh303/`7P@0?34O00T0?C8P03db7P0n<Ah0?S4N044b7`12<Al0@c0O04D`7`16<B002013<R03
044b7@03048c7P13=1l0@c@O0080A3DP0`10<A`2044b7@<0@S<N0P11=2<2040c8P0403lb8@0n<B00
?C0O03d`7`80?C0P0P0l;al0100m<200?S4Q040c8`11=2@803lb7`P0@3<P00<0@C@Q040c800n<Ah0
0P0m<1d00`0n<Ah0@3<P044d8@0803lb7`0803l]7`10;R00@2lO044`7P12<Ad0@c<L04@d7@14=1/2
04<d7@0404De7P16=1h0AcDO04Td7`80BcDP0P17=b0304Hf7`<0ACDN0`0m<Qh203hc7`<0?c@P00P0
ASHO04De7P14=1d0@c<L04@d7@15=Ah0AcLP04Ti8P80CCTQ1P1>>R8304`f7`80CCLP0`1>>24904lk
8`@0D3XS0P1?>B8204hh8@<0BSPP0P1;>B4304Xh8080Cc/R0P1>>R4404di80P0CSXR0P1<>R@204/i
8`80BSPR0P19=b400`17=b00B3PQ04Ph8@0304Ti8P80B3PQ2019=b4804Hf7`80AcPU1016=b@204Df
8`<0CC/U:oooool002[ooooo0`2KKch209a`?`<0WG5000<0Vfln09a`?`2MLD000P2NLT402@2MLD00
W70o09]_?P2IKC`0Vfln09ea@02OLd80X7A309mc@P0209ib@@80Vfln00@0W70o09ea@02MLD00WW91
0P2OLd8209]_?P0409a`?`2MLD00WG5009ib@@80Wg=2202PM4<01@2MLd40WWA20:1fA02RN4H0XgU7
0080XWQ600<0XGM50:AiA02TND@01P2TND@80:5eA080X7I40P2QMdD20:9hAP030:=iA`2TNTP0Y7Y8
0080X7Lo00@0WgI009mf@P2NMD40WWA20P2MLd<01P2MLTD0W75409aaA02KL4<0VVm209U^@@80V6e0
00H0UFPn09=X?@2CJ3d0TFPl08iX>`2<IcX208UW>@80QF8h00X0Q64g08=P=P21GS@0P5dc07mL<P1n
Fc40Pedh085K=P1oFC@0OELb0P1lES400`1mEc80OUPc07IF;`0207IF;`80MED^0`1dE2d2071=;@03
06m>;@1/CR`0Jdh/0080J4h[00<0Idl[06U<:P1YC2X01P1YC2X00`1VBB/0IdX/06U<;00206]>;00M
06a@:`1[CbP0JdlX06a?;@1]DB`0Ke4]07=C;@1fE2h0NEH^07YG;@1mF2h0O5X/07eK;@21G2l0Ped`
08IM<@28GC80Qe`a08QK<@26HCD0R64f08US=P2<HcD0SV@d095U=02DISD0U6Hd091Z>`2?JCX00`2>
J3T00`2@JS/0TV`m09=]?P08095[?P80S6Hg0`2=IcP308iX>@P0T6Xm202BIcX209AY?0<0TfPk00<0
U6Tl09EZ?@2FJch00`2DJSP909=Y=`80U6Xh0`2EJcT00`2FKCT0UF`h09A[=`0209=Z=P0;09A[=`2E
K3P0UVdi09=Y=`2DJSP0UV`j09M]>`2HKS`0Ufdk09I/>P2EJcT00`2FK3X209M]>`<0V6hl00D0VG0l
09Q_>`2HKc/0Ufhj09I]>@0209E/>00409A[=`2DJSP0UF/i09I/>P<0Ufdk00H0UV`j09E[>@2AIcD0
TVPf09=Y=`2DJSP209=Y=`80TFLe00<0TFHi091U>02>HcH00P2=HSD01@2>HcH0T6Dh095V>@2<ISL0
SFLh0080SVPi00@0SFLh08aV=`2;ICH0RV@e0`2;ICH308aV=`D0SFLh0P2>J3T308mY>P80TF`h0`2B
KCT309=^>P<0TV`m0P2CKCh309A^?`P0TFdm0P2@Jc@0102@JcH0SfXf08mY>02>J3T208iX>`0808YU
>02;IST0S6Lj08aW>P2;IST0RVDh08UT=`28HcH208US=00<08MS<`23HC40PF4`07mQ;`1nH2h0Nel]
089M<01nG2l0NeT/07QG;01dE2/0LE@/0P1_Db`01P1[DB`0J4hY06A<:01NAbD0FDDT05I38`80ED8R
0140Dd8T04`n901;?2D0Ac/S04<h8P0n=R40>c@Q03Tb800g<Ql0<c0O038_7P0b;b00<BdQ030/8@0_
:b80;RXQ02hY8`0202TY7`80:2PN0`0W9ad00`0V9Q`08R<M024R7002024R7080824K2P0O81X8028S
7@0801lR6`0P8a`08B@M024T7@0P8a`07b8K01hQ6P0M81T801hQ6PP07B0I0P0P8A/00`0Q8Q`08R<M
02<T7P0202@U7`0?02DV800]9Q`0;BHL02hX700`:Q`0<B/K03<^6`0d;a`0=2lK02`/8P0Z:R00:2PN
02HV700U9A/092@J00809BDK0P0Z:1T01P0]:Q/0<2XL03<[7P0f;200=bdQ03X^8P80=c@Q00H0>C@P
03/e7`0l=1d0?cDL040d7010=1X803/c800403Xe8@0i=200>3<O03Ha7@80=C0L0P0f<Ad303<^6`80
=2lL0`0e<1d02@0c<240<RlP030]7P0_;1d0;R/L02l/7@0`;Ah0<BhO030a8@0202l`800302h_7`0]
;Qh0;2dM00<0:b`L0P0U:1l0100T9ah08bHM028U700R9A`2024T6`P082<L200P8A/0800K81X06AhH
01/L5P0N6a@08Q/C02LM500]81P0<28I03HV5`10;ad0CS`T05a89`1YDRT0M5d[085V;`29Kc@0UGa4
09ElAP2ANTH0RWA3081[?P1bGcD0IE<]05i<9P14?RH0?CLQ03@_6`0_;1/0<2hQ030`9P0a<BT0;RlY
0P0b<240100a<R@0<C<V038d:@0a=2/202ld;@<0<S@V0P0c=BL303@f:080=C4V01L0=S8V03Hc900g
=2<0=c@Q03Pe8P0h=R40?CPU03hg9@0n=b@0?cLR04<h8P17>b<0C3dV04i09P1>B2P0CdTY05589`1D
BRL0FD`Y05e?:P1QDbh0I5D^05iE;002061G<00M05]A;@1FC2T0DdPX05E:;01HCBl0EdXZ05I9:@1E
ARL0ED@V05I59`1IARP0FdHY05a7:P1FAbX0FDPZ05i;:`1UCR`0JDlZ06e@:01_CbH0L4lT07]I:`1l
FRX0Oe/[08=M;027Gb`0Rf8^08aS;@2>Hbh00P2EIRh01P2CJBl0TV/`08m]<02>KS40SG4b08]b<P80
S6`c0`2=KC@0102;Jc80RFT`08MW;P25IcD308AV=080PfDc0P22I38207eM=00707mP=021HSH0Pf@f
08AU=P24IS@0PfDa089T<00208MR=P0:08IQ=026HS80QF4_08EQ;@24H2`0Q64[08IL:P27Gb`0Qf8^
08YU<@80QfHa00@0Q6D_089T;P26IC00QVD`0`27IS4308QW<P80RFPc00<0R6Lb08MV<@26IC000P25
I2l00`24Hbh0P6D^081U;P06081U;P0808ET>@24HcP0PF8f07eP=01jGc80Mela07IN<01eGc0207aQ
=P<0Nf0e0`1jGc@01P1eGS80M5da07=L<01aFRh0L5T]06mH;080KUL[0P1aER/09`1bEb`0LeP]07=H
;@1cF2d0LUL/075F:`1]ER`0KeP^075J<01_F2h0JU<Y06QA9`1ZDbT0KEH/06YC9`1[E2X0K5D[06aE
;01/E2h0Je<_06YB<01YDBl0ETTO05A67`1BA1l0CSlN04/l7`17=ah0ACDN04<b7P1;>B<0BSPR04Xh
801;>R00C3/O04ln801A@B00DT8Q05918`0205A18@0805M38P1KA280GdLS06=9901UBbH0Id`Q06Q=
8P1YCR<306]@9@80JTlT00H0KE0T06iA9@1^DBD0Ke8V071C9`1aE2P2079E:@80Ke@W101aERT206mD
9`80Ke8Z00@0L5<Y071C9`1`E2D0LEDU0P1aEB<307IG:`0407AG:`1bEbX0L5PZ06iH:@80KEPY00H0
LE@X071E:01`EBP0KEDW06aF9`1ZEBH206QF9P80JU4X00<0J54W06IA9P1SD2D00P1QD2@02@1ND2<0
GddU061>9P1QCbL0HU0X065?9`1PCRH0GT`T05e;8`0305m=9`D0GT`V0`1JC2D205U;90<0F4XS0`1H
AR8305U78`80FTPT00H0Fd`U05U;9P1FB2<0DTDR04i48@1<@b8204U38`0805129`1?@BH0C44U04Y1
9016?b80A3lQ04<n8011?Ql203ll7@0603hj7@0m>Ah0?3PO03`g8@0k=R00>cHR0P0i=b001P0h=Ql0
=cDN03Dc700d<Q/0<c4J038`6@<0;2lN0P0[;Qd302X]70809b/L0P0V:Q/302DY6P0302@X6@0R9A`0
8RDL00808B@K0`0P8aX01`0O8QT07b8K01hQ6P0N8AX07B0I01`O600K7QL00P0J7AH0100L7Q/06adJ
01/M6P0K7AX201XL6@806A/H0P0E6aT201@J60<04aTG00@04QPF01LH6P0G61X05aPJ0P0F5aT=01DF
60<051DG0P0C51H2018C5AP051DG200A5aL801@E5`P03aDE200A5aL8018C5BP051DG400E5QP301<D
5P8051DG2`0E5QP801HH5`T05aLG200G6AP801XJ6PP06QXH200K6aT@01`L6P8071dG0`0M7QP301hO
6@@08R8J0P0S8a/202@T70P091lI0P0S8Qh00`0S8Qd092@L02@T6P0202DU6@0302DV600X8ad0:2<M
00H0:2<M200X8A/802PT6`<0;bDK0P0`9Q`3034W7@P0=2LN0`0k:Al203`Z80<0?B/Q200g:al203D[
7`80=2XN0`0c:Ad01@0b:1`0<BHP034V800`9Al0;b@N0080;R<M0P0]8Q`0100/8A/0:B@N02TT7P0Y
91h202PS7@/09b8L0P0V8QT0100W8aX0:2@K02TU700Y9A`202XV7@0602HR6@0W8aX09b<J02PT6`0Y
9A`0:RHM0P0[9ah202`V6P<0;BLK0`0^:1`202`U7@<0;BHN0`0^9al0100d:1`0=BTM03DY7@0e:Ad2
03HZ7P<0=b/O00L0=RXN03DY7@0d:1`0=BTM03HZ7P0h;200>BdQ0080?RdM0`0o;Qh3040_7`80@C4J
0P12<Q/304<c700504@d7@15<ad0AC<M04Hd7P17=Al00P18=R0204Tg8@P0ASDS1013<R0204@c8@80
AC@R00P0A3@K04@d7@14=1d0A3<O04<b8012<B40@2hP03l]7`P0?C4Q0`0l;ah203/^7@H0>RdL0P0k
;Qd303`_7PP0>BdM0`0j;A`203/^7@@0?2lN00<0?34M03db7P0m<Qh01@0m<Qh01P0n<al0?c8O03lb
7`11<Ql0@S4O04<`7`80AC0O2013<R001P11<AX0@S8K048b6`13<a`0A3@M04De7P80ASHO0P13<a`2
04@d7@<0ACDN00@0ASHO044d8@11=240@C@Q0`10<b0203lb7`80?c8R1@0n<B400`0o<R80?c8O03lb
7`0>03lb7`03044d8@10<b00?c8O0080?S4N00<0?c8O040c8011=240200o<Ql0200o;Al0@2hP040_
7`11<1h0@S4M04<c7014=1d0A3@K0P13=1d01015=Ah0AS@N04Le7`19=1l204/e80<0B3HP0P17=Al3
04Hd7P80?C8N0P0n<al303ld8009040e8@16=Ql0ACDN04@d7@13<a`0A3@M04De7P17=b00BCTR0080
CCTQ0`1>>R8304lk8`80CcHP0P1@=b43054h8P03058i8`1>>R80CSXR00L0CSXR0P1A>283058i8`06
054h8P1?=R00CSDO04Tg7`1:>200BcTQ0P1<>R801P1;>B40BSPP04Tg7`1A?B@0D3`S04hj8@<0CCTP
0P1>>R4804hj8P<0C3XT0P1;>B<304Xh8P0304Hf7`17=b00BCTR00<0BSXS0P19>B8@04Tg8@<0B3LU
1@17=R@304lm9B_ooooo000Zooooo`<0Vfln0P2LL3l309ea@00309]_?P2LL3l0WG500080WW9100T0
WG5009a`?`2KKch0VFdl09]_?P2MLD00Wg=20:1d@`2OLd800P2NLT4209]_?P0409a`?`2MLD00WG50
09ib@@80Wg=20P2KKch0102LL3l0WG5009ea@02NLT4209mc@PP0X7A300D0WG=109id@P2PMT@0XWQ6
0:=iA`020:9hAP030:5gA@2TND@0Y7U400H0Y7U4202QMD@20:1fA080XGM50P2RN4H00`2SNDL0Y7Y8
0:AjB0020:1g?`0409mf@02OMT80WWE109id@P80WG=300H0WG9509aaA02LLD@0Vg1309Y_@P2IKT42
09Q]@00609EX?P2CJ3d0TfPm095X?02>J3/0S6Lj0P29IcT208ER>00:08AQ=`23H3H0PEhd081M<`1o
G380OU/a08=M>021FcH0OeTd07eG<P80O5Ha00<0OELb07iH<`1fERl00P1fERl207EE;P<0M5@]0P1`
CBd00`1_CRd0K4h/06]>;00206Q>:`0306M?:`1YC2X0JD`Z00H0JD`Z00<0ITT[06M:;01YC2`00P1[
CR`07@1/D2/0JdlX06]?:01/Cbd0KE4/06mA;@1cDbd0MU@^07UF;P1jEbd0OEP^07aJ;01mFbd0PE`_
08=M<026GC40R5db08ML<@28Fc40QV4e08QQ=P29HcH0S6<e08iT=02AIC@0U6He09AV=02@JS/0SfTj
00<0SVPi00<0T6Xk099/?@2CKCh0202AJch208aV=`<0SFLh0`2>J3T8091Z?@P0TVLj0P2DJC`309=X
>`0309AY?02EJSd0UV/n00<0U6Xh2@2CJCL209AZ>0<0UF/i00<0UVdi09E/>02DJcL00P2CJSH02`2D
JcL0UF`h09I]>@2CJCL0U6Xh09I/>P2GKC/0V6hl09M]>`2FK3X0UF/i00<0UV`j0P2GKC/309Q^?005
09U`?02HKc/0V6lk09M^>P2FKCT00P2EK3P0102DJcL0U6Xh09E[>@2FK3X309M]>`0609I/>P2EJcT0
TFLe099X=P2CJCL0U6Xh0P2CJCL2095W=@03095V>@2@ICP0SV<f0080SF8e00D0SV<f091U>02AIST0
S6Hg08eW>00208iX>@0408eW>02<ISL0RfDf08YT=@<0RfDf0`2<ISL508eW>080SVPi0`2?JCX2095/
>0<0TVdi0`2CKSX3099/?@80Tfdn0`2DKSl8095]?@80T6/d00@0T6/f08mZ=P2?JCP0SVPi0P2>J3/0
202:ICP0RfHi08aW>P2<IcX0RfHi08YU>029I3L0R6<f0P29Hc@03027Hc<0Pf4a085Q<01oHBl0OV0^
07]O;@22GC00OU`_07]I;01hEb`0M5@[075D;080Ke</00H0Je4/06Q>:@1TC2P0GTLU05U5901F@b<2
05E28P0A05=2901<?R@0Bc`U04Lk8`13>280?SHQ03/d8@0i<R00=c8O03<`7`0b;ah0<RlP034]8@0`
;240;b/R02hZ8@0^:B<00P0Y:Al202PX7P<09bLM00<09RHL028S7@0Q8Q`00P0Q8Q`2020Q6`X07b0J
200R8ad0200O8Q/082<L024T7@0Q91d082<L01lR6`0N8AX07B0I200N8AX801dP6@80824K00<08B8L
028S7@0S91h00P0T9Al03`0U9R00;BHL02dV700^:1`0<2XL034[6`0c;Q/0=2lL03@_6`0/;280:RXP
02PX7P0V9Q`09BDK02@T6P0202DU6`80:RPI00H0;BXK030Z700c:ah0=R`P03L]8@0j;R8203Ld8@06
03Td800k=Al0?3@M03le7010=1`0@3@J200k<b00100j=B40>C@P03Pc7`0f<Ad203D`7080=S4M0`0c
;Q/203@_70<0=C0M00T0<c0Q038_800`;Ah0;b`M02h[700_;1d0<2dN034^7`0`<B400P0_<2000`0^
;al0;BhN02`]7@0302//70809BPO00@092LN02<V7@0R9A`08RDL0P0Q91/8020S70P0824K02006b0J
01TN600K71H07Q/D028K4`0W7A@0;B0H030R6@0f9QL0@2lM04hl901LB2L0JE8Y07AM:`21IRl0RFld
09ElA02EO4H0TGY608Yd@`20Jch0LUle06EC;@1NC2H0A3hV03dg8@0d;a/0;b`K030^8@0`<2H0<C4Y
02h_:@80<S0Q00@0<C8T034c9P0b=2T0<C@[0P0_=2d3038d9P80<cDW0`0d=RP203Da9P0G03Hb9P0f
<b@0=c@S03Ld8@0h=B80>3HQ03dh9@0n=bD0?SLT03lg8P13>280Ac/S04`m9P1>@2H0CTPX04m9:@1A
B2L0E4XW05U<:@1MCbX0HE<^06AE;P1NEB`00P1PEc007@1KDBd0ET`Y05=8:01EBR`0F4d_05M::P1F
BBT0EDHW05E49P1FABL0FDHX05]6:@1LAbX0ETLZ05U8:P1NBb/0IDh/06U?:P1]D2P0KdlV071?901k
FB/0O5XZ07mK:`23GB`0Qel/08]R;P2<Hbd0SV<^0080UFH^00H0TfT_099[<02?KC00SVha08ea<P2;
LS8208a/<`<0SFdd00@0Rf/b08UY<027Ibh0QFLe0`24IS@208=U<`80PV@b0P1mGC@01`1oH3@0PF8f
08=T=P24ICH0Q6Hd08=U<@22I3000P27HSH02P26HC@0QV8b08EQ;`25HBd0Q60/08AQ:`26G2X0Qel/
08MR;P2:IC4208MV<@0408AU;`22I2h0QVD`08IU<0<0QfHa0`28Ic8208UX<`0308QW<P27IS40QVD`
0080QF@_00<0Q6<^081U;P20IBh01P20IBh02025I3T0Q6<h085R=P1mH3@0NUlb07MO<@1fGS00MEl`
0P1lHCH307]P=@<0NUld00H0MEhb07AM<@1cG300LEX^071I;@1_F2`206iG:`80LEH[02L0LUL/07=H
;@1cF2d0LeP]079G;01aER/0KEH/06mH;P1aFS00KeP^06YC:@1XDBL0JU<Y06eF;01ZDbL0Je@Z06aE
:`1/EB`0K5@^06]C;`1ZDS00JE4_05I97`1DAQl0DT@O04ho7P1;?1l0AcLN04De7P13<Qh0BcTS04Xh
8P1:>200BcXP04`k7`1??R00DD4P05928@1B@B<00P1D@B40201G@b80Fd@R05m78`1SBB@0ID/V06M<
8@1XCB80JDhS0`1[D2D206Y?900606e@901^DBD0KU4U06mB9P1`DbL0LE@X0P1bEBT206mD9`@0LEHY
0P1_E2L206mB:P04071C:@1`DbL0L5@U075E9@80LEDS0`1fEb/0101dEb/0LULZ071H:P1^F2T206eH
:@06075D:01`EBP0L5DX06eE9`1/ERL0JUDV0P1XERH206YA:00306QA9`1VDBH0He0U0080HE0T00T0
GU0S05m=9@1PCRH0HDlW069@:01QCbL0H4hV05i<901MBb<00`1OCBL505i<9P<0FT`U0P1IBb@305Q:
8`<0F4HR0`1IAb<205Y8900605]<9@1IBbH0ETPS05958P1>A240C4<R0P19@b<0201@@RL0Cd4V04a1
9@1:@B@0ASlR04@o8@13?R00@ChO0P0o?1d01P0n>Qd0?CTN03`h7`0l=b40>cHP03/f8P80>CLP00H0
>3HO03Le7P0e<a`0=38K03<a6P0b<1T302`_7P80:bhM0`0Z;A`202L[70809RXK0`0U:AX00`0T:1T0
8RDL028U7002024T6`<082<J00L07b8I01lR6`0N8AX07R4J01dP6@0L7aP06ahG00806QdF00@071hK
01/M6P0K7AX06adJ0P0J71T201TK60805A/I0P0D6QP301<I5`04018H5P0G61X05aPJ01LH6P805QLI
3@0E5QP301@E5`804a@F0P0B4aDH01@E5`P04ALG200D5AL800lE5@P04ALG200B4aDX01@E5a005AHH
0`0C51H201@E5`/05AHH200F61L901LG5`P05aTH200J6QX801XJ60P06a/I400L71X201`M5`<07AhH
0`0N7aT4028R6P808b<K0P0T91`802@O6@808b8N00<08b8M02@T700T91X00P0U9AT00`0U9QP0:2<M
02PS7@0602PS7@P0:24K200X91/302lU6`80<2HL0`0a9ad803@W7P<0>bTO0P0l:R0303d[8@P0=b/O
0P0e:al203@Z7P<0<bTM00D0<RPL034V800a9R00<2DO02lT7P0202hS7@80;B8L00@0;24K02TT7P0Y
91h0:B@N0P0X8ad;02LR70809R8I00@09b<J02PT6`0Y9A`0:BDL0P0Z9Qd01P0V8QT09b<J02LS6P0X
91/0:BDL02XV7@80:bLN0P0/9QX302dW6`<0;RPL0P0/9Ad302dV7P<0;RLO00@0=2PL03DY7@0e:Ad0
=BTM0P0f:Qh303L[7`0703HZ7P0e:Ad0=2PL03DY7@0f:Qh0>2`P03T]8@0203h]7@<0?bhN0`10;al2
044a6P80@S8K0`13<a`01@14=1d0AC<M04Dc7@16=1h0AcDO0080B3HP0P19=b4804He8`@0@c8P0P14
<b4204Dd8P0804@d6`14=1d0A3@M04@c7`13<R00@S4Q040^800o;Al803da8@<0?2lN0P0k;Qd603X]
7080>bhM0`0l;ah803T]7@<0>RdL0P0k;Qd403`_7P0303`a7@0m<Qh0?C8N00D0?C8N00H0?S<O03lb
7`0o<Ql0@C8O048a7`13<1l204D`7`P0@c8P00H0@C4J048b6`12<Q/0@c<L04@d7@15=Ah204Hf7`80
@c<L0P14=1d304De7P0404Hf7`11=240@C@Q044d8@<0@3<P0P0o<Ql203lb8PD0?S4Q00<0?c8R03lb
7`0o<Ql03P0o<Ql00`11=240@3<P03lb7`0203ha7P0303lb7`10<b00@C@Q00P0?c8O00P0?bdO040^
8010;al0@C0N048a7@13<a`0A3@M04@d6`80@c@M00@0ACDN04Hd7P17=Al0BC@O0P1;=B0304Pf8080
AcDO0`16=1h203db7P80?S<O0`0o=2002@10=B40ASHO04De7P14=1d0@c<L04@d7@15=Ah0AcLP04Ti
8P0204di8@<0CSXR0`1?>b<204lf8080D3LQ0`1A>2800`1B>B<0CSXR04hj8P0704hj8P80DCPR0`1B
>B<01P1A>280CcHP04he7`19=al0BSPP04/i8@80C3XR00H0BcTQ04Xh8019=al0DCdT050l8`1>>R43
04di8080CSXQ201>>R8304`j9080BcTS0`1:>2800`16=Ql0AcLP04Ti8P0304Xj8`80BCTR4019=b43
04Pg9@D0AcHT0`1??BD[ooooo`00:_ooool209U]?080VVhm0P2KKch209a`?`0309]_?P2MLD00WW91
0080Wg=200L0WW9109ea@02KKch0Uf/j09U]?02KKch0WG500080WW910P2MLD0209a`?`H0WG500P2L
L3l0102MLD00WW9109mc@P2PM4<20:5eA0P0X7A300<0WWA20:1fA02QMdD00P2RN4H00`2QMdD0X7I4
09me@`020:1e@080XGI100@0XWM20:=h@`2TND@0Y7U4202PM4<00`2QMdD0XWQ60:9hAP060:9hAP80
XGQ000@0XGQ20:1g@`2PMd<0WgE30P2OMDD01P2MLTD0W75409aaA02KL4<0VVm209U^@@80V6e000h0
U6Lm09=X?@2BIc`0T6Lk08eW>P2;IST0RFLi08QV>024HcP0Pf8g089Q=P21H3D0Oehc07iM<P80O5/`
00<0P5Xe07mI=01nF3<00P1mEc80101nF3<0OeTd081J=@1fERl307EE;P80M5@]0P1cDb`206m<;P03
06i=;P1[C2d0JTd]0080Idd/00<0ITh/06U<:P1YC2X01P1YC2X08P1UB2X0IdX/06U<;01[CR`0K4l]
06a@:`1[CbP0JThW06a?;@1]DB`0Ke4]07=C;@1fE2h0NEH^07YG;@1mF2h0O5X/07eK;@21G2l0Q5ha
08MN<P28GC80Qe`a08QK<@26HCD0R64f08US=P2<HcD0SV@d095U=02DISD0U6Hd091Z>`2?JCX308iX
>@03091Z>`2BK3d0Tfdn00P0TF/n0`2>J3T308eW>080S6Hg202@JSd8099W>P0308mT=`2@ICP0TFHi
00@0TfPk00<0TVLj09=Y=`2CJCL02P2DJSP209E[>@<0UV`j00<0Ufhh09I]=`2DJcD00P2CJS@01P2D
JcD0UVdg09M^>02CJCL0UF/i09I/>P<0V6hl00<0Ufdk09I/>P2FK3X00`2GKC/209Q^?080VFlm102G
KSX409I]>@0309E[>@2FK3X0Ufdk0080V6hl00D0Ufdk09E[>@2DJSP0TfTg09AZ>00209E[>@0709AZ
>02BJ3H0T6Hd08iT<P2@ICP0Sf@g08eR=@0208aQ=00508eR=@2?I3L0T6Dh08aV=`2=IcP00`2?JCX0
0`2=IcP0RfDf08YT=@0308YT=@0308]U=P2<ISL0S6Hg0080SFLh0P2<ISL208eW>0<0SVPi00D0SfTj
095/>02AK3P0TF`h099]>@0209=^>P80U6lk0P2BK3d209=]?P@0U6ho202AKCd2091/<P0408mZ<`2?
JSH0SVPg08iX>`80SVLl00<0RF@g08YU>02;IST00P2<IcX00`2:ICP0R6<f08MR=@0208MQ<P0308EQ
<@23HC40PV8a0080P68`00L0OV8`089M<01nG2l0NeT/07IE:P1cDbX0Ke8Z0080KU8[00H0JE4]06I>
:P1QBRP0GDHV05M28`1D@B4305508P0904Xk9017>b<0ACTS048g8`0m=B80>C8P03Ha7P0e;al0<2lM
0080<2hO00D0;bdP02h/800]:R40;BXS02`Y8P0302PX7P<09bLM0P0V9Q`2024R70@0824K2P0O81X8
028S7@0301hQ6P0O8Q/082<L00808B@M00<07b8K01dP6@0L7aP0400N8AX2024R7004028S7@0S91h0
92DO02@U7`809BHP00H0;bLL030X7@0a:A`0<RXM03</700e;Q`203H_700>02XZ800X:1h09RHL02DU
6`0T91X09BDK02HV700W9ad0;B`J02h[6P0_;1/0<R`L03@]7@0f;Ah203T]7`80>C@P00H0>S@N03/c
700n=1/0?c<K03lc6@11<aT803`d8@0803Le800f=1l0=38M03<a700b<1/0<c4L03Dc7P0f=1l2038]
6P80<bhK00`0=2lL03D`7@0e<1d0=C0M03<`8@0b;b00<2dN02l/7@0^:a`0;b`M030]7P0a;Ql202h_
7`0402d^7P0/;Ad0:b`L02X[6`<0:BXJ0P0R9b001P0Q9Ql082DN01lT7@0O91d07R<L01dR6`H07b4L
0P0P8Qd8020Q700Y01/Q7`0K81`07AhI028O6P0Y81T0<RDM03XY8@0o;B<0DcLO05e29`1/DC<0N5lg
085V>@27KCX0SG@k095i?@2;NT@0QgI207i^?@1`HcL0HUH`0599:016?b80@3TM03Pe8P0c<1l0;bdN
02d]8@0_<2P0<38]02h`;@0Y;B`0<BlR02l`8P0_;b<0;S0U02ha:00]<R/0;SD]02lf;`0_<B<00`0`
<R@2034c9@80<S@V0P0e<BH03P0f<RH0=S<T03Ld8`0g=240>3DR03Pf8@11>BH0@3PU048g8`14>280
B3TR04`l9@1>?RD0DClW0P1?BBL0<@1ABBD0E4XW05U<:@1ND2/0HE</06AE;P1KDRT0GUD^061G<01M
Dbl0ET`Y05979`1BAbT0DdPZ05A79`1EARL0E4DV05E49P1HABL0FdHY05m7:`1PB2`0F4P^05Y;;P1Q
CRh0J50^06iB:`1cDbX0ME<V07MB9@1oFbT0PE`X08=N:P28H2`0SF@^095V;`2EJ2l0UVT`09e];`2J
K300Ufh`09E_<@2@LC40SW8c08Yb<P28Lc80Rf`c08a]=02=KSD00P2>KcH00`2=KSD0Rf`c08Y[<P02
08EW=@0408AV=022I380PF<a07mQ;`80OV0^0P1jFS<01`1kFc@0OEdd07mP=020HC<0P64b07mQ;`1n
H2h00P27H3T01027H3L0QV0c08IP<@26HBd208IQ;00608]M;02:GRd0Rf4_08UT<029IC40R6Lb0P26
J38208IU<080QfHa0P28Ic8208UX<`0608YY=029J3<0RFPc08QW<P27IS40QVD`0P25I2l2085V;`04
081U;P1oI2d0Of@]07iS;080OF8[0P22HCH01P20HCD0OF0d07]P<`1gGc40MUh`07EO<0<0NUld0P1i
GS<307QM<P80M5h_00@0Led^075K;01`FR/0KeTZ0P1]EbP00`1cF2/0M5T/07IK;P0207ML;`0R07EJ
;@1dFB`0LeP[071I;`1bFc40Le`b071I;`1[E2X0J54W06UB:01/EB/0KUHX06mG:@1`F2`0LEP_071G
;`1^E2l0K58]06]A;P1ODRD0GU4U05Y<9@1FB2D0DT<V04hn9@1:>BD0BCPV04hl:01=>bD0C3XT04/i
8@1;>R00CC`P04hm7`80D3lQ00X0DSlQ058o7`1D?b00FD8R05e58`1RB2D0I4XW06I;801WC240JDhS
0P1[D2D00`1ZCb@0JDhS06Q=8P0206e@9080KU4U00@0Ke8V071C9`1aE2P0LE@X0P1aERT406mD9`80
LEHY0P1aE2`0101aE2X0LUDY079F9`1bERH207=G9@<0MUL[00@0M5L[07=H:`1`F2X0KeTZ0P1]F2T0
1P1aEBH0L5DV071E9P1^ERH0K5HU06]G9@80JELU0P1[DRT00`1YDRP0Ie8W06AA9P02069A9@0405mA
901OCBD0H4hV065?9`80HU0X00<0H4hV05i<901MBb<00P1NC2H605m=9`@0FT`U0P1IBb@205Q:8`04
05a89@1KAb@0FdLT05]790@0FTHS00P0FT/T05M9901DAR40D4<P04e3801;@R40BD<S04Y49080D48W
00h0CD8V04]29@17@2<0AD0R04@o8@12?b00@3dN03ll7@0o>ah0?SXO03di800l=b40>cHP03/f8P80
>SPQ00H0>CLP03Le7P0e<a`0=38K03<a6P0b<1T302`_7P80:bhM0`0Z;A`302L[70809RXK0`0U:AX3
028U70808B@K0`0P8aX01P0O8Q/07R4J01hQ6P0M81T071lH01/N5`806QdF0P0L7Q/301/M6P<06Q`I
0`0E6aT201@J60<04aTG0`0G61X201HG6@d05AHH0`0D5AL201<D5P804Q<E600D5AL8014G5`P051DG
200?5AD8014G5`P04Q<E:00D5AL@01DF60@04a@F0P0D5AL:01DF60P05QPG2@0G5aL801HH5`P06QXJ
200J6QPH01`L6P8071dG0`0M7QP301hO6@03024Q6@0R8QX08R8J00808b<K0P0T91`00`0U9Ad09B0J
02DP6P0602DP6P808b8N00<092<N02@T700U9A/00P0U9AT00`0U9QP0:2<M02PS7@0602PS7@P0:B0K
200Y9A`202lU6`80<2HL100a9ad803DX7`0403/Y7`0l:R00?2XP03`Z8080?B/Q0P0n;28503L[7`<0
>2`P0`0e:al203@Z7P<0<bTM00@0<RLQ034V800a9R00<2DO0P0^8ad202dR700302`Q6`0Z9Al0:RDO
0080:B@N0`0X8ad902LR70@0:2@K100Y9A`01P0V8QT09b<J02LS6P0X91/0:BDL02XV7@80:bLN0`0`
:Qh202lY7@<0;RPL0P0/9Ad302dV7P<0;RLO0`0e:Ad203HZ7P@0=b/O00L0=RXN03DY7@0d:1`0=BTM
03HZ7P0h;200>BdQ0080?RdM0`0o;Qh3040_7`<0@C4J0P12<Q/304<c7080AC<M00@0AS@N04Le7`18
=R00BCLQ0P1:>28804He8`03048a7`13<R00@c8P0080A3<Q0P15=2800`16=B<0A3@K04De700204Hf
7`0404Dd8013<R00@C0P03l^7PP0?c<S0`0o<1d203h_70H0?BhK0P0n;a`303l`7@P0>RhN0`0m;Q/2
03h_70@0?c0M0`0n<ad503db700603hc7`0o<Ql0?c8O044b7`12<Al0@c0O0P14;ah804<b8005044a
6P12<Q/0@S8K04<c7015=Ah00P16=Ql01017=b00ASHO04Hf7`16=Ql204Lg80<0B3PQ0`10=1h3044e
7`80@SHP0P11=2@01010<b<0?c8R03ha8@0m<20203`_7`P0@3<P200o<Ql00`12=B80@C@Q03lb7`02
03ha7P0303lb7`11=240@SDR00P0?c8O00P0?bdO040^8010;al0@C0N048a7@13<a`0A3@M04@d6`80
@c@M00@0ACDN04Hd7P17=Al0BC@O0P1;=B0204/f8@80BSDP0`19=1l01018<ah0?S<O03hc7`0n<al3
03ld8080@3DQ00P0ASHO04De7P14=1d0@c<L04@d7@15=Ah0AcLP04Ti8P80CCTQ0P1>>R8204lk8`80
D3`T0P1A>282058i8`@0DcXT2@1=>B402`1?=R00D3LQ054h8P1B>B<0DCPR050g8@1>=Al0C3<M04Pf
7P19=al0BcTQ0080C3XR00/0BcTQ04Tg7`18=Qh0DShU050l8`1>>R40CCTP04`h7`1=>B00CSXQ04lk
8P0804hj8P@0C3XT0P1;>B<204Xh8P0304De7P17=b00BCTR00<0Bc/T00<0BSXS04Ti8P19=b401`19
=b4804dh8`80AcHT1P18=bD304hm8b_ooooo000Zooooo`<0V6`k00<0VFdl09Y^?@2KKch00`2KKch0
2`2MLD00Wg=20:1d@`2PM4<0Wg=209ea@02KKch0UVXi09M[>P2JKSd0W70o00<0WG5000<0W70o09ib
@@2MLD000P2MLD0309a`?`0909]_?P2LL3l0WG5009ib@@2OLd80X7A30:5eA02RMTD0XgM600D0X7A3
0`2QMD@03P2PMT@0XGM50:9hAP2SNDL0XWQ60:5gA@2OMD<0WWA209]`>`2LLC`0WG8m09ic?P2PMD00
XGI10P2RMd880:1d@`80XgU7102RN4H30:5gA@80XWU100@0XWU30:5hA02QN4@0X7I40P2PMTH01P2M
LTD0W75409aaA02KL4<0VVm209U^@@80V6e000H0U6Lm099W?02BIc`0T6Lk08eW>P2;IST208QV>00@
08AS>023HSL0PV4f081O=01nGC80OE`a07aK<01kFRl0OeTd07iH<`1mEc80O5Ha07eG<P1oFC@0PE/f
089L=`@0LeH^0P1bEBd2075D;080Kd`^00<0KTd^06]<;@1ZCBd00P1WCB`00`1VCR`0JD`Z06U<:P06
06U<:P0306E8:P1WBR`0JD`/0080K4l]01d0K50[06]?:01ZCRL0K4l]06eA;01_DBd0Le<]07ID;P1i
ERh0NUL]07eH;P1lFR`0OE/]089M<025Gc80R5lc08UN<`27G340QeX`08IQ=@28HCH0RF<f08aS=@2>
I3@0TFDd09AV=@2DIS@0T6Xk08mY>P0308iX>@03091Z>`2BK3d0Tfdn00P0TF/n00H0T6Xk08mY>P2?
JCX0SVPi08eW>02<ISL208]U=PP0T6Xm202BIcX0202:Gc80S64d08mT=`2AIST0TVLj095V>@2?I3L0
SV<f0P2CJCL509AZ>080UF/i0`2DJSP209E[>@<0UV`j00<0Ufhh09I]=`2DJcD00P2CJS@02`2DJcD0
UVdg09M^>02DJ3L0UVXi09Q/>`2IKC`0VVhm09U]?02HK3/0Uf/j00@0Ufdk0P2HKS`209U_?@0409E/
>02FKCT0UVdi09I]>@<0Ufhj00/0V6lk09I/>P2GKC/0V6hl09U_?@2HKS`0Ufdk09AZ>02CJCL0U6Xh
09E[>@0209I/>P0709AZ>02BJ3H0SfDc08eS<@2@ICP0Sf@g08eR=@0208aQ=00608eR=@2?I3L0T6Dh
08eW>02>J3T0SfTj0P2@JS/00`2>J3T0S6Hg08YT=@0208US=080RV@e00@0RfDf08aV=`2<ISL0SFLh
0P2<ISL208eW>0@0SVPi00@0T6/g095/>02AK3P0TVdi0P2CKSX209A_>`80TV`m0P2CKCh309A^?`03
09E_@02AKCd0TFdm00H0TFdm00/0T6``091/<P2?JS<0SfXe08iX=`2>J3/0SVLl08eV?@29I3L0RVDh
08]V>@0208aW>P0308YU>028HcH0QV4d0080QEl`00<0Q60`08=Q<@22HS400P21Hc401`1oHc40Peha
07iL;`1jF2/0MUDZ079B:@1_DRX00P1^DR/01P1XD2`0IDdY06199`1JARD0ED8R05508P80D3lQ00T0
Cd0S04Lk8`16>R@0@cPR03lg8P0k=240=c8O03D_7`0b;ah00P0`;Ql00`0_;B00;R`P02h[8P0202dZ
8`0402`Y900X:1h0:2PN02PX7P809bLM0`0V9Q`5020Q6`/07b0J200R8ad00`0N8AX07b8K020S7002
024T7@0301lR6`0M81T06ahG00P07R4J200O8Q/2024R7003028S7@0S91h092DO00809BHP00`09RLQ
030X7@0`:1d0<BTL038[6`0d;A/0=BhK03H_700g<A/0:2PN02LW7@0U9A/202@T6P0302DU6`0W9ad0
:2PN0080<2dL00h0<bdM03@]7@0f;Ah0>2`N03T]7`0j;1l0>C@P03Xc800j=1h0>c<L03dc6P0n<QP0
@C<I044c60P0?3@Q00<0=S@O03Dc7P0c<A`00P0b<1/00`0c<A`0=C<N03Le8003038]6P0303<^6`0d
;a`0=C0M0080=C0M00P0<c0Q038_800`;Ah0;b`M02h[700_;1d0<2dN034^7`80;BhN00<0;2dM02//
700Z:a/00P0X:AT202LX6006028W800Q9Ql08BHO020U7P0O91d07R<L0P0M8Q/301hP6`@07b4L00<0
828M020Q700P8A`00`0P8A`301lP6`0X01dS8@0N8R408B8M02HS7P0_9Ql0>R`S04@b:019=BX0JdHY
07IB<P23HC`0SFe408meA02?N480TGe209=o@P1mL3/0MFTg06UN<01GD2H0AT8O03Xf6@0^;QH0:RTD
03Hd9@0c<B@0;blS02l`:00`<Rd0;S8a02T];P0T:B`0=3DW038b9P0^<2<0:RdR02H/8P0W;2D09bhW
02P_:080;2hP0P0];b4302h`8P0902la8`0e<BH0=C4V03Hb9P0f<b@0=c@S03Ld8@0h=B80>3HQ0080
@cPV00H0A3LT04Di8`19>R<0C3`S050n9P1B@BL204m99`0<05599@1DBRH0FDdW05e?:01QDb`0I5D/
05Q?9P1LDb`0GeH_05eC;`1GCBX0DTLW0P1@ABL205=49@0Q05A39@1F@bD0FD@W05]6:@1PB2`0HTX^
05Q:;`1LCC00HTl_06YB;P1aDbd0MUDZ07UD9`1jE2D0OeXV081K9P26GRX0Rf8/095V;`2GJS40Vfdb
09e_=02QLC40Wg8a09]b<P2HLS<0TW<c08ie<`2:MC@0R7Dc08a]=02=KSD0Sg0g0080TG8i00/0T74h
08m`=`2>KcH0Q6Pf08=W=@21IC<0Of<a07eQ;`1kGbd0NUh/07UM:`0207IH<P0707MJ<P1iG3@0Nehd
07aO<`1kGc00NUh^07UM;@0208MO>`0>08MP=`27H3D0QV0a08IQ;@26HB`0QV4Z08mO;P2>H2h0S64^
08]S;`29IS00QfPa08Q[<`29K3@208IU<080QfHa00<0R6Lb08UX<`29J3<00`2:JC@00`29J3<0R6Lb
08MV<@0208IU<00708ET;`22Ic00PFH_081U;P1oI2d0OF8[07aQ:P0207]P:@80P5ld00H0Of0d07aO
<`1kH3<0N60b07MO<@1eGc0307ML<@80MU/`0`1eFRl207=M;P09079L;@1aFb`0L5X[06iH:@1]EbP0
K5HW07EJ;@1fFbh0N5d`0080NEha02@0Me`_07EJ;@1dFB`0LEX^07AM<@1eGS80LEX^06]D:01XDBD0
JE8V06]D:01aFBT0LUXZ07=K;@1cFbl0LEP_06iE;@1[DB`0JDlZ06QJ:`1VF2/0He@[05i>;01IB2X0
E48Z054o:`1??2/0DCl[04lm:@1=>bD0BcTQ04/j801<>al0CC`P04hm7`1??R82050m7`0805<n7`1G
@200G4@R0657901SBBH0IDXO06M<8@1YCR<206]@9@0406Y?901YCR<0J4dR06a?8`80KE0T00<0KU4U
06mB9P1`DbL00P1aE2P00`1cF2/0LEHY06mD9`0206eB9@0306mD9`1aERT0LeP[0080LUD]00@0LUD[
07=F:P1cEbP0LeLW0P1dF2H01`1gF2`0MUL[07IG:`1dEb/0LeP[071H:P1_FBX00P1]F2T01P1aEBD0
L5HU071F9@1^EbD0KELU06aH9@80JEPT0P1[DRT0201YDRP0Ie8W06AA9P1SDRH0HU4U061B9@1PCRH0
HDlW0`1RD2P00`1PCRH0GT`T05e;8`0205i<9P@0GddW0P1PCRP0101KCBH0FT`U05Y<9@1JC2D205U;
9080F4XS0P1MBBH0101LB2D0FdLT05Y68`1JAR<205U58P0605Q98P1EAb80DT@O04m27`1<@Ql0Bd8Q
0P1:A2@0201A@bP0D48W04e29P1;@RD0Ad0S04E08P14?b40@d0Q0P10?Ah03P0o>ah0?SXO03di800l
=b40>cHP03/f8P0m>280?3LQ03/f800i=1h0>3<M03Ha6`0e<1X0=2lI0`0/;ah202/^7@<0:RdL0`0W
:a`302HZ6`809BTJ0`0R9A`3024T6`8082<J00H07b8K01hQ6P0N8AX07B0I01`O600K7QL201XM5P<0
71hK0P0K7AX301XL6@<05A/I0`0D6QP201<I5`<05aPJ0P0F5aT=01DF60<051DG0P0C51H2018C5AP0
51DG200A5aL801@E5`P03aDE200A5aL8018C5BP051DG400E5QP0100B4aD04a@F01<D5P0C51H201@E
5`X05AHH200F61L901LG5`P05QPG200J6QX801XJ61P071`J0P0L7AL301dN60<07QlI00@08B4I028R
6P0R8QX08b<K0P0T91`202DU7@P09B0J0P0S8Qh00`0T8ah092@L02DU6`0202DU6@0302HW6@0Y91h0
:B@N00H0:B@N200Y81/802TU7080;bDK0P0`9Q`3034W7@03038X7P0e:1l0=BPO00H0=BPO100m:B02
03hZ8@80?b/R100g:al403P/80<0=B/O0`0d:Qh203<Y7@80=2LQ00@0<bHP038U7`0a91h0<B@N0P0_
8Q`00`0^8A/0:RDO02XU7`0202TT7P@0:2<M200W8Q`202XV7@<0:BDL0`0X91/01P0V8QT09b<J02LS
6P0X91/0:BDL02XV7@80:bLN00H0<bdQ038/800b;200<B/O030Z7P0_:Ad202hX7080;2DM0`0]9Qh3
02hW7`80=BTM0`0f:Qh303L[7`0803P/800g:al0=BTM03@X700e:Ad0=RXN03L[7`0i;B4203h]7@<0
?bhN0`10;al3044a6P<0@S8K0P13<a`204Dc7@0604Hd7P17=Al0B3HP04Tg8@1:>280BcTS2017=R@0
1012<Al0@c8P04<b8014<b4204Dd8P80ASDS00P0AC@J04Hd7017=Ad0B3HP04Le8@15<R40@RlP040]
7PP0@CDU0`0o<1d203h_70H0?BhK0P0n;a`303l`7@P0>RhN0`0m;Q/203h_70@0?c0M1@0n<ad303db
700603hc7`0o<Ql0?c8O044b7`12<Al0@RlN0P14;ah804<b8006048`6013<AT0@c4I04Dc6`16=1`0
AcDM1018=Qh204Tg7`<0BSPP00D0BcTQ03lc7@0o<ad0@3@N044e7`02048f8080@cLQ0P12=BD01P11
=2@0@3<S03ha8@0m<200>bhN03X]7@P0@3<P200o<Ql00`12=B80@C@Q03lb7`0203ha7P0303lb7`11
=240@SDR00P0?c8O00P0?bdO040^8010;al0@C0N048a7@13<a`0A3@M04@d6`80@c@M00@0ACDN04Hd
7P17=Al0BC@O0P1;=B0204/f8@80BSDP1019=1l303hc7`80?c@P0`10=B402016=Ql0ACDN04@d7@13
<a`0A3@M04De7P17=b00BCTR0P1=>B4204hj8P0404lk8`1@?2@0D3`T054m9@80DcPS0P1D>B@205Dj
9@80ES/V2@1<>2000`1?=1l0D3DP054f8@02058g8P06050e801><ah0C34L04Pf7P19=al0BcTQ0P1<
>R802`1;>B40BCLO04Pf7P1B?RD0DCdT04hj8@1=>B00C3PO04di801?>b80D3`S00P0CSXR00@0CC/U
04`j901<>R@0C3XT0P1;>B<204Xh8P0804De7P17=b00BCTR04/k901<?2D0Bc/T04Xj8`19>B8804Tg
8@P0CSTT0P18=B@404Tf9@80BSLV0`1;>R0[ooooo`00:_ooool0302QMD@0Wg=209a`?`2IKC`0V6`k
09U]?02JKSd0W70o09Q/?`2JKT40W71309ibA@80Wg=600D0WG5409a`@`2LLT00VW0n09U_?@0209Q^
?00309U_?@2JL3h0W79000P0XG=200<0XGI30:1e@P2NLd000`2LLCh02P2MLSl0WW=009U`>P2LLcd0
X7M30:=iA`2TNTX0XWM:09mdA`2MLTL80:5eA00409ic?P2OM3l0Wg@o0:1e@080XGI10P2RMd800`2P
Md<0WgI209ed@00209ed@00309mf@P2RNDD0XgY600T0XWQ60P2PMD/0102OM4X0WW=909icB@2MLTP2
09aaA`80VWA500@0V79309Ma@P2EKd00U6ho0P2BK3d209=]@00<09A^@@2CKD00TV`o091Z?@2=IcX0
RfDh08ES=@25HcH0Q68e089O=@21GSH0Oe`f0P1nFSH02024GST0P5dg07iK=@1jF380N5Pa07II<@1e
FC40MUXb0`1dDc0207=B;`<0LU4^00<0LE0_071?;P1^CB`00P1/BbX01P1]C2/0KTd/06m>;@1VAbP0
IdPY06U::`80Jd`]00H0JDX[06M8:@1VAbP0K4XW06e;:01_CBX2071>:`0C06i<:@1/BRL0JdTV06e?
:@1_CbT0L50Y079A:01dDBL0Me8V07QA9P1iDbH0OEP[07iI;01oFRd0P5/^089M<023GS40Q5lb08EP
<`0208US<P0408YT<`2;IC@0SFLf08iX=`80SfTh0P2AIS/2099W?00409=X?@2DJCh0U6Tn09EZ?`80
Ufa200<0UV]009I[?P2EJc/00P2DJSP02@2CJSH0UV/n09EZ?@2DJC`0TVLj095V>@2?I3L0SV<f08eR
=@0808eW>004091U>02AIST0TFHi095V>@80TVLj0P2CJ3/809=Y=`T0U6Xh0P2DJcL309E/>0<0UVdi
00<0UV]009EZ?`2CJ3d00P2BIc`00`2CJ3d0UFXo09I[@00209EZ?@80UV/n0P2GK3l209Q]@0<0TVdi
0P2CKSX309A_>`<0VW0n0P2IKcd309Q^?006095]?@2BK3d0TV`m09=Z?02DJC`0U6Pk0P2FIc/809=Y
=`@0TFHi102BIcX01026H3<0R68e08YT=`2<IST308eW>P0308aV>@2:ISH0RVHf00H0RVHf0P2;I3T0
0`2<ICX0SFHk08iW?00208mX?@0D091Y?P2=J3`0SfXn099]@02DL400U70n09=_>`2AKCT0Sf`f09E`
?02DKc/0TF`h08mZ=P2>JCD0SfXf091[=`2AK3P0Tfdn099/?@2@JS/308iX>@0:08mY>P2@JS/0TVhj
095]>@2@K3P0SVXf08eY=@2;Ic<0RVHb08UU<@80S6Ph00@0RfLg08UU=@28I3@0QV8b0P25HC401P23
Gbl0PEl_081N;P1oGbh0OV0^07aP;P80Nf4^00h0O5h/07]L;@1fFRX0LULX06eE9`1YDRH0IE0U06A?
901YBR/0IdPY0656:01KA2D0E44S04hm7`80BC/N00T0B3XM04Lh8`16=b80@SDR03ld8P0j<Ql0=c0N
03H_7`0d;Qh00P0/;Al0100[;1h0:R/M02TZ700X:A/202LX6P0802LY6`0W:A`09RPK02DW700T9Ad0
8b@N02<T7`0R8ah2020S70<07b8K0`0N8AX0100L7aP07B0I01dP6@0M81T201hQ6P807b8K200P8aX3
024T7@8082<L0`0O8Q/801`N6`0601lO8@0O7al0820P020P7P0P8A`0824K0P0P8AT202<S5`0402@T
600U9AT09bLK02PX7080:BTM0140;2DB02`U4`0_:1H0=RlO03`d9`0k<bP0=2/R02dT6`0P8Qd08B<N
02<T7P0V9Qh0:RLN02dY7P0^:Ql0<B/O03<Z6`0203@[700303H]7P0g;Ql0>2lP0080>C0Q200n<b42
04<b7P07044b7@0o<ad0?C8L03db700k<a`0>S8K03<`8@03038_8080<BhO0P0`;Ah00`0^;ad0;c0N
034b8002038c8@03034b800_<1h0;RlM0080:b`L1@0/;Ad00`0];Qh09BHN02@U7@0202@U7@808b@L
0`0R8a/8020S6P<08B@M0P0P8a`301lR6`0T01/U3@0M9`l07RLD01/T4`0G7a805QhC01TP6@0M91d0
9QTS02/L8`0b8200=R8I044X501A<aL0ID@Q07=A:`24ICL0RFXl08ib@P2CNDP0Tga:095jB02;MD<0
QW8m06IE>`1MCC@0C40Z03/d8@0_;Ah0:R`Q02T^9`0Z<BX0=3H[038d:@0`<RL0;S0U0P0/;R<0100]
;b@0;S0U02h_7`0^;al202l`8004030a8@0a<R80<S<S038c8`80;C4P00H0;S8Q02lc8P0`=2<0<3@S
034e900b=RD203/i90H0>SPS00d0@chZ040j900o>B<0A3`U04a2:@1AAB/0DD<X04i09@1HBR<0FD/T
05e?:01PDR/0HU@]00<0HeD^00H0GE0`05a?;`1JBb`0FDPZ05Q7:@1JAbT205a7:P0`05949`1EARL0
F4LY05i9:P1RBBX0IDPX06E79@1WARD0Id@V06Y79`1aCBT0N58[07aG:P1oFRH0PEXS085J8@2=I2H0
SVDW095X:P2CJR`0Ufh`09U`<P2LLcD0WG@f09Yc>02ILSL0UW8h09=`=P2?KcH0SFhg08a]=`2;KCL0
SW/i08ei>P2:MST0Qg8i08A_>P21JcT0OfTj07eW>01jIcl0NV@m07MQ>01fGcD0MEda07ML;`1iG300
NUh_0P1lDc<06P1mEC80OePa085J;`22G2/0PehY08=O9@23Gb40Q5dV08EN9`26GbP0R64Z08YS;02<
IBh0SFH_08iW<02<J2h0SFT_08eZ<02<K340Rfda08Q[;`26JBd0PVP[08AW;`27JS80Rfhf0P2=L3P0
102:KCD0QVTa08=V;P20I38307mS<@08081T<P22IS@0QFTg08IZ>022JC<0P6La07eT;P1kHR`207YQ
:`80Nf8/00@0P6Pj07iV>01kHcD0N60b0P1fGS0207MO<@80N5/_00@0MeX^07II;@1fFBd0MEP/0P1d
Eb/307QK;`D0NE``0P1jGRh00`1iGbh0Mf0^07MQ;`0207IR;`0907AS;`1kH3<0NUlb07UN<@1gG2l0
MU/^07AI;01cF2/0LULZ0080J58]00L0JE<^06YD;@1[EB`0JeH[06aG;01/EbX0JU@]0080JeD^01d0
JU@]06QB:`1UCbP0HT`U05m98P1D@Qh0DChM04`l6P1<?A`0Cd8R05129@1;@2@0B3dQ04dn:`1<?BX0
Bc`W04/l9@1<?BH0CClU04m19P1A@bP0GT<U0656:01VC2T0JDlZ06]B:@1ZDR@0J54O06M@7P0506eA
8@<0K50P201]DRL2075D:004079E:@1cERX0MEP/07II;@80MeX^00L0LEDS079F901bER@0LUHT07AH
9P1eFBL0MUXX0080Me/Y00P0KUDO071G8@1cFBH0ME/Z07EJ:`1bEbX0KU<V06aA9P80Ke<[00@0KU8Z
06a@:01ZCRH0JDdU0P1WBb<205i?:00305e>9`1LCBH0Fd`U0080FT/T00<0FDXS061>9P1PCRH00P1O
CBD01`1NC2@0GD/S05e;8`1LBR80G4dV05Y;901HBB800P1GB2400`1HBB80FT/T05a=9P0205Y>9P03
05U=9@1HC2@0Ed/S0080EDTQ00@0E4PP05188@1@B240CdLP0P1>AQl01P1=AAh0C4@M04a47@1:?al0
BChN04Ll70<0ACXJ0P17?1`304Dl7`80A3/N0`13>Qd0200i>QX0>3TI03Pi6P0g=a/0=SHL03Hf7P0e
=Ad0=C@O0P0d<Qd0100c<A`0<S0K034_6P0`;QT202l]600802/_600[;QT0:bhI02X]6P0Y;1/0:B/M
02T[7P0X:Qd202<T70808R<K00@08B8J020Q6@0O81P07b0H0P0M81T201`O600401/N5`0J7AH06A`E
01TL5@P05adI0`0H6QT301LI60805QPG0`0D6QX201<I6@<04QPH2P0E5QP301@E5`804a@F0P0B4aDH
01@E5`P04ALG400D5AL8014G5`P051DG200A5aL@01@E5`804Q<E0P0C51H201@E5b805AHH200E5aH8
01HH5`<05ALF0`0F61L301LI60P061PH200J6QX801/K6@P071dG200L71X401`M5`@06a`F200P7aX8
028R6P<091lI0P0U81X302HQ6`8091lI100U81X202HQ6`<0:2@H0`0Y9AT202XV6P0802PU700V8aX0
9B8I02@Q600U8QT09R<J02TV7@0Z9ah202HT5`809bDH00l0:2HI02TW6P0Y9aX0:RPK034S800a91h0
<RDO03<V7P0d9ah0=BTM03HZ700g:ad0=2PH03HZ6P0h;1`00P0i;Ad01@0g:a/0=2PH03<W5`0l;al0
?C0P0080?S4Q00`0?C0P03/^7P0i;1`0=bXJ03XX6P0k:A/0?B/M03h/7P0o;Al0?R`N03d[7@0l:Q`2
03X]7@80>B`L0`0h:a/01@0g:QX0>bLN03XX7P0i9ad0=bHL0080=2HK00<0<RHJ030V6P0_9AT00P0]
9B800`0Z9B40:2DP02DT7`02028S7@06020S700X8AT0:24I02TR6P0Z8a/0:b@L0P0]9Qh00`0^9al0
;2HJ02`V6P0602`V6P0@02`U7@0[91`0:R<K02XS6`0[91`0;2DM02hW7`0`:B40;bDL030V7@0b:1h0
<bTM03@[700c:QT0<RTH034Y5P<0<BLK0`0b:1`203<Y7@80=2PH00<0=BTI03HZ6P0g:a/00P0h;1`0
100i;Ad0<bLG03@X600f:QX203L[6`0403HZ6P0d:1P0<bLG03/`7P80?2lN00<0?BdM03h]7@0n:a`0
0P10:Q`4040_7@@0@C0N0P13<a`01P15<ad0B3<N04Xd7`1==200CSDQ04ld8@80AcDM0`16=1`00`18
=Qh0BSPP04`j8P0804Le7`0304<a6`15<ad0B3HP0080BcTS00<0B3HP04Dc7@13<A/0200n<b4303db
7P@0?S<O00@0?c@P03Pc7`0h<al0>3<O1@0g<Qh00`0n;1h0?bdO03l]7`0203l]7`<0@2hP00D0@S4O
044`7P11<1h0?bhL03h]6`0203d/6P80?2/I00<0@C0N04<b8016=B<00P17=R@00`13<R00?bhL03d/
6P0803lb7`80?blO00@0@C0P048_8013<240ABlQ0P16;b401@19=b<0B3HR04Pf8P17=B40AS@P0080
AC<O00@0A38N04Pj8018>R00B3XP0P17>Al304Hh7P80BS@M00@0BCDM04Le7@17=Ad0ACDL0P14=Q`0
3P12<R80@C4Q040`800n;Qh0?blO040`8012<R80A3@T044a6P12<Q/0@c<L04@d7@15=Ah0ASHO0P17
=b0304De7PD0A3@M0P11<AX01012<Q/0@c<L04@d7@14=1d204De7P<0@3HM0P0o=A`303hd6`P0@3@L
00<0A3@M04De7P16=Ql00P17=b002`16=Ql0A3@M04<c701C=b80DCHQ04lf801;=al0ASHM044e6`0o
=AX0?CHJ00<0@3HM0P0o=A`303hd6`80@c<L00@0A3@M04De7P16=Ql0AcLP0P18>2401@19=240BcHS
04hi901@?2@0DShU0080DShS00<0DSlQ04`l8P1<?2801P1<?28204Xi7`80BCPN00/0BSTO04dl8P1?
?R@0CchT050o9@1??R00DChP050m7`1A?1l0Dc/O05@j7`0205@i7P0605Dm9@1D?2@0E3`T058j8P1A
>B40D3PP0P1?=al00`1>>R40CCTP04`h7`0204/g7P0304di801?>b80D3`S0080FCdW00T0ES`U05@l
901@>R80CSXQ04`h7`1:>Al0BCLO04/i8@1<>R800P1>?2@02`1<>R80BcTQ04Tg7`13=A/0ASPN04Tk
8@1<?R@0CClU04/m8`18>R00ACLM0080ASXT00H0BCXU04Xk9P1<>bL0CS`X050k:01A?2T204di8080
CSXQ00`0Cc/R050l8`1@?2<0DCdT05Hj9@1D>2<0DCHQ04lf801<=Ql0C3PP04di8@1<>R8304lm:B_o
oooo000Zooooo`0309mc@P2MLD00W70o00D0VVhm00/0VFe009]_@P2MLD@0WW9509mcAP2NLTD0WG54
09a`@`2MLd40Vg4o09Y`?P0209U_?@0309Y`?P2KLCl0WG=100P0XG=200<0XGI30:1e@P2NLd000`2L
LCh02P2MLSl0WW=009Ya>`2LLcd0X7M30:=iA`2SNDT0XWM:09mdA`2MLTL80:5eA0<0Wg@o00<0X7E0
0:5f@@2QMT400P2RMd80202PMd<0WgI209ie@@2MM400WWE109mf@P2QN4@0XgY62@2RN4H309mdBP03
09icB@2MLTP0WG980080W75700H0VWA509UcA02HLT<0Ug5209E_@02CKCh2099/?@0>099/?`2CKD00
Tfe009=]@02BK3l0SfTl08eW>P2;ICP0QF<e08AR=@23HC@0PUle085N=P1oG3H207iJ=P0608AN>@20
GCL0OEXd07YH<P1hF340MEP`0P1eFC4207AC<0<0Le8_0`1bDBh00`1aD2l0L4l^06i=;00306a;:P05
06e<:`1^CB`0IdPY06Q9:P1YBR/00P1ZBb`01P1YBR/0J4TZ06M8:@1/BRL0KD/X06m=:P80L4h[00/0
KT`Y06e;:01[BBH0KU0Z075A:`1aDBX0Le8Y07EB:01hDbL0NU<X07YD9`0207iI;00407mJ;@21G2l0
PUd`08AO<P80QF0c00D0RF<b08YT<`2:I3<0RfDd08eW=P0208iX=`0308mY>02AIS/0TFHk0080TVLl
00T0TfPm09AY?P2DJCh0U6Tn09M/@P2FJd40UV]009EZ?@2EJc/00P2DJSP00`2CJSH0TVLj099W>P02
099W>P@0TFHi202=IcP4095V>@80TVLj0P2CJ3/809=Y=`T0U6Xh0P2DJcL309E/>0<0UVdi00<0UV/n
09EZ?@2CJ3/00P2BIcX00`2CJ3/0UFXm09I[?P0209EZ?@80UV/n0P2GK3l209Q]@080Tfhj0`2DKc/3
09E`?0<0VW0n0P2IKcd309Q^?006095]?@2BK3d0TV`m09=Z?02DJC`0UFTl0P2FIc/809=Y=`@0TFHi
102BIcX01P28HS<0RF<d08]U=P2<ISL0SFLh08aV=`80RfDf202:ISH208]T>@0408aU>P2=IS/0SVLl
08mX?@80T6Tn0P2?JSh00`2AK3l0TVhn099^?002099^>P04095^>02DKc/0Tfhj095/>080SfXf00H0
T6/g095/>02BKCT0Tfdn099/?@2@JS/308iX>@0@08mY>P2@JS/0TVhj095]>@2@K3P0SVXf08eY=@2;
Ic<0RVHb08UU<@2<J3P0RfLg08YV=P29ICD0R6@d08IR<P80QF4a00H0Pel_081N;P20GRh0Oel^07iP
;P1kGbd207YP;@0>07aM;P1kG2d0Me//07=H:`1]EBT0JE8X06IA9P1TCRD0J4TZ06E8:01PABL0Fd@U
05A18`1=?R4204Tk7P0904Dj7P16=b80@cLQ048e8P0o=280>S8O03L`7P0d;Qh0<bdM0080;2dO00@0
:b`N02X[7@0Y:Q`0:2TK0P0W:1X01P0W:A/09bTL02HX6`0U9a`092DM02<T7P808R<N0P0P8a`301lR
6`<07R4J100M81T201hQ6P807b8K200P8aX2024T7@<082<L0`0O8Q/801`N6`0601lO7`0P8200820N
020Q700P8A/08B8L0P0Q8QX202@T600402DU6@0V9QX09bLK02PX7080:BTM0100;bPE02lX5P0a:QP0
=c0P03/c9P0j<RL0<bXQ02dT6`0Q8ah08B@M02@U7`0V9Qh0:RLN02dY7P0_:al0<B/O0P0e;1d0100f
;Ah0=bhO03P_800i<24203Xa8PP0?S<Q0P12<Ad00`11<Qd0?S8L03db700203Xb6`0403Tc6`0b;b00
<RlP038_8080<BhO0`0`;Ah00`0];Q`0;RlM02l`7P02030a7`0302l`7P0^;ad0;BhL00D0:b`L0`0/
;Ad402@U7@808b@L0`0R8a/8020S6P<08B@M0P0P8a`301lR6`0S01dV5@0O:1L07bLH01hT600J81H0
6ahG01lQ700S9B80<28R03HW9010;R@0BSDR05Dm8@1VBBL0MeX`08AU=`29KC/0SG4o099hA`2BNTX0
SGM8089]@01gHSL0KU/`05I6;@1?@2T0@SLS03L`7P0^;1d0:R`Q02X`9P0[<RX0<S@Y034c:00_<BH0
0`0];b@0100^<2D0;c4V02l`800_<203030a8@<0<C8R00H0;C4P02hb8@0^<R40;c<R030d8`0a=B@2
038f9@@0>SPS100k>B@03@12?BT0@C/U03li8`14?2D0C48Y0514:P1A@bP0CT0U05I88`1HBRD0FddX
05i@:`1PDRd00`1QDbh0>01NDC40G4l_05]<;@1IB2X0F4LY05Y7:@1KART0G4LZ05=49@1EARL0FdPX
05i9:P1SBR/0ITTY06U89`1XAbH0KT/[071>:`1eDR`0NeH/07mJ;@22GBT0QUlX08MP:@2>IRP0SfLY
091X:P2CJbd0UFd_09Q`<P2ILC<0VW8d09Ub=`2FLSH0UG4g099_=`2?KSP0S6dg08Y/=P29JcL0RgHg
08Yd>028LSP0QFlf089[=`1oJ3H0OFDe07aT=P1iHcX0Mf4h07IO=@1eGC40Me`_07QL;@1kG2h0O5d^
0P1oEc@01`20F3@0P5T`089L;`23GRX0QF0Y08MS9`28I2H00P2<IBh05P2=IRl0SVL`08mX<@2@JC80
TFXc099[=02=JBl0SVX`08i[<@2<K340Rfda08Q[;`26JBd0PfT/08IX<P28JS@0RV`f08a^>02;KCL0
R6Xd08AV<022I2h2081R<080Of4_00P0P68`089T<P24IS@0QVPf08AY=023J3<0P6D`07iS;P80OF8]
00H0OV<^07mT;`1oI3L0OF8e07]P<`1iGS4207QM<00307UN<@1jGc80OEhb0080O5da0P1kG30207YK
;`0307UJ;P1jFbl0NU/_00@0NU/_0P1kG30207aN;00407YN;01iGb`0N64]07MR;@80MV8]00H0O64d
07]P<`1jGc80NEha07ML;`1fFbh207AI;080JE</00<0JU@]06YD:`1[EB`00P1[ER/00`1/Eb`0JE</
06YD;@0206YD;@0L06UC;01VD2T0HddV069<9@1OBbP0FDLS05E28@1B@R40DD8S04m19019?R00A3TM
04`m:01;?2L0BS/T04Tj8`1:?280C3hT04i09@1?@BH0G44T05m49P1SBBP0J4hY06YA:01ZDR@0JE4Q
06M@7P@0KE8S0P1/DB8206]@8@P0KU<X0P1`DbL01`1aE2P0LUDY07=F:P1dEb/0MEP/07II;@1bER@0
0P1cEbD0101dF2H0METW07IJ:01gFbT207QL:P0>079I8`1dFbD0MedZ07UO;P1hGBh0MEX]079G:P1`
EBX0L5@/06mC:`1^DRX0K50X06]?9`1YCBD206Q<9006065?9`1PCRH0H4hV05m=9@1NC2@0GD/S0P1L
BR8205m=9@80GT`T0P1MBb<205a:8P0305]<9@1JBb@0FDXS0080F4TR00<0FDXS05Y;901KC2D00P1J
CRH01P1ICBD0F4`T05M;8`1FBR80EDTQ05A88080DTTR00<0DDPQ0517801?AQl00P1=A1d02@1<@a`0
CT<S04e28P1;@200BSlO04Tn7P1:?al0Bd0P04a18@0204Ln8@0404Hm8015?1l0A3/N04<j7@80@STL
0P0i>QX01P0h>AX0>3PL03Lg7@0f=Qh0=CDM03Dd7`80=38M00<0<c4L038`6`0a;aX00P0`;QT01`0_
;AP0;30I02`_6P0[;QT0:RdJ02T/6`0X:Q`00P0W:A`01P0T9Ad08b@L02<T700R8a/08B8J020Q6@80
7b0H00H07R4J01dP6@0M81T071lH01/N5`0J7AH201TL5@P05adI0`0H6QT301LI60805QPG0`0D6QX2
01<I6@<04QPH2P0E5QP301@E5`804a@F0P0B4aDH01@E5`P04ALG400D5AL8014G5`P051DG200A5aL@
01@E5`804Q<E0P0C51H201@E5b805AHH200E5aH801HH5`<05ALF0`0F61L301LI60P061PH200J6QX8
01/K6@P071dG200L71X401dN60@071dG200P7aX3024Q6@808R8J0`0S8a/202@O6@<09B0J0`0V8A/6
02DP6P809R4K0`0X91P302TU6@80:RHJ00<0:2DL02LT6`0U8QT00P0U8QT00`0W91/0:BHM02XW7P03
02LU600302PV6@0Y9aX0:BLJ0080:RPK00P0<R@Q038U7`0c9R00=2LO03@W7P0e:Ad0=BTK03HZ7080
=RXJ0140=b/K03P/700h;1`0=b/K03HZ6P0e:AT0>RdM03/^7P0l;al0?C0P03`_7`0k;Qh0>B`L03P[
6`0j:1X0>bTK03d[7@0203l]7`0303h/7P0m:ad0?2XL0080>RdM0P0i;1`403P[6`0403/W7P0j:1h0
>BLM03LV7080=2HK00T0<bLK030V6P0`9QX0;BDR02`T8@0Y9200:2<O02HS7P0S8Qd00P0Q8Q`01@0X
8AT0:B8J02TR6P0Z8a/0;2DM0080;BHN00<0;RLO02`V6P0/9QX01P0/9QX0400/9Ad0:b@L02XS6`0Z
8a/0:b@L02`U7@0^9al0;bPP02lU700`9Qd0<RPN03<Y7@0d:a`0<bXI038Y600a:AH3034W6`80<RPL
0`0c:Ad203@X600403DY6@0f:QX0=b/K03P/7080>BdM00<0=2PH03DY6@0f:QX00P0g:a/0100f:QX0
=BTI03@X600j;ad203/^7@0303d]7@0n;Ad0?b`M0080@B/M0P0o;Q`2040_7@0?044`7P12<Al0@S4O
04<b8013<a`0A3@M04Dc7@18<ah0BS@O04dd801>=B40Cc@Q04Tg7`18=Qh0AcDM0080AS@L00<0B3HN
04Xh801;>B402017=Al00`13<A/0AC<M04Pf800204/i8`0304Pf8015<ad0@c4K00P0@3<P1P0o<Ql2
040c80@0>C8O100h<Ah303h/7P0303l]7`10;R00@BlQ0080@BlQ00D0@c8P048a7`12<Al0@C0N03l^
700303h]6`0903d/6P10;ad0@S4O04Dd8P17=R@0ASDS04@c8@10;ad0?RdK00P0?S4N00H0@34N044b
7`12<Al0@c0O04@a8016<B0204Pa8@80B3HR0`17=B4304Hd80D0AcTO0`18>R0204/e7P0>04Xf7P17
=Ad0AcDM04De7014=Q`0@cDK04<d8@12<b00@34N03l`7@10<Ah0@C8O04<d8@14=B82048b6`0404<c
7014=1d0ACDN04Hf7`80AcLP1015=Ah404@d7@04048b6`13<a`0@c<L04<c70@0A3@M00@0@SHN044e
7@11=Ad0@CDM0P10=1`203lc6`P0@3@L0140@c<L04@d7@16=Ql0AcLP04Ph8@17=b00ASHO04De7P1A
=R40CcHP04`f7`1:=Qh0ASHM04Dg7@12=Q`0@3HK048f7P03044e7@80@3@L0P0o<a/204<c700404@d
7@15=Ah0ASHO04Lg8080B3PQ00D0B3<P04Xe8P1=>2<0Cc/S054m9002054m8P03054n801<?280C3`R
00H0C3`R00H0CCTP04`h7`1;=ah0BcLN04`h7`1?>b82054m9007058n9@1??R00DChP054n801B?B00
Dc/O05@j7`0205Dj7`0505Dm9@1D?2@0E3`T05<k8`1A>B400P1@>2000`1?=al0CSXQ04di800204`h
7`0?04di801?>b80DCdT058n9@1I?BL0F3`V05Hl9@1D?2@0D3XR04hj8@1=>B00BSTO04Xh801;>B40
C3XR0080CC/S01@0C3XR04/i8@1:>200A3HL04Hh7P1:?280C3hT04do9@1;?B<0B3XP04Hh7P15>B<0
ASXT04Pi901:>BD0C3XV04lj9`1@>bP0DCXX04di8080CSXQ0P1?>b82050l8`09054m901F>RD0E3PS
058g8P1?=R00CCLP04`h801=>B40C3XR00<0D3/X:oooool002[ooooo00h0Vfln09a`?`2LL3l0WG50
09a`?`2KKch0VVhm09U]?02KKd80W71309eaA02NLTD0Wg=609ibA@80WG5400<0WWA209ec@@2LLT00
0P2JL3h00`2LLT00WG=109id@P0809mc@P030:5f@`2PMD80WW=000<0W74n00X0WG8o09ic@02KLS`0
WG@n0:1g@`2RN4H0XgU90:5fB@2OM4L0WG97202QMD@209md@@<0X7E20`2QMT<209mf@P<0WWE100<0
WgI20:5hA02RNDD02@2QMdD0102OM4T0WW=809icB02NLdP309ebA`0709aaAP2ILd@0V79309Ma@P2F
L440UFm009=]?P02099/?@80TV`o01L0Tfe0099/?`2AJch0SfTl08aV>@2:I3L0QF<e08AR=@23HC@0
PUle081M=@1oG3H0OUXf07eI=@23GCP0Oe`f07eJ=01iEc40MeL`07EH<01dF300METa07AC<00307=B
;`80LU4^0P1aD2d0201`Cbh0Kdh]06e<:`1/BbX0JdXY06a;:P1]C2/0KTd/0P1XBBX0101YBR/0JT//
06Y;;01YBR/206Q9:P0306]:9`1/BbP0KD`Y0080KTdZ01<0KD`Y06a;:01/BbP0L58/07=C;@1cDb`0
ME@[07MD:P1jEBT0O5DZ07aF:@1nFB`0OeX]081K;P21G2l0Peha08AO<P25H3<0QV4d0080RV@e00@0
RfDf08aV=`2<ISL0SFLh0P2>J3T3099W?0<0TfPm0P2DJCh209I[@@0309EZ?`2EJSd0U6Xj0080U6Xh
00L0U6/g08mT=`2?I3L0T6Dh095V>@2BIcX0TfPk0080U6Tl202=IcP3095V>@80TVLj0`2CJ3/809=Y
=`T0UF/i0P2DJcL309E/>0<0UVdi00<0UV/n09EZ?@2DJC`00P2CJ3/00`2DJC`0UFXm09I[?P0209EZ
?@80UV/n0P2GK3l209Q]@0<0UG0l0P2FLCd309Mb?P<0VW0n0P2IKcd309Q^?008099^?P2CKCh0TV`m
09A[?@2DJC`0UFTl09MX?02FIc/809=Y=`@0TVLj102AIST208]U=P<0SFLh00<0RfDf08YT=@28HS<0
2029ICD01P2;ICP0S6Hi08aV>@2=IcX0SVPk08mY?080T6Xm00P0TFa0091[?`2?JSd0Sf/k091/>P2A
KCT0TVhj09=`>P80TF`h0`2@JcL01P2AK3P0TVdi09=^>P2CKCh0TF/l091Z>`<0SVPi0P2@JS/04@2A
KCT0T6`h08m[=`2>JSH0SFTe08aX=02;Ic<0RVHb08aX>02;IcL0RVHf08UU=@27Hc<0QV8b08EQ<@24
H300PUd`0080P5h`00<0OUh_07eN;`1jGRh00P1iGbh03P1lGBh0Ne`^07MK;01cF2/0KEDY06UB:01V
D2L0IDlV06E8:P1RAbT0GTDW05M29@1A@2@0C3`R0P16>al01`15>Al0A3PR04<g8@10=B40?3@Q03Pa
7P0e<1d00P0a;Qd202`]7`0402//7P0Z:ad0:BXL02PY6`809bPJ00H09bTK02HX6`0V:1/09BLL02@U
7@0S91h2028S7P8082<L0`0O8Q/301hQ6P<07B0I0P0N8AX301lR6`P082<J00@08B@M020S700P8a`0
82<L0P0O8Q/201hQ6PP071hK00H0820P020P7P0P81h08B8M024R700R8a/2028T6@809RLI00@09bPJ
02PY6`0X:A/0:BXL0P0Z:ad0400b;AT0<RdJ03<^6`0f<200>C<U03La9@0a:R00;2DK024T7@0R9Ah0
92DM02LW7@0[:Ad0;RXN02l/7@0b;1h203L^7@0303P_7P0i<1l0>S4P0080>c8Q00<0?3<R03db800m
<R001P0m<R02040a7P0303ha7P0l<Ad0>S8M0080>38L00<0=c8L038_800a;Ql00P0a;Ql2030]7P80
;b`M00<0:R/K02//700];Qh00P0^;al00`0];Qh0:b`L02X[6`0802X[7@<092DM0P0S91`4028S6`P0
82<J0`0Q91d2020S70<07b8K02007R<M020U7`0S9B008B8M01hO6P0O7QX09R8O02/W900j:QX0@S<N
050o9@1OBR/0KUH`07eR=@2;Kcd0UGM308mi@02ANT@0SgU708UdA`1lJD40JeTe05]8:01??R00@3@N
03db700g;a`0<R`L02h/7`0/;R<0:S0V02`a:P80;c4V0`0];b@00`0_<BH0<38W038d:@02038c8`<0
<C8R0`0`<B401P0_<R40<3<R030c8P0a=2<0<SDT03<f9@80=3LV0P0i=b8203Xh8`0@03/i900l>RD0
?C/V03dk9P12?BT0@C/U040j9014?2D0Bd4X04i2:01@@RL0CT0U05A68@1FB2<0FD/V05a>:@@0GU0[
00H0GU4a05a?;`1KC2d0FDPZ05M6:01IARP205Y5:00`05A59P1GAbH0FdPX065::P1UBbX0JD/Y06]:
9`1/BRL0MeD`07ME;`1iERh0OUT]085M;@26HBd0Rf<_08eV;`2@J2/0TFT/099Z;@2CJbh0UFd`09I^
<@2GKc80V70c09Ib>02ELCL0Tg0h091_>@2=KSL0RV`f08QZ=P25JSD0QVdd08E/=024Jc<0PVTc07mU
<P1mHc80O64b07]P<@1eGS@0MUdd07EM<@1gG2l0N5`]07]L;@1nGRd0Oel^0P25GSD01`24GC@0Ped`
08=M;025H2/0RF@]08eY;@2@K2h0202BKCH04@2>JC80SfXc08i[<`2=KC@0Rf`c08U/<P28Jc40QF/`
08MY<`28JS@0RF/e08Y/=P28JS@0QVPb08=U;`21Hbd0OV0^0080OEl]00T0O5h/07eO;@1oHBl0PF<a
08=U<`26J380QFLa08=U;`22I2h00`21Hbd00`22I2h0O60`07aP<00407YN;P0307]O;`1lH300Of0a
0080Of0a0P1nGc0307eN;`P0NU//0P1nGRd00`1mGbd0Nel]07YP;@0207QQ;@0707MR;@1oHc<0OV8b
07eQ<@1lH300NUh^07UM;@0207QL;0L0K5D[00L0Je@Z06QB:`1YDb`0JE</06YD;@1YDb`0J58[0080
IU0Y00X0JUHa06A@;@1MBbL0F4PV05I69@1B@b@0BS`O04Dg6P1;>b80BSXQ0`19>B002`1;>b80CCdT
04hn9@1G?R00FT4S05m79@1TC2P0Ie0W06QA9@1XDR<0Ie4P0080Ke@W0P1^DbH0101]DRD0K54T06aA
901[D2<8071E:P80Ke8V0P1`DbL01@1aE2P0LUDY07=F:P1cERX0M5PV00<0METW00<0MUXX07MK:@1h
G2X00P1iGB/0201fGBL0MehX07UO;01kHC00NUl`07QM<01eFRd0LeP]0P1`EBX01`1_E2T0KE8W06aA
9P1[D2D0JTlT06U>8`1RD2P00P1QCbL00`1PCRH0GddU05i<900605e;8`80G4XR0P1KBB400`1KC2D0
FT/T05U:8`0305U:8`0305Y;901KC2D0FddV0080FT`U00<0FD/T05Q:8`1GBB800P1FB2402`1DBb@0
DdXS05998P1@Ab00CdHO04e47@1<@a`0Bd8K05=8:01AARH0D4DU00<0CT<S00P0Cd@T05159@1:@B@0
BD0S04Po8P16?B00A3/N04<j7@80@CPK0P0k>Q/00`0j>A/0>CPL03Pf7@0203Le7P0303Hd7`0d<Qd0
=38M0080<c4L00`0<S0K034_6P0`;QT0<2hI02hb6`0^<A`0;2lJ02/^6`0Y;1/09bTK02HX6`0U9aX2
02@U7@0302<T700R8a/08B8J0080824I00H07b0H01hQ6P0N8AX07B0I01`O600K7QL201XM5P0301TL
5@0G7AT05adI00H05adI0`0H6QT301LI60805QPG0`0D6QX201<I6@<04QPH2P0E5QP301@E5`804a@F
0P0B4aDH01@E5`P04ALG400D5AL8014G5`P051DG200A5aL@01@E5`804Q<E0P0C51H201@E5b805AHH
200E5aH801HH5`<05ALF0`0F61L301LI60P061PH200J6QX801/K6@P071dG200L71X801hO6@P081lJ
0P0O7aL0100P81P08B4I02<S6`0T91`202DU7@0402@O6@0U81X09B0J02DP6P809R4K0P0W8Q`502HQ
6`<09B0J0`0X91P302TU6@80:RHJ00P0:BDL02PT6`0W8aX09b<J02PT6`0Y9A`0:RHM02/W7P<0:BDI
0`0Z9QX202/W6`0603@V8`0d9b40=2LQ03@W7`0d9ah0=BTM0P0e:A/00`0h;1`0=b/K03HZ6P0303HZ
6P0503L[6`0h;1`0=bXJ03P[6`0i;1`00`0j;Ad203T/700303XX6P0l:Q`0?B/M00<0?bdO00<0?R`N
03d[7@0j;Ad00P0j;Ad203T/70<0>2/K00@0?2PO03XX7P0j:1h0>2LM0P0e9a`00`0c9a/0<2HJ030V
6P0202`S7P0602XS7@0X8ad09R<L02<S6`0R8QX08B8J0P0Y8QX00`0Z8a/0:b@L02`U7@0202dV7P03
02hW7`0]9a/0;BLK00H0;BLK00<0;BHN02`U7@0[91`00P0Z8a/02`0/9Ad0;RLO02lX800_9A`0<2HM
038X7P0c:Ad0=2/L03<Z6@0b:AP0<BTF0080<BLK0P0b:1`303<Y7@0703@Z7P0d:1P0=BTI03DY6@0f
:QX0=b/K03P/700203T]7@0303DY6@0f:QX0=b/K00<0=b/K00<0=RXJ03DY6@0h;A/00P0j;A`01@0m
;Ad0?bhN044^7`13;Al0A2hP0080?RdK00@0?bhL040_7@12<Al0@c8P0P14<b4204@d7@0>04Hd7P19
=1l0BcDP04dd801>=B40Cc@Q04/i8@1:>200B3HN04Le7@16=1`0AcDM04Pf7P19=al804Pf800304Dc
7@16=1h0BCLQ0080BcTS00<0BCLQ04Hd7P15<ad02011=248040c80<0>c<P0P0j<Ql203Ta7P0703P`
7@0m;1`0?B`L03h]7@0o;Qh0@2lO048a8@0204<b8P80A3<Q00<0@c8P048a7`11<1h00P11<1h2040_
7@0803h]6`10;ad0@c8P04Dd8P16=B<0A3<Q048a7`10;ad803d`7@80@c@Q00@0A3<Q04Hc8P16<b80
BC@S0P1:<b<404Le7`<0B3HP00D0BCLQ04Lg7P17=ah0B3PO04Ti800204Xj8@80Bc/R00/0CSPQ04dg
801<>200B3HN04Le7@15=A`0@cDK048d6P15=280A3<Q04<b8002048a7`0304<b8014<b40AC@R0080
@c<L0P14=1d01015=Ah0ASHO04Lg8017=b0;04De7P<0A3@M0P13<a`3048f7P80@CDM0`10=1`8044e
7@04048b6`14=1d0ASHO04Lg8080B3PQ00@0AcLP04Hf7`1==1h0BcDN0P1:=Qh204Lg7P0304Hh7P14
>1h0@SHN0080@SHN0P11=Ad3040d7080@c<L00@0A3@M04De7P16=Ql0AcLP0P18>2401@17<Ql0BC@Q
04`g8P1>>R80Cc/R0080Cc/P00<0CS/M04dl8P1=?2801P1=?2801P1>>R40CCTP04`h7`1<>1l0CCTP
04lk8P80DCdT00L0DShU04ln801A?R00DChP058m801D?200EC/P0080ES/P00H0ECdU05@l901D?2@0
Dc/S058j8P1A>B42050h80@0CSXQ00l0Cc/R054m901C?bH0ED4X05Tm9`1H?2H0ES`U05@l901@>R80
CSXQ04di801:>Al0BSPP04/i8@1<>R800P1=>b<02`1<>R80BcTQ04Xh8016=Qd0B3PO04/k8P1=?B@0
CShU04`l8`1:>R40BCTP0080AcPQ00H0BCTR04/i8`1<>R@0CcXU050j9@1A>bH204hj8@80Cc/R101@
?2<0201F>RD0ECTT058g8P1@=b40CCLP04di8@1>>R80CC/S0`1?>RD[ooooo`00:_ooool00`2HK3/0
VVhm09a`?`0209ib@@0309ea@02JKSd0VFdl00<0WG54102NLTD0102MLD@0WgE309id@P2MLd4209]a
?`0309ec@@2NM480WgE300P0WWA200<0XGI30:1e@P2NLd000`2LLCh02P2MLSl0WW=009ed?P2NMCl0
X7M30:5gA@2RN4P0X7E809mdA`2MLTL80:5eA0H0X7A30P2QMD@609mf@P80X7M32@2QMdD809ebA@05
09Qb@`2GLD80Ug5209I`@@2DKSl00P2CKCh03`2BK3d0TF/n095[?P2BK3l0TF/n091Z?@2>J3/0RfDh
08YT=`24HS@0Q68e08=Q=021GS@0P5de07iK=@0207eI=@08089L=`1nFcD0O5Tc07QF<01fERl0M5L_
07=G;`1dF30307=B;`80LU4^0`1aD2d00`1`Cbh0Kdh]06e<:`0206]::@0306a;:P1]C2/0KTd/00<0
JDX[0P1ZBb`306U::`0306U;9`1ZC2P0JT`X00D0JddY0140LU@^07EE;`1eEBh0MeH]07UF;01lEb/0
OUL/07iH:`1oFRd0P5/^085L;`22GC00Q5lb08EP<`26HC@0Qf8e08YT=`0208]U>080S6Hi0P2=IcX0
0`2>J3/0TVLl099W?00609=X?@80UFY000<0U6Tn09AY?02DJSX00P2DJSP00`2DJcL0T6Dh095V>@02
095V>@<0TVLj00<0TfPk08eW>02=IcP01P2=IcP2095V>@80TVLj0P2CJ3/209AY?0P0U6Xh2@2EJcT2
09A[=`<0UF`h0`2FKCT00`2GKCd0UV`l09AZ>P0209=Y>@0309AZ>P2FK3`0Ufdm0080UFXm0P2FJch2
09M/?`80V6e000@0UW4m09Mb?P2GLSh0Ug8n0P2HLcl209Ud@0<0VW0n0P2IKcd309Q^?006099^?P2C
KCh0Tfdn09A[?@2EJSd0UFTl0P2GJ3`809AZ>0@0TVLj102AIST0202=IcH0SVPg08iX=`2>J3L0SFLf
08]U=028HS40Qf4`2029ICD208aV=`0308eW>02>J3T0SfTj0080T6Xk00T0TF/l099]@@2@Jcl0SVTl
08eY>@2>JSP0T6`h09=_>`2DLC/00P2?JSH2091[=`07095/>02BKCT0Tfhj09A_>`2BK3d0TF/l08mY
>P0208iX>@0308mY>P2@JS/0TF/l0080T6`h00@0Sf/g08iZ=P2=JCD0S6Pd0P2;Ic<208]W=`0408YV
=P28I3@0Qf<c08EQ<@80Q60`00H0PUda081N<@1oGC00OUd`07aM;`1iGBh207ML;@0>07aM;`1jFbl0
MUT]079G;01]E2/0J54X06E?:01TCRL0HDHY0615:01K@bL0ED4V04ln901:?24204Dk800904<i7P12
=b40@CHP03de800j<b00=c8N038_700a;Qd0;bhL0080;2dO00@0:b`N02X[7@0Y:Q`0:2TK0P0W:1X0
200V:1X09RPK02DW6P0T9Q/08b@L028S7@0R8ah08B8M0P0P8a`301lR6`<07R4J0P0M81T201hQ6P80
7b8K0P0P8a`8020S6P<082<L0P0O8Q/301hQ6PP071hK00H0820N020Q700Q8Qd08B8L028S6`0S9AX2
02@V6@80:2TI0P0Y:QX0500Z:a/0:b`L02//700[;1`0<c4L03<`7@0d<Ah0=34P03@a8P0a;B40;BTN
02XV6`0R9A`08bHM02DW700X:1`0;2XM02l/7@0`;Ah0<bdM0P0i<Ah203Xb7`0403/c800l=240?3@Q
03`d8@P0?C8P0P0m<1l0100k<1h0>C4N03L`7@0g<1d203Ha7@04034^7`0`;Ah0<2dN030]7P80;b`M
0P0^:a`00`0X:A/0:BXL02X[7@0202//7P0302X[7@0Y:Q`0:2TK0080:RXN100Y:Ad202PX708092DM
0P0S91`2028S6`<08B8J200P8aX3024T7@8082<L0`0O8Q/0800N7b40824S028R8P0T81l08ahK02TO
7@0`9B40>2/U04<c4@1>?1P0GT/S071K;P1oJCP0S7<m09=j@@2HOT<0SWe508Yi@`21LD00MF<k06AD
<`1DA2/0ASLT03h^7P0d;AX0=2dK03<]7@0b;b00;c0R02h`9@0]<2D0;C0W0P0];b@202`^8`0402h`
9@0`<RL0<S@Y03@f:`80=3DU00@0<c@T038c8`0a<R80<C8R0P0`<B42038c8`0403<d900d=BD0=CHV
03Df9P80=SLW0P0i=b800`0j>2<0>cTT03`j9@0203dk9P0=03hl9`11?2P0@C/U048l9P15?BH0BClV
04a09P1?@BH0CT0U05=58P1DAR<0EdTV05U;:00405]=:P0605iA<@1LCbl0FT//05U8:P1GARP0F4DW
0P1JABP0401FARD0FTLW05e9:01RBRP0J4/Y06e<:@1`CRT0LDdY07]J<@1kFRl0NeT/07iI;021GBd0
QV4]08aT<02?Ic<2095Z;`04099[<02CK340Tf`a09A]<P80UFhc00P0Tg0f09=`>02@KcT0SVlh08]]
=`26JcH0PfLe081V<`80OfDb00h0OV@a07aR;`1kHC00NV0_07UO;P1hGBh0MEX]07MJ;P1gFb`0NU//
07eM;020Gb`0Pel]08AP;080RV@e00L0RF<b08IQ;@26HB`0R6</08eY;`2CKc<0Ug<e0080UG8j00@0
U74i09=`>02BKcL0TFhf0P2@KCD208mZ=@0608i[=@2<JcD0RV/d08U/=028Jc<0QV`c0`28JSH01`27
JCD0QFLc08=U<@22I300P68^07iN;@1mGB`00`1lG2/01P1nGRd0P60_085Q<026IBl0QF@^08AS;@80
Pf8/0`22HB/407iN:`0407mO;020H2d0PF4^085Q;PP0P60]0`1nGR/407eM:P0607aL:@24H2h0Pel]
085P;@20H2d0Of4]0P1lHB`02@1kHR`0PfDa08=U<@22I300PF<_081R;P1oHBd0OV0/07eO:`02075I
:`04071H:P1_Eb/0KUD/06eD:`80K5<[0P1XDR/206UC;080JU@]0P1YDb`02`1aFc@0JeD`06=?:P1O
CBT0G4`Z05Q89`1A@R<0BchN04dl7P1<>al0BSTM0080BCPN00/0BSPP04`j8P1=>b<0DSXN05Dm8@1I
@R80GdTT06==9P1UD2D0IU4R06MB8`0206eE9`80K5@V00@0Je<U06YB901ZDR@0JE4S201aER/206iA
9@80Ke8V0P1`DbL2075D:0<0MUXX0P1gFbT03@1hG2X0NEd[07UM:`1iGB/0ME`V07MN:01hGR/0NEl^
07UN;`1gG2l0MEX]07=H;@1aERT00P1`EBP01@1_E2L0KE8U06aA901/DB@0Je0S0080I54W00<0He0V
069?9@1QCR@00P1PCB<00`1OC280G4XR05a:8P0305a:8P<0FdTQ00<0Fd`U05Y;901JBb@0101JBb@3
05]<9@80FT/T00l0FDXS05Q98P1HBB80F4TR05M;9@1FBR@0EDTS05=78@1AAAl0Cd<M04i2701=@A/0
DdPX05979`1@ABD00`1>@b<205159@0804a39P1;@RD0BD0S04Ln8@15?1l0@cXM044h6`10=aX203ll
7@0603hj7@0l>1d0>cLN03Xe7`0i=1h0>C@P0P0e<ah0100d<Qd0<c4L038`6`0a;aX2030^6@08030d
7@0_<Qd0;C0K02/^6`0Y;1/09RPJ02DW6P0T9QT202@U7@0402<T700R8a/08R<K024R6P80824I0P0N
8AX0100M81T071lH01`O600K7QL201XM5PP05adI0`0H6QT301LI60805QPG0`0D6QX201<I6@<04QPH
2P0E5QP301@E5`804a@F0P0B4aDH01@E5`P04ALG400D5AL8014G5`P051DG200A5aL@01@E5`804Q<E
0P0C51H201@E5b805AHH200E5aH801HH5`<05ALF0`0F61L301LI60P061PH200J6QX801/K6@P071dG
200L71X201hO6@@07b0J0P0P8A/8020O6P0801dM5@0N7QH07alG024Q6@0S8a/09BDM02HV7P0W9al3
02DP6P809R4K1@0W8Q`402HQ6`809B0J0`0X91P302TU6@80:RHJ1@0[91`00`0/9Ad0;BHN02dV7P02
02`V6PH0;BLK00H0=BLT03DX8P0e:280=BPP03DX7`0e:Ad203DY6`0303T]7@0h;1`0=RXJ0080=2PH
00L0=RXJ03T]7@0k;al0=BPH03HY6@0g:QX0>2/K0080>B`L0P0j;Ad0200k:A/0?2XL03h/7P0o;Al0
@2hP03l]7`0n;1h0?B/M0P0k;Qh203X]7@80>B`L0P0h:a/0100l:1l0>bTO03XX7P0h9ad203DW7003
03<W6`0a9a/0<2HJ0080;B8L00H0:b8K02XS6`0W8aX09R<J02DR6@0S8aT202XS6`80:b@L00@0;2DM
02dV7P0]9Qh0;BHN200]9a/00`0]9Qh0;2DM02/T700202XS6`0;02/T700]9Qh0;RLO02lU700`9Qd0
<RPN03<Y7@0d:a`0<bXI038Y600a:AH00`0b:1`303<Y7@80=2XN0P0e:AT00`0f:QX0=b/K03P/7002
03T]7@0303X^7P0g:a/0=b/K00H0=b/K00H0>2dK03T/6`0j;A`0?BdM040_7`12;b0204D_8@80?RdK
00@0?bhL044`7P12<Al0A3<Q0P15=28204@d7@0904Hd7P19=1l0BcDP04he8@1?=R80D3DR04dk8`1;
>B40BCLO00<0AcDM0P18=Qh804Tg8@0304Hd7P18=R00BCLQ0080BcTS00<0BCLQ04Pf8016=1h02015
=R400`14=B80@c@Q04<d8@0204<d8@<0@S<P0P0l=24203/c800:03Xb7`0i<Ah0>C4N03P`7@0l:aT0
?B`J03h]6`0o;Q`0@C0N048a7`80A3<Q0P15=28204@c8@0304<b8012<Al0@S4O0080@S4O00P0?RdK
03l^7012<Al0A3<Q04Dd8P14<b40@c8P048a7`P0?C0M0P15=R401016=B40B3HR04Pf8P1;=R<204`e
8`0504Hd7017=Ad0AcDM04Pf7P19=al00P1:>2001`1;>B40B3HN04Pf7P19=al0BSPP04`j8P1=>b<0
0P1>?2@0201@>R<0CcTR04di8@19=al0B3HN04De7013=A/0@S@J0P17=B400`16=200AC<O04Dc7`03
04Dc7`<0A3@M00<0ACDN04Hf7`16=Ql00P17=b000`14=1d0ACDN04De7P0204De7P<0ASHO0P17=b00
1016=Ql0ACDN04De7P14=1d204<c70<0ACHO0P14=Ah304<d7@P0@CDM00@0@S8K04@d7@16=Ql0B3PQ
0P19>B801`18>240AcLP04Te7@19=Ad0BSHN04Pf7P19=al00P19>B00101:>R40ACHO04Df7`15=Ql2
04@e7P<0@c@M0P13<a`01014=1d0ACDN04Hf7`17=b0204Ph8@0804Lb7`19=240BcHQ04di8@1>>R40
CSXO04di7P1=>Q`8050l8`06050j8P1?>B40CSPP04dg7`1>>200D3XR0P1B?2@01`1C?BD0CchP054n
801B?b40DchQ05Dm8@1F?2400P1H?B8305@l900305<k8`1B>R80DSXR0080DCTQ0P1>>R402`1?>b80
D3`S058n9@1D@2L0ED4X05I2:@1H?2H0Ec/U05Hl9@1D?2@0D3XR0080CSXQ00<0BcXP04/i8@1;>B40
101<>R8204/i8@0>04Tg7`1:>200CC/S04hl901??BD0CS`T04`j8P1;>B40AcTO04Ph7`1:>200BcTQ
04hj8P1@>R<205<j9080Cc/R1P1@?2<0201G>bH0ECTT058g8P1@=b40CCLP04di8@1>>R80CC/S0`1?
>B8[ooooo`00:_ooool0202FJST0V6`k09]_?P2NLT40Wg=209ib@@2LL3l0VVhm0P2OLdH209ibA@07
09eaA02NLTD0WW9509ibA@2OMD<0WWA209ec@@0209]a?`0309ec@@2NM480WgE300P0WGE200<0XGI3
0:1e@P2NLd000`2LLCh02P2MLSl0WW=009ie?`2OMT00X7M30:5gA@2QMdL0X7E809icAP2NLdP80:1d
@`80XGE61P2PM4D209mf@P<0X7M30P2OMT800`2NMD40X7I40:1fA0070:1fA0@0W792102MLd<01@2G
LD80UW1109I`@@2EKd00U6ho0080Tfdn00<0TV`m091Z?@2@JSd00P2AJch0502?JC`0SFLj08YT=`29
HcH0Q68d08=Q=022H3<0PEhd07mL=01nFcD0OETe07aH=021FcH0OEXd07]H<P1gEBl0MED^07=F;P1b
ERh0LeL_0P1cDRl2079A;P80LE0]0P1`Cb`0201`Cbh0KTd/06a;:P1[BRT0JTTX06]::@1/BbX0KD`[
0`1ZBb`206U::`<0JT//101YCBP206Y>:@0B06]?:P1/D2/0LeD_07IF<01fERl0N5L^07YG;@1mF2`0
OeP]07mI;020Fbh0PE`_089M<023GS40QF0c08IQ=027HSD0R6<f0P2;I3T408aU>P80SFHk1P2CJ3d2
099W?080TfPn00<0U6Tn09AY?02DJSX00P2DJSP02@2DJcL0UFXm09AY?02CJ3/0TVLj095V>@2@ICP0
Sf@g08iS=P0808eW>0<0TVLj0P2CJ3/309AY?0P0U6Xh2@2FK3X209A[=`<0UF`h0`2FKCT00`2GKC/0
UV`j09E[>@0209AZ>00309E[>@2FK3X0Ufdk0080UFXm0P2FJch209M/?`80V6e00`2GLSh209Qc?`<0
VGA00`2JL3h209U_?@<0V6hl00H0Tflo09A^?`2CKCh0UF`n09EZ?@2FJSd209MX?0P0U6Xh0P2CJ3/2
099W>P80TFHi0P2@ICP0202>JCD0SfXf08mZ=P2?JSH0SFPd08]V<P28Hbl0Qf8^2028I3@01P2<ISD0
SFLf08eW=P2>J3L0SfTh091Z>@80TF/j00`0TVe1091[?`2>JC`0SFTi08eY=`2?JcL0TVhj09Aa>`2>
JCD0SfXf091[=`2AK3P2099]>@80Tfhj00<0TF/l091Z>`2?JCX00P2>J3T0102?JCX0TF/l099/?@2@
K3P208m[=`0S08iZ=P2=JCD0S6Pd08aX=02;Ic<0RfLg08YV=P29ICD0R6@d08IR<P25HC40Q60`08=O
;`22GC<0P5dc07mL<P1mG340Ne``07QK;`1fFbh0MEX]07YK;`1iFC00M5L]071D;01[DRX0IdlY06==
:01RC2L0GT@Y05e3:01G@RL0DD0T04dm8`17>b400P12>b402@11>R00?cLP03hf7`0k=Al0>3<O03@b
7@0`;a/0;bhL02`]6`0202`]7`0402//7P0Z:ad0:BXL02PY6`809bPJ00H09RPJ02DW6P0U9aX092HK
02<T700R8ad2024R7@8082<L0`0O8Q/601hQ6P807b8K0`0P8a`8020S6P8082<L0P0O8Q/201hQ6P80
7B0I200L7Q/0200P8A`0824K024R700R8a/08bDJ02@V6@0U9aT09RPJ0`0[;1X402`]6`0702d^700c
<Qd0=3<O03@c7`0b<Al0;bdN02`Z7@0202XX700902<V6`0T9a`09RPK02TZ700]:a`0<2dL034^7@0d
;a`0>S8O00@0>c<P0`0l=24803`a7`80>RlM0P0h<1d0100f;a`0=C0L038`6`0b<1/2030]7P80;b`M
0`0^:a`0100]:Q/09RHJ02LW6`0Y:Ad202XZ7P0302TY7@0W9a/09RHJ0080:BTO0P0X:1h202LW7@80
9RHL0`0S91`2028S6`@08B8J200P8aX3024T7@8082<L0`0O8Q/08@0L6b007adP02@P7`0X81d0;R4I
03HU6`11;b40BCHW05]65`1SCQl0LU`[085[>@2=MT80Tge409ElA02CNT40PGA007Q/?01[GS@0FTd[
04/o9@11=R@0>c8S03T_9@0a;b00<S0Q03@b9@0b<bD0<S8V02la900];b@0:bhS02d_900302`^8`04
02h`9@0`<RL0<cDZ03@f:`80=CHV00<0=3DU03<d900b<b<00P0a<R801`0`<B40=C<T03Dc900f=2D0
=cDV03Pf9`0i=bP00P0j>2T203Xh8`80>cTT02`0?3XU03dk9P0m>bH0?S`W040k9`12?2H0@cdW04Dm
9P18?RD0BShT04do901>@2D0DT<R05=48`1FAbH0F4TX05U::@1JBbX0FDXY05Q9:01LCbl0FTd]05U:
:`1HAbT0EdHX05U6:01JABP0FdHY05Y79P1LB2L0GdPV06A:9`1ZC2P0LDlZ07AA:`1hDRd0OEd^07aL
;@1lFRX0OUXZ081L:P25H2`0Rf<`08eU<P<0T6`b0P2AKC<3099^=00:08m_=P2?KSP0SVlh08a^>027
K3L0PfTf07mU=01kI380Nehb07]O<080NUh_0`1iGBd02@1hG2`0NEX[07]K;01mGB`0P5l/08AP;027
HRd0RV8^08]T;@0208mZ<`0?08eX<@2;IRl0RVH/08aX;02AKC40UW8d09Yf>02DLCT0Tg0h099_=`2@
KCD0Sf`d08eZ<P2<JC40RfP`0080SfXe00<0SFXd08YY<`29JS<00P27JS801@26K3<0R6Xh08MY=`25
IcD0PfDc00@0PV@b00P0P5h^07mM;@1nG2`0OE/[07iL;01oGBd0PEl_089P<0D0QV4/00P0QF0[08AO
:P24GbX0PUlY08=P:P24HB/0QF8/08IS;@80Qf@^00<0R6D_089Q:`22HB/00`22HB/308=R;0<0Q6<]
00<0Pf8/089Q:`22HB/00P21H2X208YR;`0708QS;`26HRh0Pf8]089S;@21HR`0P68/08MX<@0208IW
<00308EV;`24IBh0Q6D^0080Pf@]00P0N5h[07MM;01fFb`0M5T/079G;01aEBd0Ke</06mC;P@0JE</
0180JU@]06]E;P1[EBh0K5H_071I<01/E2h0Ie4/06A@:`1TDRh0HE4_05e=;01GB2L0DD4O05107P1=
?A`0BcXL04Xi7`1:>20204/i8`0804dh7@1@>b00E3lP05U58P1MBB@0H4dS069@8P1SDB<206YC9`H0
JE8V201aER/206iA9@@0Ke8V0P1`DbL407MK:@@0N5`Z00X0NEd[07=J901dFbD0ME/X07EK:P1eFR/0
LeP[079G:P1aER/0LULX0P1aERL01P1`EBH0Ke@U06iC901^Db@0KE8S06QC:080Ie8W00<0IU4V06E@
9@1TCb@00P1SCR<605a:8P80GD/S00<0FT/T05]<9@1KC2D0101KC2D405Y;90@0FDXS00`0F4TR05Q:
9@1GBB@0ETPS05A68@1CAB00DD<N05127@1?@A`0D4DU04m4901=@R8304]0800B04a18@1=@R80CD@W
04a39P1:@B@0B3lR04Hm8014>ah0@STL044h6`12?Al0@C`N040k7P0o>Al0?CLO03/e7`0j=1h0>S<P
0P0e<ah0100d<Qd0<c4L03<a700b<1/2034_6P08030d7@0_<Qd0;C0K02/^6`0Y;1/09RPJ02DW6P0T
9QT202DV7P0402@U7@0S91`08R<K024R6P80824I0P0O8Q/0100N8AX07B0I01`O600K7QL201XM5PP0
5adI0`0H6QT301LI60805QPG0`0D6QX201<I6@<04QPH2P0E5QP301@E5`804a@F0P0B4aDH01@E5`P0
4ALG400D5AL8014G5`P051DG200A5aL@01@E5`804Q<E0P0C51H201@E5b805AHH200E5aH801HH5`<0
5ALF0`0F61L301LI60P061PH200J6QX801/K6@P071dG200L71X00`0M7QP07QlI01hO6@0201lP6P80
824K00<08B8L020O6P0P7aX01P0P7aX0200M7AD07QhF01lO5`0Q8AT08b<K02DU7@0V9Qh09bLO0P0U
81X202HQ6`809b8L100X8ad202LR70809R4K0P0U81X302PT60<0:BDI0P0Z9QX202`S700302dT7@0^
9Ah0;RDN00<0;RDN1@0_9a`302hV6`0603DW900e:280=BPR03DX800e:1l0=RXN0P0f:Q`0200i;Ad0
>2`L03HZ6P0d:1P0=BTI03L[6`0j;Qh0?30P0P0f:AT203LZ6P0703P[6`0i;1`0>RdM03/^7P0k:A/0
?2XL03h/7P03040^800303l]7`0n;1h0>bhN0080>bhN0P0j;Ad303T/700403dY800k:Al0>bTO03TX
7P80=RPM00<0=2PL034W6`0a9a/00P0`8a/00`0]8aX0;2<J02/T6P0202PT6@0302LU6@0[91`0;2DM
00<0;2DM0`0]9Qh802hX700302hW7`0]9Qh0:b@L0080:R<K00/0:b@L02`U7@0]9Qh0;bDL030V7@0b
:1h0<bTM03@[700c:QT0<RTH034Y5P02038X70<0<bTM0`0d:Qh01P0e:AT0=RXJ03HZ6P0g:a/0>2`L
03T]7@80>RhN200h;1`0200h;A/0>RdL03/^7@0n;Qh0@2lO048_8015;b40AS0R0P0o;Q`01010;ad0
@C0N04<b8014<b4204Dd8P80ACDN00X0AcDO04Xe801;=B00CSDQ04lf8P1@=B80CC/S04`j8P1:>200
B3HN0P17=Ad00`18=Qh0BCLO04Tg8@0704Tg8@0304Pf8019=b40BSPR0080BcTS00<0BSPR04Tg8@18
=R002018>24304He8`0304Dd8P14<b40A3<Q0080@c8P00H0@3DS03ld8P0n<b40?C8P03`a7`0k<1h2
03X_7@80?RdI00L0?bhJ040_6`11<1`0@S4M04<b7P14<al0AC@R00@0A3<Q1013<R00100n;A/0?bhL
044`7P12<Al304<b8003048a7`0m<1d0?C0M00H0?C0M0P16=b001017=b00BCLQ04Tg8@1;=R4204dg
8P0504Lf7018=ad0B3LM04Th7P1:>Al00P1;>R001`1<>b40BCLO04Tg7`1:>200BcTQ04dk8`1>?2@0
0P1??BD0201A>b@0D3XS04hj8P1:>200BCLO04Hf7@14=Q`0@cDK1018=R001017=Al0AS@N04Hd7P15
<ad304De7P@0ASHO00<0AcLP04@d7@14=1d00P15=Ah01016=Ql0AcLP04Lg8017=b0204Ph8@0404Lg
8016=Ql0ASHO04De7P80A3@M0`17=b0204Hf7`<0ACDN2012=Qh01013<a`0ACDN04Lg8018>24204Ti
8P0704Ph8@17=b00ASHM04Hf7@17=ah0BCLO04Xh800204di8@0404hj8P17=b00AcLP04Lg8080ASHO
0`15=Ah204<c700404@d7@15=Ah0ASHO04Lg8080B3PQ00P0B3<P04Td8@1;=R40CCTQ04hj8@1>>Ql0
CCTN04`i6`P0DC/S00<0Dc/S058j8P1A>B400P1@>2001@1B>R80Dc/S05<k8`1E?BD0CchP0080DSlQ
00D0E3lR05Hn8P1H?R<0FChS05Xo900305@l90@0Dc/S00H0DSXR04lk8P1?>b80D3`S058n9@1C?bH2
05A09`0905E1:01G>bD0Ec/U05Dk901C>b<0DC/S04lk8P1>>R40C3/Q0080C3XR101;>B4204`j8P05
04/i8@1<>R80CC/S04hl901??BD00P1>?2@01`1=>b<0BSXP04/j801<>b40CSXQ050j8P1C>b<00P1E
>b@2054m90H0D3`S00P0Ec/V05Hj9@1C>2<0D3LQ04hh8@1>>R80Cc/S04hl90<0DCTQ:oooool002[o
oooo00D0Uf/j09Q/>`2JKSd0W70o09ea@00209ib@@0409ea@02QMDP0X7A709mcAP<0WG5400D0WW95
09mcAP2NM480WG=109ab@00209Y`?P0309ab@02MLd40WWA200P0VgI200<0XGI30:1e@P2NLd000`2L
LCh02P2MLSl0WW=00:1g@@2PMd40X7M30:1fA02PMTH0WgA709icAP2NLdP80:1d@`<0XGE80`2PM4L2
09mcAP0809mf@P2PMd<0X7M30:5hA02PMd<0WgI209ie@@2MM4090:1fA0<0Vg4o0P2LLT0309ec@@<0
UFm00P2DKSl309=]?P80SfTl0P2@JSd02P2>J3/0S6Hi08US=P28HSD0Pf4c08=Q=022H3<0P5dc07mL
=01mFS@207aH=008081J=@1lFC<0NULa07ME;`1dE2d0LUD]075E;@1bERh3079A;P80LE0]0`1`Cb`0
201_CRd0KTd/06a;:P1[BRT0JTTX06]::@1/BbX0KD`[0P1[C2d0101ZBb`0JDX[06U::`1ZBb`206]<
;@0H06U=:01XC2L0J4`W06Q<9`1YCBP0JdlZ06a@:`1]DB`0LeD_07IF<01fERl0N5L^07YG;@1mF2`0
OeP]07mI;021G2l0PUd`08=N<@24Gc80QV4d08MR=@28HcH0RF@g202<IC`209AY?P<0TfPm0`2BIc`2
099W?@0309=X?@2CJ3/0U6Xj0080U6Xh00T0U6/g09M/?`2FJch0U6Tl09=X>`2@ICP0Sf@g08eR=@2<
HC@0202=IcP2099W>P80TfPk0`2DJC`00`2EJSd0UF/i09E[>@0609E[>@T0UV`j0P2DJcL309E/>0<0
UVdi00<0V6lk09M^>P2EK3P00P2DJcL00`2EK3P0Ufhj09Q_>`0209EZ?@80UV/n0P2GK3l209Q]@080
UW4m0P2GLSh309Qc?`0409Ud@02JL3h0VW0n09Y`?P80VFlm0`2HKS`01P2CKcl0U6ho09A^?`2EK3h0
UV/n09IZ?@80V6Tm202EJcT01@2DJC`0TfPk09=X>`2BIcX0TFHi0080T6Dh00<0Sf@g08iY=02?JSD0
0P2?JSD0102>JC@0S6Lb08UT;`28Hbh808QT=080SFPd00<0SVTe08mZ=P2@JcL00P2AK3P0302BKCT0
SfXn08mZ?P2>JC`0SVXj08iZ>02?JcL0TFdi099_>@2?JSH0T6/g095/>0<0TVdi0P2AK3P2091Z>`<0
SVPi00<0T6Xk095[?02CKCh00P2?JcL208iZ=P80SFTe0P2<J3@208YV=P0408UU=@27Hc<0QV8b08AP
<080Pel_00H0PU`e07mL=01nFc<0O5/b07YJ<@1fFBl207AI;P0>07MG;P1fERl0LE@/06eA:P1XCRT0
I4`X06199`1OB2H0Fd<W05Y2:01E@BH0D3lU04/m8`15>b82044i8P0903li8@0m=al0?3HN03Td7P0e
<ah0<S4L02d_6P0/;A/0:RdJ0080;2dO00@0:b`N02X[7@0Y:Q`0:2TK0P0W:1X0200U9aT09BLJ02@V
6@0S9AX08R<K024R700Q8Qd0824L0P0P8a`301lR6`D07R4J0P0O8Q/3020S7003024T7@0P8aX082<J
00H082<J0`0O8Q/201hQ6P<07B0I200L7Q/01P0P8A/08B8L028S6`0S9AX092HI02HX6P809bXI100]
;aX402h`6`0@030b700a<ah0<38M02d^700X:AT09RLI02LW6`0Y:Ad092PJ02DY6`0W:A/0:R/K02h]
6`0a;Q/0<RlL03D`70P0>c<N200l<Al01P0i;Ad0=bhM03L^7@0e;Q`0=2lL034^6`80<2lK0P0_;1d2
02h[70<0;BXK00@0;2TJ02HV700W9ad0:BTO0P0Z:R000`0Y:Al09bLM02HV700202PX80809bLO00@0
9RHN02DU7@0T91`092@L0P0S91`2028S6`<08B8J0P0P8AT8020S6P<08B@M0P0P8a`301lR6`0J01dK
700S7a`0:b@L03<W6`0l:aT0BCDL05Y18`1TBB/0Nf4^07mU<P28KS/0TWQ509IoB`2DOD/0S7E308E^
?01WGSL0GeDa0599:014?B40>S@N03Lb7`0f<b@0>3@X030b9`0a<bP2038d:@04034c9P0_<B@0;BlR
02/]8080;BlT0P0/;R<01@0^<2D0<38W038d:@0d=R/0=CHV00<0=3DU100c=2@01P0g=2D0>3DV03Pe
9P0i=RL0>SLX03/h:@80?3TZ200l>RD0300o>RH0@S`V04Do:@16?RL0AS`S04Lk8@1<?R<0Cd4V0593
901DABH0ETLX05Q9:P80FDX[00D0F4TZ05M8:@1HBb/0EdXZ05M8:@0205M6:00;05Y7:@1LAbX0GDP[
05a89@1OB2H0HDTU06M;9P1^CRP0M54[07YD;`1mERl00P1nGbT01`1oGRT0PUhZ08=O:`27HRh0Rf<b
08aT<`2>Jc<00P2?K3@2091]=@80TFhf00T0TVlg08a]=P2=KSP0S6hh08U^>@25JcP0OfPf07YR<P1g
HC000P1jFS<0101kFc80Ne``07]L;P1lGBh207aN;00807mN:`20Gb`0QF4]08UT;`2=IC40SfH`091W
;`2AIRl2099^<00J095];`2?Jbd0Sf/]091/;P2CKc40UW8d09Ue=`2?KcH0SVhe08e]=02;Jc80RVXa
08QX;`27Ibh0QVH]08iY=@2=J3@0RfLc08MV<@26Ic40QFLa08IX<P24JC80QVLh08AU=P22Hc@2081Q
<P06085R<`23I3D0Q6Df08IR<P25HC40Pel_0P22GRh01P23Gbl0QF4a08IR<P2:HB/0Rf8/08aS;@80
SF@^00L0S6<]08]R;02:HB/0R6</08UT;@2;IRl0S6L`00<0SFPa00<0S6L`08QU;@29IRh00P29IRh3
08YW;`0608]X<02=JS80SFXb08aY<@2;J300RVL_0P29IRh01`28IBd0TFHc08mV<P2?IS80SFDa08YU
<028IBl00P25I2h308YZ<@80RFT`0P28J2l02@27Ibh0OfD/07iS;01lH2h0NEd]07MJ<01dEbl0LU@`
075C<@0206]E;P0N06YD;@1YDb`0JU@]06]E;P1/ERl0KEL`06mF;P1[DRX0J50Z06QB;@1YEC00JELc
06MD<`1RDS00FdTQ05U78@1E@al0DChN04lk801=>B40CCPS04dh9@1;=ah0CCTN050m7`1D@B00FDLQ
05a:8P1OCR80H4lS0P1TCb@00`1UD2D0IU4V06MB9`0206QC:00306UD:@1`EBX0L5DZ00H0L5DZ0`1_
DRH5071C9`T0Me/Y0P1cFR@01P1cFBH0LeTX07=H:@1bEbX0LEHY075F:`<0LUPW0P1aEbH2071F9@06
06mE901ZDbL0JU<W06UB9P1XDBD0Ie0T0P1VCb<00`1UCR80GD/S05e;8`0205e;8`80GT`T0P1OCBD0
0`1JBb@0Fd`U05a=9P0305a=9P0305]<9@1JBb@0FdTS00L0FdTS0P1GAb<0101FAR80EDDQ05A4801D
A20205=37`0304i38`1=@R80Bd0P00<0BChN0P1;@20204a39P0604Y19019@2<0AchQ04Dl7`14>ah0
@cXM0P14?B001`12>al0@CXP03lg800m=B00?3@O03/c800f=1l00P0e<ah00`0d<Qd0<c4L038`6`02
034_6P0802hb6`0^<A`0;2lJ02/^6`0Y;1/09bTK02HX6`0U9aX202DV7P0402@U7@0S91`08R<K028S
6`808B8J0P0O8Q/0100N8AX07B0I01`O600L7aP201/N5`P05adI0`0H6QT301LI60805QPG0`0D6QX2
01<I6@<04QPH2P0E5QP301@E5`804a@F0P0B4aDH01@E5`P04ALG400D5AL8014G5`P051DG200A5aL@
01@E5`804Q<E0P0C51H201@E5b805AHH200E5aH801HH5`<05ALF0`0F61L301LI60P061PH200J6QX8
01/K6@P071dG200L71X201`M5`0401dN600N7aT07QlI01lP6P80824K200P7aX201lO5`04020P600Q
8AT08b<K02@T70809BDM0`0V8A/202LR70<0:2<M0P0Y91h0100X8ad09b8L02HQ6`0V8A/202DP6P<0
:2@H0`0Y9AT202XV6P0402dR700^8ad0;b@N030U7`80<BHP00@0<2DO02lT7P0b:1h0<RPN0P0a9ad4
030V700603<U8P0d9b40=2LQ03DX800f:B00=b/O0P0h;1h203L[6`0603HZ6P0g:a/0=b/K03T]7@0k
;al0?30P0P0i;1`303P[6`0<03T/700j;Ad0>bhN03`Z700m:ad0?bdO040^8011;b40@2hP03l]7`0n
;1h0?2lO0`0k;Qh203X]7@80>B`L00@0?BTP03`Z800k:Al0>BPN0P0f:1d00`0d:1`0<RPL034W6`02
038T6`04034T6`0_9A/0;RHK02dW6`80:bLK200]9Qh802hX700302lX800^9al0;2DM0080:R<K00`0
:b@L02`U7@0]9Qh0;bDL030V7@0b:1h0<bTM03@[700c:QT0<RTH034Y5P0b:1`303<Y7@80=2XN0P0e
:al203HZ6P0303L[6`0h;1`0>BdM0080>RhN00<0>blO03X^7P0i;Ad0100h;1`0200i;Ad0>RhN03X_
7@0k;Qd0?2lN03l_7`10;al0@RlP0P15;b401011<1h0@S4O048a7`12<Al304<b800604@c8@15=Ah0
ACDN04Le7`1:=B00C3HQ0P1?=R80101A=R<0C3XR04/i8@19=al304Pf7P0304Xh801;>B40BSPR00T0
BSPR101;>B<204Xh8PP0BcTQ0P19=RD00`18=B@0Ac@S04Hc8P0204Db8@0704@a8012=B@0@C@S040c
8P0o<R40?C0O03`_7P0203/^7@80@30I0`11<AX3048b6`T0@c8P0P10;ad2044`7P<0@S4O00<0@C0N
03lb7`0o<Ql01P0o<Ql01P15=ad0ASPN04Lg7P18=Qh0BCLO04/g7`80CCLP00@0BCPN04Xi7`1:>Al0
BSTO101;>R0204di8@80CSXR00`0Cc/S050l901A?BD0DCdU054k901@>R<0CSXR04/i8@1:>200AcLN
04Hh7P15=ad404`h800404/g7`1:=Qh0B3@L04Lc6`P0ASHO0P14=1d01015=Ah0ASHO04Lg8017=b04
04Ph8@<0AcLP0`16=Ql304Tg8@80B3HP0`17=Al8048f7P0304Hf7`17=b00B3PQ0080BCTR00D0B3PQ
04Lg8016=Ql0A3PN04Hh7P0204Ph7`0404`h801=>B40CSPQ054h8P<0BCLQ0P18=R0304Le7`80@c<L
00@0A3@M04De7P16=Ql0AcLP0P18>240201:=B80BcHS04dh8`1>>R80Cc/R04hj7`1=>Ah0C3TK201D
?2@00`1E>b@0E3XS05<i8P02058h8@0:05<i8P1D>R<0E3XS05Dk901@?b40DSlQ05=08P1D?b80EclS
05To9080Fd0U201D?2@0101?>b80D3`S054m901B?RD205<o9P07058n9@1A?B@0ESXT05Hj901E>b@0
Dc/S054k8`0204lk8P0404dl8P1=>b<0C3XR04/i8@80BSPP00D0BcTQ04`j8P1=>b<0CSXR04lk8`02
050l90@0DCdU00P0CC`R04lk8P1@?2<0DS`T05Dm9@1G?BH0F3`V05Tm9`80DShU0P1A?B@4050l8`08
05Lk9P1F>RD0DcPS054h8P1>>240CSXR04lk8`1>?2@305@j8b_ooooo000Zooooo`<0V6`k00P0VFdl
09]_?P2MLD00X7A30:5eA02RMTT0XGE809mcAP<0WG5400D0WW9509mcAP2MLd40Vg4o09Y`?P0209U_
?@0309Y`?P2KLCl0WG=100P0VgI200<0XGI30:1e@P2NLd000`2LLCh01`2MLSl0WW=00:5h@P2QN480
X7M309me@`2OMDD00P2NLdH00`2NLdP0Wg=209mc@P0609mc@P80XWI90P2QMDP01P2PM4L0Wg=609mc
AP2OLdH0WgI20:1g@`<0XGQ400<0WgI209ed@02LLcl02@2OMD<209Y`?P80Vg4o00@0W79009ec@@2M
Ld40WG=11@2DKSl309=]?P0>08iX>`2?JC`0SfTl08mY?02>J3/0RfDh08US=P27HC@0Pf4c089P<`21
Gc80P5dc07iK<`1mFS@207aH=00607mI=01lFC<0NEH`07ID;P1cDb`0LE@/0P1aEBd2079A;P80LE0]
101`Cb`00`1_CRd0KD`[06a;:P0306Y9:00506]::@1/BbX0K4d^06]<;@1ZBb`00P1YBR/01@1ZBb`0
Jd`]06a=;P1WCBP0IT`W0080ID/V00`0IT`W06U?:P1[DB`0KE<^079D;P1eEBl0MED^07MF;@1iER`0
O5L[07iG;01nF2/2089M<00408=N<@25H3<0QV4d08QS=P80RF@g202<IC`309AY?P0309=X?@2BIc`0
TVLl0080TFHk00D0TFHl099W?@2BIc`0TfPk09=Y>@0209AZ>00609E/>02DJC`0TfPk09=X>`2BIcX0
TFHi0P2@ICP00`2?I3L0SFLh08eW>00608eW>0<0TfPk0`2DJC`209EZ?@P0UF/i2@2FK3X209A[=`<0
UF`h0`2FKCT00`2HKcT0Ufhh09I]=`0209A[=@0309I]=`2GKSP0V6li0080UFXm0P2FJch209M/?`80
V6e00P2EL3`209Ia?@@0Ug8n0`2JL3h209U_?@<0V6hl00H0Tflo09A^?`2DKSl0UVdo09I[?P2GJch2
09QY?@P0UF/i0P2DJC`0102CJ3/0TVLj095V>@2@ICP208mT=`0808eX<@2>JC80SfXc08mZ<`2>JC80
SFPa08]V;`29I2d808MS<`80SFPd00@0SVTe08mZ=P2@JcL0TF`h0P2BKCT208eX?00908mZ?@2@K3`0
T6`j091/>02?JcL0Sf`f091[=`2AK3P0TVdi0080Tfhj00D0TF`h08mZ=P2>JCD0T6Xk08mY>P0308iX
>@03091Z>`2BK3d0Tfdn00@0SVXf102=JCD01P2:ISH0RFDe08QT=027Hc<0QF4a08AP<080Pel_00H0
PU`g07mL=P1nFcD0NeTc07UI<P1eF30207=G;`0>07AD;@1cDb`0KU0Z06Y>:@1UBbP0HDTW05e6901L
ABD0FD4W05I0:01C?bH0CShU04Pl9013>b@2040j900903hi8`0k=ah0>SHM03Le7P0d<Qd0<C0K02d_
6P0Z;AX0:B`I0080;2dO00@0:b`N02X[7@0Y:Q`0:2TK0P0W:1X01P0U9aT09BLJ02@V6@0S9AX08R<K
024R7080824L0P0P8a`301lR6`<07R4J0`0O8Q/3020S70808B@M200P8aX201lR6`807R4J100M81T8
01`N6`08020Q6@0Q8QX08R@I02@V6@0U9aT09bXI02P[6P0X:aP702la700902h`6`0];aT0;c4L02la
700Z:aT092DE028S5@0U9AT0:BTM00809BTJ00H0:2/J02//700_;Q`0<BhK03<a700e<1`403Xb6`@0
>C4J200k<1h01P0f;Ah0=BhN03D^7P0c;Ad0<BhM02l^7080;BhL0`0^:a`202dZ6`<0;2TJ00<09bLM
02PX7P0Y:Al00P0Z:R000`0Y:Al0:2PN02LW7@0202PW8P0602LV8@0V9B009B@O02@S7P0S8Qd08R4L
0`0R8a/3024R6P<0824I200P8aX3024T7@8082<L0`0O8Q/08P0T8AX0:RHK03@]7@11<Q/0CS/K0619
801cERX0PF8c099d@P2@M480TWI609AiBP2CN4/0RG5507YQ>01_ERd0Bd@Z04I0:011>b<0>SDO03Dc
7P0c<Qh0<C8P038c8`0Z;bP0:c4W02d`9`0]<2D0;S0U02d_8P0];B40;2`P02la9P0^<2D302d_9004
02la9P0a<bP0<S@Y03<d90<0=3DU100e=RH01P0h=BH0>CHW03Tf9`0j=bP0>cPY03`i:P80?CX[0P0o
?BP0100n?2L0?C/V03`j9@0k>B@203Xh8`0;03hi9@13?BL0AT0Z04Hn9`15>b80ACTO04/m8P1?@BH0
Dd@W05E6:@1GB2/00`1IBRd02P1HBB`0EdP[05E8:01DAbL0EDHW05I59`1GARP0FdPZ05i9;01PBbh2
05m9900?06=9901XBR@0L4hX07IC;@1mERl0P5Tb089S:P23I2/0QVD_08YW<@2;Ic<0S6Lc08iV=@2=
IC@0Rf/b0080S6`c01d0SFdd08m_=P2@L3L0T70g095a>02:JcD0RV`f08]]>@29KC/0QF/j07iV=P1g
HC00M5h_07]I=P1kFC@0O5Xd07eL<`1nGC00OUh_07mO;P20H2d0QV8^08UT<02;IS40T6Tb09=Z<P2E
Jc40UfXa09IY;P0309=`;080Tg0^00X0Tg0`09Aa<@2ELC<0UG4c08e^=@2<KC@0Rf`c08Y[<P29JS40
QfP_0P26Ibh08`2<ISD0RfDd08QT<P25I340Pf<`08=U<@24IS80PfPc08AU=`22HcD0Of0b07eN<01n
Gc40PF8d08AU=`27J3X0RfDf08US=028HS<0Qf4b08IP<@27HC80RF<d08YT=@2AIRl0TVL`09AY<P2E
JS<0UV/d09EZ<`2CJ340TVL`095Y;P2CJc00U6`a0080UVhc00<0UFdb09A/<@2CJc000`2BKS800`2C
Kc<0U70d09A`=00309Ea=@0509A`=02CKc<0TVhb095]<@2@K3000P2?Jbl0202GJCD0UVPd09AY=02A
J380SfPa08aW<02;IRl0RVL_0`2<K2l408][;P0<08YZ;@26JBl0QFP^089T;P1oH340O5da07UI<P1f
EC80ME@c06iH<@1]Ec00JeD^0`1ZE2d08P1/ERl0KEL`075E;@1/DbX0JU4Y06]C;@1^F3<0KETf06YH
=01WE3<0I54V065>901LB2<0Ed<R05<n8`1@>R<0CSLU04hg9`1;=al0C3PO04lk801B?al0ET@P05U7
7`1LBb00GD`P05e:801NBb40Gd`R065>901SD2H0IE8X06MD:P1XEB/806iC:0D0LE@X0`1`DbL307IJ
:0H0METW00P0MehX07IM9`1fG2T0MU`[07EJ:`1eFRd0M5T/07AI;P80LeTV0`1bF2D3075G9080K5@V
00<0Je<U06YB901YDB<00P1XD2800`1WCb40GT`T05i<900205m=9@80H4hV0P1QCbL00`1JBb@0Fd`U
05a=9P0205e>9`0305a=9P1KC2D0FT/T00H0G4PS0P1MBB@805M58@0804m4901>@b<0C44Q04]0801:
?al0Bd0P04a18@1=@R8204]29@0404Y19019@2<0B3lR04Ln8@80ASdP00P0ASlR04Dn8@13?200@CXP
03lg800m=B00?3@O03/c8080=S@O00<0=C<N03@b7@0c<A`00P0b<1/01`0a;aX0;30I02`_6P0[;QT0
:RdJ02T/6`0X:Q`00P0W:A`01P0V9al09BHN02DV7P0T9Ad08b@L028S6`808B8J00H082<L01lR6`0O
8Q/07R4J01dP6@0L7aP201/N5`P05adI0`0H6QT301LI60805QPG0`0D6QX201<I6@<04QPH2P0E5QP3
01@E5`804a@F0P0B4aDH01@E5`P04ALG400D5AL8014G5`P051DG200A5aL@01@E5`804Q<E0P0C51H2
01@E5b805AHH200E5aH801HH5`<05ALF0`0F61L301LI60P061PH200J6QX801/K6@P071dG200L71X2
01XK5@0401/L5P0L7AL07AhH01hO6@807b0J200P7aX3024Q6@808R8J0`0S8a/202HQ6`809b8L100X
8ad202XU7`0602TT7P0X8ad09b8L02HQ6`0U81X091lI0`0X91P302TU6@80:RHJ00<0;B8L02hS7@0`
9Al00`0b9b40100`9Al0;b@N03<Y7`0c:Al2038X7P0B034W7@0`9Q`0<2HL030V700a8b00<RDO03<V
800e:200=bXQ03T]8@0j;R00>blQ03@X600f:QX0=b/K03T]7@0j;Qh0>blO0P0j;Qh02`0m<200?2lO
03X]7@0i;1`0>2/K03T/700j;Ad0>bhN03`Z700m:ad0?bdO0080@BlQ00<0@2hP03l]7`0n;1h00P0l
;al303/^7P<0>RdM00@0?BTP03`Z800k:Al0>RTO0P0g:Ah02@0e:Ad0<RPL038X700f9A/0=2HK03DW
700d:1`0<RPL034Y7002030Z70P0;BHN200^:1`0100_:200;RLO02`U7@0[91`202XS6`0:02/T700/
9Ad0;bDL030V7@0b:1h0<bTM03@[700c:QT0<RTH034Y5P<0<bTM0P0d:Qh303D[7`80=RXJ00@0=b/K
03P/700i;Ad0>RhN0`0k;al0200j;Qh0>BdM03P/700h;1`0>BdM03X^7P0k;al0?34O0P0m<1l00`0o
;al0@2lO044^7`0204@^80<0A3<Q0P13<R02048a7`0<044`7P15=Ah0ASHO04Le7`1:=B00C3HQ04lf
8P1@=b<0DCHS04/i8@1:>200BCLO0P18=Qh00`1:>200C3XR04dk8`0@04/i8`P0CSXQ0P1<=bH03P1;
=RD0BSDT04Td8`18<b80Ac8Q04Ha8015=BD0A3@T04<c8`11<B40@30P03h^7P0m;Ad0?2`L0P13<a`2
048b6`80@C4J0P10<1T;048a7`80@C0N1010;ad8044d8@80ACLL00@0ASHL04Pg7@18=ad0BcLN0P1<
=Qh304`k7`<0BcXN0P1:>Ad3050j8`D0DC/T00<0D3XS04li8P1>>R800P1;>B400`19>B00B3XP04Pj
800204hh8080CcTQ00@0CSPP04`f7P19<a/0B38J1017=b0404Hf7`80A3@M00@0ACDN04Hf7`17=b00
B3PQ0P19>B8404Lg80<0B3PQ00<0BCTR04`g8P1<=b800P1;=R4304Xe800304Td7`12=Qh0@SHN00H0
@SHN0P19>B8204Xj8`0<04Ti8P17=b00ACDN04<c7014>Ql0ACTO04Pj8019>B00C3PP04dg801@=b40
DCHQ0P1<=b8204/f8@<0BSDP00L0BC@O04<c7013<a`0A3@M04De7P16=Ql0AcLP0080B3PQ00P0C3LT
04dh9@1?>RD0D3`T050l8`1?>b00CSXO04dj70P0E3`T00<0Ec/U05Hj901D>2800P1C=b402P1D>280
ECTS05Di8`1F>R@0D3lQ058o8@1C@280ED0S05Q0901J@2D205a19PP0E3`T00<0D3`S054m901B?RD0
0P1B?RD00`1@?2<0CSXQ04di800205Hj900905@j8`1C>b<0DC/S050l8`1?>b80CC`R04dk8`1<>R80
BcTQ0080BSPP00<0BcTQ04`j8P1=>b<0101A>b@2058l9@80DcdV00T0DCdR058n8`1C?R<0EShT05Pn
9@1J?RH0FclW05do9`1C?bH00P1B?RD2054m9080D3`S00T0Cc/R05Pl9`1G>bH0E3TT054h8P1?>B80
CSXR04lk8`1>?2@00`1G>b<[ooooo`00:_ooool04`2IKC`0V6`k09M[>P2GJcX0VFdl09ea@02QMD@0
XgM60:=gBP2RMTT0Wg=609eaA02LL4<0WG5409ibA@2OLdH0W79009Y`?P2IKcd00P2HKS`00`2IKcd0
VW0n09ab@00809Yf@P030:5f@`2PMD80WW=000<0W74n00L0WG8o09ic@02RND<0XGQ20:1g@`2OMD<0
WWA40080WW=600<0WW=809mc@P2OLd801P2OLd820:9eB`80XGA:00`0X7=909mbB02OLTP0WW5709mf
@P2PMd<0XGQ40:9iA@2QN4@0WgI209ed@02KLSh909me@`<0VW4m00<0Vg8n09ac?`2MM4000P2MM404
09A^?`@0Tfdn0P2>J3/208mY?00D08eW>P2;ICP0R68e08MQ=023HC<0PV0c085O<P20GC<0OU/c07eJ
=01lF3@0NeLc07mI=01kF380NEH`07EC;@1cDb`0LE@/071D;01aEBd2079A;P80LE0]0`1`Cb`0301_
CR/0Kdh]06e<:`1[BRT0JTTX06U89`1ZBBP0JdXY06a;:P1]CRl0K4d^06Y;;080J4TZ00D0JT//06a=
;P1]CRl0IThX06E=9`0206A<9P0D06E=9`1XD2X0JU8/06aD;P1bE2h0M5@^07EE;P1gERd0NEH/07aG
:`1mER/0OUP[089M<023GS40Q5lb08EP<`27HSD0R6<f08UT=`2:ICP208eV?`@0S6Dn0P2;I3d0102E
JSl0U6Tn09AY?P2CJ3d2099W?080TFHk0P2AIS`00`2BIc`0TVLj09=Y>@0209AZ>00609E/>02?I3L0
T6Dh091U>02AIST0TVLj0P2CJ3/00`2DJC`0SFLh08eW>00608eW>0<0TfPk0P2DJC`309EZ?@P0UF/i
2@2FK3X209A[=`<0UF`h0`2FKCT00`2HKcT0Ufhh09I]=`0209E/=P0309I]=`2GKSP0V6li0080UFXm
0P2FJch209M/?`80V6e00P2DKc/209E`?0<0UW4m00@0Ug8n09Y`?P2JL3h0VW0n0P2IKcd309Q^?006
09A`@02DKSl0U6ho09I]?`2FJch0Uf/n0P2HJCd809E[>@0;09EZ?@2DJC`0TfPk099W>P2AIST0T6Dh
08mT=`2>HcH0S6L`08eX<@2>JC800P2?JS<00`2=J340S6L`08]V;`0808MS<`0608eX<`2>JC@0SVTd
08mZ=@2@JcH0TF`g0P2BKCP04P2;ISX0SFPl08mZ?@2BKSh0TVhl095]>@2?JcL0SFXd095/>02BKCT0
Tfhj09A_>`2CKSX0TF`h08iY=@2=J3@0T6Xk08mY>P<0SVPi00<0T6Xk099/?@2CKCh0102>JSH408eY
=@0N08YV=P29ICD0R6@d08MS<`25HC40Q60`08=O;`22GRh0PU`g07mL=P1nFcD0NeTc07QH<@1eF300
LeL_079F;P1bDR/0LE4[06e?:@1YCBP0HdTV05m79@1LABD0FT<S05I0:01E?bL0DClW04dm9018?2@0
@SXS0P0n>B<02@0m>280>cLN03Xf7@0f=1d0<c8M02la6`0[;QT0:RdJ02P]6@0202`]7`0402//7P0Z
:ad0:BXL02PY6`809bPJ00H09BLI02@V6@0T9QT08bDJ028S6`0Q8Q`2020Q708082<L0`0O8Q/301hQ
6P<07b8K0P0P8a`3024T7@P082<J0P0O8Q/201hQ6P<07B0I00<071lH01`N6`0L7Q/01P0L7Q/0200P
8AT08B<H028T6@0T9QT09RPJ02LZ6@0X:aP0:B`I100`<Q`402la6`0@02X^5`0/;aX0;2lJ02LZ5`0Q
91<07b4C02@V6@0Y:ah09BTJ02HZ6`0X:aX0:b`J02l^6P0b<1/0<c4L03Ha6`D0>C4J0`0h<1T803/`
7P0603D^7P0d;Ad0<bdM03<]7@0`;A`0;bhL0P0/;A/202h[7080;BXK0`0/:AX0100[:1T09bLO02PX
800Z:R8202/[8`0;02XZ8P0X:2009bLO02PW8P0W9R409RDP02DT7`0T8ah08b8M028Q700Q81/00`0R
8a/2024R6P@0824I200P8aX3024T7@8082<L0`0O8Q/08`0Y9aX0<2dL03`d7@1;?1d0FTLO071F9@25
Ic40Tg<h09UiB02FMdP0TgA608mbB029KDD0NV0k06Q>:`1I@Al0>34Q03Pb8P0i<b<0>3DT03He8@0b
=1l0;S4L02`_6P0U;2D09B`T02H[900Y;2<0:B`Q02/]800];B40;BhP030b9`0_<BH0;S0U0080;BlT
00@0;S0U030b9`0a<bP0<S<S0P0c=2@00`0d=BD0=CHV03Hg9`0203Lh:080>cDW00<0?3HX03dg:@0n
>2X00P0o>B/01`10>R`0@ClZ040n:@0o?BP0?S`W03`j9@0j>2<00P0i=b803P0m>2@0@cdW04M1:`16
?RL0AC/R04@h7P1:?240Cd4V05A5:01EART0EdP[05U:;@1JBbh0FDX]0P1HBB`205=69P0f05A59P1E
A2H0EdHX05a9:`1PBbh0HTd`05m9901QBBD0HdTT06U;9@1`CRP0N58[07iG<023FC40QFL[08MX;`2;
Jc80T6dg095]>@2AJcX0TFTh091X=`2:JC<0RfXd08a[=@2=K3H0Sfhh091_>@2AL3X0TW4k08U[=@2:
K3P0RFhi08M]>P22JcT0O6He07IP<@1bGBh0NePh07]I=P1lFSD0OE`c07mN<`20H340PF4`085Q;P2:
IC00S6Lb095Z<`2EK3@0V6hd09Y]=02JK340VF/_0P2CLBX03@2DLR/0UG8^09Eb;P2ELS00U74a09=_
<@2BKS00SVlf08e^=@2<KC@0Rf`c08Y[<P29JS400P28JC004`2;IC@0RV@c08MS<@23HRl0PF4^085S
;`23IC40PVLb089S=@20HC<0OEh`07aM;`1mGS00PF8d08EV>028JC/0SFLh08aV=`2:I3D00`29Hc@0
1@2;ICH0S6Hg09U/=@2JKCH0W6lh0080WW4j00H0WG0i09]^=`2JKCH0UFdb09M_=02HL3D209Yb=`03
09Q`=@2FKS<0UFdb0080VGDi0P2JMSX0302KMc/0W7Pl09ah?02MNCd0VGDi09Qd>02GLcL0UW8f09Ea
=@2DL3@0Tflc099^<P80VV/g00@0V6Xf09EZ=@2BJC<0T6Tb0P2=J34408m]<0@0SV`_0300RFd^08Q[
<@25J300PV@b07iO<`1kFc@0N5Ld07IE=01`FS<0KUPa06aF;`1ZE2d0JE</06YD;@1/ERl0KEL`07=G
;`1`E2`0Je8Z06aE;01^F340KETd06]G=01WEC40JELY06IC:01PCBD0FTHU05E08`1A>b@0CcPV04hg
9`19=al0BSPP04`k7`1??ah0DT8N05E67`1HBAh0FDXO05U6701KB1h0GDXP05m<8P1RCbD0IE8X06MD
:P1XEB/806eB9`@0LUDY101aE2P407EI9`D0M5PV00D0Nf8/07YQ:`1iGb`0NEl^07QM;P0207QM<003
07QM<P1cFBH0LeTV0080LeTV101bF2D01P1]EBL0K5@V06aD9P1[DbD0JU8T06UA8`80J50R0P1OCBD2
061>9P07065?9`1RD2P0HU0X06=A:@1IBR<0Fd`U05e>9`0205i?:00305e>9`1KC2D0FDXS00D0G4PS
0`1MBB@305I4800305M58@1HAR80F4HR0080FDLS00<0DTLW05159@1?A2@00`1=@R800`1>@b<0Cd@T
04Y1900204Y19080BD0S1018?b801`17?R40AS`Q04@j8@12=b40@3DQ03hc7`0m<R000P0f=1l0100e
<ah0=38M03<a700c<A`2038`6`0802/_600[;QT0:bhI02X]6P0Y;1/0:B/M02T[7P0X:Qd202HW7`04
02DV7P0T9Ad08b@L028S6`808B8J0P0P8a`0100O8Q/07R4J01dP6@0L7aP201/N5`P05adI0`0H6QT3
01LI60805QPG0`0D6QX201<I6@<04QPH2P0E5QP301@E5`804a@F0P0B4aDH01@E5`P04ALG400D5AL8
014G5`P051DG200A5aL@01@E5`804Q<E0P0C51H201@E5b805AHH200E5aH801HH5`<05ALF0`0F61L3
01LI60P061PH200J6QX801/K6@P071dG200L71X0200H6A<06AXD01XK5@0K71H071dG01dN600N7aT0
7b0J200P7aX8028R6P809R4K0P0W8Q`302PS7@0902TT7P0[9R00:RDO02TT7P0X8ad09b8L02HQ6`0U
81X091lI00<0:2@H0`0Y9AT202XV6P0902lR700`8ad0<bHP03@W8@0e:280=2LQ03<V800a91h0=RTP
0080=BPO00<0=2LN03<V7@0c9Qd00P0b9A`0300`8Ql0<B@N038U7`0e:200>2/R03X^8P0l<280?C4S
03<W5`0e:AT0>2`L03/_7`80?30P00H0>RhN03T]7@10<b<0?S4Q03`_7`0j;Ad203T/700503/^7P0l
;al0?2XL03d[7@0o;Al00`11;b400`10;R00?bdO03`_7`0203`_7`80>bhN0`0j;Ad0100n:R40?2XP
03`Z800j:Al203LY7P0303DY7@0b:1`0<RPL0080>2LM00<0=RPM03DY7@0d:Qh00P0c:ah0100b;1h0
;RLO02hW7`0^9al502dV7PP0;RPL00@0<2TQ02hW7`0/9Ad0:b@L0P0Z8a/02P0[91`0;2DM02lU700`
9Qd0<RPN03<Y7@0d:a`0<bXI038Y600a:AH203<Y7@<0=2XN0`0e:al01P0f:QX0=b/K03L[6`0h;1`0
>BdM03X^7P80>blO00<0?30P03/_7`0i;Ad00P0h;1`0100i;Ad0>blO03``800n<b4203ha8005040`
8010;al0@BhO04<]7`12;1h00P16=B<01015=280A3<Q048a7`11<1h2040_7@80ASHO00P0B3HP04Xe
801<=R40CcHR050g8`1A=R<0BSPP04Tg7`80B3HN00@0BCLO04/i8@1=>b<0CS`T201;>B<204`j90@0
BcTS0P1<>R@804lk8P0604dh9`1<=bH0BcHU04Xe9019=2<0B3<R0P17<R403P15=BD0A3@T04<c8`12
<R80@30P03h^7P0m;Ad0?2`L04De7014=1/0@c<J048b6@11<AP0@30G0P0o;aH00`10;ad0@C0N044`
7P02044`7P@0@S4O0P13<R000`12<Al0@C0N040_7@0303l^70P0@SDR0P14=Q/01015=A/0AcHL04Lf
701:=Qd204/e7@0504hm7`1=?1h0CC`N04`k7@1;>Q`00P1:>A/01019>1X0DS`U058l9@1B?2D2054k
90<0D3XS0P1?>B80101>>R80BcTQ04/i8@1:>R4204Tk8@0804hh801?>B40D3XR050j8P1?>B40C3HN
04Xd7018<QX504Lg80<0ASHO0P14=1d01P15=Ah0ASHO04Lg8018>240BCTR04Xj8`80ASHO0P17=b00
1018>240BCTR04Xj8`1:>R<304`g8P80BcHQ0`1:=B08048f7P0@04Xj8`1;>b@0Bc/T04/k9019>B80
ASHO04@d7@12<Q/0A3dQ04Hl8@16>R00BCTP04`h801?=R00D3DP054e80<0C3LR0P1;=R4304Xe8080
@c<L00@0A3@M04De7P16=Ql0AcLP0P18>240201=>2D0CSTV050k9P1A?BD0DCdT050l8@1?>b00CS/M
201E>b@00`1G>bD0ESXT05Di8`0205<g8@0:05@h8P1E>B<0ECTS05Hj901@?b40DSlQ05=08P1E@2<0
FD4U05]19P80GD8W1@1D?2@305Dm9@0=050l8`1A?B@0DShU058n9@1A?B@0Cc/R04`h7`1:=Qd0ESXT
05Di8`1D>R<0Dc/S054k8`02050l8`0404dl8P1>?2@0C3XR04/i8@80BCLO00<0BcTQ04`j8P1>?2@0
101A>b@0301B?2D0DcdV05<m9P1D?RL0Dd0R05@o8P1E@2<0F40T05Y09@1L@BH0GT0V05m19`80DclV
0P1B?RD0301A?B@0D3`S050l8`1?>b80F3`W05Lk9P1D>B@0DCPR04li8P1?>b<0D3`T04lm9@<0F3dR
:oooool002[ooooo00P0V6li09Ya>`2LLcl0WG=109idA02MLTD0W75409]`A@<0X7A30P2OLd8309ib
@@<0Vfln0P2LL3l309ea@0030:5eA02PM4<0WW9100<0W70o00@0WG5009ib@@2NMD40WWE10`2MM403
09ac?`P0Wg=2202NMD4809id@P80YGa800<0Y7]70:=jAP2RNDD00P2PMd<0102OMT80WG=109id@P2P
MT@30:5gA@030:1fA02OMD<0WWA20080WG950P2LLD@209]`@`80VVm200P0UV/n09M/?`2HKD00VFi1
09Q]@02FJch0U6Tl09=X>`80T6Hn00H0SFHm08YU>`29I3X0QV<i08AS>023HSL208AQ=`0408=P=P22
GcD0PEhd081M<`80Oe`b00@0Ne/d07UI<P1fERl0Le</0P1aDBX2079B:`0607I@;01eCb/0MDh]07A=
;P1cC2d0LT/^0P1aBBl206i@;P0406e?;@1/CR`0Jdd[06]=:`80JT`Z0P1YBbT206Y<:P0506U;:@1X
BRP0ITPV06E79@1/Bb`00P1]C2d206i=;P0306m>;`1`Cc00L4l`0080NU@]0100NeD^07eG<01nF340
OeTb081J<`21Fc@0OeTd085K=P23GCH0QF0f08IQ=@26HC@0QF4a08AP<02=IcX0S6Hi0`2:I3L00`2<
IST0SVPk08mY?00508iX>`0308mY?02@JSd0T6Xm00<0TfPk0P2BIcX3095V>@0308iY=02=J3<0S6Lb
0080RfHa00<0SFPc08mZ=@2AK3L00`2DJC`509=X>`80VFlm00@0V6hl09M]>`2GKC/0UV`j0P2EJcT2
095]>@80TVhj0P2CKc/209A`?00309ec@@2JL3h0UV`j0080TVPf0P2FK3X00`2JL3h0WG=1095^>002
099]>00309A/>02EK3P0UV/h0080V6Xh00<0V6hl09I/>P2DJSP00P2CJCL00`2DJSP0UV`j09Q^?002
09M^>00609I]>@2FK3X0UV`l09I[?P2GK3l0Ufa10P2JL3h409U_?@80V6hl0P2FLCd309E`?0<0U6lk
102FJch409M/?`P0TVdi00<0Tfhg099]=P2@Jc@00P2?JS<01`2@Jc@0TVdf09=^=`2CKCh0TF/l08iX
>@2;ICH00`29Hc@00`2:I3D0R64f08QQ=P0608QQ=P<0SFTi0P2>JSX308m[>`0309=]?P2BK3d0TF/l
0080T6Xk00<0TV`m09A^?`2FL440202AK3P208mZ=P04091[=`2AK3P0TF`h099]>@80Tfhj1@2<J3P3
08eY>@0608IU;`26IC00QF@_08AS<024HS80Pf4c0P22H3<05P1oGb`0OUh[07eM;01kFb`0NEP[07MF
:`1fEBX0ME@[06e<:`1WB2T0HT<T06549P1RAbX0HdT^0659;`1OAbd0DclT050o8`1??R@0C3`S04Pi
8P14>282044f8007040e8@0`<B40;c0P02l`800^;al0;BhN02`]7@0202//700602X]700Y;1/0:B`K
02P[6P0W:QT09RTH0P0U:1L01P0R9Ah08B@M024T7@0O8Q/07R4J01dP6@8071lH0`0N8AX301lR6`80
82<L0P0N8AP0100O8QT082<J020S6P0Q91/2028U70<08B@M0P0P8a`301lR6`P071hK00H06adL01/M
6P0L7Q/07AlJ01hQ6P0O8QT2020S600N028R6P0S8aT092@J02LW6`0Y:Q`0;2dM02h_7@0`<Al0<BlF
038`5`0c<AX0<c4L038_700a;Qd0;b`K02dZ6`0U:1l092LL02<V6`0S9aT092PI02DY600W;1P0:BhJ
02dW6`0^:1`0;bTM034[7`0c;B40=BlS0P0g<BD203H]700403L^7@0h;ah0>2lN03T`7`80>S4P0`0i
;QX203X_6`<0>c0L00/0=c4Q03H`800e;al0=2hN03<]7@0b;1`0<B/K030Z6P0Y:Q`0:R/M02//7P02
02d^800302//7P0Z:ad0:BXL0080:2TQ00@09bPP02HW7`0U9Qh09BHN0P0T9Ad3028U7P<08B@M0P0P
8a`00`0S9Ql08RDN01lR6`0201hQ6P0401lR6`0P8a`08RDN028U7P80824I00<08B8J02<T700T9Ad0
0`0U9Qh0800K:1L06bHH01`T5`0O8QT08b8N02TS8`0^9BH0<BHZ04<Y4P1A=Ad0HdP[07=F=01mGcT0
QVLk08e^?`2DM4<0UgI0099d@028KSd0M64f061B;@1;AB<0?C`N03Lg6`0`<bX0;c8Y02ha:00]<2L0
;2lV02/^9@0Z;B@0:B`S0P0Y;b<202X`9080:c4U0P0/<RH502la8`<0;S0R0180>CLZ03Pf9`0f=2D0
=SDS03He8@0h=b80>SXR03`l901:>Rd0ASP[04<g:@0n=bL0>SLV03Th9P0f>BH0=cXW03Pg8`0l>bL2
040o:`0403/j9P0h=b<0>3LS03Xi9@<0BClT101:@2D01P1;@BH0CTLZ04i7:P1@AbX0DDHZ05=5:P80
E4@Z01P0ED@Z059=9`1?Ab80CT4O05528@1JAbT0HDT_0657<01O@bd0HD8S06948P1XAR<0KT/U07E>
9@1mDRP0PUHY08IG:@2<IB@0SfPW09E];`2HL3<0VG4f09M^=P2DJc<2095X<P0O099[=02DKcP0UW<k
09Ae?02@MS/0S7@h08Qb=P28MTH0R7=408=^?`20JS/0OFDg07aQ=01lGc<0Nehb08ML:@29GR/0Rf0Y
08iT:P2@IbT0TFPV095Y902@J280VFd/09Q_;@2GL2l0V70b09Qb=02GLcL0UgDh09Md>P0209Ac;00?
09=b;@2@Lc40SW4e08U`>025L3/0Q70n085_?`26K3T0PVTc07iU;`1oIRh0PfXa08A/<021JB/0O6@V
0080PUli00l0PEhf085N=021Gc80PElb085O<@21Gbl0RfDh08]R=02:H300Red[08aM9`2AGRL0UF4W
09UR:@2EI2T00P2FIBX02`2GIR/0V6L/09YY;P2JJBh0VfX_09M/9`2IKRT0Vg0[09ic;P2OM2l0X7D`
0080Wg@_00<0VgH_09eh<@2NNC800`2PNc@0202NNC80WGPa09Uk<`2INc<0WG`e0:1n=`2TOcT0YX4k
0P2YPSd209Uj>P80V7Ti00@0UgPh09Ig=`2FMcL0UGHf0P2FMc@00`2EMSD0U7De09=c=P02099b=`09
095a>02>L3@0Sg4e091b=P2ALcL0T78f08i`=02<KS80RV``0080RFPc0P2:JC@02028Ic80QF@_089Q
;020GbX0NU`h07MI=@1bE300KU0/0P1/CRX06P1^D2`0Ke4]06a@:@1^DR/0LED^07AH<@1eFC80LeL`
075E;P1_Db`0J5DZ06IC:@1SD2H0Gd`T05Y68@1G@b00E40O05<o7P1;?1/0BS/J04Pi6P17>1/0BSXP
04hn9@1C@bX0ETH_0P1GAB405`1GAAl0FDLO05a;801PCb@0He8V06ED:01QCR<0He0U06QC:01[E2X0
KE@[06iB:P1/D2P0JdhV06UC901ZDR@0Je<U06iC9P1`DbL0M5DY07ED:@1fEBX0Me/[00<0MUXZ00<0
METY07AH:01dF2P00P1cEbL02`1dFRL0ME/X07IL:@1gGBX0N5h[07UO;01jH2d0Nf4^07aP<01jGRh0
N5`/0080MUXZ00<0Me/[07QL;01jGRh00P1_E2L0101_E2T0KU<X06eA:@1]DBX206a@:`80IddX00<0
IDdW06A>9`1QCRH00P1OCBD00`1LCB@0GD/U05e;9@0605e;9@P0FDXS0P1GBB@305I88`<0EDLR00P0
DT0J0590701A@Ad0D48O05138@1?A2@0Cd@V04m69`<0DTDU00h0DD@T04m28P1<?al0BC`L04Lj6P18
AB80Ad@S04A18011?Ql0?CTL03Te6P0g<aX0=C4H038d7PL0<C<M00H0;S0J02h`6`0];aX0;2dK02`]
7@0[;1h202XZ7P0602DW700T9Q/092HK02<U6P0R91T08B<H0P0P8QL01P0O8QT07R4H01hQ600M81L0
71lF01/N5@806QdD0`0L7Q/201/M6P<06Q`I100H6QT201LI60X05QPG200B61P201HG6@@05AHH:`0D
5AL8014G5`P03aDE:00D5AL@01DF60P05ALF0`0D5AL301DF60805QLI200F61L801HG6@<05ALF0`0F
61L;01LI60@06QXJ0P0K6a/201`L70/06QXH0`0K6aT201`L6P8071dG0`0M7QP301hO6@<06a`F0P0L
7AL301dN60807QdH0P0O7QT2020O6P808B0K00/0824I024Q6@0R8QX09B8K02LR700Z8ad0:b8M02`S
7P0W8aX0:2@K02XV7@0202/W7P0;02XV7@0X91/09b<J02/T700Z8a/0:B8J02PQ6@0Y8QX0:b@L02dV
7P0_:200200_9A/4034W7@80<RPN0P0c:Al0200f:QX0=b/K03P/700g:a/0=RXJ03@X600b9QH0<2@D
0P0`9aH0100a:1L0<RTH03@[6P0e;1/203H]700303T/700k;Qh0?2lO00<0?S4Q00<0?C0P03`_7`10
;ad00P10;ad503l^70@0@2lM0P0o;Q`203h]6`80@2dN00<0@2dO03l[800o:b800P0n:R<01@0n:B@0
?BXL03/Y6`0k:A/0>RXK0080=bXJ00T0=RXJ03<Z6@0c:QT0>B`S03P[8P0g:R40=RTP03@W7P0c9Qd0
0P0b9A`802dZ6`06030Z700a:A`0<BTL03<Y7@0e:Ad0=bTN0P0i:1h203DU6006038T6@0a91/0;R@K
02`S700[8Q/0:R<M0P0_91h2030U7`80<BHP0P0b9b4203DY6@0403HZ6P0g:a/0>2`L03T]7@80>RhN
0P0h:a/203T/700403X]7@0k;Qh0>bhN03`_7`80=bXI0P0h:aX203T/6`80>RdL0`12<Al00`11<1h0
@2lM03l^700203l^700403`[6@0n;A/0@2lM048a7`80@c8P01d0@S4O044`7P17>b40ACTO04Dg7@14
=Q`0A3@K04Hd701:=Qh0BcLO04He6`18=1/0BSHM04`f7P1@>200DcTR05Di8`1F>R@0Ed8U05E08`1B
?B00D3/N04lj7@1@>ah0DSdP05<n8@1??BL0CC/U04`j900304Xh8P0C04/i8`1<>R@0D3PP054i8@1C
>b<0ECdU05Hn9P1E?BD0Dc/S058j8P1E>b@0DSXR04lg7`1;=Ad0BCDL04Pg7@19>Al0Bc/Q04Lg8002
04Df7`03048f7P10=Qd0?CHL0080>cDK200n=1/9044`7P03040c800n<Ah0?C0M0080>bhK00<0?C0M
03ha7P10<b000P11<1h01012<Al0@c8P04<b8014<b4204Dd8P0804@c7`15=200AS@N04Te7@1;=Ad0
CSHL04lg7@1@=Q/304`h7`0304di801>>R40Cc/R0080Cc/R01/0E3TT05<h8`1B=b80DCHQ058g8P1C
>2<0ECXU05Hk9P1??R@0Cc/R04hj8@1>>200D3PP05<i8P1F>R@0F3`V050o9@1??R@0CSdS04`k8@1;
>R00BCPN04Pg7@17=Q`0BCDL04Xf7@1<>1l00P1=>B001P1<>1l0BSHM04Te7015=200ASDQ04Lf8P80
B3LS00<0ASDQ04@c7`12<Ad02019=al504Pf80<0AcDO0`1<<ad00`1==1h0CSDO04lf800204lf8006
054g801@>200D3PP04dg7`1<>1l0BSTO0P18>1h204Ph7`0304Tg7`1;=al0C3HO0080CSDO00<0Cc@O
04/g7P1;=ah01P1;=ah204Lg7P80ASHM0`15=A`01014=1/0BcLN04di801?>b82054m9003050l8`1?
>b80CSXQ00P0EcdV00H0CClU04dm8`1>?B<0DC`Q05<i7P1D>A`205Lh6`0305Hg6P1H?R<0EcdR00<0
ES`Q00<0F3hS05Y09@1K@BH00P1F>bH00`1D>bD0DS`U054m9@0204lm9@0404hn9@1E?B40EShR05Q0
9080FD4U00<0EclS05Dm8@1D?2000`1D?20205<k7`<0DSXN00P0ED0S05@o8P1A?1l0CcXM04hi701?
>Qd0D3/N054l7`80EC/P00<0E3`P058m801A?R000P1??R00101>?b00EclS05Q0901I@BD205Y29P03
05Q0901F?R80ECdQ00<0F3hS00<0EcdR05Hl8@1E>b000P1E>b000`1E@2<0E3lR058m8002054l7`03
058m801D?b80ED0S00<0CShU:oooool002[ooooo00P0V6li09Ya>`2LLcl0WG=109idA02MLTD0W754
09]`A@80X7A30`2OLd8309ib@@<0W70o0P2MLD0309ib@@030:5eA02PM4<0WW9100<0W70o00<0WG50
09ib@@2MM4001`2MM40809mc@PP0WWE1202NM4801@2TNdL0XgY60:=jAP2RNDD0X7M30080WgI200@0
WWE109ec@@2NM480X7I40`2QMdD00`2PMT@0WgE309id@P0209ebA@80W7540P2KL4<209Y_@P0309I[
?P2GK3l0V6e00080V6e000T0UV/n09AY?02BIcX0T6Hn08mU?@2<IC`0RVDk08UT>P25HSP00P23HSL0
1P24HCL0Pf0f08=P=P22GcD0PEhd081M<`80Oe`b00H0NUXc07QH<@1fERl0Le</079B:`1aDBX2079B
:`0607A@;01cCb/0Ldl]079>;P1aCBd0L4/^0P1_BRl206i@;P0306e?;@1/CR`0Jdd[0080JT`Z00D0
JD/Y06Y<:P1ZC2X0JD/Y06Q::00406M99`0406a;;01]C2d0KD`]06i=;P80Kdh_0P1`Cc0207YD;@0<
07]E;P1mEc00OUPa07mI<P20FS<0PE/d081J=@21FcH0Pedf08EP=P26HCD0QV4d0P25HC400`2=IcX0
S6Hi08]U>00208YT=`0408aV>@2>J3/0SfTl08eW>P<0SVPk0P2?JC`2091Z?@<0TVLj0`2AIST2091U
>00308iY=@2=J3@0S6Lc0080S6Lc00<0SVTe091[=`2AK3P0102CJ3/4099W>P0309Q^?02GKC/0Ufdk
0080UV`j0P2EJcT00`2DJSP0TVdi099]>@0209=^>P80U6lk0P2EL3`00`2KLCl0VFlm09I/>P0209E[
>@80UV`j00<0VFlm09]a?`2BKcT00P2CKST00`2EKCT0UVdi09M/>@0209U[>@0309Q^?02FK3X0UF/i
0080U6Xh00<0UF/i09I/>P2HKS`00P2GKSP00`2GKSX0Ufdk09M]?@0209M/?`0309M/@@2IKcd0VFlm
00@0VFlm0P2HKS`209Ia?@<0UG0l0`2DKc/509I[?P<0Uf`o202BKCT00`2BKCH0TF`e091[=00208mZ
<`07091[=02AK3D0TVdf099/?@2@JS/0SVPi08]U=P0308US=00308YT=@29HSL0RF8g00H0RF8g0P2<
J3P308eY>@<0SVXj00<0Tfdn099/?@2AJc`00P2@JS/00`2BK3d0U6ho09E_@008095/>00308mZ=P2@
JcL0T6/g0080TF`h0P2BKCT00`2CKSX0S6Ph08aX>00408aX>080SFTi00H0QVD_08IU<025I2l0Q6<`
08AR<P23HC<2089P<`0F07mO;01nGRd0OEd/07]K;01iF2/0MeH[07IE;01eE2/0KDl]06Q9:P1RABD0
Gd@V0617:@1QBBd0GdL]05Y5:P1A@2@0D3lU04dm8`1:?280ACTQ04<g8@<0@3DQ0P0_<20202h_7`04
02d^7P0/;Ad0:b`L02//7080:B`K0P0X:aX02P0W:QT09RTH02DX5`0U:1L08RDN024T7@0P8a`07b8K
01hQ6P0M81T201`O60<07R4J0`0O8Q/2020S700301hQ600O8QT07b8I008082<J0P0Q91/00`0R9A`0
8B@M024T7@03020S70<07b8K200L7Q/01P0K7A`071hK01`N6`0M7aX07R4J01lR6@8082<H00T08R8J
02<S6@0U9A/09bLK02X[7@0/;Ad0;RlM02l`7P0b<1L00P0c<AX01P0d<Qd0<c0M034^7@0_;1d0;R/L
02DX7`8092LL00h08bLI02@X6@0V:QT0:2dI02T^6P0^:1X0;bTK030Z700b;1h0=2hP03D_8@0f<280
=c4S03H]7080=bhM0P0h;ah203T`7`0303Xa800h<1/0>30K00<0>30K0`0g;aX01P0d<B00<c0O038_
7P0a;Qd0<2dL02l/6`80;R/J00<0:BXL02X[7@0[;1h00P0/;Al00`0[;1h0:R/M02TZ700202PY8@03
02LX800V9al09BHN008092DM00@08b@L028U7P0R9Ah08RDN0P0Q91d3020S7003028U7P0Q91d07b8K
00807R4J00@07b8K020S700Q91d08B@M0P0P8AT00`0Q8QX08R<K028S6`0202<T700I02@U7@0P:1d0
7RHK01lR6@0O8AH09B8I02hW7@0f;2<0>S0W05Hk7@1TBRT0MU`i08IZ@`2=LTL0TWI709IjB02JO4P0
SVm108=V>P1aFS40GddY05138`12?280>SPQ03He800202lb:@0602ha:00]<2L0;2lV02/^9@0Z;B@0
:B`S0P0Y;b<202X`9080:c4U0P0/<RH802la8`0H03Pf:@0g=BH0=S@U03He8`0g=R80>CPS03`l900m
?BD0Bcd`04Pl;P14>b`0@3TY03`i:00k>RP0>CXX03Tl:@0h=b<0?3/W040o:`0o?RX0>STU03Lf8P0h
=b<0>STU0P19?b@204Y09@0404]19P1<@RL0C48W04e3:080CTLZ00<0D4LZ0556:P1CABX00P1DA2X0
<P1EA2X0EDdX05578`1@@b40Dd<R05]6:@1QBBd0HTH^0694;01YB2L0JdXW071<:01gDBX0OUL/08IK
;P2;Gc00Sf4`08iW9P2@J2X0Tf/]09E]<02EKC80U6/c095X<P2?IS00SfPa099[=02CKSL0Tg<j099c
>P2=LcP0RG4e08M_<`24JC`0PVLj085T>021HSH0PF0e089O=@23H3H0QF0f08UP;02;HR`0SVD]095Y
;P2CJbd0U6d/09A]:P2DKBP0VW4_0P2ILS400`2HLS<0Ug<e09Id=`0209Ad>@80Tg8_00l0T74`08i`
<02<KcD0R6lg08A]>`22K3/0PF`m08M[?023IcP0P6@d089V=025JSD0QV/d08=X<@20IRd00P23GCH0
0`23GS@0Q5lc08AO<P0208EQ<@0908EQ;`2=IC@0S6@c08eS<@2@HRh0TF8/09ER:@2HI2X0VFD[0080
UVP/00X0UfT]09U[;`2JK300Vfda09a^<P2MKc<0Vg0[09eb;@2OM2l0XGHa0P2SN3<20:9g<P0309ii
<`2ONS@0XG`f0080XG`f00/0X7/e09mj=02NNC<0V7/e09Yl=P2KOCL0WWdh0:5n>P2TOc/0YWll0:N0
?@0209al?`80Vg/n0P2JNSd209Ui?00609Mh=@2FMcH0UWLf09Ef=P2DM3L0Tg<h0P2BLST00`2>L3@0
Sg4e091b=P02091b=P0408i`=02<KS80RV``08]Z=@<0S6/f00P0RVTd08MV<@25I2l0Pf8]07aN>P1i
FcL0MELc075C;`80Ke4]00H0L58^079D<01]DBX0KU8[071D;@1aEBh4079F;`0H06aI;P1[F2d0J5D[
06AA:@1QCBP0GDTV05]7901IAB@0Cd4N04dn7@1:>aX0BCXK04Xk7P1=?B<0D40W05=3:P1IARD0FDLS
05Q68P1IAb40FdTQ05e<8@1PCb<0HU4U0P1UDRL03P1YE2T0JU<Y06aC:P1]DBT0K50X06e@:01YDb@0
JU8T06]C9@1^DbH0L5<W07=D:01eE2T0MUDZ101fFRX00`1eFBT0M5PX07AH:00207=G9`80ME/X00@0
MU`Y07MM:P1hGR/0NEl/0P1jH2d03P1lH300NUh^07QL;01gFb/0MUXZ07MK:`1hG2`0NEd]071E9P1`
EBP0Ke@W06iC:01^DRX0KE4Z0P1/D2/206M=:00306E=9`1TCRL0HDhV0080GddU00<0G4dT05e;9@1M
BbD01P1MBbD805U:8`<0EdTT0P1FB2<305E78P0805A2701D@Qh0DT8N0553801@@b40CT<S04i39@1=
A2D20554900>05959@1AA2@0D4<S04e0801;?Qh0BC`L04A17P13@1l0@SlN040m7P0n>Qd0?3PM03/g
7P0j=Qd3038d7P@0<C<M00L0<38L02h`6P0^<1/0;BlJ02`]6`0/;Ad0:b`N0080:RXN0P0U9a`0100T
9Q/08bDJ028T6@0Q8aP2020R5`807b8I00@07R4H01dP5`0L7aH06ahE0P0J7A@301`N6`806adJ0`0J
71T0100I6aX061XI01PJ6@0H6QT201LI60X05QPG200B61P201HG6@@05AHH:`0D5AL8014G5`P03aDE
:00D5AL@01DF60P05ALF0`0D5AL301DF60805QLI200F61L801HG6@<05ALF0`0F61L;01LI600401TI
6@0J6QX06QXJ01XJ6P806a/K0P0L71`;01XJ60806a/I0`0L71X201`M5`<07AhH0`0N7aT201/L5P<0
71dG0`0M7QP201hM60807ahI0P0P7aX2024P6`0;020Q6@0Q8AT08R8J02DR6`0W8Q`0:R<M02/R7@0/
8ah09b<J02PT6`0Z9Qd00P0[9ah01P0Z9Qd0:2@K02LS6P0/9Ad0:b@L02XS6`80:B8J00<0:R<K02`U
7@0]9Qh0200_9A/0100`9Q`0<BLM034W7@0a9ad2038X7P80<bTO00P0=RXJ03L[6`0h;1`0>2`L03HZ
6P0d:1P0<RHF034U5@80<BPG00@0<RTH03<Z6@0d:aX0=B`K0P0f;A`0200i;1`0>bhN03d`800n<B40
?c8R03ha8@0m<200?2lO1010;ad403l^7004044`7P10;ad0@2lM040_7@80?bhL0P0n;A/2040]7P04
040]7`0o:b00?b/R03l[8P80?RXS00@0?BXL03`Z700k:A/0>RXK0P0g:QX0100f:QX0=2/J03<Z6@0h
;20203L[7`0503HZ7P0e:Ad0=2PL03@X700c9a/0200]:Q/01P0`:Q`0<BTL034Y700c:Ad0=BTM03LY
7P80>BPN00P0=RHI03DU600c9AX0<B@K02hT6`0/8a`0:b8K02XS7@80;b@N0P0`9Al2034V8080<RLQ
0P0e:AT0100f:QX0=b/K03P/700i;Ad203X^7P80>2/K0P0i;1`0100j;Ad0>bhN03/^7P0k;Qh303P[
6PD0>B`K0P12<Al2044`7P80@2lM0P0o;Q`0100l:aT0?RdK040_7@12<Al204<b800@048a7`11<1h0
Ac/Q04Di7`16>1h0ACDL04Hd7019=Ad0BcLO04dg8017=Q`0BSHM04/g7P1==al0D3PP05<i8P80ECTS
00@0ET4T05E08`1C?R40DSdP0P1A?1l2058m800F054l9`1@>bH0CSTT04dh8`1<=b80CCPS04hi901?
>RD0D3PP058j8P1D?2@0ECdU05Hn9P1E?BD0E3`T05<k8`1B>240DCTQ04lg7`1==al0BcLN04Xi7`80
BSXP0P17=b000`15=Ql0@SHN040f7@0203df700303/e6`0o<a/0?c<K00H0?c<K2@11<1h00`10<b00
?c8O03d`7@0203`_700403d`7@0o<Ql0@3<P044`7P80@S4O0P13<R0204@c8@0904Dd8P15=200AC@P
04Le7`19=Ad0BcDM04hf701?=ad0D3HK0080C3PO0P1=>B0204hj8@80Cc/R01H0DSTS054h8P1@=b40
CcHP050g8@1A>280DcXT05@k9@1??R@0D3`S04lk8P1@>R80DSXR05Dk901H?2H0FCdW058n9@1A?B@0
D3`S04lk8P1=>B00C3PO0`1:=Qd02@1;=ah0C3PO04di801=>B00C3PO04/g7P1:=Qd0AC@P04He8@03
04Pg8`0304He8@14<al0@c8N00P0BCLO2018=R0204dd7P80CSDO00D0CcHP050g8@1@=b40D3LQ054g
8002050h800304dg7`1<>1l0BSTO0080B3PN0P18>1l00`19=al0BcLO04`f7`0204he7`0304ld7`1;
=ah0BcLN00H0BcLN0`17=ah204Hf7@<0ACDL00P0C3PO04di801?>b80D3`S054m901@?2<0Cc/R04hj
8@P0EcdV00H0CCdT04dm8`1A?B@0DSdR05Dk801F>ah205Pk7@0405Tj7@1I?b@0F3hS05Lm8P80ES`Q
00D0F3hS05Y09@1K@BH0EcdV05Hl9@0205Dm9@0;058l901A?B@0CchT04ln901E?B40EShR05Q0901I
@BD0F40T05Lo8`1E?B40101D?20305<k7`80DSXN00@0ED0S05<n8@1A?1l0D3/N0P1?>Qd2054l7`80
ES`Q0P1E?B401P1C?R40DSlQ050o8@1@?b40F40T05U19@<0FT8V00@0F40T05Hn8P1E?B40FClT0P1H
?R<205Lm8P80ES`Q00@0EC/P05I1901E@2<0E3lR0P1C?R400`1D?b80ED0S05I1900304lo9B_ooooo
000Zooooo`0909Q_>@2JLC/0W7<o09ec@@2NM4@0WG9509aaA02KL4D0X7A300<0Wg=20P2NLT4409ea
@080WW910P2OLd820:1d@`030:5eA02PM4<0WW9100<0W70o00L0WG5009ib@@2KLSh0Vg8n09ac?`2M
M400WWE100<0WgI2202OLd8809mf@PP0WWA20P2QN4@20:1g@`0709mf@P2NMD40WGA009ed@02NM480
WgE30:1fA0030:5gA@030:1fA02NM480WG=10080WG950P2LLD@209]`@`80VVm20P2GK3l209Q]@004
09M/?`2EJSd0TfPk099W>P80SfDm00H0S6Dl08UT>P28HcT0QF8h08=R=`22HCH208=P=P04089O=@21
GS@0P5dc081M<`80Oe`b00@0NETb07QH<@1fERl0M5@]101bDR/01P1dD2`0Ldl[07=?;@1bCRh0LDd]
071;;P80KdX_00H0KU0^06e?;@1]Cbd0K4h/06]=:`1ZC2X206U;:@0306a>;01ZC2X0J4XX0080IDLU
00<0ITPV06U;:@1ZC2X00P1/BbX0101]C2/0KTd/06m>;@1`Cbh2075@;`80NU@]00l0NeD^07eG<01n
F340OeTb081J<`21Fc@0P5Xe089L=`24GSL0QV4g08MR=P27HSD0QV8b08EQ<@2<IST00P2;ICP00`2:
I3L0RfDh08aV>@0208iX>`80SFLj00<0SVPk08mY?02?JC`00`2?JC`3095V>@80T6Dh0`2?I3L208iY
=@<0SFPd00<0SfXf091[=`2AK3P0202AIST0102FK3X0UF/i09E[>@2EJcT309AZ>00309=Y=`2BKCT0
TVdi0080Tfhj0P2DKc/209E`?0T0V6hl00H0U74k09E`>`2EL3/0Uflk09Q_>`2IKS/209]]>`0309Q^
?02GKC/0UV`j0080UF/i00<0UV`j09M]>`2HKS`00P2GKSP00`2GKSX0V6hl09Q^?P0209M/?`0309M/
@@2HKS`0V6hl00<0V6hl0`2IKcd209Ia?@<0UG0l0`2DKc/809I[?PP0TVdi00<0TVdh095/=`2?JSD0
0P2>JC@02@2?JSD0TF`g099]>02AJc`0T6Xk08eW>02;ICH0RV@e08US=00208YT=@P0RfDh0`2;IcL2
08aX>0<0SFTi00P0TV`m095[?02@JS/0T6Xk095[?02BK3d0Tfdn09A^?`P0TF`h0`2@JcL2095/>0<0
TVdi202<J3P01P26IBl0QVD`08ET;`24Hc00Q68b08=Q<`80PV0c01H0OEl]07aN;01kG2d0NEX/07MH
;01eEB`0M5@]07=C;01_DBl0J4/[06=69P1OA2H0GdHX05i6:P1IA2T0ET4V04ln901=?B<0C3`S04Pi
8P14>280@CHR0P0m=B001P0l=240;c0P02l`800^;al0;BhN02`]7@80:b`L00H0:R/K02T[7@0Y:ad0
:2XL02LY6`0V:1X202DW6@0602@V600Q91d08B@M020S700O8Q/07R4J0P0M81T0100L7aP07R4J01hQ
6P0N8AX301lR6`8082<L0`0O8QT2020S6P<08B@K00@08B@M020S700P8a`082<L0P0O8Q/201hQ6PP0
71hK00H071hM01`N6`0M7a`07R0K01lR6`0O8QT2020S600I02<S6`0T91X09RHL02TY7@0[;1h0;BhN
02h_7@0_<1h0<c4J03@b6`0e<ah0=C8O03@a800b;b00;b`M02hZ7P0V9al09RPM02DW700U9aX09RPJ
02P[6P0Z;AX0:bhK030Z7002034[7@0503<]7`0d;R00=BlQ03H`8P0g<B<00`0g;Qd203P_7P<0>C0O
0P0i<Ah0100h<1d0=blL03H^6`0f;Q/203D]6P80<RlP00@0<BhO030]7P0_;1d0;b`M0P0^:a`00`0X
:A/0:BXL02//7P0202`]7`0302//7P0Y:Q`0:2TK00809bPP00<09RLO02DV7P0T9Ad00P0S91`00`0R
8a/08RDN028U7P02024T7@<082<L00<07b8K024T7@0P8a`00`0O8Q/0100P8a`08B@M024T7@0Q91d2
024R6P<0824I0P0Q8QX06@0R8a/08bDR024R7@0P81P0920D02dV500j;a/0ASXR04m19`1/DbX0N60d
08Q`@P2DO4`0VX1?09QnB`2DNdD0TWU307aQ@`1[DS@0E40U04@d6`0m<Qh0>C<S03Dc9P0a<BD00P0^
<BP0100]<2L0;2lV02/^9@0[;RD202X]9080:bhS0P0/;b@202d`9@80;S4V200_<B<03P0g<bL0=c@U
03Ld9@0h=B@0>SLT03`j9@0o?BH0@3hW04a0<018?bh0AC`[048k:@0o>RL0?3TV0P0l>bL0200h=R40
?3XU03lm:00n?2L0>SPS03Pf8@0i=b80>cTT0P19?b@01P1:@2D0C48W04e3:01>A2T0CdDZ0516:`80
CDHY00<0CdHY0515:@1BA2T00P1C@bT04@1D@bT0ET`Y05=99P1CA2<0EDDT05]69`1QB2X0HTLZ06=5
:@1bCRX0ME8/07aF;`23G340Rf8d095W=@2FJcP0V6dh0080TFh^00D0T6`^091/<02?Jc40SVTb08eX
<@0208eX<`0708mZ=@2@KCL0T6li08i_>02;KSH0QV`c08AZ<@02085L;`0;089L;`24Fbl0Qe`a08YO
=02>HCL0TV<i08mV;P2AJ300U6`a09M_<P2ILC<00P2JLc802@2JLc00VgDf09]e=P2HM3H0UW@g09Eb
>02BLST0TG8i091a>P0208i`<00[08e_<@2;KS@0R6he08E/=P21JSP0P6Pj07iX>@27Id40Q6@m089R
>`24I3/0QVLk08MX>P26IcP0Pf@e08=L<@24GC80QElb08IP<@28HS40RF@`08YU<@2:IC00SVDa091W
<@2CJ3<0V6/d09Y[<`2LJc40WF/`09aZ;`2JK300Vfda09a^<P2NL3@0X78f0:5c=`2RM3P0XgDi09mg
<P2PN3<0Xg/f0:Al=`020:Em>0040:Al=`2SNcH0X7di0:1m>@<0XGhj00<0Wg`h09ej=P2KN3@00P2I
O3X0102JNcX0WG/k09ek>`2OO3`20:5k?080WWi10`2MOD0309al?`0809Qi>02GN3L0UgPh09If>@2E
MCX0U7@k09=c>P2CLS`208e`=P<0SW4g00<0SG0f08]^=02:KC<00`2?KST03@2>KCP0SF`g08]Z=@29
J3<0R6Lb07mR>P1mH3P0NE`d07EH<01cERh0M5L_07EH<01fFC400P1_Db/206iB:P0D071D;01bERh0
M5P`07IJ<P1bGC00LE`a071K<01]Ebh0JU@]06MA;01TCB/0Hd`Z05I6901C@b40D40O04dl7P1;>Qh0
C3/Q04hm8`1??BD205U69@0?05Q68P1HAR00FDLQ05]98@1MC240GdhS06UF:`1XEBX0JE@Y06UB:01Z
DBP0K50X06eA:@1_DRX0JE<T0080Je<U00<0KU<V071C9`1cE2P00P1eE2T307IJ:P<0METY0`1dF2P0
1@1eFbP0MU`Y07IL:@1gGBX0N5h[0080NEl/00@0NV0]07]O;`1jGRh0NEd]0`1gFb/0201hG2`0NEd]
075G9P1aERL0L5DV06mD9`1^DbP0KE4Y0P1/D2T206Q>:@0606E=9`1SCBH0H4dU05m=9@1NC2@0G4dT
201MBbD805U:8`0405Q:9@1GBB@0EdTT05M99080ETPS0P1EAb80201GAAl0ET@P05A4801BA240D4<Q
04e28P1<@B<0Bd8S0P1=@R8304m4900;04e28P1;@200BSlO044n6`11?Qd0@3dL040m7P0o>ah0?SXO
03hj8@0m>B000P0c=Al2038d7P80<C<M0P0`<Q`01P0^<1X0;S0K02d_6P0/;A/0;2dM02//7P80:RXN
0P0U9a`00`0T9Q/08bDJ028T6@02024S6006020R5`0O8QT07b8I01hQ600M81L071lF0P0K7QD0100J
7A@071hK01`N6`0L7Q/201/M6P<06Q`I0`0I6aX201PJ6@<05aTH200F61L8018H60805QLI100E5QP[
01@E5`P04ALG200?5ADX01@E5a005AHH200E5aH301@E5`<05AHH0P0F5aT801HH5`P05QLI0`0E5aH3
01HH5`/05aTH0`0I6AT201XJ6P<06a/K2P0J6QP201/K6@<071`J00<07AdK01`M5`0L7AL00`0M7QP3
01hO6@0401/L5P0L7AL071dG01`M5`807AhH0P0N7aT201hM60807ahI0P0P7aX2024P6`0;020Q6@0Q
8AT08R8J02DR6`0W8Q`0:R<M02/R7@0/8ah09b<J02PT6`0Y9A`00P0Z9Qd00`0Y9A`0:2@K02LS6P02
02dV7P0602/T700Z8a/0:R<K02XS6`0[91`0;2DM200_9A/3030V7080<BLM0`0b:1h0200f:QX0=b/K
03P/700h;1`0=b/K03DY6@0c9aL0<BDE0P0d:1P0100e:AT0=RXJ03L[6`0g:a/203P/700803X]700k
;Qd0?C0O03ha800o<R40?S4P03d`7`0l;ah8040_7@<0@C0N0P10;ad303l^7080@BhM00<0@2dN040]
7`0o:b000P0o:b801@0n:R<0?R/M03`Z700l:Q`0>b/L0080>2/K00<0=b/K03@[6P0d:aX0200f:Qh9
030Z7080<BTL00<0<bTM03DY7@0g:Ah00P0i:1h0200g9aX0=RHI03@V6`0b9A`0;bDL02dT7@0/8a`0
:b@N0P0_91h2030U7`80<BHP0P0b9b4203DY6@0403HZ6P0g:a/0>2`L03T]7@80>RhN0`0i;1`303X]
7@80>bhN0`0j;A`303T/6`80>2/J00@0@S4O044`7P11<1h0@C0N0`10;ad01@0o;Q`0?B`J03h]6`10
;ad0@S4O00<0@c8P00@0@S4O04Pj8017>Al0AcLN0P18=Qh02@1:=Qh0CCLP04dg801:>Al0C3PO04di
801>>200DCTQ058h8@0205@h8P0;05Dm8@1F?R80EShR05Lo8`1F?R80ECdQ05@l801C>al0DclW058n
9P1@?2@00`1>>R801`1?>b<0D3`T058j8P1C>b<0E3`T05Dm9@1F?RH00P1E?BD02P1D?2@0CcDN04lg
7`1@>200CcTQ04lk8P1<>b40Bc/Q04Xj8019=b4204Lg800304Df7`12=Qh0@3HM0080?CHL200o<a/9
044`7P80?c8O00@0?S4N03d`7@0m<1d0?S4N0P0o<Ql3048a7`80@c8P0`14<b4204Dd800304Le7`1:
=Qh0C3HN0080CcLM00<0DCLL04`h7`1=>B000P1=>B0304hj8@0304lk8P1@=b40CcHP00<0CSDO00/0
D3LQ058i8`1C>R@0DD0V058n9@1A?B@0DS`T05Dm9@1G?BH0FCdW05Xn:002058n9@05054m901?>b80
CSXQ04di801<>1l00P1;=ah00`1<>1l0CCTP04di800204di800304`h7`1;=ah0B3HP0080BCLQ00D0
BSPR04Tg8@18=R00AcDO04Hd7P0804Tg7`P0B3HP00@0CcHP050g8@1@=b40D3LQ0`1A>2801`1B>B<0
DCLP050h801@>200CCLO04`h7`1:>Al00P18>1h204Ti800304Xh801<>200CCLP0080CcHP00<0D3DP
04`h7`1<>1l01P1<>1l204Tg7`80B3HN0`17=Ad01016=1`0C3PO04di801?>b83050l8`80Cc/R201G
?BH01P1>?2@0DCdT054m901C?R<0EShR05Po8@80FChP00T0FSlQ05To901H?R<0EcdR05Hl8@1G?B80
F3hS05Y09@1K@BH00P1H?2H0201G?BH0EShV05@n9P1B?RD0DCdT04ln901E?B40EShR101G?b<0101F
?R80ECdQ05Dm8@1E?B4205@l80<0Dc/O00D0DSXN05Hn8P1E?B40E3`P05<k7`02058j7P0705<k7`1D
?200FChS05Tn8`1H?R<0EclS05E08`0205A18`0905918`1I?b@0FT0U05]19P1L@RL0Fd4V05Y09@1H
?R<0EcdR0080FClT0P1H?R<405Lm8P0305Y29P1I@BD0F40T0080EclS00<0F40T05U19@1J@RH00`1A
@2H[ooooo`00:_ooool0202HKcT0VW4k09ac?`2MLd40WWA409ebA@2LLD@0Vg150`2OLd8209ib@@<0
WG5000@0WW9109mc@P2OLd80Wg=20P2PM4<30:5eA0030:1d@`2NLT40W70o0080W70o00P0WG5009ib
@@2JLCd0Vg8n09ac?`2MM400WWE10:1g@`80XGQ4202OLd8809mf@PP0WWA20`2OMT800`2NMD40WGA0
09ed@00209ac?`0309id@P2OMD<0X7I400<0XGM500<0X7I409id@P2MLd400P2MLTD209aaA080Vg13
0P2JKd80202GK3l0V6e009Q]@02HKD00Uf`o09AY?02BIcX0T6Dh0P2>I3`01P2;I3/0R6<i08MR>024
HCL0PV4f085P=@80Pf0f00@0PUle085N=020GC<0Oe`b0P1nFc401@1hF340MeL`07IF;`1dE2d0Le</
00<0LU8[00H0Le4/079@:`1bD2d0LDh^071=;@1_C2h206i;;`80KDl]00@0K4h/06]=:`1[CB/0JT`Z
0P1YBbT0201]Cbd0Jdd[06I89P1TAR@0HdDS06I89P1ZC2X0KDl]0P1/BbP0101]C2T0KTdZ071?;01a
D2d2079A;P80NU@]00h0NeD^07eG<01nF340OeTb081J<`21Fc@0PE/f08=M>025GcP0Qf8h08QS=`28
HcH0Qf<c08IR<P@0RfDh00L0S6Hi08eW>P2=IcX0SVPk08aV>@2=IcX0SVPk00<0T6Xm00<0SfTl08iX
>`2AIST00`2@ICP208mT=`80SV<f00<0SfTh08iX=`2>J3L00P2?JCP2091Z>@04095[>P2@ICP0T6Dh
091U>0@0TFHi00<0TVLj09AZ>02DJSP00P2DJSP409=Y=`80U6`i0P2EKCX209I^>`80Ufll00<0UF/i
09M]>`2IKcd00P2JL3h209U_?@0309M]>`2EJcT0UG8l0080UW4l00<0V70l09U`?02JKc`00P2LKS`0
0`2HKS`0Ufdk09M]>`0409M]>`0909Q^?02FKCL0Ufhh09Q_>`2IKcd0VFlo09Q]@02GK3l0UV]00080
Ufdk102HKS`209U_?@80UW4m0`2EL3`309A_>`@0UV/n102EJSd8099]>@03095/>02@JcL0SVTe0080
SFPd00<0SVTe091[=`2AK3P00P2?JCX00`2=IcP0S6Hg08]U=P0308YT=@P0S6Hg0P2:ISH208]W=`<0
S6Ph00@0SFTi091Z>`2@JS/0T6Xk0P2AJc`2099/?@0309=]?P2AK3P0TF`h00h0TF`h0`2=JCT408aX
>00708]W=`26IBl0QVD`08ET;`24Hc00Q68b08=Q<`02089P<`0F07YN;P1iGBd0N5`]07II;@1dEbd0
LUD]075D;01`DR`0Ke8`06M=;01QAbH0GD@U05a59P1IA2L0ED4V054m8P1=?B@0BcdS04Tj8`15>B<0
@CHR03de8P80>S<P00L0>C8P02l`800^;al0;RlO02d^7P0/;Ad0:b`L0080:R/K00H0:B/N02PZ7@0X
:Qd09bTL02HX6`0U9aX202@V6@<082<L00<07b8K01hQ6P0N8AX00P0M81T301hQ6P<07b8K0P0P8a`8
020S6P<082<L0P0O8Q/301hQ6PP071hK00H071hM01`N6`0M7a`07R0K01lR6`0P8aX2024T6@0602@T
700U9A/0:2PN02/[7`0];R00;RlO0P0^;ad04@0d<Qd0=C<N03Db7`0e<R40=34R034]8@0_:al0;BTN
02PX800W9ad09RHL02LW6`0X:A/0:R/K02d^700^;ad0<R`L0080<bdM00<0=2hN03D_7`0e;al00P0f
<20803P_7P80>34O00@0=c0N03H_7@0d;A/0<b`J0P0b:aT202l]8080;R`O0P0]:ah202`Z7@0302PY
6`0Y:Q`0:R/M0080;2dO00<0:R/M02TZ700X:A/00P0V9al0100U9Qh092DM02<T700S91`2028S6`<0
8B@M0`0P8a`201lR6`04020S700O8Q/07b8K01lR6`8082<L0`0Q91d00`0R8a/08B8J020Q6@0201lP
600K020Q6@0Q8QX08B8J02HP800W7a`0:1lF030T500m;aD0CSlN061>9P1ZEb`0OfDb08M]>P2@NDD0
UGi:099lBP29Ld40OFTf07IR;`1RD3`0DD0^03h^7P0c9aT0<b`R03Db:`0`;b/0:b`W0080;C0W0P0/
;bH202/^9@80:RdT0P0/;R<202d_9080;S0U0P0_<BH302la8`@0<38T00d0<C<U03Pb9P0h<R@0>S@V
03/e9@0n>BH0@3/W048m9`13?RP0Ad0]04Dn:`12>bP0?cXV0080?CPT0P0k>B@03P0k=R00?STS044l
9P10>bD0?3LQ03Xe7`0l=b40?cXT04To901:@2D0Bd4V04e3:01>A2T0CdDZ0P1AAb`204a5:00304i5
:01?A2P0DD<X0080DT8X01H0Dd8X05I<:@1GBRP0EdLV05U69@1NAbL0HTPW06E8:01WBBL0NU<Z07mE
;@25G300S6@c099Z=P2IL3X0W7@i09if>`2JN3T0UgDf09Ab=@2@KC<0SV/c0P2>JcD00`2?JcL0RfLc
08YY=00208a[=P0408Y[=@28JC<0QVLa08AU;`80R5`]00/0RU/]08]L;P2?Gc40U64d09QS=`2KISX0
U6db09E^<`2HLS@0VgDg09eg>@0309eg>00809Yf>P2IMcX0Ug@j09=c>P2@LCX0SG0h08Y_>029KSL3
08U/=00708I[=024JC@0PVHf081U=P1oI3L0OV<f089N?P02089N?00E08=O>`24HC/0QF8j08ER>024
HCL0R5h^08UO;`2:H2h0S68`08iU<@2@Ic40TVTa09=Z<P2CIR/0UfX_09a_=02PLcP0XgDi0:9d>02P
LSH0WW0d0080Wg<f00@0X7@g0:9f>@2TN3/0YGTl0P2WNch02@2SO3T0Y7dj0:Io?02WP3d0Z84n0:N0
?@2VOc`0YGhk0:1n?P030:5o?`040:1n?P2MNc/0VgTi09Ug=`80Ug/j00H0V7Xj09Qi>@2JN3T0VWPi
09]g>@2MMcT309]k@0D0VWXo00P0V7Ti09Mh>02GMcX0UWHk09Ee?02DLcd0Tg8l09=b?@80RW0g0`2;
LCP208Y`=`0708U_=P2AL3/0TG0k095`>`2@KcX0Sfhi08e/=`0208a[=P04089U>@20HcL0OF0d07]N
<P80NE``0P1jGC405@1cF2d0LEH[06iC:01]DRL0KU<X079G;01fFc00NEhc07AN;`1dGC40Le``075J
<01_F2l0K5@^06UA;@1WCb/0GT`X05a:9P1HAB@0Dd0P050m7`0204hj7`0G04hj8@1D@B40E44Q05A1
801E@al0F4HP05]98`1NC2@0H4lT06aI;P1ZEb`0JE@Y06QA9`1XCbH0JdlW06eA:@1`Db/0JU@U06]C
9@1/E2H0KU<V071C9`1cE2P00P1dDbP707EI:@80M5PX0P1fG2T207MM:P80N5h[0P1iGb`207YN;P03
07UM;@1hG2`0N5`/00<0N5`/00d0LeTX079H9`1aERL0L5DV06mD9`1^DbP0KE4Y06a@:01ZD2/0JDlZ
06I>:01SCBH0Gd`T0080GT`T00<0G4dT05e;9@1MBbD01P1MBbD805U:8`80F4XU0`1GBB@305I88`0;
05U78@1HAR80EDDQ05=58P1@@b40C44Q04]08P19@240BT4P04]28@1=A2<00`1>AB@02P1<@b80Bd8Q
04A17P13@1l0@SlN044n7`0o>ah0?SXO03di800l>1l203@f800403<e7`0b=1h0<S@N034c7@80<38L
00H0;S0J02h`6`0];aX0;2dK02`]7@0[;1h202XZ7P0602HX7@0U9a`09BLL02@V6`0S9AX08R@I0P0Q
8aP01P0P8aX07b8I01lR6@0N8AP07B0G01`O5P806ahE0`0L7Q/201/M6P<06Q`I0`0I6aX301PJ6@80
5aTH200F61L8018H60805QLI100E5QP[01@E5`P04ALG200?5ADX01@E5a005AHH200E5aH301@E5`<0
5AHH0P0F5aT801HH5`P05QLI0`0E5aH301HH5`/05aTH0`0I6AT301XJ6P806a/K2`0K6aT301`L6P80
7AdK0P0L7AL301dN60<07QlI0`0L7AL201dN60<07QlI0P0N7AP201lN6@8081lJ0P0Q81/02@0P8AT0
8B4I028R6P0U8Q/09b8L02XS7@0[8Qd0;2<N02PT6`0602TU700302PT6`0^9al0;BHN0080;2DM100[
91`802lU6`<0<2HL0`0a9ad2038X7P0903HZ6P0g:a/0>2`L03P/700g:a/0=RXJ03@X600c9aL0=RTI
0080=bXJ0P0h:a/203T/700403X]7@0j;AX0>bhK03d`7@<0?c8O00<0?S4N03d`7@0o;Q`01010;ad6
044`7P<0@2lM0P0o;Q`2044_6`04044^7@10;Ah0@2dO03l[8080?b/R00@0?R/M03d[7@0m:ad0?2`M
0P0i;1`00`0h;1`0=B`K03D/6`0303HZ7080=b/M0`0h;1h8038Z7@06030Z700a:A`0<BTL03<Y7@0e
:Ad0=bTN0P0i:1h203LW6P0603@V6`0c9Qd0<2HM02hU7P0]91d0;2DO0P0_91h2030U7`80<BHP0P0b
9b4203DY6@0403HZ6P0g:a/0>2`L03T]7@80>RhN0P0i;1`603X]7@80>bhM0P0j;A`203T/6`80>2/J
1011<1h4040_7@80?bhL00<0@2lM044`7P12<Al00`13<R001P17>Al0B3PO04Tg7`19=al0BcLO04dg
8080D3LQ00H0C3/Q04hj8@1>>R40CcTQ054i8@1B>24205<g8@0305Dk801F?240FClT0080FT0U00d0
F3hS05Hl8@1D>Ql0ET0X05@n9P1B?2@0DC/S050j8P1A>b<0DS`T05<m9@1C>b<0E3`T0080ECdU101F
?RH02@1>=1d0CcLO058j8P1B?2@0DShU04hm8`1;>b40BSXP04`g8P0204Tg8@0304Lg8015=Ql0@SHN
0080@3HM2012<a`9048a7`80?c8O100n<Ah203lb7`P0@c8P00P0AC@P04He8@17=Al0BSHN04`f7P1?
=ad0D3PN054g70@0CCTP101>>R400`1==b00C3HO04/e7P0204/e7P0404dg801>>240D3XS05509P80
DclV00D0E3hV05Lo9`1I?bP0FShX05/o:@0205<m9@04058l901A>b<0D3XR04li8@80CSPP201=>B05
04`h800304/g7`1:=Qh0BSHN00P0BCLO0`18=R0404Tg8@0304Xh8P1B>B<0DSTS00H0DSTS00H0DCLP
050h801@>200CCLO04`h7`1:>Al204Ph7P80BSXQ00<0BcTQ04di8@1>>2400P1@=b400`1A=R40CCTP
04di800604di8080C3PP0P1;=al304Xf7P0404Te7@1=>B00CSXQ04hj8@80Cc/R0`1@?2<805Lm9P06
058l9@1B?2@0DcdU05Hn901H@2@0FD8S0P1K@R<00`1L@b@0FClT05Pn8`0305Lm8P0305To901K@BH0
G48W0080FcdU00L0FShV05To9P1G?bD0E3lT058m8P1@?240E3`P0080ECdQ1@1F?R8305Dm8@80E3`P
0`1C>al205Hl8@80EC/P00@0E3XO05Dk801E>b00EC/P0P1L?R@00`1J?b@0FClT05Q0900205I19004
05E2901J?b@0Fd0U05a19P80GD8W00<0Fd0U05Tn8`1H?B80101I?b@405Pn8`80G48W101K@BH205a2
9`<0E40U:oooool002[ooooo00P0V6li09Ya>`2LLcl0WG=109idA02MLTD0W75409]`A@80Wg=20P2N
LT4209ea@080W70o00@0WW9109mc@P2OLd80Wg=20P2PM4<30:5eA0030:1d@`2NLT40W70o0080W70o
00X0WG5009ib@@2KLSh0Vg8n09ac?`2NMD40WgI20:1g@`2QN4@0XWU5202OLd880:1g@`P0WWA20`2N
MD4409ed@00309ac?`2OMD<0X7I400@0XGM500<0WgE309ec@@2LLT000P2MLTD209aaA080Vg130P2J
Kd80202GK3l0V6e009Q]@02HKD00UV/n09=X>`2AIST0Sf@g0P2=Hc/01P2:HcX0R6<i08IQ=`23H3H0
PF0e081O=080PUle00@0PEhd081M<`20GC<0Oe`b0P1nFc4307IF;`0307EE;P1dE2d0Le</0080LU8[
00H0LU8/075A:`1aD2d0L4l^06m>;@1^CBh206e;;`80KDl]00@0K4h/06]=:`1ZC2X0JD/Y0P1XBRP0
401]Cbd0JT`Z06I89P1SAB<0I4HT06I89P1[CB/0KDl]06];9@1/C2H0KDdW06m?:@1`D2X0LU8/07=C
;@1dE2h207YD;@0?07]E;P1mEc00OUPa07mI<P20FS<0PE/d089L=`24GST0QV0i08QS>@29I3P0RF@g
08QT=027Hc<0RV@g0080RfDh00<0S6Hi08eW>P2=IcX00P2=IcX00`2;ICP0SFLj08mY?002095[?P03
091Z?@2?JC`0SFLj00<0TFHi0P2@ICP308mT=`80SfTj0P2@JS/4095[?0<0T6Dh00<0TFHi099W>P2B
IcX00P2CJ3/409=Y=`@0U6Xh0P2EJcT209I/>P80Ufdk0P2HKS`00`2DJSP0UV`j09U_?@0209]a?`80
VFlm00<0UV`j09AZ>02FLcd00P2GLSd00`2ILCd0VW4m09]`?@0209e_?@<0V6hl0P2IKcd309Q^?008
09I]=`2GKSP0VG0l09Y`?P2JL400VFi109M/?`2FJd0209I/>P80Ufdk0P2HKS`209U_?@80UW4m0`2E
L3`309A_>`0309M/?`2FJch0UV/n0080UFXm0P2DJC`00`2CJ3/0TVdi099]>@06099]>@03091Z>@2?
JCP0SFLf0080S6He00<0SFLf08mY>02@JST00P2>J3T208eW>00408aV=`2;ICH0RV@e08YT=@P0SFLf
0`2;IcL208aX>0<0SFTi00<0SfTj091Z>`2@JS/00P2AJc`3099/?A00TF`h0P2>JSX208eY>@0:08aX
>02;IcL0RfLg08]W=`26IBl0QVD`08ET;`24Hc00Q68b08=Q<`80PV0c01H0N5d^07ML;@1fFbh0M5T^
079F;P1aEBh0Ke</06iB;@1]Dc00ITh/05m79@1KA2@0F4<T05I39@1@?b<0C3/O04Xk9017>b<0ACTS
048g8`0m=B80>S<P0P0g<Ql01P0f<200;RlO02h_7`0];Qh0;2dM02//7080:R/K00H0:BXJ02PZ7`0X
:Ql09bTN02HX7@0U9a`202@V6`0302<U6P0P8a`07b8K00<07b8K1P0N8AX301lR6`8082<L200P8aX2
020S70807b8K0P0N8AX201dP6@P071hK00H07AlN01dO700N81d07b4L01lR6`0P8aX2024T6@0802DU
7@0W9ad0:RXP02d]8@0^;b40;c0P02h_7@0];Q`203@a7P0703Db8@0d<B80<blS030/8@0]:Ah0;2PO
02XW800202TV7@0502TW6`0[:A`0;R`M030_7@0b<Al01P0e<1d203Ha7PP0>2lN0P0f<200100e;al0
=2hN038/700a:a/2030Z6P80:b/O100Z:Qh202TY7@0302LX6P0Y:Q`0:R/M0080:b`N00<0:R/M02TZ
700W:1X00P0U9Qh202@U7@0402<T700R8a/08B8J024R6P808B@M0`0P8a`301lR6`807R4J00<07b8K
020S700Q91d0100Q91d0800R8a/08B8J01lP600N7aL07b0H020Q6@0R8a/08b@L02dO700_8QX0=bLH
04<a6@1E@B00J5<X07YS<@23K3H0T7Dn091g@@2BN4D0SGM608A_@01dHCH0I5<X05Q9801;?c<0?S@X
038Z7`0^:R40<c0Y03<d;`0];b`09BLT0P0/;bH402/^9@80:RdT0P0/;R<202d_9080;S0U0P0_<BH3
02la8`03030b900a<bD0<C<U0080<S@V00H0>C4V03Xb9@0l=2L0?SLW044j:012>bP204@n:00F03lm
:00n?2L0?CPT03/f8P0j=B40>c@Q03`e8P0m=R<0?CLO040j8P13?BD0@C/S03hh800m=al0@3XR04<m
9@1:@2D0Bd4V04a29`1=@bP0CT@Y04m5:P80D4H[0P1<ABP00`1>ABP0Cd@X0553:0020592:00E05=2
:01GBRX0F4TZ05U9:01LB2L0H4PT06E9901YBbD0KDdW07mC9P23EbX0RUh]091W<`2GKSH0W7@g09ih
=`2ONCP0WX1209]m?`2FN3`0TW<j0080Sg0i00<0T74k095a?P27Ic@00`28J3D01P28Ic@0QfHc08ET
<@26HS00TVLd09=U<`80Tf<b00P0UV@c09UU=@2MIcP0WVPi09Ic<`2GM3@0VGHf09]g>@80W7Pj00X0
VgLk09Yf>P2EMC`0Tg@k095b>`2>LCT0RFhg08I]=`22JcL0PFXf0`21IcH07P20ISD0P6@e07mS=01n
HCD0Of0d07mO=P1oESH0P5Pe089J=`23FcL0Pe`e08AM=025GS<0Qf0e08mQ;`2@HRh0TV@`09AW<02F
JC00VF`a09Y^<@2KKc80VF`[09e`;`2RMC@0YgXi0:Ql?@2WNc`0XgLh0:5e=P80XWTk00@0XgXl0:Ak
?@2UO3h0YWdo0P2WOT000`2TOSd0YGln0:J0?`020:N1@0040:Eo?P2TOSd0Xgdl09il?`<0Wge000@0
WW`o09]i?02IMcX0UgDh0P2CNC`01P2DMc/0UGLk09Ee>P2GM3X0UW<i09Mc>@D0U7@k0`2EMC`0202G
McX0UWHi09If>`2EMC`0U7<m09=b?02BLC`0TW4n0P29L3L308Q_=P80RG0g00D0RW4h099a?02AL3/0
T6lj08m^>@0408i]>00408EY>P23IcP0PFDf07mS=0@0OV8c00<0N5d`07EJ;@1aERT00P1_E2L0101c
F2/0N5d`07]P<`1dG2`207AL;P0=07=K;`1aF2l0KE@/06U?:P1WCBP0IE4/069>:@1NBRL0FDDT05E0
8@1B?B00D3/N04lj7`0204hk7@0?050m7@1C@1l0EdDQ05a:901PCRP0He4Y06YG;01XEBX0Ie8W06I?
9@1WCRD0JdlW06eA:@1`Db/0JeDV0080K5@V00D0Ke@W071C9`1bDbL0Le8W07AC:00307AH:0H0METY
101gGBX407QN:`D0NEd]00<0N5`/07MK:`1gFb/00P1dFRL03P1cFBP0LEHW071E:01^DbH0KE8W06aA
9P1/DRd0JU0[06I>:01RC2D0GT/S05e;8`1NC2@0G4dT201MBbD805U:8`<0F4XU0`1GBB@205I88`0;
05Y88P1JB2@0ETHR05=58P1@@b40C44Q04]08P19@240B48P04U38@1;AB<00`1=AbD204]58`0804U6
8`17A2<0AD8Q048o800o>ah0?3PM03Te700h=1/203Dg8@0403@f800c=Al0<S@N034c7@80<38L00H0
;S0J02h`6`0];aX0;2dK02`]7@0[;1h202XZ7P809RPM00<09BLL02@V6`0S9AX00P0R91T01P0Q8aP0
82<J020S6P0O8QT07R4H01dP5`8071lF00@06ahE01`N6`0L7Q/071hK0P0K7AX301XL6@806Q`K0`0I
6aX301PJ6@P05QPG200B61P201HG6@@05AHH:`0D5AL8014G5`P03aDE:00D5AL@01DF60P05ALF0`0D
5AL301DF60805QLI200F61L801HG6@<05ALF0`0F61L;01LI608061PH0`0I6AT301XJ6PX06a/I0`0L
71X301dM6`8071dG0`0M7QP301hO6@8071dG0P0M7QP201hO6@807b0J0P0N7AP201lN6@8081lJ0P0Q
81/0200P8AT08B4I028R6P0U8Q/09b8L02XS7@0[8Qd0;2<N0`0Y9A`202PT6`<0:BDL00<0;2DM02dV
7P0]9Qh00P0]9Qh202`U7@0302/T700_9A/0;bDK00P0;bDK0`0`9Q`3034W7@80=RXJ0`0h;1`00`0g
:a/0=BTI03@X600203XZ6`@0>b/L0P0l;1d0200k;aT0?30J03hb700o<ad0@3@N03lc7@0n<Q`0?C4K
0P0o;Q`2040_7@03044`7P12<Al0@S4O00<0@S4O0`11<1h3040_7@80@S0J00@0@BlK044^7@10;Ah0
@2dO0P0o:b00100o;1h0?R`N03h/7P0l;1d203X]7@0303T]7@0f;A`0=RdL00<0=b/K0P0h;1`303T]
7@P0<bTM00H0<2XL034Y700a:A`0<bTM03DY7@0g:Ah203TX7P80>2PK00H0=BLL03<V7@0`9Qd0;bHO
02hU7P0]9R0202lT7P80<2DO0P0a9R02038W8@80=BTI00@0=RXJ03L[6`0h;1`0>BdM0P0j;Qh603X]
7@80>B`L0P0k;Qd403X]7080>B`K1010;ad4044`7P<0@2lM00/0@C0N048a7`13<R00A3<Q04Dd8P18
>1l0BCLO04Xh801=>B40CSPQ054h8P02058g8P0604dl8P1?>b80Cc/R050j8P1B>R80DcTR0P1D>280
0`1F>b00F3dR05Xo900205a19P0;05]09@1H?B80Ec`Q05U19`1H@2H0EShT05Dm8`1D?280ECdS05Hn
901G?bD0101E?BD205Hn9P0@05Lo9`1H@2P0D3HO050h801C>b<0DcdU058n9@1??R@0C3`R04Xj801>
>2<0C3LR04Xh8P19=b40AcLP04Df7`80@SHN2013<a`9048a7`P0?c8O2013<R0204He8@0304Pf801;
=al0CCLO0080D3PN00<0DSPM04hj8@1>>R400P1>>R4404di800304`h801;=al0BSHN0080BSHN00T0
C3PP04di8@1?>b<0DD0V05<o9P1D@2L0ET0X05Q0:01I?bP00P1J?RP01@1F?RH0ECdU05Dm9@1D?2@0
Dc/S0080DSXR00<0DCTQ04hj8@1>>R401P1>>R40101@>R80CcTQ04hh801>>20404dg7`P0BCLO0`18
=R000`19=b40BSPR04Xh8P0204/i8`@0DcXT101B>B<01P1A=b00D3PP050h801==al0C3PO04Xi7`80
B3PN0P1;>b800`1<>R80CSXR04li8P02054h8P03058g8P1>>R40CSXQ00H0CSXQ00@0CSPQ04dg801=
=b00CCLP0P1<=Ql204/e7P@0CSXQ0P1?>b82050l8`P0EcdV00H0ECXU05Hl9@1F?RH0EclU05Q0901G
@R<205Q48`0A05U5901J@2D0FClT05Pn8`1G?B80F3hS05To901K@BH0G48W05dm901N?RD0GT0V05a1
9P1J@2D0EclS05@l801@>ah0101D?200101E?B40EShR05Lo8`1G?b<205Hn8P80ECdQ0P1D?20205<k
7`<0ES/P101G?2401P1F>b00GShU05hn9@1M?bD0Fd0U05Y09@80FD4U00T0Ed8U05do9@1N@2H0Gd4W
0612:01O@BL0GT0V05`n901J?280101I?b@405Y09@80GD8W101N@bP205e29`<0Ed8U:oooool002[o
oooo00P0V6li09Ya>`2LLcl0WG=109idA02MLTD0W75409]`A@<0WW910P2MLD0309a`?`80WG500P2N
LT4209mc@P80X7A300<0XGE40:1d@`2NLT400`2LL3l00`2MLD00WW9109ed@00209ed@00309ie@@2O
MT80X7M30080XGQ4202OLd880:1g@`P0WWA2202NMD420:1fA0070:5gA@2RN4H0XGM50:5gA@2OMD<0
WG=109]a?`0209ebA@80W7540P2KL4<209Y_@P0@09M/?`2HKD00V6e009M/?`2EJSd0TfPk091U>02>
HcH0SF<k08aR>P29HST0Qf8h08EP=P22GcD0P5ld07mN<`80PUle00<0PEhd081M<`1oG3800P1nFc40
0`1mFS00M5@]07EE;P0207IF;`0:07EE;P1dE2d0Le</079B:`1`DR`0Ke4[06mA;@1^D2h0KDl]06a=
;P80Jd`_0P1/CR`206]=:`0706Y<:P1YBbT0J4XX06Q::01ZC2X0JD/Y06I89P0206E79@0;06Q::01Z
C2X0K4h/06];901/C2D0KDdV06m?:01aDBX0Le</07AD;@1eEBh00P1jE2d03P1kEBh0OEL`07iH<@1o
FC80P5Xc085K=023GCP0QElj08MQ>P29I3X0RVDi08UT=`29ICD0R6@d0P2:I3L00`2<IST0SFLj08iX
>`0208eW>P0:08aV>@2:I3L0S6Hi08mY?02AJch0TV`o091Z?@2>J3/0SFLj09=X>`<0TVLj0P2AIST2
091U>00508mY?02@JSd0TF/n099/?`2CKD000P2BK3l01`2AJch0T6Dh095V>@2AIST0TVLj09=X>`2D
JC`00P2EJSd0102CJCL0U6Xh09AZ>02DJSP309E[>@0309I/>P2FJST0UVXi0080Uf/j0P2HK3/209U]
?00309E[>@2GKC/0VFlm0080VW0n0P2IKcd00`2GKC/0UF/i09Eb?00209Ia?00309Q`?02IL3`0VVll
0080W6hl00<0V6hl09U_?@2JL3h00`2JL3h02P2IKcd0V6hl09E/=P2GKSP0VW4m09]a?`2KLD40VVm2
09M/?`2EJSl209E[>@0409I/>P2GKC/0V6hl09Q^?080VFlm0P2FLCd309E`?0<0U6lk0P2GK3l00`2F
Jch0UFXm09AY?00209=X>`03099W>P2BKCT0TVdi00H0TVdi00<0SfTj08iX>@2<ISL00P2;ICH0102<
ISL0SVPi08mY>P2<ISL208eW>00508iX>@2=IcP0S6Hg08YT=@29Hc@0202<Ic<208aX>080SFTi0`2>
JSX01@2?Jc/0SVPi08mY>P2@JS/0TF/l0080TV`m00<0TF/l091Z>`2AK3P01`2AK3P3099]>@80TF`h
0`2@JcL01P2?Jc/0SVXj08iZ>P2=JCT0S6Ph08]W=`80RVHf00H0QVD_08IU<025I2l0Q6<`08AR<P23
HC<2089P<`0F07ML;`1fFbh0MEX_07=G;`1aEBh0L5@_06iB;@1^DBl0Je<_06A=:`1MAR@0Ed<R05I3
8`1B@B<0CChQ04Xk7P16>R@0ACTS048g8`0n=R<0>c@Q03Lb7`80=34P00L0<c0O02h_7`0];Qh0;BhN
02`]7@0[;1`0:R/K0080:BXJ00H0:2TQ02LX800W:2009RLO02DV7P0T9Ad202<T70P07b8K0`0N8AX3
01lR6`8082<L0`0Q91/2020S6P<07b8I0`0O8Q/201hQ6P<07B0I200L7Q/0400M7ah07AlL01hP7@0O
8A`082<L024T6`0Q91T08RDJ02DU7@0X:1h0:b/Q02h^8P0`<B<0<34Q02h_7@0];Q`203<`7`0>03<`
8@0b;R80<2`Q02hZ8@0[9ah0:B@N02/V800[9ah0:RHM02/W700]:Ad0<2dN03<`7`0d<B0303Lb7P<0
=S4M0P0e<1`303T`7`80>2lN0`0g;Qd2038_8080<BhO00@0<2dN02l/7@0^:a`0;R/L200X:Ql00`0W
:1X0:2TK02X[7@0202//7P0402X[7@0X:A/09bPJ02DV7P8092DM00<08b@L028S6`0Q8QX00P0P8AT0
100Q91d082<L020S700P8a`201lR6`807R4J00@071lH01hQ6P0O8Q/08B@M0P0R9Ah3024T7@0P02<T
700Q8QX07b0H01lP600P8AT08R<K02HW7`0X:B40>BLI040]701<>200GDHV06mF;P20I3@0SFli09Ae
?02LOT`0UGU908aaA020JD00LUhk065@<P1A@bP0AcTO03Le:00b<2<0;2`P02h`9@0b<b/0<SD/02T^
9`0S:24502/^9@<0:RdT0P0];B<202h^9080;blU0P0`<2H01P0^<280;c4S02la8`0`<R@0<C<U038d
9P80<cDW00H0>c4W03`b9P0o=BT0@CPY04<j:@14?2T204@l9`0<03`l900k>b<0>SPQ03/f800l=R00
?SHQ040h8`13>2@0@CXP04@m8`15?R@0A3dS0P10>Al01014?B<0B44W04]19P1;@BH304a29`<0CD<X
0P1;A2L00`1=A2L0CT<W05129`0205519`0G05919`1EART0FDPZ05e::P1PBBL0HTPS06M:8P1^CRD0
Le8W08MD9@29FBP0T64]09MZ<@2KLS@0WWLd09mj=02ONS<0W89509Uo@P2ENd00TGLn08me?02>Lc`0
0P2>Lch208=W=@0<08IX=P26ISD0QfDe08QT=029Hc@0R68c09Ub>`2HKcT0Ufhh09I[=P2HJSH0VFXf
0P2MJcP0402GMS40V7Ld09Uh=@2IMcL0VGLh09Qf>@2FLcT0UG8h08ia>@2<KSP0RFhg08E/=P20JCD0
OFLe07YV=01iIC<207QQ=@80NF4e00<0Nf0e07aO=@1nGSD00P1oGSD06020E2d0PeL`08IK<@27G340
QU/^08MM;@2:H2h0SF<a09QW;`2IJ300VVT_09a[<02OKc40XG4a0:9b<02SLc40XW8Z0:Ed;`2XNC<0
ZWdi0:^0?02WOS`0Y7dl0:9k>PP0Y7`n0P2QOSh0202ROcl0Xh100:9o?`2POCd0WW/k09ai>@2GMch0
V7Po0P2IND00102HN3l0UWHm09Ad>`2CLcX208ie?00308me?02AM3`0TG8k0080TW4k00<0U74k08m^
>02?KSP00P2?KSP2091_>@80TG0j00H0UGDj09Ad>@2DM3/0Tg8l099a>`2AL3/2091_?080R6lg0`27
KSH01`28KcL0RW4i08]b>P2@KcX0Sfhi08i]>02=K3L00P2<JcH01P2=K3L0SVdh08IZ>025JCL0Q6Pf
089V=0<0PFDc00X0P6@b07eR=@1kH3<0Me`_07AI;01cF2/0MEX]07QM<01kH3<0Med/0P1hGBh05@1g
G2l0M5T^06mC:`1[CbP0J4`U06YD;@1XDR/0IDlZ065::01MARH0FD8S05M08@1F?R80BcLL04`h7@1>
>ad0DChN05E28@1JB2@0GddY069@:P0206AA9P0706E@9@1VCbD0IdhU06]?9`1/D2P0KU4Y06aF9`02
06eE9`0306mD9`1`DbL0LU<W0080Le8W101dF2P307EI:@80MUXZ101gGBX407QN:`0307QL;01iGBd0
NUh^0080NUh^01<0N5`/07MK:`1fFRX0MUdW07EL9P1dFRL0LUPW071E9P1_E2L0KE8U06eB9`1]Dbh0
Je4/06I>:01QBb@0GDXR05a:8P1NC2@0GDhU00P0GD/U201IBR<205U;9P80F4XU0`1GBB@0301FB2<0
FTPR05U78`1FAR80E4HS05548P1=@R80C44S04Y18P19@b40BT@R04a690<0CDLU00X0BdDS04Y48P1;
B2D0BDHU04I38P13@240?c/N03/g700h=1/0=c<J0P0f>280300e=b40=3HP038d7P0a<ad0<38L02la
6`0^<1X0;S0K02d_6P0/;A/0;2dM02//7P80:RXN00H09bTN02HX7@0V:1d09BLL02@V6`0S9AX2028T
6@06024T6`0P8aX082<J01lR6@0N8AP07B0G0P0L7aH301`N6`806adJ0`0J71T301XL6`806A/J0`0H
6QT801HH5`P04QPH0P0F5aT401DF62/051DG200A5aL800lE5BP051DG400E5QP801DG5P<051DG0`0E
5QP201HG6@P05QPG200F5aT301DG5P<05QPG2`0G6AP301PH60806ATI0`0J6QX901/K6@<071`J0P0M
7A/201hN708071dG0`0M7QP301hO6@<07AhH0P0N7aT301lP6P807QdH0P0O7QT2020O6P808B0K00/0
824I024Q6@0R8QX09B8K02LR700Z8ad0:b8M02`S7P0Z9Qd0:BDL02PT6`0202LS6P0602PT6`0Y9A`0
:RHM02XS6`0[91`0;2DM0`0^9al202dV7P/0;bDK0P0`9Q`3034W7@0303DY6@0f:QX0>2`L0080>BdM
00<0>2`L03HZ6P0e:AT0200m:ad00`0k;aL0?30H03hb6P03040d7080?S8J0P0o;Q`01010;ad0@C0N
048a7`12<Al204<b80<0@S4O0P11<1h3040_7@06048`6012<1X0@S0J044_6`11;Qd0@2dN0`10;Al2
03l]7`0403d]7P0k;Qh0>bhN03T]7@80=bhM200i;Q`803HZ7P06030Z700a:A`0<BTL03<Y7@0e:Ad0
=bTN0P0i:1h203TY700303HX7@0d9ah0<BLN0080;bHO00<0;BHP02lT7P0_91h00P0`9Al2034V8080
<RLQ0P0e:AT0100f:QX0=b/K03P/700i;Ad203X^7P80>bhN0`0j;Ad303T/7080>B`K0P0j;A`203/^
7@80?2lN00@0?bhL040_7@10;ad0@2lM0`11<1h00`12<Al0@C0N044`7P02044`7P0:048a7`13<R00
AC@R04He8`18=Qh0BcLO04di8@1?>B80DSTS05<h8`80E3PS00d0CC`R04lk8P1?>b80DC/S05<k8`1E
>b@0ESXT05Lk9@1J?280FcdS05`n901M?bD0GT0V0080GClU00X0G3hT05a29`1K@BH0FClT05Pn8`1G
?B80F3hS05To901J@2D0EclW0P1F?RH01P1E?BD0EShV05Lo9`1H@2P0FD4Y05@j8`80E3`T00<0DcdU
054m901>?B<00P1;>b401P1?>B@0CSPS04dh8`1:>280BCLQ04Lg8080ACHO2015<ad9048a7`0303ha
7P0o<Ql0@3<P0080@C@Q00<0@3<P03lb7`0n<Ah00`14<b4204<b80<0@S4O00T0ASDQ04Lf8P18=R00
BcLO04dg7`1@>1h0DCTO058h7@1?>b800`1>>R4304di800304`h7`1;>B40BSPP00<0BCLO00T0BcTQ
04dk8`1>?2@0CchT058n9@1D@2L0ET0X05Q0:01I?bP00P1I?BL205Lm9P80ES`U0P1E>b@205@j8`03
050l8`1?>b80CSXQ00<0CSXQ00D0Cc/R050l8`1D?2@0Dc/S054i8@03050h8080DCTQ2019=al01P17
=Al0B3HP04Pf8019=b40BSPR04/i8`80C3XT0`1C>R@2058i8`<0DCPR00H0DCLP050h801@>200CCLO
04`h7`1:>Al204Ph7P80C3`S00<0CC/S04lk8`1@>R<00P1B>B<00`1C>2<0Cc/R04lk8P0604lk8P04
054h8P1@=b40D3LQ050g8@80CcHP0P1>=Al0201?>b80CSXQ04hj8@1=>B00CSXQ04lk8P1@?2<0DCdT
201G?BH01P1G>bH0Ec/U05Lm9P1G?bD0ED0S05E28P80ET<R00<0E4@R05Y09@1I?b@00`1H?R<0301J
@2D0Fd4V05e3:01P?R<0HClT06119@1P@RH0G44T05Po8@1D?Ah0DS/L05@l80<0Dc/O00@0E3`P05Hn
8P1G?b<0F40T0`1F?R8205Dm8@<0E3`P0P1G>Al0101I>b40FS`R05Xl8P1J?28205Tk8@80GcdT00@0
GCdT05`n901J?b@0FClT0P1H@2@0201N?RD0GclV06109`1Q@BP0H40W05lo9P1M?B@0G3`S0P1I?b@2
05Y09@@0Fd4V00<0GT0V05m19`1P@RP00P1Q@bT00`1P@RP0Gd4W05i09P0305Y392_ooooo000Zoooo
o`0809Q_>@2JLC/0W7<o09ec@@2NM4@0WG9509aaA02KL4D209ib@@80WG501`2LL3l209ea@0<0WW91
00<0XGE40:1d@`2NLT400`2LL3l00`2MLD00WW9109mf@P0709mf@PP0Wg=2202PMd<809id@PP0WgI2
00@0X7I40:5gA@2RN4H0XWQ60P2PMT@00`2NM480W79009]a?`0209ebA@80W7540P2KL4<209Y_@P<0
V6e000/0Uf`o09EZ?@2BIcX0Sf@g08eR=@2<HSX0Rf4i08QQ>026HCL0Q5le085N=00207mN<`06089O
=@21GS@0PEhd081M<`1oG380OU/a0P1mFS000`1cDb`0M5@]07EE;P0207IF;`0907EE;P1cDb`0LU8[
06mC;01^DR/0KU8]06e@;P1/Cbd0Jdh^0080JTd_0P1/CR`00`1[CB/0JT`Z06U;:@0206Q::0D0IdTW
00`0J4XX06U;:@1ZC2X0JT`Z06];901/C2D0KDdV06m?:01aDBX0Le</07EE;P1fERl207YD;@0<07]E
;P1mEc00OUPa07mI<P20FS<0PE/d08AN>@25GcX0Qf4j08UT>P2:ICT0RVDh0P29ICD00`29HcH0RV@g
08aV>@0208iX>`0608eW>P2<IST0RfDh08YT=`2<IST0SfTl0P2BK3l00`2AJch0SVPk08aV>@0409AY
?080TfPk0P2BIcX0202?J3d0T6Tn099[@02CK440U6e209=/@@2BJd00TFXo0P2BIcX0102CJ3/0U6Tl
09EZ?@2FJch209M/?`0309AZ>02EJcT0UF/i0080UV`j0P2GKC/00`2HKS`0V6Xi09QZ>@0209U[>P80
VV`k0P2KKC`209M]>`D0V6hl0P2GKC/01P2DLC/0UG0k09E`>`2GKc/0V6lk09U^>`80Vfdk00<0V6hl
09U_?@2KLCl00P2LLT002`2KLCl0VFlm09Q^?02EK3H0Ufhh09Ya?@2LLT00W79209Y_@P2GK3l0UFXo
0080U6Xh00H0UF/i09I/>P2GKC/0V6hl09U_?@2JL3h209Ia?@<0UG0l0`2DKc/209M/?`0609I[?P2E
JSd0U6Tl09=X>`2BIcX0TFHi202BKCT00`2>J3T0SFLh08aV=`0208]U=P0608aV=`2=IcP0SVPi08]U
=P2<ISL0SFLh0P2>J3T00`2<ISL0RfDf08US=00808]V<P80SVXj0P2?Jc/4091/?00308eW>02>J3T0
T6Xk0080TV`m00<0TF/l091Z>`2?JCX0202AK3P00`2CKSX0TVdi099]>@02095/>080T6/g00l0SfXf
08m[>`2?Jc/0SVXj08eY>@2<J3P0RfLg08YV=P29ICD0QVD_08IU<025I2l0Q6<`08AR<P23HC<00P22
H3<05P1eGC40M5``079I<01aF2l0KeH^06eC;P1/DRl0Je4^06QB;@1RBbT0FDDR05E28@1C@b80DD8S
04dn8@18>Qd0@cPR04<h900o=b80?3DR03Pc800d<B02038_8005030^7`0];Qh0;BhN02`]7@0[;1`0
0P0Z:a/202TZ6P809bPR00@09RLQ02DV800T9Al092DO0P0S91h201hQ6PH07b8K0`0N8AX301lR6`80
82<L00<08RDL024T6`0Q91/00P0P8aX201lR6@0301hQ600O8Q/07b8K00807R4J100M81T801`N6`06
01dO7P0N81d07R0M01lQ700P8a`08B@K0P0R9AX02@0V9Qh0:BTO02d]8`0`<2@0<C8T030a8@0^;ad0
;2dK034^7@02034^7`06030/800^:Ql0:bLN02PS7@0V8A/0:bHP0P0[9ah01@0/:1d0;RXN034^7`0d
<B00=S<R0080>C@N00@0>3<M03Lb700f<A/0=S4K0P0e<1X00`0j<B00>C0O03T`7`0203P_7P80=bhM
00@0=RdL02l]7P0_;Ah0;bdN1@0^;1d302DX7@D09RTN00<09bPJ02PY6`0Y:Q`00P0Z:ad0100Y:Q`0
:2TK02LX6P0T9Ad202<T7003028S6`0Q8QX0824I00807b0H0`0P8a`201lR6`<07R4J00@06ahG01dP
6@0O8Q/08B@M0`0R9Ah2024T7@0P02<T700Q8QX0824I01lP600Q8QX09BHN02X[8`0];RH0BcHK05Hn
8P1UC2d0Me/d08MX?02AKcl0UW<m09Qc?02INTh0S6m507aP>`1[E3D0GTXb0550<014=RT0?2lV02da
800/<1l0:blN02T`800Z<B40:30Q02L_800U;Ah602X]9080:bhU0P0_;2<2030]9080<BhU0P0b;bH0
1@0^<280;c4S02la8`0`<R@0<S@V0080<cDW01T0=3HX03dc:@0n=2P0@CL[04<j:`14>bX0A3`Y04<k
9P12>RD0>ShS03Xm8P0l?280?C/R044k8`14?2D0B3dW04/o:@13?280ASlU04M09P15?R@0@S/Q04<l
8P17@2H0C4D[00<0C48W00D0Bd4V04Y09@1:@2D0BT0U04To900204Y39P0304a39P1=@RH0Cd4V0080
D40V01T0DD0V05=2:01IABX0GTTZ069::01UBB80Jd/R079A901iEbT0SUTW099O:P2HIbl0WFlc09mf
=02QNc@0XGdc09mn<@2EOCl0U7a0099j?P2?MSd0SG@l08]b?02:L3d0RFll0080PFLd00@0PVHd08IV
=@27ICD0RV@e0P2=I3H0602EMCP0Tg<f09Ab=@2CKc<0UFhc09I^<`2HL3D0VW0f09Eg;`2FN380UWLd
09Ef=@2CLcH0T70e08i^=@2<JcD0QFXe08=Z=021Ic@0OFHd07YT<`1gHS<0Lf4a079P<P80LE/d02D0
LU/b07AK<`1gFc@0O5`e07iM=020GCD0PU`e08EI:029GB`0SF8_08iS;P2<HBX0SF<Y095W;@2FK300
Wfdb0:1^<@2QKc80Xg4b0:Ac<@2VMC80YgHa0:Qg<P2YN2`0ZgX^0:al<P2[OcP0Zh0k0:N0?@2TOSd0
Xgdl0:J0@@2UOd00Y7ho0:=m?P2RO3d0XG/l0080X7Xk0P2NNc/209ml?00709ej>P2KN3P0VGHf09Md
=02@LCX0TG8k099c?00209=d?@04099c?02@LCX0Sg0i08Uc>P80Rg8j00<0S74j08ma>`2@LC/00P2A
L3/00`2=K3L0SVdh08i]>00208m^>@80T6lj00L0TG0k09=c>02BLST0TW8i095`>P2@KcX0Sfhk0080
SV`l00<0QVli08E^>024KCL00P24KCL01P26KcT0R74k08Yc?@2>KCP0S6/f08]Z=@80RFPc00@0RVTd
08]Z=@2<JcH0QV/d0P25JS<00`24JC80PfPa08=X<@02089W<008089W>01oI3D0O64b07UN;`1hGBh0
Me`]07QM;P1iGRl207aR<@0?07eR<`1kH3<0N5db079F;P1/D2P0JDdV06]E;01ZE2d0J58[06E?:P1R
BbT0GdPX05e69`1KA2D0Cc/R0080Cc/P00X0D3dO05=0801F@b80FDLS05]99@1MBQl0GT/P06=>8`1V
CbD0J4lV0P1[CbL01`1/CbL0K5HW06eE9`1]EBL0Ke@W071C9`1bDbL00P1bDBH307=G9`80M5PX00@0
METY07IJ:P1fFRX0MUXZ101hGR/407MM:P0807QL;01iGBd0NUh^07]O;`1jGRh0NEd]07MK:`1eFBT2
07MN9P0>07EL9P1cFBH0LELV06mD9@1^Db@0KE8U06iD;`1[DB`0IThX065;901LBB40G4XR05e;8`1M
CRD805e;9@P0FDXS0`1IBbH205Q:9@<0EdTT00P0FDLQ05U78`1FAR80E4HS05548P1>@b<0CD8T04a3
9080BTHS00h0C4PU04e99P1<B2D0BdLT04Y68`18A240B4DR04M48`15@R40@SlP040l7`0m>Ah0>cLN
03Xf7@80=cTS00`0=SPR03@f800b=1h0<C<M030b700_<A/0;S0J02h`6`0];aX0;2dK02`]7@0[;1h2
02XZ7P809bTN00@09RPM02DW700T9Q/08bDJ0P0R91T2024T6`04020S6P0O8QT07R4H01dP5`8071lF
0`0L7Q/201/M6P<06Q`I0P0K7A`201XL6`<06A/J00<061XI01HH5`0F61L01P0F61L8018H60805QLI
100E5QP[01@E5`P04ALG200?5ADX01@E5a005AHH200E5aH301@E5`<05AHH0P0F5aT801HH5`P05QLI
0`0E5aH301HH5`/05aTH0P0G5aL201PH60<06ATI00<06QXJ01`L6P0L71X02@0L71X201dM6`<07QhL
0P0L7AL301dN60<07QlI0P0M7QP201hO6@@07b0J0P0N7AP201lN6@8081lJ0P0Q81/02`0P8AT08B4I
028R6P0U8Q/09b8L02XS7@0[8Qd0;2<N02/W7P0Z9Qd0:2@K00809b<J00L0:2@K02XV7@0[9ah09b0H
02TR6P0/9Ad0;RLO0080<2TQ0P0_:20802lU6`80;R@J0P0_9A/3030V7004034W7@0e:AT0=RXJ03P/
7080>BdM00<0>2`L03L[6`0f:QX0100n;1h403d[7@0803``600m<AT0?c<K040d7011=Ad0@3@L03lc
6`0n<QX203l^7004040_7@11<1h0@S4O04<b8080A3<Q0P13<R02048a7`<0@C0N00<0@2lM048`6012
<1P00P12<1X01@11;a/0@BhM040]7P10;Ah0@BhP0080@2hP00@0?RhO03`_7`0l;al0>RhN0P0h;ah0
1@0l<Ad0>c0L03/`700j;a/0>BhJ0080>2dI00<0=b`H03PZ7`0h:Ql01P0h:Ql01P0`:Q`0<BTL034Y
700c:Ad0=BTM03LY7P80>BPN0P0j:Qd00`0g:Ah0=BPO038X7`02030W800302hW8@0_91h0;b@N0080
<2DO0P0a9R02038W8@80=BTI00@0=RXJ03L[6`0h;1`0>BdM0P0j;Qh303/^7P0303X]7@0i;1`0>B`L
0080>2/K00P0=bXI03P[6P0i;1/0>RdL03`_7P0m<1l0?S4P03lb8@80?bhL0P10;ad2044`7P@0@S4O
01@0@C0N040_7@11<1h0@c8P04He8`17=R@0BSHN04/g7`1>>240DcXT05Dj9@1F>RD0ECTT05Hg8`1;
>R00CSXQ04lk8P1A>b<0E3`T05Lm9P80FCdW0P1L?R@205/m8`0705`n901M?bD0Gd4W0612:01OA2L0
GD8U05a1900305Xo8P0@05]08`1L@B@0F40X05Lo9`1F?RH0ECdU05Hn9P1G?bL0FD4Y05]3:`1J@2T0
F40X05Dm9@1A>b<0Cc/R04`k8@80Bc/Q0P1A>2@00`1>>2<0C3LR04Tg8@0204Lg800304Df7`17<Qd0
Ac8M00H0Ac8M2@13<R000`0n<Ah0?c8O044d8@02048e8P04044d8@0o<Ql0?S4N04Dd8P80A3<Q0P13
<R02048a7`09044`7P17=R80AcHR04Tg8@1<>200CSPP050h7P1A>Al0DSPM0080Cc/R0P1>>R4204di
8080C3PO0100C3`S04/k8P1:>R40BCTP04Xj8@1;>b80CCdT04hn9@1>?B<0DCdT05<o9P1E?bL0F40X
05Pn9`1H?2H0Ec/U0`1H?2H305Lk9@80ESXT00<0DCdT050l8`1?>b800P1>>R402`1?>b80D3`S054m
901E?B<0E3`R058j801A>Al0D3PN054i7`1B>R00Dc/Q00P0BCLO00D0AcDO04Pf8018=R00BCLQ04/i
8`0204`j900504dk9@1B>B<0DSTS058i8`1A>2800P1@=b4204lf8006054g801@>200D3PP04dg7`1<
>1l0BSTO0P18>1h204dm900304hl901@?2@0DC/T0080DcXT00<0E3TT050l8`1@?2<01P1@?2<3054h
8P80D3LQ0`1?=R0204lk8P<0CCTP00<0Cc/R054m901B?RD0201G?BH01P1K>RL0FS/V05Pl9P1G?B@0
E3lR05=080<0D48O00<0Fd4V05Y09@1I?b@00P1H?R<03@1J@2D0G48W05e3:01Q?R80HT0T06A29P1R
@bH0H4<U05Xo8@1E?1d0DSTJ05@l801C>al00P1B>Qh0101C>al0ECdQ05Q0901I@BD405Hn8P80ECdQ
0P1D?2002@1F>1h0EcTO05Tk8@1K?B<0G3hT05/m8`1J?280FC/Q05lk8`0205hl8`0305`l8`1K?B<0
FChS0080F3hS00<0HClV06909`1S@BP00P1S@BP0101Q?bH0H3hU05hl8`1I?b@205Y09@80Fd4V0P1L
@RL0101M@bP0GClU05i09P1O@BL20612:00305m19`1N@2H0GClU00<0Fd@T:oooool002[ooooo00P0
V6li09Ya>`2LLcl0WG=109idA02MLTD0W75409]`A@80WW910P2MLD0309a`?`@0Vfln0P2LL3l309ea
@0030:5eA02PM4<0WW9100<0W70o00<0WG5009ib@@2PMd<00P2PMd<309mf@P80WWE1202OLd880:1g
@`P0WWA20`2OMT840:1g@`030:5hA02QMdD0XGM50080XWQ60P2PMT@00`2NM480W79009Y`?P0209eb
A@80W7540P2KL4<209Y_@P<0V6e000D0Uf`o09EZ?@2BIcX0Sf@g08eR=@0208]Q>@0608QQ>026HCL0
Q5le085N=01oGS<0OUdb0P21GS@2081M<`0B07mL<P1nFc40OEX`07eJ<01cDb`0M5@]07EE;P1gEc00
MUH_07EE;P1cDb`0LE4Z06mC;01^DR/0KU8]06e@;P1/Cbd0Jdh^0P1ZCBl206a>;00406]=:`1ZC2X0
JD/Y06Q::080IdTW00@0IDLU06I89P1XBRP0JD/Y0P1ZC2X206U;:@0806];8P1/C2<0KDdT06m?9P1b
DRT0M5@[07EE;01fERd207YD;@0A07]E;P1mEc00OUPa07mI<P20FS<0PE/d08AN>@26H3/0R68k08YU
>`2;ISX0RfHi08YV=P29ICD0RF<f08YT=`2<IST00`2>J3/02P2<IST0RfDh08US=P2<IST0SfTl099/
?`2CKD00TF/n08iX>`2<IST209I[?P80UFXm0P2DJC`209=X>`0808mX?@2@JCh0TV]009A]@P2EKT<0
U6e2099[@02AJSl209=X>`0309AY?02EJSd0UV/n0080V6e000@0VFi109E[>@2EJcT0UV`j0P2GKC/0
0`2HKS`0VFlm09U_?@0209QZ>@80VF/j0P2JK3/209]]?080V6hl1@2GKC/209Q^?00609=`>P2DKcX0
U6lj09I^>P2GKSX0V6dj0P2JK3X00`2HKS`0VFlm09]a?`0209ab@00C09]a?`2IKcd0V6hl09E/=P2G
KSP0Vg8n09ec@@2MLd<0Vg1309M/?`2EJSl0TfTg09AZ>02EJcT0UV`j09M]>`2HKS`0VFlm09Y`?P02
09Ia?@<0UG0l0`2DKc/209M/?`0409I[?P2EJSd0TfPk099W>P80TFHi202BKCT00`2>J3/0SFLj08]U
>00208YT=`0608]U>02=IcX0SVPk08YT=@2<ISL0SFLh0P2>J3T00`2=IcP0RfDf08US=00808YU<080
Sf/k0P2@K3`2095]?@80TVhn00<0S6Hg08iX>@2@JS/00P2BK3d00`2AJc`0T6Xk08mY>P08095/>080
Tfhj00@0TVdi095/>02AK3P0T6/g0P2?JSH208m[>`0308iZ>P2=JCT0S6Ph0080RVHf00L0RFDe08IU
;`26IC00QF@_08AS<024HS80Pf4c0080PV0c01H0Le``079K;`1aFS00KeP_06eE;`1/E300JU8^06UA
;`1WDB`0Gd/X05U58P1E@R40Dd<R05528`1<?R40BC/N04<h9010>2<0?SHS03/d8P0g<B40<c0O0P0a
;b001P0`;Ql0;BhN02d^7P0/;Ad0:b`L02X[6`80:BXJ00H0:2TI02LX8P0W:2809RLQ02DV800T9Al2
02<T7P04028S7@0N8AX07R4J01hQ6PD07b8K0`0N8AX301lR6`8082<L0P0R9A`0100Q91/082<J020S
6P0O8QT201hQ60807b8K0P0N8AX301dP6@0301`O600L7Q/071hK00H071hK00H07R0O01hP7@0O8Ah0
7b4L020S700Q91/2028U6P0802HV7P0Y:Al0;BdS034a9@0b<bD0<C8R02h_7@0/;A/2030]7P07030/
800_:b00;BTP02XU7`0W8Q`09B0L02dV800202dV7P0602hW7@0`:Qh0<bdO03H`800h<R80>SDO0P0i
=1h00`0h<ad0=c8L03Ha6`0203D`6P80>S4P00@0>C0O03P_7P0h;ah0=bhM0P0f;A`302d[7P80;R`O
0`0_;B000`0T9ah09BPO02DX7`0302DX7`809RTP00<09RLI02PY6`0Y:Q`00P0Z:ad00`0Y:Q`0:2TK
02HW6@0202<T70808R<K00@08B8J020Q6@0O81P07b0H0P0P8a`301lR6`<07R4J00@06ahG01`O600O
8Q/08RDN0P0S9Ql01@0R9Ah08B@M024T7@0S91`08B8J0080824I01@08b@L02LX800];RH0<34Y05U2
801TC2P0Me/d08MZ@02CLd@0VGE309Mb?@2GL3T0T6i8085P?@1/Cc40FD4Y04`i:P14<b/0>bdZ03@X
:080:C8M00H0:34L02D^6@0R:aH08R/F02D^6@0X<Ah202T/8`@0:RdT0P0[;RD202l/8`80<2dT0P0a
;RD2038_9P0602h`8P0_<B<0;c4S034c9@0b=2H0<cDW0P0d=RP05010<bX0@SHZ04@h;016>R`0ASXZ
04Hk:@14>BD0@cPT03e19P0l@2D0?clU044o9P16@2P0C44[0514;P1CA2l0AcdR04To901;@BH0BClT
0P16?240201;@BH0D4H[04e3:01<@RL0Bd4V04Y09@19?b@0B3hS0P17?B8204Y39P0304a39P1=@RH0
Cd4V0080D40V0140DD0V05919`1HA2T0GTTZ069:9P1UBB80K4dQ07AD9@1lFRX0UEdZ09MR;02MJc00
XG<e0:=k=P2TOSD0XH0c0:60<@0208eg>`0V08af?02:M3/0R74k08I_>@24KCT0Pf`h07iW=@20ISD0
PVHf08EU=P29I3L0RfDh08iU>@2@ICX0SWDe08mc=02=LC80SW0b08m_<P2BL3<0UG4e09Ib=P2EMbh0
UGL_09Eg<@2CM3<0T70c08e]<P29J380QfH`081W<@1mIS80Nf@`07QR<01eHBl0LEl_06mN<01^GBl2
06aH<`0506iH<`1aFC<0MUXc07]K=@1mFcD00P22G3D08@2;GRL0T6<Z09EX;`2FJBh0TfLZ09AX:@2I
KB`0WW8a0:A`=02ULS<0YW<d0:Md<`2XMC<0ZGLb0:Yh<@2[NC80[g`]0:el;`2]OC40Zglf0:Yo>P2V
OcX0YGln0:9o?@2WPD80YX110:Eo@02SOCh0XG/l09mi>P2NN3T0WGLh09Yh>@0309]i>P0<09Ug>02G
MCH0U78c09=a<P2<KCL0SFhh08m`>P2@LC/0TG8l091a>`2?L3X0SVli0P27L3X01`2:LC/0Rg0k08i`
?02?Kc`0T70m095`?@2>KCP00P2?KST00`2@KcX0TG0k095`>`02099a?080TG4h0140T6li08m^>@2>
KCX0SF`i08e[>`2<JSX0QG0i08A_>023KSL0PVdf08=^=`25L3T0Qg8k08Ud?@2<JcH0RVTd08QW<P02
08MV<@0308QW<P2:JC@0RfXe00@0QFXc00X0Q6Tb08=X<@23J340PVL`08AZ>@22J3L0P6He07eS<P1k
HC00NEl^0P1hGRd08@21IC<0PVHf089V=P21ICH0O5lc07II;`1`Db/0K4lW06eF;@1/EB`0Je<]06UA
;@1VCR`0I4//0699:P1PAbT0E40W05<o9P1B?R<0DChP054n7P1B?ah0E44P05E37`1HAAX0FdPM065<
8@1VCbD0JE0W06]?9`1ZCRH0JTdU06aF9`0206eE9`0306mD9`1`DbL0LE8V0080LU4V0`1cEbL207AH
:00407EI:@1fFRX0MUXZ07MK:`@0N5h[101gGBX00`1gFb/0NEd]07YN;P0207]O;`0C07UM;@1gFb/0
METY07QO9`1gGRH0MUdW07AJ9`1aEbH0KeDT06iC901]DR<0KeD`06aB;@1VCRP0H4XS05a98@1KBB40
GD/S05e>9@0805e;9@P0FDXS0`1IBbH305Q:9@80EdTT00X0F4HP05Q68P1EAB40E4HS05958`1?A2@0
CT<U04e49@1:Ab@0BdPU0P1<BBH01@1;B2D0BTLT04Q58P17A240A44N0080@d0O00<0@SlP044m8010
?2400P0o>b803P0h>R@0=cTS03Hh8P0d=R00<cDO034c7@0`<Q`0;c4K02h`6P0^<1/0;BlJ02`]6`0/
;Ad0:b`N0P0Z:Qh202LY7P0302HX7@0U9a`092HK00808bDJ00H08R@I024T6`0Q91/082<J01lR6@0N
8AP201dP5`0401`O5P0L7Q/071hK01`N6`806adJ0`0J71T201/M70806Q`K100I6aX801HH5`P04QPH
0P0F5aT401DF62/051DG200A5aL800lE5BP051DG400E5QP801DG5P<051DG0`0E5QP201HG6@P05QPG
200F5aT301DG5P<05QPG2`0G6AP201LG5`8061PH100I6AT:01`L6P<07AdK0`0N7Q`201`M5`<07AhH
0`0N7aT201dN60807QlI0`0O81X00`0P8A/07QdH01hM600201lN6@8081lJ0P0Q81/02`0P8AT08B4I
028R6P0U8Q/09b8L02XS7@0[8Qd0;2<N02/W7P0Z9Qd0:2@K00809b<J00L0:2@K02XV7@0[9ah09QlG
02PQ6@0[91`0;RLO00<0<BXR00<0<2TQ02lU6`0_9A/01P0_9A/202hT6P80;bDK100`9Q`00`0e:AT0
=RXJ03P/700303T]7@0403L[6`0f:QX0@2dO040]7`@0?b`N0P0n:ad0200l<1H0?C4G03lc6@10=1X0
@CDK040d6P0o<aT0?S8H0P0o;Q`01P10;ad0@C0N048a7`13<R00A3<Q04Dd8P80@c8P0P12<Al4044`
7P0604<b6012<1P0@S0H048`6P11;a/0@BhM0P10;Ah01011;R00@2hP040^800n;Ql203`_7`0303X^
7P0h;ah0>2lN0080?C8N00H0?34M03/`700i;QX0>2dI03L/600f:aL803PZ7`06030Z700a:A`0<BTL
03<Y7@0e:Ad0=bTN0P0i:1h203XZ7@0603LY7P0e:1l0<RPO034X8@0`9b00;bPR0P0_91h2030U7`80
<BHP0P0b9b4203DY6@0403HZ6P0g:a/0>2`L03T]7@80>RhN00@0?2lO03/^7P0k;Qh0>RdM0P0i;1`2
03P[6`80=RTH00@0>2/J03X]700l;ah0?S4P0P10<b8303l^7003040_7@11<1h0@S4O0080@S4O00h0
@c8P048a7`11<1h0@2lM044`7P13<R00ASDS04Pg9@19=Ad0C3HO04li8P1C>R@0ES/V05Hj9@80EcPT
02h0BcXP04di801?>b80DC/S05Dm9@1H?RL0FShX05/o:@1O?bH0GShU05`l8`1K>b80G3`S05hn9@1Q
@BP0Hd<Z05m49`1N@bH0G44T05]08`1J?b80Fd0S05a1901M@RD0FD4Y05Q0:01F?RH0ECdU05Hn9P1H
@2P0FT8Z05]3:`1NA2d0FT8Z05Hn9P1@>R80CCTP04/j801;>b40C3`R058i9@1A>2@0CcTT04hh8`1<
=b80BCLQ0P17=b0804Lb7@T0@c8P00<0?S4N03lb7`11=2400P12=B800`11=240?c8O03ha7P0204Dd
8P0404@c8@13<R00@c8P048a7`80@C0N0P17=R800`19=b40C3PP04hh8002054i7`0605<i7P1?>b80
Cc/R04lk8P1>>R40CCTP0`1<>1l0401=?B@0C3`S04/k8P1:>R40Bc/R04`l8`1>?RD0CclV04`k8@1@
?2<0DShU05Do9`1G?bL0F3hW05Lk9@1F>R@405Pl9P@0Ec/U00<0DShU054m901?>b800P1>>R402`1?
>b80DCdT058n9@1G?B80ES`Q05@j7`1B>1d0DCLL058h7@1D>Ql0EC/P00P0BCLO00H0AcDO04Pf8018
=R00BSPR04/i8`1<>R@204dk9@80DSTS00@0DCPR050g8@1@=b40CcHP0P1>=Al01P1A=b00D3PP050h
801==al0C3PO04Xi7`80B3PN0P1=?B@00`1>?2@0D3`T054k900205<j900305@i901@?2<0D3`S00H0
D3`S00@0DcPS058g8P1B=b80DSLR0P1A=R42050e8008050l8`1?>b80CCTP04`h7`1=>B00Cc/R054m
901B?RD805Lm9P0605/j9`1K>bH0Ec/U05Hl8`1C?R40CclN0P1>@1d04@1=@1d0Fd4V05Y09@1I?b@0
F3hS05To901J@2D0G48W05e3:01Q?R80Hd0T06A29P1SA2L0H4<U05Xo8@1F>ad0DSTJ0080Dc/O00L0
DSXN054i7@1C>al0ECdQ05Q0901J@RH0EclS00<0EShR0P1E?B4205@l800805Hf7@1H>1l0FSXQ05`l
8`1M?B@0G3`S05/k8P1J>R4205hj8P0305dk8P1K>b80FS`R0080F3dR00T0EcdR064o9P1R@2L0Hd4X
06A2:@1S@BP0HT0W060n9@1N?2<00`1J@2D00`1K@BH0G48W05e3:00205e3:00305dm901N?RD0H40W
0080HD4X00<0H40W05hn9@1M?B@00`1MA2D[ooooo`00:_ooool209Y^?@<0Vfln0`2LL3l00`2JL3h0
WG=10:1fA0020:=iA`030:1fA02MLd40VW0n0080WG@n00<0WGA009ec@@2MLd<00P2MLTD00`2MLTL0
WG5009ea@00209ib@@<0Wg=200@0X7A309mf@P2NMD40WGA00P2LLcl00`2NMD40X7M30:5hA0030:1d
@`80Wg=20`2NLT4209me@`80X7I40`2QMdD0102RN4H0X7I40:1fA02OMD<209id@P0309ec@@2LLT00
W7900080Wg=20`2PM4<30:5eA0040:EkB@2SNDL0XGM509me@`<0WWA200<0WgE30:1fA02MLTD00P2L
LD@00`2KL4<0VVm209U^@@0209Q]@00<09Q_>`2GKSX0UVdi09E/>02CJSH0TVTe095X=02@Ic<0T6Hn
08iT?02<HSX0RV0h0P28GSH208UO=`H0Oed_0P1nG2h0201fEC80MeHc07QG=01hEc@0MeHc07ED<@1c
DRl0LE0]0`1^D2h206e?;@<0K4h/00<0JT//06U::`1WB2T00P1UARL0101VAbP0IdPY06Q9:P1UB2P2
06I9:@0306M::P1XBb/0J4/[0080JD`/0100KTd^06e<;@1/BbX0K4/X06i>:01`D2T0Le</07EE;01e
F300NETb07]K<P1nGC80P5ha089M<023GBh0PU`]0P27HC@01028HSD0RF<f08YT=`2;ICP208aV>@0;
099V>@2@ICP0SV<f08aS=@2:I3D0RVHf08YX>02;JCT0S6Hi08eW>P2@JSd00`2BK3l0102@JSd0SfTl
08eW>P2=IcX208iX>`80SfTl0P2@JSd0102FJch0UFXm09EZ?@2EJSd409AY?080TVLj00@0TfPk09AY
?02DJC`0UFXm0P2FJch01P2IKcd0V6hl09Q^?02GKC/0UV`j09E[>@80U6Xh202HKc/909U^>`80UF/i
00H0UV`j09M]>`2HKS`0VFlm09Y`?P2KLCl809]`?@0609eZ>`2KJc/0W6`l09a^?@2JKSd0VW0n0P2J
LSl@09Q^?00509Ia?@2EL3`0UG0l09A_>`2CKSX00P2BKCT00`2AK3P0TV`m09=]?P0209A^?`0709=]
?P2AJc`0SfTj08eW>02>JCD0SfXf095/>002099]>@03091[=`2>JCD0SFPd0080TF<b00<0Sf<b08mU
<`2>IS<00P2=J3@0102<J3@0RVHf08YV=P2:ISH208]W=`<0S6Ph0P2>Jc<00`2>JcD0SVXf08iZ>002
08iZ>P0708iY?02@JS/0T6Xi091Z>@2@JcL0T6/f091[=002091/<P<0TVdi0P2AK3P3091[=`0409A_
>P2CKST0Tfhi09=^>@80TVdh0P2AK3L06028ISH0S6Xj08i/?02;JCT0QF<c089P<024HS80R6Hf08YV
=P29ICD0R6<f08MR=P25H3H0Q5hg08=M>022G3L0LUX/075I;@1^Eb/0JeH[06IC:@1SDBT0HDlY05i?
:080Fd@T00`0Ed8S05E08`1A?B80CC`R04Xj8019>B00@S<N044b7@0n<Ah0>c0N03L^7@0d;Ad203</
7003034[7@0[:b40:RXP0080:RXP0P0Y:Al202PX7P0402DV7P0T9Ad092DM02@U7@808b@L0P0R8a/8
01lR6`807R4J00@07b8K020S700P8a`08B@M0P0R9Ah3024T7@8082<L0`0O8Q/:01`N6`@06adJ0P0J
71T201/P700601dO6P0O81X08B8J02HV7P0/:B00;R/R1@0c;Q/203@_700?03D`7@0`<B40;BhP02PY
6`0T91P08R8H02<S6`0U9Ad09RDP02dY7@0^:Qh0<B/O03@/8@0f;280>RdT0080?BlV00H0@3DQ03de
800l=1l0>S@N03Pc7@0d<Q/2038b6P0803@_700e<1d0=C0M03D`7@0d;a`0<RdJ030[600^:AH202//
7P80:R/M0P0Y:Q`202PY6`@0:BTO100Z:R0202TV7`80:2DN0`0W91d0100V8a`08R<M028S7@0R8ad2
024R70<0824K200N8AX01`0L71808B4G02DV7P0T9b008B@M01`Q6`0K8Ad00P0M8al0600F81L06b<H
028T5`0W91D0<2DC03`[5`1<=Ql0EclW07QI8P27J340T74k091`?@2CLd80UgQ9099cA@25ISP0K5]1
05a<<`18?2H0>c@Q03Hd9@0b=2T0:BhW028Y8PP0:RdT1@0Z:b<302TZ8P0602`/900];B<0;RhT02l_
8`0a<R@0<S<S0P0c=280500h=RX0>CLZ03`h;00o>B/0?cPX03he900k<b00>c0N03Xe8@0l=B80?CHS
040h9@13>2H0ASTX04Ti:@1:>RX0CD8V04m4:01AARX0DdP/0P1DBBd03P1BAb/0DDHZ05Y;;01FAbP0
DD8S04dn7`1<?Ah0CSlP05528`1DABH0CdDZ04e3:01;@BH0BClT0P17?B805`18?R<0BClT04a0:P1;
?bT0C3dX04/l9`1=?2P0CcdY05<n:`1D?b`0EClZ05U3:`1OAb/0Hd/W06I>8P1]Db80ME`T07aR:@2?
JRH0TVdY09Eb<02IMcL0VW/k0080VG/m02T0UgXn09>1D@27MDD0Q6m208M`AP25K4<0OF4j07iR?@27
JDD0Rf5908QNA@28Fch0QeTh08]I=02AG380UV0b09]S=02EKRd0Ug0_09Qb<@2HMC<0V7Ld09Ef<`2D
MC80TWDa08a^;P2<KS00RF``08MZ<P23J3<0P6Hc07aT=01jHS80ME/j07AJ>@1dEcL0LeDc07ED<`1g
E3@0NUHf07]G=`0207UB9`0W07mE:`23F2/0QULY08EE9029ER40SEPR09=L902FHRP0V6@Z09YX;@2L
Jc00W6hb09a`<`2KKc80VG0b0:9h;P2YOcD0ZGlg0:5f<@2QMS80ZGhj0:Yn?@2RMSD0Vgl/09f0<02Q
PS80Y8<f0:R4>P2YPc`0ZH8m0:V1?02VNd@0XWU109ie?`2ILCd0UW4l09Ib?P2GMT<0VGQ50080VGHn
01T0V7Dm09Ic>`2CL3P0T6de08i[<`2<JC40QF0/08IQ;@28Hbl0RVDa08eX=02?JSH0TF`h099]>@2?
JcL0T6`h095]>@2BKSX0Tflk09A`?02ELCd0UW8n08iZ=P2@K3P0TFdi00<0Tflk0P2AKCT0102>KCL0
SF`f08a[=@2;JS@208YY<`80RfXd0`25JcP508I/>@80Rf`c03l0SFdd08m/=02=JS80S6L`08aU;P2:
Hb`0P6Pj089W>024J3P0R6Pe08]X<P2=J340T6T`095Y;P27Jc/0Q6Ph07mS<`1kGbl0N5`/07UM;@1k
Gbl0O60`08=S<P21HC00OV0^07YN;01iGb`0N64]07UR;P1iI2l0N5Pb07MG<@1bE2h0KE4Z06M>9P1S
C2<0GdTP05i87`1RDS00GDd[05E58`1>?Q`0Bc/I04dm6`1A@Al0E4@R05<n8`1F@B@0G4LX065=:P1T
DBT0IE8W06EC9@1TDR80JD`R06e@901`DbL0L5@U06iB8P1^DR00LULR07IK9P1_DRX00P1`Db/0101`
DbT0LE@X079F9`1cEbL207AH9P80NEd]0`1jGRh307]O;`80OF4_00@0O60^07]O;@1kGbd0NUh/0P1i
GB/0601kHRT0NF0X07EL901bFB<0LELT079H9`1dFBX0MU//06]E8`1ZE2<0J58Q06MA8P1UCR80Hd`R
069;8P1QBR40He4Y065?9`1MBb<0FTPP05U77`1KBB40GT`T061>9P80FDXS0P1JBb@205]<9@80G4dV
00@0F4XS05I88@1EAb00EdTR0P1KCBH06P1GBB80DdDN051::01@BRP0CdTW04e79@1<AR@0BdDS04Y4
8P19@b40BdDS04Y48P1;@R40CD8R05138`1CA2D0EDHW05Q7:@1@@b00Cd8O04a27`19@1l0AClO048m
7`11?1h0?c/N0P0m>1X01P0k=aX0=cHJ03De6`0a<a/0<38J02lc7080<c0M0P0b;a`2034^6`80<2dJ
00P0:RPK02XX700W9a/09BLL02@U7@0R9Ah082DO01lT7P808B@K00<082<J01lR6@0N8AP00P0M81L0
100L7aH071lH01`O600L7aP201/N5`<06QdF0P0J71T201TK608061XG0P0G6AH801LI60P05QPG0P0F
5aT401DF62/051DG200A5aL8018C5B0051DG200E5QP801@E5`<051HE0`0E5aHB01HH5`0301DG5P0H
6QT061XI00805QPG0P0H6QT00`0E5aH05QPG01HH5`0601HH5`T05aTH200H61P801TK6PP071`J0`0K
71H201`M5`<07AhH200Q81/201lO5`<0820H0`0Q8AT3020P60<08B4I0P0R8QX0200P8A/08B0K028R
6P0U8QT09b<H02XT600[8aH0;2@G200]9a/302hX7080;bTM0`0`:Qh0200a91`0<RDM038U700b9QX0
<bLI03<W5`0d:1P0=2TG0P0e9R400`0f9b00=bTP03PZ7`0203T[7P0403X]7@0j;A`0>RdL03X]7080
>bhM0`0l;ah0200h:aX0>B`K03/^7@0m<1l0?S4P03d`7`0k;Qd0>RdL0P10<Ah01P12<Al0@c0O04@a
8016<B00Ac0P04Pa8@80AC8Q1014<B0204<`7`0404@d7@13<a`0@c<L048b6`80@C4J0P10<1T2044^
7@80@RlN00D0@c0O04@a8014<B00AC8Q048_8@03044^80<0@2dO0P0o;1h803/`700803`_7`0m<200
?S4Q03d`800l;al0>RdM03P[6`0f:AT203<Z6`0>03@[700e;1d0=RdN03L^7`0h;b00>C0Q03h^7`0m
;Ah0>RdM03T]7@0f;A`0=2dK03</6P0b;AX3034W6`80<2HJ0`0_9AT0200b9QX0<bLK03@X700f:Qh0
>BdQ03/_8`0l<2@0?C4U0`10;al503l^7P0603`[6@0m;1X0?RdK03l^7010;ad0@C0N0P12<Al00`14
<b40@S4O044`7P02040_7@0V044`7P12<Al0A3<Q04Da9P14<2D0@c0R04<`8@14<B00AS@P04Pf8P1:
>280C3@L04de7@1>=Qh0D3PP054i8@1C>b<0E3`T05Dm9@1>>A`0CcXM058j7P1D>Ql0Ec`Q05/m8`1L
?R@0GShU06138`1N@B40GD0P05`o7`1M@200GT4Q0654901RABD0GD0P05i18@1O@R8206138`0D05i1
8@1L?al0FchN0653:`1O@BT0GClW05Xl901I>b<0FS`T05/m9@1L?RH0FTDZ05Q3:01E@2D0DSdR054l
8@1B?B80E3lT05E09@1=>bD204`j900304/i8`1:>280BCLQ0080B3HP00H0CC8M04`c7@1<<ad0BS@M
04Pd7016=1`204De70T0@c8R200l<QT8044a6P0604Db8`16<b80Ac@S04Pf8P19=b40BCLO0P1:>Al8
058j8PP0CSdS0P1I@28205Y18`@0Fd8T00H0Hd</0651:P1O?bP0G3`U05/k901J>R<205/k90<0FC/Q
0P1H>R0305Li7`0905Tj7P1H>Qh0EcTO05@h801B>240D3LQ04hh8`1==b80EC/T0080Dc/S00<0D3XR
04hj8@1;>R000P19>Al00`1B>R80Dc/S05@l900205Dm9@0305<k8`1B>R80DCTQ0080F3hW00<0EcdV
05Hl9@1E>b@00P1D>R<0101C>B80CCDM04hf7P1@>202058j8P06050h801>=Qh0CCDM050d7`1B=R40
E3PS0P1F>RD00`1E>B@0E3PS05<g8P08054i8@0305<k8`1B>R80DCTQ0080D3PP00<0DCTQ05<k8`1D
?2@0201D?2@00`1D>Ql0ES`Q05Lm8P0205To900305Lm8P1F?240E3XO00T0E3lR00H0FC/O05Xl801K
?B40G3hR05i0901P@RH206539`0;05/n7P1M@200HD@T06=69P1RABD0H4<S05`o7`1J?Ad0EchP05Po
8@1I@2800P1J@B<00`1H?b40ESdO05@k7@0205i0900405do8`1L?R80G3hR05/m8@80FS`P00T0H48V
05m19@1M?b<0G3hR05/m8@1L?R80GClS05i0901NA2T00P1M@bP00`1L@RL0Fd4V05]19P0205Y09@P0
FD@Y00<0ED0S05M29@1IA2L00P1KART00`1JABP0FD@W05Q39P0205]48PH0G4DS0`1TC2X[ooooo`00
:_ooool209Y^?@<0Vfln0`2LL3l00`2JL3h0W79009me@`020:5gA@0309me@`2LLT00VW0n0080WG@n
00<0WGA009ec@@2MLd<00P2MLTD00`2MLTL0WW9109ib@@0209mc@P@0X7A300<0WgI209ie@@2MM400
0P2LLcl00`2NMD40X7M30:5hA0030:1d@`80Wg=20`2NLT4209me@`80X7I4102QMdD309me@`<0WWA2
0P2MLd4209mc@P<0X7A30`2QMD@0102UNdT0XgU70:5gA@2OMD<309id@P0409me@`2PMT@0W75409aa
A080Vg1300@0VVm209U^@@2HKD00V6e00P2GKC/0102FK3X0U6Xh09=Y=`2AIcD2091V=00408iT?02=
Hc/0RV0h08QN=P80Qede0P28GSH307mM<0D0OU`_0P1fEC8207MF<`0407IE<P1dDc00LU4^075@;@<0
KU0^0P1]Cbd306a>;00306Y;;01YBR/0IdPY0080IDHW00<0ITLX06M8:@1XBBX00`1VBBT00`1WBRX0
J4/[06Q;:`0206U<;00@06i=;P1]C2d0KD`[06e<:@1^CRP0LE4Z07=C;01eEB`0MEP`07QH<@1kFc80
OUdb081N<@22GC00Ped^089L;@80Qf4d00@0R68e08US=P2:I3L0RfDh0P2<IST0402BIST0T6Dh08iS
=P2<HcD0RV@e08YV=P2:J3P0RfTi08aV>@2=IcX0SfTl095[?P2BK3l0TF/n091Z?@2?JC`208eW>P80
SVPk0P2?JC`2091Z?@80TfPk1P2DJC`309=X>`0309AY?02EJSd0UFXm0080UV/n102JL3h309U_?@03
09Q^?02HKc/0V6lk00H0V6lk2@2IKS/209I/>P80Ufdk00@0V6hl09U_?@2IKcd0VFlm202KL3d01P2N
Jc`0W6`l09e]?@2LKSd0VVhm09Y`?P80VG4n402HKS`409A_>`@0Tfhj0100TF/l099/?@2CKCh0Tfdn
099/?@2@JS/0SVPi08aV=`2>JCD0SfXf095/>02BKCT0TF`h091[=`2>JCD0SFPd0P2AHc800`2@I3<0
SfDc08iV<`0208eX=00308aX=02:ISH0RVHf00<0RfLg0`2<J3P208i[<`0308i[=@2>JSH0SVXh0080
SVXj00H0SVTl091Z>`2@JS/0T6Xi091[=`2@JcH2091[=004091/<P2BKCT0TVdi099]>@80TF`h0`2@
JcL3091[=P80SfXe0`2>JC@01`28ISH0S6Xj08e[>`2:J3P0QF<c089P<024HS800P27ICD01@26I3@0
QF<e08AR=@23H3H0PEhf0080P5dg01H0LET]071H;01^Ebd0JUDZ06EB:01RD2P0H4hX05e>9`1KA2@0
FT<T05I18P1C@280CchR04/k8@1:>R40B3XP044b7@0o<Ql0?C0M03/`7P0g;Qd0=2dM0`0a:ad402XZ
8080:BTO0P0X:1h402@U7@808b@L0P0R8a/801lR6`0301hQ6P0O8Q/07b8K008082<L0P0Q91d00`0R
9Ah08B@M024T7@03020S70<07b8K2P0L7Q/601/M6P806b0L00H07AlJ01lP6P0R8a/09bLM02`Y800^
;203038]6P0=03<^6`0d;a`0=C0M03D`7@0f<Ah0;RlQ02//7P0W9a/092@H02<S6@0T91X09RHN02PX
800202l/7@04038/7P0d;1l0=bdQ03X^8P80?2hS00H0?S<O03`d7`0k<ah0>C<M03Pc7@0e<a`203<c
6`80=C0M0P0f<Ah0100e<1d0<bhK034/6@0_:QL202//7P80:R/M0P0Y:Q`202PY6`D0:BTO0`0Z:R00
100Y9Ql0:2DN02PU7P0X9Ah202LT7@809R<L0P0R8ad3024R70<0824K200N8AX01`0M7A<08R8H02HW
7`0V9al08RDN024T7@0P9Al00P0R9b40600J8AX07b8K02<S5`0[9AD0=RXD04Lf701MARL0JU4b089S
;@2>L3X0UWQ409AfA02>LT<0Rfi207iQ=`1_DRX0Fd/b04ho:00n<al0=RlM03@b8`0b=2T0:S0V02<Z
8PP0:RdT200Z:b<05P0/;2@0;BdS02h^900_;b<0<C8T038c8`0c=280=3DS03Pf:@0i=bX0>cPY03dg
:@0m=RH0?C@S03`d8@0m<R00?3LQ03hh8P0o>B<0@SXU04Dj9P18>bP204/l:@0304i39`1@ABT0DTL[
00<0DdP/00h0DDHZ0515:@1IBR/0ETLX05=49@1@@B80Cd0Q05118P1B@b@0Dd@U0556:P1@ABT0CT<W
04]09080BSlS0480Bd0T04a19@1=@BT0C40X04dn9`1>?RL0CcdW05<n:@1D?bX0Ed4/05Do:01K@bT0
H4TZ06A<:01WCb<0KeDT07QM:01nI2/0TF`X099_;@2FLc40VGLg09Uj>P2HNS`0UGPl09Ag>`2>O4`0
QW52085/?`23K400PFPo07]O=`1lGSP0Q6I008]R@P2;H3h0RUhi08YM=02?Gc40U68a09YW<P2MJ380
V78a09Uc<P2HMCD0UgDe09Id=02BLc<0Sg4a08i`<024Jc80Q6/c089Y<`1nIc<0Nf<c07QR<`1fGc<0
M5ld07AG=@1cES@0LeDc07AC<P1eDc00Me<a07UE<@1lES8207eD:00=085H:P26G2`0RU`[08UJ9P2=
FRD0TUdW09IR:@2IIB/0VVP]09aZ;`2NKC80WW0d09ea=00209]b=00V0:5j;`2WOcL0Yglg0:1h<P2P
N3<0Yghl0:Mn?P2PMcL0Vgdd09an=@2POcP0XWlk0:An?@2TOC`0XWXl0:9h?02QMSl0WWDm09Ya>`2F
KSX0U6lj09Ea?@2EM440UgI309Md?02FLc/0U74i099_=`2@KCD0Sf`d08i[<`2=JS80RF@`08YU<@2;
IS80S6Lc08iY=@2@JcL2095/>0<0TFdi00<0TVhj09=_>`2DL3`00P2ELCd209=_>`80U70l00@0Tflk
091/>02>JSH0S6Pd0`2<JcD00`2=K3H0S6/e08a[=@0208]Z=080Q6Xg1P25JcP0202:Jc80Rf`c08a/
<`2>Jc<0SFXb08aW<02<IBh0RV</0P22IcP01024J3P0QfLd08UX<`2=J34208mX;`0408M[>`24J3P0
Of<c07]O;`80NEd]02/0Nel_07aP<023Hc80PV8a07mQ;`1kGbd0NV0]07QQ;@1iHRh0NF@_07UI<`1h
F380M5H`071D;@1[DRX0Ie0W06A>9@1RC2<0HTl^061=;01NBbX0FTLV05I38P1C@1l0D3dL04ll6`1B
?B00ED0Q05Q48`1LB2D0Gd`T069?9@1SD2D0He4S06Q=8P1/DBH0L5DX071E9P1]Db80KE<P075G901e
G2H0L5<[0080LE@/00@0LE@Z079E:@1cEbP0M5PX0P1eFBL307QL;080NEd]0`1jGRh00`1mHBl0O60^
07aP;P0207]O;@80NUh/00L0NEd[07UP9`1hGbL0MUdU07AK9@1cFBH0LeTX0080M5TZ00H0JeDS06YD
8`1YDb80Ie4R06E>8P1TCB<2069;8P03069@:01PCRH0GD/S0080FTPP00<0G4XR05m=9@1QCbL00P1I
BR<205Y;9080Fd`U0P1LCBH0101HBR<0ETPQ05E7801GBB8205]=9P0505M98P1CAAh0D4XV051:9P1?
BBD00P1>B2@04`1=Ab<0C4HR04a68P1;AB<0BT@R04]28@1<@B40D4<S05=49@1EARL0EdHX0513801?
@Ql0C48O04U07`15?al0@SdO044l7P0o>ah00P0m>1X01P0k=aX0=cHJ03De6`0b=1`0<C<K02lc7080
<c0M0P0b;a`2034^6`80<2dJ00P0:bTL02XX6`0X:1`09RPM02DV7P0S9Ql082DN020U7`808B@K00@0
82<J01lR6@0N8AP07R4H0P0M81L301`O60<06ahG0P0J7AH201XL6@806A/H0P0H6QL201LI5PP05aTH
200F61L201HG6@@05AHH:`0D5AL8014G5`P04Q<E800D5AL801DF60P051DG0`0D5QD301DG5Q<05QPG
00H05aTH01HH5`0D5QD051HE01HH5`0G6AP901HH5`T05aTH200H61P801TK6PP071`J0P0K71H301`M
5`<07AhH200Q81/2020P60<08B4I0`0R8QX3020P60808B4I0`0R8QX01P0P8A/08B0K028R6P0U8QT0
9b<H02XT6080;2@G200/9QX302dW6`80;RPL0`0_:Ad2038U7@03038U700c9a/0<bLI0080=2PH00L0
=2TG03DV8@0e9Ql0=RLP03LY800h:Ql0>B/N0080>RdM0`0j;A`203/^7@<0?2lN00<0>2/J03T/6`0k
;Qd00`0m<1l203/^7@80@C8O00@0@c8P04@a8015<R40Ac8Q0P18<B4804@a800304@d7@13<a`0@c<L
0080@S8K0P11<AX00`10<1T0@BhM044^7@02048_7P0404<`7`14<B00A34P04@a8080@RlQ0P11;R04
040]7`0303l/7P0l;a`0?2lL00H0?2lL0P0m<20203ha8@0403d`800k;Qh0>2/K03LZ6P<0=B`M0P0f
;Ah303L^7`0803d]7P0l;1d0>RdM03P/700e;1/0<b`J038[6@0a;1T3038X70<0<BLK0P0`9QX203@X
700603DY7@0g:al0>2`P03T]8@0j;R80>blS0P10;al603l^7P80?B`J00@0?RdK03l^7010;ad0@C0N
0P12<Al00`14<b40@S4O044`7P02040_7@0;044`7P12<Al0A3<Q04Da9P14<B<0@c0R04<`8@14<B00
AS@P04Pf801:>2800P1==Ad01P1>=Qh0D3PP058j8P1C>b<0E3`T05Dm9@80CcXM00P0DSXN05Dk801G
?240FcdS05`n901N?RD0H4<S05m28P<0GD0P00D0Gd8R0654901RABD0Gd8R06138`030654900705m2
8P1N@B40G3lO0653:`1P@RX0GClW05/m9@0205Xl900605/m9@1L?RH0FD@Y05Q3:01F@BH0ED0U101D
?b@204lj9@0704hi901=>2<0C3LR04`g8P1;=R40BSDP04hc7P0204dd7P0304Xd7@19=Ad0AcDM0080
ACDL2@13<R0803hb6PP0@S8K00H0AC8S04Hc8P16<b80AcDQ04Pf8019=al204Xi7`P0DSXR201@?2<2
05U08P80FT4S0`1K@R@01@1L@bD0Hd</0651:P1O?bP0GCdV0080Fc/T0P1L?2D0101K?B<0FS`R05Xl
8P1J?28205Tk8@80F3XP00H0FS/O05Pj7P1H>R00ECTQ05<i8P1A>28204hh8`0605@j8`1B>R80DSXR
04li8@1=>B00BSTO0P18>1h00`1B>R80Dc/S05@l900205Dm9@0305@l901B>R80DCTQ0080EcdV00@0
ES`U05Dk901D>R<0E3XS0P1C>B800`1>=Qh0CcLO050h8002054i8@06050h801?=al0CSHN054e801B
=R40E3PS0P1F>RD00`1E>B@0E3PS05<g8P08054i8@0305<k8`1B>R80DCTQ0080D3PP00<0DCTQ05<k
8`1D?2@0201C>b<00`1E>b00ES`Q05Lm8P0205Pn8`0305Lm8P1F?240EC/P00T0E3lR0P1K?B40101L
?R80GClS05i0901O@BD206129P0:05/n7P1N@B40HD@T06=69P1RABD0H4<S05e0801K?Qh0EchP05Po
8@<0FT4S00<0F3lQ05Hm7`1E?1h00P1N@2@205do8`0705`n8P1K?B40FcdQ05/m8@1P@RH0Gd4U05do
8`0205`n8P0305do8`1N@2@0Gd4U0080Gd@W0P1N@bH0101M@RD0G44T05a1901L@B@805U4:@0305I1
8P1G@R<0FD@U00<0FdHW00@0FD@U05Q3901NAbD0GTLU0P1MAR@0101LAB<0Fd@R05Y38@1J@b43069:
:2_ooooo000Zooooo`80VVhm0`2KKch309a`?`0309U_?@2KLCl0WG=10080WgE300<0WG=109]a?`2I
Kcd00P2LLcd00`2LLcl0W79009ab@P0209aaA00309aaAP2OLd80Wg=20080X7A30`2QMD@0102RMTD0
WgI209ie@@2MM40209ac?`0309ie@@2PMd<0XGQ400<0X7A30P2OLd8309ib@@<0WgE30P2PMT@30:5g
A@@0WWA20`2OMD<00`2PMT@0Wg=209mc@P030:1d@`<0XGE400@0Y7Y80:=iA`2QMdD0WgE3102NM480
1P2OMD<0W75409aaA02KL4<0VVm209U^@@80V6e000h0Uf`o09M]>`2FK3X0UF/i09AZ>02BJ3H0TFLe
091V=02?IC<0RV<j08QQ>026GcH0Q5dd08=L<`80Q5dd00<0QEhe07mL<P1nFc400P1nFc4207eJ<080
O5T_00P0ME@a07IE<P1fEC80MeHc07IE<P1dDc00LU4^071?;0<0KDl]0P1/CR`306]=:`0306Y;;01Y
BR/0IdPY0080IDHW00<0ITLX06M8:@1XBBX00P1VBBT306M::P<0J4/[0P1]C2d0301]C2/0KTdZ06m?
:@1aDBX0Le</07EE;01dEbl0N5Pa07YJ<@1nGC80P5ha08=N<@80Ped^0P27HC@01028HSD0RF<f08YT
=`2;ICP208aV>@06095U>02@ICP0SV<f08eT=P2;ICH0RVHf0P2:J3P01@2=IcX0SVPk08mY?02@JSd0
TF/n0080T6Xm00<0SfTl08eW>P2=IcX00P2>J3/208mY?080T6Xm00D0T6Dh095V>@2AIST0TVLj09=X
>`0209AY?00309EZ?@2CJ3/0U6Tl0080U6Tl0`2EJSd00`2FJch0Vg4o09]a?`0209]a?`<0W79000<0
WG=109Q_>`2HKc/01P2HKc/909U^>`80Ufdk1P2HKS`809]`?@060:5^?`2NKSh0WVhn09e_?P2JKSd0
VFlm0P2HL3d@09Q^?0@0Tfhj102DKc/2091Z>`80TF/l00H0T6Xk08iX>@2<ISL0RfDf08iY=@2?JSH4
091[=`0;08mZ=P2>JCD0TF<b099T<`2@I3<0SfDc08mW=02=J3@0SVTe08eY=@2:ISH00`2;IcL208aX
>080SFTi0P2>Jc<00`2>JcD0SVXf08iZ>00208iZ>P0708iY?02@JSd0T6Xk091Z>`2@JST0T6/g091[
=P02091[=0<0TVdi0P2AK3P3091[=`80SVTd0P2=J3<308aW<P0808]V<@29IcL0RfTi08aZ>P2:J3P0
QV@d08=Q<@24HS8208IT=00508ES<`24HS@0Pf4d089O=@20GCD00P1oG3H05P1aFBd0L5L^06aE:`1Y
DbX0I54Y061>:01NC2P0Fd/W05Q3901G@R<0E44S050o8`1>?B<0BSXQ04Pi8P17>240?c8O03ha7P0l
<Al0>2lN03D^7P0b;1h202l/7@0402hZ7P0Z:R00:RXP02XZ8080:BTO0`0X:1h302@U7@808b@L0`0R
8a/;01lR6`8082<L100Q91d3020S70807b8K0P0N8AX801`N6`<06adJ1@0L7Q/201`Q6`0;01hQ6P0Q
8QX08bDJ02LW6`0/:Qh0;R`O030[600a;1T0<RdJ03<^6`0e<1d00`0f<Ah0200[:al0:BTM02HV6P0U
9AT092@J02HV700Y:Al0:b/Q0P0a;Ql0100d;R00=BdP03L]8@0i;B4203/]8P0603`a7`0j<Ql0>S8O
03Pa7P0g<Qh0=C<N0P0d<ah0200e<1d0=S4N03Lb7`0g<Ql0=S4N03@_700b;AX0<B`I0P0[;1h202X[
7@80:BXL0P0X:A/802TY7`809RHN0P0U9Ad302@T700302<S6`0R8ad08B8L00808B8L0P0P8A/201lP
6PP07R4J00L07QlG028S6`0V9al09RLO02<T700R8a/092DM00809bPP01P07ahJ02DR7@0]9a/0=b`J
04Hf701KBBD0Le`c08=[?`2?LCd0UGU709UmC@2AMTT0Q6]207IN>01TC2P0DS/I04Di8`0l<A/0<b/H
034[6`0b<2<0<C<X02X`9P0U:R<802T/8`P0:R/S01H0;BdU02d]8`0^;R@0<30T034b900b<b<0<c@R
03@e8`0i=bX0>3HW03Tf9`0j=2@0>c@R03de8P0n=R40@CHR040k9@12?2H0@cdW04Dm:018?BT0Bch[
0P1>?b`20556:P<0DTL[00<0DDHZ0515:@1?A2P00P1GB2T00`1FAbP0EDHW05A59P0205=49@050593
901DBBd0DTL[0515:@1>@bL00P1=@RH01@1>@bL0Cd@X0553:@1@@RP0D40W0080DClW03@0ED4Y05M1
:P1I@b`0F40V05e5:@1TC2X0J4hY06eB9`1cEbL0OEl[08=U;`2BKbl0U74a09Id=@2GMcX0UWPl09Ag
?@2AM3X0SG<j08UdA`21K3l0OFHj07iV>P1mHSL0N5/a07]K<P21HCP0SF@f08eU=02>I380Sf@_09AW
;P2IJbl0WFla0:5a<@2LNCT0VgPh09Ug>02DM3L0T78f08]^=027JS00PfT`07QV=P1gICL0MF<e079O
=01_G380KEXb06aH<`1[Ec@0L58`0P1bDBh01@1cDB`0ME8/07UC;01lEB`0OEH]0080PeTW00d0Qed[
08eR;`2@HRh0T64[09=R:P2IIRd0WFXa09e[<02NK340Wfhc09ma=@2PM3L0WWDg0080WGDg01`0XG/d
0:Eo>02UOST0XGXg0:1i>02TO3h0Xg/m09if>@2JNc/0Vg`l09ek?P2MNCd0WGHm09ac?@2IL3`0V6dj
09U^=`2GKSH0UF`f099Z=P2AK3L0TVhj09=b?`2EM440UG8j099_=`2?K3@0SFXb0P2<JC400`2>Jc<0
T6de08iY=00308mZ=@80T6/f0P2AK3L809=`>P80Ug@n00h0UW<m09Eb?02BKcT0Sf`f08aY<`2:Ic40
RFPb08]Z=02=K3H0Sfhh091_>@2>KCL0S6/e08YY<`P0Q6Pf01@0RFXc08Y[=02<JcD0SV/e08eZ=02<
Ic80S6@`08]S;`23IcL0Q6Ph08IX=P27Ic@0RFPc08]X<P2<Ic00SFPa08IZ>P23IcL0Of<c07aP<080
NUh^00X0Nel_07aP<023Hc80PV8a081R<01lH2h0Nf4^07UR;P1jHbl0NF@_0P1jFS<0101fFC40LeL_
071G;P1]ER`206YE:P0H061>:P1RD2`0IE<_06AB;P1PCRX0FDLS054o6`1<>QH0E3dN05@m7@1E?Q`0
Ed0N05Y47@1NB240HD/R06=>8`1XC2@0K50X071E:P1aERT0Ke@U06iD8`1aEb@0ME/X0`1bEBd01P1c
ER`0M5L[07EI:P1fFRX0MUXX07MK:@<0MUXZ0P1gFb/307QL;0<0O60^0P1kGbd307YN;00C07IM901g
GRH0N5lW07QO:@1gGBX0ME/Z07=H:@1aERL0KELU06aF9@1[EB@0JE<T06M@901UCR@0I4dT06=<8`1Q
CbL0GddU05e;8`0205]98@0305i<901PCRH0HU0X0080FDXS0P1JBb@205]<9@80G4dV00@0F4XS05I8
8@1EAb00F4XS0P1KCBH00`1GBB80DdDN059:9P07059:9P0H04]58`1:A280Bd8Q04a18@1?@R80DT<T
05A59P1GARP0DD@Q0513801=@b00BT4P04I08013?R00@SdO040l7`0n>A/0?CPJ03/g6P0h=a/0=CDK
038d700a<a/0;c<L0P0c<1d2038_7080<BhK0P0`;AX01P0/:Q/0:bTJ02TZ700W:A`09RPM02@W7P80
8BHO00H08RDL024T6`0Q91/082<J01lR6@0N8AP201dP5`807B0I0P0L7aP301/N5`0301XM5P0J71T0
6Q`I00806A/H0P0H6QL201LI5PP05aTH200F61L201HG6@@05AHH:`0D5AL8014G5`P04Q<E800D5AL8
01DF60P051DG0`0D5QD301DG5Q805QPG00<061XI01DG5P0D5QD00`0D5QD00`0E5aH061XI01HH5`07
01HH5`T05aTH200H61P801TK6PP071`J00@06a`F01`M5`0L7AL071dG0P0M7QP201hO6@P08B0K0`0R
8QX302<S6`8092@L0P0P81P2024Q6@<08R8J00L08b<K020Q6`0R8A`08R8J02DR6@0W8aP0:R@H0080
;2@G2P0[9AT202`V6P80;BLK0P0^:1`03`0b9Ad0<bHN03<V7@0c9a/0=2PJ03@X600e:AT0=BXH03DV
7`0f9b00=RPO03LY7P0h:Qd0>B`L03X]7@0403X]7080>bhM0`0l;ah00`0i;1/0>RdL03/^7@0303d`
7`80?2lN0P12<b001P14<b40AC8Q04Hc8P18<b80BC8R04Xc8`P0A34P1013<a`2048b6`80@C4J0`12
;ah304<`7`80A34P00@0@c0Q048_8012;b00@RlP0`11;Ql2040]7PP0?C0M0P0m<1l203ha800403d`
7`0l;ah0>B`K03P[6P<0>RhN0`0i;Ad203P/7080>b/L00H0>2/K03L[6`0d:aX0<R/I034Z600`:aP3
03@Z7P80<bTM0`0b:1`303HZ7P80=b/O0`0h;20803l^7P80?RdK0P0o;Q`01`10;ad0@C0N048a7`12
<Al0A3<Q048a7`11<1h00P10;ad02`11<1h0@S4O04@c8@15<R@0A34S04@a8P14<B00AC<O04Le7`18
=R00BSPP0080CSHN00H0CcLO050h801B>R80Dc/S05@l901E?BD2050k7P0805<k7`1F?240F3dR05/m
8`1L?R@0GShU06138`1O@R8205i18@0@05m28P1P@b<0HD@T06959@1QA2@0HTDU06=69P1TAbL0HdHV
06959@1P@b<0Gd8R0653:@1P@RP0Gd4W05do9@<0G3hT00<0GClU05Y29P1J@RH00P1J@RH0101I@BD0
F40T05Hn8P1E?B42050l900404lk8`1>>R80CCTQ04di8@80C3PP00H0D3DP04he7`1>=Al0BcDN04Xf
7P17=Ad204Hf7@T0A3<Q2010=1`804@d7@0804Hc9016<b80AS<R04Le8@18=R00BCLO04Xi7`1;>R08
058j8PP0DCdT0`1J@B<205]290<0G4<U00H0Hd<Z0651:01O?bH0GCdT05`l8`1M?B@205hn9@<0GClU
0P1L?R@305/m8`0C05Xk7`1I>al0F3XP05Di8@1C>B80DCPR04li901>>2<0DcTR058j8P1A>B40CSPP
04`h7`19>1h0B3PN04Lg7@1B>R80Dc/S05@l900205Dm9@0305@l901C>b<0DSXR0080ES`U00<0EC/T
05@j8`1C>B800P1B>240101A=b00CcLO04lg7`1@>202054i8@07050h801?=al0CcLO054f8@1B=b80
DcPS05@i900205Dj9@0305@i901C>2<0DSXR00L0DSXR00P0E3`T05<k8`1B>R80DCTQ050h801A>B40
Dc/S05@l90P0DSXR00<0EC/P05Hl8@1G?B800P1H?R<00`1G?B80ES`Q05Dk800905Hn8PP0GT0T00<0
G3lO05i18@1P@b<00P1RABD00`1P@b<0GT4Q05`o7`0205U08P<0FT4S00@0FD0R05Ln801F?Al0GT0T
0`1M?b<305`n8P0405/m8@1P@RH0Gd4U05i09080GClS00<0GT0T05m19@1P@RH00P1RA2P306539`<0
H48V201LA2P01@1J@b@0Fd@U05a59P1MARL0GTLX0080GDHW00L0G4DV06599`1PB2H0H4PV05i6901M
AB<0G4@R0080Fd<Q0`1PB2H[ooooo`00:_ooool209Y^?@<0Vfln0`2LL3l00`2IKcd0VW0n09ab@002
09ec@@0309ab@02JL3h0VFlm0080W7<m00<0W7<o09ab@02LLT800P2LLD@0102LLDH0X7A30:1d@`2P
M4<20:5eA0<0XWI500<0WgI209ie@@2MM4000P2LLcl00`2NMD40X7M30:5hA0030:1d@`80Wg=20`2N
LT4209id@P80WgE30P2PMT@20:5gA@80WG=100@0WWA209me@`2OMD<0X7I40P2QMdD209mc@P<0X7A3
0`2QMD@20:9hAP040:5gA@2PMT@0WgE309me@`<0WWA200H0W75409]`@`2KL4<0VVm209U^@@2HKD02
09M/?`0>09I/?02EJc/0U6Xj09=Y>@2AIcL0T6Hf08mU=@2>I3@0Qf8h08EP=P23GS@0PUdc085L<P22
GC<208=N=080OU/a00@0OEX`07aI;`1lFBl0NeP^0P1jEbd0201dDc00ME@a07IE<P1fEC80ME@a07=B
;`1aD2d0Kdh[0`1/CR`306]=:`80JT`Z00<0JT//06U::`1WB2T00P1UARL00`1VAbP0IdPY06Q9:P06
06M::P80J4/[0P1]C2d03P1^CB`0Kdh[075A:`1bDR/0M5@]07AD:`1cERh0MeL`07YJ<@1nGC80P5ha
08=N<@24GRl0Ped^0P27HC@01028HSD0RF<f08YT=`2;ICP208aV>@06091T=`2?I3L0Sf@g08iU=`2<
ISL0RfLg0P29IcL208iX>`H0SfTl0P2=IcX208iX>`80SfTl0P2@JSd208mT=`04091U>02AIST0TfPk
09AY?0X0UFXm00H0Ufdk09Q^?02HKS`0VFlm09Y`?P2KLCl209ab@0P0V6lk2@2IKS/809Q^?0P0Vg0m
00H0XVm00:1`@02OKcl0WFln09]_?P2IKcd209M_?0P0VFlm202HKS`01@2AK3P0TVdi099]>@2CKSX0
U6lk0080UG0l00<0UW4m08mY>P2?JCX00P2@JS/01@2?JCX0SFLh08]U=P2:I3D0SFPd0080SVTe1@2?
JSH2099T<`03091T<`2@IS@0SfLd0080SVTe00@0SFTe08]W=`2;IcL0RfLg0P2<J3P308eY>@80SV/c
00<0SV/e08iZ=P2>JSP00P2>JSX01`2>JC`0T6Tn091Z?@2@JSd0T6Xk091Z>@2@JcL00P2@JcH3099]
>@80TF`h0`2@JcL308mZ=@80SVTd0`2=J3<308]Y>@0S08UW=`27ICD0QF<c08AR<P25Hc<0Q6@c08=S
<P22HS<0PF0c07mN<`1nGC@0OE/e07aJ=01`Ebh0KUD/06]D:`1WDBX0HThY05i<:01LBBP0F4PV05M2
9@1E@R@0DD0T04ln901;>b80B3TR04@h8013=b40?C8P03`a7`0i<1l0=RlO03<]7`0_:al00P0^:Qh0
0`0/:Qh0:RXP02XZ800202TY7`80:2PN0P0W9ad202@U7@808b@L0P0R8a/2024R6PP07b8K2`0P8a`2
01lR6`<07R4J200L7Q/201/M6P@071hK0P0M7a`0300L8AX07B8K020S6P0S9AX09BLJ02PX700/:Qd0
;B/N02hY5P0`:aP0<RdJ03@_70@0=S4N00P0:2PP02LW7`0V9Q`09BDK02HV6P0Y:Ad0:b`N02d^8080
<c0O00@0=BlO03H_7`0h;b00>RhP0P0k;B00400i;Ad0>2lN03P_7P0g<1h0=c8O03Db7`0d<al0=C@P
03D`7@0f<Ah0=c8O03Pc800g<Ql0=C0M03<^6`0b;AX202//7P80:R/M0P0Y:Q`202PY6`@0:BTO100X
:1h202@U7@808b@L100R8a/3024R7080824K0`0O81X801lR6`07020S6P0T9Ad09BHN02@T6P0P81H0
8AlC02@R5P0202LU600H02HM600_9A`0?S4Q04hn9@1OC2/0LUdb08I_?@2DNdD0V7a<09IkC02?Md/0
Pfa3075M>P1OC2`0C3dP040`5P0g<1d0<b`J02lY6@0_;1d0<34S030b9`0[;R<09bXQ200Y;2<302X[
8`@0:b`T00L0;2dU02d]9@0^;R@0;blU030`900a<R@0<c@T0080=3DS0100>CLX03Pf9`0g=2<0>C@Q
03/d8@0n=R40@CTR04Dj9014@2L0AClW04I0:018@2T0Bd0Z04e1:`1@@B`0DD8]0`1BAb/20556:P0c
04m4:01>@bL0CT<W05E69`1FAbP0F4TZ05U::`1HBBX0ETLX05A59P1B@b@0F4X]05I8:`1EAbX0DdDX
05949`1CABP0E4HY05E7:P1DART0E4DX05A39`1C@RH0ET8W05Q3:01LA2X0GDD[05a3901RBRP0JDl/
06mC:`1bEBT0NEX[081R;P27Ic@0Tg4d09Ec=P2EMCX0UGHm099e?@2=LcX0RFhg08I]=@21JSh0OFHj
07YR=P1iGS40NE``07UJ;01kG2h0Oel`0080T6X/01@0Tf/]09E^;@2HLB`0W7@^09mg;`2QNC40WGhn
09]k?P2FN3`0T7<i08Q]=P21J380OF<`07QQ;`1]GcX0KEdi06YJ=P1YESD0Ie@c06IB<@80IU4b00P0
L4h[075?:P1cD2X0Me8X07YC:01oERP0PETX08=I:@80S5lX00L0T6</09EX;`2GJS40V6Ta09U[<02N
L3D0XgDj0080XW4f00<0XG<g0:5e>02PMcT00P2PN3X0702ONCX0Wgdf0:5n>P2QOS`0Wg`j09ik>`2N
NS`0W7Pl09Ue>@2IND00VGQ209Yg@@2IM400Ufln09AY?02@ICX0Sf8h09=X<@2AJ300T6La08mW<`2>
JC@0Sf/g091_?02BLCh0Tg0h091]=@2<JC4208UV;P0408]X<02?K3@0TVlg09A_>080Tfhg0P2BKCH3
095/=@0409Eb>P2DLCT0U74i09Aa>@<0Tg0h0140TVlg09Eb>P2FLc/0UW<k09Eb>P2CL3P0T6de08i[
<`2<JC40QfH`08YY<`2?KSP0TW4k09=b?02@KcT0SF`f08YY<`0308IX=P@0QFLe00@0Q6Hd08QY<`29
JS@0RfXe0P2=JCD00`2<Ic<0S6@a08]S<00408MW=0<0R6Lb00D0RVLa08EY>@23IcL0P6@d07eQ<@02
07]O;`0707aP<01mHC40Pf<b089R<@21Hc40OV8`07eS<00207YS;`0Q07YU<01kFc80Ne/b07UL<P1g
G340M5``079K;`1aG2l0L5/^069>:@1TD2/0Ie<^06QD;`1VDRd0H4`W05U5801E@A`0EclM05Hn701D
?1X0Dc/G05Dm6@1J@Q`0GdLQ069:901UC2@0JU4X06iE;01_Eb/0KEDW06aD901_F2H0LU/Y00<0LeH^
00L0M5L]07EH;01fFR/0Me/[07MK:@1hG2X0M5PX00<0METY0P1fFRX207MK:`P0Nel]00h0M5/R07IM
9@1iH2P0Nf8/07YP;@1fG2/0LULX06mD9@1^F2H0KUPW06aF9@1ZE2D0JE8V06M@9P80IDhU00P0H4hV
05i<901MBb<0G4XR05e;8`1OCBD0HDlW069@:080FDXS0P1JBb@205]<9@80G4dV00@0FD/T05M98P1F
B240F4XS0P1LCRL0101HBR<0E4HO05=99@1CBBD205A:9P@0ED/W0100BdDS04Y48P1;@R40C44Q04m2
8P1A@R<0Dd@U05E49P1BAB80DD@Q04i48@1;@R40Ad4Q04@o8@13?R00@CdP0P0n>A/01P0l>1/0>3LK
03Hf700b=1`0<C<K030d7@80<c0M0P0b;a`2034^6`80<2dJ00P0;B`J02d[700Z:a/0:2XL02LY700U
:1d08bTO028X7P808RDL00<08B@K020S6P0O8QT00P0N8AP0100M81L07B0I01dP6@0M81T201`O60<0
6ahG0P0J71T201TK608061XG0P0G6AH801LI60P05QPG0P0F5aT401DF62/051DG200A5aL8018C5B00
51DG400E5QP301@F5@<05ALF4P0F61L00`0I6aX051HE018D4`0201DG5P03018D4`0D5QD06A/J00P0
5QPG2@0G6AP801PH60P06A/J200L71X301`M5`807AhH0`0N7aT8024P6`<08b<K0`0T91`202DU7@<0
8B4I0`0R8QX202<S6`08024R700R8A`08b<K02HS6P0X91T0:bDI02`T5`0]9AP:02XT6080:bDI0`0/
9QX02@0]9a/0<bHN03@W7`0d9ah0=2PL03DY6`0e:AT0=RXJ03H[6@0203HX7`0303LY7P0h:Qd0>B`L
0080>RdL00@0>bhK03X]700j;A`0>RdL0P0k;Qd303`_7P0403X]700k;Qd0>bhM03`_7P@0?C0O0P13
=2401014<b40AS<R04Hc8P19=2<204Xc8`80@c0O1014<B0204Db8@H0@c<L0P12<Q/2048_7PX0@c0O
0`12;ah2044^7@P0?c0M00<0?C0M03ha7P0o<Ql00P0o<Ql02`0m<1d0>bhK03X]6P0o<R40?S4P03d`
7`0l;ah0>bhM03X]700i;1/0>2/J0080>b/L00H0>2/K03HZ6P0c:QT0<BXH030Y5`0_:QL203H/8080
=B/O0`0d:Qh00`0c:Ad0=b/O03L[7`0203L[7`@0=RXN00<0?RdM03l^7P0o;Qh00P0o;Qh3040_7`<0
?bhL00<0@2lM044`7P11<1h00P12<Al00`14<b40@S4O044`7P02040_7@03044`7P12<Al0A3<Q0080
A34R00H0AC8Q04Dc7`16=1h0AcDM04Pf7P19>1h204lg7`04050h801A>B40DSXR05<k8`80E3`T00P0
DC`O058m801E?B40EcdR05Tn8`1L?R@0GClU05hn9@D0H4<S0100HD@T06959@1RABD0HdHV06A79`1U
B2P0ITTY06E8:01TAbL0HTDU0654901RA2P0HD<W06129P1O@BD0GT0T0`1M?b<02@1J@B<0G4<U05e4
9P1NABL0GD@V05]2901G?R00EC`N05<m9@02058l9003054k8`1@>R80CcTQ0080CSPP00P0DSLR050g
8@1@=b40CCLP04/g7`18=Qh0AcLN04Hf7@T0A3<O2014=Ah804De7P0804Ld9@16<b80AS<R04Hd8017
=Al0BCLO04Xi7`1<>b4805<k8`P0DcdU0P1J@B<305]290<0G4<U00<0Hd@X06529P1P@BD00P1N?b<0
101O@2@0H44U06529P1P@RP305m19`80GT0V0P1M?bD03P1K?200FS`P05Tk8@1F>R80E3XS058i8`1@
>RD0CcTT05<i8P1B>R80DCTQ04hh801<>1l0BCPN0P17=ad00`1A>B40Dc/S05@l900205Hn9P0405Dm
9@1D?2@0Dc/S05Hl9@80EC/T00<0E3XS05<i8P1B>2400P1A=b03050h8080DCTQ0`1@>2000`1A>280
DSTS058i8`0205<j90<0E3/U201C>b<00`1E?BD0E3`T058j8P02054i8@03058j8P1C>b<0E3`T00P0
DCTQ0P1F?24405Lm8P80ES`Q2@1H?R<206129P80Gd4U00L0GT0T05do8`1M?b<0G3hR05`o7`1N@B40
H4<S0080HTDU00<0HD@T05m28P1N@B400`1K@R@205Y18`80FD0R00<0F3lQ05do8`1M?b<01P1M?b<0
201P@RH0Gd4U05i0901M?b<0GT0T05m19@1Q@bL0HT@X101SARP406959`P0GdHX0P1MA2D00`1NABH0
GdHW05m69`0305m69`<0GdDT101PARD0101QAbH0GdLU05m79@1OAbD[ooooo`00:_ooool209Y^?@<0
Vfln0`2LL3l209Y`?P@0W7900P2JL3h209]b?00309]b?P2KLCl0Vg510080Vg1300<0Vg1509mc@P2P
M4<00P2PM4<20:5eA080XWI500<0WgI209ie@@2MM4000P2LLcl00`2NMD40X7M30:5hA0030:1d@`80
Wg=20`2NLT4309id@P80WgE30`2PMT@01@2MLd40WWA209id@P2OMD<0X7I40080XGM500<0XWQ609mc
@P2OLd800`2PM4<30:5eA0<0XGM500H0X7I409me@`2OMD<0WWA209ec@@2LLT0209]`@`0309Y_@P2I
KT40V6e00080Uf`o00`0UV/n09EZ?@2DJC`0TfPk099W>P2@ICP0Sf@g08iS=P2=HSD0QF0f08AO=@22
GC<2085L<P03089M<`23GS@0Q5le0080OEXb00@0O5Ta07]H<01jEbl0NEH^0P1hEBd0201cDRl0M5<`
07ED<@1eE340M5<`079A;P1`Cb`0KTdZ101[CB/206Y<:P80JD/Y00<0JT//06U::`1WB2T00P1UARL0
0`1VAbP0IdPY06Q9:P0206Q;:`H0IdXZ0P1]C2d0301_CRd0L4l/079B;01cDb`0M5@]07AD:`1cERh0
MeL`07YJ<@1nGC80PElb08=N<@80Q5h_0P27HC@01028HSD0RF<f08YT=`2;ICP208aV>@06091T=`2?
I3L0Sf@g08iU=`2<ISL0RfLg0P29IcL208mY?0H0SVPk0P2=IcX208iX>`80SfTl0P2@JSd208mT=`05
091U>02BIcX0TfPk09AY?02EJSd01@2FJch409EZ?@0609=Y=`2DJSP0U6Xh09E[>@2FK3X0Ufdk0P2H
KS`809Q_>`T0VFhk0`2GKC/509Q^?0P0Vg0m00P0Xg110:1`@02PL400WW0o09]_?P2IKcd0V70m09M_
?0P0VFlm202HKS`01@2AK3P0TVdi099]>@2CKSX0U6lk0080UG0l00<0UW4m08mY>P2?JCX00P2@JS/0
102?JCX0SFLh08]U=P2:I3D408eX=00408iY=@2?JSH0T6/g091[=`80TV@c00H0TFDd091V=02@J3D0
SVTe08mZ=P2>JSH208]W=`80S6Ph0P2=JCT208iZ>P80SV/c00<0SV/e08iZ=P2>JSP00P2>JSX01`2>
JC`0T6U0091Y?P2@JCh0T6Xm091Z>`2@JST00P2@JcL3099]>@80TF`h0`2@JcL209=^>@80TVdh0`2A
K3L01@2@JcH0S6Xj08]Y>@29IcL0R6Hf0080QfDe00P0QF<c08=Q<@21Hc40PF<a081Q<P1nGc40OEhb
07]K<P80NUXc01H0KUD]06eD;01ZDR`0IDlZ061<:@1KB2L0FDHV05I69@1D@2D0DD0T04ln901<?2<0
BCXS04Di8`12=b40@CHR03Xa800i<1l0=c0P03@^800`;200;B/O0P0/:Qh402TY7`80:2PN0`0W9ad3
02<T70808R<K0`0Q8QX801lR6`X082<L0P0O8Q/201hQ6P807B0I200L7Q/201/M6P8071hK0P0M7a`2
01hP7@0601dS6@0N91X08RDJ02DW700W:A`0:BXL0P0/:Q/0100^:AH0<2/H03<^6`0e<1d203Ha7P0:
03D`7@0d;a`09RDQ02DT7`0V9Qh09RHL02PX700Z:ad0;BhN02h_7@80=34N00@0=S4N03L`7P0i<1l0
>blO0P0l;al02`0h;1h0=bhO03L^7`0f;al0=S0P03@a800c<R00=3<Q03@_700e<1d0=S4N0080=c8O
00<0=C0M03@_700b;AX00P0[;1h202X[7@80:BXL0P0X:A/00`0Z:R00:BTO02TY7`0202PX7P809bLM
00<09RHL02<T700S91`00`0R8a/3024R6P808B8L0P0P8A/201lP6P807QlI200O8Q/01`0R9Ah08bHO
02@U7@0Q8AL07a/?024K3@0V7`l00P0Z8a<0600c8AD0@C0P05Q4;01ZECH0NV<j08E]?@2@Md40UWa3
09IkCP2;LdL0O6Ho06]H=`1IBRd0B3`T03de800j<b40<c4R034_800`;R40;c0R034a9@0_<B@0:bdR
02HY7PP0:B`S0`0Z:b<00`0[;2@0;2dU02`]9@0202d^9P0A02h^9P0^;R@0;blU034a9@0b<bD0<c@T
03@e8`0e=R@0>CPV03Pg9@0h=B80>SDQ03dg8@11>B80AChT04Y09`17@bP00P19@bT00`1;A2X0CT@[
04m3:`020593;00405=8;01BAb/0DDHZ0515:@80Cd@X0P1>@bL00`1DABH0ETLX05Q9:P0205Y;;00S
05M8:@1DABH0DT<T05Y;;01IBR/0EdPY05I7:01EARL0ETLX05M8:@1HBBX0F4TX05Q89`1GAbH0F4DU
05Y59P1MARL0H4LY0658:P1RB2<0IddX071D;@1eF2h0NEX^07eM;P23Hc80RFPe095a>02BLST0TW<l
095d?02<LCX0Qfhh089X=@1mIS800P1kHST09P1jGc@0MeX^07UJ:`1nGRd0PF4^089Q;P2EKR/0UVl/
09Ub;@2JMBl0WGPa09mk<@2PO380WW`b09]o@02HNcl0T7Hm08Q_>@1oJ3H0N60b079K<@1_FC00J5Tj
06MF>01WE3@0IE0a06E>;`1WC2h0JTd_06]><01cCBP0MDlZ07QA:01nEBT0PUPX08IK9P29GRL0S5lV
0P2CIBL01`2HJR`0WFla09ma=@2MLC@0Wg<f0:Ag?02XNd000P2UMc/01`2TN3/0XWTk0:5i>`2PNS/0
XG/l09ml?02LOCX00P2KO3/00`2LOCd0Vg/n09If>`0209=c>P0C09Mf@02GMT40Ug<o09I`?`2DJcd0
T6Dj08aQ=`2:GC@0Sf@]08iU;@2>IBl0SVHb08eX<`2>JSH0Sfhk091_?02BKcL0T6de08aY<@0208UV
;P0;08aY<@2@KCD0Tg0h09Mc>@2FLSP0UG4g09A`=P2CKcD0TVhd095]<`2@K3800`2ELSP209Aa=`<0
Tg0f00<0TFhd099_=@2DLCL00P2ELSP01P2CL3H0TVle095^=029J380S6/e091_>@80Tg8l00<0TG0j
08e/=P2:JC<00P28J3L208MW=P0=08IV=@25IC@0QFDd08EU=027Ic@0R6Pe08YY=P2=JCL0S6Pf08aV
=@2<I3<0Rf<b08YW<@0308QW<P@0QVHc00@0Q6Ph089V=P20I3@0OV8b101mHC4208=S<P06089T<P20
I380OV@a07aU<@1kI300NVD`0P1lGC40101jGC40N5d`07IN<01eGc0207AO<080J58]0`1WDB`306I@
:`0@05i47`1K@A`0EcdH05@j5`1E>aP0FClN05e38P1QAbH0HTXT06M@9`1/EB`0KUL]06aE:@1ZE2D0
K5HU06iH9`<0LeH^00H0M5L]07EH;01fFR/0Me/[07MK:@1hG2X207AH:0<0METY0`1fFRX807]O;@0>
07AK8P1fGBD0NV4Y07aS;@1kHBh0Med/079G:01_E2D0L5XX071J:@1^F2L0K5HW06]D:01YDRP206M@
9`03061>9P1OCBD0GT`T0080GT`T00<0GddU061>9P1QCbL00P1IBR<205Y;9080Fd`U0P1LCBH0101I
Bb@0EdTR05I88@1IBb@205a>9`0305Q:8`1DAQl0ETXT0080ETXT0`1GBbD205Q<9P80BdDS01H0Bd8Q
04a18@1>@B40D44R0593901D@bD0DdHS05958P1>A240C4<R04Q28P15@280A3lQ048n8@0o>Q`0?STK
03`h6`0i>1`0=SHL03<e7@0b=1`0<3@M0P0c<1d2038_7080<BhK0P0`;AX01P0_;QX0;RdK02`]6`0Z
;A`0:B/M02L[7@8092XN00H08bHM028U700R9A`08B@K020S6P0O8QT201hQ60807R4J0P0M81T201`O
60806ahG0P0J71T201TK608061XG0P0G6AH801LI60P05QPG0P0F5aT401DF62/051DG200A5aL8018C
5B0051DG400E5QP301@F5@<05ALF4P0F61L00`0J71/04aDD018D4`0201TK6P03018D4`0C5A@06Q`K
00P05QPG2@0G6AP801PH60P06A/J200L71X201`M5`807AhH0P0N7aT201lP6PP08B0K0`0S8a/302@T
70809BDM0P0Q8AT3028R6P<08b<K00H08B8L02<R7@0S8a/09R<J02PT6@0[9AT202dU60X0:R@H0P0[
9AT302`V6P0602dW6`0d9al0=2LO03DX7`0e:Ad0=RXL0P0f:QX02@0g;1X0=RPM03LY7P0g:A`0>2/K
03T/6`0j;A`0>bhK03/_6@0303X]7080>bhM200l;ah02@0m<1l0?S4P03ha8012<b00@c@Q04@c8@15
<R40AS<R04Pc8P0204Xc8`03048_7P13<1l0@c0O0080A34P0P15<R400`16<b80@c<L04<c700404<c
7080A3@M1P13<1l2048_7P<0A38N1013<Ad2048`70P0@C0N00<0?C4K03hb700o<ad00P10=1h02`0n
<Q`0?C4K03/_6@13<b<0@S8R044a8@10<200?RhN03d]7@0l;1`0>b/K0080>b/L00H0>2/K03HZ6P0c
:QT0<R/I034Z600`:aP303H/8080=B/O0`0d:Qh303L[7`80=RXN0`0e:Ad303h]7@0303l^7P10;al0
@2lO0080@C0P0`10;ad4044`7P04048a7`14<b40@S4O044`7P80@2lM00/0@C0N048a7`14<b40A34P
04Db8@16=200AcDO04Pf7P18=ad0BCPN04Th7002050h8004054i8@1B>R80DSXR05<k8`80E3`T0P1C
?R401P1F?R80F3hS05Xo901L?R@0GClU05hn9@80H4<S00<0HD@T06959@1RABD00`1RABD0201TAbL0
IDPX06I9:@1WBRX0ITTY06E8:01SARH0HTDU0`1RABL00`1QA2H0H4<U05m2900205i18`0805e2901N
@bD0H4DW0656:01PABL0GD8T05Xo8@1H?Al205Hn900305Dm8`1D?280Dc/Q0080DSXP00T0DCTO05@i
901B>B<0DSTS04li8P1<>200BCLO04Ph7`17=ah06@15=Ah02018=BH0Ac@S04Db8@15<al0AS@N04Pf
7P1;>R00C3/Q201C>b<805Hn9P<0Fd8T0`1L@bD205e49P80HT<V0`1P@B@00`1Q@RD0Hd@W06A5:002
0653:@<0H48X0`1O@BL02@1L?B40FcdQ05Xl8P1G>b<0EC/T05<j901A>bH0D3XU05@j8`02058j8P03
04li8@1=>B00BSTO0080B3PN00P0DCTQ058j8P1D?2@0EShV05Lo9`1F?RH0ECdU05@l9080ES`U00<0
EC/T05@j8`1C>B800P1B>240101A=b00DCTQ054i8@1A>B42050h80<0DCTQ0`1@>R<2054k9080DS`U
00<0DcdV05<k8`1C>b<01P1C>b<01P1G?bL0ECdU05<k8`1B>R80DCTQ058j8P80Dc/S201A>B4205Lm
8P@0ES`Q0P1G?B8905Tn8`80HD<W00<0H48V05m19@1N@2@00P1M?b<01P1L?R80GD0P05i18@1P@b<0
HD@T06959@80HD@T00<0H4<S05a39@1L@bD00P1K@R@405Y18`@0GClS101N@2@206129P0605m19@1N
@2@0Gd4U06129P1RA2P0I4HZ101UARL406I7:0P0HDHX101PARD206579P0:06989`1SBBP0GD0P05e0
801O@R80HD@T06A79`1VBBT0J4/[06U<;0<0GTHT:oooool002[ooooo0P2JKSd309]_?P<0W70o00<0
Vg4o09ab@02LLT000P2MLd4209ab@00609]a?`2KLS`0Vg8l09]b?P2KLCl0Vg510P2KL4<0102KL4D0
WW9109ib@@2NLT4209mc@P<0X7A300<0WgI209ie@@2MM4000P2LLcl00`2NMD40X7M30:5hA0030:1d
@`80Wg=20`2NLT40102MLd40WWA209id@P2NM48209me@`80X7I40`2OMD<30:1fA080XGM50P2OLd83
0:1d@`<0XGE4102PMT@209me@`0409id@P2LLT00Vg4o09]`@`80VVm200<0VFi109Q]@02GK3l00P2F
Jch05P2DJCh0TfPm099W?02AIS/0Sf@i08iS>02=HSL0S64f08=P=P22GcD0PEhd081M<`1oG380P5dc
089O=@23H3H0OEXd07aI<`1kF380NULa07QE;`1gE2h207IC;@09079A;P1cDRl0M5<`07AC<01cDRl0
LE0]06m>:`1]C2T0Jdd[00<0JT`Z0P1YBbT206Q::00306Y;;01YBR/0IdPY0080IDHW00<0ITLX06M8
:@1XBBX00`1XBb/306M::P80ITTY00D0K4//06i=;P1`Cbh0LU4^07=C;@0207AD;@0707AD:`1bEBd0
MUH_07UI<01mG340PElb08AO<P0208EO<080Qf4d00@0R68e08US=P2:I3L0RfDh0P2<IST01P2?HcH0
SV<f091U>02?ISP0SFLh08aX>080R6Hf00D0T6Xm08mY?02>J3/0SFLj08aV>@0208eW>P0308iX>`2=
IcX0SFLj0080SVPk0P2?JC`2091Z?@80TVLj00@0TfPk09AY?02DJC`0UFXm0P2FJch309M/?`80UV/n
0`2EJSd309=Y=`<0U6Xh0P2EJcT809Q_>`T0VFhk00H0UF/i09I/>P2FK3X0Ufdk09Q^?02IKcd209Y`
?PP0Vg0m00H0XVm00:1`@02OKcl0WW0o09a`?`2JL3h209Ua?PP0VW0n202HKS`409=^>P@0U6lk0P2@
JS/2095[?005091Z>`2>J3T0S6Hg08]U=P2=J3@00`2<Ic<0102=J3@0SfXf091[=`2AK3P209=U=003
095U=02AIcD0T6Pe0080SfXf00@0SVXf08aX>02<J3P0S6Ph0P2=JCT308iZ>P80SV/c00<0SV/e08iZ
=P2>JSP00P2>JSX01`2>JC`0T6U2091Y@02@JD00T6Tn091Z?@2@JS/00P2@JST3099]>@80TF`h0`2@
JcL309A_>P80Tfhi0`2BKCP0102=Jc/0RVPh08QV=P27ICD208QV=P0808ES<`22H300OV8`07eQ;`1l
H300Nel`07UL<01hFc4207MJ<P0F06eC;P1/DRd0J50/06A=:`1NBRT0FDHV05M4901C@R@0DD0V04lo
9@1=?B@0BS/T04Di8`12=b<0?cLR03hf8`0h<B40=c0P03D_8@0a;B40;R`P02XZ8080:BTO00<09bPP
02TY7`0Y:Al00P0X:1h302LW7@0302HV700S91`08b@L00808R<K0`0Q8QX00`0P8AT07b8K01lR6`06
01lR6`<08B@M0P0P8a`601lR6`807R4J0`0M81T801`N6`806adJ0P0L7Q/02P0M7a`07R0M01lQ7P0O
8Ah07R@J01lU6@0T9a`09bTL02PZ700Z:a/202`[6@0@02lZ5`0a;1T0=2lL03Ha7P0g<Ql0=C0M03<^
6`0b;AX09B<T02DT8P0V9B00:2PP02TZ700[;1`0;BlJ02h`6P80=38M00@0=c8N03Pa7P0j<Ql0?34O
0P0n<B001P0i;B40=bdQ03L]8@0f;R40=BlQ038_8080<BlP00<0<RdJ03<^6`0d;a`00P0e<1d00`0d
;a`0<bhK038]6P0202//7P80:R/M0P0Y:Q`202PY6`80:RXP00<0:BTO02PX7P0W9ad00P0V9Q`0100U
9A/08B@K024T6`0Q91/2020S6P<07b8I0`0P8A/201lP6P<07QlI200O8Q/01`0O91h082DN02<T700S
8AD08ad?02LN3@0`9A<00P0g:QL0601:<QH0Fd8T075I=`23JD@0SG97091dA02@MD00TW@n08M^A@1h
HCP0He4]05A5:014>B<0=c8O03<a900g=bd0<C<X030b9`0_<BH0;S0U02d_8P0/;R40:R`O02PZ7@P0
:2/R00H0:BXR02X[8`0Z:b<0:b`T02`]9@0];RH202h_9`0602h^9P0_;bD0<30V034a9@0b<bD0=3DU
0P0e=R@203Pg8`0<03Xh8`0n>B<0@S`T04Ho9@19@RP0CD<X04U5:01:ABP0BdHY04a5:@1?ABX0D4@Z
0P1CAB/00`1BAb/0DDHZ0515:@0304i39`0504m4:01@ABT0E4DV05E69`1GB2T00P1HBBX01P1GB2T0
EDHW05=49@1KBbX0FTXY05Q89`80EdLV04<0F4PW05Y::@1KBbX0Fd/W05e;9`1KBBD0G4PU05i79@1Q
BBL0I4XY06E;:P1YCBD0Ke@Y07II;`1lGC40OUd`085O<@25HcD0RfLg08e^=`2>KcT0SW0j08]`>`27
KCX0P6Tg07]S<`1gHC00N5`e07aP>01kGS@0NEX/07aL:`26IC00RVTc08]X<02KLbh0WGD`09mh<`2P
NcD0Wgdf09el=`2INcD0V7Xd09Il?`2ANCd0RW4i081Y=`1hHCD0L5Xc06YF<`1XE3<0Je@e06UB<`1Y
CS00JT//06e::P1`C2X0MD`/07U>;01iCbT0O58Z085F:`27FbX0SV0/099T:@2DIRP0UfLW0080WF`Y
02X0XG0]0:Ee<`2TMcH0XWHg0:5h>P2UOCl0ZH540:Ql?`2WNch0Y7/m0:9j?02PNS/0Wg`l0:1m?@2O
OCd0V7`k09Ei>P2FNS/0VWe109Mj@02?LSX0Rfdg08e_>@2EMCX0UGDl09Ic>`2EL3/0Tf/h091V=P2<
HC@0RUha08mT;@2>IBd0SfH`08mW<`2>JC@0Sf/g08i]>P2?KS/0U74i099_=`2?K3@208eZ<P0408m/
=02AKSH0Tg0h09Mc=`80UW8f00<0U70d09=_<`2BKS800P2AKC4509Ab=@<0UG<f00<0T6ha095_<P2C
LC@00`2ELcH02`2DLSD0Tg4d08i]=`2?KSP0TG0j09=b?02BLC/0T6li08e/=P2;JS@0RfTi0080RVPh
00<0RFLg08QV=P27ICD00P26I3@00`26ISD0QfLf08UW=`0208aX>00308aV=`2<HcD0Rf8d0080RfH_
00@0RVLa08MV<@26IS<0Q6Hd0P22ISH01023IcL0PVHf085U=@1oHc<207iR<P80OF4a01<0Pf<b08AT
<`23IC<0PVHd081V<`1mIS80O6Da07YU<01lGC40Ne``07UL<01hGC00MUh`07EO<01dGc00Leh_06iF
<01[Dbd0J50Z0080IThX01<0J50Z06]C;@1^ES00Id/S06A88@1PA1l0G40K05Xm7@1L?al0GT4S0653
9`1NB2<0HddV06UC;01[EB`0JE@Y06MB9@1XDb@0JUDV00<0LUD]00H0LeH/07AG:`1eFBX0MUXZ07IJ
:01gFbT307EI:@80MUXZ0`1gFb/307YN;080Nel]0`1lH2h04`1eG2<0MehV07YQ:@1lHbd0Nf4^07MM
;01cF2T0L5DV079L:P1aFbX0L5XY06iH:@1/EBT0JU<Y06UB:@1XDBP0HU0X065?9`1PCRH01@1OCBD2
05U:8`80FT/T0P1KC2D205a=9P0405Y<9@1HBR<0EdTR05U;9080GDlX00<0FD/T05A67`1GBB801`1G
BB80201<AR@0BdDS04]28@1;@200CD0P04m08@1A@R<0Dd8T0P1CAR<01P1?AB80CD@S04U38`16@B<0
AD0R04<o8P80?cXL00H0?CTL03Th700g=ad0<cDM038d700a=Ah203<`7@80<RlL0P0a;Q/2030]6P08
030_6P0`;a/0;BlJ02/^6`0Z;A`0:2`M02H/7P0U:ad202<V7@03028U700Q91/082<J00807b8I00@0
7R4H01hQ6P0N8AX07R4J0P0M81T301`O60806Q`I0P0I6aP201PJ5`805aTF200G6AP801HH5`805QLI
100E5QP[01@E5`P04ALG200B4aDP01@E5a005AHH0`0D5QD301DG5Q805QPG00<06Q`K018D4`0D5QD0
0P0P8R400`0D5QD04Q@C01XL6`0801HH5`T05aTH200H61P801TK6PP071`J0`0M7QP201hO6@<07b0J
200Q81/3028R6P<08b<K0P0T91`0100Q8AT08R8J028R6P0R8QX202<S6`8092@L00P08R<M02<R7@0T
91`09b@K02TU6P0/9QX0;BDH02hV6@P0;2HJ0P0[9AT202`V6P80;BLK0P0^:1`203DX800303HY800f
:Qh0=b/M0080=b/K00T0>2dK03LY700g:A`0>2/K03T/6`0j;A`0>bhK03/_6@0l<1X00`0j;A`203/^
7@<0?2lN00P0?C0O03`_7P0l;ah0>bhM03`_7P0m<1l0?S4P03lb8@80@C8O00@0@S4O04@a8014<B00
Ac8Q0P18<B42048_7P0404<`7`14<B00A34P04Db8@80AS<R1013<a`204@d7@80ACDN0P14<B0304<`
7`<0@RlN0`15<ad304@b70<0@c4K2012;ah00`0m<AT0?S8J040d7002044e7@08040d700n<QX0?C4I
04Dd8P14<b40@c8P048a7`11<1h203l^700:03h]6`0m;Ah0?2`M03X]7@0h;1`0=B`K03</6P0b:aT0
<B`I03H/80<0=B/O0P0d:Qh203<Y7@@0=RXN100e:Ad203d/700303h]7@0o;Qh0@2lO0080@C0P00<0
@S4Q044`7P11<1h01P11<1h00`14<b40@S4O044`7P02040_7@08044`7P12<Al0A3<Q04<a7@15<al0
AS@N04Pf7P19>1h204Th700304Pg6@1A>B40DCTQ0080DSXR0P1C>b<205@l9080ED0S00<0EclS05To
901J?b@00P1M?bD01@1N?RD0H4<S0654901RABD0HdHV0080I4LW00@0HdHV06959@1TAbL0IDPX0`1V
BBT00`1TAbL0HdHV0654900206=69P80I4LW00@0HdHV0654901O@R80GT4Q101RABD0101QA2@0H4<S
05i18@1M@20205Pn8`80EcdR00X0ES`Q05Dk801D>Ql0E3XO05Hk9P1D>bD0DcXT050j8`1>>R80BSPP
0P18>1l904De70P0AC<M2014=1d02018=BH0Ac@S04Db8@14<Qh0AC<M04Pf7P1;>R00CC`R201D?2@8
05Pn9`<0Fd8T0P1L@bD305e49P80HT<T0`1Q@R<00`1SA2D0IDHW06M8:@030653:@80H48X0`1O@BL0
2@1M?R80G3hR05/m8`1H?2@0ES`U05@k9@1B?2L0DC/V05Hl9@0205@l9003054k8`1?>b80C3/Q0080
BSXP00@0DCTQ058j8P1D?2@0EShV0P1G?bL00`1F?RH0ECdU05Pn9`0205Lm9P0305Hl9@1E>b@0E3XS
0080DcTR0P1B>R80101A>B40D3PP050h801A>B42058j8P08054m9@1@?2@0Cc/S04lk8`1@?2@0DCdU
058n9P1C?bL805@l900505Q0:01F?RH0E3`T058j8P1A>B400P1B>R8905<k8`0305Pn8`1G?B80ES`Q
0080EC/P00<0ES`Q05Lm8P1H?R<02@1K?B<206539`80H48V00@0Gd4U05i0901M?b<0GClS0P1N@B40
0`1O@R80HD@T0654900306959@0405i59`1MA2H0G4<U05]29080FT4S00<0Fd8T05a39@1M?b<00P1M
?b<205i090<0Gd4U00P0HD<W06129P1O@BD0Gd4U06129P1RA2P0I4HZ06E7:`80J4LV0`1YB2L306Y9
:0P0I4LW0P1TAbD306=6900;06A79@1VBBL0IdXX05dn7`1N?b00H44R06=49@1VAbP0JDX[06]<;@1/
CBh00`1OAbD[ooooo`00:_ooool209Y^?@<0Vfln0`2LL3l209id@P@0WG=10P2NM48209Ya>`0309Ya
?@2JL3h0VW100080VVm200<0VVm409a`?`2LL3l00`2MLD0309ib@@0309mf@P2NMD40WGA00080W7<o
00<0WWE10:1g@`2QN4@00`2PM4<209mc@P<0WW910P2MLd4309id@P<0WgE30`2QMdD30:1fA080WgE3
0P2OLd830:1d@`<0XGE40P2OMD<01`2PMT@0XGM50:1fA02PMT@0WWA209]a?`2JL3h00P2JKd80102I
KT40V6e009M/?`2GK3l209I[?P80TfPn00@0TVLm091U>`2?I3X0SF8h0P2<HCL00`23HSL0PV4f081O
=002081O=003085P=@23HSL0Q6<h0080O5Pd00H0NUHb07UE<@1gDbl0MU8^07EA;@1dD2`2079A;P80
Le8_00@0LU4^071?;01^CBX0KD`Y0P1ZC2X206U;:@<0J4XX00@0IdTW06Y;;01YBR/0IdPY0P1UARL0
0`1VAbP0IdPY06Q9:P0206U<;080J4/[00T0IdXZ06I9:@1VBBT0ITTY06a;;01^CBh0L4l^07=B;`1d
E2h00P1dE2d02@1cDbX0LE@/07EE;P1iFC00OE`a085O<P24Gc80QV0a08EO<00208MQ=00408QR=@29
HcH0RV@g08]U>080S6Hi0100SV8e08iS=P2@ICP0T6Li08iX>@2<J3P0R6Hf08MU=@2AJch0T6Xm08iX
>`2<IST0RfDh08aV>@2=IcX0SVPk0P2=IcX208iX>`80SfTl0P2@JSd809I[?P80V6e00P2GK3l0102F
Jch0UFXm09EZ?@2EJSd309M]>`<0UV`j0P2EJcT809Q_>`T0VFhk00P0TfTg09AZ>02EJcT0Ufdk09U_
?@2KLCl0W79009ec@@P0Vg0m00H0X6dn09i^?P2OKcl0WW0o09a`?`2LLT0209]c@0P0VW0n202HKS`4
09A_>`@0Tfhj00X0TF/l099/?@2CKCh0Tfdn099/?@2@JS/0SVPi08aV=`2=J3@0S6Lc0P2;IS80102<
Ic<0SVTe095/>02BKCT209=U=003099V=@2AIcD0TFTf0080SfXf00<0SVXf08aX>02<J3P00P2=JCT4
08iZ>P80SV/c00<0SV/e08iZ=P2>JSP00P2>JSX01P2>JC`0T6U2091Y@P2@JD00T6Tn091Z?@80T6Xk
00@0T6Xi099]>@2BKCT0TVdi0P2AK3P3091[=`04099]>02AK3L0TF`g095/=`80T6/f0P2?JSD0102>
K3`0RVPh08IT=027ICD208UW=`0808ES<`21Gbl0O68_07]Q;P1jH2l0NEh_07ML;`1fFc0207EI<@0F
06eC<01[DBh0Idl]069;:`1LAbP0F4DU05E2901A@280CclV04hn9@1;?2D0Ac/S04<h8P0o=b80?SHS
03`e8P0f<200=S0R038_800`;200;B/O02XZ80<09bPP0`0X:1h302LW7@809RHL0`0R8a/3024R6P80
824I200O8Q/00`0R9Ah08B@M024T7@02020S70807b8K00<07R4J01lR6`0O8Q/00P0N8AX401dP6@P0
71hK00H06Q`I01/M6P0L7Q/07AlL01hP7@0O8Ah2020R7`0;01lU6@0P9QP09BTK02PZ700Y;1/0:R/I
02`[5`0[:QH0<B`I03<^6`0f<Ah00P0g<Ql02`0d;a`0<B`I02hY5P0V92L09R@U02LV8P0Y:B40:R/M
02//6P0/;QP0;BlG0080<c4J00@0=S4K03Pb700k<ah0?S<O0P10<b001P0j;R80>2hR03L]8@0e;B00
=2hP034^7`80;bdN00P0;bXG034/6@0b;AX0<bhK03@_700c;Q/0<B`I030[6080:b`N0P0Z:ad202TZ
7080:2TK0P0Z:R001P0Y:Al0:2PN02LW7@0V9Q`09BDK02@T6P<07R@J0P0M8aT301`R6080824K0P0O
81X401hO6@P082<L00L06b4M01hS7@0S91`09R@H02`U5@0f:aT0A3DP0080CCdV01P0IdXP07AG;@25
J3`0T7=709EfB02BLdD0Sg1208i^?`1dGC@0I4hY05518017>b40>C@Q02XZ7P0Y;2D0;S@`02X_:00Y
;bD0:RdT02P[800X:Ql0:2XM02TY7@0Z:Qh802P[8P0502TZ8P0Z:b<0:R/S02//900];RH00P0^;bL0
4P0_<2P0;RhV02l_9@0`<2H0<C4U03<d9P0d=BD0=CHT03Hg9@0g=R40>CPS03dk9013?bH0B48X04]4
:P1<ABT0CdDZ04Y7:080BdHX00<0CDHY04m6:@1@ABT00P1BA2T00`1@ABT0Cd@X04i39`0204e29P03
04m4:01AARX0DTL[0080E4DV0P1EARL01`1FAbP0EDHW05E69`1EARL0G4TX05]89`1JAbH00P1IARD0
@`1JAbH0G4TX05e::@1PCRP0GddW05m;9P1PBRD0HDTU06A:9`1VC2T0JD`Z06mB9P1eF2`0OEh`081Q
<`20Gc80PV0b08MR=@2:ICP0RFTf08U[=`2:K3X0Qf/k08=X>@1lI3H0MV0a079K;`1gFCD0OEli07mO
=P1jFbd0P60]08e/=P2ELSP0TW0c0:9f=`2RNCT0Xg`k0:9o?`2POSl0VW/k09Ah=`2BMSL0SWPl08Yd
>P22KCP0NF@e071M<`1YEc<0IE8d069A=@1_D340Kdh]06m;:@1aBBH0MTXU07e;9P23CbP0Qe8Z07iB
;@22Ebd0R5`_091R<02GJBh0WFd]0:1_;02QLBT00P2SLBP03@2WMB`0ZWTd0:Qk=`2UNCP0Xg`k0:J0
@@2ZQ4H0Z7m10:Mn@02TO3h0XWXl0:1j>`2NNc/00P2OOCd0202ENch0SgDh091f>`2GOD@0U7Y108Q]
=P23J3<0Qf`g0P2CM3<0302ELc@0UG4e09A]=02BJC<0SVD_08eR;`2BIc00TFP`099Y<`2AJCD0T6/f
091/>080SVdj00@0UW<k09Eb>P2ELSX0U74i102CL3P01P2FLSH0UG4e09Ea=@2DL3@0Tflc099^<P80
TFda0P2CLC@209Ab=@0<09Ec=P2FM3L0UgDh09Me>02CLC@0U78e09Ec=P2FM3L0UG<f09=a=02AKc80
T6ha0P2CLS`0302BLC/0TG0j091_>@2>KCL0SF`f08a[=@2=Jc/0S6Xj08]Y>@2:J3P0RFLg08QV=P80
QfDe00<0QFDd08IV=@28ISH00P2<J3P00`2<ISL0SF@f08aS=@0208eV;@0408]V;`27IS40QFDb089V
=P80P6Df00<0PVHf085U=@21ICD00P20I3@04@1oHc<0OV8b07iR<P23Hc80Q6@c08AV=023IcD0PFLd
07iW<`1lIC40NVD`07]L;P1jFbd0N5`]07ML;@1dG2`0Led/0080LEd[00H0LeXb075H<01]E2`0JU4Y
06U@:01XCbL206U@:00A06mD:@1/D2P0J4`U06=78P1P@b<0Gd8T05m19@1O@BL0F4@O05i:9@1UDRX0
Ie@Z06EB9`1SD2D0He4S06EC9@1`Db/00P1aE2`0101aE2X0LUDY07=G:01dF2P207EI9`<0MUXZ0P1g
Fb/307QL;00307UM:`1jGR`0NUh/0080Nel]0P1lH2h06@1mHBl0MehU07QO9`1jHBT0NV4[07UO;01g
GB`0M5TZ079G:01cGB/0Led/075K:P1`FR/0KUL[06aE:`1[E2/0JU<Z06AB:P1SDBT0HU0X065?9`1O
CBD0GT`T05e;8`1LBR800P1IBR<205Y;9080Fd`U0P1LCBH0101JC2D0F4XS05M98P1IBb@205e?:005
05U;901EAb00F4/Q05Q;8@1GBR000P1FBAl04`1EB1h0E4LM05A77@1<AR@0BdDS04]28@1;@200CD0P
04m08@1@@B80DT4S05A7901CAR<0D4HS04e48`19@b<0Ad8T04E08P13?b800P0o>Q`01P0m>A`0>STM
03Lg7@0d=Qh0<cDM034e7P80<c0M0P0b;a`2034^6`80<2dJ0P0a<1/01P0^<1/0;2lL02/^7@0Y;A`0
9bhN02H]7@808bHM0P0R9A`0100Q91/082<J01lR6@0O8QT401hQ6P807B0I0P0L7aP201XL6@806A/H
0P0H6QL201LI5PP05aTH200F61L201HG6@@05AHH:`0D5AL8014G5`P04Q<E800D5AL801DF60P05QLI
0`0D5QD301DG5Q805QPG00<06A/J014C4P0G6AP00P0W:BP00`0G6AP04A<B01TK6P0801HH5`T05aTH
200H61P801TK6PP071`J0P0M7QP201hO6@@07b0J200Q81/2020P60<08B4I1P0R8QX202<S6`<092@L
00H08R<M02<R7@0T91`09b@K02TU6P0/9QX202hV6@P0;RPL0`0]9a/202hX70<0;bTM0P0f:B400`0f
:B00=b/O03L[7@0203P/700703P]6`0g:A`0=bXJ03P[6`0i;1/0>RdJ03/_6@0203``60<0>RdL0P0k
;Qd303`_7P0803ha800m<1l0?2lN03/^7@0l;ah0?C0O03lb8@10<b8203l`7@04044`7P12;ah0@RlN
04D`7`80ARlO00D0@BhM048_7P12;ah0@c0O04Db8@0204Hc8P0404Ld8`12<Q/0@c<L04<c7080A3@M
0P15=Ah01@16=Ql0A34P04@a8014<B00@c0O0080@RlN0P11;Qd304Hd7P<0AC<M0`14<Q`804D`7`03
03da6@0n<QX0@3@L00<0@CDM00@0?c<K03hb6P14<al0A3<O0P13<Qh03012<Ad0@C0L044`7010;a/0
?blP03h^7`0l;al0>RhN03L^7@0e;Q`0=2dK03<^6`@0=2XN0P0c:Ad2038X70D0=BTM0`0f:Qh01P0l
:a/0?B`L03h]7@0o;Qh0@2lO044`8080@S4Q1012<Al4044`7P0304@c8@12<Al0@C0N0080@2lM00/0
@C0N048a7`14<b40@c4M04Dc7@17=Al0BCLO04Xi7`1:>Ad0BCPJ04Pg6@03058j8P@0Dc/S00H0E3`T
05I1901F@B@0F40T05Y09@1K@2D205do9@0405lo9P1P@b<0HD@T06=69P<0IDPX00`0HdHV06959@1S
ARH0I4LW06E8:01VBBT0IDPX06A79`1RABD0HD@T06=69P1TAbL206E8:00806A79`1RABD0H4<S05i1
8@1UB2P0I4LW06959@1QA2@406138`0605]08`1J?b80FChQ05Tn8@1H?B00Ec`O0P1F>ah0201G?2L0
ESdW05Dl9P1A>b@0Cc/S04/i8@19>B00B3PO2@15=A/804Ha70P0@S8K00P0BCHW04Ld8`15<R40A38N
04Dc7@18=Qh0BcXP04hm8`P0E3`T201J?RP0101K@R@0G4<U05a39@1L@bD205e49P80GTDW0P1R@b@2
06528`0406=49@1UARL0IdPY06U::`80HD<Y0P1P@RP305m19`0705i09P1N?b<0G3hR05`n901I?BD0
EcdV05Dl9P02058l9`0<05Pn9`1G?bL0EShV05<m9@1A?B@0CSdS04dm8`1<?280DCTQ058j8P1D?2@0
EclW0P1H@2P0101G?bL0EShV05To:01I?bP205Pn9`0705Lm9P1F?2D0EC/T05Dk901C>b<0DSXR054i
8@02050h8006054i8@1B>R80Dc/S058n9P1A?BD0D3`T0P1?>b<00`1A?BD0DclW05A0:00805Dm9@04
05U1:@1G?bL0ECdU05<k8`<0DSXR00<0Dc/S05Dm9@1E?BD01P1E?BD00`1H?R<0EcdR05Hl8@0205Dk
800305Hl8@1G?B80F3hS00T0G3hT101P@RH405m19@80GT4Q00h0Gd8R06138`1QA2@0HTDU06=69P1T
AbL0GdHX05i59`1L@bD0Fd8T05Y18`1K@R@0G4<U05e49P<0GClS00<0GT0T05m19@1O@BD00P1P@RH0
201Q@bL0H48V05m19@1O@BD0HD<W06=5:@1UAb/0ITP/0P1ZB2D206]99P0406a:9`1]BbP0KD/X06e;
:0P0IDPX00P0ITXU06E9901TB2<0HdLR06A88`1UBB@0Id/V06Q<9`80ID@U00@0ITDV06M69`1XAbP0
JDPY0P1ZBBX306189R_ooooo000Zooooo`80VVhm0`2KKch309a`?`80WgE3102NM48209me@`80VW4k
00<0VW4m09Y`?P2JL4000P2JKd80102JKd@0Vfln09]_?P2KKch209a`?`<0WG5000<0WgI209ie@@2M
M4000P2LLcl00`2NMD40X7M30:5hA0030:1d@`80Wg=20`2NLT4309ec@@80WWA20`2OMD<01@2SNDL0
XWQ60:9hAP2QMdD0X7I40080WgE300<0WWA209mc@P2OLd800`2PM4<30:5eA00409id@P2OMD<0X7I4
0:5gA@80X7I400<0WWA209]a?`2IKcd00P2JKd800`2IKT40V6e009M/?`0209I[?P0K09EZ?@2CJ3h0
TVLm095V?02@IC/0SV<i08eR>02<HCL0Rf0f08=R=`22HCH0PF0e081O=021H3D0PV4f08AS>025I3T0
O5Pd07]G<`1jES80N5@`07MC;`1eDBd0M50/07=?:`1aD2d0LU4^0080Le8_00D0LU4^071?;01^CBX0
K4/X06Y<:P0306U;:@80J4XX0P1WBBL00`1ZBb`0JDX[06M8:@0206E69`0306I7:01WB2T0J4TZ0080
JD`/0P1XBb/04P1WBRX0ITTY06I9:@1UB2P0K4//06i=;P1aD2l0Le8_07EE;`1eEBh0M5@]07=C:P1a
E2`0MED^07UI<01mG340PElb08AO<P80QV0a0P27HC@01028HSD0RF<f08YT=`2;ICP208aV>@0;08iR
=@2>HcH0T6Dh091W>@2>J3T0S6Ph08QV=P27ICD0TF/n091Z?@2=IcX00`2;ICP0102=IcX0SVPk08eW
>P2=IcX208iX>`80SfTl0P2@JSd309Q]@080Uf`o0`2FJch309Q]@00309M/?`2FJch0UFXm0080UFXm
0P2KLCl209Y`?P0409U_?@2HKS`0Ufdk09M]>`P0V6lk2@2IKS/0202AIcD0TVPf09AZ>02FK3X0VFlm
09ab@02MLd40WWA2202KL3d0202OK3d0WVhn09i^?P2NL3l0WG5009ec@@2LM440WGE2202JL3h809Q^
?00509Ia?@2EL3`0UG0l09A_>`2CKSX00P2BKCT00`2AK3P0TV`m09=]?P0209A^?`0409=]?P2AJc`0
SfTj08eW>080S6Lc00H0RfHb08YU<@2<Ic<0SVTe095/>02CKSX209=U=003099V=@2AIcD0TFTf0080
SfXf00<0Sf/g08aX>02<J3P00P2=JCT308iZ>P0608m[>`2>Jc<0SV/c08i[=@2>JSH0SVXh0P2>JSX0
1`2>JC`0T6Q4091Y@P2@JD80T6U0091Y?P2@JSd00P2@JS/3099]>@80TF`h0`2@JcL308iY=080SFPc
0`2<Ic80202?KCd0RVPh08IT=026I3@0RFLg08YX>025Hc<0PEl_0P1kHBh0701jH2l0N5d^07ML;`1f
Fc00METa07AH<01/DRl0JU0]06M?;@1RBb/0G4LX05M49P1D@B<0D3lS04hn9@1<?R@0Bc`U04Hj9013
>2@0?cLT03`e8P0k=280=S0R03D_8@0b;R80;bdQ02/[8@0X:B4202LX800402DX8@0X:1h0:2PN02PX
7P809bLM0`0V9Q`3028S6`808B8J0`0P8AT801lR6`808RDN00@08B@M020S700P8a`07b8K0P0N8AX2
01lR6`807R4J0`0M81T00`0L7aP071hK01`N6`0601`N6`0P01XL6@0K7AX071hK01dO700N81d07b4N
020R7`0Q8b007bDG024W6@0U:AX0:B/M02X]700[;1X0;2/G02/Z5P0b;AX0=2lL03Lb7`0h<b00=c8O
03<^6`0_:QL0;2LD02HT9`0W9BH0:2LS02TY8@0Z:ad0:b`J02`^600/;QH2038`6@0A03Ha6`0i<ad0
>c<N03ld8011=240@SDR03/^9@0i;bD0>2hT03D]8P0c;B40<2`P02h/7`0]:ah0;RTF02lZ5`0a;1T0
0`0b;AX0100`:aP0;bXG02//7P0[;1h202X[7@80:BXL0P0X:A/202XZ800402TY7`0X:1h09RHL02DU
6`8092@J0`0N91X201dS6@<0728H0P0P8A/201lP6P<07QlI00<07AhH020S700P8a`01P0P8a`01`0I
7a/07B8L02<T700Z:1/0<b`L048e8P1C@b`00P1OCCD0601kGBL0Q6Hb091b?P2FMTD0UGA7091_A02=
K440RfY106I@:@1F@Ql0BCXK04<h8P0e<R409BHN020V8P0V;bh092/T02<Z8P0S:24092LN02<V6`0U
9aX0:BTM02`]7`P0:2/R00H0:BXR02X[8`0Z:b<0;2dU02d^9P0^;bL202l`:00=02l_9`0_;bD0<30V
034a9@0c=2H0=3DU03Df900f=bD0=SDP03Th8`0o?BH0Ad<Z04]5:`0204i7:`070517:P1:AbP0BdHX
04]6:01<ABP0CdHY0515:@020594:@0804m4:01>@bL0CD8V04a19@1=@RH0Cd@X0597:`1DBBd205A5
9P<0Dd@U00D0E4DV05E69`1EARL0G4TX05]89`0305U69@1305Y79P1LBBP0GDXY065?9`1QCRH0H4dU
065;901RBR@0ID/V06U=:01ZCRT0LUHW07QL;@20HC<0Pf<d08=Q<`24Gc80Qf8e08]U>026J3@0QfTg
08IZ>024JST0OfLg07US=01dGC40KeX]07IH=01nH3X0PF4h07eM;P23HRl0UG8j09]i?02IMCL0YGTl
0:Ek?`2VOT40Y81409in@`2HND00T7Hk08ab>@29MCP0QG0g07eY=01fHC@0KETd06MD=01RDCL0HDlg
07=?;@1cCBT0MDXW07I8901nBR<0QT`T08i@9`2BDbP0PeH_08II<02>Gc40UVLc09i]<P2SLS00YWH^
0:Qg:`020:Qd:00W0:Yi;@2/O380ZGdf0:Ik=`2SO3/0YX110:R4AP2YP480Z7m10:Al?P2QNc`0WW/k
09ek>`2NO3`0WGhm09=k?@2<M3P0SGDi09El@`2BND40QF`f07mU<P24JSL0TW@/099d;P2DLbh0UG8`
09E_<02DK2l0TFT^091V;02DJC80TfXb09A[=@2CJcL0TVdh095]>@2?KS/0SVdj00@0V7Dm00@0Ug@l
09Eb>P2CL3P0TVlg0`2DL38209=_<@03099^<02AKBl0TFd_0080TW0a00@0Tg4b09Ab<`2FM3D0UgDf
1@2HMSL02`2GMCH0U78c095_<02>K2d0S6X[09Mf@02FMCl0Tg8l091_>@2>KCL0SF`f0080S6/e00H0
T6`l08m[>`2?Jc/0SFTi08aX>02;IcL208YV=P0@08AT=@25ICH0R6Hh08]V>@2<IcX0S6Hi08eT>02<
HcL0SVH[08eV;@2;IRl0RFH`08EU<P21ICD0P6Df07iV>0@0PFDe00`0P6@d07mS<`1nHS80OV8b08=S
<P24I3<0QFLe08AX=P22J3D0OVLc07aU<@1jIC0207YK;00407MK:`1eFbX0Le`Z075K:@80Ke/X01T0
ME`d07AK<`1bFC40KeH^06]B:P1WCRH0HdXR0658801dEb/0LUD[06iA:@1ZC2P0IDHW06939`1P@2L0
GclX05I27`1MBB@0I50[06IC:`1TDBL0HDhS069@8P1SDB<0Ke8Z0080L5<[00@0L5<Y075D:01bERL0
LeLW0P1dF2H307MK:`80N5`/0`1iGBd207UM:`0407YN;01kGbd0Nel]07aP;P80OF4_0100NF0W07UP
:01iH2P0NF0Z07QN:`1gGB`0MEX[07AI:P1dGR`0Led/079L:`1`FR/0KUL[06eF;01[E2/0JU<Z0P1U
Db/01P1SDBT0HU0X061>9P1MBb<0FdTQ05Y88080FDXS0P1JBb@205]<9@80G4dV00@0FT`U05Q:8`1G
BB80FD/T0P1MCbP0201IBb@0EDLP05Y;8P1IBR40F4TP05M87`1EAQd0E4DL0P1CA1/0601<AR@0BdDS
04]28@1;@200CD0P04ho801@@B80DT4S05E89@1DAb@0D4HS04i5901:A2@0Ad8T04I18`14@2<0@3/M
03lj700m>A`0>STM03Lg7@0d=Qh0<cDM034e7P80<c0M0P0b;a`2034^6`80<2dJ00H0<S8J034`6`0_
<A/0;C0K02`_700Z;Qd202L^7P0602@W7P0S9Qd08bHM028U700Q91/082<J0P0O8QT0100O8Q/07R4J
01hQ6P0N8AX201dP6@8071lH0P0J71T201TK608061XG0P0G6AH801LI60P05QPG0P0F5aT401DF62/0
51DG200A5aL8018C5B0051DG200E5QP801HG6@<051HE0`0E5aHB01HH5`0301TK6P0A4a806A/J0080
;2h]00<06A/J014C4P0I6aX0200F61L901LI60P061PH200I6aX801`L6P807AhH0P0N7aT301lP6P03
020Q6`0Q81/08B0K00H08B0K0P0O7aL3020P60<08B4I0P0R8QX302<S6`<092@L00H08R<M02@S7P0T
91`09b@K02TU6P0/9QX202hV6@P0;bTM0`0^:1`202lY7@<0<2XN0P0f:B400`0g:R40=b/O03P/7P02
03P/700703T^700g:QX0>2/K03P[6P0i;1T0>RhH03/_6@0203``60<0>RdL0P0k;Qd303`_7P0303lb
8@0m<1l0?2lN0080>bhM00<0?C0O03lb8@11=2<00P0n;a`0100o;Q`0@BhM044^7@14;ah204D^7P80
@BhM00@0@RlN04<`7`15<R40AS<R0P17=2<01012<Q/0@c<L04<c7014=1d204De7P80ASHO00@0AC8Q
04@a8014<B00@c0O0P12;ah2044^7@<0AS@L0`15<a/304@b6PP0AC0O00<0?C4G03lc6@10=1X00P12
=Q`00`11=A/0@3@J03lc6@0204Dc7`<0A38N0`13<Ad2040`8@0703d`800k;al0>2lN03H_7@0e;Q`0
=2lL03@Z7P0303<Y7@80<RPL0P0a9a/00`0c9a/0=2PL03@X700203DY7@80=RXN00L0=b/O03`[6`0m
;1`0?B`L03l^7P10;al0@C0P0080@S4Q1@12<Al3044`7P0304@c8@12<Al0@C0N0080@2lM00`0@C0N
048a7`14<b40@c4K04Dc7@17=Ad0BCPN04Xi7@1:>A/0BCPJ04Ph5`1B>R8705<k8`80Ed8U00d0FD4U
05Y09@1K@2D0GClU05i09P1O?bH0H4<S0654901TAbL0IDPX06I9:@1UB2P0I4LW0080HTDU00T0HdHV
06A79`1UB2P0I4LW06=69P1QA2@0H4<S06A79@1UB2H00P1VBBL0301UB2H0HdHT06138@1O@R00JD/Y
06I89P1SAB<0HD<Q0612801Q@b40HT@R06A69080Fd0S00<0FSlR05Tn8@1H?B000P1G?1l01`1F>ah0
F3dX05Ln:01E?2H0DS`U04lk8`1;>B400P19>B0904De6`P0AC0K2011<AX02019=RL0Ac@S04Db8@13
<Ad0A38L04Le7@1;>R00CSdS201D?2@805Xn:0@0G4<U0P1MA2H205i59`80HT@R00H0HD<Q06948P1S
AB<0ITPV06Q::01ZC2X30612:080Gd4W0`1N@2H03P1N?b<0GClS05`n901I?BD0EcdV05Dl9P1C?BP0
DS`W05To:01H@2P0EclW05@n9P1B?RD0D3lU0P1>?R@0101A>B40DSXR05@l901G?bL205Q0:080EclW
00H0Fd4Z05Y0:@1J@2T0FClX05Pn9`1G?BH205Hl9@0305@l901C>b<0DCTQ0080CcLO00H0DCTQ05<k
8`1D?2@0D3hV04lm9@1>?2@204dk8`0304lm9@1A?bL0Dd4Y00P0ECdU00@0FD4Y05Q0:01E?BD0Dc/S
0`1B>R800`1C>b<0EShV05Hn9P0605Hn9P0305To901G?B80ES`Q0080E3XO00<0ES`Q05Lm8P1I?b@0
2@1M?B@205m19@H0H48V0100GT4Q05m28P1O@R80H4<S0654901SARH0I4LW06E8:01PAbT0GdHX05a3
9@1K@R@0FT4S05]2901MA2H0GTDW0`1M?b<00`1N@2@0Gd4U06129P0206129P0906539`1P@RH0H48V
06129P1Q@bL0HdDY06I8;01WBBd0JTPU0080JdTV00<0K4XW06e;:01]BbP00P1^C2T806M99`0806Q:
9P1WBBD0IDLS06A68P1UAb<0IdTU06U;9`1ZC2P206Y9:P0406U8:@1XAbP0IdHW06I59P80ID@U0`1Q
BBL[ooooo`00:_ooool809aaA080WG=1102NM48209me@`0309aa?P2MLSl0WgA10080X7E200<0WgA1
09eb?`2LLCh00P2MLD00102NLT40Wg=209mc@P2PM4<50:5eA0D0X7A3202OM4400`2SNDL0XGM509me
@`0209ec@@0309id@P2OMD<0X7I40080WWQ90P2MMdP0102LMTL0VgE609]eAP2JM4D209me@`80X7I4
0P2QMdD50:9hAP060:5gA@2PMT@0X7I409ec@@2KLCl0VW0n0P2EKd0209A^?`<0Tfdn00<0TV`m08mY
?02?JC`00P2>J3/01`2=IcX0S6Hi08aV>@2<IST0Qf8h08IQ=`23GS@01021G3801@22GC<0Oe`f07eJ
=01jEc40N5D_00<0MU<]00L0Me@^07YC<P1hE380Me<a07EC<01cDRl0L58^0080KU8]0100ITPR06M9
8`1YBbL0JD/Y06Q::01VAbP0I4DX06939P1[BR/0JDPY06M69`1VABH0IdHW06U8:@1/Bb`0KTd^201W
B2/01P1aCRH0LTlW07=@:01dDBT0MU<[07MD;080NEH^00T0PE/d085L<P21G380PUda08=N<@23Gbl0
Pel]08AP;P28HS<00`29Hc@208YT=@80RfDf00H0RV@g08]U>02;ICP0SFLj08iX>`2?JC`2091Z?@08
09A^@@2BK3l0SfTl08aV>@2;ICP0S6Hi08iX>`2?JC`2095[?P80T6Xm00D0SfTl08iX>`2>J3/0SFLj
09AX>`0209EY?00309IZ?@2GJch0Uf/n0080V6`o202GK3l01P2HK3l0Uf`o09M/?`2FKCl0U6ho09=_
?`80TFlo0P2IKcd209Q^?0<0Ufdk00<0UV`j09E[>@2EJcT00P2FK3X409M]>`0<09Q^?02DJSP0U6Xh
09I/>P2GKC/0VFlm09]a?`2LLT00WG=109Y`?P2KLCl0WG=10P2NM4800`2LLT00VW0n09U_?@0209ag
@`0309]f@P2JMD40VGA00080V7<o00<0Ug8n09Ib?P2FLSh00`2FLSh309Mc?`P0V7<o0P2FK3X209E[
>@0409AZ>02CJCL0TVPf099X=P80TFHi0P2BIcX03`2CJ3/0U6Tl09AY?02EJSd0RfTi08YX>02:ISH0
RV@e08aS=@2>HcH0T6Dh099V>@2>JCD0S6Lc08]V<P0208UT<00308]V<P2<Ic<0SVTe00P0SfTj0`2>
JSX308m[>`80T6`l00P0S6Lc08iY=@2@JcL0TVdi09=^>P2DKc/0Tfhj099]>@<0SfTj0`2@JS/2095[
?080T6Pg00H0T6Li08mV>P2?IC/0SfDm08iT?02>I3h208UV?00408QU>`27I3X0QV<i08ER>080Q64g
01T0P5`Z07mN:`21Gbl0P60a07eN<01gFRh0LEHY06iC:01ZCRT0JTd[06M=:P1SBbT0GTLW05M28`1B
?B00CS/M04Lk8@16>R80A3XQ040h8@0n>280>cHR03Pe8P0g=240=BlS0080=2hR00<0<bdQ038/800a
:al00`0`:Qh202LX800302HW7`0U9Qh092DM00808b@L00<08R<K020S700P8a`01P0P8a`301hQ60<0
7b8I0P0P8aX3024T7@8082<L0`0O8Q/2020S70807b8K100N8AX04P0K7QL071lH01hQ6P0O8Q/07R4J
01dP6@0K7QL06A`E01`P8@0K7ah06QhM01TN6P0J7aT0724J01hT6P0O9A/09B4E02XV6P80;b/O0P0/
:1`04P0`;200=C4U03dY800m:b40>bdT03H]900_;2<0:2TQ020U7P0L8a/0:RDQ02XU7`0/9b40;RXQ
030/8@0b;R80=34R03Db8`<0>C0O0P0h;ah303L^7@0;03Db8`0d<B80<c0Q034^7`0_;1d0;BXK02`Y
6P0[:1T09bPJ02TZ700Z:ad00P0/;Al00`0Z:ad0:BXL02LX6P0402TZ70@0:R/M00P0:BXR02PY8@0W
:2009RLO02@U7@0R8a/08B8J020Q6@807b8K0P0N8AX201dP6@<071lH0`0M81T201hQ6P807b8K00l0
8R8H02DU6`0V9al08RDN01dP6@0H7AL05adI01TO6`0O6a`08ahK02XR5`0d:180@C8A05I3601/Eb80
0P1kIB/0402AJCH0TV`k09Ec@`2FNT/0T7Y;089_A01]GS<0GU4W03e1:P0i?2L0=3LT02h`8P0[;B00
:R/S02//9P0/;BP402PY8@@0:BXR0P0[;B8302X/8@<0:B/P01P0:2`M02T]7P0[;b00;C4R02lc900a
=BH0<SHW03<g:00j<b/0>C8Z03L`9P0f<2@0=S0R03Pb8P0j=2@0>cHS04Pj7`1:?240CClT05129`1B
A2T0DD<X04m19P1>@2D204a19@80CD8V00`0CT<W04m4:01?A2P0Cd@X05Q9:P1GB2T0EDHW05A59P1C
A2D0EDHW05I7:01HBBX205949`80DD<V0P1@@RD204m19080FT@/00H0FD@Y05Y5:01LAbP0Gd/Z069>
:`1UDBh206a>:P0406a>:01/CbL0KE0V06e@9P80KU4U03P0N5`Z07EI:@1cEbL0METZ07aO<`20HcT0
PF@l081S>`20Jc`0OfXk07iW>`1lHcX0NUhg07QJ=01gES<0ME@a07iB;@20E2d0PeX^08QP;`2;IRl0
Sfd^091a;P2BM2h0VX0c09In=02BNcL0RgLl08Ac?`1lKD80MfU407EVA@1XGd00J5do06QK>`1WEcH0
J5@c06Q@;P1WCB`0J4/Y07Q5:P1kB2/0P4h[08ED:`29FBP0S5hS08iP8P2?HQl0UUhU09UQ:02LIRX0
W6P/09aZ:`2QL2h0YgPd0:io>`80Z7Tc00P0YGTb0:=h<`2ON3<0WgXf09im>P2NOc`0Wh9009Qh?@<0
VGTn00@0UgLl09Ad>@2ALCH0Sfld0P2EKch609A^?@80T6ha0`2AKc83099`<`0609Q^=02GKc@0Ufld
09I_=02CKc<0TW0c0P2@L3<309M^>0<0V6li0P2IL3X0402AKc80T6ha08m]<02?KC00T6ha09=a=02F
M3L0UgDh09A`=02GL3D0V74f09Yb=`2KLCL0W6lf09a]=@2KK3@209Qf>@80UgDh102FM3L0402BKS00
UG4c09Mc=@2CKc40SFT[08]W:@2>JR`0TVh`08iS<02@IC80T6Pd091[=P2>KCL0Rfhf08Q^=@26KC@2
08UU<`0408YV=02;IcD0RfLe08aX=P80SFTg00<0QfH`08QW<@29J3800P2;JS@00`2:JC<0R6La08MV
<00808IY<@0608IW>026J3H0QVPf08IX=026J380QVTa0P26JBl207mU<P0307iT<`1mHS<0O64d0080
Nf0e01X0NUhf07UQ=@1fGS80LEX^06eF:P1ZEBP0IeDW06MF:01XEbT0JU@U06eG:01`FBd0LEX`06eF
;@1VCRP0GDDO05Q0701MA2H0GdHW06=;:@1WCb/0JE8Y06UB9P1XDR<0Ie4P06]>9080KU4U00l0LUDY
07EI:P1eFBT0M5PV075F8@1_E1l0K5PU06mK:01cGB/0Le`Z079H9`1bERH0MePY07]L;@1gFb/00P1h
G2`00`1iGBd0NUh^07]O;`0207aP<080Of<a00<0OV8`07eQ;`1lH2h00P1jGR`02P1iGB/0MU`Y079H
9@1^E2<0Ke@U07=H:`1eFRl0LED]06a@:01VDBH206E@9@0306A?901SCR<0HTdR0080HD`Q00/0FdlW
05U=9@1FB240E4DN05E67`1JB280Gd/V069>:@1IBR40Fd`S05m@9`02065B:@0605m@9`1KC2<0FDXQ
05M78`1HB2@0FDTU0P1JBRH0101HB2@0ETHR05E58@1?@AX204m1700304m17P1@@B00D44R0080D44T
0P1A@BP01P1@@2L0CclV04hn9@1=?B@0C3`S04/k8P80ACXN00h0@cTN03lh700m=ad0>SHM03Td7P0g
=Ah0<S@N034c7@0b<A`0<c4L03@b7@0h<al0?3DR03hg9080=cDP00<0=S@O03Dc7P0d<Qd00P0b<1/0
2@0a;aX0;2PL02/Y700Z:1`09bLM02DV7P0S9Ql082DN020U7`02024R6P0301lR6`0M8Q`06b4M0080
624N00<05R0O01XL6@0J71T00`0J71T301TK60806Q`K0P0I6aX201PJ6@805aTH0`0D6QP201<I5`<0
4QPF0P0F5aT401DF60/051DG200E5QPH01@E5`P04ALG400D5AL801DF60P051DG600E5QP301DG5P80
5QPG0`0G6AP801HH5b405aTH200I6aP@01/K6@807AhH0P0N7aT301lP6P03020Q6`0Q8AT08B4I00H0
8B4I0P0U8AP302HR6@<09b<J0`0Z91P302/U6@80;2HJ00@09R@G02LU600W9AP0:2HI0P0Y9aX202XX
6`80<BLK0P0b:1`403<Y7@@0<BLK100`9QX0200`9aH0<BPG03@X600f:AT0>RXK03d[7@0n;1h0@2dO
0`0m;1`203h]7@<0?bhN0P0n;A/303l^70<0@2lM0P0l:aT203d/6P80?RdK0P0o;Q`8044`7P80@30I
00@0@C4J048b6`14=1d0ACDN0P16=Ql2044_6@04048`6P13<A/0AC<M04Hd7P80AcDO0P15=Ah01014
=1d0@c<L04<c7012<Q/2044a6P0404Dc6`16=1`0AS@L04Hd70<0AcDM0P18=Qh804D_8@<0@34J1011
<Q/01@12<a`0AcHT04He8`13<R00@2lM0080?bhL00D0@2lM044`7P0e;AX0=RhK03P`7@0203Ta7P0>
03P`7@0f;Q/0=BdJ03`_7P0k;Qd0>RdL03T/6`0h:aX0=bXI03HY600e:1L0=bXQ03HY800d9ah203<V
7@0703@W7P0f:B00=bXQ03/Z6P0o;Qh0@S4Q04<b8P02044`800404Dd9019>2P0@c4K04<a6`80@S0J
0`11;aT01010;QP0@RlN048_7P12;ah204<`7`<0A34P0100@C8M04<b7P17=B40C3DS050e901B=BD0
E3<T05<b8`18>1h0BCPN04Xi7`1>>R40D3XR05<k8`1E>b@0ES`U101J?2003@1K?B40GClS05i0901O
@BD0G3lO05e0801N@B40H4<S06959@1TAbL0IDPX06I9:@1WBRP00P1VBBL00`1UB2H0I4LU06A79@02
06=6900306Y<:P1RA280HT@R0080Jdd[0P1TAR@00`1/CR`0IDdY06E=:@0206A<:00706=;9`1RBRH0
HDTU06599@1O@BL0GT0V05`n900205Xl8P0@05/m8`1M?bD0GT0V05/l801I>al0ESPN058f7P1@=Ql0
CcHP04li901@>RD0C3LJ04`g701:=Q/0AcHL04Hd7080A3@M00L0@c@O048c7P19=1l0BC@O04Pc7P17
<Qd0AS4L0080AC0K00<0A2lJ04<a6`13<A/00`13<A/00`14<Q`0AC<M04Dc7@0204Xf7P0404/g7`1=
>B40CSXR050l9080DCdU0P1A?1l01P1D?200ES`Q05Pm8P1K?B<0G3hT05dm9080FT8X00@0FT0W05Xn
9P1K?BD0G3`U0P1N>bD01@1R@2D0Hd4V06A29`1VA2T0IdDZ0080J4H[00@0JDL/06I89P1VB2H0ITPV
0P1WBBL306Q::00;06Q9;01VBB/0IDPZ0697:@1OARL0GDHV05Y69@1IAB@0FT<T05U28`1G@2400P1F
?b001`1G@240FD8S05Y3901NA2T0G48W05To901G?B80101E>b0805Lm8P<0ED0S00<0E3lR05<n8@1B
?B000P1B?B02050j8`03054k901B?2D0DcdV0080E3hW00L0EClX054h901?>B@0D3XU050k9P1>?2H0
CShW0080CSlX0`1E>b000`1F?240EcdR05Pn8`0205Pn8`0305Xl801K?B40G3hR0080GClS00H0G3hR
05/m8@1J?200DchO05E08@1H@b@205Y59P0905Q3901E@240DchO05@k7@1E?1h0ESdO05Ln801I@280
FT4S0080Fd8T0`1K>b@205`l9@@0GCdV201Q@bT206=49@80I4DV0P1UARL406I7:00706E69`1TABH0
Hd@U0693901Q@R<0H44R06I89P0206M99`0506I89P1UAbD0HdDS06538@1P@R000P1TAbD0101UB2H0
ITTW06M::01WBRP206Q;:@0406Q7901YB2D0K4/X06i=:P<0Kdh[00X0KTdZ06]=:`1[CB/0JT`Z06U;
:@1XBRP0IdTW06I89P1UAbD0IdTU101XBRH306U;9`0406I7:01WB2T0IdPY06Q9:P80JDX[0P1ZBb`3
0617:2_ooooo000Zooooo`P0Vg130P2MLd4609id@P0309aa?P2MLSl0WgA10080X7E200@0WgA109eb
?`2LLCh0WG500P2NLT4209mc@P80X7A30`2QMD@60:1d@`P0WgA100P0XWQ60:5gA@2OMD<0WWA209ec
@@2NM480WgE30:1fA080WWQ90P2MMdP0102LMTL0VgE609]eAP2KMDH209me@`80X7I40P2QMdD20:9h
AP040:AjB02SNDL0XGM509me@`80WWA20`2LLT0209E_@080U6ho102CKCh208mY?080SVPk00T0SFLj
08aV>@2<IST0RfDh08IQ=`25H3H0PUdc081K<@1oFS000P20Fc401021G380NePb07UF<01hEBl207MD
;P0407QE;`1iES00NePb07UB<@80MU8`00<0M58_079A;P1_DBd00P1]DB`206U;9@0606Y<:01ZC2X0
JD/Y06M8:@1TABP0HT<V0P1XAbP206M69`0406Q7:01YB2T0JTTZ06]::`<0ITLZ00D0IdP[06Q9;01X
BB`0J4T/06U:;@02075>9P0<07=@:01dDBT0MU<[07QE;@1iERh0NUL_081J<`20Fc40PE`b089M<@23
GS40Q60`0P25HBl408US=080RV@e0P2;ICH01@2:I3L0RfDh08]U>02<IST0SVPk0080SfTl0`2@JSd0
1`2>J3/0SFLj08eW>P2=IcX0SVPk08mY?02BK3l00P2AJch2091Z?@80SfTl00@0SVPk09AX>`2EJC`0
UFTl0P2FJSd209M[?P0309Q/?`2GK3l0Uf`o00H0Uf`o00H0V6`o09M/?`2GK3l0UVdo09A^?`2CKcl2
095_?`0409U_?@2HKS`0V6hl09Q^?080Ufdk0P2FK3X209E[>@80UV`j1@2GKC/209AZ>00909E[>@2G
KC/0V6hl09U_?@2JL3h0Vg4o09Y`?P2KLCl0W7900080WG=100<0W79009Y`?P2IKcd0102JMD4409Ud
@0H0Ug8n2P2HLcl01P2GKC/0UV`j09I/>P2EJcT0U6Xh09=Y=`80TVPf0P2AIST2099W>P0?09=X>`2D
JC`0U6Tl09AY?02;JCT0RVPh08YV=P2:I3D0S6<e08iS=P2@ICP0TVHi08iY=@2=J3@0S6Lc0080RfHb
00<0S6Lc08eX=02>JCD0202?JCX308iZ>P80Sf/k0`2@K3`0102<Ic<0SVTe091[=`2BKCT309=^>P03
099]>@2@JS/0T6Xk00D0T6Xk00X0SfTj091X=`2@J3L0T6Li08mV>P2?IC/0SfDm08iT?02>I3h0RFHl
0P28IC/00`27I3X0QV<i08ER>00208AQ=`0F081L:P1oGBd0P5h^07mO<01lGBl0MUT]071E:P1]DRL0
JTd[06M=:P1VC2/0HTTZ05e69`1F@B80DChP04hk7@16>R00ASXR04@j8@10>240?CLQ03/f8P80=c@Q
0P0b;R800`0a;B40<2`P02l[7`0302hZ7P0702dY7@0W:2009bPP02HW7`0U9Qh092DM02<T7002028S
6`P082<L0`0N8AP201lR6@<082<J0P0Q91d3020S70<07b8K0P0P8a`201lR6`<07R4J00@07B0I01/N
5`0L7aP07B0I0P0N8AX03@0M81T06ahG01XM5P0L81l06alN01XO6`0J7aT06b0I01dR6`0O9A/082HL
02PU5P0]:Q/00P0`;Ah202dZ6`0B034^7`0e<R<0?B/Q03`[8@0h:b80<bXQ02`Y800U9Qh07b@M01`S
6`0Z9Al0:bHP02`X7`0^:Ql0<2`P038_800d<B80=C8Q0P0i<1l303P_7P<0=bhM200`;Ah00`0W:1X0
:2TK02X[7@0202//7P0302X[7@0X:A/09bPJ00@0:BXL100Z:ad202PY8@0602LX800U9Qh092DM028S
6`0Q8QX0824I0P0O8Q/201hQ6P807B0I0P0L7aP401dP6@807R4J0P0O8Q/03`0N7Q@08B4G02<T700Q
8QX071lH01XM5P0J7aT07B8L024L6@0Y8Q`0<bXK040d701??ad0HU0R07IQ;00208=]=00@09Qc?02G
Lcl0U7A308mdA@25L4D0MF<m061B;`1AA280>C`W03Hi9P0a=2<0;2hP02X/8@0Z:b<0:b`V02`]:0@0
:BXR100X:B4802X/8@0D02X^7`0[;b00;30Q02da8P0_<b@0<3@U034e9P0b=RL0>C8Z03Pa9`0g<2H0
=c4U03Pb900j=2@0?3LT03dh9@1;?B80C3hS04i09@1@@RL40553:0<0CD8V1@1>@bL00`1GB2T0ETLX
05E69`0205A59P0305E69`1GB2T0F4TZ00<0DdDX0`1BA2L205539P80FdH[00H0FTDX05]69`1LB2L0
Gd/X069>:`1TD2/206iB;@0;06mC;01`E2`0LUL/07=H:`1dFB`0MEX[07UO;P1eFbX0LePY07EJ;@1j
Gc@00P1nHSX0<@1mHCX0Mf8e07IQ=01fGc<0MUdd07MK=01gFC<0NETc07UH=@21EC00PUH_08EL<027
HC00RfP`08e]<02@LC00TG@`09Al=02BNS@0SWHf08Ia>020K3X0N6Ll07=T?@1aHCl0JEPj06]H>01[
ESL0KE@e06mB<P1`Cbh0LDl/075=:`1lBBX0Odd/08=A;029FB/0SUl[095S:02CIRD0U6LT09]S:P2N
J2`0XF/_0:1];P2OKBh0XW8`0:Ii=P2/Oc`00P2WNSH0202UNSD0XGTd09mh=@2LNCL0W7Xj09am?02L
OSh0UWHk0`2GMc`01@2EMCX0Tg<h091`=@2>KS<0SfTh00D0T6Xi0P2AJcX2091^<@<0TFlb0`2BL3<0
1P2DJS00U6`a09E]<P2EKS<0U70d09Ec=P80U7@g0`2GKSP209Q_>@<0VG0j0P2BL3<2095_<P0<099`
<`2DLSD0UgDh09Qf>@2ELCD0UW8f09Ub=`2KLcP0W78h09e`=`2LKcH0W6de0P2HMST0102GMCP0UW@g
09Ec=P2ELcH209Ab=@0@095]<@2ELCD0V7@h09Ib=P2AKC40SVX^091/<02CKc<0TVPf09=Y=`2AK3P0
TVhj091_>P2=KcT0RFhg08M^=P<0QfHc00<0R6Ld08UX=@29J3D00P2:JCH00`27IS40R6Lb08UX<`02
08YY=00308QW<P27IS40QVD`00P0QFLa00H0QFHg08EW=@25IcD0QFLc08EW<@25J30208EX;P0607mV
<01oIC80OV@a07eS<P1lHC80O64d0P1kH3D01P1iGS<0MUhb07=K;`1`FBd0KEP[06YH:P80JEPZ00h0
KELX06mI:P1aFRh0LU/a06mH;`1ZDR`0I4`V06599@1NABH0GdHW069::01TC2H0ITlV06M@9080J58S
0140JTlT06aA9P1/DBH0L5DX07=H:@1dFRT0LUPU071F8`1^EAl0K5PU06mK:01cGB/0Le`Z079H9`1b
ERH0MePY07]L;@0207MK:`0407QL;01iGBd0NUh^07]O;`80O60`0P1oHc403P1nHS00OF4_07aP;P1k
Gbd0NUh/07UM:`1gGBX0LeTV071F9@1`EBH0LeP[07AI;P1`E2`0K50X0P1VDBH00`1UD2D0I4lT06=>
8`02069=8P0<065<8@1JCRH0F4`T05M98P1FAb00EdPQ05Y88P1NBRD0H4`W05U:8@1KC2<0GTlV0P1P
DBP01@1NCbH0Fd`S05U:8@1HB2@0FDTU00<0FTXV00T0F4PT05I68P1EAB40DT@M05947`1CAB00DdDR
05=48`1CA2D00P1CA2L01P1B@RP0DD4W05109P1??bD0CShT04dm8`80C3`R00H0B3XM04Hk7`15>Qh0
@SPM03lh7P0l=Qh203Xe7`0>03Hf7P0e=Ad0=C<L03@b6`0g<Q`0>3<M03/e7`0m=b40>3HO03Le7P0f
=1d0=C<L03@b6`0c<AX2038`6@0802h[700]:Q/0:bTL02PX700U9a`08bHM024T7@0O91d2024R6P04
01lR6`0L8AX06R4J01XP70805b0M0P0K7AX401XL6@806A/H0P0J71/201TK6P8061XI0P0G6AP301@J
60804aTG0`0B61H201HG6@@05AHH2`0D5AL801DF61P051DG200A5aL@01@E5`P05AHH200D5ALH01DF
60<05ALF0P0F61L301LI60P05QPG8@0G6AP801TK61006a/I0P0M7QP201hO6@@07b0J200Q8AT202DQ
60<09R8I0`0W8aX302XT6080:bDI0`0/9QX202HT5`809bDH00@0:2HI02TW6P0Y9aX0:BLJ0P0`9QX3
034W6`<0<RPL1@0a9a/3030V6P08030W5P0a:1L0=2PH03LZ6P0j:Q/0?B/M03h/7P10;Al303d/7080
?RdM0`0o;Qh203h]6`<0?bhL0`10;ad403h]6`80?bhL0P10;ad8044`7P80@C4J00@0@S8K04<c7013
<a`0A3@M0P15=Ah01P11;aT0@S0J04<a6`14<Q`0AC<M04Hd7P80AcDO0P15=Ah204@d7@80@c<L0P12
<Q/404Hd70<0AcDM0P18=Qh804D`7`H0@C8K0P12<a`00`16=B<0AC@R048a7`03040_7@05044`7P12
<Al0=BdJ03H^6`0h<1d00P0i<Ah02@0h<1d0=RhK03D]6P0l;ah0>bhM03X]700i;1/0>2/J03LZ6@02
03HY600303L[7`0f:Qh0=BTM0080=2PL00D0=BTM03HZ7P0g:al0>bXJ03l^7P02048a8@80@C0P00<0
A3<S04Pg9`13<A/00P13<A/2048`6P<0@BlI0`12;ah204<`7`<0A34P00P0@c8N04Dd801:=B80CCHT
050e901A=2@0DS8S05<b8`80BSTO00@0CCTP050j8P1C>b<0ECdU0P1G?BH01@1J?200FcdQ05`n8P1M
?b<0GT0T00<0Gd4U00T0GT4Q05m28P1P@b<0HD@T06959@1SARH0I4LW06E8:01WBRP00P1VBBL206E8
9P80I4LU00@0HdHT06Y<:P1SAB<0HdDS0P1[CB/206E79@0706a>;01WCBX0IT`Y06I<:@1UBbP0I4XW
06=99P0206989@0606539`1P@RH0GClS05/m8@1J?200FcdQ0P1L?R801P1K?200FC/O05Li7`1C=al0
DCLP050g8@80CcTT00D0C3LJ04`g701:=Q/0AcHL04Hd700204De7P80@c@O0P1:=B001019=1l0B3<N
04Lb7@17<Qd204Ha70@0A38L0P15<ad204Hd7P80BSHN00H0BcLO04di8@1>>R80Cc/S050l901A?BD2
054l7`0305@l801F?240F3dR0080FcdS00L0GCdT05U19`1I@BL0FT0W05/o9`1M?bL0GShW0080H3dW
0P1O?B800`1P?R<0HClT06=19P0206A29`0306E3:01VB2H0ITPV00<0IdTW0`1XBRP206M8:`0906E8
:P1QARP0GdHW05e69P1LABD0FDDT05Y3901I@R<0F44R0080Ed0Q00L0F44R05U28`1J@b@0GT@Y05a2
9`1J@2D0EcdR00<0EC/P00<0ES`Q05Lm8P1G?B801P1G?B8305E08`0305@o8P1C?R40DchQ0080DSdP
101B?2@305<m9@0905@n9P1B>BD0DSTU054k9P1@>bH0CcdW04hn9`1??bP0CSlX0080EC/P0P1F?242
05Lm8P80F3hS00<0FC/O05Xl801K?B400P1L?R801P1K?B40FS`P05Tk7`1D?b00ED0Q05I18P80Ed8S
00<0ET4R05E08@1D?b000P1F?Al0101G?R00F3lQ05U08P1I@28205Y18`<0Fc/T0P1L?2D405dm9PP0
GT0T0P1SA2D206A59P80IDHW0P1VAbP01P1WB2T0ITLX06E69`1TABH0Hd@U06939080HD8S0P1XBRP0
0`1VB2H0IDLU06A6900306=58`80I4LU00<0IDPV06I99`1WBRP00P1XBbT01@1YC2X0JDPU06Y99P1/
BbP0KTdZ0080Kdh[00P0KTdZ06e<:@1/CR`0Jdd[06Y<:P1YBbT0J4XX06M99`80ITPV0P1WBBD206Q:
9P0506U;9`1ZC2P0JT`X06]=:@1WB2T00P1XBBX206U::`80JT//00@0Jd`]06=8:P1SB2X0HdPZ:ooo
ool002[ooooo202JKd8309id@PD0WG=100<0W74n09eb?`2NLd000P2OM4400`2NLd00WG8o09aa?P03
09ib@@80Wg=22`2PM4<80:1e@P030:9hAP2QMdD0WgE300<0WWA20P2OMD<309egB0<0W7I70P2KMDH2
09me@`80X7I40P2QMdD20:9hAP040:EkB@2SNDL0WgE309ab@0<0Vg4o00<0WG=109id@P2EKd000P2E
Kd0209A^?`<0Tfdn00H0T6Xm08mY?02?JC`0SVPk08eW>P2<IST208]U>00408AO=@23GS@0PE`b07mJ
<080OUT_00@0OeX`081K<@1hEBl0Me@^0P1fDbd01@1gE2h0NULa07aI<`1mFS@0Me0_0080M50^00<0
LU0]071?;01]Cb/00P1[CbX206a>:00906a>:P1[CB/0JD/Y06M8:@1UART0Hd@W06=49@1TABH0IDHW
00<0ITLX0P1UARL0201TABH0IDHW06I7:01WB2T0J4TZ06U::`1ZBb`0Jd`]0P1aCRH0301cD2P0ME8Z
07MD;01hEBd0NUL_07]H<01nF340OeX`081K<@22GC40Q5lb08EQ<@80Qf<a0`29Hc@208YT=@<0RfDf
00H0RV@g08]U>02;ICP0S6Hi08eW>P2>J3/208mY?00308aV>@2=IcX0SVPk00<0SfTl0P2>J3/3099/
?`<0TF/n0P2@JSd409EY?080UVXm0P2GJch809M/?`0609Q/?`2GK3l0Uf`o09I]?`2DKSl0Tflo0P2A
Kcl209Q^?080Ufdk0`2FK3X409E[>@80UV`j102GKC/01@2DJSP0UF/i09E[>@2EJcT0UV`j00<0Ufdk
0P2JL3h01P2KLCl0W79009ab@02LLT00Vg4o09Y`?P80V7<o0`2IM40309Ye@@P0Ug8n202HLcl209M]
>`0309I/>P2EJcT0U6Xh0080TfTg00@0TVPf099W>P2BIcX0TVLj0`2CJ3/209AY?00808]Y>@2:J3P0
RVHf08YT=@2<HcD0SV<f091U>02BIST208mZ=P@0SFPd0P2?JSH808mY>P80SVXj0P2?Jc/3091/?005
095]?@2=J3@0SVTe091[=`2BKCT00P2CKSX2099]>@80TV`m00@0TF/l091Z>`2?JCX0SfTj0P2>J3T2
08iX=`0608iX>@2=IcX0SFHk08eV?@2<IC`0S6Dn0P28IC/01027I3X0QV<i08ER>025HSP208AQ=`0I
07mK:`1nG2`0Oed_07iM<01jFbl0M5L]06mC:`1/D2P0IT`Y06I<:`1SBbT0GdPX05U49@1D@B<0D3`Q
04`k7`16>R00ASXR04<i800o=b00?3HP03Xe8@0f<b00=C8O038^8P02034]8@03030/800_:al0;RXN
00<0;BTM00H09bPP02HW7`0V9al09BHN02@U7@0S91`2028S6`P082<L0P0N8AP201lR6@<082<J00<0
8B@K024T7@0P8a`00P0P8a`201lR6`807R4J0`0O8Q/201hQ6P<07B0I01806ahG01`O600M81T07B0I
01hQ6P0M81T071lH01/N5`0N81l07R0M01dO700M7aX07R4J020S6P0R9AX092LL02dZ6`0`;Ah2038_
800:030]7P0_;1d0<RlP03@a8P0l;R<0>BdQ03<Y7`0]9Q`09b@K028S6`807R<L00T0:bHP02`X7`0]
:B00;b/P034]8@0c<240=34P03Db8@0i<1l00`0h;ah203L^7@80=RdL00P0:bPI02`Y6P0]:Q/0;b`M
034^7`0b;b00=34R03Db8`80:2TK00@0:BXL02X[7@0Z:ad0:BXL0P0X:A/402X[7@@0:BXL0P0W:200
1P0V9al092DM02<T700R8a/08B8J020Q6@807b8K0P0N8AX201dP6@8071lH0`0M81T201hQ6P<07b8K
00@06a`D01dN5P0P8AT07QlG0P0K71@02@0O81P08b@L02XP5P0e:A/0ACPU05E6:@1UDbd0MV4d08E`
>`0208mi@00A09moA02HND00SG4o081Y?@1bH3`0H54d04a0:P0n=R<0<cHU034d8`0];b40:R`O02T[
800Y:R80:R/U02`]9`0[;2@00P0Z:b<01@0Y:R80:2TQ02LX800W:2009RLO0080:B/P0P0Z;240100[
;B80;2hS02d_900];b@202h`8P80;c4S0`0`<R@02@0a<bD0=c0V03L`9P0g<BD0>38T03Xd900l=b@0
?cXW040k9`0404e29P0504i39`1?A2P0DDHZ0597:`1?A2P0101>@bL304e29P80EDHW0P1DABH0101E
ARL0ETLX05Q9:P1IBR/205E69`H0ETLX04P0GdL[05m8:@1OB2T0GdPX06199`1RC2L0I4hW06E?:01`
E2d0LED^07AH<01fFc00NEha07]P<@1mHS<0OF<b07aR<@1hGBh0M5TZ07EJ;@1iGS<0O60h07]O>01i
GCH0KEP]06aG;01/EB/0KE@[075E;@1eF300NUXc07aL=@24FS80QE/c08IP<`28I380RfPb08e]=02>
L380T78b08ed=02:LS@0QVdd07mX=01hHS<0Lehc06iJ=@1/F3D0K58a06iA<@1bDC00M58_07QB;P1l
DBh0OE4^07mA;@22D2/0QE@/08YI;P2@H2l0UFH^09U[;@2KKR/0W6l[0:9_<02ULS<0YgDf0:Ee=@2R
MC@0XWHe0:Ij>@2YP3h20:Em>0050:Al=`2QNSL0WWPg09]h>02JN3T00P2INC`02@2CLcX0U7@k09Ad
>`2CLcX0TW8i091`=`2>KSD0S6`c08YU<@0208]V<P0308aW<`2=J3@0SVTe0080SVTe0P2@KS43095_
<P<0TW0c00P0TVP^099Z;`2CJc00UFhc09Ea=@2GMCP0UWHi09Mg>P80Ufhh0P2HKcT309U`>P0309Ya
>`2ELcH0U78e0080U78e00d0UG<f09Id=`2HMST0VGLj09Ec=P2GLcL0VGDi09ae>P2MMCX0WG<i09e`
=`2LKcH0V7Hi0080UgDh00L0UW@g09Ec=P2CLC@0TW0c095_<P2@KS40U78e0080V7Hi00@0UG<f09=a
=02BL3<0Tg4d0P2CKSX01P2CKc/0TG0k08m`>P2<KSP0R6df08M/=@80QV@d0P27ICD408QV=P0808MV
<@28Ic80RFPc08UX<`28Ic80QVD`08AS;P23HRd808AV<00608AU=P24IS@0Q6Hd08AV<P24IS00Q6L_
0P24Ibd2081W<@0307mU<P1nI3<0OF8c0080O64d00T0Nf0e07QK<@1gG340Me`a07EM<@1cG300L5/^
06aJ;01[FB/00P1_FBX01P1`FBd0LEX`071I<01_Ec40KED_06]C;`80H4PV00L0H4PT06598`1RBb80
IDhT06M@901XDBD0JDdU0080JdlW00h0Ke@Y075F:@1bEbP0LUPW071F8`1^E240K5PU06mK:01cGB/0
Le`Z079H9`1bERH0MePY07]L;@80Me/[00<0N5`/07UM;@1jGRh00P1kGbl01`1lH300Of<a07iR<01n
HS00OF4_07aP;P1kGbd00P1jGR`02@1iGb`0MU`Y07=I:01bEbP0LeP[079G;01_Db/0K50X06MB9`02
06IA9P0306E@9@1TCb@0HdhS0080HTdR00<0FDdU05Q<901IBb@00P1IBR<01P1LBR@0GDTT05e9901I
BR40Fd`S05i?9P80Ge0W00`0GTlV05]<8`1IBR40F4PT05U99@1JBRH0Fd/W05Y:9P1IBBD0EdLS05I6
8P1FB24205I88`0305I89@1FAbH0ETLX0080ETLZ00H0DT8X05519`1A@BL0D40V04lo9@1>?R@204dm
8`0804Xm7@1:?1l0Ac`N04@k7P11>Qh0?cTO03hh800l>1l203`g8@0403Xe7`0i=1h0>C@N03Td7P80
>SDO00H0>cHP03Xe7`0j=Al0>C@N03Pc7@0g<Q`203Ha6`08038/700`;A`0;R/L02/Y700W9a/08bDJ
024T6@0P8aX2028R6003020Q6@0N8AX06b0J00806AlK00<05QlL01`N6`0K7AX00P0K7AX201XL6@80
6A/H0P0J71/201TK6P8061XI0P0G6AP301@J60804aTG0`0B61H201HG6@@05AHH2`0D5AL801DF61P0
51DG200A5aL@01@E5`P05AHH200D5ALH01DF60<05ALF0P0F61L301LI60P05QPG8@0G6AP801TK6100
6a/I0`0M7QP201hO6@<07b0J200Q8AT202DQ60<09R8I0`0W8aX202XT6080:bDI0`0/9QX0100]9a/0
9b<G02LS5`0W8aL302PT6080:BDI0`0_9AT3030V6PX0<BLK00P0<BPG038Y600e:AT0=bXJ03/[700m
:ad0?R`N03l/7P<0?B`L0P0n;Ad303l^7P80?RdK0`0o;Q`3040_7@0403l^7010;ad0@2lM040_7@80
@C0N0P12<Al8044`7PP0@c<L00H0@S0J04<a6`13<A/0A38L04Dc7@16=1h204Le7`<0AS@N0`15<ad2
04@b70<0AS@L0`17=Ad304Pf7PP0AS4P2013<a`00`14<b40@c8P048a7`02044`7P06048a7`13<R00
@c8P03P]6`0i;Q`0>c0N0P0l<Al00`0k<1h0>BhL03P]6`0203/^7@80>RdL00@0>B`K03P[6P0g:QT0
=bXI0P0g:al0100f:Qh0=BTM03DY7@0f:Qh203L[7`0403/Z6P0o;Qh0@S4Q048a8@80@2lO00@0A3<S
04Lf9P14<Q`0A38L0P13<A/3048`6P04044_6@13<1l0@c0O04<`7`80A34P0`15<R405017=Al0BSDP
04/f8@1>>2<0D3LS050e8P1?<R00CS4O04`k8@1>>R40Cc/R058l901E?BD0EcdV05Tm9`1J?RP0FS`P
05`n8P1O@BD0HD<W0P1RA2P00`1P@RH0Gd4U0654900206549080HTDU0P1SARH00`1TAbL0ITTW06I9
9`0206I99`80IDPV0P1TAbD01@1YBbT0IDLU06E79@1ZC2X0Jdd[0080IdTW00L0K4h/06Y=:`1YC2X0
JD`Z06Q;:@1WBRP0ITTW0080IDPV00D0I4HZ06=5:@1P@RH0GT0T05`n8P0305/m8@0605/l801I>al0
EcTO05@h801B>240D3LQ0P1?>B@01@1=>1/0CCPM04/g7018=ad0AcDM0080ACDN00L0A3DP04<d7`1<
=b80C3LR04/f8@1:=B00BC@O0080B3<N00@0Ac8M04Dc7@15<ad0AS@N1@17=Al02019=Ad0BSHN04/g
7`1<>200CSXR04lk8`1@?2@0DCdU0P1A?1l0301D?200EC/P05Ll8@1J?280FcdS05`l8`1G?b<0F40T
05Y09@1L@BH0Gd4W06109`80HT0W0P1J>al205/l800505`m8@1M?R80GSlS05m0901VB2H00`1WBBL2
06Q::080JD/Y0P1YB2T0101VAbP0HdHV06169@1MAB<205]48P0305a39@1K@R@0FT4S0080FD0R00L0
FT4S05]2901L@bD0GT@Y05a29`1J@2D0EcdR00<0ES`Q2@1G?B8305Lo8`80EShR0`1E?B4405Hn9P<0
ECdU00L0E3`T05@i901C>R@0E3/U058l9@1A?BD0D3hV0080CclV00@0EC/P05Hl8@1F?240ES`Q0`1G
?B80101H?R<0F3XN05Tk7`1J?20205/m8@0605Xl801I>al0F3XN05Q18P1G@240EChO0P1D?Ah00`1E
?Ql0Ed0Q05Q18P0805U08P<0G3`S0P1M?B@405hn9@P0GClS0P1SA2D206A59P80IDHW0P1VAbP01P1W
B2T0ITLX06I7:01UARL0I4DV06=49@80HT<T00T0Jdd[06U;:@1VB2H0HdDS06948P1SAB<0IDLU06I8
9P1UAbD00P1VB2H00`1WBBL0J4XX06U;:@0206Y<:P0306]:9`1/BbP0KTdZ0080Kdh[00@0KTdZ06e<
:@1/BbP0K4h/0P1[CB/00`1ZC2X0JD/Y06Q::00206M99`0806I8901WBBD0J4XV06U;9`1ZC2P0JddY
06a>:P1]Cb/306U;:@80JT`Z0`1[CB/306U<;2_ooooo000Zooooo`P0VFi10P2NM48409ec@@80W790
00<0WG8o09ic@02NLd00102NLd000`2MLSl0Wg=209mc@P0709mc@P@0X7A30`2QMD@80:1e@P030:5g
A@2PMT@0X7I40080WgE30`2NM48209egB0H0W7I70P2OMD<20:1fA080XGM50P2RN4H0102VO4X0XgU7
09id@P2JL3h209U_?@0309]a?`2NM480X7I40080UW110P2EKd0209A^?`80Tfdn00H0TF/n091Z?@2?
JC`0SVPk08eW>P2;ICP208YT=`0408=N=022GC<0P5/a07iI;`80OEP^00D0OUT_07mJ<01jEc40NEH`
07QE;`0207MD;P0907QE;`1jEc40NePb07E>;@1cCbd0LTh/071>:`1^CBX0K4hZ0080JThY00/0Ke4[
06i@:P1]Cb/0Jdd[06U;:@1WB2T0ITLZ06E6:@1P@b<0HD@T06A79`0206I9:@0K06A79`1RABD0H4<S
06=58`1TAR@0IDLU06M99`1YBbT0Jdd[06a>;01]Cbd0L4dU075>9P1cD2P0ME8Z07MD;01iERh0NeP`
07aI<@1mEc00OUT_081K<@22GC40Q5lb08MS<`28I380RFDc0080RF<d0P2:I3D208]U=P80S6Hg0`2;
ICP00`2<IST0SFLj08eW>P0208iX>`0808QR=@2:I3L0SFLj091Z?@2AJch0T6Xm08iX>`2=IcX6099/
?`80TF/n1P2EJC`209IZ?@P0Uf`o00H0V6`o09M/?`2GK3l0UVdo09A^?`2CKcl2095_?`80Ufdk0P2F
K3X409E[>@80U6Xh0P2EJcT309I/>P80Ufdk202EJcT00`2IKcd0VW0n09Y`?P0509]a?`0609Ia?@2G
LSh0Ug8n09Qc?`2IM400VWE10P2KMT8309Yb?`@0VG4n00<0V70m09Qc?`2HLcl01P2HLcl209M]>`04
09I/>P2EJcT0UF/i09AZ>080TfTg0P2BIcX609=X>`0808]Y>@2:J3P0RVHf08YT=@2<HcD0SV<f091U
>02BIST808mZ=PP0SfTj0`2?Jc/3091/?080TFdm00@0SVTe08mZ=P2AK3P0TVdi0P2CKSX02P2BKCT0
TF`h09=]?P2CKCh0TV`m091Z>`2?JCX0SVPi08eW>02<ISL208eY=`0608eY>@2<IcX0S6Lk08aW?@2;
IS`0RfDn0P28IC/01027I3X0QV<i08ER>024HCL208=P=P0I07mJ;@1mFbd0OE/^07]J;`1gEbh0LE@/
06eA:@1ZCRL0I4`Z06=::`1OB2P0FTDV05I39@1@?b<0CC`R04/k8@16>R00ACTQ04<i800o=b00>cDO
03Pc7`0e<Ql0=34N030^8@0202l]800302h/7`0]:ah0;2XM00<0:bTL0P0V9al00`0U9Qh092DM02<T
7002028S6`03024R6P0P8a`082<L00H082<L0`0O8QT3020S6P808B@K0`0P8a`201lR6`<07R4J0P0O
8Q/301hQ6P<07B0I0P0K7QL00`0L7aP07B0I01dP6@0301dP6@0<020P7P0P8A`07b0K01lP6P0P8AT0
8bDJ02DW6P0W:A`0<RlN03<`7`0d<B00<c0O0P0b;ah04P0c<1l0=34P03P`8`0d;1l0;RPL02LS600Q
8AL0824I020S700R9Ah0;BTP02hZ7`0_:b00<2`P038_800c<1l0=34N03Db7`<0>2lN0P0g;Qd303H]
700802/X6@0/:AX0;BXK02h[700`;Ah0<BhO038_800c<24202PY6`@0:BXL0P0X:A/402X[7@@0:BXL
00H09RLO02DV7P0T9Ad08b@L028S6`0Q8QX2020Q6@807b8K0P0N8AX201dP6@8071lH0P0M81T201hQ
6P807b8K0P0P8a`03`0L7aH07b0H020Q6@0N7Q@06a/A01hL400S8AD0:2HI03TZ5@16=Ql0FTT]06eJ
>@1jIcd0Qg52095jAP0209IoB@0<09Z0@`2?MSd0OVPg06iK<`1MCS40CD8`03de:P0c;2@0;BlR02`^
8`0Z;240:2XO0P0X:B40200Z:b<0:b`T02//900[;2@0:R/S02TZ8P0X:B409bPP0P0V9al01P0X:Ql0
:B/P02X/8@0[;B80;2hS02h`9@80;c4V1@0a<R@3030a8`0@03D_8`0f<2@0>38T03Xd900l=b@0?cXV
044l:013?RP0D4LZ04i5:01<@bH0Bd8U04a39P1>ABP0DDP[05=:;@<0Cd@X00D0CT<W04e29P1=@RH0
CD8V04a19@0305A59P0605E69`1FAbP0EdPY05Q9:P1IBR/0EdLV0P1HB2L205U9:080FTXY04T0Fd/Z
06=::`1SBR/0Hd/Y06=;9`1TC2H0IDhU06I?9P1WD2H0KUD/071G;P1cFbl0Mela07]S<`1mICD0OVLe
07mX=P1lI3@0Mela079J;01bFRh0ME`c07IM=@1dFSD0LUPc06MA:P1VD2T0ITlV06M>9P1/D2P0LE@Z
07MG;P1jFS40Qede08IO=026HC@0R6@d08UX=@2:Jc@0RVdc08]^=024JcD0PFPb07eS<01fGRh0LET]
06iE;01[Dbd0JU8/075>:01eCbX0N54Z07eA;023Dbd0R5@]08]F;P2>Ec00Re/]08iN;P2CI300VFXb
09i`=02QM3<0XgHb0:Ah<@2ZNCL0[7`j0:ao?02ZOC`0YWXi0:9i>@2TOC`0Z81200<0X7dk00H0WW/k
09ah>P2IMcX0V7Dk09Md>P2GM3`2095`>P06091_>@2?KSP0SVdg08e/=P2<JcD0RfXd0P2;IS400`2<
Ic80SFPc08iY=00208mZ=@03091[=P2@KS40T6ha00<0TFlb0`2BL3<01P2EJc40U6`a09E]<P2FKc@0
UG4e09Id=`80UGDh0`2HKcT309U`>P80VW4k0`2FM3L209Me>00;09Qf>@2IMcX0VWPk09Ad=`2GMCP0
VGLj09]g>`2MMS/0WGDj09ab>02KLCL00`2GMCP05@2FM3L0UG<f09=a=02@KS40Sfd`08i^<`2ALCH0
UGDj09Mg?02FMS/0U7@i09=c>02BLSL0T6ll08i^>`2=KCX0S6`i08YZ=`27JCD0QVPd08EW<`0808EU
=P80QVDb0P27IS<01026IC80Q6<`089Q;P21H2d808=U<@0608AU=P24IS@0Q6Hd08AV<P24IS00Q6L_
0P24Ibd2085X<00>081W<@1oIC80OV@c07eR<`1lHC80O64d07II;`1hFc40NEhc07YO=01gGc<0M5da
071K;P1^FB`206eG:00?06eF:P1]ER`0KUL^06mG<@1`F380LETe06=;9`1RBR@0H4PR05m78@1PBB00
HT/R06E>9@1WD2L0ITdU0080J4lV00l0Je8Y06iF:P1_EbT0KeLW06iG9@1]ER@0K5PU06mK:01cGB/0
Le`Z079H9`1bERH0MePY07]L;@1fFRX00P1gFb/00`1hG2`0NEd]07YN;P0207]O;`80OV8`0P1mHBl0
3@1lH2h0Nel]07]O;@1kGbd0NV0]07QN:`1fG2/0M5TZ07=H:`1aER/0KU8Z06eA:@1XDbP00P1WDRL0
0`1VDBH0IE0U06A?900206=>8`80F4`T00T0FT`U05a=9P1KC2D0G4XT05a88`1KAb80FT/R05]<8`1M
CRD00P1NCbH01P1MCRD0Fd`S05Y;8P1HB2@0FDTU05Y:9P80Fd/W00@0FDTU05M78`1FAR80ETPQ0P1E
Ab800`1EAb@0EDHU05A59P0205A5:080DT<V0P1A@RD04@1@@B@0Cd0S04m08`1?@2<0CSlP04dn7`1;
?B00B3dO04Hm8012>al0@CXP040j8014>B<0@CTR040h8@0m=al0?3HN00<0>SHM00<0?CLO03`f7P0l
=Qh00P0k=Ad203Xd700B03Tc6`0g<1d0=C0L03<^6`0^:aX0:RPI02HW6@0S9AL08R@G02HT600U8aL0
8R8H020Q6@0N8AX06b0J01TP6@0H7QX07AlL0P0L7Q/00`0K7AX06Q`I01XL6@0201TK60806Q`K0P0I
6aX201PJ6@805aTH0`0D6QP201<I5`<04QPF0P0F5aT401DF60/051DG200E5QPH01@E5`P04ALG400D
5AL801DF60P051DG600E5QP301DG5P805QPG0`0G6AP801HH5b405aTH200I6aP@01/K6@8071dG0P0M
7QP201hO6@807b0J200Q8AT202DQ60<09R8I0`0W8aX302/U6@<0;2HJ0P0]9a/302TS5`D0:R@H100^
91P202lU6@80<2HJ100a9a/4038X7008038Y600c:QT0=RXJ03P[6`0k:a`0?B/M03h/7P0o;1h303d/
7080?RdM0`0o;Qh203h]6`<0?bhL0`10;ad3044`7P80@S4O0`13<R08048a7`<0A3@M0P13<a`3048b
6`0304<a6`14<Q`0A38L0080AC<M0P16=1h00`17=Al0B3<N04Pc7P0604Pc7P80AS@L0P17=Ad304Pf
7P80BCLO2017<Ql00`16=1h0AC<M04Dc7@0204Dc7@<0A38L1012<Al204<b8080A3<Q00<0>RdL03/^
7@0m<1l00P0n<B000`0m<1l0>bhM03X]700203/^7@80>RdL0P0i;1/203P[6PP0=b/M00P0>bXJ03l^
7P12<B40@S4Q040_7`0o;Qh0@c8R04He9@80AC<M0P14<Q`304<a6`04048`6P14<B00A34P04@a80<0
AC8Q0P16<b803P1<=Ql0CCLP04hh8@1A>280D3LQ04lf801><ah0CC8M04lk8P1A>b<0DS`T05Dm9@1H
?RL0FShX0P1M?RT0201K?B40GT0T06539`1TARX0IDL[06A6:P1RA2P0H48V201SARH606I99`80IDPV
00<0JD/Y06M99`1XBRP00P1ZC2X206U;:@0306]=:`1ZCB/0JTd[0080JD`Z0180J4/Y06M::01VBBL0
ITTW06M:;01VBB/0I4LY06549P1N@B<0G3lQ05/n801J?Al0Fc`P05Tk7`1H>R00ECTQ05<i8P1A>282
04li900504hi701>>Ah0C3PM04Th7P18=Qh00P16=Ql204@e800604hi901=>2<0CCPS04`g8P1;=R40
BSDP0P19=1l204Hd7P0304Pf8019=b40BSPR0080BCLQ00L0B3HP04Te7@19=Ad0BSHN04`h801=>B40
Cc/S0080D3`T0P1@>ah0301C>al0EC/P05Ll8@1J?280FcdS05`l8`1E?Ql0Ed0Q05Y18`1N@bH0HD<W
06=4:080ID<X00P0G3hR05/m8@1J?200FS`P05/m8@1L?R80GT0T05m19@<0IdTW0P1XBRP306U;:@06
06]8:01YB2L0J4LV06E79@1SAR@0GdDR0P1MAB400`1OA2L0GT<V05a1900205]08`0705a1901N@bH0
Gd@W05e3:01L@RL0FT0U05Pn8`0205Hl8@0305Lm8P1H?R<0F3hS00/0F3hS101G?B801P1J@2L0FClV
05To9P1H?RD0EcdT05Hl8`80EC/R00H0Ec/U05Hl9@1F?2D0ECdU05<m9@1B?RD2050o9@@0ES`Q101G
?B800`1G>Ad0F3XN05Tk7`0205/m8@0605Tk7`1H>Qh0EcTM05Y18`1H?b40E3/M0P1B>A/00`1D>ad0
F3lQ05Y18`0205]290<0FT4S0`1I@28305dn8P<0GSlS0`1O@2@805m29080Hd@U0P1TABH206E69`80
ITLX0P1WB2T206I7:00<06E69`1TABH0I4DV06A59P1]Cbd0JT`Z06E79@1RA280HD<Q06A6901WBBL0
JT`Z0P1XAbH0101YB2L0JTTX06Y9:01[BRT206a;:P0806e<:@1^CBX0Kdh[071?;01_CR/0KTdZ06a;
:01[BRL206a>;080Jdd[00X0JT`Z06U;:@1YBbT0JD/Y06I8901WBBD0J4XV06Y<:01[CBT0K4hZ0P1^
D2`506]=:@<0K4hZ0`1]D2h[ooooo`00:_ooool809Y_@P80WWA20P2MLd4209ab@080Vg4o0`2NLd02
09eb?`<0WW=02`2OLd800`2PM4<0XGE40:5eA0020:9fA@P0XGI3102PMT@209me@`80WWA21P2LMTL2
09egB080WgE30P2PMT@20:5gA@80XWQ600<0YG]90:5gA@2MLd400`2IKcd00`2KLCl0WWA20:1fA003
09I`@@80UFm00`2DKSl2095[?P0:091Z?@2>J3/0S6Hi08]U>02:I3L0RF<f08=N=022GC<0P5/a07iI
;`80OEP^00L0OUT_07mJ<020GCL0OU/e07]H<P1hEBl0MU<]00<0ME8/00H0MDh]07=?;@1bCR`0L4h[
06i=:P1[CBT206U=:00;06mA:`1^D2X0K4hZ06Y<:P1YBbT0IdPY06M8:`1VAbX0GT@S06169@1RB2L0
0P1TBRT06`1RB2L0GdDT05i48`1TAR@0IDLU06I89P1XBRP0JD/Y06]=:`1/CR`0KDl]071=9@1aCRH0
Le0X07EB:P1hEBd0NUL_07aI<@1mFS80OUPa07mJ<020Fc40Pehb08EP<`27Hc<0RFDc08YV=00308YT
=@80RfDf0`2<ISL308]U>0@0S6Hi00@0SFLj08QR=@2:I3L0SFLj0`2@JSd00`2>J3/0S6Hi095[?P04
095[?P<0TV`o1P2EJC`209AX>`P0Uf`o00H0V6`o09M/?`2GK3l0UVdo09A^?`2CKcl2095_?`80UV`j
0`2EJcT609AZ>080UF/i102FK3X809E[>@@0VFlm00@0VW0n09]a?`2LLT00W7900P2FLCd00`2GLSh0
V7<o09Ud@00209Ye@@0309]f@P2LLT00W7900080Vg4o00@0VW0n09U_?@2IKcd0VFlm202GLSh209Q^
?00409M]>`2FK3X0UF/i09AZ>080TfTg1P2CJ3/2099W>P0808]Y>@2:J3P0RVHf08YT=@2<HcD0SV<f
091U>02BIST808mZ=PP0SfTj0P2?Jc/3091/?0<0TFdm00<0SVTe091[=`2AK3P00P2CKSX00`2BKCT0
TF`h091[=`0209=]?P06099/?@2@JS/0SfTj08iX>@2=IcP0S6Hg0P2=JCL01P2=JCT0S6Lj08aW>`2<
Icd0RfHl08]U?P80Qf@j00@0QV<i08ER>025HSP0Q64g0P23H3H06@1oFRh0O5X]07]H;P1hEbh0M5@]
06mA:`1ZCRL0JDdX065::P1OB2T0FdHW05I39@1A@2@0CchT04`l8`1:?280ASXP04Di8@12>1l0?SHO
03Xd7P0g<Qh0<c0M038_700];R000P0/;Al00`0[;1h0:R/M02TZ700302PY6`0602HW7`0U9Qh09BHN
02@U7@0S91`08R<K0P0Q8QX8020S70807b8I0`0P8aX3024T6`8082<L0P0O8Q/201hQ6P807B0I0`0N
8AX301dP6@8071lH100K7QL01@0L7aP07B0I01hQ6P0N8AX08B8M0080824K00H0824I028T6@0U9aX0
9bTK02T[7@0d<Ah303<`7@0B03@a7P0e<Ql0=34N03<`7@0b<240;R`M02TW6P0R8QH0820F020Q6@0S
91h09BPQ02l[800_:al0<2`P034^7`0c<1l0=34N0P0e<ah203P_7P80=bhM0P0f;A`203D/6`<0<2dN
00<0;b`M02h[700^:a`00P0]:Q/802PY6`80:b`N0P0Z:ad202TZ7080:2TK0P0T9Ad0100S91`08R<K
024R6P0Q8QX2020Q6@807b8K0P0N8AX201dP6@8071lH0`0N8AX201lR6`<082<L00l08B@M028U7P0R
8a/07alE01lK3`0S7@l0:b@D034Z6P1=>1T0FdLV075K=P21Jd80RgA8091hB02CO4X00P2EOTX0202:
MCh0OFTf06YI;@1IBRT0BSlY03hh;00d<B`0;2/Y0P0Y:R@01P0X:B<09bPR02LX800X:B40:R/S02X/
8@<0:R/S00<0:BXR02PY8@0W:2000P0W:2001P0Y:b00:R`Q02/]8P0/;R<0;BlT02la9P80<38W00D0
=C<V03@b9@0d<RD0=38U03<a9003038`8`0@03D_8@0f<280>C<S03`g900o>RH0@C`X04<n:014@2L0
CdP[04e6:@1;A2L0BD8U04Y39P1<ABP0CTLZ0519;0D0CT<W0`1=@RH0101CA2D0E4DV05E69`1FAbP4
05M8:@0805M79@1HB2H0FDTW05Y::01KBbT0G4`Z05e=:`1NCR`206I<:@0306Q>:@1YD2P0JU4X0080
Je<W00L0K5@V06aE:@1^Eb/0LU`]07MQ<P1jI3<0NfDc0080O6Lb01H0NV@e07EN<P1`FBd0KUL]071I
<01aFC<0KeLc06aD<01WD2h0IU0[06I>:01WCRH0JdlW06iA9@1cE2H0MEHX08IO=026HCD0QV4d08ES
=@24I3<0Q6Hb0P23J3<01P1jHSH0Melc07=K;`1aEBd0Ke<[06eA:@80KU4Y01P0N54V07]B9P1oE2T0
QEHZ08aI;02BG2h0UUh_09UO<@2EIRh0UfT^09a^<P2QLcD0YWTf0:Ul>02ZOSL0Zglf0:f1>P2_QCd0
/HI10:b4?`2VOch0XW`m0:5m?`2SOd4209am?@0:09]l?02JNSd0VGTn09Uf?P2GM3h0UG8l09A`?02?
KSP0SVdg08e/=P80S6/e0`2;JS@0102?JSD0T6/f091[=P2AK3L2099]>080Tfhi0P2@KS43095_<P<0
TW0c00H0VW0f09Ua=P2ILCH0Ug0e09Ea=@2CLC@2095a=080V6li0`2IL3X309Ya>`0309Me>02HMST0
V7Hi00D0VGLj00P0TgDg09Ee>02IMcX0VWPk09]g>`2LMCX0Vg<h09Yb=`80UW@g00H0UgDh09Qf>@2F
M3L0U78e095_<P2?KC0208m`=`0<095b>@2CM3/0UGHm09Ae?02ALST0Sg0g08Q/>P27JcT0QFTg08EW
=@23IC<0PF<a0P21HC0408=T=P@0PV<e00P0Pf4a08AR<P25Hc<0QF<c08AR<P23HC40PEl_07mM;@P0
PF<a00H0Q6Df08AV=024IS@0Q6Hb08AV<024Ibl208AW;@80PVT`01l0PFP`081W<@1oIC80OV@c07eS
<P1mHS<0N5P_07YJ<@1jGC<0NUld07QP=01eGC40LU/_071I;@1[EBH0JU@U06YC9`1ZDbT0Je@[06aD
;P1^ES00L5Pd06QA:01VCbH0Hd`S0619801OAb40H4PR069:901TC2P0IDdW0080ITlV00@0J54X06]D
:P1/EBT0KELX0P1]EbH0201/F2D0Ke/X07=M:`1cG2X0LUPW079F9P1gF2T0Ne`]0P1fFRX00`1gFb/0
N5`/07UM;@0207YN;P0407]O;`1mHBl0OF4_07eQ;`@0O60^00L0Nel]07UO;01iGb`0N5h]07IK;01c
F2/0L5DZ0080Ke<[00H0JE@Y06QC:01XDbP0Ie8W06IA9P1UD2D206A?900305U=9@1JCRH0FddV0080
G4dV00H0G4XT05a88`1KAb80FT/R05]<8`1LCB@205e>9@0<05a=901KC2<0FT/R05U99@1JBRH0Fd/W
05a<:01KBbL0FTXV05Q8901FAR80DdDN0P1CAB000`1BA240DD8Q05528`02051190<0DT<T101A@R<0
2@1@@B80DT8Q0551801?@240CClR04Tn8P17?R40AS`Q04@m8@0204Tj8`0604Hj8P14>R40?cTO03di
7P0i>1`0>3LK0P0o>1h403hg7@80?CHL00P0>c<L03Tc6`0g<A/0=2lK02l/6@0[:QP09bPF02HW5`80
:BDI00H09bDI02<S6@0Q8QX07R4J01/P6@0J7aT201hP7@0601dO700L7Q/06adJ01XL6@0I6aP061XG
0P0J71/201TK6P8061XI0P0G6AP301@J60804aTG0`0B61H201HG6@@05AHH2`0D5AL801DF61P051DG
200A5aL@01@E5`P05AHH200D5ALH01DF60<05ALF0P0F61L301LI60P05QPG8@0G6AP801TK61006a/I
0`0L7AL201dN60<07QlI200Q8AT202DQ60<09R8I0`0W8aX202/U6@<0;2HJ0`0]9a/502`T6@<0:b<H
100^91P202lU6@<0<2HJ0P0a9a/2038X7080<bTM00H0=2XN03@[6P0d:aX0=b/K03P[6`0k:a`203d[
7@0403l/7P0m;1`0?B`L03d/7080?RdM0`0o;Qh203h]6`<0?bhL0`10;ad01011<1h0@S4O048a7`12
<Al204<b8080A3<Q2012<Al304@d7@80@c<L0`12<Q/404Dc7@@0AS@N201:=1l304Le7@<0B3HN0`19
=al804Pc7P<0AcDO00<0AS@N04Dc7@15<ad00P14<Q`2048a7`80@c8P1014<b400`0m;Ad0?RhN03l_
7`02044a8@0303l_7`0n;Qh0?BdM0080>bhM100j;A`203T/6`P0>2`L00T0?2/K03l^7P12<B40@S4Q
03l^7P0n;Ad0@C0P04Dd9016=1h00`15<ad204@b7080@c4K1015<R4204Hc8P80Ac@S01P0D3HO054g
801A>B40DSXR054i8@1>>200C3HN04/e7@1A>b<0Dc/S05@l901G?BH0FCdW05`m:01N?RT0GclZ05do
8`1O@BD0HT@X06A6:P1UAb/0I4HZ06=5:@1RA2P806A79`H0ITTW0P1WBRP00`1XBRP0JT`Z06Y<:P02
06U;:@0306]=:`1/CR`0JT`Z0080K4h/00@0Jdd[06Y<:P1YBbT0JD/Y0P1XBRP05@1YC2`0J4/[06I9
:@1TAbL0HD@T05i18@1K?Qh0FSdM05Xk7`1I>al0FC/Q05Hj8P1D>R<0DSTS04li901>>2<0CcXM04lj
7`1=>Ah0BSTO04Tg7`0204Lg8080ACHQ0P1>>B@00`1=>2<0C3LR04/f8@0204Xe800404Td7`15<ad0
AcDO04Tg8@80BcTS00/0BSPR04Tg8@17=Al0B3@L04Te7@1:=Qh0BcLO04di8@1>>R80Cc/S050l9002
050k7P0A05<k7`1E>b00ES/P05Tk8@1J?280Fc/R05Dn7P1G@200G4<T06159`1TAbT0IDHY06M5:@1V
A2P0Gd@W05i39P1M@RD00P1L@B@00`1N@bH0H4DX0656:@0206M99`80J4XX0P1YBbT206Y<:P0606i:
:P1/BBT0JdPX06U89`1UAbD0HdHT0P1PAR<00`1RA2P0HD<W06129P0205m19@0706129P1Q@bL0HT@X
05e3:01L@RL0FT0U05Pn8`0205Lm8P0305Pn8`1I?b@0F3hS00L0F3hS201I?R<205]09@80FSlT00D0
FChS05Pm8P1G?240Ec`Q05Xl900205Pl900305Lm901F?R@0E3lT0080DclT101G?B8405Hl8@0305Li
7@1H>Qh0FS`P0080FcdQ00H0FS`P05Pj7P1G>Ad0G44T05Tn8@1E>Qd2058g6P0305Dj7@1I?R40G44T
0080G4<U0`1K@R@305Y18`@0GSlR0P1O@2<3061190P0HdHV0P1SA2D206A59P80IDHW0P1VAbP306M8
:@@0ITLX00@0IDHW06e?;@1ZC2X0ITPV0P1SAB<00`1UAbD0JD/Y06]=:`0206U69P0406Y79`1[B2P0
K4TY06e::P80KT/[00<0KD`Y06i=:P1`Cb`00P1`Cb`00`1^CBX0KD`Y06]:9`0306a>;0@0Jdd[00L0
JT`Z06Q:9P1YBbL0JD/W06]=:@1/CRX0KDl[0080KU0/1@1]CbT306a>:0<0Ke4_:oooool002[ooooo
202KL4<209id@P80WG=100L0W79009]a?`2JL3h0VW0n09md@@2NLd00WG8o0080W74n00<0WG8o09ic
@02OM4400`2PM4<209mc@PD0WW9100<0Wg=20:1d@`2QMD@00P2RMTD00`2SMdH0XGI30:5f@`060:5f
@`0809me@`2PMT@0X7I40:5gA@2PMT@0WgE309id@P2MLd4209]eAP<0W7I70`2MMdP209me@`80X7I4
0P2QMdD30:9hAP030:1fA02MLd40Vg4o0080VW0n00@0Vg4o09ec@@2OMD<0Ug520`2FL44209E_@080
U6ho00H0TV`o095[?P2@JSd0SVPk08aV>@2;ICP208US=P0408AO=@23GS@0PE`b07mJ<080OUT_00P0
OeX`081K<@22GcT0P5dg07aI<`1hEBl0ME8/07AA:`80Le0Z00H0MDh]07=?;@1bCR`0LDl/06m>:`1/
CRX206Y>:@0606e?:@1[CBL0JT`X06Q::01WBBL0IdPY0P1XBB`206599`<0HTXX00<0HDTW06189P1O
AbD00P1VB2@0101WBBD0J4XV06Y<:01[CBT206a>:P0@071=9@1aCRH0Le0X07IC:`1hEBd0NeP`07eJ
<P1nFc<0P5Xc081K<@22GC<0Pehb08EP<`27Hc<0R6@b08UU<`80RV@e0P2;ICH308aV=`0308eW>02;
ICP0RfDh00H0RfDh00<0RV@g08]U>02=IcX00`2>J3/00`2=IcX0S6Hi08mY?00208mY?0<0T6Xm0P2A
Jch409EY?080U6Pk0P2CIcX809M/?`0609Q/?`2GK3l0Uf`o09I]?`2DKSl0Tflo0P2AKcl309E[>@80
U6Xh102CJCL309AZ>0<0UF/i0P2FK3X01@2DJSP0UF/i09E[>@2EJcT0UV`j00<0Ufdk00P0VFlm09Q^
?02HKS`0V6hl09U_?@2JL3h0W79009ec@@<0Ug8n0`2HLcl209Ud@00609ib@@2MLD00WG5009a`?`2K
Kch0VVhm0P2IKC`809Mb?P80V6hl00@0Ufdk09I/>P2EJcT0UF/i0P2DJSP209AY?0<0TfPk0`2BIcX0
202;JCT0RVPh08YV=P2:I3D0S6<e08iS=P2@ICP0TVHi0P2=J3@408mZ=P80SFPd202?JCX0102?Jc/0
T6`l091/?02@K3`2095]?@80TVhn00<0SfXf091[=`2BKCT00P2CKSX00`2BKCT0T6/g08mZ=P02099/
?@04095[?02@JS/0SfTj08mY>P80SVPi0P2;JSL01P2;JCT0RVPj08YX>`2:Icd0RFHl08UV?P80Qf@j
00<0QV<i08ER>024HCL00P23H3H06P22GcD0OeX`07aI;`1jEbl0MU@^079B;01/CRX0J4`W06M::01M
B2T0FdHW05M49P1B@BD0CchT04`l8`1:>b@0BCXS04Hj8015>B40@SPO03de7P0i<ad0=S4M038_700`
;AX0:bdO0P0Z;1h00`0Y:ad0:2XL02LY6`0302HX6P809BHN00<092DM02<T700R8a/00P0Q8QX00`0P
8AT082<L020S7006020S700401lR6@0P8aX082<J020S6P808B@K0P0R9A`301lR6`807R4J0`0M81T3
01hQ6P807B0I0`0L7aP201/N5`0601XM5P0K7QL06ahG01dP6@0O8Q/082<L0P0R8A`05`0R8QX08b<I
02@T600W:1X0:R/K02`]7@0d<Qd0<S0K030^6@0b<1/0=C<N03Le800e<ah0<c4L02/^7@0Y;1/09BLI
028T5`0Q8aP08b@L02LX8P0Y:R@0<2`P0080<BhO00<0<RlN03<`7@0d<Qd00P0e<a`303L^7@80=RdL
0`0e;1/02`0d<B80<c0Q034^7`0_;1d0;BXK02/X6@0Z9aP0:BHG02TZ700X:A/09bPJ00809RLI00@0
9bPJ02PY6`0Y:Q`0;2dO0P0[;1h01@0Z:ad0:BXL02PY6`0X:A/09bPJ00<08R<K0P0Q8QX3020Q6@80
7b8K0P0N8AX201dP6@8071lH0P0N8AX201lR6`<082<L01008B@M020U7`0Q9Ql08b@L02<Q5@0V8180
;2<B03P]6`11=240IDTQ079G;024JCh0TGI9099jBP2?N4H0S7E30P2:Lcl02@1eHSP0JEL_05I79P16
?240>cHS03<c9`0^<2/0:Bd/02PX:00202PX9P0302PY900X:B<0:2TQ0080:B/P100X:B4402TZ8P05
02/]8P0/;R<0;2hS02d_900^<2D00P0_<BH00`0`<RL0=S8V03Da9@0303Da9@<0=30T00H0=S0P03Pb
8P0k=R<0?STU044l:013?RP204A09`0304e6:@1<ABP0Bd@W0080BT<V00@0Bd@W04a5:01=ART0C44U
0`1=@RH0101>@bL0Cd@X04m4:01?A2P205E69`0<05I7:01GB2T0EdPY05I7:01EARL0E4DV05Q68P1I
Ab<0FTPT05a:9P1NC2P0GddY0P1QCb/01@1YCBH0JdlX06eA:@1`EBX0LULZ0080LePY0140LeTX06iI
;01`Fb`0M5l`07MS<@1iIC80NFD`07QU;@1gI2`0MV4d075L<@1/Eb`0JU@[06]E;P1/ES40JE8`06I?
;@0206QA<@0706YB;P1/Db/0Ke@Y075E9P1cE2D0M5HT08EP<`02089P<P03081P<@1nGc00O60`0080
NV0_01H0LETg071F=@1^E340KU8]06mA:`1cDb`0MUD/07QG;P1oFbL0PE`X08IN:P2;H2/0TV<]09QU
;P2KIS00WfP`09ia<02PLc00Y7Ld0:Qk=`2/P3T0[X8i0P2_PcP0202]QST0[hTn0;6;@P2]R480YH90
09mm?P2MOD00WWi30`2ENch02P2GNT00UgQ109Ie?`2FLSh0UFln09=]?02>KCP0SF`g08a[=P2;JSD2
08YY=00308]Z=@2<JcH0U6lh00L0U6lh0P2@KS43095_<P<0TW0c00T0WG<i09ad>@2KLcP0V74f09Ea
=@2BL3<0Sflb08i^<@2HKcT00`2IL3X209Ya>`80Vg8l00<0UgDh09Qf>@2IMcX00P2JN3/01P2IMcX0
V7Hi09Me>02BM3H0TgDg09If>@80VGLj00H0VGDi09Ub=`2HLCH0U78e09Id=`2HMST209Ug>P0A09Me
>02DLSD0TW0c091c>`2=L3P0Rfhf08a_=`2?LSX0T7<k08ia>@2;KSH0PF/i081Y=`1nIcD0OV@c07eQ
<@1nGc000P1oGc03081S=`<0Of8f0P1nHCD00`1oGBl0P5h`089P<P0208=Q<`03089P<P21Gc40P5h`
00P0P64b00H0QVLh08IX=P26J3H0QVPd08IX<P26JC4208IY;`0808=[;`22JRh0PVT`085X<020Ic40
OfDb07iT<@1nI3<207aK<P0607]K<P1iG380Me`a07=K;`1bFRh0L5T]0P1[EBH03`1[E2P0JU<Y06]D
:`1[Dbd0K5@^06eE<@1/EBT0Je@X06QA9`1TCB@0HTXT0618901OAbD0GTHT06==:00206A>9`0406I@
:@1XDRT0JUDZ06]F:@80K5LX00T0K5PU06mK:01cGB/0Le`Z079H9`1bERH0MePY07]L;@1eFBT00P1f
FRX00`1gFb/0N5`/07UM;@0207YN;PP0O60^00T0N5h[07UO;01jH2l0Me`]07=H:`1`EBX0LED]079F
;P1ZEBX00P1YE2T00`1XDbP0Ie8W06IA9P0206E@9@0605a@:01KCbL0FddV05]<9@1JBb@0G4XT0P1L
B2<305]<8`80G4dT0`1KC2<03P1IBBD0FTXV05];9`1LC2P0Fd/W05Y:9P1HB2@0EdLS05=57P1CAB00
DT@O0553801@@B00D44R0P1?@2<805938P0@05M48`1F@b80Dd<R05528`1>@2<0Bd0T04Xo8`18?R<0
CSXR04`j8P1;>b80B3`R04@m8@10?1l0?3/M03Tj6`P0@SPM00H0@3HK03df700l=A/0>38J03D`6P0a
;aX202h]6@0602lY6`0/:AX0:bLK02PV6P0T91X08R<K0P0O8Q/201lQ7P0601hP7@0L7Q/06adJ01XL
6@0I6aP061XG0P0J71/201TK6P8061XI0P0G6AP301@J60804aTG0`0B61H201HG6@@05AHH2`0D5AL8
01DF61P051DG200A5aL@01@E5`P05AHH200D5ALH01DF60<05ALF0P0F61L301LI60P05QPG8@0G6AP8
01TK61006a/I00@06a`F01`M5`0L7AL071dG0P0M7QP201hO6@P08B4I0P0U8AP302HR6@<09b<J00@0
:bDI02`V6P0/9QX0;2HJ0P0]9a/202hX7080<2HL0P0_9A/402hT6P<0;bDI0`0`9QX2034W6`80<2HJ
00<0<BLK038X700c:Ad00P0d:Qh01P0e:al0=B`K03D/6`0g:a/0>B`L03/[7080?B/M00@0?b`N03d/
700m;1`0?B`L0P0n;Ad303l^7P80?RdK0`0o;Q`3040_7@<0@C0N0P12<Al304<b80P0@S4O2013<a`8
04Hd7P<0C3<O0`1==20204he8@80AcDM0P18=Qh404Tg7`0304Xh8019=Ad0BCDM00H0BCDM0P1;=R40
0`1:=B00BC@O04Pc7P0204Lb7@0404Ha7013<R00@c8P04@c8@80AC@R00H0A3<Q04<b8012<Al0?bhN
040_7`11<202048a8@03044`8010;al0?bhN00<0>bhM1@0j;A`203P]6`0403T^700j;ad0>RlM03T^
7080>2dK00T0?2/K03l^7P12<B40@C0P03h]7@0m;1`0@2lO04@c8`17=Al00`16=1h204Dc7@80A38L
00@0AC8Q04Hc8P16<b80AS<R0P17=2<204Pe900>054e7`1B=R00DSPQ058j8P1@>R80Cc/R04di801:
>Al0DSXR05<k8`1E>b@0Ec/U05Xk9P1M?BP2060m:@0605m19@1P@RH0H48V06539`1RA2P0HdDY0P1T
ARX00`1SARH0I4LW06A79`0206E8:0<0ITTY101VBBL206M::080J4/Y00D0IdTW06a>;01/CR`0J4XX
06U;:@0206i@;P0606Y<:P1_CRd0Kdh]06i=;01]C2/0K4/Z0P1[BRT05P1ZBBP0JD`Z06U<:P1XBbT0
ITTW06A79@1P@b40GD0N05`o7@1J>al0FC/O05Xl8P1G>b<0EC/T05<j901?>B@0CSPS050k7P1?>Ql0
CSXO04/j801:>20204Ph8@80ASLR00H0CSTT04dh8`1=>2<0C3LR04/f8@1:=B0204Td7`0304@b7016
=1h0BCLQ0080BcTS00<0BSPR04Pf8016=1h00P18=1`01019=Ad0BcLO04`h801>>R8204lk8`0C04lj
7@1@>ah0DSXN05@j7`1F>b00FC/Q05Xl8P1K>b80ESlM05U2801NAR@0HTPW06I9:@1WB2T0IdHW06I5
9P1SBR`0HDPZ05i59`0205e49P0305m6:01QB2X0HdX/00<0J4XX0P1YBbT306Y<:P0;07=<:`1`C2X0
Kd/Y06e;:01ZBBH0IdTU06E9901TB2<0IDHZ06A5:@1R@bL00P1Q@RH01P1R@bL0I4DY06E6:P1M@bP0
G48W05Y09@<0F3hS00<0FClT05Y09@1H?R<01`1H?R<0101J?280FcdS05/m8`1K?B<305`n900405do
9@1M?b<0GClS05do8`<0G3hR0P1K?B401P1M?B@0G3hT05/m8`1I?R<0F3hS05Hn8P80E3lR00@0F3hS
05Lm8P1G?B80EcdR0`1F?240101E>b00FC/O05Xl801K?B4205`n8P0605/m8@1J?200FC/O05i0901L
?R80F3XN0P1F>1`00`1H>Qh0G3hR05i0900305]290D0G4<U00@0GSlP05m08@1O@240Gd0Q0P1P@B83
06528`P0ITTW0P1SA2D206A59P80IDHW0P1VAbP806M8:@0306a>;01ZC2X0IdTW0080IDLU00<0IdTW
06Y<:P1[CB/00P1[AbL206a8:00<06e9:@1^BRX0Kd/[06m;:`1]C2T0KTdZ06m>:`1`Cb`0LE0]071?
;01^CBX0KD`Y201/CR`206]=:@<0K4hZ0`1]Cb/306mB:P80KU4Y0`1]D2P3071?;2_ooooo000Zoooo
o`P0WG9500H0WgE309id@P2MLd40W79009]a?`2JL3h209U_?@030:1e@P2OM440WG8o0080W74n00@0
WG8o09md@@2PMD80XGE40P2PM4<209mc@P80WW910P2MLD001@2NLT40Wg=20:1d@`2QMD@0XWI50080
XgM6202QMT<209me@`<0XGM500<0WgE309ec@@2LLT000`2KMDH00`2LMTL0WGM809egB00209ihB@80
WgE30P2PMT@20:5gA@80XWQ60P2NM48209ec@@<0W7900P2MLd4209Ma@P<0UW110`2EKd003@2CKD00
TV`o091Z?@2>J3/0S6Hi08YT=`29HcH0R68e08IQ=`25H3H0PUdc081K<@1oFS000P20Fc401P21G380
Oe`f07iK=@1kF380N5D_07IC;@80ME8/00L0MU<]07M@;`1dD2h0M50^079@;@1`Cb`0KDl[0080JdlZ
00<0JD/U06Q:901WBBD00P1VB2H01`1WB2T0J4T/06Y;;P1TCB/0Hd`Z069;:@1QBRP00P1PBBL2065:
:0<0J4XT00<0JD/U06Y<9P1ZC2H00P1[CBL03P1`CBD0LDhV07=@:01fDb/0NEH^07aI<@1nFc<0Oe`d
089L=@22GC<0Pehd08AO<`25H3<0QV8b0P27Hc4308]U=P<0S6Hg0P2=IcP808]U>080SVPk00@0S6Hi
08]U>02;ICP0RfDh0`2<IST208eW>P80SVPk0P2?JC`0102@JSd0UVXm09EY?02EJC`209AX>`80TfLj
00<0TVHi09M/?`2GK3l01P2GK3l01P2HK3l0Uf`o09M/?`2FKCl0U6ho09=_?`80TFlo0`2DJSP209=Y
=`<0TVPf0P2CJCL309AZ>0@0UF/i0P2DJSP01P2EJcT0Ufdk09Q^?02IKcd0VW0n09]a?`80V6hl0P2G
KC/0102HKS`0VW0n09ab@02NM48409Qc?`@0Ug8n0P2PLT401P2OLD00WW0o09e_?P2LKSd0Vfdl09Y/
>`P0UW4m00H0VFlm09Q^?02HKS`0Ufdk09I/>P2EJcT209AZ>0<0U6Tl00<0TfPk099W>P2BIcX00P2A
IST02`2;JCT0RVPh08YV=P2:I3D0S6<e08iS=P2@ICP0TVHi08]V<P2<Ic<0SFPd0080SVTe00<0SFPd
08aW<`2;IS80202?JCX3091/?080TFdm0`2BKSh00`2@JcL0TF`h099]>@0209=^>P03095/>02@JcL0
SfXf00L0T6Xk00X0SfTj08YZ=`2:JSL0RVXi08UY>P29J3/0RFPm08QW?028Ich0Qf@j0P26HcT00`25
HSP0Q64g08=P=P02089O=@0H07iH<@1kF300N5D_07AB;01_CbT0JT`X06M::01VBBL0G4LZ05U6:01E
@BH0D3lU04`l8`19>R<0Ac/S04Lk9@16>R00A3PP044g7P0l=1d0>38L03D`700`;AX0;b`I0P0Y;Ah0
0`0X;1d09b/L02HZ6`0302DY6P0702@X6@0U9Qh09BHN02@U7@0S91`08R<K024R6P02020Q6@P082<L
0`0P8aX2024T6`<08RDL0P0O8Q/201hQ6P@07B0I00@07R4J01dP6@0M81T07B0I0P0L7aP401/N5`80
6QdF00@06ahG01dP6@0O8Q/08B@M0P0U8Q/05P0U8QT09B<G02PV6@0[:AX0;R`M02l^700b<1T0;bdF
02d[500`;QL0=C<L03Pf7`0f=1d0<c4J02@[6@0S:QP092PI02<W6@0U9a`09bPP02/Z9@0];2L2038_
8003038_7P0c<1d0=38M0080=C<L00<0=S@K03L^7@0g;Qd00P0f;A`403D/6`0;03<`8@0b;b00<BhO
02l/7@0]:Q/0:bPI02XW600Y9QL0:BXL02PY6`0V9aT00P0U9QP00`0V9aT0:2TK02TZ700202`]7`04
02//7P0Z:ad0:BXL02PY6`809bPJ0`0Q8QX4020Q6@0301lP600O8Q/07b8K00807R4J0P0M81T201`O
60<07b8K0`0P8a`2024T7@0?01/Q7@0N8ad08R<K02DS5`0/9AD0>BhL04Tj9@1DA2d0N5XX08AV=02B
M480Ug]909EiB@2;LD00PVPg0080O6Dc0100I5<g05Q8;P17>b<0>34N034_800/;b@0:2lW02D_9`0Y
:2d0:BT[02TY:@0Y:BL0:BXT02TZ8P0Y:b00:2XM0P0V9al0100W:200:2TQ02TZ8P0Z:b<202//90H0
;S0U0P0_<BH703Da9@0703Hb9P0h<R80>SDR03dh9@10>bL0@SdW04<o9P0204<o900304Q39@19A2H0
BTDW0080BTDW00d0BD@V04Q39@17@R@0BSlS04]0901<@BD0CD8V04m4:01@ABT0DDHZ0597:`1FAbP0
EdPY0080F4TZ0180EdPY05E69`1CA2D0DD8S05Q48@1IAB80FTHS05a89@1NBRL0HDdZ069>:`1SCb`0
JdlW06eA:@1aER/0M5T/07ML;@1iGbh207UO;00f079P<01eHc40N6Hd07YY=@1jJC<0N6L_07EU:P1c
HbP0L5db06]H;@1VDbT0I54Y06IB;@1VDRl0I50]065=;01UCC40J54b06eE<`1bF3<0MU/`07MK;01h
FRP0MeTU085O;`20GS00OUh_07]L;P1gFb`0MEX]07=H:`1aFB/0K58i06]A>01[D3<0KTl`07=B;`1i
ES00P5/a08=N=024Ib/0QVP/08UY;02?Jbd0U6`^09Y^<@2MKc40X70`0:Ei<02WNc80ZWhe0:f1>02_
PcP0/8@i0P2`QCL0202ZQcH0[XXl0:j<@P2ZRD80Xh8o09al?`2JO400Vga30P2?NCd02P2BNSh0TgU0
09Eg@@2FMD80UW9209A^?`2EK400Sfhk08e/>@2<JcP208YY=P0308]Z=`2<JcP0SF`i0080UW8h00@0
UG4g09A`=P2CKcD0TVhd0P2AKC<2091^<@<0TFlb0`2BL3<01P2KLCL0VW8g09Ua=P2HLCH0UW8f09Ab
=@80TW8e0`2IL3X209Ya>`<0Vg8l02P0UW@g09Me>02IMcX0VWPk09Ug>P2HMST0UW@g09Ec=P2@M3D0
TGDf09=e=`2EMCP0UgDh09Mc=`2FLSH0Ug0e09=a=02ELcH0VGLj09]i?02LNSd0VWPk09Qf>@2FM3L0
TW@n08a^>026J380QFLa08QZ=02;KCL0RV`f08QZ=01nK3X0Of/i07eW=P1lI3@0OV8c081Q<`21H3<0
Pf4d0P1oI3L00`1nHcH0OF8e07eR=@0307aQ=00407aJ;@1mFbh0Oed`085O<P80PV0c0P21Gc8807mP
<P0608QY>P28JSP0R6Xh08QZ=P28JS@0R6/c0P28Jc401P23Jbd0Pf/_089Z;P22JC00PFP`081W<@80
OfDb00D0P5de07mL=01kFS40N5P_07AG;@02079G;00B071H;01`FR/0L5X[071I;@1`FBl0KeP_06eE
;`1/E2h0Je<_071J:`1_FBX0KEHZ06YC:P1UCBL0H4PV05a3901I@240H4`W0P1QCBP03P1RCbL0I54W
06IC:01XEBX0JUPZ06]I:`1/F2D0Ke/X07=M:`1cG2X0LUPW079F9P1gF2T0Ne`]0P1eFBT0101fFRX0
Me/[07QL;01iGBd207YN;PH0O60^0P1mHBl0201fG2T0NEl/07]Q<01hGBh0LeP[075F:`1cEbl0MUXb
0P1ZEBX00`1YE2T0J5<X06MB9`0206IA9P0906E@9@1ODb/0GE4Y05]=9P1IBR<0F4TR05]98`1MBB@0
Gd/V00P0Fd`S00<0FTXV05];9`1LC2P00P1LC2P02@1JBRH0FDTU05M78`1GBB80ETPS05E78P1DAR<0
Dd@S0593900205529@80DT@Q1P1CAB80401JAR<0F4HR05M48`1DA2<0DD8S04m1901<@B<0Bd0T054i
8@1?>B40CSdS04`n8`16?b80@SlP03dn7P0j?Qd704@i7@0I04Dj7P12>A`0@CPK03hg6`0l=Q`0>CDL
03Hd7@0e<a`0<c8M038/700b;1h0;R/L02`X700Y9a/09BDK02<T700R8a/0828O01lQ7P0N81d07AlL
01/M6P0J71T06A/H01PJ5`0201XL6`806A/J0P0H6QT201LI60<051XH0P0C6AL3018H5P805QLI100E
5QP;01@E5`P05AHH600D5AL8014G5a0051DG200E5QP801@E5aP05AHH0`0E5aH201HH5`<05aTH200F
61LQ01LI60P06A/H400K6aT201/L5P<071dG0`0M7QP8024Q6@809B4H0`0V8QT302LS6P<0;2HJ0P0]
9a/302hX70<0<RPN00<0<BLM030V700`9Q`00P0_9A/2030V6P<0<BLK0`0b:1`2030V6P06034W6`0b
:1`0<bTM03@Z7P0e:al0=R`P0P0f;A`00`0h;1`0>B`L03`/7@0203d[7@0403h[7@0m;1`0?B`L03d/
7080?RdM0`0o;Qh203h]6`<0?bhL1P10;ad3044`7P80@S4O2013<R02044a6P04048b6`13<a`0@c<L
04@d7@80ACDN0`17=Al504Hd7P80C3<O0P1==20204he8@80CcHR0`18=Qh404Tg7`80BSPP2019=A`2
04dg8P0804`f8@1;=B00BS@O04Tc7P18<Qd0Ac4L04@c8@15=28304He8`0604@c8@11<1h0@2lM040_
7`11<200@S4Q0P13<R800`12<B40@C0P040_7`0203X]70H0>bhM00<0>2dI03T^6P0j;a/00P0k<1`0
2`0j;a/0>BhJ03P]6@0l:a/0?bhN048a8@11<200?RdM03d/7010;al0@c8R00<0AcDO0P16=1h304Dc
7@80AS<R0P17=2<304Pe900704Tf9@1B<Q/0DcDM05<g7`1D>R40DSdR050l8@0204`m8080DSPQ01L0
E3PR05Pi901J>RD0GS/W05ll:01P>bP0HT@X06129P1N@2@0GClS05i0901Q@bL0I4HZ06M9;@1RABD0
HdHV06A79`1UB2P0ITTY06M::P1XBb/0JD`/06E89P0206I99`80IdXX0P1XBbT0101YC2X0IdTW06i@
;P1^D2h206Q::080L58`00H0JD/Y075>;P1aCRh0L4d]06m<;01^Bb/206e::P0F06a9:@1YCBP0JDdX
06U=:01XC2L0ITXU06=78P1PA1l0GT8M05Xk7`1I>al0FS`R05Pl901F?2D0DcXT04li901>>2<0D3/N
050k801>>Ql0C3/Q04/i8@80BCTR0P17>2<204`g8P80BcHQ00`0BSDP04Td7`18<ah0B3<N048`6P14
<Q`0B3HP04Xh8P1;>B<0BCLQ04Hd7P14<Q`204Pd700604Te7@1:=Qh0C3PP04di8@1>>R80Cc/S0P1?
>Qd00`1B>Qh0E3XO05Hk800205Tk8@0A05/k8P1H@Al0Fd@R06189P1TBRT0IdXZ06M8:@1WARL0ID@U
069;;01PBBX0GDHW05]49@1J@b@0G4DV05m8:@1QBR/00P1XBRP206U;:@@0JT`Z00/0MU0/07E?:`1b
CRX0L4hY06e=9`1/C2H0JD/U06Q:901XAR/0IdDZ06E3:00206A29`0606E3:01WABX0J4H[05e3:01K
@BH0FT0U0P1H?R<00`1I?b@0FT0U05]19P0805To9080FS`R0P1K?B<0101L?R@0GClU05do9@1M?bD3
05`o8@<0GD0R0P1N@B<205ho8`0605`n8P1J?b80F3lQ05M08@1F?b00E3lP0P1H?R<205Lm8P80ES`Q
0P1E>b000`1K?B40G3hR05do8`0205i0900605do8`1L?R80FcdQ05i0901M?b<0FS`P0P1I>al00`1J
?200GClS05i0900205Y18`0305]2901L@bD0GD@V00<0GTDW0P1O@24206118P@0HD8S00<0HT<T06A8
8`1TB2<01P1TB2<206=49@80I4DV0P1UARL206I7:080IdPY1P1XBBX306U;:@0306Q::01YBbT0JD/Y
0080JT`Z0P1[AbL00`1/B2P0KDTY06i::P0206m;:`05071<;01[BRL0K4/X06m>:`1`Cb`00P1aD2d0
101`Cb`0Kdh[06a>;01/CR`606e?;@<0KU0/0P1]Cb/206a>:P0406]=:@1aE2`0L5<[071C:`80Ke8Z
0P1^DBT0101]D2P0KddX06m=:01_CBP[ooooo`00:_ooool809mdA`0;09me@`2NM480WG=109ab@02K
LCl0VW0n09U_?@2HKS`0X7E209md@@2MLSl00P2LLCh00`2MLSl0WgA10:1e@P020:5eA0040:1d@`2O
Ld80Wg=209ib@@<0WG500P2NLT400`2PM4<0XGE40:9fA@020:=gAPP0XGI300T0WWA209me@`2QMdD0
XWQ60:5gA@2OMD<0WG=109ab@02JM4D00P2KMDH00`2LMTL0WGM809egB00209ihB@80WgE30P2PMT@2
0:5gA@80XWQ600<0W79009ec@@2NM4800`2NM4800`2MLd40W79009]a?`0309Ma@P80UW110`2EKd00
2`2CKD00TV`o091Z?@2>J3/0S6Hi08YT=`29HcH0R68e08MR>026HCL0Pehd00@0PE`b00@0PUdc07]H
<P1jEc40N5D_0P1gE2h02@1hEBl0NEH`07YG<@1hDC00ME4_07A@;P1cDBh0LE0]06i@;00206a@:`0@
06M98`1VB280IDLS06A6901UAbD0IdPY06U:;@1ZBbh0Ie0^06E>;01RBbT0H4TW05m89P1PBBL0HT/Y
06A=:`@0JD/U101ZC2H02@1_C2@0LDhV07=@:01fDb/0NEH^07aI<@1nFc<0Oe`d08=M=P0208AO=@03
08AO<`25H3<0QV8b0080QV8`0`2;ICH208aV=`<0SFLh1@2;ICP308YT=`03095[?P2?JC`0S6Hi0080
RF<f00<0RV@g08]U>02=IcX00P2;ICP208aV>@0508eW>P2>J3/0SVPk08mY?02FJSd00P2EJC`00`2D
J3/0TfLj09=W>P02099V>@P0Uf`o00H0V6`o09M/?`2GK3l0UVdo09A^?`2CKcl2095_?`<0U6Xh0P2C
JCL3099X=P<0TfTg0P2DJSP409E[>@80U6Xh00P0UV`j09M]>`2IKcd0Vg4o09ab@02MLd40V6hl09M]
>`80UV`j00D0Ufdk09Y`?P2MLd40WWA209Ye@@0209Ud@00309Qc?`2GLSh0UW4m0080UG0l0P2PLT40
0`2OLD00WW0o09e_?P0209]]?00309Y/>`2FLCd0UW4m00H0UW4m0P2IKcd0102HKS`0Ufdk09I/>P2E
JcT209AZ>00409EZ?@2DJC`0U6Tl09=X>`80TVLj0P2AIST02`2;JCT0RVPh08YV=P2:I3D0S6<e08iS
=P2@ICP0TVHi08UT<02;IS80S6Lc0080SVTe00<0S6Lc08]V<P29I300202?JCX2091/?0<0TFdm0`2B
KSh00`2@JcL0TF`h099]>@0209=^>P03095/>02@JcL0SfXf00<0SfTj0`2@JS/2095[?080RVXg00H0
RVXi08UY>P29J3/0RFPm08QW?028Ich208IS>@80QF8h0180Q64g08=P=P22GcD0PUle07iH<@1kF300
N5D_07=A;01^CBX0JD/Y06I99`1UB2P0FTLY05Q4:@1B@BD0CCdS04Xl8P19>R<204Lk9@0904Hj8014
>200@CLN03`d7@0h<Q`0=2lK030]6P0_;1T0:BdN0080:2`M00<09b/L02HZ6`0U:AX00`0T:1T01P0U
9Qh092DM02@U7@0S91`08R<K024R6P80824I200P8a`2020S6P<08B@K0`0R9A`201lR6`807R4J0`0M
81T00`0L7aP07B0I01dP6@0201dP6@8071lH100K7QL01`0J7AH06A`E01/N5`0M81T082<L028U7P0U
8Q/00P0U8QT03@0V91P0:2HI02/Y6P0^;A/0<2lM034_600]:a@0:bTB02l]5P0e<a`0>CLP03Le7P0c
<AX00P0Q:QL03P0R:AT09BTK02LZ7`0Z:b<0;B`W02h]:00b;b00<RlN03<`7`0d<Ah0=38M03Dc700e
<aX0=S@K0P0g;Qd203H]70<0=B`K00D0=2/J030]7P0_;1d0;b`M02h[700202dZ6`80;2TJ00<0:BXL
02PY6`0V9aT00P0U9QP02`0V9aT0:2TK02TZ700];R00;2dO02//7P0Z:ad0:BXL02PY6`0W:1X09RLI
00H0824I0P0O81P201lR6`807R4J0P0M81T201`O60<07b8K0P0P8a`3024T7@0?01HL600J7aT0824I
02HT5`0a:QX0@C@Q05E5;P1RD3P0Q6<]08e^>02INT@0Vge909=gA@25JcP0NV0_0080LU/Y00h0G4/i
0552;`0n=R<0<R`L02//7P0W;Al092lQ028^8P0Z:Bl0:RT^02XZ;00Z:RP0:BXT02TZ8P80:2XM00P0
92DM02DV7P0V9al0:2TQ02TZ8P0[;2@0;2dU02d^9P80<38W0P0_<BH402h`9@<0=S0T00<0=c4U03Pb
9P0h<RH00P0i<bL0100i=240>cHS03hi9@11?2H204<o9P0504<o9012?R<0AD8S04I39019ARL00P1:
AbP02`18ABH0AD8S04=08@18?B40BChR04]0901=@RH0Cd@X0556:P1BAb/0DdP/0080F4TZ0P1IBR/0
4@1GB2T0E4DV05528`1?@240Ed<N05Q47`1IAB00G4PS05i:9@1PC2L0HThY06=?:P1/CbD0Ke8X07=F
:P1hG2d0O60`0080OV8`03D0OV<^07QV=01jJ3H0OF`h07i]>@1mK3H0NVTa07IV:`1cHbP0KU/`06UF
;01SD2H0HTlW06A@:`1TD2d0HTh]05m;:P1RBRh0ITl`06iF=01fG3L0Nf0e07eQ<@1mGb/0NedW07mM
;@1mGB`0Ne//07QI:`1dEb/0LEHY06eE:@1/E2P0J4li06Q>=`1YCCD0KTlb07EC<01oFC@0QUlf08]T
>@27Kbl0RG0^08a`;`2@LC00UG8`09Yc<02LM2l0Wg@`0:Um<P2[P380[H8d0;25=`030;66>0090;25
=`2YQS@0ZhXi0:f<?`2YR440XH9109]m?`2HNd40VGa40080S7Pm00X0SWPn095h@02EMd<0UGE409Ib
@P2EKd80UF]108m^>`2>KCX0S6/h0P2:JCH02`2;JSL0SF`i08i]>P2FLSP0UG4g09A`=P2BKS@0TFdc
08m[<@2>JS00SFT_0080T6ha0`2AKc83099`<`0809M]<`2GKc@0Ufld09M`=@2GLcL0UgDh09Ee>02F
MST209U`>P<0VW4k0`2KLS`00`2ELcH0UgDh09Qf>@0209Ug>P0H09Me>02ELcH0U78e08mc=02@M3D0
TW@f09=e=`2DM3L0UG<f09Ea=@2DL3@0TW0c09Ec=P2IMcX0WG/n09il?`2MNch0VWPk09Qf>@2AMSl0
RVlh085V;`1nHb`0PVL`0P25JS<02P24JC80Ofll07i/>P1nJSP0OVHf081T=@23I3H0QV@g08MU>01o
I3T207iS>00307eR=`1lHCH0O64f0080Nf0e00@0NELZ07]I;01nG2l0P5ha1022H3<807iO<@0608UZ
>`29JcT0RF/i08U[=`29JcD0RF`d0P29K3803024K2h0Pf/]08=[;`22JC00PFP`081W<@1oIS00OfDb
089O=`20GCD0NeXa07IF;@80LE@Z0P1aER/207EO<00?07IO<`1fGcD0M5dd071H<P1]EBl0Je<_07=M
;01bG2d0LEX^06eF;@1WCb/0H4PV05Y18P1F?Al0H4`Y0080HDdX00h0HThY06AA:@1VDbT0J5DZ06YH
:P1[FB/0K5PU06mK:01cGB/0Le`Z079H9`1bERH0MePY07]L;@80METY00<0MUXZ07MK:`1hG2`00P1i
GBd00`1jGRh0O60^07aP;P0307aP;P<0OF4_00T0M5XW07QN:`1kHC00NEh_07AI;01aER/0M5P`07QL
=01[ER/00P1ZEBX00`1YE2T0J5<X06MB9`0206IA9P08069F;P1NDRX0FddV05Q98P1FAb00FTPR05i:
9@1PC2L205]<8`@0FT/R0P1KC2<03P1JBRH0Fd/W05a<:01MCBT0G4`X05];9`1IBBD0EdLS05Y<9@1J
C2L0FD/V05Q:9`1GB2L0EDHW0P1DABP00`1BA240DdDR05=58P0205=58P<0E4HS0100FdLT05Y68`1H
AB@0EDDT0593901@@b<0Cd4T04a18`1A=b00DCTQ050l8`1=?b@0BT4T04A18P0o@200>clN0`14>Ad4
04Dj7P0704Hk7`14>A/0@cXK048i700o>1`0?CLM03/g7P0203Pf7`0@03D^7P0d;Qh0<R`N02hZ7P0[
:Ad09bLM02@V6`0S91`08B<P020R7`0O8Ah07AlL01/M6P0J71T06A/H01PJ5`806Q`K0P0I6aX201PJ
6@805aTH0`0D6QP201<I5`<04QPF0P0F5aT401DF60/051DG200E5QPH01@E5`P04ALG400D5AL801DF
60P051DG600E5QP301DG5P805QPG0`0G6AP801HH5b405aTH200I6aP@01/K6@<06a`F0P0L7AL301dN
60P08B4I0P0U8AP302HR6@<09b<J0P0/9QX302dW6`<0;RPL0P0f:B0203DX7`0403@W7P0c9Qd0<bHM
038U7080<BLK0P0b:1`403<Y7@80<2HJ00@0<BLK038X700d:Qh0=B/O0P0f;20203H]700303P/700j
;Ad0?2`M0080?B/M00@0?R/M03d/700m;1`0?B`L0P0n;Ad303l^7P80?RdK0`0o;Q`3040_7@<0?bhL
0P10;ad3044`7PP0@c8P0P10<1T01011<AX0@S8K04@d7@15=Ah204Hf7`@0AcDO1016=1h204db7`04
04hc801?=240Cc@Q050e8P80DCHS0`18=Qh304Tg7`<0BSPP201:=Qd01P1>>2<0CCLR04`f8@1;=B00
BS@O04Tc7P80B38M00/0AC@R04He8`17=R@0AcHT04He8`13<R00@2lM03l^7011;Ql0@RlP04<`8@02
04@a8P0304<`8@12;b00@BhO0080>RdL100k;Qd203`_7P0303P]6@0i;QX0>c0L0080?34M00`0>c0L
03T^6P0h;AT0?2/K03l^7P12<B40@C0P03h]7@0l:a/0?bhN048a8@18=R0304Le7`80AS@N0P15<ad0
1016<b80Ac@S04Ld8`17=2<204Pe9080BCHU00h0DC4H05<c6P1B=a`0E3XO058m801??R00CSlP04`o
7`1A=b00DcLQ05@h8P1G>2<0FCTT05dj9P80GcXW0140HdDY06129P1M?b<0FcdQ05`n8P1P@RH0IDL[
06Q:;P1QA2@0HTDU06=69P1UB2P0IdXZ06U<;01ZCBd0Jdh^06E89P0206I99`0306M::01XBbT0J4/Y
0080JD`Z00<0IdTW06mA;`1_DBl00P1XBRP2075C<@0506U;:@1aCRh0LDh^071=;@1_C2`00P1^Bb/2
06e::P0E06Q<9`1YCBP0JDdX06U=:01WBbH0I4PS0655801O@ah0FCXN05Tk7`1K?B<0FCdU05Lm9P1D
>bD0CcTT04hh8`1A?1l0D3/P04lk801<>b40BcTQ0080BCTR0P17>2<01P1<=b80BcHQ04/f8@1:=B00
BC@O04Pc7P80Ac8M00<0@BlI04<a6`17=Al00P1:>2802`18=R00AC<M04<a6`17<a/0B3@L04Te7@1:
=Qh0C3PP04di8@1>>R80Cc/S0080CcXM0140DSXN05@j7`1F>b00F3XP05Tk8@1J>R40FD<N05a68@1Q
BBD0ID/X06Q;:@1WBBL0ITDT06A38P1QBR/0GTLX05]49@0205Q18P0305Y3901MARL0GdPY0080J4XX
0P1YBbT306Y<:P0<06]=:`1hD2d0Me4]07I@;01bCRX0L4hY06i>:01[CBL0JT`V06Q6:`1WABX0IT@Y
0P1U@bP02@1VA2T0IdDZ06Q6:`1M@bP0Fd4V05Y09@1I?b@0F3hS05To900205]19PP0FClT0P1K>b80
101L?2<0GCdT05dm901N?RD205lo9P80G3dP00@0GChQ05ho8P1O@2<0Gd0S0P1P@B@01P1Q?b@0Gd0T
05ho8`1L?R80FSlR05Po8@80ESlP0`1H?R<00`1G?B80ES`Q05Dk800205Dk800305`n8P1M?b<0GT0T
0080H48V00H0GT0T05do8`1L?R80Gd0T05ho8`1M?R8205`m8@0905dn8P1N?b<0Gd0T05U08P1J@B<0
Fd8T05a39@1MA2H0GdHX0080H4LY00@0Gd4O0612801P@R00H48P0P1Q@b4306948PP0HDDP0P1SA2D2
06A59P80IDHW0P1VAbP00`1WB2T0J4TZ06Q9:P0206Q9:P<0JDX[0P1XBRP206Y<:P0406]=:`1ZC2X0
JT`Z06U;:@80KDHW00@0KTLX06m8:@1`BBX0LDX[0P1bBb`0101ZBBH0K4/X06i=:P1`Cb`2079A;P80
LE0]00<0K4h/06e?;@1]Cbd00P1]Cbd306i@;P80L58^00<0Ke4]06i@;01]Cb/00P1[CBT01@1ZC2P0
LUD[075D:P1aE2X0L5<Y0080Ke8X0P1^DBL306i<9b_ooooo000Zooooo`070:5gA@2OMD<0WG=109]a
?`2JL3h0Vg4o09ab@00909ec@@0809]_?P2LL3l0WW9109mc@P2PM4<0Wg=209ib@@2MLD030:5f@`<0
X7E20P2OM440102MLd40WWA209id@P2OMD<20:1fA080XGM500H0VgM309ag@`2LMd<0WWI309me@`2P
M4<20:9d@`<0X7E20P2QMT<30:9gA0@0XGM5102PMT@20:5gA@80X7I400@0WgE309id@P2NM480WG=1
0P2JMD403@2IM400V7<o09Ud@02IM400VWE109]f@P2LMd<0W75609]`A@2JKd@0V6e209EZ?`2CJ3d0
0P2AIS/03P2BIC/0TFHk099W?02@Ic/0SFLj08YU>025HcD0Q68d08IP>@25GcP0Q5hg08=M=P22G3D0
P5Xc0P1oFC800`1jEc40NEH`07IC;@0307AA:`0:07IC;@1gE2h0MT/[07A;:`1cC2/0KddZ06]=:@1Y
CBP0IThX06E=9`80ITPT00L0IdTW06M8:@1WB2/0IdP/06Q9;@1XB2l0IdXZ0080ITTY00<0IDPX06A7
9`1TAbL00P1SARH0201XBB`0JDX]06Y;;01[CB/0KDl]06i@;01_DB/0L58/0`1dDBT01@1eDRX0Me@/
07]H<01nFc<0P5de0080P5Xe00@0PE/d08=N=024Gc<0QV4d0P27Hc<208eW>P@0S6Hi0P2;ICP2099W
?080TFHk00l0T6Dj08mT>@2?I3T0SV<h095Z?`2=IS/0Rf@i08aU>P2?J3d0T6Tn08eV>`2:HcP0SV<f
091U>02BIcX00P2DJC`01P2CJ3/0TVLj091U>02AIST0TVLj09=X>`80UFXm00<0TfPk099W>P2AIST0
0P2DJcL309E/>0<0UVdi102EJSd0102DJC`0TfPk09=X>`2BIcX209=]@004095/?`2>K3h0SFdn08a/
?@80RV/l2@2DJC`309EZ?@80UV/n0`2GK3l00`2FLCd0Ug8n09Qc?`0209Ud@00709Qc?`2FLCd0UG0l
09]f@P2JMD40V7<o09Ia?@0209E`?00309Ia?@2GLSh0Ug8n00L0Ug8n01P0VG@m09E`>@2BKCH0U6lh
09Qc?02JMCh0Ug8k09=^=`2JL3h0VFlm09Q^?02GKC/0UV`j09E[>@2DJSP0TfTg099/?@2AJc`0T6Xk
08mY>P2>J3T0SFLh08aV=`2;ICH508eW>0<0SVPi0P2<ISL308eW>0<0SVPi102;JcX408YZ>@0308iZ
>P2?Jc/0TFdm0080TVhn00<0TFdm08m[>`2>JSX00`2@JS/2095[?0<0TV`m202>JSX308YX>P80RFLi
0`28ISP08023IC40QFLc08MY=`27J3T0QFHh085R=P1lGC40NET`07IG:`1dEbd0LeH/071D;01ZDBT0
I4`V05i88`1LAR40Dd8T05529@1>?b80BS`Q04Hj8014>R40@SXS04<k900n>200?3HN03Lb700b<1/0
;RdI02//6P0Z:aT0:B`K0`0X:Ql302LY7P<09RPM00P09BHP02@U7`0R8ad08B8L020Q6`0Q8Q`08R<M
02<T7P<07b8K0P0P8a`3024T7@03024R6P0R8a/092DM00<09BHN00@08b@L028S6`0O8Q/07b8K0P0N
8AX201dP6@8071lH200L7Q/02P0I7QP06QlI01dP6@0O81P08B<H02<S5`0V91P09R@G02/W700Z9Q/2
02TU6P0=02XV6`0^:Ql0<BdR03@`9@0b;1@0=2hF03Lb700g=B00=SDQ034b800];Q`0:RdL02@U7@02
02DU6`0802PV6P0/:1`0<B/M03H_7`0i<R80<bhK03D`7@0g<Ql203Td8@0403Lb7`0e<1d0<bhK03D`
70<0=2lK0P0c;QX2038]6@0@02h^900];B<0;2`R02XZ800Y:Al09bLM02HV700U9A/09RHL02PX7P0Z
:R00:b/Q02`/8P0[:b40:RXP02TY7`809bPP00<09RLO02DV7P0T9Ad00P0S91`00`0R8a/0824K020Q
6`0201lP6P807QlI100M7QP201hO6@807b0J0P0P8A/05`0Q8AL0820F01lP600N8AX07b8K01`Q6`0I
7a/05adI030W:00_9B<0<BDI03XZ4`1;=aH0H4TM07IM9`23JBh0W7E:09UdB02DLdP0SG9508=^@@1b
I3L0HEHX0080Dd/M00H0=ST^03@g;00`<bP0;C0U02X]8P0X:b0202LZ7`80:B`U100X:b@202LZ8`06
02HW7`0W:200:2TQ02TZ8P0[;2@0;2dU0P0];RH00`0];B<0;blU034a9`0303<c:@0B034a9`0`<2H0
;S0U02h^900];B40;bdP038_800g<B40>c@T03df901<@RT0CD<Z04a2:@18?RD0@cTP048h7`16?2<0
BT0W1015@b`02P13@BX0@T0Y040n9`0o?BH0BSlS04a19@1@ABT0DdP/05I;;`1GC30205Q=<@0605=:
:@1CB2P0DTLW05=69P1CA2D0Dd8T0P1D@B<05P1>@RP0E4@Z05Y9;@1SC2d0JTd]06e<:@1^BRH0KdTT
07M@9@1jEBT0P5/^08AR<P27IcH0QfTe08EZ<`24JC80Nflk07U/>01fJ3L0M6@c07=Q<`1dGc@207EN
=@05075E;P1_Db`0K50Y06Y>9`1XC2D00P1WBb@01P1XC2D0KEH/06mH;01bFbl0MEl`07MQ<080Mf4_
02T0Mf8]06aN>`1[GCP0JeTe06YF<@1/E2h0L5@]07AD;@1eEBh0Oe4]089D<024Ec00Q5L^08AG;@27
Fbh0Sf<d09EY>P2DJRh0UV``09Ya<@2OMS@0XWXd0:Am<P2UOS40YWl`0:ao?02aQ440]HY60;B<A`2_
R4<0ZhI00:b7@@2[RD80ZH9;0:N2B`2VPd/0XH9909f0AP2FOT80T7Xn08ei?00209ij?P0G09ah?P2H
M3X0U6lh09A_>P2EL3`0V79109Yd@`2HMCD0VGHf09Yf>02JMSX0V7@j09Ia>P2CKSL0TF`g08e]<02B
LSD0UgLj09Qh>`2CLcH0Sflb08e]<02>KS400`2=Kc<208i`=0<0Sg4e00T0VW0d09ab=P2PMSX0XWPl
0:=i?@2PMSX0WG<g09]a=@2KNC`00P2JN3/00`2IMcX0V7Hi09Qf>@0209Me>00309Mf@@2EM3l0TW4l
0080TG0k00`0TW4l09Ed?`2FMD00Ug=109=b?`2AL3d0Sfll08e_>`2;L3/0S74l08ac?@2@Mc@3095h
=@07091g=02>MC80Rg8_08Ya;P2:KD40QfXn089U>@0207iQ=@0>081S=`24Ic/0QfXn08IV=`24I3D0
PF0c07iM<P1lFc80OE/e07iL=P20GST0Of<d07iR<`1lH34207YN;`0F07]O<01mHC80OV8c07eH;P1l
FBl0Oe`b081O=020HCD0OF0d07]P<`1jGc80Nehf07YM<`1iG300NEd]07YO:P1lHRT0OfDZ085W;026
J3@0QFLc08=U<@80PV@`00/0Q6Hb08EW<`27JCD0R6Pg08MW=P26ISD0QFDd08=S<P21HC00P60_07mO
;P0207IP;`80MEl^0`1dGRd04P1cGB`0O5`c07aL<`1kGS@0NEhc07EM<@1bFbl0KUT/06aG:P1/GRd0
KEd/06aK;@1[F2d0JeD/06YB;01ZD2/0JDl/05a67`80GTPQ00H0H4XS06==9P1VD2T0J58[06UC;01Z
E2d2075F:`07079E:`1cER`0MED/07MF;@1iERh0NUL_07UL<P0207UL<00307YN;`1jGRh0NUh/0080
NUlZ0`1mHBl307aP;P80Nel]00P0Mf0^07QP<01gHC00Mf4b07EP<`1`GC80KE`a06]J;`D0JeDV0P1Z
E2D02@1YDb@0HT`U061:8`1MAb00FdDN05a67`1OBB80HddV06E?:00205Y89080FdTU0`1LBRH0101M
BbL0EdXW05M:9`1GBRL205I99P<0EDPU0P1JC2T0101IBbP0F4XW05M99P1FB2D205E7900904do701>
@1d0D48O05948@1EAb@0EdTV05U;:01JC2T0FT`W00<0FD/V0P1HBRD205M99080E44P00@0DT8P0553
801@@b00D4<P0P1=@al02@1C?R40DSdP050m7`1=?1h0C3/M04Xk7018>a/0AcXJ04Po7P0204U08@0C
04U08`16?240@CLN03db700j;aT0=cDN03Hd7@0d<Qd0<BhK02l/6`0/:AP0:RLH02TV5`0W9ad09RHL
02@U7@0R9A`07R<L01`Q6`0201XP70806Q`I0P0I6aP301PJ5`0301LI5P0F61L05QPG00H05QPG2@0E
5aH8018H610051DG2P0E5QP201@E5`804a@F0P0B4aDP01@E5a005AHH200E5aHB01HH5`<05aTH0`0H
6QT201LG5@8061PF100I6AL801XJ60P061PF500J6QP301/K6@X071`J0P0M71L0100N7AP07ahI020O
6P0Q81/2028Q70<08B4I0P0R8QX302<S6`808R@I0P0S9AX202@V6`809BLL0`0[91`202`U7@<0;BHN
0`0a9ad3038X7P80<bTO0`0a9AT00`0b9QX0<bLK03@X700203@X700803DX600g:QX0>B`L03X]7@0k
;Qh0>RdM03T/700h:a/403D/6`80=2/J0P0c:QT203/Y7@0>03/Y6`0k:QX0?B`L040_7@12<Ad0A3<O
03h]7@0o;Qh0@C0P048a8@11<200@2lO03h]7@0l:a/203X_6`80>c0L100l<Ad204@a8080AC8Q0`16
<b801017=2<0BSDP04Pc7P16<A`204D`6`0904Ha7018<ah0BSDP04Lb7@18<ah0BC@O04Xe801;=R40
C3LR0080CCPS00`0C3XR04di8@1;=al0BcDN04he7`1A=R40E3PS05Di901D?RH0DcdU050j8P1>>203
04`f7P0304dg7`1>>200BSPP0080BSPP0P19=al304Pf7P80DCDP00<0Cc@O04dd7P1:=1d00P18=1`0
4@15<a/0@S0J04<a6`16=1h0AcDO04Pf8017=Al0AC<M04@b7019<ah0B3<N04Dc7@12<a`0@3@L03`e
6`0j=1X0>CDJ00P0?RdM0`0h;b0203L^7`<0=RdN0100<c4J03@b6`0h<Q`0>S8M03ha7P12<Al0A34P
04Lb8@14<al0AC@P04Le7`1:=Qh0CCLO050h7P1A>Al0DcTN2019>1h204li8@07054i8@1C>B80E3PR
05Hg8P1G>2<0F3PS05Xk9`0205Xk9P0305/m9@1K?B<0FcdQ0080G3lQ0`1M?b<00`1N@2@0Gd4U05m1
9@0206129P80H44T00@0HT<T06A6901UAbD0IdTU0P1YBbD206=;9@0606M;9P1XBRH0K4XW06m89`1`
AbL0LTLW0P1/BbP0101]C2T0KTdZ06m>:`1_CR/2071?;0<0Kdh[101`Cb`03P1aD2d0KU0/06e?:`1/
CRX0JT`X06U;9`1WBBD0ITPT06E78`1TAR80HT@P05m17`1L?Ah0FS/N0P1I>Qh01P1J>R40FClV05Pn
9@1F?R@0DchS054m8P80CC`P00<0C3/O04/l7`18>1l00P18>1l204Lg7P<0ASHM0P16=20204Le8@04
04Pf8P19=b<0BCLS04Xh90P0AcDM00P0CCPM04hi7P1A>Ad0E3XO05Ll7`1K?R00GD0P05m08@80HShT
0P1S?bD0201T@2H0ID4W06E19`1U@BL0Gd0Q06118P1SA2D0IDHW0P1VAbP02P1UARL0I4DV06M?:`1X
CR/0JDl/06a?;@1]Cbd0Kdh]06m<;01^Bb/4079A;P04071?;01]C2T0JTTV06Q79080J4TZ1P1WB2T0
0`1M?ad0Gd4O06=58`0206E79@0606948P1O@Al0GClM06539`1O@BD0G3hR0P1I>al01P1J?200G3hR
05i0901K@R@0G4<U05e49P80GTDW00<0GD@V05]2901I@280201O@BD0201L@RT0FT0W05Lo9@1B?B80
D3`Q04ln8P1@?b<0D44T201H?R<205Q18P0>05Y18`1L@B@0H48V06939`1U@bP0IT@Y05hl8@1O?B80
Gd0T06129P1N@bH0Fd8T05Q18P1G@24205U28`0305Y3901KA2D0G4DV0080GTLX00@0GdPY05m28P1O
@R80Gd8R0`1P@b<3065490H0HDTW0P1RBRP0201WB2T0J4TZ06Q::01YBbL0JT`V06]>9P1/CbL0K4lU
201[BRL806e=9P80JDPU00@0JTTV06a;:01^CBX0Kdh[0P1aD2d00`1`C2P0LDdY07=?:`0207A@;003
07=?:`1bCRX0LDdY00P0L4`X00P0MU<]07=@:P1aCRP0LTlY07AA:`1eDR`0LTlY06i;9@<0LE4Z0P1`
D2T306m?:0<0M50^:oooool002[ooooo00<0X7I409me@`2MLd400`2KLCl00`2LLT00WG=109ec@@07
09ec@@0309]_?P2LL3l0WW910080X7A300<0Wg=209ib@@2MLD000`2QMT<30:1e@P80WgA10`2NM480
0`2OMD<0X7I40:1fA0020:5gA@0609]g@`2LMd<0W7M309if@`2OMD<0X7A30P2RM4<30:5f@`<0XWM4
0P2SN4D30:9hAP030:5gA@2PMT@0WgE30080WgE30P2QMdD20:1fA080WgE30P2NM48209Ud@0L0VWE1
00H0Vg1509Y_A02IKT<0Ufa109EZ?`2DJCh2099W?00>099U>`2AIS/0TVLl091W>`2=IcX0RF@g08ES
=@23HC<0QV0i08EO>024GSL0Pedf089L=@20FS<207mI<P0407YG<@1iES00Me@^07EB;080M54[00X0
ME8/07IC;@1fCBd0MTd]079>;01`CR/0K4hZ06Y>:@1WCBP0IDdW0P1WBBD00`1WBBL0IdPY06M8:`02
06M8;00506M7;P1VBBT0ITTY06I9:@1UB2P00P1TAbL206=69P0906Q9;01YBRd0JT//06]=:`1]Cbd0
KU0/06mA:`1`DR`0ME8Z0080M54Y00D0ME8Z07IC:`1iERh0O5Ta07iK<`02081J=@04085K=023GS@0
Q5lc08IQ=080Qf<c202<IST2099W?080TFHk01<0T6Dj08mT>@2?I3T0Sf@i095Z?`2=IS/0Rf@i08aU
>P2?J3d0T6Tn08iW?02:HcP0SV<f091U>02BIcX0TfPk09AY?02CJ3/0TVLj0080TFHi00L0TVLj09=X
>`2EJSd0UFXm09=X>`2BIcX0TFHi00<0U6Xh0P2EJcT309I/>P<0UFXm0P2DJC`209=X>`09099W>P2E
K3h0TV`m099/?@2@K3`0SV`l08a/>`2;KC/0RV`j00T0U6Tl0`2FJch309M/?`80V6e000<0UG0l09Ia
?@2HLcl00P2IM4001`2GLSh0UW4m09E`?02JMD40VGA009Mb?P2FLCd00P2EL3`00`2FLCd0Ug8n09Mb
?P0709Mb?P0809Qc?02EL3T0TVdf09A_>02HLc`0VG@m09Mb>`2CKSL209U_?@0609Q^?02GKC/0UV`j
09E[>@2DJSP0TfTg0P2AJc`0102@JS/0SfTj08iX>@2=IcP208aV=`H0SFLh0P2>J3T208aV=`<0SFLh
0`2>J3T408][>P@0RVXi00<0SVXj08m[>`2AKCd00P2BKSh00`2AKCd0Sf/k08iZ>P03091Z>`80TF/l
0`2BK3d808m[>`80RVPj0`29IcT308QV>008089T<024IS80QFLe08IW>024ICL0PF8f07aM<@1jFS42
07AG;@0<079F;P1^EB`0JE8Y06==9P1OBB@0FTHQ05=2901@@B@0CChQ04Tk8016>R00A3XQ0P12>R<0
200n>200?3HP03Pc7@0b<1/0;bhJ02//6P0[;1`0:RdL0`0X:Ql202LY7P@09RPM00<09BHP02@U7`0R
8ad00P0P8A/00`0Q8Q`08R<M02<T7P0301lR6`8082<L0`0Q91d00`0Q8QX08R<K02@U7@0202DV7P03
02@U7@0S91`08R<K00807b8K0P0N8AX201dP6@8071lH200L7Q/0200I7QP06QlI01dP6@0O81P08B<H
02<S5`0V91P09bDH0`0Z9Q/03P0[9a`0;BTN02l[800a;B80<RhS03@^5P0f<1X0=c8L03Le800e=200
<34O02`]7@0X:aX092DM0P0U9A/01@0Y9a/0;2PL038/7P0f;al0>34Q0080=C0M00@0=S4N03Lb7`0g
<Ql0=S4N0P0e<1d403@_7080<bhK0P0b;AX202d]8`0902`/8P0Z:R00:2PN02LW7@0V9Q`09BDK02HV
700X:1h0:BTO00<0:b/Q00P0:RXP02TY7`0W:2009bPP02HW7`0U9Qh092DM02<T70808R<K0P0P8A/2
01lP6P807QlI100M7QP201hO6@807b0J0P0P8A/2020P5P04020Q6@0Q8QX08B@M024T7@807b@N00l0
:1hL02/P6P0e9aX0A3@K05U58P1`FBd0Q6/e091f?@2KMdL0U79408a]?`21JCd0MV<i06IH<@1DBRH0
0P19@A`0100c=R/0<C@Y02ha9P0[;R<202P[800302LZ7`0X:b009bXS00L09bXS01409RLO02LX800X
:B40:BXR02//900/;BD0;BhV02h_9`0];B<0;blU034a9`0b<RP0<c<Y038b:00a<BL0<30V02d_9002
02h^8P0=034_8P0e<R<0>S@T03hg9@10>BL0C48Y04e3:P1>A2/0Bd4X04Hl8`14>R40AS`S04Y09`02
04=1:P030490:@11?bP0@3hW00<0@3hW00D0C44U04i39`1@ABT0DdP/05E:;P0305I;;`0N05E<:`1F
Bb/0EDXZ05I9:@1FAbP0ETDW05M49P1F@bD0DT8X05E6:@1MBR`0ITd^06a?;@1`Cb`0LDhX079<9`1j
EBT0OEP/081N<024I3D0QVPf08MY=`24JC@0PfPc07a_>`1jK3/0NFTh07QV>01hHcH0N6<h0P1iHSP0
1@1fFS<0METb079F;`1_Db`0KE4Z00<0K50Y00H0KEHZ06mH;01bG2d0M5h_07EO;P1fH2l207EO;@0X
06YL=`1ZFSH0JUPb06aF;`1^EBd0LeH^07IF;`1hEbh0QEPa08QK<P2;GSD0RUdc08QL;`29GBh0SV8a
099V=@2GKC40VG0b09ed=02QN3H0Y7`f0:In=P2VOc80Yh0c0:ao?02`QD40]X]70;F=B02`RD@0ZhI0
0:R6?`2YQd00ZH9;0:N2B`2VPd/0XX9909f0AP2HOT<0Tg/o08mi?@80VgLk00L0VGDi09Ib>02DKcP0
UG0k09Mb?P2JMD40WGM60080WW/k00P0Wg/m09mk?`2MNCl0VgHo09Qc?02GLSd0Sflb09Ad=`80VGTl
00D0U7@g08m_<P2>KS40SVha099^=00309=_=@80U70f0P2ELCL00`2JLSD0W7@g0:1h>`020:9j?@03
0:1h>`2MMCP0Vg<f00<0VWPk00<0VGLj09Qf>@2HMST00P2GMCP0102EM3l0U7<n09=b?@2BLC`2095`
>`80TW4l00P0Tg8o099a?P2@Kc`0SVhk08e]>P2<KSX0SFlk08i`?080T7<g0P2AM3P04P2@LcL0SW4e
08a_<`2:KC40RV/o08QY?@25ISX0PV<g085R=P23I3P0QFHj08IW>`23Hc80PV8a085Q<P1oGS40OUdb
07iM=080Oedg00<0P64c07iO<@1mGS000P1kG2h05@1lGBl0OEh`07iO<@1mF2h0OEX`07mL<P20Gc@0
Of0d07eP=01kH3<0NUlb07aO=@1kGS@0NUda07YN;P1kGbd0OF8[07mU;020IRd0Q6Hb08=U<@03089T
<00908AV<P26J3@0QfTe08UY>028J3L0QfLf08IV=@24I3<0PV8a0080PF4`00@0N60`07MO;`1gGbl0
Mel_0P1fGRh207EM;@80O5da00l0Nehb07UN<@1fGS00LU`]06iI:P1]F2T0Jed/06aL:`1[FR`0JeP]
06]E;01ZDR`0JU0[06Y@;@1OBB800`1PBR<02`1RC2D0HddV06I@:@1WDBX0JE</06iF:P1`EBX0LEH[
079E:`1eEB`0MeH]0080NEH^00H0NE`b07UL<01iG300NEd^07UM;@1jGR`207YO:PL0O60^00T0OF4_
07YP;`1hHBl0NF4a07MQ<P1eH3<0LEhc06eL<01[FRl00P1]EbP206aF9`0706]E9P1ZE2D0JE<T06UC
901TCRL0HD/T05i88@0205a67`0405i88@1RC2D0I4hW05Y890<0FdTU0P1LBRH205e;9`<0EdXW0`1F
BBH205E89@80FD/X0P1HBRL0301GBBH0ETPU05E7901EAb@0D48O0553801BA240E4HS05I89@1HBRL0
FD/X05Y<:@80FddX0P1JC2L305U;9P0905Q:9@1JARD0FDHU05U69@1FAR@0EDLT05A7901BB2@0DDLS
0080E3lP00@0DSlO04lo7P1>?Qd0C3dL0P1:?A/204Pm7@0F04Pm7`18?B40Ac/Q04Di8@13=al0@SHP
03Tg7P0h=Ql0=S@M03<a700a;Q/0;R/J02dZ6`0/:AX0:BLK02HV700U9A/08R<K020S700L8A/06R0L
01TO6`806Q`I0P0I6aP401PJ5`P05QPG2@0E5aH8018H610051DG2P0E5QP201@E5`804a@F0P0B4aDP
01@E5a005AHH200E5aHB01HH5`<05aTH0`0H6QT201LG5@8061PF0`0I6AL901XJ60P061PF500J6QP3
01/K6@X071`J0P0M71L0100N7AP07ahI020O6P0Q81/2028Q70<08B4I0P0R8QX302<S6`808b<I0P0T
91X202DU6`809RHL0`0[91`202`U7@<0;BHN0`0a9ad3038X7P80<bTO00<0<BDI038V6P0b9QX00P0c
9a/203@X700:03DY7@0e:1P0=bXJ03T/700j;Ad0>bhN03X]7@0i;1`0>2/K03H]70<0=B`K0P0d:aX2
03<Z6@0;03`Z7P0k:Ad0>bTK03/Z6P0m;1`0?bhL048a7@14<al0?RdM03l^7P10;al00P11<2000`10
;al0?RdM03d/700203/^6`80?2lL0`0m<1d00`0n<Ah0@BhM044^7@02048_7P<0@c0O00@0A34P04Td
7`18<ah0Ac8M0P16<A`00`17<Qd0B3<N04Td7`0204Lb7@0404Pc7P19=1l0BSDP04/f8@80C3LR00`0
BcTQ04`h801:=Qh0BcDN04dd7P1@=B00DcLR05@h8`1C?BD0DS`T04li8@1==al304`f7P80CCLO0`1<
>20304/g7`80BSHN0P1A=B002@1?=1l0CC@N04Xd7@19=Ad0B3@L04Hd7014<Q`0AC<M04Hd7P0204Le
7`0;04Hd7P14<Q`0@c4K04Tc7P18<ah0AC<M04@d7@10=1`0?cDL03`e6`0k=A/0200o;Q`0100i<240
>2lP03P_800h;b0203L^7`80=RdN0P0f<A/03P0h<Q`0?34M03ha7P12<Al0A34P04Db8@14<al0AC@P
04Le7`1:=Qh0CCLO050h7P1A>Al0DSPM101<>1l404/g7P80CSPP00L0DCTQ05<i8P1D>280EcPS05Pi
901I>B@0FS/W0080FS/V00<0FcdU05/m8`1K?B400P1L?b40101L?R80GClS05do8`1N@2@205m19@80
H48V00h0H44T06529@1R@b@0I4HT06I89P1WBBD0JD/U06Y<9P1UCBL0IT`W06Q<9`1YBbL0K4XW06e9
9`80KdHV0P1/BbP00`1]C2T0KTdZ06m>:`02071?;003075@;@1_CR/0Kdh[00@0Kdh[0P1`Cb`01P1^
D2`0KDl[06a>:P1[CBT0JD/W06Q:9P80ITPT00D0HdDQ0694801O@Al0GChO05/l7`0205/l800605`l
8`1J@2L0FClV05Lo9@1F?R@0DSdR0P1@?2400`1=?200C3/O04Ti800304Ph7`80AcLN0P16=Qd00`16
=200AcDQ04Le8@0204Pf8P80BCLS00<0BSPT04Le7@17=Ad01P17=Ad0201==al0CSTN054i7`1D>Ql0
Ec`O05/n801M@200GSlP0P1R?R@206<o9@0806A09P1U@BL0ID4W06I2:01P@B80HT<T06A59P1UARL2
06I7:00:06E69`1TABH0I4`X06M=:P1YCb`0KE0^06mA;`1`Cbh0Kd`/06i;:`80Le8_00H0M5<`07=B
;`1aD2d0Kdh[06a;:01ZBBH506Q9:P<0IdPY00P0Gd4O06538@1TAR@0ITPV06E79@1RA280Gd4O05`n
7080GT0T0P1L?R801`1K?B40G3hR05do8`1M?b<0FT4S05]2901L@bD00P1MA2H00`1L@bD0FT4S05U0
8P0805i0900605]1:01J@2L0EShT05@l8P1A?240DCdR0P1@?b<805Pn8`80F44R00@0FT4S05a1901O
@BD0H44U0P1S@BH0201O?B80H3hS05m0901O@BD0GD8U05]2901I@R<0F44R0P1I@R<01P1J@b@0Fd@U
05a59P1MARL0GTLX05m8:@<0Gd8R0P1P@b<4065490@0HDLV101RB2L206Y9:P0306]::@1/BbP0KDdW
0080KThW00<0KdlV06a;:01/BbP01P1/BbP806e=9P0606U89@1ZBBH0JdXW06e<:@1^CBX0L4l/0P1a
D2d0201aCBT0LThZ07A@;01eDBd0MU8^07EA;@1dD2`0Ldl[201bCRX0201fDbd0Le0Z071=9`1aCRP0
ME8/07IC;@1cD2X0L4dW0`1bDR/3075A:P80L50Y0`1dD2h[ooooo`00:_ooool01@2OMD<0WWA209ec
@@2LLT00Vg4o0080W7902@2MLd400`2KKch0WG5009ib@@030:1d@`0309mc@P2NLT40XGI30080XGI3
0`2PMD8209md@@80WWA20`2OMD<30:1fA00609]g@`2LMd<0W7M309if@`2OMD<0X7A30P2RM4<30:9g
A080XgQ50`2TNDH0202TNTP0XgU70:9hAP2QMdD0X7I409me@`2NM480WG=10P2QMdD30:1fA0<0WgE3
00<0Ug8n09Ud@02KMT800`2MN4@0202KMT80V7<o09Mb?P2IKT<0V6e209M/@@2FJd00UFXo0P2DJCh0
3`2CJ3d0TF@j095V>`2AIS/0T6Lk08eW>P29I3L0QF<e08=Q<`26H3T0QElh08AN=`23GCH0PU`e081J
<`0207mI<P0407YG<@1iES00Me@^07EB;080M54[0P1eDR`0201hDC00ME4_07A@;P1aCb`0Kdh[06]=
:@1YCBP0J4`W0P1WBBD00`1WBBL0IdPY06M8:`0206M8;00306M7;P1VBBT0ITTY00<0IDPX0`1TAbL0
201XBB`0JDX]06Y;;01[CB/0KDl]06i@;01_DB/0L58/101eDRX0101fDb/0N5D]07UF;P1kF302081J
=@04085K=023GS@0Q5lc08IQ=080Qf<c202<IST3095V>`<0T6Dj0P2?I3T02`2@JSd0SFLj08]U>02<
IST0T6Xm095[?P2?JC`0RfDh08mT=`2@ICP0TFHi00<0TfPk00D0TVLj095V>@2AIST0TVLj09=X>`02
09EZ?@0409=X>`2BIcX0TFHi09=Y=`<0U6Xh0P2EJcT209I/>P80UFXm00<0U6Tl09=X>`2CJ3/00`2C
J3/209A[?@04099/?@2@K3`0T6`l08e[>`80S6`k2@2DJC`309M/?`80V6e00`2IKT400`2DKc/0UG0l
09Mb?P0209Qc?`0609Mb?P2EL3`0U6lk09Ye@@2HLcl0Ug8n0`2EL3`:09Mb?P0809Qc?P2EL3/0Tfhi
09A_>P2GLSd0V7<n09Ia?02CKST209Q^?00409M]>`2FK3X0UF/i09E[>@80U6Xh00D0TF/l091Z>`2@
JS/0SfTj08iX>@0208eW>00308aV=`2=IcP0SFLh00H0SFLh0P2<ISL308eW>0<0SVPi102;JCT408aZ
>P0308iZ>P2?Jc/0T6`l0080TFdm00<0T6`l08m[>`2>JSX00`2@JS/2095[?0<0TV`m202@K3`0102:
J3X0RFLi08UW>@29IcT208QV>080QfDg0200PF<_089T<024IS@0Q6Df08=T=P21HSH0OEhb07]K<P1e
F2h0LeL_075E;@1]E2`0J50Z069<9`1MBBH0FTHS05918`1?@2<0CChQ04Tk8015>Al0@cTP044i8P12
>R<0?SPR03`f800h<al0<c0M030_7@0];Qh0;2dM02/]7`80:2XO0P0W:Ah402HX7@0402DW700U9R00
8b@N028S7@<0824K00<08B8L028S7@0O8Q/00P0O8Q/2020S70<08B@M00<08R<K02<T700T9Ad00P0U
9Qh00`0T9Ad08b@L028S6`0201lR6`807R4J0P0M81T201`O60P071hK0P0J7aT02P0M81T0824I024S
600S8aL09R@H02LU600Y9AT0:RHJ02`X700^:Qh4030/800C03La6`0h<Q`0=c8N03Db7`0b<Al0;BhN
02X[6`0V:1X09BHN02HV700W9ad0:RPL02hZ7P0b;1h0=RlO03Pa8@0g<Ql0=S4N03D`7@0203@_7003
03D`7@0f<Ah0=c8O00<0=2lL0P0c;Q/3038]6P80;2`R00l0:b/Q02XZ800X:1h09bLM02HV700U9A/0
9RHL02LW7@0Y:Al0:RXP02/[8@0Z:R00:BTO02PX7P0W:2000P0V9al00`0U9Qh092DM02<T7002028S
6`80824K0P0O81X201hO6@@07AhH0P0N7aT201lP6P80824K01L07b0H020Q6@0Q8QX08B8J028S6`0T
9Ad09RLO02TZ8P0[7QD0=2HI04Dd8P1GARX0KETd081Y?@2?MD80UGa409Qi@`2?LCl0PFHi079L<`1S
Dc40E4T[04@m8`0203Xd7P0402d`9`0/;bH0:B`S02P[8P<09bXQ00<0:2/R02DX8@0U:2400P0U:244
02HY8P809bPP00T0:2TQ02X[8`0[;2@0;2dU02d^9P0^;bL0;BdS02h^900`<2H00`0a<BL2030`9P0=
02d_8P0_;b<0<34S03@b8`0i=RD0?STV04<l:P15?R/0BT0W04i4:`1@ARd0CT@[04To9P0204Hl8`04
04Pn9@13?RP0@C`V03lj9080?STS00L0@3/U04<n:015@2X0CT<W04m4:01AARX0DdP/00<0E4T]02H0
DdP/05M>;@1GC2`0Ed`/05Q;:`1GB2T0EdHX05U6:01HABL0E4<W05U6:01RBb`0JE4_071B;P1dE2d0
ME8Z07MB:01oFRd0Oed_08=Q<`25ICH0QFHg08=W=`20ISD0OfDd07U[?01jJC/0NFPj07UW>@1jICP0
O6Di07eU>@1nISX0O60h07YN=P1gFc<0M5P`079F;P<0LED]00@0KUPY06mI:P1aFb`0Led^0P1dGRd0
5`1cGB`0LU`[06YH<P1ZF300KEL`06mF;P1cEbl0N5P_07aI;`1mFS00Rehd08mS=P2CIcX0TfLh091T
<`2>Hc00T6D`099W<P2LLc<0WWDe0:5h=P2TO3L0Ygli0080Z80h00T0Z84f0:Yn?@2`Q4<0]Ha:0;J?
C02aS4P0ZHI20:J3?`2TPch00P2UP4T01P2SP4P0X81709amA02HNd40U7Xo099h?@80V7@f00L0Ug<g
09Ea=@2ELCL0Ug8k09Ye@02NNDD0XGa80080YX=300h0YX940:F1A@2TP4H0XWe60:1kA02NND@0UW@g
09Yh>`2NO3l0WG/n09Me>02BL3<0TFlb099`<`80Vfhe0P2LKcH209e`=`80WW4h00P0WGDh09if>@2Q
NC`0Xg/n0:9j?@2QNC`0WWHi09ad=`80VWPk0`2IMcX309Qf>@<0U7<m00l0Tg8l099a>`2@KcT0SVdg
08e/=P2AL3/0T6lj08i]>02=K3L0S6/f08e/=`2=KSP0SVli08a^>P2=Kc/00P2>L3`0102=Kc/0Rfdi
08U[=`28JSH208IW>080QFHg1024ICH2085P;@09089P<023HC<0Pf4d089O=@21GS@0P5de07iO<01m
GRl0Ne`]00<0NU//0P1kG2d01P1oFS00OU/a07mL<P1oGS<0OUlc07aO<`80NUlb00T0OF0f07eP=01l
Gc<0O60a07aP<01mHBl0OV<^07mT;`21Hc400P20HS002`21Hc40PV@b08AV=026J3H0QfTg08U[>@28
JSP0QfTg08IX=P25IcD0PfDc0080PV@b0P1kHC0307YP;`<0NEl^0140O5da07eN<P1kGS80NUlb07IN
<01cGBh0L5//06iI:P1YFbX0Je/Z06YI:`1ZEb`0JeD/06]C;@1[DB`0Je4^06A>9`02069<9@0<065;
901PBR<0H4XS069<9@1TCRL0IU0Y06]D:01/E2P0KUHZ075F:`1cER`0MED/0P1gERd01P1gFS00MeX^
07QK;`1hG2d0NEd]07UM:`80NUlZ0P1jGR`0101kGbd0O60^07eQ;`1mHBl207iR<00H07]O;@1kHBh0
Nf4`07UQ<@1gHC80Leha06mL<@1]FRl0LE//071J:`1^F2T0K5HW06YD9@1YDb@0J58S06MA8P1VD2T0
I4hW065;901NB240GDLP05i88@1PBR<0HD/T0P1KBB<205a:90<0GD/U00<0GT`V05U;9P1IBbH00P1H
BRD305M9900305I88`1IBBD0F4PT0080F4PT101GAb<205I68P0305M78`1HB2@0FDTU0080FTXV00<0
Fd/W05i?:01NCbP00P1MCRL305a=9P0905]<9@1OBbP0Gd/X05i<:01KBbL0FTXV05U;9P1HC2H0Ed/U
0080Ed8S00@0ED8R05=38P1B@R40D44P0P1>@Al204To700F04Pm7@17?1h0Ac`P04Pl8P19?BD0BShV
03hj8@0m>B00>cHP03Td800f<Ad0=2lL03<]7@0b;1`0:RPK02TW6`0V9QX08bDJ024R6P0N8AX06b0J
01XO6@<06Q`I0P0I6aP301PJ5`P05aTH2@0E5aH8018H610051DG2P0E5QP201@E5`804a@F0P0B4aDP
01@E5a005AHH200E5aHB01HH5`<05aTH0`0H6QT301PH5P806ATG2`0J6QP801TI5a@06QXH0`0K6aT:
01`L6P807A`G00@07QdH01lN6@0P7aX08B0K0P0R8A`3024Q6@808R8J0`0S8a/202<S6@8092@J0P0U
9A/202HV70<0:b@L0P0/9Ad302dV7P<0<BLM0`0b:1h203<Y7`@0<bLK0P0d:1`203DY7@0803DX600g
:QX0>B`L03X]7@0k;Qh0>RdM03T/700h:a/303P/7080=b/K0`0f:QX02`0l:Qh0>bTM03/Y6`0k:QX0
?2/K03l^7011<1`0@c8N03d/700n;Ad0?bhN0080@2lO00<0?bhN03h]7@0n;Ad00`0l;a`203d`7@<0
?S4N0`0o;1/2040]70<0@BhM00<0BC@O04Pc7P17<Qd00`17<Qd01`18<ah0BC@O04Ha7016<A`0Ac8M
04Pc7P19=1l00P1:=B003@1;=R40BCLO04Xf7P1:=Qh0BS@M04dd7P1?=1l0DCDP058f8@1C>b<0DSXR
050h801?=al0101>=Qh00`1?=al0CCTQ04di8@0204`h80<0BcLO00X0BSHN058f8@1A=B00D3DP04he
7`1;=Ah0BCDM04Pd7016=1`0AS@N0`17=Al01016=1h0AC<M04<a6`12<1X204Pc7P0404Hd7P14=1d0
@c@M044e7@80?cDL2010;ad0100l<200>blO03/_7`0k;al203X^7P80>BdM0P0i<A`01P0l<Ad0?S4N
044b7`12<Al0@c8P04@a8080A3<O00H0AS@N04Xf7P1<=Qh0D3PN054i7`1B>1d204hj8@80CCTP00d0
C3PO04/g7P1:=Qd0BSHM04dg7`1>>200D3PP05<i8P1E>B<0F3TT05Tj9@1K>bH0FS/W0080FS/V00<0
FcdU05/m8`1K?B400P1L?b401P1K?B40G3hR05`n8P1M?b<0GT0T05m19@80H48V00d0H44T06529@1R
@b@0I4HT06I89P1XBRH0JD/U06Y<9P1[CbX0JThY06]=:@1/BbP0K4XW0080K4PV00L0KDHU06a;:01]
C2T0KD`Y06i=:P1_CR/0L4l/0080LE0]00<0Kdh[06i=:P1^CBX01@1^CBX206i@;00C06e?:`1[CBT0
JT`X06U;9`1XBRH0IdTU0694801Q@al0Gd4O05ho801M?R40GSlS05m0901P@2L0G44V05]09@1I?b@0
EclS05<n8@02054n8003050m7`1=?1h0BcTQ00<0BSPP0P19=al204Pf7P80AcDO0P18=R0404Tg8@P0
AcDM00T0CCLP04hh801A>B40E3XQ05Ll8@1J?200G3lQ05dn8@1P?R<00P1Q?b@00`1R@2D0Hd4V06A2
9`0206E3:00306=49@1TABH0IDHW0080IdPY00/0ITLX06E69`1TABH0HDTU06E;:01YCb`0Ke8`079D
<P1bDC00LDh^06m<;00207ED<@0607IE<P1eE340M5<`079A;P1_CR/0KTdZ0P1ZC2X206U;:@<0J4XX
00T0IdTW06=58`1UAbD0ITPV06M99`1UAbD0HT@R05m17`1M?ad00P1L?R801P1N@2@0Gd4U05m19@1O
@BD0GT0T05do8`80FD0R101K@R@00`1J@B<0FD0R05do8`0705do8`0505]09@1J?b@0F3hS05Dm8@1B
?B000P1A?R000`1@?b40F3hS05Pn8`0605Pn8`80FD8S00@0FT4S05]08`1M?b<0GSlS101P?R<0101O
@2@0Gd4U05e29@1K@R@205U28`0605Y18`1K@R@0Fd8T05a39@1MA2H0GTDW0P1OARP205m28P80H4<S
101QA2@00`1RABD0HD@T0654900206959@80HdHV0P1TAbL206]::`0306a;:P1]C2T0KThX0080KdlX
00<0L50W06m>:`1_CR/01P1_CR/806i>9`80JdXW00T0K4/X06i=:P1_CR/0L4l/075@;@1bDBh0Le0Z
07AA:`1fDbd00`1hEBl00`1gE2h0MU<]07EB;00707EB;00807IC;@1cD2X0L4dW075>:01eDR`0Me@^
07EB;01bCbT307AD;@80Le</0`1bDR/307A@;R_ooooo000Zooooo`0309id@P2MLd40WG=100<0W790
2P2MLd40202LL3l0WG5009mc@P2PM4<0XGE40:1d@`2OLd80WW910`2QMT<30:1e@P80WgA11P2OMD<2
0:1fA00609]g@`2LMd<0W7M309if@`2OMD<0X7A30P2RM4<0102RMd@0XgQ50:=hA@2SN4D20:AiAP80
YGY70P2TNTP0102SNDL0XGM50:1fA02NM48209ec@@80XGM51P2PMT@0102FLCd0V7<o09ag@`2ONTH2
09iiA@0309]f@P2GLSh0U6lk0080Ufa10P2FJd0209EZ?`80U6Tn00h0TF@j091U>P2AIS/0T6Lk08aV
>@29I3L0Q68d08=Q<`26H3T0QElh08AN=`23GCH0PU`e081J<`80OeTb00D0NULa07UF<01hEBl0MU<]
07EB;00207AA:`0907=@:P1fE340ME<`07AB;`1aD2d0Kdh[06e<:@1ZC2P0JD/W0080J4XV00H0IdTW
06M8:@1WB2/0IdP/06I7:`1VARd606E8:080I4LW00T0J4T/06U:;@1ZBb`0Jdd[06e?;@1^D2`0Ke4[
071B;01fDb/00P1eDRX207IC:`0307MD;01hEBd0N5D]0080P5Xe00@0PE/d08=N=024Gc<0QV4d0P27
Hc<208]U>0@0S6Hi0P2=IcX2095V>`H0T6Dj00P0T6Xk08eW>02;ICH0S6Hg091Z>`2BK3d0T6Xk08aV
=`80T6Dh00<0TFHi099W>P2BIcX00`2BIcX00`2AIST0TVLj09=X>`0209EZ?@0309=X>`2BIcX0TFHi
0080TfTi0`2DJSX309E[>`0609I[?P2EJSd0TfPk099W>P2AIST0TVLj0P2CJ3/209AZ>P0609=[>P2A
JcX0T6`j091/>P2>KCX0SFdj2@2DJC`0102GK3l0V6e009Q]@02HKD0209U^@@80VVm200<0Tfhj09A_
>`2EL3`00P2GLSh02`2FLCd0UG0l09A_>`2HLcl0Ug8n09Ia?@2EL3`0U6lk09E`?02GLSh0V7<o00P0
UW4m00<0Ug8n09Ia?@2EL3`00`2EL3`0102DKc/0Tfhj09M]>`2GKC/209I/>P80UF/i0P2DJSP2091Z
>`80SfTj0P2>J3T208eW>0<0SVPi102=IcP308aV=`<0SFLh0`2>J3T408eY>@@0SVXj00<0SFTi08iZ
>P2@K3`00P2AKCd00`2@K3`0SVXj08eY>@03091Z>`80TF/l0`2BK3d8095]?@<0RFLi0P28ISP308MU
=`0M081R;P21Hbl0PV@b08=T=@22HcD0P64e07eN<P1lG3<0M5P`071G;P1^EBd0JU8/06E?:P1OBbP0
FdPW05U69@1A@280Cd0S04`m8018>Ql0A3PN048h7`10>240@CTR03hg900l=B80>3<P03<`7`0`;Ql0
0P0];R00100/;R409bTN02LY7P0W:Ah302HX7@<09BLL00P092DO02<T7P0Q8Q`0824K01lP6P0P8A/0
8B8L028S7@<07b8K0P0P8a`3024T7@808b@L0`0U9Qh00`0T9Ad08R<K024R6P0201lR6`807R4J0P0M
81T201`O60P071hK02<06QlI01/P6P0N8AX0824I024S600T91P09bDI02LU600Y9QL0:bPI02h[700a
;Ql0<RlP034^7`0`;Ah0;R/L03Xc800i<Ql0=c8O03<`7`0_;Ah0:R/M02PY6`0U9aX09RLO02LW7@0X
:1h0;2XN02l[7`0c;Al0=RlO03L`800h<b00=S4N03@_7002038]6P0303@_700f<Ah0>3<P0080=2hN
0P0c;Ad2038/7080<B/K0P0[:b40100Z:R00:BTO02PX7P0W9ad202HV700802DU6`0W9ad0:BTO02XZ
800[:b40:RXP02TY7`0X:1h202HW7`0302DV7P0T9Ad08b@L00808R<K00<08B8J020Q6`0P8A/00P0O
81X201hO6@@07AhH0P0N7aT201lP6P80824K01L07b8I024R6P0R8a/08B4G020P5P0T8QH0:BLK02d[
7P0m;1X0B3LS05]:<01`Fc`0PF]408YcA`2=MT@0SgE2099i@`25KS`0M5lb061@;01AARX0A3`Y03Pb
900202h/800302P[900W:R<09RTR00809BPQ00<09RTR02LZ8`0Y;2D0100T9b0402DX8@0602LX800X
:B40:BXR02X[8`0[;2@0;BhV0P0^;bL0100];B<0;RhT02h^900_;bD4030`9P0:02d_8@0_<280<S<S
03Pg9@0m>RL0@chZ04M0;@19@bd0BClV04i4:`80DDL^0180C48Y04Lm9016?2<0AcdT048l9P10>R@0
?CLQ03/e7`0m=b40@3XT04Do:@19@bd0Cd@X0556:P1BAb/0DdP/05A9;@1CB2`20556:P0605A;:P1E
BRX0E4TY05I9:@1FAbP0EdHX0P1HABL04@1KA2D0H4LX06M=;01_Dbh0MEP`07QI;@1iF2/0NUPZ089P
<P22HS<0Q6@e08AU=`22ISL0Of@g07]S=@1jHSH0MF@h0080MV<h00X0N6<f07YS=`1kHcD0OV<f07mT
=@1mHSL0Nf0e07QM<P1eFRl0M5T^0P1cF2d07P1dFBh0L5XX075K:@1bG2/0Led/07=M;P1bG2d0L5T]
06mH;01YER`0JeD/06mF;@1cF2d0NEX^07iL;`23GS40QElb08iR<@2DJ3L0VFhk09]`>`2HKCH0UV`b
09M]<`2IKc<0XgXh0:Ak>@2VOST0Z80k0:V1?080ZH4k00T0Z80j0:Mn?P2^QDD0]Hi=0;J@C`2_S4X0
Z8M40:>2?`2PPCh00P2OO4@01P2NNd<0W7U109Ui@02GMch0UGDl09Ad>`80Ug@d0P2FLS@01@2HM3P0
VWHl09ii@P2RODP0Y7m:0080ZhQ800h0ZXI80:V5B@2XQ4X0YX5:0:F0B@2TOdX0VWHj09ij?P2QOD40
Wg/o09Ue>@2ELCD0U70d09Ea=@80XVlf0P2SL3L30:Aa>0040:Eb>@2NN3X0WgTk0:1j?080XG/m00<0
WgTk09eg>@2LMSP01P2IMcX209Qf>@0K09=c>P2DM3/0UGDl09Ee?02CLcX0T70g08a/<`29JC00Sg0i
08i_>02=K3H0S6/e08i[=@2?K3H0TF`g099]>02:JC`0RfXm08a[?P2=K3l0S6/n08YY?029J3/0QfHi
08AT<@26IS<0R6Pe0080RFTf00/0QfLd08EU<P24I340PEhX08=P:P26HRh0R6@b08QT=027HSD0QF0c
08=N<P0207iN;@0407eM;01lG2/0Ne/Z07]K:P80NUXY00H0P5/a07iK<@1oG380OUdb07iO<`1kGS82
07YO<P80OV4e00@0OF0d07eQ<P1mHC80OF4b0P1mHC40201mGRl0OUl`07mP<@20HC80PV<d08AU=P26
IcP0QfPi0P27JcT01P26JSP0QFTg08AX=P23IcD0PVHd085U<`80OF<`0P1lHRl307]Q;P0B07YP;@1l
GBl0OEh`07aP<@1kH340N60`07AN;@1aGB/0L5`Z06QJ:@1ZFRT0JEPZ06UF:`1[EB`0Je<]06]A;01[
DBh0J58[0P1VD2T05P1RC2D0GdTR05i88@1OBB80HT`U06==9P1XDBD0JE8V06aD:01^ERX0LEH[07=F
;01eEB`0M5@[07II;`1fFBd0MeX^07MK;01hG2`0NEd[07UN:@1jGbX207UM:`0D07YN;01lH2h0OF4_
07iR<01oHc40P6@b07aQ;01mHBl0O68_07aR<@1iHC40MEl`079M<01`Fbh0MEl`07=M;P1`FR/0KELX
06YD9@1XDR<206MA8P0406QB:`1VD2T0HddV061:8`80GTPQ0P1OBB8205a:8P80GD/S101NC2@305Y;
9080FDXS0`1HBB8805Y88PD0GD/U0`1NC2H0101SDBT0HU0X069@:01RD2P2065?9`80H4hV0P1SCBP0
1P1PC2L0GT`V05a=9P1KC2D0FD/T05Q<9080FTHU00@0FDHU05I6901FAR@0E4HS0P1BAB80601AA240
Cd8P04e07P1:?Ad0BS`O04/m8P1=?bD0Cd4W048l8P11>b40?cTQ03dg8@0k=240>C8O03Pa7`0g<200
;BTM02`X700Y9a/09BDI028T6@0P8AT07B0I01XO60806adJ0P0J71T201TK608061XG200G6AP901DG
5PP04QPH400D5AL:01DF608051DG0P0C51H2018C5B0051DG400E5QP801DG5Q805QPG0`0G6AP301PJ
6@8061PF0`0I6AL301XJ60P06a/I200I6AL901/K6@/06QXH0`0K6aT:01`L6P807A`G00@07QdH01lN
6@0P7aX08B0K0P0R8A`3024Q6@808R8J0`0S8a/202DR6@809R<J0P0W91/202PU70<0:b@L0P0/9Ad3
02dV7P<0<BLM0`0b:1h203<Y7`@0=2PL100e:Ad0200e:1P0=bXJ03T/700j;Ad0>bhN03X]7@0i;1`0
>2/K0`0i;1`303P[6`80=bXJ00P0?2XN03/Y7@0k:A/0>bXJ03`[6`0n;A/0@2lK048a7@80?B`L00<0
?RdM03l^7P0o;Qh00`0o;Qh203h_70<0?c0M0`10<Ah3044^7@80@RlN0`13<1l00`19=1l0B3<N04Pc
7P0404Pc7P0304Td7`16<A`0AS4L0080Ac8M00D0B3<N04Td7`19=1l0BC@O04Le7@0204Te7@0804/e
7P1==1h0Cc@O050d7`1A=B00DcTR058h8@1A=b03050f7`<0CcDN0`1>>24204dg80<0C3HO0P1B=R40
0`1@=B00CSDO04/e7P0204Te7@0904Hd7018=R00B3HP04Le7`16=1h0AC<M04<a6`12<1X0@BlI00@0
AS@N1015=Ah8044`7080?S4P0`0m<1l303`_7P80?C0M0P10<Ah03@11<Ql0@S4O04<b8013<R00@c8N
04@c7`16=1h0BCDM04`f7P1?=ad0D3PN058h7@1A>b<00P1@>R801@1?>B40CSPP04dg7`1<=Qh0BcDM
0080CCLO00L0DCTQ05<i8P1F>R@0FCXU05Xk9P1L?2L0FS/W0080FS/V00<0FcdU05/m8`1K?B400P1L
?b40201J?200FcdQ05`n8P1M?b<0GT0T05m19@1P@RH0HD<W0P1Q@RD0101SA2D0IDLU06I89P1XBRH2
06Y<9P0606i@;01]Cb/0KTdZ06e<:@1/BbP0JdTV0P1ZB2D206e<:@0406i=:P1_CR/0Kdh[071?;080
LE0]0`1_CR/406i=:P0706e<:@1^D2`0KU0/06e?:`1/CRX0JddY06Y<:00206U;9`0=0694801Q@al0
H48P05m08@1O@2<0HD8V06939`1S@bX0Gd4U05i0901K@2<0FD0R05M08@0205<n7`04058m7P1A?Qh0
CSXR04hj8P<0CCTQ0`1<>20204Pf7PH0BCLO2018=Qh03P1==b00CSPQ054i8@1C>B80ESXR05Xl8P1K
?B40G3dQ05dn8P1N?b<0Gd0T06119@1Q@RH0Hd@X0P1TABT00`1UARL0ITLX06M8:@0206Q9:P0;06M8
:@1UARL0I4DV05m78`1TBRL0JU0]071C<@1cEC<0M5<b079?;`1_C2`00P1fEC801P1gES<0N5Ld07MF
<`1eE340Le8_079A;P80K4hZ00@0JddY06Y<:01ZC2P0JD/W0P1XBRH02`1WBBL0J4XX06Q::01XBRP0
ITPV06=58`1P@R00GT0N05/m8@1M?b<0Gd4U0080HT@X00@0HD<W05m19@1M?b<0F3lQ0P1I@28505Y1
8`P0G3hR0P1M?b<00`1J?b80F3lQ05Ho800205<n7`03058o7`1I?b@0FClT00H0FClT00P0FT<T05U2
8`1J@B<0Fd0S05`n8P1M?R80GcdR05hl8@80HClT00@0Gd0T05m19@1M@RD0Fd8T0P1J@b@205a19080
GD8U00@0GT<V05m49`1OA2L0Gd@W0`1P@b<3065490<0HTDU00D0H4<S0654901QA2@0HTDU06=69P02
06A79`0906E8:01]BR`0KDX/06i;:`1_CBX0L4hY075?:@1bD2X0LU4X00P0LE0]201_CbP206e<:@0;
06i=:P1_CR/0L4l/075@;@1bDBh0Le8_07EB:P1fDb/0N5D]07YG;`1kF3000P1jEbl00`1iERh0N5D]
07QE;@0607QE;@0807MD;P1cD2X0L4dW075>:01eDR`0N5D_07MD;P1eDR`207IF;`80MED^0`1dE2d0
101cDb`0M50^07A@;P1dD2h[ooooo`00:_ooool209ab@0h0WG=100<0W70o09ea@02OLd800`2QMD@0
0`2PM4<0Wg=20:5f@`020:5f@`<0X7E20P2OM4420:1fA0H0WgE300H0VgM309ag@`2LMd<0WWI309me
@`2PM4<20:9d@`<0XWM40P2SN4D30:AiAP080:AjB02SNDL0XWQ60:5gA@2PMT@0WgE309id@P2MLd42
0:1fA0H0XGM500@0Ug8n09Ud@02MN4@0WgY60P2NNDD00`2KMT80UW4m09=^>P0309I[@080UFXo0`2D
JCh03P2@HcT0T6Dj091U>P2?ISX0S6Hi08QS=P24HS@0PV0b08IP>@25GcP0Q5hg08=M=P22G3D0P5Xc
0P1oFC805@1jEc40NEH`07UF<01hEBl0MU<]07AA:`1cD2X0LTlY079D<01aDbl0LU4^071?;01_CR/0
KT`Y06e;:01/BRL0JD/W06Q:9P1XBRP0IdPY06M8:`0206I7:`0306E5;01TAbL0I4LW00H0IDPX00P0
J4T/06U:;@1ZBb`0Jdd[06e?;@1^D2`0Ke4[071B;080MU<[00<0Me@/07QE;@1hEBd00`1hEBd2081J
=@04085K=023GS@0Q5lc08IQ=080Qf<c00<0RV@g08]U>02;ICP00P2<IST208eW>P0308iX>`2@ICX0
T6Dj00@0T6Dj0P2AIS/0202@JST0SFLf08]U=02=IcH0TF/j09=]?02AJcX0SVPg1@2AIST01P2BIcX0
TfPk09=X>`2AIST0TVLj09=X>`80UFXm00<0TfPk099W>P2AIST00`2CJ3/309AY?080UFXm00<0UV/n
09AY?02BIcX00P2@ICP00`2AIST0TVLj09AY?00209EY>00309AZ>02CJcP0TF`h0080T6`h00<0SVdh
09AY?02DJC`01`2DJC`309M/?`80V6e00`2IKT400`2AK3P0TVdi09A_>`0309Ia?@0509E`?02DKc/0
Ug8n09Ia?@2EL3`00P2DKc/00`2EL3`0Ug8n09Qc?`0809Ia?@0509E_?P2FL3l0UW0o09E_?P2DKSd0
0P2CKC`00`2DKSd0UV`j09I/>P0409E[>@80U6Xh102?JCX408iX>@80SfTj0P2>J3T00`2=IcP0S6Hg
08aV=`0308aV=`<0SFLh0`2>J3T208aX>080SFTi0P2>JSX208m[>`0308eY>@2>JSX0Sf/k0080T6`l
00<0Sf/k08iZ>P2=JCT00`2@JS/2095[?0<0TV`m202@K3`208UW>@80R6Hh0P27ICL208IT=P80PF<_
01/0PF<a085R<`20HC<0OUlc07aM<@1kFc80L5L_06eF;@1ZDR`0IDlZ05m;:01KB2L0EdLV05I69@1@
?b40CSlR04/l7`17>Ah0@cLM044g7P0o=b00@3PQ03`e8`0j<b40=c4Q038_800_;B000P0];B400`0/
;R<09bTN02LY7P0302HX7@@09BLL00<092DO02<T7P0Q8Q`00`0O81X00`0P8A/08B8L01lR6`0201lR
6`8082<L0`0Q91d0200S91`092DM02DV7P0V9al09BHN02<T700Q8QX0824I0P0O8Q/201hQ6P807B0I
0P0L7aP801`N6`806b0J01`07R4J024R6P0R91T092@H02LU6@0X9QT0:RLF02dZ6@0`;A`0<RlN03<`
7`0b;ah0<2dL02l/6`0k=280>S<Q03H`800`;Ah0;2XM02PX700W9a/09BLL02LX800X:1h0:RXP02h/
800a;B40=2hP0P0f;al00`0g<Ql0=S4N03<^6`02038]6P0303<^6`0f<Ah0=c8O00<0<bdO0P0b;1h3
034[7@80:RXP00@0:BTO02PX7P0X:1h09bLM0P0V9Q`00`0U9A/09RHL02PX7P0202XZ800402TY7`0X
:1h09bLM02HW7`809BHN00<092DM02<T700R8a/00P0Q8QX2020Q6`807b0J0P0N7aT401dN60807QlI
0P0O81X2020Q6`0G020S700R9Ah08b@L024Q5`0P710091h@02`U5@0d;Ad0CcXM05]6:@1^FST0PVa7
08igCP2@NDd0SGE508Ua@@27LT<0NFHk06EF;`1BAbT0@cdW03Te:@0_;bL00P0Y:RD0200U9b8092HQ
02<U800S9B0092HQ02DW8P0W:B@0:B/V0P0S9Ql202@W80809BPQ0P0V:B8202PY8@0602TZ8P0[;2@0
;2dU02d^9P0^;bL0;c0X100];B<07`0^;R@0;blU02l_9@0`<2H0;C0O030a8@0d=B<0>STU040n:@15
@2`0BD<]04]5;@19?bH0CD<Z0557;P1@ARd0Bd4X04Lm9016?2<0AcdT04@l9`11>B@0?SHQ03de800o
=b80@c/V04Q0:`1;@bh0D4DY0556:P1BAb/00P1CB2`08@1BAb/0D4DY04m4:01>AB@0Cd@T05159@1C
ARH0E4DV05I59`1HABL0FDHX06A79`1XBbT0KU8]07EH<01kG300OEh`07iN;@1mGBX0Q6@c08=U<`24
ICH0PFDf07iS>01jHCP0Mf0g07IO=P1^Fc<0LE/d079L<`1dGC<0MUh`07UN;`0207]O;`0607UN<@1g
G2l0MEX]07=H:`1bEbX0LeP[0P1dFB`06`1bGBH0LehY07AN;01dGRd0Led^075J;P1_F2h0KUL^06aE
:@1^ERX0LeP[07YK;@20GS00QV0a08]S<P2=Hc<0Sf@]09I[=02LLSP0X7Hj09mf>02NMCD0X7Lg0:=j
>02XP3X0ZH4k0:Z2?0020:^3?P0;0:Z2?@2XOcd0Yghl0:In@02/Q4H0/Xa=0;:?C`2]Rd/0YhE50::3
@P2PPd400P2KN4000`2JMcl0V7Dm09Qc?00309Mb>`80VGHd00`0VGHf09Yg=`2LN3X0Wg/o0:9nA02U
P4T0Yh9;0:b9B@2[R4P0ZHE70:R4B02VPTP20:F0B@060:AoBP2MMS/0X7Tn0:=l@@2QNSl0W7Dj0P2H
LCH00`2JLcP0Y78g0:Ab=`030:Ec>0<0YW@i0P2MNC/309ij?00309ah>P2KMcT0VWHh0080V7Hi1P2I
McX06`2CLcP0U7@i09Ee>P2EMCX0Tg<h091`=@2<K340RVX_08e`>02=KSL0SF`f08i[=@2?JSD0TVXf
09E/>02GK3T0RfTl08aZ?@2=Jch0SV`o08e[?P2<JSd0RVPk08UW>P26IBl0R6La08]Z=00208e/=P0;
08]Z=028Ic40QVD_08AQ9`26HbT0RFH^08]X<P2;Ic<0RVHd08QT<P26HS800`21H2d00`20Gb`0Oeh[
07eL:@0207aK:006089M<`20GC<0Oe`b07iM<P1lGC40Nehb0P1jGc8307iR<`0307eP=01lGc<0Nehb
0080NUdc00H0Ne`^07aM;`1nGc40P64c085R=023I3H208AU=`80QF/h0P24JSL01@23JCH0PVPe089X
=@21Ic@0P6D`00<0Of@_0P1nHbh207eR;@0A07aM;P1mGRl0O60`07]Q<01iHS00MV0^07=O;01aGBX0
J5XY06YJ:@1YF2X0JEH[06YD:`1ZDR`0JU0[06Y@;@1ZE2d00P1XDR/00`1UCbP0HT`U061:8`02061:
8`05065;901TCb80IU4T06YC9`1]EBT00P1aER/02P1bEB/0LE@Z07AG;@1dEb/0MEP/07IJ:`1gFb/0
N5`Z07UN:@1jGbX207UM:`0C07YN;01lH2h0OF4_07iR<01oHc40P6@b07mQ:`20HRh0OV<^07eS<01j
Hc40Mel_07AN;`1bG2d0Mf4b07EO<01aFb`0KELX06YD9@0306QB8`0506UC;01WDBX0IDlX069<9@1P
BR<00`1OBB8205e<8@<0GTdR0`1OCR<205]<9@80FT/T0P1IBR<205Q98P0505Y68@1KAb80FdLR05a8
8`1MBB@00`1NBRD7069>:@04065=:01VDbT0IU<Y06IC:@80IE8X0`1TDBL206A<:009069<9`1OBbH0
GD/U05Y;901IBR<0F4XS05e99P1LB2D0FdTU0080FDTU01/0EdTT05I:901FBR@0FT`W05M99P1CAB80
Cd0O04dn7`1<?B00CCdS04hn9015?R80A3dQ04<l8P11>B80?cLR03hf8`0l=240?3<R038/7P0a:ad0
;BTM02XX700U9A/08R@I020Q6@0N8AP00`0K7AX201XL6@<06A/H200H6QT901DG5PP04QPH400D5AL:
01DF608051DG0P0C51H2018C5B0051DG400E5QP801DG5Q805QPG0`0G6AP301PJ6@<06ATG0`0J6QP:
01/K6@P06QXH2@0K6aT;01XJ60<06a/I2P0L71X201dL5`0401hM600O7QT081lJ024P6`808R4L0`0Q
8AT2028R6P<08b<K0P0V8QT202LS6P80:2@K0P0Y9A`302/T7080;2DM0`0]9Qh3034W7@<0<RPN0P0c
:Al403HZ7P@0=BTM00P0=BPH03LZ6P0i;1`0>RdM03/^7P0j;Ad0>B`L03P[6`80?2`M0`0k:a`303XZ
6`80?2XN00H0>bTK03XY6@0k:QX0?B`J03l^6P10;a/403d/7080?RdM00<0?bhN040_7`10;ad00P10
;ad3044`7P80@S4O0`15<R4204Hc8P<0Ac@S00<0B3<N04Td7`19=1l01019=1l00`18<ah0Ac8M04Lb
7@0304Pc7P<0BC@O00P0AcDM04Te7@1:=Qh0C3HO04he7`1@=B00DCDP050d7`H0DcLQ0P1B=R000`1A
=Al0DCPR054h8P02050g8@80CcHP0P1>=Al03P1C=b80DSHQ054f8@1?=R00C3HO04Xf7P19=Ad0AcDM
04Tg8@18=R00AcDO04Dc7@14<Q`0@c4K0P12<1X404Le7`@0BC@O2012<Q/3044a8@<0@30P0P0o;al2
048_7P0404<`7`12<Al0@S4O048a7`80@S<P0P13<Qh01P15<ad0BCDM04/e7@1?=ad0D3PN054g7080
Dc/S00@0DSXR054i8@1A>B40D3PP0P1?=al02@1>>200CcTQ058j8P1D>R<0ESXT05Tj9@1J>bH0Fc/V
05Xk9`0205Xk9P0305/m9@1K?B<0FcdQ0080G3lQ01H0FC/O05Xl801K?B40G3hR05i0901O@BD0H48V
06539`1Q@RD0HT<V06=49@1UAbD0IdTW06U;9`1ZC2H0JddW079@;@1aCb`0L4h[06i=:P1]C2T0JdXW
0P1XBRH206e<:@0406i=:P1_CR/0L4l/075@;@80LU4^0P1aD2d2071?;00506m>:`1^CBX0KTdZ06i=
:P1_DBd00P1^D2`01@1]Cb/0K4hZ06]=:@1[CBT0JT`X0080HdDQ00H0HD<Q06528`1Q@RD0Hd@X06E6
:P1VARd206529@0305m2901K@280FD0Q0080Ed0P00<0ESlO05<o7P1@>R<00P1@>R<304li8P80CSPQ
0P1:>Al604Th7PP0B3HN00P0CCLR04hh8`1A>280DcTR05Di8@1I>b<0FS`R05/k8P80G3hR01h0GClS
05m19@1Q@bL0HT@X06=5:@1TARX0IDHW06I7:01XBBX0JDX[06Y;;01YBR/0IdPY06I7:01PB2@0ID/X
06Y@;@1`Dc40LeDc07AC<P1cD300LDh^07ED<@1fEC80N5Ld07UH=@1hEc@0MeHc07IE<P1eE34206i@
:P0406e?:@1/CRP0JddW06Y<9P80JD/U0`1ZC2X03@1YBbT0IdTW06E79@1RA280HD<Q05do8`1O@BD0
HD<W06=5:@1TARX0HT@X06129P1N@2@0101I@280101J@B<0Fd8T05]2901L@bD805do8`80Gd0S00H0
GT4S05]08P1I@240Ed0P05Ho7`1D@1l805To9080FT<T00@0Fd8T05]08`1M?b<0GChR0P1O?B820690
9@0406119@1N@2@0G44T05a39@80Fd@U0`1O@BD406129P0306539`1P@b<0H4<S00<0HD@T101RABD2
0693900406=49@1TABH0IDHW06I7:080IdPY0P1`Bbh01P1aCBd0LDd[079>:P1cD2X0M54[07AA:@P0
LU4^201`D2T206m>:`04071?;01aD2d0LU4^079A;P80Le8_00@0ME8X07MD:P1iER`0NeP^0`1lFBl9
07]H;P0507YG<@1eDR`0LDhX075>:01eDR`00P1hEBl0101fDbd0MUH_07IF;`1fERl207EE;P<0M5@]
0`1dD2h[ooooo`00:_ooool00`2JL3h0Vg4o09ec@@0309id@PX0WG=100P0WG5009ib@@2PM4<0XGE4
0:9fA@2QMD@0X7A309mc@P<0XGI30`2PMD8209md@@<0X7I40`2OMD<209id@P0609]g@`2LMd<0W7M3
09if@`2OMD<0X7A30P2RM4<0102PMD80XGI30:5f@`2QMT<20:9gA080XgQ500@0XWQ60:5gA@2QMdD0
XGM50`2PMT@00`2OMD<0X7I40:1fA0030:5gA@<0XWQ600@0VGA009Ye@@2LMd<0WGQ40P2LMd<00`2J
MD40Ug8n09A_>`0209M/@@0409I[@02EJSl0U6Tn09=X?@80TVLl00h0T6<i08mT>@2@ICX0SfHj08]U
>028HcH0Pf4c089P<P26H3T0QElh08AN=`23GCH0PU`e081J<`80OeTb0P1jEc401P1iES00N5D_07MD
;P1dDB/0LTlY071=9`80KE4/00H0KDl[06m>:`1_CBX0Kd/Y06i::01`BBP206U;9`0606Q::01WB2T0
IdP[06I7:`1UARX0IDD/0`1TAbL306E8:080ITTY00`0J4T/06U:;@1ZBb`0Jdd[06e?;@1^D2`0Ke4[
071B;01eDRX0Me@/07QE;@1jEbl407]H<080P5Xe00@0PE/d08=N=024Gc<0QV4d0P27Hc<208YT=`04
08]U>02<IST0S6Hi08eW>P80SVPk0P2?I3T3091U>P<0TFHk00X0T6/g08eX=02;IS80SFPd095/>02D
Kc/0TVdi08mZ=P2BIcX0TFHi0`2@ICP01P2BIcX0TfPk09AY?02AIST0TVLj09=X>`80UFXm00<0TfPk
099W>P2AIST00P2BIc`209=X?@<0U6Tn00@0UFXo09I[?P2DJC`0TFHi0P2?I3L00`2@ICP0TVLj09AY
?00209IX=P0309AY=P2DJcL0Tf/g0080TVdh00<0TFhh09AY?02DJC`01`2DJC`0102EJSd0UV/n09I[
?P2FJch209M/?`80V6e000D0SfXf095/>02CKSX0UG0l09Ia?@0209E`?00909A_>`2FLCd0UG0l09A_
>`2CKSX0U6lk09E`?02GLSh0V7<o00P0UG0l00P0U6ho09I`@@2HLT<0UW11099/?@2@JS/0TV`m09A^
?`D0UF/i0`2DJSP408mY>P@0SVPi00H0T6Xk08mY>P2?JCX0SVPi08eW>02<ISL208]U=P80S6Hg0`2=
IcP308iX>@0508aV=`2=IcP0SFLh08iX>@2?JCX00P2@JS/0102AJc`0S6Ph08eY>@2?Jc/2091/?003
08m[>`2=JCT0S6Ph00<0T6Xk0P2AJc`3099/?@P0Sf/k0`28ISP208MU=`<0QV@f01H0PfDa089T<021
Hc40P64b07iO<@1lGC40NU/_07UI<01]EBl0JE</06I@:`1OBbP0FTLV05I69@1CA2<0DT<T050o8@1=
?R40BS/N04Hh7@12=Q`0@3HM0P0o=b001@0i<R80>34Q03@^800`;200;B/O0080:b/Q00<0:b`T02LY
7P0V:1d00P0V:1d202DW70<092HK00P08b@N028S7@0P8A/07b0J01hO6@0O81X0824K024R70<07b8K
0P0P8a`3024T7@0802@U7@0U9Qh09RLO02HW7`0U9Qh08b@L024R6P0O81P201lR6`807R4J0P0M81T2
01`O60P071hK00`06b0J01`Q6`0O8Q/08B8J028T6@0U9AT0:2HJ02PV6@0^:aP0;b`I030]6P0a;Q/2
038_7007034^6`0`;AX0>c@T03Tb8P0d;R00;RXN02XX700202LW7@809bPP00D0:RXP02`/8P0`;R80
<RhR03D_8@0203H_7`80=C0M00@0=2lL03<^6`0c;Q/0=2lL0P0e<1d203<]8@80<R`P0`0a:al00`0`
:Qh0:BTO02TY7`0202PX7P809bLM0P0V9Q`0200U9A/09RHL02PX7P0Y:Al0:RXP02TY7`0X:1h09bLM
0P0U9Qh00`0T9Ad08b@L028S6`02024R6P03020Q6@0P8A/0824K00807b0J0P0N7aT401dN60807QlI
0P0O81X2020Q6`0G01hS7@0Q9Ql09BHN02DS5`0T7Q00:R4@03L/6P13=R<0GdLQ06YB;01kI3/0RgA;
09=lDP2BNdl0S7I708I`@@1cHcl0IULf05=8;014?2D0>3DT030b9@0X;BH00P0T:RH00`0U9b@092HS
02<U8P0202<U8P0402DW900W:BH0:2XW02<V7`8092LP00/09BPQ02HY8P0W:R<09bXS02P[900X:B40
:BXR02X[8`0[;2@0;2dU02h_9`0202l`:080;BdS0`0/;2807P0];B<0;blU030`9P0^<Ah0<C8P03Dg
8P0l>bH0@ClZ04I1:`19@b/0BT@/04To9P1<@RT0CdD/04e3:P18?RD0A3XQ04Dk8P17?B@0Ac`X04Hk
9`15>RH0A3TU04Dj9P18?BT0C44]04i3;`1?A2P0D4DY0556:P80DdP/04@0DTL[0515:@1?A2P0Bd8Q
04e28P1>@b<0DTDU05I7:01IB2X0G4T[05e:;01/BbP0L4l/07EE;P1kG300Of0b081R<020HR`0Of4[
08AV<P23IC<0P6@d07eR=@1iH3L0MUhh07=M>01bFcT0K5Dc06eG<P1`F380LeXa07IK;P1gFb/0NE/Y
07UK9`1eFRd0M5T/07=H:`1bEbX0LeP[07AI;01fFbh0Me`_07IR9`1fHBP0MV4/07IP;P1dGC40LEX`
06mG<@1]EC40LEHW07EI:P1kG2d0PEl_08QR<@2>I380TFDd09AV=02DJRh0VG0b09mf>02RNCT0XWTg
0:=k=P2WOcT0Zh<m0:b5>P80[HDm01<0[HDo0:b4?`2ZPCl0Yghn0:Im?@2UOd40ZXA60:j:C02^S4d0
ZXQ90:F6AP2SQDD0YHM709]k@P2JNT40VgQ009Ye?P2LMCh0WG@n0080Wg@o0P2OO3P0302OO3X0X7dk
0:5n?P2SOd40YH550:N3B@2XQ4X0YhA40:F2@P2SOd40XGe10:1l@P80WgY300T0WgY509ee>P2PN3d0
XWXo0:1h?@2LM3T0VG4f09]c>02MMCX00`2QMCP20:9f>@<0XgLj0`2LNS/01@2KNCX0VWPi09Ug>02H
MSL0UgDf00<0V7Hi0`2IMcX209Yh>`@0UGDh00l0Tg<f099b=@2@L3<0SVha08]a=P2<KcD0SFdd08i[
<`2BJc@0UFXe09Y[=`2KK3P0SVXh08m[>@2AKC/00P2BKS`01P2@K3X0Sf/i08iZ>02;J300S6Ta08m/
=080TFhf00/0T6de08i[<`2=JS80S6PZ08eY;@2>JRh0SVX`08iY<P2=J3<0S6Lc08]V<P0408MS;`0:
08EQ;@23Gb/0PEdY081L:023GS@0P5dc07mL<P1mG340O5da07YM<@80NUlb00`0O60`07eQ<P1mHC80
O5lc07]N=01iG3@0MeTc07IH<P1jFbl0Ne``07eN<P1oH3@4085R=P0508AZ=`23JCH0PfTf08=Y=P22
J3D00`21Ic@308=U;`<0PV@^0P21Hbd04@1mGbd0OV0^07eQ;`1lHRl0NV<_07MR;@1dH2/0LelZ06YL
:`1[FbX0JUT[06UF:`1YDbX0J50Z06Q>:@1WCBX0JeD^0080JU@]01@0J58[06I@:@1TCRL0HT`U065;
901PBR<0GddO065?8@1WDRD0K5DY06mG:`1aER/0Ke@Y06mB:01bEB/0LeHZ07AG:`1eFBX0Me/[07QL
:P80NEhY0P1jGR`0101kGbd0O60^07eQ;`1mHBl207iR<00H085R:`22Hbd0PF<]07mT;`1lHRl0N64_
07IN;P1cGB`0N68c07EO<01aFb`0KELX06YD9@1YDb@0JU@U06]E9P1XDR/0Ie4Z06I@:@1TCRL0HT`U
065;901PBR<0GdTR0`1NCB4205m>8P<0H4lS0`1MBb<205a:8P<0FdTQ00H0GDLP05i88@1OBB80H4XS
065;901SCBH206A>9`80IU0Y1P1WDBX306]F:`80JUDZ0`1YE2T206M=:00906E=9`1RC2D0Gd`T05e;
8`1LBR80FDXQ05i:9@1MBB@0G4XT0080FT/T01`0FD/T05Q<901HC2@0GTlX05a<:01HB2@0EDDS0592
8@1@?b40CchR04hm8@18?b80AchQ04Hl8@15>b80@cPR048g8`11=R80@3DS03L`800f;al0<bdO02hZ
7P0Z:1`09RHL02@T6P0R8a/071hK0`0K7AX201XL6@806A/H200H6QT901DG5PP04QPH400D5AL:01DF
608051DG0P0C51H2018C5B0051DG400E5QP801DG5Q805QPG0`0G6AP301PJ6@<06ATG0P0J6QP;01/K
6@P06QXH2@0K6aT;01XJ60<06a/I2P0L71X201dL5`0401hM600O7QT081lJ024P6`808R4L0`0Q8AT2
028R6P<08b<K0P0X8AT202TR6P80:R<K1@0[91`202`U7@<0;BHN0`0a9ad3038X7P80<bTO100g:al2
03HZ7P80=BTM00P0=BPH03LZ6P0i;1`0>RdM03/^7P0j;Ad0>B`L03P[6`<0?B/M0P0l:Q`303/Y6`08
03d[7`0l:Qh0>bTK03XY6@0k:QX0?2/I03h]6@0o;QX203`[6`0603/Z6P0l:a/0?B`L03h]7@10;al0
@C0P0`11;Qd2048_7P<0@c0O0`17=2<204Pe90<0BCHU00<0B3<N04Td7`1:=B000`1:=B000`19=1l0
B3<N04Xe800704Xe800;04Pf7P1;=al0C3PP04hh8@1A>280DCHQ058f8@1A=B00ECHQ05Hg8P1G>2<0
0`1H>B@00`1G>2<0ESLR05Df8@03058g8P80DCHQ0`1@=B0205<g8P03054f8@1?=R00C3HO0080BSHN
00@0AcDM04Tg8@18=R00AS@N0P14<Q`00`13<A/0A38L04@b700204Hf7`0404Le7`1:=B00BcDP04dd
8080Cc@Q2014=1/204@c8@80@c8P0`12<Al00`11<1h0B2hO04H_7`0204D`7`0<048a7`13<R00@S<P
040c8012<Ad0@c8N04Dc7@18=1`0BcDM04hf701?=ad0DCLL201C>B82054k8`0705<k8`1D>R<0ESXT
05Pi901I>RD0FSXU05Xk9`0205Xk9P0305/m9@1K?B<0FcdQ0080G3lQ00H0F3XN05Tk7`1J?200G3hR
05i0901O@BD206539`80HT<V00@0I4DV06E79@1WBBL0JD/W0P1[CBL01P1dCB`0LTh/075=:`1`CR/0
KTdZ06]=:@80JDdX0P1^CBX206m>:`04071?;01aD2d0LU4^079A;P80Le8_0P1bDBh0101aD2d0L4l/
06m>:`1_CR/206mA;@80KU0/0P1]Cb/206a>:P0=06I8901UAb<0I4HT06=49@1SA2L0I4DY06I7:`1W
Abh0ID@U06A3901Q@R<0Gd8R05]1800205U17`0405M07P1F?ad0E3/U05@k9@80DcXT0`1B>B<00`1A
>280BcXP04/j800204Xi7`@0BCPN2018=Qh204hg9@03054h901C>2<0ECTS0080F3XR00L0FSXQ05/m
8@1L?R80GClS05m19@1Q@bL0HT@X0080I4HZ00@0IDHW06I7:01XBBX0JT//0P1[C2d206Y;;00606E=
:@1WCBX0JU0]06iA;`1`DS00Le8a0P1cD3000`1dDc00MUDb07MF<`0207UH=@0307QG=01gES<0MUDb
0080L5<[00H0Ke8Z06iA:@1/CbL0JdhV06Y=9@1YC2@306]=:`0306Y<:P1XBRP0IdTW0080IDLU0P1R
A2P306=5:@030694:01P@RH0Gd4U00@0FT4S00@0Fd8T05a39@1NABL0GdHX201N@2@0201S@R<0I4<T
0693901QA2@0GT@S05]38@1I@R00F44O201J@2D205Y3900405]2901L@B@0GT0T06119@80HT0U0P1S
@BH0101P@BD0GT0T05a1901L@bD205a59PP0HD8V00@0H4<S0654901QA2@0HD@T0P1RABD306=69P80
ID@U00H0ITDV06Q7:01YB2T0JTTZ06]::`1/Bb`207=<;`0307A=;P1eCRd0MU0/0080Me4/00<0N58[
075@;@1aD2d01P1aD2d8075A:P80LE0]0P1bDBh207=B;`80M5<`00@0ME8X07MD:P1iER`0NeP^0`1m
FS0907aI;`0507eJ=01hEBl0Le0Z079?:@1eDR`00P1gE2h00`1eDR`0MUH_07EE;P0207EE;P80M5@]
0P1cDb`307A@;R_ooooo000Zooooo`0809U_?@2KLCl0WG=109id@P2OMD<0WWA209ec@@2LLT0809ec
@@0309ea@02NLT40X7A30080XWI500<0XGE40:1d@`2OLd800`2QMT<30:1e@P80WgA10P2QMdD20:1f
A00509me@`2NM480WWA209id@P2KMd<00P2LMd<00`2NMT<0WgE30:1d@`020:9d@`@0WgA10P2PMD82
0:5f@`80WgE30P2PMT@20:5gA@80XWQ60P2PMT@20:5gA@80XWQ60P2SNDL309ag@`0<09]f@P2JMD40
VWE109Qc?`2GLSh0UW4m09U^@`2HKD80Ufa109EZ?`2CJ3d0TVLl0P2@ICX03P2@HcT0Sf@i091U>P2>
ICT0RfDh08MR=@23HC<0PEla08IP>@25GcP0Q5hg08=M=P22G3D0P5Xc0P1oFC8307YG<@0;07UF<01g
E2h0M54[075>:01_C2H0IThX06M=:01YCBP0JT`X06e;:01^BRP00P1aB2P01@1ZC2P0JD/W06U;:@1X
BBX0ITLZ0080IDHZ00<0I4@[06=69P1SARH00P1TAbL04@1UB2P0ITTY06I9:@1VBBT0J4T/06U:;@1Z
Bb`0Jdd[06e?;@1^D2`0Ke4[071B;01eDRX0Me@/07YG;`1mFS80OU/c0080Oe`d00L0OU/c081J=@20
FSD0PE/d08=N=024Gc<0QV4d0080Qf<c00D0RF<f08YT=`2:I3L0RfDh08eW>P0208iX>`0508mY?02?
I3T0Sf@i08mT>@2@ICX00P2AIS/2099W?00C08mZ=P2<Ic<0RfHb08eX=02BKCT0U6lk09=^>P2@JcL0
TVLj095V>@2@ICP0Sf@g091U>02AIST0TfPk09EZ?@2AIST0TVLj09=X>`0209EZ?@0309=X>`2BIcX0
TFHi00<0TVLm0P2CJ3h309AY?`0309M/?`2DJC`0TFHi0080SV<f00@0Sf@g099W>P2DJC`0UVLc0P2F
J3@01@2EJSD0U6/e09A]=P2BKCH0Tfhg00d0U6Tl0P2EJSd209I[?P0408iY=@2@JcL0TVdi09A_>`80
UG0l0P2DKc/00`2EL3`0U6lk09=^>P0209=^>P0309E`?02GLSh0V7<o00P0UG0l00P0U6ho09Ma@P2I
Ld@0UW11095[?02?JCX0TF/l09A^?`H0U6Xh0P2EJcT408iX>@@0SfTj0P2@JS/01P2?JCX0SVPi08eW
>02<ISL0RfDf08YT=@80S6Hg0`2=IcP308iX>@80SVDg00@0SfHh091W>@2AJ3X0TVTk0P2CJS`00`2<
J3P0SFTi08iZ>P02091/?00308iZ>P2=JCT0S6Ph00<0T6Xk0P2AJc`3099/?@P0SFTi0P28ISP208MU
=`@0QV@f01H0QFLc08AV<P22I380Of0a07aM;`1iFRh0MeP/07IF;@1YDbh0IU0[061<:@1JAbH0EDDT
05528@1@@B80Cd8R04ln801<?B00BCXM04Dg7011=A/0@3HM0P0n=Ql0200g<200=BdP038/7P0^:Qh0
:bTM02TY7`0Z:R80:BXR0`0V:1d202DW70@092HK00<08b@N028S7@0P8A/00P0N7aT00`0O81X0824K
024R700301lR6`8082<L0`0Q91d202DV7P809RLO00@09BHN02<T700P8AT07b0H0P0O8Q/201hQ6P80
7B0I0P0L7aP801`N6`0:01/P6P0L8A/07b8K024R6P0S9AX09BDI02PV6P0Y9aX0<RlL034^6`<0<2dJ
00X0<BhK038_700c<1d0>c@T03L_8P0b;1h0:bLK02PV6P0V9Q`0:2PP0P0X:B402P0[:b40;BdS034_
8`0d<2@0=S0R03H_7`0e;Qh0<RdJ03<^6`0d;a`203D`7@0303@_700c;Q/0<RdJ00<0<R/Q0`0a:R02
030Y7`<0:2PN100W9ad0100V9Q`092@J02DU6`0W9ad302TY7`0802PX7P0W9ad09BHN02DV7P0T9Ad0
8b@L028S6`0Q8QX2020Q6@80824K0P0O81X201hO6@@07AhH0P0N7aT201lP6P80824K01L06b4M024V
800X:B40:RPL02dV5P0h;A/0Bc`W05Y:<`1fFbh0OV<f08U^@`2@N4`0TGU=08]dB021JSh0NVDh05e>
>@1AABl0@CTV03H`800];R00:2hR028/8@0201l[8@0902HX9@0U9b@092HS02<U8P0T9R<09BLT02LY
9P0X:RL092LP00809BPQ01/09RTR02P[900Y;2D0:B`U02X]9P0X:B40:BXR02X[8`0[;2@0;BhV02h_
9`0_<2P0<34Y02d]8`0/;280:b/Q02XZ800[:b40;2`R02h^900`<2H0;c8O038d7`0f>2<0?C`W044o
:016@RT00P18@RP02019?bH0Bd4X04a2:@18?RD0A3XQ048h7`14>R40AcdT101;?R/0;@1<?b`0CD0]
04i1;P1?@Rl0CD8V04i39`1@ABT0DTL[05=8;01BAb/0DDHZ0515:@1;@R40CT<S05569P1FBBT0Fd`]
061?<@1UDS@0IU<e07=?:`1fDbd0NeP`07mN<@22HS40PV@^085T;020HbT0P6D^07mT;`1mHc80NF4c
07EN=@1bG3L0LEXj06iI>P1^ECH0KeLe07=I=01gFc<0NE``07YL:P1iFbL0NU/U07AI:P0207=H:@0e
07AI:P1fFb`0N5d^07]P<@1mHS<0NFDX07UU:P1iI2d0N68`07IO<`1bFc80KeLc06eE<`1hFBX0NU`Z
085O;`28I380SfLd09=X=@2FJ3@0V6Te09ac<@2OMS@0XWXe0:=k=P2QNC<0Xg/c0:R1=P2]QS/0[XLj
0:n8>`2_Qcl0[XI00:b3@@2YP400YWdo0:Aj?P2UOT<0Yh=70:^7B`2ZR4/0YHE80:>5A`2URDX0ZHe>
0:62B@2QPDP0XGi60:5lA@2TNdD0YW]60:UkA`2[O4P00`2VPcl00`2VPd40YhA40:N3A@020:N3A`0A
0:N3B@2POCd0WW/k09]g>@2IMCT0Ug<i09Mb>`2HLc`0V7<n09Yb=`2MMCX0X7Pm09if>`2KLcP0VW8g
09ad>@2PN3d00`2KN3H209ai=`<0WGXh0P2INSX01P2HNCT0UgPh09Ig=`2EMSH0U7De09=d=080UgDh
0P2HMST0102IMcX0VWPk09Yh>`2JN3/209Mg>P0F09Ee>02DM3L0Tg<f09=c=P2DM3L0UGDh08ab=@2=
L3@0SVhc095]<`2EK3@0VV/e09i/=`2PKCP0TVhd09=_=@2DL3H0UG4g09Ib>02ELCL0Tfle099^=080
T6``00<0TFda099^<P2CKc<00`2CKc<01@2FL340UFl`09=];`2BJc00TFXa0080TFXc00<0TFTe08aW
<`2=J3@00P2=J3@0302;IS80RF@`08IQ;@24Gb/0QF0f085N=01oG380O5/`07]L<01iG300NEha07YO
<P80Nel_00l0O60a07]N=01iG3@0MUPd07AF=01bE380NU/_07aM<@1nGc<0Of0d081Q=@1oH3@0OUlc
07eN<P20JCD0101oJ3@307iW<`80QVLa0P25IS0308AU;`0B08=T;P1mGb/0OV0/07eR;@1mI2h0NV<]
07QS;01eHRX0M64Y06aN;@1]GB`0JeX/06UF:`1XDRT0IdlY06E;9P1TBRL0JE</0P1ZE2d0501/ERl0
JeD^06UC;01VD2T0HT`U05m98P1LBad0GdhP06AB901ZEBP0KEHZ06iF:P1]EBT0KE8W075D:P1bEBT0
LeHZ07AH:@1fFRX0Me/Y0P1iGRT707aP;P0=07eQ;`23HR`0Pf8/08=T;P22I300OV8`07]Q;P1hGRd0
MEh/07QR<`1eGc00LE//06aF9`0206YD9@0806aF9`1]EbP0Ie4Z06MA:P1VD2T0IDlX06A>9`1RC2D2
065;90<0GdhR0P1PCb<3065@90@0GT/Q0P1MBR0205a97`0905m9801PBR40HD/R069<8`1TCRD0IU0W
06MA:01XDRT0Ie4X0080J58Y00<0JE<Z06YD:`1ZE2/00P1[EB`306eH;@80K5L/0`1[ER/0201^DR/0
K5<[06]B:P1XDBP0IU0W069?9@1PCb@0GdhS0P1NBb<0101MBb<0Fd`S05]<8`1JCB<205U=8`80G4XT
01H0G4XV05]89`1IARH0Ed@T05A18`1C@280BChP04Pm8@17?200ASXP04Di8@14>280@cHS048e8P0l
<b80>C8P03L`800c;Al0;RXN02/Y7@0V9QX09BDK0P0L7Q/301/M6P<06Q`I200H6QT901DG5PP04QPH
400D5AL:01DF608051DG0P0C51H2018C5B0051DG400E5QP801DG5Q805QPG0`0G6AP301PJ6@0401TI
5`0J6QP06QXH01XJ60806a/I2P0L71X801/K6@T071`J2`0J6QP301/K6@X071`J0P0M71L0100N7AP0
7ahI020O6P0Q81/2028Q70<08B4I0P0R8QX302<S6`80:B0I0P0Z8AX202/R6`80;2<L0`0[91`202`U
7@<0;BHN0`0a9ad3038X7P80<bTO00<0>BdQ03P/800h;2000P0g:al203HZ7P0903DY7@0e:1P0=bXJ
03T/700j;Ad0>bhN03X]7@0i;1`0>2/K0080?R`N0P0m:ad303`Z700403/Y6`0m:al0?2XN03/Y6`80
>RTI00@0>bXH03d/600n;AT0?2/K0P0k:QX01P0j:AT0?2/K03h]7@10;al0@S4Q04<^7@<0A2lN0P15
<1l204Ha800404@a8015<R40AC8Q04Db8@80AS<R0P17=2<00`18<ah0BC@O04Xe800204/f8@0304Xe
8019=1l0B3<N00@0C3LR101;=R403019=al0C3PP04hj8P1A>b@0DcXT05@i901C=b80DSHQ05Hg8P1G
>2<0FCXU05Xk9P80Fc`W00<0FS/V05Pi901G>2<0101C=b82058f8@80DCDP0P1C=b802@1A=R40D3LQ
04dg801;=al0BSHN04Pf7P17=Al0AS@N04Dc7@0204<a6`0;04@b7016=1h0AcDO04Df7`16=Ql0B3HP
04Xe801>=B40Cc@Q054d8P1C=2802015=A/204Dd8080A3<O0`13<Qh01`12<Ad0BbhP04X^8019;b00
AS4P04@a8013<R000P0o<Ql02012<Ad0@c8N04Dc7@18=1`0BS@L04hf701?=ad0D3HK0P1B=R00101C
=b40E3PR05Di8`1F>R@205Lk9@80DcdU00<0ECdU05Dk901F>R@00P1G>2<01`1H>2<0FS/W05Xk9P1J
>bH0FcdU05/m8`1K?B400P1L?b40401G>Ad0F3XN05Tk7`1K?B40GClS05m19@1Q@bL0HT@X06939P1S
A2L0I4DV06I89P1XBRP0JT`X06]=9`1/CRP207A;:`06075=:`1`CR/0KDl[06a@:`1ZD2/0JE4[0P1^
CBX00`1_CR/0L4l/075@;@02079A;P0907=B;`1fEC80MUDb07ED<@1dDc00Le8_079A;P1aD2d0L4l/
00<0Ke4]0`1^D2`206e?:`0=06Q:9P1WBBD0ITPV06A59P1TABP0IDHZ06I7:`1WAbh0Id@V06E49@1T
@b@0HD8S05i18@0205]1800405U17`1H@1h0EC`V05Dl9P80E3/U0`1C>R@0101B>B<0C3/O04/j7P1;
>Qh204Xi7@80BCPL00<0B3LK04Tg7`19=al01P19=al204hg9`0C054g9P1C>2D0E3PS05Lh8`1H>B@0
FCTR05Pm801I?R40Fd0S05e29@1OA2L0HDHY0697:P1SB2/0Hd@U06E69`1XBBX0Jd`]06e>;`0206i?
<00>06e>;`1ZDRh0Je4^06Y@;@1/Cbd0KDl]075@;`1cD300M54a07=B;`1dDc00MUDb07QG=01iF3D2
07QG=00707MF<`1bEBd0LE@/071C:`1_DRX0KE0X06a?9`0206Y=9@<0Jdd[00<0JT`Z06U;:@1YBbT0
0P1YBbT01@1XBRh0IdT]06A6:P1RA2P0HD<W00<0H48V0P1L@bD205]2900405a39@1NABL0HDPZ0699
:`P0H48V00P0Id@V06I59P1WARL0ITLX06A79`1PARD0G4@R05]38@P0FT0U0P1J@b@0101L@bD0GT<V
06539`1SA2P206E3:00806A29`1S@BH0H44U05i0901L@B@0G4<U05a59P1MARL606=19P80HT0U0`1Q
A2@206959@@0HdHV00P0Id@V06Q59`1YARP0JdPZ06a9:`1^Bbd0Kd`^071=;`80MD``00<0MTd_07M>
;P1hD2d00P1iDBd00`1jDb`0LE0]075@;@06075@;@P0LE4Z101cDRl407AC<00507AB9@1fE2L0N5HY
07]I;01lFRd00P1mFbh907aJ;@08085N>01kF380ME8/079?:@1dDB/0Me@^07IC;@1dDB/407AD;@80
Le</0P1bDR/307A@;R_ooooo000Zooooo`0309U_?@2JL3h0WG=100<0WgE300<0WG=109ab@02MLd40
1`2MLd400`2MLD00WW910:1d@`030:9fA@030:5eA02PM4<0XGI30080XGI30`2PMD8209md@@80XGM5
0P2PMT@01@2OMD<0WWA209id@P2MLd40VgM30080W7M300<0WWI309me@`2PM4<00P2RM4<209eb?`80
WW=00P2OM4420:1e@P80WWA200@0WgE30:1fA02QMdD0XWQ60P2SNDL20:1fA080XGM500P0XWQ60:=i
A`2SNDL0Y7Y809iiA@2MN4@0VgI209Ud@080V7<o00`0Ug8n09Qc?`2HLcl0VVm409U^@`2GK440UFXo
09=X?@2AIS/0Sf@i08iS>02?HSP208mT>@0;08iU>@2;ICP0Qf8e08=Q<`21Gc40QV0i08EO>024GSL0
Pedf089L=@20FS<00P1oFC8407YG<@0407MD;P1dDB/0LDhX06i;9@80Hd/U00H0Id/V06U;9`1/BRL0
L4TX0799:@1dBBT206Y<:00606U;:@1XBBX0ITLZ06E6:P1TABT0I4@[0P1SARH206A79`0A06E8:01V
BBT0ITTY06M::P1XBB`0JDX]06Y;;01[CB/0KDl]06i@;01_DB/0L58/07EB:P1gE2`0NeP`07iK<`20
GCD00`21GSH2081J=@04085K=023GS@0Q5lc08IQ=080Qf<c0P29HcH0102:I3L0RfDh08eW>P2>J3/2
08mY?00408iS>02?I3T0Sf@i091U>P80TFHk0P2BIc`02`2?JSD0S6Lb08]V<@2=J3<0TVdh09E`>`2C
KST0T6/f09=X>`2AIST0T6Dh0080Sf@g00H0TFHi09=X>`2EJSd0TFHi099W>P2CJ3/209EZ?@0309=X
>`2BIcX0TFHi00<0TVLm0`2CJ3h209AY?`0809M/?`2DJC`0TFHi08iS=P2=HSD0Sf@g099W>P2DJC`2
09IW<`0609IX=02EJSD0U6/e09A]=P2EKSL0Tfhg2@2DJC`2099W>P80TfPk0P2DJC`209EZ?@0408eX
=02?JSH0TF`h09=^>P80UG0l0P2DKc/00`2EL3`0U6lk09=^>P0209=^>P0309E`?02GLSh0V7<o00P0
UG0l00P0Tfe009MaA02ILdH0UW13095[?P2>J3/0T6Xm09A^@@80TfTg102DJSP209E[>@@0SVPi102?
JCX2091Z>`0308mY>P2>J3T0SFLh0080RfDf00<0RV@e08aV=`2<ISL00`2=IcP308iX>@0;08eT=P2>
ICL0SfHh091W>@2AJ3X0TVTk09=Z?02DJcd0S6Ph08eY>@2>JSX00P2?Jc/00`2>JSX0SFTi08aX>003
091Z>`80TF/l0`2BK3d808aX>080R6Hh0P27ICL308IT=P0Q08ES=@27JCD0QFLc089T<P1nGc00Ne`^
07QI;@1fEb/0M5@[06MA;01SCbX0GTXW05Q5901B@R40Cd0Q04e0801=?b80CSdO04`m8019>Qd0ACLL
044e6`0o=A`0?CDN03hf7`0e;B00=2`O030Z7P0/:1d0:RLN02PX800Y:B40:2TS00809RPM0`0U9a`4
02@V6`0302<T7P0R8ad0824K00<07QlI00<07b0J020Q6`0O8Q/00P0O8Q/2020S70<08B@M0P0U9Qh2
02HW7`0402DV7P0R8a/0824I01lP60807b8K0P0N8AX201dP6@8071lH200L7Q/201`Q6`0Q01lR6`0Q
8QX08bDJ02DU6@0X9QX0:BLJ03@b7@0b<1/0<2hI02h/5`0_;AP0<2hI03<a700e<ah0>S8U03L_8P0`
:Qh0:RHK02LT6`0V9Qh0:BTQ02X[9@0X:B40:b/Q02h^900b<2@0=30T03H`8P0f;al0=BhN034/6@0b
;AX0=C0M0080=c8O00<0=C0M038]6P0a;1T00`0b:b42034Z80<0<2TO00<0:2PN02LW7@0W9ad01@0W
9ad00`0T91X09BDK02LW7@0202TY7`0402PX7P0W9ad09RHL02DV7P8092DM00<08b@L028S6`0Q8QX0
0P0P8AT2020Q6`807b0J0P0N7aT401dN60807QlI0P0O81X2020Q6`0G01XP700Q9R00:R/S02l]800d
;Ad0@cHS05Y:<`1[FD40Rflo08mcA02CN4T0U7U<08eeB@20JCd0LUdb06YE:P1<?S40@cL[03D]800[
:A`09bTL02<[700O:ad00P0L:Q/00`0W:BP09RPW02DW9P0202@V9@0302DW9P0W:BP0:2XY00809BPQ
00@09RTR02LZ8`0Y;2D0:RdV0P0[;RL202TZ8P0802X[8`0[;2@0;BhV02h_9`0_<2P0<34Y02d]8`0/
;28302XZ800902`/8P0^;R@0<30V02lb7@0b=1l0=cTS03dm9@11?bH0AD4X0080AT0V00/0BT0W04]1
:01:@2L0AS`S044g7P10=Qd0A3XQ04Pn9@1=@2d0CT4^04m2;`030513<00604m2;`1>@Bh0C44U04e2
9P1?A2P0DTL[0P1CB2`08P1BAb/0DDHZ04e48`1@ABD0E4TY05Y=;@1PDC80IUDg06]H>P1]FS`0N58]
07]E<020Fc40PV0b08AT<@23IBl0PVD[07mU:P1oI2d0OF@^07]Q<01gGc<0M5dd075J>01^FCX0KEPk
075H>P1cF3X0MU`i07YN=P1kGc00OEl]07aM9`1kG2D207AJ:@0f07EK:P1fG2/0NEl^07eS<P20ISD0
PVPg07]W:P1kIb`0NfH_07US<@1gH3@0Le`c071H=01]EC<0NU`Z07iN;@24Hc00RfHb099Y=@2GJCD0
VFXf09]Y=02SNcH0YGdh0:Em=`2SNc<0X7T^0:5j;`2VOc80Zh@g0:n8>@2`RC`0[hPm0:j6@02[PT00
Z7lo0:Ek?`2RN3`0Y8140:N3A`2XQTT0YHE80::4AP2SQDL0Yh]<0:b@D@2WR4l0YhM>0:N4C02YPT/0
ZX5;0:j0C02aPTh0]H=@0P2[RD80302[R4@0ZXM30:Z7A@2YQTH0Z8A60:N3A`2VPTH0VWLg09Uf=P2F
LS@0Tflc099^=080TVdf00D0Tfhi09U_=@2LLSP0WgDk09id>P0209]a=`0309id>P2RN3h0UWTc00<0
UgXd0P2HNcD209Ul=P0509Uj>P2HNCT0UgPh09Ef=P2DMCD00P2CM3@00`2BLc<0UgDh09Me>00209Qf
>@0709Ug>P2JN3/0VWPk09]i?02INSX0UgPh09Ef=P0209=d=00>09Ef=P2GN3P0VGXj08ad=P2>LCD0
SW0d099^=02GK3D0Vf`f0:1]>02SKSX0Tg0`09Eb<P2FLc<209Qe=@0309Md=02FLc<0UG8b00@0Tflc
00d0U70d09Ea=@2FLSH0Ug<g09]e=02ILc80UFl`099/;P2AJRl0TFXa09=/=@2DKCH0SfXe00<0T6/f
01L0SVTd08]V<@28Hbh0QV4/08EP=P22GcD0Oe`b07aK<01jFbl0NE``07UN<@1jGc80NUh/07YN;P1k
Gc00NUdc07QJ=01eEcD0LU<d06m@<@1kFc80O5`c07iN=@0207mO=P0307iN=@1lG3<0Ne/b00D0OFPc
0`1lIc801027J340QVL`08IW<026Ic0208EV;`80Q6D^0140OEl[07iP;01mHRd0OF@^07]T;P1iI2d0
MV<[07ER:P1^H2l0KUh]06aK;@1YER/0J58Y06E=9`1TBRD0HTPU06QB:`0206]E;P0:06iH<@1_FC80
KEL`06QB:`1SCBH0GdTR05]:701NCAl0I58T06YE:080KEHZ00X0K5@X06]C9`1`DbT0LE@X079E:@1d
F2T0MUXZ07MK:@1hGBP0NEhY0`1mHBl307aP;P80Nel]0100Pf<Z08AS;@23I2d0PV@^07mT;`1lH2h0
NEl^07MM;01hHS<0MEl`071J:`1/ERL0JU@U06]E9P1]EbP0KeTZ0`1VD2T00`1UCbP0I4hW06==9P02
069<9@<0GdhP0P1PCb43065@8P0405m<8P1NBb40GT/Q05i;8@80GDXP0P1LBAl0201QBR40HT/R06=<
8`1UCRD0Ie0W06UB:@1ZDbX0Je@[0P1YDRT0101ZDbX0Je@[06aE;01]ERd206iG;P<0KeP/0P1^Eb/3
06eF:P0807=G<01bERl0KeH^06eF;@1ZE2/0IU<Y06EB:01SDRL205e:8P0405e;8`1KC2<0Fd`S05Y=
8`80FThT00P0EdDM05U78@1KBB<0GD/W05e::@1KB2P0F4DW05M49P80B3dO00h0Ac`P04Hj8015>B40
A3PR04<g8@13=R<0?SDT03dd8`0i<R80=BlQ030/800/:Qd0:RPL02LW6`<071hK0P0K7AX301XL6@P0
61XI2@0E5aH8018H610051DG2P0E5QP201@E5`804a@F0P0B4aDP01@E5a005AHH200E5aHB01HH5`<0
5aTH0`0H6QT401XJ60806a/I2P0L71X801/K6@T071`J2`0J6QP301/K6@X071`J0P0M71L0100N7AP0
7ahI020O6P0Q81/2028Q70<08B4I0P0R8QX302<S6`80:B0I0P0Z8AX202/R6`80;2<L0`0[91`202`U
7@<0;BHN0`0a9ad3038X7P80<bTO0`0i;B400`0h;200=b/O03HZ7P0203HZ7P0803DX600g:QX0>B`L
03X]7@0k;Qh0>RdM03T/700h:a/203l/7P80?R/M100m:Q`00`0m:al0?2XN03XX6P0203XY6@0503/Z
600m;1P0?RdI03`[6`0k:QX00P0j:AT0100k:QX0?RdM040_7`12<B4404@_7P80AC0O0P16<B001011
;Qd0@RlN048_7P12;ah204<`7`80A34P00<0Ac8M04Td7`1;=R400P1<=b800`1;=R40BC@O04Lb7@05
04dh8`<0C3LR00/0BSPP04di8@1?>b<0DS`U05Dl9P1E>RD0E3PS05<g8P1H>2<0FCTT05`l9`0305dm
:00405`l9`1K>bH0FCTT05@h8`<0DcLR0P1B=R42054e800;05@h8`1C=b80DSLR050g8@1==b00BcLO
04Xf7P18=Qh0AS@N04Dc7@14<Q`00P13<A/02`15<ad0AcDO04Tg8@15=Ql0ASHO04Pf801<=R40CSDQ
054d8P1D=B<0EC@S00P0ACDK0`16=20204Dc7`<0A38N00H0CRhQ04`_8@1:;R00Ac0P04@a8012<b02
03lb7`80@S4M00H0A38L04Pd701:=1`0CSHL04lg7@1@=Q/2054e7`0405<g8@1D>280ESXT05Lk9@80
FCdW0P1E?bL01`1F?RH0ES`U05Hj901G>2<0ESLR05Hf8@1J>bL00P1J>bH00`1K?BD0FcdS05/m8@02
05`o8@0F05Hh701G>Ad0FC/O05/m8@1M?b<0Gd4U06539`1RA2P0HT<V06=49`1TABH0ITPV06Q::01Z
C2P0JddW06a>:01eBRX0LdXZ07=<:`1`CR/0KDl[06eA;080JU8/0P1^CBX0101_CR/0L4l/075@;@1b
DBh207=B;`0607QG=01gES<0MUDb07ED<@1dDc00Le8_0P1bDBh406mA;@@0KU0/00P0JT`X06U;9`1W
BBL0IDHW06E6:@1UARX0ITL[06M7;P80Id@T00<0ID@S06538@1O@R000P1L@Ql00`1K@Ah0FD4M05Hk
9P0205Hk9P80ECXU0`1D>B@204`k7@80BcXL00@0BSTK04Th6P19>1X0B3LI2019=al204hg9`0R054g
9P1B=b@0E3PS05Lh901G>2<0FCTT05Ln801H?b40FT4S05a39@1NABL0H4LY0658:P1RBB/0HT<T06A5
9P1XBBX0Jd`]06i?<01_D340L54b06m@<@1^ES80KE<`06Y@;@1ZCB/0Jdd[06m>;@1cD300ME8b079A
;P1cDRl0ME@a07MF<`<0N5Ld00T0MeHc07=F;01bEB/0LE@Z06mB:01^DBL0K4lU06]>901ZCB<00`1[
CB/306Y<:P80Jdd[00@0K4hb06U;;`1UAb/0HT@X0P1O@BD0101P@RH0HD<W05i59`1MA2H205a39@04
05e49P1OARP0HTT[06A;;@P0HT@X00P0J4DU06U69P1YB2L0J4XX06I99`1QAb@0GdDR05a480P0FT0U
0100FT<T05]49@1MA2H0Gd@W0694:01TABT0IdDZ06Q6:`1U@bP0I48W06119@1M?b<0Fd0S05a39@1M
ARL0GTLX1@1S@BH306909@80HD@T0`1RABD406=69P80JDHX00@0JdPZ06a9:`1^Bbd0Kd`^0P1aCS00
201eC300MTda07M><01gCRh0N50]07UA;@1jDRh0NU</201`Cb`8079B:`H0M5<`0P1eE3401P1cDB<0
ME<U07QF:01jF2X0O5X/07eK;@X0O5X/00T0Q64k07eJ=01fDbd0Le0Z07AA:`1fDbd0ME8/07=@:P1d
E2d00`1cDb`2079B:`80LE4Z0`1dD2h[ooooo`00:_ooool@09ab@00>0:IcA02SLd<0XW920:1b@@2O
Ld80WgE30:1hA@2QNDH0YWY90:AhA`2QMD@0Wg=209ea@02NLT4209mc@P80X7E200@0WgA109ic@02M
LSl0WG8o0P2LLCh20:9hAP80XGM50P2PMT@209me@`050:IhA`2UMdH0XgM60:5gA@2OMd@00P2LMd<0
0`2JMT80WgE309me@`0609me@`80XgY600@0XWU50:5hA02PMd<0WgI20P2NMD40102KMDH0W7I709af
A`2MMdP209afA`0409YdA@2GLD80UW11099`@080TFlo00<0T6hn08m]?@2>K3`00P2=Jc/0102AJDD0
SFE108YR?P2:HSh208aT@00308QP?024G3P0OU/c00@0OU/c0`1mFS800`1cD2X0M54[07IC;@0207MD
;P0307EB;01cD2X0LTlY0080KT/[00h0KTd/06e?;@1]D2h0Je4^06aB;`1[Dbl0JD`Z06Q;:@1WBRP0
IDPV06=6901RAB<0HD@R06138@<0HD@R0`1RAB<206=69080Id/V00`0J4XV06]:9`1^C2T0Ldl]07IB
<01jDc80MU8`07MC<@1hE300NULa07aI<@1mFS8207mL<P<0Q5lb0`25H3<208IQ=00308aV=`2=IcP0
SFLh0080SFLh0`2>J3T208eW>P80SVPk0P2?JC`2091Z?@@0SfTj102>J3T02`2=HSD0SV<f091U>02B
IcX0U6Tl09I[?P2GK3l0V6e009=]?P2BK3d0T6Xk00<0SVPi00D0SfTj091Z>`2DJC`0TVLj095V>@02
08mT=`06095V>@2BIcX0U6Tl095[?02@JS/0SFLh0P2<ISL00`2=IcP0T6Xk095[?003099W>P<0TfPk
0P2DJC`00`2CJSH0U6/g09I]>@0209M^>P80UVdi00<0U6/g09=Z=P2FJch01`2FJch02`2@JcL0TVdi
09A_>`2EL3`0UW4m09E`?02DKc/0Tfhj09I/>P2GKC/0VFlm0080Vg4o00<0VW0n09U_?@2HKS`00`2H
Lc`209Mb>`<0UW4j0P2EL3`209A_>`80Tfhj0P2BKCT209AY?080TfPk102BIcX0202AJc`0T6Xk08mY
>P2=IcP0S6Hg08YT=@29Hc@0R68c202;IcL208QT=00408UU=@2:ISH0S6Ph08eY>@80SVXj0`2=JCT5
08aX>080SfU200T0SfXn08mZ?@2?JcT0Sf`f08m/=02?K380TFdm091/?02>JSX00P2=JCT01P2>JSX0
T6`l095]?@2<JSX0SF/k08i/?080Sfdm01/0SF/k08]Y>@29IcL0Sfdm08i/?02<JSX0RVPh08QV=P26
I3@0Q68b08=Q<@22GR`0P5l/07mM;@1mGBh0NEX/07AG:`1`EBP0KU<X06aA<`1XCc00ID`^05i6:P1G
@RL0DCdT04/j8019=al00P14>2801P14>BD0@SXW040i9P0m>2D0>CHU03Pe9080<34S00<0;c0R02h_
8@0];R000P0/;Al01`0[;1h0:bTL02/Y7@0X:1`09BLL02@U7@0R9Ah00P0O91h00`0N8ad07R4J01hQ
6P0601hQ6P808B@K100P8aX201lR6@06028V5`0R9QP08BDG020S600O8QT07R4J0P0M7aX301dO70<0
71hK0P0K7AX01P0M7Ad07AdK01hN700N7aX07b0J020Q6@80828G01/082<H028T6@0S9AP09RLI02XX
6@0/:AP0<2XJ030[600k;B00>R`O03L[6`0e;AX0=BhK03Ha6`0f=1/0>3HM02l^:@0/:bH0:BTQ02HV
700U9AT09bPJ02X[6`0/;Ad0=C0M03Ha7P0h<b000P0i=2401@0h<b00=c8O03Ha7P0f<Ah0=c8O0080
>C@Q00l0>3<P03Ha7P0d;a`0<RdJ03H^8@0d;1l0<B/M02dZ6`0[:AX0:BXJ02X[6`0Z;A`0:RXP02TY
7`0W9ad00`0U9A/02P0W9ad0:2PN02XX6`0Z:1`09bLK02DW700T9Ad08RDN020U7`0O91h3024T7@80
82<L0`0O8Q/301dP6@D071lH01`0728F01hT600Q91/0824K01hM600P71T09B4P02XT900/:R/0;2PU
02lW700g:aD0BSLG0699801gFbT0QVL`09edB02HLT40TW4k08aa>P24KSd0M60k05i<=P1??Bl0;2lX
02/^9`0X:b@09RTR0P0U:24302HY8P<092LP0P0U:24302HY8P<09RTP0P0W:R4302P[8P80:B`S00<0
:R/S02/[8`0]:R<00P0_:R@03P0a:R@0:2/P02/]8P0^<2<0;RlQ02h/7@0a;Qd0>C<S03lj9`0m=Q`0
?cPN048k8@16?bD0B44W0`1:@bT304]1:0@0BT0W03H0BClV04Lm8P1;@2@0Cd@X05E7:P1GB2T0ETHU
05I38P1D@B00D3lQ05A18@1F@b<0FTHU05i79@1OAb<0GdDP05i47`1OCBL0H4hV06=@:01XDRT0K5D[
06mH;01bFR`0Le/]085R;023I2h0Q6Hb08=W=@20ISD0NV8b07IN;P1bG2d0M6Hi07AS>01aGcL0KUXe
06iG=`1]DcP0KU8j06iB?01ZEcT0JePh06aH=@1`FS40LUd`07EO;@1gH2X0N68Y06eI901_FbH0M5lZ
07UR;P1mHc0207mS<@0A085S<@1fIS<0MVHc07ES=@1eH3D0Le/e06mG=@1]DS@0Je0c07eL9`21H2X0
R6D]08m[;`2EKc00VG8_09Ub;@2JLR`00P2QN3X03`2RNCL0Xg/f0:In=P2ZPcH0[XLh0;2:>@2]Rd`0
[8Y;0:^9BP2YQdP0YhE60:B2@`2QOd00X7ho0:N3A`020:B0A00=0:N3A`2/R4`0[XY>0:^7B`2XQ4P0
W7Q409ejA02NNdD0X7e50:>0AP2XQTT0[8Y;0:j<C@020;B=BP0?0:n8A`2ZPd80Z8120:R0@`2VOT<0
XWU109ie?@2HNS`0TG4d08YX:`2<IBX0TfT_09]^=@2PKcL0Wfhf0080WWLn1@2ON3l05`2NMch0UVT^
09M]<@2ILC@0VGDg09Ig=`2BMSD0S7<a08Ub;`2<KCH0TW<l09Qi@P2INT<0UWM009=d?@2BLc`0Tg@m
09eh@`2LMd80VgI109Ud?`2HLch0Ug8m0080UW4l0P2ILRl0102JLc00Vg@a09]d<@2LMC8209ef<`08
09]c;P2LM2l0WWHa09mg<P2PN3<0WgLb09if<@2MMC0209]d<@<0W7Db0`2MMS<00`2JLS@0Vg<e09ad
=P0209ad=P0309Yb=02HL380Ufla0080UWD`0P2EM2l309Ac;P0:09=b;@2CKc<0Tfle09=_=@2CKSL0
TF`g08iY=@2;IC@0RF<b08AS=P<0QF@g0100Pf8e085P<`1nGC00O5/^081J<`20FSD0OeTe07eG<`1l
EC@0Ne@e07YC=P1iDSD0Me<_07UE<@1kEc<0OETe0P1nFSH01`1mFCD0O5Pd07YU;P1jIBh0NVD`07YT
<P1iHc800P1iHc@01`1iHSH0OFT^07iX;P1mIbd0OfH]081V;@22IBd00P22Hb`04@1fH2l0N68a07]U
=01lISD0NV@c07IP;`1aFbX0KELV07=Q<`1bH380L5db06eJ<01XEBd0HdlZ05i:9@1KAb@0I4PS0080
J4`W01`0K50[071D;`1aEC00KU8]06Y>:@1WBbH0GdLQ06188P1SBbD0IThX06YB;01/E2h0KUH`06mG
<@1/Cb<0L5<W07EH;01iG300NUda07UL<01fFBd0M5L[07MR;@1hHbh0NF@_07YU<01kIS40OFPc0P1n
JC@0601nHS00P6@b089V=023IcD0PVHd07mS<@1jGR`0N5`Z07UP:P1hGbT0MedZ07IL:`1dFBX0LeP[
079G:P1aER/0KUTT06eH8`1[EB<0JE<R06I@8@1TCB40HT/Q065:80P0GdhR0P1MBRT605i;:P08069:
:01SBbL0I4`X06I>:01XDBP0JU<Y06]D:01/EBT806]D:P80LU`Z00<0LE/Y071J:01_FBL00P1^F2H0
0`1]EbD0K5D/06eF;@0206eF;@0406]D:`1XDBP0I4dT069;8PH0HDXX0P1PBBL03P1J?b40Fd0R05e4
9@1MARH0FdLV05Q5901E@R40DT8P0514701@A1h0CT8L04e07@1;?Q`0BC`L0P17>A`04@13>B00@SLQ
040e7`0m<Qh0>RlM03L[6`0e:A/0<bLI02@T6P0S8aT08B8J01hQ600K81T06AhH01LM6@0F71P06Q`K
00806A/J00<061XI01LI600F61L00P0E5aH901HH5aP05AHH200D5AL801DF610051DG200E5QP3014G
5`<04QPH0P0C6AT@01DF60P05ALF200F61L801LI60P061PH0P0H61H201TI5`806QXH0P0K6aT301XJ
60<06a/I0P0L71X801/K6@T07QdK200K6aT301XJ60<06a/I0P0L71X301/K6@8071`J0`0M7A/201dN
60807QlI0P0O81X2020Q6`<08B4I0P0R8QX302<S6`P0;2HJ00/0;R@J02dS6@0/8QP0:b4G02`R600_
9A/0<BLM03<Y7`0c:Ad0=2XN03H/800203L]8@0303H/800d:Qh0<bTM00P0=2/J0`0f:QX203DY6@<0
=2PH0P0i;1`203X]7@@0>bhN00@0=bXI03P[6P0h:aX0>2/J0P0i;1/203X]7008044_8@10;R00?RdM
03d/6P0m;1P0?blH044a6P12<QT3048`6P80@c4K0`14<Q`01010;QH0@S0H04@b6P16=1`304Pf7P05
04Le7@19=Ad0BCDM04Xf7P1;=al00P1<>20204di8@0504`f8@1==b80CCLR04hh8`1?>B@00P1@>RD0
3@1A>bH0DS@J05<e6`1D=Q`0ESPN05Pj801J?280FcdS05`n901I>b40FS`R05/m8`1L?R@00P1K?B<0
0`1I>b40ESPN05Dg7@0205Hl8@80EC/P00D0E3XO05<i7P1B>1d0DSPM058h8@03054g8080D3HO0P1?
=Ah204Hd7080AcDM00`0B3HN04Tg7`1:>200BSPP04Lf701;=ah0CCTP04li8@1B>R80DSPQ054e7`1@
=1h304Tg8@80B3HP0`17=Al804Dc7@0304@b6P15<a/0AcDM0080AcDM0100AS@L04@b6P13<AT0@BlG
048`6013<AT0AC<K04Pf7P1:>200BcTQ04`j8P1:=1`0C3HN054i8@1E>b@0F3`V0P1K?2L00`1L?2L0
EcTO05Li7`0205Pj80@0FC/Q0100Fc`Z05Xk9`1H>BD0ESLR05Li8@1I>b40G3hR05i0901@?Al0DSlO
05I18P1KA2@0GDDS05i68P1NA1l0GD<N0P1YB2D0101ZBBH0JdXW06a;:01]C2T206i=:PP0K4hZ00<0
LU8[075A:P1`D2T00P1`D2T02@1bDR/0M5@]07EE;P1kDB/0NE8[07QB:`1eE2/0LUD[075F:`0206iG
:`0A07AC=01cDS<0L54b06iA<@1[DC00JE4_06Q@;P1VCbd0Le8c06i=;P1XAbP0IdHW06U8:@1[BR/0
JDPY06I59P1Q@RD00P1R@bH01P1SA2L0HD8U05m08`1O@2<0G3dP05Xk7P80GClS0140G3hT05`n9P1K
?2L0Fc`X05Xk9`1J>bT0DcPK05<j701C>al0D3`Q04`l8P19>b40A3XQ048h7`1;=al0C3PP04hj8P02
04lk8`0404hj8P1<>200BcLO04/i8@80C3PP00H0CCLP054h8P1D>B@0F3`W05Tm:01K@b4205a48P05
05e58`1NAR@0GdLU06189P1QBBL00P1YB2T01P1YB2L0JTTV06];9@1]CBH0KdlX071@9`<0K4h/00D0
KDl]06i@;P1_DBl0L58`075C<@0207QH;`80NET`01D0Ne/b07aL<`1mGC@0OUhe07eF;`1lEBh0N58[
07AA:@1bDBP0LE4X07=C:P1bEB/0MTl^079>;01_BbT0K4XW06Y99P1YBbL0JDdX06Y>:@1VAbP00P1U
ARL00`1TABH0Hd@U0693900206528`<0GTLU0P1MAR@305a58`80Hd@U00@0I4DV06E69`1VAbP0ITLX
0P1WB2T806538@80HdDY0P1RA2P306539`0706129P1NAbD0GTLU05m79@1OAB@0HD@T06528`0206=2
8`0306199`1NAbD0G4DS0080FT<Q00/0Fd@R05a58`1MAR@0Hd0R06A18`1UA2D0Hd@U06959@1NA2<0
Fd4P05U17`0906E9900@06e=9P1/C2D0K4`U06a<9@1]CBH0KdlX075A:P1cDb`0Le4[079@:P1bCbL0
LdhT07A?8`1gDB@0Ne8T07eD9P80MDlZ00H0M4hY07==:01dCRT0MU0[07QB;@1iDbh407QB;@@0NE<^
00@0NePb07UF<01gE2h0ME8/0P1dDB/01@1eDR`0MU<]07mJ<01nFBl0OEP^0080O5L]00<0OEP^07iI
;`1oFS000P21G2l3081K;P<0OeX]1`1kF300101jEbl0LE4X07=C:P1eEB`307MG;P0307EE;01dE2/0
L5DZ0080L5DZ:oooool002[ooooo402LLT00302ULT<0XW920:5a@@2PLT40Wg=20:1fA02QNDH0XWY7
0:EiB02SMdH0XGE409mc@P80WW910P2OLd8309md@@<0WW=00P2MLSl20:9hAP80XGM50P2PMT@209me
@`80Y7I500<0XWI50:5gA@2OMd@00P2MN4@00`2LN4@0WgE309me@`0609me@`060:=jAP2RNDD0XWU5
0:5hA02PMd<0WgI20P2NMD40102JM4D0VgE609]eAP2LMTL209]eAP0409UcA02FL440UFm0099`@080
TFlo00<0T6hn08m]?@2>K3`00P2=Jc/0102AJDD0SFE108YR?P2:HSh208aT@00308QP?024G3P0Oe`d
00@0OU/c0`1mFS80201dDB/0ME8/07MD;P1hEBl0Me@^07IC;@1dDB/0Le0Z0P1bCbl03P1`Cbh0KDl]
06a?;@1YCb`0J4h[06M?:`1ZCB/0JD`Z06Q;:@1VBBL0IDPV06=6901RAB<0HD@R0`1RAB<206=690<0
I4LU0P1XC2L03P1YBbL0K4/X06i<:@1bCR`0ME4_07UB<@1eDBl0MU8`07MC;`1iES00NeP`07eJ<01n
Fc40Oed`0`24Gc8208EP<`<0QV4d00@0RfDf08aV=`2<ISL0SFLh0P2>J3T208mY>P80SFLj0P2>J3/2
08mY?080T6Xm102?JCX408iX>@0C08mT=`2@ICP0TFHi099W>P2DJC`0UFXm09I[?P2GK3l0Tfdn099/
?@2@JS/0SVPi08eW>02>J3T0SfTj091Z>`2CJ3/0TVLj095V>@02091U>006095V>@2BIcX0TfPk091Z
>`2?JCX0SVPi0P2=IcP00`2>J3T0SfTj091Z>`03099W>P<0TfPk0P2DJC`00`2CJCL0U6Xh09I/>P02
09M]>`80UV`j00<0U6Xh09=Y=`2FJch01`2FJch0402@JcL0TVdi09A_>`2EL3`0UW4m09E`?02DKc/0
Tfhj09I/>P2GKC/0VFlm09Y`?P2KLCl0VW0n09U_?@2HKS`309Qc?080Ug8k0`2FLCX209E`?080U6lk
0P2CKSX2099]>@80U6Tl0P2CJ3/3099W>P07095V>@2@JS/0T6Xk08mY>P2>J3T0SFLh08aV=`0208]U
=PP0RfLg0P28I3@01P29ICD0RVHf08]W=`2<J3P0SFTi08iZ>P@0SFTi102<J3P01P2?JD80SfY008mZ
?P2?JSd0Sf/i08m[=`80Sf`d00<0TFdm091/?02>JSX00P2=JCT08`2>JSX0T6`l095]?@2<JSX0SF/k
08i/?02?KCd0SV`l08e[>`2;JCT0RFLg08i/?02=Jc/0S6Xj08YX>028ISH0QV@d08AR<P23HC40QF4_
08=Q<@22H300P60a07aM;`1gFRh0LUL/071E:P1UC2d0I4//0619:P1MABT0Ed8W05<o9P1>?B<0CC/S
0080A3PR00H0A3TU044i9P0o>2D0>cHS03Ld8`0e<R4202l`8P0402h_8@0];R00;2dO02//7P80:R/M
00H0:bTL02/Y7@0X:1`09BLL02@U7@0R9Ah201lT7P0301hS7@0N8AX07R4J00H07R4J0P0Q91/6020S
6P0602<W600S9aT08RHH024T6@0P8aX07b8K0P0N81/301dO70<071hK0P0K7AX03P0M7Ad07AdK01hN
700N7aX07b0J020Q6@0P8QL08B<H02<U6P0T9QT09RHJ02XX6`0]:Q/0;R/J0P0b;AX04`0l;al0>bhN
03T]7@0f;Q/0=RlL03Ha6`0f=1d0>3HO02h]:00/:bH0:2PP02HV700V9QX09bPJ02X[6`0/;Ad0=2lL
03D`7@0g<Ql00`0i=240800h<b00=c8O03D`7@0f<Ah0=c8O03Pc800g<Ql0=C0M03<^6`0b;AX0=blR
03D]800b;1h0;R/L02`Z6`0Z:a/0:b`L02/^7@0Z:R00:BTO02LW7@0V9Q`09BDK02HV700W9ad0:2PN
02XX6`0Z:1`09bLK02DW700T9Ad08RDN0P0O91h2024T7@<082<L0`0O8Q/401dP6@@071lH01`06b4E
020S600R9A`08B8J01lN6@0P7AP09B0M02TT8@0[9b@0;bPR03H]7P14=Ah0Ed<R06aD:01nHS00Rf`f
09QaAP2ELD40Sfll08E[>01hHcH0IU<b0591;@16=RT0;2lX02X]9P0X:b@09RTR0P0U:24302HY8P80
92LP0`0U:24302HY8P<09bXQ0P0X:b8302T/8`80:2/R00<0:BXR02/[8`0]:R<00P0^:B<03P0`:B<0
:2XO02/]800_;b<0<S0S038_800e<R40?CPU048m:P0o>1h0@CXP04@m8`17@2H0BD8X0`1:@bT204a2
:@80Bd4X0180BT0W04To9P19?bH0B3hU04Lm8P1:?b<0Cd@X05A6:@1GB2T0EdLV05M48`1E@R40ETDW
05U69P1LBBT0Gd/Z06=<:P1TC2P206A:9@0F05m=9`1PCRH0He0X06QB:@1]ER`0LET]07=K;@1fFbh0
OUh[07mQ;@22I380PVHf081U=P1kHcD0Mf4b07EN<P1`HCH0L5ld06eK<`1[Ec@0K5De06aB=`80KE4i
0400JUDf06]G=P1_FC@0LE/b07AN;`1fH2h0NF8/07YT:`1fIC40NFDb07]W=01mIcD0OVLe07mU=01o
Hc<0OV8b07IV<`1eIC@0M68d07=N<`1bFS@0LELd071F=@1aE3H0PF0[08=R;029IRh0Sf/_09I`<@2J
Lc00W7D`09if<02SNcd0Xg`k0:=l>@2UOST0Yh4h0:^5>P2_RS`0/H`l0:j<C@2/RT/0ZXQ90:R6A`2V
Q4D0Y8930:>1@P2RP440[8Q<0:V5B@2XQ4P0ZXI:0:f9C@2/R4`0YX960:5m@@2IM3l0VWE009ag@02O
Nd40Xgm30:R4B02]RD/0[h]=0P2aRTL03`2]QTD0Z8500:In@02VOT40Y7a109mf?P2KLSX0V7Pk095a
=02<J2`0SFH[09=Y;`2IK3<0W6de09i]=@0409ef?@@0W7Dl00d0UF/a09I^<`2HLCH0V7@h09Ee>02A
LcD0SG4b08U`<02<KCH0TG8k09Mh@@2HND80UGHo0080TG8k00D0TW<l09]f?`2JMCh0VG@m09Qc?002
09Mb>`80UW4j00<0VW<b09]d<`2KM3<00P2LMC@209ef=@0909ig=P2LMC00WGHa09mh<`2PNC@0XGXe
0:1i=02ON3<0WWLb0080W7Dd0P2MMSD309ig=P0309mh=`2OMcT0X7Pj0080XGTk00@0X7Pj09if>02L
M3H0VW8d0P2GLcD309Ib=0<0UG4c0P2DL3@01`2ELCL0U6lh099]>02?JSH0S6Lc08YT<`25ICH00`26
ISL01025ICH0PV8c081P<@1nGRl208=N<@03089M<@21G380P5Xc0080OeTd00D0OeTe07UF;01kF2h0
OEX`081M<`03089O=@06085N=01kI2h0Nf@^07]T<01kI380Nf<c0P1jHS@01`1jHSH0O6L^07eW;P1m
Ibh0OfH^081U;P22I2h00P22Hbd04@1jHS80Nf<c07aT=01mICD0Nf<c07QP<01dG2`0LUXZ07=Q<`1b
H380LEhc06iK<01YER`0I54Y061<9`1MBB@0Id/V0080JDdX0180K50[06iB;@1_Dbh0KE4/06]?:P1Y
CBP0HDTS069:901SBbD0IDdW06M?:@1YDB/0K5@^06eE;`1^DBD0L5<W07AG:`1gFRh207QK;`0B07II
;@1eF2`0N64]07QQ;@1iHRh0Nf@`07aU<@1mIS80OVLc07mX=01nHS00P6@b089V=023IcD0PVHd07mS
<@1kGbd0N5`Z0P1iH2X03P1hGR/0MU`[07EJ:`1cF2/0LULZ079G;01_FRD0KUTT06aF901ZE2<0J58S
06E>8P1TCB<0Hd`R201OCR8205e::@<0GT/Z0`1OC2/0201VCRX0Idl[06Q@:P1ZDbX0K5D[06iG;@1_
F2`0L5T]201]ER`3075K:@<0L5XX0P1_FBL206eF;@0606iG;P1]ERd0Je@[06QA:01UCRD0Hd`S101R
BbT4065::00P05e2901N@bD0GTDV05e69P1KAbH0FDHU05M48`1EAB<0DTHN05557`1@A1h0CT4N04`o
7@1:?Ad0BC/N04Pj7@14>R40@cTP040e7`0n<al0>c0N03P/700f:QX0=2PJ02LU6@0T91X08b<I020Q
6@0M81T06QlI01PN6P0G7AT201XL6`0401TK6P0H6QT05aTH01HH5`805ALF2@0F61LH01DF60P051DG
200E5QP@01@E5`P05AHH0`0A5aL3018H60804aTI400E5QP801DG5PP05QPG200G6AP801PH608061PF
0P0I6AL201XJ60806a/I0`0J6QP301/K6@8071`J200K6aT901hM6`P06a/I0`0J6QP201/K6@<071`J
0`0K6aT201`L6P<07AdK0P0M7QP201hO6@807b0J0P0P8A/3024Q6@808R8J0`0S8a/802`V6P0;02hT
6P0]8aT0;28H02`R600]8aT0;bDK034W7@0c:Al0<RPL03<Y7@0e:al00P0f;2000`0e:al0<bTM038X
700803@[6P<0=RXJ0`0e:AT203@X6080>2/K0`0i;1`303X]7@@0>2/J0P0i;1/203X]7008044_8@10
;R00?RdM03d/6P0n;AT0?blH044a6P12<QT3048`6P80@c4K0`14<Q`01012<1P0@c4I04Dc6`17=Ad2
04Pf7P0704Le7@16=1`0BCDM04Te7@1:=Qh0BcLO04`h800204di8@0404hj8P1>>2<0CSPS04hh8`<0
CcTT0P1@>RD02P1D=Q`0ECLM05Hh7P1G>Al0F3XP05Tk8@1J?280FcdS05Xl8P1K?B<405`n900405Xl
8P1H>R00ESPN05Lm8P80ES`Q00<0EC/P05@j7`1C>Ah00P1B>1d2058h8@80DCLP0`1@=Ql00`1?=Ah0
BCDM04Te7@0304Xf7P<0BcLO00P0AcHL04Xf7@1<>1l0CcTQ058j8P1B>240DSHP054e7`<0BcHQ0P1:
=B0304Td7`P0AC<M0P16=1`03017=Ad0B3HN04Le7@15<a/0@c4I048`6013<AT0A38J04Dc6`16=1`0
AcDM04Tg7`80BSPP00D0BS@L04`f7P1A>B40EC/T05Pl9P0205/l9`0305/k9P1G>Al0EcTO0080F3XP
0`1I>b404@1J?280FS/W05Xk9`1I>RD0FC/S05Tk8@1J?200G3hR05e08P1A?R00DSlO05I18P1KA2@0
GDDS05m58P1NA1l0H4@O0080JTTV0P1[BRL206a;:080KD`Y201^CBX00`1bDR/0LE4Z071@:@02071@
:@03079B:`1dE2d0MED^0080NE8[01/0MU<[07ED:`1bEB/0LEH[06mG:`1^Eb/0ME8d07AC=01cDS<0
L54b06iA<@1[DC00JE4_06Q@;P1dDc@0Kdh_06U8:@1XAbP0JTTZ06a;;01ZBBX0IdHW0611901Q@RD0
HT<V06=49`1R@bH00P1P@B@05@1N?b80G3dP05i18`1M?b<0G3hR05/m8`1J?2@0FCXU05Tj9P1H>BD0
E3TL05<j701C>al0D3`Q04dl8P1:>R40ACTQ04@h801:=Qh0BcLO04di8@0204hj8P0404di8@1;=al0
BSHN04/i8@80C3PP00D0CCLP054h8P1D>B@0F3`W05Tm:00205]1800605e38P1NA2<0H4HU06579P1R
B2L0HdTX0P1XAbP01P1ZBBP0K4/X06e=9`1^CRL0KdlX06m?9P80Kdh[00@0L4l/075@;@1bDBh0Le8_
0P1dDc0307UI<00307YJ<@1kFc80Ne/b0080O5`c0100OEH_07]D;@1hDR/0M54Y079A:01aDBP0LU8Y
075D:P1fCbh0LTh/071<:P1]BbP0JdXW06U;9`1YCBP0JThY0P1VAbP01P1UARL0I4DV06=49@1SA2D0
HT<T06528`D0GDHT0`1NAbD206=49@<0I4DV0`1UARL806538@<0HT@X0P1Q@bL306129P80GDHT00@0
GTHT05m5901QA2@0HT<T0P1T@b@00`1OB2H0GTLU05a58`0305Y38@0:05a58`1MAR@0I44S06E2901U
A2D0Hd@U06959@1NA2<0G48Q05Y28080I4PS0P1UBB@206I:9@<0Id/V0P1]CBH206a<9@0D06e=9P1_
CbP0LU8[07=C;01dDR`0Le4[07=@:01dCbD0ME0T07QB9@1lDbD0OUDW07QB;@1gDB`0MU0[07E?:P1f
D2/0N58]07YD;`1kEC0507UC;P<0NU@_00@0NePb07YG<@1hEBl0MU<]0P1eDR`207IC;@0307mJ<01n
FBl0OEP^0080O5L]00<0OEP^07iI;`1oFS000`21G2l2081K;P<0OeX]00<0O5Ta07]H<01kF3000P1j
Ebl307UF;P08075A:01cDbX0MED/07IF;@1gEbh0MUH]07EE;01dE2/3075F:b_ooooo000Zoooooa00
W79000/0Y7520:5a@@2QLD40X79109mc@P2PMT@0XWY70:=kB02TN4L0XgM60:5eA00209mc@P0309ib
@@2OLd80Wg=200<0WW=00`2OM4420:1e@P80XWQ60P2QMdD20:1fA080WgE30P2SMD@00`2QMD@0X7I4
0:1hA@0209iiA@0309eiA@2PMT@0X7I400H0X7I40P2RNDD0102QN4@0X7M309mf@P2OMT8209ie@@04
09Qb@`2ILd@0VWA509YdA@80VG=400@0Ug5209E_@02DKSl0U7100P2CKcl00`2BKSh0TFdm091/?002
08m[>`04095Z@`2=ISl0RV<l08YS?080S6Dn00<0R64j08AM=P1oG3@00P1oG3@01P1nFc<0OEXb07eJ
<P1mFS80O5Ta07MD;P80N5D_01<0NEH`07QE;`1gE2h0ME8/07AA:`1eDS80M54a079A<01^D2h0Jdh/
06M=:P1UBbP0Hd/W06]>;01ZCB/0JD`Z06Q;:@1WBRP0IDPV00@0I4LU0P1UB2H306I99`0A06M::01[
CbX0JThY06Y<:01/BbP0KT`Y075=:`1dD2h0Me0_07A@;01eDBd0MU<]07QE;@1jEbd0O5X]07eK;P1n
G2h00P24Gc8208EP<`<0QV4d00T0Qf8e08YT=@2:I3D0RfDf08eW>02>J3T0SfTj091Z>`2AJc`00P2=
IcX208iX>`80SfTl0P2@JSd408iX>@@0SfTj00D0TFHi099W>P2BIcX0TVLj09=X>`0309AY?00;099/
?@2AJc`0SfTj08iX>@2=IcP0SVPi08mY>P2@JS/0TfPk099W>P2AIST00P2@ICP01P2AIST0TVLj09=X
>`2=IcP0SVPi08mY>P80T6Xk00<0SfTj08iX>@2=IcP00`2BIcX309=X>`80U6Tl00<0TfTg09AZ>02E
JcT00P2FK3X209E[>@0309AZ>02CJCL0UV/n00L0UV/n00/0T6/g099]>@2DKc/0UG0l09Ia?@2EL3`0
U6lk09=^>P2EJcT0Ufdk09Q^?00309Y`?P0309U_?@2HKS`0Ug8m0080Ug8m0P2FLC`309E`>`80UG0l
0P2DKc/209=^>P80TVdi0`2CJ3/2099W>P<0TFHi202?JCX808YV=P80R6@d00<0RFDe08YV=P2;IcL0
0P2<J3P908eY>@80SfXn00<0SfXm08m[>`2?JcT00P2?JcL0102?K3H0T6`l08m[>`2>JSX208eY>@04
08iZ>P2?Jc/0T6`l08aZ>P80SF/k00/0SV`l08e[>`2<JSX0RfTi08YX>02=Jc/0S6Xj08]Y>@29IcL0
QfDe08IT=00208AR<P0@08MS<`25Hc<0Q68d085P<`1nGc<0N5/a07=G;`1aEBd0HDPY05m8:01MARL0
FD@W05I29`1B@BL0CclU04lo9P80A3PR00H0@cPT040h9@0m=R<0>3<P03<`7`0a;Qd202d^800302`]
7`0[;1h0:R/M0080:BXL00L0:2TK02/Y700[:Ad0:2PL02DW700T9Ad08RDN00807b@N00<07R<M01hQ
6P0N8AX01P0N8AX3020S6PD08B@K00H092PI02@X6P0S9aT08RDJ028U700Q91d2020R7@<07AlL0`0L
7Q/201/M6P0T01dM7@0M7A/07QhL01lP6`0P8A/08B8J024S600R91T09RPK02PX700Y:Q`0;B/L030]
700d;a`0=RlM03L`7@0o<R40?S4P03`a7`0i<Ah0>34N03Lb7P0f=1l0=cDP02`[9P0[:RD0:2PP02HV
700V9QX0:2TK02//700];Qh0<RdJ03@_700f<Ah0>3<P0P0j=B8203Td8@80=2lL0`0e<1d03`0d;a`0
<bhK038]6P0h<2<0=RhQ03<]7`0_;1d0;B/L02//700/;Ad0;2lN02XZ800Y:Al0:2PN02LW7@0202HV
700802LW7@0X:1h0:RPK02TW6`0W9a/09BLL02@U7@0R9Ah201lT7P04024T7@0P8a`082<L020S7080
7b8K0P0N8AX801dP6@0L01`O5P0P8aX08b@L02<S6`0R7aP08QdG02@O6@0Z8ad0;2@I03@[7013=R<0
EdHZ06aF<@1nHcP0Rfdk095b?02BKdD0T6m208Q[?`1iHSH0I58/05109P11=2<0>2hR02/^9`0Z;BH0
9bXS02HY8P809BPQ0`0V:B80100T9b009BPQ02DX8@0U:24202HY8P809bXS0P0X:b8202T/8`80:RdT
0P0[;RD202LZ8@0302PY8@0Z:R80;2TR0080;RTS00h0<2TS02PZ7@0];B40<C8T03Dc900g=2<0?3LT
04<l:P19@Rl0@CXP04<l8P16?bD0BD8X04Y3:@<0Bd@Z00H0CT@[04e3:P1<@RT0Bd4X04Y09`18?RD2
04Lm900>04Hl8@19?R80CT<W05=5:01GB2T0F4PW05U69@1HAB@0G4/]05m<;01QCRh0I50_06QA;`1Y
DBd206Y@:`0P05m;9P1QCRH0IDlX06YC:P1^EB`0M5T^07IK;P1iG300O5h/07iP;P1nHS80Of@e07eU
=`1jHcL0MV4f07AO=01YFS40JEL_06QF<01WDc00JE8b06YA<`1/DCH0KE8g06eE<`1^ES80LETc07=L
<P1fH340N68`07YU<01kIRl2081^?P0F085/?@21Jc`0P6Pj081U>01mHSD0OF0d07MU=@1eHc<0Leha
079K<@1bFC40METd07MK=P1iFcT0QfHa08QW<@2<JC40T6``09I`<@2LMC80X7Td0:=k=@80Yh0o00X0
Yh0m0:V2?@2[QCh0[XPo0;6;@P2bS440[he>0:b:B`2YQdP0YXA50P2TPT<20:F3A0030:j:CP2/R4`0
ZhM;0080[8Q<00/0Z8A809mk?`2HM3P0U6lj09Ia>P2HLc`0W7Pn0:5m@@2XQ4H0[HY:0;2=C@020;29
AP0=0:b5A02WP3l0YWi00:In@@2TO440WWDm09Ya>@2KNC`0Ug<g095]<@2AJRl0U6`a09Q^=00209]^
=@80VG@m00@0V7<l09Mb>`2FLCX0UW4j0P2EL3T03@2FKS<0UVld09Ib=P2GLcL0Tg<f095a=02=Kc40
RVh_08a[=@2AL3X0UWDo09Mf@02CLS`00P2@KcT00`2AL3X0Ug8k09Mb>`0309Mb>`80UW4j00<0UG0i
09ad=P2MMCL00P2MMCL309if>00409mg>@2NMc@0X7Tf0:5j=`<0Xg`i00@0XW/h0:5j=`2NMSP0WWHh
0P2OMcT30:1h>P030:5i>`2TO3h0YGdo0080YGdo00@0Y7`n0:9j?02OMcT0WWHh0P2HLc`209Mb>`<0
UW4j00T0UG0i09Ib=02FLSH0Ug<g09Ib>02DKcP0TF`g08iY=@2<Ic<00P28ISH308UW=`0408MU=@25
Hc<0Pf4a08QU:`80R6D]00<0Qf@^08MS;`27Hc400P27Hc<01@1oGRT0PF0[08=R;@25I2l0QVD`00<0
QfHa0P1nIBl00`1nI340OF<b07eR<`0207aQ=00707aQ=P1kIRd0O6H]07aV;@1nIBd0Of@]089T;P02
08=T;P80P6He00H0OfDd07iT<`1mHc80Nf4`07YP;`1iGbh207EP<@0607AO<P1aG340KUP_06UC;01U
CbP0HT`W1P1/D2/306]?:P0=06I>:01TC2H0Hd/U069:901SBbD0IThX06Q@:P1ZDR`0Ke8V071C9`1b
EBT0LeHZ07EH;00207II;@0707MJ;P1iGb`0NV0]07]Q;P1lHRl0OF<`07mU<P02081V<`0H07iR<01o
Hc40PFDc089V=021IC<0Of<a07aP;P1iGB/0NV4[07UP:P1hGR/0Med/07EJ:`1dFB`0LeP[079G;01a
G2L0L5/V06mI9`1/ERD0JU@U06QA9@1VCbD0IDhT201PCb<405i<:080GddY00X0H4hZ065?:`1ZDRh0
Je<]06aD;P1^Ebh0L5T_079K;`1cGBh0M5h_201aFRh2071J:0<0LE/Y0`1bG2X306mH;P0506iG;@1/
EB/0JE8X06M@9P1UCR@00P1TCRT206==:080HT`W0P1QBbH0801SBBP0HTPW05m79@1MAR@0FdLT05Y8
901KBBD0FDTU05I88@1EAb80DdDP05948@1@@B00CSlP04dn8@1<?B00AC/P04@j8@12>1l0?c@N03`a
7@0i;Q`0=b/K03HZ6P0Y9aX0:2HJ02DU6@0R91T0824I01dP6@0J7aT06AhH0P0J71/00`0I6aX061XI
01LI600201HH5`0301DG5P0F61L05QPG00L05QPG600E5QP801@E5`P05AHH400D5AL801DF60<04ALG
0`0B61P201<I6A005AHH200E5aH801HH5`P05aTH200H61P201PH5P806ATG0P0J6QP201/K6@<06QXH
0`0K6aT201`L6PP06a/I2@0N7A/801/K6@806QXH0P0K6aT301`L6P0401dM6`0K6aT06a/I01/K6@80
71`J0`0M7A/201dN60807QlI0P0O81X2020Q6`<08B4I0P0R8QX302<S6`P0;2HJ0P0^91X202dS6@07
02hT6P0`9Q`0<RPN03<Y7`0c9a/0=2PL03HZ7P0203L[7`0303HZ7P0d:1`0<bLK00X0=b/K0P0f:QX3
03DY6@0403@X600g:QX0=bXJ03LZ6P<0>2/K0P0i;1`303P[6P80>B`K0`0j;A`02010;R00?bdO03l^
7P0n;A/0?bhJ040`6@11<AX0@S8I0`13<A/204@b70<0AC<M00<0A38J04Dc6`17=Ad00P18=Qh01017
=Ad0AS@L04Dc6`19=Ad204Xf7P0304/g7`1<>200CCTQ0080CSXR00@0DcXT058i8`1B>B<0DSTS101A
>28305Li7`80F3XP0P1I>b400`1J?280FcdS05`n900405do9@0305/m8`1J?280FC/Q0080EcdR00<0
ES`Q05Dk801D>Ql00P1C>Ah00`1B>1d0DcTR058h8@02058h8@80DCLP0P1@=Ql204`h80<0BcLO0`1:
=Qh01P16=A/0BSHM04/g7P1>>200DSXR05<i8P80E3PR0`1<>20204/g7`<0BSHN2016=1h02017=Ad0
B3HN04Pf7P18=Qh0AcDM04Dc6`12<1P0@BlG0`16=1`204Le7@<0B3HN00D0BS@L04`f7P1A>B40EC/T
05Pl9P0205Xk9P0405/k9P1H>R00F3XP05Pj8080FC/Q0`1J?280401I>RH0FS/V05/l9`1L?RH0GClU
05`n8P1L?b40FchP05@o8P1E@240FD8S05a3901NA2<0HD@R0655801RA20406]:9`@0K4/X201^CBX0
0`1bDR/0LE4Z071@:@02071@:@04079B:`1dE2d0MED^07UC;080Me@/00<0MUD/07EE;01cER`00P1b
Eb`207EB<P0807=B<@1aDc40Ke8`06aB;`1[DBh0JU8^07ED<`1`Cbh206]::@0806e<:`1^CB`0JdXY
06Q79P1P@B80HD8S0693901SA2D306939080H44R0100Gd8T05i18`1M?b<0FcdS05Xl901H>B@0EcPS
05Hg8`1C>Q`0E3/M05@l801B?B80D3`S04`j8P19>B80AcLP0P1:=Qh0101;=al0C3PP04`h801;=al2
04Xf7P0H04/i8@1<>200C3PP04dg801A>280E3TT05Pl9`1I?BP0FchN05`o7`1M@200Gd8R06959@1T
AbL0IDPX06I9:@1UA2D0J4LX06]::@1^CBX0L50Z06m?:01^CRL0KDdT0P1aD2d00`1bDBh0M5<`07ED
<@0207ED<@0407IE<P1jFS40NUXa07YJ<@@0Ne/b00l0NUXa07aE;P1kE2d0N58[07AA:@1cDRT0LE4X
079B:@1`DbT0MTl^07=?;@1aCB/0KddZ06e<:@1[CBT00P1ZCRT206M8:@0406I7:01UARL0I4DV06A5
9P80Hd@U0P1MAB<0101NAR@0GdLU06189P1PB2H206599`<0I4DV0`1SA2D2069390P0HT@R0`1Q@bL2
06129P<0Gd4U00/0Fd@R05a58`1MAB<0GdDT06959@1TABH0ITDV06M69`1OAbD0GTHT05e58`0305]3
8@80G4@R0P1U@R@0301UA2D0Hd@U06959@1OAB@0GD<R05a48P1TAR80IDLS06I8901WBBD0J4XV06U;
9`80JT`X00<0JddY06m?:01^CRL00P1]CBH03P1^CRL0L50Y079B:`1cDb`0M58/07=A:`1dDBT0MU4W
07MB9P1jE2L0OUDW07mF:01kEBh0NU@]0`1iDb`00`1jE2d0O5H_07eG<00807]E;P0407eJ<P1kF300
NEH^07MD;080MU<[00D0Me@/07QE;@20Fc40OeX`07iI;`0207eH;P0407iI;`1oFS00P5/a089M<0<0
PE`_0P20Fbh207mJ;@80OEXb00T0O5Ta07YG;`1iERh0N5D]07MD;01fDb/0LU8Y07=C:P1dE2/00`1f
ERd00`1eEB`0M5@[07EH;P0207EH;R_ooooo000Zoooooa00WG=100P0Xg110:5a@@2PL400X79109mc
@P2QMdD0XWY70:AlB@80XWI500<0XGE40:1d@`2OLd800`2OLd8209ic@080WgA100@0X7E20:5f@`2R
Md@0XWM40P2RN4H20:5gA@80X7I40P2OMD<01@2QLd80XWA30:1d@`2PMT@0X7Q50080WgY600<0Wg]7
0:1fA02PMT@01P2PMT@20:9iA@040:5hA02PMd<0WgI209ie@@80WGA000@0Ug5209Qb@`2ILd@0VG=4
0P2HLT<0102FL440U6ho099/?@2EKd0209A^?`0309=]?P2BK3d0TF/l0080T6Xk00@0TFY108eV?@2:
HcX0RV<j0P2<IC`00`28HCP0Q5dd081M=@0207mL=00307iK<`1mFS80OEXb0080O5Ta0P1jEc4207UF
<00B07QE;`1gE2h0MU<]07IC;@1cD300LTl_071?;P1]Cbd0Jdh/06M=:P1VC2T0IDdY06a?;@1[CR`0
JTd[06U<:P1XBbT0IdXX101VBBL206M::0<0J4/Y0140JD`Z06a@:`1/D2/0JddY06e<:@1^C2T0LDd[
07=?;@1fCbh0M54[07EB;01fDb/0N5D[07YH:`1lFRd0OE/]07iL;P0308EP<`<0QV4d0P27HSD01P29
Hc@0RV@e08]U=P2<ISL0SVPi08mY>P80TF/l0P2=IcX208iX>`80SfTl0P2@JSd408iX>@@0SfTj1@2C
J3/3099W>P03095[?02@JS/0SVPi0080SFLh00<0SVPi08mY>P2@JS/00P2BIcX4095V>@80TVLj00<0
S6Hg08eW>02@JS/00P2AJc`00`2@JS/0SFLh08aV=`03099W>P<0TfPk0P2DJC`00`2BJ3P0U6Xj09E[
>`0209I/?080UF/k00<0U6Xj099X>02FJch01`2FJch02`2@JcL0TVdi09A_>`2EL3`0UW4m09E`?02D
Kc/0Tfhj09E[>@2FK3X0V6hl0080VW0n00<0VFlm09Q^?02GKC/00`2FLCd309E`?080U6lk0P2EL3`2
09A_>`80Tfhj0P2BKCT209=X>`<0TVLj0`2AIST0102=IcP0SVPi08iX>@2?JCX2091Z>`80TF/l202:
ISH00`28I3@0RFDe08UU=@0208YV=P80RfLg0P2<J3P408eY>@<0SVXj0P2?JSd308m[>`<0Sf/i0`2?
Jc/208iZ>P<0Sf/k0`2=Jc/208aZ>P80RfTi01T0RVPh08aZ>P2;JCT0RVPh08UW=`27ICD0QV@d08ES
<`24HS80QF0c08=Q<`22H3<0Oehc07]K<P1eF300L5@/06iB:`1OB2P0GTLW05Y59P1GA2H0DT4U04lo
9@1<?R<0BcdS0080A3PR00L0@SLS03lg900k=240=S4N034^7@0_;1/0;2dO0080:b`N00<0:R/M02TZ
700X:A/00P0W:1X01P0[:A`0:bTM02PX700U9a`092DM028U7P807b@N00<07R<M01lR6`0O8Q/01P0O
8Q/2020S6P@08B@K0P0R9A`01P0U:AX09BTK02@X6P0T9a`08bHM028U7P808B<N0`0M7a`301`N6`80
6adJ02@071`L01dM6`0N7Q`07b0K020Q6`0Q8QX08R@I02<U6P0Z:ad0;B/N02h/7@0a;Qd0=C0M03Pa
7P0j<Ql0>c<N044e7`10<b00?S<O03/c800i<Ql0=c8O03Db7`0e<R40:RTT02TX8`0X:2009bLM02PX
700Z:ad0;2dM02d^7P0b;AX0<bhK03Ha7P0h<b0303Xe8P0303Td8@0c;Q/0<bhK00@0<bhK0P0b;AX0
2@0h<2<0=blR03@^800`;Ah0;R`M02`]7@0];Qh0;2lN02XZ800202TY7`0302PX7P0W9ad09bLM0080
9bLM00P0:BLJ02TW6`0V9QX092HK02<T700Q91d07b@N01hS7@<082<L0P0O8Q/301hQ6P0301`O600M
81T07B0I00807B0I0`0N8AX07`0M7QH08B8J02DU7@0W91/09B4H02HO5@0X8AL0;BDJ03<W4@10<AX0
ED@X06aH=`1oJ3l0S75409=e@`2DM440Rfi408Y^AP20J480K5Pg0592:00m<Qh0<b/N030Y7`0Z;BH0
:B`U02LZ8`0U:24092LP02DX8@0V:B800P0W:R<302DX8@809RTR0`0W:R<0100Y;2<0:RdT02X]900Z
;B@202/^9@80;2lV0P0V:B000`0X:B40:BTQ02`Y8P0202hY8`0=034Z900Z:ad0<BlR03Hd9@0j=bH0
?CPU044j9`18@2d0CDD`04@m8`15?R@0B44W04Y3:@0304]4:P0?04Y3:@1>A2/0CT@[04a2:@1;@BP0
BClV04Pn9@17?B@0AS`S04Hl8@19?R80CD8V05=5:01GB2T0FDTX0080FdPW00H0GTd_065>;P1RCbl0
IE4`06QA;`1ZDRh206aB;@0A069<9`1TCRL0IdlY06aC:`1aEBd0MEX_07QK;`1jGC40OF4b07iR<`1m
HSD0Nf<g07QQ=`1dGSD0LE/b06eJ<P1RDb`00P1SDBd02`1SCb`0ITl_06U@<@1/DC<0KU<e075C;@1b
ERl0METa07MO<`1jHS80NfDc0080O6Lb02T0Ofi007i]?`1nK3h0OVTl07eV>P1lI3P0NV8f07]P=@1h
Hc@0MF0c07=L<01aFBd0M5P`07MK<`1lGcL0Of8j08a[=P2<JcD0SV/c095]<@2HLS<0WgPe0:Am>02X
P3X0ZH=20:V4@02ZQD40[8M30:f8@P2_RT@0/Ha60;:=A`2]Rd`0ZhU:0:N5AP2TPT<0Xh520:B2@`2U
Pd@0YhE60:N3A`020:J2AP0=0:N3A`2XQ4P0Y81409]g>`2DL3@0UFhg09I_=P2ILST0WWLl0:An@02Z
Q4D0/8Y90;>=C0020;><B@0C0:n8A`2[Q4<0ZX940:Z2A@2XP4D0XWU109ac>`2RNd00WgPm09ae>P2J
LSL0VG4f09Yb=`2KLCL0W78h09Ic?@2ELS`0Tg0j095^>003091]=`0>095^>02CKcD0U70f09Ea=`2D
LCL0Tg0f08m_=02=KC80Rf/`08i[=@2CL3X0Ug@n09Ic?@2CL3X2091]=`04099_>@2CKcD0U70f09Ea
=`<0Ug<i00<0UW8h09Ea=`2NMSP00`2NMSP409mg>@0309mi>02PNST0XW`k00<0Y7hm0P2RO3/30:1h
>P80XGTk0`2RNS`20:Em?`80YWi000@0YGdo0:=k?@2PN3X0WgLi0P2LM44309]c@0<0VW8o0180VGHf
09Ue=`2IMCL0VGDi09Mc>@2DKcP0TF`g08mZ=@2<J3@0SFTe08iZ=P2?JcL0SVXf08eY=@2;Ic<0RVHb
08e/9`2>KBX208i/;00408m];P2?KC00Sf`b08m/<P80RVX]00@0Rf/^08YZ;@2:JRd0RFT/0P28J2/0
1@20Ic40OfH`07mU<P1nI3<0OF8c0080O64d00L0Nf0e07YU;P1kI2h0O6D_07iU;`1oI2l0PF<_0080
Pf<`00@0PfTf089X=@20IS<0OV@a101mHc0207IP;`0707IP<@1dGC40LEX`06eF;@1ZDbX0J50Z071D
;`0206iB;@0>06a@:`1ZCRT0JDdX06Y>:@1/D2/0KE4/06UA:`1WCbT0I4`V069:901QBB<0Hd/U06E=
9`1WCbT3071C9`0;075D:01bEBT0M5L[07II;@1hFbl0N5h[07UO;01jH2d0Nf4^07aR;`1nI3400P1o
IC800`1nHS00Of<a085U<`02085U<`0C07mS<@1lH2h0Nel]07]R;01jHB/0NEl/07QN;@1fFb`0MEX]
07AI;01cF2d0LehY079M:01aFbT0KUPW06aF9`1ZDbL0J54W06M@9P08065@9080GddW0P1NC2H0301O
CBL0H4hX069@:P1SDB/0Je<]06aE;01]ERd0KeP^075J;P1cGBh0M5h]07EO;PP0M5h_00D0L5XX075K
:@1aFbT0LU`Z07=M:`0207AN;00907EO;@1bFbl0LEX^071I;@1_F2`0KEHZ06]D:01YDRH0J54U0080
IU0Y00@0IDlX06A>9`1SCBH0HddV0P1RC2D08@1XCR/0IT`Y06599@1NB2<0FdLR05]98`1MBbD0GDhW
05U:8`1HB2@0EdLS05E58`1C@b80DD0R050o8`1??R80ASdP04Dk8013>Ah0@CLN03hc7@0l<Ad0>RlM
03T^700/:1`0:bLK02TW6`0U9AT08B<H01lP600M81T06QlH01/M700201XL6`0301TK6P0H6QT05aTH
00/05QPG600E5QP801@E5`P05AHH400D5AL801DF60<04ALG0`0B61P201<I6A005AHH200E5aH801HH
5`P05aTH200H61P201PH5P806ATG0P0J6QP201/K6@<06QXH0`0K6aT:01`L6PT07QdK200L71X301/K
6@<071`J0P0M7A/301/K6@8071`J0`0M7A/201dN60807QlI0P0O81X2020Q6`<08B4I0P0R8QX302<S
6`P0;2HJ0`0^91X0200_9A/0<2HL034W7@0b:1h0<bTO03<U6P0d9Q/0=RPM0P0g:Ah00`0f:1d0=2HK
03<U6P0803P[6`<0=b/K0P0f:QX303DY6@@0=RTI0P0g:QX203P[6`80>2/J0P0i;1/203X]7080>bhM
0P0o;Al01P0o;Qh0?bhL040_6`11<AX0@S8K04<c6P<0A38L0`15<ad204Hd7P80AcDM0`19=al00`17
=Ad0AS@L04@b6P0204Xf7P0404/g7`1<>200C3PP04di8@80CSXR00D0ES`U05Dk901E>b@0E3XS05<i
8P02058h8@03054g801I>b40FC/Q00H0FC/Q00<0G3hT05do9@1M?bD00`1M?bD305`n9080EcdR00@0
ES`Q05Dk801E>b00E3XO0P1C>Ah405<i8P80DSPQ0P1A=b0204li8P0404hh8@1==b00C3HO04`f7`80
BcDN00P0AcHL04Xf7@1;=ah0CSPP054i8@1D>R<0ECTS05Hj9080CSPP0`1==al304`f7PP0AS@N00P0
B3HN04Tg7`19=al0BCLO04Le7@15<a/0@S0H044_5`@0B3HN1017=Ad01@1;=Ad0CCLO054i8@1E>b@0
F3`V0080FS/V00<0FSXU05Pj801H>R000`1I>b4305Xl8P0@05Pi901J?2@0GClW05m19`1P@RH0GT4S
05`o7`1K?Qh0F40T05U28`1K@R@0GD8T06138`1QA280HT@P06=58@@0K4/X101[BRL806m=:P03079B
:`1aDBX0L50Y0080L50Y00<0LU8[07AD;@1eEBh00`1fEB`307EE;080LeH/0P1gDc40201eDc00M5<`
075C;`1`E2l0Ke<^06eC;P1fEC80LU4^0P1^CBX2071?;00506e<:@1YB2D0HD<Q06538@1RA2801P1S
AB<0401QA2@0H4<S05i18`1L?R80FS`R05Li8@1F>200ECHQ05<l7@1D?Ah0ECdQ05<n8`1B?2@0D3XS
04hh8`1;=R4304Xf7P80BcLO0`1:=Qh0701;>B40C3PP04`h801==b00DCPR05@i901H?2L0FCdX05Tl
701J?Ad0G3lO05m28P1QA2@0I4LW06I9:@1WBRX0I4<T06M69`1/BbX0LE0]079B;01aDBX0KThW06];
8P1cDB`0M58]07ID;`1gEC0407QF<@0307UI<01jFS40Ne/b0080O5`c00P0Ne/b07YJ<@1iFC00O5D^
07]D;@1iDb`0MU<[07AC:P80LU8Y00L0L5<Y07M@;`1dD2h0Ldl]075?;01_CR/0K4hZ0080JdlZ00H0
JDX[06Q9:P1XBBX0IdPY06I7:01UARL206A59P80GT@S00@0GdDT06169@1RB2L0HdTX0P1TBRT01@1U
ARL0I4DV06A59P1SA2D0HT<T0080HD8S00<0H44R06A6901TAR@01P1TAR@306539`80H48V0`1O@BD2
05]48P0405e58`1OAB@0HdHV06E69`80J4LX0P1OAB@205i48`@0GD<R0P1V@bD0301UA2D0Hd@U0695
9@1PARD0GdDT05i6901VAB80IdHS06Q7901ZBBH0K4/X06e<:@<0Kdh[00P0L50Y06m?:01^CRL0KThW
06m?:01`D2T0LU8[07=C;080M58/00@0MU<[07UD:P1jEBT0O5HY0P20EbT00`1oFS00OUT_07eH;P02
07aG;@0307eH;P1oFS00P5/a00<0OUT_101mF2h01@1lEbd0Oe`b07eJ<01kF2h0NEH/0080N5D[00D0
NEH/07YG;@21G380P5/a07mJ<00207eH;P0307mJ<020Fc40PE`b0080PUd`0`21G2l3081K;P0807mL
=01nFc<0OEXb07]H<01iERh0Me@/07IC:`1eDRX207AD:`80MED/101fERd307UI<2_ooooo000Zoooo
oa00WG=100P0Y7520:5a@@2QLD40X79109mc@P2PMT@0XWY70:=kB0D0XGE400@0X7A309mc@P2OLd80
WW=00P2OM4400`2PMD80XGI30:9gA0020:=hA@80XWQ60P2QMdD20:1fA080WgE300D0XG=20:9d@`2P
M4<0X7I40:1hA@0209mjAP0309mkA`2QMdD0XGM500H0XGM50P2QN4@0102PMd<0WgI209mf@P2NMD42
09ed@00409Ma@P2HLT<0VG=409UcA080V79300@0UW1109A^?`2BK3d0Ufi00P2FKCl00`2EK3h0U6/m
09=Z?002099Y>`04095Z?`2=IS/0RV<h08YS>080S6Dj00P0R64f08AM<P21GSH0P5de07mL=01nFc<0
OEXb07aI<@80NeP`0P1kF3800`1iES00N5D_07MD;P0307IC;@80KT/[00H0KD`[06a>;01[CR`0JDl/
06Y@;@1YDBd206]>;080JTd[00<0JD`Z06Q;:@1XBbT00`1WBRP206Q;:@@0JD`Z0100KE4/06a@:`1/
CRX0KD`Y06m=:P1bCR`0Ldl]07M@;`1eDRX0MU<[07MD:P1iER`0NeT/07eK;@1nG2`0Oed]0P25H3<3
08IQ=0<0Qf8e00H0RV@e08]U=P2<ISL0SFLh08iX>@2?JCX2091Z>`80SFLj0P2>J3/208mY?080T6Xm
0P2=IcP208iX>@80SfTj0P2@JS/309AY?00=09=X>`2BIcX0TVLj099W>P2AIST0T6Xk08mY>P2=IcP0
S6Hg08eW>02>J3T0SfTj091Z>`02095V>@@0TVLj0P2AIST00`2<ISL0SFLh091Z>`02095[?003091Z
>`2=IcP0S6Hg00<0TVLj0`2CJ3/209AY?003099W>P2CJ3/0U6Tl0080UV/n0P2DJC`00`2CJ3/0TVLj
09EZ?@0709EZ?@0@091[=`2BKCT0U6lk09E`?02FLCd0UG0l09A_>`2CKSX0U6Xh09I/>P2HKS`0VFlm
09Y`?P2IKcd0V6hl09M]>`@0UFln0P2DKSd209=]?080UG0l0P2DKc/209=^>P80TVdi0`2BIcX3095V
>@80T6Dh00H0S6Hg08eW>02=IcP0SVPi08mY>P2@JS/2095[?0P0RVHf1029ICD408YV=P80S6Ph0P2=
JCT0102>JSX0Sf/k08m[>`2?Jc/308m[>@<0Sf/k0P2?JSd00`2>JSX0Sf/k08m[>`0408m[>`0408iZ
>P2=Jc/0S6Xj08aZ>P80RfTi0`2:J3P0602;JCT0RVPh08UW=`28ISH0QfDe08IT=025Hc<0Q68b085L
<01nG2l0OEX`07YI<01fERl0Ke4[06Y>9`1XC2L0H4`[05i::@1JAbL0E4<U04m08`1:?240ACXN04@h
7P80@cLQ00H0@SLS03hf8`0j<b00=S4N030]700^:aX202//7P0302X[7@0Y:Q`0:2TK00809bPJ00L0
9RLI02/Y700[:Ad0:2PL02DW700T9Ad08RDN00807b@N00<07R<M01lR6`0O8Q/01P0O8Q/2020S6P80
8B@K0P0R9A`202<V7@0602DY6P0U:A/092PJ02@W700S9Qd08RDN0P0Q8ah301dO70<071hK0P0K7AX0
400L71`07AdK01hN700O81/08B8L028S6`0S9AX092HK02l]7P0`;Ah0<RlN03Ha7P0h<Ah0>c<P03ld
800o=1h2048f7P0B040e7`0l=1l0>S<Q03La8@0c<240<RlP02PW8P0W9R409bLO02PX7P0Y:Ad0:b`N
02d^7P0^;al0<RdJ03@_700f<Ah0>3<P0P0j=B8203Td8@<0<bhK00d0<RdJ03<^6`0c;Q/0<bhK03@_
700h<2<0=RhQ03<]7`0_;1d0;B/L02//700/;Ad0;2lN00D0:BTO00T0:2PN02LW7@0W9ad0:BLJ02PV
6P0V9QX092HK02<T700Q91d00P0N8ad2020S70807b8K0P0N8AX201dP6@8071lH0P0M81T07`0N8AX0
7b8K01lR6`0O8Q/081lJ02<R7@0X9Ah0:2@K02PR5P0Z8QD0;RLG03@[7015<Q80DclN06YD;`1oJ3l0
SgA909AhB@2EMTL0Tg=208A]A020JTD0LUm105e==P14>2P0<R`P02/X7`0[:b40:B`U02LZ8`0V:B80
0P0T9b00100U:2409RTR02LZ8`0W:R<202DX8@809RTR0P0W:R<202P[900402T/8`0Z;B@0:RdT02X]
9080:bhU0P0/;bH202HY800D02PY8@0Z:R80;BXS02lZ900`:bD0<b`V02l]7P0e<R<0>cPW040k:011
>RL0A3`Y04]0;01?A2h0AChT04M09P19@RP0BT<Y04]4:P1:@bT204U2:080CD<Z00`0C48Y04]1:01:
@2L0BClV04Pn9@17?B@0AcdR04Xo8`1=@RH0DT@W05I7:01IBBP205a9:00I05a;;@1NBb/0Gd`/065=
;01TCB/0Idl[06U?:P1ZD2/0IThZ06M?:@1ZD2/0KE@/079F;P1fFBl0NU/_07]L<01oI3T0OV<h07YQ
>01gH3L0LU`e06]G<P1WDbh0I58^05m?;@02061=;015069>;@1VCbd0JU8`06eC<P1_EC80MUD/07QG
;01kG300OF4b07eU=@1mIcD0O6Pe07]W=01dICX0Lf@i07AS>01dHCL0MV0g07MP=`1fGcH0N5lg07QQ
=@1eGS80Le/_079J;P1eFRd0NUda085R=P24ICL0SVdh08i]=`2AKSH0U70d09Yd=@2QNSL0YWlj0:^3
?@2XQD40ZHI20:Z7@`2[R4@0[8U70:f:B02^RdT0[X];0:V7B02WQDH0YH=40:>1@P2RP440Xh520:B2
@`2VQ4D0W7Pl09]g>`2LN3`0X7a00:B0A02SOd<0WGTm09Mc=`2KLSX0W7@i09if>`2RNSd0Z8120:j7
AP2cS4T0]Xm<0080^95>00`0]8e<0;6:B@2aRD/0/HU<0:j6B`2WOTH0XGQ00:UoA@2XOT@0YWi30:=k
@02OMc`309ae>P0309=`>P2BKcT0Sf`f00<0SFXd00<0Sf`f091]=`2?KcH00P2@L3L2099_=`0?095/
=@2@Jc@0SfXc08m/=P2CL3X0UW<m09Eb?02AKSP0SV/e08m/=P2AKSP0T6``099^<P2DL3@0Ug<g00<0
V7@h00<0Ug<g09mg>P2OMcX00P2OMcX409if>@0809ej>P2NNc/0X7dm0:5n?P2ROcl0XGhn0:1m?@2O
O3`20:1h>`80XGTl102RNSd0202RNS`0Xg/m0:Al?P2UOCl0Y7`n0:9j?02PN3X0WgLi0`2PMd<209mf
@P<0WWE10100W7Tg09ai>@2LNCT0VgLi09Yf>P2GLcT0U6lh099]=P2>Jc<0Sf`d095^=P2BKcL0Tg0h
099_=`2AKSH0T6de0P2CLR/0102CLRd0U7<^09Ac<02DLS8209Ec=00=09Ig=`2DMCD0TG8b08i_;`2;
K2`0R6TY08IW9`25IRH0PVLb085V<@21IC<0P6@d07iR<`0207eP=00707aO=@1iI2l0NV<_07]T<01m
Hc00Of<a085S<@0208=S<P0408AY=023J3<0PVLb081U<080Of@_0P20IC002@1gH2h0N64_07QP<01g
Gc40MEda079I<01_ERd0KE@/07=G<P02075E<00:06eA;01ZCRT0J4`W06U=:01[CbX0KE4/06]C;@1Y
DB/0IThX06=;9@80HTXT00<0Hd/U06A<9P1_DRH00P1_DRH02`1`DbL0LE@X07=F:P1eF2`0MeX^07QL
:P1iGB/0NUh/07]O;@1mHBl0OV8`0080Of<a00<0OV8`07mS<@20I3800P20I3804`1oHc40OF4_07eQ
;`1lHbd0Nf8/07YP;@1iGbh0Me`]07IK;P1eFRd0M5T^07AO:P1cGRT0LE/Y06mI:01]EbP0Je@X06UB
:01XDBL0201RDBD0401PCRP0GddW05i<9P1NC2H0GddW065?:@1TDR`0IU@^06YC:P1[E2X0K5D[06iG
:`1`FR/0LU`[07=M:`1dGR`807IP;`80LU`Z00@0Led[07AN;01dGR`0MEl]0P1fH2h01P1eGc00M5h_
079L;@1`FR/0KUPY06aF9`80JeDV0P1XDRT0501WDBP0IU0W06E?9P1TCRD0HddT069<8`1ZD2d0J4h[
06=;9`1PBRD0G4PS05a:901NC2H0GDhW05Y;901JBRH0F4PT05I6901EAB@0Dd8T0P1A@2@01P17?Ql0
ASdP04@k7P12>1d0@3HM03hc7@80?34M00P0<B/M030Z700/:1`0:BLK02@T6P0Q8aP07b0H01dP5`80
6adL00<06Q`K01TK6P0H6QT00P0G6AP:01HH5aP05AHH200D5AL801DF610051DG200E5QP3014G5`<0
4QPH0P0C6AT@01DF60P05ALF200F61L801LI60P061PH0P0H61H201TI5`806QXH0P0K6aT301XJ60<0
6a/I2P0L71X901hM6`P071`J0P0K6aT301`L6P<07AdK0`0K6aT201`L6P<07AdK0P0M7QP201hO6@80
7b0J0P0P8A/3024Q6@808R8J0`0S8a/802`V6P0502hT6P0_9A/0<2HL034W7@0b:1h00`0c:Al00`0f
9A/0=bHL03PW7@0203TX7P0303PW7@0g9Q`0=RDK00P0>b/L0P0h;1`203L[6`80=RXJ0P0e:AT403HY
6@80=bXJ0P0h:a/303T/6`80>RdL0`0k;Qd01@0m:ad0?R`N03l^7P11<1h0@S4M0080@c<L00<0@c<J
04Dc7@15<ad00P15<ad204Hd7P80AcDO00<0AcDM04Pf7P1:>2000P1:>2000`18=Qh0AcDM04Dc6`02
04Xf7P0404/g7`1<>200CCTQ04hj8P80Cc/S00D0F3`T05Lk8`1G>b<0ESXR05Di8@0205@h800305<g
7`1J?280FS`R00H0FS`R00<0GClU05`n901L?R@00`1L?R@305do9@80F3hS00@0EcdR05Hl8@1E>b00
E3XO0P1C>Ah305@j8`<0DcTR0P1B>242058i8`03054h8P1@=b40CcHP0080CSDO00L0CC@N04Th7P1;
=ah0C3PO04hh801A>B40DcTR0080ESXT0P1A>Al2050h7P@0CcLM2017=Al02018=Qh0BCLO04Tg7`19
=al0B3HN04Hd7013<AT0@S0H0`19=al204Pf7P<0AcDM00P0C3HN04dg7`1B>R80EC/T05Lk9@1J>bH0
FCXU05Ti90<0FC/Q0`1J?28205/m8`0@05Xl901L?R@0Gd4W06539`1QA2H0H4<S05i17`1L?ad0G48W
05a39@1M@RD0GD8T06138`1RA280ID@Q06I58P@0JdXW101/BbP8071<:P03079B:`1aDBX0L50Y0080
L50Y00<0LU8[07AD;@1eEBh00P1dEbd307IF;@<0MeH]0P1jE300201gDbl0MU@_07EE;`1cEBl0LU@^
075E;P1hF380M5@^0P1aDB/207=C;@0306m?:@1[BbD0HdDS00<0HdDS0`1TAR@206E79@0@06958`1Q
A280H4<S05e08P1K?B40FC/Q05Li7`1F>200DSdN05<n7`1F?R80EShT05Dm9@1D>B@0DSLT050e8P<0
BcLO0P1:=Qh304/g7`0L04/i8@1<>200C3PP04dg801A>280E3TT05Pl9`1I?BP0FCXK05Xk701L?Ah0
Gd0Q0693901UARL0IdPY06Q9:P1UA2D0J4LX06e<:`1aD2d0Le<]075A:P1^CRL0K4`S07AA:`1fDbd0
N5D_07YG<@80NePb00D0NULa07UF<01hF2l0NET`07]K<P0207eM=00307aL<`1jFS40NET`0080OEH_
00L0NeD^07UF;P1gERd0MED/07AD:`1aE2X0Me0_0080ME4_00D0Le4^075@;@1^D2`0K50[06]?:P02
06Y;;00306U::`1XBBX0IdPY0080ITLX00L0IDHW0654901QA2@0HTDU06=69P1UB2P0ITTY0080IdXZ
0P1UARL0101TABH0Hd@U0693901R@b@206528`P0IDLU0`1RA2P206539`<0H48V00P0Fd@R05a58`1N
AR@0H4HU06=69P1UARL0J4LX06U8:@@0HTDU0P1QA2@206138`80Id@V00<0ID@U06=49@1RABD00P1Q
AbH01`1QBBL0JDLT06U7901[BBH0K4XW06i<:@1`CR/00P1aCb`0101bD2d0LU8[075A:P1`D2T206m?
:009075A:P1bDR/0M5@]07AB;01eDbd0N5D]07]F;01mF2`0OeT/0080PUT[00P0PUda085L<020Fbl0
OeX^07iI;@1oFRh0PE``089M<@<0PE``00<0P5/_07mJ;P1oFRh00P1nFBd01020GS40Oed`07eK;P1k
FB`207YH:`0507]I;01lFRd0PUdc085L<P1oFS000P1nFBl00`1oFS00PE`b089M<`03089M<0<0PE`_
0P20Fbh01P20GCD0Oe`d07iK<`1lFC40NeP`07UF;P80Me@/101fERd0101gEbh0N5P_07QH;`1iFC03
07aK<R_ooooo000Zoooooa00WG=100`0YW=40:=c@`2RLT80X79109mc@P2OMD<0X7Q50:5iAP2OLd80
X7A30:5eA02RMTD20:5eA0030:1d@`2OLd80XGI300<0XGI30`2RMd@00`2SN4D0XWQ60:9hAP020:5g
A@80X7I40P2OMD<20:=eA0030:5eA02PMT@0X7Q50080WWU500<0WGU50:5gA@2QMdD01P2QMdD20:5h
A0030:1g@`2OMT80WWE10080WGA000<0W7<o09Qb@`2ILd@00P2JM4D209UcA00409Ma@P2EKd00U6ho
09Q]@080Uf`o00<0UV/n09EZ?@2DJC`00P2CJ3/0102AJch0SFLj08YT=`2:I3L208aV>@0@08QR=@24
GS40PEhf085N=P20GCD0OU/c07eJ<P1lFC40NeP`07YG;`1lFC<0NePb07QE;`1fDbd0ME8/07AA:`80
ME8/00P0JdPX06a9:@1/BbX0Jdd[06]>;01ZD2d0Je4^06YB;P80JTd[0P1YC2X306Q;:@@0IdXX0P1X
BbT306U<:P0A06a@:`1[CbX0K4hZ06i=:P1`CR/0Ldl]07EA;`1hDC00Me@/07QE:`1iER`0NeT/07eK
;@1oGBd0P5l/085P;@25H3<00`26HC@208MR=@80R6<f0P2<ISL308eW>0<0SVPi0P2=IcX208iX>`80
SfTl0P2@JSd01@2<ISL0SFLh08eW>02>J3T0SfTj0080T6Xk00<0TF/l09AY?02CJ3/00`2CJ3/3099W
>P0308mY>P2>J3T0S6Hg0080S6Hg00H0SVPi08mY>P2AJc`0T6Dh095V>@2BIcX209=X>`06099W>P2A
IST0T6Dh08eW>02>J3T0SfTj0P2@JS/00`2?JCX0SVPi08eW>003099W>P<0TfPk0P2DJC`00`2BIc`0
TfPm09AY?P0209EZ?`80U6Tn00<0TfPm099W?02EJSd01`2EJSd02`2@JcL0TVdi09A_>`2EL3`0UW4m
09E`?02DKc/0Tfhj09AZ>02EJcT0Ufdk0080VFlm00@0V6hl09M]>`2FK3X0UFm00`2DKSl209=]?P80
TV`m0P2EL3`209A_>`80Tfhj0P2BKCT3099W>P80TFHi0`2@ICP0102;ICH0S6Hg08aV=`2=IcP208iX
>@80SfTj4029ICD208aX>00408eY>@2>JSX0Sf/k08m[>`80T6`l00H0Sf`f08m[=`2?JcL0Sf/i08m[
>`2?JSd208mZ?P0308eY>@2>JSX0Sf/k0080T6`l00P0Sf/k08iZ>P2=JCT0SF/k08aZ>P2;JCT0RVPh
08UW=`80RVPh00L0RfTi08YX>029IcL0RFLg08QV=P27ICD0QV@d0080QF<c0100OeX`07aI;`1kF300
N5H`07=C;@1/CRX0Id/V06A79@1NBbX0GDXY05M79P1B@b@0CClR04Hk7`13>1`0@3HK0P13=b401`12
=b<0?cLT03/d8@0g<Ql0<RlN030]700/;Al00P0[;1h00`0Z:ad0:BXL02PY6`0202LX6P0602/Y700[
:Ad0:2PL02DW700T9Ad08RDN0P0O91h00`0N8ad07b8K01lR6`0601lR6`8082<J0P0Q91/02P0R9A`0
8bHM02@W7P0T9ah092PI02@X6P0S9aT08RDJ028U700Q91d2020R7@<07AlL0`0L7Q/201/M6P0S01`L
700L71X07QhL01lP6`0Q8Q`08b@L02@V6`0U9a`0<BhM038_7P0e<1d0>34N03/c800n<al0@CDO048f
8013>1`0@SHL040f7@0m=B00>C8P03D_8@0`;200;RXO02DT7`0V9B009bLO02PX7P0Z:Qh0;2dO02h_
7`0_<200=2lL03Ha7P0g<Ql00`0i=24203Lb7`80=2lL0`0c;Q/02`0d;a`0=C0M03Ha7P0f;R40=BdP
038/7P0^:a`0;2XK02X[6`0[;1`0:RdL0080:BTO0`0Z:R002`0Y:Al09bLM02HV700X9QT0:2HJ02DU
6@0S9AX08R<K020S700N8ad07B8L00<07b8K0P0N8AX301dP6@8071lH00@07B0I01hQ6P0O8Q/07b8K
0P0P8a`06`0V8Ql09b@O02PS7@0Y8QP0:B4D02hU500g;a`0@3DQ05e46`1YDBD0O64f08aaA02ENDX0
UWM8095a@P2<K3/0NFE0071M?@1OCcP0BShb03H_9`0Z:B@09bXS02L/9@0W:R<09RTR02DX8@0202@W
800402DX8@0V:B809bXS02LZ8`<09RTR0P0W:R<302P[9080:2/R0P0Y;2<202X]9080:bhU01P09bXQ
02P[8P0Z:b<0;2`T02l/9@0b;BL0<bhX03D^:00e<R40>SLV044l:@13?2T0@c/X04Dj9P19?BL0CD4[
04Ho9@17@2H0B44W04U2:01:@bT0BD8X04M09P16?bD304]1:0<0BT0W0P19?bH01P1:@2D0C44U04i3
9`1BA2L0ETLX05Q89`80G4TX02P0FTT[05]8:01KB2P0GDTX065::01TC2P0IddX06Q>:@1ZDRh0Je4/
06eC;P1`E2d0LeH^07MG;P1iF2d0NUT^07]R>P1iH3P0MUhh075K=P1[Ec80IE<_069?;P1NCR`0Gdh`
065><01QCRh0Hdl^06M@;P1[Dbl0KeD`075G<P1mEbX0OUT/081N<022Hc@0PFLf07iX=P1kIc@0N6Lc
0P1[GCH0701[G3D0K5Xd06iJ=@1aFcH0LU`g07AL>01fGcD0MUdd07AL<01fFbh0NEd^07iO<023Hc80
QFDd08e/=`2>KCL0TVlg09Mc=`2MMcP0Xg`i0:N0>`2ZPS`0YXDn0:N6?`2XQd80ZXU60:Z8B02ZR4T2
0:V7BPP0XX110100Ug<g09Ib=P2GLcL0W7Pl0:9n@P2UPDD0Xgm309mk?`2VO480Yge30:Qn@P2ZPD<0
[XE50;>:B02gSdX0^I5<0P2jTe004P2hTE00]Hi=0;F=C`2eSE00/XY?0:Z1B@2TNd<0Zgi50:f0A`2[
PDL0Ygm40:1i?P2IMCT0V7@h09Qf>@2?KST0SF`g08YY=080RFPc00D0RVTd08e/=`2?KST0Rfhf08e^
=`0208i]=`80TF`g00h0Tf/g09=Z=P2BKCP0UW4l09Qc?P2FLC`0TVdh08mZ=@2AK3L0Tfhi08iZ;02@
K2h0UG4c09Qd=P80VgLi00<0VWHh09Ue=`2OMc`00`2NMS/309ee>P0409ad>@2IMcP0VWPi09aj>`80
WW`m00@0WG/l09aj>`2KNCX0WgLl0`2PN3d20:5i?P80XWXo00<0X7Pj0:9j?02SNcd00`2UOCl00`2T
O3h0Xg/m0:Il@P030:Ek@@80Y7Y00P2SNCl02`2NNcL0Wg`j09ml>P2NNc/0W7Pj09Ue>@2GLcT0UG4g
095]<@2CKc<0UG4e00<0Ug<g0P2FLSH209Mf<@0309Mf<`2GMCD0UgDf0080UW@g01L0UW<i09Yj?`2H
N3d0U7@i08m_=02;Jc00QfL/08IV:`25IBX0QFLc08AV<P23IC<0PV<d085R=01oH3@0OUlc07iN=@1h
HS00NF8`07YS<@1mHc80Of<c085R<`0208=S=0@0Q6H`00d0PfD_089T;P21Hbd0PF<]07UO;01jH2d0
Nf4`07]P<@1jGc80N5db07EI<@1dF300M5Pc0080LUHa01@0KU8]06]?:P1YCBP0JDdX06Y>:@1[CbX0
Je<]06YB;01YDB/0J50Z06I>:01TC2H0Hd/U069:901]D2@0KU4U06mB9P1aE2P0LUDY07=F:P80M5L[
00T0NE/Y07YL:P1kGB/0O5h/07iP;P1oHBl0P68`085S<@1nHS001@1oHc4207iR<00@07eT;P1lHbd0
Nf4^07YP;`1hGBh0Me`_07IK;P1eFRl0M5lZ07=N:@1aFbT0KeTX06eG:01ZDbL0JE8X06QA9`P0He8V
0100HDlW061>9P1NC2@0GT`T05m=9@1RD2P0IU@/06QF;P1[E2X0K5D[06eF:P1_FBX0LE/Z07=M:`1d
GbX0MF0[201gHBl0101dGR`0MEl]07EO;@1eGbd407IP;P0607MQ<P1fH340Led^075K;01_FBX0KUPY
0P1]EbP206YE:P0;06UD:@1WDRL0IU4V06E@9@1TCb@0HdhS06U?:P1XCRT0IDdW069<9@1NBb<00P1M
Bb<06P1KC2<0GD/U05a:9P1KBBD0FDHU05M4901E@R@0E40U05<o9018?ah0AchO04Hm7P14>ah0@SPM
040f7@0o=1h0?S<M03@]7@0c;1`0<2XL02`X700X9QX08b<I024Q5`0O81P071hM0P0K7A`00`0J71/0
6A/J01PJ6@0201LI60T05QPG600E5QP801@E5`P05AHH400D5AL801DF60<04ALG0`0B61P201<I6A00
5AHH200E5aH801HH5`P05aTH200H61P201PH5P806ATG0P0J6QP201/K6@<06QXH0`0K6aT201`L6PP0
7AdK2@0N7A/801dM6`0401/K6@0L71X071`J01`L6P807AdK0P0N7Q`301/K6@8071`J0`0M7A/201dN
60807QlI0P0O81X2020Q6`<08B4I0P0R8QX302<S6`P0;2HJ00@0;R@J02lU6`0a9ad0<bTO0P0d:R02
03<Y7`0303PV700i9ad0>bTO0080?2XP00<0>bTO03TW7@0h9Q`0200l:Q`303P/7080=b/K0`0f:QX3
03LZ6P<0>2/K0P0i;1`203T/6`80>RdL0`0k;Qd01P0l;ah0?2XL03h/7P10;al0@S4O04<b7P80A3@M
00<0@c<J04Dc7@16=1h00P16=1h204Le7`80B3HP00<0AcDM04Pf7P1:>2000P1;>B400`1:>200BCLO
04Pf7P0204/g7`80C3PP00@0CCTQ04hj8P1?>b<0Cc/S101I>b4305Pj800405Li7`1I>b40FS`R05Xl
8P80FcdS101L?R@00`1K?B<0FS`R05Xl8P0205Xl8P0305`n901M?bD0GT0V0080F3hS00@0EcdR05Hl
8@1E>b00EC/P0P1D>Ql305Dk9080E3XS0`1C>B80101C>2<0DSLR058g8P1B=b84054f8@0804`k8@1>
>R40CCTP04hh801@>200DSPQ05Di8`1F>R@205<i7P80DSPM0`1A=a`00`1@=Q/0AcDO04Le7`0604Le
7`0304Hd7017=Ad0BCLO0080BCLO00<0AcDM04Hd7014<QX01019=al404Pf7P0804dg7`1>>200DSXR
05Dk901G>bD0FCXU05Pi901I>B@305Tk8@80FS`R0`1K?B<0401M?bD0GT0T05m19@1P@bD0HD@T0654
8P1PA1l0Gd<N05i4:@1OA2L0GT<V06139@1Q@R<0I4<R06M58P1XAR<206U89@0406Y99P1[BRL0K4/X
06e<:@80KTdZ201bBbX00`1bDR/0LE4Z071@:@02071@:@03079B:`1dE2d0MED^0080LeP]00<0M5L]
07IF;@1gERd00P1hEBd01P1jE2d0Ne<_07]C;`1jE2l0N5D_07ME;`80MUH_00D0M5L_07UI<P1fERl0
Le</07AD;@0207IF;`05075A:P1/C2D0IdTU06I8901UAb<00P1TAR8206E78`80ITPT0100HdLR0696
8@1QA280Gd8R05i18`1L?R80FcdQ05Xl8P1C?Ql0E3lP05Hn8P1H?RD0F3`V05Pi9@1F=bD0EC@S0P1=
>B40101<>200BcLO04/g7`1<>20204di8@0X04/i8@1<>200C3PP04dg801A>280E3TT05Pl9`1I?BP0
G3/L05dl7@1O?Ql0HD0Q06=28`1UA2D0IdHW06Q7:01WARL0JDPY06e<:`1`Cb`0LE4[075A:P1_CbP0
KThU07E?:01gDBX0NU@]07eG<01nF340OEL`07]E;P1jE2d0MED/07MG;P1jFS40OEdd07iN=@1mGC@0
Ne/b07YJ<@80OePa00L0OeTb07aI<@1kFS40N5P_07IF;@1cER`0N54`0080MU8`00D0ME<`07=B;`1`
DRh0KE4/06a@:`0206]<;@80JT//00@0JDX[06Q9:P1WB2T0IdPY0P1TABH206E69`0406I7:01WB2T0
J4TZ06Q9:P@0IDHW0`1TABH00`1SA2D0IdTW06M99`0606M99`<0I4HZ0P1SABT30694:080GDHT00@0
GdLU06579P1SARH0IDHW0P1XAbP206E69`<0ITLX0140I4DV06=49@1R@b@0J4DW06M49P1UA2D0Hd@U
06=69P1RB2L0HdTX06=;:@1/B2H0KDTW06i::01_BbT0L4`Z075=:`02079>;00407=?;@1dE2d0Le</
075A:P80L50Y00T0LE4Z07=C;01dE2d0ME<]07ID;P1iERh0OUT_081K;`22G2l00P24Fbd02024Gc80
Peha085L;`20Fbh0OeX]081K;P21G2l0PUd`0P24Gc801023GS40PUd`085L;`21G2l2081K;P04089P
<P21Gc40Oed_07eK;@80O5X/0P1mFbd00`23GS@0PUdc081K<@0207mJ<003081K<@22GC<0Pehd0080
Peha0P22GC03085L;`0:081K;P21GSH0PEhf081M=@1nFc<0OEXb07aI<@1kF300NUL_07YJ<@80NET`
00<0N5P_07UI<01jFS400P1lG3<307eJ<R_ooooo000Zoooooa00WWA200/0Z7E60:EeA@2SLd<0XG=2
09ib@@2NM480WWI309mgA02NLT40Wg=20:5eA0020:9fA@030:5eA02PM4<0Wg=200@0XgQ50`2RMd@0
0`2QMT<0XWQ60:9hAP020:5gA@80X7I40P2OMD<20:AfA@030:9fA@2QMdD0WgM40080WGQ400<0W7Q4
0:9hAP2RN4H01P2RN4H01P2QN4@0X7M30:1g@`2OMT80WWE109ed@080W7<o00@0VWA509]eAP2KMDH0
W7I70P2KMDH0102ILd@0UW1109E_@02HKD0209M/?`0309I[?P2EJSd0U6Tl0080TfPk00@0TF/l08eW
>02:I3D0RV@e0P2<ISL02028HS<0Q5h_089O=`21GSH0P5de07mL=01mFS80NeP`0P1jEbl01P1kF380
NULa07MD;P1dDB/0Le0Z079?:@80Le0Z0P1^Bb/00`1]C2/0Jdd[06Y=:`0206Q>:`0306M?:`1XBbT0
J4/Y0080J4/Y101WBRP206I99`80IdXX0`1XBbT04@1YC2X0JThY06Y>:@1[CBT0KTdZ071>:`1dD2h0
Me<a07]D<`1iER`0NUP[07]I;01mFbd0Oed]085P;@22HB`0Pf8]00<0QV4d0P27HSD308QS=P0508mY
>P2>J3T0SVPi08iX>@2=IcP00`2<ISL208eW>P80SVPk0P2?JC`2091Z?@80S6Hg00@0SFLh08iX>@2?
JCX0T6Xk0P2AJc`3099W>PD0TfPk00/0SVPi08eW>02<ISL0RfDf08aV=`2>J3T0T6Xk095[?02@ICP0
TFHi099W>P0209=X>`06099W>P2AIST0T6Dh091Z>`2?JCX0SVPi0P2=IcP00`2>J3T0SfTj091Z>`03
099W>P<0TfPk0P2DJC`00`2AIS`0TVLm09AY?`0209EZ@080U6To00<0TVLm095V?02DJC`01`2DJC`0
402@JcL0TVdi09A_>`2EL3`0UW4m09E`?02DKc/0Tfhj09AZ>02EJcT0Ufdk09Q^?02IKcd0V6hl09M]
>`2FK3X209A^?`80Tfdn0`2BK3d00`2AJc`0UG0l09E`?00209A_>`80Tfhj0P2BKCT0102BIcX0TFHi
095V>@2AIST2091U>080Sf@g102;ICH408aV=`d0RFDe0`28I3@208aX>00408eY>@2>JSX0Sf/k091/
?080TFdm0P2?K3@02@2?JcL0Sf/i08mZ?@2?JSh0SfY008mY@P2=JCT0SVXj091/?002095]?@0<091/
?02>JSX0SFTi08i/?02<JSX0RVPh08UW=`28ISH0RFLg08YX>02;JCT0RFLg0P28ISH00`27ICD0QV@d
08IT=00208ES<`0@085K=01nFc<0OEXd07UG<@1dE2h0KDl[06Q;:@1UB2H0F4PV05I6901CA2<0Cd8R
04Xo8@18?B40A3/N04<i7P80@SHP00H0@SLS03lg900m=R<0>C@Q03Db8@0c<1l202d^800402`]7`0[
;1h0:R/M02TZ7080:2TK00H0:bTL02/Y7@0X:1`09BLL02@U7@0R9Ah201lT7P0301hS7@0P8a`082<L
00H082<L00H07b8I020S6P0Q91/08RDL02<V7@0T9ah202DX7`0602<W600S9aT08RHH024T6@0P8aX0
7b8K0P0N81/301dO70<071hK0P0K7AX08P0K6a/071`J01hN700P8A`08R<M02@U7@0U9a`09RPM03<]
7@0d;a`0=RlM03Ta7P0m<Qh0@3@N044e7@14=Ah0@SLI048g6`10=Q/0?3@O03Pa7`0b;200;2PM02XV
7@0T8ah09B@O02HV7P0X:1h0:b/O02d^800^;al0;c0P03Lb7`0h<b0303Td8@0E03Lb7`0e<1d0=2lL
03Ha7P0e<1d0=2lL03<^6`0d;a`0=S4N03Pc800i=240=2`O03<[7P0`:Q`0;2TJ02XX6@0X:AT0:BXJ
02T/6`0Y:Al0:RXP00<0:b/Q00T0:BTO02LW7@0V9Q`0:2HI02PV6P0U9AT08bDJ028S6`0P8a`00P0M
8Q`201lR6`807R4J100M81T201`O600401dP6@0N8AX07b8K020S70808B@M01l0:BDT02XU8P0X8ad0
:24G02TR4P0b:QL0@CHP04]1:01dF2H0O60^08Y/>P2DMT@0UWM8099b@`2:JS/0Pf<d06YJ=P1MCS40
B3/[03H]:00[9bP09RLY02@Z9P0S;BD09bXS02HY8P0T9b008bHO02@W800U:2409RTR00809bXS0P0V
:B8202LZ8`@0:2/T0`0W:R4202P[8PD0:B`S0140;2dU02h^9P0b;bP0=2lY03D`:P0h<B/0>cDU040k
:015?R`0ASh[04Dj9P14>280ACTQ04Tj8`15?R@0ASlU04M09P0204Q19`0304M09P15?R@0A3dS00<0
BClV00/0BT0W04]1:01;@BP0Bd4X04a2:@1=@bP0CT<W04m4:01BA2L0EDHW05M79P0205]89`0>05Y9
:`1LBBT0FdPX05a89`1PBBL0Hd/W06M=:01XCRT0KU@a071D;`1aEC00LeD_07EE;P1gERd207UF;00k
079J=01aFC<0KUPc06]D<P1WDc80I54a061@;`1OCS00HU4e06A@=@1TDC<0IE4`06UB<01]EBl0LEP`
07=J<P23FBT0QEd/08EQ<@25IC@0PVPg07iX=P1iIcD0MVHc06]O>@1ZG3L0JE/f06QH=01ZF3@0JeLd
06mH=P1`FCL0ME`d07QL=01hGC80NUda07iO<021HC00Pf8_08AS;P2;JSD0SVdg09Aa>@2IMCT0X7Xk
0:Am>P2VOcX0Z80j0::4>`2SQCd0YHM10:J7A02VQdL0YHE80:B4B@2SPdX0VgTj09ek?02POSl00P2R
P4402`2QOd00Wgdn09ek?02MNCd0VWHj09Ue>@2MNCd0Y8140:V5B@2ZQTX0ZHE90080]8M<00H0]8Q;
0;B8B@2fRTT0^Hi:0;bAC@2mTTd20;VBC`0`0;N@C`2eSTd0]He?0;F=D02aRDh0ZH180:=j@P2ZND40
Zga40:aoAP2VO480W7Dj09A`=02?Kc80T70c08][>029JCH0QfLd08IV<`27Ic@0RVXg08i^>`2@L3d0
Qf`e08U[=@2;K3H0SF`g095/>02DK3T0UF/i09M[>P2GKc/0VW8n09]c?`2ILCd0U6`h099Z=P2CJcL0
UVhj08eZ:P2@KBd0UG8b09Yg=`2MNSX0WW/k09ej>P2LNCT0WWDm0P2MM3`209ac>`80Vg8j00X0VW4i
09Ad=`2EMCP0UgLj09Qh>`2INC`0V7Pk09Mg>P2FMST0WWDm0`2OMSh20:1g?`80XGQ000H0XWXl0:=k
?@2VOT00Z8120:Z2A02[PdD20:Z2A0<0Zh0l0P2ZOc/30:Un>P0N0:1m>@2QOSX0XGhl0:1m?@2NNS`0
VgLk09Ue>@2GLcT0UFla09I`<P2ILcD0VgDg09af>02MMcT0W7Hh09]e=`2JN3T0VGLh09Ug>P2HMST0
Ug@j09Ic>`2FLcd0UG8l09Mf@@2DLch0TG0k08e/=`2:JC@0RFPc0P28Ic804`27Ic@0QVHc08EU=024
I3D0PV4d081O=01oGS<0Oehe07MQ<01hH300NF4a07aQ<P1nHS<0PF8d08=R=@24HcH0PF8/089S;@25
IS000P26Ic403024IBl0PF8/07mP:P1jHB/0NV0]07aR;`1lHS40O64b07YO<P1hGC80Me`a07AH<`80
LUHa00P0L5@_06iB;@1[CbX0JThY06U=:01XC2L0JE4[06]C;@80K5@^00P0Je<]06Q@:P1TC2H0HDTS
06Y=8@1/Cb<0Ke8V079E:@80M5L[00X0LUDY075D:01jFRT0NUXY07]K:P1lG2/0OUh]07mO;P20H2l0
PF4`0`1nHS0507mS<@80OF@^00h0O68_07YP;`1iGRl0Me`_07IK;P1fFc00LehY079M:01aFbT0KUPW
06aF9`1ZDbL0J54W06M@9PP0I5<W0100HU4V061?901NCB80GTdR05m>8`1SDRL0IeH[06YI;P1_F2`0
L5T]075K;01cGB`0MEl]07MR;@1hHbh0NF@]201hHbh407MQ;`<0MV0^00D0MEl]07US<P1gHC00M5h]
075K:P0406mI:00606aG;01[ER/0JUDZ06QC:01WDRL0IE0U0P1TCb@206M>9P0N06I?9P1TCRD0H4dS
05e<8@1KBQl0F4TN05e9901LB2D0FdLT05U5901G@R<0ET4T05@o901C?R<0BD0O04Po7P17?Ql0AC`O
04<i7P12>1l0@CLN040e7`0g;Qd0=BhL03</700_:A/0:RHJ02HT600R8QH08B4G0P0L7Qd0100K7A`0
6Q`K01TK6P0H6QT201LI60T05QPG600E5QP801@E5`P05AHH400D5AL801DF60<04ALG0`0B61P201<I
6A005AHH200E5aH801HH5`P05aTH200H61P201PH5P806ATG0P0J6QP201/K6@<06QXH0`0K6aT201`L
6PP07AdK2@0N7A/801dM6`<071`J0P0M7A/301hN70<06a/I0P0L71X301dM6`807AhH0P0N7aT201lP
6P80824K0`0Q8AT2028R6P<08b<K200/9QX0100^91X0<2HL038X7P0d:R0203D[8@0503@Z800c:Al0
>RPN03/Y7`0m:b400P0n;2800`0m:b40>bTO03XX7P0803d[7@@0>2`L0P0g:a/203HZ6P80>2/K0`0i
;1`303X]7@<0>RdL0`0k;Qd203`_7P0803`Z700m:ad0@2lO04<b8014<al0ACDN04@d7@14=1/204Hd
7P80AcDO0`18=R001@19=b40AS@L04Le7@19=al0BcTQ0080C3XR00L0BcTQ04Xh801;=al0BcLO04`h
801=>B40CSXR0080Cc/S00<0D3`T05Pj7P1H>Qh00`1I>al305Xl800:05Pj801I>b40FS`R05/m8`1L
?R@0GClU05i09P1O@BL0FS`R05Tk8@@0F3XP00@0FS`R05`n901N@2H0FClT0P1H?R<00`1G?B80ES`Q
05Dk800205@j7`<0ES`U0P1E>b@305@j8`04058f8@1C=b80DcLR05<g8P@0E3PS00T0D3lU050l8`1>
>R40CSPP04lg7`1A=b00DcLQ05@h8P1E>Qd00`1D>A`205<h6`80DSLJ2018=R002014<QX0AS@L04Pf
7P19=al0BSPP04Tg7`18=Qh0AcDM0`18=Qh504Tg7`0904dg7`1?>B40Dc/S05Dk901G>bD0FCXU05Pi
901H>2<0FC/Q00<0FS`R0P1K?B<205`n9080H48V00h0Gd8T05m28P1O@R00HDDP06968@1SAb00HDH[
0694:01Q@bL0HD8U06=28`1U@R80J4@R06Y69080IdHS00@0JDPU06]:9`1/BbP0KTdZ0P1`Cb`807=:
:P03079B:`1aDBX0L50Y0080L50Y00T0LU8[07AD;@1eEBh0LEX^079J;P1dFBh0MEP^07QG;P1iERh0
0P1lEBh01P1nDc00O5@`07aD<01kEC00NEH`07UG<@80N5Pa00`0NUXc07MG<01eEBh0MeL`07UI<P1h
F340LU8[06e=9P1ZC2H0JD/U06M98`1UAb4306A6800306E78@1VB280I4PQ0080HdLR0100HTDS0654
901P@bD0Gd4U05i0901C@200E3lP05Lo8`1H?RD0FS/V05Th9@1I=BD0FC@T050l901?>b<0CCTQ0P1<
>200101=>B40Cc/S050l901;>B4204`h800504dg801A>280E3TT05Pl9`1I?BP00P1O?1h01P1Q?R00
HSlQ06=08P1U@R@0IT<U06M49P80JTTZ0180K4/Z06i=:P1_CbT0L50Y075A:P1aDBP0M4dT07M@9`1k
E2/0OUL^07mH;`1mERd0Ne@[07UB:@1bDRT0MED/07UI<01mGC@207mO=P0D07eM=01lG3<0PEXc089K
=022G3D0P5de07iM=01kFc80NET`07EH;P1hDC00Me<a07QD<P1gEC80ME@a075C;`1^DRd0K50[06e>
;`1/CBh206]<;@0406Y;;01YBR/0J4TZ06Q9:P<0J4LX1@1YB2T206E69`<0ITLX0`1WB2T806Q::0<0
ITP/0P1UAb/306A6:P80GdPV00@0H4PV06579P1SARH0I4DV0P1WARL00`1XAbP0JDPY06]::`0206]:
:`0;06U8:@1WARL0ITDV06U6:01XABL0ITDV06=49@1SARH0HTPW06E;:P1UCB/00P1_BbT2071<:P80
LDd[0`1bCR`00`1eEBh0M5@]079B:`02075A:P0>079B:`1cDb`0M5@]07EC;@1gEBl0NeP`081K<@22
GC40Q5ha08IM;`25G2h0QF4a08AP<022GRh3081L;008085M;@22GRh0Qf<c08IR<P25HC40Q60`08=O
;`22GRh2085M;@0408AR<P22H300P5h^07iL;080OE/[00D0OU`/07mM;@24GcD0Pehd085L<P02081K
<@03085L<P23GS@0Q5le00<0Peha0P22GC03085L;`80PUlg0P21GSH2081M=@80Oe`d00<0OUhe07eM
=01kFc800P1kFc800`1mGC@0Oelf081P=`0307aI<B_ooooo000Zoooooa00WWA20100ZWM80:MgA`2T
M4@0XG=209ib@@2MLd40W7A109ee@P2MLD00Wg=20:5eA02RMTD0XgM60:9fA@2PM4<0Wg=20P2UNTL0
0`2TNDH0XgQ50:9gA0020:5f@`030:1e@P2RN4H0XWQ60080XGM50P2PMT@209me@`050:IhA`2UMdH0
XgM60:5gA@2OMd@00P2LMd<00`2JMT80XWQ60:9hAP060:9hAP80X7M30P2OMT801@2NMD40WGA009ac
?`2LLcl0VgE60080W7I700L0WGM809afA`2LMTL0VWA509Ma@P2FL440VFe00080V6`o00<0Uf/n09IZ
?@2EJC`00P2DJ3/0102AJc`0SFLh08YT=@2:I3D208aV=`0>08QR<`24GRl0PUlg085N=P20GCD0Oe`d
07eJ<P1kF300NUL_07UF;P1kF380NEH`07IC;@1cD2X2075>:080LTlY0P1bCbl01P1_CRd0K4h/06U<
:P1UBbP0I4XW069:9PD0IdXX0`1VBBL0101UB2H0ITTW06I99`1VBBL206M::080J4/Y0P1YCBP01P1Z
C2P0KD`Y075?;01eDBl0N5@b07aE=080NeT/00@0OE/]07mM;`20GRh0PV4^0P24Hbh208IQ=0<0Qf8e
0`28HcH2091Z>`0608mY>P2>J3T0SFLh08aV=`2;ICH0RV@e0P2=IcX208iX>`80SfTl0P2@JSd0202;
ICH0S6Hg08eW>02>J3T0SfTj091Z>`2AJc`0TV`m0P2AIST2099W>P0609=X>`2DJC`0U6Tl09AY?02=
IcP0S6Hg0P2;ICH01`2<ISL0SVPi091Z>`2AJc`0Sf@g095V>@2BIcX00P2DJC`01P2BIcX0TFHi08mT
=`2AJc`0T6Xk08eW>080S6Hg00<0SFLh091Z>`2AJc`00`2BIcX309=X>`80U6Tl00<0TFHl099W?@2D
JCl00P2EJT0209AY?`03099W?@2AIS`0U6Tl00L0U6Tl0140T6/g099]>@2DKc/0UG0l09Ia?@2EL3`0
U6lk09=^>P2DJSP0UF/i09M]>`2HKS`0VFlm09Q^?02GKC/0UV`j09A^@@0309=]@080TV`o0P2AJch2
09E`?080U6lk0P2CKSX2099]>@@0TFHi0P2@ICP208mT=`80RfDf1P2:I3D<08UU=@@0R6@d0P2<J3P0
302=JCT0SVXj08m[>`2@K3`0TFdm099^?P2?K380Sf`d08m/=P2?JcT0SfXm08mZ?P80SfU200<0SFTi
08iZ>P2@K3`00P2AKCd01P2@K3`0SVXj08eY>@2>K3`0S6Xj08YX>080R6Hf00<0RFLg08YX>02;JCT0
0`28ISH00`27ICD0QV@d08IT=00208ES<`0808AN=`21GSH0P5dg07aJ=@1gES<0L58`06Y=:`1XBb/2
0592800?0511801>@B40Bd0R04U08`18?b80AChR044e7`12=R00@SLS040h9@0n=b@0>cHS03Ld8`0e
<R40;RlQ0080;BhP00<0;2dO02//7P0Z:ad00P0Y:Q`01P0[:A`0:bTM02PX700U9a`092DM028U7P80
7b@N00<07R<M020S700P8a`01P0P8a`03P0O8QT082<J024T6`0R9A`08bHM02@W7P0U:1l09RTP028V
5`0R9QP08BDG020S600O8QT07R4J0P0M7aX301dO70<071hK0P0K7AX07P0K6a/071`J01hN700P8A`0
8R<M02@U7@0V:1d09bTN03<^6`0e;Q`0=RlL03Ta700m<Q`0@3@N04<d7@14=Ah0@SLG048g6@10=Q/0
?3@O03L`7P0a:al0:bLN02PS7@0S8Qd092<N02HV7P0Y:Al0:b/O02d^8080;c0P02H0>3<P03Td8@0j
=B80>SDR03Pc800f<Ah0=2lL038]6P0g<Ql0=S4N03D`7@0d;a`0=C0M03Lb7`0i=240>cHS03<[7P0b
:Qd0;bTK02/X6@0Y9aP09bPH02PY6@0W:QT0:2PN02XZ800[:b40;2`R02/[8@0Z:R00:2PN02HV700X
9QT09bDI02DU6@0S9AX08R<K020S70807B8L0P0O8Q/201hQ6P<07B0I0`0L7aP08@0M81T07R4J01lR
6`0P8a`08B@M028U7P0/9RH0:bHS02XS7@0X81D0:R4B03H[5`16?2<0DTH/08AU;P29JS@0TG8l09Mg
A02EMD@0SVhm08AT=@1mGBh0H58]05129`0g;Ql0:B4O02<Q9P0R9RT08BXY020[9@0V:B809BPQ02@W
800202<V7`0402DX8@0V:B80:2/T02P[90809RTR0P0W:R<302P[900402T/9@0V:B009RTP02HY8080
9bXQ0`0X:b804P0Z;B@0:bhU02d^9P0_;bL0<c0Y03Ha:`0g<R`0>S<]03hi9P13?2X0Ad0]04Lo:P15
>R@0@SHP04@e7P16=b00AChT04Ho9@<0Ad0V00T0AChT04<l8P12>b40AcdT04Pn9@19?bH0BT0W04]1
:01<@RT00P1=@bX05P1>A2T0Cd@X0515:@1CABP0EDHW05M79P1JAbH0FdPW05a;;@1MBRX0G4TY05e9
:01QBRP0I4`X06Q>:@1ZD2/0LUDc079F<@1cEC40LeD_07EE;P1fEB`207MD:P80JU8^01/0J54_06IB
<@1TDC40HU8a069A<`1QDSD0I5<i06IB=`1UDS@0Ie<b06]E<01_Ec40LeXb07AK<P26FRT0R5h/08QR
<@27IcH0Q6Pf07iX=P1hIS@0M6@a06mR?`1]H3d0JU`i06UI=`1YESD00P1ZESD09`1]ESH0MUXc07QL
=01kGS@0OF4b081Q<P22HRl0Pf8]08=R;029J3<0SF`f09Aa>@2KMc/0XG/l0:En>`2UOST0YWhh0:22
>@2QPc/0XhDo0:B5A02TQDD0Xh=80:61B02POdT0UgDf09Yh>@2OOCh0XX110:>1@P2POSl0W7Xk09Yh
>@2TP4@0X7a009ei?@2PO400YX960:f9C@020:n;C`080;b?E02kSe80^XiA0;V=CP2jSTd0^i1<0;fB
C@2oU4l20;J?C00[0;B=C02cS4/0/h]=0;>;CP2_Qd`0Ygi60:1g?`2UM3`0ZGQ00:Qk@P2RN3h0Ug0e
08e[;P29JB`0RF/]08YZ=`28J3D0QVHc08EU<P27Ic@0Rf/h08m_?02BLSl0Q6/c08EZ<`28JS@0S6/f
091[=`2EJcT0V6`k09Y/>`2HL3`0Vg<o09ad@02ILCd0UFdi099Z=P2DK3P0Uflk08eZ:P2@KBd0UW<c
09]h>00209ml?00509ik>`2MNSX0WG@l09ed?02LLc/00P2KLSX01P2JLCT0VG0h09U`>02ALC@0Tg<f
09Ad=`<0UWHi00<0UGDh09Ad=`2MM3`00`2NMCd209mf?P80X7Lo00D0Y7`n0:In@02YPD<0[8A60:n7
B@030;28BP80[X@h0P2]PcL30:b2=P0=0:^1=@2RP3T0XWlk0:9o>`2QOS`0Wg`l09ei>`2JMSX0V7@h
09I`<@2GLC80VW@e09af=`0409ih>@0<09]h?P2JMcd0VGHn09Qe?`2GLcl0UG4o09A`?P2DL400TFm1
091^@02=Jcd0RfTk0P2:J3X05@2;JC/0S6Xl08MW=027Ic@0QFDd08AT=@22HC@0PF0e07mN<`1oGSD0
MV0_07QP<01iHC40O64b07iR<`21HS@0Pf8e08AS=P1nGbP0PF8[08EV;`0208MX<@0<08AU;P20HBX0
OEhW07]P:`1lHB`0OF4_07iR<P1nHS<0OF0d07]N<P1jGC<0LeLb0P1bES40701aEC00Ke<^06eA;01Z
CRT0J4`W06I:9@1XD2X0Je<]06iF<01`F380KUH`06YB;01UCBL0HDTS06M:7P1[CR80L5<W07AG:`1e
F2`0M5L[075D:01_DRH0NETX07YJ:@1kFbX0O5`[07iN;@1oGbh2081P;`0307mS<@1nHS00OV8`0080
OV8`00/0Of<a081T<P20I380OVD_07eT;P1lHRl0Nf4`07UN;`1hGC00Me`_07IK<002079M:006071J
:01^F2L0JeDV06UB9P1WD2H0ITlU201TDbL0401RDBH0HE0U05m>8`1NCB80H4lT06=B9`1XEb`0JeX_
07=L<01dGRl0MEl`07MQ<01iHc40NfHa07aW<01mJ34807QS;P80NF<a00@0N68`07MQ;`1fH2h0MV0^
0P1eGbd01P1jI380N68`07EO;@1bG2X0L5XX06mI9`80L5XX0P1/EbX0101[ERT0JE@W06MB9@1VDB@2
06A?8P0P06E<901VCBD0ITlV06E?9P1QCR@0GD`Q05U87@1EAQ/0GDTT05a89@1KAb@0FDDT05M28`1E
@2<0E3lT05<n8`19@Ad0BD0O04Ln7@16?Ah0A3/N04<i7P12>1l0@CLN03P_7P0g;Qd0=2dM030Z700[
9a/09bDH02DS5`0Q8AD201`N7@0301/M700J71/06A/J008061XI00<05aTH01HH5`0F61L01`0F61LH
01DF60P051DG200E5QP@01@E5`P05AHH0`0A5aL3018H60804aTI400E5QP801DG5PP05QPG200G6AP8
01PH608061PF0P0I6AL201XJ60806a/I0`0J6QP301/K6@8071`J200M7A/901hM6`P07AdK0P0L71X3
01dM6`<07QhL0`0K6aT201`L6P<07AdK0P0M7QP201hO6@807b0J0P0P8A/3024Q6@808R8J0`0S8a/8
02`V6P0;02hT6P0`9Q`0<RPN03D[8@0f;280=B/Q03@Z800c:Al0?2PO03hZ8@0o:b800P10;2<00`0o
:b80?RXQ03`X7`0803h[7@0403T]7@0h;1`0>2`L03P/7080=b/K0P0f:QX203T/7080>RdM100k;Qh3
03X]7080>bhM0`0l;ah02@0k:A/0?B/M040_7`13<R00AC@P04De7P14=1d0A3@K04Hd7P0304Le7`80
B3HP0P19=b401015<a/0AcDM04Tg7`1;>B4204dk8`80C3XR0P1;=al0101<>200CCTQ04hj8P1?>b<2
050l900505Pi7@1I>Qh0FCXN05Xk7`1K?2000P1L?B403@1M?R80EcTO05Pj801I>b40FcdS05do9@1O
@BL0H48X0653:@1I>b40F3XP05Li7`1F>1h00P1G>Al00`1I>b40G3hT05do9@0205To900405Pn8`1G
?B80ES`Q05Dk8080E3XO0`1F?2D205Dk90<0E3XS00H0DCDP058f8@1B=R40DcLR05@h8`1E>B@205Hj
9@0805919`1B?RD0Cc/R04hh801?=al0D3HO058f801C=b4205Dj7@80E3TL0`1C>1/00`1B=aX0B3HP
04Pf800604Pf800404<a6@14<QX0AcDM04Tg7`<0BSPP00@0BCLO04Le7@18=Qh0B3HN0P19=al204Xh
800904/i8@1==al0CcTQ05<k8`1E>b@0Ec/U05Tj9@1H>B@0F3PS00@0FS`R0P1K?B<205`n900H06=5
:@1QA2H0Gd8T05i18@1N@Al0H4@O06=7801UBB80I4H/06=5:@1R@bL0HD8U06=28`1V@b<0JDDS06Y6
901UA240ITDR06Q7901ZBBH0KD`Y06m>:`1aD2d0LU4^201cBRX00`1bDR/0LE4Z071@:@02071@:@03
079B:`1dE2d0MED^0080LEX^00D0M5T^07EH;P1hEbh0NeD^07aE;P0307iD;P0307eF;`1lERl0NUL_
0080NEP_00d0NET`07]K<P1hF2l0MUH]07QH;`1jFS40NET`07=C:P1^CRD0KDlY06]=9`1XBR@0IDLQ
00<0I4HP00L0IDLQ06I88P1TB240I4PQ06=78P1SAR@0HTDU0080HTDW00`0HD<W05=0801D@B40F40T
05To9P1K?2L0G3TV05/f9P1J<b@0DCdU050l901>>R8204di8@0404hj8P1@?2@0DCdU04/i8@80C3PP
00D0CCLP054h8P1D>B@0F3`W05Tm:002060m7`04064n801R?b40Hd0R06A18`80ID8T01@0K4//06]:
:`1[BRT0K4/X06i>:01`D2T0LU8[07=C:P1cC2<0MTlV07YC:P1mERd0OUL^07eF;@1jDbX0N54X071@
9`1cDbX0N5P_07eM=080P60g0180OUhe07eM=023G3D0Q5df08AN=`22GcL0P5lf07eM=01jFS40MeX`
07QA<01gDc40N5@b07QF<`1fEC80LU@`06iB;@1/D2/206e>;`0306a=;P1[C2d0JT//0080JDX[00@0
J4TZ06Y9:P1ZBBX0JTTZ0P1YB2T306Q7:00506E69`1VAbP0ITLX06M8:@1XBBX00P1YBR/00`1ZBb`0
J4XX06Q::00606Q::00406Q:;P1WBBd0IdT]06M9;@80ITP/0P1UAb/02`1QBRP0H4TW06599`1RB2L0
HdHV06A59P1VABH0ID@U06Y9:P1[BR/0K4//0080KD`]00/0JdX[06U8:@1WARL0JDHX06Q59`1VABH0
Hd@U06=69P1SBBP0ID/Z06I>;00907=<:`0307EE;P1dE2d0Le</0080LE4Z00T0LU8[07=C;01dE2d0
ME<]07ME;`1kF300PE`b08=N<P25Gc800P26GBl01P25HC40Q60`089N;P20G2`0Oe/[081L;080PEd]
00`0R6@d08MS<`26HS80QF4a08AP<023Gbl0PUh^085M;@24HS80Pf4a085O;`1oGBd207iL;080Oed]
00<0Q5le08=N=021G3800P20Fc400`21G380Pehd08AO=@0308=N<@<0PUd`0P21G2l8089O=`08081P
=`1oGcH0OEdd07aL<`1mGC@0OUhe085Q>022HST307iH<B_ooooo000Zooooo`P0WG=1202PM4<809mc
APP0WgE300<0XWQ60:5gA@2PMT@0102NM4801`2OMD<0X7A30:5eA02QMD@0XWI50:=gAP2TN4L00P2U
NDP02@2UNdT0Y7Y80:5gA@2PMT@0WgE30:1fA02RN4H0XgU70:EiB0020:AhA`030:=gAP2RMTD0XWI5
0080XGE400H0XgY40:9i@`2QN480X7M109mf@02MM3h209ac?@80WW=80100WgA909icB02LLDH0W756
09Y_A02GK440UFXo09E`>`2EL3`0U6lk09=]?02BK3d0TF/n095Z?`2@JCh0RVDk0`2;IS`0202:IC/0
Qf8h08AO=@23GS@0Pf0f089O=@20GC<0OU/a0P1mFS0207iK<@80M5DY00<0M5@[07=C;01cDbd00P1b
DBh01@1bDC00KU4_06e@;P1ZCB/0IdXX00<0ITTW00@0IdXX06E89P1UB2H0IDPV0P1VBBL306M::080
IdTW00@0J4XX06U;:@1ZC2X0Jdd[0P1/CR`00`1bCbT0Le0Z07=@:P0207AA:`<0ME8/0P1oFC@01`20
FS<0PUdc08=N<P24Gc80QF4a08IR<P28HS<00`29Hc@208YT=@80RfDf202<ISL808mY>P@0TFHi102B
IcX00`2EJSl0TfPm099W?002091U>P03095V>`2BIc`0TfPm00<0TFHi0`2@ICP208mT=`80Tf@h00<0
TFDh095V>@2AJ3X00P2@JS/0102?Jc/0TFHi095V>@2AIST3091U>080Sf@g0`2=IcP00`2>J3T0SfTj
091Z>`02091Z>`<0TfPk0P2DJC`409EZ?@@0U6ho0`2CKCh02@2BK3d0VFi409U^A02HKD<0UV]109AY
?`2CJ3h0TVLm095V?00209I[?P80Uf`o00@0V6e009U^@@2IKT40VVm2202FKCL309EZ?@80U6Tl0`2C
J3/01P2@JS/0SfTj08mY>P2>J3T0SFLh08aV=`80RfDf0P29HSL00`2:I3L0RV@e08]U=00208aW<`03
08eX<`2:IS80RVHb00H0RVHb0P2:ICT00`2:ICP0RfLg08]W=@0208aX=00708aY<`2;Ic<0RfLc08aX
=02=JCD0SVXf08m[=`02091/>00;095]>@2DL3`0UW8n09Qd@02ELCd0T6`h08YV<P27Hbl0SVXf08m[
=`2@K3P00P2BKSX00`2AKCT0T6`h08m[=`0208mV>P0408eW>P2<IcX0S6Lj08YX>P80RVXk0P29JS/0
1027J3T0QFHg08AU=P22Hc@2081Q<P0H07mO;01nGRd0O5d^07MJ;P1aEBd0JDlZ06A:9`1PB2H0DT@Y
04m19P19?B<0AC/R04<k9013?BL0AT0Z04M2;P10>BH0?CHT03Td8@0d<B00<2hO02`]7`0/;200:bdP
0P0^;1d0100[;1h0:B/N02PZ7`0V:B0202<X8@808bHO00@08RDN024T7@0O8Q/07R4J0`0M81T301lR
6@8082<J0`0Q91/5028S6`<08b@L200O8Ah201dN60807QlI0P0O81X2020Q6`0=01dO700N7aX081lJ
02DQ600/91T0<bLI03P[6`0l;1`0?30F03da5`10=1X0@cLM04Di7`0304Hj800=044k8`10>R@0?3LS
03Ld8`0b<2<0;2`R02TY8@0V9b409B8I02LT6`0[9a`0<2XN03<[7P0203D/7@0603L[6`0j;aT0>RlI
03X_6`0i;Q`0>BdM0P0i;Al00`0i;B40<BdQ034]8@06034]8@0602h_8@0];R00;2dO02//7P0Z:ad0
:BXL0P0X:A/0100[;1`0:R/K02X[6`0Z:a/202TZ6P80:2TI0`0S91h3028S7@808B8L0P0N8AX201dP
6@0P01`O600K7QL06ahG01XM5P0H7aP06R4J01hS700Q9ad092LL02DW6P0U9AT09BHH020Y500U:AX0
:RPL034T700i9QP0CS8J06M78@1iEbX0S6]2095a@P2EMd40UG]208ie?`21JCd0LeXk06UA>@0_<R/0
;S4Z02/^9`0Y;2D202P[9080:B`U0`0T9b0202DX8@@09RTR200X:b@302X[8`0302TZ8P0X:B409bPP
00809bPP0P0/;bP0;P0/;BD0;BdS034_8`0d<2@0=S<T03Xd9P1:>2X0AcLX048e9@0m=2<0?CHT03dj
9`0o?RX0@48]04i2;01AABl0DDHb04a4<@16?b`0@SdZ044n;@13@2l0AShW04Lo:01<@RT0CT8X0553
:01A@RD0D44T050o8@1A@R40D44P05107`1C@200ED0Q05Y3901MARL0H4LY06199`1UCR`0JU8^06Y@
:`1YCBH0JTdU075A:P1fERd207ID9P0307IE:01fEb/0MEP^0080METa00L0M5/c06AE;01VE2h0IE<]
06EA;P1WD300Idh`0080Id`_0P1[CBL0901[CRH0KU4W075D:01fFR/0Nel`07eQ<@1iHc@0NV@e07]U
=P1lISL0NfDf07YT=@1hHS<0Mf4b07EN?01cG3X0LETe071F<@1cEc00MUTa07]K=01nGSD0O5hh07aO
=`1kGS@0Nel`07aP;P1nHbh0PFL^089X;`27JC<0RF/e08e`>02BMC/0UGPl09Ii?@80UWXk00@0V7Po
09]k@P2NOTD0XH580P2SPdX06P2RPTT0XH5809MnA@2HOTD0VGm609]nAP2KO4D0VWU309Yg@@2IMT00
W7Xm09mm?P2UOd40YWi00:Um?P2_Ocl0]hI40;j;BP2lT4D0`9A;0<>IC`30V500_9I?0;ZEC`2kUU80
_9UE0P2gTT/0;@2eT4X0/Y190;>BC@2cU540[i9@0:J8B02MPD00W84n09Mk>P2?LSH0QfXb08=U<`23
I3P0QFDn08IV@01oJ3H0P6Te08=Y=P25JSD0RF/e08]/=@2<KC@0SVhe09M[?02FJS/0U6Pg09=X=@2D
JC@0UFXc09M/=@2IKcD0Vg4e09ab=P2NM3P0WgDi0:1f>P2OMCT0WW@h09ec=`2@JR/0Tfd^09Ma<P2L
MSL0WgTj0:5k?0020:9l?@0H09mf@02LMCh0VW<l09Ia>P2DLCT0TW8i099c>P2CM3/0UGPl09Ih?02G
Mc`0VWLm09ef?@2PMCh0XWDn0:=d?P2JMC40VgHb09ii=@2QO3P0Y7lk0:R3?`2ZQD40ZhI20P2eR4D2
0;J9AP80]hY70P2hRdP0202`RcX0[XTi0:f8>02_RS`0/he20;>=A02`RT<0ZhDn0P2WPD801P2UOd00
Xgdn0:1j>`2NN3T0WGLh09af=`80WgPg0P2PNCP20:5j>@80XW/j00T0WG/n09Qf>@2CL3H0U74g09Md
?02GM3h0TVhj08eY=@29Kc@00P28KS<00`26K340QF/`08AZ;`0208=Y;P80RFDe00@0R6@d08MS<`27
Hc<0QV8b0P25HC4208AO:`0>08=N:P22GBT0PehZ08EP;027HRh0R6<_08]^8P2<KRD0SW0Z08m`<02=
KC@0RVTd08ES<`22H382085X<004089W<024IS00QFH`08EV<080QF@_00T0Pf@h07mP=01oH3@0MUT_
06mD:@1ZDBP0JE8Y06YD;@1/ERl00`1XD2X0201YDB/0J50Z06Q@:P1XD2X0IdlY06I?8`1YDRH0K5DY
0P1_F2`02`1^Eb/0K5DY06aE:@1cGS40Leh_07EO<01gGbl0NV0_07eQ;`1oHBd0P68^00@0OF4_101n
HS0207mS<@80OV8`0P1mHBl207aP;P80MV4/00H0M5h/079L:`1`FR/0KUL[06aE:`1[E2X806IA9080
IdlY00L0ITlV06M@9P1XDBD0Je@X06iH:@1_FBX0Nel]0080O60^00<0OF4_07iR<01oHc400P20I382
07]W<P0407aW<P1lIC40OV@a07iR<080P68`00H0OV@a07eS<01mHc00O68_07]Q;P1jH2d207UO;00<
07YP;@1kHBh0Nf4^07]Q;P1iGb`0MedZ07AJ9`1cFBH0LU/_071I;@1^Eb/0Je@X0`1ZDbL0:@1[E2P0
J5<V06MB9`1VDBH0IDlV06==9P1RC2L0HDXX06199`1PCRX0G4TX05Q5901GA2@0Ed@V05I29`1B?RD0
CSXQ04m2801=@1h0BSdM04Li7015=a`0ACLM04Df7`16=b00?S<M03/c700j<Ql0=c0N038/7P0/:1d0
9b@M02@Q6P0Q8aP0828G01`O5P0G71D05A`E018K5P0C71L04QdI00@061XI0`0G6AP201HH5a005AHH
200D5AL@01DF610051DG400E5QP301@F5@<05ALF0P0F61L801DG5PP05QPG0`0E5aH201HH5`<05aTH
200J6QX@01XJ60P06a/I0`0L6aH201dL5a@07QdH200N7QH801hM60<081lJ0`0Q81/2028Q70<09QlI
0P0W81X302PQ6`80;B<I1P0/8QP4034W6`80<RPL0P0c:Ad803T]7@0303PV600j:1X0?2XL0080?B/M
00<0?2XL03XX6P0i9aT0200f;A`0100d;1T0=BdJ03D]6P0e;AX203H^6`80=blL0`12<Al00`11<1h0
@2lM03l^700203l^7006040^6011;aT0@BlI048`6P13<A/0A38L0P15<ad00`1<>200BcLO04/g7`05
04Xf7P0404dg7`1>>200CSPP04hh8080CcTQ0P1@>R802`1C>2<0DSLR054f8@1@=B00DCHQ05<h8`1F
>bH0F3dX05/m8@1J?200FC/O0080F3XN00/0FC/O05Xl801K?B40GCdV05`l9@1J>R<0FCTR05Xj8`1K
>b@0GCdV05lo:00205Xl8PL0FcdS0P1E?B<205@l8P0805<k8@1B>R00DCTO054i7`1I@2X0EchX05Dl
9P1B>B<3050g8@04054h8P1I>2D0FCPU05Th9@80F3LT0`1G=R<205Dk900405@j8`1C>B80DSPQ058h
8@80DCLP0`1?>B8204hh8@<0CCLP00P0AcDM04Hd7015<a/0AC<K04Hd7019=al0BcTQ04dk8`<0CC`R
101<>b402@1;>R00D3PP04lg7`1>=Qh0CCDM04hf7P1?=al0DCTQ058j8P0205@j7`<0EC/P0`1F?242
05/l800905`m8@1N?b<0Gd0T06119@1Q@RH0HT<W06E69`1SA2D0HD8S0080H44R00T0HD8S06=49@1T
ABH0Kd<V06e49P1/ABH0J4DU06A6901RAB<00P1OAb<806Y99PP0KTdZ0P1`C2`206m;:`04075=;@1d
D300Me<c07UE=@80Le/_00<0M5T^07EH;P1gEbh00P1gERd02@1hEBd0Me<_07UE<@1lF3@0Oe/g085M
>@20G3P0Oe/g07iJ=P0207QI;@0307QH;`1gEc00MeLa0080MUDb00H0MUDd071?<01_CRl0KTd^06a;
;01[BR/206U8:@0=06Q7:01WARL0JT/^06Q9;01VAbX0I4DX06=49`1TABP0IDHY06I7:P1J?2@0G3hV
05i0:00205m1:@0S05do9`1J?2@0F3XR05Hm7P1E?1d0EC`N05<i7P1B>1l0DCLP050f7`1@=B00E3TT
05<h8`1B=b80DCHQ058g8P1D>B@0Ec`W05Pm:01E@R@0ET4R05Q18P1J?b40Gd8R06E48`1YAb@0KDTW
06]::`1/Bb`0KD`[06m>:`1aDB/0LU8[07AD;@1dE2/0101gDbl407QD<00507EF9`1gF2T0Ne`]07iO
<020HC800`21HS<02020GcH0PF0g085P=`22HCP0PF0g07mN=@1mG3<0NeXa0P1kEc<00`1jES80NEDa
07QD<00207MC;`0907IB;P1fERl0M5@^075A:`1_CR/0KTd/06i=;P1_CC40L4hb00<0Jd/T1@1ZBR<0
201XAb@0JDPU06Y99P1[BRL0KD`Y06m>:`1`Cb`0LE0]0P1^CBX306e<:@<0K4/X0P1TAR@206E79@04
06I89P1WBBL0IdTW06Q::080I4HT0P1UAbD0101VB2H0IdTW06Q::01XBRP206E8:080ITTY00D0IdXZ
06Q;:`1XBb/0J4/[06A79@0306E89P80ITTW0P1WBRP0101aCBT0LThZ079>:P1bCRX207=?:`<0M50/
00H0ME8X07IC:@1gE2X0N5D[07UF;01jEbd207]H;P<0P5/a0P21G383089M<`80RFH`00`0R6@b08MS
<`25H3@0Q5hg08=M>023GCT0Q68d08=Q<`22H380PEla081N<01nG2h207eK;@@0P5dc1021GS@00`1o
GS<0OUdb07eJ<00207iI;`0C081I<024FS80QE/c081J<`21Fc@0PU`e08=M=P24GSL0QElh08IP>@27
HCX0R6D_08MS;`25HBd0Pel]089N;P23GS40QF0d08IQ=@05089L=@<0Pedf0`21GS@[ooooo`00:_oo
ool809id@PP0X7A3202OLdH809me@`<0XGM50P2PMT@00`2OMD<0WWA209ec@@030:9fA@<0XgM60P2T
N4L00`2SNDL0XWQ60:5gA@020:1fA0030:5gA@2SNDL0Y7Y800<0Y7Q700<0XgM60:9fA@2RMTD00P2Q
MD@20:5h@P80X7M100@0WgI009ie?`2MM3h0WG@n0P2NLdH0402OM4L0WW=609aaA02LLD@0VVm209M/
?`2FJch0U6lj09A_>`2CKSX0TV`k095[?02@JSd0T6Tn08mX?@2:IC/308]V?00808YU>`27HSP0QF0f
08=N=023H3H0PUle081M<`1nFc4207eJ<080OU/a00D0MUL[07EF:P1eEB`0M5@]079B;002075@;@05
071?;P1^DBl0KE0^06Y=:`1XBbT00`1VBBL00`1WBRP0IDPV06E89P0306I99`<0IdXX0P1WBBL0101X
BRP0JD/Y06Y<:P1[CB/206a>;004075>:01bCbT0LTlY07=@:P80ME8/00X0MU<]07MD;P1oFC@0OeTd
081J<`22GC<0Pehb08AO<P25HC40QV8b1029Hc@208YT=@80RfDf202<ISL808mY>P@0TFHi102BIcX0
0`2CJ3d0TVLl095V>`0208mT>@03091U>P2AIS/0TVLl00<0TFHi0`2@ICP208mT=`80Tf@h00H0TFDh
095V>@2AJ3X0SfTj091Z>`2?Jc/3095V>@<0T6Dh0P2?I3L208eW>080SVPi0P2?JCX2091Z>`<0TfPk
0P2DJC`409EZ?@P0Tfdn00H0V6e309M/@P2GK480UV]109EZ@02DJCl209=X?P80UV/n0P2GK3l209Q]
@080VFi1202FKCL209EZ?@<0U6Tl0`2CJ3/01P2@JS/0SfTj08mY>P2>J3T0SFLh08aV=`80RfDf0P29
HSL01P2:I3L0RV@e08]U=02;IS80S6Lc08aW<PP0RVHb0P2:ICT00`2;IST0RfLg08]W=@0208aX=007
08aY<`2;Ic<0RfLc08aX=02=JCD0SVXf08m[=`02091/>00;099^>P2CKc/0U70l09Ea?@2CKc/0T6`h
08eY=@2:IS80SVXf08m[=`2@K3P00P2BKSX00`2AKCT0T6`h08m[=`02091W>`0408iX>`2<IcX0S6Lj
08YX>P80RFTj02H0RFXk08QY>P27J3T0QFHg08=T=@22Hc@0P64b07mP<@1nGRd0OEl]07]L;P1eF2h0
L5@]06Q>:@1RBRP0GdLU0553:01?@BH0BCdS04Dk8P12>R<0@cdW04Do:@16@Bd0?cPU03df900i=240
<c0O030^7`0/;Al0;2`P02/]800^;1d0;B/L02//7P0Y:ah0:2XO02HY80808bPQ0P0R9Ah0100Q91d0
82<L020S700O8Q/301hQ6P<07b8I0P0P8aX3024T6`H08R<K0P0S91`801hP7@807AhH0P0N7aT201lP
6P80824K00d07R0M01lP6`0Q81/09R8I02dU6P0d:1X0>B`L03d]7@0l<1H0?S8H044e6`14>1h0ACTO
0080ASXP01L0ACTO044k8`0o>B<0>cHR03Db8@0`;R40:RXP02LW7`0T9Al09b@K02TW6`0]:Ah0<R`P
03D]800g;Ql0=bhM03P/700i<AX0>C4L03P`6`0h<1d0>2lN03L^7`0203L]8@P0<BdQ0P0];R00100/
;Al0:b`N02X[7@0Y:Q`202PY6`<0:R/K0P0Y:QX302PY6@<08b@N0P0R8ad3024R70807R4J0P0M81T0
2@0L7aP06ahG01/N5`0K7QL06B0I01/R6`0N8a`08bHM02DW700202HV6P0E02LU600S:aH09bXI02dY
7@0g:al0Ac8Q05a19P1bDR/0PEla08i]@P2ALT@0U7U409=jA029LT00NF8i06QA<P1KABh0;S4Z02`_
:00Z;BH0:2/T00<09bXS00@0:2/T02@W800T9b0092LP0P0U:24402HY8PP0:2/T0P0Z:b<202TZ8P80
:2TQ0P0W:20202/^9`0l02`]9@0];B<0<BlS03@`900g=2D0>cDW04Hf9`13<b@0?c8R03Xa800i<R00
>3DR03Xi9@0m?2P0BclY04e1:`1>@bl0BD4^04<l:@10>bP0?c`[048o;P15?BH0AShW04]1:01>@RP0
DD<X05939P1A@RD0DD0R05938P1A@R40DT8Q05A18@1G@R<0Fd@U05i7:01QB2X0Hd`Z06I?;@1[Dbl0
Je4/06U=9P1YC2@0KdlX07=C:P1dE2D0M5<V07=D9P1aE2P0L5DZ06iE;01_ERh0KUL^065B:`1SDB/0
He4]06A@;@1VCbl0Idh_0P1YCS409P1[CbP0K50Y06a@:01^DbP0LULZ07IK;01jGc00O68a07US=01j
I3D0NfDf07aV=`1kICH0NV@e07QR<`1gHC80M5dk079K>@1`F3@0L5Ha079F;`1fFC40Ne/d07iN=@1n
HCT0OF0f07aO<`1lH340O60^07iS;P20IBh0PFL^08EW<`27JC<0Rfdg08mb>P2BMC/0U7Lk0P2ENCX0
2P2EMC`0VGU009inA@2RPTT0YHE<0:B4B`2RPTT0XH5809Il@@2ENd0209Mj@00D09Uj@@2JNT40WGY2
09ej@P2MNc`0XWi00:J0@@2XPD00ZWhm0:f0?@2eQD<0_8]80;nCBP31Udd0a9YB0<6ID`2mUU40_9MA
0;fJEP31WUX20;^FD00E0;NECP2eTTh0]YEB0;FFE@2aTe<0Z8a=0:65AP2HO3/0TgLh08a_=@25Ic40
PF<a085R=P23HcX0QFDn07eV=020IS<0PFLd08=X<`27JC<0RFXc0080Rf/b00/0UFTj09AX=`2CIcH0
TfPe09AY=02FJc@0V6hd09Y`=P2LM3L0WGDh09if>@0209mg>P0809if>@2LM3L0Vg<f09=];P2EKc00
V78c09]e=P2NN3T309mi>P0>09ie?`2MM3h0VW<l09Mb>`2ELSX0U7@k09If?@2FMch0UWPl09Mi?@2H
N3d0VgLm09ig?P2PMCh20:=f?`0909eg=P2NN3L0X7Xi0:9l>`2UOch0Z8910:V3@P2ZQ4<0/hI30080
]8M401<0]HQ50;N:A`2hRdP0^8]80;V<B@2bSCd0/8/m0:j9>`2aRd00]8i50;B>A`2`RD@0Zh@o0:V3
A02XPT<0Yh520:Eo@02SOCh0XW`m0080X7Xk0`2QNC/30:9j?080Xg/m00P0W7`o09Mg>P2CLcP0Tg<j
09Ie?`2FMD00TW4l08i]>P80SVhe00@0SFdd08a/<`2;Jc80RVXa0P29JC000`2;IcL0RVHf08YV=P02
08UU=@80R6@d00<0Qf<c08UT<028Hbl00`27HRh02`29I300RfHb08aW<`2;KB@0SFlW08m`;@2?L300
SVhe08YY=026I3@0Pf4c00<0PVL`00H0PfD_08AU;`24IBl0Q6D_08AS;P21HS@207iO<`0707MJ;P1b
Eb`0K5<Z06YC:P1ZE2d0JeD^06M?:@0406Q@:P<0JE4[0100J54U06E>8P1TCB40JE8V071I;@1dGC40
LEX^06aE:@1bGC00Leh_07EO<01gGbl0NV0_07aP;P1oHBd0P68^1@1mHBl307iR<0<0Of<a00<0OV8`
07eQ;`1lH2h00P1lH2h207IQ;00607AN;01bG2/0L5X[06iG:`1]ER`0K5D[201VDB@0201XD2X0IdlY
06M@9`1WD2H0JE8V06aF9`1_FBX0L5XY0P1lH2h207eQ;`0407iR<01oHc40P6@b081T<P80NfLb00@0
O6Lb07aU<@1nI340OV8`0P20HS0207iT<@0407eS<01lHRl0Nf4^07YP;@80NEl/0P1kHBh207aR;`08
07]Q;P1hGR/0MU`Y07AJ9`1aFRh0L5T]06eF:P1[E2P306UB9P0706YC9`1WDRD0IU4V06E@9@1TCRD0
HT`U065;9P0206199`0>061>:P1LBRH0F4DT05Q59@1IARP0FDDZ05E19P1A?B@0D4<Q04i17`1;?Qh0
B3XM04Hh7@15=ad204Hg800@03hd6`0n<ad0>c<N03Pa7`0c;Al0;BTN02TU700U8Q/08B<H01lQ5P0L
7aH05a`E01@K500D6QH04Q/F018K60@061XI0`0G6AP201HH5a005AHH200D5AL@01DF610051DG400E
5QP301@F5@<05ALF0P0F61L801DG5PP05QPG0P0E5aH301HH5`<05aTH200J6QX@01XJ60P06a/I0P0L
6aH301dL5``07QdH200O7QT801lO5`P07QdH0`0P7aX3024P6`808R4L0P0V7aT302LP6P<0:24K1@0]
8aT302hT6P04030V6P0a9a/0<BLK034W6`80<RPL0P0c:Ad803T]7@0303TW6@0k:A/0?2XL0080?R`N
00<0?B/M03`Z700k:A/0200f;A`303D]6P80=RhK0`0g;a`3048a7`03044`7P10;ad0@2lM0080?bhL
0P11;aT00`12<1X0@c4K04@b700204Dc7@0304Hd7P1:=Qh0BSHN0080BSHN1019=Ad304hh8080CcTQ
0`1@>R802`1C>B80DSPQ054g801A=b00DSPQ05@j8`1F?2D0F3hW05`n8P1J?200FC/O0080F3XN00H0
FC/O05Xl801L?R80GCdV05`l9@1K>b@205Xj8`0305/k901M?BH0GShW0080G3hT1@1K?B<205Xl8P04
05Dm8`1D?280E3`R05@l8P@0Dc/Q00@0F40X05Lo9`1D?2@0DSXR0P1A>B40101B>R80Dc/S05Xj9@1J
>RD205Ti90<0F3PS00@0EcLR05@j8`1D>R<0E3XS0P1C>B83058h8@04054k8`1@>R80D3XR050j8P80
CcTQ0P1>>200201;=al0BSHN04Te7@18=1`0BCDM04Xf7P1<>200CCTQ101>>R4404di8003050h801?
=al0CSHN0080CSHN00<0D3PP054i8@1C>b<00P1D>Ql305Dk80<0ES`Q00D0G3dQ05dn8P1M?R80GSlS
05m0900206119@0406529P1SA2D0HT<T06528`80H44R00<0HT<T06=49@1UARL00P1]A2H01P1ZARH0
J4DU06A6901SAR@0H4HS05m78`P0JTTV201^CBX02@1aCB/0L4`Z071<:P1`C2X0LTh/07A@;P1gDc40
NEDc075I;@0207=H;@0307AG;@1gEbh0N5L^0080NEH^00@0NEDa07YF<P1lF3@0OETe0`1nFSH01P1m
FCD0N5T]07QI;@1hF2l0MeL`07MG<@80MUDb00H0MUDd07AC=01cDS<0LU4b071?<01_CRl206e<;@06
06a;;01[BR/0JT/^06U:;@1WB2/0IDHY0P1TABP206I7:P80HD<[00H0H48Z05m1:@1M?bL0FS`T05Li
8@1F>20205Hm7P0605Dl7P1D>Ql0DcTP058h8@1A=b00D3DP0P1D>R<2058h8@0D05<i8P1D>R<0ES`U
05Pn9`1F@B@0ET4R05Q18P1K@280Gd8R06E48`1YAb@0JdTV06]::`1/Bb`0KD`[06i=:P1_CbT0LE4Z
079B:`1bDRT407MC;`@0N5@`00H0MePY07UJ:`1kG2d0OUl`081Q<P21HS<2081Q<P09081O=021H3D0
PV4f089Q=P21H3D0Oehc07eL<@1kFRl0O5Pd0080NeLc00<0NUHb07UE<@1hE3000P1gDbl0201gEc00
MED^07=C;@1`Cb`0Kdh]06i=;P1_CRl0Kdda1@1[Bb@306Y:8`0606U89@1ZBBH0JdXW06a;:01^CBX0
L4l/0P1aD2d306i=:P80KD`Y0`1/BbP00`1TAR@0IDLU06E79@0206I89P80IdTW00@0J4XX06E79@1U
AbD0IDLU0P1VB2H306M99`0506A79`1UB2P0IDPX06I9:@1WBRX00`1XBb/306M;9P80J4`W0`1YCBP0
101bCRX0Ldl[07=?:`1cCb/207A@;0<0ME4]0P1gE2X00`1hEB/0NEH/07YG;@0207aI;`0707eJ<01o
FS00OeX`081K<@21G380PUdc08=N=00208AO=@0808UV<029IC40R6@b08MS<`26HCD0QF0f08AN=`24
GST208=Q<`80PV0b00@0PEla081N<01oGBl0Oed_1`21GS@01022GcD0Oehc07iM<P1nFc4207iI;`04
085J<@24FS80QE/c085L<P80PUdc00d0Pehd08EP=P26HCL0QV4g08MR>028IBl0Qf<_08EQ;@23Gbd0
Pel_08=N<@25H3@0QV4e00@0PUdc1023GS@3081M<b_ooooo000Zooooo`P0WgE3202PM4<809mcAPP0
WgE300<0WWA209me@`2RN4H00P2SNDL00`2PMT@0WWA209ab@0020:AhA`<0XgM60`2RMTD0202QMdD0
X7I40:1fA02PMT@0XGM50:9hAP2TNTP0YG]90P2TN4L30:=gAP<0XWI500<0X7M309mf@P2OMT801@2O
MT80102MLTD0WW=609icAP2NLdH209ebA@0409Y_@P2HKD00UV/n09=^>@80TVdi00<0TF/j091Z>`2?
JC`00P2>Ic`308]V?00908YU>`29I3X0Qf8h08EP=P24GcD0Pf0f089O=@20GC<0OU/a0080OEX`0P1n
Fc403@1hFBd0MeP/07IF;@1dE2d0LU8/071?;01_CR/0KTd/06iA;`1]D2h0Jdh/06U<:P1WBRP00P1V
BBL00`1WBRP0IDPV06I99`0206I99`80IdXX0P1XBbT206M99`0406Q::01YBbT0JT`Z06]=:`80K4h/
0P1`CBL01P1bCbT0Le0Z07EB;01gE2h0N5D_07UF<080OeTd00H0P5Xc089M<`23GS80Q5lb08EQ<@26
HS8308US=080RV@e0`2;ICH808eW>0P0SfTj102BIcX4095V>@03095V>`2@ICX0Sf@i0080SV<h00<0
Sf@i091U>P2AIS/00`2AIST3091U>080Sf@g0P2CI3P00`2AICP0TFHi091W>@0208mY>P0408iZ>P2A
IST0TFHi095V>@<0T6Dh0P2?I3L0102=IcP0SVPi08iX>@2>J3T308mY>P04091Z>`2CJ3/0TfPk09=X
>`80U6Tl102EJSd01@2@JS/0TF/l095[?02BK3d0Tfdn0080U6ho00<0UFm009EZ?`2EJSl01P2EJSl2
09I[?P<0Uf`o0`2HKD0809I]>@0409EZ?@2DJC`0U6Tl09AY?080TfPk0P2BIcX01P2@JS/0SfTj08mY
>P2>J3T0SFLh08aV=`80RfDf0P29HSL00`2:I3L0RV@e08YT<`0208]V<P0308]V<@2:IS80RVHb00H0
RVHb00P0RVDi08]V>P2;IST0RfLg08aX=P2<J3@0SFTe08eZ=080RfLc00@0S6Pd08eY=@2>JSH0Sf/g
0P2@K3P2099^>P80TFdi0`2@K3P0102?JcL0SVXf08m[=`2AKCT2099^>P03095]>@2?JcL0SVXf0080
TFPl02H0SVPk08eX>`2<IcX0RFLi08QX>@27IcP0RFXk08QY>P27J3T0QFHg08=T=@21HS<0P64b07mP
<@1lGR`0Ne`]07MK;01bEb`0Je8Z06E=:@1PBBL0GDHV05129`1>@2D0BCdS04Dk8P12>R<0@S`V04@n
:014?b/0?SLT03`e8`0h<b00<c0O02l]7P0/;Al0;2`P02/]8080;B/L00@0:R/M02PZ7@0W:Ah09RTP
0P0S:249020S70<07b8I0P0P8aX3024T6`P08R<K200M7a`201dN60807QlI0P0O81X2020Q6`0<01lQ
700Q8Q`08R8J02PT6@0^9QT0=BTI03X]700n;a`0?S8H03lc6@12=Q`0A3PN0P16>R0204Di7`0=040j
8P0n>280>C@P03<`7`0]:ah09bLM02@T700R8ad0:RPL02`Z7P0`;200=2hP03L`800203T`7`0903X_
7@0j<Qd0>C4L03Ta7P0i<1l0>2lP03P^8P0g;B40=bdS00P0<2`P0P0/;Al202//7P0502X[7@0Y:Q`0
:2TK02PY6`0Z:ad00`0Y:Q`202PY6`809bPJ0P0S91h2028S7@<08B8L00@0824K01dP6@0M81T07B0I
0`0L7aP201/N5`0L01/P6P0L8A/082<L02<T700U9a`09RHJ02PV6P0X9QT0:B/F02`Y5P0b:aT0@c@Q
05U3;01aE3@0PF4h08YX>P2?KT<0TW=509=gA`2=MDD0OfXo06UG<`1C@RP0ASDQ02/^9`0Z;BH09bXS
02HY8P809BPQ0P0V:B8302@W80809BPQ100V:B8802P[900402X[8`0Y:R80:BXR02TZ8P<0:2TQ01h0
9bPP02X]9P0Z;BH0:b`T02d]8`0a;b<0=C4U03Pe9P0l=RP0@C@T03lb8P0k;al0=bhM03D^700f<Ah0
=S<P03Pe8P15>B<0B3`V04Tn:P15?BX0@3TV03dh9@0m>RT0@3d/04@l9@15?BH0BClV04e19`1A@bP2
05=49`0Q05A39@1DAB@0Dd@S05A48`1GA2@0FD@U05e69`1OB2T0HTT[06A=:`1WD2h0JU8^06]A;01Z
CRL0JTdU06i>9`1`D2L0LE8V071A9@1]D2H0K50X06U@:01WCbT0IDlX06E?:P1MCBT0GddY061>:P1S
Cb`0ITl]06Q@;P1ZCc40Je0b0080KU8[01d0Ke<[075F:`1dFB`0Me`]07YO<01lHS40N64e07UR=P1j
HcL0Nf@h07YS=`1iHSH0Mf0d07IO<`1aFSP0L5Tg06mG<`1^E2l0LUH_07II<@1kFc@0OUhe085T>P20
HcL0OV4e07aP<@1lH300OF4_07iS;P0207mT;`0W085V<@25JS<0RFlf08ab>@2?MCX0T7Hi095g>P2D
M3/0VGU009moAP2TQ4/0YXI=0:B4B`2PP4L0WGe4099h?@2CMS`0TWDk09=d>`2FMSd0W7U10:9mAP2U
P4T0YGm10:R2@`2/Q4H0[HA40:j2@@2`Pd00]HQ40;b=B@33VDl0aI]C0<>KD`30VU<0_9MA0;bIE@31
WU`0aZER0080_Y]G01L0_9UG0;RGE02eUUD0/iEE0:jBD`2WRTh0WhE8099e>@2>LCD0R6/c089T<01o
H340Of0d085Q>022HS/0O68a07aR;`1nHS00PV@`08AU;`27IS00R6P_08YW;`02099V=@08099W=02C
J3<0UFXc09M]<`2JL3H0Vg4e09if>@2OMcX20:1h>`0809mg>P2MMCP0Vg<f09Yb=@2HL380VG4c09]c
=@2LM3H209ee=`80W7@f00h0WgDk09ee>P2MMCX0Vg@i09Yf>P2JN3/0VGTl09Yj?@2HN3/0VGTl09]i
?02LN3`0WgPm0:1h?@80XWPn0P2POCd0302QOSh0Xh100:B1@@2UPT80YX=30:N4A02]Q480[XE30:n6
A02aR4H0/hY80;B;B@80]Xe;00T0/I130:n=@`2]Rd40[he50;:@B@2aSTX0[HY80:R5@`2YQDL00P2X
Q4H01@2WPdD0YX940:F1@`2TP480Xgm100@0XGdo102PO3h0202LO440VGTn09If?@2FMCl0UgI009Mf
@@2DLd00TG0m0P2EKSL0102DKCH0Tf`e099[=02BJc@2095Z<`80SVXf0P2=JCD408aX=00308iY=02=
J3<0S6Lb0080RfHa00/0SFPc08mZ=@2@JcH0S6hV08e_:@2?L2d0Sg0`08i^<`2;JS@0QfHc08ET<@02
08AV<080PfD_0P22I2h2085S;@0907iO<01mGS00OEh`07UM;P1fFbh0LET]06eF;01ZE2/0JE<Z00<0
IdlY0P1XD2X04@1YDB/0Je<]06]C;@1/EBT0I4dQ05m8701TCB40L5T]07MP=01dGC40KEHZ075L;`1a
G2d0Led^07IN;P1iGbh0Nel]0080Of4]0`1lH2h207eQ;`<0OV8`0P20I380101oHc40OV8`07eQ;`1l
H2h207]O;@0807MR;@1fHB`0MEl]07=M;01aFb`0KeP/06iG;@1]ER`806MB9@80J54X00L0J54W06UB
9P1[EBH0KUPW071J:@1bG2X0O60^0080OF4_00<0OV8`07mS<@20I3800P21IC<207aX<`0407eX<`1m
IS80OfDb07mS<@80PF<a0P1nI3400`1mHc00O68_07]Q;P0207YP;@0=07UO;01lHRl0O68_07eS<01n
I340OF<`07]Q;P1iGb`0MedZ071I;@1_F2`0K5DY06YC9`0206QA9@80JE8V00H0IU4T06E@9@1TCb@0
HddT069<9@1PBRD205m89P0>061>:01LBRH0FDLS05U69@1LBBT0G4T[05U5:P1E@BH0DD8Q0511801=
?Ql0Bc`O04Ti7`18>1l204Lg8080@3@L00/0?S<O03Xb7`0f;al0<B/O02/W700X91/08R8H020P5P0M
7QH06A`E01DJ500201<I5@03014J5`0H6QT061XI008061XI0`0G6AP201HH5a005AHH200D5AL@01DF
610051DG400E5QP301@F5@<05ALF0P0F61L801DG5PP05QPG00@05ALF01HH5`0F61L05QPG0P0G6AP2
01PJ6@P06QXJ400J6QP801/K6@0401`K5P0M71L07A`G01dL5`807QdH4`0O7QT801lO5`P07ahI0`0P
7aX3024P6`808R4L00@09QlI02LP6P0W81X09b0J0P0X8A/202TR7080;B<I0P0^91X0100_9A/0<2HL
030V700a9ad3030V6P80<BLK0`0b:1`803P/700403/Y6`0l:Q`0?B/M03h/7P80?bdO0P0n;1h803P/
700403L/6P0h;A/0>2dK03P]6`80>BhL0P0j;ad3048a7`80@C0N0`10;ad01P11;aT0@S0J048`6P13
<A/0A38L04Dc7@80AS@N00<0B3@L04Te7@19=Ad01019=Ad00`18=1`0D3PP054i8@02054i8@80DSXR
0P1C>b<405<i8P0705@j8`1E>b@0EcdV05Pn9`1L?R80FcdQ05Tk7`0205Pj7P0605Tk7`1K?B40G3hR
05hn9@1M?B@0G3`S0P1K>b800`1L?2<0GCdT05dm900205do9@80G3hT0P1K?B<205Xl8P0305Tk8@1E
>b00EC/P0080EC/P0`1F?240101G?B80F3hW05Lm9P1E>b@205@j8`0305Dk901F?2D0EcdV0080Fc/V
0P1J>RD305Ti900305Ph8`1B>240DcTR0080DcTR101D>R<205Dm9@80E3`T0`1C>b<01P1B>R80CCTQ
04`h801;=al0BSHN04Te7@80BSHN00<0BcLO04`h7`1=>B001P1=>B00201A>B40D3PP04lg7`1>=Qh0
CcLO050h801B>R80Dc/S0P1D>Ql305Dk80<0ES`Q201O@2@206528`80H44R00D0HD8S06=49@1TABH0
IDHW06a59P0206Y69P0306Q59@1WARD0I4HT0080HdHT201[BRL806m>:`<0LDd[00D0LTh/07=?;@1e
DBl0Me<a07QD<P02075F:`0907=F;01fERd0N5L^07UF;P1jEbl0O5H_07eJ=01lFC<0NePb0080NULa
00<0NePb07aI<`1mFS@00P1iFRh00`1iFC00N5Pa07QH<P0207MF<`80MeHe00@0MUDd07ED<`1dDc80
Le8a0P1aD2l2071?;P0606]<;@1ZBb`0J4TZ06M8:@1VAbP0IDHW0P1VAbP0201WBBl0IDL]0694:P1N
@2H0FS`R05Pj801F>1h0ECLM0P1F?Ah0201E?1h0E3XO05<i801C>B80DSPQ058g8P1E>b@0E3XS0P1C
>B80501D>R<0EC/T05Hl9@1G?BH0F40T05Q18P1J@B<0G44S05m28P1SAB<0IdHS06U89@1ZBBX0JdX[
06a;:P1]C2T0KThX06m?:01`D2T0L50W0P1fDbd207MD;P80N5D_0P1iES001P1jFb`0Ne`]07eN;`1n
Gc00Of0a081Q<P80Of0a00T0PUle08=P=P23H3H0Q64g08=P=P21GS@0Oe`b07eJ<01mFS@00P1lFC<0
0`1kF380NULa07UF<00207QE;`0607YJ<@1hF340MUH_07=C;@1`Cb`0Kdh]0P1^CBh206e=9P80K4`U
0P1[Bb@206Y:8`0606]:9`1/BbP0KD`Y06i=:P1_CR/0LE0]0P1bDBh0101_CR/0KTdZ06i=:P1^CBX2
06e<:@80K4/X0P1UAbD206I89PP0IdTW0`1VB2H306E79@0306I89P1WBBL0J4XX0080JD/Y00<0JT`Z
06]=:@1[CBT00P1/CRX306e?:`0306i@;01dDB/0M54[0080ME8/101fDbd01P1gE2h0NUL]07YG;@1k
F2h0O5T_07eJ<080OU/a00T0Oe`b07iI;`1nFBl0P5/a085L<P23GS@0QF0f08IQ=`27HSP00P29IC<0
1P28I3@0R6<f08MR=P26HCL0QF0f08EO>0@0Pf4c1022H38408=P=P@0PUle00<0P5ld07mN<`1oG380
0P20Fc401022Fc80QE/c08IL=022GC<208=N=00308AO=@25H3H0QV4g0080Qf8h00H0R6D_08MS;`25
HBd0Q60^08AP<024Gc8208EP=0P0Pehd0`1oG38[ooooo`00:_ooool80:1fA0P0X7A3202OLdH809me
@`0309ab@02OMD<0XWQ60080YG]900<0XWQ609id@P2KLCl00P2UNDP00`2TN4L0XgM60:9fA@020:5e
A0090:1d@`2OMD<0WgE30:1fA02QMdD0XWQ60:AjB02UNdT0YWa:00H0XgM60P2RMTD209id@P<0WgE3
0`2PMT@209ec@`80WWA40P2MLd<0102KLD40V6hn09M]?@2BKCP2095/>003091Z>@2?JCX0SVPk0080
SFHk00`0S6Lm08]V?02;IS`0RVDk08QS>@27HSP0QF0f08AO=@23H3H0PUle081M<`1nFc4207eJ<080
OU/a00d0NEX^07QI;@1fERd0M5@]079B;01`Cb`0KTdZ06e<:`1^DBl0KE0^06]>;01ZCB/0J4/Y0080
IdXX101VBBL206M::0<0J4/Y0P1WBBL0101XBRP0JD/Y06Y<:P1[CB/206a>;00806m<9P1`CBL0LDhX
07AA:`1fDbd0N5D_07YG<@1kF38207mI=006081J<`22GC<0Pehb08AO<P25HC40QV8b0P29Hc@208YT
=@80RfDf0P2<ISL808eW>0P0SfTj102BIcX4095V>@80Sf@i0`2=HSL00`2>HcP0T6Dj095V>`03095V
>@<0T6Dh0P2?I3L209=T>003095U>02@ICP0T6Li0080SVPi00@0SFTi095V>@2AIST0TFHi0`2@ICP2
08mT=`@0SVPi102?JCX309=X>`80U6Tl102EJSd02@2>J3T0SfTj091Z>`2AJc`0TV`m09=]?P2DKSl0
UFm009=X>`0209AY?00309EZ?@2FJch0UV/n0080Uf`o0P2FJch609M/?`P0UV`j0`2DJC`209=X>`<0
TVLj00H0T6Xk08mY>P2?JCX0SVPi08eW>02<ISL208]U=P80RF8g00<0RV@g08YT=@2:I3<00P2:IC40
0`2:IC00RVHb08YV<P0608YV<P80RfHj00<0RfHi08aX>02<J3H00P2=JCD01`2=JS@0RfLc08]W<`2<
J3@0SFTe08iZ=P2?JcL00P2@K3P00`2BKSX0TFdi08m[=`0208iZ=P06091/>02BKSX0Tflk08m[=`2@
K3P0TFdi0P2BKSX02@2@K3P0Sf/g08eY=@2BJCd0TFPl08mY?02=J3/0S6Lj08UW>@0208MW>080R6Tj
00@0QVLh08AU=P23I3D0PF8c0P1oH340601iGBd0Me//07=H:`1]E2/0IdlY069;:@1NAbL0FTDV04m1
9P1>@2D0BCdS04Dk8P12>R<0@C/U048l9P12?BT0?CHS03/d8P0g<Ql0<RlN02l]7P0/;Al0;2`P02`^
8@80;B/L00@0:R/M02PZ7@0W:Ah09BPO0P0R9b0301lR6`8082<L100Q91d301lR6@8082<J0`0Q91/3
02<T70@08R<K00<08B8J01`N6`0L7Q/01P0L7Q/201dN60807QlI0P0O81X2020Q6`0>024T7@0R8a/0
92@J02TU6@0`:AT0=b`J03`_7010<A`0@3@J044e6`13=ad0ACTO04Hj8015>Al204@h7P0@03li8@0l
=R00=c8N030]700Z:1/09BDK02<S6`0Q8Q`0;B/N02l]800b;b00=c4Q03Tb800k<b00>S8O03`a7@80
>C8O00H0>34O03L`800g;b80=RhS03D]8P0e;2<802l[7`<0:b`N00<0:R/M02TZ700Y:Q`00P0X:A/0
100Y:Ad0:2PL02PX700X:1`202LW6`809RHJ0`0R8ad3024R7080824K0P0M81T601`O600K01`Q6`0O
8A`08B8L02<T700U9A/0:2HJ02XV6`0Z9QX0;RLD030X5@0j;QP0CchT06YC<`20I3d0SF`o091^?P2@
Kd80T75308ebA`23JdD0L5dl05Q8;P10=1h0<RLE02P[900W:R<09BPQ00<08bHO00<092LP02DX8@0T
9b000P0T9b0202DX8@@09RTR200X:b@402TZ8P@0:2TQ0P0Y;2D07P0Z:b<0;BdS034_8`0f<RH0>CHW
03dg:@0n=B@0?C@S03Xa800h;ah0=c0N03Pa7`0i<R00>S<Q044e7`14>280ACXV048j9`0m=R<0>cHS
03/h9`0o?2/0@c/T04@l9@18?RD0C40V05129`1CA2L0E4DX05I59`80EDHU01h0EdLV05U69P1KARL0
GdPY0619:P1RBB/0HDXX06=<:P1WCb/0JU0[06eA:P1^DBT0LE4Z079B:@1/D2P0JdlW06M>9P1TC2H0
HD/V05e9901LB2D0FTPT05Q89`1KB2P0GDXY065=;01UCR`0JE4_06aB;`1]Dc0206mF;P0J071G;P1b
FRh0M5`^07IN;P1hH300NF8`07IO=@1gH3H0N64g07UR>01hHCL0Mf0f07EN=01dGC<0KePf06eF=01/
E300KE<^071D;@1eF300Ne/d07iN=@23IcP0PVHg07mS=01mHC4207aP<080OF4_02P0O68_07iT<@21
J380Q6/c08Q_=P2;LST0SGDi08mg>@2HN3l0W7a30::2B@2VQTd0YHE<0:61B02KNd80UgLn099e>@2@
LcL0SW0d08m_=02ELSP0WWY00:N0A`2/QD`0[XI80;:;BP2fSDd0]Xe;0;B<A`2fRdH0^Y180;jDC035
WED0aYiH0<>MEP2nVE<0^IIB0;ZIEP31Wel0aJIU0P2oWEd05`2lVU/0]IIF0:nAD`2XRdl0X8I;09Uo
AP2DNd80S6lg08QZ=023IC40Of4_07aM;P1mGS80OUlc081P=`1jGRh0Nel]07iP;P20H2d0Pf8]08IS
;@27I2`0RF@]0080T6Db00L0TVLb09AY<P2GKC<0VW0d09ab=P2MM3H0WgTk00<0X7Xl00@0WgTk09eg
>@2JM3H0VG<e0`2NMCL209ed=P0409ac=@2KLS@0VW4c0:9f>@80X7Li00H0WgLi09mi>P2NNc/0WW`l
09mm?@2LNS/209ei>`0309ij?02PNS`0XG/m0080XG/m00<0XX100:>1@@2SPD400P2SPD430:B2@P0@
0:N1@02XPT40ZXA30:b6A@2^R4L0/H]:0;:<B`2cSD`0/8m80:j=AP2/RdH0[Ha90;2>CP2_SDh0ZXQ9
0:J4A`80ZHM:0P2XQTT20:N5B080YXA70`2QOT@00`2POD<0Wga209ml@P0209ik@@0809Yl@02INT40
UgQ109Ig@02FMd40UWI309Ad@`2CLd8209U^>@80V6dh00@0Uf`g09I[=P2FJcH0UV/f0`2AKSP5091]
=`0308mZ<`2>JC80SFPa0080S6L`00/0SFPa08mZ<`2@Jc@0SFh[08i_;02?L2l0Sflb08i^<`2<K3<0
RFPb08MV<@0208IU<080Q6D_00D0PV@^07mT;@1nHb`0OV</07aM;P0207eN;`0707]O<01iGRl0MEd_
071I;@1[ER/0JE@Y06Q@:P0306M?:@0B06Q@:P1ZDR`0K5@^06eE;`1^Eb/0J54U06A=8@1UCR80Je@X
06mH;01`FBd0KUL[06mJ;@1_FR/0LE//07AL;01hGRd0NUh/0P1nH2`01@1jGR`0Nel]07]O;@1lH2h0
OF4_0080OV8`00l0Of<a085U<`20I380Of<a07iR<01mHBl0O60^07]O;@1jGR`0Mf8]07IQ;01eGbd0
M5h]079L;@1`FBd00P1_F2h806UD9`80JE8X00H0JE8V06YD9@1]EbH0L5XY07=M:`1eGbd207eQ;`04
07iR<01oHc40P6@b085U<`80PVHd0P1mJC@0101mJ3<0OVLc081V<`20I382089T<P0607mU<P1nI340
OV@a07eS<01lHRl0Nf4^0P1jH2d0301lHRl0OF<`07iT<@1oIC80OV@a07eS<01kHBh0NV0]071I;@1_
F2`0K5DY06YC9`<0J54U00L0JE8V06IA901UD2D0I4lT06==901QBb@0H4XU0080GdPV00h0H4hV05a:
901JB280FdTU05i;:P1OC2`0GDX/05U6:01C@b80DT8Q050o8@1>?B40C3/Q04Xh8080BCLQ0100@cDK
044e6`10=1h0?S<Q03T`7`0d;1l0;bPN02dV700U8QT08b0G01hN5P0J6aD05aTD01@I5@0C6AD04aTG
100H6QT301LI60805QPG:00E5QP@01@E5a005AHH0`0D5QD301DG5QD05QPG0P0G6AP301PJ6@P06QXJ
400J6QP801/K6@<07A`G0P0N7AP<01lN6@P081lJ200P81P801lN6@<081lJ0`0Q81/2028Q70<09b0J
0P0X8A/302TR700602dS6@0^91X0;R@J02lU6`0`9Q`0<BLM0P0b:1h3030V6P<0<BLK0P0b:1`803P/
700303`Z700m:ad0?R`N0080?bdO0`10;R0803X]7@0403T/6`0j;A`0>RdL03X]7080>bhM0P0l;ah4
048a7`@0@C0N00H0@S0J04<a6`13<A/0A38L04Dc7@16=1h204Le7`80Ac<K00L0BCDM04Xf7P1:=Qh0
BSHN04Te7@18=1`0DSPQ00<0DcTR0P1D>R<205Dk90<0E3XQ00P0EC/R05Hl8`1G?B@0F3hU05To9P1L
?R80FcdQ05Xl8080FC/O00<0FS`P05/m8@1L?R800P1N?b<00`1M?R80G3dQ05`m8@0305`m8@80GT0V
00@0GClU05`n901K?B<0FcdS0P1J?280101I>b40ES/N05Hk7P1G?1l205Pm800505Tn8@1J?b80FSlR
05Pl901G>b<00P1F>R80101G>b<0F3`T05Xn9P1L@2P305`l9@80Fc/T0`1J>R<01P1A=b00DSPQ058h
8@1C>B80E3XS05Dk9080ES`U0P1H?RD205Lm90<0ES`S00L0EC/R050j8`1@>R<0CSPQ04dg801<=Ql0
BcDN0080BS@M101==al404hh8008058j8P1A>B40D3PP04lg7`1@>200DCTQ05<k8`1D?2@205@j7`<0
EC/P0`1F?24306119@<0Gd0T0P1N?b<306118P0506528`1R@b@0Hd@U06A59P1UARL00`1YARH00`1X
AbH0IdHU06M69@0206E79@P0JdXW201_CR/2079>:P0F07=?:`1dD2`0ME4]07IB;P1gDbl0N5@`071C
:@1aE2X0M5@[07IE;01hEBd0O5H_07eG<01nEc00Oe`d07iK<`1kF300NEH^07QE;@1jEbl0O5Ta07eJ
<P80NU/_00<0NET`07UI<P1iFC<00P1hEc@01P1hEcH0MeHc07IE<P1eE340M5<`07=B;`80LU4^0P1a
D2d206a>;00406Y<:P1YBbT0J4XX06M99`80ITPV00D0J4X^06E7:`1Q@bL0G3hR05Xl800205Tk7`09
05Xl801F?Ah0ESdN05Hm7`1E>b00E3XQ05@j8`1C>B80DcPS00<0EC/R00<0E3XQ05Dk8P1E>b800P1F
?2<04@1J?b@0Fd0S05]08`1L@B<0H4<S06958`1SAb80I4PS06U8:@1ZBBX0JTTX06a;:01]CBL0KThW
06m?:01_CbH0ME8Z0080MU<[00H0Me@/07QE;@1iERh0NEH^07YG;`1lGBh207eN;`0307iO<01oH340
Of0a0080Of0a00P0QF0d08IQ=@26HCD0Qf8f08IQ=@24Gc<0PE``081K;`80OU/c00<0OEXb07aI<@1k
F3000P1jEbl02@1iERh0O5da07]K<P1hF2l0MED^07=C;@1`Cb`0Kdh]06i=;00206i>9`80KDdV00@0
K4`U06];901[Bb@0JTXS0P1]C2T01P1^CBX0Kdh[071?;01aD2d0LU4^07=B;`80Kdh[0`1^CBX306e<
:@80ITPV1P1WBBL206U;:@0306Q::01WBBL0ITPV0080IDLU00L0I4HT06M68`1WAR<0J4LT06U89@1[
BRL0K4/X0080KD`Y0`1aDB/2079B;0<0Le<]00@0MU<[07MD;01gE2`0Me@/0P1hEBd307UF;P80OEX`
0P1nFc403`1oG380P5dc081M<`20GC<0OEP^07iI;`20Fc40PUdc08AO=@26HCL0R6<i08UT>P2:ISH0
RFDe08UT=`0208QS=P80Qf8f00<0QV4e08=Q<`23HC<00`24HS@308ES=@<0QF8h1024HCL01023H3H0
P5ld081O=021GS@2089M<`0308AM=026G3@0QU`d0080Q5lc0P25H3@208IQ=@80Qf8f00H0Qf@^08MS
;`26HRh0QV8`08EQ<@25H3<208EP=0<0Q5lc1023GS801022GC40OU/a07iK<@1nFc4[ooooo`00:_oo
ool80:1fA0P0X7A3202OLdH809me@`0809ab@02NM480XgU70:EkB@2VO4X0XgU709me@`2LLT020:Ei
B0030:AhA`2SMdH0XWI50080XGE400L0X7A309id@P2OMD<0X7I40:9hAP2SNDL0Y7Y80080YG]90P2R
MTD60:=gAP80WWA40`2OMDD30:1fAP80W79000P0WG=109id@P2MLd40WG=109]a?`2IKcd0V6hl099]
>080TF`h00<0T6Xi08mY>P2>J3/00P2=IS/01@2=J3h0S6Lm08YU>`29I3X0Qf8h0080QV4g00D0QF0f
08=P=P22GcD0P5dc07iK<@0207eJ<080OU/a00P0NEX^07QI;@1fERd0M5@]079B;01`Cb`0KTdZ06e<
:`80KE0^00D0K4l]06]>;01ZCB/0J4/Y06M::00306I99`80IdXX0P1XBbT206U<:P80IdTW00@0J4XX
06U;:@1ZC2X0Jdd[0P1/CR`0201_C2H0L4dW079?:@1dDB/0MU<]07UF<01jEc40NePb0P1oFC@01P20
FS<0PUdc08=N<P24Gc80QF4a08IR<P<0RV@e0P2;ICH308aV=`P0SVPi202?JCX209=X>`80TVLj0P2A
IST2091U>00808mT>@2>HcP0SF8g08aQ=P2=HSL0Sf@i095V>`2BIc`3095V>@<0T6Dh0P2?I3L209=T
>003095U>02@ICP0SfHh0080SFLh00@0S6Ph095V>@2AIST0TFHi0`2@ICP208mT=`@0SfTj102>J3T3
09=X>`80U6Tl102EJSd0202=IcP0SVPi08mY>P2@JS/0TF/l099/?@2CKCh0U6ho0P2CJCT00`2DJSX0
UF/k09I/?00209M]?@0309Q^?P2GK3l0Uf`o00H0UV/n202EJc/209AY?080TfPk0P2BIcX2095V>@06
091Z>`2?JCX0SfTj08iX>@2=IcP0S6Hg0P2;ICH208YS>00308US=P29Hc@0RF<b0080RF@`00<0RF@_
08YV<P2:IS801P2:IS8208]V>P0608aW>P2<J3P0SFTg08eY=@2>JSH0SV/e0P2;Ic<0102<J3@0SFTe
08iZ=P2?JcL2091/>00:099^>P2@K3P0SVXf08aX=02=JCD0Sf/g099^>P2ELCd0T6`h095]>@80TVhj
00@0TFdi091/>02>JSH0SFTe0P2AJ3`06`2>J3/0SFPk08aW>P29IcT0R6Pi08MW>028JCX0QfPi08IW
>024ICH0PV<d081Q<P1oH340OUl`07IK;01dFB`0KUHZ06UB:@1SCBP0GDTX05Y59P1GA2H0CT0U04do
9019?B<0AC/R048j8`02040j900903lj9P0l=B80>S<Q03Ha7P0b;ah0;bdN02`]7`0/;200;2hQ0080
;2XK00@0:BXL02LY700W:Ah09BPO0P0R9b0301lR6`8082<L100Q91d301lR6@8082<J0`0Q91/202@U
7@808b@L00@08R<K024R6P0Q8QX08B8J200L7Q/201dN60807QlI0P0O81X2020Q6`0;02<V7@0T9Q/0
9RHJ02/X6@0b:aT0>BhL03hb7012<a`0@SHL04<g7@14>1h00P16>R004`15>Al0A3PN04<g7@0m=al0
>S@N03D`700^:aX0:BLJ02@T6P0S8a/08R<M02l]7P0a;b00=34P03Pc800k=240?3@Q03/c7P0m<Q`0
0P0g<Ql01P0f<200=BlQ03@^8P0c;280<R/Q038[8`P0;b/O0`0Z:ad402TZ700302PY6`0X:1h0:2PN
00809bLM0`0V9Q`00`0U9A/08R<M028S7@03024R70<0824K1P0L7aP201dP6@0K020R7@0Q8Qd08R<M
02@T700W91/0:RHK02dV700^:1`0<bHE03TZ5@16=AT0GTXW07QO=P2:KSl0TG50091_?02?Kd00RVe1
085W@P1bGCh0GDdd04Hk:@0a:a/09B8C02LZ8`0U:24092LP00808RDN00<08bHO02@W800U:2400`0T
9b0202DX8@@09RTR200X:b@402PY8@@0:BXR0P0Z;BH01P0[;2@0;BdS034_8`0e<BD0>3DV03`f:080
?cPV00<0?CHT03`e8`0m=2<00P0n=B@05P0o=RD0@3@N04<g8@14>BD0@CTV03`e8P0j=B80>SLV03hk
:P14?2D0ACdV04Pn9@1;?bD0Cd4V05=49`1EART0EdHX05E69@1FAbH0F4PW05]8:01MB2T205m8:@0I
0617:@1LAB<0GTLU06=;9`1YCbX0L5@]07=F;P1fERl0MED/06M?:@1VCRP0HddX05m;9P1KBBD0EdLU
05E5901CA2<0E4<W05M49P1JAbL0Gd/Z06A=:`1YDB/0KE<^06iE;@02071I<008079K<@1cG300M5h_
07AN;@1eGbh0MEl]07=L<`1dGC@307EN=@0@07=L<`1bFc80L5T`06aE<`1ZDc40JU8^06]A;01_Db`0
M5L_07]K=01nGSD0QFTg08=W=@20I3@0OV8b07aP<080O60a02T0OF4b07YS<@1kI380OFHb085Z=025
KcH0RG<i08af?02>N3`0WWi50:61B02TQ4/0YHE<0:>3BP2MOD@0UWHm099b>@2BM3H0T78d08i^<@2@
KS40UW8f0:1i?P2ZPTL0/8Q=0;R<C@2lT4l0`9AC0;jFD@2lU4h0_9A<0;jHC@32W540aZ1I0<JOFP32
WEL0^iQD0;FDD@2eTe<0^9UI0;fOG`020;RHF`0;0;FEFP2]Se<0XXE;09Il@`2=M3`0R6li08A]=`26
J3H0PfDc081Q<P1lGBh00P1kG2h04`1mGS80OUlc07aM;P1lGR`0OUh]085P;@24H2`0QF8/08MR:`2:
Hb`0T6D`095V<@2DJC80Ufdc09Y`=02LLcD0WWDg09mf=P2NNS`00`2ONcd02@2NNS`0VgLi09Ue=`2G
LcD0XgLj0:9f>@2QMCP0X7@g09mc=P0309ib=@060:Af>02TN3T0YGTj0:Ak>`2TOC`0Y7hm0P2ROcd2
0:1j>`80XG/l0`2POCd0102POSh0Y8930:B2@`2TPT<50:>1@P0@0:1n?P2QOcl0Xh510:F3@`2XQTH0
ZXQ80:^9B@2/RTX0ZXe;0:N:B02VR4P0YhU;0:Z<D02ZRe80YHI=0:62B`80Z8E;0P2WQ4X20:J3B@80
YH980P2NOdP0102MOTL0W7e609YkA02INT<209Qi@P0909Eh?P2FND40UWU109Eg@@2CMD40TWA2099c
A02CM4D0VG0j00@0V6li0`2GKSP609=`=P80U74g00<0Sf/a08iZ<02<J2h00P2;Ibd00`2<J2h0SFT_
08iZ<00208i_;`0?08m`<02?Kc80SVhc08e]<P2;Jc80RVXa08]V<P2:IS80QfHa08EV<023IBl0OfH^
07aV;@1kIB`0O5h/0080OEl]00l0OF4a07aQ<P1gGc40LU`]06eH:`1ZEBP0JU8/06UA:`1XD2X0IdlY
06Q@:P1ZDR`0K5@^06iF<01]ERX00P1_F2`03P1ZDbL0I4dQ06=<801XDBD0KEHZ06aG:P1]F2T0L5X[
079J:P1gGB`0NUh/07eO:`1nH2`0NEd[0P1jGR`05@1kGbd0OF4_07iR<01nHS00Of<a089V=021IC<0
P6@b07iR<01mHBl0Nel]07YN;01iGB/0Mf8]07IQ;01fH2h0M5h]07=M;P1bFbl0LEX`071I;`0806YE
:00806]D:01ZDbL0JeDV06aF9`1_FBP0LU`Z07EP:`1gHRd207iR<00407mS<@20I380PFDc089V=080
PfLe0P1nJSD0101nJC@0OfPd081V<`21IC<208=U<`80OfDb00<0OV@a07eS<01lHRl00P1kHBh0101j
H2d0Nf4^07aR;`1nI34207mU<P0707iT<@1mHc00O68_075J;P1`FBd0KEHZ06]D:00306UB9P0706YC
9`1WDRD0IU4V06E@9@1TCRD0HT`U065;9P0206199`08061?901MBb<0FTPR05a:901OCBT0HDh]05i;
:`1KB2P205=38P0F05918`1@?b<0CSdS04`j8P1:>280BCLQ04De6`14=Q/0A3DN040c800m<R00=bhO
03<[800a:Ah0:2@K02HR6@0R7aP07A`G01TJ5@0G6AH051TE01DI60@061XI0`0G6AP201HH5bP05AHH
400D5AL@01DF60<051HE0`0E5aHD01HH5`805aTH0P0H6QT201TK6PP06QXJ400J6QP801/K6@807A`G
0P0N7AP201lN6@/081lJ200Q81/8024Q6@/081lJ0`0Q81/2028Q70809b0J0P0X8A/202TR7080:R<M
0P0^91X202lU6`04030V700a9ad0<BLM038X7P80;bDI0`0`9QX3034W6`P0=b/K0P0l:Q`01P0m:ad0
?R`N03l]7`10;R00@BlQ048`8PP0?2`M0P0l;1`203d]7@<0?RhN00<0?blO048a7`12<Al01P12<Al0
1P13<A/0A38L04@b7015<ad0AS@N04Le7`80B3HP00<0AS8J04Lc6`1:=Qh00`1<>200101:=Qh0BCDM
05@h8P1D>28205Di8`<0ESXT00H0Ec/U05@j7`1E>b00ES`Q05Lm8P1H?R<305To900305do8`1L?R80
FS`P0080FC/O00<0FS`P05`n8P1M?b<0101N?b8205dn8@0405`m801K?1l0GT0V05i09P80GClU0P1L
?R@205/m8`0605Xl8P1I?1h0FSdO05Xm7`1K?R00G3lQ0P1M@2800`1N@B<0FcdS05Xl8P0205Tk8@05
05Xl8P1L?R@0GT0V0612:01N?RD00`1M?B@205`l8`80Fc/R0P1B>2400`1C>B80E3XS05Dk900205Hl
9@0305Lm9P1J?b@0FSlT0080FChS0`1H?B802@1G?240DcXT05<j901B>B<0DCPR04lf801>=Al0C3<M
04/b700204lg7`80D3PP0P1A>B42058j8P0805<k8`1B>R80DCTQ050h801A>B40DSXR05@l901E?BD2
05@j7`<0EC/P0`1F?24206529P<0H44U0`1O@2@206118P0306528`1R@b@0Hd@U00<0Hd@U0P1VB2H3
06Q79P<0JDHV201/BbP8071?;00307=@:P1dDB/0ME8/0080MU<]0`1gE2h2079B:@0>07AC:P1gE2`0
NU@]07]E;P1mERl0P5H`081M<`1oG380O5T_07YG;@1iER`0NeP^07eJ<01nFc4207]L<00307YJ<@1j
FS<0NETc0080NEPe00<0NEPg07AD;P1dE2h00P1cDbd00`1bDR`0LE4[075A:`02071@:P0E06i@;P1]
Cbd0KDl]06]=:`1ZC2X0J4XX06M99`1VB2H0IDPZ06959`1O@R@0G3lQ05/n801L?b40GT4S05m2901G
?Ql0ESdN05Hm7`1F?240ES`S0080EC/T00<0ECXU05Dk801F?2400`1F?24305Dk800805`n901M?b<0
GT0T06139@1OAB@0H4HS06168@1QAb8206Q7:00606Y9:01[BRL0KDdW06m?:01`D2T0LE4X0P1eDRP0
101fDbT0Me@Z07QE:`1iER`207YG;@D0OUl`00@0Of0a081Q<P20HC80QV4d1027HSD01025H3<0PUd`
085L;`20GC<207mL<P0307iK<@1mFS00O5T_0080NeP^00P0OEh`07aM<@1kG300N5P_07IF;`1cDbd0
L4l/06m>:`80L50Y00H0KdlX06i>9`1]CBH0K4`U06];901ZBR<206i=:P80Kdh[00@0L4l/075@;@1b
DBh0LU4^0`1_CR/306i=:P80KD`Y0P1XBRP606M99`0606Y<:P1YBbT0JD/Y06Q::01WBBL0ITPV0P1U
AbD206U78P0606]9901/BRD0KT`W06m=:01`CRT0LDlZ0`1eDbd207ID;P<0MeD_0`1iER`207YG;@@0
NeP^00<0Oe`b081M<`20GC<00P20GC<3085N=00807iI;`1oFS00PE`b08=N=025H3H0Qf8h08UT>P2:
IC/208YU>@0408UT>029I3L0RF@g08UT=`80R6@d0P25HcD308IT=P<0QfDg0P28IC/208MT>P0408IS
>@25HSP0QF8h08ER>080PF0e00@0PUle08EP=P25H3H0QEhe0P27GCD408IQ=0@0Qf8e00H0Qf@^08MS
;`27Hbl0Qf<a08IR<P26HC@208EP=0<0QF0c00<0Q5lb08=N<@23GS400P22GC0307mL<R_ooooo000Z
ooooo`P0WWA2202PM4<809mcAPP0WgE300<0WG=109me@`2RN4H00P2TNTP00`2SNDL0XGM509me@`02
0:AhA`<0XgM60`2RMTD00`2NM480WgE30:5gA@020:=iA`030:AjB02SNDL0XgU700<0XWI50`2SMdH2
0:AhA`030:1eB02OM4L0WgA700D0WgA700@0Vg8n09ac?`2MM400WWE10P2MM400102KLSh0VW4m09Q_
>`2CKST2099]>@03095[>P2@JS/0SfTl0080SVLl00D0SFPn08aW?@2:IC/0R6<i08MR>00308IQ=`04
08=P=P22GcD0P5dc07iK<@80OEX`0P1nFc40201hFBd0MeP/07IF;@1dE2d0LU8/071?;01_CR/0KTd/
0`1]D2h01@1/Cbd0Jdh/06U<:P1WBRP0ITTW00<0IdXX0P1XBbT306U<:P80IdTW00@0J4XX06U;:@1Z
C2X0Jdd[0P1/CR`01P1aCRP0LTlY07=@:P1eDR`0Me@^07QE;`80NULa0P1oFC@01P20FS<0PUdc08=N
<P24Gc80QF4a08IR<P80RV@e0P2;ICH308aV=`0308eW>02>J3T0SVPi00H0SVPi202?JCX01@2DJC`0
TfPk09=X>`2BIcX0TFHi0080T6Dh00<0Sf@g08mT>@2>HcP00P2=HSL0102>HcP0T6Dj099W?02DJCh3
095V>@<0T6Dh0P2?I3L01@2DICT0Tf@h095U>02@ICP0SVDg0080S6Hg00@0RVHf095V>@2AIST0TFHi
0`2@ICP208mT=`04091Z>`2?JCX0SfTj08mY>P<0SVPi00@0SFLh09=X>`2CJ3/0TfPk0P2DJC`409EZ
?@0508eW>02>J3T0SVPi08mY>P2@JS/00P2AJc`01@2BK3d0TfTg09AZ>02DJSP0UF/i0080UV`j0P2G
KC/209M/?`<0UV/n2`2EJSd309=X>`80TVLj0`2AIST01P2@JS/0SfTj08mY>P2>J3T0SFLh08aV=`80
RfDf0P2:HcP00`29HcH0RF<d08US<P0208QS;`0308QS;P2:IS80RVHb00H0RVHb0P2<Ic/00`2<IcX0
SFTi08eY=`0208iZ=P0708i[=@2;Ic<0RfLc08aX=02=JCD0SVXf08m[=`02091/>003095]>@2@K3P0
SVXf0080SFTe00<0Sf/g095]>@2CKc/00P2AKCT2099^>P04095]>@2?JcL0SFTe08aX=080SfHj00@0
SFLj08aW>P2<IcX0RVPj0P29JCX208MX>@0408EV=`24ICH0PV<d081Q<P80OUl`01P0Le/]071H;01[
E2X0IDlX05i:9`1IARH0Ed@V05A39`1=?b@0C3hS04Tm8`16?2<0@SXS03li8`0n>280?CPT03/d8@0i
<R00=C0M034^7@0_;Ah0;2dO02d]8@0/;R4202`Z6`0602TZ700W:A`09RPM02@W7P0R9b008BHO2@0P
8a`301lR6@8082<J0`0Q91/01P0U9Qh092DM02@U7@0S91`08R<K024R6P80824I200M7a`201dN6080
7QlI0P0O81X2020Q6`0:02DX7@0V:1/0:2TK02dZ6@0c;1T0>c0L03lc6`14=Ah0A3PN04Di7`<0ASXP
01/0ACTO04<g7@12=Q`0>cDM03Tc7@0c;QX0;BXI02TW6P0V9Q`09RHN02HW8@0`;ad0<S4O03Db7`0i
=200>c@Q03`d7`0k<a`0?34K03@a800c<1l0<RlP034]8@0_:b00;RXQ02dY800]:280200^:Qh802TZ
70809bLO0P0V9Qh302DU7@0302@T700R8ad08B8L00808B8L0P0P8A/201lP6P806ahG0`0L7aP301dP
6@0K028S7P0S8Qh08b8M02DR6`0X91/0;2DK02lV7@0`:1d0?bXI04Tc701KA280LET]08AZ=`2@LS`0
TG8l091_?02<K3/0PVDi079J>01OBc<0BC`/03La9@0Y:Ad08bDH02HY8P0U:2408bHO00808RDN00<0
8bHO02DX8@0V:B800`0T9b0202DX8@@09RTR200X:b@0100W:200:2TQ02PY8@0X:B4302TZ8P0902X[
8`0/;bP0;2lX02`]9@0];B<0<BlS03@`900f<b@0>S@V0080?3TV00@0?STV040i9`11>2L0A3PX0P16
>BT02012=R00ACTS04Hk9`12>RL0?CHS03Xe8P0k>2L0?S/Z0P16?RL02`18?RD0BShT04i09@1B@bH0
E4DX05I59`1EARD0ETLV05Q89`1KB2P0GDPY0080GTLX01T0GTDW05]48P1LAB<0HDTU06U?:P1bERl0
MUTa07IF;`1dE2/0I50[06=?;01PCRX0Fd/Y05U9:01EARL0DT@W05539P1B@BL0ED4X05Q59`1MBBP0
HddX06Q@:P1/DbX0KEDY0080L5Xa00H0LE`a079M<01cGRl0LUh/075M:`1`G2T206mG<@<0LETc0100
KeLa06eE;`1/E2h0JE8`06QA;`1XD2`0JDlZ06iB:`1dEbl0Ne/d07iN=@24JC@0PfPc085U<`1nHS80
OF4b0P1mH3@02`1nHCL0NV@c07]U=01mIcD0P6/f08E`>@29M3/0SGPo091l@@2PP4L0XH580080XX99
01@0X81709al@`2GMch0U7@k09Ae=@2BLc<0TW0a09=_<@2ILcD0XWXm0:Z2A@2`QTX0_8a<0;nBC`34
Ue@0a9UD0<6ID@30VTl0`Ie?0<FQD`80aJ1J00H0`9eI0;RGE02`STh0ZX];0:^=C`2_TE<20:Z;DP0Q
0:R9D02PPd/0TgQ108M^>01mIS80Nf@`07YT<P21HSH0Of0d07eN<P1kG300NU/]07]L;P1mGS00OUla
07iN;`1oGbh0PEl_08AP;P26HRh0R6<^08]T;@2<IBh0TfPa09AY<P2GKC<0Vg4e09ed=P2OMSH0X7Lg
0:1g=@2MNc`0WW`m0080Wgdn00L0WW`m09aj>`2JN3T0VGLh0:Eg>`2TMSX0XgDi00<0XW@h00P0XgDi
0:Af>P2ZNSP0ZG`i0:Ym>P2ZOc/0Z80k0:N0>`80YH0j0P2TNcd0102SNcd0Xgdn0:5n?P2QOcl209n0
?`<0XH541@2PP4<01P2KO3`0W7dm09en?P2OP400XH920::3@`80Y8E500P0X8I909j4A`2MPdP0WhE<
0:>9D02SR540WhA?09^0B`80Xh=:00@0XX990:61B02PP4L0Wgm60P2NOTD0402IOTL0V7e609MlA@2E
NT<0TgQ1095f?`2@MCh0Sg@m08id>`2@MCh0TGHo091e@02=LCl0Rflo08ea@P2?Ld@8099b>@<0U78c
0`2ELc@209Id=@03091/<02?Jbl0SFT]00<0S6P/00<0SFT]08iZ;P2?Kc800`2?Kc8208i^<@0:08e]
<02<K2l0T6Pe08mW=02;Ic<0QfPb089W<01nJ2l0O6L^07]X;P<0OV0/00T0OF4_07aR<@1hH300M5h_
06mJ:`1]F2/0KED_06]C;@1YDB/00P1WCbT06@1YDB/0Je<]06eE;`1/EBT0LU/_07EN<P1^Eb/0Hd`P
05e66P1SC200JU<W06YE:01[ERL0KUPY075I:@1eFbX0NEd[07aN:P1mGb/0N5`Z07UM:`1jGR`0Nel]
07aP;P1nHS000P1oHc42089V=004081T<P1nHS00OF4_07]O;@80NEd[0P1gHRd0101fH2h0MEl^07AN
;`1cG302079K<@P0K5LZ00P0K5DY06aF9`1/ERL0KUPW075K:@1dGbX0N6</07YU;P80Of<a00<0P6@b
085U<`22IS@00P23IcD02P24J3H0Of/f07m[=P1oJSD0P6Te085W=022IS@0Q6Hd08=U<`20IS<207mU
<P0307iT<@1mHc00O68_0080Nf4^00@0NEl/07YP;@1lHRl0OV@a0P1oIC801P1nI340OF<`07=L<01a
FRh0KeP/06eF:P<0Je@X0140K5DY06UD9`1XDbP0Ie8W06I@9`1TCRL0HddX069;:@1QBRP0H4lT05e<
8@1JB200G4XT05m=9`1PCRX0GT/Z05Y79P0205I38`0E05E2901D@2D0DShU050l901=>2<0C3LR04Lf
6P17=ad0ASHM04@e8010<b80>blO03H/800d:Qh0;RLO02TU700V8A/08AhI01`K5`0J6QP061XG00D0
61XI0`0G6AP201HH5bP05AHH400D5AL@01DF60<051HE0`0E5aH201HH5`P05aTH200F61L301LI6080
61XI0`0I6aX801XJ6Q006QXH200K6aT301hM60807ahI300P7aX8028Q70P08R8J2`0P7aX3024P6`80
8R4L0`0X8A/202TR70<0:R<M200_9A/302lU6@80<2HJ0`0a9a/803L[6`<0>bTK00D0?2XL03d[7@0o
;Al0@BlQ048`8P0803d[7@80?RdM0P0o;Qh3040_7`03044`8011<1h0@S4O0080@S4O0`13<R001`14
<b40A38L04Dc7@15<ad0AS@N04Le7`18=R000P19=b402016<QX0B3@L04`h801>>R80Cc/S04hj8P1<
>200BcLO0P1G>2<205Pi90<0FCXU00D0FS/V05Dl7P1F?Al0F3lQ05U08P0405Y18`0305do8`1L?R80
FcdQ0080FS`P00<0FcdQ05`n8P1M?b<00P1O@2401P1P@B80Gd0Q05ho801M?Ql0Fc`M05Xk70T0GClU
0`1M?Ql305ho8080Gd0Q00<0GSlS05dn8P1L?B400P1L?B400`1N?b<0H44U06939`0305m09080GSlS
0`1M?R8405@j8`<0EC/T00<0ES`U05`n8P1K?B400P1K?B4205Xl8080FC/O101D>B@0101B=b80D3DP
04hc7P1=<Qd2054g8003058h8@1C>B80E3XS0080EC/T00T0ES`U05@l901C>b<0DSXR054i8@1B>R80
Dc/S05Dm9@1F?RH00P1D>Ql305Dk80<0ES`Q201P@BD00`1Q@R<0HT<T06=49@0206=49@080693901Q
@R<0HD8S06A79@1UB2H0ITPV06Q79P1ZAbL206]79`0306i7:01/BbP0K4/X00H0K4/X201`Cb`0101d
DBT0ME8Z07IC:`1gE2`207QE;@0807MD;01fDb/0M5<Z07AC:P1fDb/0N58[07UC;01kE2d207iD;P80
Oe`b00H0OU/a07eJ<01mFS00OU/a07mL<P20GC<207aM<@0307]K<P1kFc@0NUXd0080NUTf00<0NEPg
07AD;@1dE2d00P1cDb`3079B:`80LE4Z0`1_DBd02`1^D2`0K4hZ06U;9`1WBBD0ITPT06959@1QA2@0
H4<S05m28P1N@B40Gd8R0080H4<S0P1G?Ql00`1G?R00EcdR05Lm900205Lm9P0305Hk9P1F?Al0ESdO
00<0EchP00T0ESdO05@k7@1D>ad0GcdT060n8`1P@BD0HD@V06169@1OAb<00P1MAb004@1VABH0IdHW
06U89`1/BbP0KdlY075A:P1cDb`0MED/07AA9`1eDRP0MU<Y07MD:P1hEB/0NEH/07YG;@1kF2h0OUl`
00<0OEh_00@0OUl`081Q<P22Hc@0Pf@e0P28HS<208US=00408QR<`26H340Q5h_08=M;P80PEhd00<0
P5dc07mL<P1nFc400P1mFS003`1lFBl0OEh_07eN<01lGBl0Ne``07QH;`1eEBh0Le<]075A:`1bDR/0
LE4Z071@:@1_CbP0KDdV06a<9@0206];900506e<:@1^CBX0KTdZ06i=:P1_CR/01@1`Cb`206m>:`<0
KTdZ00<0KD`Y06U;:@1YBbT00P1XBRP406M99`0406U;:@1XBRP0J4XX06Q::0@0IdTW00H0K4TS06e:
901^BbD0L4dW079?:@1cD2X207EB;00407MD;01hEBd0N5D]07QE;@80NEH^0P1jEbl307]H;P80O5T_
101mFS03081M<`D0PEhd00H0P5/a085L<P22GC<0Q5le08IQ=`27HSP208UT>P0608YT?@2:IC/0RVDk
08YU>@2:ICP0RVHf0P2:IS@808QV>080RVLm00@0RFHl08QU>`28IC/0Qf@j0P26HcT00`21H3D0PV4f
08AQ=`0208MR>00308MP=`28GSH0Qede00L0Qf<c00T0R6@d08MT;P27Hbl0R6@`08QT<P28I3@0Qf8e
08EP=024Gc<00P26HS8208EQ<@0408AP<023Gbl0PUh^089N;P<0P5dc:oooool002[ooooo202LLT08
0:1d@`P0Wg=62@2OMD<0102PMT@0XGM50:9hAP2RN4H30:=iA`<0XWI50`2SMdH20:AhA`030:1fA02Q
MdD0XWQ60080Y7Y800<0XgU70:5gA@2PMT@00P2QMD@20:9fA@040:=gAP2TN4L0Y7Q70:AhA`80XGI9
0P2PMDP01P2OM4L0WW=609ebA@2MLTD0VW4k09]b?0@0WG@n00l0W7<m09Ya>`2IL3X0U6lj09A_>`2C
KSX0TV`k095[?02@JSd0T6Tn08mX?@2>JCl0S6Lm08YU>`27HSP00`26HCL01@27HSP0Pf0f089O=@20
GC<0OU/a0080OEX`0P1nFc401@1fEb/0MEHZ07EE;01dE2d0LU8/0080LE0]00T0L4l^06e@;P1]D2h0
KU4_06e@;P1/Cbd0JTd[06M::01UB2H00P1WBRP206Q;:@@0JD`Z0P1WBBL0101XBRP0JD/Y06Y<:P1[
CB/206a>;00507=@:P1dDB/0ME8/07EB;01gE2h00P1hEBl02@1iES00OeTd07mI=020FS<0PUdc08=N
<P24Gc80QF4a08IR<P0308]U=P<0S6Hg0P2=IcP808iX>@P0SfTj0P2DJC`0102CJ3/0TVLj095V>@2@
ICP208mT=`08091U>P2?I3T0Sf@i08mT>@2@ICX0TVLl09AY?P2FJd03095V>@<0T6Dh0P2?I3L209AU
>@03095U>02@ICP0SVDg0080RfDf00@0RVHf095V>@2AIST0TFHi0`2@ICP208mT=`80T6Xk0P2?JCX2
08iX>@80SFLh0`2CJ3/209AY?0@0UFXm202?JCX509E[>@<0UV`j0P2GK3l209I[?P80UFXm2P2DJC`2
09=X>`80TVLj102AIST01P2@JS/0SfTj08mY>P2>J3T0SFLh08aV=`80RfDf0P2:HcP01P29HcH0RF<d
08QR<@28Hbl0Qf8^08MR;@P0RVHb0P2<Ic/00`2=J3/0SFTi08iZ>00208iZ=P0708i[=@2;Ic<0RfLc
08aX=02=JCD0SVXf08m[=`04091/>00408m[=`2>JSH0SVXf08iZ=P80Sf/g00P0TFdi099^>P2BKSX0
TVhj095]>@2?JcL0SFTe08]W<`80SF@h02`0S6Hi08aW>P2=J3/0S6Xl08][?02<K3d0QfPi08IW>025
ISL0Pf@e085R<`1oH340OUl`07eN;`1aFRh0KUL]06QB:@1RC2L0G4PW05M4901C@RH0Dd8X04do901<
?R<0B3`R04Hl8`12>R<0?SPR03dg8@0k=R80>S<P03Pa7`0e<1d0<BhM02h/7@0/;Al0;BdQ02`^8@0/
:Q/0:bTJ02TZ700W:A`09RPM02@W7P808BHO0P0R9Ah0100Q91d082<L020S700O8Q/301hQ6P<07b8I
0P0P8aX3024T6`809BHN00H092DM02<T700R8a/08B8J020Q6@0O81P801hP7@807AhH0P0N7aT201lP
6P80824K00X09RTN02LY700Y:QX0;R/J03D^6`0l<A/0@CDM04Dg7@15>Al0ASXP0P17>b406P16>R00
A3PN048f7011=A/0>S@L03La6`0b;AT0;2TH02TW6P0X:1h0:RXR02X[9@0`;ad0<S4M03Db7`0h<al0
>S@N03/c700j<aT0>c4H034`7P0`;Ql0;bdN02d[7P0/:Qh0:RLN0P0Y9Ql802dY7@@0:2TK100Y:Q`3
02HU80809B@O0`0T8ah3024R7080824K0`0O81X301/N5`0301`O600M81T07B0I00807R4J01/092<O
02<R7P0U8Qd09R4K02TR6P0]91/0;bHM038X7P1;<B80Fd4X071F<@24JST0T7<k09=d>`2CLS`0TW4l
08MY=@1jGC<0I4/]04/j:P0h;RD0;BXU02P[900V;R<09RTR02DX8@0T9b000P0S9Ql00`0T9b009RTR
02LZ8`0302@W80809BPQ100V:B8802P[90809bPP0P0X:B4202TZ8P80:R/S0P0^<BX01P0];RH0;RhT
030^8P0c;b<0=34R03Pb9080>3LS00@0>cPU03lh9P12>BP0ASTY0P19>BX0>P16>R@0BCdW04Xo:`15
?BX0?cPU03`g900k>2L0?S/Z04U1:P18@2T0BClV04Xn901=?b@0D44T05=49`1EA2H0Dd@S05E69@1G
AbH0FdPX05a7:01MARL0G4DV05a39@1PBBL0GdPV069:9P1YCbX0LUH_07EH<01cDb`0KThU06=@;`1R
Cbh0GTh]05]<;@1HBRd0DdP/0597:`1@AR/0DClY05E1:@1G@bP0G4LX069<9`1WD2L0Je<W06aD9P1]
FS00KU/a071M<P1`GS00L5h^06iL:P1/FRP0JeXV06]C;@1/E2h306eE;`0K06]C;@1ZDR`0J50Z06M@
;P1VCbd0IThZ06Q>:@1]DBX0M5L_07]K=01nGSD0PfT`089W<020IC00OV8`07iR<`1nHCD0Of8h081S
>`1lIcP0OFTg07iZ>021KCX0QW8m08]h@02@OD<0Th160080W7a300<0WGe409inA@2NOTD00P2NOTD0
6@2MOD@0VGLg09Me=@2GM3@0VG<d09ee=`2RNS`0ZH120:f4AP2hQdD0_He;0<6DD032V500_YQ=0;jJ
C02nWDh0`J9@0<>NFP32We/0_iaJ0;FCD`2YRTX0X89409f1@P2NPDD00P2KO4D02P2INdD0UGM108U^
>@1oIC80N64_07US<P1mIcH0OUhg07eM=01lG3<207]L<00907aM;`1mGS00OUla085Q<P23HC40Q68b
08MS<@29I300SFDa0080SfH`00/0UV/d09Q^=02KLCL0WW@h0:5h>P2RNCT0XWTg0:5h=P2JNc/0Vg`l
09am?@0209en?P0409am?@2JNc/0VGXj0:Eg>`80Y7Hj00d0XgDi0:Af>P2WNCd0ZG/o0:Yl@02]OSP0
[Wli0:f1>P2]Pc/0Zh<k0:R2>@2VP3L0Y80f0080Yg/l00@0YG`l0:An?@2ROcd0X84n0P2OPSh809j0
A080Ug/l00@0V7`m09Um?P2JOSl0Vgm00P2LP4403P2GOTD0UWe409ElA02IP4X0WH=@09j4D@2KPE00
Uge<09n0A`2NOdH0WGi509]l@`2INT40V7U00P2FMch0402DNTL0TgU6099hA@2@MT<0SWA108]a?P2:
L3d0RFll08M^=P2;LSX0SG@n08ab?`27KC`0QV/l08Q]?P2<LD@308Yd>0D0RgDi0P2DLS8209Ec<`80
UW@d0P2GMCD00`2ELCD0U70d099^<P03091/<004095]<@2BKS80T70g091`=@80Sfld00`0Sflb08i_
;`2>Kbl0SVl_09AX=`2CJCL0SfXf08YY=025JS<0P6Xa07eZ<01jJRl3081R;00T07eR;@1kHBh0Mf0^
07AN;@1aGB/0L5//075I<`1^ES00JU8/06M?:@1VCRP0IdlY06YB;01[Dbd0JU<W06mH;01bFbl0KUL[
06M@901RBal0Hd`P06I?8`1YE2L0JUDV06aF9`1`F2P0M5XY07QL:P1lGRX0OEl[07MK:@1hG2X0NEd[
07YN;01lH2h0OV8`0P1oHc402023IcD0PVHd081T<P1oHc40O60^07]O;@1iGB/0N5`Z0P1gHRd01P1f
H2h0MV0_07EO<01dGC40M5dc07=L<PP0KEP[00P0K5HW06eG9P1]EbH0KeTW079M:01fHBX0NVD/07aW
;P80P6@b00@0PFDc089V=023IcD0PfLe0P24J3H01P20K3L0Of/f081[=P21JSH0PVPe08=W=@80Q6Hd
0P20IS<0101oIC80OV@a07eS<01lHRl207]Q;P0407IL:@1hGR/0NV0]07eS<0<0OV@a00D0OF<`07EN
<P1dGC40LEX^06mH;00306eF:P0706iG:`1[ERT0JUDZ06UD:@1XDRT0Ie4Z06E?:P0206A=:`08065@
901MC200FTTN05]98@1NC2H0GddY05a:9P1HAB@205M28`0F05Q39P1G@RL0EClW058l9@1?>B@0CCLR
04Pg6@18=a/0AcLM04Df7`11=240?S4Q03X^800h;200<BXR02hW7`0Y91h09B0L024M6P0M71X06a/I
01/K6`@061XI0`0G6AP201HH5a005AHH200F5aT@01DF610051DG400E5QP301@F5@<05ALF0P0F61L8
01LI60P05QPG0P0G6AP201PJ6@@06A/J200J6QX@01XJ60P06a/I0P0N7AP201lN6@@081lJ2@0Q81/8
02<R7@P08b<K200Q81/3020O6P<08B0K0P0R8A`202PQ6`80:B8L100Z8ad01P0`9Q`0;bDK02lU6`0^
91X0;B<I02`R6080:b4G0P0^91P202lU6@<0<2HJ00<0<BLK03HZ6P0f:QX01P0f:QX0200j:1X0>BLI
03TW6@0i9aT0>bTK03h/7P10;R00@S0R200n;1h303l^7P80@2lO0`11<202044`7P80@S4O00@0@c8P
04@c8@14<b40A3<Q0P15<ad00`16=1h0AcDO04Pf800204Tg8@0904Xh8P17<a/0BSHN04hj8P1A?BD0
DShV054m9@1?>b<0CCTQ00<0F3TT0P1I>RD305Xk9P0405Dl7@1G?Ql0FD0Q05]28`80G4<T00D0Fd8S
05Y18P1N@2@0GClS05/m8@0205Xl800405/m8@1M?b<0GT0T05m08@80H44R00T0HD8S05m08@1M?Ql0
Fc`M05Tj6`1J?280FcdS05`n901M?bD00`1N@2H0101O@BL0H48X06918P1R@B8306508@<0H3lP00<0
HT0T064o8`1P?R800P1O?B400`1P?R80HT0T06=19@0306119080Gd0S0`1N?b8305Hl9@80EC/T0`1D
>R<205/n8080FSdO0`1I?1h02@1H>ad0DcLR05@h8`1E>B@0ESXU05Di901C=b80DCDP04lc7P0205@h
8P0405Di8`1F>R@0Ec/U05Pl9P80FCdW0P1D?2@3058j8P0305@l901F?RH0EclW0080E3XO0`1E>b03
05Hl8@0505ho8`1O@2@0Gd0T06119@1Q@RH00P1R@bL00`1SA2P0Hd@U06=49@0206A59P0:06=49@1Q
@R<0Gd0Q05ho801QBBD0HTPU06E89P1VB2H0JTLW06a8:080KdHX201]C2T8071?;00307AA9`1fDbT0
Me@Z0080NEH/00@0N5D[07MD:P1fDbT0ME@[0P1fDb/00`1hDR/0NU</07aB;00207eA;00407eK;P1n
G2l0P5ha085O<P@0PV0c00P0OEhb07aM<@1lG3<0O5`e07]K=@1kFSL0NUTf07YI>0@0MeL`1@1fERl4
071B;00406e?:@1ZC2H0IdTS06E78@@0HdHV00@0HD@T05m28P1M@200FchN0P1G?Ql00`1G?R00EcdR
05Lm900205Pn9`0R05Pm:01F?Ah0EchO05Po801I@240F3lP05Hm7P1D>a`0DcXK060l901Q?B<0HT0U
06549P1PARD0GTPS05]8801JAal0I4<T06I59P1YB2L0KD`Y075A:`1eEBh0MeL`07UI<01cDB@0M58U
07EC9P1gEBP0N5HY07YH:`1kFB`0O5X]07eN;`<0O5d^00H0OUl`085R<`24ICH0QVLh08YR<@2;Hc82
08aT<`0408]S<P29HC00Qel^08IN;@80PV0c00<0PElb081N<@1oGC000P1nG2l03`1mFbh0O5d^07aM
;P1mGS00O5da07]K<P1hF340MUH_07AD;P1cDb`0LU8[075A:P1`D2T0KThW06e=9P0206];900306a;
:01]C2T0KD`Y0080KD`Y0`1^CBX3071?;080Kdh[0`1^CBX00`1ZC2X0JD/Y06U;:@0206Q::080IdTW
00@0ITPV06M99`1WBBL0IdTW0P1XBRP306U;:@0806i;9@1_C2H0LDhX07=@:P1eDR`0Me@^07QE;`1i
ES0307QE:`80NEH/0`1jEbd307eK;P80OU`_101oGC000`21GS@0P5dc081M<`05081M<`80Pehd00@0
Q5le08EP=P26HCL0Qf8h0P28HcT02@2:I3l0RV@m08YU>`2:ICT0RfLg08]W=@2;Ic<0RfPb08aZ?002
08]Y>`0508YX>P29IcT0R6Hh08QV>027ICL00P2<JCl0102;J3h0RVLm08UV?028IC/208MT>P03089Q
=P23HSL0QF8h0080RF@j00<0R64h08UO=`28GSH02028I3802026Hbd0Qf<_08UU<@29IC<0RFDe08MR
=@25H3@0Q5lc0P27Hc401026HS00QF4_08AP;P23Gbd2089N;0<0PUle:oooool002[ooooo202KLCl8
0:1d@`P0Wg=6202OMD<20:5gA@80X7I400D0XGM50:9hAP2TNTP0YG]90:1d@`020:5eA0030:9fA@2S
MdH0Y7Q70080YGU800<0XGM50:9hAP2SNDL00P2TNTP00`2RN4H0X7I409id@P020:5eA080XWI500X0
XgM60:AhA`2TN4L0YGU80:=hC@2RMd`0XGI;0:1eBP2OM4T0WG970P2LLDH00`2JLC/0Vg8l09ed?P03
09ed?P0?09ac?@2JLC/0VG0j09E`>`2EL3`0U6lk09=]?02BK3d0TF/n095Z?`2@JCh0SVTo08eX?P2:
IC/0Qf8h00<0QV4g00D0Qf8h08=P=P22GcD0P5dc07iK<@0207eJ<080OU/a0P1dEBT00`1dE2/0Le</
07=C;@02079A;P03079A<01/Cbd0KE0^0080KU4_00@0K4l]06Y=:`1WBRP0IDPV0P1WBRP206Q;:@<0
JD`Z00L0JTd[06M99`1WBBL0J4XX06U;:@1ZC2X0Jdd[0080K4h/0`1eDR`207IC;@80Me@^00T0N5D_
07mI=01oFC@0P5Xc089M<`23GS80Q5lb08EQ<@26HS800`2;ICH208aV=`<0SFLh202>J3T808mY>P09
09EZ?@2DJC`0TfPk099W>P2AIST0T6Dh08mT=`2>HcH0TFHk00<0T6Dj00@0TFHk09=X?@2EJSl0Ufa1
0`2AIST3091U>080Sf@g0P2DICT01P2AICP0Sf@g08iU=`2;ICH0RV@e08UU=@<0TFHi0`2@ICP208mT
=`<0T6Xk00<0SfTj08iX>@2=IcP00P2=IcP309=X>`80U6Tl102EJSd0102@JS/0SfTj08mY>P2?JCX4
08iX>@80UVdi1P2EK3P209M/?`80UV/n00@0UFXm09AY?02DJC`0TfPk202DJCh209=X>`80TVLj0`2A
IST01`2@ICP0T6Xk08mY>P2?JCX0SVPi08eW>02<ISL00P2;ICH208YS>00308US=P29Hc@0R68a0080
Qf8^00<0QV4/08YV<P2:IS801P2:IS8208aW>`0308eX>`2=JCT0SVXh0080SVXf00L0Sf`f08]W<`2;
Ic<0S6Pd08eY=@2>JSH0Sf/g00H0T6`h0180Sf/g08iZ=P2=JCD0S6Pd095]>@2BKSX0Tflk099^>P2A
KCT0Sf/g08eY=@2;Ic<0Rf8f08aS=`2;ICP0RfHi08eX>`2=Jcd208e]?P0@08MX>@26IcP0QFHg08=T
=@21HS<0Of0a07iO<01mGRl0L5T]06eF;01WDBP0Gd/V05U69@1D@bD0Dd8V05519`80C3hS00h0B3`R
04Hl8`11>B80?SPR03`f800j=B40>C8O03Pa7`0d;a`0<2dL02h/7@0/;Al0;BdQ02`^8@80:bTJ00@0
:2TK02LY700V:1d092LN0P0Q9Ql202<V7`04028U7P0Q91d07b8K01hQ6P<07B0I0`0O8QT2020S6P<0
8B@K0P0U9Qh00`0T9Ad08b@L028S6`02020Q6@0301lP600O8Ah07b4N00H07b4N0P0M7QP201hO6@80
7b0J0P0P8A/0200W:ad0:2XL02X[6`0_;1T0=BlI03db7012=Q`0ASPM0P16>R0204Lk8@0D04Hj8014
>1h0@SHL044e6`0i<a/0=S0J034/600/:AP0:RPK02XZ800/;2@0;BhX030_6`0a<1`0=38M03Pc7@0j
=1`0>S8K03Tb600k<AP202l]7P0602h/7`0/:Qh0:RLN02TV7`0W91d09b@O200]:Ad502PY6`<0:BXL
0P0V9B0202DT7`<092<N00<08b8M024R700Q8Q`00`0P8A/301lP6P0401XM5P0K7QL06ahG01`O6080
7B0I0P0N8AX06P0T8al09R8O02DR7@0V8A/0:B8J02dT6`0a9ah0<bTO05Dh:01WBc<0P6@l095f@@2F
NCd0UGLi09Ad>`2DLch0QFLa07EH;P1K@bL0@BlS02hU800W9R809bhW02Xd:`0W:R<09RTR0`0T9b00
0`0U:2409bXS02P[900302@W80809BPQ100V:B8802P[90<09bPP00<0:2TQ02TZ8P0Z:b<00P0Z:b<0
B`0`<b`0;c8[02h_9`0^;R@0<2hR038^8P0c<240=S0R038d7`0e=200>3DR03df9010=bH0ACPX04Ph
:@1:>2X0BCdW04a0:P1<@Bd0Acl/044j9`0m>2D0?3TX03hk:P1:@R/0BD4Z04Y09`1:?R@0CClT04m0
8`1B@bH0E4<U05938P1DAB@0EdLV05Y79`1LAbP0G4DV05]49@1J@B<0IDh/06A=:`1UCBT0Je4/079F
;`1bEBd0KThW06Q87`1QDBl0H50_05i?;P1KCRh0Ed`^05E:;P1BB2d0D4T]054o:@1D@2P0Ed<X05a7
:01QBbH0ITlU06YB901[Db<0KEX`06iK<@1_G340L5h`06mM;@1]FbT0JUPV06UH901XD2`0JE4]06YB
;P0206]C;`0C06UA;@1WCb/0IThZ06I?;@1UCR`0IDdY06Q>:@1]DBX0LeH^07]K=01nGSD0PfT`085W
;P20IC00OV8`07iR<`1oHSP0P6<k085S?@0207iY>P07081/>P23Kc`0Qg<n08ej@P2BOdL0UH9809Mg
?P0209Qh?`0M09Yj@@2MOD@0X8170:B4B`2VQTd0VgTi09Yh>02JMcL0W7Hg09mg>@2TNcd0Z7m10:b0
@`2dPD00^HQ50;n@C02oUDd0^iE:0;^GB@2kW4X0_Ym=0<2MF@30WE/0_IaI0;:CDP2UQdL0VW`n09Eh
?02DMc/00P2?LC/05@2@LS`0S74l08AZ=`1jHc40Mf4`07eW>021K3d0OEdg07aL=@1kFc@0Ne/b07]L
<01lGBl0OUla07mP<@24HS@0QF<c08QT=02:I3<0SFDb08mW<`02095X<P0A09U_=@2KLCL0WW@h0:5h
>P2SNSX0XgXh0:9i=`2RNSD0VGXj09Yk>`2LOCd0WGhn09io?`2MOSh0W7dm09]l?02WMS/00`2VMCX0
502XMc`0ZgXo0:mn@`2aP4D0/7lj0;21>`2aPS`0/8@m0:j4?02ZPSX0YX0g0:Eo=P2XNcX0Yg/j0:Im
>`2TOc/0XX4l0:22?02OPS`0Wh@m0`2LOT8409eo@`0409j0A02FNS/0UWXk09Ij>`80Ug/l0`2HO3d0
5P2ANd80SgU008mh@P2CO4P0V85?09Z2DP2GOdl0U7a>09enA`2LODH0VW]409Qi@P2FMd00Tg@m099c
?02ALS/0T7U508mhA02=MT80RgA008Ub?P26Kc/208A]>@0908A[<`28KcT0Rg8l08U_?024JST0PVLh
08I[?P2:Kd80QGDg00D0QWHh0P27McT309Ac<00309Ed<@2FMC80UgHc0080UgHc00@0VWHh09Qd=P2F
LS@0UG4c0P2DL380102ELC<0UW8d091`=`2@L3L208m_=00=08m_<P2?L300Sg0_08m`;`2FJST0U6Xh
091[=`2<JcH0QV/d081[<P1lK340NV/`089T;P02085S;@0:07eR;@1jH2d0MUl]07AN;01cGbd0LUh/
07=K=@1`F380Je<]06M?:@80IThX00D0JE4[06YB;01YDRH0JU<W06]D:00206aE:@0;06YC9`1VCb<0
Hd`P06QC9P1YE2D0K5HW06mG9`1dFRT0Me/Y07]M:@1lGRX00P1gFbT0101iGB/0NUh/07aP;P1mHBl2
07mS<@0808=W=@22IS@0PFDc07mS<@1lH2h0NUh/07UM:`1hG2X207MR;@0407MQ;`1fH2l0MEl`07EN
<P80M5dc201]F2/206eG9P0606iH9P1`FRP0LehY07MR:`1kIRd0OFP_0P20I3800`21IC<0PVHd08=W
=@0208AX=P0908EY=`20K3L0P6`g081[=P21JSH0PVPe08=W=@25IcD0Q6Hd0080P6Hc00<0OfDb07iT
<@1mHc000P1lHRl01`1kHBh0ME/X07MM:P1iGb`0O68_07eS<01nI3400P1mHc001P1gH3@0MEhb07=L
<01`FBd0KeP/06iG:`80KeP/02P0K5LZ06aG;01[ER/0JE<Z06QB:`1WDB`0ITl]06E>;01QD2@0GTdQ
05Y97P1KBQl0GD/S05e;9@1JB2@0ET@P05M28`1H@b@0F4<V05Q3:01F@2P0DcdV050j9@1>>2<0BcPJ
04Th6P19>1h0AcLP04@e8P0o<R40>blQ03T]7`0c:R<0<2TQ02`U7`0V8Ad08QhK01hM6`0M7A/07AdM
100H6QT301LI60805QPG400E5QP801HG6A005AHH400D5AL@01DF60<051HE0`0E5aH201HH5`P05aTH
200F61L201LI608061XI0`0I6aX00`0J71/06QXJ01XJ6P0601XJ6Q006QXH200K6aT201hM60807ahI
0`0P7aX:024P6`P08b8M200S8a/8024P6`<081lJ0`0Q81/2028Q7080:24K0P0Y8Q`302XS7@0902/T
7P0`9Q`0<2HL02lU6`0]8aT0:b4G02XP5P0Y7aD0:1hD0080;R@H0P0_9AT4030V6PP0=RXJ00P0>BLI
03PV600h9QP0>2HH03XX6P0l:Q`0@2hP048`8PP0?b`N0P10;Ah2044^7`<0@RlP00@0@c0Q044`7P11
<1h0@S4O0P13<R001014<b40AC@R04Dd8P15<ad204Hd7P0304Le7`18=R00BCLQ0080BSPR00P0B3@L
04/g7`1?>b<0DclW05A0:01C?bL0D3`T04hj8P80FCTT0P1J>RD305/k9P0<05`l9`1E?1d0EchO05Y1
8P1L@b@0GD@U05a3901K@R<0FT4R05i0901M?b<0FcdQ0P1J?2001@1K?B40GClS05i0901O@Al0H48P
0080HD<Q00P0H48P05do7@1K?A/0FC/I05Tk8@1J?280FcdS05`n9080GT0V00@0H48X0653:@1Q@bT0
I4<R0P1S@R400`1R@B00HD0O060o7P0205ln7@0306A29P1R@2@0HClS00<0H3hR00<0HT0T06=19@1Q
@RD00`1P@B@205m08`80GSlR0P1G?BH205Hl9@0405Dk901D>R<0DcTR05<i8P<0Fc`O0P1J>ah305Tj
7@03058f8@1C=b80ECTT0080ESXU00<0E3PS058f8@1A=B000P1E>B<0101F>R@0Ec/U05Tm9`1J?RP2
05/o:@0805Dm9@1D?2@0Dc/S058j8P1C>b<0E3`T05Hn9P1G?bL205@j7`<0EC/P0`1F?2401P1M?R80
GSlS05m0901P@BD0HD8V06=4:080I4DY00P0I4DV06E69`1UARL0IDHW06=49@1Q@R<0GSlP05`m7P80
HDTU00H0IDPV06M99`1ZAbL0KTLX0717:@1bART806e<:@P0L4l/00<0ME8X07IC:@1hEB/00P1jEbd0
0`1iER`0Me@Z07IC:@0207MD;00407UC;01iDR/0Ne4[07]A:`80NdlZ00P0O5X/07iL;P21Gc40Q68d
08IT=P25HcD0Q68d089P<P80OEhb00<0O5`c07aL=@1kFcD00P1kFSL00`1jFCP0Ne/b07]K<P0207]K
<PD0NUXa00T0L58/075C;@1aDbd0LE<]06i@:P1[CBL0J4XT06E78@1VBBL00P1WBRP01@1VBBL0HTDS
05e07P1I?1X0ESTG0080EchO00<0EchP05Pn8`1H?RD00P1H?RL08P1H?BP0ESdN05Ln7`1H?b00FD0Q
05Po801F?Ah0E3/L058i6P1Q>b@0HCdS06=19P1RABL0H4HU05i88`1JAal0F4HN06A3901UA2D0JDPW
06e<:@1bDR`0MeL`07YJ<`1lG3<0Le4S07AB901eDbD0MeDW07QF:01jF2X0NeT[07aJ;01lGBh207]L
;@0607aM;P1nGc00PV<d08EV=`28JCX0Rf<b102<I3<0102:HS40Qel^08IN;@23HC<2089P<P03085O
<@20GS00Oed_0080OU`^0100Ned[07aM;P1mGRl0OEh`07aM<@1jFS40MeL`07EE;P1dE2d0Le</079B
:`1`D2T0KThW06e=9P1/C2D0Jd/T1@1/BbP306e<:@<0L4l/0`1_CR/206i=:P80JT`Z0P1YBbT00`1X
BRP0IdTW06M99`0306I89P0406M99`1XBRP0JD/Y06U;:@80JT`Z00P0LT`U07==9P1dCRL0MU0Y07UC
;01kEBh0O5H_07eG<080NUD[0`1kER`307aG;@<0OU`^0P1oGBl4081N<0@0P5dc101oG38308EP=P80
QV4g0`27HSP01P2:I400RV@o08]U?P2;ISX0RfLg08]W=@80S6Tc00H0SV`n08e[?@2<JS`0RfTk08UW
>@28ISP208MU=`80SFY000@0S6To08]X?P29IS`0R6Dk0P27I3X00`22HCH0Pf8g08IS>@0208UT>P03
08UR>@29GcL0R5hf00@0RFDc1028I3803P26Hbd0Qf<_08UU<@2:IS@0RFDe08MR=@25H3@0Q5lc08QT
<P27Hc40QV8`08EQ;`24H2h0Pel]0P22GR`308=P=R_ooooo000Zooooo`P0WgA10`2PMT@309me@`80
WWA2202OMD<20:5c@P<0XWA30`2SMD@00`2PMd<0XGQ40:=jAP020:AkA`060:9iA@2PMd<0WgI20:1h
A@2QNDH0XWY70P2SNdP00`2QNDH0WgM409ee@P020:=jAP<0XWU50`2QN4@80:1fA080Y7I500<0XWI5
0:5gA@2OMd@00P2MN4@01@2LN4@0W7I709]eAP2JM4D0V7930080UW1100<0UFm009A^?`2CKCh00`2@
KcT508m^>00<08YV=P2;IcL0RfHi08YU>@28HcT0QElh08=M>021FcH0P5de07mL=01mFS80NeP`0P1j
Ebl207]H<00607YC<P1hE380Me<a07ID<@1dDc00LE<_0P1`E2l01P1aDbl0L58^06mA;@1^D2`0KDl[
06]=:@80JT`X0P1ZCB/206U<:P<0J4/Y00T0IdXX069:9P1UBbP0IddZ06a?;@1^D2h0Kdh]06m<;01^
Bb/00P1dD2`0301eDR`0Me@/07QE:`1jF2/0NeT/07]I:`1mG3<0OE`a07mL<P23GS80Q5lb08MQ<P80
RV8a0`2@ICP3095V>@X0TVLj0P2?JCX3091Z>`<0TF/l00H0TfPk099W>P2BIcX0TFHi091U>02?I3L2
08iS=PP0SFLh00<0RV@g08]U>02=IcX00P2>J3/00`2=IcX0RfDh08YT=`03091U>080Sf@g0`2>HcH4
099W>P@0TFHi00H0RVHf08aV=`2<ISL0SfHh095V>@2BIST209EV>PT0TfPk00<0TF`h091[=`2?JSH0
0P2>JCD00`2?JSH0TF`h099]>@0309=Y=`80U6Xh2`2EJcT809=X>`03095V>@2BIcX0TfPk0080UFXm
00<0TfPk099W>P2AIST00P2<ISL308]U=P<0RV@e2027Hc<308YW;`80RfP`0`2<JC401024H2`0QV8^
08UU<@2<J3@308iZ=P0408eY=@2@JcL0T6/g091[=`80TF`h0`2BKCT@08m[>`0308YX>P29IcT0RFLi
00@0RFLi02T0R6Hh089V=023IcD0PVHf089V=`1oHSH0O5le07UL=01hFc<0JUL/06QE:`1TDRX0GThZ
05Y::@1DABH0D48W04i09P19?b@0B3hU04Hl8`13>280?c@P03`a7`0j;Qh0>BdM03H_700e;Q`0=2lL
034^7@0_;Ah0;2dO02/[7`0Z;1l0:RdL02T/6`0X:Q`09bTL02DW700T9Ad08b@N028S7@09020S6PP0
7R4H0P0R9Ah0100Q91d082<L020S700O8Q/201hQ6P807b4N0P0N81d201dO708071hK02H07QhP01hN
7P0O7al07alM020Q700Q8Q`08B8J028S6`0U9a`09bTL02`Z7@0a;Qd0>34N03hc7@14=Ah0ASPN04lk
8019>1`0ASDK04Hf7@18>B80Ac/U04@i8`11=R80;BhX02`/900Y:B40:BHM02XV6`0_:Ad0<b/N03H^
8@0n<aL0?S8H03dc600k=1X0>C<K03Pc7@80=S@O0P0b;R80100a;B40<2`P02hZ7P0]:Ad202`X70P0
9bTN0P0U9a`402HX7@809bTN0P0T9b000`0S9Ql08RDN024T7@0201lR6`T07R4J02<07B8L01`Q6`0K
81T06R0F01/Q5@0M8aD082HH024X600N9a@09RXL02/Z9@0Z92@0:AhL038R5@11;aT0Cc`N06e>8022
I300TWDk09=g>02AM3P0TWM208mbB027JDD0HE8k04i1;P0g;a`0:bDG02LW7@0V:b@08bTU01`W8`0S
9Ql092LP02HY8P0202LZ8`0302HY8P0T9b008bHO00<092LP0P0U:24402HY8P809bPP0P0X:B4202TZ
8P80:R/S0100:RlX02P]9P0X:b80:2XO02T[7P0^;b40=38S03Le9P0g<bP0=C4U034]8@0_;1d0<2dL
03<`7@0h=R40>cTT0P0g=R803P0h=R40>cHP03hh8012>b40AChT04To9017>b<0BclW04e1:@1;?bL0
ASXR04<g7`16>R80BShV0P1<?280101=?B<0CclU05109P1B@RP205=3:@0F05109P1B@BL0ED@X05U6
:01LAbP0GTLW05m69`1NAR@0Jd`P06Y=8`1/CbD0KE4Y06]B:P1ZDR`0J58]06MA;01OEC80G58_05]>
;01FBBL0EDHU05A48`80ET<S0500Gd4O0612801RA280I4HT06M99`1ZC2X0K4h/06i@;P1TEbd0IEP^
06QI<01ZF300JUL_06YD;@1XDR/0IdlY06AA:@1UDRX0JE</06aD;P1^E2l0Ke<^06iB;@1^D2`0M5T^
071E:P1[D2D0JDhS06Y?901`EBX0Me`a07aQ=P21IcH0OV@c07YP;`1gGB`0N5h]07]Q<020ISD0PfTh
08=Z<@24Jc80QVdd08U`=`2=M3/0T7Ln09=j@@2EO4<0V7Xn09Uk?`2MOD00XGm00::0@02SP3h0YGln
0:Ao>`2ONS<0X7/d0:=n=`2WPS/0[8M00;:=AP2fTDX0^IA=0;ZEA`2gTT@0/hm50;6<A@2`SDT0/Y1@
0;JFF@2iVE`0[i5M0:f?F`2XRUH0XH=?09YlB02DMT80Sg4m08a^>P80S6Xj02l0RfTi08IW>021ICH0
O6@f07UT=`1gI3T0MfHj07UH=@1hEc@0MeD`07ID;P1gE2`0NUD[07eF;@1nEb`0PEDV08IL;02>I380
T6Pd08eX<@2;J2h0S6T_08i/;`2CLSd0U7<m09Uf?P2ON3d0XWPl0:Eg>@2VMSH0YWDc0:ImA`2TNd<0
XGTn0:1h>P2QNSL0Y7dh0:R2>@2ZQ3/0/ghj0;:0>`2dPCl0]HA20;F5A@2bQ4H0/8A50;24A`020:^5
A080ZXA300`0ZH=20:N1@02VP3l0YX0o0:=j>02TNcT0Xgdl0:5n?P2NOcl0W81109V0@02GOd4208Qh
A00608Yi@`2<ND40SWU0091j@02@NSh0Tg/o0P2AMDH0502?Ld@0SG5208]_@029KCh0R6`m08M[?01o
JCX0P6Pj089W>026IcP0RVXi091/>P2EKch0VG4n09akA@2KNT@0VWU309Qg@@2FMCl0UG@n0P2CLS`0
2`2<Lc/0S74j08]_?@2;K3d0RFPm08QU?`29Hcl0R65008Y]A@29K4@0QVU10080Q6Lo00<0QFQ008IY
@@28Jd<00P24JCh02024JCX0QF/j08E/=P26KC@0QVhb08I^<028M3T0Qg<h0P25LCH03@26LSL0R7@i
08Yf>`2<N3d0QgHn08If>`27M3X0QW8g08Ma=@2:LS@0Rg<c08ed=02AMCH00P2@M3D208mc=00908ib
<`2=LC80SG4b08aa>P2;L3T0RVlh08Q]=P27K3D0QFXc0080PfPa00<0QfPj08=T=P23I3H00P1oH382
085R=00B07eN<01iFR`0OF8g07UN<`1bERh0JdlX06Q<9`1WBRP0JD`Z06]>;P1YDB/0JU<Z06]D:`1/
EB/0Je@X06UC901WDB00IDlN0P1TCb001P1UCb00J50R06mD9`1fFBd0OUlc089S=`80Ned[01H0O5h/
07eO;@1oHBl0P68`085S<@22I380OV</07mT;@20IBh0PFH_081U;P1nHb`0Nf0Y07UN9`1lHbX0OF@[
07iU;@1nIBl0O68_07UO;P1eFbX0LULX0P1bG2X0101aFbT0L5XX06mI9`1^F2H206eG9@0@075G9P1b
F2L0M5XY07MM;01jH2l0OF<b081V=@21IcH0PVTa08=Z<P24Jc<0QF`d08A[<`23JS80PFP`081W;`80
Q6Xg00@0PfTf089X=@20IS<0OfDb0P1nI3405P20IS<0OfDb07eS<01lHRl0Nf4^07aR;`1mHc00OV@a
07AN;01hHBl0OFHd08=Y>026JSX0R6Tj08MW>026ISL0PV<d07mP<P1iGBh0LeP[06iF:P1[E2X206YD
:`80J5<T00H0Ie8U06E@9@1TCRD0HT`U065;901QBbH205m=9`<0GT`V0`1MBbD205U:8@0F05M88@1E
AB40E4@R05928@1@@1l0D3lQ04`k7@19>Qd0AcPK04<e6P10=1X0?cDL03de7P0n=Ql0<RdI038]6P0^
:aX0:bTL02@T6P0O81X06Q/F01HH5@@061XI1@0G6AP@01HH5bP05ALF200E5QP801DG5PP05QPG200G
6AP@01TK60P06QXH200L71X801/L5PP06a/I0P0M71L301hM60<07ahI0`0P81P4024Q6@808R8J0P0U
8AP302HR6@L09b<J0P0V8QT202DQ6080:1lJ00<09b0J02@O6@0S81T00P0P81P01P0O81P07QhF01hN
5P0O7aL0820H024Q6@808b<K00<092@L02LP600W81P00`0X8AT302TR6P809BDK00L0:2DL02TU700/
9Ad0;2DM02dT7@0^9Ah0<BDI00<0<RHJ0P0c9a/203@X70<0=RTI00<0=bXJ03P[6`0h:a/00P0i;1`3
03d/7080?RdM0`0o;Qh3048`8P03044_8@10;R00?bdO0080?bdO00<0@34L044b7@12<ah00P13=1l0
2@11<Qd0@34L03h_6P10<1L0@C4H048b6@14=1/0ACDL04Lg7P0204Ph7`80C3@L00@0CCDM04hf7P1?
=al0CcLO0P1@>200401<?Ah0C3/M04/j701=>Q`0CSTL058j7P1E>b00ES`Q058k701D?Ah0EchP05]0
8`1N@2@0GSlS05lm8P1N?24205/l7@@0FS/L0P1I>Q/0401L?B40GChR05m0901P@BD0Gd0T05dn8P1K
?200FS/O05dn7`1N?b00H44R06528`1P@B80Gd0Q05dn7`1K?1d906529@0:05Xk701K?1d0G3dN05dn
7`1O@240H44R06528`1R@b@0Hd8S06A390<0ITDV00@0I4<T06918P1Q@240G48W0`1K@BH205Y09@80
FClT00<0G3`S05dm901N?RD00P1O?bH00`1M?B@0Fc/R05Xj8@0305]38@D0FT8P00H0EclS05Hn8P1F
?R80ECdQ05@l801C>al2058j7PP0F3XP0P1D=Qh0201E=al0ESPP05Pj8P1I>b<0FS`T05/m9@1H>Qh0
EcTM0P1E=a/01@1G>Ad0FS`P05i0901P@RH0HT4R0080Hd8S00<0I4<T06E49@1VABH00P1WARL206Q7
9P80JDPW00@0J4LV06M69@1T@b80Hd8Q0`1UBB@206I:9@<0Id/V0P1]BR@0101^BbD0Kd`V075>:01b
CbT207=@:PP0ME8Z00d0LU8Y07IF;@1iFC00N5P_07=C:P1bDRT0MED/07YJ<@1`E2d0LED^079D;P1e
EBl0MeD`0080NEDa00@0O5Hb07aI;`1mFS00Oe`b0`21GS@207mL<P<0Pf0f00<0PUle085N=020GC<0
0P20GC<01@22ICd0P6<k07eP>01jGCD0N5/c0080MeXb0P1hFc<0201gEc00MUH_07EE;P1cDb`0LE4Z
06m?:01^CRL0KDdV0P1WBb<01P1VBR80I4PP06=77`1RAQh0HDDM061470<0GClU0P1L?R@305/m8`80
F3XN00<0FC/O05Xl801J?2000`1J?20205ho8`80Gd0T0P1P@BD206529P0506I5901XAbH0JdXW06m?
:@1bDR/00P1cDbX06@1cE2P0MU8^07IB;P1eDR`0MU<[07MD:P1kFB`0OU`_081N<01kF2h0O5T_07iK
<@1oG380PEhd08=P=P24HCL0QF8h08YT=@2=IcP0T6Xk08eW>028HS<0QEl`08US=02=IcP00P25Fc<0
1023G3<0PUdc089M<`20GC<207mN<`80PE`_0`22GC0308=N<@0@07=>8@1bD2<0Le4T07=B9`1aDBP0
KE0X06Y>9`1YCBH0L50Y06m?:01^CRL0KDdV06i>9`1_CbP0LE4Z079B:`80M54[0P1cD2X3079?:@0<
075>:01ZC2X0KD`[06e<:`1_C2`0Kd/[06m8:@1^ABL0KD@V06i@:P1]CbT0JddW0P1ZC2H04@1[CBL0
KDlY06mA:`1eCbP0MU0Y07MA:P1iDb`0NeD^07aF;`1mEc00OUPa07UD9`1kERT0OUT/081K;P22GC00
PE`_0080P5/^2@22GC000`27HSD0QV4d08AO<P0208=N<@0408AO<P25H3<0QV4d08UT>080RVDi00<0
RfHj08aW>`2=J3`00P2>JCd208iU>@0408aV>@2;IST0RfHi08UW>@80R6Pi00<0Sf/k08eY>@2;IcL0
0P2:ISH00`2;IcL0SFTi08m[>`0209Ea@@80U7100180Tflo099^?P2AKCd0TFdm095/=`2?JSD0S6Lb
08UT;`28Hbh0Qf8]08QS;P29I2l0Qf8]08QS;P29I2l0RVD`08]V<@2=J3<208iY=0P0RF@g0`27HSD2
08IQ=0<0QF0c0`25H3H[ooooo`00:_ooool809md@@<0X7I40`2OMD<209id@PP0WgE30P2QLd830:9d
@`<0XgE400<0X7M30:5hA02SNTH00P2TNdL01P2RNDD0XGQ409mf@P2OMd@0X7Q50:5iAP80Xg]800<0
XWY70:1hA@2OMd@00`2SNTH20:9iA@<0XGQ4202QMdD20:AfA@030:9fA@2QMdD0WgM40080WGQ400D0
W7Q409]eAP2KMDH0VWA509Qb@`0209I`@@0309E_@02DKSl0Tfdn0080T6lj102?KST208i]>00<08UU
=@2:ISH0RVDh08YU>@29I3X0QV0i08AN>@22G3L0PEhf081M=@1nFc<0O5Ta0P1kF30207aI<@0807YC
<P1hE380Me<a07ID<@1dDc00LE<_071D;`1_Dbh206mA;@80KU0/00@0KDl[06a>:P1[CBT0JddY0P1Z
CB/206U<:P@0J4/Y00H0Hd/W06E;:01XCR/0K4l]06i@;P1_CRd206m<;00>07A@;01eDBd0MU<]07MD
;01iER`0NUP[07]I;01lFR`0OE`c07iM<P20GC<0Pehb08AO<P27HC8208YR<@<0Sf@g0`2@ICP2095V
>@P0TVLj00<0T6Xk08mY>P2?JCX01@2?JCX3095V>@<0T6Dh0P2?I3L808eW>00308YT=`2;ICP0SFLj
0080SVPk00<0SFLj08]U>02:I3L00`2@ICP208mT=`<0SV<f0`2BIcX5095V>@0608]W=`2<ISL0SFLh
08mV>02AIST0TVHi0P2EISX909=X>`03099]>@2AK3P0SfXf0080SVTe00<0SfXf091[=`2AK3P00`2C
JCL209AZ>0/0UF/i202CJ3/00`2AIST0TVLj09=X>`0209AY?00309=X>`2BIcX0TFHi0080S6Hg0`2;
ICH308YT=@P0R6@d0`2:Ibl308]X<080S6Ta00@0QV8^08QT<02:IS80SFTe0`2>JSH0102=JCD0T6/g
091[=`2@JcL2095/>0<0TVdi402?Jc/208YX>P@0RFLi0P28ISP2089V=00N089V=P21ICH0Of8f07aO
=@1iG3@0MeXb06UF:`1WE2X0He4Y05e=:@1IBBP0Dd@W04m19P1=?bD0BClT04Pn9@16?2<0@cPR040e
8@0n<b40?30P03/_7`0e;Q/0=BhL03<^6`0a;Qd0;bdN02`]7`0[:al0:R`O0P0Y;1/01P0X:Q`09bTL
02DW700T9Ad08b@N028S7@T082<J0P0N8AP201lR6@8082<J0P0Q91/2028U7P04024T7@0P8a`082<L
01lR6`807R4J0P0O8Ah201hP7@807AlL0P0L7Q/201hN7P0401lO7@0P8A`08B8L024R70808R<K01P0
9RPM02PX700]:a`0<bdM03Ta7P10=1h0ACHO04Lg7P1=?200BCPN04De6`15=ad0ASXR04Lk9@13>2@0
?c@P02`]9@0[:b<0:BTO02TW6`0[9a/0<2XL03@/7`0g<20203hb600403dc6P0j<aT0>C<K03Pc7@80
=S@O00H0<RhR034]8@0`;200;b/O02hZ7P0]:Ad202`X70P09bTN100U9a`402HX7@0502@W800S9Ql0
8bHO028U7P0P8a`00P0O8Q/901hQ6P0S01dR700L8A/06b0I01/Q5`0L8QH07R@F020V600R:AT07RDC
02@X6P0X:200:b<P02dP6P0h9QP0C3PO05]69`1jFbd0R6Xh091f>`2?MCP0SG<h08ec@028K4@0OV51
05M:=`18?BT0=B`K02TU6@0X:1h0:2/T02<Y9@0M9R<08bHO02@W800V:B800P0W:R<00`0V:B8092LP
02<V7`0202@W80<09BPQ100V:B8202LX8080:2TQ0P0Y:R8202X[8`0@02X_:00X;BH0:2/R02PZ7`0Y
:ah0;RlQ03@b8`0g=BH0>CDY03Lc9`0d<B80<c0Q03@a800g=240>SPS03dk9P80>CPT01@0>SPS03dh
8P10>R80A3dS04M09P1;@BH0B3`T04a0:01>@RX0C40X04Lk8`15>B40Ac/S04/o9`1<?280CCdS04hn
901??bD0D40V0592:080Dd<Y00H0DD0V05=29P1HA2T0G4LZ0619:P1QBRX206599`0=06a?9@1]D2H0
KE4Y06eD:`1/EB`0JU@]06QB;@1UDB`0GE<`05]A;P1JCB/0F4TX05I69@0205Q59@1A05U49@1QA280
HTDS06A79@1VBBL0J4/Y06Y=:`1[CR`0K4l]06=F;01TEbd0IUL^06UG;`1YERh0JU@]06MA:P1WCbT0
He0X06MA:P1YDb`0K5@^06eC;P1_Dbh0Ke4]06i@;01aER/0Ke@Y06aA9P1[D2D0K54V075F:`1fFc00
NUld07iT<`1mHc80Nf4`07YP;`1kHC00OV@c085W=P24JST0QF`d08I]=@28KcL0Rg8j08ed?02?MSh0
T7Lo095h@02DMSX0UWPl09Yj?@2POSl0XX100:B1?`2WPD00Yh8n0:V4?@2[QSl0[XU20;:=AP2fTDX0
^YE>0;bGD02nVE80^IA60;NAAP2cSdD0/8i70:n>B`2_T500/Y9E0;>EF@2WRED0YHMC0:22CP2JO4P0
U7I208i`?029JcL0QfTe0080RfTi04L0R6Pg08AU=P1oHc@0NV8d07UR=P1hHcP0MV<h07YJ=01iFC<0
N5H`07QE;@1jEB/0OEH[07iG;022FBd0PELW08QN;02?IC<0TFTe095Z<`2>JS00Sf/_095]<@2CL3X0
UG8j09Ue>`2OMc`0XGPj0:Eg>@2WMcL0YWHd0:Ak@`2SNd00XGTl0:1h>P2QNSL0Y7dh0:R2>`2[QC`0
]88i0;B4>P2fQSh0]hQ20;J9A@2dRDD0/HU40;68AP2ZQdL0ZHI60:R5A@2WQ4@0YH920:B1@@2SP400
XWlo0:1l?P2ONcl0Vg/n09Uk?`2HNd40U7]2099l@`2BOD@0QG=508Ec@`28M480RWA308]d@P2>M440
SWDo08md?`02091a@`0>08i_@@2=KT00Rf`n08UZ?028JC/0QfPj07mW>@21ISL0PVHg08EV=`29IcL0
SVXh099]>@2EKCX509=b?0<0TW4k00`0SG8k08aa?02=Kcd0Rf`m08YY?P29ISh0RV@o08US?`28J3l0
QfLn08IV?@25IC`208AT>`80QFDl00P0PFHk089W>P22IcP0PfTh08=Z=024Jc<0Q6``08E]<@80Q6di
0P22JcL03023K3P0Q6di08I_>`28LCd0Q7<k08Eb>P24LCL0Q70e08I`=P29LCD0S78e08ec=P@0Sg<d
102>LS<208aa>P0708Y_>028KCH0QV/d08AY<P23J340PVL`08EV>002085R=080OUla0P21HS@08P1n
Gc40NU/]07]P=@1hGC80LeL_06iB:P1ZCRL0JDdX06U<:P1ZCB/0JU8/06]C;@1]ERd0KUL]06iG:`1]
EbP0JeDV06YD8`1QC1d0HdhO06QB8`1]EBL0LeP[07MJ;P1kG300O5da07YL:P1kGB/0O5h/07eO;@1o
HBl0P68`085S<@22I38208AV<080QFLa00`0Q6H`089T;P20HR`0OV0Z07eT:`1lHbX0Nf8Z07UP:P1g
GBX0ME/X07EK:P1dFRT2079L:P03075K:@1`FRP0KeTW0080KUPV00`0KELU075G9P1bF2L0ME/Z07MM
;01kHC00OF<b081V=@21IcH0PVTa08=Z<P24Jc<208E/=00308A[<`22JC40PFP`0080QF/h01@0Q6Xg
08=Y=P22J3D0PFLd081V<`1oIC80PFLd081V<`1nI340OF<`07aR;`1mHc00OV@a07mU<P1fH2h0NF8`
07aU<`20ISD0PfLg08MX>@80R6Pi0100Q6Df089S=01kGc00MEX]06mG:`1/EB/0JUDZ06UC:P1YE2D0
J5<T06MB9@1VDBH0I4hU06==9P1RC2D0HD/V0`1OCBL205i<9P<0GD/U0P1FAah05P1DAAh0Dd<O0551
7`1??ah0CCdL04dl7P1<>ad0BS/N04Lh6`14=Q/0@3@J03le700m=Ah0?SHO03<^6P0b;AX0;b`K02`X
700W91/08B0K01/L5`0I6AL501PJ6@@05aTH400F61LX01DG5PP05AHH200E5aH801HH5`P05aTH400I
6aP801XJ60P071`J200K71H801/K6@807A`G0`0N7AP301lN6@<0820H100Q8AT2028R6P809B4H0`0V
8QT302LS6P0402PT6`0W8aX09b<J02LS6P809R8I0P0U8AP202PO6P0302LP6P0T7aT08b0I0080820H
00H07b0H01hN5P0O7aL07alG020P600R8QX202<S6`0302@T700W81P09b0H00<0:24I0`0Y8QX0200T
91X09BDK02LT6`0X91/0:b@L02`S700]91d0;R<M100b9QX203<W6`80=2PL100g:QX403P[6`80?B`L
0`0n;Ad303l^7P0304<a8`12<280@S0R0080@BlQ0P10;R00100o;Al0@34L044b7@12<ah204<d7`03
048c7P10<A`0?c0K0080@S8I00@0@c<J04@d6`16=Qd0AcLN0P18>1l204`d700304de7@1>=Qh0CcLO
0080D3PP0140DCTQ04hm7`1=?1h0CS/M04hi701@>1`0DSXN05Dk801F?240Dc`M05@m7P1G?R00FSlR
05do8`1N?b<0GcdR05hl8@0505`m7P<0Fc`M0P1M?R8305m0900605dn8P1K?200FS/O05dn7`1N?b00
H44R0P1Q@R<00`1O@240GSlP05`m7P0906529@80G3dN00@0GChO05m08@1P@B80HD8S0P1R@b@00`1S
@R<0I4<T06E49@0206I59P0306A3901R@B80HD0Q0080GD8U0P1L@B@305]08`0305Xo8P1M?R80GSlS
00<0Gd0T00<0GChR05`m8@1J>al0101L@R4405]18080Ed0Q00H0ESlP05Dn7`1D?Ah0E3dN05<l7@1B
>a`805Pj800505Dg7`1F>200ESPP05Li8@1H>R800P1I>b<00`1J?2@0F3XN05Li7@0205Pj7P0505Xl
801L?R80GT0T06129P1Q@2400P1R@B800`1S@R<0I4<T06E49@0206I59P0306I5901WARD0J4LV0080
J4LV00<0IdHU06E48`1T@b800P1UBB@306I:9@<0Id/V00H0KDXT06i;9@1_C2H0L4dW075>:01bCbT2
07=@:PP0ME8Z00P0LU8Y07IF;@1iFC00N5P_07AD:`1cDbX0MUH]07YJ<@80LUH_00X0LeD_07IF<01g
EC00N5@`07UE<@1kEC40NeP^07aI;`1nFc40P5dc0`21GS@01020GC<0Q64g08=P=P23H3H2089O=@80
PEhd00D0P5dc08AT?@22HS/0P60i07eM=P0507]K=00807QH<@1gEc00MUH_07AD;@1bDR/0L50Y06m?
:01^CRL206Q<900606M;8`1VBR80I4PP06=77`1RAQh0HDDM0P1O@BD0101N@2@0GClS05`n8P1K?B42
05Xl8080FcdQ00<0G3hR05do8`1M?b<00P1N@2@00`1O@BD0GSlS05ho8`0205m09080H44U0P1Q@RH0
1P1UA2<0IdHU06Y99P1^CRP0L50Y075A:P80LU8Y01P0MU8^07EA;@1eDR`0MU<[07QE:`1kFB`0OU`_
081N<01lFBl0OEX`07iK<@20GC<0PUle08=P=P25HSP0QV<i08YT=@2=IcP0SfTj08eW>029Hc@0Qf4b
08US=02<ISL208IL=00408AM=023GS@0Pehd085N=080P5ld1023GS44089M<00@07A?8P1cDB@0M58U
07=B9`1bDRT0KU4Y06]?:01YCBH0L50Y06m?:01^CRL0KDdV06i>9`1_CbP0LE4Z079B:`<0M54[0P1c
D2X3079?:@0@06Y<:01]C2T0KTdZ06m=:P1`C2X0L4TX06m69P1^ABD0L50Z06m?:@1^CRP0KDdW06i>
:01_CbT0LE4[07=C;@80Me8X00X0N5<Y07YE:`1kER`0OEP^07iI;`1oFS00NeHY07aG:P1oFRd0PE`_
0P22GC000`21G2l0P5/^08=N<@0808=N<@0308MR=@26HC@0QF0c0080Peha00<0Q5lb08IQ=027HSD0
0P29I3P00`2:ICT0RfHj08aW>`0208eX?00408iY?@2?ISX0SfHj08eW>P80S6Lj00H0RVPj08UY>P29
JCX0Sf/k08iZ>P2<J3P208]W=`0308aX>02>JSX0Sf/k00<0T6`l0`2?Jc/208iZ>P04095/>02?JSH0
SFPd08YU<@80R6<_1029I300102:IC40RfHb08]V<P2<Ic<208eX=0P0RF@g0P28HcH208MR=@<0QV4d
00@0QF0c08EP=P25H3H0QF0f:oooool002[ooooo202OM4430:1fA0<0WgE30P2NM48809me@`80Wg=2
0`2PM4<30:5eA0030:1g@`2QN4@0XWU50080XgY600H0XWU50:5hA02QN4@0WWA209me@`2QMdD20:=i
A`040:AjB02SNDL0XgU70:AkA`<0XgY60P2RNDD20:5hA0P0XgU70P2UMdH02P2RMTD0XGM509mgA02M
N4@0W7M309]g@`2KMDH0VWA509UcA02HLT<209Ma@P0309E_@02DKSl0U6ho0080TVhj0P2AKCT3091/
>00=08m[=`27Hc<0R6@d08UT=`2:ICT0RF@j08QR>`26H3/0QElj08=P>021GSH0Oe`d07eJ<P0207aI
<@0307eJ<P1nFc<0Ne@c0080N5@b00<0MU@a07AC<01aDbl00P1_Dbh00`1^D2`0KDl[06e?:`0506e?
:`<0JTd[0P1YC2X306Q;:@0606A<:01VC2T0J4h[06a?;@1^D2h0L4l^0P1`CBd0401eDBd0MU8^07MD
;P1hEBd0NEH/07]I;01lFRd0O5X/07eL<`1nGC80P5dc08=N<P25H3<0Qf4b08YR<@2;Hc8208eR=@<0
SV<f0`2?I3L8099W>P80T6Xk00@0SfTj08iX>@2=IcP0SFLh0P2<ISL208mT=`<0T6Dh0`2AIST808eW
>00308YT=`2;ICP0SFLj0080SVPk00<0SFLj08]U>02:I3L00`2@ICP208mT=`<0SV<f202AIST01P2<
J3P0SFLh08eW>02@IcT0TFHi099V>@80UFHj2@2BIcX00`2DKc/0TVdi091[=`0308iY=@0308mZ=P2@
JcL0TfTg0080TfTg0P2DJSP;09E[>@P0TfPk00<0T6Dh095V>@2CJ3/00P2DJC`00`2CJ3/0TFHi091U
>00208aV=`<0RfDf0`2:I3D808UU=@80RFH`0P2:Ic4308]X<P0608aY<`2:IS80RfLc08eY=@2>JSH0
Sf/g0P2>JSH0102=JCD0T6/g091[=`2@JcL2095/>0<0TVdi402?Jc/308YX>P80RFLi0`28ISP2089V
=00N089V=P21ICH0OV4e07]N=01hFc<0MUTa06QE:`1VDb/0HDlY05];:@1GARP0DT8X04m19`1=?RL0
B3hS04Lm9016?2<0A3TS048g8`10=B<0?c<S03hb8P0e;Q/0=BhL03<^6`0`;A`0;R`M02//7P0[:al0
:B/N0P0Y;1/0100X:Q`09RPK02DW700S91`2028S7@T082<J0P0N8AP01P0O8QT08B@K028U700S9Qd0
92LN02DX7`808RDN00@08B@M020S700P8a`07b8K0P0N8AX201lQ7P807R0M0P0M7a`201`N6`0601hN
7P0O7ad07alM020Q700Q8Q`08R<K0P0S9AX07P0X:1`0:BXL02l/7@0f;ad0>S8M044e7@17=ah0B3PN
04`k8@18>1h0ACDL04Df7`15>B<0A3TU03hf8@0j<Ql0:b`T02/[8@0Y:Al0:RPL02`X700a:ad0=BhN
03Pa8@0n<QP0?S8J03dc6P0j<Q/0>C<M03Lb7P80=C8O00H0<BdQ030/800`;200;b/O02hZ7P0]:Ad2
02`X70P09bTN200U9a`202<V7`03028U7P0Q91d082<L00807b8K2@0N8AX0800O8A`07R0K01hQ6P0N
8AP07b8G024U5`0R9QP092PI020R500T91P0:2@I02/S600c9AP0A38L05a7:P1_F3H0RFXn08ea@@2A
MSl0SWDl08Yd>`25Kd00NF4o06YB=P18@2d0?SDT030Z700Y9aX0:2TQ02P[900R:2@072DR0P0T9b04
02HY8P<092LP0`0U:24202HY8P<09bXS0P0W:20202PY8@80:BXR0P0Z:b<0A@0Y;RL0:2dV02P[8P0Y
:b00:R`O02l`8P0d<R<0=cDV03hh;00l=RP0>cDW03Xd900k=R<0?STU044l9P13?RP0?C`X03`k9`0m
>bH0@3/U04<m9@17@2H0BD8X04e3:01:?RH0CD4Y04i2:P1=@BT0BShV04Pl901:?RH0C40X04`l8P1=
?B<0CShT04lo9@1A@BL0DT8X05=3:@1DA2X0DT4U05I29`1IARP0GTTZ06=<;01UCB/0Idd/06M=:P1a
E2X0L5@/075E;@1_ERh0KED_06]E<01VDRl0IE4^05a?;@1JCB/0FT/Z05U9:01HB2L0FTLW05]69`1L
AbP0ITTW06M::01XBbT0JD`Z06Y=:`0306]>;080HU@]00`0I5D^06ID;P1WDbh0J58]06I@:`1WCb/0
IDlX06I@:@1YDB/0K58]06mC;P1`DRh2075@;@@0KU4W0200L5<Y07=F;01fFBl0N5/a07]Q<01lHS40
OF<b07mU=021IcH0PVPg08AZ>@25JcX0Qfhf08Q_=`2;LSX0SG@l08ie?@2=M3`0Rg8j08Ya>@2?LCD0
TW@h09Mg>P2NO3d0Xh510:J3@@2ZQ4<0ZXE10:j<A@2aSdP0]I=<0;VGD080^iUB00P0^YQA0;VGD02e
TDL0]I570;:@B@2`Sd`0[he=0:b<C`80ZX]B00P0WGm=09]mB`2GNDL0TWA208a^?027JCL0PfDc085S
<@80QfLf00L0QFDd089S=01mHC80NUlb07MO<`1gGSD0Mf0f0080NeTc03H0NeP`07eH;P1nFBd0P5X]
08=J;024Fbd0Q5XX08YP;P2AJ3@0U6/e09A[<`2CJc00UFdb09Q`<`2FKc@0Ug0e09]c=P2OMSP0XgLh
0:Ii>02VNCH0Z7Pf0:Em@02TO3h0XWXl0:9k>P2TOCX0Z84l0:^5?P2^R440]XPj0;J;?02gS3h0^8i2
0;N@A@2eSdH0/hm50;>>A`2ZR4/0ZHM:0:N5B02TPTD0XX130:1n@@2OOD00WW`o09QmAP2FNd@0TWU3
08ef@P2:M480RWI408]fA`2;NDT2089/A@0<08=/@`25K4<0Qfa108U/@02;K400Rf`n08a]?P2;K3d0
RV/l08UZ>`27J3T0QVLh0P25ISL02@23IcP0PVHg08=T=@24I3<0QVDb08YV<P2=J3@0SfXe08]Z=002
08a[=@0=08e/=P2?KSP0T6li091_>@2AL3X0S74l08e_>`2<KS`0S6`m08aZ?@2=J3h0SFHm08aU?P02
08AU>@80QFHj00@0Q6Di08=T>022HcL0PV<g0P1oHc@01`20I3@0PFDc085V<@22Ic00PfPa08=Y<020
I3`00P1oHc/03@1nHSX0Of<k081T?021ICd0PVHn081/>@20K3L0P6/f085Z=025K3@0R6he08e`=P2>
LCL00P29Kc@00`2:L3D0Rg4f08ab=`0208ec>00708id>@2<LCX0S74j08Y_>028KCH0QV/d08AY<P02
089W<00G08=T=@1oH340Of0a07aM;P1mGRl0P64b085R<`1nGc00NU//07UN<@1hGC00MEX_079F;P1_
Db`0K50[06U=:01XBbT0JU8^06]C;@1]EBl0KeP_06mH;P1`FBd00P1_FBX03P1PBa`0HdhO06YD9@1a
FB/0MU/^07MJ;P1hFBd0MeP/07YL:P1kGB/0O5h/07eO;@1nH2h0P68`0P21Hc4408MY<`0908EW<@24
IS00PV@^085S;@1oIBX0OF<X07YP9`1hGBH0MU/V0080MUXX00<0MUXZ079L:P1bG2X00P1aFbT03`1`
FRP0KeTW06iH9P1^F2H0LUPW07=I:01eFbX0N5h]07]Q<01mHc80OfDd081V=@22JC40PfXb08E/=002
08I]=@0308E/=023JS80PVTa0080QV`i0P25JcP01`24JSL0PfTf089X=@22J3D0PfTf089X=@20IS<0
0`1nI3400`1oIC80P6Hc07YT<P0207YS<@0=07eS<P20I3@0QFHg08QX>@2:JS/0R6Xh08EW=@1oHc<0
NEh_079J;01]ERX0JUDZ06UD:@0206UD9@0706QC9P1VDBH0IDlV06A>9`1SCBH0HT`W061>:00305m=
9`80GT`V0P1MBbD03P1EAQd0E4DL05=47@1A@Ad0CclM04dm701<?1/0BcXL04dl7P1:>ah0AcPK04@f
6`11=A/0?cDL0P0n=Ql0200e;aT0=BhK038]6P0^:a`0:BLK02<S6`0N7AP06a`G100I6aX201PJ6@80
5aTH4@0F61LX01DG5PP05AHH200E5aH801HH5`P05aTH400I6aP801XJ60P071`J200K71H801/K6@80
7A`G0`0N7AP301lN6@<0820H100Q8AT2028R6P809B4H0`0V8QT302LS6P<0:2@K0P0W8aX302HR6@80
:B0K00<0:24K02DP6P0T8AX00P0Q8AT01P0P8AT07alG01lO5`0P81P08B4I028R6P808b<K00<092@L
02LP600W81P00`0X8AT302TR6P809R<J00<09b<J02XS6`0[8Q/00P0]8Q`0100_8Q`0<RHJ038V6P0b
9QX203<W6`<0=2PL0P0i;1`303P[6`<0=bXJ00@0?B`L03h]7@0n;Ad0?RdM0P0o;Qh2040_7`80@c8R
0P12<B44044`8003048b6`13<a`0A3@M0080ACDN00<0A3@M04<c7012<Q/00P15<a/01016=1`0AcDM
04Le7@18=Qh204Tg7`0604`d701==Ad0CCDM04hf7P1?=al0D3PP0P1A>B40401>?Al0Cc`N04hk7@1>
>A`0DCTM05<i7P1F>b00Ec`Q05@m7P1E?Ql0EchP05Xo8P1M?b<0GSlS060n8`1O?B8805ho8080GSlS
0`1O@2@01P1M?R80G3dQ05/l801N?b00Gd0Q06118P80HD8S00<0H44R05m08@1N?b002@1R@b@01@1O
@240H44R06118P1Q@R<0HT<T0080Hd@U00L0I4DV06A3901UA2D0ID@U06I59P1UA2D0I4<T0080HT4R
00@0H48V05m19@1O@BD0Gd4U0P1N@2@205do8`80GSlS0`1P@BD00`1N?b<0G3dQ05/l800805i18@80
FD0R00@0F3lQ05Ln801F?Al0ESdO0P1E?1h@05Pj800405Pj7P1I>al0FcdQ05do8`@0Gd4U00H0H3lP
06508@1Q@240HT4R06=28`1T@b@206E49@0906=28@1T@b80ITDT06M69@1XAbH0IdHU06I5901UA2<0
ITPT00<0IdTU0P1XBRH206U;9`0606i;9@1_C2H0Kd`V071=9`1aCRP0LTlY0P1cD2X807IC:`0=07=C
:P1fERd0N5P_07QH;`1fERd0MED/07MG;P1jFS40METa07AH<01eF300MeL`07ME;`0207QE;`0507YD
;`1iER`0NUL]07eJ<020GC<01022GcD208AQ=`80Pf0f1022GcD01024I3/0Pf<j085Q>01oGcH507eM
=00@07YJ<@1iFC00N5P_07IF;@1dE2/0LU8Y075A:01`D2L0K4lW06]>9P1ZCBD0JD`T06M:8P1VBB40
IDPP06A77`80HT@X00H0H48V05m19@1M?b<0FcdQ05Xl801I>al205do8`0405i0901O@BD0H48V0653
9`80HdDY0P1N?b<205m09080H44U0P1Q@RH01@1S@R<0ID@U06Q79P1[BRL0KThX0080KdlX00T0KdlV
07EA;@1eDBd0ME8/07MD;01hEB/0NeT/07eK;P1oGBl00P1mFS003P1oG380P5dc089O=@24HCL0QF8h
08IS>@2:I3D0S6Hg08iX>@2=IcP0RV@e08US=02:I3D0S6Hg0P26G3@01024GC@0Pehd08=N=021GS@2
081O=080QF0c00@0Q5lb08=N<@22GC00PUd`0P21G2l0201fDB@0ME<V07ID9`1eE2T0Le<Z06mB:P1/
D2T0JThW0P1`D2T306i>9`03071@:@1bDR/0Le</0080ME8/0P1dDB/307=@:P09079?:@1[CBT0KTdZ
06m>:`1aCb`0LDd[079;:P1aB2P0L4LW00@0KdlX00@0LE4Z07=C;01eEBh0MUH_0P1iE2X02@1jEB/0
O5L]07eH;P1nFBl0OeX`081K<@1mF2/0OUT/081K;P02089M<00308=N<@22GC00PUd`00T0QF0c00<0
R6<f08MR=@25H3<00P24Gc801025H3<0Qf8e08QS=P28HcH208UT=`0308YU>02;IST0S6Lj0080SFPk
0P2@Ic/0102>J3/0SFPk08eX>`2;JC/208YZ>`0308m[>`2>JSX0SFTi00<0SFTi00<0SVXj08m[>`2:
ISH00`2;IcL408aX>005095/>02?JSH0SFPd08]V<P2:IC400P29I3000`2:IC40RfHb08]V<P0408]V
<P80S6Lc202:ICP208UT=`80R6<f0`27HSD01026HC@0QV4g08IQ=`26HCL[ooooo`00:_ooool809md
@@<0X7I40`2OMD<209id@PP0WgE30P2NM48309me@`<0X7I400<0X7M30:5hA02QN4@01@2RNDD01P2O
Ld80X7A30:5eA02SMdH0Y7Q70:EiB080YWY90P2TNdL30:=jAP<0XWU5202TNTP01@2VN4L0YGM60:=g
AP2QMdD0WgM40080W7M300D0VWI209YdA@2JM4D0VG=409Qb@`0209Ma@P0309I`@@2EKd00U6ho0080
Tfdl0P2BK3/0402AJcX0T6Xi091Z>@2?JCP0Qf<c08QT=029I3L0RVDi08YU>`29Hc`0Qf4l08IP>`24
HCT0PUlg081M=@1nFc<207eJ<P0807iK<`1oG3@0O5Dd07UE<`1hE380MU@a07AC<01`DRh206iB;@80
K4hZ0`1]Cb/306i@;080Jdh/0P1ZCB/206U<:P80J4/Y00H0IThZ06Q>:`1YCb`0K4l]06i@;P1`Cbh2
079?;`80MU8^00`0Me@^07UF;P1jEbd0O5X]07eK;P1mFbd0OUdd07iM<P20GC<0Q5lc08EP<`28HS<2
08]S<P80S64d0`2=HSD308iS=PP0TfPk0P2@JS/01P2?JCX0SFLh08aV=`2;ICH0RV@e08US=080SV<f
00<0Sf@g091U>02AIST00P2BIcX00`2CJ3/0S6Hg08aV=`0608aV=`0308YT=`2;ICP0SFLj0080SVPk
00<0SFLj08]U>02:I3L00`2@ICP208mT=`<0SV<f102@ICP4095V>@0608eY>@2>J3T0SVPi091W>@2A
IST0TVHi0P2EISX9099W>P0509A_>`2CKSX0TF`h08iY=@2=J3@00P2>JCD0102?JSH0TfTg09=Y=`2C
JCL209AZ>0<0UF/i202DJSP809=X>`03091U>02AIST0TVLj0080U6Tl00<0TVLj095V>@2@ICP00P2<
ISL308]U=P<0RV@e202:ISH308UU<@80RVHb0`2;Ic<01@2=JCD0SVXf08iZ=P2>JSH0Sf/g00<0SVXf
0`2@JcL2095/>0<0TVdi402@K3`208]Y>`0408YX>P29IcT0RFLi08QV>080QfDg0P22IS@05021ICD0
P6@e07eP=01jGC<0MUTa07AG;`1VDb/0I50[05m=:@1HB2L0E4<W05109P1>?bP0CChY04Lm8P17?B@0
AS`S04@i8`13>2@0@CHT0P10=2@0400e;Q/0=2dK03<^6`0`;A`0;R`M02//7P0Z:Qh0:B/N02T/6`0X
:aX09bTK02HX6`0T9Q/08b@L028S7@0Q8Q`9020S6P0601hQ600O8QT082<J028U700T9ah09BPO0P0W
:R42028U7P04024T7@0P8a`082<L01lR6`807R4J0P0O8Ah201hP7@807AlL0P0L7Q/01P0O7ad07b0K
020Q700Q8Q`08R<K02@V6`809BLJ0140:bTL02d[700b;1`0=c0M03hc7@14=Q`0BCPN04Xi7@1:>R40
ASPN04@e7P12=R00@cPT040h9@0k=240=RlM02X/8@0202XZ7P0>02`Z7@0^:a`0<bdM03L`7P0i<R00
?c<K03hb6P0m<Q`0>S8M03Pa7P0f<Ah0=34P03<`7`0`;20202l[7`80;RXN0P0]:Ad00`0/:1`09bTN
02LY7P0602LY7P809BLL100T9Q/202<U6P808RDN0P0Q91d0100P8a`07b8K01lR6`0O8Q/801hQ6P80
824L01h0824K024R6P0R91T08bDH02@V6@0U9aT08R8F02HT5`0/91L0<RLE03l_601F@B@0L5Pd089Y
@@2BLTT0TGE6095h@P2?N480RWI307UW?`1QD3@0CS`X03Tc9@0b;R80:bTM02LW7@0X:B40:2/T028W
8@0M8al;02DX8@809RTR100W:R<202LX8080:2TQ0P0Y:R8202X[8`0802T^9`0X;BH0:B`S02X/8@0/
;R40;c0R03@b8`0f=2D2040h:`0>040i:@11>RP0@S/X04@n:016@2P0Ad4Y040o:`0o?RX0@3hY048m
9`15?bL0B44W04]4:P1?ABX204e1:@0304i2:P1=@BT0C40X0080C40X00L0CD4Y04dm8`1=?B<0CShT
05109P1A@BL0Dd<Y0080E4@Z0180ED8T05Q39P1LAbP0HT/[06I>;01YCb`0K4l]06a@:`1cEbl0LEP_
075H<01`F380KELb06UE<P1UDS40He0_05Q;:@1IBRT205Y::@0<05a9:@1MB2T0H4TZ0619:P1XCR/0
JDl/06Y@;@1[DBh0JU0]06U?;01XCR/0IddZ0P1PDRd02`1QDBd0He4]06A@;@1VCbd0IDh/06I>;01T
C2H0IThX06U?:P1^DRd0L58^0080LU4^00L0LU0]06i>9@1_CbH0LE4X07AD:`1fERd0N5P_0080NET`
00D0NV0_07eS<P20ISD0Q6Xi08I/>`0208M]?00408I/>`29L3X0Rg8l08ed?P80SWDo00h0Rg8l08Q_
>@25K3H0S6hb08ma=@2FMST0WW`m0:B2@P2YQT@0[HM60:j9A@2^SDP0/8m:0;FDC`80^9MB01<0]YE@
0;:AC02_STT0/Ha50;2>A`2_ST/0[he=0:^;CP2VQdh0XXE=09n1B`2EMTL0U7E6091a@P2<KCh0R6Tj
08AU=P21HS<0Of0a0080QFDd00D0Pf<b07mP<@1lGBl0NU/_07QK<@0207QK<`0H07aK<01nFc40P5/_
085L;`23GBh0QUh]08QN;P29Gbd0Qel[08aT<02DJcD0Ufhf09Q^=02JKC80WG0e0:1d=`2JLC40Vg8`
09mc<P2RMSD0Y7Pg0:Mj=`2YO3T0ZWdj0P2ZPd00502YPSl0ZX<n0:b5@02_R4<0/Xa50;B>A`2eSch0
]I0o0;NB@P2gTdD0]IA50;>CAP2`TdL0[i960:J7D02TQDh0XH9;09ioB02KO4D0VGY30P2HND80202B
O4/0SWY808UdA@24Kd80PVe2085^A024LDL0QW=;0P20ITD00`22ID<0PfE108EU?`0208IT?P0308MT
?028J3L0R6Pg0080QfLf00`0QVHe08EU=024I3<0Q6@c08MU=`26I3H0QF<c08AS<027Hbl0R6D_08UV
<02;J30208a[=@80SF`f102>KCL0202=Kc/0S6hj08e]?02>K3`0Sf/k091Z?@2BJCd0TFPl0P27IcP0
1P28J3T0RFTj08QX>@27IcP0QFDf08AT=@80P64b00@0P68`085S<@21Hc40PF<_0P22I30207YM>`<0
NE`j0P1jGC/06P1kGS`0NfDf07YT<`1lI3@0OfDd089V=027JCD0RV`f08e^>023JS40Q6/b08E/<`27
KSD0RG0g08Ya>02;LST0S7<j08]`>@2:KcP0RFhg08M/=@26Jc@0Q6Tb08=X<@22Ic00PV@b0P1oHBl0
1P1lGR`0OEl]081R<021Hc40OV0^07]M:`80Me`]00`0Me`_07IK<01cEbl0KU8[06Y>9`1XC2L0Idl]
06Q@;01YDBd0Je<]06eF;@1^Ebd206mH;00606E@8@1WDR<0JeDV06iF:01bEbX0MEP/0P1gF2`207YL
:P0707]M:`1mGbd0OV0^07mQ;`20HS00PF<a08MX<P0308IW<@0408EV<024IBl0Pf@^089S;@80PVDY
00H0PVD[089U;@20HR`0OEl[07YL:P1hFRP207=M:`04079L:P1aFbT0L5XX06mI9`80KUPV0100LeTX
07AJ:@1fG2/0N5h]07]Q<01mHc80OfDd081V=@22JC40PfXb08E/=026KCD0Qfhf08I]=@25K3@0Q6/c
0P27KCX208I/>@80QF/h0`24JSL00`23JCH0PFLd07mU<P0207mU<P0B081V<`21Ic@0OFLe07aU<`1i
HS00NV0_07eQ<@23I3D0R6Pi08a/?@2;KCT0RF/i08=W=@1mHc80MUh^071J:`1/EbX0JUDX0P1ZEBH0
1P1YE2L0Ie8W06I@9`1TCRL0HddV06==:080H4hX0`1OCBL305i<9P0705M87`1FAah0EDHO05=37`1A
@Al0CclN04hn7@0204dl7P0?04Xk7P18>A`0A3HK044e6`10=Qd0?SHO03lg800h<1T0=blJ03D^6`0b
;1`0;BTM02LT6`0S81T07ahI00806Q`K0`0I6aX00`0H6QT05aTH01LI600A01HH5bP05ALF200E5QP8
01DG5PP05QPG200G6AP@01TK60P06a/I200L71X801`M5`P071`J0P0M71L301hM60<07ahI0`0P81P4
024Q6@808R8J0P0U8AP302HR6@<09b<J0`0X91/302LS6P809R8I0P0Z8A`00`0X8A/09R4K02DR6`02
028R6P03024R6P0P81P0820H00808B4I00@08R8J02<S6`0S8a/08b<K0P0W81P302PQ6@<0:B8J0P0W
8aX0100Y8QX0:R4J02`Q6`0/8A/202lR7080<RHJ0P0c9a/203@X7080=BTM00D0>RdM03T/700i;1`0
>B`L03P[6`0303LZ6P<0?RdM0P0o;Qh3040_7`@0@c8P1012<Al02013<AT0A38J04Hd7017=Ad0B3HN
04Le7@16=1`0AC<K1@1:=Qh304/g7`80CCDM00@0CSHN04lg7`1?=al0D3PP0P1A>B403P1@?Al0D3/N
04lj7@1A>Ad0DSPM05Dj7`1I>b40FS`R05Dn7`1F?b00F3lQ05Xo8P1M?b<0GSlS0P1Q?b@406118P@0
HD8S101O@2@0101N?b<0GChR05dn8P1L?B4205m08@0306118P1Q@R<0HD8S00<0HD8S2@1TAR@506=4
9@<0I4DV101UA2D0101T@b@0Hd8S06=28`1R@B8406139@80Gd8T0P1N@B<00`1N?b80Gd0S06119002
06529@0405m08`1M?R40G3dP05e080@0GT4Q0`1O@R801P1L@B<0Fd0R05]08P1J?b40FChP05Pm7`80
Ec`N201H>R0305Xl8080FC/O0`1H>Qh0201I>al0FcdQ05i0901Q@bL0HT@X06539`1P@RH0GT0T0P1P
?b0206508@0906918P1S@R<0I4<T06A3901Q@1l0Hd8Q06E48`1WARD0J4LV0080IdHU00@0ITDT06U8
9@1YB2D0JDPU0P1ZBBH306]:9`0306m<9P1`CBL0L4dW0080LDhX0P1bCbT00`1cD2X0MU<[07IC:`06
07IC:`0=07EE;01fERd0MeL^07QH;`1gEbh0N5P_07UI<01jFS40Me`a07IK<01gFS00N5P_07QG;P02
07QE;@0607UC;01gE2X0NEH/07aI;`20GC<0PUle0`23H3H408AQ=`@0Pf0f0P24HcP00`23HSL0PV4f
085P=@03085P=@09081O=01mGS80O5da07]L<01iFRh0MeP/07EF:P1dEBT0Le@X0080L50Y00@0KdlX
06e=9P1/C2D0JTXS0P1YBB80201UB2X0I4LY06959`1P@bD0GT4S05`o8@1J?Al0FC`N0`1L?R801@1M
?b<0GT0T06129P1SABT0I4HZ0080GSlS0P1O@2@206119@80HD8V01d0HT0T06A29P1WARL0JTTX06a;
:01]CBL0KDdV06a<9@1dD2`0ME4]07IC;@1gE2`0NEH/07]I;01mFbh0OU`^07eJ<01nFc40P5dc085N
=023H3H0QF8h08IS>@27I3X0RV@e08aV=`2=IcP0SVPi08eW>00308]U=P80Qede00@0QEhe08AO=@24
GcD0PUle0P21H3D01P27HSD0QV4d08EP<`24Gc80Peha085L;`80P5/^0100NE@W07ME:01hERT0MeH[
07AD:`1`Db/0KE4Z06]?:01aDBX0L50Y06m?:01^CRL0KdlX071@:@1bDR/0Le</0P1fDbd207EB;0<0
M54[00T0Le0Z06a>:01_CbT0L50Z079@:`1cCb/0M4hZ07=;:01bBRL00P1aD2L01P1bDBP0M5<Z07IE
;01hEbh0NEP_07YI<080O5L[00@0OEP/07iI;@1oFRh0P5/_0P21G3000`20Fbh0PE`_089M<00208=N
<@<0Q5lb2@27HSD00`28HcH0Qf8e08IQ=00208EP<`0308MR=@28HcH0RF@g0080RFDe0P2:ISH0102;
IcL0S6Ph08eY>@2=JCT2095X?00408mY?02>JC`0SVTl08aZ?080Rf/l00<0T6`l08m[>`2?Jc/0102?
Jc/01@2@K3`0RVHf08YV=P2;IcL0S6Ph0080SFTi0P2>JSX01@2@JST0SfTh08iX=`2=IcH0S6He0080
RfDd00<0RV@c08eW=P2=IcH00`2<ISD308]U=0P0RfHi0`2:ICP208UT=`<0R6<f0`27HSP[ooooo`00
:_ooool809md@@<0X7I40`2OMD<209id@PP0WgE30P2MMD8309if@`<0WgM4102QN4@20:9iA@0:0:=j
AP2TNdL0XWA30:9d@`2SMD@0Y7I50:EgAP2WNDP0Z7Y90:UkBP<0Y7]70`2SNTH20:9iA@P0Y7Y80P2V
N4L01P2SMdH0XGM509mgA02LMd<0VgI209Yf@P80VG=40P2HLT<209Ma@P80UW1100L0UFm009I]?`2E
K3h0U6/m09=Z?02BJC/0TFPj0080T6Li00`0Qf<c08QT=02:ICP0RfHj08]V?029Hc`0R68m08MQ?024
HCT0PUlg081M=@1nFc<207eJ<P0:07iK<`1oG3@0O5Dd07YF=01iEC<0MU@a07=B;`1`DRh0KU8]06eA
;080K4hZ0`1]Cb/306i@;0<0Jdh/0P1ZCB/306U<:P0806Q@;01YCb`0JDl/06a?;@1^D2h0LE0_07=@
<01dDC4207MC;`0>07QE;`1jEbl0NeP^07eK;P1nG2l0OU`^07iM=01oGS<0PEhd08AO<`26HC@0R68c
08]S<P2<I3<208aQ=0<0SF8e0`2>HcH809=X>`80T6Xk00H0SfTj08eW>02<ISL0RfDf08YT=@29Hc@2
08iS=P0308mT=`2@ICP0TFHi0080TVLj00<0TfPk08aV=`2<ISL01P2<ISL00`2:I3L0RfDh08eW>P02
08iX>`0308eW>P2;ICP0RV@g00<0T6Dh0P2?I3L408iS=P80Sf@g0P2@ICP2095V>@07099W>P2>JSX0
SfTj08mY>P2AJ3X0TVLj09=W>P0209AU>@T0TFHi00<0Tfhj099]>@2@JcL00`2>JCD00`2?JSH0T6/g
09=Y=`0209=Y=`80U6Xh0`2EJcT809AZ>0P0TfPk00<0Sf@g095V>@2BIcX00P2CJ3/00`2BIcX0TFHi
08mT=`0208aV=`<0RfDf0`2:I3D808YV=P80R6@b0P29IC<208YV=080RfLe1`2>JSH0102?JcL0T6/g
091[=`2@JcL2095/>0<0TVdi402@K3`01@2<JS`0RfTk08]Y>`2:J3X0R6Hh0080QfDg00l0QV@f089V
=022IS@0PFDe07mS=01lGc<0N5/a07EH<01bEBd0I50[069>:@1LBBP0ED@V05919`1??bH00P1=?RT0
4017?B80AS`S04Dk8P14>B<0@SLS044f9010=2@0?c<S03@]6P0d;A/0<RdJ02l/6`0]:a`0:R/M02XZ
7P0X:Qd202P[6P0402LY6`0U9aX092HK028S6`808B8L2@0P8aX201lR6@06024T6`0R9A`092LN02HY
800W:R40:2/R0P0R9Ah0100Q91d082<L020S700O8Q/201hQ6P807b4N0P0N81d201dO708071hK02P0
7b0K01lP6P0P8A/08R<K02@V6`0U9aX09RPJ02LY6`0]:a`0;b`K03D^700i<A`0@3@L04Lg7@1:>Ad0
CS/M04Tj8`14>200@SHP044f8P10>2D0?CHS03Ha7P0a:a/0:2XM02TZ700Z:ad0;B/L030]700e<1d0
>C8O03/d8@0o<ad0?S8L03db7P0j<Ql0=c0N03D_7`0c<240<RlP100^:Qh402dY7@P09bTN00<09BLL
02@V6`0T9Q/00P0S9AX2028T6@03024S600Q91d082<L00<082<L0`0O8Q/801hQ6P80824L01X08R<M
02<T700T9Q/092HI02DW6P0U9aT09b<J02`V6P0c:aP0@38G054n7@1YDB/0PFDm091cB@2BLT/0T7=7
08mhAP2?NdP0QGA806]L>`1:?RP0=RXL02`/8P0Y:Al09RPM02HW7`809bXS00<08bPR020U7`0U:240
2@0U:24202HY8P809bXS0`0X:b@202LX8080:2TQ0P0Y:R8202X[8`80:2dV00`0:RdT02`^8`0];b80
<34S03@b8`0f=2D0@3LX048i:P13>RT0ACdZ04Lo:P18@2T204Q19`80@3l[00X0@3hY048m9`15?bL0
B44W04Y3:@1>A2T0CT8Z04e1:@1<@2P0CD4Y0`1>@RX07`1=@BT0CCdS04hn901??bD0D40V0592:01C
@bT0E4@Z05E5:`1G@R<0Fd@U05m8:01TC2X0JDl/06e@;P1_DBd0Ke4[075H<01`FC00L5Pb06iH<`1Z
ES<0IU<b065A<01PD2l0EdPW05U9:01JBRT0GDXZ05m::`1QBR/00P1RBB/0201WCb/0J50/06YB;P1Z
DRh0JE4]06M?:`1UCBT0I4`X0P1MCb`02`1NCR`0H4d/065=;01SC2`0I4d]06E<;@1TBRD0IT`W06Y>
:@1^D2`0LU4^0080Le4^00L0Ldl]06m>9@1aD2L0M5<Z07MF;@1jFC00NeXa0080O5/b00@0O68a07mU
=024JST0R6hm0P2:L3l0:P29Kch0R6hm08Y`?@2;LCh0S78o08ec@02<LSl0RW0m08M]>P25JcP0SFlc
091b=P2GMcX0Wgdn0:F3@`2ZQdD0[hU80;2;A`2`Sd`0/Y5>0;FDD@2gUU<0]YEB0;:ACP2]S4T0ZXU6
0:Z7@`2ZRDH0ZhU90:R8B`2UQTd0Wh5;09QmB02ENDL0T75308m`@P2<KCl0RFXl08IW>@23I3H0PF8d
081Q<`80PV@b0200PF<a07iO<01lFbh0NUT^07UH;`1iEc40NePb07iL;P21G2l0Pel_08IP;`2:HRl0
S6<_08iS<02>Hbh0RF@]091Y<P2GKSH0Vg4g09e`=@2OLCD0YG@i0:Yh>`2UMS00YWLa0:Ei<P2WNSH0
ZG`h0:Yo>P2/PCd0[H8n0;>=A080/Xa50180/he60;F?B02gT4/0^Y=>0;^DC`2dTd@0]IA70;BDA`2b
UDT0/9A:0:fCB@2[T4T0Yhm709n3D@2MPDl0VGe;09EiA`2BMT@3095e@`0=08ehB@29M4D0Q6m2081[
@01oJ3l0P6Q208=[A@26K4T0PVA2085S@@23HSl0Q68m08ER?00208MQ>P0308QQ>027IS<0QfHc00H0
QVDb01P0S6Hg08]U=P2:I3<0R6<_08MT;P28IBl0RVL_08]X;P2DLcd0Tg8l099a>`2AL3X0Sfhh08i]
=`2=K3H0S6/e08a/>`2=KC`0SV`l091/>P2BK3/0U6`k09E[>`2FK3X508e/>@0308a[>02;JSL0RfXg
00<0Pf<`0P22HS400`21HC00PF4b085Q<P0607QJ>080MeTg0100MUdd07IN<P1hGC00Nehb07mP<P23
Hc@0QfLf08YX>01mIS00OVLa07mX<P21JS@0Pf`f08E^>026KcT0Qg0j0P28KCH01027K3D0QV/d08I[
=025JS<208AY<P0W08AV<P20HRh0P68^07eO:`1nH2`0PF<_089T<01oHBd0NedY07MM;01hGRd0NEh_
07QM<01eFRl0LED]06a@:01YCBH0HTTZ06=;:@1TC2P0IThZ06Q@:P1ZDbX0Je@Z06eF;01_FR/0K5LX
06YD9@1YDB<0Je0S071C9`1gF2`0NU/_07UK:@1jG2X0Ned[07aN;01mGbd0Of4_0080P68`0P24Hbh3
08=R;@<0Q6<^00P0QVPZ08U[;@2>L3@0Sg0g08a]=P25IS00OEdZ07MG9080Led[00@0LU`Z075K:@1a
FbT0L5XX0P1_FBL207EK:P0<07MM;01iGbh0Nf4`07eS<P1oIC@0P6He089Y<@24Jc<0QVde08M^=P28
KcL0Qfhf0P26KCD208M]>P@0QV`i0P25JcP00`24JSL0PfTf085W=00307mU<P0B081V<`21Ic@0OVPf
07aU<`1iHS00NEl^07]O;`21HS<0R6Pi08][?02>L3X0S6hj08M/=`21Ic@0NV<a07AN;@1_FR/0KEPY
0P1[ERL01P1ZEBP0J5<X06MA:01UCbP0I4hW06A>:@<0H4hX0`1OCBL205i<9P80Fd`S00`0FDXS05M7
8`1FAR@0E4@S05928@1B@B<0CC`N04/l7`18>A`0ACLL044e6`10=Qd203lg800:03/a600k<1X0>30M
03D^700a:ad0:bLL02LS6P0T8AX071hM01/M70806Q`K00<06A/J01PJ6@0G6AP04P0F61LX01DG5PP0
5AHH200E5aH801HH5`P05aTH400I6aP801/K6@P071`J200L7AL801`L6P807A`G0`0N7AP301lN6@<0
820H100Q8AT2028R6P809B4H0`0V8QT302LS6P80:BDL0`0X91/302LS6P80:b8M00<0:B8L02LR700U
8Q/00P0S8a/00`0R8a/08B4I028R6P03028R6P<08b<K0P0W81P302PQ6@@0:B8J00D0:R<K02/R6`0[
8Q/0;B8L02lR7002034R7@<0<bLK0P0d:1`303DY7@D0>B`L0`0h:a/203h]7@80?bhN0P10;al2044`
80@0@c8N1014<al00`14<aT0AC@J04Lf700304Th7P0304Pg7@17=Q`0CCLP00@0CCLP0`1<=Ql204de
7@0404hf7P1?=al0D3PP054i8@80DSXR00P0DSdP05<k7`1B>Qh0DSPM05@i7P1G>Al0FSXQ05/k8P80
ESlP00L0F3lQ05Tn8@1L?R80GSlS064o901R@2D0H44R0080HD8S0P1R@b@206=49@0406A59P1P@BD0
H44U05m090D0GSlS101P@B80101Q@R<0HT<T06=49@1SA2D906E79@<0IDHW1@1TABH0101VABH0ID@U
06E49@1T@b@406=28`<0HT<T0`1Q@R<206118P0305m08@1P@B80HD8S0080HT<T00<0H44R05ho801M
?Ql00P1N?b0205m08@0406118P1Q@R<0HD8S06528`80Gd8R00<0GT4Q05e0801L?al00P1K?Qh00`1J
?Ad0F3XP05Pj800605Pj80<0FchP0P1J?Al305Tl7P0805/m8@1M?b<0H48V0694:01SABT0HT@X0612
9P1O@BD2060o800306508@1R@B80Hd8S0080I4<T00H0ID@U0691801T@b80ITDT06Q79P1YB2L206Q7
9P0306M69@1ZB2D0JTPU0080JdTV0P1/BRL206e;:0@0LDhX101bCbT807MD;0<0MUH]00<0MeL^07UI
<01kFc800P1kFc801@1hGC00Me`_07QK;`1iFRh0NEP]0080NEH/00H0NUD[07MD:P1iER`0O5T_081M
<`22GcD308=P=P@0Q64g1025HSP308ES=P0408IT=`25HcH0QF<f08ES=P80Q68e00P0P64c07mP<P1m
GS00O5d_07YK;@1hFB/0MePZ07IG:@80M58/00@0Le4[075?:@1`CRP0KT`V0P1]BbD01P1VBBT0IDPX
06A79`1RABD0Gd8R05e08080FchN00P0FcdQ05Xl801I>al0FC/O05Xl801M?b<0Gd4U06539`80GSlS
0P1O@2@206119@80HD8V00H0HT0U06=19P1VA2P0JDPY06]::@1[BRL206];9@0H07=?:`1dD2`0MU<]
07QE;@1jEbd0O5X]07eK;P1mFbd0OU/a07mL<P20GC<0PUle08AQ=`26HcT0Qf@j08QU>`2:I3D0RfDf
08aV=`2>J3T0SfTj08iX>@2<ISL0RV@e0P28GSH01026GcH0QF0f08EP=P23H3H2089Q=P80Qf8e00L0
QV4d08AO<P23GS40PUd`085L;`20Fbh0NeHY0080NUP[00L0NEP]07IF;@1bEBd0KU8[06a@:@1aDBX0
L50Y00<0KdlX00@0LE4Z07=C;01dE2d0Me@^0`1fDbd207EB;080M54[00h0KE0X071@:@1bDR/0M58/
07EB;01fD2/0MThZ07E=:@1dDBL0ME8X07IC:@1hEB/0NUL]07aI;`80OEX`0P1oFRd01020Fbh0PE`_
085L;`22GC0208=N<@D0Q5lb0P25H3<00`26HC@0R6<f08QS=P0808QS=P0708MR=@26HC@0QV4d08IQ
=028HcH0RVDh08]V>@0208YV=00308]W=@2<J3H0SFTg0080SVXh00@0Sf/i099Y?@2BJCd0T6Xm0P2?
JSd0102=Jcd0S6`m08a/?@2@K3`6095]?@05091/?02>JSX0SVXj08m[>`2@K3`00P2AKCd2099^?P@0
SfTj00@0SVPi08eW>02<ISL0RfDf0`2=IcP308aV=`80RfDf202;IST0102<IcX0RfHi08]V>@2;IST2
08YU>080RF@g0`28HcT[ooooo`00:_ooool809md@@<0X7I40`2OMD<209id@PP0WgE30P2KMT8309ag
@`<0WGQ400T0XGQ40:1g@`2PMd<0X7M30:5hA02SNTH0Y7]70:ElB02UMDD00`2TM4@0102UMDD0YWI6
0:QhB02YNDT20:ElB080Y7]70`2SNTH00`2RNDD0XgU70:=iA`060:=iA`090:MiB02VN4L0XgM60:5g
A@2OMd@0W7M309]f@P2IMD40VG=400<0V7930P2GLD8309I`@@0609M/@@2FJd00UFXo09AY?P2CJ3d0
TFHk0P2@ICX03029ICD0RVHf08]V>@2;ISX0RfHl08US?027HC`0QV0k08=P>021GSH0Oe`d07eJ<P80
O5Ta00P0OEXb07iK<`1mESD0NUHd07UE<`1fE340Le8_071B;P80KE4/00<0KU0/06e?:`1]Cb/01@1]
Cb/0101/Cbd0Jdh/06]>;01[CR`206Y=:`80JD`Z00P0JE4]06Y@;@1ZD2d0K4l]06i@;P1aD2l0M54a
07EB<P80N5@`00`0NEH`07]H<01lFBl0OE/^07iL;`1oGBl0Oehe07mN<`21GS@0QF0d08IQ=029Hc@2
08aT<`80SF8e0`2>HcH308mT=`P0TfPk0P2@JS/0102?JCX0SVPi08eW>02=IcP208aV=`80Sf@g0`2@
ICP3095V>@P0RfDf00<0RV@g08]U>02=IcX00P2>J3/00`2=IcX0RfDh08YT=`03091U>080Sf@g0`2>
HcH01P2=HSD0SV<f08iS=P2?I3L0T6Dh095V>@80TVLj00H0Sf/k091Z>`2@JS/0TFPj099W>P2CIcX2
09AU>@T0TFHi00<0TF`h091[=`2?JSH00P2>JCD00`2?JSH0TF`h099]>@0309=Y=`80U6Xh0`2EJcT8
09=Y=`P0TfPk00<0Sf@g091U>02BIcX00P2CJ3/00`2BIcX0T6Dh08mT=`0208aV=`<0RfDf0`2:I3D8
08UU=@<0R6@d0P29ICD308YV=P0808eY=@2<J3@0S6Pd08]W<`2<J3@0SFTe08m[=`2@K3P3091[=`80
TF`h0`2BKCT@095]?@0808e[?@2<JS`0RfTk08YX>P28ISP0QfDg08IT=P25HcD2085U<`0<081T=01n
HS<0Nehb07MJ<01cERh0LE@/06=?;01PC2T0FTLW05=29P1??R@0CCdV0P1<?BX06017?B80AS`S04@j
8@13>280@CHR03ld8P0m<B40?30P03@]6P0c;1X0<RdJ02l/6`0]:a`0:R/M02TY7@0X:Qd0:2/J02LZ
6@0V:1X09BLJ02<U6P0R8a/08B8L020Q6`T082<J00H07b8I020S6P0Q91/08RDL02<V7@0U:1l202HY
80808RDN00@08B@M020S700P8a`07b8K0P0N8AX201lQ7P807R0M0P0M7a`201`N6`0601lP6P0P8A/0
8B8J02<U6P0U9aX09RPJ0P0X:aX0600_;1/0<RdJ03H_700m<Q`0@cDK04Th701>>ad0D3/L04Hj9013
=b40@3DQ03lg900o>2D0>cHS038_7P0[:1L09bTK02TZ6P0Z:a/0;bhL038_700g<Qh0>cDO03`f8080
?c8O00H0?C8P03T`7`0g<200=BlQ038_800a;B4802dY7@P09bTN0P0T9Q/202<U6P04028T6@0Q8aP0
828G020R5`P07b8K200N8AX0600Q81`08R4M02@S7P0U9Ad09RHL02LW6`0V9QX09RLI02hU800d:Qh0
@3@L05107P1UD2D0NUlb08e^@02HMdX0Sg5;08]`A@2:M4D0QgI807IX@@1GCS40>C8R02/T7P808bPQ
00<092LP02DX8@0V:B800P0V:B800`0U:2409RTR02HY8P0402@W80D09RTR0P0W:R<402P[90809bPP
0P0X:B4202TZ8P80:R/S0P0X;BH07P0[;RD0;BlT02h`8`0a<R@0=38S03Dc9010=2@0@SHV04Dj:019
?RX0Bd0Z04]1:01:@2L0BClT03ln:P0n?BT0?cdX040k9@12?2@0AChT04Q19`1;@BH0CT8Z04/o9`1:
?RH0BclW04i2:P1@A2`0CT8Z04a0:080CShT00@0CclU05519`1B@RP0E4@Z0P1EAB/01P1KA2@0GDHV
06599`1VC2T0Jdh/06e?:`80L50Z00h0K5@^06]E;P1/ES40JEDb06IC<P1RDS40GTl^05a=;P1HB2L0
FdPX05e::P1OBR/0HT//06=:;080HdP[00P0HddX06A>:@1VD2/0J58]06MA;01TCRT0HD/V05m99080
Fd`[00/0Fd/Z05e::P1NBBX0HDX[06=<;@1TBbd0IDTT06M;9P1[CBT0Kdh[079@;@0207A@;P0707E>
;@1cD2P0M54Y07MD;01jEbl0OEXb07mL=002085N=P04085W=P23JCP0Qfdl08Y`?`80S79100<0Rg50
08Y`?`2:L3l00`2:L3l408U_?P0:095c=`2DMSX0VWXm0::0@@2WQDD0[8U70;2:B@2aS4P0/Y=B0;>D
D`80]9ED0180/Y=B0:j?CP2ZRdX0YhQ70:>1@@2RPd<0XX950:21B02LOTP0UWY8095gAP2?M4D0RV/o
08UZ?P28JCd0QVLk08AU>@22HcL2081Q=@80P6@b00D0OV8`07eN;`1lFbh0NeP^07aF;`0207eE<@06
085M:`24GRd0Qf8^08]S;`2?IS80TFHa0P2DIc00602;J2h0TFdc09Yb=`2MLcL0Xg8g0:Id=`2]Mc/0
/g/n0;1o<P2`Oc<0[gle0:j0=@2^PS/0[hDm0;66@@2`R4<0^9=50;VDAP2iTdP0^I=:0;ZDC@2kU4l0
_9EB0;fFD`80/IA@00X0[iAA0:^BD02XT500XXe>09n9C@2KQdX0VGiA09IkCP2BMdX0SW=60`2<LD@0
4P2=LTD0RG9008M`?P25JS/0PfHj08AT>`25Hcd0R6Do08UU@@27ISd0QVDl08MT>P29I3P0R6<f08US
=02;HS@0RV8a08QT<0<0RFDa102:IS806`2CIcP0TVHg08mU<`2=IC40RfHa08aY<@2;Jc00S6`a09Mf
@02FMCl0U7<m09=b?02@KcT0Sfhh08e/=P2<JcD0S6Xl08e[?@2@K3`0TV`k09E]>P2GKSX0V6li09Y_
>P2DLC/0Tg0j095^>00308m/=P0<091]=`2AKSP0RVTc08UX<`28Ic80QVDb08AR<P22H380PElb081N
<@1jFS<0Ne/d0P1lG3D0101kFc@0NUXc07UI<P1hF34207AH<@0607EH<01hF2l0NeX_081N<@23HC@0
Qf8e0P1hHS001`1jI380NfDc07eW=@1oJCL0P6Xh085[>@24JC800`25JS<208I[=080Qf`e00<0R6Xd
08AV<024IS000P20HR`2089T;P0J07mQ:`1kGBL0N5h[07UO;01iGbh0N5d^07IK;P1bEb`0KU8Z06a@
:01RBBX0HDPY069::01SBbL0I4`X06M?:@1YDRT0JU<Z07EP<@1`Fb`0JU@U06I>801XCB00KE0T07IG
:`1jFbl207UK:@0607YL:P1lGR`0OEl]07iP;P1oHBl0P68`0`24H2`03P25HBd0QV8^08QT<02:IS80
S6Pd08i_;`2ALC@0UGDh09Ee>P2ALCP0R6La07mN:@1hEb80M5h/0P1cGB/00`1bG2X0LE/Y071J:002
06mI9`80MU`[00X0N5h]07YP;`1lHS40OV@c07mU=020ISD0PfXb08A[<`26KCD0R6lg0P29L3P00`28
KcL0Qfhf08I/>@0208I/>@D0QF/h00<0PfTf089X=@20IS<00`1nI3406P1oIC80P6Hc07eW=@1lIC<0
NF8`07UO;P1kGbl0PF8c08IV=`29JCX0Sg8j08i`>P2:KcP0QF`f07iW<`1hHS00Lel]071L:P1/EbP0
JeHW06YE:01YE2T0J58Y06I@:@1UCbP0IDlZ0P1QCbT2061>:0<0GddW0140GT`V05i?9P1MCRD0G4dV
05Y:9P1HB2H0ETHU05E5901D@bD0CSdO04/l7`19>Qd0ACLL048f7011=ah0?cLP040h8@0203hb6P08
03`a7@0h<1d0=BhN030Z7P0Z9Q/0:2@K01dO7P0L7Qd201/M700301XL6`0H6QT05aTH01805QPG:00E
5aH801DF60P05ALF200F61L801LI61006A/H200K6aT801`L6PP07AhH200M7A/201dL5`<07QdH0`0O
7QT3020P60@08B4I0P0R8QX202DQ60<09R8I0`0W8aX302TU7080:2@K0`0W8aX202`S7P0302XS7@0X
8ad09R<L008092@L00<08R<K02<S6`0S8a/01P0S8a/202LP60<0:24I0`0Y8QX01P0[91`0;B@M02dT
7@0^8ad0<B@N038S7P80=B<O0P0c9a/203@X70<0=BTM00@0=RXN03P[6`0h:a/0>2/K0P0i;1`203X]
7@0403/^7P0o;Qh0?bhN03l^7P80@2lO0`11<20204<c7080A3@M1015=Ah01016<QT0B3@K04Xf7@1<
>1l204di800504`h7`1;=ah0DSTS058i8`1A>2800P1@=b400`1?=R00CSDO04he7`0204hf7P80CcLO
01@0D3PP054i8@1B>R80DSXR05@l801C>al0DcTN05@i7P1F>1h0FCTP05`j8@1N?2<0F44R05M08@1H
?b40FChQ05`n8P1O@2@0HT0U06=19P80H44R00<0HD8S0693901SA2D00P1TABH01P1UARL0HD8V0611
9@1O@2@0GSlS05dn8P80GSlS00<0Gd0T06528`1Q@R<00P1P@B80101Q@R<0Hd@U06E69`1VAbP906M9
9@80ITLX0P1UARL0101TABH0Hd@U0693901R@b@206I59P0306A3901S@R<0HT4R0080Hd8S00@0I4<T
06E48`1UA2<0ID@S0P1T@b8306=28@080612801Q@b40HT@R06=58`1RA280HD<Q05m17`1N@1h2060o
800406508@1R@B80Hd8S06=28`80I4<T0P1Q@b420612800405m17`1N@1h0GClM05do7@P0F3XP201K
?Qh0101M?b<0GT0T05m19@1P@RH206539`0406129P1O@BD0HT4R06918P80Hd8S00L0I4<T06E49@1V
ABH0ITDV06I5901WARD0JDPW00<0JTTX0P1XAbH306a89P80KDTW0`1^BRP8079?:@P0Me@/00P0N5P_
07IF;@1eEB`0MeL^07]K<P1nGSD0OEdd07]K<P80Me`_00<0N5/_07YK;`1jFBh00P1kF2h01@1lEbd0
NEH/07YG;@1mFS00P5dc00@0PUle0P24HCL208ER>0@0QV<i0P27HSD00`29I3L0RVDh08YU>00208YU
>00808UT=`28HcH0PV<d085R<`20HC80OUl`07aM;P1kG2d207UJ:`0807QE;`1gE2h0MU<]07EB;01c
D2X0LTlY075>:01`CBL206I99`0906A79@1SAR@0HD@R05m2801N@Al0GD0N05do8`1K?B40FC/O0080
F3XN00<0FS`P05do8`1O@BD00P1N?b<205m09080H44U0P1Q@RH03@1S@BP0I48W06M5:P1YAb/0JdX[
06]::@1[BRL0JTTV07=?:`1dD2`0Me@^07UF;P1kF2h00P1lFRd02@1lFR`0Oe`b081M<`21GS@0Pf0f
08ER>027I3X0R6Dk08UV?00208YT=@0608]U=P2>J3T0TF/l095[?02=IcP0RF<d0P29GcL01027H3L0
QV4g08IQ=`24HCL208=R=`80QV4d0P25H3<01@24Gc80Peha089M<022GC00OUT/0080O5X]00h0NeX_
07QH;`1cERh0Ke</06eA:P1bDR/0LE4Z071@:@1_CbP0L50Y075A:P1cDb`0M5@]07QE;`<0Me@^0P1f
Dbd207EB;00606iA9`1bDRT0Le<Z07IE;01gE2`0NE</0P1hDBX0101iE2X0NUD[07aG;@1nFBl4081K
<@<0PUh^0P23Gbl208AP<00408EQ<@27HSD0Qf8e08IQ=080QF0c00<0QV4d08MR=@28HcH02P28HcH2
08MR=@0608IQ=027HSD0RF@g08]V>@2=J3/0S6Pd0P2=JCD00`2>JSH0Sf/g091/>002095]>@80U6/o
00@0TV`o095/?`2AK3l0Sfdo0P2>KSl00`2AKCd0TVhn09=_?`0309=_?`04099^?P2AKCd0TVhn099^
?P<0Tflo0`2DL40208mY?0<0T6Xm00<0SVPk08eW>P2<IST00P2<IST608eW>PP0S6Lj0`2=J3/208aW
>P<0RfHi0`29I3X[ooooo`00:_ooool809md@@<0X7I40`2OMD<209id@PP0WgE30P2KMT8309ag@`<0
WGQ400/0XGQ40:1g@`2OMT80WgI20:1g@`2SNTH0YGa80:MnBP2WMdL0YWI60:EeA@020:AdA0030:Ee
A@2WMdL0Z7Q800<0YGa80P2TNdL30:=jAPP0XGM500P0Z7Y90:MiB02TN4L0XGM509mgA02KMT80VWE1
09Qd@0<0V7931@2GLD805@2FL440Ufa209I[@@2EJT00U6To099W?@2AIS`0T6Dk08mT>P2;IcL0S6Ph
08aW>P2<Ic/0RfHl08QR>`26H3/0Q5hi085N=P20GCD0OU/c07aI<@0207]H<080O5Ta00P0OULf07]G
=@1iEC<0MU@a07=B;`1_DBd0KE4/06a@:`80Ke4]0P1^D2`0101]Cb/0K4hZ06]=:@1[CBT206a?;@<0
Jdh/0`1ZCB/05P1[Dbl0Je4^06Y@;@1/Cbd0KU0^079A<01eDS80Me@d07QD<01iEC40NULa07]H<01m
FS00OU`_07mM<020GS00Oehe081O=022GcD0QF0d08MR=@29Hc@208aT<`<0Sf@g0`2@ICP2095V>@P0
U6Tl00<0T6Xk08mY>P2?JCX01@2?JCX3095V>@<0T6Dh0P2?I3L808]U=P0308YT=`2;ICP0SFLj0080
SVPk00<0SFLj08]U>02:I3L00`2@ICP208mT=`<0SV<f00H0S64d08eR=@2>HcH0Sf@g091U>02AIST2
099W>P06091/?02AJc`0T6Xk099Y>`2BIcX0TfLj0P2DICT9091U>00808mZ=P2>JCD0SVTe08eX=02>
JCD0T6/g09=^>P2DKc/309=Y=`80U6Xh0`2EJcT809=Y=`P0TfPk00<0Sf@g091U>02AIST00P2BIcX0
0`2AIST0T6Dh08mT=`0208aV=`<0RfDf0`2:I3D<08QT=080RFDe0P2:ISH0202:IS80RFDa08UU<@29
IC40RVHb08eY=@2?JcL0TFdi0`2@JcL2095/>0<0TVdi402AKCd0202=Jcd0S6Xl08]Y>`2:J3X0R6Hh
08MU=`26I3H0QF<e0P21IC<07P20I3@0OV8c07YM<@1fFBl0LUD]06mB:P1QCBX0GTXY05Q59@1A@2@0
CC/S04`k9`1;?2T0C3`/04Lm8P16?2<0A3XQ044f800n<al0?34O03X^7P0i;Ad0<b`I03</6P0a;1T0
;R/J02`Z6`0Z:ad0:BTM02PZ7@809bXI00H09RPJ02@V6@0S9AX08R<K024R700P8A/;020S6P808B@K
0P0R9A`202<V7@808RDN00@08B@M020S700P8a`07b8K0P0N8AX201lQ7P807R0M0P0M7a`201`N6`0P
01lP600P8AT08B<H02<U600U9aT09bXI02T/6`0Z;AX0<RdJ03@]6`0h<1/0?c<M04Hf7@1<>1d0D3/L
05<l7@14>B<0@SLS03hf8@0n=b@0?CPU03Ld8`0_;1d0:2HG02HY600X:AT0:b`J030_6`0d<Qd0>C@N
03`f800m=al203lb8@0603da8@0i<240=RhQ03@^800a;B40<2`P0`0/:1`502dY7@P09bTN0P0T9Q/0
100S9AX08R@I024S600P8QL201lQ5PP07b8K200N8AX01@0S7a`0920M02LT7`0Y9Ql0:RLN0080:BLK
0140:2HI038W9@0m;b@0CCdS065?9`1fH2h0Qf`g09=c@02HMTH0T79>08Q/A022Jcl0MfPm065G<`12
?2@0;R`P02/Z:003028X90808RLQ00H09BPQ02LZ8`0X:b@09bXS02HY8P0T9b0202<V7`0302@W800V
:B809bXS00809RTR0P0W:R<502P[90809bPP0P0X:B4202TZ8P80:R/S0P0X;BH0100/;bH0;S0U02la
900b<bD203Dc900403d`7`10<b80ACPU04Tm9`80BclW01P0BCdS04Pl8P0m?2P0?3/W03`j9@0n>B<0
?cTQ048k8@14?B<0B3hS04e1:@19?BD0Ac/S04Tm9@1>@RX0D4@/04i2:P1:?RH0CShT04lo9@1@@2H0
DD4W05=3:@1DA2X205E5:`0^05e49@1OAbD0HdTX06Q;:@1[CBT0KThX06i>9`1^C2H0IU0[06MA;01U
DBh0I54`065A<01NCbh0Fd`]05U<;01JAbL0G4TY05m::`1RBb`0I4/]06A9;01SB2/0I4HZ05a88`1N
BRD0HDdX06=?:P1RCRT0H4`W05a88`1JAR40FT/Z05U::@1IBBP0FTLW05a7:01OB2T0HT//06A;;@1U
Ab<0IdTU06a;:01_CR/0LU0]07A@;P80MTl^00d0Me@/07QE;@1iERh0NeP`07iK<`22GcL0QF8j08IS
>`27KC`0R6hm08U_?P2:L3l0Rg5000<0S7910100RVm008Q]?P26Jc`0QV/l08M/?@29KSl0SG9308md
A@2GNCd0VWa009mo@P2UPd@0ZHM70:b9A`2`RTT0/8]70P2]T4h03`2[ST`0ZHa:0:N:B02UR4H0XXE3
0:64@P2MOD00W7`o09Yk@P2GNT80TgQ308meA02=LT<0RW9408=T>002089S=`03081Q=@1oH3@0OUlc
0080OEhb0P20IS<01@1oHc40OUl`07eK;P1mF2h0OEH_0080PEDb01P0PehZ08EP;02;Hbl0SfH`09=X
<@2FJC00UfXa09QZ;`2>Jc40U70d09ad>@2QM3T0YG@i0:]e>@2dNCd0^Gi20;b7=`2kQSH0^HHg0;F5
>@2eQc`0/hU10;>;A@2dS4H20;ZEA00L0;ZEA`2jU4T0^YA;0;ZCCP2iTTl0^I9A0:fCFP2/TEX0ZY5I
0:F>F02ORUD0VHEB09B0CP2@OT`0T7U?08efC029LTP0QVm508A]@`25KT@0Qg1608QaA`29JS<0R6Tc
08UX<`2;IC@0S6<e08iQ=`80T60h0P2;JSL01P2=JCD0SFPc08iW<02?IS00SVD]08mT;@80RfHb0P2<
Ic<0302=J3@0SVTe08iY=@2?JSH0V6Pj09IX=`2CIcH0TVTe08mZ<`2@KC<0T70c091b=080TW4k00@0
TG0j091_>@2?KSP0Sfhh0P2>KCL02`2=J3`0SVTl091Z>`2DK3T0Ufhj09U`>P2KLCL0W78h09Ia>P2C
KSL0SfXc0080RfH_00/0SFPa095/=@2DKcP0T70g08m_=P2=K3L0RVTf08IT=P23HC@0PEhd081M=@02
07iN;@80P60_00`0Oel^07iN;@1lG2/0NUXY07=E<`1cEC40ME@a07EE;`1hES00NeP`081K<@22GC<2
07AO<00407EP<@1fHC80N6<d07UT=@80NVDf0P21IRl01`23J340Q6Tb08I[=028KCH0RFhg08Y_>02<
KSP00P28JS@03P24IS00PfD_08AV<023IBl0Of4[07]M9`1kHR`0NV0]07UO;01gGB`0MEX[07=H:`1a
ER/0Ke@Y0P1UC2h05P1TBb`0I4`Z06E=:@1XD2X0JU8/06aE;01dGc00L5//06eG:01ZDR@0Je0S06e@
901bDbL0MEHZ07QJ:01iFbT0NU`Z07]M:`1mGbd0OV0^07mQ;`20HS0308QS;`0=08UT<02<Ic<0T6/g
09A_>`2FLCd0V7Ti09Ig=`2DM3L0Sflb08UY;P23HbX0OUdW07]J900207AN;00307=M:`1bG2X0LE/Y
0080L5XX00L0KeTW07MM;01gGB`0NEl^07YP;`1lHS40OV@c0080OfDd00@0PfXb08A[<`26KCD0RG0h
0P2:LCT00`29L3P0R6lg08AZ=`0408AZ=`<0QF/h0200PFLd081V<`1nI340OF<`07aR;`1mHc00OV@a
07mU<P1kIC<0Nf@b07YS<@1kHC00OF4a085R<`25ICH0QVHg08mb>P2>LCT0Rg0i08Q_>@22JcL0O6Lb
07IR;`1dH2d0KEPY06aG:01[ERT0JUDZ06QB:@1WDBX0IU0Y06E?:P<0HDlY0P1PCRP305m=9`0J05a=
901KC2<0FT/T05Q8901FAR@0E4@S05=38P1B@B<0CSdO04`m8019>Qd0ASPM048f7011=ah0?cLP040h
8@11<aT0?c<K03lc7@0l<Al0=bhO03<[7P0^9ad0;2DM01hP7`0M7ah201`N7@0501XL6`0I6aX05aTH
01HH5`0E5aH0400F61LX01DG5PP05AHH200E5aH801HH5`P05aTH400I6aP@01`L6PP07AhH200M7A/2
01dL5`<07QdH0`0O7QT3020P60@08B4I0P0R8QX202DQ60<09R8I0`0W8aX202XV7@80:BDL0`0X91/0
2@0W8aX0;B@O02`S7P0[91h0:B@N02LT7@0U9Ad092@L02<T700802<S6`809b0H0`0X8AT302TR6P06
02lV7`0`9Al0<2DO03<V800d9B00=bDQ0P0h9B4303@X70<0=BTM0P0f:Qh203HY6@0403LZ6P0i;1`0
>RdM03`_7`80?C0P0P0o;Qh2040_7`@0@C0P00<0@c<L04@d7@14=1d00P15=Ah204Hf7`0504Lg8018
<aP0BC@I04`g701>>Ah00P1?>Ql204hi7P80E3/U00@0DcXT058i8`1@=b40CcHP0P1>=Al204hf7P03
04lg7`1@>200DCTQ0080DSXR0140Dc/S05Hl8@1E>b00ECXO05Hh7P1G=ah0FcTP05dk8P1O>b<0FD8S
05Q18P1H?b40FChQ05`n8P1O@2@0Hd4V06A29`0205m08@0@06118P1Q@R<0HT<T06=49@1TABH0IDHW
06939`1Q@RH0Gd0T05ho8`1M?R80GSlS05m0901P@BD0HT<T06528`80H44R00@0HD8S06A59P1VAbP0
J4TZ2@1XBR@01@1WB2T0ITLX06E69`1TABH0Hd@U0080HD8S00@0H44R06M69`1VABH0I4<T0P1R@B80
0`1S@R<0I4<T06E49@0306M58P80IT@Q0`1U@b00201Q@al0HT@P06=58@1TAR80HdDQ0694801P@Qh0
Gd4M0P1Q?R00101R?b40Hd0R06A18`1U@R@206I39@0606E48@1T@b00Hd8O06=27`1R@Ah0HD0M0P1P
?a`805Pj800505Tl701J?Ad0FSdM05/n7P1L?al00P1M@200101N@B40Gd4U05i0901N@2@205do8`04
05i0901P@RH0HD<W06=28`80I4<T00<0ID@U06I59P1WARL00P1XAbP0201ZBBP0JdXY06a;:P1]C2/0
K4/Z06]::@1YB2L0J4LV0P1/B2H206e99`@0KTXX0`1cD2X5079?:@P0Me@/00P0NET`07IF;@1dE2/0
MeL^07eM=020H3L0OUhe07]K<P80MU//00<0N5`]07YK;@1kFRd00P1mFbh01@1oFRh0NeP^07aI;`1n
Fc40P5dc00<0PEhd00@0P5dc08AQ=`25HSP0QF8h0P26HcT208MT>P0408QU>`27HC80RF<d08]U=P@0
SFLh00P0S6Hg08]U=P24IS@0Q6Hd089T<P20HS00OV0^07eO;@80Ned[00H0NULa07UF<01hEBl0Me@^
07EB;01dDB/207=@:P0506I:9@1UBB@0I4PS06=78P1RAR400P1QAB00101PA1l0HdDY06129P1M?b<2
05Xl800305/m8@1N@2@0H48V0080GSlS0P1O@2@206119@80HD8V00d0I48Y06E3:P1XAR/0JTP]06]9
;@1[BR/0JdXY06Y9:01bCRX0M50/07MD;P1jEbl0O5T_0080O5X]00d0O5X/081M<`21GS@0PUle08AQ
=`26HcT0R6Dk08UV?02:Icd0RfDf08US=02:I3D0SVPi0080Tfdn00D0SVPi08QR<`2:H3P0RV0h08QQ
>00208MR>00308ER>024HcP0Q6<h00@0QF0c1024Gc804020Fbh0OU`_07iL;`1lFc00NET`07AG;`1`
E2d0KU8[079B:`1aDBX0L50Y06m?:01`D2T0LE4Z07=C;01eEBh307QE;`80Me@^0`1fDbd0401_DRH0
LU<W07AE:@1gER/0NEH/07YE:`1jDbX0NE8Y07eF:`1oF2d0PEX_089K<023G340PU/`085J;`20FBh3
08AP;P<0QF4_0P26HS000`2:ICP0RF@g08MR=@0208IQ=00308MR=@28HcH0RF@g00T0Qf8e0P28HcH2
08MR=@0408QS=P2:ICP0S6Lj08iY?080Sf/g00<0T6`h095]>@2BKSX00P2CKc/0102DL3`0UFa009E/
@02CKD02099]@006091^@02?Kd00Sfm0095]?@2BKSh0U7100P2ELD400`2DL400TVhn095]?@0409=_
?`<0TVhn00<0TFdm08iW?02?J3d00`2AJSl00`2@JCh0SVLl08eV>`0208]T>@0408aU>P2=IS/0SFHk
08iW?080SfPm202=J3/308iY?080SFPk0`2<IcX308UT>R_ooooo000Zooooo`P0WgA10`2PMT@309me
@`80WWA2202OMD<209Yf@P<0VgM30`2LN4@0402QN4@0X7M309mf@P2OMT80X7M30:=jAP2UO4P0Ygi:
0:]hB@2ZMdP0YgA50:IcA02ULT<0YW=40:QeAP2YMTL30:ElB0<0Y7]70P2SNTH80:1fA0080:QjB@2W
NDP0Y7Q70:5gA@2OMd@0VgI209Ye@@2HM40309Qb@`H0Ug5200P0V6]209MZ@@2FJD00UFPo09=V?@2A
I3/0T6<j08mR>@80SFTi00X0SFPk08aW>`2;IS`0R68k08EO>P23GCP0P5de07mL=01mFS80NeP`0P1j
Ebl207]H<00>07iG=P1kEcD0NEDc07ID<@1cDRl0Ke4]06eA;01/D2/0LE<_071B;P1_DBd0KU0/06e?
:`1[CBT206Y<:0<0K4l]0P1[CR`306Y=:`0806aD<01/DRl0JU0]06a?;@1^D2h0LU4`07IC<`1gE3@2
07UE<@0>07YG<@1lFC40OEX`07mM<020GS40P5h`07mN=@20Gc@0PUle08EP=027HSD0RF<d08aT<`2=
IC@3091U>0<0TFHi0P2BIcX809AY?080SfTj0`2@JS/3095[?00609=X>`2BIcX0TVLj095V>@2@ICP0
Sf@g0P2>HcH808]U=P0308YT=`2;ICP0SFLj0080SVPk00<0SFLj08]U>02:I3L00`2@ICP208mT=`<0
SV<f0P2<HC@0102=HSD0SV<f091U>02AIST2099W>P06095]?@2AJc`0TF/l099Y>`2BIcX0TfLj0P2D
ICT9091U>0@0SFPd00@0SfXf095/>02DKc/0UW4m0`2CJCL209AZ>0<0UF/i202CJCL809=X>`0308iS
=P2@ICP0TFHi0080TVLj00<0TFHi091U>02>HcH00P2<ISL308]U=P<0RV@e2027Hc<01027HSD0R6<f
08QS=P28HcH208UT=`80RVDh00P0R6@`08MS;`27Hbl0Qf<_08UU<@2<J3@0Sf/g095]>@<0T6/g0P2A
K3P3099]>A00TFdm0P2=Jcd0102;JC/0RVPj08QV>027ICL208ES=@80PFDc01h0P6@d07eQ<P1jGC40
MEP^075D;01_DRX0HDd/05e9:01GA2H0CchT04`j901;>RH0Bc/[04`l;017?B80AS`S04<i8010=Al0
?C8N03X_7@0g:a/0=RXJ03</6@0c;1X0<B`I02h[6P0/:Q/0:BXL02TY7@0W:A`202LZ6@0402HX6P0T
9QT08bDJ024R6P80824K2P0P8aX7024T6`808RDN00@08B@M020S700P8a`07b8K0P0N8AX201lQ7P80
7R0M0P0M7a`201`N6`0P01lP600P8QL08R@I02@V6@0V:1X0:2/J02T/6@0Z;AX0<RdJ03D^6`0k<1`0
?c<K04Hf701=>Q`0D3/L05@m7@14>BD0@3PS03hf8`0n=bD0?CLW03Hc8P0]:a`09R@E02HY600X:AL0
:b`J030_6`0e<ah0>SDO03dg7`0n>20203lb8@0603``800i<240=RhQ03@^8P0`;200<2`Q100/:1`4
02dY7@P09bTN0P0T9Q/0100S9AX08R@I020R5`0O8AH201hP5@<07R4J1@0O8Q/801hQ6P0S02<O700U
8Ah09b@O02TV7`0Z9ah0:RPL02TW6`0X9QT0=bTX044c:01DABP0JeP]081Y<`2?LSX0UG@o09Qd@P2B
M500R6a507]V>`1/GC80DDTU03Ha7@0[:b<0<S8d020[9`0Q:RL082TV024W8`0Q9R009BPQ02LZ8`0[
;2@09bXS02HY8P0T9b000P0S9Ql00`0T9b009RTR02LZ8`0202HY8P809bXS0`0X:b@202T/9@809bPP
0P0X:B4202TZ8P80:R/S0P0X;BH0100/;bH0;S0U030b9@0b<bD203Dc900V03/^7@0n<B00A3LT04Pl
9P1;?bL0BShT04Pl8P16>al0>cXV03Xi9@0j>2<0?3LQ03dg7`10>Al0@S/Q04Dk801<@2P0B3`T04Hj
8P18?2@0CD4Y0514;01=@BT0BCdU04hn901??bD0D40V05519`1C@bT0E4@Z05E5:`1FAR`0GTHT0657
9P1SBBH0J4`W06Y<9P1/C2H206e;9@0U06==:01QCBP0HTh[065>;@1OCbh0G4d^05U<;01GBB`0FdPX
05e8:@1OBR/0Hd`]06A;;@1TBB`0I4HZ06=5:@1IAB00FdLR05i:9@1QCBP0H4`W05i:9@1JAR40F4@O
05U::`1HBBX0EdHX05U6:01KART0GdL[0659;@1TBRl0IDLS06M99@1/BbP0L4h[07=?;@0207I?;P0:
07M>;P1lERl0O5H_07aF;`1mEc00P5Xc08EO>029Hc`0S6Ho08]a@0<0RW0o01T0Rg5008ab@@2=Ld80
SG=208U^?`27K3d0Q6Tj08=X>@25JS/0RVm008mdA@2CN4T0Vge109eo@`2RPTD0YhE60:Z8B02]RTP0
[hU80:n:AP2UQdL0XhE50:22@P2MOcl0Vgdm0080VG/k00T0V7Xj09Yj?@2HNSh0UWLn099d?P2>LT00
S75208Ua@`29LDD00P1mGC@207aL<`0407]K<P1jFS40NUXa07UI<080P6Hc00D0Of<a07iO<01nG2l0
OeP_081F<002089D<P0H08=N:@28H2`0S6D^095X<02EJc40V6/b09U[<02IJbl0T6ha09Ea=@2MMCP0
XWHi0:Me>02^MST0]W/o0;eo@P34SCX0`X/i0;j9>@2jRC`0^8Xo0;J<@P2eSDL0]Y190P2iUD407P2h
Td<0^9=50;NAB02fSdX0]Hi;0;F>C@2[TF00ZXmP0:J>GP2QRe`0VXEH099oE02=NU00RGQ=08]eC029
LdX0QFm6085[@P20JT40PVa308A^A@26L4L0R6D[08YV;02=IRl0T6Db09=S<`2DHC@0UElc09AM=080
T6de00H0T6`b095Z;`2BJRd0TFT[095X:P2CIbP208aW<P0408eX<`2>JC@0SfXe091[=P80TF`g00P0
VfPi09UY>@2GJCL0U6/e09A]=02CL3H0Tg<f09Af>080RfXd00@0S6/e08e/=P2>KCL0SVdg0P2?KSP0
2`2=J3`0SVTl091Z>`2DK3T0V6li09]`>@2LLSH0Wg8g09Ea=`2AKC<0RfL]0080QV8X00d0RFD[08m[
<@2CKcD0Ug@j09Eb>P2BKcT0SVXh08YU>026HCD0Pedf089L=@20HBX0PF8[00<0PV</00<0P64Z07eN
9`1lGBH00P1bE3801`1cDRl0M58]07MD;P1kEC00OEL`081I<P1bGBh00P1cGRl03P1dGc00MF0a07IQ
<P1fHC80Mf8c07iS;01oI2d0PFH_08AY<P26Jc@0RFhg08]`>@2<LCX0Sg8j0P2;KSH04026JC40QFP`
08EX<024Ibl0Of8Z07YM9@1lHbd0Nf8/07UO;01fG2/0M5TZ07=H:`1bEbX0LUL/06YA<`1YD38206M>
;`0:06Q@;P1ZDRh0K5@^06iF<01`Fb`0KeX[06mI:P1_EbT0Ke@W06mB9P80Ke0T00H0N5XX07UK:@1j
G2X0Ned[07eO;@1nH2h207mQ;`<0RfHb00d0SVTe095/>02FLCd0VWE109ehA02QOcl0VgTj099`<@28
IRT0PUlU07mL901oG2H0P5dW0080M5h/00@0Led[079L:P1aFbT0LE/Y0P1`FRP01P1gGB`0N5h]07UO
;P1jH2l0O68a07iT<`80OfDd00@0PfXb08A[<`27KSH0RG0h0`2:LCT00`29L3P0PfTf08=Y=P0208=Y
=P@0Q6Xg01P0P6Hc07mU<P1mHc00O68_07]Q;P1lHRl0OF<`07iT<@1jI380Nf@b07YS<@1lHS40OV8b
085R<`24I3D0QFDf08ia=`2>LCT0S78i08U`>024KCL0OVTd07UU<P1fHRl206eH:@0606aG:P1ZEBX0
JE<Z06MA:P1VD2T0IU0[0`1QCbT3061>:080GddW00h0FDXQ05Q9801GB240EDDQ05=38@1A@B00D40O
04ln801>?Al0C3dP04Tj7@16>1d0@SHL044g7P80@3PQ00X0@S@I048d6P0o<ad0?C8N03P_7P0d;1l0
<2PM02dV700N81l07AlN0P0L7Qd01@0K7A`06A/J01LI600F61L05ALF01005QPG:00E5aH801DF60P0
5ALF200F61L801LI61006A/H400L71X801dN60P07AdK0P0M71L301hM60<07ahI0`0P81P4024Q6@80
8R8J0P0U8AP302HR6@<09b<J0P0Z9Qd202TU70@0:2@K0P0]91l00`0[91h0:B@N02LT7@0202DU7@04
02<T700T91`092@L02@T70D08b<K0P0W81P302PQ6@<0:B8J0P0a9R0203@W8@0403DV8@0h9R80>BHR
03TV8P<0=2PL0P0e:Ad303HZ7P0803@W5`0e:1P0=bXJ03T/700k;Qh0?C0P03ha8@0o<R8203l^7P80
@2lO0`11<2001P12<B40A3@K04@d6`14=1/0ACDL04Hf7@<0AcLN00@0B3<F04Xe601<=aX0CSTL0P1@
>ah0201?>Qd0CSTL05Ll9`1F>bH0ECXU05<h8`1B=b80D3DP0P1?=1l204hf7P0404lg7`1@>200DCTQ
058j8P80Dc/S01H0ES`Q05Hk801E>Ql0ESPN05Ph7`1K>B00GSXR05lk8`1I@R<0F44R05Po8@1H?B00
FcdQ05m0901S@BH0ID<X05ho801O@240H44R06528`1R@b@0Hd@U0P1TABH00`1SA2P0HD8V05m09002
05dn8P0505ho8`1O@2@0HD8V0693901Q@R<00P1P@B80101R@b@0I4DV06M8:@1YBR/906Q:9080ITLX
00@0IDHW06=49@1R@b@0H44R0P1O@2400`1WARL0ITDV06A3900306918P0306A3901UA2D0IdDR0080
IdDR0P1VA24306E3800806537`1RA200HdDQ06A68P1SAB40HT@P06127P1O@Ad2064n8006068o8@1S
@280I44S06E2901V@bD0Id@V0P1UA2400`1T@b00Hd8O06917P0206507@03060o701H>R00F3XP00H0
F3XP00H0F3/I05Tl6P1J?A/0FchL05e07P1N@Al205m2800306129P1O@BD0G3hR0080FcdQ00<0GClS
06129P1Q@bL00P1UA2D0101VABH0IdHW06M69`1XAbP206U8:@0806a;:P1]C2/0KTd/06i=;01]C2/0
JdXY06U89`1XAbH206i79P80KdPW0`1`BBP00`1aBRT0Le0Z07=@:P0207=@:P@0LTlY201gE2`03@1j
FS40MUH]07AD:`1gEbh0OUhe085Q>01oGcH0Ne/b07EK:P1fG2/0Me/[07YK;01lG2d00P1nG2h01021
G2l0O5T_07eJ<01oG383085N=080Oe`b0`25HSP00`26HcT0Qf@j08QU>`0208QU>`0508MQ<P29Hc@0
RfDf08iX>@2?JCX00P2>J3T0202=IcP0S6Hg08EW=@25IcD0PfDc085S<@20HS00OV0^0P1lGR`01P1m
Ec80O5Ha07]E<01jE2l0NE<^07MA;080MU0[0P1UBB@206A88`80HdLR0P1RAR40201XBRh0IDL[0653
9`1N@2@0G3hR05i0901P@RH0HT@X0P1N?b<205m09080H44U0P1Q@RH01P1U@R`0IT@[06U7;P1[BBh0
K4X^06a;;080JdXY00D0LThZ07A@;01gE2h0NUL_07aI;`0207aJ;@0=07]I:`20GC<0PEhd089O=@24
HCL0QV<i08QU>`29IS`0RVLm08]U=P29Hc@0RV@e08mY>P0209A^?`0508iX>@28HS<0RV0h08YP>028
HCP00P27HSP00`25HSP0Q6<h08AS>00308AO<P<0QF0c0P26HC@02P21G2l0Oed`07mM<01mG340NUXa
07EH<01aEBh0Ke</079B:`1aDBX3071@:@04079B:`1cDb`0MED^07UF<0<0N5D_0P1gE2h207IC;@0;
071C9`1cE2P0MEHZ07QG;01jEbd0NeH/07]D:`1jDbX0OeT/085K;P23GC000P24GS400`23GC00PE/^
081J;@0208EQ;`H0QV8`00<0RfHi08YU>028HcH00P26HC@00`27HSD0RF@g08YU>00908MR=@80R6<f
0P27HSD01029I3L0RfHi08eX>`2?JSd2095^>080TVli00@0Tg0j09Aa>`2ELS`0UG8l0P2EK400102C
KD00TVe0099]@02@KT0208m_@003095]?@2CKcl0UG510080UW9200@0UG5109=_?`2AKCd0Tflo0P2B
KSh00`2AKCd0T6`l08m[>`0208iZ>P0308iW?02?J3d0TFXo0080TV]000<0T6Tn08iW?02=IS/00P2:
HcP01P2;I3T0SFHk08iW?02?J3d0T6Tn095Z?`P0SFPk00@0SfXm08iY?02>JC`0SVTl0P2=J3/208aW
>P<0RVDk:oooool002[ooooo00<0W74n09md@@2RMd@00P2TNDH00`2RMd@0WgA109aa?P0309ec@@80
WWA20`2OMD<0202PLdT0XGE80:=gBP2TN4T0Y7Q70:=hA@2QMT40X7E00`2PMT@20:5gA@<0XWQ6202R
MTD01P2YMdH0YgM60:MgAP2WNDL0YW]80:ElB080YGe9202PNdL80:9hAP080:EkB@2TNTP0XgU70:5g
A@2PMT@0WWA209ec@@2LLT0209UcA080V7930P2GLD8309I`@@0609=]@02BK3l0TF/n091Z?@2>J3/0
SFLj0P2<IST2091[@@0408iY?`2<Icd0RfHl08UT>P80Qf8h0`23GCH5089L=@80LeP[00T0LUL/079F
;P1aEBh0L5@_06mC;P1_DS00Kdh[06i=:P1/BbP00P1[BRL00`1/BbP0KTdZ06m>:`0206]=:`80JT`Z
0`1YBbT04@1XBRP0J50^06U?;P1ZD2d0KE4/06mA:`1aDBX0LU0Z079A:01iE2X0NUD[07]F;01mF2h0
P5/a089M<`23GS@0Q5le00D0R68e0`29HcH208aV=`0408eW>02>J3T0T6Xk095[?080TV`m00H0SVXj
08mY>P2?JCX0TVTk09=X>`2DJ3/209MX?0P0TfPk00<0TfTg099X=P2@IS@00P2?IC<01@2AIcD0TfTg
09AZ>02@ICP0TFHi0080TfPk00@0TVLj091U>02=HSD0S64d0P2>Id002@2=ISl0Rf@m08YS?029HS/0
R64j08MP>@2=JS@0RfPb08UV<00208QU;`0308YW<@2=JS@0Sf`f00<0T6Hd00<0TFLe099X=P2CJCL0
0P2CJCL3095W=@<0T6Hd0P2?IC<01@2CJ3/0TVLj091U>02?I3L0SV<f0080Sf@g00@0T6Dh095V>@2C
JCL0TVPf0`2AIcD00`2CJCL0U6Xh09I/>P02095/=`<0T6/f0`2?JSD00`2CJCL0U6Xh09E[>@0209I/
>P0309AZ>02BJ3H0TFLe0080U6Tl0P2CJ3/4099W>P0308mZ=P2>JCD0S6Lc0080RVDa00<0RfHb08aW
<`2=J3@00P2<ISL208]U=P@0RV@e2027Hc<208MR=@80R6<f0P29I3L208YU>00608UU<@2:IS80RVHb
08aX=02=JCD0SVXf0P2?JcL2095/=`<0T6/f0`2?JSD00`2DK3T0Tf/h08mZ=P0208eY=@0308a[=P2=
KSP0SVli0080Tflk0P2BKSX0=02AKCT0T6`h091/>02?JcL0RF/i08Y/>P2;KC/0S6hl08]]>`29JcT0
QfTg08IX=P21Ibh0PVD]085S;`1oGbh0O5X]07UC;01eCb/0LT`X069>:`1MBBH0Ed@S05=38P1C@R@0
D44R04Xl7`15=aX0B3`V04Lk9@14>BD0?cLT03/d8@0g<Ql0<c0O038_7P0^<Ah0;C0M02`_7P0[;Al0
:B/N02LY7P0V:1d09BHN02L[700V:Q`09BTK02<V6`0R9A`082<L01lQ700N81/301lR6@8082<J100Q
91/01P0O8QL082<H028U6P0T9a`09BPM02@W70808bHK00<08bHO028U7P0P8a`00P0N8AX00`0O8Q/0
82<L024T7@0301hQ60<07b8I0P0P8aX07P0M8Q/07bDK02@W7P0W:Ah0:RXN02`Z7@0/:Q/0;BXK03L_
600i<AX0?S@K048f7017>Ah0BS/N04/l7`1=?1h0ACXV044i900o=b@0>c@R03H`800`;Ah0;2XK02XX
6`0/:QD0;R`G03<^6P0h<Ah0>c<P03hc8@80@3<R0P0j=Al01P0h<al0=c8O03D_7`0c;Al0<R`N038/
80P0<B/M00H0<2XL02dZ6`0]:Ad0:bTM02PX7P0V9al202@W80<08B@M0P0P8a`501lR6`807R4J0P0M
81T201`O600P024Q8`0P82007alO01dM6`0M7QT07QlI020Q6@0Q8QX09B4F02PT6@0[9a`0:RHK02PT
6@0[91X0;bPN03</8P0k8A80EC/T071H<P20JCL0Rg8i099h?`2@MCh0Rfdk08a`B020IDL0JU@o050o
=`0h;B/0:BHQ02DV7P0S:A/802@W80P09BPQ00L08RDN02<V7`0U:2409bXS02P[900W:R<09BPQ0080
92LP00H082/U024Z9@0R;2@092/S02H/8P0Y;2<202X/8@0402/^7@0]<1l0;c8Q034d8`80<SDT0P0`
<b801P0i=200>SDQ03Xe8@0l=b<0?CPT03hi9@80?cXV00P0=CDM03He800i=b80?3LT03hg9`0o=BT0
?S@X040d:0P0Ac`V00H0CT0V04m19P1A@BL0E4<W05E49P1IARH205Y69@0H069:901WCBP0Je4^06e@
<01[C2l0JdT^06a:;`1_Bc<0GeDb05eC<01LCbd0F4/Y05M89`1HB2L0FTLW05]8:01NA2<0GdDT05m7
9@1PBBL0GTXW05]99@1JB2@0EdLS0`1EAb`205A6:`<0DdDZ01h0DD8[0512:01??bH0D3lU05<o901G
@RD0FTDV05i7:01WBR00JTdS06iA9`1bEB/0M5L]07=F;01aE2X0L5<Y07AG:`1`DbL0KU4W079E;@1l
GSP0PfE108IXA025IdD0PVHg08AX>@27Jc/0RVhn08ea?`2@MD02095f?`0X08U^@`26Jd00PfHl085T
>P26ISd0SVe409QeC@2MNU80Vge109j0A02RQ4P0YHM;0:J8C02TQTX0XH=709n1A@2TQTX0WX1409Qk
?`2ENch0UWi009=n?`2>NCX0Qg<d091dA02?Ld<0RgA208Ma?`22LCd0O6lj07U^>01gKSL0Nehd07aM
<@1kG300O5/^07mM;`23Gbl0QV0_08MQ<080SVD_01T0Rf8^08MN:P23FbP0OeTX07mK:`21GBd0P5h^
08UR8@2?IRP0TfX/09MZ;`2GJ300VVPc0:1]>02TL3h0[7<n0:ac?02/M3T0[WPh0;9m=`2gPcL0_8Tj
0;n<>`2eTD<0]Y940080]i=701l0]Y980;B?B02aS4H0/8]50;RC@`2hU4H0]iE;0;BFCP2aU580Zi5D
0:J=E02RS5<0WX]C09^7DP2FPU00TGaA08afC`29LU80QfmC08I^E026Hc/0R6Dm08UV?027ICP0Q68d
08=Q<@27ICD0S6/h095W;@2@IR`0SfD[0080SV@Z00H0SF<Y08iT:P2>I2X0SFT[091/;P2ELC<209Qd
=P1809Ib=02BKS00Sf/]09M/>@2EJSL0TfPe095V<`2@IC80Sf@a091U<P2AIS<0UG8b09Ib=02FM3D0
U7@g09=e>@2@LcT0SW4i08]a>02@J3L0SFLf08aX=P28J3D0QFXe08E/=P22KCH0Pfhg08Y_@02:KSl0
S6dn08m]?@2DKSd0VFlm09ea@02QLd40VGA009Mb?P2@K3P0QF@_07aM9`1jG2H0PV@^08M/=@2GMS40
UWDb09=a<P2@KCD0SFTe08UT=`27HSP0QV0i08IR;P27Hbl0R6@`08UU<@28I300QV8^08AP;022GRX0
P5XY07mI:01nF2T0O5HY07YC:01iDRT0N54X07M@:@1/BRD0KT`W075A:`1bE2h0LeL`0P1aF3002P1_
F2l0KUlh079P>01jICX0PFTk08Y/>P2@KCL0U6dd09E]<P2DLCT2099_=`0908i[<`2;J300R6D]08ER
:P24HBT0Pf0X07UT;`1hHbh0MV4/0080M5lZ01l0MF0[07MR;@1hHbh0LUdb06eG;P1WDBP0HT`U061:
9@1RBbT0ITl_06UB<P1^FBh0KeX_079K;`1dG2h0M5TZ071D901^D1h0JT`J07=D:01hFBd0OEh`07eN
;`1jG2X0NU`X07iP;023IBl0PelS08UU:@2BKS80VgLk0080Wg/o00X0W7Pl09Yf>P27KC80QV`a08AZ
<@21IRl0Of@_07aP;P1jGR`0NEd]0P1jHB/03P1iGb`0NEl^07QM;P1gG2l0MU/^07IK<01iGB/0NUh/
07aP;P1oHc40PFDc08AX=P26JSP0Qf/i202;Kcl308M[>`<0QVXj0P25JCT0201oIRh0OVD]07eT;01l
Hb/0OF@/07iU;@20Ibl0PFP`0P1jH2d0401kHBh0O68_07eS<01nI340OfDb081V<`2AKCT0TG0k09=b
?@2CM3h0T78l08U^=`23JS80OfH^07=M;P1_FBX206aE:@0406iG;@1^Ebh0JU8/06E=9`<0I4hW1@1S
CBH0201NBb<0GDXR05]98`1GAb<0E4@R05528@1?@R00CT4Q0P17?AX04015?1/0@cdM044l7P0o>ah0
?SXO03`k7`10=B40?c@P03hc8@0l<200>RhP03T]7`0g:al0=RXN02`U7`0W8Q`202@O6`0501lK600J
6AL05aLG01DG5P0E5QP0200G6AP801HH5a005ALF200F61L301@F5@<05ALF0P0F61L801DG5Q005QPG
200E5aH801LI608061PF0P0I6AL201XJ60D06a/I0P0L71X301dM6`807QdH100M71L201`K5PP07AdE
0P0O7aL01P0N7QH07AdE01hN5P0P81P08R8J02<S6`P07QhF200N8AX3024P6`<08R4L0`0S8Qd04@0P
8AT08B4I028R6P0U8Q/09b8L02XS7@0[8Qd0;2<N03@Q6P0c8QX0<B<J02lU6`0_9a`0;2PL02`Z7@0Z
:ad0:RHJ0080:RHK00<0:BDL02TT7P0X8al00P0X8b002`0Y8QX0:R<K02/T700/9Ad0:b@L02XS6`0X
8AT09b0H02XS6`0Y8QX09b0H00809QlG00<0:24I02XS6`0[91`01`0^91X00`0_9A/0=RXN03HZ7P06
03HZ7P80=RPK00@0=bXJ03P[6P0i;1/0>RdJ0P0k;aT03@15=280@c8P044`7P10;ad0?bhL040_7@12
<Al0@c8P04Lb7`18<b00B3<N04Pd7018=1/00P18=1T01019=QP0CCDM04de7@1==Ad204hf7P<0CcLO
1@1==al304hh8080CSTL0P1?>Qd0101@>ah0DC`O054l7`1B?B0205Q18P0405Po8@1I?R40FcdQ05/l
8080GC/P00H0FSdM05/n7P1K?Qh0G3lO05e0801N@B4205m28P80Gd4O00T0H48P06538@1SAB<0I4HT
06E79@1VB2H0G4@P05i68P1OAb<00`1QBBD205m78`04060o7P1R@B00I4<R06I59080J4LV0P1WARD2
06e4900406i59@1_ARH0L4LW07179`80LDPX0140LTTY07599@1aBBD0KTPS06]88P1XAR00IDDN06A4
7@1RAAd0IDLS06Q7901YB2D0JdTV06a89P1/AB@0Jd8R06Y18@0206i77P0306a67`1YAR00IdDP0080
ID@Q00D0HT@R0691801S@R40ITDT06Q79P0206U89`0706Q79P1WARD0Id<S06M38`1V@R80ID4Q06A0
800306<o7`0;06Y39P1V@B@0I3lR060m7`1N?Ah0G3dN05/n7P1L?al0H44R05m08@1M?Ql00P1K?1d0
201L?Ah0GChO05ho801M?Ql0GSlP05m08@1P@B80HD8S0`1R@b@01P1LABD0GD@U05e49@1OA2H0HD@V
06=49`80ID<W0P1UA2400`1VAB80IdHS06Q7900206Y99P0406]:9`1^BbD0KT/U06i;9@80Kd`V0`1`
CBL03`1`Cb`0KTdZ06a;:01[BRL0K4/X06i=:P1aD2d0LU4^07MC<`1fDS00ME4_07EA;@1eDR`0Me@/
07UF;00307YG;@<0NEH/0`1hEB/02@1lFBl0NeP^07]H;P1kF2h0OEX`07mL<P22GcD0Pf0f07YH:P02
07]I:`0307aJ;01mFbd0OU`^0080Oed_00P0OEX`07iK<@1oG380PEhd089O=@24HCL0QF8h08IS>@80
Qf8e0P28HcH208UT=`80RVDh0`2;ICH208aV=`@0SFLh0`2:ICP01@29I3L0Qf8e08AO<P21G2l0OeX]
0080NeP^03L0NUL]07QE:`1gE2X0MU<Y07EB:01dDBL0L50W06m?:01^CRL0K4`V06Y99P1XAbH0IdHW
06I59P1TABH0Hd@U0693901P@B80Gd0Q05dn7`1L?Ah0Fc`M05e49@1L@B<0Fd0R05`o8@1N?b80HClS
06E29P1V@bL0JdX[06Y9:P1ZBBP0JTTV06a<9P1^CRL0LE4Z079B:@1dDBT0ME8Z07IC:`1hEBd0NUL_
07aI<@1mFS80OU/c08EP<`26HC@0Qf<c08QT<P2:IS80RfPb08aY<`2=JS80Sf/k0080SVXj00<0SFTi
08aX>02<J3P01P2;IcL408aX>080RF@g0P28HcH03027HSD0QV4d08IQ=025H3<0PUd`089M<@21G300
P5/a07mI<P1oFC@0OUPd07eG<`P0N5D_00@0M5@U07EE9P1gEbP0NETZ0P1jFR/207UI:P0307eK:`1n
G2`0Oed]0080Oed]00<0OU`/07aJ:P1kFBT00P23GS4208AO<P0408EP<`26HC@0QV4d08MR=@<0Qf0e
00<0R64f08UR=`29HSL00P2:HcP808iR=@T0RV@e00X0RF<d08YT=@2;ICH0SFLh08iX>@2@JS/0TF/l
099/?@2CKcl0U7100P2ELD401`2DL400TVhn091/?02>JSX0TV`m09=]?P2DKSl00P2EKd001P2DKSl0
Tfdn099/?@2@K3`0TVhn09Ib@P80VGE500<0Ug=309A`@02BKSh00P2BKSh209=_?`0409A`@02ELD40
UW9209Ib@P<0UFi300<0U6e209=/@@2BJd000P2BJd000`2;ICH0S6Hg08aV=`0208eW>0<0SVPi0P2?
JcL0102>JSH0SFTe08eY=@2<J3@208]W<`0808iX@@2?JD80T6/o091[?P2@K3X0SV/e08aY<@2;J2h3
08aX>2_ooooo000Zooooo`0309eb?`2OM440XWM40080Y7U600<0XWM409md@@2MLSl00`2MLd4209id
@P<0WgE300P0Wg980:1dA`2RMTT0XgM80:=gAP2RMd@0X7E009md?`80WgE30`2PMT@30:5gA@P0XWI5
00H0ZWQ70:QhA`2XN4L0YgU70:EjA`2UO4P20:AlB0P0X7]7202RN4H0202TNTP0XgU70:9hAP2QMdD0
X7I409me@`2NM480WG=10`2ILd@00`2HLT<0Ug5209Ma@P0209I`@@0709E_@02DKT40Tfe0099/?`2A
Jch0T6Xm08iX>`0208eW>P0808mZ@02>JCl0SFPn08]V?029I3X0R6<i08IQ=`25H3H2081J<`<0OeTb
0`1nF34207AI;00907=H;@1bERh0L5@]06mC;P1^DRd0KU4_06m>:`1^CBX0K4/X0080JdXW00<0K4/X
06i=:P1_CR/00P1[CB/206Y<:P@0JD/Y0140Idl]06Q>;@1YCb`0K50[06i@:P1`D2T0LU0Z079A:01i
E2X0NUD[07aG;@1mF2h0P5/a085L<P23GS@0Q5le08IP<`0208MQ=00;08QR=@29HcH0RV@g08YT=`2;
ICP0RfDf08aV=`2=IcP0SVPi08mY>P2@JS/00P2AJc`01P2>JSX0SfTj08mY>P2BJC/0TfPk09AX>`80
UfPl202CJ3/0202CJCL0TVPf091V=02?IC<0T6Hd095W=@2CJCL0U6Xh0P2AIST2099W>P04095V>@2?
I3L0SF8e08aQ=080SFHm00@0S6Dl08]T>`2:HcX0RV<j0P29HST00`2;Ic<0RVHb08YV<P0208YV<P03
08]W<`2=JCD0SFTe00<0T6Hd00<0TFLe099X=P2BJ3H00P2CJCL7091V=006095W=@2CJ3/0TVLj091U
>02?I3L0SV<f0P2?I3L02P2@ICP0TFHi09=Y=`2BJ3H0TFLe091V=02AIcD0TVPf09AZ>02FK3X2095/
>0<0T6/g0`2?JSH0202CJCL0U6Xh09E[>@2FK3X0UF/i09AZ>02BJ3H0TFLe0P2DJC`209=X>`<0TVLj
00@0TFHi08mZ=P2>JCD0S6Lc0`2:IC40102;IS80S6Lc08aV=`2<ISL208]U=P<0RV@e00<0RF<d08MS
<`27Hc<01P27Hc<208MR=@80R6<f0P29I3L208YU>00608UU<@2:IS80RfLc08aX=02=JCD0SVXf0P2?
JcL408mZ=@@0T6/f00<0U6`i09=[>02?JSH00P2=JCD0102<JcH0SFhh08i_>@2CKc/2099^>P80TFdi
0P2@K3P00`2?JcL0RF/i08Y/>P0308]]>`0[08U[>@27JCL0QFLe08=V;P22I2h0PF<_07mO<01kFRl0
Me@^079>:P1`C2X0HDdZ05e99P1GA2<0Dd<R05=2901@@B@0BS`O04Dg7016>R@0ACTS048g8`0n=R<0
>S<P03Ha7P0b;ah0<BhM02ha7P0]<1d0;2lN02X/7P0Y:ah09bTN02HX7@0U9Qh09b/L02HZ700U:A/0
8bHK028U700P8a`07b4L01hP6`0301lR6@8082<J100Q91/02`0O8QL082<H028U6P0T9a`09BPM02@W
700S9Q/08RDJ02<V7`0R9Ah082<L00807R4J00<07b8K020S700Q91d00`0N8AP201lR6@<082<J01h0
7R@J024T6`0T9a`0:2XM02//7P0]:a`0;R/L02dZ6@0g;aP0>C4J03le7013=ad0B3XO04Xk7P1;?1l0
C3/M04@i9@11>B@0?SHS03Xc8@0e;al0<2dN02`Z6`0Z:1/0;B/F02l]600d;a/0>34N03/c800n<b42
03lb8@0803Xe7`0i=1h0>3<O03Ha7P0e;al0<bdO038/7P0a:al8034[7@0602lY6`0]:Q/0;2PL02/Y
7@0X:1h09RLO0P0T9b02024T7@<082<L1@0O8Q/201hQ6P807B0I0P0L7aP0800P82007alO01hN700M
7QT07AhH01hO6@0P8AT08B8J02PT6@0[9a`0<2TO02lY7@0]9a/0;bLL03@/7`0i<B@0Bc0O0657;P1i
H3P0Q6di08ac>P2AN3l0Sg@o08Q/?027KDP0MUm005e8=`15=2d0<RPV02TV8@0V:B009R`N200T9b08
02DX8@03028U7P0S9Ql09BPQ00<09bXS0`0U:242024Z9@0D02@[900U;2@09bdS02T/8@0[;B80:bdP
02l`800`<B40<S<S03<d900d=BD0<c@T038c8`0a<R80>C@P03Xe8@0k=R80?3LS03dh900n>BD203lj
9P80=cHQ00H0>3DR03Xe8P0l=BD0?SDV03le:@12=RX804Pl9P0604m19`1?@BH0DD4W05A39`1EA2H0
FDHV0P1KAbH06@1SBB@0IddX06]A;P1]D300JTd_06Q9;@1ZBbl0KT`c05iD<@1LDRl0Fdh/05Y;:P1I
BBP0FTLW05]8:01LAbP0GdDT06169@1QBBL0HDXX05m;:01MBbL0FdTU05Q8901FB2d00P1EAb`04@1D
AR/0DT@Y0553:01A@bP0D48W04m19`1@@2L0D40V05919@1F@bD0FD@U05i7:01OB2P0JD`R06a?9@1`
DbT0M5L]0080MEP^01d0LeH/075D:P1fFBd0LUDY071C:@1dEbl0Nedg089T@023ID40PVA2089W>P25
JS/0RFho08ec@P2?MD80T7M1091g?`2?MSh0RG5508Q]@P24JCh0PfHl08QX?`2?KTD0V7E=09ikD`2M
OTD0Wh170::3BP020:B5C00K0:62B@2NOdH0W7e40:21B02JOD<0UWTo09=i?P2DO400TG/o08ah>`27
LcH0Sg=408eb@`28L400Pfdl07aZ>01hJ3D0LVHb071T<01kGS@0OEhb07aM<@1mG2l0P5h`08AP<027
HC00RF<b0080S6<_03P0RV4]08IN:`23FbP0P5XY089L:`23Gbl0QF4a08eT902AJ2X0V6`_09Y/<@2K
JS00WFXc0:9_>02WLS`0/WXm0;9l?02cOS`0]H0j0;R7>`2mS3d0`I4m0<BD?`2eU4L0]YE80;NEB`2f
U4`0]I=<0;:@B@2`SDT0[X]70:n?AP2]SdL0[8m;0:^?CP2USDl0X8YA09b7DP2IQE80VhI?09R3CP2D
OTd0SgQ<08YbC027Kdd0QVe?08E[D025HSX0Qf@j08UV?027ICP0Q68d08AR<P28Ic@0SF`i091X;@80
TFT^00<0TVX_09=[<02BJRl00P2BJRl00`2AKC40Tflc09Ib=P0209Mc=`0709Ea=@2CKc<0TFda09M^
>P2EK3P0TfXf095X=002091W<`80TFPd00P0U70b09Ea<`2ELcH0Tg<f095c=`2>LCL0S6lg08U_=P80
S6He0200RVTf08UY=P26JcH0QF`f089[=@21K3D0Qf/l08UZ?02:JS/0S6Xj095[>P2FKS/0VW0n09eb
?`2IM400U6lk08UU<@1oGRT0Ne`V081R;02;KCL0TGHo09Qg=02GMCD0U78c095^=P2>JSH0RfHi08UT
>028HcT0Qf<_08QT<080RFDa00@0R6@`08IR;P24H2`0Pel[0P24GRd05`23GBh0PE/^07mH;@1nEbh0
OEH]07aE;P1^C2L0L4hY075A:`1bE2h0LUH_071G;`1_ERh0KEH]06eK<`1`GC<0Mf8g081U=P27JCL0
RfXe08mZ<`2BJc80T70g0080Sflf00T0SFdd08][<P28J2l0QFD/089R:@21HBP0NV<_07QQ;@1gH2`0
0P1eGRX0:`1fGb/0Mf0/07QQ;@1aG340KEP]06MA:01SCBH0HD/V06=<:P1WD2h0JE8b06aG;01^FBh0
LU/_07AL;P1eFR/0LeLW075C8@1^D1h0MUL[07]L;P1nGc40OUl`07]M:`1kGBT0OV0Z089T;P2?Jbl0
Tflc09Qd>02LN3`0WWXn09ah?02IMCT0Ug<g08M]<P26K340Q6Xa089W<01oI2l0OF4_07]O;@1jGRh0
0P1iH2X03P1hGR/0Med/07ML;@1fFbh0MEX]07EJ;`1iGB/0NUh/07aP;P1oHc40PVHd08AX=P26JSP0
Qf/i202:KS`308M[>@<0QVXh0P25JCL00`22JC40PFP`07mV;P0207iU;@0407mV;P20Ibl0PFP`07]Q
;P<0O68_0P1mHc0207iT<@0@08iZ=P2?KST0Tg8m09Ae?`2BM3h0Rg0i08A[<`20Ibl0M5h]071J:`1/
ERL0K5DY06eF;01]ERd0JE4[06E=9`<0I4hW101SCBH03`1RC2D0GT/S05e:8P1KBB<0EdLS05E58`1B
@b80Cd8P04i18@1:?A/0AcdJ04Ll7015?1d0@S/N040k7P0203hj7`0:044f8010=B40?S<O03db800k
;al0>BdO03P/800g:al0:b@N02LR708091lK00<07a`G01/J5P0H61H02P0G6AP801HH5a005ALF200F
61L301@F5@<05ALF0P0F61L801DG5Q005QPG200E5aH801LI608061PF0P0I6AL201XJ60D06a/I0P0L
71X301dM6`@07QdH100M71L801dM5@03020P600O7aL07QhF00807QhF00<0820H028R6P0S8a/0200O
7aL801hQ6P<08B0K100R8A`202<R7@08020Q6@0Q8AT08R8J02DR6`0W8Q`0:R<M02/R7@0/8ah203@S
6`04038T6`0_9A/0;RHK02`X7080:bTL01<0:bLK02XV6P0Z9Q/0:RHM02TT7P0Y9200:2<O02PS800Y
8QX0:R<K02/T700/9Ad0:b@L02XS6`0X8AT09b0H02XS6`0Y8QX0:24I00809b0H00@0:24I02XS6`0[
91`0;B<I100^91X302lU6`P0=RXN00H0=RPK03LY700g:QX0>2/J03T/6`0j;AX203/_6@0304@c8@13
<R00@C0N0080@2lM00P0@C0N048a7`13<R00B3<P04Td8@19=1l0BCDM04Te7080BSHK00<0BSLI04de
7@1==Ad00P1>=Qh304lg7`04050h801==al0CCLO04dg7`D0CSPP0`1?>Qd00`1@>ah0DC`O054l7`02
058m8080Ed0Q00@0F3lQ05Tn8@1K?B40G3dQ0P1N?24205`o7`0305e0801N@B40Gd8R0080H4<S00H0
HD@T0612801Q@b40HD<Q06948P1SAB<206A6900=06E79@1OAB80H4HS06989@1SBBH0HTPU0657901P
AR<0GdDR06507`1S@R40ID@S06M69@0206Q79P80IdHU0P1]A2@01@1^ABD0KdHV07179`1`AbL0LDPX
0080LTTY0P1aBBD03P1_BB@0JdPR06U78@1VAQl0IDDN06957@1TAR80IdHS06U89@1[BBH0K4PV06e6
9@1]A2@0K4<S0P1^Aah02@1/AQl0JDHP06M5801VAB80ID@Q06=58`1R@B00I4<R06I5900306Q79P80
IdHU00@0Id<S06I28P1V@R80ID4Q0P1T@20206<o7`0@06Q1901U@2<0HchQ060m7`1N?Ah0G3dN05`o
7`1M@200HD8S06118P1N?b00G3dN05/l7@1L?Ah0GChO05ho8080GChO00<0GSlP05m08@1P@B800P1Q
@R<01P1R@b@0GTDV05i59P1OA2H0HTDW06=49`80IT@X00L0Id@X06I58P1VAB80IdHS06Q7901YB2D0
JTTV0080JdXW0`1^BbD206m<9P<0L4dW0100K4/X06]:9`1ZBBH0JTTV06]:9`1/BbP0KD`Y06i=:P1e
DC40ME4_07A@;P1dD2`0ME8/07MD;01iER`0NeP^0`1jEbd207UF;0<0N5D[00P0O5T_07]H;P1kF2h0
NeP^07aI;`1oG380PEhd08=P=P80O5X/0`1mFbd307iL;P0807eJ<01nFc40Oe`b085N=022GcD0Q64g
08ER>026HcT208MR=@80R6<f0P29I3L208YU>080RfDf0`2<ISL408eW>0@0RVDh00X0Qf8e08AO<P21
G2l0P5/^07aI;`1kF2h0NUL]07UF;01hEB/0MU<Y0P1eDRP01P1_CbH0KdlX06e=9P1[BbD0JDPU06Q7
9P80ITDV0P1TABH09`1R@b@0HD8S05m08@1N?b00GChO05`m7P1MA2D0GD8T05a18`1M@280GSlR0690
901U@RH0IT<W06]::`1ZBBX0JTTX06Y99P1/C2H0KThW075A:P1bDRT0M54Y07EB:P1fDb/0N5D]07YG
;`1lFC40OEXb07iK<`24Gc80QF0c08IR<P27Hc<0RFDc08YV<P2;J380S6Tc08iZ>P0208eY>@80S6Ph
0P2;IcL408YV=PD0RfLg0`29I3L00`28HcH0Qf8e08MR=@0208IQ=080Peha00<0PUda085L<P20FS<0
0P1oFC@00`1nF3@0NEH`07UF<00607UF<00507EE9P1gEbP0NETZ07]K;01lG2d00P1kFb`0101jFR/0
OU`/07mM;@20GRh2085O;`03081N;P1oGBd0OU`/00<0Q5lb00<0QF0c08IQ=026HC@00P27HSD208QQ
=PH0RF8g202=HSD:08YT=@0508]U=P2<ISL0SFLh08mY>P2@JS/00P2BK3d00`2BKSh0Tflo09A`@002
09Ea@@0609=_?`2AKCd0T6`l099/?@2CKCh0UFm00P2FL4401P2EKd00Tfdn099/?@2BKSh0U71009Mc
@`80VGE500<0Ug=309=_?`2AKCd00P2CKcl309A`@0<0UG5100<0UVm409E^@`2EKT<00P2DKD8209=/
@@03099[@02>J3T0SVPi0080SVPi102?JCX308m[=`80SVXf0`2=JCD0202?JD80T6]1095/@02AK3l0
TFdk08m[=`2=JS80S6Ta0`28I3@[ooooo`00:_ooool00`2MLSl0WgA10:9gA0020:=hA@030:9gA02O
M440WG8o00<0WG=10P2NM48309me@`0809iaA`2OLdH0X7A70:5eAP2QMD@0X7E209md?`2NLch309id
@P80WgE30`2PMT@80:9fA@080:]iB02YNDP0ZGU80:MiA`2UNTL0Y7]70:=kA`2RNTH80:5lB0X0XWQ6
0P2QMdD20:1fA080WgE30P2JM4D0102ILd@0V79309Ma@P2GLD8209I`@@0909E_@02EKd80UFm209A^
@@2BK3l0TF/n091Z?@2?JC`0SVPk0080SFPn00@0RfHl08UT>P27HSP0QV4g0P24GcD307eG<080O5H_
0`1kEBh02`1fFBd0MEP/07AG;@1cERh0LE<]06mA;@1^D2`0KDl]06m>:`1^CBX0KD`Y0080K4/X00<0
KD`Y06i=:P1_CR/00`1[CB/206Y<:P<0JD/Y00P0ITh/06M=;01XCR/0JThY06a>:01`D2T0LU0Z079A
:080NUD[00@0O5L]07iI;`1oFS00PE`b0P23GS@02024GS40QElb08IP<`28HSD0RV@g08]U>02=IcX0
SVPk0P2;ICH0102<ISL0SFLh08iX>@2>J3T208mY>P0608iZ>P2?JCX0SfTj099Y>`2CJ3/0U6Pk0P2G
J3`809=X>`0309=Y=`2BJ3H0TFLe0080T6Hd00<0TFLe099X=P2CJCL00P2AIST01P2BIcX0TFHi091U
>02?I3L0SF8e08aQ=0L0Rf@k00@0RV<j08UU<@29IC40RfLc102<J3@0102;Ic<0T6Hd091V=02@IS@2
095W=@<0TVPf0P2>I380102?IC<0T6Hd095W=@2AIcD2099X=P0509=X>`2BIcX0T6Dh08mT=`2>HcH0
0P2?I3L02P2@ICP0TFHi09=Y=`2BJ3H0TFLe091V=02AIcD0TVPf09AZ>02EJcT2095/>0<0T6/g0`2?
JSH00`2CJCL0U6Xh09E[>@0209E[>@0309=Y=`2BJ3H0T6Hd00@0TfPk0P2BIcX02P2AIST0T6Dh08iY
=@2=J3@0RfHb08YU<@29I300RVDa08]V<P2<Ic<308]U=P80RV@e0`29Hc@808MS<`80Qf8e0P28HcH2
08UT=`80RVDh0P2:IS800`2;Ic<0S6Pd08eY=@0208iZ=P0508m[=`2=J3<0SFPc08iY=02?JSD00P2@
JcH2095/=`0309A/>@2CJcP0T6/g0080SVXf00<0SF`g08e^>02>KcT00P2BKSX2095]>@@0T6`h0P2:
K3X208]]>`0/08Y/>P28JSP0QVPf08EW=@23IBl0PV@^081R<01mGS00NEX^07AD;@1_CR/0KD`Y061<
:`1KAbH0ED8R05918`1B@BD0CclU04Tk8015=ad0A3PR04<g8@10=B40>c<P03L`7@0d;a`0<2dL02l/
6`0]<1d0;2lL02/^7@0Z;1h0:2XM02LY7P0V:1d09RLO02HZ6`0U:A/092PJ02<V6`0R9A`08B@M020R
7@0O8A`301lR6@8082<J100Q91/02`0P8aP08B@I02<V6`0T9a`09BPM02@W700S9Q/08RDJ02<V7`0R
9Ah082<L00807R4J00<07b8K020S700Q91d00P0N8AP201lR6@<082<J00h08B@K020S6P0R9AX09RPM
02XZ7P0^;1l0<2dN030]700a:a/0>30I03Xb6`10=Qd0A3PN04Tk8080BS/N0140BcXL04<h900o=b80
?CDR03Pa7`0d;Qh0;b`M02`Z6`0[:A`0;R`G030^6@0e<1`0>34N03/c800n<b40?c8Q03ha800203Pc
7@0603Lb7P0f<Ah0=2hN03<]7`0b;1h0<B/O200a:ad02@0_:A/0;BXK02`X700Z:1`09bLM02DV7P0T
9b008bHO024T7@03020S70807b8K0P0N8AX201lR6`807R4J0P0M81T201`O600P01lO7`0N7Q`07AdK
01`M600M7QP07QlG020R5`0Q8aP0:bLL030Y7`0b;200<RXM038Y6P0f:QX0?C4Q04@g9P1PA2h0LULi
08=Z@@2:Lcl0SgHn099i@`2=LT<0QFXo07QT@@1UDCH0BCLY03@W8@0/9280:BPT02T/8`0W;Al802@W
80P09RTR00<08bHO02@W800U:2400`0W:R<302HY8P0:028/900T:b@09B`T02L]8`0Z;B80;2hQ02d]
8@0^;b40<c@T03@e9@<0=CHV00<0=3DU038c8`0a<R800P0j=B400`0k=R80?3LS03dh900203hi9@09
03lj9P0i>2@0>3LS03Ld8@0h<b00>S<Q03he9011>2T0ACT[00P0BCdU01H0D48X05129`1B@RP0E4<W
05E49P1IARH0FdLV05a89`1SBB@0IddX06]A;P1[DC00JD`^06M9;@1XBRh0JT`b05iA;`1MD2h0G4d/
05];:P1IBBP0FdPX0P1LAbP09@1QAbH0HTPW06=;:@1SC2X0HDdZ05m=:@1MBbL0FTXV05M7;@1FAR`0
EDD[05=3:@1B@RP0D40V04lo9@1>?R@0C3`S04hn901B@BL0F4@Y05]6:@1OB2T0H4TY0699:P1/CbD0
Ke8X07=F;01fFBl0N5/a07MJ<01eF2h0LeH/07QK;`1fFBd0MEP^07MJ<P1kGCL00P1nH3`04`1mGcd0
PFHk08EZ?@2:Kd80SW=4091fA@2@MT<0SG@n08ac?@28LDD0QVi2089Z?P22Ic`0QFPn08e]A02EM4/0
VWU@09j1B@2OPTX00P2PPd/0702OPTX0Vgi609Qk@`2EN400V7]309Eh@02@MSd0SWDl08eg?@2<N3d0
R7Dj08Eb=`2:LT@0R71208=]?P1nJCX0MfDe075Q<01^GRd0JU`[07aO=@1nGc<0OEhb07mN<@21Gc40
QV8b08US<P2;IC@208YR;`0G08QP;@23GRX0PUdY089M:@25H2`0R68a08YT<`2BJBT0V6`]09a`<@2N
L380X6ld0:9`=@2WLcT0ZgLm0;Z4>P2jQSX0_8Pl0;j=?P31TT00a9M20<FLA037WT@00P2hV4l08P2g
UTl0]YE@0;BCD02aSdl0[he=0:f;C02RRTX0XXY<09n9C@2LQdh0V8A?09>1C`2?Odh0SWe?09QoB@2F
O4T0TWQ708ebA@2:KTH0Qf]608IYA`26JDT0QF0d08QS=`2:ICP0RFDe08IR<027Hbl0S6Pd095^>02A
JBh0Tf/`09I^<`2ILCH209]c>00409Yb=`2ILCH0V7@h09Qd>080Ug<g00P0UW8f09Ea=@2DL3@0U70d
09Q_>`2GKSX0UF`h09=Z=P80TVTe02X0TfXf09A[=`2BKS00Tflc09=a=02ALCH0Sg0g08a_=`2:K3H0
QV/d08QT=028ISH0RVPh08YZ>@29JcT0QVXh08=Y=P21Ic@0Q6Dg08ET=`26I3H0R6Hf08eW=P2AK3P0
UVhk09Ya?@2IM400T6/g08AP;01lFbH0OUlY08QZ=02DMT00VGi709Ug=`2HMSL0UW@g09=`>02@K3P0
SVXj08aW>P2;ISX208UU<@0608YV<P29IC40R6@`08MS;`25HBd0Q60/0P28I3805`27Hc<0QF0c08AO
<`23GS@0PUdc085K=01bD2X0Le4[07=C;01bEBd0LED]06iE;01]E2/0Je@Z06YG;@1^FBh0Le``07YO
<022I380QfHa08YW<@2<Ic00S6/e0080SF`f00T0SVdg08e/=P2;JS@0QfH`08=R;021H2X0Nf4^07YP
;@1iGb`00`1gGBX207QN:`0H071I;@1]ER`0JE8X06E>9@1TC2H0IThZ06Q@;P1[Dc40JUDZ06aG;01`
FBd0Le/]07IK;01fFRX0MUPV07AF901iFR`0O5d_07iO<01nH2h0OEl[07iP:P21Hbd0QFP`0P2JN3/0
3P2KNC`0VWPk09Ug>P2GMCP0U78e099`<`27KC80QV`a08AZ<@22Ic00Of@_07eQ;`1lH2h0Nel_0P1h
GbT03@1gGBX0MU`[07EJ:`1dFB`0LeP[07=H;@1iGB/0NUh/07aP;P1oHc40PVHd08EY=`27JcT02@28
K3X308M[>@<0QVXh0P25JCL01@26KCD0Q6/c089Y<@20Ibl0OfH^0080P6L_00@0PFP`07iT<@1nI340
OV@a0P1mHc0307aR;`0A08YV<P2<JcH0Tg8m09Ig@@2EMd40SW<l08I]=@22JC40Mf4_079L:`1]EbH0
K5HW06eF:P1/EB/0J54X06E>9@1UCbP00`1TCRL06P1SCBH0HT`U069<9@1RC2D0GT/S05e:8P1KBB<0
EdLS05E58`1B@b80D4<Q04m28P1;?Q`0BSdK04Pm7@16?Ah0@c`O044l7`10>R00?c/P044f8010=Al0
?c@P03db800k<1h0>RhN0P0h;1h02@0[91`09b<J02@O6@0T7aT081dH01`K5`0J6QP06A/H01TK6P08
01LI60P05QPG400E5aH801HH5`<051HE0`0E5aH201HH5`P05ALF400F61L801DG5PP05aTH0P0H61H2
01TI5`806QXH1@0K6aT201`L6P<07AdK200N7AP801hN5P03024Q6@0P81P07alG00807QhF00<0820H
028R6P0S8a/0200O7aL801lP6P8081lJ0`0Q81/3028Q700902<R7@0P8AT08B4I028R6P0U8Q/09b8L
02XS7@0[8Qd0;2<N0080<bDL00`0<RDL02lU6`0^9Q/0;BLK02/W6`0Z9QX0;RPJ02dW6@0]9a/0;BHL
02`U7@0/9Al202/S800;02XS6`0[91`0;2DM02dV7P0/9Ad0:b@L02TR6P0X8AT0:b@L02XS6`0Y8QX0
0P0X8AT00`0Y8QX0:R<K02/T700202dS6@80;R@J0P0_9A/2030V70P0=RXN0P0g:A`0100h:a/0>B`K
03X]700j;AX203/_6@0404<b8012<Al0@C0N040_7@80@C0N00L0@S4O04<b801:=B80BSDR04Xe801;
=al0BcLN0080C3PM00@0C3TK04hf7P1>=Qh0CSHN0P1?=al3050h8080CcLO0P1@>202054i8@80DSXR
00@0DSXN05<k7`1C>al0Dc/O0`1D?2001`1E?B40ESlP05Ho801H?b40FChQ05`n8P1N?b<00P1Q?b@2
05i18@0305m28P1P@b<0HD@T0080HTDU00<0HdHV06=58`1SAB<01P1TAR@206A79@0;06E89P1VBBL0
IDPV06=6901QA280Gd8P0691801T@b80ITDT06Q79P1YB2L00P1XAbH01@1WARD0K4DT06e69@1]ARD0
KTLV0080KdPW0140L4TX075::@1aBRT0LTXV07599@1_BB@0K4TS06Y88P1WAb00ITHO06A77`1SAB40
IdHS06Q7901[BBH0KDTW06m89`0206m69P80KdPO00<0KDLP06Y78@1XAR400P1VAB80101SAB<0Hd8Q
06A38P1VAB@206Q79P0306M69@1VAB@0ID@S0080ID4Q00<0IT8R06E18@1U@B400P1T@2003@1S?al0
Id0S06@o8P1R?B00H3dO05ln7`1N?b00GT4Q05m28P1TABH0HT<T06118P1N?b000P1L?Ah505dn7`0;
05ho801O@240H44R06528`1R@b@0GdLU06169@1QAbH0HdHV06A59P1WARL00P1XABL206M68`0306Q7
901YB2D0JTTV0080JdXW00@0K4/X06m<9P1_C2H0Kd`V0P1`CBL3075>:00506Q7901YB2D0JTTV06]:
9`1/BbP00P1[BRL02P1ZBBH0Ldl_079>;01bCR`0Ldl[07AA:`1gE2`0NUL]07aI;`1kF2h307YG;@80
NEH/0P1hEB/207]H;P0607YG;@1kF2h0O5T_07mL<P21GS@0Pf0f0`1oGBl307iL;P80OE/]00P0OU/a
07mL<P20GC<0PEhd089O=@23H3H0Q64g08ER>080Qf8e0P28HcH208UT=`80RVDh00@0RfDf08aV=`2<
ISL0S6Hg0`2=IcP208iX>@<0RfHi00D0RVDh08UT=`26HC@0Peha085L;`0207eJ<00D07aI;`1jEbd0
NEH/07QE:`1gE2X0MU<Y06m?9P1^CRL0KDdV06];9@1YB2D0IdHU06I59P1UA2D0IDHW06A59P1SA2D0
HT<T06118P1O@24205ho800H05e58`1NA2<0GD<R05m28P1P@B80Hd8S06I39@1WA2H0JdX[06Y9:P1Z
BBP0JTTV06a<9P1^CRL0LE4Z079B:@1dDBT0ME8Z07MD;01hEBd0NUL_07aI<@1mFS80OU/c0P23GS80
1P24Gc80QV8b08MS<@29IC40RVHb08YW<@80S6Ph0`2;IcL808YV=P<0RFDe1029I3L208QS=P80Qf8e
0P24H3001023GS40PUda089M<`21Fc@2081J=@P0NUL_00@0N5HX07YH:P1lFR`0OU`^0P1oGBl01P1n
G2h0OE/]085M;@23Gbl0QF4a08IR<P80Qf<c00<0QV8b08EQ<@25H3<00`26HC@308MR=@0308QS=P2;
ICP0RfDh00<0RV@g0`29HcH808mT=`T0RfDf00/0S6Hg08eW>02>J3T0SfTj091Z>`2AJc`0TV`m09=]
?P2AKCd0TVhn09A`@00309Ea@@0509A`@02CKcl0Tfdn09A^?`2EKd000P2FL4402`2EKd00U6ho09=]
?P2ELD40UW9209QdA02IMDD0V7A409Ib@P2BKSh0T6`l0080UW920`2ELD4309A`@080UW130P2EKd84
09A^@@P0TF/l102?JcL4091/>008091[?`2AK400TVe009=_?`2BKS`0TFdi08m[=`2>JcD308EQ<B_o
oooo000Zooooo`0309ic@02OM440XGI30080XWM400<0XGI309md@@2NLd000`2MLd4209id@P<0WgE3
00H0WW5709ibA@2OLdH0Wg=409mc@P2OM44209ic?P80WG=10P2NM48309me@`030:1fA02RMTD0XWI5
00H0XWI500H0[7Y90:UiB02YNDP0Z7Y80:EjA`2SNTH20:9jAPP0XGa8202RN4H40:5gA@@0X7I400@0
W7I709]eAP2JM4D0VG=40P2HLT<00`2FL440UFm009E_@00209I`@`0>09E_@P2DKT40TV`o095[?P2@
JSd0SfTl08aW?@2;IS`0RVDk08QS>@26HCL0Q5le08=N=022GC<207mI<P0407iH<@1mEc00OEL`07aF
;`80NeD^0P1hFBd01P1fERd0M5@]079B;01`Cb`0Kdh[06i=;0<0KTdZ0P1]C2T306i=:P80K4h/0P1[
CB/206Y<:P80JD/Y01P0ITh/06M=;01WCBX0JDdX06a>:01`D2T0Le4[07AC:P1jEB/0NeH/07aG;@1n
FBl0OeX`085L<P22GC<0Pehd08=M<024GS40QElb08QR=@2;ICP0SFLj08mY?02@JSd208]U=P80S6Hg
0P2=IcP208iX>@0608iZ>P2?JCX0SfTj099Y>`2CJ3/0U6Pk0P2GJ3`809=X>`0309=Y=`2BJ3H0TVPf
00D0TFLe0`2AIST01@2@ICP0Sf@g08iS=P2=HSD0S64d00<0RV<h0`2;I3T208aU>P0308MS<@29IC<0
S6Pf0080SVXh00<0SFTg08]W=@29IC<0102@IS@4095W=@80SF<a00/0SV@b091V=02AIcD0TVPf09=Y
=`2DJSP0TfPk099W>P2@ICP0Sf@g08iS=P0208mT=`04091U>02AIST0TVPf095W=@<0T6Hd00<0TVPf
09AZ>02EJcT00P2AJcX3091Z>@<0SfTh00<0TVPf09=Y=`2DJSP00P2EJcT00`2CJCL0TFLe091V=002
099W>P<0TfPk00H0TVLj091U>02?I3L0SVTe08eX=02;IS8208UT<00308YU<@2;IS80S6Lc0080RfDf
0`2:I3D308US=0P0Qf<c0P27HSD208QS=P80RF@g0P2:ICP308]W<`0308aX=02=JCD0SFTe0080SVXf
00H0RfHa08aW<P2=J3<0SVTd08mZ=@2AK3L2099]>080Tf/h00@0TF`h08m[=`2?JcL0SVdh0P2=KSP2
095]>@H0T6`h00P0RV`j08]]>`2;KC/0Rfdk08Y/>P27JCL0QFLe08=U<`80Pf<`02@0P64b07eN<01f
FBl0L5@]06]>;01XBbT0GTTZ05Y59P1D@B<0DD0T05509P1??bD0BC/Q04Dg7@12=R00@CDO03hc7`0i
<Ah0=BhK038]6P0^:aX0;BXI02`_700[;Q/0:RdL02T[7@0X:Qd09bTN02HX7@0V9al09BTJ02DY6`0T
:1X08bHK028U700Q91d2020R7@<07b8I0P0P8aX4024T6`03020S600Q91T08bHK008092LL00H08bHK
028U6P0Q91T08bHO028U7P0P8a`201hQ6P0301lR6`0P8a`08B@M00<07b8I0`0P8aX2024T6`0U02<U
6P0T9QT0:BTM02h/7`0a;Ql0=2hN03@_700e;Q`0>C4J03/c7011=ah0ASXP04Xl8@1:>ah0BCXM04Th
6P11=R80?SHQ03/c800f;ad0<bdM02l/7@0]:a`0;B/N030^6@0b<1/0=S4M03Tb7`0k<b00?S<Q03ha
800m<1l0=c8L03Ha6`0f<Ad0=C0M03<]7@02038/7P03034[7`0a:ad0<B/M00H0<B/M00H0;bTK02`Y
6P0/:1`0:RPL02LW7@0U9Qh202<V7`<082<L0P0O8Q/301hQ6P807b8K0P0N8AX201dP6@8071lH0200
7AdK01dN6@0L7AP071dG01dN5P0O8AH08R@G02<U600[9a`0;bTM038Z7@0b:AX0=RTH03h]6`17=B40
CcdW07=D>021Hd40S754091g@@2@NT40TGY808UbAP1oId40H58e04ho:P0g:al0:b4O02/U9`0[:bT0
:2/R028X6PP092LP200V:B80100T9b009BPQ02DX8@0V:B8502LZ8`0802@[8`0U;2@09bdS02X]8P0/
;R40;RhR034_8P0b<2<303Tg:00503Pf9`0g=BH0=S@U03Dc900d<R<00`0k=R800`0l=b<0?CPT03dh
900203hi9@0803/i:P0h=RL0=S<R03La8@0i<R00?SDT04<k:018?B/804do9@0F0553:@1A@bP0DT8X
05=29P1EA2H0FDHV05a89`1MBBP0IDTT06U=:01[DBh0JU0_06I=;P1SBR`0Hd`]06E=<@1KCR`0G4d/
05a<:`1KBbX0G4TY05a7:080GTLX00h0HdTX06A::@1TC2X0I4d[069>:`1PCRX0GddY05a<:01HAbd0
EdH/05I5:`1D@bT0DD0V04ln9080CC`R0100C3/Q04ln8P1F@RL0G4LZ069;;01TBb`0IDd[06E;:P1_
DRP0LUD[07II;`1iG380NUdc07UL<P1gFS00MEP^0P1jGC405P1iG380NUde07]M=`1kGCT0NE/g07QJ
>01jHSH0OFDi08=[?@28L480RW9208Qa?`25KSX0Pf`h08A]@@21JSh0OVHj07aT>020ICX0QVTo08i^
A@2BLTT309^0B`0F09YoBP2GO4L0TgQ308md?`2=LSd0SW<n08aa?02:LC/0Qg0j08Ia>P25LSX0Pg0h
081_=`24KSl0PV`m07mZ>`1lIcP0N6<d07=Q<@1`GRh0Ked]07eP=P80OUlc00D0P5lb089P<P27Hc<0
RfDd08eW=P0208IR<P0E08AP<024GRd0Ped/08IN:`2:HRl0SfHb099Y=@2IKBh0WW0b0:=e=`2VMSH0
YgHd0:Uf=@2`NcT0]7lm0;j<=@30SST0`I4l0<>G@034Vd<0a9m60080aJ5902@0]iYD0;JIE@2dUe<0
/YEC0:nAD@2/SU00ZXa@0:R:CP2JRE<0V8MA09F4D02BP4h0SWe?08akC`2:NDh0R7U>09AiA02BMd80
SW9008]_?`28Jcl0QVTo08IY@@25J400QV0a08US=02;IC@0RfHb08UT;`2:IC00T6/d09E`>@2CK340
UVld09Yc>02NMc`20:5j?`0M0:1i?P2ON3d0WWY009ah?P2HM3X0UW8h09A`=P2ELCL0UW8h09Mc>@2H
L3`0Uflk09E]>@2CJcL0TVXf09=[=`2DK3P0UFdi095]<@2BKS80TFhd08m_=P2=KSL0RV`f08MY=@24
JC@0Pf<d08EU=P28J3T00P29JS/00`27J3T0PVHf081T=002089P<`0>089P<P26HS80RFDc08iY=@2A
K3P0U6lj09Mb?P2?JSH0QV8^085P:`25IS00SFli09Af@02ENT<209Ug>P0609Md>P2ELSX0Tflk095]
>`2?Jc/0SVXj0P2<J3@02`2;Ic<0RVHb08UU<@27Hbl0QV8^08EQ;@27IS<0QVDb08IT=025HcD0Q68e
0080PUle0180PEhf07MF;@1gERd0MED/07=F;01aER/0KEDY06aD:01[E2P0JU<W06aE:@1`F2X0MU//
07eO;@21HBh0Q6<^08ET;`27J38208UZ=00608a]=`2>KcT0S6dg08QY<`23I2h0P64[0P1kHBh00`1j
H2d0NEl/07QN:`0307MM:P0>075I:`1_Eb/0K5@X06U@9`1XCbL0J4hY06Y@;@1[DBh0Ie8W06YE:P1^
Eb/0LUX/07ML;@1hG2`207YL:P0>07MH:@1iFR/0Ned[07eO:`20HR`0Q6L_08Q[<`2;KS@0V7Pk09Mg
>P2EMCP0Tg<f091`<`2?Kc8208i^<@0808I/<@25Jc00Q6Xa089W<020IC00OV8`07eQ;`1lH30207MN
:00>07IL:@1eFbX0M5TZ07=H:`1bEbX0LUL/07UM:`1jGR`0O60^07mS<@23IcD0QVXh08Q/>P29KC/;
08M/=`<0QV/f0P25JSD01P28KcL0Qfhf08A[<`22JC40PFP`081W;`80PFP`01P0PFLd081V<`1oIC80
OV@a07eS<01lHRl0Nf4^07YP;@25HBd0RFPc099a?02GN480V7Y4099g@02;LSX0QVde07]U<`1fH2h0
L5XY06eG9P1]EbP0K5DY06UB:01UCR@206E?:080I4hW00`0HddV069<9@1RC2D0HD/T05i;8`1MBR80
FdTS05M78`1FAR@0Dd@S05548P1@@b<204`m700@04Xm7@18?Al0ASdP04<l8012>b40@C/Q048h7`11
=ah0@3DO03hc7`0l<Al0>c0N03T]7@0h;1h0:b@J02PT6@809B4H00D08AhG01dL5`0L7AP06adH01/M
6P0801LI60P05QPG400E5aH801HH5`<051HE0`0E5aH201HH5`P05ALF600F61L801LI608061PF0P0I
6AL201XJ60D06a/I0P0L71X301dM6`807QdH100O7QT2020O6PP07alG00<08R8J024Q6@0P81P00P0O
7aL00`0P81P08R8J02<S6`08020P60P08B0K0`0P7aX3024P6`<08R4L00T0824I024Q6@0R8QX09B8K
02LR700Z8ad0:b8M02`S7P0a9ad00`0`9Q`02P0^9Q/0;BDJ02dU6P0]9AX0<2TI030X6`0_9aX0;bLL
02lV7@0^9Ah202hU800902/T700/9Ad0;BHN02hW7`0]9Qh0;2DM02XS6`0Y8QX0;2DM0080:b@L1@0Z
8a/202dS6@0402hT6P0_9A/0;bDK030V7080<BLM200f:Qh203LY700403P[6`0i;1/0>RdL03/^6`80
?30J1@11<1h00`12<Al0@c8P04<b800204/f8`0304/f8@1<>200CCTP0080CSXO00@0Cc`N04lg7`1?
=al0CcLO0P1@>203054i8@04050f7`1A=b00DCLP058h8@80DcTR0P1D>R<205Dk80H0ES`Q00H0EChO
05Ho801H?b40FSlR05do8`1P@BD206=19P80H4<S00<0HD@T06959@1SARH00P1TAbL0101UB2P0ITPV
06I89P1VB2H206E79@<0I4HT0P1VBBL206M::00706E89P1SAR@0HD@R05m2801T@b80ID@S06M69@03
06U89`0606Q79P1WARD0JdLU06]79@1/B2H0KDTW0P1^BRP206m;:@0?071<:P1cBbL0LTXV071:9@1]
BR@0JdTS06U98P1XB240ITTQ06A68P1WAR<0J4LT06]99P1]BBL0L4TX0080LTTY0P1`BB002@1^B240
JdPR06U78P1WAR<0ITDR06A6901T@b80ID@S06I5900206M69@0506I5901T@b80Hd8Q06A0801U@B40
0`1V@R803`1U@B40I40P06<o7`1V?b80HchQ068m801P?Al0H3lP05m08@1P@b<0HD@T06I7:01TABH0
HD8S05m08@0205dn7`80GSlP101M?Ql01@1N?b00Gd0Q06528`1R@b@0HTPU0080I4LU00<0ITPV06Q7
9P1ZAbL00P1[AbL206U89@80JTTV00@0JdXW06a;:01/BbP0K4/X0`1`CBL3075>:080LTlY00T0JDPU
06Y99P1]C2T0Kdh[071?;01_CR/0KD`Y06]:9`1aCBd00P1aCB/01@1bCRX0ME8/07QE;@1kF2h0OEX`
0080NeP^0`1jEbd307UF;00907]H;P1jEbd0NUL]07YG;@1lFBl0OU/a085N=022GcD0PV0b0080PEla
00D0P5h`07mM;`1nG2h0OU`^07eK;@0207mL<P04081M<`21GS@0PUle08=P=P80Q64g0P27HSD208QS
=P80RF@g0P2:ICP308aV=`80SFLh102>J3T0202;IST0S6Lj08aW>P2<IcX0RVDh08MR=@25H3<0Peha
0P1oG380101nFc40O5T_07]H;P1iER`207QE:`0806m?9P1^CRL0KDdV06];9@1YB2D0IdHU06I59P1U
A2D206E69`0406A59P1SA2D0HT<T06528`80H44R00H0GTHR05m58P1OAB80HD@R06948P1UA2<206M4
900@06]::`1ZBBX0JTTX06Y99P1/C2H0KThW075A:P1bDRT0ME8Z07IC:`1gE2`0NEH^07]H<01mFS80
OU/c07mL=080PUdc00H0Pehb08EP<`26HS80R6@b08UU<`29IC4208]W=`P0RVHf1029ICD208QT=0<0
RVDh1@29I3L02026HS00QV8b08EQ<@24Gc80Pehb089M<`22G3D0PE/d201mFS00101nFB`0OeX]085L
;`23GS4208AO<P0808=N<@22GC00QEl`08IP<@29Hc@0RfDf08aV=`2=IcP208aV=`80Qf8e1P28HcH0
1@2=IcP0S6Hg08aV=`2<ISL0RfDf00<0RV@e202@IcT908eW>00608iX>@2?JCX0T6Xk095[?02BK3d0
Tfdn0P2DKSl2099^?P0309=_?`2ELD40UG5100<0UW9200<0U6ho09E_@02FL4400P2GLD801@2FL440
UFm009A^?`2GLd<0V7A40080VGE500@0V7A409Ea@@2BKSh0T6`l0P2HM4@0102GLd<0UW9209Ea@@2E
LD4209A`@0@0UW111P2EKd0209A^?`0509=]?P2BK3d0TV`m099/?@2>JSH00P2?JcL03@2@K3P0TFdi
099^>P2BKSX0Tflk095/?`2BKD00Tflo09A`@02CKcl0TVhl091/>P2?JcT00`26HS8[ooooo`00:_oo
ool00`2OM440X7E20:5f@`020:9gA0030:5f@`2PMD80WgA100<0WG=10P2NM48309me@`0609mbB02O
LdH0WW9509ib@`2NLT40WW=00P2OM3l309id@P80WgE30`2PMT@80:9fA@060:]iB02YNDP0ZGU80:Mi
A`2UNTL0Y7]70P2SNdL80:9mB@P0XWQ6102QMdD40:1fA00409egB02LMTL0VgE609YdA@80V79300<0
UW1109E_@02EKd000P2FL4<01P2EKd80U6i1099/?`2AJch0T6Xm08mY?080RfHl00@0RF@j08MR>026
HCL0Q5le0P22GC<01@23GCH0PU`e089L=@21Fc@0OeTb0080OUPa00T0OEL`07QG;01gER/0MUD/07EC
;@1cDB`0LDl/071>:`1_C2`00`1^CBX206m>:`<0KTdZ0`1/CR`206]=:`<0JT`Z01P0Idl]06Q>;@1W
CBX0JDdX06a>:01aDBX0ME<]07IE;01kER`0O5L]07eH;P1nFBl0OeX`081K<@21G380PUdc089L;`23
GC00QV0c08QR=@2;ICP0SVPk091Z?@2AJch308aV=`<0SFLh0P2>J3T01P2>JSX0SfTj08mY>P2BJC/0
TfPk09AX>`80UfPl202CJ3/309=Y=`80TVPf00P0TFLe091V=02?IC<0TVLj095V>@2@ICP0Sf@g08iS
=P<0SF8e0`2:I3L308]U>080S6Hi00<0Qf<c08UU=@2<J3P00P2>JSX00`2=JCT0RfLg08UU=@08091V
=080SF<a00/0SV@b091V=02AIcD0TVPf09=Y=`2DJSP0TfPk099W>P2@ICP0Sf@g08iS=P0208mT=`0:
091U>02AIST0TVPf095W=@2@IS@0SfDc091V=02AIcD0TfTg09AZ>080TF/l0`2@JS/308mY>P0H099X
=P2CJCL0U6Xh09E[>@2DJSP0TfTg095W=@2?IC<0T6Dh095V>@2CJ3/0U6Tl09=X>`2AIST0Sf@g08iS
=P2>JCD0S6Lc08YU<@29I300R6<_08UT<02:IC40RfHb0`2:I3D308US=080R68c2027Hc<208MR=@80
R6<f0P29I3L208YU>00308]W<`2<J3@0S6Pd0080S6Pd0`2=JCD208]V<@0608aW<P2>JC@0SfXe091[
=P2AK3L0TVdh0P2CJcP0102AK3P0TFdi095]>@2>KCP208e^>080Sf/g1P2@K3P0802:K3X0Rfdk08]]
>`2;KC/0RF/i08IX=P24IS@0PV@b08AS<022HS40Of0b07YM<@1dF300K58]06I>:P1RBbT0GDP[05Q3
9P1C?b@0D3lS050o9@1>?RD0BCXS04@e7P11=Al0@3@N03db7P0h<1d0=BhK034/6@0]:QT0;2TH0P0Z
;AX00`0Y;1/0:B/M02PZ7@0202LY7P0902HW7`0U:AX092PJ02@X6P0S9Q/08RDL024T7@0Q8ah0828M
00<07b8I0P0P8aX4024T6`03024T6@0R9AX08bHK008092LL00H08bHK024T6@0P8aP08bHO028U7P0P
8a`201hQ6P0301lR6`0P8a`08B@M00807b8I0`0P8aX3024T6`0P02DU6@0W:1X0;2XM030]7P0e;al0
=c0N03Pa7P0i<Ah0>S8K03de7P13>B00Ac/Q04/m8P1:>ah0B3TL04Lf6010=B40?3@O03P`7@0d;A/0
<B/K02h[700^;1d0;R`O038`6`0c<A`0=c8N03Xc800l=240?C8P03d`7`0l;ah203D`6P0603@_6`0c
;Q/0<bdM038/7P0a:ad0<B/O200a:ad0200^:1X0;2TJ02/W6`0Y9a/09RHL02@U7@0S9Ql08RDN0P0P
8a`201lR6`807R4J0P0M81T201lR6`807R4J0P0M81T201`O600P01dN6@0M7QP07AhH01dN5P0O8AH0
8R@G02@V600V:1X0:RHK02hX700a:1T0=BPG03XY5@15<AT0E3`R05i4:@20GS/0RVY1095eA@2AN400
T7U308ihB@23KDP0M5m004Dn900i<R00;2DM02TS9@0/:Rd0;Bd]02<X8@0K8A<802@W80P09bXS1@0V
:B80300W:R<0:2/T02P[900X:b@09R`R02L]8`0Z;B80;2hS02l_8`0b<2<0=34R03Db8`80>cPY00<0
>SLX03Tf9`0h=BH00`0g=2D00`0k=R80?3LS03`g8`0203`g8`<0?CPT00P0>SP/03Pf:@0f<b@0=c4Q
03Xc8@0o=b80A3`W04Tn:0P0CclU02H0DT@Z0594:@1B@RP0Dd8V05A39@1IARH0GDTX05m;:P1VB2@0
JDdX06e@;P1YDBl0I4d]05m::`1OC2`0GTd_05U::@1JBRT0Fd/Z05e::P1NBBX0GdPY0617:@1OARP0
HdTX06A::@1UCB/0IDh/06=?;01QCb/0GddY05a<:01HAbd0EdH/05I5:`1D@bT0DD0V04ln9080CC`R
02P0D3`Q05=08P1IA2L0H4TZ06E<;@1XCRd0JDl/06Y=:`1bEB/0M5L]07QK<@1jGC<0Nehd07YM<`1h
Fc40MUT_07]N<P1lGc<0OV4g07iQ>@1kGCL0N5Xf07EG<`1dES@0LEX`07AM<`1iHSH0OVPi081Z>@1o
JCP0OFLe07aV=01mJ3/0NfHi07UR=P1hH3@0Nf0e07mT>@25J3h0R6]10P2ENdX02`2DNTT0TWQ708me
A02<LT40RFln08M]?025JcX0QV`k08A]>`22K3X0Of/h0080NfXf00L0Nf/g07]Y>`1jJ3X0NVPj07YU
>01iI3L0N6<f0080N64e00P0O5le07iO<`1nGc<0Oeha08=Q<`28I3@0RfDd08eW=P80Pf8e02@0Pf4c
089P<025Gbh0RF4^08iU;`2CJ3<0V6/d09i`<P2TM3H0ZWXj0:el>@2^O3L0/ghh0;V3>`2nR3h0`I0d
0<6B=P34USh0aIa40<>OB@30X4/0_j1>0;bPC@2dVeT0/iYJ0:nFEP2/TUD0Z8iC0:F;DP2RQe00XHI?
09N7E02FQ5@0TX1@08ilCP2;ND/208agC00608ehC@2CLd00TG4n08i^>`2<K3/0RVXi0P29JCX07029
J3/0RV8_08eU<P2@J3@0SfLc08eV;`2?J2l0U6db09Ub=`2ELCD0Ug<g09]g>`2NNSh0X7a00:5m@@2P
O400Wg/o09mj@`2LMd00VG@m09E`>@2DKcP0UG0i09Mb>`2HLc`0UW4l09A_>P2CKST2095/=`03099]
>02CKST0U6lj0080TFdc00T0TFhf08i]=`2<KCL0R6Xf08IX=P22IS@0Of<d085U=P25ISP00P26IcT0
0`26ICP0Q6<f089Q=00208AM<P0;08AN<@25HC40Qf<a08UX<`2<JcH0SVdg09=^>P2AK3P0SVXf08a[
=P2<KCL00P2<KSP03`29KSL0VGHl09Qe?@2GM3`0UW<m09Aa>`2BKSX0TFdi095]>`2?JcL0SVXf08eY
=@2;Ic<0RFDa08QT<00208MS;`0508AT<@23Hc00Pf<b089R<`21H3<00P20Gc@04P1oGSD0O5/`07]J
;`1hFBd0MEP/079G:P1_EbT0KUHX06aF9`1]EBL0L5DV075F9`1eFBT0Me/[07aN;01oHBl0P68`089T
<080QFLc00L0R6Xf08]]>@2:K3P0QfTe089T<01oHBd0OV8`0080OF4_00/0O60^07]O;@1jGR`0NEd[
07QL:P1cF2T0LULZ071E:01^DbP0K50X06]?:00206Y>:@0606E@9@1WDRL0Je@X071H:P1fFb`0NEd]
0P1mGbd207EG9@0F07IH901kGBL0PF@/08Q[<`2>LCL0T7<g08i`<P2=Kc40Rfd_08Y/;P29Jbd0RV`^
08]];`2<KS00QV`a08E[<024JS40PVL`085V<@1oHc40OV8`07eQ<@80MehX00h0MU`Y07EK:P1dFBX0
LeP[079G:P1bEb`0NEd[07YN;01lH2h0P6@b08=W=@27JcT0RFdk08Y^?0/0Qf`e0`26Jc@208EZ<`04
08U`>027KSH0QF`d089Y<@<0PFP`01T0PVTa089X=@21Ic@0P6Hc07mU<P1mHc00O68_07]Q;P1jH2d0
Pel[08MV<@2@KcX0UWM109UkA@2ENT<0T7Lo08ac>`21K3L0NfHa07AN;01`FRT0KeTZ06iH:@1ZDbL0
ITlS0080IU0Y00H0IDlX06A>9`1SCBH0HT`U065;901PBR<205e:8P0605]98`1HB2@0ETHT05A5901B
AB<0DTDU0P1>?Qd0401<?Ah0BS`O04Ll8016?240AC/R04<l8P13>Ah0@SPM044g7P0o=1h0?C8N03/`
7P0j;ad0>BdM02hX700Z9QX202LS600502<P5`0O7aL07AhH01`O600L7QT0200G6AP801HH5a005ALF
200F61L301@F5@<05ALF0P0F61L801DG5QP05QPG200G6AP201PH5P806ATG0P0J6QP501/K6@8071`J
0`0M7A/00`0N7AP07ahI01lN6@02020O6P808B0K00<08R4L020P600P81P01P0P81P00`0S8a/08R8J
020P600201lO5`03020P600Q8AT08R8J00P08B4I200S81/201lN6@<081lJ0P0Q81/2028Q7008020Q
6@0Q8AT08R8J02DR6`0W8Q`0:R<M02/R7@0/8ah302lW700302hV6`0_9A/0;bDK0080;bDK00H0<RTH
038Y6P0b:AX0<BLK034W7@0a9ah2030U7`0802`U7@0]9Qh0;RLO02lX800^9al0;BHN02/T700Y8QX4
02`U7@0402/T700Z8a/0:R<K02TR6P80;B<I00@0;R@J02lU6`0`9Q`0<BLM0P0b:1h803HZ7P80>2XM
00@0>B`L03X]700j;A`0>bhK0P0l<1X2040_7@03044`7P12<Al0@c8P00<0@c8P00D0BSDR04/f8`1;
=R40C3PP04hj8@0204lk8004050m7`1@>200D3PP050h8080DCTQ0`1B>R801P1A=Al0DSHP05<g8@1D
>280ECTS05Hj9080Ec/U0P1I?R<605Pm8P0605Ho801G@240FD0R05]08`1N@2@0HD8V0P1T@RL20654
900306959@1SARH0I4LW0080IDPX00<0ITTY06Q::01WBBL00P1WBBL306I89P0306E79@1XBRP0J4XX
0080JD/Y00L0IdTW06E79@1SAB<0HD<Q06I5901WARD0J4LV0080JTTX00@0JDPW06Q79P1WARD0JTPU
0P1[BBH0101/BRL0KD/X06e;:01^C2T206m=:P80Ld/W00h0LD/V06m<9P1]BbD0Jd/T06Y:8`1XBb<0
ITPT06Q7901YB2D0JdTV06e99`1`BBP0LdXZ07A;:`80LDXQ00P0KdTR06a98`1ZB2<0J4LT06M68`1U
AbD0ID@S06I59080IdHU00L0ITDT06E48`1S@R40HD0O068n7P1S?al0ID4Q0080Id<S00l0IT8R06A0
801S?al0Id0S06@o8P1R?B00HChP060o801P@B80H4<S06959@1VAbP0IDHW0693901P@B800P1O@242
06118P0905m08@1N?b00GChO05dn7`1N?b00H44R0693901TABH0ITTW0080IdTW00<0JTTX06]8:01]
BBT00P1_B2T00`1[BRL0K4/X06a;:00206a;:0<0KD`Y101aCRP2079?:@80Le0Z00T0KTdZ06m>:`1b
DBh0M5<`07ED<@1dDc00LU4^071?;01bCRh00P1bCR`01@1cCb/0MU<]07UF;P1lFBl0OU/a00<0NeP^
0`1jEbd207UF;080NUL]00H0NEH/07YG;@1kF2h0OU/a081M<`22GcD208=Q<`04089P<P21Gc40PEla
081N<080Oed_00D0Oe`b081M<`20GC<0PEhd089O=@0208=P=P0308AQ=`27HSD0Qf8e0080R6<f0P29
I3L208YU>080S6Hg0P2=IcP308iX>@80SfTj0P2<IcX208eX>`0408aW>P29I3L0Qf8e08EP<`80PEhd
00@0P5dc07iK<@1mFS00NeP^0P1jEbd0201aDBP0L50Y06i>9`1]CBL0JdXW06U89`1XAbP0IdHW0P1V
AbP0101UARL0I4DV06A59P1SA2D20693900605i68P1PAR<0H4HS06=6901UAbD0IdHU0P1XABD0401[
BR/0JTTZ06Y9:01ZBBH0K4`V06i>9`1aDBX0LU8Y07EB:P1fDb/0Me@/07UF;P1kF300OEXb07iK<`1o
G3@2089L=@0608=N=025H3@0QV4d08QT=029ICD0RFDc0`2:ISH708]W=`80RVHf0P29ICD208QT=0H0
RVDh0P2;IST02028I300R6@b08MS<@26HS80QF0c08AO<`24GcD0Pehd201oGC000`21G2l0PUd`08EP
<`0408MR=@0508IQ=029H380Rf8d08iU=`2@IcT00`2AJ3X00`2@IcT0RVDh08YU>00608UT=`D0SFLf
0`2<ISD808mY>PT0SVPi0P2AJc`0102BK3d0Tfdn09A^?`2DKSl209E_@0<0U7100P2ELD401P2GLd<0
V7A409QdA02EKd00UW1109Ma@P80V79300<0Ug5209I`@@2EKd00102IMDD0102GLd<0UG5109=_?`2B
KSh209UeA@0309QdA02GLd<0UW920080UG5100<0U71009I`?`2FL3l00P2FL3l409Ma@080V79300@0
Ug5209E_@02DKSl0Tfdn0P2BK3d01@2>JSH0Sf/g08m[=`2@K3P0TFdi0080TVhj00T0Tflk095]>`2B
KS`0Tflm09A`@02CKcl0TVhn091[?P2?JSd00`2:ISH[ooooo`00:_ooool30:1e@P80XGI30`2PMD83
09ec@@80WWA20`2OMD<0202QM4X0X7A709mcAP2NLT<0WW9109md@@2PMD00XGI10P2OMD<20:1fA0<0
XGM500<0XWQ60:9fA@2RMTD01P2RMTD0202YMdH0YgM60:MgAP2WNDL0YW]80:ElB02TO4P0YGe9202R
ODT:0:9hAP80XGM50P2PMT@209me@`0409ihB@2MMdP0W7I709YdA@80V79300<0Ug5209E_@02DKSl0
0P2EKd803P2DKT40TV`o095[?P2@JSd0SfTl08iX>`2<Icd0RfHl08YU>`28HcT0QV4g08AO=@23GS@0
PUdc0P24GSL04@23GCH0PU`e081J<`1oFC80OUPa07eG<01gE2X0MU<Y07IC:`1eDR`0M50/07=?;@1b
CR`0LTh^06e<:@1^CBX0Kdh[0080L4l/00@0Kdh[06i=:P1]C2T0KDl]0`1/CR`206]=:`80JT`Z00P0
JE4_06U?;P1XCR/0JThY06e?:@1cDb`0MeD_07YI<080O5L]00@0OEP^07iI;`1oFS00P5/a0P21G380
2023GC00Q5ha08IP<`29HcH0S6Hi08iX>`2@JSd0TF/n1@2>J3T308mY>P0608iZ>P2?JCX0SfTj099Y
>`2CJ3/0U6Pk0P2GJ3`809=X>`@0TfTg00X0TVPf095W=@2?IC<0SV@b099W>P2AIST0Sf@g08iS=P2=
HSD0S64d0P2=HSD708]U=P0408YT=@29I3L0RF@g08]V>@@0S6Lj00<0RfHi095W=@2@IS@00P2@IS@3
08mU<`<0SV@b00@0SfDc091V=02AIcD0TFLe0P2BJ3H01@2CJ3/0TVLj091U>02?I3L0SV<f0080Sf@g
00@0T6Dh095V>@2AIcD0TFLe0`2?IC<00`2AIcD0TfTg09AZ>002095[?P<0T6Xm0`2?JC`00`2AIcD0
TVPf09=Y=`0209AZ>006099X=P2@IS@0SfDc08mT=`2AIST0TfPk0P2DJC`02`2AIST0Sf@g08eR=@2=
J3@0S6Lc08YU<@29I300R6<_08UT<02:IC40RfHb00<0RV@e0P29Hc@308QR<`P0Qf<c0P27HSD208QS
=P80RF@g0P2:ICP808aX=080S6Lb0P2=J3<01`2>JC@0SfXe091[=P2@JcH0TVXg09=[>02BKCT00P2B
KSX00`2?KST0SFhh08a]=`0208iZ=P80Sf/g102@K3P0802:K3X0Rfdk08]]>`2:K3X0R6Xh08IX=P23
IC<0PF<a08IR<P23HC<0Of0b07UL<P1`FC00JE<^065?:`1LC2X0FdHY05M29`1B?R<0CchT050n9P1>
?RL0B3TT04@e8011=Al0@3@N03db7P0i<Ah0=BhK034/6@0]:QT0;2TH0P0Y;1T00`0Y;1/0:2XL02PZ
7@0202LY7P0702HW7`0T:1T092PJ02<W6@0S9Q/08RDL028U7P02024S7P<07b8I0P0P8aX4024T6`0;
028U6P0S9Q/092LL02DX7@0T9a`08bHK024T6@0P8aP08bHO028U7P0P8a`00P0N8AX0100O8Q/082<L
024T7@0O8QT3020S6P808B@K0P0R9A`0800X9QT0:RPI02h[700d;Qh0>34O03/c800k<ah0?C8N03/c
700n=Ql0AC/R04Tm8`1<?R<0BS/N04Lh6`15=1H0?S<O03Xb7@0f;Q/0<R/I030Z6P0^:a`0;R`M030^
8@0d<Qd0=C<N03Td800k=240?3@Q03db800l;ah0>bhM0P0c;QP00`0c;QX0<RdJ038/7002034[7@03
034[7`0a:ad0<B/M00H0<B/M00H0;RPJ02/X6@0[9a/0:BLK02HV700T9Ad2028U7P<07b8K0P0N8AX3
01dP6@807b8K0P0N8AX201dP6@8071lH0P0N7aT07P0N7aL07b4F028T5`0U9aT0:2/J02X]700]9Q`0
<2PM03DY6@0k:QP0@blG058h7@1TAbT0L54b08YT?@2AKd80UGM3099g@02<Md80QW5607=P?`1PCcD0
<C0L02`Z7@0V9B409bH[02/Z<00Z:bd08BHO01XP4PP092LP2@0W:R<202HY8P0402DX8@0V:B809bXS
02P[9080:B`U00h0:B`S02T/8@0/;R<0;RhR038`8`0e<R<0=S<R03Tc8`0l=RP0>cDW03Xd9P0i<bD0
>38T03Tc9@80>S@V200l=b<0200h=B`0=c@[03Lc9`0i<b<0?3DR040h8`14?B<0BClT201A@2H05P1D
AR`0DT@Y0592:01B@BD0E4<U05U69P1NBRT0H4`[06U89@1[CBT0KE0^06UA;`1QCB`0Fd/Z05Y=:`1K
CRh0F4PW05Y79`1LBBT0GTTZ0619:P1QB2X20656:@0K06989`1SBBP0I4`Z06A=:`1RCR/0H4hZ05i<
:01KBbL0FTH]05U5;01HA2/0ET8Y05E1:01C?bH0DShU054m901E@2<0Ed8S05e69`1RBBX0Idd/06]>
;01]DB`0Ke4]07=F;01eF2h0N5/a0080Nehd01`0NUdc07MJ<01eF2h0NUda07iQ=@21I3X0PF@l07aN
>01fF3@0LU@`075C<@1[EB`0KEL^075L<@1dGc80Mf8c07UU<`1jIS@0NVHc07UW>@1gICL0MV4d07EN
<P1gGc<0O64f081U>P23IS`0SG950P2<LD@02P2:Kd80RFi108M/?`25JSd0Q6Tl07iV>020J3X0P6Xk
07aW>01fI3@207=S<P0707=U=01cICP0MF@h07ET>01fHcP0N6<h07UR>00207YQ>00807YM<`1lGC40
O5da07iM<022H380Qf<c08]U=02=IcH2089U>@0[08=T>023HC<0QF4_08]S;`2AIS40V6Ta09]]<P2R
LS@0Z7Hg0:mn?02cPC`0]h<j0;^6>P34S3l0bI920<BC=`35US`0aiY50<FOC032XE80_ImF0;FME@2b
VeD0/IUM0:nGF`2[TUT0YHaD0:68DP2MPe00Vh5>09Z0C`2HPU40UGm>095iB@2?M4D0SW93095bA02C
M4H0UWE809Ea?`2CKcd0TFdi08m[=`0208iZ=P80Sf/g00P0T6Lc09=Z=02EK3H0TfXb095Y;P2BJRd0
Ufla09ad=P80VGLj0P2JN3/03`2KNC`0W7Xm09aj?@2MNch0W7M209Ye@02HLch0UG0k09A_>P2EL3/0
Ug8m09Qc?P2CL3X0TVli095^>002091]=`03095^>02BKcT0Tg0j0080TVdf00H0TFhh08m^>@2<K3T0
R6Xh08EW=@21ICD207mT=`03081S=`22HcL0Pf8g0080Q64g0140QV4g08YO=@28GS@0QV0c08MQ<P26
IC80RFPc08Y[=@2;KSH0SfXf09A_>`2GLcl0Tg8m08a]=`26J380Q6H`08=X<@0209Md?P0409Ic?@2E
LS`0U74k09=`>P80TVli00H0TVhj091/>02>JSH0RfLc08YV<P29IC4208QT<080PF<_00<0PF<a081Q
<P20HC<00P1oH3@01P1oGcH0P5ld07mN<`1kG300MeX^07AI;080LET[00X0L5X[07AH:01dF2P0M5PX
07EI:@1fFRX0N5`/07YN;P1lH300OF4_0P1oHc401P22IS@0Q6Pf08AX=P23IcD0PFDc07mS<@@0PV@b
01`0P68`07iP;P1lGR`0Ned[07IJ:P1fFR/0M5PY079E:@1_DRP0K4lW06U;9@1XBR@0HdhS06A?901Y
DRH0KUHX07AI:P1hG2`0OEl]07iP;P1fF2@0M5HR07AF801hFb<0PF@/08U/<P2>LCD0Sg8f1025JBX0
3026JR/0R6`]08U];P2:KRl0QV`a08E[<024JS40PfPa085V<@20I380Of<a07iR<P80N5lY00h0MedZ
07IL:`1eFR/0M5T/07=H:`1cF2d0N5`Z07YN;01mHBl0P6@b08AX=P27JcT0RVhl08a`?PP0R6he0`27
KC@308I/<`80QF/b00@0Qfhf08I]=@23JS80PVTa0P21J3008022JC40PfXb089X=@21Ic@0P6Hc07mU
<P1nI340OF<`07aR;`1kHBh0PUhZ08ET;`2=K3L0U7Do09QjA02GO4D0UGa409Ak@`28Lc`0PF`e07QS
;P1cGB/0LU`[071J:`1/ERL0JE8V06MA:P1VD2T0IDlX06A>9`1SCBH0HD/T0P1PBR<205e:8P0605]9
8`1HB2@0EdLU05E69@1CAR@0DdHV0P1A?Qh0401>?Al0C3dP04Xl8@17>b40Ac/S04Dk8P14>ah0@cXM
048h7@10=Qd0?S<M03`a7@0k<1`0>RlM034[7@0]:Q/202TU6@0302@R5P0P81H07AhF00806ahG200G
6AP801HH5a005ALF200F61L301@F5@<05ALF0P0F61L801DG5Q005QPG400G6AP201PH5P806ATG0P0J
6QP501/K6@8071`J0`0M7A/201lN6@8081lJ00@08B0K028Q700S8Qd08b8M200Q8AT01`0T91`08b<K
024Q6@0P81P07alG020P600Q8AT02@0R8QX802@O6`<07ahI0`0P7aX3024P6`08020Q6@0Q8AT08R8J
02DR6`0W8Q`0:R<M02/R7@0/8ah202XV6P0@02`V6P0^9Q/0<2HL038U700c9A`0=2HM03H[6@0f:QX0
=BTI03DY6`0d:1`0=2LN03@W7`0c9Qh0;BHN02hW7`<0;bPP00@0;BHN02`U7@0Z8a/0;BHN0`0^9al0
2P0]9Qh0:b@L02XS6`0Y8QX0;28H02dS6@0^91X0;bDK034W7@0b:1h203<Y7`P0=RXN0P0h:Qd02@0i
;1`0>RdL03/^7@0l;a`0?30J03da6`0n;A/0?bhL044`7P0204<b800304@c8@13<R00@c8P0080BC@Q
00H0BSDP04`h801=>B00CSXO04lk801@?Al3054i8@80DSXR0`1C>b<205@e800705Df8@1F=b80F3TT
05Tj9@1J>bH0Fc`W05do9@0305`n90<0FcdS00T0FS`R05Q18P1I@R<0FT4S05a1901O@BD0HD8V06=1
9P1T@RL00P1QA2@00`1RABD0HdHV06A79`0206E8:00306I9:@1XBRP0J4XX00H0J4XX00/0JDPW06Y9
:01[BRT0JdXY06Y9:01YB2L0IdHU06E48`1WARD0J4LV06Y9:00206]::@0306Y9:01XAbH0IdHU0080
JTTV00@0JdXW06a;:01]C2T0KD`Y0P1^CBX02P1_CR/0M4`X07A<:01bC2L0L4dW06i<9P1]CBH0K4`U
06Y=9@1YBbL206Y99P0>06]99P1]BBL0L4TX07=::P1dBb/0LT/R075:8@1`BR<0KDXT06]9901YB2D0
J4LT06I89P1VAB@306M69@0706I5901S@R40HD0O05ln7@1Q?Ad0HclO06E18@0206Q4900>06M38`1T
@200HclO06Q1901U@2<0I3lR064n801P?b00Gd0Q06138`1QA2@0ITLX06A59P1SA2D306528`0;06=4
9@1TABH0HT<T06528`1O@240GSlP05m08@1Q@R<0IDHW06M8:@1YBbL00P1[BRL00`1]BbP0KTXX0719
:0020799:@<0KD`Y1@1^CBX0101aCRP0LTlY079?:@1bCbT207=@:P80M54[00@0LU4^07=B;`1dDc00
ME@a0P1fEC800`1eE340M5<`07EA<@0207EA;`0507EA;@1gE2h0NUL_07eJ<01oG3800P1lFBl207]H
;P<0NUL]00<0NEH/07YG;@1iER`00P1iER`0101kF2h0OEX`081M<`21GS@408=Q<`<0PV0b00<0PEla
081M<`20GC<00P21GS@2089O=@80Pf0f0P27HSD208QS=P80RF@g0P2:ICP308eW>080SVPi102?JCX2
08eX>`80SVTl00X0SFPk08]V>@29I3L0Qf8e08=P=P22GcD0PEhd081M<`1oG380OEX`0P1lFBl02@1c
DbX0LU8[075A:P1_CbT0KD`Y06]::@1ZBBX0JDPY06M8:@0306I7:080IDHW0P1TABH0601OAb40HDLR
06988`1UBB@0IdTU06U89@1YAb@0J4HS06]::`1ZBBX0JTTX06Y99P1/C2H0KThW075A:P1bDRT0MU<[
07MD;01hEBd0NUL_07aI<@1mFS80Oe`d081M=@80Pedh00@0Q5hg08IQ=`27HSH0RF@g0P2:ISH208]W
=`<0S6Ph1@2=JCT0102<J3P0RfLg08YV=P2:ISH208UU=@80RVDh0`2;IST308aW>P0608YW<@2:IS80
RFDa08QT<P27Hc<0QV4d0P25H3@8085O<@0508EO<P27HC@0RF<f08]U>02<IST00P2;ICP01`2:I3L0
SF8e08mT=`2AIST0TfPk09AY?02CJ3/00P2BIcX0102<IcX0RfHi08]V>@2;IST308YU>00408UT=`2=
J3@0SFPd08eX=080SVTe0`2?JSH8091/?0T0SfTj0`2DKSl209E_@0<0UW1100<0Ug=309Ib@P2ELD40
0P2ELD401P2FLT80V7A409UeA@2FL440Ug5209Qb@`80VG=400<0V79309Ma@P2FL4400P2IMDD209Qd
A00509Mc@`2FLT80UG5109A`@02IMDD00`2HM4@409Mc@`80UW4m0P2GLSh409Qc?`0809YdA@2ILd@0
V79309I`@@2DKSl0TV`m095[?02@JS/408m[=`@0T6`h00P0T6dg095]>@2BKSX0Tflm099^?P2AK3l0
SfXn08iY?@<0SVXj:oooool002[ooooo202PMD8309ec@@80WWA20`2OMD<0202SMT`0XWI90:1dA`2O
Ld@0Wg=20:1e@P2RMd80XgQ30P2QMdD20:9hAP@0XgU7202RMTD0202VM4<0YGE40:IfA@2VN4H0YW]8
0:ImB@2VOTX0Ygm;202RODT80:9hAP0<0:AjB02SNDL0XWQ60:5gA@2PMT@0WgE309id@P2MLd40WgU:
09ihB@2MMdP0VgE60P2HLT<02@2GLD80UFm009A^?`2DKT40Tfe0099/?`2AJch0T6Xm08iX>`0208eW
>P0808eX?P2<Icd0RfHl08UT>P27HSP0QF0f08AO=@23GS@2089L=@06081J<`1oFC80OEL`07aF;`1k
EBh0NU@]0P1dDBL00`1dDBT0M54[07A@;00207A@;P0407A@<01]C2T0KTdZ071?;080LE0]00<0L4l/
06i=:P1]C2T00P1]Cbd306a>;0<0Jdd[00P0K5@b06]A<01ZD2d0K50[06mA:`1eEBh0NUPb07eL<`<0
OEP^00<0OUT_07mJ<020Fc400P20Fc402025Gc80QV0c08MQ=029HcH0S6Hi08iX>`2?JC`0T6Xm0`2A
Jc`5091Z>`0608iZ>P2?JCX0SfTj099Y>`2CJ3/0U6Pk0P2GJ3`809=X>`0<099X=P2CJCL0U6Xh09AZ
>02CJCL0TFLe08iT<P2=Hc40TVLj095V>@2?I3L0SF8e0P2<HC@208eR=@80SFLf00@0S6He08]U=02:
I3<0RV@c0P29Hc800`2;ISX0RVDi08YU>@0208YU>@0308]V>P2=J3`0SFPl0080TFLe0P2@IS@0102?
IC<0SV@b08iT<P2>I387091V=006095W=@2CJ3/0TVLj091U>02?I3L0SV<f0P2?I3L02P2@ICP0TFHi
095W=@2@IS@0SfDc08iT<P2?IC<0T6Hd099X=P2CJCL2095Z?`<0T6Tn0`2?J3d02`2AIcD0TVPf09=Y
=`2DJSP0TfTg099X=P2@IS@0SfDc08iS=P2@ICP0TfPk0080U6Tl00H0TFHi08iS=P2<HC@0SFPd08]V
<P2:IC4308QS;`0308UT<02:IC40RV@e00<0RF<d0P28HS<208MQ<PP0Qf<c0P27HSD208QS=P80RF@g
0P2:ICP208eY=@H0S6Pd102=J3<408iY=003099Z=`2CJcP0Tfhj0080Tflk00@0T6lj08e^>02<KCL0
SFTe0P2>JSH208m[=`80T6`h0240TFdi08]]>`2;KC/0Rfdk08Y/>P28JSP0QFLe089T<P20HS00QV4d
08=Q=01nGc<0Me/c06mG<@1UDbl0GDl/05U::@1JABX0ET0X054m901>?2@0CcdW04dl:018>BH0A3DR
048f8011=Al0?S<O03Ta7P0e;Q/0<RdJ02h[6P0]:QT00P0X:aP00`0X:aX0:2XL02LY700202LY7P07
02LX800S9aP08bLI02<W6@0S9Q/08RDL028U7P02028T7`<07b8I0P0P8aX4024T6`0;028U6P0S9Q/0
92LL02DX7@0T9a`08RDJ020S600O8QL08bHO028U7P0P8a`00P0N8AX00`0O8Q/082<L024T7@03020S
6P808B@K0`0R9A`0800Y9aP0;2TJ02l/6`0e<1d0>C8O03`d7`0o=200?c@N03`d7@0o=b00AS`S04Xn
901<?R<0BS/N04Hg6P14<aD0?C8N03Ta700e;AX0<BXH02hX600^:a`0;bdN034_8P0e<ah0=S@O03Td
800k=240?3@Q03db800l;ah0>bhM0P0b;AL00`0b;AT0<RdJ034[6`02034[7@03034[7`0a:ad0<B/M
00H0<B/M00H0;BLI02/X6@0Z9QX0:2HJ02DU6`0T9Ad2028U7P807b8K0P0N8AX401dP6@807b8K0P0N
8AX201dP6@8071lH0P0P8AT07P0P8QL08R@G02@V600X:aX0:bhM02ha7P0c;280=RhQ03/_7`13<Ad0
CcLM06549P1gEC80QF4m099/?`2HM480VGY3095g?P27LSd0NFHl05m><P18=b<0:R`N02P[8P0V:2L0
9BH[02<V;@0S9bP08RLP020V6PP092LP200W:R<01`0X:b@09bXS02HY8P0U:2409RTR02LZ8`0Y;2D0
0P0Z;BH02P0Z;240:bdP02d]8@0a;b80=34R03Hc8P0j=B80>cHS03/c9P0j<RD303P`8`0303Xb9@0k
<bH0?CDX0080?CPT1P0l=b<0200f<bh0=S</03Pd:@0l=RP0?cPU048j8`14?B40AchQ201D@2D08@1E
Abd0DdDZ0592:01B@BD0E4<U05U69P1NBRT0HDd/06U89@1[CBT0KE0^06QA;`1PCB`0FDXY05M=:P1G
CRd0F4DU05U69P1LAbP0H4TZ0699:`1RAbX0HDHY06=5:@1QAbH0HTPW06=;:@1SC2X0HDdZ05m=:@1M
BbL0FTXV05]5;@0205Y4;00@05U3:`1G@BT0ET0X05I0:01E?bL0FdHW05e69`1NAbL0HTXX06I<:@1[
CbX0L58^079D;P1cER`0MEP^07QK<@80Nehd01/0NE`b07II;`1dEbd0N5/_07iQ=@24Icd0PfHn07aN
>01eEc<0LE<_071B<01YERh0JUL_06]H;P1^Fc00LV0b07MU=@1kJCT0OF/i07]Z?01iJ3X0MfDg07MR
=@1iHSH0O6@h07mW>`23J3d00`22JSh5085Y?@0807YS=`1mISX0OFPk07UT=`1aGc40K5/]06aN;`1^
H34206mR=P07075P=@1bGcD0M5dd07AK<`1eFC80MUPb07QK<@0207YK;`0507eL;`20GS00QV8b08YT
<`2<ISD00P23Icl0?`23IS`0Q6<f08MS<`2=I300U6L`09]Z<02OKC80Y78e0:Yh>@2bOcd0^H@n0;f8
?034SCd0biA10=:JA@3:V4<0bi]70<^PD@39XeX0a:=P0;ZPH`2aVf40[IQQ0:bGGP2XTeX0XhiG09f8
D`2HPU00U7i=099lB`2ANd`0UWY809AfA02@L3d0SF`i08mZ=P2CJcP0V6lk09aa?P2FLCd0UG0l09=^
>P2BKCP0TF`g099]=P2CKSL0U6lh09E/=02GKSH0VG4f09M_<P2DK2h0U6d/09Ub<@2MMS<0Vg/n09Ui
?02FMST0Tg<f099b=@2CLcH0UGDh09Mg>P0209Mb?PD0UW4m00T0Ug8n091_>@2?KSP0SF`f08a[=@2=
K3H0SVdg08m^>02AL3X00P2CKST07P2BKSX0T6ll08a/>`28JSP0QFHg089V=P1oJCX0OVHh07eR=@1l
Gc<0Oehc089O=@28HCP0RV<j08mR>@2=HSP0S6<g08US=027IS<0R6Tc08U[=@29KcH0SFPd09Ia?@2K
Md<0Tg8m08IW<@1nH2X0PV@^08M/=@<0UG4m00<0U74k09=`>P2CL3P00P2BKcL01@2DL3`0TVhj08m[
=`2<J3@0RVHb00<0RFDa0P23IC400`23IC<0PV<d089S=@02089S=`06085Q>023HSD0PF0c07iO<@1i
GBh0Me`]0P1eGBd0101eGbh0O5h/07]M:`1iFbT207IJ:P0307ML;@1hGBh0N60b00<0Nf4^00@0O68_
07iT<@1oIC80OfDb0P20IS<07P25IC@0QVHe08IV=@26ISD0Q6@c089R<@1oGbh0OEd/07]L;@1jFb`0
NEX/07MH;01cDbX0KThW06U98P1VAR00HD`Q06=>8`1WD2@0Je<U075F9`1fFRX0Ned[07eO;@1mGb/0
NE/U07EG8@1gFR80OV4W08EX;080Qf//00@0Q6PY08EY:P27Jb`0R6`]1029KBh208E[<00308AZ<@23
J340PVLb0080P6@b0140Of<c07UP:P1iH2X0N5h[07MM;01gG2d0MU/^07EJ;@1eFRl0N5`Z07YN;01m
HBl0P6@b08AX=P28K3X0Rflm08a`?P0808Y`=@<0Qfdb0`26K34208E[<00308A[<`23JS80PFP`0080
P6L_00@0PFP`089Y<@23JS80PFLd0P20IS<00`1oIC80OV@a07iT<@0207eS<00@089N:P24Hbh0RfXe
095b?02FN480V7e609Z1B@2KPTX0SWU008Ia>01mJ340MV4/07AN;01bG2/0KeTX06]E9P80Ie4Z0200
IU0Y06A>9`1RC2D0HD/T061:8`1OBB80GDXR05a98@1KBB<0F4PT05M79@1FAbH0E4LU05A79`1C?Ql0
DSlO054n801>?B40C3`R04Xl8P18?2@0Ac/S04Dl7@14>ah0@cXM044g700o=A`0?C8L03`a7@0k<1`0
=2hN030]7P80;2TJ00<09R@G020P500M7a@00P0J7A@801LI60P05QPG400E5aH801HH5`<051HE0`0E
5aH201HH5`P05ALF400F61L@01LI608061PF0P0I6AL201XJ60D06a/I0P0L71X301dM6`807ahI00@0
81lJ024P6`0R8A`08b8M0P0T8ah8028R6P0302DU7@0T91`08R8J00<0820H00<08B4I028R6P0S8a/0
1`0S8a/802DP70D07ahI0P0P7aX2024P6`0@020Q6@0Q8AT08R8J02DR6`0W8Q`0:R<M02/R7@0/8ah0
9R@G02LU600Y9AT0;BDJ030V700d9Qd0=bHN03PW7`80>2/J00T0=bXJ03LY700f:1d0=RPM03HX7`0e
9ah0;BHN02hW7`0_:2000P0`:B400`0^9al0;2DM02/T700202hW7`80;bPP00X0;RLO02`U7@0Z8a/0
:24I02`R600]8aT0;R@J02lU6`0a9ad0<bTO0P0d:R0803HZ7P0603PZ7@0i:ah0>B`L03X]700k;Qd0
?2lL0P0m<A/0100m;1X0?bhL044`7P13<R0204@c8@80@c8P00T0Ac8O04Pc8019=1l0BSHN04`h7`1>
>Ql0Cc/P04ll7P1A>B400`1B>R8205<k8`80E3`T0P1D=B001P1F=b80EcPS05Tj9@1J>bH0Fc`W05`m
:0<0GT0V00<0GClU05`n901L?R@00P1K?B<205]49@0405a39@1M@RD0Gd4U06119@80Hd4V0P1P@b<0
0`1QA2@0HTDU06=69P0206A79`0306E8:01WBBL0IdTW0080J4XX00L0JD/Y06Y<:P1[CB/0Jdd[06U6
9P1ZAbL0K4TY0080KDXZ00H0JdPX06Y79`1YARH0J4LV06U89`1[BRT206a;:P0306Y9:01YB2L0J4LV
0080JTTV00D0JdXW06a;:01]C2T0KD`Y06i=:P0206m>:`80M4`X00<0LddX075>:01_CBL00P1^CRL0
2@1/CbL0K4hZ06e<:@1[BRL0JdTV06a89P1`BBP0LTTY07=::P02079;8P06071:8`1^BbD0K4XU06Y9
9P1YB2D0IdTW101WARD05P1UA2<0HT4P060o7P1N?A`0Gc/K068n7P1U@B40J4@T06U59@1W@b<0ID4Q
06<o7`1Z@bH0Id8U06E08`1R?b40H3lP05m08@1N@B40Gd8R06A59P1SA2D30693900;06A59P1VAbP0
IdPY06E69`1SA2D0HD8S05m08@1P@B80Hd@U06M8:@1ZBb`00P1/C2H00`1]BbH0Kd/W075;9`0207=;
:00307E::01_CR/0Kdh[00<0Kdh[0`1^CBX2079?:@80Le0Z0`1dDB/00`1eDR`0Le8_079A;P03079A
;P0;07=B;`1eE340ME@a07UE=@1iEC<0N5@b07QD<01iES00NeP`07eJ<01oG3800`1lFBl207]H;P@0
NUL]0`1iER`01@1jEbd0OEX`07mL<P21GS@0PV0b00<0Pf4c1024HS@4085N=0@0PUle0P27HSD208QS
=P80RF@g0P2:ICP208eW>080SVPi1@2?JCX0202=J3/0SVTl08mZ?@2?JSd0SVTl08aW>P2:ICP0RF@g
0P24HCL03023H3H0PEhd081M<`1oG380OU/a07eJ<01eEB`0MED^07=C;01bDR`0L4l/06i=;080K4//
0`1WB2T506I7:00Q05m87`1RBB40HdXR06M;901YBbD0JTXT06Y88`1YAb80JdX[06Y9:P1ZBBP0JTTV
06a<9P1^CRL0LE4Z079B:@1fDb/0Me@/07QE;@1jEbl0O5Ta07iK<`1oG3@0P5de08AN>P25GcX0QV0k
08MQ>P29I3X0RVDi08]V>@2<IcX0S6Ph0080SFTi0P2>JSX208m[>`80T6`l00D0Sf/k08iZ>P2=JCT0
S6Ph08]W=`0208YV=P80RVDh0P2;IST0102<IcX0SFPk08eX>`2=J3/208]X<P0608YV<P29IC<0R6@d
08MS<`27HSD0QV4d2023HC401029H3@0Rf8f08eT>02?ISX2091W>`0508mV>P2>ICT0T6Dh095V>@2C
J3/00P2DJC`00`2CJ3/0TFHi091U>00308eX>`0308aW>P2;IST0RfHi0080RVDh00P0RfHb08aW<`2=
J3@0SVTe091[=`2AK3P0TVdi09=^>PP0T6hn2@2@JS/409I`@@@0Ug5200<0VWI609UeA@2GLd<00P2E
LD401P2FLT80Ug=309QdA02FL440Ug5209UcA080VWA500<0VG=409Ma@P2FL4400P2HM4@709Mc@`<0
V7A4102IMDD00`2FLCd0Ug8n09Mb?P0209Qc?`80VGA000T0VWE109YdA@2ILd@0V79309I`@@2CKCh0
TF/l091Z>`2?JCX00`2?JcL208iZ=P<0SFTe00P0Sf`d091]=@2AKCT0TFdk095/?`2?JSh0SFPn08aV
?`<0SFTi:oooool002[ooooo00<0XGI30:1e@P2PMD80102PMD80102QMT<0WG=109ec@@2MLd4209id
@P<0WgE300P0Y7M=0:=gBP2QMDP0X7A50:1d@`2QMT<0XgQ30:AiA080XWQ60P2SNDL20:AjB080YG]9
202RMTD0202ULd80Y7A30:EeA02VN4H0YW]80:MnBP2XP4`0ZH5=202RODT80:9hAP0<0:EkB@2TNTP0
XgU70:5gA@2PMT@0WWA209ec@@2LLT00WgU:09ihB@2MMdP0VgE60P2ILd@02@2GLD80UFm009A^?`2C
KD00TV`o095[?P2@JSd0SVPk08eW>P0208aV>@0@08iY?`2=J3h0S6Lm08YU>`28HcT0QV4g08EP=P24
GcD0OeTb07iH<@1mEc00NeD^07YD;@1hDR/0Me4Z07I@:@80M4lU00<0MDlX07E?:P1fD2`00P1gD2l0
101hDC80KD`Y06i=:P1`Cb`2075@;@03071?;01^CBX0KD`Y00<0KDl]0P1/CR`306]=:`0806eE<`1]
Dc80Je4^06eA;01`DR`0MUH_07aJ=01oGSD207eH;P80OUT_0P1oFS02081K<@0608IP<`27HC@0R68e
08YT=`2<IST0SFLj0P2?JC`4099/?@@0TF/l00H0SVXj08mY>P2?JCX0TVTk09=X>`2DJ3/209MX?0P0
TfPk00`0TVPf09=Y=`2DJSP0U6Xh09=Y=`2AIcD0SV@b08aR<02BIcX0TFHi08iS=P2<HC@208]P<`0=
08eR=@2>HcH0SVPg08iX=`2=IcH0RfDd08YT<`29Hc80R68a08MQ<02=J3`0RfHj08UT>00208QS=`03
08YU>@2=J3`0SfXn0080TFLe00@0T6Hd08mU<`2?IC<0SV@b0P2=Hc43095W=@<0T6Hd0P2?IC<01@2C
J3/0TVLj091U>02?I3L0SV<f0080Sf@g00X0T6Dh095V>@2AIcD0T6Hd08mU<`2>I380SfDc091V=02B
J3H0TfTg0P2AJSl3091Y?P<0SfPm01P0TFLe099X=P2CJCL0U6Xh09=Y=`2BJ3H0T6Hd08mU<`2=HSD0
T6Dh09=X>`2EJSd0U6Tl095V>@2>HcH0Rf0c08eX=02;IS80RF@`08QS;`27HRh0R6<_08UT<02:IC44
08US=080R68c0P27HC8808MS<`80Qf8e0P28HcH208UT=`80RVDh0`2=JCD508aX=0<0SVTd0`2=J3<2
08aW<P03099Z=`2CJcP0Tfhj0080Tflk00<0T6lj08e^>02<KCL00P2=JCD208iZ=P0408m[=`2@K3P0
T6`h095]>@<0Rfdk01d0RV`j08QZ>025IcD0PV@b081R<026HC@0Pf4d07iN=@1gFc<0KUPa069B;P1L
CR/0ET`Y05U3:`1E?bL0D3`T04dk8`1??BL0CC`X04Pi9P14=B80@cLQ048f800o=200>S8O03H_700b
;AX0;R/J02dZ6@0202P[600302P[6P0W:A/09bTL00809bTN00L09bPP02<W600S9aT08bLI02<V6`0R
9A`08RDN00808R@O0`0O8QT2020S6P@08B@K0P0S9Q/02@0T9a`09BPM02@W700R9AX082<H01lR5`0S
9Ql08RDN020S700201hQ6P0301lR6`0P8a`08B@M008082<J0`0Q91/3028U700P02XW600/:AP0<R`L
03L`7P0k<b00?c@P040e7`11=Al0?3@M040h8@17?B@0BclU04do901:>ah0ACHI04<b500m<Qh0>30K
03@/6@0`:AL0;RPH02dZ6`0_;Ah0<BlR03Hd7`0g=B00>SDQ03`e8P0l=240?34O03`_7P0j;A`2038]
5`03034/600a;1T0<B/K0080<B/M00<0<B/O034[7@0a:ad01P0a:ad0200]9aT0:bPI02XV6P0X9QX0
9BDK02<T700R9Ah08B@M0P0O8Q/201hQ6P<07B0I00<071lH01lR6`0O8Q/00P0N8AX201dP6@8071lH
02008B8J024S600Q8aP08bDH02HX6P0Z;A`0;S4N030c800h<BL0>c<V044d8`19=b40F3hS06]<;@23
Gc/0TVa709Ma@P2LN4@0Vga5095g?P24KS`0LEhf05919`0h9aD0:BlQ02P]9P0U:BX082<Z01dP9`0N
8RD08bPR02L]8@P092LP200W:R<00`0Y;2D09bXS02HY8P0202DX8@0D02LZ8`0Y;2D0:bhW02/^9`0Z
;1l0:bdP02h_8@0b<2<0=C8S03Tc8`0k=R<0?3DS03Ta900h<2<0=blR03H^8@0g;b80>C4T03`d9`0m
=BP303dh90D0?3LS00P0=34/03Db:`0i=BX0?SPZ044j9`13?280A3dP04Hm7PP0ED8T0200EDL]05=5
:P1B@RP0DT4U05=2901IARH0GTXY065=;01ZB2D0KD`Y06e@;P1WD2h0GTh/05Q;:@1ECBT0EDl]05I3
8`1IA2D0G4LX0619:P1RBB/0HdP[06A6:P1SABT0H4HU06579P1RBRP0HT/Y061<:@1NC2P0G4XV05U9
9@<0FT@/0P1I@b/305Q2:P0;0619:P1PBBT0H4LX06989`1WBRP0K4hZ071B;01eEBl0LUD[07EH;P1h
Fc400P1jGC<02`1hFc40MUT_07AG;@1gFRh0OV4e08EX?P24Icl0O5hh07AF<P1`DRh0L58`0080JeP`
00l0JeP^06eJ;`1bH380N6Hh07i/?022L400Ofi007e/?P1kJC/0NfHi07aU>@1nIc/0PFTm08=[?`1k
I3X00`1lIC/05@1mIS`0OVLm07mX?P20JCl0NF8h07aU>`1lIc`0MV<h06eL<01WFB`0J5X]06YM<01]
HSD0KF0d06eN<`1^Fc40KUL^06eD;01_DB/0KU0Z07MJ<00207UJ;P0507aK;P1oGBl0QF4a08US<P2;
IC@00P23JT40?`23J3d0Q6Dg08QT=02=I300U6L^09]Z;`2OKC00Y78e0:]h>@2cP3h0^hLn0<2;?`37
T3h0d9Q30=JNA`3?W4/0d9m@0<nSFP3=YV<0aJEX0;^RK02aVfX0ZIMY0:VFGP2UTUX0Wh]F09V5DP2C
Odd0SgY;08ehB`2<MdX0UG@o09=_>`2>JC@0S6D^08iS;02EIS00W6/c0:1]=P2ILCh0V70m09I^>P2E
KCT0UFhg09I_=P2GL3D0V74f09U^=`2LLSP0WG<i09Y`=02GKS00Ufh^09]b<02OMS@0WWi109Yj?@2D
M3L0Sflb08e]<02?Kc80TG4d09Ad=`0209A_>`0309E`?02FLCd0UW4m00<0UW4m00P0Sfhh08i]=`2<
JcD0RfXd08a[=@2=K3H0Sfhh091_>@80U6lj01h0Tflk091_?02=KC`0RFXk08IW>022ISL0P6Tm07eV
>P1lHCH0NUdc07eL<`23GCH0R64j08eS?@2DI3`0TF@k08mT>@2;ICH0RFPe08QZ=027K3D0R6lf08aW
<`2FLCd0VgM3091_>P1oH2X0N5XT08=U;`2?M3d209A`?P0409A`?02CL3X0Tg0j09=`>080TVle00H0
UG4m09=_>`2@K3P0S6Pd08YV<P29IC4208YV<P80Q6Td00<0Q6Pf08=W=`23IcP00P23ISX04@23IS`0
QFDf08=S=01oH340Nel_07UO;P1gH2h0N64_07QR<021HBh0Oel/07aN;01hG2`0MU//07ML;@1fGS00
Mela00D0NV0_00@0O68a07eS<P1oIC@0PFLf0P27IcH208QX=`0O08IV=@23Hc80P60_07iN;@1lGR`0
O5d^07]L;@1hFB/0Le@X06e=901WAb00I4@M061;801RCB80IDhR06YB901`EBH0METY07YL:P1lGR`0
Q6H`07eO:@1gFR80MeXP07aO8`21I2P0PFDV07mS9025K2`0QVd]08U`<00208Ya<@0308U`<027KRh0
QVd]0080QF/`00H0Q6Xa08=X<@22Ic80PFDc081T<P20I3@207YQ:`0>07UO;01iGbh0N5d^07ML;`1f
Fbh0MU/`07QL:P1jGR`0OF4_081T<P25JCL0R6`j08]_?@2=LCl808]a=P<0Qfdb0`26K34208E[<003
089Y<@21J300P6L_0080OfH^00<0PFP`08=Z<P24Jc<00P20IS<307mU<P<0OV@a0200Pel[08AS;P29
J3<0Sg0j09Eg@@2IOTL0WHA<09n6CP2AO4<0RG@k07mZ<`1hHbh0MV0^07AN;01`FRT0KELV06QB:`1W
DBX0IU0Y06A>9`1RC2D0HD/T061:8`1OBB80GDXR05a98@1KBB<0F4PT05Q89P1FAbH0E4LU05A79`80
DchO0100DChP04hm8@1<?280BcdS04Xk9018?2@0AC`M04@k7013>Qd0@CLL03le700m<Q`0?34K03/`
700g<B40<RlN0P0]:Q/01@0W9AP0820D01`N4`0I71406A`C00P05aTH200F61L@01DG5PP05QPG0`0D
5QD301DG5P805QPG200E5aH@01HH5a005aTH0P0H61H201TI5`806QXH1@0K6aT201`L6P<07AdK0P0O
7QT0100P7aX08B0K02<R7@0T8ah202DT7`P08R8J00@09RHN02@T700R8QX08B4I0P0P81P00`0Q8AT0
8R8J02<S6`0702<S6`P09alL00<07QdH01lN6@0O7QT00P0O7QT2020O6P808B0K0140824I024Q6@0R
8QX09B8K02LR700Z8ad0:b8M02`S7P0S91H09R@G02PT600]9AX0<2HL03DW7P0i:200>bPQ03P[6002
03P[6P0303LZ6P0g:A`0=RPM0080=RPO00<0;RLO02lX800`:B400P0`:B401@0^9al0;BHN02/T700^
9al0;bPP0080<2TQ00`0;bPP02`U7@0Z8a/0:24I02`R600]8aT0;R@J030V700a9ad0<bTO03@Z800e
:b4803HZ7P80>B/N00@0>RdM03X]700k;Qd0?2lL0P0m<A/01P0l:aT0?RdK044`7P13<R00AC@R04@c
8@80@c8P00P0AS4N04Lb7`18<ah0BSHN04/g7P1=>Ah0CSXO04ll7P<0DSXR0P1C>b<305@l900805De
801F=R40EcLR05Ph8`1J>RD0G3`W05dm:01N?RT206109`80GclV00@0GShU05dm901M?B@0G3`S0P1M
ARL0101MA2H0GT<V05m19@1P@BD206909@0605m28P1P@b<0H4<S0654901RABD0HdHV0P1TAbL206I8
9P0906M99`1YBbT0JT`Z06]=:`1/CR`0KDl]06Q59@1ZAbL0JdPX00<0KDXZ00D0JdPX06Y79`1YB2L0
JTTX06]::@0206a;:P0406]::@1YB2L0J4LV06Q:9P80JD/W00@0JT`X06]=:@1[CBT0K4hZ0P1]Cb/2
07E=:@0307==:01aCRP0L4hX0080KdlX0180KE0X06i@;01^CBX0K4/X06a:9`1/B2H0KdPW0799:@1c
BRX0Ld`S079;8P1aBb@0KT/U06a:9@1ZBBH0JDPU06M99`1WARD206Q79P0C06M69@1UA2<0HT4P05ln
7@1M?1/0Gc/K064m7@1U@B40J4@T06U59@1XA2@0ID4Q06<o7`1/ABP0J4<V06I1901S@280H3lP05ho
800205i18@80Hd@U0P1R@b@03@1SA2D0IDHW06Q9:P1YBR/0IdPY06E69`1R@b@0H44R06528`1UARL0
JDX[06]<;@1]CBL00P1^C2L00`1`C2P0LT`X07A<:@0207I;:@<0L4l/101_CR/00`1^CBX0LTlY07=@
:P0207=@:P80M54[0P1eDR`0401bDBh0L4l/06i=:P1]C2T0KTdZ071?;01cDRl0M5<`07aH>01kEcD0
NUHd07YF<P1jEc40O5Ta07iK<@1oG38307aI;`<0NeP^0P1jEbd207UF;00607QE:`1iER`0NUL]07eJ
<01oG380PEhd0P22H38208=Q<`0408AR=025HcD0QV@f08IT=P@0PEhd1022GcD208MR=@80R6<f0P29
I3L208YU>080SFLh0P2>J3T408mY>P0?091Z>`2=J3/0SVTl08mZ?@2@Jch0SfXm08eX>`2;IST0RVDh
08ER>024HCL0Pf0f089O=@21GS@0Oe`b0080OU/a00P0MeL^07IF;`1eEBh0Le<]075@;@1_CRd0KTd^
06e<;@H0IdPY0P1VAbP08@1OB1l0HTTQ06A;8`1XC2D0JD/U06];9@1ZB2<0JDLR06]::`1ZBBX0JTTX
06Y99P1/C2H0KThW075A:P1bDRT0MU<[07MD;01hEBd0NUL_07aI<@1nFc<0Oe`d081M=@25Gc/0QV0l
08MQ?028HS/0RVDk08]V>P2<Ic/0SFPk08eY>@0208iZ>P0308m[>`2@K3`0T6`l00@0TFdm00@0T6`l
08m[>`2=JCT0S6Ph0P2;IcL0102:ICP0RfHi08]V>@2<IcX208eX>`80SVTl00P0S6Ta08aY<`2;J380
RVHb08UU<`28I3@0R6<f08MR=@P0Q68b00@0Rf8f08aS=`2>ICT0T6Lk0P2AJ3`2091W>`03099V>@2C
IcX0U6Pk0080UFTl00<0TfLj095U>02@I3L00P2>JC`208eX>`0<08aW>P2;IST0RfHi08YU>02:IC00
RfHa08eX<`2?JSD0TF`g09=^>@2DKcX0UG0k202@KSh9095[?0H0Ug520P2HLT<0102LN4P0VWI609Qd
A02FLT8209Ea@@0509Ib@P2GLd<0Ug5209Qb@`2ILd@00P2JM4D00`2ILd@0V79309Ma@P0509Mc@`04
09QdA02IMDD0VGE509Ib@P80Ug=300<0V7A409UeA@2JMTH00P2KMdL309Mb?@0309Qc?P2IM3l0VWE0
0080VWE000P0VWA509UcA02HLT<0UFm009=]?P2AJc`0SfTj08iX>@80Sf/g00@0SVXf08eY=@2=JCD0
S6Pd0P2;Ic<0202>Jc40Sf`d091]=`2@K3X0T6/n08iY?@2<ISl0RfDn0`2;IcL[ooooo`00:_ooool2
0:9fA@80XGE400@0X7A309mc@P2OLd80WW91202PM4<0202JMT80W7M309iiA@2QNDH0XgU70:=gAP2T
MTD0XgE40P2PMT@209id@P0409me@`2QMdD0XgU70:EkB@<0YW]800<0YGY70:AiAP2SN4D00P2SN4D2
0:5gA@040:9hAP2SNDL0XgU70:AjB080YG]90`2XODH00`2WO4D0YW]40:Ej@`020:Ej@`050:AhA`2U
NDP0YGU80:IjB@2WNdX00P2XO4/01`2YOD`0XgU70:9hAP2QMdD0X7I409me@`2MLd400P2LLT0209ic
AP0509ebA@2LLD@0Vg1309]`@`2JKd800P2IKT40302AJcX0TV`k09=]?P2CKD00TFXo08mX?`2<IC`0
RV<l08mX?`2=ISd0Rf@k08QQ>0<0Qf0g00T0R64h08MM=`26G3H0QE/e08AJ=022F380P5H`07mE;`1n
E2h00`1fERl01`1eEBh0M5@]07=C;01bDR/0LE4Z06iB;@1_Dbh00P1`E2l0101_Dbh0KE4/06]?:P1Y
CBP206i@;00406e?:`1/CRX0K4hZ06]=:@80JT`X0100LU4`075@;@1_CR/0KThX071@:@1dE2/0NEX^
07aM<@1nFcD0OEXd07aI<@1lFBl0OE/^081N<023HC40QF<c0P25IcD01026ISD0QfLf08QV=P2:ISH2
08]U=P<0TVPf0`2CJCL209AZ>00809=Y=`2DJSP0UV`j09M]>`2HKS`0Ufdk09I/>P2EJcT209A^?`80
Tfdn00<0TV`m095[?02AJc`00P2@JS/01`2AJc`0TV`m099/?@2BK3d0SfTj08eW>02;ICH00`2=ISl2
08aU?P<0Rf@m0P2<IST308]U>0<0RV@g0`2;ICH208aV=`<0SFLh202?I3L8095V>@80T6Dh0P2AIST3
099W>P80TfPk0`2CJCL00`2DJSP0UF/i09I/>P0209I/>P80TF/l0P2BK3d01@2CKCh0U6ho09A^?`2E
Kd00TfXf00<0TVTe0P2AJ3@2091W<`0608iX>@2=IcP0SFLh08]U=P2:I3D0RF<d0P28HS<408US=080
R68c0P27HC8808MS<`P0Qf8e0P2;Hc801P2:HS40RF4`08YR<@2<I3<0SVHe08mW=PP0S6Tc00<0TFdi
091/>02>JSH00P2=JCD0502>JSH0T6`h095]>@2DL3`0Tflk095]>@2@K3P0Sf/g091/>02AKCT0TVhj
099`@02?KCd0S6Xj08e[>`2AKcl0TW10091^?P2=Jc/0S6Lj0P2;JC/06`2:JS/0R6Tj08AX>021IcH0
OfDd07iM<01lFc00N5P_079D;P1/Cbd0IT`[06=8:`1QB2X0Cd@T04i39@1=@R@0Bd0T04Tm8`17>b<0
ASXT04Di8`14>BL0?cHU03`c8P0g<200<bdO02l[7`0202d[7`0@02X]6P0Y;1T0:B`K02PZ700W:A`0
9RPM02DW700U9Qh092LP02<V7`0Q91d082<L01lR6`0P8a`08B@M028U7P<07b8I0P0P8aX4024T6`80
9BTH00@092PI02<W6@0R9AX08B@K0P0P8a`301lR6`8082<L0`0Q91d2020U7P04028U700S9AX092HI
02DV60809bDF00H0;2TH02h[6P0c;Q/0=c0M03Xb7`0l<Ad203da6`0@048e4`13=QH0A3TI04Dl7@14
?B00@SdP040j800n>Ql0<bdQ038/7P0a:ad0;bTI02lZ5`0`:aL0<B`F038]5`80>S8K00@0>C4L03P`
7@0h<1d0=bhM0P0f;Ah202l[7`<0;RXN0`0]:Ad01P0_:200;BTP02dY800]:R40:b/Q02X/8@80:B`Q
00@09RTP02DX7`0U:1l092LN0P0S9Qd2028U70<08R<M0P0Q8Q`3020Q6`807AhH0P0N7aT201lP6P80
824K01P08RPT01lT7P0P8a`09RHL038^8P0j<b<0?3<R03`a7`10=Al0?S8J048c5P1A?A`0ITlV07aP
<@2;JcX0TG0k09Ak@`2AM3`0U7<m09IfA@24J4<0Fd/d03Hb:@0V:R/202DX8@<092LP0`0S9Ql302@W
80809BPQ0`0V:B8802HW8@809bPS00D0:2TS02X[8`0[;B80;2hQ02d_8P0202h`8P0@03Ha7P0i=240
>cHS03Td8@0e<1d0<RdJ03@_700g<Ql0>RlM03/b8@0n=B@0?3DU03Pb900e<BD0=S@X03Xh;0@0=c<W
100f<RH07P0h=B@0>cDU03dh9@10>BH0A3`W04Pm9`1;?bT0C40X05Y79`1IARH0Ed@V05I29`1F@RT0
Ed<[05U4;`1JAC00D4LX05=49`1I@BD0GT0T06139@1OB2H0GDlZ05]D:P1SER`0HE</05i@:@1KCBP0
FD/X05Q9:080F4TZ0P1JAbL305]8:0<0G4TY01H0GD/U05i<9P1PCRP0HDlY061>:01NC2H0G4XT05]9
8`1FAc80Dd@_0510:@1=>b<0CSXQ050k801C?R<0EclS0653:`1SAB/0ITP^06U;;`1[CS00K4l_0P1[
CR`00`1]EBl0KUH`071H<P03079J=080L5Pb01X0M5dc07UP=`1kHST0O60h07YM=@1lG3D0P5hh08AR
?01fF3`0LE@f06m@<@1eE340PEli08i]@P2HMTT0W7Y<09AaA`2BLDP0Sfm608U]A@22Jd80OVQ107QV
@01gICl0Melk07IN>P<0M5`h00/0MEdi07MO>`1hH3`0LFH`071T<01`HS40LF0d071M<`1aFcH0L5Tg
071G>002071A<P0>06mB<01_Dbh0KUD]06iG;@1_FRl0L5/^081D8`22ERD0Q5`Y08IQ;@25I2l0Q6H`
089W<021J30208=O?@0`08EO>P29GcD0Sf@a09]Z<02ULS00/7Xb0;Mo=02gPbl0^HDa0;f;=P30T3/0
a9I00<JJ@`38W4D0aii60;RWC@2iZE@0^ZYL0;JYI@2_YFX0YYa[09ZCJ@2ESFP0ThMO09:5F`2BPEH0
T7]>091eAP2?Kch0Sf/i08iY=@2BHcL0T6@e08mS<P2?IS80T6T`099^<02FM3@0V7Ld09=c>02DM3T0
UWHk09Mg?02EMCX0TW8g08m_=02=KC80UG4g0P2DL3H509=_=@80UGHm00@0UGDl09Md?02GM3`0Ug8k
0P2ILS/00`2DL3@0UG4e09Mc=`0209Mc=`0609Ea=@2BKS80TFda08mZ=@2@JcH0TVdh0P2DKcX09P2C
KST0TF`g091[=P2BMC<0TW@d091b=02?L3L0SFhh08][>P2:JS/0RFPk07iS=P1oHSH0Pf8g08MR>02;
GcP0T5hi09AN>P2EGCX0Sf8[091R;P2?I2l0T6Lc091X=@2@JST0TF/l095]?@2DKcX0UG0k09=^>@2>
JC@0RVD`08]V<@2CKST0VgI109Mc=`2DL3@0T6``0P2=JBd02`2@K300UG4e09Qd>02FLSH0V7@h09Mc
=`2DL3@0Sf/_08iZ;P2AKC40UG4e0080QfPa01L0QfPb08MW=025IC@0Q6@e089R<`21H3<0Pf4d085P
<`20Gc80OUla07YN;`1hGBh0MEd]07AL;028HSD0QV0c08=N<@1nG2h0O5`]07]L;@1lGBh0NUh^07QF
:@0207]I;00707iL;`22H3<0QF<f08IT=`27ICP0QV@g089S=@02085R=0<0P64c0P21HS@0601kIC<0
NfDd07YT<`1hHS<0M5da06mH;P1ZDbX0Ie0W06A6:P1XBbd0KE0`075E<01dF300MEX_07AI:P1cF2T0
OEl]07iP;P1mGbd0N5XX07=E8`1eEbD0OEl]08EW=@<0R6Xd1@29JcD208AZ;`0308AZ<@23J340PfPc
0080PVHd00<0PVHf07UO;P1iGbh01P1iGbh01P1nHS80P6@b089V=025JSD0QV/d08M]=080QV`a00@0
RFlf08Y`=`2:L3L0Rg4h0P2<LST208ec>P80S78i00@0Rg4h08Y`=`29KcH0R6he0P27KC@4089Y<@@0
PFP`0P20IS<00`1oIC80OV@a07eS<00207aR;`0A07]Q;P1kGbd0OV8`089V=028K3X0T7A209QlBP2O
Pe40XhME09f3AP2HOT<0T7Hm08M/=`20I3@0Nel`07QK<@1gFS00101ZDbL0501YDRH0J54U06M@901V
Cb<0HdTT06988`1PB2@0GTLU05Y69@1HAB@0Ed@T05A48`1A@Al0D40N05107`1??R00CSdQ04dl8P1<
>b40BcTQ0`12=Q`5044e6`0903<^6P0b;AX0;BXI02dZ6@0Y9aX09BDK024R700O81/07AlL00806Q`I
0P0I6aP301PJ5`@05aTF0P0F61D301DG51005QPG400E5aH@01HH5a005aTH200F61D801TK60<06QXH
0`0K6aT201`L6P807QhF00<07alG020P600Q8AT00P0S8a/00`0T91`09B4H02DQ600602DQ60T09R8I
0`0W8aX202PT6`80:BDL200Z8Ql00`0Y8Ah0:20M02HN6`0302DM6P0C02HN6`0X81d0:B4N02TQ7P0X
81d09b0J02LP600X8AL0:R@H02`V600^:1X0;b8I030S6P0a91/0<RDL03<V7@0d9ah0=BPO03HY8002
03HY6@80=bXJ00@0>2/K03T/700j;Ad0>RdM0`0g:A`00`0f:1/0=BLJ03@V6@0203@V6@P0<2XN0P0Z
91P0100[9AT0;2HJ02`V6P0]9a/202hX700:02lU6`0`9QX0<BLK03<Z6`0e;1/0=blL03Ta700j<Qd0
?bdS03h/8P80?B/O00@0?R`N040_7`12<Al0A3<Q0P0o<1T01011<AX0@c4K04Dc7@18<ah204Xd7`0>
04`c7`1==200CSDO050h801A>Al0Dc/O05@m7P1E?Ql0CcDN050f7`1A=b00DSPQ05@j8`1E>b@205Hl
9@0905Pj8P1G>B40ESPP05Hh801G>B40FC/S05/m9@1M?bL0FT8P0080G48Q00<0GT4Q06118P1R@B80
0P1T@B<01P1WB2T0ITLX06E69`1TABH0HT<T06118P80Gd0Q00<0IDLS06A68P1SAB400P1SAB406`1U
Ab<0ITPT06Q:9P1UBB@0ITXU06Q:9P1[BRL0KD/X06m;:@1`C2X0Ld`[07AA:`1bCbT0Kd`V06a98`1[
B280K4TS06i;9@1`CBL0KD`Y06a;:01ZBBH0JDPU06Q7901YB2D0JTTV06]:9`0306m<9P<0L4dW0`1a
CRP01@1gDBX0MU0Y07I@:@1eCbP0M4hW0080LddV00T0LT`U07E@9P1dCbD0LD/T06m9901^B2@0KTLV
0719:01aBR/00P1_BB@00`1^B2<0KDLR06a68@0206]5800506Y47`1[AR/0JD@Y06I19P1S?R<00P1R
?B80101S?R<0I3lT06M69@1WARD206Q79P<0JDPW0180JTTX06Y9:P1YB2T0IdHW06E49@1T@b@0ID@U
06I59P1WARL0H44U06939`1UART0IdP[06U::`1YBbT0J4XV06M99@1TAbL206E8:00306I9:@1WBRX0
IdXZ0080J4/[00H0KDdV06i>9`1^CRL0KdlX071@:@1aDBX2079B:`<0LddV00<0M4hW07E?:01fD2T0
0P1fD2T01P1aCBT0LDlZ075?:P1`D2X0Ke4[06iB:`80KE@/00<0Le0X07AA:@1fDb/00P1gE2`00`1f
Db/0M54Y07=@:00207QE;@0407UF;P1jEbl0NeP`07]H<080O5Ta00<0NUPZ07]I:`1lFR`00P1lFR`0
0`1jF2X0N5HX07ID9P0207aG;@80NeH/00d0OEP^081K<@23GS@0QF0f08EO>026HCL0Qf8h08QS=`28
HcH0QV8b08EQ;`24H2h0P5h`0080PEla00<0PV0b08=Q<`24HS@00P25HcD208AT=@80QFDf0P26ISL2
08MW>00508aX>02=JCT0SFTi08iZ>P2?Jc/00P2@K3`2095]?@P0TFdi00H0TFdm08m[>`2;IcL0Qf<c
08AP<022GRh2085M;@0>07aO<`1kGS80NE`b07MJ<01eF300LeD_075C;`1`DRh0KThW06i>:01]CBL0
JdXW06Y9:01XAbP206M5:@040694801SAB40ITPT06U;9`80JT`X01X0JD/W06Q:9P1^CB`0KD`[06a;
:P1[BRT0K4/Z06i=;01aD2l0Le8a079>:P1cCb/0ME8/07MD;01jEbd0OE/^07mM<020GS00PE`b089M
<`23GS@0QF0f08MR>029I3X0RVDk08]V?0P0T6Xk0`2@K3P208m[=`<0SVXf00H0S6Pd08eY=@2>JSH0
T6`h099^>P2CKc/209Ea?@80SVTe00H0SfXf091[=`2?JSH0SFPd08]V<P2:IC4408eX?080SVTm0P2?
JSh0102?JSD0T6/f091[=P2AK3L2099]>080Tfhi0P2HLcl0102GLSh0UW4m09Ia?@2EL3`209A_>`0;
099_>@2AKCT0Sf/g08iZ>02>JSX0SfXm095/@02BKD40T6Xk08mY>P2>J3T00P2=IcP01P2?JCX0TF/l
09=]?P2DKT40UFm209I`@`80Ug5400T0UW1309E_@P2DKT40V7<n09Mb?@2EL3/0Tfhi099]>02CKST0
0P2EL3/00`2FLC`0UG0l09E`?00309=^>P0;09E`?02GLSh0V7<o09Qc?`2IM400VgI209ag@`2KMT80
VWE109Qc?`2FLCd00`2HM4000`2IMD40VWI209]g@`0209]g@`0409Ib@P2GLd<0Ug=309Mc@`<0V7A4
00<0VGE509QdA02HM4@01P2HM4@0202FL440UFm009A^?`2CKCh0U6ho09I`@@2ILd@0VWA50P2ILdH0
2@2GLD@0UFm2099/?`2@JSd0SfTl08iX>`2@JS/0SfTj08eW>00208aV=`0808eW>02?JCX0T6Xk09Ia
?@2EL3`0Tfhj095/>02@JcL208iY=@0408eX=02?Ic@0SfLd08mW=2_ooooo000Zooooo`80XWI50P2Q
MD@0102PM4<0Wg=209mc@P2OLd880:1d@`0@09Yf@P2LMd<0WWU50:5iAP2SNDL0XgM60:AfA@2SMD@0
XGM50:1fA02OMD<0WWA209me@`2PMT@0XWQ60:=iA`80YGY70P2TNDH20:=hA@80XWM40P2QMdD0102R
N4H0XgU70:=iA`2TNTP20:EkB@80Z7e60P2WO4D20:IkA080YGY3102VNTT40:MkBP80XgU700H0XWQ6
0:1fA02OMD<0WWA209ec@@2LLT0209icAP0509ebA@2LLD@0Vg1309]`@`2JKd800P2IKT403P2AJcX0
TV`k09=]?P2BK3l0TFXo08iW?P2<IC`0RV<l08mX?`2=ISd0Rf@k08QQ>027H3L0QUlf0P27H3L01P27
GCL0QU`f08EK=@24FS@0PUPb081F<080OeD_00H0MeL`07IF;`1fERl0MED^07AD;@1cDb`2079B:`09
06eA;01^DRd0Ke<^071D;`1_Dbh0KU8]06a@:`1[CbX0KU0/0080KDl[0P1/CRX206]=:@0A06Y<:01b
DC00L4l/06m>:`1^CRP0L50Y07AD:`1iFRh0O5da07eJ=01lFC<0O5Ta07aI;`1nG2l0PEla08AR<P25
Hc<00P25IcD01P27IcH0R6Hf08YV=P2;ICH0S6Hg08iU=`<0TVPf0P2CJCL309AZ>00309E[>@2FK3X0
V6hl0080VFlm00<0Ufdk09I/>P2EJcT00P2DKSl209=]?P0<099/?@2AJc`0TF/l095[?02?JCX0T6Xk
095[?02BK3d0TF/l091Z>`2>J3T0SFLh0`2=ISd208aU?0<0Rf@k0P2<IST308]U>0<0RV@g0`2;ICH2
08aV=`<0SFLh202?I3L=095V>@@0TVLj0P2BJ3H209=Y=`80U6Xh0P2EJcT2091Z>`80TF/l0P2BK3d2
09=]?P@0TVPf0P2AIcD2091V=00608iX>@2=IcP0S6Hg08]U=P2:I3D0RF<d0P28HS<0102:I3D0RF<d
08US=029Hc@208QR<`80Qf4b2027Hc<808MR=@0808aT<`2;Hc80RV8a08UQ<02:HS40S6@c08iV=@2?
IcH808eY=@03095]>@2@K3P0SVXf0080SFTe00H0SVXf091/>02AKCT0T6`h08m[=`2=JCD208aX=00<
08iZ=P2?JcL0T6`h095_?`2>K3`0S6Xj08e[>`2AKcl0TW1008m]?@2<JSX0S6Lj0P2;JC/04`2:JS/0
R6Tj08=W=`20ISD0OfDd07iM<01lGC40N5P_079D;P1/Cbd0ID/Z0658:P1OARP0CT<S04i39@1<@B<0
Bd0T04Tm8`17>b<00P15>B<01P12=bD0?SDT03/b8@0f;al0<bdO030/8080;R`P0100:RdJ02T/6@0Y
;1/0:2XL02LY700V:1d09BLL02DV7P0T9b008bHO024T7@0P8a`07b8K020S700Q91d08RDN0P0O8QT3
020S6P@08B@K0P0U:AP0100T:1T08bLI028U6P0Q91/2020S70<07b8K0P0P8a`3024T7@8082DN00@0
8RDL02@V6`0T9QT09BHH0P0X9QL03@0]:QT0;R/J03<^6`0g<1d0>S8O03db7P0n<Q`0?C4K04<f5P14
=aL0@cPJ04<j7@12>al00P10>R002@0n>R40<R`P034[7@0`:Q`0;bTI030[600a;1P0<bhH03@_6@02
03Xb6`0403Ta700h<1d0>30M03L^7@80=RdN0P0_:al302hZ7P<0;BTM00H0;bPP02dY800]:B00;2TP
02XZ800Z;24202T/8@809BPO0P0T9ah202<V7@808RDL0`0R8ad2024R70<0824K0`0N7aT501lP6P0H
020U7`0P8a`08R<K02XX700e;b40?3<R03hc8@0m<1d0A3PP04Dg7@1;>Q`0FTHS06mF;P22ISL0Sfln
09Ac@02>MCl0TgDo09If@`2<KCl0KUHd04Xk9P0`;BH09b//0P0U:24302@W80<08bHO0`0T9b0202DX
8@<09RTR200V9b401`0V9b809bPS02PY8`0Y:R80:R`Q02`^8@0];b800P0];b40400f<Ah0>C@Q03`g
900j=B80=S4N03@_700g<Ql0>SDR03db800n=B@0@3LV03df9P0h<R@0=30T03Dc9`0h=RX403Lc9`@0
=S8V01`0?3HV03dh9@10>BL0A3`Y04Tn:P1<@2X0CT8Z0552:`1JAbL0FDHV05M49P1F@RL0ED4X05I2
:P1G@Rd0F4<^0517:01DABP0FT8V05i0901QA2H0H4TW05e?:P1KE2X0HU@]065C;01ND2/0FddZ0P1H
BBP205Q9:P80FTLW0`1KB2P305a9:@0K05a:9P1MBbL0GT`X05m=:@1NC2P0GD/W05]99@1JB2@0Dd@_
0592:`1??bP0CS`T050l8`1C?R<0F40T05Y29P1Q@bT0HT@Z06E7:`1XBRh0JTd_06]>;P1[CR`0JTd[
06aD;P1]EBl0KeLa00<0LETc01d0L5Pb06mG<@1bFc80N5lf07aS>P1nHSX0OF0f07mO=P23HST0QVDl
07mP@@1jFc`0MUPd07YJ=023HST0S6]0099aA02ELdD0U7=:095aB02<KdL0QVY207iW?P1hHS/0LUhi
06mM=`1_F3H0KULe06eF=00206aE<`0K06iG=@1_F3H0L5Tg06YN:P1YGB/0JU`]06]J;P1/FC40KELb
06aE<`1]E3D0Ke8b06iA<@1]D2h0Je4/06aC:`1]ER`0KeP^06mJ;@21EbD0PeTW08=N:P25HBd0QF@_
08AV<022Ic00PFP`0080Pf0j01l0QV0i08]R=P2AIS40WF`a0:Qe<`2cOCD0^X8g0;Z7=02lRCH0_Xhj
0<:D?`35V4D0aI]70<NMB@36WD/0^:EF0;RVFP2gYV40/ZAW0:ZMJ@2PTfT0U8YV08n4I02=P5H0S7eD
08ejC`2=MdP0SW9308m_?P2@K3P0SfXf0080TVHg00H0TVPf09=Z=02DKC@0UG4c09Id=02HMSH409Ad
>@0409=c>02ALCH0Sfld08i^<`80UG4g1P2DL3H209Ae?00909Ad>`2FLc/0UG8j09Ia>P2HLCX0Ug0i
09A`=02ELCD0UW8f0080Ug<g01/0UW8f09Ea=@2CKc<0U6lh09E`>@2GLS/0V7<l09Ud?@2HLc`0UW4j
09E`>@2@LS80Sg4c08i`=02<KC@0RV/e08QX=@26ISD0QVHg07mS=021HS@0Q68e08QQ=P2=HSP0TV4i
09EQ>P2FH3X00P2CIRl05`2BIc80TVTe099Z=P2AK3P0TV`k095]>`2FLCX0Ug8k09E`>@2@Jc@0S6L`
08iY<P2EL3T0W7M009Ib=P2DL3@0Tflc099^<P2DL3@0Ug<g09Yf>P2MNCd0UW8f0080V7@h00/0U70d
08m[;`2>JRh0TFda09Ea=@2;K3D0RV/d08UZ=028J3D0QVHe08EU=00208EU=P80Pf4d00l0PF0c07iO
<@1kGc00NEh_07QM;P1eGBd0Ped`089L;`1oFRd0OE/]07aL;@1lGBh0OUl`07eQ<@1mFbh00P1nG2l0
1P21Gc80Pf4d08AR=@24HSD0Pf4d089P<`80PV<e0`21HS@3081Q<`80Nf@b00l0NV8b07QP<P1eGC40
LEP_06eD:`1[DRX0ITT[06Q;:`1[CR`0Ke<^075E;@1cF2d0M5T/07AI:P1mGbd00P1oHBl01@1kGB/0
MeTW07MI9`1mGbd0PV@b0080QVPb0`27JC<308QZ=080PfT^00<0PfT`089W<022Ic800P21IC<01@21
ICD0NV0_07YP;`1jH2l0NEl^00<0N5h]00L0Med/07eQ<@1oHc40PVHd08EZ=@27K3D0R6he0080R6hc
0P2:L3L208]a>080S78i102=LcX0102<LST0Rg4h08Y`=`29KcH208Q^=@D0PVTa0`21J302081V<`03
07mU<P1nI340OF<`0080O68_0240Nf4^07aP;P1nHS00PVHd08Q/>P2?Ld40Ug]909j2D02RQU@0WhE:
09^1AP2CN440Rg0k089V=P1lH340N5/_07II;`1_F2`0KUL[06aE:@1ZDbL0Ie0T06E>8P1SC200HT/O
06=:8P1RB2<0H4PR05i88`1KAb@0FDHU05Q59@1FARD00P1B@R001P1A@B00CchP04hm8@1<>b40BcXP
04/i8@@0@SHL1011=A/02@0d;a/0<bhK02h[6P0^:aX0:bLK02HS6P0Q81/07QlJ01`L6P0201XL6@80
6A/H100H6QL301LI5P<05QPE0P0E5a@@01HH5a005ALF400F61L@01LI60P05QPE200I6aP301XJ6080
6a/I0`0L71X201hN5P0601lO5`0P81P08B4I028R6P0S8a/092@L200U8AP;02LS6P80:2@K0`0Y9A`8
02XR7`0302TQ7P0X81d09alL00<09QhK00/09alL02PP7@0Y8Ah0:B4N02PP7@0X8A/09b0H02PQ5`0Z
91P0;BLI02hX6P02030S6P04034T6`0b9A`0<bHM03@W7P80=BPO0P0g:QX0100h:a/0>B`L03T/700j
;Ad203/^7P80>B/N00<0>2XM03LY700g:A`00`0f:1/8038Z7@0302lW6P0`:1/0<2PK0080<BTL0P0b
:Qd05`0c:ah0;bDK030V6P0b:1`0=2/L03H]700h<1d0>C4L03Xb7@0o;B<0?R`R03h/800m:ad0?RdM
040_7@12<Al0A3<O03l`6@10<AX0@S8K04@b7015<ad0B3<N0080BS@O00P0C3<O04dd801>=Al0D3PP
054i7`1C>al0E3dN05Dn7`80D3HO00L0DCLP058h8@1D>R<0EC/T05Hl9@1G?BH0F3XR0080EcTQ00H0
ESPP05Li8@1I>b<0FcdU05do9`1K@b4205a28@0305m28P1P@B80Hd8S0080I44S1@1R@b@306=49@0=
06I8901UAb<0I4HR06=58@1TAR80IDLS06M99@1XBRH0ITXU06M;9P1XBRH0JdXW06i<:@02071<:P04
07=<:`1bCbT0LDhX071=9`@0KT/U00T0Kd`V06e<:@1/BbP0JTTV06U89@1XAb@0JDPU06Y99P1[BRL0
0`1_C2H4071=9`80LDhX101eCbP407A>9`0907E@9P1dCbD0LT`U071:9@1_BBD0KdPW0719:01`BBX0
LddX0080LT`W00<0LD/V071:9@1_BB@00P1^B2<0101YA2T0J4<X06I19P1T?b@206<n8`0406@o901U
@2D0ITDT06I59080IdHU0`1XAbH03P1YB2L0JdX[06Y9:P1XAbP0ITDV06E49@1VABH0IdHW06Q7:01Q
@RH0Hd@X06E6:@1XBBX0JD/Y0P1YBbL0101XBR@0IDPX06E8:01VBBT206M::P80J4/[00H0JD`/06e=
9P1]CBH0KThW06m?:01`D2T2075A:P04079B:`1cCBH0M4hW07A>9`80MDlX0P1fD2T01P1gDBX0LThZ
079>:P1aCbX0LE4[06mA:`80Ke</00@0KE@/07AA:@1eDRX0MU<[0P1gE2`00`1fDb/0ME8Z07AA:@02
07QE;@0307UF;P1jEbl0NeP`0080O5Ta00X0OEXb07]I:`1kFB/0O5X/07eK;@1lFR`0NUPZ07UG:@1g
EBL0OEP^0`1lEbd0301nFBl0P5/a08=N=025H3H0QElh08IQ=`27HSP0R6<g08QS=P26HS80QF4_08AP
;P80PEla0P22H3801023HC<0Q68d08ES=@25HcD308EU=PD0QVHg0P2<J3P00`2=JCT0SVXj08m[>`02
091/?080TFdm202AKCT01@2@K3`0SVXj08YV=P27Hc<0QF4a00<0Pel_01@0P64c07mP=01mGS80NUXa
07QH<@1eEBl0Le8_079A;P1_CbP0KThW06e=9`1/BbP0JdXY06U8:@1XAbP0J4HZ06=58@1TAR80IdTU
06U;9`80JT`X00@0JD/W06Q:9P1^CBX0KD`Y0P1/BbP0301]C2T0Kdh[075@;@1cDRl0Ldl[07A@;01f
Dbd0N5D]07YG;@1lFRd0OU`_07mM;`80PUdc00@0Q5le08EP=P27HSP0RF@j0P2;IS`8091Z>`04095]
>@2@K3P0T6`h091/>080Sf/g0P2>JSH01@2=JCD0SVXf08m[=`2@K3P0TFdi0080Tflk00T0U70l08mZ
=P2?JSH0T6/g095/>02@JcL0SfXf08eX=02;IS800`2>JCd208mZ?P<0T6/o0P2@JcH00`2AK3L0TVdh
099]>00209=^>@0309A_>P2HLcl0V7<o0080Ug8n01<0UW4m09E`?02EL3`0UG0l09=`>P2BKSX0T6`h
08m[>@2?Jc/0T6/n099]@@2CKT80TV`m095[?02@JS/0SfTj091Z>`2AJc`0Tfdn0080UFm000d0UW11
09Qb@`2ILd@0VG=409Qb@`2FL440UFm009Qc?P2GLSd0UG0k09A_>P2CKST0U6lj0080UG0k00`0UW4l
09Ia?@2EL3`0U6lk09=^>P2DKc/0UG0l09Mb?P2HLcl0VGA009Ye@@2KMT8209ag@`0309]f@P2IM400
V7<o0080VGE10P2JMT8209]g@`80W7Q41P2HM4@:09Mc@`80UW110P2DKSl0102EKd00UW1109Qb@`2J
M4D209Qb@`0909I`@@2EKd00Tfdn095[?02@JS/0SfTj095[?02@JS/0SVPi0080SFLh00L0SVPi091Z
>`2AJc`0U6lk09=^>P2BKCT0TF`h0080T6/g0P2?JSH308mW=2_ooooo000Zooooo`<0XGE40`2PM4<2
09mc@PP0X7A300/0VWI209ag@`2NNDD0XWY70:=iA`2SMdH0Y7I50:=eA02SNDL0XWQ60:5gA@0309me
@`030:1fA02QMdD0XgQ50080XgQ50P2RMd@30:5f@`80XGM500@0XWQ60:=iA`2SNDL0Y7Y80P2UNdT0
102XODP0Yga70:MlA`2WO4L30:IkAP030:EjA@2WNdX0Yg]:0080Yg]:102VNTT01P2TNTP0XgU70:9h
AP2QMdD0X7I409id@P80WG=10P2NLdH01@2MLTD0W75409]`@`2KL4<0VVm20080VFi10P2BK3/02P2B
K3d0TV`o091Y?P2>Ich0S6Dl08]T?@2>Ich0SFHm08YS>P28HCP208IO=P80Qf0g0P24GCH01P23G3D0
PEXc081I<P1oF340OUL`07eF;`80MeL`00@0MED^07AD;@1cDb`0Le</0P1bDR/01P1]Cb/0KU0/06mA
;@1`DRh0LE<_071B;P80Ke4]0`1]Cb/206a>:P<0JddY00P0LE0_071?;01_CR/0KdlY075A:P1dE2/0
N5T]07]L<080NePb00H0O5Ta07eJ<01oGC00PV0b08ES<`27ICD208IV=@0608QV=P2:ISH0RfLg08aV
=`2>ICL0SfHh0P2BJ3H209=Y=`<0U6Xh00<0UF/i09Q^?02IKcd00P2JL3h0102IKcd0Ufdk09E[>@2D
JSP309=]?P<0TV`m0P2AJc`208iX>@06091Z>`2AJc`0TF/l095[?02@JS/0SfTj0`2=ISd208aU?0<0
Rf@k0P2<IST308]U>0<0RV@g0`2;ICH208aV=`<0SFLh202?I3L8095V>@80TVLj0`2AIST4091U>0<0
TFLe0P2BJ3H309=Y=`@0SfTj0P2@JS/2095[?0<0TVPf0P2AIcD3091V=080SFLh00<0S6Hg08]U=P2:
I3D00P29Hc@01028HS<0RV@e08YT=@2:I3D208US=0<0R68c2027Hc<808MR=@0808YT=@29Hc@0R68c
08MQ<P28HS<0RF<d08]U=P2<ISL808iZ=P03091/>02?JcL0SVXf0080SFTe00<0SVXf08m[=`2@K3P0
0P2;Ic<0;02:IS80RFDa08YV<P2<J3@0SVXf091/>02AKcl0SV`l08]Y>@2<JSX0T6hn095_?`2?KCd0
RfTi08aW>P2:J3X0RfTk08UY>P27J3T0PVHf07mU=01mHc80OUla07aM<@1fFBl0L5@]06Q>:`1RBRP0
GDHW05]49@1>@b<0CD8T04a18`1:?b<0B3`R04Hj8P15>B<0A3PR03ld8P0k<R40>C0O03D^7P0c;Al0
<BdQ0P0`;R804@0Z;AX0:B`I02T/6`0X:Q`09bTL02HX7@0U9a`09BHN02@W800S9Ql08B@M020S700O
8Q/082<L024T7@0R9Ah07b8I00<082<J0P0Q91/3028U70809BTH00@092PI02<W6@0R9AX08B@K0P0P
8a`301lR6`8082<L0`0Q91d2020U7P0402<V7@0T9Q/09BLJ02HW6@80:BLH00H0;BXI02l/6`0d;a`0
>34N03/c800m<Qh203hb700@04Hi6@15=aX0@SLI044h6`0o>1`0?SPN03li8@0n>R40<2XN030Z700_
:A/0<2XJ034/6@0c;QX0=S4K03Lb7080>S8K00@0>C4L03P`7@0h<1d0=bhM0P0f;Ah202l[7`<0;RXN
0`0]:Ad0200_:200;BTP02dY800/:B00:RXP02T[800X:b009bXO0`0T9ah302<V7@808RDL0`0R8ad2
024R70H0824K0`0O81X201hO6@0H01hQ6P0P8AT09BDK02l[7`0i<R80@3DS040c800o<1/0BCTO04dl
801HABD0JE<^07]R>@2:KSl0TWA209Ee@P2:KS`0U7Q8099eB@1fGCD0DChP03H[6@0[:2409b/Z0P0U
:24302@W80<08bHO0`0T9b0202DX8@<09RTR200V9b401`0U9R409RLR02LX8P0X:B40:R`Q02/]800/
;R400P0];b40400f<Ah0>SDR03`g900k=R<0>3<P03Lb7`0j=B80?CPU04<h9P13>RT0A3/Z040i:@0i
<bD0=30T03<a9@0f=2P403Hb9P@0=c<W00h0?STV040i9`12>bP0AShY04]0:P1?@b/0Dd@]05A6;01K
B2P0FTLW05M49P1E@BH0E40W05<o9`80E3lZ00h0DDPY05E6:@1K@bL0H48V06959`1PBBL0GDlZ05YC
:@1QDb`0Ge4/05a>:@1IBbP0F4TX05M8:@80EdP[0P1JAbL305]8:0<0G4TY0P1KBBD305a:9P0A05Y8
901IAb<0F4HR0510:@1??bP0CcdU054m901D?b@0FD4U05e69`1PAbT0HD<Y0694:01UAb/0IdX/06U<
;01ZCB/00P1[CbX00`1[Dbd0K5@^06iF<002071H<P0N06mG<@1^ES00KED_06eF;@1dFc<0Nf8i081U
>P20HcL0PV<g08ET=`28IcX0QFDo081P>P1kFc@0O5`c081Q=@25ISP0QVLi08EV=`2?LTP0S71808IZ
@P1nICd0MUhh06mI=01YEC80Ie<`06QA;`1WD2h0ITl]0P1UCR`00`1VCbd0Ie0^06QA;`02069F9P0D
06=E:01VEBX0Ie@/06YD;`1ZDc40Je<a06YB<01YDBl0J50/06Q@:P1YDRT0Je@Z06eF;01_F2`0PE`X
089M:@23Gb/0Q6<^08AU;`24IS02089W<080QV4g02D0R68e08iT<P2DJC80XG4c0:]j=@2fPSL0^hHj
0;f>?02oT3h0`IA30<:GB034Vd`0`ia?0<>ND033WE80]J5R0;FQI02bWfL0ZiUY0:>AJ@2GQfD0SGiQ
08MgGP26LdT0Qg9708QaA@2;L440SFlm08m^>@2AKSP0TF`e09IZ>@2FK3X0V6lk09Ub>`2HM3X0UgDh
0080UGHf00@0UGDl09Ad>`2BLST0TG4h102@L3L309Ea=@80UW8f0`2ELCD2099c>P0:099b>@2DLCT0
Tg0h09A_>02FKcP0UFhg09=_<`2DL3@0UW8f09Mc=`<0V7@h00@0Ug<g09Ye?P2KMSl0W7M00P2MN440
2`2LMd00VgHo09Ye?P2CLcH0TW8g095a>02?KcH0S6/f08YY=029J3D0R6Hf0080Pf<b00h0R6@d08aS
=@2@I3L0UF@i09QU>P2JIC/0VF`a09U/<`2GKC<0UVde09E^=`2CKST0Tfhj099^>P80VG@m02H0Ug8k
09=^=`2@Jc@0TVdf09Qc?02MN440UG4e09Ib=P2GLcL0VGDi09Yf>P2LN3`0WGTm09ij?P2ELCD0Ug<g
09Qd>02ELCD0TFda08m[;`2BKS80UW8f095a>02?KcH0RfXd08QW<P27IS<0QfDe08UW=`2:J3X0QV4d
08AR=023HC<0P60a07iO<01kGbl0NEl^07QN;@80OUP[00H0OEP[07]I:`1lG2d0OEh_081Q<P1oHc<3
085O<@06089P<P23HC<0Pf4c089P<P21Gc40P5h`1@22Hc@00`21HS<0P64b07mP<@0207aR;`0707]Q
<01jGc00N5d`07IK<01cEbl0LUH^06Y=:`0206Y>:@0=06]?:01]DBT0L5DZ07AI;01eFRd0OV0^081R
<022I380P68`07eO;@1kGB/0O5h/07iP;P0208=U;`80Q6H`0P25Ic4208IX<P80PVP]00H0PFL^085V
;`20IC00P6@b07mS<@1oHc<207aR<@0<07]Q<01iGbh0N5h]07MM;01fG2/0ME/Z07aP<01nHS00PVHd
08EZ=@28KCH0RW0g0P2:L3D308]a>0<0S78i0P2=LcX208id>`0408ec>P2<LST0S78i08]a>080RW0g
0`23JS82089Y<@<0PFP`0P20IS<00`1oIC80OV@a07eS<00207aR;`0I07]Q;P1lH2h0OV8`085U<`26
JSP0SG4o09EiA`2LP4h0X8AB0:>9D02OQ4d0VGi7095f@@28K3X0P6@d07YN;`1gFb`0Le``075J;P1^
Eb/0JU<W06I?8`1RBal0H4TM05m8700206998@0>06598`1OBB@0G4PS05]99@1JAbH0F4PV05E58`1D
A280DT8Q050o8@1>?B40C3/Q04Xi7`19=al304<g7@80@SHL0P11=A/00`10=1X0=S0J03D^6`02034/
6@0502`Y6P0V91P0820H01dL5`0J6aH00`0J71T201TK60D061XG0P0G6AH301HH5@0301DG500F61L0
5QPG00h05QPG400E5aH@01HH5a005aTH200G6AH801TK60806QXH0P0K6aT301`L6P0701dM6`0N7QH0
7alG01lO5`0P81P08B4I028R6P0202<S6`P09R8I2@0W8aX302PT6`80:BDL0P0Z9Qd902XS7@0302TR
700W81X09QlI00809QlI00<09b0J02TR700Z8ad00P0Y8Ah01`0X8A/0:24I02TR600[9AT0;BLI02hX
6P0`8aX00P0a91/01@0b9A`0<bHM03@W7P0d9ah0=BPO0080>2/K00@0>B`L03X]7@0k;Qh0?2lO0P0m
<20203/^7P80>RdM100i;1`803@Z7P<0=B/O0`0f;20203L]8@0F03<V7@0c9a/0=BTM03HZ700h;1`0
>RlM03/`700l<Ad0@2hR03l]8@0n;1h0?RdM03l^7P11<1h0@c8N04Dd8010<AX0@C8K048b6`14<Q`0
AC<M04Pc7P80BS@O0180CC@P04he8@1?=R00D3PP054i7`1B>Qh0Dc`M05@m7P1@=Ql0DCLP058h8@1C
>B80EC/T05Hl9@1G?BH0F3hW05Tk8@1H>R0205Li7`0505Pj801J?280G3hT05i09P1K@b400P1M@b80
0`1O@R80HD8S06=28`0206E2900605ho801O@240H44R06528`1SA2D0IDHW0P1VAbP0401WBBD0ITPT
06E78`1TAR80IDLS06I8901XBRH0JD/W06M;9P1XC2L0JD/W06a;:01^C2T0L4`Z075=:`1cC2/2071=
9`<0LDhX00H0L4dW06i;9@1^BbD0KTdZ06e<:@1[BRL306U89@80JdXW0P1^BbD206m<9P@0L4dW00<0
LDhX07A>9`1dCRL00P1dCRL407E?:00807E@9P1dCbD0LT`U075;9P1`BRH0KdPW0719:01`BBX207E?
:P0307A>:@1cCBP0LT`W0080LD/V00@0L4XU06Q39P1W@RD0IT4T0P1U@2<00`1V@B@0Id8U06M29@02
06E48`80ITDT0`1WARD0101XAbH0K4/Z06Y9:01YB2L306M69@80JDPW00H0Hd@W06A5:01VAbP0J4XX
06U;:@1ZC2P206Y<9P80J4XX0`1YBbT306Y<:P80K4`U00<0KDdV06i>9`1_CbP00P1`D2T00`1aDBX0
MDlX07E?:00207E?:080MU0Y0P1gDBX01P1eCbX0Le0Z07=@:P1cDB/0LU8[075D;080L5@/00<0ME8Z
07IC:`1gE2`00P1hEBd0101gE2`0MU<[07EB:P1hEBd207UF;P0307YG;`1kF300O5Ta0080OEXb00P0
NeT[07aJ;01mFbd0OU`^07eK;@1lFR`0NUPZ07UG:@<0OEP^00d0OUT_07mJ<021G380Pehd08AO=@24
GSL0QF0f08MR>028HcL0R6<f08MS<`25HBl0Q60^0080PEla00<0PV0b08=Q<`24HS@00P25HcD01026
I3H0R6Hh08QV>028ISP308MU=`80QV@f0P2<J3P00`2=JCT0SVXj08m[>`03091/?003095]?@2BKSX0
TVhj00H0TVhj00H0SVXj08aX>02:ISH0Qf<c08IR<P25HC4208IR<P0D089S=021HS@0Of0b07aM<@1i
FC00MUH_07=C;@1bDR`0LE4X071@:@1_CbP0KThX06a;:01[BRT0JTTZ06U8:@1UAb<0ITPT06M99@1Y
BbL306Y<:00306U;9`1]C2T0KD`Y0080KD`Y01@0KTdZ06m>:`1aD2d0LU4^07EA;@1fDRh0Me@^07UF
;P1jEbd0O5X]07eK;P1mFbd0PUdc08=N=024GcD0QV4g08QS>@2:IC/0RfHl08aW?@<0SfTj00<0T6Xk
095[?02AJc`00P2BK3d0102BKSX0TFdi095]>@2AKCT2091/>0<0Sf/g0P2@K3P2095]>@<0TVhj00<0
T6/g095/>02CKSX00P2CKSX00`2AK3P0T6/g08iY=@03091[?P80TF`o0`2BKD02099]>0<0Tfhi0`2D
KcX0102HLcl0Ug8n09Mb?P2GLSh309Ia?@0;09E`?02DLC/0Tflk099^>P2@K3X0T6`l099]@02CKT80
U6m309E_@02DKSl00P2CKCh00`2DKSl0UFm009I`@@0209Ma@P0<09Qb@`2JM4D0VgE609]eAP2JM4D0
V79309Ma@P2HLch0Ug8m09Ia?02EL3/0U6lj0`2EL3/00`2FLC`0UW4m09Ia?@0309A_>`0609Ia?@2H
Lcl0VGA009Ye@@2KMT80W7M30P2MN4@00`2LMd<0VgI209]f@P0309]g@`80W7Q40`2MNDD209YfAP04
09UeA@2HM4@0V7A409Mc@`X0UW9200T0Ug5209I`@@2EKd00UFm009I`@@2GLD80V79309UcA02GLD80
0P2FL4401@2EKd00U6ho09=]?P2BK3d0TF/l0080TV`m00@0TF/l091Z>`2@JS/0TF/l0P2BK3d3095/
>080TVdi0P2AK3P0102@JcL0SVTe08iY=@2>JCD[ooooo`00:_ooool20:5eA0h0X7A300P0VWI209eh
A02ONTH0XWY70:AjB02TN4L0YGM60:AfA@80XgU700<0XWQ60:1fA02PMT@00`2OMD<80:5f@`80XGM5
00@0XWQ60:=iA`2SNDL0Y7Y80P2UNdT40:MlB@@0YW]800D0ZGe<0:QlB`2XO4/0Yg]:0:IjB@020:Ei
B0070:AhA`2UNdT0Y7Y80:=iA`2RN4H0XGM509me@`0209id@P80WW=600D0WG9509aaA02KL4<0Vg13
09Y_@P0209U^@@80Tfdl00X0TV`m095[?P2?J3d0SVLn08aU?02<ICh0SVLn08aU?02:HcX0Qf0g0`26
GcH01`27H3L0Pedf089L=@21Fc@0P5Xc07mI<P1nF3400P1mEc00101hF340MeL`07EE;P1cDb`2079B
:`80Le</0P1_CR/00`1`Cb`0LU4^079A;P0307=B;`P0K4hZ0180L4l^071?;01_CR/0L50Z079B:`1e
EB`0N5T]07YK;`1jEc40NePb07aI<@1nFc40PElb08=Q<`26I3@0QfDe08IV=@27ICD208YV=P0408aV
=`2?ISP0T6Dh095V>@<0TfTg0`2DJSP209E[>@0809Y`?P2KLCl0Vg4o09]a?`2JL3h0Ufdk09E[>@2C
JCL209=]?PH0TV`m00@0SFLh08iX>@2?JCX0T6Xk0`2AJc`0102BK3d0SFHk08eV>`2=IS/208aU>P<0
Rf@i0P2<IST308]U>0<0RV@g0`2;ICH208aV=`<0SFLh202?I3L8095V>@80TVLj0P2AIST3091U>080
Sf@g202AIcD608iX>@80SfTj0P2BJ3P2095W=`80T6Hf0P2?ICD308aV=`0308]U=P2:I3D0RV@e0080
RF<d0`2:I3D308US=080R68c2027Hc<808MR=@0308YU>029I3L0R6<f0080Qf8e00<0R6<f08YU>02;
IST0202>JSP308m[=`80SVXf0`2?JcL208]W<`80RVHb00d0S6Pd08iZ=P2AKCT0TVhj091^?P2=Jc/0
RVPh08]Y>@2?KCd0T6hn08i/?02;JCT0S6Lj0080RVPj02d0RFTj08IW>021ICD0OF<b07aR<@1lH340
NUda07EJ;`1]E2`0IThZ05m89P1J@b@0ET4R04e28P1<@B<0Bd0R04Tn8P17>b40ACTQ04@h8P13=b40
?C8P03T`7`0g;Qd0=BhN03<]7`0a;B40<BlS038`900Z;AX0:B`I02T/6`0X:Q`09bTL02HX7@0U9a`0
9BHN02@W800S9Ql08B@M020S700O8Q/082<L024T7@0R9Ah00`0P8aX2024T6`@08RDL0P0U:AP0100T
:1T08bLI028U6P0Q91/2020S70<07b8K0P0P8a`3024T7@0>020U7P0Q9Ql08bHM02DW700V:1/0:2TK
02XX6@0[:AX0;R/J030]700e<1d0>C8O03`d8@0n<al203lc7@0904Li7016>1d0@SLK03le6P0m=Q`0
?3HN03dg8@0m>280;bTM0080;bTK00D0<2XJ038]6P0e<1`0>3<M03Xe7`0203Xb6`0403Ta700h<1d0
>30M03L^7@80=RdN0P0_:al302hZ7P<0;BTM00H0;bPP02`X7`0/:1l0:bPO02TY7`0W:Ah202HY7PH0
8bHM0P0R9A`3028S7@808B8L0`0P8A/2024R7080824K0P0O81X201hO6@0H01hN500T8QH0;2PL03L`
800o=280ACHQ04@d7@14<QX0CSTJ05E08@1UCR`0MEdg08IZ@P2>LT<0TgA509=e@`2>LDD0TWM<08=[
A@1NBb/0>RhF02`V600Y:B409BXV0P0U:24302@W80<08bHO0`0T9b0202DX8@<09RTR200V9b401`0U
9R409RLR02LX8P0X:B40:B/P02/]800/;R400P0/;R00400f<Ah0>SDR03dh9@0m>2D0>SDR03Td8@0m
>2D0@3/X04Hk:@16?B`0Ach]044j:P0i<bD0<blS038`900d<RH403Hb9P@0=c<W0200?CHS03lg9012
>RD0Ac`V04/o9`1@@RP0Dd<Z05A4:P1LBBT0FTLW05M49P1E@BH0DclV058n9P1B?BP0DchY0558:@1F
AbX0GDDY0694:01SARP0HDXX05e?:P1JDbT0Ge4/05e?;01KCBX0F4TX05I7:01FAbX0ETH/05M7;@80
FTLW0`1KB2P305a9:@0305U69@1JAbH0FTLV0080FDHU00<0F4DT05M48`1GA2<00P1??BD0<@1A?B@0
E3lT05U19@1NABL0HTT[06I;;@1RA2P0HdDY06E8:P1WBRX0JD`Z06Y>:@1[CbP0K50Y06YB;01/E2h0
KUH`06mG<@1`F380KeLa06iF<01]EBl0IThX06iE;@1gGSD0OF8g07mS=022Hc@0QFDd08QX=@26HcT0
PUle07iM<P1oGS40PF8d07mS=01lH300NEd]08=/@P20JCl0Nf@k07AN=`1^F3<0JU<a06EA<01SCbh0
I50_06=?;P1QCB`00P1OBbX0601PC2/0HDd/069>;@1NDBL0Ge8X065B:@1TDRX0Ie<^06YD;`1[EC00
KEDa06MC<01UDBh0HdlZ06A>9`1VCbH0JE8X06eD:`1`F2`0PF0[081Q:`22Hbd0Pf@^08EV<080QFLa
02d0QVPb08aT<`2<I3<0SfDc09=X<`2KKS<0Y7Ld0:n0>02gQc/0_8/n0;jEA@2oUTH0_iQ;0<2JC`30
Ve@0_YaE0;fJEP2kVUL0/9aZ0:jIJP2ZUFX0XXmW09V5I02?NUd0Qg5I085]E@20J3`0PfPk08IZ>`29
JcT0S6dg095^>02CL3H0U70d09U`?02KLS`0W7Dn09ag@02KN3h0V7Pm09Af>P2BM3P0UG@n09=b?02@
KcT00P2=K3H01P2>KCL0T6li095`>P2DL380UG4c09Mc=@<0V7@f00D0Ug<e09Ib=02@LCP0T74h095a
>002099_=`0;099]=P2DKCH0U6df09=_<`2DL3@0UW8f09Mc=`2IMCT0VWHj09]g>`2LN3`01@2MNCl2
09ah?P0T09]g?@2HMCd0Ug@l09Ic>`2DLC/0Tg0j095]>@2@K3P0Sf/g08UV<02;IS40SVHb095X=02D
JCH0VFTh09YZ>@2MJcX0Wg<d09mc=P2LLcD0Vg<f09Ub=`2FLSP0UW4j09Aa>@2MNCl0VgLm09Qd>P2F
LSP0UG4g09Mc>@2KMcd0WWY009Mc=`2HM3P0VWHj0P2LN3`06`2KMc/0VGDi09Mc=`2DL3@0Ug<g09Qd
>02FLSH0TVhb091/<02CKc<0UW8f09Eb>02AKS@0S6Ta08QU;`26HRh0Qf<a08YV=P2<J3P0RF<d08MS
<`26HS80Pf4a081P;`1nH2h0Nel]07YN;00207iH:`0607eH:`1lFR`0O5`]07aM;P1mGRl0O60`0`20
GRh00`21Gbl0PV0`089P<003089P<009089T<P23IC<0PfDc08AV=023IC<0PF<a07mQ;`1nH2h0Nf8/
0080Nf4^00<0NV0_07UN;`1hGC000P1gG340401^DRX0K50X06U=9@1YCBD0JTlT06iC:01cF2d0MU/^
07iP;P21Hc40Q6Hd08EW=@23IC<0Of4_07aN;01jG2X2081R;004085S;@22I2h0PfD_08=U;`80Q6H`
00P0PFL/081V:`20IRd0P6D^07mT;`1oHc40OV8`07iR<P80OF<b00`0Nf4`07YP;`1hGRd0MU`[07EK
:P1dFRT0O60`07iR<022IS@0QV/f08U^=`2;LCP208ab=`H0S78i0P2=LcX208me?080SW@k00D0SG<j
08ab>@2;LCP0Rg4h08E/=00208A[<`0508=Z<P22JC40PFP`085X<020Ibl00P20IS<00`1oIC80OV@a
07eS<00207aR;`0I07]Q;P1mHBl0OV8`081T<P24J3H0Rflm09=gA@2JOT`0WX9@0:F:E@2SR5<0WhA?
09QlBP2?Ld40QVXh07iR<P1iGBd0M5da075J;P1^Eb/0JE8V06I?8`1SC200HT/O065:7P0206=:8@0>
069;8P1PBR<0GTXU05a:901LBRH0FTXX05M79@1FAR@0E4@S05508P1??R80C3/Q04Xi7`19=al204@h
7P80@cLM00H0@SHL044e6`11=A/0@3@J03P`6@0g;aX203@]6P0502lY6@0Y9AT08b0G01hK500I61<0
0P0K7AX201XL6@806A/H1@0H6QL201LI5P<05QPE600F61L801DG5Q005QPG400G6AP801LI5PP06Q`I
0`0K6aT301`L6P807AdK0P0O7aL2020P6004024Q6@0R8QX08R8J028R6PP09b<J2@0X91/302TU7080
:RHM0P0[9ah902/T700302XS6`0X8AT09b0H00809b0H00/0:24I02XS6`0[91`0:R8O02TQ7P0X8A/0
:24I02TR600[9AT0;BLI02lY6`02034T6`80<RDL0P0c9Qd203@W7P80>B`L00@0>RdM03/^7P0l;al0
?C0P0P0n<B4803`_7Pd0=RdN0`0g;Ql01P0e9ah0=RPM03LY7P0h:Qd0>RdM03`_7P80?C0M00/0@BlS
040^800o;Qh0?bhN040_7@12<Ad0A3@M04Hf7`11<Q/0@S<L04<c700204Dc7@0304Pc7P19<ah0BS@O
0080CSDQ00@0CcHP050h801A>Al0DSXN0P1C?1d01P1A=b00DSPQ05<i8P1D>R<0ES`U05Lm9P80F3hW
00T0FS`P05Tk7`1H>Qh0F3XN05Tk7`1K?B40GClS05m19@1LA2800P1NA2<00`1P@b<0HT<T06A39002
06I39@80H44R00@0HD8S0693901TABH0IDHW0P1VAbP0201XBRH0IdTU06I8901UAb<0ITPT06M99@1Y
BbL0JddY0P1YCBP02@1[CBT0KD`Y06m=:P1`C2X0LDd[07=<:`1^BbD0L4dW079?:@0207AA:`0;079?
:@1_C2H0KDXT06i=:P1]C2T0JdXW06Y99P1YB2D0JTTV06]:9`1/BbP00`1^BbD306m<9P<0L4dW00D0
LT`U07==9P1cCBH0M4hW07E?:00207I@:@0607MA:P1eD2H0M4lU07==9P1bC2L0LD/W0P1`BBP01`1`
BBX0M4hY07==:01cCBP0LT`W075;9P1`BRD00P1_BB@406M38`80J4@T0P1YABD406E48`80ITDT0P1W
ARD00`1]C2T0K4/X06Y99P0206U89@0906Y99P1[BRL0K4/X06E6:@1VAbP0IdTW06U;:@1ZC2P0JddW
0080K4lW201]C2T206a<9@0306e=9P1^CRL0KdlX0080L50Y00<0LE4Z07I@:@1fD2T00P1fD2T407MA
:P0607M@:@1gDBX0Me4Z07EB:P1eE2/0M5@[0P1cER`00`1fDb/0Me@/07UF;P0207YG;`0307UF;P1g
E2`0MU<[0080NEH^00@0NUL_07]H<01kF300O5Ta0P1mFS800`1lFR`0OE/]07iL;P0207mM;`0307iL
;P1lFR`0NeT[0080OUT_00l0OeX`081K<@21G380PUdc08=N=024GcD0Pedf08EP=P26HCL0R6<g08QS
=P27Hc<0QV8`08EQ;`21Gc400P22H3800`23HC<0Q68d08ES=@0208IT=P80RfHi0P2:ICP208UT=`80
R6<f00D0RfLg08aX>02<J3P0SFTi08iZ>P0208m[>`80T6`l202BKSX01P2=JCT0S6Ph08YV=P28I3@0
Qf<c08QT=080RFDe00h0QVHg08AT=@22HC@0Oeha07]J;`1hEbh0MU@^07AB;01cE2P0LU8Y075A:01`
D2T0KdlY06e<:@80K4/Z0P1WBBD00`1XBRH0JD/W06Y<:00306Y<:0<0KDdW01D0KThX06m?:@1`D2X0
LE4[079B;01gDbl0N5@`07QE;`1iERh0NUL]07]I;01lFRd0O5X/08=N=024GcD0QF0f08MR>029I3X0
RfHl08aW?@2=J3h00P2>J3T01P2?JCX0T6Xk095[?02BK3d0Tfdn09A^?`80Tflk0`2BKSX3095]>@P0
TVhj00<0Tfhj09A_>`2EL3`00P2FLCd0102EL3`0Tfhj099]>@2BKSh309=_?`80U7100P2ELD4809E`
>`P0Ug8n00P0UW<m09Ea?@2CKc/0TVhl099^?P2CKT40UG1409IaA@@0Ug520P2HLT<01@2ILd@0VWA5
09Uc@P2JM4<0W7I50080WGM600<0W7I509Yd@`2ILd800P2HLch209Mb?@D0UW4l00<0Ug8n09Ia?@2E
L3`00P2EL3`00`2GLSh0VGA009Ye@@0209ag@`H0WGQ4202MNDD0202LN4P0VgM709YfAP2IMDD0V7A4
09Mc@`2FLT80UG51202DL40309Ma@P0309I`@@2GLD80Ug520080V7930P2FL3l209E_?P80U6hm0P2C
KC`209=]?P@0TV`m0P2CKCh0102>JCD0SfXf095/>02BKCT209=^>P80TVdi0`2=JCD[ooooo`00:_oo
ool60:1d@`80XGE4202PM4<0202KMd<0WGQ409mjAP2SNdP0Y7Y80:AhA`2UMdH0Y7I50`2RN4H20:5g
A@0309me@`2NM480WWA200P0XGI30P2QMdD0102RN4H0XgU70:=iA`2TNTP20:EkB@@0YW]8102WO4T0
1@2YOD`0Z7a;0:QlB`2WNdX0YWY90080YGU800L0Y7Q70:IlBP2UNdT0Y7Y80:=iA`2QMdD0X7I40080
WgE30P2NLdH01@2MLTD0W75409]`@`2KL4<0VVm20080VFi100`0U6hm09=]?02BK3d0T6Xm08mX?@2>
Ich0SFHm08eV?`2=ISd0S6Dl08UR>@27H3L208EN=@80QUlf00@0PU`e085K=021Fc@0P5Xc0P1oFC82
07iH<@0307UI<P1gEc00MED^00<0LU8[00@0Le</07AD;@1aCb`0LDl/0P1bD2d0101cDBh0M58_07EC
<01fE34806a>:P0?06m>;@1_CR/0L4l/075A:`1cDb`0MED/07QI;@1iFRh0NePb07aI<`1nFc<0P5dc
089P<`24HS@0QF<c0080QV@d00D0RFDe08YV=P2<ISL0SfHh095V>@0209=W>P80TfTg0`2DJSP309E[
>@80VW0n0P2KLCl0102IKcd0Ufdk09AZ>02CJCL6099/?@80Tfdn0`2>J3T00`2?JCX0T6Xk095[?002
099/?@<0SFLj0P2<IST308]U>080S6Hi0`2;ICP308YT=`<0RfDf0P2<ISL308eW>0P0Sf@g202@ICP2
095V>@D0T6Dh0P2?I3L8095W=@D0SVPi0`2=IcP3095V>@80T6Dh0`2?I3L00`2<ISL0RfDf08]U=P02
08]U=P<0RV@e0P2;ICH308YT=@<0RF<d2027Hc<808MR=@0308]V>P2:ICT0R6<g0080Qf8f00<0R6<g
08UT>02:ICT0202>JSX00`2>JSH0Sf/g08m[=`0408m[=`0308iZ=P2?JcL0SVXf0080SVXf00d0Sf/g
099^>P2DL3`0UW8n08m]?@2<JSX0RFLg08]Y>@2>K3`0Sfdm08e[>`2:J3P0RfHi0080RVPj02d0R6Pi
08EV=`20I3@0O68a07YP;`1jGc00N5d`075I;@1ZDbX0HddX05]7901G@R<0E44Q04a18@1;@280BSlQ
04Pm8@16>R00A3PP04<g8@12=R00>c0N03P_7P0f;A`0=2dM03<]7`0a;B40<BlS038`900Z;AX0:B`I
02T/6`0X:Q`09bTL02HX7@0U9a`09BHN02@W800S9Ql08B@M020S700O8Q/082<L024T7@0R9Ah00P0P
8aX2024T6`808RDL0`0S9Qd202DY600402@X6@0S9aT08RDJ024T6`8082<L0`0O8Q/2020S70<08B@M
0P0Q9Ql0100T9ah09RPM02LY700Y:Q`202`Z6`0602l/6`0a;Qd0=S4N03Xc800l=240?c@P0P10=1h0
4017>Ah0ASPN048f7010=Qd0?3@M03/e7`0j<b00>C@P02lY7@0_:A/0<2XL034[6`0c;Q/0=c8N03Xe
7`0l=b4203Xb6`0403Ta700h<1d0>30M03L^7@80=RdN0P0_:al302hZ7P<0;BTM00H0;RLO02`X7`0/
:1l0:RLN02LW7@0V:1d202@W70H08RDL0P0S9Qd3028S7@808B8L0`0P8A/2024R70@0824K0P0O81X0
600T81@0;2HH03@]7@0n<b40ACHQ04Pf7P1:=Qd0BcHK05<k6@1OAB80KeD`085U?P2;L4D0Sg9608mc
@`2>LT80U7M?08U_C01/FC/0Ac/U034[6`0/;200:RdV02DW8P809BPQ0`0T9b0302<V7`<092LP0P0U
:24302HY8PP09RLQ00L09RLR02LX8`0X:B<0:BXR02X/8@0/;R40;BlR0080;BlQ00@0=c8O03Xe8P0n
>BH0?CPU0P0j=B802P0m>2D0@C`Y04Hk:@16?B`0Ach]044j:P0i<bD0<blS038`900d<RH203Da9@80
=S8V0P0g<bL203Pd:00>03/c7P0o=200@CHP04Di8@1;?B<0CclU05=2:01D@bL0G4TY05]8:01HABL0
ED4V05<o9P1C?bL205<n:@0>0599:P1GB2/0GTHZ06A6:P1UB2X0HT/Y05e?:P1IDRP0GDl/05]<:`1I
BRT0ETLX05E6:@1EAB/205I6;@80FTLW0`1KB2P305a9:@80FDHV0P1HABD405M4900^054m901B?RD0
E3lT05Q0901MA2H0HTLY06E:;01YC2`0I4LY06E8:P1VBBT0IdXX06U=:01[CbP0KE4Y06iB:P1[Dbd0
K5@^06iF<01_Ec40L5Pb06mG<@1^ES00KED_069:9P1ZD2/0LUT`07UN<@1lH300P68^08EV;`29JS40
SVPg08]W=@29IcL0RVXi08a^?027KC`0OfPf07UR<01cHSL0LEhd06eJ<P1YEC00IU8_06M@<080Ie0a
00<0I54a06=@<01QCRh00`1OC2`04`1PCBd0HDh^05mA;01ODB`0HU8^06ID<01YEC00KELb06mI=01`
F3@0HeD`065C;P1OD2T0HDhV06A>9@1XDBL0KE@[079G;01nHb`00P1oI2d01@23IBl0Q6H`08IX<P29
JS@0RV/e0080TVLb03L0U6Tb09Y]<P2QMC@0ZG`h0;65?02iRch0_Hm10;bHBP2mVDd0^iU?0;^JE@2h
VEP0]YII0;>DF`2aTUT0YY=Y0:>@J02PRVD0VH9P095jFP2:LE<0Q6Y?081VB`22HC@0Q6<f08MU=@2;
JSD0T6de09=`=P2GLcD0V7@f09ae?02MMSd0WGTo09ej@02IND00UWLn099e>`2?LSX0TW4k091_>@2>
KCL0S6/e08]Z=02=K3H0Sfhh095`>P2DLC40UW<c09Qe=@2JMcL0VgPh09Yg=`2HMCD0Ug@d0080T74h
00@0T70g099_=`2AKSH0TVdf0P2DKCH209Ea=@0909Ib=P2HM3P0VWHj09ah?02NNSh0Wg/o09ei?@2L
N3`0VgLk0080VWHj0`2IMCT209=_>`04099^>P2AKSP0T6dg091]=@80Sf`d01X0Tf/`09A/<@2FK380
Ufdc09]^=@2ML3L0Wg0h0:1a>@2UNSH0Y7Pg0:9i>@2PNCP0WWPi09]g>@2JMSX0VGLj09mk?`2LN3`0
VGDi09Qd>02IMCT0VgLk09ei?@2NNSh0VGDi09Yf>P80W7Pl01X0VWHj09Ib=P2BKS80Sf/_09=_<`2F
LSH0VGDi09Mc=`2DL3@0TVhb09=_<`2FLSH0Tg4d091^<@2:Ibd0QV<[08AQ:`24H2`0Qf<a08UU<`2<
I3<0RV@c08QT<P26HS00Pf8_081P;@80OV0/0P22G2l01`21G2l0OU`^07aL;@1jFb`0NEX[07MK:`1l
FbP00P1mG2T0201nGBX0P5l/089Q;P25I340QfHc08QW=023IC40Q6Hb0P25Ic<01@24IS80PV@`07mQ
;@1mGb/0OF8[0080O64/0100Nel]07]O;`1kGc00Nehb07aO<`1aERL0KU<V06]@8`1YCR40JTlT06iC
:01cF2d0Me`a07eO;@1oHBl0PfDc0P26J3H00`22I380OEl]07QJ:00207iP:P0>07mQ:`20HR`0PF<]
089T;P23IBl0Q6H`085W;020IR/0P6H]081U;P1oI2l0Of<a07iR<01nHS8207eS<P0<07]Q<01jH2l0
N5h]07IL:`1eFbX0M5XY07eQ<@1oHc40PfLe08M/=`2:KcP0S78i0P2=LcP608ec>P80S78i0P2?MC`2
08id>`0508ec>P2<LST0Rg4h08]a>026KCD00P25K3@01@24Jc<0PVTa085X<021J300P6L_0080P6Hc
00<0OfDb07iT<@1mHc000P1lHRl05P1kHBh0OV8`07iR<01oHc40PVHd08Q/>P2@M480V7a:09b0CP2T
R5P0YHUI0:>7E@2OPe40V7a:08ic?P25JSD0Of@_079K;`1`FBd0KEHZ06YC9`1XDBD206M@900606QA
9@1UCB40IDdQ06=<8P1RC2<0Gd`T0P1MBbD03`1KBbL0F4PV05M79@1EAB@0DT4S050o8`1=?280BcXP
04Xh8016>R00ACTO04@h7P13=ad0@SHL044e6`02040d6P0903/a600k<1X0=blL03L_700c;1X0;RPJ
02HR5`0Q7A@071TB00<06adJ0P0J71T501TK608061XG0P0G6AH201HH5AP05QPG200E5aH@01HH5a00
5aTH200H6QL801XL6@806a/I0`0L71X301dM6`<0820H100Q8AT00`0R8QX0:2@K02PT6`0602PT6`X0
:BDL0P0Z9Qd302/W7P0302`X7`0[91X0:b@J00H0:b@J00<0;2DK02/T6P0Y8QP00`0X8AL00`0Y8QP0
:b@J02`U6`0202XR7`0602TR700Y8QX0:R<I02`V6P0^:1X0;bTK100b9A`403<V7@80>B`L00@0>RdM
03/^7P0l;al0?C0P0P0n<B4403d`7`@0?S4P200j;Qh503L[6`<0=RXJ00H0>BPP03TX7P0j:Al0?2`O
03d]7P0n;Qh203l`7@08048`8P11<200@2lO040_7@11<1`0@c<L04De7016=Qd204<d7@0404@d7@15
<ad0AS@N04Pc7P80BC<N00h0CSDQ04lf8P1?=R00D3PP054i7`1B>Qh0DS/L05<l7@1B>240DcTR05@j
8`1E>b@0ES`U05Pn9`80FClX0100FchP05Xm7`1I?1h0FC`N05Xm7`1L?b40GT4S05m2901MAB<0GT@S
05m5901QA2@0Hd@U06E49@1V@bD0Id@V0P1VAbP306E69`<0I4DV00<0JT`X06U;9`1XBRH00P1WBBD0
0`1YBbL0JddY06a>:P0206]?:P0306a>:P1^CBX0L4h[0080LDd[00@0Ld`[06i;9@1`CBL0Le0Z0P1e
DR`01P1cD2X0LDhX06m<9P1_CR/0KTdZ06a;:0<0JTTV00@0JdXW06a;:01]BR@0KDXT0P1^BbD306m<
9P80L4dW00D0LT`U07==9P1cCBH0M4hW07E?:00207I@:@0907MA:P1dCbD0M4lU07A>9`1cCBP0LT`X
075::@1`BBP0KdPY0080L4XU00<0KdTT06i88`1]Ab800P1/AR400`1[AB00J4@T06Q4900206U59@@0
JTHV0`1UA2<206I590<0IdHU00<0KThX06e=9`1/C2H00P1[BbD02`1/C2H0KThX06m?:@1WB2T0IdTW
06Q::01YBbL0JT`V06a?9`1]D2H0KU4W00P0L4hY0P1]CBH00`1^CRL0KdlX071@:@02075A:P03079B
:`1hDR/0N58[0080N58[101gDBX01P1kDBT0NE8Y07QC:@1iE2X0Me@Z07MF:`80MUL[00<0N5D]07UF
;P1jEbl00P1kF3000`1jEbl0NEH^07QE;@0207UF;P0407YG;`1kF300O5Ta07eJ<P80OU/c00<0O5X/
07eK;@1oGBl00P20GS001P1oGBl0OU`^07eK;@1oFS00P5/a085L<P80PUdc0`23GS@02023GCH0Q5le
08IQ=`27HSH0R6<f08QT=027Hc40QV8`0P22H3800`23HC<0Q68d08ES=@0208IT=P0308MU=`2;IST0
RfHi00@0RVDh0P29I3L208]W=`0308aX>02=JCT0SVXj00<0Sf/k00<0T6`l09=_>`2CKc/01P2CKc/0
6@2=JCT0S6Ph08YV=P29ICD0R6@d08UU=@2:ISH0RfLg08QV=P27ICD0Q68d089P<`1nFc40NeP^07UF
;P1hEBd0MEHX07EF:P1dEBT0LU8Y075A:P1`D2X0Kdh[06i=:P1ZC2P00`1YBbL206Y<:080JddY0P1]
CBH00`1^CRL0KdlX071@:@03075A:P80N5@`00<0NEH`07YG;`1kF2h00P1lFRd04@1mFbd0Q5le08EP
=P26HCL0R6<i08YU>`2<Icd0SFPn08iY?`2=IcP0SVPi08mY>P2@JS/0TV`m09A^?`2EKd00UW1100<0
U70l0`2CKc/2099^>PD0U70l0`2ELCd0202FLCd0Ug8n09Qc?`2IM400VWE109Ud@02GLSh0UW4m0P2E
LCl209Ib@0<0Ug=100<0V7A209Mb?@2GLSd01P2GLSd409Mb?P@0V7<o00P0V7Do09Mc?`2ELCd0U70n
09A`@02EL4<0Ug9609QcA`80VG=40P2JM4D409]eAP0309Ye@@2KMT80WGQ40080WWU500@0WGQ409]f
@P2JMD40V7<n0P2IM3l209Qc?P<0Ug8m00<0UW4l09Qc?`2GLSh00`2FLCd00`2HLcl0VGA009]f@P04
09ag@`0409ehA02NNDD0WWU509mjAPP0WGU50P2LN4P0102KMdL0VWI609QdA02GLd<209Ib@PP0U710
00<0Ug5209Qb@`2HLT<00P2HLT<309Ma@P<0UW4m0P2EL3`309A_>`P0Tfdn00P0S6Lc08iY=@2@JcL0
Tfhj09A_>`2CKSX0TVdi095/>0<0SVXf:oooool002[ooooo0P2OLd830:1d@`<0XGE4202PM4<02P2K
Md<0WWU509mjAP2SNdP0Y7Y80:EiB02VN4L0YGM60:1fA02QMdD30:9hAP030:1fA02OMD<0WWA200<0
XGI30P2RMd@30:=hA@80XGM500@0XWQ60:=iA`2SNDL0Y7Y80P2UNdT0102UNDP0YWY90:IjB@2VNTT3
0:MkBP030:QlB`2WNdX0Yg]:0080Yg]:102VNTT0202WOD/0YWa:0:EkB@2TNTP0XWQ60:5gA@2PMT@0
WgE30P2NLdH01@2MLTD0W75409]`@`2KL4<0VVm20080VFi100D0UFln09=]?02AJc`0SfTl08iW?002
08eV?@0508eV?`2=ISd0Rf@k08UR>@26GcH00`25GSD01@26GcH0Oe`d07mL=01oG3@0OU/c00<0OEXb
00/0O5Ta07YJ<`1hF340M5@]079B:`1aDBX0LU8[07=C;01eEBh0ME4_07A@;P0307=?;@0307A@;P1f
DS00Me<a00<0JddY0P1/CRX306e?:`0>06m>;@1_CR/0L4l/079B;01cDb`0MUH]07MH;01hFBd0O5Tc
07eJ=01oG3@0PUle08=Q=023HC<208=Q<@0608QT=02:I3D0RfDf08iU=`2@ICP0TfLj0P2FIc/0102C
JCL0U6Xh09AZ>02DJSP209E[>@80UV`j00P0Ufdk09Q^?02IKcd0VFlm09Q^?02FK3X0U6Xh09=Y=`80
TF/l0`2BK3d309=]?P08091Z>`2?JCX0SfTj08iX>@2?JCX0T6Xk095[?02BK3d308eW>080S6Hg0`2;
ICH208aV>@<0RfDh0`2:I3L308]U=P80S6Hg0`2=IcP808mT=`P0T6Dh0P2>HcH208mT=`<0T6Dh0P2A
IST309=Y=`80TVPf0`2AIcD408mY>P80SVPi0P2=IcP2095V>`80T6Dj0`2?I3T00`2>HcP0RfDf08]U
=P0908]U=P80RV@e0`29Hc@808MS<`P0Qf8e00P0RFHl08QU>`26HcT0QF8h08AQ=`25HSP0QV<i08MT
>PP0S6Lj00<0SFTe08iZ=P2?JcL00P2@K3P01@2?JcL0SVXf08eY=@2BKSX0TFdi0080T6`h00d0TFdi
099^>P2DL3`0UW8n08i/?02;JCT0R6Hf08YX>02=Jc/0SV`l08aZ>P29IcL0RfHi0080RFLi02d0QfLh
08AU=P1oHc<0NV0_07QN;@1eGBd0Le/]06iG:`1XDRT0H4`W05Y8901F@b<0DT8Q04]0801:?b40BChP
04Ll8015>Al0@cLO048f8011=Al0>c0N03P_7P0f;A`0=2dM038/7P0`;200<2hR034_8`0Z;AX0:B`I
02T/6`0X:Q`09bTL02HX7@0U9a`09BHN02@W800S9Ql08B@M020S700O8Q/082<L024T7@0R9Ah00`0Q
91/2028U70@08bHM0P0U:AP0100T:1T08bLI028U6P0Q91/2020S70<07b8K0P0P8a`3024T7@808BHO
00`092LN02LY7P0X:Qd0:R/M02d[700^;1d0<2dL038_7P0g<Ql0>S<P03de8P10=B42044e7`0904Dg
7@15=Ql0@cLO048g8@0n=R40>S<P03L`7P0d;a`0<B/O0080<B/M00D0<R`L03@_700g<Qh0>SDO03`g
8@0203Xb6`0403Ta700h<1d0>30M03L^7@80=RdN0P0_:al302hZ7P<0;BTM00H0;RLO02`X7`0[9ah0
:BHM02HV700U9a`202<V6`<08B@K0`0R9A`202<V7@<08R<M0P0Q8Q`3020Q6`807b0J0P0P8A/2024R
70808R<M01P0;RLG03@[6P0m<R00ACHQ04Pf7P1;=a`0D3PL058k701N@1X0JT`V07aO=`2:KD<0T7=7
095dB02?Ld@0SW93095cD@1iH480Dd</03D_8@0[:b40;C0Y02/^9`0T9b0202DX8@<092LP0`0S9Ql3
02@W80809BPQ0`0V:B8802HW8@0702PY900Y:RD0:R/U02//900/;R<0;S0S02la900202la8`0A03Pc
800k=R<0?STV03dh9@0j=B80>C@Q03/f8`0o>RL0@cPV04<j:@14>bX0@3TY03Tc9@0d<2@0<c4U03Hd
:00d<2@00P0e<BD08`0f<RH0=c<W03Pd:00h=2P0>CDY03hc7@10=1h0@cLO04Pj801=?B<0DT4U05I2
9`1HABL0GDXZ05]8:01IARP0ET8W05E1:01E@BT0ED0[05I1;01CBR/0F4T/0618;01VB2`0IdX/06=<
:P1MCbX0F54W05]<:`1IBRT0EdPY05E6:@1DA2X0E4@[0080EDD^0P1JAbL305]8:0<0G4TY00D0FTLY
05U6:01HABL0Ed@V05I39@0205M49P0905Q59`1E@2D0ET4V05U19@1L@bD0H4DW06E8:01WBRX0JD/Y
0080IdXZ00T0J4/Y06U=:01[CbP0KE4Y071D;01aER/0K5@^06iF<01_Ec400`1aFC<02P1`F380KeLa
06I>;01/DRd0LeXa07QM<01kGbd0PF@/08QZ;P2>L38209]d?@0B09Yg@@2KO4H0VWm:09=lB028LT00
Of/h06II;`1TEbd0HU</069@;01RCRd0IDh_06Q?<@1YCc@0I5<e069A<`1PCc40GTd_0P1MC2h04`1N
CBl0Gdh`061A<P1PDC80He<b06MD<`1ZES<0KUPc071J<`1bFS@0H5Pa05mF;`1ODBX0GTlV069?9@1X
DBL0L5@/07=H;@1jIB`00P1lIRd01@20Ibl0PfPa08QZ=02<KCL0SVli0080VV``01l0WFla0:5d<`2W
NSH0[H<i0;>9?@2hScl0^i920;RHC@2fV4l0]IMA0;>EE@2`TeT0ZXmH0:J<F`2TREX0W8QS09V5H02F
P5/0TGUC08abC@29KDP0QFU408AV@P2;HS@0S6<e08eX=02AK3L0U70f09Qd=P2KN3P0W7Tg0080WGTk
00T0W7Xm09Qh?@2EMSd0TG@l08ma>`2;L3T0Sfhi08i]>02=K3L00P2<JcH04@2=K3L0SVdh08i]>02D
LC40UW<c09Uf=P2LNCT0WGXj09ai>@2JMcL0VGHf095b>@2@LCP0TG4h09=`>02BKcL0Tfhg0080U6df
0P2GLcL209Qd>00809Yf>P2MNCd0Wg/o0:1l@02MNC/0W7Pj09Yf>02IMCL409Qd=P0808aV=`2<ISD0
S6Lc08eX=02=J340SVTb08iZ<02>JRh209ma=@030:1b=P2QLcL0XGDh0080XWHi00H0XgLj0:Un>@2X
OCP0YWhi0:Am>P2RO3/209ml?00609il?@2PO3h0WGTk09Ue=`2HM3H0VgLi0P2MNC/06@2LN3X0VgLk
09ah?02LN3`0VgLk09Ue>@2ELCD0TFda08m[;`2BKS80UW8f09Ue>@2HM3P0UG4e09=_<`2DL3@0Ug<g
09A`<P2BKS80SVX^08YV;027HR/0Qf8]08QS;`29I3000P2=IC801P2:IC40R6@`08IR;P23HRd0PF8/
081Q:`80QElb00H0Q5lb085O<@1nGRl0Ne`]07UJ:`1fFRX307]J9@0807eL9`1oGRT0PV4/08ET;`29
J3<0RVTd08=U;`24IS0208IX<P0L08EW<@22I2h0OV0Z07aN:021I2`0P68/07mQ:`1nH2`0OV0^07iO
<01oH380P64c07=I9P1aEb@0KU@S06aA8P1]DRD0L5DZ07AH<01fFS80O5h/07eO;@20HS00Q6Hd08MY
=`24IS@0OV0^07QJ:080OElY00H0OV0Z081R;021Hbd0PV@^08=U;`24IS02089X;@06085W;P21IRl0
P6D`081T<P1oHc40Of<c0P1lHS40301kHC00NEl^07QN;@1gGB`0MU`[07EK:P1oHc<0PFDc08AX=P28
KCP0Rg0i08ab>@80SG<h0`2>M3/308ec>P80S78i0P2>M3/0102=LcX0S78i08ab>@2;LCP208Y`=`06
08M^=P26KCD0QF`d08A[<`23JS80PFP`0P20Ibl2081V<`0307mU<P1nI340OF<`0080O68_01D0Nf4^
07mS<@1nHS00OV8`081T<P26JSP0SW9009EiA`2JOT`0XHEF0:B8F@2VRUX0YXYH0:25D02GO4D0SG8k
08M]=01eGS80Le``06mH;01/EBT00P1ZDbL0601[E2P0KEHZ06UA8`1XD280ITlS06A?901PCB<0GT`T
05e;8`1JBb@0F4PV05M79@1EAB@0Dd8T0550901??R@0CC`R04`j8P17>b40ASXP04Di7`14>1h0@SHL
044e6`80@3@J0P0m<AT203`a7@0603P`7@0b:a/0;2HJ02@P5@0Q7A@071hK0`0K7AX201XL6@D06A/H
0P0H6QL301LI5Q005QPG200G6AP801DG5Q005QPG400G6AP801PJ5`P06Q`I00@06a/I01`L6P0L71X0
71`J0P0M7A/201hN70P08B4I200Y9A`:02XV7@80:bLN0`0/:1l00`0]:B00:bDI02/U6@0602/U6@03
02dW6`0/9QX0:R@H00<0:B<G00/0:R@H02`V6P0]9a/0:b<P02XR7`0Y8Q`0:B8J02XS6@0/9QX0;RPJ
030Z7004038U70@0<bHM0P0h:a/0100i;1`0>RdM03/^7P0l;al203d`80<0?C0M0`0n<Ah203lb7`P0
?C0O0`0i;1/303P[6P80=bXI0100?2TR03`Z800m:b40?R`P03l]7`10;al0@2lM044`7P12<B40@S4O
044`7P11<1`0@S8K04@d6`16=Q`0AcLM0P14=Ah01015=Ah0AS@N04Hd7P18<ah204Tc7P80CcHR00@0
D3LQ050h801A>Al0DCTM0P1B>a`01P1C>B80E3XS05Dk901F?2D0EcdV05To:080FT0Y0P1K?Qh205Xm
7@0=05/n7P1M@200Gd8R06138`1NAR@0GdDT06169@1RABD0I4DV06I59P1WA2H0J4DW06Y;;00206U:
:`0306Q9:P1WB2T0IdPY0080ITLX00P0JddY06Y<:01YBbL0J4XV06U;9`1ZC2P0K4hZ06e?:`80K50[
00<0KDl[06m>:`1`CR/00P1aCB/0101dCB`0L4dW075>:01cD2X307AA:`0:07=@:P1bCbT0Kdh[06i=
:P1/BbP0JdXW06Y99P1[BRL0K4/X06e<:@<0KDXT0`1^BbD306m<9P@0M4hW101eCbP207A?9@0707E?
:01dCRT0LddY079;:P1`BBP0KdPY06m9900206i88`0306e78P1/AR40JdDP0080JT@O0P1ZAR@01`1[
AbD0K4PV06a89P1[AbD0JTHT06U58`1VAB@00`1WARD206Q79P80JDPW00T0KdlX06i>9`1]CBH0K4`U
06e=9P1^CRL0L50Y075A:P1YBbT00P1YBbL01@1ZC2H0JdhV06e@9P1_DRH0L5<W0080M54[0`1cD2X3
079?:@80KdlX00<0L50Y075A:P1bDR/00P1cDb`00`1dE2d0NE</07UC;00207UC;080N58[0P1gDBX2
07aB:P0907]D:`1jEB/0NeH/07UF;01hEb`0NEP]07UF;P1jEbl0O5Ta0080OEXb00<0O5Ta07YG;`1i
ERh00P1jEbl207]H<00@07aI<@1mFS80OU/c07iK<`1mFbd0OU`^081N<021Gc40PV0b085O<@20GS00
Oed_081K<@21G380PUdc08=N=080Q5le00P0Pehd089M<`22G3D0Pehd08EP=P27HSH0R6<f08QT=080
Qf<a00H0PV0b08=Q<`23HC<0Q68d08ES=@26I3H208MU=`80RV@g0P2;ICP208aV>@80SFLj00D0RVHf
08]W=`2;IcL0S6Ph08eY>@0208iZ>P80Sf/k202CKc/0102?Jc/0SFTi08]W=`2:ISH208UU=@80RfLg
0180RVHd08UU<`27Hc<0QF0c08=N<P20Fc40OeX`07iH<@1hFBX0MePZ07IG:@1eERX0Le<Z079B:`1a
DB/0L50Z06a>:P1[CBT406Y<:080K4hZ00@0K4`S06e=901_CbH0LE4X0P1bDRT2075A:080Me<_01@0
N5D_07YG;`1kF2h0OE/^07iL;`1oGBl0QF0f08IQ=`27HSP0RF@j08]V?02=J3h0SVTo08mZ@02<ISL0
SFLh08iX>@2AJc`0Tfdn09E_@080Ug520P2FLSh209Ea?@<0U70l00<0Tflk09Ib?P2FLSh00P2GLcl0
302HM400VGE109Ue@@2IMD40V7<o09Ud@02KMT80W7M309ehA02LMd<0VgI209Ye@@<0V7A00P2IMD43
09Yf@P80VWE00`2IM3l309Qc?P<0Ug8n0P2HLcl309Ud@00<09Yg@@2HM400Ug<o09Ib@02FLT80Ug95
09QcA`2JMDT0VG=409YdA@2KMDH0W7I70P2MMdP01@2LMTL0VgE609Ye@02KMT40WGQ30080WWU400<0
WGQ309]f@@2JMD000P2IM3l309Ye@00609Qc?P2GLSd0Ug8m09Ia?02IM400V7<o0`2GLSh0102IM400
VWE109ag@`2KMT8309Ye@@0409]f@P2MN4@0WWU509mjAP<0WGU50P2LN4@309]g@`0509ahB02KMdL0
VgM709YfAP2IMDD00P2HM4@00`2GLd<0UW9209Ib@P0609Ib@P80V7930`2ILd@00`2HLT<0UW1109I`
@@0209Qc?P0409Mb?@2FLC`0UG0k09A_>P80Tfhi00<0TF/l099/?@2CKCh00P2DKSl01P2CKCh0TV`m
095[?02<Ic<0SVTe095/>080U6lk00<0Tfhj095/>02@JcL00`2<JcH[ooooo`00:_ooool309mc@P03
0:1d@`2QMD@0XGE40080XWI5202PM4<0402LN4@0WWU50:1kA`2SNdP0YG]90:EiB02VN4L0YGM609id
@P2OMD<0XGM50:9hAP2SNDL0XWQ60:5gA@2PMT@20:9gA080XgQ50P2TNDH20:EjA`80XGM500@0XWQ6
0:=iA`2SNDL0Y7Y80P2UNdT20:EiBP80YWY;0P2WNd`20:QlC@@0YWY9102WNdX20:MmB`060:IlBP2U
NdT0XgU70:9hAP2QMdD0X7I40P2NLdH01@2MLTD0W75409]`@`2KL4<0VVm20080VFi100D0UFln09A^
?@2AJc`0SfTl08eV>`0208eV?@0708iW@02=ISd0Rf@k08UR>@26GcH0QEhe08AM=00208EN=@0307iM
=01mG3<0OE`c0080OE`c0`1lFc802`1jFS<0N5Pa07AD;@1aDBX0L50Y075A:P1dE2d0MUH_07QD<P1f
DS00ME4_00<0Ldl]00<0ME4_07IB<01ZC2P00P1[CBT206a>:P80KDl[01T0KU0/06i=;01_CR/0L4l/
079B;01dE2d0MUH]07MH;01hFBd0OU/e081M=`21GSH0Pf0f08=Q=023HC<0PEl_081N;P29Hc@0RV@e
08eT=P2?I3L0TVHi09EV>P2FIc/0V6Ll00<0U6Xh0P2EJcT309I/>P0809=Y=`2DJSP0UV`j09M]>`2F
K3X0UF/i09AZ>02CJCL3095[?003099/?@2CKCh0Tfdn0080U6ho00<0Tfdn095[?02?JCX00`2>J3T0
0`2@JS/0TF/l08eW=P0208eW=P80S6He0`2;IC@208aV>@<0RfDh0`2:I3L308]U=P80S6Hg0`2=IcP@
08mT=`0508]P<`2<HC@0SF8e08iS=P2@ICP00P2AIST0102BIcX0TfPk09E[>@2EJcT209AZ>080TfTg
0P2BJ3H2095[?080T6Xk0P2?JCX208iX>@<0T6Dk0`2?I3X208iS>@80RV@e1P2;ICH208aV=`80RfDf
0`2:I3D00`29Hc@0Qf<c08MS<`0608MS<`P0Qf8e00P0RFPm08QW?026ICX0Q6<h08=R=`24HcP0QF@i
08IU>PP0RVDi00<0SFTe08iZ=P2@K3P00P2AKCT01@2@K3P0SVXf08eY=@2AKCT0T6`h00<0SVXf00`0
Sf/g091/>02AKCT0SF/k08YX>028ISH0RFLg08aZ>P2>K3`0RfTi08QV=P2;IST208UW>@0C08MW>023
I3D0OF4a07UO;P1gGB`0LE/Z06mI:P1[ERT0IU0W05m;9P1JB2@0E4@S05=38P1:?al0BSlQ04Pm7`16
>al0A3PN04<g7`02044e7`0H03`a7`0i<1l0=bhM03@]7@0a:ad0;b/O02l]8@0`;R80:RdJ02T/6@0Y
;1/0:2XL02LY700V:1d09BLL02DV7P0T9b008bHO024T7@0P8a`07b8K020S700Q91d08RDN0P0Q91/2
028U70D08bHM0P0U:AP0100T:1T08bLI028U6P0Q91/2020S70<07b8K0P0P8a`3024T7@06024V7`0R
9b009BPO02LY7P0Y:ah0:b`N0P0_;Ah0600a;Qd0<RlN03Lb7`0k=240?SHS044f8P12=R00@CDO048c
7014=Ah0A3PR04@i9@10>2D0>S<Q03@]6`0`:QX0<bdQ03<]7`0b;1h0<bdM03D`7@0g<Qh0>SDO03`g
8@80>S8K00@0>C4L03P`7@0h<1d0=bhM0P0f;Ah202l[7`<0;RXN0`0]:Ad0200^9al0;2PO02/W7P0Y
9Qd09RHL02@V6`0R9AX08B@I0P0P8aX2024T6`808RDL0P0S9Qd3028S7@808B8L0`0P8A/0800M7QP0
7QlI01lP6P0P8A/08R<M02<T7P0T9Al09BHP03L^7@0n<b40A3LT04Ph8@1:=Qd0CSHJ05<j701I?R00
JdXQ07UH;`29JD00UGI:09IiC@2DMd/0TGI7091eAP25ITT0IDde03lb8P0Y:Al09BXV02H/:00U:R@0
9BPO0P0U:24302@W80<08bHO0`0T9b0202DX8@<09RTR200V9b401`0Z:bH0:b`W02`]9`0];RH0;c4V
030b9@0a<bH00P0a<bD0400h<b00>cHS03hi9P0l=b@0>3<P03Ha7P0i=240?3LT03db800n=B@0@3LV
03df9P0h<R@0=30T03Dc9`0h=RX203@`900403Da9@0f<RH0=c<W03Pd:080>CDY0200@cLQ04Di8@19
>R<0CShU05=2:01IABX0G4T[05i9;01MBRX0FdPX05U6:01HA2T0Ed<Z05Q4;01IA2l0FTD`05A;;01I
BRd0HDT]06M9;@1XBbd0Hd`Z05a>:@1HDBL0FDX[05Q9:P1FAbX0E4@Z05=3:P1C@b`0E4@]05E4<080
FTLW0`1KB2P305a9:@0305a8;@1KAb`0FDDZ00<0Ed<X01D0F4@Y05U5:P1IA2L0G4@X05e69`1OARP0
HDHX06E8:01VB2H0IdTW06]>;01ZCB/0JThY06]?:01]DBT0L5@/07=H;@1dFBh0KUH`071H<P1aFC<0
0`1cFcD07P1bFS@0LETc06mG=@1dFSL0N5lf07]P<@1nHbh0QVT_091b<P2GNSP0XgTm0:=k@02SOdD0
Xh=:09n4C@2DODL0QG4l07UX=01QF2l0GUD/05i@:`1LC2X0GDXZ069;;01UBc00J4db069C=P1PDC@0
GTlb05a=<0<0Fd`_01T0G4d`05i>=01OD3<0HE0b06EB<P1XE340K5Ha06eG<01_F2l0Ge`c05eH<01M
E2/0GE0V069?9@1YDRP0LUH^07II;`1gIb`0NFH/07]V;@1nJ2l0Q6Tb08Y/=P2?L3X0Tg8m0080XG4_
02D0Xg<a0:Ii=@2[OcP0/8Hj0;F<?@2gTD00^I=20;:FC02`UDh0[iAA0:^AE02VSEL0WhMG09Z3E`2G
P5L0TGmG091mD`2=N4d0RW=708Y_@P29KCh0RV/l08][?02BISL0U6Pg09I[>02HKcL0VgDg09ih=`2P
NcL0X7hg09mm?@2MNc/0UgPh09=e>@2?LSP0SFli0080RFhi00<0RVTf08]Z=`2<JcP00`2=K3T0402<
JcP0RfXg09Aa;`2FLc40VWLe09ej>02OO3X0WW/i09]h=P2IMS@0TW<j095b>@2BLST0U74i09=`>02D
KcP209E^=`80VWHj0P2IMCT0202JMSX0WGTm09mk?`2QOD40X7dm09ml?02LNCT0VWLg0P2IMSH02`2J
McL0VgPh08mV>P2@IcT0TFTh09=[>02EKSL0UVlf09Qa=P2HLS@0ZWTg0080ZGTg0P2WNSL30:Ej=P0:
0:^1=`2[PCT0Z80h0:N1>P2VPC/0Y84m0:>0?P2RPCh0X7dm09ai>@80V7De00@0W7Ti09ml?02MNSX0
VgPh102LN3`01P2KMc/0VWHj09Ue>@2IMCT0TFda09Ea=@80VGDi00X0UW8f09A`=02ELCD0Ug<g09Yd
=P2HLS@0UVld09=/<@2AJS40SfPa0P2=IC4208mU<`0>08eU<P2:IC40Qf<_08AS;P23HRd0PF8/08=M
<024GS40Q5lb08=Q<`22HS<0Of0a07eN;`1jGRh307mN:@0R07iM:01oGRT0P5lZ08=R;@26IC00R6Lb
08=U;`25Ic40QfTc08QZ=026J380PV@^07iP:P1kGBL0Q6D^08=T;@21HR`0Oel/07mO;P20H2l0PF4b
089R<`1eG2@0M5/U079H9@1`ERD0L5DX079G;01dF300MUXc07]M:`1jG2X0Ned[081R<080QFLe00X0
P68`07YL:P1mGbT0OElY07mQ:`20HR`0PV@^08=U;`24IS00QFLa0P23JBh00`23JC00PVL`089W<P02
085U<`05085U=@1jH2l0NV0_07YP;`1iGbh00`1hGRd01`1gGB`0PFDe08=W=@26JSP0RFhi08]`>@2<
LST00P2<LSL208me?080SW@k0P2=LcX208ab>@80SG<j00@0S78i08]a>02:L3L0RFlf0P28KSD01P28
KcL0Qfhf08I]=@25K3@0PfXb085X<080P6L_0P20IS<00`1oIC80OV@a07eS<00207aR;`0Q07]Q;P20
I380Of<a07iR<01oHc40Q6Pf08a`?P2DN4H0VGe;09f0EP2RQET0Yh]L0:Z>GP2WS5L0WhA=09Ek@02?
MCX0O6Di07UR=P1dGC40KeP/06]D:01ZDbL0Je@X06aE:@1/E2@0Je<U06QB8`1UD2<0HDhS05e<8@1L
BR80FDXQ0080ETHT0100EDDT05=2901B@BD0D3lU04ln901??BD0B3`R04Lk8@16>R00A3PN04<g7@11
=A/0@3@J03lc6@0o<AL0?S8J0P0o<ad01@0m<R00=bhO034Y700Z8aT09b0H008071hK0`0K7AX301XL
6@@06A/H0P0H6QL201LI5Q005QPG200G6AP801DG5Q005QPG400G6AP801PJ5`P06adJ0`0L71X201dM
6`<07QhL1P0Q8AT2020P60P0:RHM2`0[9ah202`X7`<0;BTP200/9QP00`0]9aT0;2HH02/U5`0302XT
5P0;02/U5`0/9QP0;BLI02/S800Z8Ql0:R<M02XS6`0Z8aT0;2HJ02lY6`0`:Q`0100c9Qd4038U7080
=bXJ00@0>2/K03T/700i;1`0>RdM0P0k;Qh303``6P0303da6`0n<Q`0?S8L0080?c<M2@10<Ah203l`
7@80?RlL0P0m;Q/01`0l;AX0?BXS03d[8@0n;280?R`P03l]7`10;al00P11<1h02013<R00@S4O048a
7@12<Q/0@S8I04@d6P17=ad0B3TL0P15=Ql01016=Ql0AS@N04Hd7P18<ah204Tc7P80D3LS00@0D3LQ
050h801A>Al0DCTM0P1A>Q/205@j8`0705Dk901G?BH0F3hW05To:01J@2T0Fd4Z05`o7`0405/n7P04
05e0801P@b<0HD@T05m79@80H4HU00<0HdHV06A59P1WARL00P1XABL306U::`0=06Y;;01[C2d0K4d^
06a=;P1]CRl0K4hZ06]=:@1ZC2P0JD/W06Y<:01[CBT0KDl[06i@;00206eA;00306i@;01`Cb`0LDl/
0080LTh/00<0M4d/07=@:P1bCbT00`1bCbT02`1dDB/0ME8/07IC;@1`Cb`0KTdZ06a;:01[BRL0JTTV
06]:9`1/BbP0KD`Y00@0KDXT0`1^BbD206m<9P@0MDlX101dCRL207A?9@0607E?:01eCbX0M4hZ079;
:P1`BBP0KdPY0P1aBbH00`1`BRD0KdTT06i88`0206e78P0306a68@1/B2@0KDTU0080KTXV00D0KDTU
06]78`1YAB40J4@P06Q79P0306U89`80JTTX0P1[BRT00`1`D2T0KdlX06i>9`0206i>9`0;071@:@1b
DR/0Le</06]=:@1ZC2P0JT`V06Y=9@1[CR@0KU4U071C9`1bERL00P1fDbd00`1eDR`0M54[07AA:`02
07=@:P06079?:@1aDBX0LE4Z079B:`1cDb`0M5@]0P1eEBh0101fERl0NeD^07YD;@1jE2d207UC;080
N58[00H0Me4Z07iC:@1nDbT0OU@Z07aE:P1lEb/207YH:`0407YI;01jEbl0NeP`07eJ<P80OU/c00<0
OEXb07]H<01jEbl00P1jEbl00`1kF300O5Ta07eJ<P0207iK<`0507mL=01mFbd0Oed_085O<@22H380
0P23HC<2085O<@03081K<@22GC<0Pehd0080QF0f00/0Q5le08=N=022GC<0PE/d08=N=025H3H0Qf8f
08QS=P28I3@0R6@b08MS<@0208=Q<`0408AR=025HcD0QV@f08IT=P80QfDg00P0RV4e08]R=P2<HcL0
SF@h08mV>P2@Ic/0TFPl099Y?@80RVHf00<0RfLg08aX>02=JCT00P2>JSX208m[>`P0U70l00@0TFdm
08m[>`2=JCT0RfLg0P29ICD02P2:ISH0RfLg08YU<@29I300R68a08MQ<P25Gc80Q5db08=L<@23G3<2
07UJ:`0907QI:`1fEb/0MED/07AD;@1cDb`0LU8/06i@;01]Cb/0JddY0080JT`X00P0JddY06a>:P1]
Cb/0K4dQ06e>8P1`DBD0LU<W07=D:080LU<W00T0LE8V07EA;@1fDRh0N5D_07YG;`1lFBl0OU`_081N
<@21Gc400P26HCL01028HcT0RVDk08aW?@2=J3h208mZ@00808]U=P2<ISL0SVPi095[?02CKCh0UW11
09Qb@`2ILd@209Mc?`80UW8n0`2ELCd01`2DL3`0Ug<o09Qd@02IMD40VWI209ahA02MNDD00P2NNTH0
0`2JMD40VgI209ehA00309mjAP0309iiA@2MN4@0VWI20080VWI20P2KMd<309ahA080W7M200<0VgI1
09Ye@02JMD000P2IM3l01@2HLch0Ug8n09Mb?P2GLSh0V7<o0080VGA00P2JMD404`2KN480VWI209Qd
@02GLd40Ug=309QcAP2JMDT0VgI:09UcA02JM4D0W7I709egB02NN4T0WGM809afA`2KMDH0VG@m09Ye
?P2LMd000P2MN4401@2LMd00VWDn09Ud?@2IM3l0VWE000<0VgI100`0VG@o09Mb?@2GLSd0UW4l09Ye
@@2IM400V7<o09Mb?P2HLcl0VGA009]f@P2LMd<209Ud@080V7<o00@0VGA009]f@P2MN4@0WgY60P2L
N4@209]g@`80VWI20P2IMD4809YfAPP0Ug=300P0V79309UcA02JM4D0VgE609YdA@2HLT<0UW1109E_
@080VWDn00T0V7<l09Mb>`2EL3T0Tfhg099]=P2AK3D0SfTj091Z>`2BK3d00P2CKCh01P2BK3d0T6Xk
08mY>P2=J3@0SfXf099]>@80UG0l00<0Tfhj091[=`2>JCD00`2<KCL[ooooo`00:_ooool0102NLT40
Wg=209mc@P2PM4<20:5eA080XWI5202PM4<0302LN4@0WWU50:1kA`2TO4T0YG]90:EiB02VN4L0YGM6
09ab@02NM480X7I40:9hAP80XgU70P2QMdD30:=hA@030:AiAP2UNTL0YW]80080YW]80P2QMdD0102R
N4H0XgU70:=iA`2TNTP20:EkB@<0YGU:00<0YWY;0:MkC02XO4d00P2XO4d01@2TN4L0YGU80:EiB02V
NTT0Yg]:0080Z7a;00L0ZGe<0:QnC02WOD/0YWa:0:EkB@2SNDL0XWQ60080XGM50P2NLdH01@2MLTD0
W75409]`@`2KL4<0VVm20080VFi100h0UW0o09A^?@2AJc`0SVPk08eV>`2=ISd0SVLn08iW@02<IC`0
Rf@k08QQ>026GcH0QEhe08AM=080QEhe1@1mG3<307aK<P0@07]K=01hF340M5@]075A:P1`D2T0LE4Z
07AD;@1fERl0Ne@c07YC<P1gD2l0MDh]07A=;01eCRd0MTl^07M@;`80JT`X00@0JddY06a>:P1/CRX0
KDl[0P1^D2`01P1^CB`0Kdh[071?;01bDR`0M5@]07IF;@80MeP/0100P5dg085N>023H3P0Q64g08AR
=@22H380P5h^07mM;@29Hc@0S6<e08eT=P2?I3L0TVHi09IW>`2HIc`0VFPm0P2DJSP309E[>@<0UV`j
00T0TFLe099X=P2DJSP0UF/i09I/>P2EJcT0U6Xh09=Y=`2@JS/00P2AJc`00`2BK3d0Tfdn09=]?P03
09A^?`0709=]?P2@JS/0SVPi08eW>02>J3T0SfTj091Z>`0308eW=P80S6He0`2;IC@208aV>@<0RfDh
0`2:I3L308]U=P80S6Hg0`2=IcP@08mT=`80RUlb00<0S64d08iS=P2@ICP00P2BIcX209AY?0<0UV`j
00<0UF/i09AZ>02CJCL00P2CJCL2099/?@80TF/l00@0T6Xk08mY>P2?JCX0SVPi0`2@IC/208mT>P<0
SV<i0`2:I3D508]U=P80S6Hg0P2;ICH408YT=@P0Qf<c2027HSD01P29J3l0R6Ln08IU?024HcX0Pf8i
08AS>P80QF@k2029I3P00`2=JCD0SVXf091/>002095]>@0D091/>02>JSH0SFTe08m[=`2>JSH0S6Pd
08]W<`2:IS80RfLc08aX=02=JCD0SF/k08YX>027ICD0RFLg08aZ>P2=Jc/0RfTi08QV=P2;IST208UW
>@0K08IV=`23I3D0OF4a07UO;P1gGB`0KeTX06iH:@1ZEBP0I54W05i<9P1HB2@0EDDT05938P1:?al0
BChP04Pm7`16>al0A3PN048f7P11=Al0@3@N03db800j<B00=bhM03@]7@0a:ad0;b/O0080;R`P0100
:RdJ02T/6@0Y;1/0:2XL02LY700V:1d09BLL02DV7P0T9b008bHO024T7@0P8a`07b8K020S700Q91d0
8RDN0P0Q91/2028U70@08bHM00L092LN02DY600U:AP092PI02<W6@0R9AX08B@K008082<L0`0O8Q/2
020S70<08B@M00h08BHO028W800U:1l0:2XO02T[7P0/;Al0;bdN030^7`0a;Qd0<c0O03Pc800l=B80
?SHS044f8P80@SHP0100@34J04<d7`15>B<0AS/W048j9`0j<b40<b`L02`V5P0d;R80=2hP03<]7`0c
;Ad0=C0M03Lb7P0i=1h0>cHP0P0j<Q/0100i<A`0>30M03P`7@0g;Qd203H]7P80;b/O0`0^:Qh302dY
7@0602hW7`0[9ah0:bLN02PU700U9A/08bDJ0P0Q91T0100O8QT082<J020S6P0Q91/2028U70808bHM
0`0R8ad2024R70<0824K0P0L7AL0100N7aT0824K028S7@0T9Al202HW8@0H03hc8@13=R<0BCXU04/i
8@1;=Q/0CSLH05Hk7@1N@B40ME8X089O=@2BLDH0Vga@09enDP2HNdl0UGY=09AiC01kFCh0EchX03@X
6P0T9Al082TV01dV8`0O9Ql09RTP0P0U:24302@W80<08bHO0`0T9b0202DX8@<09RTR200V9b4202`]
:00502d^:00^;bL0<38W034c9P0b=2L00P0c=BL0>00i=240?3LT03hi9P0k=R<0=c8O03D`7@0g<Ql0
>SDR03X_7@0k<R40?SDT03`e9@0h<R@0=C4U03Hd:00j>2`0<blS03@`900e<BD0=S8V03Lc9`0h=2P0
>CDY03Xf:P18?2@0Bc`U04i09P1C@bT0F4L[05i;;@1RCC00Hdh_05a9:@1KB2P0FTLY05U5:P1IAB`0
FTH^05]6<@1LAc80E4//05Y;;P1RBRh0J4X^06U<;P1TCB/0G4hY05M@9P1HBBX0EdP[05E6:@1C@bT0
DT8Y05=3;01D@bl0ED@`0P1JAbL305]8:0<0G4TY00<0GDT^05]7;01IABX00P1G@bP00`1HA2T0FDDZ
05Y6:`0205i6:P030617:@1RAbT0I4LW0080IDLU02d0IdHS06e@;P1/Cbd0K50[06a@:@1^DRX0LEH[
07AI;P1fFbh0KeLa075I<`1cFcD0M5`f07EM=`1dG3H0Le/e079J=01hH3h0Nf4n07eT>`1oI3D0PVL`
08Y]<@2FNCL0WX4m0:9i>`2RNS`0XGe10:61AP2JP4L0S7M007UX<P1/G2P0HEX`05iG;@1MDB/0FT`Y
05]8:01OAb/0HTP]06E9<@1PDC@0GTlb05a=<01IBRd00P1HBB`205U:;@0H05a<<`1MCC<0Gdhb069?
;`1UDC00JE<^06YD;@1[E2/0H5he05eJ<@1LEB/0GU4W06=@9P1ZDbT0LeL_07MJ<01eIR/0MVH[07UV
;01nJ2l0QFXc08a^>02CLSd0UG@o0P2UM340?@2VMc<0ZW/e0:f1>02aQc/0]8dn0;NA@02hTd80[iE;
0:bDC02YTTl0YXeD09n8E02IPUH0TgeD091jE@2;NTl0RGQ<08QcAP26L3l0R6hk08]]>@2=KSP0Sfhh
09YZ>P2JK3/0W6hj09ec>@2OMcX0X7Xi0:9m=`2RP3T0X7ll09ek>`2FMcL0T78f08]^=P28KCH0R6dh
08M]>P28Ic@0RVTf08a[>02>KCX0Sfhk08e/>@2;JSL0RFPe09Aa;@2GM300VgPd09ik=`2POCT0WW/g
09ai=@2JMc<0Tg@k099c>P2CLcX0UG8j09Aa>@2EL3T00P2FKcP03P2LN3`0VgLk09Yf>P2IMCT0VWHj
09ah?02ONcl0X7a00:B1@@2ROcl0Wg`l09ej>P2KN3P0W7Ti0P2MNSX02@2GKD<0V6m309Ya@`2MMD80
WgQ10:9k@02TOT00YGm00:ml>P020:im>P050:am>@2YO3P0Z7dh0:Ml=`2UOCL00P2/PSP03P2ZPSX0
ZH<l0:R3?@2VQ3d0YX<o0:F4?`2POCd0VgPh09Md=02HMCD0WGXj09ml?02MNSX0VGHf0`2LN3`01`2M
NCd0Wg/o0:5m@@2ROT80Xgm3091/<02ELCD00P2JMSX04P2GLcL0U70d09Ea=@2GLcL0WGLh09eg>@2L
MSP0VW<h09M`=`2DKCH0TFTe08mW<`2@Ic<0SfHb08eU<@2<I300RF@_08IS;@80Pf8/00T0OeT/085K
;P23GS40Q68d08AT=@23I3D0PV<d07mS<`24Hbd00P22HB/0;P20GbT0OehX07mN:021H2X0Pf8/08AS
;@24Ibl0QFP`08MZ<P28Jc<0QVTa089U;@1nHBT0NehV08IW;P24IBh0PV</081Q:`1oGb`0P60_085Q
<P22HS<0ME`S07EL901dFbD0LeTX07=H:@1dFBh0M5P`07EI<P1jG2X0N5XX07UK:@1nH2h0Q6Hd08EW
=@21Hc40Ned[07eO:@1nH2X0Of4[085S;@22I2h0Q6H`08EW<@26J38208AZ;`0308AZ<@23J340PfPc
0080PVHd00<0PVHf07UO;P1iGbh01P1iGbh01P23IcL0QFTg08M[>@2:KcX0Rg0i08ab>@80Rg4f00@0
T7Hm08me?02?MC`0SW@k0P2=LcX408ab>@0408]a>02:L3L0RFlf08Q^=@80Qfdd0P28KcL01026KCD0
QF`d08=Z<P22JC42081W;`80P6Hc00<0OfDb07iT<@1mHc000P1lHRl09P1kHBh0P6@b07mS<@1mHBl0
OV8`08=W=@2;Kcd0TgM509QlBP2KOU@0X8=I0:R<G@2/T600Zi1K0:B:D@2JP4D0TgTl08=/@01oJ3`0
N64e075J;P1/EBT0JU<W06UB9P1ZDbL0KUHV06eE9@1ZE2D0IU4T065>8`1MC240FdXO05Q9801FAR@0
EDDS05A48`1C@R@0DT4U0P1A@2H02`1@?RH0B3`R04Lk8@16>R00ACTO04<g7@11=A/0@3@J03lc6@10
<QL0@C<I0080@3@N00D0?c@P03Xa800d;1l0;RHK02XS6@0301`N6`806adJ100J71T301TK608061XG
0P0G6AH@01HH5`P05aTH200E5aH@01HH5a005aTH200H6QL801/M6P8071`J0`0M7A/301hN70D08B4I
0`0P81P802XV7@X0:bLN0P0/:1l302dY800302hZ8@0/9QP0;2HH00H0;2HH00<0;RPJ02dW6@0[9AL0
0`0Z91H00`0[9AL0;BLI02hX6P0202/S800602XS7@0Z8a/0:b@J02dW6`0_:A/0<2XL100c9Qd4038U
7080=RTI0P0g:QX0100h:a/0>B`L03X]7@0j;Ad203/_6@80?30J00@0?C4K03hb700n<Q`0?c<M2011
<Ql204@e8P0404<d8@12<b00@S<P044b7`80@34N00H0?RXS03l[8P0o:b80@2`Q044^8011;Ql2048_
7P0804@c8@13<Qh0@S4M048b6`13<aX0ACDK04Lh6`18>A`204Df7`0404Hf7`17=Al0AS@N04Pc7P80
BC<N0P1@=b<0101@=b40D3PP054i7`1A>Ad2054j6`0605@j8`1E>b@0ES`U05Lm9P1H?RL0FT0Y0P1K
@BX0601M@1h0G3lM05/n701K?Q`0G3lM05i17`1P@b40HD@R05m79@1PARD0HDLV06=69P1UARL0IdHW
06Q59`1YARP0ITLX06M8:@1YBR/0Jd`]06i?<01`DC80LU<d07=D=@80K4hZ0`1ZC2P00`1/CRX0KU0/
06mA;@0206iB;@0306mA;@1aD2d0LDl/0080LTh/00`0M4d/07EB;01cD2X0LDhX071=9`1aCRP0M54[
07MD;P1iES00L4l/06i=:P1]C2T306]:9`0306a;:01]C2T0K4TS00<0KDXT0`1^BbD206m<9P0507MA
:P1fD2T0MU0Y07E?:01dCRL00P1cCBH02P1bC2D0LdhT07A?9@1fD2T0MU0[07E?:`1cC2/0L4TX06m8
:@1eCbX207A>:@0307==:01bC2L0LD/V0080L4XU00P0KDTU06i:9P1_BbL0Kd/W06i:9P1[Ab<0J4@P
06I27P<0JTTX0`1[BRT206a;:P0A071@9`1_CbH0KdlV06i>9@1_CbH0LE4X07=C:P1dE2/0K4hZ06]=
9`1ZC2H0JTdU06a?9@1^DBD0LEDV07=G:01iDb`00P1hDR/00`1gDBX0MU0Y07I@:@0207E?:006079B
:`1cDb`0Le</07AD;@1eEBh0MUH_0P1gEc0307]E;P0307YD;@1iDb`0N58[0080N58[0P1oE2T0101n
EBT0OeHZ07eG:P1mF2/207]I:`0307]H<01lFC40OEXb0080OU/c00<0OEXb07aI<@1kF3000P1jEbl0
101kF300O5Ta07eJ<P1nFc<207mL=00607iL;P1oGBl0PEla08=Q<`24HS@0Pf4c0P22H3800`21G380
PUdc08AO=@0208IQ=`0;08EP=P23GS@0PUdc085K=023GS@0QF0f08MR=P28HcH0RFDe08QT<P27Hc40
0P23HC<00`24HS@0QF<e08IT=P0208MU=`0708QV>029H3@0RF0d08]R=P2=I3P0SfHj095X?00209=Z
?P80RVHf00<0RfLg08aX>02=JCT00`2>JSX00`2?Jc/0U70l09A`?00609A`?006099^?P2@K3`0SVXj
08]W=`2:ISH0RFDe0P2:ISH01029I300R6<_08QR<@27HC8208IP<`80QEhc00H0NU`Z07YK;01iFR/0
MePZ07IG:`1dE2/207=C;00306mA;@1]Cb/0JddY0080JT`X00L0JddY06a>:P1]Cb/0K4dQ06e>8P1`
DBD0LU<W0080Le@X01X0LU<W075B9P1dD2`0ME4]07MD;P1jEbl0OEX`07mM<021Gc80PV0b08IQ=`27
HSP0R6<i08YU>`2<Icd0SVTo08mZ@02@Jd40RfDf08aV=`2>J3T0TF/l09A^?`2FL440VG=409YdA@<0
Ug<o0P2FLSh309Ea?@0>09Qd@02IMD40VWI209ahA02NNTH0X7a80:5mB@2ROTX0VgI209ag@`2NNDD0
X7]70:5lB02PNdL209mjAP80VgQ20P2LND<409ejA00409eh@`2LMd80W7M209]f@@80VWE00P2IM3l3
09Mb?P0309Qc?`2IM400VWE10080VWE100/0W7U309]g@`2IMD40V7A209QdA02IM4L0VgI:09agB`2H
LT<0VWA509afA`0209ihB@0609egB02LMTL0VWA509Ud?@2JMCh0VgHo0P2LMd001P2KMSl0VWDn09Ud
?@2IM3l0VWE009]f@@80W7M200H0VWE009Qc?P2HLch0UW4l09Ye@@2IM40309Qc?`0309Ye@@2KMT80
WGQ40080V7<o00H0Ug8n09Ia?@2HLcl0VWE109ehA02ONTH309]g@`0309Yf@P2IMD40V7A00080V7A0
0`2IMDD209YfAP<0VgM7202HM4@04`2HLT<0VG=409YdA@2KMDH0VWA509Qb@`2FL440U6ho09ag@02K
MSl0VG@m09Mb>`2EL3T0Tfhg095/=@2@Jc@0SVPi08mY>P2AJc`00P2CKCh01P2AJc`0SfTj08iX>@2=
J3@0T6/g09=^>P80UG0l00<0TVdi08mZ=P2=J3@00`2<KCL[ooooo`00:_ooool01P2MNT@0WWU409ii
A02PN4@0XWU50:=hA@80YWQ6202PMD801P2NLdP0WW=609mdA`2OMDD0X7I40:1g@`80X7M10P2PM4<0
0`2QMD@0XWI50:=gAP020:EiB0030:IjB@2WO4T0Yga900H0Yga90P2SMdH00`2TN4L0YGU80:IjB@02
0:MkBP040:QlB`2VODL0YWe70:ImA`<0Ygi80P2XOdT30:5lB0030:9mB@2SOTX0Y7m;0080Y7m;0P2X
OT`01`2WOD/0YG]90:AjB02SNDL0XWQ60:5gA@2PMT@00P2OMD<0102NM480WG=109ec@@2LLT0209]a
?`@0TV`m102AJc`308YT?@0608US?027HCX0Q5hg081J<`1nF340OE/]0P1mFbh00`1mFS00O5Ta07aI
<`0207aH=00607MG<01fERl0MUH_07EE;P1dE2d0Le</0P1bDR/01P1eEBh0M5@]07AD;@1bDR/0LE4Z
071@:@80KdlX0P1/CR`306]=:`0306a>;01]Cbd0KDl]0080Ldl[00`0ME8/07MD;01hEB/0NUP[07aJ
;@1lFR`0NeXa07aK<01nFc40PE``08=N<@25Gc0208QP;`0608US=02:I3D0RfDf08eW>02@JS/0TV`m
0P2DKSl0202EKd00U6ho095[?02?JCX0SVPi08mY>P2@JS/0TF/l202EJcT209EV>P0409IW>`2GJ3`0
UfPl09QY?@80VFXn0P2AJc`3091Z>`<0SfTj0`2;ICH208aV=`<0SFLh0P2?JCX0102>J3T0SFLh08]U
=P2:I3D208US=0<0RV@e0`2;ICH208aV=`<0TFHk0`2@ICX208mT>@0909IU>P2EI3T0Tf@h08mS=P2>
HcH0SfHh091W>@2?JCX0S6Lc0080SFPd00<0SVTe08mZ=P2@JcL00P2@JcL00`2AK3P0T6Xk091Z>`03
091Z>`<0SfTj202CJ3/01P2DJ3/0TVLj099W>P2@IcT0SFLh08]W=`80R6Hf0P2?I3L208iS=P@0SF8e
0`29Hc@308QR<`80Qf4b2027HSD208IQ=0<0Qf8e0`28HcH308UU=@D0RVHf00<0TFdm08m[>`2=JCT0
0`2:ISH02P2;IcL0S6Ph08YV=P2;IcL0S6Ph08eY>@2>JSX0Sf/k091/?02AKCd808m]?@0608YZA02:
JT<0RVY108Y[?@2:K3X0RV`h0P2:KCD08@2<K3d0R6Pi08=T=@20I3@0PFLf07iW=@1kI380MV0^075J
<01^FBh0JU@]06A@:`1NBbX0EdHX05939P1@@2H0BC/P04Xl8@18?280AS`S044i8P0m=b40>S@N03Pc
7`0i<Ql0=c0N03@_700`;A`0;R`M02`]7`0];B40;BlR02X/8@0202T[800302PZ7`0W:Ah09RPM0080
9BLL200Q91/302<V6`<092LL0`0U:1d01P0U:1l092LN02<V7@0R9A`08B@K01lR6@807R4H0P0Q8aP0
100R91T08bDJ02@V6`0U9a`202HX7@0602@U7`0U9Ad09bLO02/X7`0^:Ql0<B/O0P0d;1l05P0b;AT0
=BlI03Tc7@0m=Ah0@CLN04<g7@15=a`0A3HK040e6@12=Q`0@SPM040i7`0m=al0=S4K02h/5`0[:A@0
<BPI03<Z6`0f;A`0>C4N03/c800l=1l203`d7@0603da8@0k<R40>S4P03Pa7`0e<1d0<RlL0P0`;a/2
02d^800302`]7`0[;1h0:R/M0080:BXL00<0:2TK02DV7P0U9Qh00P0T9Ad202<T70808R<K00@0824I
024R6P0Q8QX08R<K0P0S91`202@U7@80820N0P0O7ad201hN70807AdK0P0M7Ad0400N7aX07b0J028T
6@0V:1X0:R/I02`]6`13<aX0BcXP0550901A?R00CCPI054j6P1MAB<0J50^08AT=@2<KS`2099d@P0<
09IhA02LOTP0V7]308e`>01>AST0@S``030/800S8aL082<H020X7@0Q:b808BdS0P0Q8b02028T8@80
8bDR0P0T9R<802HW8@0=028V9`0Q9B@08bDT02@T8P0U9R40:2LR02dZ8`0^:b@0<2TO038[8@0f<2@0
>S@V03`f9P0203dh9@80?CPT00H0?C/V03/h9@0h=B80=S<R03@a8P0c;b<203@`9@@0>38V00@0>S@X
03dg:`0o>Bd0@C/_0P0h=b<04@0h=R40>cHP03dg7`11>R00A3dS04Lm8P19@RD0C4<V04i39`1C@bT0
FDD/05i6;P1PARl0HTH`0658:P1PAbT0GTDW0080GD@V0140GTDW05m6:01PAbT0H4LO0619801RBR@0
HddX065=:P1PCB`0GDd[05a<:`1B@b`0Dd@]05E5;01GAR`0F4L[05]8:P0205e8:@1P05m6:01OB2T0
H4TZ05m::`1MBRX0FTXY05M89`1FAbH0G4<]05]3:`1L@R/0GD4Y0653:@1TABT0IdP[06Y8;01H?b/0
FD0Z05Y1:`1LA2`0GTH/0618;01QBR/0HT//06I>:01WCbT0J50Z06]C;@1]EBl0KeLa075I<`1bFS@0
Kedi06mM=`1_FcH0LE/d07=L<`1fGcD0NF4e07]S=`1jHS80OFDe08AX=P2;KCT0TW4k09Ue>`2NMc`0
X7Pk0:N0?@2ROcd0WG/n09=f?P27L3h0OVTn07ES>`1_Gc/0Je8Z06QA:01VCRP0HddX061<:@1OC2/0
GTh/05m?;P1UCC40HTd`05m<;P1KBR`0FD`/05I=;01ECbd0EE4^061;;01PCBd0H50_05mB<01NE340
FU@`05QD;`1FE2h0Gddg061<=01OC2h0HDdX06MB9`1`FRP0N64[07eW;@1eJ340Nf`c085^=P23KC@0
QVTa08aY<@2BKS@0VG0h0P2NNbT09`2PObh0YXDh0:^;@02^T4P0/9=?0;2EDP2`U5<0YY9E0:BBE02P
SE80VHQ@09:2CP2:O4/0QGM808=eB026LU40PFY807eT?020HcL0RFPe09A]=02FKS40V6`]09MZ<@2H
KS@0WG<i0:5i?02SOCl0XWi00:1n?`2OOCh0Tge;095kB@2?NDL0RgE308I`?P22K3X0OfTg07eW=@02
08AT=@0<08ES<`27Hc40R6@`08]V<@2?Ic<0T6Tb091]=@2CL3P0UW<i09Yh>`2MNc`0Wgdn0P2POSh0
0`2BLCh0TG0m091_?00208i]>P0I08m^>`2AL3d0TW4n09if>`2PMS`0XWTk0:Mk?02YO3T0[7dg0:en
=P2^OS@0Zh4e0:Qn=02UNc40Ygde0:Yo>P2YOSX0XgLf09ea<02WM3d0Yg@k0:Qf>`2YMcP0ZWTf0:Yj
<P020:]k<@0L0;:0>`2`OcX0[ghi0:en>02/P3T0[H<k0:j6?P2_Qcl0YXDh0:V5>`2[QSl0[HI30:b3
@`2/Od@0ZW]30:Mh@P2ZQD40Yh8n0:=n>P2ONSH0WGPd09ii=@2QO3P0XWdi0:1g=@2QN3H0XWTg0:=j
>0@0Y7/i01P0YW/f0:Ml>02WO3P0Yg/j0:Ij>`2TN3/0XWHi0:1c>02MMS<0W7Db09]d<@2JLc00V74^
09I_;02EKR/0U6dZ095^=02>Jc40S6T_08eZ<02?K380SV/a08UV;024HBL3085M:@03089N:P23Gb/0
Pel[0080Q60/00L0PUhZ081O:P20GbX0PF0[081Q:`20HR`0OV</0080OVD]00T0O6P]07eY;P1oJc00
P6`a07m[<01nJRl0O6P]07YV:`23I3D00`22Hc@2085R<`80P64b01P0Q60`07mM;@1kFB/0MUDX079C
9`1_DRP0Ke@Y071D;01bG2/0Led/07IP;P1iI2l0O6L`081[<P22KC@0Pfld08MT;021HBP0OUdW081Q
:`25Ic<0R6`j08I/>@23JCP808AU;`03081V<`1oIC80OF<`0080O68_00@0OF<`07mU<P20IS<0QV/d
0P27K3D01@29KSL0RVlh08aa>P2>Lc`0Sg@m00P0Rg0i202:LS@208AZ>@0308=Y>022J3L0PFLf0080
P6He00@0OfDd081T<P20I380P6@b0P1oHc4307iR<00b07US<@1iHRh0N64]07aS;@22Ic00S6lg09Ig
?P2KO4<0WH5B09n3E02TR5P0ZhmM0;2EH02]TUd0Y8UB09b1BP2=M3/0PfXb07QO9`1aF280L5HS075G
9P1_E2D0K54R06UF:`1UDRP0HTlU069?9`1TD2/0IE4^065=;01NBRT0G4XV05U69@1E@R40DChN04ll
7P1@?240DShU05A09`16>a/0AS/M04@k7010>A`0?STL03/g700j=Qd0>3HM03hc7@0j<Q/203Ta700=
03Tb7`0i=200=34N02/Z600T8a407R0E01dO500J7A@05Q/D01DL5@0C71L051dH01@O6`0201XL6@80
6A/H0P0H6QL201LI5Q005aTH200H61P801DG5PP05QPG200H61P801LI5PP06A/H00@061PF01TI5`0I
6AL06ATG0P0J6QP201/K6@P06a`F200M71L0200L7aH07B0G01hO5`0O7aL08QlH02<N600T7aT09QlI
0P0X9A`03P0X91/0:R<K02`S700_91h0<BHP03@W8@0^:a`0;BXK02/X6@0Z9aP0:BHG02XW600[:1T0
;2TJ0P0_9A/2030V7005034W7@0b:1h0<RPN03<Y7`0a91/00`0b9A`203<V7@80=2LN00<0<BXP030Y
7`0`:Al00P0_:1h202hW7@80;BHL0P0]8aX01P0/8QT0;B<J02hT6`0a9ah0=2XQ03D[8PP0<RPL00@0
<bLG03DY6@0g:a/0=BTI0P0b9QH02P0f:QX0>blO03d/6P0n;A/0?bhL040_7@11<1h0@S4O04<b8014
<b4204<c6P80A3@K1015=A`01011<B40@30P040`8010<20403l_7`80>S<P00<0>c<P03db800n<B00
0P0o;al01010;al0@34L040a7011<Qd2048c7P0304<d7`14=B00A3DP00<0B3PO1@19>B00401:=AP0
C3LJ050h701C>Ah0ECXO05Li7`1F>1h0ESHM054n7P1B?al0E3lP05M08@1J@B<0Fd8T05e29@1N@bH2
05Xm7@0F05/n7P1M@200GT4Q05m28P1P@b<0HD@T05ho801R@b@0IdPY06a=;P1^Cc00K4d^06U::`1W
B2T0HTXX06A::@1VC2/0JTd]06i?<01bDC80ME8d07IC=@D0KE0X0`1^DBT2075>9P80L4dU0P1_C2@2
06i;8`@0LDhV0100Le0X07EB:P1hEBd0NUL_075@;`1`Cbh0Kdh]06i=;01]C2/0KTd/071?;P1aD2l0
Le0Z06m<9P1[B280K4TS0P1`CBL03P1cD2X0LTlY071=9`1eCbP0Me4Z07YD;@1lERl0NeD^07QB:`1d
CRL0LT`U079@:`1aCbX0L4hY0P1_CBP00`1`CRT0LDlZ079@:`0206m99@03071:9P1aBbL0LT`X00<0
LT`X0100LdhQ07=>8P1dCb<0M4lU07==9P1bC2L0KdTU06i8901]B2/0K4LZ06Y5:01YA2L0JTDX06a7
:P1_BRd0LTd`201bDR/207QE;@80Me@/00H0MU<[07EB:P1eDRX0M54Y07EB:01fDbT307MD:P0507EB
:01cD2H0LDhT07QE;@1gE2`00`1fDb/00`1hEBd0NEH^07]H<00807]H;PP0O5T_00<0OeX]085L;`23
GS400P24Gc804`23GS40PE`_07mJ;@1nFBl0OeX`081K<@21G380Pehd08EP=P26HCL0Qf8h08AN=`25
H3H0QV4g08MR=P26HC@0QF4a08=O;@22GR`00P24HB/04@24H2h0Q60`08AO<`24GSL0Q5hi08AN>P1n
HcP0Of8f081Q=@22H3<0QV0c08aQ=02?Hc@0Tf@f08UU=@2:ISH0RfLg0080S6Ph00l0RVHf08QT=026
HS80Qf4b08QR<`29Hc@0RfDf08eW>02?JCX0T6Xk095[?029IC40RfLc08iZ=P2@K3P00`2BKSX03P2A
KCT0T6`h095]?@2DL400Ug=309YfAP2KMdL0VGE509Ib@P2CKcl0Ug8n09E`?02BKCT0T6/g0P2>JCD0
102?JSH0T6/g08MS<`27Hc<208IR<P<0QF4a00H0Q60`08AO=@22GC<0OeX`07eH;P1kER`307YE:`06
07EF9`1dEBL0Le@V079C9`1`D2L0KdlX0P1^CRP02@1dD300Ldl]079>;01aCBT0LDhX079?9`1cD2H0
ME8X07QK<`0207UI<P0E07YH<P1mFS@0PU`g08IN>P28H3`0Q5hg08IQ=`29I3X0S6Lk08eX>`2=JCT0
SFTg08aX=P2CKST0U6lj09Ia?02HLch0VWE009eh@`2NND@0WgY500<0WgY600<0WWU509ehA02MN4@0
0P2LMd<809iiA@80XGa70P2RODP0102SOTT0Y7m:0:AoBP2UP4/20:=nB@<0YH1;00<0Xgi90:5lA`2P
NdH00P2QNdh01P2PNTd0WWQ;09egBP2LMTT0VgE809YdA`80WGU500<0WWY609mkA`2PO4P00P2QODT0
1@2ROTX0X7e709ikA@2LND<0VgQ20080VWM100<0VgQ209ai@`2KMDP00`2KMDP409YdA`0809Mc?`2J
MT80Wg]70:=oB`2TP4`0XWi:09ijAP2KMd<209Ye@@80VGA0102HLcl00`2GLSh0VG@o09Ud?`0609Ud
?`0409Ye@02KMT40VgI109ag@P80WGQ30P2NND@02`2IMSh0VWLo09]h@P2KMd<0VWI409QdA02ELD40
Tfi109]f@P2LMd<0WGQ40080WWU500h0WGQ409ag@`2KMT80UW<k09Eb>P2DLC/0Tflk09=_?@2ELD40
UW9209QcAP2GLd<0V7A409YfAP80VgM700<0VWI609QdA02GLd<00P2HLcl209Mb?P0709Ia?@2EL3`0
U6lk09A_>`2BKSh0Tflo09A`@00209Ea@@0709=_?`2AKCd0Sf/k08eX<`2?JSD0TVdh09E`>`0209Mb
?@80UW4l0`2BK3d[ooooo`00:_ooool01P2LND<0WWU409iiA02PN4@0XWU50:=hA@80YWQ6202PMD80
2@2NLdP0WW=609mdA`2OMDD0X7I40:1g@`2PMd40XGQ20:1d@`020:5eA0050:9fA@2TN4L0YGU80:Ei
B02VNTT0202VNdP20:=gAP030:AhA`2UNDP0YWY90080Yg]:00@0Z7a;0:ImA`2VODL0YWe70`2WOTP2
0:QoB@80XGa80P2RODT0102SOTX0Y7m;0:AoB`2TOd/20:IlBP040:EkB@2TNTP0XgU70:=iA`80XWQ6
0P2OMD<01@2NM480WG=109ab@02LLT00Vg4o0080VW0n0P2CKCh00`2BK3d0TF/l091Z>`0208mY>P03
08iX>@29Hc`0RF<l0080RF<l00X0Qf4j08AN=`21Fc@0OeTb07iL;P1nG2l0OE/^07eJ<01lFC40O5Tc
0P1kEc<207MG<00407IF;`1eEBh0M5@]07=C;080LU8[00H0MED^07AD;@1cDb`0LU8[075A:P1`D2T2
06m?:080K4h/0`1]Cbd06@1/CR`0Jdd[06]=:`1cCb/0M50/07EB;01gE2`0NEH/07YH:`1lFRd0OE/]
07eL<`1mG340Oe`b089M<@24Gc80QV0a08UQ<02:HS40RV@e08]U=P2<ISL0SVPi091Z>`2AJc`00P2C
KCh0102EKd00Tfdn095[?02@JS/208mY>P80TF/l202EJcT00`2EISX0UVLk09IW>`0209MX?080V6Tm
00<0VFXn095[?02AJc`00`2@JS/308mY>PP0S6Hg00D0SfTj08iX>@2>J3T0SFLh08]U=P0208YT=@03
08US=02;ICH0RfDf00H0RfDf202@ICX0202FICX0U6Di09=T>02?HcH0SV<f08mV>02>J3T0SfTj0P2=
J3@308iY=@@0SfXf102@JS/408mY>PP0TfPk00H0TfLj099W>P2AIST0T6Li08eW>02;IcL208QV=P80
Sf@g0P2>HcH308eR=@0408aQ=029Hc@0RF<d08US=0<0R68c0P27HC8808MR=@80QV4d0`27HSD308QS
=P80RFDe102:ISH208]W=`0808m[>`2>JSX0S6Ph08]W=`2:ISH0RfLg08aX>02=JCT308aX>00308eY
>@2>JSX0Sf/k0080T6`l202>K3`0:02:JT<0RVY108Y[?`2:Jcd0RV`j08Y/>02:K3H0RVde08e]?P29
JCX0Pf@e081T=020ISD0OFHd07UR<01dGR`0L5T_06eH;@1ZE2d0HdlZ05e::@1GARP0DT<V05109P19
>b00BS`Q04Lk8@15>b80@CTR03dg8@0j=1h0=c8N03Tb7`0g<1h0=2lL030]700^;1d0;2dO02d]8@0]
;b8202T[8080:2XO00@09bTN02HX7@0U9a`09BLL200Q91/302<V6`8092LL100U:1d202<V7@808RDL
00D08B@K020S6P0O8QT07b8I024S6002028T6@0302<U6P0T9Q/09BLL00809RPM01h092DM02HV7P0W
9ad0:bTM02hZ7P0b;1h0=2`O03D^7P0c;QX0=S0J03Tc7@0m=Ah0@CLN04<g7@15=a`0A3HK044e6`12
=Q`0@SPO03lh7P0k=Ad0=S4K02h/5`0[:A@0<BPI03<Z6`0f;A`0>C4N03/c800l=1l203`d7@0603da
8@0j<B00>C0O03L`7P0e<1d0<RlL0P0`;a/202d^800302`]7`0[;1h0:R/M0080:BXL00<0:2TK02DV
7P0U9Qh00P0T9Ad202<T70808R<K0`0Q8QX00`0R8a/08b@L02<T700202@U7@80820N0P0O7ad201hN
70807AdK02007AdM01hN700N7aX0824I02@T600X:AT0;RdK030_6`17=Ad0BcXP054m8P1?>Qd0CSLH
05@m6`1SBbT0L5Pd08MX>@2DMT@0UgU7095c?`2FN4@0WX=>091d@P1dFRL0Ad4e03/g:`0]:al092@J
024T6`0R9b008RTQ020Z8P808B<P0P0R924202<U8P8092HS200V9b403@0S9bH08RHU02<U8P0T9B00
9BHP02PW8P0]:R<0;R/T034Z800c;280=S0T03Xd9P0l=RH00P0m>2D203`g8`0603`j9@0j=b@0>3DR
03Db8@0d<B80<blS0P0d<2D403Pb9P0G03Xd:00l=RX0?cT]040j;P0k>RH0?3TV03`j9@0n>B<0@C/S
04Dn9019?bH0Bd4V04a39P1=@RH0DD<X05A4:P1HA2/0FdD]05m7;`1PARl0GDHW05a59P1KA2D00P1I
@R<04@1J@b@0G4DV05e69`1PBB00HDTS069<9@1SCBP0HTh[061=;01MCB`0G4`[0593;01CA2d0E4@[
05I5:`1FABT0FDHX0080FdHW00T0GTDW05i7:01OB2T0GTTZ05a9:@1IBBP0ETLV05E69@1F@2T00P1G
?bL01@1H?RD0FSlT05m19@1R@bH0I4DX0080FD0Z00h0Fd<[05a4:P1NARX0H4TZ069;;01RBb/0IThX
06M?:@1XD2X0Je<]06eE;`1_Ec40LETc079J=080Kedg01`0Ke`d075K<P1dGC<0N5lf07YR=P1nHcP0
OfLg08=X>@26JSX0S6hj099a?02GM3`0VgLm09ig?P2XQDD0Y81209Ui@02;L3/0OFDe079M<P1WEBl0
HU8^06UB:@1XD2X0I4hW069<9`1OBbP0Gd`[0P1NCRd0801SCS40HTd`05m<;P1JBb`0F4/[05E<:`1D
CR`0EDl]061;;01PCBd0H50_061A<01NE340G5@`05UC;`1GDbh0GT`d061<<`1QCS00I50[06]F:`1b
G2/0NF8/07aV;@1iK3D0OFhg089_=`22K3<0PVP_08MW;P2@Jc@0UG4g0P2JNBX0=02NOBh0Xh<h0:N9
@02ZSDL0ZXm<0:V=CP2VSDd0XHiC09j;D02JQdd0Th9<08imB@29NDP0QWE708EdAP28LDl0Pf]707mV
?@24ICL0RfXg09=^=`2GKc80Ufh`09Q_;`2KLS80WWHh0:9j?@2RNd00X7a209ej@P2LND40SgQ608ig
A@2<MD<0R74o08E^?021JSP0OfPf07eV=023Hc@0PV8c08=Q<@25HC40QV8`08UT<02>IS80SfLc095/
=@2CKSL0UW8h09Yf>P2LN3X209ik>`0309ik>@2ELCd0U70l00<0TVhj01<0Tflk09A`?02FLSh0WW@h
0:5g>`2VNSd0ZWhm0:f0?@2^PS/0[h0h0:io=`2^Q3X0Zh4g0:Uo=`2ZOcX0[H8n0:b1?@2VNST0XGDd
0080Z7Lm00@0ZGPm0:]k>`2/O3X0[Ghh0P2^OcL20;B3?P0/0;62?02_Pc`0[X@l0:j6?P2_RD00/8Y1
0:N5>`2WQCd0ZXDo0:^4@@2[PT@0Zgi30:YmA02ZNdD0[HM60:Z4@`2UOch0XG/j09mi>02PNST0XG/j
0:=m?02PNCP0XGXi0:9k>P2SO3/0Y7dl0:En?@2VOch0Yh0o0:Qm>@2YOC`0ZWhm0:Yn?`2XO3d0YWXm
0:Ah>`2SMcX0WgPe09ig=02MMS<0W7Db09Yc<02ILRl209M`;@0809A`=P2AKC<0Sf/a095]<`2CKcD0
TVhd08eY;`28I2X808MS;`0708=O:`21H2/0PF0[085P:`21HR`0P68/07iS;00207iU;@0307eW;@1n
J2h0P6X`0080P6X`00<0OfT_07eW;@1lIR`00`22I382085S<@<0P68`00H0Q60^081N;P1nG2`0NETZ
07IG:@1bEBT2071E:P0@07=K:`1dG2`0Mf0^07YS;`1mIS00P6Xa089/<`23KC<0RVL_08=S:P1oGRP0
Of0Z08=U<@25JCL0QF/h08=Y>0P0Q6D_00<0P6Hc07mU<P1mHc000P1lHRl02`1mHc00OfDb081V<`26
Jc@0Qf`e08Q]=P2:KcP0Rg0i08eb>`2>Lc`0Sg@m00P0Rg0i2029LC<01P25JcP0Q6Xg08AZ=`23JCH0
PVPe085W=080P6Hc0`20I38207mS<@<0OV8`0380NF<a07UR;P1hHBd0O6<]089W<02<KcL0UGHm09Yk
@P2LP500WX9B0:>7E`2[Sed0/9EP0:nDG`2WS5L0X8E>09El@`2;LSX0P6L_07QO:@1fG2T0ME/Z079G
:01_E2D0JEH[06EB9`1QCR@0HTlW06A@:`1TD2d0HDdZ05e9:01MBbL0FTPT05I38P1B?al0D3dO054m
8P1B?R<0E40W04Tl7016>ad0ACXL04<j7@0o>1`0?CLM03/g7P0j=Qd0?c@N03db7080>C4L00d0>C8O
03Td800d<Ah0;BXI02DT4P0O8AH07R0E01/N5@0G71D05A`E01DK5`0D7AP05AhK00806Q`I0P0I6aP2
01PJ5`805aTF400G6AP801PH60P05ALF200F61L801PH60P05aTF200I6aP401TI5`806QXH0P0K6aT8
01/L5PP07A`G0P0M81L04@0N7aL07alG028O600S7QP091lI02HO6@0X9A`09b@K02PT6`0Z8a/0:b8K
02hS7@0a9R00=2LQ02h[700]:Q/0:bPI0080:RLH00<0:bPI02`Y6P0]:Q/00`0`9QX2034W6`03038X
700c:Ad0<bTM00<0<RHJ0P0c9a/303@X7080<RTP00@0<BPO030W7P0`9ah0<2LN0`0_9Qd0200_9A`0
;R@K02hT6`0^91/0;bDL034W7P0c:B00=2XQ200b:1`0100c9aL0=RXJ03L[6`0e:AT2038V5P0803HZ
6P0k;al0?RdK03h]6`0o;Q`0@2lM044`7P12<Al204<b8080@c<J0P14=1/304De700304Hf7@12<b00
@S<P0080@C8O00D0@34N03l`7@0o<1d0?RlL03/e7`0203`d7`0303db7P0n<Ah0@34N0080@C0N0P11
<Qd2048c7P0404<d7`14=B00A3DP04@e80<0AcLN0`18>1l204Ti800@04/f6@1<=aX0D3PL05<i7P1E
>Ql0EcTO05Hh7P1F=Qd0DSlO05=0801E@240F44R05Y18`1L@B@0GD8U05m19@<0G3lO00<0GD0P05i1
8@1O@R800P1P@b<0401P@B80HT<T06I7:01YBR/0Jd`]06Y;;01YBR/0J4TZ06=;:@1UBbX0IT`[06Y=
;@1]CRl0LE0a07=@<P1dDC<406m?:0@0L50Y0P1bCbL2075>9P@0L4dU0180Le0X079?9`1aCRH0LDhV
079?9`1dDBT0MU<[07QE;@1cDRl0LE0]071?;01^CBX0KD`Y06i=:P1_CR/0L4l/07=@:P1_C2H206a9
8`80L4dW0P1cD2X0301aCRP0M4hW07I@:@1iDb`0NeD^07YD;@1gDBX0M4hW075;901bD2/0LDlZ071>
:@80KddX00<0L4hY075?:P1bD2/00P1`BRH2075;9`0<079<:01cCBT0LddY07==:@1dCb80M4lS07E@
901eD2H0M4hW079<9`1`BRH0KdTU0P1]B2/01P1/AbX0JdHY06a7:P1]B2/0KTT/06m:;@80LE4Z0P1b
DR/207=C;080M5@]00<0NEH^07QE;@1hEBd00P1gE2`207IC:`0307EB:P1fDbT0Me@Z0080N5D[00`0
Me@Z07IC:@1dDBL0LTlU07UF;P1hEBd0Me@/07IC:`1gE2`0N5D]07YG;`1kF30807aI;`P0NeP^00<0
OeX]081K;P22GC000P23GS402@22GC00P5/^07mJ;@1nFBl0OeX`081K<@21G380Pehd08EP=P0208IQ
=`0P08AN=`25H3H0QV4g08MR=P27HSD0QF4a08AP;P23Gbd0Q64[08AP;024H2h0Q60`08AO<`24GcD0
Q5hg08AN>@1oHSP0P64e085P=@22H3<0QV0c08YQ<`2=Hc<0T6@e08UU=@2:ISH0RfLg08aX>02;IcL0
RVHf08QT=027Hc<208US=00:08YT=@2<ISL0SFLh08iX>@2?JCX0T6Xk08YV<P2;Ic<0SVXf091/>0<0
TVhj0P2AKCT00`2AKCd0U71009Mc@`0209YfAP0709QdA02FLT80U71009Mb?P2FLCd0Tfhj091[=`03
08mZ=P03091[=`29ICD0R6@d0080R6@d0P27Hc<208IR<P0508EP=P23GS@0P5/a07iI;`1lEbd00`1k
ER`04@1eERL0M5DW07=D9P1bDbL0L50W06m?:01^CRP0KDdW07=?;`1cCbd0LTh/075=:@1bCbT0Le0X
07EB:01fDbT0MeXb0080N5Pa01D0NUPb07eJ=022G3L0QUhj08MO>`24GSL0QV4g08QS>@2;ISX0S6Lj
08eY>@2<J3H0RfLe09=^>@2DKcX0UG0k09Mb?@2JMD00W7M209iiA02ONTD01P2ONTH209iiA@P0WgY6
0`2RODP00`2SOTT0Y7m:0:AoBP020:F0B`090:9mB02SOTT0Y7m:0:F0B`2TOdX0Xgi90:5lA`2PNdH0
XG]<0080X7Y;00H0WgU:09ihB@2MMdP0WGM809afA`2MNDD209ijAP0309mkA`2PO4P0XGe90080XWi:
00<0XGi80:1mA`2NNdD00`2LND<00`2MNT@0WW]509egB00209egB0<0W7I70P2KMDH0202IMD40VgM3
09ijAP2PO4P0XGe909mkA`2MNDD0VgM30P2JMD4209Ud@0D0V7<o202IM3l309]f@@0309ag@P2MN4<0
WGQ30080WWU400/0VGHn09Yg?`2KN480W7Q409]gA@2JMTH0V7A409IaA02KMT80W7M309iiA@0209mj
AP0>09iiA@2LMd<0VgI209Md?02FLc/0UG8l09A`?02DL3h0UG5109Mc@`2HLdH0V7A409UeA@2JMTH2
09]gA`0409YfAP2IMDD0V7A409Ud@080V7<o00<0Ug8n09Ia?@2EL3`00P2DKc/00`2BKSh0Tflo09Ea
@@0209Ea@@0709=_?`2AKCd0T6`l08mZ=@2AK3L0Tfhi09E`>`0209Ia?080UG0k0`2BK3d[ooooo`00
:_ooool01P2LND<0WGQ309eh@`2PN4@0XGQ40:=hA@80YGM5202QMT<01P2OM4T0WgA709mdA`2PMTH0
X7I40:5hA080XGQ20P2QMD@00`2RMTD0XgM60:AhA`020:EiB0030:IjB@2UNTL0YGY700H0YGY70P2S
MdH00`2TN4L0YGU80:IjB@020:MkBP040:QlB`2VODT0YWe90:ImB@<0Ygi:0P2XOd/30:9mB@80Xgi:
0`2TOd/00`2SNDL0XWQ60:9hAP050:9hAP0409id@P2MLd40WG=109ab@080Vg4o00<0VW0n09U_?@2I
Kcd00P2DKSl01`2BK3d0TF/l08mY>P2=IcP0S6Hg08]U=P27HCX00`28HS/03027HCX0QElh08=M=P22
G3D0P5h`07mM<01nG2l0OEX`07aI<@1kF380NUHb07UE<@80MeL`00<0MUH_07EE;P1dE2d00P1cDb`0
1P1bDR/0M5@]07AD;@1cDb`0LU8[075A:P80L50Y01h0KdlX06a>;01]Cbd0KU0^06mA;`1^D2h0K4h/
06U;:@1WBBL0Ldl[07A@;01eDR`0Me@/07UF;01kFB`0O5X]07eK;@1oGSD0Oehc085N=025H3@0QV4d
08QR<`2;Hc80S6@c08aV=`2=IcP0SVPi08mY>P2@JS/2095[?005099/?@2DKSl0Tfdn099/?@2AJc`0
0P2@JS/00`2AJc`0TV`m09I/>P0709I/>P<0U6Pk0P2EJC`309IZ?@80TF/l0`2@JS/308mY>P80SVPi
00@0SFLh08aV=`2<ISL0RfDf0P2:I3D208iX>@0408eW>02<ISL0S6Hg08]U=P80RV@e0`2=IcP00`2<
ISL0RfDf08YT=@0208US=0<0SV<h00<0Sf@i091U>P2AIS/00P2BIc`0202EISX0U6Di095U>02>HcH0
SF@f08eW>02>J3T0SVXj0P2?JSH308iY=@@0SFPd202?JCX8099W>P0809=W>P2BIcX0TFHi08mV>02<
ISL0RVHf08QV=P27ICD308iS=P80SF8e0`2<HC@308US=0<0R68c0P27HC8808MR=@80QV4d0`27HSD3
08QS=P80RFDe0P2:ISH308]W=`0308aX>02=JCT0S6Ph00<0RfLg00<0S6Ph08iZ>P2>JSX0202>JSX8
08aZ>P0608YZ@@2:Jcl0RV/o08Y[?@2:Jc`0RV`j0P2:K3P0402>KSl0RFTj08AU=P20I3@0OfDd07aU
<`1gH2h0LE/Y06mH;P1/Eb`0JE</06=?:P1MBRT0ETDW05939P1@@2H204Xl8@0>04Lk8@15>b80@CTR
03`f800i<ad0=S4M03Pa7P0g<1h0=2lL030]700^;1d0;2dO02`/800/;R4202T[800302PZ7`0W:Ah0
9RPM00809BLL00<092HK028U700R9A`01P0R9A`202<V6`8092LL100U:1d00`0V:Ah08RDL024T6`06
024T6`808R@I00@08bDJ02@V6`0U9a`09BLL0P0V:1d01P0U9Qh09bLM02PX7P0/:Qh0;b/O038/7P80
=BhN00H0=2lK03La6`0i<ad0?CDN044g7P13=ad204Dg700A044e6`11=Ad0@CLN03de7P0i<ad0=2lK
02h[600/:AH0<RTJ03@[700g;Qd0>C4N03/c800l=1l0?3@M03/c700l<2000P0i<1l00`0g<1h0=C0M
038_7002030_6`80;BhP00<0;2dO02//7P0Z:ad00P0Y:Q`00`0X:A/09BHN02DV7P0202@U7@808b@L
0P0R8a/2024R6P<08R<K0`0S91`2020P7P807alM0P0N7Q`201dM6`807AlL01h07b0J02<S6@0X9QX0
;BXK034^6`0f<Ah0BSPP04hj8P1>>Ql0CCPK04lh601K@al0KU@_07eT?02=LD40Vge;09]kB02BLSl0
V7Y809j4D`20JCd0ED0E03/g:`0c<BD0:2PL02@T6P0S9Qd09BPQ028W8@0P9b02024S80808R@Q0P0S
9B8202@V8`P09RLQ00d09BTX02@Y9@0U9b@09RLR02HW8@0Y:B40;BXQ02h[8P0c;280=BhT03La9@0i
<bD0>cDU0080?3LT0P0l=b<01P0k>B@0>SLT03Ld8@0e<R40<c0Q03<_8`80=30U0P0h<RH203La9@04
03Tc9`0k=BT0?SP/03li;@80?S/X0140@3/W048l9P15?BH0BT0W04i2:P1?@bT0CT<W0553:01C@bT0
E4@Z05Q4:`1IAB`0FdD]05i6;P1K@bL0FT8V05U19@0205Q0900;05U19@1J@RH0Fd<W069:901RC2D0
HddX069>:`1QCRd0GTh]05]<:`1JBb`00P1B@b`0101C@bX0E4<Y05A39`1F@bD205Q3900X05a39@1L
ABH0GDHW05a7:01JAbL0EdLV05A5901CA2<0DS`U054k8`1C>b<0E3XQ05Hk801K?B40GD0R0611901I
@2X0FT8Z05]3:`1MAB/0GdL[065::`1RBb/0Hd`/06I>:01WCbT0J50Z06]C;@1]EBl0KeLa075I<`1b
FS@0Ke/f06mL=01bG3D0M5dd07MN=@1lHCH0OV<f085T>080QV/l03H0Qf/k08Y/>P2=KCX0T6lj099a
?02FLcd0WGY009If?@2:K3H0OV8b071I;@1XDR/0H4hZ05a<:P1XD2X0IDlX06A>:@1PC2T0GT/Z05a<
:`1KC2/0G4d^069?<@1QCS00G4/]05U::`1GBRX0EDXZ05A;:P1EC2/0Gd`/061=;@1PD2l0HE8a061C
<@1MDc00Fe<_05YB;P1NCC<0HThc06EB<P1ZES40L5/`07EO;P1iHRh0Nf@^07a_>P1oL3T0PFdh07mZ
<`20IBh0Q6L_08a/<`2DLCT209If:`0W09Ul<02OPCT0Y8M30:J;B02RRDT0WXI:09^3A`2HQDd0UX=;
095mB02=NDH0RGE308QcA027LT<0R7=608Y`B`26KDD0QVTo08UY>P2@K3P0U6lh09Q`<`2IL380WGD]
09ih<@2PNCH0XG/m09mj@`2KMd<0UWA409=a@`2;LD00RFln08M]?025JcX0PVPg081V=@1oIC@0OV@c
0080P5lb00/0P5h`089N;P23Gbd0Qf8^08aT<@2>IS80T6`b099^=02ELCD0V7@f09Yg=`0209]h=P03
09Yg<`2GLS/0UW4j00<0UG0i01T0Ug8k09Ud?@2JMCh0XGDf0:Ei>P2ZOSd0[hA00;>6@P2cQd00/HDn
0;24>`2aRSl0[hLo0:f5?@2]QCl0[XI10:f4@P2YP400YWdm0:Uk@02ZO400Zge10:eo@@2_PT40/8=0
0080/XE100H0^8Q60;F8A@2dQd@0/XM30;28@`2`RD@20;2;A@060:V8@@2YQd00Z8E10:V3@P2YPD<0
Zh550P2^PDP0202_S4`0[8U90:N4A02SP400X7dm09ml?02POCd0XGhn0P2RNS`0202SNcd0Y7`n0:In
@02XP480ZX940:^3A@2YP400ZX510P2[PT802P2ZPD<0Z7m10:Im?`2TNcd0XW/h0:5j=`2PNCH0WgPe
09ig=02LMC8209]d<@0909Ue>@2FLSH0U70d09Ea=@2GLcL0UW8f095]<@2<J2`0SV/e0080SFXd00<0
S6Tc08]X<P2:Ic400P29IS001`25HBd0Pf8]08=R;@23HRd0PV<]085S;@1nHb`00P1mI2`00`1oIRd0
P6L^085X;`02089Y<004085X;`20Ibh0P6L^089T<P<0PF<a0P20HS0207mQ;`0H08AP;P22HBh0PEl_
07mO<01lGBl0MeX^07=H:`1aER/0MU//07ML;@1iGbh0Nf4^07iU;`21J300PfXb08A[<P2=JS80QfL^
085P:P1oH2X0P68^089V=023JCH0PfTh2024IS000`20IS<0OfDb07iT<@0207eS<00907iT<@1oIC80
P6Hc08M/=@28KCH0RFhg08]`>@2<LCX0SG8k0080SW<l202;L3T808Q`=00608I/>@25JcP0QF/h08AZ
=`23JCH0PVPe0P21Ic@3085U<`80P6@b0`1oHc40<P1jI380NV<_07QQ;@1lHbd0PFH_08]^=P2DMC`0
VGY109b0CP2MPDl0XXID0:Z>G02aUF<0/YIT0:fAG`2XS5X0WXE<09ImA@2;LSX0PFPb07aR;`1iGbh0
MU//07=H:@1[ERT0Ie8W06=>8`1SCB@0IDlX06E?:P1RBbT0GTLU05i<9P1KBBD0F4HR05A1801B?al0
DSlQ05<o901D@2D0BC`L04Tk7P16>ad0@cXM040i7@0n>1h0?CLO03/g7P10=1h0?S8L0P0k<1`02P0j
<Ql0>c@Q03Lb7`0^:aX0:2DD024Q5`0P81H07AhF01XM5P0G71H201HL600301DN6`0J71T06Q`I0080
6A/H0P0H6QL201LI5Q0061XI200H61P801DG5PP05aTH200H61P801LI5PP06A/H0`0I6AL201XJ60<0
6a/I200K71H801hM60807B0G00<07QlG020P600R7aP00P0T7aT0300V7aT0:2DL02LT6`0W8aX0:B8J
02/R6`0^8ad0<2DO03@W8@0`:Q`0;bTK02hX6P80;BLI00<0;RPJ02lY6`0`:Q`00P0a9a/3038X70<0
<bTM0`0c9a/203@X70<0=BTM0`0c:Al4038X7P80<BLM00<0<bTO038X7P0`9Q`00P0_9A/00`0`9Q`0
<RPN03<Y7`08038X700403<W5`0f:QX0=b/K03DY6@80<RHF00<0=b/K03/_7`0n;A/00P0o;Q`01@10
;ad0@C0N048a7`12<Al0@c8P00<0A3@K0P15=A`304Hf7@80ASDS00H0AC@R04<b8012<Al0@C0N040_
7@0o;Q`203de800303ld8010<b00@S<P0080@c8P00<0A34P04@d7@14=1d00P14=1d204De7P80ASHO
0`17=Ad204Pf7P<0BCLO00P0C3LJ04dh6`1A>Ad0DcTN05Dj7`1H>R00EcTO05Ph7`80ED0Q00H0F44R
05U08P1K@2<0GClS05i0901O@2@505i18@<0Gd8R00H0HT<T06=49@1TABH0IDHW06I7:01XBBX206U:
:`0806E=:@1VC2T0IddZ06Y=:`1/CR`0Kdh]071=;@1aCRh8071@:@80M54Y0P1cD2P3079?9`04075>
9P1eDRX0M54Y079?9`80LDhV00L0Le0X07AA:@1eDRX0ME@a07=B;`1aD2d0Kdh[0080KD`Y0P1^CBX0
101dDB/0L4dW06a98`1]BR@2075>:00607AA:`1cD2X0LDhX07==9P1eCbP0Me4Z0P1hDR/01P1fD2T0
LddV075;901dDB/0Le0Z079?:@80LDhX00<0LTlY07=@:P1dDB/0101bC2L207==:00307A>:@1eCbX0
ME0S0080MU4U00D0Me8X07I@:@1dCRT0LD/W071:9P0206i::P<0Kd/[00/0KTXZ06e9:@1/B2P0L50Y
075A:P1bDR/0Le</07AD;@1eEBh0MUH_07MG<00307UF;P80N5D]0`1gE2`207MD:P<0NEH/00/0Me@Z
07IC:@1dDBL0NUL_07UF;P1hEBd0Me@/07QE;@1iERh0NeP`07aI<@0807aI;`P0NUL]00<0OeX]081K
;P21G2l00`21G2l04P20Fbh0OeX]07mJ<01oFS00P5/a089M<`23GS@0Q5le08EP=P26HCL0Pedf08AO
=@26HCL0Qf8f08MR=@26HS80QF4_08AP;P80QF4_00<0QF4a08EP<`25H3@00P25H3H02@25GcP0PF4h
085P=@21GS@0PElb08EO<P27HC80Rf<b08eS<`0208YV=P<0RfLg00<0RVHf08QT=027Hc<00P2;ICH2
08aV=`80SFLh0P2>J3T0102;Ic<0S6Pd08iZ=P2@K3P5099^>P0=099^?P2DL400Ug=309UeA@2JMTH0
V7A409Ib@P2DL400V7<o09Ia?@2DKc/0TVdi095/>003091[=`<0RfLg0`2:ISH208UU=@0408MR>025
H3H0PUdc07mJ<0@0OEP^00T0M5DV07AE9`1cE2H0LE8V071@9`1_CbP0KThX06e=9`1cCbl00P1bCR`0
4`1bCRX0Le0Z07EB:P1hEB/0NEH/07EH;P1gEbh0N5P_07YI<01mFS80PE/d08EN=`26GcP0Q5hg08EP
=P27HSP0RF@h08]V>@2;IcL00P2;IcD0202BKCP0Tfhi09E`>`2GLSd0VG@o09ag@P2MN4<0WWU40P2N
NDD00`2ONTH0X7]70:5lB0020:9mB@030:=nBP2QO4P0XGa800H0XGa80`2TOdX30:F0B`80YX5<00P0
XWe80:=nB@2TOdX0YH1;0:AoBP2SOTT0XGa70:1kAPL0X7Y;00H0WgU:09mkA`2ONdL0X7a80:5mB@2R
OTX20:=oB`040:B0C02TPD/0XWm90:5nB0<0Wga60P2QOTP20:1jB`80WgU:0`2NN4T00`2MMdP0WGU5
09eiA@0309ahA0<0VgM30`2JMD4209Ud@0@0V7<o202IM3l209]f@@<0W7M20`2MN4<209Yg?`0909ai
@`2MNDD0WGU709eiB@2LN4P0W7M:09ag@`2MN4@0WgY60080X7]700h0WgY609ehA02LMd<0VGHn09Qe
?@2FLcd0UG4m09Ea?`2FLT80Ug=309QcAP2IMDD0VWI609]gA`80W7Q800@0VgM709YfAP2IMDD0VWE1
0P2IM4000`2HLcl0Ug8n09Ia?@0209E`?00;09A`@02ELD40UG5109Ib@P2ELD40U71009=_?`2BKSh0
Tfhi09A_>P2EL3/00P2FLC`00`2EL3/0U6lj09=^>@0309=]?R_ooooo000Zooooo`0609ai@`2MN4<0
WGQ30:1hA02QN4@0XWM40P2UMdD80:5f@`0609mdB@2OM4L0X7E80:1fAP2PMT@0XGQ40P2QN4820:9f
A@80XgM600@0Y7Q70:EiB02UNDP0YGU8202SN4D20:=gAP030:AhA`2UNDP0YWY90080Yg]:00@0Z7a;
0:IlBP2VO4X0YWa:0`2WOD/20:QnC0@0Xgi:102TOd/20:1fA0<0XGM50`2RN4H209ec@@0409ab@02K
LCl0VW0n09Y`?P80VFlm00T0V6hl09I`@@2EKd00Tfdn091Z>`2>J3T0RfDf08US=028HS<01027HCX0
3@26H3T0QElh08EO>024GSL0PEla081N<@1oGC00OEX`07aI<@1jEc40NEDa07QD<01hF3400P1gEc00
0`1fERl0MED^07AD;@0507=C;003079B:`1aDBX0LE4Z0080L50Y00P0Jdd[06e?;@1_DBl0L58`06mA
;`1/CR`0J4XX06I89P80M50/00h0MU<]07QE;@1iER`0NeT/07eK;P1mFbd0PF0g085P=@23H3H0Qf8f
08QS=P2:I3D0SFDd08iV=@80SVPi0P2?JCX2091Z>`80TF/l0P2CKCh2099/?@04095[?02BK3d0TV`m
099/?@P0UV`j202DJC`2095[?0<0T6Xk1@2?JCX0102>J3T0SFLh08]U=P2:I3D208US=00308iX>@2=
IcP0SFLh0080S6Hg0P2;ICH02@2:I3D0SfTj08mY>P2>J3T0S6Hg08]U=P2:I3D0RF<d08QR<`0208aQ
=P0?08eR=`2?I3T0T6Dj095V>`2BIc`0TfPm09=W>P2BIST0T6Dh08eT=P2;ICH0S6Ph08eY>@2<JSX0
T6/g0080SfXf00<0SVTe08eX=02<Ic<00P2<Ic<0102;IS80SVPi08iX>@2>J3T408mY>P03091Z>`2B
IcX0TVLj00H0TVLj00H0TfLj095V>@2AIST0SfHh08aV=`2:ISH208MU=@80SV<f0`2=HSD308aQ=0<0
RF<d0`28HS<208MQ<PP0Qf8e0P26HC@308MR=@<0R6<f0P29ICD208YV=P0508]W=`2<J3P0S6Ph08eY
>@2:ISH00`2;IcL01@2<J3P0SFTi08iZ>P2?Jc/0T6`l00<0Sf/k0`2>JSX00`2=JCT0RfTi08]Y>@06
08]Y>@<0RV/m0`2:Jc`208Y/>P0@08i^?`2:JS/0Q6Df07mS<`1nI3<0NV<a07EN;01_FBL0KUL]06]F
:`1XDR/0HDdX05a9:01FABL0DT<V05109P80BS`Q00l0Ac/Q04Dk8P10>240?3HP03Pb700e<1`0=RlL
03H_7@0d;a`0<BhM02l]7P0/;Al0;2`P02/]800Y:b000P0X:Ql00`0W:Ah09RPM02DW700202@V6`P0
8RDL0`0T9a`302DX7@<09RTN0P0P8aX3024T6`<08RDL0P0R91T0100S9AX092HK02DW700V:1d202LY
7P0602HX7@0W9a/0:BTM02d[7P0_;1d0<bdM0P0f;ad01P0f<Ad0>38L03Xd7P0l=1d0@3HM048f7080
ACLL0140@SHN044e7@0o=1h0>c<N03L`7@0c;Q/0;R/J02`Y600c:Q/0=B`M03L^7@0j<Ql0?3@Q03`d
7`0l=1d0>c<L03/_7`0203P_7P0503H_7@0e<1d0<RlL034`700`;a/00P0];R000`0/;Al0:b`N02X[
7@0202TZ700302PY6`0U9Qh09BHN008092DM0P0S91`8028S6`808b@L0P0P81h201lO7@807QhL0P0M
7A/0800L8A/07R0K024R6P0T91X0;2PL03</700i<Ah0>c<P04hi901?>B80CCPM04hg601D?1X0I4/S
07]P=@2;L4<0TWQ709UkB@2IN4<0VGE109emC02DO500KE/g03ha4@0_;b<0:RXP02HV700T9Ad09RLQ
02HX8`0S9B80828O0P0Q8b02028T8@808bDR0P0T9R<802HW8@0=02H[9`0U:R@09RPS02LX8P0X:B40
:RXP02h/800`;R80=RlU03L`9P0h<RH0>C<U03/e9@0203`g9080?3LS00H0>SPS03Tf8`0f<b00=34P
03<`8@0c;b<203@`9@0803Pb9P0g<BD0=c4U03La9@0h<RH0>S@X03`f:P0n>2`203lj9`07040i9P12
>RD0AS/U04Xn9P1=@BT0DD<Y05=3:@0205A4:P0805E4:P1FAB/0F4@[05Q4:`1IAB`0FTDZ05U4:@1H
@bP205M29`0;05U4:@1JABX0G4L/069<9`1SCBP0HTh[065>;@1OCbh0G4d^05U<;01HBRd00P1A@R/0
?P1B@RT0Dd8X05=29P1E@R@0ET4R05E08@1K@R@0FT<T05a59P1JABH0FDHV05E5901B@b80DD8Q054m
9@1@?2<0DC/S05<k8@1F?240FChQ05a18`1O@R@0FT8Z05]3:@1LA2X0GTHZ0619:P1RBb/0Hd`Z06A=
:`1VCRP0IdlY06Q@:P1[Dbd0KED_06mG<@1aFC<0LUXd071J<`1aFc80M5dd07MN=@1kH3D0OV<f085U
=P22ISL0QV/l08IZ>`23IcP0PFDf089S=024ICH0QVLh08MX>@20HRh0NUh/07=H:@1[DbL0Ie0W06E?
:P1UDC00IE8b0P1TCRT02P1QCBX0Gd`[05a<:`1JBb`0FD`/05Q:;@1OCS00G4d^05Y;;01HBBX305I9
:@0I05M::P1MCB`0Gdl^065A<01RDS40HU<b065B<@1PDC00Ge0_05i=;`1SD380J5Dd06iJ=@1dGc@0
N68c07UQ<@1iHS00NVXg07a[=`1nJSL0OFPc07aU;`22JC40S78i09Eh@00209Ah;`0S09Ul=P2NPch0
XHQ60:69B`2KQD/0UH17095lA@2=O4P0RWU508Qd@P25LCl0Q6hm08I^@027Kd40RG5308a_A`2=KD@0
SF`o08m]?@2CKc/0UG0i09Qa=P2ILC@0WgX/0:5k<02QO3H0Wg/m09ai@`2ELdD0T6m608e[A@25JcX0
Q6Xi085W=P1oIC@0101nI3<03P1nGC80OE`a07eK;P1nFB`0P5`/08EO;P2;Hc80SFDb095Z;`2CK340
UW0b09Uc=02JM3<0VgDd0P2KMS8209ee>080W7@g0280WGDh09mg>P2QNC`0Xg/n0:Mg=@2/O3X0/8<o
0;J9A@2hSDP0^8i60;>;@`2aRD40]8i50;>=AP2bS4D0/HY50;6:A`2_R4L0[HE70:b4AP2ZPD<0Zh94
0:b3A@2^QDD0/8M70;:9B@2cRTP0]8]90;V=CP2fSDd0]Ha<0;><B`2aRdX0[X]90P2]S4T03P2/SDX0
[8Y:0:Z8B02YQTH0ZhE70:j6B@2bR4`0]8Y>0;2>CP2]Rd/0ZHM70:F3@`2QOcl0X7hn0P2OOCd20:9l
?@080:=m?P2TOSl0YX110:R2@`2[QDH0[8I70:Z2A`2[PdP20:b4A`050:b4AP2ZPT@0Z8500:N0?`2U
OS/00P2TOCX05P2SO3T0XW/h0:1i=P2PNCH0WgPe0:1j?02MMcT0VgDg09af>02NN3X0WGLi09Qb=02C
KBl0TFhf091]=@2?K3@0SFXb08aY<@2:Ibl0RFH^08QU;@27Hbl208ET;`0408AS;P23I2h0PF<]07mT
;@80OF@/0P20Ibh00`21J2l0PVT`089Y<003089Y<080PV@`0P21Hbl4081R;P0H08EQ;@24Hbh0QF@a
08AT<`21HS<0Nel`07IK;01dFB`0MU//07ML;@1iGbh0Nf4^07eT;P1oIRh0P6L_085X;`2@KCD0RVXa
08AS;@1oH2X0OV0/07iR<020IS<0PVPg2022Ic000`21Ic@0OfDb07iT<@0207eS<00707iT<@1oIC80
PFLd08Q]=P29KSL0Rg0i08eb>`0408ic?0P0Rg0i2027KSD208M^>00408I]=`25K3H0Q6/e08=Z=080
PVTc0P22IS@3085U<`<0P6@b02H0NfDc07YS;`1iHRh0O6<]085V;`2:KCD0TW<j09Mh?`2KP4T0W85:
09n4C`2WS5L0/9AR0;BHJ02cUfL0/9AT0:F<D`2NQDd0U7]308U`>P20IS<0NV0_07IK;01dFBX0KELX
06UB9P1UCR80IDhT06I?9P1VCRP0HTXV05i68P1PCRH0GT`V05Y88P1GAB40E44P05A18@80E44S00X0
Bc`M04/l7`19>ah0ACXN04<i7P0o>1h0?SHO03dg7`13=1l0?c<M0P0m<1d03@0l<Al0?3@Q03Tb800b
;1`0;BLG02DR6@0S81L07alG01`M5`0I6aH05a`H01LM6@0G7A/00P0J71T201TK608061XG0P0G6AH@
01PJ6@P061PH200F61L801LI60P061PH200G6AH801TK60806ATG0P0J6QP201/K6@8071`J200L7AL8
01hM60807B0G00H07b0H020P600S81T091lI02DP6P0W81X202LT6`0>02LS6P0Y8QX0:b8K02hS7@0`
9Al0<bHP034Y700`:1/0;bLJ02hV6@0_9aX0<2PK038Z7@0c:ah403<Z6`@0=2/L00@0=2PJ03DY6`0e
:A/0=BTK0P0f:Q`203L[7@D0=2XN100c:Ad0100f;200=B/O03<Y7@0a9a/2030V6P03034W6`0b:1`0
<RPL00L0<RPL00@0=2PH03HZ6P0h;1`0=RXJ0P0c9aL0100g:a/0?30P03l^700o;Q`2040_7@80@C0N
0P12<Al204@d6`<0ACDL0`16=Qd204Tg8`0404Pf8P16=200AC<O04<a7@80@S0L0P10=Al00`11=Al0
@c@O04Dd800204Hd800304Pc8017=Ad0AcDM00H0AcDM0P18=1`01019=Ad0BSHN04Xf7P1;=al204`h
8080CSTL00<0DCTM05<i7P1E>Ql00P1H>R001`1J>R40F44R05Q18P1I@280Fd0S05do8`1N@2@00P1O
@2@306138`<0Gd8R0P1N@B40401UARL0I4DV0693901R@b@0Hd@U06I7:01XBBX0JT//06I>:01WCBP0
J4hY06Y>:@1[CBT0KD`Y06i<:@1_CBX3079@:P@0LDlY00@0L4hX07EB:P1eDRX0ME8Z0P1dDBT307=@
:00307IC:`1eDRX0Le0X00<0LDhV00L0LTlW07=@:01gEc40MED_079B;01_CbT0KThX00<0KDdW00@0
M54[071=9`1/BB<0KDXT0P1aCRP01P1dDB/0Le0Z075>:01bC2D0LddV07E?:080MU0Y00H0MDlX07==
9P1aBb@0Me4Z07I@:@1eCbP207==9P0707E?:01fD2T0Me4Z07I@:@1eCbP0M4hW07==9P0207A>9`0H
07I@:@1gDBX0Me8U07MB9P1hDbL0N5<Y07MA:P1eCbX0LddY079<:01_BbT0L4`Z079>;01cCbd0LTh/
06m;:@1/B2H0JTHT071@:@1aDBX0LU8[07AD;@1fERl0MeL`0P1iFC8307YG;`D0NEH^00<0N5D[07UF
;01jEbd00P1kF2h02`1jEbd0N5D[07MD:P1kF300NUL_07UF;P1hEBd0NEH^07YG;`1lFC40OU/c00P0
OEX`201jEbd8081K;P0607mJ<020Fc40PE`b089M<`23GS@0Q5le0P25H3H02023GCH0Q5le08IQ=`27
HSH0R6<f08MS<`26HS00QF4_0P26HS8308IQ=0<0QV4e00P0Pf0h089O=@21GS@0Pehb08=N<@26H340
R68a08US<P<0RfLg0P2:ISH208UU=@0308QT=02=IcP0SFLh00H0SFLh00D0SFTe08iZ=P2?JcL0TFdi
099^>P0209=_>`80U70l00h0Tflo09A`@02FLT80V7A409UeA@2HM4@0UW9209Ea@@2HLcl0Ug8n09Ia
?@2DKc/0Tfhj099]>@80TF`h0`2>JSX208eY>@<0S6Ph00D0RF@j08MR>024GcD0PE`b081K<@0307mJ
<00607EF9`1eERP0M5DW079C9`1aDBP0KdlX0P1^CRP05P1cCbl0LTh/079>;01cCb/0ME8/07MD;01j
Ebd0O5T_07AG:`1gF2`0N5T]07YI;P1mFS00PE`b08AM=025GSD0QElh08EP=P27HSP0R6<g08YU>02;
IcL208aX=P0@099]>02CKST0UG0k09Mb?@2JMD00W7M209iiA02ONTD0WWU509mjAP2PNdL0XWe90:=n
BP2UP4`0YX5=0:N2CPP0Y7m;102VPD`40:N2C@090:=nB@2TOdX0YH1;0:J1C02UP4/0Y7m:0:9mB02P
NdH0X7Y900<0XG]:0`2RO4/01@2SOD`0XGe90:5mB@2ROTX0Xgm;0080Y81<0P2UPDd00`2VPdd0YH9<
0:>0BP020:9oB@030:>0BP2TPD/0YH9<0080Xge<00@0XWa;0:5kBP2QNdX0X7Y90P2ONDP0102PO4P0
WWY609]g@`2IMD4209Qd@00409Yf@P2KMd<0VgI209]f@P80VWE10P2IM40309Qc?`P0VG@o1P2LMd82
09eh@`0509Yg?`2KN400W7U309ijAP2ONdT00P2PO4`0102PNdh0WGQ409mjAP2PNdL20:5lB00>0:1k
A`2ONTH0WGQ409]h@02IMSh0V7Do09Ib?P2FLT00Ug=309QdA02IM4L0VWI609]gA`2MNDT209ijBP03
09eiB@2KMdL0VWI60080VWE10P2IM400102HLcl0Ug8n09Ia?@2FLCd509Ib@P0309Ea@@2DL400U710
00<0Ug8m0P2FLC`00`2EL3/0U6lj09=^>@0309=]?R_ooooo000Zooooo`0609]h@P2LMd80WGQ309mg
@`2PMd<0XWM40P2TMT@80:9gA0060:1eBP2PMDP0X7E80:5gA`2QMdD0XGQ40P2RND<00`2SMdH0Y7Q7
0:AhA`020:AhA`<0YGU8202SN4D20:=gAP030:AhA`2UNDP0YWY90080Yg]:00@0Z7a;0:IlC02VO4`0
YWa<0`2WODd20:QnCPP0Y7m;0P2PMT@30:5gA@<0XWQ600@0WWA209ec@@2MLd40W7900P2KLCl0302J
L3h0VFlm09U_?@2GLD80UW1109A^?`2AJc`0SVPi08]U=P29Hc@0R68c08QR>`80Qf4j00<0QV0i08EO
>025GcP00P25GcP02021Gc40P5ha07mM<01mFS00O5Ta07YG<@1iEC40N5@`0P1hF3400`1gEc00MUH_
07EE;P0207AD;@80Le</101bDR/3075A:P0H06]=:`1]Cbd0KU0^06mA;`1^D2h0K4h/06U;:@1XBRP0
M50/07EA;@1fDbd0N5D]07YG;@1lFRd0OE/^07iL;P22HCP0PV4f08AQ=`28HcL0RF@g08]U=P2>ISD0
SfLf0`2?JCX2091Z>`<0TF/l0`2BK3d409=]?P03099/?@2GKC/0Ufdk00H0Ufdk202CJS`2095[?0<0
T6Xk1@2?JCX0102>J3T0SFLh08]U=P2:I3D208US=080SFLh102<ISL208]U=P06091Z>`2?JCX0SVPi
08eW>02<ISL0RV@e0P29Hc@01P2;H3D0S64f08eR=`2>HcP0Sf@i095V>`80TVLl00P0TVLj095V>@2?
ISP0RfDf08YV=P2<J3P0RfTi08][>P80SfXf00<0SVTe08eX=02=J3@00P2<Ic<208]V<P<0SFLh00<0
SVPi08mY>P2?JCX00P2@JS/8095V>@08099V>@2AIST0T6Dh08iU=`2;ICH0RFDe08MU=@26I3@308eR
=@<0S64d0P2;H3<308US=0<0R68c0P27HC8808MR=@80QV4d0`27HSD308QS=P0608QT=029ICD0RVHf
08]W=`2<J3P0SFTi0P2>JSX208YV=P0308]W=`2<J3P0SFTi00<0SVXj0`2@K3`208m[>`<0SVXj202;
JCT208Y/>P<0RV/l0`2:Jcd0402=KCh0RFTj08=T=@1nHS80OF<b07UR<01dGB/0KUPV06aE:`1YE2T0
IU0Y061<9`1KB2L0ED@V05529@1@@2H204Xl8@0>04Lk8@15>b80@3PQ03/e7`0g<A/0=2lK03D^6`0e
;Q`0=2lL034^7@0_;Ah0;2dO02/[7`0Y:ah202PZ7`0302LY7P0V:1d09BLL008092HK00<08bDJ02<V
7@0S9Qd01P0S9Qd202@W70<09BPM100V:Ah2020S6P<08B@K0`0R9A`202<U6P0402@V6`0U9a`09BLL
02HX7@809bTN00H09bTL02PY6`0Z:ad0;R`M030]700d;a`203L`7@0I03Pc7`0j=1h0>S@N03`d7@0o
=A`0@SHL04Dg7016>1d0@cLQ044e7`0m<Qh0>30M03@]6`0a:a/0;R/L02dZ6`0d:a`0=RdN03P_7P0k
<b00?3@Q03`d7`0l=1d0>c<L03T]7@0203L^7@0303H_7@0d;a`0<RlL0080<C0L0P0];R000`0/;Al0
:b`N02X[7@0202TZ700302PY6`0U9Qh09BHN008092DM0P0S91`2028S6`808b@L1P0R8a/2020P7P80
7alM0P0N7Q`201dM6`0P01`S700N8a`08R@I02TW6`0`:Q`0>2lN03lb8@14=B80CcPV050g8`1@>200
DcXL05e37P1`EBX0QVXk09AhB02BNTX0T7A209Ic?@2NND@0WG]=089ZA01GBBl0=C0M02P[800T9ah0
8RDL02@U7`0V9b80:2LU02DS900Q7b02024S80808R@Q0P0S9B8202@V8`P09RLQ00P09R/U02DZ8`0W
:R<0:2TQ02T[800];B40<BlR03<a9080>C8X00D0>C<W03Tc9@0j=2@0>cHS03`g900203`g8`0:03Tg
8P0g=240=C8O03@a800c<240<blS03@`9@0e<BH0>38V03La9@80=S0T00@0=c4U03Pb9P0k=BT0?3HZ
0P0l=B<01`0m=B80@CHR04@h8P1:>b@0CChW05109`1IAB`00P1HA2/05@1FAB/0ED@Z05A4:P1DA2X0
Dd<Y05]7;P1JARd0FDD/05Q4:`1IAB`0FdL^05e9<01NBS40H4`Y065=:P1PCB`0GTh]05a=;P1HBRd0
E4T[05=8;0020511:P040551:01B@BL0DT4U05E29080ET4R03P0FT4S05Y3901KA2D0FTDV05Q59@1E
AB@0DT<R05528@1B@2P0DT4W05<o9P1E@2D0F40T05a39@1NABH0HDHX05]3:@1LA2P0GDDY05m8:@1Q
BRX0Hd`Z06A>:@1UCbX0IThX06M?:@1XD2X0Je<]06eE;`1_Ec40LETc079J=01`FC00LU/a07IM=01i
HCD0OV<f089V=`26IcP0QfPi08AW>`21I3P0Nehb07MJ;P1cF2d0M5T^07IK<01fGS80JE4U06I=901S
BR80H4PR05m89P1SC2`0IE0a06QC=P80H4`Y01`0Gd`[05a<:`1JBb`0F4X]05E:;01DBBd0FTd]05U<
;01GBRX0EDPX05E69`1FAbP0EdPY05U8:P1NCRd0Gdl^065A<01SDc80IE8b06AA<@1SD300HTl_05m?
;P1TDC00JUPd071M=@1fH3L0N64e0P1iHC<0201dHS80MfDc07]W=@1kIc@0OFPc08=/=P2<MSd0U7i5
0P2DNcP08P2HOcd0Vh=309b6BP2KQTd0UX9=08imB@2:N4H0Q7=508=a@`23KSl0PV`m089Z?025JS/0
R6`m08]/?P2>K3l0Sfdo09=_?`2DL3h0UG0k09E`>@2HLCP0VG8g0:1l<02QOC<0Wg`h09ek?P2HMd80
TW5408a/A@29JD<0PfLg089V=P1oHc<307eQ<@0@07mS<`20I3@0OE`c07]J<@1jEbd0O5L[07iI;023
GBh0RV4c08eU=02BJRd0U6`_09M_<@2JLS@0W7Dd09ef<`80WGHa102TN3L0<P2VNST0ZGdl0:b0?`2]
PD00/7hg0;>3>`2gR400^Xi70;bBBP2jTTX0]i5:0;F@B@2fTDX0]Y5;0;F@BP2cSTX0/H]:0:n9BP2_
RD/0/8Y<0:^5A02/QTD0[HM60:n9BP2`RT/0/Xa=0;>=C`2dSU00]Xi@0;F?D02dSTl0/8e=0:f;B`2Y
RTT0YhY80:J9A`2]Se40[8a?0:f;CP2/RTd0[HU;0;:<CP2fSU40^91B0:n=CP2/RT/0ZHM80:F3A02R
P440X7ho0P2NO3d0402QOCl0X7`n0:1l?P2PO3h0XWi00:F1@`2XQ4H0ZXI80:V1C@2ZPd`0ZhA;0:b5
BP2[QDL0ZXA30:R2@@2WPSh20:N0?@040:Io?02UOS/0YGhk0:Am>P80Xg`i0140YGdo0:9j?02PN3X0
XGTk0:Al?P2SNcd0WWHh09Ua<`2AKS@0T6dc08m/<P2=JS00RfP^08UV;028IB/0Qf@Z08YV<P0208MV
<@0608IU<024IBl0PV@^07mT;@1mI2`0O6<[1022J2l208=Y<00308AZ<@25Jc80PfD_0080PfD_0P22
I2h3085S;@0808MT;P26IBl0QfHa08IV<`23IC<0OV8b07UO;P1gG2d207QL;@0>07UM;@1kGbd0OF8]
07iS;01oI2d0P6H]08m/=02;Jc80QfH`085R;01nH2`0O60^07iT<@21IcH8089Y<@03085W=020IS<0
OfDb0080OF<`00/0OfDb081V<`21Ic@0RFhg08Y_>02=LS/0Sg@m091e?P2?M3d0SW<l08eb>`0808]`
>@P0Qfhe0P28KcL01027KSH0QVde08E/=025K3@208A[<`80PfLe0P22IS@4085U<`0V07aV=01kI300
NF8^07]R;020IBh0R6/c091a>02EMSd0Vh5609Z0A`2MPT/0Y8UD0:jBH02eVFX0]YU]0;FHK02YT5L0
Y8]C09^2BP2?MT00PfTf07]Q<01fFb`0MEX[071H:01/E2H0J50R06M?8`1YD2L0J4lW06A:9@1PAR40
HU4V061>9P1MBbD0FTPR05M58@1F@b8205E28P0:04dl7P1=?200Bc`O04Pj7`15>Al0@SPO044f800o
=b00AC@P044b7@80?c0M00d0?C0O03hc8@0k<R40=BhN030Y6@0X91/09R8I028O600N7AP06a`G01XL
6@0H7AT061`K00806Q`I0P0I6aP201PJ5`805aTF400I6aX801PH60P05QPG200H6QT801PH60P05aTF
200I6aP301XJ60806a/I0`0L71X801`M5`P07ahI0P0N8AP00`0O81P08B4I02<P6@0202DP6P0902LP
6P0W91/09R<J02HR6@0X8AT0:R4J02dR700_91h0<bHP0080<RPL00H0<BLK030V6P0a9a/0<RPL03@Z
7P0f;20803D/6`<0=RXJ0P0g:a/303P/70T0=b/M00@0>2lP03L^7`0d:a`0<RTJ0P0a:1T00`0b:AX0
<bXK038X7007038X700403@X600g:a/0>2`L03HZ6P80<bLG00<0>2`L03``8010;ad00`10;ad4044`
7P<0ACDL0`16=Qd204Lg7P0804/i8`1:>280BCLQ04Pf8017=Al0AS@N04Dc7@14<Q`2048f7P0604Df
7`16=Ql0B3HP04Pf801;=R40C3HQ1019>1h404Pg7@0504Tc701:=1d0BS@M04/e7P1<=Ql00P1>>240
2@1?>B80CcXM050k7P1B>Qh0E3XO05Hk801I>b40FS`R05/k8P0205U08P0405Xo8P1K@2<0GT0T0611
9@80HT0U0`1QA2@306138`80Gd8R00<0IdPY06E69`1SA2D00P1R@b@0101UARL0JDX[06]<;@1XDBP2
06U@:00306]?:01/CRP0KThX0080KddX0`1dDB/00`1cD2X0LTlY079?:@02075>:080MU<[0P1eDRX3
07AA:@0507=@:01gE2`0ME8Z07=@:01aCRH00P1`CBD2075>9P0607MG<01eEBh0Le</071@:@1^CRL0
KDdV0P1^CRL0101eDR`0LDhX06e:901^BbD2079?:@0607EB;01dDB/0LTlY079<9@1cCBH0M4hW0`1e
CbP01@1dCRL0LddV07QC:@1gDRP0ME0V0080M4lU01/0ME0V07MB:01hDbT0NE@Z07QC:@1fDBL0ME0V
07A?9@1fDBL0Me8X07UD:P1iE2L0NE@X07YE:@1jEB/0NE</07MA;01eCb/0M4hZ071<:01aCBT0Ldl[
07A@;01cCb/0LDdY06i:9P1[Ab<00P1bDR/01P1dE2d0MED^07MG<01iFC80NUXc07]K=0<0NUL_1@1k
F3000`1iER`0NUL]07]H;P0207eJ<00607aI;`1kF2h0NUL]07eJ<P1lFC40NeP`0P1jEbl00`1lFC40
OU/c07mL=00807iK<@P0NeP^0`21G2l2081K;P<0PE`_00@0P5/a085L<P21G380PUdc0P23GS@208AO
=@0808=M=P24GcD0QV4g08QS=`28HcH0R6@d08MS<@26HS0308IQ=@<0QV4d0P26HS802028HCX0Qf0g
08IO=P24Gc<0Q5lb08AR<P25I340QfHc0P2;IcL208YV=P@0RFDe102=IcP408iX>@<0Sf/g00/0TFdi
099^>P2DL3`0U70l09Ea?@2FLSh0U71009Ea@@2FLT80Ug=309QdA00209Mc@`0909Ib@P2IM400V7<o
09Qc?`2GLSh0UG0l09A_>`2BKCT0TF`h00<0T6`l0P2?Jc/308iZ>P0508]V?02:IC/0Qf8h08AO=@22
GC<00P21G3801`22GC<0MePY07IG:@1eERP0M5DY07=C:P1aDBX00P1`D2X03P1dD300M50^07A@;P1d
D2`0MU<]07UF;P1lFBl0OEX`07AH:@1gF2X0NEX/07aK;P1oGC00Pehb0P25GS<06026H3T0Qf8h08MR
>029I3P0RVDh08aX>02=JCL0SVXh09A_>P2EL3/0UW4l09Ud?`2KMT40WGQ309mjA@2PNdH0X7]70:5l
B02RODT0Y7m;0:J1C@2XPdl0ZHA@0:Z5D@P0YX5=102YQ4l40:R3CP030:F0B`2VPD`0Yh9=0080Yh9=
00@0YH1;0:AoBP2RODP0XWe90`2SOTX30:AoB`030:F0C02SOd/0Xgm;0080Y81<00L0YH5=0:J2CP2W
Pdl0Yh=?0:N4CP2VPdd0YH9<0080Y85;00<0YH9<0:N4CP2XQDl00P2UP4`0102TOd/0Xgi:0:9mB@2Q
O4P20:1kA`080:1lB02NNTH0VgM309Qd@02GLcl0V7A009Yf@P2LN4@309]f@P80VWE1102IM40809Ud
?`80WGQ31P2LMd802`2KN400W7U109ai@`2NNTH0Wg]90:5mC@2ROTh0XgiA09mjAP2PNdL0XGa80080
Xgi:00h0XGa80:1kA`2ONTH0WGY209ai@@2JMd40V7A009Mc@@2HM4@0VGE509YeB02KMdL0W7Q809ij
BP80Wg];00<0WWY:09ahB02KMdL00P2KMT80102JMD40VGA009Qc?`2HLcl209Mb?P0409UeA@2HM4@0
Ug=309Mc@`@0UW9200@0VWE009Ud?`2HLch0Ug8m0P2EL3/209A_>P<0U6ho:oooool002[ooooo00H0
VgQ209ag@P2LMd80WgM30:1g@`2RMd@20:AfA0P0XWM400H0X7E:0:1eB02PMDP0XGM70:5gA@2RNDD2
0:9i@`P0YGU8202UNTL20:=gAP030:AhA`2UNDP0YWY90080Yg]:00@0Z7a;0:IkCP2VNdh0YW]>0`2W
O4l20:QmD0040:J1C@2UP4`0YH1<0:F0C0<0Y7m;00<0Xgi:0:=iA`2RN4H01P2RN4H209me@`0409id
@P2MLd40W79009ab@080Vg4o00d0VW0n09Qb@`2GLD80UFm0099/?@2@JS/0SFLh08]U=P2:I3D0RV@m
08US?027HCX0QElh00<0Q5hg00X0QElh081N<01oGC00OU`_07eJ<01lFC40NePb07YF<P1iEC40NETb
0P1hF3400`1gEc00MUH_07EE;P0207AD;@P0LU8[201/CR`207EA;@0>07MD;P1hEBd0NUL]07aJ;@1n
G2l0OU`^085P=`22HCH0Q64g08MR=P29I3L0RfDf08iV=@2?IcH208iX>@0408mY>P2@JS/0TF/l099/
?@80Tfdn0P2AJc`0102CKCh0U6ho09A^?`2DKSl209=]?PP0Ufdk0`2BK3d2095[?0<0T6Xk0P2AJc`3
091Z>`<0SfTj0P2>J3T0102=IcP0S6Hg08aV=`2;ICH208YT=@P0S6Hg0P2?JCX00`2>J3T0SFLh08aV
=`0308]U=P80S64f00<0SF8g08iS>02?I3T00`2@ICX00`2AJ3X0T6Li08eW>00208YV=P0408YX>02:
JST0Rf/j08iY=@<0SFPd1@2<Ic<208aV=`80SFLh00@0SVPi08mY>P2@JS/0T6Xk202AIST01P2BIST0
T6Dh091U>02>ICL0RfDf08UU=@80QV@d0`2=HSD208aQ=0<0Rf0c0`29Hc@308QR<`80Qf4b2027HSD2
08IQ=0<0Qf8e0`28HcH01P28I3@0RFDe08YV=P2;IcL0S6Ph08iZ>P80Sf/k00D0RVHf08]W=`2<J3P0
SFTi08iZ>P0208eY>@0308aX>02?Jc/0Sf/k00<0Sf/k0`2@K3`808aZ>P80RV`h00<0RV`j08Y[?02:
Jcd00P2:Jcl04@2:JT40Rf/l08MW>021HS<0OF4a07eS<P1iHS00M5d[06iH9P1ZDbT0J5<X06E?:01O
BbH0FTLV05E49P1A@RD0D40V0080BS`Q00l0Ac/Q04@j8@0o=b00>S@N03H`6P0c;QX0=2dJ03@]6`0c
;Q/0<BhM02l]7P0/;Al0:RXN02PZ7@0X:Ql00P0W:Ah00`0V:1d09BLL02@V6`0202<U6PP08bHM00@0
92LL02DX7@0U:1d09BPM0P0V:Ah302LZ7`03028U700Q91/08B@K00D08B@K0P0S9AX00`0T9Q/09BLL
02HX7@0202LY7P0:02PZ7`0X:Q`0:BXJ02//700^;A/0<BhK03D`700g<A/0>38L03Xe8@80>cDO01<0
?3@M03le7012=Q`0ACLL04Li7P13=R<0@C@Q03`a7`0f;A`0<R/K02lY6`0^:a`0;RXN03H]7P0g;Ql0
>C0O03/c800l=240?3@O0080>c<L00H0>2`L03H]700f;A`0=BhL03@_700b;a`2034`7080;BhP00<0
;2dO02//7P0Z:ad00P0Y:Q`00`0X:A/09BHN02DV7P0202@U7@808b@L0P0R8a/302<T70<08R<K0P0Q
8QX2020P7P807alM0P0N7Q`201dM6`0P01dT700O9A/092HK02`X700e;1d0?S4P04He8`1<=b@0CS@U
04lf8P1C>B80Fd0R06U=9P1kGc00SW0n09UkA@2?NdT0Sg@o09Ud?@2RND<0Tfi106YC<`12>b/0<34[
02@/8@0Q9Ql08B@M028T7`0W9R@0:2HW02LR9P0U7b<2024S80808R@Q0P0S9B8202@V8`P09RLQ0P0T
:B801P0W:R40:B/P02/]800`<B<0=C<T03Le9P80>c@Z00D0>S@X03Tc9@0i<b<0>SDR03/f8`0203`g
8`0@03Pf8@0f<b00=C8O03<`7`0b;b00<blS03@`9@0e<BH0>38V03La9@0f<2@0=BlS03H`900g<BD0
>C<W03Xd:080>c8Q00h0?S<Q044d8@15=R40BSXS04hn9`1A?bL0GTH^05]5;@1IAB`0F4@[05A4:P1C
@bT0DD<X04i39`80EdD]0P1FA2`0101GABd0FDL_05]9<@1LBS8205i;:P0<05e=;01KC2d0F4X]05=8
;01AARX0CT@Y04ho:01?@2T0D40W05919`1C@RH0ET<U0P1H@b@09P1K@R@0Fd@U05a59P1JABH0FDHV
05E5901CA2<0DD8Q05A4:`1C@bT0E4<Y05I29`1IA2L0GDHW05m8:01RBBX0G4@X05e69`1NAbP0H4TY
069;:@1TCRT0IDlX06I@:@1VCRP0IdlY06Q@:P1[Dbd0KED_06mG<@1aFC<0LUXd071I;`1cFS40MUhb
07eR=@21ICH0QVLh0P29JCP04024ICT0Of0d07II;`1^DRX0J4lW06Q@:P1ZE2d0K5Ha06==:01QBRP0
GdPV05e69P1LABH0GTHZ0618;P1QBBl205e::@0V05a<:`1JBb`0F4X]05E:;P1CB2`0DDL/05=::@1B
BBP0DTLW05=69P1EARL0EdHX05]8:P1LBB/0GDh]05m@;`1QDC00IE8b06IA<P1XDC80J4la06M><01P
D2`0IE<_06YH<P1_G3@0MElf07QQ=`1iH3L0NF4e079M<01fHC80NfHg07eY=`1nJSL0PVhi08Yg?`2@
ODD2095l?@0e09=m@@2DP4D0U8590960C02=OD`0RGQ:08AfB@1lKD80OVe2085/@@22Jcl0QVTm08QY
>`2:J3/0S6Lj08mW=P2DK3/0UW4m09Qc?P2FLC`0UG0i09Ea=`2FLSP0W7Te09ej>02MNc`0VWY109Ig
@@2ALT<0Rfa008IY?`26IcP0Q6Df085R<`1oH340OUl`07mP<@21HS<0Pf@e07eK=@1kFC<0NEH^07]F
;01mF2`0Ped`08]R=02>ICL0U6X^09M^<02JLC<0WWDe0:5h=P2SNcH00P2SNcD30:am=`0F0:io>@2`
PC/0/h@n0;J7@@2hRD<0_HPl0;j:?`2mSD<0_i560;bDC02lUTd0^IM?0;NFC`2dTT/0]I=<0;FBCP2b
Sdd0[X];0:b8BP2^RTh0/8a@0:Z9A080ZhY700<0[8Y:0:f;C02^S4l00P2_S5820;2<D00V0:j<C`2Z
RTd0YhU;0::6A`2OPd@0W8=30:R9DP2XRE00ZHU@0:^8CP2]Rdh0/8a>0;>=CP2eSe00Z8Q;0:J6B@2T
Q4L0XH5409in@@2LO3l0Vg/n09Yj?@2POT40WW`o09ek?P2LNSd0WG/n09mm@02RP4<0Y8950:AnC@2U
Odh0Yh9=0:R4BP2XQ4H0YhA20:F2?P2TPS/20:R1?P80Yh0m0P2VOc`20:En>`0>0:V0@P2VOCl0Y7/m
0:El?P2XOd40YWdo0:5h>P2MM3H0TW0c095_<P2@KS40SV`_08aZ;@2;JB`208UW:P0708aX=029J3<0
RFPc08QW<P25IS00PV@^07mT;@0207aS:`80Q6L_0P23IRh01024Ibl0QVTa08Q[<`29K3@208IY<@80
QFP`0`24Ibl06@23IRh0RFH^08MW;P27IS00QFH`08=U<@1oHc40O68_07YP;`1jFbd0Ne`^07]L;@1l
GR`0OEl[07iP:P1oHB/0P6<[08]X<02:JS40RFPb08EV<01oHBd0O60^07eS<020ISD02022JC400`21
Ic@0P6Hc07mU<P0207iT<@0607mU<P20IS<0PFLd08U^=`2;L3T0SW<l0P2AMSl00`2@MCh0SW<l08aa
>P0808]`>@P0RG0h00H0RW4h08U`=`29L3L0R6lf08M^=@26KC@208E/<`80Q6Pf0P23IcD3089V=00G
085U<`1mIcD0O6Da07YS;`1kHR`0Of@]08MZ<P2?L3L0Tg@k09^1A02IOd80VX170:25D02[Sel0]9M[
0;RKL@2hVg<0[IAK0:ZAF@2RRE40UGa608M]>P1mHc800P1iGRl06P1eFbX0LEHW06eB8`1/DB@0KE8W
06a@:01XC2D0I4PQ06=B9`1RDBH0GddU05a:901JB280EdDQ05I38P1E@R40D3dO04lk801<>al0BSXP
04Pj8014>200@cLQ048g8@18=R80@c8N0P10;ad03@0o;al0?c8Q03hb8P0h;b00=2/L02/T700W8aX0
9B0J024N6@0M71P06a/I01XL6@0K7A`00P0J71T201TK608061XG0P0G6AH@01TK6PP061PH200G6AP8
01PJ6@P061PH200G6AH801TK60806QXH0P0K6aT301`L6P0301dM6`0M7QP07AhH00H07AhH200O7QT2
01hQ6003020Q6@0Q8AT0924J00809B0J00/0:24K02HS6P0V8aX09R8I02PQ6@0Z8AX0;B8L02lT7P0b
9Al0=BTM03@X700203<W6`0403@X700f:Qh0>2`P03T]8@@0=blL0P0f;Q/203D]6P80=b`J0P0h;A/3
03T^700303X_7@0h:a/0>2/K00<0>B`L100j;Ad0100i<1l0>2lN03D/6`0d:aX203<Z6@0303@[6P0e
;1/0<RPL00L0<RPL00@0=BTI03L[6`0i;Ad0=b/K0P0d:1P00`0h;1`0?C4Q040_7@03040_7@@0@C0N
0`15=A`204Hf7@<0AcLN0`1<>20304/g7`80BSHN0P15=ad01P17=ah0BCLO04Xh801=>B40CSPQ04li
8P80CCTP0`1<>1l304/g7P0604`c7@1==1h0CSDO04lf801A>280DSTS0P1C>R@2054l7`0>058j7P1D
>Ql0ES/P05Tk8@1K?B<0GCdT05Ln801I?R40FSlR05do8`1P@BD0Hd4V06E19`1V@RP80654900906Q9
:P1WB2T0IDHW06A59P1UARL0IdPY06U::`1[C2d0JE8X0080Je8Y00<0KE4Y06iA:@1`D2T00P1aCbT2
07MA;080MU0[00@0MDlZ07A>:@1cCBP0LddX0`1eDRX207AA:@<0Le0X00<0MU<[07AA:@1bCbL00`1`
CBD01P1aCRH0LTlW07IF;@1eEB`0LU8Y071@9`<0KdlV00D0L50W07EB;01aCRP0KDXT06i;9@02079?
:@0507EB;01dDB/0LTlY07==9P1dCRL00P1eCbP407I@:@0307YC:P1iDRT0Me0W0080MTlV01<0Me0W
07UB:@1jDbX0OEP^07]F;01hDbT0MU4W07E@9P1gDRP0NE@Z07YE:`1jEBP0NeHZ07aG:`1lEbd0NeD^
07UC;P1gDBd0MU0/0080LTlY0`1cD2X02`1bCbT0LDhX071=9`1dE2d0MED^07IF;`1gEc00N5Pa07UI
<P1jFS<0Ne/d00<0NeP`0P1lFC4307eJ<P0@07YG;@1kF2h0OEX`07iK<@1oG380OU/a07eJ<01lFBl0
OU/c07eJ<P1lFC40NeP`07aI<@1mFS80Oe`d081M=@P0Oe`b201mFS000`24Gc80Peha089M<003089M
<00308=N<@24Gc80PE`b0080PE`b00h0PUdc08=N=023GS@0Pehd08AO=@23GCH0Q5le08IQ=`28HcL0
RF@g08UU=@28I380Qf<a08MQ>P80Qf8h00<0Qf8f08MR=@27Hc<00P27Hc403@2>HSd0S68j08QQ>027
H3D0Q68d08ES<`26IS<0QVPd08aX>02;IcL0RVHf08UU=@28I3@00P29ICD0102:ISH0S6Hg08eW>02=
IcP208iX>@<0SfTj0`2@K3P01P2AKCT0TVhj09A`?02DL3`0UW8n09Qd@080UG5100<0UW9209Mc@`2G
Ld<00`2GLd<409Ud@00409Mb?P2EL3`0Tfhj099]>@80TFdm0`2@K3`308m[>`0608iY?`2<Icd0RF@j
08IQ=`24GcD0Pehd0P24GcD01P1jFb`0NEX/07QI:`1gF2`0MUH]07AD;@80Le<]00h0Me<c07IB<01f
DS00MU8^07MD;P1iERh0O5T_07eJ<01fFRX0NEX[07]L;@1oGc00PV0b08EP<`80QV0c0100RF<l08UT
>P29I3X0RVDi08]V>@2=JCT0Sf/i095]>`2FLC`0Ug8m09Ud?`2KMT40WWU40:1kAP2QO4L0XWe80P2S
OTX01P2UP4`0YX5=0:R3C`2ZQE40ZhIB0:b7D`P0ZHA@0`2[QU430:Z5D080ZHA?00<0Z8=>0:V4C`2Z
QE000P2ZQE00102XPdh0YX5<0:F0B`2VPD`70:F0B`060:B0C02UPDd0YH5=0:J2CP2WPdl0Z8A@0P2Y
QE40202WQ4h0YX==0:F2C02TPD/0YH9<0:J3C@2XQDl0ZHI@0P2VPD`02@2UP4/0Y7m:0:9mB02QO4L0
X7]609mjA@2ONdL0WWY609]g@`0209Ue@@0409Yf@P2LN4@0WGU509ag@`<0VgI20P2JMD4309Ud@0P0
VG@o0`2MN4<309ag@P80VgI100/0WGY209ai@@2LND<0WGU509ijB02PO4`0XWi>0:=nD@2PNdL0XGa8
0:=nBP020:AoB`0>0:=nBP2QO4P0X7]709mlA02NNd<0VgQ209Ue@@2IMD<0VGE509YfAP2JMDP0WGU9
09ijBP2ONd/20:1lC00309mkB`2NNTX0WGU90080W7M300<0VgI209Ye@@2IM4000P2HLcl0102GLSh0
VgM709YfAP2HM4@309Mc@`80V7A400@0VgI109Ye@02HLch0Ug8m0`2FLC`0102GLSd0U6ho09A^?`2D
KSl[ooooo`00:_ooool0202JMd40VgI109ag@P2NMT80X7M30:5f@`2SMD<0Y7I4202SN4D01P2PMDX0
XGI90:5fB@2QMdL0XWQ60:9iA@80XgY4202UNDP80:IkB080XgM600<0Y7Q70:EiB02VNTT00P2WNdX0
102XO4/0YW]>0:IkCP2VNdh30:MlC`80Z7e@0`2VPDd00`2UP4`0Y7m;0:AoB`020:=nBP80YWa:00@0
YG]90:AjB02SNDL0XgU70P2RN4H20:5gA@050:1fA02OMD<0WWA209id@P2MLd400P2LLT00302HLT<0
Ug5209I`@@2DKSl0TV`m091Z>`2>J3T0SFLh08eW@02;ICh0R68k08EO>0@0Pedf00H0OU`^07iL;`1m
Fbh0OEX`07aI<@1lFC<207]G<`80NETb00@0N5Pa07MG<01fERl0MED^0P1dE2d2075A:PH0LU8[01h0
KDl]06]=:`1YBbT0J4XX06U;:@1/CR`0Ke4_079D<P1eDBd0MU8^07MD;P1iERh0NeP^07eK;P1nG2l0
Oed_085P=`21H3D0Pf0f08MR=P28HcH0RV@e08eU=02>ISD0S6Hg08eW>02>J3T0T6Xk099/?@2CKCh2
09E_@008091Z>`2AJc`0Tfdn09E_@02FL440UFm009A^?`2CKCh809Q^?00309=]?P2BK3d0TV`m0080
TF/l0P2@JS/00`2?JCX0TF/l095[?003091Z>`<0SfTj402<ISL808eW>0P0SV<h00P0TFPj08iX>@2=
IcP0RVHf08QV=P29JCP0RF/i08Y/>P80RfHb0`2<Ic<408eX=080RfDf00@0S6Hg08eW>02>J3T0SfTj
0P2@JS/8091U>006095U>02@ICP0Sf@g08eT=P2:I3D0RFDe0P26I3@0102=HSD0S64d08aQ=02<HC@2
08]P<`80RUlb0`29Hc@308QR<`80Qf4b2027HSD208IQ=0<0Qf8e0`28HcH02P28I3@0RFDe08YV=P2;
IcL0SFTi08iZ>P2?Jc/0T6`l08]W=`2<J3P308iZ>P0308eY>@2;IcL0RFDe0080SVXj0P2?Jc/0102@
K3`0TFdm099^?P2BKSh808i/?00X08Y]=@2:K3H0RV`h08Y/>P2:Jcd0RV/o08YZ@@2:JT<0RFTj08AT
=@1oH340O60`07aR<@1iHS00MEh/071J:01YDRP0Ie8W06A>9`1OBbH0FTLV05A39@1A@RD0CclU04/m
8P1:?240Ac/Q04@j8@0n=Ql0>C<M03D_6@0b;AT0<b`I03</6P0c;Q/0<RlN030^7`0/;Al0:BTM02LY
70809bTN00@09RPM02DW700T9Q/092HK0P0S9AX802@W7P<09BPM0P0V:Ah402LZ7`808bHM0P0R9A`0
1@0Q91/082<J01lR6@0O8QT08bDJ008092HK00<09BLL02HX7@0W:Ah00P0X:Ql06`0X:aX0:R/K02//
6P0_;QX0<S0K03Ha6`0h<Q`0>C<K03`g8`0l=R00>cDO03`d7@0o=A`0@CDK04Hh7@17>Ah0A3LV044d
8`0j;Qh0=2/L030X6`0^:1X0;BTM02hZ7P0f;Ah0>2lP03Xa800203`d8@0403`d7`0k<a`0>S8K03L[
6`80=B`K00<0=BhL03@_700b;a`00P0a<1`202d^800302`]7`0[;1h0:R/M0080:BXL00<0:2TK02DV
7P0U9Qh00P0T9Ad202<T70808R<K0P0T9Ad202<T7004028S6`0Q8QX08B8J024R6P80820N0P0O7ad2
01hN70807AdK02006bDJ01hV6@0U9aX0;BXK03T]7@13<R00BcHS058i9@1<<280D3DT05Pl9P1UB2X0
M5L_08EV=`2ALcd0V7U008UgA`2GO4L0Y81609md?@20Fbh0EShT03Da:00W;c808bdT024X800O91h0
8B<P02LU9P0Z9BT0:B<W02PN9P808B<P0P0R924202<U8P8092HS200V9b4202<Y7`0=02HY7P0Y:ah0
;BlQ038c8`0h=RL0>cXX03hg;@0l=B/0>S@X03Tc9@0i<b<0>SDR03/f8`0203`g8`0803Le800f<b00
=34N03<`7`0b;b00<blS03@`9@0e<BH203La9@0603D_8`0d;R80=BlS03H`900h<RH0>C<W0P10=2@0
3P12=B@0@cHS04Pi901=?BH0DT0Z05A2:P1PARl0GdL_05]5;@1HA2/0E4@Z0553:01=@RH0C4<V0P1A
@BX20510:@0M0551:P1C@b`0EDD^05M7<01KBbT0Fd/Z05Y;:P1HBb/0DdPZ0515:@1<@RL0BT0U04dn
9`1>?bP0D40W05=2:01EA2P0FDHX05]69`1LAbP0G4<U05a59P1MARL0G4LX05Y79`1GAbH0E4DT0593
8P1BA2X00P1B@RP01@1C@RH0Ed@V05Y59P1NAbL0H4TY0080GDHW02@0GdPX065::01SCBP0I4hW06I@
:@1VD2L0IThX06M?:@1XD2X0Je<]06eE;`1_Ec40LETc079J=01`F2`0MEX_07UN<@1oHc@0QFHg08UY
>02;JCT0S6/h08IU>P1oH3@0M5L]06]?:01TC2H0I4d[06EA<01WE3<0GT/]05e:;01LBB/0G4L/05]6
:`1LA2X205a4;00X05U99`1JBRT0FT/Z05U<;01FBbd0E4T]0557;01?ABX0CDLU04a6901>AB@0DTDU
05A59P1JAbT0GDP[05m:;@1MD2h0Ge0_069B<@1UDS80JE8c06U@<P1YCS40JT``069C;01VE2`0JEL_
06eJ<P1bG3<0MUlf07QO=`1iH3P0Leha07UT=`1nJCX0Ofdk07i]>@1nKcP0PG8k08Ef?@80S7Pm03D0
RgPn08Yg?`27MT80QGE4089dA`1oLTH0Og9807QY@P1lJT@0PVa508I]A029K480S6Xm08aV>@2;ICP0
SF@`09A[=`2JLCd0Vg<o09Qa>P2CKSL0Tfle09Ea=`2IMS`0VWLm09Ui@02HND80UGM1095c?`2;Kcd0
R6`j08YZ>`28J3T0Q6@e085Q<P20H340PF4b08AT=@25ICH0OE/f07]I<`1iES00NU@]07eH;P24GC80
S6<g091W>`2HK2l0VVh_09ib<`2SMcH0Yg`h0:Yo>P020:^1>@<0/X8h01D0]8@j0;N7?@2jRT00_Xi4
0<2@AP38TD40aY530<:AA030TTL0_9E:0;bHCP2kVU<0^YaD0;>@C02eTTh0]I9@0;6>CP2[QdT0ZXI:
0:f9C@2aSE<00P2ZS4H0102YRTL0ZHY:0:V9C02YRE020:V8DP0K0:^8D02YRE00Z8Q?0:F6C@2QQ4X0
Vh5609In@P2CNcl0W7i:09j0BP2QPT/0Y8A;0:R6B@2ZQTP0ZXM70:b6A@2QPdL0X89609n1A@2MOd<0
Vge109Uk?`2HNSh0UgTm09em@P2KNd00V7Pm0080UWHk00/0V7Pm09]k@02MOD80XG]>0:9lC@2TOd/0
YH190:F1A@2TPCl0Xh0l0::0>@030:R1?P@0Yh0m00X0YWll0:f1@P2ZOSl0Z7`m0:Um?P2[Od00ZWho
0:Ei>P2PM3D0UG<f0P2DLSD00`2BL3<0TFlb091^<@0208m]<00;08iZ=P2;JSD0RfXe08UX<`26Ic40
PfD_07mT;@1lHb/0Nf8Z08IW<025IRl00P24IBh01025IRl0QfPa08Y[=02;K3D308Q[<@80QfX`0`26
JBl0202;J2h0R6P_08IV;@23I2d0PF<]07iS;P1mHc00OV@a0P1lFbh03P1lG2d0OEd/07iN:`1nGbT0
Of0Z07mP:@27I2`0R6P_08]Z=028JC<0PV@`07aP;P1lHRl0OV@c2021Jc800`22J3D0PFLd07mU<P02
07iT<@0607mU<P21Ic@0PVPe08Y_>02<LCX0T7Dn0P2BMd000`2AMSl0SW<l08aa>P0808]`>@P0Rg8l
00H0Rg<g08Yb=P2:LSH0RG4e08Q`=027Kc<208I^<P0408EY=`24J3H0Q6Pf08AX=P80PfLe0P22IS@0
5P1nJ3H0O6Da07YS;`1kHR`0Of@]08IY<@2=KSD0TW<j09^2@02HOcl0Uge209f2B`2WRe/0/YEY0;NJ
LP2iVgD0/iYQ0;:IH@2[TUX0WXE?08me@P24JST2081U=P0J07QN;@1dFRT0Ke@U06iC9P1_E2T0KU8Z
06Y>9P1VBR<0I5<W06=B9P1QD2D0GddU05]98`1IAb<0ET@P05E28@1B?B00D3`Q04lk801<>b40BCTP
04Lh8@14>280@cLQ04Pf8P14<Qh2040_7@0=03l_7`0o<R40@3<S03/_8@0h;1h0;2DM02/T700V8A/0
8ahJ01lK600M71X071`J01`L700201XL6@806A/H0P0H6QL201LI5Q006Q`K200H61P801LI60P061XI
200H61P801LI5PP06A/H0`0K6aT301`L6P807AdK200M7QP801lN6@807b8I0100824I028R6P0T8AX0
9B0J02HQ6`0X8A/09R<J02DR6@0V8QT09b0H02TP6@0/8A/0;b@N038U7`0f:1d0=BLL0P0d9Q/0100f
:1d0>2XO03X/8@0k;B8203Ta7080>30K00@0=blJ03H^6@0f;QT0=RhI0P0h;AT203T^6P<0>RlK00@0
>c0L03/[700k:a`0>b/L0P0l;1d203d]7P80?RhO00<0>C0O03L^7@0f;A`00P0d:aX00`0e;1/0=RdL
03L^7@08038X700403DY6@0h;1`0>BdM03L[6`80=2PH00<0>2`L03da8@11<1h00`11<1h4040_7@04
04De7016=Qd0ASHM04Hf7@80AcLN0P18>1l204`f7P80CCLO0P1>>20204li8@0604Hh7@17=ad0B3PN
04Xi7`1=>B00CcTQ0P1B>R8304lj7`80CSTN00T0CCPM04`g701<=a`0CSDO04lf801@=b40DCPR05<j
901D>bD00P1F?BL03P1C?R40DSdP05<k7`1D>Ql0ES/P05Xl8P1L?R@0GShU05Hk7P1I>al0FcdQ05ho
8`1S@BH0IT8X0P1YA2X206138`80HD@T00D0HTDU06=69P1TAbL0I4LW06U::`0406Q9:P0406U::`1Z
Bb`0JT//06YC:@80K5<Z00<0Ke<[071C:`1cDb`00P1eDbd207UA;@0407Q@;01gCb/0MThZ07E=:@80
M4`X0P1dDBT307=@:0<0LTlW00<0M54Y07=@:01aCRH00`1`CBD0301bCbL0Le0X07EF:P1dEBT0LU<W
071A9@1_D2@0L54U075B9P1bDbL0MU<]075>:080KT/U0P1bCbT207EB;00307=@:P1eCbP0MDlX0080
MU0Y0P1gDBX207QB:`0307eC:@1lDRP0NU0V0080NDlU00H0NU0V07aB:01mDbT0OeX^07eH;01iE2P2
07IA9@0;07MB9P1jEBT0O5L[07aG:P1lEb/0OEP/07eH;P1lERl0NU@_07QB;P1gDBd00P1cD2X3079?
:@0307=@:P1dDB/0ME8/0080MeL`0P1hF34207UI<P80NUXc00<0NeP`07aI<@1lFC400P1mFS8207iK
<`0407mL=01kF2h0O5T_07iK<@<0P5dc00X0Oe`b07iK<@1oG3@0OU/c07eJ<P1lFC40OEXb07iK<`20
GCD0PEhf2020GC<807mL<P0308MR=@26HC@0Q5lb0080Peha00@0Q5lb08IQ=027HSD0PE`b1022GC<3
08=N=00K089L=@24GcD0QV4g08QS=`29I3L0RFDe08UU<`28I380R68m08QR>`28HcT0R6<g08QT=028
I380R6@`08QU;`2AHcl0Sf<l08eS>`29HSL0QV@f08IV=@26J3@0QFXe08eY>@2<J3P0RVHf00<0R6@d
0P2:ISH208]U=P0;08aV=`2>J3T0SfTj091Z>`2AJc`0TV`m099^>P2AKCT0T6`h095]>@2BKSX00P2E
LCd0102GLcl0VGE109Ea@@2ELD4309Ib@P80Ug=300T0V7A409Ye@@2JMD40VgI209Ye@@2IM400Ug8n
09A_>`2BKCT00P2AKCd2091/?0<0Sf/k00H0SVXj08mZ@02>JCl0RfHl08QS>@26HCL208EP=P0G08IQ
=`1mGRl0O5d_07]L;P1jFbl0N5P_07MG<01fES00MED_07YF=P1iEC<0N5@b07MC;`1hEBl0NEH^07]H
;P1mFS00Me/Y07]M:`1nH2h0PV8a08ES<`27Hc<00P28HS<0402<ISl0S6Lm08]V?02;ISX0SFPk08m[
>`2BKS`0Tflm09Ud?`2JMD00VgI109iiA02PNdH0XWe80:AoBP2UP4/20:J1C@040:N2CP2XPdl0ZXEA
0:^6DP80[8MC202[QU830:f8D`030:b7DP2[QU40ZhIA0080ZXE@0P2[QU430:f8D`040:^6D@2YQ4l0
Z8=>0:V4C@80Z8=<00D0Yh9;0:J1BP2UP4T0YH190:AoB0020:J2CP030:N3C`2XQ500ZHEA0080ZXIB
00<0ZhMC0:J3C@2UPT`00P2TPD/0102UPT`0YX==0:R5C`2ZQe420:J1BP060:F0B@2SOTL0XWe60:1k
A02ONT<0WWU20P2MNDD209ahA00409eiA@2NNTH0WWY609mkA`80W7M30`2KMT8409Ye@@P0VG@o0P2N
ND@209eh@`0?09ag@P2KMT40VgI109]f@@2NNd<0WGY209ai@`2LN4@0W7Q609ijBP2PO4`0XWe@0:5l
B02RODT0Y7m;0080YH1<00h0Y7m;0:9mB@2QO4P0XGi609mlA02MNT@0VgM309Ue@`2IMDD0VWI609]f
B@2NNTX0Wg];0:1lC080XGe=00<0X7a<09mkB`2NNTX00P2MN4@00`2LMd<0VgI209Ye@@0209Ud@00<
09Qc?`2LN4P0VgM709UeA@2HM4@0Ug=309QdA02IMDD0VWI609]f@@2IM3l0V7<n0P2FLC`00`2GLSd0
V7<n09Ud?`0309E_@2_ooooo000Zooooo`0609Yg@@2KMT40W7M209if@P2PMd<0XGI30P2SMD<80:=h
A@060:5fB`2QMTT0XGI90:5gA`2RN4H0XWU50P2SNT@30:IjB@D0YGU8202WO4T20:=gAP030:AhA`2U
NDP0YWY90080Yg]:00@0Z7a;0:IkD02VNe00YW]@0`2WO5420:QmDP80Yh9>00@0YX5=0:F0C02UP4`0
Y7m;0P2SOTX20:QnC0060:MmB`2UNdT0Y7Y80:=iA`2RN4H0XGM50P2RN4H0102QMdD0X7I409me@`2O
MD<209id@P0>09ec@@2ILd@0V79309Ma@P2EKd00Tfdn095[?02@JS/0SfTj08iX@@2<ISl0R68k08EO
>023GCH3089L=@0607eK;@1mFbh0OE/^07eJ<01lFC40O5Tc0P1lF3@207UI<P0307QH<@1gEc00MUH_
0080MED^00@0M5@]075A:P1aDBX0LE4Z1@1bDR/05P1]Cbd0Jdd[06M99`1VB2H0J4XX06a>;01bE380
MELe07EA;@1fDRh0Me@^07UF;P1kF2h0OE/^07iL;`1oGBl0P5lf085P=@23H3H0QV4e08MR=@2:I3D2
08eU=00@08]U=P2<ISL0SVPi091Z>`2BK3d0U6ho09I`@@2GLD80SfTj095[?02CKCh0UFm009I`@@2E
Kd00U6ho09=]?PP0V6hl0P2BKSh0102AKCd0T6`l091/?02?Jc/208iZ>P80TF/l0`2@JS/308mY>P<0
RfDf0P2<ISL308eW>080RfDf102<ISL208eW>080S6Hg0`2=IcP308iX>@80Sf@i0`2>HcP308eR=`08
08mY>P2>J3T0S6Ph08QV=P27IcH0RFTh08U[>@2:K3X208YU<@0308]V<P2<Ic<0S6Lc0080SFPd0P2>
JCD01P2:I3D0RfDf08aV=`2=IcP0SVPi08mY>P80T6Xk202@ICP0202AICP0T6Dh08mT=`2=I3H0RV@e
08QT=026I3@0QF<c102<HC@208]P<`80RUlb0`29Hc@308QR<`80Qf4b2027HSD208IQ=0<0Qf8e0`28
HcH04028I3@0RFDe08YV=P2;IcL0SFTi08m[>`2@K3`0TFdm08aX>02=JCT0SVXj08m[>`2>JSX0S6Ph
08UU=@28I3@208eY>@0408iZ>P2?Jc/0TFdm099^?P80Tflo202?KCd208Y]=@0V08Y/>02:K3X0RV/m
08YZ@@2:JT<0RVY408MW>023Hc@0OUl`07aP<01lHS40NV<a07IO;@1aFbT0J54W06IA9P1SCBH0GTXU
05Y79P1D@bD0DD8U04lo9@1;?B80BS`Q04Lk8@14>R40?SHO03Tc7@0e;aT0<B`H038[600c;1X0<bhK
038_7P0`;Ql0;2dO02TY7@0V:1/202LY7P0302HX7@0U9a`092HK00808bDJ00<08R@I02@W7P0T9ah0
1P0T9ah202DX7@<09RTN100W:Ql01P0U:1l092LN02<V7@0R9A`08B@K01lR6@807R4H0P0T9Q/202DW
700:02HX7@0W:Ah0:2XO02PZ7`0Y;1/0:R/I02`]6`0_;QX0<S0K03Ha6`80>C<K01T0?CPT03dg8@0k
=Al0?3@M03hd6`11=A/0ASPM04Li7P14=bH0@C@S03X^7P0b:AX0;bLJ02hX700]:Ad0;b/P03L^7`0h
;b00>S4P03`d8@0m=B80?3@O03/c700j<Q/0=b/K0080=B`K00<0=2dK03@_700b;a`00P0a<1`202d^
800302`]7`0[;1h0:R/M0080:BXL00<0:2TK02DV7P0U9Qh00P0T9Ad202<T70808R<K0P0T9Ad202<T
7004028S6`0Q8QX08B8J020Q6@80820N0P0O7ad201hN70807AdK020072HK01lW6P0U9aT0;R/L03X^
7P15<R40CSLU05@i9P1:;R80D3<S05Xn:01ZCBd0Nehf08U[>@2CM3d0UWPl08IdA02PQE00/8U@09]`
>@1aBah0BC<K02l/9`0Q:c@0930V024[8`0N9Ah08B<P02HT9@0[9BT0;28Z02XO9`808B<P0P0R9242
02<U8P8092HS200V9b403`0Q9ad08RPL02DX7@0Y:ah0;S0R03@e9@0j>BL0?C`Z03lh;P0m=R`0>cDY
03Tc9@0h<R80>C@Q03/f8`0203`g8`0;03Hd7`0e<Ql0=34N038_7P0b;b00<blS03@`9@0e<BH0=c4U
03H`900e;b<00P0d;R800`0f<2@0=c4U03Pb9P0204<g9`0>04Dh9`19>RL0CC`X0590:P1FA2h0FTH^
0696<01PARl0GTH^05U5;01C@bT0CT<W04a39P19@RD204`l9@80Bc/T00@0C3`U04lo:01A@BX0Dd</
0P1JBRT0KP1HBBX0ETP[0597:`1=@bP0BT0U04Ho9@1<?BH0CChW05109`1D@bT0ETDY05]8:P1MB2T0
GTTZ05e49P1MARL0GTLX05a7:01KB2P0EdLV05E69@1CA2<0D48X04m19P1@@2H0DD0T05A18`1H@b@0
FTHU05i79`1MARL0GTLW05m8:01QBRP0HddX06E?:01VD2L0Ie4X06I>:01WCbT0J50Z06]C;@1]EBl0
KeLa075I<`1bFS@0LUL/07EJ;@1kGS80P6@e08IW>02:JST0S6/h08e/>@28Ic`0PF8f07EH<01ZDBT0
IDdY06=?;P1UDS80IUDg05I5:`1GAR`0F4L]05a8;`1NB300H4P`05m7;`1PARl0F4PW05U9:01IBR/0
FD/^05I;;`1CBBh0D4H[04a5:`19AB80BT@R04a38P1AA2@0ED@V05Y7:@1OBRd0Hd/_05e@;P1OD2l0
HU8a06MB<`1YDS<0JTlb06]=<@1[C300He@[06ID;01WEBd0JeP`071J<`1dGC@0N5lg07YQ>@1gH3H0
O6Lj089]@022L400OVhk07U/=`1jKCH0Nfhg0P27M3X05025LSX0PG0j07i^>`1kKCh0NVe107Y]@`1j
KTH0MfM307aZAP23KDP0RG1808i^A@2?JSh0S6Hi08aQ=02>H2`0U6Td09]`>`2LLcd0V74j0P2BKCH0
7`2CL3P0UW9009Qd@P2HMd80V7U309Eg@@2@MCh0S74j08Q_=P2=KCh0RVXk08IV=`22HS<0PF4b089R
<`24I3D0QVHg07iL=`1kFC@0NEH`07YD;@1mF2h0Q5db08eS>@2AJ3`0V6`]09]_<02PM3<0YGTh0:Yo
>`2]PSd00P2_QCd30;J5>@0>0;R7>`2kRSh0_hi20<:AA@35U4P0cYM50<ZEA@34Td@0`9950;bEBP2l
Ue00_9]D0;bNEP2`SdX20;>BC`0=0:n=C@2YQdP0YhE80:^8CP2`SE<0ZHe40:V<AP2XRdL0Z8Y:0:N9
C@2VQe00YXMA0:F6D0020:J6C@0>0:B5C02QQ4X0W89709In@P2?NCd0SGLk09AfA02FN4@0Vga609n0
A`2RPTD0Y8930:B1?`2SP3h209eo@`0909an@P2KOD40VG/o09Qj?P2FN3`0UGLk09em@P2JNSl0UWHk
0080Tg<h00/0U7@i09Mg?02INCh0WWU=09mjC@2QOD/0XWm90::0@`2RPCh0X7lh09mo=P030:R1?PD0
Yh0m00P0[H500:]o?P2YOC`0ZWhm0:b0?`2[Och0YWXi0:5e=080V7Hg0P2GMCH01@2FM3D0UG<d09Ab
<`2DLS<0Sf/g0080S6/f00P0RVTd08MX<P23IBl0Of@]07aS:`1kHRX0QVL`08EV;`80Q6D^00@0QFH_
08QY<P2:Jc@0S6df0P2:KC<208U/<P<0R6/a00T0QfX`08aY;`28J2d0QFD/085R:`1oHB/0OV<^07iU
;`20IS<00P1lFbh03P1lG2d0OEd/07eM:P1mGRP0OUlY07iO:023H2P0QfL^08a[=@2;K3H0Q6Hb07eQ
;`1lHRl0OF<b2020Jc800`22J3D0PFLd07mU<P0207iT<@0607mU<P21Ic@0PVPe08Y_>02=LS/0T7Dn
0P2CN4400`2AMSl0SW<l08]`>@0808]`>@P0S7<m0P2;LcL01P2:LSH0RG4e08Q`=028L3@0Qflc08I^
<P80QFTg0P24J3H308=W=@0c089V=01nJ3H0OFHb07YS;`1kHR`0OV</08IY<@2=KSD0TG8i09^2@02H
Ocl0UWa109^0B@2URET0/9=Y0;NIL`2iVgL0^9mV0;NNIP2bVF40Y8]E09EkB029Kch0QFXk08I[?01k
Gbd0Me/[079F9P1aEBH0LUDY075D:P1/CbL0J4/S06ED:01TDbL0HU4V061?901LBR80FDLQ05M58@1E
@al0DSdP058m8P1@?240C3/Q04Xj8@17>240ASLR04@h8P1;=R<0AC<O0080@BhM00d0@2lO044a8@10
<b<0?30R03T]7`0^9Ah0:b@L02PQ6`0S7QX081`I01dL6P0L71X071`L00806Q`I0P0I6aP201PJ5`80
5aTF400J71/801PH60P05aTH200H6QT801PH60P05aTF200I6aP301/K6@8071`J0`0M7A/801dN60P0
7ahI0P0O8QT00`0P8AT08R8J02@Q6P0202HQ6`0:02PQ6`0V8aX09B8I02DQ600W81P0:B0I02`Q6`0^
8ad0<RDO03HX7@<0=BLL00@0=RPM03PZ7`0k;B80?2hS0P0j<Qd0100i<A`0>30K03P`6`0g;aX203H^
6@<0>BhJ0P0j;a/303/`7080>b/K00D0?2`L03d]7@0m;Ad0?BdM03h^7P0203l_7`0303P`7@0g;a`0
=RhK0080=BdJ00<0=RhK03P`7@0i<Ah0200b:1`0100e:AT0>2`L03T]7@0g:a/203@X600303T]7@0m
<B40@C0N00<0@C0N1010;ad404Hf7@80AcLN0P18>1l01P1;=Ad0C3HN04dg7`1>>200CcTQ050j8P80
DC/S00H0AcLM04Ph7P1:>Al0CCTP04li8@1@>R8205<k8`80D3/N0P1?>Qd0701>>A`0CCPK04dh6`1<
=aX0D3DP054f8@1B=b80E3TT05Dj9@1G?2L0F3dX05Tn:@1C?R40DSdP05<k7`1D>Ql0ES/P05Xl8P1L
?R@0GclV05Li7@1H>Qh0Fc`P05ho8`1S@BH0Id<Y06Y5:`1[AR`205m28P0606138`1QA2@0HdHV06A7
9`1UB2P0ITTY0P1YBR/0101ZBb`0Jd`]06]<;@1[C2d206Y;;00606]D:01/E2P0KEDY071E:P1bEB/0
MED/0P1gERd01P1jDRh0NE4]07Q@;01gCb/0MThZ07E=:@80M4`X0`1cD2P2079?9`<0LDhV00/0Le0X
079?9`1`CBD0Kd`T071=9@1aCRH0LTlW07=@:01dEBT0Le@X075B9P02071A9@07075B9P1bDbL0Le@X
07IC;@1bCbT0KT/U06m<9P0207=@:P0307IC;@1eDR`0Le0Z00<0MU0Y0P1gDBX01P1hDR/0NE</07YD
;@1mE2P0O5<W07YA9@80NE0T01/0NU4U07aC9`1mE2P0PE`_07iI;01jEBP0Me8U07IA901hDbH0NeHY
07eH:`1lEbX0OEP/07iI;@1nFBl0OEL`07]E<01iDbl0N58^07AA:@1cD2P0LDhV071=9@1aCRH0M54Y
07MD;01iERh0201iFC8207aI<@80OEXb00P0OU/c07mL=01oG3@0P5de07]H;P1lFBl0Oe`b081M<`80
PEhd00@0P5dc07mL<P1oG3@0Oe`d0`1mFS800`1oG3@0PEhf089O=`08081M<`P0PEhd00<0RF@g08MR
=@26HC@00P24Gc800`26HC@0Qf8e08UT=`05089M<`<0Pehd00H0PU`e08AO=@26HCL0R6<g08YU>02:
ISH208UU<`0608QR?P28HSd0R68k08QS=`28I3@0R6@b0P28IBl0602EID40TVDn08mS?02;I3T0R6Hh
08IX=P26JcH0QVdg08eY>@2<J3P0RVHf08QT=027Hc<0R6@d08YV=P2;IcL0RV@e08]U=P2<ISL0SVPi
08mY>P2AJc`0TV`m09=]?P80TVhj0P2AKCT01@2BKSX0UG4m09Ea?@2HM400VWI200<0UG510P2FLT82
09Mc@`0309QdA02JMD40VgI20080VgI200D0VWE109Mb?P2DKc/0Tfhj095]?@03091/?080Sf/k0P2>
JSX01@2@Jd40SVTo08aW?@29I3X0Qf8h0080QV4g01L0Qf8h07mP<@1nGc40OEh`07aM<@1jFS40NETb
07QH<P1gEc40O5Ph07]G=@1iEC<0N5@`07QE;`1iERh0NeP^07aI;`1hG2X0O5h/07mQ;`23Hc80QV@d
08UU=@0208US=00@08iX@@2=J3h0S6Lm08aW>`2>JC`0T6`l09=_?@2ELCl0VWE009]f@@2MN4<0WgY5
0:9mB02TOdX0YX5<0:N2C@80Z8=?0P2YQ5000`2ZQE40ZhIB0:b7D`090:b7D`80[XUD0P2]R5<04P2/
Qe80ZhIA0:^6D@2ZQE00[8MB0:f8D`2^RE@0[hYE0:j9E02]R5<0ZhIA0:Z5D02[QTl0ZXE>0:V4C@2X
Pd`0Yh9;0:F0B@80Y7m800H0YX9>0:N3C`2WPdl0Z8A@0:V5D@2ZQU820:^7D`030:J3C@2UPT`0Y85;
0080Y85;00<0YX==0:R5C`2ZQe400P2VPDX0102TOdP0Xgi70:5lA@2ONT<209ii@P0309]g@`2LN4@0
WGU50080Wg]70`2PO4P309ag@`80VgI2102JMD4809Ud?`80WWU40P2MN4<03`2LMd80VgI109]f@@2J
MD00Wga409ej@P2LND<0VgM309]gA@2MNDT0Wg];0:1kCP2RODT0Xgi:0:AoB`020:F0C00>0:AoB`2S
OTX0XWe90:5nAP2PODD0WGY409]g@`2JMT@0VWI609]gA`2KMTT0WWY:09mkB`2QODd20:9nCP030:5m
C@2ONd/0WWY:0080WGQ400@0W7M309]f@P2JMD40VWE10P2IM4002`2MNDT0W7Q809YfAP2HM4@0Ug=3
09QdA02JMTH0VgM709Ye@02IM3l0Ug8m0080UW4l00<0V7<n09Ye@02KMT400`2EKd0[ooooo`00:_oo
ool80:5gA@@0XWI5102QMD@00`2MM400WWE10:1g@`030:9iA@030:1g@`2OMT80XgU700L0XgU70P2T
NdL20:ElB080YWe90P2WOTX0102TNTP0YG]90:EkB@2UNdT20:IlBP80Yge;0P2UNdT20:IlBP040:Mm
B`2XOT`0Z7i<0:UoC@P0Yge=0P2[OD`0102ZO4/0ZG]:0:QjB@2WNDP20:IhA`040:1kA`2ONTH0WWU5
09ag@`80VWE100T0V7<o09Mb?P2FLCd0UW1109E_@02DKSl0Tfdn099/?@2@JS/00P2?JCX01P2;IS`0
RVDk08UT>P28HcT0Qf8h08EP=P80Q5le0P23G3<00`22GC<0P5dc07mN<`0207mP=00907eP=01iFRh0
NEX^07YJ<@1jFS<0NETc07MF<`1eE340M5<b00<0LE0]0`1bDBh207=B;`0306i@;P1]Cbd0Jdd[0080
JT`Z00T0Jdd[06e?;@1^D2h0M5Hd07MF<`1hEc@0NUPc07aI<`1oFC800P21FS4208QR=@80Qf4d00`0
R68e08YT=`2=IcX0SfTl08mZ=P2@JcL0TF`h09=^>P2DKc/0UW4m09Mb?P2HLcl309A`@080UG510`2F
LT8209M]>`0309I/>P2EJcT0U6Xh0080TfTg00L0TVPf099]>02BKCT0TVdi099/>`2BK3d0Tfe00080
Tfa1202=IcX808aV=`03095[?02?JCX0SFLh0080RfDf00H0S6Hg08eW>02>J3T0RF<f08aV>@2AJch2
09A^@@03095[?P2<IST0RF<f0080R6Hf00<0RVHf08]U=P2=I3H00P2>HcH03P2?HcH0S6Dj08eV>`2?
JC`0T6Xk091Z>@2?JSH0SFPd08aW<P28HS40RF<b08]U=P2<IST0SFHk0P2<IC`00`2;I3/0RV<l08mY
>P0308mY>P80T6Xk0P2AJc`208mY>P0408iX>@2=IcP0RfDf08YT=@80RF<d0P2:ICP208UT=`<0R6<f
00<0Qf8e08QR<`28HS<01P28HS<02P28I3@0QV8b08EP<`24Gc<0Q5le08EO>028HSd0RF<n08MR>026
HCL308AO=@0308IQ=`28HcT0RF@j0080Q68d0P23HC<01`25HcD0R6Hh08]Y>`2=Jcd0SFTi08aX>02;
IcL00P2:ISH00`2<J3P0SVXj091/?00308e[?@0308aZ?02;JC/0RVPj0080RVPj00<0RfXd08a[=@2>
KCL00P2?KSP00`2>KCL0S6/e08]Z=00208M[?00308M[>`27JcT0Qf`g0080Qf`e01X0Qfdd08ma?`2=
Kcd0RV`j08QZ>027JCL0R6Xh08U[>@2:K3X0QFDb08AT<@23IC<0OV8b07YO<01dG2h0L5PZ06eF:P1W
Dc80IE4`065>;P1KBR`0EdHZ0592:01>@2D0CClU04`h7`80BSPP00d0AcLP04<d7`0l;a`0=b`J03@Y
5`0c;Ad0<BhM030]7P0^;1l0:b/O02X/8@0X:b00:2/R00<09RTP0P0U:1l302@W7P808B@K0P0R9A`2
02<V7@8092LN0P0U9a`402HX7@<09bTN0`0Q91/2020S6P<07b8I00P08B<N028T7`0U9R009bLO02/X
7`0^:Ql0;b/P038/8080<34Q00H0<c8P03Db8@0h<b00>SDQ03`f800m=b4203lc6@@0@3@J0P11=A/0
2`18=Qh0A3@M03`_700c:QT0;2PL02LX800U:R@09B/W03P`7@0i<Ah0>S8O0080>c<P0`0l=2400`0e
<Ql0<c0M034^6`0202l/6@03030]6P0a;Q/0<c0M00P0:R/M00P09bTN02DW700S9AX08R@I024S600R
91T08bDJ02@V6`809bPP00@09RLO02@U7@0S91`08B8J0P0P8AT00`0Q8b807b4P01hP7`0201`N7@0M
01dO7P0N81l07b4P02@T600V91L0:bPG03L`7P15>RH0CChW04`l8`19>1h0ES<M05@b6@1O?Ql0MeL`
08MX>P29JcD0SW4g09Ij>`2ZN3/0Zh9>09=jD@1UFCl0?C`Z02`^8@0Y:b009bLK02@V8`0U9b@00`0W
:BH0100U9b@08bDR028T8@0U9BD202DU8`0302HW8P0V9b409bPP00809bTN0`0W:28202HW8@<09BHP
00P08R@O02@V8@0X:B<0;BdU038_9P0e<BH0=S8W03Tc9`@0=C@P1@0f=B42034_8003034_8P0a;b<0
<2dT0080<2dV01d0<2dX02/]800_;b<0<C8T038`8@0a;Qd0=2lL03/d8P10>BH0Ac/_04Pj;@18>bX0
C3dV04m08`1B@R40EdDQ05Q6801OAB@0GTHT05e49@1J@b@0Ed8U05A18`1@?b<0CchR04`k8@1>?B<0
D3lU05919`0205A3:@80Dd8X0P1?@bT01P1@A2X0DDD[04m3:@1=@BL0BShT04Pl8P80CChW00H0CclV
05509P1B@BD0ED8T05Q3901IA2D305E69@80E4DT0`1CA2<00`1GABd0ET@/05A2:P0205=1:@0I05A2
:P1E@b/0ET@/05A39`1G@bP0FDHX05i9:P1SC2`0Idl]06Y@;`1/DRl0JTd]06]>;01^DBl0LED`07=G
<01dF300M5T^07=H;@1dE2d0N5P_07eN<P23I3D0QfTe08Y]=@0208]^=00807mV;@22JC40N64]06I@
8@1OBB00HDdZ061;;01GA2H20696;P030697;01QART0HDHX0080H4HU00<0H4HS05Q9:01IBRT00P1J
BbX02P1IBRT0EdPW05E69@1CA2<0Ad0S04Q1901:@bH0C4DX04e6:@1?B2/20519;00505M8:`1IBRd0
GTd_06=@<01VDS400P1XDBl03`1XD2`0K4la06iA<@1_EC80LEXa07=N<`1bH300Lf4_079R;P1_HC00
L6@d07=V>@1dJC/0Lf/m079[?`0206mZ@0D0M6Dj101eIS/0601oJSl0P6]008=/@025KCl0Qf`m08M[
>`27JCL0QVPf08IR<P2:IS@0TVdh09Yc>P2OMcT0XGTd09mg;`2PMR`0TW8e09=c>02DM3/0U7<m09Ac
@02BL480T6i108m/@P80S6dg01h0SF`g08m[=`2>JCD0SVHc08]S<02;HBl0Rel`08aN;@2;GB`0S5`[
091N:`2FHbh0W6La0:1[=@2/MC@0[GHe0:mh=@2aO3H0]H0j0;Z6?@2mRCh0_h]00;bBAP2kTDD0^8i2
0;N=@@2hST80_9960<2FBP33VDd20;ZHF@80^IMH0P2hUUL20;NEEP0E0;2BE02_TE<0[HmA0:^=C`2X
RT`0YXQ:0:B6B02SQDL0WXE?0:66C`2UQe40YXUA0:N8C`2WQd`0YhE80:F3AP2_QDT0Zh550:Il@02P
MSX0W78f00<0VW0d00H0Vfln09ea@02PM4<0XgM60:EiB02VNTT20:EiB00;09ifA@2MMD80W79009aa
?P2NL3`0Wg0j0:5b>P2SLSX0WG8k09aa>P2KL3T00P2JKcP02@2LLCX0WG8k09md?@2QN400XWU10:Ak
@`2VODD0Ygi60:ImA@020:ElA0030:5m@`2ROT@0Y8160080Y81600<0XWi409mk@@2NNT000`2TO3h4
0:Em?`070:In@02OMcT0WWHh09ad=P2KLcD0VG4c09M_<@0209E];`0909AY?02@ICP0T6Dh08eR=@2@
ICP0UFXm09Q]@02EJSd0TFHi0080SFPa1P2<Ic009@2?KBh0Rf/^08QX:`25Ib/0Q6L]08=Y<024Jc<0
QVde08EX;026JBd0QfX`08MZ<P26JC40Q6H`089T<020HRh0Of0a07eN;`1jFb`0NEX[07YK;01mGRl0
P64b08=T=@1mGQd0PV<S08UY;02<K3<0RfXe08MU=@22H380OU`_08AY>P25JS/0QF/j08E[>026KCL0
0P27KSH01027KSD0RFdk08IZ>023IcD207mS<@0;081T<P23IcD0QFTg08e`>02>LCT0T7<k095d?02B
MCd0TG@l091c>`2?LSX0202;LCP208Qc?00408Mb>`26LCX0QW4j08E`>@80Q6lh0P2<LST01P2;LCP0
RW0g08Q^=@27KC@0QV`c08E[<P80QF`d00<0Q6/c08=Z<P22JC400P21J3002P20Ibl0O6L^07]U;01i
HbX0NV4Y07eR:`23IBl0R6Tc08]/=P2IO4@209UkA@0C09YlB02OPDl0ZHYK0;BEI`2lWFl0^img0;^P
M@2hWG00/YQW0:N>F02HOdH0Rg<g089Z;01jGc80N5d`07EJ;`1bEb`0Ke<[06iB:`0206eA;00B06QA
9@1WD2H0IDhT06=<8`1QBB<0GTHR05e58`1LA280E4DT05=48`1B@b@0D44T04dm8`1;>b80BCTP04Ph
8@15>QX0ACXL0P14>A/00`13>1`0@SHL044e7@02040d7P0803T/700d:1P0;B<G02HO5@0P7A@071dG
01`N6`0K81`:01/K6@806QXH0`0I6AL00`0H61H071`J01`L6P0301/K6@<06QXH200I6aP801PH5PP0
6A/H200H61H201HH5@805aTF100H6QL201/K6@806QXH0`0I6AL00`0H61H06QXH01XJ600601XJ60P0
71dG0`0P81P3024Q6@808R8J200U81X202HR6@809B4H00D09R8I02TU700[9ah0;2PO03<W6`03038V
6P0503@X700g:al0>RhR03``900n<QX00P0m<AT01`0m<A/0?2lL03/^7@0k;Qd0>bhN03``800k;al0
0`0i;Ad00`0k;al0?S8R03lc8`0903X]6P80>B`L00<0>B`K03X]6P0j;QP00P0k;aL0100k;aD0=bXI
03LZ6@0g:QT203HY60<0=BPG00P0>2/J03T/6`0j;A`0>bhM03`_7P0m<1l0?S4P03lb8@P0?bhL0P16
=Qd03P18=Qh0BcLO04`f7`1?=R00D3LQ054f8@1@=Ql0DCLP058j8P1A>b<0D3`S04`k8@1:>Al0B3PN
0P1??1h0101@>ah0DSXN05<i7P1C>Ah205@i7P08058m801C?R40DchQ05<n8@1A?1l0CSTL04/f6@1:
=AP805<i7P<0DcTP0P1D>R4305Dk8P0805Lg7P1K?200GSlS05ho8P1L?Ah0G3hL06127P1SAB4206U=
:00906U;9`1ZBBH0JDLT06U58`1XA280JT<R06Y9:01/BbX0KD`[0080KTd/00/0KD`[06a;:P1ZBBP0
MDlX07I@:@1hDR/0NU@]07]E;P1jE2d0N58[07MA:P0207M@:@0>07I@:@1dDBT0Le8Y079B:@1aDBP0
Ke8X07UA;@1hD2`0MThZ07E=:@1dC2P0MDdY07I>:P1gCb/307A@;080Ldl[0`1bCRX207MA;@0307MA
;01hDR/0N5<Y0080N5<W00@0N5<V07E@9P1eD2H0ME0V101fDBL207MB:080Mdl[00<0N50/07UA;@1j
DRh00P1kDbl0101lE300Ne@]07]D;@1kE2d207aE;P<0OEH_0`1jE2d207]E;P<0O5H_00H0NE<^07YD
;`1kEBh0O5L]07eH;01nFB`207mK:`@0N58]101iDbh0201jF2X0NeT[07eK;@1nG2h0Oed_07iL;P1m
Fbd0O5X/0P1nG2h00`1oGBl0P5h`085O<@02089P<P0708=Q<`20GST0P5hh081O=P20Gc80PF4`085Q
;P02085R:`0;08QS=P26HC@0Q5lb08=N<@22GC00Peha08EP<`26HC@0P5/^085L;`23GS400P24Gc80
1023GS40PE`_081K;P20GCD2085N=003085O<P22H380PV0`0080Pf8_2026HC@308AN=`80QElh0`26
H3T01P27Hc<0R6@d08QT=029ICD0RVHf08]W=`80S6Ph00H0R6@`08UU<@29IC40RVHb08aX=02=JCD2
08iZ=P0;08UU=@2:ISH0S6Ph08eY>@2>JSX0SFTi08aX>02;IcL0S6Lj08eX>`2?JSd00P2@Jch00`2?
JSd0SFPk08aW>P0208eV>`0;08iX>`2?JCX0T6Xi095/>02BKCT0Tfhi08iY=@2@JcL0Tfhj09Ia?@2H
Lcl00P2IM400202JMD40VGA009Ic?@2FLSh0Ug<o09Mc@@2HM4@0V7=60P2IM4P0202JMDT0VgI:09eh
C02NNDd0WGQ<09agB`2JMDT0V7=70P2EL4@00`2DKd80Tflo099^?002095]>@0?091]=`2>J3/0SfTl
091Z?@2AJch0T6Xm08iX>`2;ICP0RF<f08AT=@22HC@0Oeha07aK<01jFC00NELa0080NELb00<0OUPa
07eG<01kEBh00P1iDb`0301jE2d0NeD^07aF;`24H300QF4a08MS<`29ICD0RfLg08eY>@2?Jc/0T6`l
095/>0<0T6/g01L0Tfhj09Ia?@2IM400W7M309Mc?`2IMD40VgM309mkA`2ROTX0YX9>0:R4D02YQE40
ZXIF0:^7E`2/R5P0[HUI0:j:FP2_Re/0/8aL0;6=G@2/R5@0[HUE0:n;E`020;2<F0030:n;E`2]RED0
[8QD00P0[HUE00T0/HaG0:n:E@2/Qe80ZXE@0:V4C`2[QU40[HQC0:j9E02ZQE400`2YQ5020:R3C`80
Yh9>00H0ZhEH0:Z4E@2ZQ5D0ZXAC0:Z5D@2ZQE020:Z5CP<0Z8=>1@2YQ4l20:J1BP090:F0B`2TOd/0
Xge<0:9lB`2RO4d0XG]<09ag@P2MN4<0WgY50080X7]600<0WgY509eh@`2LMd80102MN4<209ag@P<0
VgI10100XWe609ii@P2JMCh0UW4j09E`>@2GLS/0VWDn09eh@@2GM3`0VWLo09ej@P2PODD0XGi609ml
A02LND40VWLo202NNTH20:1lB080XGe90`2ROTX01P2SOd/0XGa50:5lA@2QO4L0X7]70:1jB@80WgU:
00@0WgU<0:=nBP2TOd/0YH1<0P2VPDd01P2TOd/0XWe90:1kA`2KMT80WGQ409mjAP80X7]700/0WWU5
09ag@`2KMT80VGA009]f@P2MN4@0WWU509mjAP2NNDD0W7M309]f@P0209mf@P0409ie@@2MM400Vg8n
09Ya?@80VG0l0`2HKS`[ooooo`00:_ooool80:5gA@<0XgM600<0XWI50:5eA02PM4<00P2PM4<00`2N
MD40WgI20:5hA0020:=jAP030:9iA@2QN4@0X7M300P0XgU70P2TNdL20:ElB080YWe90P2WOTX40:Ek
B@80YWa:0P2WOD/00`2UNdT0YWa:0:IlBP020:MmB`80Z7i<00<0ZGm=0:MmC@2WODd01P2WODd20:]m
C0040:YlB`2YNdX0Z7Y90:MiB080YWQ70P2NNDD01@2MN4@0W7M309Ye@@2JMD40VGA00080V7<o00H0
UW1109E_@02DKSl0Tfdn099/?@2@JS/208mY>P80RfHl00@0RVDk08QS>@27HSP0QF0f0P24GcD208=L
<`0>089M<`20GC<0Oehc07iO<`1oH3@0OF0d07UJ;P1jFbl0NUXa07YJ<`1jFS@0N5Ld07ED<@1dDc87
079A;P04075@;@1^D2h0KDl]06a>;080Jdd[00/0K4h/06e?;@1^D2h0M5Hd07MF<`1hEc@0NUPc07aI
<`1oFC80PEXa089K<P0208MQ=00>08IP<`27HC@0RF<f08]U>02>J3/0T6Xm08mZ=P2@JcL0TF`h09=^
>P2DKc/0UW4m09Mb?P2HLcl309A`@080UG510`2FLT8209Q^?00309M]>`2FK3X0UF/i0080U6Xh00L0
TfTg099]>02BKCT0TVdi099/>`2BK3d0TV`o0080TV]0202=IcX808aV=`03091Z>`2?JCX0SFLh0080
RfDf00H0S6Hg08eW>02>J3T0RfDh08eW>P2?JC`2095[?P0308mY?02=IcX0RfDh0080R6Hf00<0RVHf
08]U=P2=I3H00P2>HcH03P2?HcH0Rf@i08aU>P2=IcX0SVPi08iX=`2=J3@0S6Lc08]V<@28HS40RF<b
08]U=P2=IcX0SFHk0P2<IC`00`2;I3/0RV<l08iX>@0308mY>P80T6Xk0P2AJc`01@2?JCX0SVPi08iX
>@2=IcP0RfDf0080RV@e00<0RF<d08YU>02:ICP00P29I3L408QS=PP0R68c00/0Qf<c08IR<P25H3<0
Q5lc08AO=@25GcP0Qf4l08QR?@27HSP0QV4g08EP=P0208AO=@0308IQ=`28HcT0RF@j0080Q68d00h0
Pf4c08AR=025HcD0R6Hh08]Y>`2<JS`0SFTi08aX>02;IcL0RVHf08]W=`2<J3P0SVXj08m[>`80SF/m
0P2<JS`208]Y>`80RVPj00<0RfXe08a[=P2>KCP00P2?KST00`2>KCP0S6/f08]Z=@0208Y[?@0308Y[
?02:K3X0RV`h0080RV`f00D0RVde08e_?@2<KS`0RV`j08QZ>00208MY=`80R6Xh0100Q6@a08AT<`22
I380OV8b07YO<01dG2h0L5P/06aE:@1VDS40I50_065>;P1KBR`0EdHZ0592:01>@2D0CClU0P1:>200
3P18>240ACHO040d7P0l;a`0=b`J03@Y5`0c;Ad0<BhM030]7P0^;1l0:b/O02T[800X:b009bXQ0P0V
:B0302DX7`<092LN0P0Q91/2028U70808bHM0P0T9ah902HX7@<08B@K0`0P8aX201lR6@08028T7`0R
9Ah09BHP02PX800[:1l0;RXO030/800b;20202l`8006038a7`0e<Ql0>3<O03Xd7P0l=R00?CDN1010
=1X4044e6`0804De7011<Q/0>RdJ038[6@0]:Ad0:BTO02T/9@0X;BL303Ta7P0303Xb7`0k<b00>c<P
0080?3@Q00P0=C8O03<`7@0a;Q/0<2dJ02l/6@0`;AX0<BhK038_70P0:R/M00<09bTN02DW700T9Q/0
0`0R91T0200S9AX092HK02LX800V9al09BHN02@U7@0S91`08B8J0P0P8AT00`0P8Ql07b4N01dO7003
01`N6`0S01hP7@0O8Ah09BHH02PV5`0]:QT0>C8O04Dj901;?2D0BCTO04He6@1E<aX0F3HK06M69@1m
GCH0RFXk08]]=`2@LcT0VGdn0:Yl@02TOd/0R71:05aB=`0j>2T0;2hS02T[800W9a/092HS02DW900V
:2D09bTV02HX9@0U9b@08bDR028T8@0U9BD00P0U9B<00`0V9b809RLQ02LX800202LY7P<09bPR0P0V
9b4302DV800802@V8@0U9b809bPR02/[8`0`;B@0=30U03Lc:00j=2P203Th900403Pg8`0f=B40=C@P
03<b7P<0<S4M00H0<S4O038`8@0b<240<BlR034_8`0a;RD2030]9P0L02`^8@0`<2@0<S<U03<a8P0b
;ah0=C0M03/d8P10>BH0ACT[04Lj:P1:?BX0CSlX0592:01DA2<0F4DT05Q68P1NAR@0GDDS05]4901J
@b@0ET4T05A09@1@?b<0D3lU04hm8`1??R@0DD0V05=2:080ED@Z00@0E4<Y05=2:01?@bT0Cd<Y0P1@
A2X0101?@bT0CD4W04/o9@19?B<204`m9P0404hn9@1A@2H0Dd8V05I39@80FD@U00@0ETLV05E69@1E
ARD0EDHU0P1DAB@205=48`0F05I4;01D@RX0Dd4Y0590:01A?bL0DT0X05A2:P1E@b/0Dd8V05I29`1H
ABL0GDPY069;:`1VCR`0JDl^06]A;P1ZCB/0K4l]06mC;P1bERl0M5P`07EI<@80M5T^00H0NET`07]K
<P1oH3@0Pf@e08IX=P27JC<208MZ<P0808I]=@24KCL0NV<a06M@901NB240Gd/X05i;:`1G@bP205m3
:`0305m4:@1OA2L0GT<U0080GT@S00l0GT@Q05M89`1HBBP0F4TX05U::@1HBBP0ETLV05=48`1B@b80
B44T04U29@1:@bH0C4DX04e6:@1?B2/00P1@BB`01@1HBB`0FDX]05e<;P1RCbl0IE4`0080J54_00l0
J50/06e@<P1]Dc80L5Hc07=K=@1eH3D0MF<e07AT<`1dI340Kf4b06mR=@1aI3L0LVLj075X?@1`JCl0
0P1]J40507=T>@@0M6Dj0100NfHk07aW?01oJ3`0PVXl08EZ>`25JCT0QVPf08EW=@27Hc<0RVHd091[
=P2GL3L0W7@f09ef<`2NMS00WGD]0P2ALCH01`2BLST0Tg8m099a?P2AKd40Sfe008e[?P2<KCL00P2>
KCP07@2@K3P0T6/g08mW=02>I380SF<a08eQ<02>H2l0SEl]08mP;02CHB`0VFH_09mZ=02RKSD0[WLd
0:ii=@2aO3P0]H0j0;N5?P2kRD00_Xa30<2>A@2nU4X0_9980;Z@AP2hST@0^Hm50;bBB030UT`0`YQ>
0080^IMH00@0^9IG0;NEEP2fU5D0]I=D0P2dTU<05P2bU5H0/I=E0:nAD`2]Se40Zhe?0:R:C02WRD/0
YXQ:0:25CP2RQ4h0XhI>0:F6C@2UQDX0YhE80:N3A`2VPT@0[HA60:^2A02XOd40Y7/m0:5h>P2OMSP2
09ed=P0609me>`2QMcd0Y7Y00:Il@P2XOT@0ZGm50P2XOT@02`2RNTL0X7Q509mf@P2OM3l0X7<l0:5b
>P2RLc/0YG@j09id>P2MLcT0W78h0080Vg4g00H0W78h09id>P2OMC/0XWXo0:=k@02UOD830:MoA004
0:In@`2UOD80XGe30:9nA080Xgm500@0XWi40:5m@`2NNT00WGTo0`2RNS`00`2SNcd0Y7`n0:Em?`02
0:Em?`090:=k?@2RNS`0XGTk09mg>@2MMCL0W7@f09]c=@2JLS@0UVdi0080TfXf00H0T6Lc09=Z=P2G
KSX0VG0l09M^>P2DJcL308iY<P<0SFPa0P2<Ic001P2AKc00SVha08e]<02:K300RF`b08M]=080Qfhf
01P0QFP/08IY;@27JS00QfXb08IY<@24IS00PV@`081R;P1oH340OEh_07]L;@1iFR/0NU//07eN;`20
HC80PV<d07mP8022HRD0R6P]08e]=02?KST0RfXg08=Q<@1mFbd2089W>00A08=Y>024JSL0QF`f08I]
=@27KSH0Qfhe08Q/>P25JCL0PVHd07mS<@1nHS00P6@b08=W=@25JCL0SG0h08ia>@2@Lc/00`2BMCd2
091c>`P0S78i0P29LS`208Qa>`80Qg0j0P26KcT01P2=LcX0S78i08]a>02:L3L0RFlf08M]=080QV`c
0P25K3@01024Jc<0PfXb089Y<@22JC42085X<00@07aW;P1kIB`0NF<Z07]R:P1mHR/0PfD_08QY<`2;
K3H0UWU109YlAP2LOTP0WGm;09j0CP2UQUL0/I9T0;^LKP80_:1h01@0^j1c0;FKJP2ZTE/0W8=;08if
>P26KS80O64b07YO<P1gG2l0LeP]06mC:`1]DBX0KE4/06a@:`1YDRH0J54W06I?9@1TCB@0HDTS05m7
8`80GDDS00X0EDLT05A5901B@b80D44R04ho8P1;>b40BSXQ04Ti8015>QX0ACXL0P14>A/03@13>1`0
@SHL044e7@11=Al0@3@N03T/700e:AT0;R@H02LP5P0P7A@07AhH01`N6`0K81`02P0K6aT201XJ60@0
6ATG0P0L71X301/K6@<06QXH200I6aP801PH5PP06A/H200H61H201HH5@805aTF0`0H6QL00`0I6aP0
6a/I01/K6@0201XJ60@06ATG200J6QP801`M5`<0820H0`0Q8AT2028R6PP09B0J0P0V8QT202DQ6005
02HR6@0X91/0:bLN02`X7`0c9a/00`0b9QX0100d:1`0=b/O03T]8@0k;b<203da6@0>03da6`0l<1X0
?2lL03`_700l;ah0>bhM03d`800l;al0>bhN03X]7@0k;Qh0?C0P03lb8P10<b<903X]6P80>B`L00<0
>RdL03X]6P0k;aT00P0k;aL00`0l<1H0>2/J03P[6P0203LZ6@<0=RTH00T0=BPG03P[6P0h:aX0>B`K
03X]700k;Qd0?2lN03d`7`0n<B00200o;Q`204Hf7@0>04Pf7P1;=al0C3HO04lf801@=b40DCHQ050f
7`1B>240DSXR05<k8`1A>b<0CSXQ04/j801:>Al204ll7P03050k7P1B>Qh0DcTN0080E3TN00T0ESPN
05<n8@1C?R40E3lR05<n8@1B?B00CcXM04`g6P1;=QT0201C>Ah0101C>B00E3XQ05@j8@1D>R4205Dk
8P80ES`S00d0EcLN05/l801O@2@0Gd0S05dn7`1M?ad0H48N06A68P1XC2L0Id/V06Q:9P1YB2D0JTPU
0080JTHT00@0K4DT06a;:01]C2T0KTdZ0P1_CR/01P1^CBX0KD`Y06a;:01eCbP0MU0Y07QB:`<0NU@]
0P1hDR/207QA:P0307MA:P1dDBT0Le8Y0080LU8Y00X0Ke8X07Q@;01gCb/0MDdY07A<:01cBbL0M4`X
07E=:@1fCRX0M50/0`1cCb/2079>:P80LDdY0P1fD2`01`1fD2/0Me4Z07MB:01gDRH0N5<W07QC9P1d
CbD00P1eD2H0101fDBL0Me8X07MB:01gDRP207QC:@0607M?:`1hD2`0NE4]07UA;@1jDRh0Ne<_0P1l
E300101kE2/0O5D/07aE;01lEB`207eF;@80OUL^0P1jEB/207]F;0<0O5L]00L0OEP^07iH<`1nF3<0
OUPa07eH;P1mF2`0O5LZ0080O5PX101iDbh407YD;`0307YH:P1lFR`0OE/]00<0Oed_00@0OU`^07eK
;@1nG2h0Oed_0P20GS003`21Gc40PV0b08=Q<`23HC<0PEli085P=`21H3D0PF0c085Q<021HBh0PF8/
085R:`28HcH0QV4d08EP<`0208=N<@0608AO<P26HC@0Qf8e08AO<P25H3<0Qf8e0P28HcH01027HSD0
QF0c08AO<P21GSH2085N=003089P<`22H380Pf4a0080Pf8_0P25H3<208IQ=080Qf8e0P28HcH308EP
=P80QV4g0`27HSP208QT=00308UU=@2:ISH0RfLg0080S6Ph00<0SFTi08YV<P2;Ic<00P2;Ic<208aX
=080SFTe00<0R6@d08UU=@2;IcL00`2=JCT208]W=`0308aW>P2=J3/0SVTl0080SfXm0100SVTl08eX
>`2<IcX0S6Dj08eV>`2>J3/0SfTj091Z>@2BKCT0Tfhj09=^>@2AK3P0TVdi09A_>`2FLCd0Ug8n0P2F
LCd0202EL3`0U6lk09Ic?@2FLSh0Ug<o09Mc@@2HM4@0V7=60P2IM4P00`2JMDT0VgI:09ehC00209ii
C@0309agB`2KMTX0VGA80080UW5500<0UG1309A`@02CKcd00P2BKSX00`2AKSP0SVPi08mY>P02091Z
>`0908mY>P2=IcP0RfDf08US=026ISL0Q6@e085P<`1nGC80O5/b0080NeTc00@0NeTd085L<P20Fc40
OeX`0P1nFBl02`1oFS00PE`b089M<`25HC40QV8b08QT=02:ISH0SFTi08m[>`2AKCd0TVhn00<0TVdi
00d0Tfhj09E`?02HLcl0VgI209ehA02JMT80VgM309eiA@2PO4P0Xgm;0:J2CP2XQ500ZHEA0080ZXIF
00<0ZhMG0:b8F02]RET00P2_Re/0102`S5`0[HUE0:j:EP2_ReL20;2<F0030:n;E`2^RUH0[HUE00P0
[HUE00<0/8]F0:n:E@2^RE@00`2/Qe820:f8D`<0ZhIB0P2ZQE430:V4D0080:^5F02[QEH0ZhEF0:Z4
D`2ZQE40ZXE@0:Z5CP2YQ4d40:R3CP@0ZHA?00/0YX980:J1BP2UP4T0Y7m:0:=nBP2RO4/0XWa=0:5k
C02MN4<0WWU40:1kAP020:5lA`040:1kAP2NND@0WGQ309iiA0<0WGQ30P2LMd8309]f@@0@09mj@`2M
N440VWDn09Mb>`2FLCX0Ug8k09Ud?@2JMCh0UW<k09Uf?P2MNT80X7e50:5nAP2PODD0WGY209]h@0P0
WWY600@0Xgm;0:B0C02TP4`0Y81<0P2UPDd20:J2CP80XWe600<0XGa70:5lB02PNTT00P2PNT/0402O
ND`0Xgi:0:AoB`2UP4`0YX5=0:F0C02TOd/0XWe90:5lB02MN4@0WWU509mjAP2PNdL0WgY609iiA@2L
Md<209Ye@@0709]f@P2MN4@0WWU509iiA@2MN4@0W7M309]f@P0209ed@00409ac?`2KLSh0Vg8n09Ya
?@80VG0l0`2HKS`[ooooo`00:_ooool80:5gA@0;0:EiB02TN4L0XgM60:9fA@2QMD@0X7A309mc@P2N
LT40X7M30:5hA02RNDD00`2TNdL00`2SNTH0XWU50:AjB0070:AjB080Y7]70P2UO4P20:ImB@80Ygi:
0`2UNdT20:IlBP<0Yge;0P2VO4X20:MmB`@0Z7i<202WOD/20:UmC0040:QlB`2WNdX0YWY90:EiB080
Y7Q70`2LMd<309]f@P<0VWE100H0UW1109E_@02DKSl0Tfdn099/?@2@JS/208mY>P80RfHl00H0RVDk
08UT>P27HSP0QV4g08EP=P24GcD208=L<`03089M<`20GC<0Oehc0080OUlc00T0O5lc07UJ;P1jFbl0
Ne/b07]K=01jFS@0N5Ld07IE<P1dDc800P1dDc00101cDRl0LU4^075@;@1aD2d2071?;00306mA;`1^
D2h0K4h/0080Jdd[00/0K4h/06i@;P1_DBl0M5Hd07MF<`1hEc@0NUPc07eJ=020FS<0PU/b08=L<`03
08IP<`0=08QR=@2:I3L0SFLj08mY?02AJch0T6/g095/>02BKCT0Tfhj09A_>`2EL3`0UW4m09Mb?P03
09A`@080UG510`2FLT801P2JL3h0VFlm09U_?@2HKS`0Ufdk09I/>P80UF/i00H0TVdh099]>@2BKCT0
TV`k099/?@2BK3l2099[@0P0SFLj202<ISL0102?JCX0SVPi08eW>02<ISL208]U=P0308aV=`2=IcP0
SFLj00L0SFLj0P28ISH00`2:ISH0RfDf08eT=P0208iS=P0>08mS=P29HSL0RV<h08]U>02<ISL0S6He
08]V<P2:IC40RF@_08QR<@2:I3<0RfDf08eW>P2=IS/208eV?@0308aU?02;I3d0SVPi0080SVPi0P2?
JCX3091Z>`80SVPi00@0SFLh08aV=`2<ISL0RfDf0P2:I3D308YU>080RF@g0`28HcH808US=080Qf<c
00L0QV4d08EP=025H3H0QElh08IP>`27HC`0QV4g0080QF0f00<0Q5le08EP=P26HCL00P28HcT308AR
=00508ES=@26I3H0R6Hh08YX>P2;JC/00P2<IcX308]V>@0408aW>P2>JC`0SfXm08e[?@<0S6Xl0`2;
JC/0102:J3X0RfXe08a[=P2=K3L208i]>00308e/=`2<JcH0RfXe0080S6do00<0S6dn08a^?02<KSX0
0P2<KSP01@2<KcL0Rfdk08Y/>P28JSP0QfTg00@0QVPf0P24I3<07`22Hc@0OV8c07YO<P1cFbl0KeH]
06aE:`1UDC00Hdl^061=;@1JBB/0ETDY0592:01>@2D0CClU04/i8@19>B80B3PQ04@e800o<Ql0>RlM
03D/6`0c:QT0<bdM030]700`;Ah0;R`O02/[7`0Y:b009bXO02LZ8@0V:B000`0U:1l202@W7P808bHM
0P0Q91/2028U70808bHM0P0T9ah902HX7@808RDL0P0Q91/3020S6P0A01lR6@0R9Ah08bHO02DV7P0X
:1h0;2XN02l[7`0`;Ah0<bdO030_7@0a<1h0<c0M03Lb7P0i<Ql0>c<N03`d7@0n<ad02011=A/02010
<A`0>blI03L/6P0a:QX0;BTM02/[8@0/;BD0;C0Y100i<Ah203Xb7`0503/c800l=240=34N03<`7@0b
;a`00`0`;AX00`0a;Q/0<RlL02X[7@0702X[7@0C02LY7P0V:1d092HK02<U6P0R91T08bDJ02@V6`0U
9a`09bPP02HW7`0U9Qh092DM028S6`0Q8QX0824I01lP600N81d07AlL01`N6`0201/M6P0M01`N6`0M
7a`07b4N02PV5`0[:1T0<bhK03`d8@16>R@0BSXQ04Lf7015<AH0EC<G060o801dDc00QfLn08i_@02>
L3X0U7Lm09j1A@2[P4T0V7I607AP?@1<A2d0<S<U02/^8`0Z;2409RHL02@V8`0U9b@00P0V:2D01@0U
9b@092HS02<U8P0R92409BDU00809BDS00<09RLR02HW8@0W:2000P0W:Ah302LX8P809RLQ0`0U9R00
3`0W:B@09RPS02HW8@0X:200;BXQ038^8`0g<bP0?3HZ03dj9`0l>BH0>SLT03Pe8P0e<Ql0<c0M034^
6`02030]6P0503Db8@0d<B00=34R03<_8`0c;b@00P0b;RD07@0b;BL0;BlR034a9@0c=2H0=38S03<`
7`0f<Ah0?3DS040i9P13=bL0AcXY04/n:`1B@b`0EDD[05M6:01HABD0F4DT05e49@1KA2@0FT<T05I1
901D@2D0DD0V04lo9@1??bH0D3lU05509P1C@RP0ED@Z0080ETD[00D0ED@Z05A3:@1?@bT0Cd<Y0514
:P0204m3:@0904e19`1;?bD0BShT04Xk901;?2D0CShU05919`1D@bL0F4DW0080FTDV0`1FAbP205E6
9`<0E4DV00<0Dd4Y0590:01@?RH00P1??BD04@1@?RH0DT0X05=1:@1A@2@0ED4V05M49P1KARL0H4TY
06E=:`1XCRd0JDl/06a?;@1^DRd0LED`07AH<@1fFS80MU/`0080MU/^00H0OF0f07iQ=@20HcL0PVHg
08=W=`24J3H208AY=00808ig@@2:Lcl0NfDd06QC:01LB2<0FdPX05a8;@1FAB/205a2:@0605a29`1L
@bD0G4<T05a48P1MAB<0GDDQ101FAbP0101EARL0E4DV0593901A@R<304a39P0K04e49`1?ART0D4LZ
0599;01CBRd0F4T/05U:;@1MC2h0HDh^06A@;`1WD2h0J54_06UA;@1]Dc80KeDd079J=P1eGcP0MV<i
07MV>P1gISP0MVPi06iO=01^HCD0Kf8h06mS>`1^IC`0K6@m0080JF@n0`1`HCP2075R>@80LV<j0P1c
I3/01P1eH3D0MV4f07YS=`1mICL0PFHg08=W=`80QFLe01L0QfHc08UX=@2=JS@0TFdc09I`<P2ILS40
VW<`09ad;`2>KSD0Sflf091_>@2AL3/0T6ll08m]?@2=Jcd0S6Xl08i]=`2?KSP0TVli09=^>@2DK3P0
TfXf095X=002095V<`80TV@`0100U6D_09UX<02NJc80Y70f0:Mc>@2aNcD0/ghh0;J1>`2iQd00_8a4
0;j?A`2nTTT0_i=:0;jFCP2lU4`0^I590P2hT4P00`2jTTX0_9A<0;jFCP020;RFE`0D0;JDE@2eTe@0
/i5B0;6?D02`STl0[he>0;BDE`2cTeH0/I5D0:n?DP2/S4l0ZXY=0:R8B`2WQdX0XhA=0:>4B`2SPdX0
Y8570:B2A@2UPD<20:R2@`80[8=500X0Zh940:Z1@`2XOd40YWdo0:=j?02RNC/0YWhi0:Mo>P2ZPSd0
[8@o0`2]QD006@2/Q3l0Ygm;0:IoB02TNdD0XgQ10:Ag?P2UMc`0YGLk0:Qg?02PMSX0WgDi09id>02M
LcL0W78f09ec=`2OMCT0X7Hj0:Al?`2UOD00Ygm20:R0@`2YPD@0Z8130:Mo@P2VOT400P2QOD420:9n
@P090:5m@@2ONcl0WGTm09ah?02NMSP0WgLi0:1h>P2QNC/0XWXl0080Y7`n00L0YGdo0:In@02VOT00
YGdo0:Al?P2RNS`0XGTk0080X7Pj00T0VW8d09M_<@2GKc40UVh`09M_<@2JLS@0W7@f09Yb=02HL380
0`2@Jc@208mZ<`80SVTb00T0SFPa095_<02@L3<0T70c091b=P2>LCL0Rg4h08U`>028KcL00P26JBd0
2@27JS00QfXb08IY<@24IS00PV@`085S;`20HC80OUl`07]L;@0207YK;00S07eN;`20HC80PV<d085Q
9022HRL0QfL^08m_=P2DLch0TG0k08MV<`1mFb/0OV<d07mT=@20ISD0PVPe08A[=@25K3@0Qfhf08M^
=@26JSP0Q6Pf085U<`1oHc40OV8`081T<P22IS@0Q6Pf08ia>@2?LSX0TG@l099e?@2CMSh0TWDm095d
?02@Lc/0202<LST308]b>P<0RW4i0P29L3P208id>`0408ec>P2;LCP0RW0g08Q^=@80Qfdd00H0QVde
08E/=025K3@0Q6/c08=Z<P22JC42085X<00b07aW;P1lIRd0NV@[07aS:`1nHb`0PfD_08QY<`2:JcD0
TWDm09YlAP2QPdd0X89>09]mB`2OP540[8eO0;VJK02mXGX0_Z9j0;jSN02iWVl0/9IS0::9D@2EO4<0
SGDi085W=P1nHc@0NEh_07AI;01`EBX0KU8Z06eA:P1/D2T0JU<W06UB:01WD2H0IDhU06=;9@1QBBD0
GdLU05i6901GAbD0ETHT05A48`1B@B<0D3lS04dl8P1<>b40BcTQ04Dj6P15>Q`204@i6`0304@i7@13
=ad0@SHN0080@CDO00P0>bhN03HZ6P0_9AT09b0F024N5@0M7QP07AlL01/P70/06a/I0P0J6QP301TI
5`8071`J0`0K6aT301XJ60P06A/H200I6AL801TK60P06ATG0`0G6AH201PJ5`<06A/H0`0K6aT201XJ
60<06ATG200J6QP801`M5`<0820H0`0Q8AT2028R6PP09B0J00P09b<J02HR6@0U8AP09B4H02HR6@0X
91/0:RHM02`X7`80<bLK00H0<RHJ03<W6`0d:1`0=RXN03T]8@0j;R8203``6PD0?2lL00<0?C0M03ha
800m<1l00`0l;ah00`0m<1l0?c8Q040c8P0903/^6`80>RdM00<0>bhM03/^6`0l<1X00P0l<1P00`0m
<AL0>B`K03T/6`0203P[6P<0=bXI00L0=RTH03LZ6@0h:aX0>2/J03T/6`0j;A`0>bhM0080?2lN2010
;ad204Hf7@0>04Pf7P1;=al0C3HO04lf801@=b40DCHQ058f801C=b40DcTR05<k8`1A>b<0Cc/R04hj
8@1;>R02054l7`0305<k7`1D>Ql0ECXO0080EcTO00T0F3PO05Hn8P1F?R80EclS05Hn8P1E?B40Dc/O
050h701?=a/02@1D>Ql305Dk8080ES`Q0P1G?B803@1H>1l0G3dQ06119@1P@B@0GSlP05i07P1Q@al0
IDLS06E9901VBRD0IdTU06U89@1[BBH00P1/B2H0101_B2L0KTdZ06m>:`1aD2d2079A;P08075@;@1_
CR/0KTdZ07I@:@1gDBX0N58[07UC;01jE2d207UC;00607QB:`1iDR/0NE8[07QB:`1eDRX0M5<Z0P1b
DRT02@1`DbT0MU0[07E?:P1cCBP0LT`W075;9P1bC2L0LddX07A>:@0207=@:P80LTlY0`1aCRP01P1`
CBL0MDl[07E?:`1eCbX0MU0Y07IA9`80Me8V00D0Me8U07A?9@1eD2H0MU4W07MB:00207QC:@0307UD
:P1jEB/0NeH/0080NE8[0P1jDb`0101kE2d0O5D^07eF;`1mERl307eF;@80OUL^0`1oF2l207]F;080
O5L]0`1mF2h02@1nFBl0PU`g089L=`20FS<0OeX`07eH;01lEbX0NeLW07YF9P0707aF;`0907]E;P1l
FR`0OE/]07mM;`20GS00PEla081N<01oGBl0OU`^0080P5h`0P21Gc401@22H380Pf4c08AR=024HS@0
Pf0h0080Pf0f00L0Pf4d08=Q<`23HC40Pf8_089Q;P27HSD0QV4d00@0QF0c0`27HSD02028HcH0RVDh
08]V>@2;IST0RVDh08QS=P27HSD0PUlg0P22GcD00`23HC@0Pf4c08AR<P0208AS<00608AO<P25H3<0
QV4d08MR=@28HcH0RVDh0P2;IST01026HCL0Qf8h08MR>027HSP208QS>@80RF@j0P29ICD00`2:ISH0
RfLg08aX>00208eY>@0308iZ>P2>JSH0SVXf0080SFTe102<J3@02`28I3@0RFDe08]W=`2<J3P0SFTi
08aX>02;IcL0RVHf08]V>@2<IcX0SFPk0080SVTl00d0SFPk08aW>P2;IST0Rf@i08aU>P2=IcX0SfTj
095[>P2BKCT0Tfhj09A_>P2CKSX0U6lk00<0UG0l0P2CKSX0202AK3P0T6/g09Ic?@2FLSh0Ug<o09Mc
@@2HM4@0V7=60P2IM4P00`2KMTT0W7M:09ehB`0209iiC00<09ehB`2LMdX0VgI909QcA`2GLTH0Ug95
09Ib@P2ELCl0U70l09=_>`2CL3X0SfTj0`2@JS/02P2?JCX0SFLh08]U=P2:I3D0RFLg08MU=@24HS@0
PElb081M<`1oG3@207mL=P0@08EP=P24GcD0Pehd08=N=024GcD0QF0f08MR>029I3X0R6@d08UU=@2;
IcL0SFTi08m[>`2BKSh0Tflo09A`@0<0UG0l00d0UW4m09Qc?`2KMT80WGQ409mjAP2NNTH0Wg]70:1l
B02ROTX0Y81<0:J2CP2WPdl0Z8A@0080ZXIF00<0ZhMG0:b8F02]RET00P2^RUX0102_Re/0[XYF0:n;
E`2`S5P20;6=F@030;2<F02_ReL0[XYF00P0[XYF0P2_RUD30;2;EP040:n:E@2]R5<0[8MB0:j9E@<0
[HQD0P2/Qe<20:^6DP060:b6F@2/QUL0ZhEF0:^5E02ZQE40ZXE@0P2YQ4d80:R3CP80YX9800T0YH19
0:AoBP2SOTT0XWe90:9lB`2QNdX0WgY50:1kAP2QO4L00P2RODP00`2QO4L0X7]609mjA@0309iiA080
WGQ3102LMd8209]f@@0409Ud?`2HLch0Ug8m09Mb?@80UW4l00@0UG8l09Md?P2KN480Wga60P2PODL0
0`2OO4H0WW]509mkA`0709mkA`<0YX9>0P2WPdl30:R4D080Xgi700<0XWe80:9mB@2QNdX00P2QNd`0
0`2PNTd0Y7m;0:AoB`030:F0C0030:AoB`2RODT0XGa80080X7]700X0XGa80:1kA`2ONTH0WGQ409]f
@P2IM400VgI209ag@`2MN4@0WWU50P2MN4@00`2LMd<0VgI209Ya?@0309Ya?@@0VG0l0`2HKS`[oooo
o`00:_ooool80:5gA@80YGU800@0Y7Q70:9fA@2QMD@0Wg=20P2NLT420:9iA@030:=jAP2TNdL0Y7]7
00<0Y7]7202TNTP20:AkA`80YGa80P2VODT20:MnBP80YG]90P2VO4X20:MmB`80Z7i<0P2WOD/60:Qn
C0P0Z7m;0P2XOT`0102WOD/0YWa:0:EkB@2TNTP20:=iA`T0VgI200H0UW1109E_@02DKSl0Tfdn099/
?@2@JS/208mY>P0608aW?@2;IS`0RVDk08UT>P28HcT0QV4g0P25H3H208AM=00308=N=020GC<0Oehc
0080OUlc00T0Nehb07YK;`1jFbl0Ne/b07]K=01jFS@0N5Ld07IE<P1eE3<00P1eE3402@1dDc00LU4^
075@;@1`Cb`0Kdh[06i=:P1`DS00Ke4_06e?;@0206a>;00;06e?;@1_DBl0L58`07AF=01fEC80N5Ld
07YH<`1mFS@0PE/d08=L<`24GC@00P25Gc801P27HC@0RF<f08]U>02>J3/0T6Xm095[?P80TF`h00@0
TVdi09=^>P2DKc/0UG0l0P2FLCd309A`@080UG510`2FLT801P2KLCl0VW0n09Y`?P2IKcd0V6hl09M]
>`80UV`j00P0TVdh099]>@2BKCT0TF/j095[?02AJch0TFXo091Y?PP0SFLj202<ISL00`2>J3T0SFLh
08eW>00208aV=`<0RfDf00<0SfTl08iX>`2;ICP00P2:I3L00`2;ICP0SVPk08mY?00208QV=P0308YV
=P2;ICH0SF@f0080SV<f00H0Sf<f08UR=`29HSL0RF<f08YT=@2:I3<208UT<00608UT;`29Hc80RV@c
08aV=`2=IcX0SVLl0P2=ISd00`2<IC`0Rf@m08iX>@0208iX>@<0SfTj0P2@JS/00`2>J3T0SFLh08eW
>00208aV=`80RfDf00<0RV@e08]V>@2;IST00P2:ICP208UT=`80R6<f2029Hc@208MS<`0608IQ=026
HCD0QF0f08EO>025GcX0QV0k1025H3H01026HCL0Qf8h08MR>028HcT208AR=080QF<e00@0QfDg08QV
>029IcT0RVPj0`2;ISX208aW>`80SFPl00<0SVTm08aZ?02<JS`00P2<JS`408]Y>`0308a[>02=K3T0
SF`i00@0SF`i00H0S6/h08m^@@2?KT40Sfm008m_?P2?Kc`208m`>P0608m`>@29JcT0RF/i08QZ>027
JCL0QVPf0P25IcD08@24IS@0Q6@e08=S=022HcD0OF0d07UN<`1cFS40KeH]06aE;01SCbh0HTh]05i;
:`1IB2X0ED@X05519`1>@2D0C3hT04Xj8`18>B80ASLR044d8@0m<R00=bhM03@]7@0b:a/0<R`L030]
700_;1d0;B/N02/[7`0Y:b009bXO02LZ8@0302DX7`8092LN0`0S9Qd2024T6`808RDL0P0S9Qd202@W
7P809bTN100V:1d302DW70<08RDL0P0Q91/3020S6P0>028U700S9Qd09BLL02PX700/:Qd0;b`M030]
7P0c;Ad0<2dL038_700f<Ad0>C8O03/c7P0l=1d203hd6`80@cLM1012=Q`2044e6`0803T^6P0g;1X0
<RTH030Y6@0]:Q/0;bdQ030`9P0b<RP203Xb7`0603Ta7P0h<1d0>30M03Ta7P0j<Ql0>c<P0P0c<1d0
0`0b;a`0<BhK034^6`03034^6`P0:R/M00P0:2XO02HX7@0T9Q/08bDJ028T6@0S9AX092HK02DW7080
9RLO00@09BHN02<T700R8a/0824I0P0O81P201dO6P<06adH01/071hI01hP6`0O8A`0:bPI034[6`0h
<Ah0@CHR04Pi8P19>1h0B3@I04Ha501I>1D0JTXT085Q>P2@LDD0TWA2099d?P2HNd<0X8=90:B0CP28
Jcl0GDh]03`g8`0[;b40:BlU02TZ8P0V9Q`0100U9b@01@0T9R<08bDR02<U8P0R92409BDU00809BDS
00<09RLR02HW8@0W:2000P0W:Ah302LX8P809RLQ0`0U9R00200Y:bH09bTT02HW8@0V9Qh0:bPO034]
8P0g<bP0?3HZ0P0l=b@0100k=R<0>C@Q03Pc800f<Ah303D`7@0503Td8@0h<b00>38R03La8`0f<2@0
0P0e;R@07`0d;BD0;S0S038b9P0e=RP0=cDV03Db8@0g<Ql0?3DS040i9P12=b<0AcXW04e1:`1DABh0
F4P^05Q7:`1HABL0ET<U05]49@1J@b@0ET4T05<o901@?bD0CclU04i09P1?@BL0DD0V05=2:01EA2X0
ETD[05M6;01FAB/00P1EA2X404m3:@0:04i2:01=@BL0C40V04a09P19>R<0Bc`U04lo9P1C@RP0ED@X
05U6:080FdHW0P1FAbX205E6:@<0E4DX01L0Dd@W050n9P1??BD0CS`T04dk8`1>?2@0CcdU054o9`1B
@2P0D3lS05A09@1F@bD0FTDV05m8:01TC2X0Idd/06Q>:`1^DRd0L5@]07=G<01fFS80N5db07UN<@02
07QM;P80P6Dh00h0PFHi089W>023J3T0QFXk08M]?028KSd0TWa:08Yd@`1iI3L0IE8Z05Y79P1EA2P0
ET@/05E5;P80G4@Z00H0G4@X05e69`1NAbL0GTLU05m89P1OBB@205E6:@80E4DX00D0Dd@W05939P1A
@RD0D44T04m4:00304i39`0E04m4:01AARX0DdP/05A9;@1HBB`0FDX]05a;;@1PCBd0Hdl^06I?;@1W
D2h0JE4]06eE<@1`F3@0LU`g07AP>`1fI3`0MVLn07MX?`1fJCl0KUlf0080KElh00<0Jeli06UO>`1W
Gc/00P1TGS`306eN=`80KUlh00`0Kf0i071Q>P1`HCX0LF8k071K<01aG340MEhb07UQ<`1nHc@0PFDe
08EW=@26J3H208QY<`0Y08UX<P2=JS80Sf/_09A^<02GKc40VG4c08]Z=02<JcH0SVdh08m^>@2>KCX0
SF`i08a[>02;JSL0TFhf099_=`2DKcP0Ug0i09Q_>@2HKCP0UV/f09MY=@2FJc@0V6/d09Q[<P2KKC80
X6ld0:Ec=P2ZMcP0[GXk0;F1=P2hQ3/0^hU00;j?A`2oTdX0_YI>0;fGCP2mUe00_IIA0;^DC`2iTTd0
0P2gT4/09`2hTD`0^Y=>0;^DC`2gUEH0]YAE0;BBD`2bT540/8i?0:j<C@2/RT/0ZhU:0;:@D`2aSe80
[he@0:f;CP2[RD`0ZHM:0:N5B02VQ4L0Y8A90:F2B02TPTD0Y8120:J0@@2XPD00ZX4o0:^2@02[PT80
[8=30:n6AP2`QdL0[hI60:f4A02ZPD40Z7lo0:b5>P2]QS/0/8Tn0;6:?`020;:;@00E0;6:?`2`RCh0
[HI=0:^4B`2YPDH0Z7i20:Ql?`2YNcd0ZG`k0:al?02TNc/0XgXj0:5h>02PMcL0WgHf0:1g=`2QN3P0
XWTi0:Io?P2WP3l0ZH910080ZX=200<0ZH910:R1@02WP3l00P2ROT00102QOCl0X7`n09mk?@2NNS`2
09ah>P0909ad=P2MMCL0WWHh09mg>@2QNC/0XWXl0:=k?@2TO3h0YWi00080YGdo00<0Y7`n0:=k?@2R
NS`00P2RNS`00`2MMc00W7H_09af;`0209af;`0409eg<02NN340WGL`09eg<080Tfhg00@0TVdf095/
=@2AK3D0T6/d0P2?JS<04`2?KBh0SVha091`<`2ALcL0Sg8h08]a>027KSH0QF`d08IY;@27JRh0R6/a
08Q[<`27JS80QFLa08=U<@21Hbl0PF8c07mP<@1lGBh00P1jFb`00`1mGRl0P64b089S=00208=S:P0A
08MW;P2@KcT0UgI009Ie@02:JC@0OehY07]P<@1lHC80OV@c081V<`22JC<0QF`d08I]=@27KSD0Q6Pf
08=W=@21IC<00P1oHc402`20I380PVHd08=W=@2?LSX0T7<k099e?@2CMSh0U7Lo09=f?P2BMCd0TG@l
00P0SG<j202;LST208me?00608id>`2=LcX0Rg4h08Y`=`29KcH0R6he0P26KCD00`25K3@0Q6/c08=Z
<P02089Y<@0c085X<01lIbh0OFL^07]U;01mI2`0Of@]08AV<027J380RFXd08e`>02JO4H0YHMA0:>5
D@2JO4X0VW]<0:N8FP2eUVP0_:1k0;nSO030Y7`0_Z=f0;NMK02[TU`0WXE=09ImA027KC`0Q6Xi07eR
<`1gG2d0LULZ06mD:@1^DRX0KE4Y06aE:@1[E2X0JE8X06M@9`1UCBL0HTXV06599`1PB2H0FTPT05U7
8`1HAB@0ED8R05=08P1A?B80Cc/P04hj8@16>a/0AS/M0080ACXL00<0A3TM04<g7@12=Qh00P11=Al0
200l;al0>2`L030V6P0Y8QP08QlF01hO6@0M7a`0724M2P0L71X201/K6@806QXH0P0I6AL201`L6P<0
6a/I0`0J6QP801TK60P06ATG200I6aP801TI5`805aTF0`0H6QL301TK608071`J0P0K6aT201XJ6080
6ATG200K6aT801`M5`<0820H0`0Q8AT2028R6PP09B0J00P0:2@K02LS6P0V8QT09B4H02HR6@0X91/0
:RHM02/W7P<0<bLK00<0=2PL03DY7@0f:Qh00P0h;20203/^7@0403/^6`0l;a`0?C4K03da6`80?S8J
1P10<Ah2044b7`T0?2lL0P0l;al01P0l;ah0?C0M03da6`0m<AT0?S8J03hb60<0>RdL0P0i;1/303P[
6P0303LZ6@0h:aX0>2/J0080>B`K0P0j;A`00`0k;Qd0@2lM040_7@06040_7@80ASHM00/0B3HN04/g
7`1<=Ql0CcHP050g8@1A=R40ECHQ05Hg8P1D>280E3XS05<k8`02054k8`05050l8`1E?B40ECdQ05Hl
8@1G?2400P1I>b4205Xj8@80F3hS0P1I?b@0101H?R<0ES`Q05@j7`1B>1d805Dk80<0ESdO0P1G?R03
05Po8@0805Xj8@1N?b<0HD8V06529@1O@240Gd4O0694801VB2@206A88`0906I8901YB2D0K4XW06i:
:01_BbT0LDXY071@:P1aDB/0Le<]0080M5@^00<0Le<]075A:`1`D2X00P1gDBX207QB:`@0NE</0P1k
E2d03`1iDb`0MU<[07AC:P1cDbX0LU8Y071C:@1cD2X0LTlY071=9`1_C2H0KT/U06m<9P1`CBL0LDhX
07=@:003079?9`80LDhV0P1`CBD207A>:P0:07E?:P1fD2T0MU4W07MB9P1hDbL0N5<V07E@9P1fDBL0
Me8X07QC:@80NUD[00<0NeH/07aG;@1mF2h00P1jDbX00`1kE2/0O5D/07eF;@0207iG;P0407mH;`1o
F2d0OeP]07mH;@<0P5T^0P21FRl307eH;0<0OUT]0P1oFRh01P22G3L0PE/f085K=020Fc40P5/_07mJ
;@80Oe/[0`1oFS0407iI;`0907eH;P1nG2h0Oed_085O<@22H380Pf4c089P<P21Gc40P5h`0080PEla
00<0PV0b08=Q<`24HS@00P25HcD01@26I3H0QV4e08IQ=@26HCD0QV4d0080QF0c0P25HC4508IQ=006
08MR=@28HcH0R6<f08MR=@28HcH0RF@g0P2:ICP01029I3L0R6<f08MR=@23H3P208AQ=`0308AR=@25
HcD0QF<c0080QVDb00P0Q5lb08EP<`26HC@0R6<f08YU>02<IcX0SFPk08iY?0<0RF@h0`2:ICT208]V
>P0608YV=P2;IcL0RfLg08aX>02=JCT0SVXj0P2?Jc/2095]>@04091/>02?JcL0SFTe08aX=080RfLc
00<0R6@d08UU=@2;IcL00P2=JCT01P2<J3P0RfLg08YV=P2;IST0S6Lj08eX>`80SVTl00<0SFPk08aW
>P2;IST00P2<ICX02`2=IcX0SfTj095[>P2BKCT0Tfhj09A_>P2AK3P0TVdi09=^>P2DKc/0UG0l0080
U6lk00P0TVdi095/>02FLcd0UW8n09Mc?`2GLd40V7A409QcAP80VGA80P2LN4P00`2MNDT0WWY:09ij
BP0309ijBP80VWE900H0VGA709QdA02GLd40UW8n09Ea?@2ELS`3095[>P0=091Z>@2?JCP0SVPg08eW
=P2<ISD0SVXh08aX>029ICD0Qf8e08EP=025H3H0QElh08IP>@0208EP=00>08AO<`25H3@0QV4e08QS
=`2;ISX0S6Lk08aX>02=JCT0SVXj095]?@2CKcl0UG5109Mc@`2HM4@209Ud@00<09Ye@@2KMT80WGQ4
09mjAP2PNdL0XGa80:9nBP2SOd/0Y81<0:F1C@2VPTh0Yh=?0P2XQ5020:^7E`80[8QH00L0[HUI0:j:
FP2^RUX0[XYJ0:n;E`2`S5P0/XiJ0080/hmK00<0/XiJ0;2<F02_ReL0202`S5P0202_RUD0/8]F0;:=
F02dSeX0/hiI0;6<E`2^RE@0[8MB0`2`ReL20:n:EP<0[XUE00H0[HMJ0:f7F02/QUL0ZhED0:^6DP2Z
QE020:V4C@030:V4C`2XPdh0Z8=>0080Z8=>0`2WPTd20:J2AP070:F1A`2TOdP0Xgi90:9mB02RODT0
XG]:0:5lA`060:9mB0040:5lA`2NND@0WWU409iiA0<0WGQ30`2LMd8209Ud@00;09Ye@@2IM400V7<o
09Mb?P2EL3`0U6lk09A`?02GLcl0VWI209ijAP2PO4P00P2QODT90:1lB0<0YH5=0`2VPTh20:N3C`80
Y7m800<0Y7m:0:=nBP2SOD`00P2RO4d0102RO4l0YH1<0:F0C02UP4`20:AoB`80Xgi:00T0XWe90:=n
BP2RODT0XGa80:1kA`2NNDD0W7M309Ye@@2IM4001@2MN4@0102LMd<0VgI209]f@P2GKSX309Q_>`<0
VG0l00@0VW4m09U_?@2IKcd0VFlm:oooool002[ooooo202QMdD0202UNDP0Y7Q70:=gAP2RMTD0XGE4
0:1d@`2OLd80WW911@2SNTH00`2TNdL0YGa80:ElB0080:EkB@80Y7]70P2UO4P20:ImB@80Ygi:0`2V
O4X20:MmB`<0Z7i<0P2YOdd60:QnC0P0Z7m;0P2WOd`0102VOT/0YGe:0:AlB@2SNdP20:9jA`T0VgI2
00H0UW1109E_@02DKSl0Tfdn099/?@2@JS/208mY>P80S6Lm00H0RfHl08UT>P28HcT0Qf8h08IQ=`25
H3H208EN=@0308=N=021GS@0Oehc0080OEhb00T0Nehb07YK;`1kG300O5`c07aL=@1kFcD0NEPe07MF
<`1eE3<00P1eE3402@1dDc00LU4^075@;@1`Cb`0Kdh[06i=:P1aDc40L58`06i@;P0206e?;@0D06i@
;P1`DS00LE<a07AF=01fEC80N5Ld07]I=01nFcD0PU`e08AM=025GSD0QElb08IP<`28HSD0RV@g08eW
>P2>J3/0SfTl091Z?@2AK3P2099]>@0509=^>P2DKc/0UG0l09E`?02FLCd00`2DL40209Ea@@<0UW92
00H0Vg4o09Y`?P2JL3h0VFlm09Q^?02GKC/209I/>P06099]>02BKCT0TVdi095[>P2@JS/0T6Xm0P2?
J3d808eW>PP0S6Hg0`2=IcP208aV=`80RfDf00@0RV@e08mY?02=IcX0RV@g0P28HSD00`2:I3L0SFLj
08mY?00208QV=P0308YV=P2;ICH0SF@f0080SV<f00H0Sf<f08UR=`29HSL0RF<f08QR<`28HS4208UT
<00608UT;`29Hc80RV@c08aV=`2>J3/0SVLl0P2>Ich0102=ISd0S6Dn08eW>02=IcP308iX>@<0SfTj
0P2=IcP408aV=`80RfDf0`2;IST208YU>0<0RF@g202:I3D208MS<`0408MR=@27HSH0QV4g08EO>080
Q5hi00@0Q5le08EP=P25H3H0QV4g1027HSP00`24HS@0QF<e08IT=P0208MU=`<0R6Hh0P2;IS`208aW
?@@0SFPn102;JC/408aZ?0<0SF/k0P2<JSX308e[>`80T6i100<0T6i0091^?P2@Kc`00P2@KcX01`2@
KcT0R6Xh08QZ>028JSP0QfTg08IX=P25IcD00P24IS@208=R=@0N085R=P1mH3H0NEde079I<@1_ERh0
Je<]065=;01PC2/0GDXZ05Q7:@1EA2P0DD4W04do901<?R@0BCXU04Hj9013=R<0?c@R03T`7`0f;al0
<R`N034[7@0b;1`0<2dL02l/7@0]:ah0:RXN02PZ7`0V:Ah09RTP0P0U:1l202@W7P808bHM0P0R9A`2
024T6`808RDL0P0S9Qd202@W7P0302PZ7`0W:Ah09bTN00809RPM0`0U9a`00`0T9Q/08bHM02<V7@02
028U70808B@K0P0P8aX04@0S9Q/092LL02HX6`0Y:Q`0;B/L030]700a;Qd0=2lL03<^6`0e<1`0>C8O
03/e7`0n=Ql0@3HM040d6P0o<aT0ACTO0080A3PN0P13=ad2048f700<044e6`0d:aX0<R/I030Y6@0^
:1P0;bTK030/800d<2@0=c<W03`d8@0j<Ql0>30M0P0g;a`00`0h<1d0>S8O03/c8005038_7003034^
6`0`;AX0<2dJ00P0:R/M00<0:2XO02LY7P0U9a`00P0S9AX0:`0T9Q/09BLL02HX7@0V9al09BHN02@U
7@0S91`08B8J020Q6@0O81P07QlG01hQ6P0M81T071lH01/N5`0L7aP07R4J020S700Q91d0<R`L03L`
7P0m=B80A3PR04Ph7`19>1`0BcHI04`e5P1R@Q/0MED/08]/@02EMTL0UGM509Ih@P2KOTH0X8=;09Ah
B@1cGCH0B3lR02d^700V;2809RdU02LZ8@0V9Q`00P0U9b@00`0T9R<08bDR02<U8P0302<U8P0602DU
9@0U9B<09BDS02HW8P0V9b409bPP0P0W:Ah302LX8P809RLQ0`0U9R00200Y:bH09bTT02HW8@0V9Qh0
:RLN030/8@0f<RL0>cDY0P0h<Al203Tb8080>S<Q0`0k=2801@0l=B80>c@Q03/d8P0j<b<0>30S0080
=blT0240=RdT02la900d=2P0>3T[03Tg:00h=B@0>C@Q03`e8`10>BH0@cTP04Pl901=@BT0E4H/05M7
;P1GAR`0ET8Y05A09@1IA2L0Ed8U05A09@1??R80CShT04do9@1<@2P0CD4Y05919`1C@RP0ED@Z05I5
:`1GAR`0ETD[05E4:P1D@bT00P1?@bT00`1>@RP0CD4W04e19`0304e19`0604Tj8`1<?BH0D40W05A3
:@1GARX0FDHX0P1JABH305A4:P80Dd<Y0`1B@RP204hl900D04dk8`1<>R80CC/S04hl901@?RH0DT0X
050o8`1D@2D0ET<U05Y59P1OB2P0I4`Z06M=;01XCR/0LED^07=G;`1eFC40N5db07YO<P1kH34207]Q
<00H07mW=`1nISH0OVHf07iV>020J3X0Q6`n08Q`A02:LTH0SWU:089]@01aGS@0HU0/05I59`1A@2H0
DD0/05A5<P1KAR/0G4L/05a7:P1NBBX0Gd/Z061<:@1QCBX0HThY0P1EAB/00`1DA2X0Dd<Y0592:002
05519`0305109P1CABX0DT@Y0080D48W00@0DD<X05=5:P1EAb`0EdT^0P1IBRd0501KBR`0Gd`/069>
;@1VCbd0Ie0^06UA;@1]Ec80KeTd075M>01cHC/0M6A007EU@@1dIT40LfM106eM>@1[GCX0JU`i06MJ
>01TFCT0HUTj0P1OF3/306UJ<`0f06YK=01[G3D0K5df06eN=`1^GcP0Kf0i06iI;P1_FRl0Le``07MO
<@1lHC80PFDe08IX=P27JCL0R6Xd08Q[<`29JS<0RVXa08eZ<P2@K380Tf`c09A]=02:JCH0RfXg08a[
>02=K3T0SVdh08e/=`2;JSD0RVTc09A`=P2ELCL0V74h09]b>P2LLCX0WG0i09a_>02LKCL0Vg4e09e`
=@2OLcH0XW@f0:Qh>02]O3X0/Ghl0;B1?`2kQc/0_8/n0<6AA@32UT/0`I]B0;fKD`2jVE80]YQ@0P2i
Te80102gTE00]Y1?0;J@C`2fT4l20;NAD00S0;FCE02dTU<0/Y1A0;2>C`2^S4d0[8Y;0:Z8B@2YQdP0
[8Y=0:^9C02YQdX0YhE80:F3AP2SPD@0XGm20:1n@@2VPT@0Z8940:R2@`2YPT40Zh900:j3?`2aQ400
/XE10:b3@@2^QD<0/HQ60;>:B02dRdT0/XU70;27A@2^QD<0/HXm0;:;?P2dSD000P2eST403P2dSD00
/h`o0;:;?P2`RT`0[XQ:0:f5A`2/Pd<0[80o0:f0?@2^PCd0/84m0:V1?02XP3/0YWhi0`2TO3L01@2U
OCP0YWhi0:V2?@2ZPch0Zh@o0080[8E000T0Zh@o0:V2?@2XPC`0Y8510:>0@02ROcl0X7dm09ik>`2M
NSX00P2LNCT209ee=`0609if>02OMcT0X7Pj0:5i>`2RNS`0Xg/m202QNC/00`2PNS40XG/b0:5k<P02
0:5k<P040:1j<@2ONC00X7Xa0:5k<P80UW4j00@0UG0i09A_>02CKSL0TVdf0P2AK3D0202;JBX0Rf/^
08e]<02=Kc<0S6le08Q^=@24Jc<0PVTa0P27JRh02@28Jc40R6/c08MZ<P25Ic40PfDa089T<022Hc@0
P64b07eN;`0207]L;@0C07eN;`20HC80PV<d08=R;@24Hbh0R6Lb091_>@2FMCl0UGDl08e]=025IB`0
Nf0a07aQ<P1mHc80P6Hc089Y<`24Jc<0QVde08M^=@0208=W=@0>089V=021IC<0PFDc089V=023IcD0
Q6Pf091c>`2AM3`0TgHn09Ag?`2EN400U7Lo09=f?P2BMCd808id>`P0SG<j00H0TGLn091f?@2?MC`0
SW@k08ab>@2;LCP208Y`=`0608M^=P26KCD0QVde08E/=024Jc<0PfXb0P22JC407P1mJ2l0OFL^07eW
;P1oIRh0PFH_08AV<027J380R6Tc08U/=02GND<0Y8I@0:B6DP2KOD/0V7U:0:>4EP2_T680^Iaj0;fQ
O031YGh0`ZMl0;fRL`2cVFH0Z8mI0:68D02@MT<0Rg4n08=Y>01kH340M5T/075F:@80L5DZ0180KUL[
06eF;01[E2X0JE8Y06M?:@1TC2P0Hd/Y069::01MBB@0G4PS05Y68`1HA2<0ET4R05<n8@1B?B00DC`Q
04Hk6`16>ad204Dj700304@i7@14>1h0@cLO0080@SHP00P0?S4Q03T]7@0a9a/0:R<I02<P5`0N7aT0
7AlL01`Q7@/071`J0P0K6aT301XJ608071`J0`0K6aT301XJ60P06A/H200J6QP801TK60P06QXH0`0H
6QL301TK60806Q`I0`0L71X201/K6@<06QXH200K6aT801`M5`<0820H0`0Q8AT2028R6PP09B0J0P0X
91/302HR6@0302LS6P0Y9A`0:RHM0080<bLK00@0=2PL03DY7@0f:Qh0=RXN0P0g:al0200i:ah0>RdM
03X]7@0l;a`0?C4K03hb6P0o<aT0?c@H0P12<Ad304<b7P80@S4M00<0@C0L03d`7@0m<1d01`0m<1d2
03d`800303ha800n<Ah0?S8L0080?c<K00<0?c<I03`_7P0k;Qd00P0k;Qd203X]70H0>B`K100j;A`8
044`7P80ASHM00H0B3HN04/g7`1<=Ql0CcHP050g8@1A=R4205Lg8P0605Hg8P1E>B<0E3XS05@l901E
?BD0E3hV0P1G?B8205Pm8P0605Xl8P1K>b80GC/R05dk8P1J?b@0Fd0U0P1L@BH0101K@2D0FChS05Ll
8@1F>b0805Hl8@80EchO0P1H?b0305U08@0905Y18P1K>b80Gd0T06=4:01SA2L0H44R0612801TAR80
J4XV0080I4PS00T0ITPT06Y99P1/BRL0Kd/Y071<:P1bBbX0LE4Z079B:`1dE2d00P1eEBh00`1dE2d0
LU8[075A:P0307MA:P80N58[0P1iDb`0301jE2d0OEH_07aE;P1jE2d0Me@/07ED:`1cDbX0LU8Y071C
:@1cDB/0LU0Z071>:080KT`V00@0KddW071>:01aCbT0M54W0`1cD2H2079?9@80LDhT00D0M4hZ07E?
:`1eCbX0MU0Y07MB:00207UD:00507YE:01gDRP0N5<Y07QC:@1jEB/00P1kER`0101lEbd0OEP^07eH
;P1kE2T207aE:P0307eF:`1nEb`0OeP]0080P5T^1021Fbh2089L;`80Ped`0P1nFB`307mJ;@<0P5/^
00P0OUPc07mI=020FS<0PE`b08=N<P24Gc80QF4a08IR<P80Pehb0P22GC402`21G300P5/_081K;`20
Fbl0Oed_085O<@23HC<0Q68d08ES=@24HS@0Pf4c0080PV0b0P23HC<00`24HS@0QF<e08IT=P0208MU
=`80R6@d0P27HSD01026HC@0QV4e08EP=025H3@208IQ=00308MR=@28HcH0R6<f00<0RF@g00<0Q5lb
08EP<`27HSD00P28HcH01027HSD0QF0c08AO<P25HSX208ER>00308IT=`26I3H0QfDe0080QfHc00P0
QV4d08MR=@28HcH0RVDh08]V>@2=J3/0SVTl08mZ?@80RfHi0`2<IcX308eX>`80S6Ph00<0SFTi08iZ
>P2?Jc/00P2@K3`01`2AKCd0Tflk09=_>`2BKSX0T6`h08m[=`2=JCD00P2<J3@00`29ICD0RfLg08aX
>00308iZ>P0508eY>@2<J3P0S6Lj08eX>`2>JC`00P2?JSd00`2>JC`0SFPk08aW>P0208eV>`0;08iX
>`2?JCX0T6Xi095/>02BKCT0TVdh08eX=02>JCD0TF`h09A_>`2FLCd00P2GLSh209Ia?@0609Ic?@2F
LSh0Ug<o09Mc@@2HM4@0V7=60P2IM4P409eiA`0409ijB02ONdT0X7a:0:1lBP80W7M;00/0VgI909Yf
AP2IMD<0VGE109Qd@02HMCl0UG0l09A_>`2CKSX0TVdi095/>003091[=`06095]>@2?JcT0SFTg08]W
=`29I3L0RF@h0P2:IC/05P26HC@0QF0c08EP<`25H3<0QV4d08UT=`2;IST0SFPk091/?02AKCd0TVhn
09A`@02GLd<0VGE509]gA`2LN4P0WGQ409iiA@2ONTH0XGa80:9mB@2SOTX20:AoB`<0YX9>00<0Yh=?
0:R4D02YQE400P2ZQU820:f9F@<0[XYJ0`2_Re/00`2aSET0/XiJ0;>?F`020;B@G0030;>?F`2bSUX0
/HeI00P0/HeI00P0/HaG0;:=F02dSeX0]Y5L0;F@F`2cSUT0/8]F0:j9E0@0/HaH0P2`ReL20:n:EP06
0:j8F`2^R5T0[HMH0:b6E@2[QU80ZXE@0P2YQ4d20:V4C`80Z8=>00@0Yh9=0:J1C02VPD`0YX5<0P2V
PT@00`2UPDD0Y8160:=nA`020:9mB0040:5lB02RODP0XWe80:9mB080XGa70`2RODP209mjA@<0WWU4
102MN4<03P2ILd80VWA309Yd@`2JM4<0VG=209Ma@02FL3l0UFln09Ea?`2GLd40VWI409eiA`2ONdT0
X7a:0P2QOD/:0:5mB@<0XWi:0`2SOd/0202VPDX0YH190:F0B`2UP4`0Y7i=0:AnC`2SODh0Xge@0P2U
P4`20:AoB`@0Xgi:00H0Y7m;0:=nBP2QO4P0WgY609iiA@2LMd<209]f@P80WWU500<0WGQ409ag@`2K
MT800`2KMT80102GKSX0V6lk09Q_>`2HKc/309U`?00409Ya?@2IKcd0VFlm09U_?B_ooooo000Zoooo
o`P0XGM500@0XgM60:9fA@2RMTD0XWI50`2QMD@00`2PM4<0XgY60:9iA@030:5hA0030:=jAP2TNdL0
YGa800P0YG]90P2TNdL20:ElB080YWe90P2WOTX20:IlBP80Yge;0`2XOT`00`2YOdd0ZX1>0:Z0CP02
0:UoC@@0Z7i<202YP4X20:F0C0040:AoB`2SOTX0XWe90:5lB080X7]70`2LMd<309]f@P<0VWE100H0
UW1109E_@02DKSl0Tfdn099/?@2@JS/208mY>P0608eX?P2<Icd0RfHl08YU>`28HcT0Qf8h0P26HCL0
2026GcH0QEhe08AO=@21GS@0Oehc07eN<P1lGC40NUda0P1kG3001P1lG3<0O5`e07]K=@1iF3D0MeHc
07IE=080M5<`00@0Le8_079A;P1aD2d0LE0]0P1`Cb`00`1bE380LE<a06mA;`0206i@;P0@06mA;`1a
Dc40LU@b07=E<`1fEC80N5Ld07]I=01nFcD0Pedf08EN=@26GcH0Qf4d08QR=@2:I3L0S6Hi08eW>P<0
SVPk0P2BKCT209=^>P80U6lk0P2EL3`309A`@080UG510`2FLT801P2JL3h0VFlm09U_?@2HKS`0Ufdk
09I/>P80UF/i00H0Tfhi099]>@2BKCT0TF/j091Z>`2?JC`208iW?0P0SFLj202<ISL02`2;ICH0S6Hg
08eW>02=IcP0S6Hg08]U=P2:I3D0RF<d08eW>P2<IST0RV@g0080R68e00<0RV@g08aV>@2=IcX00P28
ISH00`2:ISH0RfDf08eT=P0208iS=P0>08mS=P2;I3T0RV<h08US=P28HS<0R68a08UT<02:IC40RfHa
08YT<`2;IC@0SFLh08iX>`2?J3d208iW?P0308eV?@2<ICh0SFLh0080SFLh0P2>J3T308mY>PP0S6Hg
00@0S6Lj08]V>@2;IST0RfHi0P2:ICP208UT=`P0RV@e0P27Hc<01P28HcH0R6<g08MR>025GcP0Q5hi
089L=`80Q5le00<0QV4g08MR>028HcT00P27HSP01@26HCL0Q68d08ES=@26I3H0QfDg0080R6Hh0P27
ICL01@2:I3d0RfDn08aV?`2=Id00SVQ10080SFM000<0S6Ho08YX>P2;JC/00P2;JC/308aZ?00408e[
?@2>K3h0SF/m08aZ?080RfTk00<0S6Xl08e[?@2>K3h00P2AK4000`2AK3l0TFdm095]>`02095]>@03
095^>029JcT0RF/i0080RF/i00@0R6Xh08MY=`25IcD0Q6Hd0P23HSL07P21HCP0OF0h07QL=@1bF3<0
KU@_06]C;`1PC2/0Gd/Z05a9:@1GARP0E4<W05109P1=?b@0C3hT04Pk:016>BH0@CHT03/b8@0g<200
=2hP030]7P0`;200<B/K02l/6`0^:a`0;B/N02XZ7P0X:Ql09RTN02HY80<092LN0P0S9Qd3028U7080
8B@K0P0R9A`202<V7@8092LN0P0X:Ql0100W:Ah09RPM02HX7@0U9a`302@V6`<08bHM0P0R9A`3024T
6`0702<W6@0T:1X09RPJ02TZ6P0];1X0<2dJ034^6`0203@_6`0703Pb700k=Al0?cLP04<i8013=ad0
A3HK04<e6P0204Hj800404Di7`14>1h0@cLM04<g7@80@SHL0180<B/M02lY6`0^:1X0;BLI02lY6`0b
;1h0=c4S03Tc9@0m=B80>c<P03P`7@0f;Q/0=BdJ03L_700i<Ah0>c<P034^6`0b;a`303<`7@03034^
6`0`;AX0;b`I00P0:R/M00P0:2XO02LY7P0U9a`092HK02<U6P0T9Q/09BLL02HX7@809BHN00@092DM
028S6`0Q8QX07b0H0P0N7aL08`0O8QT07R4H01dP5`0M81L07R4H020S6P0R9A`08bHM03Pa7`0m=B80
@SLS04Lh8@18=ad0BcPJ054j6`1D?Ad0KTlQ081Q<`2@LD80UGM509MiA@2KODL0WX1:09aoA`20JD00
GTh/03Tc6`0W:ad08R`S02@[900U:1l09bLM02HX9@0U9b@08bDR00<08R@Q0P0S9B801P0U9BD09BDS
02DU8`0V9b809RLQ02LX80809bTN0`0W:28202HW8@<09BHP00P09bTT02HX8`0V9b409bLO02/X7`0`
;240=30U03Pb9P80=bhM00@0>2lN03Xa800k<R40?C@S0`0n=B@08`0o=b80?SHQ03de8P0l<b80>c8S
03T_8`0h;R80>2hT034c9P0f=RX0>S/]03`j:`0j=bH0>SDR03df9010>BH0AS`Q04Tm8`1<@2H0DD<Y
05=3:P1C@BT0DclW058n9P1GA2H0ED4V050o8`1=?B<0BcdS04Xn9P1=@B/0CD8/05919`1C@RP0E4<Y
0080ETD[00D0ED@Z05=2:01B@BL0Cd<Y04i2:00204e19`0<04a09P1=@BL0CT8X04m3:@1;?2D0CChW
0592:@1FAB/0EdHZ05U6:01H@b@0Ed8S0P1B@RT20551:0<0D40W00<0CclV04hl901=>b<00P1<>R80
4P1=>b<0CcdU054o9`1B@2P0DD0T05E19P1GA2H0FdHW0619:@1UCB/0J4h]06U?;01cEbl0METa07QM
<P1kH3<0O64b07eS<P80OF<`0100OFLe07]U=01hHS40MV0a07QQ=@1kI3X0P6U008=/@`1oK440Lf0f
06EC;@1KBbX0Dd8X04/k901<?BX0DT8b0P1IABX02P1KB2X0G4TY05i;:P1PCRX0HDl[069@:P1GAbh0
ETH]05A4:`1B@RT20551:080DT8Y00<0ETH/05A4:P1B@RP00P1A@BL00`1C@bT0ETH/05Q8;P0205U:
;@0<05Y9:`1MBRX0H4`[06E>;01WD2h0JU8^06aI<@1]FS80Kedg06mO>`1aHCl0L6500P1^HD401P1/
G3/0JU/j06MH>@1SECP0Ge@h05eC>080FU<i0`1VES80501WEc<0J5Pd06YJ=P1[FcL0K5`h06eM>@1`
Fc00LE`a07=L<01gGc40OF8c089V=P27JCL0RV`j08M]=029K3@0RVde08]/=@2=K3H0SV/e0P2?JSD0
8029IcT0RVPj08aZ>P2=K3T0SVdh08e/=P2<K3<0Rf/b09M`=@2HLCH0Vg<h09id>P2QM3/0XW<k0:5b
>P2RLCT0X7Lg0:=g>02UNCP0ZG`i0:n0?02dPch0^8I10;Z8@@30SC`0`Y520<JHBP35WU40`ImE0;^M
E@2cVe<0[YMA0P2cSe430;:>D0<0/hmA00H0/i5B0;:@D@2aSe00[he>0:f;C02/RT/20:Z8B@0D0:Z6
BP2YQDT0Yh=70:F1A@2ROT80X7a009ij?P2MNCd0YWln0:R1@02]Q480/XM30;F8A02hRD<0^XU40;V9
@@2`R4<0/HU40;>;AP2dS4L20;F=B080]8a700<0/h]30;B<A02fSTH00P2fSTH0402eSDD0/h]30;::
@P2`RTT0[hU80:j7A02^QT40[h@o0;65?P2bQSl0]HHn0:n7?`2]QCd0Zh<k0:V1>@2XP3P20:V1>@04
0:Z2>P2[QC`0[8Hm0:f7?P80[XPo00P0[8Hm0:Z4>`2YPcX0YhA40:J3@`2SP400XGhn09ml?0<0WW/k
0P2OMcT20:1h>P@0XGTk102OMcT40:1h>P090:5j=@2TOCP0Y7dh0:En>@2TOCP0XGXe09mh<`2QNSD0
Xg`g0080VG@m0280V7<l09Ia>P2EL3T0U6lh09=^=`2BKCH0S6X[08][;P2<K2l0Rfda08U/<P26K3<0
Q6/c08=Z<P27JRh0R6/_08U/<P29K3@0R6/c08IX<P24IS80PV@`08AU=P21HS<0OUl`07aM;P1kG2d0
OEh_081Q<P21HS<0PEl_08ET<@2:JC@0SVdh0P2@L3L02P2>KS<0SFd`07eR<`1mHS<0OfDd081V<`22
JC<0Q6/c08E/=026KC@508AX=P0;08EY=`26JSP0QVXh095d?02BMCd0U7Lo09Eh@02FND40UGQ009Ag
?`2CMSh0202?MC`308mb>0<0T7<i0P2AM3X2099h?`04095g?P2?MC`0SW@k08ab>@80Rg4h0P27KSH0
0`26KCD0QF`d08A[<`0208=Z<P0b089Y<@1mJ2l0OVP_07iX;`20Ibl0PVL`08AV<026Ic40QfPb08MZ
<P2DMT00X89<0:>5D@2MOdd0Vga=0:62E02YRU`0/iIf0;VLNP30Y7l0a:R00<>XN`2kXG00/IMT0:ZA
F`2HOdT0TgY408U_?020ISD0N5d^07AI;01cF2/0LeP]071I;@1_F2h0KEH/06]D:`1XD2X0IThZ06A<
:P1SBbT0H4XS05m98P1NB2<0Fd@R05U28P1G@240EChO05@l8017?1`304Hk7@0304Dj7P14>1h0@cLO
0080@SHP00P0@3<S03/_7`0c:Ad0:b@J02<P5`0O81X07AlL01`Q7@T07AdK0`0L71X201/K6@806QXH
0P0L71X301/K6@<06QXH200I6aP801XJ60P06A/H200J6QP301PJ5`806A/H0`0J71T0100M7A/071`J
01`L6P0L71X201/K6@806QXH200K6aT801`M5`<0820H0`0Q8AT2028R6PP09B0J00<0:BDL02PT6`0W
8aX00P0V8QT0200W8aX0:2@K02TU700b9QX0<bLK03DY7@0f:Qh0=b/O0P0f:Qh02P0e:Ad0>2XQ03PZ
7`0j;Ad0>bhM03da6`0o<aT0@3DG044f6014<Q`204Dc7@0504Hd7P15<ad0A38L04<a6`12<1X02@0n
<Ah0200n<B40?c8R03lb8@0o<Ql0@3@N040d7011=Ad0@CDK0`0m<1l203`_7P/0>bhM2011<1h204Hf
7@0604Pf7P1;=al0C3HO04lf801@=b40DCHQ0P1J=b<01`1H>2<0EcPS05Hj901F?2D0EclW05Q0:01I
?b@00P1J?b@00`1L?R@0GCdT05lm9002060l900805do9@1N@2H0Gd4W0612:01O@BL0GClU05`n901J
?28805Lm8P<0FD4O0P1J@R0305]38@0805dm901P@BD0I4DY06A5:01R@b@0HT@R06E78`1YBbL206E9
900906M99@1ZBBH0KD/X06m;:@1`C2X0LT/Z075A:01bDRT0Le<Z0080M5@[00<0Le<Z079B:@1aDBP0
0P1hDR/307MA:P0307QB:`1jE2d0NeD^0080OUL`00l0O5H_07QE;@1fEB`0M5@[07=C:P1`DbT0Le</
079B:`1`D2T0KdlX06i>9`1_CbP0L50Y075A:P1fDbT00`1eDRP207AA9`80Le0V00T0MDl[07I@;01g
DB`0N58[07YE:`1kERX0O5L[07aG:P1jEB/00`1kER`407aG;@0507eH;P1mEbX0OELZ07iH:`1oFB`0
0P20FRd2085K;P80PU`]0P23GBh208AN;`80QEl`00@0Oe/[081L;020G2`0P5`/0P21GBd2089N;P08
07eG<P1nF3<0P5Xc089M<`25H3@0Qf8e08UU=@2:ISH208IQ=00408EP<`24Gc80Peha08=N<@80PUd`
00<0PEla089P<P24HS@00`26I3H01P25HcD0Q68d08AR=024HS@0QF<e08IT=P80QfDg0P28ISP0302;
IC@0RV@c08YT=@29HcH0R64f08MP=`26GcH0QUlh08EP<`26HC@0R6<f08UT=`@0RVDh00<0Q5lb08EP
<`26HC@00P27HSD04@26HC@0QF0c08AO<P26Hc/0QV<i08MT>P27ICP0R6Hh08QV=P28Ic@0RFPe08QS
=P29I3L0RVDh08]V>@2<IcX0SVTl0080SfXm0P2=JCT208iZ>P<0Sf/k00L0T6`l08eY>@2>JSX0SVXj
08m[>`2@K3`0TFdm0080TVhn0P2DL3`0102CKc/0TFdi091/>02?JcL208iZ=P0;08aX>02=JCT0Sf/k
091/?02AKCd0T6`l08m[>`2>JSX0SVTl08mZ?@2@Jch00P2AK3l00`2@Jch0SfXm08iY?002091Y?P03
091Z?@2@JS/0T6Xi0080T6/g00H0T6/f08aW<`2>JCD0TVdi09E`?02HLcl409Ud@00609Ic?@2FLSh0
Ug<o09Mc@@2HM4@0V7=60P2IM4P209ijAP80WGU50100WWY60:1lB02ROTX0Xgm;09mjCP2NNDd0WWU<
09eiB@2LN4H0VgM309Yf@P2JMd40VG@o09Qc?P2FLC`0U6lj0`2CKST01`2DKcX0UG0k09=^>P2AK3P0
SfTh08iX>@2>J3/00P2?J3d208UU=@0B08QT=027Hc<0R6@d08YV=P2<J3P0SVXj09=_?`2DL400UW92
09QdA02JMTH0WGU909ijBP2ONd/0XGa80:9mB@2TOd/0YX5=0`2WPTh01P2VPDd0Yh=?0:R4D02XQ500
ZHEA0:Z6DP80[8QD00@0[HUE0;2<G02`S5`0/8aL1@2aSEd00`2bSUX0/hmK0;FAG@020;JBGP030;FA
G@2cSe/0/XiJ00P0/hmK00P0]8mJ0;F@F`2eT5/0]Y5L0;F@F`2dSeX0/hiI0;:=F080/XeI0P2aS5P3
0;2;E`090:n:EP2_RE`0[hUJ0:j8F@2]QeH0ZhIB0:Z5D02YQ4d0Z8=<0080ZHA?00@0Z8=>0:N2C@2V
PD`0YX5<0P2UP4/20:J3@`030:F1@`2TP4@0Xgm50080XWe600@0XGa70:9mB02QO4L0X7]60P2ONTD0
0`2PNdH0XGa70:9mB00309mjA@80WWU4102MN4<01@2MMdP0W7I709]eAP2JM4D0VG=400<0V79300P0
Ug=309QdA02JMTH0W7Q809ijBP2ONd/0X7a<0:5mC@P0XWi:0`2PO4P20:5mB@<0XWi:0P2WPT/00`2W
PTd0YX5=0:J0C`020:EoD0060:EoDP2VPDd0YH1<0:AoB`2SOTX0XWe90P2SOTX20:AoB`030:=nBP2Q
O4P0WgY600@0WGQ400<0X7]709mjAP2MN4@00P2KMT800`2JMD40VgI209]f@P0409Ya?@@0VG0l0`2J
L3h[ooooo`00:_ooool80:5gA@80X7A30P2QMD@20:9fA@80XgM600<0XWU50:5hA02PMd<00P2OMT80
0`2QN4@0XgY60:AkA`080:EkB@80Y7]70P2UO4P20:ImB@80Ygi:0`2WOD/30:QnC080ZGm=00<0Zh5?
0:Z0CP2ZP4h00P2YOdd20:QnC0030:MmB`2YP4P0ZH1800H0ZH180P2UP4`0102TOd/0Xgi:0:9mB@2Q
O4P20:1kA`80WWU500D0WGQ409ag@`2JMD40VWE109Ud@00209Qc?`0609I`@@2EKd00U6ho09=]?P2B
K3d0T6Xk0P2?JCX208eX?P0408aW?@2:IC/0RF@j08MR>080QV4g0P26GcH03P24GcD0PEhd07mN<`1m
GS80O5da07UL<01kG300O5da07aL<`1mGCH0O5`f07YI=P1gES<0MUDd1`1bDBh0101aD2d0LU@b075C
<@1`DS0206mA;`0C071B<01aDc40LU@b07=E<`1fEC80N5Ld07]I=01oG3H0Pedf08IO=P27H3L0RF<f
08YT=`2<IST0SFLj08iX>`2=IcX0S6Hi08]U>00409=^>P@0U6lk0`2DL40209Ea@@<0UW920P2HKS`0
0`2GKC/0UV`j09E[>@0209AZ>00909=Y=`2CKST0TVdi099]>@2AJcX0SfTj08iX>`2>Ic`0SFHk00P0
SFLj202<ISL00`2:I3D0RfDf08aV=`0208eW>00408]U=P29Hc@0R68c08]U>080RV@g0P29HcH208YT
=`0608]U>028ISH0R6Hf08YV=P2;ICH0SF@f0P2>HcH03P2?HcH0S6Dj08]T>@2:I3L0RF<d08US<P2:
IC40RfHb08aW<P2:I3<0RfDd08eW>02?JC`0SfPm0P2>Ich0102=ISd0S6Dn08aV=`2<ISL208eW>0<0
SVPi00<0SfTj08aV=`2<ISL01P2<ISL208aW>P<0RfHi0`2:ICP808]U=P0;08MS<`28I3@0R6<f08QS
=`27HSP0QElh08=M>021FcH0Pehd08AO=@26HCL00P28HcT03P27HSP0QV4g08EP=P24HS@0QF<e08MU
=`28ISP0RFLi08QV>026I3H0QF<e08US?P2:I3l0S6I10`2>J4<208aV@@80RVPj0P2;JC/208aZ?080
SF/m00<0Sfe008i/?`2<JSd00P2;JC`00`2<JSd0SV`o08m]@002095Z?`03095[?P2AJc`0TF/j0080
TF`h00<0TF`g08Y/>P2:K3X00P2;KC/0102:K3X0R6Xh08IX=P25IcD2089Q>00N081P>@1lGcL0N5`e
079H<`1^E340JU8^05m;:P1MBBP0FdPX05I59`1C@RH0D40V04do901<?R@0Ac`Z04Dj:00o=RD0>C8R
03D_8@0a;Ql0<2`P02l]800a:a/0;b`K02h[700/:Qd0:BTM02LY7P0V:Ah09BPO0P0T9ah202<V7@@0
8RDL0P0Q91/2028U70808bHM0P0T9ah01@0Y:b00:2XO02PZ7`0W:Ah09BLL00<092HK00<08bDJ02<V
7@0S9Qd00P0S9Qd2028U70808B@K0P0T:1T03P0W:QT0:R/K02d/6P0`;AX0<S0K03@_6`0g<A/0>c<N
03lg8015>b80Ac/Q04Pj7`17=ad0ASLJ0P17>b401016>R00ACTO04@h7P13=ad2048f700H02l[7`0]
:Ad0:bLK02dW6@0^:1P0<b`L03L`800k<R40?SHS03/c800h<1d0=BdJ03@/6@0f;Q/0>30M03Xb7`0a
;Q/0<RlL03<`7@0d<Ah0<c0M038_700`;AX0;R/H200Z:ad00`0Y:b00:2XO02HX7@0302@V6`0802DW
700V:1d09BHN02@U7@0S91`08R<K020Q6@0O81P201hO5`8082<H0P0O8QL04@0P8aP08RDJ02DX7@0V
:Ah0?CHS044i9016>R@0AcTO04Lf6P1=>1T0ESlO05e58`1kGB/0R6Xh099d@P2CMD40UgU50080Wh5;
00`0V7Y406]I<`1<@B<0;bdH02<[7P0R;BD082TT02<V7`0W9ad09RPU02DW900S9B83024S8003028T
8@0S9B809BDU00809BDS00<09RLR02HW8@0W:2000P0W:Ah302LX8P809RLQ0`0U9R0202DW8P0602LX
8P0Z:R80;BXQ030/8@0b;R<0=BlS0P0i<1l203Xa8080>c8Q0`0l<b804@10>240@3PS03lg8P0m=B80
?3<R03Xa8P0i;b<0>2hR034c9P0g=b/0>c`^03dk;00k>2L0>cHS03df900o>2D0BT4R0080Bd0T00<0
CClU04hn9@1??BL00P1@>bH02`1D@bL0DT4W04hn901:?280B3`T04Xn:01<@Bd0CT<_05509P1B@BL0
Dd8X0080E4<Y00H0Dd8X05509P1@?bD0Cd<Y04i2:01=@BL204a09P0;04e19`1?@bT0D4@Z04dn9`1@
@BX0E4@[05Q7;@1HAb/0F4DW05I18P1D?b000`1??bP204hn9`<0CCdV0P1>?2@204dk8`0A04hl901@
?RH0DT0X05A2:P1C@RH0ET8W05Q59`1MB2T0HT/[06I>;01YCbh0Je4^07EJ;`1gG340NEha07aQ<P1n
I3<00P1oIC807@1nIBl0NVHc07IR;`1`G2X0JeHY06UD:@1[EBh0KeTd075K=P1`GC<0He4Y05Y8901F
ABL0D40W04Lh9@16>BT0CT0c05<o901D@2D0ET<U05Q59@1JAbH0G4XV05i<:01OCBL0FDTb05M7<01E
ABh0Dd</0080DT8[00X0Dd</05A4;@1GAbd0EDD[0592:01@@2H0DD4W05=3:@1FAR`0FDT_0P1IBRd0
501JBB/0G4TY05m;:P1TCB/0Ie0^06YB;P1[F2h0JeTa06eK=@1/G3P0K5dl06YM?@1WG3h0IU/o06aK
?@1YFSd0IEHi061B=`1KCcD0FDlf0P1FCSL206=C<@0506AD<P1UEC<0IUHd06QH=P1YFCL00P1[FcT2
07AO=00D07IO<`1iHC<0OV<d08=W=`29JcT0S6hl08M]<P29Kc@0SG0h08ia>@2>KcT0SF`g08aX=P2:
IS@0RFLj08]Y?02<JS`0SVdj08m^>@2>KSD208e]<P0H09Qa=P2JLSL0WGDj0:1f?02SMSd0YGHn0:Ie
?@2UM3`0XgXh0:Ml>02ZOc/0[h8n0;F6@02iRD40_H]20;j<@`35TSl0aiM50<RNC037XU@0`Z9G0;NO
E`2]VE80YiA?0P2^RTh0102_Rdl0/8a@0;6=D@2aSE420;:>DP80/Hm@00@0/8i?0:n=CP2^S4d0[H]<
0P2/RT/04@2/QDX0ZhA90:Z3B02WP4D0YGi30:=l@@2QNSl0X7Tn0:El>P2[P3`0/XM30;Z=B@2oT4X0
`I590<6?AP2oSD@0]8a600@0/h]500D0]He70;J>B02gSdT0]8]90;F<BP020;J=B`0@0;F<BP2cRTP0
/HQ60;27A@2_RTH0[XU30:j7@P2^QT00/HLo0;B8?`2eRCh0^H]00;B=@P2bRd00/8Tn0:j7?080[HHk
0P2^Qc`00`2]Qc`0[XPm0:n9?P020:n9?P080:f7?02[QCX0ZX@i0:Z7A@2XQD<0YH900:9o?@2POC/2
09ml>P030:1m>`2SNcd0Xg/m0080XWXl0P2QNC/20:1h>P80WgLi00@0X7Pj0:5i>`2RNS`0XWXl0P2S
Ncd02@2RNSd0YGe00:Em@02XP4<0YWi10:5i?02OMcX0XGTl0:Em@00209]f?`0<09Ye?P2HLc`0Ug8k
09E`>@2DKcP0Tfhg099`<@2?Kc80SFd`08]]<@2:KC<0R6he0P28KcL06027JRh0R6/_08U/<P29K3@0
R6/c08IX<P24IS80PfDa08EV=`22Hc@0Of0a07aM;P1kG2d0OEh_07mP<@21HS<0OU`^08ES<`2<JcP0
S6/f08UY<029JBh0Sflb09Ig=`80P6Df00H0PFLf089X=@23JS@0Q6/c08E/=025K3<208EY=`80QVXh
00L0Qf/i08Q/>P28K3X0R6`j095d?02CMSh0U7Lo00<0UWU100<0UGQ009Ag?`2@MSd01`2@MSd2091b
=P80TG<g0P2BM3P209=e>@80TgU000H0TWPo091f?@2?MC`0SW@k08ec>P2<LST208M^=P80QVde00D0
QF`d08A[<`23JS80PfXb07eX;`0207mY<003085X<023J340QFLa0080QVLa02X0QVTa08ma>`2KODL0
X89>0:22D02OP540XH9D0:B5E`2^TG40]9Mg0;jRO@35ZH80aZ^00<6VM`2hWV/0/YQU0:27C`2IP4P0
SgI008AZ=`1lHS40Me`]07IK;01fFbh0LEX^071I;`1^Ebd0K5D/06YB;01WCb/0ITh/06E=:`1QBb80
H4XS05m98P1LAR40FT<Q05Q18@1F?b00EChO04Ll7017?1h204Hk7@0=04Dj7P14>1h0@cLO04<g8@12
=R00@C@T03``800d:Qh0:b@J02@Q600O81X07R0M01`Q7@0:01dM6`<071`J0`0K6aT201`L6P<06a/I
0`0J6QP801TK60P06a/I200I6aP801/K6@0401PJ5`0I6aP06A/H01TK60806Q`I0P0K7AX201dM6`<0
71`J0`0K6aT801`L6PP071dG0`0P81P3024Q6@808R8J200U81X00`0Z9Qd0:BDL02LS6P0202HR6@06
02LS6P0X91/0:BDL038V6P0d:1`0=BTM0P0g:al02`0f:Qh0=BTM03@X700g:240=bTP03T[7P0k;Qd0
?C4I03ld6011=QH0@SPE0080Ac8M0P19=1l01018<ah0Ac8M04D`6`13;QT903ha7P0803lb8P10<b<0
@3<R040c8011=Al0@CDM048f7P12=Q`303ha8080?C0O0`0l;ah603d`7`80?2lN2012<Al204Hf7@07
04Pf7P1;=al0C3HO04lf801@=b40DCHQ05`g900205Xg8`0605Ph8`1H>B@0F3`V05To:01K@BX0Fd0U
0P1M?bD00`1N?RD0H3hU064m9@02068l9@0305i09P1O@BL0H48X0080HD<Y00<0Gd4W05do9@1L?R@0
201G?B8305Y28080Fd<Q0`1LA2804`1N?RD0HD8V06E6:P1UART0Hd@U06=58`1VB2@0JT`X06I:9@1W
BbH0J4XV06]:9`1]BbP0KTXX06m;:@1aBRT0L54U075B9P1cE2P00P1dEBT02`1cE2P0LE8V071A9@1i
Db`0N58[07MA:P1fD2T0Me4Z07QB:`1jE2d0NeD^0080OePa00h0OEL`07UF;P1gERd0M5@[07=C:P1`
DbT0MED^07AD;@1bDR/0LE4Z071@:@1aDBX0LU8[07=C;080N5HY0P1gEBP307ID9`0907EC9P1gDBd0
N58^07UC;P1jE2d0O5L]07eH;01oFRh0OeX]0080OUT_0P1mF2h307aG;@80NeH/0P1nF2T01P1oFBX0
P5X[085K;021Fb`0PU`]08=M;P<0Q5h]0P25Gbh308IP;`04081L:P21GB/0PEd[085M:`80PUh/0P23
Gbd01`21FcH0PU`g08=M=P24GcD0QV4e08MR=@28I3@00P29ICD208QT=00<08MS<`25HC40Q60`08AP
<023Gbl0Pf4c08AR=026I3H0QfDg08QV>027ICL0QV@f0`25HcD04P26I3H0QfDg08QV>028ISP0RFLi
08YX>P2>IS80SFDb08eU=02<HcD0RV0f08UO=`29GcT0R5dj08EP<`26HC@0R6<f08]V>@80S6Lj00D0
RfHi08YU>027HSD0R6<f08UT=`0208YU>00<08UT=`28HcH0Qf8e08MT?027I3X0R6Dk08QV>@29IcT0
RFLg08UX=@2:JCH0RfHi0P2<IcX208eX>`<0SVTl0`2?JcT2091/>P<0TFdk00H0SVXj08m[>`2?Jc/0
T6`l095]?@2BKSh209=_?`0409A`?02CKc/0Tflk099^>P80TFdi0P2@K3P00`2>JSX0T6`l095]?@03
09=_?`05099^?P2AKCd0T6/n095/?`2BKD000P2CKT403`2BKD00TF`o091[?P2CK440TV]0095[?P2@
JS/0SfTh08iY=@2=J3@0SFPc095/>02CKSX0UG0l09Qc?`0409Ud@00709Qc?`2FLcd0UW8n09Mc?`2G
Ld40V7A409QcAP0209UdB00809mkA`2NNTH0WGU509eiA@2NNTH0XGe90:=oB`2UPDd20:1kC`0:09mj
C@2NNTX0WGU709eiA@2LN4@0VgQ209ag@02KMSl0VG@m09Mb>`80UW4j00H0Ug8k09Qc?02ILCd0Uflk
09E]>P2DK3/209=Z?00509A[?`2EK400T6`j08m[>@2>JSP00P2=JCL03P2>JSP0T6`j095]>`2FLT80
Ug=309UeA@2KMdL0WGU909mkB`2QODd0XWi>0:AoB`2VPDd0Z8=?0`2ZQE402`2YQ500Z8=?0:N3C`2X
Q500ZHEA0:^7D`2/R5@0[XYF0:n;E`2`S5P0]91P00L0/hmO00<0/hmK0;B@G02fTUh00P2gTel00`2f
TUh0]91L0;>?F`080;B@G0040;RCGP2gTUd0]Y5L0;F@F`80]8mJ00<0]I1K0;JAG02aS5P00P2aS5P2
0;2;E`<0[hYF00P0/8YM0;2:F`2_REX0[HMF0:^6DP2ZQE00ZHA=0:R3C080ZHA?00@0Z8=>0:N2C@2V
PD`0YH1;0P2TOdX02`2VPd40YX=30:F2@P2TP480Xgm30:9nA02RODH0XGa50:5lA`2PNdH0WWU40080
WGQ300<0WWU40:1kAP2QO4L00P2PNdH209mjA@@0WWU400T0WGQ30:5kC02ONDX0W7I709UcA02HLT<0
VG=409]eAP2LMTL00P2JMTH0102KMdL0W7Q809eiB@2NNTX209mkB`X0XWi:0P2SOd/30:B0C0060:F1
C@2XPd`0Z8=<0:R3CP2WPTh0Yh5@0P2VP540102VP5<0Yh9>0:J1C@2TOd/30:9mB@80Y7m;00<0Xgi:
0:9mB@2PNdL00`2NNDD01P2ONTH0X7]70:5lB02ONTH0WGQ409]f@P80VWE10P2KMT8209ed@00409ac
?`2KLSh0Vg8n09Ya?@80VG0l0`2JL3h[ooooo`00:_ooool80:5gA@80Wg=200@0X7A30:5eA02RMTD0
XgM60P2TN4L0202QN4@0X7M309ie@@2MM400WWE10:1g@`2RNDD0XgY6202UNdT20:AkA`80YGa80P2V
ODT20:MnBP<0Yge;0P2XOT`30:UoC@80Zh5?0P2ZP4h0102YOdd0Z7i<0:QnC02WOD/80:V0B080Y81<
00@0Xgm;0:9nBP2QODT0X7a80P2ONdL0102PNdL0WgY609iiA@2LMd<209Ye@@0909Qc?`2GLSh0UW4m
09I`@@2EKd00U6ho09=]?P2BK3d0T6Xk0080SfTj0P2=J3h01P2<Icd0RVDk08UT>P28HcT0Qf8h08IQ
=`80QUlf00<0Q5le085N=01oGS<00P1lGC402@1iG300Ne``07aM<@1mGC@0OEdf07aL=P1jFCH0N5Ld
07IE=003075@;@<0LU4^0P1cDRl00`1cEC<0LU@b071B<00206mA;`0>071B<01bE380LeDc07=E<`1f
EC80N5Ld07]I=01oG3H0Q5hg08IO=P27H3L0RV@g08aV>@2=IcX208iX>`0308eW>P2;ICP0RF<f00@0
Tfhj102DKc/309A`@080UG510`2FLT8209M]>`0309I/>P2EJcT0U6Xh0080TfTg00L0TVPf09=^>@2B
KCT0TVdi091Z>@2?JCX0SVPk0080SFHk202=IcX808aV=`0308YT=@2;ICH0S6Hg0080SFLh00<0RfDf
08US=027HC800P29HcH408YT=`80RF<f0P28ISH00`2:ISH0RfDf08eT=P0208iS=P0>08mS=P2>Ic`0
S6Dj08YT=`29Hc@0RF<b08YU<@2<Ic<0SVTd08YT<`2;IC@0SFLh08mY?02?J3d208mX?`0408iW?P2=
ISl0S6Hg08aV=`80SFLh102>J3T208]U=P@0S6Hg0P2=IcP308aW>P80RfHi0`2:ICP808]U=P0;08MS
<`28I3@0RF@g08UT>028HcT0QElh089L=`21FcH0Pehd08AO=@26HCL00`28HcT01@26HCL0QF0f08AR
=025HcD0QfDg0080RFLi00/0R6Hh08IT=P25HcD0RF<n08YT?`2<IT40SVQ308mYA02>J4<0S6I108]U
@00308YX>P0308]Y>`2<JS`0SF/m0080SF/m00<0Sfe008i/?`2<JSd00P2;JC`00`2<JSd0SV`o08m]
@002091Y?P03091Z?@2@JS/0T6Xi0080T6/g00T0T6/f08Y/>P2;KC/0S6hl08e_?@2<KS`0RV`j08MY
=`25IcD00P22HCP07P20H3T0O5hh07QL=`1aEc@0KU@a06YB<01NBRT0GDTX05Y79`1FABL0Dd8V0510
9P1=?b@0C3hT04Ll:P13>bP0?SDT03Tb8P0e;b40<BdQ02l]800_;B40<B/K02l/6`0^:a`0;2XM02TY
7@0W:Ah09BPM02DX7`8092LN0P0S9Qd3028U70<08B@K0P0R9A`202<V7@8092LN0P0Y:b00100X:Ql0
9bTN02DW700T9Q/302<U6P0402@W7P0S9Qd08bHM02<V7@808RDL0P0Q91/0400T:1T09BTJ02LZ6@0Z
:aT0;RdI030^6@0b<1/0=C0J03Xb7@0l=1d0@cPR04Lm9019?B<0BS`Q04Tj7@17>1/204Pl8P0404Lk
8@16>R00A3PN04<g7@80@SHL00/0;R`P02d[7`0/:1`0;BLI02lX600c;1`0=bhM03Xa800n=R<0>c<P
03L_700203@/6@0603D]6P0h<1d0>S8O030]6P0b;a`0<c0M0P0d<Ah00`0b;a`0<2dJ02h[600802X[
7@0302T[800X:Ql09RPM008092HK03@09BLL02HX7@0W:Ah09BHN02@U7@0S91`08R<K020Q6@0O81P0
7QlG01dN5P0R9AX08B@I020S600Q91T08RDJ02@W700V:Ah0:2/P044i9P15>RH0Ac/U04Lg7P18=1T0
CSTJ05]28`1TBRT0PfDa08e_>`2BM400TG<o09MiA@2QPdl0Wh5;09Af@01NCR`0@cXM02T[5P0U;B80
8bhX01hW8P0O91d0:2PN02HX9@0T9R<08R@Q024S800P8Ql08B<P028T8@0T9R<09BDU0P0U9B<00`0V
9b809RLQ02LX800202LY7P<09bPR0P0V9b4302DV800502<U800U9b80:2TS02/[8`0_;2<00P0a;B80
1`0c;B40?c<S03lc8`0n<R80?C4Q03``800k;al00`0j;Qh204<h8P0D044f8P10=B<0?S8R03``8P0k
;b40>blS038d9`0h>2`0?3d_03hl;@0l>BP0?3LT03df900o>2D0C4<T04a18`1:?b<0BcdR04/k8P1<
>R@204hi9P0;05A3:@1A@2H0CCdT04Tk8@17>b<0B3dW04a1;@1<A2l0D3lU05509P1B@BL00P1C@RP0
4`1B@BL0D3lU04ln901?@bT0CT8X04a09P1;?bD0C40V04e19`1?@bT0DDD[04m0:@1A@R/0EDD/05Q7
;@1HAb/0F4DW05E08@1C?Ql00P1>?RL204dm9P<0C3`U00<0Bc/T04lm9@1>?2@00P1=>b<0?01??BD0
DClW05=1:@1E@b/0E4<W05M3:01IARP0GTTZ06=<;01WCbd0JU0_06aB;`1fFc00Me`_07YO<P1mHS<0
OfDd081V<`20Ic40OfH`07UU<01cGb`0JeLU06=>8@1OBB00GdTT065::01SC2X0IE<[05U78@1A@Al0
DT<V04ho:015=R<0A3LW04do=01<>al0CC`P04ln801A@B00E4@R05I68P1HB2@0FDXS05Y:<`1HB340
ETH_05=3;01B@R/0Dd</05A4;@1EABh0FDP^05M6;01C@RP0DD0V05919`1D@bT0F4L]05Y9;`80FDX]
01@0FDPZ05a9:@1OBbX0I4d[06M@;P1ZDRh0JUT^06]I<@1ZFc@0JE/h06QK>@1VF3/0HePl065E>`1[
FSh0J5Pn06AD>P1ND3H0FDde05I;=@80E4`g0`1RDS00101TE380IEDc06MG=@1XF3H206YJ>080Mf8g
01/0N64e07YR=01oI3D0QFTi08]]>`2=Kcd0QVhb08U_=02=LcX0TG<m095b?02>KCX0S6Ph08QT=02:
Icd0RfTl08e[?@2?KS/0T6li08m_=P2>KS<0SFd`09Ua=02KLcH0WgDi0:=f>`2VN3d00P2XMcd04@2X
MC`0YGdh0:Un>P2/PC`0/HDn0;R9@@2lS480`8i50<6@A037UD00bIU50<ZPCP39Y5H0`JAH0;JPE`2Z
Ue80XY=>0080ZXM=00<0[8U?0:f:D02_S5800P2`SE<00`2aSU@0/8i?0;2>C`020:n=CP<0[Xa=01T0
[H]<0:n8C@2^Qd`0[8E:0:Z3B02WP4D0YGi30:=l@@2RNd00YW/g0:f0?@2fRDD0`95;0<JFCP37UD`0
aY990<B@A@2gSdT0]He70;>;A@2aRD<0/XY40;B<AP2gSdT0^I5;0080]8Y>0P2eRdl05P2dRTh0/XQ<
0;26BP2^Q4P0[XU30:f8@P2]Qd00[hLo0;:8?P2eRCh0]h]00;^=@02gT4<0]Hi10;><?`2aRSd0/8Tl
0:n8>`2`RC`0/HXm0:j9>`2_RS`30;2;?@080:j9>`2/QcT0ZXDg0:b9A@2ZQd<0YX<o0:>0?02QOSX2
0:1m>@0:0:5n>P2UOCl0YGdo0:Al?P2SNcd0XWXl0:5i>`2PN3X0WgLi0:5i>`80XWXl00<0Xg/m0:Al
?P2UOCl00P2VOT006@2RND<0YWe70:ImA`2YP4X0YWe70:5h@P2NMCl0XGQ20:ElAP2MN440W7M009]f
?`2IM3d0Ug8k09Ia>P2EL3T0U6lh09Me=P2CLcH0T70c08e_<`2;KS@0Rg4h08ac>`2=M3`00P28Jbl0
5P29K380RF`d08Q[<`26J380Q6Hb08=U<@25ISL0Pf@e07mP<@1lGBh0Ne`]07eN;`1oH340PF8c07eK
;P26I3H0SV`l08]Z=@24I2/0Q6@W08m`<02KO3/2089W>00608=Y>023JCH0Q6/e08A[<`25K3@0QF`c
0P26JSP00`27JcT0R6`j08U]>`0308U]>`08099e?@2CMSh0UGQ009Ii@@2GNT80UWU109Eh@02DMcl8
091f?@80T78f00@0TG<g099d>02BM3P0TgDi0P2DMSX01P2DNT40TgU0099h?`2AMch0SgDl08id>`80
SG<j00H0R6lg08M^=P27KSH0QVde08E/=024Jc<208=Z<P0607eX;`1oJC00OfT`089Y<@23J340QFLa
0P26Ic401P26JC40SFli09Mi@`2OPDd0XXAB0:>4E@80XH9D01H0ZXe_0;6DM02lWgd0aJV20<R]PP34
ZGX0_:9a0;JLJ@2TRe<0WHA<099i@`27KCX0OV@c07UO;P1gG2d0N5d^079K;`1aFS00KeP^06eF;@1Z
DR`0J50/0P1VCR`02P1SC2<0HT/R06188P1NAR80Fd<Q05U08@1H?b00EchP04Ll7017?1h204Hk7@03
04Dj7P14>1h0A3PP0080@cLQ00P0@C@T03da8@0d:Qh0;2DK02@Q600O81X07R0M01`Q7@/07AdK0P0L
71X301/K6@8071`J0`0K6aT301XJ60P06A/H200K6aT801TK60P06a/I100I6aP201XL6@806adJ0`0M
7A/201`L6P<06a/I200L71X801`M5`<0820H0`0Q8AT2028R6PP09B0J00<0:RHM02TU700W8aX00`0V
8QT01@0X91/0:BDL038V6P0d:1`0=RXN0080=b/O01<0=RXN03DY7@0c9a/0=RLR03LX8@0i:b00>bhM
03hb6P10=AT0@SLG04<i5P17<a/0B3@L04Te7@1:=Qh0BCDM04Lc6`15<AT0@blG00T0?c8O0P10<b<0
0`10<b80@C@Q044e7`02048f7P03048f700o<R40?S4P0080?S4P0P0m<1l203`_7P80?c8Q100n<B02
03d`7`P0@S4O0P16=Qd03P18=Qh0BcLO04`f7`1?=R00D3LQ054f8@1M>2D0G3LT05Xg8`1H>2<0F3TT
05Pl9P1K?bT0G48[0P1M?bD205hn9@06060n9@1Q?BD0HS`U068l9@1O?bH0H40W0`1R@RT00`1Q@BP0
GclV05hn9@0805Pn8`80FT8N0P1K@al305a4800905e58@1N?RD0HT<W06E6:P1UART0Hd@U06=58`1W
BBD0JddY0080J4`W00<0JD/W06]:9`1]BbP00P1^BRP0101`BBP0Ke0T071A9@1bDbL207=D:006079C
9`1`DBD0Ke0T07UC;01hDR/0Me4Z0P1fD2T04`1hDR/0NU@]07aF;`20FC80OePa07eG<01jEbl0MeH]
07AD:`1cDbX0L5<Y07EH<01cERh0LE@/071C:`1_DRX0L5<[075D;01bEBd00`1iEbT207QF:0<0MeDW
00P0N58^07UC;`1jE2l0O5H_07eH;P1oFRh0P5/_085L;`80P5/a00@0OeX`07iI;`1mF2h0OEP^0P1k
ER`01`1jEB/0OUPY07mI:P1oFBX0P5X[085K;022G2d00P23GBh01024GRd0QEl^08EO;P25Gbh208IP
;`80Qf4`0`21GB/2089N;0<0Pel]0P26H3/01P26H3T0QV4g08IQ=@26HC@0QV8b08EQ<@80RVHf00@0
RFDe08QT=026HS80QF4a0P24H3000`23HC<0QF<e08IT=P0308QV>00308MU=`26I3H0QF<e0080QV@f
00<0QfDg08QV>029IcT00P2:J3X03P2?Ic<0SVHb08eU=02<HcD0Rf4g08YP>P29GS/0R5dk08AO<P26
HC@0RF@g08]V>@2=J3/0S6Lj0`2;IST0202<IcX0SFPk08iY?02>JC`0SFPk08aW>P2;IST0R6Dm0P28
IC/00`29IcX0RFLi08YX>00208YY=PD0SFPk0`2>JC`3091/>P80TFdk0`2BKS`208m[>`03091/?02A
KCd0TVhn0080Tflo00<0U71009=_>`2CKc/00P2CKc/4099^>P0;091/?02AKCd0Tflo09A`@02ELD40
U71009=_?`2BKSh0TF`o099]@02DKd800P2EL4<0402DKd80TVe0095/?`2EKT<0U6e209=]@02AJc`0
SfTh08eX=02<Ic<0RfHa09Mb?P2HLcl0VGA009Ye@@2IM40209Qc?`0809Ia?@2EL3`0UW<m09Ib?P2G
Lcl0Ug=109QdA02HLdH209UdB00809mlAP2NNdD0WGY409ejA02OO4H0XGi80:B1B`2VPdd20:5lD003
0:1kCP2ONd/0WWY80080WGU501@0W7U309mj@`2MN440VgHo09Qc?02GLS/0V7<l09Ud?@2JMCh0VW<l
09Ua?@2GKc/0UFdj09A/>`2EK3h0UVe109M^@P2FLT00UG4o09=_?@<0TVhl00d0Tflm09A`?P2GLd<0
V7A409YfAP2LN4P0Wg];0:5mC@2SOdl0Y81@0:J1C@2WPTh0ZXEA00<0[8MC00X0ZXEA0:V4D02WPdl0
Z8A@0:Z6DP2/R5@0[XYF0;2<F02aSET0/XiJ1@2eTF430;B@H0030;B@G02eTEd0]Y9N0080]i=O00<0
]Y9N0;FAG@2dT5`0202dT5`0202kUV40^IAO0;JAG02dSeX0/hiI0;B?FP2gTUd0^9=N0P2aS5P20;2;
E`<0[hYF00T0[XUE0;6;GP2`RU/0[hUJ0:f7EP2/Qe<0ZXE@0:V4C@2XPd`00P2YQ4l01P2XPdh0Yh9=
0:J1C02UP4/0Y7m:0:=nB@80YX=100<0YH920:B0@P2SOd<00P2ROT@0102QO4D0X7]609mjA@2MN4<2
09ag@P0309eh@`2ONTD0X7]60080X7]60P2ONTD509iiA0080:AnD@2QNdh0W7I909QbA@2GLD@0VG=6
09egBP2OND`509agBP0309ehB`2NND`0WWU<00P0Xgm;00@0YH5=0:J2CP2VPTh0YX9>0P2WPdl20:R4
D00C0:V4C@2XPd`0Z8=>0:R3C`2WPE00Yh5B0:J0D@2VP5<0Yh9>0:J1C@2TOd/0XWe90:5lB02RODT0
Y7m;0:F0C02RODT0XGa809mjAP0209iiA@0909mjAP2QO4P0XWe90:9mB@2PNdL0WGQ409]f@P2IM400
VWE10080VgI20P2OMT80102NMD40WGA009]b?P2JLCd209U`?0<0VW0n:oooool002[ooooo00H0W7<o
09ie@@2QN4@0XgY60:ElB02TNdL20:=jAP80XGQ200<0XGQ40:5gA@2QMdL00P2QMTT01@2QMT/0Y7Y8
0:=iA`2SNDL0XWQ60080XGM50P2PMT@20:MnB0030:MnBP2VO4X0YG];0080Y7U<00<0Y7U>0:QoB`2X
Od/00`2YP4`30:Z1C@040:MmB`2XOT`0Z7i<0:QnC080ZGm=0P2ZP4h01P2YOU<0ZGiA0:YoDP2ZP500
Zh5?0:^2CP80[8==00T0[XAB0:f3D@2/PU00Zh5?0:Z0CP2YOdd0Z7i<0:MmB`2RO4l00P2RO4d00`2Q
NdX0XGa80:5lA`020:5lA@80X7]700D0WgY609iiA@2MN4@0WGQ409ag@`0209]f@P0C09Qc?`2GLSh0
UG0l09=^>P2AK3P0SfXf08iY=@2=J3@0Sf/i08eY=`2:ISH0R6<f08IQ=@26HCL0Qf8h08QR>`26H3T0
Q5hg089L=@02081J<`03085K=022G3D0Pedf0080P5de00@0Oe`d07eJ<P1lFC40NUL_0P1iERh807AC
<080Kdh[0P1`Cb`04P1aD2d0LU4^079A;P1bDBh0MEP`07UI<P1jFS40OUdb089P<`26HC@0RF<d08YT
=@29Hc@0RV@e08]U=P2<ISL0SVPi091Z>`80TF/l00P0U6lj09=^>P2BKCT0TV`k09=]?P2FL4<0V756
09YcB080V6hl00@0VFlm09Y`?P2KLCl0Vg4o0P2LLT0309E_@00309A^?`2CKCh0TV`m0080TV`m202?
JCX308eW>P0308iX>`2?JC`0T6Xm0080T6Xm00H0TF/l091Z>`2?JCX0SVPi08eW>02;ICH208YT=@P0
S6Hi2029HcH208QT=00408UU=@2:ISH0S6Ph08eY>@80SVXj00<0S64d08eR=@2>HcH00P2@ICP0102>
HcH0SF8e08aQ=02>J3T208eW>00408]U=P2:I3D0RF<d08US=080R68c0`2;ICH208aV=`<0SFLh0100
S6Dj08iW?02@JCh0TFXo091Y?P2=IS/0RV<h08QQ=P2@JSd0SFLj08YT=`27HC@0QV0c08QR=@2;ICP0
SVPk2029I3L308YV=P80RFDe0`28I3@00`23GS40Q5lb08IQ=00308QS=P0308IQ=025H3<0RVDh0080
RVDh0P2;IST308aW>PH0RVPj0P2;JC/308e[?@0308aZ?02;JC/0RVPj0080RVPj00<0RVPh08]Y>@2=
Jc/00`2>K3`208e[>`P0SV`l00H0Sg8j08i`>P2=KcT0S6hj08]]>`29JS/208QY>`0Q089S=020HC<0
O60a07QM<01cFbl0KUL]06]E;01ZE2/0IE<[061>:01IBBD0ETLV05E7:P1@A2X0BclW04Dj9011>bD0
?SPR03Xe8@0d<Ah0<2lM02`]7@0[;1`0:R`N02lY7@0^:Qh0;b/O02h/7`0[;1h0:2XL02DY6P0S9aP0
9BPO008092LN00D08bHM028U700Q91/08B@K020S6P0502@W7P<08bHM0P0V:aL00`0U:AP092PI02<W
6@03028U6P03024T6`0P8aX082<J00808B@K100R9A`03P0W9a/09bPJ02/X6@0_:1H0<b/F03T]5@10
<1L0@S8H04He6`18=ad0BcXN04hm7`1@@1l0DD4O0P1A@Ad0601G@240Dc`M04`i6`1:>Ad0BC/P04Dk
800n=ad0>C<I02d[7P0]:a`0;R/L034[6`0b:aT0=2`I03@/5`0f:aL0?S4Q03d`800i;Ad0=B`K03</
6P0c;Q/0<BhK038_70<0<BhO0`0`;Ah202l/7@P0:2PN1@0W:Ah302PZ7`0402HW8@0T9Al08B8L01lP
6P@07AhH02008QlX020M900Q72008AdJ02@Q600Y9aP0;bhJ038a7015>Q`0BC/N04`m7P1>>a/0DS/K
05Y2801ZCB/0MELe08E`A@2DNDX0VWU409Yc>P2UOTD0[8]H09EjC@1_FC00>SLb03Ld;`0_;RT0:BXT
02HW8@0T9b008bPQ02DZ8`808B<P0P0R924202<U8P8092HS0`0U9R0202HW8@<09bPR00D0:2TT02LX
8`0V9b809BHQ02@U800302<T7`809RPS00d09RLQ02LW7`0Z9ah0;BTN02l[800b;200@CDY03lc9`0k
;b<0>BdQ03X^8P0n<RH0A3P/0080Ac/_00<0>cPY03Pe9P0d<B800P0b;b002`0d<B80=c@U03Tf9`0h
=b<0>CPT03dk9P11?2H0@S`T04<l8P11>R00@SPM0080BT0U00<0BClT04Pn8`17?B800P16?2403015
>b00C3/W04`k9`1;>b@0Bc/R04`l8P1>?b80D44T05528`1A@2H0DT4W05A3:@80ETD[01/0ED@Z05=2
:01B@BL0Ed<[05E1:01C?bH0DShS054n801C@200E44P05E28@1IAB@0FTHU05Y79`1HAbT0F4L[05E5
:`1BA2T0DD<Y04Y3:@18@BL0AcdT04Hj8P18>B80C3`U0510:@1C@B/00P1:>bH0:P1<?2D0CS`T04ln
901B?R<0E3lT05@o8P1C@200Ed@T05e::P1RCbl0IE8b06IC<`1UDS80I54a079B:@1gEbh0OEhb089S
=@23I3D0PF<a07aN;01iFbL0OE/[07aJ:P1hEbX0MED/071C:`1/D2/0JTd]06M=;01I@b/0Ed4Y058n
9@1=?280Bc/Q04`n8`1>@2D0CT<W04/k8P1=?B@0CclV0551:080DT8Y0100DD4X05109`1C@B/0D3hX
04`j901>?2H0DT0Z05I4;P1E@bd0Dd4[0551801B@R40Dd<R05E5901FARD0F4PW0P1IBBP0601JAC@0
FD@a05Y6;P1KB2X0GT`X069@:01VEBT0JEPZ07IG>P1cESP0KE@f06EB=01ODC@0FU4d05MB=01FDSD0
FDhh05Q==`1GCC@0ED/`05=:;@1AB2T0D4LX04m69@80HDl[00D0HU0/06=A;@1UDbl0IeDa06QF<P02
06YH=00A075E;@1dFBh0MUh`07]U<`1oJcH0PW8g08Ee>@26N3T0QGU7089d@`1mKC`0NfHg07aT=020
I3D0QVLi08YY?02AKSP00P2BKcT01`2?K3H0S6Tc08eZ=02BKcT0V7Do09ef<`2RNcP00P2WP3d0702U
OS/0Xg`i0:Am>P2WP3d0/Ghm0;9o?P2cPSl0]XLo0;V>@02oUT@0a9a70<JQB@32WDl0_i]?0;fKD`2o
WUT0_Z1P0;NMHP2[TUX0X8UC0:R0C`2^QU<0]8aH0;B=E02_RD/0ZhE40:b7@`2^RD<20;B=BP030;><
B@2bRdP0/HY70080/8U601<0[hQ50;68AP2bQTD0/8E10:n2?P2_P3X0[glg0:mm=P2_OC@0]h0m0;V4
@02jRD@0^i590;ZFC02iVD`0]Y]<0;FLC02]Rd`0[Xa=0080[he>102`STl0402eSDl0]8a>0;>;C@2a
RD/0[HE70:Z2A02WOd40YGdo0:^1A@2[PdH0[8A70:b6B02[QdT0ZhU:0:Z;B`2[S4`60:^:A@80ZXU4
00H0[Hm70:^=A`2YRTL0YhQ80:F5BP2UQ4h20:J5D0040;69C02_QdX0[8A70:Z2A@80Z8130P2YPD@0
302/RT<0YhDn0::0>@2RP3T0YX@m0:N5?P2TPS/0Wgdf09af;`2NN340X7Xc0:9l=@80Xgdf00<0XG/d
0:1j<`2VOC/00`2TOC`00`2RO3d0Wg/m09ek?P0209Yj?`0>09]h@P2KN400W7U109ai?`2JN3/0UgDf
09Ab<P2BL300QVL`08MX<@28JC80RV/d08a]=P2>KcP2091a>P04095a>02?KcH0SF`f08]Z=@80RVTf
0P2;JCT2089U:`03089U;@22I2h0PF<_0080PF<a01X0PF8c089P<P22H300Pf4a08ET<@29J3<0SF`f
099b>@2DM3/0TWPm08E[<021Ibh0RFhg08eb?@28KCP0QVXh08Y^?02:L3D0RFld08Q^=@27K3D0R6dh
08Y^?02<L3h0SG5109Eh@080UWU100<0UgY209Qk@`2HNd<00P2IO4@8099h?@<0TWPo0`2CND0209Aj
@@0308id>`2?MC`0TGLn0080TWPo00<0T7Hm08id>`2=LcX00P2;LC@0102:L3D0R6he08M]=025JS<2
08AY=00308=X<@22Ic00PFH_0080Of@]01/0PFH_089W<023J340Rfdk08i`?P2EMdD0Wh5?0:N9E`2X
RUP0XXAB09anC02[RF<0/i5[0;jNM`36ZH40bZj60<N^Q@32ZH40_JIm0<2KK`2eTEl0XXA809Ah=`28
L300OFP_07EP<@1^Fc400P1aFb`03P1bFbl0LEX^06mH;P1/EB`0J50Z06I>:01QBbH0HT`W069;:@1R
Bb/0H4TZ05e5:@1K@bL0FD4W0P1@>a`204hk7@0=04/j7P1:>Al0B3PO04Hg8015=Ql0?SPR03/d8@0e
<1d0<2XL02TU6P0V8a`08b8M028Q7@02024Q6@80820H0`0O7aL00`0N7QH07AhH01dN600601dN60P0
6a`F200K6aT301XJ60<06a/I100L71X301/K6@<06QXH0`0J6aD301/L5P8071dG0P0I6Q@201XK5@04
01/L5P0L7AL07AhH01dN60P06a`F00H06aXE01`K5P0M71L07QdH01lN6@0P7aX2024P6`/0820H0`0Q
8AT2028R6P@0:2@K100W8aX02@0]8Qh0:b0L02XO6`0Y7QX0:QlK02dR7P0a9R80<bPT034U6@02038V
6P0303<W6`0d:1`0=BTM0080=RXN01<0>RPL03`Z7P0o;Al0@C0P04<b8P13<R00@S4M044`7016<Ah0
Ac8O04Td7`1;=al0BcLN04Xf6`18=1T0Ac@F04/^7P1:;ah0BBlN0080AS4N00H0@c8N048c7P0o=1h0
@3DO04Lc6`16<QX204Da6@0<04Hb6P18=1`0BSHN04/g7`14=2@0@c<S044a8@0o;al0?RhN03l_7`11
<B40@S8R2015<1/06`14<Qh0@c4M048`7012<1`0@c4M04@b7P16=200B3HR04Lg8016=Ql0ACDN04@d
7@15=Ah0AcLP04Xj8`1;>b@0E3dN05Dn7`1G?R00FChQ05do8`1O@2@0HT0U06=19P1R@RT0H40W05lo
9P0205dm900305hn9@1O?bH0H40W00P0HD<Q201K@bL205I38P0405U5901LABD0GdHW0658:@80HdPZ
0P1SAB<00`1TAR@0IDLU06I89P0206Q::00406U;:@1]CR80KDhR06e>8P80KTlS0`1_D2@507AA:`<0
Le0Z1@1fDb/307MD;00807YM=@1iG3@0MUTa07AG;`1cERh0M5L_07EH<01fFC48079E:`0807YD9`1i
DbH0NE<V07YD9`1kEBP0OELZ07mI;020FRd207eI9`0307eI:@1mF2/0OEP/0080OEP^00D0OEL`081J
=P20FSH0P5Xe07mI<P0207iI;`80OEP/0140OEP[07]I;01kFB`0OeX^085J;`25Fc40R5dc08UN=02:
GC@0R68c08IP<@24GRl0Ped^089L;@23GBh0QEl`08IP<@0808MQ<P0408EO<027HC80RF<d08]U=P80
S6Hg00L0RfDf08YT=@2=IcP0SFLh08aV=`2;ICH0RV@e0080RF<d00@0R68c08QT=029ICD0RfLg0P2<
J3P0102;IcL0RFDe08QT=027HCX208QS>@0308UT>02:ICP0RfLg0080S6Pf00@0SFLh08aV=`2<ISL0
RfDf0P2:I3D208US=00;08QT=027Hc<0QV8b08IR<P27Hc<0RFDe08]W=`2=JCT0SfXm091[?P2AK3l0
0P2BKD000`2@Jch0SfXm08iY?00408mV>0@0T6Li0`2=IcP208iX>@<0SfTj0P2CKT44099]@080TF`o
00@0Tflo099^?P2BKSh0TVhn0P2AKCd2091/?00309Ib?P2ELCd0Tflk0080TVhj00<0Tflk09Ea?@2F
LSh0102BKSh409=_?`P0UW9200@0Ug8n09Ia?@2CKSX0TF`h0`2@JcL00`2AK3P0UG0l09E`?00209A_
>`0;09E`?02GLSh0Ug8n09Ud@02JMD40UW4m09Mb?P2HLcl0VGA009]f@P2LMd<00P2MN4@0102IMT00
WGY40:5nB02QOTP209mlAP030:9oB@2VPdd0Xh1:00L0Xh1:02T0VGA009Ye@@2KMT80W7M309ehA02N
NDD0WgY60:1kA`2KMT80VWE109Ud@02HLcl0Ug8n09Ia?@2EL3`0U6lk09Mb?P2FLCd0UG0l09A_>`2E
L3`0Ug8n09Ye@@2KMT80WW]309mlA02PODL0XGe90:9nC02TP500YH5A0:F0D`2ZQET0ZhIJ0:^6F@2/
R5P0[HUG0:j:EP2_ReL0[haF0:n;E`030;2<F080/HeI0P2bSUX20;>?F`80]91L102eTEd00`2eTF40
]Y9R0;RDI0020;VEI@030;RDI02fTV80]I5Q0080]XeO00@0]hiP0;R?H@2hSf40^I1R0P2jTF<01P2g
V680]IIP0;BCGP2cSe/0/XiJ0;:=F@80]HeJ0P2cSel30;:>GP<0/HeM00H0[HUE0:b8E02/R5@0ZhMC
0:Z6DP2YQE420:R4D0@0Yh9>102XPdl0202YOTL0ZWm80:YoB02ZOdP0ZGi70:MlA@2TND80XgQ1202P
ODL40:9mB0D0Xgi900`0Y7m:0:5lA`2MN4<0VWE009Ud?`2KMT40WWU40:1kAP2HLch0VWE009eh@`2P
NdH30:9mB0040:5lA`2ROTX0XWi:0:9nBP<0Xgm;0P2TP4`20:MoB`80Z81<102YPDd20:N2CP030:N2
C@2WPT/0Yh=90080Yh=700<0Yh=50:F0C02UP4`00`2TOd/30:=nBP80Xgi900<0XWe80:5lA`2PNdH0
0P2NND@02@2MN4<0XWi<0:1lBP2MNDL0VWI409Ue@`2JMT@0W7Q609eiA`0209]jA00409Yi@`2IN480
UgI009Ie?`80UG@n0`2DLT@[ooooo`00:_ooool0102MM400WgI20:5hA02SNTH30:AkA`060:=jAP2Q
N480XGQ20:5hA02QMdD0XGM70P2QMTT0102QMT/0Y7Y80:=iA`2SNDL20:9hAP80XGM500T0X7I40:Mn
B02WOTP0Ygi:0:IlBP2UNd/0YGY=0:AiC02TNDh00P2XOd/30:V0C0<0ZX5=102WOD/20:QnC080ZGm=
00H0ZGiC0:UnD@2ZOe80ZX1@0:^1C`2[PTh20:b3C@80[H=A00@0[89@0:^1C`2ZP4h0ZGm=0P2XOT`0
1P2RO4l0XWa=0:9lC@2RO4/0XWe90:5lA`80XGa500@0XGa80:1kA`2ONTH0WWU50P2MN4@0402LMd<0
VgI209Ye@@2HLcl0Ug8n09E`?02DKc/0TF`h08mZ=P2>JCD0SFPd08iZ>02<J3H0RVHf08MR=@26HCD2
08IQ=`0908MQ>P26H3T0Q5hg089L=@21Fc@0P5Xc085K=022G3D0Pedf0080P5de00@0Oe`d07eJ<P1l
FC40NUL_0P1iERh807AC<080Kdh[0P1`Cb`0301aD2d0LU4^079A;P1cDRl0MUTa07UI<P1kFc80OUdb
089P<`26HC@0RF<d08YT=@80RfDf00@0S6Hg08eW>02>J3T0SfTj0P2@JS/0202DKcX0Tfhj09=^>P2B
K3/0U6ho09I`@`2HLDH0VW=80`2IKcd209Y`?P<0Vg4o0P2EKd0209A^?`80Tfdn0P2BK3d808mY>P<0
SFLj00<0SVPk08mY?02?JC`00P2@JSd208mY>P0408iX>@2=IcP0SFLh08aV=`80RfDf202<IST808YT
=`80R6@d00T0RFDe08YV=P2;IcL0S6Ph08eY>@2>JSX0S64d08eR=@2>HcH00P2@ICP0202>HcH0SF8e
08aQ=02>J3T0SFLh08aV=`2;ICH0RV@e0P29Hc@208QR<`<0RfDf0P2<ISL308eW>00;08eV>`2>Ic`0
SVLl08mX?@2>Ic`0SFHk08]T>@2:HcP0T6Xm08eW>P2:I3L00P27HC@00`29HcH0RfDh08eW>P0808UT
=`80RFDe0`28I3@308MS<`0308=N<@24Gc80QV4d0080R6<f00<0Qf8e08IQ=025H3<00`2:ICP208]V
>@<0S6Lj102;JC/408YX>P80SF/m0P2<JS`208]Y>`80RVPj1@2<JSX00`2=Jc/0SV`l08m]?@0808i/
?00608ia>@2=KcT0S6hh08]]>@2:K3X0R6Tj0P27J3X05@22Hc@0P64c07aP<@1hGC00LUX^06iG;@1[
EB`0JU@[06EC:`1PCRP0FDTU05E69@1DART0D4@Z04/o9`15>R@0@3XT03hh8P0i=200<c0M02l^7002
02//700902X/7P0_:Ad0;RXN02hZ7P0^;1l0:b`N02PZ700T:1T08bLH00@08bHM100R9A`602@W7P80
8bHM00H09R/G02HZ6@0U:AP092PI02<W6@0R9AX3024T6`8082<J0P0Q91/3028U700>02<V7@0X:1`0
:2TK02`Y6P0a:QP0=RhI03da6@14=1/0ASHL04Xf6`1<>1d0Cc`N058o7`1D@B0205E37`0I05A2701J
@b<0ESlP04hk7@1;>Qh0BS`Q04Dk800n=ad0>C<K02`Z7@0/:Q/0;R/L034[6`0c;1X0=BdJ03D]600h
;AT0?S4Q03`_7`0i;Ad0=B`K03</6P0b;AX0<BhK038_7003034^7`80<2dN0`0_;1d802PX7PP09bTN
00@09RLQ02@U7`0Q8Q`07b0J100M7QP0800P7B@081hS01lM7P0R7aX09R@H02`Y6P0b;a`0=S@O04Hk
7@19>ah0Bc`M04hk6`1C?1X0GdDR06iB;@1jG3P0R7=6099gB02HMd80WgQ10:N2B`2VQUD0R6m606EA
;00g=2l0=34/02d/9`0X:B<09BHP02@W800S:2409BXS0P0Q8b02028T8@808bDR0P0T9R<302DV8080
9RLQ0`0W:28302HW8PD09BHQ00/09RPS02DW8P0V9b409bLO02/X7`0^:Ql0<BdR03D_8`0n=2P0?C<W
03X`900203T_8`0703`b9P0o=BT0@CL[044g:`0i=RL0=c@U03<`8@02034^7`0;03<`8@0f<b@0>3DV
03Pg8`0k>2D0?C/V044l9P13?BD0@c`R04@j8@13>Ah00P1;?bD0101:?R@0BCdS04Pl8P18?28204Lk
8@0d04dl:01<>bL0Bc/T04/k8P1<?280CSlR0511901A@R<0D3lU05509P1C@RP0E4<Y05E4:P1D@bT0
DT4W05509P1E@BT0E40W05<o9P1B?R<0DSlQ05A18@1F@b80Ed@S05Y69@1KAbH0FdPX05U8:P1HAb/0
ETH/05=5:P1A@bT0Bd@Z04U2:018?RD0ASXR04Pi8P1;>b@0CShW054o:@1<?BP0CChW04lo:01A?bL0
DT4W05E19P1G@RD0F4<V05=0801GA2@0G4TY065>;P80I54a01h0He0`069?;`1`D2T0M5@]07YJ<@20
HCD0PV<e085R<`1nH2h0Ned[07mO;P20H340P64c07aO=@1gFc@0KU@a06M=;01RBBX0FT@/05I2:@1B
?RD0CC`R04/k8@1;?B80Bd0T04e29P1;>b80CCdT04lo9P1A@BP20592:@0;0551:01@@2L0Dd</04lo
:01;>b@0C3`U0551:P1DA2d0Dd</0592:`1B@R400P1C@b800`1DA2<0ETHU05M79P0205Q89`0H05U4
<@1IA2l0FTH]05a9:`1OCBT0He4Y06MF:P1ZFB/0MEPj075F>@1[E3D0IE8d05i@<`1JDC@0EU4d05IB
=@1HC3H0Ed/e05M;<`1EBBl0E4T]05=8:P1BAbT0DTLW0`1QCb/06P1RD2`0I58^06EC;`1VE300IeDa
06QF<P1^DRX0L5P/07EM;`1jI3<0OFTd07i]=@1oL3D0Og4d07ea?`1kKC`0NFTh07UT=@1kHc<0PVHg
08QY>`2=K3l0SV/c095^=P2CL3P0TFhf0P2>Jc<08`2BKcL0Ug@l09ef<`2RNcP0Yh0m0:V2?`2WP3d0
YWll0:R1?P2[Q440]8500;B3@@2fQD00^HY20;b@A@31V4P0a9i;0<NQC033We<0`IeC0;nMEP2mWU/0
_ImO0;FKH02ZTET0XXUA0:MoC02/Q540/8UB0;29D02/QTP0ZhE40:f8@P2`RdD0]Hi;00<0]8e:102c
S4T0402hSdd0]Xe;0;F:AP2cQT<0]8E10;F4?`2fQSh0^8Ho0;n;@P2oSD@0`9590<2FCP2nVE80_9]D
0;VLEP2gW5D30;6=C`<0/8a>0P2_Rdd20;28BP0<0;69B`2`R4X0[HE70:Z2A02VOT00Xg/m0:Z0A02Y
PD@0ZX950:^5A`2[QdT0ZhU:0P2[S4`30:b;B0D0ZhY700H0Z8Y40:N9@`2TQD80XX=30:61A02QPDP2
0::1B`030:f5A`2/Q4H0ZX9400<0Z81200@0ZH530:Z2A02]Rd@0ZXQ10P2WQCh0202ZR440ZHM00:F3
?02POSL0[hQ50:b5@P2YPSl0YWll0P2UOS/00`2VOc`0Yh0m0:Qo?@030:N0?`0=0:J0@@2SOd40XX13
0:20A@2OOd@0VgQ209]h@02LND40VgPn09Yh>`2GMCH0UG<c09=a<@0208UZ<@0>08]/<`2<KC@0SVlf
091a>02ALST0TW<j095a=P2@L3L0SFdd08]Z=029J3<0RFPe08UW=`2:J3P2089U:`03085T;021Hbd0
PF<_0080P68`00l0P64b089P<P22H300Pf4a08ET<@29J3<0SF`f095a>02DM3/0TgTl08Y`=@25Jc00
Qfdd08Y_>029KST00P28K3X02@29Kc@0R6hc08M]=027K3D0R6dh08Y^?02<L3h0SG5109Ii@@0209Mj
@P80V7]30P2IO4@00`2JODD0TWPm099h?@06099h?@<0TWPo0P2CND0309Aj@@03091f?@2AMch0TWPo
0080TgU000<0TGLn08me?02>M3/00P2;LC@02@2:L3D0R6he08M]=026Jc@0QFXe08AY=023J340PVL`
085V;`02081U;P0L085V;`22Ic00PfPa08]]>`2>L3h0UGM509n1C`2WREL0ZH]I0:B6E02NP4h0ZHQO
0;6@I`2lW7D0aJR00<Z^QP38[hL0aJb40<6ZP@35X7H0^9IV0:N8C`2IOCh0Rg<c081Z<@1fH2l0KeT`
075K:P80LE//00d0L5T]06iG;@1[E2/0J50Z06I>:01QBbH0HT`W069;:@1QBRX0H4TZ05e69`1J@RH0
F40T0080DC`M0P1??1h00`1<>al0BSTO04Ph7`0204Hg800603lg8P0l=R00=c0N034[6`0[9a/09b@K
0P0S8Qd3024Q6@80820H0`0O7aL801dN60P06a`F200K6aT301XJ60806a/I1@0L71X301/K6@<06QXH
0`0J6aD201/L5P<071dG0`0J6aD201/L5P<071dG200K71H201`K5P0401dL5`0N7AP07ahI020O6P80
8B0K2`0P81P2024Q6@<08R8J1@0X91/302LS6P0802`Q6`0[81X0:b0J02/P6P0]8Q`0;R<M030U7`0a
9R02038V6P80<bLK00X0=2PL03DY7@0f:Qh0=RXN03TW6`0k:Ad0?R`N040_7`12<B40@S4O0P11<1`0
2`16<Ah0Ac8O04Td7`1:=Qh0BcLN04Xf6`19=AX0B3DG04d`801<<B00BS0O0080Ac8O00L0AC<O04@c
7`11=Al0@3@N04Te7@18=1`0Ac<K0080AS8J00/0B3@L04Te7@1;=al0ACHS04<d8@12<b00@34N03l`
7@10<Ah0@C8O048c800804D`6`0:04Dc7`14<Qh0@c4M048`7013<Ad0AC<O04Le8@18=R80AcLP04Hf
7`80ACDN00X0ASHO04Ph8@1:>R<0C3`U05@m7P1E?Ql0EchP05Tn8@1M?b<0Gd0T0P1R@2D00`1SA2P0
HT<W06119@0205m0900306119@1Q@RH0HT<W00@0HT@R101Q@b4805]49@80Ed@S00L0FDDT05e69P1O
ARL0HTLY06=8:P1VBB/0HdDS0080I4HT00D0IDLU06M99`1XBRP0J4XX06U;:@0306e>8P<0KTlS0P1_
D2@407AA:`@0Le0Z101fDb/407MD;00807aL=@1kFc@0NETb07MG<01fERl0MeL`07QH<@1iFC8807EE
;00507UC9P1jE2L0NeDX07aF:@1mEbX00`1nF2/207eI9`0307eI:@1mF2/0OEP/0080OEP^00D0OEL`
085K=`20FSD0P5Xe07mI<P0207mJ<00307iI;@1nFB`0OEP[0080O5X]00h0OeX^089K<025Fc40R5dc
08UN=02;GSD0R68c08MQ<P25Gc00Q5h_08=M;P24GRl0QV0a08MQ<PP0R68c00@0QV0a08QR<`2:I3D0
S6Hg0P2=IcP00`2<ISL0RfDf08iX>@0208eW>00308aV=`2;ICH0RV@e0080RF<d00<0RFDe08YV=P2;
IcL00P2<J3P02`2;IcL0RVHf08UU=@28HS/0R6<i08UT>P2:ICT0RfHi08aX>02<J3H0SFTg0080SFLh
0P2<ISL01P2;ICH0RV@e08YT=@2:I3D0RFDe08QT=080Qf<c00L0R6@d08YV=P2<J3P0SFTi08mZ?@2@
Jch0TF`o0080TVe000<0TF`o08mZ?@2>JC`01`2@IcT00`2AJ3X0SVPi08mY>P0208mY>P80T6Xk0P2A
Jc`409A_@P@0Tfi10`2CKcl2099^?P<0TFdm00<0UW8n09Ea?@2CKc/00P2BKSX00`2CKc/0UG4m09Ib
?P0209A`@0@0Tflo0P2BKSh809Mc@`0409Qc?`2FLCd0U6lk099]>@<0TF`h00<0TVdi09Ia?@2EL3`0
0P2DKc/03`2EL3`0Ug8n09Mb?P2IM400VWE109Ia?@2GLSh0V7<o09Ud@02KMT80W7M309ehA02NNDD0
VGI009ejA0020:1mA`80WW]500<0XWm90:F2C02SOd/01`2SOd/01@2KMT80W7M309ag@`2MN4@0WgY6
0080X7]700L0XGa809mjAP2ONTH0WWU509ehA02LMd<0VgI200<0VWE100l0VGA009Qc?`2HLcl0V7<o
09Ye@@2LMd<0WGQ409mlA02PODD0XGi80:9nBP2SOdd0YH5A0:J2DP2VPE@00P2[QUX00`2/QeX0[HUI
0:j:F0020:n;E`040;2=E`2`S5P0/8aH0;2<F080/HeI0`2bSUX20;>?F`80]91L0`2eTEd0102fTUh0
]I5Q0;JBHP2hU6@20;VEI@030;RDI02fTV80]I5Q00<0^8mQ00<0^I1R0;ZAH`2jTF<00P2kTV@01P2g
V680]IIP0;BCGP2cSe/0/XiJ0;:=F@80]HeJ0P2cSel30;:>GP<0/HeM0P2]RED00`2/R5@0ZhMC0:Z6
DP020:V5D@030:R4D02XPdl0Z8=?00H0Z8=?00P0Z7m70:V0B02ZPDT0ZX590:QoA`2VODD0Y7]30:=j
@PP0Wga6102RODP50:=nB@D0WgY500L0WGQ309ag@P2KMT40VG@o09]f@@2MN4<0X7]600<0XWe800@0
XGa70:9nBP2ROTX0XWi:0P2SOd/30:B0C080Ygm<0P2XP4d30:V1CP060:Z2C`2VPDd0YX5=0:J1C02V
PDX0YX980P2VPTH00`2VPT@0YX5=0:J1C@020:F0C00:0:AoB`2SOTX0Xgi:0:9mB@2TOdX0Xgi90:9m
B02QO4L0X7]609mjA@80WWU400@0XGe;0:1lBP2NNTP0W7Q60P2KMdD209ahAP80VgY400@0VWU309Uh
@P2HMd40UgI00P2FMCl309Ec@b_ooooo000Zooooo`0409mf@P2PMd<0XWU50:=jAP<0Y7]700H0XgY6
0:5h@P2QN480XGQ40:5gA@2QMdL20:5fB@030:5fB`2SNDL0XgU70080XgU70P2RN4H20:5gA@80Ygi8
00<0Ygi:0:IlBP2VO4`00P2UNTd00`2UNTl0Z7m;0:QoB`030:V0C0<0ZX5=00@0YG]90:IlBP2VO4X0
YWa:0P2WOD/20:QnC0060:UnD`2YOU40ZWmB0:Z0D02[PDl0Zh9>0P2/Pdd01@2]Pe40[89@0:b2D02[
PDl0ZX1>0080ZGm=00L0Z7i<0:AnD@2TOTl0Xge>0:=mC02RODT0XWe80080XGa50P2QO4P01@2PNdL0
WWU509ehA02MN4@0VgI20080VWE100d0V7<o09Mb?P2EL3`0U6lk099]>@2@JcL0SfXf08iY=@2=JCL0
RfLe08UU=@27HSD0QV4e0080QF0f0P25GcP01024GSL0Pedf089L=@21Fc@2089L=@0708=M=P20GCD0
P5de07mL=01mFS80O5Ta07YG;`0207UF;PP0M5<`0P1_CR/00`1`Cb`0LE0]079A;P0207=B;`0907AC
<01fFC40NETb07]K<P1nGC80PElb08IQ=028HS<0RF<d0080S6Hg0P2=IcP03@2>J3T0SfTj08mY>P2?
JCX0U6lj09A_>`2CKSX0U6hm09E_@02FL4<0V75609UbA`2KLCl00`2JL3h409U_?@0409E_@02DKSl0
U6ho09A^?`<0Tfdn00<0TV`m08mY>P2?JCX01P2?JCX308eW>P80SVPk0`2?JC`608eW>080S6Hg402<
IST208QT=00308UU=@2:ISH0RfLg0080S6Ph00@0SFTi08aQ=02=HSD0SV<f0P2@ICP00`2>HcH0SF8e
08aQ=00208eW>00308aV=`2;ICH0RV@e00<0RF<d00@0R68c08]U=P2;ICH0RfDf0P2<ISL308eW>005
08mY?02>J3/0SFLj08aV>@2;ICP00P2<IST02@2=IcX0SfTl08eW>P2:I3L0R68e08MQ=029HcH0RfDh
08eW>P0808UT=`<0Qf<c0P26HS8308EQ<@80Q5lb00<0QV4d08MR=@28HcH00P27HSD01026HC@0RVDh
08YU>02:ICP208]V>@<0S6Lj0P2=Jcd0102<JS`0RfTk08YX>P2:J3X208UW>@0408e[?@2<JS`0S6Xl
08aZ?0<0RfTk00T0RVPj08m]?@2=Jc/0RfTi08UW=`2:J3P0S6Xj08m]?@2AKcl0202=Jc/07@2<KcL0
S6hh08]]=`29JcL0R6Xh08MX>@26IcT0QFHh085R<`20HC<0O60a07ML;`1bFRh0KUL]06YD:`1YDbX0
I58Z05m=9`1HB2@0EDHU05=5:01?@bT0BShV04@i8`0o>B<0?CLQ03Pc7`0c<1d0;bhL0080:b`L00T0
:R`N02lY7@0]:Ad0;RXN02d[7P0Z:ad09bTK02@X6@0S9aP0100R9A`402<V7@P092LN00H09RXI02DY
600U:AX092PJ02<V6`0R9A`3024T7@<08B@K0P0R9A`302<V7@0X02TY7@0Z:ad0;b`M03@]6`0j<Qd0
@SHN04Ti801<?280Cc`N054n7P1C@200ET<R05Q68P1HAR00F4HN05M57@1PBBL0Fd@T058o7`1=?200
BcdR04Dk8P0n=Ql0>C<M02XX6`0[:AX0;BXK034[6`0c;1X0=RhK03L_6P0j;a/0?C0P03`_7`0i;Ad0
=B`K03</6P0b;AX0<BhK038_7080<BhO0P0`;Ah302l/7@0302h[700X:1h0:2PN00H0:2PN200W:Ah0
100U9R008b@N024R700O81X201dN60807QlI02007QdR01lM800P7ad0924J02XV6P0b;AX0>C<M03dg
7`19>b00BS/N04Xi6`1>>QT0EclK06M;9P1gFS80QFDn08ihB@2@M4@0UgI10:F0B`2[Qe<0W7eA07EO
>P1C@R@0<RlZ02l/9`0Z:B@09RLQ02@U7`0S9Ql08bPQ02@Y8P808B<P0P0R924202<U8P8092HS0`0U
9R0202HW8@<09bPR0P0U9R000`0V9b409bPR02LX8P0302LX8P809BLR00H09RLQ02TY8@0]:R40<BdR
03@`9@0h<RH303`b9P<0>c4U0`0j<2@00`0f<b@0=34R038_8002030]7P0<038_800e<R<0=S<T03Xg
900k>2D0?cXV048l9P14?2D0AS`S04Lk8`16>R00C40V0P1;?bD00`1:?R@0BCdS04Pl8P0204Lk8@0:
04dl:01<>bL0Bc/T04/k8P1<?280CSlR0511901B@b@0D3lU05509P<0DT4W00@0DD0V050o9@1@?bD0
DclW0P1B?RD08@1C?b@0E44S05I38`1HAB@0FTLV05a89`1MBBP0G4TY05Y9:`1IB2`0ETH/05=5:P1B
A2X0C4D[04Y3:@19?bH0Ac/S04Tj8`1;>b@0C3`U04lm9`1>?bP0Cd0Y0551:01C@RP0ED@X05Q59`1J
ABH0FdHW05A18@1GA2@0FdPX05m<;003065>;P0M061=;@1ZC2H0KU0Z07AG;`1jGC<0OV4e07iR<`1m
HC80O60`089S=@25ISX0QFPn08=W@01jH3d0KeLe069;;01KA2D0FDD]05M3:`1@?RH0C3`S04Tk8@17
>b40BCdS04Y09@1;>b80CCdT04lo9P1A@BP00P1B@RT02P1A@BP0D40W05=3;01??bP0Bc/T04`l9@1@
@2T0Dd</0592:`1@@2T305=2900305A39@1EA2H0ED@V0080ETDW00h0F4<^05Q4;01JARd0G4T[061=
;01TDR`0J5L/06YI;P1`EcT0KEHg06MD=P1QD3@0GDld05U?=080EU0f0P1DB3800`1DB300E4P^05A9
;@0205A9:`0305A9:@1QCb/0HDl[0080HDl[0P1RD2`206=A;@0i06AB;P1[DRT0KeH]07EN<P1jICH0
NfTg07YZ=P1iJS<0MFPa07AW>P1cICH0Lf8d07EP<@1iHC40PFDe08UZ>`2>KSd0RfP`091]=@2DLCT0
UG8j099_=`2AKSH0Tg0h09Ic>`2MMS<0Xg`i0:R1?P2[Q440ZX=00:^4@@2_R4D0/X]80;R7A@2iR4D0
^X]50;b@B@30UTX0`ia?0<JQD@39Y5<0`j5I0<:PF@2oWUT0_IiM0;ZLGP2dUed0ZHmF0:>8D@2VO4X0
Z7m;0:Z1B`2ZPTL0ZH530:^4@@2`RD@0]8i700<0]Xm<0`2gT4d20;RACP0F0;jGEP2kU5<0^8m=0;N<
B02gRTH0^ha60<2?BP33Td/0aYM70<JHBP35VDh0`i]C0<6LF02mVe`0^I]O0;VJH@2dT580/hmA0;:>
D02`S4h0[XY<0:f9B`80[8Q:0100Zh=50:f5A`2`R4X0/HU;0:n7B@2[PdD0Ygm10:Al?P2WOD40Ygm2
0:V1A02ZQ4H0ZXI80:^9BP2[S4`0[8e=0`2]Rd/20:b:BP80ZhU900/0ZXQ80:F4?`2TPd00XX4n0:1n
?P2OOCh0Wge00:1m@`2QOT@0Z8120:Mo@@030:In@0060:R0@P2ZPT@0Zh=50:f:AP2/RDD0ZhQ40P2/
RDD0302ZQd<0YH8n0:5n>P2_Qd`0Zh=80:Em@P2QNCh0X7Pm0:Al@@2YPDH0[HE:0:Z1?`80ZH9100@0
ZX=20:V3A02WPdD0YhE80P2UQDX0202KN480VgQ009]h@02KN3h0VGLj09Me=P2ELc<0U78b0P2>KSD0
102?KcH0T70g099b>@2CLcX209Ad>`0609=c>02ALCH0SVhe08]Z=028Ic40QfHa0P27IS<2089U:`0A
085T;021Hbd0P68^081R<01oHBl0Of0a089P<P22H300Pf4a08ET<@28Ic80S6/e091`=`2CLcX0TgTl
095g>P2;LCH00P25Jc800`2:KcP0RVlj08I[=P0208Q^<`0608M]=027K3D0R6dh08Y^?02<L3h0SG51
0`2HNd<209UlA0<0VWe5202CNCh2099h?`80TgU00`2DNT400`2ENd80TWPo09=i@00209Aj@@0?09=i
@02BN3l0TGLn091f?@2<LSD0Rg4d08Y`=@29KcH0Qfdd08I[=025JSD0Q6Td08AY<P23J340PFH_0080
P6D^02<0PFH_08=X<@24JC80Rfdk08i`?P2EMdD0Wh5?0:R:F02ZS5X0YXQF0:63D@2UQ5T0[HaQ0;RH
K`32YGd0bZj70<Z`R`39[hX0ajn;0<ZXPP2oWW40[i5K09n5B02CNcd0QFlf07YR<P1aFS00LU`Z079L
:`1aFbX0L5X[06eF:P1ZDbT0Ie0W06I?9P02069<9@08069<9`1QBRP0GdPX05a59P1J@b@0F40T05<n
7`1B?Ah2050m7`0=04dl801;>R00BCTP04Lh8@16=b00@SLQ03hf8@0j<Ql0=2dM02lY7@0Y9A`09R<L
02DR7@02028R6P808B4I0`0P81P00`0O7aL07QlI01hO6@0601hO6@P071dG200K6aT201XJ60806a/I
0`0L71X00`0M7A/071`J01`L6P0301/K6@<06QXH0P0J6aD201/L5P<071dG00<07AhH01`M5`0L7AL0
0P0L7AL301/L5P0301XK5@0L7AL071dG00H071dG0P0M71L201hM600401lN6@0P7aX08B0K024P6`X0
820H0P0Q8AT3028R6P0302<S6`0X91/0:2@K00H0:2@K00@0:QlI02/P6P0]8Q`0;b@N0P0`9Al202lT
7P80<RHJ00<0<bLK03@X700e:Ad00P0f:Qh01`0g:al0>BLK03XX700l:Q`0?RdM040_7`10;ad00P10
;a/01@16<Ah0Ac8O04Td7`1:=Qh0BcLN0080BSHK00@0BCHH04ld8@1?=240CC@P0P1:=1l01`18<ah0
AS@N04@d7@14=1d0C3PP04Xf7P19=Ad00P17<a/00`18=1`0BCDM04Xf7P0204He8`0304@c8@13<R00
@S4O0080@c8P00<0A3<Q04Ha7016<A`01P16<A`02@16=1h0AC<M04@b7013<A/0A38L04Dc7@17=Al0
B3HP04Pf7P0304Le7@0404Pf7P1:>200BcTQ04dk8`80E3dN00@0ESdO05Tn8@1L?R80Gd0T0P1R@2D0
0`1UARX0I4DY06939`0206529P0306=4:01TABT0IDHZ0080IDLU00@0I4HT06=58`1SAB<0HT@R0P1Q
@b4805i59`0805U58P1JAR<0GDHT05m79@1QAbH0IDPX06I9:@1WB2T206A6900306E79@1VB2H0IdTW
0080J4XX00<0JD/Y06a<8`1/C2<00P1]CB@306i>9@0306m?9P1cD2X0Le0Z00H0Le0Z00<0ME8Z07IC
:`1fDb/00P1gE2`307QE;@80Ne/b00@0NET`07QH;`1hF2l0N5P_0P1iFC0807EE;00307YD9`1kEBP0
OUP[0080P5X]00<0OUP[07aF:@1jE2L00P1nFRP00`1nFRX0OUT/07iI;@0207iI;`0507iH<@21FcH0
PE/f081J<`20Fc400P1oFRh03`1oFRd0Oe/[07mK:`1mFbd0OU`^085L;`23GC00QUda08UN<`2:Gc@0
Rehd08QR<`27HC80QV0a08EO<00208IP<@0308MQ<P28HS<0RF<d00L0RF<d00<0R68c08US=02;ICH0
0P2=IcP0102>J3T0SFLh08eW>02?JCX208iX>@0308eW>02<ISL0RfDf0080RV@e00<0RVHf08]W=`2<
J3P00P2=JCT0102<J3P0RfLg08YV=P28HS/208UT>P0308YU>@2;IST0S6Ph0080SFTg00@0SVPi08eW
>02=IcP0SFLh0`2<ISL00`2;ICH0RVHf08UU=@0208QT=00708UU=@2;IcL0SFTi08iZ>P2?JSd0T6/n
099]@00209=^@@03099]@02@Jch0SfXm00@0T6Xk102?JCX3095[?080TV`m0`2CKCh00`2EL4<0UW54
09IaA00509IaA0<0U7100P2CKcl3099^?P0309Ib?P2ELCd0U70l00<0U70l00<0UG4m09Ib?P2FLT80
0P2ELD400`2DL400Tflo099^?P02099^?PP0Ug=300@0V7<o09Mb?P2DKc/0Tfhj0P2BKCT209=^>P05
09Ia?@2EL3`0U6lk09A_>`2EL3`00P2GLSh0302IM400VgI209Mb?P2GLSh0V7<o09Ye@@2KMT80W7M3
09ehA02NNDD0V7Do09ai@`80X7e70P2NNdD00`2QOTP0YH9<0:B0C0070:B0C00609iiA@2ONTH0WgY6
0:1kA`2QO4P0XWe90P2SOTX20:AoB`040:=nBP2RODT0XGa80:5lB080X7]70P2NNDD309ehA00309ii
A@2PNdL0XGa80080XGi600H0XWm90:B0C02UPDl0YX9B0:N3D`2XPeH20:b7F`030:f8F`2^RUX0[h]I
0080/8aH00@0/HiH0;6=F@2aSET0/HeI0P2bSUX30;>?F`<0]91L0P2eTEd30;JBGP030;JBHP2gTf<0
^IEU0080^YIV00<0^IEU0;NCH`2fTV800`2hTV<20;VCI0<0^YAU00H0]iQR0;FFH02dTeh0/hmK0;:>
FP2bSET20;F=FP80/hmO0`2bSUh30;6=G@060:j:EP2]RED0[HUE0:b8E02[Qe<0ZXIB0P2YQE470:V4
D0030:R3C`2XOdT0ZH1:0080ZX5;00@0ZH1:0:MnB02UO4H0Y7]5202OO4H40:=nB@D0XWe800d0VgI1
09eh@`2QO4L0Y7m:0:=nB@2PNdH0W7M209Ud?`2KMT40W7M209iiA02PNdH0XGa700<0XWe80P2ROTX2
0:=oB`<0Y81<00@0YH5=0:J1C@2VPDd0YX5=0P2WPTh30:R3C`80YH1<00<0YH1;0:F0B@2UPDL00P2U
PDD02P2UPD<0ZHA@0:R3C`2WPTh0YX5=0:F0C02TOd/0Xgi:0:9mB@2UP4/20:AoBP030:=nB@2RODP0
XGa70080X7]600P0Wg]70:1lB02PO4P0X7a809mkA`2MNDD0W7Q409]g@`80WGY40P2LND<0102KN480
VWM109Uf@02IMT0309YfAR_ooooo000Zooooo`80XGQ400<0XWU50:=jAP2TNdL00`2TNdL20:9i@`03
0:9iA@2RN4H0XWQ80080XWM:00<0XWM<0:=iA`2SNDL0102SNDL20:9hAP80Ygi800<0Ygi:0:MmB`2V
O4`00P2VNdh00`2VNe00Z7m;0:QoB`030:V0C0<0ZX5=0`2UNdT20:IlBP<0Yge;00H0ZGiC0:UnD@2Z
Oe80ZX1@0:^1C`2[PTh20:b3C@80[89@0P2[PDl20:Z0CP80ZGm=00`0YGmB0:EoD02TOTl0Y7i=0:=n
BP2RODP0XWe60:5lA@2RODT0XGa80:1kA`2NNDD209ehA00309]f@P2JMD40VGA00080Ug8n00/0UW4m
09A_>`2BKCT0TF`h091[=`2?JSH0S6Pf08]W=@29ICD0R6<f08IQ=@0208EP=P0408AN=`25GcP0Q5hg
08AN=`80Pedf0`22G3D2081M=@0407mL=01mFS80O5Ta07YG;`80NEH^201cDRl03P1^CBX0Kdh[071?
;01aD2d0LU4^07=B;`1dDc00ME@a07MJ<P1jFS<0Ne/b07iM<P21Gc80QF0c0P28HS<208eW>0<0SVPi
0`2?JCX02@2EL3/0UG0l09E`?02EKch0UW1109I`@`2GL4D0V75609ab@00209]a?`0309Y`?P2IKcd0
V6hl0080Ufdk102DKSl409=]?PP0T6Xk102=IcX408iX>`80RfDf0`2<ISL308eW>0P0S6Hi202=IcX0
0`28I3@0RFDe08UU=@0208YV=P80RfLg00@0S6Ph08aQ=02=HSD0SV<f0P2@ICP00`2>HcH0SF8e08aQ
=00308aV=`0408]U=P2:I3D0RV@e08YT=@80RF<d0`2;ICH208aV=`<0SFLh00<0T6Xk08iX>@2;ICH0
0P29Hc@02`2;ICH0SFLh08mY>P2>J3/0SFLj08]U>029HcH0R68e08US=P2;ICP0S6Hi00P0RF@g00@0
QV8b08EQ<@25HC40QF4a0P24H30208=O;`0408AO<P25H3<0QF0c08IQ=0@0Qf8e0`2:ICP208]V>@<0
S6Lj00H0SV`n08e[?@2=Jcd0S6Xl08]Y>`2:J3X208UW>@@0S6Xl102;JC/00`2@KSh0SV`l08YX>002
08QV=P0308]Y>@2@KSh0Tg5100P0SF/k02T0Rfhf08]]=`2:K3H0R6Xf08MY=`26IcP0QFHh08AU=`21
HS<0Of0b07]O<01gG2l0LUX^06eF;01ZE2/0JE<Z06=A:@1NC2H0EdLS05A5901CABP0CT8X04Tm9@13
>280?CLQ03/e7`0g<Qh0<BhK02h]6`0[;1`0:R/K02T[7@0^:1`0;BTM02hZ7P0]:ah0:R/M02LY6`0T
:1T08RHG020S6P02024T6`05028U700S9Qd092LN02@W7P0U:1l00`0S9Qd402@W7P0602DX7`0U:AX0
9BTJ02@X6P0S9Q/08RDL0`0Q91d00`0P8Qd08B@K024T6`03028U70<08bHM00d0:RXN02//7P0`;Ah0
=c0N03de8016>R80CShU05519`1E@B00ET8Q05U58P1LB2<0GDXR0080GT/Q01T0GDXO06I@:@1PBRD0
ED8Q04ln801;?B<0ACXT03hf8`0h<Al0:BLJ02XX6@0]:Q/0<B/K03@]6`0g;a`0>C4L03`a7@0m<200
?2lO03P/700d:aX0<R/I038]6P0`;AX0<BhK00<0<2dN0`0_;1d202h[70P0:2PN0`0W:Ah402HX7@05
02DW700T9Al08b@N024R700O81X00P0M7QP08P0N7aT07b0J01dM7@0N7Q`08B0K02PT6@0`:QX0>C4N
044f8016>R00Bc/R04/j801<>A/0DS/K05e37P1^DRX0PV<g08i]@02CO4X0T7A209Uh@`2[QU80ZXQJ
08]_BP1OBc00@CDO02dZ9@0[:2<09bHQ02@U7`0S91h08bHO028W800S:242024S80808R@Q0P0S9B82
02@V8`<09BHP0P0V9b4302LX8P0402@U7@0U9Qh09bPP02TZ8P80:R/S0P0Y:R8202DW8P0802LX8P0Y
:B40;R/R03<_900f<RL0>S@X03Xb9@0k<bH203`d9`0303/c9P0h<2<0=BdP0080<b/N00<0=34R038_
800a;Ql00P0`;Ah0200b;b00=34R03Db8`0m>2D0?STV040i9P13>bH0AS/U0P18?2@01P1;?B<0CT0V
04i09P1=?bD0C3hT04/m8`80BS`R00T0BC/Q04dl:01=?2P0C3`U04`l8`1=?B<0Cd0S05529@1B@b@0
0P1@?bD205509P80D3lU0P1??R@0601A?BD0DCdT058n9@1D@2D0ET<U05U69P1KB2L0G4TX05e9:01N
BRT0GDXZ05]:;01JBBd0EdL]05=5:P1BA2X0CDH/04]4:P1:@2L0B3`T04Tj8`1:>R<0Bc/T04dk9@80
CClU00X0D40V05919@1D@bD0F4DU05Y59P1KAbH0ET<S05Q59@1KB2P0GT/[0P1OC2`02P1NBb/0GDXZ
06E89P1YC2X0KU8]07=G<01hG3@0NUld07]P=@1kH3<2089W?00B07mV?P1jHS`0LEXh06E@<@1KAR/0
E40U05M5;`1D@R`0CclX04Xk9016>R80AC/R04Lm9016?bD0Bc/R04dm901??bH0DD4X0P1B@RT0101A
@BP0D40W05=4;@1>?bP204Xk900504ho:01@@BX0Cd0Y04`m9P1B@BD00`1C@RH405A39`0H05M3:P1H
A2/0FdL/05i;:`1QCRd0IE<_06QF<01ZF300JEHh06MD=P1RDCD0GDld05U=<`1GCC@0EDhd05A>=P1B
@bh0Dd@_05A5;P1EAbd0ETP]05M9;01HBRd0F4/[2@1PCRX05@1/EB/0LEX`07MR=`1kJC/0O6/m07QZ
>`1cICH0Kf<a071S=`1_H3D0L5lc07=N;`1gGbl0Of<a08IX=02:JSL0RFH/08m/<P2GM3X0VGHl09Md
>P0209Eb>00409Ic>@2ON3D0YGhk0:Z3@080[HI301/0[hQ50;B=BP2hTDh0^ha80;b=B@2mTDX0_iE=
0<:JDP35We@0b:9G0<VUF@33XUd0`:5N0;jOGP2kW5`0]YQJ0;2AF02ZRe@0YHI?0:IkB02VNdH0YGY3
0:Il@02XOcl0[HE00;B<AP2iTDT00P2hTDh0102iTTl0^Y=@0;^DD@2kU5420;bEDP0E0<6KG02nUUP0
^I9A0;J=B`2hSDT0_8m;0<BED@38VE<0aim80<NNC034WE00`YaE0;fIF`2kV600]iIS0;JDIP2iTeD0
]i5C0;B>D02aRdd0[hU;0080[HM90180[8I80:b4AP2^QTP0/XY<0;F=C`2dS4h0/8Q:0:^3A@2XP480
Yge10:Mo@P2XP4<0ZXA60:Z6B02/RT/0Zha<0:b=C@2^S4`20:f;B`080:b:BP2[RDT0ZXQ80:Z8B02Y
QdL0YX=10:F2@02SP3h30:5n?P030:9n@02SOd40YGhm00<0Y7dl00@0YGhm0:R1@02ZPd80[8E40P2Y
QT@0202ZQdD0ZhQ60:Z7A@2WQ480XWlm09ml>P2IL3X0Ufhh0P2FKCL01@2IL3X0WgI00:ElAP2YP4X0
Z7lm0080Yh0o00L0Z8500:R2@`2WPdD0YhE80:F5BP2VQT/0VgQ20080VgQ000D0VWLm09Ug>P2GMCH0
UW@d09Ec<`0209Aa=`80UG8h02@0UW<i09Md>P2HMC/0V7Dk09Ad=`2BLSD0Sfld08][<P28Ic40QfH`
08IU<026IC80PfH/089U:`22IBd0PF<]081R;P20HS00Of4_07mP<@22H380PV0`08=Q<@25I340R6Lb
08a[=@2?KcH0TG4h09=j>P2GOSh0TGLj08E[<023JC00Rg4h08aa>P24JC@208Q^<`0608M]=027K3D0
RFhi08]_?@2=LCl0Sg=31@2JODD309]nAPP0U7Xo0`2CND0309Aj@@D0UG]200<0U7Y109=i@02BN3l0
0P2AMch208ab=@0408]a=P29KcH0R6he08I[=080QFXe00<0Q6Tb08=X<@22Ic000P20IBh06`22Ic00
PfPa08AY<P2;KC/0SW0n09AfA02OPDl0ZH]I0:f?G@2ZS5X0YHME0:>3E02ZRE`0]IIZ0<2SN@39[HH0
c;:=0<jdT`3=]I<0dK2=0<RXO`2hWFP0ZY1E09j4A`2?MSh0P6He07ML<@0207AN;006079L:`1`FRT0
KELX06YC9`1XDBL0Ie0V0P1SCB@0201SCBH0HT`W06199`1MARH0FT<T05Q18P1E@240E3lP0P1B?b40
0`1>?B40C3/Q04Xj8@0204Lh8@0804<i8011=R00?3@O03P_7P0b:Qd0;BHL02TU700W8Q`202<S6`80
8R8J0`0Q8AT00`0P81P07QlI01hO6@0601hO6@P07AhH200L71X301/K6@<071`J0P0M7A/201`L6P<0
6a/I0`0J6QP301/L5P<071dG0P0M7QP201hO6@0301dN600L7AL06a`F00806Q/E00<06AXD01dN600M
7QP01P0M7QP301hM600301lN6@0P7aX081lJ00808B0K2`0Q8AT3028R6P808b<K100X91/402TU7009
02XP5`0/8QT0;bDL034W7P0b:1l0<BLN02lU700]8aX0<RHJ0080<bLK00<0=2PL03DY7@0f:Qh00P0g
:al01P0i9a/0>RPL03/Y6`0m;1`0?RdM03l^7080@2lK00D0Ac8O04Pc8019=1l0BSHN04Xf7@0204/g
700404/h6P1A>280D3LQ050g8@80CCLP00P0C3HO04/e7P1:=1d0B3@L04hj8P1=>B40BcLO04Te7@80
B3@L00@0BCDM04Xf7P18=R80B3HR0P17=B4404Hd80P0B3<N00<0AcDM04Hd7015<a/00P14<QX00`16
=1`0AcDM04Pf7P0304Xf7@0?04/g7P1<>1l0CCTP04hj8@1?>b80Dc`M05@m7P1F?Al0F3dP05`n8P1N
?b<0HClT06909@1WB2/0ITLZ00<0I4DX00<0IDHY06M8:`1XBB`00P1WBBL00`1VB2H0IDLU06A69002
06=58`0306948P1QARP0HDHX00H0HDHX00P0GDLR05i88`1OAb<0HDLT06E89P1VBBL0IdTW06Q::080
IDLU0P1VB2H0101WBBL0J4XX06Q::01XBRP306a<9@80KDdV0`1^CRL3079?:@@0Le0Z00D0M54[07EB
:P1fDb/0MU<[07MD;00207QE;@80NEH^0P1lFc0607]J;`P0MeH]00P0NU@W07eG:P20FRd0Ped`089L
;`1oFB`0NeDX07QB9@80OUXX00<0OUXZ07iI;01nFBd00P1nFBl01@1nF340PE/d085K=021G380PE``
0080P5/^0P20G2`01P20G2X0Oed]081N;P22GRh0Q5h_08QO<@80RUlb00<0S60c08QR<`28HS<00`28
HS<208US=0T0RV@e0P2;ICH00`2<ISL0SFLh08iX>@0208mY>P<0T6Xk00<0SfTj08iX>@2=IcP00P2<
ISL0102;ICH0RfLg08aX>02>JSX208m[>`0408iZ>P2<J3P0RfLg08US?080RVDk00<0RfHj08aW>P2=
JCT00P2>JSP608iX>@80SFLh00/0RfLg08YV=P29ICD0RFDe08YV=P2<J3P0SVXj091/?02?JSd0TF`o
099]@00209A_@P0309=^@@2BKD00TF`o00<0TFdm102@K3`00`2?Jc/0Tfdn09A^?`0209A^?`80UFm0
0P2FL44409MbA@@0V7=6102ELD4209A`@080Tflo0`2FLSh209Ea?@<0UW8n0P2GLd<0102FLT80UG51
09A`@02CKcl2099^?PP0V7A400H0VGA009Mb?P2EL3`0U6lk09=^>P2DKc/209E`?080UW4m0P2EL3`0
2`2FLCd0V7<o09Qc?`2JMD40VgI209Mb?P2HLcl0VGA009Ye@@2KMT80WGQ40080WWU500@0VGI009ej
A02PODL0X7e70P2NNdD00`2QOTP0YH9<0:F1C`070:F1C`<0Xgi:00<0Y7m;0:F0C02UP4`01@2VPDd0
0`2UP4`0Y7m;0:AoB`080:=nBP80Y7m;0P2SP4P03`2TPD/0YX9>0:N3D@2YQED0ZXIF0:Z5F02]R5`0
[XUM0:j9G02_Re/0/8aJ0;6=F@2bSUX0/XmI0;:>FP030;>?F`80]91L0P2eTEd20;B@G0<0]I5M0`2f
TUh00`2gTf<0^9AT0;ZFIP020;^GI`030;ZFIP2hU6@0]i=S00@0^IEU102jUVH01P2gV680]IIP0;BC
GP2cSe/0/XiJ0;:=F@80]HeJ0P2cSel30;:>GP<0/HeM00H0[h]G0:j:EP2^RUH0[HUE0:b8E02[Qe<2
0:Z6DP@0ZXEA102YQ5020:R0C0060:V1C@2ZPTh0ZH5=0:R0C02VOTX0Y7a8202OO4H40:=nB@D0XWe8
00<0WGQ309mjA@2QO4L00P2RODP0202PNdH0WWU409ag@P2LMd80WGQ309iiA02PNdH0XGa70`2RODP3
0:=oB`<0Y81<0P2UPDd20:F1C`<0YX9@0`2WPe420:AoB`030:AoBP2TOdP0Y8160080Y81400X0Y812
0:^6DP2ZQE40ZHA@0:R3C`2VPDd0YH1<0:AoB`2SOTX0YX5<0P2UP4/20:AoBP80Xgi900X0XWe809ml
AP2PODL0XWm90:>0BP2ROdT0Wga609ai@`2JMd40WgY50P2NND@209eh@`80W7M200@0VgI109egAP2M
MdH0WGM6:oooool002[ooooo1@2SNTH20:AkA`060:ElB02RND<0XWU30:9iA@2RN4H0XWQ80P2RMdX0
0`2RMd`0XgU70:=iA`040:=iA`80Y7Y80P2WOTP00`2WOTX0Yge;0:MmC@020:MlC`030:MlD@2XOd/0
Z7m;00<0ZH1<0`2ZPDd20:EkB@80YWa:0`2WOD/01`2XOT`0ZGiC0:UnD@2ZOe80ZX1@0:^1C`2[PTh0
0P2/Pdd40:^1C`@0ZX1>00`0Yh5D0:N1DP2VP540YGm>0:AoB`2SOTT0XWe60:5lA@2SOTX0XWe90:1k
A`2ONTH209ag@`0309]f@P2IM400V7<o0080Ug8n00h0UW4m09A_>`2CKSX0TVdi095/>02@JcL0S6Pf
08]W=@2;IcL0RVDh08QS=`27HSP0QF0f08AN=`<0QElh0P24GSL208=M=P07089L=@20GCD0P5de07mL
=01mFS80O5Ta07YG;`0207UF;PP0Le8_0100KTdZ06m>:`1`Cb`0LE0]07=B;`1dDc00ME@a07IE<P1h
Fc<0NUXc07aL<`1nGC80PElb08EP<`27HC80R68c0P2=IcP208iX>@0:08mY>P2@JS/0T6Xk095[?02E
L3/0UG0l09Ia?@2GLD00Ug5209MaA080Ug150P2KLCl00`2JL3h0VFlm09Q^?00209M]>`0309I/>P2C
KCh0Tfdn0080Tfdn102DKSl8091Z>`P0SFLj0`2;ICH308aV=`80SFLh202<IST808eW>P@0RFDe102:
ISH00`2<HC@0SF8e08iS=P02091U>00408iS=P2=HSD0S64d08aV=`@0RfDf102:I3D308]U=P80S6Hg
0`2=IcP00`2>J3L0SFLf08YT<`0208US<P0808]U=02=IcH0SfTh08eW>P2<IST0RfDh08YT=`29HcH2
08YT=`0308]U>029I3L0RF@g00H0RF@g0`25HC4208AP<0<0Pel_1025H3<01026HC@0Qf8e08MR=@28
HcH308YU>080RfHi0`2<IcX0102>K3h0SF/m08e[?@2<JS`208]Y>`80RVPj102;JC/408aZ?003091^
?P2>K3`0RVPh0080R6Hf00<0RfTi091^?P2CLD40202=Jc/07@2;KSH0Rfdg08Y/=P28JSH0QfTg08IW
>025ISP0Q6Dg081Q<P1oH380Nel`07IK;P1aFBd0KEH/06YD:`1XDRT0HU0X05e;9@1FAR80Dd@S0594
9`1=@BL0B3`T048g8@0l=R00>S@N03Ha7@0`;AX0;B`J0080:R/K00X0:B/M02hX700/:1`0;BTM02`Z
7@0Y:Q`09RPJ02<W600R9QL082<J0P0Q91/01@0R9A`08bHM02@W7P0T9ah09BPO00808RDL0P0S9Qd0
2P0T9ah09BPO02DX7`0U:1l09BTK02@X6P0T9a`08bHM028U7P0Q8ah2020R7@04020R7`0R9A`08RDL
028U70<08bHM0P0T9ah03@0[:al0;2dO034^7`0h<Al0?SHQ04Lk8`1@@2L0Dd<Y05]5801MAb80H4XS
06==901UD2D00P1VDB@06@1VDB80K5L/06E?:01HAR80D3lQ04Xl8P13>2@0?3<R03H^8@0Z:1/0:bTJ
02dZ6`0a:a/0=BhL03P`7@0i<A`0?34M03`_7`0k;Qh0>2`L03@[6P0b:aT0<B`I030]6P0a;Q/00P0`
;Ah302l/7@<0;R/L200X:1h302LY7P0302HX7@0U9a`09BLL008092HK00<092DO028S7@0P8A/00`0N
7aT0800O81X0824K01`N6@0O81X092@J02`Y6P0f;Q/0@3@N04Pj801<?B00CC/U04/j801>>A`0EShL
06I:8`1hFbl0Rf/l09Ad@@2FO4T0U7I209elA`2]REL0XX5F07MN@01;?2T0<b/P02XW8P0Y9R409RDP
02@U7`0S91h08bHO0P0R9b02024S80808R@Q0P0S9B8202@V8`<09BHP0P0V9b4302LX8P0802DW700V
:1d0:B/P02/]8P0/;R<0:bdR02X/8@0Y:b0202DW8P0=02LX8P0Y:B40;R/R03<_900f<RL0>S@X03La
8`0h<R@0>S@V03/e9`0i<bD0=S0R038/7P0202lY6`03038_800a;Ql0<BhO0080<BhO00<0<c0Q03@a
8P0e<R<00P0o>2H01`11>BH0A3TU04Lk9@1;?2D0C3dV04hn9@1@@2L00P1??bH00`1>?RD0CCdT04`l
8`0204/k8P0804hm:@1=?2P0C3`U04`l8`1=?B<0Cd0S05529@1CA2D205919`0305509P1@?bD0CchT
00<0CchT00P0D3`T054m901C?bH0ET8W05Q59`1JAbL0G4TX05e::@80GTXY01/0GDXZ05]:;01IB2`0
ETH/0594:@1@@RP0C4D[04Y3:@1:@2L0BCdU04Xk901:>R<0Bc/T04`j901:?240BcdR04ho8P1A@280
Dd<R05M48`1IAB@0FTHS05U69P1JAbL0G4TY05e::P1NBb/00P1MBRX07@1LBBT0HDHX06=8:P1WCB`0
Je4^06mE<01bFC40M5/c07EL<`1kI3X0N64h071J=@1WDc00GT/[05I5:@1B@BL0CclV05A3;`1B@Bd0
C3dX04Lk9@14>B<0@c/T04@l9@15?bL0Bc/R04dm901??bH0DD4X0080DT8Y00@0DD4X05109`1AABd0
CD4Y0P18?2@0101:?RH0C40X04Xn9P18?2@205509P80DT4W01`0Dd8X05A3:@1D@bT0E4<Y05Q59`1J
AbT0G4T[05m<;01RCbh0IE8a06ME<@1XES80H58e05i@<`1KCC80Ed/a05A:<@1CB380DTXc059:=@1A
@2`0DT4]05=3;01DA2/0ETH/05Q9;01IBRd0FT//2@1OCBT06`1_FRl0M5ld07QU>`1lJd00Nfa107QY
@01bIC/0KV8h06mQ>P1_H3L0Kehc079M<01eGR`0Nf0[085S;@24IBh0RVP[095_<P2IMcX0WG/n09aj
?@2JN3/0VGLj09Yh>`2TOCX0Z84n0:f6@`020:j7A00L0;6:A`2fSd`0^iAA0;^?B02mTDX0_YA<0<2H
DP33WEH0aJ1I0<NRG036Y5d0_j5Q0;jPH02lWV00]iUK0;:BE`2/S5<0Z8Q?0:R5C@2YNdL0YgY30:Eh
?`2VNSd0Zgln0;>8@`2jT4P0_I=90;ZCD080^iAA01T0_9EB0;fFD`2nUe@0_YMD0;nHE@2nVU`0_9IH
0;J@D@2cS4/0]8]90;Z?B`31U540a9MC0<6NBP30WD`0_YY@0;ZGD`2hU5X0]I5M0;B?HP2aSV@0^I5D
0;N?DP2dS4l0/HU<00<0[XI900@0[hM:0;28BP2cRdd0]Xi@0P2hT5802@2eSDl0/HU;0:j6B02XOT80
Z8130:Z2A@2[QDL0ZhM90:b:B`020:b=C@050:f;C02/RT/0[8Y;0:^9BP2ZR4T00P2XQTL02P2WQDH0
ZhE60:Z4A@2XPT<0Yh500:J0?`2WPD00Z8<o0:V4@02UOS/30:Am>P060:En>`2WP3d0ZH8o0:^4@@2R
Ocl0Y8510P2VPd<02P2TPD40XGhn09ml?02NNc/0T6L_095X<02DJc<0Ufhf09Ya>@2LLc/209ed?00?
0:Ak>@2SO3/0Xg`k0:Am?02TOSl0Xgm10:>1A02QPDH0XX9709]h@P2KN400VWLo09Uf?02HMST0UgDf
0080UgDe0P2GMCP609Qf>@0509Ig=`2DMCD0T70c08e]<P2:JS400P28Ic405P28Ic80QFP^08EX;P24
Ibl0PfD_089T<021Hc40P68`07mP<@22H380PV0`08=Q<@24Hc00QfHa08]Z=02>KSD0T70g099i=`2H
Ocd0UG`l08U_<P25Jc0208]a>00908EZ<`29Kc@0RFld08U_=P29KSL0Rg0k08ea?`2@M480TGE500D0
W7m70`2KOTH809Aj?`80TgU00`2DNT4309Ek@P0509MmA02FO4<0UG]209=i@02BN3l00`2AMch02`2=
LcH0S78e08]a=P2:L3L0R6he08M/=@26JcH0QFXe08EZ<`23J340PVL`0080PFH_02<0PVL`08=X<@25
JS<0Rfdk08e_?@2DMT@0Wh5?0:Z<FP2_TEl0[HmM0:Z<FP2SPe00ZXYI0;BEI`2nXGL0aj^40<bbT@3@
]IL0d;NI0=BgV@3</8/0`JMf0;JLH`2YSe@0VWm808]/?@20HCD0N6<^07MR;@1dGR`0LE/Z06iH:@1[
EBH0JU<W06UB9P0206IA9P0806I@9`1TCRL0HT`W05i79@1KA2@0FD8R05M28`1F@B8205A18`0>050o
8`1>?B<0Bc/R04Pi8P17>240ACTO04@h8010=Al0>S8O03D^7P0a:Ah0;2DK02XS6`0T91`302<S6`80
8R8J0P0Q8AT801lP6PP07QlI200L71X201/K6@<071`J0`0M7A/201`L6P<06a/I0`0J6QP201/L5P<0
71dG0`0M7QP01P0O81X07QlI01hO6@0M7QP071dG01/L5P806Q/E200N7aT301lN6@@081lJ00<08B0K
024Q6@0Q8AT0200Q8AT3028R6P<08b<K00<09b<J02PT6`0X91/00P0Y9A`202XV7@0402/W7P0/8QP0
;R@J030V7080<bTO00<0<BLM02lU6`0^91X00P0c9a/00`0d:1`0=BTM03HZ7P0203L[7`0903P/800j
:1`0>bTM03/Y6`0m;1`0?RdM040_7@11<1`0@S4M0080B3<P00H0B3<N04Te7@1:=Qd0BcLL04di7P1=
>Q`2050j8P04058j8P1A>B40DCTQ050h80<0D3HO00H0D3`T04hj8P1<>200BSHN04Te7@1:=Qh204/g
7`0304Tg8@1:>280BSPR0080BCLQ0P18=R000`17=Al0BC@O04Td7`0604Td7`0304Th7P18=ad0ASDK
0080AC@J00<0ASDK04Lf7018=ad00P1;=Q/0101=>1d0CSTN04lj7`1?>Ql2050k8080Dc`M00@0EC`N
05Pm801K?B40GSlS0P1Q?b@02@1WB2T0ITLX06E69`1UARL0ITLX06M8:@1YBR/0JT//06U;:@0206Q:
:00306M99`1VB2H0ITPV0080IDLU201TAbL02@1PB2@0HDTU06989@1SBBH0ITTW06Q::01ZBBP0JdXY
06I89P0406M99`<0J4XX0P1[BbD206a<9P80KDdW0P1^CRP3075>:003079?:@1cD2X0Le0Z0080M54[
0P1eDRX01P1fDb/0Me@/07QE;@1iERh0NUL_07]H<080O5X]1P1mFbh807UF;P0807]E:01nF2/0PE/^
08AN<@23GC00P5X]07aF:@1iDbH207mK:@0307mK:`1oFRd0OeX^0080OeX`00D0OeTb085L<P21G380
PE``085L;`02089N;P80PUh/00H0PUhZ085P;@22HBh0Q60^08IP;`29HC0208]Q<@0408eQ<P28HS<0
RF<d08YT=@80RfDf0`2<ISL808]U=P0608eW>02>J3T0SVPi08mY>P2@JS/0TF/l0`2BK3d2095[?003
091Z>`2?JCX0SVPi0080SFLh00<0S6Ph08eY>@2?Jc/00P2@K3`0102?Jc/0SFTi08aX>02:I3d208]V
?00308aW>`2=J3/0SVXj0080Sf/i1P2?JCX2091Z>`80S6Ph0P2;IcL0202<J3P0SVXj091/?02AKCd0
T6/n095/?`2CKT40U6m20P2EL4<0102DKd80Tfi109A`@02DL40209=_?`04099^?P2AKCd0TFdm095]
?@<0UFm00P2FL44309Ma@P80Ug950P2HLdH209UdA`80VWE80P2GLd<209Ib@P@0UG5100<0UW8n09Mc
?`2GLcl0102GLcl01P2FLSh0Ug=309Mc@`2GLd<0UW9209Ea@@<0U710202IMDD00`2IM400V7<o09Ia
?@0209E`?00509Ia?@2GLSh0V7<o09Mb?P2FLCd00P2EL3`01@2FLCd0V7<o09Qc?`2JMD40W7M30080
V7<o00P0VGA009]f@P2LMd<0WGQ409iiA@2ONTH0VWM109ikA@80XGi80P2OO4H00`2SP4X0YhA>0:N3
D`070:N3D`80Yh9>0`2XPdl30:V4D0@0YX5=102UP4`60:R3C`80Yh9>00P0YH9:0:J3B`2WQ4h0Z8A@
0:Z6E02[QeL0[8QH0:f8F`80[hYN00<0/8]N0;6=G@2bSU`00P2cSe/0102dTE/0]91L0;B@G02dT5`2
0;FAG@<0]Y9N0`2eTEd30;JBGP80]i=O00<0^9AT0;VEI@2jUVH00P2lV6P00`2jUVH0^IEU0;RDI008
0;ZFIP060;NHHP2eUV00]9=N0;>?F`2bSUX0/XeI0P2eSEX20;>?G`<0/XiN0`2aSEd01P2`S5P0[h]G
0:n;E`2^RUH0[HUE0:b8E080ZhMC0P2/Qe<20:^6DP80ZXEA0P2YQ500202VPD`0Yh9=0:R3CP2YQ4l0
Z8=>0:N2C@2UP4/0Y7m:202PODL20:AoBP80Xgi90P2RODP30:5lA`030:=nB@2QO4L0WgY50080WWU4
00<0X7]60:9mB02TOdX0102ONTD0102PNdH0XGa70:9mB02SOTT20:=oB`<0Y81<0`2UPDd30:J2DP<0
Yh=C0P2XQ5@20:F0C0030:F0B`2UP4T0YH570080YH5500H0YH530:^6DP2[QU80ZXEA0:V4D02XPdl2
0:J1C@030:F0C02WPTd0Yh9=00@0YX5<0P2UP4/0202PODL0XWm90:B1B`2TPD/0Xh1:0:5nB02NNdD0
W7U30P2QNDD40:1hA080WgM30`2QNDH[ooooo`00:_ooool00`2UO4P0Y7]70:=jAP020:9iA@030:=j
AP2TNdL0YGa80080XWU300<0XWU50:9hAP2RN4P00P2RMdX00`2RMd`0XgU70:=iA`020:=iA`80Y7Y8
0P2UNdT01@2VODL0Ygi80:MnBP2WOD/0Z7i>0080Z7e@00<0ZGiC0:QoB`2XOd/00`2YP4`30:Z1C@<0
Yge;0P2XOT`30:UoC@060:UnD`2YOU40ZWmB0:Z0D02[PDl0Zh9>0P2/Pdd40:^1C`@0ZX1>00H0ZH=F
0:R2D`2WPE80YX1?0:AoB`2SOTT20:9mAP80Xgi:00D0XGa809mjAP2LMd<0W7M309Ye@@0209Qc?`06
09Mb?P2FLCd0UW4m09E`?02DKc/0Tfhj0P2BKCT208eY=`0708eY>@2<IcX0RfHj08UT>P27HSP0QElh
08AN=`0208EO>00508IP>@25GcP0Q5hg08=M=P22G3D00P20GCD0101oG3@0OEXb07aI<@1jEbl207UF
;PP0LU4^0P1^CBX0701`Cb`0LE0]07=B;`1eE340MUDb07MF<`1hFc<0Ne/d07aL<`1nGC80PElb08AO
<P26H340Qf4b08]U=P2<ISL0SFLh08iX>@2@JS/0TF/l099/?@2CKCh0UG0k09Ia?@2GLSh0V79109Qb
@`2GLD@209I_A0@0VFlm0`2HKS`00`2GKC/0TV`m09=]?P0209=]?P<0U6ho00<0UFm0091Z>`2@JS/0
1P2@JS/0102>J3/0SFLj08eW>P2=IcX308aV>@0308]U>02<ISL0S6Hg00H0RfDf402<IST808UU=@03
08aQ=02=HSD0SV<f0080T6Dh00<0SV<f08eR=@2<HC@0302;ICH208aV=`<0SFLh0P2;IS8308YU<@03
08]V<P2=J3@0SVTe0080S6Hi00<0RfDh08YT=`2:I3L00`2:I3L808UT=`80QV8b0P25HC4308AP<007
08=O;`26HC@0QF0c08EP<`24Gc80QF0c08IQ=00208QS=P<0RVDh0P2;IST308aW>PP0S6Xl00@0RVPj
08]Y>`2;JC/0RfTk0`2<JS`02@2=Jcd0Sfdm08e[>`2;JCT0RFLg08YX>02<JSX0Sfdm095_?`0808aZ
>P0M08a_=`2<KSP0Rfdg08U[=`28JSP0QfPi08IW>@25ISP0P64b07mP<P1jGRl0MU/^075I;@1/EB/0
JE<Z06QB:@1QCbL0G4XT05E58@1B@b80DD<V04a09P17>b<0@SLQ03Xd7P0h<Q`0=2lK02l/6@0/:aT0
0P0Z:a/02@0Y:ad0;BLK02`X700]:Ad0;2XM02TZ700V:1X08bLH024U5P04028U70@08bHM00H08B@K
028U700R9A`08bHM02@W7P0U:1l202HY808092LL00<08bHM028U7P0Q8ah00`0P8Ql0100O8B008RDL
028U700R9A`202<V7@<092LN02T0:RXN02//7P0`;Ah0=c0N03de8016>R80CShU05519`1NAah0H4TP
06A=8`1XDBD0K5HW06iH9`1_FBP0KeTW071K;P1XDbP0FTPR050o8@19>b40@CHT03T_8`0c:b00:bTL
02`Z6`0^:a`0<R`L03D^700h<1d0>C4L03`a7@0l;al0>bhN03L[6`0c:QT0<R/I034/6@0_;1T0<2dJ
030]7P0302l/7@80;R/L0P0]:Q/802PX7P0602PZ7`0W:Ah09bTN02HX7@0U9a`092HK0P0S9AX00`0S
91h08R<M020Q6`0301hO6@0J01lP6P0P8A/0728H020S600W:1X0<B`I03`a7@16=Qd0CSXO058m801@
>bP0CSXR058j7P1M@b80KU8Z089S=02AL3/0UgI009IkA02JODD0Y8==0:^7E`2CLdd0Hdde03d`9`0/
9b@202XW8P0402LV8@0U9R0092DO02<V7`808BHO0P0Q8b02028T8@808bDR0P0T9R<302DV80809RLQ
0`0W:280200W:Ah0:2XO02/]8P0];b@0;S0U02`^8`0Z;240:2XO0P0U9b80200V9b40:BTQ02dZ8@0a
;B80=30U03Pb9P0d<B80=C8S0P0f<b@00`0e<R<0<RlP02l/7@0202dZ6`08034^7`0b;b00<RlP038_
800c<240=34R03Db8`0f<b@2044h9`0604<h9P15>2D0BCXU04dm9P1??bP0DT0X0P1A?bL00`1@?RH0
CcdU04hl900204dk8`0=04`j8P1>?BT0CSdY04dm9P1=?B@0CShT0511901B@bH0Dd@U05E4:P1C@RP0
DT4W050o9@0204ln9080D3lU00H0DCdU058n9@1E@BP0F4@Y05Y7:@1KB2P205a9:080GDTX01H0G4TY
05Y9:`1HAb/0E4@Z05129`1>@2H0BT<Y04U2:01:@2L0BShV04/l9@1<?2D0Bc/T04`j901;?B00C3hQ
04m08@1B@R40E4@R05Q68P1KAb@0G4PS0P1MBRX205i;:`80GDXZ0P1LBBT0701PAR/0H4LY0658:P1S
BR/0ITh/06UA;@1/E2h0KED_06eJ<P1XE2l0H4hZ05I69@1@?b<0CCdT04`m9P1<?BP0DD8_04ho;018
>bP0A3TU048j9@12?2H0A3hX04E0:P1;>b80CCdT04lo9P1A@BP20592:@0:0551:01@@2L0DDL^04a2
:@17?B@0AS`S04Pn9@19?bH0AcdT04Dk8P80CS`T00@0CcdU054o9`1B@2P0E48Z0P1E@b/01@1KB2P0
G4TY05m<;01QCRh0He0`00<0I54a0100F4lb05I=<01CBBh0DDL^04m4;P1?A300D4Da0515<`1A?b/0
DT0/05=1:`1E@b/0ETD[05Q7:`1IB2`0FTT[0`1NC2P205m=:@80H4hZ0P1QCb/04`1^Fc00LUle07ES
>`1gJ3l0MfM307AV@@1`Hd00KF0n06eO?01]GCT0KU`d075L;`1eGR`0Nf0Y081S:@23IBT0SV`]09Ab
<`2LNS/00P2POSl01@2NO3d0Wgdn0:5o@02YPSl0[8E20080[hQ500`0[XM40:n8A@2eST/0^I9?0;Z@
AP2lTTX0_IE=0;nIDP31W5H0`IiJ0<:OG@32XEh20;VOI00>0;RKH@2cU5/0[8aC0:V6CP2YQD/0ZXI<
0:enB02ZNd<0Z7Xo0:Yl?P2aQ440^He60;jBB@30U4T40;fFD`<0_YMD01T0_iQE0;^IG02iUET0]I5C
0;>=CP2dSD`0]hi<0;fBCP2oU500^IU>0;RHC`2fUE00/i5B0;:?E`2aSET0/HeM0;6<G`2gSE40]H]?
0;:8C02`QTX0[hE90;26BP2bR4`0/hU=0080]He?00`0]Xi@0;N?D@2fSU00]He?0;>;C@2aRD/0[896
0:b4A`2]QDP0[HM90:f9B`2]Rd`20:b=C@80ZhU<0140ZXQ;0:R6B@2WQDP0YXA70:F3AP2TPTD0[XI9
0:b4AP2[PdD0ZX=20:Z3@02[Q3l0[8Ho0:f7@02YPSd0Z84l0:Io>P020:En>@0=0:Io>P2WP3/0Z84l
09mk?@2QOCl0Xgm10:9n@02ONcd0WWXl0:1l?P2SOd40Y7dl0:En?@020:Io?P050:Am?02PNCP0W7Dd
09Ub<@2RNCL00`2RNcX00`2QNc`0X7`n09mm@00209em@P0809]h@P2JMcl0VGHn09Qe>`2GMCP0UgDf
09Qf=P2IMcL409Yf>0@0VGDg00D0UgPg09Ef=@2BLc<0Sflb08a/<@0208][<P0:08]Z=028Jc40R6/a
08MZ<P25Ic40Q6Hb08=U<`22I380PF8c08=Q<`80Pf4a01D0Q6<`08IU<02:JC<0SFdd08m_=P2AN3D0
UWdj09Mn?02AN3P0S78e08Y`=@29Kc@0Qfdd08ab=`2;LCH0Rg4h08aa>P2>Lch0T7A209=gA@2ENDT0
0`2NPDT209f0B0<0W7m7202ENd00102CND00U7Y109Aj@@2DNT4209Ek@P80UWa300@0Uge409Il@`2D
NT40TWPo102@MSd208ec=P0408ab=`2:L3L0RFlf08M/=@80QV/f00<0QFXc08AY<P22Ic000P21IRl0
2022Ic00Q6Tb08EZ<`2;KC/0SFlm09AfA02OPDl0ZheK0P2aTf406P2^T5h0YXMA0:^;F02dUFH0_9me
0<FYQ03;/I00ckBI0=2fW@3D^Z40ckFD0<J^P02oYVh0]9YO0:J8DP2EMD@0RFPm07aW<01jIBh0Mf8]
07=M:`1`FRT0KELX06aF9`1/EBT0JE@W0P1YE2T01`1WDBP0I4hW065;9P1MAR@0Fd@R05U49@1H@b@0
0P1E@R@03P1A@2@0CchT04`l8`19>R<0B3TR04Pj7`17>Al0@cLO03ld800i<1l0<b/N02lW700[91X0
9BDM0`0T91`202<S6`808R8J400O81X801dM6`0401/K6@0L71X071`J01`L6P807AdK0P0N7Q`201`L
6P<06a/I0`0J6QP0100K71H071dG01`M5`0L7AL201dN60<07QlI0`0M7QP401`M5`P07b0J200P7aX9
024Q6@<08R8J0P0S8a/202@T70809b<J00<0:2@K02TU700Z9Qd00P0[9ah0100/:1l0;bDI030V6P0a
9a/2038X7004034W6`0`9QX0<2HJ03<W6`80=2PL00<0=BTM03HZ7P0g:al00P0h;20203d[7`0603d[
7@0m;1`0?bhN044`7P13<Qh0A3<O0P18<b001P18<ah0B3@L04Xf7@1<>1d0CSXO04ll7P80DC/S00@0
Dc/S05@j8`1D>R<0ECTS0P1G>2<0101H>2<0D3`T04lk8`1=>B4204/g7`0504`h801=>B40CSXR04`h
801=>B400`1>>R800`1<>200BcLO04Xf7P0804/f8@0304/j801:>Al0B3LM0080ASDK00T0AcHL04Pg
7@19>1h0CCDI04hf6P1@>1`0DCTM058j7P1C>al00P1B>Qh02P1B>a`0Dc`M05Dl7P1G?1l0FcdQ05dn
8P1P?R<0HClT06M99`1VB2H206E79@0406I89P1XBRP0JT`Z06]=:`@0J4XX101YBbT806M99`06069:
901TBRD0I4XU06M;9P1XBRH0JdXW0P1/BRL806Q::0<0JdXW0P1/BbP306e<:@80L4dW0P1aCRP0101b
CbT0Le0Z07AA:`1dDB/207EB:P0607IC:`1gE2`0NEH^07YG;`1kF300O5Ta0P1nFB`01020Fbh0PE`_
085L;`21G2l2081K;PP0O5H_00<0O5HY07iH:`21Fbh00P23GC000`21Fbh0OeT/07eG:P0207mK:@03
07mK:`1oFRd0OeX^0080OeX`00D0OeTb085L<021G300PUd`089N;P0208=O;@80Pel[00H0Pf0Z08=R
;@24Hbh0QV8^08QS;`2:HRl208aR<00508eQ<029Hc@0RV@e08]U=P2=IcP00`2>J3T908eW>080T6Xk
00H0SfTj091Z>`2@JS/0TV`m09A^?`2EKd0209=]?P03099/?@2AJc`0T6Xk0080SfTj00@0SVPi08iZ
>P2?Jc/0T6`l0P2AKCd0102@K3`0Sf/k08iZ>P2;ICh208aW?@0308eX?02>JC`0Sf/k0080T6`j00@0
SfTj091Z>`2@JS/0T6Xk0`2AJc`00`2BK3d0SVXj08eY>@0208aX>00808eY>@2?Jc/0TFdm09=_?`2@
Jch0TF`o09=^@@2EL4<209IaA00509E`@`2DKd80U79209Ab@P2CLD400P2BL4000`2AKcl0T6hn091^
?P0209E_@080UW110`2GLD801P2HLT<0UW5409IaA02GLTD0V7=609UdA`80VWE800@0VgI909QdA02H
M4@0V7A40P2GLd<309Ib@P0309Ib?P2GLcl0V7A00080VGE100<0V7A009Mc?`2FLSh01`2FLT800`2G
Ld<0VWI609YfAP0609YfAP0309Ye@@2IM400Ug8n0080UW4m00<0Ug8n09Ud@02JMD400P2GLSh209Ia
?@0;09Mb?P2IM400VGA009]f@P2LMd<0V7<o09Ud@02JMD40VgI209ag@`2NNDD00P2ONTH0102MNT@0
X7e70:B1B`2TPD/20:9oB@030:F2C02YQU00ZXEH00L0ZXEH202/Qe<80:R3C`80ZhIB0`2/Qe<00`2[
QU80ZHA@0:R3C`020:R5C@0>0:V6D02ZQU80[8QF0:f9F@2^RUX0[hYM0;2;G`2aS600/HaO0;:>GP2c
Sed0]91L0;FAG@2eTU`20;FAG@80]Y9N0`2gTel0102hU600]I5M0;FAG@2eTEd20;JBGP<0]i=O00<0
^IEU0;ZFIP2kUfL00P2lV6P0102kUfL0^YIV0;VEI@2iUfL30;RFIP<0]iEU00L0]YAT0;NHHP2eUV00
]9=N0;>?F`2bSUX0/XeI0080]HeJ0P2cSel30;:>GP<0/HeM00H0/HeI0;2<F02`S5P0[h]G0:j:EP2]
RED20:b8E0060:j9E@2]R5@0[HQD0:b7D`2[QU80ZXEA0P2YQ5000`2UPDd0YX9>0:N3C`020:R4D003
0:N3C`2VPTh0YH5=00P0Xh1:00D0YH1;0:AoBP2TOdX0Xgi90:9mB0030:5lA`0;0:1kAP2UP4/0Xgi9
09mjA@2LMd80WGQ30:1kAP2TOdX0Yh9=0:5lA`2PNdH00P2ONTD01@2PNdH0XGa70:9mB02SOTT0Xgm;
00<0Y81<0P2UPDd20:J2CP<0Y89D0P2UPeD30:J4EP80YX5=00<0YX5<0:J1BP2VPTP00P2VPTH00`2V
PT@0ZhIB0:Z5D@020:Z5D@<0ZHA@00<0Z8=?0:R3CP2XPdh01P2XPdh40:B1B@040:>0B02QOTH0X7e5
09mlA0/0XWU5:oooool002[ooooo00<0YWe90:ElB02SNTH00P2RNDD00`2SNTH0Y7]70:ImB@020:=j
A0030:=jAP2SNDL0XgU90080XgQ;00@0XgQ=0:9hAP2SNDL0XgU70P2TNTP20:EkB@060:IlBP2VODL0
YWe70:MnBP2WOD/0Z7i>0P2YOU400`2YOU<0Z7m;0:QoB`030:V0C0<0ZX5=0`2YOdd30:Z0CP80Zh5?
00H0ZGiC0:UnD@2ZOe80ZX1@0:^1C`2[PTh20:b3C@@0ZX1>102[PDl01P2ZQ5L0ZH=D0:R2D`2WPE00
YH1<0:AoBP80XWe600@0Y7m;0:=nBP2QO4P0WgY60P2LMd<0102JMD40V7<o09Mb?P2GLSh209Ia?@03
09E`?02DKc/0Tfhj0080Tfhj0100SVXh08m[>@2?Jc/0SfXm08iY?@2;IS`0RF@j08MQ>P24GSL0QElh
08IP>@27HCX0QV0i08EO>023GCH0PE/d0P20GCD0101oG3@0OEXb07aI<@1jEbl207UF;PP0LU4^00h0
KD`Y06i=:P1`Cb`0LU4^07AC<01fEC80MeHc07QG=01iG3@0O5`e07aL<`1oGS<0PElb08AO<P80QV0a
0100RF<d08YT=@2<ISL0SVPi095[?02CKCh0UFm009I`@@2FLC`0Ug8n09Qc?`2ILd80VG=409QbA@2F
Kd@0UFi30`2GKC/209Q^?0<0VFlm0P2BK3d209=]?P80U6ho0P2EKd08095[?080SVPk0P2=IcX0102<
IST0RfDh08]U>02;ICP208eW>00408aV=`2;ICH0RfDf08YT=@80RF<d202<IST808YT=`D0RFDe0`28
I3@00`2<HC@0SF8e08iS=P02091U>00308iS=P2=HSD0S64d0080RV@e2P2;ICH208aV=`<0SFLh00D0
R6<_08UT<02;IS80S6Lc08eX=00208aW<`0308]V<P2<IST0S6Hi00<0RfDh0P2:I3L00`29HcH0RF@g
08UT=`0608UT=`80Qf<c0P26HS8408EQ<@0308MR=@26HC@0QF0c0080Q5lb00<0QV4d08QS=P29I3L0
0`2:ICP208]V>@<0S6Lj0P2:J3X0102;JC/0S6Xl08e[?@2>K3h208m]?`80RVPj0P2;JC/208aZ?080
SF/m1@2<JSX00`2=Jc/0SV`l08m]?@0808aZ>P0608ia>@2=KcT0S6hh08]]>@2:K3X0R6Tj0P27J3X0
5@1oH340OUla07YN;`1fFbh0L5P/06aE:`1YDbX0Ie4X065?9`1LBR@0EDDQ05528@1@@RD0C40V04Lk
8`11=R00>C<M03La6`0c;QX0;b`I02`[6@0202TZ6P0902T[7@0]9a/0;2PL02`X700[:A`0:BXL02HX
6P0R9QL08BDF00@08bHM100R9A`2024T6`06028U700S9Qd092LN02DX7`0V:B009bXQ0P0T9ah0100S
9Ql08RDN024S7P0P8Ql301lQ8004028U700S9Qd08bHM02<V7@8092LN0P0U:1l0:00Y:Ad0:R/M02h[
700e;Q`0>S8M04<g7`1:>R40CCdS06177P1RBB00IdlS06aD9P1aFBT0M5d[07IO:`1gH2`0Lel]06YE
:01JB200CclN04Lh8@0n<R80=R`R030W800^;1l0;R`M030]7P0c;Ad0=BhL03L_700h<1/0>RlK03`_
7`0j;Ad0=b/K03<Z6@0a:QP0<2/H02l/6@0`;AX302l/7@80;R/L0`0]:Q/802PX7P0502PZ7`0W:Ah0
9bTN02HX7@0T9Q/00P0S9AX0100R91T08R<M024R700O81X201hO6@0Q01lP6P0P8A/08B8L01dU600S
9aT0:BXJ03@_6`0o<a/0BCPL058k701F?Ah0D3/X050j8`1E?B40HTPU07II;`29JCP0U7@k09Uf?02D
NT40XH9;0:^:E02TPU@0PVA205E0;@0d:bH0:BL/02`Y900[:2<0:BPS02LX8P0U9R008bHO008082DN
0P0Q8b02028T8@808bDR0P0T9R<302DV80809RLQ0`0W:2800`0Y:ah0:bdP02h`8`0202la900;02d_
8P0Y:ah09bTL02HX8`0U9b809RLQ02LW7`0[:1l0;RXO034]8P0e;b<00P0b<240100c<B80<S0Q034_
800`;Ql302l]7P80<RlP00@0<c0Q03@a8P0e<R<0=S<T0P0g=2D204@h:00604Dh9`15>2D0BCXU04hn
9`1B@2X0E48Z0P1C?bL2058n9P0@054m9@1@?2@0Cc/S04lk8`1??RX0CSdY04dm9P1=?B@0CShT0511
901B@bH0E4DV05M6;01FAB/0Dd8X05509P80D3lU00P0DD0V05919`1B?RH0E40W05M3:P1IABX0FdPZ
05a9:@80FdPW00P0FdLV05a89`1KB2P0F4LY05I5:@1B@RP0CT0U04`n9080Ad0V00<0BClV04Xn9P1<
?BH00P1=?BH02@1>?2H0D4<S0554901DAB@0EdLV05Y::01NC2P0HDdX069>:@02065>;P04061=;@1O
C2`0GT/[05e::P80G4TY01`0GdL]05i6;01MABT0GDHW05i79`1PBBL0Hd`Z06A>:@1LBRH0FdTU05E5
901A@RD0CClT04Tm9@18>bP0AS/W04dn:`19?2T0ASTV04<h9011>B@0@cdW04E0:P17@R`0Bc/R04dm
901??bH0DD4X0P1B@RT0:P1A@BP0D40W04m8;P1:@bT0AChT04@m8`15?R@0ASlU04@m8`11>R00BcTS
04`j901=>bD0D3hX0590:P1D@R`0ET@^05M5;`1MBbL0Gd`[065>;@1SD2l0I54a06=@<P1RCc40HDh`
051;;P1>BB`0C4H/04]4:P19@BX0Bd0/04a1;`1=@2l0Dch[05@o;01E@2/0ET8Z05M3:P1IABX0FTH[
05Y7:@<0GD/W01T0GT`X061>:P1QCb/0HU0/06=A;@1TDRh0JeP^06aK<01_GCD0Kelk06mQ?P1]H400
JUm106UN@01WF3L0J5Pf06]I<@1aG2l0MUl]07eR:`23IRX0QfT[099`<02HMSH0Wgdm00<0XX1000H0
YH=30:R6AP2^Qd@0/8U60;:;B02`RDH20:f6@`080;6:A`2fSd`0]Xm40;RAAP2kUD`0_YMB0<2KE`2o
W5`20;jLG@0>0;>JHP2dVf<0/iUP0:n@F@2WQdh0YX5:0:V2B@2/QD`0/8590:enAP2[OD40[h910;N:
AP2oTd`20<6EBP80_iQE0`2nUe@30;fFD`0M0;bIG`2jV5/0^9AH0;NAD`2gSe40]i1?0;V@CP2jTDl0
/iEE0;:DE02aTE@0[hmD0;2=E@2aSUP0/hiJ0;B?F`2eR4d0]8M<0;64B@2`PdP0/HA90;B7C02gRTl0
^XeB0;J>D02dS4h0/h]=0;69B`2`R4X00P2_QdT01`2`R4X0/HM;0;28B`2`R4/0/8Y<0:j:C02^S4d0
0P2/SDd20:V6C00C0:N4BP2VPdT0Y8570:>0AP2ROdD0XGi40:b4A`2[PdH0ZX940:V2?`2YPSd0ZX@k
0:b6>`2]Qc`0[XQ10:b6?`2ZQ3d0Yh4j0:Eo>0020:An=`0B0:Eo>02PO400XWi20:=o@`2QOD40WWXn
09mk?`2UPDD0ZhM;0;^EBP2iTdP0]Hm40;6;@02]Qc`0ZX@i0:N1=P2VP3D0YG`j0`2TOC`00`2RO3d0
X7`n09mm@00209al@@0809]h@P2JMcl0V7Dm09Md>P2GMCP0V7Hg09Ug=`2JN3P309eg>00=09af=`2K
MCH0VW@e09Yd=@2ILc@0V7Tf09Ig=P2CM3<0TG8b08m_<P2?Kc@0Sflf091`=`0208]^=00708U/=028
JS@0QVPd08EW=@24IS@0Pf@e08=Q<`0208=Q<@0=08AS<026IC00RFPb08a/<`2>KSD0SgLa095h=@2G
OS/0VH0n09=j>P2:L3<0Qfdb08U_=00208id>@0708id>`2?M3d0TGI109AhAP2GNdT0V7a<0:23B`02
09n2BP80WX590P2MP4P00`2LOdL0UWa109Il@@0609Il@@<0U7Y10P2ENd8309Il@`0409MmA02ENd80
TWPo091f?@<0SW@k00`0SgDl08ec=P2=LcH0S78g08]a>029KcH0R6df08M/=`26JcH0QFXc08AY<P23
J342089W<00S08=X<@24JC80QFXc08]]>`2=Kcd0U7I409n1C`2[SE/0/iES0;BFI02bU680ZX]D0:j?
F@2eUfD0_9me0<>WPP39[Y00c[:J0<neWP3C^Z@0d;NI0<^bR@36[GL0_j9Z0;2AF`2OODd0U6m3081[
<P1nJC00NVD^07EP:`1bG2X0L5XY06mI:01_FBX00P1]F2/0201/Eb`0JUDZ06MA:01SCBH0H4XU05e7
8P1KARL0FTDV0P1GA2H03@1B@BD0D3lU04`l8`1:>b@0BCXS04Xk7P19>Al0AcPQ048f800m<R00=B`M
034W6`0]9AX00`0U9Ad202@T70<08b<K200P8A/801lP6PP07AdK0`0L71X201dM6`<07QhL0P0L71X3
01/K6@<06QXH0`0L7AL201dN60<07QlI0`0L7AL201dN60<07QlI200O81X4024P6`@081lJ2`0R8QX2
02<S6`<092@L0P0W8aX02@0X91/0:BDL02XV7@0[9ah0;2PO02dY800c:Q/0<RTJ034X6@02030W6080
<BPI00D0<RTJ03@X700d:1`0=BTM03HZ7P0203L[7`80>2`P0P0o;B404@0n;1h0?RdM040_7`12<Al0
AC@P04Lf8P19=240B3<P04Pc7P18=1`0BSHM04`h7@1?>b00DChP04lk801@>b00Dc/Q0080EC/R00L0
FC/S05/k901N>bD0Gc/U04lk8`1>>R80CCTQ0080C3PP00H0CSXR050l901A?BD0CSPP04li8@1@>R82
054k8`0304li8@1==al0C3HN00P0C3LR00d0C3/O04/j7P19>1`0AcHJ04He6@17=QX0B3LK04Th701=
=QL0CSLH054j6`1C?1d0E3dN0080Dc`M0P1B>a`01@1C?1d0EC`N05Ll7`1J?200GChR0080H3hS00T0
ITPT06E78`1TAR80I4HR06I8901XBRH0JT`X06a>:P1WBBL00P1XBRP00`1YBbT0JT`Z06]=:`0206a>
;0P0JdXW00H0ID`T06M;901WBb@0JD/U06];9@1/BRD206i:9PP0J4XX101[BRL206a;:080KD`Y0P1_
C2H0101`CBL0LDhX079?:@1cD2X207AA:`0@07AA:@1eDRX0MU<[07QE;@1iERh0NeP`07aI<@1mFS80
OUPY07mI:P21Fb`0Ped^08AN;`23GBh0PU`]085K;0P0OUL`0P1nF2/00`1oFB`0P5X]085K;P03089L
;`80P5`Z00<0P5`/081K;P20Fbl00P20Fc401@20FS<0PE`_089M<022GRh0Pel_0080Pel]00<0Q60/
08AQ:`25HR`00P25I2l02P27Hbl0RF@`08]S<02<HS00SF<a08iR<@29Hc@0RV@e08eW>02?JCX2091Z
>`80SfTj202>J3T0202BK3d0TF/l091Z>`2@JS/0TF/l09=]?P2EKd00Ug520P2DKSl00`2CKCh0TV`m
095[?002091Z>`0408mY>P2?Jc/0T6`l095]?@80TVhn00/0TFdm091/?02?Jc/0S6Ho08aW?@2=J3h0
SVTm08mZ?@2@K3`0T6`j095]>`02091Z>`80TF/l00H0TV`m09=]?P2CKCh0Tfdn08m[>`2>JSX208eY
>@0808iZ>P2@K3`0TVhn09A`@02@Jch0TF`o09A_@P2FLD@209MbA@80UW540P2EMD@0102DM4<0Tg=2
099b@@2ALD02091`?`<0UFm00P2FL44309Ma@P80UG1300@0UW5409MbA@2HLdH0VGA70P2JMDP309Ue
A@80V7A40`2GLd<00`2FLSh0V7A009Ue@@0209Yf@P0309Ue@@2HM400UW8n0080UG5100<0UW9209Mc
@`2HM4@00P2IMDD00`2JMTH0VgM709]gA`0609]gA`0309Ye@@2IM400V7<o0080Ug8n00D0VGA009Ye
@@2KMT80V7<o09Mb?P0209Ia?@0?09Mb?P2IM400VGA009]f@P2MN4@0V7<o09Ud@02JMD40VgI209eh
A02NNDD0WgY60:1kA`2OO4H0Xh1:0080YX==0P2TPD/00`2XQDl0[8UC0:j9G@070:j9G@@0[hYF102^
RED30:f8E0D0[XUE01P0[8MC0:f8E02^RED0[hYF0:j9E@2/Qe<0ZXEA0:V4D02YQTh0ZXM?0:^8DP2/
R5@0[XYH0:n;F`2`S5`0/HaO0;6<H02bSF40/XeP0;>?G`2dT5h0]I5M0;JBGP2fTed20;JBGP80]i=O
0`2hU6000`2iUF40]I5M0;JBGP020;JBGP80]i=O0P2hU6000`2jUVH0^iMW0;bHJ0020;fIJ@030;bH
J02kUfL0^YIV0080]iMV0P2fUVD02P2eUF@0]9AS0;BDH`2dU6<0]iQR0;FFH02dTeh0/hmK0;:>FP2b
SET20;F=FP80/hmO0`2bSUh30;6=G@80/HeI00<0/8aH0:n;E`2^RUH00P2]RED01P2/R5@0[hYF0:j9
E@2^RED0[HQD0:^6DP80ZXEA00@0ZHA@0:>2C`2TPe00YXEB0P2WQU<00`2VQE80YHAA0:B3D0080:F2
C080YH1;00@0Y7m:0:=nB@2RODP0XGa70`2PNdH50:5lA`060:=nB@2TOdX0YH1;0:9mB02QO4L0X7]6
0P2ONTD00`2QO4L0XWe80:AoBP030:B0C080YH5=0`2VPTh0102SPUD0Y8=F0:B3EP2TPeH20:F4E`80
YXEH0P2XPdl00`2XPdh0Z8=<0:R4BP020:R4B0030:R4AP2YQ500ZHA@0080ZXEA0P2[QU820:b7D`L0
ZHA?00L0ZXE@0:N4BP2VPdT0Y8570:>0AP2ROdD0XGi40080XWm5102RNDD40:=jAP<0XWU3:oooool0
02[ooooo00<0Ygi:0:ImB@2TNdL00P2RNDD00`2SNTH0YGa80:ImB@020:=jA0030:=jAP2SNDL0XgU9
0080XgQ;00D0XgQ=0:9hAP2SNDL0XgU70:AjB0020:EkB@80YWa:0P2VODL01P2WOTX0Z7i<0:QnCP2Y
OU40ZWmB0:YoE080Z7m;0`2YP4`30:Z1C@<0ZX1>0P2[PDl30:b2D0060:UnD`2YOU40ZWmB0:Z0D02[
PDl0Zh9>0P2/Pdd40:Z0CP@0Zh5?00`0ZhEH0:Z4E@2YPe@0Yh5@0:F0C02TOdX0Xgi70:9mAP2TOd/0
Xgi:0:5lB02ONTH209ag@`0309Ye@@2HLcl0Ug8n00<0UW4m00<0UG0l09A_>`2DKc/00P2CKSX02`2?
JcT0T6`j095]?@2AK3l0SfXn08eX?P2:IC/0R68k08AN=`25GcP0QV0i0080Qf4j00<0QElh08=M=P21
Fc@00P20GCD0101oG3@0OEXb07aI<@1jEbl207UF;PP0LU4^00h0KD`Y06i=:P1`Cb`0LU4^07AC<01f
EC80N5Ld07UH=@1iG3@0O5`e07eM=01oGS<0PElb08AO<P80QV0a0100R68c08US=02;ICH0SVPi095[
?02DKSl0UW1109Qb@`2FLC`0Ug8n09Ud@02JM4<0VG=409QbA@2FKd@0U6e20P2FK3X209M]>`0409Q^
?02IKcd0VW0n09Y`?P<0TV`m00<0Tfdn09A^?`2EKd000P2EKd08095[?080SVPk00@0SFLj08aV>@2<
IST0RfDh0P2:I3L208iX>@0608eW>02;ICH0RV@e08US=028HS<0Qf4b202<IST808US=P@0RFDe1028
I3@00`2<HC@0SF8e08iS=P02091U>00308iS=P2=HSD0S64d00<0RV@e2@2;ICH208aV=`<0SFLh00P0
QV4/08QS;P2;IS40SFPc08iY=02=J3<0RfHa08YU<0<0S6Hi0P2;ICP208YT=`0308US=P29I3L0RF@g
00H0RF@g0P28I3@208MS<`<0QV8b00<0QF4a08MR=@26HC@00`24Gc800`26HC@0R6<f08UT=`0308YU
>080RfHi0`2<IcX208UW>@0608YX>P2<JS`0SV`n08m]?`2@KT00TFm10`2:J3X00`2;JC/0S6Xl08e[
?@0208e[?@0308YX>02;JCT0SF/k00<0SV`l0P2=Jc/808aZ>P0608mb>P2>L3X0SFli08a^>P2;KC/0
RFXk0P28JC/05@1oH340OUla07YN;`1eFRd0L5P/06aE:`1YDbX0Ie4X061>9P1KBB<0E4@P05528@1@
@RD0BclU04Hj8P10=Al0>38L03H`6P0c;QX0;R/H02/Z600202TZ6P0:02T[7@0]9a/0:bLK02`X700[
:A`0:2TK02DW6@0R9QL08BDF02DX7`8092LN00D08bHM028U700Q91/08B@K020S6P02024T6`03028U
700S9Qd092LN00809RTP00L09bXQ02@W7P0S9Qd08bHO028T7`0Q8b00828Q00807b4P00<07b0R02<V
7@0S9Qd00P0S9Qd202@W7P809BPO02P0:2PL02TZ700]:Q/0<b`J03P`6`10=1`0B3PO04Xj801PB1`0
Hd/O06Q@8P1^ERH0Le`Z07MP;01iHRh0NV<]07AP;P1ZEBH0FTPP04hn7@15=Ql0?C4Q03@Z8@0_9Ql0
;bdP02l]7P0a;Ql0<bdM03D^700f;Q/0=blJ03T^6P0l;al0>RdM03L[6`0c:QT0<BXH030[600_;1T0
<2dJ0P0_;1d302h[70<0;BXK200X:1h01P0X:Ql09bTN02LY7P0U9a`092HK02<U6P808R@I00<08R<M
024R700O81X00P0N7aT06`0O81X0824K024R700O9aP092PI02//6P0g<A/0@CDK04`h7@1D>ad0Ec`N
054j:01@>RD0F3hS06M::01lGC40S6`i09Md?02IMcX0TWPm0:F6C@2`SeT0XGmA07MJ>P1;>2T0<BTW
02TX<00202dZ9@0602XY900X:B<09RLQ02@W800P9Ah07b@M0P0Q8b02028T8@808bDR0P0T9R<302DV
80809RLQ0`0W:280200Z;1h0;2hP02la8`0a<bD0<38T02d_8@0Y:ad09RPJ0P0V:2<01P0V9b409bLO
02XW7P0]:Ah0;b/P038/8080<S0Q00<0<BlP030^7`0`;Ql0100`;Ql01@0b;b00<c0Q03@a8P0f<b@0
=c@U00<0>3DV0P14>2P01`15>2L0AcPU04/j9P1??BL0DT0Z05I2:P1D@2P00P1C?bL00`1B?RH0DCdU
050l900204lk8`0<04ln:P1>?BT0CCdV04dm901>?R@0D44T05939P1DABH0FDP^05M6;01D@bT0DT4W
0P1A@2H02P1B@BL0Dd8X05<o9`1E@BP0F4@[05Y6:`1LBB/0FdPX05]89`1JAbH205]79P0605Y79`1G
ARP0E4<W05109P1<?R<0BS`R0P16?bD00`19?bH0BShV04dn9`0204hn9`0904lm9`1EB2P0ETTY05U:
:@1LC2X0Gdl[06=A:`1VDRd0Ie@/0080He0`00<0HDh^061=;@1NBb/00`1MBRX0701PB300GTH^05a4
:P1J@RH0FT<T05]4901NAbD0GdPV04lo6`1A@Al0DT<R05949`1?@bT0BclY04Hk9`11>BH0BC`[04Pk
:P14>BL0@CTV040i9P12?BT0AT4]04I4;`1;>b80CCdT04lo9P1A@BP20592:@060551:01@@2L0CdP^
04Y3:@15?R@0@c`R0P15?R@08P13?280@3TO04Tg8@1:>280C3XT04lm9`1B@2X0ED<]05M5;`1HAS00
GddY065?:`1RCbh0I54`06AA<@1RCc40HDdb05m;<01<B2/0BTHY04U3:@17@BT0AclZ04Tn;01:?B`0
Bch^05<n:`1D?b`0ED0[05I2:P1G@bX0F4@Y05U5:P1IARP205a:9P0705e;9`1NC2P0H4hZ069@;01T
DRh0IE<_06ID<00206MF:`0A06IG<01WFC@0IeXh06MI?01VFcl0IUY0065B<`1TE380JELa071K;P1h
HBl0PFL^08Q[;`2<KRh0UG<c09]i>@2POSh00P2SPD40102TPT80Z8I60:b:BP2aRTL20;><B@0M0;29
AP2/QD80ZhA10:n8A@2cS4T0]Hi10;N@A@2jU4/0_9MA0;bIE`2lVUX0_9YM0;ZJG@2^Uf40/YUQ0;6F
G`2/SEH0YX=;0:=oA@2XPDP0[HA<0;B3B`2aP4H0/7m40;F5A@2nSd/0a9E=0<FGC033UDP00P30VEH0
102oV5D0_YMD0;fFD`2mUU<20;bEDP0;0;^KH02lVEl0^iUL0;VEE`2jU5D0^I9A0;V@D02iT4h0/IAL
0;2CF`2_T5T00P2_SeH01@2cT5P0]Y5J0;NBF`2cQT/0/HA90080[h9700d0/HA90;F8C@2jSE80_I1E
0;F=C`2bRT`0[XI80:^3A@2YPD<0ZX940:b4AP2]QDL0]8Y>0080/h]>00<0/Xa>0:n;C@2^S4d00P2/
SDd05P2XQD/0YhA:0:J3B@2TPDL0Xh160:5nA02POD<0Wga20:^1A`2ZP4@0Z7m10:Mn?02XP3X0ZH8g
0:^4=`2/QCP0/Xa50;2:@`2/QSl0Z88k0:Eo>02TOSL20:=m=P0A0:9n@P2TP4@0Y8140:5m@@2ONcl0
XWi20:^7B`2cSe<0`ii=0;jIB02hTd80/Xdl0;2;>P2aS3/0]I0o0;RC@P2XOcd00P2WP3l0102VOch0
YGm00:9n@02POT4209em@P0909ai@`2JMcl0V7Dm09Md>P2FM3L0V7Hg09Ug=`2JN3P0WWPi0080WGLh
01H0W7Hg09]e=P2JM3D0VG<d09Qb<`2HNCH0UWLd09Ae=02BLc<0TG4d095a=P2BLSL0Tg<j08e`=P2<
KcD0Rfhf08Y/=P28JSH0QVPf08EW=@24ICH0Pf4c0P23HC403@24Hc00QVD`08UX<P2<K3<0SVhe08ee
;`2>MS00UWdj09n6A02HOcl0RFlb08E[;P2;LCH00P2?MCX01`2?MC`0T7Dn099g@P2FNTP0VGe;09]o
C`2QQ4`00P2PPd/00`2OPTX0WX5909j1B@0209f0B0P0UWa10P2DNT4309Ek@P@0UWa30180U7Y1095g
?P2>M3/0SG<j08ab>@2=LcX0SW@k08id=`2=LcH0S78g08]a>029KcH0R6df08M/=`26JcH0QV/d08AY
<P23J342089W<00]08=X<@24JC80QV/d08]]>`2=Kcd0U7I409n1C`2/SU`0]9IT0;FGI@2cUF<0[HiE
0;2AFP2fV6H0^iib0<:VP@37[8l0c;2H0<jcWP3A^jH0d;RL0<beR`3:/7d0a:M_0;FFH02VPU80VGA8
08=^=@20Jc80O6L`07MR;@1cGB/0LE/Y075K:P1`FRT0KeX[06mJ;@1^FB`0K5L/06UC:P1UCbP0HD/V
05m9901KARL0FTDV0080Ed@V00h0Dd8V050o9@1=?B@0BS/T04Tj8`1:>ah0BSXP04Pj8013=b40?S<Q
03P/7P0a9a/0;R@J02HV7P<09BDM0P0T91`202<S6a00824K200M7A/201`L6P<07AdK0`0N7Q`201`L
6P<06a/I0`0J6QP201`M5`<07AhH0`0N7aT201/L5P0401`M5`0M7QP07QlI01hO6@807b0J200P8A/5
024P6`<081lJ2P0R8QX302<S6`<092@L0P0W8aX0100X91/0:BDL02/W7P0/:1l202dY800303D/7@0d
:a`0<BPI0080;bHG00<0<2LH038Y6P0d:a`00P0d:1`00`0e:Ad0=RXN03L[7`0203P/800D03T]8@11
;b<0@2hR03l]7`0o;Qh0@C0P04<b8016=B40B3LS04Td8@18<b00B3<N04Pd701:=Qd0C3PM050l8@1B
?b40CS/M04ll7P1C>al205Dk800505Xl8P1O?B@0HCdU06<m9P1>>R800P1=>B40201<>200CCTQ04lk
8`1A?BD0DclW04li8@1@>R80DC/S0P1B?2@00`1@>R80CSPP04`f7P0804`g8P0404dl7P1;>Q`0BCPJ
04Pg6@80AcHH00H0B3LI04Th6P1>=AL0D3LI058i6`1D>ad205Dl7P0805@k7@1C>Q`0DS/L058k701D
>ad0Ec`O05Xl801M?R82060n8`0@06E78`1TAR80I4HR06A68P1UAb<0IdTU06Y<:01[CBT0ITPV06M9
9`1XBRP0JT`Z06]=:`1]Cbd0KU0^06mA;`P0JdXW0P1XC2D206U;9@0406a<9P1]BbH0KTXV06i:9P<0
JD/Y1@1XBRP0101ZBBP0JdXY06]::@1[BRT206a;:P80KD`[00H0KT/U06m<9P1`CBL0LDhX079?:@1c
D2X207AA:`0@07AA:@1eDRX0MU<[07QE;@1jEbl0NeP`07aI<@1mFS80OUPY07mI:P22G2d0Q5h_08EO
<024GRl0Ped^089L;@P0OUL`0`1nF2/01@1oFB`0P5X]089L;`24GS40QElb0080P5`Z00<0P5`/081K
;P20Fbl00P20Fc401@20FS<0PUd`089M<022GRh0Pel]0080Q60/0P25HR`01P25HRX0QVD_08IU;`28
IBl0RF@_08aT<080SF@`00D0SV<`08US=02;ICH0SVPi091Z>`02095[?003091Z>`2?JCX0SVPi00L0
SVPi00T0Tfdn099/?@2AJc`0TF/l099/?@2DKSl0UW1109Qb@`2EKd000P2DKSl00`2CKCh0TV`m095[
?002091Z>`0308m[>`2@K3`0TVhn0080Tflo00@0TVhn091/?02?Jc/0S6Ho0P2=J3h00`2>JCd0SfXm
091/?002095]>`04091Z>`2AJc`0TF/l099/?@80Tfdn0P2DKSl208m[>`80SVXj00P0Sf/k095]?@2C
Kcl0U710091[?P2BKD00U6m209IaA0<0Ug9500L0UW5409IfA@2FMTD0UGE409Ad@`2BLT40TG500080
T70o0P2DKSl209E_@0<0UW1100L0Ug5209A_@P2DKd80UG1309IaA02GLTD0VGA70080VWE80P2JMTH2
09UeA@<0V7A400@0Ug=309Ib?P2HM400VWI20P2KMd<02`2JMT80V7A009Ib?P2CKcl0U71009Ea@@2G
Ld<0V7A409YfAP2KMdL0W7Q800P0VgM700<0VgI209Ye@@2IM4000P2HLcl01@2IM400VgI209ag@`2H
Lcl0Ug8n0080UW4m00D0Ug8n09Ud@02IM400VgI209ehA00209Ud@00809Ye@@2KMT80WGQ409iiA@2O
NTH0X7]70:5nB02TPD/20:R5C`80YX==00<0ZHI@0:f:E02`Rel01`2`Rel20;6<F0@0/8]G0P2_RUH4
0;:=F@@0/hiJ00<0[HQD0:j9E@2_RUH00P2_RUH02`2]R5@0ZXEA0:V4D02ZQdl0ZhQ@0:b9D`2]RED0
[h]I0;2<G02aSEd0/HaO0080/XeQ00<0/hiQ0;B@H02eTEl00P2fTUh0102gU5h0]i=O0;NCG`2gTel2
0;RDH0<0^IEQ102fTUh20;NCG`80^9AP00<0^YIV0;^GI`2lV6P00P2mVFT00`2lV6P0^iMW0;ZFIP02
0;JFI@80]IET00X0]9AS0;>CHP2cTf80/Y9Q0;NHHP2eUV00]9=N0;>?F`2bSUX0/XeI0P2eSEX20;>?
G`<0/XiN0`2aSEd01P2bSUX0/HeI0;6=F@2`S5P0[h]G0:j:EP80[HUE0100/8]G0:n:EP2^RED0[HQD
0:b7D`2[QU80ZXEA0:V4D02SPTl0Y8=@0:J5DP2WQU<0Z8MD0:N6D`2VQE80YHAA202WQ4h01P2VPD`0
YH1;0:AoBP2SOTT0XWe80:5lA`80X7]600`0WgY509ag@P2ONTD0Xgi90:J1C02WPTd0YH1;0:9mB02P
NdH0Xgi90:9mB02PNdH209mjA@030:5lA`2SOTT0Y7m:0080Y81<0`2UPDd30:J2CP@0Y8=F0P2UQ5L2
0:J5F080ZHA@00<0ZHA?0:V4C@2YQD/00P2YQDT01`2YQDL0Z8=?0:V4D02YQ500ZhIB0:b7D`2]R5@0
0P2^RED30:V4C`@0ZXE@00T0ZhIA0:V6C02WQ4X0Y8570:5nA02POD<0XGi40:>0AP2TPDL00P2SN4D4
0:AiAP80YGY70`2RMd8[ooooo`00:_ooool80:=hA@80Y7U60`2UNTL30:IkB0P0YG]900P0ZWm<0:Ml
B@2SN4D0X7E20:5f@`2TNDH0ZGi;0:b1CP80Z7m;0`2YP4`30:Z1C@@0Zh9>102ZPDd0202^QE40Zh9>
0:QoB`2UO4P0Y7]70:ImB@2YP4`0[8=?102ZP4h40:^1C`80ZHA@00@0Yh9>0:J1C@2TOd/0Xgi:0P2Q
O4P0102MN440WWU209mj@`2ONT<209eh@@0C09]f?`2HLc`0UW4j09E_?P2DKSd0U6ho09=]@02BJd00
TFY1091Y@02@JD80S6Pf08eY=`2>JSX0SVTl08iY?@2<Icd0RVDk08US?00208ER>P0308AQ>@23H3P0
PUlg0080PEhf00L0P5de085N>01oG3H0OEXd07YG<@1iES00N5D_0080NEH`0`1eEBh307AD;@80Le</
00P0Kdda071><P1aD340LU4`07AC<01eEBl0MUH`07MG<080Pehd0P24GcD03025H3H0QV4g08IQ=`26
HCL0SF<i08iT>P2?ISX0TFPj09=[>P2EKCX0UVhk09M_>`<0V6hl0P2IKcd309Y`?P80VWE100<0VGA0
09Qc?`2GLSh00P2EL3`01P2DKc/0U6ho09A^?`2CKCh0TV`m095[?080T6Xk00<0SfTj099/?@2BK3d0
0P2AJc`0302@JS/0SfTj08mY>P2>J3T0TF/l08mY>P2=IcP0RV@e08US=02:I3D0RfDf08aV=`<0SFXd
0`2<JC<208]X<P<0SfHj0`2@Ic/2095X?0<0RfDf1@2:I3D308ES<`0308IT=027ICD0R6Hf0080R6Hf
0P2;ICH208YT=@80RF<d0P28HS<208YU>080RF@g1028HcH01027HSD0SFLh08eW>02=IcP208aV=`/0
RfDf0P28ISH208MU=@80QV@d0P25Hc<00`27Hc<0R6@d08UU=@0208UU=@0408MS<`25HC40Q60`08QS
=P<0Qf8e0`26HC@01025H3<0R6<f08QS=P28HcH508MR=@0308UT=`2:ICP0RVDh00@0RfHi00<0RVDh
08UY>029JCP01P29JCP308eX?0D0S6Lk00P0RfLg08eY>@2?Jc/0TFdm099^?P2CKcl0TVhn095]?@P0
RF/i01P0Sg1108i_@02=KSl0Rf`m08UZ>`27J3T0QVLh08EV=`26JSX0Of@e07ML;@1`F2X0KUL[06]F
:`1UDRP0HDhT05m89P1NAbD0F4DU05919@1<?R<0AC/R040h8`0n>282034b8006030a8@0^;b40;BdQ
02`/8P0[:b40:RXR0P0W:2000`0V9al09BHN02@U7@0202<T7004028S6`0N8AP07R4H01lR6@8082<J
00D08B@K028U700R9A`08RDL024T6`02020S6P04024T6`0S9Qd09BPO02LZ8@T08B@M0`0R8a/202<T
70<092DM01`09BHP02LW7`0X:1h0;R`O03<`7`0j=B40@3XT04<m9@1<?280Cd0S05I69@1OCBT0IE8X
06YH:01_FbP0L5`W071D;@1XCRT0FdLV04`m800m=Ah0<RlN02/]7`0X:b00<RTH03@[6P0f;A`0>C0O
100k<R403P0c;Al0=2hP03D_8@0e;b40=2hP034[7@0_:A/0;BLI034[7`0_:al0;RXN02`Z7@0Y:Q`0
9bTK0P0U:AX302DU6`<09RHL0P0W9ad202HW7`0402DV7P0T9Ad08b@L028S6`808B8J00<07B8K01`Q
6P0L7aP00P0M7QP08`0O7QT08b0K02@Q700[82@0<BHR03/`7P17>A`0D40L05I27`1G@200ES`Q05Xl
901D=Q`0G3lO07IJ<P2:Kd00SWDm08mg>`2CNc/0ZH540:b<D@2JQU40KfHk04Q49`0f<b@0<bTX02lR
:@0U:2409RTR02LZ8`0X:b@09bXS02DX8@0R9Ah082<L00<08bDR0`0T9R<202DW9009028W8@0Q9R00
8BHO024W7@0R:1`092XL02H/7P0X;al0<C8T0080<S8V01@0<S8X030`:00];2L0:BPT02LV8P0W:2<0
:2LS02LV8@0Y9Ql0:bLN02lX7P0c:R40=2`Q034^6`0b;a`0=34N03Db7`0f<b00=C8O03@a7P80<c0M
00@0=C4U03Pd:00j=RX0=c<W0P0b;R803@0g<bL0?3P/04<h8P16>R@0BCdU04do9@1@@2H0DD0T05<o
901B?b40CC/U04`j901;>B<00P1:>2803P1;>B<0C3XT04dk9@1?>B@0D3XU058l9@1D?RH0ET4V05Q3
9P1IA2D0FTDV05Y7:@1IARP0ET<U0`1D@B<00`1F@bD0Ed@V05M6;00205M6;080F4L]0`1IB2h05P1M
B2T0G4LX05Y7:@1EA2P0Dd8X05109`1=?RL0C3dV04Ph8@19>B80BSXS04`l9@1>?RL0D40Y0551:P1B
@R/0E40O05I28@1JARD0GDTX061<:`1QCB`2061<:`80IE8Z01L0HdlZ065=;01OBRd0GTP`05a6;`1K
AC00G4Lf05U2<01F@2T0FD4U05i59P1RB2<0HdLO06566`1@?bd0CSd[04/j:019>2H0BSTW04dl:P1@
?bd0Dd8`048f800204@h8P06048f8010=1h0@cLQ04Tm9`1?@bd0CcT[0P1>>BP09@1>>BH0CcXU054m
9@1C?bH0E40W05529@1>?RL0ASTY044d:`0m=BX0?3TV03lo8`10A240ASlU04]1:01>@RX0D40Y054l
9`1E?2P0G44^0695<`1XBBd0J4X`06E;<01PC340FT`a05A:;`1=Abd0BTH[04I3<P17@C40AD0]04Dn
:`16?RT0BSlY04e1:`1>@RX00P1F@RT205M3:P80F4@[0P1IAB`2065==@0<05m;<P1MBC00G4P]05i;
;@1RCbl0Ie@c06YG=P1YF3X0IePk06AE>01QDcP0GU8h0P1MDcX07`1LE3d0JTXc06a=;P1_DRH0ME/R
07eS9P26K2l0SW@k09=h@`2BN3l0VGm60:64BP2PPTH0Vg/n09il?@2WQDH0/Xm?0;JEDP2eU540]99B
0;:@D@2_SE00[8Y=0:Z7C@2YQT`0]Y170;RBB`2iU4h0^YME0;^GF@2kVE`00P2hV5l0502fW5l0]IQL
0;>CEP2aSDl0/8M90;>3A@2cOd<0]7i00;N=@`2hST@0^Hm50;^AA`2lTTP0_YA:0;nEB`30UT`0_i]A
0;jJD02mV540_9MA0P2lUe<20;fGEP80_IE@00@0_9A?0;^CCP2jTTd0^I5<0P2hT4/20;fDEP0<0;^E
EP2hUED0]9ED0;6FD`2_UU<0[YMC0:F>BP2VSDX0Yha90:J;B02VRDL0YhQ70P2YQdL02`2VR4`0YhU=
0:F7B`2QPdL0WX1409n1A@2UQd/0[8iB0:F4C`2VQE00YhIA0080Z8MB00/0YXE@0:B3CP2RPD`0[7]1
0:eoA02aPdP0/hI;0;26BP2[PdH0YGm10:9l?P030:f6@`0M0:j7A02_R4D0[hQ50:n8A@2`RDH0[hM9
0:R0@P2SNcd0YWi00:f5A`2^QTP0YWi009ee=`2WNT40YGPm0:=g>P2RMSD0XgPc0:Il<P2[PCD0[H<g
0;63=P2bQ3L0]XPk0;j@@`37VD`0bYa?0<RJC@34UTT00`2ZPD<03P2YP480Z7m10:Im?`2TNcd0XgXl
0:9i>`2YOdD0YGY309md?@2IKST0Uf`i09Q/>`2JKSl0WG520P2FM3D00`2GMCH0V7Hg09Ug>00209]i
>P0709aj>`2IMcP0V7Hg09Qf=`2GMCH0UW@e09Ec=00209Ab<`0X08mZ<`2>JC80S6Tc08QW<P25IC80
PfDa085S<@1nHS00RF`d08MZ<P25J300PfH^08AW;`26JC40RVde08a_=`2:KRd0T7@c09Ql>`2LP3l0
VWhm09Ei>02AMC@0Sg<b08me>02@MST0TgTn09Il@`2GOD@0Uga509IkAP2ENTD0XhU@0:67CP2OQD`0
W89909^1B02LPTT0WH=:09j4B`D0W7m70`2MP4P0202JP4L0V7i509Il@`2ENd80U7Y109Ek@P2FO4<0
Uge40P2DND8309=h@@<0TWM00300SG@l08ac>`2;LSX0RW4i08Q_=`27KSH0QVde08E/=026KS80QFda
08=Z<@22JC40PVTc08=Y=P25JcP0QV`k08a^>P2@LSh0V7Y80::3E02/SEl0/iAX0;RIK@2kVg80/I]/
0:nIJP2^Uf/0]9ec0;jWOP37[hT0bk>=0<bdT03@]J80e;RS0=JkX03F^IT0cK280<2QL`2aTEh0YhQB
08iiA025L3/0NF<a079L:`1bG2d0Le``07AM<@1cG382075F:`08079G;01aER/0L5DZ06iC:01[D2D0
JDhS06A>:@1PC2L205a89@0H05M48`1B@R40D44R04i18@1>@2<0CSlP04`n8@1:?280ACTQ040e8@0i
<1l0<b`L034Y700W:A/09bTL02HX6`0U9a`092DM02<T7P0S91l08R<N01lN6@0Q81/08b8M0P0T8ah0
0`0S8Qd08R4L024P6`02024P6`@08R4L0P0S8Qd202@T70808b<K00@08R8J024Q6@0P81P0820H0P0Q
8AT2020P60<07alG00<07QhF01hM600N7AP01P0N7AP801dL5`0401hM600O7QT07ahI01lN6@8081lJ
0P0Q81/8020O6`08020P600O7aL07QhF01hN5P0O7aL08R8J02@T700V9Qh302<O5P80920G0`0U8AP0
100N81D0828G028T6@0U9a`302HX7@0902DW700Y9QL0:RLH02dW6@0_9aX0<BLK03@X700f:1d0=bTN
0080=BTM0`0f:Qh303L[7`<0>B`K0`0j;A`203/^7@0403l^7P10;al0@2lO040_7`80@C0P0P12<B42
048f700604@f7015=ad0BCTP04dk8`1B?RH0E40X0P1G>Ad305Pj7P@0FC/O00P0FcdQ05Xl801H>R00
EcTQ05Lh8`1I>RH0Fc`X05dn;080ECXU00<0E3TT05<h8`1B=b800P1A=R40101@=B00DC`O04lj7@1=
>1/204/f6@0;04dh6`1?>Qd0DC`O054k901@>R<0CSPQ04dg801>>240D3XS058l9@1C?BH00P1E>RD5
05Hk9P0905Ll9`1E=al0ESPP05Pj801J?200G3lQ05i18@1P@b<0H4<Q0080IdDY00h0J4LX06U89`1Y
B2L0JTTV06Y:901[BbD0J4XT06U;9@1[CBL0K4hX06i@:P1`DR`0LE<]079D;P80Mdl/00H0MDl[07=?
:`1`CRT0KThX06a<9P1YBbD306i>9`80KDdV0`1/C2D01P1^CBX0KD`Y06a;:01[BRL0JTTV06Q79080
IdHS00@0JTXS06];901[Bb@0Jd/T0P1/C2D206e=9P0806U6801ZAb40JdPR06e:901^BbD0L4dW075>
:01bCbT207QE:`0907UF;01kF2h0O5T_07eJ<01nFc40Oe`b085L;`22GC00Q5lb00<0QF0c00P0Peha
089M<023GS40Peha089M<021G2l0OeX]07iI;080OEP[00<0QV4d08EP<`23GS400P21G2l00`22GC00
Peha08AO<P08085M;@<0PU`]0`23GBh308AN;`P0Rf4_202BJ3H0202=J340SVTb08iY=02>JCD0SfTh
08mY>P2@JS/0T6Xm0P2@JcL00`2AK3P0TVdi09=^>P0209A_>`0409E`?02BKSh0Tflo09A`@080UG51
00<0Tflo095]?@2?Jc/0102BKSX409=_>`<0UW130P2EKd8309A^@@80T6`l0P2AKCd3099^?P0309=_
?`2CK440Tfa10080Tfa1102DKD80402DL400UW9209QdA02IMDD0VWI609UeA@2HM4@0Ug=309EbC02F
Ld/0V7E=09YgC@2JN4/0VGM909QfAP2GMDD209Mf@@80UWE00`2EM3l01`2DLch0VGE509UeA@2JMTH0
W7Q809eiB@2ONd/00`2PO4`00`2NNTX0W7Q809YfAP0209UeA@0509YfAP2KMdL0VGE109Qd@02GLcl0
0P2FLSh00`2GLcl0V7A009Ue@@0309Ud?`80VWE00`2KMT40102KN480W7U309ai@`2LND<209ejA080
WW]500P0WWm809amAP2JND<0VGI009Qe?`2JMD00WWI209mg@`@0VWI21@2IMD401P2JMT80VgM309]g
@`2LN4@0WGU509ijAP80Wg]700L0Xgm?0:B0D02VPU80Z8AD0:Z6EP2/R5P0[XYJ0080[h]K00L0/HeM
0;>?G`2eTF40]I5Q0;B@H02cSel0/XiN0080]i=S0P2fTV830;FAH@030;B@H02fTV80]I5Q0080]I5Q
0P2dT6020;>?G`030;2<F02_ReL0[HUE0080[8QD00<0[HUE0:n;E`2`S5P00P2^RE`20:n:G@<0/8]N
00X0/HaO0;:<G@2cSEh0/hmO0;:@H02bTV40/YAR0;>EH`2aUF<0[i=S0P2bTf@01@2dU6D0]YAV0;VD
I`2jU6L0^iEX00<0^IMY0`2jV6X20;^IJ`P0_9QX00H0^YUT0;VHH`2iV6<0^9MR0;NFH@2fUF020;FD
G`@0]I5M0P2dT5`20;>?F`80]I5M00@0]91L0;>?F`2cSe/0/XiJ0P2aSET20;F@G0030;B?F`2cSUX0
/XeI0080/HaH00L0/8]G0:j:EP2^RUH0[HUE0:b8E02[Qe<0ZXIB0080ZHEA0P2XRE80102XQe40ZXMA
0:V6D02YQ4l20:Z2CPP0Xh=:2@2UP4/00`2NND@0X7]60:5lA`030:=nB@80XGa70P2SOTX20:AoB`<0
YH1<00H0YX5=0:F1C`2UPDl0YH5?0:J2D02WPe430:R4DP80Y81<00@0YH5=0:J2CP2WPdl0Yh=?0P2X
Q5020:N3C`040:R4D02YQE40ZHEA0:Z6DP80ZhMC00<0ZHA@0:Z5D@2/Qe<00P2/Qe<00`2ZQE40Z8=?
0:N2CP080:V5D@80Yh=90P2VPTP01@2UPDL0Y8160:=oA@2SOdD0XGa70080X7]600<0WgY509iiA02N
ND@00P2MN4<30:5h@R_ooooo000Zooooo`P0XgQ50P2TNDH30:EjA`<0YW]8202TNTP00`2YOT/0Yga9
0:EjA`020:AiAP030:IkB02YOT/0Zh1=0080Z7m;0`2YP4`30:Z1C@@0Zh9>102ZPDd00`2_QU80[HA@
0:V0C0020:ImB@030:QoB`2ZPDd0[8=?00@0ZX1>102[PDl0202YQ500Z8=?0:N2CP2VPDd0Y7m;0:=n
BP2RODT0XGa80P2ONT<20:1kA080WWU200<0W7M009Ud?@2GLS/00P2EKch00`2DKSl0Tfe0099[@002
095Z@@09091Y@P2<J3H0SFTg08iZ>P2>JC`0SVTm08aW?@2:IC/0R68k0080QF8j00@0Q64i08=P>022
GcL0PUlg0P21GSH01P21GSP0Oe`f07eJ=01jEc40NEH`07QE;`80NEH`0`1eEBh307AD;@80Le</00H0
L4hb075@<@1bDC80Le8a07AC<01eEBl207IF;`80Pehd0P24GcD03025H3H0QV4g08IQ=`27HSP0SF<i
08iT>P2?ISX0TFPj09=[>P2EKCX0UVhk09M_>`<0V6hl0P2IKcd309Y`?P0509Ye@@2IM400VGA009Qc
?`2FLCd00P2EL3`01`2DKc/0UFm009E_@02DKSl0Tfdn099/?@2AJc`00P2@JS/209=]?P80TV`m00P0
TF/l091Z>`2@JS/0T6Xk095[?02?JCX0SFLh08]U=P80RV@e00<0RfDf08aV=`2=JCD00P2=JCD208aX
=0<0RfLc0`2>ICT308mV>P80T6Lk0P2<ISL608]U=P80QF<c0P26I3@01027ICD0R6Hf08QV=P28ISH2
08]U=P80RV@e0P29Hc@208QR<`80RVDh0P29I3L508QS=P80SFLh0`2<ISL;08]U=P80R6Hf0P27ICD2
08IT=080QF<c00<0QV8b08MS<`28I3@00P29ICD00`27Hc<0QF4a08AP<00408EP<`@0QV4d2027HSD4
08UT=`@0RVDh2029JCP408eX?0@0S6Lk00@0S6Ph08eY>@2?Jc/0TFdm0P2CKcl00`2BKSh0TFdm08Y/
>P0708Y/>P0H08i_@02=KSl0S6dn08Y[?028JCX0QVLh08EV=`24ICH0Q6Ph07eR<`1fFb`0L5PZ06iG
:`1/Eb`0IU<Y069?9@1PBBL0GTLU05U69P1C@RH0C3hS04Hl8`11>B@0?SPR0P0`<Al01P0_<200;BhP
02`/800Z:R00:BTO02TY8@809bPP00@09RLO02DV7P0T9Ad08b@L0P0R8a/00`0N8AP07b8I01lR6@02
020S6P808B@K0P0R9A`01`0Q91/082<J020S6P0Q91/08bHM02DX7`0W:R402@0Q91d302<T708092DM
0`0U9Qh07P0V9b40:2PP02TY7`0^;1l0<c0O03Td800o>B<0@C/S04Pj7`1<?B00DT<T05U99@1PCRH0
IE<U06YE9P1[EbD0JDlZ06=;9`1F@b<0B3XO03/c700a;Q/0:bdO02P/7P0b:AP0=2/J03H]700i<1l0
>S4P03/b8@80>S4P00T0<bdO03@^800d;R00=BlQ03<]7`0a:ad0;bTK02dW6@0a:al00P0^:Qh00`0/
:Qd0:BXL02LY6`0202DY6P<09BDK0`0V9Q`202LW7@0602HW7`0U9Qh09BHN02@U7@0S91`08R<K0P0Q
8QX00`0M8Q/0724J01dP6@0201dN600K01lN6@0S81/0924L02/Q8P0a9R00?C0M04Lj6P1@@1`0ED4N
05Ho7`1F?240FC/Q05Pj7P1UB2H0O60h08ab@@2?MSh0TGTm09In?P2_QdX0ZXYA095mB`1UGCH0@T4U
03Da9@0a:BL0;R8V00809RTR0P0W:R<0100V:B8092LP028U7P0Q91d302<U8P<092HS0P0U9b@02@0R
9b408BHP024V7`0Q9ad08RPL02D[7@0W;Al0:2lO034b9002034a9@0D034a9`0_;bL0;2/V02TX900W
9R809bPS02PW8`0W9R40:BHO02`X7`0`:Al0<bXQ03D]8P0b;a`0<c0M03Db7`0f<b00=c@Q03Hc800e
<Ql203@a7P0403Hc900i=RL0>SLX03Ld9@80<c0Q00d0=c@U03`i:P12=b40ACTS04Pl901=?bD0D40V
05919@1D@2D0E44S04hl9P1<>R@0BcTS0080BSPR01@0BcTS04`j901>?2H0CcTT050j9@1B?2D0E3hV
05I19P1H@bH0FD@U05Y59P1JAbT0F4DW05I39@1E@R@0E44S05E2901F@bD0Ed@V05I5:`<0EdH/0P1H
Abd205U8;P0805e8:@1LAbP0FDHX05E4:01C@RP0D40W04dn9`1<?BH204Xj8`0404/k901<?2D0CShW
04lo:080D40Y00H0ED4P05M38P1JARD0GDTX05i::@1OBbX205i::@0I06=?:P1RCRT0HDdZ05m::`1M
B2/0G4H^05]5;P1JA2d0Ed8a05<n:`1B?2D0F40V06A;;01bF3D0NV4i07mS>`1B@Bl0D3l]04`k:@19
>2H0B3LU04Th9P1<>bT0CSd[04<g8@0204Di8`06048f8010=1h0@SHP04Pl9P1>@R`0CCLY0P1=>2L0
9@1=>2D0CcXU054m9@1D@2L0ED4X05529@1=?RL0ASTY040c:P0l=2T0?CPU03ln8P10@Al0B3hU04a0
:01@@BX0D40Y054l9`1D?RT0Fd8^0697=01UAbd0I4T^069:<01NBS40F4X`0598;`1<AR`0BDD/04Q2
<P17@Rl0ASl]04Hn:`19?RX0BclY04e1:@1@@BX00P1F@RT205M3:P80F4@[0P1IAB`2061<=00:05m;
<P1MBC00G4P]05i;;@1QCRh0IU<b06QE=01TECP0HU<f065B=@80GU0e03/0G50f05iB>01ODc/0Jddc
06e@<01aERT0MehU07iV:027Kc40SWDm099hA@2BN3l0VGm60:64BP2OPTH0Vgdo09em@02XQTL0/Hm@
0;>DD`2bTe80/I9B0:n@D02]SE00Zh]>0:V9CP2XR4d0]I190;NBC02gU500^IID0;ZHF@2jV5/0]iML
0;NGGP2cVE`0/iMH0;6AE02`S4h0/HQ:0;:4AP2ePd@0]X=40;R>AP2iSdL0^Y180;bBBP2mTd/0_iE=
0<2FCP31Udl0_IU?0;jJD02nVE80_YUC0;jIE@2nV5L0_IMF0;fGF0020;fFD@030;bED02kU4l0^Y=>
0080^I9=00l0^95<0;bDE`2lU5L0^9AF0;JDE@2bTe<0[i=B0:bCD@2ZTe00Y8];0:J:B`2URDX0YHM9
0:F5B02VQ4L00P2WPdL02@2UQDX0YXI;0:J6B`2SPdP0Wgm40:20A@2UQDX0ZXY?0:R5C`030:V6D00<
0:R5C`2UPT`0XWm90:5nB02]O440[Gm30;22AP2`Q4L0[XE70:^3A@2WPD80YGm00P2]QT<40:j7A080
[hQ50100/8Q:0:Z2A02VOT00ZX940;69B`2bRT`0Zh=50:=k?@2ZOD80Z7]00:Ij?@2UNCP0YW/g0:Uo
=`2]PcT0/8Hl0P2dR3d01`2fRSl0_9150<6EBP32UT/0_Y970;V=@P2YPD<00`2XP4804`2WOd40YWi0
0:Em?`2TO3h0Xg/m0:R1@02UOCl0XGTk09ee>02JLSL0VW4i09]b?02LLcd0UW@e09Me=P2HMSL0VGLh
09Yh>@2KNCX00P2LNS/209Ug>00T09Qf=`2GMCH0UW@e09Id=@2ELc@0U78c095]<`2@Jc@0SV/c08YY
<`27J380Q6Hb08=U<`20I380R6/c08IY<@24Ibl0PfH^08AW;`27JS80Rfhf08e`>02;Kbh0Sg<b09Ij
>@2LP3l0WX9109Yn?@2CMcH0SW8a08id=`2@MST0TgTn09Ek@P2GOD@0V7e60P2GO4L0102SRE00XHM>
09n5C02MPdX209b2B@0309f3BP2NQ4/0W7m700D0W7m70P2MP4P0202JP4L0V7i509Il@`2ENd80U7Y1
09Ek@P2FO4<0Uge40`2DND8209=h@@<0TWM000H0SG@l08ac>`2;LSX0RW4i08Q_=`27KSH208I]=@0Y
08I^<P25KC40PfXa089Y<@22JC<0PfTf08E[>026K3/0S6hj091b?P2HNTP0XX=D0:b=G`2cU6P0^IY^
0;^KLP2cWFh0/9Y[0:jGJ`2cW780_JIm0<J^R03:/X`0bk>?0=2eXP3C^:<0ekbQ0=NjVP3@/X`0a:Eg
0;FGI@2/S5T0UWm908ae@@20JCD0NF8`07MO;`1hH380N60d07MO<`1aER/00`1bEb`01P1aER/0KU<X
06aA9P1ZCb@0IDlZ06==:080GDTV01d0F4DT05=38P1A@R40D44R04m28P1>?b00CSlR04/m8P16>R80
@CHR03Xa800e;1d0<RXM02TZ700X:A/0:2PL02LW7@0V9Qh09B@O02@S7P0T8al081lJ024P6`0S8Qd0
92<N02DT7`0T8ah08R4L024P6`04028Q70@08b8M00H09BDM02@T700T91`08b<K028R6P0Q8AT2020P
60808B4I0P0P81P401lO5`P07QdH200M71L401lN6@8081lJ0P0Q81/8020O6`80820H0P0O7aL0100P
81P08R8J02@T700V9Qh302<O5P80920G0`0U8AP0100Q8AL08R8H02@T6P0V9Q`202LW7@0:02HV700U
9A/0:RLH02XW600]9aT0;bLJ034W6`0d:1`0=RPM03LY7P80=BTM0`0f:Qh303L[7`<0>B`K0P0j;A`3
03/^7@<0@2lM0P11<1h3048a7`80@cLM00H0ACLM04Hf7@1:>200Cc/S054m9@1D?RL205Li7@<0F3XN
0`1I>al02P1J?200G3lQ05/m8@1I>al0F3XP05Pj8P1J>bH0Fc`X05dn:P1F?2D205Dk900305@j8`1C
>B80DSPQ0080DCLP00<0DC`O050k7P1?>Qd00P1>>A`02`1?>Qd0D3/N054l7`1A>b<0D3XR04li8@1>
>200CcTQ054k8`1B?2@0E3hV00D0EC/T0`1F?2D0201F>200EcTQ05Pj801J?200G3lQ05i18@1P@b<0
H4<Q0P1WABT01@1XAbP0J4LV06U89`1ZBBH0JTXT0080Jd/U00L0K4`V06e=9`1_CbT0LE4[079B;01d
E2h0MED_0080N50]00<0MDl[079>:P1`CRT00P1^CRP00`1/CRP0KdlX06i>9`0206i>9`80KDdV0P1/
C2D206e<:@0306a;:01[BRL0JTTV00<0JDPU0`1[Bb@206a<9@<0KDdV00H0KDXT06i;9@1_C2H0L4dW
079?:@1cD2X207EB;080N5D[00d0NEH/07]H;P1lFBl0OEX`07iK<@1oG380PE`_089M<024Gc80QF0c
08IQ=025H3<0Q5lb00<0Peha00@0PUd`085L;`20Fbh0OeX]0P1nFB`00`24Gc80Peha085L;`02081K
;P03089M<023GS40Q5lb00P0PUh^0`26H34308MQ<P<0R68c202<HS08099X=P80SVTb00<0SfXe08mZ
=P2@JST00P2@JS/01P2AJch0TF`h095/>02BKCT0Tfhj09A_>`80UG0l00T0UW4m09=_?`2DL400UG51
09Ib@P2ELD40Tflo099^?P2@K3`01P2CKc/209A`?00409Ma@P2FL440UW1109I`@@80UFm00P2DKSl3
095]?@80TVhn0`2CKcl609A]@P80UFi300@0Tflo09Ea@@2GLd<0VGE50P2JMTH209UeA@0909MdC02H
MDd0VWM=09]iC02JN4X0VGM709QfAP2GMT<0V7M200<0UgI10P2FMD0209Ed?`0;09UeA@2JMTH0VgM7
09ahB02NNTX0Wg];0:1lC02QODd0X7a<09mkB`2LN4P00`2JMTH209]gA`0309Yf@P2IMD40Ug<o0080
UW8n00<0Ug<o09Ue@@2JMT800P2IM3l209Ye@0<0VgI100@0W7M209ai@`2LND<0W7U30P2MNT@309ik
A@0609enA`2LODH0VgY409]h@P2JMd40VgI10P2NMT8709Yf@P80VGE10P2LN4@0102MNDD0WWY609mk
A`2PO4P20:5mB@070:=oC`2TP500YX9B0:V5E@2[QeL0[XYJ0;2<G0020;6=G@030;:>GP2dT600]Y9R
0080]Y9R00<0]91P0;>?G`2hU6@00`2gTf<20;JBHP80]I5Q0`2fTV820;FAH@<0]91P00<0/HeI0;2<
F02^RUH00P2]RED00`2^RUH0/8aH0;6=F@020:n:G@80/8]N0`2aS5l01P2bSF00/heN0;>=GP2cSel0
/Y1P0;:BH@80/iES00L0/YIT0;:FIP2dUFH0]9EV0;JFI`2gUFL0^IAW0080^iEX0`2iUfT30;ZHJP80
^iU[202lV6P01P2jVF@0^IQS0;VHH`2hUf80]iIQ0;JEH080]IAO00@0]Y9N0;FAG@2eTEd0]I5M0P2d
T5`20;>?F`80]I5M0P2dT5`0102cSe/0/XiJ0;:>FP2bSUX20;F@G0030;B?F`2cSUX0/XeI0080/HaH
00H0/8]G0:j:EP2^RUH0[HUE0:b8E02[Qe<20:Z6DP070:V5D@2YRU<0Z8UB0:V8DP2ZQe40ZHI@0:V4
C`020:Z2CPP0Xh=:2@2UP4/0202PNdH0XGa70:=nB@2TOdX0Xgi90:9mB02QO4L0X7]60P2RODT20:=n
BP<0Y7m;00<0YH1<0:F1C`2UPDl00P2VPU00102WPe40Z8AB0:R4DP2XQ5820:F1C@030:J2CP2WPdl0
Z8A@0080ZHEA00D0ZXIB0:R4D02XQ500Z8A@0:V5D@020:Z6DP80ZhMC00<0Z8=?0:V4D02[QU800P2/
Qe<00`2[QU80ZXEA0:V4D0080:V5D@060:R4BP2WPdT0Yh=90:J2B02UPDL0Y8160P2SOdD20:5lA`80
X7]600@0WgY509iiA02MN4<0WGQ30`2QN48[ooooo`00:_ooool80:=hA@80Y7U60`2UNTL30:IkB0P0
XgU70P2WO4T20:QmBP80ZGi;0P2ZOd`20:QoB`<0ZH1<1`2ZPDd40:^2CP030;27D`2^QE40Zh9>0080
ZH1<00<0ZX5=0:b3C`2^QE40102[PDl40:Z0CP080:V4D02XPdl0Yh9>0:J1C@2TOd/0Xgi:0:9mB@2Q
O4P40:5lA`80WgY501@0WGQ309]f@@2JMD00UW0o09E_?P2EKd00U6i109=/@@2BJd80TFY1095Z@`2=
JCL0SVXh08iZ>P2?JSd0SVTm08aW?@29I3X0R68k08IS>`80QF8j00<0Q64i08=P>022GcL00P21GSH0
1P21GSP0Oe`f07eJ=01jEc40NEH`07QE;`80NEH`0`1eEBh307AD;@80Le</0P1cDS<00`1cDS40M5<`
07AD;P0207EE;P0707IF;@22GC<0Pehd08=N=024GcD0QF0f08IQ=`0208MR>00808]T>@2<ICX0SVPk
08mY>P2AJcX0Tfhj09A_>`2EL3/309Q^?080VFlm0`2JL3h209Ud@00309Qc?`2GLSh0UW4m0080UG0l
00H0U6lk09I`@@2FL440UFm009A^?`2CKCh2099/?@03095[?02DKSl0Tfdn0080Tfdn0`2BK3d2095[
?003091Z>`2>J3T0S6Hg0080RfDf0P2<ISL208eY=@80S6Pd0`2;Ic<00`2:IS80RV@g08YT=`0308]U
>0<0S6Hi202=IcP308QT=080RFDe0`2:ISH208]U=P80RV@e0P29Hc@208QR<`<0RVDh0P29I3L408QS
=P0408eW>02<ISL0S6Hg08aV=`80RfDf2P2:I3D208YV=P80RFDe0P28I3@208MS<`0808IR<P27Hc<0
R6@d08UU=@28I3@0Qf<c08EQ<@24H302089M<00408=N<@24Gc80Q5lb08EP<`80QV4d2`27HSD208QS
=P0308UT=`2:ICP0RVDh00P0RVPh202=J3/0102<J3P0SVXj091/?02BKSh209=_?`03099^?P2AKCd0
S6hl00L0S6hl0P2<KCh0102:Jc`0R6Tj08MX>@25ISL208=T=@0@085U=@1kH340MEX[071H:P1`FBd0
KEP]06QE:`1TDBL0HDXX06199`1JAbL0E4<W04do9016?2<0@CTT03hh8P80;RlM00L0;BhN02//7P0Z
:Qh0:BTO02PX7P0W9al09bPP00809RLO00<09BHN02@U7@0S91`00P0R8a/301lR6@8082<J1`0Q91/0
100R9A`08bHM02DX7`0V:B09024T7@8092DM0P0U9Qh202HW7`809bPP01`0:BXT02XZ8P0Z:R00;R`O
038_7P0h<al0?3HP03hh8014=Q/0AcTN04dn7`1C@b40EdPQ05e;8`1PCB80H4hP05m89P1IAB@0CSdO
048f700g<A/0<2dJ02//7P0Y;Al0<RTH03@[6P0f;A`0>C0O0`0j<B003`0i<1l0<bdO03<]7`0d;R00
<bdO038/7P0a:ad0;bTK02hX6P0`:Qh0;RXN02dY7@0[:A`0:2TK02LY6`0202DY6P<09BDK0`0V9Q`2
02LW7@809BHN00@092DM02<T700R8a/08R<K0P0Q8QX08@0M8Q/0724J01dP6@0M7QP07QlI020O6P0T
8A`09B8M02dR800e:1l0?c<M04Xk6P1A?aT0EChL05Hm7`1G?240FCXM06528`1cEC40QVTo08mc@`2A
MSl0UG]009f3AP2fSe@0Y8E?07m/@@1ECbd0>cTT038`900^:BD0:b4R02HY8P0302LZ8`0402HY8P0T
9b008RDN024T7@<08bDR0`0T9R<202DW908092HQ00L08bHO02@W7P0U:1d0:2`N02X^800/<240<34S
0080<30T0100;blU02d]9@0[:RD0:2LS02LV8P0W:2<0:2LS02LV8@0Z9b00;2PO030Y7`0d:b80=RhS
03Ha7P0g<Ql0>C@Q0`0k=R<303Td8@0C03Xd9P0k=BL0?3HX03Xd9P0h<R@0=c4S03Xd9P0m=bT0@CHP
04@h8P17>b<0CClU05519`1C@RH0ET8W05I39@1>?2H0CC/U04/i8`0204Xh8P0904/i8`1=>bD0CS`V
04lj9@1@>bH0DCdU05<o9P1E@BH0ET<U0080F4DU00<0FDHX05Q59`1F@bD00`1E@R@205I39@<0ETD[
0P1GAR`305Q7;@0805e8:@1LAbP0FDHX05E4:01B@BL0CclV04dn9`1<?BH304`l9@80CCdV0`1>?RL0
0`1GA2@0F4DU05U69P0305]8:080FTLW01@0GT/Z05e::@1LBBT0FdPZ05Y6:`1HA2/0Ed<Z05M3:`1B
@2`0CcXU04`h801B?B80HT//07AL>P22J4D0RFm:05=2<01@?bd0C3/Y04Pg9@80ASDS00<0AcHT04Pg
9@15>2D00P16>BH01P13=R<0?c8O040c8015>2D0Bch[04Tf9`80BCHU00l0BSPT04`j901??BD0Dd8X
05A3:@1A@bH0CChW04Dh:00o<RT0?38X03`e8`0o>Al0@ChM04Pl8P1=?bD00P1A@BP0501C?bL0E40X
05Y4;@1QB380GdDZ05i6;01KAb`0F4L]05A6;01?AB`0BD<[04Q2:P17@Rl0Ad0^04M0;@17?bX0BSlY
04a0:01?@2T0D48X0P1D@bT205E4:P80ETD[0P1GAR`205e;<`0705a;<@1JBBl0FDP/05]:;01NCRd0
HE4_06AD<P0205a=<080Fd`_01@0G4`b05i>=01ODCH0H58g06i@=01aEC00MEX[07]R:@22JR`0RG4e
08mf@02BN4L0TGQ009MnAP2NQ4/0Wh9809eo@`2OOd80YhM:0;2>C`80/I5D00@0[hmB0:j>D@2]SE00
[8a?0P2[Rdh05P2bTD`0/i9?0;FDD@2gUED0^9IG0;RFF@2gU5X0]Y=I0;:DEP2aTeD0/Hm@0;:<C@2c
RTX0]XU80;R8AP2jRDL0^I590;ZBBP2kTd/0_9A<0;fEC@2oUdl20<2HD0080;VGC`2kVE40_YaE0<2M
F@30WE/0_iaL0;bIF@2kUeT20;nHE@040;jGE02mUU<0_9EB0;^DD@80^Y=@00P0^IEI0;RDF02fU5L0
/I5D0:j@DP2[Se00Yhi>0:J=C@80Y8E?00h0Y8=>0:J2CP2TP4`0Y7m;0:EmBP2TO4T0Xh540:J4A`2X
QTT0YXA70:>1A02RP4<0YH=60:R6B@<0ZHA=00H0Z8=<0:J1BP2TOdP0XWe60:1kA02`Od@20:j0A003
0:j2A@2/PdD0Zh=50080ZXA51P2^Qd@20:f6@`0H0;28BP2[PdD0ZH530:f5A`2cRdd0]He?0:n7B@2Y
PD<0[8960:Z1@`2XOd40Yghn0:Qo?@2[Pch0[XI00;28@P2iSD@0^8a30;N;@P2iSD@0_9170;Z>A@2e
RD00[h<j0`2XP4850:Mo@@090:R0@P2XPST0Yh4h0:J0>@2SO3L0XGXg09mh=`2MMSD0W7@f0080V7Hg
0P2IMcP0102JN3T0VgTj09aj>`2LNS/209Yh>@0409Ug>02HMSL0UgDf09Me=P80UW@e0100U70f09=_
=@2AKSH0SF`f08Y[=027JC<0QVPd08=X<`26JC40QFP`08=V;P22IBd0Q6L_08Q[<`2<KcL0Sg8j0P2>
LS404P2BMSD0Vgln0:>7AP2QQD@0Ug/j08ea<02>M3L0T7Hi099h?@2ENd80V7i509UnA`2IOTT0VWm:
0:>9D02RR4l0X8I=09j4B`80WH=:0P2NQ4/809aoA`0909Z0A`2HOTD0UWa309Ek@P2DNT40UG]209Il
@`2GOD@0UGY300<0U7U20P2CN442099g@080SG@l00@0S7<k08Ya>@29L3P0Qfhf0P26KCD0:026KS80
QFda08A[<P23JS80PfXd08AZ=`25JcP0QV`k08]]>@2@LSh0V7Y80:>4E@2/SEl0]9EY0;ZKK`2lW7<0
]Im`0;6KK02_V6`0/iab0;^TN`34[8H0b;2:0<ZbSP3?]Z00dk^S0=NmXP3H_Yd0dkNB0<R[P@2lWFl0
]9EV0:68DP2GOTP0RW0m085W=P1nHc@0OF8e07aQ=01kH3D207=H;@80M5T^00H0LUL/071E:P1]DRL0
K54V06M?:@1TCRL2065;9P0C05]7901GA2<0Dd<R05938P1B@b@0DD4P05118P1>?b80BS`R04@h8P0n
<b40=bhM03@[700Z:a/0:BXJ02TZ700X:1`09bLM02HV7P0202DT7`808b<K00H092@L02DU7@0U9Ad0
92@L02<S6`0R8QX802<S6`809BDM00<092@L02<S6`0R8QX00P0Q8AT0100P81P08B4I024Q6@0Q8AT2
020P60<07alG200O7QT801hM60<07ahI0P0P7aX;024P6`08024Q6@0P81P0820H020P600Q8AT08b<K
02@T700U9Ad302@P5`809B4H0`0V8QT202@T6P0602DU6`0V9Q`09RHL02HV700U9A/092@J0P0[:1T0
100^:1X0<2PK038X700d:1`203HX7@80=BTM0`0f:Qh303L[7`80>B`K0P0j;A`303/^7@0303`_7P10
;ad0@C0N0080@C0N0P12<Al204<b8080ACLM00H0ASHM04Pf7P19=al0CSXR058l9@1D?RL305Pj7P<0
FC/O0`1J?2002@1M@280G3lQ05/m8@1J?280FS`T05/l9`1L?BP0G3dY05Lm9P0205Hl9@0305Dk901D
>R<0DcTR0080DSPQ00<0Dc/O05@l801E?B400`1E?B400`1D?200Dc/O05@l900205<k8`03058j8P1C
>b<0E3`T0080EShV201E>b@0201G>B40F3XR05Tk8@1K?B40GD0R05m28P1P@b<0HD@R0P1VA2P0101W
ARL0J4LV06U89`1ZBBH206];9@80K4`U00l0KThW06m?:01aDBX0Le</07AD;@1eEBh0Ne<_07UA;@1e
CbX0LDhX06m=9`1_CbP0L50Y06mB:P1`D2T00`1_CbP206i>9`80KDdV0`1/BbP506]:9`0406];901/
C2D0K4`U06a<9@80KDdV0P1^CRL2075>:006079?:@1dDB/0ME8/07IC;@1gE2h0N5D_0P1hEB/02@1i
ER`0NeP^07aI;`1mFS00OU/a07mL<P21G2l0PUd`08AO<P0308IQ=0@0Q5lb00@0Peha089M<022GC00
PE`_0P20Fbh02021G2l0P5/^07mJ;@1oFRd0P5/^089M<024Gc80QF0c2023Gbl308US=0<0RV@e0`2;
ICH808eS<@P0TfTg0P2@Jc@01P2@JcH0TF`h095[>P2AJc`0TV`m099/?`80TVdi00@0Tfhj09A_>`2E
L3`0UW4m0P2GLSh209Ea@@<0UW9200<0UG5109=_?`2BKSh0202DL3`0102HLT<0Ug5209Ma@P2GLD82
09I`@@80UFm00P2BKSh209=_?`80U7100P2ELD4809E_@P05099^?P2DL400Ug=309YfAP2KMdL00P2L
N4P02@2KMdL0VWM?09]hCP2LNDl0W7Y=09]iB`2IMdL0UgI309Ie@P0209Uh@`<0V7M20`2GMT401P2J
MTH0VgM709ahB02MNDT0WWY:0:1lC0<0XGe=00<0X7a<09ijBP2LN4P00`2KMdL0102LN4P0VgM309Yf
@P2HM40209Mc?`0309Qd@02JMT80VgM30080VWE00P2KMT4309ag@P0309eh@`2LND<0WGY40080WGY4
0P2NNdD209mlAP80W7e600H0WGa609mlAP2NNdD0WWU409if@P2MMD4909]g@`0609mkA`2PO4P0X7a8
0:5mB@2ROTX0Xgm;0P2TP4`01`2TP500YH5A0:N3D`2ZQUH0[HUI0;2<G02cSel00P2dT6000`2eTF40
]i=S0;RDI0020;RDI080]i=S0P2iUFD30;RDI0<0]i=S0P2hU6@20;NCH`80]Y9R0P2eTF400`2cSe/0
/XiJ0;2<F0020:n;E`030;2<F02bSUX0/hmK00<0/HaO0P2bSF030;>>H@80]HmP00L0]I5Q0;>AH@2c
Tf80/iES0;BFI02bUV@0]YYZ0080^9UZ00<0^9QY0;VGJ@2kUVT00P2kUFP30;VGJ@<0^YQZ0P2kVF/8
0;bHJ0060;ZII02iV6<0^IQS0;RGHP2gUV40]YEP0P2eU5l30;JBGP80]I5M0`2dT5`0102eTEd0]91L
0;B@G02dT5`30;>?F`060;:>FP2eT5`0]I1L0;B?F`2cSUX0/XeI0P2aS5P00`2`ReL0[XYF0:j:EP02
0:f9E@040:b8E02[Qe<0ZXIB0:Z6DP80ZHYC00H0ZHQB0:Z7D@2YQU00ZHA?0:^3C`2ZPTh80:J3B`T0
YX5<0P2SOTT01P2TOdX0YH1;0:AoBP2RODP0X7]609iiA080XGa80P2RODT30:=nBP040:AoB`2VPTh0
YX9>0:J2CP80Yh=?0`2XQ5001P2WPdl0Z8A@0:R4D02YQE40ZXIB0:^7D`80[8QD00@0Z8A@0:V5D@2Y
QE40ZHEA0`2ZQU801@2[Qe<0Yh9>0:R3C`2ZQE40ZhIB00<0[8MC00<0ZhIB0:V5D@2YQE401P2YQE40
1P2YQ4d0Z8=<0:R3C02WPT/0YX5:0:F0B@80Y7m80P2RODP00`2QO4L0X7]609mjA@0209iiA00409eh
@`2QN480XGQ20:5h@R_ooooo000Zooooo`X0Y7U60`2UNTL30:IkB0P0XWQ600<0YW]80:MlB@2ZOd`0
0P2/PDh00`2[P4d0ZWm<0:QmBP020:QoB`<0ZH1<1`2ZPDd40:^2CP030;68E02_QU80[HA@0080Zh9>
00<0[8=?0:f4D02^QE40102[PDl40:Z0CP050:R3C`2WPTh0Yh9>0:J1C@2TOd/00P2SOTX01@2RODT0
Y7m;0:=nBP2SOTX0XGa80080X7]700/0WWU509ehA02LMd<0Ug5009I`?`2FL440UFm209A]@P2CK4<0
TV]2099[A00208iZ>00608m[>`2?JSd0SFPl08]V?029I3X0Qf4j0P26Hc/00`25HSX0Q64i08=P>002
089O=`07085N=P21GSP0Oe`f07eJ=01jEc40NEH`07QE;`0207UF<0<0MED^0`1dE2d207=C;080M5<b
00<0M5<`07EE;`1eEBh00P1fERd01`1fEb/0PE`b089M<`23GS@0Q5le08EP=P27HSP00P28HcT0202;
ISX0S6Lk08eX>`2?Jc/0TFdk09=_>`2DL3`0UG8l0`2HKS`209U_?@<0VW0n0P2HLcl209Mb?P0509Ia
?@2EL3`0UG0l09E`?02GLD800P2FL4400`2EKd00U6ho09=]?P02099/?@P0Tfdn00D0TF/l091Z>`2?
JCX0SVPi08eW>00308aV=`<0S6Pf0`2;IcD208YV=080R6<f0`29I3L308YU>0<0SFLh102>J3T00`2?
JCX0RV@e08YT=@0208YT=@H0RfDf0P2:I3D208US=080R68c0P2;IST208YU>0<0RF@g0P28HcH308aV
=`80RfDf2`2:I3D208]U=P80RV@e0P29Hc@208QR<`0308IR<P27Hc<0R6@d0080R6@d00<0QV8b08AP
<023Gbl00P20Fbh01021G2l0PUd`08AO<P25H3<208IQ=00308EP<`26HC@0QV4d0080QV4d1@27HSD2
08IQ=00408MR=@28HcH0RVDh08]V>@T0S6Ph102=JCT408iZ>P0308m[>`2AKCd0TVhn0080Tflo00<0
TVhn095]?@2>L3h01`2>L3h208]/?@0408UZ>`27J3T0QVLh08AU=P80PV<d01P0OV8b07UN;`1dFBX0
LET[075J;P1_FRl0JEH/06EB:01RBbT0H4TW05Y79`1D@bL0CClT04Hl8`11>B@0?SPR02d^700/;A/0
:b`L02X[7@0X:1`09bLM02HV700V9Qh202HW7`0302DV7P0T9Ad08b@L00808R<K00<08B8J020S6P0P
8aX01P0P8aX3024T6`03028U700S9Qd092LN00809BPO2@0Q91d0100U9Qh09RLO02HW7`0V9al202LX
8080:2TQ01`0:R/U02/[8`0[:b40;R`O034^7@0f<Ad0>S@N03`f7P0n<aL0@CHJ04Li701<?Ah0D40N
05=37`1FA1h0Ed<N05E28P1??R00ASPM03`b6@0d;QP0;b`I02//700Z;1h0<RTH03@[6P0f;A`0>2lN
0`0i<1l00`0h;ah0<R`N038/7P02038/7P80<B/M00P0<2XL02lY6`0`:Qh0;RXN02dY7@0[:A`0:2TK
02HX6P8092PI0`0U9A/302HV70809bLM0P0U9Qh0100T9Ad08b@L028S6`0Q8QX2020Q6@80724J01h0
7B0I01dN600N7aT08B0K02DR7@0V8ah0<B@N03X/7`15=ad0CCdK058n6@1E?A/0ES/N05Tk8`1M?1T0
KDdW089R>`2ALTH0U7I409Eg@@2KOTH0Y8M=0;NBF`2JNd`0K5Xd04Ho9@0d<R<0;RhV02dX900Y8Ah3
02LZ8`0502HY8P0U:24092LP02<V7`0R9Ah00`0S9B8302@V8`809BLT0P0U9R406@0U9R009BHN02LY
7P0Z;1l0;BlR02h`8P0`<B<0;blS02h^8P0];B<0:b/S02TX8`0W9R809RDQ02LX8`0W9R809bHQ02XW
800]:B00<BXP03D/8`0g;b@0>C8P03Xc8@0l=B<00P0n=bD01@0m=R@0?3DS03/d8P0k=280?3DU00<0
?CHV0P0l=BD03@0m=RH0?SLW040e7`13=b40Ac/S04do9@1A@BL0E4<W05M3:01HABL0CS`V04dk9@1<
>R@00P1;>B<00`1<>R@0CC/U04hl9P0204hl9P0604lm9@1A@2H0Dd8V05A39@1EAB@0ETHU0P1GA2H6
05I39@<0ED@Z0P1FAB/305M6;00805a7:01KARL0FDHX05A39`1B@BL0CclV04`m9P1;?2D804dm9P@0
EdHX0P1FABL01@1EA2H0E4<U05M6:01GARP0ETDY0080ED@X00l0E4<Y05=2:01C@RP0DD4Z04dk9@19
=al0CCTP05Q39P1TCBh0KE@e071G>01>?B/0C3/Y04Xi9`17=R@00P16=B<204Pg9@0404Lj:@18>bX0
AcXY04<f9@80?S4P00<0@cHU04Pk:P16=BD00P16=B<09@18=b<0Bc/T04hn9@1B@RP0E4@Z05539P1=
?RL0ACPX040b:@0n<2L0?S8R044g7P14>a`0Bc/Q04lo9@1C@bT0E4<Y05=2:01F@RT0FTH]05i:<@1H
A2T0F4@[05E4:P1BA2X0CT8Z04]0:P18@2/0AT0Z04M0;@18@2d0B40[04Xo:@1<@2P0Cd4W0551:01B
@RP00P1C@bT205A4:P80EDD[0P1FAR`205Y:<@0705U9;`1HB2h0F4T/05U::`1KC2/0GU0]061B;`02
05E7;00I05I7:P1GB2/0FdX/05i=;`1SD300IE8b071E=`1cFS80N64_07iX;P24Kc00RW@j08ef@P2?
MdT0SgQ209AmA`2KPTX0WH=:09j1A`2PPTH0YXQ:0:f=D02]SUL0[8eD0:^<D`020:Z<D0060:^=C`2/
SU00[HmA0:j@D02`TU80/I=C0P2dU5L04@2eTeH0]95G0;B@EP2`TE40/Hm@0;6>CP2bS4/0]8e:0;R=
B@2kST/0_I1<0;^ECP2lUTl0_IM@0;jHD@2oVE80`9YC0080`I]D00P0]iI?0;ZIDP2nWEP0`J1M0<6O
G`2oWEd0^iUJ0;RFE`80_YQG00<0_IMF0;bFE@2kUE@00P2jU5<02P2iTe80]IEL0;:CFP2`TEP0[HiE
0:Z;DP2VRDl0Y8M=0:>6C02RP5020:B0D00=0:EoD02VODl0YGY=0:AhB`2SMdX0Y7i00:R2A02[QDL0
ZXA60:N1@`2UOd40YX120:V3A@030:R0A@@0ZH5600T0Z8150;>3A@2`PT@0[X120:b0@@2[PT80[8E4
0:j8A`2_RDP00P2_R4D20:j7A00?0:f6@`2/QD80[8E20:b5@P2/Q4H0ZH530:R0@P2/Q4H0/XY<0;B<
CP2`R4X0Zh=50:j6B02]QDL0[8A60080ZhA300/0[HI50;29AP2aRTL0^8e80;F:A@2cR4<0]8U40;J;
AP2eRTD0[h@o0:Yo>P030:N1@P80YX1100`0Yh520:R2@`2ZQ4D0ZhE60:R5=02YQSD0ZHDg0:V5>@2V
PSP0XWdf09mj<`2LMc4209Ug>080VWPi00<0VgTj09aj>`2LNS/00P2LNS/209]i>P0309Yh>@2IMcP0
V7Hg0080UgDf00X0Ug<g09Ib=P2DLCL0T70g08e^=`2:KCD0RF/e08I[=P25J300PfH^0P22IBd06@25
J300RF`d08e`>02@Lc/0TGDd08ib<@2@M3<0VWhm0:J:B@2XS4/0WH50095e=02?MCP0TGLj09=i?P2E
Nd80V7i509YoB02KP4/0W85<0:>9D02RR4l0XHM>0:26C@2OQD`00`2NQ4/309f0B0@0W7m700T0Vgi6
09Z0A`2HOTD0UWa309Ek@P2DNT40UG]209Il@`2GOD@00P2ENT<309Ai@P<0TgQ10300SWDm08ed?02<
Lc/0Rg8j08U`>028KcL0Qfhf08I]=@27Kc<0QVhb08A[<P23JS80PfXd08AZ=`26K3T0Qfdl08]]>@2@
LSh0VG]90:>4E@2]SV00]IIZ0;^LL02mWG@0^:9c0;BNK`2`VFd0/Y]a0;ZSNP31ZH<0aZj80<N_R`3<
]Yl0d[ZR0=NoX`3I`:40eK^H0<jbR`34Ygd0_9mc0:ZAF@2OQTh0TGQ208I/>@21IcH0Of@e07aQ<P1j
Gc8207EJ;`0807IK<01eFRl0M5T^075F:`1_E2T0KE8W06]B:P1WD2L206A<9P0305m9901JAR<0F4DT
0080EDDT0140ED8Q05=38P1A@2@0CCdS04Pi8P11=240>c0N03T]7@0];1X0;B/L02`Z6`0[:A`0:RPL
02TV7@0Y9Ql0:2DN02DU6`0302HV70809BDK0P0T91X202DU6`@092@J0P0S8aT202DU7@0402@T700S
8a/08b<K028R6P808B4I0P0R8QX2024Q6@80820H0P0O7aLB01lN6@8081lJ0P0Q81/2028Q70`08R8J
00@08b<K02@T700T91`09BDM0`0U8AP302HR6@809b<J1@0X9A`00`0W91/09R<J02HS6P0202`Y6P04
02lY6`0`:1/0<RPL03@X7080=RPM0P0e:Ad303HZ7P<0=b/O0`0j;A`303/^7@80?2lN00@0@C0L048a
7@12<Ad0@S4M0P13<Qh204@c7`0804Hh7P17=ah0AcDM04Pf7P1;=al0CcTR05<j901E?2H205Pj7P@0
FC/O0`1J?2001@1N@B40GD0P05e08P1L?R80G3hT0080G3hV00H0G3dX05Pn9@1H?RD0EcdT05Hl8`1E
>b8205@j8@0405<i801E>b00ES`Q05To9080Fd4V00<0FClT05Hl8@1E>b00101F?2<205Lm9080F3hU
0`1F?2<405Dk8P0905@j8@1I>b<0FC/S05Xl8P1L?R80GT4S05m28P1P@b<0HD@R0080ID<W00@0ITDV
06M69@1YB2L0JTTV0P1[BbD0401]C2<0KTdT071?9P1aD2L0Le8Y07ED:`1fEB`0MeH]07aE;P1jDb`0
MU0Y075>9P1`CbH0L50W079B:@1bEB/2075A:P<0L50Y0`1_CbP206]:9`<0K4/X0`1]C2T0101/C2D0
KDdV06e=9P1]CBH206i>9`80KdlX0P1aCRP01P1bCbT0Le0Z07AA:`1eDR`0MU<]07MD;P80N5D[00`0
NEH/07]H;P1lFBl0OEX`07iK<@1oG380PE`_089M<024Gc80QV4d08MR=@26HC@508EP<`0308AO<P23
GS40Peha0080PUd`00P0P5/^07mJ;@1oFRd0OeX]081K;P22GC00QF0c08IQ=0P0Q60`00@0R68c08US
=029Hc@0RF<d0`2:I3D208]U=PP0SV@b202DJSP0202AK3D0TVdf099]>02BKCT0Tfdl09=]?P2DKSl0
U6i10P2DKc/00`2EL3`0UW4m09Mb?P0209Qc?`0309Ud@02GLd<0Ug=300<0Ug=300<0UW9209Ea@@2E
LD40102FLSh409Ea?@80VG=20`2HLT4309Ma@080U7100P2ELD4409Ib@P@0Ug52102FL4401@2BKSh0
U71009Mc@`2JMTH0WGU900<0WWY:00P0WGY@09ekCP2NO4l0WWa>09ajBP2JNDH0UgI109Ie@080VgY5
0P2JND@309Uh@`0709Qg@P2KMdL0VgM709ahB02NNTX0Wg];0:5mC@020:9nCP80XGe=00@0Wg];09ij
BP2MNDT0WGU90P2LN4P00`2LN4@0VgM309Yf@P0209Ue@@0309Yf@P2KMd<0W7Q400<0W7M20`2MN4<2
09iiA00409ejA02NNdD0WW]509ikA@80Wga60P2PODL0202LODH0WGi70:1oB@2SP4X0XWm90:1kAP2O
Md<0WGE10`2LN4@509eiA@0709ijAP2SOd/0Y81<0:B0C02UPDd0YX9>0:N3C`020:R4D0070:F1D@2W
Pe<0ZHEE0:b8F02`S5`0/hmO0;FAH@020;NCH`030;RDI02iUFD0^IEU00@0^YIV0P2kUfL20;ZFIP<0
^IEU00<0^9AT0;VEI@2iUFD00P2iUFD20;RDI080]i=S00<0]I5M0;B@G02bSUX00P2aSET00`2bSUX0
]91L0;FAG@020;>>H@80]8mR102eT6<20;NAHP0<0;JBHP2eTf<0]IET0;BFI02eUfD0/iMU0;VMK@2k
W6d0^Y]/0;^KK02kVF/0_9MZ0P2lUVT30;VGJ@<0^YQZ0P2kVF/80;bHJ0060;ZII02iV6<0^IQS0;RG
HP2gUV40]YEP0P2eU5l30;JBGP<0]I5M2P2dT5`20;F@G0030;B?F`2cSUX0/XeI0080/HaH00L0/8]G
0:n;E`2_ReL0[XYF0:f9E@2/R5@0ZhMC0080ZXIB0P2YRU<0102YR580ZXMA0:Z7D@2ZQE020:^3C`P0
Yh9;2@2VPD`20:F0B`80YX5<00@0Y7m:0:9mB02PNdH0WWU4102QO4P20:9mB@80Xgi:102WQ4h40:R5
C`060:V5D@2ZQU80ZXIB0:^7D`2/R5@0[HUE0P2^RUH80:Z6DP060:N2CP2XPdl0ZHA@0:^6DP2/Qe<0
[HQD0P2^RED80:V5D@80ZHA?0P2XPdh0102WPTd0YX5<0:F0B`2UP4/20:AoBP040:=nB@2QO4L0X7]6
09mjA@80WWU40`2RND<[ooooo`00:_ooool:0:AiAP<0YGY70`2VNdP80:=iA`030:EjA`2WO4T0ZWm<
0080[H9?00<0[85>0:UnB`2WO4T00P2XOd/30:V0C0<0ZX5=0P2YP4`20:Z1C@80Zh9>0P2/Pdl01@2`
Qe<0[hIB0:j5D@2]Q500[8=?0080[HA@00<0[XEA0:b2D02/PU000P2[PDl20:Z0CP80ZGm=0P2WPTh0
102VPDd0YH1<0:F0C02TOd/20:=nBP040:EoCP2TOTd0Xge<0:5kBP80X7Y901@0WgU809ihA`2NN4L0
V79109Ma@02GLD80UW1309E^@`2DKD@0Tfa309=/A@2>JSP0Sf/i08m[>`2?JSd0SFPl08]V?028HcT0
QV0i08MT?080QV<k00<0QF8j08AQ>@23H3P00P22GcL01P21GSP0Oe`f07eJ=01jEc40NEH`07QE;`80
NEH`0`1eEBh307AD;@80Le</0P1dDc000`1eEBl0MUH_07IF;@0207MH;00A07QI:`21G380PE`b089M
<`24GcD0QV4g08MR>028HcT0RF@j08]V>P2<Ic/0SFPk08m[>`2AKC/0Tflk09A`?02ELS`00`2HKS`2
09U_?@<0VW0n00<0Ug8n09Ia?@2FLCd00P2FLCd309E`?080UW1100<0UFm009A^?`2CKCh00P2BK3d0
0`2AJc`0TV`m099/?@02099/?@@0Tfdn0`2AJc`01@2@JS/0SfTj08iX>@2=IcP0S6Hg0080S6Ph0`2;
IcL308YV=P80R6<f0`29I3L308YU>080S6Hg0P2=IcP0102>J3T0SfTj08mY>P2?JCX808eT=P80RfDf
0P2:I3D208US=080R68c0`2;IST208YU>0@0RF@g0P2<ISL208]U=P80RV@e2P29Hc@208eT=P80S6<e
0P2;HS@208YQ<`0808EQ<@26HS80Qf<c08QT=027Hc<0QV8b08AP<023Gbl2081K;P04085L;`22GC00
Q5lb08EP<`80QV4d0P24Gc8208EP<`0<08IQ=027HSD0Qf8e08MR=@28HcH0Qf8e08IQ=025H3<0Qf8e
08UT=`2<IcX0SFPk202<J3P208aX=P80SFTg00L0SVXh08m[>@2?JcT0Sf/i08m[>`2@K3`0TVhn00<0
Tflo0P2AKCd808i`?P80Rf`m00@0RFXk08MX>@26IcP0Q6Df0P22Hc@0401mHC40N5d^07AI:P1bFR`0
LU/_071K<01YER`0IE8X069;:@1PBBL0FTLW05=29P1<?R<0A3XQ03lg8P0l=R0202`]6`0702//700Y
:Q`0:2PL02LW7@0V9Q`09BDM02HW7`0202DV7P0302@U7@0S91`08R<K00808B8J2P0P8aX00`0Q91/0
8RDL02<V7@0302@W7PT08B@M00@09BHN02HW7`0V9al09RLO0P0W:20202PY8@0=02X[9@0[:b<0:b/Q
02h/7`0`;A`0=C0L03Tc7@0k=Ad0>c4F03dd5`11=QX0AcTL04Xk7P0204`k7@0?04hk7@1;?B80ACTO
03hd6`0g;aP0<B`H02h[600];1X0;2dM03<Z6@0d:aX0=RdL03P_7P0i<1l0>2lN0080=bhM0P0b;1h0
0`0a:ad0<2XL030Z7003030Z700602lY7@0]:Ad0;2PL02XX6`0X:A/09RPJ0P0T:1T302DU6`<09RHL
0P0W9ad202@U7@0402<T700R8a/08R<K024R6P80824I02D0724J01/P6@0M81T07QlI01lP6P0R8A`0
9R<N02PU800f:1d0@34N04/l7`1C@Ad0EClH05Dk6P1H>R00Fc/V06A2701hEbh0SFa109IfA`2FMTD0
VGY40:62B`2YRU<0/HaG08]^@P1JBB/0>S<S02d]9@0Z:bD0:RLP02PT6`0X:b@09bXS02HY8P0U:240
92LP00<08bHO0`0S9B8302@V8`809BLT00h09RLR02DV8@0U9R009RLO02PZ7`0[;B00;S0S030b900_
<280;RhR02d]8@0[:b40:BTQ02LV8@809RDQ00/09bPS02LV8P0W9R40:RLP02dY800b:b40=RdT03P`
9@0k<R40?3<R03he9002040g9P0403lf9@0n=B@0?C@S03dd8`80?cHU0140?SDT03lf9@10=bH0@3LV
03lf9@0n=B@0@3DO04@h8P18?2@0CT0V0592:01EA2P0F4@Y05Q59`1??BL0CS`V04`j900204/i8`09
04`j901>?2H0CcdW04hl9P1??BL0D3hV05509P1B@BD0E4<U0080EDDT00<0ED8T05I39@1F@bD00`1G
A2H205I39@<0E4<Y0P1EA2X305I5:`0805a7:01KARL0F4DW05A39`1B@BL0CShU04`m9P1;?2D804dm
9P80F4L[00@0ETDY05E4:01D@bL0Dd8V0P1B@BD205=1:@80Dd8X00`0DT4W05919@1B@BD0DT4U0553
:@1>?RD0CC/S04ln901E@BP0F4<X05Q09P1E?B4204Lf900?04He8`17=R@0B3LU04Th9P1;>RP0CC`Z
04Lj:@18>bX0AcXY048e900n<B00?C0O048e9017>RT0A3@T0080A3DR01/0ASLR04Tj8`1<?R@0D48W
0594:@1>@bD0BclW04Dh:012<BT0@2lW048b8`15=Ql0BCXM050l8@1D@2D0F4@Y05I5:@1D@bL0Dd@W
05I7:P1JBbh0DT@Y0553:@1@@RP0C40X04Xo:@19?RX00P16?R/02016?RT0BChZ04Xo:@1=@BT0D48X
0592:01C@RP0Dd8V0P1BA2T205=5:P80E4H[0P1EAb`205M9;`80ETP]03D0ETP[05M::P1HBbT0FTdZ
05]>:`1@A2X0DT@Y05A4:P1GARP0G4TY065=;01WD2h0JU8^075I=@1eGS@0NfHa085]<027LcH0RWDl
08afA@2<MD/0S7M2091kAP2FOdT0VX5909b2B@2PPdT0Y8M;0:V;C`2XRUH0YhUE0:J8DP2UR500YXU=
0:V=CP2[Sdh0[I5@0:ZBEP2[TeD0[I=F0;2CE`2bTUL0/Y1C0;:>DP2`S500/8e=0:n<C02aRdX0/Xe9
0;F>B@2jTT`0_IE?0;jFCP020;jID`040;nJE030VeD0`IaF0<6LEP80`YeG00P0^9MB0;^JE@2oWU/0
`J1M0<6OG`2nW5d0^IMJ0;JDE`80^YMG00<0^IIF0;REE@2gU5@00P2fTe<0:P2eTU80[Y=L0:bAFP2Z
SeP0ZH]E0:F7D@2RQ4h0X85;09n0BP2RO4/0YGe<0:InC@2XOTh0Z7a=0:QiB`2WMdT0YWI80:Im?`2Z
PD<0[XE70:f4AP2YP480Ygi00:V0@P2[PT@0Yg/n0:Ql?`2YOD00[8130:j2A@2aQDP0/hM:0;B8B`2h
R4P0]8M60;64@`2_Pd80[HA20:j7A02`RdL0/Xe90;29AP80[hQ500<0[HI30:b5@P2[Q4400P2ZPd00
202WOd40YWi00:In@02ZPT@0[XI80:n7B@2]QDL0ZX940P2^R4L02P2]QdH0[8I70:f7B02^R4T0[hU;
0;2:C02`QdD0[XE30:b3@@2^QD<20;:9A`030:n6A02[PT00YhA40080YX=300h0YH920:B1@@2UPT80
Z8E50:Z7A`2/RDT0Z8Lf0:V8=`2[RS/0ZXTl0:R6?02TPSX0Wgde09aj<`<0VgTj102LNS/309ek?003
09aj>`2KNCX0VWPi0080VGLh00/0V7Hg09Ue=`2HM3H0UW@g099b=`2?L3L0S6lg08]^=P28KCH0QFP`
08=V;P02089U;@0508EX<029K3@0SG0h091c>`2CMcH00P2?Lc801@2JOSd0Yh]:0:^?CP2SQdH0VGdl
0080TWPk00H0U7Xo09Ek@P2HOTD0VWm809b1C02MPTd30:>9D0050::8C`2QQdh0X8I=09n5C02NQ4/0
0P2NPDT209f0B00<09aoA`2KOTH0Vgi609]nAP2JP4L0V7i509Il@`2ENd80U7Y109Ek@P2FO4<0Uge4
0`2ENT<309Ai@P80TgQ10P2>MCd0102=M3`0Rg8j08Ya>@28KcL208M^=P0X08M_<`26KS80QF`c08A[
<`24JcD0QF/h08I/>@27KC`0Rfdi091b?P2INdT0XhAE0:f>H02fUf/0_9ea0;nOMP2lYWL0]Z1a0;6J
KP2aVW00^:5h0;nWP@33ZhD0a:b80<ZfW@3?^Yl0e;nR0=W2X`3H`9h0d[RE0<b`R@36ZX<0]9YQ0:R>
E@2HODH0Rg0k08AX=P20I3@0O60`07QL;@80Me`a00P0N5db07ML<@1fFc00LeP]075F:`1_E2T0Ke<[
06]B:@80IdhV00h0Hd/U05m9901KAb@0FTLV05U69@1IAB@0Ed@S05A39@1A@2@0Bc/R04Df8@0o<R40
?2lN030]6P80;b`K00<0;R/L02dY7@0/:1d00P0[9ah00`0Y:Ad0:2PL02LW6`0202HV6P<09BDI00<0
9bLK02HV6P0V9QX00P0U9AT202@T600702<S5`0V9Qh09RHN02DU7@0T91`08b<K028R6P02024Q6@<0
8R8J0P0Q8AT3020P61<081lJ0P0Q81/3028Q70P08R8H00<08R8J02<S6`0S8a/01@0T91`402HR6@80
9b<J0P0X91/202XV7@80:BDL100X91/202dZ6`04030Z700a:A`0<RPL03@X7080=RPM0P0e:Ad303HZ
7P<0=b/O0P0j;A`303/^7@<0?2lN0P12<Q/204<c70<0A3@M00T0ACDN04Ph7`18=Qh0B3HN04Xf7P1<
=Ql0D3LQ05@i901E>RD00`1I>al405Xl8080FcdQ0P1O@R001`1O@R80Gd8T05i0901M?bD0G3hT05`n
9P1J@2D00P1I?b@00`1H?R<0EcdR05Hl8@0205Dk800305Ll8@1I?R<0Fd0U0080GD8W00@0Fd0U05Tn
8`1G?240F3dR0P1I?R<205Xo9080Fd0U00D0FSlT05Pn8`1H?R<0F3hS05Lm8P0205Hl8@80EC/P00D0
FS`T05/m9@1L?R@0GClS05i18`0206138`0I06548P1S@BD0I48V06E49@1WARD0J4LV06Y99P1[BbD0
K4`V06m<8P1`CB<0LDhT07=@9P1eDRP0Me@Z07QE:`1iER`0O5D/07YC:P1gDRP0Le0V079A9P1bDbL0
M5DY07=F:P03079B:`<0LE4Z0P1`D2T206a;:0<0KD`Y0`1^CBX206e=9P80KThW0`1_CbP01@1`D2T0
Kd`V06m<9P1`CBL0LDhX0080LTlY0P1cD2X207QE:`0:07UF;01kF2h0O5T_07eJ<01nFc40Oe`b081K
;P22GC00Q5lb08IQ=0<0Qf8e00<0QV4d08MR=@26HC@00`26HC@308EP<`08085L;`20Fbh0OeX]081K
;P21G2l0Peha08IQ=027HSD808EQ<@<0QV0a0`27HC8308QR<`P0T6Hd202DJSP209=^=`0309A_>P2D
Kc/0UFln0080UFm000H0UW1309Ia?@2FLCd0Ug8n09Qc?`2IM40209Ye@@0409]f@P2JMTH0VWI609Ue
A@D0V7A400<0VGE109Qd@02HM4000P2GLcl209Ib?P0409Ea?@2JMD40VWE109Ye@@<0VGA00P2HLcl2
09Ib@P<0Ug=30`2HM4@00`2JM4<0VG=209Uc@P0209Qb@@80Ug5000H0UW0o09=_?`2ELD40V7A409]g
A`2MNDT309mkB`0909ilC`2OODl0Wge?09mmC@2NODX0VgY509Uh@P2GMT00WGa700<0W7]60P2KNTD2
09YiA080W7Q800@0WGU909mkB`2PO4`0XWi>0P2SOdl20:9nCP80XGe=00L0X7a<09mkB`2MNDT0WGU9
09ijAP2MNDD0VgM30080VWI200<0VgM309eiA@2NNTH00P2MN4<309iiA0<0WgY50P2NNdD209mlAP<0
X7e700T0XGi809ioB02OP4T0XX5;0:F2C02TPD/0XWe80:5iA@2OMd<00`2ONdL20:1lB080XGe90P2R
OTX20:R4D080ZHEA00`0ZXIB0:^7D`2/R5@0[8QD0:V5E@2ZQUH0[8QH0:n;F`2bSUh0]I5Q0;NCH`2h
U6@50;ZFIP040;^GI`2lV6P0_9QX0;fIJ@<0_9QX0P2kUfL20;ZFIP<0^iMW0`2jUVH20;VEI@030;NC
G`2fTUh0]I5M0080]91L00<0]I5M0;JBGP2gTel0102fTF@20;NBI@80^9=V0P2iTf@00`2hU6@0]iEU
0;JFI@020;FGI@070;BHIP2jWVh0_9e^0;^LK@2kVf`0_9Y/0;fHJ`020;fGJP<0^IMY0`2jV6X20;^I
J`P0_9QX00H0^YUT0;VHH`2iV6<0^9MR0;NFH@2fUF020;FDG`80]i=O0`2fTUh30;FAG@@0]91L102e
TEd20;F@G0030;B?F`2cSUX0/XeI0080/HaH00@0/8]G0:n;E`2_ReL0[XYF0P2]RED00`2/R5@0ZhMC
0:^7D`020:Z;E0040:Z9D`2[R580ZXMA0:Z5D080Zh=?202ZPd`90:N2C@80YX5<0P2WPTd0102UP4/0
Xgi90:5lA`2ONTD30:5lB080XWe90`2SOTX80:R5C`80ZXIB00@0ZhMC0:b8E02]RED0[XYF0P2_ReL4
0:^7D`@0ZXIB00H0Z8=?0:V4D02YQ500ZXEA0:b7D`2]R5@20:n:EPP0ZHEA0P2ZQE00102YQ4l0Z8=>
0:N2C@2WPTd30:J1C0050:F0B`2TOdX0Xgi90:5lA`2ONTD00P2NND@30:9i@b_ooooo000Zooooo`P0
YGY70P2TNDH30:EjA`<0YW]8202TNTP00`2UNTL0YW]80:UnB`020:^0C@030:YoC02XODX0Yga90080
Z7m;0`2YP4`30:Z1C@050:QoB`2YP4`0ZH1<0:Z1C@2[PTh00P2/Pdl01@2]Q500[hIB0:j5D@2^QE40
[HA@00<0[8=?00H0[HA@0:f3D@2/PU00[89@0:^1C`2ZP4h20:UoC@040:QnC02VPDd0YX5=0:J1C@80
YH1<0`2TOd/0102UOe00Y7i?0:9lC@2PNT/509ihB@0@09Uc@P2HLT40V79309MaA02FKd@0UFi509A]
A02DKDH0Sf/i091/>P2@K3`0SfXm08eX?02:IC/0R6<i08IP>@80Qf@l00<0QV<k08ER>P24HCT00P23
H3P01`22GcL0PEhh07mL=P1mFS@0NULa07UF<01hEBl00P1iES0307EE;P<0M5@]0P1cDb`03P1cDbd0
M5@^07EE;P1fERd0N5T]07UJ;01jFbd0Ne`]081K<@21G380PUdc08AO=@26HCL0Qf8h0P29I3X0202:
J3/0RfTl08aZ?02>K3`0T6ll095`>`2CLSd0U7<m0`2HKS`209U_?@<0VW0n202EL3`01P2EKd00U6ho
09A^?`2CKCh0TV`m095[?0D0T6Xk0P2AJc`3099/?@80TF/l0P2BK3d01@2AJc`0SfTj08eW>02<ISL0
S6Lj00<0RfHi0P2:ICP208UT=`80QfDg0`28ISP308UW>@0608YT=@2;ICH0RfDf08aV=`2=IcP0SVPi
0P2?JCX0102@ICP0Sf@g08mT=`2?I3L308iS=P0308eR=@2;ICH0RfDf0080RV@e0P29Hc@208QR<`04
08aW>P2;IST0RfHi08]V>@<0RVDh0P29I3L308]U=P80RV@e2`29Hc@208iS=P80SF8e0P2<HC@208]P
<`0308EQ<@26HS80Qf<c0080Qf<c00<0QF4a08AP<022GRh00P22GC001023GS40Q5lb08AO<P25H3<2
08IQ=080Peha00<0Q5lb08EP<`26HC@00P27HSD00`28HcH0RF@g08QS=P0208IQ=00408MR=@2:ICP0
SVTl091[?PP0SFLh0P2<J3@0102=JCD0SVXf08m[=`2?JcL2091/>003091/?02AKCd0Tflo0080U710
00<0Tflo095]?@2@K3`0202=Kcd208a]?P0408Y[?028JCX0QfPi08EV=`80Pf@e01P0OF4a07QM;P1e
FR/0Le/]079K;`1`Fc00J5D[06=@9P1QBRP0GdPV05Q59@1A@2@0BS`Q048h7`0l=1l0>C<M02d^700/
;A/0:b`L02X[7@0Y:Ad09bLM02HV700V9Qh202DV7P0302@U7@0S91`08R<K00808B8J00@0824I024T
6`0Q91/08B@K0P0P8aX401lR6@03020S6P0R9A`08bHM00@092LN2@0Q91d202@U7@809BHN0P0V9al2
02LX800F02TZ900Z:R80:RXP02d[7P0`;A`0=C0L03Tc7@0k=Ad0>S<G03/d6010=Q/0@cLM04Hh7P17
=ah0ASHM04Le7@13>b@0?cLP03Tc7@0d;AX0<2/G02dZ5`80;B`J00<0<bXI03@[6P0f;A`00`0h;ah2
03H]7003038/7P0a:ad0<2XL0080;bTK00/0<2XL034[7@0a:ad0;bTM02dY7@0/:1`0:RPK02LX6P0U
9aT092PI02<W600302DU6`<09RHL0P0W9ad202@U7@0302<T700R8a/08B8J0080824I02D07b0H01`Q
6P0K81T07B0I01hO6@0O81X08b8M02LT7`0Y9R40?2`L04Lg801B@R40F4@O05Q06P1H>a/0FSXQ060m
:P1]Bah0P5ha099`@P2FM4@0V7M409mnB@2WQU40ZhYD0:9nC01kGcL0CCdV03@]9@0Z:RX09bTV02LW
7`0Z:1/0:B`U02P[900V:B8092LP00<08bHO00@092LP02<U8P0S9B808bDR0`0T9R<202DW90809bHR
00`09bHQ02PX800Z:R00;BdQ034a9@0c=2H0;c0R02d]8@0[:al0:2PN02HV7P0U91l202DT800?02HW
8P0W9R809bHQ02XW800^:R40<b`R03L^9@0i<BH0?C4Q03hb8P10=2@0@CDU048f9P11=BD0@3@T0080
?c<S00@0@cPV044f9011=R@0@SLU0P15>RP03@12=bD0?c@R048g8@15>B<0BCdU04i09P1B@RP0ED@X
05M3:01GA2H0CcdW04hl9P1=>bD00P1<>R@02@1=>bD0CS`V04lm9`1>?RL0CclX04lo9P1@@2H0DD8U
0593900205=48`0505A18`1E@R@0ET<U05M49P1HABL00P1GA2H0101F@bD0Dd8X05=2:01C@RP205A3
:@<0ED@Z00P0FdHW05Y59P1HABL0E4<W05509P1>?RD0Bc`U04Xk90<0C3`U0P1=?BH304hn9`0505M7
;@1FAR`0E4@Z0592:01A@BL00P1@@2H01P1A@BL0CchZ050o:`1@@2T0D40W05519`80DD8U01D0DD8S
0553:@1@@RP0D40W05A2:P1GABd0FDD]05Do:01@>R<0A3<Q04Dd8P16=B<0B3LU04Xi9`1<>bT0CSd[
04ln;016>BT0AcXZ04Hi:@12=BD00P0m<2000`12=BD0AcXZ048e9002048e8P0U04<g8@15>B40BCdS
04a19@1>@bL0CD@U04To9P15>2P0@c8Z04<`:@17=2H0C3LR04lk801F?R80F4<V05]8:P1JAbT0E4DV
05=49@1CARH0E4TY04i4:@1=@bX0Bd4X04Tn:018?BT0B3d[04Pl;019?Bd0Ac`V04Xn:01<@2P0D48X
0592:01D@bL0ET8W05E290020515:@80DDHZ0P1BAb/205=8;080DdL]0P1CB2`0;@1CB2X0DdPX05A:
9`1EBbL0ET`X04m5;01@A2X0E4@Z05Q7:@1NBRT0IThZ06eA:P1_Db`0LE/b07IQ<P1lJC40Pg4c08Qf
>029MSh0RGA508QbB@28M440RgM2095lA`2FOdT0Vh9:09j4B`2RQD/0Y8M=0:24E@2OPe<0WX9@09n4
C@2QQd`0YHa<0:V@CP2[TTl0YY=I0:NBF@2YTeT0[99G0:nAE@2`SU40/H]=0:n9B`020;6:B@060;:;
B02dSDP0]i5:0;^EC02nV4l0`I]@0`30WET20<6NFP<0`YmK00P0^I]E0;ZKF02lWEX0_9eL0;^LG02h
V5/0]9AI0;:BE`80]I=D00@0]99C0;>ADP2cTE80/Y1A0P2aSe00;P2UT5/0YHiJ0:><F02RR5D0X8AB
09n1C`2MOD`0W7a;0:=j@P2UO4@0ZGi70:f0B@2^OdT0[ge80:ikAP2/ND@0[7i20:n1A@2aPdL0/896
0:an@P2[OD40[X140;:4B02]OCd0[Whn0:mo?`2aPD40]HE50;R8B02lS4`0_Xi>0;f=B`2iS4T0]hY7
0;B9A@2aRD@0/HY50;:=A`2cSTP0/HY70;29AP2_R4D0[HI30:^4@@2ZPd020:R1?P090:Em?`2VOT00
Ygm10:Z2A02/Q4H0[HE70:^3A@2ZPT@0ZhQ40080ZhQ600h0ZhQ80:^7B@2[Qd/0ZhM=0:b8CP2[PdD0
ZH530:R0@P2[PdD0/8Q:0;::C02`R4X0[HE70:R6AP80YhE500H0YH=30:B2@P2UPd<0YhE50:Z8B02/
RTX20:Z:?`070:^;@P2ZRD80Z8M20:B3@02POc`0WW`l09aj>`0709ek?080WW`m0P2MNc`0102LNS/0
VgTj09Yh>@2JN3T209Uf=P0?09Id=@2BLSD0T78f08e`=P2;KS@0RFlf08IY<@25J300PfH^089U;@24
Ibl0R6/c08a_=`2?LSX0U7Pg0080TGDd00d0VGdl0:B8A`2ZSTd0ZHe<0:F9B02FO3l0UG/n09Ek@02F
O4<0Uge409UnA`2KP4/0WH9=0080XhU@0P2TRU401@2SRE00XHM>09n5C02NQ4/0Wh9:0080WX5900<0
WH1809aoA`2KOTH00P2JODD0202JP4L0V7i509Il@`2ENd80U7Y109Ek@P2FO4<0Uge40P2FNd@209Ej
@`<0U7U20380TgQ108mf?P2>MCd0SG@l08ac>`2:LCT0RG0h08Q_=`27KSH0R70d08M_<`25K3<0Q6/c
08A[=@25JcP0Qfdj08Q^?@2;KCT0T78n09UkB@2SQ5D0[XmQ0;NHK02mWW80`:1g0;nYNP2hXW<0/Y]_
0;6JL02fWgH0_JEo0<6YP`32ZXH0aKBH0<^gW03B_j40el:S0=[3X`3F_Y`0dKNF0<bbS`30XfT0]9MM
0:>6CP2DMT00Rfdi08EW=@1oHBl0Ne`]07QM<P<0NEhc00H0N5db07EJ;`1cF2d0LEH[079E:`1_Db/2
06a@:00306I=9@1RBR@0GdTT0080GDTV01@0FdLT05Y68`1HABD0Dd8V04ln9018>240@c@Q040a7P0c
;QX0<bhK038]6P0a:a/0<2XL02lY7@0_:1h0;RLM02//7P0Z:ad0:BXL02LX6P<09RLI00D09bPJ02PY
6`0X:A/09bPJ02HW6@0202DV608092DG0P0V9Qh0100U9Ad092@L02<S6`0S8a/2028R6P0402<S6`0R
8QX08R8J028R6P808B4I0P0P81P8020O6PP08B0K0P0P7aX2024P6`<08R4L00<08b8M02<S6@0S8aT0
1P0S8aT00`0S8a/092@L02DU7@0202HV7P0402DU7@0T91`08b<K02HR6@<09b<J0P0X91/202TU7080
;2DM00H0:b@L02XS6`0Z8a/0:b@L02`U7@0]9Qh202h[7004030Z700a:A`0<RPL03DY7@80=RPM0P0e
:Ad303HZ7P<0=b/O00@0>RdL03/^7@0k;Qd0>bhM0P0l;ah203d`7`80@c<J0P14=1/304De700904Hf
7@19=al0BcLO04Xf7P1;=Ah0CSDO054f8@1D>2<0ESXU00<0FC/O0`1J?20305/m8@0806147`1QAB00
HD@R0654901P@bD0Gd4U05do8`1L?R@205]2900305Y18`1I@280F3lQ0080EchP00@0ESdO05/m8`1L
?R@0GClU0P1N@2H01P1M?bD0G3hT05/m8`1K?B40G3hR05do8`<0Gd4U00@0GT0T05do8`1K@R@0Fd8T
0P1J@B<0101I@280F3lQ05Ln801G?R0205`n9P0F05do9@1N@2@0Gd8T06138`1QA2@0HD@R0690901S
@BD0I4<T06I5901XAbH0JTTV06];9@1/C2H0LTdS07=>901dCbD0MU4W07QC:@1jEB/0NeH/07aG;@80
NU<Z00<0NE@Z07MD:P1fEBX00P1eERX00`1cERX0M5@]07AD;@0207=C;0<0LU8[00<0LE4Z06i=:P1^
CBX01P1^CBX206i>9`80KdlX0`1`D2T00`1aDBX0Kd`V071=9`02071=9`04075>:01bCbT0LTlY079?
:@80N5D[00X0NEH/07]H;P1lFBl0OEX`07iK<@1oG380P5/^089M<024Gc80Qf8e0`28HcH00`27HSD0
R6<f08QS=P0208QS=P@0Qf8e00P0Q5lb08=N<@22GC00PUd`08=N<@25H3<0Qf8e08QS=PP0Qf<c0P25
Gc0208IP<@<0Qf4b0P28HS<8095W=@P0UF/i0P2EL3T00`2FLC`0UW4m09I`?`0209Ma@P0409MaA02H
Lcl0V7<o09Ud@080VWE100H0VgI209ag@`2LMd<0WGU909ahB02JMTH309UeA@80VWI600H0VgM309Yf
@P2JMT80VGE109Qd@02GLcl209Ib?P80W7M20P2KMT4309Ye@00409Ud?`2HM4@0V7A409QdA080VGE5
0`2JMTH01P2LMd<0VgI209]f@P2JMD40VGA009Qc?`80Ug8n00D0UG5109Mc@`2JMTH0W7Q809ijBP02
09mkB`0909ijBP2NO4h0Wge=0:1nCP2POd`0Wgi909elAP2KNd80VWY100<0WWe80`2MO4L209akAP80
WGU900L0WWY:0:1lC02QODd0XWi>0:=oC`2TP500XWi>00<0Xgm?00L0XWi>0:1lC02NNTX0WGU909mk
A`2NNTH0WGU50080W7Q400@0WGU509ijAP2ONdL0WWU40`2ONTD20:1kAP80XGa70P2OO4H20:1mA`<0
XGi800T0XWm90:62B`2RPd`0Xh9<0:F2C02TPD/0Xgi90:=kA`2RNTH00P2ROTX00`2SOd/0Y81<0:F1
C@030:J2CP030:N3C`2/R5@0[8QD0080[HUE00d0[XYF0:n;E`2`S5P0/8aH0:f9F@2^RUX0[h]K0;:>
GP2dT600]Y9R0;RDI02iUFD0^iMW0080^YIV00D0^IEU0;ZFIP2kUfL0_9QX0;fIJ@030;jJJP<0_IUY
0P2lV6P30;fIJ@80_9QX0`2kUfL00`2iUF40^9AP0;NCG`020;JBGP030;NCG`2hU600^IEQ00<0^9=V
0P2iU6L30;ZEJ080^iEV00<0^YIV0;RFIP2gUfH00P2fV6H01`2dV6H0^Ie]0;^LK@2jVf`0^i]/0;bJ
K02mV6/00P2nV6/30;VGJ@<0^YQZ0P2kVF/80;bHJ0060;ZII02iV6<0^IQS0;RGHP2gUV40]YEP0P2e
U5l30;NCG`80]Y9N0`2eTEd30;B@G080]I5M0`2fTUh20;F@G0030;B?F`2cSUX0/XeI0080/HaH00L0
/8]G0;2<F02_ReL0[h]G0:j:EP2]RED0[8QD0080ZhMC0P2ZRe@0102ZRE<0ZhQB0:Z7D@2[QU420:b4
D0P0Zh9<2@2WPTd02@2UP4/0YX5<0:N2C@2WPTd0YX5<0:F0B`2SOTT0XGa70:9mB@030:=nBP80Y7m;
0P2UP4`0102ZQdl0ZHI>0:V6CP2YQTh30:R5C@060:N4C02ZQU80ZXIB0:^7D`2/R5@0[HUE0P2^RUH0
102_ReL0[8QD0:b8E02/R5@20:^7D`<0ZXIB0P2[QU820:Z5D@040:^6DP2]R5@0[XUE0:n:EPP0ZHEA
0P2[QU800`2ZQE40ZHA@0:R3C`020:N2CP090:J1C@2WPTd0Yh9=0:F0B`2TOdX0XWe80:1kAP2ONTD0
WWU400<0XWU3:oooool002[ooooo202UNTL20:AiAP<0YGY70`2VNdP80:IlBP040:EjA`2VNdP0Yga9
0:MlB@@0Z7e:0P2XOd/30:V0C0<0ZX5=0P2XOd/0102YP4`0ZX5=0:^2CP2/Pdl50:f4D080[8=?0`2[
PTh20:f3D@040:b2D02[PDl0ZX1>0:UoC@80Z7i<0P2VPDd40:F0C080Y7m;00@0YGm@0:=mCP2PNT/0
WWQ90`2LMTL209egB080VG=200<0V79309MaA02FKd@00P2EKTD02@2DKDH0T6`j091/>P2@K3`0SfXm
08eX?02:IC/0Qf8h08EO>00208MT?080QV<k00X0QF8j08AQ>@23H3P0Pf0h085N>01oG3H0OEXd07YG
<@1iES00N5D_0P1iES0307EE;P<0M5@]0P1cDb`0601aDB/0LU8[07AD;@1fERd0NEX^07]L;P1mGRl0
OUl`07mJ<020Fc40PUdc08AO=@26HCL0R6<i08UT>P2:IC/0RFPk08YY?02;Jc`0SFdl08m_?02ALS`0
TW<m09=d?@<0V6hl0P2IKcd309Y`?PP0UG0l0P2CKCh0102BK3d0TF/l091Z>`2?JCX508iX>@0308mY
>P2@JS/0T6Xk00<0TF/l00L0TV`m09=]?P2CKCh0TV`m091Z>`2>J3T0S6Hg00<0RfHj0P2:ICT308UT
>0<0R6Pi0`29JCX208YZ>`0608QR<`29Hc@0RV@e08]U=P2<ISL0SFLh0P2>J3T3091U>00308mT=`2>
HcH0SV<f0080SF8e0P2;ICH208YT=@80RF<d0P28HS<208aW>P<0RfHi102:ICP208]U=P80RV@e1029
Hc@808QR<`80SV<f0P2=HSD208aQ=080Rf0c00<0Q60`08EQ<@26HS800P27Hc<00`25HC40Pel_089N
;P0408EP<`@0QV4d00D0PUd`08=N<@23GS40Q5lb08IQ=00208MR=@0908QS=P2;IST0RVDh08QS=P27
HSD0RF@g08aW>P2AK3l0Tfi100P0SfHh0P2<J3@0102=JCD0SVXf08m[=`2@K3P2095]>@03095]?@2B
KSh0Tflo0080U71000<0Tflo095]?@2@K3`0202<KS`0602>Kd00SFho08a]?P2:Jc`0R6Tj08IW>025
ISL0Q6Df07eQ<@1iGRl0MU//07=K;@1cG300KeX_06MD:P1QCR@0GdPV05e6901F@b<0CchR04Pj7`10
=Qd0>S8M03La6`80;RlM00H0;BhN02//7P0Z:Qh0:2PN02LW7@0W9al202DV7P0402@U7@0S91`08R<K
024R6P80824I00<08RDL024T6`0Q91/00P0P8aX201lR6@807R4H00<082<J028U700T9ah00P0U:1l0
0`0T9ah08bHM024T7@08024T7@<08b@L0P0T9Ad302DV7P0S02PY8`0Y:B40:BTO02`Z7@0`;A`0=C0L
03Xd7P0l=Qh0>cHI03df6P0o>1`0@SPO04<g8@14=B00A3<O04<b8010>bL0?3LS03Lb7P0b;AT0;BXG
02`Y5P0]:QT0;B`J03<Z6@0d:aX0=RdL03L^7@0h;ah0=bhM03H]700e;1/0<B/M030Z700_:A/00P0^
:1X0100_:A/0<B/M038/7P0_:Ad202`X700302XX6`0W:1X09BLI00808bLH0`0U9A/302HV70809bLM
00H092DM02<T700S91`08R<K024R6P0P8AT201lP600F01`Q6P0K81T07B0I01hO6@0P8A/08b8M02PU
800Z9b80@C0L04/k8@1IARD0GDXR05Y36P1I?1`0GS/U068n;P1fE2@0QV@d099`@02CLSl0UgI30:>2
C@80ZhYE00`0T6hn06eA;016=B<0<2/X02TZ;P0U9bH09BLL02d/6P0Y;2D0:2/T02HY8P0T9b0202<V
7`8092LP0`0S9B8302@V8`809BLT0P0Y9B806@0Y9R40:RLP02dZ8@0a;b<0=38V03Hd9`0^;b40;BdQ
02XZ7P0W9ad09BDM02@S7P0T8al09B@P02HW8P0W9R809bHQ02/X8@0^:R40=2dS03P_9P0j<RL0?C0P
03ha8@10<b<00P12=BD05`11=2@0@3<S03lb8P0o<R80ACPU04<f8`12=B80A3LT04Pk:019?2T0A3LT
03lb7`14>B<0Ac/U04Xn9P1?@BL0DT8X05A39`1F@RL0ET<U050n:01??BL0CC/U0080C3XT00<0CC/U
04lm9`1@?RP00P1>?bP02@1?@BL0Cd4V05129@1AA2@0DD@R05958`1C@280E44S05I39@0305Q59`04
05M49P1F@bD0DT4W05919`80Dd8X0`1D@bT02@1EA2X0FdHW05Y59P1GA2H0Dd8V05509P1>?RD0Bc`U
04Xk900204Xj8`0404/k901<?2D0CShW04lo:080D40Y00@0EDL/05=5:P1A@bP0Cd4V0P1>@2D0201?
@BH0D48W04dm;@1=?Bd0CSl/04m0:@1?@BL0D48U0P1AA2@0201CB2`0D4DY04m19`1@@2L0ED<]05Q3
;P1F@Bh0E3d[0P18=bD00`19>2H0BSTW04/j:00204`k:@0a04dl:P14=RT0ACLZ04Dg:P11<bH0?BlR
03h`8`13=BP0B3X]04<f9@13=R<0@SDR04<g8@14>200Ac/Q04Tn8P1;@2@0BT@T04To9P16>BT0AS</
04Lc;01<=RT0DcXV05Lo9@1J@B<0GDHW05i9:P1LBBT0EDHU05548P1?AB80D4PT04]5:`19@bT0Ad4Y
04Hn:@15?BX0B3`/04Tm;@1;?C00B3`V04Tm9@1>?bP0DT8Y05A3:@1G@bP0ET<U05M29@020515:@80
DDHZ0P1BAb/205=8;080DDD[0P1BAb/00`1BAbT0DdPX05=99P0205=99@0F0598;`1CAbd0EdL]05a9
:@1SC2X0JdlZ071C:`1dE2/0L5db07AR<01lK340Pg<e08If>027MT00QG=508=_BP24Lcl0R7A108ah
@`2BODP0V85;09b3B`80WXA;0100Vh1E09YoDP2IOdh0VH1:09b4B02QRDT0Yi1<0:ZCC@2RTe`0Y9=M
0:NBF@2ZTEP0[HiE0:j<C`2^R4X0[XI80P2bRDL01P2cRdH0]8e80;NBB`2kUdd0_i]?0;nND@<0`YmM
0`33X5h20<BQG`080;bOF`2kWU`0^YeK0;RJFP2eUeT0/YAH0;2AF02_T5L20:n?DP030:j>D@2]SE00
[8a?0080Zh]>0180ZXY=09j=F@2OReP0WXQF09f6E02MPE40WGi?09alC@2LNT`0XgXh0:Ql>`2/P3l0
/HA30;B4A02ePd@0]8520;9o@02cPdD20;B4AP050;61@`2]OCl0[Wi00;>3A@2hR4X00P2gQT@0302f
QD<0]hI40;V8AP2kRTP0_Xe;0<2?C@31TTh0_Y5=0;b?B`2iSTT0]Xi80;B>A`80/Xe600/0/X]80;6:
A`2_R4D0[HI30:^4@@2YPSl0Yh0m0:Io?02XP480ZX940:b4AP030:j6B080[HE70P2YQT80102YQT@0
ZHE70:V5B@2YQ4d20:V4C`090:^5A`2XPT@0YX120:V3A@2^R4X0/8Y<0:n9B`2/QTP0ZHY90080YhQ7
00h0Y8E40::3@P2SQ4<0YHI50:R9B02[S4/0ZX]80:Z;BP2YRTT0YhQ80:B4A`2RPTL0X81709inA@<0
WW`m1@2MNc`01P2POSl0Wgdn09il?@2NO3d0WG/l09aj>`80VgTj0280VGHd09Qe=@2FM3@0TW<c08ma
<`2=L3@0Rfhd08U_=028Jc<0QVTa08AW;`23IRh0Q6L_08MZ<P2;KSH0SG0h09Ah=`2CMcH0U7Pg09Ql
>`2OPd80Yh]:0:fAD02`U5<0VGm209Qn@@2GOD80UWa309MmA02HODH0VWm:09b1C02SRE00Y8YA0P2U
Re80102TRU40XXQ?0:26C@2NQ4/209n2BP0>09j1B@2MP4P0W7m709]nAP2JODD0VGa409Z0A`2HOTD0
UWa309Ek@P2DNT40UG]209Il@`2GOD@309IkA080UGY30`2DND801P2?MSh0SWDm08ed?02<Lc/0Rg8j
08U`>080R6lg02P0R70d08M_<`26KC@0Q6/c08A[=@26K3T0Qfdj08Q^?@2:K3P0T78n09UkB@2TQEH0
[XmQ0;NHK02nWg<0`J5h0<6[O02jY7D0/Y]_0;2IK`2dWG@0^j=m0;nWP@30Z8@0`[6C0<NfV03@_Il0
el:U0=_4Y@3H`J80eKbN0=6hV@3>/7@0`J9Y0:n@E`2OP4T0U7Do08a/>@26ISD0PF4`0P1jGc@0201k
H3D0NUld07UN<`1gG340M5T^079G;01dEbd0LUD[0P1]DBT03@1XCbH0I4dT065;901PBRD0GTXU05m9
901NAbD0FdLV05M49P1@?bD0BSXS04He8@12<b000P0e;Q/02P0d;A/0<b`L038Z7@0a:A`0<BTN030X
7@0^;al0;2dM02X[6`0W:1P202HW5`0802LX600X:AT0:BXJ02TZ6P0X:AT09bPH02HW5`0U9QH202@U
5@0602LW7`0V9Qh09RHN02DU7@0T91`08b<K0P0R8QX202<S6`<08R8J0`0Q8AT8024P6`P08R4L0`0Q
81/3028Q70808b8M200T91P00`0T91`09BDM02HV7P0202LW7`0302HV7P0T91`08b<K00809b<J0P0X
91/302TU700902XV7@0]91d0;2<L02/R6`0Z8AX0:b8K02dT7@0_9Ql0<BPQ0080;b`M00@0<B/M038Z
7@0c:Ad0=BTM0P0e9a`203DY7@<0=RXN0`0g:al303/^7@80?2lN0`0m<1l304@d6P80ACDK0`16=Q`0
2@1<>200BcLO04/e7P1==1h0Cc@O058f8@1D>2<0EcPT05Tk7`0405Xl8080FcdQ0P1L?R80201QAAh0
HTHQ06=78P1SAR@0HTDU06139@1M?b<0G3hR0P1L@b@00`1K@R<0FT4R05U08@0205Po800305Ln7`1M
?bD0G3hT00@0FcdS00D0G3hT05do9@1L?b40GD0R05m2900206549P0306139@1O@R@0GT4S0080GTDV
00@0GD@U05a3901K@R<0FT4R0P1I@240801M?bL0GT0X05i09P1O@BD0H4<U06138`1QA2@0HD@R064o
8`1R@2@0I4<T06I5901XAbH0JTTV06];9@1/C2H0M4dR07E>8`1fCb@0N54V07YC:01lEBX0OEH[07iG
;01hDBH0NE8W07]F:P1kFB`0NUT/07QI:`1eERP0LEDV0P1eEBh207AD;@<0Le</00D0LU8[075@;@1a
D2d0L4l/06m>:`0206i=:P80KD`Y0`1_CbP2071@:@<0LE4Z0`1cD2X307AA:`80ME8/0P1hEB/0301i
ER`0NeP^07aI;`1mFS00OU/a07mL<P20Fbh0PUd`08AO<P27HSD0R6<f08UT=`<0R6<f1`29I3L02028
HcH0Qf8e08EP<`24Gc80QF0c08IQ=027HSD0R6<f2028I3@01028HS<0RF<d08US=029Hc@308YT=@80
RfDf202BJ3H809I/>P0809Ia>P2GLS/0Ug8m09Mb?P2HLT40V79309UcA02ILdH209Ud@00309Ye@@2K
MT80W7M30080WGQ400T0WWU509mkB`2MNDT0W7Q809YfAP2IMDD0VWI609]gA`2LN4P00P2LN4@01P2K
Md<0VWI209Ue@@2HM400Ug<o09Ib?P80WGQ10P2LMd0309]f?`0309Ye?P2IMDD0VGE50080VWI60`2K
MdL03@2LN4P0WGQ409ehA02LMd<0VgI209Ye@@2IM400V7<o09Mb?P2HM4@0VGE509]gA`2MNDT00`2N
NTX02@2MNDT0WG];09ilC02POd`0XH1;0:60BP2OOdH0WWi509em@P020:1oBP80Wgi90`2NODP02@2M
O4L0WGU909ijBP2ONd/0X7a<0:9nCP2SOdl0Y81@0:F1D@020:=oC`<0Y81@00H0XWi>09mkB`2NNTX0
X7a809mkA`2NNTH209eiA@0409ijAP2ONdL0X7a809mjA@<0X7]60P2QO4L20:9mB0<0X7e70P2QOTP3
0:9oB@060:F6C`2TQDh0Xh9<0:B1B`2SP4X0Xgi90P2VOTX01@2UPDd0YX9>0:N3C`2XQ500ZHEA0080
ZXIB0P2[Qe<20:n;E`040;2<F02aSET0/HeI0;:>FP80/hmK0P2aSEd03P2bSUh0]91P0;FAH@2fTV80
]i=S0;RDI02kUfL0^YIV0;VEI@2hU6@0^IEU0;ZFIP2lV6P0_IUY0P30W6`20;nKJ`<0_YYZ00<0_IUY
0;nKJ`2nVVX00P2nVVX20;fIJ@80_9QX00<0^iMS0;ZFHP2iUF400P2hU600102iUF40^YIR0;^GH`2i
U6L30;ZEJ080^iIY0P2lUfX01@2mUfP0_9IW0;^GI`2iUfL0^9QW0080]iUW00L0]IUW0;JJJP2hVFX0
^IY[0;ZJJ`2kVF/0_YU/0080_iU/0`2iUfT30;ZHJP80^iU[202lV6P01P2jVF@0^IQS0;VHH`2hUf80
]iIQ0;JEH080]IAO0P2hU6020;NCG`<0]Y9N00D0]I5M0;B@G02dT5`0]91L0;FAG@020;JBGP80]i=O
0P2eT5`00`2dSe/0/hiJ0;:=F@020;6<F0060;2;E`2`S5P0/8aH0:n;E`2^RUH0[HUE0P2/R5@01`2[
Qe<0ZhaE0:Z;E02[RU@0[8UC0:^8DP2[QU400P2/Q5080:b3C@T0Yh9=00<0Y7m:0:F0B`2WPTd00P2X
Pdh0102VPD`0YH1;0:AoBP2TOd/30:F0C080YX5=0P2WPTh30:Z7C@030:V6C02XQD/0Z8E;0080YhA:
00H0ZHEA0:Z6DP2ZQU80ZhMC0:b8E02]RED20:j:EP80[HUE0P2/R5@01`2[Qe<0ZXIB0:Z6DP2ZQU80
[XUE0:f8E02[QU800P2ZQE400`2/Qe<0[HQD0:j9E@080:V5D@80[8IE00<0ZhED0:Z4D`2YPe800P2X
PU402@2WPE00ZHA?0:R3CP2VPD`0Y7m:0:9mB02PNdH0WgY509iiA0030:=jA2_ooooo000Zooooo`P0
YGY70P2TNDH30:EjA`<0YW]8202WOD/50:EjA`030:IkB02WO4T0Z7e:0080Z7m;0`2YP4`30:Z1C@08
0:MnBP2XOd/0ZH1<0:Z1C@2[PTh0[8=?0:f4D02^QE440:b3C`80Zh9>00/0ZX5=0:V0C02^Q580[H=A
0:b2D02[PDl0ZX1>0:UoC@2XOT`0Yge;0:J1C@060:F0C0050:AoB`2TOU40XWa?09miC02MMdX00`2K
MDP02P2LMTT0WGM:09Yd@`2ILd80VG=409QbA@2GL4D0UVm609E^A@2EKTL2091/>P07091/?02?JSd0
SFPl08YU>`27HSP0QElh08QU?@0208MT?00308IS>`25HSX0Q64i0080Pf0h00H0PEhh07mL=P1mFS@0
NULa07UF<01hEBl207UF<0<0MED^0`1dE2d207=C;00H071@:@1aDBX0Le<Z07IG:`1iFR`0O5d^07mP
<@20HS00OeX`081K<@22GC<0Q5le08IQ=`28HcT0RF@j08YU>`29J3/0RVTl08][?02=KC`0Sfll095b
?02BLcd0Tg@m0`2HKS`209U_?@<0VW0n0`2DKc/509E`?006099/?@2AJc`0TF/l091Z>`2?JCX0SVPi
0P2=IcP208aV=`0408eW>02>J3T0SVPi08mY>P80T6Xk00P0TF/l099/?@2CKCh0U6ho09=]?P2@JS/0
SVPi08aV=`80RfHj0`2:ICT308UT>0<0RFTj0`2:JS/208][?00608MQ<P28HS<0R68c08YT=@2;ICH0
S6Hg0P2=IcP2099V>@04095U>02@I3L0T6@g08mS=P80SV8e0P2;ICH208YT=@80RF<d0P28HS<308aW
>P80RfHi102:ICP208]U=P80RV@e0`29Hc@908QR<`80Sf<f0P2>HSD208eQ=080S60c00T0Q60`08EQ
<@26HS80Qf<c08IR<P25HC40Pel_089N;P28HcH00`27HSD308IQ=00608EP<`22GC00PUd`08=N<@24
Gc80QF0c0P27HSD02@28HcH0S6Lj08]V>@29I3L0R6<f08YU>02>JC`0TVe009E`@`0808mV>080S6Tc
00P0SFXd08i[=@2?K3H0T6dg095^>02BKcT0TFdm099^?P<0U71000<0Tflo095]?@2@K3`0202;KC/0
8@2?L440SVm008e^?`2;K3d0RFXk08MX>@26IcP0QFHg07iR<P1jGc00Me`]07AL;P1cG300KeX_06IC
:@1PCB<0GTLU05a58`1E@R80CSdQ04Hh7@0n=1/0>30K03D_6@0_<1h0;RlM02d^7P0/;Al0:b/O02TY
7`0X:1h0:2PP02DV7P0202@U7@0302<T700R8a/08B8J0080824I0P0R9A`0100Q91/082<J020S6P0O
8QT301hQ6003020S6P0R9A`092LN00809BPO00<092LN02<V7@0Q91d0200Q91d3028S6`808b@L0`0T
9Ad06`0V9b40:2PP02PX7P0/:Qd0<2dL03Ha7@0j=1h0?CLO03`g6P0m>1/0?cPN048g8@13=b40A3DR
048b8P12<B40?S/X03Xg900e<Ql0<2dJ02dZ5`0/:AH0;BXG02h[600c:QT0=2/J03H]700303L^7@0@
03D/6`0d:aX0<B/M030Z700^:1X0;BLI02hX6P0_:A/0<B/M03<]7`0^:1`0;2PL02/W6`0Z:1/09bPJ
02DW6@808bLH0`0U9A/302HV70809bLM0P0S91`2028S6`04024R6P0P8AT07b0H01lP60806b0I02H0
7B0I01hO6@0P8A/092<N02PU800Z9b80@c<L04ln8P1MBbL0HD/R05a36`1K?1d0Gc`V06E0<01mFBL0
RfLe09=_?@2BKS`0V7A20:N3D@2_ReL0[HUE08ES=@1SBBH0@C4R034[;@0Y:C408RHW02DW700];Q`0
:RdV02P[900U:2408bHO028U7P0S9Ql092LP02DX8@<08bDR0`0T9R<202DW9080:BDR00`0:BHQ02/X
8@0]:R40<BlS03@b9P0f=2L0;RlQ02`/800Y:Ad09RHL02@T700S8Qd202@S7`0;02HW8P0W9R809bHQ
02/X8@0_:b80=2dS03P_9P0k<bP0?2lO03ha8@0o<R800`11=2@05P10<b<0?c8R03lb8P16>BH0@cHS
048e8P15>2D0BC`Y04Xm:P15>2D0?c8O04Hk9@18?2H0BclW0512:01B@RP0Dd8V05E19P1D@B<0D3hX
04lm9`1=>bD204`j900304dk9@1??BL0D3hX0080CSlX00@0Cd4W04m19P1@@RD0DD@T0P1AA280201B
?b40E44S05I39@1HABL0FDHX05Q59`1GA2H0ET<U0`1B@BL205=2:0<0E4<Y01P0FdHW05Y59P1GA2H0
Dd8V05509P1=?B@0Bc`U04Xk9018>240BCTR04Xj8`1<?2D0CShW0510:@1A@BX0DT8[05A6;01BA2X0
D48X04i09P1=?bD0CT0V04m19`1@@RP204dm;P0<04hn;P1?@2/0D48X05539P1AA2@0DTDS05U><P1B
Ab/0BcdS04Pi8P1;>b@0CcdY0P1B?B`404`k:@0504/j:01:>BL0BSTW04Th9P13=BP00P14=RT0;@11
<bH0?BlR03h`8`14=RT0BC/^04<h9P13>2@0@SLS048g8@13>B00AC/P04Ln8@18?b80BT@T04To9P16
>BT0Ac@]04Xc;@1?=b/0Ec`Y05Y09`1L@B@0H4LY069;;01MBRX0EDHU04i48@1=AB40C4HR04Y6:`18
A2/0Ad4Y04Do:@15?BX0B3`/04Xl;`1;?C00Ac/S04/l9@1>@2H0DT8X05E4:01GA2H0Ed8U05M28`02
04m6:@80D4LZ0P1AB2/20599;080D4H[00D0D4LZ0558:`1AB2T0DDPW05599@020559900`059:<`1E
BC40F4X_05i;:`1UCBT0K50Y07=C:P1gER/0Ked_07AS;`1lK340Pg<e08Mg>@26MCl0Pg15085]B022
L3h0Q7<o08Yf@`2@NdH0Uh1:09b3B`2LPdX0W89909QlE02GO540UW]<09MnB02JPDP0X8Q80:J?B`2Z
Tdd0X9=N0:>CG`2VTe/0ZY5I0:b=E02]Rdh0[HM90:f5A`2dR4L0]HU80;B<A`2eSdP0]i=90;^GB`2m
W4l0`9m@1`33XUl02@34Xf00_Z5O0;bOG@2iVe/0]IMG0;:DEP2_TED0[XmF0:f>E@020:b<C`030:^;
CP2ZRTd0ZHU<0080Z8Q;0140YhM:09^;F02KREL0VhME09^3D`2LP540W7e?09ajC@2KND`0Y7Xb0:Um
=P2^PS/0]8Do0;R7@P2iQd80^HA00;R3?`020;N5AP090;J4A@2aOd00[W`m0:mm?P2fQ4D0_8Y;0<2=
B`2oS4X0_HY80080^hQ602`0_8U70;j;B@2oS4X0`iA@0<6DD030Tdl0_I9=0;VAB`2fT4T0/hi70;6<
A@2bRdP0/HY70:n8A@2]QT<0ZhA10:R1?P2VOc`0YGhk0:b4AP2^QTP0/HU;0;::C02aRD/0/8Q:0:n7
B@2`R4X0YhHo0:N6@@2WQT<0YhE60:N4BP2VPdd0YX9>0:F1C@2]QT/0ZX=80:N0A@2YPTL0[HI;0:n8
C@2^Qd`0ZhA90:^<B`80ZHY900`0YHI50:>4@`2SQ4<0YHI50:R9B02[S4/0[8a?0:Z:C`2XR4d0YHE<
0:>2C02QP4/20:1oC0D0WW`m0`2MNc`20:1n?`0309mm?P2NO3d0WG/l0080W7Xk01`0VgTj09Uf=02H
MC<0UW@d099c<`2?LC<0S6lc08]^<P28KS<0RF`d08MZ<P25J300PfH^08AW;`26JC40RVde08a_=`2D
N3L0UGTh09Ij>@2GNcX0W80o0:F9B02`U5<0^9aK09b2A@2JP4<0V7i30P2GOD@02`2HODH0VGi909^0
B`2SRE00Y8YA0:F;DP2VS5<0YH]B0::8C`2PQTd0WXA;0080Wh9:00<0WX5909f0B02LOdL00P2JODD0
2@2IO4@0VX1709QnA@2FO4<0UG]209Aj@@2ENd80UWa309MmA00309IkA0<0UGY30P2DND8208mf?P04
08ie?@2<Lc/0Rg8j08U`>080R6lg02T0R70d08M_<`26KC@0QF`d08E/=P26K3T0Qfdj08Q^?@2:K3P0
T78n09UkB@2TQEH0[i1R0;RIK@2nWg<0`J5h0<>]OP2kYGH0/ia`0;2IK`2dWG@0^Z9l0;jVP02oYh<0
_k2A0<FdUP3=_9h0eL:T0=W4Y`3J`ZH0ekfR0=BjW`3G^Gd0bZa`0;NHG`2VQe00Vga6099b?`2;JcP0
QVHe07YO=00307]P=@0607YO=01gG340MEX_07=H;@1gF2`0LeH/0P1_DRP00`1ZCRH0ITdU06=;9@02
065;9P09061:9@1OBB@0FdLV05U49@1C?b@0C3XR04Lf8P14<al0=S0J0080=BhK00<0=2dK03</700b
:Qd00P0a:Ah0100_<200;BhN02X[6`0X:AT202LX600802PY6@0Y:QX0:R/K02X[6`0Y:QX0:2TI02HW
5`0U9QH202@U5@809bLO00@09RHN02DU7@0T91`08b<K0P0R8QX302<S6`808R8J0`0Q8AT8024P6`P0
8R4L0`0Q81/2028Q70<08b8M200T9AL00`0T91`09BDM02LW7`0202PX800402HV7P0T91`08b<K02LS
6P<0:2@K0P0Y9A`202XV7@0802`S700[8Q/0:R4J02XQ6P0[8Q/0;RDN034X8@0c:R<2030]7P04034[
7@0b:Qd0<bTM03DY7@80=BLL0P0e:Ad303HZ7P<0=b/O0P0k;Qd303`_7P<0?C0O0P14=1X204De6`<0
ASHL00T0AcLM04`h801==b00C3HO04dd7P1?=1l0DCDP05Df8P1G>2@01@1J?20205/m8@80G3hR00T0
HTHO06=7801TB2<0I4LU06=69P1P@bD0GD0R05`n8P1MA2D00P1L@b@00`1K@R<0FT4R05U08@0205Po
800305lo9P1N?RD0Fc/R0080FCTP00H0Fc/R05hn9@1O?bH0GChQ05m08`1Q@RD206=49`0306939P1Q
@RD0H44T0080H4LX00<0GdHW05i59P1MA2D00P1K@R<01P1J@B80GT0X05i0:01O@BL0Gd4U06139@80
HD@T01T0HD@R064o8`1R@2@0Hd8S06E48`1XAbH0JTTV06];9@1/C2H0M4hQ07E?8P1fD2<0N58U07YD
9`1lERT0OELZ07iH:`1fD2<0NE<V07aG:P1nG2h0OEd^07UJ:`1eERL0L5@T00<0MED^0P1dE2d307=C
;00607=B;`1bDBh0LE0]071?;01^CBX0KD`Y0P1/BbP206m?:080L50Y0`1aDBX00`1bDR/0Me@^07MD
;P0207MD;P@0N5D_0P1hEB/02P1iER`0NeP^07aI;`1mFS00OU/a07mL<P20Fbh0PUd`08AO<P27HSD8
08UT=`@0RVDh00<0RfHi08UT=`28HcH00`26HC@208QS=PP0R6@d0P2<ISL208eW>0@0SVPi00<0SfTj
09=Y=`2CJCL01P2CJCL809I/>P80Ug8k00<0V7<n09Qc?`2ILd800P2ILd@01@2JM4L0VWE109Ye@@2K
MT80W7M30080WGQ400D0WWU509mjAP2PO4`0WWY:09ahB00209YfAP0309]gA`2LN4P0WGU90080WGU5
00@0W7Q409]g@`2IMD40V7A00P2GLcl309eh@@80W7M00`2KMSl309YfAP80VgM70`2LN4P209iiA004
09eh@`2LMd80VWE009Ud?`80V7<n0140VGE509]gA`2LN4P0WWY:09mkB`2NNTX0WGU909ahB02MNd/0
WWe:0:1oC02QP4/0XH1:0:61B02PP4D0Wgm40:60B`030:1oBP80Wgi90P2NODP209ijBP0409mkB`2Q
ODd0XWi>0:B0D080YH5A00/0Xgm?0:B0D02UPE40YH5A0:B0D02ROTh0X7a<09ijBP2QODT0X7a809ij
AP0209eiA@0309ijAP2PO4P0XGe900<0X7]60P2QO4L30:9mB080X7e70P2QOTP30:9oB@0>0:>0BP2X
RE80YHI?0:>2C02SP4X0XWm90:=nB@2WOd/0ZH5=0:N3C`2XQ500ZHEA0:Z6DP2[Qe<20:b8E0030:f9
E@2^RUH0/8aH0080/HeI00<0/XiJ0;>?F`2dT5`00P2eTEd0102cSel0]91P0;B@H02eTF420;JBHP80
]i=S00T0^iMW0;ZFIP2hU6@0]i=S0;RDI02jUVH0_9QX0;fIJ@31WFd00`30W6`20;nKJ`80_YYZ0`2o
Vf/20;jJJP<0_IUY00<0_9QT0;^GH`2jUV800P2iUF40102jUV80^iMS0;bHI02jUFP30;^FJ@80_9MZ
0P2mV6/20;fGJ0030;bHJ02jV6P0^IUX0080]iUW00T0]IUW0;BHJ02fUfP0]iQY0;VIJP2kVF/0_YU/
0;nIK030VVd00`2iUfT30;ZHJP80^iU[202lV6P01P2jVF@0^IQS0;VHH`2hUf80]iIQ0;JEH080]IAO
0P2hU6020;NCG`@0]Y9N0`2dT5`00`2eTEd0]Y9N0;NCG`020;NCG`80]I1L00<0]8mK0;>>FP2bSET0
0P2aS5P01@2`ReL0/8aH0;2<F02_ReL0[XYF0080[HUE0P2/R5@20:^<E@040:^:E02/RE<0ZhQB0:^6
D@80[8A@202]PTd90:N2C@030:=nB@2UP4/0YX5<00<0Z8=>00<0YX5<0:F0B`2VPDd00P2VPDd30:N2
CP80Z8=?0P2[R4h0102ZQdd0ZHI<0:V6C02XQD/20:N4BP060:R4D02YQE40ZHEA0:Z6DP2[Qe<0[8QD
1@2]RED00`2/R5@0ZhMC0:Z6DP020:Z6DP030;2;E`2^RED0[8MC0080ZXEA00<0ZhIB0:f8E02^RED0
202YQE420:b6E@040:^5E02ZQ5<0ZH=B0:V3DP80Z89A00P0ZHA?0:R3CP2WPTd0YH1;0:=nB@2QO4L0
WgY509iiA0<0XgY4:oooool002[ooooo00H0Z7e60:MlA@2WO4L0YW]80:EjA`2TN4L20:=gB0030:Mn
BP2VODT0Y7]70080Y7]700<0YGa80:MnBP2XOd/0202TNTP30:ImB@<0Ygi:0P2XOd/80:V0C0P0ZXEA
00L0ZGm=0:Z0CP2]Pe40[hEC0;26E02_QE<0[XAB00<0[H=A0`2/PU030:^1C`<0ZGm=0P2XOT`30:Mm
B`040:F0C02TOd/0XGa809mjAP<0WGQ40P2NNDD209Qc?`0309Mb?P2FLCd0UW4m0080UG0l00L0U6lk
09A^@@2CKD00TV`o095[?P2@JSd0SVPk0080SFLj01<0RfHl08YU>`29I3X0Qf8h08EP=P23GS@0PUdc
085L<P21GSH0P5de07iK<`1lFC40NUL_07QE;@1gE2`0MU<[06iA:@1_DRX0LE@/0080LeH^00<0LUD]
075D;01`Db/00P1dE2d0101fERl0N5Pa07YJ<`1kFc@207eM=P0807mN<`20Gc@0PUle08EP=P27HSP0
RF8i08aR>P2=Hc/2099W>P0909=X>`2EJSd0UV/n09M/?`2HKD00VFi109Q^?02IKcd0VW0n0080Vg4o
00<0VFlm09M]>`2FK3X00`2GLD8209I`@@<0UFm00`2BK3d2095[?0<0T6Xk0P2AK3P3091[=`<0SfXf
0P2@JS/01P2?JCX0SVPi08eW>02<ISL0RfDf08YT=@<0RfDf0P2<ISL;08eW>0P0R6Pi0P2?I3L308iS
=P<0SF8e00H0Sf@a08iT<P2=Hc40S6@c08US=028HcH208ES=PT0RV@g2027HC802028HS<0S6Hg08iX
>@2;ICH0QEl`089L;@25Gc00RF<d0`25GSL308IO>080Qf0i00P0Peha08AO<P25H3<0QV4d08EP<`24
Gc80PUd`085L;`80Qeh`00@0QEl`08AP<024H300PV0`0P21HC001020GS00PEla085O<@21Gc42089P
<P80Pf4c00P0Qf<c08QT=029ICD0RfLg08aX>02>JSX0Sf/k091/?0<0S6Ph0P2=JCT308iZ>P0508i/
?02=Jc/0SF/k08aZ>P2;JCT00P2:J3P04@29IcL0S6Xj08e[>`2?KCd0TFlo099`@02AKcl0Sfdm08i/
?02AKCd0T6hn095_?`2@L3l0Sg4o08]_?@28KS/0Qfdj0080Rflo02@0RVhn08U]?@27Jc/0Q6Ph081T
=01nHS80OF0d07QM<01eFRl0LUT`075J<@1^F340IE8Z061<9`1MBRX0F4LY05529@18?280@3PQ03Xe
8@0f<b00=3<Q02d^800[;1h0:BXL02PY6`0W:1X0:2TK02TZ700Z:ad09RXK02HZ700U:A/08bHK028U
700P8a`201lQ70P082<J200R9A`9020S70808B8J00@08R<K02<T700T9Ad09BHN0P0V9al0200U:1l0
92LL02HX7@0X:1`0;2XM030]7P0c<1l0=c4Q1@0n=R4303lg8P0804Th:014=2D0>RhN030Z6P0X:AT0
9b/L02H^7`0V<B48034[7@80<BhO00@0<2dN02l/7@0_;1d0;R/L0P0]:Q/0200^;al0;BhN02X[7@0W
9a/09RHL02DU7@0U91l09RDP200U9A/202<T7P04028S7@0Q8Q`08B8L020Q6`807b0J00/07QlA024Q
6@0U8B0091lS02<O800V8a`0;B`J03<c6`1A>AD0EShJ05a480020618900D05m78`1NAR80GDDQ07]O
=`2=L4H0UGI:099`@02LMd<0/8U@0;:8C02SNS`0I58l04dl:P0e:1L0;2@G02XW7P0W:28092TU02L]
:`0W9bD202HV900302DU8`0T928092@R00808b<Q02L09RLR02DV8@0T9Al08b@L02<U6P0T9QT09RPK
02LY6`0Y:Al0:RXP02/[8@0];B<0;blU034a9`0b<RP0<c<Y02`/900[:b<0:BTQ02LW7`0V9Qh09bLO
02TY8@0Z:R809b`X02DZ9P0U9b809BHP02PX800]:R<0<RlV03Hb:@11=2@0@SDU044f9010>2<0?cTQ
03li7`0n>Ql00P0n>Qd01P14<al0AS@P04Pf801;=al0CCLO04lg7`80CcLM01H0BSdZ04Pk:016>BH0
@cHS048e8P13=R<0A3LT04Dh9@19>B80C3`U04lo:01=?BH0BCTR04Ph8@1:>R<0CCdV04/m8P1<?R<0
CClT04m19P1A@bP0DT@Y0P1DAR/205<o9P0405A09`1E@BP0ED4X05I2:@80Ed<Z00h0D3lU05509P1D
@bT0ETD[05M6;01FAB/0ED@Z05A3:@1JA2d0FD</05M3:`1C@BT0DClW04hn9@80BcdS00h0C3XR04/i
8@1:>200BSPP04`j8P1>?2@0D3hV0590:01B@b@0DT<V05529@1A@BL0DD4X0510:@80D3l[201A@BP0
1P1GAR`0ED<[0590:01??BL0C3XV04/h9`80BcPY02/0CcXY054l:@1A?2T0CcXU04di8@1@?2<0Ed<X
05e9;P1KBB<0DD4P04Pf8013<B<0A3@U04@g9013=ad0@3DE04d^:@18<R@0@cLM03hk600m?AT0@3/N
04Dh:01:=Rl0DT0/050n:P1<>R@0BSPP04Xi7`1<>al0D3lS05918`1HAR80EdLS05Q89P1GB2L0EDPX
05159`1=A2D0Bd8U04Lo;016?R/0@c/X00<0@CTV00<0@c/X04@l:@1:?b<00P1:?b<204]090<0C44U
00P0BCdS04a09P1?@bT0CT8X04/o9@1:?R@0C40V04m3:@<0DT</00/0Dd<Z05A3:@1FABT0FdPZ05m:
:`1QC2d0I4LW06M::P1[CR`0Ke<^07=G<00207EI<@1E07EJ;`1cHCT0M68j07IT?01iIcl0O6Y207i/
A01oKDD0P6i608=[?@24K3h0Qg5208UdA@2:N4P0Rg]:08alB`2;OD`0SGI408mhAP2BNdT0UWm=09Z3
D@2NQeD0X8UG0::;F@2NSEL0Wh]F0:2:D@2UR500ZXM=0:n9B`2cRT`0]XY;0;ZA@@2jTD80_9=40;jD
B030UT`0`iUA0<FJE@36VeH0`j5J0<:QFP31X5d0_IiM0;^MG`2hVf40^9]S0;NIH`2iVEh0]iML0;FE
FP2aTEH0[HeB0:Z:C`2WQd`0YHE:0:B4B@2UQDX0Z8E;0:^7C@2]QTd0[HA<0:b3B`2/PDX0[h1F0:en
DP2ZNdd0Z7Y80:UkA`2/OdH0[h970;:6B@2cRD40]Xa40;Z@B02nU4`0`IM?0<:HD031Udl0`9I>0;^?
AP2lT4L0_I580;Z>A@020;J:@@030;Z>A@2oTdX0]YA:00L0]YA:0P2hUUH04@2gUED0]I=C0;:@D02^
S4`0ZHM70:N5A@2ZQe40ZHI>0:N4C02VPdT0YXA70:R6A`2ZR4P0ZhU90:Z6BP2/R4`0[XY>0080[h]?
00L0[XY>0:b8C02ZQTX0ZXY=0:V9C02XR4/0YXI90080YHE800/0YXI90:R8B`2YOeD0YgeC0:ImD@2U
OD`0YWi:0:Z3BP2^Qd`0/H]=0:J5@0030:N6@@030:R7@P2YR4<0ZHQ30080ZXU4102RPTL06P2OOd@0
W7a109Ui?P2FMS/0W7Pj09Ue=`2FM3D0UWLg09Uk>`2JOSd0V7`k09=j>02HNSh0VWa009in@@2RP440
XX100:9o?@2RO3/0X7/g0:9l?P2PNS`0VWHh09Id=@2CLC80T74a0P2?LC400`2BMC/0SW4g08U/<P02
08EX;P0O08Q[<@2<KcD0T7<i09Mh>02KO3`0WWlo0:21@@2QPT80Y8E50:^<C02aTU80ZI5C09Z2A02C
ND00W7i80:61D02MO4l0WgaD0:F2FP2RQe00XhQA0:B9DP2URU<0Y8UB0::7D02PQDh0WhA=0:26C@2O
QD`0W89909Z0A`0209UoAP0309Z0A`2KPDP0V7i500L0V7i500T0TgY109Ak@P2FOD@0Ugi509ImA02E
O4<0TWU0095h?`2>Lc`00`2?M3d01`2>Lc`0Rg0i08U^=`27K3D0Rg8j08Ya>@28KcL00P27KSH0;@28
KcL0RW4i08]b>P2BKS`0U7=009ajBP2UQEH0[XmQ0;JIK@2lXG@0`JIk0<>WO`32YWh0_j=k0;VMM@2e
VG40]YYb0;bPN033Ygl0`jR;0<J[SP3;/IH0dKVO0=BnYP3G`j/0fLF]0=S6/03C]Y@0c[:=0<BWO`2f
VV/0Z8YF09Uj@@2>KS40R6TY089^>@1mJC@0NFDb07QT<P1jICH0NfHi07UT=`1fHCH0N6<f07EP<`02
071K<00M06]E;01WDBX0IDlZ06A>:@1TCB/0HT/Y05m;:P1LB2L0F4DU05508P1;?1l0ACLL048d6@0h
<b00=c8O03Ha7P0e<1d0<bhK034/6@0`:aP0;bXG030]700^:a`0:bPI02TU6@0X91T0:BDL02XU7`0[
9R00100/:1d402dY7P<0;2HJ0P0[9AT302XT60P09R8I00@0:2@H02LS5`0W8aL09b<G0P0V8QH202DQ
5@0402DR7@0T8A`0924L02<P6`808QlJ0P0Q7QT3024Q5`808R8H0`0S8aT0100X8A/0:B8L02TR700Y
8Q`202XS7@80:b@N400Z9Q/0100]9aT0;RPJ02hX6P0^:1X202lY6`80<2XL00/0=BPO03<V7@0b9A`0
<B@K038U700d9ah0=RTP03P[8P0e9aX0=RPK03PZ7@0203X/7`0303PZ7@0g:A`0=BLJ00<0@34J0P11
<Q/3048c700@044e6`13=A/0ASHM04Pf7P1==b00DCHQ05@h8`1F=b<0E3XO05<i7P1A=a`0D3HK054g
701C>Ah0EC/P05Hl8@T0GChO00@0H48P06538@1SAB<0IDLU0P1VB2H206E79@0806A5:01R@bH0H44T
05m08`1N?b80Gd0S06529@1R@bH305]19PD0G48W00X0FT4R05a18`1N@bD0HD@V06=49`1T@RH0I44U
06=0901TABP0IDHY0P1VAbX01@1UART0Hd@W0611901N?b80HD8U0080H44T00<0Gd0S05ho8P1M?R40
0P1L?B0206A3800406I58P1XAb@0JTTV06a;:080KTdZ00H0JD`R06a<8`1]CB@0L4lV07AA:@1hDR/2
07]D;@0407=>901eD2H0N5<Y07]F;080OEP^0P1lEbd207aE;P0707YD;@1gE2`0ME@[07=C:P1bDRT0
Ke8X07=@:P0207AA:`0307EB;01fDbd0MU<]0080Me@^0`1hEB/207UF;0<0NUL]0P1jES8207UE<@0<
07QD<01gDbl0Me<_07IB;P1kER`0O5L]07iI;`1oFS00PE`b089M<`23GS@0Q5le0P23GS402@25H3<0
QV4d08QS=P2:ICP0RfHi08aW>P2>JSX0SFTi08YV=P0208UU=@0608YV=P2;IcL0SFTi08mU<`2@IS@0
TfTg0P2DJSP00`2BJ3H0SfDc08eS<@0208YT<`0408]U=02<ISD0SFLf08eW=P80SVPg00@0TVTe095X
=02AJ3@0TFPd0`2@Ic<208mV<P0508]R;P2=I300T6Lc09=Z=P2FKCT00`2GKSX209=Y=`0409AZ>02F
K3X0Ufdk09U_?@80VW0n0P2MM4003P2LLcl0WGA009mf@P2RNDD0YGa80:ImB@2NNTX0W7Q809]gA`2J
MTH0VgM709ahB02ONd/0X7a<0P2PODD00`2PODL0X7a80:1lBP020:1lC0030:1kCP2NNTX0WWY:0080
WGU90`2LN4P02@2KMdL0UG8l09Qe?`2LND<0X7e70:5nB02PODL0WW]509ai@`0809ihB@P0Wg]700H0
VgM309ahA02MNDD0WWY60:1lB02QODT20:=oB`060:5lA`2RODP0XWe80:=nB@2TOdX0YH1;0P2VPD`0
0`2UPTX0YX=;0:N4C0020:N4C0030:F2BP2TPDT0XWm70080XWi>0P2QODd0102SOdl0YX9B0:R4E02Z
QUH20:R2D`090:R4E02VQ5@0Y8AC0:22D02NP4h0VWi<0:F1C@2SOd/0X7a80080WWY600<0XGe90:F1
C@2WPdl00`2SOTX20:9mB@<0XGa80P2TOdP20:=nA`0<0:AoB02VPDX0Z8=<0:Z5CP2TP4`0YH5=0:J2
CP2XQ500ZXIB0:^7D`2/R5@0[HUE0P2[R5800`2/RE<0[HYD0:j;E@020:n<EP050;2=E`2aSUP0]I5Q
0;JBHP2hU6@00P2iUFD00`2hU6@0]Y9R0;FAH@020;B@G0040;FAG@2fTUh0]i=O0;VEH@80^YIR0P2l
UfX00`2mV6/0_YU/0;nJK@020<2KKP030<6LK`2nVF`0_iY]0080_iY]0P30Vfh20<6LK`P0_Ya^00/0
_iab0;jKL@2lVFl0^iQ^0;ZGK@2kV6h0_9U_0;fJL02oWFl0_I]]0;^IJ`030;VGJ@030;^IJ`2lVV`0
_I]]0080_I]]0`2lVV`20;^IJ`<0_9Y/0P2kVF/;0;ZHJPP0^YMa0`2gUFD20;JDI0<0]I=S0`2hU6@2
0;NCH`<0]Y9R202dT6020;F?GP0:0;B>G@2bS5/0/H]J0;2:F@2_REP0[XQG0;>?F`2aSET0[h]G0:f9
E@<0[8QD00@0[HUE0:^5E02[QE@0ZhIB0P2[QU400`2/Qe00[8Q>0:b8CP030:R5B`80ZHI<0`2ZQdd9
0:N3C`030:AoBP2VPD`0Z8=>0080ZXE@00H0ZHA?0:R3CP2WPTd0Z8A:0:N3B@2VPDX20:F0B`030:J1
C@2WPE00Z89A00P0ZXIB0P2/RUX30:f;F`<0[XaL00P0[hYM0:n;F`2^RUX0[HUG0:b8E02[R580ZhQ@
0:Z7C`80[XQG00@0[HMF0:b6E@2[QE@0ZXAC0P2XPU40102^RE@0[HQC0:f8D`2]R5<30:b7DP070:^6
D@2/Qe80[8MB0:^6D@2ZQE00ZHA?0:R3CP020:N2C@P0XWe80`2SOTT[ooooo`00:_ooool20:IkA004
0:IkAP2UNTL0YGY70:EiB080Y7Q900<0Ygi:0:ImB@2UO4P00P2TNdL00`2UO4P0Ygi:0:QoB`080:Aj
B0<0YWe90P2WOTX30:QoB`P0ZH1<202ZQE400`2ZP4h0Zh5?0:f3D@030:n5D`030:j4DP2]Pe40[H=A
0080[H=A0P2/PU030:^1C`<0ZGm=0`2XOT`20:MmB`040:F0C02TOd/0XGa809mjAP<0WGQ40P2NNDD2
09Qc?`80Ug8n00X0UW4m09E`?02EL3`0U6lk09=]@02BK3l0TF/n091Z?@2?JC`0SFLj0P2<IST208UT
>P0408QS>@27HSP0QF0f08AO=@80Pehd00/0PEhf081M=@1nFc<0O5Ta07YG;`1hEBd0Me@/07IC:`1^
DBT0Ke8Z075D;00307=F;P0@079E;@1aE2`0Le</07AD;@1eEBh0MeL`07UI<P1jFS<0O5`e07eM=P1n
GC80Oehc085N=025H3H0Qf8h08YS>P80SV@l0P2BIcX02@2CJ3/0UFXm09I[?P2GK3l0V6e009U^@@2H
KS`0VFlm09Y`?P0209]a?`0309U_?@2GKC/0UV`j0080Ug520`2FL44309E_@0<0TV`m0`2AJc`2091Z
>`80TF`h0`2@JcL308mZ=P80T6Xk00@0SfTj08iX>@2=IcP0S6Hg0P2;ICH@08aV=`P0R6Pi0`2?I3L2
08iS=P<0SF8e00H0Sf@a08iT<P2=Hc40S6@c08US=028HcH208ES=PT0RV@g2@28HS<01`2;ICH0SFLh
08]U=P26H340Ped^08EO<028HS<00`25GSD208IO=P<0Qf0g00P0Peha08AO<P25H3<0QV4d08EP<`24
Gc80PUd`085L;`80Qeh`00@0QEl`08AP<024H300PV0`0P21HC04085O<@80PV0b0P23HC<208MS<`06
08QT=02:ISH0S6Ph08eY>@2>JSX0Sf/k0`2;IcL208aX>0<0SFTi0P2=Jc/308aZ>P<0RfTi00<0S6Xj
08e[>`2?KCd00`2AKcl208m]?@08095]?@2@KSh0TFlo091`?`2?LCl0Rflm08Q^>`27KCX208]_?`0T
08Y^?P29KCd0Qf/k08AX>020I3@0OV8b07eP=01hGC00MEX_079I<01aFS40KUPa06EB:P1PC2L0G4TY
05M6:01A@RD0B3`R040h8@0j=B40=S<P03@c8@0];R00:b`N02TZ700X:A/09bPJ02PY6`0Y:Q`0:R/M
02HZ6`0V:Q`09BTK02<V6`0R9A`082<L0P0O8A`8020S6PP08RDL2@0P8a`2024R6P03028S6`0S91`0
92DM00809BHN00T09RLO02HY800U:1d09RPM02PX700/:Qd0;b`M038_7P0f<2000P0m=B0403hf8@80
?cLR00P0ASHV040c8`0f;A`0;bTI02LX600V:Q/09BdN02D`80P0<B/M0P0a;Ql0100`;Ah0;b`M02l/
7@0^:a`202dZ6`0602h_7`0/;Ad0:R/M02LW6`0V9Q`09BDM0P0V9B0802DU6`808b@N00@08R<M024R
700Q8Q`0824K0P0O81X0800N7Q808B4I02<R800T7b<0920Q02TU700`;AX0=cDL05Pn6@1NA1l0I4XU
06E;9P1RB2<0HDLR06A:9@1XCRT0Of<k08e`AP2EMTP0UG=30:5mB@2`Re@0[HA<09Yb=`1MC3X0AcPU
038V5P0]9AX0:bPO02LX8P0S:2@09B/Y0`0V9R@00`0U9B<092@R02@T8P0202<S8@0802HW8P0U9R40
92DO02<T700T9Q/09BLJ02LY700X:Q`202XZ800K02/[8@0/;280;BdS02h^900_;bD0<30V02/[8`0Z
:R80:2PP02LW7`0V9Qh09bLO02PX800Y:B409R/W02LY9P0U9b809RLQ02TY8@0_;2<0=30W03Lc:011
=2@0@CDU044f9010>2<0@3PQ0080@3XP0P10>ah03018=R00BSPR04hi901@?2@0DS`U054k8`1A>B40
D3PN04Tl:@18>bP0ASTV04@g9080@cHS0100A3LT04Dh9@1:>R<0CCdV04lo:01>?RL0BSXS04Ti8P1;
>b@0CShW04`n8`1=?b@0CT0U04m19P1@@RL0DT@Y0P1CABX305A09`0305E1:01F@RT0ET8Y0080Ed<Z
00<0DD0V05=2:01EA2X00`1FAB/02P1D@bT0Dd8X05U3;01I@b`0ET8Z05=1:@1A?bL0CShU04`n901;
?B<204`j8P80BcTQ00D0C3XR04hl901A?bL0DT0X0593900205939P0305519`1A@BP0D40Y0080D3l[
201A@BP01P1EAB`0Dd<Z0510:@1=?BH0BSTU04Th9P80BCPX0200CSTX050k:P1A?2T0CcXU04di8@1?
>b80ET8Y05a8;@1JBb@0DT4S04Ph8@14<R@0ACDV04Lh9@15>Qh0@cTF05Hh<01@>bX0BChR04=07@12
@R00AT0V04/n;P1@?3D0DCl[04lm:@1<>R@0BSPP04/j801>?B40DD0T05A39@80EdLU00T0EdPW05E8
:01AARP0CT<W04Y19019?b@0ASh[04Dm:P13>bP00`11>BH00`12>RL0@c/X04Tn8P0304Xo8`80Bd0T
0P1<@BD02018?2@0C40X04i2:P1=@BT0BShV04Tm9@1<@2P0Cd<[0P1B@b`0301A@R/0DT8Y05=2:01E
A2P0FTLY05e8:@1OBR/0IDPX06M::P1[CR`0Ke<^07=G<080METa02T0MU/`07=Q>@1dHSX0MV@l07UW
?`1lJT80OVa4081^AP21KdL0QFdo08I^@026L440Qg9308QfAP2:NTT0S7a;08anC@2?MdL0T7Q809=k
B`2FOTh0VH5A09b4E02OQeL0X8QH09j:E@2ORUD0WhU@0:B7C`2WQd`0[HU;0;::C02eS4`0^9=30;RC
A@2jUDL0_9I;0;jHC`30VU<0`Y]F0<>LE`020<:QG00S0;nPG@2mWUh0^YaN0;RIH02eV600/iIN0;JF
F`2eUEX0/Y9G0;2@E@2/S540ZXY?0:N7C02VQT/0Y8A90:J6B`2YQT`0[8Q>0:j7CP2^QDd0[HA<0:f2
B`2aPe40[h5?0:eoB`2/OdH0[H150;24A@2dR4L0]h]:0;R>AP2jT4P0_99:0;nEC@31Udl00`32V500
2035VE80ai]D0<NKE033Ue00_Y9;0;^?B02mTDX0`9A=202eTdT04P2cTE40]99B0;BBDP2cTE40/Hm?
0:j<C02[RDT0ZHM70:R5C`2WQ4`0YX=;0:F2B02UPdH0YXA50:R6AP2YQdL0ZXI:0:^7B`@0[8Q<0180
ZhM;0:Z6BP2YRD`0Z8Q;0:F5B02SPdH0XH540:20@`2QPD@0XX950:EmC02UODX0YGe90:EnA`2WP4D0
ZH=50:^5AP2/QTD40:R7A0030:V8A@2ZRDH0ZXU60080ZhY70P2TQ4T03P2SPdP0XX9709moA02LO440
V7Pm09If>`2KMcT0V7@f09Ec=02FMcL0VW`l09]o?P2IOC`0UG`j0P2JO4004@2MOD00X7ho0:1n?P2Q
OS`0Xgdl0:9m>@2SOCl0X7Xl09]g>@2FM3D0U78c095b<P2?LC40T78b099e>`2?LSP0RVdc0080QVT_
00H0RF`b08e`=P2@LcT0UgPh09]l?02OP4020:21@@0H0:B5A@2[S4`0/I9B0:fDE02NQ4L0UWa109]m
A`2OOdh0W7]>09elD@2UPUX0XHI?0::7D02SR540Y8UB0:>8D@2QQTl0WhA=09j3C02PQTd0WhE<09b2
B@2JP4L0VGm60P2JP4L00`2KPDP0V7i509QnA@0609QnA@0809Ak@P2EO4<0UWe409MnA@2FOD@0UGa3
09=j@@2AN3l208md?@80T7Dn00L0SW<l08aa>P29KSL0R6df08]b>P2:LCT0R6lg0080Qfhf00/0R6lg
08Ya>@2;LSX0TVhl09Ed@@2LNTX0YHEF0:j?H@2fVFd0_J9e0<6VN`020<:VOP0M0;nSN`2iWGD0]9Q`
0;FIL@2kWgL0`JEm0<:WR@35ZXd0b[6C0<ngV`3C_Z<0e/:Y0=S4[03GaJd0f;jK0=FiU03;[hL0_Z5e
0;2BH02RPd`0UWHk08m_<P23L3P0OVXe07UU<01iIC80NfLe07aW>01jICP00P1hHcH05P1eH3<0LE`a
075L<@1/Eb`0J58Y06I@:@1UCbX0I4hY06=<:P1RBbT0GTXY05U69P1B@B<0C3dP04Lh6`13=AX0>S<Q
03Tb800h<Al0=RlM03D^700c;1X2038[6@08034^7@0`;A`0;BXK02/W6`0Z9Q/0:bLN02`X7`0/9b46
02dY7P80;RXO0`0/9QX202/U6@<0:R@H200W8aX202PT60809b<G0`0V8QH00`0U8AD09B8M02DR7@02
02@Q700402<P6`0R7aX08QlJ028O6P808B4G0P0R8QP302<S6@0402@T6P0Y8QX0:B8J02TR6P80:R<K
0`0[91`@02/W70<0;bLJ0P0`:1/3034Y700;03HZ7P0e:Ad0<bLK038V6P0c9a/0=2PL03HZ7P0g:al0
=BLJ03HX6`0h:Qd00`0j;1l00`0h:Qd0=bTL040a6P02040a6P80@C8K0`12<a`01P13=A/0A3HL04Hf
7@1:=Qh0CCLP058g8P80E3PS00<0E3XO05<i7P1A=a`00P1A=a`00`1C>Ah0EC/P05Hl8@0305`m7P<0
GChO0`1N?b00101Q@b40HT@R06A6901VB2H206M99`80ITPV00<0IdP[06I7:P1TABP00P1SA2L00`1T
ABP0IDHY06I7:P0305e29@D0GT<V00P0Fd8S05e2901OA2H0HTDW06A5:01U@bL0ID8V06A19@80I4DX
0`1VAbX00`1TABP0HT<V06529@0306=49`<0HT<V0P1Q@RD206I58P0406M68`1YB2D0JTTV06a;:080
KD`Y00H0JTdS06e=901^CRD0LE0W07AA:@1gDBX207YC;00407E@9P1gDRP0NE@Z07]F;080O5L]0P1k
ER`207]D;@0307YD;@1gE2`0MUD/0080M5@[00@0LUD[07AA:`1eDR`0ME8/0P1fDbd207MD;P0307QE
;`1hEB/0N5D[0080NEH/0`1jEbd0101kF2h0NUHb07UE<@1iEC4207QD<080Me<_00L0MU8^07aG;@1m
F2h0OUT_07mJ<021G380Pehd0080Q5le00/0Q5lb08EP<`26HC@0Qf8e08QS=P29I3L0RVDh08]V>@2?
JCX0SFLh08aV=`0208YT=@0308]U=P2=IcP0SVPi0080T6Hd00H0TFLe099X=P2BJ3H0TFLe091V=02?
IC<408aV=@<0SFLf00@0SVPg099Y=@2BJCD0TVTe0`2AJ3@3091W<`0508aS;`2>IC40TFPd09A[=`2F
KCT00P2GKSX02@2FKCT0TfTg09AZ>02EJcT0UV`j09Q^?02IKcd0VW0n09]a?`0209ed@080W7<o00L0
WWE10:1g@`2SNTH0Y7]709ijBP2MNDT0W7Q80080VgM700<0WGU909mkB`2PO4`00P2QOTH00`2QOTP0
XGe90:5mB`020:5mC@030:5lC`2ONd/0WWY:0080WWY:0P2MNDT209ahB00309Yg@@2MNT@0Wga60080
XGi800<0WW]509]h@P2IMT00202NN4T309mkA`D0X7a80P2MNDD0102NNTH0Wg]70:1lB02QODT20:9n
BP80XWe800<0Xgi90:AoBP2UP4/00P2VPD`02P2WPTd0YH9:0:J3B`2WQ4`0Z8E=0:N4C02VPd/0Y859
0:>0B02SOdl30:9nCP0?0:=oC`2VPU80Z8AD0:V5E@2XPU<0ZH=D0:R4E02VQ5@0Y8AC0:63D@2OPDl0
Vgm=0:J2CP2TP4`0XGe90080WWY600<0X7a80:=oB`2VPTh00`2SOTX30:9mB@80XGa8102TOdP02P2V
PDX0Z8=<0:^6C`2/Qe00Yh=?0:R4D02YQE40ZXIB0:b8E02^RUH20:n;E`80[HUE00<0[XYF0:n;E`2`
S5P00P2aSET01@2bSUX0/hmK0;JBHP2gTf<0^9AT0080^IEU00`0^9AT0;NCH`2fTV80/hmK0;B@G02e
TEd0]i=O0;RDH02jUV80^iMS0;bHI02lUfX20;fHJ`030;jIK02oVVd0`9]^0080`Ia_0`2oVVd20<2K
KP<0`Ia_202nW6h00`30WG<0_Y]a0;fJL0030;^HKP0:0;bIK`2mVW00_ie_0;fKK@2kVF/0^YQZ0;VG
J@2jV6X0^iU[0;bJK0<0_I]]0P2lVV`30;^IJ`80_9Y/0`2kVF/;0;ZHJPP0^YMa00@0^9IV0;NEI@2g
UFD0]iEU0P2fU6@20;FCH`<0^9AT0P2gTf<30;JBHPP0]91P0P2dSUd0102cSE`0/XaK0;:<F`2aReX2
0;2:F@040;>?F`2aSET0[h]G0:f9E@80[8QD0P2]RED20:^5E0040:^6DP2[QU40[8MB0:b7D080[8Q>
0P2XQD/30:V6C0<0ZXM=2@2WPdl00`2UP4/0YX5<0:R3CP020:Z5D0060:V4C`2XPdh0Yh9=0:R4BP2W
PdT0YX5:0P2UP4/00`2VPDd0Yh5@0:R2D@030:V5D@050:Z6DP2[Qe<0ZhMC0:^7D`2/R5@00P2/RUX3
0:f;F`<0[XaL00H0/8]N0:n;F`2_Re/0[XYH0:f9E@2/RE<20:^8D080[XQG00H0[HMF0:b6E@2[QE@0
ZXAC0:V3DP2XPU440:b7DPH0[HQC00@0[8MB0:^6D@2ZQE00ZHA?0P2XPdh20:F0B`80Y7m:0P2SOTT5
0:9mB2_ooooo000Zooooo`80Y7U200@0YGY50:EjA`2UNTL0YWY90P2VNT/00`2WOTX0YWe90:ElB002
0:AkA`030:ElB02VODT0Ygi:00P0YG]90P2VODT20:MnBP<0Z7m;00<0ZH1<0:Z1C@2ZPDd01P2ZPDd8
0:Z5D@030:^1C`2/PU00[H=A00<0[hEC00<0[XAB0:f3D@2^Q5800`2]Pe420:b2D080Zh5?0P2ZP4h2
0:UoC@<0Z7i<00D0Yge;0:F0C02TOd/0XGa809mjAP0309ehA080WWU50P2IM400102HLcl0Ug8n09Ia
?@2EL3`209A_>`80TF/n00H0T6Xm08iX>`2=IcX0S6Hi08]U>02:I3L308MR>080QV4g0`25H3H01P20
GCD0Oe`d07iK<`1lFC40NUL_07UF;P80Me@/00P0Ke8Z071C:`1bEBd0LeH^07AG;`1cERh0LUD]075D
;080LU8[00@0M5@]07IF;`1hF340NETb0P1kFc@0201mG340OUdb085N=025H3H0R6<i08aU?02@ISh0
TFLo0P2BIcX02@2CJ3/0UFXm09I[?P2GK3l0V6e009U^@@2HKS`0VFlm09Y`?P0209]a?`0409U_?@2G
KC/0UV`j09Ma@P<0UW110P2EKd0209A^?`80Tfdn0P2BK3d3095[?003091Z>`2AK3P0TF`h00<0T6/g
0`2?JSH2091Z>`0408mY>P2>J3T0SFLh08eW>080S6Hg0P2>J3T0102=IcP0S6Hg08aV=`2;ICH:08YT
=@P0RFLi00@0T6Dh08mT=`2?I3L0Sf@g0P2>HcH208eR=@0608mT<@2>I380SF<a08aT<`29Hc@0R6<f
0P25HcH908YT=`P0RV@e00P0RF<d08]U=P2<ISL0RV@e08IP<@25Gc00QV0a08QR<`80QEhe0P26GcH3
08MP=`0408QQ>023GS40Q5lb08EP<`80QV4d00<0Q5lb089M<021G2l00P27GS001025Gc00Q60`08AP
<022H302085Q<0<0PEla0P22H38308=Q<`0608IR<P27Hc<0R6@d08UU=@2:ISH0S6Ph0P2=JCT308YV
=P80RfLg0`2<J3P208]Y>@<0S6Xj102=Jc/0102>K3`0Sfdm091^?P2AKcl2091^?P0908m]?@2AKCd0
T6hn095_?`2@L3l0Sg4o08]_?@28KS/0Qfdj0080Rflo02@0RVhn08U]?@27Jc/0Q6Ph081T=01nHS80
OF0d07QM<01eFRl0LUT`075J<@1^F340IE8Z061<9`1LBBT0EdHX05529@18?280?cLP03Xe8@0e<Ql0
<c8P02d^800[;1h0:BXL02PY6`0W:1X0:2TK02TZ700Z:ad09RXK02HZ700U:A/08bHK028U700P8a`2
01lQ70P082<J200R9A`901lR6`808B8J0P0R8a/03@0S91`092DM02DV7P0U9Qh09bXQ02LZ7`0W:Ah0
:2PL02/Y700^:a`0<2dL03@^7P0l=1l00`0m=B0203hf8@80?cLR00P0@C@S03``800d:aX0;BLG02LU
5P0U9aT09B/M02P^80P0<R`N0P0a;Ql0100`;Ah0;b`M02l/7@0^:a`202dZ6`0802h_7`0/;Ad0:BXL
02LW6`0V9Q`09RHN02HU800W9R4802DU6`808b@N00@08R<M024R700Q8Q`0824K0P0O81X0800N81<0
8B4I02<R800U8B809R0P02dV700g<A/0?STL0655801XC2L0KU8]06Y>:@1SAb80HTHQ06a@:`1gFcH0
QVTo08mbAP2FN4H0VW]50:J5C`2`SEL0XGa808QR<@1>@C00?C4Q02hT600]9a/0;2TR02HW8@0R9b<0
92PW0P0V9R@302DU8`<092@R00P09RLR02DV8@0T9Al092DM02@V6`0V:1/0:2XM02T[7@P0:b/Q00<0
:RXR02TY8@0X:2000`0V9Qh202LW7`809RPS00d09RLQ02PX800]:R40<RhS03Lc:00l=RX0@3@T044e
9@11=R@0@SLS04<h8P14>R40AC/R0080AS`Q00/0CSXR054m9@1D@2P0Ed<[05I2:P1D@2P0DC/T04li
8P18>bP0AcXW04Hi9P0304@g900;04Dh9@16>BH0BSXS04hn9`1@@2T0CclX04/k901:>R<0CCdV0510
:@1??bD00`1@@2H01@1A@BL0DT8X0592:01B@RP0E40W00<0ED4X0`1F@RT02@1G@bX0E4<Y05E4:P1E
A2X0ETD[05E4:P1D@bT0Dd8X05919`0205Q2:`0805I2:P1B@2P0DClW04lo9P1=?bD0C3hT04hl901=
>b<204`j8P0504dk8`1??BD0DClW05=1:@1CA2D00P1B@bH00`1B@RP0DD4X0551:P02050o:`P0D40W
00H0E4@[0592:`1??bP0BcXV04Th9P18=bL204Pf:00X04/h:@1=>RT0CS/Z04`j9P1:>280BcTQ0550
9P1GAR`0FD/X05=49`1:>BD0AS@V04Le9`19>2@0BS`O04Xm6P1K?Rh0E3lZ04]09013@1l0@D0Q04Do
9@1;?Rd0DCdd04lm:@1>?2P0C3XT04/i8@1=?280D3lS05=29P1FABL0F4PW05M89`1FAbP0DdDX04i3
9`1:@2D0AChT04<l8P80A3`Y00@0@SXW044i9P11>BH0@CTV0P12>RL01018?280BCdS04Tm8`19?B<2
04Xn9080BclU00@0Ac/S04Xn9P1<@2P0BclW0P18?2@00`1;?bL0Cd<[0552:`020552:`0F0551:01B
@BL0Dd8V05M49P1JABH0G4LX06I9:@1XBb/0Jdh/06mC;P1bERl0METa07IJ<P1gG340Lf4i07AR>P1f
I3`0NFLo07aZ@P1oKDD0PW1808=aB@80R71401h0QVm308E`@`25LdD0R7M908akC@2=Oe00SgU:091j
B`2BO4d0U7i?09N1DP2IPe@0VhEF09b6E`2KQe80VhIA09b6C@2PQTd0YXQ<0:b:B`2bS4d0/he<0;FD
A`2fU4X0^9I<0;ZHD02lVU<0_IYF0;jKF@2oW5X20;nPG`060;jOG`2mWF00^YYO0;JFG@2aTUT0[i1I
0P2cTE@0102aSe80[he@0:j<C`2/RTd20:Z8B`0@0:J6B@2WQdX0ZhU<0:j:CP2`RDh0/HU>0;28C@2`
QT`0/HQ:0;27B@2_QTH0[hI40;69A02eSDL0^I590;bDC0@0_IE@00`0_YIA0<2HD`31VE@0`YYE0<NO
FP39XE`0bZ9M0<FMF02nUU40^I5<0;R@B`2jTTd80;>ABP0A0:n=CP2`STl0/8i?0;2>C`2_SDh0[H]<
0:^9BP2ZR4T0YH9<0:F2BP2TPDT0Xh160:>1A02SPD80Y8920:F3@`2ZQTP00P2YQDL20:R4AP80ZHE7
00@0ZXI80:V7B02WQDH0Y8930`2QOd020:1n?`090:5m?`2ROT00Y8510:J3@@2WQ400YhDn0:J4?@2U
Pc/0ZHM700@0ZXQ80`2[RDT07`2/RTX0Z8I90:R6B@2VQ4L0Y8950:5o@P2MNch0VWPk09Qf>@2JMSP0
Ug<e09Ec=02FMcL0VW`l09b0?`2KOch0UWdk09an@P2KOD40W7`o09il?@2NO3`0X7dk0:An?@2TOc/0
Xgdo0:5k?@2LN3X0V7Hg09Id=@2CM3@00P2ALc<00`2CMS`0T7<i08a_=@0208Q[<@0608Y]<`2>LCL0
TG@j09Qi>@2KO3`0Wh100P2PPD402`2TQDD0ZX];0;2AD@2bUUL0YXY;09]nA02JODD0VWa809UjB`2L
ODl0XX=G0080X8E>0`2RQe001`2PQDh0WhA=09f2B`2PQTd0WhE<09f3BP2KPDP00P2JP4L209^1B0P0
V7i50P2EO4<309ImA00409El@`2CNT40TWU0091e?P<0TGHo00L0Sg@m08eb>`2:KcP0RFhg08]b>P2:
LCT0RG0h0080R6lg00/0RG0h08Ya>@2;LSX0Tflm09Ed@@2MNd/0YXIG0:n@HP2gVVh0_Z=f0<:WO002
0<:VOP0P0;nSN`2iWGD0/iM_0;>GK`2hW7@0_J5i0<2UQ`33Z8X0b:nA0<feV@3A_:40e<2W0=O3ZP3G
aJd0g/FV0=_1X03B^9<0b:f20;ZNKP2]SeT0XH9909Uk?`27LS/0PF`e07aW<P1kIC<0OFLf07mY>P1m
IcP0Nf@h07US=01gHC8207=L<00C06mH;P1[E2/0J50Z06M?:@1VCRX0IDdY06=<:P1RBbT0GDTX05M4
901??R00BCXM04Hg6P0l=240>c<P03Xb7`0i<Ah0>30M03H^6`0203D]6P0603Ha7@0e<1d0<bhK034[
6`0`:Q`0<2XN0P0a:R08030Z7P<0;BLK0P0/9QX302/U6@P09b<J00@0:BDI02PT600X91P0:2@H0P0W
8aL202HR5P0402LR700V8A/09R4K02HQ6`<09B0J00@091lI028R600R8QP08R8H0P0S8aT302@T6P<0
:R<K0P0[91`302`U7A00;RPL0`0a9a/2038X70<0<bTM00<0>2`P03L[7`0e:Ad00`0d:1`01P0e:Ad0
=RXN03@W5`0f:AT0>2/K03X]7@@0>bhN0`12<Q/204<c70<0A3@M00H0ACDL04Hf7@18=Qh0BcLO04dg
801A>28205<h8`80DcTN0`1B>1d00`1C>Ah0EC/P05Hl8@0205Xk700505/l7@1L?Ah0G3dN05ho801O
@2400P1P@B80101RA280I4HT06I89P1XBRP206U;:@0506Q::01WBBL0JT//06U::`1XBBX00P1WB2T0
0`1XBBX0JDX[06Y;;00806539`0;05a48P1NA2<0H4HU06A79`1UARL0ITDV06I39@1U@R@0Hd@U06A5
9P1UARL00`1WB2T0101VAbP0IDHW06E69`1UARL306I7:0<0IdPY0`1YB2D206Y99P<0JdXW00/0K4lU
06m?9P1`D2L0LU4X07AA:@1gDBX0N54Z07UB:`1iE2X0NUD[07]F;00207aG;@0807]F;01jEB/0NE@Z
07YC;01kE2d0NU@]07QE;@1hEbh207MG;P0407II;`1gE2`0Me@/07MD;0<0N5D]0P1iERh207UF;080
NUL]0`1kF2h00`1lFBl0NEH`07UF<00207UF<080N5D_0P1gE2h207iI;`0707mJ<020Fc40PE`b08=N
=024GcD0QF0f08IQ=00208MR=@80R6<f0`29I3L00`2>J3T0SFLh08aV=`0208]U=P0508aV=`2=IcP0
SVPi095W=@2@IS@00`2?IC<0102@IS@0TFLe095W=@2?JSH308iY=@@0SFPd0`2CJSH3099Y=@<0TFPd
00D0SF@`08mV<P2AJ3@0U6/g09I]>@0209M^>P0709I]>@2DJSP0UF/i09I/>P2GKC/0V6hl09Y`?P02
09]a?`0309ie@@2MM400W7<o0080W7<o00<0WWE10:1g@`2QN4@00P2NNTX309eiB@0309ijBP2PO4`0
XGe=0080XWm700<0XWm90:9nBP2ROT`00P2ROTh00`2ROE00X7a<0:1lC00309mkB`<0WWY:00P0X7e7
0:5nB02ROdT0Xh1:0:5nB02NNdD0VWM109Qe?`P0WgU:0P2ONdL20:1lB0040:5mB@2ROTX0XWi:0:=o
B`P0XGe900H0XWe80:=nB@2SOTT0Y7m:0:F0B`2VPD`20:N2C@0:0:J3C@2WQ4h0Z8E?0:V6D02XQDl0
YhA>0:F2C02TPD/0YH5A0:B0D080Xgm?01@0Y81@0:J2DP2XQ5@0ZHEE0:R2D`2YPe@0ZHEE0:N5E@2U
QE@0XXAB0:22D02MPDl0Z8A@0:F1C@2ROTX0X7a809mkA`2PO4P0XWi:0:=oB`<0XWe91@2SOTX30:F0
B`0=0:J1C02XPdh0ZhIA0:n:E@2aS5L0[8QD0:f9E@2^RUH0[h]G0;2<F02aSET0/XiJ0;>?F`020;6=
F@030;:>FP2cSe/0]91L00<0]I5M00@0]Y9N0;NCH`2hU6@0^IEU0P2jUVH02`2iUFD0^9AT0;NCH`2c
Se/0]91L0;FAG@2gTel0^YIR0;bHI02mVFD0_YYV0080_IQ[00<0_YU/0;nJK@30Vfh00P31W6l01032
WG00`9]^0<2KKP30Vfh20<6LK`<0`Ye`202oWFl02`30WG<0_iab0;fJL02lVFl0^iQ^0;bIK`2mVW00
_Y]a0;nMK`2nW6h0_9Y/00<0^iU[0P2lVV`20;fKK@80_9Y/0`2kVF/00`2jV6X0_9Y/0;^IJ`020;^I
J`80^YQZ0P2iUfT80;ZHJPP0^YM_0`2hUVH20;NEI@<0]YAT0`2iUFD20;RDI0<0]i=S202eTF450;>>
FP<0/XeI00D0/hmK0;6=F@2_ReL0[HUE0:b8E0020:f9E@040:j:EP2/QUD0[8IE0:b7D`80[8MB00@0
[8M@0:b8CP2/R4h0Z8E=0`2YQTh20:Z7C`80ZhQ@2@2VPTh00`2VPD`0Yh9=0:R3CP030:Z5D080ZHA?
00<0ZHE;0:R4BP2WPT/00P2VPD`00`2WPTh0Z89A0:V3DP020:N3C`060:R4D02ZQU80ZhMC0:b8E02]
RED0[XYF0P2/RUX30:f;F`<0[XaL00d0/8]N0;2<G02_Re/0[XYH0:f9E@2/RE<0[8UA0:^8D02_RUH0
[XUE0:f8E02/Qe<0ZhIB00<0ZXEA00D0ZXE@0:^6D@2[QU40[8MB0:f8D`020:j9E0040:n:E@2^RE@0
[XUD0:f8D`80[8MB00@0ZhIA0:Z5D02ZQE00ZHA?0P2XPdh01@2VPD`0YH1;0:AoBP2SOTT0XWe800<0
XGa7:oooool002[ooooo0P2SN4402@2TND@0YGY70:IkB02WNdX0Yg]<0:QlC@2XOd/0Ygi:0:ElB003
0:AkA`80YWe9202UNdT30:MnBP<0Z7m;0P2YP4`80:Z1C@P0ZXEA0P2]Pe420:j4DP030:n5D`2^Q580
[XAB00<0[XAB0`2]Pe430:b2D0<0ZX1>0P2YOdd30:QnC0040:F0C02TOd/0XGa809mjAP<0WGQ40P2N
NDD209Ye@@0409Ud@02HLcl0UW4m09E`?080U6lk0P2@JSd01P2?JC`0SFLj08aV>@2;ICP0RV@g08US
=PP0QV4g0P1oG3@02@1nFc<0O5Ta07YG;`1iERh0N5D]07MD;01_DRX0L5<[079E;@0207AG;`0C07=F
;P1bEBd0LE@/075A:P1bDR/0Le</07EE;P1gEc00NETb07YJ<`1kFc@0O5/`07eL<@20GC<0QF0f08UT
>P2=ISd0TFLo099X@002099W>P0909=X>`2EJSd0UV/n09M/?`2HKD00VFi109Q^?02IKcd0VW0n0080
Vg4o00<0VFlm09M]>`2FK3X00`2FL44209E_@0<0U6ho0`2CKCh2099/?@<0TF/l0P2AK3P3091[=`<0
SfXf0P2@JS/208mY>P0408iX>@2=IcP0SFLh08eW>080SfTj00@0SVPi08eW>02;ICH0RV@e2P29Hc@8
08]V>@80T6Dh0`2?I3L308iS=P0608mT<@2>I380SF<a08aT<`29Hc@0R6<f0P25HcH908YT=`P0RfDf
00@0RF<d08YT=@2:I3D0RF<d1027HC8308IO=0<0Qf0e0P28HCH02024Gc80QF0c08IQ=027HSD0QV4d
08EP<`23GS40PE`_0P27GS001025Gc00Q60`08AP<022H302085Q<080PEla0P22H38208=Q<`80Q68d
00D0QV8b08MS<`27Hc<0R6@d08YV=P0208]W=`0308aX>029ICD0RFDe00<0RVHf0`2;IcL01@2:J3P0
RfTi08]Y>@2<JSX0SF/k0080SV`l00<0Sfdm08i/?02>K3`00P2?KCd4091^?P08095]?@2@KSh0TFlo
091`?`2?LCl0Rflm08Q^>`27KCX208]_?`0T08Y^?P29KCd0Qf/k08AX>020I3@0OV8b07eP=01hGC00
MEX_079I<01aFS40KUPa06EB:P1PC2L0G4TY05M6:01@@B@0Ac/Q03lg800i=200=C8O03<b800];R00
:b`N02TZ700X:A/09bPJ02PY6`0Y:Q`0:R/M02HZ6`0V:Q`09BTK02<V6`0R9A`082<L0P0O8A`8020S
6PP08RDL2@0O8Q/2020Q6@04024R6P0R8a/08b@L02@U7@809BHN00T0:2/R02LZ7`0W:Ah0:2PL02XX
6`0]:Q/0;b`K038/700k<ah00P0l=1l00`0m=B00?SHQ03hf8@0203lg8P0803/c800g;Qd0<BXH02TV
5@0V91D09RLI02PZ7@0Y;Al8038/7P80<BhO00@0<2dN02l/7@0_;1d0;R/L0P0]:Q/01P0];Qh0:b`L
02TZ700W9a/09RHL02HV7P809bHQ200V9Q`202<T7P04028S7@0Q8Q`08B8L020Q6`807b0J02007R0E
020Q6`0S8R009b4S02XR7`0c:Ad0?cDL04Pm7@1TB240KE4Z075E;P1ZCRL0Gd<L06557P1aEBh0PFDn
08i^A@2DMDL0VG]70:62B`2/SEH0Zh]H095`A@1dDB/0?cLZ03<[800Z8aT0:bLN02XZ8P0U9R008R@O
02@V8`H09BDS0P0T9280200W:2<09RLR02DV800U9Qh09BLL02LY700Y:ah0:bdO0P0];B<01`0/;280
:b/Q02XZ800Y:Al0:2PN02LW7@0Y:B400P0X:20202LW7`<09RHN0P0W:2801P0X:200;2TP030/8@0g
<2H0>cDY03hf:`80?cHU00D0@CHT044f8P14>280B3TR04/l9@0204`n900805Hn901H@2P0FT@/05a6
;`1JARh0ET4/04lm9`1<>R@304Hi9P0304Dh9@16>BH0ASTV0080AcXW00P0BSXS04hn9`1@@2T0CclX
04`l9@1;>b@0CShW0551:PP0DT4W201F@RT305I5:`0305E4:P1D@bT0Dd8X0080DT4W00H0Ed4Z05I0
:@1E@BT0DT0X054o9`1@@2L204i09P03050n9P1??BD0CS`T0080CS`T00T0D3hV0590:01C@BT0Dd@U
05=49`1B@bH0DT8X0592:@1A@BX00P1A@2`805109`060552:`1?@2T0C3dX04Tj9`16=RH0ACDV0P15
=BP0:017=BL0BSTY04/j:P19>2H0AcHR04Ph8@1=?B@0DT8Y05E;:01@ABT0Bc`Y04Lg:018=RP0Bc/T
05107`1CA1d0GD8W05A18`18?Al0?S/J03Xi6`0o>B40ASTX04dj;01>?2P0CC/W04`j901=>b<0CchT
05919@1EA2P0EdHX05M8:`1EAbX0DdDZ04i2:019?bH0@c/T03li8@0n>282048j9`H0@CTV0P17>b<3
04Pl90<0BCdU00@0ACTS04Pl9P1:?RP0B3`V0P16>R@00`1:?RP0CT8/0511:P020511:P0>05109`1@
?bD0DD0T05E2901H@b@0FTDV06M::P1XBb/0Jdh/06mC;P1bERl0METa07MK<`1hGC8207AR>P0V07IT
?01hISh0NfU107i/A022L4P0Q79:08YaB028KdH0QFi4089]@P22Kd@0QWE908]jCP2<OU40SWU:08mj
B`2@Nd`0TWe>09=nC`2EP540UX5B09N2D`2GPTd0V85=09V3BP2NQ4/0XhI:0:R:BP2]STd0/I1=0;>E
C@2dUTh0]YQB0;RIEP2iVUT0^Y]K0;VJFP2iVE`20;VMGP070;ZLH02hVUh0]YIK0;:BF@2`SED0[HYB
0;6=C`020;2<CP0=0:n;C@2^RT`0[HU;0:f9B`2/R4X0Z8U90:V:BP2]Rd`0/8a>0;>=C`2dS4l0/h]>
0;>9C@040;B>A@070;NAAP2jU4T0_IM<0<2JC`31VUT0`9UH0;fFE@020;bEE00;0;jGEP31VUT0`Y]J
0;jHE`31VeX0`YaK0;nIF02hTU40/he<0;:<B`2cSD`0202_S4X03P2_SE00[Xa?0:f;CP2/RTd0ZXQ;
0:R6B@2WQDP0YXA70:>0BP2SP4P0XWm70:5nA02QOd80XGm00P2QOcl00`2XQDD0YhA40:J3@`020:F2
@P080:J3@`2WQ4@0Z8E50:R5A@2UPT80XGhn0:9o?`2TPD420:J3@`090:F2@P2RPCX0YH@m0:V9@02[
Rd80[8a30:Z:?`2VQS/0Y8@i00T0ZhU900L0[8Q:0:Z6B02XQ4H0YH530:9n@02ONcd0W7Pj0080VWHh
0280Ug<e09Ec=02FMcL0Vgdm09f1@02LP3l0Ughl09j0A02LOT80Vg/n09aj>`2LNSX0Wg`j0:An?@2V
PCd0Xgdo0:9l?P2NNS`0VgTj09Ug>02EMSH0TgDe099d=02DMcd0TG@j08ia=`2;KS@0RVdc08a_=@2?
LSP0TWDk09Qi>@2LOCd0Wh100P2PPD404`2SQ4@0ZX];0:n@D02fUeL0[Hi>0::4B02KO4D0UgU309Ij
B02JOTl0Wh=D09j3C02OQ4d0XHI?0::7D02QQTl0X8E>09n4C@2NPd`00P2OQD`00`2NQ4/0WH=:09b2
B@0309^1B0P0VGm6102FOD@209El@`80U7]200/0TGHo099g@02BMd00TWM0095f?`2>Lc`0S74j08Y_
>02<Lc/0Rg8j08U`>00208Q_=`0;08U`>02;LSX0S7<k09A`?P2FMD80WWa<0:J6E`2`TF<0^9]_0;jS
MP32Yg`00P33Ygl08030Y7`0^Iee0;>GK`2aUFd0]IUa0;ZNMP2nY8<0`JN60<F/S@3:/i@0c[VL0=:n
X`3F`ZL0e/F[0>36Z`3Ma:D0fKnL0<nfSP33Z7/0]IUW0:Z<EP2RQDd0SGLn08Ma>021JS@0OfPd081Y
=`22JSX0PFTi07mW>@1lI3@0NV8b0P1gGc403@1cFbl0KeH]06aC:`1ZDBT0JDlZ06Q>:@1WCb/0IThZ
069;:@1LB2L0E44Q04`k7@19>1X00P0m=B00100l=1l0>c<N03Xb7@0i<A`203P`6`80>C<M00@0>34N
03H_700e;Q`0=BhN0P0d;1l403<[7P@0<RXM0P0^:1`302dW6`<0;2HJ200X91/402TU6@80:2@H0P0W
8aL602TR6P80:24I0`0S8aT202@T6P<09BDK00@0:b@J02`U6`0/9A/0;2DK0P0]9Q`202hW7@P0<BTL
200`:1/0100b:1`0<bTM03<Y7@0c:Ad203@Z7P80=B/O00@0>BdO03P/7P0g:ad0=b/M100f:Q`0200e
:1L0=RTH03P[6P0j;A`0?2lN03d`7`0n<B00?c8Q0`14<Q`304Dc7@80AS@N00D0AcDM04Xf7P1:=Qh0
BcLO04hh8@0204li8P03050j8`1C>Ah0DcTN0080DcTN0P1D>Ql205Dk800305Pi6P1I>Q/0FS/L0080
G3dN00P0GSlP06118P1Q@R<0HT<T06=58`1UAbD0IdTW06U;:@80JT`Z00@0JD/Y06Q::01YBbT0JD/Y
0P1XBRP206U;:@80JT`Z101TAbT406=6:00805i68P1PAR<0HTPU06E89P1WBBL0J4LV06Q59@1WA2@2
06A6900406I89P1WBBL0J4XX06U;:@80JT`Z00D0I4HT06E79@1UAbD0ITPV06M99`0206Q::00306U;
:@1/BbP0K4/X00@0JdXW0P1ZBBH01P1^DBL0L50W075A:01bDBP0M54Y07I@:@80N54Z0`1mF2h207aG
;@0;07]F;01jEB/0NE@Z07YC;01kE2d0NeD^07YG;`1jFC00NUXa07]K<P1iG380201jEbd307]H;P<0
O5T_0P1mFS0407YG;`@0NEH^1020Fc401021G380Pehd08EP=P26HCL808QS=P0408mV>02>ICL0SVDg
08iU=`80SfHh0P2@IcT00`2BJ3H0TFLe08mU<`0208eS<@0308mU<`2BJ3H0U6Xh0080TF`g00@0T6/f
08mZ=@2?JSD0SVTd0P2=J3<409A[=`<0TfXf0P2BJCD01P2>IC40T6Lc099Y=@2EK3P0UVdi09M^>P80
UVdi0P2EJcT0102FK3X0V6hl09U_?@2KLCl209ab@00309mf@P2NMD40W7<o0080Vg8n00<0WGA009ie
@@2OMT801@2ONd/00`2PO4`0XGe=0:5mC@020:>0B0030:>0BP2SOd/0Xgm=0080Xgm?00<0XgiA0:9n
CP2ROTh00P2QODd30:1lC00309mkB`2QOTP0XWm90080Xh1:00@0XWm90:1mA`2NNdD0W7U3202QNd`0
1@2ONdL0X7a80:5mB@2ROTX0Xgm;0080Y81<00@0YH5=0:B0C02TP4`0Xgm;0P2ROTX0102QODT0X7a8
0:1lB02SOTT20:AoBP030:F0B`2VPD`0Yh9=0080Z8=>00<0Z8A@0:V5D@2ZQU800P2ZQU801P2XQ500
Yh=?0:F1C@2WPe<0YX9B0:F1D@80Y81@00l0YX9B0:N3D`2YQED0ZH=D0:Z4E@2ZQUH0Z8IF0:N7EP2T
QU@0XXAB09n3D@2YQE40Yh=?0:F1C@2ROTX00`2QODT01@2ROTX0Xgi:0:=nBP2SOTX0Y7m;0080YH1<
0P2VPDd30:N2CP0;0:V4D02/Qe<0[hYF0;>>FP2eT5`0/HeI0;:>FP2cSe/0]91L0;FAG@2fTUh00P2g
Tel00`2eTEl0]Y9P0;JBH0020;NCH@<0^9AR00@0^IES0;RDI02iUFD0^iMW0P2lV6P02`2kUfL0^IEU
0;RDI02cSe/0]91L0;JBGP2iUF40^iMS0;fII@2oVfL0`9aX0080_YU/00<0_iY]0<2KKP31W6l00P32
WG000`33WW40`Ia_0<:ML0020<:ML080`iia0P34Wg880<6OL@090<6NM030WG<0_Y]a0;fJL02lVFl0
_IY`0;jKL@2oW780_ie_0080_Ya^00<0_I]]0;bJK02lVV`01@2lVV`30;^IJ`80^YQZ0`2kVF/20;ZH
JP<0^IMY202jV6X80;ZGK@<0^IMW0P2hUVH30;NEI@80^YIV0`2iUFD30;RDI0P0]I5Q00@0/XeH0;>>
F@2cSUT0/hiI0`2dSeX01@2eT5/0/XiJ0;6=F@2_ReL0[XYF0080[HUE00D0[XYF0:n;E`2]QeH0[HMF
0:f8E0020:b7DP030:b7D02/R4h0ZhM=00<0ZHI@0P2ZQe430:^8DPT0YX9>0P2XPdh00`2YQ4l0ZXE@
0:Z5D0030:Z5D0030:Z6C02YQD/0Z8=<0080YX5<00<0Z8=?0:V3DP2ZQ5<00P2VPTh01P2XQ500ZHEA
0:^7D`2]RED0[XYF0:n;E`80[8YJ0`2]Re/30:j<G00;0;6<G`2aSEd0/8aL0:n;F@2^RUH0[HYD0:f:
DP2/RE40[hYE0:j9E02]R5<0102[QU402@2/Qe80ZHA?0:Z5D02[QU40[8MB0:f8D`2^RE@0[hYE0;2;
EP020:n:E@80[XUD00@0[HQC0:b7DP2[QU40ZhIA0P2/Qe801P2ZQE00Z8=>0:N2C@2UP4/0Y7m:0:=n
B@<0X7]6:oooool002[ooooo0P2SN4403P2TND@0YGY70:IkB02WNdX0Yg]<0:QlC@2YP4`0Z7m;0:Im
B@2TNdL0XgY60:AkA`2UO4P0YWe9202VO4X20:MnBP<0Z7m;0`2YP4`80:^2CPP0ZXEA0`2_QE<40:j4
DP040:n5D`2^Q580[XAB0:j4DP<0[H=A0P2/PU020:^1C`80ZX1>0P2YOdd20:QnC0040:F0C02TOd/0
XGa809mjAP<0WGQ40P2NNDD0202LMd<0VgI209Ye@@2HLcl0Ug8n09E`?02DKc/0Tfhj0P2@JSd01P2?
JC`0SFLj08aV>@2;ICP0RV@g08US=PP0QV4g00H0Oe`d07iK<`1mFS80O5Ta07]H<01iERh207QE;@08
06mB:P1aE2`0LeH^07AG;`1eF300M5L_07=F;P1bEBd2079B:`0407AD;@1eEBh0MeL`07UI<P80Ne/d
00P0O5/`07eL<@21GS@0QV4g08UT>P2=ISd0TVQ009=Y@@80TVLj00T0TfPk09EZ?@2FJch0Uf`o09Q]
@02IKT40V6hl09U_?@2JL3h00P2KLCl00`2IKcd0Ufdk09I/>P0209I`@@80UFm00P2DKSl209=]?P80
U6ho0P2CKCh2099/?@80TF/l0P2AK3P3091[=`<0SfXf00<0T6Xk08mY>P2?JCX00P2?JCX308iX>@80
SfTj00@0SVPi08eW>02;ICH0RV@e2P29Hc@808]V>@<0T6Dh0`2?I3L208iS=P0608mT<@2>I380SF<a
08aT<`29Hc@0R6<f0P25HcH908YT=`P0S6Hg00@0RV@e08US=028HS<0R68c0P29Hc@01028HS<0Qf4b
08IP<`26H3<308MQ=0<0R68e00<0Q5lb08EP<`26HC@00P27HSD00`25H3<0Peha089M<00208MN<004
08EO<024H300Q60`089P<080PF4`0`22H38208=Q<`<0Q68d00D0Qf<c08QT=028I3@0RFDe08YV=P03
08]W=`0408UU=@2:ISH0RVHf08YV=P80RfLg0P2<J3P208]Y>@0408aZ>P2=Jc/0SF/k08i/?080Sfdm
0`2>K3`208m]?@80T6hn00T0TFlo095]?@2@KSh0TFlo091`?`2?LCl0Rflm08Q^>`27KCX00P2;Kcl0
902:KSh0RFdm08M[>`24J3P0P6@d07iR<P1mH3@0N5d`07EJ;`1bFC00LEXa06iH<@1UDRX0H4`W05]8
:01FABL0D44T04Lk8@0o=b00>C@P03@a7P0b<Al0;BhP02//7P0Y:Q`0:2TK02LX6P0X:A/0:BXL02X[
7@0V:Q/09RXL02DY6`0S9Q/08RDL020S70807b4L200P8aX8024T6`T07b8K0P0P8AT0100Q8QX08R<K
028S6`0S91`202@U7@0802P[8P0W:Ql09bTN02LW6`0Z:1/0;2TJ02h[6P0a:a/203Xb7@0>03/c7P0l
=1l0?CDP03hf8@0o=b80@3PS03Lb7P0d;a`0;RTF02PU500V91D0:2HI02XZ7P0/;20803<]7`80<BhO
00@0<2dN02l/7@0_;1d0;R/L0P0]:Q/0200/;Ad0:b`L02TZ700W9a/09RHL02HV7P0W9R40:2LR200V
9Q`202<T7P04028S7@0Q8Q`08B8L020Q6`807b0J02007B0G020Q700T8b40:28R02lT800j;Ad0AcTN
05947`1VBB40KU4Y075D;01YC2@0Gd8J06=67P1fFC40R6]309AcB02HN4T0WH180:J9C@2]T5H0XHEE
081R@01Q@BP0=34X02/X7`0W91/0:BTQ02XY900T9Al08R<N02@V8@8092@R1P0U9B<0200W:2<09RLR
02DV800U9Qh09RPM02T[7P0[;B00;2hP0P0^;R@01P0];B<0:b/Q02TY7`0X:1h09bLM02HV70@0:BTQ
0P0X:20202LW7`0?02PX800Y:B40;2TP02l[8P0e;R@0>C4V03de:010=RX0?SLU03lf9@10=B<0@SDR
04Hg8P1<>R@0DC`W0080DclW00/0Fd0U05a29`1MAB/0G4H^05U4;`1A@2`0CC`Z04Pi9P14=b@0ACPU
04Hi9P0204Lj9`<0B3/X00P0BCTR04dm9P1@@2T0CclX04`l9@1;>b@0CShW0592:`P0DT4W101G@bX4
05I2:@0405M6;01FAB/0ED@Z05A3:@<0Dd8X00@0DT4W05Do:01E?bP0E40X0P1B@2P0301A@BP0Cd4W
04m19`1B@2P0DClW050n9P1??BD0D3hV054o9`1C@BT0E48Z05=49@80Dd@W00<0DT8X0592:@1B@R/0
0P1A@2`804lo9P0604e1:`1;?bT0B3/X04Dh9`12=BD0@C<V0P11<bP06014=2L0ASHW04Ph:017=bL0
A3DR04Df8@19>R<0CChW04i8:01=@bX0BC`[04Lg:P18=bL0D3`T05M48`1NBb40ID/X05U78`1:?al0
?CXK03Pf7@0n>280AcXY04hk;080CS`X00l0CS`V04lm9@1A@2H0Dd8V05E4:01GARP0EDL]0555:`1>
@RX0BChX04<k9P0o>2D0>cHR03Xe8P0o=b@00P10>2D3044i9P80@3PU0`16>R@304Lk9@80B3`V00P0
@cHS04Hi9P17>RL0ACPU04<f8`14=b@0BC`Y04i1;P80Cd0Y00l0CSlX04lo9P1@?bD0DD0T05E2901H
@b@0FTDV06Q;:`1YC2`0Jdh/06iB;@1aEBh0METa07QL=01iGS<00`1eHc/03@1fI3`0N6Hn07aZ@P1o
KDD0PW1808YaB@27KTH0Pfa3081Z@@1oK480PW5608MfB`28NDh00P2:N4X07P2;ND/0S7Y<08ilCP2?
ODl0T7i@095oD@2CO4P0U7e909MnAP2KPTT0X8I90:F<BP2/TDh0[iA?0:jEDP2_UU<0/YUG0;BKF`2d
VUd0]9YO0;:HG@2aUeh0/IQO0;6GGP2bUEd0/I9I0:n?EP2`Re@0[XY@0:n8C`@0/H]<102`RT/0202Z
RdX0[8e<0;2>CP2cT500]Y1A0;N?D@2fSU00]hi@102hU4P01`2iUD/0^iM=0;fIC`2oVe40`9YK0;jH
F@2lUUL00P2jU5D02`2lUUL0_YQI0<2JF`2eTeH0^9II0;ZHF`2hUUT0/Y1C0:n=D02`SU40/Y1C00P0
[8U900T0[haB0:j;D@2[R4h0Z8E;0:F2B02SP4H0XGi40:1m@`2QOTP00P2QOTH01P2QOT@0X7i109mm
?P2OOCd0WW`l0:J3@@80YH900P2TPCl20:F2@0060:J3@@2XPT40Y7hm0:5k>P2TOSd0[8I50P2aRdX0
102_RDP0YhLl0:Z:?`2^ST<20;6AB0030:j>A@2YR440YXDn00D0ZhU:102ZR4T0602_RDX0[HM80:^5
AP2WPD80Y7ho0:9l?@2PNS/0WgTj09]g>@2HM3H0UW@e09Mh>02KOCd0WH5009b0?`2GOS`0WX1409an
@P2KNch0W7Xk09aj>P2OO3X0Y7hm0:J1?@80Xgdo0100X7`n09il?@2LNS/0V7Ti09Eg=`2DMSH0UGPn
09=f?02@LcT0SW4g08e`=P2?LSP0TG@j09=f?02INSX0W7dm0`2PPD403P2SQ4@0ZHY:0:n@D02gU5@0
/i5A0:R8B`2MOTD0UWU109ImA`2HPDl0VX=A09j3C02OQ4d0XHI?0P2RQe000`2QQTl0X8E>09n4C@03
09n5C00509j4B`2MPdX0W89909^1B02JP4L0202IOdH209MnA@80UWe4102EO4<209=h@@0909Ai@P2C
N440TWM0091e?P2=LS/0S74j08ac>`2;LSX0RW4i0080RG0h00/0RW4i08]b>P2<Lc/0UG4o09Mf@`2O
ODd0YhMH0;6BI02iW700_jAg0<>XO@020<FYP@0P0<:VOP2kWgL0]9Q`0;6EK@2cUfl0]i]c0;bRO`2n
Y840`JV70<J_S`3;]YL0d;fO0=G2Y03Ea:P0gLF]0=c4Z03J`J80eK^H0<^_Q`2mXW<0/IES0:V>F@2H
OdH0TGPo08U`>025K3H0QV`i08M]?025JcX0PfPi085W=P20ISD207eR<`0=07YO<P1fFc00LUH^06mC
:`1]DBX0K50Y06Y@:`1ZD2d0Idl[065::01HA2<0DChN04dj6P02044f8004040e7`0o=1h0?c@N03hc
7@80?C8L0P0l=A/01`0k<a`0>c<N03Xb7`0i<Ah0>2lN03L^7@0g;Ql00P0f;Ah203D/7@80=2/L00<0
<bXK02lY7@0_:Ad00P0^:1`402dW6`P0:BDL0`0Z9QX302TU6@80:2@H1P0[8QT202`S6P<092@J0P0U
9A/302HV70<0;BLK0P0^:1`302lY7@P0=2/L200b:AX303HZ7P80=b/O0`0h;2000`0h;1`0>BdM03T]
7@0203T]7@0;03P/700g:a/0=b/K03LZ6@0h:aX0>B`K03X]700l;ah0?S4P040c8P11=2<01015<ad2
04Hd7P80AcDO00D0BcDN04`f7`1<=Ql0CCLP04di8@0204hj8P0304dk8`1C>Ah0DcTN0080E3XO101E
>b000`1H>AX0FCXK05Xk700205`m7P0805ho801P@B80HD8S0693901SAB<0IDLU06M99`1YBbT206Y<
:P0506U;:@1XBRP0IDLU06I89P1WBBL00P1XBRP306U;:@0306U::`1XBBX0J4TZ0080IdPY0P1VAbP0
2@1UARL0H4PT06989@1TBRL0IdXX06U;:@1ZBBP0JTLW06U69P0206I89P0606M99`1XBRP0JT`Z06]=
:`1]Cbd0KU0^0P1SAB<206A6900406E79@1VB2H0IdTW06M99`<0KD`Y0P1/BbP306]:9`0606mB:01a
DBP0LE4X07=B:@1dDBT0Me4Z0P1hDBX01020Fc40OeX`07iI;`1mF2h207]F;080NUD[00P0Ne@]07aE
;P1lERl0NeP`07aK<P1lG3<0OEdd07aO=@@0OE/^101lFRd207aI;`<0OEX`0`1nFc4807aI;`0808=N
=022GC<0PE`b081K<@21G380Pehd08EP=P27HSP808UT=`0308iS=P2?I3L0T6Dh0080TFHi0`2BIcX0
2@2CJCL0TVPf091V=02>I380SfDc095W=@2DJSP0UV`j09=^>@02099]>005095/=`2@JcH0SfXe08mZ
=@2>JC@00P2FKCT209E/>0D0U6/g00@0SfHb095X=02CJSH0UF`h0P2GKSX209I]>@80UV`j00@0Ufdk
09U_?@2JL3h0W7900P2MLd400`2OMT80WWE109ed@00209ac?`0409ed@02OMT80X7M309mkB`80X7a<
00<0XGe=0:9nCP2ROTh00P2ROTh20:F2BP030:F2C02UPDd0YH5?0080YH5A00<0YH1C0:B0D02SOdl0
0P2SOdl20:9nCP80XGe=00@0Wga60:1mA`2ROdT0Xh1:0`2TPD/00`2SP4X0XWa=0:9lC@060:9lC@<0
XWi:00<0Xgm;0:B0C02UPDd00P2UPDd20:J2CP040:F1C@2TP4`0Xgm;0:9nBP80XGe900H0Y7m:0:F0
B`2UP4/0YX5<0:N2C@2XPdh20:V4C`0;0:V5D`2ZQU@0ZhME0:b8EP2[QeD0ZXID0:R4DP2WPe40ZXIF
0:R4E02WPe<00P2UPE404@2VPU80Yh=C0:R4E02ZQ5D0ZhEF0:^7E`2ZR5P0Z8QG0:J8EP2TQU@0XHEC
0:^7D`2YQE40Yh=?0:F1C@2TP4`0Xgm;0080Y81<0P2TOd/0102UP4`0Yh9>0:R3C`2YQ5020:Z5D@80
ZXAC00H0ZhED0:b6E@2_REP0/heL0;J@G`2hTV420;JBGP040;NCG`2hU600^9AP0;VEH@80^YIR0P2i
UFD50;ZFIP80^iMW00<0^IEU0;ZFIP2lV6P00P2mVFT02`2lV6P0^YIV0;VEI@2fTUh0]i=O0;RDH02j
UV80_9QT0;jJIP30W6P0`IeY0080_iY]00<0`9]^0<6LK`32WG000P33WW401034Wg80`iia0<>NL@33
WW420<BOLP<0aJ1c2032X7802032WgD0`Iid0;nLLP2nVg40_IY`0;jKL@2oW780`9ec102oWFl00`2n
W6h0_I]]0;fKK@030;bJK0<0^iU[0`2jV6X20;^IJ`80^YQZ0P2iUfT20;RFJ0P0^YQZ202jV6/30;ZH
J080^IMW0`2hUVH20;^GI`80^YIV102iUFD80;JBHP040;>>F@2dSeX0]8mJ0;B?FP<0]I1K00@0]Y5L
0;:>FP2aSET0[h]G0`2^RUH20;2<F080[XQG00@0[XUE0:f8D`2/Qe80[8M@0P2[Qdd20:V6D080ZXMA
0P2[R5820:b9D`T0Z8A@1@2ZQE001P2[QU40[8MB0:b7DP2[Qdd0ZXI<0:R3C080Yh9=00<0Z8=?0:Z4
D`2[QE@00P2VPTh01P2XQ500ZHEA0:^7D`2]RED0[XYF0:n;E`80[8YJ0`2]Re/30:j<G00H0;:=H02b
SUh0/HeM0;2<FP2_ReL0[X]E0:j;D`2]RU80/8]F0:j9E02/Qe80ZhIA0:Z5D02[QU40[HQC0:j9E02Y
Q4l0ZXE@0:^6D@2/Qe80[HQC0:j9E02_RUD0/8]F0P2_RUD20:j9E00<0:f8D`2/Qe80ZhIA0:^6D@2]
R5<0[8MB0:^6D@2YQ4l0Z8=>0:J1C02UP4/0Y7m:0`2QO4L[ooooo`00:_ooool20:Ai@P040:EjA@2U
NTL0YGY70:IjB@80YWY;00@0ZX5=0:QoB`2VODT0Y7]70P2SNTH00`2TNdL0YGa80:IlBP070:IlBP04
0:MnBP2XOd/0Z7m;0:QoB`80ZH1<0P2ZPDd80:^2CPP0ZXEA00H0/HME0;26E02_QE<0[XAB0:f3D@2^
Q5840:n5D`80[XAB0`2]Pe40102/PU00Zh5?0:^1C`2[PDl20:Z0CP<0ZGm=00@0YH1<0:AoB`2QO4P0
WgY60`2MN4@209iiA@0809ehA02LMd<0VgI209Ud@02GLSh0UG0l09A_>`2CKSX2095[?P06091Z?@2>
J3/0SFLj08aV>@2;ICP0RV@g0`27HSP208IQ=`<0QF0f00H0OU/c07eJ<P1mFS80O5Ta07]H<01jEbl2
07UF;P0H071C:`1aE2`0LeH^07AG;`1eF300M5L_07=F;P1bEBd0Le</07AD;@1eEBh0MeL`07UI<P1k
Fc@0O5`e07eM=P1nGC80Oehc089O=@27HSP0RF@j08eV?@2AIcl0TVQ00P2BIcX02@2CJ3/0UFXm09I[
?P2GK3l0V6e009U^@@2HKS`0VFlm09Y`?P0209]a?`0309U_?@2GKC/0UV`j00<0UFm00P2DKSl309=]
?P<0U6ho0P2CKCh3099/?@80TF`h0`2@JcL308mZ=PP0SfTj0P2>J3T0102=IcP0S6Hg08aV=`2;ICH:
08YT=@P0S6Hi0P2AIST2091U>0<0Sf@g00L0SV<f08mT<@2>I380SF<a08aT<`29Hc@0R6<f0080QF<f
2@2:I3L808]U=P0408YT=@28HS<0QV0a08MQ<P80RV@e00<0RF<d08IP<@26H3400`27HC8208QR<`80
RF<d00<0QF0c08IQ=027HSD00P27HSD00`25H3<0Q5lb089M<00208MN<00408EO<024H300Q60`089P
<080PF4`0P22H38208=Q<`<0Q68d00@0QF<e08YV=P2:ISH0RVHf0P2;IcL308aX>0<0RfLg0P2<J3P3
08eY>@0408aZ>P2=Jc/0SF/k08e[>`@0SV`l0P2?KCd308i/?00;08m]?@2AKcl0TW10095]?@2@KSh0
TFlo091`?`2?LCl0Rflm08Q^>`27KCX00P2;Kcl0902:KSh0RFdm08M[>`24J3P0P6@d07iR<P1mH3@0
N5d`07EJ;`1bFC00LEXa06iH<@1UDRX0H4`W05]8:01FABL0Cd0S04Hj800n=Ql0>3<O03@a7P0b<Al0
;BhP02//7P0Y:Q`0:2TK02LX6P0X:A/0:BXL02X[7@0V:Q/09RXL02DY6`0S9Q/08RDL020S70807b4L
200P8aX8024T6`T07R4J00H07b0H020Q6@0P8AT08B8J028S6`0S91`202@U7@0802HY800U:1d09RPM
02HV6P0Z:1/0;BXK02l/6`0b;1`203Ta700>03Xb7@0l=1l0?CDP03hf8@0o=b80@3PS03@b7@0a;Q/0
;2TF02PU500X9AH0:RHJ02l[800a;B8803<]7`80<BhO00@0<2dN02l/7@0_;1d0;R/L0P0]:Q/0200[
;1`0:R/K02PY6`0W9a/09RHL02LW7`0X9b80:BPS200V9Q`202<T7P04028S7@0Q8Q`08B8L020Q6`80
7b0J01d06b0I020R7@0T8b40:b8S03<V8010;ad0D3dM05]8801[Bb80KdlV071@9`1ZBR40IDDL06a<
8`1nGSD0Sfm609MfB`2KNdP0XXE90:V@CP2XT5@0TWY<071E>P1B=RP0;RlY02LX8P0T9Al0:2TS02LX
8P02028S7@0402LX8P0T928092@R02@T8P<09BDS0P0V9R@04@0W:2<09RLR02HW8@0V9al0:2XO02X/
7`0/;R40;S0R030`9P0_;bD0;RhT02`/8P0Z:R00:BTO02PX7P0W9ad0:RXR0080:b/S00d0;2`T02/[
8`0Z:R80:BTQ02PX800/:B80;BXQ02l[8P0d;B<0=blT03/a9@0n=BH0@CDW0080?SLU00D0@3DS04@e
8P19=b<0CcXU05Ln:P0205Xo:P0<05i18`1N@2@0Fd4V05I0:01A?bT0C3/Y04Hi:013=bL0@SDR04@g
9016>BH0B3/X1019?2T02@17=b00BSXS04hn9`1=?BH0Bc/T04Xj8`1=?BH0DD4Z058n9@0305<o9P04
05A09`1E@BP0ED4X05E1:0<0F4@[0P1G@bX305I2:@80ETD[00H0E4<Y05=2:01C@RP0Dd8X05A3:@1E
A2X205@n9`0405<o9`1B@2P0DT0X0551:080DD<Y00<0E48Z05=1:@1B@2P00P1A?bL02`1B@2P0Dd4Y
05A2:P1DABH0E4DX05=49`1C@bT0DT8Y0592:`1B@Bd0DD0/00P0CclV00D0BSl[04Pm:@15>RP0@SHV
03lc9@0203hb9P0I03ha:00o<B@0@cDX04Dh:014=bH0@C@S040c8014>280Ac/U04M29@15?bL0ACTY
04De:018=BH0DCdT05m89P1YDRP0LET[06AC:01BB2D0@clR03dk9012>bP0C3l^05E2<@0204lm:@0<
050n:01A?bL0DT4W05A39`1EA2P0ETDW0514;P1>@R`0BSl[04<k:00o>2D0>cHS0P0g=2<0100m=B80
?SHS03lg9010>2D2044i9P04040h9@0o=b@0A3LT04@g9080ACPU0`16>BH02@17>RL0@SDT04@g9P15
>2L0@cHU044d8`12=B@0B3/Z04i1<00204ho:00A04dn9`1>?RD0D3lU05919@1GA2H0FdHW05e8:@1Y
C2`0JTd]06]>;01^DRd0LED^07EI<@1hG3@0NUld07IT?01eHc/00P1cHCT0;01dHSX0MfDm07]Y@@1m
Jd<0QVa708AZA@21JD<0OfU207i[@`1oKDD0PW18089cBP24LdL0QGA808IeB@27MTX0RGQ<08YiC@2;
NTh0S7]?091f@`2BN4D0U7]309QoAP2LQdP0XXe:0:NCCP2[Ue00Z9AE0:ZFE`2]VE`0[YYO0:nKH02]
V5l0ZYEN0:VDG@2WT5`0YHiH0:F:D`2VQe40ZHI>0:^6C`2aR500/hU?102cRdd40;::C0050:b=C02^
Sdh0/Y1@0;FBDP2iTe@00P2jTU@01`2jTE<0^iU?0;ZHCP2jV500^IM@0;RED@2hUE<00P2hUED00`2i
UET0^9AH0;NCE`020;NCE`040;RDF02iUET0^IEI0;BCG@80]YEO00D0/Y5K0:j=E`2/ReD0[hiH0;>B
G0080:V5B@060:b9D@2ZQdl0YhA<0:B1B@2ROdL0X7e50P2OO4@02`2QOTP0XGi60:9oA`2ROdD0XGm2
09mm?P2MNc/0W7Xj0:>0?02TPCd0YH8n0080YhA000P0YH8n0:B1?@2SP3`0ZX=00:Am>P2QNSL0YGhk
0:n8A@80]Hi;00T0/HY70:V;@P2[SDD0[Y180;2BC02_T4d0[8e<0:N8B02UQTH0102ZR4/20:V7BP<0
Z8I900D0[hM90:j6B02[PdD0Z8120:In@0020:Al?P0A0:=k?@2MNC/0VWHh09Qf=`2HNCT0Vgdm09b0
?`2KOch0UWdk09an@P2KOD40W7`o09il?@2NO3`0X7dk0:An?@2TOc/00P2TOT002@2ROT00X7ho09mm
?P2JNc/0UgTi09Ih>02FNCl0U7Lm099e>`02091c>@05095d>P2BMC/0U7Lm09Yk>`2MOSh00`2PPD40
4`2RPd<0Z8U90:j?C`2eSdh0]i5B0:n=CP2OPDD0UWa309EoAP2HPdh0UX9=09n4C@2PQDh0XXM@0:>8
D@2TRE80XhQA0::7D02QQTl0102OQD`00`2NQ4/0WH=:09^1B00909Z0A`0309V0A`2HOdH0UWe400<0
UGa30P2FOD@02`2DND80UGY309Ej@`2ENT<0TgQ1095f?`2>Lc`0SG8k08ed?02<Lc/0RW4i0080RG0h
00/0RW4i08ac>`2=M3`0UW9009QgA02OODd0Z8QI0;:CI@2jWG40`:Eh0<BYOP020<R/Q00P0<FYP@2n
XWX0]YYb0;6EK@2cUfl0]IUa0;ZPN`2lXWd0_ZJ20<>/RP38]9<0c[^K0=?0X03Ea:H0fL>/0=[4[03L
a:P0f/:P0=:hT`37[840^Ym`0;>GI`2TRTl0W897099h?`2<LCX0Rg0k08Y^?029KC/0QVXj08IZ>025
JCL208=W=`0>081T=@1mH3@0N5/a07AG;`1bEBd0Ke4[06mC;01_Dbh0K58_06I>:P1NAbD0E40O04lk
6P14>20204<g7`80@SHN0`11=Ad203he600703le6P0o=A`0?S<M03`a7@0j;a/0>BhL03/_7`0203X^
7P0303T]7@0h;1`0=b/K0080=RXJ0P0`:Qh202lY7@<0;RPL00<0;BLK02XV7@0Z9Qd01P0Z9Qd302/W
6`80:RHJ0`0Y9AT0100/8QP0;B<I02dS6@0]8aT302hT6P0402lU6`0U9A/09BDK02DU6`809RHL0`0W
9ad202hX6P80;bTK0`0`:Q`00`0a:ad0>2`L03P/700603P/70P0=RXJ0P0h:Ql203T[80<0>R`Q00@0
>bdR03L/6P0h;A/0>BhL0`0k<1h203X_7@@0>bhK00D0?2lL03ha7P10<b00@SDR04Lb7@0304Pc7P80
BC@O0P1:=B02050e800404lf801>>240CCTQ04`j8P80Bc/R00<0DSPM05<i7P1E>b000`1F?24205Dk
8080FS/L00D0Fc`M05`m7P1L?Ah0GSlP05m08@0206118P0406948P1TAR@0ITPV06Q::080JD/Y00H0
J4XX06M99`1TAR80IDLS06M99@1YBbL206Y<:080JD/W0P1]C2/206a;:P0<06]::@1ZBBP0JDPW06U8
9`1QBB<0I4XU06I<9`1YCBP0JddY06a;:01/BRL0JdTV101YBbL01@1ZC2P0K4hZ06i@;01`DRh0I4HR
00<0IDLS101VB2@206i=:P<0KD`Y0`1/BbP01P1^DBL0L50W075A:01cDRT0ME8Z07QB:`80NU</00@0
PE`b081K<@1nFBl0OEP^0`1lEbd02@1mF2h0OUL`07iG<01nF340OEXb07iM=01nGSD0Oelf07eP=P02
081N<080Oed_101nG2h0101mFS00OU/a07iK<@1nFc4207mL<P80P5dc0P1nFc4307mL<P<0P5dc00P0
QF0f08AO=@22GC<0P5/a085L<P23GS@0QV4g08QS>@<0R6<f0P29I3L208YU>00508]V>@2>HSD0Sf<f
095U>02CIcX00P2DJ3/209=W>P80TfTg0P2BJ3H0102CJCL0UF/i09M]>`2HKS`209=^=`<0TVdf0`2A
K3D309M^>P<0UVdi0`2EK3P0102@Ic<0TVTe09A[=`2FKCT209M^>P0F09I]>@2EK3P0Ufdk09M]>`2H
KS`0VW0n09]a?`2LLT00WG=109id@P2PMd<0WgI209ie@@2MM400WWE109mf@P2QN4@0XWU50:1lC02Q
ODd0XWi>0:=oC`80Y81@00L0Xgm?0:9nCP2VPd/0YX=;0:J3C@2VPTh0YX9@0080YX9B00@0YX5D0:F1
D@2UPE40YH5A0`2TP5020:=oC`050:1mA`2QOTP0XWm90:B1B`2VPdd00P2WQ4h00`2XQDl0Xge>0:=m
CP060:=mCPP0YH5=0P2WPdl0102VPTh0YH5=0:B0C02TP4`20:=oB`060:F0B`2VPD`0YX5<0:N2C@2X
Pdh0ZHA?0P2ZQE000`2ZQUH0ZhMG0:b8F0020:f9F@070:^7E`2YQED0Z8AD0:b8F02ZQUH0Z8AD0:N3
D`020:J2DP0>0:N3D`2XQ5@0ZXAE0:^5EP2/R5P0ZhUI0:Z:F@2XRUP0YXQF0:>7E@2/R5@0ZhMC0:Z6
DP2YQE440:R4D0060:J1C@2WPTh0Z8=?0:Z5D@2/Qe<0[HQD0P2_RUH0202_REX0[XQI0:n9FP2`RU/0
/XaM0;F?H02hTV<0^YAU0P2iUF420;ZFHP80^iMS0P2lV6@00`2kUVT0_9MZ0;bGJP060;bGJP030;^G
I`2lV6P0_IUY0080_YYZ00T0_IUY0;bHJ02kUfL0^IEQ0;ZFHP2kUf<0_9QT0;fII@2oVfL00P30W6P2
0<2KKP030<6LK`32WG00`iia0080a9mb00<0aJ1c0<BOLP34Wg800P35X7<30<JQM0030<NRM@33XG<0
`j5c00H0`j5c00P0`j1f0<:OM@30WG<0_iab0;jKL@2oW780`9ec0<6NM080_ie_0`30WW00102oWFl0
_I]]0;bJK02lVV`30;^IJ`80^YQZ0P2iUfT30;ZHJP80^IMY0`2hUVP@0;ZHJP<0^iUY0P2jV6P30;VG
I`80_9QX0P2kUfL30;ZFIP030;VEI@2fTV80]Y9R00H0]Y9R0`2fTEX50;F@F@030;:>FP2aSET0[h]G
0080[XYF00<0[h]G0;6=F@2bSUX00P2_REP0102^RED0[XUD0:f8D`2/Qe020:^7C@<0ZXIB0P2[Qe<3
0:b8E0T0ZXIB0P2[QU430:Z5D0060:b7DP2]R5<0[XUD0:b8CP2[Qdd0ZHA=0P2XPdh00`2YQ500ZhED
0:b6E@020:N3C`060:R4D02ZQU80ZhMC0:b8E02]RED0[XYF0P2/RUX30:f;F`<0[XaL00/0/hiQ0;>?
G`2bSUh0/HeK0;2<F02_S5H0[haD0:j;D`2`Re@0[hYC0:b7D0020:Z5CP040:b7D02^RE80/8]D0:Z5
D080ZhIA00D0[8MB0:f8D`2^RE@0[XUD0:n:E@020:j9E0040:f8D`2/Qe80[8MB0:^6D@80ZXE@00D0
[8MB0:^6D@2ZQE00ZHA?0:R3CP020:J1C0040:F0B`2RODP0XWe80:9mB2_ooooo000Zooooo`80YW]4
00@0YW]60:EjA`2UNTL0YGU80P2TN4T0102ZPDd0ZH1<0:ImB@2TNdL20:=jAP80Y7]7202WOD/30:Qo
B`80ZH1<0`2ZPDd80:b3C`P0ZXEA00P0/hUG0;67E@2_QE<0[XAB0:f3D@2^Q580[hEC0;26E0<0[hEC
0P2^Q5830:f3D@@0Zh5?0P2ZP4h20:UoC@040:F0C02TOd/0XGa809mjAP<0WGQ40`2NNDD03@2MN4@0
VgI209Ud@02GLSh0UG0l09A_>`2CKSX0Tfe0099/?`2AJch0T6Xm08mY?02=IcX00P2<IST208UT>P04
08QS>@27HSP0QF0f08AO=@80Pehd0P1mFS8207aI<@0707]H<01jEbl0NUL_07UF;P1`Db/0LUD]07=F
;P0307EH<00@07AG;`1cERh0MED^07IF;`1gEc00NETb07]K=01mGCH0OUhg07mO>020Gc@0PF0e08=P
=P27HSP0RF@j08aU?080T6Hn0P2BIcX02@2CJ3/0UFXm09I[?P2GK3l0V6e009U^@@2HKS`0VFlm09Y`
?P0209]a?`0309U_?@2GKC/0UV`j0080UFm00P2DKSl409=]?P@0U6ho0P2CKCh2099/?@80TF`h0`2@
JcL308mZ=P@0SfTj102@JS/@08aV=`P0SVDi0`2AIST2091U>0<0Sf@g00H0Sf@a08iT<P2=Hc40S6@c
08US=028HcH208ES=PT0RV@g202:I3D0202;ICH0Qf4b08EO<026H340RV@e08aV=`29Hc@0QV0a0`27
HC0208QR<@<0RF<b00P0QF0c08IQ=027HSD0R6<f08MR=@26HC@0Q5lb08=N<@80Qeh`00@0QEl`08AP
<024H300PV0`0P21HC0308=Q<`<0Q68d0P25HcD308aX>0@0SFTi00@0SVXj08eY>@2=JCT0SFTi0P2>
JSX308m[>`80Sfdm0`2>K3`308e[>`0@091^?P2?KCd0SV`l08e[>`2>K3`0Sfdm095_?`2BL400TFdm
091^?P2AKcl0T70o08ma?`2;Kcd0R6hk08M]>P80Rflo02@0RVhn08U]?@27Jc/0Q6Ph081T=01nHS80
OF0d07QM<01eFRl0LUT`075J<@1^F340IE8Z061<9`1JAbL0ED@V04m08`16>R00?SHO03Pc7`0d<Ah0
<S4O02d^800[;1h0:BXL02PY6`0W:1X0:2TK02TZ700Z:ad09RXK02HZ700U:A/08bHK028U700P8a`2
01lQ710082<J2@0N8AX201lP6003020Q6@0Q8QX08R<K00808b@L01T092DM02@W7P0S9Q/092HK02HV
6P0Z:1/0;BXK030]700d;Qh0>30K03Ta700j<Qd0>c<N03de800n=R40?cLR040h8`0a<ad0<2lK02`[
5`0X9aD0:BHG02hX700c;280=RlU00P0<bdO0P0a;Ql0100`;Ah0;b`M02l/7@0^:a`202dZ6`0802//
700Z:a/0:2TK02LW6`0V9Q`09bLO02PW8P0Y:2<802LW7@808b@N00@08R<M024R700Q8Q`0824K0P0O
81X0800J8AT0828M02@S8@0[8b40=BHO04@b7P1G@200Hd`R075@9@1bDBH0LE0U06i=8P1_CR<0NEP]
08QW?02EM4T0VGI<09emBP2VRTT0Zi==0:6;C`26KdD0HdXf04T`:`0/<Bd09BXV02@V8`0V:2<09BHQ
020Q6`0S8Qd0:RTT0P0S8b4202@T8P0402DU8`0V9R@09RHT02HV90809bPS00H09RLQ02LX800X:Ql0
:bdP02h`8`0_<B<2030`9P0802l_9@0];B<0;2`R02/[8@0Z:R00:BTO02`/900];BD302h^9P0B02`/
900Z:R80:BTQ02h[8P0`;240<RhS03H`900i<B@0?3<T03lc8`10=2@0?STV03hg9@10=B<0A3DR04/f
8`1C>RH0FSd[0P1P@Bd03P1R@B80GSlR05Ll7`1A>B40BCLQ04@e8P10=2@0?SDV044d8@13=R<0ASTV
04Pk:01:?BX0Bch[0P1:?BX03P14=1d0B3PQ04/k901;>b@0BCTR04Ph8@1<?2D0CclX054k8`1B?2@0
DcdU05@n9P1E?bL0Ed4Y0P1H@RX205U5;080F4@[00`0Ed<Z05I2:@1F@RT0ET8Y05E4:P1D@bT0Dd8X
05919`1C@RP0E4<Y05I5:`1GAR`205<m9P0905<o9`1A?bL0DT0X0592:@1A@bT0DT@Z05I4;01E@b/0
Dd4Y0080DT0X00@0Dd4Y05A2:P1E@b/0E4DV0P1DABP00`1C@bT0Dd<Z0592:`020591;@P0CShU00H0
Acl/04Dm:P12>BP0?cHW03`b9P0k<BD203/a9`0H03h`9@11<bP0A3HY04<f9P10<b80?S4N044d8@14
>280?C`P040k9@11>2T0@S@W04Ld9@1C?R<0I4`V06mG:`1gH2X0J5LY05A:9P13?b@0?3XU048k:@1=
@2d0ET@`0P1A?b/02`1B@2X0DT0X05=2:01C@RH0E4<W05A39@1=@Rh0BSl[04Dm:P0o>2H0>cDU0080
=c@U00T0=S@W03/c800l=240?cLT040h9@11>BH0@3PU03lg900n=R<00P13=R<204@g90<0ACPU00T0
ASTV040c8`12=BD0@cHV044d900o<R80@C@T04Pk:`1>@C400`1<?BH05P1>?RD0DD0V05A39`1IARP0
GTTZ061;;01ZCBd0Jdh^06]>;01]DB`0LED^07EI<@1iGCD0Nf0e07MU?@1eHc/0LV0h071N=P1aGcL0
Lf4i07IT?01iIcl2085W@P0<081X@P1nJ440OFY207aZ@P1mJd<0Nfa307m^@`20Kd@0PG1508=bA`25
M4T0QgI;0P29N4d0602=Ld00SWA1095h@02DOT@0VhI70:6>BP2WU4l0ZIQ@0:>CE`2UUET0Z9QM0:ZI
H@2YV680YiIP0:BCG`2QT5`0WXYH09b6E02KPDh0Vge70:5nB02ZPd`0/XQ>0;V<D`<0]Hi=0P2dSD`3
0;><B`050:j?C02_T4d0]9=@0;NDDP2kUE@00P2lUE@03@2mU5@0_iaH0;jKE`2lVEL0^YIH0;NCE`2e
T5T0/hiI0;:=F02aS5D0/XeF0;B?F02eT5T00P2fTEX20;F@F@080;>EH@2bU600[Y1L0:R:EP2QPdl0
X89>0:F7D`2ZS5P80:N2B`030:B1B@2SP4P0XGi60080X7e500h0XGi60:9oA`2SP4P0XGi80:9oA`2S
P4P0Xh160::0@`2POSl0WG/k09aj>P2POSL0Xh4j0:N5?P80ZXQ101<0YhDn0:>1>P2POSL0[8E00:En
>@2ON3<0XW/f0:b5@02aRTD0[hQ30:V2?@2WRTH0Z8]90:Z<C02ZS4h0ZHYA0:J7D02SQ4h0XH5>00<0
ZHI<0P2XQD/0202WQ4X0YX=90:J3B@2VPdT0[XM60:f6A@2ZPd80Z8500P2VOch20:N0?`080:1l?P2M
NC/0VGLh09Uj>P2KOCd0Vgln09Um?02DNcT209Yl@00609em@02POSl0X7hn0:5n?02SOC`0XWdi0P2T
OT002@2SOd40XX110:5o@02LOCd0VG/k09Mi>@2GNT00UWTo09Ag?@03099e>`80U7Lm01X0VW/k09io
?`2PPD40XH920:21@@2RPd<0Z8U90:f>CP2bRDL0^95@0;BAD@2TQ4L0V7i309R2B@2HQDd0TX5;0:25
CP2QQTl0XhQA0:F:D`2VRe@0YHYC0:B9DP2SR540WXA;09n5C080X8I=00@0WhE<09f3BP2KPDP0VGm6
202JP4L02@2JPDP0V7m609ImA02EO4<0U7]209El@`2FOD@0Ugi509Ej@`0309IkA00709Ai@P2BMd00
T7Dn08ic?02=M3`0S7<k08]b>P0208U`>00@08]b>P2<Lc/0SG@l09Mc@@2IN4D0X7i>0:V9FP2cU6H0
^Yea0<6VN@35ZWl0bZj60<^_Q`38[8@0`JEm0;RLM080/iM_01/0]IUa0;ROM`2jX7/0_:An0<2ZQ@35
/Hh0c;VH0=:oW`3Da:<0f<>`0=_6/@3ObK40h<VZ0=[2WP3@]hh0`j]m0;fRL`2_TUH0YXU?09]nA02C
MSh0T78l08ma?@2<KS`0RV`j08]]>@2;KC/00P2:K3X03@27J3T0Pf@f07mP=01jFS40N5P_071C:`1a
E2`0LUH_06iD;`1YDBd0H4TW05Q17`1A?A`00P17>24304Hg80<0ACHO00P0?c@D03ld5P10=AL0@CHJ
040d6P0n<QX0>blI03X^6080?C0P00L0?2lO03/^7P0j;Ad0>B`L03P[6`0g:QX0<B/O00<0<2XN0P0_
:Ad202hX70P0:bLN0`0/:1`202/W6`<0:RHJ0P0]8aL202hT600502lU6@0`9QX0<2HJ030V6P0U9A/0
0`0V9Q`202LW7@80:2PN0P0_:AT2030Z6P<0<B/K00<0<R`L03X]7@0j;Ad01P0j;Ad803P[6`80>bXP
0P0l:b4303d/8P0;03h]8`0e:QH0=b`H03T^6P0l<Ad0?C8N03hc7`0m<Qh0?34M03lc7@0n<Q`00`0l
<1X00`0n<Q`0@3@N044e7`0204Tc7P80BS@O0`1;=B001`1<=R40DSHQ058f8@1A=R40CSPQ04di8@1;
>b800P1:?2800`1B>1d0DcTN05Dk800305Lm8P0305Dk801D>Ql0G3dN0080G3dN0`1M?Ql305ho8004
06538@1RA280I4HT06I89P80IdTW0P1VB2H0101WBB<0JD/U06]=9`1]CbT206i@:P80KDlY00H0LDl/
071>:`1`CR/0KT`Y06e;:01/BRL206]99P0806=<8`1UC2@0IdhV06Y>9`1/CRP0KDdW06e;9P1/BRD2
06a>:080JT`V00@0JddW06e?:@1_DB/0L58/0`1ZC2H306U;9@80J4XT101]C2T406i=:P0606a?9@1_
CbH0L50W07=B:@1fDb/0NE</0P1lEBh00`21G380OeX`07iI;`0207aG;@0;07eH;P1nFBl0OeX`081I
<P21FS<0P5Xc07mL=01oGSD0OUhe07mO=P1mH3H00P22H302085O;`05081N;P1oGBd0Oed]07mM;@1n
Fc400`1oG382081M<`80PEhd0`21Gc800`22H3<0Pf4d08=Q=00208AR=@0D08MR>025H3H0PUdc081K
<@21G380Pehd08MR>029I3X0QV4d08MR=@28HcH0RF@g08YU>02;IST0S6Lj08eX>`2@HCD0TF8f09=T
>02FIc/209MX?00709IW>`2EISX0TfTg09AZ>02EJcT0Ufdk09Q^?00209U_?@0409Q^?02BKS@0TVhd
099^=0<0Tfle0P2DL3H309Q_>`<0Ufhj0`2FKCT0102AJ3@0TfXf09E/>02FKCT209M^>P0:09I]>@2E
K3P0Ufdk09Q^?02IKcd0VW0n09ab@02MLd40WWA209me@`80WgI200h0WWE109mf@P2PMd<0XWU50:El
B02VODT0X7a<0:9nCP2SOdl0YH5A0:J2DP2UPE40Y81@0:=oC`80YhA<00<0YhA>0:N3C`2WPe400P2W
Pe<00`2WPUD0Yh=C0:N3D`020:J2DP<0YH5A00<0Y81@0:F2C02UPT`00P2UPT`30:J3C@030:N4CP2T
OTl0Y7i?00H0Y7i?0P2XQ5000`2WPdl0YX9>0:F1C@020:B0C0030:=oB`2WPdl0YX9>00<0YX9>0`2U
PDd20:J1C0030:N2C@2XPdh0ZHA?0080ZXE@00<0ZhIA0:b8F02/R5P00`2^RUX01`2/R5P0ZXIF0:V5
E@2^RUX0[8QH0:Z6EP2WPe<00P2VPU820:N3D`080:^5EP2/QUL0[HUI0:b:FP2[ReX0ZH]I0:R:F02U
REL40:f9E@@0[8QD00T0ZHA@0:Z5D@2[QU80[HQD0;2;E`2bSET0/hiJ0;B?F`2cSEh00`2bS5d0102d
SUl0]Y1Q0;VCI02kUFH30;^GH`@0_9QT00<0_IUU0;fHK02mV6`01`2lUf/00`2lV6P0_IUY0;jJJP02
0;nKJ`030;jJJP2mVFT0_9QX00@0_IUU0P2nVVH20;nKI`060<2KKP31W6l0`Ia_0<:ML033WW40a9mb
1035X7<20<JQM0<0aj9e00<0b:=f0<BRM034XW@01P34XW@00`34XGL0`j1f0<6NM0030;nLLP80`Iid
00P0_ie_0<2NL031Wg40`Z1b0<6OL@30WW00_Ya^0;bJK0<0^iU[0P2jV6X30;VGJ@80^YQZ0P2iUfT4
0;RFJ0P0^YQZ202jV6P20;bJJP80^iUY0`2jV6P00`2iUfL0_IUY0;bHJ0020;bHJ080^iMW0P2jUVH8
0;NCH`80^9AJ00@0]i=I0;JBF02fTUP0]I5G0P2dT5H0202bSUX0/HeI0:n;E`2^RUH0[h]G0;2<F02a
SET0/hmK0P2`RUT0102_RUH0[XUD0:f8D`2/Qe020:^7C@80ZXID0P2[QeD40:b8EPT0[HUE00<0[HQC
0:b7DP2[QU400P2ZQE001P2/Qe80[XUD0:n:E@2]RDl0[8Q>0:Z5CP80ZHA?00<0ZXEA0:b6E@2]QeH0
0`2YQE401@2ZQU80ZhMC0:^7D`2[Qe<0[8QD0080[8YJ0`2]Re/30:j<G0060;B?HP2cSel0/hmO0;:>
G02aSET0/8eG0P2_S5@00`2aSE<0[h]A0:b8CP020:Z6C0030:b8CP2_Re40/XiD00@0[8MB1P2]R5<0
102/Qe80ZhIA0:Z5D02YQ4l20:R3CP80ZHA?0P2XPdh20:N2C@80YX5<0`2TOdX[ooooo`00:_ooool0
1P2XODH0Yga50:MlA`2VNdP0YGY70:AhA`80XgM800@0ZX5=0:V0C02WOTX0Y7]70P2SNTH20:AkA`P0
Yge;0P2XOd/30:V0C0<0ZX5=202/Pdl80:Z5D@040;B:F02bR5H0/8ID0:j4DP80[H=A00<0[hEC0;26
E02_QE<00P2_QE<30:j4DP80[H=A00@0[89@0:^1C`2[PDl0Zh5?0P2ZP4h20:UoC@040:F0C02TOd/0
XGa809mjAP<0WGQ40`2NNDD03@2MN4@0W7M309Ye@@2GLSh0UG0l09A_>`2CKSX0U6i109=]@02BK3l0
TF/n091Z?@2>J3/00P2=IcX0202;IS`0RVDk08UT>P27HSP0QF0f08=N=022GC<0PE`b0P1mFS8207aI
<@0D07]H<01jEbl0NUL_07YG;`1`Db/0LUD]07AG;`1eF300MUTa07EH<01dEbl0LeH^07IF;`1gEc00
N5Pa07YJ<`1lG3D0OUhg07mO>020H3T2089Q=P0408AQ=`28HcT0RF@j08aU?080SfDm0P2BIcX02@2C
J3/0UFXm09I[?P2GK3l0V6e009U^@@2HKS`0VFlm09Y`?P0209]a?`0309U_?@2GKC/0UV`j0080UFm0
0P2DKSl309=]?P03099/?@2EKd00U6ho0080U6ho0P2CKCh2099/?@80TF`h0`2@JcL308mZ=P<0SfTj
1@2@JS/308]U=P80S6Hg2`2=IcP808iU>@<0TFHi0`2@ICP208mT=`0608mT<@2>I380SF<a08aT<`29
Hc@0R6<f0P25HcH908YT=`P0RF<d00P0RfDf08MQ<P24GRl0QV0a08]U=P2=IcP0RV@e08EO<080Qf4`
0`28HS4308US<P0308EP<`26HC@0Qf8e0080R6<f00<0QV4d08AO<P23GS400P27GS001025Gc00Q60`
08AP<022H302085Q<0<0Pf4c0P24HS@308ES=@0308eY>@2>JSX0SVXj00@0SVXj00<0Sf/k08iZ>P2>
JSX00`2?Jc/3091/?080T6hn00@0Sfdm08i/?02>K3`0SF/k0P2<JSX00`2@KSh0Sfdm08i/?00208e[
>`0;08m]?@2AKcl0Tg51095]?@2@KSh0TFlo091`?`2?LCl0Rflm08Q^>`27KCX00P2;Kcl0902:KSh0
RFdm08M[>`24J3P0P6@d07iR<P1mH3@0N5d`07EJ;`1bFC00LEXa06iH<@1UDRX0H4`W05Y79`1EA2H0
Cd0S04Hj800n=Ql0>3<O03<`7@0a<1h0;BhP02//7P0Y:Q`0:2TK02LX6P0X:A/0:BXL02X[7@0V:Q/0
9RXL02DY6`0S9Q/08RDL020S70807b4L400P8aX901hQ6P807b0H00@0824I024R6P0R8a/08R<K0P0S
91`0600R9A`08RDJ02<U6P0U9AT0:RPK02h[700a;Qd0=BlO03L_6P0h<1/0>C4L03/c7P0m=B00?SHQ
03lg8P10>2<0<S@N02la700/:aL0:BPF02XW600_:Ad0=B`S03P_9PP0<bdO0P0a;Ql0100`;Ah0;b`M
02l/7@0^:a`202dZ6`0802//700Y:QX0:2TK02LW6`0V9Q`09bLO02TX8`0Z:B@802LW7@808b@N00@0
8R<M024R700Q8Q`0824K0P0O81X02P0K8QX0828O02@S8@0]8b80=RPO04Lb7@1J@R00IThR07ED:@1d
DbP2079A9P0D07MF:`22HCH0Sfi309UhC@2JN4/0X7m:0:V=C02]UDl0WHQ907eW?P1KA3@0ARh^02`b
<00U:bT08RHU02HX9@0S9B007b0J02<R7@0[:b<202<S8@8092@R00@09BDS02HV900V9R@09bLU0P0W
:2<0300V9b409bPP02T[800[;B00;S0S030b900a<BL0<30V02l_9@0^;R@0;BdS02`/8P80:b/Q00<0
;BdU02h^9P0_;bL00P0`<2P04P0^;RH0;2`T02XZ8P0a;B80<RhS03D_8`0h<2D0>S0T03hb900n<R80
@3<S03hi9P0n=bD0@3DS04@e8P1;=R<0ECXW05dn;080HT4^00`0HT4P05`m7P1D>A`0C3@J04<a6`0n
<B00>c8S03/c9P10<b00@SDR04Hi9P19?2T304/n:`0304Xm:P13<a`0AcLP0080BSXS00X0B3PQ04Lg
801;>b@0CclX050j8P1A>b<0DS`T05@n9P1F@2P0Ed4Y0P1I@b/305U5;00305Q4:`1G@bX0ET8Y0080
ET8Y00<0E4<Y05=2:01B@BL00P1B@BL02@1EA2X0EdH/05U8;P1B?2D0DcdV058n9P1A?bL0DT0X0592
:@020594:P0305M5;@1E@b/0E48Z0080DT0X00@0Dd4Y05A2:P1E@b/0E4DV0P1DABP00`1C@bT0Dd<Z
05=3;0020591;@P0CShU00D0ASh[04@l:@11>2L0?SDV03/a9@0203X`9P0N03X`9`0l<2@0?c<W048f
:011=BL0?S8R03db800o=200@SLS03Tg7P0m>2@0?cHW040b9@16<b@0ECdS06M=:01eFRd0M5hU06EE
8P1?AQl0?CTN03Hc800l=B<0AcXW0590:P1B@2`0Dd4]05=1:`1C@BT0Dd8X0P1C@RH04@1C@R@0Bd0^
04Lo;013>RT0?SLW03Xd9P0g=2D0=S@W03Hd:00j<Ql0?3@Q03hf8`10>2D0@CTV040h9@0o=b@0?SHS
00<0@cHU0P14=bH304Dh9`08040c8`11=2@0@SDU040c8`0n<B40@3<S04Lj:P1>@C4304`m9P0604hn
9@1A@2H0ED@X05]8:P1PBb`0Hdh_0P1[CRh0=P1[CR`0KE4/075E;P1eFC40NEde07aQ=P1hISh0MF<k
079P>01_GCD0KU`d071N=P1cHCT0MF<k07iT@@1oID80OfM307iX@`1lJ4<0NVQ207UW@@1gJ440NFXo
07Y[@01lKD80OVm4085bA`23M4T0QGI;08IgC02<L3h0SG=0091g?`2COD<0VHE60:2?BP2VUDl0Z9YA
0:6BE`2SU5T0YYMN0:RIHP2WUf<0Y9AQ0:2@G@2NSUd0VXEF09N1D02ENdX0UGM309ai@`2XOdL0]HQ?
0;f>EP80^8m=00@0]hi<0;J=B`2fSD/0]Ha:0P2dRdT0502^T4X0/99<0;FDC`2hUE40_9MC0;jGE02m
UU<0_YEC0<6OG`2oWEh0_I]N0;VFGP2eTU`0/HeK0:j:FP2/QeX0ZhQ@0:f:DP2`SED0/i1H0P2dTET0
2P2bSeL0/HiF0:nAG`2]Sed0YXQF09eoC@2DMT@0TgE309QjB02NP4h80:F0B@0C09ejA02LND<0W7U3
09ejA02OO4H0Xh1:0:J3C@2YQU00XWm90:>0B02TPDT0Y8570:>1A02POSl0WG/k09aj>P2OOCH0Xh4j
0:V7@0020:f;A00C0:V7@02SPCX0Wgdf0:n7@P2VOST0WgLb0:5i=02YPC`0[8@o0:R0>`2QNC@0YXQ8
0:J8BP2UQd/0YHI?0:>3D02QPE80WgiA09imD0030:R5B`040:N4BP2VPdT0YX=90:F2B080Y85700<0
[XE30:f4@P2ZPCl00`2XOcd07@2ZPCl0Zh900:9n@02NNS`0VWPi09Uj>P2KOCd0Vgln09Ql>`2BNCL0
V7Xn09Yl@02NOT40XX110::0@02ROcd0XW`k0:1k=`2TOT00YGm10:B0@P2SPD80XX1109en?P2JO3`0
V7Xj09Mj@02FNCl0UGPn00<0TgHl00@0U7Lm09Eh?P2KO3`0WWlo0P2QPT80402PPD40XX=30:R9B@2]
STh0[XE30;RACP2fTe<0YXI909UoA02IQDX0UXE=0921B02QQTl0XXM@0:B9DP2VRe@20:N<E@0:0:J;
E02URU<0WXA;09n5C02PQTd0XHM>0:26C@2NQ4/0Vh5809UoAPP0VX1700P0VX5809V0A`2FOD@0UGa3
09Ak@P2EO4<0Ugi509QoAP80UW]400T0Uga509IkA02ENT<0TgQ1091e?P2>Lc`0SG@l08ac>`2;LSX0
0P2:LCT0402;LSX0S7<k08ed?02GLd40VGQ50:5oC`2YREX0/iAV0;^NLP31YWT0aJYo0<b`R03=/HT0
bZj60<>WO`2iWGD20;>GK`0I0;FIL@2gWWH0^J1h0;^SO@2oZH@0a;2=0<^hU`3B_ih0e<BS0=W4/@3M
b;<0hlfe0>K>/P3QbJL0e[nF0<^cQ`34[7h0]IQL0:^>DP2OPTP0UWU1099d?P2@LSh0SFlk08]]>`02
08e_>`80S6hl00d0RV/l08IW>@21HSH0OEhb07YJ<@1cDb`0LUD]07AF<01bERl0Je4/069:9P1I@R00
E3dK00H0AcTO0P16>1h0200n<a<0?c@D040e5`11=QX0@3@J03hb6P0k;aL0>BdG0P0n<B00100m<1l0
?2lN03X]700i;1/203P[6P80<B/O0P0`:Qh302lY7@0302hX700[9ah0:bLN00H0:bLN0`0/:1`202/W
6`<0:RHJ00@0;b<G030T600`91P0<BDI0P0b9QX203<W6`<09RHL0P0W9ad302PX7P<0<2XJ0P0a:a/3
038/70P0>bhM200h:aX303`[8@80?B`R0`0n;B<01@0c:1@0=R/G03T^6P0l<Ad0?S<O0080?c@P00@0
?S<O044e7`0o<ad0?S8L0P0l<1X0100n<Q`0@3@N044e7`19<ah304Xd7`80BcDP0P1<=R40401D=B40
DSHQ054f8@1>>240C3XR04/k8P1:?280B3`R058h7@1C>Ah0EC/P05Lm8P1H?R<0EcdR05Dk801D>Ql9
05dn7`040612801Q@b40HdDS06E79@80ITPV0P1UAbD01P1ZC2H0K4hX06mA:`1aDbd0LeD_079D;P80
LE<]00H0LU0]075?;01aCb`0KddZ06i<:@1]BbP206a:9`0;06A=901VCBD0J4lW06]?:01]CbT0KThX
06i<9`1]BbH0KU0Z06e?:@1/CRP00P1[CBL0101]CbT0Ke4[071B;01`DR`206mA:`0306i@:P1]CbT0
K4hX0080JddW00<0K4/X06e<:@1]C2T00P1^CBX306m>:`0;06]>901^CRD0L50W07=B:@1fDb/0NU@]
07eF;`1nEc00P5/a07mJ<01mF2h00P1lEbd00`1nFBl0P5/a085L<P02089K=003089L=@20GCD0Oehe
0080Oelf00<0OF0f08=Q<@23HC400P22H3001021Gbl0P5h^081N;P1oGBd307mL<P80P5dc0`21GS@0
1022H380Pf4c08=Q<`24HS@208ES=@80QV@f00<0R6<i08IQ=`23GS@00P21G3802@23GS@0Qf8h08UT
>P25H3<0QV4d08MR=@29I3L0RfHi08aW>P0208iY?00408mP=02AHSH0U6Di09IW>`80UfPl00X0UVLk
09EV>P2BJ3H0U6Xh09Q^?02KLCl0W79009]a?`2JL3h0V6hl0P2AKC<00`2BKS@0Tfle09A`=P0209Ea
=`0309Ib>02IL3`0VG0l0080V6lk102GKSX0102FKCT0TVTe09=Z=P2EK3P309M^>P0809I]>@2EK3P0
V6hl09Q^?02IKcd0Vg4o09ab@02NM48209me@`<0WgI200P0X7M30:5hA02TNdL0Ygi:0:V0C02PO4`0
XWi>0:B0D0<0YX9B00L0Y81@0:=oC`2XQDd0Z8E=0:R5C`2XQ500Z8AB0080Z8AD00<0Z8=F0:R4E02W
Pe<00P2WPe<20:J2DP80YH5A00D0ZXMA0:V6D02XQDl0YhA>0:F2C0020:B1B`030:>0BP2UOe00YGm@
00H0YGm@00P0ZhMC0:Z6DP2YQE40Yh=?0:J2CP2TP4`0Xgm;0:9nBPD0YX9>0`2WPdl01P2VPD`0Yh9=
0:N2C@2XPdh0ZHA?0:Z5D080ZhIA00`0[8MJ0:f8F`2^RE`0[hYM0:j9G02]R5/0ZhII0:Z5F02_Re/0
[HUI0:Z6EP2XQ5@30:J2DP090:N3D`2[QEH0[8IG0:f9F@2/RUX0[8aK0:Z<FP2YReT0YXYH0080[HUE
00<0[XYF0:n;E`2_ReL00`2_ReL0202ZQE40ZhIB0:f8E02_RUH0/XeI0;B?F`2fTEd0]i9N0P2eSf82
0;B>H@040;F?HP2gTF@0^I=V0;^EJ0H0_9QT0P2mVFD30;fHK0H0_9M[00<0_9QX0;fIJ@2oVf/00P30
W6`00`2oVf/0_IUY0;bHJ0020;nKI`H0_YYV0P31W6l00`32WG00`iia0<BOLP020<FPL`@0aZ5d0P37
XWD30<RSMPP0aJ=e00X0a:5g0<>PMP31WW@0`9ec0;nLLP30WG<0`Iid0<:OM@2oWFl0`9i`0`32X780
0`30WW00_Ya^0;bJK0020;^IJ`<0^YQZ0`2iUfT20;ZHJP80^IMY0`2hUVP00`2gUFL0^YQZ0;ZHJP06
0;ZHJPP0^YQX0`2lVVX20;^IJ@<0^YQX0P2mVFT20;bHJ0<0^iMW00<0^YIV0;NCH`2gTf<01P2gTf<0
1P2jUU`0^IEK0;RDFP2gTeT0]Y9H0;B@EP80/hmE00<0/XiJ0;6=F@2_ReL00P2_ReL02@2`S5P0/XiJ
0;>?F`2aReX0/8YI0:n:EP2^RE@0[HQC0:b7D0020:^7C@80ZXID0P2[QeD30:b8EP030:f9E`2^RUH0
[XYF00L0[XYF00<0[HQC0:b7DP2[QU400P2ZQE001P2/Qe80[XUD0;2;EP2]RDl0[8Q>0:Z5CP80ZHA?
00<0ZXEA0:b6E@2]QeH0202ZQU820:b:FP<0[H]K0`2^S5`02`2dSf80]91P0;>?G`2bSU`0/HeI0;2=
E`2`SED0[haD0;6=D`2_Re40[8Q>0080ZXI<00@0[8Q>0;2<DP2bSU@0[XUD0`2]R5<30:b7DP070:^6
D@2/Qe80[8MB0:^6D@2ZQE00ZHA?0:R3CP0:0:N2C@<0YX5<:oooool002[ooooo0P2WOTX02@2VODT0
YGa80:AkA`2SNTH0XWU50:5hA02VODT0YGa80:AkA`020:9iA@060:AkA`2UO4P0YWe90:ElB02VODT0
Z7m;0`2ZPDd00`2XOd/0Ygi:0:V0BP070:V0BPP0[H=A0P2^PeP40:f2E`80[85F202^PeP01P2`QDh0
[hI>0:n6D02]QE40ZhIA0:Z6DP80YhIC102[PTh40:Z1C@040:F0B`2TOdX0Xgi90:9mB080XGa700<0
WgY509iiA02NND@00P2LMd<0102KMT80VGA009Qc?`2FLCd209E`?00809E_@P2DKT40Tfe0099/?`2@
JSd0SfTl08iX>`2=IcX2089O=@0608=P=P24HCL0Q64g08=P=P22GcD0PEhd0P1lFC40101kF300NUL_
07YG;`1iERh207QE;@P0NeP`00D0Me<_07QD<01hEBl0NEH^07UF;00207YH:`0707YH:P22GC00Peha
08EP<`27HSD0RF@g08]V>@0208eX>`80TFXo00H0TV`o09=]?P2DKSd0UG0l09Ia?@2FLC`309Mb?P80
UW4m0`2EL3`809=_?`P0Uf`o0`2BK3d2095[?0<0T6Xk0P2CJ3/2099W>P80TFHi1@2@ICP208mT=`<0
SV<f00<0S6Hi08]U>029HcH00`28HSD308YT=`0:08]U>02<IST0S6Hi08]U>029HcH0Qf4d08EO<P28
HcH0RF@g08YU>080S6Lj00H0RVDh08UT=`28HcH0R68c08US=02:I3D208]U=P0308YT=@29Hc@0R68c
00T0R68c0P2<ISL308]U=P<0RV@e00<0Qf4b08QR<`2:I3D00P2;ICH00`2:I3D0RF<d08QR<`0208YV
=P80RFDe0P28I3@208MS<`@0Qf8e1026HC@02022GC00Q5lb08MR=@29I3L0RVDh08QS=P26HC@0QF0c
2029I3L208]V>@80S6Lj102=J3/308]W=`0308aX>02=JCT0SFTi0080SVXj0`2BL402095_?`<0T6hn
202BL400<02?L440TW=409AeAP2ALT<0SFho08]/?@2<KCh0Sg1108ic?P2=LSd0Rflm08U]?@26JS/0
Q6Lk089U>@21I3X0O60^07YP;`1fFb`0L5P/06]D:`1WDB`0HTh[065=;01IARD0E4@S04ho8016>al0
?SLM03Pc7@0d<Qd0<c8N02X/500Z;1H0:B/E02PZ5@0W:1H09RLG02HW6@0U9QP09BPO02<V7@0Q91/0
7b8I01hQ600M81L07R4H01lR6@8082<L0`0O8Q/301hQ6P0301lR6@0P8aX08RDL00808bHM00<08RDL
024T6`0P8aX02@0N8AX2020Q6@03024R6P0R8a/08b@L008092DM01T09BHN02@U7`0V9Qh09bLO02/X
7`0]:Ah0<B/O03<[7P0d;1l0=3DU03He8`0g=240>S<P03`d7@0o<aT0@S@I04@e600a;2H0;b/R02`X
7`0Z9Q/0:RHJ02`Y6P0`;A`0<RlN0080=2hP0P0c;Al0100b;1h0<B/M034[7@0`:Q`202l/6`0602h[
700]:Ad0;2PM02/W7P0Z9Qd0:RDO0P0W9ad302HV70<09BDK00`09RPM02DW700S9AX08R@I02<U6P0T
9Q/09RPM02PZ7`0S91h08R<M020Q6`0M7QP201`M5`807AhH01P081hS02LS900_:280=b/K040`5`1?
?1/0HddT075I:`1mFcD0N5H`07ED:`1jFBh0QF@g099b@`2KNdX0X81?08MlCP2MR5<0]95G0;J=C`2L
MCh0KeH^04@l9@0Z;B8202DW90<092HS0`0S9B8802@T8P0902DT7`0V9B00:BTQ02`/8P0_;b<0<S<U
03@e9@0e=RH0<34S00<0;c0R00@0<34S038c9@0d=BL0=SLY0P0h=RL01P0h=BH0>38T03L_8P0g;B40
=R`P03L[7`80<BhO00@0<RlP03<`8@0e<R<0=S<T0P0g=2D01`12=B@0A3@T04Df8`17=R80BcTS054m
9@1G@BX00P1I@b/0401A?Rl0CCX[04Hf9P10<b80>S8O03Pc7`0h=R40>3LR04Lf9018=bD0BSTW04/j
:01<>bT0BcXX04Xi9`19>2H204Tj8`0404Xj8`1:>280BSPR04`g8P80CCLR0P1@?RP03P1A?bL0DD0V
05919@1C@R@0Dd<R05A48`1K@280FT4R05Q18P1E@R@0DD8U04i39`1<@bH0BT<W0`1?@2/30511;080
DD8]00<0G4@X05]39`1J@RH00P1I@BD01@1J@RH0Fd<W05a4:01FARl0DT8[0080CShW00D0DT8[05A4
;@1C@b`0DD4Z05528`020511900304lo9@1??bH0CShW0080CC`X00<0C3`R04dm8`1>?R@00P1>?R@0
201<?280Bc/Q04Ti7`18>b/0AcXZ04@g9`10<b<0?S4Q0P0m<2001`0n<B40>3<O03Pc800h<b00>38R
03Pb900h<RH00P0g<2H0700l=RX0?3@W03/c9P0l<b@0@CDU04Lj:@1>?b`0DD8_0598;@1CAbd0Cd<Y
04/m8`17=ah0B3HN04lk8`1E@BT0HD@R05i48@1L@b@0Ed8S05=29P1@@RP0CD4[04a1:`0m>Bd0?3P/
03Te:@0g<bL303Da9@0303Hb9P0f<b@0=S<T0080=c@U00@0>3DV03Tf9`0i=RL0>SLX0`0j=2H203/e
9`<0?3HX00P0@3H]03le:`10<bX0@38W04<c9P17=BL0BCPX04`i:P80CCdT00/0CShT05509P1F@RL0
FTDX05m8:@1QBRX0HdX[06E?:01XDR/0KEL`079L=@0207AN=`0@07=M=P1aFc@0Kehc071O=01bH3P0
LV0j075O>`1_G3/0KEXi06]H>01`Gd40Lf1007AQ@@1fHT40NF9007]S?`80O68m02P0PFDn089V?`24
J400R6e208aaA02@MDH0TgQ909EkBP2FO4T0Uge:09IoB`2GPTd0Uh=>09N6DP2HQe<0V8QD09FAD@2F
TU<0V9AG09RCF`2GT5X0Th]J08n7F02=QEL0TGE=09AgB`2KNdX0YH570:j7AP2hS4D0`9530<BCA02k
Wd/0^YeA0;VJF@2gUV00]IAO0;JCG@2eTeH0]99B0P2aST`09`2_SDd0[8e<0:f>CP2^T580[i9F0;2C
E`2gU5`0^9EM0;ZGH@2iUF40]I5O0:n;F@2YQED0YH5A0:n2A`2/PTP0ZX160:V0B02ZPd`0ZhIA0:j:
EP2aSET0YhmC0::7DP2LNe00V79=09U]B02PKd@0ZGI10:ij?P2WOd40ZX940:f5A`2_QdT0[XI80:Z2
A02UOCl0XGTk0:Ab<`020:=c=@0G0:9d>02SMS/0YG]10:MnAP2YP4P0Wga409Yg?`2GMCP0VGLh0:1o
?02TPc`0Y8@k0:61=P2KO4D0W7e609ioB02PPDX0XH9;0:21BP2OP4T0WWm809Qi@P2MOTL00P2RPd`0
1@2MOTL0VW]409]lA@2NOdP0XH9<0080XhA>00H0WWm909Mh@P2CM3h0Tg@n09Ef@02PPT820:63@`0C
0:>5A@2TQTH0YHM70:B6AP2SQDD0XXA40:J6B@2UQDP0XhA40::3@P2RPd00Y8I00:J8@02WRD40YXA4
0:F3@`2SPD40XGlo0:1n?P0309mm?@80W7Pj0P2KMcT01`2LN3X0Wg/m0:5m?`2SOd40Wge00:5o@P2T
PTD00P2UPdH01P2RP4<0WW`o09]i?02GN3P0UWLg09Ae=@<0Tg@d01D0UGHf09Ig=`2FM3D0VWPi0:1n
?`2VQ4D0ZXQ90:V7B02WQDH0YH=40:f:BP2]RD/0/8iA0;2@E`2SQ4h0TgE109QiBP2UREX0XXQ=0:>9
CP2TRTl00P2URe001@2SRDh0XXQ=0:67C02OQ4d0X8E>0080XXM@00@0XHI?09n4C@2LPDX0Vh190P2M
PdX209b2B@<0Vh5800@0VX1709QoA`2HOdL0V7m70P2GOTH309ImA@0609V0B02HOdL0UWe509Ak@`2B
ND40T7Lo0P2>MCd208ic?0<0Sg@m0`2@MCh03P2HMCd0VWU30:60B`2ZRUT0/iAV0;ZML`30Y7`0a:R1
0<:ZQP36[XP0b;2:0<>/P`2iXWP0/9U]0P2/UVL06P2gVG<0^Yig0;nRP030YXD0`JR:0<F]T`3<]Yl0
d[bU0=_4_03Nb;d0h/bn0>?>^@3Obk00elBT0<jlV038]Y00_iiY0;JEH02XRE80WWm809YmA@2FO4<0
TWU0091g?P2FM4L0U7=60P2@Kd805@2;K3h0QFTj081U=P1kHc<0NF4a07MJ;P1cERX0L5<Y06iA9`1^
DBT0JT`V06=58@1N@1`0CSdQ04dl8P19>Al0ASPN04<g7`13=b40@cPT044i900304<i80D0@SPO00T0
?c@R03hc8@0m<R00?34O03/`7P0j;ad0>BhL03P]6`0d;Qh00`0c;Ad2038/7080<B/K0`0a:al2030Z
7P<0;bTM200]:Ad402hX70@0;BLK0P0`:Qh202lY7@<0;RPL00D0;BLK030[5`0a;1P0<B`H038]6@02
03<^6P80=2lK0`0m<1d503`_70@0?c0K100n;aX803hc7@<0@30P0P11<B43048b8P80@cLQ0P14=B00
1014<al0A38N04Ha7P15<1d204De7P0604Hf7`17=b00BCTR04Xj8`1;>b@0C3`U0`1@>ah2054l7`<0
DSdP00T0FS`T05/m9@1L?R@0GClS05m2901P@b<0HD@T06548P1N?RD0101O?bH206109`80HD4X00/0
Hd8O06A3801UA240IdHS06U89@1ZBBH0JdXW06a;:01[CbL0K50X06eA:@0206iB:P0;06eA:@1[CbL0
JThV06a<9@1]CBH0KdlX071@:@1aDBX0L50Y06m?:01^CRL00`1/D2T206eA:P<0KU8[0100M54Y07=@
:01aCRH0L4dU075>9P1bCbL0M54Y07IC:`1cDbd0LU8/075A:`1`D2X0KdlY06i>:01]CBL0K4`V0P1[
CbP0101/D2T0KE4Z06eA:P1^DR/206mC;080M4hW0P1eCbP0101fD2T0Me4Z07MA:P1hDR/207YD;`07
07]E<01lES40OELb07eG<P1nF3<0OeTd085M;@02089N;P0308=O;`24H300QF4a0080QV8b0P29I3L2
08QS=P0408MR=@26HC@0QV4d08IQ=080Q5lb0P23GS4208AO<P0F08EP<`26HC@0R6Hh08QV>027ICL0
QF<e08=Q<`22H380PEla081N<023GCH0QF0f08MR>029I3P0RVDh08UU=@29IC<0R6@b08IQ;@28Hbl0
RfHb08iY=@80SfXf01/0SVTe08eX=02>I380SfDc091V=02AIcD0TVPf09=Y=`2DJSP0UF/i09E/>02F
KCT0V6lk09U`?02JLCd0VG0l09Q_>`2GKSX0VG0l09Q_>`2FKCT0UF`h09I]>@2HKc/0VW4m09]b?P2J
LCd00`2IL3`309Q_>`80Ufhj0`2DKT4209E_@P<0UW13102GLSd0102IM3l0W7M209iiA02PNdH209ei
A@0609ijAP2PO4P0XGe90:9nBP2SOd/0Y81<0`2WPdl20:R4D0<0ZHEA0`2XQUH20:N5E@<0YXAD0`2W
QEL20:R6F0<0ZHMI0P2]QE401`2/Q500Zh=?0:Z2CP2ZPTh0ZH5=0:R0C02VQ5@00P2VQE800`2VQE00
YXE?0:J6C@020:J6B`80ZHAH00<0Z8=F0:R4E02XQ5800P2WPdl01`2WQ4h0ZXM=0:Z7C`2ZQe40ZXID
0:Z5F02ZQET00P2ZQ5d20:N3D`040:R4E02YQED0ZXIF0:Z6EP80ZhMG00<0Z8IF0:Z8F02/RUX00P2]
Re/02`2/RUX0ZXQH0:V7E`2[RE/0[8YL0:f;G@2^S5h0[H]M0:Z8FP2XQUP0YXAF00@0/8iN102aSel2
0;>>H@030;B?HP2eT6<0]Y5T0080^9=V00<0^IAW0;>AH`2cTF<00P2dTV@30;FCI@090;JDIP2fTV80
]i=S0;RDI02iUFD0^YIV0;^GI`2lV6P0_IUY00<0`9aZ0P31WF/30<:NK080`Ia_0P30Vfh40;nJK@04
0;jIK030Vfh0`9]^0<2KKP80`Ia_0`32WG001P33W6D0`i]W0<6LI`30W6P0`9aZ0;jLK080_Ie^0P32
Vg820<>LL`040<BMM035WWD0aIie0<JOMPP0aJ9h0P37YGL01036Y7H0aJ=e0<FSM@34XW@20<>QL`80
`Z1`00@0`Ima0<2NL@30WG<0_iad0P2nVgD30;nLLP80`9ec0`31WW@40;fKK@80_9Y/0P2kVF/20;RF
IP80^IMW00@0^YQX0;^IJ@2kVFT0_9YZ0P2iUfT0102jV6X0^iU[0;^IJ`2lVV`20;fKK@<0_9MZ0P2m
V6/30;jIK0P0^YQZ0P2mV6`00`2mV6/0_9QX0;bHIP020;^GH`030;^HHP2kUf<0^YIR0080^YIR0P2i
UF430;RDH0050;NCG`2fTUh0]I5M0;B@G02bSUX00P2aSET0202gS5L0]8]E0;:9E@2_Qe@0[HMF0:j:
FP2_SEd0/HmQ202^ReD00`2[Qe<0ZXIB0:V5D@020:R4D0030:Z6DP2/R5@0[XYF0080[HUE102^RUH3
0:n;E`060:n:G@2_Re/0[h]K0:n;F@2_ReL0[haF0P2_S5@0202aS5L0/8]F0:n:E@2]R5<0[8MB0:Z5
D02YQ4l0Z8=>1@2]RED30:b8E080[hYN00@0/8]O0;6<H02bSF40/XeQ0P2cSV802`2gTel0]91L0:n;
E`2/R5@0ZhMC0:j:EP2bSUX0]I5M0;:>FP2`S5P0[HUE0080ZhMC0140[8QD0:j:EP2`S5P0[XUL0:f8
F`2[QUT0ZXEH0:^6F@2/QeX0[hYM0;2;GP2]Rdh0[8Y=0:b9C`2[R4h0ZXM?0:V6D0020:R4D0030:N4
CP2XQDl0ZXMA0080ZhQB00<0ZXMA0:R5C`2WQ4h00`2UP4/[ooooo`00:_ooool01@2VODT0YGa80:El
B02UO4P0Y7]700<0XgY600<0YWe90:ElB02TNdL00P2SNTH01P2TNdL0YGa80:ImB@2UO4P0YWe90:Qo
B`80ZX5=00<0ZH1<0:QoB`2WOTX0202YP4X80:f3D@P0[H9E202^PeH01P2`QDh0[hI>0:n6D02]QE40
ZhIA0:Z6DP80YhIC102[PTh40:Z1C@040:F0B`2TOdX0Xgi90:9mB080XGa700<0WgY509iiA02NND@0
0P2LMd<0102KMT80VGA009Qc?`2FLCd209E`?080U6i100T0Tfe0099/?`2@JSd0SfTl08iX>`2=IcX0
QF8h08AQ=`23H3H01@22GcD207aI<@0407]H<01jEbl0NUL_07UF;P80N5D]201jEbl207MC;`0307QE
;`1iERh0NUL]0080NeT/00T0O5X/08=N<@24Gc80QV4d08QS=P2:ICP0S6Lj08eX>`2>JC`00P2AJSl0
0`2BK3l0Tfdn09A^?@0209E`?00409Ia?02GLSh0Ug8n09Mb?P80UW4m0`2EL3`809E_@0P0Uf`o0`2B
K3d2095[?0<0T6Xk0P2CJ3/2099W>P80TFHi1@2@ICP208mT=`<0SV<f00<0SFLj08aV>@2:I3L00`28
HSD03@29HcH0RV@g08US=P2:I3L0RfDh08aV>@2;ICP0RV@g08QR=@27HC@0R6<f08UT=`2:ICP00P2<
IcX01P2:ICP0RF@g08QS=P28HS<0RF<d08YT=@80RfDf00<0RV@e08US=028HS<02@28HS<408YT=@@0
RfDf00<0R68c08US=02;ICH00P2;ICH00`2:I3D0R68c08MQ<P0208YV=P80RFDe0P28I3@208MS<`@0
QV4d1025H3<01023GS40Q5lb08EP<`26HC@208MR=@0308IQ=025H3<0RF@g00L0RF@g0P2;IST208aW
>P<0SFPk00<0SVTl08aX>02<J3P00P2<J3P408eY>@P0T6hn202BL400802>Kd00TG9309=dA@2ALT<0
S6dn08Y[?02<KCh0Sg1108ic?P2=LSd0Rflm08U]?@26JS/0Q6Lk089U>@21I3X0OF4_07]Q<01hGBh0
LUX^06eF;@1XDRd0Hdl/065=;01HABD0E4@S04ho8P15>Al0?CDN03Pc7@0d<Ah0<S4M0P0[;AL0100Z
;1L0:BXH02PY6@0W:1P202HW6@0402DX7`0S9Qd08B@K01lR6@<07R4H00<07b8I020S700P8a`00`0O
8Q/301hQ6P0301lR6@0P8aX08RDL00808bHM00<08RDL024T6`0P8aX02@0N8AX2020Q6@03024R6P0R
8a/08b@L008092DM0P0U9Qh01`0V9Qh0:2PN02/Y7@0^:Qh0<R`N03@/7`0e;Qh00P0f=B<0100g=240
>cDO03`d7@0o<aT2048d6@08034/9P0_:b80;2PO02XV6`0Z9QX0;BXK030]700b;ah203@^8080<bdO
00@0<R`N034[7@0a:ad0<B/M0P0_;1/01P0^:a`0;BTM02`X7@0[9ah0:RHM02XU7`809bLM0`0V9Q`3
02DU6`0302HX7@0U9a`092HK00808bDJ00L092HK02HX7@0W:Ah08b@N028S7@0O81X07AhH008071dG
0P0M7QP0600Q7b809b<R02lX800h;1`0@S8I050m701RC2<0KeL[07UG<@1fE2h0ME@[07aK<028IcX0
U7A509alB`2OOdh0SGm@0:6<E`2fTeT0/h]>09A_>`1WCbT0?cTS02/^9@809BLT0`0T9R<302<U8PP0
92@R01P09RDP02LV8@0Y:B40;2`R02l_8`0b<bD0=3DU03Df9P0b<bD0<C8T030a8`0_<280<34S034b
900c=2H0=3DW03Le9P0f=2D0=c@U03Pb900h<2<0>2hR03L]8@0i;B42038_800403<`8@0d<B80=C8S
03Hc9080=c@U0P12=B@01@14=B80ASDQ04Xh8P1?>RD0DclW0080ET0Y00/0Cc`]04/j:P16=RH0@3<R
03/c800k=240?3LS03/i9016=B<0AcHT04Th9P0204/j:00304Xi9`19>2H0B3LU0080BCXS00@0BSXS
04/i8`1:>280C3LR0P1==b82058m:00405<o9`1D@2L0E40U05E29080ET<S00P0GD8T05]28`1J@b@0
ET<U05939P1?A2P0CD@W04]4:0<0Cd0[0P1@@B`30552;@0305e5:@1K@bL0FT8V0080FD4U00`0FT8V
05]39`1MABT0EdL`0592:`1>?RL0CclX0592:`1EABh0E4@]0551:P1B@b@205529@0305109P1??bH0
CclX0080CSdY00<0C3`R04dm8`1>?R@00P1??bD01`1=?B<0Bc/Q04Xj8017>RX0ACPX048e9@10<b<0
0P0n<B4203lb8P0603Xe8@0i=240>C@Q03Tc8`0i<bD0>38V0P0h<BL0700o>Bd0?SHY03`d9`0l<b@0
?c<S04<f9@19>RL0Bc`Y04e3:01?@bT0CT8X04`n9018>1l0BCLO04lk8`1D@2P0HD@R05i48`1KA2@0
Ed8U05=2:01?@2T0C40Z04]0;00m>Bd0>cL[03Te:@0f<RH303Da9@0303Hb9P0f<b@0=S<T0080=c@U
0P0h=BH203Tf9`<0>S@V0`0k=BL203`f:080?C<Y00H0?S8V040b9`13<bH0AcDW04Xi:@1<>BX204dm
900;04hn901A@2H0ET8W05Y5:01OB2T0HDXZ06=::`1TCRL0Ie4Z06]E;P1`FS<00P1bG3D08P1`FS<0
KeTb06iM<P1_GCD0L5hf071N>01^G3P0K5Th06YG=`1XECD0IUDg06UF=P1[F3P0KUXi07=L>P1gGc/0
NElj07YP>`1mHCX0OV8k085U?@25JSl0RFi108eb@`2@MDH0TWQ709AjA`2CO4P0U7e;09AnC02EPDh0
U89@09B4D@2EQE8208b7D01A08f6DP2<Q5<0RX9C08UnD@26NU00Q7Q>09=gA`2HNTH0WWm80:N5AP2a
S4H0^Y=60<:HAP37VTL0_Z=B0;bPEP2jW5`0^9US0;JEHP2cTUd0/I5F0;:@D02cT4h0/Xm?0;2>CP2_
SDh0[Xm?0:n?DP2`TU@0/I=E0;>@EP2dTET0]I9J0;FBG02bSUX0[HUG0:R4E02TP500[H=70:f3B@2/
Q4T0[HA<0:f6C`2]R5<0[XYF0;2<F02VS540XhEA09ekCP2JLdX0Vfm80:9bA02YN400[W`o0:Z2A02[
PdD0[HE70:j6B02/Q4H0ZX940:In@02TO3h0Zg/k0:]k?@2XNS`0Yg/n0:Il@02WOd@0ZH180:Z3BP2S
P4P0Wga209aj?@2NO3d0Xh8o0:N6@@2WQSl0YHDl09Yk@P2KO4<0WGi50080WWm600D0WGi509amA02K
O4<0UGHm09Yk@P0209n0A`0=09]l@`2INT40VW]209enA@2MOTP0Wh1:0:21B`2LODL0UWM1099c?@2C
M3h0UGI009an?P0209eo?`040:22@P2SQDD0Y8I60:F7A`80Y8I600h0ZXY=0:R8B`2VQdL0YHI50:F6
@`2UQd40YhU10:R:@P2UPd<0Y8920:>1@@2QOcl0Wgdm09il?080WG/k00/0WGTk09ah>P2LN3X0W7Pj
09ei>`2ONcd0XGdo0:=o@@2POT40XX130:F3AP020:J4A`0@0:>1A02POT40WG/n09Qi>@2GN3P0UGHf
09Ae=@2CM3@0U7De09Ef=P2FMcL0V7Hg09]i>P2POSl0Y8930:N5AP80Z8I700`0YhE60:f:B02^Rd/0
/Y1C0;:BE`2UQTl0UWQ409QjB02QQED0XXQ=0:>9CP2TRTl20:F;D0050:B:C`2RR4d0XHM<0:25CP2Q
QTl00P2RQe00102QQTl0WhA=09f2B`2KP4T209f3BP80W899102KPDP309QoA`80Ugi60`2FODD0202I
P4P0V7m709MnAP2EO4@0TgY2095h@02?MSh0SWDm1P2@MCh208md?@0Z09Uf?P2KNT@0XX5<0:Z:F@2c
U6H0^iid0<6UO@35ZH80`j^70<J^R038/8X0a:f40;ZSN@2bVfl0[YQY0:fGJ02fVG40^Yig0;nSOP30
YXD0`JR:0<F]T`3;]Id0d[bU0=[4^@3MakX0hLbk0>?>^@3Pc;<0fLJV0=:oWP3<^YH0b:Md0;jNJ`2a
TU`0YhQB0:64C02LPTT0V7i509Ek@P2JN4/0V7I90P2DLdH05@2?L480RFdn08AY>P22IcP0OVHf07aP
<@1iG300MEP/07=F;01cERh0Ke4[06Q:9P1RA200DSlQ054m8P1<>al0BCTO04Li7`15>B40ACTS04Dj
900304@h80D0@cLO0P10<b001`0o<Ql0?S4N03d`7@0l;a`0>bhK03X]6P0f;al00`0e;Qh203@]7@80
<b`L0P0c:ah2038Z7@<0<BTL00<0<2PK02dZ6`0]:Q/01P0]:Q/3030X6`D0;bLJ0P0b:Qd2034Y70<0
<2PK00@0;bLJ038[600c;1T0<b`I0P0d;AX203D^6`0303H_700m<1d0?C0M0080?C0M100l;a`3040a
70D0?c0K2010=1h01010<Ah0@C8O044b7`11<Ql2048c8080@c@Q00D0A3PR04<g8@15=R40AC@P04Hd
800204Lb7`0604L`7P16=Ql0AcLP04Lg8018>240BCTR0P1:>R<00`1;>b@0D3/N050k7P03054l7`<0
DSdP0P1K?BD01P1L?R@0GClS05i18`1N@B40Gd8R05m280<0Gd0T0`1P@BD306529P0H06A3801UA240
ITDR06M68`1YB2D0JTTV06]:9`1/BbP0JdlW06a@:01]DBT0KU8Z06mC:`1^DRX0K50X06]?9`1^CRL0
KdlX075A:P1bDR/0Le</079B:`1aDBX0L50Y0`1^DR/206mC;0<0L5@]00P0ME8Z07AA:@1bCbL0LDhV
079?9`1cD2P0ME8Z07IC:`80Le<]00H0LU8/075A:`1`D2X0KdlY06i>:01]CBL206]?:00306a@:@1]
DBX0KE4Z00<0KU8[0`1eCbP00`1fD2T0Me4Z07MA:P0207QB:`0607YD;`1kEC00NeD`07aF<@1mEc80
OUPc0P1oFC@01P22GRh0Pel_08=O;`24H300QF4a08IR<P80Qf<c2028HcH00`2=J3/0S6Lj08UT=`03
08MR=@0708UT=`2:ICP0QfDg08MU=`26I3H0QF<e08AR=00208=Q<`0=089P<P25GcP0QV4g08QS>@2:
ICT0RVDh08UU=@28I380Qf<a08IQ;@28Hbl0RfHb08eX=00408mZ=P0508mU<`2@IS@0T6Hd095W=@2C
JCL00P2DJSP04@2EJcT0UF`h09I]>@2HKc/0VG0l09Ya?@2IL3`0V6lk09M^>P2IL3`0V6lk09M^>P2F
KCT0Ufhj09Q_>`2JLCd0Vg8n00<0VG0l0`2HKc/309M^>P<0UFm00P2FL44309Ma@P@0V7<n00`0VWE0
09ag@P2ONTD0X7]609eiA@2NNTH0Wg]70:1lB02ROTX0Xgm;0:B0C02UPDd20:N3C`80Z8A@0`2YQE40
102ZQU80ZHMG0:V7E`2YQeL20:R6EP<0YhEE0P2XQUP20:V7F@<0ZXQJ00H0ZhUK0:j6D`2^QU<0[HEB
0:b4D@2[Pe020:Z2C`060:V1CP2VQ5@0YXAD0:J5DP2VQE00YXE?0P2VQTd01P2VQT/0Z8=G0:R3E`2X
PeH0Z8AD0:R4DP80ZHEA00T0ZHI@0:^8D02[R500ZhMC0:^7E@2[QUT0ZhIJ0:^6G02[QEh00`2YQED3
0:Z6EP80ZhMG00<0ZHMG0:Z8F02/RUX00P2^S5`00`2]Re/0[8YJ0:^9F@020:f;G@060:j<GP2_SEl0
[XaN0:b:G02ZR5X0ZHMI0P2_SEd0102`SUh0/HmO0;6?G`2bT6020;>AH@050;B?HP2eT6<0]I1S0;JA
I02hTfH00P2iU6L00`2jUFP0]I=U0;JDIP020;JDIP80]iEW0P2hUVP01P2gTf<0^9AT0;VEI@2jUVH0
^iMW0;bHJ080_IUY0P30W6X20<6MJ`<0`Yi/00<0`im]0<:ML031W6l00P31W6l30<2KKP80_iY]0P30
Vfh20<6LK`<0`Ye`00L0`iia0<>KI`33VfL0`IaX0<2LJP30W6`0_Ya/0080_Ie^0`34WG@00`35WWD0
aYmf0<JOMP020<NPM`80a:5g1035XWP20<JSN@030<NUM`36Y7H0aZAf0080aJ=e0P34XW@01`33XG<0
`Z1`0<:PL031Wg40`9ia0<2ML`2oW7@00P2nVgD30;nLLP80`9ec0`31WW@0102nW6h0_I]]0;fKK@2m
Vfd20;bJK080^iU[00<0^9IV0;VGI`2iUfL00P2jV6P20;^IJ@050;bJJP2jV6X0^YQZ0;ZHJP2kVF/0
0P2lVV`20;fKK@80_9MZ0`2mV6/30;jIK0P0^YQZ0P2mV6`00`2mV6/0_9QX0;bHIP020;^GH`030;^H
HP2kUf<0^iMS0080^YIR0`2iUF404@2hU600^IEQ0;RDH02gTel0]Y9N0;B@G02cSe/0/XiJ0;6=F@2e
RUD0]8]E0;>:EP2aREH0/8YI0:n;F`2_SEd0[heO00P0[XYF00<0[8QD0:^7D`2ZQU800P2YQE400`2[
Qe<0[HUE0:j:EP040:j:EPD0[h]G00H0/8]N0;2<G02`S5`0/8aJ0;2<F02`SEL20;2=E@80/8]F00H0
[hYE0:f8D`2/Qe80ZhIA0:Z5D02YQ4l60:f9E@80[8QD0P2^REd0102_RUh0/8]O0;2;G`2aS6020;:=
H@080;FAG@2cSe/0/8aH0:j:EP2]RED0[h]G0;6=F@2cSe/20;2<F0030:j:EP2]RED0[HUE0080[HUE
00T0[XYF0:f9F@2/R5P0ZhMG0:Z6EP2[QeL0[8QH0:j:FP2`S5`00P2]Rdh03P2/RDl0ZhQ@0:Z7D@2Y
QE40Z8A@0:R4DP2XQDl0ZHI@0:Z7D@2[R580ZXMA0:V6D02WQ4h0YH9<0`2UP4/[ooooo`00:_ooool2
0:=jAP<0Y7]70`2UO4P00`2WOTX0YWe90:AkA`020:=jAP030:AkA`2VODT0Ygi:0080YWe900<0Z7m;
0:V0C02ZPDd00P2YP4`00`2XOd/0ZH1:0:V0BP060:V0BPP0[89@202]PUD80:n4E`060;25CP2_QTh0
[hI@0:f5D@2[QU40ZXIB0P2WQU<20:b3C`80Zh9>0P2ZPDd20:V0C0040:F0B`2TOdX0Xgi90:9mB080
XGa700<0WgY509iiA02NND@00P2LMd<0102KMT80VGA009Qc?`2FLCd209E`?080U6i100@0Tfe0095[
?P2@JSd0SVPk0P2=IcX02029IS`0Qf@j08=P=P20GC<0Oe`b081M<`21GS@0PUle0P1lFC40101kF300
NUL_07YG;`1iERh:07QE;@0@07EA;@1fDRh0Me@^07UF;P1kF2h0O5X]07iL;`1nG2h0QF0c08IQ=027
HSD0RF@g08]V>@2=J3/0SVTl08mZ?@80TFXo00H0TV`o099/?@2CKC`0U6lk09E`?02EL3/309Mb?P80
UW4m0`2EL3`809I`@@P0Uf`o0`2BK3d2095[?0<0T6Xk0P2CJ3/2099W>P80TFHi1@2@ICP208mT=`<0
SV<f00/0SfTl08iX>`2;ICP0RF<f08QR=@27HC@0R68e08US=P27HC@0RF<f08YT=`0208aV>@0608]U
>02:I3L0RF<f08QS=P29I3L0RVDh0P2<IcX01P2:ICP0RF@g08QS=P28HS<0RF<d08YT=@80RfDf00<0
RV@e08US=028HS<02`28HS<01029Hc@0RV@e08]U=P2;ICH208aV=`80RV@e00H0RfDf08aV=`2;ICH0
RF<d08MQ<P26H34208YV=P80RFDe0P28I3@208MS<`<0QF0c0P24Gc8308=N<@0308AO<P23GS40Peha
0080Peha00<0Q5lb08IQ=026HC@02029I3L308aW>P80SFPk0`2>JC`208iZ>P<0SFTi0`2<J3P01@2<
JSX0SF/k08e[>`2>K3`0Sfdm0080T6hn00<0TFlo099`@02BL4001P2BL400;02=KSl0T752099cA02@
LD80Rf`m08UZ>`2;K3d0SVm008md?`2>Lch0S70n08U]?@26JS/0PfHj085T>020HcT0Of<a07aR<@1j
Gc00M5``06mH;`1YDbh0I50]069>;@1HABD0Dd8T04dn8@14>1h0?CDN03Lb7P0c<1d0<S4O02`^600/
;QT0:bdH02X[6@0Y:QX0:2TK02PX700W9a/092LN02<V7@0Q91/07b8I0P0N8AP201lR6@8082<L0`0O
8Q/301hQ6P03020S6P0Q91/08RDL00808bHM00<08RDL020S6P0O8QT02@0N8AX2020Q6@03024R6P0R
8a/08b@L008092DM0P0U9Qh01`0W9ad0:2PN02`Z7P0_:al0<bdO03D^7P0f;al00P0h=B80100k=R80
?3HP03de7P0n=1/203lc6@0802lZ900^:R40;2PO02XV6`0[9a/0;BXK030]700b;ah303<]7`<0<R`N
0P0a:ad202l/6`0602h[700]:Ad0;2PM02/W7P0Z9Qd0:RDO0P0W9ad302HV70<09BDK00`09RPM02DW
700T9Q/092HK02<U6P0T9Q/09BLL02HX7@0S91h08B8L01lP6P0M7QP201`M5`0:01dN600N7aT08R0Q
02PT8@0`:B40>RhN04@d6`1A?Qh0H4XS06YA:080LE4Z00h0M5@[07iO<`2<KCl0UgQ909eoC@2OPDl0
UXAD0:N@G02fUUd0ZhI?08EU=P1IAB@0>C@Q02/^9`809BLT0`0T9R<302<U8PP092@R00/09RDP02LV
8@0Y:B40;2`R02l_8`0a<R@0<c@T03@e9@0d=BL0<c@V034b9003030a8`07034b900b<bD0=38S03@b
8`0e<R<0=c4S03P`8`0203T_8`0503/_8`0e;b40=BlQ03H`8P0g<B<00P0h<R@203Tc9@07044e9@12
=BD0@SDT04@e8P17=R80BSPR04hi900204lk8`0@04Ti:@17=bL0@cHU03ld8P0m=B80?CHS03lh9@10
>bL0AC@R04He8`18=bD0BCPV04Xi9`19>2H0B3LU04Lf9080BCXS00@0BSXS04/i8`1;>B<0CCPS0P1>
>2<2058m:00>05<o9`1D@2L0ED4V05I39@1F@b<0Ed@T05m49P1NABH0G4DV05Q59`1DABP0D4DY04i5
:01<ABT20510:@80DD4Z0`1B@R/0101C@b`0GDDY05a4:01J@RH205U19@0505Y29P1LA2P0GDDY05Q6
;P1D@RX00P1@?RH05`1D@RX0ET@/05E3:`1C@BT0Dd@U05=49`1B@bH0DD4W05109`1??bP0CchZ04hm
:@1=?B@0CShU04lo9P1@@2L0CclV04hn9@1<?2<0Bc/R04<g9`12=RH0@3@T00<0?S8R00<0?c<S040d
900k=R800P0k=R<00`0j=2@0>S@V03Tc9`0203Tb:00N03li;@0n=RT0?3@W03/b8`0l<200?c8Q04@e
8P15=R<0AS`Q04Xn901<@2H0CClU04Xj8@1:>200Cc/S058n9P1NA2<0GDDS05]49@1F@RL0DD4W04a0
:019?RX0AShY03di;@0k=b/0>CDY03Hb9P0e<BD0=30T0P0e<BD203Hc90<0=c@U0`0h=BH203Tc9@80
>S@V0`0k=BL02@0l=RP0>S0V03X`900m<BD0?c4T04@d9@17=RH0BSTW04dj:@0204dm900;04hn901A
@2H0ET8W05Y5:01OB2T0HDXZ06=::`1SCBP0IDlZ06UC;P1/ES400P1^F3<07`1]Ec80K5Ha06eK<`1]
Fc<0K5Xd06]I=@1ZEcH0Ie@d06EB<P1TDC<0FdX/05i;:`1QCRh0IE4`06]D<P1`F3@0ME/f07IL=`1h
G3D0NUhg07iR>P22Ic`0Qf`o08]`@@2=LT<0SgE4099kA`2BNdT0TG]9095mB`2@OTh00P2@Oe401`2?
PE@0Qh1F08ImE023NU<0PWI@081bC@20L4`00P22L4`04`2HNd40W7i00::5@`2[SDL0]YA:0;jKBP34
XDd0aj=;0;jXG02lYEl0^Z1U0;NII`2dU6D0/I1M0:f=E02]Rd`0/Hm@0;2>C`2_SDh00P2^S4d06`2_
SDh0/Hm@0;:@D@2]RU00[X]A0:j;D`2^ReD0[8UC0:V5D@2UPDl0Xgm=0:j4B02_Qd`0/HU>0;6:D@2`
Re@0[haF0:b;EP2[RUD0YXM>0::3C@2PO4`0WgI:0:1dA`2VMTD0[7]30;1n@`020:f5A`040:b4AP2[
PdD0Zh=50:Z2A080ZH5300H0]8A40;63A@2`PT@0[H540:Z0A02YPDH20:V2B@050:R5B`2UPTP0XX13
0:>1@P2VQ4@00P2YR4D00`2XQd80VGU009Yj@@0309]k@P0509Yj@@2HN3l0V7Po09Ad>`2GMch00P2K
Nd803@2IND00V7Po09Yj@@2LO4<0VGQ209]jA02MO4H0VWU309Ed?P2BLC/0U7<m09Mf@02INSX00P2K
O3`00`2NOcl0XH920:B5A@020:F6AP070:B5A@2ZRTd0ZHU<0:R9B@2WR4L0YhQ50:R:A0020:V;@`<0
YXA400L0Y8920::0@02POSh0WG/k09aj>P2ONcd0WWXl0080WGTk02L0WWXl0:1l?P2ROT00Xgm10:>1
@P2TPT<0YhE60:R6A`2WQDH0YH=40::0@@2POSl0VW/k09Uj>P2GN3P0UWLg09Ef=P2FMcL0UgPh09Qi
>@2LNS/0WG/l09mm?P2QOd00Y8930:N5AP2YQdP0ZXQ90:f:B02_S4`0/i5B0;>CF02ZRe@0W7i809Qj
B02KOdd0XXQ?0:>9D02TRU400P2URe800`2TRU40XhU@0::8C`020:66C`80XXM@00@0XHI?09n4C@2M
PT/0W85:0`2MPdX209b2B@<0Vh580`2IP4P209QoA`<0Ugi60P2IP4P01P2GOTH0UWe509Ak@`2BND40
TGQ0091g?`80TgQ100<0TWM0095f?`2@MCh00`2?M3d0:P2IMSh0VgY40::1C02[ReX0]9EW0;^NM031
YGd0aJV20<B/R037[hT0b;2:0<B]Q02lYG/0]9ea0;2JJ`2^V6T0]IQ`0;VMM@2nXWd0_jF20<6XR@34
[900b[FJ0=2jXP3G`K@0flFg0>3;^P3Sc[T0h/je0=k;[@3HaJD0dl2O0=>dQ@39ZgT0_9i/0;:DH02[
SEL0YXUA0:23B@2KOT@0WgY=09ajC080VGM901D0UGE6091a@P2;Kcl0R6hm08I/>`23IcL0Of<d07]O
<01iG300N5/a07AG;`1]CbT0IdTS05M28`1F@B80DSlQ04hm8@1<>b40Bc/R04Xk901;?2D00`15>Al2
04@h7P<0@cLM0P11=242040c800403lb7`0n<Ah0?C0M03d`7@<0>2lN0P0g;Qd303H]70<0=B/O0P0d
:Qh303<Y7@P0<B/M200b:1`0100e:al0=2XN03@Z7P0d:Qh203<Y7@80<RPL0`0e;AX203H^6`<0=blL
200m<1d8048b6`P0@CDM0`13<R0204@c8@<0AC@R0P16=b001017=b00AcDO04Le7`18<ah204Tc7PP0
BSPP00@0DSXN05<k7`1C>al0Dc/O0P1D?20205Dm8@80G3hV00<0G3hT05`n8P1L?b400P1M@200101M
@1h0H44U06119@1P@BD306529P<0HT<W0P1UA2402@1VAB80J4LT06U89@1ZBBH0JdXW06a;:01[CRH0
K4lW06iA:@03071C:`0506mB:P1^DBT0LE4X079B:@1dE2/00P1fERd00`1eEB`0M5@[07=C:P02079E
;@80LeH^0`1dEbl00`1eF300MU<[07EB:P0207AA:@0507=@:01dDBT0ME8Z07IC:`1dE2d00P1cDb`0
1@1bDR/0LE4Z071@:@1`D2T0KdlX00<0KE0X0P1^DBT306mB:P0407I@:@1gDBX0Me4Z07MA:P<0N58[
00L0NE</07]E;P1lERl0O5H_07eG<01nF340OeTb0080P5Xc0P24H3000`25HC40QV8b08MS<`0208QT
=00508UU=@28HcH0R6<f08UT=`2:ICP00P2;IST208aW>P0809UdA`2EL4<0T6/n08]V>@29I3L0RVDh
08aW>P2>JC`808IT=P0>08QR>`29I3X0RVDk08]V>P2;IST0RFDe08MS<@26HS00QV4]08MR;P2:IC40
SFPd08mZ=P2@JcL2095/>006091V=02AIcD0TFLe099X=P2CJCL0U6Xh0P2EJcT02@2EK3P0UVdi09Q_
>`2IL3`0VW4m09U`?02HKc/0Ufhj09U`?00209Q_>`0509M^>P2HKc/0VG0l09Ya?@2KLSh00`2IL3`3
09Q_>`<0Ufhj00@0UW1109Ma@P2GLD80Ug520P2HLT<209UcA080VWE000H0VG@o09Ye@02KMT40WGQ3
0:1kAP2QO4L209mkA`040:1lB02ROTX0Xgm;0:F1C@80YX9>0P2XQ5020:V5D@<0ZXIB00@0ZhMC0:Z8
F02ZR5P0ZXQH0`2YQeL20:R6EP<0ZhUK0P2/RU`30:f;G@80[HQD00@0[8MC0:^6DP2[QU80ZXEA0P2Y
Q5001P2WQEL0YhEE0:N5E@2WQU<0YhIA0:N6D080YhM>00D0Yh9F0:R3E`2XPeH0ZHEE0:Z6E0020:^7
D`80[8UC0P2/R5@00`2/R5H0[8QH0:b7FP020:b7F`<0[8QH0`2[QeL20:Z6EP030:^9F@2/RUX0[H]K
00<0[heM0P2^S5`0202_SEl0/8iP0;2>H02aSf40/8iP0:n=G`2^S5h0[H]M0P2_SEd01P2`SUh0/Y1P
0;>AH@2dTV80]I=S0;JDI080]i9U00<0^9=V0;VDI`2jUFP00P2kUVT0102lUfX0^IMY0;VGJ@2iUfT2
0;ZHJP<0^iU[0P2jUVH0102kUfL0_9QX0;fIJ@2mVFT20;jJJP80`Ie]0P32WVh30<>OK`030<BPL033
WW40`iia00<0`Ye`1P31W6l20<:ML0<0`iia00L0a9mb0<FMJ@35WFX0`iiZ0<:NK032WVh0`9i`0080
_iia0`36XGL20<NRN0<0b:=i0P33X7H01034XGL0aJ9h0<FRN036XgT20<NTNP<0aZAf0P35XgD30<BR
M080`Z1`00@0`Ima0<2NL@30WG<0_iad0P2nVgD30;nLLP80`9ec0`31WW@30;jLKP80_I]]0`2lVV`2
0;VGI`80^YQX102kVFT0102jV6X0^iU[0;^IJ`2kVF/30;bJK0030;fKK@2lUfX0_IQ[0080_IQ[0P2n
VF`20;nJK@P0^iU[0P2nVFd00`2nVF`0_IUY0;fII`020;bHI0030;bIH`2lV6@0^iMS0080^iMS0P2j
UV820;VEH@0@0;ZFHP2iUF40^9AP0;NCG`2eTEd0]91L0;>?F`2bSUX0]8UD0;B;E@2eS5P0]HeJ0;>=
G02aSEd0[XaL0:f;G@P0[h]G00<0[HUE0:b8E02[Qe<00P2[Qe<00`2]RED0[XYF0:n;E`090:n;E`06
0;2;GP2`S5`0/8aL0;2<FP2`S5P0/8eG0P2`SED00`2_RUD0[XUD0:j9E0020:f8D`<0[8MB202]RED2
0:b7FP040:f8F`2^RE`0[hYM0;2;GP80/HaO0`2bSUX20;6=F@<0/8aH00<0[XYF0:n;E`2_ReL00P2_
ReL00`2^RUH0[8QD0:b8E0020:b8F0<0ZhMG00<0[8QH0:j:FP2_Re/00P2]RU001P2/RE40ZhQB0:Z7
D@2YQE40ZHEC0:R4DP<0ZhQB00D0ZXMA0:V6D02WQ4h0YH9<0:B1B`030:J1C2_ooooo000Zooooo`06
0:5hA02RNDD0XgY60:AkA`2UO4P0YWe90`2WOTX0202VODT0YGa80:=jAP2SNTH0YGa80:ImB@2WOTX0
YWe90P2WOTX00`2XOd/0ZH1<0:V0C0020:V0C0P0ZH1:202/PU020:b2DP@0[H=C0P2^Q5@80:n5E@06
0;25CP2_QTh0[hI@0:f5D@2[QU40ZXIB0P2WQU<01@2]Q500[8=?0:b3C`2[PTh0ZX5=0080ZH1<00D0
Z7m;0:F0B`2TOdX0Xgi90:9mB0020:5lA`0309mjA@2NND@0WWU40080W7M300@0VgI209Ud@02HLcl0
UW4m0P2EL3`0402DKT40Tfe0099/?`2AJch0SfTl08iX>`2=IcX0S6Hi08aY?`29IS`0Pf0f07mL<P1m
FS00OU/a085N=023H3H207aI<@0407]H<01jEbl0NUL_07UF;P80N5D]201gE2`0201eDBd0MU8^07MD
;P1jEbl0O5T_07iL;`20GS40PEla0P27HSD01P28HcH0RVDh08]V>@2=J3/0SVTl08mZ?@80T6Tn00H0
TF/n099/?@2CKC`0U6lk09E`?02EL3/309Mb?P80UW4m0`2EL3`809U`@PP0Uf`o0`2BK3d2095[?0<0
T6Xk0P2CJ3/2099W>P80TFHi1@2@ICP208mT=`<0SV<f00@0T6Xm08mY?02<IST0RF<f1028HSD01026
H3<0R68e08YT=`2<IST208eW>P0508aV>@2;ICP0R6<f08UT=`2:ICP00P2<IcX01P2:ICP0RF@g08QS
=P28HS<0RF<d08YT=@80RfDf00<0RV@e08US=028HS<02@28HS<01P26H340Qf4b08QR<`29Hc@0RV@e
08aV=`80SFLh00P0RV@e08]U=P2<ISL0S6Hg08]U=P29Hc@0Qf4b08EO<080RVHf0P29ICD208QT=080
Qf<c0P25H3<01024Gc80Peha08=N<@22GC02085L;`0308EP<`23GS40PE`_0080P5/^00<0PUd`08EP
<`27HSD02029I3L208aW>P<0SFPk0`2>JC`01@2?Jc/0SVXj08iZ>P2>JSX0SFTi00<0S6Ph00P0RVPh
08]Y>@2<JSX0SF/k08i/?02?KCd0T6hn095_?`P0TW100240SFho091a@P2BLd@0T75208]/?@29JS/0
Rf`m08i_@02@MD00SW<n08a`?P29KCd0QVXk08=V>P21I3P0Of8h081T<P1nI3<0Nf0a07IN<P1`FC00
JU@_06A@;@1QCB`0Ed@V05919@1<?280A3PP03`d7`0f<Ah0<RlN034_800];aX00P0/;A/00`0[;1`0
:R/M02TY7@0202PX7P0402<V7@0R9A`082<J01lR6@807R4H00@07b8I020S6P0P8a`082<L0`0O8Q/3
01hQ6P03020S6P0Q91/08RDL00808bHM00<08RDL020S6P0O8QT02@0N8AX2020Q6@03024R6P0R8a/0
8b@L008092DM00X09BHN02HX7@0X:1`0:BTM02d[7P0a;Ql0=BlO03L`7P0h<Al0?3DR0`0m=b40300n
=Ql0?3@M03/c700j<Q/0;RTS02dY800/:1l0:bLL02`X700^:a`0<2dL038_7P80<bdO1P0b;1h202l/
6`0602h[700]:Ad0;2PM02/W7P0Z9Qd0:RDO0P0W9ad302HV70<09BDK0P0V:1d00`0U9a`092HK02@V
6`0302@V6`0F028S7@0Q8Q`07b0J01dN600L7AL07AhH01hO6@0O81X08b8N02TV8@0a:R00?30P04Ph
8@1C@280GTLU06E;9P1XBb<0JdhV079E:`1oHSH0SW9309UmC@80WH5?00P0XX]I0:nDG`2bTed0WWa<
07AH<01:>R00<BdQ02P]9`809BLT0`0T9R<302<U8PP092@R00`09bHQ02PW8P0Z:R80;2`R02l_8`0a
<R@0<c@T03@e9@0g>2X0=CHX03<d9P0a<R@3030a8`0:034b900b<240<c4R03@a8P0g<B<0>C4T03X`
900k<BD0?C4U03L_8P80>30S0P0i<B@203Xb9@0803/c9P0n=BH0@3@V040d9012=B@0A3DR04He8@18
=R0204Tg8@0;04@g9P13=RD0@CHT040e8`11=R@0@3PU04<k:014?2T0A3<Q04Dd8P17=R@00`19>2H0
1@18=bD0AcHT04Pi8P19>R<0BSXS0080BcTS00T0CSTT04li901?>B@0DS`W05<m:01D?RL0EClW05I1
9P1H@bH00P1IA2D0201QARP0H4LX05i7:01JAbT0EDHY0556:P1?ART0CDHZ0`1B@2P305=1:@80E48Z
00<0GDDY05a4:01K@bL00P1J@RH01@1K@bL0G4@X05e5:@1JARd0ET8Y0080DShU00l0ET8Y05Q4:`1G
@bX0ED4X05E69`1DABP0Dd@W0592:01A@BP0D40Y04ln:P1>?BT0CCdV04hn9`1??bP00P1@@2T0301>
?RL0C3`U04/k900n=B@0?C@S03`c8P0k<R40?3<R03dd8`0o=RD0@3LV03dh9080?3LT0240>cDU03Xd
9P0i<bL0>C8X03Pa9`0k=BT0>S8U03Ta900i<240?30P03lb8@13=240A3DR03le6P15>Al0BclU04i0
9P1=?B@0C3XR04lk8`1A?BD0G4<T05]4901H@bH0E4<W04m19`19?RP0A3`Y044j9`0l>2`0>cL[03Pd
:00f<RH00`0d<2@00`0e<BD0=S<T03Hc900603Ld9@<0>C<U0P0j=2H303/e9`0803P^8P0i;b<0?30R
040c8`14=2@0B3LU04/j9P1=>bL204hn9@0;04lo9@1B@BL0ET8W05Y5:01NAbP0H4TY0699:P1RBbT0
I4d[06M@;P1YDS000P1ZDc40?@1YDS00J54_06YH<P1YEc40J5Hb06MD<`1UDS80HTla065><01PC340
FTT[05a9:@1NBb/0HDd/06I?;@1[Dbl0KeD`079H<`1hG3D0NUhg07mS>`24JCh0RFi108aa@P2>Ld@0
SgE409=nB@2COD/0TWi<091nCP2>OE40S7eD08amEP2;OEH0QG]P08=hG020LUD0OVe?07i[B`22Jd/0
QVi<08M_C@2MOS/0X88l0:N9@@2^TTP0]ia=0;fSC`32Z5<0a:YE0;^ZI02hYVH0]J1[0;>HJ`2^TFL0
Zh]L0:R7D@2UQDP0ZHU<0:Z8B`2YQdX00P2YQDL00`2/QTL0[XQ90:n9B0020:R6B@0/0:R5B`2WQ4`0
YX==0:B1B`2SOd/0XWi<0:j6B@2aRDh0/haA0;B@EP2cT5P0[XeG0:V:E02WR580Y85;0:AoBP2TO4P0
Y7]70:EjA@2[O4@0[X150;:1AP2`R4X0[hM90:b4AP2ZPT@0ZH530:Z2A02/Q4H0[HE70;N:B@2eRDX0
/XI70:j5A`2ZPTD0Yh150:B0AP2SOdD0Z8E;0:J3B@2TPTD0Xh540:B2A@2UPd@20:J4A@@0VWLm0P2I
MS`01@2HMC/0Ug@j09Eb>02GM3X0V7Dk0080VGHl00`0VWLm09]h?P2LNCl0Ug@l09Yg?`2LND40VWLo
09Ic>`2ELSX0Ug@l09Yg?`2MNc`209il?@030:5o@02RP440Xh520080Xh5200T0XX110::2A@2SPdH0
Y8E50:J7AP2XRDH0Zhe70:f?A`2^T4P00P2^S4`04@2_SDd0[Xa<0:^9B@2XQTH0Xh510:5o?`2QOCl0
X7`n09mk?@2NNS`0Wg/m0:5m?`2SOd40Y8120:F3@`2VQ4@0Z8I60080ZHM700L0YhE50:F3@`2TPT80
WGhn09am?@2JNc/0V7Ti0080UgPh00<0V7Ti09Uj>P2OOCh00P2NO3d0402OOCh0XX110:F3A02YQdP0
[8Y;0:b9A@2`SD/0]99B0;BDE`2^SeH0XXE=09]mB@2FNTP0XHI?0:>8D@2TRE820:J;E0030:F:D`2T
RE80XhQA00<0XXM@00D0XHI?0:25CP2OQ4d0WX=<09f2B`0209j4B`80WH=:0P2LPTT209^1B080VX59
0`2IP4P309QoA`0809Z1B@2IP4P0V7m709MnAP2EO4@0U7]309=j@P2BND4209Ej@`0409Ai@P2CN440
TGHo091e?P80Sg@m00T0VWLo09akA@2SPTd0[8aK0;FFJ02lWgD0`ZIn0<JZP`37[h/00P38/8X07`35
[XD0_jQn0;RQM@2bW6d0[iUZ0;>FK02gW740_Z9k0;nUPP31ZHL0a:f>0<VdV@3?^Yl0eL2_0=W4/`3N
bKH0hlji0>C@]`3Rc[<0gLZ/0=[7Z@3J_I40dKB80<BXN@2lWV`0]IIP0:j?F02WQdh0XH560:9lC@2P
O4`00P2MNDT05P2HMTH0U7A3091b@02<L3h0RVhl08IZ>P22ISH0OV8c07aP<@1kGS80MeX`06mB:P1Y
C2@0GdLU05i59P1J@b<0ED0Q058o8@1@?b<0D3lU04lo9@1:?24204Tk800504Pj7`17>Ah0ASPM04Hh
7@15=a`00P15=R4204@e800404<d7`12<ah0@S<N048c7P@0>S8O0P0i<Ah203P`7@80=bhO0`0f;Ah3
03D/7@P0=2dM00<0<bXK03@[700d:a`00P0d:a`303D/7@80=bhO0P0f;Ah303D/7@0303@[700g;a`0
=blL00<0=blL0`0h<1d00`0l;a`0?C0M03d`7@0203d`7@<0?S4N00<0A38J04Dc6`15<a/00P15<a/3
04Hd70P0ACLM0`16=20304Le8@80B3HR00H0AcTO04Ph7`19=al0B3HN04Xf7P1;=Ah204dd7P<0CSXQ
0P1=>B0304`h7`<0E3XO0P1E>b0305Hl8@80GClW00L0GClU05`n8P1L?b40G3lO05/n7P1K?Q`0HD8U
00@0HT<V0P1SA2L206A5:080ITDR00X0IdHS06Q7901YB2D0JTTV06]:9`1/BbP0KDdV06i>9`1`D2T0
Le</0P1dE2d01@1cDb`0LU8[07AE:@1fEb/0MeP/00<0NEX^00<0N5T]07MH;01gEbh00`1hF2l207UI
<080NUXa00<0N5D]07MD;01gE2`01@1fDb/207EE;080M5@[00@0Le<Z079B:@1bDRT0LU8Y1P1aDBP2
079B:@80N58[1P1iDb`207eH;P0407iI;`1oFS00P5/a081K<@80PE`b0P26HS801027Hc<0R6@d08UU
=@2:ISH208]W=`0@08QS=P29I3L0RVDh08]V>@2=J3/0SfXm091[?P2AK3l0WgY=09YeB02BKD00RfHi
08QS=P29I3L0S6Lj08iY?080QV@f00@0QfDg08QV>028ISP0RFLi0P2:J3X0402;ICh0RfHl08aW?@2=
J3`0S6Lj08YV=P28I380QV8`08IQ;@27HRh0RVDa08aW<`2?JSH0TF`h099]>@2CKSX2099X=P80TfTg
0P2DJSP209E[>@0809E/>02FKCT0V6lk09U`?02JLCd0VG0l09Q_>`2GKSX409U`?080VW4m0P2KLSh2
09Ya?@@0VG0l0`2HKc/309Uc@P<0VWA30P2KMD@0202MN4<0W7M209]f@@2KMT40WGQ309mjA@2QO4L0
XWe80P2QODT01P2ROTX0Y81<0:F1C@2VPTh0Yh=?0:R4D0<0ZXIB0`2[Qe<20:b8E0<0[8YJ0P2[RET3
0:Z8F080[H]M0P2^S5h30:n=G`060;2>H02^RUP0[XYH0:f9E`2/R5H0ZhME0P2ZQU@01`2YQE<0ZHMJ
0:V7F@2YQeT0ZHMG0:V8E@2YR5<00P2YR580202WPUH0Z8=G0:V4E`2ZQUH0ZhME0:f9E@2^RUH0[X]E
0`2]REL30:f9F@80[HQK0P2_Re/0102^RUX0[HUI0:f9F@2/R5P20:^7E`040:f;F`2^S5`0[heM0;2>
GP@0/HmO0P2bT6860;>AH`080;6?G`2bT600/i5Q0;BBHP2fU6@0]iEU0;RFIP2iUfL20;^FJ@80_9MZ
0P2mV6/20;jIK0<0_I]]0P2nW6h30;nMK`<0_IUY00<0_YYZ0;nKJ`2oVf/00P30W6`30<>NL@<0a9mb
1035X7<20<BOLP@0`iia00@0`Ye`0<>NL@33WW40`iia0`34Wg820<FPL`060<NOK037Wfh0aIm^0<BP
L034Wg80`Z1c0P31X7D50<NTNP<0b:Ek00@0`Yme0<>PMP34XGL0a:5g0P36XgT00`37Y7X0b:Ek0<FS
M@070<FSM@80`Z1`00@0`Ima0<2NL@30WG<0_iad0P2nVgD30;nLLP80`9ec0`31WW@30;jLKP<0_I]]
0P2lVV`20;ZHJ0H0^iUY202lVV`30;fHJ`80_YU/0`2oVVd80;bJK080_iY^00<0_YU/0;jJJP2nVVP0
0P2mVFD00`2mVV@0_9QT0;bHI0020;bHI080^iMS0P2jUV801P2kUf<0^YIR0;VEH@2hU600]i=O0;FA
G@80]91L00P0]8UD0;F<EP2gSUX0]hmL0;F?GP2bSUh0[H]K0:^9F`P0/8aJ00<0[XYF0:f9E@2]RED0
0P2^RUH20:n;E`030;2<F02aSET0/HeI00@0/8aH0`2_ReL01P2aS5l0/HeM0;6=G@2aSE/0/HeI0;6>
F080/HiF102^RE@40:f8D`<0[8QD102]RED01`2^RUH0ZhMG0:^7E`2/R5P0[HUI0:j:FP2_Re/00P2`
S5`00`2`S5P0/HeI0;>?F`020;B@G0060;:>FP2_ReL0[XYF0:b8E02^RUH0/8aH0P2aSET00`2_ReL0
[8QD0:Z6DP040:^7E@80[8QF0P2]REL01P2^Re40[HYB0:f:E02/RE<0ZhMC0:Z6E080ZHEE0P2/RE<0
1P2[R580ZHI@0:R5C`2VPdd0Y85;0:>0BP<0YX5<:oooool002[ooooo00H0X7M30:5hA02RNDD0XgY6
0:ElB02VODT30:QoB`070:ImB@2UO4P0Y7]70:AkA`2UO4P0YWe90:QoB`040:MnBP040:QoB`2YP4`0
ZH1<0:Z1C@P0ZH1:202/PU000`2[PDl0[89@0:b2D0020:f3D@80[XAB00<0[hEC0;26E02`QU@01P2`
QU@01P2`QDh0[hI>0:n6D02]QE40ZhIA0:Z6DP80YhIC0P2]Q500102/Pdl0Zh9>0:Z1C@2YP4`20:Qo
B`040:F0B`2TOdX0Xgi90:9mB080XGa700<0WgY509iiA02NND@00P2LMd<0102KMT80VGA009Qc?`2F
LCd209E`?080Tfe000@0TV`o091Z?@2?JC`0SFLj0P2<IST0202<JCl0RFHl08=P=P1oG380OEX`07iK
<@21GS@0Pf0f0P1lFC40101kF300NUL_07YG;`1iERh207QE;@P0Me@/00P0MU8^07MC;`1hEBl0NeP`
07eJ<01oGC00PElb089P<P80Qf8e00@0R6<f08UT=`2;IST0S6Lj0P2=J3/2091Y?P06095[?P2BK3d0
TV`k09=^>P2DKc/0U6lj0`2GLSh209Ia?@<0UG0l202IKT4809M/?`<0TV`m0P2AJc`3091Z>`80TfPk
0P2BIcX2095V>@D0T6Dh0P2?I3L308iS=P04091Z?@2>J3/0S6Hi08YT=`<0RF<f00D0RV@g08MQ=028
HSD0RV@g08aV>@0208eW>P0508aV>@2;ICP0R6<f08UT=`2:ICP00P2<IcX01P2:ICP0RF@g08QS=P28
HS<0RF<d08YT=@80RfDf00<0RV@e08US=028HS<02@28HS<208IP<@0608MQ<P29Hc@0RV@e08]U=P2<
ISL0SFLh0P2:I3D01P2;ICH0S6Hg08]U=P29Hc@0Qf4b08IP<@80RVHf0P29ICD208QT=080Qf<c00D0
QV4d08EP<`25H3<0Q5lb089M<002085L;`04081K;P25H3<0Peha085L;`80P5/^00<0PUd`08EP<`27
HSD02029I3L308eX>`<0SVTl0P2?JSd508iZ>P<0SFTi00P0RVPh08]Y>@2<JSX0SF/k08i/?02?KCd0
T6hn095_?`P0TW1002/0SVm0095b@`2CM4D0TG9308a]?P2:Jc`0S6dn08m`@@2@MD00Sg@o08ea?`29
KCd0QVXk089U>@20HcL0Of8h081T<P1nI3<0O64b07MO<`1aFS40JU@_06=?;01PC2/0ET8W05509P1;
>b80@cLQ03/c800e;al0<BhO030^8@0/;A/0;2dM02//700Z:ad0:BTM02PX7P0X:2009bLO02<V7@0Q
91/082<J00807R4H00<07b8I020S6P0Q91/00P0P8a`301lR6`<07R4J00<08B@K028U700S9Qd00P0S
9Qd00`0Q91/07b8I01hQ600901hQ6P80824I00<08B8J028S6`0S91`00P0T9Ad02`0U9Qh09bTL02PY
6`0Z:ad0;bdN038_7P0g<Ql0>C8O03Xc800n=Ql0?cLP0080@3PQ00D0?SPR03/e7`0i<ad0=c0M02`W
8@0202`X7`0502`X7@0]:Ad0;b`M034^7@0b;ah01P0b;1h203<]7`80;b`K00H0;R/L02dY7@0/:1d0
:bLN02XV7@0Z9Al202LW7@<09RHL0`0U9A/402HX7@0702DW700T9Q/08bDJ02<U6P0Q8Q`0824K01hO
6@0301dN60807b0J01P09BDM02TV7@0b;200?c@R04/k901E@BH0G4DU05m5901TB200Id/S075F:`20
ICP0T7E609^1D02NQ540WH=@0:nAG@2aTel0ZXYI08a_@`1SC2X0?S8L02XZ800U:bT202DW90<092HS
0`0S9B8802@T8P80:2LR00X0:RXR02`/8P0^;R80<34S038c8`0c=2@0>3T[03Lh:P0d=BL0<C8T100`
<B<2038`8@0303@a8P0g<B<0>C4T0080>c4U00<0?S8V03X`900j<2@0100k<BD203`b9P0603`d9`0m
<bL0?SDV044e9@12=B@0A3DR0`15=20303lg900=044f9012=bD0A3TW04Lj:@18>bX0AC@R04He8`18
=bD0BCPV04Xi9`19>2H0B3LU04Lf900204Pi8P0404Xj8`1;>B<0C3XT04lj9@80D3XU00H0E3/W05Dl
:01F?BL0EclW05U19`1K@bL205a59P0806=8:P1QB2T0GdPY05Y7:@1FAbX0DDHZ04m6:@1=ARX20591
9`<0Dd8X0`1D@bT00`1NARX0GDDY05]39`0205Y29P0505]39`1MABT0GTHZ05a7;01H@bP00P1D?b@0
3`1G@RL0FTDZ05U4:@1G@RL0EDHW05A5:01CA2L0DT8X05109`1??bP0CSdY04dl:01<>bL0CC`X04hm
:@0204ln:P0504dl:01;>RH0BSTU03`e8`0k=2800`0j<b40100l=B<0?SLU03lh9P0m>2@203`g900S
03/e9@0j=2H0>38V03Pa9`0g<2H0=2hR03D]800f;R40>2lP03da8@11=2<0ACHS04Lh9@0m<aP0A3PN
04Xn901?@BL0CShU04dk8`1@?2@0DShV05]4901IA2D0Ed<X05=3:@1<@2P0ACdX040i9P0l=b@0?3P/
03Xf:P0h=2P0=C4U03@`900c;b<00P0d<2@203Ld9@H0=S<T0P0h<R@203Tc9@80>S@V0P0k=BL0200h
;b00>C0Q03hb8P11=2<0ASLT04Xi9@1;>b@0CC/U0P1??bH02P1@@2H0DT4W05I29`1JABP0GTLX05m8
:01QB2T0Hd`/06A=;@1UCRh306M@<080ITl_0P1VE300@`1TDC00HTl_061=;`1OBc00GTX_05i:<@1O
CS00HDh^061=;@1QCB`0IDh/06Q@;01/DRd0KU@_07UM=P1lH3T0PVHn08Q]@P2=LTD0T7E6099gB02B
N4L0U81;09=oC02AOdl0SgiB08amE02;NeL0RGYI08QkF`1nLEh0NfmI07YZD@1jIT/0OFI608AWA@29
JdD0Sfm80::0>@2UQ3d0ZXa40;2FC02dWU<0]jAG0;VXFP2jZU`0[jEW0:jQJP2[VV`0Z99Y0:J:H`2S
Q5P0X85;09in@`2PP4L0Wgm60:1m@`2QOD40YGdo0:Qo?`2/P3l0[H500:J4A@2UPd@0Y8950:9oA@2Q
OTH00P2QOTP0502QODT0[HM90;29CP2bSU80/i1F0;2@E`2[S5D0YHMA0::4CP2TNdL0Y7]50:Mm@`2X
OT80[H540:n3A02bQ4P0/hE90;::C02`R4X0[HE70P2ZPT@0502/Q4H0[XI80;28BP2dR4L0/HQ80;27
A`2/Q4H0Z8940:=o@`2OO480WW]10:F3AP2TPTD0Xh540:1m@`2OO480WW]10:1m@`2QOTH0VWPk0P2I
McX609Qf>@80UgDh00<0V7Hi09Ug>P2KNC`00P2KNC`02@2FLcT0VGHl09ai?`2KN3h0V7Dk09Md>P2I
MS`0WGY00:5o@0020::0@@80Xh5200h0XX110:1n?`2NO3d0WG/l09Ui?02KNch0Wh100:F6A@2ZRdP0
[i5;0;:DC02dUTh0^IMG0;^IF@80_9YJ00L0^IMG0;>AD@2]Rd/0ZHM70:=o@@2ROT00XGdo0080X7`n
00H0XWi00:=o@@2UPD<0YXE20:N6@`2XQd@20:V8A@070:R7A02WQT<0YhI30:21@@2OP400WGhn09Yk
>`0209Uj>P0409Yk>`2KO3`0XGm009mm?P80WW`m01T0X7ho0:F3A02YQdP0[8Y;0:f;A02`SDT0/i9?
0;>DE02aTeL0ZXeE09n1B`2DND@0XHIA0::7DP2TRE@0YX]F0:N<E`2VReH0YHYE0:B9E02TRE80XhQA
0::7D02QQTl0X8E>00<0WhA=0`2NQ4/209f3BP<0W8990P2KPTX209Z1B@@0VH1803X0Vh9:09Z1B@2I
P4P0V7m709MnAP2FODD0UGa409Ak@`2GO4D0UW]409Ej@`2DND80TgQ1099g@02AMSl0T7Dn09]h@02M
O4H0Y8=>0:f=G02fUfT0_J1f0<>WO`37Zh@0bK6=0<VaR`38/8X0aZn60<:[P@2lYGT0]Im`0;2JJ`2a
U6P0]Y]^0;fQN@2oYH00`JV50<>/S038/iH0cKRK0=>nZ@3F`J`0g<Nb0>;>]P3Td;P0i=2g0>;>]@3P
c;40fl:J0=>jT@3:[h80a:Ef0;jNJ`2fUEl0[haB0:V5B@2VOTd0Xge<0P2ONdT05@2LN4H0UgI3099b
?`2?LCd0SFlk08Q/>P23IcD0Of<c07eQ<P1kGS80MeX^06mB:01YC280J4`W06I99`1QAb@0GDDS05Y3
8`1G@R<0Ed8U05I39@0204ho8P0404dn8@1<?B00Bc`O04Xk7P80BCXM00<0B3PQ04Lg8017=b000P17
=b0304Hf7`80?c@R0P0n<b4403db8080>blO0P0j;Qh403T]7@P0=RdL0P0g:a/203P/700403T]7@0j
;Qh0>RhN03X^7P<0>blO0P0j;Qh303T]7@D0>c0N0`0j;ad203`_7080?C0M00@0?S4N03lb7`0o<Ql0
?c8O0P16=A/204Lf700404Pg7@19>1h0BCPN04Th7PP0B3PN1018=R0204Tg8@80BSPR00H0B3PN04Th
7P19>1h0C3PO04dg7`1?=al2050f7`<0D3/P0P1?>Ql304hi7P80ECXO0P1F>b0205Ll8@80F3dR0P1N
@2P01P1N@2H0GClS05e08P1M@200G3lO05`o7@<0Hd@U0`1TABH306E69`0406M68`1XAb@0J4LT06U8
9@80JTTV0P1[BRL0101]BbD0KddW075?:@1dDR`407ID;P0807MH:P1hFB/0NU/]07]L;P1lGBl0Ne`^
07YK;@1iFR`307]J;`80O5/`0`1mG34307YG;`80NEH^00<0N5D]07MD;01fDb/00`1fEb/407EF:P03
07AE:@1eE2T0ME@Y00<0ME@Y0`1dDbP207]E;PH0NU@]0P1nFBd0101oFRh0P5/_085L<022GC4208=N
<P80RFDe0P2:ISH0102;IcL0S6Ph08eY>@2=JCT208YU>00?08aW>P2>JC`0T6/n099]@02CKT40U6m2
09ehB`2HLdH0T6/n08YU>026HC@0Qf8e08YU>02=J3/0QfDg0080R6Hh01D0RFLi08YX>P2;JC/0S6Xl
08e[?@2<ISl0SFPn08iY?`2>JCd0SFPk08]W=`29IC<0R6@b08QS;`29I300RVDa08aW<`2>JCD0T6/g
099]>@2CKSX0102DJSP409E[>@0909E/>02FKCT0V6lk09U`?02JLCd0VG0l09Q_>`2GKSX0VG0l0080
VW4m0P2KLSh209ac?`0309]b?P2LLcl0W7<o0080Vg8n102JLCd00`2IL3`0VgI209]f@P0309ag@`<0
WGQ40P2ONTD309iiA0030:1kAP2RODP0Y7m:0080Xgm;00H0Y81<0:F1C@2WPdl0Z8A@0:V5D@2ZQU82
0:^7D`<0[8QD0`2]RED30:j<G080[H]K0`2/RUX30:n=G`<0/8iP0P2aSf420;2<G0030:n;F`2^RUX0
[HUI0080[8QH00L0ZhMG0:Z7G@2ZR5/0ZXQK0:Z8FP2ZR5P0ZXUF0080ZXUD0P2YQ5P01P2ZQEP0[8QH
0:f9E`2^RUH0[h]G0;2=E`80[hYM0`2_Re/30:n;F@80/HeM00@0/8aL0:n;F`2_Re/0[XYJ0P2]RET3
0;2>GP030;6?G`2bT600]99R0080]I=S0`2eTfD00`2fU6H0]iEW0;RFJ0020;VGJ@80]YAT00H0]iEU
0;RFIP2iUfL0^YQX0;^IJ@2lVVX30;nJK@<0`9]^0P31W6l30<2NL0<0`Ima0P32X7830<2LK0@0`Ie]
00<0`Yi^0<BOL`34Wg<00`35X7@30<JQM@040<NRM@36XG@0aZ5d0<JQM0<0aJ1c1034Wg830<FPL`<0
aZ5d00H0b:1_0<ROL@36X740aJ1c0<FPM033X7H20<:QN0H0b:Ml0P37YW/20<>PMP040<BQM`35XWP0
aJ9h0<JSN@80ajAj2035XgD20<:PL0040<6OL@30WW40`9ec0;nLM080_Y]e0`2oW7820<2ML`<0`Iid
0P2oWFl30;jLKP<0_I]]0P2lVVX60;^IJ@@0_I]]102lVV`20;fHJ`80_YU/0P2oVVd20<2KKPP0_I]]
0P30Vfl00`2oVVd0_i][0;jJJ0020;jJIP040;jKI@2mVFD0_IUU0;fII@<0_9QT0P2kUf<20;bHI00>
0;^GH`2iUF40^9AP0;NCG`2fTUh0]I5M0;J;EP2fSEL0^8mK0;VAGP2fT5l0/hmO0:j<G02/RU`80;6=
G@80[h]G0P2`S5P40;6=F@030;>?F`2bSUX0/XiJ0080/HeI0`2`S5P01`2_ReL0/XeP0;:>GP2bSUh0
/XiL0;:>FP2bSeT00P2bSeL80:j9E080ZhMC0P2/R5@0102]RED0[XYF0:j:EP2^RUH20:^7E@040:b8
EP2]REL0[XYH0:n;F@80/8aJ00/0/8aH0;:>FP2dT5`0]Y9N0;FAG@2cSe/0/8aH0:f9E@2/R5@0[XYF
0;2<F0020;6=F@030:n;E`2/R5@0ZXIB0080ZXIB0P2[Qe<40:b8E00@0:j;D`2^ReD0[HYD0:b8E02[
QeD0ZXIF0:Z5F02YQ5L0[HYD0:b9D`2ZQe40Z8E?0:J3C@2UPT`0Y85;0:>0BP<0Yh9=:oooool002[o
oooo0P2QN4@01@2RNDD0Y7]70:ElB02VODT0Ygi:0080Z7m;00H0Ygi:0:ElB02TNdL0Y7]70:ElB02W
OTX20:QoB`80Ygi:00<0YWe90:MnBP2XOd/00P2ZPDd80:V0BPP0Zh5?0P2[PTh0102/Pdl0[HA@0:f4
D02^QE420:n6DPP0/8MC00H0/8E>0:n6CP2_QU00[HEA0:^6D@2ZQU820:N6D`0<0:j5D@2]Q500[8=?
0:^2CP2ZPDd0ZH1<0:QoB`2WOTX0YH1;0:AoBP2SOTT0XWe80P2QO4L00`2ONTD0WWU409iiA00209ag
@`0409]f@P2IM400V7<o09Ia?@80UG0l0100Tfe0099/?`2AJch0T6Xm08iX>`2=IcX0S6Hi08]U>029
IS`0Qf@j08=P=P20GC<0Oe`b081M<`21GS@0PUle0P1lFC40101kF300NUL_07YG;`1iERh:07QE;@08
07QD<01iEC40NULa07aI<@1nFc40Oed`085O<P21Gc4208IQ=00408MR=@28HcH0RF@g08YU>080RfHi
00P0SfPm091Y?P2@JSd0TF/l099/>`2CKSX0U6lk09A_>P<0Ug8n0P2FLCd309E`?0P0VFe0202GK3l3
099/?@80TF/l0`2@JS/209=X>`80TVLj0P2AIST5091U>080Sf@g0`2>HcH02`2>J3/0SFLj08]U>02:
I3L0RF<f08YT=`2;ICP0S6Hi08US=P2:I3L0S6Hi00<0SFLj00D0S6Hi08]U>028HcH0RF@g08YU>002
08aW>P0608YU>029I3L0R6<f08QR<`29Hc@0RV@e0P2;ICH00`2:I3D0RF<d08QR<`0908QR<`80Qf4b
0P28HS<01`29Hc@0RV@e08]U=P2;ICH0R68c08US=02:I3D00P2;ICH00`2:I3D0RF<d08QR<`0208YV
=P80RFDe0P28I3@208MS<`0908QS=P27HSD0QV4d08EP<`23GS40PUd`085L;`20Fbh0Q5lb00@0Peha
00<0Q5lb08IQ=026HC@02029I3L308eX>`80SVTl0`2?JSd308eY>@80SVXj0P2?Jc/01P2@K3`0S6Xj
08e[>`2=Jc/0SV`l08m]?@80T6hn00<0TFlo099`@02BL4001P2BL4009P2@LD80TgA509EfA`2CM4D0
SVm008a]?P2>Kd00TG93095f@@2@MD00SG4o08U]?@26JS/0PVDi07mR=P1nHCL0OV8`07eS<P1lHC80
Melc075J<@1YDbh0HDdZ05e9:01E@BP0D3hV04Xj8`12=B80>S4P03D_8@0a;B40;bdQ02//700Z:a/0
:R/M02TY7@0X:1h09bLO0P0V9B000`0R9A`08B@K01lR6@0201hQ600301lR6@0Q91/08RDL008082<L
0`0O8Q/301hQ6P808RDL00H08bHM02@W7P0S9Qd08B@K01lR6@0M81L901hQ6P80824I00<08B8J028S
6`0S91`00P0T9Ad06@0U9Qh09bTK02TZ6P0[;1`0<2lM03@a7P0h<al0>cDO03`f8012=Q`0@cLM04@j
8@12>R<0?cTS03Xe8@0e<Ql0<RlL02/V800[9ah0;2PO02dY7P0^:Qh0<2dN034^7@0b;ah00P0a:ad3
038/7P<0<bdO0P0_;1/01P0^:a`0;BTM02`X7@0[9ah0:RHM02XU7`809bLM0`0V9Q`302DU6`809RPM
00T09bTN02HX7@0V:1d092HK028T6@0Q8aP0824K01lP6P0N7aT00P0M7QP06`0N7aT07b0J020Q6`0V
9Q`0:RPL03@^8011=R@0CclX05M3:P1J@RH0FSlR06=77`1WBb<0LEH[081U>02AMTL0W89A09n5DP2N
Q540]YEO0:n>F@2LODl0NF4k05=2:00e;Qh09bPS02<Y:@0202DW90<092HS0`0S9B8802@T8P0<02PW
8P0Y:2<0:RXR02`/8P0^;R80<34S034b8P0b<b<0>3T[03Hg:@0d=BL0<S<U0P0`<B<2034b9008038`
8@0c<B80=34R03La8`0i<B@0>S0T03/a9@0m<BD803hb9P0603Xd:00l=2L0?CDX040g:012=RH0@cHU
0`14=B802`0m>2@0?SLT03hg9010>2D0A3TW04Hi:019>BT0BSXZ04He8`17=R@0BCPV00<0BcXX0P19
>2H204Pi8P0404Xj8`1<>R@0CC/U04lj9@80DC/V00H0ECXW05Hk:01G?2L0FClX05]1:01L@RL205i5
9`0906=8:P1QB2T0GdPY05Y7:@1EART0D4DY04i5:01;A2P0E40W00<0ED4X0P1F@RT205M3:P0305i6
:P1MABT0G4@X0080Fd<W00D0G4@X05e5:@1NARX0GTHZ05Y29P0205Hn8P0<05Y29P1LA2P0Fd<W05U1
9@1DABH0E4DX05939P1A@BL0CclV04dm9P1<>bL0BcXV0P1;>RP304dl:P0_04/j:019>2H0B3LU03/f
8`0j=B80>C@Q03Pc800i=240>SDR03`g900m>2D0?3LS03`g900k=R<0>C<S03Pb900g<BD0=RlU03D^
900b;200=2`O03D]800i<240?S8R048e9017>2D0B3TV03le6P15>Al0BclU04m19`1>?RD0CS`T054m
9@1D@2P0F4<T05M49P1EA2P0DD<Y04]0:P12>bP0?3LT03Ld8`0k=b/0>SHZ03Lc9`0e<BD00`0c;b<0
0`0d<2@0=c@U03Ld9@0303Hc90<0=C8S0`0h<R@203Tc9@<0>S@V00P0>S4P03`c8P11=R@0A3LT04Tj
9@1;>b@0C3`U04dk8`80D40W00L0D40V05=2:01G@bP0FD@W05e69`1OB2P0H4LX0080I4d^1@1UCRl0
1P1TCBh0He0_069?;P1PCBd0Gd`^05i:;`80GTXa05@0Gd/c069A<`1SD300HDh^065=;01TCB/0Idl[
06]A;01]Dbh0NEdf07aP>@23Icl0RFi308mdA`2BMdP0TgQ909=iB02?OTX0Sge;08akC@29NU40QgMC
08AeEP22M5T0PG=I075TD`1bHdh0LV5707MP@@1nHSd0QVLk08i/?02DKSd0YX0o0:N4@P2[S4/0[IAB
0:nLFP2^X5l0[:=R0:^SHP2NW6<0WYQV09jAI`2LRVH0Vh=O09UlDP2INDP0UgLn09Qi@`2HND80VgQ0
09mh?@2SNS`0Z7/j0:em>`2`Oc`0Z8I60:J4A02SPD80X7i109ml@P2OO4@0XGi60:9oB@2/R4X0[HU=
0:n=D02^SU<0ZhaC0:J9D@2QPdd0W85:0:Ad@`2VMd40ZWa00:n2?`2bQd80]8U50;F9BP2eRD`0/XY<
0;28BP2^QTP20:f5A`0;0:j6B02`R4X0/HU;0:n6A02^QdH0[HI50:Z4A@2VPT@0XX1309em@P2KNd00
0P2SPD801P2SPD@0Wga209Yg?`2IMT00VgM309ijAP80VgLi0`2JMSP01@2LN3X0WGTk09ij?02ONcd0
W7Pj0080VGDg00d0W7Pj09ij?02MNC/0VgLi09Yf>P2MNCd0X7a009mk?`2LN3`0VgLk09ei?@2QOD40
Xgm10080Y8120P2UPD<03P2TP480XWi009mk?@2NNS`0V7Pk09al?`2QPT80Z8U80:n@C@2dUU00^9YB
0;ZLE033XF40aJ=S0P38YVH03034XV80_I]K0;FCD`2`STh0YH530:B0@P2ROT00XGdo0:9n@02SOd40
Y8120:F1@`80YXE000<0YhI10:R7@P2XQd800`2XQd80102SQ4@0XX=309n0@02MOSh209]l?080W7dm
0P2POSl209mm?P0@0:5o@02UPd@0Z8I70:Z8B@2]Rd<0/Hm80;6@B`2`TE00/YAF0;6DFP2UR500UGY3
0:65D`2RQU@0Y8QF0:J:F080Yh]I00H0YXYH0:F9E`2URU<0Y8UB0::7D02PQDh209n4C@80X8E>00@0
WhE<09j4B`2NQ4/0WXA;0P2MPdX209b2B@80W8=;0P2KPTX309Z1B@0609V0B02KPTX0Vh9:09Z1B@2I
P4P0V7m70P2GOTH01@2FODD0Uga509MlA@2FNd@0UGY30080U7U20P2CN440:P2LND40WWe70:F4C`2^
SUd0]iQZ0;jQM`34Z800b:b50<bdT03:/X`0b;2:0<N`Q`35[X@0`:Um0;RRL`2bW6d0/9AU0;FJK@2m
XWL0_jIn0<6YQ@33[8X0a[6B0<^fU`3A_JD0e<2X0=[6[P3Pc;@0hlng0>C@^03SckL0h/jf0=g6Y03H
`9X0d;N>0<^^PP38Z7L0`j1Z0;^DF`2dSE80[HEB0:^3D080YX5=01<0XGe909eiA@2GMT40Tg@n095b
?02;L3/0Qf`g089V=01oHc<0OV8c07UL<01aE2P0JdhT071@:P1^CRP0JD/W06E89P1PAR<0GTHT0080
GDHV00H0E4<U05=2901B@B<0DD0R04ln801>?Al204dl7PP0BSPP0`12=B82044d8@<0@3<P0P0n<B02
03d`7`80?2lN0P0k;Qd803X_7@80>RdL0P0k;Qd00`0l;ah0?C0O03ha800403ha8080?C0O0`0l;ah3
03ha8080?C0O0`0l;ah203`_700403d`7@0n<Ah0?c8O03lb7`80@3<P0P1:=Qd204/g7P0404`h7`1=
>B00CSXQ04hj8@P0BcXP0P1;=al204`h8080CCTQ0P1>>R801P1:>Al0C3PO04`h7`1>>200D3PP058h
8@80DcLQ201B>Qh305Pj8080FC/Q0`1J?28205m1:@0305m19`1O@BD0Gd8T0080Gd8R00<0Gd8P06A6
901TAR@00`1UAbD306I89P0306M99`1XAb@0JDPU0080JDPU0P1ZBBH206]:9`0506i;9@1_C2H0Le0Z
07IC;@1hEBl00`1iES00201hFBX0NEX[07]L;@1lGBh0OEh_07aM;P1kG2d0NU//0`1mFS0207iK<@<0
Oe`b00P0NeP`07aI<@1lFC40O5Ta07]H<01iERh0N5D]07MD;0P0MeP/0`1jEbd207UF;0<0N5D[00@0
OEL`07aF;`1lERl0O5H_0`1kEBh01`1jE2d0OeX]081K;P20Fbh0PE`_089M<023GS400P24Gc8208]W
=`0308aX>02=JCT0SVXj0080Sf/k00L0T6`l08aW>P2=J3/0SVTl091[?P2BKD00Tfi10080UG1300P0
V7=609E`@`2?JSd0RVDh08QS=P29I3L0RfHi08eX>`80RVPj0P2;JC/03@2<JS`0SF/m08e[?@2>K3h0
S6Ho08eX?P2>JCl0SfXn08mZ?@2=JCT0S6Pf08YV=02<Ic<00P2;IS801@2<Ic<0SFPd08mZ=P2AK3P0
Tfhj00L0UF/i00`0UV`j09E/>02FKCT0V6lk09U`?02JLCd0VG0l09Q_>`2GKSX0VG0l09Ya?@2KLSh3
09ed@080W7<o0P2OMT8209ie@@<0WGA00P2LLcl209eh@`80WWU40`2ONTD0402PNdH0XWe80:5lA`2P
NdH0WgY50:1kAP2RODP0Xgi90:F0B`2TP4`0YH5=0:J2CP2WPdl0ZHEA0:Z6DP2[Qe<20:b8E0<0[HUE
0P2^RUH20:n;E`80/8iN0`2_SEd30:j<G0<0[heO0P2`SV030;6?H@80/8iP00@0[heO0:j<GP2]Red0
[8YL0P2[RE/01P2/RF40[8UO0:b9G`2/RUd0[8YL0:b:FP80[8]H00D0ZhIJ0:b7F`2/QeX0[HUI0:j:
F0020:n;E`060;2=E`2`Rel0/8]O0;2;GP2`S5`0/8aJ0P2`S5P00`2`SEL0/XiN0;:>GP030;6=G@<0
/8aL102bT600102dTV80]YAT0;RFIP2iUfL40;RFJ0040;ZHJP2lVV`0_Ya^0;nMK`80_9YZ0`2mVf/3
0;jLK0P0`iia0P31Wg420<:PLP<0`j5c00<0a:9d0<>OK`33Wfl01P33Wfl01035X7H0aZ5g0<JQM`36
XGL20<NRN080b:=i0`38XgH40<NRM@80aZ5d00@0aJ1c0<JQM036XG@0aZ5d0P37XWD20<RSMP80bZ5c
00@0b:9e0<NRMP37XWP0aJ9j0P34XW`30<RYO@80ajQl0`36Yg/80<FRN0<0a:9d0P35XgD30<JTMP80
`Z1`00@0`Ima0<2NL@30WG<0_iad0P2nVgD30;nLLP80`9ec0`31WW@30;nMK`80_Ya^0`2mVfd20;fK
J`80_9YZ102kVFT30;jLKP80_I]]0`2lVV`30;jIK080_iY]0`30Vfh80;jLKP80`Ia`00<0`9]^0<2L
K02oVfT00P2oVfL0102nVfD0_YYV0;jJIP2nVVH20;fII@<0_9QT0100_YYV0;fII@2lV6@0^iMS0;VE
H@2hU600]i=O0;JBGP2iSUT0^I1J0;V@G02hT5d0]HmN0;:>GP2_SEd0[XaN202bSF020;2<F0030;:>
FP2cSe/0]91L0080/hmK00D0/XiJ0;B@G02dT5`0/hmK0;:>FP020;6=F@<0/8aH00H0/hiQ0;>?G`2c
Sel0/hmM0;>?F`2cT5X20;>@F080/8]F0P2_RUD20:j9E080[HQC00H0ZXIB0:^7D`2[Qe<0[8QD0:f9
E@2^RUH20:n;E`80[8QD00@0[HUE0:j:EP2_ReL0/8aH0`2aSET0202bSUX0]91L0;FAG@2eTEd0/hmK
0;2<F02_ReL0[XYF102_ReL01P2^RUH0[8QD0:b8E02XQDl0ZHI@0:^8DP<0[8UC0P2[R5801P2_S5H0
[XYF0:j:EP2]REL0[8QH0:^6F@80ZXEI00@0[8UC0:Z7D@2XQDl0YX==102UPT`30:N2CB_ooooo000Z
ooooo`040:9iA@2SNTH0XgY60:AkA`80YGa80P2VODT00`2XOd/0Ygi:0:ImB@020:ElB0060:ImB@2W
OTX0Z7m;0:V0C02XOd/0Ygi:0P2VODT00`2XOd/0ZX5=0:^2CP080:V0BPP0Zh5?00D0ZX5;0:^2C02[
PT`0[8==0:j5C`020:n6D0030;27D@2aR580/HQB00H0/HQB00H0/8E>0:n6CP2_QU00[HEA0:^6D@2Z
QU820:N6D`0<0:n6DP2^QE40[HA@0:^2CP2ZPDd0Z7m;0:MnBP2VODT0YH1;0:AoBP2SOTT0XWe80P2Q
O4L00`2ONTD0WWU409iiA00209ag@`0409]f@P2IM400V7<o09Ia?@80UG0l0P2BK3l02@2AJch0SfTl
08iX>`2=IcX0S6Hi08]U>025HSP0Q64g08=P=P05089O=@80O5Ta00@0NeP`07YG;`1jEbl0NEH^0P1h
EBd807YG;`80NeLc00H0O5Tc07eJ<P1nFc40Oed`081N<@20GS0208EP<`80QV4d00@0Qf8e08QS=P28
HcH0RF@g0P2?J3d00`2@JSd0TF/l099/>`0209=^>P0409A_>P2GLSh0Ug8n09Mb?P80UW4m0`2EL3`8
09UZ?PP0Uf`o0`2BK3d2095[?0<0T6Xk0P2CJ3/2099W>P80TFHi1@2@ICP208mT=`<0SV<f00<0S6Hi
08]U>02:I3L00P2:I3L03P2<IST0SVPk08mY?02;ICP0S6Hi08eW>P2>J3/0SFLj08aV>@2:I3L0RF<f
08QS=P29I3L0RVDh0P2<IcX01P2:ICP0RF@g08QS=P28HS<0RF<d08YT=@80RfDf00<0RV@e08US=028
HS<03@28HS<408US=00408EO<027HC80RF<d08]U=P80S6Hg00@0RfDf08YT=@2:ISH0RVHf0P29ICD2
08QT=080Qf<c00`0RVDh08UT=`28HcH0QV4d08EP<`23GS40PUd`085L;`23GS40Q5lb08EP<`26HC@2
08MR=@0308IQ=025H3<0RF@g00L0RF@g00@0SFPk08iY?02>JC`0SVTl0P2?JSd2091[?P80RfLg00@0
S6Ph08iZ>P2?Jc/0TFdm0P2BKSh8091^?PP0TW100200TW=409EfA`2GN4T0UGI7091a@P2>Kd00T752
09=dA@2BMd80T7E008ea?`2:KSh0QFTj089U>@1oHSH0OF0f07eQ;`1lHS40Nf0a07IN<P1`FC00Ie4/
05m;:01JARD0E40X04lm9`1:>BD0@C@S03T`8@0d;R00<2`Q02h[8P80:BXL00T0:2PL02LW7@0V9Qh0
9B@O02@S7P0T8al08B@K020S6P0O8QT00P0N8AP00`0P8aX08B@K028U7002020S70<07b8K0`0N8AX0
200R9A`08bHM02@W7P0T9ah08RDL020S6P0N8AP07B0G2@0N8AX2020Q6@03024R6P0R8a/08b@L0080
92DM01T09BHN02P[6P0Z:a/0;2dK034`700e<ah0>SDO03dg8@0n>200ACLL04Hh7@16>R00@c/T040j
900h=B80<c8P030_7@0Z9Al0:RHM02/W7P0]:Ah0;b/O030]7P0a;Qd0<RlN00<0<B/M00<0<R`N03<]
7`0c;Al00P0d;R0202l/6`0602h[700]:Ad0;2PM02/W7P0Z9Qd0:RDO0P0W9ad302HV70<09BDK0P0V
:1d202LY7P0702HX7@0T9Q/08R@I020R5`0P8A/07b0J01hO6@0201dN600A01hO6@0P8A/08B8L02LX
6P0[:A`0=BlO04<h9P1A@BX0F4@[05Q09P1F>b00HdXQ06I=901_Eb/0OVHh08ifAP2IPU000P2NQe<0
202lUf00[8QD08a_@`1WDc00Ac/U034]8P0U9b@07bLY0P0U9b@302@V8`<08bDR200T9280300Y:2<0
:RTT02/[8`0/;280;RhR030a8`0a<R80<S<S03Lh:P0f=bT0=3DW038c9@80<C8T00L0<S<U03<d9P0d
<R<0=38S03Db8`0g<B<0>30S0080>S0T00<0?30T040b9`10<RL00P10<RL403la9P0703Tc9`0j=2P0
?SHY044g:`14>2X0ACPX04@g9P0204De9@0;03/i900n>BD0@3TV044i9P15>2L0B3PX04Xi:@1;>2T0
B3LU04Th9P1;>RP00P1=?2X00`1<>bT0BcXX04Xi9`0204Pi8P0404Xj8`1<>R@0CC/U050k9P80DS`W
00H0ESTW05Lj:01H?2L0FShX05a0:01N@bP20615:0080697:@1PAbP0GTLX05U6:01DABP0Cd@X04a3
9P19@RH305I19P80Ed8W0`1H@bP00`1OAb/0GTHZ05a4:00205]39`0N05a4:01NARX0GdL[05m8:@1J
@b@0ESlP05M08@1J@b@0GDHW05a59P1I@R<0Dd@U05939P1A@RD0CclU04dm901;>b@0BCPT04Pg8`18
=bD0BCPV04Xi9`1;>RP0BSTW04Th9P17=R@0ASDS03Xg900i=R<0>3DR0P0f<b002@0g=240>3DR03Tf
8`0k=R80>SDR03Td8@0h<R80=S0R03@^8P0203</8P0L03D_8`0g;b80>30S03/b8`0o<b<0@C@S04@e
8P15=R<0@cTN04Pl8P1<@2H0Cd4W04dm901>?2@0DclW05I2:P1F@bD0Ed<X05A4:P1A@R/0BSl[044j
:00h=B@0=34R03/g:`0i=BT0=c<W03@`90<0<blS00<0=30T03Ld9@0g=2D00P0f<b@203Db8`80=34R
100h<R@203Tc9@80>S@V00P0?SHS03lg9014>BD0B3`V04/l9@1=?BH0C3`S04dk8`80D40W00L0DD4W
05=2:01G@bP0FD@W05e69`1NAbL0H4LX0080ITl`0`1UCRl306A=;P1H065>;@1OC2`0GT/[05e:;01M
BBh0GTXa061<=01QCCD0GTd_05i;:`1MBRX0GTXY069;:@1WCb/0K58]06mE<01eFC80NEdf081T?027
K440SG9508mdA@2@MDH0T7I508UhA027Md@0QGA6085bB`1mKTd0NVaA07IZE01fJEH0Jem906iPAP1d
HD<0Nf<m08EY>P2@KcT0Vg@i09mg>@2XP4D0ZX=:0:Z:D@2ZTET0YiIP0:>II02MVVL0ViUV092@GP2?
S5l0ShMR0960HP2ANUX0TGE>099b@`2BLC/0UWQ409Mh@P2JMcl0WgPm0:Ij?@2]OC/0/h0n0;N2?P2[
RTL0Z8I60:B2@P2POSl0WW`o09ml@P2QOTH0Xh180:Z8B@2[RD`0ZHU<0:N9C@2TQdd0X8=;09^0B@2H
ODH0Xflo0:Ie?@2]OCd0/XHm0;J:?`2gSDD0]h]:0;N;CP<0/8Q:0P2_QdT04`2`R4X0/HU;0;69B`2]
QT<0[HI50:f7AP2[R4P0Z8I70:B4A`2QPDH0WX140:B2@P2VQ4D0YH=60:1mA@2JMd40Ug<o09YfAP2N
NTX00P2NN3T209eg>00609mi>P2QNc`0Y7ho0:J0@@2XPT<0Xgdn0P2NN3T03@2QNc`0XW`m0:1j>`2M
McP0X7Tn0:Am@P2VOd@0YGi30:5j?`2PNCh0XW]00:IoA02QNcd00P2SOCl0402UOd40Yh530:R2A02X
PT@0Yh530:J0@P2RPTD0YHE80:^<C02aTU40]YMD0;ZLEP2mWeL0_Z1H0<RVIP3:Z6P20<j/K00<0<ZX
J032X600^IMG0;>AD@2WPdD0YH530:B0@P2SOd40XWi00:=o@@2UPD<0YX940P2UQ3d20:J5?P80YhHo
0P2XQd00102VQdL0Y8E50:62@P2OP40409en?P80Wgdn0180X7ho0:5o@02SPD80YH=40:N5AP2XQTL0
[Xa20;6?A`2_STL0[8e:0;:DE02fVEd0ZhiD09MmA02QQE<0XXID0:B8EP2WReT20:R<FP060:N;F@2V
RUP0YX]D0:B9DP2RQe00X8E>0P2OQ4d0102PQDh0XHI?09n5C02OQD`309j4B`<0WH=:00@0WHA<09b3
B`2LPd/0W8=;0P2KPTX209Z1B@80W8=;00@0Vh9:09Z1B@2IP4P0VH180P2HOdL809IkA00M09ej@P2O
OTP0YXE@0:j>G@2gV6X0_j9h0<FYP@39[HH0cKFA0<ZbS038/8X0ak270<N`QP33[800^ZAe0;>MKP2^
TV80]9UZ0;bQM02oYWd0`:R20<:[R@35/I00b[FF0<nkX03C_jH0f<B[0=k:/P3Rc[H00P3Sc[T02`3R
cKP0h<^/0=g6Y03H_YT0eKR>0=FcP`3@ZgH0bJ5V0<:HG02hSU`0]XaJ0080/HUF01/0ZXEA0:B0C02M
O4L0VGQ309Ig@@2AMSl0SG8k08Q]>025JCL0PfLg07iR<`1gFb`0L5<W07ED:`1cDB/0KdlX06U;9@1V
BRD0HTPU06989`1QBBL0FTLW05U69P1HABD0ET<S05E28P1C@2000P1B?al304di80D0CSXQ0P16=b82
04Df8@<0A3DP00@0@c@O044b7`11<Ql0@C8O0P10<Ah303l`7@P0?C0M0P0m;Q/01P0n;a`0?c0M040a
7P11<Ql0@S<P04<d8@<0@S<P0P11<Ql3040a7P03048b8P11<B40@C4Q0080@30P0P0o;al01`0n;Qh0
?2lL03`_700m<1d0?S4N03lb7`10<b000P11=24204`g700604dh7@1>>Ah0CcXO050k801A?240DSdR
201>>Ql304hh8080CcTQ0`1@>R801@1<>1d0CCTN04hi7P1A>Al0DSPO0080E3PP00H0EcTQ050i6P1A
>Q/0DCXK058k701C?1d205@m7P0305Dn7`1H>R00F3XP0080FC/Q101J?28205m1:@030612:01Q@bL0
HTDW0080HdHV00<0HdHT06E78`1UAb<00`1VB2@306M99@0306Q:9P1YB2D0JDPU00@0JTTV0P1[BRL0
1P1]BR@0Kd`V07=@:P1fDbd0NEH`07YG<@80NePb00<0N5XX07UK:@1kGB/00`1mGbd207]M:`80OE/^
0P1nG2l307mM<003081N<@1mFS80OEXb0080OU/c00@0OEXb07]H<01hEBd0Me@/1@1hFB/307UJ;080
OU`_00<0OE/^07aJ;@1lFRd00P1kFB`01@1jF2/0OUPa07iH<@1nF340OEL`0080O5H_0P1kEBh01P20
G2`0PEd]085M;@22GRh0Pel_08AP<080QF4a00H0S6Ph08eY>@2>JSX0SVXj08m[>`2@K3`2095]?@80
T6/n00T0TF`o099]@02CKT40U6m209E`@`2FLD@0U6m209=^@@2@Jch00`2>JC`00`2@Jch0TF`o08aZ
?00408e[?@<0SV`n0100RfDn08eX?P2>JCl0T6/o091[?P2?Jc/0SVXh08eY=`2?JSH0SVTe08eX=02<
Ic<0SFPd08iY=@2@JcL0TF`h202FK3X02`2EK3P0UVdi09Q_>`2IL3`0VW4m09U`?02HKc/0Ufhj09U`
?02JLCd0W7<o00<0WWE100<0WGA009ac?`2RNDD00`2QN4@30:1g@`80WgI20`2ONT<20:1kA0<0XGa5
00<0Y7m:0:=nB@2RODP00P2QO4L00`2SOTT0Y7m:0:F0B`020:J2CP050:N3C`2YQE40ZXIB0:^7D`2/
R5@00P2]RED30:j:EP80[h]G0P2`S5P30;6?G`80/8iN0`2_SEd0102^S5h0[heO0:n=G`2_SEl20;2>
H080/HmQ0P2`Sf800`2_SV40[XeP0:f<G`020:b;GP060:^:G@2]RV80[HYR0:f:H02]Reh0[H]M0P2]
Re/01P2]S5T0[XUM0:j9G@2^RE`0[h]K0:n;F@80[h]G00L0[haF0;6;I02aS680/HaP0;6<G`2aSE/0
/HeI0080/HiF0P2aSEd30;:>GP<0/hmO00P0]99R0;>AH@2cTF40/i5Q0;FCH`2hUVH0^YQX0;bJJP@0
^YQZ00@0_9Y/0;nMK`32X780`j5c0P33XG420<:PL080`Im_0P30WVh40<JQM0@0aJ1c0`32X7820<>Q
L`<0a:9d1@35XG430<BPL0040<JQM`37XWP0aj9h0<NRN080b:=i0P39Y7X20<ZUN080bJAg1038XgH0
0`37XWD0aZ5d0<NRM@020<NRM@80b:=f0P39Y7L20<bSM`060<ZSN039Y7X0bJ=l0<NTOP36Y7h0aZAo
0`38ZGd00`37Z7`0aZMk0<JWN`020<FVNP040<RUN`37Y7X0aZ=i0<JSN@80a:5g00<0`j1f0<:OM@33
XG<00P34XW@20<FSM@80aZAf00L0ajEg0<:PL032X700`Ima0<2NL@30WG<0_iad0080_Y]e0`2oW782
0<2ML`<0`Iid0P30WW020;nMK`<0_Ya^00@0_I]]0;jLK02mVf/0_I][0P2lVVX20;^IJ@030;ZHJ02o
WFl0_ie_0080_Ya^00@0_I]]0;bJK02lVV`0_9Y/0P2nVF`20;nJK@@0`9]^202nW6h02032WG40`Ia`
0<6LK`31WFd0`9aZ0<2LJ02oVfL0_iaV0`2oVfL20;jJIP<0_IUU0100_i]W0;jJIP2mVFD0_9QT0;ZF
HP2iUF40^9AP0;NCG`2mTUd0^i9L0;V@G02fSU/0/heL0;:>GP2`SUh0/8iP202cSV80202`S5P0/XiJ
0;>?F`2eTEd0]Y9N0;FAG@2dT5`0/hmK0P2eTEd0102dT5`0/hmK0;:>FP2aSET30;2<F0060;B?HP2d
T600]91P0;B@GP2dT5`0]95K0P2dTET20;:=F0060;6<E`2_RUD0[XUD0:f8D`2/Qe80ZhIA0P2ZQU80
1P2[Qe<0[8QD0:f9E@2^RUH0[h]G0;2<F080[XYF00@0[h]G0;2<F02`S5P0/HeI0P2bSUX01P2cSe/0
]91L0;B@G02dT5`0/hmK0;:>FP80/HeI0P2`S5P00`2^RUH0[HUE0:f9E@020:f9E@090:j:EP2WQ4`0
ZHI>0:^8D02/RE40[HYB0:b9D@2[R500ZXM?0080[h]G00T0[XYH0:f9F@2/QeX0ZhIJ0:Z5F@2ZQE/0
ZXMA0:V6D02WQ4h00`2UPT`00`2VPdd0YhA>0:N2C@020:N2CB_ooooo000Zooooo`030:=jAP2TNdL0
Y7]70080Y7]70`2UO4P00`2YP4`0Ygi:0:ImB@020:ElB0050:ImB@2WOTX0ZH1<0:V0C02XOd/00`2V
ODT00`2XOd/0ZX5=0:^2CP080:V0BPP0Zh5?0P2ZPD/0102[PT`0[8==0:j5C`2_QU020;27D@P0/HQB
00H0/8E>0:n6CP2_QU00[HEA0:^6D@2ZQU820:N6D`0<0:n6DP2^QE40[HA@0:^2CP2ZPDd0Z7m;0:Mn
BP2VODT0YH1;0:AoBP2SOTT0XWe80P2QO4L00`2ONTD0WWU409iiA00209ag@`0409]f@P2IM400V7<o
09Ia?@80UG0l0P2BK3l0102AJch0SfTl08iX>`2<IST208]U>080PUle00H0Pf0f08AQ=`24HCL0Pf0f
089O=@21GS@207aI<@0407]H<01jEbl0NUL_07UF;P80N5D]201kF300201lF3@0OETe07eJ=01mFS80
OU/a07iL;`1oGC00Oed_0P24Gc8208EP<`80QV4d0P27HSD208mX?@06091Z?@2AJc`0TV`k099]>@2C
KSX0Tfhi0`2GLSh209Ia?@<0UG0l202HJCd809M/?`<0TV`m0P2AJc`3091Z>`80TfPk0P2BIcX2095V
>@D0T6Dh0P2?I3L308iS=P0:08]U>02:I3L0RV@g08YT=`2;ICP0SFLj08mY?02AJch0S6Hi08eW>P80
SVPk00L0SFLj08]U>029HcH0R68e08QS=P29I3L0RVDh0080S6Lj00H0RVDh08UT=`28HcH0R68c08US
=02:I3D208]U=P0308YT=@29Hc@0R68c00T0R68c0`29Hc@308QR<`80Qf4b00H0Ped^08EO<028HS<0
RV@e08aV=`2=IcP208aV=`80RVHf0P29ICD208QT=080Qf<c00L0RfHi08YU>029I3L0Qf8e08IQ=024
Gc80Peha0080PUd`00L0Q5lb08MR=@29I3L0RVDh08QS=P26HC@0QF0c00P0RF@g102>JC`208mZ?@80
T6/n00P0RFDe08YV=P2<J3P0SVXj091/?02BKSh0Tflo09A`@0<0TW100P2AKcl3091^?PP0TW100240
U7E609MhB@2HNDX0UWM8099cA02?L440TG9309AeAP2BMd80T7E008ea?`2:KSh0QFTj089U>@1oHSH0
OF0f07aP;P1kHC00NUl`07IN<P1_F2l0IU0[05e99P1IAB@0E40X04lm9`19>2@0@C@S03T`8@0c;B40
<2`Q02h[8P0X:A/00P0W9a/00`0V9Q`09BDM02@S7P0202<R7P03024T6`0P8aX07b8I00807R4H00<0
82<J024T6`0R9A`00P0P8a`301lR6`<07R4J0P0S9Qd202@W7P04028U700P8aX07R4H01`O5PT07R4J
0P0P8AT00`0Q8QX08R<K02<T700202@U7@0J02DV7P0X:aX0:R/I02`]6`0a<1`0=C<N03Xe7`0n>200
?cTQ04Hg6P17>Ah0ASXP04@l9@10>BH0>3DR038a7`0];Qh0:B@N02XV7@0[9ah0;BTN02l[7`0`;Ah0
<BhM038_7P0`:Q`2034[7@03038/7P0c;Al0<bdO0080=2hP0P0_;1/01P0^:a`0;BTM02`X7@0[9ah0
:RHM02XU7`809bLM0`0V9Q`302DU6`809RPM00P09bTN02PZ7`0V:1d092HK024S600O8AH0824K01lP
6P<07AhH01407QlI020Q6`0Q8Q`0:2TK02/Y6P0e;al0A3TW05=2;P1IABd0EclU05<h7@1TCB<0ITlU
06iG:`1lISL0S7I509R2D00209f8D`080<6HH02XQ500PfHl05i;:`12=b<0<2dT02<W9P0M9BP202DW
90<092HS0`0S9B8802@T8P0602TX8`0Z:B@0:b/S02`/8P0^;R80<34S0P0a<R80200f=bT0=CHX03<d
9P0b<bD0<C8T038c9@0c=2H0=3DW0P0e<b@00`0e<R<0=c4S03P`8`0203T_8`0303/_8`11<bP0@C<X
00@0@38W0P0o<BH01`0f<RL0>S@X03dg:`11>B`0@cX[04Di:@16>BP00P15>2L01P0k>RD0?3XU03lj
9P12>RL0ASTX04Ph:080BSLX00<0BCPV04Xi9`1<>bT00`1>?B/06P1=?2X0C3/Y04Pi8P18>B80BSXS
04`j901=>bD0D3/V058l9`1C?BP0ESTW05Lj:01H?2L0FShX05a0:01N@bP0H4DX0656:@1QARP0H4LX
05e69`1HABL0Dd@W04i39`1;@RD0B44U0P1F@B@305M29@<0F4<V00<0GdL[05i6:P1LA2P00P1K@bL0
1@1LA2P0GTHZ05m7:`1PAbT0G4<U0080F3lQ01L0Fd8T05i59`1MA2H0Fd8T0593901A@RD0D44T04hn
901;>b80BCTR04Pg8`17=R80AcHV04Pg9`19>2P0BSTY04Th:018=bL0ASDU04Dd900k>2D0>SLT03Pe
8P0303Hc800;03Ld8@0h=B80>SDQ03Td8@0h<b00=S0P03D_8@0c;B40<R/Q034Z800j=2P00P0k<bH0
0`0m=2D0?c<S040c8P02044b7`0F04Hl8@1:?R@0CD4W04i09P1=?B@0CS`T05A0:01HA2`0ET<U05E4
:01DA2/0Cd<[04Q0:`0o>RL0=c@S038`8@0k=b/0>CDY03Lc9`0d<2@0<blS038^8P80<blS0P0g=2D2
03Hc900503Db8`0d<B80=34R03<`8@0g<B<00`0h<R@203Tc9@80>S@V00P0@3PU048j9`16>bL0BShX
04dn9`1=?B@0C3`S04`k8@80D40W00L0DD4W05=2:01G@bP0FD@W05e69`1NAbL0H4LX0080Idlc00<0
IThb06E=<@1TC3000`1TC300FP1OC2`0GT/[05e:;01LB2d0GDT`05m;<`1QCCD0Hdhi05M6:01IARH0
F4DU05Y69@1PBBL0Idl[06iD;`1bF3<0LED^07EI<P1lH3P0Q6Tn08U^@@2<LD80SG9308ec@P22LSh0
PG4n07e_@P1iJd@0MFQ807=UB`1_HTl0KV5@06eQB@1aHdH0NVQ408A]@@2ALcl0WWXn0:N0?@2]PSd0
ZGi90:Z2CP2ZREH0Z8iM0:>BI02LTfP0UY=X096BJ025R5T0QhEL08N1G`29NUd0S7EF08eaC02?Kd00
Sfhh09MiA`2HN4D0W7U30:9k@02ZOSl0/X4o0;V4@02mQd40[Xe:0:Z9AP2UPd<0XGm009il?`2OO480
XWm50:>0B02ZR4T0ZXQ;0:N7BP2TQTX0X8=909^1B02HODH0UGa40:=]?P2WM3d0[Wdk0;F7>P2hSCh0
^Hm50;V=C02fSDl0[hM90;28BP80/HU;01D0/XY<0;69B`2aRD/0/HU;0:f6@`2]QdH0[hU80:f:BP2/
RT/0Z8Q;0:B6BP2SQDT0YXA40:V7B02XQTT0Xh1809ahA02HM480VgI909mjC@2ONCX00P2NN3T05P2O
NCX0XG/l0:An?`2WPD80ZXA50:f7B02WPD80X7Xk09mi>P2RO3d0Y7ho0:5k?02NN3T0Y7i00:N1@`2Y
PdD0Yh530:An@02RO3h0Y7i00:N1@`2LMSP209mi>`040:9l?P2WPD<0ZXA60:b6B080[HM900H0[He@
0;2@D`2dUED0^IYI0;bMFP2nX5X20;nQF@0;0<VWI`3<ZVX0cje]0=2^KP3;ZFT0`j5Q0;VGE`2bT500
Yh=50:J2A02UPD<00P2SOd400`2TP480YH530:J2A0020:B3?080YH@m00X0YXDn0:N6?`2XQd00Z8M0
0:N8B02UQTH0XX=30:21@@2NOcl0WGhn0P2NOcl01P2NO3d0Wgdn0:5o@02SPD80Y8930:F3A080YXA5
00`0[Xa20;6?A`2]S4D0ZHY70;6CD`2iW600[i9H09Z0A`2QQED0XXIF0:B8F02WRe/20:R<G080Yh]K
00@0YX]D0:F:D`2RQe00X8E>0P2OQ4d00`2QQTl0XXM@09n5C00209n5C080WXA;0`2MPdX209f4C080
W8=;0`2KPTX00`2JPDT0W8=;09b3B`0209^2BP0509Z1B@2IP4P0VH1809V0B02ENT<00`2FNd@409Ml
A@0N09ej@P2OOTP0YXE@0:n?GP2hVF/0_j9h0<FYP@39[HH0c[JB0<^cS@38/8X0b;680<RaQ`34[H40
^jEf0;>MKP2^TV80/iUX0;bQM02oYWd0`:R20<:/Q`35/I00bKFD0<jjW`3B_Z<0el>Z0=g9/03Pc;@0
h/fh0P3RcKX02P3Sd;80gl^Z0=g5X@3M`9H0gK^;0=VdO`3BZVl0bj5U0<2GH`2nUF420;VAG@0E0;>;
E`2[QU40Y85;09imA`2LNdD0UW]4099g@02=LSd0RVhl08Q/?023IcL0Nel`07EI:P1hEB/0MU<[079@
:P1]CBH0J4XT06I:9@1VBBL0I4XW0080G4TY00@0FTLW05U69P1GA2@0ED8R0P1D@B4404hj8@@0Cc/R
0P17>2<204Hg8P<0ACHQ00<0A3DP048c8012<b000P11<Ql3040a7P0303l`7@0m<1d0?C0M00H0?C0M
00P0?BhK03h_700o<1d0@34N044b7`12<b00@c@Q04@e8P<0@c@Q0P12<b03044b7`0404<c8`12<R80
@S8R044a8@80@30P0P0o;al203`_700>03d`7@0n<Ah0?c8O040c8011=240@SDR04`g6P1=>1/0CSTL
04lj7@1@>ah0DC`O058m801C?R4804ll7P0404hh801?>B40CcTQ04li8@80D3XR0P1A>b<03P1=>Q`0
CSTL04lj7@1A>Ad0DcTN05Dj7`1G>Al0F3XP050g6@1A>1X0DSTK05<j701E?1h0ESdO0P1G?R0205Ti
8080FSXQ0`1K>b802@1L?2<0Gd4Y0612:P1Q@bT0HT@X06=6:01UB2P0ITTY06I99`0306I890<0IdTU
0`1XBRH506Y99P<0JdXW00H0KdTT075;9P1eCbX0N58]07]E<01mEc8207iH<`0307QJ:01iFbT0Ned[
0080OEl]00<0O5h/07]M:`1jG2X00P1oFRd2081K;P@0PE`_00T0OEXb07iK<`1oG3@0Oe`d07iK<`1l
FC40NEH^07MD;01hFBX01@1iFR/207YK;080PUd`0P21G2l01020Fbh0OeX]07mJ;@1nFB`207mI<P80
OUPa00@0OEL`07aF;`1lERl0NeD^0P21GBd00`22GRh0Pel_08AP<00208EQ<@0708IR<P2=JCT0SVXj
08iZ>P2?Jc/0T6`l095]?@02099^?P05095/?`2BKD00TVe009=^@@2DKd800P2EL4<00`2FLD@0Tfi1
09=^@@02099]@080Tfi100<0U6m209E`@`2>K3h01P2>K3h0302=Jcd0RfDn08aW?@2>JCl0T6/o095/
?`2AKCd0T6`j08m[>@2AK3P0T6/g08iY=@80S6Lc00<0SFPd08mZ=P2@JcL0102GKC/409I/>P0;09E/
>02FKCT0V6lk09U`?02JLCd0VG0l09Q_>`2GKSX0VG0l09]b?P2MM4000P2OMT800`2NMD40WGA009ac
?`030:=jAP<0XWU50`2QN4@30:1kA080XGa50`2RODH00`2UP4/0Y7m:0:=nB@020:9mB00:0:=nB@2U
P4/0YX5<0:J2CP2WPdl0Z8A@0:V5D@2[Qe<0[8QD0:f9E@@0[XYF0P2_ReL30;2<F0<0/Y1P0P2aSel3
0;2>GP<0[XaN0P2_SEl30;2>H080/I1S00<0/8mR0:n>H@2^SF000P2]S5l01`2/Reh0[HYT0:f:HP2]
RV80[HYP0:f;GP2]Red00P2]Re/20;2;G`060;2;GP2_Re/0[h]I0:n;E`2^RUH0[X]E0P2bS6D01P2b
SF40/XeP0;:>G02bSeT0/XmG0;:?E@80/HeM0P2bSUh01@2cSel0]91P0;FAH@2eTF40]I=S00<0]99R
00D0]YAT0;VGI`2lVVX0_Ya/0;bJK0030;^IJ`040;fKK@30WW00a:9d0<JTMP80ajEe00@0aZAd0<FS
L`33XG40`Z1`0P31Wfl50<NRM@<0aZ5d0`32X7820<>QL`<0a:9d1036XW840<FQL@<0aj5j0P38XW/3
0<VSO0040<^VN@3:YGP0bZEh0<ZUN0<0bJAg0P38XgH30<NRM@80b:=f0`39Y7L01P3<XgL0c:9h0<ZS
N039Y7X0bJ=l0<NTOP80aZAo0P36ZGd01035Z7`0a:Mk0<BWN`33YWX20<:UN@80bJIl00@0ajAj0<JS
N@34XGL0`j1f0P31WW@20<>QL`040<BRM035XgD0aJ=e0<JTMP80ajEg0P32X7001031Wg40`9ia0<2M
L`2oW7@20;jKM@<0_iab0P30WG<30<6NM080`9i`0P2oWFl40;jLKP80_Ya/0P2mVf/0102lVVX0^iUY
0;^IJ@2jV6P30;nMK`030;jLKP2mVfd0_9Y/0080_9Y/0P2nVF`20;nJK@<0`9]^00<0`Ia_0;nMK`2o
WFl01P2oWFl20<:ML@030<6LK`31WFd0`9aZ0080`9aX00@0_iaV0;nKI`2oVfL0_i]W0P2nVVH30;fI
I@80_i]W00h0_YYV0;bHI02kUf<0^YIR0;VEH@2hU600_iAO0;bCG@2iT5`0]HeJ0;:<F`2aSEd0/HmO
0;:@HPP0/hiR00P0/HeI0;:>FP2dT5`0]Y9N0;NCG`2fTUh0]91L0;>?F`80]Y9N00@0]I5M0;B@G02b
SUX0/HeI0`2`S5P01P2dSf80]91P0;B@H02dT5h0]91L0;BAF`80]95I00P0]8mJ0;>>F@2bSEP0/8]F
0:j9E02/Qe80ZhIA0:Z5D080ZXIB00<0ZhMC0:b8E02]RED00P2_ReL01@2`S5P0[haF0:n<EP2`SEL0
/HiH0080/XmI0P2cT5X00`2eTEd0]91L0;>?F`060;:>FP0J0;2<F02]RED0ZhMC0:^7D`2/R5@0[XYF
0;2<F02WQ4`0Z8E=0:^8D02/RE40[HYB0:b9D@2ZQdl0ZHI>0:n;E`2_ReT0[XYH0:f9F@2/QeX0ZhIJ
0:^6G02ZQE/0ZHI@0:R5C`2VPdd20:B1B`030:J3C@2WQ4h0ZHI@00<0Yh9=:oooool002[ooooo202W
O4T80:QmB0030:^0C@2ZOd`0ZGi;0080Yga900<0Z7e:0:UnB`2ZOd`0202/Pdl20:^2BP040:b3B`2]
Q4`0[HA<0:j5C@80[hI>0P2_QE<00`2_QU80[hI@0:n6CP020:n7C0090:n7BP2/Pdl0[HA@0:j5D@2_
QU80/8MC0;68E02bRED0/hYF00P0/hEC0P2[P5D00`2ZOe@0ZGiC0:QmDP020:MlD@050:IkD02RODT0
Xgi:0:=nBP2TOd/00P2SOTX00`2QO4P0WWU509ehA00209egB00409afA`2KMDH0VWA509YdA@80VG=4
00H0U74k099^>P2?JcL0S6Pf08UU=@28HcH208QS=`80Q6<h00@0Pf8g085P=@20Gc@0OUdb0P1mG343
07aI<@<0NeP`0P1jEbl207EB;00407IC;@1gE2h0Me@^07QE;`80NEH`00h0O5`c07]K<P1jFS40NUXa
07]K<P1mGC@0Oelf085Q>020FS<0PUdc08EP=P29I3P0RVDh08]W=`80RVHd0P2?JSH0102@JcL0TF`h
099]>@2BKCT209=^>P0809Ye@@2GLSh0Tfhj08mZ=P2>JCD0T6/g09A_>`2FLCd209Q]@080Uf`o0`2F
Jch02@2EJSd0UV/n09M/?`2HKD00VFi109Q]@02GK3l0UFXm09=X>`0309=]?P03099/?@2AJc`0T6Xk
0080T6Xk202?JSD2091U>00308mT=`2>HcH0SF8e0080S64d00<0Rf0c08aV>@2<IST01P2<IST808UU
=@0308mY?02=IcX0S6Hi0080RV@g00H0S6Hi08eW>P2?JC`0SfTj08eW>02<ISL208YT=@0308aV=`2=
IcP0SfTj00@0RV@e1@29Hc@208MU=@0308UU=@2:I3D0S6<e0080SF8e00<0SV8e08YT=@2:I3D03P2:
I3D808MQ=00308EP<`24Gc80Peha0080Peha00<0QF0c08MR=@28HcH01028HcH408UT=`0608US=02:
I3D0S6Hg08iX>@2?JCX0SVPi0P2=IcP208iZ>P0408m[>`2@K3`0T6`l095]?@80TVhn0P2@K3`2095]
?@@0TVhn00<0T6hn099`@02DLT800P2ELd<0:`2DLT80TW10095_?`2CLD40UG=309QfAP2JN4P0VGM7
09IdA02CLD40T6hn08meA02>M4<0S79108U_?P26K3/0Q6Xi089X=`20ISD0O6D_07]T<01gHBl0LUd^
06]H;@1UDb/0H4hX05];9`18AbP0A40S03di7P0k=Al0?3<R03``900i;2<0=RLP02l]7P0^;1d0:b`N
02PZ7@0V:1d092LN024V7`0P9Ah00`0R9A`3024T6`X082<J00P08RHG028V600Q9AL082<H01hQ600M
81T071hI01/M60T07R4J0P0P8A`06`0Q8Q`08b@L02@V6`0V:1/09bTL02LY6`0[:Ad0:bTL02dY7@0a
:ad0=RlO03/b8@0o=b@0@cPV044e6`14>200AC/R04Dm9P12?2H0>cHR03<`7@0_;1T07bDG024W6@0V
:Q/0:RdL02h_7@02034`7006038`6`0c:ah0<b/N038/7P0_;1d0;R`M0P0[;1`02@0Z;A`0;BXI02h[
6P0_;1d0;b/O02hZ7`0/:1l0:BDL02PS7@0202TY7`0402PX7P0W9ad09bLM02HV70809BDK0P0V9al0
100U9Qh092DM02<T700R8a/2024R6P0P024Q8`0P82007alO01dM6`0M7QT07QlI020Q6@0Q8QX0;RPB
03<[500k<AP0ASPM04ln801G@b80FT<Q05]37`1VB2H0L58`07mQ>`2:KDD0T7=709MkB`2XSEP0^9eX
0;F@F@2PQ5D0M6A304Ho;@0];BD0;2`Z02hZ:`0X8R@802<U8P0>028S7@0S91h09BHP02LX8P0Y:R@0
:2TS02HW8@0S91h09bLO02TY7`0/;280;blS034b900b<b<2038c8@03038^8P0c;b<0=C4U0080=S8V
00H0=C4U03<_8`0b;R80;b/O030/800c;b<303Da9@0803<_8`0b;R80=c4S03P`8`0i<B@0>S0T03da
9@0n<2D2044`9P0703/f8`0l=B<0?3DS03dd8`11=BD0ACPX04Xj:`0204`l;@0N040`8@18>2P0DT4a
05E2<@1B@2`0D3/V050j8`1A>b@0BcXZ04Tj9`18>BH0ACTS04Dk8P14?B40AD0R04M2901A?2T0D3/X
050k9P1@?2@0D3`S058n8`1E@BH0ET<U05A2:P1F@RT0Ed<Z05Q3:01K@bL0G4<U0P1N@bD0201SARP0
GDHV05A79@1;Ab@0BDHU04Y39P1A@BL0E40X0P1E@2/0101E@BT0ET8Y05M3:01GA2H205Q59@80FDHU
00<0F4DU05Q59`1G@bP00P1G@bX01`1F@RX0E3hV05@n9P1C?bH0DT4W05=2:01C@bT00P1BA2T01P1D
@B40E44S05=08P1C?b@0DShU054m9@80DC`W00P0C48W04]19P19?b@0AcdR04Dk8013>Ah0@SPM044g
7080>C8P0P0h<b00100f<b00=C@P03<e800c=B0303D_8`80=S0T0`0g<BD203L`9P0303La9@0g<B<0
=c4Q0080>3<P0140>3<O04<h8P12=b40@cLQ04Df8@18=b<0C3XV04lm:@1C?R/0Dd@_0511;01:?BX0
ACXX040g9P0l=BD0>c@T03Xd9P0303Xd:00303Tc9`0h<RH0=c4U0080=c4U00H0>S@V03Tc9@0i<bD0
>38T03La8`0f<28203D_8@80>C0O0P0j<B0203/b8@80?3<R00P0?SDT040g9P14>BL0AcXW04/l9`1<
?2D0Bc/T04`j8P80Dd0R00<0ED8T05M49P1JAbT0101KB2X205a<<P0405i=<`1PC3<0HT`d06===@80
IThf00<0GTT/05a7:P1JABP00P1H@bH08`1JABP0G4LZ05i9;01DA2X0ED@X05I59`1JAbH0GTXU06A>
9`1YDRP0Je@Z07MH8P1oH2X0PV@`07iR<021IcH0QVhn08M_?`21Jc`0N6Q607UYA`1gIdH0LV5306]J
?P1XESh0JeU106iLAP1iESH0PETe08aP<@2HJC<0Wg8g0:1l@02PPd/0WHQA0080UHmM03H0U8eO09><
H02@R640SXIR08^2H@29P640QgIH085aD01mJDH0OVPo08=[?@27JcT0QVLa089S;02OKc40Y7Da0:Qm
;`2^QC<0/8Xg0;6<?P2aRTD0[hU:0:V;C`2VR4`0XX990:1mA`2NNdD0WgY60:9jB@2TO4/0Xh=:0:N4
C02VPd/0XWe609ae?P2HKcT0VFhi09]`>`2UMCD0[7`j0;>3@@2gR4@0]hQ20;R9@@2kS4@0_Xm70:j7
AP2_R4L0/8U60;6:A`2bRdH0/he60;B>A@2eSdH20:n7B@030:j6B02]QDL0[8A60080Zh=50280ZX94
0:R:C02WQdX0Y8930:9l?@2PMcL0XWHe0:Mg=@2YNCL0/gT`0;Ak=02fOCH0]h4k0;N2?P2ePT00]8=1
0;>2@02XRDT0YhQ80:J4A@2QOCl0X7Xl0:Al?`2]QDP0]Xa@0;BAC@2aSTX0ZhQ40:N4@02UPSh0YX<o
0:R5@@2ZQd<0ZXM70P2XQDD01`2YQTH0[ha<0;NDE02jUeL0]iAD0;:?C`2fUDh00`2eU4d0402gUTl0
^IQA0;bKE02mW5D0aZMV0<VZJ@3=[Vd0ck1_0<b]K034YF@0^iaK0;FFE@2bSDT0[HQ40:R3?`2WPSh2
0:V4@0060:F0?02PNcL0XX110::0@@2SPD80Y8930P2UPd@20:J4A@0809n6@`2PQd@0X8M409b3@02G
OS/0UWdj09V0?@2MQ4420:62@P80X85100X0XH920:>4A02UQTH0YXM70;:?C`2cT500]95A0;FBDP2f
Te<0]iAD0P2hUED0402MPe00XhUF0:V?G02ZT5d0YXaI0:B:E`2VS5T0ZY1M0:N<E@2VRe@0YHYC0:>8
D@2RQe00X8E>09n4C@2NPd`20:>8D@040::7D02QQTl0X8E>09n4C@80WX=<0`2OQ4l209j3CP<0WH9=
00/0VX5809^2B@2LPdX0W8=:09^2B@2HOdH0UWe409Ak@P2JO4H0VG]509QjA00209Mi@`0]09QjA02J
O4H0Vge70:1mA@2SPT`0ZhYE0;BDH`2lWFl0`JAj0<FYP@38[8D0bK2A0<^bT`3>]Y@0c[JB0<^cS`35
[HL0_ZMn0;VRN@2bUFT0]9M[0;JIK`2jWGD0`:9l0<JXQ03;[HT0cJn=0<ReU@3=^Y`0d/6U0=W9/03N
ckX0h=300=oB`P3OdL@0hm2`0>?>[`3QcJ`0glRV0=_3W`3G_IP0e;RC0=6eSP3;Z780aJ9/0080_iYV
02d0_9AS0;Z@H02eRUd0[h9H0:]lDP2TP4`0X7a809Yf@P2GLcl0U70l08m[=`27Hbl0P5`X07YI;01i
F2d0N5L/07IE;01dDR`0LU0[075?;01`CR/0IU0W06E?:01SCBH0HD/V05i79@1LABD0FT<T05U28`1C
@1l0Dd0P058o7`1@?Al0Cc/P04hj8@1=>B40C3PP04Xj6@1;>aX0Bc`M04/m8018?B40Ac/Q04<i7P10
>Al00P13=b401P12=R00@CDO040d7P0o<ad0?S8L03da6`80?C8F0P0l<1H02P0k;aL0>blI03/^6`0j
;AX0?RlJ03l`6`10<A`0@C8M048c7P13=1l204@e800404@d7@15=Ah0ACDN04De7P80ASHO0P17=b08
04@d7@0804Df7`14=Ah0A3@M04Dc7@18<ah0BcDP04dg8P1@=b<3058g8P80DcPS0`1D>B@00`1G?B80
ES`Q05@j7`0205<i7P0305Dk801F?240EcdR00P0E3`P0P1G?b<01P1G?B80F3dR05Tk8@1J>R40G3XQ
05/i80P0E3XQ00H0F3PO05Ti801J>R40Fc/R05dm901N?RD205lo9P0305e58`1NAR@0GTHT0080GdLU
0`1PB2H00`1/BB<0KDXT06e:900206i;9@0506m<9P1`CBL0LDhX075>:01/BB<00P1]BR@00`1^BbD0
Kd`V06m<9P02071=9`80M5<Z00H0MUD/07MF;@1iF2l0NeXa07aK<P1mG3<207eK;@0407iL;P1oGBl0
P5h`081N<080PEla0`25H3<208IQ=0<0Qf8e00@0Q68d08=Q<`23HC<0PV0b0P21Gc44081N<00>07mM
;`1nG2h0OE/]07eK;@1lFR`0NeT[07iI;01oFRd0P5/^089M<024Gc80QV4d08MR=@28HcH208=M=P80
PU`e0`21Fc@05020FS<0OE/^07iL;`20GS00PV0`08AS<026IC00R6Lb08UX<P2<Ic<0SFPd08iY=@2@
JcL0TVdi09A_>`2EL3`0UW4m09Qc?`2FLCd0Tfhj0P2BKCT00`2EL3`0VGA009ag@`0309MgAP80UWI5
0`2EMD@309Ea@@80U7100`2CKcl8095]?@0808eV?@2>Ic`0SfTl091Z>@2AK3L0TVdf09=_=@2DL3@2
099Y=@0409=Z=P2DJcL0U6/g09E/>080UVdi0P2GKSX0102HKc/0VG0l09Ya?@2JLCd209]b?P0609]g
>@2KMc/0VgLk09]g?@2KMSl0VgI10P2LMd<309mjA@<0X7]60`2QO4L20:=nBP060:AoB`2UP4`0YX5=
0:J1C@2WPTh0Z8=?0P2WP4D20:R1B0050:V2B`2YPDd0ZH5>0:Z2C`2YQU000P2ZQe400`2[R580[8UC
0:f:E0020:j;E@080;2>H02_SEl0[H]M0:b:G02]Red0/8iP0;>AH`2eTfD80;BBI080]95W0P2cT6H0
102bSfD0/HiT0;6>I02`SF<80;:?I@030:j<GP2_SEl0/HmQ0080/Y1R00<0/HmQ0:n=G`2^S5h01@2_
SEd30:j<G0<0]8mR0P2eT6<30;JAI0<0/i5Q0P2dTV830;FCH`0;0;VGJ@2hUVP0]iEW0;RFJ02iUfT0
_9Y/0;nMK`31Wg40`9i^0<:PL033XG400`35Xg<00`34XW80`j5a0<BTN`030<FUO080aZIm0P37Ygh8
0<RUO@040<RVN037YGL0ajEg0<NUM`80aZAf0P35XgD80<JSN`<0ajMn0P38Z7l30<VYP0<0b:Ek1039
YW`20<ZWO@<0bJIl0P3:Ygd30<^XOP80bZMm0`39YW`30<RUN`P0bJIl2037XWD30<>PNP<0a:5k0P35
XW`20<BRM0060<>QL`32X780`Ima0<2NL02oWFl0_Ya^2032WVh80<6OL@030<6LK`30Vfh0_YU/0080
_YU/00<0_iY]0<6LK`32WG00202lX7080<2ML`P0_iab0`2nW6h30;nMK`80`9i`0`2oVf/70;jJJP80
_i][00@0_YYZ0;bHJ02jUVH0^IEU102gTF@40;J@H`80]Y=K00<0]I9L0;FAG@2dT5h00P2cSel0102b
SF00/hmK0;B@G02eTEd20;JBGP030;FAG@2cSe/0/XiJ0080^9EK00@0]iAL0;JCG@2dTE/0/hmK0P2b
SU`0302aSE/0]I1V0;F@I02dSf80/hmM0;>@FP2bSeL0/HiD0;6?DP2eT5/0/hiI0;6<E`<0[XUD00<0
[hYE0;2;EP2^RUH00P2^RUH20:f9E@<0[8QD0P2/R5H0102]REL0[h]I0;6=F`2bSU`20;B@GP060;6=
F@2bSUX0/XiJ0;B@G02eTEd0]Y9N0P2gTel0102eTEd0]91L0;:>FP2_ReL20:j:EP80[h]G0P2[QTl2
0:Z5CP070:^6C`2^RE80/8]D0;6<E@2XQ500ZXIB0:b8E0020:j:EP040:f9E@2/R5@0ZXIB0:^6D@L0
ZXE@0`2UP4/[ooooo`00:_ooool80:MlB@P0Z7e800<0Zh1=0:YoC02YOT/00P2WO4T00`2XODX0ZGi;
0:YoC0080:b3C`<0[8=;0`2]Q4`20:j5C@80[XAB00<0[XEA0:j5C`2^QDd00P2^QT/01`2^QTT0[8=?
0:f4D02^QE40[hIB0;27D`2aR5@00P2bRED80;>5D`80[85D00<0Zh1C0:YoDP2YOU400P2XOE001@2W
O4l0XWe90:=nBP2SOTX0Y7m;0080Xgi:00<0XGa809iiA@2MN4@00P2MMdP00`2LMTL0VgE609YdA@02
09UcA00709Qb@`2DLC/0TVhj08m[=`2<J3H0RFDe08QS=P0208QS=`80Q6<h00@0Pf8g085P=@20Gc@0
OUdb0P1mG34307aI<@<0NeP`0P1jEbl00`1fDbd0Me@^07MD;P0207QE;`80NEH`00<0NULa07]K<P1j
FS400P1iFC00301jFS40O5`c07iN=@1oGcH0P5Xc089M<`25H3H0R6<g08YU>02;IcL0RfLe08YV=080
SfXf00<0T6/g095/>02BKCT00P2CKSX02@2DKc/0V7<o09Ia?@2CKSX0TF`h091[=`2BKCT0U6lk09E`
?00209Q]@080Uf`o1@2FJch01`2GK3l0V6e009U^@@2HKD00Uf`o09EZ?@2CJ3/00P2BK3d2095[?080
T6Xk0P2?JCX808mZ=P80T6Dh00@0Sf@g08iS=P2=HSD0SF8e0P2<HC@808aV>@P0RFDe00<0SFLj08aV
>@2;ICP00P2:I3L01P2;ICP0S6Hi08eW>P2=IcP0S6Hg08]U=P80RV@e00<0RfDf08aV=`2=IcP01@2:
I3D408US=080QfDe00<0RFDe08YT=@2<HcD00P2=HSD00`2>HSD0RV@e08YT=@0>08YT=@P0Qf4d00<0
QF0c08AO<P23GS400P23GS400`25H3<0Qf8e08QS=P0308QS=PD0RF@g00@0R68c08YT=@2<ISL0SFLh
0P2>J3T0202=IcP0S6Hg08eY>@2=JCT0SVXj08m[>`2AKCd0TVhn0P2CKcl2091/?080TFdm0`2BKSh0
102CKcl0TW1009=a@@2DLT8209Ec@`0609=a@@2BL400T6hn09=a@@2ELd<0V7I60P2IMdL06`2FM4@0
Tg51095_?`2?MD@0SWA308ab@@29Kch0QV`k08=Y>021IcH0P6He07aU;`1kI300N68`07=N;`1/FBh0
IE<[061>:01KBbL0B4DV04<o8P0m=ad0>S@N03Xa800i;b<0=bXQ03@W7`0202h/7@0602//7P0X:Qd0
9RPM02@W7P0Q9Ql082DN0`0R9A`3024T6`X082<J00P08bLH028V600Q9AL082<H01hQ600M81T071hI
01/M60T07R4J0P0P8A`07P0Q8Q`08b@L02@V6`0U9aX09RPK02LY6`0[:A`0;2XM02h[700b;1h0=RlO
03/b8@0o=b@0@cPV044e6`14>200AC/R04Dm9P11>bD0>cHR03<`7@0_;1T082HH02@X6P0W:a`0:bhM
02h_7@0a<1`0<RlL034_6P80<b/N00<0<R`N02l/7@0^;1d00P0[;1`02@0Z;A`0;BXI02h[6P0^:a`0
;b/O02hZ7`0/:1l0:BDL02PS7@0302PX7P0302LW7@0V9Q`09RHL00809BDK00H09RLO02DV7P0U9Qh0
92DM02<T700R8a/2024R6P0P020P800O7al07QhL01dN6@0M7QP07QlI020Q6@0Q8QX0<bdG03P`6@13
=al0CClT05E49P1LB2L0GTLU05m78`1VB2H0LE<_081R?02;KT@0TGE609YnC02YSUT0]iaU0;2=E`2J
OE40Keln044l:@0Z:B@0:RXX02/Y:P0Y8b<802<U8P808b@N00<092DO02HW8@0V9b400P0V9b401`0U
9R00:2PP02TY7`0/;280;blS038c9@0b<b<00P0b<b400`0b;R80<blS03Da9@0203Hb9P0A03Da9@0c
;b<0<RhR02l[7`0a;B40<blS03@`900e<BD0=30T03<_8`0b;R80=c4S03P`8`0i<B@0>S0T03da9@0n
<2D00P11<2H01`0k=R<0?3DS03/d8P0m=2<0@3@T04<f9P18>2T00P19>BX01P17=bL0CSh^05M6=01J
B3@0EdD_05I1;080ET0Y01H0BcXZ04Xi9`18>BH0ASXT04Dk8P15?R80ASlR04M2901@>bP0CcXW04lj
9@1>>R80Cc/R054m8P1D@2D0ED8T05=1:@1E@BP0ET8Y05Q3:01K@bL0GD@V0P1OA2H03P1TAbT0GTLX
05A79@1;Ab@0B4DT04U29@1??bH0DclW05@o:P1E@2/0ED4Y05I2:@1G@bP0Ed@V0P1HABD205U69@03
05Q59@1HABL0Ed<X0080Ed<Z00L0Ed<[05Do9`1E?bL0ED4X05=2:01D@bT0E4@Z0080DdDZ0P1D@B<0
3`1C?b@0DShU054m9@1A?2L0D3/V050k:01:@2L0BClV04Pn9@17?B@0AC/R04@j8@13>B00@SPO03dd
8`0203/d8P0303Xe8P0g=240=C@P0080<cDP200f<2@01@0f;bD0=c0V03La9@0g<B<0=c4Q0080>3<P
00l0>3<O048g8@12=b40@SHP04<g8@16=b80BSTU04hl:01@?RX0DD8]04e0;@19?2T0A3TW03lf9@0l
=BD00P0j=2H00`0j=2P0>C<W03Tc9`0203Pb9P80=c4U00@0=S0T03Pb900h<R@0>38T0`0g<B<203H`
8P80>C0O0P0j<B0203/b8@80?3<R00D0?C@S03lf9@13>2H0AcXW04/l9`0204`l9@0604dk8`1C@280
Dd0R05A18`1GA2H0FDHX0`1KB2X01`1JAbT0EdT^05Q8;P1HB2h0FTT_05a8;`1MAbl00P1PB30205]6
:`0405Y5:P1IA2T0FD@Y05Y5:P80FdH[0140ED@Z05E4:01HABL0G4PW065;9P1VD2T0Je@Z06eF;01h
F2D0OV0/085S<@1mHC40Of@e08=[?@23KCh0OFHj07ERA00207ISA@0h075N@01/FC/0JULi06aI>`1`
GCl0MUDd07mI<P2;HC40VFXd0:9e>P2SOdD0XXM@0:2;EP2CRe`0THUJ08n6F`2;PUT0R7mH08EkF023
N5P0PWMI07m_CP1lJDP0NFE007eV?024JCX0RV`j08Y[=@28Ic40XG4c0:Eh=@2]PCH0]8/i0;J@?`2f
T4D0]8m;0;:<CP2ZRe80YhQ?0:>3BP2PODL0WGY409iiA@2QNDH0XWY70:9oA`2TPDT0YH190:AmAP2N
MCl0Vg8l09aa?02NLch0YWTf0:f0?@2eR4D20;V<B0040;R<A@2iSDH0^hm80;69B`80/HY900<0/X]8
0;><A`2dSTL00P2eSdH40:n7B@<0[XI801h0[HE70:V9C02WQdX0YX940:An?`2TNc/0YWXi0:Ul>@2]
OC/0]88i0;F3>P2fQSh0]hQ20;J9A@2fRDH0]8U50;:9A`2XRDT0YhQ80:J4A@2ROT00XW`n0:Mo@P2`
R4/0^HmC0;fJEP2iUU80/i1<0:f:AP2ZQd<20:V6@P070:Z7@`2YQTH0Z8E50:R5A@2ZQdL0/8e=0;RE
E@020;fJFP0:0;ZGE`2mW5D0_9]D0;^JD`2jVE80^iYC0;fLE@2oWUL0`9mH0<RYJ0<0bJYY00P0ajQW
0<BUI030XF00_YmN0;VCDP2cSD`0[HM60:Z4@`80ZhE400L0ZH=20:Eo?P2RP440XX110:>1@P2TPT<0
YH=40080YXA500/0YhE60::7A02SR4D0XhQ509n4@@2JOc`0VGhk09b1?P2PQD80XX=30:62@P020:21
@@040:62@P2SQ4@0YHI60:J7A`80/Hi>00h0/i1@0;FBDP2fTe<0^9EE0;VFEP2jUeL0WXAA0:>9EP2Y
Se`0ZY1M0:N=FP2VS5T0Z8iK0:^AGP80YhaE00@0YX]D0:F:D`2SR540XXM@0P2QQTl20:>8D@030::7
D02QQTl0X8E>0080WhA=00@0WX=<09n4C`2OQ4l0WhA?0P2NPdh309f2C@80Vh990P2LPdX01`2KPTT0
VH1709ImA02EO4<0Vge709YlAP2INdD00P2HNT@0;@2JO4H0Vge709anB02ROdL0YHA>0:b;EP2eUF@0
_Ii`0<:UN`36ZX80b:b50<V`T@3;/Y<0c[JD0<jfTP3;/hl0aJf70;jWOP2jXgX0/iIZ0;BGJ`2fVFl0
^Yee0;nQN`35Yh<0bZb80<f_S@38/i@0c;VI0=>oY03HaZh0gLbh0=o@_@3NdL40gm;20>CA/`3Sd;00
h/f^0>7:ZP3NaZ@0fKnL0=FkUP3D^9<0d[5l0<b[N0020<NSL@0^0<>MK032VF/0_Y=X0;N<H@2bQE/0
ZHEA0:B0C02NNTH0VgM309Qd@02BKSX0RFDa08=O:`1nGRl0OE`_07aK;P1jFBh0N5L^07ID;P1eDbh0
M58]06YC:P1YDRT0J50Z06I>:P1SBbL0HDTW0617:01OARL0F4DT05M48`1F@b<0ED8T05<o901B?RD0
DCdT050l901=>QT0CS/K04dm701<?Ah0BS`O04Dj7P13=ad0@CLL04Di8@80A3PP00H0@cLO044e7@10
=1`0@3@L03lc6`11=QP2040e6@03040d6P0o<a/0?c<M0080?S4N0P12<ah01013=1l0A3DP04Df8@16
=b8204Lh8`0404De7P16=Ql0ASHO04Hf7`80AcLP0P18>24804Hf7`0904Df7`15=Ah0A3@M04Dc7@18
<ah0BcDP04lf8P1A>2@0DSPQ00<0DcTR0P1D>R<205Dk900805]08`1J?b80FChQ05Pm801I?R40FSlR
05a1901N@bH805Ho8080F44R00H0F3lQ05Tn8@1J?200Fc`P05dk801L>Ql805Hj8P80Fc`P0P1L?B40
101M?R80GSlS05m0901O@2@205m5900406169@1QAbH0HTPW06=9:080I4XY0P1]BR@0101^BbD0Kd`V
06m<9P1`CBL2075>:005079?:@1_C2H0Kd`V06m<9P1`CBL00P1aCRP2079?:@0607AC:P1eE2/0MUD/
07MF;@1hEbh0NUT`0P1kFS4207eK;@0307iL;P1oGBl0P5h`0080PEla00<0PV0b08EP<`25H3<00P26
HC@308MR=@0408QS=P24HS@0Q68d08=Q<`80PV0b1@21Gc400`20GS00Oed_07iL;P0207eK;@0607aJ
;01oFRd0P5/^085L;`22GC00Peha0P25H3<01026HC@0PUdc089M<`22GC<2085L<P<0P5/a00P0Oed`
081N<@21Gc40PV0`08AS<026IC00QfHa08QW<@80SFPd00@0SfXf091[=`2BKCT0U6lk0P2FLCd02@2I
M400Ug8n09A_>`2CKSX0U6lk09Ia?@2JMD40WGQ409QhA`0309MgAP80UWI50P2EMD@209Ib@P80UG51
0`2DL4000`2CKcl0TVhn099^?P06099^?P80SFHk00H0SVPk08mY>02@JcL0TVdf099^=02CKcD209=Z
=P80U6/g00@0UF`h09I]>@2FKCT0UVdi0P2GKSX00`2HKc/0VG0l09Ya?@0209]b?P0709ac?`2KMcT0
VgLk09]g>`2LN3h0W7M009ag@P0209ag@`<0X7]60`2QO4L30:9mB0060:=nBP2TOd/0Y7m;0:F0C02V
PDd0Yh9>0P2XPdl20:R1AP030:V2B@2YPT/0ZX9>0080ZX9?00H0Zh=B0:Z6DP2ZQU80ZhMC0:b8E02]
RED20:j:EP030:n;E`2_SEl0[heO0080[heO00<0/8iP0;6?H@2cTF<02@2dTV@00`2eTVP0]95W0;BA
I`020;>@IP80/XmU00<0/HiT0;>@IP2cT6H01P2cT6H00`2_SEl0/8iP0;:@HP020;>AH`030;:@HP2`
SV00[heO00D0/8iN0`2_SEd20;B?HP80]I1S0P2fTF@20;NBI@80]99R0P2eTf<20;JDI080]iEU0P2k
VF`02@2jV6/0^iU/0;bJK@2oWG00`Z1c0<>QM032X700a:9b0<FSL`030<NUM@040<JTM035Xg<0aJEl
0<FUO080aZIm0`37Ygh00`38Z7l0b:Em0<RUO@060<RUO@<0b:Ii0P37YGP30<JTM`P0ajAl0P37Ygh2
0<RXO`<0bJV000<0bZZ10<VVO039YW`02P39YW`20<ZWO@<0bjQn0P3:Ygd30<VVO0<0b:Ek2039YW`0
1@39Y7L0b:=f0<RSMP38XgH0aj9e00<0aZ5d0`33X7X20<BQN`<0aJ9l00H0aJ=e0<BRM033XG<0`Z1b
0<6OL@30WW020;nMK`P0`Yi^2031Wg400`31W6l0`9]^0;nJK@020;jIK0030;nJK@31W6l0`Ye`00P0
_Ym`2030WG<80;nLLP<0_Ya^0P2oWFl30<2NL0@0_i][1P2nVVX20;nKJ`040;jJJP2lV6P0^YIV0;VE
I@80^99S0P2gTF820;J@H@80]HmP0P2fTe/02@2eTU`0]I5M0;B@GP2dT600/hmO0;>>H@2cSe/0]91L
0;FAG@020;JBGP030;FAG@2cSe/0/XiJ0080]Y=I00@0]I9J0;BAF`2dTE/0/hmK0`2bSU`20;B?H`04
0;B?HP2cSed0/hmK0;:?E`80/XmE00P0/hiI0;:=F02`ReH0[hYE0:j9E02_RUD0/8]F0;6<E`<0[XYF
0P2]RED30:b8E0090:^7E@2/R5H0[HUG0:j:F02`S5X0/HeK0;:>G02cSed0/HeI0080/XiJ00T0/hmK
0;FAG@2fTUh0]Y9N0;NCG`2eTEd0]91L0;:>FP2_ReL00P2^RUH0102_ReL0/8aH0:f8D@2]R5430:^6
C`0;0:f8D@2_RU<0/8]D0:V5D@2ZQU80[8QD0:f9E@2^RUH0[HUE0:b8E02[Qe<00`2[QU440:Z5D004
0:V4C`2UP4/0YH1;0:F0Bb_ooooo000Zooooo`P0Yga9202XODP00`2[P4d0ZWm<0:QmBP020:MlB@03
0:QmBP2ZOd`0Zh1=00P0Zh9>102]Q4h30:b3C@060:^2C02/PU00[89@0:b3C`2/Pdd0[8=;0P2/Q4T0
0`2/Q4L0[HA@0:f4D0020:j5D@040:n6DP2`Qe<0/HQD0;68E0P0/HIC00H0[X=F0:f2E@2]PUD0[85D
0:^0D`2ZOe820:UnD@040:9mB@2SOTX0Xgi:0:AoB`80Xgi:00@0XGa809iiA@2MN4@0WGM80P2LMTL0
0`2KMDH0VWA509UcA00209Qb@`0609Aa>`2BKSX0Sf/g08aX=P29ICD0R6<f0P28HcL208ER>00408AQ
=`22GcD0PEhd07mL<P80OU/a0`1lFC4307]H<080NUL_00@0N5D_07UF<01iES00NEH`0`1jEc403`1k
F380NET`07QH;`1hF2l0MeL^07QH;`1jFS40OEdd07iN=@21Fc@0Pehd08EP=P28HcL0RF@g08]W=`02
08]W=@0608mZ=P2@JcL0T6/g095/>02BKCT0Tfhj0P2DKc/0102FLCd0UG0l09A_>`2DKc/309=^>P04
09A_>`2HKD00V6e009Q]@080Uf`o102FJch01`2GK3l0V6e009U^@@2HKD00Uf`o09EZ?@2CJ3/00`2@
JS/208mY>P<0SVPi202?JSH01P2AIST0T6Dh091U>02?I3L0SV<f08eR=@80S64d202<IST808UU=@80
RfDh1029HcH208]U>080RfDf1029Hc@208]U=PT0RV@e0P27ICD00`29ICD0RV@e08aS=@0208eR=@03
08iR=@2:I3D0RV@e00h0RV@e2027HC@00`25H3<0Q5lb08=N<@0208=N<@0308EP<`27HSD0R6<f00<0
R6<f0P29I3L308YU>00308QR<`29Hc@0RfDf0080SFLh00<0S6Hg08]U=P2:I3D00P2<J3P0102=JCT0
Sf/k095]?@2CKcl209A`@0<0TFdm0P2BKSh309=_?`80U7920P2ELd<0:P2DLT80TW10095_?`2@KSh0
U79209Ec@`2GMDD0VGM709QfAP2FM4@0Tg51095_?`2>M4<0SG=208]a@029Kch0QV`k08=Y>021IcH0
P6He07aU;`1kI300N68`07AO<01/FBh0IE<[05m=9`1JBRH0B4<U048m800k=A/0>38L03P_7P0g;B40
=2XP030V7@0^;1d0;B/L02X[7@0X:Qd09bTN02@W7P808BHO0`0R9A`3024T6`8082<J200Q91/01P0S
9aP08RHH024U5`0P8aP07b8I01dP6@8071hI2@0N8AX07@0O81/0824L024R700R8a/092HK02DW6P0V
:1/09bTK02`Z7@0/:Q/0;R/L038/700g<1h0?3@Q040h8`14>BD0@CDK04@h8015>b80A3`U044k9@0j
=B40<RlL02h[600S9aT09BTK02PZ700/;Ad0<2lM0080<RlL00H0<bhJ03<[7P0c:ah0<R`N02l/7@0^
;1d202//700:02X]700]:QT0;BXI02h[700^:Qh0;BTN02/W7P0Y9A`0:2<M02PX7P<09bLM0`0V9Q`0
1@0U9A/09BHN02DV7P0T9Ad08b@L00808R<K0P0Q8QX0800O7al07QhL01dM6`0L7AP07AhH01hO5`0P
8QL08B<H03P`6@11=ah0BclU05M8:`1OC2`0Hd`Z06=;9`1TBRD0IdTU07AF<P23ISh0SG1409AhB@2O
Pe40[95J0;FJH`2[QeD0T7E:06=D=`0j=2@09RLQ02HX9@0Z:BL0:BDT200S9B803P0S91h092DO02@U
7`0T9Al08b@N02@U7`0V9b409bPR02TY8@0Z:R00;BdS030`900b<bD0<S<S0P0b<b4203<_8`@0=C4U
0P0c;b<00`0`;200<BdQ03<_8`0303@`9080<blS00H0=c4S03P`8`0i<B@0>S0T03da9@0n<2D2044`
9P0703`g900l=B<0>c@R03/b8@0n<R80@C@T04@d9@0204Hf9`0604Ti:@1>?b`0ETDc05U7<`1HAS00
Ed<[0P1F@2P0801=>R/0BcXX04Xi9`18>B@0Ac/S04Lm8P17@2<0B44T04lj9`1>>BH0CCPS04di8@1>
>R40D3`Q058n8`1C@280DClW05A09`1E@BP0F4<X05a4:01OARP0HDHX0697:@1VB2`0GdPY05E8:01;
ARH0Ad@U04Q19@1=?BH0D3/V0P1D?bX01P1E@BT0ET8Y05M3:01HABL0F4DU05U69P80FDHU00<0FDHV
05Q59`1HA2T00P1G@bX04@1G@b/0Ed4Y05Q2:P1G@bX0ED@Z05I5:`1EAB/0E4H[05E7;01A@280DD0T
050o8`1??R@0CS`T04dk9@1=>bL0C3XV00<0AS`S0P15>b8204@j8@0704<i8012=RH0@3LV03lf9@0m
=R@0>SDR03Ld8@0203Dd800503Tc9`0h<RH0>38V03La9@0f<2@00P0e;b<01P0d;R80=RlU03H_9@0f
<2@0=c4S03Pb8P80>3<P0140>C@P03lg8P0o=b80@CHR04<f8`16=b@0BCPV04/j:01=>RT0C3l/04Xm
:P15>RP0?cHU03`e9@0i<bD0=c@U03Lc9`0403Pb9P80=c4U0P0f<2@203H`8P<0=c4S0`0h<R@203T`
7`80>S4P0P0k<R4203`c8P0503/b8@0m=2<0@SLU04Hi9P1;?2L00P1=?BH01P1>?2@0D3lQ050o8@1B
@B<0E4<U05M6:0<0F4LY00T0EdHX05=5:P1CABX0E4@Z05E4:P1D@bT0ET8Y05M1:@1F@2P00P1G@bX0
101HA2/0FDD/05U5;01HA2/205M3:P0V05E4:P1HA2T0FDHX05e9:01SCBP0JE4[06iE;01aF2l0N5XX
07mQ;`1oHc<0NUl`07UQ<`1mISX0O6Ll07EP=@1]FD40Ke]3071L@@1^Fcd0JULf06UG<@1/FS80L5ld
07IH=01oG3@0S6@c09U^=`2QNCh0Xh=:0:29E@2OSE/0ShIK08b3F026OE@0P7M@07]aC@1iKd`207Q]
C@0Y07QUA01eHcl0Mf4j07aT>023JCP0Rfdg08m_=P2>KS<0XWHi0:Un>P2aRSd0^IA30;fJB@2kVE40
]i=E0;>@F02[S5D0YhQA0:>2C02PODL0W7U309ag@P2OMd<0X7Q409ek?P2QOD40Xgm30:=l@@2PN3d0
X7Hl0:Ag?P2WNT40ZWdj0;:5@P2kST/0_i9?0;jACP2kST/0^Xe:0;^>B`2dS4l00P2dS4h00`2eSTd0
]Hi;0;F>B@020;F?B080/8Q:0`2aRD/30;::C00@0:b:C@2ZQTX0YX940:N1@P2XPD00Zh900:j3?`2_
Q400]8e20;F=A@2fT4L0]i5:0;JAB`2dTDd0/I1=0;2?C080YhQ800`0YhE60:F1@`2UOd40ZX950;B<
C`2mTeL0aZ=O0<:OF`2mVUH0]iA@0;:?B`2_S4P20:f:AP070:b9B@2[R4P0ZhQ80:b9B@2bSdl0^YMG
0<2MG@020<>PH0030<BSGP32XE`0`J1K00<0_iiI00@0`9mJ0<6PF`37Z6L0aZMV0P34YF@02033Y6<0
a:ET0<FVI@36YfH0_iaL0;REE@2`SDd0ZXM70`2YQTH01P2XQDD0Xh520:>1@P2TPT<0YH=40:J4A@80
YhE600/0Z8I70:>8A@2URTL0YHY70::7A02MPSl0Vh0m09f2?`2QQT<0XX=30:62@P020:21@@0@0:62
@P2SQ4@0YHI60:N8B02^S4`0[he=0;6?C`2cTE40]YAD0;VGE`2kVET0_9YJ0:26D`2TRUL0Z8iK0:V?
G080Z8iK00<0ZY1M0:bBG`2XSEH00P2WS5D20:J;E0<0YHYC0P2SR5420::7D0030:66C`2PQDh0WhA=
00@0WhA=0P2NPd`309f2B`0:09^2B@2LPdX0W8=:09b3BP2KPTT0VX5809QoAP2GOTD0W7i809]mA`<0
VWa602d0W7i809j0BP2OPD/0YH9:0:R7D@2_SUT0]iMV0;nPLP34Ygd0aj^30<V]QP3:/I80c;>D0<jf
U03>]Y80bk>?0<J^R02oZ7l0_:El0;BGJ`2eV6`0]YU_0;VLM02nX7X0a:J20<V[Q`3<[X`0ak>B0<^f
U`3A_Z00e/F[0=c:]03NcK/0glno0=o?`03Sd[H0iM6f0>CA/`3RcJh0hLZZ0=g5X`3J`9l0f;jK0=bl
S@3F]XL00P3A[h406`3>ZG`0c:Mj0<RRM@33VVh0_YEY0;6=F@2/R5@0YX9>0:9nBP2ONdL0V7A008m[
=`28I300QV@d08ES<`23HC<0P5ha07iK<@1lFC40NULa07UF<01`EBX0Ke<[06iB:P1]DBX0JdlZ06U<
:P0206Q;:`08061:9@1OB2H0GTLU05e69P1KA2D0FT8V05U19`1H@2H2054m7006050m7@1=?1h0BcXN
04Ph7P14=Q/0@cDK0P1:>R4204Ti800504Ph7`17=ah0ASHM04Hf7@17>1T00P17>1/00`16=Q`0ASHM
04De7P0204Dd8080ASHO00@0AcLP04Ph8@19>B80BCTR0P1:>R<204Pf7P80BCLO0`1:>2000`1;>B40
BCLO04Tg7`0604Tg7`80ASHM00H0AS@L04Pd701:=1d0CSDO050g8@1B=b8305@j8`80EC/T0`1F?2D0
201O@BD0GT0T05do8`1N@2@0Gd4U06539`1TARX0IDL[201K@R@01P1J@b@0FD8S05Y18`1K@2<0G3hR
05dn8P80GS`Q201J?28305ho8`D0Gd0T00P0HD@R06958`1SAR@0IDPV06M::01YC2X0JTd[06]>;080
KT/U00@0Kd`V071=9`1`CBL0LDhX0P1bCbT00`1cD2X0LTlY07=@:P0207=@:P<0M54[00@0ME8/07IC
:`1gE2`0Me@/0P1hEBd307UF;P80OU`^00<0Oed_081N<021Gc400P22H3801023HC<0QV4d08IQ=026
HC@208MR=@<0R6<f0`24HS@308=Q<`@0PV0b00@0PEla081N<020GS00Oed_0P1nG2h2085L;`80PUd`
0P23GS4208AO<P80PUdc0P21G383081K<@0J07mJ<022H3<0PV0c08=Q<`24HS80QF@a08IU<027IS40
QfH`08eX=02>JCD0SfXf095/>02CKSX0UG0l09Ia?@2GLSh0VGA009Mb?P2FLCd0UG0l09Ia?@2HLcl0
W7M309iiA@2JN4P309UgA`80V7I60P2GMDD309Mc@`80UW920`2ELD4809A`@080SFLj00H0SVPi08mY
>02@JcL0TF`g095/=@2BKCH409E/>080UVdi0P2GKSX209Q_>`0309U`?02JLCd0Vg8n0080W7<o00L0
WGA009]g>@2LN3`0W7Pl09ah?P2MN440WGQ30080WWU50P2QO4L40:9mB0<0Xgi900H0Y7m;0:F0C02U
P4`0YX5=0:N2CP2XPdl20:V4D080Z8A:00@0Z8=<0:V4C`2YQ4l0ZXEA0P2ZQ5<01P2[Qe<0[8QD0:b8
E02]RED0[XYF0:n;E`80/8aH00@0[XaN0:n=G`2aSf40/Y1R102cTF<80;JDIP<0]I9X0P2dTFL30;>@
IPP0]I9X00<0/HmQ0;:@HP2cTF<00P2dTV@00`2cTF<0/Y1R0;6?H@080;6?G`<0]Y5T0`2gTVD20;RC
IP040;NEI`2hUVP0^9IX0;RFJ080^IMY0P2jV6X30;nLLP0=0<2ML`31WW@0`j1f0<FRN036XgT0aZAf
0<NUM`39YgT0bZQj0<^YN`3:Z7X0bJMi0<RVN0030<NWOP<0b:Qo0P39ZH080<ZWO`80bZMm0P39YW`2
0<RUN`80ajAj2038YGd30<RXO`80bJV00`3:ZX420<bYO`030<^XOP3:Ygd0bJIl0080bJIl0P38YG/3
0<VVO080bZMm0`3;Z7h20<ZWO@<0bJIl2`38YG/0203;YWT0bZEh0<VTM`38XgH0aj9e0<JQM035X7<0
a9mb0P33X7P20<BQN@<0aJ9j00L0aZ=k0<FSM@34XW@0a:9d0<>QL`32X780`Ima0080`9i`2033Wfl8
0<:PLP030<:ML031W6l0_iY]0080_YU/00<0_iY]0<6LK`32WG00202nWg080<6NM0P0_iab0P2nW6h2
0;nMK`<0`9i`00@0`Ima0<2LK030W6`0`9a/0P2oVf/20;jJJP030;fIJ@2nVVX0_YYZ0080_i][00`0
_YYZ0;bHJ02jUVH0^IEU0;ZDI@2iTf@0^99S0;NAHP2fT640]HmP0;B>G`2cSEh20;JCF`030;FBG02e
TEd0]I5O0080]91P00@0]8mR0;>?F`2dT5`0]I5M0P2gTel00`2fTUh0]91L0;>?F`020;>@EP040;>@
F02cT5X0/i1J0;>?F`<0/hmM0P2bSF00102bSUh0/hmM0;>?F`2dTE/20;BAF@80/HaG00H0/8]F0:n:
E@2`ReH0/HaG0;:=F02cSUT30:n;E`80[XYF0`2]RED01P2ZQU80ZhMC0:b8E02]RED0[h]G0;2<F0<0
/HeI0P2bSUX00`2cSe/0]91L0;FAG@020;JBGP040;FAG@2dT5`0/XiJ0;2<F080[h]G00D0/8aH0;6=
F@2aS5L0[hYE0:f8D`030:b7DP070:f8D`2^RE@0ZXIB0:^7D`2/R5@0[HUE0:j:EP020:f9E@030:b8
E02/Qe80[8MB0080ZhIA0P2ZQE020:V4C`<0YX5<:oooool002[ooooo202WO4T80:QmB0030:YoC02Y
OT/0Z7e:0080Yga900<0ZGi;0:YoC02/PDh0202[PTh20:j5D@040:f4D02/Pdl0[8=?0:^2CP80ZX5=
0P2[PDl00`2[PTh0Zh9<0:^2BP020:^3B0030:^3AP2]Q500[HA@0080[XEA0P2_QU8:0;27D`060:n5
E@2^Q5@0[XAD0:f3D`2/PU80Zh5A0P2ZP500102RODT0Xgi:0:=nBP2TOd/20:=nBP030:5lB02NNDD0
WGQ40080W7I700@0VgE609YdA@2JM4D0VG=40P2HLT<01P2DLC/0TVhj08m[=`2<J3H0RFDe08QS=P80
R6<g0P27HSP01026HCL0Q5le08=N=021G382081K<@<0O5Ta0`1kF30207YG;`@0NULa101kF380401h
F2l0MeL^07MG;P1fERd0MeL^07UI<01lG3<0OEdd089L=@23GS@0QF0f08MR=P29I3L0RVHf08]W=@2<
J3H2091[=`04095/>02BKCT0TVdi09=^>P@0U6lk00H0UG0l09Ia?@2FLCd0UG0l09A_>`2CKSX209U^
@@80V6e00P2GK3l309I[?P0709M/?`2HKD00VFi109Q]@02GK3l0UFXm09=X>`0808iX>@P0SfTh0P2A
IST00`2@ICP0Sf@g08iS=P0208eR=@0308aQ=02<IST0S6Hi00H0S6Hi202:ISH808US=PP0RF<d102:
I3D508]U=P80R6Hf00<0RVHf08]U=P2=I3H00P2>HcH00`2?HcH0RV@e08YT=@0>08YT=@P0Qf4d00<0
QF0c08AO<P23GS400P23GS401025H3<0Qf8e08QS=P27HSD208QS=P0808UT=`2:ICP0RfHi08]V>@2<
IcX0RF<d08YT=@2;ICH208eW>00;08aV=`2;ICH0RV@e08]W=`2<J3P0SFTi08m[>`2AKCd0Tflo09A`
@02ELD400P2AKCd3099^?P<0Tflo0`2ELd<0202DLT80Tg51099`@02AKcl0T6hn09Ab@P2FM4@0UgE5
0P2HMTH06`2FM4@0U792099`@02>M4<0SG=208]a@028KSd0QF/j08=Y>021IcH0OfDd07aU;`1kI300
NF<a07AO<01]FRl0IE<[05i<9P1HB2@0BD0S04<i7P0k=1X0=blJ03H_7@0e;B00<2XN02`U6`0202d[
700602X[7@0X:Qd09bTN02DX7`0R9b008BHO0`0R9A`3024T6`8082<J200Q91/0200S9aP08bLI028V
600P8aP07b8I01hQ6P0M7aX071hI2@0N8AX201lP6`06020Q6`0R8a/08bDJ02DW6P0V:1/09RPJ0P0]
:a`05P0_;1/0<bhK03Pa7P0m=B00@CTR04Dj9012=Q`0A3PP04Dk8P14?2D0@3XT03Xe8@0a;Q/0;BXG
02DW6P0W:A`0:R/M02l]7P0a;Qd0=2lL03<^6`0d;AX203<[7P03038/7P0_;1d0;R`M0080:b`L00T0
:RdL02dZ6@0]:QT0;BXK02`X700[9a`0:RHM02TU700Y91h0200V9Q`202DV7P0402@U7@0S91`08R<K
024R6P80824I02007AdK01dN6@0L7AP071dG01dN5P0O8AH08R@G02<U600k<AP0ACTO0594:@1LBbd0
HTh]06A<:01UBbH0Id/T06Y<9P1hFS@0QfY008mbAP2HO4`0Y8UD0:nEG02bV5l0X7iA089X@`1GBBl0
<RlP02<U800R9b<09bLU02LV8PP08bDR00@08b@N02DV800V9b4092DO0P0R8ad0200V9b40:R/U02XZ
8P0[:b40;RhT030`900b<bD0<c@T0P0b<b4803@`9080<RhR1P0c;b<01P0g<B<0>30S03Ta900j<2@0
?C4U03h`9@80@C0V00L0?3LT03`e8`0k=280>c8Q03da8@0o<R80@S8S0080@c<T02P0ASLT04Tj9@1?
?RX0Dd4[05=1:@1C?bH0DSdR054l8@1?>B/0C3TX04/h9`19>2@0BCXS04Pl8P19@2<0Bd8U04hi9P1=
>2D0C3LR04`h801=>B00Cc/P054m8P1B?b40DClW05A09`1E@BP0F4<X05e5:@1PAbT0HTLY06=8:P1V
B2h0H4P/05E7:P1;ARP0Ad<V04M09P1<?2D0CcXW0P1C?RT01P1D@2P0ET8Y05M3:01HABL0FDHV05Y7
9`80FTLV00H0FDHV05U6:01HA2T0F4@[05M3:P1G@b/205Y4;00405U5;01GAR`0EdH/05I6;080EDL/
00P0D44T04lo9@1>?R@0CCdT04`l9@1;>RH0BSTW04Th9P@0@cPR1014>B<204Di:@06044h9`0o=RD0
?CHT03Xe8P0g=240=S<P0P0j=2P0100i<bL0>38V03H`900e;b<203@^8P0803D^900f;bD0=S0T03La
8`0h<R80>3<P03Td8@0i=20203df8`0;03hf8`11=R@0@cHU04Lg9`18>2P0BCPX04Ll:P15>RP0@3LV
03`e9@0h<R@00P0e<BD00`0d<RH0=c4U03La9@0203La9@@0=S0T0P0e;b400`0f<280=c4S03Pb9002
03Tc9@0303Xd9P0i<1l0>C0O0080>S4P0P0k<R4203`c8P0503Xa800l<b80@CHT04Hi9P1:>bH00P1=
?BH0201>?2@0CSlP04ho801@@B80DT<T05E69`1FAbP0EdPY0P1FAbP20556:P090594:@1B@RP0DT4W
05919`1C?bH0E3hV05509P1C@RP0ED@Z0080EdH/02P0ED@Z05=2:01A@2H0Ed<Z05U4:@1KART0H4TY
06E=:@1[DB`0LUH^07EI<@1gFb`0OF4b07eR=@1fGS80M5dc07MQ>01eGcH0K5Ta06I??@1ZE3l0KEPm
06aG>01ZEbl0JUL/06iL:P1bHBd0NElj089R>@2>JSP0VG8k09mk@@2OP4X0VhED09J8F`2>PU`0RGaI
085dD@1jKDX0M6M40P1bID<0:@1cIT@0MF4l07AQ>@1hHCL0O6@d08AY=02<KCH0TVle09Ab<`2UOCl0
[8E00;JBAP2nWDh0`J5D0;jMFP2gUeh0/Y1P0:Z:E`2VQe40XX5<09mlAP2KN480VgHo09ig@02ON3l0
VgPh0:5k?02UOd00YWi00:Ak?@2VNSd0Zge10:n1A@2_Q3l0]ha70<2ED@33V5@0`9AC0;^?D02iSDh0
^8a=0080]hmB00@0]hmA0;J>D02fSdh0]Hi;0P2eSTT20;::C0040;>;C@2dS4h0]He?0;F=C`80]Xi@
0240[hQ=0:b5BP2YPdD0Zh=50:j7AP2aRTL0/h]60;::A@2cTDT0/Y990;BCC02bU4h0/IA@0:jCD02Z
TDl0ZI1>0:J7A`2WR4P0Z8I70:N3A@2XPT@0[XI90;N?DP30UUX0b:EQ0<JSG`32We/0_Y]G0;ZGD`2f
Tdl0]95=0;>@C02bSdl00P2aSTh02P2bSdl0]I9B0;^HF030WEd0`j1P0<FRHP35Y640a:=P0<6PG@2o
WU/40;fLF@050;nPG`30XF00`J9Q0<>TH`35YVD00`36YfH01030WUh0^IMG0;2>CP2XQTH20:B2@P06
0:J4A02WQDD0Y8930:B2@`2UPd@0YXA50P2WQDH20:R6A`080:F8AP2WRTP0ZHa:0:J9A`2QQ480WX4o
0:23@@2SQT@20::3@`80XH9201@0XX=30:B5A@2VQdL0YhQ80:Z;BP2[S4/0[Xm>0;6BD@2eUUD0^9UH
0;^LF`2lWE`0XhUF0:F;F02WSEX0ZHmL0:Z@G@2[TEh0[99O0:fCH0P0Z8eF0P2TRE80102SR540XXM@
0:66C`2PQDh209n4C@<0WhE<0P2NQ4/309f3BP@0W8=:0P2KPTT06P2JPDP0VH1709j0BP2NP4X0WGm9
09anB02MOdT0Wh5;0:63C@2RQ4h0ZHI>0:^:E02cTUd0^YYY0<6RM035Z7h0bJf50<^_R03:/I80c;>D
0<feT`3=]I40bk>?0<J^R031ZX40_JIm0P2fVFd0602fVFl0^9]c0;bNN032Y800b:Z60<^]R`38/Hl0
bkBD0<njV`3E`JH0fLN_0=g;]`3NcK/0g/jn0>?C^P3Td[X0i=>i0>C@]@3Sc[40hLZ[0=o6Y`3Ma:D0
hLBJ0=boU@80ekN>02D0eKB90=>`QP3B[H40bjIj0<NQM02lV6@0]i=O0;6=F@2/R5@0ZHEA0:9nBP2I
MD40TVhj08iZ=P2=JCL0RVHd08QT=025H3<0PUda081K<@1nFBl0LeLX079E:@1aE2P0L5<Y06mB:P1^
D2X0KDl[06a>:P1UBbH0I4XU06=99P1RB2D0H4HU05m49P1N@bH0GD8U0080F40N00L0ESlO058m7P1>
>ad0BSTM04Pg6`16=Q`0CchR0080CSdQ0P1=?20204`k7`0304/j7P19>1X0BCPJ0080BCPL00D0B3LM
04Pf7P17=Al0AcDO04Le7@0204Pf7P80BCLO0P1:>2000`1;>B40C3PO04di800204di8080CSXQ0P1?
>b8804di800804Th7P18=ad0BCDL04Xd701==Ad0D3HO058h8@1E>B<305Hl8`<0EcdT0P1H?RD0201N
@B<0GD0R05e08P1N@B<0H4<U06959`1UB2X0IdX/201OA2H205a59@0605a3901M@R@0GT4S05m08`1Q
?b<0H3hR201M?b<206939P<0HD8U0`1P@B@02@1RAR40HdLR06E9901WBbH0JDdX06a@:`1]DB`0KU8]
06m<9P02071=9`80LDhX00D0LTlY07=@:P1dDB/0M54[07IC;@0707MD;PP0NU@]0P1oGBl01020GS00
PEla089P<P22H38208=Q<`<0Qf8e0P28HcH308UT=`@0QF<e1P24HS@00`23HC<0PV0b085O<@02081N
<00307mM;`23GS40Peha00H0Peha0`22GC42085L<0<0P5/_00D0Q68e08ES=P25HcD0QV@d08IU<P02
08MV<@0;08MV<02>JCD0SfXf091[=`2BKCT0U6lk09Ia?@2GLSh0V7<o09Ud@02HLcl00P2GLSh0102H
Lcl0VgI209iiA@2PNdL209eiB@<0W7Q80`2KMdL209UeA@<0V7A40`2GLd<809Ea@@80SVPg0P2?JCP0
102@JcL0TF`h095/>02AK3L809M^>P80VG0l00@0VW4m09]b?P2LLcl0W7<o0P2MM4001P2LN3X0W7Pl
09ei?@2NNT00WWU209mjA@80X7]70`2SOTT30:AoBP<0YH1;0P2VPDd0102WPTh0Z8=?0:V4D02YQ502
0:Z5D@060:V6C02YQTh0ZXMA0:Z7D@2[Qe<0ZhME0P2[QeL20:f9E`040:j:F02_ReT0/8aJ0;6=F`80
/XiL00P0[H]M0:n=G`2cTF<0]I=U0;JDIP2eTfD0]99T0;:@HPP0^9IX0`2fTfT50;FBJ0P0]Y=Y00<0
]99T0;FCI@2eTfD0102eTfD00`2dTV@0/i5Q0;>AH@020;>AH@@0]99R0P2hTfH20;VDI`@0^YEX00@0
^iU/0;bJK@2lVVd0_9Y]0P2mVfh20;jLK`<0a:5g00<0aJ9h0<JSN@38YG/00P39YW`02@39YgX0bZQk
0<bZO@3=Zgh0cZao0<f[OP3<ZWd0bjUl0<RXO`030<VYP080bZZ10P3;Zh880<bYP@@0bjQn0P3:Ygd2
0<VVO0P0bJIn0`39ZH020<ZZP@<0bj^20P3>Zh400`3=ZX00bjQn0<ZWO@020<VVO0030<RUN`37Y7X0
bJIl0080bJIl0P3:Ygd30<^XOP80bZMm0`39YW`;0<RUN`080<fXN`3<YgX0bjIi0<VTM`37XWD0aJ1c
0<BOLP33WW430<BQM`<0aJ9h0P36XgT20<FSM@80a:9d00@0`j5c0<:PLP32X780`Z1b2033Wfl80<:P
LP030<>NL@32WG00`9]^00<0_iY]0P31W6l80;nOL0P0`Iid2030WG<30;nMK`<0`9i`0P31Wg420<6M
K@80`9a/00@0_i][0;jJJP2nVVX0_IUY0P2nVVX20;nKJ`0<0;jJJP2lV6P0^YIV0;VEI@2kUF@0^YAS
0;VCHP2gTF00]Y1O0;B>G@2cSE`0/XaK0P2fTe/00`2eTU`0]I5M0;FAG`020;FAH@040;F@H`2cSe/0
]91L0;JBGP80]i=O00<0]Y9N0;FAG@2dT5`00P2aSU@0102bSeL0/XmI0;:?F@2cSe/30;>?G@80/HeK
00L0/XiL0;>?G@2cSe/0]91L0;FAG@2eTU`0[hYE00<0/8]F00@0/HaG0;:=F02cSUT0]8mJ0P2`S5P3
0:n;E`<0[XYF00H0ZXMA0:^8DP2/RE<0[HYD0:j;E@2_S5H20;2=E`<0/XiJ00<0/hmK0;B@G02dT5`0
0`2eTEd02`2dT5`0/XiJ0;2<F02_ReL0/8aH0;6=F@2bSUX0/hiJ0;:=F@2`ReL0[HQD0080[8MC0P2]
R5@20:^7D`030:b8E02]RED0[HUE00<0[HUE0P2]R5<0102/Qe80ZhIA0:^6D@2ZQE020:V4C`<0YX5<
:oooool002[ooooo202WO4T80:QmB0080:UnB`2XODX0Yga90:MlB@2XODX0ZGi;0:^0C@2/PDh80:Z1
C@050:j5D@2]Q500[HA@0:b3C`2[PTh00P2ZPDd01P2YP4`0Zh5?0:^1C`2[PTh0Zh9<0:^2BP80Zh=8
00<0Zh=60:f4D02]Q500102^QE420:n6DPP0[hMC00H0[hEC0:j4DP2^Q580[H=A0:b2D02[PDl20:Z0
CP040:9mB@2SOTX0Xgi:0:AoB`80Xgi:00<0XGa809iiA@2MN4@00P2LMTL0102KMDH0VWA509UcA02H
LT<209Ma@P0609Aa>`2BKSX0Sf/g08aX=P29ICD0R6<f0P28HcL208MR>00408IQ=`24GcD0Pehd085L
<P80P5/a0`1lFC4307]H<080NUL_101kF38407YG<@0@07QH;`1gEbh0MeL^07IF;@1gEbh0NET`07aL
<`1mGC@0Pedf08=N=024GcD0QV4e08QS=P2:ISH0S6Pf08eY=`80T6/g00@0TF`h099]>@2CKSX0U6lk
0P2EL3`00`2CKSX0U6lk09E`?00309Ia?@0309E`?02DKc/0VFi10080VFi10P2HKD0309M/?`0809I[
?P2GK3l0V6e009U^@@2HKD00Uf`o09EZ?@2CJ3/808iX>@P0SfTj00H0TVLj095V>@2AIST0T6Dh08mT
=`2>HcH208eR=@P0S6Hi202:ISH808US=PT0RF<d0P2:I3D208]U=P<0S6Hg00H0SFLh08QV=P28ISH0
RVHf08]U=P2=I3H208iS=P0308mS=P2:I3D0RV@e00h0RV@e2027HC@00`25H3<0Q5lb08=N<@0208=N
<@0408EP<`27HSD0R6<f08MR=@80R6<f00P0RF@g08]V>@2<IcX0S6Lj08eX>`2;ICH0S6Hg08eW>080
SVPi00<0S6Hg08]U=P2:I3D00P2<J3P0102>JSX0Sf/k095]?@2BKSh209A`@0<0TVhn0`2CKcl209A`
@080UG=300<0U79209=a@@2BL4000`2BL4000`2ELd<0UWA409MeA@0209MeA@0K09Ec@`2DLT80Tg51
08id@`2<LT40RW0o08Q^?@25JcX0PVPg081V=@1oIC@0Nf@^07aU<@1jI380MV4b06iK<01UDb/0GD/U
05M78`1<?R<0A3PN03`b6@0g;aX0=RlM03<]7`0^:Qh0:BLK0080;2XK00H0:BXL02PZ7@0W:Ah09BPO
02<X8@0R9b03028U70<08B@K0P0P8aX8028U700602@X6@0S9aT08RHH024T6@0P8aX07R4J0P0M7aX9
01hQ6P0801hO6P0O81/0824K024R6P0S9AX092HI02DW6P0V:1X202h]6`0F030]6P0d;a/0>C<M03hf
7`12>b40AS`S048f7014>200AC/R04@l9@10>R@0>C@P030]6P0/:AH09bLK02TY7@0]:ah0<2dN03@^
7P0e;Q`0=2dK03D]6P80<b/N00<0<R`N02l/7@0^;1d00P0[;1`01P0Z;A`0;R/J02dZ6@0/:AX0:bLK
02XV6`80:BDL00<0:B@N02DU6`0U9A/00P0U9A/402HV708092DM00@08b@L028S6`0R8a/08B8J0P0P
8AT0800M7QT07AhH01dN600M7QH07b4F028T5`0T9QP09RPJ03da5`18>Ql0EDHY05i;:`1QBRP0HTPU
06E98P1XBb<0KU0Z07iQ>@2<Kd<0TWI709]oC@2YSUL0/9IM0:fCF02ELdd0M5`j04Xn:00^;2008BHP
024W8`0T9R409RLQ200S9B80100R8ad09RLQ02TZ900W:28202<T7P0:02LX8P0[;2H0:b/S02`/8P0_
;bD0<C4U038c9@0c=2@0<S<Q034b80T0=30T0P0c;b<3038^8P80<blS00H0=c4S03P`8`0i<B@0>S0T
03da9@0n<2D2044`9P0703`g900l=B<0>c@R03/b8@0m<B40?c8R048b8`0204<c900^04Pi901:>b@0
CCdV054o9`1C@RP0ED4V05<n8@1A?1l0DCX/04lj:@1<>BP0BcTU04Xj8`1;?B<0Bd0T04a19@1>>BH0
CCPU04`g8P1<>200CCTP04lk801A?B80DSlQ054o9`1D@2L0ET8Y05U4:@1MABT0H4LY06=8:P1TBB/0
ITP`0618;P1EAb`0BdHY04I29`16?RL0BcXV04hi:01B?BP0DchY05A0:01E@BP0Ed<X05U6:080FTLW
0P1JAbH00`1JAbL0FDHX05U5:P0205Q4:`0705Q4;01KABd0FdD]05Y6;@1HAbd0EdH/05I6;00205E7
;00804i09@1=?bD0C3hT04/l9@19>RD0B3TV04Lg9`16=RH3044f8P80@SLS0`13>2@05`17>RX0ASTY
04@h:010=bH0?CHT03/d8P0i=240>3<P03/e:@0j=2P0>C<W03Pb9P0g<BD0=S0T03D_8`0d;R80=2dS
03D^900f<2@0=c4S03Pb8P0i=240>SDR0080>SDQ00@0>cHR03df8`0o=b@0@SLU0P13=RD02@15=BD0
@3LV03lf9@0k=2@0=c4S03@`900b<2@0<c4U034a9`0403D_8`@0=S0T0P0e;b400`0f<280=c4S03Pb
900203Tc9@0303Xd9P0i<1l0>C0O0080>S4P0P0k<R4203`c8P0503Xa800l<b80@CHT04Dh9@1:>bH0
0P1<?2D0201<>R80C3lO04`o7`1>@B40D4<S05=69P1DAbL0EDPX0P1DAbL01@1BBB`0DDP[0597:`1C
ABX0Dd<Y0080Dd8X00@0E40W04lm9@1A?bL0Dd4Y0P1E@b/0E`1C@BT0DClW04lm9@1I@b/0G4@Z05e5
:@1QB2T0IT`Y06eA;01bEBd0MEP`07EJ;`1kH3D0NF0g075J<@1^F340Ke/f06aH<`1TDRh0I4/e06Q@
>01]ESL0KULe06eH;@1^FBX0LUhY07IS:`1nJ3l0QFXm08m_?02HMCd0VGQ209IjB02>O4h0R7aD08Yk
G025MUL0OVm@07IWAP1aHT40Kf0o071R?`1aHd00MF8h07UT>@1lI3H0PFLd08MZ<P2=KC80U78c09Qe
<`2ZQdL0/8e90;VICP30X5<0`:9J0;^MG`2cUF40[HiR0:J6E@2SPe80Wgi;09eiA@2KN400W7Pn0:1i
?P2QNSl0WgTh0:Am?02XPD00ZX510:Yn?`2/OT00/X940;J6B02cRd<0^I5;0<2HD`32VEL0_YEE0;R?
D@2eRdl0]8Y@0;R@E@2gSe@0]hmB0;N?D@020;J?CP050;J?C02eST/0]8a>0;B<CP2eSDl00P2fSU00
6`2gSe40^91B0;R@DP2cRDl0[XA:0:Z2A@2]QDL0/ha;0;NBCP2fTD/0/hi80;2?BP2_TD/0[i1=0:jA
C`2/T4l0Yhi>0:B<CP2RRT`0YHI60:N8B02YQdP0ZHE70:Z4AP2`R4/0^91C0<6GF`020<BQG@070<>P
G031WUX0_Y]G0;bIE@2iUU80^9EA0;JCD`020;NDE080^IIF00T0^YMG0;bIF@2nVe/0`9eM0<6OG`2o
WEd0_9YJ0;VGE`2gUED00`2fU5@0402eUUD0^IYI0<2QH036YfH0b:UX0<JWIP32Xf80_j1O0;^IFP2f
U5D0[Xa=0:F3A02OOCh0WW`m0:5o@02TPT<20:F3A080YXA500h0YhE60:R6A`2YQdP0ZHM80:R9B02Z
RdX0[8e<0:Z;BP2UQTD0XX=20:>4@`2VQdH0XhA40::3@`80XH9200d0XX=30:B5A@2VQdL0Z8U90:V<
BP2ZSD/0[I1>0;6DDP2eV5H0^9]I0;^NG02mX5h0ZHmL0080Z8iK00<0ZHmL0:^AGP2/TUl00P2]Tf08
0:V>E`80Y8UB00@0XhQA0::7D02RQe00XHI?0P2PQDh309n5C080WXA;0`2MPdX209f4B`H0W8=:0P2P
PT`209n1B`0^0:22C02RQ4h0YHMA0:J8DP2^Re<0/8mI0;JEH02mWF`0a:Eg0<NZP03:[XH0c;290<^b
T`3</i@0cKFC0<feT@3;/hl0ajn90<:[PP30ZH00^9]_0;NJKP2fVFl0]iYb0;^MM`30XWh0aZR40<Z/
RP37[h/0b[:@0<nhV03C_Z40f<B[0=[8/P3MbkL0gLbj0>;C_P3Sd[h0iM>m0>GC^`3UdKP0i<nd0>C<
/03RbZh0hlVV0=k4X@80f[jI01/0ekVC0=RhS`3F]HX0d:n20<^YO037Xfl0`YiZ0;bHI02hU600]I5M
0:n;E`2VPTh0Wg]709Ic>`2ELS`0TVli08m[=`2;IcD0Qf<c08EP<`23GS40NUXY07UI:P1hEbX0MeHY
07ED:@1cDRT00P1bD2X01P1YCBD0J4`T06M;901VBRD0IDPV06=69080HTDU00P0HD@R06138@1L@R40
FD0Q05Dn7`1A?1l0D3/N04hj7`@0ED0Q101D?b0204dh6@0604`g6P1<=a`0BcDM04/e7@1;=Ah0BS@M
0`17=Q`304Pg7@80BCPN0`1@>b02054l8@<0DSdR201A?240201>>Ql0CCTN04dh7@1?=ad0DCLN05@h
801F>R80FS`T101H?R<205To9080FT0U101M?Ql0101O@240HT<T06E69`1VAbP806A79`80GTLU00@0
GdLU05m5901QA2@0HD8S0P1S@R<806529@<0I4DV0`1SA2D20693900806E78@1VB280IdTS06Y<9P1/
CRP0KU0Z071B;01aDbd2075>:004079?:@1cD2X0Le0Z07AA:`80ME8/00<0MU<]07YG<@1jEc401P1i
ES0807]E;P80P5h`0P21Gc401022H380Pf4c08AR=024HS@308QS=P80RF@g0`2:ICP:08IT=P0308ES
=@24HS@0Pf4c0080PV0b00<0PEla08EP<`25H3<01P25H3<01024Gc80Peha08=N<@23GS42089M<080
PE`_0P26I3L00`26I3H0QfDe08MV<`0208QW<P0808UX<P2?JSH0T6/g095/>02CKSX0UG0l09Mb?P2H
Lcl409Ud@00509Ye@@2KMT80WWU50:1kA`2QO4P00`2NNTX309eiB@80W7Q80P2KMdL209YfAP@0VGE5
202GLd<01@2@JcH0T6/g095/>02AK3P0TF/j00<0TV`k102IL3`409Q_>`80VW4m0P2KLSh02P2LLcl0
WGA009ie@@2NMD40WGTk09ei?@2NNSh0Wg]10:1kA02QO4L20:9mB@<0YH1;0`2VPD`30:N2C@80Yh9>
00@0Z8=?0:V4D02ZQE40ZhIB0P2/Qe<01P2/RE40[8UC0:b9D`2/R5@0[HUG0:f9F@80[XUL0P2_Re/0
102`S5`0/HeM0;:>GP2cSel20;B@H0080:n=G`2aSf40]99T0;NEI`2hUVP0]iEW0;FCI@2dTV@80;VG
J@<0]Y=Y1@2gU6X80;REJ`030;RFJ02gUFL0]iEW00@0]iEW00@0^9IX0;BBHP2eTf<0]I=S0P2fU6@2
0;NEI@040;RFIP2lUfX0_9MZ0;bGJP80_IQ[0`2nVF`30<2ML`80`Iid0`32WgD01037Y7`0b:Em0<VV
OP3:Ygl20<^XP080c:V100<0bjQn0<bYO`3>Zh400`3@[H<0103?[880cZ^10<ZZP@3:ZX420<^[PP<0
c:b300<0cJf40<fZPP3=ZX802@3=ZX830<bYP@X0bjR00`3:ZX420<^[PP<0c:b30P3?[8800`3>Zh40
c:Uo0<^XOP020<ZWO@030<VVO038YG/0bJIl0080bJIl0P3:Ygd30<^XOP80bZMm0`39YW`30<RUN`P0
ajAj00P0cJQk0<bWNP3;YWT0bJAg0<RSMP36XG@0aJ1c0<BOLP80a:9e0`35XgH30<JTM`<0aJ=e1034
XW@00`33XG<0a:1`0<BPL0060<BPL0P0`j5c00@0a9mb0<>NL@31W6l0`9]^0P2oVVd00`30Vfh0`Ia_
0<2NL0070<2NL0P0`Yme2030WG<20;nMK`<0`9i`0`31Wg401P33Wfl0`Yi^0<6MK@30W6`0_i][0;jJ
JP80_IUY0P2nVVX20;nKJ`0<0;jJJP2lV6P0^YIV0;VEI@2kUV80^YEQ0;VDH02gTUh0]Y5M0;B?F`2c
SUX0/XeI0P2eTUX00`2fTed0]Y9N0;JBH0020;JBHP070;JAI02bSUX0]91L0;JBGP2gTel0^9AP0;NC
G`020;JBGP80/XmE00@0/XmG0;:?F@2cT5X0/hmK0`2dT5h01P2aSUP0/HeI0;:>FP2cSe/0/hmM0;B@
GP80]I5O00@0[hYE0;2;EP2aS5L0/XeH0`2cSUT00`2dSeX0/HeI0;6=F@020;2<F0@0[h]G0P2/RE<2
0:f:E0040:j;E@2_S5H0[haF0;2=E`<0/XiJ102cSe/0102dT5`0]I5M0;>?F`2bSUX20;2<F0070;6=
F@2bSUX0/hmK0;F?GP2cSE`0/H]J0:j8E`040:f7EP@0[8QD00@0[HUE0:j:EP2^RUH0[h]G0P2^RE@0
102]R5<0[8MB0:^6D@2ZQE020:V4C`<0Yh9=:oooool002[ooooo202WO4T80:QmB080Z7e:0P2WO4T0
102XODX0ZWm<0:b1CP2]PTl80:Z1C@<0[89@0`2[PDl20:Z0CP80[89@00<0[8=?0:b3C@2/Pd/00P2/
Q4T0102/Q4L0[HA@0:f4D02]Q5050:j5D@P0[HQC00H0[XEA0:f4D02]Q500[8=?0:^2CP2ZPDd20:V0
C0040:9mB@2SOTX0Xgi:0:AoB`80Xgi:00<0XGa809iiA@2MN4@00P2KMDH209YdA@0:09UcA02HLT<0
Ug5209Ma@P2DLC/0TVhj08m[=`2<J3H0RFDe08QS=P80R6<g0P28HCP01027H3L0QEhe08AM=022Fc82
085J<@<0O5Ta0`1kF30207YG;`0407]H<P1jEc40NULa07YG<@<0NEH`00X0N5D_07UI<01hF2l0N5P_
07MG;P1hF2l0NUXa07eM=01nGSD0Q5hg0P24GcD01@25H3@0Qf8e08UU=@2<J3H0SFTg0080TF`h0P2B
KCT00`2CKSX0U6lk09E`?00609E`?00409Ia?@2GLSh0Ug8n09Y_@P<0VFi10P2HKD0209M/?`0809I[
?P2GK3l0V6e009U^@@2HKD00Uf`o09EZ?@2CJ3/308iX>@80SfTj0`2@JS/808mY?080TVLj00<0TFHi
091U>02?I3L00P2>HcH00`2=HSD0S6Hi08aV>@0608aV>@P0RVHf0P29HcH408]U>080RF<f0P29Hc@4
08]U=P@0RF<d00<0RV@e08]U=P2<ISL00`2=IcP01P2>J3T0R6Hf08QV=P2:ISH0RfDf08eT=P80SV<f
00<0Sf<f08YT=@2:I3D03P2:I3D808MQ=00308EP<`24Gc80Peha0080Peha00<0QF0c08MR=@28HcH0
0P27HSD03P28HcH0RVDh08]V>@2<IcX0SFPk08iY?02=IcP0SVPi08mY>P2@JS/0SfTj08iX>@2<ISL0
RfDf0P2>JSX0102?Jc/0T6`l091/?02AKCd5099^?P80Tflo0`2DL4000`2DLT80Tg51099`@002099`
@00309=a@@2DLT80U79200D0UWA40240UG=309Ab@P2DLT80SG=208ab@@2:L3l0Qfdl08AZ>@22J3L0
P6He07mU=01kI2h0O6Da07YT<P1fHC80KU/`06EC:`1LBR@0EDDQ04hm8`17=ah0?S8J03T^6P0e<1d0
<RlP02//7P0W:A`0;2XK02/Y6P0Y:Q`0:2XM02LY7P0U:1l00P0S:243028U70<08B@K0P0P8aX8028U
700802@X6@0T:1X08bLI024T6@0P8aX07b8K01hP6`0M7aX901hQ6P807QlJ00H07b0J024R6P0R91T0
92HI02DW6P0U9aT202l^6P0F034_6P0e<1X0>S@L03lh7P13?280AcdR048f7014>200AC/R04<k900o
>B<0>3<O02l/6@0[:1D0:RPL02`Z7P0_:al0<bdO03D^7P0f;A`0=B`K03H[6@80<b/N00<0<R`N02l/
7@0^;1d00P0[;1`01P0Z;A`0;R/J02dZ6@0[:1T0:RHJ02TU6P80:BDL00@0:B@N02@T6P0T91X092@J
0P0U9A/302HV708092DM00<08b@L028S6`0Q8QX00P0P8AT08@0O81P07QlI01hO6@0N7aL07b4F028T
5`0U9aT0:2/J02X]7012=1T0C3dP05M6:01NBRT0GTHR0655801VBB40KDdV07=F;P25J3h0TWE909Ei
B@2NPdh0[I=J0;2FF`2WSE00RfY706Q@=012=B80:b/Q02@Z9P0R:2@08BHP02@W7P0802<U8P0@024R
700X:B<0;RlY02d^:00X:B<09BHP02PY8`0];RP0;2`T02h^900`<2H0<S8V03<d9P0c=2@0<S<Q034b
8080=C4U100c;b<303Da9@0403@`900c;b<0<RhR034]8@80<RhR00L0<blS03La8`0h<2<0>C4T03X`
900m<BD0?S0U0080@C0V00L0?3LT03`e8`0k=280>c8Q03hb8P11=2@0A3@U0080ASHW0P1@@BX09P1A
@BP0ETD[05U8;01LBB/0FTDV05I18P1A>R`0D3TY04hi:01;>BD0C3XT04`l8`1=?b@0CT0U04lj9`1>
>BH0CCPS04di8@1>>R40D3`Q058n8`1C@280Dd4Y05I2:@1G@bX0FTDZ05e5:@1PAbT0HTLY06=8:P1T
AC00GTH^05A6;01:A2X0AT8Y04Lo:P1<>bT0CcT[0P1B?BP03P1D@2P0ED4X05M3:01IARP0FTLW05]8
:01KB2L0FTLV05Y79`1JAbT0FDDZ05U5;01HA2/0F4@/0P1KABd0101JARd0EdH/05M6;01EAB/205A6
:`0804/o9@1;?bL0BCdU04Pl9P16>BH0A3LV04<f9P12=BD3040e8`@0@CHT00T0@SLU04Lg:016=RL0
@cHV044e9@0n=B@0?3DS03/d8P0i=2400P0j=2P0100i<bL0>38V03Pb9P0g<BD203H`9080=2dS00`0
=BlS03La8`0h<R80>C@Q03Xe8P0k=R80=c@Q03Pe8P0k=R<0?CHT03lf9@11=BD2044d900803/d900j
<b<0=S0R038^8P0`;R80;RhT02l_9@0_<2P403@^8P80=BlS0P0f<2@203H`8P<0=c4S0`0h<R@203T`
7`80>S4P0P0k<R4303`c8P0403he9012=bD0ACPU04Tj9@80BSXS00P0BSPP04Tn7P19?Qh0Bd0P04i3
8`1@ABD0DDHV05979`80DDHV0P1?B2/0201AB2/0DDHZ05=5:P1DA2X0Dd<Y05A3:@1>?RL0CclX101@
@2T0DP1??bP0CShW05a4;01LA2X0GT@Y0656:01WBRP0K4hZ079B:`1dE2d0LEP`07IM=@1eGCL0KELb
06UE<01ZF3@0IU<b05e=:`1TBb`0JE4_06mG<`1aFS40LEX^079L;@1eGbd0NF<a07a[?`24KSd0SW0l
09Ac?@2DMCl0S7A4089cBP1lLTh0PFmG07i]D`1iJ4h0M6=7071O@@1^GSd0KUhl06mO?@1gHSD0O6Hg
081Y=`26Jc@0Rf`c09=a<P2JMcD0XWdi0;6?C`2dUU00^YaC0;bPEP2jWeX0/YQM0:V>H@2SQf80WgiA
09emCP2KNDT0VgM309]h@02NNSh0Xgdo0:J0@@2TOCP0Z84l0:f5@02`QD40[h8o0;:2@02gQT@0^hY8
0;NAAP2kUD`0_iQC0;jGE02hT5<0/h]@0;68DP2aR5@20;J=E@030;J>D`2fSU40]Xi@0080]Xm>00@0
]Xm<0;J>D02fSU00]Xi@0`2gSe420;R@DP0J0;J9D02aQ4/0Zh550:j6B02fT4l0^9EA0;JDC@2`SdP0
/Xa=0;2=C@2`S4h0[Xa?0:Z:C`2VQdh0XXE;0:23B`2UQTH0YhQ80:Z8B@2ZQTP0ZhE70:n7BP2gSe80
_iEI0;jKE`2oW5P20<2MF@050;jKE`2kV5@0]iA@0;FBCP2eTU800P2hUED20;bIF@090;ZGE`2hUED0
^IIF0;ZGE`2lVU/0^YQI0;NEEP2dTU<0/Y1A00<0/Hm@0140/95@0;JGEP2nWeh0a:ET0<JWIP32Xf80
_IiM0;RIF02cTeH0/91C0:^;CP2SPdH0Vg/n09Ui?02LO3l0Wgm20:F3A0020:J4A@030:N5AP2XQTL0
ZHM80080ZXQ900D0ZhU90:j<C02aSdl0[he=0:Z8B0020:N5A@030:V7A`2SQ4@0XhA40080XX=300h0
XhA40:F6AP2WR4P0Z8U90:V>B`2ZSd`0[I9?0;2EDP2dVEH0]iaI0;ZOG02lXEh0[iER0:bBG`80ZHmL
00@0[99O0:fCH02]Tf00Zi5N0`2ZSeP20:V>E`80Z8eF00L0YhaE0:F:D`2TRE80Y8UB0:>8D@2RQe00
XHI?0080X8E>0`2OQDX209j4B@<0WH=800<0WhI=09j5C02MQ4/00P2LPdX00`2MQ4/0WXE<09j5C002
0::4CP0>0:63C@2RQ4h0XhE?0:F7D@2XRU@0ZH]E0;:?E`2dTed0^YUT0<2PK`36YgT0bJb20<b`R03=
/HX20<bcU00P0<feT`3<]900b[:>0<N_R@34[H@0`Z^20;ZML@2hVfl0]YU_0;JIL@2iVgD0_j5m0<FW
P`39ZhT0ajf80<V_S03=]I<0d[^L0=G0Y@3JaZh0gLRc0=g;]`3QdL40h]?00>CC`@3Ve<00i]Bn0>KB
^P3Vd;P0iLng0>G=/@3PbJX20=_3X@0]0=[0W@3K_iP0fKbB0=FfR03@/H<0dJei0<fYM@37Xfl0a:1/
0<6MJ@2lV6@0]91L0:f9E@2TP4H0XWi409mj@`2KMT40Ug8m09=^>P2@JST0SVPg08IR<025HBl0Pel_
085L;`1oFRh0O5L]07]F;01jE2d0LE8V071A9@1_CbH0KThW06e=9`1[BRL0JTTV06Y9:01ZBBH0JDPU
06A6901QA2@0GD8T05]2901J@b@0FT8V00<0G4@R1@1K@b4205<j6`0305<j701B>1d0DSPO0080DCLP
00<0DCHQ04`h7`1<>1l01P1<>1l305@l8080ECdQ2`1F?R82058m800605<k7`1D>Ql0ES/P05Xl8P1L
?R@0GShU0P1I@28205Y18`80Fd8T0P1L@bD0201Q@1l0H3lN060o7P1P?ah0HD0O06A38P1VAB@0J4LV
201WBBL2061:9@0406599@1QAb@0HdHT06=58`80ID@S201VABH506E79@<0ITPV00T0J4PQ06U98P1Z
BR<0K4`U06i>9`1`D2T0LE4Z079B:`1bCbT00P1cD2X207AA:`0507EB;01fDbd0Me@^07MD;P1lFC<0
0`1kF38307YG<@0307UF<01lEBh0O5D^0080OEH_0P1nEc0207mH<@06081N<021Gc40PEla089P<P23
HC<0Q68d0P25HcD308UT=`80RVDh0`2;IST208IT=P80QfDg1P28ISP01027ICL0QV@f08ES=@24HS@2
08=Q<`<0Qf8e0P28HcH308UT=`<0QV8b0P25HC4308AP<080QV@g00d0QfDg08QV=P29J3D0RVTd08]Z
=@2;JS@0T6/g095/>02BKCT0U6lk09Ia?@2HLcl0VGA000<0VWE100H0VgI209ag@`2NNDD0X7]70:9m
B@2SOTX20:5kC080X7Y;0`2ONDX00`2NN4T0WGU909eiB@0209ahB080VgM70P2JMTH809UeA@80Tfhg
00@0Tfhi09A_>`2DKSd0U6ho0P2DKT4209]b?P<0VW4m0`2IL3`01P2JLCd0Vg8n09]b?P2LLcl0WGA0
09ie@@80WgI200H0WGTk09ij?P2ONcl0X7a20:9mAP2SOTT20:AoB`<0Yh9=102XPdh20:V4C`060:R3
C`2YQ500ZHA@0:Z5D@2[QU80[8MC0P2]R5@01P2/ReD0[8]F0:b;EP2]S5T0[H]K0:j<GP80[XaO0P2a
S5l00`2bSF00/hiQ0;B?HP020;F@H`050;JAI02bT680/i5S0;FCI@2fU6H0102gUFL80;^IJ`<0]iAZ
0P2hUF/30;VFK0P0^YM]00<0^iU[0;ZHJP2iUfT00P2hUVP00`2iUfT0^YQZ0;^IJ`020;JDI0040;NE
I@2hUVH0^IMW0;VGI`80^YQX0`31W6l30<:ML080`iia0`34XGT20<FRNP<0aZ=k00@0bZN10<^XPP3<
ZH<0cJZ40P3>ZhD20<fZQ0030<bYP@3>Zh<0cjb400<0dJj600@0d:f50<n/Q03<[8<0c:b30`3=[H@3
0<j^Q@P0cjb40`3?[8H20<j[Q@<0cJZ4203<ZH430<^[PP80c:b30`3=[H@01@3?[880cZ^10<j[P@3=
ZX00c:Uo00<0bjQn00@0bZMm0<VVO039YW`0bJIl0P3:Ygd30<^XOP80bZMm0`39YW`30<RUN`P0ajAj
0P3<YgX0103;YWT0bZEh0<RSMP37XWD20<JQM0040<BRM035XgD0aJ=e0<FSM@80aZAf0P37YGL80<FS
M@P0a:1`2033XG<01036XG@0a9mb0<:ML030Vfh20;nJK@030<2KKP31W6l0`Ye`00L0`Ye`2032WgD8
0<6NM0040;nMK`30WW00`9i`0<2NL080`Ima0P32X7801P34X700`im_0<:NKP31WFd0_i][0;jJJP80
_IUY0P2nVVX20;nKJ`0<0;jJJP2lV6P0^YIV0;VEI@2jUF00^IAO0;RCGP2gTUd0]Y5L0;F@F`2dSeX0
/hiI0P2eTUX00`2fTed0]Y9N0;JBH0020;NCH`040;NBI@2bSUX0/hmK0;JBGP<0^9AP0P2gTel20;BA
E`040;BAF@2dTE/0]95K0;B@G0<0]91N0P2bSeL0102bSeT0/hmK0;>?G@2dT6020;B?HP060;2;EP2a
S5L0/XeH0;>>F@2dSeX0/hiI0P2bSEP20;:>FP80/HeI0`2`S5P0102_ReL0[X]C0:j;D`2^Re<20:n<
E080/8eE00<0/HiF0;:>FP2bSUX01P2bSUX00`2dT5`0/hmK0;:>FP020;6=F@070;:>FP2cSe/0]91L
0;F?H02dSUl0/H]L0:n9FP030:j8F@030:n9FP2]RED0[HUE00<0[8QD00<0[XYF0:n;E`2`S5P00P2_
RUD01P2^RE@0[HQC0:^6D@2ZQE00ZHA?0:R3CP<0Yh9=:oooool002[ooooo202WO4T80:QmB0080:Qm
BP2WO4T0Yga90:MlB@2XODX0ZWm<0:b1CP2^Pe080:V0C0<0ZX1@0`2[PE420:b2DP80[XAB00<0[XEA
0:j5C`2^QDd00P2^QT/00`2^QTT0[XEA0:j5D@060:f4D0P0[HQC0P2/Pdd00`2[PT`0ZX5;0:V0BP02
0:QoB@050:MnB02RODT0Xgi:0:=nBP2TOd/00P2SOTX00`2QO4P0WWU509ehA00209]eAP0309YdA@2I
Ld@0V7930080Ug5200L0UW1109Aa>`2BKSX0Sf/g08aX=P29ICD0R6<f0080R6<g0P2:H3P01029GcL0
Qede08IL=024FS8208=I<@<0O5Ta0`1kF30207YG;`0307YG<@1iES00NEH`0080N5D_0P1gE2h00`1f
Dbd0Ne/b07YJ<@0207UI<00507YJ<@1lG3<0OUhe07mO=P24GSL00P24GcD01@24Gc<0QV4d08UU=@2<
J3H0SVXh0080TF`h00<0TVdi09=^>P2DKc/00P2EL3`02@2FLCd0Ug8n09Ia?@2DKc/0TVdi09=^>P2E
L3`0V7<o09Ye@@0209Y_@P<0VFi10`2HKD00202FJch0Uf`o09Q]@02IKT40V6e009M/?`2EJSd0TfPk
0P2?JCX2091Z>`80TF/l0P2BK3d808mX?@80TVLj0P2AIST0102@ICP0Sf@g08iS=P2>HcH808aV>@P0
RfLg00<0RV@g08]U>02<IST00P2=IcX01P2<IST0RfDh08YT=`2:I3D0RfDf08aV=`80SFLh00<0S6Hg
08]U=P2:I3D00P29Hc@00`2:I3D0RfDf08aV=`0208eW>00708iX>@2?JCX0RFLg08UW=`2;IcL0S6Hg
08iU=`0208mT=`03091T=`2:I3D0RV@e00h0RV@e2027HC@00`25H3<0Q5lb08=N<@0208=N<@0308EP
<`27HSD0R6<f0080Qf8e00P0R6<f08YU>02<IcX0SFPk08iY?02?JSd0T6Xk095[?0<0TV`m00<0T6Xk
08iX>@2=IcP0202@K3`0102BKSh0Tflo09=_?`2CKcl209A`@080UG510P2BL402095_?`03099`@02D
LT80UWA400<0UgE50P2FM4@309Ec@`0I09Ab@P2=Ld80S79108Y`?`27KC`0Q6Xi085W=P1oIC@0OV@c
07]T;P1lIC40NfDc07MR<`1_G340IE<[05]98`1DA200DCdT04Xh8011<Q/0>c0L03Ha7P0b<240:bdO
02L[7@0202/Y6P0602TZ700W:A`09bTN02HY800T:B808bPQ0`0R9A`3024T6`8082<J200R9A`0200U
:AX092PJ02<W6@0R9AX082<J01lR6`0N81/07AlJ2@0N8AX201hO6P0601lP6P0P8AT08R@I02<U600T
9QT09BLI0P0`;aX05P0b<1T0=S8I03Xd6P0o>1h0@c`P04Pn8`13=ad0A3PP04Dk8P13>b@0?cTS03Lb
7P0^:aP0:RLD02/Y7@0^:Ql0<2`P03<]7`0e;Qh0=RdL03L[6`0f:aT203<[7P03038/7P0_;1d0;R`M
0080:b`L00T0:RdL02l/6`0]:QT0:bPI02TU6@0X91T0:2@K02TU700Z9Al00P0S8aT202@T6P0502DU
6`0V9Q`09RHL02HV700T9Ad00P0S91`00`0R8a/08B8J020Q6@0201lP6080824I01h0828G028T5`0T
9QP0:2/J02/^7@0^<Ah0BCTO05939P1MBRX0GTXY05i68P1QAAh0Jd/T07=C:P1gFS00Rfi209MkC02G
NdT0X8E>0;2FF`2`UUT0XXU9085R@`1OAbd0?30P02`]9@0V;bX08R/V020W7`0S9Qd802<U8P0C01lP
6P0Y:R@0<c@^03@e;`0];RP09bPR02TZ900];RP0;BdU02h^900`<2H0<S8V03<d9P0c=2@0<S<Q034b
800f<RH0=C4U03<_8`02038^8P0603<_8`0e<BD0=S8V03Hb9P0e<BD0<blS0`0a;B40200b;R80<blS
03La8`0h<2<0>C4T03X`900m<BD0?S0U0P11<2H01`0k=R<0?3DS03/d8P0m=2<0@3@T04<f9P18>2T0
0P19>BX06@1BA2X0D48X05109P1EA2P0FTT[05e::P1KARL0ET8Q05<i;01B>2T0CcPX04hi9P1<>R@0
CCdT04lo9@1?@BH0D3/X04lj9`1?>RD0CSXR04lk8P1A?B80E40U05E2901E@b/00P1HA2/00`1JABX0
GDDY05m6:0020656:00@0693;`1L@bd0DT</04U3:@16@RT0AclZ04dl;01A>bd0DC`W058m:01C?bL0
ED4X05M3:01IARP0FdPX05a9:@80FdPW00<0FTLW05Y7:@1JAR/00P1IAB`01`1IABd0FT@/05Y4;01I
AB`0ETD[05E4:P1DA2X00P1BA2T0201;?bL0BShV04Tm9`17>RL0ACPW04<f9P11=2@0@38U1@10=2@3
03lc8`80AC<U00<0@c<T044d900o<b<00P0l<b800`0k=280>C<W03Tc9`0603Pb9P0I03</8P0d;B<0
=BlS03H`8P0h<R80>SDR03/f8`0k=R80=C@R03Ld8`0i=RD0?3HV03df9P0n=BH0?S8T03da8`0g<B40
=S0R038_800`;200;R`P02d]8`0];RH0;RlW038/800203<]8@80=2hR0P0e;b<0100f<2@0>38T03Pb
900h<R@303La8`80=S0R0P0i<1l203Xa8080>c8Q0P0l<b80200n=B@0?cHU04<h9P16>BH0B3TT04Ph
8@17=b00AcDM0P19?Qh00`1:?al0CD8R04m4900305569P0705159@1:ABL0Bd@W04]49`1>ABP0Cd@X
0553:00205=3:@0304ho:P1=?RT0C3dX00<0C3dX0580CChY04ho:P1NA2d0GT@[05m4:@1RABL0ITPV
06]:9`1^CRL0LDlY06eE;`1cFcD0LE/f06YC<@1VDS40Ie@d065A<01JBB/0IdlS06aD:01cFbl0MUhb
07EM<@1fGS80NF4e07aT>01fJ3T0OVXh08Q_>@2?LSX0SW<n08Mb@`1mKdX0M6i<07IQCP1eH4/0Lem7
075MA01_G3h0KEXj06aI>01/FSH0MEl`07aT=024JSL0S6lg095a=02JMcD0YX4k0:n9@P2eV5H0]iYD
0;RNE02fWU@0/9UE0:NAF02OQUd0VH5O09UhC@2HMdX0UgE709Ue@@2LND40XGdo0:R2@`2[QD@0Zh<k
0:n7?`2dRT80]HU20;F6@02fQD00^HQ30;j<A`2iUDT0^iM=0;bGD@2hTU40/H]=0:f6C`2/Q540[XIC
0P2cRU@01`2dRe<0]8aA0;F=D02fSU00]hmA0;N@C`2hT5800`2gSe440;J>D00Q0;Z9D@2bPd/0[H15
0;27B@2hTU40^YMC0;>EC@2]SdL0]hY?0;N:D@2eRe40/XUA0:j7D02XPdh0YH1<0:9nBP2UQTH0YhQ8
0:Z8B@2ZQTP0ZXA60:j6B@2eSE00_99F0;^HE02mVUH0_Y]G0;fJEP2jUe<0]I9>0;2=B@2/RDD0[8U9
0080/i1@00<0^iQH0;fJFP2kV5P00P2gU5@01@2hUED0^YQK0;RFF@2eTeH0/Y1C00@0/8iA0140/iAC
0;JGEP2jVeX0_IiM0;jOGP2lWE`0^9UH0;JGEP2]Se<0[Y1D0:b>DP2UQd/0WGm309Uk?`2KOD40WX14
0:J4A@020:N5AP030:R6A`2YQdP0ZXQ90080ZhU:00X0[HY:0;6>CP2dTE40/Xm?0:f:BP2ZQdL0ZHI6
0:^8B02TQDD0XhA40P2RPd<0502SQ4@0YHI60:N8B02YRTX0Zi1=0:bACP2^Te00/IIC0;BIEP2gW5T0
^IiK0;^PG@2dVVL0[iER0:Z@G@2YSe`0[99O0:jDH@2/TUl0ZHmL0P2[T5T0102ZSeP0ZHiG0:N<E@2V
Re@40:F:D`030:B9DP2SR540XXM@0080XHI?00@0X8E>09n5B02OQDP0WhE80P2NQ4L309f3AP0309n6
C@2NQD`0WHA;0080W8=:00@0WHA;09n6C@2PQdh0Y8I@0P2SQDl03@2TQU00YHMA0:R:E02ZS5H0[8iH
0;FBFP2fUEl0_IaW0<>SLP38ZG/0bjj40<faR@3>/X/00P3</i@0803<]980c;B@0<ZbSP37[hT0aJj5
0<>/P`2kWW80^Ia`0;JIK`2eV700^9Yd0;jPO034YX80b:Z80<R/Q`38[XT0c;:A0=2gV03E_J40fL>[
0=c7/P3NbK@0gM300=kA`@3Rd/80iMC20>OE`@3Xdkh0im:m0>OA^P3Xd[X0hljc0P3Pb:`08`3OajD0
glFP0=o4V@3J_i80e[Z;0=VeP@3E/Gd0d:ah0<jZMP3<Z7@0aj=_0<2LJ02iUF40]HmA0;><D@2`RDh0
ZhA;0:N0B@2RNTH0WgM409ee@P2DKcX0TVdi091[=`2=IcH0RF<d08IP<`24GC80PU/`07]I:`1kFB`0
NUP[07QE:`1gE2`0ME8/0080M50/00P0L4hY06m=:P1/BbP0IdTW06E8:01SB2X0I4T/06A;;@@0HD@R
101RAB<205e0800305`o8@1L?R80FcdS0080FcdU00<0FS/V05<n8`1C?R<00P1C?R<4058m8P<0ESlP
0P1G@24;05Q18P0805I18P1G@240Ed0Q05Ln801I?R40GClS06119@1R@bL305]28`80G4<T0`1MA2D0
201XAR<0IdDR06I48@1U@b00IT@Q06M58P1YAb@0JdTV201YB2D2069<9@0406=;9@1SBB@0IDTT06E7
8`80IdHS201YARP206E78`0406I8901WBBD0J4XV06Q:9P80JD/W0P1[BB<0101/BR@0KD/U06i<9P1_
CBL2071>:00307=@:P1dDB/0M54[0080ME8/00@0MU<]07MD;P1hEBl0N5D_0`1lFC<00`1kF380NULa
07YG<@0207UF<00607iD;P1oEBl0P5H`085G<@22F380Q5Xd0P25FcD01P21Gc40PV0b089P<P23HC<0
Q68d08ES=@80QV@f00@0RF@g08YU>02:ICP0RVDh0P2;IST208aW>P<0QfDg00<0R6Hh08UW>@29IcT0
0P2:J3X208UW>@0308QV>027ICL0QV@f0080QF<e00L0Q68d08MR=@28HcH0RF@g08YU>02<IcX0SFPk
0080SVTl00@0RFDc08QT<P28I380R6@b0P27Hc4208IR<00808ES=P26I3L0QfDg08UW=`2;JSL0S6/f
08e/=`2>KCL2095/>00409=^>P2EL3`0Ug8n09Qc?`<0VWE100D0VgI209ag@`2NNDD0X7]70:9mB@02
0:AoB`80Y7]=0P2SNT`30:9iB`040:5hBP2NNTX0WWY:09ijBP80WGU90`2LN4P809YfAP0609Mc>@2F
LSP0UW4j09Ia?@2FL3l0UW130P2FKd@309ac?`80Vg8n00@0VW4m09U`?02IL3`0Vg8n0P2LLcl00`2M
M400WWE109mf@P020:1g@`0809ij?02NNSh0X7a00:5m@`2SOTL0Y7m:0:F0C02VPDd30:R3CP<0ZHA?
0`2ZQE001P2YQ500ZXEA0:Z5D@2[QU80[8MC0:f8E080[XUE00T0[8eG0:f>F02]SEX0[HeL0:j>G`2^
SF00[hiQ0:n>H`2bSF400P2cSV800`2dSf<0]I1T0;JAI@020;NBIP@0]I=U00@0]YAV0;NEI`2iUfT0
^YQZ202mVfd00`2gU6X0^9E[0;REJ`020;VFK080^YM]2@2kV6h00`2mVfd0_9Y/0;ZHJP020;VGJ@03
0;ZHJP2lVV`0_I]]0080]iEU00<0^9IV0;VGI`2jV6P00P2lVVX0102mVf/0aJ1c0<FPL`35X7<20<JQ
M0<0aj9e0`37Y7h20<RUO`<0bJJ000<0bjN30<bXQ03>ZXH00P3@[8P0303?ZhL0cZZ60<fYQ@3=ZX@0
cZ^50=2]Q`3A[XP0dZn90=6^R03@[HL0cjb60<f]Q0<0cZj50P3?[hH20=2`Q`P0dJj600@0dJf90=2/
R03@[8P0d:b80P3?ZhL20<jZQPP0cJZ200@0bj^20<b/P`3<[8<0c:b30P3=[H@20<j^Q@80cZ^11`3=
ZX030<VVO080bZMm0`3;Z7h20<ZWO@<0bJIl0`38YG/80<JSN@80bjIi0P3:YGP01039Y7L0b:=f0<RS
MP38XgH30<FSL`80aZAd0`37YGD20<FSM@H0aZAf2034X7080<BRM0040<JQM035X7<0`iia0<6LK`80
_iY]00<0`9]^0<6LK`33WG001`33WG080<:OM@P0`Iid0`30WW020<6OL@<0`Z1b00P0aJ5a0<BPL033
Wfl0`Ie]0<2LK02nVVX0_IUY0;bHJ080_YYZ0P2oVf/0102nVVX0_9QX0;ZFIP2iUFD20;RCG080]i9K
0P2fTEX20;F@F@80]I9J00X0]Y=M0;JBGP2gTf40]i=S0;RDI02hTfH0/XiJ0;>?F`2fTUh0^9AP0P2i
UF420;RDH080^9EK00@0]iAL0;JCG@2fTed0]I5M0`2dT5h20;BAE`040;BAF@2cSe/0/hmM0;:=H080
/XeQ00T0/XeH0;>>F@2dSeX0]I1K0;B?FP2cSUT0/HaG0;2;EP2cSe/00`2bSUX20;6=F@80/8aH0P2`
SE<40;6>E080/XmE202bSUX00`2dT5`0/hmK0;:>FP020;6=F@070;:>FP2dT5`0]I5M0;F?H02cSEh0
/H]L0;2:F`020:n9FP040;2:F`2aRe`0[XYF0:j:EP<0[8QD00<0[XYF0;2<F02aSET00P2`ReH01P2_
RUD0[HQC0:^6D@2ZQE00ZHA?0:R3CP<0Yh9=:oooool002[ooooo202WO4T80:QmB0080:QmBP2WO4T0
YW]80:MlB@2XODX0ZWm<0:b1CP2^Pe080:V0C0050:QnCP2YOdl0ZGm?0:Z0D02[PE400P2/PU801P2]
Pe<0[hEC0:n5D`2_QU80[hI@0:n6CP80[hM<00<0[hM:0:j5D@2^QE40102]Q5020:b3C`P0[8UC0P2[
PT`00`2ZPD/0ZH1:0:QoB@020:MnB0050:ImA`2RODT0Xgi:0:=nBP2TOd/00P2SOTX00`2QO4P0WWU5
09ehA00209]eAP0409YdA@2ILd@0V79309Ma@P80UW1100H0U74k099^>P2?JcL0S6Pf08UU=@28HcH2
08QS=`80RV0h00@0RElg08MM=@26G3@0Q5Xb0P23FC4307aI<@<0NeP`0P1jEbl207UF<00407QE;`1g
E2h0Me@^07IC;@80ME8/00T0O5`c07]K<P1jFS40NUXa07]K<P1mGC@0Oelf085Q>025GcP00P24GcD0
1@24Gc<0QV4d08UU=@2<J3H0SVXh0080TF`h00@0TVdi09=^>P2DKc/0UG0l0P2FLCd0202IM400UW4m
09=^>P2AK3P0TVdi09E`?02JMD40WGQ40`2JKd8209U^@@<0V6e000P0UV/n09M/?`2HKD00VFi109Q]
@02GK3l0UFXm09=X>`<0T6Xk00<0TF/l099/?@2CKCh00P2CKCh808mX?@0609=X>`2BIcX0TVLj095V
>@2@ICP0Sf@g0P2>HcH808aV>@P0RfLg00<0RV@g08aV>@2=IcX00P2?JC`01P2=IcX0S6Hi08YT=`2:
I3D0S6Hg08eW>080SfTj00<0SFLh08aV=`2:I3D00P29Hc@00`2:I3D0RfDf08eW>00208iX>@80SfTj
0P29IcL00`2;IcL0S6Hg08iU=`0208mT=`03091T=`2:I3D0RV@e00h0RV@e2027HC@00`25H3<0Q5lb
08=N<@0208=N<@0308EP<`27HSD0R6<f0080Qf8e00@0RF@g08YU>02<IcX0SFPk0P2?JSd2099/?@06
09=]?P2DKSl0Tfdn095[?02?JCX0SVPi0P2BKSh0102AKCd0T6`l091/?02?Jc/208iZ>P@0Tflo0P2D
L40209Ea@@08095_?`2@KSh0T6hn091^?P2BL400U79209MeA@2IMdL209MeA@0309IdA02ELd<0UG=3
00<0UG=301P0SG=208]a@029Kch0Qfdl08AZ>@21IcH0OfDd07iT<`1kI2h0O6Da07]U<`1hHc@0Ke`a
06EC:`1KBB<0Dd<O058n9@1:>200@S<L03/`700g<Ql0<c4R02`^800X;1h202/Y6P0402TZ700W:A`0
9bTN02HY808092TR0`0R9A`3024T6`8082<J200R9A`01P0U:AX092PJ02<W6@0R9AX082<J01lR6`80
7R0K2@0N8AX0200M7QT07QlJ01lP6P0P8AT08R@I02<U600T9QT09BLI0P0`;aX05P0b<1T0=S8I03/e
6`10>Ad0A3dQ04Po8P13=ad0A3PP04Dk8P13>b@0?SPR03Lb7P0^:aP0:BHC02dY7P0^:Ql0<R`P03D]
800f;Ah0>2`L03L[6`0g:QT203<[7P03038/7P0_;1d0;R`M0080:b`L00T0:RdL02l/6`0]:QT0:RLH
02PT600W8aP0:2@K02TU700Z9Al00`0S8aT00`0T91X09BDK02HV700202HV70808b@L0P0R8a/01@0Q
8QX0824I01lP600O81P08B8J00808B<H01d08bDH02HX6P0Z;A`0;S4N030c801?@2<0EdHX061=;@1R
BbT0GdDP06=57`1_CbH0NEP]07YM<`2>LDD0VWi>09QlBP2QQTl0/IML0:nEF02OQTH0O5e005U3:`0g
;Ql0;BhV02Tb;@0R;BL07bHN020V6P0802<U8P0501hO6@0Z:bD0=SLa03Pi<`0`<B/00P0Y:R@0300]
;RP0;BdU02l_9@0a<BL0<S8V03<d9P0c=2@0<S<Q034b800f<RH0=C4U03<_8`80<RhR0140<blS03Da
9@0f<RH0=c<W03Da9@0c;b<0<BdQ030/800a;B40<RhR03<_8`0g<B<0>30S03Ta900j<2@0?C4U03h`
9@02044`9P0703/f8`0l=B<0?3DS03dd8`11=BD0ACPX04Xj:`0204`l;@0I04i09P1;?B80BSXP04ln
8P1D@bD0F4DU05I28@1A?A`0E3X]05<i:P1@>BT0CcPV04hi901>?2@0CclU05109P1A?2T0D3/X050k
9P1@?2@0D3`S058n8`1E@BH0ET<U05M5;@0205U5;00305]6:`1MABT0GdHX0080H4DW0100H44]05]2
;01A@R/0BD<[04I1:`18@2d0CSd]058l;`1A?2L0DSdX05<o9`1E@BP0Ed<X05U6:01KB2P0G4TY0P1K
B2L00`1KB2P0FTLY05Y6:`0205U5;00405U5;@1JA2`0FT@/05Q4:`80ED@Z00T0Dd<Y0553:01A@bP0
BT0W04Tn:017?2H0ACXV04<h9P11=BD00P0o<bD00`11=BD0@3@T040d900203lc8`<0?S8R0P13<B<0
1012<R<0?c8R03hb8P0n<R8203`c8P0403La9@0h<RH0>38V03Pb9P<0>C<W01T0>S@X03</8P0d;B<0
=BlS03H`8P0h<R80>SDR03/f8`0l=b<0=3<Q03Dd8P0h=B@0?3HV03df9P0m=2D0>c8S03``8P0e;b40
=2hP030/800^;200:b/Q02//900/;BD0;2lX00<0<R`P00<0<bdQ03@^8P0e;b<00P0e;b<01P0j=2H0
>C<U03Tc9@0h<R@0=c4S03H`8P80=BlQ0P0i<1l203Xa8080>c8Q0P0l<b802010=bH0@CPW04@i9`16
>BH0AcPS04Lg8016=Ql0AC<K0P17?Qd01@19@1l0Bd8Q04i5901?ARD0D4LV0080CdHU0P16@B<02@18
@B@0BT4T04a19@1?@BH0D48W05519`1?@2/0CChY04/l9`0204Tj9@1I04/l9`1=?RT0Cd0[05m5;P1O
@b/0Gd@Y06959`1TAR@0JDPU06e;9@1^C2H0K5@`075I=@1`FCL0Ie<b06=@<01SDc80H4la05M8:`1Y
DQh0KULU07EN;01hH380Melc07QO=P1jHCT0OVDm06mS<`1gIC<0Q6/e08a^>02<LC`0QW5407]^B`1d
KTh0K5M606aGA01]F4<0KEU006aI>`1[F3P0JELc06QF<P1bG2/0NV<a08EZ=@2>LCL0UGHf0:1m>`2^
RD<0^99;0;ZMF`2iWUL0^9iD0;:JD02[U540XHYF09R1F02CNU`0UGA;09AcB02ELdD0V7A009ai@@2S
Od40ZhE40:j9A@2_Qcl0]H]30;R>AP2hS4D0]hQ20;N6@@2kRD@0_Xa70;^GB`2lV4h0^YE?0;B>C@2]
QT/0ZH5=0:Z2C`2]Q5H0/8MA0;68DP2bRE40/h]@0;F=D02fSU400P2gSe401P2iTE<0^91B0;R@DP2g
Se40]Xi@0;F=C`80]8a>01P0^hYB0;B3B`2]P4D0/8M90;RBD@2jVE@0/iE=0:^?AP2mRU<0_8]C0;^9
E02gR5@0/hEC0:f1D02XOT`0YWa<0:F6AP2WR4P0ZXQ90:Z6B02ZQ4H0[HE80;>;CP2jT5@20;bIE@07
0;fJEP2kV5@0]Y=?0:n<B02XQD40Y84m0:B1@@020:f:BP0<0;REE@2mVUX0^iQH0;REE@2gU5@0^IIF
0;VGFP2hUUT0]I=F0;:@D`2aSe80/8iA0P2aSe820;RIF0040;NHE`2fUeH0]YMF0;JGEP80]iQG00P0
[8iB0:nAE@2_TED0ZH]?0:63A`2LOT80WGm30:22AP80YhE60P2XQTL03P2YQdP0ZXQ90:^9BP2[RDX0
[X];0;:?C`2eTU80]95A0:n<C02[R4P0ZXM70:b9B@2TQDD0XhA40P2RPd<06P2SQ4@0YHI60:N8B02Y
RTX0ZY5>0:^BC`2]U540[iIC0;:IEP2eW5T0]iiK0;ROG02hWV/0/IMT0:^AGP2ZT5d0[99O0:jDH@2[
TEh0YheJ0:bAFP2[T5T0ZXmH0:R=EP2VRe@0YHYC0P2SR5420:F:D`040:B9DP2SR540XXM@0::7D080
XHI?0`2OQDP209j4A`<0WH=600<0X8M>09n6C@2MQ4/00P2LPdX0102NQD`0X8M>0:68C`2UQe420:B6
D00=0:F7D@2VR580ZH]E0:b>F02]SeT0]iAL0;RGH@2nWFP0a:Ac0<VZO03<[hD0cK690<ncS0020<bc
U00L0<bdTP3<]900b[:>0<R`RP35[XD0a:f40;bOL`2iW700]YU_0;FHL02gVG<0_Imk0<>UP@38ZXP0
aj^40<V]R03;/Hh0ckJG0=BlX03H`ZX0g<J_0=g8/`3Lc/40gM300>;B``3Te<@0i]G30>OE`@80j=>n
0380jmK10>OC^`3Sc[<0hljc0>;;Z`3SbjD0h/VP0=g5U`3J_i00gKV50=VeP@3E/Gd0djmk0=:^NP3>
ZWH0aj=_0<6MJ@30VU/0_YQJ0;ZCF02fSe@0/HYA0:b5CP2YPDd0Ygm;09mg@`2NMT80Vg=009M_?P2C
JS`0SfHh08aS=`2;HSH0PV0b085O<@20GS40Oe`b07eJ<P1lFC<0NePb07YF<P1dD2`0Ldl[071>:`1]
C2/0JT//06Y=;`1[CS00Je0c06968@@0HdLR0`1TB2<0101SARH0HTDU06959`1RA2P20653:@80H48Z
1@1H@bH305M29@<0F3lQ0P1I@28;05Y18`80FT<T00L0FT4S05]08`1N@2@0H44U06=4:01VA2T0Fd8S
00<0G4<T0P1MA2D205i59P0306e;:01/BRL0JTPU0080JDLT00<0JdTV06a:9`1]BbP0201ZBBH206==
9P0406A<9P1TBRD0ITXU06I89080J4LT201ZAbL206E78`0606I8901WBBD0JD/W06Y<:01[CBT0K4hZ
0`1/Bb8206e<8`<0KTdT0P1dDB/0101eDR`0MU<]07IC;@1gE2h207QE;`0607UF<01lFC<0O5Tc07aI
<`1kF380NULa0`1iES0207mE;`06085G<@22F380Q5Xd08IL=P27GCL0R5hh0P22H38208=Q<`0408AR
=025HcD0QV@f08IT=P<0RVDh0P2;IST308aW>P80QfDg00@0R6Hh08UW>@29IcT0RVPj0P2;JC/208YX
>P0308UW>@28ISP0QfDg0080QV@f00L0QF<e08QS=P29I3L0RVDh08aW>P2>JC`0SfXm0080TF`o0`2:
IS@208UU<`<0R6@b01P0Q68e08ES=P27ICL0RFLg08]Z=`2=K3L0Sfhi091_>@2AK3P0TVdi09=^>P2E
L3`0Ug8n09Ud@02JMD40VgI209Ye@@2KMT80WGQ409mjAP2QO4P0Xgi:0:AoB`2UP4`30:AkC@80XgY<
0`2RND/209mkB`80WWY:0`2MNDT00`2LN4P0VgM709]gA`0609]gA`0809Qd>02HM3X0V7<l09Qc?P2H
LT40Ug5409M`A@2GL4L209ed@080W7<o00@0Vg8n09Ya?@2JLCd0VG0l0P2LLcl209ed@00<09ie@@2O
MT80X7M30:1g@`2NNS`0Wg/o0:1l@02ROT@0Xgi70:F0B`2VPDd0Yh9>0`2YQ4l30:Z5D0<0ZhIA0P2Z
QE400`2[QU80[8MC0:f8E0020:j9E@070:n:EP2]SUP0[XiK0:j>F`2^SUd0[hmP0:n>H@020;2?I080
/hiR00<0]8mS0;F@I02fTFD00P2gTVH0202hTfL0^9IX0;JDIP2eTfD0]99T0;FCI@2gUFL0^YQZ2@2m
Vfd20;REJ`80^II/00<0^YM]0;^HKP2kV6h02@2lVFl00`2nW6h0_I]]0;^IJ`020;ZHJP030;^IJ`2m
Vfd0_Ya^0080^9IV00<0^IMW0;ZHJ02kVFT00P2mVf/00`2nW6`0aj9e0<NRM@020<RSMP80bJAg0P3:
YGP01038YGl0bJJ00<VVP039YX020<ZWP@80bjR20100bjN30<fYQ@3?ZhL0d:b80=6]R@3?ZhL0cZZ6
0<bXQ03=ZX@0cZ^50=2]Q`3A[XP0dZn90=6^R03@[HL0cjb60P3>[XD20<n_QP<0d;2700<0dK680=6^
QP3A[XH01P3A[XH30=6]R@80d:b80`3?ZhL80<j[P`<0c:b30P3=[H@30<j^Q@@0cJZ00`3>Zh420<n/
PP<0bJIl0P3:Ygd30<^XOP80bZMm0`39YW`30<RUN`P0aZ=i103:YGP40<VTM`80aJ=c0`36Y7@30<NU
M@030<FSM@36Y7H0aZAf0080aZAf0`37YGL80<BPL0P0a:9d00P0aj9e0<FPL`33WW40`Ia_0<2KKP2o
VVd0`9]^0<6LK`P0`ie`2032WgD80<6NM080`9i`0`31Wg430<:PLP080<FQL@34X700`im_0<:NKP30
W6`0_YYZ0;fIJ@2lV6P20;jJJP80_i][00@0_YYZ0;bHJ02jUVH0^IEU102gTU/40;JAFP80]I9J00<0
]Y=M0;JBGP2gTf400P2hU6@01@2iU6L0/XiJ0;>?F`2fTUh0^9AP00<0^IEQ00L0^9AP0;^HGP2jUed0
^IIN0;REG`2gU5h0]I5M00<0]91N00X0]I=F0;FBF02dTET0/i1J0;>?G@2bSF00/HaP0;6<HP2cSUT0
]8mJ0`2eT5/00`2bSEP0/8]F0:j9E0020;>?F`80/XiJ0`2aSET00`2`S5P0/XmE0;:?E@030;:?E@<0
/i1F1@2bSUX30;6=F@030;B@G02cSe/0/XiJ0080/HeI01/0/hmK0;B@G02eTEd0]8iQ0;>=H02aReh0
/8YM0:n9G02`RUd0/H]N0;:<G`2_ReL0[XYF0:b8E02[Qe<0[8QD0:j:EP2`S5P0/HeI0;6<E`2`ReH0
[hYE0:f8D`2/Qe80ZXE@0:V4C`2XPdh00`2WPTd[ooooo`00:_ooool30:EjA@030:IkAP2WO4L0Z7e8
0080Z7e80`2WO4T30:QmBP80ZGi;0P2YP4`20:QoB`80Ygi:0P2XOd/20:YoC080Zh1=0P2/PDh20:f2
C`P0[89@00<0[hIB0:j5D@2/Pdl00P2[PTh00`2/Pdl0[XEA0:n6DP020:^5F080[8II0P2]QeX20:j8
F`0@0:^5F02/QUL0[8IG0:b6E@2]R5@0[HQC0:f8D@2^RE80[8MB0:^6D@2YQ4l0Yh9=0:F0B`2SOTT0
XWe80:5lA`<0XWe91P2QO4P409UcA0@0V79300H0Tfdn099/?@2AJc`0T6Xk08iX>@2=IcP208aV=`0A
08]T>`2:HcX0RF8i08QQ>026GcH0QEhe08AM=023G3<0PUlg085N=P20GCD0OU/c07]H<01iERh0N5D]
07MD;01mEc<00P1lES800`1kEC40NU@`07YD<00207UC;`80O5T_0P1kF2h0301lFBl0OU/a081M<`21
GS@0QEhc08IO=027HC@0RF<d08YT<`2<Ic<0SFPd08iY=080T6Xk00@0TF/l09=]?P2DKSl0UW110P2G
LD800`2GKC/0V6hl09Y`?P0209]a?`0309Y`?P2HKS`0Ufdk00P0V6hl0`2BK3d2095[?0<0T6Xk0`2B
KCT2095/>0<0T6/g00@0UV]109AY?`2BIcd0T6Dk0P2?I3X2095V?00408]U=P2<ISL0S6Hg08eW>080
SVPi0P2?JCX208]V>@<0RVDh0`29I3L00`2;H3<0S64d08iS=P02091U>00608mT=`2=HSD0S64d08QR
<`2:I3D0S6Hg0P2=IcP01P2<ISL0RV@e08QR<`29Hc@0RV@e08]U=P80SFLh00<0RfDf08YT=@29Hc@0
0P2;IcL308YV=P@0RFDe0P2<ICh308]T?@<0RV<l0P2?I3L208iS=P0408eR=@2<HC@0Rf0c08]P<`P0
R68c2026HS8808QR<`<0RFDe0`2:ISH208]W=`P0Sf/k00<0Tf/h099Z=`2AJCH00P2@J3D01P2AJCH0
Tf/h09A/>@2BJC/0U6/m09A^?`80UG5100<0TW10091`?`2>KSd00P2CLD4209Ab@P@0UG=30P2EM3l3
09Ac?P<0Tg8m0200S71008]_?`29KCd0QVXj08AX>021ICD0Of<c07iR<P22I2h0PVLb089X=`1mISX0
LUlg06AD<01HBBP0Cd4T04<h9010>2<0?SHS03Xc8@0f<200<BhO02d[700[:A`09RPM02LY7P0Y:b00
:R`Q02T[800W:Ah09BLL02@V6`P08R<K0P0O8QL00`0P8aP08B@I028U6P0202<V6`0702@W700Y;Ah0
9b/M02@X6P0R9AX082<J01lR6`0201lQ70807b8K0P0N8AX201dP6@<071lH02005R0H01XQ6P0M91`0
8RPN02DX7@0V:1/09BDI02@U5`0a;Q/0<RlL03Ha7@0j=1h0?SHO04@j8@17>b<0BCdS04<h7017>b40
B3hU04<k9P0i<R00<2XL02XV6P0Y9AX0;2DK02dV700`:Qh0<R`N03@^7P0d;a`0<bhK03<^6P80<2XL
00H0<B/M038/7P0a:ad0<2XL02hX6P0/9QP202PX7P0302LW7@0V9Q`09BDK008092@J00<08b<I02HX
7@0V:1d01P0V:1d402<T70808R<K0P0Q8QX0800F8Ad06b@O028W800U:A/09bPF02d[5P0e<AP0?3HL
05@m7P1LABD0IDd[06M=:01UBB40J4/Q07AE9`1nGc00OVhk091jB02OOe00ZH1D0;V>H@33WF`0[HmI
08Yd>P1<BSd0?S``02d]8@0V:1d0:BXR02X]9P0S:2807B8L200T9R<0200U9R009RLQ02LX800Y:b00
:bdP02d_8@0^<B00;c8Q200c;b<00`0f<RH0=30T03<_8`03034]8@03038^8P0c;b<0>BlS0080>BlS
0P0h;R8303L]8@0?03dd8`0l<b80>S4P03T`7`0j<B00?3<R03he900o=RD0?CLW03df9P0l=B<0?CDR
040e8`13=R<0AcPS0080BCXU00d0DSdN05<n7`1D?b80ED0U05Do9`1D?RL0DS`W054k9P17=R@0B3LU
04Th9P1:>BL0BcXX0080BSTW00d0BCPV04/k8P1<?2<0CC/S050l901A>b@0E3/U05Dl9P1F>bH0F3lQ
05Y18`1L@bD0GdHX00@0HDPZ01P0HDPb05e7<01IABd0Dd4Y04i09P19?b@0ASlS04E08`1G?RP0EclW
05Hn9P1G?bD0FD4U05a59P1OB2P0HDXZ06M8;01UAb/0I4HZ0615:01L@bD0FD8S05I18P1E@242054m
9@0>04lm9@1>?RD0CClU04/o9@1:?R@0BClT04dl8P1;>b80BSXQ04Pi8P14>280@SLS03lg900n=R<2
03Xd9P<0>38T00<0>S@V03/e9`0m=bT00P0k=BL203Xd9P@0>C<U00<0?3HZ03Xd:00h<RH00`0e;b<0
7@0f<2@0=c4U03`^8`0n<2D0?c<W03hd:00n=RT0?CLY03Xg:00i=RL0>30S03Ta900j=2H0>CHW03Tg
:00f=bL0=CHV03<f9@0j;BL0>B`V03@[900a:R80;R/R02/]8P0[;R<0:S0T030/800a;B40<blS0080
=C4U00<0=30T03<_8`0a;B40200f<2@203H/8`0>03L]8`0h;R80>2lP03T`7`0j<B00>S8O03ha8@0o
<R80@SDT04Dh9@16>R@0ASXR04Di8@14>1h304Tm8`0404Xn901;?bD0C40V04i2:080Cd<Y0P1:?280
0`1;?B<0C3hT04do9@0304do9@06044f9013=R<0A3LT04Lh8`1:>R<0CC/S0P1@?2<205e5:`0D05a4
:01LABH0GTLW06199`1RBbT0I4hY06]J?P1ZES/0IU<e06A?<01UCRh0ITh/06U?;P1[DBh0LULR07AH
9P1gFbT0Nel_07eQ<P1nHCD207mR>00]07eY=`1mJ3T0OFPm07aV@@1jHd@0MUi4079I@`1`Ed<0LUXn
07=L?@1dFcd0LEHh071C<`1aDc40NEPe07iM>P20Gc80QfHi08i`?P2CN4<0Ugi509b7B02TSdh0ZYMC
0:ZML02YVfh0Y9IY0:2?H`2JQe`0UH1E091iC`2=MT`0WG5009mc@P2SN4D0Yga50:Z0A02/Pd<0[HA2
0:f5@02VOCd0ZX510;27A`2fSDd0^Y5A00<0_IAD0300^IYJ0;NHF02eTe@0]8i@0;>9C@2eQd`0]hI<
0;R5C02^P3D0/H8j0;J7?`2kS4H0`95=0<>CD@35UED0aYIF0<:GD`30UE40_Y=?0;bAC@2kT4`0_95=
0;fBCP2nTdl0`95=0<6BC033U4h0aII>0<JHC@35UdX0aIM90<BFB02mSD/0_8a:0;R=B@2eSDP0/Ha6
0:b;A02YRd<0Yh]20:n9@P2aRd@0/X]60;B=BP2dSD`0]8a>0;::C02bRTd20;J?BP040;F>B@2dSDP0
]8e80;><A`80/X]600T0Z8A:0:f9C@2]RDd0]91B0;ZGE@2kVE80]iE=0;:AA02^SD000P2bRT80102d
S4H0]He80;N>C02iT4h20;^BDP030;VGE`2kVET0_I]K0080_YaL01<0_I]K0;^IF@2jV5P0]95A0;2=
C@2ZQTP0YH530:9n@P2ROT@0Y7m80:F0B@2VOdH0Yh170:N3B@2XQD/0ZhQ>0:^;D02/SU80[HmC0080
/8m:01h0[hi90:j=B02]S4L0[8]60:^:A@2ZRD@0[i590:b>AP2XRT@0YHI30:B5A02UQTH0Z8Q;0:Z:
C@2aTU40/Y=B0;BEE02fUeH0^9UH0;ZKFP2kW5/0_9eL0;^UJ@2hXVH0[iIM0:F<E02WS5L0/99P0;2@
G`2YREX20:N<E@@0Z8eF0P2YSUL20:N<E@80YX]D0`2URU<20:B9DP80XhQA00<0XXM@0:66C`2QQTl0
0P2PQDh20:66C`H0XXM@0P2VRDd03P2WRU00ZHaD0:f?F@2aTel0]IMS0;NII`2jVf80_IiW0<6SK`35
ZGT0bJj30<Z`R`3</Y40c;>D0P3>]Y807P3=]I40c;B@0<ZbSP39/Hd0b;2<0<N_R`35YhD0_J1h0;BH
IP2cVF00^ImV0<2TLP34Ygl0a:J40<J^S037[Xl0b;6A0<ZeUP3>^id0dL2T0=O6[03IbJl0glZe0>7<
^@3Rd;`0iMC20>KFaP3Uf<P0i]S;0>CHbP80hm6k0P3UdKT0:`3Vd;P0i/jd0>C:[`3Qaj`0h<FX0=o1
W@3M_i/0g;bF0=RhT@3D/hX0dJj40=2[O`3>ZGd0bj=b0<VQL036WV/0`i]W0;nHH@2kU5/0^95H0;N@
E@2_SDH0[hY40:^6@P2XPD00Y7/m0:5e>02OLCH0WFld09YX=@2IIcH0TfDd08iR=@29GcD0Q5le081M
=`1nG3H0O5PV07]G9`1jERH0N5<V07E@901cCR@00P1aBb@01P1]C2<0K4`S06a<9@1ZCBD0JDdV06I<
9`80IDdY0P1VBAl01P1UB200I4HP06=58@1RA280HD<Q06528`<0H4<U0P1O@R@305i18`<0FD0R00/0
F3lQ05U08P1I@280FT4S05]2901K?Q`0G3lM05m2801QA280HTDS06=6900206958`80ITTW00<0IDPV
06A79@1SAR@00P1QA280101P@b40GDDS05e58`1NAR@205m79@0306189P1QBBL0HDTW00<0JDdU00<0
JThV06]?9`1/D2P00P1/D2P2071<:0@0Kd/W0P1^BRH0101[CbP0JThW06Y>9`1YCBH206Q<9@80Id/T
0`1^CB`206e<:`<0K4/Z0`1[CR@206a?9@<0KE0V00/0M50/07=?:`1aCBT0L4`X075=:@1bCRX0ME4]
07IB;P1aDRH0M5DY07II;@0207QM<00507MO<@1eGc00LU`]06mJ:`1kFB/00P1lFR`00`1mFbd0OU`^
07iL;P0207mM;`80PEd]0P22GRh308=O;`0308AP<026Gc@0Qf0e0080R64f00@0RF8g08YS>02;I3T0
Rf@i0`2;ICH208aV=`<0SFLh0P2>JSX508eY>@0908aX>02<KCL0S6dg08a[=P2>JSH0SFTe08iY=@2@
J3D0SfLd0080T6Tn0P2?J3d408iW?0<0S6Hg0P2;ICH308YT=@0608aS=@2=I3H0RfDf08]W=`2<J3P0
RfTi0P2;JcX2091/>004095]>@2CKc/0UG4m09Ib?P80V7A000/0VgM709ahB02MNDT0WWY:0:1lC02Q
ODd0XWi>0:=oC`2QODT0XWi:0:B0C0020:F1C@030:B0C02ROTX0XGe90080Xgm;0P2ROTX30:5mB@04
0:1lB02ONd/0Wg];09mkB`80WWY:0`2MNDT209ag@`0409]f@P2JMD40VGA009Ud@080V7<o0`2KMT82
09Ye@@<0VGA00P2KMT4209Ye@00809]f@@2MN4<0X7]60:5lA`2MNCl0Wg]10:9nA02UPDL30:N3B@05
0:J2B02XQ5@0ZHEE0:Z6EP2[QeL00P2/R5P00`2^RUX0[h]K0:n;F`020:j:F0030:n;F`2_RUd0/8]O
0080/8]Q00<0/H]T0;6?G`2aSel00P2bT6030;>AH@030;BBHP2eUF`0]YI]0080]YI]0P2gUfh20;RH
K`P0^II/202oWFl30;jKL@030;fJL02lVFl0^iQ^0080^iQ^0`2lW7<20;fMM0<0_Yie0P32X7820<6O
L@050<2NL02oWFl0_ie_0;jLKP30WW000P31Wg400`32X780`j5c0<BRM0020<FSM@80ajN00`38Z843
0<VYPP@0bZZ30P3;Zh@20<b/Q@<0d:n<0P3A/8d30=:aSP<0ck6=0P3@/Xh30=6cS`P0dKB:203C/Xl2
0=6`S@80d:n<0`3?[X/01`3>[HX0dK680=6aR03?[hH0cZj50<b/P`3;Zh800P39ZH080<b/Q@80c:b3
00<0bj^20<ZZP@39ZH000`37Ygh00`36YWd0bZZ10<VYP0030<RXO`0;0<ZZP@3<[8<0cJf40<^[Q@3:
ZX@0ajN00<FUO034YGT0a:Eg0<JWN@37Z7T00`38YG/30<VVO080bZMm00@0bjQn0<ZWO@3:Ygd0bJIl
0P38YG/20<NTNPP0b:Ek2035XWP40<JTMP80aJ=e00<0a:9d0<>QL`37XWD01`37XWD20<JQM080aJ1c
0`34Wg800`33WW40`Ye`0<:ML0020<>NL@<0a9mb00@0aJ1c0<JTMP34XW@0`Z1b0P30WW000`31Wg40
`j5c0<BRM0020<FRN0040<BQM`33X7H0`Yme0<6NM080`9ec00<0`9aZ0<:NK033Wfd00`35XFl02`34
X6h0`im]0<JQM035X7<0a9mb0<>NL@31W6l0`9]^0;nJK@2nVF`0`Yi^0080`Ie]00<0_i][0;jJJP2m
VFT00P2lV6P02`2jUFT0^iIZ0;bGJ`2lUf/0^iIZ0;RCI`2eT6@0]8mS0;RDH02gTel0]I5M0080]91L
00<0]I5M0;NCG`2hU600202hU6030;NEI@80]YAT102eTf<01P2eU5l0]9=N0;BCGP2cTUd0/Y5L0;6@
F`80/8mJ00l0]Y9N0;>?F`2`S5P0/XiJ0;JBGP2hU600]Y9N0;>?F`2eTU`0/i1J0;6>F02`SEL0[haF
0;2=E`2bSeT00`2cT5X30;:?F@<0/HiH00<0]Y9N0;FAG@2bSUX00P2aSET00`2bSUX0/hmK0;FAG@08
0;BAF`80/hmK00<0/XiJ0;6=F@2`S5P00P2_ReL01P2^RUH0[HUE0:f9E@2^RUH0[h]G0;2<F080/HeI
00T0/XiJ0;>?F`2cSe/0/hmK0;6=F@2_ReL0ZhMC0:R4D02VPTh00`2[QU4[ooooo`00:_ooool20:Ej
A@80YW]60P2WO4L20:QmB0<0Yga90`2XODX20:UnB`030:V0C02XOd/0Z7m;00D0Z7m;0P2ZOd`20:^0
C@80[85>0P2]PTl80:b2D0030:n6DP2^QE40[8=?0080Zh9>00<0[8=?0:j5D@2_QU800P2[QEH20:b6
E`80[HMH0P2^R5T01P2]QeX0[HMH0:f7F02]QeH0[8MC0:b7DP80[8M@00P0[8MB0:^6D@2YQ4l0Z8=>
0:F0B`2SOTT0XWe80:5lA`80XWe91@2QO4P20:1kA`<0VWA500<0VG=409Qb@`2HLT<00P2GLD82099/
?@06095[?02?JCX0SVPi08eW>02<ISL0RfDf0P2;I3/0102:HcX0R64h08MP=`25GSD208AM=009089O
=`21GSH0P5de07iK<`1lFC40NUL_07QE;@1gE2`0OELc0080O5Hb0P1kEC4207YD<00307UC;`1lFBl0
NeP^0080NUL]00@0NeP^07eJ<01oG380PEhd0P26Gc@01P27HC@0RF<d08]U=02<Ic<0SFPd08iY=080
T6Xk00@0TF/l09=]?P2DKSl0UW110P2GLD800`2GKC/0V6hl09Y`?P0209]a?`0309Y`?P2HKS`0Ufdk
00P0V6hl0`2BK3d3095[?080T6Xk0`2BKCT2095/>0<0T6/g00P0U6To09=X?P2AIS`0T6Dk08mT>P2@
IC/0TFHl099W?@<0S6Hg00<0SFLh08iX>@2>J3T00P2?JCX208]V>@<0RVDh0`29I3L00`2;H3<0SF8e
08iS=P02091U>00608mT=`2=HSD0S64d08US=02:I3D0RfDf0P2<ISL01P2;ICH0RV@e08US=029Hc@0
RV@e08]U=P80SFLh00<0RfDf08YT=@29Hc@00P2;IcL308YV=P@0RFDe0P2<IC`308]T>`<0RV<j0`2=
HSD308aQ=080Rf0c2028HS<808IR<PP0Qf4b0`29ICD208YV=P<0RfLg202?Jc/00`2DK3T0Tf/h099Z
=`02091X=@0;095Y=P2BJSL0Tf/h099Y>`2DJcd0U6ho09A`@02ELD40TW10091`?`2?Kch00P2CLD42
09Ab@P<0UG=300@0UWA409Ie@02FMD00UWE00P2EM3l309Ac?P0J08ea@@2;Kcl0RFdm08M[>`24J3P0
PFDe07mS<`1nHS80PF<]085V<@21IcH0Nf@h075N=P1SDbl0EdPW04m19013>2@0@3PS03hf8`0j<b40
=BlO030]7P0]:a`0:bTL02HX7@0W:Ah302T[800302LY7P0U9a`092HK00P08R<K0P0O8QL0100P8aP0
8B@I028U6P0S9Q/202@W700602T]7P0W:ad092PJ024T6@0P8aX07b8K0P0O8A`201lR6`807R4J0P0M
81T301`O600M01LQ6@0K8Q/07B@L020V700S9Q/09BLJ02HV6P0V9aT0<RlL03<`7@0g<Qh0>cDO03hf
7`13>B00ASXR04Lk8@13>1`0Ac/Q04Pn9@12>RD0>C8P030Z700Z9QX0:BDJ02`U6`0]9Q`0<2XN038/
7P0d;Qh00P0d;a`00`0c;QX0<2XL034[7@02038/7P04034[7@0_:A/0;BLI02`V60809bLM0`0V9Q`3
02DU6`P09RPM00@092DM02<T700S91`08b@L0P0R8a/2024R6P0P01LP7@0M8al08RLP02HX6`0Z:AL0
;R`E03Pb600o>1`0Ed0Q05i79`1VCR`0J4hY06M;8`1ZCB40MULY081Q<P22L3h0Tga:0:5oC`2ZPE<0
^HmO0;jJJ02VReH0Q6dg04M5>00k>Bd0;2`P02HX7@0Y:R80:RdV02@Y8`0N8ad802@V8`0802DV800V
9b409bPP02T[800[;B00;BlQ02ha800_<R4803<_8`0803Hb9P0d<2@0<RhR034]8@0`;200<BdQ038^
8P0c;b<803P^8P80?3<R0`0j<B002P0l<b80?SDT03lf9@0k=BD0?3DU03`e8`0m=B80@3DS04@g9019
>RD204Xk9P0905I18P1G@R<0F4<V05U4:@1H@RX0Ed4Z05Do:P1C?BP0BCPV00<0B3LU00T0BCPV04Xi
9`1;>RP0BcXX04/k8P1<?2<0CC/S050l901B?2D00P1E?2H01@1F>bH0F3lQ05Y18`1MA2H0GdHX00<0
HDPZ00L0H4LY05m9<P1MAc00F4@/0592:@1>@2H0BClT0080Ad0T0100F3lY05Q0:01H@2P0F40V05Y2
9P1MARL0H4TY069;:`1XBBd0ITP/06E7:`1QART0GTDW05]49@1G@R<0ET4R0P1B?RH00`1@?RH0CclV
04i09P0204/o9@0<04Y09@1<>R80Bc/R04Xj8`18>B80A3PR048g8`0o=b@0?SHS03`f:00j=2H0>C<U
0P0h<R@00`0i<bD0>S@V03/e9`0203/e9`80>S@V0`0i<bD07`0h<R@0>S@X03Tc9`0g<BD0=S0T03D_
8`0f<2@0=c4U03Pb9P0m;b@0?S0U03lc9`0n=2P0?SHY03dg:@0j=bP0>CHW03P`8`0i<B@0>S@V03Tf
9`0h=RL0=SLW03@e9@0b=B@0>RdW03L/9P0d:b@0<BXR02dZ8@0[:b400P0Z;B801P0_:al0<2`P038^
8P0d<2@0=C4U03@`9080<blS200f<2@203H/8`0;03L]8`0h;R80>2lP03T`7`0j<B00>S8O03ha8@10
<b<0@SDT04Dh9@17>bD00P17>b<02016>R00BShT04Xn901:?R@0BclU04a09P1=@BL0CT8X0P1?@bT8
04/l9@08044f9013=R<0A3LT04Pi901:>R<0CC/S050l8`1A?B@205e5:`1<05a4:01MARL0GdPX065:
:01TCB/0IU0[06ED>01TD3D0HDh`05m::`1PBBT0Hd/Y06I<:`1XCR/0LeTV07EK:01gGB`0NUl`07aQ
=01lHCH0O60h07]O=`1jICH0NVDh07YT>`1iHch0Mf1107AL@P1aF480KeI2075I?@1bFc`0LeXl071E
=`1_DS80LE<a07UH=@1nGCX0PF0c08IW>@2?L440TgQ309ImA@2JQ4P0XXi?0:RDE@2WV6d0YIMZ0::A
I@2MRUl0V8=F099mD02>Md/0RgA809ac?`2OMT80XgY40:MoA02[PdH0[HI50:j7A02_R4D0[8=30:j5
A@2bRDT0]Xe=0;ZAD@2mU5@0_YEE0;nFEP2jV5P0^9IF0;JCD`2eSDl0]8]=0;J8C080^8M<01<0/8@k
0;>7?P2gRd@0_8m;0<6DD@34Ue@0aIQG0<JIF034VED0`iQD0<6FDP2oU500_Y=?0;nDD030UE40`IIB
0<:ED@33UU80aIUB0080ai]B01<0ai]@0<JKC@35VT`0`i=A0<2CD02nTdl0^Y9=0;NBC02cTDX0[i59
0:j@B02bS4D0/he60;F>B@2fSd`0]Xm>0;F=C`2cRdd0/XY=0080]Xm:0P2eSTT01@2dSDP0/ha70;:;
AP2bRdH0[HU=0080/He?00H0]Y=C0;ZGE@2lVU<0^YQ@0;NEB`2dTdH20;>=A0030;B>A`2eSTT0]i1=
0080^95@01L0^I5C0;ZHF02lVUX0_YaL0;nMG@30WUh0_ieM0;jLG02mVe/0^YME0;JCD`2_S4`0ZHE7
0:B0A02ROT@0XWe60:=nA`2XPDP0ZH990:R4BP2XQD/0ZHI<0:V9CP020:V;C`80[Xe80P2]S4L30:b;
AP0?0:^:A@2[SDD0ZH]30:N9@`2UQT<0YXM60:V:BP2]SE00[hmB0;6BD@2bTe80/iAC0;FFE@2gV5L0
^IYI0080^iaK00P0^jEY0;ZRIP2`Ueh0YX]D0:J;EP2_TEl0[Y1N0:N8F@H0Z8eF0P2YSUL20:N<E@80
YX]D102URU<20:B9DP80XhQA00@0XXM@0:66C`2QQTl0XHI?0`2RQe030:>8D@80Y8UB02d0Z8]?0:R;
D@2YS580ZhiF0:j@FP2cUF40]YQV0;VKJ@2mWVL0`:5[0<BVM037Zg`0bk250<bbS@3>]9<0c[JD0<ng
T`3>]Y80cKFA0<bdT03:/Xh0bK6=0<R`S037[h/0aJN50;fPN02eVFL0]9YQ0;VOIP30Y780a:Mo0<FW
Q@36[X`0ajn=0<RaT@3;]9D0c[VL0=>oY03FaJT0fLR^0=o:]@3Qc;L0h]2l0>CC`@3Ve/H00P3Uf<P0
0`3Tf<X0i=:n0>GC_@020>OB_@0e0>OA^P3Xd;P0iLfc0>?9[P3Qaj`0hlJT0>;6X@3P`Yh0g[jH0=^i
T`3H]Hd0eK:80=F`QP3AZg`0cjUj0<fWMP39Y700aZ5/0<:MIP2oVV<0_YYP0;RED`2fTe40]Hm>0;::
C02^QDL0[7m40:Qk@02XND40Y7<k0:5b>P2MKc/0V6dj099Z=`2=IcP0R6Hh08MU>024GRd0Ped/085K
;01oFB`0O5DZ07YC:P1hDBP0Me0Y07AC:01cDRL0LU8Y06mB:P1]DBX0JU0[06U?:P1XD2`00P1]CB@2
06a<9@0506];9@1ZBBH0JTTX06Y9:01SARH00`1RABD206549080H4<S00<0GT<V05m49`1PABP0101P
ABP01@1OA2L0HDDP06968@1TB2<0ITXU0080Id/V00<0ITXU06E9901WBbH00P1VBRD01@1UBB@0HdLR
06968@1RAR40HDDP0080GdDT0P1PARD0101QAbH0HTPW06989`1RB2L306U=9@0306Y>9P1[CbL0JdlW
0080K50X201`C2P00`1/D2T0JdlX06]?:00206Y>9`80JDdV00@0J4`U06m>:`1_CR/0Kdh[0P1^CBX3
06e<:@<0KThU0P1_CbH3071@9`0;07A@;01cCb/0LThZ075=:@1bCRX0Ldl[07EA;@1gDbl0M5<X07IG
:`1iFRh00P1jGC401@1jGc80Mela07AN;`1bG2d0OE/]0080OU`^0P1oGBl00`20GS00PEla085O<@03
089N;P80Pel_0`24H30208IO=00308MP=@28HCH0RF8g0080RV<h00<0Rf@i08]U=P2<ISL00P2<ISL2
08eW>080SVPi1`2?Jc/01`2>JSX0SFhh08a]=`2=K3L0Sf/g08iZ=P2?JSH00P2@J3D508mX?@<0T6Tn
0`2=IcP208aV=`<0RfDf00H0SVDg08mV>02=IcP0SFTi08iZ>P2=Jc/208e]?080TFdi00H0TVhj09A`
?02ELCd0Ug<o09Qd@02IMD4209ahB00409eiB@2ONd/0X7a<0:9nCP80Xgm?00<0XWi:0:=oB`2TP4`0
0P2UPDd00`2TP4`0Xgm;0:9nBP030:=oB`80XWi:0`2QODT20:1lC080Wg];0`2NNTX00`2MNDT0WGQ4
09ehA00209ag@`0409]f@P2JMD40VGA009Ud@0P0VgI200`0W7M209]f@@2KMT40VgI109ag@P2NND@0
X7]60:9mB02NNT00X7a20:=oA@2UPDL30:N3B@050:J2B02YQED0ZHEE0:Z6EP2/R5P00P2]RET00`2^
RUX0[h]K0;2<G0020:n;F@030;2<G02`Reh0/HaP0080/HaR00<0/XaU0;:@H02bT6000P2cTF430;BB
HP030;FCH`2fUVd0]YI]0080]iM^0`2hV6l00`2iVG00^YM]0;ZGK@060;ZGK@P0_ie_0P2oW7820;jK
L@80_IY`0P2lVFl20;fMM080_Yie0`2oWgH01@30X7L0`j5d0<>QM033XG@0`Z1c0080`Imb0P30WW42
0<:PL`030<>QM034XWD0aJ=f0080aZAg00<0ajEh0<RXP@38Z8400P39ZH830<ZZP`@0bj^40P3<[8D3
0<f]QP040=2_S03A/8d0dK2=0=6`S@80d[6>0P3C/Xl30=2bSP80dK>?0`3B]9080=:eS@P0e;>@0`3A
/8d20=2_S0<0cjj;00P0dK680=2`Q`3?[hH0cZj50<b/P`3;Zh80bZZ10<VYP0P0bj^40P3<[8<00`3;
Zh80bZZ10<VYP0020<RXO`040<NWOP36YWd0bJV00<RXO`<0ajMn00/0bJV00<^[PP3<[8<0bj^50<ZZ
Q038Z840aZIm0<FVNP35YWP0aZMi0<JWN0030<RUN`<0bJIl0P3:Ygd00`3;Z7h0bZMm0<ZWO@020<VV
O080b:Ek00<0ajAj0<RUN`38YG/01P38YG/80<JSN@@0aZAf0P35XgD20<BRM0P0aj9e0P36XG@20<FP
L`@0a9mb00@0`Ye`0<>NL@33WW40`iia0P34Wg820<FPL`030<FSM@34XW@0`Z1b0080`Ima00<0`Z1b
0<>QL`34XW@00P35XWP00`34XGL0`j1f0<:OM@020<6NM00?0<2ML`31WF/0`Yi/0<BPKP35XFl0aZ9`
0<FQK`34X6h0`im]0<JQM035X7<0a9mb0<>NL@31W6l0`9]^0080_iY]00H0`Ie]0<2LK02oVf/0_YYZ
0;fIJ@2lV6P20;^GI`0;0;VDJ02jUFT0^iIZ0;bGJ`2kUVX0^IAX0;NBIP2eT6@0^IEQ0;RDH02gTel0
0P2eTEd00`2gTel0^9AP0;VEH@080;RDH0<0]iEU0`2fU6@30;FCH`80]IAO0180]9=N0;>BG@2bTE`0
/Y5L0;6@F`2`SeX0]Y9N0;>?F`2aSET0/XiJ0;JBGP2hU600]Y9N0;>?F`2fTed0]I9L0;:?F@2aSUP2
0;2=E`030;6>F02bSeT0/i1J0080/i1J0P2bSeT30;6>F0030;JBGP2dT5`0/hmK0080/HeI00<0/XiJ
0;B@G02eTEd0202eTU`20;>?F`040;:>FP2aSET0/8aH0;2<F0H0[h]G102`S5P0202aSET0/XiJ0;:>
FP2aSET0[h]G0:b8E02YQE40Yh=?0`2/Qe8[ooooo`00:_ooool0102UNTD0YW]60:IkAP2VNdH30:Ml
A`040:QmB02WO4T0Yga90:MlB@<0Z7e:0P2YOT/00`2WOTX0Z7m;0:QoB`020:V0C0<0Z7m;0P2ZOd`2
0:^0C@80[85>0P2]PTl80:b2D0030:j5D@2]Q500[8=?0080Zh9>00<0[8=?0:f4D02^QE400P2[QEH2
0:b6E`80[HMH0P2^R5T0402_RE`0[XQI0:j8F@2]QeH0[8MC0:^6D@2[QTl0ZXE>0:b7DP2[QU40ZHA?
0:R3CP2VPD`0Y7m:0:=nB@2RODP20:9mB@80XGa8102PNdL01`2ONTH0W7I709afA`2KMDH0VWA509Qb
@`2GLD800P2FL4401P2BK3d0TF/l091Z>`2?JCX0SFLh08aV=`80RfDf0100S6Dl08]T>`2:HcX0RF8i
08MP=`26GcH0QEhe08AM=022GcL0PEhf081M=@1nFc<0O5Ta07YG;`1iERh0N5D]101lES4207]E<080
NU@_00P0NeP^07YG;@1jEbd0NEH/07YG;@1lFBl0OU/a081M<`80Qf0e00H0R68e08US=02;IC@0S6Lc
08eX=02>JC@2091Z>`04095[?02CKCh0U6ho09I`@@80Ug5200<0Ufdk09Q^?02JL3h00P2KLCl00`2J
L3h0V6hl09M]>`0809Q^?080Tfdn0P2BK3d3095[?004091Z>`2BKCT0TVdi099]>@80TF`h0`2@JcL0
0`2BIc`0TFHk091U>P02091U>P03099W?02CJ3d0U6Tn0080S6Hg0`2=IcP308iX>@80RfHi0`2:ICP3
08UT=`80SF8e00P0SV<f08mT=`2?I3L0SV<f08eR=@2<HC@0RF<d08YT=@@0RfDf00D0RV@e08US=029
Hc@0RV@e08]U=P0208eW>00308]U=P2:I3D0RF<d0080RfLg0`2:ISH408UU=@80S6Dl0`2;I3/308YS
>P80RUlb0`2;H3<308aQ=0P0RF<d2027Hc<808IP<@80RFDe0P2:ISH308]W=`0308aX>02?Jc/0Sf/k
00H0Sf/k00@0U6lk09=^>P2AK3P0SfXf0P2>JCD01@2?JSH0T6/g09=Z?02DJcd0Tfdn0080U71000<0
TW10091`?`2?Kch00`2DLT8209Ec@`<0UWA40`2HMd8209Mf@@<0UWE001P0SG5108a`@02:KSh0Qf/k
08AX>021ICD0Of<c07iR<P20HR`0Of@_07mU=01iHSH0Ke`d065A;@1FAbH0CT0S04@i9@10>2<0?CDR
03Tb800d;Qh0<2dN02d[700/:Qd202LY7P<0:2XO00<09bTN02DW700T9Q/0200R8a/01P0O8QL082<H
020S600Q91T08RDJ02<V6`8092LL00H0:BdN02L[7@0T:1X08B@I01lR6@0N8AX201lQ70807b8K0P0N
8AX201dP6@<071lH01d06R@L01`S700L8a/07B<I024T6@0T9QT09bLK02PY6`0d<Ah0=C8O03Td800l
=R00?cLP04<i8015>B40ACTO04@i7@17>b40B3hU048j9@0h<Al0<2XL02XV6P0Z9Q/0;2DK02hW7@0`
:Qh0<bdO03@^7P0203@_700303<^6P0a:ad0<B/M0080<R`N00@0<B/M02lY6`0]9aT0:bDG0`0U9A/3
02HV70809bLM200V:1d302@U7@808b@L0`0R8a/0800J81`07RDN02@W7P0W:A/0:bXF038]5`0j=1X0
@S/N05]4901QBRP0J50/06YA:@1ZCb@0Ke<T07]L;@24IS@0R7A209MmC02SPTl0[HEB0;R@G@2fUF80
Vh5>07UU<`10?S40=S@X02XZ7P0V:1d0:BXR02T/9@0T:B<082DO200T9R<0200U9R009RLQ02PY8@0Y
:b00:bdP02d_8@0^<B00;c8Q200c;b<0200e<BD0=30T038^8P0a;B40<2`P034]8@0b;R80<blS0P0f
;200100g;B40>2hR03P^8P0i;b<203X`900?03`c8P0k<R40>c8Q03Xa800k<R40?3<R03dd8`0n=B@0
>C<S03Xc8`0j<b40?CDR044f9015>2D0BS/V0080C3dX0P1JAbL02@1KB2X0FdL/05U5;01G@b/0ED0[
05<n:@1;>RP0BCPV04Lf900204He8`0304Th9P1<>bT0CC`Z0080C3`S00<0CS`T054m9@1C?BH00P1F
?BL01@1H?BP0FD0R05]2901MA2H0H4LY00<0HDPZ00L0H4LY05e9<@1KAbl0ET@/0551:01>@2H0BclU
0080BT0U0100FD0Z05U1:@1J@RX0Fd<Y05e5:@1OB2T0HT/[06=<;01YBRh0J4X^06I8;01SB2/0H4LY
05e69`1JABH0FD@U0P1E@BT00`1B@2P0D40W04i09P0204a09P0704]19P1<>R80Bc/T04Xj8`17>2<0
A3LT044f900203he900403dg:@0l=RP0>S@V03Pb9080=c4S00<0>38T03Tc9@0j=2H00P0j=2H203Tc
9@<0>38T00<0>38V03La9@0f<2@00P0f<2@08@0g<BD0>C<W03Tc9`0m;b@0?S0U03lc9`0o=BT0?SHY
03`f:00i=RL0>3DV03Ta900j<RD0>S@V03Tf9`0h=RL0=CHV03<d900a=2<0=bhW03D/9@0b:b<0;RXQ
02/X7`0Y:Al0:RXP02T[800^:Qh0;b/O034]8@0c;b<0=30T03Da9@0203@`90P0=BlS0P0f;2<02`0g
;B<0>2hR03P_800i<1l0>S4P03Xb7`0n<B40@3<S048e9015>2D0B3`V0080BCdU00L0BShT04/o9@1;
?bD0BclU04a09P1=@BL0CT8X0080Cd<Y00D0D4@Z04/o9`1:?RH0BCdU04Pl900404Lk8`08044f9013
=R<0A3LT04Pi901;>b@0CS`T054m901B?RD205a4:P0D05a4:01MARL0H4TY06=<:P1VCbd0J58]05e<
<01MBBh0FTLY05Y59P1LABD0H4PV06A::@1VC2T0ME/Z07IK;01hGBh0NUlb07YO=01jGSH207QL=@0X
07EP<`1eH3D0MElh07AN>@1bFc/0L5Pl06iF?P1/E3`0KeLk071I>P1aF3X0Ke@f06iA<@1aDc40N5Ld
07iM>P21HS@0QfPj08ea@@2AMd@0TW]509J1B02MRU00Xi1E0:2AIP2OSV<0VhYN09J4EP2BODh0SWQ9
08]c@`2:LT80WWDm0:1g?`2UOD80ZX950:j6B02aRTT0/X]:0;><B@80/XU701@0/hY80;F<BP2hSdd0
^i9@0;jED`30UeD0^iEF0;ZDE@2iTE<0]hi@0;R<C`2hRTh0]hU=0;V8C@2gRd80^He60;fABP32UE40
aYUF0<RKFP80bI]M00H0aYeK0<FLFP34VeT0`iYH0<:IE`33VUP20<BKF@080<RKFP39W5T0biiK0<bO
F`3<X5T0c:1G0<^OE03:WU<20<FIF00>0<:IE`30VEH0_IQD0;ZGD`2iUU80]iIA0;NABP2hTT/0^I9=
0;VBC`2hTE00]hmA0;B<CP2cRdh20;N@B`030;J?BP2eSTT0]8e80080/ha700P0/X]60;>?D@2dTE40
]95A0;JCD`2iUU@0^iQD0;^IDP80^iUA0P2lUTl00`2lUE00_9EB0;bEE0020;bDEP050;bDE`2lVUX0
_I]K0;nMG@31Wel00`32X6002@31Wel0`j1L0;nLFP2hUE<0/8e=0:V5A`2TP4@0XGe30:1l@P020:V2
A`040:R4B02WQDP0Z8I90:J6B@80YXQ:0`2[RTD30:b;AP80[Ha700h0ZH]30:R:@P2WRD<0YhQ50:V:
B@2]STh0/I5D0;>CEP2aTU40/Y=B0;>DD`2eUUD0]iQG0;RIF080^Y]J00P0_:9W0;^QIP2cVF00Z8eF
0:J;EP2/T5h0ZhmM0:F9F@D0ZHiG0`2XSEH30:N<E@80YX]D102URU<30:B9DP<0XhQA00<0XXM@0:>8
D@2SR5400P2TRE820:F:D`80YX]D0P2[SU@0502/SeL0[Y1J0;6CG`2fV6H0^YaZ0;bMKP31XFh0a:Ac
0<RYNP3:[H40c[::0<neT03@]Y<0d;RF0<ngT`3>]Y80cKFA0<bdT03;/hl0bK6=0P38/8`06P35YhD0
_Z5i0;NKJ@2eVf80^9iU0;jRL033YWh0aJN50<N]RP37[H`0b;2>0<^dU03=^9T0d[nQ0=O3Z03Haj/0
g/Zb0>3;]P3QckT0i=>o0>GF``3TelH0iMS80>?Ga`3Ue<00i]G10P3WeKl0=@3YeKd0jM>k0>S@]P3V
c[@0iL^`0>O?[@3WcJ`0i<ZW0>;6X@3P`Y`0g[jG0=fkU@3K^Y40f[F90=VdR03G/XD0e;200=2/NP3=
ZGD0bjMc0<ZWL@34XVD0a:1T0<6MH@2oV5d0_9AI0;V?E@2hRe80]XU@0:n3A02^PT<0ZX530:Em@02P
NCh0VGDk09Ia>P2CL3P0SFPc08aW<`2:IC40Qf4`08AN;`21Fbh0OeP]07iG;01oFRd0O5X]07]I;01h
Eb`0MED/075D;01_Db`0KU8[0080Le@X00<0LU8Y079B:`1bDR`00P1bDBh0101bDC00J4XX06Q::01X
BRP206M99`<0ITPV00<0IDPX06M::P1YC2`00P1ZCBd01P1YC2`0IdXZ06E8:01YBbL0JT`X06a>:P80
KDl[00<0K4hZ06]=:@1ZC2P00P1YBbL0101XBRH0IdTU06I8901VB2@206E78`@0I4LU0P1UB2H206I9
9`0406Y=9@1[CRH0JdhV06]>9P<0K4lW00<0KE0X079?:@1bCbT01P1bCbT0101_DRX0KU4Y06iA:@1^
DBT306e@:00406a?9`1aD2d0LE0]075@;@80L4l/0`1_CR/3071@9`80LE4X0`1bDRT207EB;0<0M54[
00H0ME8/07MD;P1hEBl0MeH[07UH;@1lGC4207aO<`0407aQ=01iHC<0Mela07EO<0<0PEla0P22H383
08=Q<`<0Pel_0P24H30308EQ<@80QV0c0P27HC@01@28HSD0RF<f08YT=`2:I3L0S6Hg00<0SFLh0P2>
J3T208mY>PP0TVhn0P2>KcT0102>KCP0T6`h091/>02@JcL2099Z=`80SfTl0P2@JSd0102AJch0TV`o
09=]@02CKD0308mY>P80SVPi0`2=IcP2095X>P04091Z>`2@K3`0TFdm091^?P80T70o01<0TVhj09=_
>`2DL3`0UG4m09Mc?`2HM400VGE109Yf@P2LN4P0WGU909ijBP2ONd/0XGe=0:9nCP2SOdl0Y81@0:=o
B`2TP4`0YH5=0080YX9>00<0YH5=0:B0C02SOd/00`2TP4`20:=oB`<0XWi:0`2QODd20:1lC0<0Wg];
00H0X7]709mjAP2ONTH0WWU509ehA02LMd<209]f@P0509Ye@@2KMT80VgI209ag@`2MN4@00P2NNDD0
0`2ONTH0WWU409eh@`0209ag@P0809eh@`2ONTD0XGa70:=nB@2PNd@0XGa50:=nA`2UP4T40:N2B`04
0:Z6EP2[QeL0[8QH0:f9F@80[XYJ00<0/8aL0;6=G@2aSEd00P2aSE/00`2aSEd0/XeP0;:=H@020;>>
I0040;>=IP2dTV@0]99T0;BBI080]I=U0`2fU6H30;RHK`<0^IU`0P2jVW480;^HKPP0_ie_0P31WW@2
0<2ML`@0_iab00@0_imf0<2PM`30X7L0`:1g0P31XGP20<:RN@040<JSN@35XWP0aJ9h0<FRN0<0a:5g
00@0`j1f0<FRN035XWP0aZ=i0P37Y7X00`38YG/0bJIl0<VVO0020<ZZP`80bj^40`3<[8D40<f]QP80
cZj70`3?[hP30=:aSP80dk:?0`3D/i020=6cS`<0d[B@0`3C]I480=BgS`P0eKBA0P3B/Hh20=6`S@<0
d:n<00T0cjj;0=6aR03@/8L0cjn60<j^Q@3<[8<0bj^20<ZZP@39ZH00203:ZX<01@3<[8<0bj^20<^[
PP3:ZX40bJV00080b:Qo0P37Ygh04038Z7l0ajMn0<JVO@35YG`0aZIm0<NWOP39ZH00bZZ10<^[Q@3:
ZX@0b:R10<NWOP36Yg/0aJIh0<JWN@36YgP30<RUN`<0bJIl1P3:Ygd20<VVO080b:Ek2039YW`80<NT
NP80ajEg00<0aZAf0<FSM@35XgD00`35XgD80<RSMP<0aZ5d0P35X7<30<BOLP80`iia0P34Wg830<FP
L`040<JQM035XgD0a:9d0<>QL`80`Z1b00<0`j5c0<BRM035XgD00P35XWP20<BQM`070<>PMP32WgD0
`Iid0<6NM031WFd0`im_0<BPL0030<JRLP080<FQL@34X700aZ5d0<JQM035X7<0`iia0<:ML030Vfh2
0;nJK@060;nKJ`2nVVX0_YYZ0;fIJ@2lV6P0^iMW0P2jUVH0102hTfH0^IAW0;ZEJ02kUVT20;ZEJ005
0;VDI`2hTfH0^iMS0;VEH@2hU6000P2gTel00`2hU600^IEQ0;^GH`080;VEH@80^9IV0P2gUFD40;JD
I0050;FCH`2fUF00]YEP0;FDG`2dTeh00P2cTUd20;:AG00<0;JBGP2cSe/0/HeI0;>?F`2gTel0^IEQ
0;JBGP2cSe/0]iAN0;JCG@2dTE/0/XmI102aSUP0102dTE/0/i1J0;>@FP2cT5X20;:?F@80/HiH00<0
]I5M0;B@G02cSe/00P2bSUX00`2cSe/0]91L0;FAG@080;FBG080]91L00<0/hmK0;:>FP2aSET00P2`
S5P00`2_ReL0/HeI0;6=F@030;2<F0@0[h]G00L0/8aH0;6=F@2aSET0/8aH0:j:EP2/R5@0ZXIB00<0
[8MB:oooool002[ooooo102VNdH40:MlA`<0Yga90`2XODX20:UnB`080:ImB@2WOTX0Z7m;0:V0C02Z
PDd0ZH1<0:QoB`2WOTX20:YoC080Zh1=0P2/PDh20:f2C`P0[89@00<0[XEA0:f4D02[PTh00P2ZPDd0
0`2[PTh0[HA@0:j5D@020:^5E080[8IE0P2]QeH20:j8E`080;2:G@2_REX0[XQI0:f7EP2/Qe<0ZhIA
0:Z5CP2YQ4d20:^6D@060:Z5D02XPdh0YX5<0:F0B`2TOdX0Xgi90P2RODT20:5lB080X7]70P2ONTH0
2@2NNDD0WWQ909egB02LMTL0VWA509UcA02GLD80UW1109E_@002099/?@04095[?02?JCX0SVPi08aV
=`80RfDf0100SFHm08aU?02;I3/0RV<j08QQ>027H3L0QUlf08EN=@22GcL0PEhf081M=@1nFc<0OEXb
07]H<01jEbl0NEH^1P1lERl207]E;P0807]H;P1jEbd0NEH/07UF;01jEbd0O5T_07iK<@20GC<208QQ
=P0608US=P2:I3D0RfDd08aW<`2=J3@0SFPc0P2@JS/0102AJc`0Tfdn09A^?`2FL44209Ma@P0309M]
>`2HKS`0VW0n0080Vg4o00<0VW0n09Q^?02GKC/0202HKS`309=]?P80TV`m0`2AJc`3099]>@80TF`h
0`2@JcL3091U>080TFHi00<0TfPk09AY?02DJC`01P2=IcP208iX>@80RfHi0`2:ICP308UT=`D0SV<f
0P2=HSD00`2<HC@0RF<d08YT=@0508YT=@80RF<d00L0RV@e08]U=P2=IcP0SFLh08]U=P2:I3D0RF<d
0080RfLg0`2:ISH408UU=@80S6Dj0`2;I3T308YS>00508QM<029GS40REha08YO<P2;H3<00P2<HC@0
0`2=HSD0RF<d08US=00608US=0P0Qf<c2026H34308YV=P<0RfLg0P2<J3P808m[>`0509A`?02CKc/0
TFdi08iZ=P2=JCD00P2>JSH0102?JcL0U6/m09A[?@2CKCh209=_?`03095_?`2@L3l0T70o0080U792
0`2ELd<309IdA00409YiA02IN4<0VGQ309Uh@`80V7M20P2GMT40602=LD40S71008Y^?P27Jc/0QFTi
089V=P20I3@0Of<c081R;01oI2l0OF<b07MP=01]FS80H50/05E69@1>@2<0A3TU040h8`0m=B80>34O
03<]7@0_;1d0;B/L02`Z7@@09bTN0P0V:1d202DW70P08R<K0P0P8aP00`0Q91T08RDJ02<V6`0202@W
700702DX7@0X;1d09RXL02@X6P0Q91T07b8I01hQ6P0201hP6`807b8K0P0N8AX201dP6@<071lH0240
72HN01`S700K8QX0728H01lR5`0S9AP0:2PL02X[7@0e<Ql0=S<P03Xe8@0n>280@3PQ04<i8014>200
@cLM04Dj7P17>b40AcdT044i900h<Al0;bTK02/W6`0[9a`0;BHL02hW7@0a:al0<bdO03D_7`0e<1d0
=2lL03@_6`0a:ad00`0b;1h01@0a:ad0;bTK02`V600[9AL08b<I008092@J00<09BDK02HV700W9ad0
0P0X:1h802HX7@<092DM0`0S91`2028S6`0P01/R6`0P9Ah09RPM02PY6@0]:aH0=BlG03lh7018?b80
GdPV06A>:@1YDB/0Je8Y06iC9P1dF2T0Of4_08MY=@2?MdL0VWi<0:N4CP2aR500^95J0:j>F`2>MTP0
K5T^03Pf:@0b<2@0:BTM02LY7P0Y:R80:B`U02DZ900R9b4802@V8`0802HW8@0W:280:2TQ02X/8@0/
;R40;S0R02lb8@0`<b8803@`900303Da9@0d<2@0<RhR00<0<2`P00P0<BdQ038^8P0e:al0=B/O03H/
800g;B40>BlS03X`9080>c4U100k<R4203`c8P80?C@S00L0>38R03Tb8P0j<b40?3@Q044f9016>BH0
Bc`W0080CChY0P1HB2L03P1HAbT0F4L[05I5:`1C@BT0D3hX04hl9P1=?2X0BSTW04Lf9014<b40AC@R
04Pg9@1<>bT0Cch/0P1<?2<02P1>?2@0DCdU05@n9`1G?RP0F3lY05Tn:@1J@B<0G4<U05i59`1PAbT3
0658:P050617:@1IAbl0ETH]05A4:`1A@BP0101>@2H05@1J@B/0Fd<[05a4;01MAB/0GdL[065::`1S
C2`0I4d]06Y;;`1XBRh0IdT]06A9;01QB2X0GdPY05a7:01KARL0F4@/05M3:`1C@BT0D40W04m19`02
04e19`0=04e3:01<>R@0BSXS04Th9017>2D0@cHU044e9@0n=BH0?C@U03hh:P0l=RP0>S@V03Pb9002
03H`8P80=c4S0P0j=2H303Tc9@<0>38T01d0=BlS03H`900f<2@0=S0T03La9@0h<RH0>C<W03Xd:00n
<2D0?c4V040d:00o=BT0?SHY03`f:00i=RL0>3DV03Ta900j<RD0>S@V03Tf9`0g=BH0=3DU038c8`0`
<b80=BhV03@]9@0_:b80;BTP02`X7`0202/X7`0702`Y800]:Ad0;RXN030/800a;B40<blS03@`9002
03Da9@P0=BlS0P0f;2<03@0g;B<0>2hR03P_800i<1l0>S4P03Xb7`0o<R80@3<S048e9015>2D0Ac/U
04Xn9P1;?bL0101<@2H204e19`80CT8X0P1?@bT01@1<@B/0BSlY04Pm9`15>R@0A3TS00<0@cPR00P0
@CHT048e8P14=b@0B3TT04/k901>?2@0DShU05<o9P80G4@Z0400G4@X05e69`1PBBT0Hd`Z06M@;P1Y
Dbh0FTT]05Y6:`1HABL0FD@U05a59@1QBBL0IT`[06Q>:`1dG2h0MEda07IN<P1fGC@0ME`d07AJ=@1b
F3D0LELd071J<@1`FS<0KeTb06iG=@1]ESH0K5Df06YB=P1ZDSP0K5@h06iG>01_ESP0KU<e06e@<01`
DS00N5Ld07iM>P20I3D0QFTj08]`@@2<M4@0SGM5091lB@2GPe00VXUE09R6GP2GQ5X0Th1E095lC`2=
MdH0S7E308ab?`2;LS`0X7Xl0:9l?P2WPD80[8I70;6;C02dSTd0]Hm>0;J@C`2eSDP0]8a70P2cRdH0
102eSDP0^I5<0;fED030V5<20;fDE0030;jBD`2mTE80_91A00<0_8i@00H0_YA<0<2ED034VE@0aiaH
0<ZNG@3<X6420<bPH`040<ZSHP39XV40bJ9Q0<VRH@80b:5P0P39XV40203<X6<0cZ9S0<nSI03@Y6<0
dJIR0=2UH03>Y5`0cJ=K0P35W5`01033W5/0`Y]J0<6JF@2oVEP20;jHE`80_IM@00L0_YMB0;jGE02l
UE@0^Y9D0;N?D@2fSU40^I9=0080^95<00<0]i1;0;J?BP2eSTT00P2dSDP02@2eTU00]95?0;BAC`2d
TDl0]95=0;JCC`2iUU80^iUB0;fKE0020<BOF@040<>NFP32W5/0`I]L0<2JF`80_iUK01P0_9YJ0;fK
F`2nW5`0`ImO0<:PH034XV80aJ=S0<JTI03<ZFD0b:EQ0<6NG02hUE<0[ha<0:R4AP2ROT80Wg/o0:J0
@P2WPD<0YX940:J4A@2XQTL0YhQ80:N9B@2XRTX20:V8@`0F0:Z9A02[RTD0[8]60:f<A`2^SDP0[hi9
0:b>AP2[SDD0ZXa60:Z;B02/SD`0[Xm?0;6AE02cTeH0/Y=B0;>DD`2dUE@0]IIE0;NHE`2hVEP0^IYI
0;ZKFP80_Z5W00<0]iYR0:Z?F02WS5L00P2ZT5d00`2RReT0ZXmH0:Z?F0040:V>E`@0Z8eF0P2WS5D2
0:J;E0P0YHYC0P2TRE820:F:D`80YX]D00@0YhaE0:R=EP2YSUL0ZHiG0P2_TUX03P2`TU`0/YAP0;FG
I@2jVf`0_Ym`0<2QL`36YWL0b:Mj0<b]P@3>/HL0dKF=0=6gTP3B^9D0d[ZF0P3?]i<07P3>]Y80c;B@
0<^cS`3:/Xh0bK6=0<R`S035YhD0`:=k0;ZNK02fW6<0^9iU0;fQK`33YWh0aZR60<R/Q`39[8X0bJn<
0<^cT@3>]iL0d[fN0=K1Y03HaJL0gLV`0=o;/`3QckL0hm>l0>CE`03Se/<0i=O60>;Ga@80i]O40P3X
el<0=@3Zf<80jmNo0>[D_03Zd[X0jM6g0>WB/`3XdK40ilj_0>G;ZP3TajD0hLFP0=o1V`3P`9X0gkfG
0=jmU03L^i80fKR=0=JeR03D]8D0d[:10=6aP03=[7L0cZYf0<^WL`39Y6l0aim[0<FLIP33V6<0`YMP
0;ZAC`2iT4h0]Xm<0;><B@2^QdH0Z8910:=m?02PNST0VG8k09M`>@2EKCT0TVXf08iV<`2;Hc80R5la
08MN<026H340QEl`089M<020Fbl0NeP^07QG;01eEB`0M5@]0080MeHY00<0N5L/07QG;P1hES000P1h
ES400`1hES<0L50Z071@:P0206m?:@<0KThX00@0KDdW06U<:P1[CR`0KE0^0P1_DS001P1/Cbd0JD`Z
06M::01_CbT0L50Z075A:`80LU8/00<0L50Z06i>:01]CBL00P1^CRP206e=9`0406a<9P1[BbD0Jd/U
06];9@P0J4`W0P1^CRL606m?:0<0M54Y0`1eDRX207IC:`@0Le<Z101bDRT307AD;P80Le<]0`1bDR`3
07=B:@80M5<Z0`1eE2/507MD;00607QE;@1iERh0NEH^07]H;P1mFS00Oehc0P20HCD01@1oHSH0OF8e
07aQ=01iHC<0Q68d00L0QF<e0P24H30208EQ<@@0QV8b0P26H3400`27HC80R68c08US=00208YT=@04
08]U=P2>J3T0SVPi08iX>@80SfTj0`2@JS/409A`@0@0UG510P2@LC/03P2@KcX0TVhj095]>@2BKCT0
U6`i09=[>02?JCX0T6Xk095[?02BK3d0Tfdn09A^?`2EKd00UW110`2BK3d2095[?0<0T6Xk0P2DJcd0
1P2CKCh0Tflo09A`@02CLD40TW9109=c@P80UG4m0140UW8n09Mc?`2HM400VGE109Yf@P2KMd<0WGU9
09ijBP2ONd/0X7a<0:9nCP2SOdl0Y81@0:F1D@2TP4`0YH5=0:N3C`020:R4D0030:N3C`2UPDd0Y81<
0080YX9>0P2UPDd30:B0C0030:=oB`2SOdl0Xgm?00<0XWi>0`2QODd20:9mB@030:5lB02PNdL0WgY6
0080WWU500L0WGQ409]f@P2LMd<0WGQ409iiA@2ONTH0XGa80080XWe90P2PNdH01P2ONTD0WWU409mj
A@2PNdH0XWe80:AoBP80Xgi900<0Y7m:0:J1C02WPTd00`2XPdh20:b8F0050:f9F@2_Re/0/8aL0;2<
G02bSUh00P2cSel20;>?G@030;B@H02dSf80]I1T0080]I1V00<0]HmX0;JDI`2fU6L00P2gUFP40;RF
J@040;VIL02jVW40^YYa0;ZJL@80^i]b0P2lW7<80;jKL@P0`9i`0`33X7H50<:OM@<0`j=j0P34Y7/3
0<FUO0T0b:Ek0P39YW`00`3:Ygd0bjQn0<bYO`020<fZP0<0cJf60P3>[XL40<n_R0<0d;290P3A/HX2
0=:bR`<0e;>@0`3E]9420=JeTP<0dkFA0P3D]Y830=FgT`P0eKNA203F]I820=>bS`80d[6>0`3A/8d0
1P3@[h`0d;270<n_QP3?[hH0cZj50<b/P`80bj^200<0bZZ10<VYPP39ZH801P39ZH820<^[PP80bZZ1
00<0bJV00<RXO`38Z7l00P38Z7l03@37Ygh0aZIm0<FUO034Y7/0aJEl0<JVO@38Z7l0bJV00<^[Q@3:
ZX@0bJV20<RXO`37Z7`00P36YgT01036YgP0b:Ek0<RUN`38YG/30<VVO0P0bZMm0P39YW`80<ZWO@P0
b:Ek00H0bJMi0<RVN036Y7H0aJ=e0<BRM035XgD20<JTMPP0b:=f0P37XWD20<JQM080aJ1c1034Wg82
0<FPL`@0aZ5d1@34XW@20<FSM@070<JTMP36XgT0aZ=i0<FRN034XGL0`j1f0<:OM@020<6NM0030<:M
L034Wg80aJ1c00<0aj9e00X0aZ5d0<FPL`37XWD0aZ5d0<FPL`34Wg80`Ye`0<6LK`30Vfh0_iY]0P2m
VFT20;bHJ0040;^GI`2jUVH0^YIV0;ZFIP80^9AT0P2iUFD40;ZFIP030;bHI02kUf<0^IEQ0080^9AP
00<0^IEQ0;^GH`2lV6@0202iUF430;RFIP80]iEU102fU6@01P2hUf80]iIQ0;NFH@2fUF00]IAO0;BC
GP80/i9M00d0]i=O0;B@G02aSET0/hmK0;NCG`2iUF40]i=O0;B@G02hUEl0]iAN0;JCG@2dTE/0/i1J
0080/HiH00<0/8eG0;BAF`2dTE/00`2cT5X30;:?F@040;B@G02cSe/0/hmK0;>?F`80]91L0P2eTEd8
0;JCG@80]I5M00@0]91L0;>?F`2bSUX0/HeI0P2`S5P01P2cSe/0/XiJ0;:>FP2aSET0/8aH0:n;E`<0
[XYF00L0[h]G0;2<F02aSET0/HeI0:n;E`2^RUH0[HUE00<0[HQC:oooool002[ooooo102WO4L40:Ik
AP<0Yga90`2XODX20:UnB`080:AkA`2VODT0Z7m;0:Z1C@2[PTh0ZX5=0:QoB`2WOTX20:YoC080Zh1=
0P2/PDh20:f2C`P0[89@00<0[HA@0:b3C`2[PTh00P2ZPDd00`2[PTh0[8=?0:f4D0020:^6DP80[8MC
0P2]R5@20:j9E@080;2:G@2_REX0[XQI0:f7EP2/Qe<0ZhIA0:Z5CP2YQ4d20:^6D@0:0:Z5D02XPdh0
Yh9=0:J1C02UP4/0Y7m:0:=nBP2RODT0XGa80:1kA`80WgY601/0WWU509ehA02MN4@0WgU:09ihB@2M
MdP0VgE609UcA02GLD80UW1109E_@02DKSl0Tfdn099/?@2AJc`0SfTj08iX>@2=IcP0S6Hg08iW?P2=
ISd0S6Dl08]T>`29HST0R64h08MP=`26GcH00P21GSH01020GCD0Oe`d07eJ<P1lFC4207]H<0H0O5L]
0P1mF2h0201lFBl0NeP^07YG;@1jEbd0NeP^07eJ<01oG380PEhd0P29HSL01P2:I3L0RfDf08]U=02<
Ic<0SFPd08eX<`80T6Xk00@0TF/l09=]?P2DKSl0UW110P2GLD800`2GKC/0V6hl09Y`?P0209]a?`03
09Y`?P2HKS`0Ufdk00P0V6hl0P2DKSl209=]?P80TV`m0P2AJc`3099]>@80TF`h0`2@JcL208mU=@03
091V=P2BJ3P0TVPh00<0TfTi0P2>J3T608eW>080RfHi0`2:ICP308UT=`04091U>02?I3L0SV<f08iS
=P@0SF8e00<0RV@e08US=029Hc@01029Hc@0102:I3D0RF<d08YT=@2;ICH208eW>00308]U=P2:I3D0
RF<d0080RfLg0`2:ISH408UU=@80S6Hi0`2;ICP308YT=`80REha0P2:Gc80102;H3<0S64d08eR=@2=
HSD808YT=@P0R6@d2027HC8208YV=P<0RfLg0`2<J3P808m[>`0409A`?02CKc/0TFdi08m[=`80SVXf
00D0Sf/g091/>02EK3h0UF`n09=]?P02099^?P03095_?`2ALD00TG5000<0UG=30`2FM4@209MeA@80
VWU40`2IN4<309Qg@P0H08ib@P2=LD40Rflo08Q/?025JCT0PVHf081T=01oHc<0PF<]07mT;`1mHc80
MUlc06aI<@1OCb/0EDHU04m19014>BD0@3PS03`d8@0f;ad0<R`L02h[700/:Q/0;2XM0P0W:Ah202HX
7@@09BLL200R8a/01P0P8aP08B@I024T6@0R9AX08bHK02@W70809BPM00H0:2`M02HZ700S9aT082<H
01hQ600N8AX201hP6`807b8K0P0N8AX201dP6@<071lH01d072HN01`S700K8QX0728H01lR5`0S9AP0
:2PL02X[7@0d<Ah0=S<P03/f8P0o>B<0@SXS04@j8@14>200@cLM04Hk7`18?280AcdT040h8`0g<1h0
;bTK02/W6`0/:1d0;BHL02lX7P0a:al0=2hP03D_7`0203D`7@0:03@_6`0b;1h0<R`N03<]7`0b;1h0
<B/M02hX6P0/9QP0:R@F02<S6@8092@J00<09BDK02HV700W9ad00P0X:1h802HX7@809BHN0`0T9Ad3
02<T700P01dR6`0S9Qd09bTL02/Z600`:aD0>34G04@k7P1=@R@0HddX06E?:P1YDRT0K5@X071E9P1h
G2`0PfDa08Y/>02EN4`0WGe:0:V5B`2dS4l0^95F0:N9E@21K440Gdl[03<a900`;R80:RXN02T[800Z
:b<0:RdV02H[9@0T:B<802@V8`0802HW8@0W:280:2TQ02X/8@0/;R40;S0R02lb8@0`<b8903@`9007
03<_8`0a;B40<2`P02l[7`0`;200<BdQ038^8P0203D[7`0403H/800g;B40>BlS03X`9080>c4U00<0
>S4P03/b8@0k<R400P0l<b8303dd8`0703Pb8P0i<R80>S<Q03`d8@11=R@0ASTV04/l9`0204dn:@80
E4@S01`0ED@V05A39`1B@BL0CcdU04dk9@1;>B<0CC`Z04Xi9`17=R@0A3<Q04Dd8P18=bD0C3/Y04ln
;01<?2<0CCdT04lm9@1B?RH0EClX05Po:@1I@2X0Fd0[05a39@1MA2H0GdHX0658:P1RBB/0HDPZ0P1P
AbT0101FB2h0E4H/0594:P1@@RP305109`070590:01J@B/0Fd<[05a4;01OAbd0H4P/069;;00206=<
;00F06Y;;`1XBRh0IdT]06A9;01RBB/0H4TZ05e8:@1LAbP0FDD]05Q4;01C@BT0D40W04do9@1<@2H0
CD4W04e3:01;>BD0BSTU04Th9P16=RH0@cHV040d9P80?C<W00@0?SPZ03`f:00i<bD0=c4S0`0f<280
100g<B<0>C<U03Tc9@0i<bD303Pb9080=c4S0P0e;b<00`0f<2@0=c4U03Pb9P0303Tc9`0C03la9P10
<RL0@3@X03le:@0n=RT0?3HX03Pe9P0g=2D0>C4T03Xb9@0j=2H0>3DV03Le9P0c=2@0<C8R02lb8@0a
;RD0<2dT02h[8P0302dY8003030Y8@0a:R80;b/O0080;b/O00D0<2`P034]8@0c;b<0=30T03Da9@08
03D_8`80=R`S00h0=bdS03P^8P0h;b00>C0O03Xa800j<Ql0@3<S044d9012=B@0A3LT04Hj9018?2@0
BShV04/o9@D0C40V101=@BL0101:@Rd0B40[04@l9`11>B@303lg8P09040h8`10=B<0@SDR04@g9018
>B@0C3`U04lm9@1C?bH0E40W0080G4@Z01`0G4@X05e69`1OB2P0HT/Y06E>;01WDB`0FdX^05]7;01J
AbT0FdHW05m8:01TC2X0JU0_06eC<01aFS00LEXa079K<P1bFS@0LETe06mG=@1/Dc@0Je8c06aF<@1[
EC00JU<a06UB<01YDS80J54a0P1XDC808P1YDCD0Je@e06eD=P1/DC<0K4l_06mA;`1hEc@0OUdj07iS
=P23J3/0QVi008Qb@`27LTD0R7I808ekC@2AP580T7aG091jD`2=N4d0S7I708]d@P2=M3h0SW@k08me
>P2ROc/0YH8n0:V6A02^RdT0/Xm=0;FBDP2fTe<0]iAD0;J>B02eSDL20;B<AP060;J>B02iTD/0_IE?
0<2HDP34U5@0aIEE0`33UUD20<:FE@0:0<6EE033VeD0aIeH0<RPF`3;XV00cJAT0<jUI`3>Y6P0cJ=W
0<bVI`80cJMX0`3>Z6T20<fWJ0090<nUJ`3@YVX0dJQZ0=:YJ`3BZFT0dJQV0<nWHP3>YV40`ieN0080
`YaM00h0`YYL0<6IF`30V5X0`IQJ0<2GF@31Ve@0`YaE0<:KEP32VeP0`IYI0;jFF02lU5H0^Y9E0;bE
D080^iA?00<0^Y=>0;VBC@2hTD`00P2gT4/02@2eTd`0/i5:0;>ABP2`SDT0[ha80;2=B@2cT4h0]iAB
0;ZGE@020;nLF00N0;jKF@2lVEL0^YMG0;VEE`2hU5P0]i=G0;VGE`2jV5P0_9YJ0;jLG031Wel0a:9R
0<JTI038YVH0dJmX0<j/I@38YF40`9eK0;NDE02^Rd/0Yh=50:=o@@2SOCh0Y7ho0:B1@@2VQ4@0ZHM7
0:Z;BP2[ST`0[8m=0P2YR4<07P2[RTD0[8]60:f<A`2_STT0/8m:0;6@B`2bU4`0/I=;0;2BC02_T4d0
[Xm>0:n@D02_Se80/91C0;BEE02eUUD0]YMF0;NHE`2hVEP0^IYI0;ZKFP2kW5/0`:1W0<>SJP2mWVL0
/99L0:R?F@2XTEd0Yi9M0:>=F`80Zi1I0P2ZSeP20:V>E`D0Z8eF0P2WS5D90:J;E080YhaE00H0YX]D
0:N<E@2XSEH0ZHiG0:Z?F02[T5T20:bAFP80/iEO00/0]9IR0;JHIP2jVf`0_Yma0<:SM@34YGT0bZV0
0<b[PP3?[hP0dKB<0=>gT0020=>iU0070=:jU03@^9@0ckNC0<jfTP3=]I40c;B@0<ZbSP020<VaS@0J
0<BVQ031Y7`0_:1^0;RNI@2gWF@0^im]0<:UO@37ZHL0bJ^50<Z/R03:[H/0bk6>0<jfU03B^i/0el2Q
0=O2X`3Lb:d0g/Za0>3?]@3Rd[T0hmBm0>;F`03Se/<0h]O30>CGaP3Uf<L20>SIaP0C0>[Ia@3[fL<0
k=S00>_E_P3Ze;`0i]:g0>GB]03Ud;<0i<f^0>?:Z`3QajH0glFR0>33X@3O`Il0g/2L0=foV`3K_IL0
fKbD0=NjT0020=FhS00G0=BcR03D/HL0djj20=6]O@3?ZGP0cZIc0<fTL03;XV`0`ieL0<:LF`31VeX0
_iQG0;ZCD02dSDX0/8M50:f4@P2TO440Xg]00:1g?`2LLcd0V6lk09A[=`2AIcD00P2?IC<01`2>I380
Rf<b08IP<@22GC00P5/_07]I;01jEbd00P1lFR`00`1lFRd0NeP^07]H<00207]H<P0407]G<`1gERd0
MeH]07MF;@80MUD/0`1eE2/0401]CbT0KU0Z071B;01aDbd0L58/06i@:P1/CRP0JT`V075?:@1bD2X0
Le4[07AB;01cDB/0LU0Z071>:01_CBL307=A:`<0LU0Z0P1aCbT706i@:P0306e?:@1cDB/0LU0Z00H0
LU0Z0P1fDbT207MD:P0407QE:`1iER`0NEH/07UF;0P0MeH[0P1gEc0207IF;`<0MED^00<0M5@]07IC
:`1fDb/00P1gE2`307QE;@0507UF;P1hEB/0NEH/07UF;01jEbd0101kF2h00`20Fc40PE`b085N=002
085P=@04085R=P1oHSH0Of8f07iS=PH0QfDg0P26I3H408IR<P80Qf<c0P28I3@01P27HC00R68a08QR
<@29Hc80RV@c08]U=080S6He0P2?JCX2091Z>`<0TF/l00<0TV`m09Ea@@2ELD400P2FLT8209Mc@`80
V7A400H0TW<m095b?02BLC`0U70l09=_>`2DKc/209E]>P08095[>P2BK3/0Tfdl09A^?@2EKch0UW0o
09Ma@02HLT4209E_@080U6ho0`2CKCh02@2BK3d0UVdo09I]?`2EKd00UG5109Ib@P2ELd<0U7A309Ee
A00209Qd@080VGE100l0VWI209]g@`2KMd<0W7Q409ijBP2ONd/0X7a<0:5mC@2SOdl0Y81@0:F1D@2V
PU80YH5=0:J2CP2XQ5000P2YQE400`2XQ500YX9>0:F1C@030:N3C`80YX9>0`2UPDd20:F1D@80Y81@
102SOdl20:F0C0030:AoB`2SOTX0XWe90080XGa80100X7]709iiA@2NNDD0WgY60:5lB02RODT0Xgi:
0:AoB`2UP4`0Xgi90:9mB02QO4L0X7]60:5lA`2RODP0Y7m:102UP4/00`2VPD`0Yh9=0:R3CP020:V4
C`80[XYJ00D0[h]K0;6=G@2bSUh0/XiN0;B@H0020;FAH@80]Y9P00H0]Y9R0;JAI02gTVH0]i9X0;RC
J@2hTV/40;VFK080^YM]0P2kV6h20;^KLP80_9ac0`2mWG@00`2nWWD0`9ec0<2ML`060<2ML`P0`Z1b
1P35XWP20<JSN@<0aZIm0P37Ygh30<RXO`X0c:V100<0cJZ20<j[P`3?[8@00P3@[HD0103A[XH0d;29
0=2`R@3@/8T20=6aRPD0d[:;0P3C/h`30=BdS@030=FeSP3F]I80e[FB0080e[FB0P3G]Y<20=RgU0<0
eKNC0P3F^9@;0=NiU@P0f;ND00@0e;>@0=>bS`3C/Xl0dk:?0P3B/Hh20=6`S@80cjn600@0cZj50<f]
Q03=[H@0c:b30P3;Zh880<VYPP<0bZZ11@39ZH002@38Z7l0ajMn0<JVO@35YG`0a:Ak0<FUO036YWd0
b:Qo0<VYP0020<ZZQ0060<ZZP`39ZH00b:Um0<NXNP36YgT0aJIg0`38YG/30<VVO0P0bZMm0P3;Z7h8
0<ZWO@P0bJIl00<0bZQj0<RVN036Y7H00P34XW@00`35XgD0aZAf0<RVN0080<VTM`<0aj9e0P36XG@5
0<FPL`<0aZ5d0`37XWD00`33XG<0a:9d0<FSM@020<JTMP<0ajEg0P36XgT01035XWP0a:5g0<BQM`33
X7H20<:OM@030<>NLP34Wg<0aZ5e00<0b:=g00P0aj9f0<JQM@37XWD0aj9e0<JQM034Wg80`iia0<6L
K`80`9]^0`2lV6P40;^GI`040;ZFIP2iUF<0^IES0;RDHP80^IES0P2jUV@0102kUfD0_9QT0;^GH`2i
UF420;RDH0030;VEH@2kUf<0_9QT00P0^YIR0P2iUfL20;RFIP80]iEU0`2fU6@20;VHH`030;RGHP2g
UV40]YEP0080]IAO00T0]9=N0;NCG`2dT5`0/XiJ0;B@G02hU600^YIR0;NCG`2dT5`00`2gU5h01@2f
Ted0]I9L0;>@FP2bSeT0/HiH00<0]95K0`2cT5X20;:?F@030;:>FP2cSe/0]91L0080]I5M0`2fTUh8
0;NDGP80]Y9N00@0]I5M0;B@G02cSe/0/XiJ0P2aSET20;>?F`030;:>FP2aSET0/8aH0080[h]G00@0
[XYF0:f9E@2_ReL0/8aH0P2aSET00`2`S5P0[h]G0:j:EP030:j9E2_ooooo000Zooooo`040:QmB02W
O4L0Yga70:MlA`<0YW]600@0YGY50:MlB@2WO4T0Yga90`2XODX20:UnB`080:=jAP2UO4P0Z7m;0:^2
CP2/Pdl0Zh9>0:V0C02WOTX20:YoC080Zh1=0P2/PDh20:f2C`P0[89@00<0[HA@0:b3C`2ZPDd00P2Y
P4`00`2ZPDd0[8=?0:f4D0020:^6D@80[8MB0P2]R5<20:j9E0090:n9G02^R5T0[XQI0:f7EP2/Qe<0
ZhIA0:^6C`2ZQDh0ZhIA0080ZXE@00<0ZHA?0:R3CP2WPTd00P2VPD`0102SOTX0XWe90:5lB02PNdL2
09mjAP0A09ehA02LMd<0W7M309ihB@2MMdP0W7I709]eAP2JM4D0VG=409Qb@`2GLD80UW1109E_@02D
KSl0Tfdn099/?@2@JS/00P2?JCX0202?J3l0SVLn08eV?@2<IC`0RV<j08UR>@28HCP0Qf0g0P21GSH0
1020GCD0Oe`d07iK<`1mFS8207aI<@@0O5L]0P1mF2h207iI;`0807iK<@1mFS00O5T_07aI;`1mFS00
Oe`b085N=023H3H208YS>00608]U>02;ICH0S6He08aW<`2=J3@0SFPc0P2@JS/0102AJc`0Tfdn09A^
?`2FL44209Ma@P0309M]>`2HKS`0VW0n0080Vg4o00<0VW0n09Q^?02GKC/0202HKS`309A^?`80Tfdn
0`2BK3d3099]>@80TF`h0`2@JcL00`2?IC<0T6Hd095W=@0309=Y=`03099X=P2AIcD0SVPi0080SVPi
0`2=IcP208aV=`80RfHi0`2:ICP308UT=`04095V>@2@ICP0Sf@g08eR=@<0S64d00<0SF8e08YT=@29
Hc@01028HS<01@29Hc@0RV@e08US=02:I3D0RfDf0080SFLh00<0RfDf08YT=@29Hc@00P2;IcL308YV
=P@0RFDe0P2<ISL308]U=P<0RV@e00@0Rf0c08aQ=02<HC@0S64d102=HSD808YT=@P0R6@d2029Hc@0
102:ISH0RfLg08]W=`2;IcL208aX>080SFTi202?Jc/00`2@KcX0Sfhi08i]>00208e/=`0608i]>02@
KcX0TG0k09I]?`2EK3h0TV`m0P2AKCd00`2AKcl0TG50099b@@0309Ec@`80UWA40`2GMDD309Uh@`80
V7M20`2GMT406`2>LT80SG5108]_?`28K3`0QFTi08=W=`21ICD0P6@d08=U;`20IC00OV@c07IO<`1/
FC40H50/05M89`1@@RD0ACXV040h8`0k<b00=BhL034[6`0]:Q/0;2XK02d[7P0X:Ql09bTN02DW7003
02@V6`809BLL200R8a/2024T6@03028U6P0S9Q/092LL00809BPM00T09RTN02L[700U:A/08bLI020S
600N8AP07B0I01dO6P0N81/00P0O8Q/201hQ6P807B0I0`0L7aP0800J91`072<L01`S6`0M8aT08B@I
02@V6@0W9a/0:2TK03<`7@0e<Ql0>cHR040j9013>b@0AC/R04Di8@14>1h0AS/O04Pl8P17?B@0?cLR
03H_7@0_:A/0:bLK02`X7@0]9Q`0;bPN038/800d;R00=BlO03Ha7P0e<1d0=C0L0`0c;Al01@0b;1h0
<B/M02hX6P0[9AL0:B<E00<09BDK0`0V9Q`202LW7@P09RPM0`0U9Qh202@U7@<08b@L00P08B@K02@V
6`0X:A/0;BXG038/5P0m<aP0BChP05=69P80IU0Y01H0J54W06]C9@1bEbP0Nel]08EW<@2;KCL0VGY>
09imBP2[Q4T0]i1?0;NCE@2OQ4l0MV<k05A6:@0`;R40<2hR02d]8@0/;R<0;2dU02/^9`0W;2H09BXT
200T9R<0200W:280:2TS02TZ8P0[;B80;BlR02h`8P0`<b80<C@S200e<BD00`0d<2@0<blS034]8@03
02l[7`80<BdQ0P0f;200100g;B40>2hR03P^8P0i;b<203X`900303T`7`0j<B00?3<R00<0?C@S0P0l
<b801`0i<b<0>S<S03Xc8@0m=B80@CHT04Dh9@1:>bH00P1<?BP02`1@@B00DD8Q0593901A@RD0D40V
04hn9@1;>b@0BSXS04/j:019>2H0AcHT0080ASDS0240BCPV04`k:@1=?2X0C3`S04dm901??BD0DclW
05I0:@1J@B/0Fd8/05e2;@1MA2H0GTDW0617:@1QB2X0HTT[0658:P1PAbT0GdHX0557;01@AR/0Cd<Y
04m19`1@@2L0DClW05A0:01E@BT0F3lY05Y2:P1LA2`0GdL]0659;@1RBb`00P1RBb/06`1XBBd0IdT]
06I8;01SB2/0HDPZ05m8:@1MB2T0G4LX05Y6;P1G@b/0DT0X04hn9@1;?B<0BShT04a09P1<@RL0BcPW
04Th9P18=bL0ASHW048d9`10=2P0?C<W03`b:00l=RP0>S@V03Pb900303H`8P80=c4S0`0i<bD203Pb
90<0=c4S00D0=BlS03H`900g<BD0>38V03Tc9`0203Pb9P0J03La9@0o<BH0@38W040d:00o=BT0?SHY
03/e9`0g=2D0=S<T03Ta900j<RD0>S@V03Pe9P0f=2D0<S<S030a8@0^<B00;BlT02d]8`0/;280;BXQ
02l[8P0b:b<0=B`U03H]9P0a;B42030/800502l[7`0`;200<BdQ038^8P0c;b<0200d;R8203H/8`0>
03L]8`0h;R80>2lP03T`7`0j<B00>S8O048e9@11=2@0@C@S048e8P13=b40ACTQ04Lk8`19?B<204Xn
90L0BclU00@0BD4^04Hn:`12>RL0?cLT0P0m=B806P0o=b@0@3PU040e8`12=B80A3LT04Tj9@1=?BH0
D3hV05A09`1E@BP0G4@Z05]3:@1K@bL0Fd@U05e69P1OB2H0HDXX06==:01LBbl0GDT^05]8:P1LAbP0
HDXZ06I>;01[DC00KU@a0P1/ERl02@1]Ec80KEHd06aE=@1YDS<0Ie0a06I><P1YDS80J54a06M@;P03
06I?;@0R06M@;P1XDBl0IThb06QA<P1[DS@0JTla06]>;P1_DBl0N5Ld07iM>P1kHcD0OfLi089[?`23
KT<0P6e3081^AP24LTX0QWM@08]dDP29Ld`0RG9808Ua@`2<LSl0T7Hm09Eh?02HO3d0YhLn0:V9@02]
S4D0/I1;0;BCD02fU5@0]iEE0;RFE`<0^Y9:00X0_9A<0;jFCP30V500`i]C0<BLE03;V5L0c9UH0<bK
F@3=WE/0biiK0P3:We/03`38X5/0b:5L0<ZSGP3<YF80cZMV0<nWJ@3?YfX0cjM/0<jVJ`3=ZF/0cZY/
0<n[K@3@[6h0dJe_0=2/KP020<n[K@090<nVKP3@Yfl0dJU^0=:ZK@3BZV`0d:UX0<jWIP3=YV<0`9iO
0080`9aN00<0`I]M0<:JG@32V5`00P34Ue`02034WUL0aImH0<FNF@36We`0aIiM0<>KG@31VE/0_iMJ
0P2oV5<00`2nUe80_IIA0;bED0020;^DC`0b0;ZCCP2fU4`0]99:0;BBBP2aSdP0[X]70:j;B@2aSTh0
]95A0;JBE02dTdh0/i9?0;:ACP2`STh0[Xa=0:f;CP2/RDl0ZhQ>0;FCD`2fU5@0]iEE0;ZHF02nW5`0
`Z1P0<JTI038YVH0d[1X0=2^IP3=Zf@0ajAP0;nLFP2gU5@0[ha<0:Z6B02TOSl0YX110:J3@`2WQDD0
ZXQ80:^<B`2/Sdd0[Y5?0:^:A@2/RdH0[Ha70:j=B02_STT0/8m:0;6@B`2bTD`20;FGC`040;>EC`2b
Te00/I9A0;2AD@80/91C00H0]iQG0;RIF02hVEP0^IYI0;ZKFP2kW5/20;bMG0080<FPJ@38YFd0`j9/
0;FGH@2ZTE/0ZIAO0:RDG`2STUh20:bAFP040:^@F@2ZSeP0ZHiG0:V>E`80Z8eF00@0ZHiG0:R=EP2X
SEH0Z8eF0P2WS5D30:J;E0<0YhaE0`2XSEH02@2YSUL0Z8eF0:R=EP2YSUL0Zi1I0:bAFP2]TU/0[Y=L
0:nDG@020;NII@0>0;RJJ02jVf`0_Yma0<:SM`36Yg/0b:Qo0<f[R03?[HX0dK2=0=:dT03D^9<0dkVD
0=>jTP3B^i820=2hU00P0<ngT`3=]I40c;B@0<^cS`3:/Xh0bK6=0<BVQ033YWh0_Z9`0;VOIP2gWF@0
^Yi/0<:UO@38ZXP0bj^50<b/QP3;[HT0c:n=0<jdT@3B^YP0eKjN0=S1X@3LbJ/0gLV^0=o>/P3QdKL0
h]Bj0>;F_P3Re/00hMK00>;FaP3TelL20>KIb00=0>[Kb03[f/H0jmW30>cG`P3[ekl0iMFl0>CD^P3S
d[P0hlnd0>;=/03Sc:d0hLZZ0>78Z@020>74YP040>33X`3N`Il0gL2N0=^oVP80f[jG0200fkRH0=Zh
U@3I]Y00fK><0=JaQ03E[h00eJej0=B/N03:Yfl0bjI_0<^WK@3;Y6T0b:1S0<>JG02oTe@0_91A0;>:
C02aR4X0[XA80:Z0AP2UNT<0XGI109eb?@2KL3d0VV`h09U[=`2EJSL0TVPf08iV=@2:I3D0R68c08IQ
=080Q60`00H0Peha089M<@21G380P5Xc081J=@1oFC@207iK<@80OEX`0`1lFBl01P1kF2h0MUH]07IF
;@1eEB`0M5@[07=C:P80LU8Y00@0LE4X07AA:@1eDRX0MU<[0P1gE2`00`1fDb/0ME8Z07AA:@0707UF
;P0307QE;@1fERl0MUH_0080MUH_0P1eEBh207AD;@0407QE;`1gE2h0Me@^07MD;P<0MU<]00H0ME8/
07QE:`1hEB/0NEH/07YG;@1kF2h207aI;`0407eJ<01jEbd0NUL]07YG;@80NeP^0`1lFBl0101jFS40
NET`07UI<01iFC0207QH;`80MeL^00@0NU@]07]E;P1kEBh0NeD^0P1lERl207eG<00507YG;@1kF2h0
O5T_07eJ<01nFc400P1mFS00101lFBl0PU/b08=L<`23GS@2089O=@05089Q=P21HSH0PV<g081S=`29
IcT00`28ISP308MU=`0408IT=P27Hc<0Qf<c08MS<`80R6@d0`29ICD208YU<@0408]V<P2<Ic<0SFPd
08eX=080SVTe0`2AJc`2099/?@<0Tfdn0P2ELD400`2FLT80Ug=309QdA00209UeA@0409YfAP2CM3h0
Tg@n09Ac?P80UG4m00<0UW4m09M_?02GKc`00P2DKc/0102EL3`0UW4m09Mb?P2GLSh209Qc?`0409Qb
@`2GLD80Ug5209Ma@P80UW110P2EKd0209M^@00409I`@@2FLT80UW9209Ec@`80UGE40P2JMT8209]g
@`80W7Q40P2MNDD02`2ONd/0X7a<0:5mC@2ROTh0Y81@0:F1D@2VPU80Yh=C0:N3C`2XQ500ZHEA0080
ZXIB00@0ZHEA0:R4D02WPdl0ZHEA0`2XQ5020:N3C`80YX9>0P2WPe<20:J2DP80YH5A0P2TP5001P2X
Pdl0Yh9>0:N2CP2VPDd0YH1<0:AoB`80Xgi:00D0XGa80:9mB@2RODT0Xgi:0:AoB`020:F0C0040:J1
C@2VPD`0YH1;0:=nB@80XWe800D0Xgi90:F0B`2VPD`0Z8=?0:N2CP020:J1C@040:N2CP2XPdl0ZHA@
0:Z5D@80/8aL00L0/HeM0;>?G`2dT600]91P0;FAH@2fTV80]i=S0080^9AR00<0^9AT0;VDI`2iU6P0
0P2jUF/0102jU6d0^iQ`0;^HL02kV7020;bIL@<0_IYb0P2mWG@30;jNM@<0_imf2032WgD80<FSM@<0
ajAj0`38YG/20<VVO080bJV00P3:ZX430<^[PP030<b/P`3>ZhD0cjb60080cjb60`3@[HL0103A[XP0
d:f70=2]Q`3A[XP20=:_R@040=>`RP3D/H/0e;6;0=:bR`<0dk><0P3D]8d50=FeSP80e[J?0`3G]i02
0=NfT`80f;ND0P3I^9D20=ZiUP<0ekVE0`3H^YH20=VkU`P0fK^I203I^9D0103E]940e;>@0=BcT03D
/i020=>bS`80d[6>0`3>[XD20<f]Q0<0c:b3203:ZX<90<VYP0080<RXO`37Ygh0aZIm0<FUO036YWd0
ajMn0<VYP03:ZX420<ZZQ0060<^[Q03:ZX40bJYn0<RYN`36YgT0aJIg0`38YG/30<VVO0H0bZMm0P3;
Z7h20<bYOa00bjQn00<0bjUk0<VWN@36Y7H00P34XW@00`35XgD0ajEg0<VWN@080<VTM`040<RSMP37
XWD0aj9e0<NRM@80aZ5d0P35X7<30<JQM080aj9e0`38XgH01033XG<0a:9d0<JTMP37YGL30<RVN007
0<NUM`37Y7X0aZ=i0<JSN@35XWP0a:5g0<>PMP020<:OM@030<BOM@35X7H0aj9h00<0bJAj0P37XWP0
2038XgH0aj9e0<JQM035X7<0`iia0<:ML031W6l0`9]^202lV6P00`2kUf<0^YIR0;VEH@020;RDH006
0;VEH@2jUV80^YIR0;^GH`2iUF40^9AP0P2gTel00`2hU600^IEQ0;^GH`080;ZFHP<0^IMW0P2hUVH4
0;NEI@80^YUT0P2iV6<03P2hUf80]iIQ0;JEH02fUF00^9AP0;FAG@2bSUX0]91L0;RDH02jUV80^9AP
0;FAG@2eTU`0]Y=M0`2gU5h00`2fTed0]95K0;>@FP020;FBG080]95K0`2cT5X01@2bSeT0/HeI0;:>
FP2dT5`0]Y9N0080]i=O0P2fTUh80;REG`060;NCG`2fTUh0]Y9N0;FAG@2dT5`0/hmK1@2bSUX30;6=
F@80/8aH00<0[h]G0;2<F02aSET00P2bSUX00`2`S5P0[h]G0:j:EP030:n:EB_ooooo000Zooooo`80
Z7e80P2WO4L20:IkAP80YGY50`2WO4T30:QmBP80ZGi;00P0XGQ40:AkA`2XOd/0Zh9>0:b3C`2[PTh0
ZH1<0:MnBP80ZWm<0P2[P4d20:b1CP80[H9?202/PU000`2]Q500Zh9>0:Z1C@020:V0C0030:Z1C@2[
PTh0[HA@0080ZhI?0P2/Qe020:f8D@80[XUB00H0[HMJ0:f7F02]QeP0[HMF0:b7D`2/Qe820:b7D005
0:^6D@2ZQE00ZXE@0:V4C`2XPdh00`2WPTd0102SOTX0XWe90:5lB02PNdL209iiA@0309ehA02LMd<0
VgI200<0W7I700D0VgE609YdA@2JM4D0VWA509UcA00209Qb@`0609Ma@P2FL440U6ho09=]?P2BK3d0
TF/l0P2?J3l0102>Ich0S6Dl08]T>`29HST208QQ>004085N=P20GCD0P5de07mL=080OU/c0P1mFS80
0`1kERX0O5L[07aG:`0207eH;080OUT]00<0OeX^081M<`1oG3800P1nFc40101oG380PEhd08=P=P25
HSP208]T>@0308]U>02<ISL0S6He0080S6Lc00L0SFPc091Z>`2@JS/0TF/l09=]?P2DKSl0UW110080
Ug5200<0Ufdk09Q^?02JL3h00P2KLCl00`2JL3h0V6hl09M]>`0809Q^?0@0U6ho0P2CKCh2099/?@<0
TVdi0P2AK3P3091[=`08095W=@2BJ3H0TfTg09AZ>02CJCL0TVPf091V=02?IC<208mY>P80SVPi00@0
SFLh08aV=`2<ISL0S6Hg0P2;IST308YU>0<0RF@g00@0TfPk095V>@2?I3L0S64d0P2;H3<01@2<HC@0
SF8e08YT=@29Hc@0R68c0080Qf4b00H0R68c08US=02:I3D0RF<d08YT=@2;ICH208eW>00308]U=P2:
I3D0RF<d0080RfLg0`2:ISH408UU=@80S6He0`2;IC@308YT<`<0Sf@g0`2>HcH208eR=@P0RfDf2028
I3@808]U=P<0RfLg0P2<J3P308eY>@P0Sf/k0P2=KSP208a]=`0=08e^>02?L3X0TG8l099c?@2FKCl0
UF`n099/?@2@K3`0TFdm091^?P2ALD00Tg=209Ec@`0309IdA080UgE50P2HMTH309Qg@P80UgI10`2F
MD006`2?Ld<0SG5108]_?`29KCd0QVXj08=W=`21ICD0P6@d08EW<@22Ic80OfDd07MP=01]FS80HE4]
05Q9:01CABP0ACXV040h8`0j<Ql0=2dK030Z6P0]:Q/0;2XK02d[7P0X:Ql09bTN02DW700302<U6P03
02DW700V:1d08R<K00L08R<K0P0Q91T0100R9AX08bHK02@W700U:1d202HY7P0602L[700U:A/08RHH
01lR5`0M81L07B0I0P0M7aX201lR6`807R4J0P0M81T301`O600M01LQ6@0K8Q/07B@L020V700S9Q/0
9BLJ02HV6P0V9aT0<BhK03@a7P0k=R80@C/U04@l9@17?B@0Ac/S04Hj8017?200B3`R04Hl8`0o=b80
=BhL02hX6P0/:1`0;BTN02hW7@0_:1h0<R`P03@^800f<2000P0f<Ah00`0e<1`0<bdO03<]7`0203<]
7`04030Z700]9aT0:bDG02TS5@809bLM0`0V9Q`302DU6`P09RPM0P0V9al202DV7P<092DM0P0S91`0
7`0V9QX0:bTJ02lZ5`0d;1D0?c@H04e0801GB2L0Ie4Z06I@9`1VCbD0JU8T079H9`1lHB`0QVPb08a_
=`2JNDh0Wg]70:b4AP2jTTd0^9EC09^0B`1_GCT0CD4Y030^8@0a;b<0<30T030b9`0^;bL0:bhW02L/
9P0V:bD0200T9R<0200W:280:2TS02TZ8P0[;B80;BlR02la8`0`<b80<C@S200e<BD0200c;b<0<RhR
030/800_:al0;RXN02l[7`0`;200<BdQ200h;R803`0i<1l0>S4P03`c8P0m=2<0?SDT03dd8`0l<b80
>c8Q03/e9@0l=BD0?3DS03de8P10=B<0A3LT04Tj9@0204Xk9P0905138@1AA280DTDU05949`1BA2T0
D48X04ho:01=?RL0BCPV00<0B3LU00l0BCPV04Xi9`1;>RP0BcXX04`l8`1=?B@0D3hV05A0:01G@BX0
Fd8/05a3;@1N@bh0GTDW05m6:01QB2X00P1RBB/0501QB2X0H4LY05m6:01>Ab/0CDHZ04e3:01?@BL0
D40W05A0:01F@2T0Ed4Z05Ln:01H@2P0Fd<[05i6;01PB2`0HDX[065::P1PBBT0IdP/0P1UAb/00`1R
AbX0H4LY05m8:@0205a7:00C05Y6;P1G@b/0DClW04`l8`19>b40B3`R04Xn901:@2D0BSLX04Th:018
=RP0ACDX048d:@10=2P0?C<Y03`b:00j=2H0>38T03La8`0203H`8P0403La8`0h<R@0>C<U03Tc9@<0
>38T0P0g<B<203H`8P0303H`900g<BD0>C<W0080>C<W00/0>38V03H`900d;R80@38W044c:011=BT0
?cDY03de:00k=BL0=c@U03Hc900203Xb9@0F03Xd9P0h=BH0=S@U038c8`0_<200;C0O02/^8`0Z;B80
;2`R02h[8P0c;2@0=bhW03X_:@0n<B/0=30T038^8P0`;200;b/O02hZ7P0_:al0<2`P034]8@P0=2hR
0P0f;2<03P0g;B<0>2hR03P_800i<1l0>S4P03Xb7`13=RH0@SDU044d8`10<b00@3@N048f7P14>200
ACTO1@19?B<404Pl8P0Z04Ho;@13?2X0?cPV03`e8`0k=280?3DS03hg9@10>BL0@3DS048e8P14=b@0
BCXU04dm9P1A?bL0ED4X05I2:@1LA2X0Fd<Y05Y29P1I@R<0FT<S05]48P1MAR@0GTPS05]:;P1LB2d0
FTLY05]69`1OB2P0I4`Z06U?;P1/DRl0IE4/06IB;`1WDc00Ie<b06IA<P1TCc80HTdb061;<01WD340
ITl`0P1TCBd08P1TCB/0IDh/06MA;01XDRd0I4``06I?<01YD380JDh`06Y=;@1^D2h0N5Ld07iM>P1h
HS<0O6Hg07iY?01nJ3l0NfQ007YXA01kJdT0Ofm=08I^C026KTX0QVe408U^?`2>Lch0UGPn09]o?P2P
Pd40ZXdo0:b?@@2_TTH0/YA<0;FGD@2fUeH20;JGE`060<2HD032VU80aIeE0<RPF03:XUX0c:AL0P3=
YEd0803BVeX0e9eL0=FPGP3EY640eJIR0=:WHP3@Z680cjMQ0<^VHP3=Z6@0cZQW0=2ZJ`3@ZV`0d:U^
0<nXK@3>Yfh0cZY^0<n[K`3A[G40djmc0=B`M03C[g<0dZib0=6]L@3>YW80cjQa0=2YLP3AZW40d:U^
0<jXJP3<YVL0bjEV0P30X6<03`33Wf<0aIiS0<JLHP38Vf80bIYR0<^JHP35WeP0aZ1I0<NPF`38XEh0
b:5P0<NOH@36WV00a9aO0<>LE`020<:KEP030<6JE@30VE@0_iQC0080_YMB01T0^YU<0;RFC02hUT`0
]I=;0;>ABP2aST`0/Xm?0;>?D@2dT5@0[Xm<0:j?CP2]STd0Zha<0:Z:C@2YRDh0Z8Q?0:N7CP2`STh0
/Hm?0;:@D02eTe<0^YQH0;nMG@34XV80aZAT0080d:iT00H0cjeU0<bZH`36Xel0_Y]I0;NDDP2cT502
0:b6A@060:^8AP2ZRDH0ZhY70:Z;B02YS4P0ZXe90P2_STT20;2?BP040;6@B`2bTD`0/Y5<0;>BC@80
/iE=00@0/iE?0;BEDP2dUE@0]9EE0P2dU5L0102jVeX0^iaK0;^LF`2lWE`20;fNG@80_YmN00P0b:5Z
0<fXL@38Yg40^I]U0:fDGP2YUF00Z9MQ0:BDH080[I9K00H0[95J0:^@F@2ZSeP0ZHiG0:R=EP2WS5D2
0:V>E`<0Z8eF1@2WS5D20:R=EP0:0:V>E`2ZSeP0ZXmH0:Z?F02YSUL0ZXmH0:^@F@2/TEX0[Y=L0:nD
G@80/IIO02d0^YaX0;^MJ`2kWF/0_Ym`0<6RM035YWX0bJV00<^[PP3>Zhd0d:f?0=:aT03C]I<0e;RC
0=>iU03C^Y80dKZA0=6iU@3@^9@0ckNC0<jfTP3<]900bk>?0<ZbSP39/Hd0a:J40<BWO`30Y780^Z1W
0;JLH`2iWF/0`JAl0<V[R@3<ZX@0bj^40<b/QP3=[h/0ck:@0=:hU`3E_I/0f;nP0=_8ZP3MbZ`0g/fa
0>3@]P3Re;X00P3QeKd00`3PeKl0hMG70>;FaP020>GHb0050>OJb@3ZflP0jm[60>_I``3Zf<800P3W
f<401P3Wekh0i]Fk0>CC]`3Ud[@0iM2a0>C?/080hlV^02@0h/V[0>78ZP3PajP0glNU0=k6XP3MaJ40
hKnT0>2nXP3P_Id0gk^G0=njT03N^8/0g;J50=fePP3C/H@0e;:40=NaPP3H/7d0ejai0=>UL@3?X6P0
cIaT0<FIF033UeP0_i=D0;Z>D@2eR4d0/8=:0:f0B@2[OTL0Z7I10:Ef@02SM400X79009aa?P2IKcd2
09I^?@0808mY>02>J3T0SFLh08]U>029HSL0Qf0g08IO>025GSL3089P<P80PEla0`20GS003021H3D0
Oehc07]J;`1hEb`0MeH[07QG;01jFBh0NeX_07MD:P1iER`0NeP^07aI;`80OEX`00<0O5T_07]H;P1m
FS000`1mFS0407iK<@80OE/e0P1lFS@0101kFC<0NUPb07YH<P1jF38307]H<P0307YG<@1iES00NEH`
0080N5D_0P1jF2/0101kFB`0O5X]07eK;P1nG2l207mM<080O5X]0P1mFbh207iL;`80Oed`00@0O5da
07]L<01kG300Ne``0P1jFbl207UJ;P80OEH_0P1nEc0307mH<@04081I<P1kFB`0O5X]07iL;`80P5ha
00H0Oed`07iL;`1mFbh0Q5Xb089K<P23G3<208=N=004089O=@22HCH0PF8f089S=`80RFLi0P28ISP0
1027ICL0QV@f08IT=P26I3H308QT=080RFDe0`2:ISH01P2<Ic<0SFPd08eX=02>JCD0SfXf091[=`80
TF`h0`2BK3d209=]?P<0U6ho00H0U71009Ea@@2FLT80Ug=309QdA02IMDD209YfAP80UGI000H0UG@o
09Mc?`2FLSh0Ug8n09Ua?P2HL3d309Mb?PD0V7<o00@0VWA509UcA02ILd@0VG=40P2HLT<209Ma@P06
09I]?`2GKT00UFm009Ea@@2FLT80UG=30P2EMD@309ahA0<0WGU50P2NNTH20:1lC0040:5mC@2SOdl0
Y81@0:J2DP80Yh=C00<0Z8A@0:V5D@2ZQU800P2[Qe<0102ZQU80ZHEA0:R4D02ZQU830:V5D@80Z8A@
0P2WPdl30:R4E080Yh=C0`2VPU801P2ZQE40ZHA@0:V4D02XPdl0Yh9>0:J1C@X0YH1<01@0Z8=>0:J1
C02UP4/0Y7m:0:=nB@2TOdX0YX5<0:N2C@2YPe80Z89A0:N1D02VP4l0Yh5@0:R2D@2ZQ5<0ZhED0;6=
G@2bSUh0/hmO0;B@H080]I5Q00`0]i=S0;RDI02hU6@0^IES0;ZFI02jUVH0^YEX0;^FJP2kUV`0_9M]
0;bFK`2lVG<30;fJM080_Y]e0P2oW7H0102nWWD0_imf0;nOMP2oWgH20<2PM`80`J5h2034XGL80<NU
M`030<RUN`39YW`0bJIl0080bZMm0P3;Z7h00`3<ZGl0bj^20<b/P`020<b/P`80cJf40P3>[XD30=6]
R@030=:^RP3C[h/0djn;0080e;2<00H0dZj:0=>_R`3C[h/0e;2<0=FaS@3F/Xh20=NcS`040=BdS@3E
]Hh0eKF>0=FeSP80e[J?1@3G]i020=RhT@<0fKVB0`3I^9D20=ZiUP<0fkZG0`3H^YH20=VkU`<0f[bH
203J^i`80=ZiUP<0eKBA0P3D/i030=>bS`80cZj5103=[H@20<b/P`P0bj^41`39ZH020<ZZP@030<VY
P038Z7l0ajMn0080ajMn00<0bJV00<^[PP3<[8<00P3:ZX@01P3;Zh@0bj^20<Z[O`38ZG/0aZMi0<FV
M`<0b:Ek0`39YW`20<ZWO@030<VVO03:Ygd0bZMm0080bjQn0P3<ZGl00`3=ZX00c:Uo0<bYO`0>0<bY
O`080<bZO03:Z7X0aZAf0<BRM033XG<0aJ=e0<RVN03:Z7X80<VTM`80b:=f0`37XWD30<JQM0<0aj9e
0P38XgH30<VTM`050<:PLP34XW@0aZAf0<RVN03:Z7X00P39YgT01P38YWP0ajAj0<NTNP36XgT0aJ9h
0<BQM`80`j1f00l0`Yme0<FPMP36XGL0b:=i0<VTNP3:YG/0bJAj0<RSN@37XWP0b:=f0<NRM@36XG@0
aJ1c0<BOLP32WG000P31W6l20;fIJ@H0_YYZ00@0_IUU0;bHI02jUV80^9AP0P2gTel01@2hU600^IEQ
0;VEH@2hU600]i=O0080]I5M00<0]i=O0;RDH02iUF40202jUV840;VGI`80^9IV0`2gUFD01P2lVfH0
^iYU0;ZII02jVF@0^IQS0;RGHP80]iIQ00/0^9AP0;FAG@2cSe/0]I5M0;VEH@2jUV80^9AP0;FAG@2c
T5X0]95K0;JCG@030;REG`030;NDGP2fTed0]I9L0080]I9L0P2dTE/30;>@FP040;6=F@2bSUX0]91L
0;NCG`80^9AP00<0]i=O0;JBGP2iUV001`2iUV020;NCG`80]Y9N00@0]I5M0;B@G02cSe/0/hmK102a
SET40;:>FP030;2<F02aSET0/XiJ0080/XiJ00<0/8aH0:j:EP2]RED00`2`ReH[ooooo`00:_ooool3
0:QmB0030:MlA`2VNdH0YGY50080YGY50`2WO4T30:QmBP80ZGi;00P0XGQ40:AkA`2XOd/0Zh9>0:f4
D02[PTh0ZH1<0:MnBP80ZWm<0P2[P4d20:b1CP80[H9?202/PU000`2/Pdl0Zh9>0:Z1C@020:V0C003
0:Z1C@2[PTh0[8=?0080ZhI?0P2/Qe020:f8D@80[XUB00P0ZhEH0:b6E`2/QUL0[8IE0:f8E02]R5<0
[HQA0:j9DP<0ZXE@00<0ZHA?0:R3CP2XPdh00P2WPTd0102SOTX0XWe90:5lB02PNdL209iiA@0309ag
@`2KMT80VWE100P0VgE60P2JM4D0102ILd@0Ug5209I`@@2DKSl209=]?P09091Y@02?J3l0SVLn08eV
?@2;I3/0RV<j08UR>@28HCP0PEhf0080P5de0P1oG3@0101nFc<0OEXb07eJ<P1kERT207aG:P0307eH
:`1nFB`0OUT/0080OeX]0P21GS@2081M<`09085N=023H3H0QF8h08IS>@2;I3T0S6Dj08aV>@2<ISL0
S6He0080S6Lc00L0S6Lb091Z>`2@JS/0TF/l09=]?P2DKSl0UW110080Ug5200<0Ufdk09Q^?02JL3h0
0P2KLCl00`2JL3h0V6hl09M]>`0809Q^?00409E_@02DKSl0U6ho09A^?`80Tfdn0P2BK3d3099]>@80
TF`h0`2@JcL2099Y=@80U6/g00@0TfXf095X=02?IS80SF@`0P2?JCX208iX>@0408eW>02<ISL0S6Hg
08]U=P80RfHi0`2:ICP308UT=`0409=X>`2AIST0Sf@g08aQ=080Rf0c00D0S64d08eR=@2;ICH0RF<d
08MQ<P0208IP<@0608MQ<P29Hc@0RfDf08US=02:I3D0RfDf0P2=IcP00`2;ICH0RV@e08US=00208]W
=`<0RVHf1029ICD208aV=@<0RfDd0`2:I3<01@2BIcX0TFHi095V>@2@ICP0Sf@g0080SV<f00<0SF8e
08]U=P2;ICH01P2;ICH808QT=0P0S6Hg0P2;IcL308aX>0<0SFTi202?Jc/02`2<KCL0Rf`f08]/=P2<
KCL0SFhh091a>`2CM3h0U7Do09M^@02EK3h0TV`m0080T6`l00<0T6hn095a@02CLd80102FM4@209Me
A@80V7I60`2GMT4209Ie@0<0UG@o0200Sg=308ib@P2<L400RFdm08IZ>P23IcL0PFDe081T=026J380
PfPc081V=@1hHCD0KU/c069B;P1JBbX0E4HY04Dj9P10>2<0>S8O03</6P0_:AT0;2TJ02`Z6`0]:ah0
:2XO02LY7P0U9a`08bDJ028T6@0S9AX09BLL02HX7@P08R<K00H08B@I028U6P0R9AX08bHK02@W700U
:1d202HY7P0602L[700U:A/08RHH01lR5`0M81L07B0I0P0M7aX201lR6`807R4J0P0M81T301`O600M
01HP600J8AX07B@L028X7P0U:1d09RPK02DU6@0T9AL0;b`I03<`7@0j=B40@C/U04Dm9P18?RD0B3`T
04Lk8@17?200BCdS04Hl8`0n=R40=BhL02hX6P0/:1`0;BTN02hW7@0`:Al0<R`P03D_8@0f<2000P0f
<Ah02@0e<1`0=2hP03@^800d;R00<bdO030Z700]9aT0:R@F02PR500202PX7P0302LW7@0V9Q`09BDK
008092@J00<08b<I02HX7@0V:1d01P0V:1d202HW7`809BHN100T9Ad0800S9AX09bLK02/Y6P0`:aL0
=BhD040e6@1>@B40FDXY06QB:@1VD2L0IDhR06UA8@1bF2D0O64/08MZ<P2<KcL0VgQ>09mjAP2[Q4<0
^i==0;RED`2HOdT0JUXh04Tn:00`;R40<S0T03<c9`0b=2T0<34Y02`_:00X;BL09b`V200T9R<0200W
:280:2TS02TZ8P0[;B80;BlR02la8`0`<b80<C@S200e<BD0200c;b<0<RhR030/800_:al0;RXN02l[
7`0`;200<BdQ0`0i;b<203P^8P<0=bdQ00<0>2lN03Xa800l<b800P0n=B@02P0m=2<0?3<R03/b8@0m
=bL0?CHV03`e8`0m=B80@3DS04<f8`17>2<204Tj9@0=05958`1CAR@0E4LW05E7:P1EAb`0E4H/05=4
;@1B@b`0AcHT04Pg9@19>2H0BSTW04/j:00204Xi9`0<04Th9P1<?2<0CCdT050n9P1D@2P0Ed4Z05]2
;01MA2h0GT<^05i59`1OARP0HDPZ0`1RBB/04`1PAbT0GdHX04e8:`1=ARX0CD<X04m19`1A?bL0E40X
05M1:P1J@B/0EC`V05Lo9`1K@b/0GTH/0618;01PBBX0H4TY05m8:01VAb/00P1TARX00`1QART0H4LY
05i7:00205]69`0H05U5;@1F@RX0D3hV04/k8P18>R00Ac/Q04Tm8`19?b@0BSLX04Th:018=RP0ACDX
048d:@0o<RT0?38X03`b:@0h<R@0=c4S03H`8P0e;b40=S0R03La8`0i<bD0>S@V100h<R@203La8`80
=S0R0100=c4U03Pb9P0i<bL0>S@X03Tc9`0g<BD0=2hR03<]8@10<RL0@C<X044e:@0o=BT0?CDX03/e
9`0g=2D0=C8S0P0j<RD05P0j=2H0>3DV03Dc900a<R80;c0P02`_7P0X;R80:RdR02/]8P0_;2<0=BhV
03T`:@0o<R`0@C@^03Hb9P0d<2@0<BdQ02l[7`0]:Ad0;RXN02l[7`0`;20803@^8P80=R`S00h0=bdS
03P^8P0h;b00>C0O03Xa800j<Ql0A3LW048e9@10<b80?c8O03hb7010=1`0@CDM048f70<0B3`R1017
>b4204Hj801F04@o;011?2T0?CPU03Xe8P0i=240>cHS03hi9P10>bP0@3DS048e8P14=b@0BCXU04dm
9P1A?bL0ED4X05M3:P1LA2X0Fd<Y05Y29P1H@B80F44Q05U2801J@b40FdDP05U8;01JAR/0F4DW05Q3
901LABD0HDTW06I<:`1XCR/0HTh[06=?;01TD2l0I4l`06A?<P1RCC80H4Xb05m9<@1VCc00IDh_06A=
;P1SC2`0Hd`Z06E?:P1WDB`0JE</06=;;`1UCRl0J4la06Q=;`1ZCBd0KU0^07QG=01nGCX0Mf4b07YT
=@1lIc`0NVLm07MU?`1dI480MfM607Y[C024K4X0Q6Y708A[@P29KSl0Sg@m09Qk?`2PPd40Y8M30:f@
@02_TT80/YE70;BFC@2fV580]YMF0;JGE`2fUUT0aIiC0<RQEP3=YU/0dJYO0=B]HP3F[f@20=F^H`0V
0=NMG@3IWel0fZ=R0=ZWI@3JZfL0ejaW0=F]I`3C[FH0cJQT0<jXI`3@ZVT0dJ]/0=6[K@3@ZFh0cjQ_
0<jWKP3=Zfh0cje`0=6_LP3C/G@0e;9e0=>aM03B/7<0dJmb0<jVLP3?Yg<0cjQa0=2YL03?Z6d0cJI[
0<^UI`3:Y6H0`jEW0<BTI`35XfH0b:5V0<ZPIP3<WfH20<nNIP080<FOF037XEX0b:5L0<ZSH03:Xf80
bZ9T0<RPHP37Wf820<FNF@030<BMF033W5L0`Y]F0080`IYE0100`9UD0;jMD02mW4l0_Ia?0;ZHD02g
UDh0]I9@0;B@DP2dT5@0]I5G0;>DD`2bTe80/I9B0;2AD@2_Se80[XiC0P2]SE@0602]Rd/0[Xa<0:n=
C@2bT500]iEE0;fKF`32X600aJ=S0<j/HP3?[F<0d:iV0<j/I@3:Yf<0`j1L0;bIE`2hUE<0/hi:0;:=
B@2_S4P0[Ha70:^:A@2XRT@0YXU30:F8@P80/I1;0`2bTD`30;>BC@080:nAB@2`TTX0/YA>0;BEDP2f
UeH0]iQH0;RHF`2iVE`20;bMG0030;fNG@2nWeh0_YmN0080_j1O0140`:5P0<^RK03AZW<0c:Uc0;^M
I`2]UV00ZiMR0:RIHP2TUf80[Y=L0:fBF`2/TEX0Zi1I0:Z?F02YSUL0Z8eF0:N<E@030:V>E`80Z8eF
102WS5D20:R=EP030:V>E`2ZSeP0ZXmH0080Zi1I0P2ZSeP0102/TEX0[I9K0:nDG@2aUUl20;:GH080
_9i/00/0_Ii_0;nPLP33Y7P0ajMn0<^[PP3=[HH0cZ^?0=2]S`3B/I80dkFC0=BhT`020=:iT@070=6j
T@3A^ID0d;RD0<ngT`3>]Y80c;B@0<^cS`020<ZbSP080<BVQ034Ygl0`JEc0;^QJ02fW6<0^9aZ0<6T
O03:[8X20<bZQ00@0<b/QP3<[XP0ck>>0=6gU03E^iX0eknM0=[7Y`3LbJ/0g/f_0>3A]03QdkP0h=Bj
0>7E_@3Pe[d0g]G60>;Fb080i=S802d0im[90>[Kb03[f/H0jmW50>[H`P3YgLL0j=c40>WJ``3YfL00
jMRn0>WE^P3Ye[P0jMBg0>K>]P3Vc[@0iLfc0>C</03Sc:d0h/^[0>;;Z@3QbZP0i/>]0>K4Z`3U`ZH0
i<:O0>?0V03S_Y80hkf>0>:lR`3I]i40fkRB0=njT03Q]hd0h;B70=f_OP3KZGP0ejEb0<nSHP3=XF00
bIeN0<BHF`2oTUL0^XeD0;J9D02dQe000P2_OTH03P2[O4H0ZG]70:EjA`2RN4H0XGM509mgAP2FL3l0
UFln09=]?P2AJch0SVLl08aU?02:HcX0RF8k0P27Hc<208IR<P<0QF4a00d0Q60`08UX>`25I3L0P5lb
07aK;P1jFB`0O5/^081O<P22HC@0OEP^07iI;`21G380Pehd0080QF0f0P24GcD4089M<`@0Pehd0P20
GcH207mN=@0507iM=01mG3<0OE`c07aK<P20FSD00P1oFC@00`1nF3<0OELb07eG<P0207aF<@0807YH
:P1kFB/0O5X/07eK;@1nG2h0Oed_081N<021Gc4207mJ;@80P5/^00@0PE`_089M<022GC00Peha0P1m
GS8207aM<@<0Ne``00<0NU/_07iG<01nEc000P1oF343081I<P04085J<`1kFB/0OE/]07mM;`80PEla
00<0P5h`07mM;`1nG2h00P24FS801`22Fc80PUdc089M<`21GS@0PF0e089Q=P22HcL00P29IcT01028
ISP0QfDg08MU=`26I3H208ES=@0408QT=029ICD0RFDe08UU=@80RVHf0P2;IcL208iY=00308mZ=@2@
JcH0TF`g0080TVdh00<0Tfhi099/?@2BK3d00P2CKCh309A^?`0609E_@02DL400U71009Ea@@2FLT80
Ug=30P2IMDD01`2JMTH0UWM109Ef@02FMD00V7A009Mc?`2HLcl00P2ILCh409Ud?`80V7<n0P2GLSd2
09]eAP80VWA50`2ILd@01`2HLT<0UVdo09M^@02EKd00UG5109Ib@P2ELd<00P2EMD@409eiA@@0WWY6
00/0X7a<0:5mC@2ROTh0Xgm?0:F1D@2VPU80Yh=C0:R4E02XQ500ZHEA0:^7D`020:b8E0030:^7D`2Y
QE40Z8A@00<0ZXIB0P2YQE430:R4D080ZHEE0P2XQ5@30:N3D`070:J2DP2[QU80ZhIB0:Z5D@2YQ500
Z8=?0:N2CP020:J1C@<0Yh9>0P2VPDd30:F0C0030:V4C`2WPTd0YX5<0080Y7m:00/0YH1;0:J1C02W
PTd0ZXAC0:V3DP2WPE00YX1?0:N1D02XPU40ZXAC0:^5E0020;:>GP0@0;>?G`2eTF40]Y9R0;JBHP2g
Tf<0^9AT0;VEI@2jUV@0^iMU0;^GI`2kUVT0_9M[0;bGK@2mV6h0_IM`0;fJM0<0_Y]e0P2oW7H20<2M
M`80_imf0P30X7L30<6QN0030<:RN@35XWP0aJ9h00H0aJ9h2039YgT20<VVO0040<ZWO@3;Z7h0bjQn
0<bYO`80cJZ00`3=[H@20<j^Q@<0cjn60P3B[XX20=>_R`040=B`S03E/Hd0eK6=0=JbSP80e;2<00<0
eK6=0=JbSP3G/hl00P3H]900103I]I40e[J?0=JfS`3F]Xl30=NgT0@0f;RA0P3I^I840=ZjT`040=Vh
U@3J^IH0f[VF0=ZiUP80fkZG0P3L^iP30=VkU`80f[bH0`3K_IT80=^lW@P0fkZG00@0e[FB0=FdT@3E
]940eKBA0P3D/i020=>bS`030<j^Q@3=[H@0cJf400@0cJf400<0c:b30<b/Q@3<[8D01P3<[8D50<VY
P0D0bZZ100l0bJV00<RXO`38Z7l0b:Qo0<ZZP@3<[8<0cJf40<VYP`3:ZX@0c:b50<b/P`3;[800bJYl
0<JWN@35YWL00`38YG/30<VVO080bZMm00@0bJIl0<ZWO@3:Ygd0bjQn0P3<ZGl20<fZP100c:Uo00P0
cJ]m0<ZXNP36Y7H0a:9d0<>QL`35XgD0b:Ih0<ZXNPP0bJAg0`38XgH20<NRM@<0aZ5d0`37XWD20<RS
MP<0bJAg00@0`Z1b0<BRM037YGL0bJMi0P3:Z7X01P39YgT0b:Ih0<NTNP37Y7X0aZ=i0<FRN080a:5g
0P33X7H00`35WgP0aZ1i0<RRN`030<ZTO@80b:9k0P38XgH01037XWD0aJ1c0<BOLP32WG020<6LK`<0
_YYZ1@2oVf/0102oW6H0_IYT0;ZGH@2hUEl20;JCG@050;NDGP2hUEl0^9AP0;NCG`2eTEd00P2dT5`0
0`2eTEd0]i=O0;RDH0080;ZFHP040;ZHJ02iUfL0^IMW0;VGI`80^9IV0`2gUFD20;bKIP030;^JI@2j
VF@0^IQS0080^9MR0140]iIQ0;RDH02eTEd0/hmK0;FAG@2iUF40^iMS0;RDH02eTEd0/HiH0;>@FP2f
Ted0^9EO0;ZGH@2iUV00^9EO0;NDGP030;FBG0<0]95K0P2cT5X0102`S5P0/XiJ0;FAG@2gTel20;RD
H0030;NCG`2fTUh0^IIP00L0^IIP00H0^9AP0;NCG`2gTel0]Y9N0;FAG@2dT5`20;>?F`060:n;E`2`
S5P0/8aH0;6=F@2bSUX0/hmK0P2dT5`0202aSET0/XiJ0;>?F`2cSe/0/XiJ0;2<F02]RED0[8QD0`2`
ReH[ooooo`00:_ooool20:EjA@80YW]60P2WO4L20:QmB0060:EjA@2VNdH0YW]60:MlA`2XODP0ZGi9
0P2ZOdX0102WOTX0Z7m;0:QoB`2YP4`20:Z1C@80Zh9>202/PDh30:b2D080[H=A0`2^Q5880:R4D00@
0:j5D@2_QU80/HQD0;:9E@2cRUH0/XUE0;68E02`Qe<0]8]G0;>:EP2bRED0/8MC0:n6DP2]Q500[8=?
0:^2CP80[8=?00H0Zh9>0:Z1C@2YP4`0Z7m;0:MnBP2VODT20:QoB`050:MnBP2UO4P0Y7]70:AkA`2R
NDD00P2QN4@01P2TNTP0XgU70:=iA`2QMdD0X7I409me@`@0WWA200<0WG=109ab@02KLCl00P2JL3h0
2@2IKcd0U6i109=]@02BK3l0T6Xm08iX>`2<IST0RV@g08US=P0208YP>P0608UR>`28HS/0Qf4j08=P
>020GcH0OUdd0P1mFS8207aI<@80NeP`0P1jEbl04@20Fc40OeX`07eH;P1lEbd0OEP^081K<@23GS@0
QF0f08QR<`29Hc@0RfDf08aV=`2=IcP0S6Hg08]U=P2:I3D0UF/i0080UV`j00<0Ufdk09Q^?02IKcd0
0P2JL3h209Ia?@<0Ug8n0`2HLcl00`2IKcd0Ufdk09I/>P0209E[>@0309I/>P2GKC/0V6hl00<0V6hl
00<0Ufdk09I/>P2EJcT00P2EJcT209=]?P04099/?@2AJc`0TF/l091Z>`80SfTj102AIcD4099X=P80
U6Hd00H0TVLd091W<`2?Ic<0SFPc08aW<P2;J388091S>@P0Rf@i202;H3<208eR=`80SV<h102?I3T0
1028HS<0RF<d08US=029Hc@308YT=@80RfDf0P2=IcP208aV=`0408eW>02?JCX0TV`m09=]?P80RfTk
00T0S6Lj08aV>@2>ICT0SV<h08eR=`2>HCL0RF<d08YT=@2=IcP00P2?JCX00`2>J3T0S6Hg08YT=@08
08ES=@0:08eZ=02<J3@0RVHb08UU<`28I3@0RF@g08YU>@2;ISX0RVHf08UU=@80R6@d00@0RFDe08]W
=`2>JSX0T6`l0`2AK3l2091[?P<0SfXm0`2BKSX3095]>@80T6`h0P2CJS`01P2BK3d0TVhn09=_?`2B
L400TG50099b@@P0UGM50`2HNT@309Mi@`80UWQ200H0TgE3091b@02=KSl0RFXl08IW>`25IC`208AT
?@0@08Y[=@28JSH0PfLg07YR=P1_FC80HU0/05M79P1@@B@0BS`Q04Di7`10=Qd0>38L038_700/;Ad0
:R`N02P/7P80:2XO00@09bTN02HX7@0V:1d09BLL0P0T9Q/00`0S9Qd08RDL024T6`0201lR6@03024T
6`0R9A`08bHM00<08bHK0`0T9a`302DX7@0702@W700Q91/07b8K01dO6P0M7a`07R0M01hP7`0901`N
6`0K020U7`0O91h082<L020Q6@0Q8aP08b<G02LU6@0X9QT0<S8J03@d700i=ah0?c/P04<n8@16?b<0
Ad0S04Y1901?A2P0BclU04@j8@0l=1l0=RlM03<]7@0c;B40<RhS03<^6P0d;a/0=S4M00<0>3<O0P0f
<Ad02@0a;Qd0<BhO02l/7@0^:Qh0;2PM02XV7@0Y91h0:2<M02`X700202/Y7@0302PX7P0V9al09BPQ
00808RLQ2`0U9a`302@V6`808bDJ01P08R<N02HU800/:1d0<BXJ03T]5`18=a/0FdLV06UB<01VCb<0
IdlQ06YB901aERL0NUh^08EW=@2?Kc`0UGE208ek?@2NQTP0/I=E0;NEF02VQE00QFU1069?<@1<?BP2
034d8`06038d9P0a<bH0<38W02d^9P0[;2H0:BXT0`0U9R000`0T9Al08b@N028S7@03028S7@0502@U
7`0W:200:bdR02d_8P0^<2800P0^<B0402l`8P@0;RlQ0P0^:Qh00`0_:al0<2`P034]8@02038^8P06
03<_8`0f<RH0=S8V03Hb9P0e<BD0=30T0`0c;b<203la9P0403hb9P0l<RH0>c<V03Xd9P80>3DV00L0
>c8Q03`c8P10=B<0@cHS04Pi901;>b@0C3`U0080CS`T00H0DT<R0593901A@R<0D44T05109P1??bH2
04hn9`0Q04Pf8019=b40C3XT04dk9@1>?2H0CC/U04/i8`1:>280DdDZ0594:@1B@RP0DT4W05A09`1G
@BT0F48Z05a4;01UCBL0IDlZ06A>:@1QCBX0GT/Z05U9:01EARL0Dd@U050n9P1>?2@0BcTQ04Xh801;
>B40CC/S054o9`1C@BT0G4@X00<0Fd<W0200GDDY05m7:`1QBBd0Hd/_06=:;01QBR/0H4P/05e8;@1J
ARd0EdD]05E5;P1DA2d0Dd</04lo:01;>b@0C3`U0510:@1A@BX0CShW04Ti8P17?2P0A3`W04<k:010
>BL0?3HV03Pe9P0f=2D0=C<V03Xd:00i<bL0=c4U03D_8`80=2hR00L0=BlS03H`900f<200=S0P03H`
8P0f<2@0=RlU0080=RlW00<0=RlY03<_8`0c;b<00P0d<2@0700e<BD0=S8V03Hb9P0g<bL0?RdS03l^
900o<BH0?S8V03`b9P0j<RD0>30S03H`8P0^;R@0<30V038b:00c<bT0<S8X02h^900Z:R009bLM034X
8`0a:240<RTR03@[8P0g;b@0?3@W03lh:012>b/203@`9`0603<_9P0a;B@0;b/R02hZ8@0]:B00;2PO
100f<2@403La9@08038^8`0c;b@0=BlS03L_8P0h;b00>blO03d`800m<1l204Df8`0304@g9014>BD0
@SXU0080@S`V00<0@SdW040k9@10>bD01`10>bD01P15?2d0A3//04<j:@12>RL0@CTV03lg8P80?SHO
0100@S8S04De9@1:>BD0D3hV05A39@1HAB@0FTHQ05]8801DA280DT@Q05528@1@@b<0Cd@V0517:01B
BB`0DDX]0P1OAB@0101QAbH0HdTX06E;:P1WCB`206U?;P<0H4/^0`1OBRd205i9;01606U7:`1ZB2`0
JD`^06Q=;`1VCbl0HDh]05e=:`1KCBX0Ed`^05E8:01CA2D0FTLW06A=;@1[Dc40Ke8`06e@;P1^ES`0
KeDj06mF=`1aEcH0METd07YM=@20H3L0PV<g08U[>@2>L3`0U7I209Ih@P2GNT80VGa209n2AP2TQd/0
[I1F0;6CE`2dUUX0]IEH0;JDE@2iUUH0`9YI0<FOGP3=We@0d:9G0=>WGP3G[FD0fk=]0=jgLP3O^W@0
h;]g0=V`L03DZfd0cZQY0<bXJP3>[W40d;=g0<jdM`3<]7P0cJai0<ZYMP37YW40a:=]0<>RK034Y6/0
ajM/0<RXK@3@/7D0dK5f0=>cNP3E]7h0ekJ00=RgPP80f;N400T0cJaf0<b[M@3:ZG<0b:Ma0<NVL038
Yg40bZUc0<^ZM03;YUl00`3:YEh40<VTG@0>0<bWH@3=Z680cZUS0<jYH`3<Yf40bZEO0<NRG035X5X0
c:=U0<bSH`3;XV80bj9P0<^SGP3;Xed20<^SF`0:0<FSG032X5T0`Z1I0;bJD`2hUTl0]iE>0;VGD02l
VU<0_ieF0;JED080]iA@00<0^9=?0;VBC`2iT4h00P2kSdh05@2fSTT0]Hi90;F>B`2fT4l0]iAD0;^I
FP2mWF00`:1S0<FWJ@36Z6X0ajQX0<RVIP36YF80`YmK0<2KE@2mV580]iEF0;FCE02bT540/8i?0:j<
C@020:f;C00;0:j<C@2cTE80/i5B0;BBD`2eTe@0]YAE0;NEEP2hUUL0^IMH0;NHE`2hVEP00P2iVUT0
202jVeX0^iaK0;bMG02lWE`0`9iO0<:PH@34XV<0aZAU0P37YFH02P36Y6D0aJ=T0<RUJ`38Z6d0c:ac
0<Z[M02lWfL0Zi1I0:V@FP2bVF<80:fCH0@0ZHmL0P2XSU/20:N=FP030:b@GP2[Sed0ZXiL0080ZHeK
00<0ZXiL0:b@GP2]TEl00P2^UEl04P2_UF80/IMV0;:GJ02cV6/0]9U/0;FJK`2jWg80^j1c0;fRM@30
YGP0`jQk0<J[OP38[H00bJj10<b`R`3>/Xd0d;B?0=>gTP<0e;RC01l0dkNB0=FhUP3D]iD0dkJD0=6d
TP3?/Y00c[6?0<b_S@3;[X`0b:]o0<JYO@32YGT0^iib0;JIK@2hVfl0_j9f0<NZOP38[8D0bZj70<b`
R`3?/Y00d[FC0=FhV03G^Y`0f;^M0=o6Z03PbJX0hl^_0>C?]03UdKP0i=:j0080hm>l00L0imFo0>OE
`@3Xe/80j=K20>WFa@3ZelP0j]O90080jmO<00H0jmS90>_Ha`3ZelH0j]S40>WG`@3Xe[h20>OF_0<0
i=:j0P3SdKT30>;@^080iL^b00@0i<Z_0>?9[P3Qb:X0h<NX0P3OajD20=k0WP0N0>2oW03P`9X0gkfG
0=fjU03M]i00fkJ<0=R/Q@3FZX<0djQn0<nTN@3;X7<0aie]0<BJJP32V6H0^IEK0;RDFP2hTEH0]XiA
0;B;C@2dR4T0/hE70;:5A02YOdD0YGY309md?`2MLD00W71109Y]@`2DIch0Sf8k0P2>HcP208eR=`<0
S64f00T0Rf0e08]V<P2:I3<0R6@b08AR<P21HC80Oeha07aM<@1kG3001@25H2`308IQ;@P0R6<f0`22
HC@00`21H3<0P5lb081O<P0207mN<@06089M<022GC40PE``085L<P21Fc@0P5Xe0P20FSH2089M<080
PE`_00L0PUd`08EP<`27HSD0RF@g08EP=023GS80PUda0080P5/_01H0PUda08=N<P25H3@0QV<k08ER
>P22GcL0P5de07mL=020GCD0PEhf089O=`22H380PV0c085O<P21GS@0P5de081M=`20G3P0Oe/g085L
;`22GC00Q5lb0P26HC@01025H3<0Peha089M<027HSD408QS=P80RF@g0P2:ICP0202<J3P0RfLg08YV
=P2:ISH0RfLg08eY>@2?Jc/0TFdm0P2=IcP208iX>@0408mY>P2@JS/0T6Xk095[?0@0SVPi0P2?JCX2
091Z>`<0UG0l0P2FLCd309Mb?P0309QdA02GLd<0Ug=30080Ug=300<0VGE509ahB02MNDT00P2HM400
0`2IMD40VWI209]g@`0209eiA@0409ijAP2LMd<0VgI209Ye@@80VGA000H0VgI209ehA02ONTH0Ug8n
09Ud@02LMd<209iiA@0609ehA02KMT80VGA009ahB02KMdL0VGE50P2HM4@0102IMDD0VgM709ahB02M
NDT309ahB00409ijBP2QODd0Y81@0:J2DP80Y81<0P2UPDd30:J2CP070:N3C`2YQED0ZXIF0:Z6EP2[
QeL0[8QH0:f9F@020:j:FPD0[8YL00@0ZhUK0:Z8FP2ZR5X0[8IO0P2/Qed00`2/Qe/0[8MJ0:b8F002
0:b8EP080:b6G`2]Qf00[XUM0:j9G02]REL0ZhQB0:V6CP2WQ4X50:N4CP<0YX==0`2SOd/20:B0C0<0
YH5=00`0ZhMG0:Z6EP2ZQUH0ZHEE0:Z6EP2/R5P0[XYJ0;2<G02`SUh0/HmO0;:@HP2cTF@20;BAI`0;
0;JCJ`2gU6h0]iA^0;RIJP2hVF/0^IY/0;ZKK`2kVg80_9ae0;bLMP2mWGL0102oWgP40<2PN@80`j=j
0P34Y7/20<FUO080aZIm0`36Yg/20<NXO0<0b:Um0P38Z7l20<VYP080bZZ10P3;Zh80203:ZHH0bjZ7
0<b[R03>[HX0cjj;0=6`S@3B/Hh0dk:?0`3@/8L20=6aR0<0d[:92`3D]Y@20=FgU@<0e[RF0`3H^Y@2
0=VkU@<0f[bF0P3G^IL0103H^YP0fK^I0=^mV`3L_Y`20=foW@80g/2N0P3M_id30=bnW0030=^mV`3M
_id0gKnM00H0gKnM103L_Y`20=^mV`80f[bJ103I^9D20=RgU080ekJC00T0dkFA0=BfTP3E]i<0e[RD
0=FgT`3D]Y80d[B@0=6cS`3B/I000P3B/Hh00`3A/H/0dK6:0=2`Q`020=2aQ@P0c:b50P3;Zh@20<b/
Q@D0cJf6203=ZX00203<ZGl0cJZ00<j[P@3?[880cZ^10<fZP03;Z7h0bZMm0P37Y7`20<RUO@060<VV
OP3:Ygl0bZMo0<^XP03<ZH40bjR00`3:Ygl00`3<ZH40cZ^30=2]Q@080<VYP0040<VYPP3:ZX<0bZZ3
0<ZZP`80bj^40P3<[8D30<VYP080b:Qo0`37Ygh30<VVO0030<RUN`37Y7X0aZ=i0080aZ=i0`3;Z7h2
0<ZWO@<0bJIl00<0bZMm0<RUN`36XgT00P34XGL00`35XWP0aZ=i0<NTNP020<VVOP030<VVP03:YX80
bZJ40080bjN700<0bjJ90<VVO039YW`00P38YG/30<NTNP030<JSN@38YG/0b:Ek00H0b:Ek103:YW@0
1038Y780a:1^0<6MJ`2oVfT40;fKK@@0_Ya^00@0_i][0;fIJ@2kUfL0^IEU0P2hU6@00`2iUFD0^YIV
0;NCG`020;NCG`80^9AP0`2iUF430;bHJ080_IUY0`2nVVX30;VGI`80^YQX102kVFT02@2iUfL0^YQX
0;^IJ@2kVFT0^YQX0;RFIP2fU6@0]99R0;F@H`020;FAH@030;FAG`2fTUh0]Y=M0080]Y=K0P2dT5`0
0`2eTEd0]Y9N0;NCG`020;VEH@070;ZFHP2iTf80^I=R0;RCG`2gTUd0]Y5L0;F@F@020;B@EP80/XmI
00<0/i1J0;BAF`2eTU`00P2fTed00`2gU5h0^IEU0;VEI@060;VEI@0<0;JBHP2gTf<0^IEU0;VEI@2h
U6@0]I5Q0;6=G@2_Re/0[X]E0:n<EP2aSUP0/i1J0P2dTE/02P2cT5X0/XmI0;BAF`2cT5X0/XmI0;6>
F02`SEL0[haF0:j;E@2]RU@30;2<FR_ooooo000Zooooo`80YGY50P2VNdH20:MlA`80Z7e80P2VNdH2
0:MlA`040:QmB02YOTT0ZWm:0:YoBP<0Z7m;00<0ZH1<0:Z1C@2ZPDd00P2[PTh80:^0C@<0[89@0`2]
Pe420:j4DPP0ZHA@0100[XEA0:n6DP2aR5@0/XUE0;>:EP2bRED0/HQD0;27D`2dReL0/hYF0;:9E@2`
Qe<0[hIB0:f4D02/Pdl0Zh9>0P2/Pdl0102[PTh0ZX5=0:V0C02XOd/20:MnBP040:V0C02XOd/0Ygi:
0:ImB@80YGa800<0Y7]70:=jAP2RNDD00P2UNdT0102TNTP0XgU70:9hAP2QMdD20:1fA080XgU700<0
XWQ60:5gA@2PMT@00P2OMD<04@2NM480VWA709UcAP2GLD@0UFm209=]@02AJch0T6Xm08mY?02<HSX0
SF<k08]T>`2:IC/0R6<i08AQ=`20Gc@0Oehc0080O5Ta0`1kF30307YG;`80OeX`0P1nFBl0201oFS00
PE`b08=N=024GcD0QV0a08QR<`2:I3D0S6Hg0`2=IcP01`2<ISL0UF/i09I/>P2FK3X0Ufdk09Q^?02I
Kcd00P2JL3h209Ia?@<0Ug8n0`2HLcl00`2JL3h0VFlm09M]>`0309E[>@0409I/>P2GKC/0V6hl09Q^
?080Ufdk00@0UV`j09E[>@2EJcT0UF/i0`2BK3d2095[?0<0T6Xk102AIcD4099X=P80TfDd00<0TFDd
091V=02?Ic@00P2=J3@00`2=JCD0Sf@i08mT>@0608mT>@P0Rf@i202;H3<208aQ=P<0SF8g0`2>HcP4
08US=0<0RV@e0P2;ICH208eW>080S6Hg00@0SFLh08mY>P2AJc`0Tfdn0P2;JC/02@2<IcX0S6Hi08iU
>@2>HcP0SF8g08iQ=`27HC80R68c08US=00308YT=@0308US=028HS<0QV@f00L0QV@f00X0S6Tc08]W
<`29IC40R6@b08QT=028HcH0RVDi08]V>P2;IcL0RVHf0P29ICD0102:ISH0SFTi08m[>`2@K3`3095/
?`80T6/n0`2?JSd7095]>@07099^>P2FKCl0Ufi009E_@02ELD40UW9209Ec@`0209EeA0P0UGM50`2H
NT@309Mi@`80UWQ200H0TgE3091b@02=KSl0RFXl08IW>`25IC`208AT?@0@08UZ=027JCD0PVHf07UQ
=@1_FC80He4]05Q89`1B@bH0BS`Q04Hj8010=Qd0>C<M038_700/;Ad0:R`N02T]7`80:2XO00@09bTN
02HX7@0V:1d09BLL0P0T9Q/00`0S9Qd08RDL024T6`0201lR6@03024T6`0R9A`08bHM00<08bHK0`0T
9a`302DX7@0702@W700Q91/07b8K01dO6P0M7a`07R0M01hP7`0901`N6`0P01lT7P0N8ad07b8K020Q
6@0Q8aP092@H02PV6P0Y9aX0<S8J03Hd7@0i=ah0?c/P04@o8P17@2<0BT4T04Y18P1A@bH0Bd0T04Di
8@0n<ad0>30M03D^7P0d;R00=2hR03D_6@0f<1X0>38L03Tc7@0j=1h0>C<M03Pb700g<A/203<`7`06
034^7`0_:al0;BTN02/W7P0Y9A`0:2<M0P0/:1`01P0Z:1`0:2PN02HW7`0T9b008bHO024V80P09BLL
0`0V:1d302DW708092HK02408b@O02HU800/:1d0<R/I03/_5`1:>Ad0G4PW06YC<@1ZDbL0Je<U06iF
:01eFR/0OV8b08U[>@2CLd00V7Q508mk?P2OQdT0/Y9E0;JCF@2SPTl0PFDn05e9;P15>2D0<3<R034d
8`0a<bD0<C<V030b9`0];RH0:b`V02TZ900V9b400P0U9R0202@U7`808b@N00L08R<M02<T7P0U9R00
:2TQ02/]8P0];b80;S0R0080;S4P1@0_<28302h_8@80;RXN00@0;b/O030/800a;B40<RhR0P0c;b<2
03Da9@80=30T0P0c;b<2038^8P80?c4V00@0?S8V03`b9P0k<bH0>S@V0P0h=BH01`0j<B00>c8Q03ld
8P12=B80AcPS04Xj8`1<?2D00P1>?2@205528`030511901??bD0CShU0080CCdV0280C3/W04/i8`1=
>bD0CcdW050n:01A?bT0D3hX04lm9`1>?2H0DdDZ05=3:@1B@RP0DT4W05A09`1G@BT0FT8Z05]3:`1T
C2P0I4hY06A=:`1QCB`0GT/[05U9:01EARL0Dd@U05A2:P1B@2P0CcdU04dk8`1>?2@0D3hV05=1:@1E
@b/0Fd<W0`1J@RH0901LA2P0GTHZ0659;@1RBRh0I4/]069;;01QBBd0GDP]05Y6;@1FA2`0E4@]05=3
;01A@BX0CShW04/k901<?2D0D40Y0551:P1>?RL0Bc/T04Ll:016>bL0@SXW040i9`0l=RH0>CHW03Ld
9@0e<bH0>C<W03Pb9P0f<2@0=BlS03@^8P0e;b<0=S0T03La9@80=c4Q00<0=c4S03H`900f;bD00P0e
;RH00`0e;RP0<RhR038^8P0203<_8`0?03@`900e<BD0=C4U03Da9@0n;B<0?BlT03h`9@0n<RH0?38V
03Xb9@0g<B<0=S0R02d]8`0_;bD0<C4W0080<S8X00`0;blU02/[8@0X:1h0<BPS034X8@0b:B80<bXQ
03H^8`0i<B@0?3DU03hg9`0c;bH2038^9@03034]900`;2<0;b/R0080;RXQ00@0<bdQ03@^8P0d;R80
=BlS0P0f<2@203La9@08038^8`0c;b@0=BlS03L_8P0i<240>blO03d`800m<1l204Hg900304@g9014
>BD0@SXU0080@C/U00<0@3/U03lj900o>R@01`0o>R@2048i:P0>044h9`11>BH0@3PU03lg8P0o=b00
?SHO04Hd9P18=bL0C3/W054o9`1D@bD0F4DT05U78@1IAal205938P0>05528@1@@b<0DD@T0556:01D
BB/0EDX^06169@1QAbH0HTPW06=9:01UBbX0IT`[06M=;01XCRd305m:;@0305i9;01MB2/0GDP[0080
G4LZ03/0IDHY06I7:P1WBR`0ID`]06=<;01OC2/0Fd/Y05Y::01HBb/0ETLX05E5901JAbL0I4d]06YB
<01/DRl0KE0^06eC>01]E3H0KU<e075D<P1eEc40Ne/d07iO<`21H3<0QfTg08a^?02BM400UGM109Ii
@@2IO480Wh980:B7B`2[SU@0[Y5G0;>EF@2dU5L0]YAE0;VFEP30WEd0aj5P0=BXG`3F[6@0fk5Y0=jf
L03R^gH0iL1l0>G2P03V`h40iKf00>2hN`3H]7H0eK=f0=BdN@3B]GT0cK=f0<VaM@3;ZWL0bJQe0<JU
L0020<>RK00@0<BTJ`37Yf`0bJU^0<^[L03>[W<0dK5h0=BcO@3F]Gl0e[F00=FdP@3D/h00cjmf0<f]
M03:ZW40ajM^0<JVK@80aJE/00<0aZI]0<^VH03;YV000`3;YV030<bWH@090<fXI03>ZFD0cjYV0<jY
I@3=Z6@0bZEQ0<RSG`36XEd0cJEX0080cJEW00<0cJIU0<bUHP3<YF000P3<YUl01@33XEX0`ImH0<6O
F02nW5D0^iUB0080^YQA00<0_9YC0;jLE@2iV5<00P2iUU800`2kUU80^iAA0;bCD@020;fAD00D0;fE
D02lUE00_9EB0;fGEP2mVUX0`9iO0<6QI034Y6L0`jEW0<:TIP33Y6@0`j5Q0<6PG@2oW5P0_YUC0;bG
D@2gUEH0]I=D0;:@D@2`STl40:f;C080/i5B00@0]99C0;JDE@2gUEH0^9IG0P2iUeP01P2hVEP0^IYI
0;VJF@2jVeX0^iaK0;bMG080_IiM00@0`ImP0<:PH@34XV<0aZAU0P37YFH20<JTI@080<RUJ`38Z6d0
c:ac0<^/M@2mX6P0[95J0:V@FP2bVF<80:fCH0040:Z@G@2YSe`0ZHmL0:V?G080Z8iK0P2WSEX00`2/
T5h0ZhmM0:Z>G0020:V=F`090:^?G@2/T5h0[Y9P0:jEG`2_UF80/9IS0;:HI`2cV6T0]IY]0080]Y]`
00`0^j1c0;bQM02nXgH0`JIi0<>XN`36Zgh0b:f00<V^P@3</8/0c[:=0=2dS`3C]i830=BhT`070=>g
TP3E^9H0eKRF0=>fU03A]980d;>A0<jaS`020<b_S@0F0<R[O`37ZWh0`ZEi0;^NLP2fVFd0]iY^0;nR
MP36ZGd0b:b50<V]QP3;[hX0c[6?0=6dTP3D]iL0ekZL0=RkW@3OaZP0h<VZ0>?;[`3Tck@0iM6h0>CB
^P80hm>l0P3WeKl20>SF`P060>WFa@3ZelP0jmS:0>_HbP3/f<d0k=W:0P3[f<L00`3Zf<@0jMO10>SF
_P020>OF_0<0i=:j0P3SdKT30>;@^0060>K>]P3UcK<0i<bb0>?;[`3Rbj`0hLZZ0P3PbJL20=o2XP0O
0>73X@3R`Ih0h/2K0>2mU`3M^Y@0g[RA0=fcS@3L/X`0fJn70=J/PP3BZGd0cjIh0<bSM@3;Xg80`YmY
0<:MIP30Vf@0`9UP0;jFF`2mTeL0_I5D0;b@D`2cRdd0[XI90:V1AP2VODL0YWe90:AjBP2NLdH0VFi1
09M/?`0209I[?P0309AY?02CJ3/0TVLj0080TFHi00P0TFTf08mZ=P2=IcH0RfLg08MU=`25I3L0Pf@f
089S=`80RF@`1P2:IC4808UT=`H0QVDh0P25I3L208EP<`0708AO<`24GcD0Pedf08=M>022G3L0PU`h
08MR=@0308IQ=00708MR=@29I3L0RfHi08eX>`29I3P0R6<g08MR=P0208EP=00;08MR=P28HcL0RF@h
08IS>@25HSP0Pf0f089O=@21GS@0PUle08=P=P24HCL00P23HC<00`23HC@0PUle089O=`02085N>004
085M>@22GC00Q5lb08EP<`80Qf8e00<0QV4d08AO<P23GS400P28HcH308UT=`<0RVDh00<0RfHi08aX
>02<J3P00P2;IcL0102<J3P0SVXj091/?02AKCd208iX>@80SfTj00@0T6Xk095[?02AJc`0TF/l0`2?
JCX2091Z>`<0TF/l00@0UG0l09Ia?@2FLCd0UW4m0P2GLSh209Qc?`0>09UeA@2HM4@0Ug=309Mc@`2H
M4@0VWI609ahB02MNDT0VGE109Yf@P2KMd<0W7Q409eiA@2NNTH209mkA`0309ehA02LMd<0VWE10080
VWE100P0W7M309iiA@2ONTH0VWE109]f@P2LMd<0WGQ409iiA@80WGQ400@0W7M309eiB@2LN4P0VgM7
0P2IMDD0102KMdL0W7Q809eiB@2NNTX309eiB@0409mkB`2QODd0Y81@0:J2DP<0YH5=0P2VPTh30:N3
C`80ZXIF00<0ZhMG0:b8F02]RET00P2^RUX0102_Re/0[8YL0:b:G02/RU`20:^9F`<0ZXQJ00H0[HMP
0:f8GP2]R5h0[HQL0:f8F`2]RET20:f9E`090:f7H02^REl0[hYN0:n:G@2^RUP0[8QD0:Z7C`2XQDd0
ZHEA00@0Z8A@1@2WPdl30:R4D0<0ZHEA00`0[8QH0:^7E`2ZQUH0ZXIF0:^7E`2]RET0[h]K0;6=G@2a
Sel0/Y1P0;>AH`2dTVD20;FBJ00;0;NDK02hUFl0^9E_0;VJJ`2iVV`0^Y]]0;^LL02lW7<0_Ief0;fM
M`2nWWP01030X7T40<6QNP<0aJEn0P36YWl30<NWP080ajQl0P38ZGd30<VZOP040<Z[O`3:ZX<0bZZ3
0<ZZP`80bj^40`3<[8D20<b[R0060<j]RP3?[X/0dK2=0=:aSP3C/Xl0e;>@0`3A/HX20=:bR`<0dk><
2`3E]iD20=JhUP<0ekVG0P3H^Y@20=VkU@<0f[bF00P0fkfG0=RjV03H^YP0fK^I0=ZlVP3K_I/0g;jL
0=foW@@0g/2N0P3M_id30=bnW0T0gKnM0`3L_Y`20=^mV`80f[bJ00@0f[VF0=VhU@3I^9D0fKRE0P3H
]i@20=NfT`030=>eT@3D]Y80eKNC0080e[RD00@0e;JB0=:dT03A/hl0d[6@0P3B/Hh00`3A/H/0dK6:
0=2`Q`020=2aQ@030<j^Q`3=[HH0cJf60080c:b50`3;Zh@20<ZZP`<0bj^4103<[8D80<fZP0090<bY
O`3=ZX00cZ^10<n/PP3>Zh40cJZ00<^XOP3:Ygd0ajAl0080b:Em0P39YWh20<ZWO`80bjR000L0bZMo
0<VVOP39YWh0bJIn0<^XP03=ZX80cZ^300P0bZZ10`3:ZX<20<^[Q0<0c:b500@0bZZ10<VYP039ZH00
bJV00P38Z7l20<NWOP030<ZWO@39YW`0bJIl0080b:Ek0P37Y7X01036XgT0bjQn0<^XOP3;Z7h20<ZW
O@<0bJIl00<0bZMm0<VVO037Y7X00`35XWP01036XgT0ajAj0<VVOP39YWh20<ZWP@040<ZVPP3;YhD0
bjN70<^WQ`80bJIl0P38YG/40<NTNPP0b:Ek1039YG<01037Xg40`im]0<2LJP2nVVP80;jLKP040;nK
J`2nVVX0_9QX0;ZFIP80^IEU0P2jUVH20;NCG`80^9AP0`2iUF400`2jUV80_9QX0;bHJ0020;fIJ@<0
_YYZ00@0_i][0;VGI`2iUfL0^IMW0P2jV6P40;^IJ@80^YQX00L0^iUY0;bJJP2kVFT0^IMW0;JDI02e
Tf<0]Y5T0080]Y9R00<0]Y9P0;JBGP2fTed00P2gU5`20;FAG@040;JBGP2gTel0^9AP0;VEH@80^YIR
0P2iTf801`2hTel0]i9M0;JAG02eT5T0]I5G0;B@EP2bSeT00P2cT5X00`2dTE/0]I9L0;JCG@020;ND
GPP0^YIV00/0^9AT0;VEI@2iUFD0^9AT0;JBHP2dT600/XiN0;6=G@2_S5H0/8eG0;:?F@030;BAF`08
0;>@FP2bSeT0]95K0;>@FP2bSeT0/HiH0;2=E`2_S5H20:j;E@<0[h]I:oooool002[ooooo0P2UNTD2
0:IkAP80Yga70P2XODP20:IkAP030:MlA`2XODP0ZGi90080ZWm:00<0Zh1;0:QoB`2XOd/00`2YP4`3
0:Z1C@P0ZWm<0P2[PDl20:b2D0<0[H=A00<0[XAB0:V4D02YQ5001P2YQ5000`2]Q500[XEA0;27D`03
0;:9E@80/8MC00L0/hYF0;:9E@2aR5@0/8MC0:n6DP2^QE40[HA@00<0[8=?00@0Zh9>0:Z1C@2YP4`0
ZH1<0P2XOd/20:V0C0050:QoB`2WOTX0Ygi:0:MnBP2VODT00P2UO4P20:QnC0030:MmB`2VO4X0YG]9
0080Y7Y800H0XgU70:UoC@2YOdd0Z7i<0:MmB`2VO4X20:EkB@090:AjB02PNTd0WgU<09ihB`2LMTT0
VWA709QbA@2GLD@0UW130080TVQ000H0T6U008iY?`2;IS`0QV<i089Q=P20Gc@407eG<0@0O5H_00@0
OEP^07iI;`20Fc40PUdc0P23GS@2089M<`0608EO<027HC80RF<d08aV=`2>J3T0SfTj0P2>J3T01P2E
JcT0UV`j09I/>P2GKC/0V6hl09U_?@80VW0n0P2FLCd309Mb?P<0V7<o00H0W79009]a?`2HKS`0UV`j
09E[>@2DJSP209E[>@<0Ufdk0P2FK3X309E[>@<0T6Xk0P2AJc`3099/?@@0TVPf102AIcD2095S<P06
091T<`2@IS@0T6Pe08iY=@2?JSH0SVXf202?I3T808]U>0P0S64d0`2;H3D308aQ=P80SF8g0`29Hc@2
08YT=@@0RfDf0P2=IcP208aV=`0408eW>02>J3T0TF/l099/?@80RfTk00H0S6Lj08aV>@2>ICT0SV<h
08eR=`2>HCL208QR<`0608MQ<P26H340QV0a08IP<@27HC80R68c2028HcH02@2:Ic40RFDa08MS;`26
HS00Qf<c08QS=P29I3P0RVDi08eY>@0308aX>00408eY>@2>JSX0T6`l095]?@<0TF`o0P2@Jch308mZ
?@80Sf/g00@0T6`h095]>@2BKSX0TVhj0P2CKc/209U`@P0609Qb@`2HM4@0VGE509QfAP2GMdH0V7Q7
202EMdD309QjA0<0UgU30P2FN4801P2CMD<0T79008e^?`29JS`0QVLk08EU?080Q6@m0100QfPb08EW
<`21ICD0NF4e071J<`1TDRh0FTXY05A5:01;?B80ASXP044g7P0j=1h0<c0M02d^7P0[;Al0:BdO0P0X
:Ql0100W:Ah09RPM02HX7@0U9a`202@V6`0302<V7@0R9A`08B@K00807b8I00<08B@K028U700S9Qd0
0`0S9Q/302@W70<09BPM00L092LL024T6`0O8Q/07AlJ01dO700N81d07R0O00T071hK0P0L8A/06@0N
8AX0824I024S600U9AT0:RPL02`Z7@0d<QT0=S@K03di7P12?B00ASlR04Y18P1<@B<0C44Q05949`1>
@2D0ASXP03ld7P0h<1d0=BhL03D]800e;b40=blJ03P`6`0j<Qd00`0l=1l04P0k<ah0>S8M03Td800h
<b00=S4N03<]7@0a:ad0;RPL02`U6`0[91X0;RPJ02`Y6P0[9a/0:BLK02HV700T9Ad08bHO028U7PP0
9BLL0P0X:Ql302LY7P<09RPM020092DO02LW7`0]:Ad0=2dK03hb6P1>?Al0Gd/X06YD;`1]ERX0L5PZ
079J;01jGc00PVHf08e_?@2FMT<0Vg]8095k?`2QR4P0/Y9E0;>@EP2MNd/0Medh0592:@0m<B40<3<R
034d8`0a<bD0<C<V02la9P0];RH0:R/U02TZ90809RLQ0P0U9R0502@U7`0502HW8@0Y:R80;2hS02h`
8`0^<2800P0^<B03030a8`80;c0R0`0^;b401P0^:Qh0;b/O02l[7`0`;200<BdQ038^8PD0<blS0P0b
;R83034]8@80?c4V00@0?S8V03`b9P0k<bH0>S@V0P0h=BH01`0i<1l0>S4P03hc8@11=240ASLR04Ti
8P1:>R<00P1<>R801P1?@240Cd0S04ho8P1=?B<0C3`S04`l9@80BcXV00<0CS`V04lm9`1@?RP00`1B
@2X2054o:@0905=3:@1B@RP0DT4W05<o9P1E?bL0F40X05Y2:P1L@R/0HTXV0080HT/Y00P0Gd/Z05a9
:@1HAbT0E4DX05939P1HARh0ET@/05=1:@80D3hV00@0DT0X05A2:P1FA2`0FT8V0`1I@BD0501J@RH0
GDDY05m7:`1QBBd0ITd_06A=;P1RBRh0GDP]05U5;01E@b/0DT8[0551:P1??bP0CCdV04/k901<?2D0
CclX0510:@1??bP0CCdV0P17>RL02014>BL0@3LV03hg9`0k=BL0=c@U03Lc9`0g<BD0=S0T0`0e;b<0
0`0f<2@0>38V03Tc9`0203Tc8`0703Pb900g<BD0=BhT03@]9@0c;2@0<b`V034]8@03038^8P<0<blS
00`0=30T03`^8`0m;b@0?C4U03`b9P0j<RD0>38T03@a8P0c<240:b/Q02d]8`0_;bD2034a9`0402l_
9@0/;280:b/Q034Z9080<2TQ00D0<2TO038/800d;R00=c4Q03Pb8P08030/8`08030Z7P0a:al0<R`P
03<]8@0d;R80=BlS03H`900g<BD2038^8`0603D_8`0g;b80>C0Q03``800n<B40?S4P0P18>BH01P15
>2D0@cPT040h8`0o>B<0?SPR03dh8PT0?3LS0P10=2H01010=2@0@CHT044f9011=R82048g8@0904/h
:@1=>RT0D3hX05=1:@1EA2H0EDDT05E58@1EAQl0DT<T00<0DD8S00@0Dd@U05E69`1GBRX0FD`/0`1R
BRP206=;:@<0I4`Z0P1MBR`0101LBB/0FdPZ05Y7:@1IARP205Q59`0^05m49`1PABP0H4LY0619:P1N
BBX0G4TY05]8:01HB2L0FDPZ05U69P1HABD0G4PW06=<:P1YDBd0Je4/06Y@:`1ZDC<0Je0c06aB<@1`
Dc40M5H`07UI<01mG340Oeha08AU=P29JcT0Sg4o09=e@@2DMT00V7]309j1A`2SQT`0YXaC0:b?E@2`
TeT0/YAH0;BDE`2jV5T0`YmO0<RUI@3F[VT0f;5/0=ffL`3Q^gX0i<610>G3Q080i<B700/0j<B:0>>o
Q@3M^X80f;Qo0=FfO@3?/WP0aZaa0<2VJ`37YW<0aJAa0<:QK0020;nNJ00@0<6QJ034Y6T0aZI[0<FU
JP38Z6d0cJed0=6`NP3C/W`0dk9m0=2_O03?[W/0d:ee0<j[L`3;Z700b:E]0<JSJ`<0a:5Y0P3:Yf<0
103;Z6@0c:UU0<fZIP3=ZVH20<j[I`<0cZ][00D0cJYZ0<bYJ@3:YfL0b:EU0<JSH`020<nWK0070<nW
JP3?YfT0cZMV0<fVH`3=YV40c:EP0<6NFP030<2MF@060;nLF02nVeL0_IYF0;fJEP2lVED0_9]F0P2m
VUH00`2nVED0_iQE0;nFE0020<6EE00>0<JNF@35WUT0aIiK0<FOGP34XF40aJ=T0<FUJ037YfX0`ZAV
0<2RI02oX600_YaL0;bKF02lVED20;fHDP050;NEEP2eTe@0/Y1A0:n=CP2]Rd`00`2/RT/0202cTE80
]99C0;FCE02fU5D0^9IG0;VGF02jV5T0^iUJ0P2jVeX0102kW5/0_9eL0;bMG02mWUd20;jOGP040<6O
H033XF80aJ=T0<NUIP80b:IW00X0ajEV0<JTI@39YV`0b:Q]0<b/L`3;[7D0_j9Z0:jCG02ZTE/0/IQR
202]Tf030:Z@G@80ZHmL0`2XSU/00`2/T5h0ZhmM0:Z>G0020:Z>G0090:b@GP2^TV00[i=Q0:nEHP2`
UV<0/IMV0;>HJ@2eVVd0]iaa0080^Iee00`0_Z=h0;nTN@30YGX0`ZMl0<FZO`37[840b:f20<V^P`3<
/8/0c[:=0=2dS`3C]i830=BhT`0O0=>gTP3F^IL0eKRF0=BgU@3B]I<0d;>A0<jaS`3=/8h0c:n=0<V/
P037ZWh0`jIj0;bOL`2fVFd0]iY^0;jQM@34Yg/0aZZ30<R/Q@3:[XT0cK2>0=6dTP3D]iL0e[VK0=Rk
W@3NaJL0glRY0>;:[P3Tck@0iM6h0>GC^`020>CD_@070>OE_@3Xe/00j=K00>SF`03Yel<0j]O60>_H
b@020>cIb`080>cIbP3/fLP0jmS70>[Ha03Yel40j=Jn0>SG_@3We[`30>GC^`80i=:j0`3SdKT0>03X
ckT0j=2h0>O?]`3Vc[@0iLfa0>C=[P3TcJd0hlb/0=o6Y`3QaZP0hLNV0>?6Y03SaJ<0hl:O0>6oVP3O
_IP0h[bH0>6kU`3P^YD0gKN@0=^fS03I]8P0ek:60=JaQ03?[W/0cZej0<jZMP3=Z7<0cJEa0<^RK03:
XFT0bYmX0<:KFP2mUUD0^91B0;J>D@2fSU<0]8]C0:j5C`2ZPD/0Y7U<0:=hB`2QMTT0WgA709ebA@2K
L4<0VFi109Q]@02GKc/0Ufll09A_>`2BKS`0TFdm08i/?P2<Jch0RfXm202?JSH808aW>P<0S6Xl102=
Jcd01`2>K3h0RFDe08UU=@29I3L0R6<g08QS>@27HCX00P27HC`02P2=J3/0S6Lj08]V>@2;IST0S6Lj
08iY?02@Jch0TF`o08iY?02=J3/408aW>P0408eX>`2>JC`0Qf@j08IS>@<0QF8h00<0Qf@j08QU>`29
IS`00P26I3@01025HcD0QF<f08ER>024HCT208AQ>`80QV4d00H0Qf8e08QS=P28HcH0Qf8e08IQ=025
H3<308YU>0@0RfHi0P2<IcX0202>JSX0SFTi08aX>02<J3P0SFTi08m[>`2AKCd0Tflo0P2@JS/2095[
?0@0TV`m0`2AJc`2099/?@<0Tfdn00@0UW4m09Mb?P2GLSh0Ug8n0P2HLcl209Ud@080VGE50P2HM4@0
102IMDD0VgM709eiB@2NNTX209ahA00309eiA@2NNTH0Wg]70080X7a800<0XGe909ehA02MN4@00`2L
Md<0102MN4@0WgY60:1kA`2NNDD209ehA00809ag@`2MN4@0WWU509mjAP2PNdL0Wg];09ijBP2MNDT2
09ahB00309eiB@2NNTX0Wg];00@0Wg];00@0XGe=0:=oC`2UPE40YX9B0`2VPTh20:N3C`<0Z8A@0P2[
QeL00`2/R5P0[HUI0:j:FP020:n;F`030;2<G02]Red0[8YL0080ZhUK102ZR5X01P2_RF80[hYP0:n:
H02_RUh0[hYM0:n;F`80[h]I00P0[hYN0;2;G`2`Reh0/8aL0:n;F@2]RED0[8QD0:^8DP<0ZhMC0P2Z
QU830:V5D@80ZhMC0P2/R5@30:f9E@030:j:EP2^RUX0[HUI0080[8QH00@0[HUI0:n;F`2aSEd0/hmO
0P2cTF403@2dTV@0]YAW0;NDJP2gU6X0^9E]0;VFL02jUg40^ia]0;^LKP2lWFl0_Iib0;jNM@2nWWL0
0P2oWgT20<6QNP80`Z9k0P33Xg`20<BTO@<0ajN00P38Z8430<VYPP040<VYP03:ZX40bZZ10<ZZP@80
bj^20P3<[8<30<b/Q@80cJf60`3>[XL20<n^R`060=2_S03A/8d0dk:?0=BcT03E]940e[FB0`3C/h`2
0=BdS@<0eKF>2P3F^9H30=NiU`<0f;ZH0P3I^iL20=ZlV0<0fkfI00L0g;jJ0=VkV@3J_9X0f[bJ0=^m
V`3L_Y`0gKnM0080g/2N0P3O`Il20=k0WP<0gKnM00<0g;jL0=foW@3M_id02@3M_id20=bnW0<0fkfK
0`3J^IH20=VhU@<0f;ND00<0e;JB0=FgT`3F^9@00P3F^9@0103D]Y80dkFA0=6cS`3C/Y420=>bS`03
0=:bS03B/X/0dK680080dK:60P3@/8T01@3?[hP0cZj70<b/Q@3;Zh@0bZZ300@0bJV2103:ZX<20<^[
Q0P0cJZ000<0c:Uo0<fZP03>Zh400P3?[8800`3=ZX00bjQn0<ZWO@020<RUO@80bJIn103:Ygl00`3;
Z800bZMo0<RUO@020<RUO@030<ZWO`3;Z800cJZ200P0bZZ100@0bZZ30<^[Q03;Zh@0bj^40P3<[8D2
0<f]QP<0bZZ10P39ZH030<RXO`80bZMm0P39YW`40<RUN`<0bjQn0P3:Ygd30<VVO0030<ZWO@39YW`0
b:Ek00<0aZ=i0P37Y7X02039YW`0bZMm0<ZWO`3:Yh40bjN30<^WQ@3<Z8H0c:R80`39YW`20<RUN`<0
ajAj2038YG/30<RTM0050<NSL`35XG40`im_0<2LK02oVf/01`2oWFl01P2nW6h0`9a/0;jJJP2lV6P0
^YIV0;VEI@80^YIV00@0^iMW0;RDH02hU600^9AP0P2iUF430;ZFHP<0_IUY0P2nVVX30;nKJ`<0^YQX
0P2kVFT40;bJJP090;^IJ@2lVVX0_9YZ0;bJJP2kVFT0^IMW0;RFIP2fU6@0]i9U0080]i=S00<0]i=Q
0;NCG`2gU5h00P2gU5`20;JBGP030;NCG`2hU600^IEQ0080^YIR00L0^iMS0;VCHP2iTf80^9=O0;RC
GP2gTUd0]Y5J0080]I5G0P2cT5X00`2dTE/0]I9L0;JCG@020;NDGP030;REG`2jUVH0^YIV00H0^YIV
00D0^iMW0;ZFIP2hU6@0]Y9R0;FAH@030;B@H0080;2=E`2aSUP0/i1J0;BAF`2eTU`0]95K0;>@FP2b
SeT20;>@FP80/XmI00@0/HiH0;2=E`2_S5H0[haF0`2^RUH[ooooo`00:_ooool20:EjA@80YW]60P2W
O4L20:QmB0060:IkAP2WO4L0Yga70:QmB02YOTT0ZWm:0P2[P4/60:V0C080ZX5=202XODX30:^1C`80
[89@0`2]Pe480:b4D@080:f4D02^QE40/8MC0;68E02bRED0/HQD0;27D`2_QU820;:9E@040;68E02`
Qe<0[hIB0:j5D@80[HA@0P2/Pdl20:^2CP040:Z1C@2YP4`0ZH1<0:V0C0<0ZX5=1P2YP4`20:^1C`80
ZX1>0P2YOdd20:QnC080[89@00<0Zh5?0:Z0CP2YOdd00P2XOT`01`2WOD/0Xge@0:9lC`2QNdh0X7Y=
09ihB`2MMdX00P2KMDP209Q^A00609I_A02CKT80T6/o08]Y?026ICP0Q6<f0`20FC8207mH<@<0OUL`
00d0O5L]07iI;`22GC<0Q5le08EP=P24GcD0Pehd085L<P24GRl0QV0a08US=02<ISL0SfTj00<0T6Xk
00H0UF/i09I/>P2FK3X0Ufdk09Q^?02IKcd209Y`?P80UW4m0`2GLSh309Qc?`0509id@P2LLT00VFlm
09M]>`2EJcT00P2DJSP00`2EJcT0UV`j09I/>P0209I/>P@0UF/i0P2?JCX0102@JS/0TF/l095[?02B
K3d209=]?P@0TVPf102AIcD2091Q<`0608mS=02@ISH0T6Pg08mY>02@JST0T6`j202>ICT808]U=PP0
S64d102:Gc@208]P=@80S64f0P29Hc@208YT=@<0RfDf0P2<ISL0202>J3T0SFLh08aV=`2;ICH0S6Hg
08iX>@2@JS/0TF/l0P2;JC/02@2<IcX0S6Hi08iU>@2>HcP0SF8g08iQ=`2=IcP0RfDf08QR<`0208IP
<@0308MQ<P29Hc@0RfDf00P0RV@g00P0RFH`08QT<027Hbl0QV8`08IR<P27HSD0RF@h08YU>@@0SVXj
00@0Sf/k091/?02AKCd0TFdm0`2AK3l2091[?P<0SfXm0P2>JSH0302?JcL0TFdi099^>P2CKc/0U70l
09Ea?@2GKT00V6m109I`@@2FLT80Ug=309IdA080UWI5202EMdD309QjA0<0UgU30P2FN4801P2CMD<0
T79008e^?`29JS`0QVLk08EU?080Q6@m0100QFH`08AV<P20I3@0NF4e071J<`1UDbl0Fd/Z05E6:@1<
?R<0Ac/Q048h7`0j=1h0=34N02h_7`0/;R00:RhP0P0X:Ql0100W:Ah09RPM02HX7@0U9a`202@V6`03
02<V7@0R9A`08B@K00807b8I00<08B@K028U700S9Qd00`0S9Q/302@W70<09BPM00L092LL024T6`0O
8Q/07AlJ01dO700N81d07R0O00T071hK0P0J7aT06@0M81T07b0H028T6@0V9QX0;2XN02h/7`0f<QL0
>CDJ03lj7@15?R40Bd8S04e2901=@R80CT4Q05A59P1@@B@0BC/P044e7@0k<1`0=blL03L^7`0g;b80
>C4J03Xb6`0l=1d00P0n=Ql04@0m=Ah0?3@M03/c700m=b40?3HP03Xc800g<1d0=2dK034Z6P0_9aX0
;RHI030Y6@0_:A/0;RPJ02/W6`0X9QX09BDK00808b@L200V:1d202T[80<0:2XO0`0W:Ah0600V9al0
:2PN02h[700f;a`0@SHL05928@1QCBP0JeD^06iG:`1`F2X0M5`^07]P<@24J3P0SW0n09If@`2JNTL0
Uge00:J8BP2dTUD0/8]D09AdA@1]EC<0BCXU03@/7`80<3<R00H0<C<U030b9@0_<BH0;2dU02X[9@0X
:B<402HW8@@09BHP00H09RLQ02PY8`0Z:b<0;BlT02h`8`0_<B<202ha8005038c9@0a<R@0<C8T030a
8`0_<2800P0^;b401P0];R00;b/O02l[7`0`;200<BdQ038^8P80<blS00<0=30T034]8@0a;B401P0a
;B4203la9P0403hb9P0l<RH0>c<V03Xd9P80>3DV00L0>C0O03Xa800m<R00@C@Q04Df8@18>240BSXS
0080C3XR00H0CSlR04dm8`1=?B<0C3`S04/k901:>BD204Th9P0304dk9@1>?2H0CS`V0080CcdW0`1@
?RP0601B@BL0DD0V058n9@1C?BD0EShV05To:01K@BX0GD4[06189P1OB2P0H4TY05e8:@1KB2X0ETDY
05=3:@1A@BL0EdD]05E3:`1B@2P0CcdU04hl901@?RH0Dd4Y05A2:P80FD4U0P1H@2@03@1J@RH0G4@X
05m7:`1PB2`0Idh`06A=;P1RBRh0GDP]05U5;01D@RX0D40Y04lo:01=?BH00`1<?2D03P1>?RL0CclX
04lo:01>?RL0BCXW04Hi9P15>2L0@SHV03lf9`0l=2L0>S@V03Tc9`0g<BD0=S0T0P0e;b<0300f<2@0
>38V03Xd:00k=BT0>cDU03Xd900i<bD0=c4U03D^900c;2@0<R/S034Z90P0<RhR0P0l<2@02@0k<BD0
>c<V03Tc9@0e<R<0<c0Q034_800Z:R00;2`R02h^9002030`9P0<02l_9@0];B<0;2`R030[9@0_:b80
;RXQ02dY7P0]:Ad0;b`M030]700b;ah0;RXQ0P0_:b800`0`;2<0<BdT034]9002038^9@0802hX700_
:Ad0<2XN034[7`0c;B40=2hR03D_8`0f<2@2038^8`0603D_8`0g;b80>S4R03da8@0o<R80?c8Q0P19
>RL01P15>2D0@cPT03lg8P0m=b40>cDO03Xe7`T0>SDR0P0m;b805P0n<B40@3<R048e9013=R<0A3PR
04Di8`1B>bT0DSdX05A0:01D@bT0ED@X05=49@1CA2<0DD@Q05129`1@@RD0DD8U05528`1EA2H0F4PW
05a9:@1NBb/206=<:P@0HT/Y0P1QBRP01P1KBR`0FTT[05U8:P1GARP0ETDW05A39@80Dd8T0P1J@RH2
05U49`0405Y5:01IARP0FDHX05U6:080GDHW0340GDHV06199`1TC2P0IdlY06UB:@1ZDBT0J4d`06]>
<01]D2h0LE<_07IF;`1jFBh0OU`_07mM;`22HcD0QfPi08e^?`2ALd40TgE109Mi@`2MP4P0XXE=0:68
D02WSE@0[99I0;2CF@2cUET0^IUL0<>QHP39YfP0dJe_0=B`LP3H]WT0fk^00=fnQ@3M`8H0gL280=_1
R03N_HX0fKV60=FfP03B/gd0d;5j0<V/M02oXVP0^9]Q0<2OK02mW6T0^YUT0080^9MQ00/0^YYQ0;bL
H@2nWV<0_IeR0<6QIP37Yfh0c:]e0<j]M`3>[GP0bjYg0<VXM@020<^WK@030<ZVK039YF/0b:AZ00<0
aj=Y0P3;ZFT01P3<ZVX0cJ][0<n]K@3@[Vh0dJm_0=:`L0<0cZa]00h0c:Y[0<^YJP39YfP0b:IW0<NU
IP3<YFh0c:E/0<fVK@3=YV/0c:IX0<ZTI@39Xf80b:9Q0;nLFP80`9eK02<0`YmM0<>PGP32Wed0`9eK
0;fJF02lVEL0`9mJ0<6NFP30WET0`YeI0<:KF033VUP0aIUH0<BHE`3;Xeh0bZ=N0<ZSH039Xf80ajAT
0<NUIP35YFP0aZIY0<BVJ031XfD0_YmO0;bJFP2jVEH0^iQD0;jID`2oVU@0]YAE0;BBD`2aSe00[he>
0:f;C0020:b:B`0:0:f;C02dTU<0]I=D0;JDE@2hUUL0^IMH0;^IFP2lVU/0_I]L0;^LF`80_9eL00<0
_IiM0;jOGP2oX5l00P30XF001032X640a:9S0<JTI@38YVL20<VWJ00:0<RVI`37YFH0bjQ^0<RXK@3<
[7<0c:ef0<:UK@2aUUl0Zi9L0;2GH@P0[99O0`2ZT5d30:V?G080Z8iK0P2/T5h06P2[Sed0ZXiL0:^?
G@2]TEl0[i=Q0;2DHP2aUfH0/YQW0;>HJ@2fVfh0^9eb0;^OM`2mXGT0_Z9k0<6UO@32YWh0`jMo0<BX
P036ZX80b:b40<V]Q@3:[XH0c;2;0<jbS@3@]8l0dkNB0`3D^9<03@3C]i80e[VG0=FhUP3D]iD0d[FC
0=2cT@3>/Hl0cK2>0<b_S@39[800b:]o0<BWN`2mX7@00P2gVVh0402lWg<0`ZEi0<FYPP36ZX<0bJf8
0<b_S@3@/i40dkJF0=JiV`3H^id0g/FW0=o8Z@3RbZh0i<nd0>GA^03Udk/20>CD_@070>SG_@3Xe[h0
jMNo0>WG_`3Zf<80j]S40>_Ha`030>cIbP050>cIb03[f<L0j]S40>[H`P3Yekl00P3Xekd20>KD_0<0
iM>k0`3Td[X20>SB^`040>SB^P3WdKT0i]6f0>KA]080iM2a00P0h/Z^0>?;[`3Uc:h0i/^]0>O:ZP3U
b:H0hlFS0>C3X080hl:S02H0h/6P0>70W@3O_iT0g[jG0=fmUP3M_I@0fKZ>0=VhS@3G]XT0e[B60=Jb
PP3E[gh0eZim0=F]NP3?ZFP0bZAU0<FOH033WEh0`ieO0<6KG@2lUUP0^99D0;67E`2_QED0[H=C0:Uo
C`2VO4`0XgU90:1fAP2OMDD0WG@n09ed@02KLcl0V7<o09Ib@02FLT80Tg53099b@`80Tfhj0`2BKCT3
095/>0P0T6/n00<0T6`l095]?@2AKCd00P2BKSh309=_?`0608iZ>02>JSX0SVXj08eX>`2=J3`0S6Lm
0P2<ISl00`2?JSd0SVTl08eX>`0208eX>`0308mZ?@2AK3l0TVe00080T6`l102?Jc/2091/?0<0RFLj
00<0RVPk08]Y?02<JSd00P2=Jch01P2:JCH0RFLg08UW=`29IcT0R6Hi08QU>`80Qf@l1@2:ICP208UT
=`0308QS=P2;IST0S6Lj00<0S6Lj0P2=J3/208iY?008091/?02?Jc/0SVXj08iZ>P2?Jc/0TFdm09=_
?`2ELD4409=]?P@0U6ho00@0Tfdn09A^?`2DKSl0U6ho0P2EKd0209I`@@<0V7<o0P2IM40309Ye@@03
09YfAP2IMDD0VGE50080VGE500<0VgM709ijBP2ONd/00`2ONdL00`2PO4P0XGe90:5mB@020:9nBP@0
WWU500L0WgY60:1kA`2PNdL0XGa80:9mB@2PNdL0WWU50080WGQ400@0WgY60:9mB@2TOd/0XGe=1P2P
O4`40:5mC@030:9nCP2SOdl0Y81@0080YX9B0P2WPdl20:R4D0@0ZHEA0P2/R5P0102]RET0[XYJ0:n;
F`2`S5`20;6=G@050:j<GP2]Red0[8YL0:^9F`2ZR5X00P2[RE/01`2/RU`0/XaU0;:=H`2bSF<0/XeQ
0;:=H02bSUh00P2bSU`01P2cSV40/XeP0;:>GP2aSEd0/8aL0:n;F@80[XYH00D0[h]I0:j:F02^RUP0
[HUG0:b8EP030:^7E@80[8QD0P2]RED30:j:EP030:n;E`2`S5`0[h]K0080[XYJ00@0[h]K0;6=G@2c
Sel0]I5Q0P2eTf<01@2fU6H0^9IY0;VFK02iUV`0^iQ`0080_9Uc00T0_Ii_0;fNL02nWg40_j1d0<2P
M`31XGX0`J5k0<:RO033Xg`00P34Y7d00`35YGh0aZIo0<JVO`020<NWP080bZZ40P3;ZhD30<b/QP04
0<f]Q`3=[HH0cJf60<f]QP80cZj70`3?[hP20<n_R@80d;2:0`3A/H/01`3B/X`0d[6>0=>bS`3D/i00
eKBA0=JeTP3G]Y<00P3H]i@30=JfT080ekNA0`3H^98;0=RjV080fK^I0`3J_9X30=^mV`<0g;jL0P3M
_id00`3K_I/0g;jL0=bnW0020=foW@80g/2N00<0gl6O0>32X03P`Z000P3O`Il30=k0WP030=foW@3N
`9h0g/2N00H0g/2N0`3M_id30=bnW080fkfK0`3J^IH30=VhU@80f;ND00h0e;JB0=FgT`3F^9@0ekVE
0=JhU03E]i<0dkFA0=:dT03D/i80e;>@0=>bS`3C/hd0dk><0=:bR@80d[>70P3B/X/01P3@/8T0cjn8
0<f]QP3;Zh@0bZZ30<VYPP@0b:R10`39ZH820<ZZP`P0cZ^100P0cJZ00<j[P@3?[880d:f30<n/PP3>
Zh40c:Uo0<ZWO@80bJIn1P3:Ygl00`3;Z800bZMo0<RUO@020<NTO0030<VVOP3:Ygl0bjR000P0bj^2
00@0bj^40<b/Q@3<[8D0c:b50P3=[HH20<j^Q`<0bj^20P3:ZX430<VYP0@0bZMm1039YW`30<^XOP80
bZMm0`39YW`00`3:Ygd0bJIl0<VVO0020<RUN`80ajAj00H0b:Ek0<ZXN`3:Z7/0bZMm0<^XP03;Z882
0<bXQ0030<bXQP3:Ygd0bZMm0080bJIl0P38YG/20<NTNPP0b:Ek0P38XgH01P37XWD0aZ5d0<BOLP33
WW40`Ia_0<2KKP@0`9i`102oWFl01031WFd0_i][0;fIJ@2kUfL20;ZFIP030;^GI`2lV6P0^IEQ0080
^IEQ0P2jUV830;^GH`<0_YYZ0P2oVf/30<2LK0<0^iUY0`2lVVX30;fKJ`060;jLK02mVf/0_I][0;bJ
JP2kVFT0^YQX0P2iUfL01P2iU6L0^IEU0;VEI@2iUF<0^9AP0;REG`80^9EM0P2hU6020;VEH@040;ZF
HP2kUf<0^iMS0;^GH`80^YAS00@0^IAP0;RCGP2gTUd0]Y5J0P2eTEL20;BAF`030;FBG02fTed0]iAN
0080^9EO00<0^IIP0;^GI`2kUfL01P2kUfL0102nVVX0_9QX0;RDI02eTF420;B@H0050;JBHP2gTf<0
/XmI0;>@FP2dTE/00P2fTed00`2eTU`0/i1J0;:?F@020;>@FP80/XmI0P2aSUP20;2=E`<0[HYD:ooo
ool002[ooooo0P2UNTD20:IkAP80Yga70P2XODP20:MlA`030:QmB02YOTT0ZWm:0080Zh1;00<0[85<
0:Z1C@2ZPDd01P2YP4`80:QmBP80ZX1>0P2[PDl20:b2D0X0[H=A00<0[8=?0:f4D02_QU800`2aR5@0
0`2`Qe<0[hIB0;:9E@020;68E0060;27D`2_QU80[XEA0:j5D@2]Q500[8=?102[PTh30:Z1C@<0Zh9>
1P2/Pdl20:n5D`<0[XAB0`2]Pe401P2^Q580[H=A0:f3D@2/PU00Zh5?0:Z0CP80ZGm=0P2TOU40102S
OE00XWa?0:1jC@2OND`209ihB`80WgI:01l0W7I909YeB02GLTD0TFm108e]?P2;Jc`0REli08QN>027
GCL0QU`f08AJ=023FC<0PUPb085G<@1mF2h0OeX`08=N=025H3H0QV4g08EP=P24GcD0PUdc08EO<027
HC80RV@e08eW>02?JCX0T6Xk095[?02@JS/0UF/i0080UV`j00<0Ufdk09Q^?02IKcd00P2JL3h209Ia
?@<0Ug8n0`2HLcl0102NM480WG=109Y`?P2GKC/<09E[>@80SfTj00@0T6Xk095[?02AJc`0TV`m0P2C
KCh209=Y=`80TVPf0P2AIcD2091V=080T64e00H0Sf<f091U>02@IcT0SfTj091Z>`2@K3`808aV>@P0
RfDd202=HSD408YO=080Rf0e0P2<HCH308YT=@80RfDf102<ISL00`2>J3T0SFLh08aV=`0208]U=P03
08eW>02>J3T0T6Xk0080RfTk00h0S6Lj08aV>@2>ICT0SV<h08eR=`2>HCL0TF/l08mY>P2<ISL0RV@e
08US=02;ICH0SFLh08iX>@P0SF@h00T0R6D_08QT<027Hbl0QV8`08MS<`28HcH0RVDi08aW>`2>JSX0
0P2?Jc/5091/?0<0TF`o0P2@Jch308mZ?@80SVXf00H0Sf/g095]>@2BKSX0Tflk09A`?02ELCd209A[
?@0609=]?P2CKcl0U71009=a@@2BLT40Tg=2202EMdD309QjA0<0UgU30P2FN4801P2CMD<0T79008e^
?`29JS`0QVLk08EU?080Q6@m0100QFH`08AV<P20I3@0NF4e071J<`1UDbl0Fd/Z05E6:@1=?b@0B3`R
04<i800k=Al0=34N02l`800];b40:blQ0P0X:Ql0100W:Ah09RPM02HX7@0U9a`202@V6`0302<V7@0R
9A`08B@K00807b8I00<08B@K028U700S9Qd00`0S9Q/302@W70<09BPM00L092LL024T6`0O8Q/07AlJ
01dO700N81d07R0O00T071hK0P0J7aT06@0L7aP07b0H028T6@0W9a/0;2XN02l]800h<aH0>cHI048k
7P1:@B@0CT<U0554901@@b40D44P05E5901B@B<0Bc`O04@f700m<A/0>RlM03X^7P0i<240?C<J03hd
6`10=Qd00P12>1l02P11=ah0@3HM03le7010>Al0?cPN03de7P0k<ah0>30M03H^6`0d:aX203<Z6@07
038[6`0a:QX0;RPJ02/W6`0X9QX09BDK02@T6P0802HX7@80:B/P0`0X:Ql302LY7P0P02PZ7`0Y:Ad0
;R/J03Pb7017?200EdLU06A@:`1/ERd0K5DY06mG:@1cFbd0Nf0a08=W=`2<KS`0Tg=009MgA02OPD<0
Zha<0;FAD`2[QTl0RfXm06=<;@11=BD0<2`S02lb8@0`<b80<38T030b9@0^<2D0;2dU02TZ900X:B<4
02HW8@@09bPR00T0:2TS02TZ900/;BD0;S0U02la900_<B<0;c8Q02ha800c=2H00P0b<bD01P0a<R@0
;c0R02h_8@0^;b40;BhP02l[7`80<2`P00<0<BdQ038^8P0c;b<00P0d<2@8034]8@80?c4V00@0?S8V
03`b9P0k<bH0>S@V0P0h=BH01`0i<1l0>S4P03hc8@11=240ACHQ04Ti8P1:>R<00P1<>R801P1=?B<0
CCdT04`l8`1;>b@0BSTU04Xi9`80BCPX101:>28204/i8`80C3XT0P1B?RD01`1B?2@0E3`T05Hl9@1I
?BL0FclY05m0:`1MA2D00P1MARL0201KART0FDDZ05E4:P1A@BP0D40W05=1:@1A?bL0CS`T0P1;>B40
101=>b<0D3hV0590:01J@RH305U19@0>05Y29P1MABT0GdL[0659;@1VCBl0I4d^0659;@1LAb`0F4@[
05=1:@1@@2T0CShW04/k901<?2D204dm9P80C3`U00`0CCdV04hn9`19>2H0AcPU04Hf9P13=RH0@CDW
03hd:00l=2L0>c<X03La9@0f<2@203D_8`0<03H`900h<RH0>S@X03`f:P0k=BD0>S@T03Tc9@0g<BD0
=BhT03</900b:b<0<BXT100c;b<4038^8P0>03X`900k<BD0>S8U03Tc9@0f<b@0<c4R034_800];Qh0
:b/Q02`/8P0];B<0;RhT02l_9@0^;R@202d]8`0802l/9@0^:b80;BXQ02/Y7@0[:A`0;2XK02d/6P0^
;A/202hZ8@0302l[8P0`;2<0<BdT0080<RhU01T0<blV02hX700_:Ad0<2XN034[7`0b;200<bdQ03@^
8P0e;b<0<BdR038^8`0e;b<0>30S03Xa8P0n<R80@3<S044d8`19>RL0B3TV04Dh9@12=b<0?SHQ03/e
7`0j=1h0>3<M00T0>38R01P0?BdP03h^8@10<240@S8R04@d9016=b@0AcPS04Pi901E?2H0ESdW05Do
9`1F@RT0Dd@W05539P1>@b<0CD8R04e19`1?@BL0D40V05=29P1GA2@0G4PW065::01TC2X3065=:P80
H4`Y0`1OBbP0201KBR`0FTT[05U8:P1GARP0ED@V05=2901A@280D3lQ0`1C@RH0B`1E@BH0ET8W05I2
9`1H@bP0FD@Y06549P1QARP0HdTX06E;:01VCRP0Ie0W06UB:01ZDbT0JTd_06e>;`1`DS00MED_07YI
<01nG2l0PUd`08=O;`22HcL0QfPj08e^@02ALT<0TWA209IhA02LOTP0XH==09f6D02TRe<0ZI1G0:fC
FP2bUE/0^9YN0<6QI038Z6/0cZmh0=6bN`3E]h40f;f60=W0RP3G`8`0eKj<0=>mR`3B]HT0c[:30<b`
P03=[gd0c:ij0<R[L`31XV/0^iaS0;VHI@2gUV<0/i9M0;2?F@2_SUP0/I5H0;>CF02eUEX0]iML0;^K
H030X6L0aJA^0<NVL037YW40aZEb0<BSL037X6D0b:5V0<ZSJ03<YFX0cZM/0<nXK@020=2YKP80cJ]^
00@0cZa_0<n]L03A[g80d[1c0P3C/G@20<n/LP040<fZL03<ZFl0bZM]0<VVK080b:E[00T0aj9^0<NR
K@38Xfh0bJA]0<RTJP35XFD0`imQ0<6MG`2oW5`00P30WEd03033X600aJ9R0<BQH@32Wel0_iaL0;fJ
FP33XUd0a:5M0<>PG035X5`0aIiK0<JMF`80ai]J00H0bZ9M0<VRG@39XUl0b:9Q0<JSH`35Xf@20<:R
I@060<JXJP33YFL0`:5Q0;jLG02kVUL0^iQD0P2nVE<0102cTE80/Y1A0;2>C`2^S4d20:f;C080[Xa=
00T0]I=D0;JDE@2gUEH0^IMH0;^IFP2mVe`0_YaM0;nMGP2mWUd00P2nWeh00`2oX5l0`:5P0<6RH@02
0<:SHP040<>QHP35Xf@0ajEV0<VWJ080bZQY00X0bJMX0<RVI`3<ZFl0b:Q]0<^[LP3=[WL0a:M_0;BI
HP2/Ted0[YEO202/TUl20:^AGP<0ZY1M0`2YSe`20:b@GP80ZhmM0180[91N0:jBH02aUF<0/YIT0;:G
J02cV6T0]IY]0;RMLP2lX7P0_j=l0<6UOP32YX40a:R10<FYPP36ZX<0aj^40<R/Q@39[HH20<Z^Q`04
0<b`R`3>/Xd0d;B?0=>gTP<0e;RC01l0dkNB0=NjV03F^IL0eKRF0=>fU03A]980ck:@0<jaS`3=/8h0
bZf10<V/P035Z7`0_Z5e0;NJKP2fVFd0^Yea0;nRMP33Yh00aJV20<R/Q`3;[X`0ck:@0=>fUP3F^I/0
ekZL0=g4YP3NajP0h/Z^0>C?]03Vd[T0iM>k0080iMFn00L0j=Nk0>SG_@3Yf;h0jMRn0>[H`03[fL<0
k=[60080kM[900H0kM[;0>gJb@3/fLP0jmW50>[H`P3Yekl20>SG_@80imFm0P3Ve;`40>GC^`80j=>n
00@0j=Bl0>SD^`3WdkP0im>h0P3We;H06`3Rc[D0hlnf0>G@]@3Wck<0j<na0>O<[P3UbZ`0iLRX0>76
Z`3QaZT0h<FX0>35Y`3OaJ@0g/BQ0=k4W`3M`ih0gL6L0=foV@3L_YP0g;bE0=bkTP3K^8h0g;N;0=^f
RP3G/gT0dZid0<jZL0020<bXK00D0<^WJ`36XVH0`IeO0;bBH02jT5h0]heK0;>9E`2_QE<0Zh5?0:Qn
C02WOD/0Y7U20:AiA02RNDD0X7Q409ag@`2JMT@0VGE509MeA@2FLCd209E`?080U6lk0P2CKSX00`2B
KCT0UG1309E`@`0609E`@`D0Tflm0`2DL3h01P2CKc/0TVhl099^?02BKSh0TF`o095/@080T6]100<0
T6/n08mZ?@2=J3/00P2=J3/00`2>JC`0T6/n095/?`02091/>P@0TFdk0P2@K3X0102<JS`0SF/m08i/
?P2?KCl2091^@080TFm100H0SF`g08e/>@2=K3T0S6Xj08aZ?02;JC`208]X?P80SVTl00<0SFPk08aW
>P2<IcX00`2;IST208eX>`<0SVTl0`2?JSd00`2@Jch0TVhn095]?@02091/?004095]?@2CKcl0UG51
09Ib@PX0UW110P2GLD8309Qb@`0309UcA02IM400VGA00080VWE10`2KMT802P2LMd<0VgM709YfAP2J
MTH0VGE509YfAP2LN4P0Wg];0:1lC02PO4P40:5mB@<0XWi:00@0WgY60:1kA`2PNdL0XGa8102RODT0
2@2TOd/0Xgi:0:5lB02ONTH0X7]70:9mB@2UP4`0Yh9>0:9nCP060:=oC`80XWi>00<0Xgm?0:B0D02U
PE400P2VPU820:N3D`@0ZHEA0P2ZQU820:^7D`80[XYJ0P2_Re/03@2`S5`0/HeM0;:>GP2bSUh0/HmQ
0;2>H02]Red0[8YL0:^9F`2/RU`0[XaN0:n=G`2dSVL00P2dSfD00`2dSf<0]8mR0;B@H0020;B@GP06
0;JBH02eTEl0]91N0;>?G`2bSUh0/HeM0P2aS5l20;:>GP040;6=G@2`S5`0[h]K0:j:FP80[HUI0`2[
Qe<20:b8E0<0[HUE0P2bSUh20;6=G@080;:>GP2dT600]Y9R0;NCH`2gUFD0^9IV0;VGJ@2jV6/20;bI
K`040;fJLP2nVgD0_iaf0;nPL@80`:5c00<0`J9f0<:RN@33Xg`00P34Y7h01P35YGh0aZIo0<NWP038
Z840bJV20<ZZP`80bj^400@0cJb90<j]RP3>[HX0cZf:0P3?[X/20=2_S0<0d;2:0P3A/H/30=:bS004
0=:aSP3C/Xl0dk:?0=>bS`80e;>@0P3E]9420=NfT`80f;ND00D0fKRE0=ZiUP3J^IH0fkZG0=RgU003
0=VhU@80f[VF0P3K^YL;0=ZlVP80fkfK1@3L_Y`30=foW@L0g/2N103O`Il0103Q`j40h<:P0>32X03P
`Z020=o1W``0g/2N0`3M_id30=bnW080fkZG0`3J^IH30=VhU@030=FgT`3F^9@0ekVE0080ekVE00T0
eKNC0=>eT@3B]900eKBC0=FdT@3D/i00e;B>0=>cS03C/hX00P3C]8P20=>cS0060=6aRP3@/8T0cZj7
0<b/Q@3;Zh@0bZZ31038Z8430<VYPP80bZZ3203>Zh400`3=ZX00cZ^10<n/PP020=2]P`030<j[P@3<
ZGl0bjQn0080bjR01P3:Ygl00`3<ZH40bjR00<VVOP020<RUO@030<VVOP3:Ygl0bjR000P0c:b30P3<
[8D20<f]QP<0cZj700@0cjn80<b/P`3<[8<0c:b30P3;Zh830<ZZP@@0bZMm1`3;Z7h20<ZWO@<0bJIl
103:Ygd20<VVO080b:Ek0P3:Z7X01P3;ZG`0bjQn0<bYP@3<ZH<0cJZ40<fYQ@<0bZMm0P39YW`;0<RU
N`80bJAh00@0aj9f0<JQM@35X7@0a9mc0P33WW820<:PLP80`Ima0P30WW020;nMK`040<:NKP30W6`0
_YYZ0;bHJ080^iMW00<0_9QX0;fIJ@2jUV800P2jUV820;^GH`<0_9QT0`2oVf/20<2LK0<0`Ie]102l
VVX20;fKJ`<0_Ya/00D0`9i^0;nMK@2nW6`0_I][0;bJJP030;^IJ@090;bGJP2kUfL0^iMW0;ZFI02j
UV80^IIP0;VFGP2hUEd0^YIR00@0^iMS0`2lV6@20;ZDH`040;VDH02hTeh0^9=N0;NBF`80]Y9H0P2e
TU`00`2fTed0]iAN0;REG`020;VFH0030;ZGH@2lV6P0_9QX00H0_9QX00@0_i][0;fIJ@2iUFD0]Y9R
0P2eTF402@2gTf<0^9AT0;>@FP2dTE/0]Y=M0;NDGP2fTed0]I9L0;BAF`030;>@FP@0/XmI0P2aSUP3
0:j;EB_ooooo000Zooooo`80YGY50P2VNdH20:MlA`80Z7e800H0Yga70:QmB02XODP0ZGi90:YoBP2[
P4/20:b1C0<0ZX5=0`2YP4`20:QoB`P0ZWm<0`2ZP4h20:^1C`<0[89@202_Pe80202/Pdl0[HA@0:n6
DP2`Qe<0/HQD0;27D`2_QU80[XEA0P2aR5@20;27D`80[hIB0P2^QE480:^2CP80[8=?00D0[HA@0:j5
D@2^QE40[XEA0:n6DP020;27D`P0/XQF00H0/HME0;26E02`QU@0[hEC0:j4DP2]Pe420:b2D0060:R2
E@2WPE@0Yh5D0:J0D`2UOe80Y7iA0P2SOE020:ElCP0D0:=mCP2QODd0Wg];09UgA`2EMD@0Tg=209=W
@P2BIT40T6@o08eQ?02:GST0Qe/f08EI=024F3<0P5/a085L<P23GS@0Q5le08EP=P26HCL208EP=P05
08IP<@28HS<0RfDf08iX>@2?JCX00P2@JS/01`2?JCX0UF/i09I/>P2FK3X0Ufdk09Q^?02IKcd00P2J
L3h209Ia?@<0Ug8n0`2HLcl0102NM480W79009Y`?P2GKC/309I/>P0309M]>`2CJCL0U6Xh0080U6Xh
0`2EJcT0102FK3X0T6Xk091Z>`2@JS/2095[?0<0TV`m00D0U6Xh09=Y=`2CJCL0TVPf095W=@02091V
=00908mU<`2AHSP0TF8h091S>@2@ICX0T6Lk08iX>`2?JC`0SVTl00P0RfHi202;IS8808eR=@<0Rf0e
0`2<HCH208eR=`80RV@e0P2;ICH408aV=`0408eW>02>J3T0SFLh08aV=`80RfDf00<0S6Hg08eW>02>
J3T00P2;JC/02P2<IcX0S6Hi08iU>@2>HcP0SF8g08iQ=`2BK3d0TF/l08mY>P2>J3T408eW>0P0Sf@i
00P0RFH`08QT<028I300Qf<a08QT=02:ICP0S6Lk08iY?@80SVXj00H0Sf/k091/?02@K3`0T6`l08m[
>`2>JSX3095/?`80T6/n0`2?JSd208m[=`04091/>02AKCT0TVhj099^>P80Tflk00H0TVTk09=Z?02A
Jc`0TFdm099^?P2AKcl2095a@0P0UGM50`2HNT@309Mi@`80UWQ200H0TgE3091b@02=KSl0RFXl08IW
>`25IC`208AT?@0@08MX<P25Ic<0PFDe07UQ=@1`FS<0I58^05Y::@1DABP0CT0U04Tm8`14>R40?3HP
03Db7`0`<B40;S0R02``8P80:2XO00@09bTN02HX7@0V:1d09BLL0P0T9Q/00`0S9Qd08RDL024T6`02
01lR6@03024T6`0R9A`08bHM00<08bHK0`0T9a`302DX7@0702@W700Q91/07b8K01dO6P0M7a`07R0M
01hP7`0901`N6`806QlI02D07B0I01lP600R91T09RHJ02`Z7P0^;1l0>C8F03df6@16?B00CD8T0595
9@1CA2<0DT@Q05517`1HAB@0ED8R04dl7P15=A/0@34J03`_700l;ah0?30P040d6P11=A/0@cLM04@h
7P15>Al0A3PN04<g7@12=Q`0@cXM048i7011=a`0?cDL03db700k<1`0>RlK0080>BhL00L0=RdL03@[
6P0b:a/0;bTK02/W6`0Y9a/0:2HJ00P09bTN0P0X:Ql302LY7P<09RPM01P0:R`Q02X[7@0_;1T0>S@L
04]08P1KBbL0Ie@/06eH;@1/EBT0L5PZ07AL;P1lHC80Q6Ph08a^?02CLd00UWI30:J7A`2aSDl0]Y1B
0:InBP22HCP0FD@Y03dc9`0a;RT202lb8@06030b900_<B@0;S0U02//900Y:R@09bPR0P0V9b4202LX
8P@0:2TS00h0:BXT02//9P0];RH0;c4V030b9@0`<R@0;c8Q02ha800d=BL0<c@V038c9@0a<R@0<34S
02h_8@80;BhP0P0`;2000`0a;B40<RhR03<_8`0203@`900403Da9@0a;B40<BdQ034]8@80<RhR0`0c
;b<203la9P0403hb9P0l<RH0>c<V03Xd9P80>3DV00L0>c8Q03`c8P0o=280@SDR04Lh8`1:>R<0C3`U
0080CS`T00T0CShU04hn9`1=?BH0C3/W04/j:01:>BT0BSPZ04Tg:@19=b400P18=R006017=Al0B3HP
04Tg8@1:>280BcTS058l901A>b<0Dc/S05@j8`1F>R@0Fc`W05dn:@1P@2/0Fd8T05Y3901K@bL0FD@Y
05M3:P1C@BT0D40Y04lo:01@?RH0CS`T04/i8@80BSPP00<0CC/S050n9P1B@2P00P1K@bL205Y29P0O
05a4:01NARX0HDT]069:;P1TBbd0HT//0618;01LAb`0F4@[05=1:@1@@2T0CclX04`l9@1>?RL0CclX
04hn9`1;>b@0BCTR04/k901=?BH0BCHU04Pg9@17=RH0ACDV048d9`10=2P0?C<W03dc:@0i<bL0>38V
03La9@0203H`900303Pb9P0i<bL0>cDY0080>C<S00H0>38T03La9@0e;R@0=2dU03</900c;2H303Da
9@80=30T0`0c;b<02@0i<B@0>S8U03Tc9@0g=2D0=C<T030a8@0^;al0:bhM02`/8P0502d]8`80;2`R
00T0;RhV02`/8P0[:b40:BTM02TZ700Z:a/0:b`J02`]6`0^:R400P0_:b800`0`;2<0<BdT034]9002
038^9@<0<B/O0P0b;20303<]8@0@034]8P0b;R<0=BlS03P`8`0k<R<0?c<S044d9012=B@0B3TV04Lh
9@14=b@0@CHR03de800k=Al0>C<M03Pc7@T0>38T01P0?bdQ040^8P12<280A3<S04He9@18=bD0BCPT
04Xi9@1E>B40EC/R05Hn901D@2D0DD4W04i39`1;@RD0B44T04]0:P1<@2P0D40W05=29P1IA2D0H4PV
06M::01YCBP2061>:P@0GddY0P1NC2P02P1LCBh0Fd`]05U::`1FAbP0Dd@U05528`1?@240CSlP04i3
9`1?@BH205109P1205A09`1E@BP0F48Z05]3:`1UA2D0JDPY06]=:`1[CbX0JE0X06QA9`1YE2T0JeHY
06e>;`1aD2l0ME@a07YH<P1oG380Q5lb08IP<@27HC00QFDl08Y[?`2?L4@0TW=5099cA02EMdD0Vge9
0:22CP2LQe00XHYD0:NAF02/TeX0/9IM0;NJH030XVH0ajU]0<jbP03@]X<0e[b;0=S0T03H`Y<0e/6D
0=6nT`3?_940bK:90<N^Q@34[800ajam0<Z^O03;[GL0b:Ub0<>TJ`2iV6D0]YER0;:AG02^SEL0[8]E
0:b<D`2^SU<0[hmD0;>CF02eUEX0^IUP0;bKI@2oWVP0`J1[0P31X6d02037Wf80bJ5T0<bTI`3@Z6/0
e:a_0=J^L@3G[g80f;1c0P3=[G@20<j^M@080<n_MP3@/7L0dK5h0=6aN03=[7H0c:]e0<ZYL`38Yg44
0<JUK`090<JRL037Xg40b:A`0<VVL037Y6h0a:5Y0<6NI02nVf40`9aN0080`YiP00L0a:1R0<FQH`35
XF<0a:1R0<6MG`30W5h0a:=N0080aJ9N00<0aZ5M0<NPG@37WU`00P39WE`04P38X5/0aj1K0<RQGP38
XV40aJ9R0<>QHP30X6<0_imR0<FWJ@33YFL0`:5Q0;jLG02jVEH0^9EA0;VDCP2hTdd0[he>0:j<C@<0
[H]<00/0[Xa=0;2>C`2aSe00]I=D0;JDE@2hUUL0^YQI0;bJF`2oWEh0`9iO0<6OH0020;nPG`040<2Q
H031XV40`Z=R0<>TH`80a:ET00D0a:9S0<JTI@38YVL0bZQY0<^YJP020<ZXJ@070<VWJ03=ZW00bJU^
0<^[LP3>[gP0ajYb0;JKI0020:fDGP/0Zi5N0P2ZT5d30:V?G00@0:fAG`2/T5h0[91N0:b@GP2]TEl0
/9AR0;:FI02dV6H0/iQ[0;FJK@2gW740^img0;nSO032YX40aJV40<JYQ`<0b:b70P39[HP30<Z^R@04
0<b`R`3>/Xd0d;B?0=>gTP<0e;RC01l0dkNB0=NjV03F^IL0eKRF0=>fU03A]980ck:@0<jaS`3=/8h0
bjj20<Z]P@37ZWh0_j9f0;RKK`2fVFd0^Ia`0;fPM032YWl0`jN00<JZQ@3:[H/0ck:@0=:eU@3F^I/0
ekZL0=c3Y@3MaZL0hLV]0>?>/`3Vd[T0i]Bl0080i]Jo00L0jMRj0>WH_03ZfKd0j]Vm0>[I_`3[fL40
k=[40080kM_700H0kM[;0>gJb@3/fLP0jmW50>[H`P3Zf<020>WH_P80j=Jn0P3WeKd30>KD_0060>GC
^`3Ve<00i]C00>KD_P3Ve;`0i]Fk0P3VeKT02P3VeKL0hM6j0>;B^`3Td[X0im>j0>OB]`3Xd;@0i/n`
0>K=[`3Sb[@20>;:/P030>79[`3QbJd0h<VZ0080glRX00H0glJW0>35Y`3OaJ@0gl:P0=o1W`3O_Y/2
0=nmV00H0=njSP3K]XT0e[640=FaP@3E/Gl0e;1l0<n/MP3;Z700aiiZ0<JMJ@33VVH0_iIR0;^BGP2g
SUX0]8]G0;>:EP2`Pd`0[h9;0:b1C02YP4`0YWi:0:9mB@2QNdX0Wg]90P2KMT8209Ye@@0409Ud@02H
Lcl0Ug8n09Mb?PP0VGA700D0VGA009Qc?`2HLcl0V7<o09Mb?P0309Ia?@0609Ic?@2ELCd0UG4m09Ea
?`2DL400U6m20P2CKT800`2BKD00TF`o091[?P0208mZ?@05091[?P2AK3l0TVe0099^>P2CKc/0102D
L3`01@2CKc/0TVhj095_?`2BL400Tg5100<0U7920P2CLD401P2AL3X0TG0k091_>P2@Kc`0T6hn08m]
?`80Sfe000@0Tfi1099]@02@Jch0SVTl0P2=J3/208iY?080SfXm102@Jch3095/?`80Tflo0P2BKSh0
102CKcl0UG5109Mc@`2HM4@309UcA0<0V7930P2GLD8309UcA080VWA50`2KMDH309]f@P80W7M30`2M
N4@0202LN4P0VgM709]gA`2JMTH0VgM709eiB@2ONd/0XGe=202QODT00`2PNdL0XGa80:=nBP030:Ao
B`80Xgi:00/0YH1<0:AoB`2SOTX0Xgi:0:AoB`2UP4`0YX5=0:N2CP2TP500YH5A0:J2DP020:N3D`06
0:J2DP2UPE40Y81@0:B0D02UPE40Yh=C0`2XQ5@20:N3D`<0ZXIB0P2[Qe<30:b8E080[h]K00<0/8aL
0;6=G@2bSUh00P2cSel02P2dT600]I=U0;>AH`2`SV00[XaN0:f;G@2_SEl0/HmQ0;:@HP2gTFX20;NB
J0030;NBIP2gTVD0]i=S0080]i=Q00H0^IIP0;RDH02fTUh0]91N0;>?G`2cSV420;B?H`060;JAI02e
T6<0]8mR0;>>H@2aS5l0/8]N0P2_RUd30:b8E080[HUE0`2^RUH0202eTF40]91P0;>?G`2cSel0]91P
0;JBHP2hU6@0^IEU0P2jV6P03@2kVF/0_9Y]0;jKL@2nVg40_iad0<2MM`31WWP0`Z=d0<:SM@33Y7H0
`jAh0<BTN`35YGh00P36YX001P37Yh00b:R10<VYPP3:ZX<0c:b50<f]QP80cZj70`3A/8l20=:aT0<0
dk:A0P3C/Xl20=BcT0<0eKBA00@0e[FB0=JeU03F]I@0e[FD0P3G]YD30=RgUP030=ZiUP3K^YL0fkZG
0080g;^H0`3M_9T20=^jV@80g;^J0`3M_9/00`3N_I`0g;jL0=bnW0090=bnW0<0gKnM0P3N`9h0103M
_Yl0g[nP0=joX03N_j020=o0X@80h<6R203P`Z00103Ra:80hL>Q0>73X@3Q`j420>32X080gl6O2`3N
`9h20=foW@<0g;jL0`3K^YL20=ZiUP<0fKRE0140eKNC0=JhU03G^ID0f;ZF0=NiU@3F^9@0e;JB0=>e
T@3F]I@0e[FB0=FdT@3E]Hl0e;B=0=BdR`3D]HT0dkB80=>cS0020=:bR`050=2`R@3?[hP0cZj70<f]
QP3<[8D00`39ZH840<ZZP`80bj^42@3>Zh401`3?[880d:f30=2]P`3@[H<0cZ^10<fZP03;Z7h00P3<
ZH420<^XP0@0bZMo00P0cZ^30<fZPP3;Z800bZMo0<VVOP3:Ygl0bjR00<bYP@P0cJf40P3=[HH20<j^
Q`<0cjn800@0d;290<f]Q03=[H@0cJf40P3<[8<30<^[PP80bZMm0P3;Z7h40<bYO`<0bjQn0P3:Ygd3
0<VVO0080<ZWO@3;Z7h0bjQn0<bYO`3;Z7h0bZMm0<VVO038YG/20<^YN@040<^YN`3<ZWd0c:Uo0<fZ
PP80cJZ400@0bjQn0<ZWO@3:Ygd0bZMm0P39YW`:0<RUN`040<^VO03:YG/0bJAj0<NRN0@0aZ5g00H0
a:9d0<>QL`33XG<0`Z1b0<6OL@30WW020;nMK`040<>OK`31WFd0_i][0;fIJ@80_9QX00<0_IUY0;jJ
JP2kUf<00P2kUf<20;bHI0<0_IUU0`30W6`20<6MK@<0`Yi^00@0_9YZ0;fKJ`2mVf/0_I][0P2nW6`3
0;nMK@060<:PL031Wfl0_ie]0;jLK02mVf/0_9YZ0P2mVf/01P2nVF`0_IUY0;fIJ@2lV6H0^iMS0;ZG
H@80^IIN0`2lV6@50;fII@060;^EI02jU6<0^YEQ0;VDG`2hTeh0]i9K0P2fTUP20;JCG@030;NDGP2h
UEl0^IIP0080^YMQ00<0^iQR0;fIJ@2mVFT01P2mVFT0102nVVX0_IUY0;^GI`2iUFD40;NCH`070;FB
G02fTed0]iAN0;REG`2gU5h0]Y=M0;BAF`040;>@FPD0/XmI0`2_S5@[ooooo`00:_ooool20:EjA@80
YW]60P2WO4L20:QmB0060:MlA`2XODP0Z7e80:UnB@2ZOdX0Zh1;0P2/PD`30:Z1C@<0ZH1<0P2XOd/8
0:YoC0<0ZX1>0P2[PDl30:b2D0P0[h=B00P0[8=?0:f4D02_QU80/8MC0;68E02`Qe<0[hIB0:j5D@80
/HQD0P2`Qe<20:n6DP80[XEA202[PTh20:b3C`050:f4D02^QE40[XEA0:j5D@2_QU800P2`Qe<80;:8
EP060;67E@2`QU@0/8ID0:n5D`2^Q580[H=A0P2/PU001P2XPUD0Yh5D0:N1E02VP5<0YGmB0:AnD@80
Xge@0P2UO4h0502SODh0XGe=09mkB`2IMdL0UGE409=c@P2CId80TVI1091T?`2=HC`0RUhi08MK=P25
FC@0Q5Pc081K<@21G380Pehd08AO=@25H3H0QV4g0P25H3H01@26H340R68c08]U=P2>J3T0SfTj0080
T6Xk00L0SfTj09E[>@2FK3X0UV`j09M]>`2HKS`0VFlm0080VW0n0P2FLCd309Mb?P<0V7<o00@0WWA2
09ab@02JL3h0Ufdk0`2FK3X00`2GKC/0TfTg09AZ>00209AZ>0<0UF/i00@0UV`j091Z>`2@JS/0T6Xk
0P2AJc`3099/?@0509AZ>02CJCL0TfTg099X=P2AIcD00P2@IS@02@2?IC<0TF8h095R>02@HcT0T6Dj
091W>`2>J3/0SfTl08iY?00808]V>@P0RfHb202=HSD308]P=@<0S64f0P2=HSL208YT=@80RfDf102<
ISL0102=IcP0SVPi08eW>02<ISL208]U=P0308aV=`2=IcP0SVPi0080RfTk00X0S6Lj08aV>@2>ICT0
SV<h08eR=`2>HCL0TV`m095[?02?JCX0SVPi102=IcP808mT>@0808UV<028I300R6@`08MS<@28I3@0
RVDh08aW>`2>JCd208iZ>P0608m[>`2@K3`0T6`l091/?02?Jc/0SVXj0`2AK3l2091[?P<0SfXm0P2?
JcL0102@K3P0TFdi099^>P2BKSX209=_>`06099Y>`2CJS`0TF/l095]?@2BKSh0TFlo0P2ALD0809Eg
A@<0V7Y40`2GND<209Ih@P0609=e@`2@LT00SFho08UZ?026Ic/0QFDl0P24I3d04027J380QFLc085U
=@1iHCD0L5Xc06AB;P1JBRT0E4DX04i09@19?B<0A3XQ03`f800e<Ql0<34Q02h`8P0/<28202PZ7`04
02LY7P0V:1d09RPM02DW708092HK00<08bHM028U700Q91/00P0O8QT00`0Q91/08RDL02<V7@0302<V
6`<092LL0`0U:1d01`0T9a`08B@K01lR6`0M7aX07AlL01hP7@0N81l02@0L7Q/201XO6@0U01dP6@0O
81P08R@I02HV6P0/:Qh0;R`O03Tb5P0m=QT0ASdP04e2901BABD0Dd@S05948@1A@Al0F4DT05E28P1=
?1h0ACDK040a6P0l;a`0?2lN03``8010=1X0@CDK04<g7@14>1h0ACTO04@h7P13=ad0@SHL04<j7@12
>A`0@CLL03le700m<Q`0>c0L03X_6`0203T^700703H]700d:aX0<R/K02lY6`0[9a/0:BLK02PV6P08
02LY7P80:2XO0`0W:Ah302HX7@0H02X/8@0Z:ad0;b`I03Xd701;@280Fd/W06MD;01]F2d0K5DY071H
:P1dG2h0O64b08AX>02<KS`0Tg=009If@`2VQdL0/He?0;J@DP2VOTX0PV4h05U4:@0m<bL0<BhY0P0_
<R401P0`<R@0;c4T02h`9@0[;2@0:BXT02LX8P809RLQ0P0W:28402PY8`0>02TZ900[;2H0;BhV02la
9P0`<RD0<38T02lb8@0^<B00=3DW03<d9P0b<bD0<C8T030a8`0^;b4202d^8080<2`P00<0<BdQ038^
8P0c;b<00P0d<2@0100e<BD0<BdQ034]8@0a;B42038^8P<0<blS0P0o<BH0100n<RH0?38V03/c9P0j
=2H203Pe9P0703/b8@0l<b80?c@R048e8P17>2<0BSXS04`l9@0204hl900904hn9@1>?RL0CCdV04`k
9`1;>RP0BSTY04Xh:P19=bT0BCLQ0080B3HP01P0AcDO04Pf8019=b40BSPR04/i8`1B?2@0DC/S05<k
8`1D>R<0ESXT05/l9`1M?RT0H40[05]2901J@b@0Fd<W05U4:@1G@bX0Dd4Y0510:@1??bP0D3hV04hl
901;>B4204Xh800304dk8`1@?RH0DT0X0080Fd<W0P1J@RH07`1LA2P0GTHZ0659;@1RBRh0I4/]069;
;01PB2`0G4L/05Q4:`1C@BT0D40Y04lo:01<?2D0CShW04lo:01>?RL0Bc/T04Ti8P1;>b@0CCdV04Tf
9@18=bD0AcHV04De9P12=2L0@3@X03dc9`0m<bT0>C<W03Pb9P0g<BD00P0f<2@00`0h<RH0>C<W03/e
:@0203Tc8`0603Pb900g<BD0=BhT03@]9@0c;2@0<b`V0`0e<BD203@`90<0<blS00T0>C4T03Xb9@0i
<bD0=c@U03Dc900`<B40;RlO02/^7@0/;2801@0];B<202`/8P0902h^9P0/;280:b/Q02TY7@0Y:Q`0
:R/K02//6P0/;A/0;RXQ0080;b/R00<0<2`S034]900a;B@00P0b;RD3034[7`80<R`P0`0c;B40400a
;B80<RhS03D_8`0h<2<0>c8S03lc8`11=2@0@SDT04Pi9P17>2D0A3LT044f8P0m=B00>cDO03Tc7@0h
<ad903Pb900H03l]8@10;R80@S0R04@c8`16=BD0B3LU04Th901:>BD0ECTQ05Dk8P1F?R@0E40U0551
9`1>@bL0Bd8U04Q1901;@2X0C40X05109`1C@RH0FD@U06189P1WBRP0JDdX0P1PCRX405m=:@80GT`X
00X0G4d^05]<;@1IBR/0ETLX05=49@1A@R<0Cd0Q04ho801>@bL0Cd4V0P1@@2H0@P1D@2L0ED4X05Q2
:P1K@b/0ID@U06U8:@1[CB/0JdlZ06U@:01XDBL0JE@Y06]F:@1]CRl0LE0_07ED<@1jF380Oe`b08AO
<P26H340Qf4`08EU?02:Jcl0Sg14099cA@2BLd@0UGM509]mB@2PPTh0W8M@0:6:E02WTEP0[9=J0;2F
G@2gVV00`:9V0<NYK@3>/X00d;J30=JlR`3H`900f<:C0=K1U03A_Y<0ckbA0<VbR@37[XD0a:b00<N/
O@3:[W`0bjeg0<RYLP33Y6/0^IQU0;JEHP2bTE`0[XeG0:b;E@2/S5<0[XiC0:n?E02cTeP0]IEJ0;VI
H02lVfD0_iiX0<6PJ`80`J1]00P0aimR0<VQI03<Y6L0d:Q[0=B/K`3F[W40ejmb0=R`L`80cJed0P3>
[WD0203?[gH0d;1g0=6aN03A/GP0cJaf0<b[M@3:ZG<0b:Ma1036YFl02@36XW00aj=a0<RTL039YW00
ajA^0<BQJ@31WV@0_Y]Q0<2LGP020<:NH0070<BPHP35XF<0aJ5S0<BPHP31WEl0`9aN0<BSGP020<FR
GP030<JQG@37X5d0aiiL0080bIeL0180b:1K0<NPF`38XEh0b:9Q0<FRHP33XF80`:1S0;nOHP35YfT0
`jEW0<2QH@2nW5`0^YUF0;RED@2iU4h0^9==0:n=CP2^S4d30:f;C00;0:j<C@2`STl0/Hm@0;FCE02f
U5D0^9IG0;ZHF@2lVU/0_ieN0<2NG`31Wf000P2oX5l01030XF00`J9Q0<:SHP33Y6<20<BUI0050<BR
H`36Y6D0b:IW0<ZXJ@3;ZFX00P3:Z6T01`39YfP0cJY`0<VYKP3;Zg80cZmh0<NZLP2fVf@00P2]U5h;
0:^AGP80ZY1M0`2YSe`0402]TEl0[91N0:b@GP2/T5h0[I5O0;2DHP2bUV@0]9QV0;>HJ`2eVVd0]iaa
0;^OM`2oXg`0`ZJ10<FYQ036ZHL30<R/Q`80bJf80`3:[XT0103</8/0c[:=0=2dS`3C]i830=BhT`0O
0=>gTP3G^YP0e[VG0=FhUP3C]Y@0dKBB0<nbT03>/Hl0cK2>0<^^PP3:[H40ajYn0;nRMP2hVfl0]YU]
0;VLL02mX7@0`ZIo0<>WP036ZXD0bZf;0<nbT03B]ID0e[VK0=NjW03L`jD0gLJW0>79[@3Sc[<0i]:i
0>KD_0020>KF_`070>WH^P3Yf;`0j]Vm0>[I_@3ZfKl0jmW10>cJa0020>gKa`060>gJb`3]f/T0k=W8
0>_Ia@3Zf<80j]S00P3Yf;h20>SF_P80imFm0`3Ve;`01P3Udk/0i]C00>KD`03Ve;h0i]Bl0>KE^`80
i]Fi00X0i]Fg0>7A^P3Rd[/0i=:j0>OC^P3Wd[L0j=2d0>K?/03VcJl0hlZd0P3Rb[800`3QbJl0hLV]
0>39ZP020=o8Z0060=o6Y`3PaJL0glFT0=o2X03O`Il0gkjK0P3O_IP0603O^Xh0fkJ90=JaQ03E/H40
eK5o0=B`O03?[7H0bjQ`0<NNJP36WFT0`iYV0;nFHP2kTUh0]hiJ0;B;E`2cRUH0/8=<0:n2B`2/PD`0
ZH1<0:InBP2RODT0XG]:09mkB@80VgI20P2JMD40102IM400V7<o09Mb?P2GLSh809UdA`0509Ud@02H
Lcl0V7<o09Qc?`2GLSh00`2FLCd01P2FLcd0UG4m09Ea?@2ELCl0U71009A_@P80Tfi200<0TVe0095/
?`2@Jch00P2?JSd01@2@Jch0TF`o099]@02BKSX0Tflk00@0U70l00D0Tflk099^>P2AKcl0TW1009=a
@@0309Ab@P80Tg5100H0TG0j095`>`2@KcX0T6ll091^?P2?KCl208m]@00409=^@@2BKD00T6/n08iY
?080SFPk0P2>JC`208mZ?@@0T6/n0`2AK3l209=_?`80TVhn00@0Tflo09Ea@@2GLd<0V7A40`2ILd@3
09Qb@`80Ug520`2ILd@209YdA@<0VgE60`2KMT8209ag@`<0WGQ400P0W7Q809]gA`2KMdL0VWI609]g
A`2MNDT0Wg];0:5mC@P0XGe900<0X7]70:5lB02SOTX00`2TOd/20:=nBP0;0:F0C02TOd/0Xgi:0:=n
BP2TOd/0YH1<0:J1C@2WPTh0Y81@0:F1D@2VPU800P2WPe<01P2VPU80YH5A0:B0D02TP500YH5A0:N3
D`<0Z8AD0P2WPe<30:Z6DP80ZhMC0`2/R5@20:n;F`030;2<G02aSEd0/XiN0080/hmO00X0]91P0;FC
I@2cTF<0/8iP0:j<GP2]Red0[heO0;6?H@2bT680]i5Z0P2gTVP00`2gTVH0]i9U0;NCH`020;NCH@06
0;VFH02hU600]Y9N0;B@GP2cSel0/hiQ0P2dSf<01P2fTF@0]I1S0;B?HP2cSV40/HaO0;2;GP80[hYM
0`2/R5@20:f9E@<0[XYF00P0]I5Q0;B@H02cSel0/hmO0;B@H02fTV80^9AT0;VEI@80^YQX00d0^iU[
0;bJK@2nVg40_Y]a0;nLM030WGL0`Iih0<:SM032XgD0`jAf0<>TN034Y7/0aJEn0080aZJ000H0ajN0
0<RXP@39ZH80bZZ30<b/Q@3=[HH20<j^Q`<0dK2?0P3B/I030=>bT@80dk:?0P3D/i030=FdT@040=Je
TP3F]I@0e[FD0=JeU080ekJE0`3H]iH00`3J^IH0fkZG0=^jU`020=bkV0<0gKbI0P3K^YT20=bkVP<0
gKbK00<0g[fL0=bnW03L_Y`02@3L_Y`30=foW@80g/2N00@0gKjO0=joX03N_j00g[nP0P3O`:420>31
XPP0h<:P00@0h/BR0>73X@3Q`j40hL>Q0P3P`Z020=o1W`/0g/2N0P3M_id30=bnW0<0fkZG0P3J^IH3
0=VhU@0A0=FgT`3F^9@0ekVE0=RjUP3G^ID0e[RD0=BfTP3C]I40e[FD0=JeTP3E]940eKF?0=BdS@3D
]8/0e;F90=>dR03C/h`00P3B/X/01@3@/8T0cjn80<j^Q`3=[HH0c:b500<0bJV2103:ZX<20<^[Q0T0
cZ^100L0cjb20=2]P`3@[H<0d:f30<j[P@3=ZX00bjQn0080c:V10P3;Z8040<ZWO`080<j[P`3=ZX80
bjR00<ZWO`39YWh0bZMo0<^XP03<ZH480<f]Q080cJf60P3>[XL30<n_R0040=2`R@3=[H@0cJf40<f]
Q080c:b30`3;Zh820<ZWO@80bjQn103<ZGl30<^XOP80bZMm0`39YW`0203:Ygd0bjQn0<^XOP3<ZGl0
bjQn0<ZWO@39YW`0b:Ek0P3;ZGT0103;ZG/0c:Ym0<bYO`3=ZX820<fZQ0040<^XOP3:Ygd0bZMm0<ZW
O@80bJIl2P38YG/0103;YW`0bZEk0<VTNP37XWP40<JQM`060<BRM033XG<0`j5c0<:PLP31Wg40`9i`
0P2oWFl01033Wfl0`Ie]0;nKJ`2mVFT20;bHJ0030;fIJ@2nVVX0^iMS0080^iMS0P2lV6@30;fII@<0
`9a/0P31WFd30<:NKP040;bJJP2mVf/0_I][0;fKJ`80_Ya/0`2oWFd01P32X700`Im_0;nMK@2nW6`0
_I][0;bJJP80_I][00H0_YU/0;fIJ@2mVFT0_9QV0;^GH`2jUf420;VFGP<0_9QT1@2mVFD01P2kUF@0
^YAS0;ZEH@2iU5l0^9=N0;NBF`80]Y9H0P2fTed00`2gU5h0^9EO0;VFH0020;ZGH@030;^HHP2mVFT0
_IUY00H0_IUY00@0_YYZ0;fIJ@2kUfL0^IEU102gTf<01`2eTU`0]Y=M0;NDGP2hUEl0]iAN0;JCG@2d
TE/0102cT5X50;:?F@<0[haD:oooool002[ooooo0P2UNTD20:IkAP80Yga7102XODP0102YOTT0ZWm:
0:^0B`2[P4/20:b1C080Zh9>0P2ZPDd0102YP4`0Z7m;0:QoB`2XOd/80:^0C@@0ZX1>0P2[PDl20:b2
D0P0/H=B00P0Zh9>0:f4D02_QU80/8MC0;68E02`Qe<0[hIB0:j5D@@0/8MC102_QU840:^2CPD0[8=?
00<0[HA@0:j5D@2_QU800P2`Qe<00`2aR5@0/XUE0;>:EP080;F;F@060;N=F`2fS5X0]XaJ0;F;F@2d
RUP0/hUG0P2bR5H0102^R5/0[HMJ0:f7FP2/QUT20:^5F080ZXAG0100ZH5@0:Z2D@2XPU40Yh=A0:F1
C`2QP4d0WGe:09]kB02LL4/0VVi909M[AP2CId80Sf<n08]O>P28G3L0Qe/f0P23GS@02P22GC<0Pehd
08AO=@25H3H0Qf8h08QS>@29Hc@0RV@e08aV=`2>J3T308mY>P0708iX>@2EJcT0UV`j09I/>P2GKC/0
V6hl09U_?@0209Y`?P80UW4m0`2GLSh309Qc?`0309ab@02KLCl0VFlm00<0Ufdk00<0V6hl09U_?@2C
JCL00P2CJCL00`2DJSP0UF/i09E[>@0209I/>P<0TV`m0P2AJc`3091Z>`80U6Xh00@0TfTg099X=P2A
IcD0T6Hd0P2?IC<209=S>`03095T>`2@IC/0SfDk0080SFHk00<0SFPl08UW>@29IcT01P29IcT808]V
<PP0SV<f0P2<HCH308eR=`<0SV<h0`2;ICH408aV=`80SFLh00P0SVPi08eW>02<ISL0RfDf08YT=@2;
ICH0SFLh08iX>@80RfTk00H0S6Lj08aV>@2>ICT0SV<h08eR=`2>HCL208iX>@0608mY>P2>J3T0SFLh
08]U=P29Hc@0R68c202@ICX02`2:Ic40RVHb08UU<@29IC<0RVHf08aW>P2?JSh0T6/o08aX>02=JCT0
Sf/k0080T6`l00<0SVXj08eY>@2;IcL00`2AK3l2091[?P<0SfXm1`2AKCT02@2BKSX0UF`n09E/?P2D
KSl0U71009Ea@@2DLT80Tg=209Ad@`0809EgA@<0V7Y40`2GND<209Ih@P0609=e@`2@LT00SFho08UZ
?026Ic/0QFDl0P24I3d04029JS@0QfTe089V=P1iHCD0KeTb06=A;@1HB2L0DT<V04i09@1:?R@0AC/R
03dg8@0f<b00<C8R02h`8P0]<B<202PZ7`0402LY7P0V:1d09RPM02DW708092HK00<08bHM028U700Q
91/00P0O8QT00`0Q91/08RDL02<V7@0302<V6`<092LL0`0U:1d01`0T9a`08B@K01lR6`0M7aX07AlL
01hP7@0N81l02@0L7Q/201/P6P0I01dP6@0O81P08R@I02HV6P0[:Ad0;B/N03`c5P10=aP0B3dO04i3
8`1DAbD0EDLT05A4801B@Qh0FTHS05E28@1??1`0AcHJ048b6@0o<1/0?C0M03d`7`13=AX0A3HK04Hh
7@0304Pj7`80ASPM00H0@cPH04<h6P12=aT0@SLK044e6`10=1`203lc7@0803`a7`0k<1h0=bhM03@]
7@0a:ad0;BXK02`X700Z:1/802LY7P<09RPM0`0U9a`202@V6`0Q02`^8@0[;1`0<2dJ03`f701>@b<0
Gdl[06UF;01^FB`0L5T]07AL;P1hH380PFHg08Q/?02@LT00UWI309QhA@2^RT`0]Y1A0;J>D@2QNDD0
NUXc05A09`0l<bX0<c<a02ha800_<R40;c4S02la900^<2D0:b`T02TZ900W:2809RLQ00809bPR0P0X
:B<202TZ900702X[9@0[;2H0;2dW02h_9`0`<RL0<C<V030b900202lb8@0603Df:00d=BL0<c@V038c
9@0`<B<0;RlQ0P0];R02030/8004034]8@0b;R80<blS03@`9080=C4U0P0b;R8203<_8`80=30T0P0e
<BD203la9P0403hb9P0l<RH0>c<V03Xd9P80>3DV00L0?3<R03dd8`11=R@0A3LT04Tj9@1<?2D0CShW
0080D3hV0P1??bP00`1>?BT0CC`Z04`k:`0204/i:`0404Xh;01<>R@0BcTS04Xh8P80BCLQ00@0BcTS
04dk9@1>?2H0D3XR0P1B>R803`1C>B80ESXT05Xk9P1N?RT0H40[05To901I@BD0FD4W05Q2:P1F@RX0
DT0Z04lo:01>?BT0D3hV04hl900204`j8P0504dk8`1A?bL0ED<[05M5;@1MABT00`1LA2P0501NARX0
H4P/06=;;`1TC300HTT[0619:P1OAb/0FdH[05Q4:`1D@RX0DT8[0551:P1=?BH0D40Y0592:`1??bP0
BCTR04Hf7`18>240Bc/T0P18=B@03P17=RH0ACDV048d9`11<bP0@3@X040c:P0k=BT0>S@X03Pb9P0g
<BD0=S0T03La9@0h<RH0>C<W0P0g<B400`0g<B<0=S0T03H_9@0203D^9P0503D^:00g<bL0=c<W03Lc
9`0f<RH00P0e<BD203@`900:03Pb900i<bD0=c@U03Ld9@0d<R<0<34Q02`_7P0Z;A`0;blU02h^9080
;BdS00`0;2`R02/[8@0Z:R00:RXP02h^9P0];B<0:b/Q02XZ7P0Z:ad0:b`L02d^700^;ad5030/8`<0
<BdT00<0=BlS03@^8P0d;R800P0c;B43038/800@034]8P0b;R<0=BlS03P`8`0k<R<0?c<S048e9@13
=RD0ASLT04Df8`12=B80@3DQ03de800k=Al0>S@N03Pc7@T0>C<U01T0@BlS048`9014<R@0AC@T04Lf
9P19>2H0BSTU04/j9P1E=ad0E3TN05Dk8P1B?R<0D40V04]29@18@BD0AT4T04Xo:`1;?bT0D40Y05E1
9P1LABH0I4LW06U;9`1^CRP0GT`X00H0GddY05L0H4hZ05e@<01LCbl0FD`/05I9:@1CARH0D4<S04i1
8@1=@200BT<V04a39P1<@BD0CclU05509P1E@BP0Fd<[05a4;01XA2@0K4TY075@;@1`DR`0Je8Y06UB
:01[ERT0K5X/079A<01dDc00NUPc081M=@26HCD0RF<d08]U=02=IC80R6Po08e]A02BLdL0TgA609=d
A@2EMdD0VWa:09j0C02LQe80XHaG0:N@FP2/Te/0[iEL0;JIG`2nXFL0aZQ/0<J`P@3:]8D0c[V<0=:m
TP3A_Y@0c[bD0<RiT035]Xl0`:b90;jXP`2kY7/0_JEi0<>WM`37ZGD0aZM`0<BTJ`2nWFX0^iYW0;JE
H02aT5X0[HaF0:f=E02]SE80[XiC0;6AEP2bTUL0/i=J0;FDGP2hUf40^iYU0;nNJ`31X6d0c:AV0<jV
J03AZF/0eJe_0=R`LP3I/G<00P3J/W@30<f^M`D0cZmh00@0bjaf0<Z[M@37Z780aJI`0`33Y6h02P34
YFl0b:Ih0<VWM`3;ZGT0c:]h0<ZYM037YW00`Z9Y0<2PI`32WV820<>OH`D0a:1T01T0`imS0<FTG`36
Xel0aJ9N0<NRGP37X5d0b9mM0<ZNG@39WE`0aimJ0<NPF`39XUl0bJ=R0<NTI035Xf@0`J5T0<2PH`30
XV@0_j5S0;fNGP2kVET0]YEB0;:?B`2_RT@0[HQ200@0ZhU:00d0[H]<0;2>C`2cTE80]I=D0;JDE@2g
UEH0^IMH0;^IFP2nW5d0`9iO0<:PH@33XF80`:5P0080`J9Q00<0`Z=R0<>TH`34YF@00P35YVD01035
Xf@0aZAU0<RVI`3:Z6T20<^YJP80bZQY00P0cZ]a0<VYKP3;Zg80ck1i0<V/M02hWFH0[IAN0:bCG@P0
Zi5N0P2/TUl20:^AGP<0ZY1M00<0ZHmL0:fAG`2/T5h00P2/T5h0302^TV00/IES0;>GI@2eVFL0]9U^
0;JKL02iWGD0_J5i0<6UOP35ZH@0b:^90<V/RPD0bZj90`3;[hX0103</8/0c[:=0=2dS`3C]i830=Bh
T`070=>gTP3G^YP0ekZH0=FhUP3C]Y@0d[FC0=2cT@020<jaS`80bjj201@0ajYn0<2SM`2hVfl0]IQ/
0;RKK`2kWW80`:Am0<:VO`35ZH@0bJb:0<jaS`3B]ID0eKRJ0=NjW03L`jD0gLJW0>79[@3Sc[<0i]:i
0>KD_080i]Jo0P3Yf;X20>[I_@060>_J`03/f/80kM_50>gKa@3^g<P0k]_<0P3]f/T00`3/f/H0jmW3
0>[H`0020>WH_P040>WG_`3Xe[h0j=Jn0>SF_P80imFm0P3Ve;`20>GD`P030>GD`03UeKh0iMFl0080
iMFk0140i]Nj0>7B_@3Rdkh0i=Bm0>KD_03VeK/0i]:g0>KA]P3Tck80iM2m0>G@^`3TckX0hlng0>;>
]@3QcK80hLj`0>3=[`020>C</P0N0>C:[`3Sb:/0i<NY0>C5YP3Ua:D0iLBS0>K2XP3R_Yh0g[ZH0=bi
T`3M^Y80g;Z=0=RfR03C/H<0e:]e0=:YL`3@Yg40c:=]0<ROJ@35W6H0`YUS0<6HHP2mSUH0^hiE0;V<
E@2dRE@0/8MC0:f5DP2YQ500Yh5@0P2TOd/01P2SOTX0XWe90:5lB02PNdL0WgY609iiA@P0W7M:00P0
Xg]80:9jA`2QNDH0X7Q509if@`2MMD80W7A109]c@080Ug@n00@0Ug<o09Ib@02FLT80UG510P2EL4<0
2`2HLdH0UW5409E`@`2DKd80Tfi109A_@P2FLD@0Ug9509Mc?`2HM400VGE10080VgM300H0VGE109Qd
@02GLcl0UGA109Ie@P2GMT<209QgA00709Ie@P2DLd00Tg8o09Ac?@2CLS`0Tg8m09=b?`02099`@080
TFm100@0UW5409A_@P2BKD00T6/n0P2?JSd3091[?P@0TF`o0P2BKD0209=^@@0909Ea@@2DL400Tflo
09=_?`2DL400UW9209QdA02JMTH0W7I70080VgE60P2JM4D209UcA00409Qb@`2KMDH0VgE609]eAP80
W7I70`2MMdP309ag@`80WGQ40`2NNDD0202MNDT0W7Q809]gA`2KMdL0W7Q809ijBP2PO4`0XWi>0`2Q
ODT50:1lB0030:5lB02RODT0Y7m;00<0YX5=00H0Y7m;0:=nBP2TOd/0YH1<0:J1C@2WPTh20:R3C`05
0:N2CP2VPDd0YX9B0:N3D`2XQ5@00P2ZQUH01P2XQ5@0Yh=C0:J2DP2UPE40Yh=C0:R4E080ZXIF00<0
ZHEE0:R4E02WPe<00`2[Qe<20:b8E0<0[HUE0P2`S5`00`2aSEd0/XiN0;>?G`020;B@H00:0;FAH@2h
UVP0]YAV0;>AH`2`SV00[heO0;6?H@2dTV@0]YAV0;VCK080^IAZ00<0^IAX0;VDI`2iUFD00P2iUF<0
202kV600^YMO0;NCG`2eTEl0]I1S0;F@I02fTFL0]Y1Y0P2hTfL01P2fTFD0]I1T0;>>HP2bSF40/HaP
0;2;G`80/8aH0P2aSET40;:>FP80]Y9R0P2eTF40202fTV80^9AT0;ZFIP2kUfL0^iUY0;bJJP2mVfd0
_Ya_0P30WG<01031WWH0`Ymi0<>PNP33Y7D20<BUM`030<FVNP36YWd0ajN00080b:R20P39ZH801P3;
Zh@0c:b50<j^Q`3?[hP0d;290=6aRP<0dk:C0P3D/i@30=FdU@040=FdT@3F]I80e[FB0=JeTP80ekJC
0P3H]i@30=RgV080fKRI0`3J^IX00`3M_9T0g[fJ0=jmVP020=jmVP<0gkjK0P3M_9d20=jmWP<0gkjO
00<0h;nP0=foW@3M_id02@3M_id20=k0WP<0gl6O00@0g[nR0=o0X`3O`:<0gl2S0P3P`J@20>72Y@H0
hL>Q0P3P`Z030>;4XP80hL>Q0`3P`Z0:0=o1W`80g/2N0`3M_id00`3L_Y`0g;^H0=bkV0020=^jU`<0
f[VF00@0fKRE0=FgT`3F^9@0ekVE0P3H^YH0103F^9@0e;JB0=>eT@3G]YD20=JeTP030=JfT03E]Hh0
eKF<0080e;F90P3B/X/20=6aRP040=2`R@3?[hP0cjn80<n_R080bZZ30`3;Zh@40<b/Q@P0cjb200T0
cZ^10<n/PP3@[H<0dJj40=2]P`3?[880cJZ00<bYO`3=ZX800P3<ZH420<^XP080bZMo00D0bJIn0=2]
Q@3?[8@0cJZ20<bYP@020<^XP0030<bYP@3=ZX80cZj500L0cZj50`3>[XL20<n_R0<0d;290P3>[XD2
0<f]Q0<0c:b300@0bj^20<ZWO@3;Z7h0bjQn0P3<ZGl20<fZP0040<j[P@3;Z7h0bjQn0<^XOP80bZMm
0`39YW`03P3:Ygd0bjQn0<bYO`3=ZX00c:Uo0<^XOP39YW`0b:Ek0<^ZM`3;ZGT0c:Yj0<bZO03=Zgh0
cJZ00P3=ZX820<^XOP<0bZMm0`39YW`80<RUN`090<jYO`3<Ygd0bZEk0<RSN@37XWP0b:=i0<VTNP3:
YG/0aJ=e0080a:9d00T0`j5c0<6OL@30WW00`9i`0;nMK`33Wfl0`Yi^0<2LK02nVVX00P2mVFT20;jJ
JP040;^GH`2lV6@0_9QT0;bHI080_IUU0P2nVVH01030W6`0`Ie]0<6MK@31WFd20<:NKP80`im_0P2m
Vf/20;jLK0@0_ie]00D0`9i^0<BRLP32X700`9i^0;jLK0020;fKJ`0:0;jLK02oWFd0_iY]0;nKJ`2n
VVX0_IUW0;bHI02kV680^YMO0;VFGPD0_YYV0`2mVFD20;^EI0070;ZEH@2iU5l0^9=N0;NBF`2gTeT0
]Y9H0;JCG@020;NDGP030;REG`2iUV00^YMQ0080^iQR202nVVX02P2lV6P0_IUY0;fIJ@2lV6P0^iMW
0;VEI@2fTV80]I5Q0;JCG@2gU5h30;REG`030;JCG@2dTE/0/i1J0080/XmI1P2cT5X30;6>E2_ooooo
000Zooooo`80YGY50P2VNdH20:MlA`@0Z7e800<0ZGi90:YoBP2[P4/00P2/PD`00`2]PTd0Zh9>0:^2
CP020:Z1C@040:V0C02XOd/0Z7m;0:MnBPP0[85>00@0ZGm=0:Z0CP2ZP4h0ZX1>0P2[PDl20:b2D0P0
/H=B00<0Zh9>0:f4D02^QE400`2`Qe<00`2_QU80[XEA0;27D`030;27D`@0[hIB0`2[PTh50:b3C`80
[HA@00D0[XEA0;27D`2aR5@0/HQD0;>:EP020;B;E`<0]XaJ1@2gSE/01P2lTV00^i5O0;^AG`2jT5h0
^HmM0;R>G080]heK0P2cSF020;:<G`040;6;GP2`RUd0/8YM0:n9G080[8AC01T0ZhED0:Z6E02YQE<0
YHAA0::2C`2PP4d0XgEA0:5cC`2MKd/0V6Y609=U@@2?HCd0Redi08UK=`25H3H0Q5le089M<`21G380
PUdc08EP=P28HcT0RVDk08YT=@2;ICH0SFLh00<0SfTj00<0SVPi08eW>02EJcT00P2FK3X00`2GKC/0
V6hl09U_?@0209Y`?P80UW4m0`2GLSh309Qc?`0309]a?`2JL3h0V6hl0080Ufdk00<0V6hl09Y`?P2K
LCl00P2BJ3H0102CJCL0U6Xh09AZ>02EJcT209I/>P80Tfdn00@0TV`m095[?02AJc`0T6Xk0P2?JCX0
202EJcT0U6Xh09=Y=`2BJ3H0TFLe091V=02?IC<0SV@b0P2DI3`01P2BIC`0T6Dk08mU>`2=IS/0S6Dj
08]V>PP0RFLi202;IS4808iS=P80SF8g0P2>HcP408mT>@<0RfDf0P2<ISL408eW>00308mY>P2=IcP0
S6Hg0080RV@e00<0RfDf08aV=`2=IcP00P2;JC/03P2<IcX0S6Hi08iU>@2>HcP0SF8g08iQ=`29Hc@0
RfDf08aV=`2=IcP0S6Hg08US=025Gc00Ped^202AI3X02`2;J380RfLc08YV<P2:IS@0S6Ph08iY?02@
Jcl0TVe108]W=`2=JCT0SVXj0080Sf/k00<0SFTi08]W=`2:ISH00`2AK3l2091[?P<0SfXm0`2BKSX3
095]>@80T6`h00H0V6m109U`@P2GLD80Ug=309QdA02GMDD209MgAPP0UGM50`2HNT@309Mi@`80UWQ2
00H0TgE3091b@02=KSl0RFXl08IW>`25IC`208AT?@0@08Y[=@28JSH0PfLg07YR=P1_FC80HU0/05M7
9P1@@B@0Cd4V04Xn9015>b80?CLQ03Hc800a<R80;c4S02da8`80:2XO00@09bTN02HX7@0V:1d09BLL
0P0T9Q/00`0S9Qd08RDL024T6`0201lR6@03024T6`0R9A`08bHM00<08bHK0`0T9a`302DX7@0702@W
700Q91/07b8K01dO6P0M7a`07R0M01hP7`0901`N6`0P01dR700L8A/07R4J020Q6@0Q8aP09BDI02XX
700/:Qd0?3<D044h6@19?Qh0DD@T05I79P1FAR@0E4@P05A27P1JAR<0Ed<R050m7@18=a/0@S8I03l`
6`0o<1d0?S4P04@f6`15=a`0AcTN04Pj7`19>b00B3XO04Li7P16>1d204<h600304<h6P12=a/0@SHL
0080@SHN00T0@SHP03ha7P0m<R00>c0N03L^7@0d;Ad0<B/M02dY7@0/:1`0200W:Ah302DW70<092HK
0P0S9AX07`0/;R40:b`L030^6@0l=Q`0Cd@T065B:`1ZEbd0KUT/07AM<@1hH380OFDg08EZ>`2<L400
U7I409UiAP2LO4T0/Xm?0;RBD`2eSE00WWI207IF;`1A?BD0?3D]03Lg=`0^<B00;c8Q02la8`0_<B@0
;BlT02//900X:B<0100W:2800`0X:B<0:BXT02X[9@0202X[9@0602//9P0/;BL0;RlW030b9`0a<bH0
<38T0P0_<R4203Df:00403<d9P0b<bD0<34S02l`8P80;BhP00H0<2`P034]8@0a;B40<RhR03<_8`0d
<2@203Da9@<0<blS00<0=30T03Da9@0f<RH00P0f<RH203la9P0403hb9P0l<RH0>c<V03Xd9P80>3DV
00L0?SDT03lf9@12=bD0ASTV04Xk9P1=?BH0CclX0080DClW00/0D40Y050o:`1??RX0CSd[04dl;01<
>R`0C3X^04/i;@1??BL0CS`V04dk9@0204`j900K04hl9P1@?RP0DT0Z058j8P1A>B40DSPQ05@h8P1G
>2<0Fc/V05hn:@1Q?RX0F3hS05Q09P1I@BL0Ed4Y05E1:@1B@2X0CchZ04dl:01A?bL0D3hV04lm9@1>
?2@0DClW05E3:`1IAbl0G4Xb0080GTHZ0P1MABT0801OAb/0HDT]06A<<01UCC40HDPZ05m8:@1NARX0
FdH[05Q4:`1E@b/0Dd</0592:`1>?RL0DD4Z05=3;01??bP0B3PQ04De7P16=Ql0BSXS04Xe9018=B@0
Ac@U04Hd9P14=2L0@S@Y040d:010<bX0?CL[03/e:@0i<bL0=c4U0P0f<2@01`0g<BD0>38V03H`800f
<200=S0R03H`900f;bD00P0f;bL0100f;bT0>CDY03Te:@0h=2P203Lc9`0303Hb9P0e<BD0=C4U0080
>C<U00`0=c@U03Hd9@0b<b<0;S4P02`_7P0Y;A`0<30V02l_9@0^;R@0;2`R02/[8@0Z:R0202TY7`08
02d^9P0/;R<0:R`Q02X/7`0Z;1h0:bhM02d`7@0^<Ah2034]90H0<2`S0P0g<BD00`0f<2@0=BlS03<]
8@02038/8009034[7`0a;B80<RhS03D_8`0h<2<0?3<T040d9012=BD0@cHU0080A3DR00H0@C@Q03ld
800m=B00>cDO03Xd7P0i=1h903Tc9`0604@`9@15<BH0AS<U04Ld9@19=RL0BcPW0P1<>RH04@1D=AT0
E3HL05<i7P1A?B80CclU04Y09@16@B@0AD4V04Q0;@1;?R/0CSlX05E1:01MA2H0IDPV06a<9P1_CBL0
Fd/W0080G4`X0P1MCBT205i>:P1705m?:`1NDC40GE0`05Y=;@1GBRX0E4LW05138`1>@B40CD0P04Y5
:01:@bL0Bd4V04i09P1A?bL0ET0Y05]2;01MA2h0Jd@U06m;:`1eDc00LeD_06mC:`1ZDbL0K5LZ06eK
:`1dDc80N5Hc07eK=P23H3P0RF@h08aV=`2?IcH0T6Pe08][A02?KdH0Tg=:09EfBP2DMDL0UGI709Uk
B@2MOdd0W8QC0:6<E`2VTEX0ZY=M0:jEG@2cVF00_J1V0<BWK@2mZ7/0`:^00<BaQP37]X/0aKJ=0<:c
S02m[hX0^Zb70;RUQ02dX7d0/I]d0;:IL02hW6d0_Im[0;nNJ02mWF@0a:=`0<2OK02jVF@0]IAN0;6@
FP2_SeH00P2`T5D0302aTEH0/91E0:n?EP2`SeT0/i9L0;RGHP2mW6T0`J1]0=:YJ`3DZfd0eji`0=Za
L`80fk9d00<0f[5c0=V`LP3>[gT00`3>[gT20<f^N080c:eg00@0bj]h0<VYMP36YW<0`j=`0P32XVl2
0<>SL0080<bZO@3>[7h0d:in0=6_O`3?[W/0bjYe0<NVL034Xfd30<BPI080`imS0P34X6@02035XFD0
aZ9V0<FTG`36Xel0aJ9N0<NRGP38XEh0b9mM0P3:WUd02038X5/0b:5L0<ZSH03;YF@0bJIV0<NUIP34
Y6L0`Z9U0P2kWEl01P2jVe/0^9IF0;>BC`2/RDD0Z8<m0:Ao>@<0ZHM800h0ZhU:0:j<C@2aSe00]I=D
0;NEEP2fU5D0]iEF0;VGF02lVU/0_YaM0<6OH033XF80a:9S0<6RH@80`Z=R00<0`jAS0<BUI035YVD0
0P36YfH01035Xf@0ajEV0<VWJ03;ZFX20<bZJ`0:0<^YJP3:Z6T0cjab0<VYKP3;Zg80ck1i0<Z]M@2i
WVL0[YEO0:bCG@P0Zi5N0P2/TUl20:^AGP@0ZY1M0P2]TEl03P2/T5h0[I5O0:nCH@2aUF<0]9QV0;JJ
J02eVVl0]Y]`0;VMM@2nXW/0`ZJ10<JYQ`39[8X0bjj>203;[X`0103</8/0c[:=0=2dS`3C]i830=Bh
T`090=>gTP3H^iT0ekZH0=FhUP3D]iD0d[FC0=2cT@3?/Y00c[6?0080bjj201P0b:]o0<6TN02iW700
]IQ/0;NJKP2jWG40`:Am0<6UOP35ZH@0bJb:0<jaS`3B]ID0eKRJ0=NjW03K`Z@0gLJW0>79[@3Sc[<0
i]:i0>KD_03Ve[l0imO00>WI^03Yf;X20>[I^`030>_J_P3/fl40kM_30080k]c600H0k]_<0>kKbP3]
f/T0k=[60>_I``3Zf<020>WH_P80jMNo0P3Xe[h30>OE_@050>KD_03Tdl40i=?10>CC_`3UeKh00P3U
eK`0403UeK/0i]Jl0=oB_`3Pdl00hmBo0>GE_P3Ve;`0im>j0>GA^03Ud;D0j=G40>SF`P3WeL40i]Bn
0>CB^P3Sd[P20>;A]@0Q0>K@^@3Xd;P0ilng0>O=]03Wc;40j<Z^0>S9[03Wb:/0kLNb0>S2Z`3T_jD0
hkjQ0>C0WP3S_i/0gkbD0=ZgS`3L/gd0fk9l0=V`NP3E[7H0dZUc0<jUK`3<Xfd0bj9/0<NHH035UUh0
`YEN0;bAFP2hSeT0/h]G0;69EP2]R5@0ZhIB0080ZXEA00<0Z8=?0:N2CP2VPDd00P2UP4`809ehB`0C
0:Z2CP2YPDd0Ygm;0:EmB@2SNdL0XGU50:1hA02OMd<0V7Dm09Qe?`2GM3h0Ug<o09Ib@02FLT80UW54
09E`@`2LMdX0VgI909YeB00209QcAP0609UdA`2JMDP0VgI909]h@P2MNT@0WW]50P2PODL01@2NNdD0
WGY409]h@P2HMd@0VGQ50080VWU600D0VGQ509Mf@`2EM440Tg8o09Ee?00209Ed?P0309Ac?P2DLd00
Tg510080Tg5300H0V7=609IaA02CKT40TF`o08mZ?@2@Jch4095/?`<0TVe00`2CKT400`2DKd80UG51
09Ea@@0209A`@00509Ea@@2GLd<0VGE509YfAP2MMdP00P2LMTL00`2KMDH0VWA509YdA@0209UcA080
W7I70P2MMdP409ihB@80W7M30P2MN4@309iiA@0909mjAP2MNDT0W7Q809ahB02KMdL0W7Q809ijBP2P
O4`0XWi>00@0X7a8102ONdL00`2QO4P0Xgi:0:F0C0020:N2CP0>0:J1C@2UP4`0Y7m;0:=nBP2UP4`0
Z8=?0:Z5D@2[QU80ZHA@0:N2CP2VPDd0Yh=C0:R4E02ZQUH20:^7E`060:Z6EP2XQ5@0Yh=C0:J2DP2W
Pe<0ZHEE0P2[QeL0102ZQUH0Z8AD0:N3D`2[Qe<30:b8E080[HUE0P2^RUH01P2`S5`0/HeM0;:>GP2b
SUh0/hmO0;B@H080]I5Q00<0^YQZ0;RFJ02dTV@00P2aSf40102cTF<0]YAV0;RFJ02jU6d20;ZEJ`03
0;ZEJ@2jUFP0^YIV0080^YIT0100_9UO0;^HH02hUEl0]Y9P0;F@H`2fTFD0]i5Z0;RBJ`2jUFT0^IAX
0;RCI`2fTFD0]8mS0;>>HP2bSF40/HaP0P2dT5`20;FAG@<0]Y9N00<0]i=O0;NCH`2fTV800`2fTV80
1`2hU6@0^iMW0;bHJ02lVVX0_I][0;jLKP2oWG000P31WW@01032WgL0`j1j0<>PNP34YGH20<FVN003
0<JWN`37Ygh0b:R10080bJV30P3:ZX<0103<[8D0cJf60<n_R03@/8T20=:bR`80e;>D0P3E]9D20=Je
UP80ekJG0`3G]YD20=RgUP<0fKRG0P3I^9T20=ZiVP80fkZK0P3L^i`40=nnV`@0h;nL00@0g[fN0=nn
W`3O_Yl0gkjO0P3P_j020>70X@/0g/2N0P3O`Il30>32X0<0gl2S0P3P`J@30>72Y@@0h/BR103Q`j40
103SaJ<0h/BR0>;4XP3Ra:820>73X@80h<:P2P3O`Il20=k0WP@0gKnM0P3L^iP20=^jU`@0f[VF00<0
e[RD0=NiU@3H^YH00P3H^YH02`3F^9@0e;JB0=>eT@3G]YD0ekJC0=JeTP3F]Y00eKF>0=FeS03E]XX0
e;F900P0dK6:0P3;Zh@20<b/Q@D0cJf6203?[8800`3>Zh40cjb20=2]P`020=6^Q0030<n/PP3=ZX00
c:Uo0080cJZ20P3<ZH40203;Z800bZMo0<ZWO`39YWh0dZn70=6^QP3?[8@0cJZ20P3<ZH400`3=ZX80
cZ^30<j^Q@070<j^Q@80cZj70P3?[hP30=2`R@040=6aRP3>[XD0cZj50<j^Q@80cJf40`3<[8<30<^X
OP030<bYO`3=ZX00cZ^10080cZ^10`3;Z7h20<ZWO@<0bJIl00P0bZMm0<^XOP3=ZX00cZ^10<fZP03;
Z7h0bJIl0<RUN`80bjYg00<0c:Yj0<bZO03=Zgh00P3=ZX00103>Zh<0bjQn0<^XOP3;Z7h20<ZWO@<0
bJIl2038YG/00`3?ZH80cZR10<^UOP030<VSO00>0<^UOP3<YWl0aZAf0<FSM@34XW@0`j5c0<:PLP31
Wg40`9i`0;nMK`34X700`Yi^0<2LK02nVVX20;fIJ@030;jJJP2oVf/0_9QT0080_9QT0P2mVFD30;jJ
IP<0`Ie]0P32WVh30<>OK`040;fKJ`2nW6`0_Ya/0;jLK080_ie]0`30WVh03P35Xg<0`j5a0<2NKP2n
W6`0_I][0;jLK02oWFd0`9i^0<2KKP30W6`0_i][0;jJJ02lV6@0^iQR0P2jUel30;nKI`@0_YYV00L0
_IUU0;^EI02kUF@0^YEQ0;VDG`2hTeh0^9=L0080]i=I0P2gU5h00`2hUEl0^IIP0;ZGH@020;^HHP03
0;bIH`2nVVX0_YYZ00H0_YYZ00X0^iMW0;bHJ02nVVX0_YYZ0;fIJ@2jUVH0]Y9R0;B@H02gU5h0^9EO
0P2iUV00102hUEl0]Y=M0;BAF`2cT5X20;:?F@@0/i1J0P2dTE/30;:?EB_ooooo000Zooooo`040:V0
C02XOd/0Z7m;0:MnBP80YWe90P2UO4P20:ImA@040:MnAP2XOdL0Z7m70:V0B080ZX59202ZPDd30:Yn
C@030:]oCP2/P4l0[H5@0080[H5@00T0[XE?0:f4CP2/Pdd0Zh9<0:b3C@2_QU00/HQB0;>:E02aR5@0
0`2`Qe<20:n6DPD0[XEA00<0[hIB0;27D`2aR5@00P2aR5@00`2cREL0/HME0:n5D`030:f3D@0:0:j4
DP2_QE<0[X1>0:j0CP2]PTl0[XEA0:j6DP2^RE@0[hYE0:j;E@80]8UF0P2cR5D20;B9EP030;N<F@2j
Se`0_95N00<0]Y9P0P2gTf430;RDHP030;JAI02gTVD0^IAW0080^iIY00<0^YEX0;VDI`2hTfH00P2k
UFH0102jU6D0^I=T0;NAHP2fT6420;F?H0080;6;FP2bS5/0/XaK0;:<F`2`RUT0[HMF0:Z4D`2XPU42
0:AjDP060:9hD02OMDd0Vg5909I/A02BJ400SfDm0P29I3L00`27HSD0QV4d08IQ=00208IQ=00908MR
=@2:I3D0RV@e08]U=P2=IcP0SVPi08mY>P2@JS/0TF/l00<0U6lk0`2EL3`209Ia?@<0Ug8n0P2FLCd3
09E`?080W79000@0Vg4o09Y`?P2HKS`0Ufdk0P2FK3X01P2AIcD0TVPf09=Y=`2DJSP0UV`j09Q^?080
VFlm00H0Uf`o09I[?P2EJSd0TfPk095V>@2@ICP208iS=PP0T6@g0P29Hc@308YT=@<0RfDf0100S6Dn
08]T>`29HST0R64f08US=P2;ICH0SFLf08iX=`2CJ3/0TVLj08mT=`2=HSD0S64d08eR=@2>HcH0Sf@g
0P2<ISL308]U=P<0RV@e00@0R68e08US=P29HcH0RF<f0P2:I3L208]U>0T0SFLh00<0TF`h091[=`2=
J3@00`2;IS800`2=J3@0SVTe08eW>00708eW>080RVXk00@0RFTj08QX>@28J3T0QfLh0P26ISL208]U
>00308aV>@2=IcX0SVPk0080SfTl00<0T6Xm08aV=`2<ISL00P2=IcP308iX>@0308mY>P2AKCT0TFdi
00H0TFdi202DL40209=_>`04099^>P2AKCT0Sf/g08iZ=P80SFTe0P2AK4001P2CKT40U71009Ib@02G
Lcl0VGE109Uf@080UGM100<0UWQ209Mi@`2HNT@00P2INdD01P2JO4H0U7Q609EiA`2ENDL0UWY809Mk
B@80V7a:00H0VGe;099cA02@LD80S6dn08UZ>`26IcP308EV=`0V08Y[=@2:K3P0QVXj07]S=`1]Ec00
GddY05Q89`1FAbX0C3hT04Tj8`13=al0@SLQ040h8`0m=R<0=RlM030[600]<1d0:bhK02T/6`0V:1X0
9BLJ02@V6`0U9a`09BHN02<T700R8a/08B8J020Q6@0Q8QX08R<K02@U7@0U9Qh092DM02@V6`0U9a`0
9RPK02LY6`0W:QT202P[600402@W7P0S9Qd08B@K01lR6@807R4H0P0O8QT201`O60807B0I0P0N8AX3
01lR6`0L01`N6@0M81T07b0H02<S5`0Y9aP0<2dJ03@b7@0i=1h0?cPK04Dl7`1:@B80DDHV05I99`1I
BbP0FDTW05U99@1NBb40FDDT054l9`18=BL0@S0V040`8`10<Ah0@3@L04<c6P15=A`0AcLN04Ti80<0
BSXQ00D0BCTP04/k8P1:>R40AcLN04De700304@d6`0304De700m=Q`0?SLM0080?SLM00H0?3DK03Tb
600f;aD0=2dC02TZ700Z:ad402T[7@80:2XL02009RPM02@V6`0R91T08B<H028T6@0U9a`0:2XO02/]
8P0/;200;R`M03Ha7@15?1l0F4XU06MD:@1`FRT0LU/W07EG9@24IS@0S6hl08QZ>02:K3X0TgE309Mi
A`2BM480/h]60;VBE`2]S5l0R6e?05i<=P16>bT0>SPS03Dg7`80<C@S00@0<38T02h`8`0];b@0:b`T
0P0Z:bD01P0R9b0092TR02T/8`0];b@0;S0S030a8`80<S0Q00@0;BhP02l`8P0a<R@0<S<U0P0c=2H0
100b<bD0<C8T03@`900d<2@203<_8`@0<RhR00/0=C4X03@`9`0c;bH0<RhU03<_9P0d<2L0=S8Y03Pd
:`0k=BT0>C<W03H`900203<]8@0303@^8P0f<2@0=c4U0080>CDZ00d0>cDY03`d9`0n=BH0@3@T044d
9011=2<0A3PX04@g9`13=RD0ACHS04Pg8`1;>B<0D3/V0080DShV00H0CT8X04a0:01:?RH0B3`V04Hi
9P16>BP204Lj:P0604Ti:@19>RL0BcXX04dk9`1??BL0DShV0P1D?RH03P1A@R<0D44R050o8@1B?b40
DchQ05Lo8`1H@2@0Fd4V05U49`1IA2T0Ed<X05E4:P1D@RX0DT8[0P1@@B`01@1<>bL0CC`X04lm9`1C
?bL0EClW0080EclU01X0F3hS05E3:`1F@RT0ET8Y05M29`1K@bL0GTDW0697:@1SB2X0Ie0`06E>;P1R
Bb`0GdL[05e5:`1LA2`0GDD]05e4;P1D@bT0DT8X0551:01>?bP0BCdW04Hk9`13>bH0@SXW040k:080
@3TW00d0@3LV044e9@11=2@0@c<T048b8`10=2H0?SDV03dc9`0k<bP0>C8X03Hb:@0e<RT0=34Z0080
=BhT00<0=BlS03D_8@0f<2000P0f<Ah0100f<Ad0>C<U03Pb900g<B<203D_8@0303La8`0h<R@0>C<U
0080>3DT00H0=c@U03Da9@0d<2D0<RhU034]900a;2H202`/900402/[8`0Z:R80:BTQ02PX80809bLO
200^:R403P0^;R@0;2`R02/[8@0Z:R00:b/Q02`/8P0_;bD0<30V03Tc9`0h<RH0=c4U03H`900d;R80
<R`P0P0a:al01@0_:1h0<R/Q03La9@0l=RP0?cTY0080@3/X00T0?cXV040c8P0o<R40?S4P03d`7`0k
;Qd0>RdL03T/6`0h:aX0100h<R@303La8`80=S0R02T0>c8Q03dd8`12=bD0ASTV04Xk9P1<?2D0Bc/T
04`j8P1??ah0Cd0Q05528`1BA2L0D4DY04i4:@1=@bP0BD8X05Q0:01J@RP0GTHZ065::P1TCRT0IDlX
06I@9`1VDBH0HU0/065?:`1PCRX0GddY061>:P1SDBd0IE<_06ME<@1KC2/0FT/Z05Q9:P1FAbX0Dd<Y
05109`1=?BH0C3`U05529@0205508P0M05A18@1HA2<0GDHT069:9P1TC2P0Gd`R061=8`1TCb@0J54U
06aD9P1aERL0LePY07EI:@1lDbD0PE//08QT=029JCP0Qf/i08Q^>`29M3l0SGQ309I[?P2HKD00VW53
09ifA@2NNDD0Wga609elAP2MOD@00P2OReP07P2QReT0Y8eK0:Z@G`2_Tf<0]YMX0;VJJ`2cYGH0]JMj
0;NYO02iZWl0^Z^20;VZP`2gYh<0]ZJ20;>LLP2eWG40]Yi`0;RNK@2jWfX0_9mW0;fNI@2mWf<0_Z1T
0;nQI@31XF@0`Z1Q0;jLG02iUU@0]Hm>0;6<B080[HQC01X0/8UB0;>:DP2iSeD0_iEK0<NJG`3:WF80
ej]P0=V_I@3K]6l0fkUi0=NhO`3?]H80ak600<:]P03CYh@0dZJ10=2TO@3>XgP0cZAd0<nUL`3@Yg<0
dJQb0=2^K`3>[6d0c:Y[0<ZXJ@80bJMX00L0bZQY0<^YJP34Xf00bZUV0=6`K@3C/Vl0dK1]0080cZeZ
00`0cji[0<j]J03<ZfH0c:]V0<RWHP36YF00aJAO0<NVH@3:ZF@0c:]V0=2[I`3;YV820<JQG@0<0<VT
H03;YV80b:=O0<BOF`30WeX0`Z5L0<BSGP35Y5l0aZEP0<BSGP33XUd0`Z5L0P2lWed03@2kW5/0^iUI
0;JDE02aSTh0[XQ90:^5AP2XQTL0ZHM80:Z8B@2]Rd`0/8i?0;FCE02iUeP00P2lVU/0102mVe`0`9iO
0<>QHP35Xf@20<JTI@030<FSI036Y6D0ajEV00@0ajEV0P38YVL20<ZXJ@0>0<^YJP3=Zf`0cZa]0<n]
KP3@[Vl0dJm`0<baKP3=/Vl0a:QW0<FYJP3A]7P0aJQ^0;6DFP2`Te/20:^AGP@0[99O0P2]Tf00602Z
Sf@0ZXmR0:V>H@2YSUl0Z8iM0:N=FP2WSUP0YXeG0:R<G02YSEd0ZhmO0:fAH@2_Tf<0/YIV0;>GI`2d
V6P0]IYU0;FII`2hW6`0`JAh0<Z]Q@3@/Xh0dK>A0<n`T@80ck:@0P3@/i420=6dTP80d[FC0P3@/hT0
1P3A]8X0d[F;0=>fS03D]hd0eKR>0=JiS`@0dkbC01X0dKZA0<jgSP3;]8/0bK:90<bgS039]8T0a:f1
0;nWN@2mXW<0^Yi^0;^LK@2jW6X0`j=m0<FUO`38ZXH0c:n=0<jdT@3@^9H0dKZJ0=:kV`3J`J<0g<FV
0>38[03RcK80iM6h0>GC^`80iMFn0P3ZekT20>_H^P030>gJ_03^fkd0l=fo0080lMk0203/f/820>cH
_`030>_G_P3Ze[d0jMFl0080j=Bk00<0im>j0>SF_P3Xe[h00P3WeKd30>KD_0070>GC^`3Ye[H0jMJf
0>WF^03YeKX0jMFl0>WE_@020>WD_`<0iM>m0P3Ve;h30>OE_`<0jM>k0P3Xd[X30>OA^@0P0>S>]@3W
cK@0i/ba0>C:[`3SbZ`0hLRY0>38YP3OajD0gKZJ0=biV@3J^9D0f;JA0=JdSP3D/X`0d[680=:aQP3B
ZG/0dJQj0<jVM@3:XVl0aYiZ0<>KI`30VF80_YMP0<6CG`30TUh0_I1I0;V<D`2eR4d0/XI90:n3AP2]
PD830:YmE0030:UlD`2XNe80YgYA0080YgYA00<0Y81@0:=oC`2SOdl00P2ROTh00`2QODd0X7a<0:1l
C0060:1lC080Wg];0P2JN4X00`2IMdT0V7I809MeA`0209IdAP0309EcA@2MO4H0WGa600H0WGa600<0
Wg];0:1lC02QODd00P2QODd00`2ONd/0WWY:09ahB00209miBP0309ihB@2MMdP0W7I70080VgE600T0
VWA509MbAP2HLdL0VGA809YeB@2IM4P0V7=709IaA@2EL4@02@2DLC/0102DL400UG5109Ea@@2FLT82
09Mc@`80V7A40`2NN4T209miBP<0X7Y;202PO4`0202SOE00Xge>0:9lC@2QNdX0X7]709iiA02NND80
WGQ10P2ONT<00`2PNd@0XGa50:9mAP020:=nA`040:AoB02UPE40YH5A0:F1D@80YX9B0`2WPe<20:B1
B`80YH9<0`2VPdd01P2WQ4h0Z8=<0:R3C02YQ4d0ZXE>0:^6C`80[8M@00<0[HQA0:f9F@2]RET01P2]
RET20:Z6E0040:^7E@2/R5H0[XYH0:n;F@80/8aJ00H0[HeD0:j=E`2^SEL0[XeH0:n>F`2_SEd20;2>
H0040;:?I@2cT6H0/i1V0;>@IP80]95W0P2eTVP20;RCIP80^IAW0`2jUFP0102kUVT0^9IX0;RFJ02i
UfT20;ZHJP0;0;^IJ`2lVV`0_9Y/0;bKJ02kVVL0^9MT0;NFH`2fUF80]iIS0;VHI@2jVFH00P2jV6P0
102iUfL0^9IV0;RFIP2gUFD20;JDI0@0]I=S102fU6@02@2bTf@0/iAU0;BEIP2eUVL0]iQY0;RIJP2i
VV/0^Y]/0;jOL0020;nPL@040<2QLP31XW<0`J9c0<:SM080`jAe0P3:Zgl0103;[800c:f10<b]P@3=
[X820<j_P`060<j`RP3?/H/0d;:>0=2bT03A/i40d[>D0P3C]9L30=RkV`80fKbL0`3J_Id02@3J^IX0
fkZK0=bkW03M_9d0g[fN0=nnW`3P_j00hL2Q0=nnV`030=jmVP80gKbI0P3L^iP80=g1W0040=g0X03N
`J40g/6Q0=o2XP80h<>S2P3Qa:@20>;4Z080hL>W0`3P`ZH00`3O`JD0h/FU0>;5Y@060>;5Y@P0h/BX
0P3RaJD20>74Y0<0h<>S00<0gl:R0>74Y03Qa:@00P3P`j<0103O`Z80g/6Q0=k1X@3M`:080=fnW`80
g/2N0P3M_id30=bnW0030=^mV`3I^iL0fK^G0080f;ZF0`3G^ID00`3F^9@0fKRE0=VhU@020=RgU004
0=NfT`3F]I80eKBA0=FdT@80dk><00<0d[:;0=6aRP3@/8T00P3?[hP00`3>[XL0c:b50<b/Q@050<f]
QP80cZj70`3>[7`00`3=Zg/0c:Yj0<^YN@020<^YN@P0cjb40`3>[XL20<f]QP<0c:b50`3=ZX820<j[
P`<0cjb400@0cZ^30<n/Q03?[8@0d:f50P3A[XH20=:_Q`030=FbS03D/H/0dk2:0080dZn900@0e;6;
0=JcS@3G]8h0d;290`3?[hP20<j^Q`80cJf60P3>[7h20<f[O@<0c:Yl00<0bjUk0<fZPP3=ZX801P3=
ZX880<^XP0<0cZ^30P3?[8@30=2]Q@080<f[O@3<ZWd0bjUl0<ZWO@3:Ygl0bjR20<bXQ03=ZHD80<fZ
P0@0bJIl0P38YG/20<NTNP040<BQM`35XWP0aJ9h0<JSN@80ajAj0P38YG/01P35X7<0a9mb0<>NL@33
WW40`Ye`0<6LK`80`9]^00H0`Ie]0<6MJ`31WF/0`IeY0<6NJ031WVH20<6NI0P0`Ima0P30WW020<6O
L@@0`Z1b00@0`j5c0<6OK`31Wfl0`Im_0P30WVh30;nMK@030;nKJ`30W6`0`Ie]0080`Yi^00<0`9a/
0;jJJP2lV6P0202lVVX02032WV`0`Ie[0;jJIP2kV680^IIP0;REG@2hUE/0^IIL0P2gTf<00`2hU6@0
^IEU0;ZFIP020;^GI`070;bHJ02nVF`0_YYZ0;fIJ@2mVFL0_IUU0;fJI0020;bIH@080;ZFHP2lV6@0
_i]W0<2LJ02oVfL0_9QT0;RDH02eTEd80;NCG`080;>@F02dTET0]Y=K0;NDG02fTe/0]I9J0;:?E`2a
SUH30;6<Eb_ooooo000Zooooo`<0Z7m;00<0Ygi:0:ImB@2VODT00P2UO4P20:ImA@040:MnAP2XOdL0
Z7m70:V0B080ZX59202ZPDd20:YnC@80Zgm>0P2/P4l20:f1D0080:j5C`2]Q4h0[8==0:b3C@2]Q4h0
[hI@0;68DP2bRE<40;27D`80[hIB102^QE420:n6DP80/8MC0P2aR5@01P2bR5H0/8ID0:j4DP2]Pe40
[89@0:f3D@80[XAB00`0[h5?0;22D02_Q540[hIB0;28E02_RUD0/8]F0:n<EP2eReT0]8YH0;>9E`2d
RUP20;F;F@040;R>G02jT5h0_99P0;NCH@<0^9AR0P2iUF<20;ZFI0030;RCIP2jUFP0^iIY00<0_IQ[
00P0_9MZ0;^FJ@2mUfP0_9IW0;^EIP2jU6D0^I=T0;RBH`80]i5R00P0]8iM0;F?GP2eSeh0]HmN0;>=
G02aReX0[XQG0:b6E@80Zh5I00h0ZGmG0:MmE@2SNE40WWA<09Y`B02GKDD0SVTl08aW>P29I3L0QV4d
08EP<`26HC@0Qf8e08QS=P80RV@e00H0RfDf08eW>02>J3T0SfTj091Z>`2AJc`309A_>`<0UG0l0P2F
LCd309Mb?P80UW4m0`2EL3`01P2LLT00Vg4o09Y`?P2IKcd0V6hl09M]>`80UV`j0P2CJCL00`2DJSP0
UF/i09I/>P0209M]>`0309Q^?02DJC`0U6Tl00H0TfPk202?I3L00`2<ISL0RfDf08]U=P0508]U=P0;
08aU?P2;I3/0RF8i08UR=`29HcH0RfDf08eW=P2>J3L0TVLj095V>@2?I3L00P2=HSD00`2>HcH0Sf@g
091U>00208aV=`<0RfDf0`2:I3D408US=P80RV@g0P2;ICP908eW>008095/>02@JcL0SVTe08aW<`2;
IS80S6Lc08eX=02>JCD808eW>0<0RFTj0P28J3T308MW>080RfDh00<0S6Hi08eW>P2>J3/00P2?JC`0
0`2@JSd0S6Hg08eW>00208eW>080SVPi0P2?JCX8095]>@P0Tflo0P2CKc/0102BKSX0TFdi091/>02?
JcL208iZ=P08095/@02BKD40Tfi109A`@02FLT00V7A009Ue@@2IMT0209Eg@@0309Ih@P2GND<0V7Y4
0080VG]500<0VWa609IjB02FNTP00P2FNTP409MkB@06099cA02@LD80SFho08UZ>`26IcP0QFHg0P24
ICH0;02:JcD0RV`h08IZ>P1jHSH0K5H_05m=:@1HB2L0ETLZ04`n9019>R<0@cLO048g8@10>2<0?CHS
03L`7P0`:aP0;C0M02/^6`0Y;1/09RPJ02DW6P0T9Q/09BLL02DV7P0S91`08R<K024R6P0P8AT08B8J
028S6`0T9Ad09BHN02@U7@0T9Q/09BLL02HX6`0W:A/0:2/J02P[600Y;1T092LN02<V7@0Q91/07b8I
0P0N8AP201lR6@8071lH0P0M81T201hQ6P<07b8K01`071hI01dP6@0P8AT08b<G02XX6@0`;AX0=38M
03Td7P12>A`0AC`M04a18`1AARH0EdXX05U;:01JBRH0FDTU05e:801HAB@0D3/V04Ld9P11;bD0?blR
03ha7P10=1`0@c<J04De7017=ah0BCTP0P1:>R4204Ti800404`l8`1:>R40B3PO04Hf7@<0ACDL00<0
ASHM04<i8013>B000P14>R402012>1l0@3HM03dc6P0l<QT0;RdK02h/7@0/;Ad0:b`L0P0Y:ad202PZ
700V02HX7@0T9Q/08R@I024S600R91T09BLL02PZ7`0[;B80;R`P030]7P0h<Q`0AchQ05U;9P1YER/0
LE/Y07=L9P1hFRP0QFLe08e_?@2:K3X0Rfdk09AfA02HNTP0UGM50;B=B02gTeL0Z8ML085XBP1IAc<0
@CTV03Pf8@0d=Qh0<C@S030c8P0_<B<0;S0S02d_900[;2@202X[9@0<02DZ8`0V:b@0:bhU02h`9@0_
<B@0<34S038`8@0a;b00;RlQ02l`8P0a<R@0<S<U0P0c=2H0100b<bD0<C8T03@`900d<2@203<_8`<0
<RhR00h0<BdQ03@`9`0c;bH0<RhU034]900b;RD0<blV03Da:00f<RT0>C<W03Pb9P0f<2@0=BlS03@^
8P80=BlS0100=S0T03Lc:00g<bP0>S@X03/c9P0m=2D0?c<S044d9011=2<0@cLW04<f9P13=RD0ACHS
04Pg8`1<>R@0DC`W0P1C?bL01P1?@bT0CD4Y04Xn9P18?2H0ASTV04Dh9`80ASTY01H0AcLW04Pi9P1:
>BL0CC/W04lm9`1B?RH0E3hV05Do9`1A@RD0D44T050o8`1A?B80DchS05Hn901H@2H0FT0W05Y5:01J
ABX0F4@Y05E4:P1C@BT0DD4Z0P1?@2/204hm:@0C04lm9`1B?RH0E3hV05Lo9@1H@2H0FT0U05E3:`1G
@bX0ET8Y05M29`1K@bL0GTDW0697:@1SB2X0ITl_06A=;@1QBR/0GTHZ05a4:P0205]3:`0:05a3;@1B
@BL0D40V04lo9P1<?BH0B3`V04Hk9`12>RD0@SXW03hi9P80?cPV00<0?cHU044e9@12=BD00P13<b@0
2010=2H0?C@U03dc9`0k<bP0>C8X03Hb:@0d<BP0=34Z0P0f;bD00`0f<2@0=S0R03H`800203Lb7`04
03Lb7P0i<bD0>38T03La8`80=BlQ00<0=c4S03Pb900i<bD00P0g=2<01P0f<b@0=30T03<_900a;B@0
<2`S030[9@80;2`T00@0:b/S02XZ8P0Y:B40:2PP0P0W9al802hZ8@0302`/8P0[:b40:RXP0080:RXP
00<0;2`R02h^900_;bD00P0g<BD0100f<2@0=BlS03@^8P0c;B42038/8008038[8@0c;280=S0T03Tc
9@0k=BD0?CPU03hi9P0n>BD2048e9@04044d9010<b<0?S4Q03d`8080?2lO100h<R@303La8`80=S0R
00D0>c8Q03dd8`12=bD0ASTV04Xk9P0204/k900?04`j8P1?@240D44R05529@1BA2L0DT@Y04m4:01=
@BL0C40V05U19`1K@bT0GTHZ069;:`1TCB/0IDlX0080IDlV00<0I58^06=A;@1QCb/00P1OCBT02`1P
CRX0HDl[069@;01MCRd0G4d/05U::`1FAbX0Dd<Y05109`1=?BH0C3`U0080DD0R01h0E44Q05I18P1K
A2@0GdPV06A<:01VCRX0IU<Y06QB:@1YE2T0K5DY06iF:01aERL0LeLX07AH:01nF2T0Q5h_08QV=P2:
JST0R6`j08Q^>`2:Lcl0SGQ309AY?02GK3l0VW9109ihA`2QODT0XX5<0:B3C@2TQDh20:2<F@070::<
FP2USU`0ZY1O0:nCH`2eUVL0^9UZ0;>RM0020;>RMP0`0;>RM`2aWgL0[ieg0:bJMP2ZV7@0[YM]0;2H
K02bVV`0]I]Z0;RMJ02lWfL0_YmV0;jPI031XfL0`ZAX0<BTI`35Xf@0`Z1P0;jKF@2jU5<0]i9>0:n:
E@2^RE80[hQA0;:9D@2gSE<0_i9G0<JJG@3;WF40eJUP0=N]I@3I/Vd0fKEg0=FfO@3?]7l0ajmo0<>]
OP3AYW/0d:Eh0<nUM@3>Y780cZE_0<nVKP3AZFh0dZY]0=2^L@3?[G00c:Y]103:Z6/01P3;ZF`0bJMZ
0<j/K`3D/WD0eK=f0=:`L`80cje`00D0d:ia0=2^K`3=Zf`0cJ]/0<^YJP020<VWJ00>0<^YJP3>[6d0
d:i_0=6[JP3<YVD0aj5P0<JPG`38XV40bJ=R0<NQH033WE`0`J1M0<:QGP34Xf020<FTH@030<BSH033
XUl0`Z5N0080_J1N00H0_IiM0;fKF`2jV5P0]iAD0;F?D02cSDh30:n=CP0;0;2>C`2cTE80]YAE0;VG
F02kVEX0_9YK0;jLG@31Wf00a:9S0<JTI@37YFH00P36Y6D30<NUIPD0b:IW00H0bZQY0<^YJP3<ZV/0
cJ]/0<j/K@3@[Vl20=6_L0080<^`K@3=/Vl0aZYY0<N[K03B]GT0ajY`0;>FG02_TUX20:^AGPH0[99O
00H0ZXmT0:Z?HP2YSV40ZHiO0:R>G@2XSU/20:N>F00@0:Z>GP2[Sel0[91P0:jBHP2_Tf<0/IEU0;:F
IP2cUfL0]IYU0;FII`2iWFd0`JAh0<^^QP3A/hl0d[BB0=2aTP<0dKBB0P3B]I<30=>fU080dKB<00@0
d[F=0=>fSP3D]hl0eKR@0P3F^I405P3C_9<0e;fD0=BmU03C_9<0dKZA0<jgSP3;]8/0b[>:0<bfS@39
]8T0aJj40<2XO02mXWD0^im`0;^LK@2jVf`0`j=m0<FUO`38ZXH0c:n=0<jdT@3@^9H20=6jVP060=[1
X`3Ka:D0glN[0>;=/P3Td;L0iM>k0P3UeKh01`3Ze[/0jmNl0>cH_@3/f;d0kMVn0>kJ_`3`g<400P3a
gL880>cJ`P060>gI`03/f;l0k=Ro0>_G_P3Ze[d0jMFl0P3Xe;/20>[F_@80jMFl103Xe;/20>WF]P04
0>WF^03YeKX0jMFl0>WE_@80jMBo0P3Ve;h20>OE_`<0j=K000<0jMO10>_E_@3[eKd00P3Ze;`30>WC
^`070>SB^P3YdKT0j=2f0>O?]@3UcK40i<f^0>;;Z`020>7:Z00N0>?2X`3R`J80hL2O0=nnV`3M_IL0
fk^D0=ViTP3H^8l0f;:50=NaQ03D[Wl0dJ]l0<fWMP3:YG40aj9]0<JQK038WFX0aiaY0<BII031UUl0
_I=I0;Z@EP2gSE40]Xa@0;>8F`2bQeX0/HII0;25F02_Q5L0[H9E0P2/PE@0102YQED0Z8AD0:R4E02W
Pe<20:J2DPL0YH5A0`2TP5001P2OODl0WWa>09ilCP2MNdd0W7Y<09]iB`80VWQ:202MO4L00`2PO4`0
XGe=0:9nCP020:=oC`040:5mC@2ONd/0WWY:0:5kC080X7Y;00<0WgU:09ihB@2MMdP00P2LMTL0202I
M4P0VWE909]fBP2LMd/0VgI:09YeB@2HLdL0Ug962@2IMD400`2IMDD0VWI609YfAP0209]gA`0309ah
B02MNDT0WGU900<0WgU:0P2PNT/30:5kC0P0XWi>00P0Y7iA0:AnC`2SODh0XWa;0:5lB02ONTD0WgY3
09ii@P80X7]400<0XGa50:9mAP2SOTL00P2TOdP00`2UP4T0Y81@0:F1D@020:F1D@80YX9B0P2WPe<2
0:F1C@80YX9>0`2WPdl01P2XQ500ZHA=0:V4C@2ZQDh0ZhI?0:b7D080[HQA00<0[XUB0:j:FP2^RUX0
1P2^RUX01P2[QeD0[8QF0:f9E`2^RUP0[h]I0;2<FP80/HeK00@0[XeG0:n>F02_SUT0[hiK0P2`SUh2
0;6?H@80/i1V0P2dTFL30;FBJ0040;JCJ@2iU6L0^IAW0;VDI`80^YEX0`2kUVT20;VGJ@80^YQZ00`0
^iU[0;bJK02lVV`0_9Y/0;fLJ@2kVVL0^IQU0;RGI02gUV<0^9MT0;VHI@2jVFH20;ZHJ080^IMW00@0
^9IV0;NEI@2gUFD0]iEU102iUfL40;ZHJ080]iQZ00@0^9U[0;ZKK@2kW6h0_Ii`0P2nWg401033Y7H0
a:Eg0<BUM`35YWP20<JWN@030<NXNP38ZG/0b:Uk0080bjb000<0c:f10<f^PP3>[h<00P3?/8@02@3@
/HD0dK>=0=6cS@3B]900dkFC0=BfU03D]IH0eKJI0=JgVP030=VlW080f[fM0`3K_Yh01P3K^Y/0g;^L
0=flW@3N_Ih0gkjO0>2oX080hL2Q00@0h;nL0=nnV`3O_Y/0gkjK0P3N_IX20=flV@P0g/:M00<0g/6Q
0=o2XP3O`Z800P3P`j<20>74Y0030>;5Y@3Qa:@0hLBT00H0hLBT0`3Ra:P20>73Y`<0h<:V203RaJD8
0>;4Z080h/FU0P3Qa:@40>33X`<0hLBT00<0h<>S0=o2XP3O`Z800P3N`J480=fnW`<0g/2N0P3M_id3
0=bnW0<0fK^G0P3H^YH30=NiU@060=ZiUP3I^9D0fKRE0=RgU03G]Y<0e[FB0P3E]9401P3D]8d0dk><
0=>cS03B/X/0dK6:0=2`R@80cjn8103=[HH50<j^Q`030<n]O@3>[7`0cZal0080cJ]k0P3<ZWX00`3;
ZGT0cjb40<n/Q0060<n/Q0040<n_R03>[XL0cZj70<j^Q`80cJf60P3<[8D30<fZPP80cZ^31@3?[8@2
0=2]Q@80dJj60P3B[hL00`3E/X`0e;6;0=>`RP020=:_R@030=BaR`3F/hd0ekB>00<0d;290P3?[hP3
0<j^Q`040<n]P03>[7l0cZao0<j/O`80cJ]n0P3<ZWd80<fZPPP0c:V10P3>Zh<30<n/Q0<0d:f500P0
cJ]m0<bZO@3;ZG`0bZMm0<ZWO`3;Z880c:R40<fYQ@P0cJZ00P3;Z7h20<ZWO@<0bJIl00<0b:Ek0<FR
N035XWP00P36XgT01037Y7X0b:Ek0<RUN`38YG/20<FPL`030<BOLP33WW40`Ye`0080`Ia_00H0`9]^
0<6MK@31WFd0`Ie[0<6MJ@31WVP20<6NIP030<6NI032X780`Z1b00H0`Z1b00@0`9i`0<6OL@31Wg40
`Ima0P32X7830<>QL`040<:PL031Wfl0`Im_0<6OK`80`9i^0P2oWFd00`2oVf/0`9a/0<6MK@020<:N
KP030<2LK02nVVX0_IUY00P0_9YZ00P0`Yi/0<6MJ`2nVVH0^iQR0;VFH02hUEd0^9EK0;VFG080]i=S
00@0^9AT0;VEI@2jUVH0^iMW0P2lV6P01P2nVF`0_YYZ0;fIJ@2mVFL0_IUU0;fJI080_IYR00P0^iMS
0;bHI02oVfL0`9aX0;nKI`2lV6@0^9AP0;JBGPP0]i=O00P0]95I0;FBFP2fTe/0]iAL0;JCF`2eTUX0
/i1H0;6>EP<0]I1K:oooool002[ooooo0P2XOd/30:MnBP<0YWe90P2VODL0102WOTP0Z7m90:QoB@2Y
P4X20:Z1B`P0ZX5=00@0ZWi=0:]oCP2[Odh0Zgm>0`2/P4l00`2]PE00[HA>0:b3C@020:b3C@040:f4
CP2_QU00/8MA0;68DP<0/8MC0P2_QU840:j5D@<0[hIB0`2`Qe<02@2aR5@0/8ID0:n5D`2]Pe40[89@
0:^1C`2/PU00[H=A0:j4DP020;:4DP070;66D`2aR5@0/XYF0;6<E`2bSEP0/XmI0;N=F`020;J<FP06
0;N=F`2hSU`0^8iL0;^AG`2mTf40_YAR0P2jUVH30;^GI`<0_9QX00<0_9MZ0;fHJ`2oVVd00`31W6l2
0;nJK@80_YU/00@0_IQ[0;bGJP2kUVT0^iIY0P2jUFP40;VEI@040;NCH`2eTF40/hmO0;:>GP80/X]R
00X0/HYQ0:j7GP2ZPeX0YWmF0:9kDP2ON4l0UG13099]@02=J3/0R6<f0P26HC@02P28HcH0RVDh08YT
=@2:I3D0RfDf08eW>02>J3T0SfTj091Z>`2AJc`309A_>`<0UG0l0P2FLCd309Mb?P80UW4m0`2EL3`0
1P2KLCl0VW0n09Y`?P2IKcd0V6hl09M]>`80UV`j202EJcT2099W>P0609=X>`2DJC`0UFXm09I[?P2G
K3l0V6e0202@ICP208mY>P0408iX>@2=IcP0S6Hg08aV=`80RfDf00P0Rf@m08]T>`2:HcX0RV<h08YT
=`2;ICH0SFLf08iX=`80Sf@g0`2>HcH00`2?I3L0T6Dh095V>@0208aV=`<0RfDf0`2:I3D308US=P80
RV@g0`2;ICP908eW>005091[=`2?JSH0SVTe08eX=02<Ic<00P2=J3@00`2>JCD0SFLh08eW>00608eW
>0<0R6Hh0P29IcT308YX>P80RfDh00<0S6Hi08eW>P2>J3/00P2?JC`00`2@JSd0SFLh08eW>00208iX
>@<0SfTj00<0T6Xk095]>@2AKCT01P2AKCT8095]?@80Tflk0P2BKSX0302AKCT0T6`h08m[=`2?JcL0
TVe109=^@P2DKd80UG5109Ib@02HM400VGE109Uf@080UGM100<0UWQ209Mi@`2HNT@00P2INdD00`2J
O4H0Ug]909MkB@0209MkB@@0UWY800H0TgA5095b@`2=KSl0RFXk08IW>025ISL208AU=P0H08UZ=029
JcL0QFTi07YR=P1/ERl0GT`X05M79P1EART0C3hT04Tj8`13=al0@SLQ044i900n=b@0>34O034/6@0]
<1d0:bhK02T/6`0V:1X09BLJ02@V6`0U9a`09BHN0P0S91`3024R6P0402<T700U9Qh09RLO02@U7@80
9BLL00<09RPK02LY6`0X:aX00P0Y;1T0100T9ah08bHM024T6`0O8QT201hQ60807b8I0P0L7aP201dP
6@807R4J0`0O8Q/07@0M7aX07R4J020Q6@0T91P0:bTJ034^6`0e<ah0>SDO04<j6`18?Al0CD8R05A7
9@1HBRL0FTXV05a:9P1KBB<0G4/P05M48`1=>bD0A38T03l^900m;b80?S4N03le7013<aX0ACDL04Lg
7P19>B00BSXQ0080BCTP00D0B3PO04`l8`1;>b80BCTP04Lg7P0204Hf7@0404Lg7P18>1l0B3`R04Pl
8P80BCdS00X0B3`R04Hj8015>Al0A3PN03Ha7@0c<1d0<BhK02l^700[;1`0:B/M0P0W:ad05P0V:1d0
92HK028T6@0Q8aP08R@I02DW700X:Ql0:bdR02l]800b;ah0>S@N04Xo8@1MCRL0KEP[07AM:@1gGRP0
OEl]08MY=`2>L3h0SFlm08i`?P2EMdD209]mB`0K0;RACP2eTEL0Wh1D07MM@P1@?b/0?3DS03Dd800a
=Ah0<C@S030c8P0_<B<0;S0S02`^8`0[;2@0:R/U02TZ900X;BH0:BhW02d`9`0`<RL0<38U034b900b
<240<BlP02h_8@0_<280<C8T0080<c@V00<0<S<U034b900`<B<00`0c;b<2038^8P<0<BdQ00P0<RhU
034]900`;2<0;b/R030/8`0a;B@0<blV03@`9`80=S0T0`0g<BD00`0f<2@0=BlS03@^8P0203@`9@0=
03La9@0i<B@0?3<T03lc8`11=2@0@C@S044e9@12=BD0@cHU04Hg9019>2@0CC/U058m:00205<o9`06
0514:P1>@RX0BclW04Pl9P15>2D0A3LV0P14=bL08@16=RH0AcPU04Th9P1<>RH0CcdW05<o9`1E?bL0
ET0X05109P1??bD0CchT054m901B?2@0EShV05Lo9`1J@2T0FdHY05Y5:P1HA2T0ED@Z05=1:@1@@2T0
CSlZ04dn:@1@?b/0CchZ04lm9`1@?2@0DS`T05Hn901I@BL0G48W05E3:`0205M3:P0F05Q3:01K@bL0
GdHX0697:@1TBB/0Hd`/069;:`1OB2T0GDDY05]3:@1J@RX0FD4Y05U0:P1>?B<0CCdS04`l8`1:>b@0
Ac/U04Dj9P12>RD0@SXW03`g9080?CHT00<0?cHU044e9@12=BD00P15=BH0200o<bD0?C@U03`b9P0j
<RL0>34W03Da:00d<BP0<c0Y0P0f;bD02@0g<BD0=c4S03Pb8P0h<b00>C@Q03Td800i<bD0>38T03La
8`0203D_8@0;03La8`0h<R@0>C<U03Hc8P0e<R40=34R03<_8`0a;B80<2`S02l[8P0^:B<00P0/;2@0
100[:b<0:RXR02TY8@0X:20202LW7`P0;RXQ00P0:b/Q02XZ800Y:Al0:BTO02XZ800[:b40;2`R02d]
8`P0=2hR00P0=BhT03@]8`0e;b<0=BlQ03La8@0i=240>cHS03`g8`80@SHV00@0@CDU040d900o<b<0
?c<S0P0n<R8403Pb90<0=c4S0P0f<2801@0k<R40?C@S044f9015>2D0BCXU0080Bc/T00<0C3XR0511
901A@RD00P1B@bH02P1B@RP0DD4W04m19P1>@2D0Fd<W05e5:@1PBBX0HT/[06A=:`1UCbX206A>9`04
06EC;`1SDBd0HDl[05m=:@@0GD/W0100Ge0_05e>;@1JBb`0EdP[05=3:@1@@2L0CShW04dm9P1@?b40
Dd0P05A18@1HA2<0GTLU06=;9`1XCRT0JU0[0P1_FC00A`1`FBl0LUX^07AI;01eFBX0N5T[07QI:P22
GRh0QF<c08]Y>@2<K3/0Rfdk08U]>`2<LSl0SgE209=[>P2FKSd0VWE10:1lB02VPTh0ZHQC0:^<EP2/
SEL0X8aI0:6=FP2SSE/0YHiL0:Z@G`2^TV80/iAU0;FFI`2^WFl0[Ia`0:^JKP2XUf`0Y99Z0:2>J02L
RVH0VXQT0:J?I@2YTFD0Zi=U0;2FI@2eVVD0^YeU0;nPI`30XVH0`jEY0<BVJP36YVT0b:IW0<JTI033
X5h0`I]J0;jIE@2eSUD0/haC0;::C`2bR4`0^8a?0;nAD`37VE/0cYiN0=>YH@3CZfD0eZm/0=JbM03C
/gX0ck5k0<Z^OP36Zg`0cjI^0080cZI[00X0cZIY0<nWJ@3AZVT0dZ]X0=>/J@3A[g80cje`0<f[KP3;
ZF`0bZQ[0P3;ZF`00`3<ZVd0cZYf0=>_N`020=NcO`050=:^NP3>ZWH0cJUe0<n[M`3?[7@00P3>Zg<0
2@3;Z700bZM_0<^XL03>Zg<0dJif0=BaN@3@[Fd0c:UY0<JSH`030<BQH@060<>PH031WUh0`ImO0<:P
H033XF40a:9R0P35Xf<03@34XV80`j5Q0;nRH02oXV00`:5P0<:PH031Wel0`9eM0<6KG030VU/0^YQI
0;VGF02gUEH00P2fU5D01`2gUEH0^IMH0;ZHF@2nW5d0`9iO0<>QHP36Y6D01038YVL80<VWJ080bjUZ
00h0c:Y[0<j/K@3?[Fh0d:i_0=6_L03B/740bJi[0<fbK`39[F`0bZi_0=>fNP3;[W@0]iYP0:f@F0<0
[99O1@2[TEh01P2ZSf@0ZXmR0:V>H@2YSUl0ZHmN0:R>F`80Z8mI00H0[91P0:fAH@2]TF40[Y9R0:nC
H`2`U6@20;6EI@080;FJI@2fVVP0^Yi^0<:UN@3=/8P0dkFA0=BfU03C]9D30=>fU080e;NE0`3E^9H2
0=>fSP030=BgS`3E^900e[VA0080ekZB00<0f;^C0=BlUP3D_9H00P3D_9H06P3B^Y@0ckNA0<bdSP3:
/X`0bkF<0<VcRP35[X@0`JUm0;jSMP2kWg00^ia^0;ZKK032XW`0aJEo0<NYQ@3<[hd0c[BA0=2hUP3@
^IT0dKZJ0=W0XP3J`j@0glN[0>7</@3Td;L0iM>k0P3UeKh02@3Xekd0jMRn0>[I_`3ZfKl0jm[00>gL
`P3^gL<0kmk40?3Oa@080>gK``060>kJ`@3]fL00kMW00>cH_`3[ekh0j]Jm0P3YeK`30>[F_@80jMFl
0`3Xe;/20>WF]P040>WF^03YeKX0jMFl0>WE_@80jMBo00@0j=K00>WG`@3Yel40jMO10P3Zf<820>_I
``80kMW10P3/f<020>_G_`80j]Jn00H0k=>m0>_C^`3Zd[X0jM6g0>O?/`3Vck020>G>[P060>[;[P3Y
bZd0j<VZ0>K8YP3TaZ@0hlFQ0P3Q`id06@3R_9D0h;^A0=jiS`3K]XX0f;>60=FaP@3B[W`0dJek0=BZ
NP3CZGT0d:Id0<fTL03:XFd0aiiX0<FLI033VV80`9MQ0;nFH02nUEl0_9=M0;V@FP2gSUP0]HaF0;B;
E@2`S5`00P2_Re/00`2^RUX0[HUI0:b8F0020:^7E`80[8QH0P2[QeL20:Z6EP80ZHEE0P2TPU@00`2S
PE<0XX1B0:5oD@020:1nD00309mmC`2OOTT0Wgi900H0Wgi900<0Xgm?0:B0D02UPE400P2VPU80102T
P500XWi>0:5mC@2TOTl20:=mCP030:9lC@2QNd`0X7Y;0080WgU:0P2MN4/309mjC@0309ehB`2KMTT0
VWE800T0WWY60P2ONd/20:1lC0@0XGe=0`2QNd`20:9lC@<0Xge>202TP5001P2UOe80YGm@0:AnC`2S
OD`0XWe90:9mB080XGa50P2QO4L0102RODP0Xgi90:AoBP2UP4/20:J1C080Y81@0P2UPE420:J2DP80
Yh=C0`2WPdl20:R4D0<0ZHEA0P2[QU400`2/Qe80[HQC0:j9E0020:n:E@030;2;EP2`S5`0/8aL00H0
/8aL00H0[XYJ0:n;F`2_Re/0/8aL0;6=G@2bSUh20;>?G`080;2?F@2`SeX0/I1K0;6@G@2bT600/Y1R
0;:@H`2cTF@30;FBJ0<0]Y=Y0P2gU6X20;ZEJ080^iIY0P2lUfX20;fHJ`<0^iU[0P2lVV`30;fKK@03
0;jLK02mVf/0^iUY00<0^YQX0P2kVFT30;ZHJP<0^IMY0P2hUVP30;fKK@80_Ya^0`2oWFl01P2lWG40
_Iib0;jOL`2oX7@0`:5e0<:SM`80`jAh0P39ZWh0103:Zgl0bjb00<b]P@3<[H420<f^PP070<j_P`3=
[H@0cZj50<j^Q@3?[hH0d;270=6aR0020=:bR@060=BfT03E]i40eKNC0=JhUP3G^IL0f;VJ0P3I^Yd3
0=^nWP80g;nO0`3M`:020=bmWP040=fnW`3N_j00gl2Q0=o0X@80h<6R0`3O`Il20=k0WP<0gKnM203O
`Z030>33X`80hLBT2`3RaJD20>?5Z@80h/BX0`3Q`jL00`3P`ZH0h/FU0>;5Y@060>;5Y@P0h/BX0`3R
aJD20>74Y0<0h<>S103Qa:@20>33X`80gl:R203N_j020=o1W`80g/2N0`3M_id0103L_Y`0f[bH0=Zl
V03J_9P20=VkU`<0f;ZF00H0fkZG0=ZiUP3J^IH0fKRE0=RgU03G]Y<20=JeTP060=FeSP3D]8d0e;B=
0=>cS03B/X/0dK6:0P3@/8T90<j^Q`80cjeo0P3>[7h40<f[O@P0d:f50`3?[hP20<j^Q`<0cJf60`3>
Zh<20<n/Q0H0d:f50`3A[XH20=:_Q`030=FbS03D/H/0dk2:0080dZn900<0e;6;0=JcS@3G]8h00`3A
/HX20=2`R@<0cjn80P3@[H<30<n/PP<0cZ^14@3>Zh<30<n/Q080d:f50P3A[XH0203>[7h0cJ]n0<bZ
O@3;Z7h0bjR00<bYP`3=ZHD0cZZ62`3=ZX020<bYO`<0bjQn0P36XgT20<NTNP@0b:Ek0P36XG@00`35
X7<0a9mb0<>NL@020<:ML0070<6LK`32WG00`Yi^0<:NKP32WV`0`YiZ0<:OJ@020<:OI`P0`Z1b0P31
Wg420<:PLP@0`j5c00@0a:9d0<:PL032X700`Z1`0P31Wfl30<2NKP80`Ie]0`32WVh00`30W6`0_i][
0;jJJP080;fKJ`090<:NK031WF/0_YYV0;^HHP2iUV00^9EM0;REF`2iUU`0]i=S0080^9AT00<0^IEU
0;ZFIP2kUfL00P2lV6P01P2mV6/0_IUY0;fIJ@2nVVP0_YYV0;jKI@80_Y]S00L0_9QT0;fII@2oVfL0
`9aX0;nKI`2lV6@0^IEQ00T0]i=O0P2eTU`30;JCG@030;FBG02cT5X0/XmI00<0^9=N:oooool002[o
oooo1P2WOTX40:ImB@040:MnBP2XOd/0Z7m;0:V0C0X0ZX5=102[Odh40:b0C`80Zh9<0P2/Pdd0102]
Q4h0[XE?0:n6D02`Qe420;27D`80[hIB0P2^QE420:f4D0@0[hIB102`Qe<00`2_QE<0[XAB0:f3D@02
0:^1C`030:b2D02^Q580[hEC0080]HME00L0]8UF0;F<F02eSET0]8mJ0;F@F`2eTU`0^91O0080^I5P
00H0^Y9Q0;bDH`2lU6<0_IET0;nGIP30V6L30;jIK080_iY]1030Vfh00`32WG00`iia0<FPL`020<FP
L`030<BOLP33WW40_ie`0080_ie`00<0_Ya_0;fKKP2mVfh00P2lVVd0202nW6h0_I]]0;fKK@2lVV`0
^iU[0;ZHJP2iUfT0^9IX0P2gTVP02P2fTFL0]8mU0;2;H@2/Qed0Z8=I0:J1E`2NND`0VWE809=^@@2=
J3/208UT=`0:08]V>@2<IcX0RV@e08YT=@2;ICH0SFLh08iX>@2?JCX0T6Xk095[?0<0U6lk0`2EL3`2
09Ia?@<0Ug8n0P2FLCd309E`?00309Y`?P2IKcd0VFlm0080V6hl0P2GKC/00`2FK3X0Ufdk09M]>`02
09I/>P0409E[>@2DJSP0U6Xh09=Y=`<0UFXm0`2FJch209M/?`P0SfHh0P2AJc`01`2@JS/0SVPi08eW
>02<ISL0RfDf08YT=@2;I3d00P2;I3/00`2;I3T0S6Hi08aV=`0208eW=P80SF8e0P2>HcH0102?I3L0
T6Dh095V>@2BIcX208aV=`<0RfDf0`2:I3D208US=P80RV@g0P2;ICP208aV>@T0SFLh0P2?JSH608iY
=@P0S6Hg0P29I3L0102:ICP0RfHi08]V>@2<IcX208eX>`80RfDh00<0S6Hi08eW>P2>J3/00P2?JC`0
0`2@JSd0SVPi08iX>@0208mY>P@0T6Xk202AKCT8091/?00309A`?02CKc/0Tflk0080TVhj0P2AKCT0
1P2@K3P0Tfi209A_@`2DKd80UG5109Mc@@80V7A000H0VGI009Eg@@2EMd40UWQ209Mi@`2HNT@209Uk
A@0609YlAP2IOD/0V7a:09QlBP2GNdT0UWY80P2ENDL01`2DN4H0TgA5095b@`2=KSl0RFXk08IW>024
ICH00P23I3D09P28JC<0R6Xf08AX>01iHCD0JeD^05e;9`1FARD0E4DX04`n9018>B80A3PP04<h8P12
>RD0?SLT03Tb800b;AX0;C0M02/^6`0Y;1/09RPJ02DW6P0T9Q/09BLL02DV7P0T9Ad08b@L028S6`0Q
8QX08R<K02<T700U9Qh09RLO02DV7P0U9a`09RPM02LY700W:A/0:2/J0P0Y;1T0100T9ah08bHM024T
6`0O8QT201hQ60807b8I0P0L7aP201dP6@807R4J0`0O8Q/0700N81/07b8K024R6P0U9AT0:bTJ034^
6`0f=1l0>cHP04Hk6`19?Qh0D4<Q05I89@1JBRH0GD/U05e9901LBB40FDXO05A48P1:>R<0@C4R03/]
8P0k;b40?C8N03hg7@14=1/0ACDL04Lg7P18>1l204Ti800504Ph7`17=ah0C3`S04/k8P19>B000`17
=ah00`18>1l0BCTP04/k8@0604`l8P0Y04/k8@0o=b00?CDN03Pa7P0b;a`0;2dM02T[7@0V:Q`092XN
02HX7@0T9Q/08R@I024S600R91T09BLL02PZ7`0[;B80<BhO03D`7@0n=Ql0D4<S06=A:@1bG2d0NEl/
07]P:@23IC<0RF/i08i`?P2@LT00TG=109IhAP2MOdd0XH=A0;^EE02aSUH0U7M=06]C=`18>BH0>34Q
038c8@0_=1h00P0`<b80100_<B<0;BlR02`^8`0Z:b<202TZ900;02X_:00[<2T0;c8Y034c:00a<bH0
<C8T038`8@0a;b00;c0R030a8`0b<bD00P0c=2H00`0b<bD0<C8T030a8`0203<_8`<0<RhR0`0a;B40
0`0a;B@0<2`S02l[8P0202hZ8@06030/8`0b;RD0<blV03<]8@0e;b<0=c4U0P0i<bL04P0g<BD0=2hR
03<]8@0a;B80<RhS03D_8`0h<2<0>c8S03lc8`11=2@0@SDT03lc8`11=2@0@cHU04Lh9@1:>BD0CS`V
058m:080DclW00H0D4@Z04i2:P1;?bL0Ac/U04Dh9@13=RD204<f9P0Q04De9@16=b@0B3LU04`j9P1>
?2H0DclW05Do9`1F@2P0CclU04hn901>?B<0D3`S054k8`1E?BD0EShV05To:01KART0FdH[05Q4:@1D
@bT0DT0X04lo:01=?RT0C3dX0591;@1@?b/0CcdW050l901B?2@0EShT05Y2:01M@bP0ET@/0080Ed<Z
01H0F4<X05a4:01OARP0HdPZ06A9:`1QBRX0H4TY05i7:01LA2P0FT8X05U1:@1H@2P0EchX04/j801:
>R00BSXQ04Pi8P16>R@0A3TU048j9@12>RL0>SDR0P0l=B<03@0n=B@0@CDU04<f9P15=BH0ASHW03hb
900l<b@0>c4U03Ta9P0g<2H0=30W03<`9`0b;bP00P0f;bD02@0g<BD0>38T03Pb8P0i=240>SDR03Xe
8@0i<bD0>38T03La8`0203D_8@0;03La8`0h<R@0>C<U03Db8@0d<B00<c0Q038^8P0`;240;b/R02hZ
8@0]:2800P0/;2@0100[:b<0:RXR02TY8@0X:20202LW7`P0;RXQ100Y:Al202XZ800402/[8@0/;280
<R`P038/8080<bdQ00`0=2hR03D_8`0e;b<0=S0T03L`9P0e;R@0<bdQ038/7P0c;Ad0=C0M03Pc800j
=B4403`c90@0>c8S100h<R@303La8`80=S0R00P0?3<R03dd8`10=B<0@cHS04Lh8`1:>R<0Bc/T04`j
8P80D48X0P1A@BL205919@80Dd0R00@0GTLW05m8:01QBRX0Hd`/0P1TCB/01@1SC2X0HT`W061>:P1P
CRX0GddY0080GT`X0`1MBbL01P1PDC00GTl^05Y;;01FAbX0DT8X05109`80CShW00d0DSlO05E08@1G
@b80GDHT069:9P1WCBP0KE4Z06mC;01aFS40LU/b07AK<P1gG340NE``0080OEh`00D0Oel`08AT<`29
JCP0SFdl08a^?00208]]>`0j08a`?P2@M480VG4m09Ye@02NNTH0Y81<0:R7E02[ReP0[8iL0:f?G@2P
S5T0XHeJ0:>=F`2USU`0ZHmN0:b@H02`TF80/I9S0:RFJ02WU6T0Y95V0:6>I02MRV80VHEP09F1GP2C
Oe`0WXMM0:69G@2SRed0ZHmN0;2EH02gVV80_IiU0<2RIP31XfL0`ZAX0<BTI`37YFH0aZAT0<FRH035
Weh0`iiJ0;fEFP2jTUD0^8mA0;R<C`2lSU00`iIE0<fMF`3BXV00dj]U0=F]J03F[fh0ek5c0=BaM`3A
/7/0cZik0<b/N`80cjQS00/0d:UT0=6[I03B[6D0e:iW0=F_J03F/6L0dk1f0=:_M@3?[780cJY`0<bY
K`020<fZL00:0<j[L@3A[7l0e:n20=NbQ@3E/8<0cjYm0<ZUN039Y7L0bZEh0<bXM080bZIb00/0b:A`
0<NSK`39YG40c:Qd0=2/N03C[g/0d:i^0<bZJP37YFD0`j5Q0<6OG`030<2NGP80`ImO00<0`Z1P0<>Q
H@34XV800`35Xf<01P31Y680`ZES0<BUI037YFD0b:IV0<VVIP80c:IW00D0aJ=T0<>QHP30WUl0_I]L
0;^IFP030;ZHF@060<2NG`32X640aJ=T0<RVI`3:Z6T0bjUZ0P3:Z6T20<^YJP@0bZQY0P39YfP20<bZ
J`0>0<f[K03?[Fh0d:i_0=6_L03B/740dk5b0<V^J`3=/Vl0cK5`0<faLP3B]GT0c[5g0;bOI@2/SeL2
0:bBG`@0Zi5N0P2ZT5d01P2ZSf@0ZXmR0:V>H@2YSUl0ZHmN0:V?G080ZI1J0`2^TV803@2_Tf<0/9AT
0;2DI02`U6@0/IEU0;JKIP2fVVP0^im_0<BWN`3?/XX0e[RD0=NiU`3F]iP00P3F^IL20=NjV0<0f;^I
00<0fKbJ0=JhTP3F^9800P3G^I<20=RjU080fK^E103E_IT0703C^iL0d;RD0<feT@3;/hl0bkF>0<Vc
S036[hH0`ZV00;nTN@2lWg<0^ia`0;ZKK@32XW`0a:An0<NYQ@3;[X`0cK>@0<ngU@3@^IT0dKZJ0=Ro
X@3I`Z<0g/JZ0>7</@3Td;L0iM>k0>GE_P3Ve[l20>SH_P80jMVo00<0jm_10>cL`P3^g/@00P3_glD8
0>oMa@80km_200<0k][10>gI`03/f;l00P3[ekh00`3Ze[d0k=Nl0>cG_0020>_F^`80j]Fj0P3Ye;T2
0>[G]`040>[G^@3Ze[/0j]Jm0>[F_P80j]G000@0j]S20>_I``3[fL<0jmW30P3/f/@20>gKa@040>kL
aP3]flD0kM_50>gKa@80k=[40P3[fL<01P3]el00k=Jo0>_E_@3Ze;`0jMBi0>SC]P80im:c0P3/dKH0
9P3[d;<0jLj`0>S>[@3Vc:T0iL^X0>C:Y@3Va9l0iL>N0>?1V`3Q`9L0g[fB0=^jS@3I^8/0f;R90=^d
R@3J/hP0f;:50=F_P03C[G`0d:]g0<jYM@3=Z7<0bjAY0<ZSJ038XFH0aIiS0<:KH02oV5d0_9EJ0;^D
F@2fTV80]I5Q0;B@H02cSel0/XiN0;6=G@2`S5`0[h]K0P2`S5`20:n;F`060:j:FP2]RET0[HUI0:b8
F02XQUP0YhEG0P2VQ5H0102UPeD0Y89D0:>1D`2SPE<80:>2C`030:N3D`2XQ5@0ZHEE0080ZXIF00@0
Z8AD0:J2DP2UPE40Z89C0P2WPE800`2VP540YGm@0:AnC`020:=mCP080:5mC@2ROTh0Xgm?0:B0D02S
Odl0XWi>0:1lC02ONd/90:5mB`<0XWi>1@2SOdl30:AnC`80YGm@0`2VP5480:J2DP080:N1E02VP540
YX1A0:EoCP2UP4`0Y7m:0:AoB02SOTL20:=nBP030:AoB`2UP4`0YX5=0080Yh9>00<0Z8=?0:F1D@2U
PE400`2VPU830:N3D`80ZHEC0P2ZQU@40:^7E@80[XUE00@0[hYF0;2;E`2aS5P0/HaH0P2bSET80;>?
G`80/XeP0P2cSV401@2dSf80]I1S0;F@H`2eT6<0/Y5L0080/i9O00<0/i5Q0;BBI02dTVD00P2eTVP0
102fTfT0]iAZ0;NDJP2gU6X20;REJ`80^II/0P2lUfX20;fHJ`@0_YU/0P2mVfd60;jLKP80_ie_00<0
_Ya^0;fKK@2mVfd00`2mVfd20;bJK@H0^iU/0P2nW6l0102oWG00`9ia0<2NL@31Wg820<:PL`80_j1d
00@0`:5e0<:SM`33Y7P0aJIj0P36Yg/0103;[800c:f10<b]P@3=[X820<j_P`040<n`Q03@/HD0d;65
0=2`R@80dK6:00<0d[:;0=>cS03D]8d00P3E]Hh20=RjU0060=VkU`3J_9X0fkfK0=bmWP3L_J00gKjQ
0`3M`:020=k1X@<0gl:R0`3N`J400`3O`Z80h<>S0>33X`020>74Y0@0h<>S0P3O`Z820=k1X@P0hLBT
1@3RaJD;0>?6YP80i<JZ0P3SaJT30>;4Z0030>73Y`3SaZH0hlJV00H0hlJV203SaJT20>?6YP80h/FU
0P3Qa:@20>33X`<0h/FU1@3Qa:@80>31XP80h<:P0P3O`Il30=k0WP030=foW@3L_YX0g;jJ0080fkfI
0`3J_9P00`3I^iL0fkZG0=^jU`020=ZiUP040=VhU@3H]i@0ekJC0=NfT`80e[J?00<0eKF>0=BdS@3C
/h`00P3B/X/00`3A/HX0d;290=2`R@050<n_R080cZj7103?[H040<j/O`P0d:f50`3@/8T20<n_R0<0
cZj70`3?[8@30=2]Q@P0dJj60P3B[hL00`3E/X`0e;6;0=>`RP020=:_R@030=BaR`3F/hd0ekB>00@0
d[:;0P3A/HX20=2`R@80dZn50P3A[X@30=2]P`030<n/PP3@[HD0d:f500h0d:f50`3?[8@20=2]Q@<0
dJj600P0cjeo0<j/O`3=Zgh0bjQn0<^XP03=ZX@0cZZ60<n[Q`P0cZ^10`3?[8820<j[P@<0cJZ01@38
YG/30<VVO080aj9e0P36XG@01@35X7<0a9mb0<>NL@33WW40a9mc0080a9mb00<0a:1`0<BPKP34X6`0
0P34XF/80<>QL`80`Z1b0P33XG<50<BRM0<0`j5a0P32X7030<6OK`D0`Yi^00<0`Ie]0<2LK030W6`0
202mVf/02032WV`0`Ie[0;jJIP2kV680^IIP0;REG@2hUE/0^IIL0P2hU6@00`2iUFD0^YIV0;^GI`02
0;bHJ0070;fIJ@2mV6/0_IUY0;jJJP2nVVP0_YYV0;jKI@020;nLI0030;fII@2nVVH0_i]W0080_i]W
00<0_9QT0;ZFHP2hU600202hU6040;JBGP80]I5M0P2dT5`30;NBGB_ooooo000Zooooo`80YWe91P2W
OTX20:ImB@040:MnBP2XOd/0Z7m;0:V0C080ZX5=202YP4`40:b0C`@0Zgm>00@0ZX5;0:^2C02/Pdd0
[HA>0P2^QDl20:n6D0<0[hIB0P2^QE430:f4D0@0/8MC102_QU800`2`QU@0[hEC0:f3D@020:b2D00?
0:j4DP2_QE<0/8ID0;R:F02iReT0^8eJ0;R?F`2hT5`0^9=N0;VDG`2hUEl0^I=T0;ZDI@2lUVL0_IMX
0080_iUZ0P30VV/00`31Vf`0`Ia`0<:ML@020<:ML@80`iib0P34Wg<02034Wg80aJ1c0<NRM@38XgH0
bJAg0<RSMP37XWD0aZ5d0`32XGH30<6PM@80`9md0P32XG@01031X7<0`9mb0;nNL@2oWW420;jML080
^iI/00/0^YE[0;RCJ@2eT6H0/HaR0:f8GP2[QU`0Z8=F0:=nD@2LMdX0UG1308mZ?@0208eX>`0908iY
?02:I3D0RV@e08]U=P2=IcP0SVPi08mY>P2@JS/0TF/l00<0U6lk0`2EL3`209Ia?@<0Ug8n0P2FLCd3
09E`?0@0V6hl102GKC/01P2HKS`0Ufdk09M]>`2FK3X0UF/i09AZ>080TfTg0P2IKT401P2HKD00UV/n
09EZ?@2DJC`0TfPk099W>PP0SVPi0P2AJc`0302@JS/0SVPi08eW>02<ISL0RfDf08YT=@2;I3d0Rf@k
08aU?02<ICX0SFLj08eW>080SFLf00@0S64d08eR=@2>HcH0Sf@g0P2@ICP2095V>@80S6Hg0`2;ICH3
08YT=@<0RV@g0P2;ICP308aV>@T0SFLh0P2>JCD608mZ=PP0S6Hg0P29I3L0102:ICP0RfHi08]V>@2<
IcX208eX>`80RfDh00<0S6Hi08eW>P2>J3/00P2?JC`00`2@JSd0SfTj08mY>P03091Z>`<0TF/l202A
KCT808m[>`80U70l102CKc/2099^>P0509A_@`2EL4@0UG1309Ib@P2GLd400P2HM4001P2IMT00UGM1
09Eg@@2FN480UgU309QjA080VG]500H0VWa609UmB`2HO4X0V7a:09MkB@2FNTP209EiA`0S09AhAP2D
MDH0TW=408i_@029JS/0QVLh08AU=P23I3D0PV<d08MX<P27JCD0PfLg07QP=01ZE2d0G4XV05E5901C
A2L0BcdS04Pi8P14>200@cPR048j9@0o>2D0>S<Q03@_700]<1d0:bhK02T/6`0V:1X09BLJ02@V6`0U
9a`09BHN02@U7@0S91`00`0R8a/02@0T9Ad09RLO02LX800U9Qh09BLL02HX7@0W:A`0:2XL02T/6`02
02X]6P0402@W7P0S9Qd08B@K01lR6@807R4H0P0O8QT201`O60807B0I0P0N8AX301lR6`0K01lQ700O
8Q/08R<K02HV6P0/:Q/0<RlL03Le800l=b40BC`J04e07P1CAB80F4PT05e;9@1NBRD0GdTR05i87`1G
BQh0DD<P04Lh8@0m<200>BdQ03P_800l=1l0?SPN04@d6`15=A`0AcLN00<0B3PO0P16=Qd0201;>b80
BSXQ04Ph7`17=ah0ASHM04Lg7P18>1l0BCTP0`1=>Ah00`1>>Ql0Cc/P050l8@02054m8P0k04/m8P16
>R00?SHO03Ha7@0^;A/0:2XL02@Z7P0S:b009RPM02@V6`0R91T08B<H028T6@0U9a`0:2XO02/]8P0e
;al0>34N04<i801DAB@0J5D[07IN;P1mHRd0Of8Z08QZ>02:K3X0SW0n095c@@2BM480UWQ609j0CP2V
R5H0^YMG0:b;E@2:KTH0GdX_044d8`0g<B<0<C@Q02`d7`0`<b80;c8Q02h`8P0];b80:bdR02X[8`0Y
:R@0:2TS02X_:00[<2T0;c8Y034c:00a<bH0<C8T038`8@0a;b00<34S034b900b<bD00P0c=2H00`0b
<bD0<34S02l`8P03038^8P<0<BdQ0P0`;2002`0`;2<0;b/R02hZ8@0]:B00;RXQ02l[8P0a;B@0<RhU
03<]8@0d;R80=c4U0080>C<W0180=c4U03D_8`0c;B40<BdR038^8`0e;b<0>30S03/b8`0o<b<0@C@T
048e900o<b<0@C@T04<f9@18>BH0BcXV04hl9P1A?2L2054m9@0`04m3:@1=@BT0BShV04Lk9@14=b@0
@cHU04<f9P14=bL0ACDU04Hg9018=bD0BcTU04hl9P1B?RH0E3hV05Do9`1>?RD0CCdT04dk8`1?>b<0
D3XS05@k9@1F?BL0F3dX05Y5:01IA2T0Ed<X05A3:@1B@2P0CclX04dn:@1<?BP0DD0/050o:`1@?RP0
DCdU05<m9@1G?bD0FT8X05e3:01FA2`0F4@[05M3:P1IA2T0G4@X0617:@1SB2X0IDX/0P1OB2P0501N
AbP0G4@X05Y2:01H@2P0EclW05Hm9`1;>R00BSXP04Ti8018>B80ACTS04@i9@11>B@0@CTV03Xe8P0k
=280?3DS03he9010=2@0@SDU0P15=BH0200m<B<0>c8S03X`900h<2D0=RlU03<_9P0b;bH0<BhW0P0e
;R@02@0f<2@0=c4S03Pb8P0i=240>SDR03Xe8@0i<bD0>38T03La8`0203D_8@0;03La8`0h<R@0>C<U
03Db8@0d<B00<c0Q038^8P0`;240;b/R02hZ8@0]:2800P0/;2@0100[:b<0:RXR02TY8@0X:20202LW
7`P0;RXQ0P0Y:Al00`0Z:R00:b/Q02/[8@0302/[8@80<B/O00<0<R`P03<]8@0d;R800P0e;b<02@0f
<2@0=c0V03H_9@0c;B40<R`N038/700e<1d0=c8O03Td800203D]80@0=RhQ0P0g;b8403Pb90<0=c4S
0P0f<2807P0l<b80?C@S040e8`12=B80ASLR04Ti8P1;>b@0CC/S04e1:`1?@2T0D40W05509P1C?b@0
ED0S05Q18P1I@240H4XU065::01SC2X0I4d[06A=;@1SC2`0HT/[065::P1JB2@0FdTU05a:9P1NC2P0
H4hZ065?:`80HU0/00H0GTl^05a=;01HBBX0E4DX05519`1??bH204lo:00V05E1801I@R80G4DS0659
9@1WCBP0K50Y071C:`1aE2`0KeH^071G;`1eFC40NE`b07iO<`23HSD0QF@g08MU=`24J3H0R6`j08e_
?@2<KS`0RV`j08][>P2?Kch0Tg=209mk@@2PODD0Y8590:J5D02XR5D0Z8YH0:N;F`2WRe`0Wh]H0:2<
F@2RS5X0Y8eK0:N=G02YSEd20:^<G@060:B?HP2SSV<0XHaQ09j8G`2LQUl0VXAO0P2HPEl09P2HPEL0
VX9F09f5E`2SREP0ZXmJ0;>FGP2jVf80_ImS0;bNHP2mWf<0`:1S0<>QHP34XV80aJ9P0<JPG`36XEd0
aiiP0<FLG034V5T0`iMF0<NJE`3?X5`0ejIQ0=b[IP3I/Vl0fK9a0=ZbM03I/gD0fK9i0=JaNP3E/7`0
djmk0=:/H@3C[F@0e:iU0=J`I`3G/FX0f;9[0P3I/f`0103F/g/0eK9j0=>`N03A[WH20=2]M@0;0=6^
MP3B[gL0dJao0=B_PP3E/8<0dJao0<ZUN035X7<0a9mb0<FPL`37Y6h00P36Xfd02P34XF/0`j1Z0<BQ
J`38YFl0c:Uc0<j[M@3?[Fh0c:Y[0<NUIP32X6420;jLG@030<2NG`32X640`ImP0080`ImP00D0`Z1Q
0<>QHP35Xf@0aZAU0<NUIP020<FXIP0<0<NXI`3:Z6P0c:YZ0<n/K03C[Fh0e:i_0<f[K03:Z6T0ajEV
0<:PH@2oWEh0_I]L0P2lVU/01@33XF80aJ=T0<NUIP3:Z6T0c:Y[00D0cJ]/0P3<ZV/20<^YJP80bZQY
0P3=Zf`03P3>[6d0cje^0=6_L03B/740dk5b0=BbL`3;/6d0c[=`0=2dL`3>/W<0d;=g0=6dNP33YV`0
[8mG0P2/TUl20:^AGP80ZY1M0P2YSe`01P2YSV<0ZHiQ0:Z?HP2ZSf00ZY1O0:Z@G@80ZY5K00D0[Y9R
0:nCH`2_Tf<0[i=S0;2DI0030;6EI@090;JKIP2gVfT0_:1`0<FXO03A]8`0fK^G0=ZlVP3I^Y/0fKbJ
00<0f[fK0P3K_Y`20=boW@80fK^G103J_9P20=^mV@<0e[jJ01<0eKfI0=BlV03A^ID0c[JB0<bdT03:
]8l0bK>>0<N_R@34Zh<0`JEm0;fPMP2kVg80^IY^0<6QN`34Y7h0ajV50<^^S03=/i00ckNE0080d;VI
00X0e[fO0=S1XP3MaJT0h<^`0>C@]`3Udk/0iMFn0>KF_`3WfKl0j=[00P3Yfl401@3Zg<80k=k40>gO
a@3^h<H0kn7700P0l=k600H0lMg40?3L``3`g<<0km_20>kJ`@3]fL020>cH_`<0k]Jj0P3]eKT30>cD
^080j]Ng00@0j]Ni0>[F^`3Ze[d0j]Jn0P3ZeL00103[fL<0k=[40>cJa03/f/@20>gKa@80k]c60`3_
gLT30>kLb080kM_700@0k]W40>gH``3]fL40k=Ro0P3[ek`20>[G^@0@0>cD_03[dk/0jm>i0>WA]@3X
dK80im2`0>K?[`3UcZ`0ilRY0>K7Z03TaZ@0h/BP0>32W03N`IT0gL2H0=boU@80g[^E01@0g;VA0=Zg
S@3H]XT0e[B60=FcQ@3D/X80dZid0=6]L`3?Zg40c:Q^0<RTJP35XFL0`YiT0<6MH`2mVFT0_9QX0;^G
I`2jUVH0^9AT0;JBHP80]I5Q0P2dT600102cSel0/XiN0;6=G@2`S5`20:n;F`80ZXQJ00<0ZHMI0:R6
F02WQEL00P2VQ5H00`2UPeD0Z8IF0:R6EP060:R6EP030:b8F02]RET0[XYJ0080[XYJ00<0[8QH0:^7
E`2YQED00P2/QUL00`2[QEH0ZXAE0:V3E0020:R2D`030:N1DP2VPU00Yh=A00<0Z8AB00<0YX9@0:F1
C`2SOdd02@2ROTh80:=oC`040:J0D@2WPE80Yh5B0:N1DP80Z89C0P2YPe@80:V5E@060:R2E@2XPU<0
Z89C0:R2D@2WPTh0Yh9=0P2WPT/20:EoCP030:J0C`2WPE00Z89A0080ZH=B00@0ZXAC0:N3D`2WPe<0
Yh=C0P2XQ5@30:V5E@@0[8QH0P2]RET20:j:FP80/H]J0P2bS5/0102cSE`0]8iM0;F?GP2eSeh80;JB
HP80]Y5U0`2gTVH30;RCI`060;FDH@2eTf<0]I=S0;JDIP2fU6L0]iAZ0P2gU6`20;REJ`80^II/0`2j
Ufd00`2kV6h0_YU/0;jIK0030;nJK@<0`9]^1@30WW030;nMK`@0`Imb00@0`9ia0;nML02oWG00_Ya_
0`2nVg470;nLLP040<2ML`31WW@0`Yme0<>PMP80a:5g00H0`J5h0<:RN@33XgX0a:Ak0<JVO@37Ygh2
0<RXO`040<b/P`3=[H@0cJf40<j^Q@80cjn600<0d;270=6aR03A/HP00P3D]8h00`3E]Hl0e[J@0=Ng
T@020=RhTP090=ViT`3K_IL0fkfG0=bnVP3M_id0g/2N0=o0X@3O`:<0h<6T0080gl:R0P3P`j<30>74
Y0040>;5Y@3OaJ@0glFT0=o5Y0@0h<JU00<0hLNV0>76Z03QaZP00P3PaJL40=o4YPP0hlJX1@3TajL;
0>?6YP040>G7Z`3TaZX0i<JZ0>C6ZP80hlFY0P3Ra:P80>?6YPP0hlFY0`3SaZH20>;5Y@<0hLBT1P3R
aJD20>?6YPP0hL:S00@0hL>Q0>32X03P`Z00h<:P0P3O`Il20=k0WP<0gKnK0P3L_YX30=^mV@80g;^H
00@0fkZG0=ZiUP3I^9D0fKRE0P3H]i@01P3H^940ekN@0=NgT03F]Xl0eKF>0=BdS@80dk><00<0d[:;
0=6aRP3A/HX00P3@/8T30<n_R0030<j^Q`3?[880cjb20080cjb2103@[H<80=6^QP<0dK6:0P3@/8T3
0<n_R0@0d:f50P3A[XH80=:_Q`80dJj600<0eK:<0=BaR`3C/8X00P3B[hT00`3D/H/0e[>=0=NdSP02
0=BdS@80dk><103B/X/0103D/HT0dk280=>`R03C/8P20=:_Qa80dJj60P3?[8@20=2]Q@80dJj60P3B
[hL0203@[X00cjf00<f[OP3<ZGl0c:V10<fZQ03?ZhL0d:b8203>Zh420=2]P`<0cjb20`3>Zh420<ZW
O@H0bJIl0P39Y7L01038XgH0aj9e0<JQM035X7<20<BOLP060<FPMP35X7@0aJ1d0<FPL`35XG40aJ5_
0P35XFd80<BRM080`j5c0`34XW@40<FSM@<0a:9b0P33XG430<:PL080a:1`00<0`im_0<:NKP32WVh0
0`32WVh80;jLK0090<:NK031WF/0_YYV0;^HHP2iUV00^9EM0;REF`2iUU`0^9AT0080^IEU00<0^YIV
0;^GI`2lV6P00P2mVFT01P2mV6/0_IUY0;jJJP2nVVP0_i]W0;nLIP80`9eU00P0_YYV0;nKI`2oVfL0
_i]W0;jJIP2lV6@0^iMS0;VEH@P0^9AP0P2gTf420;JBH0@0]I5O0`2dSeX[ooooo`00:_ooool30:Im
B@<0Ygi:0P2XOd/20:IlBP040:MmB`2XOT`0Z7i<0:UoC@80ZX1>202YP4`0102]PE00[81?0:b0C`2/
P4l30:]oCP050:YnC@2YP4X0ZX5;0:^2C02]Q4h00`2^QDl00`2]Q4h0[hIB0:n6DP020:j5D@<0[HA@
00<0[8=?0;68E02`Qe<00P2`Qe<30:n6DP0E0:j5D@2aQeD0/8ID0:n5D`2^Q580[hEC0;26E02bR5H0
/hUG0;^=F`2lSU`0^i1M0;^BGP2lU600^iIQ0;bGHP2kV680^iIY0;bGJP2nVF`0`Ia_0080`Ye`0P33
WW400`32WG00aJ1f0<FPMP030<JQM`<0aj9h00P0aZ5d0<NRM@39Y7L0bZEh0<^VN@3:YGP0bJAg0<RS
MPP0a:Ak00<0aZMk0<FVNP33Y7P00`32XgL20<>TN080_IY`00h0_9U_0;ZGK@2gU6X0]95W0;2=H`2^
Rf40[hYM0:b7FP2VPE@0WgY=09QcAP2CKT40T6/n08mZ?@80RV@e00H0RfDf08eW>02>J3T0SfTj091Z
>`2AJc`309A_>`<0UG0l0P2FLCd309Mb?P80UW4m0`2EL3`:09M]>`80UV`j00`0UF/i09AZ>02DJSP0
TfTg09Y_@P2IKT40V6e009I[?P2DJC`0TVLj091U>02?I3L808eY>@80SfTj00@0SVPi08eW>02<ISL0
S6Hg0P2;ICH01P2:Hc`0Rf@k08eV?@2>Ic`0SVPk08iX>@80SFLf00<0SF8e08iS=P2?I3L00`2@ICP2
08mT=`80S6Hg0`2;ICH308YT=@80RV@g0P2;ICP308aV>@0308eW>P2=IcP0SFLh00L0SFLh00D0SFPd
08iY=@2?JSH0T6/g095/>002091[=`0308mZ=P2;ICH0RfDf00H0RfDf0`2;ICP208aV>@<0SFLj0P2;
ICP00`2<IST0SFLj08iX>`0208mY?004091Z?@2@JS/0T6Xk091Z>`80TF/l0`2BK3d8095]>@P0T6`l
202DL3`209IaA@0309IaA02GLd<0Ug=10080V7A000H0V7Do09Eg@@2EMd40UWQ209Mi@`2HNT@209Uk
A@0309YlAP2GNdT0Ug]90080Ug]9102FNTP01P2EMTL0TW=408i_@02:Jc`0QVLh08=T=@80PV<d01L0
QfPb08MY=@22ISH0Melc06UC;01KBBD0E4@S05939P1;?B<0B3TR04@h8013>280@c/V040i9P0k=280
=C0M02d`7@0[;Q/0:B`K02HX6P0U9aX092HK02DW700202DV7P0=02@U7@0S91`08R<K02<T700T9Ad0
9RLO02LX800V9al09RPM02LY7P0W:A`0:2XL02T/6`0202X]6P0402@W7P0S9Qd08B@K01lR6@807R4H
0P0O8QT201`O60807B0I0P0N8AX301lR6`0K020R7@0P8a`08b@L02LW6`0]:a`0<c0M03Pf8@0m>280
C3hK04m17P1EAB40FdTS05m;9P1QBb@0H4XQ05m87`1EBQd0Cd8O04@h800k;al0=B/O03H_7`0k=Al0
?CTN04@d6`15=A`0AcLN0080B3PO00H0AcLN04De7014=1/0BCTP04Ph7`16=Qd204De700304Hf7@17
=ah0B3PO00<0D3PL02d0DCTM05<k7`1E?B40F40T05U19@1E@R@0CSlR04Di7`0j<Qd0<2dJ02PZ700T
:Qh08RXO02HX7@0T9Q/08R@I024S600R91T09BLL02PZ7`0[;B80=c0N03/c7P16>R00FDTW06eG;P1l
HS40PV@^08=T:`2<KS`0RV`j08e_?@2BM480TgE309AfA02NP4h0ZXaJ0;RFEP2VQe40PfM005U5;00n
<R80=c@U034e900Z<b000P0_<R40100^<280;2hQ02/]8P0Y:R8202PY8`0;02P]9P0Y;RL0;C0W030b
9`0`<RD0<C8T038`8@0a;b00<34S034b900b<bD00P0c=2H00`0a<R@0;c0R02h_8@03038^8P80<BdQ
0`0`;2002`0a;B@0<2`S02l[8P0^:R40;b/R030/8`0b;RD0<blV03@^8P0e;b<0=S0T00<0=c4U0P0f
<2@203@`9@0=03La9@0i<B@0?3<T03lc8`11=2@0@C@S040d9013=RH0ACPW04Tj9`1;>RH0CC/U04lj
9@0204hj8P0604a09P1;?bL0B3`T04Hj9014=b@0A3LV0P15>2P02017=bL0AcPU04Th9P1;>BD0CC/U
050l901B?2@0DcdU0P1=?BH0301<>R@0CSTT04li901C>RH0EC`X05Ll:@1H@bH0Ed8W05I29`1C@RP0
DT0X0510:@80CSlZ0P1??RX00`1A?bT0E40X05I0:00205U19`0905]19P1GABd0F4@[05Q4:`1IA2T0
GDDY0617:@1TBB/0IDX/0080GdPX00l0GdPY05i6:P1LA2X0FD4Y05Lo9`1E?2H0CC`R04/k8@1;>b80
BCXS04Hj9014>BD0@CTT040h9@0k=R<00P0l=B<03@0m=2<0@3@T044d9013<b@0A3@U03``8P0j<B80
>BlS03L_900e;R@0<RhU034^9@0`;BH00P0c;2802@0d;R80=BlQ03La8@0h<b00>C@Q03Xe8@0i<bD0
>38T03La8`0203D_8@0;03La8`0h<R@0>C<U03Hc8P0e<R40=34R03<_8`0a;B80<2`S02l[8P0^:B<0
0P0/;2@0100[:b<0:RXR02TY8@0X:20202LW7`P0;RXQ00<0:BTO02XZ800/;2800`0];B<202`/8P80
<B/O0P0b;200100c;B40=2hR03D_8`0e;b<203D^900603@^8P0d;R00=BlO03Ha7P0h<b00>C@P0P0a
:al2038/800403<]8@0d;R80=BlS03D_8`@0>38T0`0g<B<203H`8P80?3<R01/0?c@R044d8@15=R40
B3PQ04/k901=>b<0BSl]04/n:`1>?RL0D3hV05@o8P1I@280GT4Q06138@1SCBH0I4hW06E?:P1UCR`0
I4d]069;;01PB2`0GdL[05Q68P1JB2@0G4XV05m=:@1RD2`00P1TDRh0=`1UDbl0FT/Z05Q9:01DABH0
DD8U04lo9@1??bH0D40Y0551:P1I@R00G4DS0618901VC2L0JdlX06mB:P1cDb`0Le<Z06iB:`1`E2d0
M5L_07YJ<@1oGS<0QF<f08QV>@2;IST0Q6Xg08M]>P2:KS`0Rfdk08UY>02;JCT0Sfdm09Ib@P2RP440
XX950:B4B`2UQTl0YHMC0:B8F02RQeX0XHII09f9EP2NRUL0X8YH0::;F@2TRUT0YHUI0:J7F02UQUL0
XX]O0:6:H02OR5h0WHIM09^3G@2JPUh00P2JPV007@2EOU@0UgmC09R0DP2MPe80Y8UD0:f@F02dUE`0
^9YN0;ZLH02kWF40_YiQ0<:PH@34XV80ajAR0<ZTH`3;YV80d:MU0=:WH`3AYV80djIR0=VZI03O[fL0
iK=Z0>VgKP3T_7h0hk]m0>:jO@3P^7d0g[Em0080gKAn00d0gKB00=VcJP3J]6/0fkE^0=ffL@3N]g@0
g[Mf0=jfN03M]GL0fkR20=VfP03G]7h0eK9l0080e;5k00<0eK9l0=JcO@3B[WX00P3E/Gd01P3A[GT0
bZIb0<FQK@34X6`0aZ9^0<JTI`80aJ=V00X0`Z1S0<6OHP32X6<0aJ=V0<RVJ@3;ZF`0bj]^0<VYK035
YFP0_imR0P2jVUd00`2nWV40`j=V0<6OHP030<6OHP040<>QI035XfH0ajEX0<RVJ@80b:]Y00`0bJYY
0<bZJP3>[6`0dJi^0=F_L03F/740d:i_0<j/K@3:Z6T0aZAU0<:PH@30WUl20;nMGP050<FSI037YFH0
bZQY0<f[K03>[6d01@3?[Fh0103>[6d0cJ]/0<bZJ`3<ZV/20<^YJP0@0<f[K03>[6d0cje^0=2^K`3B
/740dk5b0=BbL`3E/g@0c[=`0=2eLP3B]WD0c[9c0<b_L`3C]W`0bZec0:nBFP80[99O0P2[TEh02P2Z
T5d0ZHmL0:R>F`2XSU/0ZHiS0:V>H@2ZSf80ZXmP0:Z@G`2[TEh20:^BG080[Y9R00<0[i=S0;2DI02a
UFD00P2bUVH02@2cUfL0]iaW0;RLJP2mXG40ajYn0=>fSP3K_IT0gKnM0=bmWP030=g0WP80g/6O0`3O
`Z080=bnW0<0eknM01d0e[jL0=BlVP3B^YP0ckNE0<feT`3:/i40bK:@0<R`S035ZhH0`ZIo0;jQN@2k
Vg@0^IU`0<6QN`34Y7h0aZR40<Z]R`3=/i00c[JD0<nhV03@^IT0eKbN0=O0X@3La:P0glZ_0>??]P3U
dk/0iMFn0>KF_`020>KJ`P80im_300<0jMg50>[NaP3/h<P00P3]hLT80?7Oa`80l]k500<0lMg40?3L
``3_fl800P3^f/400`3]fL00l=Ni0>oF^0020>oF^080k]Fg0P3]e;H20>[G]`040>[G^@3Ze[/0j]Jm
0>[F_P80j]G00P3[fL<20>cJa0<0kM_500@0k]c60>oNc03_g/`0kmk<0P3^gL/30>gLbP80kM_700H0
k=[40>cJ`P3[f/00jmZn0>[I_@3ZfK/20>[E`0040>WE_@3Xe;/0im>h0>KC]@80iM:b01h0jL^a0>S:
[P3WbJd0i/V[0>C7Y`3SaZ@0h/JQ0>75X03R`J00h/6N0>70W@3O_iT0g[jG0=blT`3K_900f[^?0=^g
Q@3I]H<0ek>10=B`OP3A[G/0cZYh0<bXMP3:YW@0aj=c0<JRLP35XG40`im_0<6MK@30W6`20;jJJP09
0;^GI`2jUVH0^IEU0;RDI02gTf<0]Y9R0;FAH@2dT600/8iP0080[heO00<0[XaN0:f;G@2/RU`00P2[
RE/80:f;G@030;2<G02aSEd0/XiN0080/XiN00<0/8aL0:n;F`2]RET00P2`RU/00`2_REX0[XQI0:f7
F0020:b6E`090:^5EP2ZQU80ZhMC0:b8E02]RED0[8QD0:^7D`2YQE40Z8A@00T0YH1C0`2VPU830:F1
D@80Y81@0P2YPe@20:Z4E@<0ZhEF00<0[8IG0:b8F02/R5P01P2/R5P01P2ZQ5L0ZXAE0:Z4E@2ZQ5<0
ZXEA0:Z5D080ZXE>0P2WPE80102XPU<0ZH=D0:V3E02ZQ5D20:^5EP<0ZXIF0P2[QeL30:b8F0<0[XUL
0P2_RUd30;2;GP060;>=GP2dSUl0]8iO0;F?H02fT640]i5R0P2hTV<80;RDI0P0^YE[0P2gUFD0102g
UFL0^9IY0;REJ`2iUVh20;VFL080^YM]0`2kV6h30;bIK`<0`9]^0P31W6l30<:ML0040<>QL`32X780
`Z1b0<:PLP<0`Ima00T0`9i`0<:OM@33X7H0`j1f0<BQM`33X7H0`Yme0<6NM030WG<00`32WgL30<>P
N080a:5i0100`Ymg0<>PN034XGT0aJ9j0<JSN`37Y7`0b:Em0<VVOP36YWl0ajN00<RXP@39ZH80bj^4
0<b/Q@3=[HH0cZj70P3?[hP0103@/8T0dK6:0=:bR`3B/X/20=>cS0060=BdS@3G]Y<0ekJC0=RgU03I
^9D0f[VF0P3K^YL01`3L^iP0g;jH0=foV@3M_i/0g/2N0=o1W`3P`J800P3Q`ZD0103Qa:@0h/FU0>;5
Y@3RaJD20>?6YP80i<NW203QbJL30>;9Z`80hLRZ0`3PajT80>G7Z`<0i/VY0P3Ub:P;0>C7Y`040>K8
[03Uaj/0iLN[0>G7Z`80i<JZ0P3SaJT80>C7Y`P0i<JZ00@0i<NW0>?6YP3SaZH0hlJV0P3RaJD20>74
Y080h/FU0`3SaZH30>C7Y`P0h/>T00@0h/BR0>73X@3Q`j40hL>Q0P3P`Z020=o1W`040=o1W@3N`9`0
g/2L0=k0W080gKnK0P3L_YX20=flV@030=bkV03K^YL0f[VF0080fKRE00H0f;ND0=ViTP3I^I80f;RA
0=NgT03F]Xl20=FeSP050=BdS@3C/h`0dk><0=:bR`3A/HX00`3@/8T20<n_R080cjb40P3@[HD<0=6^
QP<0d[:;0P3A/HX30=2`R@040=2]Q@3A[XH0dJj60=6^QP80dZn71@3C/8P30=:_Q`80dJj600<0eK:<
0=BaR`3C/8X00P3B[hT00`3D/H/0e[>=0=NdSP030=FeSP80e;B=0`3C/h`30=FbS0<0e;6;0P3C/8X8
0=:_Q`P0dJj60`3@[HD20=6^QP<0dZn700P0dJn10=2^P@3>[7l0cJZ00<fZPP3>ZhD0d:b80=6]R@P0
cZ^10P3@[H<20<n/PP<0cZ^100@0cJZ00<^XOP3;Z7h0bjQn0`3:Ygd20<VVO080bZEh00<0bJAg0<RS
MP37XWD00P36XG@01`35X7<0aj5j0<NRN037XWP0aj9f0<NRM@37Xg<00P37Xg480<FSM@<0a:9d0P35
XgD40<JTMP<0aJ=c0P34XW830<>QL@030<JRLP35XG40a:1`00<0`Yi^0P33Wfl80;jLK0080<:NK031
WF/0_YYV0;^HHP2iUV00^9EM0;REF`2iUU`20;VEI@030;ZFIP2kUfL0_9QX0080_IUY00L0_YYZ0;fH
J`2mVFT0_YYZ0;jJJ02oVfL0`9eW0080`IiV0P30W6P20;nKI`040;jJIP2mVFD0^iMS0;^GH`P0^IEQ
00<0^IEU0;RDI02fTV800`2eTF420;JBHP<0/hiI:oooool002[ooooo0P2UO4P20:ImB@040:MnBP2X
Od/0Z7m;0:QoB`80YWa<00@0Yge=0:QnCP2XOTh0ZGm?0P2ZP5080:QoB`80[H5@0P2/P4l20:]oCP80
ZWi=00@0Z7m90:V0BP2[PT`0[HA>0P2^QDl00`2]Q4h0[8==0:j5D@020:j5D@<0[HA@0P2/Pdl20;68
E080/8MC0P2_QU820:j5D@80/XQF00H0/HME0;26E02aQeD0/hUG0;B:F02fS5X20;j@GP0:0;fBG`2m
U600_YIR0;fHH`2nVF@0_Y]U0;^IK02mVfh0_ie`0<:PL`80`j5d00<0a:9e0<>QM032X7<00`38XgT2
0<VTNP<0bZEk00P0aj9e0<RSMP3:YGP0bjIi0<bWNP3;YWT0bZEh0<VTM`H0ajN00P38Z8400`39ZWh0
ajQl0<FVNP020<BUN@030<FVNP36Yg/0ajQl0080`Z5f00h0`J1e0<2OM02mW740^IQ]0;JEJP2dTfP0
]I1S0;>>H@2^RE`0Z8=F0:5lC`2IM4L0TVe008mZ?@80RV@e00H0RfDf08eW>02>J3T0SfTj091Z>`2A
Jc`309A_>`<0UG0l0P2FLCd309Mb?P80UW4m0`2EL3`309I/>PD0Ufdk0`2FK3X509E[>@80UFXm0P2D
JC`0102CJ3/0TVLj099W>P2AIST808]Y>@0308aV=`2;ICH0RfDf00D0RfDf00/0RV<l08]T>`2=ISd0
SfPm08mY?02?JCX0SFLf08aV=@2>HcH0Sf@g091U>002095V>@0308mT=`2=HSD0S64d0080S6Hg0`2;
ICH308YT=@<0RfDh0`2<IST208eW>PT0SFLh00P0S6Lc08eX=02?JSH0TF`h099]>@2AK3P0T6/g08mZ
=PP0RfDf0`2?ISX208iU>@<0SF@h0P2;ICP00`2<IST0SFLj08iX>`0208mY?004091Z?@2AJc`0TF/l
095[?080TV`m0`2CKCh8095]>@P0TFdm102DL3`409Ea?@80Ug9600<0Ug9509Mc@`2GLd400P2HM400
1P2HMCl0UGM109Eg@@2FN480UgU309QjA080VG]500<0VWa609IjB02FNTP00P2FNTP409MkB@0O09Ef
A`2CM4D0Sg1108Y[?026IcP0Pf@e089S=021HS<0QVLa08IX=022ISH0MUhb06QB:`1KBBD0E4@S0552
9@1;?B<0B3TR04@h8013>280@c/V044j9`0l=B<0=S4N02d`7@0[;Q/0:B`K02HX6P0U9aX092HK02DW
700202DV7P0C02@U7@0S91`08R<K02<T700T9Ad09RLO02PY8@0V9al09RPM02LY7P0X:Qd0:B/M02X]
700Z;AX0:bhK02@W7P0S9Qd08B@K01lR6@0201hQ60807b8I0P0L7aP201dP6@807R4J0`0O8Q/08`0P
8Qd08B@M02@U7@0X:1`0;R`M03@a7P0i=b80?CPR04hn701A@Ad0F4HR05e9901QBb@0HD/R065:801P
BAl0EDXM04a27P12=Qh0>BdM03@Z7P0e;Qh0>SDO03hj7`14=1/0ACDL04Lg7P18>1l0AcLN04Hf7@15
=A`0@c<J04Hf7@15=A`0A3@K0080@c<J00<0A3@K04Hf7@17=ah00`1E?1h0<`1F?Al0FD0R05a39@1O
ARP0HDPZ05e69P1F@b<0BS/N03hc7@0a;Q/0:2XL028Z7`0P:R409RPM02@V6`0R91T08B<H028T6@0U
9a`0:2XO02/]8P0i<Ah0?S<O04Xl8@1MBRT0LEX`07mU<P25J300QFL[08ma?`2:K3X0Rfdk095c@@2C
MD<0TWA209eoC@2/SU`0]9EE0:63C@1lHSd0E48Z03lc9@0i=bX0<cLX02/d8@0_<R40;S4P02d_8@0/
;R40:R`Q02TZ8P0202PY8`0:02DZ8`0V:b@0:bhU02h`9@0_<B@0<34S038`8@0a;b00<C8T038c9@80
<c@V00D0<S<U034b900_<280;RlQ038^8P03034]8@80<2`P0P0_:al02@0b;RD0<BdT030/8`0_:b80
<2`S034]900c;bH0=30W03H`900203D_8`0503@^8P0e;b<0=S0T03Pb9P0i<bL00P0g<bP03@0j=2P0
>c<V03dd9@0o<b<0@C@T044d8`12=RH0ACPX04Hi:01:>bP0BcXV04`j901<=b800P1;=al03P19?B<0
B3`T04Hj8P15>B<0A3LT04Dh9`16>BT0AcXZ04Ti:@19>RL0BSTW04`j9P1<>R@0CSXR0P1@>R803P1=
?2P0C3/W04`j9P1=>2D0CcPV058h9`1D>RT0ES/Z05E08`1E@2D0E40U05919`1B@2P0DD4Z0P1@@B`0
401<>bL0CSdY05=1:`1G@b/0FD<[05Y2:01I@BL0F3hS05M5;@1IAB`0F4@[05Y5:P1MABT0H4LY06A9
:`1UBR`20619:@0?0619:P1PB2`0GTH/05]3:`1H@2P0ESdW050o9@1>?R@0CCdT04Xk9016>R@0A3TU
040h8`10>2D0?3LT0080?CHT00<0?C@S03lc8`10<b<00P11<B804`0l<280>C0Q03T_8`0g;b@0=BhT
038^9@0`;B@0<2dV030Y7`0a:R00<R`P03<]7`0e;al0=c8O03Pc800h<al0>C<U03Pb900g<B<00P0e
;b400`0g<B<0>38T03Tc9@0203Ld8`0603Hc900d<2@0<blT034]900`;2<0<2/U0P0/;2@0100[:b<0
:RXR02TY8@0X:20202LW7`P0;RXQ00P0:b/Q02`/8P0^;R@0;blU030`9P0_;bD0;RhT02d]8`@0<R`P
100c;B401@0c;280=2dS03H`900h<R@0>C<S0080>C@Q00T0>C@P02l[800`;240<BdR038^8`0c;b@0
=30U03Da9P0f<RL0100h<R@303La8`80=S0R0100?C@S03`c8P0n<b40@3<P04@e8018>240Bc/T04dk
8`18?2`0BC`[04`k9`1A?BD0EShR05i18`1RA280ITDR0P1UCbH02P1VD2T0ITl]06A=;@1RBRh0GdL]
05i6;01KBBD0GD/W061>:P1RD2`206AB;P80He4]05H0ETLV05A5901@@B80CChQ04`l8P1>?RD0D40Y
0592:`1MAB40H4PT06A:9@1ZCRL0KU4Y079B:`1cDbX0M5<Z071B;01aDbd0MUH_07UI<01mG340PElb
08IQ=@27HSD0OfXe08=/>027KCX0Qf/i08QX=`2:J3P0TV`m09Ma@P2NOch0X8510:63A`2RQDd0XXID
0:66E`2QQU/0WXEL09^7E02LR5D0WXQF0:29E`2RR5L0XHEE0:62D`2PPE80Y8aP0::9H02NQE`0Vh9J
09UoFP2HOU/0UgeL09QnG@2EOU@0UWiB09InD02JP4l0WhA?0:N:DP2^SeH0/YAH0;bNHP2mWf<0`:1S
0<FSI038YVH0c:UW0=6[JP3B[FT0fZmZ0=b_J`3O/f`0iKI^0>ZjLP3__G@0mL5f0?K2M`3_bH/0k<J8
0>[2Q`3V_X<0iK^10>>hP@80iKR100`0h;Ud0>6jM`3S_7/0i;an0>BlP@3S^X80h[V30>6hQ03N^XH0
gKV50=^gP`3I]H420=RdP0030=VeP@3J]X80ekEh0080fKMj00H0e;9e0<f[KP39YfX0bJMZ0<^YK03:
ZF820<RWH0060<FTG@33XU/0`j9K0<FTG@39Z640bjYS0P37ZFd01P34YVX0_Z1T0;RJGP2iVel0_j5U
0<FWJ`80`IiT01<0`9eS0<6NI032WfD0aJ9X0<NTJP39YV`0c:m]0<^^K03;[6/0c:YZ0<f[J`3@[Fd0
e:i_0=F_L03A[g00cje^0<^YJP37YFH0aJ=T00<0`j5R00D0ajEV0<VWJ03;ZFX0cZa]0=2^K`020=6_
L0070=2^K`3A[g00d:i_0<n]KP3>[6d0cJ]/0<bZJ`020<^YJP060<j/K@3?[Fh0d:i_0=6_L03C/G80
e;9c0P3E/g@03P3B]g@0dKIc0=>gMP3</740b:]_0=FhOP3@/gT0/YEM0:fCH02/TUl0Zi5N0:Z@G@2Y
Se`0Z8iK0P2WSEX01P2YSV<0ZHiQ0:Z?HP2ZSf00Zi5P0:^AGP80[9=M0100[91P0:fAH@2^TV80/9AT
0;6EI@2cUfL0]9QX0;FIJ@2gW6L0^9aZ0;fQL@38Zgl0eKR@0=foV`3P`Z00gl2Q0`3O`Z020>33X@<0
hLBR1`3N_j005`3M_Yl0ekjO0=RoX03H_j00ekjO0=FlW@3B^IX0ckJG0<jeUP3:/i<0bK:@0<R`SP36
[8T0`jN20;jPNP2kVg@0^9Qa0<2PNP33Xgd0aZR40<Z]R`3</Xl0c[JD0080ckRH00H0e;^M0=JoX03K
`jL0glZ_0>??]P3Udk/20>KF_`070>KJa03WflD0j=c60>SLaP3YgLL0jmo90>cPbP020>gQb`P0l^38
0P3cglH00`3bg/D0lMg40?3L``020>oK`P030>kJ`@3ae[P0lMJh00<0l=Fg0`3_e;H20>_H^0040>_H
^P3[ek`0jmNn0>_G_`80jmK100@0j]S20>_I``3[fL<0jmW30P3/f/@20>gKa@<0k]o<0P3]g//30>cM
bP80k=_900<0jm[60>_Ka03[fl800P3Zf/001P3Zfkh0jmW50>_Ia@3Zf<80j]S00>WH_P80j=Nk00L0
imJh0>[@^@3Zd;L0jLnf0>S>/`3Wc[00i/f^0080iLf[01P0ilR[0>K7Z03VajP0iLNU0>C6XP3Ra9h0
h/FM0>74W03R_iL0hKjF0=nlU03M^Y80f[N?0=ReS@3F/h/0eK::0=B`P03C[gl0dZin0=2/O03>ZWX0
c:Qh0<ZVMP39YGD20<BPL0060<>OK`31WFd0_i][0;jJJP2mVFT0_9QX0P2hUVP00`2gUFL0]YAV0;FC
I@020;BBI0030;>AH`2bT6<0/Y1S00H0/Y1S00P0/hmO0;B@H02eTF40]Y9R0;FAH@2dT600/XiN0;2<
G080/heN00<0/XaM0;6;G02`RU/00P2_REX00`2^R5T0[XYF0:n;E`030;2<F0030:j:EP2]RED0ZhMC
00T0ZXEI0P2/R5P20:^7E`040:Z6EP2YQED0ZHEE0:V5E@80ZhEF0P2/QUL30:f7F0030:j8F@2^RUX0
[XYJ00H0[XYJ00H0ZhEH0:^5EP2[QEH0ZhED0:^6DP2/Qe820:b7D080Z89C00<0ZH=D0:Z4E@2[QEH0
0P2/QUL0102]QeP0[HUI0:f9F@2]RET20:j:FP<0[h]K00@0[hYN0;2;G`2`Rel0/8]O0P2aS6020;:=
H@060;F?H02fT640]Y1Q0;NAHP2hTV<0^I=T0P2jU6D80;ZFIPD0_IQ^0`2lUfd20;VGJ@030;VGJP2j
Ufd0^YM_0080^iQb00<0^iMc0;^HKP2lVFl00P2lVFl20;fJL080_Y]a0P31W6l20<:ML0<0`iia00@0
a9mb0<FSM@34XW@0a:9d0P33XG<01P32X780`Ima0<6OL@33X7H0a:5g0<FRN080aZ=i00<0a:5g0<:O
M@31WW@00P35XW`20<JSO@040<NTOP38YGl0b:Eo0<RUO`80bJJ000l0bjR20<bYP`3>ZhD0cjb60=2]
Q`3A[XP0cZj80<n_R@3@/8X0dK6;0=>cS@3D]8h0eKF?0=JfT03D]8h00P3E]Hl0103F]Y00ekNA0=Ng
T@3H^9820=ViT`060=VhU@3J^IH0f[VF0=^jU`3L^iP0gKbI0P3N_IX20=foV@060=k0W03O`Il0h<:P
0>72X`3Q`ZD0h/>V0P3SaZH20>C7Y`<0iLRX00<0i/VY0>;;Z@3RbjT00`3RbjT30>7:Z080hlb]0P3R
bj`30>7:Z`030>39ZP3Vb:`0i/R/00H0i/R/00<0j<^[0>O:ZP3WbZX00P3VbJT20>G8Z0030>C7Y`3U
b:P0iLRX00H0iLRX0`3Vb:`20>G7Z`<0i<JZ203TajL80>C6ZP80i<NW0`3SaZH50>;5Y@80hlJV00@0
i<NW0>G8Z03Ub:P0iLRX203Sa:D30>;4XP80hL>Q0`3P`Z00103P`Yh0gl6M0=o1W@3O`Id20=k0W080
gKnK0P3N_IX00`3M_9T0g;^H0=^jU`020=ZiUP060=VhU@3J^Y<0f[ZC0=ViTP3H^940ekN@0P3F]Xl0
1P3E]Hh0e;B=0=BdS@3C/h`0d[:;0=6aRP80d;290P3?[hP00`3?[8H0d:f70=2]Q`020=6^R080dZn9
00<0dk2:0=6^QP3A[XH01P3A[XH20=>cS080d[:;0`3A/HX00`3@/8T0dJj60=6^QP020=:_Q`<0dk28
0`3D/HT20=>`R080dZn70P3A[XH00`3E/X`0e;6;0=>`RP020=:_R@030=BaR`3F/hd0ekB>00<0e[J?
0P3E]Hh30=BdS@80ek>?0P3F/Xh30=FaS@030=B`S03C/8P0dk2800H0dk282P3@[HD20=6^QP@0dZn7
00P0d[220=6_PP3?[H00cZ^10<j[P`3?[8H0dJf90=:^RP/0cjb20P3>Zh430<fZP0<0c:Uo00<0bjQn
0<ZWO@3:Ygd00P39YW`20<^VN@030<ZUN039Y7L0b:=f0080aj9e00H0aZ5d0<RRN`38XW/0b:=i0<RS
M`38XgH20<RTM0030<RTLP36Y7H0aZAf00H0aZAf0`35XgD20<JTMP@0ajEg0P36Y7@20<FSL`<0a:9b
00@0`j5a0<NSL`36XW80a:1`0P32WVh00`33Wfl0a:1`0<FQL@080;nMK@080<:NK031WF/0_YYV0;^H
HP2iUV00^9EM0;REF`2iUU`20;VEI@040;ZFIP2kUfL0_9QX0;fIJ@80_YYZ00H0_9MZ0;fIJ@2nVVX0
_i]Y0<2LJ031WVP20<:OI`040<6MJ@30W6P0_i]W0;jJIP80_IUU0P2lV6@80;VEH@080;ZFIP2hU6@0
]Y9R0;FAH@2dT600]I5Q0;JBHP2gTf<30;JAG2_ooooo000Zooooo`80YGa80P2VODT0102WOTX0Z7m;
0:QoB`2YP4`20:IlC0040:MmC@2XOTh0Z7i>0:UoC`80ZX1@202XOd/30:f1D0030:b0C`2[Odh0ZWi=
0080ZWi=00P0Ygi80:V0BP2[PT`0[XE?0:n6D02^QDl0[HA>0:b3C@<0[XEA0P2]Q5030:b3C`<0/HQD
00<0/8MC0:n6DP2^QE400P2^QE400`2dRUP0/hUG0;:8EP020;:8EP030;B:F02fS5X0]heK0080_i5O
00X0_Y=P0;nFHP2oUf<0_iYU0<2KIP2oW6H0_9Y]0;jLK`31Wg80a:9e0`35XgH20<BRM@80bJ=l0P3:
Y7d30<^UOP090<bVO`37XWD0b:=f0<ZUN03;YWT0c:Mj0<^VN@3:YGP0bJAg0080aZV11037ZX820<R[
P`030<R[P@36ZGl0a:Mm0080`jIl00<0a:Mm0<JYO`37ZX000P37YW/03P36YGX0aJAi0<:QMP2oWW<0
^iY_0;VHK@2hTfH0]i9U0;B?HP2^RE`0YX5D09agBP2DKd80SfXm0P2:I3D01P2;ICH0SFLh08iX>@2?
JCX0T6Xk095[?0<0U6lk0`2EL3`209Ia?@<0Ug8n0P2FLCd309E`?0@0UV`j102GKC/609E[>@80UV`j
0P2@ICP0102AIST0TVLj09=X>`2CJ3/209AY?0P0RfTi0P29Hc@308YT=@<0RfDf0100RV<l08]T>`2=
ISd0SfPm091Z?@2?JCX0SFLf08aV=@2?I3L0T6Dh095V>@2BIcX0TFHi08mT=`2<HC@0Rf0c0P2<ISL3
08]U=P<0RV@e0`2;ICP208aV>@<0SFLj2@2=IcP00`2<Ic<0SFPd091[=`03099]>@03091[=`2?JSH0
RfDf00L0RfDf0P2@Ic/0102?ISX0SVDi08iU>@2=I3P208aS=`80RfDh00<0S6Hi08eW>P2>J3/00P2?
JC`0102@JSd0TF/l095[?02AJc`2099/?@<0Tfdn202AKCT8099^?P80U70l102ELCd209Ib?P80Ug96
00<0Ug9509Mc@`2HM4800P2HM4001P2HMCl0UGM109Eg@@2FN480UgU309QjA080VG]500H0VWa609Ah
AP2ENDL0UGU709IjB02GNdT209QlBP0709UmB`2FMdP0TgA508m`@@2:Jc`0QVLh08=T=@02085R<`0G
08EV<025Ic<0PFDe07IN<P1XDR/0FTPT05=38P1A@RD0BcdS04Pi8P14>200A3TS04<k9P11>RL0?3DS
03Ha7P0]<1d0:bhK02T/6`0V:1X09BLJ02@V6`0U9a`00P0U9Qh03@0T9Ad08b@L02<T700S91`09BHN
02HW7`0X:B409RLO02HX7@0W:Ah0:2XM02T[7@0Z;A`00P0[;Q/0100T9ah08bHM024T6`0O8QT201hQ
60807b8I0P0L7aP201dP6@807R4J0`0O8Q/06P0Q8ah08B@M02@U7@0X:1`0;R`M03@a7P0i=b80?STS
04lo6`1B@Qh0F4HP05e:8P1RC2<0HT/R065:801QB1l0Dd/M04a27P11=ah0=RdL038Z7@0d;Qh0>SDO
03`k7`14=1/0ACDL0`17=ah01P16=Qd0A3@K04<c6P15=A`0A3@K04<c6P80@S8I00<0@c<J04De7016
=Qd00`1J?b80>`1K@2<0GT<V0697:P1VBbh0J4d`06599`1IAB@0CC`P03le700a;Q/0:2XL028Z7`0P
:R409RPM02@V6`0R91T08B<H028T6@0U9a`0:2XO02/]8P0i<Ah0?c@N04`n8`1OCBT0Le`b085U<`27
J340QfL/091b@029JcT0RV`j095c@@2BM480TG=109anC02]Sed0/i=F09n1C@1hH3X0Dd4Y03lf9`0k
>Bd0<cXZ02Td8`0_<R40;S4P02d_8@0/;R40:R`Q02TZ8P0X:B<09bPR028W800T:B80:B`S02d_900^
<2<0<34S0080<S0Q00P0<C8T038c9@0c=2H0<c@V038c9@0a<R@0;c0R02d^80@0<BdQ0P0`;20202l[
7`0;03<_9P0b;RD0<BdT030/8`0a;B@0<RhU03@`9`0e<BP0=c4U03H`900d;R800P0c;B400`0f<2@0
>C<W03/e:@0203Te:P0=03/e:@0l=2L0?SDV040d9011=2@0@C@S04@h:016>BT0AcXY04/l:@1;>RH0
BcTS04/f8@0204Te7@0>04Pl8P17>b<0ACTQ04@h8P15>2D0ASTX04Pk:`19?2`0BSXZ04Xk:01;>RP0
C3XV04/i8`1=>B4204hh8080C3/W03@0BcTU04dh9@1>=bD0DSPW05@j:@1F>bX0DchQ05<n8`1C?b@0
DD0V0590:01B@R/0DD8]0593;P1:>BD0CSdY05A2;01JARh0G4H^05a4:P1H@2H0ES`Q05M5;@1IAB`0
F4@[05Y5:P1MABT0HDPZ06A9:`1VBbd0H4TY065::P1QBR/0HDT]05m7;@1LA2`0FD4Y05Hm9`1B@BL0
D40V04hn9@1;?2D0Ac/U04@i9@10>2<0?cLT03dh9@0n=bD0?CHT03dd8`0o<b<0?c8R0P10<240200k
;b40>C0Q03P^8P0f;R<0=2dS034]900`;B@0;b`U0P0_:1h02@0a:al0<R`N03@^7P0e<1d0=c8O03Lb
7P0i<bD0>38T03La8`0203D_8@0303La8`0h<R@0>C<U0080>3DT00H0=c@U03Da9@0d<2D0<RhU034]
900a;2H202`/900402/[8`0Z:R80:BTQ02PX80809bLO200^:R400`0/;280;BdS02l_9@03034a9`04
02l_9@0^;R@0<bdQ03<]8@H0<R`P00P0<BXP03</8P0g<BD0>S@V03`f9P0k=R<0>SDR03Td8080<RhS
00@0<blT03Da9P0f<RL0>3@Y0P0i=BX403Pb90<0=c4S0P0f<2806`0m=2<0?3<R03hc8@0o<Ql0@c@O
04Lg801;>b@0CS`T04@k:P17>RT0BS/V050l901G?B80Gd8T06I5901ZB2D0IU4V06I@9`1WDBX0IU0[
06A=;@1QBBd0GdL]05e5;@1PCRX0HDl[06=A;@0206AB;P0C06=A;@1QCb/0GddY05=48`1A@R40CChO
04/l7`1;>b40CCdT0551:P1C@b`0GdLS06=99P1VC2L0K50Y06mB:P1bDRT0Le8Y07=B9`0207=E;`0T
07MG<01iF2l0O5T_081K;`21G300Ped`07iY=021K3L0QV`i08IZ>027IcH0RfLg099/?@2IL480VW/h
09]n?02NP480XHA<0:65D`2QQUL0WhMK09n6G@2JQU<0VhMD09f7E@2OR5H0X8IE09n3D`2NOe00WGi?
0:F=H@2RRF00WHAK09V0F02ENeH0TgUF0P2BN5L0;02EOU@0UGeA09EmC`2HOTd0W85<0:B7C`2[S5<0
[Y1D0;nQI@30XVH0`j=V0<RVI`3<ZVX0dJi/0=J`K`3H/fl0h;=_0>:fK`3Y^W@0kl1h0?C4NP3ib7`0
oLUm0?k:OP3fci@0llbA0>o7S03[`hP0j;j40>VlP`3Y^X@0j[^50>FnO@3V_X00j<230>RoQ`3X_hT0
i[b:0>BjRP3S^8/0hKf90=nkQ`3M^HD0fkN30P3J]X800`3K]h<0g;R40=bkN0020=flN@060=RgM03B
/Fh0cJaY0<j]JP3@[f`0cZmO0P3<[Ed02P39ZUX0aZMG0<JWE`38ZET0bZ]K0<b]G@35Yf/0aZQ/0<>U
J@2mWf<20;RJGP040<2RIP37ZFd0`IiT0<6NI080`9eS00L0`YmU0<FRJ038YF/0bZM]0<f`KP3<[fd0
bja[0080c:YZ00P0cZ][0=:/K@3D[Vl0d:i_0<j/K@3;ZFX0b:IW0<JTI@<0aJ=T00D0b:IW0<VWJ03<
ZV/0cje^0=6_L0020=:`L@090=6_L03B/740dJm`0=2^K`3?[Fh0cZa]0<f[K03<ZV/0bjUZ0080cje^
02h0d:i_0=6_L03C/G80e;9c0=FcM03F]7D0e;Uf0=>hM@3D^7L0bjm`0<FXK03E^7h0dkIl0;BGG`2]
Tf00[99O0:^AGP2ZT5d0ZHmL0:R>F`2WSEX0YXaI0:V>H`2YSV40ZXmR0:Z?H02[TF00[99O0:bCG@2]
U5h0ZhmO0:b@H02]TF40/9AT0;:FIP2dV6P0]YYZ0;NKJ`2gW6L0^9aZ0;jRLP39[800e[VA0=k0W03Q
`j40h<6R0P3P`j420>74XP80h/FS0P3SaZ@00`3P`J80gl2Q0=o0X@020=o0X@<0g[nP0`3H_j004`3G
_Yl0e[fN0=>jV`3@]iP0c[FF0<ZcT`39/Y80bK6?0<J/R@34Z8<0_j5k0;^KM@2hV740`:1j0<>SO@36
Z8@0bZf;0<bbS`3>]Y@00P3?^9P02P3D^id0e[nP0=_3Y`3ObZl0hlnf0>GC^`3Ve[l0imO00>GJa03V
flD20>OLaP050>SMa`3ZglT0jn3:0>cQb`3]h/`0203chLT01P3dh<L0lmo60??OaP3bg/D0lMg40?3L
``80km_20`3ae[P20?3E]`<0kmBf0P3[f;P0103[f;X0jmNl0>_G_P3[ekl20>_F`@<0j]S20P3[fL<3
0>cJa080k]k>0P3]gLd30>cLc0050>_Kb`3/flT0jm[80>_JaP3[fl@00P3[fl802P3[fl40j][00>gL
bP3]g<X0kMc80>cLa@3[fl80jm_10>[J`03Zfkh20>gD_P040>cD_03/e;X0jm>g0>[C]080jM:b0200
jlfa0>_>/03ZcJl0jLb/0>S;Z@3WbjH0il^T0>K:X`3YaJ<0j<BR0>O3X@3U`Il0h[jL0>2lVP3O^iT0
g[ZH0=fiR@3L^8P0fkN70=VeQ@3G/h<0eK610=>_O`3B[Wh0c:Qh0<^WM`3:YWH0b:Ad0<JRLP35XG40
a:1`0<>OK`80_ie_00@0_Ya^0;fKK@2lVV`0^iU[0P2jV6X80;FCIP80]I5Q0`2gTf<0102eTF40/hmO
0;:>GP2eSf020;B>G`030;>=GP2bS5d0/H]L0080/8YK0P2`SEL30;:?F@030;2=E`2^ReD0[HYD00T0
[hYN0P2aSEd0102`S5`0[h]K0:n;F`2^RUX20:f9F@040:b6E`2]QeP0[HMH0:f7F080[XQI0P2_REX8
0:n;F`060:b6F@2/QUL0[8IG0:b6E@2/Qe<0[HQC0P2]R5420:V3EP070:Z4E`2[QEP0[8II0:b6F@2]
QeX0[XQK0:j:FP030:n;F`80/8aL0P2aSEd0102`Rel0/HaP0;6<H02aS6020;:=H@80/hiR00H0]Y1S
0;NAI02gTF@0^99U0;VCIP2jU6L20;^EJ0P0_9QX0P2oVG840;jHL@80_IM`00H0^YQZ0;ZHJ`2jV6/0
^iQ^0;^HL02lVG<20;bHM080_9U_0P2mVW030;jKL@040;nLLP32WG00`Ye`0<:ML080`iia0`34Wg80
1036Y7H0aJ=e0<FSM@34XW@20<>QL`80`Z1b00<0a:5i0<FRNP36Xg/00P37Y7`00`35XWX0`j1h0<6N
MP020<NTOP040<RUO`39YX00bJJ00<ZWP@80bjR20P3?[8H0103A[XP0dZn90=BaR`3F/hd20=NdSP80
eKF?00@0e[J@0=RhTP3I^I<0fk^E0P3L_9H0103I^I<0f[ZD0=ZjU03K^iD20=blUP030=fmU`3N_YP0
g[jH0080fkZI00@0g;^J0=flV`3M_9/0g[fL0P3O_Yd20=foV@040=k0W03O`Il0h<:P0>72X`80h/>V
0P3TajL20>G8Z0<0i/VY00<0ilZZ0>?<ZP3Sc:X00P3Sc:X40>;;Z@80i<b`0P3Sbjl30>;:[P030>79
[@3WbJl0ilV_00H0ilV_00@0jLb/0>S;Z`3Xbj/0ilZZ0P3VbJT:0>G8Z0040>O9[@3Vb:`0i/R/0>K8
[080iLN[0P3TaZX80>C7Y`P0i<JZ0`3TajL20>?6YP@0h/FU0P3SaZH00`3TajL0iLRX0>G8Z0020>K9
Z@P0i<FV00@0hlFS0>;4XP3Ra:80h/BR0P3Q`j420>32X0<0h<:N0P3O`Id30=k0W080g[fJ00@0gKbI
0=bkV03K^YL0fkZG0P3J^IH01P3K^i@0f[ZC0=ZjT`3I^I80f;RA0=NgT080e[J?0P3E]Hh00`3D]8d0
dk><0=6aRP020=2`R@80cjn80`3@[HL00`3A[XP0dZn90=>`RP020=>`RPP0dJj60`3C/h`20=:bR`<0
dK6:00@0dJj60=:_Q`3B[hL0dZn70P3C/8P20=BaR@040=FbRP3D/HT0e;690=>`R080dZn70P3A[XH0
0`3E/X`0e;6;0=>`RP020=:_R@030=BaR`3F/hd0ekB>0080ekN@0P3F]Xl30=FeSP030=BdS@3H]900
ek>?0080ek>?0P3F/Xh20=FaS@P0e;692P3@[HD20=6^QP<0dZn700T0dk280=:`PP3A[h80cjf00<j[
P@3>Zh<0cjb60=6]R@3B[XX0203?[8830<j[P@80cJZ00`3<ZGl20<fZP080c:Uo00D0bjQn0<ZWO@3:
Ygd0bJIl0<bWNP020<^VN@030<ZUN039Y7L0b:=f0080aj9e00H0b:9m0<RRN`38XW/0b:=i0<RSM`38
XgH20<RTM0P0aZAf0`35XgD20<JTMP@0ajEg0`36Y7@20<FSL`<0a:9b00<0b:Ad0<JRLP34X7000P32
WVh00`33Wfl0a:1`0<FQL@080;nMK@090<:NK031WF/0_YYV0;^HHP2iUV00^9EM0;REF`2iUU`0^IEU
0080^YIV00<0^iMW0;bHJ02mVFT00P2nVVX0302lUfX0_IUY0;jJJP2oVfT0`9aX0<6NJ032WfL0`j1X
0<6MJ@30W6P0_i]W0;jJIP80_IUU0P2lV6@80;VEH@080;ZEJ02iU6L0]Y5T0;F@H`2dSf80]I1S0;NB
I@2hTfH30;VDGb_ooooo000Zooooo`060:EjA`2VNdP0YW]80:MlB@2XODX0ZGi;0P2ZOd`01@2XOd/0
Ygi:0:MnBP2VODT0YGa80080Y7]700@0XgY60:MnBP2WOTX0Ygi:0P2XOd/30:V0C0P0Zh9>202]Q503
0:b3C`80[HA@0`2^QE420;26E00B0;67E@2bR5H0/HME0:n5D`2]Pe40[89@0;26E02aQeD0/hUG0;F;
F@2gSE/0^HmM0;^AG`2lTV00]i=Q0;VEH`2lV6H0_i]Y1031WF/01032XF`0`Z5^0<>QL@35XgH20<NT
NP030<RUO`3:YX80bZJ400<0cJZ20P3>Zh<30<n/Q0<0c:b300<0bj^20<ZZP@39ZH000P39ZH080<b/
Q@80cZj7103=[HH20<b/Q@0H0<ZZP`39ZH80b:R10<JVO`34Y7d0`Z9k0<6QNP30X7T0^iEX0;VCIP2f
T6<0]8iQ0;6;GP2ZQ5L0WWQ;09E_@P2DKDH0T6U008eV?@2>Ic`0TV`o09A^?`2CKC`0TF/j0P2BKCH0
0`2CKST0U6lk09E_?P0209Ma@P0309QbA@2FLCd0UW4m00H0UW4m0P2IKcd0102HKS`0Ufdk09I/>P2E
JcT209AZ>0P0Tfhj102AIcD2091V=080SfDc202BIcX04P2<ISL0RfDf08YT=@2:I3D0RfDf08aV=`2>
J3T0T6Xk08iZ;02>JRh0SFPa08aW<`2<IST0Rf@m08YR?`2:HD40RfDf08aV=`<0SVPi00<0S6Hg08YT
=@29Hc@00`2:I3D308]U=P80S6Hg0`2>J3T308eW>080S6Hg102>J3T308eW>080S6Hg00@0SFLh08iX
>@2>J3T0SVPi0`2?JCX02@2@JS/0TF`e095/=@2@JcH0SfXf08eW=P2;ICH0RF<d08QR=@0208YT=@80
RfDf0P2<ISL208eW>003099]>@2AK3P0SfXf0080SVTe00<0SfXf095/>02BKCT00P2>JSX208m[>`<0
T6`l00<0TFdm09=_?`2CKcl01P2CKcl309A_@`0309=^@P2BKD40TFa00080TFa00P2AKCd00`2BKSh0
Tflo09A`@00209Ib@P0309Mc@`2IMD40VGE100<0VGE10`2HM4001P2FM4@0UgE509MeA@2IMdL0VWQ8
09]iB@80W7Y:1P2JO4H209]mA`0[09Ih@P2CMCl0SW0j08U[=@24IS00PF<]07mQ:`1nH2X0S6`_08YZ
<@23IBl0NUl`06mF;P1TCB/0FTLY05I2:@19?b@0AS`Q04<i7P14>Ql0AC/P04@j7`0n=1T0>BlD03<]
7@0_;1/0;BXK02TW6P0V9QX092HK02@W700T9ah0:2XL02LY6`0V:1X09BLI02HX6P0W:A/0:B/M02X/
7P0Z;aP0:c0I02`a6P0302hc700502db6`0/<AX08RDL024T6`0O8QT00`0M81L0100N8AP07b8I01`O
600L7aP201dP6@807R4J0`0O8Q/0600K8Ad07B8L024T6`0V9aT0;R/H03Da600l=AT0@CPK050n:P1D
@bT0Fd/W061B9@1QDbH0Ge0W05Y::01GARX0CD8R04@h7P0h;1`0<BLN030W800b;1h0<BlJ034`50P0
?C8N0P0o=282040e8`17044f9012=bD0@SLU04<h9P1;>B40BSTO04di801A?240FD4U0699:`1YD340
Ke@f07E<;P1dDRd0Je8Y05M9700l>A009R/=01/V5@0J9ad092LP02<V7`0R8a/08b<I02HT600[9a/0
;b`M03@^8017<BH0Ac8O05@m7@1YDB<0N5lY07mQ;@26I3@0SF/n08a^>02;KCL0T78l09QjA02FN480
TgDo0::4CP2gVF<0/8]G09IgB@1WEC40?SPN038d7P0l?RT0?C`W03Da600a<bP0;c4V02`]9@0X:B<0
9BHQ02@T8P0S8b4092@T02LX8`0X:B@0:BXT02//900];b@0;c4T030b9@0a<bD0;RlQ02l`8P0a<R@0
0`0c=2H02`0a<R@0<34S03Hb9P0e<BD0=30T038^8P0a;B40;b/O02hZ7P0]:Ad09bTK0080:2XL00<0
:B/M02X/7P0[;Al00P0/;R0203/e9`0403Xd9P0i<bD0>C<U03Pb9080=c4S100j<2@403/a9@03044c
9P13=BP0ACPX0080ASTX00X0ACPU04<g8@12=R00@SHP04Df8`16=b@0AcHT04Tf9@1:=bH0CCPW0P1?
>2P204Hg800604Ph8@1:>280BcTS04hi901?>B@0D3XU1@1=>b<304`j8PP0D40V00P0DclW05<o9P1D
@2L0ET8W05M49P1HABD0FDHU05Y79P80H4LY0P1QB2X0101RBB/0HdX/06=:;01TBbd206=8:P0>0658
:P1OAb/0G4L/05Y6;@1IAB`0ET@/04i2:01=@BT0Bd4X04Lo:014?RP0@C`X040k:00m>RL2044h9`04
03lf9@0n=B@0?3<R03/b8@80>C0O0P0h<RH0100g<BD0=S0T03H`900e;b<203@^8P0502l[8P0`;2<0
<2`S034]900b;RD00P0c;bH0100d<2L0=BlS03D_8`0e;b<203H`90<0=c4U0P0c<bT0100b<RP0<C4W
030`9P0`<2H202l_9@0802d]8`0/;280:b/Q02XZ800Y:Al0:2PN02LW7@0V9Q`202/[8`80:RXR0P0Y
:B4202PX8006030Y8`0`:B40<2TQ034Z800a:al0<R`N0P0b;1`2038/8080<bdQ0`0d;R802P0e;b<0
<BdT038^9@0c;bH0=30W03<_9P0a;B@0;b/R02dY800b:bD203</900303@]8`0e;b<0=S0R0080=c4Q
0P0g<2H01`0g;RD0=RhS03L]8@0j;R00?S4Q04<c9015=BD00P1=>2<00`1;>B<0BSXS04Xk900204Pl
900:04Lm9013?BD0AChT04Y09@1?@B@0EDDT05Y68`1OBB@0HDTS05i=;`80HE0b01d0GD`^05I59`1C
@R@0ETDW05Y9:`1OBB80HD/V069>:@1TD2d0He0_05i>;@1IBR/0EdPY0514;01?@2T0C3`S04`h7`1@
>1h0EC/P05i0901SA2L0LE4P075A8P1`DB<0KU4W06iB:`1/DRl0KE<b06aC=00207UH;@0N07UJ;P1h
Fbl0NEha07UQ<`1lI3H0O6Hg07QS>01iHSP0NV<g07eU=`22IcP0Qf/k08e_?@2?LCl0UWE:09QgC02J
Ndd0Vgm@09f3DP2LQE40W8E?09^6C`2MR5d0VhAH09IoD`2DO4h0UGY;09QlC02MOdd0X89@0P2RQe80
0`2RQU@0XXIF0::6E`020:64F00R0:64FP2QQU/0XHII0:64F02TQEL0YXIG0:Z8F02]S5T0/8aJ0;ZF
G02oVf40aj=Y0<^XKP3>Zg40e;5g0=biO`3R_hL0kkn10?32Q03daXX0n<b?0?[@U03kdiP0o=>K0?_D
V`3]fj/0k=ZX0>cHYP3[eJ<0j=6M0>O>V03Tbi<0i<VB0>C:S`80i<ZA01H0hlRA0>35T03M`Hl0fKf=
0=NkR`3A`I00dKn?0=6mR`3A^XP0e;R60=JhQ03J^HH0fkZ50=2gO`3D^H80eK^20=FhOP3A/gL0cjmb
0=>aM03F]7D0cK5X0P3</6L02@3;[fH0b:aS0<JZH@34Z5l0`ZIM0<6UG038Xed0aZ5K0<:ME`020;nJ
E0060<2KE@32WEL0a9mI0<>QH@32X600`9iN0P2oWEd01`30WUh0`Z1P0<>QH@35Xf@0ajEV0<VWJ03:
Z6T00P3;ZFX0403:Z6T0bJMX0<bZJP3<ZVX0c:Y[0<^YK03:Yfd0b:E]0<NTK037Y6h0c:Ua0<j[L`3A
[WH0dk1h0=FbNP3F/g/20=FbNP80e;9b00L0dk5a0=:`L03A[fl0cje]0<j/K03=Zf/0ck1`0080cZm_
01P0ck1`0=2aL@3C]7@0eKIf0=NhN03E^7`0f;]o0=JiO@3C]WX0eKQl0=NjOP3?/WH0`ZEY0:V?GP2]
Tf80/9IU0:jDH`2YSeh0YXaK0:R>G@2/TV40YXaI0:R>F`2ZT5d20:^AGP0C0:Z@G@2XSU/0YheJ0:b@
H02]TF40[i=S0;6EI@2cUfL0]YYZ0;NKJ`2hW6`0`:9^0<2RL033YgL0c;640=JmU03MaIl0g/RS0=g6
Y0020>77Y080h/RU0`3SbJH00`3TbZL0glJW0>37Z0020>37Z00J0=o6Y`3L`j@0f/6R0=RoX03HaJ@0
elBS0=G2X@3C`9l0dKjM0<nlV`3=^YT0c;VH0<ZeUP39]9D0bK:@0<J^RP32ZH40_jAi0;VNL@2gVf`0
_imf0<6QNP34Ygl0aj^40<V_RP3;/hl20<^dTP0:0=FlWP3F_j00f/:V0=g8[@3QcK@0i=:j0>OG`03Y
fL80iM[80>KKb@80imc:00D0jMk<0>_PcP3]h]00k^?A0>oTdP030?3QcP80lN;?0`3bhm020?GPb`03
0?GQb@3dh<L0m>350080ln3200<0ln300?3K_P3`fkh01P3`fkh80>gH^@P0k][10P3[g<L20>cMb004
0>gNb@3^glX0k]o:0>oPb`80jMg=0`3Zg/h30>_Oc`80kmk>00@0k]g=0>gLc03]g<`0k=_;0P3[f/X2
0>cH`080jmNo0`3Ze[h01@3YeKd0jM>k0>SB^P3Xd[X0im6i0080i]2h0P3UckL0603UcJ/0i<bZ0>?;
Z@3RbZP0h<RV0=k6Y03MaJ<0g<BR0>;0V`3Q_iX0h;jI0=jlU`3L^YD0f[RC0=RfT@3G]I00ejn<0=N_
R`3E[HT0djb50=6ZP@3?Z7d0cJMj0<bVN@80c:9h00@0bj5g0<ZPMP39WgD0bIme0P38WW@20<>MK00>
0<:LJ`30VVT0_iUX0;jHI`2mUfH0_9IU0;jHJ@2mUfP0_9IW0;^EIP2iTf@0^99S0;NAHP2fT6470;NC
H@040;JBH02eTEl0]I5O0;FAG`80]91N0`2cSed20;2=H`<0[haR102^Rf420:n=H080/8iP00@0/8iN
0;2?G02aT5/0/I1K0P2bSU`30;6=F`<0/8aJ0P2cTF420;:@H0040;6?G`2`SUh0/8iN0:n=G@<0[XaN
0P2]Red30:b:G0@0[HaI0P2/ReP20:^:E`<0/HaO0P2bSF030;>>H@<0]99R0P2eTf<30;JDI0040;VG
I`2hUVH0^9IV0;RFIP<0]iEU00<0]YAT0;^IJ@2kVFT00P2lVVX30;fKJ`030;jLK02kW6d0^ia]0080
^ia]0P2lWFh20;fNK`80`:1g0P2oWgH0102nWWD0_Ied0;fMM02lW7<40<2MM@@0_iad1@34WW430<>M
L080aj5d0P38XWD01039XgH0bZAg0<^UN03;YGP20<VSO0030<ZTO@3;YGh0c:Io0080cJN000L0cZR1
0<ZXP`3:Z8<0bjV40<f[QP3?[HP0d:j90080d[2;00P0e;6;0=>`RP3B/8/0dK6;0=2bSP3B]980dkJF
0=FhV080e;bH00@0eKfI0=JnVP3H`9`0fL6M0P3J`Yh90=k0WP<0h;nN0P3Q`9l30>;1X0<0hLBR0P3R
aJ<30>?6Y0P0i<Z_403Tc;00103Wck<0i/jb0>K>/P3Vc[820>G=/@80i<b`0`3Ubk020>C:[`<0hlV^
203SbZ`80>78ZPP0hlZ/0`3Sbjl00`3RbZh0hLV]0>38[0020>38[080hl^_0P3RbZh30>79[@030>38
[03Sbjl0hl^_00H0hl^_00@0hlZ/0>;9Z`3RbJ/0h/V[0P3Qb:X20>37Z@P0h/FU0P3Pa9d20=o3W005
0=k2V`3M`IX0g<2I0=c0V@3O_Y/00`3N_IX20=flV@80g;^H00T0fKRE0=ZiUP3J^IH0fkZG0=ZiUP3H
]i@0e[FB0=BcT03E]9400`3D/i030=>bS`80d[6>0P3B/X/20=>cS0<0e;B=00<0eKF>0=:bR`3B/X/0
1P3B/X/80=>cS080d[:;0P3C/h`40=BdS@P0eKF>0P3A/HP00`3B/XT0dk>:0=BdR`020=FeS0040=Jf
S@3E]Hh0eKF>0=FeSP<0e[J?0P3G]i00103E]Hh0e;B=0=BdS@3D]8d20=>cS080d[:;103D]8/20=>c
RP80d[:9203B[hL80=2`R@<0dK6800<0d;270<n_QP3>[XD00P3>[XD80=:_R@<0d:f50P3?[8@30<j[
P`80cJ]k0P3<ZWX0103;ZGT0bZQh0<ZXN039YgL40<VUM@@0bZIf0P3;ZG/01P3:Z7X0b:Ih0<NUM`36
Y7H0aJ=e0<BRM0P0b:Ek2@36Y7H80<FTL@080<FQL@36XW80aj=c0<NSL`36XW80a:1`0<:NKP30W6`4
0;nKI`80_YYV0P2mVFD20;nKI`040;jJIP2mVFD0_IUU0;bHI080^iMS102iUF40102kUf<0_IUU0<2L
J032WVX30<2LJ0<0`IeY0P32WVX02030W6P0`IeY0<>OJ`33Wf/0`YiZ0;nKI`2lV6@0^IEQ202kV684
0;ZGH@80^IIP0P2hUEl30;RCGR_ooooo000Zooooo`<0Yga90`2XODX20:UnB`80Ygi:0`2VODT30:El
B0<0Ygi:0P2XOd/30:V0C0P0Zh9>202]Q5030:b3C`80[HA@0`2^QE405P2_QE<0/8ID0;67E@2bR5H0
/HME0:n5D`2]Pe40[89@0;26E02aQeD0/hUG0;F;F@2hSU`0^Y1N0;bBH02mTf40^IES0;^GI@2nVVP0
`Ie[0<>OK@34X6h20<>OK@80a:=`00L0aJ=c0<NUN038YG/0b:Ek0<ZWP@3;Yh<0c:R400<0cJZ20P3>
Zh<30<n/Q0030<f]Q03<[8<0c:b30080bj^20P3:ZX400`39ZH00c:b50<b/Q@060<b/Q@@0cZj7103=
[HH0603<[8D0bj^40<ZZP`38Z840aZIo0<FUOP34Y7d0`j=l0<:KL02oV6d0_II[0;^DJ@2hTFH0/8UN
0:EnD`2LMDX0UFi7095Z@@2=ISd0SVLl099/?`2EKd00U6hm099/>`80TVdf00H0Tfhi09A_>`2EKch0
UW1109Ma@P2HLTD809Ia?@80VFlm00@0V6hl09M]>`2FK3X0UF/i0P2DJSP809=^>P04099X=P2AIcD0
TFLe095W=@80T6Hd0P2?IC<8099W>P0C08aV=`2;ICH0RV@e08YT=@2;ICH0S6Hg08iX>@2?JCX0SVX/
08iZ;P2=J340SFPd08aV>@2;I3/0Rf<o08]S@02;ICH0S6Hg08eW>00208iX>@0308aV=`2:I3D0RF<d
00<0RV@e0P2;ICH308aV=`L0SFLh00<0SVPi08mY>P2>J3T00P2>J3T308eW>080S6Hg102?JCX408iX
>@08095/=@2@Jc@0SVTd08eX=02<ISD0S6Hg08]U=P2;ICP408aV=`80SFLh0P2>J3T00`2BKCT0TF`h
08mZ=P0208iY=@0308mZ=P2AK3P0TVdi0080Sf/k0P2@K3`2095]?@80TVhn202CKcl309A_@`0309=^
@P2BKD40TVe10080TFa00P2AKCd01P2BKSh0Tflo09A`@02ELD40UW9209Mc@`H0VGE10P2HM4001P2F
M4@0UgE509QfAP2IMdL0VWQ809]iB@80W7Y:0`2JO4H509UkA@0c09Ih@P2CMCl0SW0j08U[=@24IS00
PF<]081R;01oHB/0S6`_08YZ<@23IBl0NEh_06mF;P1TCB/0FDHX05E1:018?R<0AC/P04<i7P14>Ql0
AS`Q04Dk8010=Q/0>c4F03<]7@0_;1/0;BXK02TW6P0V9QX09BLL02@W700U:1l0:2XL02LY6`0V:1X0
9BLI02HX6P0W:A/0:B/M02X/7P0Z;aP0:c0I02db6`0^<a`0;c@M02hc700]<Q/0;34J028U700Q91/0
7b8I00807B0G00<07R4H01lR6@0P8aX00P0L7aP201dP6@807R4J0`0O8Q/0600L8a`07R<L028U6P0X
:A/0<2dJ03Pb6P0n=a/0@cXM05<n:@1G@bP0GT`V06=B9P1TDbD0HE0U05]89`1HA2T0CD8R04@h7P0h
;1`0<BLN030W800b;1h0<BlJ034`50P0?C8N0`0n<b400`0o=280@3DS040e8`02044f900P04Tg7`18
=Qh0BcLN04hi7P1E?B40G4DV06A;;@1XCc00M4d^07EC<01_ERd0GDhS04<n600/;a808BXI01dX800T
9b008bHO028S6`0S8aT09R@H02/W6`0_;1d0=2hP04La9P18<ah0ESlM06YB901iH2X0Of4[08IT=02>
K3h208e_>@0C099d?P2HNT@0UWQ209Ih@P2SQDl0]iUS0:j9E@2DMDL0IE<_03dg7@0b=1l0>cdX03dl
9`0f<QT0<C<X02la9P0[;2@0:2TS02DV8@0202@T8P0I02@T900W:2<0:2TT02TZ900[;2@0;BlT02la
900`<RD0<C<U02h_8@0_<280<C8T038c9@0c=2H0<S<U034b900`<B<0=S8V03Da9@0d<2@0<RhR034]
8@0_:al0;RXN02dY7@0202TZ700302X[7@0[;1h0;2dO0080;BhP00@0;RlQ03Xd9P0i<bD0>C<U0P0h
<R@203La8`0303H`8P0j<2@0>S0T0080>S0T100k<BD01`10<RD0@S@W04@g9`15>2L0ASTX04Dh9@14
>2800P13=b4204Hg900404Pg9@1:=bH0BcPW04hi:080D3TY0P16=b001018>240BSPR04/i8`1>>B@2
050j9@P0CC/S201@@2H0201C?bL0DclV05A09`1F@RL0Ed@V05Q59@1IARD0FTLV0P1PAbT0101QB2X0
HTT[0699:`1SBR`206A;;@0H06E:;01TBB/0HTT[05m7:`1KAR/0FDD/05M3:P1E@b/0D48X04e1:@1<
@2P0BChX04Dm:012>bP0@3/X03lj9`11>2L0@3LV03lf9@0n=B@0?3<R03/b8@0j<B00>C0O0P0h<RH0
100g<BD0=S0T03H`900e;b<203@^8P@0<BdT100b;RD303D_8`<0=S0T0P0g<BD203<c:@03038b:00a
<BL0<30V0080;blU00L0;RhT02`/8P0/;280:b/Q02XZ800Y:Al0:2PN00809bLM0P0[:b<202XZ8P80
:BTQ0P0X:200200]:280;RTS02hZ8@0^:Ql0;b/O02l/7@0`;Ah0<2dL0P0b;20203<]8@@0=2hR00T0
<BdT038^9@0c;bH0=30W03<_9P0a;B@0;b/R02hZ8@0b:bD00P0c;2@00`0d;B<0=BlS03H`8P0203La
8@80=c0V00L0>2lV03L_900h;R80?30R03lb8P14=2D0ASHV0080C3LR00<0BSPR04Xj8`1:>b@00P19
?BD02P18?RD0@cdU04Dn901;?bD0D48U05E5901KAb@0GdTT06598`1KBR`205e<;P0S05Q7:@1B@B<0
D3lQ05=2901FABL0GdTT065;9P1QCBX0HTl^05m?;P1KC2/0F4TZ05A79`1>@RX0CSlX04`l8`1=>Ah0
DSXN05Tn8@1QA2H0ITLX07EE901cE2D0Le@V075D:P1`E2d0KU@a06iF=01^ECH0MeH]07MG;P1hF2l0
MeX`07QM<P1fGS800P1fGc<03@1eGSD0MUle07QP=01lHC@0PFDf08MX>@2;KC/0Sfll09EdB@2GMTT0
VGY<09YnCP2KPE000P2JPdl02@2HPdh0V85E09IoD`2DO4h0U7U:09EiB@2INdT0WGm=0:20C@020::7
DP030::6E02RQUH0XHEF0080XHAH0240XHAJ0:66F`2QQUT0XHAH0:B5E`2WQeP0ZXQH0:f<F@2aSE/0
]iAJ0;fJH034XFT0bZM_0<b[M@3A/7X0f;V20=o0R@3/aHh0klRA0??<U@3ed9/0mmBN0?WEX@3jeZ80
n=NR0>kK/@3]fZl0k=N/0>[CY`3Xd:80i/^L0>C:V@3SaiL00P3TbY405`3TbI80hlRC0>34TP3L`8h0
fKf=0=NkR`3A_hl0d[j<0=6kRP3@^HL0dkN50=FgP`3G^880fKR30<jcO03A]Wl0eKR00=:eN`3?/GD0
cJe`0=6_LP3D/W<0cK1^0080c:m]01T0bji/0<V/JP38ZfT0aZUW0<FXIP34YfD0bZEO0<NRG033WUP0
`9]E0;jID`2oVU@0`IaF0<>NF02nW5`0_I]K0;bJFP2kVET0_9YJ0;jLG030WUh0`ImO0<NUIP38YVL0
bZQY00<0c:Y[00L0bjUZ0<ZXJ@3>[6`0cZa/0<f[K03=Zfh0c:U_0080bjQ`00L0bZMa0<j[L`3?[7@0
dZmg0=FbNP3F/g/0ekAl0080e[=k00T0e[Ad0=FcL`3D/W80dk5a0=6_K`3@[Vh0cje]0<j/K03A/G@0
0P3@/7<0603A/G@0d[9e0=FeN03H^7/0f[Ym0=NjOP3J_H40f;]o0=BgN`3F^Gd0f;]o0=6dN035Z6`0
ZHmN0:fCHP2_UF@0[YAS0:V?GP2WSE`0ZHmN0:fCHP2WSEX0ZHmL0:Z@G@80[99O01@0Zi5N0:Z@G@2Y
Se`0[I5Q0:jBHP2_Tf<0/IEU0;BHJ02fVVX0^9a/0;VMK@30XW00`J=a0<BXN@3=/XL0e[fE0=g5W`3N
ajD0gLJT0>77YP<0h/RW0P3SbJP20>C:Z@80glRX0P3PbJT06P3NajL0g<FU0=W2XP3H`J40f<FT0=O4
X`3E`Z40dl2O0=6nW@3?_9/0cKZI0<biV03:]IH0bKBE0<VbT037[h/0`jZ20;nTN@2jWg80^9a]0;nO
MP31XGX0`jIn0<N[Q039[hX0b[:>0P3;]9802P3D^id0e[nP0=W1Y@3Laj`0h<bc0>?A^@3Ve[l0j=S1
0>GJb03VflT20>OLbP050>WNc03[h<h0kN;@0>kSd@3_i=800P3`hLh30?7Rc`<0l^?@00H0mN3=0?GP
b`3eh</0m>380?CPa`3cgl@20??P`PP0l=_0203^fKX80>kJ`@80j]_60P3[g<L0103/gLP0kMk90>gN
b@3]g/T30>[Mc@80jmk>0`3/gll20>oNcP80k]g=00@0kMc<0>cKb`3/fl/0k=_;0`3]f<<20>cG`P<0
jmK10`3Ze;`00`3Ydk/0j=:j0>SB^P020>OA^@080>[C/@3Yd[00j=6_0>K?[@3UcZ`0hlbZ0>;;Z@3Q
bZP20>O6X`0>0>G4X@3S`Yl0hL2M0=nnV`3N_IX0gKbI0=fgT`3L]Y80fkF@0=VcS03G/XP0eK240=>^
PP3C[X420=:[PP030=6ZP@3@ZH00cjQo0080cZMn00L0cJIm0<ZTM@39Xg@0b:9c0<NQLP36X740a9i_
00<0`ie^00D0`Ya]0<6KK030VV/0_iUZ0;fGJ0020;bFI`D0^iMU0`2jUV@40;VEH`80^9AR0P2gTf43
0;FBJ0<0]95W0`2cT6H01P2aSV@0/HmR0;:@H`2bT680/Y1P0;:AGP80/Y5L102cSed20;:>G080/HeK
0P2dTV820;>AH@80/Y1P0P2aSel20;6?H@80/8iP0`2_SEl00`2^S5h0[hiK0:n>F`030:j=FP<0[HaI
0`2bSF020;>>H@<0]8mR0`2eTf<20;JDI0<0]iEU0`2hUVH50;VGI`80_9YZ0P2mVf/30;jLK0040;nM
K@2lWFl0_9e_0;bMK`80_Ii`0`2nWg420<6QN080`:1g00@0_imf0;jNM@2nWWD0_Yie1`33X7P00`32
WgL0b:5f0<RQMP030<RQMP<0aj1e0P38XGH20<VRM`040<ZSN03;Y7T0c:Ej0<bUNP80bJJ000<0bZN1
0<^XPP3<ZH<00P3=ZX@04P3>ZhD0cJ^60<f[QP3?[HP0d:j90=:`R`3C/H`0e;:=0=FcSP3G]8h0e[>=
0=BbS@3C/Xl0dkFC0=BgU`3F^IT0eKZL0=JnW080eknM00<0fL6O0=[2X03K`j400P3La:890=k1X@<0
hL2Q0P3R`J830>?2X`040>74Y03RaJD0h/FU0>;5Y@80hlJV0P3TajL80>C:[a00iLfa0P3Wck<20>K>
/P<0iLfa00@0i<b`0>G;/03Ubk00iL^`0P3TbZl30>?9[PP0hlZ/203RbJ/80>?:[0030>C</03Sbjl0
hl^_0080h/Z^0P3QbJd0103Pb:`0hl^_0>?;[`3Sbjl20>;:[P<0hLV]203Sbjl20>?:[080h/V[0`3Q
b:X00`3PajT0h/FU0>;5Y@060>;5Y@060>75WP3Pa9d0h<BM0=o3W03N`Y/0gL6J0P3L`9T20=nnV`80
g[fJ0`3M_9T00`3L^iP0fKRE0=ZiUP020=^jU`040=ZiUP3H]i@0e[FB0=BcT080eKBA0P3D/i040=>b
S`030=:aSP3B/X/0dk><0080dk><0P3D]8d20=FeSPP0d[:;203C/h`20=:bR`80dk><0`3D]8d90=Fe
SP@0dk><0`3D]8d40=FeSP80e[J?0`3G]i020=FeSP80e;B=0`3C/h`00`3B/X/0eKF<0=BdR`020=Bd
R`80dk>:0P3B/XT80=:_Q`P0d;2900<0d[:90=6aR03A/HP00P3@/8L20<n_QP030<j^Q@3B[hT0dZn9
00H0dZn90`3@[HD30<n/Q080cZ^30`3=Zg/00`3<ZWX0bjUi0<^YN@020<ZXN0H0b:If0P39YgL20<ZX
NP040<VWN@38YWP0b:Ih0<NUM`80aZAf2038YG/90<JTMPP0aJAa00T0aJ5a0<JRLP37Xg<0aj=c0<JR
LP34X700`Yi^0<2LK030W6P00`2oVfL20;jJIP80_IUU0P2oVfL0102nVVH0_IUU0;fII@2lV6@20;^G
H`@0^IEQ00@0^iMS0;fII@30W6P0`YiZ0`30W6P30<6MJ@80`YiZ00P0`IeY0<:NJP32WVX0`YiZ0<2L
J02oVfL0_IUU0;bHI0T0^iQR0`2jUf420;VFH080^9EO0`2hTeh[ooooo`00:_ooool20:UnB`<0Z7e:
0`2WO4T20:ElB0<0YWe91P2WOTX20:QoB`<0ZH1<202[PTh;0:b3C`80[HA@0`2^QE405@2_QE<0/8ID
0;67E@2bR5H0/HME0;26E02^Q580[H=A0;26E02aQeD0/hUG0;J<FP2iSed0_99P0;jDHP2oUF<0_IUY
0;nKJ`32WVh0a:1`0<JRLP030<NSL`040<NUM@38YWH0bJMi0<ZXN`80bjQn00<0c:V10<fZQ03>ZhD0
0`3>Zh<20<n/Q0<0d:f50P3=[H@20<b/P`@0bj^2203=[HH:0<j^Q`0N0<f]QP3<[8D0bZZ30<VYPP38
Z840ajN00<VTNP36XGL0a9me0<:ML`30Vg40^9=Y0:f8GP2TOeD0V75:09=/@`2?J3l0SfPm099/?`2E
Kd00U6hm099/>`2BKCH0Tfhg09=^>@2DKc/0UFln09I`@@2GLD80Ug54202GLSh209U_?@0409Q^?02G
KC/0UV`j09E[>@80U6Xh202CKSX3099X=P80TFLe0`2@IS@8099W>P0308eW>02<ISL0RfDf0080RV@e
00`0S6Hg08iX>@2?JCX0SVX`08eY;`2=J3<0SFLf08aV>@2<IC`0S6Dn08]S?`2<ISL208eW>00308iX
>@2=IcP0S6Hg00@0RV@e0P2;ICH308aV=`0508eW>02;ICH0RfDf08aV=`2=IcP00P2>J3T508mY>P80
SVPi102=IcP01@2AJc`0T6Xk091Z>`2?JCX0SVPi0080SFLh00X0S6Hg091[=02>JC80S6Lb08]V<P2;
IC@0S6Hg08iX>@2@JSd0SFLh0`2>J3T208mY>P80T6Xk00<0TVdi095/>02@JcL00P2?JSH00`2@JcL0
TF`h099]>@03095]?@80TVhn2`2CKcl309A_@P80Tfi10`2BKD001P2AKCd0TVhn099^?P2CKcl0U710
09Ea@@80UW92202IMD4209MeA@0309QfAP2IMdL0VWQ80080VgU900D0W7Y:09YlAP2INdD0VG]509Qj
A00209Mi@`80UWQ200H0UGM109=e?`2>L3X0RF/e08EW<@22I2h2081R;00S08a/;`2:JS40PfD_07UN
;`1^EBd0Hd`Z05Q59`1D@2L0AS`Q04<i7P12>1d0A3XO04Lm8P16?240@SPM03hd6@0c;Ad0<2dL02dZ
6`0Z:1/09RHJ02DW700T9a`09BPO02PZ700W:A/09RPJ02DW6@0V:1X09bTK02T[7@0Z;1h0:blH02da
6P0_<a`00P0a=Ah02`0`=1d0;c<L02hb6`0R9A`08B@K01lR6@0N8AP07B0G01hQ600O8QT082<J0080
71lH0P0M81T201hQ6P<07b8K00/07b@N028U7P0V:1d0;2XK03D`700m=Q`0A3/N04Pm7`1E@BH0FDHU
061?900206EE900;065@9@1KB2L0ET8W04a18@13=ad0>2`L030V7@0`9b00<R`N038`6`0a<1@0200m
<Qh203`a7`<0?C8P0`0n<b408015=Ah0A3@M04Hd7019=A`0CSTN05Hn8P1KA2D0GdHX06m:;@1dDc00
LU/b06=D:`1:AAl0<SDJ02D[7@0P:R8092LP028U7P0R8a/08R8H02HT600[9a/0<2dN03D_8@18<RD0
BSDP05Y38@1^ERH0Nf8Z081R;027IS<0T6i00P2@LS`04`2DMT00V7Y409QjA02INdD0YXQB0;JHHP2Z
Q5<0SVm3065>;@0l=Qh0<S@O03Tj:00k>RH0=S4K030b9`0^<2D0:b`T02LX8P0U9R400P0T92803@0T
92@09RLR02LX8`0X:B<0:R/S02`^8`0^<2<0;c4T030b900^;b40;c0R030a8`0a<R@00P0b<bD02`0a
<R@0<34S03Da9@0d<2@0<blS038^8P0a;B40<2`P02l[7`0^:Qh0:BXL0080:R/M00<0:b`N02`]7`0]
;R000P0^;b40100h<R@0=c4S03La8`0g<B<303H`8P0303D_8@0i;b<0>BlS0080>S0T0P0k<BD203`b
9P0603la9010<RD0@SDU04@g9P16>BP0ASTV0`16>R@01P17>2D0B3TV04Th9P1;>2L0C3TX04lj:@80
DCXZ00H0ASLP04Lh8@18>240BSPR04/i8`1>>B@2050j9@P0CC/S201A@2H0201C?bL0DclV05A09`1F
@RL0Ed@V05Q59@1IARD0FTLV0P1PAbT00`1QB2X0HTT[06=:;00206A;;@0I06E<;P1WC2h0IT/]06=:
;01PB2`0FdH[05M3:P1E@BP0DT0X0512:01?@2T0C40X04Tn:015?BP0@S/X044j:00o>RL0@CPW040g
9P0o=RD0?SDT03`c8P0k<R40>S4P03T`7`0203Pb9P0403La9@0f<2@0=S0T03D_8`80=2hR100b;RD4
034]9080=2hR0P0e;b<303H`900603La9@0b<RP0<S8X034a9`0`<2H0;blU0P0^;R@01P0];B<0;2`R
02/[8@0[:b40:RXP02TY7`80:2PN00<09bLM02/[8`0[:b<00P0Z:R8202TY8@80:2PP0P0]:2@0100]
:280;RXQ02hZ7`0_:al202l/7@<0<R`P0P0c;B4303@^8P80<BdT0`0b;RD0100a;B@0;b/R02l[8P0b
:bD203</900303@]8`0e;b<0=S0R0080=c4Q0P0h<BL0C00i<2L0>C4V03/a9@0n<R@0@C@T04De9P16
=RH0BSDP04/f8@1:>280BSXS04Xk9019?BD0BShV04Y09`14?2D0AcdT04/o9@1A@RD0Ed@T05e6901Q
BBD0HdTT05U8:P1JBB/0F4LY05A39@1@?b40CSdO05508P1D@bD0G4PS05i:9`1NC2P0GDd[05a<:`1H
BBX0E4HY05949`1=?RT0CCdV04`j8P1@>b00ESdO05m28P1WBBL0KD`Y07UK:@1iFR/0Me//07EJ;`1c
FS80LETe06mH=P1^EcL0LU8[07AD;@1dEbl0METa07=J<@1aFS00KEP]06]F:`1_Ec40L5L_079I<01g
G2l0OF4b08AV=02:JSL0S6dg09EeAP2FMTL0UgQ909QlC02HOTd209IoC@0909AnC02CO500Tg]=099j
C02DNDX0UWY:09]mB`2OOd`0XH5>0080XHIA00<0XHEC0:65E@2QQEH00P2QQ5P08P2QQ5X0XHIK0:66
F@2RQET0YHIH0:R8F@2[RET0[XeJ0;:>G02fTe/0^i]R0<>RK038ZG<0bjei0<ncP@3E^hP0fl6@0>K;
WP3XcJ00jm2S0>oDY`3bejX0m=V/0?GJ[@3ffjh0k]Zi0>cH]@3[e;80jM6]0>K<Y`3UbJ80hlNO0>?6
WP3TbY420>C9TP0F0>;7TP3O`i40fkn?0=RlS@3F^X/0dK^:0=6iR@3?^8H0d;J30=6fP@3C]Gl0eKJ0
0=FfO`3:[gP0ck5k0=6dO03@/GP0c:aa0<bZK@3?Zfl0dZi`0<f]M0@0c:ac0P3;Zg820<ZZL@040<^X
I038YF40`j1L0;nLF080_9UE00<0_Y]G0;nLF02hUUH00`2hUUH01`2jV5P0_I]K0<2NGP32X600bJMX
0<ZXJ@3<ZV/00P3>[6d00`3=Zf`0c:Y[0<^YJP020<f[J`0:0<f[K03<ZVd0cJY`0<fZLP3>Zg<0cZ]e
0=2]M@3B[gL0e;5i0=NdO0<0f;Em00L0ekAl0=RfM`3G]GH0e[Ae0=BbL`3C/G80d[1a0080dJm`00/0
e;Ag0=>cMP3C/gH0e;Ag0=JfN@3I^G`0g;ao0=jnP@3I_880gL260=boQ@020=NjP00?0=ZmP`3D]gd0
bJab0:^AH02]Tf80[YAS0:fCHP2ZT5l0ZHmN0:^AH02^U6<0ZHmL0:Z@G@2[TEh0[99O0080[I=P0P2/
TUl0402^TV80[i=S0;2DI02bUVH0]IUY0;NKJ`2iWFd0^Yi^0<6SL@32Xg@0a:Qi0<fbQ`3G_YH0g/JR
0=o8YP3NajL20>79Y`80h/ZX0`3SbjT00`3Tc:X0h<VZ0>7:Z`020>7:Z`0J0=o8Z@3MaZL0f/>T0=W2
X`3HaJD0elBT0=G2XP3C`:00dKjN0<nlW03=^YX0c;VI0<ZeUP39]9D0bK:@0<N_R`33ZX80`:Ej0;^P
L`2iWFh0_Yie0<2PN@33YWh0aZZ30<R^R@3:/Xh20<ZcT@0:0=>jW03D_Ih0f<2T0=_6Z`3Obk80h]2h
0>GE_P3Wel00i=W70>GJb080i]_900H0j=g;0>[Oc@3/hLl0kN;@0>kSd@3^hM030>oRd@80l>?B0P3a
i=<20?CRcP030?CRc03chLT0ln;80080l^7500<0l^730?3L``3`g<<01P3`g<<80>oL_PP0km_200@0
j][30>_Ka03[fl@0jm_40`3/g<D00`3]gLH0jMc;0>[Mc0020>[Mc080jmk=0P3/glh0103_g/h0k]g=
0>kMc@3^gLd30>gLc0030>cKb`3^g<H0k]c60080kM_50`3/f/@00`3[fL<0k=S00>cH`0030>_G_`<0
j]Jn0P3_f;T05P3^ekP0kMJg0>_D]@3Zdk@0jM:c0>SA/P3]cjd0k<j/0>[<ZP3YbjT0ilVW0>G7Y@3T
aZ@0hlFS0>C0X03S_id0h[jL0>2lV03N^iD0g;VA0=^hSP3J]hd20=^eSP030=ZdS@3I/h`0f;:;0080
ek6:00l0e[290=:]P03A[7l0d:]n0<nZO@3=Z7/0c:Mj0<^VN@3:YGP0bJAg0<RSMP37XWD0aZ5d0<BO
LP33WW400P32WG030<2LK080_i][0`2nVVX0102oVf/0_YYZ0;jJJP2nVVX20;fIJ@80_9QX0P2kV6h4
0;ZGK@<0^II/00H0]I9Z0;FBJ02eTVP0]I=V0;FCI@2eTf<20;FDH@<0]Y9R0P2eTF430;B@H0<0]YAV
0P2eTfD30;BBI080]I=U0`2dTV@30;>AH`80/Y1P0P2aSel20;2>GP80[heM0`2dSf820;F@H`<0]Y5T
00@0]YAV0;NEI`2gUFL0]iEW0P2hUVP20;VGJ@050;RFJ02iUfT0^IMY0;ZHJP2kVF/00P2lVV`0102m
Vfd0_Ya^0;jLKP2nW6h20;nMK`<0`9i`0`2nWg<20;nPM0<0`:5e1032XWT20<6QN080`:1g2036Xg/8
0<^VO080bJAj00<0bZEk0<^VO03<Ygd00P3=Z7h01`3>ZGl0cJZ40<fZQ03>ZhD0cjb60=2]Q`3A[XP0
0P3B[hT20=:aSP0?0=>bS`3D/i00e[FB0=NfT`3H]i@0fKRE0=^iU03J^9<0f;ND0=JhUP3F^IL0e[bK
0=RmW`3H_j00f/:P0080fl>Q00<0g<BR0=g5X`3NaZ@00P3OajD90>33X`<0hL:S0P3R`j@30>?4Y@<0
hlJV0P3TajL30>G8Z0P0iL^`403Vc[80103Xd;@0ilnc0>O?/`3Wck<20>K>/P80iLfa0`3Vc;420>G;
/0<0i<Z_203SbZ`80>;9Z`P0i<^]0P3Tc;020>?;[`@0h/Z^0P3Tc;020>?;[`<0h/Z^00<0hLV]0>C<
/03Tc;001P3Tc;00103Tbjd0hlZ/0>?:[03SbZ`20>;9Z`80hLRZ203SaZH01P3RaZ40hLFP0>75X03P
a9l0gl>N0=k2W@80gL6L00@0h;nL0=nnV`3O_Y/0gkjK0P3N_IX20=flV@090=ZiUP3K^YL0fkZG0=bk
V03K^YL0fKRE0=NfT`3E]940e[FB00<0eKBA0`3D/i020=>bS`80dk><0P3D]8d30=FeSP030=JfS`3C
/h`0dk><00H0dk><203D]8d30=>cS080e;B=3`3E]Hh30=BdS@030=>cS03E]Hh0eKF>0080e[J?0`3G
]i000`3H^940e[J?0=FeSP020=FeSP80e;B=0P3C/h`30=FeS080e;B;0`3C/hX80=>`R0P0dK6:0P3B
/XT20=6aR0@0d;27203B[hT20=6^QP80d:f50`3?[8@00`3>Zh<0cJ]m0<f[O@020<f[O@80c:Yl0P3;
ZG/=0<VWN@<0b:Ih2038YG/90<NUM`P0aZAd00P0aZ9b0<NSL`37Xg<0aj=c0<JRLP34X700`Yi^0<6M
K@<0`9aX0P2oVfL30;jJIP80_i]W00@0_YYV0;fII@2mVFD0_9QT0P2kUf<20;ZFHP80^IEQ00@0^iMS
0;fII@2oVfL0`IeY0`30W6P30<6MJ@80`YiZ00@0a:1/0<>OJ`31WFT0_i]W0P2nVVH20;nKI`P0_9US
0`2kV6820;ZGH@<0^IIP0`2hTeh[ooooo`00:_ooool20:YoC0030:UnB`2XODX0Yga90080YW]800H0
YGY70:AkA`2UO4P0YGa80:ImB@2WOTX20:QoB`040:V0C02WOTX0Ygi:0:MnBP80Z7m;0`2YP4`80:^2
CP/0[8=?0P2]Q5030:j5D@030:j4DP2_QE<0/8ID0080/HME0100/8ID0:j4DP2]Pe40/8ID0;67E@2d
RUP0]heK0;^AG`2nU680`9IT0<:HIP31W6l0`Ye`0<FPL`38XgH0bZEh0P3;YWT01@3:YGP0bjUl0<^Y
O03<ZWd0cJ]n0080cZ^100<0cjb20=2]P`3@[H<00`3?[8@30=2]Q@80dJj6103=[H@40<b/P`X0cZj7
103?[hP20=2`R@050=6aRP3@/8T0d;290<n_R03>[XL00`3=[HH0403;Z7h0bJIl0<NTNP36XgT0`j1f
0;bIK`2aSV@0Z8EK09]dC@2FKdH0TFY108mX?@2BK3l0UFm009E_?P2CKC`209=^=`0309A_>P2DKc/0
UFln0080UW1100<0UW1309Mb?P2GLSh01P2GLSh209U_?@0409Q^?02GKC/0UV`j09E[>@80U6Xh202C
KSX3099X=P<0TFLe0P2@IS@8099W>P0308eW>02<ISL0RfDf0080RV@e00T0RfDf08eW>02>J3T0SFPa
08eX<`2=J3@0SFLf08eW>02=IS/00P2=ISd408eW>00408aV=`2;ICH0RfDf08YT=@<0RfDf0`2<ISL2
08eW>080RV@e00H0RfDf08eW>02>J3T0SfTj091Z>`2AJc`308mY>P@0SVPi0P2=IcP0402BK3d0TF/l
091Z>`2?JCX0SVPi08eW>02<ISL0RfDf08mZ<`2=J340RfHa08UT<02:I3<0SFLh091Z>`2CKD0308mY
>P80T6Xk0`2AJc`00`2CKSX0TF`h091[=`0208mZ=P03091[=`2AK3P0Tfhj00<0TVhn0P2CKcl309A`
@0P0Tflo102DL40409=_?`80TVhn0P2CKcl0102DL400UG5109Ea@@2ELD4309Qd@0@0VGE100D0VWI2
09QfAP2HMTH0V7I609UgA`0209YhB080VgU90P2INdD0102HNT@0UgU309Ih@P2EMd4209Af@00609Eg
@@2CMCl0SW0j08U[=@25Ic40PfD_0P21Hbd0:`2<K2l0RFT`089T;P1hGBh0KE@/069;:@1GA2H0DShU
04@j7`12>1d0@CLL04@j7`17?B80B3hS04@j7`10=Q/0=2hN030]700^:a`0:RPK02LW6`0U9a`09BPM
02DX7`0X:Q`09bTK02HX6P0U9aT09RPJ02LY6`0Y:ad0:R`N02`^600^<1X0<C<M03<e7`0d=R00<cDO
030b700_<A/08bHM028U700P8aX00`0N8AP0100O8QT082<J01`O600L7aP201dP6@807R4J0`0O8Q/0
2`0S9Ql09BHN02TY7@0`;A`0>C<M044j7P19?R00Cd8R05U5901NBb<0IE<S0080JEPT00/0He0U05a8
9`1F@BH0Bd0P04<g7@0h;1`0<2HM030W800b;1h0<S0K038a5@0803db7PH0>c0N0P0l<Al0=@10<A`0
@34J044a6P13<AT0B3@K04dh7@1C>al0ECdQ06E39`1/Cbd0KeTb06AG;@1=Ab<0=CDM02HY7P0Q9R80
8bHO028U7P0Q8QX08R8H02LU6@0/:1`0<2dN03D_8@1:=2H0CSXR05m9901bFbT0OF@[085T;029J3<0
TW10099d?P2CMCl0UWQ209Mi@`2HNT@0WGm90:V;E@2dUV00YX1A08MW?P1KB2P0>cDO038c8@0g>2P0
>CPV03Lb7P0_<BH0;BlT02X[8`0W:2809BHQ008092@R00X092@T02DV8@0V9b809bPR02TZ8P0[;B80
;BlR02h`8`0_<B<0;RlQ0P0_<2800`0`<B<0<C8T034b9002034b9080=30T00@0<blS038^8P0a;B40
<2`P0P0_:al01P0/:Qd0;B/N02d[7P0^;1l0;bdP030^8@80<BlR100f<28403D_8@0503P^8P0i;b<0
>BlS03X`900k<BD00P0l<RH01`0m<bL0?c4T040b9@11=2@0@cHU04Dh9`17>RL00`18?2H204Pi9P06
04Xi9`1<>BP0CCXY050k:P1A>RX0DS/[0P17>2401P19>B80BcTS04`j901?>RD0D3XU054k9P<0CC/S
101>?2@00`1??BD0E40W05A09`0605A09`0>05<o9`1C?bH0E40W05I29`1GA2H0F4DU05U69@1JAbH0
GdHX0617:@1QB2X0HTT[06=:;01UC2h206I=;`0A06U><01XCBl0I4/]0618;01JABX0ET8Y05<o9P1@
?RH0DD4X0510:@1>?bP0BShX04Ll:013>bP0@STX040i9`10=bH00P0o=RD01@0n=B@0?3<R03/b8@0k
<R40>S4P0080>38V00@0=c4U03H`900f<2@0=BlS0P0d;R801@0d<2L0<blV03<_9P0b;RD0<BdT0080
<2`S00@0;b/R03@^8P0d;R80=2hR0P0e;b<303H`9080<C4W00@0<30V02l_9@0^;R@0;RhT0P0];B<2
02/[8@80:RXP0P0Y:Al202PX7P80:b/S0P0Z:R8202TY8@80:2PP00H0:bLT02/X8`0[:2<0;2TR02`Y
800]:al202d[7P80<B/O0P0b;20203<]8@80=2hR00<0<2`S034]900a;B@00P0a;B@3030/8`06038[
9@0c;2@0<b`T03@]8`0e;b<0=S0R0P0g<B4203Pa9`0703Xa:00j<RL0?38V040d9P12=BD0ASHW04Lg
9`0204Xe800B04Tg8@1:>R<0BS/T04Xn9P1;?bL0BT0W04Hk9@18?2@0CClU05919@1IA2D0GdLU06=9
9P1VBRD0G4/]05Y9:`1GARP0Dd8T0P1A@280>P1C@R@0ED@V05a89@1KB2L0FTXX05Y::@1GB2T0E4HY
04m4:01=@RH0C3/Y04`j9P1?>b<0E3`P05]08P1TAbD0KThX07=A:`1kGbd0Nel_07]P<@1hH3@0MEhe
079L=`1`FCL0KETh06e?:`1_DBd0LED`075G<P1_Ec40JU@]06E?:01PCBD0JDl^06a?;@1_Db`0M5L]
07]L;@23Hc00RFPb08a/<`2DM4<0UGE409IhAP2FNTX0UG]:09=kB`2ANDT0T7Y;095iB`2DNDX0UGY;
09QlC02MOdd0XH5>0:F4C`2VQE020:25D0030:24DP2QQED0XHEF0080XHAH0280XXEK0:66F`2QQUT0
XXEI0:F6F02YREX0[H]K0;2?G02dT5h0^9MQ0;fNJ035Yg<0b:ik0<VaP@3<]hP0d;j@0=G2U`3KbjT0
gLf[0>7>[@3TdZh0j=Ba0>_G/P3_fK@0l=Zc0>_F^`3Ye;L0ilnc0>C;[@3RajT0h/FU0>74XP3Q`j40
i<VB0P3Sb9<05P3QaI<0gL6A0=VmSP3F^Hd0dkJ:0=6eQ@3@]8@0d;B20=6cO`3@/W`0d;=k0=6bN`3A
/WT0b:Yd0<^]M`3>[gP0cJed0<^XKP3:YVX0cZM/0=6[K@3=ZGL30<jZN080cj]i0`3@[7X0103<ZfP0
bJQU0<BSH02nWEX30;^JE`0<0;bKF02gUED0]iEE0;NEE@2iUeL0_9YJ0<2NGP34XV80aZAT0<^YJP3<
ZV/0cZa]0`3?[Fh03P3=Zf`0c:Y[0<VWI`38YVH0b:IW0<VWJP3:Yfd0c:Ua0<j[L`3?[7H0e;5i0=Fb
NP3G]7`0f[Mo0P3K^800203J]gl0fKIn0=^iO03J^7/0f;Ii0=FcMP3D/WD0dk5d0P3D/WD30=NgO00=
0=RhO@3J^Wl0gKf20>30Q@3R`XL0gL280>;5S@3Qa8`0fkj60=ZmQ@3L_hL0f;^30<nbNP020:jDH`09
0:fCHP2/TV40Zi5P0:^AH02]Tf80[YAS0:Z@G@2[TEh0[99O0080[I=P0`2^U640402_Tf<0/9AT0;:F
IP2dV6P0]YYZ0;RLK02jWVh0^im_0<6RL`32XgD0aJQl0<jbRP3H_YT0glNU0>39Z@3NajP20>7:ZP80
h/^[103Sc:`07P3ObZd0h<^^0>3;[P3Pbjh0glZ]0=c7ZP3JaJP0f<>V0=S5Y`3Ga:H0eL:T0=?0XP3A
_Z00ckbN0<fjW03<^I/0b[FF0<VdU@39/Y00ajn;0<B[P`30YGX0_:5d0;ZNK`2mWG@0_imh0<:UO@35
ZH80ajf80<VaS@80bK:@00X0d[VK0=>lW@3G_j<0f/FZ0=k:/@3QckL0i=Bm0>KF_`3Sf<H0i=W70P3U
f/P01@3Wg<X0jMk<0>_PcP3/hLl0kN;@00<0k^;B0P3_hm<30?3Te080m>?A00<0ln;>0??Sc03chlX0
0P3bh/P00`3bhlH0l=o50?3Oa@060?3Oa@P0k]g1203`g<<80>cJ`P80jmc90`3/gLX30>gNb`P0k]g=
0`3_g/X20>kMb@<0kMc8203/f/@20>oJ_`040>kI_P3]f;d0k=Nl0>_F^`80j]Fj0P3]d[@01P3/dK<0
j/na0>W>/03Wc:h0i/^]0>G:[080ilJW00H0i/FT0>C3XP3S`Yl0hL6K0>30V@3O_iP20>2nV@040=nm
V03N_9L0gK^F0=bjU@80fkVD0P3F/hT0303E/XP0dk260=:_Q@3A[X@0d:f30<n/PP3<ZWd0bjUl0<ZX
N`39YgX0b:Ii0<JTM`80aJ=f0P34Wg801033WW40`Ye`0<6LK`31W6l20<2KKP040<:ML031W6l0`Ia_
0<6LK`80`9]^0P2oVVd30;jKL@<0_IY`0`2lVFl20;ZGK`80^II/00@0^IMZ0;RFJ02hUVH0^9IV0P2j
UFP20;VDI`<0^9=V00<0]i9U0;RFJ@2hUVT01P2hUVT0102jV6X0^IMY0;VGJ@2iUfT20;RFJ080]iEW
0`2eTfD20;BBI0<0/i5S0`2gTVD20;RCIP<0^IAW0`2iUfX30;ZHJ`80^iU/0P2jV6/01P2kVF`0_I]^
0;jLK`2oWG00`9ia0<6OLP80`9ia0P31Wg840<:PL`040<2QM@31XWH0`J9f0<6RMP80`Z=g0P33Y7P8
0<BTN`80aZ=k1037Y7`20<RUO@030<VVO03:Ygd0bZMm0080bZMm1@3;Z7h0103<ZGl0cJZ00<j[P@3>
Zh420<n/PP060=6_RP3B/8/0d[2;0=>aS03D/Xd0eK>>0P3F]8l01P3F^9H0ekVG0=RjV03I^iT0f[bJ
0=^mV`80g;jL00P0h<2J0=nnV`3L_Y`0f[fK0=VoWP3K`:80fl:T0=g4YP<0glJW00<0h<NX0>78Z@3Q
b:T00P3RbJX90>76Z0<0h/FW0P3SaZP30>C7Z@<0iLRZ0`3VbJ/20>O:[0P0ilfb403Wck<40>S@]080
ilnc0P3Vc[820>O=/P<0i/ba0`3Ubk080>C;[@P0hlZ/203Uc:h40>C</0@0hl^_0P3UcK420>C</0<0
hl^_00<0h/Z^0>G=/@3UcK401P3UcK440>C;[@80hlZ/0P3RbJ/80>C7Y`80h/FS0P3Qa:80103P`j40
gl:P0=k1W`3N`Il40>2oW080gkjK0P3N_IX01`3K^YL0g;^H0=bkV03M_9T0g;^H0=ZiUP3G]Y<01@3F
]I830=FdT@80e;>@0P3D]8d20=FeSP@0e[J?403D]8d20=>cS0<0e;B=0`3E]Hh80=JfS`060=RhTP3G
]i40ekNA0=JfT03E]Hl0e;B>0P3C/hd30=JfS`<0ekN@0P3H^9440=JfS`80eKF>0P3D]8d30=FeS0<0
e;B;0P3C/hX80=BaR@P0d[:;103B/XT40=6aR0P0dk2:0`3A[XH20=2]Q@<0cjb40`3>[7l50<f[OP@0
bZUl1039Z7/01038YWP0bJMi0<VWN@39YgT30<ZXNP030<^YN`39YW`0bJIl00H0bJIl2@37YGL80<JT
MP<0aj=c00<0aZ9b0<FQL@34X7000P33Wfl30<2LJ0<0_i]W0P2nVVH20;nKI`040;jJIP2mVFD0_IUU
0;bHI0<0^iMS00H0^YIR0;VEH@2iUF40^iMS0;fII@2oVfL40<2LJ0<0`IeY0P32WVX02035XFd0`im[
0<2LJ02nVVH0_IUU0;jJIP30W6P0`YiZ202mVV@30;^HHP<0^YMQ0P2iUV030;RCGR_ooooo000Zoooo
o`80ZWm<00<0ZGi;0:QmBP2WO4T00P2VNdP0102UNTL0YGa80:ElB02VODT20:MnBP030:QoB`2YP4`0
ZH1<00<0Ygi:0P2XOd/30:V0C0P0Zh9>2`2/Pdl20:f4D0<0[XEA00<0[H=A0:j4DP2`QU@00P2aQeD0
402`QU@0[hEC0:j4DP2`QU@0/HME0;B:F02hSU`0_99P0<2FI033VFL0aI]Y0<BOL`35X7@0b:=g0<^V
NP3=Z7`20<jYO@050<fXO03=ZX00cZ^10<j[P@3?[8800`3@[X420=6_PP@0d:f50P3A[XH20=:_Q`@0
cJf4103>[XD80<n_R0030<j^Q`3?[hP0cjn80080d;290P3A/HX50=:bR`@0dK6:0100c:^20<ZYP038
Ygh0ajIm0<FTN`2nWG@0/i9Y0:^:H@2ON540VG99099[@P2@JCh0Tfe009E_@02EKch0U6hm0P2DKcP0
0`2DKcX0UG0l09E_?P0209E_@00309I`@`2HLcl0V7<o00H0V7<o0P2IKcd0102HKS`0Ufdk09I/>P2E
JcT209AZ>0P0TVdi0P2CJCL3099X=P<0TFLe202BIcX00`2>J3T0SFLh08]U=P0208YT=@0308]U=P2<
ISL0SFLh0080SFPd0P2=IcH01@2>J3T0SVPk08iX>`2>J3/0SVPi0080SFLh00<0S6Hg08]U=P2;ICH0
102;ICH308aV=`<0SFLh0P2:I3D01P2;ICH0SFLh08iX>@2?JCX0T6Xk095[?080T6Xk0`2?JCX408iX
>@0A099/?@2AJc`0T6Xk08mY>P2>J3T0SFLh08aV=`2;ICH0SFPa08aW<02;IS40RVDa08]U=02>J3T0
TF/l099/?`2?JCX00`2@JS/2095[?080TV`m00<0Tfhj099]>@2AK3P00P2?JSH00`2AK3P0TVdi09=^
>P03099^?P80Tflo0`2DL40809=_?`P0U70n0`2CKcl409A`@00309Ea@@2GLcl0Ug<o0080V7A000D0
VGE109Yf@P2JMT80VWI209QfAP0409UgA`<0VWQ800@0VG]509QjA02HNT@0UgU30P2FN48309Eg@@0g
099d?P2>L3X0RV`f08IX<P24IS00PfD_089T;P2;Jbh0RFT`089T;P1gG2d0K5<[06199`1E@R@0DCdT
04@j7`12>1d0@CLL04@j7`18?R<0BClT04Dk8011=a`0=2hN034^7@0^:a`0:bTL02LW6`0V:1d09BPM
02HY800X:Q`09bTK02HX6P0U9aT09RPJ02LY6`0Y:ad0:R`N02h]600a<1/0=3<N03Lf8@0h=b80=SDP
03<b7@0a<1/08bHM028U700P8aX07b8I01hQ600O8QT082<J024T6`0201`O60807B0I0P0N8AX301lR
6`0H02@U7@0U9a`0;2XM03@_700l=1d0AC`O04m28P1BAB<0H4XQ06E@8`1/F2<0L5dU06iJ9@1XDbH0
GdPV05U19`1;@200@SHL03L[6`0`9Qd0<2LP03<]7`0c<A`0<c8F200m<Qh203/`7PH0>RlM03D0?2lL
03``6P0n;aX0@30I04<a6@18=1/0C3LL04hi7P1H>Qh0HDLV06MC;P1PDR/0BT@R03@b7@0U9Ad07b4P
028U7P0Q91d08B8J028R600W9AT0;2PL034^7`0f<280BcHU054m901TCRL0Mf0/081X;022IB/0RVTc
09Ed@@2CMCl0UWQ209Mi@`2FN480V7Y40:63C@2[SEL0/I=M0:1jC@20H3T0ET<U03Xd7P0c=2@0=CHX
03Lf900h<b00;BlT02`^8`0Y:R809RLQ02@U800202@T8P0902@T900T9B009BHQ02LX8P0X:B40:R`Q
02`^8@0];b80;S0R00D0;c0R00@0<34S034b900a<R@0=30T0P0c;b<01P0b;R80<BdQ030/800`;200
;b/O02hZ7P80;b/O00<0<2`P034]8@0b;R800P0c;b<403D_8@@0=S0R0P0h;R80100i;b<0>S0T03/a
9@0l<RH203dc9`80@38U00D0@C@T048e9014=bH0ASTV04Pl9P0204Tm9`0604Lh9@18>BH0BCPV04/h
9`1<>BP0CcXY0P1A>RX01P17>240B3TR04Ti8P1;>B<0C3XT04lj9@80DC/V0`1=>b<00`1>?2@0CcdU
04lm9@02050n9PP0EClW00h0DclW05<o9P1D@2L0ET8W05M49P1HABD0FDHU05Y79P1OARP0H4LY0658
:P1RBB/0I4/]06I=;`80Idh`0100JTla06U><01UC2h0H4P/05Y5:P1F@RT0DclV04lm9@1B@2P0DClY
04lo:01<?BP0B3/X04Dj:014>2P0@CPW0P0o=RD0100n=B@0?C@S03dd8`0l<b8203/b8@80>38V00@0
=c4U03H`900f<2@0=BlS0P0d;R801@0d<2L0<blV03<_9P0b;RD0<BdT0080<2`S00<0;b/R03<]8@0c
;B400P0d;R8203D_8`80=S0T0P0`<2H202l_9@0402h^900];B<0;2`R02`/8P@0:RXP100Y:Al202/[
8`80:RXR0P0Y:B4202PX800602PW9@0X9b<0:2LS02TX8`0Y:B40:RXP0P0Z:Qh3034[7`80<R`P0`0c
;B43030/8`0302l[8P0`;2<0<2`S0080<BdT00H0<R/U03</900c;2@0=2dS03D_8`0f<28203La8@80
=c0V01X0>C0W03/c:00m<bL0@CDW04<f9P15=BH0ASHV04Xe801;=R40BSPR04Xj8`1:>b@0BCdU04Xn
9P1:@2L0ASXT04Xk901>?RD0E40U05a59P1QAbH0ITTW06U;9`1PCc40GD`^05Q7:@80E4<U00@0ETDW
05M6:01HAbT0FTLV0P1HB2L0=@1FAbP0DT@W04e29P1:@2D0B3hS04/h9`1<>RH0DC/T05Pn8`1QA2@0
JT`V07AC:01hEbX0OF<`07eS<P1lI3@0NV<g07IP=`1aGCP0KETf06YG=P1YC2`0Jdh^06aB<@1/E380
JU<a06=?;01NBRL0FTPT06I8;01YBR/0K4hZ07=C:P1kFb`0Pf8]08aY<@2@KS40UGI009Ig@@2FN4@0
UGU709=hB@2@N4X0SWI:08aeB@2BMdP0UGU909UmC@2OPDl0Y8AA0:R7DP2[R580[8UC0080WhA?03l0
Wh=A0:24E02QQEH0XHAH0::5F@2RQE/0XXML0:66F@2SQUX0YXMI0:Z:F`2^S5`0/I1M0;FAG`2kWFL0
`J=_0<N]O038/X<0akB90<FhSP39_IL0bl6M0<[0Y@3<`:H0dL>X0=G6Y`3JbZT0glb[0>??[03WdJ`0
hljc0>7<[`3Pb:`0gLBV0=c1X`3M`:00gL2N0=k0WP3QaY40hLFC0>34TP3N`Y80f[j?0=JiS@3B]H/0
d;>90=6_O`3@/7l0d;1m0=2aN`3?/7T0cK1h0<f`MP3<[g<0aJI`0<RYL`3<ZgD0c:Ua0<VUJ`39XVL0
cJEZ0=2XJ`3<Z7H00P3=ZGL0103>ZWP0cj]i0=2/NP3A[G/20=:^O0050<f[J`3:Z6P0a:9R0;nMG@2l
VUX00P2kVET0302lVUX0^IMG0;VGE`2jV5P0_9YJ0<2NGP34XV80b:IV0<^YJ@3=Zf`0cZa]0<n]KP80
d:i_00<0cje^0<f[K03<ZV/00P33XF402@33XF80a:9U0<JSJ@3:Yfl0cZ]c0=2]M`3G]7`0fKIn0=^h
P0030=fjPP060=biP@3K^800g[^10=biO`3J]gd0ekAj0P3E/WP00`3F/gT0ekAj0=ViP0020=ViP006
0=ZjP@3M_H@0h<270>C4R`3VaXd0hLB<0P3WbY802@3P`h/0g;n70=k1R@3L_hL0e[V10;>IJ02`UVD0
[I=R0:^AH0020:bBH@80[I=R0P2ZT5d05P2[TEh0[99O0:fCH02^U640[iER0;2FH`2`U6@0/IEU0;>G
I`2eVFT0^9a/0;ZNKP2lX700_J5a0<:SM@33Y7P0aZUo0<ncS03I_i`0h<NX0>7:Z`3Oaj/20>3;[0<0
hLb]0`3RcJh20>3</@0>0>7=/P3Pc;40gl^`0=g9[P3JaZ/0fLFZ0=S4Z@3G`jP0eL6V0=>oY03A_J80
ck^P0<fiWP3<^9d20<VdU@0<0<VbT037[h/0a:^30<6VN`2mXWD0^im`0;bLL`2oWgP0`JAl0<BXP@36
[8L0b;2<0P38/Hl02P3A^9X0d[^L0=FmX@3H`jP0gLV`0>3>]P3Rd[/0i=Bm0>;Ga@3Sf<H20>GJb005
0>KKb@3XgL/0j]o=0>_PcP3/hLl00P3/hm@20>gTe@80k^GF0P3_i]L20?CTe0030??Td@3ci<l0l^?<
0080l^C:00<0l^C90?7Oa`3aglL01P3aglL80?3Oa@P0l=c3103]g<840>cK`@<0k=_70`3]g<P20>kM
b@@0k]g=103_g/h20?3QcP80kn3=0`3^gl`00`3]g//0k]c80>kLb0020>kLb0@0kmg900D0k][10>gI
`03]fL00k=Ro0>_G_P020>[F_@070>WE_03/e;P0k=Bh0>_C]`3Zd[H0jM6e0>O?/`020>K>/P80ilV]
00@0i/V[0>G8Z03TajD0h/FS0P3QaJ020>;4XP030>73X@3P`Z00gl6O0080g/2N0180gKnM0=ZhTP3J
^980fKNA0=RfT03F]8h0eK>=0=BbS03C/H/0d:n40<n^P`3>[H80cJb10<^ZO`3:ZGh0bJQm0<RWO038
XgL20<NRMP050<JQM@34Wg<0`iib0<>NLP32WG400P34Wg<20<>NLP<0`Yea00@0`Ia`0;nLLP2oW780
_iab0`2nVg430;fJL080_iaf00@0_Y]c0;jKL@2mVfh0_9Y]0P2lVV`0102nVFd0_IQ/0;fHK02mV6`2
0;bGJ`80^iIZ102kV6h40;bIK`<0_I]]0`2lVV`20;^IJ`<0^IMZ0P2hUVT30;NEJ0040;VDI`2jUFP0
^YEX0;ZEJ080^iIY0P2lUfX20;^HKP<0_9U_1@2mVW001P2nVg40_iab0<6NM032WgD0`j1f0<BQM`@0
`j1f0P34XGL20<FRN080`j=j0P34Y7/30<FUO0030<JVO@37Ygh0ajMn00H0ajMn00<0aJ9j0<JSN`36
Xg/00P37Y7`30<RUO@030<RWOP39Z7l0bJQo0080bZV00P3;ZX401P3<Zh80cjj50<n^Q@3@[hH0dK27
0=:aR080dk:900L0e;>:0=JeTP3G]Y<0ekJC0=RgU03I^9D0f[VF0080fkZG00D0fkjL0=boW@3L_id0
gL2N0=k1W`030=o2X0090>?5X@3Ra:80h<>Q0=o2XP3M`Z@0gLBV0=k6ZP3Oaj/0h/V[00@0hlZ/0`3T
bjd90>?:[080h/NZ0P3Sb:/30>C9[0030>G:[@3WbJd0ilV]0080ilV]0P3XbZh20>W;[`P0j<jc403X
d;@30>WA]@<0j=2d0P3Wck<20>S>/`80ilfb103Vc;4@0>C;[@P0iLb^103Tc;040>G=/@040>K>/P3U
cK40iLfa0>G=/@80i<b`0P3Sbjl80>K>/P<0iLb^0`3Tbjd20>?:[0P0iLRX0P3SaZ@0103RaJ<0hLBR
0>33X@3P`j420=o2X0<0hL2M0`3P_i`20=nnV`030=bkV03M_9T0gKbI0080gKbI00<0fkZG0=RgU03G
]Y<00`3G]Y<40=JeTP80eKBA0P3E]Hh30=JfS`<0ekN@403E]Hh30=BdS@<0eKF>2P3F]Xl20=RgU080
ekJC00@0e[FB0=FdT@3D/i00e;>@0P3F]Xl30=NgT0<0f;RA0`3G]i030=JfS`80eKF>0P3F]Xd30=Fe
S0<0e;B;203D/HT80=:bR`@0d[:9103C/hX80=>`RP80dZn70P3A[XH20=2]Q@80cjb41P3>Zh420<n/
PP030<b]P@3;[800bjb00080bZ]o0P39ZWh00`38ZGd0bJMi0<ZXNP020<ZXNP<0bjUk00<0c:Yl0<VV
O039YW`01P39YW`90<RVN0P0ajEh00D0bJEe0<RTM037Xg<0aZ9b0<FQL@030<BPL080`IeY0`30W6P5
0;nKI`040;jJIP2mVFD0_IUU0;bHI080^iMS00<0_9QT0;^GH`2jUV800P2jUV800`2lV6@0_YYV0<2L
J0030<2LJ0<0`IeY0P32WVX00`35XFd0`im[0<2LJ0020;jJIP030;nKI`32WVX0`im[00P0_IYT0P2l
VF<30;^HHP<0^YMQ0`2hTeh[ooooo`00:_ooool20:UnB`<0Z7e:0`2WO4T0102VODT0Ygi:0:MnBP2W
OTX40:QoB`<0Ygi:0P2XOd/30:V0C100Zh9>0`2/Pdl20:f4D0<0[XEA01@0[H=A0:j4DP2`QU@0/HME
0;:8EP2aQeD0/8ID0:n5D`2`QU@0/HME0;F;F@2iSed0_YAR0<:HIP36W6X0aie[0<FPMP37XWP0bZEk
0<fXOP@0cjZ00P3?[8H01@3?[8@0d:f30=2^P@3@[X40dJn10080dJmo00@0d:f50=6^QP3A[XH0dJj6
0P3B[hL20=>`R080cJf40P3>[XD40<n_QPP0d;290P3?[hP20=2`R@040=6aRP3B/X/0dk><0=>cS080
d[:;0`3C/h`30=BdS@0@0<j^Q`3<[8D0bZZ30<ZZP`38Z840`J5j0;JFK`2^SVL0XgaE09aeC02DKD@0
TFXo09=]@02EKd00UW0o09A^?@80UG0i00<0UG0k09E`?02EKch00P2EKd000`2EKd80V7<o09Qc?`06
09Qc?`80VFlm00@0V6hl09M]>`2FK3X0UF/i0P2DJSP8099]>@<0TfTg0P2BJ3H3095W=@P0TVLj00<0
SfTj08iX>@2<ISL00P2:I3D00`2;ICH0S6Hg08eW>00308eW>080SVPi0`2?JCX208iX>@0308aV=`2;
ICH0RV@e0080RfDf00<0S6Hg08]U=P2<ISL00P2<ISL208eW>080SVPi0P2;ICH0102<ISL0SFLh08iX
>@2>J3T208mY>P<0T6Xk0P2?JCX408iX>@05095[?02@JS/0T6Xk08mY>P2>J3T00P2=IcP02@2<ISL0
RfH_08aW<02<Ic80SFPd08iX=`2>J3T0SfTj08mY?00308mY>P80T6Xk0`2AJc`00`2CKSX0TVdi095/
>002091[=`03095/>02BKCT0Tfhj00<0TFdm0P2BKSh;09=_?`0409=_>`2DL3`0U70l09A`?0<0UG4m
00<0UW8n09A`@02DL4001P2DL4001P2FLSh0Ug<o09Mc?`2HM400VGE109Yf@P80VgM3202IMdL809Qj
A00[09Eg@@2BM3h0SW0j08Y/=P27JC<0QFLa08AV<023IBl0Rf/^08UY<021Hbd0MU//06]B:P1OB2H0
E44S04lk8P15>b00@cTN048h7@15>b00B3hS04To9015>b00@CLL03D_7`0a;Qd0;b`M02/Y700X:1`0
9RPM02HY7P0V:B00:2XL02LY6`0V:1X09BLI02HX6P0W:A/0:B/M02X/7P0_;AP0<S0K03Le800203Xh
8`0603Pf8@0d<Qd0<S0K02@W7P0R9A`08B@K0`0O8QT0100P8aX08B@K01`O600L7aP201dP6@807R4J
0`0O8Q/0600T91X09RHJ02dZ6`0e;Q/0?CHL04Pm7`1A@R40EDLT06I@8@1[ER40LUdT07IR9@1dGbH0
K5HW069::01K@BP0BSlO048f700g:a/0<2HM034X8@0c;Al0<c4L03@c5`P0?C8N100k<1h203X_7@<0
>BhL03@0>RdJ03/^6`0o<1/0@S8K04Hd7019=A`0BcLN04le6P1I@R80H4hZ05]=:019@240=2lL02HS
7P0P7R408B@M020S700P8AT08R8H02LU6@0]:Ad0<RlP03La8`1<=b@0E40U06UC:P1lIBl0PVX^08=V
:P2<K3<0UgI109=e?`2GND<0UWQ209=e?`2GND<0XhE?0:^=E`2]SeT0VgE807UI<`1@?240>C8O03<d
9P0c<bL0=C<T03Tc8`0/;R<0:bdR02PY8@0V9b4092DP0P0T92802@0U9BD092DP02@U800V9b409bPP
02T[800[;B00;2hQ02d_8@0202l`8P<0;RlQ00<0;c0R034b900b<bD00P0c;b<2038^8P80<BdQ0P0`
;2001P0a:al0<R`P038/800c;B40=2hR03D_8`80=S0T00@0=BlQ03H`8P0f<280=S0R0`0g<B<0400h
<R@0=bdQ03P^8P0i;b<0>S0T03/a9@0l<RH0?C<W03hd:012=2L0@C<V044d9012=B@0@cHU04Dh9@17
>bD204Pl9P80ASLT00H0B3LU04Xg9P1;>2L0CSTX04lh:01@>BT204Pi8P0704Xj8`1<>R@0CC/U050k
9P1A>bH0DS`W04`j8P0204dk8`0304hl901??BD0D3hV0080DClW201G?bL03P1C?bL0DclV05A09`1F
@RL0Ed@V05Q59@1IARD0FTLV05m6:01PAbT0HDPZ06=:;01UC2h0ITd_0P1XCc40401ZCc40J4d_06E<
;P1PB2`0FTDZ05I2:@1C?bH0D3hV05A0:01C?RT0D3hX04dl:01:>bP0ASTX04Dh:013=bL303he9080
?C@S0`0l<b8203Pb9P0403La9@0f<2@0=S0T03D_8`80=2hR100b;RD4034]90<0<bdQ0P0d;R8303D_
8`06030`9P0_;bD0;blU02h^900];B<0;2`R0P0[:b4402XZ80@0:BTO0P0[:b<202XZ8P80:BTQ0P0X
:2001P0V9RH09RHT02HV900W:2<09bPR02PY8@80:2XO00@0<2XN034[7`0a:al0<B/O0P0b;20203<]
8@09030/8`0_:b80;RXQ02hZ8@0_:b80<2`S034]900b;RD0<R/U0080<b`T00<0=2dS03D_8`0f<280
0P0g<B4203H_9@0<03P_9P0j<RL0?C<W040d9P12=BD0A3@U04@d901<=b80CCPS04/i8`1:>R<0BS/T
0P18?2@0A`18?RD0B3TT04/k901??BD0ET4V05e49P1TAbL0J4XX06a;:01SDS@0GD`^05I59`1D@bD0
ED@V05Q7:@1IB2X0FTT[05Q89`1FAbH0EDHW05539P1=@RH0BClT04@m8`13?280CCLY04hi:01D>bD0
Fd0S06A88`1_CbH0N5HX07aK:01lIC40O6Dc07]U=01iI3L0M64g06iL=P1YEc<0I5@b06M<;`1XCC00
J4la06M@<@1SCRl0Gd`/05]8:01GAbH0I4@[06Q6:`1]C2/0M5<Z07eK;@27I2h0T6``09A`<P2GN3l0
UgQ109Mi@`2ENDL0TgQ908ifBP2<LdX0RG99095eA@2FN4H0Vge;0::2C`2WQU40ZhQB0080[HQA0P2N
Pdh09P2OPe40Wh=C0:24E@2QQ5P0XXEI0::5F`2RQe`0XXMJ0:>6FP2WR5X0Zh]L0:n=G@2cTUl0]i=Q
0;^PJ`30YW<0a:im0<>bQP2o/HX0^[:>0;VdU02j]iP0]jfD0;R^U@2m[i@0`k:D0<^gUP3C^iT0fKnJ
0=g1VP3IaJ@0el>P0=JoW@3D_9P0e;ZE0=NkU03I_ID0fkjF0P3N`Y001P3M`I40f[j?0=NjSP3B]H/0
c[690<^^QP80d:Yi00h0d:ah0<j]M`3=[WL0bjid0<N]L036[6l0a:=^0<NVL@3<ZG<0bjI_0<ZSJP39
XFH0c:AY0=2VJP<0cJQa00h0cZUb0<nZL`3@Zg@0dJae0=:]MP3C[WL0bja/0<RYJ@33Y6@0_IiN0;ZK
F`2iVUX0^Y]K0;^LG080^YQH00P0^iUI0;jLG031Wel0aZAT0<ZXJ03<ZVX0cJ]/0<j/K@<0cje^01L0
cZa]0<bZJ`3;ZFX0`ImO0<2NGP30WUl0`Z1S0<JSJ@3;Z700d:ee0=>`NP3K^800g;V10=jkP`3O_8@0
h;f50=nlQ03N^h<0gKZ20>6nQP3O_8@0fkR00=ReO@020=NdO0030=VfOP3J]gl0f[V30080f[V300H0
g;^50=nnR03R`H/0i/F?0>S7T@3TaY020>c>V00=0>C6T03O`H/0hL>=0>32S03L_XP0^Im^0;BJJ@2^
U6<0Zi5P0:bBH@2]Tf80[99Q0:^AH0030:V?G00E0:Z@G@2[TEh0[I=P0:nEHP2`UV<0/YIV0;>GI`2d
V6P0]i][0;VMK@2kWfl0_J5a0;jRLP33Y7P0a:Ak0<NZPP3@]8l0f/2O0>78ZP3QbJd0h<R^00<0h<f_
0P3Qc[030>;?/@0@0=o>]03PckD0h<ne0>3?]@3NcK<0g<^a0=W8[P3Hajd0f<B[0=O3ZP3E`JP0dknV
0=6mY03?^j80cKVP0<bhW`80bKBE01H0bK:@0<R`S035[8@0`ZMl0;jSMP2lX740^i]b0;jNM`30Xg/0
`jN00<F[QP37[h/0ak2>0<RaS`3?]YP0d;VJ0=BlX03G`ZL0flN^0=k<]03QdKX0hm>l0P3RelD20>CI
a`050>GJb03Wg<X0jMk<0>[Oc@3[h<h00`3]hmL20>kTf0<0knGI0P3ci]H00`3biM@0l^GB0?7Uc`02
0?7Uc@030?3TbP3bh//0l^;;00H0l^;;203ahLP;0?7Ma080l=c30`3_fl820>cJa080kM_50`3^g<H0
103_gLL0k]g=0>kMc@3^gLd20>oNcP<0l=o?0`3^hM020>gPc`<0k=o>103^gL/20>oNc080l=o=00<0
k=[40>_I``3[fL<00P3Zf<830>WG`@80jmNn00<0j]Jm0>WE_03Xe;/00P3WdkX02P3Vd[T0j<je0>S>
]@3WcK80i/f_0>G<[@3Tc:X0hl^Y0>?;Y`3WbZX20>K9Z@030>G8Z03TajL0hlJV0080h/FU0P3P_i`0
103O_Y/0gKbI0=bkV03J^IH20=VhU@060=JfS@3E]H`0e;B;0=>cRP3B/XT0d;270P3?[hH01P3@Zh40
cjZ00<jYO`3=Z7h0bjIl0<ZUN`@0bJAj0P38XgT30<NRN0040<JQM`32WgD0`Yme0<:OM@@0`Iid0P30
WG<20<>ON`060<:ON@32WgL0`Iid0<2NL@2oWG00_ie_0`31W7820<2KL@<0_iY`00@0_IYb0;jKL`2n
Vg<0_Y]c0`2oW7@00`30WGD0`9i`0<2NL0030;nMK`<0_Ya^0P2mVW020;bIK`80^iQ^0P2jUfd20;bG
JP80_IQ[0`2nVF`00`2oVVd0_IYb0;fJLP020;jKL`<0_iad00<0`9ee0<6NMP31WWH00P32WgL00`33
X7P0a:5i0<FRNP040<FRNP80aZ=k0`37Y7`30<JVO`80ajN00`38Z8440<VYP080bZZ10P3;Zh801P37
Y7`0b:Em0<RUO@39YWh0bZMo0<^XP080c:V10P3;Zh@20<b/Q@040<f]QP3>[XL0cjn80<n_R080e;B=
00<0eKF>0=JfS`3G]i000P3H^940103I^I80f[bJ0=ZlVP3K_I/20=bnW0030=foW@3N`9h0g/2N0080
h<>S0P3Qa:@30>;5Y@090>?6YP3Vb:H0i<NW0>?6YP3PaJL0glJX0=o7Z`3ObZl0h<^`00P0iL^`2@3T
c;00103SbJh0i<Z_0>C:[`3TbZl20>G;/080i/ba0P3Xb[020>W;/@80j/bb0P3[cK<80>[@]A<0j]:f
0P3YdKD30>S@]080jLnd0P3Xc[<30>O=/P030>K</@3Tbjd0i<^]00H0i<^]203Uc:h80>K=[`80i<b`
0P3UcK440>K>/P040>O?/`3Vc[80i/jb0>K>/P80iLfa0P3Tc;080>O?/`<0i/f_0P3Uc:h30>C;[@P0
i/VY0P3TajL00`3SaZH0h/FU0>74Y0020>33X`040=o2XP3R`Ih0h/6N0>;1WP80hL2M0`3P_i`20=fl
V@80g[fJ00<0gKbI0=^jU`3I^9D0103H]i@20=NfT`@0e[FB0`3F]Xl20=NgT0<0f;RA203F]Xl80=Fe
SP<0e;B=0P3E]Hh;0=JfS`<0f;NF0`3G]YD20=JeU0040=JfS`3G]i00ekN@0=NgT080f;RA0P3I^I83
0=RhT@80ekN@0`3F]Xl30=JfS@80eKF<0`3D]8/80=FbRPP0dk><0P3B/XT20=>cRP@0e;B;203C/8X3
0=:_Q`80dJj60`3@[HD20<j[P`<0cjb40`3@[HD01P3<[hD0bjj40<^^Q03:[H<0bJb20<R[P@80ajZ0
0`3<ZW`50<^YN`P0bJIl2@38YWP80<NTNP040<ZVMP39YGD0aj=c0<JRLP@0aJ5a0`31WFT20<2LJ0D0
_i]W00@0_YYV0;fII@2mVFD0_9QT0P2kUf<00`2lV6@0^iMS0;ZFHP020;ZFHP030;bHI02nVVH0_i]W
00<0`9aX0`31WFT20<:NJP030<>OJ`32WVX0`IeY0080`9aX00<0`IeY0<:NJP33Wf/0202nVfD30;bI
H`80^iQR0`2jUf430;RCGR_ooooo000Zooooo`<0Yga90`2XODX20:UnB`80ZH1<0`2XOd/60:MnBP80
Z7m;0`2YP4`@0:^2CP<0[8=?0P2]Q5030:j5D@0E0:b2D02]Pe40[hEC0;67E@2bR5H0/HME0;26E02_
QE<0/8ID0;:8EP2eReT0^Y1N0;nEH`34VVP0b9i/0<ZPKP36XGL0b:=i0<ZUN`3=Z7h0cjZ00080d:^1
00D0cjZ00<n[Q`3?ZhL0cjb60=2]P`020=2^P@030=2^OP3A/7d0dK1m0080dJj60P3B[hL30=>`R004
0=BaR@3=[H@0cZj50<j^Q@80cjn60P3@/8L00`3A/HP0d;290=2`R@060=2`R@80cjn800@0d;290=6a
RP3B/X/0dk><0P3D]8d20=:bR`80dk><00H0e;B=0=FeSP3E]Hh0e[J?0=>cS@3A/H/20<n_R@0<0<f]
Q`37Yh40_9af0;BDKP2VOeP0WWM>09I_AP2BJd00Tfe009E_@02FL3l0UFln0P2EL3T01P2EL3/0UG0l
09E_?P2EKd00U6ho09A^@@P0V7<o0P2IKcd0102HKS`0Ufdk09I/>P2EJcT209AZ>0P0TF`h0P2DJSP2
09=Y=`<0TVPf00<0TFLe099W>P2BIcX01P2BIcX0102?JCX0SVPi08aV=`2;ICH208YT=@0308]U=P2<
ISL0SFLj0080SFLj00P0SVPi08mY>02?JCP0T6Xi091[=`2?JCX0SVPi08aV=`80RV@e00<0RfDf08aV
=`2=IcP00`2<ISL208eW>0<0SVPi1`2=IcP00`2>J3T0TF/l095[?002091Z>`@0SfTj00<0SVPi08mY
>P2?JCX00P2?JCX408iX>@0808UT;@2;IRl0SVTd091[=`2AJcX0SfTj08eW>02;ICP308iX>@<0SfTj
0P2@JS/00`2DKc/0Tfhj095/>002091[=`03095/>02CKSX0U6lk0080Sf/k0P2@K3`2095]?@80TVhn
202CKcl209=_>`80U70l00@0UG4m09Ib?P2FLSh0UW8n1P2DL40209=_?`80UW8n00H0Ug<o09Qd@02I
MD40VWI209]g@`2LN4@209YhB0H0VGM70P2GND<00`2HNT@0VG]509YlAP0209]mA`0709anB02DMT00
TW@n08i`>P2:K3H0QfTc08EW<@0208AV<00[08][;P28J2l0PF<]07IK;01ZDBT0GTLU058o8@1>>R40
AS`Q04@j7`13>Ah0AC/P04Pn8`19?b@0A3XO040f6`0e;al0<BhM02l/7@0[:A`0:2PL02LY7P0V:Ah0
9bXQ02PZ700W:A/09RPJ02DW6@0V:1X09bTK02T[7@0Z;1h0;bdH03<a700h=R40>cTT03`j9@0i=b80
=C<N038`6`0T9ah08bHM024T6`0201lR6@03020S6P0Q91/08RDL008071lH0P0M81T201hQ6P<07b8K
01P08b<G02LU600/:AP0=BlI03le6P1:?1l0DT<R05M79@1/EB40LE/R07QS901lIbP0NF<Y071H:P1U
BbX0GD8W04Tn7P11=A/0=RXJ030V7@0a:240=2hP03@b7@0d<aL803db7P80?C8P0P0l<Al0>@0k<1h0
>RlM03X_7@0j;ad0>2dK03T^700l;a`0?S8L04<d7@16=Ql0B3HN04Tg7`1==AT0ET4R05m=:@1IC2T0
B3lR03H_7@0Y92009B0V024T7@0P8a`0824I028R600W9AT0;BTM038_800g<B<0CCPU05M49P1]F2d0
OfPb08A/;P24J2T0SFdd09Uh@P2BM3h0UgU309Eg@@2@LS`0UGM10:>5C`2[SEL0ZH]E09QaAP1dDc00
C3PO03Tb800c<bL0<C4W03<a900i<bD0:bdR02X/8@0W:2009BHP02@U800202@T8P0;02DU9@0S91l0
92DP02DV800W:200:B/P02X/7`0/;R40;BlQ02l`8P0^;b400`0];R000`0_<280<C8T038c9@04038^
8P@0<BdQ0P0c:b000`0d;240=BdR03H^8`0203L_900403P`9@0f<280=c4S03La8`80>38T0P0i<bD0
300j=2H0=R`P03L]8@0h;R80>S0T03/a9@0m<bL0?S@X03le:@14=RT0@cDX048e9@80@SDT00@0A3LT
04Hj9017>bD0Ac/U0P14=B801016=B<0B3DT04Tf9@1<=bH204hg9`80B3TR00@0BSXS04`j901=>bD0
D3/V0P1B?2L01@1<>R80CC/S04dk8`1>?2@0D3hV0080DClW00<0DT0X05Q0:01H@2P01P1H@2P03P1C
?bL0DclV05A09`1F@RL0Ed@V05Q59@1IARD0FTLV05m6:01PAbT0HDPZ06=:;01UC2h0Idh`0P1YD380
401XCBl0Id`^06A;;@1PB2`0FdH[05M3:P1D@2L0DClW05Do:01C?RT0DSdX04hl:01;>RP0B3PX04Dh
:014=bL203he90@0?C@S0P0l<b8203Pb9P0403La9@0f<2@0=S0T03D_8`80=2hR100a;B@4038^9@@0
<bdQ0P0d;R8203D_8`0602l_9@0^;R@0;RhT02d]8`0/;280:b/Q0P0Z:R0402TY7`@0:RXP0P0[:b<2
02XZ8P80:BTQ0P0X:20202@V9@0602DW900U9b809RTR02HY8P0V:B009bXQ0P0`:Qh3034[7`<0<R`P
0P0_:b8202dY800502hZ8@0_:b80<BdT03<_9P0b:bD00P0c;2@00`0d;B<0=BlS03H`8P0203La8@80
<b`R00L0=RdT03Ta9P0l<RH0@3@V044d9012<R<0@S8R0080CcXU02h0C3XT04/k9019>R<0Ac/S04Hj
8P15>b80BCPT04/k901A?BD0ET4V05i59`1UB2P0JdXY06e<:@1QD380FTT[05918`1??R00DT4S05I5
9`1HAbT0EdHX05M8:@1EARL0DT@W04e29P19?b@0A3dS044j800o>B40CSP[054j:P1F?BL0GT<V06Q:
901bDB@0NUTV07mK9`1jIC00NV@b07YV=01hHcH0LUle06aJ=01TE300H50^0P1VC3406`1TC300Hd/_
061;;P1MBR`0FTT[05U8:P1V@bl0J4H]06i;;@1fDbd0PEd]08]V;`2CKc40VG<b09Uk?`2INT40V7Y4
09IjB02CN4T0SWE<08]bBP28L4X0SW0n099d@P2INDH0X7m:0:J3C@020:R3C00Y0:V2B@2MPTd0WH9=
09j2D02OPe<0X8AE0:64F02RQET0XXEK0::7G02RQeX0Y8MK0:N8FP2/S5d0/8iN0;BCH02hU680^Ie[
0;bUL`2oZWd0^jb30;:ZQ@2ZYhP0YZJ:0:BXS@2SUgl0YYQn0:^JOP2bWGh0_:9o0<JXPP3?[XD0dk26
0<nlTP3=^Xl0cKR=0<beR@3=]HL0d[N80=FkRP3H_8`00P3K_hl05`3J_Xl0ekZ>0=>fS03>/HT0bZf5
0<NYP`3@YWH0dJMe0<nZMP3>ZgD0c:ac0<R[K`34Zf/0`ZYZ0<FQK@38Y700c:Mb0<bUKP3:XFT0bJ5V
0<fSJ@3@YVX0cZQY00<0cjUZ00<0d:Y[0=6[K03B[6d00P3C[Fh02039Zfd0aZQZ0<6SI@2mWf40^YaN
0;VKG@2kWEl0_9iP0P2hUUH0202iUeL0^iUI0;nMG@33XF40ajEU0<VWI`3<ZV/0cJ]/0`3>[6d00`3<
ZV/0bZQY0<VWJ0020<>QH@090<>QHP35XfH0bJI/0=2]M@3F/g/0f[N10=fjPP3O_8@0h;f50080h[n7
00/0hKj60>2mQ@3O_8@0i<690>6nQP3M^X80fKIn0=ReO@3I]Wh0fkR00=biP@020=ZiQ00G0=^jQ@3L
^hH0gkj90>?2S@3WaY40jLRC0>O9U@3_dId0l=:N0>O9U@3P`Xh0h/B@0>?5T@3Q`hl0_ZAc0;NMK02_
UF@0Zi5P0:bBH@2]Tf80Zi5P0:R>G@2XSU/00`2WSEX0502YSe`0[99O0:jDH@2`UV<0/iMW0;BHJ02e
VFT0^9a/0;ZNKP2lX700_Z9b0;nSL`34Y7/0aJEn0<RZQ03A]980f[nQ0>78ZP3Rb[00hLVa0`3QcK82
0>;>/`<0hlnd02X0glne0>3@]P3Pd;H0h=2f0=k>]03Lc;80f/Z`0=S8[P3Ha:/0el>Z0=G1Z03C_jH0
dKfT0<nkXP3=^J00c;RO0<VdU@38/i@0bK:@0<R`S035[8@0`jQm0;nTM`2mXG80^YYa0;fMMP2oXWX0
`jN00<F[QP36[XX0aZn=0<N`SP3>]IL0ckRI0=>kW`3F`JH0f/J]0=g;/`3Pd;T0h]:k0>7Fa03RelD2
0>?HaP050>GJb03Wg<X0j=g;0>[Oc@3[h<h00P3/i=L20>gUf0@0k^KI00H0m>KI0??VeP3ci]H0lnKE
0?;UdP3bi]020?7Uc@P0l^?>203ah//80?;Na@<0m=o400<0lmk30?;M`P3bgL800P3ag<430>kIa080
km[50`3`flH30>kMc@030>oNcP3`gll0l=o?0080lN3@00@0k^7A0>gPd03]h=00kN3@0P3/gll20>_N
cP030>cMbP3]g//0kMk;0080k]o<0P3_h<d00`3`hLh0kMc:0>gLbP020>gLbP@0k=_90`3]fl<01P3/
f/80jmW10>[H`03Zf<00jMNo0>gD_P80k=Bl00<0jm>i0>[B]P3Yd[<00P3Yd[801P3[d[@0j]6c0>[A
/`3Yd;80j<na0>O>/080i/f_00H0jLRW0>S7YP3WaZD0i/FT0>C3XP3S`Z420>;1X0080>30V@3O_iP0
g[jG0=fmUP3K^i@0f[ZC0=ViTP3H^9420=ZeR`060=VdRP3G/XP0eK260=B_Q@3C[X@0dZf30P3A[882
0=2[P@@0cjZ00`38YG/30<NTNP<0aZ=i0P37Xh401P36XWh0aJ9l0<BQN@33X7H0`Yme0<6OLP80a9me
0P33WW@40<:ML`030;nLMP30WGL0`9eg0080`Iih0P32WgT01033X7X0`Ima0<6OL@31Wg420<2NL0<0
_ie_0`2oW7830;jKL@80_IY`0P2nVF`20;nJK@<0`9]^00@0`Ia_0;nLMP2oW7H0_iaf0P30WGL30<6N
N0P0aJ9l00@0aZ=m0<NTOP37Y7h0ajAn0P38YGl20<VVP0<0b:R20P39ZH<30<ZZQ080bZZ10P3;Zh80
1@3<[8<0cJf40<f]Q03=[H@0cJZ20080cZ^300D0cjb40=6^QP3B[hL0dZn70=>`R0020=6aR`070=:b
S03C/hd0e;B>0=FeS`3F]Y00ekNA0=ViT`020=ZjU0030=^kU@3L_9H0gKfG0080g[jH0P3M`:001P3N
`J40gl:R0>33X`3P`j<0hLBT0>;5Y@@0hLJX103RajT0203Xbj/0i<ZY0>?8ZP3Qb:X0glN[0=k9[P3O
bk00h<bc103Vc;<40>G;/PT0i<nd0P3Tc;820>G=/`<0i/jd00@0ilne0>[<]03Zc;@0j/bd0P3[cKD3
0>c>]PP0jm6f4`3[dkL20>[B]P<0jM6e00@0j]2e0>W?]03Yck@0jLnd0P3Xc[<20>O=/PP0iLb^203V
cJl80>O>/0030>C</03UcK40iLfa0080i/jb0P3Wck<0103Xd;@0ilnc0>O?/`3Wck<20>K>/P<0iLfa
203Wck<30>O>/080i/f_0`3Uc:h80>K9Z@80iLRZ00<0i<NY0>?6Z03RaJL00P3Qa:H0103P`jD0hl:O
0>?2W`3S`Yl20>;1WP<0hL2M00L0gKbI0=jmVP3O_Y/0gkjK0=jmVP3L^iP0f[VF00@0fKRE0P3H]i@4
0=NfT`<0ekN@0P3H^9430=ViTPP0ekN@203F]Xl0103D]8d0eKF>0=FeSP3E]Hh20=JfS`X0ekN@0`3G
]YL30=RgV080fKRI0`3G]i020=RhT@H0fKVB0P3H^9430=NgT080ekN>0P3F]Xd30=FeS0030=BdR`3F
/h/0e[>;00H0e[>;203D]8d00`3B/XT0dk>:0=>cRP020=BdR`80eKF<00<0e[J=0=BaR`3D/H/01P3D
/H/40=:_Q`80dJj60P3@[HD20<j[Q@80cjb600@0d:f70=6^R03A[XP0dJj80P3</8P01P3;[hL0bZj6
0<V]Q@38[8@0aj^30<JZPP80cZan00@0cJ]m0<bZO03<ZW`0bjUk0P3:Z7X80<ZWO@T0bJMi2037Y7X0
1P3;YgL0bZIf0<NSL`35XG40a:1`0<FQL@80aZ9b0P32WVX20<6MJ@<0`9aX0`2oVfL0102nVVH0_IUU
0;fII@2lV6@20;^GH`030;fII@2lV6@0^iMS0080^YIR00<0^iMS0;fII@2nVVH00`30W6P30<6MJ@80
`YiZ00<0`9aX0<6MJ@32WVX00`33Wf/00`32WVX0`IeY0;nLIP070;nLIP80_IYT0P2lVF<30;^HHP04
0;ZGH@2hTeh0^9=N0;RCGR_ooooo000Zooooo`060:EjA`2VNdP0YW]80:MlB@2XODX0ZGi;0P2ZOd`2
0:Z1C@040:V0C02XOd/0Z7m;0:MnBP80YWe90`2WOTX20:QoB`<0ZH1<402[PTh30:b3C`80[HA@0`2^
QE401P2/PU00[H=A0:n5D`2aQeD0/XQF0;67E@<0/8ID00`0/XQF0;F;F@2jT5h0`9IT0<FKJ@39Wfd0
bj5_0<JPN@38XW/0bZAm0<fWP03?ZH830=2ZP`040<n[R@3?ZhL0cjb60<n/PP80d:j100@0d:in0=2_
O03@[gX0dJj60`3B[hL20=>`R080e;690`3>[XD00`3?[hH0d;270=6aR0020=6aR0P0dK6:0P3?[hP0
103@/8T0dK6:0=>cS03D]8d20=FeSP060=6aRP3B/X/0d[:;0=>cS03D]8d0eKF>0P3F]Xl0403E]i40
dkF?0=:dSP3B]8h0d;:<0<Z/QP2oXG/0]iUc0:N0F@2PNE00UVm6099[@02CKD00UW1109I`?`2EKch2
09E`>@0309E`>`2EL3`0UFln0080U6ho00<0U6i109Qc?`2HLcl01P2HLcl209U_?@0409Q^?02GKC/0
UV`j09E[>@80U6Xh202AK3P209AZ>080TfTg102BJ3H8099W>P04091Z>`2>J3T0S6Hg08]U=P80RV@e
00P0RfDf08aV=`2=IS/0SFHk08eW>P2>J3T0SfTh091Z>@80T6/g00<0SfTj08iX>@2<ISL00`2:I3D0
102<ISL0SFLh08aV=`2<ISL308eW>0H0SVPi0`2=IcP208aV=`80TF/l0P2@JS/508mY>P0408eW>02>
J3T0SVPi08iX>@<0SfTj00T0T6Xk08QS;02;IRl0T6/f09=^>P2BK3/0SfTj08]U=P28HSD00`2=IcP2
08iX>@<0SfTj00<0U6lk09=^>P2AK3P00P2@JcL00`2AK3P0Tfhj09A_>`0208iZ>P80Sf/k0`2@K3`0
0`2AKCd0Tflo09=_?`0609=_?`80Tg0j00@0U74k09Eb?02ELS`0UW<m0P2GM3h509A`@0<0Tflo0P2F
LSh00`2GLcl0V7A009Ue@@0209]g@`0409ahA02JN4P0VWQ809YhB0D0VGM700H0UWQ209Mi@`2HNT@0
VG]509]mA`2MOdT209j0BP0609Af@02BM3h0SW0j08Y/=P27JC<0QVPb0P25Ic40302;Jbh0R6P_085S
;@1fFb`0JU4Y05e6901B?b40CCTP04Pn8`15>b00A3XO04Hl8@80B3hS0280A3XO03le6P0e;al0<RlN
02l/7@0/:Qd0:2PL02LY7P0V:Ah09bXQ02PZ700W:A/09RPJ02DW6@0V:1X09bTK02T[7@0Z;1h0<B`H
03D`700j=B40?STU03lj9P0l=b<0=c8N03@_6`0T9ah08bHM024T6`0P8aX07b8I020S6P0Q91/08RDL
0P0L7aP201dP6@807R4J0`0O8Q/0600T8QH09R@G02dW5`0e;AP0@3@J04Xm7@1C@b40EdLS06mI801d
GR@0NfHU07mZ:@1lIR`0LUXZ06I<:@1OA2T0BChN044e6`0f:QX0<2HM034X8@0d;R00=38M03@c5`P0
?C8N00@0?S<Q03db800m<R00?34O0P0k<1h203X_7@0e03H]700i;Q`0>c0N03lb7`14=B00AcLP04Xh
801;>B40C3LL05M28`1MCB/0FD`Y04U08`0g<200;RHT02XS:P0Q91d082<L020Q6@0R8QP09bDI02dY
7@0b;b00>38T04hi901HABL0KeX_085[<P25KBd0QFTZ08e]<P2JND<0TG<m09Mi@`2EMd40SW0j09Af
@02TQU00ZheG0:J8DP2FKdH0LE0]04Xf7@0h<Al0<c<W030`9P0b<2<0>S@V02/]8P0Y:b009bPP02DV
800T9B000P0T92804@0U9BD08R<N02<T7`0U9R009RLO02PZ7`0Z;1l0:bdP02`^800`<B<0;RlQ02d^
800/;Al0;BhP02h_8@0`<B<0<S<U00@0<RhR100a;B401P0c:b00=2`Q03@/8@0e;B80=RhS03L_9080
>30U0P0g<B<0100h<R@0>C<U03Tc9@0j=2H203/e9`0?03H/800g;B40>2hR03X`900k<BD0?C<W03hd
:00o=BT0ASP[04Dg:P13=RH0@C@S048e9013=R<0ACTS0080ASXT0P13=2403015=280Ac@S04Pe901;
=RD0C3DU04df9P18>B80BCXS04Xj8`1<>R@0CC/U050k9P80DS`W00H0C3XR04dk8`1=>b<0CcdU050n
9P1A?bL20590:0P0FClX0240DclW05<o9P1D@2L0ET8W05M49P1HABD0FDHU05Y79P1OARP0H4LY0658
:P1SBR`0ID`^06M><01YD380JU4c06M<;P1VBbd0HdX/0618;01KAR/0Ed<Z05E1:01B@2P0EClX05@n
:@1B?BP0CS`X04/j:018>2P0AcLX04@g9`0n=B@01P0m=2<0100l<b80>38V03Pb9P0g<BD203H`9004
03D_8`0d;R80=2hR02l[8P80<2`S00H0<BdT038^9@0c;bH0<blV03@`9`0b;20303<]8@80=2hR0P0e
;b<202h^9080;BdS00@0;2`R02/[8@0Z:R00:RXP100Y:Al402XZ8080:b/S0P0Z:R8202TY8@80:2PP
00H092DW02@V9@0T9RD09BLT02DW8P0V:B8202HY80<0<2XN0P0a:al3038/800902l[8P0^:R40;BTP
02`X7`0]:B00;b/R038^9@0c;bH0<R/U0080<b`T00<0=2dS03D_8`0f<2800P0g<B42038[8@0703D/
8`0h<2D0>c4U03lc9@10<b<0@C4R040`8002050k9P0c04dk9@1;>b@0BCXS04Hj8P15>B40A3XQ04Th
901<>R@0DCdU05Q09P1OA2L0ITLX06]::@1^C2T0GTd_05I59`1=?1h0BcXL04ln801D@bD0ED@V05A3
9@1FAbP0E4HY05539P1<@BD0AcdR048k8@0o>B40?SPP050h;01A>RX0F3dX06539`1[BbD0Le8U07aH
9020GBD0NF@_07US<@1iIC<0MF<e071O=01XFC80HE4]05a>:`1WCC@0ID/b06=;<@1OBRl0GDT^0080
FdX^05T0FT/^06I3;`1ZAS00Kd`^07MD;P23Gbl0SFPa09Ma<P2LMSD0VW`n09]m@@2IO4@0UWY809=h
B`2>MD`0Rg5<08Q`C02:K3X0Sfll09Ee@P2LNdH0XWm90:AoB02UOTD0Y7e409b1C02MPTd0WX9@09n3
D`2PQ5D0XHAH0::5F@2RQE/0XXML0::7FP2TQe/0Z8UK0:b<G@2aSel0]IAQ0;VEH`2eVfP0^:1`0;VW
N@2dYWl0Z::009nNP02HW8<0UIf509V9K`2KRVh0XHa]0:VAK`2dUW00_iad0<VRM`3?YWP0bKN70<Ne
P`37/h40ak5o0<VbOP3>]Gl0dkZ20=NlQ@3J_Xh0fKf>0=RlS@3E^8`0dKB:0<b_Q`37ZH<0aJN10<nS
LP3@Y7<0d:Qd0<jYLP3;Zg00ajY^0<>ZJP31ZFT0a:1/0<RTL03;YW40c:E^0<ZQJ@3:X6H0cJ=Y0=:U
JP030<jYH`80cjYT00P0d:]U0=6/IP3A[6H0dJaV0<RZK035YfT0`J=U0;fOH@80^YaN00X0_9iP0;fO
H@2fU5@0]YAD0;NEE@2hUUH0^iUI0;nMG@33XF40aJ=S0P3<ZV/04@3=Zf`0cZa]0<f[K03;ZFX0bJMX
0<RVI`37YFD0aZAT0<JTI@39YfX0cZ]a0=FbNP3L^H40h;f70=nlQ03P_HD0hKj60080hl2800/0h[n7
0>6nQP3P_HD0iL:<0>:oR@3N^hD0f[N10=VfP03J]h40g;V30=jkQ@030=ZiQ00F0=bkQP3P_hX0i<>>
0>O6T@3ZbI@0jL^G0?7CW`3be:00jL^G0>73S`3SaI40iLNC0>?5T@31YgH0^Im^0:nEI02[TF00[99Q
0:fCHP2ZT5l0YheL0:N=FP<0YXaI00X0Z8iK0:Z@G@2^U640/9IS0;>GI`2dV6P0]YYZ0;RLK02kWfl0
_J5a0P2oXg<02034Y7/0aJEn0<RZQ03A]980fl2R0>;8[@3Sbk40hLVa0`3Oc[820>3?/`<0hM2d0P3P
d;L0703QdKP0h=2g0=o?]P3McK@0f/Za0=S8[`3Ha:`0el>[0=G1Z@3C_jL0dKfU0<nkX`3=^J40c;RP
0<VdU@38/i@0bK:@0<R`S035[8@0`jQm0;nTM`2nXW<0^YYa0;fMMP2oXWX0`ZIo0<BZQ@36[XX20<J_
S@0:0<jeU`3?^9T0dk^O0=G0Y@3JaZd0gL^c0=o?^03QdKX0h=G30>7Fa080hmS600D0i=W70>KKb@3X
gL/0jMk<0>[Oc@020>_Uf@80k>KJ0`3]im/01P3^j=`0lnOI0??Wf@3bi]H0l^OE0?7VdP80lNK@00<0
l>K=0?;ScP3bhlh01P3bhlh80?;Sc0P0l]k50P3fhL@0103eh<<0m=o20?CO`P3cg/420?;M`0<0k][2
0`3_fl<20?3La0<0k]g=00<0kmk>0?3Oc`3ah=000P3ah=030>cPd080jmo?0`3Zg/h20>cLc080kMg=
00@0k]k>0>oOc`3_gll0l>3@0P3ah<h60?3Oc@<0l>3900<0kmo80>kNa`3^g/L00P3]gLH20>oI`P06
0>oI`@3^fKh0kMRk0>gH^@3/ekP0k=Rg0P3_f;T0103^ekP0kMJg0>cE]P3/eKH20>_D]@80kLj_00H0
k<f^0>[;[03YbZ/0j<VZ0>O8Z@3VajP20>G8X0040>C7W`3RaId0hLBL0=o2VP80g/6I00P0hkfF0>:l
U@3Q^i@0gkVB0=fgT03L]Xl0fkF>0=ZdS@<0ek6:0`3F/8T20=F_R0D0cJZ00P3<ZGl20<^XOP80bJF3
00@0b:B00<NTOP35XWX0a:5i0P33X7H30<FON0<0a9ig0P33WGH01030WGL0`Iih0<6NN032WgT20<>P
NP80a:5k00@0`Z1b0<6OL@31Wg40`Ima0P30WW020;nMK`80`Iif0P30WGD40;nLM0040;nJK@30Vfh0
`9]^0<2KKP80`Ia_0P32WG030<2MM`80`Iih0`32WgT30<NTOP80aZ=m0`35XW`01037Y7h0b:Eo0<RU
O`38YGl20<VVP080bZN10P39ZH<20<ZZQ0@0bj^50P3;Zh820<b/P`040<f]Q03>[XD0cZj50<n_QP80
dk2800H0e;690=FbRP3F/h/0ekB<0=ReS@3I]Xh20=FgT@040=JhTP3G^I<0f;ZD0=ZlUP80fkfG00H0
f[bF0=^mU`3K_IL0g;jH0=foV@3N`9X20=o1V`80gl:R00<0h<>S0>74Y03RaJD00P3SaZH00`3TajL0
hLRY0>78Z@020>78Z@@0h/VZ00P0i/b[0>G:[03SbZ/0hLRZ0>38[03ObZl0gl^b0>3</`@0i/bc103U
bk890>KA]P80iLfc0P3Vc[@30>O?]@030>S@]P3Zc;@0jlfe0080jlfe0P3/c[H20>g?]`P0jm6f4`3[
dkL20>[B]P<0jM6e0P3Zd;D20>W?]0<0j<jc00<0ilfb0>G<[P3Uc:h01P3Uc:h80>K=[`P0ilj`0`3U
cK400`3Vc[80ilnc0>S@]0030>S@]0<0ilnc0P3Vc[820>G=/@P0j=2d0`3Wc[020>K=[`<0iLb^203W
bZX20>G8ZP040>C7Z@3SaZP0h/FW0>;5Y`80hLBV0`3S`Yl20>;1WP<0hL2M00<0g[fJ0=nnV`3O_Y/0
0P3O_Y/00`3M_9T0f[VF0=VhU@030=VhU@80f;ND103G]Y<30=NgT080f;RA0`3I^I880=NgT0P0e[J?
103E]Hh20=JfS`X0ekN@0P3F]IH0103G]YL0f;NH0=VhV@3I^9T20=ZiVP80ekN@0`3H^9460=ViTP80
f;RA0`3G]i020=NgSP80e[J=103E]H`80=JcR`P0e;B=0`3C/hX00`3D]8/0eKF<0=JfS@020=JfS@P0
e;6;00@0dk280=:_Q`3B[hL0dZn70P3A[XH20=2]Q@040<j[Q@3?[8H0cjb60=2]Q`80dJj80P3B[hT2
0<faR@040<b`R03;[hL0bJf50<R/Q080aj^300H0d:j00<n]O`3>[7h0cJ]m0<bZO03:Z7X20<VWN@P0
bZMm2@39YgT80<NTO0080<bXN03:YWH0aj=c0<FQL@34X700aJ5a0<JRLP37Xg<20<:NJP80`IeY1030
W6P20;nKI`040;jJIP2mVFD0_IUU0;bHI080^iMS00<0_IUU0;bHI02kUf<00P2jUV800`2kUf<0_IUU
0;jJIP030<2LJ0<0`IeY0P32WVX00`2nVVH0`9aX0<>OJ`020<FQK@030<BPK031WFT0`9aX00P0_iaV
0P2mVV@20;bIH`@0^iQR0`2hTeh[ooooo`00:_ooool:0:ImB@H0Ygi:0P2UNdT0102VO4X0Yge;0:Uo
C@2ZP4h20:^1C`80[H=A0P2/PU040:^1C`P0Zh9<00P0Z7i<0:UoC@2ZP4h0[89@0:j4DP2`QU@0/HME
0;:8EP80/XUE0`2aR5@30;27D`050;B6DP2hRUH0_95N0<:HIP35WF`00P36X7402@35X7<0bjR20<bY
P`3>ZhD0cjb60=2]Q`3?[8H0cZ^50<fZQ0040=:_Q`D0dJj6203C/h`80=>cRPP0dK6:00P0cJn;0<j`
S03?/Hd0d;:>0=:dT03D]Y80eKNC0=JhU0T0e;JB00l0dkFA0=:dT03C]I40dkFA0<f_R`32Y800^Yah
0:^2HP2NMED0UVi:09M`A`2HLDH0U6ho09A_>`2HLcl00P2FL44309Ma@PH0V7930`2GLD8209I`@@0;
09Mb?P2FLCd0UG0l09A_>`2CKSX0TVdi095/>02@JcL0U6lk09=^>P2AK3P00P2@JcL00`2AK3P0Tfhj
09A_>`0209AZ>0<0TfTg0`2BJ3H00`2?IC<0TFLe099X=P0209AZ>003099X=P2AIcD0SfDc0080TfPk
0P2BIcX2095V>@80T6Dh202?IS8208US=0<0RV@e0`2;ICH00`2AJc`0T6Xk08iX>@0208eW>00308iX
>@2@JS/0TF/l00P0SfTj0P2DJ3L00`2CIcH0TVHe099V=@02095U=080T6@c202@JcL8095/>00708iX
>@2<ISL0RF<d08MQ<P28HS<0RfDf08iX>@09095[?080S6Ph00<0SFTi08iZ>P2?Jc/00P2@K3`00`2A
KCd0Tflk09=_>`0609=_>`P0UG0l00H0T6`l095]?@2BKSh0Tflo09A`@02FLT8209Mc@`<0Tg8m1@2D
Lch0202INdT0V7Y809MiA`2FN4H0UgU709QjB02JO4X0W7i<202INdD01P2DN4P0T7A408Y^?P25JCT0
PFDe07mS<`80P6@d00T0QVHc08=U<`1mHC80M5/b06YD;`1OC2`0ETDY05519`14>Ql00P12>1d09P14
>Ql0B3hS04Pn8`14>Ql0?cDJ03H_700f;ad0=2lL034^7@0_;Ah0;2dO02/[7`0Y:ah09BPG02HY600W
:QT0:2/J02T/6`0Z;A`0:bhM02`_7P0Y;1L0<38M038d7P0d=1`0>cTP04<o900o>Al0=C0C02<S6@0R
8QP07b0H01dP6@0K81X06b4M01`R7P0K92407R0O0P0M7a`00`0L7QT07B0I01lR6@02028U6P0I02<V
6`0V8ah0:RDO034[7`0k<b00B3`R05I7:01OCb/0IU@^06eL:01gIRh0Ofd_07eY:P1kIB/0NEh_06eA
;01Q@RH0DSX^044_8@0`:AL0;2hI02d`6`0^;AT0=RdL03lb8P03044d8@80@3<P0`0o<Ql403`a7`80
>c0N0P0j;ad0<00e:QP0>2/H03d`7@13=1l0ASHO04Le7@19=A`0B3@K05Tk8@1F?Ah0FTHQ05m@9`1A
Ab<0>38H02XW600[:240724K024T7@0T9Ad0:2HJ02/U5`0b:AP0?34O04@g901J@R00JDl/07YQ>025
JS/0Qf`e08Y^;`2@Lc40UWTc09IjBP2HNTP0U7I409Ad@@2NODP0[8UC0:f8D@2UP4T0NV@o05A59P0n
>280=SP[02db:`0_<R/0<c4U02dW6`P09BPQ0P0T9B00300V9b40:2TQ02T[800[;B00;BlR02d_8@0^
<280;c0R030a8`0c<B@0=30T03La9@80>C4V00<0=2hP03D_8@0g<B<00P0h<R@00`0g<B<0=BlQ03@^
800203Ta9P0403P`9@0g;b@0=blT03H^8`80=BdR00<0>BlS03X`900k<BD00P0l<RH0100k<BD0>S0T
03T_8`0k;b<203``900303da9@0n<RH0?c<W0080@3@X00L0?cHU03dd8`0n<b40@cHS04Tj9@1;>b@0
B3PQ0080AC<K2018=bL204Xj8`80Bc/T00L0C3`U04dm9P1>?RL0CShW054o:@1@?RP0CS`V0080CC/U
00`0CS`V050n:01A?bT0Ed<Z05E1:01D@2L0DclV05A09`1E@BP0Ed<Z05U5;01G?bL305Q0:080FD4Y
0P1J@RX01@1MAB<0GdLU069::01UCB/0Idl]00<0J50^0200Hd/W05m79@1K@b40G4<T0617:@1QAb`0
GD<Z05To9P1C@BT0DT0X050n:01>?2P0C3TX04Tf9`18=BH0Ac@V04@e8P13=240@3<R03hb8P0k<R<0
>C4T03P`8`0g<BD0>S@X03Tc9`0f<2@0=2hR03<]8@0d;R80=BlS03H`9080<blS00@0<RhR034]8@0a
;B40<2`P0P0_:al03P0_:RL0<2/X030[9`0a;2H0<RhU03<_900d<2D0=30T03La8`0e<R<0=30T034_
8`0^;R@0:b`T0P0Y;2D802TY8@80:bXU00<0:RTT02TX8`0X9b800P0V9B000`0U91l09bLO02LW7`03
02PX80<0:BTQ0P0]:B00100^:R40;b/R02l[8P0`;2<2034]90P0<2`S00P0<BdQ030/800_:al0;b/O
034]8@0c;b<0=S8V03Pd:080<S0T00d0<c4U03Da9@0i<bD0?3DU03he9010=bH0@cPV03hi8`10>R80
@cdU04Ho9@19?b@0BSlS0080BS`O0P1E=ad04`1E>Ql0Fd4V0659;@1OBRd0FD@W054n801<AbX0C4DY
04e3:01@@RP0DT0X05E1:@1G@BX0FT4[04e5<01;@bh0BSl[04Pk:018>BH00P18=bD0>P19=RD0ECXW
05Tm:01N@bP0ITTY06iA:@1fEbT0O5`Y07mP:P1mId00NFHn07MS?P1aGc/0JETg065B<@1JCB/0ETTY
0618;P1OAbd0GdL[05m8:@1QBRX0Hd`Z06I?;@1XDRd0K4PT06m<9P1gDRP0OeTZ08UQ;@2AJRl0Ufla
09]d<`2NOT/0WGe:09anC02HO4`0U7U:08ifB02:LT@0Qg14095gAP2BN4D0U7Y709ImA`2GOTH0Ugi5
09Em@@2DO400X7e509moAP2RPD/0Y8E?0:B6DP2SQeD0XXQE0:67EP2VS5/20:B:F@0]0:V?GP2`UVD0
/iUX0:nEI02ZT5l0[YYg0:jJN@2^VGX0[9Ml0:ZDO@2VT7/0XX]k09n8N02PQEP0YhIK0;26G02dQeh0
]8UN0;BBHP2fWfT0^:U`0;RYOP2iZWl0_Z^00<:]P037[h40c;210=2aP`3B/X<0dK^90=:kR@3B^hL0
d[R50=2eP03>/7X0bjae0<VZL`37[5l0aj]Q0<NYH`38YVL0b:E]0<ZTL`3=Y7P0cZAj00@0cj=T00D0
d:AU0=6UIP3BYVL0dZIW0<fWH0020<jYH`0:0<j/I@3>[FP0bJaX0<>ZI`2nYf<0^ZER0<JSG`34XEd0
`9mJ0;^ME`80^9]E02P0^9eF0;VNE`2mVe<0_9YB0;bJD`2lVED0_IYH0<2MG@32Wel0a:1R0<VXH`3<
ZfH0cjiY0=6`J`3@[fX0cZeX0<ZYI038Yf80a9iO0<JPHP38Y6H0bjU/0=2]L`3C/gX0e[N00=RiPP3L
_7l0gKf00>30Q@3R`XL0hl>:0>?2S03S`Xd0h/6<0=k3S03N`8X0fkf70=VjQ03H]h80fKF10P3J]H40
603L_8T0fk^80=blR@3M_HX0h<2=0>?3T03Wai@0jLVF0>_?W@3ZciX0ilbG0>C9TP3Qahh0gL>80=_1
Q03J`8<0cK>20;^QL02]Tf80[99Q0:jDH`2[TF00Z8iM0:V?GP80Zi9L01H0ZY1M0:Z@G`2[T640[Y=V
0;2EJ02bUf`0]9YY0;FKJP2fW6/0^Im^0;^QL02mXg80_jEd0<2VM@35Yh<0a:R30<V/RP3@]YD0fL2Q
0=o8Z@3ObZ/0gLR[0P3NcZd01P3Oc[00h<nc0>7@]P3Rd;P0h]2j0>?A^`80hLni0P3Rd;X09P3Pc[P0
g/bf0=_9/`3Jb;80e/:Z0=C0Y`3B_ZD0d;bQ0<fjW03:]iL0b;FD0<NdT`3:/I80bK2A0<R`SP36[XX0
a:b80<:ZQ031ZX40`:V00;ZNMP2kWgP0_Z9k0<6UP034YhD0ajZ:0<Z]S`3;[Y00bk2B0<fbU03@]iT0
eKfQ0=S3Z03MbK00hLfd0>7?]`3NdL00gm;10P3Pe<@01@3PelP0hMW<0>;Ld03SgM40h]kC00<0kN?I
00<0k^CJ0>oUf`3_iM/00P3`i]`80?7Wfa00m>GB0P3dhM800`3dhM00m>;>0?CRc0020?CRbP060?CS
b@3chL/0ln7;0?CPb03dg/H0mMg30P3efl00103ef[d0l]g00?;M`03bgL020?7L_`<0l=^n203^g<H2
0>gQd@80k>3@0`3[gll00`3Zg/h0l=kB0?3NdP060?3NdP040>_Nc@3/glh0k=o>0>cOcP80kN3?0P3^
hM001P3^h/`0kN7;0>gQb`3[glT0j]k80>WMa`80j=c6203]fL40103^f/40kMW00>gI`03]fL020>cH
_`80jmNn0P3Xd[X20>OA^@<0i]2h00T0iLng0>W?]P3Xc[D0ilfb0>K</@3Tbjd0h/VZ0>79Y`3Pb:H0
0`3R`Ih20>70W@<0h;nL00T0h;fG0=nlUP3N^iD0g;VC0=^hTP3I]Y00f;F?0=NdSP3G/8L00P3F[hH2
0=F^Q@0<0=B]Q03C[8<0dZ^20=:[PP3>/8`0cJn90<j^R03>[8H0cZ^30<jYO`3=Z7`0cZMl0`3:Y7d2
0<VSO0<0b:9k1@35YWX30<JWN`P0b:Eo0`38YG/20<NTNP<0aZ=i0P34XGL01033X7H0`Yme0<:OM@31
WW@20<2ML`<0aJ9h0P36XgT30<NTNP@0aZMk1035YWX40<nYPP@0d:Z300H0cJ^60<j/Q`3>[8L0cjf8
0=2^R@3A[hX20=:`R`080<f[Q@3>[8H0cjf70=6_R@3B/8X0e;:<0=FcS@3F]8h20=JhU080ekVE0`3H
^YH02@3I^iL0f[bJ0=^mV`3L_Y`0gKnM0=k0WP3O`Il0h<:P0>73X@020>35ZP<0hLJ[0`3Raj`30>C9
[080iLZ]0`3Vbjh20>G<[P80i/f_0`3Wc[000`3Xck40i/ba0>K</@060>K</@<0jLnd0P3Zd;D30>_A
]PT0im:e203Yd;820>C@]`040>GA^03Vd[T0i]:i0>OC^P80j=Bk203YeK`80>WE_@P0j]Jm203YeK`3
0>OC^P80i]:i0`3UdKP20>;>]@80hlnf00@0i=2g0>GA^03UdKP0i]:i203UdKP80>S@]0P0jM6i0P3Y
ckP20>S>]`<0ilff00<0i/be0>S@^03Xd;P0203Xd;P20>O?]`<0i/jf00H0iLfe0>G<[P3Uc:h0i<^]
0>?:[03RbJ/20>78ZP030>37Z@3Tbjd0i<^]0080hlZ/0`3RbJ/0103Qb:X0hLFP0>75X03QaJ030>;6
X@80hlNR103O_Y/40=jmVP80g;bF00<0g;^H0=^jV@3K^YT00P3J^IX20=ZhW0<0e[RF00<0ekVG0=Rj
V03I^iT00P3I^iT20=NfT`80f;ND103I^9D20=>eT@040=BfTP3E]i<0eKNC0=JhU080ekVE203F]Xl2
0=NfT`80f;ND0`3I^9D20=ZiUP070=VhU@3H]i@0ekJC0=NfT`3H]i@0fKRE0=ZiUP080=^jU`@0fKVB
0`3J^Y<0103K^i@0fKVB0=RhT@3F]Xl20=FeSP030=JfS`3H^940fKVB0100e[J?103F/h/20=FbRP80
e;6900P0d;290=6aRP3D]8d0eKF>0=JfS`3E]Hh0dk><0=:bR`<0dk><0P3B/X/30=6aRPP0d;2900P0
cJf60<j^Q`3?[hP0d;290<n_R03=[HH0bZZ30<RXP@@0c:Uo0P3;Z7h20<ZWO@030<VVO03;Z7h0c:Uo
0080cJZ000<0c:Uo0<^XOP39YW`00P39YgT40<ZXNP<0bjUk00H0aZ=k0<JSN@36XgT0aZAg0<JTMP36
Y7@20<JULP060<VWM`38YWH0b:If0<NUM@36Y7@0aJ=c0P34XW820<JQK@040<FPK034Wf/0`YeY0<6L
J080`9]W0P31WFT20<2LJ0<0_i]W00@0_YYV0;jJJP2mVFT0^iMW0P2jUVH00`2kUfL0_IUY0;jJJP03
0;jLK0<0_ie]0P30WVh20<:NKP<0`Ie]0`30W6`20;nMK@80_Ya/0P2mVf/20;bJJP80_i]W00@0_YYV
0;fII@2mVFD0_9QT0P2kUf<30;REGb_ooooo000Zooooo`P0YWe91@2WOTX30:ImB@060:EkB@2VO4X0
Yge;0:QnC02YOdd0ZX1>0P2[PDl20:f3D@80[89@0`2[PDl00`2ZP4h0Zh9<0:^2C0060:^2C0P0[H=A
102`Qe<40;68E0050;F7D`2iReL0_I9O0<>II`37Wfh00P38XW<01037XWD0bjR20<bYP`3>ZhD30=2]
Q`80cZ^52@3B[hL80=>cS0P0dk>:203A/HX01P3=[h/0c[2<0<naS@3@/Xh0d[B@0=BfTP80eKNC203D
]Y80403E]i<0e;JB0=>eT@3D]Y80dkFA0<j`S034YX80_9ij0:b3H`2OMUH0UVi:09M`A`2GL4D0U6ho
09=^>P2GLSh309I`@@80Ug521P2HLT<209Ma@P<0UW110P2FLCd0102EL3`0U6lk09=^>P2BKCT2095/
>00309A_>`2CKSX0TF`h0080T6/g00<0TF`h09=^>P2DKc/00P2DJSP309=Y=`<0TVPf00<0T6Hd095W
=@2BJ3H00P2CJCL00`2BJ3H0TFLe091V=00209=X>`80TVLj0P2AIST2091U>0P0SfDc0P2:I3D208]U
=P<0S6Hg00@0SFLh091Z>`2?JCX0SFLh0P2<ISL00`2=IcP0SfTj091Z>`0808mY>P80U6Xh0P2CJCL0
0`2BJ3H0TFLe095W=@02095W=@P0T6/g202AK3P00`2?JCX0SFLh08]U=P0208US=00308aV=`2@JS/0
TV`m00P0TF/l00H0SFTi08iZ>P2>JSX0Sf/k091/?02AKCd2099^?PP0Tflk202EL3`2099^?P80Tflo
00@0U71009Ea@@2FLT80UW920P2DLch409Ed?`80UWE000P0VG]909QjB02GNDL0UWQ609MiA`2HNTP0
VWa:09anC0P0VG]500H0U7Q8091dA02:KSh0QFTi085U=@1oHc<2081T=00<08MW=024IS@0OF4b07AK
<P1YDbh0GT/[05A39`1??bD0AC/P04<i7P12>1d0A3XO0P18?R<02P14>Ql0?cDJ03H_700f;ad0=2lL
034^7@0_;Ah0:b`N02/[7`0Y:ah202HY600402LZ6@0X:aX0:B`K02X]7080:bhM0140:RdH030b7@0b
=1h0=3@L03Xh7`13?b@0?cTO03D`4`0S8aT08R8H01lP600M81T06b0J01/Q7@0L8Qh06b@Q01hP7`02
01dO700301`N6@0M81T07b8I00808RDJ01T08bHK02LT7`0Z9Qd0<B/M03Ta7P15>Al0D44P05U99@1O
CBD0J5LS07=R:P1lJR`0O6PY07]U:`1jGc00L5@_06E6:P1B>Rh0@BlQ030Y5`0/;QT0;C0K02h]6@0f
;A`0?c8R0080@C@Q0`10<b0303lb7`0403db800l<Al0?34O03`a7`80>c0N0P0j;ad01P0g;1X0>RdJ
03`_7011<Qd0ACDN04Le7@80BSHM02P0F3dR05Po801LB2<0GU0Y0518900h<QP0:BHG02TV8@0M8Q`0
8RDN02DV7P0X9QX0;2HH038Y600l<Al0A3LT05Y27P1YCbX0NV4h08I/>`28KCH0Rfhb099e<`2GNSH0
Ug];09QjB02DMT@0U7A109mnB@2]RU@0[HQA0:AoB01hHSd0Dd@U03dg8@0f>2/0;S</02lb:`0c<BD0
;BLK200U:2401`0T9B009BHQ02HW8@0X:B40:R`Q02/]800];b800P0^<282030a8`0803<a900d<2@0
=c4U03P`9@0i<BH0=2hP03D_8@0g<B<203Pb900303La8`0e;b40=2hP00<0>30U00<0=blT03H^8`0f
;R<00P0e;B800`0i;b<0>S0T03/a9@0203`b9P0403/a9@0j<2@0>BlS03/_8`80?30T00<0?C4U03hb
9P0o<bL00P10=2P01`10=bH0?SDT040e8`14=b@0Bc`W04dm9P19>B800P16=1`804Pg9`80BCTR00<0
BSXS04/k901<?2D00P1>?RL0101??bP0DClY050n:01>?2H204dk9@0<04hl9P1@?RP0DClY05E1:01D
@2L0DclV058n9@1C?bH0E40W05I2:@1HA2/0F40X0`1I@BT205Y2:P80Fd<[00D0GDDS05m79@1RBRP0
IDd[06M?;@0306Q@;P0@069<9`1NAbD0Fd@R05a59@1OB2T0H4P/05a4:P1H@2H0Dd4Y0590:01A?bT0
CS`V04`j9P1:=bH0B3DV04Ld9@80A3DR00T0@C@S03lc8`0k<R<0>C4T03P`8`0g<BD0>C<W03Pb9P0f
<2@00P0d;R80100e;b<0=S0T03La9@0d<2@203<_8`80<RhR0P0a;B401`0`;200<2/X030[9`0a;2P0
<B`V038^9@0c;b@00P0d<2@01P0g<B<0=C8S03@`900a;b<0;RhT02//9080:B`U200Y:B4202/Z9@06
02XY900Y:2<0:2LR02LV8@0V9B009B@O0P0W9al302PX80<0:BTQ0P0]:B00100^:R40;b/R02l[8P0`
;2<2034]90P0<2`S00P0<BdQ030/800_:al0;b/O030/800b;R80=30T03Da9@<0<S0T01`0=C4U03Tc
9@0k=2@0?SDT040g9P12=bD0?CPR040j9012?2@0AChT04Pn8`19?R80BS`Q04Tk7P1E=ad0DcPM05Hk
801L@RL0H4P/05i9;01GA2H0DChP04Y39`1;A2P0CD<X0553:@1C@bX0ET8Z0P1F@2T01@1<A2l0BT8]
04Xo:`18>bP0B3TV0080B3LU0140BCHU05Hk:01H?BP0GT<X06I9:@1]CbT0MEHX07YL:P1mGBX0MElh
07AN=`1aGCP0KU`h06QH=P1SE3<0GTl^05]>;P020618;P0W05m7:`1OB2T0H4TY069;:@1UCR`0IU0[
06i<9`1bCbT0N5D[089N;P2;IS40UFhc09ad=P2PNCP0Wgm<09inB`2MOdd0VGe=09EjB`2>MTP0Rg=5
08M`A02=Ld80SgE2095gA02DNdD0UGa409El@`2EOD40U7a00:1mA@2OOdH0XX5;0:B5C`2TQU80XhME
0:67E02QQeH0YXaK0080Y8YI01d0Z8iM0:fCHP2_UF@0Zi5P0:N=G02TTFL0YI9Z0:FAK02TT6d0XXe^
09n:K@2KQV/0VXA/09n2EP2WQUT0/8UN0;F:G`2fSF40]9AS0;FNJP2gYW00/Z=h0;JUNP2jYg`0_jYm
0<F]O`3;/840ck>40=:cQ0020=:lR`0F0=:kR@3B^8D0ckAo0<f_N@38ZW@0ajQa0<V/J037ZVH0aZMV
0<JTI`36XfT0bJA]0<fUL@3>YW<0bZ5S0<^RI03<XfD0cZEW0=2WJ@3BZF/0djY/0=B[K@<0d:Y[00l0
cZY/0<^/K038ZV`0`ZUY0;nWJ@2nYVP0b:9T0<BPHP32WV00_ieN0;bMG@2kWEd0^imN0;bPG`30WUH0
0P2oWEH06P30WET0`IiL0<BQH@37XfD0b:AV0<^ZI`3=[6T0cji[0=6`K@3@[f`0cJaY0<VXI@37YV<0
a9iP0<JPHP38Y6P0bjU/0=2]L`3C/gX0e[N00=RiPP3K^gh0gKf00>30Q@3S`hX0i<>=0P3Ua8l02@3T
`i00h<F>0>32S03M_hT0fkb60=ZiQ03K]h<0fkJ20=bgP`030=fmRP0]0=noS03Q`Hh0iLFB0>S8U@3[
biP0k=2N0>_?W@3YcYT0i/^D0>;8S`3OaHX0gL>80=_1Q03@]XD0_J=b0:jDH`2]Tf80[YAS0:Z@G`2W
SE`0Z8iM0:^BG02ZTE/0ZHmL0:V?GP2ZSf00[I9U0:nDI`2`UFX0]9UZ0;FJJ`2fVf`0^Ii_0;^PL@2m
XW<0_jAe0<2UMP35Yh<0a:R30<V/RP3@]YD0fL2Q0=o8Z@3ObZ/0gLR[0080g/j]00H0glj`0>3?/`3Q
d;H0h]2h0>;@^P3SdK/20>7?^@80h]2j02H0h<jh0=k<]P3KbK<0f/Rb0=K2ZP3D`:L0d[jU0=2lX@3=
^Y`0b[NG0<ReU037]9<0bK2A0<R_T037[hd0aJf90<>[Q`31ZH<0`:V00;nXO`2jWWH0^img0;fQNP31
YH00a:N50<NZRP39[8`0bjj@0<^`TP3=/Y@0d;NI0=FmX@3H`jP0gLV`0>7=]03QckL0h=300=oB`@80
hMC400H0hMG70>;Hc03Sflh0hmgA0>CNdP3/h]P20>gSf@030>kTfP3_iM/0knGK0080l>KL203aim/@
0?CUdP80m>?C00@0m>?A0?CSc`3di<d0m>C=0P3di</01P3dh/h0ln7;0?GPb`3eglP0m]k60?GM``80
mM_00`3cg/<20?;M`P<0lMc1203_gLL20>kQd@80kN3@103/gll80?3NdP@0k=o>0P3]h<l20>kQd005
0>oSc@3^h/`0k^;<0>gQb`3[glT00P3Zg/P00`3YgLL0km[50>oJa@060>oJa@<0k][10P3]fL030>cH
_`<0j]Bl0P3Ydk/30>SB^P080>[B^P3Zd[P0j=2f0>O?/`3UcZl0i<f]0>?<ZP3RbjT30>?5X`80h/BR
0`3Q`j401P3S`9X0h[nI0>6nV03P_IL0g[^E0=fjU080fkRB00<0gKN@0=bfS`3L]Xl00P3K]Hh0303J
]8d0fK><0=RbR`3H/X/0dK>?0=2bSP3A/H/0d;290<n^Q@3?[880d:^10<nZOP80bjR20`3:Yh430<VV
P0<0aZMk1@37Z7`80<VVP080bJIl0P38YG/40<NTNP030<RUN`37Y7X0ajAj0080aZ=i0P35XWP00`34
XGL0aZ=i0<JSN@020<JSN@80ajAj0P38YG/60<VZOP80b:Um0P3=ZX@20<j[Q@80cjb60P3@[HL01P3?
[HP0d:j90=6_RP3A[hX0d[2;0=>aS080e;:=0P3A[hT01P3C/H/0e;:<0=JdSP3G]Hl0f;J@0=VgT@80
f;bG0`3I_IP30=ZnV@80g;nO00H0gL2P0=k1X@3O`Z80h<>S0>74Y03RaJD20>76Z`80h/N/0`3Sb:d0
103TbJh0iLZ]0>G:[@3UbZd20>K;[P<0ilb_0P3UcZl20>K?/0<0im2a00<0j=6b0>K>]03Vc[@01P3V
c[@30>WA]`80j]:h0`3[dkT90>SC^0P0jM:c0P3UdKP20>KB^@040>OC^P3Xe;/0j=Bk0>SD^`P0jMFl
203YeKd80>[F_@P0jMFl0P3Xe;/20>OC^P<0i]:i00@0iM6h0>??]P3SckH0hlnf0P3Td;L00`3UdKP0
i]:i0>KB^@080>GA^0P0j=2d203YdKT30>S@^080ilng0`3Vc[H;0>S@^080ilng0`3Vc[H30>C;[@<0
hlZ/0P3RbJ/20>C;[@80hlZ/103RbJ/80>;6X@80h;nL0`3O_Y/30=jmVP80g;bF00<0g;^H0=^jV@3K
^YT00P3J^IX20=ZhW0030=JhUP3G^IL0ekVG0080f;ZH0P3I^iT00`3J_9X0fKRE0=VhU@040=VhU@80
f;ND0P3D]Y820=FgT`80e[RD0P3G^ID80=JfS`040=NfT`3H]i@0f;ND0=RgU080fKRE0`3J^IH01`3I
^9D0f;ND0=NfT`3G]Y<0f;ND0=VhU@3J^IH0203K^YL80=ZjT`030=ViTP3H^940e[J?0080eKF>00<0
e[J?0=RhT@3I^I80403F]Xl0103G]8`0e[>;0=JcR`3F/h/20=FbRP80e;6900L0d;290=:bR`3D]8d0
eKF>0=JfS`3E]Hh0e;B=00@0dk><0`3B/X/20=6aRPP0d;290P3>[XL01`3?[hP0d;290<n_R03=[HH0
bZZ30<VYPP3=ZX000`3<ZGl20<^XOP<0bZMm00L0bjQn0<bYO`3=ZX00cJZ00<bYO`3;Z7h0bZMm00T0
bZQj00H0aZ=k0<JSN@36XgT0aZAg0<JTMP36Y7@20<JULP060<VWM`38YWH0b:If0<NUM@36Y7@0aJ=c
0P34XW801@36XFd0aJ1/0<FPK034Wf/0`YeY0080`IaX00<0`9]W0<6MJ@31WFT00P30W6P40;nKI`03
0;jJJP2mVFT0^iMW0080^YIV00<0^iMW0;fIJ@2nVVX00`2nW6`20;nMK@<0`9i^0`32WVh20<6MK@<0
`9a/0P2oWFd20;jLK080_I][0P2lVVX20;nKI`040;jJIP2mVFD0_IUU0;bHI080^iMS0`2hUEl[oooo
o`00:_ooool80:ImB@040:V0C02XOd/0Z7m;0:MnBP80YWe90P2UO4P01P2VO4X0Yge;0:MmB`2XOT`0
ZGm=0:Z0CP80Zh5?0`2/Pdl20:^2CP<0ZX5=202[PT`01@2`QU@0[hEC0:n5D`2^Q580[89@0080Zh5?
00D0ZX1>0:j5D@2^QE40[hIB0;27D`020;68E080/XUE0140]XQD0;Z<F02oU640aI]Y0<VQL03:Y7D0
bjEf0<ZUN03<ZH<0cJZ40<n/QP3@[HL0dJj80=2]Q`3?[8H0cZ^50=:_Q`080=>`R0P0dk><203C/hX8
0=6aRP80c[2<00H0ck6=0=6cS`3B]900dkFA0=BfTP3E]i<80=BfTP030=NiU@3E]i<0e;JB0080e;JB
00`0ck6=0<JXQ02nX7`0[XEU0:1gE`2FKTX0Ug1709M`A@2CKCh0Tfhj09Mb?P2EKd0309I`@@80Ug52
102HLT<209Ma@P<0UW1100H0UFm009Ia?@2EL3`0UG0l09A_>`2CKSX2099]>@04095/>02CKSX0TVdi
095/>080T6/g00<0TF`h099]>@2CKSX00P2DJSP309=Y=`<0TVPf00<0T6Hd095W=@2BJ3H00P2CJCL0
0`2BJ3H0TFLe091V=00209=X>`80TVLj0P2AIST2091U>0P0T6Hd0P2<ISL208eW>0<0SVPi00@0SfTj
08iX>@2>J3T0SFLh0P2<ISL00`2=IcP0SVPi08iX>@0808mY>P<0UF/i0P2DJSP409=Y=`P0T6/g202A
K3P00`2AJc`0SfTj08eW>00208aV=`0308mY>P2AJc`0Tfdn00P0TF/l00H0Sf/k091/?02@K3`0TFdm
099^?P2CKcl209A`@0P0Tflk202EL3`00`2CKcl0U71009A`@00509A`@00309Ed?`2FMD00UWE00080
UgI10`2HMd80202INdT0V7Y809MiA`2FN4H0UgU709QjB02JO4X0W7i<202INdD01P2DN4P0T7A408Y^
?P25JCT0PFDe07mS<`80P6@d01T0R6Pe08EW=@1nHS<0M5/b06UC;P1LBBT0DT4U04dm8`15>b00@cTN
044g7013>Ah0AcdR04Pn8`14>Ql0@3HK03L`7@0f;ad0=2lL034^7@0^;1d0:b`N02XZ7P0X:Qd09RTH
00809bXI01H0:2/J02T/6`0Z;A`0:RdL02/^7@0Z;AP0<38M038d7P0c<a/0>SPO048n8`10>R00=S4D
02@T6P0S8aT0824I01dP6@0K81X06R0L01/Q7@0J8b007R0O0P0M7a`00`0L7QT07B0I01lR6@02028U
6P0J02<V6`0Y9Ql0:bLL034[7@0h<1/0@SLK04dn7@1DAAh0FTPP06=B7P1_GRH0NVPZ07]W:01lIR`0
O64b079F<@1VAb/0DSX^044_8@0`:AL0;2hI02d`6`0^;AT0=RdL03lb8P11=243040c8080?c8O0P0n
<Ah303db8080?34O0`0k<1h0<00j;ad0>bhK03`_700o<1/0@c<L04Le7@1<>1l0CCTP05Tm9@1J@b@0
GT`X05i@:@1?Ab<0=c<J02LU600S8Qd07b@N02<V7`0V9al0:BLK02`V600b:AP0?34O04@g901I@A/0
JE0X07YR=P27KC`0RVlh08ia=`2EMcL0Vghl09QlC02INdT0U7I409Ad@@2POdX0[X]E0:b7D02QO4D0
MV0k05528`0l=R00=SP[02hc;00_<R/0<c4U02`V6PP09BPQ00T092DP02DV8@0V9b40:2TQ02X/8@0/
;R40;BlR02h`8P0_<B<00P0`<B<00`0c<B@0=30T03La9@0203P`9@0303@^800e;b40=c4S0080>38T
00@0=c4S03D_8@0d;R00=c4U0`0f<2@303D_8`0403@^8P0i;b<0>S0T03/a9@80?38V00@0>c4U03X`
900i;b<0>blS0P0l<2@00`0m<BD0?S8V03lc9`02040d:007048i:010=bH0@SLU04Hi9P1<?BP0CclX
04/k900204Pf7PP0B3LW00H0AcLP04Ph8@19>B80Bc/T04dm9P1>?RL20510:@03054o:@1@?RP0CcdW
0080CS`V00@0CcdW050n:01A?bT0DclV0P1B?RD00`1A?B@0DShU05<o9P0205E1:00405U1:@1J@RX0
FT8Z05Y2:P80Fd<[0P1LA2`01@1MAB<0GdLU069::01UCB/0ITh/00<0Idl]0100HT`W05m89P1MAR@0
GDHV05i7:01NARX0G4@Z05U19`1D@bT0Dd8X054o9`1??BL0CC/W04Xg9P19=RD0B3DV0P15=R<01P11
=2<0?c<S03`c900i<B@0>30S03La9@80=S0T0`0e;b<0100f<2@0=c4U03Pb9P0e<BD303@`90<0<blS
00L0<RhR030[9`0a;2P0<B`V038^9@0c;b@0=30T0080=C8S00H0=c4S03Db8`0d<2@0<BlS02h^900[
;2@202T/9@P0:BTQ00H0:bXU02XY900Z:B@0:BPS02PW8P0W9R4202HU80809bLO0`0X:20302TY8@80
;BTP00@0;RXQ02l[8P0_:b80<2`S0P0a;B@8030/8`03034]8@0`;200;b/O0080;b/O00<0<2`P034]
8@0b;R800P0a;b<0900b<2@0=30T03Pb900k=2@0?SDT03lf9@12=bD0?CPT03li8`10>R@0@c/T04Hl
8`17>b40BC/P04Pj7`1C>1d0E3TN05Lm8P1K@bL0GDP[05]8:P1F@bD0CchP04To901;@BH0Cd<Y05=5
:`1EAB`0ED<[05E1:@1C?bL0BT8]04U1;018?BT0AcXW04Pi9P80BCPV0240BcPW05Dl9P1H@2P0GD<X
06=9:01ZCRT0L5<Y07IG:@1iFR/0KED_06aF;`1]Ec80JeLd06QE=01TE3<0HE8a05m@<@1QBBl0H4P^
05m7:`1OB2T0GdPX065::01SC2X0I4hY071>:@1dDR`0NeP^08IR<P2?K3H0V7@h0:1j>`2TOSd00P2P
P4d0302NP4h0VWi>09EjB`2?MdT0Rg=508QaA@29KCd0Rflm08ib@02AMT40TgQ109Aj@@80UG]000`0
X7e509moAP2RPD/0XhA>0:B6DP2RQU@0X8IC0:26E@2VS5/0YH]J0:B:F@2UReX20:R>G@0c0:F;FP2Q
QeH0VXID09^7E@2KQUL0VhII09Z5FP2HPUT0Uh5J09EoF02PPE80YhMH0;2;GP2dSV40/hiQ0:n@H@2^
UfD0/9aY0:bIK`2_W780]J1e0;^TN031ZG/0bJio0<fbP`3@]8@0d[f@0=6lS@3@^X/0cKF50<^aP037
ZgT0aJMc0<:TL03:Zg80ajQ_0<BTJ@34XFL0`j5T0<NSI@3<YVL0cjUZ0<VQI03:XVD0c:AW0<nWJP3A
ZF`0dj]^0=B/K`3E[G00dJah0080cjYf00@0bjMc0<JUL033Y6h0`J=]0P2oY6d02035WVL0a9eV0<6L
I@30WFD0_iaT0;jNI@2nWfH0_j1W0P31WeP07031WUX0`YmM0<FRHP38Y6H0bjM[0<fYK@3<ZVX0cJ][
0<n]K@3@[Vh0cZa/0<^YJ@38YVH0aZAT0<BNH036Wf@0aj=W0<^XKP3A[WH0e;=m0=JgP@3I^X@0g;b1
0=jnP`3Q`HP0i<>=0>K5S`3WaY420>O6T`060>?8T@3SaHl0gl6;0=fnR03L^hH0g;R40P3M^8@30=k0
SP0@0>32T03SaI<0ilVG0>[<VP3]cid0km>S0>kBX03[cid0j<fH0>G:T`3Rb8l0glF:0=k4R@3D^XT0
`JMf0;6GIP80[iET01/0Zi5P0:N=G02XSUd0ZY5K0:V@FP2YSe`0Z8iM0:V>G`2[T6<0[I9U0:nDJ@2d
VF`0]IY]0;JKKP2iWW40^j1c0;fRM@2oY7L0`:Eh0<FWP`34Z8<0bJb:0=2fU@3I`:40glRY0=o:Z`3M
b:/00P3NcZd01P3Oc[00h<nc0>7@]P3Rd;P0h]2j0>?A^`80hLni0P3Rd;X0303Pc[P0g/bf0=_9/`3J
b;80e/:Z0=C0Y`3B_ZD0d;bQ0<fjW03:]iL0b;FD0<NdT`80ajj?00@0aJf;0<>[Q`32ZXH0`:R20P2n
Ygh04P2iWW<0^img0;fQN@30Y7d0a:R30<NZR039[8`0bZf=0<^`TP3=/Y@0d;NI0=FmX@3H`jP0gLV`
0>7=]03QckL0h=6n0>7B_`80hMC300H0hMG50>7Hb@3Rf/d0hm_>0>?Md@3[hML20>cRf0030>gSf@3^
i=X0knGK0080l>KL203aim/80?;Ue0P0lnKE0P3ehmD00`3ei=@0mNCB0?GTd0020?GUcP060?GUc03d
hll0m>??0?CRc03ehLT0mMo70P3fg/@0103fg<40lmo60??OaP3cglH30?;Na@80lMg4203`g/P30>kQ
d080kN3?0`3/glh80?3Nd0<0k=o>0P3]h<l30>kQd080l>?@00@0kn;?0>kQcP3]h<d0kN3=0P3/gl`8
0>oMa`80k]c40P3]fl<20>cJ`P80jmW100@0kMW10>cH`03/f<00k=S00P3[ekl20>[F_P080>gD_P3]
eKd0k=Bl0>_C^@3YdKD0j=6b0>O@/03Vcjl30>O:ZP80i/VY0`3Ub:P20>K5XP060>G4X@3T`j00h/6N
0>70W@3P_i`0gkjK0P3S`9X01@3R_iT0hKjH0>6nV03Q_YP0h;fG0080gkbF00P0eKRF0=BhT`3D]Y80
eKF?0=BbS03D/HT0dk260=F`QP<0d:f70`3?[8H20<j[Q@D0bZZ10`39ZH080<^XPP040<^XP03:Ygl0
bZMo0<ZWO`80bJIn0P38YGd0103<ZH40bjR00<^XP03;Z8030<ZWO`030<VVOP37Y7`0b:Em0080b:Em
0P39YWh20<ZWO`P0c:b30P3>ZhD01P3?[8H0dJj80=:_R@3C/8X0e;6;0=FbS080dk:?00@0e;>@0=Fd
T@3E]940e[FB0P3G]Y<0203F]I80ekJC0=RgU03I^9D0f[VF0=^jU`3L^iP0gKbI0`3M`9h20=k1W`<0
gl:P00H0h<>S0>74Y03Qa:@0h/FU0>?6YP3TajL20>G8Z080h/R]0P3SbJh30>C:[`80iL^`0`3Vc;42
0>O=/P80j<jc0`3Wck<20>S@]0<0jM6e203Xd;P20>[B^P<0jm>k0`3/e;`90>SD^`P0j]:f103WdkX2
0>SD^`80jMFl203Ze[d80>[F_PP0jmNn203Ze[d20>WE_080j=Bk0`3WdkX00`3Vd[T0i=2g0>C@]`03
0>GA^0/0i]:i203YdKD80>[B^P<0jM6i0P3Xd;P30>O?]`X0jM6i0P3Xd;P30>O?]`030>K>]P3SbZ`0
hlZ/00<0i<^]0`3Uc:h30>C;[@80hlZ/0`3RbJ/20>G8YP040>C7Y@3SaZ@0h/FS0>;5X`80hLBR0P3Q
`9d20>2oW080gkjK0P3N_IX20=fmU`030=flV@3L^iX0g;^J0080fkZK0P3K^Id40=RjV080fK^I0P3J
_9X01@3L^iP0fkZG0=^jU`3J^IH0fKRE0080f;ND00<0ekJC0=FgT`3E]i<00`3F^9@30=NiU@P0ekN@
0P3H]i@20=VhU@<0f[VF0P3K^YL01P3J^IH0fKRE0=RgU03H]i@0fKRE0=ZiUPT0fkZG00D0gKfF0=bl
U@3L_9D0fk^D0=ZjT`020=ViTP040=RhT@3I^I80f;RA0=NgT080e[J?00<0ekN@0=RhT@3I^I80203G
]i080=JfS`<0ekB<0P3F/h/30=FbRP030=6aRP3B/X/0e;B=00<0eKF>103D]8d20=>cS0<0d[:;2@3A
/HX40<n_R0040<j^Q`3=[HH0bj^40<ZZP`<0cJZ00P3<ZGl30<^XOP030<ZWO@3;Z7h0cJZ00080cZ^1
00<0cJZ00<^XOP3:Ygd02@3:Z7X01P37Y7`0ajAj0<NTNP37YGP0ajEg0<NUM@80ajIc00H0bJMg0<RV
MP38YWH0ajEe0<JTM035Xg<20<BRLP80aJ1/00@0a9m[0<>NJP33WVX0`YeY0P31W6P30<6MJ@80`9aX
0`2oVfL00`2mVFT0_9QX0;^GI`020;ZFIP030;^GI`2lV6P0_IUY0080_Ya/0P2oWFd30<2NKP030<6O
K`33Wfl0`Yi^0080`Yi^0P31WFd20<2LK080_ie]0P2nW6`20;fKJ`80_9YZ0P2oVfL0102nVVH0_IUU
0;fII@2lV6@20;^GH`<0^IIP:oooool002[ooooo202VODT20:V0C0030:QoB`2WOTX0YWe90080YGa8
00@0Y7]70:MmB`2XOT`0Z7i<0P2YOdd20:Z0CP030:^1C`2/Pdd0[8==00<0Zh9<0`2ZPD/80:^2C0<0
[XAB0P2]Pe430:b2D0060:b3C`2]Q500[XEA0:n6DP2`Qe<0/XUE0P2cRUH0402fR5@0^heI0<2EHP37
WF/0c:Ac0<fWN03>Z7T0cJQk0<fZQ03>ZhD0d:f70=6^R03B[hT0dJj80=2]Q`3?[8H40=>`R0D0e;69
203C/h`80=>cRPP0dK6:00H0c[2<0<naS@3@/Xh0dK>?0=:dT03C]I4:0=BfTP030=RjUP3F^9@0e;JB
0080eKNC00/0d;:>0<RZQP31Xgl0/8MW0:9iF@2GKd/0UVm609I_A02BK3d0TVdi09Ia?@0209E_@0<0
UW111P2GLD8309I`@@80UFm00P2EL3`209A_>`80Tfhj0`2BKCT6095/>003099]>@2DJSP0U6Xh00<0
TfTg0`2BJ3H2095W=@@0TVPf0P2AIcD209=X>`80TVLj0P2AIST2091U>0P0T6Hf0`2>J3T208mY>P<0
T6Xk0P2=IcP408aV=`80SFLh202?JCX409E]>PD0U6`i202@JcL8095/>003099/?@2AJc`0SfTj0080
SfTj00<0TF/l09=]?P2EKd00202AJc`01P2AKCd0TVhn099^?P2CKcl0U71009Ea@@80UW92202DL3`8
09E`?080UG510`2DL40309=_?`0409Ie@02GMT40UgI109Qg@P80VGQ30P2JND@0202INdT0V7Y809Mi
A`2FN4H0UgU709QjB02JO4X0W7i<202INdD01P2DN4P0T7A408Y^?P25JCT0PFDe07mS<`80P6@d01P0
RFTf08IX=P1nHS<0M5/b06QB;@1KB2P0DD0T04/k8@16?240@cTN044g7013>Ah0AS`Q04Lm8P14>Ql0
@CLL03Pa7P0g<1h0=C0M034^7@0^;1d0:b`N02TY7@0X:Qd202LZ6@80:2/J0P0Y;1/202X]700A02/^
6@0a<ah0<C<M038b6P0i=ah0@ShS040j800g<QD09BDK02<S6@0P8AT07B0I01/P6P0J81`06b4M01XS
800N81l00P0M7a`00`0L7QT07B0I01lR6@02028U6P0I02<V6`0Y9Qd0;2PM038/700j<Q/0ACXL0512
7`1HBB00GTdR06AC7`1`GbL0NfT[07aX:@1lIR`0Nf0a071D;`1TABT0DSX^044_8@0`:AL0;2hI02d`
6`0^;AT0=RdL03lb8P03040c8080?c8O0`0n<Ah303db80<0?34O0P0k<1h0<00m<R00?C0M03`_700o
<1/0@S8K04Le7@1=>B00D3`S05Pn9`1MABT0GTh/05]?:@1:A280=38K02@T600N7aX07b@N02@W800W
:200:RPL02dW6@0c:QT0?C8P04Dh9@1KA1/0Je8Y07eU=`29Kch0SG8m099e>`2INcl0Wh5309]oC`2J
O4X0U7I409Ee@P2RPD`0/8eG0:b7D02NND80Ledh04m08@0k=Al0=CLZ02hc;00_<R/0<c4U02`V6PP0
9BPQ0P0U9R401`0W:280:BXR02X/8@0/;R40;S0S02h`8P0`<R@00P0a<R@00`0c<B@0=30T03H`9002
03L_900303@^800e;b40=c4S0080>38T00<0=c4S03D_8@0d;R00200c;b<00`0i;b<0>S0T03/a9@02
03`b9P0403/a9@0j<2@0>BlS03/_8`80?30T00<0?C4U03hb9P0o<bL00P10=2P01`13>RT0@CPW04<h
9P17>RL0CSlZ0510:@1=?BH00P1:>20804Pg9`80AcLP00L0BCTR04/k901=?BH0CclX0510:@1A@BX0
D3hX00H0CcdW00<0D3hX054m901A?B@00P1A?B@2058n9@0405<o9P1D@2L0FT8Z05Y2:P80Fd<[101L
A2`0101MAB<0GdLU069::01TC2X306I>;00A06E=:`1PC2L0Gd/X05e99P1LB2L0G4LX05]6:@1IA2T0
F4<X05E4:01D@bL0DT4W050n9P1>?2H0BcTU04Xh9019=RD00P16=b@01P12=B@0@3@T03`c900i<B@0
>30S03H`9080=2hR0P0e;b<0100f<2@0=c4U03Pb9P0i<bL403Da9@@0=30T0P0a;2H0300b;RD0<blT
03@`900e<R<0=S<T03Hc8P0g<B<0=C8S03@`900a;b<0;RhT02//9080:B`U200Y:B4202XY9080:BPS
00@0:2LR02LV8@0W9R409bHQ0P0W9al302PX80<0:BTQ0P0]:B00100^:R40;b/R02l[8P0`;2<2034]
90P0<2`S0P0a;B400`0`;200;b/O02l[7`0302l[7`80<BlS00d0<S0T03@`900h<R@0>c@T03he900o
=RD0@SLU03`g900m=R<0?SLT040h8`13>280ACTQ0080AcTO05<0DSPM05Dk801H@2@0FdHY05]8:P1G
ARP0Dd8T04ho8019>b40C3hT0553:@1DAR`0ETH]05A4:`1A@BP0CcdU04Q0:`16?RT0Ac`X04Hi9P18
>BH0BCPV04/j:01<>BP0E3hW05Q0:01K@bL0H4LX06I<:@1/D2T0L5<Y079E:@1ZD2/0JU8/06YB;P1Z
Dc40Ie<b06AA<@1PD2l0GTd_0659;`1PB2h0GdL[05i7:01NAbL0H4TW069;:@1SCBP0KdlY07=C;01j
FBh0Q68b08m/=P2HMST0Wg`l0:Eo?P2QPDh0X81=09j0CP2JOTh0UGY;08mgB@2;LdD0Qg1408MX>@28
JSP0Rfdk08i`?02ALcd0U7Lo09Ii?`2GNT00Wga409inA@2QP4X0XX==0::4D02PQ580WXAA09j4D`2T
RUT0XhUH0::8E`020:67EP030:26E@2NQ5<0W89A0080U7m800@0UH1909F0B`2EP4/0UH1;0P2EOdd0
8`2QPE00YhMF0:b<F`2]SEh0ZHYK0:66E`2NQUH0WXQI0:B>I@2WTFP0[II/0;>LL02jY7D0`ZYj0<N_
O`39/X00cKZ?0<fhS@3:]HP0ak620<>[N`31YWL0_Z9b0;bPKP38Z7T0aJEd0<:QK031WVH0`ImP0<FR
GP3<Yf00cj]Q0<^WK@3<Z6h0cJU_00<0cj]a0P3>ZW001@3=Z7`0b:Ii0<RVN@32X7<0_Ya^0080^YYY
00X0_9aY0;jNJ`30UV@0`9IT0;nGI02nVFD0_IUU0;jJIP2mW6L0_IiX0P2oW5P01`2oW5X0`9eM0<>O
H@36XVH0bZIZ0<bXKP3<ZVX00`3=Zf/04P3<ZVX0bJMW0<JTI034XV80a9eR0<JOI038Y6X0c:Ua0=:_
N@3E]7l0f;R50=ZjQ`3M_H80gkn60>?2S03VaHl0jLRC0>[9UP80j/RH00H0iLZC0>G7T@3Ra8h0gl2:
0=flQ`3N^XH20=jiQ@<0g/:B0100h<BD0>C8V03Xc9`0jlnO0>kBXP3aeJH0l=BT0>kBXP3[cid0ilbG
0>C9TP3Rb8l0h<J=0=VoSP36[7/0]9YY0P2`UVD06`2[TF00Z8iM0:V?GP2ZTE/0ZI1J0:R>F`2XSUd0
Z8eN0:Z?HP2/TF@0[I9W0;BIK02eVVd0]Y]^0;VNL@2kX7<0_J9e0;nTM`30YGP0aJN30<BXP`39[8X0
d;JE0=W0X@3Ob:T0glZ[0=g8Z`020=k>[@060=o>/03Pck<0hM2f0>;@^03Rd;X0hm6k0P3QckT20>;@
^P0<0>3>^03Nc;H0flVc0=[8/P3F`ZX0e<2W0=:nY@3@_:40cKZL0<ZgU`38]I@0akBC0P36[Hh01034
[8X0`ZZ60<6YQ@2oYh420;fVO@0@0;VNL@2jWg@0_J9g0<2TO033Yh00aZZ50<V/RP3:[H/0bk2B0<fb
U03@]iT0eKfQ0=S3Z03MbK00hLfd0>7?]`80h]6m0P3Rdl003@3ReL@0hmO70>;IbP3SfLd0hm_>0>[P
eP3[hML0k>;H0>gSf@3^i=X0knGK0?3Vg03aimd0203aim/80?;VePP0lnOG0P3eiMP0103eiMH0mNGE
0?GVd`3ei]420?GVc`80mNKC00H0mNC@0?GSc@3fh/X0m^380?OOa`3gglD30??Rb080l^770`3ah<H8
0?7Ob@80lN;?0P3`hLh20>oPc@80k]o<203`gll20>cOcP80kN3?0P3^hM020>oRd@80lNCC0P3`hm80
103_h]40k^7@0>kQd03^hM080?7Pc0@0k]k70P3]gLH20>cLa@<0k]c60P3]flD30>cJa0080>oI`P3^
f<40k]S00>gG_`3/ek`0j]Fh0>[E]P3Ye;D30>[A/`80jM2b0`3Xck420>W<ZP040>S;Z@3WbZP0i/VW
0>G8YP80i<NU0P3WaZ<00`3VaJ80iLBQ0>G4X@020>C3X080hl:O00T0f/2O0=VoW03J_I/0f[bH0=Zj
U03J^980fKR?0=VfSP3G]I000`3F]8l20=FcSP80e;:=0`3?[hP40<j^Q`030<f]QP3?[8H0cjb600H0
cjb6103=ZX@20<bYP`80bjR2103=ZX@40<bYP`<0bjR20P3<ZH<30<fZQ0@0cJf6103>[XL01P3@[XT0
dJn:0=:`R`3D/Xd0eK>>0=NeT080fKNB0P3F^9H00`3G^IL0f;ZH0=VkV@020=ZlVP80fkfK0P3L_Y`0
1P3M_id0g/2N0>32X03P`Z00hL>Q0>36Y@<0hLNV0P3Rb:L20>?9Z080hlRZ00<0i<V[0>G:[03UbZ`0
0`3Vbjd30>C</080iLfa0`3Vc[830>O?]@<0j=2f0P3YdKL20>OB]`80j=>h103Ye;T80>SB^P<0j]Bl
0P3[eKd30>cF_PT0j=Nm203ZeKX80>WE_0P0jmNn203[ekl80>cH_`P0jmNn0`3Ze[d20>WE_0<0j=Bk
103Vd[T40>OC^PP0j=Bk203Zd[H80>_C^`80jM>k0P3Xd[X30>OA^@030>K@^03Zd[X0j]:j00P0j]:j
0P3YdKT30>S@^0060>O?]`3SbZ`0i<^]0>C;[@3Uc:h0i/f_0P3Wc[000`3Xck40iLb^0>G<[P020>C;
[@80hlZ/0P3RbJ/20>O:ZP070>K9Z@3TajL0hlJV0>;5Y@3Qa:@0h<>S0>?2W`020>;1WP050>70W@3P
_i`0gkjK0=nnV`3N_IX00P3N_YP00`3M_9T0gKbK0=flV`020=bkW080g;ZN103I^iT40=ZlVP060=jm
VP3M_9T0g;^H0=^jU`3J^IH0f;ND0P3G]Y<80=NiU@P0f;RA0P3I^9D20=ZiUP@0fkZG00<0g;^H0=^j
U`3J^IH00P3H]i@00`3J^IH0fkZG0=bkV0080=bkV00;0=noV03N_YL0gKfF0=blU@3K^i@0f[ZC0=Vi
TP3H^940f[ZC0=ViTP3G]i000P3F]Xl00`3G]i00fKVB0=ZjT`080=RhT@P0ekN@0`3G]8`30=JcR`80
eK::0P3C/h`20=BdS@@0eKF>0`3D]8d20=>cS0/0d[:;0`3@/8T01@3?[hP0cZj70<f]QP3<[8D0bj^4
00<0cJZ00`3<ZGl20<^XOP030<ZWO@3<ZGl0cJZ00080cZ^100<0cJZ00<bYO`3:Ygd00P3;ZG/40<ZX
NP<0bJMi00H0ajAl0<NTNP37Y7X0ajEh0<NUM`37YGD20<NVL`060<VWM`38YWH0b:If0<NUM@36Y7@0
aJ=c0P34XW800`35X6`0a9m[0<BOJ`020<>NJP80`YeY00<0`IaX0<:NJP32WVX00P31WFT20<2LJ080
_i]W0`2lV6P20;^GI`<0_9QX0`2oWFd30<2NKP80`Im_0P33Wfl30<:NKP<0`Ie]0P2oWFd20;jLK080
_I][0P2lVVX20;nKI`040;jJIP2mVFD0_IUU0;bHI080^iMS0`2iUV0[ooooo`00:_ooool80:ImB@04
0:V0C02XOd/0Z7m;0:MnBP80YWe90P2UO4P40:UoC@@0ZX1>0`2[PTX30:Z1B@80ZH18202[PT`0202Y
Odd0ZX1>0:^1C`2/PU00[XAB0:n5D`2`QU@0/HME0P2/Pdl05P2]Q500[hIB0;27D`2aR5@0/XUE0;>:
EP2fR5@0^heI0<2EHP37WF/0cJEd0<nYNP3AZg`0d:]n0<j[Q@3?[8H0dJj80=:_R@3C/8X0dZn90=6^
R03@[HL20=>`R080e;690`3E/XX20=JcR`P0dk><203C/hX80=6aRP040<naS@3@/Xh0d;:>0=6cS`80
d[B@0P3C]I480=BfTP030=RjUP3E]i<0dkFA0080e;JB00/0d;:>0<V[Q`33YH40/XUY0:=jFP2GKd/0
UFi509A]@P2@JS/0TF`h09Ia?@0309E_@0<0UW11102GLD8309I`@@<0UFm0102DKc/409=^>P03091[
=`2AK3P0TF`h00@0TF`h00<0T6/g09AZ>02DJSP00`2CJCL5099X=P@0TFLe0P2BJ3H209=X>`80TVLj
0P2AIST2091U>0P0TFHi0P2>J3T208mY>P@0T6Xk00<0S6Hg08eW>02=IcP0102=IcP00`2<ISL0SfTj
08mY>P0608mY>PT0Tfhj202@JcL8095/>080TV`m00H0TF/l091Z>`2AJc`0TV`m09A^?`2EKd08095[
?006099^?P2CKcl0Tflo09A`@02ELD40UW920P2GLd<809A`?0P0UG0l0P2ELD4309A`@0<0Tflo0P2F
MD003P2GMT40V7M209Uh@`2JND@0VgY509akAP2INdT0V7Y809MiA`2FN4H0UgU709QjB02JO4X0W7i<
202INdD01P2DN4P0T7A408Y^?P25JCT0PFDe07mS<`80P6@d01P0RFTf08EW=@1nHS<0LeXa06QB;@1K
B2P0D3lS04/k8@17?B80A3XO044g7012>1d0AC/P04Lm8P15>b00@SPM03Pa7P0h<Al0=C0M034^7@0^
;1d0:R/M02TY7@0W:A`402P[6P@0:B`K0140;2lJ034c7P0a<ad0<C4I03Pf7@12?R<0@3XP03Pc5P0U
9A/092@J024R6P0N8AX06QlI01TO6`0J81`06B8O01hP7`0201dO700301`N6@0M81T07b8I00808RDJ
01T08bHK02TW6`0]:Ad0=2lL03hg7@1:?al0EdTT061A9P1WERX0JEPT07ET;01oKBl0Of//07eW;@1j
Gc00K50[05m0901B>Rh0@BlQ030Y5`0/;QT0;C0K02h]6@0f;A`0?c8R0080@3<P0P0o<Ql203ha7P80
?C0M0P0n<b4303db80<0?34O0300?S<Q03ha7P0m<1d0@34L04<c7018=Qh0CSXQ054m901G?bL0G4L/
05e=:`1CBBD0@SdM034`6`0S9AX071hK01lT7P0T9b009bPP02/Y7@0^:1X0=B`K03ld8P17>RL0GdPL
06mG:@21JCT0SWA3099g@P2FN480WGi50:B5C02MPE40Vge;09AfA02FMT<0Y8=>0;6>F02[QTl0VgHo
06mI=01<?Ah0>C<M03Dg:P0^<b`0<3</03<a9@0/9QX802DX8@0902DV8@0V9b809bPR02TZ8P0[;B80
;BlR02h`8`0_<B<0<38T0080<C8T00<0<c4T03@`900f<2@00P0g;b@00`0d;R00=BlQ03La8`0203Pb
900303La8`0e;b40=2hP00@0<BlR100b<2<00`0i;b<0>S0T03/a9@0203`b9P0403/a9@0j<2@0>BlS
03/_8`80?30T00<0?C4U03hb9P0o<bL00P10=2P01`14>bX0@STX04@i9`18>bP0CSlZ0551:P1=?BH0
0P1:>20804Pg9`0804Lg8018>240BCTR04/k901=?BH0CShW04lo:01@@2T304lm9`80D3hX0`1??BL0
101@?2<0DCdT054m901B?RD405<o9P<0FT8Z0P1K@b/305a4;00405i6901OAbD0HTXX06A<:P<0IDd[
00L0I4`Z05m=9`1OCBT0GddY05e::@1JAbL0F4DW0080F4@Y00P0ETDW05E49P1C@RH0DD0V04lm9@1<
>R@0BcTS04Xh9080AcPU00X0@cHU040d900l<b@0>C4T03P`8`0f<2@0<bdQ03@^8P0e;b<0=S0T0P0g
<BD203Pb9P@0=30T100e<BD2038^9@0<03<_900d<2@0=C8S03Hc8P0g=2<0=c@Q03La8`0e<R<0=30T
034_8`0^;R@0:b`T0P0Y;2D802PX80<0:BPS100X9b800`0W9R409bLO02LW7`0302PX80<0:BTQ0P0]
:B00100^:R40;b/R02l[8P0`;2<2034]90P0<2`S100a;B42030/800A02l[7`0^:Qh0<2hR030^8P0a
;b<0<blS03La8`0j<b<0?C@S03he9011=R@0>cDU03`e8`0l=B80?SHS044f8P13=b400P16=b00D01A
>Ad0EShR05U49`1KB2X0F4LY05E49P1@@B80CD0P04`j8P1>?RD0DT8Y05E5;01DAR`0DT@Z04i09P1;
?B<0ACdX04@l9`15>RH0ACPU04Pi9P1:>BL0C3/Y04hk:P1E@BP0Ed8W05U49`1NAbP0HTXX06I<:@1[
CbP0K50Y06eA;01[DB`0Je4^06UA;`1VCbl0HD`]05e::P1KB2X0GdL]05i6;01MABT0GDHW05i79`1O
B2H0HDXX06==:01/CRP0L5<[07QI;@21HC00RfXd09Id=`2LNSX0X7dk0:61CP2PP4d0WX1>09UmC@2D
NDX0SGE708Ua@`25KT80QFDf08MW=P29JCP0S6`i08m`>P2BLc`0UGHm09Mh?`2MNT80W7a309imA`2O
P4X0Wh5=09b0CP2KPDh0VX1?0P2OQE@00`2NQ5<0WH=B09Z0C`0209UoCP0409Z0C`2DODL0U7e709An
A@80UGm602<0UX1609N1A`2HPTP0Xh9=0:J7D@2WS5L0Y8YG09Z2DP2BNT`0SGE908]cA`2MQ5`0WhIN
0:F<H`2ZTfL0/Ya]0;RRL@2lZ7H0_j]h0<>aR@32[hL0_jb20;fXO@2kY7P0^:1b0;RML02gW6d0a:=h
0<:QM030Wf`0`9eU0<6OH036Y5d0c:QN0<n[G@030<n^N0060<j]M`3<ZgD0b:Ma0<BSK@32XF/0`j9i
0P2oWWD02`2iV6d0]9AU0;>AH@2dTf00]iIQ0;^HHP2kT5d0_95N0;bCG`2lU600^iIQ0080^iQR00T0
^IQR0;^HEP2kV5H0^iQH0;bHFP2nVUh0`IeS0<BPIP36XFX00P39YfP0503:Z6T0bJMX0<RVI`36Y6D0
a:9S0<>QHP36WfH0b:5X0<ZUKP3?[7H0eK5m0=RgQ03K^hX0g[j=0>71R03S`X`0i/F?0>W8T`3[bYL0
k<ZJ0P3/bY`01P3Wc9D0ilVC0>?5S`3P`H/0g[f80=jjQP80gkZ60P3M`Y<0;P3Oa9D0hLJG0>C9VP3Y
cYl0kM:S0>oDY@3ceZX0lMFV0>oCY03/d:00jLfK0>G:U@3Sb940h/N@0=k4T`39[gh0]ie/0;:HI`2a
UfH0[I=R0:Z@G`2/TV40Zi9L0:ZAF`2YSe`0Z8iM0:V>G`2ZSf80[95T0:fBI`2dVFh0]IY_0;JKL02i
WW<0^j1e0;fRM`2oY7T0`:Ej0<FWP`34Z8<0bJb:0=2fU@3I`:40glRY0=o:Z`3Mb:/20=k>[@060=o>
/03Pck<0hM2f0>;@^03Rd;X0hm6k0P3QckT20>;@^P0<0>3>^03Nc;H0flVc0=[8/P3F`ZX0e<2W0=:n
Y@3@_:40cKZL0<ZgU`38]I@0akBC0P36[Hh01034[8X0`ZZ60<6YQ@2oYh420;fVO@0@0;VNK`2jWg80
_:5d0;nTN@33Ygl0aZZ30<R/Q`39[HP0bk2B0<fbU03@]iT0eKfQ0=S3Z03MbK00hLfd0>7?]`80hm6k
0P3Sd[h03@3TeL80hmK50>?Ga`3Tf<X0hm[;0>WOe@3Zh=H0jn7G0>cRf03^i=X0knGK0?3Vg03aimd0
203aim/80?3Wf0P0lNSI0P3eim`0103eimX0mNSH0?GXe`3ej=D20?GYd`80mNSG00H0m^OD0?KUd@3f
i<h0mn?;0?OQbP3ghLT30?GSb`80m>;:0`3chLT80?;PbP<0l^7=0P3ah<`30?3Ob`P0l=o?0`3]h<l2
0>kQd0<0kn;A00<0lNCC0?3SdP3`hm800P3`hm830>oRd@P0lN;?0`3_h</30>kObP80kMk90`3agl/2
0?3NbP<0kmg900T0lMc70?3KaP3`g<@0km_20>kJ_`3]fKh0kMZl0>cI^`3]f;d00`3/ek`20>_F^`80
j]Fj0P3]d[@0103/dK<0jm2b0>_@/P3Zck420>W>/0030>S;Z`3WbZX0ilZZ0080i/VY00`0iLRX0>C7
Y`3SaZH0hlJV0>37Z03OajD0glFR0>33X@3O`Id0h<2J0=noV03O_IL30=flV@80g;^H0`3K^YL30=Jf
T0030=FeS`3D]8h0e;B>0080dk>=203C/8X20=:^RP80dJf90`3@[8P00`3?ZhL0cJV50<jZQP060<jZ
QP<0d:b80P3A[HT30=:^RP<0cZj800<0cjn90=2`RP3@/8X00P3A/H/20=FdT@060=NfT`3H]i@0f[VF
0=bkV03M_9T0g[fJ0P3K_Y`00`3L_id0gL2N0=k1W`020=o2X0030>33X@3Qa:H0hLBV0080h/FW00@0
hlJX0>C7Z@3TajT0iLRZ0P3Tbj`20>G<[@<0i/f^00<0ilj_0>K=[`3Wc[000`3Wc[030>S?/@<0iM2c
0P3VdK@30>OB]@80im6i0`3Xd[X30>WC^`@0jMFl0P3Ze[d20>_G_PP0j]Jn0`3[ekl20>cH`0<0kMW1
2@3Zf<0<0>_G_P@0j]Jm203[ekh80>_G_`P0kMW0203[ekh0103/f;l0jmNn0>_G_P3[ekh20>[F_@80
jMFl203Xe;/80>WE_0P0jm>g203/e;`30>WE_080j=Bk0`3WdkX90>_C^`<0j]:j0P3YdKT20>S@^080
iLb^00@0i/f_0>O>/03Wc[00j<na0P3Yd;830>G<[P80i<^]0`3SbZ`20>S;[@060>O:[03Ub:X0i<NY
0>?6Z03RaJL0hLBV0P3T`j00103S`Yl0h/6N0>70W@3P_i`20=nnV`80gknI00<0g[fJ0=jmW03M_9/0
0P3M_9d20=fkW`@0fkfK103J_9X01P3O_Y/0g[fJ0=flV@3L^iP0fkZG0=VhU@80f;ND203H^YH80=Vi
TP80f[VF0`3K^YL30=bkV0030=flV@3L^iP0f[VF0080fKRE00<0f[VF0=bkV03M_9T0203L^iP02`3P
`9T0gknH0=jnU`3M_IH0g;bE0=^kU03J^Y<0fKVB0=ZjT`3I^I80f;RA0080ekN@00<0f;RA0=ViTP3J
^Y<0203I^I880=NgT080f;F=0`3G]8`30=JcR`@0e;B=0P3E]Hh20=JfS`80eKF>0P3D]8d20=>cS0X0
d[:;0P3A/HX00`3@/8T0cjn80<j^Q`030<f]QP80cZ^10`3=ZX030<bYO`030<^XOP3<ZGl0cJZ00080
cjb200@0cJZ00<bYO`3;Z7h0c:Yl0P3;ZG/20<ZXNP<0bJMi00L0b:Ih0<RUO@38YG/0b:Ek0<RVN@38
YWP0b:If0080b:Md00H0bJMg0<RVMP38YWH0ajEe0<JTM035Xg<20<BRLP80a9m[1033WVX20<:MJ@<0
`YiZ0P31WFT30<2LJ0030;^GI`2lV6P0_9QX00@0_9QX00<0^iMW0;nMK@2oWFd00`30WVh30<6OK`<0
`im_0`32WVh20<6MK@80_ie]0P2nW6`20;fKJ`80_9YZ0P2oVfL0102nVVH0_IUU0;fII@2lV6@20;^G
H`<0^YMQ:oooool002[ooooo202VODT80:MnBPP0ZX1>0`2[PdP20:Z2A`<0ZH56202[PT`0202XOT`0
ZGm=0:Z0CP2/PU00[XAB0;26E02aQeD0/XQF0P2]Q5020:j5D@0D0:n6DP2`Qe<0/HQD0;68E02dQU80
^H]G0;nDH@37WF/0cJEd0=2ZN`3B[7d0dJao0<n/QP3@[HL0dZn90=>`RP3D/H/0dk2:0=:_R@3A[XP2
0=>`R0040=BaR@3E/XX0e[>;0=JcR`80ekB<00<0f;F=0=>cS03C/h`01P3C/h`80=>cRPP0dK6:0`3@
/Xh01@3A/hl0d[B@0=:dT03B]900dkFA00P0e;JB00<0ekVE0=BfTP3B]9000P3B]9002`3?/Hd0bJ^7
0<>UP@2eS6`0YGaL09Q`C02EKTD0Tfa108mY>P2@JcL0UG0l0080U6ho0P2EKd0309I`@@80Ug520`2F
L44209E_@080U6ho102DKc/409=^>P0308mZ=P2@JcL0TF`h0080TVdi00<0TF`h091[=`2?JSH00P2D
JSP309=Y=`<0TVPf00<0TfTg099X=P2AIcD00P2@IS@00`2AIcD0TVPf09=Y=`0209=X>`80TVLj0P2A
IST2091U>0P0TFHk00@0SFLh08iX>@2>J3T0SVPi0P2?JCX2091Z>`0308eW>02>J3T0SfTj0080T6Xk
00<0SfTj08iX>@2=IcP0202?JCX0102@K3P0TFdi095]>@2AKCT4099^>P0309=_>`2@JcL0T6/g00H0
T6/g202AK3P4095[?080TV`m00<0Tfdn09A^?`2AJc`01`2AJc`01P2BKSh0Tflo09=_?`2DL400UG51
09Ib@P80Ug=3202DL3`809E`?00309=_?`2DL400U71000D0U7100P2EM3l03P2FMD00UgI109Uh@`2J
ND@0VgY509akAP2INdT0V7Y809MiA`2FN4H0UgU709QjB02JO4X0W7i<202INdD01P2DN4P0T7A408Y^
?P25JCT0PFDe07mS<`80P6@d01P0QfLd08AV=01mHC80LUT`06MA;01KB2P0DD0T04/k8@18?R<0A3XO
040f6`11=a`0AC/P04Lm8P15>b00@cTN03Tb7`0h<Al0=S4N034^7@0^;1d0:R/M02PX700V:1/402P[
6P@0:B`K0140;C0K034c7P0a<ad0<C4I03Le7011?B80@C/Q03Pc5P0V9Q`092@J024R6P0N8AX06QlI
01TO6`0J81`0624N01hP7`0201dO700301`N6@0M81T07b8I00808RDJ01T08bHK02TW6P0]:Q/0=C0L
040i7@1=@R80FT`U06AF:@1[FR`0K5/W07QW;`22L380PVh_07mY;`1kH340KE4/05ho8`1B>Rh0@BlQ
030Y5`0/;QT0;C0K02h]6@0f;A`0?c8R00<0?c8O0P0n<Ah303d`7@<0?S<Q0P0m<R0303`a7`0`03db
800n<Ah0?c8O048c7P16=Ql0BSPP04hj8@1@?2<0EClX05]7;P1HBBP0BD4M03Tf5`0];aX08bHM01XN
7@0M8Q`08RDN02HW7`0[:Ad0<2XL03L^7@13>2H0Bch[06I@7`1eGBd0Qg0n09=iAP2GO4L0Vge70:62
C02WR540Wh=C09anC02DMT@0UgM40:J5D02cT5X0ZXE>09Qc?01/ES40BS/L03Pb700e=bX0;S</030c
;00c<BD0:bDI200U:24202HW8P0702PY8`0Y:R80:bdR02d_8P0_<B@0;c4S034c9@02038c9@0303<a
900d<2@0=BlS0080=RhS00<0=2hP03D_8@0g<B<00P0h<R@00`0g<B<0=BlQ03@^800302h_8@80;c0R
0`0`<B<00`0i;b<0>S0T03/a9@0203`b9P0403/a9@0j<2@0>BlS03/_8`80?30T00<0?C4U03hb9P0o
<bL00P10=2P01`13>RT0@CPW04<h9P17>RL0CSlZ0510:@1=?BH00P1:>20804Pg9`0604Ti8P1:>R<0
BSXS04/k901<?2D0CCdV0P1>?RL00`1>?2H0CcdW050n:002054o:@03050n:01??BL0CS`V0080DCdT
00<0DclV05A09`1E@BP00P1D@2L00`1C?bH0F40X05Q0:00205U1:@<0FT8Z00D0Fd<[05i6901OAbD0
HTXX06A<:P0206E=:`0@06A<:P1SBbT0GDhW05i>:P1OCb/0G4`Z05Q89`1EA2H0ED@X05M6:P1GAbH0
ETHU05A39@1B@BD0CchT04dk8`80BcTS00/0BCXW04Pi9P14=bH0@CDU03dd9@0i<B@0>30S03H`900d
;R80=BlS03H`900303La9@80=S0T00@0<RhR03<_8`0c;b<0<blS0`0d<2@01P0e<BD0<blT03<_900d
<2@0=C8S03Hc8P80=c@Q00L0>3HQ03La8`0e<R<0=30T034_8`0^;R@0:b`T0080:B`U200X:20802PW
8P809bLO0`0X:20302TY8@80;BTP00@0;RXQ02l[8P0_:b80<2`S0P0a;B@8030/8`03030/800a;B40
<RhR0080<blS00<0<RhR034]8@0`;2000P0`;R807`0a;b<0<blS03La8`0j<b<0?C@S03he9011=R@0
>S@T03Xc8`0j<b40>c<P03hc8@11=240A3DP04Df8@1@>ah0ED0S05Y7:@1JBB/0EdHX05528`1>@B40
CD0P05<o9`1D@2P0E48Z05A4:`1BA2X0CD4W04To9017?B800P12>RD05P13>2@0A3LT04Pi9P1;>RP0
CC`Z050m;01D@bL0ET8W05Q59`1KARL0GdPX069::01UBbX0ID/X06mA;@1^DRd0KE0^06Y@;`1VCBh0
HT//05a7:01JABP205a4:P0>05]39`1LABH0GDHV06199`1RBbT0I4hY06iB:`1aEBd0N5/_085S<@2:
Jc@0Tg<f09Uj>@2NOCX209moC00O09anC02GNd/0TWM808]cA@26KT00Pfa008MU=`27ICD0R6Hf08]Z
=`2>KCP0TW4k09Ee?02GMch0VWLo09Ui@02KNT@0Vga609]mB@2HO4X0UWa909EkBP2GOD`0VGm>09Z0
C`2HOTd0UG]:09AjB@2GOD`0VX1?09QmCP0209MmC00U09MmBP2GOTP0VH1809^2B@2LQ4P0YH9:0:F6
C`2SRU80VhMB091nC028LdH0QFa308EY@P2INeD0VWiG09n3F`2SRel0Z99S0:fII`2`WV`0/Z5]0;BT
P02eXgl0/Z1j0;6NMP2aVg80/IY`0;:IL02bVVh0_9]^0;bLJ`2nWFP0`IiV0<>QHP37Y600c:MP0<jZ
H0030<naN`060<f_N@38ZW@0`jE_0;fOJ@2jW6H0^Ia`0P2fVV/02`2dUFH0/I5N0;2?F@2dTEL0]i=E
0;VEE`2kSUD0_8mF0;bBF02mUEX0_9EJ0080^YIJ00T0^IMJ0;VFEP2iUUH0^9AF0;RDF02jUU`0_9MP
0;nJH`30VfH01@34XVD04@33XF@0`Z1S0<:PH`38XFX0bjA]0<fXL`3B[WX0f;B20=bjRP3O_hh0h/:C
0>G4SP3VaI00jLRC0>_:U`3]bi/0kL^M0080k<ZM00H0j<fF0>O9T`3SaHl0h<6;0=jmR03N^XH20=ji
Q@80gL:E0140g/>F0>76V@3UbYd0jLjQ0>gBY@3`eJP0lmJ/0?;EZ@3_dZH0k=2Q0>W=W@3VbYP0hlRC
0>;7TP3PaYD0bk600;RNK@020;>IJ00K0:nEI02]Tf80[iET0:jEG`2]U5h0Zi5N0:Z@G`2ZSf00Zi1S
0:fBI@2^TfP0]9Q`0;FIL@2fVW80^Iee0;^OM`2mXGT0_j=k0<2TO035Yh<0a:R30<V/RP3@]YD0fL2Q
0=o8Z@3ObZ/0gLR[0080g/j]00H0glj`0>3?/`3Qd;H0h]2h0>;@^P3SdK/20>7?^@80h]2j00`0h<jh
0=k<]P3KbK<0f/Rb0=K2ZP3D`:L0d[jU0=2lX@3=^Y`0b[NG0<ReU037]9<20<N^S`040<F]R`33ZhL0
`ZZ60<2XPP80_ZMn0180^9i]0;VNK`2lXG80_jAg0<:WO035ZH40b:b50<V]QP3;/980cK:D0=2gV@3E
_J40f<>X0=g9/03QcK@0hLng0>GA^@3VdK`20>CB_00;0>CC_`3TeL80hmK50>CGa`3SelL0j=kD0>WO
e@3Zh=H0k>;H0>kTfP3_iM/00P3aimd80?7Wf`P0l>KJ203bj=`01P3ej=l0mNWM0?GYg@3ejM/0mNWI
0?GZf080mN[F00P0m^[J0?KYf@3fjMP0mnSE0?OVdP3giLl0n>?>0?STc080m^K?0`3eiLh30?CTc@T0
m>;<0`3chL/20?;PbP80lMo9203`gld20>gPc`80k^7@0`3_h]400`3`hm80kn;B0>oRdP060>oRdPP0
kn;A0`3_h/l20>kQcP<0kN3=0P3bhLl20?7PcP<0l=o=00X0kmk<0?3NbP3`g/X0kmg70>oMa@3^gL<0
k]g10>gL`03]g;h0k]c40`3]fl<20>cJ`P80jmW10P3_ek/20>kF^P<0kMFi00@0k=Bh0>S?/@3Xck40
ilj`0`3VcJl00`3Uc:h0i<^]0>C;[@020>G>[P060>G=Z`3UbjP0iLRV0>G7X`3VaZ00iLFO0`3Ra:83
0>73X@80h<:P00H0g[fJ0=flV@3M_9T0g;^H0=^jU`3J^IH20=VhU@P0fKJ@0P3G/i420=JbT0<0eK6?
00@0e;2>0=6]R`3A[H/0dJf;0P3B[X`30=>_S@80eK6?0P3F/Y030=NcT@040=RdTP3C/Xl0dk:?0=Bc
T080eKBA00T0e[FB0=NfT`3G]Y<0f[bJ0=^mV`3L_Y`0gKnM0=k0WP3P`Z000P3Q`j420>33X`040>74
Y03RaJD0hlJV0>C7Y`80iLRX0`3Vb:h20>O9[`<0j<Z`0`3Wd;420>SA/P<0jM:c203Xd;@0103VdkD0
imBf0>OD]P3We;H20>SE]`80jMJh0P3Xe;`20>WE_@<0j]Jn00@0jmNo0>WG_`3Yekl0jMNo0P3Zf<03
0>_I`@P0j]S20`3[fL<30>cJa080kM_52@3[fl@80>_I`@80kMW00`3/f;l30>_G_PP0k=Ro203/f<08
0>kJ`@P0k=Ro0`3]fL020>cH_`<0jmNn103Ze[d20>WE_080j=Bk203[ekh80>cD^0P0kMFm00@0jMRn
0>SG_@3Xekd0j=Nm0P3We[`20>KE^`T0k=Bl0`3[dk/20>[B^P80jM6i00@0ilj`0>S?/@3Xck40j<na
103Yd;80103VcJl0iLb^0>G<[P3Uc:h20>C;[@80hlZ/00D0j<Z^0>O9[@3WbJd0i/R/0>G7Z`020>C6
ZP070>?5Z@3VaJ80iLBQ0>C3X03S`Yl0h/6N0>2oW0020=nnV`80h<2J00<0gkjK0=nnW@3N_I`00P3N
_Ih00`3N_:00gK^O0=bnW0030=bnW080fkfK0P3J_9X20=jmVP80gKbI00@0g;^H0=^jU`3J^IH0f[VF
0P3J_9P30=VkU`<0f;ZF203J^Y<30=^jU`80g;^H0`3M_9T00`3N_IX0gKbI0=^jU`020=ZiUP030=^j
U`3M_9T0g[fJ00P0gKbI00D0h<2I0=noV03O_iP0g[jG0=fmUP020=blU@80fk^D00L0f[ZC0=RhT@3G
]i00ekN@0=RhT@3J^Y<0fk^D00P0f[ZC203H^9430=ReS@80ekB<0`3F/h/20=FeSP<0e;B=00<0eKF>
0=NgT03H^9400`3E]Hh20=BdS@`0dk><00<0d[:;0=2`R@3>[XL00`3=[HH0103>[XL0cZ^10<j[P@3>
Zh420<fZP0<0c:Uo00<0bjQn0<bYO`3>Zh400P3?[8800`3>Zh40c:Uo0<^XOP020<bZO0040<^YN`3:
Z7X0bZQj0<VWN@<0b:Ih00H0b:Em0<RUN`38YG/0b:Ii0<RVN038YWH20<RWM0060<VWM`38YWH0b:If
0<NUM@36Y7@0aJ=c0P34XW880<>NJP040<>OJ`32WVX0`YiZ0<:NJP80`IeY0P30W6P00`2jUVH0^iMW
0;bHJ0020;fIJ@040;bHJ02kUfL0^YIV0;nMK@<0`9i^0P31Wfl20<:PL080a:1`0P33Wfl30<:NKP03
0<6MK@2oWFd0_ie]0080_Ya/0P2mVf/20;bJJP80_i]W00@0_YYV0;fII@2mVFD0_9QT0P2kUf<30;ZG
HB_ooooo000Zooooo`P0YWe900H0Y7]70:ElB02UO4P0YWe90:MnBP2XOd/20:V0C0<0Zh5?1@2ZP4h0
102[PdP0ZX970:Z2A`2ZPTL20:V1AP80Z815202[PT`20:^1C`040:b2D02]Pe40[H=A0:j4DP80[hEC
102^QE440:n6DP0;0;:4D02gRED0_Y=P0<JLJP3<Y7<0cjUj0=:/O@3A[7l0cjb60=6^R03B[hT00`3D
/H/00`3C/8X0dZn90=>`R0020=BaR@030=FbRP3G]8`0ekB<0080f;F=00<0fKJ>0=>cS03C/h`01P3C
/h`80=>cRPP0dK6:00<0d;:>0=6cS`3A/hl00P3A/hl30=:dT0P0e;JB0100e[RD0=:dT03?/Hd0ck6=
0=2bSP3>/8`0b:Z60<>UP@2fSFd0YWeM09Q`C02DKD@0TV]008iX>@2?JSH0UG0l0`2DKSl209E_@0H0
UW110P2EKd0309A^?`@0Tfhj102DKc/00`2>JCD0SfXf095/>002099]>@03095/>02?JSH0SVTe0080
U6Xh0`2CJCL3099X=P0309=Y=`2BJ3H0TFLe0080T6Hd00<0TFLe099X=P2CJCL00P2CJ3/2099W>P80
TFHi0P2@ICP8095V?00408aV=`2=IcP0SFLh08eW>080SVPi0P2?JCX00`2>J3T0SfTj095[?002099/
?@03095[?02?JCX0SVPi00P0SfTj0`2=K3L0102>KCP0Sfhi08m^>@2?KST2091_>PP0T6/g202AK3P3
091Z>`80TF/l0`2BK3d8095[?006095]?@2BKSh0TVhn09=_?`2DL400UG510P2FLT8809Ea?@P0UG0l
0P2BKSh209=_?`0D09A`@02ELD40UW9209Ib@P2CLSd0U7<n09Ed?`2FMD00V7M209Uh@`2JND@0VgY5
09UkB@2HNTP0UgU709IhAP2GNDL0V7Y809YlBP2LOT`809UkA@0609AhB02@M4@0RVhn08EY>@21ICD0
Of<c0P20I3@02P25IC80PV@b07]O<01bFC00Ie4/05a9:@1B@BD0CCdS04To9014>Ql2040f6`0<04@j
7`16?240AC/P04<i7P0j<b00>C8P03Ha7P0b;ah0;R`M02X[7@0X:1`09RPK100Y;1/402P[6P0=02ha
700b=1l0<38L030`600f=1/0@CdR044k8@0i=1L09bLM02DU6`0Q8QX07R4J01XO6@0201TO6`0701LP
7@0N81l07AlL01dO700L7QT07B0I01lR6@02028U6P0I02<V6`0[:A`0;R/J03D`6P0n=a/0BT0M05M:
801PDRD0IUHU06YI9@1gIRh0Pg4c08A`<@23KC<0Of@e075E<01SA2P0DSX^044_8@0`:AL0;2hI02d`
6`0^;AT0=RdL03lb8P0203lb7`80?S4N100m<1d203ld8P80?S<Q0`0m<R001`0l<Al0>c0N03ha7P10
<b00ACHQ04Ti8P1;>B400P1>>R40:01C?RT0F4L]05=69P0n>1H0;bh@02X/5`0T9b00720Q01/P6P0P
8a`09BHN02/Y7@0a:ad0>S4P04Hk:@1?@Rl0K5HT07]T<P2<MD40V7i;09]oC@2NP4`0Y8AA0:Z:E`2Q
QED0WGm=09AfA02GMd@0YhIA0;BAF`2YQ4d0UW4j06YD;`18>AX0=c4K03@f:@0_=2d0<3</03<a9@0[
9AT802DX8@0902HW8P0W:2<0:2TS02X[8`0/;R<0;S0S02la900`<R@0<S@V0080<S<U00P0<c4T03@`
900e;b<0=RhS03D]8P0d;R00=BlQ03La8`80>38T00<0=c4S03D_8@0d;R000P0];R0202h_8@0702l`
8P0`<B<0<34S030a8`0i;b<0>S0T03/a9@0203`b9P0403/a9@0j<2@0>BlS03/_8`80?30T00<0?C4U
03hb9P0o<bL00P10=2P01`12>BP0@3LV048g9@16>BH0CChY04lo:01;>b@00P19=al804Pg9`P0C3`U
00<0CC/U04hl9P1@?RP00P1A?bT02`1@?RP0CS`V04dk9@1A?B@0DclV05E1:01F@RT0Ed<Z05I2:@1E
@BP0E40W0080EShV0P1G?bL305Q0:00505U1:@1NAR@0H4PV069::01SBbT00P1TC2X07@1SBbT0HTXX
05a>9`1ND2/0H58]05a>:`1FAbH0Dd@U05A5:01GB2/0EdLU05I69@1EAB@0Dd8T050o8`1>?B<0C3XR
04/i8@1:>bP0BCXW04Dh9`11=BD0?C@U03Ta900h<2<0=S0T03D_8`0f<2@0=c4U0080>38V00@0=S0T
03@^8P0c;B40<2`P0P0a;B42038^8P80<blS0`0d<2@0100e<R<0=S<T03Ld8`0g=24203Pf8@0603La
8`0e<R<0=30T034_8`0^;R@0:b`T0P0Y;2D802LW7`H0:2LR0P0Y:2<202LW7`<0:2PP0`0Y:B4202dY
800402hZ8@0_:b80;b/R030/8`80<BdT200`;2<01P0_:al0<BdQ03<_8`0e<BD0=S8V03Da9@80=30T
0`0`;R807P0c;b<0=c4S03Tb8P0l<b80?SDT040e8`0i<bD0>C4T03Pa8@0i<1l0?34O03lb7`13=240
ACHQ050k7P1E@R@0G4T[05]:;01EARL0Cd8R04Xo7`1;@200FD</05Q2:`1F@RX0DD4X04i09P19?b@0
AChR04@m8@80@3PS00h0@SLS04@g9018>BH0BcXX04hm:`1A?Rd0E4<U05E49P1HABL0FTDX05e69`1N
AbP0H4LY0658:@80KDl[00H0K4l]06Y@;`1WCRl0Hd`]0619:P1MB2/205U19`0Z05U19@1J@b@0GDHV
06199`1SC2X0IDlZ079I<@1gFc<0O64d08AX=P2=L3P0U7Hh09]l>`2MOS/0WWi;09emBP2JO4X0UGU9
091eAP28L480Q6`n081Y?@29IcT0R6Hf08UW=`2:JCH0SF`g091_>@2DM3/0UWHm09Md?02FMSd0V7M1
09Qi@`2GNDD0UGU7099hA@2AMdH0T7I509=iB02ENdX0TgU80P2AMdH0:`2GOD`0W89A09QlE@2GNe<0
UW]@09EjC@2FO4/0Uge:09V0BP2KPTX0YH570:B5C02NRE00UXM@08aoB`28MDX0RG1808a^BP2FMU00
UWQB09UmE@2LQ5P0WhYK0::@GP2TU640Y9MR0:NGM@2VUW@0YiEa0:NCKP2YTfh0ZiE^0:fFK@2_V6l0
]IIP0;NHHP2lVfD0`YmU0<JTI@3:YfL0cJMV0<jYI@3:[W`00P3;[gd01P3:[W`0aZYh0<2TLP2jWV`0
]i]Y0;FKJ080]9]U0100/YQO0;>EF@2dUE@0^9EA0;bGD02mVDl0`9=@0<6FDP32Ue<0`YYE0<6JE@2o
VU@0_9YC0;^IDP2lV5X0^iMI0P2iUET0102iUE/0^iIO0;bGHP2nVF@30;nLHP80`9eS0P31WV@06@32
WfD0bj=_0<fUL@3@ZgL0eK5o0=^gQ`3O_Hd0hl>D0>G5UP3Yb9<0j/VD0>c;V03]bi/0k/bN0>g;WP3/
bYd0jlRN0>O<U@3WbI<0hlF?0>31R`3M_8L0gKV50=fhQ03L]h<00P3J`Y@04@3La9H0g/JH0>;:W03W
cj40jm>U0>kFZ03ceZ`0lMBZ0>oBYP3/d:40j<bL0>G9U`3SaiD0h/NB0>77UP3</X40^Im^0080]9YY
01/0/IMV0;2FI@2cVFP0/9MQ0:nFH02]Tf00[99Q0:bAHP2]TVD0[Y=V0:nDJ@2dV740]IUb0;JJL`2i
WGH0^imh0;fQNP2oXg`0`:Am0<FWP`34Z8<0bJb:0=2fU@3I`:40glRY0=o:Z`3Mb:/00P3NcZd01P3O
c[00h<nc0>7@]P3Rd;P0h]2j0>?A^`80hLni0P3Rd;X09P3Pc[P0g/bf0=_9/`3Jb;80e/:Z0=C0Y`3B
_ZD0d;bQ0<fjW03:]iL0b;FD0<NdT`39/940b:n@0<N_S@35[HT0`j^70<6YP`30ZH00_jQo0;RNK@2i
Wfh0^j1a0;nTM`32Yg`0aJV10<N[P`39[HH0bk2B0<fbU03@]iT0eKfQ0=S3Z03MbK00hLfd0>7?]`3V
d;T0i]:j0P3VdK`00`3Udkd0iMC00>GF``020>?Fa@080>OMd`3Xg]@0jMoE0>_Qe`3]hmT0knGK0?7W
g@3bj=h80?7Wf`P0l>SK203bj]d20?CZh080m>[N00`0m>_L0?C[fP3dk=T0m>cI0?O[g@3gjm/0mn[J
0?KYf03gj=D0mnKB0?SVd03giLl30?KWdP80mNKA0`3diM080?GSc@80m^7<0`3eh</30?CObPP0l=o;
0`3^hM030>oRd@80l>?B203^h=<80>oRdP040?7Td@3`hm00l>?@0?3Sd080kn;?0P3^hLh30?7Rc`80
l>7>0`3_h<d20>oNc0030>oNbP3_glP0k]k50080k]k400<0k]o20>oOb03_glP00P3^g/L30>gMaP03
0>cLa@3^f/40k][10080k][1103]fL020>gE^@040>cD^03[dkL0jm>g0>[B]P80jM6e00T0j=2d0>WD
]@3Zdk@0jM:b0>WA[`3XcZ/0jLfX0>W;Y`3XbZ@00P3WbZX20>K9Z@@0iLRX0P3T`j00103S`Yl0h/6N
0>70W@3P_i`20=nnV`P0g[^E0`3K]iD30=ZfU080fKFC0`3H]9800`3I]I<0f[JD0=ZfU0020=^gU@80
f[JD0P3K]iD40=bhUP060=^jU`3L^iP0gKbI0=jmVP3O_Y/0h;nL0P3Q`9d20>74Y080h/FU0P3SaZH2
0>C7Y`060>;7Z@3Sb:X0hlRZ0>C9Z`3UbZ`0i/^]0P3Wc:h40>O;]@@0j<bf0`3Wd[<30>SC]080jMBe
0P3XdkP60>OB]`040>SE]`3Ye[P0jMJh0>WF^080j]Ni0P3[f;X30>[E`080jmK10`3/el80103YfL80
j][30>[J``3Zf/<20>_Ka080k=c52`3[f/H20>cKa`<0kMc82@3[g<L80>_Ka0<0k][10P3]fL000`3/
f;l0jmNn0>_G_P080>gI`0P0kMW1203^f/480>gI`0<0k][10P3]fL050>cH_`80jmNn00@0j]Jm0>WE
_03YeK`0jMFl203/f;l80>cD^0P0k]Jn00@0jMVo0>SH_P3Xf;h0j=Rn0P3Wekd20>KF_0/0k=Bl0P3[
dk/30>[B^P@0j]6c0`3Yd;800`3Xck40i/f_0>K=[`030>G<[P<0i<^]0P3WbJd60>K8[080ilJS00/0
iLBQ0>C3X03R`Ih0hL2M0>2oW03O_Y/0hL6K0>30VP3P_i`0h;nN0=nnW@020=nnW`80g[bP00<0g/2N
0=foW@3M_id00P3L_Y`20=^mV`030=ZlVP3M_9T0gKbI00H0gKbI0P3K_IT20=ZlV080fK^G0P3H^YH8
0=ZjT`<0g;^H0P3M_9T30=jmVP030=nnV`3N_IX0g;^H0080fkZG00<0g;^H0=jmVP3O_Y/0203M_9T8
0=jnU`030=^kU03J^Y<0fKVB0080ekN@00<0fKVB0=ZjT`3K^i@0203J^Y<80=RhT@80fKJ>0P3H]Hd3
0=NdS0090=JcR`3F]Xl0eKF>0=BdS@3C/h`0e;B=0=FeSP3G]i00fKVB00@0eKF>0P3D]8d20=>cS0T0
e;B=00<0d[:;0=2`R@3>[XL00P3=[HH0103>[XL0cjn80<n/PP3?[8820<j[P@<0cJZ00P3<ZGl0203=
ZX00cZ^10<n/PP3?[880cZ^10<fZP03<ZGl0cJ]m0P3<ZW`00`3;ZG/0bJMi0<RVN0020<RVN0070<NU
M`39YWh0bJIl0<VVO039YgX0bJMi0<VWM`020<VXM@060<VWM`38YWH0b:If0<NUM@36Y7@0aJ=c0P34
XW880<>NJP80`im[0`32WVX30<6MJ@030;ZFIP2kUfL0_IUY0080_YYZ00<0_IUY0;^GI`2jUVH00`30
WVh20<6OK`<0`Z1`0`34X7020<>OK`<0`Yi^0P2oWFd20;jLK080_I][0P2lVVX20;nKI`040;jJIP2m
VFD0_IUU0;bHI080^iMS0`2jUf4[ooooo`00:_ooool80:ImB@80XgY600H0Y7]70:ImB@2XOd/0ZH1<
0:Z1C@2[PTh40:^1C`@0ZX1>102ZPTD20:V1A080Z813202[PT`20:n5D`040:j4DP2]Pe40[H=A0:b2
D080Zh5?0`2_QU830:j5D@80[HA@01@0/H=?0;J8E02mTUl0aI]Y0<bTL`3?ZGX0dZam0=6/O`3@[HL0
dJj80=>`RP3D/H/0eK:<0=BaR`3C/8X0dZn90=>`R03D/HT0eK::0=JcR`80ekB<00<0f;F=0=VfSP3J
]hl0203C/h`80=>cRPP0dK6:1@3A/hl30=:dT0P0e;JB0100eKNC0=6cS`3>/8`0c[2<0<naS@3=[h/0
ajV50<:TP02gSVh0YgiN09Q`C02DKD@0TV]008iX>@2?JSH0UG0l0`2DKSl309E_@0@0UW110`2EKd03
09A^?`@0Tfhj102DKc/00`2>JCD0SfXf095/>002099]>@03095/>02?JSH0SVTe0080U6Xh0`2CJCL3
099X=P0309AZ>02BJ3H0TFLe0080SfDc00<0TFLe099X=P2DJSP00P2CJ3/2099W>P80TFHi0P2@ICP8
095V?00408]U=P2<ISL0S6Hg08aV=`80SFLh0P2>J3T00`2?JCX0TF/l099/?@0209A^?`03099/?@2A
Jc`0SfTj00P0SfTj00@0RfXe08a[=P2<JcH0SF`g0`2>KCP208m^>@P0T6/g202AK3P208mY>P03091Z
>`2AJc`0TF/l00/0TF/l0P2AKCd00`2BKSh0Tflo09A`@00209Ea@@0309Ib@P2ELCd0UG4m00H0UG4m
202EL3`01P2@K3`0TFdm099^?P2CKcl0U71009Ib@P80Ug=30P2BLC`0102DLch0UG@o09Mf@@2IN4<2
09YiA00809UkB@2HNTP0UgU709IhAP2GNDL0V7Y809YlBP2LOT`809UkA@0609AhB02@M4@0RVhn08EY
>@21ICD0Of<c0P20I3@02P23Hc00P68`07YN;`1aF2l0Ie4/05a9:@1C@RH0CShT04To9014>Ql2040f
6`0<04@j7`16?240AS`Q04@j7`0j<b00>C8P03Ha7P0b;ah0;R`M02TZ700X:1`09BLJ100Y;1/402P[
6P0=02ha700b=1l0<38L030`600f=1/0@CdR044k8@0i=1L09bLM02DU6`0Q8QX07R4J01XO6@0201TO
6`0701LP7@0N81l07AlL01dO700L7QT07B0I01lR6@02028U6P0I02<V6`0/:Q/0;b`K03D`6P0l=AP0
AcdJ05546P1IBa`0GdlN06MF8P1eI2`0PW0b08Ea<P25KcD0PfPi07IJ=@1YBRh0DSX^044_8@0`:AL0
;2hI02d`6`0^;AT0=RdL03lb8P0203lb7`80?S4N0`0m<1d00`0l;a`0?c@R03ld8P0203hc8@@0?C8P
0300>RlM03d`7@11=240AcPS04/k901<>R80CSXQ04di801B?BP0EdD]05138`0i<a40:RT;02LZ5`0S
:240728R01TN600O8Q/09BHN02/Y7@0b;1h0>c8Q04Pm:`1AA340L5/V07mX=02@NDD0Vh5>09f1C`2P
PU00YXIC0:^;F02RQUH0WGm=09AfA02GMd@0Z8MB0;BAF`2YQ4d0U6lh06QB;@17>1T0=S0J03@f:@0_
=2d0<3</03<a9@0[9AT802DX8@0>02HW8P0W:2<0:2TS02X[8`0/;R<0;S0S02la900`<R@0<S@V03<d
9P0b<bD0<c4T03@`900e;b<203D]8P0303@^800e;b40=c4S0080>38T00<0=c4S03D_8@0d;R000`0/
;R000`0];b40;S0R02la8`0202la8`0303T_8`0j<2@0>c4U0080?38V00@0>c4U03X`900i;b<0>blS
0P0l<2@00`0m<BD0?S8V03lc9`02040d:007044h9`0o=RD0@CHT04Dh9@1<?BP0CShW04/k900204Pf
7PP0B3LW00@0CShW04dm9P1=?BH0C3`U0P1;>b@204Xj8`0304dk9@1>?2H0D3hX0080DClY00H0D3hX
04hl9P1=>bD0DShU05A09`1F@RT205Q4:`0305M3:P1F@RT0E40W0080ECdU0`1F?RH305Lo9`0405i6
901PB2H0HTXX06=;:@80I4`Z0280Hd/Y069::01LCRL0Ge4/065C;P1MCb`0ETLV0593901DABP0EdP[
05Q89P1GAbD0EDDT05=2901@?b<0CSdS04dl8P1<>R80BS/X04Tj9`15>2L0@SHV03dd9@0i<B@0=blR
03D_8`0f<2@0=c4U03Pb9P0i<bL0>38V03H`900c;B40<R`P0P0_:al0100`;200<BdQ034]8@0b;R82
03<_8`80=30T00<0=C8S03Hc8P0g=2400P0h=R401`0i=b00=c4S03Db8`0d<2@0<BlS02h^900[;2@0
0P0Y;2D802LW7`D0:2LR0`0Y:2<202LW7`<0:2PP0`0Y:B4202dY800402hZ8@0_:b80;b/R030/8`80
<BdT200`;2<0100_:al0<BdQ03<_8`0f<RH303Lc9`0H03Hb9P0_;B40;bdQ030^8P0c;b<0=S0R03Tb
8P0l<b80?C@S040e8`0h<R@0>C4T03L`800h;b00>blO03ha8013=240A3DR04ll7P1F@bD0FdX/05Y;
;01DAbL0CT4Q0P1:?al0201NABl0FT@]05I2:P1A?bL0C3hT04Lm8P14?B40@SdP0P0o=b803011=R80
@cHS04Pi9P1<>bT0Cch/058o;P1DABH0ED@V05I59`1IARP0FTDX05e5:@80GdDZ00P0JdXW06Y<:01/
CR`0Jdh^06U><01VCBl0I4d^069:;P80EclU05P0F40T05Y3901MARH0HDXX06A=:`1WDB`0N5lg07YQ
>021IST0R6`j095d?02HNS`0W7lm0:21?P2MODX0W7a909UkB@2DN4P0SW=408M_@@22JS`0OVLk08aW
>P2<J3P0RfLg08aX=P2>JSH0TVli09Eb>P2GM3`0UG8j09Ad>`2FMCl0UWM109Eg@`2BMT@0T7I308me
A02;LD00SgE4099hA`2AMdH0SgE4091fA@2GOD`0WXAC09UjF`2HNUP0UWQD09EhD02EN4`0UWY;09Ql
BP2JOT`0Y8140:>5B@2MRDh0ThQ@08f1C`2<Ndl0T7IA09EgE@2ELdh0UWI@09MjDP2HP5@0VXEF09b:
F02LSe/0WY5L09j?KP2OSfh0WXi/0:2>JP2SSfX0Z99[0:bDKP2^Ufh0/95H0;BEG02kVf00`j1V0<RV
J@3;YfT0cZQZ0<fWJ@35ZgP0aZai0P37[GX01@35ZgP0`:Ic0;^QKP2gWFX0/ieT0080]9aP01L0]I]N
0;NJF02kVU<0_9Y@0;nKC@31W4`0aIU>0<JJC`37WE40aYmB0<FPDP33We40`Ie?0;fLC@2oVed0_YYL
0;bHG02kUed0^iIO0;^FH@2mV6<0_YUU0;^HGP020;bIG`030;fJH02nVf40_iaR0080`IiT02/0cJEa
0<nWL`3B[GT0ek>10=fiR@3Q_i40iLFF0>S7VP3/biH0kLbI0>k=VP3_cId0k/bN0>g;WP3/bIl0j/NM
0>O<U@3Vb980h/B>0=o0RP3L^hH0g;R40=bgP`3K]X80f<6E0=W2UP3J`iL0gLJJ0>7:WP3Vcj<0j]>W
0>gFZP3beJd0lMBZ0>kAY`3[cZ80j<bM0>G9V@3RaY@0hLFC0>77UP3</X40^Im^0080]I]Z01/0/iUX
0;:HI`2eVfX0/IQR0;2GH@2_UF80[I=R0:fBH`2^TfH0[iAW0;2EJP2dV740]IUb0;JJL`2iWGH0^imh
0;fQNP2oXg`0`:Am0<FWP`34Z8<0bJb:0=2fU@3I`:40glRY0=o:Z`3Mb:/00P3NcZd01P3Oc[00h<nc
0>7@]P3Rd;P0h]2j0>?A^`80hLni0P3Rd;X09P3Pc[P0g/bf0=_9/`3Jb;80e/:Z0=C0Y`3B_ZD0d;bQ
0<fjW03:]iL0b;FD0<NdT`3:/I80bK2A0<R`SP36[XX0a:b80<:ZQ031ZX40`:V00;RNJ`2iWfh0^j5`
0;jSM032YgX0aJYo0<N[P`39[HD0bk2B0<fbU03@]iT0eKfQ0=S3Z03MbK00hLfd0>7?]`3WdKT0im6j
0P3Vd[X03@3Udkd0iMC00>CE`P3UeLD0hmK50>KLdP3WgM<0jMoE0>_Qe`3]hmT0knGK0?7Wg@3bj=h0
203aim/80>oYg@P0lN_O00H0mN_R0?G[h@3ejn40mN_O0?G/g@3ek=/20?G]fP080?K]gP3gjmd0mn_K
0?OZf@3hjMH0n>OC0?SVdP3hi]030?OXd`80m^OB0`3ei]480?GSc@<0m^;:0P3ehLT30?CPb0P0l=o;
0`3^hM020>oRd@<0l>?B00<0k=kA0>gOdP3]gm800P3]gm830>kPd`P0kN7A0`3`iM<20>oTdP<0k^?A
0`3ahM430?3Pd080kmo?0P3_g/`0103_g/X0kmo80>oOaP3^g/D20>kNa080kn3;0P3^glX30>gNb@03
0>cMb03_fl80km_200D0km_200@0k][10?3K`03`fl00kmZo0P3^fKh0103]f;d0k=Nl0>cG_03[e[/2
0>_F]`060>cE]@3[d[<0jm6`0>c?[@3[cjX0jlfY0P3ZcJd20>W<[0<0j<^[00L0ilZZ0>S7YP3WaZD0
ilJU0>G4X`3T`j80hl:Q0080h/6P203Q_YP30=jjVP80gKVI0`3L^9P20=jjVP80gk^K00@0h;bL0>6m
W@3Q_Id0h[jN0`3M^IT20=jjVP<0gk^K00P0h/6P0>?2X@3T`j80iLBS0>K5Y03WaZD0j<NV0>W8Y`80
iLRX1P3VbJT01P3SbZ/0i<^/0>C;[03Uc:d0i/f^0>O>[`80j<n`0`3WcKH50>S>]`040>OB]@3XdkH0
j=>f0>SC]P80jMBg0P3ZeKP40>SC^0@0im:g0`3XekT30>WH^P80j]Vk0`3Yel420>[H`P<0jmW300@0
j][30>_Ka03[fl@0jm_40P3/g<D20>gMaP/0k=_70P3]g<P30>kMb@T0k=g8203/g<D20>oK`P80k][1
00@0kMW00>cH_`3/f;l0jmNn203]fL080>gI`@P0km_2203]fL00103_fl80k][10>kJ`@3^f/420>gI
`080k=Ro0P3]fL00103/f;l0jmNn0>_G_P3Ze[d20>WE_0P0k=Ro203]eKT80>kF_P<0jMVo0P3Xf;h3
0>OG_@T0kMFm0`3/e;`20>_C^`80j]:j0P3/dkD0103[d[@0j]6c0>W@/P3Yd;820>S?/@<0i/f_0P3U
c:h30>C;[@@0i/R^0P3WbJl20>S:/0080>S7Y03WaZ<0i/FR0>C3X03S`Yl0hL2M0>2oW03O_Y/20>71
V`030>2oW03P_ih0gkjM0080gkjO00<0gkfQ0=jlX03N`9h00P3N`9h00`3M_id0g;jL0=^mV`020=^m
V`80g;^H0`3M_9T30=jmVP80g;jJ00@0fkfI0=ZlV03J_9P0fK^G0P3H^YH80=^kU0<0g;^H0P3M_9T3
0=jmVP030=nnV`3N_IX0g;^H0080fkZG00<0g;^H0=jmVP3O_Y/0203M_9T0103M_IH0g[jG0=jnU`3N
_YL40=noV0030=^kU03J^Y<0fKVB0080f;RA00<0fKVB0=ZjT`3K^i@0203K^i@80=RhT@80fKJ>0P3H
]Hd40=NdS0090=NgT03F]Xl0e;B=0=>cS03D]8d0eKF>0=RhT@3I^I80e[J?00<0eKF>0P3D]8d20=>c
S0T0e;B=00<0d[:;0=2`R@3>[XL00P3=[HH0103>[XL0cjn80<n/PP3?[8820<j[P@@0cJZ000<0c:Uo
0<fZP03>Zh400P3@[H<00`3>Zh40cJZ00<bYO`020<f[O@040<bZO03;ZG/0bJMi0<RVN0<0ajEg00H0
bJIn0<VVO039YW`0bJMj0<VWN@39YgL20<VXM@060<VWM`38YWH0b:If0<NUM@36Y7@0aJ=c0P34XW82
0<:MJ@@0`iiZ0P34Wf/30<>OJ`80`YiZ0`31WFT00`2jUVH0^iMW0;fIJ@020;jJJP030;fIJ@2kUfL0
^YIV0080`9i^0`31Wfl30<:PL0<0a:1`0`33Wfl20<:NKP80_ie]0P2nW6`20;fKJ`80_9YZ0P2oVfL0
102nVVH0_IUU0;fII@2lV6@20;^GH`<0^YMQ:oooool002[ooooo1@2XODX30:MlB@P0Z7m700H0Z7m9
0:QoA`2XOdL0Z8150:R0@`2XP4820:R1@0030:V0BP2ZPD/0Zh9<0080[8==00<0Zh9<0:Z1B`2YP4X0
202YP4`50:b3C`<0Zh9>202aPe40402eQe<0^H]G0;jCH034VVP0bZ9a0<jXN@3AZg`0dZf00<n]O`3?
[H00d:j10=6^Q03B[hL0dk2:0=>_R`3D/8`20=2`R@80dK6:103B/X/00`3C/h`0dK6:0=:bR`020=:b
R`80dk><1@3D]8d30=>cS080d[:;0P3;[XH0103<[hL0cK280<f`R03>/HT20<nbRPP0d[F=0P3A/Y<0
0`3A/i40d[B@0=:dSP020=:eS@0A0=>fS03B]Xl0d;B=0<naR`3A/H/0dk6<0=2/R038Y800`iei0;F?
JP2VP5/0UW19091[@@2BKD40UG13095]?@2<J3P0102DKSl209E_@080UW1100P0V7<o09A_>`2AK3P0
Tfhj09Ud@02KMT80V7<o09A_>`P0V6li202@JcL8091Z>`P0SfXf00/0TFHi091U>02?I3L0Sf@g091U
>02BIcX0U6Tl09I[?P2DJSP0TVPf095W=@0208mU<`03095W=@2BJ3H0U6Xh0080T6Hd0P2AIcD2099X
=P80TfTg102BJ3H209=Y=`80U6Xh00@0SFPd08iY=@2>JCD0SVTe0P2?JSH2091[=`T0UF/i00<0SfXe
095/=`2CKST00P2DKcX00`2BKCP0SfXe08eX<`08099]>@80Tfhj0P2BKCT3095/>004091[=`2?JSH0
SfXf08mZ=P<0T6/g0P2AK3P01`2@JcL0TF`h099]>@2CKSX0U6lk09E`?02FLCd0102GLSh209Ia?@<0
UG0l202DL3`209=_?`0409A`@02ELD40UG5109Ib@P80Ug=30`2HM40309Ue@@80VWI20P2FM4@0102G
MDD0V7I609UgA`2IMdL209YhB0P0UgU701D0Ug];09EiB@2@M4@0Rflo08IZ>P23IcL0P6@d07mS<`29
JCH0Q6Hd07aP<@1`Ebh0IDlZ05U69P1A@2@0C3`R04Pl8P14>1h0@CDK048f7017>b400P1:?R@02@19
?B<0>C8O03Pa7`0f<Ah0<BhM02h/7@0Z:ad0:2PL02HX6`0302X[6`<0:b`L0P0/;Ad0300d=1`0=cLM
03Hd6`0f<QL0?CPK04M08`16@200@CPI02@W800S9Ql08B@M01lR6`807R4J0P0O8Q/01P0J91T072@I
01/S600L8QP07b8I028S6`809BDM01T09RHN02PX800_;B40=S<R03hh8P16?B00D4<P05Y<9@1SE2T0
LeXT07aT:022JRX0QFhZ08M_;`26KCL0NEde06U<:P17>A`0>S<I02d/600V:Q/0:RhO03<b7P0l=A/0
@C<F00P0?c<M00`0@C8O040a7P0n<Ah0?C8N03Xb7@0i<ad0>38L03Lb700j;a/0?34M03hc7`11=R84
04<h900X04Xn9P16>bD0@3DQ03L^7@0`:1/0:R@H02HR6@0U81X0:28R024P6`0P8aP09b`H02h^500i
;Q00CcPI06A59P1jGBD0Rfdg09YlAP2PPTh0Y8ID0:^<G@2/SEl0Z8UK0:b:FP2OODd0UWA409mmC@2_
SEd0/8iN09ekB`29IcL0BdDe03dj:@0f<b@0=S@W03@d:00/;R<09bXO02T/8`P092LP00P092DP02DV
8@0W:280:BXR02/]8P0];b80;S0S02la8`<0<S<U0P0a<R@3030a8`0803Da9@0c;b<0<BdQ030/800_
:al0<2`P034]8@0b;R8203Da9@@0=30T0P0c;b<203Dc900603Hc900g<B<0>30S03T_8`0h;R80>RhR
0P0l<2000`0m<B40?S8R03lc8`02040d9005044e9@14=1d0ASHO04Ph8@1:>R<00P1<?2D304/k9008
03hf8`10=B<0@CHT04<f9@16=RH0BCPX04Xg:01;>2T204/i8`0304`j901=>bD0CS`V0080CcdW00@0
D3hX04`j8P1>?2@0DClW0P1D@RX01P1C@BT0DClW050n9P1??R@0D3lU05509P80DT4W00H0DD0V050o
9@1@?bD0G4@X05Y29P1I@BD205Q0900;05Y29P1LA2P0GTHZ0694:P1TARX0ITP/06U<;P1ZCBd0JTd[
06U=:01XC2L00P1NBbX05`1NBb/0GDX/05a8;@1JARd0F4@[05I2:P1IARP0F4@Y05A39`1A@BL0CT0V
04Xn9P19?BL0Ac`V04Di8`14>280@SLS03lg900m=R<0>SDR03Tc8`0g=2<0>S@X00<0>C<W0P0h<RH2
03La9@P0<RhR0P0g;B400`0h;R80>BlS03X`900203/a9@0903`b9P0b<b<0<C8R030a8`0^;R80;2`R
02XZ8P0Y:2<0:2LR00<09RHN0P0W9al302PX80P09bPP00@0:2PN02TY7`0Y:Al0:BTO0P0Z:R0202/[
8@80<2/W00@0<2/U030/8`0`;240<2`P0P0`;Ah0200f<RH0<blS030/800^:Qh0;BTM02hZ7P0`;200
<BdQ200h<R@203@Z7P0303H/800h;R80>c4U0080?38V05P0>c4U03X`900k=BD0?3DU03/d8P0l=240
?c@R048e8P16=b80B3TT05M29@1IA2L0FTDX05M29@1D?b80DchQ05M29@1KART0Fd@U05Y29P1F@BH0
E3hW050k:01;>2T0B3HX04Hd:018=R80BcTU04lm9`1D@RX0ED@Z05E4:01C@RH0DD0R04i6;`1=@R`0
CChW04dm901B?RD0Fd<Y0698;`1XCC80KD`Y06]:9`1XBRP0Jdh^06eB=01ZDC80HT//05]49@1<@RL0
Cd<Y05A5:01H@b@0Fd<Q06948P1]BbH0ME4]08UR>@28HcT0RF@g08UW=`2;K3H0SW4g08me>02AN3P0
T7YA08igCP2:LdT0Qfm308EZ?@24J3T0QFHh08EV=`25ICh0QFDl08AT>`25ISX0QVLi08QY>P2;KC/0
SFlm095b>`2ALS`0TW<m099b?`2CLd80UGE60P2FMDP02`2ENTD0TgQ3091e@02?M3l0T7E009=h@`2G
O4L0VGi909AjA`2BN4D0SgE20080SG=000<0T7I309=iAP2FO4T00P2DMd/0302EN4h0U7M=099eC@2?
LD/0Rfe908U[A`2=KT00Sg1209=dAP2GN4X0Vga>09enD080WWmA0P2PRF060:6:H@0A0:V>E`2^Te`0
]IYS0;^PJ@2oY6d0`:E^0;jSK02mXV/0`:=[0<6RJ`32XfX0`Z9W0<:PH`30W5h0_iUK0;fGF035V640
0P35V5l03P33UeX0`YMC0<>ID@34Vd`0aYe;0<NOBP33WeD0a9mH0<FPFP37XF00aj5S0<JOI034WFH0
`iaU0P34XVD01033XF@0`Z1S0<6OHP30WV420;jLG`0=0;RIF02kW5`0_IiN0;^KGP2hV5d0]iMN0;ZI
H`2nWFL0aJMc0<^]N@3E]hD0gl2A0>K7V@020>W:WP060>S8W`3^d9`0kLnK0>c>VP3[cIT0j/bH0`3Y
biL0703Qah`0h<>90=boQ@3H^H00e[Im0=NdO03I]7d0f[En0=ZkPP3K_8D0gL280=k3S03Qb980hlbH
0>K?W@3Vd9h0lMJQ0?3EX03_e9l0kM:M0>W>V@3TbI@0h<F@0=k3SP3QaiH0eK^:0;ZPK`2_UF@20;^Q
L0030:nEI02^U6<0[IIZ00L0[IIZ0400/9U_0;6JL02dWG<0]Yme0;ZSN@2mYW`0_jQn0<2YO`2lYWl0
`J^40<VcSP3B^iT0f/>S0=o8Z@3QbZ/0h/Z^0=k9ZP3ObZ/0glb^0=k=/@3PckD0h=2g0>3A^P3Qd[/0
hm6i0>;@^03QckL0h<jf0=k<]03Mbk<0g<Zb0=_9/@3La:X0fL6W0=JnXP3B^i`0ckRH0<jgU@3=]Y@0
cKNB0<RdT@37/i00ak6<0<J^R034Zh<0a:R00<:VOP32YG/0^Yi^0;^OL02nXW<0`ZEi0<JYO`39[8@0
bjf70<b^R03</Xl0ckFD0=>kV@3H`J40flJW0=k;[@3Pc;40gljb0P3Rd[P20>?C^P0=0>GE_P3VeL40
j=O50>WHaP3Yf<P0jMc;0>[Mc@3Zg/h0j^7B0>_SeP3/i]X0jnOL0>cXg@080?3VfPP0lnOK0P3aj=T0
0`3aim/0lNOM0?7WgP020?7Vh0030?7VhP3_jMd0knWM00<0l>[N0`3ajml80?C^gPP0mNcM203gimL3
0?OXe@80m^OD0`3ei]<30?KQcP80mN3=0`3dgl`80>kQd0<0l^GE0P3ai=@30?3Sd`P0l^GE203_hm<8
0?7Ue@P0ln3?203]h<d80?7Lb@T0km[7203^f[l80>cD^P080>gB]03/dK<0jm6`0>[@[@3YcjX0j<nW
0>O>YP3VcJ@30>?7X080h/JO0`3QaIh80>;5X`P0i<NU203Qa:@80>O:[0P0iM6`0P3Vd[430>OC/P<0
j=Bc203[eKd80>[F_PP0jmNo203/f<080>cJaPP0l=k:203^g<P30>gKa`80k]c8303_gLT80>[Nb0<0
lMg50P3`g<@30>oK``P0km_2203]g<X30>gMa080k=c30`3[fl880>gMa0<0kmk40P3^gL<30>gL`P04
0>cJ`P3[fL40jmW10>_I`@80j]S0103Yekl20>[H`0<0jmW100<0k=[20>gH^`3]f;/01P3]f;/01P3W
eKd0j=Jn0>WG_`3Zf<00jmW10>cJ`P80kM_3203/f/880>WG_`<0jmNn0P3Ze[d30>WE_0<0j]:f0P3Y
dKD30>S@]080i/jb0`3UcK430>C</080i<^]103Uc:h20>K=[`080>S9[03Wb:/0i/NX0>G7Y@3SaJ<0
h/BP0>73W@3P`Y`20>;1WP030>70W@3P_i`0gkjK00<0g[fJ00<0gKbI0=k0WP3N`9h01P3N`9h40=jm
VP80gKbI0P3L^iP30=fmUP80g;bE0`3K^i@30=ZjT`<0fk^D0P3L_9DH0=nnV`P0gknF203L^iP00`3J
^IH0fkZG0=bkV0020=flV@030=^jU`3I^9D0ekJC00P0f[ZC203F]Xl0103H^940ekN@0=NgT03F]Xl2
0=FeSP80e;B=0P3E]H`20=BdR`040=>cRP3B/XT0d[:90=6aR0<0dk><00<0e;B=0=FeSP3F]Xl00P3F
]Xl0203@/8T0dK6:0=:bR`3C/h`0d[:;0=6aRP3?[hP0cZj70`3?[8@20<j[P`<0cJZ200H0bjQn0<fZ
P03>Zh40cjb20=2]P`3?[8820<fZP0040=>aP@3@[Wh0c:Yj0<VWM`80ajEe0P39YgL02P3;ZGT0cZUm
0<jYO@3?ZWd0cj]k0<jZN03<Z7@0bJEa0<RUK`3;YgL20<ZVMP030<VUM@38Y7@0aj=c0080aZ9b00<0
`im_0<BPL036XW800P37Xg<02`35XG40`im_0<:NKP31W6l0`Ye`0<>NL@34Wg80`iia0<:ML030Vfh0
_YU/0080_YYV00<0_IUU0;bHI02kUf<00P2jUV802@2iUF40_9QX0;fIJ@2nVVX0`9a/0<:NKP34X700
aJ5a0<JRLP080<FQL@80`im_00<0`Yi^0<6MK@30W6`00P2oVf/02@2nVVX0_iY^0;jIK@2nVF`0_9QX
0;^GI@2jUV80^IEQ0;VFH0030;VHHR_ooooo000Zooooo`H0Z7e:0P2WO4T80:QoA`80Z7m900<0Z7m7
0:R0A@2XP4<00P2XP480102XPD00ZH1:0:Z1B`2[PT`20:b3C@030:^2C02ZPD/0ZH1:00P0ZH1<1P2/
Pdl20:^2CPP0/H=A00h0]HMC0;V;E`2mTUl0a9YX0<ZRL@3=YgP0d:Yk0=6/O`3?[Gl0cjf00=2^P@3A
[X@0dZn70=:_R@80djn;0P3A/HX20=:bR`D0dk><00@0d[:;0=>cS03C/h`0dk><0P3D]8d20=FeSP<0
e;B=0P3C/h`30=:bR`030<b_Q`3=/8P0cK280080c[690P3?/XX00`3@/h/0d[F=0=:eS@060=:eS@80
d[>D00<0d[BB0=:dT03B]8h00P3B]Hd04P3C]X`0dKF>0<jbR`3=[hT0d;2:0=6_RP3>ZXH0aZ9n0<6K
M`2bS6L0YGmJ09I`B@2@Jd40TVe109A_@P2AKCd0S6Ph09=]?P<0U6ho0P2EKd0209I`@@0809Qc?`2D
Kc/0TVdi09A_>`2HLcl0VWE109Mb?P2DKc/809Q_>@P0T6/g202@JS/808mZ=P0;099W>P2AIST0T6Dh
08mT=`2@ICP0TFHi09=X>`2DJC`0TfTg099X=P2@IS@00P2?IC<00`2@IS@0TVPf09=Y=`02091V=080
TFLe0P2BJ3H209=Y=`04095W=@2BJ3H0TVPf099X=P80TfTg0P2DJSP408iY=@80SfXf0P2@JcL909E[
>@08095/=`2BKCP0TVdh09=^>@2BKCP0TF`g091[=P2?JSD:099]>@80TF`h102@JcL308mZ=P80T6/g
1@2AK3P0102BKCT0Tfhj09A_>`2EL3`209Ia?@<0Ug8n0P2FLCd309E`?0P0U70l00<0Tflo09A`@02D
L4000P2ELD4209Ib@P0409Mc@`2HM400V7A009Qd@0<0VGE10P2JMT8209IdA00309MeA@2HMTH0VGM7
0080VWQ800<0VgU909MiA`2GNDL01P2GNDL05@2FNTX0U7Q808mc@`2:KSh0QVXj08=W=`22ISH0PFDe
08UY=P24IS@0O60a071G;P1UCbX0FDHV0550901<?280B3`R04@h7P11=A/0@SHL04Lk8@0204Xn9009
04Pl8P0i<Ql0>34O03Ha7P0a;Qd0;R`M02X[7@0X:1`09RPK00<0:R/K0`0[;1`202`]7@0;03<c6`0f
=Qh0=S@K03Hb5`0m>1/0ASlR04Dn8@10=aP092LP02<V7`0P8a`0100N8AX01`0O8Q/06R@I01`T6@0K
8aP0728H01lR6@0R8a/00P0U9Ad06@0V9Qh0:2PN02l]8@0g=2<0?cTQ04Hm801@@b00FdhT06=D:@1c
FR@0O6@X08=[:`25KRX0R70`08I]=`1iGCD0J4/Y04Hh6`0j<aT0;2/G02HZ6`0Y;Ah0<c8N03/d6P11
<aH0200n<Q`01P10<Ah0?S4N03ha7P0l<Ad0>S8M03Pb7080=c8L00@0=blJ03Ta700k<ah0?SHQ0`10
>2<0:@0o=b80AC/R048g8@0k<ah0=2dK02hX6P0X91T09R8I02@Q6P0X8R808B0K024T6@0W;1P0;RhD
03X_4@1@>AX0IDHW07eP:02>L3X0WX1:0:B6DP2YReT0/95R0;6BI02]SV00[8YJ09mmC@2GMDD0X7i>
0:n=G@2`SUh0W7Y:08MU=@1:A3@0?CXY03Hc900g=BP0=3@X02`^8`0X:b00:B`S00P092LP00P092DP
02DV8@0W:280:BXR02/]8P0];b80;S0S02la8`P0<C8T00P0=C4U03<_8`0a;B40<2`P02l[7`0`;200
<BdQ038^8PH0=30T0P0c;b<203@b8`0303Db8`0g<B<0>C4T0080>S0T00H0?30T03da8@0m<B40?S8R
03lc8`10=2@2044e9@05048f9P15=Ah0ASHO04Ti8P1;>b@00P1<?2D304/k9008040e8`11=R@0@SDT
04<f9@17=bL0BCPX04Xg:01;>2T204Xh8P0404/i8`1<>R@0CC/U04hl9P80CcdW00D0CC/S04hl901@
?RH0DClW0590:002054o9`03050n9P1@?bD0D3lU00<0D3lU0P1A@2H04@1B@BL0Fd<W05Y29P1I@BD0
F40T05U19@1J@RH0G4@X05i6:P1WBBl0ITP/06A6:P1TAbT0IDPX06Q;:@1[CbX0KE4/0080Gd`[01H0
GDXZ05]8:P1JAR/0FDD/05Q4:`1HA2`0FTLY05U5:P1EA2P0DT8X04m19`1;?bL0BShX04Pm9`17>2<0
ACTS04@g9011=R@0?SHS03`e8`0j=2@0>C<S100i<bL203Pb9P80=c4U200b;R8203L]8@0403P^8P0i
;b<0>S0T03/a9@80?38V00P0<S<S034b8P0`<B<0;RhR02`/8P0Z:R80:BPS02PW8P809RHN0P0W9al3
02PX800302TY8@0W:2009bPP00H09bPP100Y:Al202XZ8080:b/Q0P0_:RH02`0_:R@0<2`S034]8P0a
;B40<BhO038_800c;b<0<RhR034]8@0`;200;b/O0080<2`P00<0<BdQ03Pb900h<R@01P0h<R@203@Z
7P0303H/800h;R80>c4U0080?38V00h0>c4U03X`900l=RH0?CHV03`e8`0l=240?c@R044d8@15=R40
AcPS05M29@1IA2L0FTDX05M29@80DchQ03X0Ed8U05]6:@1KA2D0FT8V05I19P1B?RH0CC/W04Xi:@18
=RP0ACDX04Pf8P1;>BD0CcdW05=1:@1EA2X0ED@X05=29P1A@280Cd@^04e1:@1<?BH0CC/S05<m9@1J
@RP0HdP]06U;<@1]CBL0K4/X06U;9`1[CR`0K58a06YA<P1SC2d0GDHW04i2:01BA2T0ETDY05U49@1M
@b80I4HR06i<9`1fDbd0QV4g08QS=`28ISP0RVXi08a^>02>LCT0SW@i08id=`28LDP0QVm508E/@`25
JSl0QFPl08MX>P28JCX0RVXk0P26ISd01`25ISX0QFHh08MX>@29JcT0S6hl08e_>`2ALS/00P2BLcd0
0`2CLd00U7A309AdA@0209EdA`0309AiA02BMd80Sg@o0080SG8m00H0T7E009=h@`2FNdH0TgU6095g
A02>M44208ab?`0408id@@2AMd@0TgU609=gB080TgI:00/0TWE;091cB`2=KdT0RVa808QZAP2=KT00
Sg1209=dAP2GN4X0VW]=09amC`0209enD080W8=J102MQ5/209j5G0050:F:D`2XSEH0[Y=L0;>HH@2g
W6D00`2iWVL20<2SJ`070<:SJP33XfP0a:9U0<>OH`31WEl0`I]M0<NLI@020<JLHP0?0<FLGP34VeT0
a9aD0<FND@37XE00b:9?0<NRF`38Xed0bJAP0<ZTH`3:Y6H0bJ9W0<NPI`36WfP0`j5T0080`Z1S0180
`ImR0<2NH@2nW5l0_YaO0;fKGP2kW5`0_IiN0;jNH@2mWF00^YYO0;bLH`31X6X0aZE_0<^]N@3@/Wh0
fK^90>;3U03YbY`20>_<X00I0>[:X@3^d9`0kLnK0>c>VP3Zc9P0j<ZF0>O9U@3Vb9@0iLNC0=o5RP3N
`HL0f[f30=JgOP3E]G`0ekAl0=VdO@3J]Gh0f[^40=bmQP3M_hT0glB?0>;8U@3Sc9P0i/nM0>OAW`02
0?3EX00:0>oDW`3]dYd0j/nJ0>K;UP3Rai80glB?0>;8U`3G_H`0_:9a0;6GIP80_:9a0P2`UVD80:jG
J`100;6JL02bVg40]9ec0;NPMP2jXgT0_JIl0;nXOP30ZGl0_:Io0<6[Q039/hh0d[^I0=[3X`3Ob:T0
hLZ[0>;:[P3NbJX0glZ[0=o<[P3NcK40h<ne0>3@]`3PdKX0hM:k0>?A^@3Rd;P0hLng0>3>]P3Nc;@0
gL^c0=c:/P3KbK40g<BZ0=[2Z03F_Z80d[^L0<nhV03>]iD0cKJD0<fgTP38]940ak>@0<NaS036[XP0
aJb40<BXP033Ygl0`jIl0;ZNKP2lX740_Z9c0<:UN@35Z7h0b:^30<^]Q`3<[XP0c;:?0<neU03C^iT0
f<6Q0=_6Y`3Nbjd0h<ba0=o>/P80h]:h0P3SdkX03@3UeKh0i]G10>SGa@3Yf<H0jMS80>WLb`3ZgLd0
j]k>0>[QdP3[hmH0k>KJ0>_Wg03/j=d0203`i]X80??Wf`80lNSI00<0lNOK0?7Wg@3aimh00P3ai^00
0`3ai^80knSN0>oXgP030?3Yg`<0lN[P203dk]h80?G/g@P0n>SI0P3hjMH20?OXe@<0m^OD00@0mNKC
0?ORc`3gh/l0mn;?0P3fhLh30?GPc@P0kn;A00@0l^GE0?7Te03ai=@0lNCD0P3`hm<20>oRdPP0lNCD
203`i=@80?7Ue@P0ln;@203]h<d80?;MbPT0l=_8203_fl880>oG_`80k]Fg00H0kMBe0>cD/P3[djl0
j]:/0>WAZ`3XdJP20>_?ZP80j/jY0`3YcJP00`3Xc:L0ilZZ0>O:ZP0>0>O:ZPP0j<^[203Ybjl80>KA
/P040>OB/`3Xdk@0j=>d0>SC]080jMBe0P3ZeKH80>cF_PP0jmK1203/el880>gH``P0k=_7203_g/X8
0>kMb@<0kMc80P3^gLT<0>oNbPP0jmo90P3bgLP20?7La`<0l=_600<0km[50>oK`P3_fl801P3_fl88
0>kMb`040>kNa`3]gLH0kMg60>gMaP80k=c50P3[fl@80>kNa`040?3Oa@3_g/@0kmk40>oNa080k]g3
0P3]g<820>cJ`P80jmW10`3Zf<020>WG_`<0j]S00P3[fL420>cJ`PP0k]Vn0P3Xe[h01P3Yekl0j]S0
0>_I`@3/f/80kM_30>kLa0P0k=[2203Yekl30>_G_P80j]Jm0`3YeK`0103[dkL0j]:f0>[B]P3Zd[H2
0>WA]@80j=2d0`3Wck<20>K>/P<0iLfa103Uc:h40>K=[`80j<V/00@0ilRY0>G7Y@3TaZ@0h/BP0P3Q
`id01@3S`Yl0h/6N0>;1WP3Q`9d0h;nL0080gkjK0P3N_IX80=k0WP040=nnV`3N_IX0g[fJ0=jmVP80
gKbI0P3L^iP30=fmUP<0g;bE0P3K^i@30=ZjT`80fk^D0`3L_9DH0=nnV`P0gknH203L^iP00`3J^IH0
fkZG0=bkV0020=flV@030=^jU`3I^9D0f;ND00P0f[ZC203F]Xl30=NgT0030=JfS`3E]Hh0eKF>0080
e;B=0`3E]H`00`3D]8/0dk>:0=>cRP020=:bR@80dk><0P3D]8d20=FeSP80e[J?00<0d;290=6aRP3B
/X/00P3C/h`00`3A/HX0cjn80<j^Q`030<n/Q080cZ^30`3=ZX80303=ZX00cZ^10<n/PP3@[H<0cjb2
0<j[P@3<ZGl0bjQn0<n]O@3>[7`0c:Yj0<ZXN080bJMg0`3:Z7P20<fXO0070<jYO03>ZWX0cJUg0<^W
L`39YG40ajA^0<^WM`020<ZVMP030<VUM@38Y7@0aj=c0080aZ9b0100`Yi^0<>OK`35XG40aZ9b0<NS
L`36XW80a:1`0<>OK`32WG00`iia0<BOLP35X7<0a9mb0<>NL@31W6l0_iY]0P2nVVH0102mVFD0_9QT
0;^GH`2kUf<20;ZFHP080;bHJ02mVFT0_YYZ0<2LK032WVh0a:1`0<FQL@36XW880<FQL@80`im_00<0
`Yi^0<6MK@30W6`00P2oVf/01P2nVVX0_iY^0;jIK@2nVF`0_IUY0;^GI@80^YIR00@0^IIP0;RGHP2h
Uf80^9MR:oooool002[ooooo202XODX80:QoB@060:QoB`2XOdT0Z7m90:QoA`2XP4D0Z8130P2XP480
0`2YP4X0ZX5;0:^2C0020:b3C@030:^2C02ZPD/0ZH1:00P0ZX5=202/Pdl80:n4D@0@0;F7D`2hRUH0
_I9O0<>II`38X6l0c:Ig0<nYNP3?ZWd0cZan0<j/O`3?[H00d:f30=6^QP3B[hT0dZj:0=>_R`80d[:;
0P3C/h`40=BdS@030=FeSP3C/h`0e;B=0080e;B=0P3E]Hh20=JfS`80e;B=0P3C/h`30=:bR`030=6a
RP3>/HT0ck::0080ck::0`3@/h/90=6dS080d[>D00<0d[BB0=:dT03B]8h00P3B]Hd04@3B]H/0ck>;
0<b`R03;[XH0c:b50<f[Q@3:Yh40`Iih0;bFL@2^R6<0XgeH09I`B@2@Jd40TFa009=^@@2AKCd0SFTi
00<0Tfdn0P2DKSl309E_@00809Ia?@2DKc/0TVdi09A_>`2GLSh0V7<o09Mb?P2EL3`809M^>PP0T6/g
202@JS/808mZ=P0309AY?02BIcX0TFHi0080Sf@g00D0T6Dh095V>@2BIcX0TVPf095W=@04091V=004
095W=@2BJ3H0T6Hd091V=080TFLe0P2BJ3H209=Y=`<0TFLe0P2BJ3H309=Y=`<0SVTe0P2?JSH3091[
=`T0UF/i00@0U6lj09=^>@2BKCP0TF`g0P2@JcH00`2AK3L0TVdh099]>@07099]>@80TF`h0P2@JcL3
08mZ=P0308iY=@2?JSH0SfXf0080T6/g0`2AK3P01P2BKCT0TF`h099]>@2BKCT0Tfhj09A_>`80UG0l
00@0UW4m09Mb?P2GLSh0Ug8n0P2FLCd309E`?0P0U70l0`2DL40209Ea@@<0UW920`2HM40309Ue@@80
VWI200H0UWA409MeA@2GMDD0V7I609UgA`2JN4P209]iB@P0V7Y800D0UGU9099fAP2>LT80RFdm08IZ
>P0308AX>00=08UY=P24IS@0O60a071G;P1UCbX0FDHV0550901<?280B3`R04@h7P11=A/0@SHL04Lk
8@0204Xn900904Pl8P0i<Ql0>34O03Ha7P0a;Qd0;R`M02X[7@0X:1`09RPK00<0:R/K0`0[;1`202`]
7@0<038a700e=Ad0=S@M03Hb6@0l=Q`0AChR04@m800m=1L092LP028U7P0P8a`07R4J0P0M81T0200N
8AX07b8K01XT6@0L91T06b<H01`R600O8QT08R<K0P0U9Ad06@0V9Qh0:RLN030/800i=240@3PQ04Pm
7`1BA1l0GDhU06MF:P1dFbD0OFDY08A/;026Kb/0R70`08I]=`1hG3@0IdXX04Hh7@0i<AX0;2/I02DY
6`0X;1h0<S4O03Xb6`10<QL0200k<1`203d`7`0403`a7`0i<Ah0>34N03Ha7@80=38M00H0=RhK03L_
700j<Ql0?3@Q03de8P0n=R<203de8P0L03ld7P0j<Qd0=blL034Z6P0]9a/0:2@K02DR6`0T8A`0:28R
024P6`0Q91T0:2dI030`5P0l<A<0DS/L06M8:@20Hb/0TG<m0::4CP2YReL0[i5O0;JGJ02gV6X0/Y=U
0:b:FP2OODd0V7I60:5oC`80/8iN00X0VgU908AR<P19@c<0?3TX03Hc900g=BP0=CDY02d_900X:b00
:B`S200T9b00200U9R409RLR02LX8P0Y:R80:bdR02`^8@0^<2<0;S0R0P0_<280100`<B<0<C8T034b
900b<bD203<d9P0803Da9@0c;b<0<BdQ030/800_:al0<2`P034]8@0b;R8503<_8`<0=30T0P0c<B80
1P0e<R<0=c4S03Ta900k<BD0?38V03hb9P80?S8R00<0?c<S040d9011=BD00P12=RH01@13=bL0ASHO
04Lg8019>B80Bc/T0080C3`U00/0Bc/T04Xj8`1:>R<0@CHT048e9013=RD0ASHV04Pg9`1:=bP0C3HX
04dg:@0204Tg8@0304Xh8P1;>B<0C3XT0080CC/U00<0CS`V04lm9@1>?2@00`1=>b<03@1??BD0D3hV
054o9`1B@BL0DD0V04hm8`1=?280CSdS050o9@1C@RP0ED@Z05]39`1J@RH00`1I@BD08`1K@bL0G4@X
05e5:@1ZC380IdT]06=5:@1P@bD0HTDU06M::01]DB`0LED`069?;P1PCB`0G4TY05U6:01HA2T0F4@[
05U5;01KAbl0FTLY05Y6:`1FABT0E4@Z0553:@1=@BT0C40Z04Xo:@18>B@0AcPS04@g9012=bD0?cLT
03`e8`0k=2@0>S@T00<0>C<W0P0h<RH303La9@P0<RhR00H0=bdQ03P^8P0h;R80>BlS03X`900k<BD2
03`b9P08038c8`0a<R80<34S02h^8P0/;280:RXR02TX8`0X9b8302LW7`80:2PP0`0Y:B4802PY8@<0
:BTO0P0Z:R0302/[8@80;BPT00/0;RTS030/8`0a;B80<RhR03<`8@0d<B80;b/O030/800a;B40<RhR
03<_8`02038^8P03034]8@0h<R@0>38T00H0>38T0P0f;2000`0g;B40>2hR03X`900303/a9@0=03X`
900n>2P0?SLW03`e8`0l=240?c@R044d8@14=B00ACHQ05E2901GA2H0F4DW05I39@02058o8@1805I3
9@1JAbT0FD@U05Q39P1D@2D0CcdU04`j9P19>2P0ASHW04De:018=R80BcTU04hl9P1B@2P0E4<Y05A3
9`1C@RH0DT4S04i2:P1<@2P0CCdT04dl8P1C?R<0Fd4V0697:P1WBBd0KdlY06i>:01/CRX0K4l]06aB
;`1YDBl0Hd`/05m8:01C@bT0ETDY05Y7:@1MARH0GdDR06I8901_CbP0MeD_08EP=025HcH0RFLi08a/
>`2>L3`0S74j08Ya>@29L3L0OVLm07iU?01nISX0PFHi08=W>028JCX0Rf/j08e]?027Ich0QfPl08IW
>`27J3X0R6Tj08]]>`2=Kc/0Sg4m095d?02ALcd0TW@n09=e@@2CMD<0TgA50P2CM4H02`2AMD<0Sg=1
08ea?`2;Kcd0RVhl08a`?P2>LT00Sg=1099fA02@M480SG4o0080Rflm0100S70n08ib@02@M480TGE5
095eAP2@M4D0Sg9608e`AP2;KTH0RF]508MY@`2=KSl0Sg1109=dA@2GN4T0VGY;0`2KO4d309UnD`80
VWmD0`2KP5D04@2QQTl0XhQA0:J;E02YSUL0[I9K0;6FG`2cV640]IYS0;fRJ`30XV`0`ZE]0<BUK036
YV/0ajEX0<RTJ037XfD0c:=[0080bZ9W0180bJ5T0<RQH038XE`0bJ=J0<ZTF@3;YUP0bJIR0<ZWI@3;
Z6H0bjQX0<^WJ@39YFT0aj=Y0<JRJ031Wf80`9iQ0;nMH02nW5l20;fKGP80_9YM02P0_IiN0;nOHP2o
Wf80_YiS0;fMI032XF/0bZUd0=:aO03D]X80fK^70>73T@3XbIX0kLjP0>o@Y03^cj<0k/jU0>g?W@3/
cY`0jlfK0>W;V@3Vb9H0hlFC0>73T@3P`Y00g<:90=^nQP3G^X80e;En0=>bO03F/gd0f[F00=^fP@3K
_8D0gKj80=k0RP3PaI00hlVF0>C=V`3Wcil0j=:Q0P3_dj403P3^dZ00kM6O0>_?W@3WbiT0i<RF0>;6
U03SbIP0fKn>0<2VM@2dVVT0_ZAc0;fSLP2bV6L0/iUX202_V6`09@2aVW00/Y]a0;FNM02gX7H0^Z=i
0;fVO02oZ7h0`:Uo0;fWP032[8D0b[B?0=:kV@3J`j<0g/NX0>39ZP3QbJd0g/VZ0=o:Z`3Oc:h0g/fa
0>3?]@3Pd;L0h=6j0>7B^`3SdKT0h]2h0>7?]`3Pc[H0g/bd0=g;/`3Lb[80flVa0=c4ZP3J`ZP0e[jR
0=>lW@3@^IT00P3>]iD06@3>^9<0b;BA0<NcT038/Xd0aZj80<F/Q035ZH40`jMo0<>VO02kWfl0_:1a
0;jRL`31Y7P0a:Mm0<NZPP3:[8H0c:j80<bbS`3?]I@0dk^I0=S1X@3KaZL0g/^]0>3</@3Oc[800P3R
d[P20>?C^P0=0>GE_P3VeL40j=O50>WHaP3Yf<P0jMc;0>[Mc@3Zg/h0j^7B0>_SeP3/i]X0jnOL0>cX
g@080?3VfPP0lnOK0P3aj=T00`3aim/0lNOM0?7WgP020?7Vh0030?7VhP3_j>00knSP00<0l>WQ0`3a
j^880?C^h0P0mN_O203fjMT20?OZf@80m^WH0`3ej=L0103dimH0m^?B0?KSdP3fhm830?GRd@80m>7@
203`hm830?7Te080l>?C0`3_h]880?7Te0P0l>CD203bi]H80?CSd`P0kn;A203bglh90?3Mc0P0kmg5
203`g<@20?7I_`060?3H_03_f;T0k]Ng0>kG]@3]e[@0kMNb0P3afKL30?3H]P<0kmNe203[d[@80>W@
/PP0kMBf203[dKH80>SE]`<0jMJh0P3ZekT30>_H^PP0kMW1203[fL<80>cJa0P0kM_5203]g<X@0>oN
c080k]g;0`3_g/`30?3Oc@T0lN3>203/gl`20?7Ob@80l=k80`3_gLL00`3^g<H0k]c40>kLa0060>kL
a0P0kmk<00@0kmo80>kNa`3^g/L0k]k70P3]gLH20>cLa@P0kmo80`3`g/H20>oMa@<0k]c400@0kM_3
0>cJ`P3/f/80k=[20P3[fL440>[H`080jmW10`3/f/800`3]fl<0kMW00>gI`0060>gI`080jMNo00<0
j]S00>_I`@3/f/800P3]fl<00`3^g<@0kM_30>gK``060>gK``P0j]S00`3/f;l20>_G_P<0j]Jm0`3[
dkL20>[B]P<0jM6e00@0j]:f0>WA]@3YdKD0jM6e0P3Xd;@20>O?/`P0i/f_00P0jLZ]0>S9[03Wb:T0
i/RV0>C6Y03SaJ40h/BN0>73W@80hl:O00<0h/6N0>70W@3P_i`00`3O_Y/00`3N_IX0g/2N0=k0WP06
0=k0WP<0gkjK0P3N_IX30=flV@80g[jG0P3M_IH30=blU@030=^kU03J^Y<0f[ZC0080fk^D0`3L_9D0
0`3M_IH0gkjK0=nnV`0F0=nnV`P0gknH203M_9T0203K^YL0g;^H0=flV@3M_9T0g;^H0=^jU`3J^IH0
fKRE203J^Y<80=JfS`80ekN@0`3F]Xl30=FeSP@0eKF<0P3D]8/20=>cRP040=>cS03D]8d0e;B=0=Bd
S@<0eKF>00<0e[J?0=6aRP3B/X/00`3C/h`00`3A/HX0d;290<j^Q`030=2]Q@80cjb40`3>Zh<02`3?
[880d:f30=2]P`3@[H<0cjb20<fZP03:Ygd0b:Ek0<ZXNP3;ZG/0c:Yl0080cJ]m00d0c:Yl0<ZXNP3:
Z7X0bJMi0<^VNP3<Yg/0cJQk0<fYN@3<Z7H0bZIb0<RTL036Xfd0bjMg0080bZIf00<0bJEe0<RTM037
Xg<00P36XW801031WFd0`Yi^0<BPL035XG430<JRLP040<FQL@33WW40a9mb0<FPL`80aZ5d00@0a9mb
0<:ML031W6l0_i]W0P2nVVH00`2mVFD0_9QT0;^GH`020;ZFHP080;bHJ02mVFT0_YYZ0<2LK032WVh0
a:1`0<FQL@36XW880<FQL@80`im_00<0`Yi^0<6MK@30W6`00P2oVf/02@2nVVX0_iY^0;jIK@2nVF`0
_IUY0;bHIP2kUf<0^YIR0;ZGH@030;NFHB_ooooo000Zooooo`<0Yga9102XODX00`2YOT/0Z7m;0:Qo
B`060:QoB`060:QnC02XOd/0Z7m;0:QoB@2XOdL0Z8150P2XP4<00`2YP4X0ZX5;0:^2C0020:b3C@03
0:^2C02ZPD/0ZH1:00P0ZX5=0`2[PTh40:b3C`030:f4D02^QE40[XEA00H0[XEA00h0]8IB0;R:EP2l
TEh0`YQV0<NOKP3:Y7D0cJMh0<fXN`3=Zgd0cJ]n0<j/O`3?[880d:f50=6^R080dZj:0`3C/h`30=Bd
S@<0eKF>0P3D]8d20=FeSP@0e[J?0`3C/h`30=:bR`80dK6:103@/h/40=6dS0P0d;>;0P3B/i@00`3B
]980d[B@0=6cS@020=6dS00A0=6dRP3</HH0bJj30<NZP038Z7l0b:Mn0<BQN@2lVG40]i5Z0:V3GP2P
NUD0UFm8091[@@2@Jcl0TVe0095]?@2?Jc/00`2CKCh309A^?`80UFm00P2DKc/0102CKSX0U6lk09Ia
?@2GLSh209Ia?@P0Ufdk202AK3P8091Z>`P0SfXf00@0UFXm09=X>`2AIST0Sf@g0P2>HcH0102?I3L0
T6Dh095W=@2AIcD4091V=080TFLe0P2@IS@2095W=@80TVPf0P2CJCL3095W=@<0TVPf0P2CJCL208iY
=@80SfXf0P2@JcL2095/>0T0UF/i00<0UW4l09A_>P2AK3L00P2?JSD00`2@JcH0TVdh09A_>P08099]
>@<0T6/g0P2?JSH308iY=@<0T6/g0`2AK3P4099]>@80Tfhj0P2DKc/209E`?0<0Ug8n0P2FLCd309E`
?0P0U70l202ELD4309Qd@0<0VGE10P2JMT8209MeA@0409QfAP2IMdL0VGM709YhB080VgU9202HNTP0
802ENDT0TWI608ea@@28K3`0QFTi08AX>025JCT0QVXj08UY=P24IS@0O60a071G;P1UCbX0FDHV0550
901<?280BCdS04Di7`11=A/0@SHL04Lk8@1:?R@0BCdS04Lk8@0i<Ql0>34O03Ha7P0a;Qd0;R`M02X[
7@0X:1`09RPK0`0Z:a/302//7080;2dM00`0<C0L03@c7P0e<ah0=C0J03/e7@14?B<0@CXN03/a5P0S
9Ql08RDN020S700N8AX201dP6@807R4J00H06R@I01`T6@0K8aP0728H01lR6@0R8a/202DU7@0I02HV
7P0[9a`0<R`N03/d8@13>B00BchN05E67`1QD2D0JELY07EL9P1nIRX0QVh^08Qa;@29LC40QVdg07MK
<`1UB2H0ACLM03P`6`0[:AX092LL02P[800a;b00>S8M040b600803L_700<03/_7`0j;Qh0>2lN03L`
7P0e<1d0<c0M038_700a<1`0<b`J03@]6`0f;ad0>34O0P0j<b40:P0i<R00>34O03H^6@0d;AX0<R/I
02hX6P0Z9Q/09b@K02<R7@0S8Qh0:28R028Q700R9AX0:BhJ034a5`0n<aD0EChO06Y;;020Hb/0TW@n
0:B6D02[SET0/I=Q0;RIJP2hVF/0/iAV0:^9F@2OODd0VGM70::0D02aSel0[heM09QfAP21Gbl0Ad4a
03/h9`0e<R<0>3HY03Hf:P0^<2D0:2/P02T/8`P092LP0P0V9b801P0W:280:BXR02/]8P0/;R40;BlR
02h`8P80;RlQ00@0;c0R030a8`0b<bD0<c@V0P0d=BL01`0e<BD0<blS034]8@0`;200;b/O030/800a
;B400`0b;R8403<_8`80=30T0P0b<2401P0d<B80>38T03Xb9@0l<RH0?C<W040d:080?c<S00@0@3@T
044e9@12=RH0@SHV0P13=bL00`17=b00B3PQ04Xj8`0304`l9@0304/k901:>R<0BSXS0080@cHU00@0
ASHV04Lf9P19=RL0C3HX0P1==RP01P18=R00BCLQ04Tg8@1:>280BcTS04`j9080CC/U0100D3hV04hl
901<>R80BSPP04/i8@1<>R80CcdU054o9`1C@RP0DD0V04dl8P1;>R00C3/Q050o9@1D@bT0EdH/1@1J
@RH08`1K@bL0G4@X05a4:01VB2h0IDL[06=5:@1SARP0IDPX06Q;:@1/D2/0Ke<^06AA<01PCB`0FdPX
05M49P1F@RL0Ed<Z05Y6;@1LB300FdPZ05Y6:`1GARX0EDD[0594:P1>@RX0CD4[04a1:`1:>BD0BCPT
04Lh9@14=bH0@SLU03he900m=2D0?3DU0080>C<W0P0h<RH203La9@80=S0T200b;R8203P^8P0303T_
8`0j<2@0>c4U0080?38V00T0?C<W038c8`0a<R80<34S02h^8P0/;280:RXR02TX8`0X9b800`0X:202
02TY8@<0:RXR200X:B4202TY7`80:RXP0P0[:b4202`/8P80;2LS00h0;RTS02l[8P0a;B80<blS03@a
8P0e<R<0;BTM02l[7`0b;R80=C4U03Hb9P0e<BD0<blS038^8PP0>38T0P0g;B400`0h;R80>BlS03T_
8`0403X`900<03hh:00n=bL0?CHT03`d8@0n<b40@3<P04@e8015=R40DT4S05A39@1EA2H0Dd8T0P1@
?b403`1D@bD0FDPZ05U49@1F@bD0DD0T04dk8`19>2@0AcLW04@g9`13=BP0B3HR04Xh901>?2H0DClW
05=2:00205=29P0905918`1=@BL0CT0V04hm8`1@?240ECdQ05a1901SABT0IdP[0080L50Y0380KU0Z
06iB;@1/DRl0J50/06A=:`1QBRX0FTDZ05a7;01PBBX0HDTW06=6901XBR@0LU8Y07UI<021Gc80Pf<d
08QX>@2<KCh0Rflm08U_?025KSX0PV/g07]S=`1lHCH0OF8e07mS=023I3D0QfLf08]Y>@2=K3T0RFXn
08UZ?028JC/0RFXk08Y/>P2<KSX0Sg4k091b?02?MC`0T7Dn095f?`2BMd80TWI4095eA@2?Ld@0SW93
08ib@P2<L400RVhn08Q/?080Qf/k00D0RFdm08Y^?P2@LT00Sg4o08e_?@0208]]>`0@08a^?02>L3h0
Sg4o08mc@`2>LT80SW9308a`@@2;KT80RFa208Q[@`27JT80SW0n091b@02CMD<0UWQ609QjB0<0VG]9
0P2GO4d0102HODh0VGi?09UnC`2JOe0209^0D@80XHI?00`0XXM@0:B9DP2XSEH0[I9K0;:GH02eVV<0
^j9/0;fRK@2oY6d0`jI^0<NXK`39ZFh20<f[KP0E0<jZL03=ZFl0cJU_0<^WJ`3:YVP0bJIT0<ZWH`3;
ZF80c:YS0<RVI`39YfP0bZQY0<ZXJ`39YfX0aZAW0<BQI`33X6H0`9iQ0;nMH02mVeh0_9YM0080^iUL
0P2lVUd0402mWF00_imR0;nOI02oWfH0`9mY0<NVL@3B/Gh0g;^80=o1S@3SaI40j<ZH0>k?X03adZ@0
l]>W0?7BYP3`d:L20>_<W@0G0>[;W03XbIX0i/NH0>;3U03O`940gKj?0=_0R@3I^hD0eKN10=:cO@3B
/G`0e[9n0=ZeP@3M^8@0gKj80=jnR`3P`Xh0hLFC0>C:V@3VcYh0jM6S0>WCY03^dZ800P3_dj<03@3^
dZ80k=2P0>W=W@3VbYX0i<RH0>C:V@3K`I00`jUh0;NMK02oYG@0_J=b0;BJJ@2fW6/0202aVVh0@02c
W780]9ec0;FNM02hXGL0^Z=i0;fVO02nYgd0_jQn0;jXP@32[8D0b[B?0=>lVP3J`j<0g/NX0>39ZP3P
b:`0g/VZ0=o:Z`3Oc:h0g/fa0>3?]@3Pd;L0h=6j0>7B^`3SdKT0h]2h0>7?]`3Pc[H0g/bd0=g;/`3L
b[80flVa0=g5Z`3J`ZP0eknS0=>lW@3@^IT0ckRF0<jgU@3>^9<0bKFB0<RdT@38/Xd0ajn90<F/Q035
ZH40`jMo0<>VO02lX700_J5b0;jRL`30XgL0`jIl0<JYP@3:[8H0c:j80<bbS`3?]I@0dk^I0=S1X@3K
aZL0g/^]0>3</@3Oc[820>;B^080hm>j00d0iMFn0>KE`@3XelD0jMS60>WHb03Yg</0j]g=0>[NcP3Z
hM80jn?F0>cVfP3[im`0k>SM00P0l>KJ203cim/20?7Xf@030?7Wf`3aimd0lNON0080lNKP00<0lNKR
0>oXh03_j>000`3`jN430?7ZhPP0m>kR203fk>880?KZg0<0mn_K0P3fj]X30?GYf@<0mnKF0P3fiMD3
0?GTe0P0l^GD0`3ai=@30?3Sd`80kn;B203`hm<80?7Ue@P0lnOG203di=D80?7Te0P0l^7A2@3ah=08
0?7Pc0P0l^3<00T0l]g80?;NaP3bg/H0lMg40?7M`P3`gKl0l=fm0>oL_03dgl800`3cg/420?;M`080
lMbo203_f[l80>cG_0P0k]Vn203^f<0;0>[I_`80jm[00`3/fl480>kLaQ00kMc8203^gLT80>oOc`P0
k]k>203`h=030>oOc`80l>3@303ahM480>kQd0<0lN3<0P3`gl/30>oNbPP0kmo8203`gld20?3Ob`<0
kmk:0`3^gLT80?3Ob`<0lMo90P3`g/P30>oMa`@0kM_30P3/f/840>_I`@80k=[2103]fl<80>cK`@<0
jmW100<0k=[20>gK``3]fl<02P3^g<@80>_I`@80kMW00`3/f;l30>_G_P<0k=Bh0P3[dkL30>[B]P04
0>cD^03[dkL0jm>g0>_C]`80j]:f0P3YdKD20>S?/@@0ilj`0P3VcJl0203Zbjh0jLZ]0>S9ZP3WbJL0
iLNU0>C6XP3SaIl0h/BN0P3T`j000`3S`Yl0h/6N0>70W@030>2oW0030=nnV`3O`Il0gl6O00H0gl6O
0`3O_Y/30=jmVP80gKbI0`3N_YL20=fmUP<0g;bE0`3K^i@30=blU@80gKfF403O_Y/80>2oW0P0h<2J
2`3M_9T20=bkV080fkZG00<0f[VF0=ZjT`3J^Y<01P3J^Y<>0=JfS`80eKF>0`3F]Xd50=FeS0@0e;B=
103E]Hh0203A/HX0d[:;0=>cS03D]8d0dk><0=:bR`3@/8T0cjn80P3A[XH30=2]Q@<0cjb400h0dJj4
0=:_Q@3B[hD0dJj40<j[P@3;Z7h0b:Ek0<JSN@35XgH0b:Ii0<bZO@3?[H00d:j10<j/O`80bjUl00X0
bJMj0<ZUN@3;YWX0c:Mj0<bXN03;YgD0bZIb0<RTL037Y6h0bjMg0P3:YWH00`39YGD0b:Ad0<NSL`02
0<JRLP060<6MK@32WVh0`im_0<BPL035XG40aZ9b0P37Xg<00`34Wg80aJ1c0<JQM0020<NRM@030<FP
L`33WW40`Ye`0080_i]W00<0_YYV0;fII@2lV6@00P2kUf<02@2jUV80_9QX0;fIJ@2nVVX0`9a/0<:N
KP34X700aJ5a0<JRLP080<FQL@80`im_00<0`Yi^0<6MK@30W6`00P2oVf/02@2nVVX0_YU]0;jIK@2n
VF`0_IUY0;bHIP2lV6@0^iMS0;^HHP030;JEHR_ooooo000Zooooo`80YW]80P2WO4T0102XODX0ZGi;
0:UnB`2YOT/80:QoB`060:QnCP2XOT`0Z7m;0:QoB`2XOdT0Z7m70P2XP4D00`2YP4X0ZX5;0:^2C002
0:b3C@030:^2C02ZPD/0ZH1:00P0Zh9>0P2ZPDd20:^2CP040:b3C`2]Q500[HA@0:f4D0P0[HEA00h0
/hEA0;N9E@2kT5d0`9IT0<FMK038XW<0bjEf0<^VN@3<ZW`0c:Ym0<f[OP3>Zh40cjb40=2]Q`80dJf9
00@0d[:;0=>cS03C/h`0dk><0`3D]8d20=FeSP<0e;B=0P3E]Hh30=JfS`80dk><0`3B/X/30=6aRP@0
dKB<303@/h/20=6bT`0F0=6cT@3@/Xh0ck6;0<nbRP3>/HT0c[670<R]P035ZWd0`jIj0<BUN@33XWL0
_iab0;JCJ@2`Rf40XgeH09afD@2DKTL0T6]108mZ?P2@Jch0TFdm091/?080TV`m0`2CKCh309A^?`04
09=^>P2DKc/0UG0l09E`?080U6lk00<0UG0l09Ia?@2FK3`01`2FK3`8095/>0P0T6Xk202?JSH0102D
JC`0TfPk095V>@2?I3L208iS=P0308mT=`2@ICP0T6Hd00T0T6Hd0P2AIcD2099X=P80TfTg0P2@IS@3
095W=@<0TVPf0`2?JSH2091[=`<0TF`h2@2EJcT0202GLSd0UG0k099]>02@JcH0SfXe095/=`2CKST0
U6lj202BKCT0102AK3P0T6/g091[=`2@JcL208mZ=P80SVTe0P2@JcL3095/>0<0TVdi102CKSX409A_
>`<0Ug8n0P2FLCd309E`?0P0U70l202ELD4309Qd@0<0VGE10P2JMT8209MeA@0409QfAP2IMdL0VWQ8
09]iB@80W7Y:202INdT0102ENDT0TWI608ea@@27Jc/208AX>00J08EY>@27Jc/0RFTf08AV=01lH340
L5L^06E?:P1IARH0DD0T04`l8P1:?R@0ASXP048f7013=ad0ASXP04Tm8`18?280ASXP03Tb7`0h<Al0
=S4N034^7@0^;1d0:R/M02PX700V:1/302X[6`<0:b`L0P0/;Ad0300_;Q`0<c8N03@b7@0e<1`0>cDO
048j8`0o>1h0=bdD02<V7`0Q91d07b8K01dP6@8071lH00P07B0I01hQ6P0J91T072@I01/S600L8QP0
7b8I028S6`809BDM01T09RHN02dW6`0d;Ad0?3@Q04Di7`1=?Qd0ETLP06=@9@1]F2T0MUdW081X;028
L300RW<_08Yb<P26KCL0METa06=69014=Ah0=blL02XX6`0S9Qd09bXQ030^8@0i<Ah0?c0I00P0=BhK
0P0g;Ql00`0f;al0=2hN038_7P02030_7@0702h_7@0_:AT0<B/K03<]7@0e;al0=S0P03D_7`0203@^
7P0X030Y5P0_:QH0;RPH02/W6`0Y9Qd09BDM02<T7`0R8ah0:28R028Q700R9AX0:RlK03<c6@10=AL0
F44R06e>;`1oHRX0TW@n0:B6D02/SUX0/I=Q0;NHJ@2fUfT0/I9T0:Z8F02OODd0VWQ80:B2DP2bT600
[XaL09IdA01mFb/0AT0`03Xg9P0e<R<0>CLZ03Lg:`0^<2D0:2/P02T/8`P092LP00P09RLR02LX8`0X
:B<0:BXR02X/8@0/;R40;BlR02d_8@80;RlQ00@0;c0R030a8`0b<bD0<c@V0P0d=BL0200e<BD0<blS
034]8@0`;200;b/O030/800a;B40<RhR0P0a;B42038^8P80<blS0P0d<2@02@0b<240<c4R03Db8`0h
<R@0>S8U03dc9`0n=2P0@3@X03hb8P0203lc8`03040d9011=BD0@SHV0080@cLW00L0B3PQ04Ti8P1;
>b@0C3`U04dm9P1<?2D0Bc/T0080BSXS00H0ASHV04Lg9`18=bL0BCHW04/e9`1==RP204le:080BCLQ
00<0BSPR04/i8`1<>R@00P1=>bD04@1>?2H0DClW04lm9@1<>R80BcTQ04Xh801<>R80CS`T050n9P1B
@BL0D3lU04dl8P1;>R00C3/Q050o9@1EA2X0F4L]0080FD4U00<0FT8V05]39`1K@bL00`1K@bL0801O
@BL0HD<W06I8;01YC2h0K4l_06a?;@1ZCRT0JDdX06AA<01PCB`0FdPX05M49P1F@RL0Ed<Z05Y6;@1L
B300FTLY05Y6:`1GARX0E4@Z0594:P1?@b/0CT8/04e2;01<>RH0BcTU04Th9P17=bL0@cHU044e9@10
=2H0?SDV0`0h<RH203La9@<0=S0T200b;R801P0h;R80>BlS03T_8`0j<2@0>c4U03`b9P80?C<W00P0
<S<S034b8P0`<B<0;RhR02`/8P0Z:R80:BPS02PW8P<0:BTQ0P0Z:R8302/[8`P0:BXR0`0Z:R0202/[
8@<0;2`R0P0/9b<03P0^:B<0;b/R034]8P0c;b<0=34R03Db8`0^:Qh0<2`P03<_8`0f<RH0=c<W03Hb
9P0d<2@0<RhR200g<B<603T_8`80>S0T00d0>c4U03dg9`0n=bL0?3DS03`d8@0o=280@C@Q04@e8016
=b80D3lQ05=2901D@bD0DT4S0080D3lQ04h0E4<U05U8:P1HABD0Dd8T04ln8P1:>R40AcPS04<f9@12
=RH0@SHX04Tg8`1:>2@0CC/U04lm9@1A@2H0DT4U05=29P1C@R@0Cd4V04lo9@1??R80DchQ05Po8@1O
@R@0IDHY06U8:@1bDRT0Le<Z079E;@1`E2d0Je4/06M?:`1UCbX0I4d[05m5:P1SB2d0IDX/06I99`1V
BRD0JdhV07=F:P1jGC40OUh_081Q<P25ISL0Qf/k08M/?@23Jc/0OfTh07eW>01nHcH0Of8f07iR<`21
HS<0Pf<b08IU<P2;IcD0S6Pd08]/?P2;K3d0RV/l08Y/>P2<KSX0SW0j095d?02BMCd0SgHm091g?`2A
N400TWU3095gA02?MD@0SG9308]`@@2:KSl0RFdn08M[?026JS/308EY>P0E08IZ>`2=KC`0SFdl08a/
>`2;JcX0S6`k08e]?02>KSd0Sfln08ib@02=LCl0S71008Y^?`29K400R6/o08Q[@@27JT00SW0l091b
?P2CMD40UGM300@0UgU500D0VGe;09YnC02JOT`0Vgm=09f1C`0209j2D00@09n3D@2TRE80XhQA0:>8
D@2URU<0ZHiG0:jCG02dVF80]iaU0;NPK02jX6d0_:=]0<2UKP35Z700bZ]b0<j^L`80cjmd0P3=[G80
1`3;Zg00bZY]0<VYK03:Zf/0bja/0<^/J`37Y6`00`37Y6X01`35XVP0`Z1S0<2NH@2nW5l0_ieP0;jL
G`2lVUd00P2jV5/0502kVE`0_9YM0;jLG`2mWF80_imT0<6QJ031X6X0a:=^0<f/N@3I]hL0hl6A0>S:
UP3[cIT0k]2N0?;CY03ce:H0lmBX0?7BYP3`d:L0jLZL0`3Zbid0503XbI/0iLJH0>;3U@3P`I<0g<6<
0=ZlR03D]X80dK5n0=6`O@3E/Gl0f[B30=fgQP3N_X/0gkn>0>73T@3SaiL0i/^L0>O?X@3ZdZH0j]>W
0P3_dj@03P3`e:D0km>T0>gAXP3ZcYl0il^L0>G9VP3SbIP0gL>B0<J/N`2iWfh0_jEd0;bRL@2dVVT0
^9i]202cW7009@2dWG<0]Iid0;JOM@2hXGL0^jAj0;fVO02nYgd0_jQn0;jXP@33[HH0bkF@0=>lVP3I
`Z80gLJW0=o8Z@3Pb:`0g/VZ0=o:Z`3Oc:h0g/fa0>3?]@3Pd;L0h=6j0>7B^`3SdKT0h]2h0>7?]`3P
c[H0g/bd0=g;/`3Lb[80flVa0=g5Z`3K`jT0eknS0=BmWP3A^YX00P3?^9H02P3?^I@0bKFB0<RdT@38
/Xd0ajn90<J]Q@36ZX80a:R00<BWO@2mXG420;fQLP0=0;jQM@31Y7X0aJR00<V[Q@3;[HL0c;:?0<ne
U03C^iT0f<6Q0=_6Y`3Nbjd0h<ba0=o>/P020>;B^080hm>j00d0iMFn0>KE`@3XelD0jMS60>WHb03Y
g</0j]g=0>[NcP3ZhM80jn?F0>cVfP3[im`0k>SM00P0l>KJ203cim/20?7Xf@030?7Wf`3aimd0lNON
0080lNKP00<0lNKR0>oXhP3_j>800`3`jN<30?7Zi0P0m>gS203fk><80?G[g`040?O^g`3fkMh0m^gN
0?K]gP80mNcM0P3djm`30?SXf080mnOG0`3fi]H80?CWeP80lnKF0P3biMD30?7Te0030?3Sd`3ai=@0
lNCD00H0lNCD203bi]H80??We`P0lnGH203bi=L80??Sda40l^;B203chm<0203ch]80ln;@0??Rd03b
hLd0l^;;0?;Rb@3bh/P0lN770`3bh<P30?7Oa`80l=k6203bh<X80>oMa`P0kMc2203`g/P:0>gKa@80
k]c60`3_gLL00`3`g/P0lMo;0?7Ob`060?7Ob`P0kn3=203^gl`80?3QcPP0kn;A203^hM080?3SdP<0
kn;A0P3`hm8<0?7Td`P0l>?B00@0l^?@0?7Rc`3ah/l0lN;?0P3`hLh20>oPc@P0kn3;2`3ah<h30?3O
c@80kmk<203ah<h30?;Pc080lMo;0`3`g/X30>kLa0<0kM_3103/f/830>gK``<0k]c4203]fl<00`3/
f/80kM_30>gK``020>gK``/0k]c4203/f/820>kJ`@80kMW0103/f;l30>gE^@80k=Bh0`3[dkL40>cD
^080jm>g0P3Zd[H00`3ZdK<0jM2b0>W@/P020>S?/@80ilj`00T0i/f_0>_<[`3Zbjh0jLZ[0>S:Z03V
b:H0iLNS0>C6X03SaIl00P3Ua:400`3T`j00hl:O0>;1WP030>70W@030>2oW03O`Il0gl6O00H0gl6O
0P3P_i`30=nnV`<0g[fJ0P3O_iP20=jnU`80gKfF0P3L_9D20=^kU0<0g;bE0`3M_IH@0=nnVa00h;nL
2@3N_IX20=flV@80g;^H0`3K^YL80=ZjT`P0e[J?0P3E]Hh60=JfS`H0e[J=0P3G]hh40=FeSP@0e;B=
00<0d[:;0=>cS03D]8d00P3D]8d00`3B/X/0d;290<n_R0020=:_Q`80dJj6103@[HD30=:_Q@0;0=6^
Q03>Zh40bjQn0<RUN`36XgT0`j1f0<NTNP3<ZGl0d:f30=6^Q03?[8800P3;Z7h02P39YW`0bJAh0<ZU
N@3<YgX0c:Qh0<bXMP3;Yg<0bJEa0<RUK`3;YgL20<ZVMP030<VUM@38Y7@0aj=c0080aZ9b0`33Wfl2
0<BPL0060<FQL@36XW80aj=c0<BOLP35X7<0aZ5d0P37XWD01035X7<0`iia0<:ML030W6P20;nKI`03
0;jJIP2mVFD0_9QT0080^iMS00P0_9QX0;fIJ@2nVVX0`9a/0<:NKP34X700aJ5a0<JRLPP0aJ5a0P33
Wfl00`32WVh0`Ie]0<2LK0020;nKJ`060;jJJP2nVFd0_YU]0;jIK02mVFT0_IUW0P2mVFD0102lVF<0
]iEU0;NEI@2gUFD[ooooo`00:_ooool01P2UNTL0YW]80:IkB02WO4T0Z7e:0:UnB`80ZWm<202XOT`2
0:QnCP040:QnC02XOd/0Z7m;0:QoB@80Z7m700<0ZH1:0:Z1B`2[PT`00P2/Pdd00`2[PT`0ZX5;0:V0
BP080:^2CP060:V0C02ZPDd0ZX5=0:^2CP2/Pdl0[HA@0P2^QE480:^6D@090;>5D@2fR5@0^XmL0;nE
H`34W6/0aZ1a0<VSM039Y7L0bjUk0080c:Ym00<0cJZ00<j[P`3?[8H00P3@[8P30=6aRP<0d[:;0`3C
/h`20=:bR`80dk><0`3D]8d00`3E]Hh0dk><0=:bR`020=:bR`80dK6:0P3@/8T0103A]8`0d;>;0=2c
R`3@/h/30<nbRP030<jaR@3?/XX0ck::00H0ck::0P3?/9400`3>/8h0cJn;0<b^R0020<^^QP0A0<Z]
P`35ZWd0`ZMj0;nRMP30XGD0_Yeb0;VFK02`SF<0ZXEK09egDP2ILdh0Tfe608mZ@02>JCd0SfXm091/
?02AKCd00`2BK3d209=]?P<0U6ho00P0TF`h09=^>P2FLCd0UG0l09=^>P2BKCT0UG0l09Mb?PP0UV/n
202BKCT8091Z>`P0SfXf00<0TVLj095V>@2?I3L00`2>HcH01@2?I3L0T6Dh08iT<P2?IC<0T6Hd0080
TFLe00<0T6Hd08mU<`2>I3800P2@IS@2095W=@80TVPf0P2CJCL3091V=080TFLe0`2BJ3H208mZ=P80
T6/g0`2AK3P00`2BKCT0UF/i09E[>@0709E[>@0509E`>`2DKcX0Tfhi099]>02AK3L00P2BKCP00`2C
KST0TVdi099]>@09099]>@80TF`h102@JcL3095/>080TVdi1P2CKSX409A_>`<0Ug8n0P2FLCd309E`
?0P0U70l0`2FLT8209Ea@@<0U7100`2HM40309Ue@@80VWI20P2HMTH209UgA`0409YhB02KNDT0W7Y:
09ajBPP0VG]900@0V7a<09=gA`2=LD40Qf/k0P23IcL06P25JCT0QVXj08UY=P24IS@0O60a071G;P1U
CbX0FDHV0550901<?280BclU04Hj8012=Q`0@cLM04Hj8019?B<0B3`R04Hj800i<Ql0>34O03Ha7P0a
;Qd0;R`M02X[7@0X:1`09RPK0`0Z:a/302//7080;2dM00`0;RdK038a7`0d<Ah0=2lK03Xc8011>B@0
?CDN03DZ500R9Ah08B@M01lR6`0M81T201`O60807B0I00H06R@I01`T6@0K8aP0728H01lR6@0R8a/2
02DU7@0I02HV7P0^9QT0=B`K03ld8018>Ql0CclM05U77`1WDRD0KUXX07MN:021JBd0RG4a08]d<02;
Lc<0QVdg07AH<01QA280@c@O03H]700Y9a/08RDN02HY8P0_;B40>2lN03h_6P0803@_7080=BdP00<0
<bdO034^7`0_;Ah00P0];Qh0<@0[;Qd0:bPI02dZ6`0_;1d0<2dN034^7`0`;Ah0;b`M02h[700]:1D0
;2TF02`Y6P0[:Ad09bLM02@U7`0R9240828O02PR8P0R8A`08bHK02/`700e=A/0@SLI05Y3901`DC80
PF@/09Af@02VR580[Y1L0;>EH`2gV6T0]YMY0;2AH`2YQeL0Wge=09]iB@2UPe<0/i5Q0:j<G02CLD40
NUPX04@n;P0i=RD0=C8S03Tg:P0h>2`0;c4V02T/8@0Y;2<0200T9b00200W:2<0:2TT02PY8`0Y:R80
:R`Q02/]800/;R40;2hP0P0_<280100`<B<0<C8T034b900b<bD203<d9P0803Da9@0c;b<0<BdQ030/
800_:al0<2`P034]8@0b;R82030/8004034]8@0b;R80<blS03<_8`80=30T0P0d<R<01P0f<b@0>C<U
03/c9P0l<RH0?C<W03lc9`80?C4Q00@0?S8R03lc8`10=2@0@3@T0P11=BD00`19>B80BSXS04`l9@02
04dm9P0404`l9@1;>b@0BSXS04Xj8`80BCPX00<0BSLX04`f:01==RP00P1?=BP01`1@=2P0BSPR04/i
8`1;>B<0C3XT04dk9@1>?2H00P1??BL00`1A?bL0D3hV04lm9@0304dk8`0404hl901??BD0D3lU04ln
9080CC`R00L0CSdS05509P1EA2X0EdH/05Q0901I@BD0FT8V00<0G4@X0280Fd<W05Y29P1K?B<0H48V
06I8;01/Cc40Ke8b06e@;P1ZCRT0Id/V069?;P1PCB`0G4TY05U6:01HA2T0F4@[05U5;01KAbl0F4DW
05Q4:@1EA2P0Dd<Y0553:@1>@RX0CT8/04a1:`1?>RL0CSTV04/h9`19>2P0ASHV04<f9P12=2L0@3@V
0P0h<RH203La9@<0=S0T00<0=BlS038^8P0b;R801P0b;R8203T_8`0303X`900k<BD0?38V0080?C<W
00T0?S@X038c8`0a<R80<34S02h^8P0/;280:RXR02TX8`0X9b800`0Z:R8202/[8`<0;2`T200Y:R82
02XZ8080:b/Q0`0/;2803`0];B<0;BPT02dX900^:B<0<2`S034]8P0b;R80<c0Q03@a8P0b;R80<blS
03@`900e<BD0=S8V03Da9@0203@`90P0=c4S0`0j<2@08`0i;b<0>2hR03P^8P0i;b<0>S0T03/a9@0k
=BD0?3DU03/d8P0l=240?c@R048e8P16=b80B3TT04ho801A@R<0DT<T05528`1>?b00Cd0Q05=49@1H
BBX0ETHU0593901=?R40B3XP04<g8@11=R@0?cHU040g:019=b<0BSPT04`j901>?2@0D3lU0080DT4U
02X0Dd8T05529@1B@BD0E44S05Q18P1L@B<0Hd@U06Q7:01/BBT0M5DY07IG:`1eF2h0LED]06]B:P1W
CbT0IU0Y06MA;01VAb/0JDX^06Y;;01ZC2X0JT`V06iA9`1fFBd0O60a07eO;@1oHBl0P6@d085V=`1o
IcT0OFHj07YU>P1iI3T0PVHg08=T=P23I3D0Q6@c08IU<P2:IS80SFPd08iY=02=KSl208a^?00?08a^
>P2>L3X0T7<k09=f?02DMcd0T7Ln095h@02BND40TgY4099hA@2?MD@0Rg1108U^?`27JSh0QVTm0080
QFPl0P24Ic/208EX?0<0RfTi0140S6Xj08i/?02@KSh0TFlo099`@02>Lch0SG8m08]_?@2:KSh0RFdn
08Q[?`29K400RFa208ma>`2@LS`0TgDo09Eg@@0209Ih@P0:09Eg@@2DMT00W7i809anB02MOdT0WX1:
0:22C02QPdd0XXA>0:>5C`<0YHYC00h0YhaE0:^@F@2`UEh0]IYS0;RMIP2cWF/0]IiZ0;NPK02lXfd0
`JI_0<NZLP3<[G@0cZmf0<jaM@80cK1d00@0bZec0<V/LP38Zg40b:]a0P39[7820<FTK`090<FTKP34
Y6/0`Z9W0;nOHP2lWEd0^Y]K0<2NH@2nW5l0_9YM0080^YQK01H0^iUL0;jLG`30WV40`J5X0<BTJ`38
Yg40bZUd0<j]NP3F]8@0h/2@0>_9V`3_dId0l=:N0?;DXP3ce:D0lmBV0?7BYP3_d:@0k/jU0>K7V`3X
bId0jlbP0P3]cZ804`3[c:00jLZN0>O8W03O`i40g;j<0=JhQP3A/H00dJmo0=FaP@3K]HH0g[R90=no
SP3Q`I00hlBE0>C8V@3Wc9l0jM6U0>_BZ@3/eJ/00`3ae:P03@3`djL0kM2T0>[=X@3WbYh0iLRL0>;8
U`3M`i80ajel0;VOKP2nY7<0^j5`0;BJJ@2iWfh0202eWW80@02eWW@0]Yme0;NPMP2iXWP0^jAj0;fV
O02nYgd0_jQn0;nYPP34[XL0bkF@0=>lVP3I`Z80gLJW0=k7Z03Oaj/0g/VZ0=o:Z`3Oc:h0g/fa0>3?
]@3Pd;L0h=6j0>7B^`3SdKT0h]2h0>7?]`3Pc[H0g/bd0=g;/`3Lb[80flVa0=k6[03K`jT0f<2T0=Bm
WP3A^YX0d;VG0<nhUP3?^I@0b[JC0<VeTP39/hh0b;2:0<J]Q@36ZX80a:R00<BWO@2nXW80_Z9c0;fQ
LP2mX7@0`:=i0<BWO`38ZX@0bjf70<bbS`3?]I@0dk^I0=S1X@3KaZL0g/^]0>3</@3Oc[820>;B^080
hm>j00d0iMFn0>KE`@3XelD0jMS60>WHb03Yg</0j]g=0>[NcP3ZhM80jn?F0>cVfP3[im`0k>SM00P0
l>KJ203cim/20?7Xf@030?7Wf`3aimd0lNON0080lNKP00<0lNKR0>oWi03_in@00`3`j>D30?7YiPP0
m>gU203gk>H80?K/hP<0n>kR0P3gkN430?K/h080n>_K0`3gj]X30?KYf@P0m^WH0`3ej=P20?CWe`/0
lnKF203cimL80?CXf0P0m>SL203di]/80??VePT0l^GE203ci]H80?;VeP80l^CG00@0l^GE0?;Ue03b
iM@0l^GB0P3bi]020??Rd080l^7?0`3ah<h00`3`gld0m>?C0?CSd`060?CSd`P0l^7A203^g/L80?;Q
c`P0l=o=00@0kmk<0?3Oc@3`gld0l=o=0P3ah<h:0?;Qca00kn;A203`hm8@0?3Te0P0lNGE0`3`i=@3
0?7Ue@/0l^KF203biMD30?7Td`80l>?B0`3_h]480>oRc`P0ln;@0P3ch]820?;Qd@<0lN3@00<0l=o?
0??RdP3ch]801P3ch]830??Pc`80l]o>0`3ag/d30>oMa@80k]c41P3]fl<20>kLa0<0kmg5203]gLH8
0>kLa0P0kmg5203]fl<20>oK`P80k][10`3]fL00103/f;l0k]Jj0>kF^P3^e[X20>gE^@H0k=Bh0P3[
dkL30>[B]P80jm:d00@0j]6c0>W@/P3Xck40j<na0P3Wc[00203/cK00jlb_0>[;[03YbjT0ilVW0>K8
Y03Uaj40i<JP0P3VaJ800`3Ua:40i<>P0>?2W`030>;1WP030>70W@3P`Z00h<:P00H0h<:P0`3P_i`2
0=nnV`<0g[fJ0`3O_iP20=jnU`<0gKfF00@0fk^D0=blU@3L_9D0g;bE0P3M_IH20=jnUa00gkjK203P
_i`80>2oWPP0g[fJ00@0gkjK0=jmVP3M_9T0g;^H0P3K^YL00`3L^iP0gKbI0=ZjT`070=ZjT`P0e[J?
0`3E]Hh30=JfS`80ekN@0P3F]Xd30=NgSP<0f;R?00@0e[J?0=FeSP3E]Hh0eKF>0`3D]8d02@3C/h`0
d[:;0=>cS03D]8d0eKF>0=BdS@3C/h`0dK6:0=2`R@020=>`R080dZn70`3A[XH03`3@[HD0dZn50=:_
Q@3B[hD0dJj40<j[P@3;Z7h0b:Ek0<JSN@35XWX0b:Em0<bYP@3?[8@0d:f50<j[P`020<^XP00:0<VV
OP3:YGT0bjIj0<fXN`3>ZWX0cZYh0<fYM@3;Yg<0bZMa0<^WM`80bZIf00<0bJEe0<RTM037Xg<00`36
XW802P35XG40a:1`0<>OK`33Wfl0a:1`0<FQL@36XW80`iia0<BOLP35X7<20<JQM0030<BOLP32WG00
`Ia_0080`9aX00<0_i]W0;jJIP2mVFD00P2lV6@02@2kUf<0_9QX0;fIJ@2nVVX0`9a/0<:NKP34X700
aJ5a0<JRLP080<FQL@80`im_00<0`Yi^0<6MK@30W6`00P2oVf/01P2nVVX0_YU]0;jIK@2nVF`0_YYZ
0;jJJ080_YYV00@0_Y]U0;RFJ02hUVP0^9IX:oooool002[ooooo0P2UNTL01P2VNdP0Yga90:QmBP2Y
OT/0ZWm<0:^0C@P0Z7i>0P2XOE000`2XOTh0Z7i<0:QoB`020:QoB@040:QoA`2YP4X0ZX5;0:^2C080
[8==00<0Zh9<0:Z1B`2YP4X0202/Pdl20:V0C0060:Z1C@2[PTh0[8=?0:f4D02^QE40[hIB202[QU40
3P2bQ500]HMC0;V>F`2nU680`i]Z0<FOL037XG80aj9e0<^YN`3;ZG`0c:Ym0<bYO`3=ZX80cZ^50P3?
ZhL20<n_R0@0d;290`3A/HX20=2`R@80dK6:0`3B/X/0103C/h`0d[:;0=:bR`3B/X/20=6aRP<0d;29
00<0d;>;0<nbRP3?/XX00P3>/HT20<f`R0030<b_Q`3>/HT0c[6900H0c[6901P0cJj?0<b]SP3;[H/0
bZb80<V[Q@38Zh<0ajZ20<NZP033Z7T0_jAe0;fQLP2lWFl0^iY]0;FCIP2/RUd0YX5E09UcCP2FL4/0
Tfe608mZ@02>JCd0SVTl091/?02BKSh2095[?080TV`m0`2CKCh02@2DKSl0T6/g09=^>P2FLCd0UG0l
099]>@2AK3P0U6lk09Qc?`0809EZ?@P0TVdi202@JS/808mZ=P0;091U>02?I3L0SV<f08eR=@2>HcH0
Sf@g095V>@2BIcX0SF<a08iT<P2@IS@00P2AIcD00`2@IS@0SV@b08eS<@02091V=080TFLe0P2BJ3H2
09=Y=`80SfDc0P2@IS@3095W=@04099X=P2@JcL0T6/g091[=`<0TF`h0P2BKCT909E[>@0809=^>@2D
KcX0U6lj09E`>`2DKcX0Tfhi099]>02AK3L8099]>@80U6lk0`2CKSX3099]>@<0TF`h0P2BKCT309=^
>P@0U6lk102CKSX309Mb?P80UW4m0`2EL3`809A`?00309Mc@`2FLT80UW920080UG510P2DL400102C
Kcl0V7A009Qd@02HM40309Ue@@80VWI20P2HMTH00`2IMdL0VWQ809]iB@0209ajBP0309ekB`2JO4X0
VWa:00H0VWa:00@0VWi>09EiB@2>LT80Qf/k0P22ISH03023IcL0QFTi08UY=P24IS@0O60a071G;P1U
CbX0FDHV0550901<?280BclU04Lk8@80@cLM00`0ASXP04Pl8P17>b40ACTO03Tb7`0h<Al0=S4N034^
7@0^;1d0:R/M02PX700V:1/302X[6`<0:b`L0P0/;Ad03@0]:a`0<BlP03<`7`0d;a`0>S<P040h8`0k
<ah0<RLA028U7P0Q91d07R4J01`O600K7QL00P0L7aP01`0M81T06R@I01`T6@0K8aP0728H01lR6@0R
8a/00P0U9Ad06@0V9Qh0;RLG03D/6`10=1h0B3XM05107P1KB1h0J5<T075K:P1hGbT0PVX^08Yb<P2<
MC40S7@d08I]=`1dF300H4<Q048c7P0f;A`0:2DL024S7P0U9b80;b`S03L^7@0m;QT0200c<1l203<]
7`80<2dN00X0;R`M02`]7@0[;Qd0:RdL02TW600Z:1T0;2XK02d[700^;1d0;B/L0P0[:AX0:00/:AH0
;2TH02`Z6`0Z:Qh09bPP02@V8@0R92407R8Q02PR8P0R8A`08bHK02`a7@0f=Q`0A3TK05a59P1bDc@0
R6/c09]mA`2]SeT0]9IR0;RJJ02kW6d0^9U[0;6BI02YQeL0Wge=09ajBP2WQED0]99R0:f;F`2BL400
MeDU04<m;@0h=B@0=C8S03Xh:`0i>Bd0<38W02T/8@0Y;2<802@W8080:2TT00<0:BXT02TZ8P0Z;240
0P0[;B000`0/;R00<C8T034b9006034b900803Da9@0c;b<0<BdQ030/800_:al0<2`P034]8@0b;R82
02l[7`06030/800a;B40<RhR03<_8`0d<2@0=C4U0P0f=2D00`0g=2D0>C<U03/c9P0203`b9P0603hb
9P0k;al0>blO03``800m<B40?S8R0P0o<b<00`10=2@0BSXS04/k900304dm9P0404`l9@1:>R<0BCTR
04Ti8P80BSLX00@0C3HX04df:01?=BP0CcDX0P1@=2P204`j900404dk9@1>?2H0CcdW050n:080DClY
00P0D3hV054o9`1A?bL0DT0X054o9`1@?RH0CS`T04dk8`80CC`R01H0CSdS04ln901A@2H0Dd8X05A3
:@1EA2X0EclS05U19@1K@bL0G4@X05e5:@1LA2P0Fd<W05Y29P1N@2H0HD<W06E7:`1YC2h0Jdh^06a?
;@1/D2/0JdlZ0P1OC2/05P1MBRX0FdPZ05Y6:`1IAB`0F4@[05Q4;01F@bD0ET8W05=29P1B@RP0D48X
04e1:@1=@B/0Bd0Z050i9`1?>RL0CSTX04/h:@18=bL0ASHW04<e:012=2L303La9@<0=S0T0P0e;b<8
038^8P80>BlS00@0>S0T03/a9@0l<RH0?C<W0P0n=2P02@0b<b<0<C8R030a8`0^;R80;2`R02XZ8P0Y
:2<0:2LR02XZ8P0302/[8`80;2`T0P0];BD802X[8`<0:b/Q0`0/;28202d]8`80;bXV00`0;bXT030/
8`0a;B80<BdQ034^7`0b;b00=c<W03Hb9P0e<BD0=30T03<_8`0d<2@203Da9@P0=S0R0P0l<RH0A`0j
<2@0>BlS03L]8@0g;B40>2hR03X`900k<BD0>C<S03Xc8`0j<b40>c<P03ld8P13=R<0B3TT04Xk9P1<
?al0Cd8R0554901?@R80CD0P04i18@1CARH0EdXZ05E69@1A@R<0BcdP04@h7P11=R00?SHS03lf9@0o
>2P0BCLS04Xh901;>B<0CC/S04ln901A@2@0DT4U05=2901D@bD0ET<U05M28`1K@R@0HD@V06M69`1[
B2P0KTXZ07EF:01hFBd0MeX^079G;01ZDBP0ITlV06I@:@1YDb`0JdL]06i;;`1_CRl0KTdZ06a?9`1`
DbL0Me`]07eS<P1kH2/0Nel]07]Q<01iHC40N64e07MR=`1gHCP0M64i0080Q6Df00H0QFDd08MU=@2;
IcD0SfXf099]>02FKSX208i`?P0?08e_>`2>L3X0Sg8j095d>P2DMcd0UWTm08ih?P2?ND00TG]2099k
A@2@NDD0S7E308Q`@025KCd0PfHj00<0Q6Lk1025J3`0<@27ICD0R6Hf08YX>02=Jc/0T6hn099`@02D
LT80UG=308md?@2>Lc`0S74l08Y^?029KCd0RFdn08Y^?`2;KT80Sg4k095c?@2CMCl0U7I009Eg@@2D
MT00TgDo099d?P2JNd@0Vga509amAP2MOTL0Wh190:21BP2QPT/0XX=<0::7D02SR540YHYC0:R=EP2/
TEX0/9EN0;BIHP2eVV<0/9YX0;6KJ@2cW6P0^9i[0;fRK@34YW00bJad0<b]MP3</WL00P3:/7D00`38
[W<0aZac0<F[LP020<FZL`0<0<J[M038Z7L0b:Qg0<RYL`36Yg00a:E/0<2RI02mWel0^YeK0<6OHP2o
WF00_9YM0P2jV5/02`2mVeh0`9iQ0<:PH`38Yg40cJaf0=>bO@3G]X<0fkV90>;0T03/bY`0m=:T0080
lmFQ00X0lmFS0??DY@3adZ@0km2T0>g>XP3[bj80i<FI0>O8W03/cJ40l=6U0P3bdjL04P3`dJD0km2T
0>?7U@3P`Y00f;Z80=>cPP3A[gl0eK610=^eQP3N^8T0h<2A0>;2T`3TaIL0iLRL0>S=XP3ZdJP0k=>Z
0>gF[@80m=N[00h0lmJZ0?7DZ03^dJD0j/fQ0>K9W@3Tai/0h<JE0=c2T@37[G`0^Im^0;fSLP2iWfh0
/iUX0;ZPK`P0]Ymc0400]Yme0;NPMP2hXGL0^J9h0;^TNP2mYW`0_ZMm0;nXOP30ZX<0a:j70<^eT03C
_9X0fL:R0=g6Y`3NajP0g/JZ0=k9ZP3ObZ/0glb^0=k=/@3PckD0h=2g0>3A^P3Qd[/0hm6i0>;@^03Q
ckL0h<jf0=k<]03Mbk<0g<Zb0=_9/@3NaZ`0g<BZ0=S0Y03D_Ih0d[^K0=2iU`3?^9H0ckVD0<ZfT`39
]I80bK>>0<R`RP37[XH0aZZ20<FYP@35Z7h0_j=c0;jRL`2lX740_9mc0;nRN033YWh0b:Z40<^]Q`3<
/Xl0ckFD0=>kV@3H`J40flJW0=k;[@3Pc;40gljb0P3Rd[P20>?C^P0=0>GE_P3VeL40j=O50>WHaP3Y
f<P0jMc;0>[Mc@3Zg/h0j^7B0>_SeP3/i]X0jnOL0>cXg@080?3VfPP0lnOK0P3aj=T00`3aim/0lNOM
0?7WgP020?7Vh0030?7VhP3_inD0knOU00<0l>SV0`3ajNL80?C]i@P0mncV203fkN@30?S`h`80mnoR
0`3fk^430?W[gP80n>[M0`3gjM`80?OZf@80n>_K0P3gj]X30?KYf@030?GXf03fjMT0m^WI00H0m^WI
203dj=P80?GYf@P0lnWM203fj=dA0?CVf@P0mNOL203aim/20?;Ug080lnOK00@0lnOI0??We`3cj=H0
lnSF0`3ci]H20?;Ue@<0lNCD203bi=L80?7SePP0l>?@203ai=<80?;RdP<0lN7A0P3bh]830??Sd`P0
lnCA203ai=@80?3Sd`P0l^GE203`imP80?7Xf@P0l>OH0`3_i]L20?3Wf0`0lNSI203ciMP30?;Ue@80
lNCD0`3`hm<80?3Sd0P0m>?A0P3dh]@20??Qd`<0l^3B00<0lMoA0?CRe03dh]@01P3dh]@20?CQd080
ln3?0`3bglh0103ag/d0l=k60?3NaP3`g/H20>oMa@H0k]c40P3_gLD30?3NaPP0kMk91P3_gLD20>kL
a0P0l=k6203^g<@0103`g<<0km_20>oK`P3_fl820>kJ`@80kMW00P3_ek/20>kF^P<0kMFi0P3/e;P3
0>_C]`80j]:f0P3YdKD20>cC]@040>_B]03ZdK<0jM2b0>S?/@80ilj`0P3/cK00103[c:d0jL^Y0>S:
Z03Vb:@20>G7X@050>O6X`3VaJ80i/FR0>G4X@3T`j000P3S`Yl20>;1WPP0h<:P0P3Q`9d20>2oW0<0
gkjK00<0g[fJ0=noV03O_iP00P3O_iP20=jnU`80gKfF0`3L_9D20=fmUP<0g[jG403O_Y/80>70W@P0
hL2Q203N_IX00`3P_i`0gkjK0=flV@020=^jU`030=bkV03M_9T0g[fJ00P0f[ZC203F]Xl20=BdS@80
eKF>00@0e[J?0=NgT03G]i00ekN@0P3F]Xd20=NgSP040=RhS`3I^I00fKV@0=ViT080e[J?0P3E]Hh2
0=BdS@80dk><00<0d[:;0=>cS03D]8d00P3E]Hh0103C/h`0dK6:0=2`R@3D/HT30=>`R080dZn70P3A
[XH02`3@[H<0dJj40=6^Q03@[H<0cjb20<bYO`39YW`0b:Ek0<RUO`3:Yh40c:V30080cZ^500d0cJZ4
0<^XPP3;Z880bJJ00<bWN`3=Z7`0cZUl0<n[N`3@[7X0cj]g0<fYM@3<ZG<0bjMg0080bZIf00<0bJEe
0<RTM037Xg<00P36XW801039YGD0aj=c0<FQL@33Wfl20<:NKP0:0<>OK`34X700`Ye`0<>NL@34Wg80
aJ1c0<BOLP33WW40`Ia_0;nJK@80`9aX0P2oVfL0302nVVH0_IUU0;bHI02lV6@0_9QX0;fIJ@2nVVX0
`9a/0<:NKP34X700aJ5a0<JRLPP0aJ5a0P33Wfl00`32WVh0`Ie]0<2LK0020;nKJ`060;jJJP2nVFd0
_YU]0;jIK02nVVX0_YYX0P2nVVH0102nVfD0^YQ[0;ZHJ`2jV6/[ooooo`00:_ooool20:EjA`030:Ik
B02WO4T0Z7e:0080ZWm<00<0Zh1=0:QnCP2XOTh01P2XOTh20:QmD080Z7i>00L0Z7i<0:QoB`2XOdT0
Z7m90:V0BP2ZPD/0Zh9<0080[8==00<0Zh9<0:Z1B`2YP4X0202/Pdl20:V0C0030:Z1C@2[PTh0[8=?
0080[XEA00<0[hIB0:Z7D@2ZQe401P2ZQe402@2bQ500]HMC0;R=FP2nU680`YYY0<BNK`37XG80aj9e
0<ZXNP020<^YO0030<bYO`3=ZX80cZ^50080cj^70`3>[XL30<n_R0<0d;290P3?[hP30=2`R@<0dK6:
0P3B/X/30=6aRP<0d;290P3?/XX0103>/HT0cK280<f`R03<[hL20<^^QPP0c[690P3;[8d05P3:[8X0
bJ^70<NYP`36ZH40aJR00<FXOP32Z7L0_ZAc0;^OK`2kW6d0^IUZ0;>AH`2YQeT0XgiA09I`B`2EKdX0
Tfe608mZ@02=J3`0SVTl091/?02CKcl2095[?080TV`m102CKCh0202?JSH0Tfhj09Mb?P2FLCd0TF`h
091[=`2DKc/0V7<o202EJSl8099]>@P0T6Xk202?JSH02`2?I3L0SV<f08eR=@2=HSD0SV<f091U>02B
IcX0TfPk08eS<@2>I380T6Hd0080TFLe00<0T6Hd08iT<P2=Hc400P2@IS@2095W=@80TVPf0P2CJCL2
08mU<`80T6Hd102AIcD3091[=`80TF`h0`2BKCT909E[>@08099]>02CKST0UG0k09Mb?@2FLC`0U6lj
095/=`2?JSD8099]>@<0UG0l0P2DKc/309=^>P80TF`h0`2BKCT309=^>P@0U6lk102CKSX309Mb?P80
UW4m0`2EL3`809A`?080Ug=300@0UW9209Ea@@2ELD40U7100P2CKcl309Qd@0<0VGE10P2JMT8209Qf
AP0409UgA`2JN4P0VgU909ajBP80WG];202JO4X04P2LP500Ug];08ib@P27Jc/0PVHf085U=@22ISH0
Q6Ph08UY=P24IS@0O60a071G;P1UCbX0FDHV0550901<?280BclU04Lk8@80@cLM00`0ASXP04Pl8P17
>b40ACTO03Tb7`0h<Al0=S4N034^7@0^;1d0:R/M02PX700V:1/302X[6`<0:b`L0P0/;Ad0300/:Q/0
<BlP03<`7`0d;Qh0>C8P03lg900j<Qd0<BHB028U7P0P8a`07R4J01`O60806ahG00P071lH01dP6@0J
91T072@I01/S600L8QP07b8I028S6`809BDM01T09RHN030W600g;1X0@3@N04Tj7@1B@1`0G4TO06UC
901bFbT0N5lY08=[;`2;Lc<0SGHb08ee=@26KCL0LeL_05m28012<b00=B`M02PU700Q8ah09BLR02h[
8P0g;Ql0?BhK00P0<c0O0P0b;2000`0`;200;R`O02`]7`0202X/7P0402T]7P0X9QT0:BLJ02/Y70<0
;2XM02X0:RPK02TW6P0/:AP0;2/I02d[7P0[:b40:2TS02@V8@0P92<07R8Q02PR8P0R8A`08bHK02`a
7@0g=ad0ACXL05e69`1cE3D0SG0h0:22C02bU5h0^I]W0;bNK02oX740^ia^0;>DIP2YQeL0Wge=09aj
BP2WQED0]99R0:f;F`2AKcl0ME<S048l;00h=B@0=C8S03Xh:`0i>Bd0<38W02T/8@0Y;2<802@W8080
:2TT00<0:BXT02TZ8P0Z;2400P0[;B00100[;Al0<S<U038c9@0b<bD2034b90<0<34S0100=C4U03<_
8`0a;B40<2`P02l[7`0`;200<BdQ038^8P0^:Qh0;b/O030/800a;B40<RhR03<_8`0d<2@0=C4U0P0h
=RL00`0h=BH0>S@V03/c9P0203/a9@0403da9@0j;Qh0>RhN03/_7`80?30P00X0?C4Q03hb8P0n<R80
Bc/T04`l9@1=?BH0CShW04dm9P1<?2D0BSXS0P19>B8204/h:@0304dg:@1==RP0CcDX0080D3@X00L0
DC<X04dk9@1>?2H0CS`V04lm9`1@?RP0DClY0080DT0Z00<0D3hV054o9`1C@BT00P1D@RX01`1A?bL0
CS`T04`j8P1;>R00C3/Q04ln901A@2H00P1C@RP205A3:@0305Lo8`1I@BD0Fd<W0080GDDY00/0G4@X
05]39`1I@BD0HT@Z0694:01SABT0I4LY06M::P1ZCB/0KU8]071D;`0205i;:P0F05i;:`1MBR`0G4P]
05Y6;@1HA2/0ET8Z05E2901E@BH0DT4U05519`1?@BL0C40X04a0:P1:?bT0DCXX050i9`1>>BP0BcPY
04Pg9`16=RL0ACDX04<e:0<0=c4U0P0f<2@303D_8`P0<RhR00H0>BlS03X`900j<2@0>c4U03`b9P0m
<bL203hd:008038c8`0a<R80<34S02h^8P0/;280:RXR02TX8`0X9b8302/[8`80;2`T0`0];BD802X[
8`<0:b/Q0P0/;28302d]8`80<2/W00@0<2/U030/8`0`;240<2`P0P0`;Ah0200j=RX0>3@X03Da9@0c
;b<0<RhR03<_8`0e<BD0=S8V200f<28203`b9P0O03/a9@0i;b<0=bdQ03L]8@0h;R80>S0T03/a9@0g
<B40>34Q03Tb800k<b00@3DS04@g901:>bH0C3dX04`o7`1>@B40D4<S04m28P1=@200CT4Q05=69P1G
BRX0EDHU05138`1;?B00A3PN040e7`0n=R<0?SLU03lh:00204Xh900n04/i8`1=>b<0CchT0550901B
@BD0Dd8T05E49P1GA2H0FD@U05e49@1SARH0JDPW06a9:@1_BbT0MEHX07UJ;01hFbl0LeP]06YA:01V
CbH0Ie4X06YD;@1]B2d0L4/`075>;P1_CR/0KdlX075D:01hGRd0OfDd07]P:`1iGb`0N5h]07EM;`1d
GC40M5he07=P>01cGcX0PV<d08=S=024I3<0R6Ld08eY=@2CKST0VG4m09ae?P2?LCl0Sg4m08i`?02>
L3X0T7<k099e>`2EN3`0UWTm08ei?P2?NT40TGa3095lA@2?NTD0RgE308I`?`23KC`2089U>`0308=V
?025J3h0QFPn00<0QVTo01<0R6@d08UU=@2<J3P0Sf/k09=_?`2FLT80V7A409UeA@2@MCh0SW<l08aa
?02:KS`0RFdm08Y^?P2;Kd00S711091c>`2AM3`0TWDm00<0U7Lo0P2BMCd06@2GN3l0V7U009Uj@@2J
Nd80W7e409ioAP2OP4L0X85809n4C@2QQTl0Y8UB0:R=EP2/TEX0[iAM0;6FG`2bUf00[YYX0:nII`2`
VVP0]9eY0;ZQJ`30YFh0ajYb0<V/M03:/WH00P38/7@01P36[G@0a:]b0<>ZLP32ZG<0`jUf0<BZM`80
c:am00T0c:ai0<Z[M@37Z6l0`jEW0<2RHP2mX5h0`Z1S0<2NH@2mVeh00P2kVE`02`2nW5l0`ImR0<BR
I@3>[GL0e;=m0=bkQP3Q`8d0iL>C0>_9V`3ddZ@0n]R[0080m=JR02h0m=JT0?;CY03`dJ<0kLjR0>_<
X03YbJ00hl>J0>K6W@3/c:<0l]:Y0?KF[@3gejh0m]J]0?GE[03VbYX0h/>D0=ZkS03D]8D0d[220=Ja
Q03K]HP0g[R;0>71TP3R`I@0i<FG0>K9W@3YcZ<0j]6X0>gD[03]eZd0m]V_0?GH[P3dejd0l]F[0>kA
Y`3Yc:80iLRN0>?6W03OaI@0g<:A0<N]O02iWfh0^j5`0;RNK@2bV6L0^Z1_202gX7@09@2fWgD0]j1f
0;RQM`2jXgT0^jAj0;fVO02nYgd0_jQn0<2ZP`34[XL0bkF@0=>lVP3I`Z80gLJW0=k7Z03NaZX0g/VZ
0=o:Z`3Oc:h0g/fa0>3?]@3Pd;L0h=6j0>7B^`3SdKT0h]2h0>7?]`3Pc[H0g/bd0=g;/`3Lb[80flVa
0=k6[03La:X0f<2T0=FnW`3B^i/00P3@^IL06@3?^I@0b[JC0<VeTP39/hh0b;2:0<N^QP37Zh<0aJV1
0<FXOP30Y7@0_Z9c0;bPL@2lWg<0_Z5g0<:UO@37ZH<0bZb60<bbS`3?]I@0dk^I0=S1X@3KaZL0g/^]
0>3</@3Oc[800P3Rd[P20>?C^P0=0>GE_P3VeL40j=O50>WHaP3Yf<P0jMc;0>[Mc@3Zg/h0j^7B0>_S
eP3/i]X0jnOL0>cXg@080?3VfPP0lnOK0P3aj=T00`3aim/0lNOM0?7WgP020?7Vh0030?7VhP3_inD0
knOU00<0l>SV0`3ajNL80?C]i`P0mncX203ek^@0103hl^H0mo7U0?Oai@3glND20?K`i080mNoS0`3i
kMl20?S/gP<0mn_M203hjmX30?W/g080n>_K2`3gj]X80?CXf0P0mNWI203cjMl80?KXga40m>SJ203e
jMd80?3Xf`060?7Vh03aimh0lNON0?7Wg@3bj=`0l^WJ0P3bjMP30?KXf`80mNOJ0`3di]T@0?;Tf@P0
m>OD203biMD80??Se080l^;C0`3chm@30?CTe@P0mNGE203bi]H80?3Te0P0l^KF203aj=T80??Zf`P0
lNSI0`3`imP20?7Xf@`0l^WJ203di]T0103bi]H0lNGE0?7Ue@3aiMD20?3Te080kn?C203_i=880?CS
d@<0m>;D0P3chM<30?;PdPP0m>;D0`3dhM820??Pd@<0l]o@0`3`g/H20>oMa@H0k]c40P3_gLD30?3N
aPP0kMk90`3`g/H40>oMa@030>kLa03`g/H0l=k600H0l=k6203^g<@20?3L``80km_20`3^f/40103]
fL00kmNk0>oG^`3_ek/20>kF^P<0kMFi0P3[dkL20>[B]P<0jM6e00L0j=2d0>gD]P3]e;H0k=>e0>_B
]03Yd;80j<na0080ilj`00P0kLja0>c=/03[c:d0j/bZ0>S:Z03WbJD0i/RR0>G7X@80ilJS00<0i/FR
0>G4X@3T`j000`3S`Yl00`3R`Ih0h<:P0>32X0060>32X080hL2M0P3P_i`40=nnV`040>30V@3O_iP0
gknH0=noV080g[jG0P3M_IH20=blU@<0gKfF0`3N_YL@0=nnV`P0hL2M203Q`:480=jmVP030>70W@3O
_Y/0gKbI0080fkZG00<0g;^H0=flV@3N_IX0203J^Y<80=JfS`80e;B=0P3E]Hh01@3F]Xl0ekN@0=Ng
T03H^940e[J=0080ekN>00<0f;R?0=ViT03I^I000P3J^Y430=JfS`030=FeSP3D]8d0dk><00<0dk><
00L0e;B=0=FeSP3E]Hh0eKF>0=>cS03A/HX0d;290080e;690P3C/8P30=:_Q`030=6^QP3?[880d:f3
0080d:f300@0cjb20<fZP03:Ygd0bJIl0P3;Z8830<bYP`<0bjR200X0bZN10<fXO03>ZGd0cjYm0=6]
O@3A[G/0d:ah0<n[M`3>ZgD0bjMg0P3:YWH00`39YGD0b:Ad0<NSL`020<JRLP040<^WM`39YGD0aZ9b
0<>OK`80`Ie]00/0`Yi^0<>OK`31W6l0`Ye`0<>NL@34Wg80`iia0<:ML030Vfh0_YU/0<6MJ@020<2L
J0030;nKI`2nVVH0_IUU0080_9QT00P0_9QX0;fIJ@2nVVX0`9a/0<:NKP34X700aJ5a0<JRLPP0aJ5a
0P33Wfl00`32WVh0`Ie]0<2LK0020;nKJ`060;jJJP2nVFd0_YU]0;jIK02nVVX0_YYX0P2oVfL0102o
W6H0_9Y]0;bJK@2lVVd[ooooo`00:_ooool80:IkB080Yga900@0Z7e:0:UnB`2YOT/0ZWm<0P2[P4d8
0:V0C00>0:Z1C@2YP4`0Z7m;0:QoB`2YP4`0Zh9>0:f4D02_QU80[85G0:b1EP2[P5D0Zh1C0:Z0D02Z
P4h20:V0C0P0[85>2@2^QE401@2bRED0]hiJ0;fDH032VFD0aIaX0080aiiZ00P0aJ9/0<NSK`39YG40
c:Qf0<fYN@3=Z7/0cJQl0<bWN`T0cJZ0203@[H<80=6aR`@0cJf40P3<[8<20<^[PP0H0<^ZR`3<ZhX0
cJb;0<j]RP3>[XP0cJf60<^[PP3:ZX40b:b40<N[P`36ZX80a:R00<:VOP30Y7`0_Z9j0;fQN@30WG<0
_IY`0;ZGK@2hUF/0]I9X0:j;H@2TPEL0W7U?0P2?JSh00`2?JSd0Sf/k08m[>@0208iZ=P0708i[=@2>
J3T0SVPi08mY>P2@JS/0TV`m09=]?P0209A^?`@0TVhj0P2AKCT2091/>080Tfhj00@0TVdi095/>02A
K3P0T6/g0P2?JSH00`2BK3d0Tfdn09A^?`0209A^?`03099/?@2@JS/0SfTj00P0U6Xh0`2?JCX3091Z
>`80TF/l0P2?JCX208iX>@0708eW>02<ISL0S6Hg08]U=P2CJ3/0TVLj095V>@02091U>003095V>@2B
IcX0TfPk00P0TVLj202=IcP309E[>@<0UV`j0P2GKC/209Ia?00309E`>`2DKcX0U6lj0080Tfhi0P2B
KCP2091[=`@0TF`h0P2BKCT209A_>`80Tfhj00@0TVdi095/>02AK3P0T6/g202AKCT00`2CKSL0TVdf
095/=@02091[=003099]=P2DKcP0UW4j0080U6lh0P2CKSL0102BKCH0TF`e095/=@2@Jc@309E`>`80
UW4l0`2GLSd309=_>`D0U70l0P2BKSh0102CKcl0U71009Ib@P2GLd<209QdA0<0VGE10P2JMT8309]g
@`0809ec@@2LLT00VW8o09Yb?`2IM400VgM309akAP2MO4L809QjB00409YeB02GLTD0TF`o08aW>P80
RF@g00d0RVDh08]V>@26J3@0P6@b07UN;`1^Ebd0HThY05I69@1?@2<0BcdR04To9P17?B@0A3XQ0080
@CLN00P0A3XQ04Lm9019?bH0>c@T03Pa8@0d;R00;b/O02/Y7@809bLM00<09RLO02HX6P0V:1X00`0W
:A/302PZ700;034d7`0_<Qd0;c8M038e800e>2<0<cHQ02d`6`0X:aH08RDN024T7@0O8Q/00`0M81T0
200N8AX07b8K01TS6`0J8AX06R4I01XP5P0M81D0828E0P0T91P06@0U9QP0;2XM034^7`0h<al0?SLK
04Dj6P1@@Q/0G4hQ06MF:01fH2@0P6//08Md;`27MS00Pg@c07YZ=P1VE2`0CclN03<d9P0/;Al09BHH
02@U5`0W:1X0;2dO02h_8@0];R000`0]:Q/302h[7080;b`M0P0/;Al0100[;1h0:R/M02TZ700X:A/2
02LX6P0302@T6P0U9A/09bLM00<0:BTO02X09bLM02HV700X:AT0:2TI02TZ700X:1`09bLM02@T700R
8A`081lJ01/W6@0P:Ql08RDN02`X7`10=bH0Bc`O05]87@1gHbh0SWLd0:69C@2cVFP0^Iee0;^ON02k
X7D0]YaY0:jEG02WQeh0XX=D0::4CP2[SU@0/iIN0:R:F02:JT<0L4l`03li:`0k>2T0>CDY03Hd:00a
<BL0;BhV02X]9P0Y;2D202DW90<092HS0`0S9B80200S9B0092HQ02HW8@0Y:B40;BXQ030/8@0a;B80
=2hR200c;b<04`0b<bD0<C8T030a8`0_<280;RlQ02d^800/;Al0:b`N02h`8`0_;b<0<34S03<a8P0d
<B00=c8O03Tb800i<Ql0>2hR03X`900l<RH00P0n=2P00`0m<bL0?38V03/a9@0203Xa8080>c8Q00L0
?3<R03dd8`0m=2<0?SDT04Le7@19=al0CC/S0080D3hV00`0CS`T04/i8@19=al0BCLO04Pm:@18>bP0
ASTV04Lh9@17=R@0BCHU04`g9P1=>2L204hj8P0704lk8`1@?2@0DCdU058n9P1C?bL0E40X05Do:P02
05@n:@0305<m:01B?2L0DC/V0080D3XU0P1=?BH304hn9`<0CclX00@0ETD[05E4:P1D@bT0E4<Y0P1B
@BL0201A@2H0D3lU05m6:01PAbT0HDPZ0699:`1SBR`0I4/]0P1UC2h02@1MCC<0G4`b05a;<@1LB2l0
FdD]05a4;01J@RX0Fd4Z05=2;P020591;@030550;01@?b/0CchZ0080CSdY0P18?RD03`19?bH0B3hU
04Hl8`14>R40@CLN03le700n<2D0?BlT03/_8`0h;R80=RhQ03H`8P0f<b@0=c@U03Pa9`0203L`9P80
=RlU0`0e;R@0200j<Ql0>C4N03P`7@0g;a`0>C4N03`d8@10>2D0@c/X0P0a=2400`0`<b80;c4S02h`
8`0202d_900902`]9@0c;Al0=2hP03D_8@0f<280=BlQ03@^800b;1h0<B/M0100;b/R0P0a:al0100b
;200<bdQ03@^8P0e;b<203H`900803Pd:@0g<bP0=30U03<_900b;R<0<blT03Da9P0f<RL803L]8@80
>2lN00L0>C0O03Xa800k<R40>c8Q03Xa800i<1l0>2lN0080=blR00H0>C0Q03``8P11=2@0AcLW04`m
:P1??R`204do900D04lo9@1A@2H0DT4W05I2:@1G@BT0F48Z04i3<@1;@2h0AS/Y048g9@0o=280@3DS
048g9@13>2H0@SDU04@g9P1:>RX0CSl/0550;01C@B/205E1:@<0GTHT00/0H4PV069::01TC2X0Idl]
06Q@;P1bE380LE<_071B;P1_DB/0Ke8Z071C:@02075D:080M58/0P1cDB/0?01dDR`0MU@^07QF<01i
Ec40O64Z07]P:`1iGB/0Me//07II;@1fFC40MUPb07MI=@1oHBl0PV@b08IX=P2:K3X0SW0n091b@02A
Ld40TWA2091cB@2<KdD0R6`m08Y^?P2?M3l0TgU009Aj?`2CNC`0TgQ=099gC02?M4T0S75608Q]@P24
JCh0PFHk081U>P1mHS<0PVLh08Q^?@29Kc`0QVdg08A[<`25K3@0Qfhe091X=@2DK3T0VGA009ijAP2O
OTT0WGi809]lAP2GND<0TGM408me@P2=LCl0SFlm08e]?02>K3`0Sfdm099^?P80RG=10`28LT0308Ma
?`0;08]`@`2?M4D0UGU909QjAP2HND80Vg]209moA02UPdH0Vgm=0:65D`2XS5X00`2ZSU`02P2]TEl0
/9AR0:ZFF`2/UU`0[YQN0;BKHP2jX6L0`ZE]0<RYLP3;[7D30<jcQP080<fbP`3;/840b[1o0<R^N`37
[WP0aZeg0<RYL039ZW420<Z[LP0B0<VZL@36Yfh0`Z=Z0<2QJ038Xfl0aJ1/0<6LJ02oVVH0`IaX0<NR
KP3>ZGD0dZei0=6dRP3F^Hl0gl:H0>O:X03^dJL0l]F[0P3dejd20?SIZ`0L0?KGZ03ceJ<0k]2L0>S:
U03Ra8h0gl::0>[7W`3Xaih0ilZR0>_BZ@3ag[@0l^Fk0>gT^`3XhKL0m=:R0>;0T03D/X80d[200=Bb
PP3C/H40ekF50=fkR`3VaiP0jLZL0>_?X03^djH0kmN[0?3I[`80l=Za0P3dg[D01P3dgK<0l]Z^0?7F
Z@3^dZ<0k<fO0>W:V`80iL^H00H0cK>20;RMKP2lXG@0_jAi0;VMM@2jWWH40;JPL@@0]Im`0100]Yih
0;NON@2iXG/0^j=m0;jVP030Z880`ZZ40<>[Q@35Yh<0bJf80=2cT@3E^iX0f/6R0=c5YP3KaZL0g<NZ
0P3Obk80103Pc;<0hLfd0>7=]03Rc[D20>??]P80hM2f00`0h<ne0=k=/`3Mc;80g<^a0=_:/03JbJl0
glRY0=g6Y`3H`J80e;fN0=2iVP3=]YL20<beUP0J0<RdS`37/hh0b;:=0<N_R`36[8T0aZV70<BWQ@34
YX@0_jYo0;ZUNP2gX7H0^J1g0<2TO036ZH40bZZ30<VYPP38[X/0c;:A0=6iU`3G`:00f/FV0=_8ZP3L
b:d0fLR/0>7?]`3SdKT20>GC^`050>SF_P3Yekl0jMNo0>WG_`3Xe[h00P3ZflP01P3ZgL`0jmo?0>[Q
dP3[hmH0kNGH0>cVfPP0lnOK0P3dj=P40??We`80l^KF203aim/01P3ci]d0lNON0?;Xg`3aj>40l>WS
0>oZiP80k^[W0`3ak>H20?;]i`<0lnkX203ek^H20??^jP80m>o[0P3el>`20?Kak@P0n?3U203kkn<8
0?G_h@P0nNgQ203fk>880?K/h0P0n>cP203gj^4Q0?G[h@P0mN[T0`3gkN<20?K/hP<0mN_Q203dj^0@
0?3Yh@P0l^SL403fj]h80?;[h`P0mN[T203ckMl80?3Yh@P0lN[R203ck>@80??]h@80m>gU0`3ck>@3
0?;[h`P0m>[P2@3ejn480?;Xg0<0lnSF0P3bimD30?7Ve0P0mNKC203aiMD20?CWeP<0lnKE0`3biM@8
0?GTdP@0m>?A0P3ch]020?;Qc`P0lN3>403`gld20?7QbP80l>390P3_glP:0>kNa`<0kmg50P3^g<@;
0>gK``80kMW00P3/f;l0103[ekh0j]Jm0>WE_03YeK`20>gE^@80k=Bh0`3[dkL01`3Zd[H0k]Fg0>gD
]P3]e;H0k=>e0>_B]03ZdK<00P3Yd;820>W:Z`<0j<VZ0`3Wb:T20>G7Y@030>C6Y03SaJ<0h/BR00<0
hL>Q1P3P`Z030>73X@80gl6M0`3N`9`30=foV`80h;nL0P3O_Y/30=jmVP030=flV@3L^iP0g;^H0080
gKbI103N_IX30=nnV`<0h;nL0P3Q`9d20>2oW080gkjK0P3N_IX20=flV@<0gkjK0`3P_i`20>70W@80
hl:O0P3R`Ih30>70W@030>2oW03O_Y/0gkjK00H0gkjK0P3Q`9d20>2oW0@0gkjK00P0fKRE0=^jU`3M
_9T0g[fJ0=flV@3K^YL0f;ND0=NfT`80gKZD00@0fkRB0=ZgT@3H]Hl0ekB>0P3E/X`01P3B/X/0dk><
0=>cS03D]8d0eKF>0=JfS`80ekN@1@3H^9430=ViTP80ekN@0`3F]Xl30=FeSP@0e;B=0P3C/h`20=:b
R`80djn;00P0dZn90=:_Q`3A[X@0dJn20=2^P@3@[X00d:f50=6^QP<0dZn700T0d:f50<j[P`3=ZX80
d:j00<n]O`3>[7h0cJ]m0<bZO03;ZG/00P3:Z7X00`39YgT0bjQn0<^XOP030<^XOP<0c:Uo00@0b:Ih
0<NUM`37YGL0ajEg0P36Y7H20<FSM@80b:A`00<0aj=_0<JRKP35XFd00P34X6`01033Wf/0a:1/0<BP
K033Wf/20<:NJP030<6MJ@30W6P0`9aX0080_YYZ102mVFT20;bHJ080`I]d00H0`Ia`0<6LK`31WF/0
`9eW0<2MI@30WF<80<FPL`80`Yi^0`31WFd30<2LK0080<>OJ`31WFT0_i]W0;jJIP2mVFD0_YYV0;nK
I`30W6P30;jJIR_ooooo000Zooooo`X0Yga90P2XODX0102YOT/0ZWm<0:YoC02ZOd`80:V0C0080:Z1
C@2YP4`0Z7m;0:QoB`2YP4`0Zh9>0:f4D02_QU820:b1EP80Zh1C00@0ZX1@0:Z0CP2YP4`0ZH1<202/
PDh80:j5D@060:n6DP2bRED0]hiJ0;bCG`31V6@0a9]W0P36WFT01P34XF/0aZ9^0<RTL03;YgD0c:Qh
0<bWNP80c:Mk0`3<ZGl30<fZP080cZ^100<0cjb20=2]P`3@[H<01P3@[H<80<n_R@040<j^Q@3=[H@0
cJf40<f]Q080c:b30P3;Zh807@3;ZXT0c:^:0<f/R@3>[XP0cJf60<b/Q@3:ZX40bJV00<N[P`36ZX80
aJV10<>WO`30Y7`0_Z9j0;fQN@2lX7P0_IY`0;ZGK@2fTfT0]95W0;6>I02ZQed0WgaB09MdBP2?JSh0
SVTm08iY?02>JSX0SVXh0080SVXf00H0SV/e08iX>@2?JCX0SfTj091Z>`2BK3d209=]?P0309A^?`2C
Kc/0TVhj0080TVhj0P2AKCT2091/>080Tfhj0P2BKCT01P2AK3P0T6/g091[=`2@JcL0TV`m09=]?P<0
U6ho00<0TV`m091Z>`2?JCX0202DJSP4091Z>`D0SfTj0P2>J3T208eW>080S6Hg00@0RfDf09=X>`2B
IcX0TFHi0P2@ICP00`2AIST0TVLj09=X>`08099W>PP0SFLh00@0TfTg09AZ>02DJSP0U6Xh0P2EJcT2
09I/>P<0U6lk00@0Tfhj099]>@2BKCT0TVdi2P2AK3P00`2DKc/0Tfhj09=^>P02099]>@80TF`h00<0
T6/g099]>@2BKCT01P2BKCT0202CKSL0TVdf095/=@2@Jc@0TF`e099]=P2DKcP0UG0i0P2DKcP209=^
=`04099]=P2AK3D0TF`e095/=@<0UG0k0P2FLC`309Mb?@80Tflk1P2DL3`01@2BKSh0Tflo09=_?`2D
L400UW920080Ug=300@0V7A409Ue@@2IMD40VGE10`2JMT8209]g@`0809ec@@2LLT00Vg=009Ud@02I
MD40VGQ309]jA@2LODL809QjB00409QfB02DLT@0Sfdo08YX>P80QfDg00d0R6Hh08UW>@25Ic<0P6@b
07QM;P1]ER`0HDdX05I69@1?@2<0BcdR04To9P17?B@0A3XQ0080@SPO00/0A3XQ04Lm9019?bH0>S<S
03Pa8@0d;R00;RXN02/Y7@0X:1h09bLM02HW7`0202HX6P<09bTK0`0X:Q`02`0`<ah0;c8M02lb7@0b
=B00=CPS03<f8@0^<A`0:2/F028U7P0Q91d07b8K00<07B0I00P07R4J01lR6`0I8a/06R4J01XQ6@0J
81H07B0E020R5@8092@H01L09BHH02`Z7@0a;Ql0>C@P03lh7017?1`0DT@M05i@8`1YF2X0Mf4W081[
;027M300QWD`089c<P1jJSH0IU@/05107`0c=2H0;2dO02DV600S91H09bPJ02//7P0202d^80L0;R/L
00L0;BXK02`]7`0[;1h0:b`N02X[7@0Y:Q`0:2TK00809bPJ00<092@J02DU6`0W9ad00P0Y:Al00`0X
:1h09bLM02HV700202PY6@0V02TZ700X:1`09bLM02@T700R8A`081lJ01/W6@0R:Ql08RDN02dY8012
=RH0C3dP05a97P1hHbh0SgPe0:::CP2dVVT0^Yif0;^ON02lXGH0]YaY0:fDG02WQeh0XX=D0::4CP2[
SU@0/iIN0:N9E`2:JT<0L4l`03hh:P0k>2T0>CDY03Dc9`0a<BL0;BhV02X]9P0Y;2D202DW90<092HS
0`0S9B80200T9R409BLR02LX8P0Z:R80;R/R034]8P0b;R<0=BlS200c;b<01@0a<R@0<34S030a8`0_
<280;RlQ0080;BhP0180;2dO02h`8`0_;b<0<34S03<a8P0d<B00=c8O03Tb800i<Ql0>BlS03X`900l
<RH0?C<W03hd:00m<bL0?38V03/a9@0j<B0203/b8@80?3<R0P0m=2<0200n=B@0AcLP04Ti8P1<?2D0
CclX0510:@1>?RL0Bc/T0P19>B802017?2P0AcXW04Hi9P17>2D0AcHT04Tf9@1=>2L0CSTX0P1?>b<0
101@?2@0DCdU058n9P1C?bL205A0:080E3hY0P1C?BP0101B?2L0DC/V050j9@1@>RD304dm9P80CShW
0`1??bP205E4:P0405A3:@1C@RP0Dd8X05919`80DD0V0P1OARP0101PAbT0HDPZ0699:`1SBR`206A;
;@80Fd/a00L0FdX`05a8;`1KABd0G4@/05]3:`1L@R/0DT4]0080DD0/00<0D3l[04ln:P1>?BT00P1=
?2P204Tm9@0>04Xn9P19?BD0B3`T04Di8@12=Qh0@CDM040b9`0o<BH0?30T03P^8P0g;b80=S0R03Db
8`0f<b@403L`9P@0=RlU0`0i<Ah05@0j<Ql0?3@Q03hf8`10>2D0@SXW03<d8P0b<b40<S<S034b900`
<2@0;blU02h^900^;RH0<bdO03@^800e;b40=S0R03D_8@0d;R00<R`N034[7@0@02l[8P80<R`P0P0c
;B40300d;R80=BlS03D_8`0e;b<0>3@Y03Hb9`0d<2D0<blT038^8`0c;b@0=30U03Da9PP0=bdQ0P0h
;ah03`0i<1l0>S4P03/b8@0k<R40>S4P03T`7`0h;ah0>C4T03X`900k<R<0?S8R044d8`17>2D0BcXX
04dl:00204do900:04lo9@1A@2H0DT4W05E1:01G@BT0F48Z04e2<01:?bd0ACXX044f9080?c@R0100
@CHT048g9@13=RD0ACPW04Xk:01>?BT0DClY05@o:P1D@2P0E3hW05e58`1NAR@0H4PV069::01SBbT0
IDd[0P1VCR`01P1^D2h0Ke4]06mA;@1`DR`0L5<[071C:@80Ke8V01H0MU@^07EC;@1dDR`0M58/07EC
;@1gEBl0NELa07]I<`1iGRT0NUlZ07YN;01jGRl0NUda07UL=01iFcD0N5Xd085S<@23IC<0QfTg08]]
>`2?LCl0TG=10P2BM4809@2@LdT0S6m308U]?P2:KSh0Sg@o099g@02BN3d0T7Hk08aaAP2;L4D0RFi3
08I[@023J3d0P6Dj07iS>01mHSL0OF8c089W>026K3/0QV`i08A[=@23JS80QF`d08Q_=P2@J3D0TVdi
09Qc?`2LN4@0W7]609YkA@2FN480U7I0091f@`2>M440SG4o08e_?@2=KC`00P2>K3`00`2AKCd0RG90
08Ub@00208Qa?`<0Qg0n00d0QVlm08U^?`2=LT<0TgM709MiA@2GN480VWY109moA02UPTP0Vgm=0:65
D`2WReT0ZHeK0080Z8aJ00/0ZhmM0:jBH02ZUU/0ZiEK0:jHGP2cVV40^ImV0<6TK037Z740bZ]d0<nd
Q`020<ndQ@060<jcQ03=/h80c;:10<^aOP3:/7d0bJml103<[GH04@3;[7D0bJYc0<NXL@36Yg00bZIb
0<RTL036XVh0aJ5]0<RTL03>ZWH0eK5m0=ZfPP3L_iD0hLBJ0>O:X03^dJL0lmJ/00<0m]V_01<0mmRZ
0?KGZ@3deJH0lM>Q0>c>VP3Vb980hL>=0=k1R@3R_iD0h;nD0>?3VP3VcJ@0k]R_0?7O]`3^hKL0jmng
0?CBXP3S`I40eK>300<0dk6100P0ekF50=jlS03VaiP0jLZL0>_?X03^djH0kmN[0?3I[`80l=Za0P3c
gK@01P3dgK<0lm^_0?;GZP3_dj@0kLjP0>_<W@80iL^H00H0c[B30;RMKP2lXG@0_Z=h0;VMM@2jWWH2
0;RRL`040;NQLP2fX740]Z1a0;FOL080]9i_0100]Ieg0;JNN02hX7X0^Z9l0;fUO`2oYh40`JV30<:Z
Q036Z8@0bJf80=2cT@3E^iX0f/6R0=c5YP3LajP0g<NZ0P3Obk80103Pc;<0hLfd0>7=]03Rc[D20>??
]P80hM2f00`0h<ne0=k=/`3Mc;80g<^a0=_:/03JbJl0glRY0=g6Y`3H`J80e;fN0=2iVP3=]YL20<be
UP0J0<RdS`37/hh0b;:=0<N_R`35ZhP0aZV70<BWQ@34YX@0`:^00;^VN`2hXGL0^Z5h0<6UO@37ZX80
bj^40<ZZP`39[h`0cK>B0=:jV03H`J40flJW0=c9Z`3MbJh0f/V]0>7?]`3Rd;P20>GC^`050>OE_@3Y
ekl0jMNo0>WG_`3Xe[h00P3ZflP01P3ZgL`0jmo?0>[QdP3[hmH0kNGH0>cVfPP0lnOK203cimL80?7W
f`060??Vg@3aimh0l^SO0?7Xh@3`jN<0kn[V0P3^j^L30?7/iP80l^gW0`3ck^P80?G^iP80lnkZ0P3d
kn/20?G`k080m_7]203hknH80?W_h`P0m_3R203hk^880?K/hPP0m^cP203hk>080?OZhB40mN_Q203e
j^@30?O]h`<0m^cR0P3ejn480?CZh100lN[R203cjMd@0?CZgPP0l^_S203ej^@80??]g`P0lN[R203b
jn<80??/i0P0lngQ0`3dkND20??/i0<0l^_S203dj^090?G[h@P0lnWM0`3cimL20?;VeP<0lNGE203e
i]<80?7Ue@<0m>OF0P3ci]D30?;Ue0T0mNCB0`3dhm420??Rd080l^7?203ah<h@0?3Oc@80lN7:0P3`
h<T20>oOb0X0k]k70`3_gLD30>kLa0X0kM_300H0k][10>gI`03]fL00k=Ro0>_G_P3Ze[d20>WE_080
kMFi0P3/e;P40>_C]`060>kE]`3]e;H0kMBf0>cC]@3[d[@0j]6c0P3Yd;820>W:Z`<0j<VZ0`3Wb:T2
0>G7Y@030>C6Y03SaJ<0h/BR0080h/BR0P3Q`j440>32X0@0hL>Q0`3O`Id20=k0W0<0gKnK0P3P_i`2
0=nnV`@0g[fJ0P3L^iP20=flV@<0g[fJ103O_Y/30>2oW080hL2M0P3P_i`20=nnV`80g[fJ0P3M_9T3
0=nnV`<0h;nL0P3Q`9d20>;1WP80hL2M0P3P_i`:0=nnV`80hL2M0P3P_i`30=nnV`030=jmVP3K^YL0
fkZG00<0g;^H00<0fkZG0=VhU@3H]i@00P3M^Y@01P3L^I<0f[NA0=ReS`3G]8h0e[>=0=FbS080dk><
0P3D]8d0103E]Hh0e[J?0=NgT03G]i040=RhT@@0fKVB0`3G]i020=JfS`@0eKF>0`3D]8d20=>cS080
d[:;0P3C[h/0203B[hT0dZn70=6^Q03A[h80d:j10=2^P03@[HD0dJj60`3B[hL00`3@[HD0cZ^30<fZ
PP020<n]O`040<j/OP3=Zgd0c:Yl0<^YN`<0bZQj1P3;Z7h20<bYO`80b:Ih0P37YGL30<JTMP030<FS
M@37Xfl0aj=_00<0aZ9^0`35XFd20<BPK0040<>OJ`32WVX0`YiZ0<6MJ@80`9aX0P2nVVX60;fIJ@06
0<6KM031W780`Ia`0<6LK`31WF/0`IeY0P31WVH80<FPL`<0`Yi^0P31WFd30<2LK0080<>OJ`31WFT0
_i]W0;jJIP2mVFD0_YYV0;nKI`30W6P30;jJIR_ooooo000Zooooo`P0ZGi;00@0Yga90:QmBP2XODX0
Z7e:0`2YOT/00`2ZOd`0ZH1<0:V0C0080:V0C080Z7m;00X0ZH1<0:^2CP2]Q500[XEA0:b1EP2/PE@0
Zh1C0:^1D@2ZP4h0ZX5=0P2YP4X80:b1CPP0[XEA00H0[hIB0;68E02eS5P0^Y5M0;jEH@32VFD20<BK
I`060<:OJ@34X6`0aj=_0<VUL`3:YWH0bjIi0P3:YGT20<ZWO@050<^XOP3<ZGl0cZ^10<j[P@3?[880
0P3@[H<80<n/PPP0cJf60`3=[H@20<b/P`<0bj^201P0bZV80<^ZQ`3<ZhP0cJf70<b/Q@3:ZX40bJYn
0<NXO036ZGl0aJQn0<BWO@31Y7X0_j9h0;bOM@2kWW@0^Yec0;VFK02eTVP0[haR0:b9G`2XQE/0XGiD
09QeB`2@KD<208eX?00308eX>`2=JCT0SFTg0080SFTe00@0SFXd08mY>P2?JCX0T6Xk0P2AJc`00`2B
K3d0Tfdn09=]?P0309=_>`80TVhj0`2AKCT0102CKSX0TVdi099]>@2BKCT3095/>003091[=`2BK3d0
Tfdn00<0U6ho00<0TV`m091Z>`2?JCX0202DJSP2095[?080T6Xk00@0SfTj08iX>@2=IcP0SFLh0P2>
J3T208eW>0@0S6Hg00<0TfPk099W>P2AIST00P2@ICP00`2AIST0TVLj09=X>`08099W>PP0SVPi00@0
TFLe099X=P2BJ3H0TVPf0P2CJCL209AZ>0<0TVdi0P2AK3P4091[=`P0TF`h0P2CKSX2099]>@@0TF`h
202BKCT2099]>0<0TF`g00<0TVdh09A_>P2EL3/00`2CKST3099]>080TF`g0`2EL3/209Ia?0<0Ug8m
202DL3`209=_?`0409A`@02ELD40UG5109Ib@P80Ug=30P2HM40209Ue@@<0VWI200T0VgM309ad@@2L
M440VGA009Qd@02IMD40VGQ309UjA02KO4H0202HNTP01@2GMDL0U79408m]?`2;JC/0R6Hh0080QfDg
00`0R6Hh08AV<P1oHc40Me`]06aE:`1QCBP0ETHU04m08`1:?240B3hU04Lm9014>R42048h7`0804@j
8@17?B@0B3hU03Xc8`0h<B40=2hP02hZ7P0[:Ad202PX7P0302LX800V:1X09RPJ00<09bTK0`0X:Q`0
2`0`<ah0;S4L02ha700a=1l0=CPS03<f8@0^<A`0:2/F028U7P0Q91d07b8K00<07B0I00P07R4J01lR
6`0I8a/06R4J01XQ6@0J81H07B0E020R5@8092@H01L09BHH02/Y700a;Ql0>C@P040i7@18?Ad0E4HO
065C9P1/Fbd0Mf4X081Z;P26Lc40Q7<^085a<`1iJCH0IU@^050o8@0b<bD0;2dO02DV600S91H09bPJ
02//7P0202d^8080<2dN00@0;b`M02h[700]:Q/0;BXK0P0/:AX202//7P0402X[7@0Y:Q`0:2TK02PY
6`809bPJ0P0U9A/00`0W9ad0:2PN02TY7`0202PX7P0Y02LW7@0X:AT0:2TI02TZ700X:1`09bLM02@T
700R8A`081lJ01`W6@0R:Ql092DO030Y8@13=bL0CSdQ05m:7`1jIC00TGTi0:B;DP2fVf`0_:1i0;fQ
O02lX7P0]I]Z0:bCF`2UQE`0XH9C0:63C@2[SU@0/iIN0:N9E`29JD80KTd^03hh:P0k>2T0>CDY03Dc
9`0`<2H0;BhV02X]9P0X:b@00P0U9b@302@V8`<08bDR00P09RPS02LY900Y:R@0;2`T030]900c;b@0
=30U03La9@P0<blS100_<28402h_8@0;02h`8`0_;b<0<34S03<a8P0d<B00=c8O03Tb800i<Ql0>BlS
03X`900l<RH00`0m<bL203`b9P80>c8Q0P0l<b8403dd8`0304Ph8@1:>R<0CCdV0080CclX00d0CShW
04`l9@1:>R<0BSXS04Ll:017>RL0ACPU04Hg9017=R@0BSLV04dh9`1>>BP0D3`T0080DCdU00<0DShV
05<o9`1D@2P00P1E@BT205<n:@03058m:01A?2L0D3/V0080CcXU00<0CSTT04`l9@1=?BH00P1=?BH2
04hn9`80CclX0`1D@bT205=2:0<0DT4W0P1NABL00`1OARP0H4LY0658:P020699:`0906=:;01IBBl0
FDT_05Y9;`1KAbh0FdD]05e5;@1LA2`0GD</0080DD4Z00<0D40Y04lo:01>?RL00P1=?BH00`1<?2D0
BCdU04Xn9P0204Xn9P0<04Pl9016>R80A3PP048f7P13=BX0@C<X03hb9P0i;b<0=blR03H`8P0d<B80
=C8S0P0f<2@303La9@<0>38V00@0>C4N03Xb7`0l=240?SHS1010>2D203<d8P03038c8`0a<R@0<30T
0080;blU00T0;RhV03@^800e;b40=S0R03La8`0f<280=BlQ03<]7`0b;1h0400`;2<803@^8P0303Tc
9`0h<RH0=S0T00<0=BlS0P0f<2@803P^8P80>C0O00L0>S4P03/b8@0l<b80?3<R03/b8@0j<B00>C0O
0080?SDV00`0@3@T044d8`14=2@0AcHT04Th901;>BD0CClT04i09@1??bD0DD0V05919`1E@BP205M1
:@0404Xo;@17?2X0@cPV040e8`80?S<Q00P0?c@R040e8`16=RH0AcPU04Xi9`1>?2P0CcdW058n9P80
DcdU0180G4@R05i6901RBRP0IDd[06I>;01UCB/0I4`Z06=;:@1YBbT0JddY06i@;01`DR`0LE@/071C
:@1^DBD0K4lS07EE;P1dE2d207=C;00B07AD;@1fERl0N5Pa07UI<P1fFRP0N5`Z07aP<01nHS<0Of8f
07iQ=`1lGcL0Nehf08AV=026J3H0RV`j08e_?@2@LT00TG=10P2BM4809@2AMDH0SG5208Y^?P2:KS`0
SW<n091e?P2?M3d0S78i08AY?P23J3d0PVLl081U>P1nHcP0O64f07]P=@1jGc@0Of<d089V=`25JCT0
Q6Pf089W<P23J340Qf`e08ab>@2@JcL0U6lk09Qd@02JND@0VW]509Mi@`2DMT00Sg@m08id@@2=Ld00
S70n08e_?@2=KC`00P2>K3`00`2@K3`0RFln08U_?P0208Q^?@<0Qfdl0P26K3/02`2:L3l0TGE309Eg
@`2FMd40VGQ209inA@2UPTX0Vgm=0:24DP2UREL0Yh]I0080YHUG00X0Z8aJ0:b@GP2XU5T0ZYAJ0:bF
G02bVF00]ieT0;nRJP35YVl0ajQa1@3=/h840<bbP@060<naN`3>/7X0cJmi0<b^N03;[GL0c:ih0P3=
[gT08`3?[Gd0cZal0<f[N`3?[Gd0e;:20=^iR@3Q_hl0i/BD0>_>Y03^dJL0l]F[0?KI[`3hfk40nMbb
0?SK/@3gf[00m=FW0??DYP3adZ<0kLnM0>S:UP3SaHl0gl6;0=boQ`3L]hX0fkV<0=fnT03SaYX0jM:V
0>oJ[`3^gK80jmba0?;@X03S`I40e[B40080dk6100/0d[200=NeQ@3O_Hd0ilRI0>W:W03[cj00k]>V
0>oGZ`3`fJl0l=Za0?7K/P020??M]00V0?CM/`3dg;00lmR[0?7EYP3_d:80kLjO0>G;V03Vc9T0ckF4
0;VNK`2kX7<0_J9g0;RLM02jWWH0^Z=g0;VRMP2hXGD0]j1d0;JOL`2eWW80]9ea0;>LL02eWGL0]Yih
0;RPNP2jXW`0_:An0;jVP030Z880`JV30<JXQ039[HP0d;>A0=JlV`3K`Z<0gLJW0=c7Z03LajX20=o;
/P040>3</`3QcK@0hLfd0>;>]@80hlnf0P3Qd;H0:03PckD0g/fc0=g</P3Lbk40flZ`0=[9[`3Ob:T0
g<FV0=S1XP3C_9d0ckRI0<ffU`3<]IH0bkBE0<NcSP36/Xd0ak6<0<J^RP35ZhP0aZV70<BWQ@34YX@0
`jj30;jYOP2jXgT0_:=j0<>WO`38Zh<0c:b50<^[Q03;/Hh0c[BC0=BlVP3I`Z80g<NX0=k;[@3NbZl0
g<^_0>3>]P3Rd;P20>GC^`030>OE_@3Xe[h0jMNo0080j=Jn0P3ZflP01P3ZgL`0jmo?0>[QdP3[hmH0
kNGH0>cVfPP0lnOK203cimL80?;Xg0060??Vg@3aimh0l^SO0?7Xh@3`jN<0kn[V0P3^j^L30?7/iP80
l^gW0`3ck^P80?G^iP80lnkZ0P3dkn/20?G`k080m_7]203gl>P80?W_i@P0m_3T203hk^@80?O]h`P0
mngQ203ikN480?OZhB40mN_Q203fjnD20?S^i080mngS0`3fk>890?G[hA00lN[R203cjMl@0?G[h@P0
lncT203fjnD80??]h@P0lN[R203dkND80??/i0P0lngQ00@0mNkV0?C]i@3dkND0m>gU0P3ck>@20?;[
h`P0m>[P2@3ejn480??Yg@<0m>SH0P3cimL30?;VePP0m>OF203bi]H0103ej=L0m>OF0?CWeP3dimH2
0??Ve@80l^GD2`3ei=820?CSd@<0ln;@203ah<h@0?3Oc@80lN7:0P3`h<T20>oOb080k]k7203_glP2
0?3NaP80kmg50`3^g<@90>gK``80k][100<0kMW00>cH_`3[ekh00P3Ze[d0103YeK`0kMFi0>gE^@3]
eKT20>cD^0<0jm>g00H0k]Fg0>gD]P3]e;H0k=>e0>_B]03ZdK<20>W@/P80jLZ[0`3XbJX30>O8Z@05
0>K8YP3UajD0iLNU0>C6Y03SaJ<00P3Ra:8:0>73X@040>32WP3O`Id0gl6M0=o1W@80g/2L0P3M_i/3
0>2oW080gkjK0`3N_IX30=flV@80g[fJ1P3O_Y/30>2oW080hL2M0P3P_i`20=nnV`80g[fJ0P3M_9T3
0=nnV`<0h;nL0P3Q`9d30>2oW080gkjK0`3N_IX80=nnV`<0h;nL0P3O_Y/30=jmVP050=flV@3L^iP0
fkZG0=ZiUP3I^9D00P3J^IH02P3K^YL0gKZD0=fjU03L^I<0f[NA0=VfT03H]Hl0ekB>0=JcS@3C/h`2
0=BdS@030=FeSP3F]Xl0ekN@0080f;RA203I^I80103H^940ekN@0=NgT03G]i020=JfS`D0eKF>0P3D
]8d30=>cS080djn;00P0dZn90=:_Q`3A[X@0dJn20=2^P@3@[X00d:f50=6^QP<0dZn700@0d:f50<j[
P`3=ZX80cjeo0P3>[7h00`3=Zgd0c:Yl0<^YN`020<^YN`030<ZXNP3;Z7h0bjQn00H0bjQn00@0bJMi
0<RVN038YWP0b:Ih0P37YGL20<JTMP<0aJ5]0`36XVh20<NSK`80a:1/00@0`im[0<:NJP32WVX0`IeY
0P30W6P30;fIJ@D0_YYZ0P31W7000`31W6l0`Ie]0<6MJ`020<6MJ@030<6NJ035X7<0aJ1c00H0aJ1c
00@0`im_0<:NKP32WVh0`Yi^0P31WFd20<2LK0080<>OJ`31WFT0_i]W0;jJIP2mVFD0_YYV0;nKI`30
W6P30;nKIb_ooooo000Zooooo`P0ZWm<202XODX90:V0C0070:QoB`2WOTX0Ygi:0:QoB`2ZPDd0[8=?
0:j5D@020:b1E0040:^1D@2[PDl0ZX5=0:Z1B`80ZH18202]PTl80:j5D@0>0:n6DP2aR5@0]8]G0;R?
F`2lTel0_iIR0<6HI032VFD0`9eW0<:NJP34X6`0aj=a0<RTM039Y7L20<RSM`040<NTNP38YG/0bJIl
0<^XOP80cJZ000<0cZ^10=2]P`3@[H<0203>Zh480<^[PP<0c:b30P3;Zh830<ZZP@0H0<RWQ039ZH<0
bZZ40<ZZP`39ZH00b:Um0<FVN034YGL0aJIj0<BUN@32XgL0_j1d0;bML@2jVfl0^9U]0;NHK02cT6H0
[X]Q0:N4FP2ROeD0WW]A09QeB`2@KD<0RFHl0P2;ISX00`2;IST0S6Ph08aX=P0208aX=00408eZ=02?
JCX0T6Xk091Z>`80TF/l0P2BK3d0102CKCh0Tflk09=_>`2CKc/3099^>P80TFdi202BKCT00`2BK3d0
Tfdn09A^?`0209A^?`03099/?@2@JS/0SfTj00P0U6Xh0P2BK3d01P2AJc`0SfTj08iX>@2=IcP0S6Hg
08]U=P80SFLh1P2<ISL00`2CJ3/0TVLj095V>@02091U>003095V>@2BIcX0TfPk00P0TVLj202>J3T3
091V=080TFLe0`2BJ3H4091Z>@D0SfTh0P2BKCT4095/>080T6/g0P2BKCT6095/>0P0Tf/h0`2AK3P2
099]>@80Tfhj00<0U6lk09=^>P2CKSX01P2BKCT309E`>`80UW4l0`2GLSd00`2ELCd0U70l09A`?002
09A`?0<0Tflk00<0Tflo09A`@02DL4000P2ELD4209Ib@P0409Mc@`2HM400V7A009Qd@080VGE10`2J
MT801P2LM440VWE109Ue@@2IMD40V7M209Qi@`80V7Y4202HNTP01@2DM4D0TW9308i^?`2:JS/0QfLh
00<0QVHg00/0PV@`07eQ;`1fFb`0Je@Z061<9`1EAB@0CSlR04Xl8@17?B@0AS`S04@j8@0204<i8008
04@j8@16?2<0AcdT03Tb8P0g<200<bdO02hZ7P0[:Ad202PX7P0302PY8@0V:1X09RPJ00<09bTK0`0X
:Q`02`0^<A`0;C0K02ha700a=1l0=3LR03<f8@0^<A`0:2/F028U7P0Q91d07b8K00<07B0I00P07R4J
01lR6`0I8a/06R4J01XQ6@0J81H07B0E020R5@8092@H01T09BHH02XX6`0`;Ah0>C@P040i7@19?Qh0
ETPQ06=E:01^GBl0Mf4X07mY;`23L2h0PFl]07e]<@1fISD0IE<_050o8`0b<bD0:b`N02@U5`0S91H0
9RLI02//7P0];R00;2dO0080<BhO00H0<2dN02h[700]:Q/0;2TJ02/X6@0Z9aP202//7P0402X[7@0Y
:Q`0:2TK02LX6P809RLI00@09BDK02HV700V9Q`09bLM100X:1h202PY6@0V02TZ700X:1`09bLM02@T
700R8A`081lJ01lW6P0T:R009RDP034Z8P16>BT0DShS069;8@1mIS80U7`n0:N>EP2iWW40_j=n0;jQ
O`2lX7T0]9UZ0:ZAF`2TQ5/0Wh1A0:63C@2[SU@0/YEM0:J8EP28J440KD`]03hh:P0j=bP0>3@X03Dc
9`0`<2H0;2dU02T/9@0X:b@202DW90<092HS0`0S9B80200W:B@0:2XU02X[9@0];BD0<BhU03@`9@0e
<BH0>38V200c;b<0100];R00;RlQ02h_8@0^;b4302l`8P0:030a8`0^<2<0;blS030a8`0c<B80=34P
03Lb7`0i<R00>C8O03X`9080>c4U0P0l<RH303dc9`80?3<R1P0m=2<00`17>2<0BCXU04/l9`0204dn
:@0<04`m:01;?2L0BS/V04Xk9P16>bL0ASTV04Dh9@16=b@0B3LU04Xg9P1>>BP0CcXY0`1B?RH00`1C
?bL0E40X05A0:00205E1:@06054o:@1@?RP0D3hX04lm9`1>?2H0CC/U0P1<>R@204`l9@<0CCdV0`1>
?RL805=2:080GTDW0P1OARP0101PAbT0HDPZ0658:P1QB2X205M7;@0305Q7;@1JARd0FdD]0080GDD]
00L0GT@]0551:01A@BP0D40W04lo9P1>?RD0CCdT0080C3`S00h0Bc`U04`m9P1=?RL0CChW04`m9P19
>R<0AcPQ04Hg8015=b`0@cDZ03lc9`0j<2@0>30S03H`8P80=34R0`0g<B<203Pb90<0>C<U00@0>C4N
03/c800n=R<0@CTV0P12>RL01`10>2D0?cLT03He8`0f=B<0=C<T03@b9@0c<BD00P0b;bH02@0a;RL0
=BlQ03H`8P0g<B<0>38T03La8`0f<280=2hP03<]7`0@030/8`@0=BlS100d;R80100j<RD0>C4T03Ta
900h<2<403L_8PP0>BlS0P0i<1l03`0k<R40?3<R03dd8`0m=2<0?3<R03/b8@0i<1l0@cLY048f9P13
=RD0ASHV04Lf9019=b<0BCLQ04`g8P0204i09@0405109P1A@2H0DT4W05E1:080ET0X00@0Ac`Z04Dj
:012=bD0@3DS0`0n<b401`0o=280AcPU04Th901;>BD0CC/U050l901B?2@00P1E?B<04P1LA280GdLU
06A<:P1WCbd0J50^06I>;01RBRP0H4PV06E79@1XBRH0KDl[075C;@1bEBd0L5<Y06e@901[CR80L5<[
06mB:P80KU4Y0100Ke8Z075D;01cERh0M5L_07AH:@1gFb`0OF4b085U=P23ISX0PVDi081S=`1nHCD0
QfTg08U[>@2<KS`0Sg4o102ALd402@2AMDD0SG5108Y^?02:KS`0SG4o08ic?P2;L3/0R6dh081U>P02
07mT>@0307iS>01mHSL0O64f0080O64f01D0PF8d08=T=P25ISL0Q6Hd089T<025Ic40Rfdg095d?02F
LSh0VGE109]jA@2MOTP0W7i809MlA@2BMd00SWDm08ab?`2;LCh0Rflm08a^?02=KC`00P2=Jc/0102?
Jc/0Qfdl08M]?027KC`208I/>`<0QF/j00X0Q6/e08Q_>@2?M3l0TgE109Ae?`2HMd80WGa70:B1B`2J
OT`0Wh=A0P2SQeD0302QQE<0XXID0:F9E`2YSE/0Yi=H0:VCF@2ZU5X0[iIM0;FKHP2lWfL0`Z=/0<FV
K`<0ajej03h0b:ik0<V_OP3:/7l0bZn00<^`P@3;/8<0cK5o0<b`OP3:[W`0bJek0<Z^O03</7h0d;B2
0=:fQ03E]XP0e[N90=RiR`3L_Hl0hL:D0>S9V`3^cj40l]>U0?KI[`3gf[00nMbb0?[M/`3ig;80mmZ`
0?GH[P3dejd0lM:T0?3AX`3]cYl0jL^I0>G7T`3P`X`0gKn90=^nQP3M^HT0g;Z:0=jnS`3Sa9H0ilZN
0>WAX`3ZdjL0jmBZ0>o=W@3Q_hl0e[B40=>aP@3B/800dJmo0=NeQ@3Q_hl0j<VJ0>[;W@3/d:40kmBW
0?3H[03bfk40lM^b0?;L/`80m=je00h0mMjd0?GM/@3dfJ`0l]JW0?7BY03_d:40i<ZG0>K<V@3A]hH0
^Ym`0;ZOLP2kX7D0]i]c0;^OM`80^jAj00@0^Z=i0;RQM`2gX7H0]Iid0P2dWG<0402eWGL0]Yih0;RP
NP2jXW`0_:An0;jVP02oYh40`:R20<JXQ03:[XT0dKBB0=JlV`3K`Z<0gLJW0=c7Z03LajX20=o;/P04
0>3</`3QcK@0hLfd0>;>]@80hlnf0P3Qd;H0303PckD0g/fc0=g</P3Lbk40flZ`0=[9[`3NajP0g<FV
0=S1XP3C_9d0ckRI0<ffU`80bkBE01X0a[:=0<FaS036/8/0aZj:0<F[R035Z8H0a:N50<FWQ@35/8D0
`:^00;bUN`2mY7/0a:R00<Z]Q@3=[HH0c:b50<bbS`3@]YD0eKfK0=[3X`3Mb:T0glb^0=o;/03Mc;00
h<jf0>;@^080i=:j00D0imFm0>SF_P3Xe[h0j=Jn0>OE_@020>[Kb0060>[Mc03[gll0j^7B0>_SeP3]
iMP0k>KJ203cim/20?;VeP@0lnOG0P3dj=P80?;Xg0060??Vg@3aimh0l^SO0?7Xh@3`jN<0kn[V0P3^
j^L30?7/iP80l^gW0`3ck^P80?G^iP80lnkZ0P3dkn/20?G`k080m_7]203fl^T80?W`i`P0mo3V203h
knH80?S^i0P0mngQ203ikN480?S[hR40m^cR203gk>H30?S^i080mngS2`3fk>8@0?;[h`P0m>[Q403e
k><80?C]i@P0mncV203dkN<80?;[h`P0m^oW203dkND80?C^hP80mNkV0`3dkND30??/i0P0mN_Q2@3f
k>880?CZgP80mNWK0`3dj=X30??Wf@P0m>SH203cimL20?GXe`<0m>OF0`3ci]D80?KUd`<0mNCB0`3d
hm420??Rd0P0l^7?403ah<h20?7QbP80l>390P3_glP20>kNa`P0kmo80`3`g/H20>oMa@/0k]c40P3^
f/40103]fL00k=Ro0>cH_`3[ekh20>[F_@80k]Jj0P3]eKT20>cD^080jm>g00H0k]Fg0>gD]P3]e;H0
k=>e0>_B]03ZdK<20>W@/P80jLZ[0`3XbJX30>O8Z@80i/RV00<0iLNU0>C6Y03SaJ<00`3Ra:80103Q
`j40h/BR0>;4XP3Ra:840>73X@030>32X03P`Yh0h<:N00<0gl6M0`3N`9`20>70W@80h;nL0P3O_Y/2
0=jmVP80gKbI0`3N_IX60=nnV`<0h;nL0P3Q`9d20>2oW080gkjK0P3N_IX20=flV@<0gkjK0`3P_i`2
0>70W@<0gkjK0P3N_IX30=flV@X0h;nL0`3O_Y/30=jmVP030=nnV`3M_9T0f[VF0080f;ND00@0fKRE
0=^jU`3M_9T0gKZD0P3L^I<01@3K^980fKJ@0=ReS`3H]Hl0ekB>0080e;B=00@0eKF>0=JfS`3G]i00
f;RA0P3I^I830=ZjT`@0fKVB0`3H^9430=NgT0<0e[J?0`3E]Hh30=BdS@80dk><0P3C[h/0203B[hT0
dZn70=6^Q03A[h80d:j10=2^P03@[HD0dJj60`3B[hL00`3@[HD0cZ^30<fZPP020<j/OP80cJ]m0P3<
ZW`30<^YN`<0c:Uo103;Z7h00`3:Ygd0bJMi0<VWN@020<VWN@80b:Ih0P37YGL01P33Wf/0a:1/0<BP
K035XFd0aZ9^0<NSK`80b:A`0P34X6`01033Wf/0`YiZ0<:NJP31WFT20<2LJ080_IUY102nVVX20;nK
J`80`Ia_00<0`Ie]0<:NKP32WVh00P32WV`00`33Wfd0aJ1c0<FPL`060<FPL`80`im_0`32WVh30<6M
K@080<>OJ`31WFT0_i]W0;jJIP2mVFD0_YYV0;nKI`30W6P30;nKIb_ooooo000Zooooo`P0ZWm<102X
ODX40:MlB@P0ZH1<0P2XOd/20:MnBP040:QoB`2ZPDd0[8=?0:f4D080[89B00@0Zh5?0:^2CP2ZPD/0
ZX590P2YPDH80:f2C`P0[XEA0100/8MC0;68E02cRUH0]HaH0;R?F`2kTUh0_YEQ0;nFHP2nVfD0_i]W
0<:NJP34X6h0aZ9b0<JQM036XGD0aJ1d0P35XWP01`37Y7X0b:Ek0<ZWO@3:Ygd0c:Uo0<fZP03>Zh40
203<ZGl80<RYO@80bZZ10P39ZH030<RXO`0I0<NWOP35YGl0aZIo0<JVO`36YWd0aJIj0<>TMP31XW<0
`:5b0<6PL`2oWW40_Ia_0;ZIK02gUVT0]IAW0;:AI02aT6<0[HYP0:J3F@2NNe40V7E;09EbB02@KD<0
RFHl08AQ=`0208UT>00608UT=`2:ISH0RfLe08]W<`2<J3@0S6Tc0P2@JS/4095[?080TV`m0P2DL3`3
09=_>`<0TVhj102BKCT409=^>P03099/?@2CKCh0U6ho0080U6ho00<0TV`m091Z>`2?JCX0202DJSP0
1P2BK3d0TF/l091Z>`2?JCX0SVPi08aV=`@0RfDf1P2<ISL00`2CJ3/0TVLj095V>@02091U>003095V
>@2BIcX0TfPk00P0TVLj202?JCX4091V=080TFLe0P2BJ3H908mY>P0309=^>P2BKCT0TVdi0080TF`h
0P2@JcL00`2?JSH0T6/g091[=`06095/>0P0U6Xh0P2AJcX2099/>`@0Tfdl1P2BK3/209=]?0<0UG0k
0P2FLC`309Mb?@<0UG4m00<0U70l09=_>`2CKc/00P2BKSX209A`@0@0UG510P2FLT8209Mc?`80V7A0
0P2IMD4209Yf@P0809Ye@@2IMD40VWI209Qg@P2HND<0UgU309Ej@`2DND8809MiA`0C099cA02@LD80
SFho08UZ>`26IcP0QFHg08AU=P23I3D0PF<_07]O;@1eFR/0JU<Y05m;9P1EAB@0CSlR04Xl8@17?B@0
AS`S04Dk8P0204@j8@0804Dk8P16?2<0AcdT03Pa8@0g<200<bdO02hZ7P0[:Ad202TY7`0302PY8@0V
:1X09RPJ00<09bTK0`0X:Q`02`0]<1/0;2lJ02d`6`0`<ah0=3LR03<f8@0^<A`0:B`G028U7P0Q91d0
7b8K00<07B0I00P07R4J01lR6`0I8a/06R4J01XQ6@0J81H07B0E020R5@8092@H01L09BHH02XX6`0`
;Ah0>3<O03lh7018?Ad0EDLP069D9`1]G2h0MUlY07eW;P20K2d0O6XZ07UY;P1cHS@0He0_04ln900a
<R@0:b`N02@U5`0R8aD09RLI02X[7@0202`]7`80<BhO00H0<2dN02h[700]:Q/0;2TJ02/X6@0Z9aP2
02X[7@0402TZ700X:A/0:2TK02LX6P809RLI100V9Q`0100W9ad0:2PN02PX7P0Y:Al202PY6@0V02TZ
700X:1`09bLM02@T700R8A`081lJ024W6`0W:R40:BHQ03<Z8`1:>R/0ED0U06E<8`21Ic@0Ugm10:ZA
F`2lXGH0`JB20<2SP`2mXGX0/iQ[0:R>F`2RPUT0WWm@0:22C02[SU@0/YEM0:J8EP26ISl0JdX[03dg
:@0j=bP0>3@X03@b9P0_;bD0;2dU02T/9@0W:R<202DW90<092HS0`0S9B80200W:B@0:2XU02X[9@0]
;BD0<BhU03@`9@0e<BH0>38V200c;b<0100];R00;RlQ02h_8@0^;b4302l`8P09030a8`0^<2<0;blS
030a8`0c<B80=34P03Lb7`0i<R00>C8O00@0>c4U0P0l<RH203dc9`80?SDT1P0m=2<01015>2D0ASTV
04Lj9`18>bP204Tl:@0;04Pk:017>RL0AcXW04Dj9P16>BH0ACPU04Hg9018=bD0BSLV04hi:01@>bX0
0`1B?RH305<o9`80E40X0P1@?RP00`1??BL0CS`V04dk9@0204`j900404/i8`1<?2D0C3`U04`l9@<0
CCdV0P1>?RL205509P0405919`1C@RP0Dd8X05A3:@80ED@Z0P1OARP30617:@<0HDPZ0P1GAbd00`1H
Abd0FTH]05]5;@0205e5;@0705i4;@1B@RP0DD4W05519`1@@2H0CclU04hn900204dm8`0304`l9@1=
?BH0CShW0080CShW00T0C3`U04Xj8`18>240ASP]04@f:`10=2P0>c4U03P`8`0g<B<00P0e<R<203Pb
8P@0>C<S0P0j=2@0200j<Ql0?3@Q03lg9011>BH0@SXW044i9P0o=b@0?SHS0P0h=B@00`0g=2D0=S8V
03Da9P0203@`9`0903<^:00f<280=c4S03Pb900i<bD0>38T03La8`0e;b40<bdO0100<BdT00<0=2hR
03D_8`0e;b<0100e;b<00`0f<2@0?3<T03`c900203`c900403/b8`0j<B80>S4R03T`8@P0>S0T0P0j
<B003`0k<R40?C@S03he900n=B@0?C@S03/b8@0j<B00@cHV04@g9P17=bL0BCPV04/i9@1;>B<0CCTQ
04hh8@0204m19P0:05109P1B@BL0DT4W05A09`1E?bL0ET0X04Hk:@14>BL0@SLU040e8`@0?c@R00/0
BCPT04/i8`1;>B<0Cc/S054k8`1E?B<0F3hS05To901NAR@0HDTW06E=:`0206Q@;P0;06E=:`1RBRP0
GdLU06A6901WBBD0K4hZ075C;@1bEBd0LE@Z06iA9@1/Cb<00P1[CbL206Y>9P0@06]?9`1]DBT0Ke<[
071D;01cERX0MeX^07eP=022ICT0QFTj08AX>@22ISL0P6@e08U[>@2;KC/0SFlm08ma?`80T79000H0
Sg4o08i`?P2?M3l0S74l08U^>@2:KS`208a`?P0308U]?@25JCT0P6Dj0080P6Dj1@1oI3T04021H3<0
Q6<f08IV=`25IC@0QFDb08MX<P2>KcT0U7Dn09akAP2OOTT0XH9<0::4CP2NPd`0V7m7099i@@2=Mch2
08U_?00308Y^?02<KS`0SFdl0080SF/k00<0SVXj08Q/?028K3`00P27Jc/408IZ>P0:08A[<P29L3P0
Sg@m09=e?`2DM440UgI309akB02SOdd0VWi<09f1C`80X8AB0P2MPDl02P2QQE<0YHUG0:FAEP2WTEL0
Z99H0:fDF`2bV5l0^IaT0;nPJ@31XV/30<2WK`080<:YL`34ZWL0aZ]l0<R]P039[X<0bZn40<baPP3;
/8420<Z_P00<0<baPP3?]8D0dkR90=JkS03M`YD0g/>F0>;7VP3Vbih0k=6T0?;GZP3gg:l0nMja0`3j
gK<06@3hfk40m]V_0??F[03ae:X0km:X0>o@XP3^cj40j/^L0>K8UP3Ra900g/2:0=bnR03J_HD0hkn;
0>C0S03S`Xl0i<:B0>C4U@3TaIL0i/NI0>S9W@3YaiL0gK^;0=BbPP3B/8000P3?[Gd0203G]HD0i<:B
0>[;W03/cIl0k]:S0?;GZP3cfjl0m=fc0P3dg[D20?KP]`0V0?OP]P3fg[80m]^^0??GZ03bdjD0l=6R
0>C:U`3WcIX0dkV80;^PL@2iWW40^Iic0;JJLP2kWgL0_:El0;^TN`2jXgX0^J9i0;RQN02gX7L0]Ymf
0;FNM@2gWgT0^:1j0;VQN`2kXgd0_JEo0;jVP02oYh40`:R20<NYQ@3:[XT0dKBB0=NmW03K`Z<0g/NX
0=g8Z@3Mb:/20=o;/P040>3</`3QcK@0hLfd0>;>]@80hlnf0P3Qd;H0:03PckD0g/fc0=g</P3Lbk40
flZ`0=[9[`3NajP0flBU0=O0X@3B^i`0ckRI0<beUP3;]9D0b[>D0<FaS034/8/0aJn:0<F]R@35ZhP0
aJR60<BWQ@35YhD0a[660<6/P@2mYW`0_ZEl0<BXP03:[HD0cJf60<b/Q@3</Xl0d;JE0=FmV`3J`j<0
gLRY0=o<[P3Obk00gLb`0>3>]P3QckL20>CB^P030>KD_03Xe[h0j=Jn0080imFm0P3ZflP01P3ZgL`0
jmo?0>[QdP3[hmH0kNGH0>cVfPP0lnOK00<0lNGE0?;VeP3bi]H00P3cimL20?CXf0030?GYf@3cjMd0
lnWM00H0lnWM00H0lnKM0?7WgP3bj=l0lNSQ0?3Yh`3_j^H20>kZi`<0lNcV0P3bkNL30??^j0P0mNkV
0P3ck^X20?C_j`80mO3/0P3flNd80?GbjaP0n?7Y203iknD80?S^hPP0n^kR203hjn8Q0?K/hPP0n>gW
0P3iknD20?S^i080mngS2P3fk>8@0??/i0P0mN[T603dkND80?S]i`P0m>gU203ck>@80?K_i`P0m>gU
203dk^830?G^iP<0m>gU0P3ck>@80?G[h@T0m^cR203ejml20?KZgP80mNWM103dj=`80??Zf`P0lnOG
0`3ej=L30?CWeP80lnKE2P3fiM<30?GTdP<0m>?A203bhLl@0?7PcP80lN7:0P3`h<T20>oOb080k]k7
203`h<T20?7Oa`80l=k60P3_gLD:0>kLa080km_200@0k][10>gI`03/f;l0jmNn0P3Ze[d30>kF^P80
kMFi0`3/e;P01P3^eKL0kMBf0>gD]P3/dkD0jm:d0>[A/`80jM2b0P3YbZ/30>S9ZP<0ilRY00D0ilVW
0>K8YP3Vb:H0iLNU0>C6Y0020>?5X`80h/BR0`3SaJ<00`3Ra:80hL>Q0>73X@020>32X0<0h<:N0`3O
`Id20=k0W0<0hL2M0P3P_i`30=nnV`<0g[fJ0`3O_Y/20>2oW0<0gkjK0`3P_i`20>70W@80h;nL0P3O
_Y/20=jmVP80gKbI0`3O_Y/30>2oW080hL2M0`3O_Y/20=jmVP<0gKbI203P_i`30=nnV`<0g[fJ0P3M
_9T00`3O_Y/0gKbI0=ZiUP020=RgU0040=VhU@3K^YL0gKbI0=fjU080g;VC00D0fkRB0=ZgT@3I]Y00
fKJ@0=ReS`020=FeSP040=JfS`3G]i00f;RA0=ViTP80f[ZC0`3K^i@00`3J^Y<0fKVB0=ViTP050=Rh
T@<0ekN@103F]Xl30=FeSP<0e;B=0P3C[h/0203B[hT0dZn70=6^Q03A[h80d:j10=2^P03@[HD0dJj6
0`3B[hL00`3@[HD0cZ^30<fZPP040<f[O@D0c:Yl0P3=ZX020<bYO`040<^XOP3:Ygd0bZMm0<ZWO@<0
bZQj0`39YgT20<RVN0060<>OJ`34X6`0a:1/0<FQK@36XVh0aj=_0P38Y7020<BPK0040<>OJ`32WVX0
`YiZ0<6MJ@80`9aX0P2mVFT20;jJJP80_i][0P30W6`30<6MJ`030<:NKP33Wfl0`im_0080a9mb2035
X7<30<>OK`<0`Yi^0P31WFd01`33Wf/0`IeY0;nKI`2nVVH0_IUU0;jJIP2oVfL01030W6P[ooooo`00
:_ooool80:UnB`<0Z7e:0P2WO4T30:IkB0P0ZH1<00P0Z7m;0:MnBP2VODT0YWe90:MnBP2YP4`0Zh9>
0:f4D080[89@00H0Zh9>0:^2C02ZPDT0ZX970:V1AP2YPD@80:f2C`P0[XEA00h0/8MC0;68E02aR5@0
/hYF0;F<F02iT5`0^i9N0;fDH02lVF<0_IUU0<2LJ032WV`0a:1`0<BOLP80`iib0P33X7H01@34XGL0
aJ9h0<NTNP37Y7X0b:Ek00X0bJIl2035YWX01037Ygh0aZIm0<JVO@36YWd20<FUO080a:Ak01P0`J5j
0<:RN`32XWT0`Z=g0<6RM02nWg00_9i/0;ZLJP2lVV`0^iU[0;RFJ02eTfD0/Y1R0:n=G`2/RU`0ZhUK
0:J3F@2OO580UW=9091]@`2=JT00RVLm08IS>@22GcD208MR=P0608QS=P28I3@0RFDc08YV<P2;Ic<0
RfPb202AJc`309A`?080Tflk0`2BKSX3099]>@80Tfhj0`2DKc/00`2BK3d0Tfdn09A^?`0209A^?`03
099/?@2@JS/0SfTj00P0U6Xh0P2@JS/0102?JCX0SVPi08eW>02=IcP208aV=`80RV@e0P2;ICH408aV
=`0309=X>`2BIcX0TFHi0080T6Dh00<0TFHi099W>P2CJ3/0202BIcX808mY>P80T6Hd0P2AIcD3099X
=P0309=Y=`2>J3/0SfTl0080SfTl102@JSd0102AJch0Tfhj09=^>P2BKCT2095/>003091[=`2?JSH0
SfXf0080SfXf0P2@JcL4095/>0P0U6Pg00D0T6Xk095[?02BK3d0Tfdn09A^?`0209=]?P03099/?@2A
Jc`0TF/l00<0TV`m0`2CKCh309E`>`80UW4l0`2GLSd209Ib?P0309Ea?@2DL3`0Tflk0080TVhj00<0
TFdi09Ea@@2ELD401P2ELD4309Mc?`80V7A0102IMD401`2GMT40V7M209Qi@`2GND<0UGY309=j@P2B
ND40202GNDL04@2?Ld<0SG5108]_?`28K3`0QFTi089V=P21ICD0P6@d07mQ;@1jGR`0LePY06UB:01N
BRD0E4@S04ho8P1:?240AS`S00H0AC/R00T0AS`S03Pa8@0f;al0<R`N02hZ7P0[:Ad0:BTO02XZ800Y
:R800P0V:1X302LY6`<0:2XL00/0;2lJ02/^6@0/;aX0<3<N03@g8P0c=R40;S4L02T/5`0R9Ah08B@M
01lR6`0301dP6@0801hQ6P0O8Q/06B<K01XQ6P0J8AT06R0F01dP5@0P8QD202@T600G02DV600Z:1/0
;b`M03Lb7P0n=a/0Ac`L05=57P1PDRD0JeX/07AM:@1jI2/0NfLZ07MU9`1cHRX0KUda061=;@1=>b<0
<C8T02X[7@0S91H08R<E02DV600Z:ad00P0/;Al2030]7P0402l/7@0^:a`0;BXK02dZ6`80;2TJ0P0Z
:ad00`0Y:Q`0:2TK02LX6P0202HW6@0702DV600W9ad09RHL02HV700U9A/09RHL02LW7@0202TY7`80
:2TI02H0:BXL02PX700W9ad092@L028Q700P7aX08bHK02TZ8P0[9R80=R/U04`j;01I@BL0IdhU08AX
=P2IPDD0[I=P0;nSN`34YhD0`ZF50;fQO02cV6d0YheL0:20E`2MOTl0Wh5;0:^>E02bUEd0YHME08EU
?P1YB2T0?CLY03Tf9`0g<bL0=38V02l_9@0[;2@0:2/T02LZ8`809BLT0`0T9R<302<U8P0802HX8`0W
:B@0:BXT02`/900`;B@0<blT03@`9@0g<BD803<_8`@0;c0R100^;b402@0^<2<0;blS030a8`0c<B80
=34P03Lb7`0i<R00>C8O03`b9P0203/a9@0503X`900k<BD0?38V03dc9`0n=2P00P0o=RD203he90@0
?C@S00@0@SLU04<h9P13>2H0A3TW1@15>RP02015>RH0ACPU04@g9016=b@0B3LU04/h9`1?>RT0D3/Z
201A?BD01P1??bP0CShW04hn9`1=?BH0C3`U04/k9080BSXS0P1;>b@204`l9@<0CCdV00L0CShW050o
9@1@?bD0DD0V05919`1D@bT0ED@Z0080ETD[201RBB/205Q8;P0305Q7;@1JARd0FT@/0080Fd<[00L0
G48[05A4:P1C@bT0Dd<Y0592:01A@BL0D40V0080CclU00<0CS`V04lm9`1@?RP00P1@?RP02`1>?2H0
C3XT04/i8`15=b`0A3H[040d:00l<RH0>S8U03Pb900g=2D0>3DV00<0>cHS0P0j=B8303Td8@0303/c
800l=240?CDR00<0?cLT0P0n=R<203/e9@0303Xd9P0i<bL0>34W0080=c0X00<0=RlY03La8`0h<R@0
0`0i<bD00`0g<B<0=S0R03@^800@034]9080<bdQ00@0=2hR03D_8`0f<2@0=c4U0P0h<RH2040d90<0
@CDU00<0@3@T03hb8P0m<B40200k<BD203/b8@0=03`c8P0n=B@0?cHU03lf9@0n=B@0?3<R03/b8@13
<b<0A3DR04Pg9@1;>BD0CC/U054m9@02058l9080D48W00@0DD4W05919`1B@BL0E40W0P1E?bL01@15
>RP0A3TW04<h9P12=bD0@CHT00<0@3DS00/0BcTS04dh8`1>>R80D3XR05Dm8`1I?b@0GD8U05i39P1R
BRP0Hd/Y06E=:`0206M?;@0906A<:P1RBRP0H4PV06E79@1XBRH0K4hZ071B;01bEBd0LUD[0080LE@X
0200KE4Y06a@:01[CbL0JdlW06a@:01^DRX0L5@/079F;P1eF300MeXb07aO=@20HcL0PfLh08=W=`23
IcD0PVHd08]]>`2<KS`0SFlm08i`?P2?LCl0SW0n08a^?02;KC/0SG<j08Y_>028KCH0RFhi08a`?P2<
L400R6`m08=W>0H0P6Dj0P1oI3T06@21Gc80QF<f08UW>@2:J3P0RVTf08a[=P2BLC`0UgI00:21B`2R
Pdd0XhE?0:66C`2MQ4`0UGm608mi@029M3/0QV`i08M]>P29KC/0S6hl08e]?02=Jc/0S6Xj08eY>@2;
K3d00`2:Jc`208UZ>`80R6Tj00`0Qflc08]c=`2@MSd0U7I009Ad@@2FM4@0VgU;0:5lC`2JOT`0W81>
09j2D02MPDl209YnC00;09j2D02RQU@0Y91E0:F?E@2VT5H0Zi9I0;2FG@2gVV80_9eV0;jOJ02kXfL0
0P2mY6/05P2oYVh0`ZQe0<FZN`38[H80bZj60<b`R@3=/XL0c[>80<ndR@3A]X/0e;V>0=RmTP3K`9D0
gL:G0>C=X`3VcjD0j]>Y0>oH[P3cg;80mn2f0?[S^@3ki;X20?_N]00J0?WL/P3gf[00m=N]0?7DZP3^
dJL0kM2V0>o@XP3]cZ00jLZK0>C6U03Q`hl0g/2:0=bnR03K_XH0i<690>G2RP3U`X`0h[j:0=jjR03L
^8P0g[Z:0>6lS`3P_Xh0ekF50=2^OP3?[Gd20<f[N`080=RfQP3Va9@0kLjO0?3AX`3beZL0mMZ]0?KN
/P3gh;H20?OQ^080nN>j00h0nN:h0?SP]03gg:l0lmNX0?;CY@3_d:40hlVF0>S>V`3E^hX0_:5b0;RM
L02gW740]IUa0;bPN0@0^Z9l0P2iXG/20;RPNP80^Z9l00@0^j=m0;fUO`2nYX00`:R20P31ZH<02037
ZHD0bjn:0=:eT`3G_I`0g<>T0=k7Z03Mb:T0gLR[0P3Obk80103Pc;<0hLfd0>7=]03Rc[D20>??]P80
hM2f00`0h<ne0=k=/`3Mc;80g<^a0=_:/03JbJl0gLJW0=_4Y@3G`:40d[^L0<jgV03<]IH20<ZcU080
`jn:00<0a:j90<B/R034ZXL00P35Z8H04`35YhD0a[660<6/P@2mYW`0_ZEl0<BXP039[8@0bj^40<ZZ
P`3;/Hh0c[BC0=BlVP3I`Z80g<NX0=k;[@3NbZl0g<^_0=o=]@3QckL00P3SdKT01@3Ve;`0imFm0>OE
_@3WeKd0i]Bl0080j]_800H0j]g<0>_Oc`3ZhM80jn?F0>gUf03/i]X80??Wf`80lNGE00@0l^KF0??W
e`3cimL0m>SH0P3ejMT80??Yg@060??Vg@3aimh0l^SO0?7Xh@3`jN<0kn[V0P3^j^L30?7/iP80l^gW
0`3ck^P80?G^iP80lnkZ0P3dkn/20?G`k080m_7]203cl^d80?Kaj`P0nO;/203gl^`80?[`iPP0n>kR
203jk^880?W/hb40mngS203ik^P30?W_i@80n>kT2`3gkN<@0?C]i@P0m^_W403ck^P80?G^iPP0nNkX
203ek^P80?C]iA00mNkV203ekn<20?K_i`80mNkV0`3dkND00`3ck>@0mN_Q0?G[h@060?G[h@T0mngS
203fk>020?OZh@80m^WP0`3ej=l00`3dimh0m>[N0?CZgP060?CZgPP0m>SH0P3fjMP20?GXe`<0m>OF
00<0lnKE0?KUd`3fiM<02@3fiM<20?GTdP<0m>?A203ch]0@0?7PcP80lN7:0P3`h<T20>oOb080k]k7
203`h<T30?7Oa`80l=k62`3_gLD20>oK`P040>kJ`@3]fL00k=Ro0>cH_`80jmNn00@0kmNk0>kF^P3^
e[X0k]Jj0P3]eKT20>cD^0060>kE]`3]e;H0kMBf0>cC]@3[d[@0j]6c0P3Yd;820>W:Z`<0j<VZ0`3W
b:T20>O9Y`030>K8YP3UajD0i<JT00<0hlFS00<0h/BR0>C6Y03TaZ@00P3SaJ<0103Ra:80hL>Q0>32
X03P`Z020>73W`80h<:N0`3O`Id00`3N`9`0h/6N0>70W@020>70W@80h;nL0P3O_Y/30=jmVP80gkjK
0`3P_i`30=nnV`<0h;nL0P3Q`9d20>2oW080gkjK0P3N_IX20=flV@<0gkjK0`3P_i`20>70W@<0h;nL
0P3O_Y/30=jmVPP0h;nL0`3O_Y/20=jmVP@0gKbI00@0g;^H0=^jU`3J^IH0fKRE0P3J^IH0103K^YL0
g;VC0=biT`3L^I<20=^hTP<0f[NA0P3F]Xl00`3G]i00f;RA0=ViTP020=ZjT`030=^kU03L_9D0g;bE
0080fk^D00@0f[ZC0=ViTP3H^940f;RA0P3I^I820=RhT@<0ekN@103F]Xl20=FeSP<0e;B=0P3C[h/0
203B[hT0dZn70=6^Q03A[h80d:j10=2^P03@[HD0dJj60`3B[hL00`3@[HD0cZ^30<fZPP040<f[O@D0
c:Yl00H0cZ^10<fZP03=ZX00c:Uo0<^XOP3:Ygd20<VVO0<0bjUk0P3:Z7X30<VWN@<0aJ5]0`36XVh2
0<NSK`80a:1/00@0`im[0<:NJP32WVX0`IeY0P30W6P20;fIJ@80_YYZ00D0_i][0<2LK031WFd0`Ie]
0<2MI`020<6MJ@030<:NK033Wfl0a9mb0080aJ1d2035X7<20<BPL080`im_0`32WVh02031WFd0`im[
0<6MJ@2oVfL0_YYV0;fII@2nVVH0_i]W1030W6P[ooooo`00:_ooool80:MlB@<0Z7e:00<0Yga90:Ik
B02VNdP00P2UNTL80:V0C0070:QoB`2WOTX0YWe90:ImB@2WOTX0ZH1<0:^2CP030:b3C`040:^2C02[
PTX0ZX970:Z2A`80ZH54202^Pe080:j5D@0A0;68E02`Qe<0/8MC0;68E02cRUH0]XeI0;V@G02kTUh0
^YMQ0;bHI02nVVH0`9aZ0<:NKP32WG00`Yea0<6LL031WW@00P32WgD30<>PMP<0a:5g2035XWP80<>T
MP<0`j=j0P32XWT30<6QN080_Yie01H0_Ymc0;jOL@2lWFh0^YaZ0;NII`2eUf<0]iEU0;FCH`2cTF40
/8iN0:b:FP2YQeL0YXAD0:F3D`2QOU@0VGI<091]@`2:Icd0RFHl08MT>P24HCL0PEhd0P25H3@00`26
HC@0Qf<c08QT<P0208YV<P0308]X<P2AJc`0TF/l00H0TF/l0P2ELCd209A`?0<0Tflk00D0TVhj099]
>@2BKCT0TVdi09=^>P0209A_>`80UG0l00<0TV`m09=]?P2DKSl00P2DKSl00`2BK3d0T6Xk08mY>P08
09AZ>0@0SVPi102=IcP00`29Hc@0RV@e08YT=@0208]U=P80S6Hg00@0SFLh09=X>`2BIcX0TFHi0P2@
ICP00`2AIST0TVLj09=X>`08099W>PP0T6Xk0P2AIcD2099X=P<0TfTg00<0U6Xh08mX?@2?J3d00P2@
JCh00`2AJSl0TV]0099[@002099[@00509A_>`2CKSX0Tfhj099]>@2@JcL00P2?JSH208iY=@80SfXf
0P2@JcL2095/>003099]>@2FJ3L0UVPg00H0UVPg00<0SfTj091Z>`2BK3d00`2DKSl2099/?@<0TF/l
00<0TV`m09=]?P2CKCh00P2DKSl309E`>`80UW4l0`2GLSd01P2GLcl0UW8n09Ea?@2DL3`0Tflk099^
>P80TFdi202ELD4409Mc?`80V7A00P2IMD40202GMT40V7M209Qi@`2HNT@0UW]409Ak@`2BND40SgU0
202FN4H0402=Ld80S79108Y`?`27KC`0Q6Xi085W=P1oIC@0OV@c07iP;01iGB/0LULX06QA9`1NBRD0
E4@S04ho8P1:?24804Dk8P0803L`800e;Qh0<R`N02hZ7P0/:Qh0:BTO02XZ800Z:b<202HX6P<09bTK
0`0X:Q`0100[;QT0:RdH02/^6@0_<Qd203<f8@0502ha700Y;1L08RDN024T7@0O8Q/00`0M81T0200N
8AX07b8K01TS6`0J8AX06R4I01XP5P0M81D0828E0P0T91P05`0U9QP0:RPK02l/7@0g<Qh0?CHJ04Dj
6P1@@Q/0G4hQ06MF:01bFbT0Mf0Z07MS:01bGb@0KUdW06YI;@1MBRX0BcTS034b900Z:ad08b@F024R
500U9QP0:BXL0080:b`N1`0^:a`01`0]:Q/0:R/M02TZ700Y:Q`0:2TK02LX6P0V9aT00P0U9QP00`0X
:1h09bLM02HV700202DU6`0302LW7@0Y:Al0:RXP0080:2TI02H0:BXL02PX700W9ad092@L028Q700P
7aX092LL02XZ8P0[9R80>B`V04hk;@1J@RP0JdlW08QZ>02KPTT0[iER0<6UO@36ZHT0`jJ80;jQO`2b
UVh0YX]L09moEP2LODh0Wh5;0:^>E02bUEd0YHME08AT?@1XAbP0?3HX03Tf9`0g<bL0<c4U02l_9@0[
;2@0:2/T02LZ8`809BLT0`0T9R<302<U8P0802@V8@0U9b809bPR02XZ8P0^:b80<BdR038^8`0e;b<8
03<_8`05034b900`<B<0<34S02l`8P0^;b400P0];R002@0/;Al0;S0S02l_8`0`<B<0<c4R03@a800g
<Ql0>C8P03Tb7`0203`b9P<0>S0T00@0?38V03hd:00o=BT0@3LV0P0o=RD203he9080?C@S00<0?3<R
03he900n=B@00P0o=RD3040g9P80@CPW00P0A3TU04Dh9@14=b@0ASLT04Pg9@1;>2L0CcXY054l:`@0
D3`T101?>b<204dn9`0404`m9P1;?2D0BS/T04Xk9080BCXS0`1;>b@204`l9@<0CCdV0P1??R@0101@
?bD0DT4W05A3:@1FAB/205M6;0@0I4/]101SBR`205U9;`0605U8;P1JARd0FD<[05Y2:P1I@BT0FT0Y
0P1FAbX00`1EART0E4DX05=49`0205939P0A05529@1@>bH0DC`W058m:01C?RT0DSdX054l9`1?>RD0
CSTT04@f:`13=BX0@3@X03`b9P0k<bH0>S@V03Tf9`0j=bP00P0n>BH0100m>2D0>cHS03Xe8P0h<b02
03Lb7`0303de8P0l=240>c<P0080>c<P00h0?3@Q03de8P0n=R<0?CHV03`e9@0l=2L0>c<X03Xa:00i
<2T0>2lX03P_:P0g<B<0>38T03Tc9@80>S@V00<0>38T03H`8P0e;b40400a;B@0400a:al0<R`P03<]
8@0e;b<0=c4U03Tc9`0j=2P0>cDY04<f9P14=bL0ACPX04Hi:@15>2P0A3LW048e9@10<b<803/a9@80
?3<R00l0?C@S03lf9@10=bH0@3LV03lf9@0m=2<0?3<R03l`7@12<Al0ASDQ04`j901B?RH0EClW05Q0
:01I@BL00P1@@RL0101A@BL0DT4W05919`1D@2L205@n9P<0ACXX00l0A3TW04<h9P12=bD0@SLU044f
901=>B40CSXR04li8@1C>b40F3hS05e29@1QART0ITT[06E=:`1VCR`00P1UCB/03P1TC2X0Hd/Y069:
:01QBBL0J4XX06U;9`1/CRX0KU0Z075D;01cER`0MEP/07II;@1aF2l0L5L^0P1_ERd03P1`Ebh0LUT`
07AK<P1eG3<0MeTc07QJ=01jGCD0OF0d07mS=021IC<0PVLb08=X<`2;KC/0S6hl0`2=Kcd02`2;KC/0
RF/i08QZ>02:L3D0Qfdb08I[=028KCP0S71008a`@@27JSh0PfHl0080Of@i0P1nHcP207eR=`80O64f
01T0P5ha08ES=P2;JC/0SV`l08i]>P2@KcX0U7<n09Qg@@2OP4X0X89<0:63C@2OQ4d0VH18091j@@28
LcX0Pfhe08E[>026K3T0R6`j08a^?02=KC`0SF/k08aZ>P2<J3P0SFdn00<0S6`m0P2;Jc`208YZ>`0<
08Yb=02>MSP0TgTn09Eg@@2EMD80UWA609YhB`2PNdl0VGe;09]oC@2LP4h0VWi<0P2GNdT02`2KOdd0
Wh=A0:>?E02TSU@0YHmE0:V@E`2^U5/0]IQP0;ZKI02lWFH0_JEW0080_ZIZ00`0`JQ`0<F[N039[Wl0
cK690<ncS03A]I00d;N>0=:iT03F_I@0fl:I0=o6W@3RbJ020>C;XP060>_E[P3]ek00lM^d0?GO^03h
h[/0n^Bm0P3kiKh06P3mh;H0o=ne0?[M/`3gf[00mMR^0?;EZ`3`djT0km:X0>o@XP3]cZ00j<VJ0>C6
U03P`Xh0g/2:0=foR@3M`8P0gKZ00=nlPP3P^h@0fkJ10=N_N`3D[7T0f:in0=bbPP3H]XH0dJmo0P3<
ZWX0703:Z7P0bjUi0=RfQP3XaYH0lM:S0??DYP3efJX0n=f`0?WQ]@3jhkT0n^Bk0?_U_03mikh0o>Jm
0?cU^`3jh[H0mmb_0??GZ03`dJ<0k/nP0>?9UP3Yci`0e[b;0;fRL`2gW6l0]IY_0;BHL02lX7P30;VQ
N`80^Z9l0`2kXgd20;fUO`040;jVP02oYh40`:R20<:ZQ080`j^500P0b:Z60<^_RP3B]I<0ekfL0=c3
Y03Ob:T0g/VZ0=k9[080gl^b00@0h<bc0>7=]03QcK@0h/je0P3SckH20>7@]P0<0>3?]@3NcK<0gLbb
0=c;/@3Kb[00f/V_0=g6Y`3J`j@0e[nP0=:kW03>]iP0bkBE0P3:/i@20<:^R@030<B^R@34[8P0a:Z7
0080aJR601<0aJN50<F`Q@30Zh00_:Ek0;fTN`32YWh0ajZ20<ZZP`39ZH80bJn<0<fcTP3B^YP0f<6Q
0=_6Y`3LbJ/0gLV^0=[9[@3OcKD0h<jf0080hm6i00D0iM>k0>OE_@3WeKd0imFm0>KD_0020>[Kb006
0>[Mc03[gll0j^7B0>_SeP3]iMP0k>KJ203cim/01@3`i=@0lNGE0?7Ue@3bi]H0m>SH0080mNWI00<0
m^[J0??Yg@3cjMd01P3cjMd01P3ci]d0lNON0?;Xg`3aj>40l>WS0>oZiP80k^[W0`3ak>H20?;]i`<0
lnkX203ek^H20??^jP80m>o[0P3el>`20?Kak@P0m??_203flnh80?[bk`P0moC_203klNL80?S^hPP0
n^kR203ik><Q0?O]h`P0nNkX103iknD20?S^i080mngS203hk^@@0?G^iPP0mncZ403cl>/80?K_i`P0
nNkX203ekNX80?G^iPP0m>gU203ek^H80?G_h`<0m^oW0P3ek^H30?C]i@P0m^cR2@3gkN<80?O]h@04
0?S[h`3gj^80mn[R0?OZhP80m^WQ0P3ej>080??[gPP0mNWI0`3fjMP20?GXe`<0m>OF2P3gi]@20?KU
d`<0mNCB00<0m>?A0??Rd03ch]001P3ch]0@0?;Qc`80lN7:0P3`h<T20>oOb080k]k7203ahLX40?7O
a`80l=k62P3_gLD01P3`g<<0km_20>oK`P3^f/40kMW00>cH_`80jmNn0P3_ek/30>kF^P<0kMFi00H0
k]Fg0>gD]P3]e;H0k=>e0>_B]03ZdK<20>W@/P80jLZ[0`3XbJX30>O8Z@80ilVW0P3Vb:H00`3UajD0
i<JT0>C6Y0020>?5X`80iLNU00@0i<JT0>?5X`3Ra:80hL>Q0P3P`Z030>73W`80h<:N0`3O`Id20>;1
WP<0hL2M0`3P_i`0103N_IX0gkjK0=nnV`3O_Y/20>2oW080hL2M0`3O_Y/30>2oW080hL2M0P3P_i`2
0=nnV`80g[fJ0P3M_9T30=nnV`<0h;nL0P3Q`9d20>;1WP80hL2M0P3P_i`20=nnV`P0hL2M00@0gkjK
0=jmVP3N_IX0g[fJ0P3M_9T20=bkV080fkZG0`3L^iP00`3K^YL0fKRE0=RgU0030=biT`D0fkRB0P3G
]i00103H^940fKVB0=ZjT`3J^Y<20=^kU080gKfF00@0g;bE0=^kU03J^Y<0fKVB0P3H^9430=ViTP80
f;RA1@3G]i020=JfS`<0eKF>00/0e;B=0=>_R`3C[h/0dZn90=:_Q`3A[X@0dJn20=2^P@3@[X00d:f5
0=6^QP030=:_Q`030=2]Q@3>Zh<0cJZ200@0c:Yl1@3=Zgd20<j[P@060<fZP03<ZGl0bjQn0<ZWO@39
YW`0b:Ek0`3<ZW`20<^YN`<0bZQj0P37Xfl30<JRKP<0aJ5]0P34X6`01033Wf/0`YiZ0<:NJP31WFT2
0<2LJ0060;bHJ02mVFT0_YYZ0;nKJ`30W6`0`Ie]0P32WVh02030WFD0`IiV0<6MJ@32WV`0a9mb0<FP
M035X7H0aZ1i2035X7<30<BPL080`im_0`32WVh02033Wf/0`IeY0;nKI`2nVVH0_IUU0;jJIP2oVfL0
`9aX0`31WFT[ooooo`00:_ooool80:IkB0<0Z7e:00<0Yga90:IkB02UNTL00P2UNTL80:V0C080Ygi:
0P2VODT00`2WOTX0ZH1<0:^2CP030:b3C`060:^2C02[PTX0ZX970:Z2A@2YPD@0ZH53202^Pe080:j5
D@0@0;68E02`Qe<0/8MC0;27D`2bRED0]HaH0;R?F`2jTEd0^IIP0;^GH`2mVFD0`9aZ0<6MK@31W6l0
`Ia`0<2KK`T0`Iid2033X7H80<:SM0<0`J5h0P30X7L30;nOMP0D0;^KLP2lWG40_9ea0;^LKP2jVf`0
]iUW0;BFHP2cUF40]Y9R0;B@H02bSUh0[XYJ0:^7E`2WPe<0YH5A0:=oC`2NNe40UW=908eZ@027I3X2
08IS>@0:08AQ=`22GcD0Q5lc08EP=026HC@0Qf<c08QT<P29IC40RVHb08YW<@80TV`m102AJc`2091Z
>`80UG4m0P2DL3`409=_>`<0TVdi00<0Tfhj09A_>`2EL3`00P2EL3`00`2BK3d0Tfdn09A^?`0209A^
?`03099/?@2@JS/0SfTj00P0U6Xh0P2<ISL308eW>0<0SVPi0P29Hc@208YT=@0708]U=P2<ISL0S6Hg
08eW>02CJ3/0TVLj095V>@02091U>003095V>@2BIcX0TfPk00P0TVLj202@JS/2099X=P80TfTg0`2D
JSP00`2EJcT0T6Tn091Y?P02095Z?`05099[@02CK440Tfa109=/@@2DKD800P2DKc/0102CKSX0TVdi
091[=`2?JSH408iY=@80SfXf00@0T6/g095/>02AK3P0TVdi202FJ3L02@2?JC`0T6Xm099/?`2DKT40
UFm209A^@@2BK3l0TF/n091Z?@02095[?P03099/?`2CKD00Tfe00080U6i10`2EL3/209Ia?0<0Ug8m
00H0Ug<o09Ib?P2FLSh0U70l09=_>`2BKSX2095]>@80UW92102ELD4209A`@00409Ib?P2GLcl0Ug<o
09Mc?`80V7A00P2IMD40202FMD00UgQ209Qi@`2HNT@0UW]409Ak@`2?ND00SWPo202FN4H0402<LT40
Rg5008Y`?`27KC`0Q6Xi085W=P1oIC@0OV@c07eO:`1hG2X0LULX06QA9`1NBRD0E4@S04dn8@1:?243
04Dk8P80AS`S0`15>b801@0g<200=BhN038/7P0^:Qh0;2XN0080:RXP00<0:R/S02HX6P0V:1X00`0W
:A/302PZ700402/^6@0Z;AP0:bhI02lb7@80<cHQ00D0;S4L02T/5`0R9Ah08B@M01lR6`0301dP6@08
01hQ6P0O8Q/06B<K01XQ6P0J8AT06R0F01dP5@0P8QD202@T600G02DV600Z:1/0;b`M03Ha7@0l=AT0
@cPH04i06@1JC1l0I5<U071I9`1eGRP0MF4V06mL8@1/FbD0J5L/05]8:P19=b40<34S02X[7@0S91H0
8B8D02DV600Y:Q`00P0[;1h302dZ6`<0;R/L0P0_;1d202TZ7080:2TK00H09bPJ02HW6@0U9QP09BHH
02PX7P0W9ad302DU6`0302LW7@0Y:Al0:RXP0080:2TI02H0:BXL02PX700W9ad092@L028Q700P7aX0
9BLL02/[8`0^9R<0>B`V04ll;P1L@RT0KE0X08U[>@2MQ4/0/9IU0<>WP037ZX`0a:N90;jQO`2bUVh0
YHYK09inE@2KO4d0Wh5;0:^>E02bUEd0YHME08AT?@1WARL0?3HX03Tf9`0g<bL0<c4U02h^900[;2@0
:2/T02HY8P809BLT0`0T9R<302<U8P0802<U800T9R409RLQ02TY8@0]:R40<2`Q034]8P0d;R8803<_
8`0H038c9@0a<R@0<34S02l`8P0^;b40;BhP02`]7`0[;1h0;S0S02l_8`0`<B<0<c4R03@a800g<Ql0
>C8P03Tb7`0m<bL0?38V03X`900i;b<0>S0T03`b9P0n=2P0?cDY0P10=bH203lf9@0403he900m=2<0
?C@S03`c8P@0?C@S0P0n=B@303lf9@0804@i9@14=b@0A3LT04Hg9018=bD0BcPW050k:P1A?2/304lk
8`D0CSXR0P1=?RL00`1<?BH0Bc`U04Xk900204Tj8`0404Pi8P1;>b@0Bc/T04/k90<0C3`U0P1=?BH0
201>?B<0CchT050o9@1B@BL0E4<Y05I5:`1GAR`0F4L]1@1UC2h306A;;@80FTX`00H0FDP^05Y6;@1I
@b/0FD4Y05Q0:01H?RL205M8:@0405I7:01EARL0E4DV05A59P80Dd@U00<0D3/V054l9`1B?BP00P1C
?RT02`1B?BP0D3/V04lj9@13=BX0@S@Y040d:00l<RH0>c<V03/e9`0k>2T0?3TZ0080@3/W00@0?STU
03`g8`0j=B40>3<O0P0f<Ad00`0n=R<0?3@Q03Xb7`0203P`7@0303Xb7`0m=B80?cLT0080?CHV00<0
?3@W03/c:00j<BP00P0i<2T00`0h;bX0>38T03Tc9@0303Xd9P0303Pb900g<B<0=BlQ0100<BdT0100
;bTM030Z7P0b;200=BlS03La9@0j=2P0?3HZ03dg:`14=bH0ASTX04Lj:@18>bX0AcXY04Hi:013=RD0
@SDT200l<RH203`c8P0?03dd8`0o=RD0@3LV040g9P0o=RD0?C@S03`c8P0m;1X0@2lK04Hd801>>B@0
E3hW05Q2:P1K@bT0G4@Z0080D48W00@0DD4W05919`1B@BL0DclV0P1D?RH304Hk:@80ACXX0100A3TW
04<h9P12=bD0CCTQ04li8@1@>R80E3`R05To901OA2L0ITT[06U<;P1XD2h0Idl]06E=:`1TC2X0Hd/Y
0P1RBRP02P1SBbT0JT`Z06Y<:01/CRX0KU0Z075D;01dEbd0MeX^07UL<01eGS@207AM<`0=07=L<P1d
GC<0MUle07QQ=`1jHcT0NE/g07UK=@1iG3@0Nehb07eQ<P1oHc40PVLb08=X<@0208]]>`<0S6hl00`0
RV`j08QZ>026J3H0R6ha08I/<@25Jc80R6dh08a`@02<L440R6]108=V?01mHSL207aQ=P0N07]P=@1j
Gc@0NEhc07UN<`1hGC80PE``08MR=P2?JSd0Tflo09A`?P2DL3`0Ug<o09Yg@@2LOTP0WGm909b1BP2J
PDT0Tge408]f?@23KSD0OFX`08AZ=`25JcP0R6`j08a^?02=KC`0SF/k08]Y>@2<J3P0SVho0`2=KCh2
08a/?@80Rf/l00`0SGDe091h>P2ENd00UWU109Ee@P2FM4H0VGM:09mjD02IOD/0Vgm=09b0CP2IOD/2
09EiA`0;09UmB`2NPU00XXiC0:>=D`2TSU@0ZI1G0:fCFP2dUel0^IYS0;^LI@2oYfL00P31ZF/02`34
Zg80b:ik0<fbQ@3A]Hd0e;RC0=JiU`3D_I@0el2G0=g6W@3Sc:<0im2W00<0j]>Z00@0kMZb0?3M]@3c
h;P0mnBl0P3ii[h20?SU_@060?kQ]`3mh;H0nmjd0?WL/P3gf[00mMR^0P3ceZ`04P3_d:80kLjP0>S9
VP3TaY@0h<:>0=k0RP3M_hT0gL280=FcMP3G]GP0fKEk0=J_N03AZ7@0cjEc0=BXM`3H[7d0e;:20<f[
N`80bZQh0280b:If0<ZXN03H]XH0j/RH0??DY@3eeZP0mm^/0?[O/P3khkL0o>Fk0?cV_@3mikh0onW0
0?kX_`3mi[`0n^:f0?OL[`3cejP0l=6S0>g>W`3Rb9D0jLnL0=NmS02mXW<0]ia_0;BIKP2dV700_J5i
0;NON`2hX7`0^J5m0;ZROP2kXgl0_:B00P2mYH401P2nYX00_jN10<2XPP31ZH<0`ZZ40<>[Q@80a:b6
00P0b:Z60<^_RP3B]I<0f;jM0=c3Y03Ob:T0g/VZ0=k9[080gl^b00@0h<bc0>7=]03QcK@0h/je0P3S
ckH20>7@]P0>0>3?]@3NcK<0gLbb0=c;/@3Kb[00f/V_0=g6Y`3J`j@0e[nP0=6jV`3>]iP0bkBE0<Zc
U039/Y<20<:^R@030<>]R034[8P0a:Z70080aJR601<0aZR60<F`Q@30Zh00^jAj0;bSNP31YGd0aZV1
0<VYPP38Z840b:j;0<bbT@3A^IL0el2P0=[5YP3Kb:X0g<R]0=W8[03OcKD0h<jf0080hm6i00<0iM>k
0>OE_@3WeKd00P3Ve;`20>[Kb0060>[Mc03[gll0j^7B0>_SeP3]iMP0k>KJ203cim/20?3Te0040?7U
e@3bi]H0m>SH0?GYf@80m^[J203cjMd01P3ci]d0lNON0?;Xg`3aj>40l>WS0>oZiP80k^[W0`3ak>H2
0?;]i`<0lnkX203ek^H20??^jP80m>o[0P3el>`20?Kak@P0loC_203flnh80?[bk`P0moC_203klNL8
0?S^hPP0n^kR203ik><Q0?O]h`P0n^oY00@0n_3V0?W_i@3iknD0nNoU0P3hk^@20?O]h`P0n>kT403e
k^H80?O/jQ00lo3[203fknL80?[_j@P0mNgZ203ek^H80??/i0P0mNkV203ekn<30?K_i`<0mNkV0P3d
kND80?K/hPT0mngS203gkN420?S[h`80mn[R0`3fjN400`3ej>00lngQ0??]h@060??]h@P0mNWI0`3f
jMP30?GXe`80m>OF2P3gi]@20?KUd`@0mNCB203ch]0@0?;Qc`80lN7:0P3`h<T20>oOb080k]k7203a
hLX0103bh<P0lMo70?7Oa`3aglL20?3NaPX0kmg50P3`g<<0103_fl80k][10>gI`03/f;l20>_G_P<0
kmNk0P3^e[X30>gE^@060>kE]`3]e;H0kMBf0>cC]@3[d[@0j]6c0P3Yd;820>W:Z`<0j<VZ0`3Wb:T0
1@3XbZP0ilVW0>O9Y`3Vb:H0iLNU0080i<JT0P3SaJ<01P3Vb:H0iLNU0>C6Y03SaJ<0h/BR0>73X@80
h<:P0`3Q`il30>32WP80gl6M0`3R`Ih20>70W@<0h;nL103O_Y/20>2oW080hL2M0`3O_Y/30>2oW080
hL2M0P3P_i`20=nnV`80g[fJ0P3M_9T30=nnV`<0h;nL0P3Q`9d20>?2W`80h/6N0`3Q`9d00`3P_i`0
hL2M0>70W@060>70W@@0g[fJ0P3M_9T20=bkV0080=VhU@3K^YL0gKbI0=jmVP3M_9T0fkZG0=RgU03G
]Y<40=biT`@0fkRB0P3G]i000`3H^940fKVB0=ZjT`020=^kU0070=blU@3N_YL0gKfF0=blU@3K^i@0
f[ZC0=ViTP020=RhT@<0fKVB0`3H^9440=NgT080e[J?103E]Hh20=>_R`080=:_R@3B[hL0dJj40=6_
PP3@[X40d:j00=2]Q@3A[XH30=:_Q`030=2]Q@3>Zh<0cJZ200@0c:Yl1@3=Zgd20<j[P@030<fZP03<
ZGl0bjQn0080bJIl00@0b:Ek0<bZO03<ZW`0c:Yl0P3;ZG/30<ZXNP80b:A`00<0aj=_0<JRKP35XFd0
0P34X6`01033Wf/0a:1/0<BPK033Wf/20<:NJP0A0<6MJ@30W6P0`9aX0;bHJ02mVFT0_YYZ0;nKJ`30
W6`0`Ie]0<:NKP33Wfl0`9eS0<6NIP31WVP0`im]0<BOLP35X7@00P36X7T80<FPL`<0a:1`0`33Wfl2
0<:NKP080<>OJ`31WFT0_i]W0;jJIP2mVFD0_YYV0;nKI`30W6P30<6MJB_ooooo000Zooooo`80ZWm<
00<0ZGi;0:QmBP2WO4T00P2VNdP01P2UNTL0Y7]70:AkA`2TNdL0YGa80:ImB@<0Ygi:0P2YP4`40:Qo
B`80Ygi:0P2XOdL20:V0B0@0ZX59202/Pdl30:j5D@80[HA@0`2/Pdl20:j5D@@0[HA@0P2/Pdl80:n6
D0050;F;F@2gSE/0^i5O0;jDHP30UV@00P31UfD01030UV@0_IMX0;fGJ02nV6T30;nIJP030<2JJ`31
Vf`0`I]/00P0`Ia`2032WVh02031X7<0`9mb0;nNL@2mW6l0^iY]0;VHJ`2hUfX0]iIY0P2iUFD20;ZF
IP0A0;RDI02fTV80/hmO0;:>GP2aSEd0/8aL0:j9G02ZQET0Y7mE09egD02GLD`0U6i908]X@02:Icl0
Qf@l08AQ>@22GcL00`21GSH2085Q<P0408=Q<`26HC@0QV4d08QR=@80Rf8f00D0SVPi08mY>P2?JCX0
SfTj091Z>`03095[?00409Y`?P2IKcd0VFlm09Q^?080Ufdk0P2FK3X:09M]>`80UV`j00/0UF/i09AZ
>02DJSP0TfTg095]<`2BKS@0U6lh09E`>`2DKc/0TV`k091Z>@0408mY>PL0T6Xk0P2?JCX208iX>@80
SFLh00H0TVTe099X=P2BJ3H0TVPh099W>P2BIc`2099W?@0308aV=`2>J3T0T6Xk0080TV`m00<0TF/l
091Z>`2?JCX04P2BIcX00`2CJ3/0U6Tl09AY?00209EZ?@80UV/n0P2FLCd209E`?0@0U6lk0P2>JC@2
08mZ=@07091[=P2AK3L0TVdh099]>02BK3d0TF/l08mY>P0208iX>@0308mY>P2AJc`0TV`m00P0Tflk
00<0U70l09=_>`2BKSX00P2BKSX00`2DL3`0UW8n09Mc?`0809Y^?@P0U70l0P2ELCd309Ib?P<0Ug<o
102HM4@209UeA@80VWI60`2GMT4209Qg@P<0VGQ3102FN4H409MiA`0@091a@P2?L440SVm008]/?@28
JCX0QVLh08=T=@22Hc@0Of0a07]O<01eFRl0K5@^069>:`1IB2X0Dd<Y0512:0<0AS`S0`15>b8204@j
8@0803D_7`0b;ah0<2dN02h/7`0Z:Qh09bTN02DX7@0T9ah202DW6@0302HX6P0W:A/0:2XL0080:B/M
00T0:R`N02P_7@0U;1X09BTH02P[6P0]<1l0<34Q030^7`0]:a`00P0P8a`301lR6`<07R4J0`0O8Q/2
020S70@08B@M01D0:RPL02/Y700b;1`0>S8M04@h7P1>@B40EdLU05];9`1YEC80LEhf07=S<P1[GRT0
IeXV06=F:P1IC2X0CClT030`9P0Z:R0092@J02<S6@0V9Q`00P0Y:Al00`0X:1h0<RXO038Z7`02034Y
7P@0<2PM00P0;2dO02d^800];R00;2dO02X[7@0X:A/09BHH02<T5PP09bLM02P0:B/M02PZ7@0W:A`0
9RPM02@U7@0R8ad08B8M020Q700Q8ah08b@N02hZ7P0k<b00ASHL05Dn701]E2`0QVTo0:28BP2cVV80
`ZMj0<BXP`2oXX00^imh0;>HJ@2YSe`0VHAE09^1CP2SPTd0/haE0;R@G@2SP5H0Nehn05Q0900i=bX0
>3HZ03<c9`0_<BH0;2dU02P[900S:2808RLQ200U9b@202XY9@0902/Z9@0];BD0;RhT02l_8`0`<2@0
<C8T034a9`0`<2H0;blU0080;RhT00T0;blU030`9P0a<BL0=S8V03Da9@0d<2@0<blS038^8P0a;B40
0P0`;2001P0d;BL0=2dU03D^9P0e;R@0=S0T03La8`80>38R00T0=bdQ03H/800e:al0=R`P03L]8@0j
<2@0?C<W03le:@0k<BD01@0j<2@203T_8`80@SDU0P11=2@5040c8`0304Ld9@18=BH0BSLX00<0C3TZ
0P1:=bP404dk9@80CS`V00D0CcdW050n:01C@b`0DD4Z04lo:00304dm9P80CShW00H0Cc`]04hk;01<
>BX0BSLX04Tf9`1:=bP204/h:@0H054l9`1B?BP0DclW05E1:01G@bP0FDHX05]8:01LBBT0Fdh/05m@
;`1SDc80J5<d06]B=01YCS40J4T]06I7:`1PCBl0Gd`^05i;;@1LBB/0FTLY05Q59`1F@bD0ED8T0P1I
AB`205Q4:`80Ed<Z0P1F@RT02`1@?bD0CclU04lo9P1=?RL0BclY04Xo:`18@2/0B40]04@i9`12=bD0
?c@R0080?C8P00/0?S<Q040e8`12=bD0>bhV03/^9@0l;bH0?C4U03hb900o<b<0@3DS044f900203Lc
9`80=S8V0P0e<BD203@`90@0>C<U100h<R@00`0i;b<0>S0T03/a9@0203/a9@0303T_8`0g;B40=R`P
00@0<BdQ0P0`;20202l[7`0602hY9@0^:B<0;bXT030/8`0a;B80<RhR0P0c<2404`0i<RP0=RhS03<[
800g;B40?c<U04<f9P13<b<0@30P040c8`11=2@0ASHW04hm;@1C@S00DT0/04Xe8P11;1L0@CHR048g
8`13>2@00P14>BD00`12=b<0@3DQ03hc7`0903hb8P0803d`9`0o<BH0@SDU04Pi9P1>?RD0ED@V05a9
:01OCBT405I6;00505A4:P1A@BL0CclU04dm8`13>2H00`12=bD2044f9080@3DS00P0ASPN04Ph7P1<
>ad0DchO05Y2801QAB00ITPR06Y:8`80IddX00<0IddZ06M=;01VBbd00P1VBbh04@1VBc00JTd[06U=
:01XC2L0JDdV06]?9`1^DbP0LULZ07AI;020G2`0OE/[07aJ;01jFB`0NEX^07QK<@1hG3@0NEde0080
Oedg00H0Oehe081O=022HC@0Q6@e08IV=`28J3L207iV>P0I085V>`23IS`0QFDl08MV?@28Ich0RFHn
08A_=P25L3L0QG4l08Ab@022LT40Og5407e^A@1kKT@0NVI107QT?`1eGcX0Le/g07=I=P1fFCL0NE`j
07]M>`1jGR`0Of<a08AX=P0208M[>@0Q08U]>`2>LT00TgM509Ad@`2CLd80T79008]_?@28KS/0Pf`h
085Z=P1oJSD0O60`089V=P28K3X0Rg0k08]`>@2;LCP0SG<j095g?02LLCh0V6lk095/=`2:JC<0QV`c
08A`=@24M3P0QWPk09Ie@02GMT40V7M209Uh@`2JND@0VgY50080W7]600@0XH5@0:20C`2NOTd0W7a;
0P2KNdX02`2LO4/0WGe<0:F8D02VRE40Z8]C0:^>EP2^TET0/IAL0;BGG`2eV600]j1f0080^J9h01H0
_JIl0<:[P@37/8H0c;F;0=2iS`3B^i40f<>H0=_6V`3PbZ40i]2Y0>_E/03_f;H0l=Vg0?7J^P3ki;/0
n^>j0?WR^@3hhKP0nN:i0?[S^P3mi[d0o^Nn0`3lgkD04`3kg[@0n=^a0?GH[P3beJ/0l=>Y0?7@W@3`
ci`0kLbI0>W8U@3VaI80h/6>0=nnR`3N_HX0e[F00=BcOP3A/7/0c:]f0<VXL`36YG000P35Y6l04039
ZF`0ajMZ0<RXK`3:ZG<0b:Md0<VWN@3I]hX0k<VO0?OG[P3lg;<0on:h0?oU^P3miKT0o>Fi0?kY_03o
k;l20?oZ`@0>0?oY_`3ni[X0n]nb0?CHZ@3_d:80j/^L0>S8U@3S`i00dkF30;fQL@2cV6T0]9a^0;NO
L@2cW7030;^TNP<0_:Ek0P2mYW`0402nYX00_jN10<2XPP31ZH<0`j^50<B/QP35[HL0aZj80<N]R03;
/H`0dKVE0=O0WP3KajH0g<VY0=g:ZP3KbZ`20=g=]0030=k>]@3OckH0h=2g0080hM6h0140h]:i0=o@
^`3Od;/0h=2i0>7?]`3Oc[@0g/Z_0=c7[03JaJP0f/>T0=S1XP3F_j00d[^L0<jgV03:/i@0b;6B0<J_
T0020<NZRP080<JYQ`36ZXD0aJV20<BXP033Ygl0`jQm0<JYQ`31Y8820;bOO@090<2SP@34YhD0aJR6
0<BWQ@36/8T0b[B=0=2jU@3F_id0flBT0080gLJW00<0g<BX0=g;/`3OcKD00P3Rd;P00`3Udk/0imFm
0>OE_@020>OE_@090>SIaP3Yf/L0j=_:0>WMc@3Yh=40j^;E0>_SeP3[iMT0k^WF0080knSF00<0l>OF
0?;VeP3ci]H00P3eiMH20?;VfP030??Wf`3dj=`0mNWM0080m^[N00<0mn_O0?G[g`3ejml00P3dj]h2
0??Yg@80l^SL00H0m>SL0?;Xg03bj=h0lNSO0?3Yh@3^jN<20>gZi@<0lNcV0P3bkNL30??^j0P0mNkV
203gknd30?;ckP80loC_0`3dmO080?Wak`P0n_?[00@0oOK^0?cek@3lmNd0o?G]0P3km>`20?[cj`P0
no3/0`3kk^H20?[]i@<0nNcT203jk]h80?W]h@P0nNcT203ikN490?O]h@P0mngS403hk^@80?S]i`P0
mNkV203ek^P80?K_i`P0m^oY203gl>X@0?O`j300mNkV203gkN<A0?K/hP<0nNgQ0P3hk>030?O[g`P0
mn_K203fj]X@0?GXe`P0m^GC0P3fiMD20?GTe080m>?C0P3ch]8@0??Rd100ln7;0P3bh<P20?7Oa`80
l=k60P3_gLD80>oNa0<0k][10P3]fL030>cH_`<0kmNk0P3^e[X30>gE^@080>cB^@3]dkX0kM>h0>kE
]`3]e;D0jm>a0>S@[P3Wcj/30>W<ZP80j<^Y0`3WbZP20>S;Z`030>O:ZP3VbJT0iLRX0080i<NW0P3S
aZH20>C6Y080hlFS103Ra:830>;1X080hL2O0`3P_ih20>?6W0040>74VP3P`iT0g/6G0=g0UP80fkjD
0P3O_Yl00`3O_Yd0gkjK0=noV@020=noV0030=noUP3O_Y/0gkjK0080gkjK0P3P_i`20>70W@P0h;nL
0`3O_Y/30>2oW0X0hL2M0`3S`Yl20>;1WP<0hL2M00@0h;nL0=nnV`3O_Y/0gkjK0P3N_IX20=flV@80
g;^H0`3K^YL30=ZiUPP0fk^D403I^9D80=NgT080fkRB00@0f[NA0=VfT03H]Hl0f;F?0P3G]8h0103F
/hT0e;670=:_Q@3@[H<20<n/PP030=2]P`3A[X@0dJj40080dJj40`3@[H<20<n/PPT0cZan0`3;Z7h2
0<ZWO@<0bJIl0`38XW/00`39Xg`0bZAm0<^UOP020<^UOP030<VUM@38Y7@0aZ9b00<0a:1`00H0aJ5a
0<JRLP35Wg00aIm`0<BNK`33WFh20<:LK@80`I]/202mVFD01P30WFL0`9aX0<6MJ@32WV`0`Yi^0<>N
L@80a9mc2034X7001031WFd0`Yi^0<:NKP33Wfl20<BPL080aJ5a0P32WVX20<6MJ@@0`9aX0`2nVVH[
ooooo`00:_ooool0102ZOd`0ZGi;0:UnB`2XODX20:MlB@80YW]80P2TNdL20:ElB0040:ImB@2WOTX0
Ygi:0:MnBPP0Z7m;0P2XOdL20:V0B0<0ZX5900<0Zh9:0:b3C`2/Pdl01P2/Pdl@0:f4D0P0[hI@00D0
]H]I0;N=F`2jT5h0_I=Q0;nEH`020<2FI0050;nEH`2kUFH0_9IW0;bFI`2mUfP00P2nV6T00`2oVFX0
`9Y[0<2JJ`080;nJKPP0`9a/0P2mW6l0102lVfh0^iY]0;VHJ`2hUfX20;NFJ@80]I5Q00D0]Y9R0;FA
H@2cSel0/HeM0:j:FP020:f9F@0;0:b8F02YQ5L0YH1D09mjD02HLT/0Tfe808mYA029ISh0R6Dm08ER
>P22GcL01020GCD2085Q<P0408=Q<`26HC@0QV4d08QR=@80Rf8f0P2=IcP0102>J3T0SfTj091Z>`2A
Jc`2099/?@80VFlm0P2HKS`209M]>`80UV`j2P2GKC/209I/>P0;09E[>@2DJSP0U6Xh09AZ>02AKC<0
TVdf09A_>02DKcX0U6lk099/>`2@JS/01@2?JCX6091Z>`80SfTj0P2>J3T208eW>006099Y=@2BJ3H0
TVPf099X>02BIcX0TVLl0P2BIcd0202<ISL0SVPi091Z>`2AJc`0TV`m095[?02@JS/0SfTj202BIcX;
09=X>`0409AY?02EJSd0UFXm09EZ?@80UV/n0P2FLCd209E`?0<0U6lk00@0Tfhj08mZ=P2?JSH0SfXf
0P2@JcL3095/>003099/?@2AJc`0SfTj0080SVPi00<0SfTj095[?02BK3d0202CKc/00`2DL3`0Tflk
099^>P02099^>P0309A`?02FLSh0Ug<o00P0VFlm202DL3`809Ib?P0409Mc@`2HM4@0V7A409QdA080
VGE50P2JMTH309Mf@@<0V7M20P2IN4<309EgA@D0UWQ60100T75208m`@@2=KSl0Rf`m08QY>P25ISL0
Pf@e089S=01nGc00NUh_07AI;P1[Dbd0HDdZ05Q7:@1B@RP0CT0V0`16?2<204Dk8P<0A3XQ00P0=2hN
038_7P0`;Ah0;B/N02XZ7P0W:Ah092LL02@W7P809BLI00@09RPJ02LY6`0X:Q`0:2XL0P0Y:ad0200X
;ad09RdK02HZ6@0Y;1/0;S4P034b8P0a;b00;R`M0P0P8a`301lR6`<07R4J0`0O8Q/3020S70<08B@M
01D0:2PL02/Y700`;A`0>38L048h7@1=?b80E4DT05U99`1TD2d0K5Ta06iN;@1WFRD0HeHR05mB9P1F
BBL0BS`Q030`9P0Z:R0092@J02<S6@0V9Q`00P0Y:Al00`0X:1h0<RXO038Z7`02034Y7P<0<2PM00<0
;bLL02//7P0/;Al00P0/;Al0100[;1h0:2TK02HW6@0T9AL802LW7@0X02T[7@0X:Qd09bTL02DW700T
9Ad08R<M024R7@0P8A`08B<N02<T7P0^:Qh0>c<P04Lg7@1F?ad0KUD]08MZ@02OQdT0/IQP0<2UN032
YX40_j:00;^ON02cV6T0ZHmL09V4E@2JP4d0Xh9=0;><E@2hT5d0Xh1F07YM?@1H@2@0>CLZ03Pf:P0c
<bL0;c4V02`]9@0X:b@08bPR028W8@P09BLT0P0Y:2@02@0[:RD0;2`T02h^900_;b<0<C4U034b900a
<BL0<30V02l_9@0202h^900302l_9@0`<2H0<C4W0080=C4U00@0=30T03<_8`0b;R80<BdQ0P0`;200
1P0c;2H0=2dU03@]9@0e;R@0=S0T03La8`80>38R00P0>BlS03P^8P0h;R80=bdQ03P^8P0j<2@0?C<W
03hd:0H0>c4U0P0j<2@204<f9P<0@SDU1011=2@02016=BD0AcHV04Th:01:>BT0BcXZ04Xi:@19>2P0
B3LW101=>bD204hl9P80CcdW00<0DD4Z04lo:01>?RL00`1<?2D01@1>?RL0CclX04ll:`1>>bX0C3TX
00<0BSLV00P0BcPW04`i:01A?2L0DSdX05<o9`1E@BP0Ed<X05U6:080FdPX0100G4d/05i?;P1TDC40
Ie8c06YA<`1XCC00IdT]06I7:`1QCS00H4d_05m<;P1MBR`0FTLY05U6:01GA2H0ET<U0P1IAB`205Q4
:`80Ed<Z0P1F@RT0201@?bD0CclU04lo9P1=?RL0BclY04Xo:`18@2/0Acl/0P13>2H00`11=R@0@3DS
040e8`02040e8`03044f9010<bX0?c8Y0080?c<W00@0?S8T03hb8P0m<R00?C8P0P0g=2D603Hc90@0
>C<U100h<R@00`0i;b<0>S0T03/a9@0203/a9@0403T_8`0g;B40=R`P038^8P<0<BdQ0P0`;20202l[
7`0D02dX8P0^:B<0;b/R030/8@0b;R80<c0Q03@a8P0e<R40>C<W03P`9@0g;b80?38V04@h:P18>b/0
B3PX04De9@18>2P0AcLW04Pg9@1<>bT2054o:`0504hi9018<ah0@CHR048g8`13>2@00P14>BD00`12
=b<0@3DQ03ld800204<g9`<0@SHV00d0@CDU040d9010=2@0@3@T03lb:@11<bP0@cHV04Pi9P1=?B@0
E4<W05Y79`1MBRT0EDD[0080ETH/00D0EDD[05A4:P1A@BL0CclU04dm8`04048g9@80@CHT0P10=B<0
2018>R00Bc/Q04ln8P1F@B80GDDS06A88`1XBR@0K4`U0P1WCBP01`1WCBX0IT`[06I;;@1VBbh0IDX]
06E:;`1XBbT00P1XC2L05P1YCBH0K50X06mD:@1cF2/0MEX]07iJ:P1mFb/0OE/]07aK;P1kG300NE`b
07QL=01gFc<0OE/f07eK=@1lFS@0OE`c07mN<`21H3<0Q6@e08EU=P1lI3H207mT=`05085T>025ISX0
QfHk08QU>`29IS`00P24KcH0;P24L3/0Q70n081^?P1mK400NFY107MX?`1hICd0MF8j07AN=`1bFS@0
LeTd07IJ=@1iGCP0O5hj07aP;P20I380QFTg08IZ>025JCL0QVXh08Y^?02>LT00SVhm08e]?02;KC/0
Qf/i08AZ=`20JCD0OfPd07eX<`1nHS80Q6Ph08U]>`2;Kcd0RFhi08U^=`2;LCP0SW@k09U^>`2FKCT0
T6/f08a[=@28KSD0QW0f08Md>@26MSX209Mf@@0409Qg@P2IN4<0VWU409]jA@80W7]600<0X81?09mo
CP2MOD`00`2KNdX02`2LO4/0WGe<0:>6CP2TQdl0YhYB0:V<E02/SeL0[i9J0;6DG02cUUh0]9a`0080
]imc01L0^j=g0<2XO036[X80bk>70<ngR`3A^Hd0e/6D0=[5VP3ObYl0iLnV0>[D[@3^f;<0l=Vg0?7J
^03hgkL0mmjf0?GL]03dfk<0mMbd0?KM]@3hgkL0nN2h0?[M/`020?_N]00C0?[M/`3hfk40mMR^0?;E
Z`3`djT0lm:O0?7@W@3^cIX0j/VF0>G4T@3Q`8d0g[f:0=bkR03F]H00e;=n0=2_NP3<ZgH0bJQc0<NV
L@020<JUL00@0<ZZK@37YfX0b:Q_0<ZYL`38Yg@0bJMi0=VgRP3/bIl0m=B[0?WI/03mh;H0o^>h0?_S
]`3ih[H0nnJi0?kY_080on[100h0onVo0?kV^P3jgk80m=RY0>k?X@3Zbi`0ilND0>?3T03C]H<0_J5a
0;>HJ@2dW6h0]ima0;BML@<0^jAj0P2lYG/30;fVO080_jN100/0`:R20<6YP`33ZhD0a:b60<F]Q`36
[XP0b:j90<bbS@3A^ID0el2N0=_7YP020=g:ZP070=_:[03McK@0g/je0=k>]@3OckH0h=2g0>7A^002
0>;B^@80gm2k01P0h=2i0>7?]`3Oc[@0g/Z_0=c7[03JaJP0f/>T0=S1XP3F_j00d[^L0<jgV03:/i@0
b;6B0<J_T038Zh/0ajZ:0<NZR036ZXD0aJV20<BXP033Ygl0`jQm0<FYQ030Y7l20;^ONP090;nSOP34
Z8<0aJV40<BXP`36/8T0b[B=0=2jU@3F_id0flBT0080gLJW00<0g<BX0=g;/`3OcKD00P3Rd;P00`3U
dk/0imFm0>OE_@020>OE_@090>SIaP3Yf/L0j=_:0>WMc@3Yh=40j^;E0>_SeP3[iMT0k^WF0080knSF
00<0l>OF0?;VeP3ci]H00P3eiMH20?;VfP030??Wf`3dj=`0mNWM0080m^[N00<0mn_O0?G[g`3ejml0
0P3dj]h20??Yg@80l^SL00H0m>SL0?;Xg03bj=h0lNSO0?3Yh@3^jN<20>gZi@<0lNcV0P3bkNL30??^
j0P0mNkV203gknd30??bkP<0m??_0P3em?080?Wak`P0n_?[0`3lmNd20?_dk0<0n_?[203kl>X20?c_
i`80nnkV0`3jkND00`3ik>@0n^kN0?[^gP060?[^gPP0nNgQ203ik>@80?W]h@T0mngQ203gkN<@0?S^
i0P0n>gW203ek^H80?G^j0P0m^oW203fknT80?O`jQ00mo3X<03ek^H80?O]ha40m^cR0P3ikN430?S/
h0<0mn_O203gjm/80?KZfQ00mNSG203fiM<20?KUe@80mNCD0P3dhm<20??RdQ00ln;@403chL/20?;P
b080lMo70P3`g/H20>oMa@P0kmk40`3_fl820>kJ`@<0kMW00`3_ek/20>kF^P<0kMFi00P0k=:i0>gC
^P3]dkP0k]Fg0>gD]@3[dk40j=2^0>O?Z`<0jLbZ0P3XbjT30>O:Z080j<^[00<0ilZZ0>K9Z@3Ub:P0
0P3TajL20>?6YP80i<JT0P3SaJ<30>;4XP030>73X@3Q`9l0hL2O00H0hL2O00P0hlJN0>;5W@3Qa9`0
h<>K0=k1V@3M`9P0g;nG0=^nUP80h;nP00<0h;nN0>2oW03P`9X00P3P`9T00`3P`9L0g[fJ0=nnV`02
0=nnV`80h;nL0P3Q`9d80>2oW0<0gkjK0`3P_i`:0>70W@<0hl:O0P3R`Ih30>70W@@0gkjK0P3N_IX2
0=flV@80g;^H0`3K^YL30=ZiUPP0fk^D403I^9D80=NgT080fkRB00<0f[NA0=VfT03H]Hl00P3G]8h0
1@3F/hd0e[>90=BaQ`3B[hD0d:f30080cjb200<0d:f30=6^Q03A[X@00P3A[X@30=2]P`80cjb22@3>
[7h30<^XOP<0bZMm0P39YW`20<RSN@80bJAj00L0bZEk0<^VO03;YW`0bjIl0<VUM@38Y7@0aZ9b00<0
a:1`00L0aJ5a0<JRLP35Wg00aIm`0<BNK`33WFh0`Ya]0080`I]/00<0`9Y[0;fII@2mVFD01P2mVFD0
1P30WFL0`9aX0<6MJ@32WV`0`Yi^0<>NL@80a9mc2034X7030<:NKP030<>OK`34X700a:1`0080aJ5a
0P32WVX20<6MJ@<0`9aX00@0_i]W0;jJIP2nVVH0_YYV:oooool002[ooooo0P2YOT/30:QmBP<0Yga9
0`2UO4P20:ImB@<0Ygi:202XOd/30:V0BP80ZX5;0`2[PT`80:b3C`80Zh9>00@0[8=?0:f4D02]Q500
[XEA0P2_QU880:f4D0P0[hI@00D0]8YH0;F;F@2hSU`0^Y1N0;bBH0030;fCH@80^I=T00@0^YAU0;^E
IP2lUVL0_9IW0P2mUfP00`2nV6T0_IQ[0;fHJ`060;fHJ`P0_IUY0P2iUfT20;RFJ0050;NEI`2fU6H0
]YAV0;JDIP2`S5`00P2aSEd0102`S5`0[XYJ0:^7E`2XQ5@20:J2DP0;0:B0D02QO4l0W7M;09IaA`2@
JT<0RfE008QR?@26Hc/0Q64i089O=`20GCD00P1nFc<207mL=080PF4b00@0Pf4c08IQ=026HC@0R68e
0P2;HSH208]U=P0608eW>02>J3T0T6Xk099/?@2CKCh0U6ho0`2HKS`309M]>`80UV`j202GKC/309I/
>P<0UF/i0P2DJSP2099]=P0609=^>@2CKSX0Tfdl099/?@2@JS/0SfTl202?JCX2091Z>`80SfTj0P2>
J3T208eW>006099Y=@2BJ3H0TVPf099X>02BIcX0TVLl0P2BIcd01@2=IcP0SVPi08mY>P2@JS/0TF/l
0080T6Xk00<0SfTj099W>P2BIcX01P2BIcX809EZ?@0409=X>`2DJC`0U6Tl09AY?0@0UFXm00@0UV/n
09E`?02EL3`0UG0l0P2DKc/309=^>P@0TF`h0`2@JcL0102?JSH0Tfdn099/?@2@JS/208mY>P03091Z
>`2BK3d0Tfdn00P0Tflk00<0U70l09=_>`2BKSX00P2BKSX00`2DL3`0UW8n09Mc?`0809U_?@P0U70l
0P2HM4000`2GLcl0UW8n09Ea?@0309A`?0<0Ug=30P2HM4@309UeA@80UWE00P2GMT4309Qg@P0309Uh
@`2EMdD0UGM500<0UGM50`2DMT@0402ALT<0Sg1108e^?`2:Jc`0QfPi08EV=`23I3D0PV<d07aM;P1h
G2d0LUL/06UA:`1OBbP0ETDW05109P1<?R@204Hl8`80AC/R0`14>R402P13>B00=2hN034^7@0`;Ah0
;B/N02TY7@0V:1d092LL02<V7@0T9QP202DW6@0302HX6P0W:A/0:2XL0080:B/M00P0:S4O02L^700W
:aX0:RdL02lb8@0b<b<0<S0Q02l]7P8082<L0`0O8Q/501hQ6P807b8K100P8a`05P0Q91d09bLM02TY
7@0_;1d0=c0M03lh7P19?R00DT<R05I89@1PC2T0J5D]06YJ:@1TEb80H5<O05e@901CAR@0B3XO030`
9P0Z:R0092@J02<S6@0V9Q`202TY7`0402PX7P0`:Qh0<2XN030Z7P80;bTM0`0^:1`0200Y:Q`0:R/M
02//7P0/;Al0:b`N02TZ700X:A/09RLI200V9Q`01P0X:Q`09bTL02HX6`0U9a`08b@L028S7@808B8M
02008B<N02<T7P0^:Qh0?3@Q04Ph7P1H@Al0KeH^08U/@P2NQTP0[iIN0;fRM@30Y7l0_j:00;bPN@2b
UfP0YheJ09V4E@2JP4d0XX5<0;:;E02hT5d0XWmE07YM?@1H@2@0>CLZ03Pf:P0c<bL0;c4V02`]9@0X
:b@08bPR028W8@P092HS00/09bHR02PW8`0Y:2<0;2`T02h^900`<2@0<S8V038c9@0`<2H0;blU02h^
900202d]8`0302h^900_;bD0<30V0080=30T0P0c;b<0300b;R80<BdQ030/800`;200<b`V03</900d
;BD0=BhT03H`900g<B<0=c4Q03Pb8P80?38V00H0>c4U03X`900j<2@0>c4U03`b9P0m<bL803`b9P<0
A3LW0`13=RH3048e9@0304Dd9016=BD0B3LW00<0BSTY0P18=bL204`j900304dk9@1>?2H0CS`V00<0
CS`V00/0CCdV04`l9@1;>b@0BSXS04/k901<?2D0CShW04lo:01@?B`0CS/Z04`i:00304/h9`0804`i
:01=>RT0DC`W058m:01C?bL0ED4X05M3:01HABL205Y79`0805a<:`1PCBd0HTl_06E@<@1WD340ITd_
06E:;@1SB2/2065><00605m<;P1NBbd0G4T[05Y7:@1IARP0F4DW0P1IAB`205Q4:`80Ed<Z0P1F@RT0
201A@2H0CclU04lo9P1>?bP0BclY04Tn:P17?bX0Acl/0P13>2H304@i9`0;04<h9P11=R@0@3DS04<f
;@13=b/0@SHZ040d9P0o<b<0?C8P03`a7@0k<1`0100i<bD603Xd9P80>C<U0P0h<R@203La8`80>BlS
0`0k<BD00`0i;b<0>2hR03H/8003038^8P80<BdQ0`0`;200600^9b40;bPP034Z8P0c;280=BlS03La
8`0i<b<0>S@T03Xd:00j<RD0?3@W044h:@18?2`0Bch]04`m:P19>RL0CC/U04/i8`1:>280C3XT04lm
9`1A?bT0D3hX04dk9@80@cPT0`14>BD00`12=b<0@CHR040e8@0204Ll:P80AS/Y00d0A3TW04<h9P12
=bD0@CHT040e8`12=RP0@cDX04@g9P18>B@0C3`S05919@1GA2H0FTLW0080E4@Z0P1EAB/0101C@bT0
DD4W04hn901=?B<3048g9@80@CHT0`10=B<02019>R<0C3`S05509P1H@bH0GdHW06I99`1ZC2P0KDdW
0P1VCRP07P1UCBT0IDd[06A;;01TBbd0HdX/06=9;P1VBBL0Id/V06Q<9`1[CbP0KU8Z079G;01eFRd0
MU/^07aH:01lFRX0Oed_081O<P1oH3@0Nehd07MK<`1eFC40NETc07QH<P1gEc00MeL^07UJ;P1kG2h0
OUla081Q<P80O64d00H0OV4e089S=`24HcP0Qf@j08QU>`2:IC/208A^=@0F08=^>@21KC/0OF/k07QW
>`1eHc/0LF8i07AQ>@1bGcL0LU`e079J=01cFC@0Me/f07YN>@1mGc/0OV8b089V=P25JCT0Q6Ph085U
=@20I3@0PfLg08M[>`80QfLh00h0QFHg089V=P20ISD0OFHd07aU<`1kIC<0PFDf08IZ>`2:KSh0RVhl
08M/=`26Jc@0R6df08Y`=`80TVXf00H0Sf`f08e^=`2;LCP0RG<i08Ue>P29MS/209Qg@P80VGQ301D0
VWU409]jA@2LNdH0W7]609j0CP2MOdd0Vge;09YlBP2INdT0VWa:09]mB`2LOT`0XHA<0::5C@2TQdl0
YXUA0:V<E02/SeL0[Y5I0:nBFP2aUVT00P2cV6/03`2gW6l0_J9e0<>XN`39[X40cK:50<ndQ`3D_Xl0
el6B0=c5V@3Rbj40j=6X0>cD[P3_ek40l=Rd0??G[`020?;F[P80lMF]00@0l]J^0?CH/03df;00mmZ`
0`3hfk404@3gf[00mMR^0?;EZ`3ae:X0mM>S0??AX@3_cId0j/RH0>G3T`3P_Xh0g;Z:0=ZhR03F]H00
e;=n0=2_NP3<ZgH0bZUd00<0bJQc0100bj]^0<VYK039ZG00bjYd0<RWM039YgT0f;J90>_8WP3bdZT0
mmN^0?_N]03lhKH0nN6e0?SQ]@3jiKP0oNRk0P3oj/403P3ojKl0oNFi0?[O/P3cejP0k/nQ0>[;W03V
aY<0h/:?0=:dPP2lX700/iQY0;BLKP2gWg40]9ea0P2kY7X20;bUN`<0_JIl00L0_ZMm0;nWP@2oYh40
`:R20<:ZQ033ZhD0aJf70080aZj800P0b:j90<bbS@3B^YH0f<6O0=_7YP3MbZX0g/^[0=c;[@80g/je
00<0glnf0>3@]`3QdKP00P3Rd[T04@3SdkX0gm2k0>3A_03QdKX0hLng0=o>]03NbZl0g<N/0=_6Z@3J
`j@0f<6R0=JoX03B^i`0c[NH0<ZcU038/I80aZn@0080b:^;00<0ajZ80<JZQ@35ZH800P34Z8000`33
Z7d0`jN20;jRO@020;VMN0090;jRO@32YX40a:R30<>WPP36/8T0b[B=0=2jU@3F_id0flBT0080gLJW
00<0g<BX0=g;/`3OcKD00P3Rd;P00`3Udk/0imFm0>OE_@020>OE_@090>SIaP3Yf/L0j=_:0>WMc@3Y
h=40j^;E0>_SeP3[iMT0k^WF0080knSF00<0l>OF0?;VeP3ci]H00P3eiMH20?;VfP030??Wf`3dj=`0
mNWM0080m^[N00<0mn_O0?G[g`3ejml00P3dj]h20??Yg@80l^SL00H0m>SL0?;Xg03bj=h0lNSO0?3Y
h@3^jN<20>gZi@<0lNcV0P3bkNL30??^j0P0mNkV203gkn`20?;ak080lo;]0`3dlnh00`3em>l0n?3]
0?S`k@060?S`k@P0n_?[00@0o?G]0?_dk03km>`0noC/0P3jln/20?WbjPP0n^oY00@0oO3W0?c_iP3l
knH0o>oV0P3kk^D20?[]i0P0nNgM203hk>080?S[hPP0n>cP2@3fk>080?O]ha00n>kT203hkNL80?G^
iPP0mNkX203fknL80?K_j@P0mo3Z403gl>P`0?G^iPP0mngS4@3fk>80103ikN40n>cP0?S/h03hk>02
0?O[g`80m^[N203gjm/80?KZfQ00mNSG203fiM<20?KUe@80mNCD0P3dhm<20??RdQ00ln;@403chL/2
0?;Pb080lMo70P3`g/H20>oMa@P0kmk40P3agL@20?3L``80km_20P3^f/430>oG^`80k]Jj0`3]eKT0
203/d[T0kM>j0>gC^03^eKL0kMBe0>_C/@3Xd:h0iln[0`3Yc:X20>S;Z@<0ilZX0P3Xbj/00`3WbZX0
i/VY0>G8Z0020>C7Y`80hlJV0`3SaJ<20>;4XP<0hL>Q0P3O_Yd0103P_ih0hL2O0>70W`3R`J020>?2
X@080>?6WP3RaId0hLBL0>33V`3N`IT0gL2H0=boU`3K_YH20>;1XP030>;1X03R`Ih0h/:L0080h/:K
00@0h/:I0=jmVP3N_IX0g[fJ0P3O_Y/30>2oW0/0gkjK0`3P_i`:0>70W@<0h/6N0P3Q`9d30>2oW0<0
gkjK0P3N_IX30=flV@80g;^H0`3K^YL30=ZiUPP0f[ZC403I^9D80=NgT0060=^hTP3J]i40f[NA0=Vf
T03H]Hl0ekB>0P3F/hd0103F/hT0e;670=:_Q@3@[H<20<n/PP030=2]P`3A[X@0dJj40080dJj40`3@
[H<20<n/PPT0cZan0P3<ZGl20<^XOP<0bZMm00@0bJIl0<VTNP39Y7X0bJAj0P3:YG/30<^VO0030<VU
M@38Y7@0aZ9b00<0a:1`00<0aJ5a0<JRLP35Wg000P34WVl00`33WFh0`Ya]0<6KK0020<2JJ`P0_IUU
00H0`9eW0<2LJ031WFT0`Yi/0<:NKP33WW420<BOL`P0a:1`0P32WVh30<>OK`<0a:1`0`31WFT20<2L
J0H0_i]W:oooool002[ooooo0P2WO4T60:QmBP@0YWe91P2WOTX40:QoB`@0ZH1<0`2ZPDd30:^2CPP0
[8=?0P2ZPDd0102[PTh0[8=?0:j5D@2_QU820;27D`80[8=?102]Q5020:j5D@P0[hI@00D0/hUG0;B:
F02eReT0]heK0;R>G0020;Z@GP050;^AG`2fT640]Y1Q0;NAHP2hTV<00P2iTf@20;ZDI@030;^EIP2j
UVH0^YIV00H0^YIV202iUFD30;FAH@D0]91P0`2^RUX04@2]RET0ZXIF0:N3D`2SOdl0XGe=09ijBP2L
N4P0V7=609=^@P2=J3h0R68k08=M>021FcH0Pf0h085N=P1oG3@0OU/c0080OEXb00D0OU/c07mL=021
HC80PF4b08=Q<`0208IQ=00;08QR=@2;HSH0Rf8f08US=02:I3D0RfDf08iX>@2@JS/0TV`m09A^?`2E
Kd001P2GKC/209I/>PP0Ufdk0P2FK3X609E[>@80TVdh00L0TVdi099/>`2AJc`0TF/n091Z?@2@JCh0
T6Xk00@0SfTj0`2>J3T2091Z>`80SfTj0P2>J3T208eW>006099Y=@2BJ3H0TVPf099X>02BIcX0TVLl
0P2BIcd00`2=IcP0SVPi08iX>@0208mY>P<0T6Xk202CJ3/809I[?PT0UFXm0P2EL3`309A_>`<0Tfhj
0P2CKC`00`2BK3/0TF/j091Z>@0208mY>00408iX=`2DKSl0Tfdn095[?080T6Xk00<0TF/l09=]?P2D
KSl0202CKc/00`2DL3`0Tflk099^>P02099^>P0309A`?02FLSh0Ug<o00P0V70m202ELCd01P2IMD40
V7A009Mc?`2FLSh0UG4m09=_>`80TVhj0`2GLd<309QdA080VGE50`2FMD0209Mf@@<0V7M20P2EMdD4
09AfA080TgE300H0TG9308m`@@2<KCh0RFXk08IW>024ICH208=T=@0807]L;@1fFR/0LEH[06M?:@1N
BRL0E4<U04lo9@1;?B<304Dk8P<0A3XQ0P13>B00200d;Qh0<BhM030]7P0]:ah0:BTM02HX7@0T9a`0
8bHM0P0T9QP00`0U9aT09RPJ02LY6`0202PZ700902T[7@0Z<Al09bhL02P/6`0[;Qd0;c8Q03<d900c
<B80<2hO008082<L0`0O8Q/601hQ6P807b8K100P8a`05@0V9al09bTN02d[7P0e<1d0?CDN04Dl7`1>
@B40DTDS05i:9`1WE2`0JUXY06=F8@1PDal0GE0T05A79@19>b00<30V02XZ800T91X08b<I02HV7002
02TY7`0302PX7P0^:Qh0;RXN00<0;BTM0`0/:1`00`0X:A/0:BXL02X[7@0202//7P0302X[7@0Y:Q`0
:2TK00P09RHL00H09bTK02HX6`0U9aX092HK02<T700R8ad2024R7@0P028T7`0S91h0;RXN03`d8@18
>1h0F44O071G;`29K480W8A60:^BFP2iWW40_J5l0;jQO`2lX7T0/YMX0:J<F@2HPe@0VX1=0::1C02b
Re@0]hmL0:9oE@1jGCd0EclS03Tg:P0h=RX0<c<W02la9P0/;BD0:2/T02<X8P0R9b4802@V8`0;02HU
8@0W9R80:BPS02/[8`0^;R@0<30T038b9P0c=2H0<30V02h^900];B<00P0/;2800`0];B<0;RhT030`
9P0303<_8`03038^8P0a;B40<BdQ0080<2`P00H0<b`V03</900d;BD0=BhT03D_8`0f<28203La8@04
03le:@0n=2P0?C<W03`b9P@0>c4U100l<RH403dc9`@0ACPX0P14=bL304<f9P0304<c8`14=2@0ASHV
00<0B3PX00P0AcLW04Hf9P1:>280BcTS04dk9@1>?2H0CcdW04hl9P80CC/U00/0Bc/T04Xj8`19>B80
BCTR04Xj8`1<?2D0CShW04lo:01@?RX0CcdY04dk9`0204`j9P0904dk9`1>?2P0CcdY054l9`1B?BP0
DclW05A09`1F@RL0F4DW0080FDHV00<0GTTZ05m::`1QC2d00P1UCRl00`1TCBh0HdX/0699:`02065>
<006061=;`1NBbd0G4T[05]8:P1JAbT0FDHX0P1IAB`205Q4:`80Ed<Z0P1F@RT0401A@2H0D40V04lo
9P1>?bP0BclY04Tn:P17?bX0ASh[04<h9P14>BL0AS/Y04Pm:`17?2X0ACXX048g9@10=B<2048f:P06
048f:011=BD0@3DS040e8@10=Al0?c@N0`0k=2@01P0l=BD0?CHV03df9P0m=RH0?SLW03/e9`80>S@V
00P0>C<U03Pb900g<B<0=c4S03H`8P0h;R80>BlS03X`9080>c4U00<0>S0T03P^8P0g;B400`0b;R83
034]8@80<2`P01P0;bHO030W7P0b:B00=BdR03P`8`0j<b<0?3DS03df900k=BL0?CDX03lh:013>RT0
Ac`Z04Pk:019>RD0AcPS04`g701=>1d0CcTQ050l8`1C?bL0DT0X054o:@1??bP504@i9@0304<h9012
=b<0@SLS0080B3dY0140Ac`X04Hk9`14>BD0@SLS040e8@0o=200?S<O04@h:015>2L0ACPU04Pi901;
>b@0D3lU05E19P1G@bP0DT8X05=3:@0205A4:P040592:01@@2H0CShT04dm8`80@SLU0P11=R@2040e
8`80?c@R00d0AcPS04Xj8`1??R@0Ed8W05m6:01UB2P0J4XX06]:9`1UCbP0I4hW06A>:@1SC2X0HT/[
0080HDX[01P0H4P/06A79@1VBRD0JDdX06eA:P1aEBd0M5T^07IK;P1gG2l0NUHV07aJ:P21Gc40Q6<f
08=T>01mH3H0Me/c07=G;`1dES80LeDa075C;@1`Db/0LE@Z07AG:`1gFRh207YN;`0707]O<01nGc40
PF0c08ES=P28HcL0RVDi08aU>P0208I]=@0F08=/>020JST0NfHg07ER=`1aGSH0KU`d075N=01`GC<0
LE/b079K<P1dFc<0NEdf07]O>01nH3X0P6@e08=W>025JCX0PVHg07iR<`1lH340OF4b081T=@80Q6<f
00<0Pf@f085U=P20ICH00P1mICD03`1lISD0PfHj08IY?@29KCh0R6`l08AX=P23J3<0QFXe08Q]=P2>
JC@0SV/e08i]=`2?L3T0T7<k08ie?00208af?0<0VGQ300<0VWU409]jA@2KNTD00P2LNdH00`2JOT`0
VGe;09QlBP0209IjB00<09MkB@2IOD/0VWi<09j1B@2OPTX0XHA<0:>6CP2VRE40Z8]C0:Z=E@2[SUH0
Zi5P0P2^U6<03P2bV6L0]ie/0;fSLP33ZGP0ajel0<Z`O`3@^HL0d[^90=JnSP3La9H0hLVM0>K=Y03Z
dJT0jm:Z103]dZL01`3^djP0kmBY0?3EZP3`eJX0lmJ/0?CG[@3ef:h00P3ffJl03`3dejd0l]F[0?7D
ZP3geJL0mM>U0?7?X@3/bY`0i/BF0>6oT@3M^hd0fkV;0=RgPP3F]H00dK1k0<f/M`020<^ZM@0B0<b[
MP3=[7L0cJe`0<ZZK@3;Zg80bjYd0<RWM039YgT0f;J90>[7W@3de:/0nMV`0?gP]P3nhkP0n^:f0?WR
]P3ki[T0o^Vl0P3ojL003P3oj;h0oNFi0?WN/@3cejP0k/nQ0>W:V`3UaI80hL6>0=6cP@2lX700/YMX
0;BLKP2gWg40]9ea0`2lYG/30;fVO080_ZMm0100_jN10<2XPP31ZH<0`ZZ40<B/QP35[HL0aZj80<N_
R@38[XT0c;:=0=:jUP3H`Il0flNV0=g:ZP3Nbj/0g<^]0P3OckH00`3Pd;L0hM6h0>;B^@020>?C^P0A
0>CD^`3PdK`0h=6l0>7A^P3Rd;P0h<ne0=o;/03Mb:d0flJY0=[3Y03H`J80e[nP0=:kW03>]iP0b[>D
0<RaTP36[i000P38Zh/02037ZXP0aZZ50<JZP`35ZH40a:R00<BYOP31YGh0_:1i0P2hW7D02@2mXGX0
`ZIo0<>WP032YWl0a[290<ZdS@3@^YD0e[nM0=_4Y0020=g6Y`030=c4Z03Mbk<0glfe0080h]2h00<0
iM>k0>OE_@3WeKd00P3WeKd02@3XfLH0jM[70>SKbP3YgLd0jN3A0>[Re@3[hmH0jnGI0>kYeP020>oX
eP030?3WeP3bi]H0lnKF0080mNGF0P3bi]X00`3cim/0m>SL0?GYg@020?KZgP030?O[g`3ejml0mN_O
0080m>[N0P3cjMd20?;Xg0060?CXg03bj=`0l^SN0?7Xg`3`jN40k^WS0P3]j^D30?7/iP80l^gW0`3c
k^P80?G^iPP0mo3Z0`3dlNX20?Gbj`<0m_?/203hlN/80?WbjP040?_dk03jln/0n_?[0?[cj`80nO;Z
0P3hlNT80?W_iP80oO7U0P3ll>@30?__h`030?[^hP3hk=`0n>cL00H0n>cL603gjml90?G[g`P0m^cR
403hk^@80?S]i`P0m>gU203ek^P80?K_i`P0m^oY203gl>X@0?O`j300mNkV203gkN<A0?K/hP<0n>cP
0P3gjml30?KZgPP0mn_K203fj]X80?GXe`P0m>OF203fiM<20?KUe@80mNCD0P3dhm<20??RdQ00ln;@
403chL/20?;Pb080lMo70P3`g/H20>oMa@P0kmk40P3bg/D20?7Ma0<0l=c300@0km_20>oG^`3_ek/0
kmNk0P3^e[X30>gE^@080>cB^@3]dkX0kM>h0>kE]`3]e;D0jm>a0>S@[P3Wcj/30>W<ZP80j<^Y0`3W
bZP20>S;Z`030>O:ZP3VbJT0iLRX0080i<NW0P3SaZH20>?5X`<0h/BR0`3Q`j420=jmW0040=nnW@3P
_ih0h/6P0>?2X@80i<>R00D0h/BN0>73W@3Q`id0h<:L0=k0VP020=foV@060=bnV03S`Z<0hl:S0>?2
X@3S`Yl0hl>M0P3S`i`0103S`iX0g[fJ0=jmVP3N_IX30=nnV`80h;nL2`3O_Y/30>2oW0d0hL2M0`3P
_i`40=nnV`80g[fJ0P3M_9T40=bkV0<0fkZG0`3J^IH80=ZjTa00fKRE203G]i020=ZgT@040=VfT03H
]Hl0f;F?0=NdSP80e[>=00@0e[>90=BaQ`3B[hD0d:f30P3?[8800`3@[H<0dJj40=6^Q0020=6^Q0<0
d:f30P3?[8890<j/OP<0c:Uo0P3;Z7h30<ZWO@@0bZEi103;YWX00`39YGD0b:Ad0<JRLP030<BPL005
0<FQL@36XW80a9i_0<BNK`33WFh00P32W6d00`31Vf`0`9Y[0<2JJ`080;fII@060<2MI`30W6P0`IeY
0<:NK032WVh0`iia0P34Wg<80<BPL0H0`im_0P34X7020<6MJ@<0`9aX1P2oVfL[ooooo`00:_ooool2
0:IkB080Yga900@0Z7e:0:UnB`2YOT/0ZWm<202WOTX00`2VODT0Ygi:0:MnBP020:QoB`80ZH1<102Z
PDd30:^2CPX0[8=?0P2ZPDd0102[PTh0[8=?0:j5D@2_QU820;27D`030:^2CP2/Pdl0[8=?0080[HA@
0P2^QE400`2_QU80[XE?0:j5C`060:j5C`<0/XQF00H0/hUG0;F;F@2fS5X0]heK0;R>G02bS5d20;>=
GP040;B>G`2eSf00]HmP0;J@H@80]i5R202fTV080;FAH@P0[h]I0P2]RET04@2/R5P0ZXIF0:N3D`2S
Odl0Wg];09eiB@2FLT80Tflo091[?P2;ISX0QV4g089L=@1oFC@0OELb081M=@1oG3@0OEXb0080O5Ta
00<0OEXb07iK<`1oG3@00P21HC801023HC<0QV4d08IQ=028HSD208]R=P0808QR<`29Hc@0RfDf08eW
>02?JCX0TV`m09=]?P2DKSl609I/>PX0Ufdk1P2EJcT209I/>P80TVdi00<0TF/j095[?02@JSd00P2@
JCh00`2@JD00T6Xk091Z>`0208mY>P0408iX>@2=IcP0SFLh08eW>080T6Xk0P2?JCX208iX>@80SFLh
00H0TVTe099X=P2BJ3H0TVPh099W>P2BIc`2099W?@<0SFLh0P2>J3T208mY>P03091Z>`2CJ3/0TfPk
00H0TfPk302FJch509EZ?@<0U6lk0`2CKSX2099]>@0609A^?`2CKCh0Tfdn099/?@2AJc`0T6Xk0P2?
JCX00`2EKd00Tfdn099/?@02095[?003099/?@2CKCh0UFm000P0Tflk00<0U70l09=_>`2BKSX00P2B
KSX00`2DL3`0UW8n09Mc?`0809Ia?@P0UG4m0P2HM4001P2GLcl0UG4m09A`?02CKc/0TVhj095]>@80
UW920`2GLd<309QdA080UG@o0P2FMD0209Mf@@80V7M20P2FN4H209EgA@80U7I40P2CMD<01@2BLd@0
Sg1108]/?@27J3T0Q6Df00<0Pf@e00P0NU//07IJ:`1`EBX0IdlY05e99P1D@bD0CShT04Xl8P80AC/R
0`14>R4304<i800903<]7@0`;A`0;b`M02`Z7@0X:1`09BLL02<V6`0R9A`08bDG008092HH00<09BLI
02HX6P0W:A/00P0X:Q`0200Z<Al09bhL02L[6P0Z;A`0;c8Q038c8`0b<240;bdN0P0P8a`301lR6`<0
7R4J0P0M81T201hQ6P807b8K0`0P8a`05@0U:2409bPP02XZ7P0a;Qd0>C<M044j7P19?R00CT4Q05m;
:01XEBd0Je/Z06EH8`1REB40H5<W05Q;:@1=?b@0<30V02XZ800T91X08b<I02HV700202TY7`0402PX
7P0/:Qd0;2XM02`Z7@<0:bTL0P0Z:1/00`0X:A/0:BXL02X[7@0202//7P0302X[7@0Y:Q`0:2TK00P0
9RHL02P09BLI02DW6P0T9QT092HK02<T700R8ad08R<N024R7@0R91l092DO02hZ7P0l=240AcLM05Ho
7@1]E2`0QVTo09Z2A02XSeL0]IY]0;ZNN@2mX7h0_J5j0;:GJ02TRUL0V8=D09UoC02QP4/0/HYC0;N?
G02ROeD0NE`l05Lo8`0i=bX0>3HZ03<c9`0_<BH0;2dU02P[900S:2808RLQ200T9R<02`0V9B409bHR
02TX8`0[:b<0;BdS02l_8`0`<2@0<C8T02l_9@0^;R@0;2`R0080:b/Q00<0;2`R02h^900_;bD00`0b
;R84034]8@07030/800b:bD0<R/S03</900d;B<0=BlS03H`8P0203La8@<0?S@X00H0?C<W03`b9P0k
<BD0>S0T03T_8`0j<2@203/a9@80?38V0P0m<bL00`0n=2P0ACPX04Dh:00204Dh:080A3LW0`13=RH0
0`10<b80@SDT04<f9@0304Dh9`0504@g9P13=RD0BCLQ04/i8`1=>bD00P1??BL01@1>?2H0CC/U04/i
8`1;>b@0BSXS0080BCTR00L0BSXS04`l9@1>?RL0CclX050n:01??BL0CS`V0080CC/U00T0CS`V050n
:01A?bT0DC`W058m:01C?bL0E40W05E19P1GA2H00P1HABD01P1OARP0H4LY065::`1RBb`0Hd`]065<
;@80H4//0P1PCBl0101OC2h0GDX/05a9:`1KB2X205Y7:@80FDD/0P1HA2/205M3:P80ET8Y00/0DT4W
05519`1@@2L0CSlX04/o:@19?RX0AShY04Dm:P13>2H0ACXX04Ll:P0204Pm:`0904Dj:013>2H0@CHT
03hb900o<bD0@3@T044f9013>2@0A3TS0080AS`S1@0o=RD3040g9P80>cDW00@0>S@V03Tc9@0h<R@0
=c4S0P0f<2800`0g;B40>2hR03X`900203/a9@0303X`900i;b<0>2hR0080<blS0`0b;R83034]8@0H
038X7`0c:Al0=B/Q03L]8@0j<B80?C@S03lg9010>2D0?CLW03lh:010>BL0@3PU048g8`12=R00A3DN
04Df7`1@=QD0E3TK05Ln801I@BD0ET8W05919`1>?RD0CCdV0P16>bL00`15>RH0A3TU04@i9@0304@i
9@80AS/U00D0ACXT04@i8`12=b40@3DO03ld7P0203db700804Dj9P16>BH0ACTS04Pi901;>b@0CS`T
05<o9`1E@BT205519`<0DT8X00<0D40V04hn901<?2800`11=R@2040e8`<0?c@R00P0@c@O04Lf8P1=
>b<0EClW05e3:01SARP0IDLU06M69@80HTlW00`0HDdX061<:@1OBbX0GTTZ05e8:@1MB2/0HdHT06I:
9@1[CbX0L5@]07AH<01fFc0207IK;P0H07YF9P1mFb/0PV0b08ET=`24ICT0OV4g07QL=01cEbl0LE@b
06mB<01/D2/0JThW06]?9`1^DbP0LUL/07EJ;@1kG2d0O5d^07mO<022H380Qf8e08UT=`2<IST0SfHj
0P28KCH01P25JcP0PFTi07aV=`1fHCH0LE/d06eJ<P80L5db00h0LUdb07AM<`1fGC@0NUhf07eQ>@1o
HSX0P6<g08=V>P24Ic/0PF@h07aO<`1iG300Nehb07eP=080QF@i00<0Q6Di089U>@21IST00P1oIcT0
3P1nJ3T0PF@j08AW?@27JSh0QFTj089V=P21IC<0Q6Pf08Q]>02<JcD0SVdg08m`>@2BLc`0TgHn0`2B
N3l309YiA0@0VgY50180W7]609QnB`2GODX0UG]809AjA`2ENdP0UWa909MmBP2HOT/0W7m709f0B02O
PTX0XHA<0:>6CP2UR500YhYB0:R;D`2YSUT20:^@F`0C0:nDG`2dVF@0^IiY0;jSKP32Yg80a:Ud0<V`
NP3;/W`0c[B10=:hQ`3G_8d0g<6D0>35VP3Rai`0ilZN0>S;W`3ZcJ40jljR0>g@Y0020>kAY@040>oB
YP3_dZP0l=>Y0?;EZ`80m=N]00l0lmJ/0?;EZ`3ae:X0mmFX0?GCYP3bd:<0k/bO0>W7VP3T`YD0hKnB
0=nmT03M_8L0f[V40=FdO`3@[gX00P3=[7L04P3?[WT0d:mj0<n_LP3<[6l0c:ac0<b[M@38Yg@0b:Ih
0=NeR03YaY`0m]J]0?cL/`3oh[P0onFj0?gU^@3liKT0o^Vl0?o/_`80onW000h0onRn0?cT^03ig[40
l]JW0>g>X03YbY/0i<BA0>30S@3@/X00^im_0;:GJ02dW6h0^:1b0;BML@80_:Ek0`2mYW`30;jWO@80
`:R200@0`JV30<>[Q@34[8H0aZj80P37[hT02039[hX0cK>>0=>kU`3I`Z00g<RW0=k;Z`3Oc:`0gLb^
0P3Pd;L00`3QdKP0h]:i0>?C^P020>CD^`0A0>GE_03PdK`0hM:m0>;B^`3Rd;P0h<ne0=o;/03Mb:d0
g<NZ0=[3Y03H`J80e[nP0=:kW03>]iP0b[>D0<RaTP36[i000P39[8`04`38ZhT0aj^60<JZP`35ZH40
a:R00<BYOP30Y7`0_:1h0;NKL`2hW7@0_J5i0<:VOP34Z800`jMo0<J`R@3:]8d0d;ZE0=JoW@3Ka:@0
0P3MaZL00`3La:P0gL^c0=o=]@020>;@^0030>GC^`3WeKd0imFm0080imFm00T0j=W60>WJa`3XflX0
jMg=0>WPd@3Zh]D0jn?F0>_Uf@3^jMH00P3_j=H00`3`imH0l^KF0??VeP020?GUeP80l^KJ00<0lnOK
0?CXg03ejMd00P3fj]h00`3gjml0mN_O0?G[g`020?CZgP80lnWM0P3bj=`01P3dj=`0l^SL0?;XgP3a
j=l0l>WQ0>kYh`80kN[U0`3ak>H20?;]i`<0lnkX203ek^H80?O`j080m?3W0P3elNP20?Kbj@80mo?Z
203hlNT80?WbjP80n_?[0P3il^X30?Saj@030?O`j03hk^@0n>kT00H0n>kT0P3ll>820?__h@<0n^kP
00<0nNgO0?S/g03hk=`01P3hk=`80?KZgPP0m^[L203fj]h90?CZgPP0m^cR403gkN<80?O/iPP0m>gU
203ek^P80?G^iPP0mNkX203gl>X@0?O`j300mNkV203gkN<A0?K/hP80n>cP0P3gjml20?KZgP80mNWM
203gjm/80?KZfPP0mNSG203dimH80?KUd`80m^GE0P3ei=@20?CSd`80ln;B403ch]0@0??Qb`80l^38
0P3aglL20?3NaP80kmg5203_g/@20?;Na@80lMg40`3`g<<0103_fl80kmNk0>oG^`3_ek/20>kF^P<0
kMFi00P0k=:i0>gC^P3]dkP0k]Fg0>gD]@3[dk40j=2^0>O?Z`<0jLbZ0P3XbjT30>O:Z080j<^[00<0
ilZZ0>K9Z@3Ub:P00P3TajL20>?6YP<0h/BR0`3Q`j420>32X080g[fL00@0gkjM0>2oWP3R`J00hl:Q
0P3T`j820>73W`040>32WP3O`Id0gl6M0=k0W080gKnK0P3S`Z<00`3S`Z40hl:O0>?3W@020>?3W003
0>?3VP3M_9T0gKbI00<0g[fJ0`3O_Y/80=jmVP<0gkjK0`3P_i`:0>70W@@0h;nL0P3O_Y/50=jmVP80
gKbI1@3L^iP30=^jU`<0f[VF203I^I8@0=RgU0P0ekN@0P3J]i40103I]Y00f;F?0=NdSP3F/hd20=Fb
S0040=JcR@3D/HL0dZn50=2]P`80cjb200<0d:f30=6^Q03A[X@00P3A[X@30=2]P`80cjb22@3>[7h2
0<fZP080c:Uo0P3;Z7h20<ZWO@P0bjIi00<0bJEe0<RTM036XW800`34X7002035XG40aZ9b0<BNK`34
WVl0`ie^0<:LK@31Vf`0`9Y[0P2oVFX80;fII@060<2MI`30W6P0`IeY0<:NK032WVh0`iia0P34Wg<8
0<>OK`80a:1`1P33Wfl30<2LJ0<0_i]W0P2nVVH30<2LJ2_ooooo000Zooooo`060:AiAP2UNTL0YW]8
0:MlB@2XODX0ZWm<0P2[P4d0102YP4`0Z7m;0:QoB`2XOd/30:MnBP<0YWe900@0Ygi:0:QoB`2XOd/0
ZH1<0P2ZPDd30:Z0CP80Zh5?0`2/PU080:b3C`80Zh9>00@0[8=?0:f4D02]Q500[XEA0P2_QU820:^2
CP040:b3C`2]Q500[HA@0:j5D@80[hIB202^QDl40;26E0050;67E@2cREL0]8YH0;F;F@2_REX00P2`
RU/0102aRe`0/XaM0;:<G@2cSEh20;B>G`P0/hmK202aSEd00`2]R5@0[8MC0:b7D`020:^6DP<0ZXEA
0P2YQED0302XQ5@0YH5A0:5mC@2MNDT0VGE509Ib@P2?Jc/0SFTi08UT=`25H3@0PUdc07mI<P80OUPc
00P0Oe`d07iK<`1mFS80O5Ta07eJ<P1nFc<0P5de085N=P80PF4b00@0Pf4c08IQ=026HC@0R68e0P2;
HSH01P29Hc@0RV@e08]U=P2=IcP0SfTj091Z>`80TV`m0`2EJcT309I/>PX0Ufdk0P2DJSP309E[>@<0
UV`j00P0Tfdl099/>`2@JS/0SfTl08mX?@2?J3l0T6U0091Y@P80T6Xk00@0SfTj08iX>@2=IcP0SFLh
0P2<ISL2091Z>`80SfTj0P2>J3T208eW>006099Y=@2BJ3H0TVPf099X>02BIcX0TVLl0P2BIcd0202>
J3T0SFLh08eW>02<ISL0SFLh08iX>@2?JCX0T6Xk202CJ3/809EZ?@<0Uf`o0P2FJch409EZ?@<0U6lk
0P2CKSX3099]>@0409=]@02BK3l0TV`o099/?`@0TF/n00<0UFm009A^?`2CKCh00P2BK3d00`2CKCh0
U6ho09E_@00809=_>`0309A`?02CKc/0TVhj0080TVhj00<0U70l09Ib?P2GLcl0202ELCd;09Ib?P03
09Ea?@2DL3`0Tflk0080TVhj0`2FLT8209Mc@`<0V7A40`2EM3l209Ie@0<0UgI10P2HNTP0102GNDL0
UWQ609EgA@2EMdD209AfA006099cA02?L440RV/l08IW>023I3D0PV<d0P23I3D02@1kG2d0MUX[075F
:`1WCbT0GTXW05A39@1??bD0BcdS04Dk8P0304@j8@80@cTP0P12>1l0200c;Ad0<2dL02l/7@0/:Qd0
:2PL02DW700S9Q/08RDL0P0S9AL00`0T9QP09BLI02HX6P0202LY6`0902PZ700X;ad09B`J02HZ6@0Y
;1/0;C0O034b8P0a;b00;R`M008082<L0`0O8Q/301hQ6P<07B0I0P0N8AX401lR6`0E028W8@0U:240
:2XO02h/7@0f<Ad0?SLM04Dl7`19?R00GDTV06IC:`1ZFRT0IEPS06=F8P1QE2P0FD`Z04i09@0`<2H0
:RXP02@T6P0S8aT09RHL0080:BTO00@0:2PN02X[7@0Z:ad0:R/M0P0Y:Q`302PY6`0802TZ700Z:ad0
:b`N02`]7`0[;1h0:BXL02PY6`0V9aT802DU6`0X02@V600T9QT092HI02<U6P0S91`08R<M028S7P0Q
8Qd08bDP02@U7`0^:Qh0>S8O04De6`1B>aT0JE0X089U>`2HP480YHaD0;6FJ@2gVgH0_J1n0;fQNP2a
UVL0XXQE09N2D`2IOd`0XH1;0;6:D`2fSU/0XGiD07UL?01G?b<0>CLZ03Pf:P0c<bL0;c4V02`]9@0X
:b@08bPR028W8@P08bDR0P0X9b<02@0Y:2<0:b/S02`/8P0];B40;RhR02l`8P0^;R@0;BdS02/[8@02
02XZ800302/[8@0];B<0;RhT00P0<BdQ00H0<R/U038[8`0c;2@0=2dS03D_8`0e;b4203H`8080?38V
0P0m<bL00`0l<RH0>c4U03T_8`0203P^8P80>BlS00<0>S0T03/a9@0l<RH00P0m<bL304@g9`<0@cHV
0`12=BD00`0n<b40@3DS044f900304<h9P05048g9@11=R@0B3HP04Xh8P1=>bD00P1??BL04`1>?2H0
C3XT04Xh8P1=?BH0C3`U04/k901:>R<0Bc/T04`l9@1>?RL0CclX050n9P1??BD0CS`T04dk8`1>?2@0
CcdU054o9`1B@2P00P1B?BP03`1C?bL0E40W05E19P1F@bD0ET<S05M4901OA2L0H4DX0617:@1PBBX0
GdX[05i;:`1OC2`0GDd/05i;;@0205e:;00305a9:`1KB2X0FTLY0080FDHX0P1IAB`205Q4:`80Ed<Z
0P1F@RT02@1C@RP0DD4W05109`1>?bP0BclY04Pm:@15?BP0ACdZ04@i9`0204Dj:00=04Hk:@15>RP0
A3TW04<h9P12=bD0?C4Q03hb8P10=B<0@SLS04Dj9017?B@0BClV04Y09@0304@i9`80@cPV0`12=bD0
2`0l=RP0>cDW03Xd9P0i<bD0>38T03La8`0f<280=BlQ03H/800h;R80>BlS00<0>c4U0P0i;b<303<_
8`80<RhR0`0a;B406`0f:B00=b/O03T]8@0k;b40?C4Q03ld8P11=R80@SLS03dh9@0n=bD0?SLT03de
800n<ad0@3@L04Lh8@1<?R@0J4PR06Q:901XBbT0HTTZ05U49`1@?bD0BcdS04/l9@18?BT0Ac`X04Hk
9`0304@i9@80ACXV0`16?2<01`15>b80A3XQ048h7`11=ah0@3HM03le7015>b800P15>B401`17>240
BSXS04hl9P1B?BP0E3lZ04lo9@1@@2H00`1A@BL00`1??bD0CCdS04`l8P02044f9080@3DS0`0o=280
2@0n<b40@c@Q04Lf901>?2H0Ed4Y05i4:`1SABT0IDHW06M69`02065?9`0V061>:01NC2P0GDXY05a9
:@1KB2P0FTLY06A79@1WBbH0KE4/07=G<01fFS80Me`a07EJ;@1dFB`0O5PX07iL;023HC<0QF@g08AU
>@1oHSP0NEde07EI<@1`Dc<0KE0`06U<:P1WBbH0J4`U06]?9`1_Db/0LUL/07]K:P1mGB`0P5h^08EQ
<@28I3@0S6Hg091W>@2BJC/208a^>00608Q/>P24JCX0OVHh07QQ=`1cGCH0L5Xc0P1bH3801@1eH3<0
MUlc07UQ=@1lHCH0OV<h0080Of8h00L0PF@j08=V?021I3X0O5le07YM<`1kGS@0OV4g0080Q6<j00<0
Pf<j085T>P20ICX00P1nISX02@1mISX0OF0h085T?023IS`0PfHj085U=P22ISH0QVXh08]_?@02091c
>`06095d?02BMCd0U7Lo09Ii@@2HNd<0VGa4202KNTD04@2FO4T0UG]809AjA`2CNDH0U7Y709EkB02G
ODX0V7i;09aoA`2MP4P0WX590:23B`2RQDd0Y8M?0:F8D02VRE40ZXeE0080[8mG01@0[i9J0;>FGP2g
VV80^iiV0;jQJ@30Xf/0`JM^0<:WL033Z740aZ]f0<Z^O03>/X80d[J70=BhR@3O`9@0h<6E0>C5V@3W
b9`0j/^O0>c=X@80kLjR00@0jljT0>g@YP3_dZP0lMBZ0P3ceZ`20?;EZ`0<0?KCZ@3ddJL0l/nU0?3=
X`3]bZ00j/NM0>S5V`3Wa9X0i<>>0>2oRP3J^H@0e;=n0P3@[gX08`3B/G`0dk9m0=6aM03>[W40cJed
0<f/MP38Yg@0b:Ih0=JdQ`3XaI/0m]J]0?_K/P3oh[P0onFj0?cT^03ki;P0oNRk0?o[_P3ojL00o^Ro
0?kW_@3li;P0n=f`0?;FY`3]cZ00j<VJ0>?3T03O_h`0ck5o0;ZNKP2bUfP0]9a^0;RPLP2eWW80_:Ek
00<0_JIl0P2nYgd20;nXOP0@0<2XPP31ZH<0`ZZ40<>[Q@35[HL0aZj80<N_R@38/8X0bJn:0<fcSP3C
^iL0fL:P0=c8Y`3Nbj/0glb/0=g<[P80hM6h00<0h]:i0>?C^P3Te;/00P3UeK`04@3Ve[d0hM:m0>7B
_@3Rd[/0h]2h0>7@]P3Pc;40g/V^0=c7ZP3J`j@0f<6R0=JoX03B^i`0c[NH0<ZcU038/I80aZn@0080
bJb<00`0b:^90<N[QP36ZX<0aZZ20<FYP@35ZWl0`JIk0;bQMP2hWG80^Iic0;jSN034ZGh20<FZO`05
0<J`R@3:]8d0d;ZE0=JoW@3Ka:@00P3MaZL00`3La:P0gL^c0=o=]@020>;@^0030>GC^`3WeKd0imFm
0080imFm00T0j=W60>WJa`3XflX0jMg=0>WPd@3Zh]D0jn?F0>_Uf@3^jMH00P3_j=H00`3`imH0l^KF
0??VeP020?GUeP80l^KJ00<0lnOK0?CXg03ejMd00P3fj]h00`3gjml0mN_O0?G[g`020?CZgP80lnWM
0P3bj=`01P3dj=`0l^SL0?;XgP3aj=l0l>WQ0>kYh`80kN[U0`3ak>H20?;]i`<0lnkX203ek^H80?O`
j0<0m^oW0P3gl>P30?Saj@P0mo3X203hlNT20?WbjP80n?7Y0`3gl>P00`3fknL0mngQ0?O]h@060?O]
h@80n^kN0P3ikMd30?S/g0T0mn_K203ejMd80?GYf@P0mNWM2@3cjMd80?G[hA00mngS203gk>H80??/
i0P0mNkX203ek^H80?G^j0P0mo3Z403gl>P`0?G^iPP0mngS4@3fk>830?O[g`80m^[N0`3ejMd80?O[
f`P0m^[J203ej=L80??Ve@P0m^GC0P3fiMD20?GTe080m>?C0P3ch]8@0??Rd100ln7;0P3bh<P20?7O
a`80l=k60P3_gLD80>oNa080lMg40P3`g<<20>oK`P80k][10`3_ek/20>kF^P<0kMFi00P0k=:i0>gC
^P3]dkP0k]Fg0>gD]@3[dk40j=2^0>O?Z`<0jLbZ0P3XbjT30>O:Z080j<^[00<0ilZZ0>K9Z@3Ub:P0
0P3TajL20>?6YP<0h/BR0P3Q`j430>32X080gkjM00@0h;nN0>70W`3Q`9l0h/6P0P3S`Z430>32X080
gl6O0`3N`9h20>;1XP030>;1X03R`Ih0h/:L0080h/:K00@0h/:I0=flV@3M_9T0gKbI0P3N_IX30=nn
V`P0g[fJ0`3O_Y/30>2oW0X0hL2M00@0h;nL0=nnV`3O_Y/0gkjK0P3N_IX20=flV@80g[fJ0P3M_9T3
0=bkV0030=^jU`3L^iP0g;^H00<0fkZG0`3J^IH80=ViTQ00f;ND203G]i020=VfT080f;F?00P0ekB>
0=JcS@3E/X`0eK:<0=JcR@3D/HL0dZn50=2]P`80cjb200<0d:f30=6^Q03A[X@00P3A[X@30=2]P`80
cjb22@3>[7h30<fZP080c:Uo0`3;Z7h0103=ZGT0c:Qh0<bXN03<Z7P30<^WM`040<ZVMP39YGD0b:Ad
0<JRLP<0a:1`00@0aJ5a0<JRLP33WFh0`ie^0P32W6d01031Vf`0`9Y[0;nIJP2oVFX80;fII@060<2M
I`30W6P0`IeY0<:NK032WVh0`iia0P34Wg<80<>OK`<0a:1`0`33Wfl20<:NKP<0`9aX0P2oVfL30;jJ
IP<0`9aX:oooool002[ooooo00H0XgQ50:AiAP2UNTL0Yga90:UnB`2ZOd`20:b1CP<0ZH1<00<0Z7m;
0:MnBP2WOTX00P2VODT01@2UO4P0YWe90:ImB@2WOTX0ZH1<0080ZX5=00<0Zh9>0:Z0D02[PE400P2[
PE420:b2DP80[H=C202/Pdl80:f4D0050:Z1C@2[PTh0Zh9>0:b3C`2^QE400P2_QU800`2`Qe<0[HA>
0:f4CP060:f4CP80[hEC00H0[XAB0:f3D@2^Q580/8ID0;:8EP2cREL20:f7F0040:j8F@2_REX0/8YK
0;2:F`80/H]L00<0/XaM0;6=F@2aSET01P2aSET80:j:FP0F0:f5DP2/Q540Zh=@0:Z2C`2YPDh0Z81=
0:MoC02VOT/0XWi>0:5mC@2PO4`0WGU909UeA@2DL400Sf/k08eY>@2:ISH0R6@d08EP<`22GC40P5/a
07mI<P80P5Xe00P0Oe`d07iK<`1mFS80OEXb07iK<`1oG3@0PEhf08=P>080PF4b00@0Pf4c08IQ=026
HC@0R68e0P2;HSH208]U=P0408aV=`2=IcP0SVPi08mY>P80T6Xk0P2DJSP209E[>@80UV`j2P2GKC/3
09AZ>00309E[>@2FK3X0UV`j0080Ufdk00P0Tfdl099/?@2@JS/0SVPk08iW?02>Ich0T6U2095Z@`80
T6Xk00@0SfTj08iX>@2=IcP0S6Hg0P2;ICH2091Z>`80SfTj0P2>J3T208eW>006099Y=@2BJ3H0TVPf
099X>02BIcX0TVLl0P2BIcd0202>J3T0SFLh08aV=`2;ICH0S6Hg08eW>02?JCX0TF/l202DJC`809=X
>`80V6e00P2GK3l00`2FJch0UFXm09EZ?@0209EZ?@0409A_>`2CKSX0Tfhj09=^>P80TVdi0P2AK3P3
095Z?`80TV]00`2CK4400`2FL440UFm009A^?`0209=]?P0309A^?`2EKd00UW1100P0Tflk00<0U70l
09=_>`2BKSX00P2BKSX00`2DL3`0UW8n09Mc?`0809=b?@P0UW8n202DL3`209Ea@@80UW920`2GLd<0
0`2HM4@0UG@o09Ed?`0209Ed?`80UWE00P2GMT401P2KOD/0VWa:09UkB@2HNTP0UgU709IhAP80UGM5
00@0TW=408m`@@2:Jc`0QFHg0P22Hc@02P23I3D0Q6Df07aM;P1hG2d0LUL/06UA:`1OBbP0ETDW0510
9P1<?R@304@j8@80@cTP0`12>1l0200b;1`0<2dL02h[700[:A`0:2PL02DW700R9AX08RDL0P0S9AL2
02@V600<02DW6@0V:1X09bTK02LY6`0V;A/092/I02@X5`0W:QT0:bhM02l`800_;Ah0;2XK0P0P8a`3
01lR6`<07R4J100M81T201hQ6P<07b8K01D08BPQ02<X8@0V:Ah0:b`N03<`7@0k=Ad0@CXN04Dl7`1I
AB80HTlW06IF9@1QE1l0Ge8N05iA9@1FBBL0C3hS030`9P0Z:R0092@J02<S6@0V9Q`00P0Y:Al00`0X
:1h0:R/M02TZ700202TZ7080:2TK0P0W:1X0200[;1h0;2dO02`]7`0/;Al0:b`N02PY6`0V9aT092DG
200U9A/01P0S9AL08bDH02<U600S9AX08R<K028S7@808R<N020092HQ02@U7`0]:Ad0>C4N048b601?
>1H0I4/S07eP=P2GOd40XXUA0:jCIP2eVG@0_9mm0;jRN`2aUVL0XHMD09N2D`2HOT/0XH1;0;6:D`2f
SU/0XGiD07QK>`1F?R80>CLZ03Pf:P0c<bL0;c4V02`]9@0X:b@08bPR028W8@P08bDR0P0Z:BD00`0Z
:B@0:b/S02/[8@0202`/800402`]7`0];B<0;2`R02XZ8080:BTO00<0:RXP02`/8P0];B<0100`;204
034]8@06034Z900b:b<0<R/S03</8P0d;R80=BlQ0P0f<2000`0i;b<0>S0T03/a9@0203`b9P0303X`
900h;R80=bdQ0080=R`P00H0=bdQ03P^8P0i;b<0>S0T03/a9@0l<RH204<f9P<0@SDU1011=2@04`0l
=240?CDR03lg9010>2D0@CTV040h9@0o=b@0?SHS04Le7`19=b40CC/U04lm9`1@?RP0CS`V04/i8`19
=b40DD4Z04lo:01>?RL00`1<?2D0101>?RL0CclX050o9@1??R@204hm8`0404ln901@?bD0DT4W05A3
:@80DSdX00@0DclW05A09`1D@2D0ED8T0P1F@b<0201Q@RH0HD<W05m49`1OARP0GDPY05e::P1KC2/0
G4d/0`1KB2X01@1JAbT0FDHX05Q59`1HABL0Ed@V0080FDD/0P1HA2/205M3:P80ET8Y00P0Dd8X0592
:01A@BP0CSlX04Xn:018?BT0ACdX04@l:@80ACXX00@0@cPV048g9@12=bD0@SLU0P13>2H01P11=R@0
@SLU04<h9014>B<0AC/R04Lm9080B3hS0P19?2T01018>bP0ASTV04Dh9@13=R<2048e8P0;03dg:@0l
=RP0>cDW03Tc9@0h<R@0=S0R03D_8@0d;R00=R`P03L]8@0i;b<00`0k<BD0100j<2@0>BlS03@`900d
<2@203<_8`<0<RhR01`0<BdQ03X/8@0k;B80?2hQ03d`800o<R40@3<P044d8@12=R00>cHR03df8`0m
=b40?3@M03hd6`16>R80DdD[05a>=02=JT00R6Ln07]M=`1ZD2d0Ed8S04`k7`1:?280BclW04Tn:P18
?BT0AS/W0P14>BD00`15>RH0AS/W04Ll:00204Y09`<0BClV00D0B3hU04Lm9017?B@0AcdT04@j7`02
04@h7P0=04Lh8@1:>BD0CS`X05<n:`1D?bh0CShT04lo9@1@@2H0DD4W05109P1??bD0CCdS04`l8P03
040e8`<0?c@R0P0n<b40>017=bL0C3/Y05=1;@1LARl0I4Xa06Q:;P1YBRd0JdX[065?9`1PCRH0GddW
05i<:01LBBP0FdPX05U69P1IARP0IDPV06U=:01`E2l0METb07QL=01gG340M5T/079G:P1oFb/0Oed]
08=Q<`24HcH0Pf@h07mR>01jGSH0N5`d06iC=@1[DC00IT`[06=99P1TBRD0IdhV06aC:P1_ERd0O5`Y
07iM:P21H2d0QV8`08]U=02@J3L0U6Xj09E[>`2?L3X0SW0j08a^?028K3d0PfPk07eT>`1gGcT0MEdg
0P1eHc<00`1hHc@0NV@e07]S=@0207iS=P09081S=`1lGcL0P6<k089U?@21I3`0OF0h07aO=`1nHCT0
PF@l0080PEli01H0P60i07eP>01kGcL0NF0g07QO=P1gH3H0NE/e07aO=`1oHSX0P6<i081S=`23IcP0
RFdm08mc@`2ENd80TgU0099h?`2CMSh0UGHo09Qi@P2LODH0Wgi8102LNdH409]jA@0309=lB02BNdL0
TGY60080TGY600`0Tga809EnBP2FOd/0W7m709f0B02NPDT0X8=;0:64C02SQTh0Y8M?0:F8D02/SE@2
0:f>E@0J0;2AF02cU5/0]YMN0;VJH@2kW6<0_9eT0;^NI02jWF<0^iiV0;bNJ02oXFd0`ZAb0<JXMP38
ZGX0d[640=FdQ`3J^H`0gkjA0>?2U@3VaIP0ilJI0>S7VP3Xbj40j/fS0>g@YP3`djT40?;EZ`<0lm2V
00<0l/nU0?7>Y03acZ@00P3`cJ<0603[bYD0i/F@0=nnR@3G]X40dk9m0=:aO03D/gh0eKAo0=:bM@3?
[g80cZie0<j]M`39Z7D0b:Ih0=FcQP3XaI/0lM6X0?KF[@3jgK<0nn2e0?SP]03gh;@0n>>f0?_V^@80
o^Ro00h0o^Nm0?cT^03hgK00lMFV0>c=W`3XbIX0h/:?0=jnR`3?/Gl0^Yi^0;6FI`2dW6h0^:1b0;FN
LP<0_JIl0P2nYgd30;nXOP80`JV300/0`ZZ40<B/QP35[HL0aZj80<N_R@38/8X0b[2;0<jdS`3C^iL0
fL:P0=g9Z0020=o<[0070=g<[P3QdKP0h]:i0>;B^@3SdkX0i=Bk0>GE_0020>KF_@80hM:m01`0hm>l
0>?A^@3Qd;H0h<ba0=k9[P3LajX0f/>T0=S1XP3F_j00d[^L0<jgV03:/i@0b;6B0<J_T03:[Hd0bJb<
0<V/RP38[8L0aj^40<JZPP35ZH40aJYo0<:WNP2mXWD0^Iia0;ZOLP30YGP0aJYm0P37[7l01@36/8T0
b[B=0=2jU@3F_id0flBT0080gLJW00<0g<BX0=g;/`3OcKD00P3Rd;P00`3Udk/0imFm0>OE_@020>OE
_@090>SIaP3Yf/L0j=_:0>WMc@3Yh=40j^;E0>_SeP3[iMT0k^WF0080knSF00<0l>OF0?;VeP3ci]H0
0P3eiMH20?;VfP030??Wf`3dj=`0mNWM0080m^[N00<0mn_O0?G[g`3ejml00P3dj]h20??Yg@80l^SL
00H0m>SL0?;Xg03bj=h0lNSO0?3Yh@3^jN<20>gZi@<0lNcV0P3bkNL30??^j0P0mNkV203gl>H40?O^
i@80n>oV0P3il>L80?O`iP/0n?7Y0P3gl>P30?K_i`P0m^gN00@0n>cL0?O[f`3gjm/0mn_K0P3fj]X2
0?GYf@P0m^[J203ejMd80?GYf@P0mNWM2@3cjMd80?G[hA00m^cR203fjnD80??/i0P0mNkX203dkND8
0?C]i`P0mo3Z403gl>P`0?G^iPP0mngS4@3fk>820?O[g`80m^[N103ejMd80?O[f`P0m^[J203ej=L8
0??Ve@P0m^GC0P3fiMD20?GTe080m>?C0P3ch]8@0??Rd100ln7;0P3bh<P20?7Oa`80l=k60P3_gLD8
0>oNa0<0km_20P3^f/430>gI`0<0kmNk0P3^e[X30>gE^@080>cB^@3]dkX0kM>h0>kE]`3]e;D0jm>a
0>S@[P3Wcj/30>W<ZP80j<^Y0`3WbZP20>S;Z`030>O:ZP3VbJT0iLRX0080i<NW0P3SaZH0103Ra:80
hL>Q0>73X@3Q`j420>32X080gl6O203Q`9l20>31XP@0gl2Q0P3N_j020>2oX0030>2oWP3P_i`0h<2J
0080h<2I00<0h<2G0=bkV03L^iP00P3M_9T30=jmVP030=nnV`3M_9T0gKbI00H0gKbI0`3O_Y/30>2o
W0X0hL2M0P3O_Y/20=jmVP<0gKbI00@0g;^H0=flV@3M_9T0gKbI0`3L^iP20=^jU`80g;^H0`3K^YL3
0=ZiUPP0f;RA403G]Y<80=NgT080fKJ@00<0f;F?0=NdSP3F/hd00P3E/X`01@3D/H/0e[>90=BaQ`3B
[hD0d:f30080cjb200<0d:f30=6^Q03A[X@00P3A[X@30=2]P`80cjb22@3>[7h40<fZP080c:Uo0P3;
Z7h30<fYM`030<bXMP3;YgD0bjMe0080bZId00<0bJEe0<RTM036XW800`34X7001`35XG40aZ9b0<>M
KP33WFh0`Ya]0<6KK030VV/00P2oVFX00`2nV6T0_IUU0;fII@060;fII@060<2MI`30W6P0`IeY0<:N
K032WVh0`iia0P34Wg<80<:NKP80aJ5a0P34X7001@33Wfl0`Yi^0<:NKP32WVh0`9aX00<0_i]W0P2n
VVH20;fII@<0`IeY:oooool002[ooooo0P2SN4D01P2UNTL0Yga90:UnB`2[P4d0[85>0:f2C`80ZX5=
00@0ZH1<0:QoB`2XOd/0Ygi:0P2VODT20:ElB0040:ImB@2WOTX0ZH1<0:Z1C@80Zh9>102[PE420:b2
DP80[H=C202/Pdl30:j5D@80[HA@0`2/Pdl20:Z1C@040:^2CP2/Pdl0[XEA0:n6DP80/8MC202]Q4h0
202_QE<0[XAB0:f3D@2/PU00[H=A0:n5D`2aQeD0/XQF0P2/QUL01@2]QeP0[XQI0:j8F@2^R5T0[hUJ
0080/8YK202`SEL80:b8F0060:b4D02[Pdl0ZX9>0:R0C02VOTX0YGe90P2SNdL04P2LN4P0VgM709Ue
A@2FLT80TVhn08eY>@28I3@0QF4a08QT=026HS80Peha085L<020Fc40P5Xc085K=P22G3L0Oe`d07iK
<`80OEXb00@0OU/c081M=@23H3P0Q64i0P21HC801023HC<0QV4d08IQ=028HSD208]R=P<0S6Hg00H0
SFLh08iX>@2>J3T0SVPi08mY>P2CJCL209AZ>00309E[>@2FK3X0UV`j00X0Ufdk00@0TfTg09AZ>02D
JSP0UF/i0P2FK3X209M]>`0809=]?P2BK3d0T6Xm08iW?02=ISd0SVM0091Y@P2AJDD2091Z>`0608mY
>P2>J3T0SFLh08aV=`2;ICH0RV@e0P2@JS/208mY>P80SVPi0P2=IcP01P2BJCD0TVPf099X=P2BJ3P0
TVLj099W?080TVLm00<0SVPi08eW>02<ISL00P2;ICH00`2=IcP0SfTj095[?00809AY?0P0TVLj0`2H
KD000`2GK3l0UV/n09EZ?@0309EZ?@@0Tfhj0P2BKCT2095/>080T6Tn00@0TFXo099[@02CK440Tfa1
0P2DKD800`2FL440UFm009A^?`0209=]?P0309A^?`2EKd00UW1100P0Tflk00<0U70l09=_>`2BKSX0
0P2BKSX00`2DL3`0UW8n09Mc?`0809=b?@P0UW8n0`2CKc/309A`?080UG4m0P2ELD4209Ib@P@0Ug=3
00@0U7<n09Ed?`2EM3l0UG@o0P2FMD0209Mf@@80W7i<00@0Vge;09YlBP2HNTP0UgU70P2FN4H0402B
Ld@0Sg1108UZ>`24ICH0PV<d085R<`23I3D0Q6Df07eN;`1hG2d0LeP]06UA:`1PC2T0ETDW05519`1=
?bD204@j8@<0@cTP0`12>1l02@0b;1`0;b`K02h[700[:A`09bLK02DW700R9AX08B@K028T5P0202<U
5`0302@V600U9aT09RPJ00809bTK00P09B`J028Y5`0S9aH09RTH02X]700];Qh0;R`M02/Y6P8082<L
0`0O8Q/301hQ6P0401`O600M81T07B0I01dP6@807R4J0`0O8Q/05@0Q9b<08RLQ02HY800[;1h0<RlL
03Te700o>1`0A3/N05A07@1NBb<0HU8Q05e@6`1LCa/0FdhR05=69019>b00<30V02XZ800T91X08b<I
02HV700202TY7`0302PX7P0X:Q`0:2XL0080:2XL0P0W:A/202HX6P0802`]7`0];R00;BhP02`]7`0Z
:ad0:2TK02DV600S91H802DU6`0602<U5`0S9AP08bDH028T6@0R8a/08R<M0P0R8ah0800T9R409BHP
02dY7@0h<1d0@30F04`e4`1QB200NE`b09In@02QR500[95T0;BHL`2lWgd0_Z9k0;6FI`2PQU<0Uh9C
09QnB`2POdX0/8UB0;J>F`2QOU@0N5/k05Hn8P0i=bX0>3HZ03<c9`0_<BH0;2dU02P[900S:2808RLQ
200S9B8202/Z9P0302/Z9@0[:b<0:b/Q0080:RXN00@0:R/M02d]8`0/;280:RXP0P0Y:Al00`0Z:R00
;2`R02d]8`05030/80<0<BdQ00H0<BXT034Z8P0b:b<0<b`R03@^8P0e;b4203H`800303H/800g;B40
>BlS0080>c4U00/0>S0T03P^8P0g;B40=2XN03D[7`0f;200=bdQ03P^8P0i;b<0>S0T03/a9@02048e
9@80@C@T1@10<b<00`0k<b00?CDR03hf8`03040h9@0=03lg900n=R<0AS@N04Tg8@1=>bD0CcdW050n
:01>?2H0BcTS04Tg8@1C@b`0DD4Z04lo:00304dm9P80CShW0P1@?bD01P1??R@0CSdS04ln901A@2H0
Dd8X05A3:@80DSdX00H0DclW05<o9P1D@2D0ED8T05E28P1F@b<206529P0605i39P1NABL0GDPY05];
:P1KC2/0Fdh/0P1JAbT205U6:00405Q59`1GA2H0Ed@V05M49P80FDD/0P1HA2/205M3:P80ET8Y00/0
E4<Y0592:01A@BP0CSlX04Xn:018?BT0ACdX04@l:@16>bT0A3TW048g9@0203ld8P08040e8`12=bD0
A3TW04Hk:@15>RP0ACXV04Dj9015>b8204Dk800D04Dl7`1<?b`0Bch[04Tl:@17>RL0ACPU04<f8`12
=B80@C@Q03dg:@0l=RP0>cDW03Tc9@0h<R@0=S0R03D_8@0d;R00=R`P03L]8@0i;b<303/a9@0403X`
900i;b<0=30T03@`9080<blS100b;R801P0l;R<0?2hQ03d_8P0n<B40?c8Q040c8080@CDO01<0>C@P
03`e8P0l=R00?3@M044g7P1<@2H0GU0f06]M@P2]R5`0XGiD08][A01]Dbh0E40O04Th701:?280CT8Z
04Xo:`18?BT0AS/W0080A3TU00<0ACXV04Hk9`17?2P02@1=@bP02`13>Qd0@cPL04@h7P17>240BSTU
04hl:01C?Rd0ED0_04dm8`1>?R@0CclU0080D40V00<0CclU04dm8`1<?2800`10=B<203ld8P<0?S<Q
0300Bc/[050o;`1HAS80HD/f06U?>01]CcD0KTlb06m=<@1OD2L0GTlV05e>9`1KBbL0FTXX05Q89`1G
AbH0ETDW06I99`1ZCRT0LED`07MK=01iGCD0Me`a07=H:`1`EBP0PEd]081N;P23HC<0Pf8e089S=`1o
HSP0Nelg07YN=P1]E3D0JU4b06E=:`1RBRH0HTXT06E>9@1ZDbX0KUL]07eL:@1oGR/0Pel]08QR<@2>
ISD0TVXi09E[>`2GKCd2091a>`0608i`?P2:KSl0QFXm07mV?@1kHC`0Meli0P1gICD00`1jICH0NfDf
07eU=`0207mT=`03081S=`1kGSH0OV4i0080PF@l00@0OV4i07eP>020Hc/0Q6Lo0P1nG3H05P1lG3D0
NE`d07MK<`1dFc80LeXa079K<@1fF380NE/e07eP>01oHSP0P6<g08AX>@2;Kd00TWI609V0A`2FOD@0
U7Y109Ag?`2FMd00VGY309mnB02RPD/509akAP<0VgY500P0TGa7091kAP2?NTD0SgY5091kAP2BODP0
U7m:09F0B`80WH1800L0WX590:23B`2RQDd0XhI>0:B7C`2UR500[HmC0080[Y1D00@0/99F0;:DF02e
Ue/0]iUM0P2iVel03P2fVEd0]IQN0;FHGP2eV600]iUS0;ZLJ02mWfd0_j5_0<VYNP3<[7d0dK620=Rh
R@3M_Hh0h<2A0P3R`Y<01@3WbZ00jLbR0>c?Y@3_dZP0lMBZ00<0l]F[0P3bcjL20??@Z00L0?CAZ@3e
dZX0mM:Z0?GBZP3`ciX0j/VD0>;1S03J^H@0eKAo0=>bO@3E]7l0e[F00=>cMP3@/7<0cjmf0<j]M`39
Z7D0ajEg0=FcQP3Wa9X0k<bS0?;BZ@3ef:h0m]^`0??K[`3bfjl0m=nb0?OR]@80o^Ro00h0o^Nm0?cT
^03hgK00lMFV0>c=W`3XbIX0hL6>0=jnR`3>/7h0^Yi^0;6FI`2dW6h0^:1b0;FNLP80_JIl0`2nYgd3
0;nXOP80`JV300@0`ZZ40<B/QP35[HL0ajn90P38/8X0203:/8/0c[B?0=BlV03J`j40gLVX0=o<[03P
cJd0gLb^0P3Rd[T00`3SdkX0i=Bk0>GE_0020>KF_@0A0>OG_P3Qd[d0h]>n0>?C_03SdKT0hM2f0>3<
/@3NbJh0gLR[0=[3Y03H`J80e[nP0=:kW03>]iP0b[>D0<RaTP36[i000P3:[Hd04`39[8X0b:b70<N[
Q036ZX80aJV10<FZO`32YgX0_Z=f0;ZOLP2kX7<0`JIi0<N/O`39[X40b:f00<J`R@3:]8d0d;ZE0=Jo
W@3Ka:@00P3MaZL00`3La:P0gL^c0=o=]@020>;@^0030>GC^`3WeKd0imFm0080imFm00T0j=W60>WJ
a`3XflX0jMg=0>WPd@3Zh]D0jn?F0>_Uf@3^jMH00P3_j=H00`3`imH0l^KF0??VeP020?GUeP80l^KJ
00<0lnOK0?CXg03ejMd00P3fj]h00`3gjml0mN_O0?G[g`020?CZgP80lnWM0P3bj=`01P3dj=`0l^SL
0?;XgP3aj=l0l>WQ0>kYh`80kN[U0`3ak>H20?;]i`<0lnkX203ek^H80?Oai@040?K^h`3gkn@0mnoT
0?O_i080n?3U0P3ilNH80?Oai@X0n?7Y0P3gl>P30?K_i`030?G^iP3fkMh0m^gN00H0m^gN0`3fjmT2
0?GZf0<0m>WG203fj]X80?CXg0P0m>WG203dj=`90?;Xg0P0mN_Q403fk>880?K[i@P0lncT203ek^P8
0?C]i@P0m>gW203gl>X@0?O`j300mNkV203gkN<A0?K/hP80mn_O0P3fj]h30?GYg@030?CXg03gjm/0
mn_K00H0mn_K203fj]X80?GXe`P0lnKE203fiM<20?KUe@80mNCD0P3dhm<20??RdQ00ln;@403chL/2
0?;Pb080lMo70P3`g/H20>oMa@P0kmk40`3^f/420>gI`0<0k=Ro0`3_ek/20>kF^P<0kMFi00P0k=:i
0>gC^P3]dkP0k]Fg0>gD]@3[dk40j=2^0>O?Z`<0jLbZ0P3XbjT30>O:Z080j<^[00<0ilZZ0>K9Z@3U
b:P00P3TajL20>?6YP@0hL>Q0P3P`Z020=o1W`<0h/6P0P3Q`9l30>2oWP030>31XP3O`:40gl2Q00@0
gl2Q00H0g[nP0=nnW`3O_Yl0gkjM0=nnV`3O_iT20=noV0030=noUP3L^iP0g;^H0080gKbI103N_IX8
0=flV@<0gkjK0`3P_i`:0>70W@040=nnV`3N_IX0g[fJ0=jmVP80gKbI0P3L^iP30=flV@80g;^H0`3K
^YL20=bkV0<0fkZG0`3J^IH80=RhTA00ekJC203G]i020=VfT0040=ReS`3G]8h0e[>=0=FbS080e;6;
00@0e[>90=BaQ`3B[hD0d:f30P3?[8800`3@[H<0dJj40=6^Q0020=6^Q0<0d:f30P3?[8890<j/OP04
0<j[P@3=ZX00cJZ00<fZP080c:Uo0P3;Z7h20<jZN0040<fYM`3<Z7H0c:Qf0<^WM@80bZId00<0bJEe
0<RTM036XW800`34X7002035XG40aZ9b0<>MKP33WFh0`Ya]0<6KK030VV/0_iUZ0P2nV6T80;fII@06
0<2MI`30W6P0`IeY0<:NK032WVh0`iia0P34Wg<80<:NKP80aJ5a0P34X7001033Wfl0`Yi^0<:NKP31
WFd40;nKI`80_YYV0P2mVFD30<6MJB_ooooo000Zooooo`080:MnBP2VODT0YGa80:AkA`2UO4P0Ygi:
0:Z1C@2[PTh20:QoB`<0Ygi:0`2VODT30:MnBP80Z7m;0`2YP4`80:UoC@80Zh5A00@0Zh5?0:^2CP2[
PTh0Zh9<0P2[PTX20:ImB@80Ygi:0P2XOd/20:V0C0P0[89B0P2_QU80102^QE40[HA@0:f4D02/Pdl5
0:^2CPD0[8=?00@0[HA@0:j5D@2^QE40[hIB0P2`Qe<0202aR5@0/XUE0;>:EP2cQE@0/XAC0;24D`2^
Q580[HEB0P2ZQE406@2XQ500[h=F0:n3EP2^PUD0[81C0:]oDP2ZOU40ZGe@0:QlC`2NNTX0Wg];0:5m
C@2ROTh0XGe=09mkB`2MNDT0W7Q8099_A@2AKT@0Sfa208]X?P28IC/0Q64g089O=@20GC<00P1oHBl0
1P1nH2h0OEl]07aN;01lGR`0Ned[07YL:P@0OEX`101lFBl0101nFB`0P5/^08AO<P27HSD208QS=P08
08MR=@25H3<0RF@g08UU=@2:ISH0RfLe08]W<`2<JC<208eZ<PP0Ufdk0P2AK3P0102BKCT0Tfhj09=^
>P2DKc/209E`?0<0UV/n0`2EJSd209AY?0P0UFTl00@0TfTg09AZ>02DJSP0U6Xh0P2EJcT209I/>P<0
T6Dh00<0TFHi099W>P2CJ3/00P2CJ3/00`2AJc`0T6Xk08iX>@0208eW>00308iX>@2@JS/0TF/l00P0
SfTj0`2@JS/2095[?0<0TV`m00d0U6Xh09=Y=`2AIcD0T6Hd095W=@2CJCL0UF/i09I/>P2BK3l0TV`m
09=]?P2CKC`0U6lk0080U6lj00<0U6lh09E`>@2DKc/00`2DKc/409=^>PP0TVdi00<0VFlm09Q^?02F
K3X00P2EJcT00`2FK3X0V6hl09U_?@02095/=`04099]>02CKST0U6lj09E`>`80UW4l0`2CKc/309A`
?080UG4m0`2FLSh209Ea?@<0U70l00P0VWE109Qc?`2EL3`0TVdi095/>02BKCT0U6lk09E`?0P0U70l
0P2HL3d0102GLSh0UW8n09Ib?P2EM3l209Ae?`80U7920P2ELd<209IdA080UgE50P2FN4H209EgA@@0
U7I400H0SG5108Y^?P27Jc/0PVHf07mS<`1mHC4207aP<00F07QR<@1dGc00KUT^06A@:`1KB2P0DD0V
04Xj8`17=R80?cLR040h8`11>B@0@SXU044i900o=b80?CDP03`d7`0^;1d0;B/L02X[7@0X:Qd09RPM
02@W7P808BHO00P08RDJ02<V6`0T9a`09BPM02HY7P0W:Ql0:2/P02T/8@80:BhJ0P0Z;a/302/`7006
02`a7@0S9Ql08RDN01lR6`0M81T071lH0P0M81T01`0N8AX06QdF01/N5`0L7aP07B0I01hQ6P0O8Q/0
0P0P8a`05`0Q91d082@F024U5P0U:1L0:R`G034a6@0i=ah0?SdO04=08@1@@1l0FDTX05e=;01JBRT0
FDTX05];:P1FARD0CCdL03H_9`0]:B009R8I028O5P0S8aT09RPM00809RTN00H0;RLO02`X7`0/:1l0
:RLN02PX7P0W:Ah202DX7@0302DU6`0V9Q`0:2PN0080:BTO00<0:2PN02HV700U9A/00`0S91`3028S
6`808B8J0`0S8a/2028R6P<08B4I01d07B<G01lR6`0V9B40<b/X03/^9P16=B40GDXY07=P=P2FO4<0
XXM@0:fBF`2dVF@0_:1^0;nSL`2dV6T0YHUJ09J0D@2HO4X0X7m:0:j9DP2bSUX0Vga@06mH=P19>Q/0
<S@Y030b9`0];RH0:BXT02LX8`0202DU8`0302DU9@0T9R<092HS00H092HS2P0V9b4302LX8P<0:2TS
0100:2LS02TX900Y:2<0:RXR02/[8@0/;200;BdQ02d^800b;200<bdQ03D_8`0f<2@0=c4U03H`900e
;b<0=2hR0P0g<BD00`0f<2@0=BlS03@^8P0203<]8@08038/800/:1d0;BTN034[7`0e;B00>C0Q03hb
8P11=2@3048e9080@C@S1@10<b80200n<b40?c8Q040c8P13<b<0AC@T04Ld9@19<bD0BS@V0P1;>b@2
04`l9@0504dm9P1>?RL0CclX04lo:01??BD00P1@?RH00`1A?bL0DT0X05=1:@0205A2:P<0CShW1@1?
?bP0201>?bX0Bc`W04Ti8P1=>b<0E4<Y05U5:P1G@RL0E3lR1`1MARL00`1NAbP0DdHV05=69P0205A7
9`0405=69P1BABD0D4<S04m28P80Ed8S00@0ET<U05A39`1D@bT0DT8Y0P1A@R/0201C@RH0DT4U0550
9P1@?RH0CS`V04dk9`1<>RH0C3TX0P18>bP01P17>RL0ASTV04@g9013=R<0@SDR044d8@@0@SLU0`13
>2H00`14>BL0@3LV03lf9@0203he9080?3<R00l0>c8Q03Xa800j>2<0>CHS03Pe8P0f<b80=34R038^
8P0a;B80<2`Q03<W6`0d:1`0=RXN03P/800j;R800`0k;b<03P0f=bT0=3DW034b900_<280;RlQ02l`
8P0`<B<0<C8T03H`900g;b80>C4T03`c9010=2@0@cHU0P17>2D06014=bL0@3<S03`_7P0l;a`0@cLQ
0514;01NDSX0Ie]10:J6G`2DMU80NEll05i9:P1=?280B3`T04]3;P1?B3D0B3/Z04Lj:@15>2D0A3PR
04@h8015>Al0Ac/Q04Pm8@<0DT8Y01H0DD4X04lo9P1=?B@0C3`S04/k8P1:>R40A3`U04Dj9013>280
@cLQ04Hg8P1;>RH0DCl[05A2;P1=?280C3`R04`l8`1:>b@0B3`V04Ll:015?BP0ACdZ0P0i=2404@0h
<b00=c8O03Lb7`0g<Ql0>3<P03Td8@10:Ql0DC/^05a7=P1IABd0F4DW05e99P1MBR80ET<I061:8@1R
C2<0HddV0080IDlZ02<0I4d[069;:`1QBRX0IDHW06Q9:P1[CB/0JT`X06Y<9P1^DBT0MEP`07]N=026
Fbh0Rf<`095]<`2BLSD0SW4g08=W=@1fGCD0KE@e065=:P1RCR/0IDlZ06M?:@1YD2P0KE4Y06iB:P1_
DRP0P5`h08AQ>`27ISd0R6Lj08EW=@25JS<0Rg8i099j?P0208a^>00H08U]>`27K3d0PVXl07iW?@1j
I3d0NF<l07aU?01jHCT0N5lf07aQ=P21I3P0QFHh08AS=P21HC80Pf<b08EU=026IcP0Q6Pi089W>P1m
ICT0NF0g07EN=01fFc00Me`a0P1hGC806P1gG340M5T^079G;01`EBX0Me/f07UM=P1lH3P0Of@g08=X
>@27KCX0RW4k08]b>P2<N3/0RW@h08Qb=P2<M3P0TgTn09Ul@P2KO4<0VW]209Eh?P2HND80W7e60:1o
BP2TP4h0YX1A0P2WOU004@2JO4H0V7Y609AiA02BN4D0T7U7095kBP2DOTl0UH1A09QjB02INdT0Vge;
09eoC@2OPDl0XXAB0:>5D`2TQU@0YHUG0080ZH]I00@0[8iJ0;6AGP2eU5l0^9EO0P2jUEh40;VGF0@0
^9IG00d0`YmY0<FRK039YW00cZ]e0=FbO03K^880h;f70>?0RP3PaIP0hlRK0>K;WP3Zcj80kM:U00<0
k]>V0200lm>T0?3?XP3_d:80lmJZ0?[O]03mi;/0nn:j0?OP]`3kgkP0mMVa0>g@YP3UaYP0g[j=0=Zi
Q03I^880f[Mo0=FeNP3D]7T0d;1g0<ZYL`37YW00bjYe0=FdP@3M_8T0im6P0>SBX@3Ydj80j]BS0>cF
Y@3^f:L0kmVX0?3JZ@<0nmb^01/0n=V[0??DYP3]cZ00i/NI0>;3U@3J`8D0fl660=2fO@2lXFX0/9EP
0;6EH`2eVFL0]IUY0;JPL@2gXG80^:9c0;VSM02kYGH0_JMh0;jXN@2oZGX0`JZ00<:[P@33[880a:f3
0<F^Q036[hD00P37/8H0203<[XX0ck>>0=JiU`3L`Z40h<NX0>;;[03Qc:d0hLb_0P3QdKL20>;B^00J
0>?C^@3Te;X0iMFk0>GE^`3Td[X0iM>k0>CB^P3SdKT0hLng0=g;/`3Jb;00f<J^0=NoX`3F_Z80eKfQ
0=:jWP3@^9`0c[JJ0<bdV03;/iL0bk:C0<ZaTP39/Hl0ajn;0<J^RP35[HL20<B]Q0060<:VO`2nXW/0
^Yig0;bPN@32YWl0b:b50P3:[XL02P3>]940dkVH0=NoW@3H`J40eL2Q0=K3Y@3Kaj`0g/fa0>;=/03S
c[<20>GA]P050>KE^`3Xe[h0j=S10>OH``3Vel800P3ZfLl01P3Zg=40jmoC0>[Pe03[hmH0kNGH0>cV
f0P0l>KJ0P3aim/20?;Xg0@0lnWM0P3ejn420?CZh080lnWO0P3bj=h20>oXh080l>WQ103aj^820?C^
hP<0mNoS0`3fl>@0103jl>H0nNoU0?W_i@3iknD20?S^i080mngS00H0m^k[0?K_j@3fknT0m^oW0?K_
i@3fl>@20?K`hP040?[ahP3il>40nO3Q0?W`h@80n>oP2P3gk]l80?W]g@040?[^gP3ikMd0nNgM0?W]
g@80n>cL0P3gjm/80?GZePP0mnKD103ej=L40?CWePP0l^GD0`3aiMD30?;VeP80lnOG0`3biMD30??V
eP80m>OG0P3cim/40?CXg0<0mNWM203ejn480??]h@P0mN_Q203ek=d@0?G[hA00l^_S203`kN@80?C]
i@P0mo3X203hk^D80?K/h`P0n>kU403gkN@80?O]ha40mN_Q203djm`20??Zf`80l^WJ0`3aj=T00`3`
imP0mn_K0?KZfP020?KZfP80mNWI0P3dj=P80?SWe@<0n>OG0P3gi]H;0?KUe@040?OUd@3fi=00m^C@
0?KTd080mN??0P3dh/h80?GSc@P0ln7;0P3eh<d20?COc0<0lmk;00<0l]g:0??Qc@3chLd01P3chLd8
0?;Pc0040?CObP3cg/T0lmk90??Nb@80l]g80P3ag<L30>oOa@80k]k40`3]gL<20?3M_`80kmbn0`3^
fkd0103]f[`0l=Ni0?3G^@3`ekT20>oF^0<0k]Fg00H0k=>e0>_B]03[d[@0j]6c0>W@/P3Xck420>O>
/0<0ilZZ0P3VbJT30>G8Z080j<^[00<0ilZZ0>K9Z@3Ub:P00P3TajL20>?6YP<0hl:O0`3R`Ih40>70
W@<0h;nL0`3O_Y/80=k0W0P0gkjK203N_YL80=nnV`P0h;nL0P3Q`9d20>2oW0@0gkjK00<0gknH0=jn
U`3L_9D00P3K^i@00`3L_9D0g[jG0=noV0020=jkU@80gKZD103L^I<80=ViTP<0f;RA0P3G]i030=Jf
S`P0eKF>203G]i020=FeS0040=JfS@3G]hh0ekN>0=RhS`80fKV@0`3F/h/50=FbRP<0dJj40`3@[H<2
0<n/PP030<j[P@3?[880d:f30080dJj400H0cjb20<fZP03<ZGl0cjb20<fZP03<ZGl20<ZWO@0<0<bY
O`3=ZX00cJZ00<n/PP3@[8P0cj^70<fZQ03<ZH40c:Uo0<f[OP3>[7l0cjeo0P3<Z7P0103;YgL0bZIf
0<VUM@38Y7@20<NSL`080<VUM@38Y7@0aZ9b0<BPL033Wfl0a:1`0<JRLP37Xg<20<>OJ`030<:NJP31
WFT0`9aX0080_i]W00@0_YYV0;^LI@2kW6D0_9]U0P2nVfD0302oVVD0`IUU0<6II@2mVV@0_IUU0;jJ
IP30W6X0`Yi^0<>NL@34Wg<0aJ1d0<6NJ080`IeY00<0`Ie[0<6MK@30Vfh00P30Vfl01031Wfl0`9i^
0<2NKP30WVh20;nMK@80_Ya/0P2mVf/01P2lVVX0^iUY0;bJJP2nW6`0`9i^0<6OK`<0_9e^:oooool0
02[ooooo00<0Z7m;0:MnBP2UO4P00P2UO4P00`2VODT0Z7m;0:Z1C@020:QoB`<0Ygi:0`2VODT30:Mn
BP80Z7m;0`2YP4`80:UoC@80Zh5A00@0Zh5?0:^2CP2[PTh0Zh9<0P2[PTX40:QoB`80ZH1<0P2ZPDd8
0:b2DP<0[XEA0P2]Q5030:b3C`@0Zh9>1P2/Pdl20:f4D080[XEA00<0[hIB0;27D`2`Qe<00P2`PU40
0`2^PU40[H=A0:^3D0020:V4D00;0:R4D02/PE@0Zh1C0:YoDP2YOU40Yga?0:IkCP2UNTd0Y7U<09ei
B@2NNTX00P2ONd/03@2NNTX0W7Q809UeA@2HM4@0Sfa208i[@@2<JCl0RFHl08IS>@23H3H0PEhd081M
<`1oHBl00P1nH2h00`1mGbd0O5h/07]M:`0207YL:PD0O5T_0`1mFS001@20Fbh0PE`_08=N<@25H3<0
QV4d00<0Qf8e00H0RF@g08UU=@2:ISH0RfLe08]W<`2<JC<208eZ<PP0Ufdk0P2BKCT209=^>P0409A_
>`2EL3`0UG0l09E`?0<0UV/n0`2EJSd:09AY?080TVPf0P2CJCL209AZ>080UF/i0P2@ICP2095V>@80
TVLj0P2CJ3/00`2@JS/0SfTj08eW>00208aV=`0308eW>02?JCX0T6Xk00P0SfTj0`2@JS/3095[?080
TV`m00<0U6Xh09=Y=`2AIcD00P2AIcD0202CJCL0UF/i09I/>P2BK3l0TV`m09=]?P2CKC`0U6lk0P2D
KcX209A_>0@0U6lk102CKSX8099]>@0309Q^?02GKC/0UF/i0080U6Xh00<0UF/i09M]>`2HKS`00P2A
K3L0102BKCP0Tfhi09A_>P2EL3/209Ia?0<0Tflk0P2DL3`309Ea?@<0UW8n0P2ELCd309A`?00509Mb
?P2FLCd0UG0l09A_>`2CKSX00P2DKc/00`2EL3`0U70l09A`?00609A`?080V70m00@0Ug8n09Ib?P2F
LSh0UG@o0P2DMCl209Ab@P80UG=30P2FM4@209MeA@80UWQ60P2EMdD309AfA00709=e@`2=LD40RVhn
08M[>`22ISH0Of<c07eQ<@0207aP<00:07MQ<01cGRl0KEP]06A@:`1KB2P0DT4W04`l9@19>2@0?cLR
040h8`<0@CTT0140?cLR03de800k<ah0;R`M02d[700Z:ad0:2XM02HX7@0T9ah08BHO020U7P0Q91T0
8RDJ02<V6`0T9a`09BPM02HY7P0202LZ7`<0:2dI0P0Y;QX302X_6`0502<V7`0R9Ah07b8K01dP6@0L
7aP00P0M81T01`0N8AX06ahG01/N5`0L7aP07B0I01hQ6P0O8Q/00`0P8a`02`0P8aP08BDG02DX5`0Z
:aT0<C0K03Pf7@0m?200@clR04m07`1GB2L0Fd`[0080F4TX00T0FT/Z05E69@1<?A`0=RlW02dY800V
8QT08QlF02<S6@0V:1d00P0V:Ah01P0^9al0;2PO02`X7`0Z9ah0:2PN02HX7@809BPM00<09BDK02HV
700X:1h00P0Y:Al00`0X:1h09RHL02DU6`0302<T70808R<K0`0Q8QX302<S6`808R8J0`0Q8AT07@0M
8aL07b8K02HU8@0b:RL0>RdU04Dd801LBBP0Lf0f095g?P2LPDX0YhaE0:jCGP2fVVP0^Ie]0:nCI02Q
QEH0UX1A09QlBP2POdX0[XUB0;:>FP2LOE40KePf04Tj6`0b=2T0<38W02`]9@0Y:R@09RLR00809BDS
00<09BDU02@V8`0T9R<01P0T9R<;02HW8@809bPR0`0X:B<02`0X9b<0:BPT02TX8`0Z:R80:b/Q02`/
800];B40;BhP038/800c;B40=BlS0080=c4U00<0=S0T03D_8`0d;R800P0g<BD00`0f<2@0=BlS03@^
8P0203<]8@09038/800_:b00<2`Q03<]8@0g;b80>S4R03hb8P11=2@0@SDT0080@cHU0`12=B@4044d
8`0603hc8@10<b80@3<R04<c8`15=2@0Ac@U0P1:=2H01P1:>R<0Bc/T04/k901<?2D0CCdV04hn9`80
CclX0`1A?bL30590:080Dd4Y0P1=?BH604hn9`0904ho:P1;?2L0BSXS04hl901C@RP0F4@Y05M29`1D
?b80G4DV00@0GDHW0`1NAbP00`1EB2P0E4LW05=69P0505959@80F4<T00@0Ed@V05E4:01D@bT0Dd<Z
0P1B@b`02@1A@RD0DD4W05109P1??bH0CCdV04`k9`1;>RP0BSTW04Lj9`0204Hi9P0504Dh9@14=b@0
@cHS04<f8`12=B802010=bH203lf9@0403he900m=2<0?C@S03`c8P80>c8Q00`0>SPS03Tf8`0h=B80
=S<R03@a8P0b;R80<BdR030/8@0d:Qh0=R`P03T_8`0l<RH303dc9`0703`b9P0e=RP0=3DW034b900_
<280;RlQ02l`8P02030a8`0P03D_8`0g;b80>C4T03`c9010=2@0@cHU04Lh9@18>BH0AcXZ04@g9`10
<b80?S4N048f801;?bL0EDTa05a@=P21Hcl0N5`g06M?;@1G@RD0Bc/Q04Di8@13>bH0A3dZ04Pk:P17
>RT0ACPU04@h8P14>200ACTQ04Lk8@18?28305109`0304lo9P1>?RD0CCdT0080C3`S0240Bc/R04Ll
9P15>R@0ACTS04@h8P17>2<0C3/W054o:`1D@Rh0D3lU04hn901>?RD0C3dV04Tm9`17?2P0A3`W04@l
:@12>bT0@3TW03hg9@0k=280>S<Q03/d8P0l=B<0?CHT04/g;01H@SD0FdHe05E1:@1E@2<0GTXW06AA
:@1TDBL00P1XDRT05P1XDR/0Ie4/06E?:P1RBbT0GdPX05e69P1SA2D0IdPY06]=:`1/CRX0K4hX06mB
:P1eF300NUdc08IK;P2:HRl0T6`b099b=@2?LSP0Q6Xg07QO=`1`EcP206A@;@0>06MA;01YDB/0Je8Z
06eA:@1^DRX0Ke8X07YF<P1mFcD0PF0g089Q=021Hc40PVL`08U_=P2?MCX208ma>`0F08a`?P29KSl0
Q6`n07mX?P1kICh0NF<l07AM=01cFS80LEP_07IK<01lGc<0P64c081O<P1mGBh0PV8a08AT<`26IcP0
QFTj08=X>`1nISX0Nf8i07MP=P80MU/`0`1hGC80;01fFc00M5T^07=H;@1jGSL0Nelh07eQ>@20ICP0
PfPi08I/>@28KcT0RG0j08Qd>@26L3H0Q6hd08U`=`2@MSd0UgY209Uj@`2HND80VWe509]nAP2NOdT0
XH1;0:=oC@2SOD`0XWa=0:=jC02KO4H0VG]509QjAP2ENDL0U7Y909=kB`2COD`0Tge>09MiA`2HNTP0
VG]909anC02NP4h0X89@0::4DP2SQE<0YHUG0P2YReT01P2]Se/0/I9L0;BCG@2hUEd0^IAM0;VEF`@0
^9IG102gUEH03P2mVV80_iaT0<>PJ039YVh0cjad0=BaN@3I]Wh0fkR00=_0T`3N`iH0h/NJ0>K;WP3Y
cZ40jm2S0P3/dJ@0603cdj@0lM2S0?7BY03ef:`0o>6f0?kU_03lhk/0n>6h0?gQ^P3gfk<0km:X0>S9
V`3Q`I00gKb70=ZiP`3K^800e;Ai0=>cN03@/7L0bZUc0<NVL03:ZG@0dk9o0=^jQ`80i<bL01`0i/jN
0>S@X03ZdZ80k=BT0>kFYP3_ejL0n=V[0?WJ[03hfJ/0m]NY0?7BY03[c9h0iLJH0>72U03H_X<0fKn4
0<jdN`2jWfP0[Y=N0;2DHP2dV6H0/iMW0;FOL02fX740]j5b0;RRL`2jY7D0^jEf0P2mYgP20<6XO`04
0<:YP034Zh80aJb30<J]Q080ajj500T0c:j:0<ncSP3F^IL0fl6P0>37Z03Rbj`0hLb]0>7<[`3Pd;H0
0P3QdKL00`3Rd[P0hm>i0>CD^P020>GE^`<0i=:j01/0hm6i0>3>]P3Mbk<0f/R`0=S6[P3G_j<0e[jR
0=FmX@3B^Yh0d;RL0<jfVP3<]9P0bk>G0<^bT`3:/I80bK6?0<R`S036[XX0aJf70<B]Q033[8<0`ZIo
0;fQNP2jWWL0_:1i0<:VO`38[8D00P3:[XL02P3>]940dkVH0=NoW@3G`:00eL2Q0=K3Y@3Kaj`0gLb`
0>;=/03Tck@20>GA]P030>KE^`3Xe[h0j=S10080imS300P0j]W?0>_Jd03Zg=40jmoC0>_Qe@3[hmH0
kNGH0>gWf@P0l>KJ0P3aim/20?;Xg0<0lnWM00<0m>[N0?G[h@3ejn400P3dj^020??Yg`80l^SN0P3_
j>020?3Yh@<0lN[R00<0l^_S0?C^hP3dk^800`3ekn<30?K`i0@0nNoU0P3hk^@20?O]h`80mnkY00<0
mnkW0?O^i@3gkn@00P3gkn80103gl>00nO3Q0?W`h@3il>420?S_h0<0mnkO203fkMh:0?W/g080n>_K
0`3gj]X00`3fjMT0m^WF0?KYeP060?KYePP0m^GC0`3dimH50??Ve@P0lNCC0`3aiMD30?;VeP80lnOG
0`3biMD30??VeP80m>OG0`3cim/30?CXg0<0mNWM203dj]h80??[gPP0m>[N203djm`@0?CZgQ00ln[S
203akN@80?G/i@P0n>oX203gkN<80?K/hPP0mngS403fk>880?O]hA40m^cP203djm`30??Zf`80l^WJ
0`3aj=T30?OZfP80m^WI0`3ej=P90?SWe@<0mnKD0P3fiM<:0?GTdP<0m^C@0P3ehll30?CRcPP0mN?=
203chL/0103eh<d0m=o<0?COc03dgl`20??Nb`80l]g:203bh<`80?7Ob`<0lmk90P3bgLP30?7La`<0
kmo50P3^g/@30>gM``040?3M_`3_g;h0kmbn0>oL_P80k]^m0P3]f[`20?3G^@80kmJh0`3^eKL00`3]
e;H0k=>e0>cC]@020>_B]0040>[A/`3Yd;80j<na0>S?/@<0j<^[0P3WbZX30>K9Z@050>S;Z`3WbZX0
ilZZ0>K9Z@3Ub:P00P3TajL20>?6YP<0hl:O0P3R`Ih50>70W@<0h;nL0`3O_Y/80=k0W0P0gkjK203N
_YL80=nnV`P0h;nL0P3Q`9d20>2oW0<0gkjK00@0g[fJ0=noV03N_YL0g;bE0P3K^i@00`3L_9D0g[jG
0=noV0020=jkU@80gKZD0`3L^I<00`3K^980fKVB0=ViTP060=ViTP<0f;RA0P3G]i030=JfS`P0eKF>
203G]i020=FeS080e[J=00@0ekN>0=RhS`3H^8l0f;R?0`3F/h/40=FbRP040=BaR@3A[X@0dJj40=6^
Q0<0d:f30P3?[8800`3>Zh40cjb20=2]P`020=6^Q0060<n/PP3=ZX00c:Uo0<j[P@3=ZX00c:Uo0P3;
Z7h0303<ZGl0cJZ00<fZP03>Zh40d:b80<n/QP3=ZX@0c:V10<^XOP3<ZWd0cJ]m0<j/OP80c:Qh00@0
bjMg0<ZVMP39YGD0b:Ad0P37Xg<00`39YGD0b:Ad0<JRLP030<BPL080aZ9b0P33Wf/01032WVX0`IeY
0<2LJ02oVfL20;jJIP80^iaU00@0_9]U0;jKI@2nVfD0_iYU0P31VFD01P2nVfD0_YYV0;nKI`30W6X0
`Ie]0<:ML080`iib00H0`IiX0<6MJ@31WFT0`Ie[0<6MK@31W6l20<2KK`@0`Im_0P30WVh20;nMK@08
0;jLK02mVf/0_9YZ0;^IJ@2lVVX0_Ya/0<2NKP31Wfl30;bMKR_ooooo000Zooooo`050:V0C02XOd/0
Ygi:0:ImB@2UO4P00P2VODT00`2WOTX0Z7m;0:QoB`030:MnBP<0YWe90`2WOTX20:QoB`<0ZH1<202Y
Odd20:^1D@040:^1C`2[PTh0Zh9>0:^2C080Zh9:00@0ZH1<0:Z1C@2ZPDd0ZX5=0P2[PTh20:b3C`P0
[89@0`2/Pdl20:f4D0<0[XEA202[PTh40:Z1C@@0Zh9>00H0[8=?0:anC@2/OTd0ZWi=0:Z0CP2YPDh2
0:N2CP070:N3C`2WO4l0Yga?0:IkCP2TND`0XgQ;0:5fB@020:1eB0<0VgM700h0VWI609QdA02FLT80
U710099^?P2:Icd0RFHl08QU>`26HcT0Q64g089O=@21GS@0P5dc07iO<080OEh_00<0O5d^07]L;@1j
Fb`00P1iFR/207YG;@0407]H;P1lFBl0O5T_07eJ<080OU/a1022GC000`24Gc80QV4d08QS=P0208UT
=`0508UU=@2:ISH0RfLe08]W<`2<JC<00P2=JS8809M]>`<0U6lk0P2EL3`309Ia?@<0UV/n0`2EJSd:
09AY?0<0TFLe0P2BJ3H309=Y=`04091U>02AIST0TFHi095V>@<0TVLj00@0TfPk08mY>P2>J3T0S6Hg
0P2;ICH00`2<ISL0SVPi08mY>P0:08mY>P80T6Xk0`2AJc`00`2BK3d0TfTg09=Y=`03099X=P0409=Y
=`2EJcT0UV`j099/?`80TV`m00@0Tfdl09=^>P2DKcX0U6lj0P2DKcP409=^>P@0U6lk202BKCT00`2F
K3X0UF/i09AZ>00209=Y=`0309AZ>02EJcT0UV`j0080TF`g00@0TVdh09=^>@2DKcX0UG0k0P2FLC`2
09=_>`80U70l0`2ELCd409Ib?P80UG4m0`2DL3`209=^>P0609E`?02FLCd0UW4m09Ia?@2EL3`0U6lk
202DL3`209Q`?@0409Mb?P2FLSh0UW8n09Ed?`80U7Do0P2DLT8209Ec@`80UWA40P2GMDD309EgA@80
U7I40`2CMD<01P2=LD40RVhn08M[>`22ISH0Of<c07eQ<@80O60`00P0MEl^075L;@1/Eb`0I50[05a9
:@1D@bT0CShW04/j9P80@3PS0P11>B@01010>2<0?SHQ03`d7`0k<ah202d[700602X[7@0W:A`09RPM
02@W7P0Q9Ql082DN0P0P8aP00`0Q91T08RDJ02<V6`0202@W700402DX7@0V:QT09RXI02HZ6@809b/J
0`0X;1/01@0S9Ql08RDN01lR6`0M81T071lH00807B0I00H07R4J01/N5`0L7aP071lH01dP6@0N8AX3
01lR6`0<020S700P8aP08BDG02@V600Y:QP0<2lJ03Le7P0l>al0@CdR04ho7P1GB2L0Fd`[0P1HBBP0
5P1JBbX0EDHU04`m700g<2P0;RXQ02HR6@0R7aH08b<I02DW700V:Ah09BPM02hW7`0/:1l0:bLN02XW
7P0W9ad09RPM02DX7@0T9a`09BDK02HV700W9ad202PX7P0302LW7@0V9Q`09BDK00808b@L0P0R8a/3
024R6P04020Q6@0S8a/08b<K02<S6`808R8J0`0Q8AT07@0M8aL07b8K02HU8@0b:RL0>B`T04@c7`1K
B2L0LEhd08]a>02FNd@0XHI?0:R=F02`U680]9QX0:Z>G`2LP540Uh5B09QlBP2POdX0[hYC0;:>FP2L
OE40KePf04Xk700a<bP0;c4V02`]9@0Y:R@09RLR00809BDS00<09BDU02@V8`0T9R<01P0T9R<802HW
8@0402DV800V9b409RLQ02HW8@809bPR0P0X:B<02`0X9b<0:BPT02TX8`0Z:R80:b/Q02`/800];B40
;BhP038/800d;R80=BlS00<0=c4U00L0=S0T03D_8`0g<BD0=c4U03H`900e;b<0=2hR0080<bdQ00T0
<R`P03<_900c;b@0=S0T03Ta900k<R<0?c<S044d9011=2<00`14=bH304<f9@<0@SDT00P0?c@R040c
8P11=2<0A3@T04He9@18=BH0BS@V04/e9`80BSXS00<0Bc/T04`l9@1=?BH00P1>?RL00`1??bP0Dd4Y
05=1:@030590:0<0DClW201<?2D0201=?RT0Bc`W04/k901>?2@0Dd8X05M3:01G@RL0ED0S0P1LABH2
05e69`80GTLX0P1OB2T0201HBBX0EdPY05A59P1B@b@0DD8S05=49@1EARL0ETLX0P1JABH03P1HABL0
ETDY05E4:P1DA2/0Dd@]0593;01A@BL0D40V04lo9P1>?RL0C3/W04/j:01:>BL0BCPX2013>2H01@11
>2L0@3LV040g9P0o=RD0?SDT0080?C@S00@0?3<R03he900n=B@0?SDT0P0m=2<303`c8P0D03Xh8`0i
=R<0>3DR03Hc8P0d<B80<RhR034]8P0`;240=R`P03T_8`0n=2P0@CL[04<i;@12>2`0?cDY03dc9`0d
=BL0<c@V034b900`<B<402l`8P0P03D_8`0g;b80>30S03`c9010=2@0A3LV04Lh9@18>BH0BSd]04Lj
:P14=bH0@C@Q048f8016>R80BclW04i2:01L@Ql0Fd<Q05U28`1D@B<0CShU04Pl9014>BD0@3PU04Lj
:P16>BT0A3LV04<f8`13=b40A3PP04Hj8P17>b4904dm900h04Pn9@18?2@0ASXR04Pi8P1:>R<0CS`V
05@o:P1F@B`0Dd8X0592:01@@2L0CSlX04Xn:017?2P0A3`W04<k:016?B`0@cXY03lf9@0k<R40>S4P
03/b8@0n=B@0@3LV05Q6>P1JB3X0ET<b04lk8`1@>ah0H4TW06iH<@1eGSD0L5Xa06mI<01]Ec00JU@_
06E?:P1QBRP0G4DU05Y38`1O@240I4DV06]=:`1^D2`0Ke4[075D;01eF300NE`b08AK;@28Hbl0Sf`b
095c=@2>M3T0Q6di07]T>`1cG3`206QD<@0306]E<01/E2h0KE@/0080Ke<[00T0L5<Y079B;01eEBh0
NET`07]L;P1nH2h0PV@^08U/=02>LCL00P2CMCl06@2@M480SG9308M_@@21JT00O6Ho07US?01bFc80
L5L_06mF;@1eFRl0O5lc085R=022HC@0Oel`089R<@24I3<0QVLh08IZ>`25JSd0PFTm07iU?01jHcT0
MEX_07IK<01hGC800`1iGS<207QM<P80OV8j00@0Of@i081U>022IcP0PfTh0P24JSL02@22KC@0P6Xa
07iX;`24Jc<0Rg0i09=e?`2EMT00U7Do09b1BP0209j0BP0F09n0BP2POdX0X7a809miB02NN4L0Vga5
09amA`2KODL0VGi909MmBP2CO4X0TWY:091jB@2DN4H0UGU709IjB02IOD/0Vgm=09f1C`2OPe40X8AB
0:N<E`80ZheI00@0[HmI0;6BF`2dTed0]iAL0P2gTeT80;JDE@0P0;REG@2jUel0_Y]S0<>PJ038YFd0
cJYb0=2]M@3A[WH0e;R80=NkR`3K_hl0gl>C0>C8V03Wbi/0jLfM0>[>WP3bdZ<0l]6T0?GFZ03ig;00
o^>h0?oV_@3niKd0n^>j0?oS_03jg[H0m=N]0>c=W`3UaI@0h;n:0=bkQ@3M^X820=>cN00?0=2`M`3;
ZW@0ajI`0<ZYM03A/7d0f;N40=o5U03PaYD0h/RG0>C:V@3WcI`0jLnN0>_AX03/dZ40lmBU0080m=FV
00D0l]>T0>k?X03XbIX0h/>D0=joT0020=FkP0060<^aN02gW6D0Zi1K0:fAG`2aUF<0/IEU0P2dWVl0
5P2eWg00]Z1a0;RRL`2iXg@0^ZAe0;^UMP30YGX0`JIk0<:WO033Z7d0aJYo0<J[P037[840b:f20<Z/
R03>/Xd0eKRF0=[0W`3OaZL0hLZ[0>7<[@3Qc:l20>3@]P030>7A]`3Rd[P0hm>i0080i=Bj0140iMFk
0>?A^@3Td[X0hm6i0>;@^03Pc[H0g<Zb0=W7[`3GaJd0eknS0=JnXP3E_J40d[ZN0=2hW03>]YX0c;BH
0<^cU`020<ZaTP0<0<VaS`38/8`0ajn;0<F]Q`34[H@0`jb30<6UO@2mXGT0^Iee0;^OM`32YWh0b:b4
0P3:[XH02P3>]940d[RG0=JnW03G`:00eL2Q0=K3Y@3Kaj`0gLb`0>;=/03Tck@20>KB]`030>OF_03Y
ekl0j=S10080imS300P0j]W?0>_Jd03Zg=40jmoC0>_Qe@3/i=L0kNGH0>gWf@P0l>KJ0`3bj=`20??Y
g@<0m>[N0P3ejn420?CZh080lnWO0P3bj=h30?3Yh@80lN[R0`3bjn<20?C^hP<0mNoS0`3fl>@30?W_
i@80n>kT0`3gkN<01P3gk>P0mncV0?O/iP3gkN@0mngS0?O]h@80mnkO0`3jk]h20?W]g@<0n>cL203g
jm/80?OZf@80m^WH0`3ej=L30?CWePP0m>OD203dhm450?7Td`<0l^GD203`hm830?7Ue@<0l^KF0P3c
imL30?;Ue@<0lnKF0P3dimL00`3bi]X0lnOK0??Wf`020??Wf`80m>SL0P3ejMd80?KZgPP0lnWM203e
jMd80?GYfA00mNWM403dj^080??]h@P0mN_Q203gkN<80?W]h@P0mn_O203ikN4Y0?S/h0P0mn_K0P3f
j]X20?GYf@<0m>SH00@0lnOG0?KYf03fjMP0m^WH0P3ej=L30?CWePT0mnKD0`3fiM<20?GTdPX0m>?A
0`3ehld20?CRc0<0ln7;203dh/`80?;PbP80m=o:0P3cg/T30?;Mb0030?7La`3aglT0lMo900h0lMo9
00@0lmo70?;NaP3bg/H0l]k60P3agLD20?3La0<0kmk40P3^gL<30>gL`P80kmbn0P3^fkd30>gJ_004
0>cI^`3_e[P0kmJh0>oF^080k]Fg1@3]e;H00`3/dkD0jm:d0>[A/`020>W@/P040>S?/@3Yc:`0jLb/
0>W<[080j<^[1@3WbZX00`3VbJT0iLRX0>C7Y`020>C7Y`80hlJV0P3S`Yl20>;1WP<0hL2M00<0h;nL
0>70W@3Q`9d00`3P_i`30=nnV`P0g/2L203O_Y/80=jnU`P0gkjK2`3P_i`20=nnV`<0g[fJ00<0g[jG
0=fmUP3L_9D00P3K^i@00`3L_9D0gKfF0=jnU`030=fjU080g;VC0`3K^9880=ViTP<0f;RA0P3G]i03
0=JfS`P0eKF>203G]i00103E]H`0e[J=0=JfS@3F]Xd30=NgSP030=RhS`3G]8`0e[>;0080e[>;00@0
eK::0=BaR@3D/HT0e;690`3A[X@30=2]P`80cjb200<0cZ^10<n/PP3@[H<00P3A[X@01P3?[880cJZ0
0<bYO`3>Zh40cJZ00<bYO`80bjQn00`0c:Uo0<fZP03=ZX00cZ^10=2]Q`3?[8H0cJZ20<^XOP3;ZG`0
bjUk0<bZNP3=Zg/20<bXN0040<^WM`3:YWH0bJEe0<RTM080aj=c00D0b:Ad0<NSL`36XW80aJ5a0<BP
L0020<FQL@070<JRLP33Wf/0`YiZ0<:NJP31WFT0`9aX0;nKI`020;jJIP80^iaU00@0_9]U0;jKI@2n
VfD0_iYU0P31VFD01P30WFL0`9aX0<2LJ030W6X0`9a/0<2KKP80`9]_00H0`IiX0<6MJ@31WFT0`Ie[
0<6MK@31W6l20<6LL0040<>QL@32X700`Z1`0<:PL080`Im_0P30WVh0202nW6`0_I][0;bJJP2kVFT0
_9YZ0;fKJ`2oWFd0`9i^0`2lWFh[ooooo`00:_ooool20:V0C0030:QoB`2WOTX0YWe900<0YGa80P2X
Od/30:MnBP<0YWe90`2WOTX20:QoB`<0ZH1<202YOdd20:^1D@040:^1C`2[PTh0Zh9>0:^2C080Zh9:
0`2[PTh20:b3C`/0[HA@0P2[PTh0102/Pdl0[HA@0:f4D02^QE420:n6DP030:b3C`2[PTh0Zh9>0080
Zh9>0`2ZPDd30:QoB`H0Ygi:0P2XNTT00`2VNTT0YWa:0:EmBP020:AoB`070:B0C02QN4X0X7M909mf
B02NMDL0WGA609]bA00209Ya@`80V7A400L0UW9209A`@02BKSh0T6`l08iZ>P2=JCT0QF8h0080Q64g
00<0Pf0f085N=020GC<00P1oG38207aM;`0407]L;P1jFbd0NEX/07UJ;080N5T[0P1iER`0101jEbd0
NeP^07aI;`1mFS0207iK<@0>08=N<@22GC00P5/^081K;P21G2l0QF0c08QS=P2:ICP0RF@g08UU=@2:
ISH0RfLe08]W<`2<JC<208eZ<PP0Ufdk102EL3`409Ia?@<0UV/n0`2EJSd209AY?0P0TfXl0`2@IS@2
095W=@<0TVPf102AIST4099W>P0308iX>@2=IcP0S6Hg0080RfDf00<0S6Hg08eW>02>J3T02`2?JCX2
091Z>`<0TF/l102CJCL209AZ>080UF/i00D0TF/n095[?02BK3d0TV`k09=^>P0209=^>@80U6lh102C
KSX409A_>`P0TVdi00<0UF/i09AZ>02CJCL00P2BJ3H00`2CJCL0U6Xh09E[>@02095/=`04099]>02C
KST0U6lj09E`>`80UW4l0`2DL3`309Ea?@D0UW8n0P2ELCd309A`?008091[=`2BKCT0UG0l09Mb?P2H
Lcl0Ug8n09E`?02DKc/809A`?080V70m00@0Ug8n09Ib?P2FLSh0UG@o0P2DMCl209Ab@P80UG=30P2F
M4@209MeA@80UGM50`2DMT@309=e@`0608ea@@2:KSh0Qf/k089V=P1oHc<0OF4a0P1lH3002@1cGB`0
L5//06aG;01TD2/0GDXZ05E4:P1@@2T0CSdY040h8`03044i900:040h8`0m=B00>c<N03Ta700]:a`0
;2XK02TZ700W:A`09RPM02<V7@8082DN00<07b8G020S600P8aP00P0Q91T2028U6P0402<V6`0T:1T0
92PI02@X6@809BTJ0`0V:Q/01@0S9Ql08RDN01lR6`0M81T071lH00807B0I00<07R4J01`O600L7aP0
0P0M81T201hQ6P<07b8K00/082<J024T6@0T9QT0:2TI02l^6P0f=1l0>cTP040l8@1<?ad0EDPV05U<
:P0205I99`0<05U<:P1DAbD0BchL03L`:00^:R409R8I028O5P0S8aT09BLL02DX7@0T9a`0;BHN0P0[
9ah00`0Y9Qd09bLM02HX7@0202@W700302@T6P0U9A/09bLM0080:2PN00<09bLM02DU6`0T91X00`0R
8a/3024R6P80824I0`0S8a/2028R6P<08B4I01d07B<G01hQ6P0U9200<BTV03P[8`13<Qh0FTLV071M
<`2:L3L0U7U209j3C02URUD0[I5O0;:FIP2YSEh0W81A09N1DP2IOD/0XH1;0:n:D`2cSe/0W7eA071I
=`1:>a`0<38W02h`9@0[;2@0:2TS02HW8P0202DU8`0302DU9@0T9R<092HS00H092HS200V9b4202DV
80<09RLQ0`0W:280400X9b<0:BPT02TX8`0Z:R80:b/Q02`/800];B40;BhP03<]8@0d;R80=S0T03La
9@0h<RH0=c4U03H`900e;b<203La9@0303H`900e;b<0=2hR0080<bdQ00T0<R`P03Da9P0f<RL0>C<W
03/c9P0m=2D0@3@T044d9012=B@01015>2L204@g9P<0@cHU00P0@3DS044d8`12=B@0ACDU04Lf9P19
=RL0BcDW04`f:080BSXS00@0Bc/T04`l9@1<?2D0CCdV0P1>?RL205A2:P0305=1:@1B@2P0DClW0080
D3hV00@0CcdU04`l9@1<?2D0C3`U101;>b@02@1:>R<0C3dX04/l9`1=?BH0CcdU05919`1E@BH0Ed8W
05I1900205a59P0405e69`1NAbP0GTLX05m8:@80H4TZ00P0FdX/05U8:P1EA2H0DT4S05508P1D@bD0
F4LY05]:;080FdHW00h0FDHX05M6:P1FAB/0E4@[05=4;@1B@b`0Cd4W04i09P1=?RL0C3dX04Xk:019
>BT0B3PX04Ph:@<0?cHU0P10=bH3044h9`80?cPX00H0?SLW03`e9@0k=2@0>S<S03Tb8P0h<B4803dd
8`0E03Xh8`0i=R<0>3DR03Hc8P0d<B80<RhR034]8P0`;240=2`O03P`8`0m=BP0@CT/048j;@10>2/0
?3@W03Xb9@0c=2H0<S<U034b900`<B<0;c0R00<0;RlQ00P0=2hR03H^8@0h<2<0?3<T040d9014=bH0
B3TV04Tj9`80ASTY01H0A3LV04<f8`13=b40A3PP04Hj8P16>R00CCPI04lj7@1B?R<0Dd8X0594:P1>
@RX0BSlY04Ll:016>2/0ACLZ04<f9P12=B@0@SDR04<g8@15>B40ASXR0P1:>R4204/k8P0304`l8`1=
?B@0CCdT0080CShU01<0BclU04Xn901;?B<0C3`S04hl901B?RH0ET0Y05Q2:`1FAB/0E4@Z05=3:P1?
@2T0BShX04Ll:013>bH0@SXW048i:00o=RD0>c8Q0080>C0O02<0?C@S048i:015?2/0F4Xm05I6=`1?
?R`0C3PP050k7P1PB2H0KeD`07QO=`1cGC@0LU`c06mI<P1[EC00IU0[069;:@1NAbL0G4DU05`m7P1S
A2D0Jdd[071B;P1aDbd0LUD]07EH<01hFc40PE//08IR;P2<K340T7@e08ee>@26Kc/0O6Hm07EQ@002
06aH=@0306iH<`1^ES00KeH^0080L5@/00T0LE@Z06mA:`1aE2`0M5L]07YK;@1oGbh0QFH`08a[=@2@
L3L00P2EMd405P2CMdD0T7E608Ua@`23K480O6Ho07QR>`1eGSD0M5/c07=J<@1jGc@0PF@h08QY>`28
IcX0QVHg089R<@25IC@0QfPi08M[?027K3l0Pf/o081W?P1mIS`207ML<@0307QM<P1jGc@0Nf0e0080
O64f00<0OF8g085V>@21IST00P21IST4081U=P0>07aW<P1jHbl0NF8^07iT<@26JSP0SW0n091`?`2?
Kch0Uge:09QlBP2IOTT0W7i:09enB02NODP20:1mA`0A09inA@2OOTP0Wh1909n1B`2LPD`0V7i;09Aj
B@2@NDL0U7Y709EkB02GODX0VGm<09^1CP2NQ540WhEB0:26D`2ZSeX00P2]SeT0102_TUX0/Y=L0;BD
F`2fTeT20;JBEP80]99C102eTe@20;JDE@060;NDFP2jUed0_IYP0<:OI@36XfT0bJI/0P3;Z6h0603>
/7`0d;9n0=BfPP3I^hL0g/2<0>?5T@3Vb9@0ilVE0>o?X03cdZD0n=V[0?gP]03oi[/0onNn0?oV_P3l
iK`0onFn0?kR^P3hfk40lM:T0>[:V@3T`hh0g[f70=jkP`80dk=h00l0dK5h0<f/MP39Z780bJQc0<n^
N`3E]840f;j;0=VoS03K`Hh0g/BA0>77U03SbIH0iL^H0>O=VP3]cid00P3^d9h03@3]cid0jL^I0>C6
U03N`8h0fkf;0=6gO03B^7d0ajed0;BIHP2XSEP0ZhmM0:nCH@2_Tf<00P2bW6d0102cWFh0]9i_0;FO
L02fX7420;NQLP0@0;fRM@2nXgH0_jAg0<6VN@32YgX0a:Ul0<FZO@36Zgh0bJ^70<b`R`3C]Y@0fKnN
0=k5YP3QbZ/0h<^/0>7<[`80h=2f00@0hM6g0>;B^03Rd[P0hm>i0P3Te;X0:P3Rd;P0hm6i0>;@^03Q
ckL0glfe0=c:/P3HaZh0e/B/0=NoX`3F_Z80eKfQ0=:jWP3@^9`0c[JJ0<bdV03;/iL0bK2A0<ZaTP3:
/Y00bK6=0<R`S035[HL0`jb30<:[PP30YGX0^j1e0;RMLP2kX7D0`JIk0<R]PP3:[h@0bk250<fcT03B
^9L0e[jL0=O0X03D_j00eL:T0=[6Z`3Mc;00hlja0>C?]080i]:g00D0imJl0>WG_`3YfL80j=W40>OH
``020>_Jd0060>_MdP3/h=@0jn7E0>cTe`3^i]T0kNOI203aim/20?;Xg0<0lnWM0`3dj]h20?G[h@80
m>[P0P3cjMl20?;XgP80l>WQ0`3aj^830?;[h`80m>kR0`3ekn<30?K`i080nNoU0P3hk^@20?O]h`80
m^cR00H0m^_U0?K/h`3fk><0m^cR0?K/h03fkMh20?K]g0040?[]g03ik=/0nNcK0?W/f`80n>_J0P3g
j]T80?KYf0P0mnSE0`3ei]<20?CUdP<0lnCA203diM880?;Qc`<0kn;A0`3`hm820?7Td`P0k^7@0`3a
iMD30?;VeP80lnOG0`3biMD30??VeP80m>OG0P3bi]X40??Wf`<0m>SL203fj=/80?;YfPP0mNOJ203e
j=L@0?CVfB00ln[K203ek=d80?S[f`P0m^WI203hjm/@0?OZfQT0n>[M203gj]T40?KYf080mNSG0P3d
imH0103gj=D0m^OD0?KWe03fim@20?GVd`80m>GB203ei=830?GTd080m>??2`3ch/h0103dh/X0ln79
0??Qb@3chLT20?;Pb080lMo7203bh<X80?7Ob@80lmo70P3bg/H40?7MaA00l=k600@0l]k50?7Ma03a
gL@0lMg40P3`g<<20>oK`P<0l=c30`3_fl820>kJ`@80k]^m0P3]f[`40>cI^`<0k]Fg0P3]e;H30>cC
]@80kMBf0P3/dkD0103[d[@0j]6c0>W@/P3Yd;820>[=[@<0jLb/0`3Xbj/20>O:ZP030>K9Z@3Ub:P0
i<NW0080hlJV0P3RaJD30>;1WP<0hL2M0P3P_i`20>70W@<0h;nL0`3O_Y/80=k0W0P0gkjK203N_YL8
0=nnV`X0h;nL0`3O_Y/30=jmVP030=jnU`3M_IH0g;bE0080f[ZC00<0g;bE0=fmUP3N_YL00P3M^Y@3
0=biT`<0fkRB203I^I830=RhT@80ekN@0`3F]Xl80=FeSPP0ekN@203F]Xd20=NdS080e[>;00@0eK::
0=BaR@3D/HT0dk280`3A[X@30=2]P`80cjb200<0cZ^10<n/PP3@[H<00P3A[X@00`3?[880cJZ00<bY
O`020<fZP0@0c:Uo0`3=ZX00203@[HD0cZ^30<bYO`3:Z7/0bZQj0<ZXN03;ZGT0bjYg0P3<Z7P0103;
YgL0bZIf0<VUM@38Y7@40<NSL`80aZ9b1035XG420<:NJP030<6MJ@30W6P0_i]W0080_YYV00@0_IUU
0;ZKI02jVf@0^iYT0P2mVV@0102nVF@0`9QT0<2HI032WfT20<6MJ@030<2LJP2oVf/0_iY]0080_YU]
00P0`9eW0<2LJ030W6P0`Ie[0<6MK@31W6l0`Ia`0<:ML@<0`j5a0P32X7030<6OK`030;nMK@2nW6`0
_I][0080_9YZ00<0_I][0;nMK@30WVh00`2lWFh[ooooo`00:_ooool0202YP4`0Z7m;0:QoB`2XOd/0
Ygi:0:ImB@2UO4P0Y7]70P2XOd/30:MnBP<0YWe90`2WOTX20:QoB`<0ZH1<202YOdd20:^1D@040:^1
C`2[PTh0Zh9>0:^2C080Zh9:00@0Zh9>0:b3C`2/Pdl0[8=?0P2]Q5020:j5D@P0[HA@0P2[PTh0102/
Pdl0[HA@0:f4D02^QE420:n6DP80[8=?0P2[PTh0102ZPDd0ZH1<0:V0C02YP4`20:MnBP050:ImB@2U
O4P0YGa80:ElB02TNdL00P2SNTH20:EgAP030:=gAP2RN4H0XGU60080X7]70140Wg]709]eAP2JM4D0
VG=409Qb@`2FL440UFm009A^?`2CKCh0UG5109A`@02BKSh0Sf/k08eY>@2;IcL0RVHf08UU=@02089O
=@04085N=020GC<0P5dc07mL<P80OU/a0P1kG300101jFbl0NEX^07QI;@1gF2`207IG:`80NEH/00@0
NUL]07]H;P1kF2h0O5T_0P1mFS003P23GS40PE`_081K;P20Fbh0PE`_08AO<P28HcH0RVDh08UT=`29
ICD0RVHf08]W=@2;Ic<0S6Tc0P2=JS8809M]>`P0UG0l0`2FJch309EZ?@80U6Tl202AJc`3091V=080
TFLe0`2BJ3H4099W>P@0TFHi00<0SfTj08iX>@2<ISL00P2;ICH00`2<ISL0SVPi08mY>P0808mY>P80
SVPi0P2?JCX2091Z>`80TF/l0P2CJCL209AZ>0@0UF/i00D0TF/n095[?02AJc`0TV`k099]>@0209=^
>@80Tfhg0P2BKCT209=^>P80U6lk0P2EL3`8099]>@0309E[>@2DJSP0TfTg0080TVPf00<0TfTg09AZ
>02EJcT00P2AK3L0102BKCP0Tfhi09A_>P2EL3/209Ia?080U70l0`2ELCd609Ib?P80UG4m0`2DL3`0
202@JcL0TVdi09E`?02GLSh0V7<o09Mb?P2EL3`0U6lk202DL3`209Q`?@0409Mb?P2FLSh0UW8n09Ed
?`80U7Do0P2DLT8209Ec@`80UWA40P2GMDD309AfA0<0TgE30P2BM4801P2=LD40RVhn08M[>`22ISH0
Of<c07eQ<@80O60`00T0Led/071K;01/Eb`0I50[05i;:`1FAB/0DD4Z04ln:P10>2<00`11>B@0100o
=b80?3@O03Xb7@0h<1/202`Z6`0602TZ700V:1/09BLL02<V7@0P9Ah07b@M100P8aP4024T6@<08bLI
0P0T:1X302DY6`0502<V7`0R9Ah07b8K01dP6@0L7aP00P0M81T00`0N8AX07B0I01dP6@0201dP6@D0
7R4J00/082<L020S6P0S9AX09bPJ02h]6`0d<Qd0>CLP03hj8@19?a`0DDLT05I<:@0205A:9`0905I<
:@1BB2D0BT0M03Pa:@0_:b809b<J02<P5`0S8aT09BLL008092LL00H0;BHN02/W7P0Z9Qd0:BHM02LW
7@0U9a`202@W700302@T6P0U9A/09RHL00809bLM00<09RHL02DU6`0T91X00P0R8a/3024R6P<0824I
0`0S8a/2028R6P<08B4I01d0728F01hQ6P0U9200<2PU03LZ8P12<Ad0F4DT06iK<@2;LCP0UGY309n4
C@2URUD0[Y9P0;>GI`2[Sf00Wh=D09N1DP2IOD/0XH1;0;2;E02cSe/0WGiB071I=`1;?1d0;c4V02d_
900Z:b<09bPR02HW8P0202DU8`0302HV9P0T9R<092HS00H092HS200V9b4302DV80<09RLQ0P0W:280
2`0X9b<0:BPT02TX8`0Z:R80:b/Q02`/800];B40;BhP03<]8@0d;R80=S0T00<0>38V00L0=c4U03H`
900g<BD0=c4U03H`900e;b<0=2hR0080<bdQ00T0<R`P03Hb9`0f<RL0>C<W03/c9P0m=2D0@3@T048e
9@12=B@01015>2L204@g9P<0@cHU00P0@CHT048e9013=RD0ASHV04Pg9`1:=bP0C3HX04dg:@80BCTR
00@0BSXS04/k901<?2D0CCdV0P1>?RL205A2:P0305=1:@1B@2P0DClW0080D3hV00<0CcdU04dm9P1=
?BH00P1<?2D0301;>b@0BSXS04Xj8`1:>R<0BS/V04`m:01>?RL0D3hV05509P1D@2D0ET4V05Q39P80
G4DV00@0GDHW05i7:01OB2T0H4TZ0P1QBR/03P1LBbd0FDPZ05E49P1B@B<0Dd8T05E49P1JBB/0G4/]
05a7:01KARL0FDHX05I5:@1EA2X0Dd<Z0P1A@R/0201<@2P0BclW04Xn:019?2T0B3/Z04Hi:015>2P0
ACLZ0`0m=RH203hg9`<0?cPX0P0l=RP01P0k=BL0>C<U03Pb900g<B<0=S0R03D_8@80>c8Q00@0?3<R
03dd8`0m=2<0?SDT0P0o=RD0400j>2<0>CHS03Pe8P0f<b80=34R038^8P0a;B80<2`Q034[7@0d;R00
>38T03/e9`0l=RP0>S@V03La8`0e;b43034b9003030a8`0_<280;RlQ0080;BhP00P0<bdQ03D]800h
<2<0>c8S044e9@14=bH0BCXW04Xk:080@C@T00<0@SDT04@g9015>B<00P16>R801`17>b40C3/Q04`l
8P1=?B<0CClU04ho:01<@2P00P1=@B/02015=b`0A3H[04<e:011=2@0@C@S04<f8`14>280ACTS0`19
>B00101:>R40Bc/R04`l8`1=?B@204hn9@0B04m19P1>@2D0CclU050o9@1C?bH0EClW05U1:@1J@RX0
EdH/05E5:`1C@bX0Cd0Y04Xn:017?2P0@SXU044i9P13=bL0@CDU0P10=2@0:@13=bL0BCd]04i2<P1B
ASH0Cd<e04Tm;@17>2D0BSPP05Dm8@1OAB@0JdlZ07AF<01aFc80L5Xa06eG<01ZE2l0Ie4/06E>;01S
C2`0HT/[05dn7`1TABH0K4h/071B;P1aDbd0LE@/07AG;`1gFS00P5`/08EQ;@2:K300S7<c08Yd>024
KcX0NfPn07IR@@1^FSL0KETf06mI=01`F380L5L_0080LUH^00T0LUD[06mF;P1_ERd0LeP]07]L;P23
Hc80RfXe099_>@2EL3T00P2DMT005P2CMdD0T7E608YbA022Jd40NfDn07MQ>P1cG3<0LUTa079I<01i
GS<0PF@h08QY>`29J3/0QfLh08AT<`27IcH0RFXk08U]?P29KT40QFe1089Y@01oJ3h207UN<`0_07YO
=01kH3D0OF8g07iS>020ICX0PFHk08AY>P23J3T0PVLh085V=`1oI3L0OV<f07eR=@1lHC@0N68a07IN
;P1dG2`0NEh_085U=P28JC/0RfXm08YY?02<M4@0SgE4095gA02ENTD0VWa609n0A`2SPdX0Y8A90:>0
AP2TPDT0Y8==0:>4C@2QPdd0W85<09QlBP2ENdP0Uh1<09R1C@2JPdl0W8EA09j7D`2PRED0XX]G0:><
F02^Te`00P2aU5`01`2cUUh0]IIM0;JFF`2gUEP0]Y9D0;FAD`2cTE800P2dTU<20;FCE080]YAE00H0
]iEF0;^IG02mVeh0`ImR0<FSIP38YVT30<VWJP0`0<RYLP3:Zg@0cJig0=:cO03H^H80gKj70>72R`3S
a8d0k<bM0?;AY03jfjd0on>g0?oW_03oikh0onJn0?gV_@3oil00onBl0?_N]03fejT0k/jM0>K5T03O
_XP0gKZ20=>cN03E]GX0e;Ak0=2_N@3;ZW@0bZUd0<j]NP3B/Gh0e;V40=FjQ@3G_8L0fKj90=c1S03N
`hh0h<F@0>76T@3Vb9@0ilVE0>S:UP3WbID0i<JB0=o1S@3J_8P0ekV50P3?]GX01P35Zg80/YMP0:N<
E`2YSE/0[Y9P0:jBHP<0/9Y[01D0/I]/0;:LK@2cWFh0/ie^0;BNK`2jWVl0^im`0;fQLP2oXg@0`JEf
0<>WN034Z7T0aJUj0<NYQ@3;[hX0d[FC0=RnW@3NaJH0h<VZ0>3;[03Pbjh00P3OckD0103Pd;H0hM6g
0>;B^03SdkT20>CD^P80h]2h01`0hLng0>3>]P3Nc;@0flVa0=O5[@3E`j/0eknS0=JnXP3E_J40d[ZN
0=2hW03>]YX0c;BH0<^cU`38[i00bK2A0<ZbT03:/Xh0bK6=0<J^R033[8<0`JZ10;jSMP2jWg80]ia_
0;ZOLP31YWT0b:f00P3;/8<02P3=/i00dKNF0=FmV`3F_il0e;nP0=G2Y03JaZ/0g<^_0>?>/@3Ud;D2
0>OC^0030>SG_@3Zf<00jMW20080j=W400P0jm[@0>cKd@3[gM80k>3D0>cReP3]iMP0k^KI0>kXfPP0
lNOK0`3cjMd30?CZgP80mN_O0P3ejn420?CZh080lnWO0P3bj=h30?7ZhP<0l^_S0P3ck>@20?C^hP<0
mNoS0`3fl>@30?S^i080mngS0`3fk>801P3hjn<0n>_R0?S[hP3hk>00n>cN0?S/g080n>gK0`3jj]X2
0?WYf@<0n>SH203fi]H80?KUd@<0m>??0P3ch/h30?;Qc@P0m>?A203ah<h20>kQd080kn;A0P3`hm82
0?7Td`P0k^7@0`3aiMD30?;VeP80lnOG0`3biMD30??VeP80m>OG0`3bi]X40??Wf`80m>SL203gimP8
0?;VePP0mNGF203eiMD@0?CTeA00l^OE203ci]D80?;We@P0lnSF203fim@80?GVdaP0m^OD6@3hj=T;
0?OWe`80m^KF0`3eiMD30?KUd@80mNC@0`3dhll80?CSd@80m>C=0P3chl`30?;Rb`T0lN7:0`3bhLL2
0?7PaP<0l=o5203aglT80?3Nb080l]k50`3agL@30?3L`a00kmk40P3agL820?3L`@<0km_000<0k]Zo
0?3J`P3`f/800P3`f/820>oI`@80k]S00P3]f[`30>cI^`<0jmRj0`3]e;H20>cC]@<0jm:d0P3/dkD2
0>_B]0050>[A/`3Yd;80j<na0>S?/@3ZcJd00`3Yc:`20>S;Z`80ilZZ0P3VbJT00`3Ub:P0i<NW0>C7
Y`020>?6YP80h/FU0P3R`Ih30>70W@<0h;nL0P3Q`9d30>2oW0<0gkjK203N`9`80=nnV`P0gKfF203O
_Y/80>2oW0<0gkjK0`3N_IX20=flV@030=jnU`3L_9D0fk^D0080f[ZC00<0fk^D0=blU@3N_YL00`3L
^I<30=^hTP80f[NA2`3H^9420=NgT0<0e[J?203E]Hh80=NgT0@0e[J=103E]H`20=ReS@060=NdS03F
/h/0eK::0=BaR@3C/8P0dZn70`3A[X@30=2]P`80cjb200<0cZ^10<n/PP3@[H<00P3A[X@00`3?[880
cJZ00<bYO`020<bYO`@0cJZ00`3<ZGl0203?[880cZ^10<bZO@3:Z7X0b:If0<RWM039Z7D0bZUd0P3<
Z7P0103;YgL0bZIf0<VUM@38Y7@50<NSL`80aZ9b0P35XG401`34X700`YiZ0<6MJ@31WFT0`9aX0;nK
I`2nVVH00P2mVFD20;ZKI0040;^JI02mVV@0_IYT0;jII080`9QT00H0`YmY0<6MJ@31WFT0`9aZ0;nK
J`2nVF`20;fHK0060;nLIP2oVfL0`9aX0<2LJP31WFd0`Ye`0P32WG420<>QL@80`Z1`0`31Wfl20<2N
KP070;nMK@2mVf/0_9YZ0;bJJP2mVf/0_Ya/0;nMK@030;bMKR_ooooo000Zooooo`030:ImB@2WOTX0
Z7m;0080Z7m;00<0Ygi:0:ElB02UO4P00P2XOd/30:MnBP<0YWe90`2WOTX20:QoB`<0ZH1<202YOdd2
0:^1D@040:^1C`2[PTh0Zh9>0:^2C080Zh9:0`2[PTh20:b3C`<0[HA@202^QDl30:b3C`80[HA@0`2^
QE420:b3C`040:^2CP2ZPDd0ZH1<0:V0C080Z7m;0P2WOTX01`2VODT0Y7]70:=jAP2SNTH0XWU50:5h
A02PMd<00P2SMD@00`2QMD@0WgE309ee@P0209]f@P0>09Ue@@2GLd<0UW9209Ea@@2DL400TVhn095]
?@2@K3`0Sf/k095]?@2@K3`0SVXj08]W=`29ICD308QT=080PUle00L0PEhd081M<`1oG380OU/a07eJ
<01lFBl0NUXa0080NET`00<0N5P_07MG;P1fERd00P1eEB`507]H;P<0NUL]0`20Fbh02`21G2l0PUd`
08AO<P26HC@0R6<f08UT=`29ICD0RVHf08]W=@2;Ic<0S6Tc0080SFXb202GKC/0102EL3`0U6lk09A_
>`2DKc/309=^>P04099]>@2FJch0UV/n09I[?P<0UFXm0P2DJC`8091/?0<0TFLe0P2BJ3H309=Y=`04
09=X>`2BIcX0TVLj099W>P<0TFHi00@0T6Dh091Z>`2?JCX0SVPi0P2=IcP00`2>J3T0SfTj091Z>`08
08mY>P<0SVPi0P2?JCX3091Z>`03099X=P2CJCL0UF/i00<0UV`j0P2EJcT01@2@JSd0TF/l095[?02A
JcX0TVdi0080TVdh0P2CKSL01@2AK3P0TVdi099]>@2CKSX0U6lk0080UG0l00<0UW4m099]>@2BKCT0
1P2BKCT00`2FK3X0UF/i09AZ>00209=Y=`0309AZ>02EJcT0UV`j0080TF`g00@0TVdh09=^>@2DKcX0
UG0k0P2FLC`0102DL3`0UG4m09Ea?@2ELCd209Ib?P80Ug<o0`2FLSh209Ea?@<0U70l0P2CKSX01P2E
L3`0UW4m09Ia?@2FLCd0UG0l09A_>`P0U70l0P2HL3d0102GLSh0UW8n09Ib?P2EM3l209Ae?`80U792
0P2ELd<209IdA080UgE50`2DMT@209=e@`<0TWA200H0SG5108Y^?P27Jc/0PVHf07mS<`1mHC4207aP
<00907AN;@1aG2d0K5L/06EA;01NBb/0ETD[0551:P1??RX0@3PS0080@CTT00/0@3PS03hf8@0l=1l0
>C4L03L_6P0/:Q/0:bTJ02PY6`0V:1/09BLL028U700201lT7@P08B@I0`0S9Q/202@W70<09BPM00D0
8bHO028U7P0O8Q/07B0I01`O600201dP6@0301hQ6P0M81T07B0I00807B0I1@0N8AX06@0O8A`082<L
02<T700W9a/0;B/L03<`7@0h=R40?3LQ04Lo6`1?Ab<0E4`X059:9P1CBbL0EDdY05599@19@Ad0>C8Z
030/8`0W8aX08b0G028R600T9Q/092LL02<V6`0]9Qh00P0Z9Qd00`0Y9Qd09RHL02DW700202<V6`03
02<S6@0T91X09RHL00809bLM00@09RHL02@T6P0S8aT08R<K0`0Q8QX2020Q6@807b0H0`0S8a/2028R
6P<08B4I01d0728F01hQ6P0T8al0<2PU03HY8@10;a/0Ed@S06eJ<02;LCP0UGY309j3C02TRE@0[I5O
0;>GI`2]TF80X8AE09R2D`2JOT`0XX5<0;2;E02dT5`0WGiB075J>01;?1d0;BlT02`^8`0Y:R809bPR
02DV8@0202DU8`0302HV9P0T9R<092HS00H092HS200V9b4202@U7`809BHP0`0V9b404@0W:280:2LS
02TX900Y:2<0:RXR02/[8@0/;200;BdQ02d^800d;R80=BlS03La9@0h<RH0>C<W03Pb9P0g<BD0=S0T
0080=c4U00<0=S0T03D_8`0d;R800P0c;B402@0b;200=30U03Da9P0h<RH0>S8U03dd9@10=2@0@SDU
04<f9@0304@g9P<0@cHU0`12=B@02012=bD0@cHU04@g9P17=bL0BCPX04/h:@1==bT0CSPZ0P19>B80
101:>R<0Bc/T04`l9@1<?2D204dm9P80Dd4Y0`1B@2P3054o9`0604lo:01>?RL0CShW04dm9P1<?2D0
Bc/T0P1:>R<03P19>RD0C3dX0510:@1A?bL0D3lU058n8`1F@BH0FD@W05]49@1LABH0GDHW05i7:01P
BBX0HDX[0P1RBb`00`1LBB/0FTLY05Q59`0205M49P0905U6:01LBB/0GT/]05]69`1JABH0F4DW05E4
:01D@bT0DD4X0080Cd0Y00H0BSlY04Tn:018?BT0Ac`Z04Hk:@14>2P204<g:@P0?3HX0P0g<bL0100f
<RH0=C4U03Da9@0d<2@203<_8`80>S4P00@0>c8Q03`c8P0n=B@0?cHU0P10=bH02`0j>2<0>CHS03Pe
8P0f<b80=34R038^8P0a;B80<2`Q02l/7@0`;Ah0<RlP00<0=34R00<0<c0Q038_800`<B<00`0a<R@0
5`0`<B<0;RlQ02`]7`0[;1h0<bdQ03D]800g;b80>c8S044e9@15>2L0BCXW04Xk:00n<B40?c8R044d
8`13=R<0ASXT04Pl9019?BD0BShT04Xn9P18?2@0ACTQ0080@cLO00/0ACTQ04Pl901:?RH0A3H]04<e
:P12=2T0@C<V044d9012=B@0@cHS04@g900204Ph7`80BCTP00<0BSXQ04/k8P1<?2<00P1<?2<20551
9`0T05919`1D@2L0ET0X05U1:@1J@RX0Fd4Z05I5:`1DA2X0DT8Y04ho:019?BL0AS/W048j9@11>BH0
AcXZ04Pk:`19?2`0Bch^04m2<P1DAcL0F4/k05Y=?@15?Rh0?cHU040c801<>R80FD4U06138`1YB2D0
L4hY071J<@1^F2l0K5H_06UC;P1WDB`0ITl]0P1UCRh0401Q@R<0ITLX06a>;01_DBd0KU0Z06mB:P1c
ERh0MeX`07iL;023HRd0QfX^08Ua<@27LCD0PFdh07QW?01dHD0206eI=P0306mI=01`F380LEP`0080
LeL_0280M5L]071J<@1`FBl0LUX^07YN;`25IC@0Sf/g09I^>P2GL3T0Sg4k091b?02@M480SW=408Q`
@P21JT00NF<l07EO>01^Ebh0KE@/06eD:`1cF2d0Nehb085R=022HC@0P60a08MW=P29JCP0Rf`m08]_
@02:Kd80QVi208=Z@@20JCl0OF8g0P1lHCH07@1mHSL0OV<h081U>P22Ic`0PfPm08E[>024JSL0PfTh
085V=`1oI3L0OF8g07]O=`1jGSH0Mf0d07AL<01bFRh0MU/`07eP=P24I3/0QVDl08AS>P22K3d0QFdo
08Qa?`2?MT00UG]209j1A`2TQTP0YhU90080ZHE;00l0ZHI>0:J5C`2UQTl0XXA>0:22CP2MPTd0WXUD
09n:E@2PReH0XXeH0:F@F`2WTUd0ZIAO0:ZEH02cVF000P2fVEl01P2gVV00^9YN0;RHF`2hUUL0]iAD
0;JCD`80]99C00@0]I=D0;JDE@2fU5D0]iEF0P2hUUL0<P2oWEh0`ImP0<FSI038YVL0bZQY0<VWJ038
YVL0ajEV0<FUK037Yfh0bJU`0<f]M03B/WT0f;Qo0=fmQ03O_hH0j<RI0?7@X`3kg:h0onFi0?oX_@3o
i[d0o^Fm0?gV_@3oil00onFm0?kQ]`3ifZ`0lM6P0>S7TP3O_XP0g;V10=FeNP3G]g`0ekMn0=BcO@3>
[GL0c:]f0<j]NP3A/7d0dkEo0=BfP03E]h40ekV30=VkQ@3K_HL0g;j80=foR@3P`X`0hL>=0P3Ra8h0
303P`X`0fkf70=JhPP3C]Gl0cK=h0<jdN@34ZW40/IIO0:J;EP2YSE/0[Y9P0:jBHP<0[YQY0P2_VFX3
0;2JJ`0@0;VJJ`2jVf`0_9e^0;jOL030XG80`Z=d0<BUMP35YWL0aJN30<V]R03A]980ekfL0=g4Y@3P
bJX0h<^/0>3;[P80glne00@0h=2f0>7A]`3Rd[P0h]:h0P3SdkT30>7?]`0K0=o=]@3Mbk<0f/R`0=K4
[03E`j/0eknS0=JnXP3E_J40d[ZN0=2hW03>]YX0c;BH0<^cU`38[i00bK2A0<ZbT03;/hl0bK6=0<J^
R033[8<0`:V00;fRM@2iWW40]ia_0;VNL@31YWT0b:f00080bk2300X0c;:?0=6gUP3E_I/0e[nO0=>n
W`3D`J<0fLFZ0=c;[`3Tck80iM2e0P3WdkP01@3Xekd0j]S00>[J``3Yf/D0j=W40080k=_A00H0k=kC
0>cPe03/h]H0kNGH0>oWfP3^j=X80?;Xg0<0lnWM0P3dj]h30?G[g`80mN_Q0P3dj^020??Yg`80l^SN
0`3aj^820?;[h`<0lncT0P3dk^830?G_h`<0m_3T0P3hk^@20?O]h`<0m^cR00L0mN_Q0?SZh@3hj]l0
n>[O0?SZg@3hjm/0n>_J0080n>_H0P3jjML20?WXeP<0n>OE00<0mnKD0?KUd`3fiM<01P3fiM<80?GS
c@<0m>;<0`3chL/20?;PbPP0ln3?203ah<h20>kQd0040>oRd@3`hm80lNCC0?7Td`80l^GD203`hm83
0?7Ue@<0l^KF0P3cimL30?;Ue@<0lnKF0P3dimL20?7Uf@<0l^KJ0`3cim/00`3dj=`0mnKF0?OVeP06
0?OVePP0l^GD203ei=@80?GTdQ00ln;B403`hm080?;Qca00kn;?203chl`80?;Rb`P0ln?<403di<dI
0?KUe@P0mNCB00@0m^GC0?GTdP3ei=80mNCB0P3dhm420??Rd080m^C>0P3ehld30?CRc0030??Qb`3b
hLl0l^7?00H0l^7?0`3bh/T20?7Qb0/0l>370P3ah<H20?3Oa@<0kmk400<0k]g30?3Nb03`g/P01P3`
g/P80>oMa`<0lMg40P3`g<<30>oK`PP0kMc2203^gL<20?3M_`80kmbn0`3^fkd00`3]f[`0l][20?7I
`@020?7I`@80l=S00P3_ekl30>cI^`80jmRj0`3ZekT30>cC]@80jm:d0`3ZdK<01P3[d[@0j]6c0>[A
/`3Yd;80j<na0>O>/080i/f_0`3Xbj/20>O:ZPD0i/VY00<0iLRX0>C7Y`3SaZH00`3RaJD00`3Qa:@0
h/6N0>70W@020>70W@80h;nL0P3O_Y/20>70W@<0h;nL0`3O_Y/80=k0W0P0gkjK203M_IH80=nnV`P0
h;nL0`3O_Y/20=jmVP<0gKbI00<0gKfF0=blU@3K^i@00P3J^Y<00`3K^i@0g;bE0=fmUP030=biT`80
fkRB0`3J]i4;0=RhT@80ekN@0`3F]Xl80=FeSPP0ekN@0`3F]Xd20=FeS0<0e;B;00H0fKJ>0=ReS@3G
]8`0e[>;0=FbRP3C/8P20=:_Q`<0dJj40`3@[H<20<n/PP030<j[P@3?[880d:f30080dJj400H0cjb2
0<fZP03<ZGl0bjQn0<bYO`3=ZX020<j[P@0<0<fZP03<ZGl0c:Uo0<^XOP3?[H00cZao0<^YN`39YgL0
ajIc0<NVL@38Yg80b:Ma0P3<Z7P0103;YgL0bZIf0<VUM@38Y7@20<NSL`80aZ9b0`37Xg<00`36XW80
a:1`0<>OK`020<6MJ@030<2LJ02oVfL0_YYV0080_IUU00@0_9QT0;VJH`2iVV<0^YUS0P2lVF<02@2m
V6<0_iMS0;nGH`31WVP0`IeY0<2LJ02oVfT0_YYZ0;jIK0020;fHK0060;jKI@2oVfL0_i]W0<2LJP31
WFd0`Ye`0P33WW830<6OK`80`9i^0`2oWFd02030WVh0_ie]0;fKJ`2lVVX0^iUY0;bJJP2mVf/0_Ya/
0`2lWFh[ooooo`00:_ooool0202TNdL0YGa80:MnBP2XOd/0ZH1<0:QoB`2WOTX0YWe90P2XOd/30:Mn
BP<0YWe90`2WOTX20:QoB`<0ZH1<202YOdd20:^1D@040:^1C`2[PTh0Zh9>0:^2C080Zh9:0`2ZPDd3
0:^2CP80[8=?202^QDd30:j5D@80[HA@1@2/Pdl0102[PTh0ZX5=0:V0C02XOd/20:MnBP040:QoB`2W
OTX0YWe90:AkA`80XgY600/0XGQ40:1g@`2OMT80XgE40:9d@`2OLd80WG=109Yb?`2GLSh0UW4m09A`
?00209=a@@04099`@02@KSh0Sfdm08e[>`80S6Xj00@0Sf/k08eY>@2;IcL0RFDe0`28I3@02P29ICD0
Q64g08=P=P22GcD0P5dc07mL<P1mFS00O5T_07]H;P1iFC8207QH<@0307MG<01fERl0MED^0080M5@]
00H0OEX`07aI;`1lFBl0NeP^07YG;@1iER`207QE:`0507iI;01oFRd0PE`_08=N<@24Gc800`25H3<0
1P29I3L0RFDe08YV=P2;IcD0RfLc08aY<`80SFXb202GKC/309=^>P03099]>@2AK3P0TF`h0080T6/g
0`2FJch309EZ?@80U6Tl202>K3`2099X=P80TfTg0P2DJSP209E[>@80TfPk0P2BIcX2095V>@80T6Dh
00<0TV`m095[?02@JS/00P2>J3T00`2@JS/0TF/l099/?@0808mY>P@0SVPi0P2?JCX2091Z>`03099X
=P2CJCL0UF/i00<0Ufdk00L0UF/i09AZ>02@JSd0T6Xk095[?02AJcX0TF`h0080TVdh0P2BKCH2095/
>004099]>@2CKSX0U6lk09E`?080UW4m202BKCT00`2HKS`0Ufdk09E[>@0209AZ>00309E[>@2GKC/0
V6hl0080TF`g00@0TVdh09=^>@2DKcX0UG0k0P2FLC`309Ea?@80UW8n0`2GLcl309Ib?P80UG4m0`2D
L3`01@2GLSh0UW4m09E`?02DKc/0Tfhj0080U6lk00<0UG0l09A`?02DL3`01P2DL3`209Q`?@0409Mb
?P2FLSh0UW8n09Ed?`80U7Do0P2DLT8209Ec@`80UWA40P2GMDD0102DMT@0TgE309=e@`2CMD<2099d
@P80TG=100H0SG5108Y^?P27Jc/0PVHf07mS<`1mHC4207aP<00807IP;`1bGBh0KUT^06IB;@1NBb/0
ETD[0510:@1>?BT3044i900=040h8`0n=R40>c<N03P`6`0f;QT0;2XK02/Y6P0X:A/09RPK02@V6`0R
9A`07b@M01hS700202<V6`H08RDJ0`0T9a`202DX7@<09RTN00D08bHO028U7P0O8Q/07B0I01`O6002
01dP6@D07R4J1@0M81T02`0O8Ah0828M028S7@0V9Q`0;2XM038_7P0g=240>cHR04@n6P1=Ab<0DT`X
0080D4XV00`0DddY04m99@17@Ad0>C8Z030/8`0X91/08b0G028R600T9Q/08bHK028U6P0/9Ad202XV
7@0302PU700V9Q`092HK00808bHK00<08b<I02@T6P0U9A/00P0W9ad00`0U9A/092@J02<S6@03024R
6P80824I0`0O81P302<S6`808R8J0`0Q8AT07@0L8QH07B0I02@S7`0_9b@0=BPP03l^6P1E@R40JeP^
08Q^=@2BMd00Vh190:66D@2ZSU`0/IEU0:^?H02OPe@0V89C09YnC02RPD`0/8]D0;B@G02NOe<0LEXh
04`m7P0/;R<0:bdR02TZ8P0V9b409BHQ00809BDS00<09RHV02@V8`0T9R<01P0T9R<802HW8@<092DO
0P0U9R0302HW8@0;02PW8`0Y:2@0:BPS02XZ8P0[:b40;2`P02d]8@0];R00=2hR03D_8`0g<BD00P0i
<bL00`0h<RH0=c4U03H`900203La9@0303H`900e;b<0=2hR0080<bdQ00T0<R`P034]8P0b;R<0=BlS
03Ta900l<b@0@3@T04<f9P14=bH00P13=RD3048e90@0@C@S00H0@SLU04@g9P14=bH0AcLW04Th:01;
>2T204hh:P0604Ph8@19>B80BCTR04Xj8`1;>b@0C3`U0P1=?BH3054o9`<0DT0X0P1C@BT01P1A@BX0
D40Y04lo:01>?RL0CCdV04`l9@80Bc/T00h0B3TT04`m:01A@BX0DT0X04ln901A?B80ET4V05Y5:01K
A2D0G4DV05e69`1NAbP0H4TZ069;;080Hd`]101KART05@1LAbX0GDP[05e8:`1NBB`0FTDV05U49@1G
A2H0Dd8V05919`1??bH0CChW04`m9P17?bP0AclZ04Hn:@14?2T0@cXY048i:P11=b/0@3HZ03`i:P02
03/h:@0503Xg:00i=RL0>3DV03Pe9P0g=2D01@0c<BD3038`9080>C0O00@0>S4P03`c8P0n=B@0@3LV
0P11>2L0200j>2<0>CHS03Pe8P0f<b80=34R038^8P0a;B80<2`Q0P0b<240200a;b00<2hO034_800b
<240<c4R03@b8`0_<280<34S0P0a<R@0900`<B<0;RlQ02`]7`0Z:ad0<R`P03@/7`0g;b80>c8S044e
9@15>2L0BS/X04/l:@10<b<0@C@T044d8`13=R<0ACTS04Pl901:?RH0BclU04Hn:@14?2L0A3TU044f
8012=R00A3PP04Tj8`1:>b@0@cD/048d:`11<bP0@38W040b9@11=2@0@SDT04<f9@@0BCTP1@1:>R42
05A39`0405I29`1H@bP0FT8X05Y2:080Fd4X00h0Dd8X05519`1??bH0C3dV04Pl9P15>RH0@SXU044i
9P18>2T0BSX[04`l;@1??c00DD4b0592<`80Dd<d00h0ACl_03`e8`0m<Qh0CC/S05]39`1RABD0JTPU
07=?:`1aFc80KeT`06aF;`1XDRd0IDlZ06=<:P80Hd`/01D0ITLX06U::`1/CR`0KDl[06]=9`1]D2P0
LUD]07MJ<01nG2`0PF8/08IY;@27Kbl0Q70c07a[=@1eI3T0Kelm06YF<`1[Ec@0KELb06mG<@1aF300
0P1dF3008@1fFBl0Ke`b06iI;P1`F2`0N5`]08ES<`2?JSH0U6/g09EZ=@29JcD0Rfdg08a`?P2;L440
QVi007mX?P1gHCX0Ledf06mH;`1^EBd0KE@[07=H;@1jGC40P64c085P<`1nGRl0Rf/j08a/>`2>Kd00
SG5208]`@`26KT80PfY107mX?P02081U>P0<07mT>@1nHcP0Of@i085V>`23J3d0Q6Tn08E/=P24JcD0
PVPe081U=P1nHcH0O60h0P1jGSL08@1gH3H0M5/b075H;`1eFC40Nehf085Q>P22H3X0P5hh07mX?P20
JCd0Q6`l08]a?P2BN3l0Vgi20:65A02UR4H0[hQ=0:b8C02[Qdd0ZXM?0:N6D02WR580YhUC0:R:EP2T
T5/0YI5L0:NCGP2YUF00[9QS0:jJI@2`W6L0/IeX0;RNH`020;ZMH`060;ZMH@2kWEl0^iaL0;ZHF02i
UUH0]iAB0P2eTe@0102fU5D0]iEF0;RFE`2iUeP20;ZHF@0X0;nMG@32X600aJ=S0<RVIP39YfL0b:IV
0<FSH`33XF40a:AW0<FUJ036YVT0bZY]0<j^L@3D]7L0f;Qk0=^kOP3Ta9D0kljQ0?cM[`3oiKT0onNl
0?kU_03mi;`0o>Fl0?oW`03oiKd0on:h0?[K[@3bdZ40j<NB0=jmQ`3K^800ekMl0=ZjO`3K^h80ekJ0
0=:aN`3>[GP0cjik0=6`O@80e;Eo00<0eKJ00=JgP@3G^8800P3H^H<00`3I^X@0fkf70=bnR0020=k0
RP0<0=bnR03H^X@0e;J00=6cO@3=/gP0c[Ai0<BZL@2aUUl0YX]F0:V=F`2^TV00[Y9R0`2/UVL40:fG
J00B0:jHJ@2gUfH0^9QW0;ZJJ@2mWF`0_im^0<6QL033Xg80a:Ac0<BVPP38[8L0d;>A0=JlV`3L`j@0
h<VZ0=o:Z`3Pbjh0g/jd0P3OckD00`3Pd;H0hM6g0>;B^0020>?C^@<0h<jf01/0glfe0=c:/P3Iajl0
e/B/0=C2ZP3G_j<0e[jR0=FmX@3B^Yh0d;RL0<jfVP3<]9P0bk>G0<N^S`39/940bk>A0<^cS`3:/Xh0
aZj80<:[PP30ZH00_:5b0;RMKP2fVf`0^Ii_0<2UMP38[Gh00P3;/8402P3</Xl0dKNF0=FmV`3E_Yh0
dkjO0=C1X`3IaJX0flZ^0>C?/P3VdKH20>SD^@030>SG_@3Zf<00j][30080jM[500P0k=_A0>gLdP3/
g]<0kN7E0>gSe`3^i]T0knOJ0>oYf`P0l^SL00@0lnWM0?CZgP3dj]h0m>[N0P3ejml20?K/h080mN_Q
0P3dj^020??Yg`80l^SN00@0lN[R0?;[h`3bjn<0l^_S0P3ck>@20?C]i@80m>kR0`3ekn<30?K`i0<0
mngS0`3fk>820?G[h@80nNSN00<0nNWL0?WYfP3ijMT00P3ij]L00`3ij]D0nNSD0?WXe0020?SWd`<0
mnKB00<0m^GA0?CSc`3dhll01P3dhll80?GPb`040?ORc@3fhL`0m^7<0?KQc080mN3;0P3dglX80??N
c@P0l^7?00H0k^7@0>oRd@3`hm80lNCC0?;Ue03ci]D20?CWePP0lNCC0`3aiMD30?;VeP80lnOG0`3b
iMD30??VeP80m>OG0`3aiMT30?;VfP<0lnOK203fiM<80??Td@P0m>?A203dhll@0?;Qca00kn39203`
g/P@0>gNa`P0kmo6203^g/D80>oOaQ00l>37203bhLlA0??Rd0P0l^7=0`3ch/h20?;Qc@<0lN3<0P3g
h/d20?KQc0<0mN3;00<0m=o:0?7PcP3ah<h01P3ah<h30?7Qa`80l>362`3_glD20?3O``80kmk20`3^
gL400`3]g<00kmg70>oMa`060>oMa`P0k]c60`3`g<420>oK`0<0k]Zo203/fkl80>gL`0<0kmbl0P3^
fk/30>gJ^P80lMW10P3`f<030>oG_`040>kF_P3[f;X0jmRj0>_H^P80j]Ni0`3Ye[P0103/dkD0jm:d
0>_B]03[d[@20>[A/`80jM2b0P3Xck40103Wc[00i/f_0>G<[P3Uc:h20>C;[@<0i/VY0P3Ub:P30>C7
Y`050>K9Z@3Ub:P0iLRX0>C7Y`3SaZH00P3RaJD20>74Y0<0hL2M0P3P_i`30=nnV`80hL2M0`3P_i`3
0=nnV`P0g/2L203O_Y/80=blU@P0gkjK203P_i`0103O_Y/0g[fJ0=jmVP3N_IX20=flV@80g;^H00<0
gKfF0=blU@3J^Y<00P3I^I80103J^Y<0g;bE0=fmUP3L^I<30=^hTP80f[NA0P3I]Y080=NgT0<0f;RA
0P3G]i030=JfS`P0eKF>203G]i030=JfS@030=FeS03D]8/0e;B;0080dk>:0P3I]Xh01P3H]Hd0e[>;
0=BaR@3C/8P0dZn70=6^QP<0dJj40`3@[H<20<n/PP030<j[P@3?[880d:f30080dJj400H0cjb20<fZ
P03<ZGl0bjQn0<bYO`3=ZX020<j[P@0<0<fZP03<ZGl0c:Uo0<^XOP3?[Gl0cJ]m0<^YN@38YWH0ajIc
0<JUL036YFl0ajI`0P3<Z7P0103;YgL0bZIf0<VUM@38Y7@20<NSL`080<FQL@36XW80aj=c0<RTM037
Xg<0aZ9b0<BPL033Wfl20<6MJ@040<2LJ02oVfL0_YYV0;fII@80_9QT0P2iVV<0102jVF<0_9US0;bI
H`2mV6<20;nGH`060;nLIP2oVfL0_i]W0;nKJ@2nVVX0_YU/0P2nVFd0202nVfD0_YYV0;nKI`30W6X0
`Ie]0<:ML033WW80a9mc0`2oWFd30;jLK080_I][00P0`Im_0<2NKP2nW6`0_9YZ0;^IJ@2lVVX0_I][
0;jLK0<0_9e^:oooool002[ooooo00<0XWU50:AkA`2VODT00`2YP4`0102XOd/0Ygi:0:QoB`2XOd/3
0:MnBP<0YWe90`2WOTX20:QoB`<0ZH1<202YOdd20:^1D@040:^1C`2[PTh0Zh9>0:^2C080Zh9:0`2Y
P4`20:Z1C@<0Zh9>202^QDd20:n6DP040:j5D@2]Q500[HA@0:b3C`80Zh9>0P2/Pdl02P2[PTh0ZX5=
0:V0C02XOd/0Ygi:0:ImB@2YP4`0Z7m;0:MnBP2UO4P20:=jAP0F0:5hA02OMT80WgI20:=eA02RM4<0
Wg=209ab@02HL3d0U6lk09=^>P2AKCT0Tg51099`@02AKcl0T6hn08i/?02=Jc/0S6Xj08]Y>@2=JCT0
RfLg08UU=@80Qf<c00/0R6@d08UU=@2:ISH0QF8h08AQ=`23H3H0PEhd07mL<P1mFS00NeP^07YG;@02
07QH<@0307MG<01fERl0MED^0080M5@]00L0Le</07iK<@1nFc40O5T_07]H;P1iER`0N5D[0080MU<Y
00@0O5LZ07iI;021G2l0QF0c0P26HC@02024Gc80Peha08UT=`29ICD0RVHf08]W=@2;Ic<0S6Tc0P2=
JS8809M]>`<0TVdi00<0TF`h091[=`2?JSH00P2?JSH309I[?P<0UFXm0P2DJC`808i/?00409=Y=`2D
JSP0U6Xh09AZ>080UF/i0P2FK3X309=X>`03099W>P2AIST0T6Dh0080T6Dh00<0Tfdn099/?@2AJc`0
0P2@JS/00`2AJc`0TV`m09=]?P0808mY>P0408eW>02>J3T0SVPi08iX>@80SfTj0P2@JS/02@2BJ3H0
TfTg09E[>@2GKC/0V6hl09M]>`2EJcT0U6Xh091Z?@02091Z>`04095[>P2AK3P0TVdh099]>080TVdf
00P0T6/g095/>02BKCT0Tfhj09A_>`2EL3`0UW4m09Mb?PP0TVdi00<0VFlm09Q^?02FK3X00P2EJcT0
0`2FK3X0V6hl09U_?@02095/=`04099]>02CKST0U6lj09E`>`80UW4l0P2ELCd309Ib?P<0Ug<o0`2F
LSh209Ea?@<0U70l00P0VWE109Qc?`2EL3`0TVdi095/>02BKCT0U6lk09E`?0P0U70l0P2HL3d0102G
LSh0UW8n09Ib?P2EM3l209Ae?`80U7920P2ELd<209IdA080UgE5102CMD<2099d@P80TG=100H0SG51
08Y^?P27Jc/0PVHf07mS<`1mHC4207aP<00807MQ<01cGRl0KUT^06IB;@1NBb/0ETD[0510:@1=?2P3
044i9005040h8`0n=R40>c<N03P`6`0f;QT00P0[:AX01P0X:A/09RPK02@V6`0R9A`07b@M01hS7080
92LL1@0S9Q/00`0R9AX092LN02DX7`0202DX7`809RTP0P0W:R401@0S9Ql08RDN01lR6`0M81T071lH
00807B0I1@0N8AX501dP6@0;01lQ7P0P8Qd08R<M02HV700/:Qd0<RlN03Hc800k=R80@cdI04a68P1A
BbL00P1@BRH04@1CCBT0CdTU04M17@0j<b/0<2`S02PT6`0S81L08R8H02@V6`0S9Q/08RDJ02`U7@0Z
9Qd0:BDL02PU700V9Q`092HK00808bHK00<08b<I02@T6P0U9A/00P0V9Q`00`0U9A/092@J02<S6@02
024R6P<0824I0`0O81P302<S6`808R8J0`0Q8AT0800L8QH07B0I02<R7P0_9b@0=BPP03l^6P1E@R40
JeP^08E[<P2?M3d0Uga509f2C@2VRUP0[I5Q0:R<G@2LP540V89C09YnC02RPD`0/HaE0;B@G02NOe<0
LEXh04`m7P0/;R<0:bdR02PY8@0V9b409BHQ02DU8`0V9R@09RHV200T9R<802HW8@<092DO0`0U9R02
02HW8@0;02PW8`0Y:2@0:BPS02XZ8P0[:b40;2`P02d]8@0];R00=2hR03D_8`0g<BD00`0i<bL01`0h
<RH0=c4U03La9@0g<BD0=S0T03D_8`0d;R800P0c;B402@0b;200;b/P030/8@0d;R80=blR03/b8`10
=2@0@cHV04@g9P02048e9080@C@S1@10<b802013>2H0A3LV04Dh9`18>2P0BSTY04`i:P1>>2X0CcT[
0P18>2401019>B80BSXS04/k901<?2D204dm9P0604lm9@1@?RH0D3hV054o9`1B@2P0Dd4Y0P1D@RX0
1P1B@R/0DD4Z0551:P1??bP0CShW04dm9P80C3`U01@0AcPS04`m:01B@R/0DT0X04ln901@?240ET4V
05]6:@1KA2D0G4DV05e69`1OB2T0H4TZ069;;01SC2d0I4d^05U49`1JABP0G4LZ05e8:`80GTT/0P1M
B2/03P1IA2D0F4<T05I39@1B@BD0D3lU04hn9@1<?BH0Bc`U04Lo:P16?RT0ACdZ04@k:P13>R/0@CPY
0P10=RX01P0m>Bd0?3P/03/g:`0j=RX0>3@X03Lc9`80=S8V0`0a;b<3038`9080<c4U01X0>2lN03T`
7`0j<B00?3<R03he9010=bH0@CPW048i:00j>2<0>CHS03Pe8P0f<b80=34R038^8P0a;B80<2`Q03Le
9P0e<b@0<S0Q030^7`0a;b00<c4R03Hd9@0h=RL0;c0R030a8`80<C8T00`0<34S02h_8@0/;Al0:R/M
038/800d;1l0=blR03/b8`11=BD0ACPW04Xk:01;?2T204@g9`0F04<f9@13=R<0A3PR04Lk8`19?BD0
BclU04Ho;015?R/0ASh[04Pm:@19?BL0BShV04`m9P1=?bD0@c@]048d:`11<bX0@38W040b9@11=2@0
@SDT04<f9@@0BSXQ1@19>B001@1D@bD0ED@V05M49P1IA2L0Fd<W0080G48W00`0G44V05509P1??bD0
CShU04/l9@17>bD0ACXV044i9011>BH0@S8S04@d9@17=bP204Ti:P1>04Ph:@15=BH0@c<T04Q5=00l
=b@0?34M04dk8`1LA2P0I4DV06e;:01iDbl0M5he075K<P1]Ec00Ie4/06==:01QBRP0H4TY05m8:01Y
BR/0Jd`]06e?;@1[CBT0JD/U06]>9P1bEBd0MeX`07eM;021HR`0PfT/08A_;P21Kc40NVTc075R=`1]
GC/0J5@a06UE<P1/ES40KUH`075H<01dF300METa07II;`1]G340JUL/06aE:@1eFBX0PV0`08aW<`2A
J3@0TFHa08EW<@28JS@0RFdk08U^?`24K3h0OVLm07IP>@1bG3D0MEhe07AK<`1cFS40NEhc07mR=P25
ISP0QF@g08=S=02=KC`0SVhm08m`@@2>LT<0S75408I^@P22JD00OfPn08=X?@22Ic`0P6Dj0P1oI3T0
;021IS/0PfPm08AY?P24Jc<0Q6/e089X=@20ICH0OV<f07aP>01jGSL0NUhi07QQ>01eG3@0LEP`07AH
<@1jG3H0Oeli07mM>01mFcH0OVTn081Y?@22K3/0Qg0l08ie?02FOCd0WH8o0:66@@2bRe00/8U>0:b8
CP2ZQdd0Z8Q?0:V:D`2/SEL0[HmI0:VEH02ZUV40[9QS0:jJI@2aWFP0/imZ0;FQK02fXVd0^Z1U0`2m
X6@0402mWf40_9eM0;bJFP2jUeD0^9EC0;FCE02fU5D0]iEF0;RFE`2iUeP0^YQI0;^IFP2lVU/0_YaL
0<6OG`34XV820<NUI@030<FSH`32X600`9iN0080aZAW01h0ajEX0<ZXJ`3>[6l0dk5d0=RfN@3K^G`0
hL6B0>g<W`3lgJl0onFi0?oW_03mi;/0o>>k0?_T^`3oi[l0onFm0?oR^03kg:h0lm>R0>S7TP3N_HL0
fKIn0=RhO@3K^h00gKf40=ZiP`3D/gd0cjii0<n^N`3A/7d50=FfO`<0e[N00100f;^30=ZmQ@3L_hL0
g;n70=ZmQ@3F^H40d[Em0<nbNP3=/gP0c[Ai0<BZL@2aUUl0YhaG0:Z>G02_Tf40[i=S0`2[UFH50:bF
I`0@0;JFI@2gUfH0^IUX0;^KJP2nWVd0`J5`0<:RL@33Xg80a:J20<N[QP3?/Y00e[bK0=c3Y03Ob:T0
glZ[0>3;[P80g/jd00@0glne0>3@]P3QdKL0h]:h0P3SdkT20>3>]P0L0=o=]@3Nc;@0g<Zb0=W7[`3E
`j/0dl6Y0=NoX`3F_Z80eKfQ0=:jWP3@^9`0c[JJ0<bdV03;/iL0ajj?0<R_T03;/i40c;B@0<ZbSP37
[hT0`Z^20;nXO`2lXW40^9i]0;JLJ`2iWfh0`:Ie0<R^O@80bk6000X0c;:?0=2fU@3D_9X0eKjN0=>n
W`3D`J<0fLFZ0=_:[P3Tck80i]6f0P3Xe;T00`3Yf;h0j]S00>[J``020>WJa@080>cKd@3]g=80k=kC
0>gQe@3]hmL0k^KI0>oWfP3_jM/80?;Xg0@0m>[N0P3ejml20?K/h080mN_Q0P3dj^020??Yg`80l^SN
103bjn<20??/i080m>gU0P3dk^830?G_h`<0m_3T0`3gkN<20?K/hP<0mN_Q00H0nNSN0?WYg03ijM`0
nNWJ0?WYf@3ij]L20?WZe@<0nNOC0P3hi]830?OUd@P0m>;>203dh<P20?OSb`80m^;:0`3ehLT00`3d
h<P0lmk=0??Nc@060??Nc@P0ln;@0P3_h]40103`hm80lNCC0??Ve@3dimH20?GXe`P0l^GD0`3aiMD3
0?;VeP80lnOG0`3biMD30??VeP80m>OG0`3aiMT40?;VfP80lnOK203gi=<80?;Sd0P0m>7@203dh/h@
0?;OcQ00kMk7203`flH80>[Ka0P0jmc5203^gL<80>cK`@P0k]g3403_g/@80?7NcA40ln3?203agl/0
103chLd0l^3<0?;Pc03bh<`20?7Ob`80l=k:0`3fh/X20?GQb@<0m>38203ah<h20?7Qa`80l>360`3_
glD90>kNa0<0kmk00P3^gKl30>gL_Q00k]c60`3`gKl20>oL_P<0k]^m203/fkd80>gL_P80kmbl0P3^
fk/30>gJ^P030>cI^@3bf<40lMO00080lMO00P3`e[l20>oE_P<0jmRj0P3ZekT30>WF^0<0jm:d0P3Z
dK<30>W@/P80ilj`00@0i/f_0>G<[P3Tbjd0hlZ/0P3RbJ/20>G8Z0<0i<NW0`3SaZH20>G8Z080i<NW
00<0hlJV0>;5Y@3RaJD00P3Qa:@20>70W@<0h;nL0`3O_Y/20>70W@<0h;nL0`3O_Y/80=k0W0P0gkjK
203L_9D80=nnV`P0h;nL103N_IX20=flV@80g;^H00<0gKfF0=blU@3J^Y<00P3I^I800`3J^Y<0g;bE
0=fmUP040=^hTP80f[NA0P3I]Y080=NgT0<0f;RA0P3G]i030=JfS`P0eKF>203G]i030=JfS@030=Fe
S03D]8/0dk>:0080dk>:00P0f[N?0=VfSP3H]Hd0e[>;0=BaR@3C/8P0dZn70=6^QP<0dJj40`3@[H<2
0<n/PP030<j[P@3?[880d:f30080dJj400H0cjb20<fZP03<ZGl0bZMm0<bYO`3=ZX020<n/PP090<fZ
P03<ZGl0c:Uo0<ZWO@3?[Gl0cJ]m0<^YN@38Yg@0aZE`0080aZE_00L0aZI]0<bXN03<Z7P0bjMg0<ZV
MP39YGD0b:Ad0080aj=c00<0aJ5a0<JRLP37Xg<00P38Y7@01036XW80a:1`0<:NKP31WFT20<2LJ003
0;nKI`2nVVH0_IUU0080_9QT0P2iVV<0102jVF<0_9US0;bIH`2mV6<20;nGH`060;jKI@2nVVH0_YYV
0;jJJ02nVVX0_YU/0P2oVVh0202nVfD0_YYV0;nKI`30W6X0`Ie]0<>NL@33WW80a9mc0`2nW6`20;fK
J`<0_9YZ00H0`Im_0<2NKP2nW6`0_9YZ0;^IJ@2lVVX20;fKJ`<0_9e^:oooool002[ooooo0`2VO4X3
0:MmB`80Z7i<202YP4`80:IlBPP0ZGm=0P2ZPD/30:V0BP<0Z7m90`2[PE430:b2DP80[H=C0`2]PTl2
0:j3D0<0[hAA0P2_QU80102^QE40[HA@0:f4D02/Pdl20:^2CP80ZhIA00<0ZXE@0:V4C`2XPdh00P2W
PTd01@2VPD`0XGe30:9nA02RODH0XWe80080X7]600L0WWU509afA@2JM4<0WGQ409]f@P2HLcl0UW4m
0080U6lk00d0UG0l09Ia?@2LK3/0W6`l09U[>P2FJS/0TfPk095X?02?IC/0SFHk08aY<`2:Ic40R6D_
00<0QF8/00P0QV<]08MT;P21Gbl0PEl_081N<01oGC00Oe`b07iK<`80OEXd00@0NUXa07QH;`1eEB`0
LE4X0P1`D2L00`1bDRT0Le<Z07QE;@0707QE;@80OEX`00H0O5T_07eJ<01oG380PEhd08AQ=`26HcT2
08AO<P0408IQ=028HcH0RF@g08]V>@80SFPk0P2EJSd409AY?080TfPk202BK3d0202FIc/0UfPl09M[
?P2GK3l0UVdo09=]?P2AJc`0Sf/k0`2@JS/00`2AJc`0TV`m09=]?P0209=]?P80T6Xk0P2?JCX308iX
>@0508eW>02FJch0U6Tl099W>P2@ICP00P2?I3L0102AIST0TVLj08mY>P2?JCX6091Z>`P0SfTj0P2A
IcD2099X=P0409=Y=`2DJSP0U6Xh09E[>@<0TfTg1@2BJ3H2099T<`0309=U=02DISD0U6He0080UFLf
0P2FJ3L208mY>P80T6Xk0P2AJc`2099/?@P0UG0k00T0UG0l09A_>`2CKSX0Tfhj09A_>`2FLCd0V7<o
09Ud@02BKCT00`2CKSX209A_>`80UG0l0P2HLcl0102GLSh0UW4m09Ia?@2EL3`209A_>`<0Ug<o0`2F
LSh209Ea?@P0U70l0P2ELCd309A`?0<0Tflk0P2BKSX0102CKc/0U70l09Ib?P2GLcl209Qd@080UWA7
00<0UWA609IdA02FMD800P2FMD00102FMCl0Sg4o091b@02BM48309AfA00R09=e@`2BM480SVm308a]
@@27JSh0PVLj07aT=P1gHC80Leh_075L;@1hHCL0M5ld06iH<@1VDRd0GT/Z05E49P1@@B@0CCdS04<j
7@10>Ad0?SLK03`f700i=A`0=C<L03<b7@0b<A`0;b`S02h[8P0Z:R009bTN02DW700R9AX07R@H01dS
5`<08RDL0`0Q91/2020S6P808B@I00@08bHK02@W700V:Ah09bXO0P0Y;2401@0T9a`08bHK020S6P0N
8AX071hI008071hK00<07AlN01`N6`0L7Q/01`0L7Q/0600I7a/06R4J01lR6`0T9Q/0;2XM03@^7P0j
<b40?SHS03hh601=A2D0ED`]05=8:P1A@bH0Dd@W05A39`1@?b<0>SHM034^6`0X91/0920O02<Q8P0U
9R4092PJ02<W5P<0:BXL0`0X:A/202LX6P809BHN0P0T9Ad202<T70808R<K00<08R<M020Q6`0O81X0
0P0N7aT00`0O81X0824K028S7@0201lP6P04020Q6`0Q8Q`08B8L028S7@808b@N01`0:AhH02DM6P0U
8Ah0:2LR030Y7`10;a/0GD8T07UG<P2>LT00UGU709]oC@2PQ580ZHeK0;6EH`2[Sed0Wh=A09V5B02J
OT`0XX1C0;2;E`2eTeH0X8=907EO=P1A@BX0<S<]02h_:@0[;2H0:R/U0P0[;2H01@0V9b408R<M02DV
800V9b40:2TS0080:R/U00<0:BXT02LX8P0V9b40200U9B<302@U7`<09BHP0P0V9b40200T9Al09BHP
02HW8@0X:B<0:BXT02//9P0/;BL0;BhX0P0b;R806P0c<240=34P03@a7P0e<ah0=S@O03Hd7@0f<b80
=34P038_800`;200;b/P02l[8P0`;2<0<B`V030_:P0a<BT0=C0Z03Xa:P0m<bX0@S@[04Hd:P17=B/0
AS@X04Le:@18=RX0AC<W0P11;b<00`16=2P0BSP/04Xh;00204Hd7P80AcDO00`0BCLQ04Xh8P1;>B<0
C3XT04dj:`1=>RT0CS/Z04lm:@1@?RP0DClW05509P1B@BL205509P80D3lU00H0CchT04hm8`1=?280
CC`R04lo:01@@2T20551:P0:0510:@1=?BH0BSXS04Ti8P1:?280BcdS04`l8`1>?2@0CcdU058n9P80
E3hW01H0Ed@T05U69P1LBBT0Gd`/061=;@1OC2`0GDXZ05a9:@1MBR`0GT/]061=;`1QCS00H4d_05i;
;@1LBB/0FdPZ05Y;;01HBB`0EDHY0592:01A@BP0DD4Z0P1B@Bd01P1:@B@0BT0U04To9017?B@0AS/U
04@i9@80@cPV00@0?CLY03`f:00i<bD0=c4S0P0e;b4203H`8P0803Lc9`0e<BD0<blS030/800_:al0
<2`P034]8@0b;R8203L]8@0403P^8P0j<2@0>c4U03dc9`80?S@X0P0d<B80100c;b<0<RhS034]900`
:bD202lZ9P<0<2`S00<0<BdT038^9@0c;bH00P0c;bH3034]90<0<2`S0P0_:b80200`;240<BdR03D_
8`0h<2<0?3<T040d9013=RH0A3LV100m>2@403hi9@0@04Ll:P19?2T0BSdZ04dn:@1=?BH0CC/S04di
801<>1l0ACXX04<h9P11=R@0@3DS03ld8P10=B<0@CHT048g9@<0AS@V00L0AcHV04Pg9@19>2@0BSXS
04/k901<?2<0F4<T00L0Ed8S00P0CS`T04dm9P1=?BH0Bc`W04Lj9`14>BL0?cHU03he90P0A3@T00h0
CCX/04`i:P1>>BP0DC/V05Q0:01OABX0ITd_06]@<P1_ERh0KE<^06U?;01UBR`0HTL/0614;080Gd<^
01h0H4H]06=8;@1VBbh0K4l_075C;`1fERl0NUT`07]J;`1eFR<0MehX07aR;`1nISH0OFLh07YU>P1e
HSP0Lf0h079O=`1XEBd0I4hW06M?:@1XCRT0JThY071D;`1lGSX0Me//07UM;P1mHC80PFDf08AX>@26
JS/208M[?00H08Q/A`27Jd@0QFU108AY?023J3T0Q6Xg08E/=P26KCD0Q6m007eX>@1hHS<0N60b07mT
=`24Ic/0QfPl08EV>P2DKSd0TVhl099^?P2?KCl0SVe008e^@P2;KT80S6m50P24JC`01023J3/0PVLj
085V>@20ICP207mT=`0;08YZ@@2;Jd80RFa208M/@@23Jcl0OfPl07]V>@1iI3L0MUXb07MK<`1jGSH0
0`1lH3P04P1jGSH0NEde07]M>@1nH3X0PVDm08Q[?`2>LT<0TgM509QmB02JOdP0Y8YA0:F;DP2ZSE<0
[Y1D0;:BE@2gUEH0^IMH0;bIF@80^ieM00@0_9iN0;jPH02oXF40`J=S0P32Y6@01`35Xf@0`j5R0<>Q
HP2oWEh0_9YK0;VGF02hUUL00P2gUEH0402hSU80]heA0;J<D02fS500^8iB0;bBEP31Ue/0a9YN0<VR
G`3;Y640cJIS0<nXI@3>Yf@0c:ER0<RQGP36We`20<jVJ@0>0<nWK03@Yfl0dZUc0=>ZMP3DZgL0e:Yh
0>?2S@3^cY/0oMfZ0?oW]@3ojKT0onFf0?_S]@3ihK<20?oS]`0>0?oR]03mgJh0m]BT0>c8UP3R_8/0
fkJ20=ZgP@3I]X00f;Eo0=NdOP3E/W`0e;5k0=>`NP3B[gT20=6aN080d[9i00D0dk=j0=BdN`3D]7/0
eKEl0=RgP@020=ViP00=0=ViOP3H^7/0e[Mg0=BeM03B/g80cZa/0=6bLP2oWf80ZX]B0:Z<EP2YSE/0
YH]J0:V>G`020:R>G@040:V?GP2ZT5l0Zi5P0:bBH@80[I=R00h0Yi5O0:bEH`2aVVP0]I]Z0;FIJ@2i
VV/0_im`0<>SM033Ygl0aj^40<ncS03G^iH0g/6O0>;5Y@80i<NY0P3TbZL01P3SbjT0i<^/0>C=[P3R
cK00h/na0>;>/`80glne02P0g/je0=c</`3IbK80eLB`0=;1[`3@_jd0dl2R0=:oX@3A_Z00ckbN0<fj
W03<^I/0b[NI0<VfV03;/Y<0b:n@0<J^S037[h/0b;2<0<N_R@32Zh80_JIm0;ZML@2gVVh0]YU_0;ZM
M@32Y7h0b:Z60<Z/R039ZhT0ckF@0=2fT`3@^9@0d[^I0=C0W`3HaJD0g<V[0=g<[P3NcK40hmBg0P3X
f;h01@3Xf/00iMW10>?H`P3Tg<D0i]k90080j^3F00H0jn7G0>gSf@3^i=X0knGK0?3Vg03aimd80?CZ
gPP0mN_O203fjnL01P3ajNL0l^[W0?;Zi`3ck>H0m>gU0?C]h`80mNoS0P3gjml50?S/h0040?W]h@3i
k]`0nNkL0?W^g080n>gK0`3gk=X30?WWc`80n>K>0`3giLd80?KRbPP0l^3:203_gLL80?3Pb@/0l=o=
0`3ah<h20?;Qc`80l>?B0P3ai=<20?;Ue080lnKE00@0m^CH0?GSe`3ehmL0mN?G0P3dh]H20??Qe@P0
l^WJ0P3giML20?KTeP<0mN?E00<0m>;D0??Sd`3chm<00`3bh]830?7Qd@030?3Pd03bhlh0l^?>0080
l^?>103ah/d50?;Sd0<0lnCA0P3agm420?7Pd0040?3Oc@3`gl/0l>390?3Pb@80m^;900@0mN780?CP
a`3cglH0l]k50P3agL@20?3L`@<0km_00`3^f[l20??I`P040??I`03cfKh0l]Vk0?;I^P80lMVg0`3_
ekD50?3H]P80kmNe0P3^e[@0103]eK<0k=Bb0>cD/P3[dk450>cE]@<0jmBd0`3/e;P00`3[dkL0j]:f
0>WA]@020>WA]@80jM:b103XdK420>O@/080j=2d0`3YdKD30>[B]P/0jm>g0`3/e;P40>gE^@<0k]Jj
0`3_ek/30>cG^P80kMRk0`3^fK`80>kI_PX0l=_00P3ag<440?;M`P030??N``3^g<@0k]c400h0k]c4
403_gLD80>kM`@P0k]c400@0l]Zn0?7I_@3afKd0lMVm0P3`f;`20>oG^`80j]S00P3[fL430>cJ`P04
0>gK``3^fKh0k]Vn0>kI_P80kMRm0`3/ek`80>oF`0<0kmFj0P3`e[/30?7G_0P0kmK0203_eK`20>cG
_080jmJk0`3ZeKX0103Ye;T0jm>g0>_C]`3[dkL20>[B]P<0jM6e00P0k]6a0>g@/03/cjl0jlj^0>[=
[@3Yc:`0j<^[0>O:ZP<0jLb/0P3Xbj/30>O:ZPP0i<NU0P3Vb:H00`3UajD0i<JT0>?5X`020>?5X`03
0>;4XP3Q`j40h;nL00L0h;nL203Q`9d30>2oW0030=nnV`3N_IX0gKbI0080gKbI2`3N_IX30=flV@80
g;^H2P3N_IX20=nnV`0<0>2oW03Q`9d0hL2M0>;1WP3T`I/0hl2J0>:oV@3P_IL0g[^E0=fjU03L^I<0
fkRB1@3K^YL30=ZiUP80gkbD00@0g[^C0=biT@3K^900fKJ>0P3H]Hd01P3E]XL0eKJ80=FfR03E]XX0
e[J=0=JfS`80ekNA0P3F]Xl40=NgT080f;RA0`3D]8d20=FeSPH0e[J?0P3G]i030=RhT@P0e[FB0P3F
/h/0103E/XX0e;690=>`R03C/8P20=:_Q`80dJf900H0dJj80=2]Q@3@[H<0d:j10<n]P03?[Gl80<j[
P@<0c:Uo0`3;Z7h30<ZWO@80c:Mj0`3;YWT30<ZUN00@0<^VNP3:YGT0bZEh0<VUM@38Y780aj=_0<JR
KP36Xfd0`Ye`0<>OK`35XG40aZ9`0<JRKP36Xfd0a:5Y0<>PJ0P0_YYV202mVFD00`2jUf40^iQR0;fJ
I0020;jKI@030;fJI02kV680^YMQ0080`9]^0P31W6l01032WG00`iia0<BOLP34Wg830<>OK`80`Yi^
0`31WFd80;nKJ`<0_IUU:oooool002[ooooo0`2VO4X30:MmB`80Z7i<202YP4`80:MmB`P0ZGm=00<0
ZH1:0:Z1B`2ZPD/01@2ZPD/30:^1D@<0[89B0P2]Pe<30:f2C`80[X=@0`2_Q5400`2_QU80[XEA0:j5
D@020:f4D080[8=?00L0Zh9>0:^6D@2[QU40ZXE@0:V4C`2XPdh0Yh9=0080YX5<00@0XWi40:=oA@2S
OTL0Xgi90P2QO4L04@2ONTH0W7I509]eA02MN4@0VgI209Ud@02FLCd0UG0l09A_>`2EL3`0UW4m09a/
>`2JK3/0VF/j09IZ>`2CJ3/0T6Lk0080SFHk00@0S6Pd08YV<P28I300QV8^0P25HBd02026HRh0Qf<_
085O;`21Gbl0P5h`07mM<01oG380OU/c0P1mFS@01@1jFS40N5P_07IF;@1dE2/0Le<Z00<0LU8Y201h
EBd207aI;`0607]H;P1lFBl0OU/a081M<`23H3H0Q64g0P24Gc801026HC@0R6<f08UT=`2;IST208eX
>`H0U6Tl0P2CJ3/8099/?@0809IW>`2GJ3`0Uf/n09M/?`2FKCl0Tfdn095[?02?Jc/208mY>P80T6Xk
0P2AJc`2099/?@80T6Xk0P2?JCX408iX>@0809EZ?@2DJC`0TVLj091U>02?I3L0T6Dh095V>@2BIcX5
091Z>`/0SfTj00<0TFLe099X=P2BJ3H00P2CJCL209AZ>00309E[>@2DJSP0U6Xh00H0TfTg0P2DISD2
09EW=P<0UVPg0P2GJCP4095[?080TV`m0P2CKCh809E`>`0809A_>`2CKSX0TVdi099]>@2CKSX0U6lk
09Ia?@2GLSh409=^>P80U6lk0P2EL3`00`2HLcl0Ug8n09Mb?P0209Ia?@80UG0l00<0U6lk09Ib?P2F
LSh01P2FLSh809A`?080UG4m0`2DL3`309=_>`05099^>P2CKc/0Tflk09A`?02FLSh00P2GLcl01P2H
M400UWA709IdA`2FM4H0UWA409Ie@P80UWE000@0UWDo091b@02ALd40TgE30P2DMT@06@2CMD<0TWA2
095c@@2<KD40Rfa008IY?@22IcX0O6@f07MQ<P1dGc00LUd^07AM<`1`Fc00JeD^06=?:P1KB2L0DT4S
04dn8@1:>R00@SPM040i7@0n=ad0>cDK03Te700e<a`00P0b<A`0200^:b80;BXQ02XZ800W:Ah09BLL
028U6P0O9AT07R@H0`0R9A`2024T6`<082<J0P0Q91T02`0R9AX092LL02HY7P0W:Ql0:2/P02T/8@0T
9a`08bHK020S6P0N8AX071hI008071hK00<07AlN01`N6`0L7Q/01`0L7Q/0600J81`06R4J01lR6`0S
9AX0:bTL03<]7@0i<R00?CDR03he501:@B00DdPX04m4901>@B40D44R050o8@1;>Q`0>CDL030]6P0X
91/08alN028P8@0S91l08bLI028V5@<0:BXL0`0X:A/202LX6P809BHN0P0T9Ad202<T70808R<K00<0
8R<M020Q6`0O81X00P0N7aT0100O81X0824K028S7@0O81X2020Q6`808B8L0P0R8ad0900S91h0:1lH
02<N6P0T8al0:RTT03</8P13<Qh0H4DW07eK=P2AMD<0VWi<0:>7E@2XS5X0[i=Q0;BHIP2[Sed0WH5?
09V5B02JOT`0XX1C0;2;E`2dTUD0X8=907IP=`1B@R/0<C8/02d^:00Z:bD0:BXT02//9P0Z:bD09RLQ
028S7@0T9Al09RLQ02LX8P80:BXT00<0:2TS02HW8@0U9R00200U9B<302@U7`<09BHP0P0V9b401P0T
9Al09BHP02HW8@0W:280:BXT02//9P80;2dW01`0<2`P034]8@0b;b00<c0Q03@a800e<Ql0=S@O03Le
800f<b80=34P038_800`;200;b/P02l[8P0`;2<0<B`V02d]9@0^;RH0<RhU03L^9@0j<2H0?c4V04<a
9`14<RH0AC<W04Le:@18=RX0AS@X0P12<2@00`17=BT0BcT]04/i;@0204Le7`0<04Pf8019=b40BSPR
04/i8`1<>R@0CC/U04dj:`1=>RT0CS/Z04lm:@1@?RP0D3hV0P1A@2H3050o9@80CchT0`1>?B<00`1>
?RL0CclX0510:@020510:@0904hn9`1;>b@0BSXS04/m8`1<?R@0CCdT04lm9@1@?RH0DclW0080EClX
00@0FDHV05Y79`1LBBT0GDXZ101NBb/00`1LBB/0GDX/05m<;P0205m<;P0F05e:;01KB2X0FTLY05Q9
:P1GB2/0E4DX0592:01@@2L0D40Y050o:`1A@2`0BT0U04To9018?RD0AcdT04Dj9014>BD0@cPV048g
9@0m=bT0>cDW03Tc9@<0=c4S0P0h<R@0100h=2P0=S8V03@`900b;R82034]8@0:038^8P0c;b<0=bdQ
03L]8@0h;R80>S0T03/a9@0l<RH0?C<W03hd:080=34R00@0<blS038^8`0a;B@0<2/U0P0_:RH2030/
8`80<BdT0P0b;RD203<_9P<0<BdT0`0`;2<202l[8P08030/8@0a;B80=BlS03P`8`0l<b@0@3@T04<f
9P14=bH303df8`0303hg900o>2D0@3TV0080@3TV00/0AS/Y04Pk:01:?BX0CChY04dm9P1=>b<0CSXQ
04di8015>RP0@cPV048g9@03040e8`03044f9012=bD0AcDW0080AcDW00H0B3LW04Th9P1:>BD0Bc/T
04`l9@1=?B@405I18P@0Ed8S00H0D3hV04hn9`1<?2D0B3TT04@g9011=R@203he90P0A3@T02d0BCHX
04Tf9`1;=RD0CSPS05@l901K@bL0HTT[06I=;P1/DRd0Je4/06M=;01TBB/0HTL/0655;@1QABl0HDD`
0657;P1RB2d0IT/^06]>;P1`DRh0MED^07MG;P1iF2d0MU/V07UN:@1kHBh0O6@d07aV=`1jICX0N68i
07ER>01bGcL0JEH^06E?:01WCbT0JDlZ06Y>:@1`E2l0Nedi07UM;P1kGc00Of<d08=W>025JCX00`27
Jc`04026JT<0QFU208AX@023J3/0PfPi08AZ=`25K3H0QVdg08=^?`1mJ3T0N68c07QP<P1nHcH0PfHj
08EV>P23I3P2095]>`0<08m]?@2>KSl0S6do08a]@@2:KD40RVe308Y_@P29KT40R6e008M/?`26Jch0
Q6Tl0P23J3/0802:Jcl0Rfa008U/@027K3l0Q6`n081Z>`1lIcP0NVDf07IJ<P1hG3@0NUhf07aP>01m
HCT0O60h07]O=`1jGSH0O60i07iR>`21ICd0QV/n08]`@@2@MT<0U7]509ImA`2OQD`0X8I=0:F8CP2Y
S500[i5C0;>CEP2hUUL0^YQI0P2lWUh0102mWel0_Z1P0<2RHP31Xf<20<:TI0060<>QHP31Wf00`ImP
0;jLG@2jV5T0^9IG0`2fU5D0402gSe80]XiA0;F=D02eSE00^91C0;bDE`31VE`0a9aO0<RQGP3:Xf00
cJIS0<nXI@3>Yf@0c:ER0<RQGP36We`20<fUJ00N0<jVJ`3?Yf`0d:M_0=6XLP3BZGD0djYf0>70R`3/
biH0n]ZW0?oU/`3oi[H0o^>d0?_P/@3hh;80on:f0?oR]03oh;80nm^/0??AX@3ZaY@0h;^70=ZeP@3I
]Wh0f;Em0=NdO03F/g/0eK9j0=BaN@3C/7P0dZmg0P3A/GP20=:bN@80dk=j0P3D]7/04@3G]X00ekMn
0=RhO`3H^7d0e[Ii0=BeM@3B/g80d;5`0<f[J`3@/G40_YiQ0:V:D@2YReD0Z8aJ0:B:F@2YSUl0Z8iM
0080ZHmN0P2ZT5l06@2[TF00[99Q0:bBH@2WTEl0[9ES0;6JJ02dVVT0]IUY0;RIJP2nWVl0`Z9c0;jR
NP33Ygl0bjn80=BhT`3K_Y`0gl:R0>74Y03RaJL0iLRV0>?9YP3TbZT0i<^/0>C=[P3RcJh00P3Rck40
203Nck80g/jd0=g=/`3Lc;<0fLVb0=K5/@3B`Jl0d;n]0P3C`:80103A_Z00ckbN0<jkW@3<^I/20<Zg
V@0J0<^bT`38[i00aZj<0<N_R`38/8`0ajn90<:[PP2mYWd0^Ia`0;JIK@2eV6h0^Iad0<6SO@37ZHD0
bJ^70<V[R@3>]940ckFB0<ngU@3A^YX0dkjO0=O4Y03Kb:X0g<^]0=o>/P3SdkT20>SH_P050>WK`@3U
fL40hmS20>CLa`3WglX00P3Zh=H0103[hML0kN?I0>kTfP3`i]`20?7Wg@P0m>[N203ejml80?K[i@08
0??Yi`3dj^P0m>_V0?G/i@3ek><0m^kS0?K^h@3gkn850?SZg`<0nN_P0`3ik=T20?S[f0<0mn[G00@0
nNO?0?SVcP3hi/h0n>K>0P3giLd20?KTc0P0m^;:203bh<X80>oMa`P0l>392`3`gld20?7PcP<0l^7?
0P3`hm820?7Td`80l^GD0P3ci]D40?GSe`80m>;F0P3chMD80?;YfP<0m^CF0P3ehmD30?CRe0<0lnCA
0`3bhm030?7Rc`@0l^?>103ah/d50?3Oc@<0lN3>0P3bgm00103bglh0lMo;0?7Ob@3aglT20?3NaP06
0?;Na@3agL@0lMg40?3L``3_fl80k][10P3]fL00103^fkd0kMZl0>gJ_03]f[`20>cI^`80jmRj0P3^
d[X00`3^dkP0kM:e0>gB]0020>cB/@030>cB[`3Zd:l0j]2_00<0j]2_0`3[dK000`3Zd:l0jLn^0>W?
[P020>S>[@030>O=[03Vc:/0i/b[00H0iLj^0P3TcJd20>K?/080iLj_00@0i<f^0>?<[@3Sc:d0hlb]
203UcZh20>G>[`80i/n`0P3Wd;420>SA/PP0i/n`0P3XdK830>WB/`<0j]>d103[e;D20>cE]P80kMJg
0`3[e[L20>cG^0<0kMRi203]f;d;0>kI_P<0kmZo0`3`fl0@0>oK`Q00l=c3203_fl080>oK`P040?7I
_@3`f;`0l=Rl0?3H_080kmNk0P3^e[X20>_G_P80k=Ro0`3]fL00103^f/40kMRm0>gH_@3]f;d20>cG
_0<0jmJk203^e[h30>kD^@80kmFj0`3`e[/80>oG_`P0k]Bk0`3[e[/20>[E^P<0jMBi00@0jmBe0>[C
]03Zdk@0j]>d0P3Yd[<20>SA/P060>g@/03/cjl0jlj^0>[=[@3Yc:`0j<^[0P3WbZX20>W<[080j<^[
0`3WbZX00`3VbJT0i<NU0>C7Y@060>C7Y@050>K8YP3UajD0iLNU0>C6Y03SaJ<00P3Ra:820>73X@P0
h;nL203Q`9d20>2oW080gkjK00@0g[fJ0=flV@3M_9T0gKbI2`3N_IX20=flV@<0g;^H2P3N_IX20=nn
V`80h;nL0P3Q`9d0203S`9X0h[nI0>6nV03P_IL0g[^E0=fjU03L^I<0fkRB1P3K^YL20=ZiUP80gkbD
00@0g[^C0=biT@3K^900fKJ>0P3H]Hd01P3D]HH0eKJ80=FfR03E]XX0e[J=0=JfS`80ekNA103F]Xl4
0=NgT0<0dk><0`3D]8d20=FeSP<0e[J?0`3G]i020=RhT@P0e[FB0P3F/h/00`3E/XX0e;690=>`R002
0=:_Q`060=6^QP3A[HT0dJf90=6^R03@[HD0d:f30P3?[H000`3?[Gl0cZ^10<j[P@060<j[P@<0c:Uo
0`3;Z7h30<ZWO@80c:Mj0`3;YWT30<ZUN080bZEi00h0bJAg0<VUM@38Y780aj=_0<JRKP36Xfd0a9mb
0<BPL036XW80aZ9`0<JRKP34XF/0`j1X0<6NIPP0_YYV202mVFD00`2jUV80^iMS0;fII@020;jJIP04
0;fII@2kUf<0^YIR0;nJK@80`9]^00<0`Ia_0<:ML033WW400P34Wg820<>OK`<0`Yi^0`31WFd80;nK
J`<0_IUU:oooool002[ooooo0`2VO4X30:MmB`80Z7i<202YP4`@0:UoC@80ZH1:00@0ZX5;0:^2C02/
Pdd0[8==0P2]Q4h30:^1C`<0[89@0P2]Pe430:f2C`80[X=@0`2_Q5430:j5D@80[HA@0`2/Pdl01P2[
QU40ZXE@0:Z5D02YQ4l0Z8=>0:N2C@80YX5<00@0Xgm50:B0AP2TOdP0Y7m:0P2SOTT01`2PNdL0WWQ7
09afA@2LMd<0VgI209Ud@02GLSh0102EL3`02`2JK3X0VF/j09IZ>@2DJSX0TVTk08iX>`2=IS/0S6Lk
08]W<`2:IS80R6@`0080QV8^00<0QF4]08IR;P26HRh00P21Gbl01020GS00Oed`07mL<P1nFc<207eJ
=0<0NET`00D0N5P_07MG;P1eEB`0Le<Z075A:00807QE;@80NeP^00H0NUL]07]H;P1lFBl0OU/a085N
=022GcD208AO<P0408IQ=028HcH0RF@g08]V>@80SFPk1@2CJ3/309AY?0P0TV`m00P0UVLk09MX?02F
JSd0UV/n09E/?P2BK3d0TF/l08m[>`<0SVPi0P2?JCX6091Z>`80SfTj0`2>J3T00`2DJC`0TfPk099W
>P03091U>003095V>@2BIcX0TV`m0080TF/l00<0T6Xk08mY>P2?JCX00P2>J3T808mY>P80TVPf0P2C
JCL409AZ>0P0UF/i102EJCP309IZ>@80Uf/j00@0TV`m09=]?P2CKCh0Tfdn0P2DKSl209E_@0P0UG0k
00P0Tfhj099]>@2AK3P0T6/g095/>02BKCT0U6lk09E`?0<0Tfhj0P2DKc/309E`?0<0Ug8n0P2FLCd3
09E`?0<0U70l00<0UG4m09Ib?P2GLcl00P2HM40809A`?080UG4m0`2DL3`509=_>`0409A`?02ELCd0
UG4m09Ib?P80Ug<o0P2FM4L00`2FM4H0UWA409Ie@P0209Ie@00Y09Ie?`2CMD<0TgE309AfA02EMdD0
U7I4099d@P2@LT00SW0n08Y[?`29JSh0Q6Lk085V>@1lI3H0N68c07EP<@1dGc00L5T_06eH;@1YDb`0
HDdX05U69@1A@280BS/N04Lg7@12>1d0?cPN03hg7@0k=Ad0>3<M03@b7@0b<Ad0<C0L02h[8P0]:R40
:RXP02LY7P0U9a`08RDJ01lU6@0N91P00P0R9A`2024T6`<082<J00h07b8I024T6@0Q91T08RDJ02@W
700U:1d09RTN02LZ7`0X:b0092LL02<V6`0P8aX07R4J01`N6@8071hK00<07AlN01`N6`0L7Q/01`0L
7Q/0600K8Q/06b8J01lR6@0S9AP0:RPI038]6P0g<1d0>c<N040h501=@b00E4XW05=6901A@R40E4@S
05=0801<>AT0>CDL030]6P0W8aX08AdL020N7`0R8ah08BDG024U50<0:BXL0`0X:A/202LX6P809BHN
0P0T9Ad202<T70808R<K00<08R<M020Q6`0O81X00P0N7aT00`0O81X0824K028S7@03020Q6`808B8L
0`0R8ad0300W7QL08ahJ02DT800/;BL0=30U04Hg8P1TBb`0P60j09EiA`2QQE<0[I5O0;>GI@80^9aZ
00`0ZhmM09b0CP2IQDP0VWi<0:5oDP2_RUH0]99E0:64BP1gHCP0E4@]034b;00/;BL202PY8`80:BXT
00H09RLQ028S7@0T9Al09BHP02HW8@0W:28202HW8@0302DV800T9Al09BDS00L09BDS0`0T9Al302DV
80809RLQ00H092DO02DV800V9b409bPR02TZ900Z:bD202//9P0=02hZ7`0_:b00<2`P038_800d<B00
=C8O03Ld8@0g=B00=C8Q03@a800b;b00<BdQ030/8@02030/8`0=030[9@0[:b<0;2`R030/8`0e;2<0
>2hT03`^8`11;b<0@S0T04<a8`16=2H0B3HX04Le9`0204@b900304Pf:01=>bd0CC/]0080BCLQ00<0
BSPR04`j901=>bD00`1=>bD01P1<>BX0CCXY04dj:@1>?2P0CcdW050n9P80DD0V101>?2@304lm9@04
050n9P1=?BH0CCdV04hn9`80CclX00<0CShW04dm9P1<?2D00P1=?bD01P1??bH0DClW0590:01E@BT0
ET0Y05M1:P@0FdPX00D0G4TY05e::P1OC2`0H4d]05]8:P0205a9:`0;05e:;01LBB/0FdPZ05Y7:@1I
ARP0ETLX05E6:@1CA2L0DD4W04lo9P1??bP00P1??RX01P19?b@0B3hU04Lm9016>bD0ACXV04<h9P80
@SHV00<0?3HX03/e9`0i<bD00P0h<R@01`0i<bD0>S@V03/e9`0h=2P0=c<W03Hb9P0d<2@00`0c;b<0
2@0d<2@0=R`P03L]8@0h;R80>BlS03/a9@0l<RH0?C<W03hd:00203@a8P0403<_8`0b;R<0<BdT030[
9@80;bXV00@0<2`S034]900a;B@0<BdT0`0b;RD0100c;bH0<BdT034]900a;B@3030/8`80;b/R0200
<2`Q034]8P0e;b<0>30S03/b8`0o<b<0@SDU04<f9@0l=240?CDR03hf8`0o=b@0@3PU044i9P12>RL0
@c/X04Hk:@18>bP0BC`Y04dn:@1>?RL0CS`T04hj8@1=>B00ACXX04@i9`12=bD0@CHT040e8`11=R@0
@SLU04<h9P<0BCLY00<0BSTY04/j:01<>bL00P1=?BH01P1>?RD0Dd0R05=08P1C@280E44S05E29080
ET<U00L0Ed@V0590:01>?RL0BSXS04Df8@10<b00?S<Q0080?C@S2012=B@0;@15<bD0AC@T04Hc8P1:
=B00D3XR05Lo8`1MARL0HDPY06M?:`1VCR`0I4`Z0699:P1QB2X0HDL/0698;`1SBC00HTX`06=;;`1U
C2h0J4h]06eA;01`Db/0M5@[07IG:`1jG2X0Ned[07YN;P1kH340Nf<e07]T>01jICX0NfHk07AQ>@1Z
Ebl0Ie4Z06UA:`1ZD2/0JThY071D;`1jG3P0OF4a07mS<`22ISH0QFTi08M[>`0308Q/?00/08EY@@24
J400PVLl089W>P22IcP0PfTh08E[>026K3T0PVdn07eX>@1iHc@0NF4c07eR=@20HcL0PV<g085R=P2@
K3X0SVdj08i/?02<K3d0Rf`n08Q[?`26Jch0QV]0091eB02?M4L0SW=608aaA02:Kd80RFi108Q]@027
K3l0RV/o08]/@029K400R6e008E]?`22K3d0OVTj07eX>@1hGC80NEhc07]P=@1mHSL207iS>080OF8g
0100OV8j081T?023J3d0QV/n08Y_@02=Ld80T7I3099hA@2GOTH0VH1809j4B`2UR4h0ZheA0;:BE@2e
UEP0^YQI0P2oX6020<2QH@050<6RHP32Xf<0`jAT0<>TI030WUl00P2nW5d00`2kVEX0]iEF0;FCE003
0;BBD`0;0;J>D@2eSE00]He@0;F=D02iTE@0_YII0<>KGP36WV40b:5N0<ZSH03=YV<00P3>Yf@00`3;
Y640b:5N0<JOG0020<^SI@030<bTI`3=YFX0cZE]0080cjI`00L0d:Mc0=jkQ@3WaY40m]FP0?oO[03o
h[00nmn_0080n=f^00P0o>2a0?gN/03kg:d0mmNV0>o>V`3W`hl0gKR40=NbO@<0e[=k00<0eK9j0=Ba
N@3C/7P00P3B[gL20=6aN0<0d[9i0`3C/gX0403D/gd0eKEl0=FeO03E]GX0dk=f0=6bLP3>[fh0cJi]
0<^YJ@3>[fl0_IeP0:R9D02XRU@0Yh]I0:>9F02XSEh80:V?GP120:J@GP2[U680/9UW0;>IJ02cUfL0
]YMX0;bLK@30X740^iid0<2SN`38Zh<0dK>=0=VkU`3M_id0h<6R0>72X`3Uaj<0i<RS0>G8YP3TbZT0
i<^/0>C=[P3ScZl0hlja0=g<[P3NcK40gLb`0=c;/@3Jb;00elF_0=C2[P3B`:`0e<6S0=?0XP3B_j40
d;fO0<jkW@3<^I/0bkRJ0<ZgV@3</i@0bK2A0<J^S037[h/0b;2<0<N_R@31ZX40_:El0;NJKP2eV6`0
]9M]0;RKL`30XW`0ajV50<V[Q`38ZXP0c;:?0<fcTP3>]Y@0d;VI0=:mWP3F`jD0flN/0=_:[P3Oc[@0
hm>i0P3Xf;l02`3Yf/<0iMW30>CIa@3Tg<L0imo<0>[PeP3[hML0k>;H0>gSf@3_iM/0l>KL0080lNOM
203dj]h80?G[g`P0m^_U00H0m^_W0?K[i@3fjnD0mngT0?O]h`3gkN420?S_h0P0mn[J0P3hjmP30?OZ
e`<0m^WF00@0n>K>0?OUc@3giLd0mnG=0P3fi<`20?GSb`P0mN79203aglT80>oMa`P0l>392P3`gld2
0?7PcP<0l^7?00<0ln;@0?3SdP3`hm800P3ai=<20?;Ue080lnKE0`3ehmD20?CRe0<0ln7C203cimL3
0?GTe080m>?C0`3ch]830?CSd@<0ln;@0`3bhLl30??Sc080l^;;0`3ahLX80>oMa`80lmk;00<0l]g8
0?;NaP3agL@00P3agL801`3`gKl0l=Rl0>oG^`3_ek/0k]Jj0>gE^@3/e;P00P3[dkL0103/eKH0jmBe
0>_D]@3[e;D20>[C]080jM:c00P0j<Z`0>S:[P3WbJd0ilZ/0>K9Z@3VbJL0i/ZU0>G9Y0P0i<NU00@0
hlJT0>;5X`3RaJ<0h/FS0`3Qa:800`3P`j40gLFS0=g5X`060=g5X`040=o6Z03NaJL0g/FW0=k5Y`<0
gLBV00<0g<>U0>79Y`3QbJL01P3QbJL30>;9Z`80hlZ/0`3Tbjd80>;9Z`<0iLb^0P3VcJl50>O>/080
j<na0P3Yd;820>[A/`<0jmBe0P3/eKH30>gF]`P0k]Jj2@3/e;P30>gE^@<0k]Jj0P3_ek/@0>gI`100
k][1203]f[`80>gI`080kmNk0P3^e[X30>gE^@030>cD^03YeK`0j]Jm0080j]Jm0P3[ekh20>cH_`04
0>kF^P3]eKT0kMFi0>gE^@80k=Bh0P3[dkL80>cD_080k=:g0P3]dkP30>kD^@030>oE^P3^e[h0k]Jn
00H0k]Jn203]dkP20>cD^080jm>g0P3Zd[H20>WA]@<0j]6c0P3Yd;830>S?/@80jlj^00@0j/f]0>W<
[03Xbj/0j<^[0P3WbZX30>S;Z`80ilZZ0`3VbJT80>?6Y0050>G7Y@3TaZ@0i<JT0>?5X`3Ra:800P3Q
`j420>32X0P0gkjK203P_i`30=nnV`80g[fJ0`3M_9T:0=jmVP80gKbI0`3L^iP00`3K^YL0g[fJ0=jm
VP080=jmVP<0gkjK0`3P_i`20>:oV@060>6nV03O_9H0g[^E0=fjU03L^I<0fkRB203K^YL20=nlU004
0=jkT`3L^I40fkR@0=VfSP80f;F=00H0e;F60=BeQ`3D]HL0eKJ:0=FeS03F]Xl20=JfT0P0e[J?0`3A
/HX20=:bR`<0dk><0P3E]Hh20=JfS`<0ekN@00<0f;RA0=JeTP3F]I801P3F]I801P3F/h/0eK::0=Fb
RP3D/HT0dk280=:_Q`80dJj60P3A[HT00`3@[HL0d:f50<n/PP020<n]P0030<j/OP3>Zh40cZ^100H0
cZ^10`3<ZGl30<^XOP<0bZMm0P3<YgX30<^VN@<0bZEh0P3:YGT00`39Y7L0b:Ad0<NSL@020<JRKP09
0<FRK036XG@0aZ9b0<NSL`36XW00aJ5]0<>PJP30WFD0_iaT00P0_YYV202lV6@00`2kUf<0_9QT0;fI
I@020;jJIP030;fII@2lV6@0^iMS0080_iY]00<0`9]^0<6LK`32WG000P33WW400`34Wg80`im_0<:N
KP020<:NKP80`Ie]0P30W6`80;nKJ`<0_IUU:oooool002[ooooo0`2VO4X30:MmB`80Z7i<202XOd/8
0:Z0CPP0ZGm=0P2YP4X01P2ZPD/0[8==0:f4CP2^QDl0[hI@0;27D@<0Zh9>0`2/Pdl20:f4D0<0[H9?
0P2^Pe030:n4D@P0[HA@0P2ZQE000`2YQ4l0Z8=>0:N2C@020:J1C0050:F0B`2TP4H0Y8160:F0B@2U
P4/00P2SOTT00`2QO4P0WWQ709egAP0209]f@P0409Ud@02HLcl0UW4m09E`?080U6lk00`0Uf`i09IZ
>@2EJcT0Tf/j08mY>P2=J3/0SFPl08YX>`2:IS@0RFDc08QT<P27Hc4208IR<080QF4_0P21Gbl01020
GS00Oed`07mL<P1nFc<207eJ=00807QH;`1iFC00Ne/b07]K<P1jFS40MUH]07=C:P1aDBP807UF;P08
07]H;P1jEbd0NUL]07YG;@1kF2h0OEX`07mL<P21GS@208AO<P0408IQ=028HcH0RF@g08]V>@80SFPk
0P2BIcX409=X>`80U6Tl202BK3d209MX?00309EY?02EJSd0U6/m0080TF/l00<0T6`l08iX>@2>J3T0
1P2>J3T2095[?080T6Xk0P2?JCX208iX>@<0TVLj102AIST01P2BIcX0TV`m099/?@2AJc`0T6Xk08mY
>P80SVPi00<0SFLh091Z>`2@JS/01P2@JS/209=Y=`H0U6Xh0`2EJcT409I/>P0309M]>`2FK3X0UV`j
0080UV`j1@2GKC/309A^?`80UFm00`2FL44809E`>`03099]>@2AK3P0T6/g0080SfXf00<0T6/g099]
>@2CKSX00P2CKSX209A_>`80UG0l2P2FLCd2099^>P0609=_>`2ELCd0UW8n09Mc?`2HM400VGE1202D
L3`209Ea?@<0U70l102CKc/209A`?080UG4m0P2FLSh01P2GLcl0UWA709IdA`2FM4H0UWA409Ie@P80
UWE000<0UWDo09EgA@2EMdD00P2EMdD0102CMD<0TG=108i`?P2<KS`208MX?00N08=V>P1oI3L0Nf<e
07QR<`1eH340M5l`071I;`1]F2d0JU@]06=?:P1KB2L0Dd8T04`m8019>Al0@SPO03lh7P0n=Ql0>cDO
03Pc7`0d<Ah0<S4O034`7P0]:R40;2TP02TY7`0W:Ah09BLL02<V6`0P9QX07bDI0`0Q91/3020S6P80
7b8I00D08B@I028U6P0R9AX08bHK02DX7@0202HY7P0602LZ7`0T9a`08bHK020S6P0N8AX071hI0P0L
7Q/00`0M7ah071hK01`N6`0701`N6`0H01`S6`0L91T082<H02@V600Z:AL0<RdI03La6`0k<a`0AchG
05998P1JCRP0FD/V05Y:9P1MBbL0FDDR054m6P0j=Qd0<2dJ02HR6@0P71/07adN020Q700Q9AL082@C
0`0Y:Q`302PY6`809bPJ0P0U9Qh202@U7@808b@L0P0R8a/00`0R8ad0824K01lP6P0201hO6@0301lP
6P0P8A/08R<M00P08B8L02009AhF028O6P0U9R40;2lX03Dc9`16>R@0IDh^081R?02FNTP0YHUG0;BH
IP2jWV`0_:1^0;RLJP2ZSU`0VWi<09V5B02IOD/0X7iA0:n:EP2dTUD0XXE;07US>P1FARl0<C8/02`]
9`0W:2809RLQ02PY8`0Y:R@09RLQ02<T7PD09BHP00<092DO02<T7P0S91h0200U9B<302@U7`<09BHP
0P0V9b4202DV800402HW8@0W:280:2TS02TZ9080:R/U00P0;BTP02hZ8@0_:b00<BdQ03<`8@0e<R40
=S<R03Ld8@80=34P00<0<c0Q038^8P0a;B800P0`;2<01`0`:bD0;BdS02d]8@0b;R<0=blT03T_8`0n
<2<00P13<B<01013<R80ASDU04Th:018=bL204He9@0704Th:01=?2`0CC`/04Xh8P1;>B<0CC/U04hl
9P0204lm9`0:04hl9P1=>bD0C3TZ04`i:01=>RT0CS`X04lm9`1@?RH0D3lU05509P80C3XT00<0CC/U
04hl9P1??BL00P1@?RP00`1A?bT0C3`U04`l9@0204dm9P@0CShW0P1>@2H03`1@@2L0DT0X05=1:@1F
@RX0Ed4Z05Q2:`1MBRX0G4TY05Y79`1IARH0FTLW05e::P1PCBd0HTl_05Y7:@0205]8:P80FTLY00T0
FDHX05Q59`1HABL0E4DV05=49`1B@bH0D40V04lo9P1>?RL00P1=?2P204Pn9@0404Ll9P15>RH0A3TW
048f9P80@CDW00<0>cDW03Xd9P0i<bD00P0i<bD0200j=2H0?3HX03dg:@0i=BT0>3@X03Lc9`0f<RH0
=C4U0`0d<2@203H/800403L]8@0i;b<0>S0T03`b9P80?C<W0P0d<B80100c;b<0<RhS034]900`:bD2
02lZ9P@0<BdT100b;RD3034]90<0<2`S0P0_:b80200`;240<BdR03D_8`0g;b80>c8S03hb8P11=2@0
@SDT0P0l=240100m=B80?cLT040h9@12>RL204<k:00@04Dj:017>RL0BC`Y04`m:01>?RL0CS`T04lk
8P1>>R40AS/Y04@i9`12=bD0@CHT040e8`11=R@0@SLU04<h9P<0BcT[00H0BcXZ04`k:@1=?2P0CCdV
04hn9`1>?RD204ln8P03050o8`1A@2@0DT4U0080Dd8V00T0E4<W05=1:@1??bP0B3PQ048c7P0m<1d0
?34O03`c8P0m=2<02011=R@0;014=2D0A3@T04He8`1:>280D3`S05I1901LABH0GdPX069;:`1QBRX0
H4TY05m8:@1PBBX0HDX[06=;;`1TC300HTdb06=;;`1TCBh0IDd[06Q>:@1/D2P0L5<Y075D:01kFRd0
NU/]07]L;P1jGRl0Nf0c07aT=P1mIcP0OfTj07ER>P1/FC40JE</06]C;@1[DB`0JdlZ06mC;P1iFcL0
PFDc089V=025JCL0Qf/i0`29KC/03`28K3X0PfPk089W>P21IST0P6Dh085V=`22IcP0PfPi08EZ>`20
Jc`0OFPi07]U=P1jHS@0O64d07iQ=@02081Q=@0808a[>02;JcP0S6`k08]/?@28K3d0QV/n089Z?021
JCd208mdA`0408icAP2<LD@0RVm208U^@@80Qf`o00d0RV/m08]/?P2:KSl0RFho08I^?P24KSd0PFdk
07m[>@1kH3<0O64d07eR=@1oI3L0P6Dh0080PFHi0140PVLj089Z?023Jcd0Q6`n08I^@029LD40Rg=3
08eeA@2>MTH0TGY409=lAP2IP4P0X8I=0:V<DP2_TED0]9IH0;NGFP020<:PH@@0`j5R0P34XV<01P2m
Ve`0^iUJ0;^IFP2hUUL0]I=D0;>ADP<0/Y1A0P2eSe403P2dSU00]HmA0;VCE@2nV5X0`ieO0<NQH`38
XEh0bZ=P0<bUHP3>Yf@0cJIS0<^TH@37X5d0aIiK0P39XV403039XF<0bZ9U0<^SJ03;XVX0c:=[0<bS
K@3I]7d0hl2:0?;?V@3if:<0nm^X0?SJZ080mMVY00P0n=b/0?WJZ`3ff:H0l]:O0>[9U03R_hT0fKAo
0=B_N080e;5g103C/7H20=:_M@80dK5h1P3B/WT0403B/G/0d[9i0=>cNP3B/WL0d;1c0<j_K`3;[6/0
bJYY0<VWI`3<[Fd0^YYM0:J7CP2VR580YXYH0::8E`2WS5d80:R>G@0@0:F?G@2ZTf40[YMU0;6GIP2a
UFD0]9EV0;ZJJ`2nWVl0^ia`0<2PM`39ZH00d[:;0=ZjU03O_Y/0h/6P0>?2X@80hlFO00@0hlNR0>C7
Y@3TbZT0i<^/0P3TcJh20=k;[@80g/Z_02H0g<R_0=W5[@3G`Zd0eL2[0=C1X`3C`:80d[nQ0=2mW`3>
^id0c;VK0<^hVP3:]iT0c;>D0<V`T@37[hd0ajn;0<R`S036[XP0`JZ10;bUO02eV6`0/iIZ0;:EJ`2g
VW80_j5k0<JXQ038ZXH0b:Z80<^aT03</I<0cKBE0<nhV@3B_J00e/:W0=_7[P3Lbk40glfe0>CD^`80
jMW200D0jM[50>KIaP3TfLL0iMg:0>ONc@020>_Qe`060>cRf03^i=X0knGK0?3Vg03aimd0l^SN203d
j]h80?G[g`P0m^cS00H0mngT0?O]h`3gkN<0mngQ0?O^g`3gk]d20?O_g080nNWI103hj=P20?OWe`<0
n>WD0P3gj=<30?KWdP<0m^C<0P3ehl/30?CRbPP0m>38203aglT80>oMa`P0l>392`3ah<h30?;Qc`80
ln;@0P3`hm820?7Td`80l^GD0P3ci]D20?GTe080m>?C0P3ch]820?;Qd@P0l^GD0P3dhm420??Rd0@0
l^7?0`3dh/h40??Qc@80l^3<0P3chLT20?;Pb0040?7Oa`3`g/H0l=k60>oMa@<0l]c4103afl<01`3`
f/80lm[40??K``3bf/80lMVo0?7I_@3`fKX00P3_f;P20>kC]@030>gB]03/dK<0jm2b0080j/na00@0
jLj`0>K<Z`3Vc:/0i/b[0P3UbjX30>C:Z@080>;5Y`3Qa:H0hLBT0>74XP3Pa9l0h<BM0=o3W03O`i/2
0=o3WP<0g/:M0`3M`I`30=c0V`D0fknJ0P3G_IX30=RnV`<0fKnL1`3J_j400`3I_Z00g<:O0=c2W`02
0=c2W`@0gL>P0`3N`jD20=o4YP/0h<FW0P3QaZP20>;7Z@<0hlRZ103TbJ/20>G:[0<0i/^]0`3Yd;42
0>[A/P<0jm:c203/dkD;0>[A/`<0jm:d0`3/dkD@0>_F^a00k=Nl203[e[L80>_F^`040>gE^@3/e;P0
k=Bh0>cD^080jm>g0P3Zd[H20>SC^080jMBi0`3ZeKX0103[e[/0k=>e0>cC]@3/dkD30>_B]080j]6c
203YdKL20>[@]@<0jm6f0`3/d[L80>gE^`X0jm:d0P3ZdK<40>W@/P<0jLj`0`3XcJl20>O<[P80jLb/
0P3Xbj/20>O:ZP80i/VY0`3WbZX20>K9Z@<0iLRX203RaJ<20>?5X`030>;4XP3Q`j40h<:P0080h<:P
0P3O`Il@0=nnV`@0g[fJ103M_9T80=jmVP<0gKbI0`3L^iP20=^jU`X0g[fJ1P3O_Y/20>6nV0060>2m
U`3O_9H0g[^E0=fjU03L^I<0fkRB0`3J^IH40=^jU`070=bkV03O_9@0gkbD0=jkT`3L^I40fkR@0=Vf
SP020=ReS@060=BeQP3D]HL0e;F70=FfRP3E]H`0eKF>0P3F]Y020=JfS`@0eKF>0P3D]8d20<n_R080
d;290`3A/HX0103B/X/0eKF>0=FeSP3E]Hh20=JfS`<0ekN@203F]I820=FbRP040=BaR@3C/8P0dk28
0=:_Q`80dJj60P3@[8P01P3@[HL0cjb40<n/PP3?[H00cZao0<j/OPP0cZ^10`3<ZGl30<^XOP<0bZMm
0P3<YgX30<^VN@<0bZEh00T0bZEi0<VTN039Y7L0b:Ad0<NSL@36XVh0aJ5]0<FRK037XWD00P37Xg<0
1@36XW00a:1/0<6NJ02nVf<0_9UQ00P0_IUU202lV6@00`2lV6H0_IUW0;fII`040;fII`040;bHIP2o
VVd0_iY]0<2KKP80`Ia_00<0`Ye`0<>NL@33WW400`32WVh20<6MK@<0`9a/202oVf/30;fIIB_ooooo
000Zooooo`<0YWa:0`2WOD/20:QnC0P0Z7m;202ZP4h80:UoC@80ZH1:00H0ZX5;0:b3C@2]Q4h0[XE?
0:n6D02`Qe430:^2CP<0[8=?0P2]Q5030:f2C`80[X=@0`2_Q5480:f4D0060:Z5D02YQ4l0ZHA?0:R3
CP2WPTd0YX5<0P2UP4/0102SOdD0Y8160:AoB02TOdX20:=nB@030:1kA`2NN4L0W7I50080VWE100h0
VGA009Qc?`2GLSh0UG0l09A_>`2CKSX0UF`h09AZ>02CJcP0T6Xi08iZ>P2=J3/0RfTl08UX>`<0RFDe
00D0R6@d08MS<`26HS80QF4a08AP<002085O;`04081N<01oGC00Oe`b07iK<`80OEXd00P0N5P_07UI
<01kFc80Ne/b07YJ<@1fERd0Le<Z075A:0P0NEH^00P0O5T_07]H;P1jEbd0NUL]07]H;P1lFBl0OU/a
081M<`80Q5lb00@0QV4d08QS=P29I3L0RfHi0P2=J3/2095V>@80TVLj0P2CJ3/209AY?0P0TV`m0P2G
J3`00`2EJC`0TfPk099Y>`02095[?003091/?02>J3T0SVPi00H0SVPi0`2AJc`2091Z>`<0SfTj0`2A
IST4099W>P05095V>@2BK3d0TF/l095[?02@JS/00P2?JCX208iX>@P0T6Xk0P2EJcT809AZ>080UF/i
00@0UV`j09M]>`2GKC/0Ufdk102GKc`509I^>`0409A^?`2EKd00UFm009E_@080UW110P2GLD8809E`
>`03099]>@2AK3P0T6/g0080SVTe00<0SfXf095/>02BKCT00`2DKc/209E`?0/0UW4m00H0TFdi099^
>P2CKc/0U70l09Ea?@2GLcl209Qd@0P0U70l0P2ELCd309A`?0<0Tflk0P2DL3`409Ea?@80UW8n0P2F
M4L00`2FM4H0UWA409Ie@P0209Ie@00Q09Ie?`2FN4H0UWQ609IhAP2EMdD0TgE3091b@02=Kcd0Rfdk
08MX?026Ic/0PVDi07mT=`1jHS@0Mf4b07AO<01cGRl0LU/a071K<01]Ec00Ie<^061=;01GARP0D44T
04`l8P11=R00?SHO03de800j<b00=c8O03<`7`0a;b00<2hO0080;2TP00@0:BTO02LY7P0U9a`08bHK
0P0P9QX2024T6`<082<J0`0O8QT01@0Q91T08RDJ028U6P0S9Q/092LL00809BPM00H09RTN02@W700S
9Q/082<J01hQ6P0L7QT201`N6`0301dO7P0L7Q/071hK00L071hK01P072@I01dU600Q9AL09BPG02`[
5`0d;a/0>C<K03df7019?A<0DdLM05Y=8`1KC2<0GddU069?9`1NB240DcdF03`h7`0a;Q/09b<J020L
6`0N71d0824L024U5`0Q9A@302TZ70<0:2TK0P0W:1X202DV7P8092DM0P0S91`2028S6`03028S7@0P
8A/07b0J00807QlI00<07b0J020Q6`0R8ad0200Q8Q`02`0R7QD081lJ02@V8@0]<2T0<c<W04@i8`1P
C2/0Nelh09=gA@2SQeD0/YIT0080]i]Y0180]9QV0:N;F@2JOT`0V8A709UmB`2POU40[XUE0;BBE@2S
QT`0NfDl05U9<P0b<bd0;BhX02LX8P0V9b40:BXT02X[9@0X:B<302HW8@0302DV800T9Al08b@N00<0
8b@N200U9B<302@U7`<09BHP0P0V9b4202DV800402HW8@0W:2809bPR02PY8`80:BXT0P0]:2801P0_
:b80<2`Q038^8P0c<240=C8S03Db8@80<c0O00`0<c0Q038^8P0a;B80<2`S02l[8P0_:R@0<C4U034b
900f<RH0>c<V03dd9@12=BD204Lf9P0704@c8`17=RH0BcXZ04Xi:@18=bL0AcHV04Th:00204dl;003
04Xh8P1<>R@0CS`V0080D3hX00@0CcdW04dk9@1<>R@0BcPY0P1<>BP00`1=>bL0CS`V04lm9@02050o
9@0604/i9@1<>RH0C3XV04dk9`1>?2P0CcdY0P1@?RX404`l9@80CCdV0P1>?RL204i09P0?05109`1B
@2P0Dd4Y05I2:P1G@BX0F48[05e::P1LBBT0FTLW05U69P1JAbL0GDXZ061=;@1RCbl0FdPZ0080FTLY
0P1IARP305Q59`0805=49@1CA2L0DT<V05519`1@@2L0CShW04dl:01<>bL204Ll9P0404Hk9`14>BL0
@cLW044e9`80@3@X00<0>cDW03Xd9P0i<bD00P0h<R@00`0j=2H0?3HX03dg:@0203Pd:080=c<W00`0
=S8V03Da9@0d<2@0<blS03D[7`0f;200=bdQ03P^8P0j<2@0>c4U03`b9P0m<bL203@a8P0403<_8`0b
;R<0<BdT030[9@80;bXV100b;RD7034]90<0<2`S0P0_:b82034]8P0D03@^8P0g;b80>S4R03hb8P10
<b<0@3<R03hc8@0o=280@3DS044f9012=bD0@cPV04@i9`15>RP0A3TW04Lj9`19?2T0C3dX04hn9`1>
?2@204lk8P0304Hk:@15>RP0@cPV0080@CHT00<0@SLU04<h9P14>BL00P1;>B/0101<>R`0C3/[04`k
:@1<>bL204dm9P0304dm901>?B<0CSdS0080CchT00`0D3lU05509P1A@2H0DT4W05=1:@1>?RL0B3PQ
048c7P0m<1d0?34O03dd8`0n=B@803hf8`0:04Dh:015>2L0BCXW04`l9@1A@2H0Ed@V05a7:01NBRT0
GDP[05a7:P80G4LX0200GDPY05m;:P1RCRd0I50_065=<P1QC2l0H4//069;:@1TC2H0J4lV06eB9`1_
E2L0NeP^07YI;P1kFRl0O5da07aP<@1oI3D0P6Ph085Y>@1gI3`0KU/c06]E;P1]EBl0KE<^06]?:P1^
DRd0MeTe089W<P23J3<0QV/f08Q]>0<0RVlj00T0RFhi08=X>@22IcP0PFHg07mT=@1oI3L0P6Dh085V
>@22IcX00P1mJ3T03P1mIcP0O6@f07eR=@1mH3@0PF8f089S=`2:JSL0RV`h08]]>`2:KSh0Qf`m08=[
?@1oJCX0OVLk0P29KT401028KD00Qf`o08I[?P25JSd208AY?00808Y[?02;K3d0RVhn08Y`?`28LCl0
QW0n08=_?022KS/2081U=P0F085V=`22IcP0PfPi08EZ>`27K3d0R6dn08Qb@@29Ld80RWA308]eA02=
MdP0SWQ908miBP2@NT/0TGa709AoBP2IPT`0X8M?0:N=E02_TUP0/iIJ0;JHG0<0`j5R0`32X6420<6O
H0060;ZHF@2iUeP0^IMH0;JDE@2cTE80/Y1A0P2aSe00302bT540]I5C0;B@DP2cSe40]91B0;NCE@2l
V5X0`YiP0<FQH`37X5d0bJ9O0<bUHP80cJIS00<0bZ=P0<NPG@35WU/00P36We`05P36Weh0aimQ0<NO
HP37Wf@0b:1U0<ROI`3E[WD0gKR10>_8TP3ddI/0mMBO0?CDX@3ceJ<0m=JT0?CHYP3eejD0lM>O0>c=
U`3T`hd0gKZ40=F`N@3@[7840=6_LP@0d[1c0P3B/WT60=6aN00@0=6`NP3A/GP0dK5h0=2`M@3>[W40
bja/0<RYJ036YfH0aZAT0<VZJP2hV5/0Y8E<0:B6D02UREL0XHMF0:J;G0D0YXaK0`2WSE`05P2SSE/0
ZI9P0:fFI02_UF@0[i=S0;:CI02gUfP0^i]/0;fLK`32XGH0bZUn0=>bR@3K^I<0h;jI0>;0W@3S`Ih0
hL6J0>;2V`3Q`id0hLFP0>77Y03Rb:L20>?:Z`80gLRY02P0g/V/0=k9[P3Majl0flF]0=S2Z`3G`JX0
eL:T0=C1X`3C`:80dKjP0<nlWP3=^Y`0c;VK0<^hVP3=]9D0b[6B0<N_S@37[h/0b;2<0<J^R030ZH00
^jAk0;>FJP2aU6P0/9=Y0;FHL02nX7X0aJN30<NYQ@37ZHL0bk2B0<baU03=]9H0ckNK0=:mXP3G`jX0
g<R`0=g;/`3Pc[P0i=Bm0P3Yf<@02`3ZflP0i]W80>GJb03Ug</0j=o@0>_Qe`3/h]P0kN?I0>kTfP3_
iM/0lNOM0080l^SN203dj]h80?G[g`P0m^cR00H0n>cP0?S/gP3hk=h0n>cL0?S]f`3hkMT20?S]e`80
nNSD0P3him<20?OVdP80m^GA0`3gim020?KVc`<0mNG>0P3ehl/20?CRbP<0ln7900<0l^380??Oa`3c
glL01P3cglL80?3Nb0P0kmg7203`h<T:0?7PcP<0l^7?0`3ch]020?3SdP80lNCC0P3biM@20??Ve@<0
m>?C0P3ch]830?;Qd@P0ln?C103bhLd20?7Pc080l=o;00<0ln7;0?;PbP3bh<X00P3bh<X20?7Ob@80
l=k80P3ah<H0103`glD0kmk40>kM``3]g<820>cK`@80mM_20P3df/420??I`080l]Ro00H0l=Fj0>oD
]`3^dkH0kM:d0>cB/@3[dJh20>[@Z`80k<n]00@0jlj/0>[=Z`3Yc:X0j<^Y0P3WbZP20=o3WP80g/:M
103M`I`20=k0WP030=foV`3M_iT0g;nG0080g;nE00@0fkjB0=bnV03L_YP0fkfG0P3J_9H30=VkU@<0
ekVC1@3H^Y@20=FhUP030=JiU`3G^YP0ekZH00<0f;^I203J_Id20=RkV@80fKbJ00D0f[fK0=^nW03K
_Y`0fkjL0=^nWP030=boW`80gL2P0P3N`J480>74Y0040=o2XP3P`j<0h<>S0>33X`80hLBT1@3RaJD2
0>?6YP<0i<NW0P3WcJ`20>S>[@<0jLn^00<0j]2_0>_@/P3[d;801P3[d;8;0>S=[`<0jLj`0`3Zck4@
0>[B]Q00jm>g203Zdk<;0>[B]P80jM6e1P3Xd;@20>WA]@<0j]:f0P3[d;830>[?/@<0jLj`203Vc[83
0>S>/`<0jLnd0P3Zd;D80>_C]`P0jM2a0P3Zck430>W>/0<0j<f_103Yc:`20>S;Z`@0ilZZ103VbJT2
0>G8Z0<0i/VY0P3Ub:P30>C7Y`P0hLBR0P3Ra:800`3Q`j40h<:P0=o1W`020=k0WP80gKnM403N_IXB
0=flV@<0g;^H0`3K^YL80=flV@80gkjK1P3N_IX0103P_IL0gkbF0=nlUP3N^iD20=fjU080g;VC0P3I
^9D20=ZiUP040=^jU`3L^iP0g;^H0=bkV080gkbD00@0g[^C0=biT@3K^900fKJ>0P3H]Hd01P3C]8D0
dkB60=BeQ`3D]HT0e;B;0=FeSP80eKF?00<0e[J?0=FeSP3E]Hh00P3D]8d20=>cS0040=:bR`3?[hP0
cjn80<n_R080d;290`3A/HX20=BdS@80eKF>0P3F]Xl20=NgT0P0e[FB0P3E/XX0103D/HT0dk280=:_
Q`3A[XH20=2]Q@80d:b800<0cjb60<n/Q03?[8800P3>[7l00`3>[7h0cZ^10<j[P@060<j[P@<0c:Uo
0`3;Z7h30<ZWO@80c:Mj0`3;YWT30<ZUN080bJAh00<0b:=f0<NSL`36XW000P35XFd02@34XF/0aj9e
0<RTM037Xg<0aZ9`0<BPK030WFL0_IYR0;^HH0080;fII@P0_9QT00<0_YYZ0;fIJ@2mVFT0102mVFT0
1`2nVVX0_YU/0;jIK02oVVd0`9]^0<6LK`32WG000P33WW420<:NKP80`Ie]0P30W6`20;nKJ`P0_YYZ
0`2mVFD[ooooo`00:_ooool30:IlBP<0Yge;0P2XOT`80:MnBQ00ZGm=0P2YP4X0102ZPD/0Zh9<0:b3
C@2/Pdd20:f4CP<0Zh9<0`2/Pdd20:f4CP<0[H9?0P2^Pe030:n4D@<0[8=?0P2]Q5030:j5D@80ZHA?
00<0Z8=>0:N2C@2VPD`00P2UP4/01@2TOdX0XWi40:9nA02SOTL0Xgi90080XGa700<0WgY609afA@2K
MD@00`2JMD402`2IM400V7<o09Ia?@2DKc/0TVdi099Z=P2BJSL0T6/g08iZ>02>JSX0RfTk0080RVTl
00P0R6<f08UT=`29I3L0RF@g08QS=P26HC@0QF0c08AO<P80PEl_00@0P5h`07mM<01oG380OU/c0P1m
FS@307UI<00507QH;`1gEbh0MED/07=C:P1aDBP0201iERh207eJ<0<0NeP^00<0OEX`07mL<P20GC<0
0P24Gc801026HC@0R6<f08UT=`2;IST208eX>`80T6Dh00@0TFHi099W>P2CJ3/0TfPk0P2DJC`8099/
?@0809QY?@2GJ3`0U6Pk099W>P2AJ3X0T6Xk095[?02AKCd3091Z>`80SfTj0`2>J3T0102BK3d0TF/l
095[?02AJc`2091Z>`80SfTj00<0Sf@g091U>02AIST00`2CJ3/00`2BIcX0TFHi091Z>`0?091Z>`80
UV`j0P2EJcT409AZ>006099X=P2CJCL0TfTg09AZ>02EJcT0UV`j0P2GKC/409E`?0<0U6lk0P2CKSX3
09A^?`80UFm00`2FL44809E`>`0309A_>`2BKCT0TF`h00<0SfXf00@0TF`h099]>@2DKc/0U6lk0P2E
L3`309Ia?@0409Mb?P2EL3`0UG0l09E`?080UW4m0`2GLSh2099^>P0309=_>`2DL3`0UG4m00<0UW8n
202DL3`209Ea?@<0U70l0`2CKc/809Ea?@80UWA700<0UWA609IdA02FMD800P2FMD00:P2FMCl0UGM5
09EgA@2FN4H0UGM509=e@`2@LT00SW0n08a^?027J3`0QVLk089U>@1nHcH0NF4c07EO<01bGBh0LE`]
079K<@1`Fc00KeTb06UE<01RCbh0FDPZ05529@1=?B<0@CHR03hf8@0m=B80>S<Q03La8@0c<240<BlP
030^8@0/:B00:bPO02PX7P0W:Ah09BLL02@W700Q9a/082HJ024T6`<082<J0P0O8QT201hQ60<08RDJ
0P0S9Q/402@W700402<V6`0P8aX07R4J01`N6@8071hK00<07AlN01`N6`0L7Q/01`0L7Q/0600M9AP0
7BDF028V5`0W:QL0;bhI03Lb700m=ad0@CXP04Tl3`1BAAP0FD/N05e<801SD2D0J5<X065<8@1F?aD0
?c/R03@a7P0X91/081`K01lM7P0Q8Qd08RHH028V5@<0:BXL0`0X:A/202LX6P809BHN0P0T9Ad202<T
70808R<K00<08R<M020Q6`0O81X00P0N7aT00`0O81X0824K028S7@03028S7@808B8L0`0P8A/0300R
7aH07b0J028W8@0Y;RL0<30T03de7P1HAB@0LUTa08]_?@2KOdd0Z8aJ0:^?G@80ZXiL0140XhME09Yn
C02HQ4L0VGe;09mmD02]R5@0]99E0:B7C@1mIch0G4`e03@e;`0^;bT0:BXT02LX8P0Z:bD0;2dW02//
9P0202TZ900502PY8`0V9b4092DO02@U7`0S91h00P0T9Al802DU8`<092DO0`0U9R0202HW8@809BHP
0P0V9b4202LX8P80:2TS0P0^:BD0100_:R@0<2`S034]8P0a;B42038_8080<c0O01D0<c0Q03<_8`0b
;R<0<BdT02l[8P0^:B<0<S<U03<d900h=BH0?3DU03lf9@14=bH0B3LU04Th9P16=B<0BSTW04dl:P1<
>bT0BCPV04Lf9018=bD00P1;>RP00`1:>280C3XT04hl9P02050n:00<04hl9P1<>R@0BSPR04/h:@1;
>2L0C3TX04dk9`1>?2H0CcdU04ln901@?bD0C3TX0`1=>RT404hk:P0304hn9`1=?BH0C3`U0080Bc/T
00<0C3`U04dm9P1=?BH00P1=?bD01P1??bH0DClW0590:01E@BT0ET0Y05M1:P@0FdPX00T0G4TY05e:
:P1OC2`0H4d]05a9:`1KB2X0FTLY05U6:01HABL00P1IARP02@1JAbT0E4DV05A5:01DABP0Dd<Y0592
:@1@@2T0CSdY04`k9`0204Hk9`0904Dj:013=bL0@SHX044e:@10=2P0?c8Y03/e9`0j=2H0>38T0080
=c4S00<0>38T03Tc9@0j=2H00P0f<RH01P0g<bL0=S8V03Hb9P0d<2@0<RhR034]8@80=B/O00@0=R`P
03P^8P0i;b<0>c4U0P0l<RH203@a8P0403<_8`0b;R<0<BdT030[9@80;bXV00@0<blV038^9@0b;RD0
<RhU0`0a;B@0100`;2<0<BdT034]900a;B@3030/8`80;b/R0P0a;B801`0d;R80=blR03T`8@0m<B40
?c8R03lb8@11=2<00`12=B@304<f9@0A04@g9P14>BL0ASTV04Pk:01<?BP0CShW04lm9@1@?2<0Cc/R
04Hk:@15>RP0@cPV048g9@11=R@0@SLU04<h9P14>BL00`1;>B/00`1;>RX0BcXX04/j9P0204/k9004
04/k8P1>?RD0CShU04hn9@D0CCdT00P0D3hV04dm9P19>B80A3DP040c800o=280?SDT040g9PP0?SHS
00P0A3PX04Hi:018>bP0CChW05519`1FABL0FdPX05a9:080FTH[02<0FDHX05Y79`1KB2L0GT`X065?
:`1RD2X0GTda05m<;P1MBRX0GTXW065;901VCbD0JU8V06eE9`1iDbh0NEH`07aI<@1nGC80P64c085U
=@22J3D0PfTf07QU?@1_G3@0KEL`06mG<@1^E2l0K50[06iB;@1fF3@0P6D^089W<025JS<0R6df08Y_
>00208]`>@0I08Y_>025JcP0PfTf085W=P1nHc@0OF8e07eR=`1mHCT0OV8j07]V=`1mJ3T0OfTj07mW
>@1nHcH0Of8f08=T>026Ic/0RV`h08]]>@2;Kcd0RW0o08M_?`23KCh0OVTj07aW>P08089W>P0808Y/
>P2;KC/0Rflm08]a?P2:Lcl0R7<n08Ib?@25LC`308E[>P0508I/>`28KSd0RW0o08ec@P2>M4<00P2@
O4L0102AODX0TWi<09AoD02EP5<209J1EP0809R4D@2IQE00WXUD0:><EP2ZTET0[iEL0;BGG@2fVEl2
0<>OH@80`YiP00D0`IeO0<2LGP2oVed0_i]M0;ZHF@020;RFE`030;FCE02cTE80/Hm@0080/Hm@00<0
/Y1A0;NEEP2fU5D00P2eTe@0302gUEH0^iUJ0<2NG`33XF80aj1M0<VRG`3;Y640cJIS0<bUHP3:Xf00
aj1M0<BMFP80a9eH00@0a9eJ0<BMG034W5h0a9aO0P34W640403?Z6l0fK9i0>G0R@3^biD0l/nI0?3?
VP3`d9d0l]:O0?7FX@3adil0k<jH0>O8T@3O_XP0f;Em0=6]L`3<Z6h20<j/K@040<n]KP3@[Vl0dJm`
0=6_L080d[1a0P3B/WT30=6aN0<0d;1g0140dK1j0=6aN03A/GP0d;1e0<f]L03:Zf/0ajQW0<FVI@34
XV80ajQX0;JFF@2RPdX0XhE?0:>7E@2PQUD0YHYK0::8E`020:>9F0030:B:F@2UReX0YXaK0080YheL
00h0XXaJ0:N@GP2[U680[YAS0:fAH@2`TF80]IEV0;VIJP2mVfd0`Z1c0<ZXN`3B[hD0fKJ>0=fjU080
gk^G02P0g[fD0=jlUP3O_iP0g/2J0=o3WP3OaJ80h<JU0>38YP3MaZH0g/NW0=o8Z@3Oaj/0glN]0=g5
[@3K`j/0f/6[0=G2Y03D`J<0dl2R0=6nX03?_9h0cKZL0<biV`3;^9X0c[FF0<ZaTP37[hd0ajn;0<R`
S036[XP0`:V00;ZSNP2aU6P0[i9V0:nBJ02dUfl0_Imi0<BVPP37ZHD0aZR60P3</I@0203>]9T0dKVO
0=BnYP3IaJd0g/Vd0=o=]`3Pc[X0i=>o0P3ZfLL01@3Zf/X0im[90>GIb@3Ug<d0j=o@0080k>;H00H0
kN?I0>kTfP3`i]`0lNOM0?;XgP3cjMl80?CZgPP0mN_O203fk>020?S[f`060?S[fP3gj]L0mn_E0?O[
d`3fj]80m^[@0P3iill20?SVcP040?OUc@3fi<`0mN?;0?GSb`<0m^C<0`3ehl/20?CRbP<0ln790P3b
h<P30?7Oa`P0l]k6203`g/P80>oMa`P0l>392@3ah<h30?;Qc`80ln;@0P3dhm420?3SdP80lNCC0P3b
iM@20??Ve@80m>?A0P3ch]030?;Qc`030?7PcP3bhLl0l^7?00H0l^7?0`3ahLX20?3Pb@<0kmo80P3b
g/H30?7Ma@80l=c40P3_fl<20?3L``060>oK`P3]fL00k=Ro0>_G_P3Ze[d0jMFl0P3de[X00`3ceKT0
l]Bh0?7C]`020?3B]P090>oA]@3[c:d0jlb]0>[<ZP3YbjL0ilVS0>K9X@3Ub:00i<NM0080ilJS00<0
i/FR0>G4X@3T`j000P3S`Yl0103R`Ih0f;RA0=RhT@3H^9420=NgT0<0e[J?00P0f[ZD0=ViT`3I^I80
fKV@0=RiS@3H^H/0ekR:0=NhR@80f;RA00@0ekN@0=JfS`3E]Hh0eKF>0P3D]8d0103B/X/0dk><0=>c
S03C/h`30=BdS@040=FeSP3B]900d[B@0=>eT@80e;JB00@0eKNC0=JhU03F^9@0ekVG0`3H^YP30=Vk
V@060=ZlVP3E]i<0eKNC0=JhU03G^ID0f;ZF0P3I^iL00`3J_9P0fK^I0=ZlVP020=ZlVP80fkfK0P3L
_Y`80>32X0<0g/2N0P3O`Il50>32X080hL>Q0P3Ra:820>?5X`040>K9Y`3WbZP0ilZX0>O:Z080j<^Y
0P3Yc:X80>_>[PX0j<^[0P3Yc:`40>[=[@030>_>[P3Xck40j<na00h0j<na403ZdK<80>S@[PP0j<na
0`3Xd;@20>O?/`<0i/jb0`3Wc[020>S?/@<0jM2b0P3[cZh20>[=[@<0jLb/00<0j<^[0>C=[P3TcJh0
1P3TcJh0103Ubk00i/ba0>K</@3Vc;420>O=/P80j<jc203XdK880>O?[@<0j/f]0P3Yc:`30>S;Z`80
jL^Y0P3XbZP20>O9Y`80i/RV2`3Ub:P20>C7Y`<0hlJV203P`j401@3Q`j40h<:P0>32X03O`Il0g/2N
0080gKnM0P3L_Y`80=jmVPP0gKbI00@0fkZG0=bkV03L^iP0g;^H0`3M_9T00`3N_IX0gKbI0=flV@07
0=flV@<0g;^H0P3K^YL20=ZiUPP0gKbI0P3O_Y/30=jmVP<0gKbI00@0gkbF0=jkU@3N^iD0g[^E0P3M
^Y@20=biT`060=RgU03I^9D0fKRE0=ZiUP3K^YL0g;^H0P3M_9T20=nlU0040=jkT`3L^I40fkR@0=Vf
SP80f;F=00H0dkB50=>dQP3C]8H0e;F90=BdR`3E]Hh20=FeS`80eKF>0P3D]8d01@3C/h`0d[:;0=6a
RP3A/HX0cjn800<0d;290P3A/HX20=:bR`<0e;B=0P3E]Hh30=JfS`P0e[FB0P3D/HT20=>`R00<0=:_
Q`3A[XH0d:f50=2]Q@3@[8P0cj^70<n/QP3?[8@0cZ^10<j/O`3=Zgh0cJ]m203>Zh430<bYO`<0bjQn
0`3:Ygd20<bWNP<0bjIi0`3:YGP02@39Y7P0b:=g0<RSMP37Xg<0aZ9`0<FQK@34X6`0a:5[0<JQM002
0<NSL`050<FQK`33Wf/0`9eW0;fJHP2kV600202lV6@80;^GH`030;nJK@2nVF`0_IQ[0080_9MZ00<0
_IQ[0;jIK02oVVd00P2nVF`0102oVVd0`9]^0<6LK`31W6l20<:ML0<0`Ie]0P30W6`30;nKJ`P0_YYZ
0`2mVFD[ooooo`00:_ooool30:IlBP<0Yge;0P2XOT`80:MnBPP0Yge;202YOdd00`2YP4X0ZX5;0:Z1
B`050:Z1B`<0Zh9:0`2/Pd/20:f4C0<0[H9?0P2^Pe030:n4D@030:^2CP2/Pdl0[8=?0080[HA@0P2^
QE401`2_QU80ZHA?0:V4C`2XPdh0Yh9=0:J1C02UP4/00P2TOdX0102PO480XGe30:5lA@2QO4L209mj
A@0409ehA02JM4<0VG=209Ud@0<0VWE100D0V7<o09Ia?@2CKSX0TVdi095Y=@0208mZ=P0308iZ>02<
JSX0RVXk0080RFXl00P0R6<g08UT>029I3P0RVDi08UT>027HSH0Q5lc08=N<P80PEl_00@0P5h`07mM
<01oG380OU/c0P1mFS@01@1jFS40N5P_07IF;@1dE2/0Le<Z00<0LU8Y201jEbl00`20GC<0Oe`b07eJ
<00207eJ<00307iK<@20GC<0PEhd0080Q5lb00@0QV4d08QS=P29I3L0RfHi0P2=J3/208mT=`06091U
>02AIST0TVLj09=X>`2DJC`0UFXm202BK3d0202HJCd0UfPl09=W>P2AIST0T6Li08mY>P2AJc`0TFdm
0P2BK3d2095[?080T6Xk0P2?JCX2099/?@<0TF/l0`2@JS/02@2>HcH0Sf@g095V>@2CJ3/0U6Tl09=X
>`2BIcX0TFHi08eW>00208iX>@0308mY>P2@JS/0TF/l0080TV`m202AJc`00`2GKC/0UV`j09I/>P02
09E[>@80U6Xh00L0TfTg091V=02AIcD0TVPf09=Y=`2DJSP0UF/i0080UV`j0P2EL3`209A_>`<0Tfhj
0P2BKCT309=]?P<0U6ho0P2EKd0809E`>`0309E`?02DKc/0TVdi00<0T6/g00<0TF`h099]>@2EL3`0
0P2EL3`309Ia?@80Ug8n00<0U6lk09E`?02EL3`00P2FLCd209Mb?P0309Qc?`2DL3`0U70l00h0U70l
0P2ELCd309A`?0<0Tflk202ELCd209IdA`0309IdAP2FM4@0UWE20080UWE000<0UWDo09AfA02DMT@0
0P2EMdD06P2CMD<0TG=108ma?`2=Kcd0R6Tm08MX?022ICT0OV<f07QP<P1cGBh0L5//06iI:P1^Ebd0
KEP]06aF;`1WDbh0HDh]05M6:01?@2<0Bc/Q040e8`0n=R<0?3<R03Tb8P0g<B<0<c0Q0P0`;R4202/X
7`0402PX7P0V:1d09RPM02@W70808BLK0`0P8aX201lR6@<07R4H0`0R9AX502<V6`0502@W700S9Q/0
82<J01hQ6P0L7QT00P0L7Q/00`0M7ah071hK01`N6`0701`N6`0H01dU600N9QL092PG02T/6@0b<A`0
>cLN048l8P16?b<0DT@E05Y<7@1SDR@0J5HX075L;`1fHC@0KeP/065:7P12?RD0=c@Q02XV7@0R7Qd0
81hO028S7P0T:1X092PG0`0Y:Q`302PY6`809bPJ0P0U9Qh202@U7@808b@L0P0R8a/00`0R8ad0824K
01lP6P0201hO6@0401lP6P0P8A/08R<M02<T7P808R<M0P0Q8Q`2020Q6`0;01lP6P0P81H07R4J020W
800V;BD0:bdP03H`601@?A`0J4lW08=W=@2AMD<00P2LP4h04@2KOdd0Wh=A09n3D@2KOdd0V8A709Ql
BP2NO4l0[HQD0;BBE@2TQdd0OfU005i>=`0f=c40<34[02X[9@0Y:R@0:b`V0080;RlY00D0;BhX02`]
9`0Z:bD0:2TS02DV800202@U7`0302DV800V9b409BDS00L09BDS0`0T9Al302DV80809RLQ00<09BHP
02HW8@0V9b400P0V9b4302LX8P06030[:00`:bL0<2/W02lZ900_:b80;b/P0P0_:al05@0b;ah0<c0O
03@a8P0d<2@0<blT034]900_:b80;BPR030a8@0a<R80=C8Q03Xc8@0m=B80@SDR04He8`17=R80B3LS
04`k9`1??RX0CSdY04Xi9@0204He8@80B3LS00h0B3HP04/i8`1>?2H0D3hX04lm9`1=>bD0BSPR04Pf
801;>2T0BcPW04`i:01<>RH0CC/U04hl9080CchT0`1>>bX204dj:@<0C3TX00<0D40Y04lo:01<?2D0
0`1:>R<0201;>b@0C3`U04/m8`1<?R@0CCdT04lm9@1@?RH0DclW0P1E?bP0101IARH0FTLW05a9:@1M
BRX405i;:`0305i;;@1MBR`0FdPZ00<0FDHX01P0FdPZ05a9:`1DABH0EDHY05I7:P1EAB/0E4@[0551
:P1??RX0CC`X04Hk:@15>RP0A3PX04<g:@11=BT0@3@X03lb:@0n<BP0>cDW03Tc9@0g<B<0=BlQ03@^
800e;b4203H`8P0803@`900e<BD0=C4U03Hb9P0e<BD0<blS030/800_:al203D[7`0603H/800g;B40
>BlS03X`900k<BD0?38V0P0d<B80100c;b<0<RhS034]900`:bD202lZ9P80<blV0P0b;RD2034]9080
<2`S0`0a;B@3030/8`80;b/R0P0a;B801P0d;R80=blR03T`8@0l<200?S4Q03ha8080ASHV0P15=BD2
04@d9080@c<S00H0@cPV04Hi9P18>bP0C3dX04hn9`1??BD2050l8`0304Ll:P16>bT0A3TW00<0@SLU
00<0@cPV04@i9`1:>2X00P1:>2X01P1:>BT0BSTW04Xi9@1:>R<0BCTR04Ti8080CSlX00@0CChW04`m
9P1;?2D0BS/T0P19>R<01P1=>b<0Bc/T04Xj8`18>B@0ACPU04<h9P80@CPW200l=B807P11=BD0@SLU
04Dh9@18?2@0CT0U05528`1EAB@0ETHT05Y6;P1IAB`0FDDZ05U6:01KB2L0GD/W061>9P1QCbL0G4/_
05]:;01KB2P0G4PU061:8`1TCb@0JU<W06eG:01fD2`0NE<_07aI<`20Gc@0Pf@f08EW=@80PfPc00h0
NFHn075N=P1^F340LETc06mE<01/D2/0KE4/07EG<`1mHR/0P6D^08=X<@27K3D0RVlh08]`>@80S74j
00H0Qfhh08E/=P21Ic@0OV<d07]P<`1jGSH207YN=`0A07QS=01mJ3T0PF/l089Z?021IST0PF@h08IW
>`2:Jcl0RFhi08Y_>P2;LCh0RW=108Ma@023KSl0OVTj07YX>P1nHcH00P1oI3L00`20ICP0PVLj08=X
>`0208AY?00808Y/>02;KCT0Rg0k08ac?@2;M3h0RWDn08Qe?@27M3`308U_?00508Y`?@2<LSl0SgE2
099hA@2DNTL00P2FQDd03P2GQU00VHME09Z8F02KR5d0W8UO09f:H02OSUX0XXiK0:B@F`2XTeh0[9EO
0;6HH02dVV40]I]R0P34WV001033WEl0`YaN0<2JG02oVE/20;jHFP050;VGF02hUUL0^9IG0;FCE02c
TE800`2bT5404P2cTE80^9UI0;NHF02eUUH0]9EE0;FFEP2iVUX0_IiN0;nPH036We`0b:5N0<^TH@3=
YV<0c:ER0<ZSH036We`0a9eJ0<:LE@80`Y]F00<0`IYG0<6JF@31VE/00P31VE`0403;XfP0eJeb0>:k
PP3ZaHh0kLZD0>c;UP3^cIP0l=2M0>kCWP3^d9X0jL^E0>?4S@3K^h80e;5g0<jZKP39YFT20<bZJP04
0<f[J`3?[Fd0d:i^0=6_K`80d[1`0P3B/WT20=6aN080d;1g0P3?[gH0:03B/G/0d[9i0=6aN03@/7D0
cJe`0<Z[J`37Z6L0aJIU0<:PH035YVH0]9AG0:21B02RQ4h0XXID09n5E02TREX0WhED0:26E@2QQeH0
XhUH0:F;FP2WSE`0Z8iM0:V?GP2RS5X0YXmM0:ZCH@2]Tf80[91P0:j?H02cTf@0]iMX0;VGJ@2nW6h0
aJ=f0<bYO`3B[hL0eK:<0=JcS@3F/Xh20=^hT00>0=bjU03M_IH0gKnI0=k2W@3O`Z00g/BQ0=_4XP3L
aJ<0g/NW0=o8Z@3NaZX0gLF[0=c4ZP3K`j/20=G2Y0040=?0XP3A_Z00d;fO0<jkW@80c;VK01L0c[FF
0<^bT`38/8h0ajn;0<R`S035[HL0_jQo0;ZSNP2`TfL0[I1T0:f@IP2cUVh0_9ih0<>UP@36Z8@0aZR6
0<fbU`3>/iP0ckFL0=:jXP3F`:T0flJa0>3;]P020>7?^`080>GD`P3ZfLL0j]W70>_Kb`3Wf/X0iMW;
0>KLd03Ygm<20>cRf0040>gSf@3_iM/0l>KL0?;XgP80lnWO203dj]h80?G[g`P0m^gN00P0nNWI0?SY
eP3hjMH0mnSC0?OXd@3fj<h0m^S=0?GWc080nnO>00H0n^K=0?WUc03hi</0mn?:0?KRb@3ehLP30?OS
bP80m^;90`3ehLP30?;Pb080lMo70`3`g/H80?;NaQ00kmg7203`h<T;0?;Qc`80ln;@0`3dhm420?3S
dP80lNCC0P3biM@20??Ve@<0ln;>0`3bhLd:0?7Pc0<0l>390P3_glP30>kNa`80l=[20`3_fL430>kH
`0090>gG_`3^fKh0k]Vn0>cG_03[e[/0jMBi0>SC^03Wd[L0i]6f0080kLj_00H0k<f^0>_<[@3Zbj`0
jLZ[0>S9ZP3Wb:T20>K5XP060>G5W`3S`i`0h/:I0>31U@3O`9@0g[nA0P3N^iD00`3M^Y@0g;VC0=^h
TP020=ZgT@040=VfT03B[hL0dZn70=:_Q`<0dJj60P3@[HD20=:`RP040=:aR03A/8D0dK230=2`P@80
d;1o0P3A[hT0103@[XP0cjf70<j/QP3=ZhD20<bZQ0030<ZXPP3;ZH<0bjV30080c:Z400T0cJ^50<j/
QP3>[8H0cJf70<j^R03?[hT0d;2:0=6aR`3B/X`00P3C/hd20=BcT080eKBA00@0e[FB0=NfT`3G]Y<0
ekJC0P3E]Hl0103F]Y00ekNA0=RhTP3I^I<20=ZjU0<0f[VF0P3K^YL;0=bkV0<0gkjK0`3P_i`40>70
W@<0h/6N0`3S`Yl0103Tb:<0iLVT0>G9Y03UbJ@20>K:Y@80il^V203Yc:`;0>S;Z`<0jLb/0`3ZcJd@
0>O<[Q00jLj`203WcJ`80>O<[P<0i/jb0P3UcK430>C</0<0i/^]0P3Wc:h30>S=[`<0jLb/0P3Xbj/3
0>O:ZPP0h/^[0`3TbZl20>G;/0<0i/ba203TcJd80>K>[080jLb/0P3Xbj/30>O:ZP040>K9Z@3Yb:D0
jLRU0>W8Y@80j<NT0`3WaZ<30>?6YPD0i<NW00@0iLRX0>C7Y`3TajL0i<NW0P3SaZH20>;5Y@P0h<>Q
00D0h<:P0=o1W`3O`Il0g/2N0=foW@020=bnW080fkfK203M_9T80=bkV0<0fkZG00<0g;^H0=flV@3M
_9T00P3N_IX;0=bkV080fkZG0`3J^IH80=bkV080gkjK0P3N_IX20=flV@80g;^H0P3N^iD40=fjU080
g;VC0P3H]i@01P3I^9D0f[VF0=^jU`3L^iP0gKbI0=jmVP80gkbD00@0g[^C0=biT@3K^900fKJ>0P3H
]Hd0203B/h@0d[>50=>dQP3C]8P0e;B;0=BdS@3D]8h0eKF?0P3E]Hh0103D]8d0dk><0=:bR`3A/HX2
0=2`R@@0dK6:0P3B/X/20=>cS0@0e;B=0P3E]Hh20=JfS`P0e[FB0P3D/HT00`3C/8P0dZn70=6^QP02
0=2]Q@060<n/Q03?ZhL0cj^70<n/QP3>Zh<0cZ^10P3=Zgh00`3=Zgd0cZ^10<j[P@060<j[P@<0c:Uo
0`3;Z7h30<ZWO@80c:Mj0`3;YWT30<ZUN080b:=g00L0aj9e0<JRLP35XFl0aJ5]0<BPK034XF/0aJ1c
0080aJ5a00D0aJ5_0<>OJ`31WVP0_Y]S0;bIH@080;bHI0P0^iMS00<0`9]_0;nJKP2mV6`00P2lUf/0
102mV6`0_iY^0<2KK`2mV6/20;jIK0030;nJK@30Vfh0`Ia_0080`Ye`0P31WFd20<2LK0@0_i][202m
VFT30;fIIB_ooooo000Zooooo`<0YWa:0`2WOD/20:QnC0P0Ygi:202VO4X80:UoC@80ZX5;0`2YP4X3
0:QoB@<0Zh9:0`2/Pd/20:f4C0<0[H9?0P2^Pe030:n4D@80Zh9>00@0[8=?0:f4D02]Q500[XEA0P2_
QU801P2YQ4l0Z8=>0:R3CP2WPTd0YX5<0:F0B`80Y7m:0P2ONd401`2PNd@0X7]609iiA02NND@0W7M3
09Uc@P2HLT400P2IM40209Ye@@0:09Ud@02FLCd0Tfhj095/>02?JSD0SfXf08iZ=P2<JcP0RVXi08YZ
>`80RFXl00P0Qf8f08QS=`2:ICT0RVDi08UT>027HSH0Q5lc08=N<P80PEl_00@0P5h`07mM<01oG380
OU/c0P1mFS@0101jFS40N5P_07EE;01aDBP2071@9`03079B:@1cDbX0NUL_00L0NUL_00<0PEhd081M
<`1nFc400P1nFc400`1oG380PEhd089O=@0208AO<P0408IQ=028HcH0RF@g08]V>@80SFPk00P0SV<f
08mT=`2@ICP0TFHi099W>P2CJ3/0U6Tl09EZ?@P0TV`m00P0V6Tm09MX?02CIcX0TFHi091W>@2?JCX0
TF/l095]?@<0Tfdn00<0TV`m095[?02@JS/00P2@JS/3099/?@80TF/l0`2@JS/0102=HSD0Sf@g095V
>@2CJ3/209AY?00:099W>P2AIST0S6Hg08aV=`2=IcP0SfTj095[?02BK3d0Tfdn09A^?`P0TF/l0P2G
KC/209I/>P0509E[>@2DJSP0U6Xh09=Y=`2?IC<00P2@IS@00`2BJ3H0TfTg09AZ>00209E[>@0409A`
?02CKc/0Tflk099^>P<0TFdi0P2@K3P3099/?@80Tfdn0`2DKSl809E`>`0309Mb?P2EL3`0Tfhj00<0
TF`h00<0TVdi09=^>P2EL3`00P2EL3`209Ia?@<0Ug8n0P2DKc/0102EL3`0UW4m09Ia?@2GLSh209Qc
?`80UG4m0`2DL3`309=_>`P0U70l0P2ELCd309A`?0<0Tflk0P2FLSh409Ea?@80U70l0P2FM4L00`2F
M4H0UWA409Ie@P0209Ie@00309Ie?`2CMD<0TgE300<0U7I401h0TWA2091b@02>L3h0RFXn08MX?022
ICT0OF8e07MO<@1bG2d0KUTZ06eH:@1ZDbT0JE@Y06UC;01TD2/0GT/Z05A39@1<?B00AcLM040e8`0m
=B80?3<R03Tb8P0f<280<blS030^8@0_;B40:bPO02XW7P0X:1h202HX7@0302@W700R:1`08BLK0080
82<J0`0O8QT301hQ60@08RDJ100S9Q/01@0T9a`08bHK020S6P0N8AX071hI008071hK00<07AlN01`N
6`0L7Q/01`0L7Q/0600M9AH07RLF02@X5`0Z;AP0=3@L03hj8@15@2<0BD8U05i@7`1VF2L0Kel^07IT
=020Jc`0QW1107iX>@1aFB/0A40W03Pe8P0[9ah08alN024O800S91l09BTK02HZ6@<0:BXL0`0X:A/2
02LX6P809BHN0P0T9Ad202<T70808R<K00<08R<M020Q6`0O81X00P0N7aT00`0O81X0824K028S7@02
02<T7P04028S7@0Q8Q`08B8L020Q6`807b0J00/08B4G01hQ6P0O9Ql09B`T02L[7@0a:a<0BCTG065:
8@1mHBl0RVhl09=gA@02095e@`0@09QlBP2LP4h0W81>09R4A`2HO4X0WWa?0:f8E02dTUD0YHQ>081Z
@@1OCcP0>3Tc038c;@0[;2H0:R/U02d^:080<34[00D0;c0Z02d^:00[;2H0:BXT02HW8@0202DV8003
02HW8@0W:2809BDS00L09BDS0`0T9Al302DV80T09RLQ00H09bPR034/:@0a;2T0<2/W02lZ900_:b82
02hZ7`0H02dY7@0b;ah0<c0O03@a8P0d<2@0<blT034]900_:b80;BPR02d^7P0^;ad0<RlN03L`7P0j
<Ql0?c8O04<b7P14<al0BSTU04hm:@1A@2`0CchZ04Xi9@16=B40AC@P0P17=R800`18=R00BSPR04dk
9@0204lm9`0404`j9019=b40AS@N04Xg:080BcPW00<0C3XV04dk9@1>?2@00P1??R@204ll;@0404hk
;01=>R/0C3TZ04`i:P80BcPY00@0DD4Z0510:@1=?BH0BSXS0P19>B80201:>R<0Bc/T04Xl8P1;?B<0
C3`S04hl901??BD0DShV0P1D?RL0601GA2@0FDHV05a9:@1OC2`0H4d]05m<;01MBRX0G4TY05m<;P1N
Bbd0G4T[05Y7:@1IARP0FTLY05a9:`1MBR`0EDHW05I7:P1GB2/0EdL]05E5;01C@b`0D3l[04hm:@80
ACXX00X0A3PX048f:011=BT0?c8Y03ha:00n<BT0>cDW03Tc9@0g<B<0=2hP0`0c;Al00`0d;R00<RhR
03<_8`0203Da9@0<03@`900b;R80;b/O02hZ7P0d:Qh0=B/O03H/800g;B40>BlS03X`900k<BD0?38V
0P0d<B80100c;b<0<RhS034]900`:bD202lZ9P<0<blV00<0<RhU034]900`;2<00P0`;2<3034]90<0
<2`S0P0_:b80200a;B80<RhS03@^8P0f;R40>C0Q03``800n<B40?S4P0P17=bL01016=RH0ACDU04@d
9013<b<2048b8P0;04<h9P15>2D0B3/X04`m:01>?RL0CcdU054m901@?2<0Ac`Z04Hk:@14>BL00P12
=bD00`13>2H0A3TW04Dj:00304Tg:@0304Th:019>2H0BCPT0080B3PQ00L0B3PO04m0:@1>?bP0CChW
04`m9P1:>b@0B3TR0080AcPQ00P0BSPP04Xj8`1;>b@0BS/V04Pk:016>bT0@cXY048i:0P0>cHR02h0
>c8Q03hc8@11=R80ACTQ04Xl8@1>?b00DD4P0592801HARh0EdD]05M6:P1GARP0F4PV05]<9@1MCRD0
Ge0U05Y;;P1IB2X0F4PW05Y8901MBR80I4lT06YC9`1^F2T0MD`/07QB;P1oFC@0Pf0f08IU>026J3H0
PfPc085V;`1jIcl0LUlg06mI<P1bFS@0L5Ha06a@:`1]DB`0M5Hb07aR:@1nI2/0PVP_08I/<`29KcH0
Rg4h0P2<LST0:028KcL0QVdg089X=@1nHc@0NUlb07QL=01gFc@0Me/f07MR<`1lIcP0PV`m08=[?@22
IcX0PfHj08UZ?P2=KT80RVlj08Ya>`2<LSl0RgA208Uc@P24Kd00OF/k07YX>P1mHSD0OV<f07mT=`21
IST0PfPk08EZ?@26Jch0Qf`o08Y/>02;KCT0S74l08ed?P2<MCl0RgHo08Uf?P28MCd208ab?`0F08]a
?P2<LSl0SWA1099hA@2ENdP0Uge:09^;D02KRU80W8]E09j<FP2OSEd0XHiS0::?I@2RSfL0YYAR0:JE
H@2ZUV<0[9MR0:nHHP2cVV80]9]R0;JLH`80`ieO00@0`YaN0<2JG02oVE/0_IMI0P2lUUP0502jV5T0
^9IG0;RFE`2fU5D0]99C0;>ADP2bT540/i5B0;BBD`2jVe/0^9UI0;JGE`2dUED0]IIF0;RIF@2lWEd0
_YmO0<JOG038XEh0bjAQ0P3<YF800`39XUl0aYmL0<BMFP020<6KE00F0<2IE030VEH0`9UH0<2HFP2o
UeT0_iMJ0<VQIP3CZg00gkQo0>W2R@3/ai00k<VC0>g<U`3_cYT0k=6J0>c>V03WbY80hL:90=ViOP3B
[gD0c:Q/0<RTJ080bjUY00@0c:YZ0<j/K03?[Fd0dJm_0P3B/7020=:bN@80dK5h00D0d;1g0<n_MP3?
[gH0cZie0=:aN`020=:bN@0S0=2`M@3>[W40bZ][0<NXI`35YVD0`ImO0<BUI@2cTeH0Wh170:63C@2R
QU@0WXAC0:>8F@2MPe80WXAC0:26E@2RR5L0YH]J0:N=G02YSeh0ZY1O0:6;F@2VSed0ZY=Q0:bBH@2[
Sel0[HiO0;:BH`2fUVL0]i=S0;^FJ@32WG00bJAh0<jYO`3AZh@00P3AZhH0<P3H]H/0fKJ>0=ZiT03K
^i@0fkfG0=foV`3M`9h0g/6O0=c4XP3MaJ<0g/FV0=o6Z03OaJX0g/BY0=g3ZP3L`ZT0e/>U0=G2Y03C
`:80d[nQ0=2mW`3>^id0cKZL0<biV`3?]YL0bk:C0<R`SP37[h/0b;2<0<F]Q`2oZ7l0^J9i0:nBIP2]
T6@0[I1V0;:EK@2kWGL0`jF10<JXQ036Z8H0c[>H0<ncV`3@]Yd0dk^S0=O1ZP3Lak80h/fj0>?A_@3Q
c[d0iMC20P3ZfLT02`3[fl`0imW<0>KJc03Vg=00jMoC0>cRf03]hmT0k^CJ0>oUf`3`i]`0l^SN0080
lnWO203dj]h80?G[g`P0m^gN0P3gj=D0103gj=<0m^O@0?GWc@3di//20?CVb@080?_Wc03ji//0nNG:
0?STb@3ghlP0m^;70?GQaP3dh<D30?KRb@80mN780`3dh<L20?;Pb080lMo70`3`g/H00`3_gLD0lMg5
0?7Ma@060?7MaA00kmg7203`h<T:0?;Qc`<0ln;@0`3dhm420?3SdP80lNCC0P3biM@20??Ve@<0ln;>
0P3bhLd30?7Pc0P0l^3<00@0l>370>oOaP3_glH0kmo60P3^g/D20>gMa0<0k]S00`3]ekl30>cF_P80
k=Nj00@0j]Fh0>WD]`3Wd[D0iM2c0P3Tck820>S7Z0040>O6Y`3VaJH0i<>T0>?2X`80h/6R0P3S`I`0
103Q_iT0h;nF0=jmTP3L^hh20=^kS0060=JcS@3E/X`0eK:<0=BaR`3C/8X0dZn90P3A[XP20<j[P@80
cJZ00`3<ZGl01P3;Z7h0c:^20<b[PP3;ZWl0bjYm0<ZZN`80bZYi00H0bZYg0<^ZP@3;ZX40bZV00<VX
O`38Ygh20<JUO0030<FTN`34XgX0a:=j0080aJAk00`0aZEl0<NVO@37YWd0b:Mn0<RXPP39ZH<0bZZ4
0<^[Q@3<[8H0cJf70<j^R03?[hT30=2_S0030=6`S@3B/Hh0dk:?0080dk:?0P3D]8h01P3E]Hl0e[J@
0=NgT@3H^980fKVC0=ZjU080fKRE0P3J^IH30=^jU`030=bkV03G]Y<0ekJC00H0ekJC0P3N_IX20=nn
V`<0h;nL103Q`9d20>;1WP<0hl:O0P3TaZ820>G7X`<0i/RT00<0ilVU0>W;Z@3YbjT04@3YbjT40>[<
ZP80jlf[403Vbjd@0>O<[PP0i/bY203Vbjd30>G=/@80i<b`0`3Sbjl30>G:[080i/^]0`3Wc:h30>W;
Z@80j<ZX0`3WbJL80>39Z@<0hlV^0P3TbZl30>G;/0P0h/^[203UcJT30>W;Z@80j<ZX0`3WbJL0103Y
b:D0j<NT0>S7Y03Xaj@20>O6X`80i/FR00<0h/FU0>?6YP3SaZH00`3SaZH50>C7Y`80hlJV0`3RaJD8
0=o2X080gl6O00<0g/2N0=foW@3L_Y`00`3K_I/00`3J_9X0gKbI0=flV@060=flV@P0g;^H0P3J^IH0
103K^YL0g;^H0=bkV03M_9T20=jmVPX0g;^H0`3K^YL30=ZiUPP0g;^H0P3O_Y/20=jmVP040=flV@3L
^iP0g;^H0=^jU`D0gKZD0`3L^I<20=RgU0030=VhU@3J^IH0fkZG0080gKbI00L0g[fJ0=nlU03O_9@0
g[^C0=biT@3K^900fKJ>0080f;F=00H0d[>40=:cQ@3C]8H0dkB80=BdR`3D]8d20=BdSP80eKF>00@0
e;B=0=>cS03A/HX0d;290P3?[hP0103A/HX0d[:;0=:bR`3B/X/20=>cS080e;B=00@0dk><0=BdS@3D
]8d0e;B=0P3E]Hh20=JfS`P0e[FB0P3D/HT0103C/8P0dZn70=6^QP3@[HD20<n/Q080cj^700<0cZ^5
0<j[P`3>Zh400P3=Zgh00`3=Zgd0cZ^10<j[P@060<j[P@<0c:Uo0`3;Z7h30<ZWO@80c:Mj0`3;YWT3
0<ZUN080b:=g00<0aj9e0<JRLP35XFl00P34X6`02@33X6X0a9mb0<BPL035XG40a:1^0<>OJ`31WVP0
_Y]S0;fJHP080;bHI0P0^iMS00<0`9]_0;nJKP2mV6`00P2lUf/00`2mV6`0_iY^0<2KK`020;fHJ`04
0;jIK02oVVd0`9]^0<6LK`80`Ye`0P31WFd20<2LK0<0_i][00<0_YYZ0;fIJ@2mVFT01P2mVFT30;fI
IB_ooooo000Zooooo`050:AiAP2UNTL0YGY70:IkB02WO4T00P2XODX00`2YOT/0Ygi:0:MnBP060:Mn
BPP0ZGi900@0Y7]70:ElB02UO4P0YWe90P2WOTX20:QoB`080:QoB@2YP4X0ZX5;0:^2C02ZPD/0Z7m9
0:ElAP2TNdD30:V0C0030:Z1C@2[PTh0[8=?0080[8=?00H0YWe90:QoB`2[PTh0[HA@0:n6DP2^QE42
0:f4D0P0[8=?00@0[89@0:^1C`2[PDl0Zh5?0P2ZP4h20:UoC@80YGa800D0Y7]70:=jAP2SNTH0XgY6
0:9iA@020:5hA00@09ag@`2KMT80VWE109Qc?`2FLCd0UG0l09A_>`2CKSX0TVdh099]>@2AK3P0T6Xi
08mY>P2>J3/0SVLl08eV>`80R6@d00l0Qf8e08IQ=@24GcD0Pedf089L=`21FcH0OeX`085L<P23GS@0
Q5le08EP=P24GcD0PUdc085L<P1fEbP00P1fEbT00`1fEb/0MED/07EE;P0207EE;`80Le</0`1dE2d3
07EE;P0507YF<P1kEc<0NePb07aI<@1nFc400P1oGC002P20GS00QF0c08IQ=027HSD0R6<f08YU>02;
IST0S6Lj08eX>`2=J3<208iY=00308mZ=@2@JcH0TF`g0080TVdh00H0TVPf09=Y=`2CJCL0UF/i09I/
>P2GKC/209Q^?080TF`h0P2BKCT0102CKSX0U6lk09A_>`2EL3`309=]?P<0TV`m0P2AJc`3091[=`80
TF`h0`2BKCT01P2:IC40RfHb08aW<`2=J3@0SVTe08mZ=P80T6/g00<0SfTj08iX>@2<ISL00P2;ICH0
0`2<ISL0SVPi08mY>P08099X=PP0VV`k1@2EJcT309AZ>080UVdi00<0UF`h09A[=`2DJcL00P2CJSH2
099Y=@0809IZ>@2FK3X0UV`j09E]>P2DKc/0Tflk095`>`2BLC`3099]>@80TF`h0`2@JcL0202?JS<0
T6/d095/=@2CKSL0U6lh09Ia>P2GLS/0V7<l0P2IM40309Qc?`<0Ug8n202ELCd00`2AKCT0TVhj09=_
>`0209A`?00309=_>`2BKSX0TFdi00P0U70l2`2CKc/309A`?080UG4m0P2FMD0209Ed?`0509Ac?P2C
LSd0Tg8m099a?02CMdL00P2BMTH00`2AMDD0T7A408mc@`0208ib@P80QfHk01`0QFHj085T>01mHSD0
Mela079J;01_FBX0K5D[06aG;01[EBh0Ie<^061=;01GARP0Cd0S04/k8@11=R80?SHQ03de8P0i<R00
=S0P038_800_;Ah0;R`O02hW7`0/:1l0:bLN02TV7@0W9ad09BLL0P0S9Q/2020S70<07b8K0`0N8AX2
024T7@04028U700R9AX08bLI02@X6@8092PG0P0P8aP01P0O8QT07b8K01dO6P0L7Q/06adJ01XL6`T0
6AlK01P08AlP02@P7`0W91d0;BTM03Ha7@0n>A`0AClO04U37`1RD2P0JeX/07UX<P25LSL0R7@i08=/
>01lHCH0METd04E0800k=Ad0;BLI02<N6P0R7Qd08b8N02HV700V:1X202/[8@0302XZ800Y:Al0:2PN
00809RHL00<09BDK02DV7P0T9Ad00P0T9Ad202<T70808R<K200Q8Q`0100R8ad08B8L024R700P8A/2
01lP6P807QlI01d08ahJ02@O6@0W81P0:B4F02dT5@0h;A/0AS/W0555;`1_FbT0N6@b085[>@25KS`0
SgE209^0B`2NP4X0V7Y409IgB@2HNTP0W7m50:>7B02/Se<0YhUE08QX?`1XAb@0>CT_02h^900Y:Al0
;RhT034a9`0202h^9009038b:00[;Al0:bdP02/]800[;B80:BXR02HW8@0S91l08R<N00X09RLQ0`0W
:28302PY8`P09RLQ0P0X:1h00`0Y:Al0:RXP02/[8@0202d]8`0402h^900b;200<bdQ03D_8`80=c4U
0180=S0T03@^8P0c;B40=R`S03T_9@0m<2L0?2hS03`/7`0o;Al0ASDU04hk;01C@Rh0E4<_0550;01;
>RH0A3<O04<b7P19>2@204ln:P06050n:01??BL0CS`V04dk9@1<>R@0BcTS0P1:>28204Tg8@0604Xh
8P1<>R@0CS`V04lm9`1@?RP0DClY201A?bL2058n9P0C050n9P1>?RD0CClU04/o9@1:?R@0BClT04Dk
8P16>R80ACTQ04Pi8P1;>b@0CcdW05<n:@1E@2/0FT8X05a4:P1OAb/0HT//06=<;00206A=:`0F06A>
:@1VCBh0I4//0617:@1M@bP0G48Y05i4;@1QAc00HdPc05I39@1G@bP0ED@X05=3:@1A@bT0C40X04Tm
9`16>bD0Bc`W04Xk9P15>2D0@SLU03he9080?CHV00@0?CLY03Da9@0e<BD0=C4U0P0d<2@303<_8`08
038b:00a<BL0<30V02l_9@0^;R@0;BdS02`/8P0[:b42038^8`0>03D_8`0h<2<0>S4R03da8@0o<R80
@3<R03hg9`0m=RH0>cDW03Hb9P0c<BD0;blU02d]8`0[;2@202/]8P80;2hS100];b@203D_8`80=2hR
0`0c;B408@0b;200=c0V03L^9@0g;b@0>2hR03/_8@0o<R80@c<T04De9@15>Q`0A3TM04@h7P13=b40
@cHU04<f9P14=RT0A3H[048e9013=R<0ACPU04Lk9@19?BD0BclU04a19@1=@RH0AclX04Dm9P13>bH0
@SXW044i9P11>2L0@STZ04<j:`0204@h800304Hj8P18?2@0BShV0080BclW00@0BShV04Tm9@1>>BP0
CcXY101@>bX01`1?>RT0CSTX048g8@12=b40@cPR04@i8`15>R@00P17?2H03`18?BL0AcTO04Hg8014
>200@SLQ03lg8P0m=R<0?CHT03/f8`11=2<0@cHS04Hi9P19?BL0C40X04e19`0204e29P0405A18`1F
@bD0F4DW05Y7:@80FdPZ00X0FTLY05U6:01PAbT0HdX[06E<;@1SBbT0GdLS05m78@1TCB@0JU<Z0P1a
E2`0;`1dE2/0N5L/07aJ;@23GS40Qf8e08YT=@1mIcP0NF<d07=L<01^Ebd0K5D/06iF<01cFcD0MUhj
07YK;01oH340Q6Hd08MY=@27JC<0RVde08mb>P2DMcd0RFlf08U^=`2:KcP0RFhi08Q/>P25JCT0PVHg
085U=P1mJCH0O6Pe07]U<`1lIC<0P6He08IZ>P2=KSl0T75208iaB@2=L4P0Rfi408U/@028K3d0R6`l
08Q/>P29KC/0P6`i0080P6`j00<0P6/l081[?P20Jd000P21Jd801P22ISL0QFTj08Y^?P2@M4@0U7Q6
09IkAP80UW]400P0T7U708mhAP2>MdD0SgQ6095jB02EOT`0VH9@09^4DP80XY9G00h0YY=H0:ZFF@2]
V5T0/YYJ0;>KF`2eW5X0^Y]T0;FFG`2bTe`0]IIO0;^LI@2oX6T0_IiW0;ZKI080_9YM00L0^iUL0;ZH
F`2iUeX0^9II0;NEF02fU5L0]i9>0080]i5@00@0^I=B0;ZDE@2lUUP0_IIK0P2oV5l00`2kV5P0^YMG
0;REE@030;JCD`0:0;NDE02hUED0]iYH0;RKF@2lWE`0`9iN0<6OG`32Wel0a9iO0<>MGP80_9UI00`0
^iQH0;ZGE`2iUUH0^9EE0;NDE02fTe<0_YUT0<FPJ`3@ZgH0fkJ10>BoRP3Ya8l20>[5T00@0>c7T`3W
`Xd0gkZ50=JaNP3?Zg40bZIZ0<RTIP37XfD0b:YT0<RYIP39ZVL0bZ]Z0<b]K@3=[G00cZic0<n_M080
d;1g00<0cjmf0<j^M@3=[G@00P3<[7<04@3;Zg80cJe`0<b/K`3;Zfh0bJU/0<RXJ`36YVT0aJEX0<BT
I`33YV`0`:=Y0:^>EP2NP4X0XhEA0:63C`2LOT`0XXAB0080X8E>00H0XHI?0:>8D@2TRE80YHYC0:J;
E02WS5D30:V=F`030:Z>G02[Sed0ZhmM0080[91N01h0]91N0;RDHP2nVVX0a9mb0<ZUN@3>ZGl0d:^1
0=6[Q03?/Hd0d[6>0=BdSP3G]Hl0f[N?0=jhT@3P^I00hKZA0>30U`3Q`IP0hLBL0>;6W`3PaZ40glNS
0=k6XP3LaJ<0f<>V0=O2Y@3F`J@0eL2S0=>nX@3B_J020=6lW`0J0<^bU038[i40aJb=0<B[S035[H/0
`ZZ60;bTOP2fWWP0]YYX0:fAH@2[Sf00]IQ^0;jPNP32Y880aZN80<f^T@3</iD0cKJG0=6iW@3D_j@0
f<B[0=_9/@3Nc[L0h=2i0>7D``3Se/D20>KIb0030>WLb`3/glh0kN3?0080kN3?00H0jnGI0>cVfP3/
i]X0kNOK0>kXg03_jMd20?3ZgPP0ln[I00@0mn_K0?KZfP3fj]X0m^[J0P3ejMT20?CXf0060?[Zf`3i
jMT0nNWI0?WZe`3hjM@0n>WB0P3gjLl20?kWb0030?gVa`3liLH0nnC50080n^?400L0nN;30?[R_03i
hKd0nN6m0?SP_P3gg[l0mmk00080m]c10P3ah<820?3O`@040>oN`03^gKl0k]fo0>gL_P<0kmk40P3^
gL<30>gL`P80k]g;0P3_g/`20?3Oc@80lN3>203^g/D80>kMba00k^?A203`h=020?KTePH0mN?E00H0
k^KC0>oTdP3`hm00kn?=0?7Rb`3ahLX20?7Oa`H0k]g90P3]g<P20?;La0090?7K``3`f/80kmW10>kH
`03]ekl0k=Jn0?;C]P3bdk@0lM:c0080km6_0180k]2/0>g?Z@3/cjL0jljV0>o=Y`3^c:H0kL^U0>_9
X`3XaZ00i/BN0>G3W@3T`Y`0hl2H0>:oU`3Q_YH0h;fE0=nlU03M^Y820=biT@080=bfT@3K]Hh0f[B=
0=RcR@3G/XH0eK230=B`P03C[gl20<jYO080cJQk00`0c:Mj0<^VN@3;YWT0bZEh0<^VN@3:YGP0b:=f
0<NRM@38XgH0bZEh0<bWNP3=Z7/20<bVP@80bjF00`3:Y7l00`39Xgh0bJ=l0<VSO0020<RRN`040<NQ
NP36X7T0aZ1i0<FON080aj>100@0aj=o0<JSO@36Xg/0aJ9j0P35XWP01P37Xgl0b:B00<RTP039YH40
bZJ20<^WP`80c:R400/0b:N80<VXR@3;ZX/0cJb=0<n^S`3A/940dk:C0=BcU03D/i00dk:?0=:aSP02
0=6`S@030=>bS`3E]940e[FB00<0e[FB0`3G]Y<20=RgU0D0ekJE0`3F]I@20=BfTP070=FgT`3G^ID0
f;ZF0=VkU`3J_9P0fkfI0=flV@020=jmVP030=nnV`3P_i`0hL2M0080h/6N00H0f/:N0=_3W`3La:00
gLFQ0=k6XP3Oaj<20>38Y080h/>V00@0hlBW0>C5Z03VajX0ilR[0P3XbJ`30>C6XP80iLNS0`3Vb:@9
0>S:Z0<0jL^W00<0j<ZV0>O9Y@3Vb:@00P3Vb:@30>G=Z`030>C<ZP3SbjT0h/ZX0080h/ZX00@0h/VZ
0>?:Z`3SbZ/0hlZ[0P3Tbj`20>G<[@P0i/NZ203WbJL80>G7Y@P0h/VZ203Pb:H80>38Y0P0gLFQ0P3O
aZL20>37Z0<0hLRY00<0h/VZ0>K8YP3Vb:H03P3Vb:H30>C7Y`80hlJV0`3RaJD80>?5X`P0hL>O0`3Q
`ZD20>31Y0<0gl2S203Q`9d30=jnU`80gKfF103L_9D80=jkT`P0g;^H0P3J^Y<0103K^i@0g;bE0=bl
U@3M_IH20=jnU`P0g;^H0P3M_9/00`3L^iX0fkZI0=ZiV0020=VhU`030=RgUP3I^I80f[ZC0080f[ZC
0P3K^i@20=blU@060=ZiV03K^YL0gKbI0=noV@3O_iP0gknF0P3M_Y80103K^i@0f[ZC0=ZjT`3J^Y<2
0=ViTP80f;RA0P3J^Y<0103K^i@0g;bE0=blU@3M_IH20=jnU`0;0=fjTP3L^I40fkR@0=ZgS`3H]Hd0
ekB<0=JcR`3E/XX0e[J=0=FeS03C/hX00P3A/HP0103B/XT0e;B;0=FeS03E/hD20=FcQP030=FbR03E
/XX0eK:<0080eK6=00H0d:f70=6^R03A[XP0dZn90=>`RP3D/H/20=FbS0040=6aR03B/XT0d[:90=>c
RP80e;B;0P3E]H`80=JcR`040=>`R03B[hL0dZn70=:_Q`80dJj60P3@[HD20<j[Q@040<fZPP3=ZX00
c:Ym0<^YN`80bjUi203:Ygd30<^YN`80bZQj1039YgT02038YGd0bJIl0<ZWO@3;ZG`0bZQj0<VWM`37
YW<0aZEb2035XG402032WG00`im_0<BPL035XFl0a:1/0<:OJ@2oW6@0_IYR0P30W6P0102oVfL0_YYV
0;fII@2lV6@30;^GH`0?0;ZFHP2iUF40^9AP0;VEH@2jUV80_9QT0;jJIP2kUfL0_9QX0;nKJ`30W6`0
`Ie]0<2LK02nVVX0_IUY0080`9aX00@0`IeY0<:NJP32WVX0`im[0P34X6`20<>OJ`80`YiZ00@0`IeY
0<2LJ030W6P0_i]W1@2nVVH30;nKI`<0^iY]:oooool002[ooooo102VNdP40:MlB@P0Ygi:202YOTT3
0:ImB@030:MnBP2XOd/0Z7m;0080ZH1<00<0Z7m90:V0BP2ZPD/00P2ZPD/00`2XOdT0YWe70:AkA@02
0:V0C080ZX5=0P2[PTh20:b3C`040:MnBP2YP4`0Zh9>0:f4D080[XEA0P2]Q5080:b3C`@0Zh5?0P2Z
P4h20:UoC@80YGa800D0Y7]70:=jAP2SNTH0XgY60:9iA@020:5hA080VgI200`0VWE109Qc?`2FLCd0
UG0l09A_>`2CKSX0U6lj09=^>P2BKCT0TF/j08mY>P2>J3/208aU>P0;08UU=@28I3@0Qf8e08IQ=@24
GcD0Pedf089L=`21FcH0OeX`085L<P22GC<00P24GcD02@23GS@0PE`b081K<@1gF2T0MePZ07IG:@1f
Eb/0MED/07EE;P0207AD;P80Le</0`1dE2d307EE;P80NEDa00`0NULa07]H<01lFBl0OU`_07mM<01o
GBl0Q5lb08EP<`26HC@0Qf8e08UT=`2:ICP208]V>@80SFPd00@0SVTe08mZ=P2@JcL0TF`h0P2BKCT0
1P2BJ3H0TfTg09AZ>02EJcT0UV`j09M]>`80V6hl0P2@JcL2095/>004099]>@2CKSX0Tfhj09=^>P<0
Tfdn0`2BK3d2095[?0P0TF`h0P2;IS802@2<Ic<0SFPd08iY=@2?JSH0T6/g095/>02CKCh0TF/l091Z
>`0208mY>P03091Z>`2AJc`0Tfdn00P0TfTg202JK3/609I/>P80UF/i0`2EK3P409A[=`80TfXf00H0
V6`k09M]>`2GKC/0UVhk09=^>P2BKSX2091_>P<0TVdi0`2AK3P2091[=`80TF`e00<0TVdf09=^=`2D
KcP00P2EL3T00`2FLCX0UW4m09Ia?@0209Ia?@@0Ug8n202ELCd00`2AKCT0TVhj09=_>`0209Ea?@03
09=_>`2BKSX0TFdi00P0U70l2`2CKc/309A`?080UG4m0P2FMD0209Ed?`0409Ac?P2CLSd0Tg8m09=b
?@80TWI60P2AMDD0102@M4@0Sg=308ib@P2>LT8208MV>`0L08EV>P21I3P0OF8e07IN<01bFR`0KeTZ
06aE:`1/Eb`0JeD^06IB;@1PCB`0EdHX04m08`1;>b40@CHR03hf8@0l=240>C8P03H`800b;b00;bdN
02h/7`0^9al0;2PO02/W7P0Y9Qd09bLM02DW70808bHK0P0P8a`301lR6`<07R4J0P0Q91d03P0R9A`0
8RDJ02<W6@0T:1T092PG02DY600Q91T082<H020S6P0N8AX07AlJ01`N6`0K7AX06Q`K2@0I7a/06@0Q
7b008R4M02LT7@0]:Ad0=C0L03dg7@13?R00Ad4O05U:8`1SDRH0Kel[07UY;P1mJS00N68`071G;P1Y
Cb`0AD0P03/e7@0]9aT091lK028N7@0S8Qh09RHL02DW6@0[:b400P0Z:R001@0Y:Al09bLM02HV700V
9Q`09BDK00@092DM0P0S91`2028S6`/08B8L00<0824K01lP6P0O81X00P0N7aT08@0Q7QT091lK02DQ
600X8QH0;2DE03H]7015>RH0Cd@`06eH:@1gHc40OfTh08=/>P2<LSl0Uga709YlAP2EMd40UWM909Qj
B02KOT@0XXI70:b?D`2WRED0RFU006U89@0h>2h0;RhT02PX7P0];B<0<C4W02h^900_;bD0<c<Y02d_
8@0202d_8P0502`^8`0Z:b<09bPR02@U800R8ah02`0V9b4202LX8P<0:2TS200V9b4202PX7P0902TY
7`0Z:R00:b/Q02`/8P0];B<0;RhT038/800c;B40=BlS0080=c4U0180=S0T03D_8`0d;R80=B/Q03T_
9@0n<RH0?c4V040`8`13<B<0B3LW04ll;@1B@Bd0Dd8^0550;01<>bL0AcHR04He8@1;>RH20550;0<0
CS`V00L0CC/U04`j901<>R@0C3XT04/i8`1:>280BcTS0080C3XT00@0CC/U04hl9P1??BL0D3hX201A
?bL2058n9P0C050n9P1>?RD0CClU04/o9@1:?R@0BClT04Hl8`17>b<0ASXR04Pi8P1;>b@0CS`V058m
:01D?bX0FT8X05a4:P1OAb/0HDX[06=<;00206A=:`0I06A>:@1UCRh0Hd`/05m8:@1LA2P0Fd<Y05e5
;@1OAbl0HDPb05Q59`1HA2T0ETDY05A4:P1@@RP0BclW04Pl9P15>R@0Bc`W04Tj9`15>2D0@CHT03he
900m=RH0?CDX03`f:00303Da9@80=30T0`0c;b<01P0b<RP0<C4W030`9P0_;bD0;RhT02d]8`80;2`R
0P0b;R<03P0e;b<0>30S03Xa8P0m<B40?c8R040c8P0m=RH0?3DU03Xd9P0f<RH0<c4U030`9P0^;R@0
;BhV0P0/;28202d]8`<0;RhT00<0;blU03D_8`0e;b<00P0d;R8403<]8@0803H_9@0g;RD0=RhS03P^
8P0k;b40?c8R04<c9015=BD204Dj7P0404Di7`14>280A3LT04<f9P80@cDX0100@SDT04<f8`15>2D0
Ac/U04Tm9@1;?bD0C44U04e29P17?bP0ACdV04<k9P12>RL0@CTV044h9`12>BX0@cX[0P14>2000`16
>R80B3`T04Xn9P0204/o9`0304Xn9P19?BD0CCPW00<0CCPW00X0CSTX04lj:@1@>bX0D3/Z04@h8P15
>B<0ASXT04Lk9@18?2H0BCdW0P1:?RP03P18>R00AcPQ04Di8@12=b40?cLR03df8`0m=R@0>cHS044d
8`13=R<0ASTV04Tm9`1<@2P0CD4W0P1=@RH0101D@B<0ET<U05Q59`1JAbT205]8:P0j05Y7:@1IARP0
GTLX065::`1SC2`0HDXX05i88`1NB240HddV06QB:@1_DB/0Ke8Z07=C;01eEB`0NUT^081N<@27HSD0
RF@g07iX>@1jI3D0M5da06iG;@1/EB`0KUH`075I<`1dG3P0OEh_085R<`25IcD0QfTg08IX=027JC<0
Rfhf091c>`26K3<0QV/d08M/=@28KCP0Qf/i08IZ>P24J3T0PfLh07eY=`1lJ3H0NfDd07]S<`1oI3D0
Q6Pi08Y[?@2=KT00RVe508U/A027JT00QVTm08IZ>`27Jc/0RFdk08Y^?080PFdj00`0PVhl089]?P22
KD00PVe208=^@`23KD@0RFi108Y_@02=LT<0SgE4095gA02BND<2099i@@0H095iB@2@N4P0T7Q8095i
B@2BNTX0UGe=09R0D02JPU80XI5F0:BAE`2VTeP0ZIEH0:fHF@2bVUX0]IaL0;JMF`2lWF@0^IYQ0;NH
G`2iVV40_YmV0<2QJ02mWVD0^IYQ0P2hUUT20;NEF080]YAG0P2eTeH01`2hTdl0^I=B0;VCDP2iTe80
^YAE0;^EE`2lUEX00P2mUUd00`2jUeL0^IIF0;NDE0020;JCD`0;0;NDE02hUED0^IIF0;RKF@2iW5X0
_9eL0<6OG`32X600`j1P0<BNG`33WEh00P2kV5P0102jUeL0^9EE0;NDE02fTe<20;FBDP060;VDG@2o
VV<0bZE^0=F`N@3M^840h[f60P3T_hP01P3Ya8l0i;n:0=bgP03C[gD0c:Q/0<RTJ080aZ9T00H0ajUS
0<RYIP39ZVL0bZ]Z0<^/K03=[G020<j^L`060=2`M`3?[gH0cZie0<j^M@3=[G@0c:ac0P3;Zg801P3=
[G00c:a_0<^[KP39ZF`0ajMZ0<JVJ@80a:AW00h0`ZEY0;jQI`2ZSE<0WH180::4CP2PPTh0Vge;0::4
DP2NPd`0WhA=0:25CP2QQTl0XXM@0:B9DP80YHYC00@0Z8aJ0:V=F`2YSE/0ZXiL0P2[Sed20:b@GP0F
0;6@G@2dTf00^YQX0<2NL035XgH0bJIl0<^XOP3<ZH40cJn;0=2_S03B/X`0eK>=0=ReS@3L]hd0gkR?
0=nhS@3P_iH0h<2G0>;2V`3RaId0h/JO0=o5X080gLFQ0280f<>T0=O2X`3F`J80eL2Q0=>nW`3B_Ih0
dKbM0=2kW03=]9H0bK2B0<J]SP35[H/0aZj:0<>[Q@2mYGl0]j1g0;FII`2/T600ZhmP0;FHKP2oXG/0
`ZB20<NXR@3>[i80cKBF0<jgV03B^Yh0eL2U0=W5[03Lb[80glnh0>7A^P3ReL@0i=O60P3Wf/T01P3Z
gL`0k=o>0>gPc`3]h<l0k=o>0>cTe`80kNGH00<0k^KI0>oWfP3`j=/00P3ajM`80??Zf@<0mn[J0P3f
jMT30?GXf080nNWI00H0n>WF0?SYe03gj=40mnSA0?OYc`3fj<h20?gVa`030?cUaP3ki<D0n^?40080
nN;300X0n>720?SR_@3ghK`0mn2n0?KO_`3fgl00mMjo0?GM`@3dg<00lN340P3`gl<20>oN`P80k]g1
00@0kMc00>oNa03_g/@0kmk40P3^gL<30>gL`P80k]g;0P3_g/`20?3Oc@80lN3>203^g/L80>oNc0P0
kn;?203^hLh80?7Rc`@0l^7A103ah=001P3]h]00kN3=0>gPc@3^glX0k]k70>oMa@80l=c30P3_gLL4
0>kLaP80kM_500P0l=Rn0>oG_@3^e[`0kMFk0>cD^P3[dkT0j]:h0>WA]`80kLb]01L0k<^Z0>[9YP3Z
bJH0jLVS0>O7X03VaYl0i/JM0>O5W`3Va9h0i<:L0>;0VP3P_YP0g[bF0=fkU@3L^Y@0g;V?0=^hSP3J
]hd0fKJ<0=NdRP3F/hT0eK:80=BaQ`020=B^Q`060=:]P`3A[800cjYm0<jZNP3=ZGT0c:Qf0`3:YGP2
0<VTM`0;0<RSMP37XWD0aj9e0<FPL`34Wg80`iia0<:ML033WW40a9mb0<JQM037XWD00`37XG`20<JP
N`<0aImj0P37XWP00`36XGL0aJ1f0<FPMP030<BOM@80aJ5o00<0aJ5m0<FRO035XWX00P35XWP01P35
XgH0aZ9n0<JROP37Xgl0b:B00<VUP@80bZJ200L0bjN30<RWR039Z8T0bZV:0<b[S03>[Hh0cjj?0080
dK2A00<0d[6>0=6`S@3@[h`00P3@[h`00`3B/Hh0dk:?0=FdT@020=BcT080eKBA0`3F]I800`3G]Y<0
e[FB0=JeTP030=JeTP<0eKBA00H0dkFA0=BfTP3E]i<0e[RD0=NiU@3I^iL20=ZlV0060=bkV03M_9T0
gKbI0=jmVP3O_Y/0h;nL0P3Q`9d20=_1WP040=c2W`3M`j00g/BQ0=o5XP80h<JS0P3R`jH0103Sa:L0
i<FX0>C5Z03UaZT20>K7ZP<0hlFQ0P3TaZ830>G7X`T0i/RV0P3XbZH20>O9Y@80i/RT0P3Uaj<30>G;
ZP030>C:Z@3SbJP0hlVX0080h/RW0`3Sb:X20>C9Z`<0iLZ/203VajX80>K8YPP0iLNU203RajT80>36
Y@P0h<JS203Na:430=o4YP80h<FW0`3QaZP@0>C6Y0<0hlJV0P3RaJD30>74Y0P0h/BR203Q`il20>72
Y@80h<6T0`3O`:<00`3N_j80h;nL0>2oW0060>2oW0<0g[jG0P3M_IH40=blU@P0gKZB203L^iP20=Zj
T`80fk^D0P3L_9D20=fmUPP0g;^H00H0gKbI0=bkV03L^iP0fkZG0=ZiUP3I^9D20=RgU0<0fKVB0P3J
^Y<30=^kU0080=ZiV03K^YL0gKbI0=jnV03O_iP0g[jE0=fnTP3L_I440=ZjT`80fKVB0P3H^9420=Zj
T`80fk^D0P3L_9D20=fmUP060=biT@3K^900f[N?0=VfSP3H]Hd0e[>;0P3E/XX00`3E]H`0e;B;0=:b
R@020=6aR0040=:bR@3C/hX0eKF<0=FcQ@80eK>600<0eK:80=FbRP3E/X`00P3E/Hd30=:_R@<0dk2:
0P3D/H/00`3A/HP0d[:90=:bR@020=>cRP80e;B;00<0eKF<0=JcR`3F/h/01P3F/h/40=:_Q`80dJj6
0P3@[HD20<j[Q@060<fZPP3=ZX00c:Ym0<^YN`3;ZGT0bZQh203:Ygd20<^YN`<0bZQj1039YgT02038
YGd0bJIl0<ZWO@3;ZG`0bZQj0<VWM`37YW<0aZEb2035XG402032WG00`im_0<BPL034X6h0`im[0<6N
J02oW6@0_IYR0P2oVfL0102nVVH0_IUU0;bHI02kUf<20;ZFHP0@0;^GH`2jUV80^IEQ0;RDH02iUF40
^YIR0;bHI02nVVH0^iMW0;fIJ@2oVf/0`9a/0<6MK@30W6`0_i][0;jJJP80`9aX0P31WFT01@32WVX0
`im[0<>OJ`33Wf/0`YiZ0080`IeY0P30W6P20;nKI`L0_YYV0P2oVfL30;^JKB_ooooo000Zooooo`@0
Yga9102VNdP80:MnBPP0Z7e80`2XOd/30:V0C080ZX5=0P2XOdT30:V0BP040:QoB@2WOTP0YWe70:V0
C0<0ZX5=0`2[PTh0102/Pdl0Z7m;0:V0C02[PTh20:f4D0030:j5D@2]Q500[HA@00P0[8=?0`2[PDl2
0:Z0CP<0ZGm=0P2UO4P01@2TNdL0XgY60:=jAP2SNTH0XWU50080XGQ400H0VgI209Ye@@2IM400V7<o
09Mb?P2EL3`209A_>`0>09Ia?02EL3`0Tfhj095[>P2?JCX0S6Hi08]T>@2:HcP0RFDe08QT=027HSD0
QV4e08EP=P23GCH2089L=`03081K<@21G380PUdc00<0PUdc0P20Fc40201iFR/0N5T[07MH:P1fEb/0
MED/07AD;@1cDbd0LU8/0P1cDb`307AD;@<0MED^0100MU8^07MC;`1hEBl0NEH^07]H;P1lFRd0OE/^
07iL;P22GC00Peha08AO<P25H3<0Qf8e08QS=P29I3L0RVDh0P2=J3@00`2>JCD0SfXf091[=`02095/
>006099]>@2CJCL0TfTg09AZ>02EJcT0UV`j0P2GKC/00`2HKS`0SfXf08mZ=P03091[=`<0TF`h0`2C
KCh3099/?@80TF/l0P2CKSX0102BKCT0TF`h095/>02@JcL208mZ=P80S6Lc00<0SFPd08iY=@2?JSH0
0P2@JcL0102AK3P0UFm009A^?`2CKCh2099/?@0309=]?P2DKSl0UFm000P0UF/i202HK3/809M]>`@0
U6/g102EK3P02@2FKCT0VVhm09Q^?02HKS`0UVhk09=^>P2AKCT0Sfhi08i]>00209=^>P80TVdi0`2A
K3P00`2@JcL0Tfhi09=^>@0609=^>@<0Tfhj00<0U6lk09E`?02FLCd00P2GLSh809Ea?@03095]>@2B
KSX0U70l0080UG4m00<0U70l099^>P2AKCT04`2CKc/309A`?080UG4m0`2EM3l309Ac?P80Tg8m0P2B
MTH00`2AMDD0T7A408mc@`0208ib@P0O08ea@@27IS/0QfHk08AU>@20HcL0O64d07IN<01bFR`0KeTZ
06eF;01[ER/0JU@]06EA;01OC2/0ETDW04m08`1;>b40@CHR03hf8@0l=240>C8P03D_7`0a;Ql0;bdN
02h/7`0^9al0;2PO02/W7P0Y9Qd09bLM02DW700202<V6`8082<L0`0O8Q/301hQ6P808B@M00h08RDL
02<V6`0T:1X09BTJ02DY600V:QT08RDJ024T6@0P8aX07R4J01dO6P0L7Q/06adJ01/M70T06AlK01P0
820N028Q7@0T91`0:RPK034^6`0i=1h0@3/N04<n801>@1d0ETTO065C8P1[G2D0KE`V06UD9@1PBR<0
Fd8S04@o7`0k=Ad0;BLI02@O6`0S7ah092<O02DU6`0U9aT202XZ800302TY7`0X:1h09bLM00809RHL
00@09BDK02@U7@0T9Ad092DM0P0S91`3028S6`P0824K0P0Q8Q`3020Q6`<07b0J02P08AdJ02<P6`0U
81X09b0F02/S5P0d:aX0@CTV04a1;@1ZEBP0MF0a07eW>020J3P0Qfdl095e@`2DMT80T78n09EfB02G
NDL0VWe30::6A`2[SU80YhUE08YZ@@1[BRL0>3P^02d]8`0W9ad0;2`R030`9P0^;R@0;blU03@d:P0`
<R@0<38U02la900^<2D0:b`T02LX8P0T9B008R<N200V9b40100U9R009RLQ02HW8@0V9b4202LX8P80
:2TS200V9b401P0X:1h0:BTO02TY7`0Z:R00:b/Q02`/8P80;BdS00<0<R`P03<]8@0e;b<00`0f<2@2
03D_8`0903@Z800i;b<0@3@X04@f:@17=bP0BCPX04`k:@1??2/0D3hX0080DClY00@0CS`V04/i8`1;
>B<0CS`V0P1A?bT304`j90<0CC/U0P1>?2H804dk9@P0DClW0P1B?RH04`1@?RH0CShU04do9@1;?bD0
BShT04To9018?RD0B3`T04Lk8`19>R<0BSXS04dk9@1A?2L0DSdX05Y2:01K@bT0GTHZ065::`1SC2`0
0P1TCB/05P1SCBP0IDh^069;:`1OB2T0G4@X05]3:@1LA2`0GTH^05m6<01IARP0FDDZ05I5:@1DA2X0
D48X04/o9`17>bD0A3TS04Xk:018>BH0A3LV044e9@0m=2D203`d9`0403`f:P0e<BD0=C4U03Da9@80
=30T0`0c;b<2034a9`80<30V00@0;blU02h^900];B<0;BdS0P0b;R<01P0e;b<0>30S03Xa8P0m<B40
?c8R040c8P80>c@T00H0>C<U03Hb9P0d<RH0<C4W030`9P0_<2P302d]8`80;RhT0`0_;bD303D_8`80
=2hR0`0c;B40200f;bD0=bhU03H^8`0g;B40>blQ03ha8@13<b@0A3@T0P16>R001016>R80ACTS04@g
9013=RD2048e9@0@04<f9@14=b@0ACPU04Hj9018?2@0BShT04a19@1=@RH0AclX04Hn9`13>bH0@CTV
040h9@10=bH0@CPY048i:P80A3PP00<0ACTQ04Pl901:?RH00`1:?RH02@19?BD0BSLV04Tf9@17=2<0
AS<R04Pe901;>2L0CS/Z054n;@0204Lk8`0304Pl9019?BD0BShV0080BclW01@0C40X04Xl8P19>R<0
ASXR04<h8P10>2<0?CHS03`e8`0k=R<0@3<R048e8P15>2D0BCdW04/o9`1<@2H0CD8V04a19@1D@B<0
ED8T05Q59`@0FTLY03l0FDHX05i6:P1OB2T0H4TZ05m8:01NAbD0GdTT06==9P1WDBX0JThW06]?:01^
DBT0Le<Z07UH;@1oGC00Q68e08UT=`1nJ3T0NV@e07EN<P1`FBl0KEH]06eE;`1_Ec40L5Pd07eN<021
HS@0QFHg08IX=P24IS80Q6H`08QZ=02<KcL0QV`c08M/=@28KCH0RFhi08U]>`27Jc/0QVXk08EY>P1m
J3T0NfHg07YT=@1kHcD0OV<f085T>027J3`0RFXn08=V?P22ICd0PVDk08=V>P24J3T0Qf/k08Y^?02<
L3h0Q6lj08E`>`26L3h0QW0o08Ma@P27L4@00P27L4H0202BMd`0TGI9091eB02@MDH0T7I5091f@`2A
N480TWU30`2CODh00`2DOTl0UGm@09J0D@0209R2D`0@0::?E@2ST5H0Yi=H0:ZDF02`V5X0]9]K0;RL
G@2iWE`0_imV0;jNI@2oWfH0`J5X0<>SJP32XVT0_IeT0;VIH0<0]99C0`2eTe@20;JDE@070;RED@2h
UE<0^9EC0;RED`2hUED0^9AF0;VEF@020;VEF`80]iAD00h0]Y=C0;FBDP2fTe<0^9EE0;ZGE`2lVET0
^IaJ0;ZMF`2mWUd0`ImO0<:PH033X600a9iO0<>MGP80^IIF00@0]iAD0;JCD`2eTU80/i1@0P2bSdl0
1P2cSUL0^IAM0<>NI`3=Z740eK1i0=ZeOP80g;N000H0h[f80=jiPP3F/GX0cj]a0<VUJ@35XF<20<BQ
H@060<JXHP36Yf@0ajQU0<VZJ@3:Zf/0c:a_0P3=[G820<j^M@80cJed01X0c:ac0<^[LP3:ZW40bZYa
0<b/K`3;Zfh0bZY]0<RXJ`36YVT0a:AW0<>SIP32XVD0`:=W0;bOH`2XRe40W7m70:64C02OPD/0VWa8
0:63C`2KP4T0W85:09f2B`2NPd`0WhA=0:66C`80XXM@00H0Yh]I0:R<FP2XS5X0ZHeK0:Z>G02[Sed2
0:b@GP0H0;2?G02bTEh0]YAT0;^IJ`30WW40a:5g0<JSN@37Y7`0bZb60<b/QP3>[XL0dK270=BaQ`3I
]8P0g;F:0=fgRP3M_940gkjC0>30U`3P`i/0h<BM0=k4W`3M`ih0fl>O0P3I`Z<02@3H`J80e[nP0=Fn
W`3D_Ih0dkbM0=:kW03?]YL0bk:C0<R`SP020<N_R`0E0<B/QP2nYgh0^:5h0;>GI@2[Sel0ZhmP0;FH
KP2oXG/0`jF30<NXR@3>[i80c[FG0<nhV@3B^Yh0eL2U0=[6[@3Lb[80glnh0>7A^P3Se/D0iMS70080
im[900H0j]g<0>cOcP3]h<l0kN3?0>cOcP3]hmL20>kTf0030>oUf@3`i]X0lNOK0080l^SL203djML3
0?KYf080mNSG0`3dimH01P3himL0n>OE0?SWe@3gi]80mnO@0?OWcP80m^K<0P3liLH0103ki<D0n^?4
0?WR``3hhL820?OP`@060?KP^`3fgkd0m]nm0?GN_P3eg[l0m=c00P3dg<820?3Oa@80kmk4103^gL<3
0>oMa@80k]c40`3]fl<20>kMb`80kmk<0P3`gld20?7PcPP0kmo8203`gld80>kQcPP0kN3=203bhLl0
0`3ag/d0l=g<0?3Mc0020>oLb`<0k]_:0P3]g/T01P3]gLH0kM_30>cK`@3]fKh0kMRm0>gH^`80km_2
0P3^f/420>gI`080k=Ro00/0jm:d0>[A/`3Yd;80j<na0>K=[`3Uc:h0i<^]0>?:[03S`Z40hl:O0>;1
WP020>71V`040=noV03N_YD0gKjB0=bmT@80g;VA01H0f[N?0=VfSP3G]8`0eK::0=BaR@3C/8P0dZn5
0=6^Q03@[H<0cjb20<fZP03<ZGl0bjQn0<ZWO@3:Y7d0bZEk0<VTNP37XWH0aZ5d0<FQL@34X6h0`im]
0`34Wg830<>NL@80`Ye`00P0_YU/0;fHJ`2mV6/0_9MZ0;fHJ`2nVF`0_iY]0<2KKP<0`Yae0P31Vg@3
0<2JL`80`iid0P32WG<40<6LLP80`Iei00H0`Ymi0<:OM`33X7H0a:9e0<FSMP35XgD20<BQN`040<FR
O036Xgd0ajAn0<NTOP80b:Eo0P38YhH01039Z8L0bZV80<^ZR@3<ZhX20<f/R`070=2_S03?[X/0cZf:
0<f/R@3>[HX0cjj;0=6`S@040=:aSP80dk:?0`3D/i000`3C/Xl0e;>@0=BcT0050=BcT080d[B@00H0
dkFA0=FgT`3F^9@0ekVE0=RjUP3I^iL20=^jU`040=bkV03M_9T0g[fJ0=nnV`80h;nL0P3L_id00`3M
`9h0g/6O0=o2X0020>33X@030>74XP3R`j@0h/>T00H0h/>T0`3Q`il20>;4X0<0hlFQ2@3TaZ@40>G7
X`80i<JR0P3SaJ430>G8YP80i<NU0`3SaZ@20>?6YP80i<NW0P3Ub:P20>K9Z@P0iLJW203SaJ<80>C6
Y0P0hlJV403Qa:880=o2X080g/6Q0P3O`Z830>33X`030>74Y03Q`j40hL>Q00h0hL>Q0`3Ra:820>73
X@/0h<:P203O`Id20>31XP80gl2Q0`3N_j000`3M_Yl0gkjK0=nnV`060=nnV`<0gKfF0P3L_9D40=^k
U0P0g;VA203K^YL30=ZjT`<0fk^D0P3L_9D80=^jU`80g;^H00<0fkZG0=ZiUP3I^9D00P3H]i@0103G
]Y<0f;RA0=RhT@3H^9420=ViTP<0f[ZC00H0fKRG0=ZiUP3L^iP0g[jH0=jnU`3N_YD20=bmT@<0f[ZC
0P3I^I830=RhT@<0f[ZC0`3K^i@20=blU@060=^hT03J]hl0fKJ>0=ReS@3G]8`0eK::0P3D/HT00`3D
]8/0dk>:0=:bR@020=6aR0040=:bR@3C/hX0e;B;0=FcQ@80eK>600<0eK:80=FbRP3E/X`00P3E/Hd2
0=BaR`<0dk2:0`3B[hT40=:bR@80dk>:0P3D]8/80=FbRP<0dZn70P3A[XH30=2]Q@80cZ^500H0cJZ2
0<bYO`3;ZG`0bZQj0<ZXN039YgL80<VVO0040<^YN`3:Z7X0bZQj0<ZXNP80bJMi0`38YWP02038YGd0
b:Ek0<ZWO@3:Z7/0bZQj0<RVMP36YG80aJAa2035XG402033WW40`im_0<>OK`33Wfd0`YiZ0<6NJ02o
W6@0_Y]S0P2mVFD0102lV6@0^iMS0;^GH`2jUV820;VEH@0;0;^GH`2jUV80^IEQ0;RDH02iUF40^YIR
0;bHI02nVVH0_9QX0;fIJ@2oVf/00`30W6`20;nKJ`040<2LJ031WFT0`IeY0<6MJ@<0`YiZ00@0`im[
0;nKI`2oVfL0_i]W0`2nVVH20;fII@P0_YYV0`2lVV`[ooooo`00:_ooool01@2YOT/0Z7e:0:QmBP2W
O4T0YW]80080YGY700<0Y7U60:MnBP2WOTX01P2WOTX80:QmB080ZH1<1P2ZPDd30:QoB@030:V0BP2X
OdT0Z7m90080Ygi8102ZPDd40:^2CP80ZX5=00<0Zh9>0:b3C`2]Q5002`2]Q5020:^1C`80ZX1>0P2Y
Odd20:QnC080YGa800D0Y7]70:=jAP2SNTH0XgY60:9iA@020:5hA080VWE100h0VGA009Qc?`2GLSh0
UW4m09E`?02DKc/0Ug8m09Ia?@2DKc/0TF/j08iX>@2<IST0RV<h08UR=`80RFDe00H0R6<f08IQ=@25
H3H0Q5hg08=M>022G3L5085L<P0;081K<@1oFS00OeX`07YK;01iFR`0N5T[07IG:`1eEB`0Le</079B
;01aDB/00P1cDb`307AD;@<0MED^00P0M50/07EA;@1fDbd0N5D]07UF;01kFB`0O5X]07eK;@80PE`_
00@0PUd`08AO<P25H3<0Qf8e0P28HcH01P2<ISD0SFLf08eW=P2>J3L0SfTh091Z>@80TF/j0`2DJSP0
0`2EJcT0UV`j09I/>P0209M]>`H0SfXf0P2@JcL309=]?P<0TV`m0P2AJc`209A_>`0409=^>P2BKCT0
T6/g08mZ=PD0SVTe00<0SfXf091[=`2@JcL00P2AK3P209=]?P@0TV`m0P2CKCh809I/>PT0Ufdk102H
KS`309U_?@80TfXf00<0U6/g09E/>02EK3P00P2FKCT209M^>P0809]_?P2IKcd0V6hl09I^>`2CKSX0
TFdi08i]>02=K3L309=^>P80TVdi0`2AK3P309A_>`0309=^>P2BKCT0TF`h0080TF`h0P2@JcL01P2A
K3P0TVdi09A_>`2EL3`0UW4m09Mb?PP0UG4m00<0TVhj09=_>`2DL3`00P2ELCd00`2DL3`0Tflk099^
>P0C09=_>`<0U70l0P2ELCd209Ed?`H0U7<n00H0TWI6095eA@2AMDD0T7A408mc@`2>LT8208ea@@0N
08QW?027IS/0Pf@h07mR=P1jGc80MEd_079J;01`FR/0KEH/06]F:`1YDb`0I50[05i;:P1EA2H0Cd0S
04/k8@10=B40?CDP03`d8@0h<Al0=BlO034^7`0^;1d0;B/N02hW7`0/:1l0:bLN02TV7@0W9ad09BLL
0P0S9Q/2020S70<07b8K0`0N8AX03@0P8a`08B@M028U700S9Q/092PJ02DY6P0V:QT09b/J02@W700S
9Q/082<J01hQ6P0L7QT00P0K7AX00`0K7A`06AlK01TO6`0701TO6`0H01hP6`0P8A`08R<K02LW6`0]
:a`0=38M03/f800n>R40ACXL04e07@1FBah0GE4O05mA801LBb00ED4P04lj7`13?Qh0>S@L02hX6P0U
81`0920O02@S7`0U9A/092HH0P0Y:Al202PX7P0402LW7@0V9Q`09RHL02HV708092DM0P0S91`2028S
6`808B8J3P0P8A/201lP6P0Q01hM6`0P7a/0924L02DQ600Y8aL0<BXJ03df9017?b`0IE0S075L;`1k
ICH0OFDg085V=`2:KSh0SW0n08]]>`2EMTP0UgU709Ul@P2PQ4D0ZhiB0:R:EP2<K4<0KD`Y03Ph;P0]
;B<09RHL02/[8@0^;R@0;BdS02l_9@0d=2X0<C<U0080<C<V00D0;c4V02`]9@0X:B<092DP028S7P08
02HW8@809BHP0`0V9b4302LX8PP09RLQ0P0Y:Al202XZ800802/[8@0/;280;2`R02`/8P0b;200<bdQ
03@^8P0e;b<403H`900:03@Z7P0i;b<0@SHX04Tl;01>?Rh0Cch/04ln:P1@?RX0CCTQ04hj8P<0Cc/S
00@0CSXR04lk8`1@?2@0D3`T0P1:>2801@1;>B<0C3XT04dk9@1>?2H0CcdW0080D3hX0P1??BL00`1>
?2H0CC/U04dk9@0204`j90P0DClW0P1B?RH04`1@?RH0CShU04do9@1;?bD0BShT04To9019?bH0BCdU
04Pl9019>R<0BSXS04`j901@>bH0DC`W05U19`1K@bT0GTHZ065::`1SC2`00P1SC2X05P1SCBP0HTh]
061<:`1MB2T0FdHY05Y5:P1JA2`0FdD]05]5;P1IARP0FDDZ05M6:P1DA2X0D48X04Xn9P17>bD0@cPR
04Ti:@18>2P0@cHV040d9P0l<RH203/c:00403/d:P0e<BD0=C4U03Da9@80=30T0`0c;b<2034a9`80
<30V0P0_;bD202h^9080<RhS00/0=BlS03P`8`0j<B80?C4Q03lb8P10<b80>S<S03Tb8P0h<R@0=S8V
03@b9P02034a9`03030a:@0_;2<0;b`S00<0<2dT0`0a;RD203H`9080=BlS0P0d;R8203<]8@0903H_
9@0f;B@0=RhS03L]8@0j;R00?S4Q048b8`14=2@0ACTS00<0ASXT00D0ASTV04@g9013=R<0@SDT04Dh
9`0204Dh9@0=04Di8`17>b<0BCdS04]0901=@RH0AclX04Hn9`13>bH0@CTV040h9@10=bH0@3LX044h
:@0204@h800304Di8@17>b<0BCdU0080BShV00X0BCdU04Pl9018=bD0ASDS04<b8012<Al0A3<Q04Pg
9@1>?B/0DD0^0`1<?R@00`1=?bD0CT0V04i09P0204m19`0>04`n901;?2D0B3`T04Dj9010>2<0?SLT
03`e8`0j=B80@3<R048e8P15>2D0B3`V04/o9`1<@2H204a19@0405A18`1E@R@0Ed@V05U6:080FTLY
00<0FDHX05Q59`1KAR/00P1KART04P1KARL0FdLV05e99P1PC2L0HdlZ06E;9P1VC2L0JThW06iA:@1e
EB`0O5/`085P=@25HcH0OFLh07YT=@1fGc<0LEX`06iG;P80K5@^01T0KEDa07QI;@1mGS80PV<e08=T
=@23IC<0Q6Hb08U[=`2=KcT0SW@k08ic?02?M3d0SW<n08a`?P2:KSh0Qf/l08EY>P1lIcP0NVDf07YT
=@1jHS@0OF8e081S=`24ICT0QFHj0080OV4i00`0OV4g081S=`23IcP0Qf/k08]_?@2=LCl0R74k08Ub
?P2:Lcl0S7E308eeA@2=MDL208adB00809EmD@2CNdl0TGU;091hBP2@N4P0TW]909EnBP2GP4`209N2
D`0309V4E@2JQEH0VXEF00<0VXEF00/0Y8mF0:JAF02YTeT0[YIJ0;:HF`2gVe`0^IeN0;^MG@33X6H0
a:5W0<JSJ@020<RUJ`030<BQI`2nVf40^YMM0080]99B00@0]I=C0;JDE02hUUH0^IMG0P2jV5P01`2i
V5<0^IQE0;VHE@2hUe@0]iEE0;NEEP2fU5L00P2eTUP40;FBDP0<0;NDE02iUUH0_9UI0;jKF`2iW5X0
^YeK0;fNG@31Wel0`Z1P0<:OG`33WEh0`YaM0P2gU5@0302eTU80]95A0;:?C`2`SDd0[ha<0:j;B`2a
SE<0]Y9H0;nKH@38Y6X0d:ab0=FaM`80ek=i00H0fkIo0=NcN@3@[780bZIZ0<FQH`32Wel20<:OG@08
0<FWH@35YV<0aZMT0<NXI`39ZVX0bZY]0<^[L03<[7420<f]M0030<b/L`3;Zg80bZYa0080bJU`03l0
b:Q_0<^[KP3;Zfh0bJU/0<NWJP35YFP0`j=V0<6QI030X6<0_J5R0;VMGP2VRDd0VGa209n2BP2MP4P0
V7Y409n1C@2HODH0VGi709YoB02KP4T0WH9;09j3C02OQ4d0X8E>0:J:F02WReT0Z8aJ0:V=F`2ZSU`0
ZhmM0:b@GP2]TEl0[HeJ0:n?G02bTV40]YIW0;ZIK02mW740_iic0<6PM`35Z800b:R10<RXO`3;ZWl0
cjf00=B_P`3H/XD0f[B70=^iS03M^hh0g[fB0>30U`3O`YX0g/:K0=g1VP3K`I`0f/6R0=W0X@3H_j00
ekjO0=JmWP3D^i`00P3C^Y/06P3@]iP0cKFC0<VaS@38/8`0b;2:0<F^Q@2nYgd0^J9h0;6EH`2ZSUh0
ZXiO0;JIK`30XW`0a:J40<RYRP3?/9<0c[FG0<nhV@3C^il0e/6V0=[6[@3Mbk<0h=2i0>;B^`3TelH0
i]W80P3XflX00`3[g/d0k=o>0>gPc`020>cOcP060>gTe@3^iMH0k^GF0>oVe`3`imP0lNSI0P3bjMX8
0?CWe0040?OXe@3fim@0m^OD0?KWe080mNKC0P3diM801P3hiM@0mnGA0?OUd@3giLl0m^C<0?KUb`80
mNC80P3jhl@00`3ih/<0n>720?OP`@020?KO`0070?GN_`3bg[/0l]jm0?;N_@3bgKh0l]g00?7L`@02
0?7K``80kmk41P3^gL<30>oMa`80k]c60`3]flD20>kMb`80kmk<0P3`gld20?7PcPP0kmk:203ah<h8
0>oPb`P0k]o:203bh<`01@3cg/T0l]g80?;Mb03ag<L0l=_60080km[500L0k]W40>gMaP3^g<@0kMc2
0>kJ`@3]f;d0k]Jj0080k]Fg00D0k]Nh0>gF]`3]e[L0k=Ff0>_D]@020>[C]0090>WB/`3Yc:X0j<^Y
0>O:Z03VbJL0i<NU0>;5X`3Qa:80h<>Q0080g;ZE00l0fkVC0=ZiT03J^I00f;N<0=NfR@3F]XL0eKF6
0=F`QP3D[hD0djj40=:]P`3@Zh40cjZ00<jYO`3=Z7h00P3:Z7/03039YgX0b:Ii0<JTM`35XgH0a:9e
0<>QM033WW@0`Yea0<6LL030Vfh0_i][0;jJJ080_IUU1`2mV6/00`2lUfX0^YEX0;ZEJ0020;ZEJ005
0;^FJ@2lUfX0_9MZ0;fHJ`31W7800`30Vg420;nJL080_YU_202nVFd20;fJM0060;jKL`2oW780`Imb
0<:PL`33XG<0a:9d0P31WWH20<:OM`040<>PN034XGT0aJ9j0<FRNP<0aZF20P37YX<20<RWQ0080<VX
Q@3=[8T0c:^80<^ZQ`3:ZHH0bjZ70<b[R03>[HX40<n^R`80d:n<0`3A/8d30=2`RP<0dK6;0P3B/X`2
0=2bSP040=6cS`3C]I40e;JB0=JhU080ekVE00H0fKRE0=ZiUP3J^IH0fkZG0=bkV03M_9T20=jmVP80
fkjL0P3L_id20=g0WP80g/6O0`3P`Z030=o1W`80g/2N0`3N`9`20=o1W@<0h<:N2@3Ra:850>;4X0<0
hL>O1@3RaZ430>75X0@0h/FS0P3SaZ@20>C7Y@P0hlFS203Q`j480>;4XPP0h<>Q203O`ih80=o2X0P0
gL2N0`3L_id20=g0WP<0g/6O403N`9h30>;1WP80hL2M0`3P_i`80=k0WPP0gKnK0`3N`9h30=foW@80
g;jL203N_IX30=blU@@0fk^D0P3J^Y<80=^hT0P0f[VF203J^Y<80=ZiUP80fk^E00<0f[ZD0=ViT`3H
^9800P3G]i400`3F]Y00ekN@0=NgT0020=NgT080f;RA0P3I^I80203H]iH0fKRE0=^jU`3M_IL0gKfF
0=fmU03L_I40fkb@0P3J^Y<20=ViTP80f;RA0P3G]i080=ZjT`080=ZgS`3I]Xh0f;F=0=NdS03E/XX0
e;690=>`R03B[hL50=:bR@80dk>:00L0e;B;0=BbQ03D/XD0e;:50=BaQ`3D/HT0e;6;0080e;2<0P3E
/X`00`3D/H/0dk2:0=:_R@020=6^R0030=2]Q`3B/XT0d[:900@0d[:90P3C/hX80=BaR@80dZn70P3A
[XH20=2]Q@80cjb400P0cjb60<j[Q@3=ZX80c:Uo0<^YO03:Z7X0bJMg0<RVMPP0bJIl0`3:Z7X20<VW
N@@0b:Ih00P0ajAl0<RUN`39YW`0bZQk0<VWN@38YWH0aZEb0<FTL@P0aJ5a00P0`iia0<>OK`33Wfl0
`Yi/0<6MJ@30WFL0_iaT0;jKH`80_9QT00@0^iMS0;ZFHP2iUF40^IEQ0P2hU600202kUf<0^YIR0;VE
H@2hU600^IEQ0;ZFHP2lV6@0_YYV0P2nVVX20;nKJ`@0`9a/2031WFT50;fII@<0_9QT0`2oVfL40;jJ
IP040;fII@2mVFT0_IUY0;fIJB_ooooo000Zooooo`050:UnB`2XODX0Z7e:0:MlB@2VNdP00P2UNTL0
0`2TNDH0Ygi:0:MnBP060:MnBPP0Z7e81P2ZPDd20:V0C0<0Z7m900<0Ygi80:QoB@2XOdT00P2YP4X4
0:^2CP@0ZX5=1@2[PTh00`2/Pdl0[HA@0:f4D0080:f4D0<0ZX1>0P2YOdd30:QnC080YGa800D0Y7]7
0:=jAP2SNTH0XgY60:9iA@020:5hA080VGA00P2HLcl04P2GLSh0UW4m09Ia?@2EL3`0Ug8m09Ia?@2D
Kc/0TF/j08iX>@2<IST0RV<h08UR=`2:ISH0RFDe08QS=P27HSH0QV4g08AN=`80Pedh0P21G3800`20
Fc40OeX`07mJ<00307iI;`0807YK;01iFR`0N5T[07IG:`1eEB`0Le</079B;01aDB/207=C;0<0M5@]
0`1eEBh0401cCb/0M50/07EB;01gE2`0NEH/07]I;01lFRd0OE/]081K;P21G2l0PUd`08=N<@25H3<0
QV4d08MR=@28HcH208aV=`0308eW>02>J3T0SfTj0080T6Xk00<0TF/l09AZ>02EJcT00`2EJcT309I/
>P80T6/g1P2?JSH309=]?P<0TV`m0P2AJc`209A_>`0409=^>P2BKCT0T6/g08mZ=P80SVTe00<0SfXf
091[=`2@JcL00P2@JcL3095/>080SfTj102@JS/208mY>PP0UV`j202FKS/309M]>`0309Q^?02IKcd0
VFlm0080VW0n00D0TfXf09A[=`2DJcL0UF`h09I]>@0309M^>P0909Q_>`2KKch0VFlm09Q^?02FKS/0
Tfhj095]>@2>KCP0SF`g0080U6lk0P2CKSX2099]>@80TF`h00@0UFln09A^?@2CKC`0Tfdl0P2AJcX0
202@JST0SfTh08mZ=P2@JcL0TF`h099]>@2CKSX0UG0l0P2FLCd809Ea?@03099^>P2CKc/0UG4m0080
UW8n00<0UG4m09=_>`2BKSX0202BKSX;09=_>`<0U70l0P2ELCd609Ac?P80UG@o0P2AMDD00`2@M4@0
Sg=308ib@P0208ea@@0O08a`@028Ic`0QVDj08=T>01mH3@0NEha07AL;P1bFR`0L5X[06iG;@1[ER/0
JE</06=?:P1LBBP0E4<U04m08`1<?280@3DQ03de800k<b00>34O03D_7`0`;Ah0;R`M02d[7P0^9al0
;2PO02/W7P0Y9Qd09bLM02DW700202<V6`8082<L0`0O8Q/301hQ6P0=020S700Q91d08RDL02<V6`0U
:A/09RXK02L[6P0X;1/09RTN02@W700Q91/07R4J01`N6@0201/M6P0301`N7@0I7a/06AlK00L06AlK
01T0724K01lR6`0Q8QX092HI02PY6`0_;Q`0=34N03Ld8@10>Al0AchO04i67`1DC1h0Ed`O05A68@1>
?B40BSPR04<n7P0j=1`0;RPJ02HQ7@0U8B0092<O02DU6`0S9AL0:2PN00@09bLM0`0V9Q`302<T7080
8R<K0`0Q8QX8020Q6`807b0J1P0P8A/08@0L71`07alM024P700T8AX09R8G02hX6P0i<b<0@S/Y061;
801^FBh0NF8f07YR=01mHS<0Q6Pi08Y[?029JS/0U7E709IhAP2HNd40Wh=40:Z=D@2XRUH0SFe406m>
:`0j>S00;RhT02HV700Z:R00;BdS02`/8P0^;R@0<c<Y030b9002030b9@0502la9P0/;BD0:2TS02DV
8@0S91l0200V9b4302DV80<09RLQ0P0W:28802HW8@<0:RXP100[:b40600/;280<R`P03<]8@0c;B40
=2hR03D_8`0f<2@0=c4U03Pb9P0g;Ql0>S4R04<g9`1;?Rd0DD8_05=2;P1A@BX0CcdW04/e7@1<=Qh0
CcTQ054k8`1C?BD0DS`T04li8@80CCLO0P19=b401@1;>B<0C3XT04hl9P1??BL0D3hX0080DClY0P1@
?RP00`1??BL0CS`V04dk9@0204`j90P0DClW0P1B?RH04`1@?RH0CShU04do9@1;?bD0BShT04To9019
?bH0BCdU04Pl9019>R<0BSXS04`j901@>bH0DC`W05U19`1J@RP0GDDY0619:P1RBb/00P1SC2X01P1R
C2L0H4d/05m<:`1MBRX0FTLY05U5:P80F4@[00h0F4@/05U6:01IABX0ETDY05A4:P1@@RP0BclW04Lk
9@14>B<0B3PY04Lg:012=2L0?c<W03/a9`80>S4X00@0>S<[03Da9@0e<BD0=C4U0P0d<2@303<_8`80
<C4W100`<2H202l_9@80<RhS00/0=BlS03P`8`0j<B80?C4Q03lb8P10<b80>S<S03Tb8P0h<R@0=S8V
03@b9P02034a9`04030a:@0a;B@0<BdT034]90<0<RhU0P0c;bH303H`9080=BlS0`0d;R80800e;R@0
=RdT03D]8P0f;200>RhP03d`8012<R<0@c<S04<f9@15>2D0ASTV04Pk:017>bD0ASXT04@h8P13=b40
ASTX04Hi9P15>2D0ACTS04Hj8P18?280Bd0T04e29P18@2T0AShW04<k9P11>BH0?cLT03lf9@0o=RL0
@3LX0P13=al01014>200Ac/S04Tm9@1:?RH204Tm9@0:04Pl9016=b@0A3DR048c8011<Ql0@S<P04Lh
9@1<?BX0D44^04hn90@0CclU0`1@@2H03P1>@2H0CChW04Tm9@16>bD0@CTT03hg900l=B<0>SDR03lb
8@11=240ACPU04Pl9P1:?RH0BclU0P1<@BD01@1C@280E44S05M49P1IARP0FTLY0080FDHX00T0F4DW
05U5;01HA2T0Ed<X05M49P1JAbL0GDXY05m=:@1PCRX00P1RBRH07P1UBbH0JThW071C:`1gEbh0O5`c
081O=01kICH0NF<d07IO<`1cG380KeP_06eE;`1[Dbd0JU8^071@9`1fERd0O5da081Q<`22Hc@0QVPf
08a^?02BM400V7i509MlA@2FNd@0U7U4091d@P2;Kcl0Qf/l08AX>@80NVDh0300NV<g07]S=`1mHSL0
Of8h08=S>P24I3/0OF0h07iQ>@1oHSP0PF@h08AX>@28K3`0S70n08ib@02<Lc/0SWDo095h@P2CNDH0
U7Y909AiBP2CN4/0TWM:09AmD`2CO580TW]?09=mCP2EOdh0VXAC09j8EP2QReT0VhUK09b:G02OSEl0
XHmQ0::@HP2QSf40WheO09f;G@2YTeX0ZYAK0:jEG02aUe`0]YUM0;VKG@2kWEl0_IiN0<>QI036Y6L2
0<VWJP040<JTI`31Wf80_9YM0;ZHF`80^9MD00@0^IQE0;^JE`2lVeP0_YeJ0P2oWU/01`2iV5<0^IQE
0;VHE@2hUe@0]iEE0;JDE@2eTeH00P2dTEL30;BAD@080;FBDP2gU5@0^YMG0;fJFP2oW5`0^9]I0;ZM
F`2lWE`20<2NGP0Q0<2MG@31Ve`0`9YK0;NDE02fTe<0]95A0;>@D02`SDd0[X];0:f:BP2/RDT0/XiB
0;NCE`2nVUh0aZ9V0<fYK@3B[W80e;1d0=FaM@3D/7H0d:a`0<^WJ`35XF<0`IiN0<2MF`30WET0`IiJ
0<>UG`34YF80aJIS0<JWIP38ZFT0bJU/0080bZY_00H0c:ac0<^[LP3;Zg80bZYa0<VYL038Z6l20<NW
KP0e0<^[KP3:ZVd0b:Q[0<JVJ@33XfH0`J5T0;nOHP2nWV40^YiM0;JJF@2SQdP0UgXn09aoA@2KOTH0
UWU109eoB@2FNd@0Uga509QmAP2IOTL0Vh1909b1BP2MPT/0WX=<0:F9E`2VRUP0Yh]I0:R<FP2ZSU`0
ZhmM0:b@GP2]TEl0[8iJ0:f?F`2_TEl0/I9S0;BEI`2gV6`0^IY^0;^KLP31Y7X0`j=j0<>TN035Y7T0
bJMj0=2[OP3E[h00ek620=ZeR03L]hX0g;Z=0=jmTP3O_iH00P3M`9P08`3K_iP0f/2O0=[0W`3I_ih0
ekfL0=JlV`3E^iX0e;ZI0=>iV03A^IL0cKFA0<ZbSP38/8X0b;680<B]P`2nYg/0^:5e0:nCH@2XS5`0
ZXiO0;NJL032Y7h0aJN50<VZR`3?/9<0ckJH0=2iVP3D_:00el:W0=_7[P3Nc;@0hM6j0>?C_03Uf<L0
im[90080jMc;00<0jmk=0>gPc`3]h<l00P3/glh01P3_hm<0l>CD0?3Te03aiMD0l^KF0??We`80m>SH
203fim830?KUd@80mNC@0`3dhll0203fi=00m^C>0?GSc@3ehl/0m>?90?CSa`3dhlD0ln;40P3hhL80
0`3gh<40m]o00?GN_`020?CM_P070??L_@3_g;/0kmbl0>oL_03_g;h0km_00?3L``020?3La080kM_3
1P3^g<@30>oMb@80k]c80`3]flL20>kMb`80kmk<0P3`gld20?7PcPP0l=o=203ah<h80>oOb0P0k]k7
203`g/P20?CNaP040??Ma@3bg<@0lM_30?3J`P80kmW100h0km_20?3K`03_f[l0kmNk0>kE]`3^dkD0
km:b0>kA/@3Ycj`0j<j[0>O=ZP3Vc:T0iL^X0>C:Y`80hlVV00/0ilNP0>K6W`3UaIh0hl>L0>30V@3O
_iP0gKfF0=blU@3G]8`0e[>;0=FbR0020=BbQ@040=:`PP3A[gl0d:ml0=2_O080cZUm00@0cJQl0<bW
N`3:YGT0bJAh0P38XgL02@36Y7H0aJ=e0<BRM033XG<0`Ima0<2NL02oWFl0_Ya^0;jIK@020;fHJ`03
0;bHJ02kUfD0^YIR0080^YMQ202gTVD20;ZEJ080^iIY102lUfX20<6LL080`9]_0`2oVVh00`2nVFd0
^iIY0;^FJ@060;^FJ@80^YM_00L0^iQ^0;fJL02nW6l0_ie_0<2NKP31Wfl0_IY`0080_Y]a00<0_iab
0<2ML`31WW@00P32WgD00`32XW`0`j=m0<>SO@020<BTOP<0aJEo0P39Z8D30<NVP`040<VXQ@3;ZXL0
c:^80<^ZQ`<0c:^80P3=[8T20<j]RP030<b/Q@3=[HH0cJf60080cZj70P3?[hP01`3@/8T0c[2<0<j`
S03?/Hd0dK>?0=:dT03D]Y800P3E]i<01P3G]Y<0f;ND0=RgU03I^9D0f[VF0=^jU`80g;^H103K_I/4
0=bnW0@0gKnM0P3L_Y`20=^mV`80fkfI0P3L_YX30=foV`030=k0W03O`Il0gl6O00L0gl6O0P3N`9`6
0=o1W@D0h<:L0`3Q`id30>73X@<0h/BR0P3SaJ<80>;4XPP0h<:P203Q`j480=o1W`P0g/2J203N`9h8
0=foW@80fkfK0P3L_Y`30=foW@030=k0WP3L_Y`0g;jL00h0g;jL0P3Q_iX20>2nV@<0gkfH00<0g[bG
0=^mV`3K_I/01P3K_I/80=bnVP80gKnM0`3L_Y`30=^mV`P0gKbI103K^i@30=ZjT`80fKVB203J]hl8
0=VhU@P0fKVB203I^9D20=ZjT`030=ViTP3H^940ekN@0080e[J?0`3E]Hh20=JfS`@0ekN@00P0ekJE
0=VhU@3J^IH0g;bF0=blU@3L_9<0fkb@0=ZkS`<0fKVB0P3H^9430=NgT0P0fKVB0P3H]Hd0103G]8`0
eK::0=BaR@3B[hL20=6^QP80d;2700<0dK680=:bR@3C/hX00`3C/hX01P3D/X@0e;:50=BbQ@3D/HL0
e;690=BaR`80e;2<0P3E/X`00`3D/H/0dk2:0=:_R@020=6^R0030=2]Q`3B/XT0d[:900@0d[:90P3A
/HP80=BaR@<0dJj60P3@[HD30<n/Q0080<n/QP3>ZhD0cJZ20<bYO`3:Z7/0bJMi0<RVMP37YGD80<VV
O080bZQj0P39YgT20<RVN0<0ajEg00P0ajAl0<RUN`39YW`0bJMj0<VWN@37YGD0aJAa0<BSL0P0aJ5a
00H0`iia0<>OK`32WVh0`Ie[0<2LJ02oW6H20;nLI080_9QT00@0^iMS0;ZFHP2iUF40^IEQ0P2hU600
202kUf<0^YIR0;VEH@2hU600^IEQ0;ZFHP2lV6@0_YYV102oVf/20<2LK080`Ie]1031WFT40<2LJ0H0
_9QT0P2mVFD20<2LJ080_i]W00@0_YYV0;fII@2mVFD0_IUU0`2mVFL[ooooo`00:_ooool40:MlB@@0
YW]8202WOTX80:MlA`80ZX5=0`2YP4`30:QoB`80Z7m90`2WOTP0102XOdT0ZH1:0:Z1B`2/Pdl30:^2
CP<0ZX5=00D0ZH1<0:f4D02/Pdl0Zh9>0:Z1C@020:^2CP030:b3C`2]Q500[XEA00L0[XEA0P2ZP4h2
0:UoC@<0Z7i<00@0Yge;0:ElB02UO4P0Y7]70`2SNTH0102RNDD0XGQ40:5hA02IM40309Qc?`0<09Mb
?P2FLCd0UW4m09Ia?@2FLC`0UG0l09=^>P2AJcX0SfTj08aV>@2;I3T0RV<h0P2:ISH02P29I3L0Qf8f
08IQ=`25GcP0Q5hi08=M>022GC<0PE`b07mJ<01nFBl407eH;P0807UJ:`1hFB/0MePZ07IG:`1eEB`0
M5@]07=C;@1bDR`207=C;0<0M5@]0`1eEBh0201cCb/0M50/07EB;01gE2`0NUL]07aJ;@1nG2l0Oed_
0P21G2l01022GC00Q5lb08EP<`27HSD208QS=P0608]U>02<IST0S6Hi08eW>P2>J3/0SfTl0P2@JSd8
09E[>@<0TF`h0`2@JcL208mZ=P<0Tfdn0`2BK3d2095[?080Tfhj00@0TVdi095/>02AK3P0T6/g0P2?
JSH8095/>00308eW>02>J3T0SfTj0080T6Xk00<0SfTj08iX>@2=IcP0202EJcT809A_>`80UF/i00<0
UV`j09M]>`2HKS`00P2IKcd0102JL3h0UF`h09E/>02EK3P409I]>@80Ufhj00P0VVhm09Q^?02HKS`0
UVhk09=^>P2AKCT0Sfhi08i]>0<0U6lk0P2CKSX3099]>@0509A^?`2CKCh0Tfdn099/?@2AJc`00`2@
JS/2095/>003099]>@2CKSX0U6lk00<0UG0l202ELCd00`2CKc/0U70l09Ea?@0209Ib?P0309Ea?@2D
L3`0Tflk00P0TVhj2`2CKc/309A`?080UG4m0P2CLSd309Ac?P<0UG@o00H0TGE5091dA02@M4@0Sg=3
08ib@P2=LD4208a`@00N08QW?026ICX0PV<g07aO<`1hGC00Le/]079J;01`FR/0KUL]06]F:`1XDR/0
HDdX05]89`1D@bD0Cd0S04`l8P0o=200?3@O03/c800h<Al0=2hN030]7P0]:a`0;2XM02hW7`0/:1l0
:bLN02TV7@0W9ad09BLL0P0S9Q/2020S70<07b8K0`0N8AX2020S700>028U700S9Q/09BTK02L[700X
;1/0:BdL02P[800V:Ah08RDL01hQ6P0K7AP06adJ01`N6`0M7ah901TO6`0H01`Q6P0L8QP07b8I028T
6@0U9aX0:R/M02l]800b<240?3LS044k8@17@ah0CDPN05197`1>A240Bc`U04Ph:012?Ad0>S@L02hX
6P0W8Qh09B4P02DT800T91X08R@F200V9Q`202<T70808R<K0`0Q8QX00`0P8AT07b0J01lP6P0901lP
6P<0824K0P0Q8Q`08@0J6ad07AlN020P7P0R8A`09B8I02/W6`0d<B80?CLW05]5701[EB`0Mf0f07QP
=01iGS40PFDf08UZ?029JS/0TgA609EgA@2GNT00WX930:Z=D@2YReL0Sfm6079A;P0n?S@0<30V02LW
7@0Y:Al0:b/Q02TY7`0[:b40<C4W02d_8@0202h`8`0502d_900[;2@0:BXT02HW8P0T9B00200V9b42
02@U7`809BHP0`0V9b400`0W:2809RLQ02HW8@0602HW8@P0:b/Q01L0<bdQ038/800b;200<bdQ03@^
8P0f<2@0>38V03Xd:00k<R40?3<R048g9@1:?BX0DT<^05A4;@1A@BX0CS`T054i8@1B>R80ECdU05Y2
:P1MABd0Fd<[05@l900204lg7`0604Tg8@1:>280BcTS04`j901=>bD0CcdW0P1@?RP0101A?bT0D3hX
050n:01??BL204hl9P80CC/U201A?bL2058n9P0C050n9P1>?RD0CClU04/o9@1:?R@0BClT04Pn9@18
?2@0Ac/S04Tj8`1:>R<0CC/U054l9`1B?BP0F40V05Y2:01MABT0H4TZ069;:`02069;:@0I069<9`1N
CR`0GDd[05];:P1IB2X0EdHZ05I5:`1EA2X0E48Z05M49P1G@bP0ED@X05=3:@1A@bT0C40X04Tm9`16
>bD0AcLZ04Hf:@11<bP0?S4X03X`9`0i<2T0>S4Z03Tb;00303Da9@80=30T0`0c;b<3034a9`D0<30V
0P0b;R<01P0e;b<0>30S03Xa8P0m<B40?c8R040c8P80>c@T00H0>C<U03Hb9P0d<RH0<C4W030`9P0_
<2P303</9080=2dU0`0e;RH0100g<BD0=S0T03H`900f<2@203D_8`80=2hR01h0=BhT03D/8`0e;B80
=R`P03T]7`0m<200@C4R04<c8`10<b<0@SDU04Hi:018>bP0BCdW04Pl9017>b40ACTO04Pk:P17>RL0
ACPU04@h8P15>B40B3`R04]0901=@RH0B40Y04Hn9`13>bH0@3PU03lg900n=B@203he9P80@cLO00<0
A3PP04Hj8P18?2@00P19?BD02P18?2@0Ac/S04@g9013=R<0@SDR044d8@12=B80ACPU04Tl:@1;?R/8
050o9@0>0553:@1?@2T0BclW04Ll9P12>RD0?SLT03/d8P0i=240?c8Q044d8@14=b@0Ac/U04Xn9P1;
?bD204]0900405=08P1D@B<0ET<U05Q59`80FDHX00P0F4DW05M49P1FA2`0Dd8X05509P1C@RH0F4LY
05];:P80G4`Z0P1PBBL07P1SBbL0IT`W06a@:@1bEBd0N5Pa07YJ<@1hHS<0Mf4b07IO<`1cG380LEXa
06iF<01[Dbd0JU8^06];901aDBX0NET`07iO<`21HS@0QVLh08e_?@2CMD<0VGm609UnA`2GO4D0U7U4
091d@P2;Kcl0QVXk08=W>080NF@i00H0NV<i07aS>P1oHc/0PF@l08AT?@25ICh2089U?@0d089U>`24
Ic/0QVXk08Y^?P2=LCl0Sg=1091f?@2BMd00UW]409UnB@2JOT`0VWi>09QlC@2GNd`0TgeD09AnE@2F
PEH0VHAG09f8F@2QSE/0YI5O0:RDH@2PSf<0Xi9V0:NFJP2[VVh0[9]_0:ZIK@2WUVX0YIAX0;6HH02b
VF40]9YQ0;NJH02jW600_9aO0;fMH030WUl0`imQ0<JRI039YFL0aj=U0<>OH@2nVU`0_9QJ0;^GF@2j
VE@0^iYE0;bKEP2mW5L0_YeH0<2OFP80`J1K00L0]YQB0;JGE02fUe@0]IIC0;BEE02dUED0/i=F0080
/Y9G0P2eTU80;02dTE40]I9B0;NDE02jUeL0_9UI0;jKF`2gVUP0^9]I0;ZKFP2mVe/0_YaL0;jKF`2n
V5T0_IMH0;NDE02fTe<0]I9B0;:?C`2`SDd0[X];0:b9B@2[R4P0/Xi@0;JBE02mVE/0a:1R0<ZVJ03?
Zfd0dJe_0=:^L03>ZVh0bjM[0<JRI032Wel0_iaJ0;nLF030WUL0`ImH0<:TGP32Xf00`jAQ0<FVI@36
YfL0b:Q[0P39ZFh20<ZZL@040<VYL038Z6l0ajM^0<NWKP80aZI]0100bZY]0<VYK037YfX0a:AW0<:R
I@2oWf80_IeP0;bLG`2gW5T0]9UF0:24@`2DN3T0VWe109Ul@P2EN3h0W7m70P2FNd@0302GO4D0VGi7
09YoB02KP4T0W85:09f2B`2TR5H0YHUG0:J:F02XS5X0ZXiL0:^?G@80[I5O0P2[T5/01`2[Sed0[I5Q
0:nCI02aU6P0]9M[0;FHKP2lWgD00P2nWg<04`30Wg80a:9d0<^WM`3AZgX0e:im0=RbP`3J]8D0g;N:
0=fkSP3N_I80gKfD0=fmUP3K_YH0g;nM0=^nW03J_I/0fKbJ0=RkV@3F^IL00P3E^9H06P3A^ID0cKF?
0<VaR`37/8L0ak260<>/P02lYWL0]Z1a0:b@GP2VRUX0ZHeN0;NJL033YGl0aZR60<Z[S03@/I@0d;NI
0=6jV`3E_J40f<>X0=c8[`3OcKD0h]:k0>CD_@3VfLP0j=_:0P3ZgL`01P3/glh0kN3?0>gPc`3/glh0
jmk=0?3SdP80lNCC00<0l^GD0??Ve@3dimH00P3ej=L80?KVc`80m^C>0P3ehld30?CRc0070??Qb`3f
hL`0m^7<0?GQb@3ehLP0mN760?CQ``020?CQ`@80m]o000@0mMjo0?CM_P3dgKh0lmbm0P3bfk`20>_K
^P040>_J_03/fkl0k=_10>gK``80kM_50P3/f/@20>gKa@@0k]c60`3_g</20>kKbP<0kM[90P3^gL/2
0>oNc080l=o=0P3ah<h80?3Oc`P0l=o=203_gLD80>gK``P0km_30P3dg<001@3cfkl0l]Zn0?3H_03_
ek/0k]Jj0080kMFi01X0kMJg0>cC]@3[d;80k<n_0>_=Z`3/bjP0jlZW0>?6WP3RaId0hLBL0>33V`3O
`YX0g/6I0=g0V03L_iL0h;fC0=nlTP3M^Y00fkR>0=VfS03F/hT0eK:80=BaQ`3A[800d:]o0<nZO@80
cZYj00@0c:Qf0<^WL`3:YW80bZMa0P38XWD01037XG@0aZ1c0<FOLP34WW420<>ML0090<6OK`30WVh0
_ie]0;jLK02lVVX0^iUY0;ZHJ02iUfL0^9=V0080^9AT00<0]i=Q0;NCG`2fTed00P2fTe/30;:=H0<0
/hiQ0P2dSf800`2hTfH0^IAW0;ZEJ0030;bGJP80^iIY0`2oVVd20;jIK0<0_IQ[0P2hU6@20;VEI@@0
^YIV00P0^9E]0;VFK02iUV`0^YQ[0;^IJ`2lVVX0_9]X0;fLJ@80^YM]00<0^iQ^0;bIK`2mVW000P2n
Vg401`2oW780_Yig0;jNM`2oWgP0`:1i0<6QNP32XW/00P33Xg`00`36YH80aJB10<BSP0020<BSP003
0<JUPP37YX<0bJR50080b:N40P39Z8D30<ZYQP060<^ZQ`39ZH00bJV00<ZZP@3;Zh80c:b30P3=[H@0
1`3>[XD0c:j:0<f_R`3>/8`0ck6=0=2bSP3B]9000P3C]I420=JeTP040=NfT`3H]i@0f;ND0=VhU@80
f[VF203L^iX30=VkU`D0f[bH00@0f;ZF0=VkU`3I^iL0fK^G0P3J_9P20=^mV@T0g;jL0P3K_IT30=bn
VP<0gKnK0`3O_iP20>30V@<0hL6J0`3Q`9d20>;1WP<0hl:O203Q`il80>73X@P0gl6O203O_Y/80=jn
Ua00g[fL0`3M_9T20=jmVP<0gkjK403L_Y`0103P_IL0gkbF0=nlUP3O_9H20=jkU@80gKZD203I^iT8
0=ZlV0040=bnVP3K_IT0fkfI0=^mV@80f[bH0P3I^iL80=^jU`040=^kU03J^Y<0f[ZC0=ZjT`<0fKVB
0P3H^9480=ReS@P0f;ND0`3I^I830=RhT@80ekN@203H]i@20=ViT0030=RhS`3G]hh0e[J=0080eKF<
00@0e;B;0=BdS@3D]8d0e;B=0P3E]Hh30=JfS`080=JeU03H]i@0fKRE0=^kU@3K^i@0fk^B0=ZkS`3I
^Xh20=ViTP80f;RA0`3G]i00103F]Xl0fKVB0=ViTP3I^I830=RhT@80ekN@00H0ekB<0=JcR`3E/XX0
e;690=:_Q`3A[XH20=2]Q@040<j^Q@3?[hH0dK680=:bR@<0dk>:00L0d[:90=>aP`3C/H@0dk640=>`
QP3C/8P0dk2:0080djn;0P3D/H/30=>`RP<0dZn9103B/XT20=6aR080d;27203C/8P20=6^QP80d:f5
0`3?[8@02@3>Zh<0cjb60<n/QP3=ZX80c:Uo0<ZXN`38YWP0ajEe0<JTM0080<RUN`<0bJMi0P38YWP4
0<NUM`080<JSN`37Y7X0b:Ek0<VWNP38YWP0ajEe0<FTL@34Xg080<FQL@060<BOLP33Wfl0`Ie]0;nK
J@2nVVH0_Y]U0P2oW6@20;fII@040;bHI02kUf<0^iMS0;ZFHP80^IEQ00P0^iMS0;ZFHP2iUF40^9AP
0;VEH@2jUV80_9QT0;jJIP80`9a/0`2oVf/00`30W6`0`Yi^0<>OK`030<6MJ@80`9aX0`2oVfL30;bH
I0<0_IUU0P2nVVH01P31WFT0`9aX0<2LJ02oVfL0_YYV0;fII@80_9QT0`2mV6@[ooooo`00:_ooool4
0:IkB0@0Yga9202WOTX80:MlA`80ZH1<0P2XOd/01P2WOTX0YWe90:ImB@2VODT0Z7m90:MnB0<0YWe7
00<0Z7m90:Z1B`2/Pdd00P2/Pdl20:^2CP80ZX5=0P2YP4`00`2^QE40[HA@0:^2CP020:Z1C@030:^2
CP2/Pdl0[HA@00P0[XEA0`2YOdd30:QnC080Yge;0P2UO4P01@2TNdL0XgY60:=jAP2SNTH0XWU50080
XGQ40`2HLcl409Mb?P0709Ia?@2DKcX0Tfhj099]>@2AJcX0SfTj08iX>`0208aU>P0<08]W=`2:ISH0
RF@g08QS=`26HCL0QElh08AN>@23GCP0PUdc085L<P1oFS00O5L]0P1kER`0201lEbd0OEP^07MH:@1g
F2X0MULY07IG:`1eEB`0MED^0P1dE2h207=C;0<0M5@]0`1eEBh03P1cCb/0M50/07IC;@1hEBd0NeP^
07eK;P1oGC00P5h`089M<023GS40Q5lb08EP<`26HC@0R6<f0P29I3L208]T>@0408aU>P2=IS/0SVLl
08mX?@80T6Tn0P2FK3X609E[>@<0Tfhj00<0TVdi095/>02AK3P00P2@JcL309=]?P<0TV`m0P2AJc`8
095/>0H0TVdi0P2AK3P00`2?JCX0TF/l099/?@0209=]?P03099/?@2AJc`0SfTj00P0TfTg202DKc/2
09=Y=`0609AZ>02EJcT0UV`j09M]>`2HKS`0VFlm0`2GKSX409I]>@80UF`h00H0V6`k09M]>`2GKC/0
UVhk09=^>P2BKSX2091_>P@0U6lk0P2CKSX2099]>@<0TV`m1@2AJc`409A_>`@0UG0l202ELCd00`2C
Kc/0U70l09Ib?P0209Mc?`0309Ib?P2DL3`0Tflk00P0TFdi2`2CKc/309A`?080UG4m0`2CLSd00`2D
Lch0UG@o09Ed?`0209Ie@080T7A400@0Sg=308ib@P2=LD40SG510P2<L4007P29J3d0QVDj085R=P1k
GS80Me`_07=K;@1bFR`0LE//06iG;@1[ER/0Ie4Z061<9`1JAbH0Dd8T04ho8P1<?280?c@P03`d7`0j
<Ql0=c0N03@^7P0`;Ah0;B/L02`Z7@0^9al0;2PO02/W7P0Y9Qd09bLM02DW70808bHK0P0P8a`301lR
6`<07R4J01007b8K020S700R9A`092LL02HZ700X;1d0:BdL02X^7@0Z;B809bXO028U700M81T06adH
01/M6P0L7Q/07AlN2@0I7a/201/S600F01`R600O8QL08bDJ02LW7@0Z:Qh0;R`P03Hc8P0i=b00@ChM
04M37@19A1h0BT4R04Pk:016>2/0@C`L03Tc6`0_:A/09b8N02HR8@0U920092@J024S5@P09RHL0`0R
8a/3024R6P80824I200O81X201hO6@807b0J01h0824K024R700Q8Q`08B8L01PL7@0M7R007b4N020Q
700R8QX0:2HJ038_800h=BH0Ed4J06QB:`1fGcH0Mehe07QM<P20HcL0RFXn08Y[?@2CM4H0U7I409Ii
?`2MPD80ZHa@0:V;E`2@L4L0Le8_0451=`0c<bT202PX7P0<02TY7`0W9ad0:BTO02h^900Z;1h0:R`O
02/]800[;B80:R/S02PY8`0V9b809BHQ200V9b4302@U7`809BHP2`0V9b4602/[8@80:RXP01L0<bdQ
038/800b;200<R`P03@^8P0f<2@0>C<W03/e:@0o=b@0?SHS044f8P18?2H0D44Z05=3;01@@2L0CC/S
05Y2:01K@bT0GTH/06A<<P1XD3H0IDdc05a4:P0205@l8P80BcTS0P1<>R@0101=>bD0CS`V04hl9P1?
?BL2050n:0@0CcdW0P1>?2H8054o9`80DShV01<0D3hV04hn9@1=?bD0BclU04Xn9019?b@0AS`S04Lk
8`16>R80B3TR04/k901>?2H0DSdX05@o:P1H@2H0FT8X05a4:01OB2T0HDXZ0080HT/Y01T0HT`W05a>
:`1LCR/0FT/Z05Q9:P1FAbX0E4@Z05=3:@1B@RT0E44S05E19P1D@bL0Dd<Y0553:@1=@BT0BclY04Tn
:017=bX0AC@Z044c:00m<2L0>S0W03P_:00i<2/0>34[00<0=C4U0P0d<2@303<_8`80<30V1P0a<BL2
038^8`0?03D_8`0h<2<0>S4R03da8@0o<R80@3<R03df9P0l=BD0>S@V03Hb9P0c<BD0<30V02h^900]
;RH0=2/T00<0=B`U0P0f;BH203L^9`80=c4U0`0f<2@303D_8`0N03@]8`0e;2<0=2`Q03H/800i;Al0
?C0P044a8P13<b<0?BlR040b9@15>2P0BC`Y04/o:@1;?bD0BChR04Pm8@19?2/0AcXW04Dh9@13=b40
A3PP04Lk8@1;@2@0CD8V04Q0:@16?RL0@c/V040h9@0n=R<0?C@S0P0m=2D2048f7P0304@h8016>R80
B3`T0080BCdU00<0B3`T04Lk8`15>2D00`15>2D01016>BH0AcXW04Lj9`18>bP3058n8`D0DCdR00h0
DT@Z0552:`1<@2P0B3dW048j9@0n=b@0>c@R03Td8@0o<R40@C@Q04@g9017>bD0BCdU04/o9@80Bd0T
00@0DSlQ05A18`1F@bD0F4DW0P1IARP01`1HABL0Ed@V05E5;01A@BP0CShT0511901FAbP00P1KC2/0
2@1IBbP0GTXY06199`1QBRP0I4`X06M=:01]DBX0LUD]07AG;`0207AN;`0?07EN<P1dGC<0LU/b06mG
<@1/E2h0JU8^06a<9P1bDR/0N5Pa07eM=01oH3@0Pf@f08Y[?02@LD80T7Hm0080T7Dn00/0SW<n08a`
?P28K3`0QFTj08=W>01gHCP0N68i07YS>P1mI3`0PFDn08AV@00208MW@@80R6]302h0QfY008Q[?`29
KCh0Rflo08ib@02?Ld40U7Lo09Mj@P2KODL0WX1<0:22D02OPDl0WGi?09amCP2EPUX0UhAL09Z7G@2O
S640XY1R0:FCH`2WUFD0Z9IT0:FDJ@2YV6d0[iic0;BSN02fYGX0]:=h0;6PM@2^WG80^9eV0;VNI`2k
WVH0^iiT0;bNHP2mWF00`9iQ0<2NG`32W5d0aImP0<NQHP34WUl0_iUJ0;^EEP2lUUL0_iUJ0P2jVE80
102kVU<0_9]D0;bKE02mW5D20;jMEP070;>FD02cUU80/iIB0;>FDP2cUU@0/iEE0;:DEP020;:DF080
]Y=C0P2eTU801`2gU5@0^IIF0;^HF02mVUX0]IQF0;JIE`2hVEP00P2kVET08`2kV5P0^iEF0;ZDE@2h
UED0]iAD0;FBDP2cT500/8e=0:j;B`2/RDT0ZhQ80;2=C@2cT500^IIF0;nLG035XV80bJIV0<bYJ@3>
Zf/0bjMY0<RTIP34XF40`9eK0;nLF02oWEH0`ImH0<:PF031Xed0`J9O0<:SH034YF@0aJIV0<JVJ@37
Yf`0b:Q]0080bJU`01H0b:Q_0<NWKP36YVd0aZI]0<FUK034Y6/0bZY]0<RXJ`36YVT0`j=V0<2PH`2n
WV40^i]N0;ZJG@2dVE@0/IIC09j3@02BMSD0VGdn09Qk?`2CMS`0Vgi40P2FNd@03P2GO4D0VGi709Yo
B02KP4T0W85:09f2B`2SQeD0Y8QF0:F9E`2WReT0ZHeK0:^?G@2]TEl0[Y9P0P2[TU`01`2ZT5d0ZY1O
0:bAHP2^TfH0/IIY0;>HK@2iW7000P2jVfd02`2lW6d0`9i^0<RTLP3>ZGD0dZei0=R`O`3H/X<0fkF6
0=fhR`3M^hh0gKbA0080g;bC0280g<2K0=^oVP3J_YT0fKfH0=NkUP3F^YD0eKVD0=BhT`3@^980c;B>
0<RaR036[hD0aJj20<6[O02jY7D0]9i]0:^?G@2URET0ZHeN0;RKL@34YX00ajV70<^/S@3@/I@0dKRJ
0=:kW03F_Z80fLBY0=g9/03Pc[H0hm>l0>GE_P3Wf/T0jMc;0P3[g/d01P3/glh0kN3?0>gPc`3/glh0
jmk=0?;Sd080lnCA00<0m>GB0?GVd`3fim@00P3gj=D80?GUcP80mn;=0P3fhL`30?GPb`090?CObP3f
h<T0mMo80?GOa`3eh<D0m=o20?CO`03cg[l0lmnn0080mMjo00<0m=fn0??L_@3bfk`00P3af[/01P3`
fKX0j=Vj0>WJ^`3Yf[d0j][00>[J`@80jm_400@0k=_70>_Ia@3/f/H0k=[60P3]flL20>kLb0040>oM
b@3_g</0kmc;0>oLb`80k]_:0`3]f/T20>kMb`80kmk<0P3`gld20?7PcPP0lMoA203_g/`80?3L``P0
k][1203]ekl0403_f;T0k]Nh0>gF]`3[e;D0j]>d0>SA/P3Wd;40i/n`0>K=[P3Vbjd0i<ZY0>C7Y@3S
aJ<0hl:O0>?1W03R`9/20=fnTP0A0=^lT03J^hl0f;V=0=NhS03F]h/0eKJ:0=JbPP3E/H40djmo0=6]
O@3>ZWX0c:Qh0<ZVMP39YGD0b:9e0<RRL`37XG800P35Wfh01@34Wf/0`YeX0<6LI@31W6D0`YU[0080
`IQZ00<0`9MY0;nFJ02nUFL00P2nUFL0202jVFH0^IQU0;RGI02gUV<0]IAQ0;BCH02cTUl0/Y5N0P2a
SEd00`2aSE/0/HeI0;2=E`020;2=E@040;2=D`2_RUd0[hYM0:n:G@80/8]N00H0/HaO0;:=H02bSF00
]8mR0;F@H`2gTVD30;VDI`030;NBI@2fTF@0^YIV0080^YIV0P2iUFD30;RDI080]i=Q0P2hU6801@2i
UF<0^YIT0;ZFI02jUV@0^9E[0080^9IY00<0^IMY0;VGI`2iV6D00P2iV6<20;RFJ@040;VGJP2jV6/0
^iU/0;^IK080_9Y]0P2jVW<03@2lW7D0_Ief0;nON031XGX0`Z9k0<>SO034Xh00`j9o0<:QOP31X7d0
`Z5n0<>RO`35Y8401036YH820<NVP`<0b:N400H0aZMk0<NXO038ZGd0bJYn0<Z[O`3;[8020<b]P@80
bjf900L0c:j:0<j`S03?/Hd0d;:>0=6cS`3B]900e;>@0080eKBA00<0e[FB0=NfT`3H]i@00P3I^9D3
0=biV@D0fkRH00D0eKNA0=JhTP3F^980ekVC0=RjU0020=VkU@030=ZlUP3F^9@0ekVE0080ekVE0P3H
^YH20=VkU`T0f[bJ00<0f;ZF0=VkU`3I^iL00P3J_9P20=^mV@050=bnVP3N_9H0g[bF0=jlUP3O_IL0
0P3P_YP20>6oV@040>2nV@3Q_iX0hKnJ0>6oVP80h/2K0P3S`I`80>32W0P0hL>Q203N`9h80=jlU`P0
g[bF403N^i/0103N_9L0gkfH0=nmV03O_IP20>2nV@80hKnJ403L_Y`20=jkU@80gKZD0`3L^I<00`3K
^980ekVG0=NiU`060=NiU`P0f;ZF00@0fkfG0=ZlUP3J_9H0f[bF0P3I^iD20=RjU0P0f[VF0P3J^Y<2
0=ViTP@0f;RA00<0ekN@0=NdS03G]8`01P3G]8`80=NfT`80fKVB0P3H^9420=NgT080e[J?203G]Y<0
1P3I^Xh0f;V=0=RiS@3G^8`0e[N;0=FfRP80e;F90`3C/h`20=BdS@<0eKF>00P0e[FD0=NfT`3I^9D0
f[ZD0=^kU03J^Y40fKZ>0=RiS@<0f;RA0`3G]i020=JfS`80fKVB0P3H^9420=NgT080e[J?00H0e[>;
0=FbRP3D/HT0dk280=6^QP3@[HD20<n/Q0040<b/P`3>[XD0d;270=:bR@<0dk>:00L0d[:90=>aP`3C
/H@0dk640=>`QP3C/8P0dk2:0080djn;0`3B[hT30=>`RP80e;6;00<0dk>:0=:bR@3B/XT00P3A/HP2
0=2`Q`030<n_QP3B[hL0dZn700H0dZn70`3@[HD30<n/Q080cZ^300P0d:f70<n/QP3=ZX80bjQn0<VW
NP37YGL0aZAd0<FSL`P0b:Ek0P39YgT20<RVN0D0ajEg00P0aZ=k0<NTNP38YG/0bJMj0<RVN037YGD0
aJAa0<>RK`P0aJ5a00P0a9mb0<>OK`30W6`0_YYX0;fII@2nVfD0_Y]S0;nLI080_i]W00@0_YYV0;fI
I@2lV6@0^iMS0P2jUV80402kUf<0^YIR0;VEH@2hU600^IEQ0;ZFHP2lV6@0_YYV0<6MK@30W6`0_i][
0;jJJP2oVf/0`9a/0<:NKP34X7030<6MJ@030<2LJ02oVfL0_i]W0080_YYV00<0_9QT0;fII@2mVFD0
0P2nVVH20;nKI`090<2LJ031WFT0`IeY0<2LJ02oVfL0_YYV0;fII@2lV6@0^iMS00<0_iMT:oooool0
02[ooooo00D0Y7U60:EjA`2UNTL0YW]80:MlB@020:QmBP030:UnB`2WOTX0Ygi:00H0Ygi:202WO4L2
0:QoB`80Ygi:00`0YWe90:ElB02UO4P0Y7]70:QoB@2WOTP0YWe70:ElAP2VODL0Z7m90:^2C02/Pdd3
0:b3C`030:^2CP2ZPDd0ZH1<0080ZH1<00P0[hIB0:f4D02[PTh0ZX5=0:V0C02ZPDd0[8=?0:f4D0P0
[XEA0`2YOdd20:QnC0<0Yge;0P2UO4P01@2TNdL0XgY60:=jAP2SNTH0XWU50080XGQ40`2HLcl509Mb
?P0>099]>02BKCT0TF`h091Z>@2?JCX0SVPk08iW?02=IS/0RfLg08YV=P29I3L0R6<g08IQ=`25GcP2
08AN>@0608=N=021G380OUT_07aG;@1jEB/0NeH/0P1lEbd01P1fEbP0MULY07IG:@1fEb/0MED/07EE
;P80MED_0P1cDb`307AD;@<0MED^00h0M50/07EA;@1gE2h0NEH^07aI;`1nG2l0P5ha085O<@23GS40
Q5lb08EP<`26HC@0Qf8e08UT=`80RVDh0P2;I3T00`2<ICX0SFHk08iW?00208mX?@04091Y?P2FK3X0
UV`j09I/>PD0UF/i00@0UG0l09A_>`2DKc/0Tfhj0P2BKCT2095/>0<0Tfdn0`2BK3d2095[?0<0T6/g
0P2AK3P3099]>@<0Tfhj102BKCT0102AK3P0Tfdn09A^?`2FL44209Ma@P0309I`@@2DKSl0Tfdn00P0
TVPf202CKc/2099X=P0709=Y=`2DJSP0UF/i09I/>P2GKC/0V6hl09U`?00209Q_>`0309M^>P2FKCT0
UF`h0080UF`h00X0U6/g09IZ>@2FK3X0UV`j09E]>P2DKc/0Tflk095`>`2BLC`0UG0l0`2DKc/209=^
>P80TVdi202AJch409Ia?@80UG0l0P2DKc/809Ea?@0309=_>`2DL3`0UW8n0080Ug<o00<0UW8n09A`
?02CKc/0202AKCT;09=_>`<0U70l0P2ELCd0102BLC`0Tg8m09=b?@2DLch209Ed?`80UWE00P2@M4@0
0`2?Ld<0SW9208ea@@0208a`@00608]_?`29J3d0QVDj085R=P1jGC40MU/^0P1bFR`05`1aFb`0KUL]
06]F:`1WDBX0H4`W05U69@1C@R@0CSlR04dm8`0o=200?3@O03Xb7`0g<1h0=2hN02l/7@0]:a`0;2XM
02hW7`0/:1l0:bLN02TV7@0W9ad09BLL00808bHK0P0P8a`301lR6`<07R4J01007b8K020S700R9A`0
92LL02HZ700X;1d0:RhM02/_7P0[;R<09bXO028U700M81T06adH01XL6@0L7Q/07AlN2@0I7a/201/S
600F01`R600M8aT08B@K02DW700Y:Al0:RXP034_800e<ah0>cXL048o7015@Ah0AChR04Dj:014>2`0
@C`L03Tc6`0_:A/0:2<O02HR8@0U920092@J024S5@<09BDK1@0V9Q`3028S6`808B8J0`0P8AT801lP
6P807QlI0P0O81X07`0P8A/08B8L024R700R8ad061`O01XN7`0O8B00824L028R6P0X9QX0;bdP03Ld
9@1E?aP0IU0Y07EN=@1fGC@0Me`a07mR>029JSh0S6e109=dAP2DMT@0UGPn09f1@P2YS500ZH]G095a
B01dDc00@d<i03@d:P0Y:Al00P0X:1h02`0V9Q`09bLM02`/8P0W:A/0:2XM02T[7P0Z;240:R/S02PY
8`0W:2<09RLR00P09RLQ0`0T9Al302DV80X09RLQ1@0[:b4302XZ800@03<]8@0b;200<B/O038/800c
;B40=S0T03Tc9`0k=BT0@SXW040h9@11=R80ASXT04ho:01B@RT0D40W04dl8P80I4X_00D0Iddb06iD
>@1bF3d0KU@i06=9;P0205To90<0C3XT101=>bD00`1>?2H0CcdW04lm9`0404lm9`80D3hX201A?bL2
058n9P0C050n9P1>?RD0CClU04/o9@1:?R@0BClT04Dk8P16>R80ACTQ04Pi8P1;>b@0CcdW05<n:@1E
@2/0F40V05U19`1LA2P0GdPY065::P02069;:@0F065;9P1LCR/0G4h[05Y;:P1IBR/0ETLZ05A4:P1B
@RP0DD4X05=08P1D@2D0Dd8V05=3:@1A@bT0CT8Z04a0:P1:?bT0ASD[04Dd:P10<RT0?C0X03T^:080
>2lZ00@0>30]03Da9@0e<BD0=C4U0P0d<2@303<_8`80<30V100a<BL2038b:080<RhS00h0=BlS03P`
8`0j<B80?C4Q03lb8P10<b80?SLW03df9P0k=BL0=S8V03<a9@0_;bD0;BdS02//90@0=B`U0P0f;BH2
03L^9`<0=c4U0P0f<2@303D_8`0N03@]8`0e;2<0=2`Q03H/800i;Al0?2lO044a8P12<R80>bdR03h`
8`14=bL0BC`[04a0:P1<@2H0Bd0T04Xo8@1:?B`0B3/X04Dh9@13=b40A3PP04Lk8@1;@2@0CD8V04Q0
:@16?RL0@c/V040h9@0n=R<0?C@S0P0m=2D2048f7P0404<g7`16>R80B3`T04Tm9@80B3`T00@0Ac/S
04@i9@15>RH0AS/W0P17?2P204Hk9`0304Dj9P1A?R00DChP0080DChP101@?Al03P1CAB/0DT</04e1
:@18?BL0@SXU03hg900k=280>C@Q03ha8010<b00A3LT04Lk9@19?BD0BShT0P1;@2@01@1B?b40Dd0R
05I39@1HABL0FDHX0080F4DW00T0Ed@V05A4;@1@@2L0CCdT04lo9@1FAbX0Fd`]05]<:`1HBBP00P1O
BbX0901QBRP0Hd/W06I<9`1[CbP0KU8[075D;01bG2d0Led^07AM<@1dGC<0Le`c071H<P1/E2h0JU8^
06m?:@1dE2h0NUXc07eM=01nGc<0P64c08IW>@2;K3d0QF/b08I[=028KCH0R6dh08Q/>P26JSX0QFTj
08=W>01fH3L0N68i07]T>`1nICd0PVHo08EW@@80RFU301@0SG1808a_A`2;KT@0RVe108]_@02<L400
SW9008mc@@2EN3h0V7]309aoA`2PPT`0XXA@0:63D@2OP540WGi?09V6GP2KR600X8eS0:BAIP80YiEW
00X0YiEU0:JDI02VUf`0Ziaa0;:SN02hZGh0^Z^00;RYOP2eYW/0/Z=h0P2lXFX00`2nXFT0_YmV0;nO
I0020<2NH@090<6MG`31Ve`0a9iO0<FOH031Ve`0^iEF0;RBD`2kUEH0`9YK0080^9M@0`2iV5430;ZI
DP070;:EC`2bUE40/YEA0;:ED@2bUE<0/iEE0;>EE`020;>EF@80]iAD0`2fTe<01P2hUED0^YMG0;bI
F@2cUU@0]9ME0;NHE`80^IMG0240^IIF0;VCE02hTU<0^IIF0;REE@2fTe<0]95A0;6>CP2^Rd/0[8U9
0:^8B02]RTX0/8e=0;FBDP2kV5P0`9eM0<FRHP38YFD0bJIV0<VUI`37Y6@0`j1P0<2MF`2nVeL0_ieF
0<6OE`33XET0`:9L0<6RG`32Xf00`jAS0<FVIP36YVT00P37Yf`01P39ZG00b:Q_0<RXK`37Yfh0aZI]
0<FUK080a:A[01H0bJU/0<RXJ`36YVT0`j=V0<2PH`2mWF00^i]N0;VIG02cV5<0/9E@09f2?`2AMC@0
V7`m09Mj?P2CMSX0VWe309IkA02GO4D0V7e609UnA`2JOdP0W85:0P2MPT/07@2RQU@0XhME0:F9E`2W
ReT0ZHeK0:^?G@2]TEl0[Y9P0:bCG@2[TU`0ZY1M0:Z@G`2[T640[I9U0;2EJ02bUf`0]i]/0;RIJ`2g
V6T0^YY[0;jLK036XW00cJQd0=6/N03G[gh0fK600=ZdQ@3L]hX0g;Z=0080g;^@02<0fk^B0=bnVP3L
_YX0fkfI0=ZlV03H^YH0ekVE0=JhU03E]i<0ckNA0<^dR`37/8L0aJj40<B]P@30ZW/0^J=b0;>MK02Z
SU`0Y8QH0:V=GP2hVg40a:J00<RZR03;[8d0d;6D0=6hVP3B^i`0e[jR0=W4Z@3MbK00h<jf0>?C_03U
eKh0j=_:0>WLb`020>_Nc@<0kN3?00<0k=o>0>_Nc@3bhm000P3ci=400`3diM80mNKC0?KWe0020?OX
e@P0m^C<0`3fh/X20?GQb@<0m>3800P0mMo80?GOa`3dg/H0m=o40??N`@3cg[l0lmnn0?;N_@80m=fn
00L0lmbm0?;K_03af[/0lMZk0?3I^P3_f;T0imRi0080j=Vl00<0jMVo0>[J`@3Zf/<00P3[f/H20>_I
a@80k=[600@0kM_70>kLb03^g<P0kmg90`3_g<d20>kKc0<0kM[;0P3^gL/20>oNc080l=o=0P3ah<h8
0?7Od@P0k]g;203`g<<80>kJ`@P0k=Jn0100j]6b0>W@/@3Xck00ilj_0>G<[@3SbZ/0h/VZ0>78Z@3O
a:H0hLBT0=o2XP3N`9h0g[fJ0=fkUP3L^I<0fkRB0P3I^8/0103G]XT0e[F80=BcQP3C/XD20=6`P`0;
0<jXM`3=YgH0bjEd0<VSLP36X6l0a9i]0<:LJ`31VfX0`I]/0<2JJ`2oVFP00P2nVFD0102mV6<0^iIO
0;ZEGP2jUU`30;^BI0030;ZAH`2iT680^I1R0080^8mQ0P2dTf001`2cTUl0/Y5N0;2?G02_SU/0[XeJ
0:f<F@2/R5P00P2/R5H00`2[Qe<0ZhQB0:^8D0020:^8CP80[HQK00@0[XUL0:n:G@2_RUd0/8]N0P2a
S5l00`2`Reh0/XeP0;B?HP020;JAI0040;F@H`2dSf80/hiQ0;JBHP<0]I5Q0P2dT6020;>?G`80]i=Q
0P2hU6801P2iUF<0^YIT0;ZFI02kUfD0^IMZ0;RFJ@80^9IX00D0]iEU0;NFH`2gUV40]YEP0;JDIP02
0;NEI`030;RFJ02iUfT0^YQZ0080^iU[00/0]iM^0;RHK`2jVW40_9ac0;jNM@30X7L0`Z9i0<>SNP33
XWl0`Z5n0<6PO@020<2OO0030<:QOP34Xh00aJB100<0aJB10`36YH820<NVP`060<FVNP36Yg/0aZMk
0<RYO@39ZWh0bZ]o0P3;[8001P3:[8P0bjf90<b^RP3=[h/0c[2<0=2bSP80dK>?00H0dk:?0=BcT03E
]940eKBA0=JeTP3G]Y<20=RgU0D0fkRH0`3J]iL0203C]Hl0e;J@0=FgT@3F^980ekVC0=RjU03I^iD0
f[bF0P3E]i<20=JhU0<0ekVE00<0f;ZF0=VkV@3I^iT01`3I^iT20=NiU@040=RjUP3I^iL0fK^G0=Zl
V080fkfI0`3M_9<00`3N_I@0gkjE0>2oUP020>2oUP<0h;jI0P3Q_iX30>;0V`P0gl6K203Ra:880=k0
WPP0gK^F203M_9<@0=fjVP<0gkfH0P3P_YT30>6oVQ00g;jL0P3O^I820=jhT@<0gKN@00<0g;J?0=Jh
UP3F^9H01P3F^9H80=RjUP<0f[bF0P3I^iD30=RjU0P0f[VF00@0f[ZC0=ViTP3I^I80fKVB0`3H^942
0=NgT0P0ekB<203G]Y<20=ViTP040=RhT@3G]i00ekN@0=JfS`80eKF>203G]Y<20=RiS@030=NhS03F
]h/0eKJ:0080e;F900<0dkB80=:bR`3B/X/00P3C/h`30=BdS@090=FeSP3E]9<0ekJC0=RgU03J^Y@0
f[ZC0=ZjT@3I^Xh0f;V=00<0f;RA0P3G]i030=JfS`80fKVB00@0f;RA0=NgT03G]i00e[J?0P3E]Hh2
0=FbRP0<0=BaR@3B[hL0dJj60=2]Q@3?[8@0cZ^30<^[PP3=[H@0d;270=:bR@3D]8/0dk>:0P3B/XT0
1P3C/H<0dk640=>aQ03C/8H0dk280=>`RP80djn;00H0d:f70=6^R03A[XP0dZn90=>`RP3D/H/20=Fb
S0040=>cRP3B/XT0d[:90=6aR080d;270P3?[hH80=:_Q`<0d:f50P3?[8@30<j[P`080=2]Q`3?[8H0
cJZ20<^XOP39YgX0ajEg0<FSL`34XW880<RUN`80bJMi0P38YWP40<NUM`090<JTMP36Xg/0ajAj0<RU
N`38YWT0b:Ih0<JTM035Y740`j9_00P0aJ5a00P0a9mb0<>OK`30W6`0_YYX0;fII@2mVV@0_Y]S0;nL
I080`9aX00@0_i]W0;jJIP2mVFD0_9QT0`2kUf<03`2jUV80^IEQ0;RDH02iUF40^YIR0;bHI02nVVH0
`Yi^0<6MK@2oVf/0_YYZ0;nKJ`30W6`0`im_0<BPL0030<6MJ@030<2LJ02oVfL0_YYV0080_YYV0P2m
VFD20;jJIP030;nKI`30W6P0`9aX00<0`IeY00<0`9aX0;nKI`2nVVH00P2lV6@0102kUf<0_iMS0;nG
H`2oUf<[ooooo`00:_ooool20:EjA`030:IkB02WO4T0Z7e:0080ZWm<00D0Zh1=0:MmB`2XOT`0Z7i<
0:UoC@020:Z0CP80Zh5?202WODd80:QnC0<0ZX5=0`2YP4`20:QoB`P0[8=?202^Pe080:j5D@<0ZX1>
1@2YOdd0102VOT<0YGa40:AkA@2SNTH20:9hB0040:5fB`2QMT`0XGE>09ebA`80W75600<0Vg1509Y_
A02IKT<00P2HKD804P2CIcX0TfPk09AY?02CJS`0T6Xk08eY>@29IcL0QfDe08YU>`29I3X0R6<i08MR
>025H3H0Q5le08=N=022GC<0P5/a07mJ<0<0OEP^00T0OUT_081K<@21G380MEHW07EF:01dEBL0M5DY
07=C:P1bDR/00P1aDB/206a?9`0606e@:01_DRX0LE@/079E;@1cERh0M5L_0P1hE300301gE2h0Me@/
07UF;01kFB`0OU`_07mM;`21G2l0PUd`08=N<@24Gc80QF0c08MR=@80R6<f0P2;ICH0102<ISL0SVPi
08mY>P2AJc`2099/?@0309EZ?@2FJch0Uf`o0080V6e000<0Uf`o09I[?P2EJSd00P2EJcT209AZ>080
TfTg0P2BJ3H309Q]@00309M/?`2FJch0UFXm0080UFXm0`2BK3d2095[?0<0T6Xk0P2FK3X0102EJcT0
U6Xh09AZ>02CJCL2099X=PP0UF/i00<0Tfdn099/?@2AJc`00P2@JS/00`2BK3d0U6ho09I`@@08095/
>0P0UV`j0P2FLCd209E`?0D0U6lk00D0VVhm09U]?02IKC`0V6`k09M[>P0209IZ>@0309EY>02DKc/0
U6lk00H0U6lk0P2AK3P3099]>@<0Tfhj00/0TFdm099^?P2DL400UG5109Ib@P2ELD40U71009=_?`2C
KCh0U6ho09E_@00209Ma@P0309E_@02DKSl0Tfdn0080TW<m00@0Tg8m09Ea?@2ELCd0UW4m0P2HL3d8
09A_>`<0TFdm00<0TVhn09=_?`2DL4000P2DL40@09=b?@0X09=dA@2BLd@0TG9308m`@@2>Kd00S6dn
08]/?@2:Jc`0RVTn08ET>@20HCD0OF0d07eR=@1jHS@0MUh`071J:`1YER`0J5D]06EC;@1OCbd0F4LY
05519`19>b40ASLP03df8`0k=280>3<P03<`7`0_;Ah0;2dO02/[7`0Z;1l09bXI02HY600V:1X09RPK
02HX7@0V9al09RLQ02DV80<08B@M0P0P8a`301lR6`<082<L0P0Q91d3028U7P0802@W700S9Q/08RDL
024T7@0O8A`07R0M01dO700L7Qd301TO6`8061hJ100G7AT06`0L7Qd06adJ01/M6P0L7QT07R4J024T
6`0T9a`09BPM03@_700i<R00?SLT04@l9`19?RP0BCdU04Tj8`17>Al0@C@Q03ld8P0i<1l0;bTK02<Q
5@0M7QH07R4J020U7`0Y9A`0:RHM02/W7P0202`X7`0402XV7@0Y9A`0:2@K02DV7P8092DM00<08b@L
028S6`0Q8QX00P0P8AT@01lP6P0S01PJ5@0L7QT0824K028R6P0S81L09b<H02dY7P0e;b<0F3hW06Q=
;`1hGcH0OV@a07YO:01kGBT0Pf8e08a[@P2:Kd00TGI709=gA`2EMdD0XX9?0:b;EP2KNTD0PEhX04dk
9@0g:QX0;BXQ02/a;`0P:R/08BLW02X/9`0/:B809bPR02PY8`0Y:R@00P0Z:bD01@0Y:R@0:2TS02LX
8P0U9B<09RHT00809bLU00@09RHT02@T8P0R8R008B4O200U9B<00`0V9b409BHP02@U7`0202<T7P0R
02@U7`0V9b409bPR02lW9@0_9b@0;bXV030]9P0_;bD0;S0S02/]800X;1d0<2/U030/8`0c;2@0=B`S
03L]8`0j;R80?2hQ03d_8P14=bL0@C@S048b8P17>2D0CchZ05=1:`1C?bL0Cc/S06Q@=P1`ECP0Le8a
06a:9`1TABH0GdL]0554<`80A3h`00h0A3LW04@g9P17=bL0B3TV04`k9`1@?RP0ED4Y05I2:P1C?BH0
DS`W04lj9@1;>BD0BCHU04Pg9`80AcLX00/0E40W05<o9P1A?B@0D3`S04lk8P1@?2<0DCdT058n9@1>
?RL0CclX0510:@050551:P0H04<m8`14?B<0AcdT04Xk901=>bD0D3/V054k9P1D>bL0DD0T05919@1F
@bD0FTDX05i7:01RBBX0I4`Z06I<:`1LBBT0GDXZ05e:;01MBBh0GDT`05]7;`1H@bh0Ed8]0P1>?R@0
0`1=?B@0CCdV04`k9`0204/j:00904/j:P0l=b<0?3LT03/f8`0j=2@0>C<U03Pb9P0h<BL0=c0V00<0
=C4U0P0d<2@303<_8`80<blV0P0b;RD2034]9080<2`S00H0=2hR03D_8`0f<2@0>38V03Xd:00k=BT2
03dg:`0>044e9`0o=RL0?S@X03/c:00i<RP0=S8Y03@a:00c<2T0;bXT02l[8P0`;2<0<BdR038^8P0c
<24203@a8080=S0T0`0e;b<303@^8P06034/9P0a;B@0=2dU03H]900h;R@0>RhR0P0k;B00200n>BH0
?cXW048j9`16>bL0Bc`W04lm9`1B?BP0E3hW1@1:>R<02`1;>b@0C3`U04`l9@18>2P0BCTY04Tl:`18
?B/0A3`Y040i9P0m=R<0>SDQ0080@SDU00L0A3LW04Lj:@19?2T0BShX04Xn9P19?BD0BCdS0080B3PQ
0P19>B80101;>b@0C3`U04dm9P1>?RL204lo:00404lo9P1>?R@0CSlR04ho8080CSlN02@0CchT04lo
9@1A@BP0D44Z04/o:@15>RH0?SHQ03Xb7`16<RL0B3@Y04/h:P1=>R/0Cc`]04ll:`1>?2P0CC/W04Y0
9@1;?bD0C40V04m19`1A@BP0Dd4Y05I2:P1G@b/0DT@Z0553:01B@RP0E4<W05I59`1KB2P0Gd/Z061<
:`1WBRP0JTd[06]>;01XBbT206A79@0P06U<:P1_DS00NehV07aN:01jGbX0N5h]07AL;01aFRh0KEP]
06]E;01]EC<0K58a06aB;`1cEc80Nedg089R>`23HC/0PF0g07eW>01nISP0OfLi08=X>`25JCX0QfPj
08QW>P29J3/0PVP_08AY<P28KCH0S74l08mc@@2AMDD2099fA`0H095]B`2DL4`0UWA?09=cBP2=L4@0
Rfm008ab@@2?MD@0U70n09UgA`2PP540X8=G09f1F@2IPUT0VhEP09f9I02OTVP0X95X0::CJ02UU6P0
Z9IX0:bGJP2_VFX0/9Y[0`2oYF`00`30YVd0`JM^0<6WKP020<:XK`<0a:Ub00X0`jQa0<6VK`2nXf`0
^j1Y0;VNI`2lV6H0^iMU0;RDH02eTU`0/i1H0P2cT5H01`2dTUD0]95A0;JCD`2jUeL0_IYJ0;nLG030
WEd00P2oW5`0302jUel0^IIN0;VFGP2gU5X0]I=F0;BBD`2eTe@0]iEE0;RFEP2hUUT0]YAG0;>AE080
/8iA00h0/i5D0;JDE`2hUUT0]9EO0;JGH@2iVV<0_9iR0;^MG@2iW5P0]IQB0;>GCP2_SDd0[H];0:^9
B@80ZHM700l0ZXQ80:b:BP2]Rd/0[HY60:n<B02bSd/0]iA@0;bIE@31WUX0a:5M0<JSG`35Xf<0`j5Q
0<2NGP2mVe/00P2lVUX02P2mVe/0_YaL0;jLG02oWEd0`9iN0<6OG`33XF40a:9R0<FSH`36Y6@30<BT
J@030<>SJ032XVL0`J5V0080`J5V00@0`J5X0<2PI`30X6D0_imR0P2nWel20;fNG@090;fTHP2ZTE40
VH1009Il?`2HOT<0UG]209Ai@P2GO4D0UG]200<0U7Y100@0UG]209QnA@2JP4L0W8990P2OREL01`2Q
ReT0XheK0:F?G@2WTEl0Z99P0:VCH@2[TEh00`2/TUl20:fCH080[YAQ0100[IAN0;:IH`2iWF/0_Ym`
0;nNL@32WgD0ajAj0<fWP03?ZX00e:n50=VdRP3J]H/0f;>90=NbR03I]8X0g;N=0`3G^i@50=JjT`0H
0=6dS03>/HT0bjj60<Z]Q@39[8@0a:Mo0;bOM`2eV700ZHeK0:J:FP2/T640^Iab0<6SO@34YX@0bZ^<
0=>dU`3D_9X0e[fN0=S1X@3KaZL0g/^]0>7@]03TdkT0iMFk0P3[g<D20>cMaP0;0>gNa`3^glP0kn39
0>oPb@3`hLX0l^3:0??Qb`3ehld0mnG?0?SVd03giLl00P3fi<h30?GTb080m>?70`3ch/H20?ON`004
0?KM_`3eg;h0mMbn0?CK_@80lmZl00H0mMfk0?CM^`3dgKd0l]fn0?;O`@3`gl420?3Qa0<0k]Vl1@3]
f;/0203/f;d0kMVn0>gI`03]fL40k]W40>kIaP3_f/L0km[90P3XflX0103Yg</0j]g<0>[Mc03[g/d2
0>cOcPP0k=o<0P3ahM420?3Pd0<0kmo?00@0k]k>0>gNb@3]g/T0kMk91@3^glX30>cMaP030>_La@3Z
fl@0j]_40080jM[300H0l=_:0?3Kb03`flP0l=_60?3La03`g<<20?3L`@80lMc100<0l=_00>oJ_`3]
f;d00P3/ek`03`3[e[/0l=2g0>o?]P3^ck<0kLja0>c=[P3[cJ/0j/bZ0>[<Z03^bId0kLRL0>c7V`3Z
aIT0j<>G0>O2UP020>G0U0060>:mT@3Q_900gkZ>0=fhS03K]XX0fKB80P3G/XH0303F/Gd0eK1l0=>^
NP3@ZgL0cJQd0<^VLP38Xfl0aj9^0<FPK033WVX0`IaX0;jII@@0_9MS0P2fTEX0102fTE`0]i9N0;NB
GP2gTF020;RBH`040;RBI@2aSEd0/HeM0;6=G@<0/8aL0P2_Re/0202_SF00[XaO0:j<GP2]Re/0[8]H
0:^:E@2ZRE@0ZXUC0P2[Qe<20:Z6DP040:V5D@2XQ500Z8A@0:N3C`80ZhMG0P2/R5P20:f9F@80[XYJ
0P2[QeL00`2/R5P0[HUI0:j:FP020:n;F`040;2<G02cSel0/XiN0;2<G080[h]K00<0/HeM0;>?G`2d
T6000P2dSf<20;F@I0<0]Y5U00<0]i9V0;RCI`2hTfL01P2hTfL30;NBIP80^9=W0`2iU6P01P2cUV`0
]9M]0;FHKP2fVFl0^9]a0;VLLP80^Yec00@0_IY`0;jKL@2nVg40_Y]a0P2oW7820<2ML`080<2MM`31
WWP0`Ymi0<>PNP34XG/0aJ9l0<JSO@37Y7h20<BQN`040<FRO036Xgd0ajAn0<NTOP80b:Eo00@0bJR7
0<ZYR03<ZhX0cZf<0P3?[Xd01`3>[H`0cJb;0=:bR`3B/X/0dk><0=BdS@3E]Hh00P3F]Xl00`3G]i00
e[RD0=JhU0060=JhU0P0f;RA0P3D]8d00`3E]Hh0e[J?0=NgT0020=ViTP030=ZjT`3F]I@0e[FD00L0
e[FD203G]hh30=NgT080f;RA0`3I^I830=jkU@80gkbF0`3P_IL20=fmUP80g[jG0`3O_iP:0>30V@08
0=noV03M_IH0g;bE0=blU@3M_IH0gknH0>30V@3O_9@30=jkT`80gKZB0P3L^I480=fjTPP0fkR@203M
^Y@80=nlUP<0fK^I0P3J_9X30=^mV`<0gKbI0P3L^iP30=^jU`<0gkbD0P3N^i<30=fjTP<0f;RA0P3G
]i050=JfS`@0ekN@0P3H^9420=NgSP80e[J=0`3E]H`02@3D]8/0f;>F0=RcUP3H]9@0f;B@0=ReS@3H
]XT0f;J80=RfQP090=NdS0040=>`R03D/HT0e;690=FbRP80e[>;0P3G]8`0103F/hd0ekB>0=NdSP3G
]8h20=ReS`80fKJ@0`3J]i420=VfT0<0f;F?0P3E/Hd20=JbSP<0ek>?00@0f;B@0=FbRP3E/XX0eK::
0P3D/HT30=>`R0P0e;69103G]8h20=ReS`80fKJ@203G]i080=JfS@040=BaQ`3C/8H0dJj40<n/PP80
cZ^100@0cjb20=2]P`3?[8@0cjb40`3@[HD30=6^QP040=>`R03B[hL0dZn70=:_Q`80dJj60P3@[HD0
203>Zh<0cjb40=2]Q@3A[XH0dZn70=>`R03D/HT0eK::0P3E]Hh0103D]8d0dk><0=6aRP3@/8T20<n_
R080cjb20`3@[H<30=6^Q0030<n/PP3@[H<0d:f30080d:f30`3A[X@01P3@ZXD0cZR10<bVO`3:YG/0
b:=g0<RSMP80bJEe1@36Y7@30<NUM@<0aJ5a0`36XW8=0<NSL`80aZ9b1035XG420<:NKP80`Ie]1030
W6`0202nVfD0_IYT0;bIH`2kV680^YMQ0;VFH02hUEl0]iAN0P2kUUl00`2kUV40^iIR0;^EI0020;^E
IP070;^EJ02mVFD0_IUU0;jJIP2oVfL0`9aX0<6MJ@020<:NJP040<6MJ@30W6P0`9aX0<2LJ080_i]W
0P2nVVH20;^GI`80_9QX0`2mVFT00`2nVVX0_ie]0;jLK0020;jLK080_I][0P2lVVX30;bIHB_ooooo
000Zooooo`80YGY700L0YW]80:MlB@2XODX0ZGi;0:YoC02[P4d0Yge;0080Z7i<0P2YOdd20:Z0CP03
0:^1C`2WODd0Yge=00H0Yge=202XOT`30:Z1C@<0ZH1<0P2XOd/80:b3C`P0[X=@202]Q5030:Z0CP@0
ZGm=00D0Z7i<0:ImA@2UO4@0YGa60:AjB0020:=iB@030:9gC02QMT`0XGI<0080WG9500@0W75409]`
@`2JKd80VFi10P2HKD004`2CIcX0TfPk09AY?02CJS`0T6Xk08eY>@29IcL0QfDe08YU>`29I3X0R6<i
08MR>025H3H0Q5le08=N=022GC<0P5/a07mJ<01nFBl00P1mF2h0101nFBl0P5/a085L<P1fEbP207EF
:00307AE:@1cDbX0LU8[0080LE4[00H0KE0X06iA:@1^DBT0Ke8Z071C:`1aE2`2079E;@0>07QD<01g
Dbl0Me@^07MD;01iER`0NeT/07iL;`1oGBl0PE`_089M<023GS40Q5lb08EP<`27HSD208QS=P80RfDf
00T0S6Hg08iX>@2?JCX0T6Xk095[?02BK3d0UFXm09I[?P2GK3l00P2HKD000`2GK3l0UV/n09EZ?@02
09I/>P80UF/i102DJSP209Q]@080Uf`o00@0UV/n09EZ?@2EJSd0UFXm0`2BK3d2095[?0<0T6Xk00<0
UV`j09E[>@2EJcT00P2DJSP209=Y=`03099X=P2EJcT0UF/i00H0UF/i00P0Tfdn099/?@2AJc`0T6Xk
095[?02BK3d0U6ho09E_@0P0TF`h202FK3X209Ia?@80UG0l102DKc/00`2CKSX0Ufdk09M]>`0209M]
>`@0UV`j0P2DKc/409=^>P80TVdi0`2AK3P2099]>@<0Tfhj00/0TFdm099^?P2DL400UG5109Ib@P2E
LD40U71009=_?`2CKCh0U6ho09E_@00209Ma@P0309E_@02DKSl0Tfdn0080TW<m00@0Tg8m09Ea?@2E
LCd0UW4m0P2HL3d809A_>`80TFdm0P2BKSh209=_?`80U710402CLSd0802CM4D0TW=4095b@`2?L440
SVm008a]?P2;K3d0RV/l08YY?P26ICX0P64e07eP=01mHSD0NV8d07EM;`1`FR/0JEH/06QE;@1UDbd0
GTh/05Q7:@1A@BL0BS`R04Hg800m=R<0?3DS03Lb7`0b;ah0;bdN02`]7`0[:al0:R`O0P0W:QT0100V
:1X09RPK02HX7@0V9al202DV80<08B@M0P0P8a`301lR6`<082<L0P0Q91d3028U7P0802@W700S9Q/0
8RDL024T7@0O8A`07R0M01dO700L7Qd301TO6`8061hJ100G7AT06`0L7Qd06adJ01/M6P0L7QT07R4J
024T6`0T9a`09BPM038]6P0f<Ah0?SLT04Dm:019?RP0BCdU04Hj8P15=ad0@C@Q03ld8P0i<1l0;bTK
02@R5P0M7QH07R4J020U7`0Y9A`0:RHM02/W7P0202`X7`0402XV7@0Y9A`0:2@K02DV7P8092DM00<0
8b@L028S6`0Q8QX00P0P8AT@01lP6P0S01PJ5@0L7QT0824K024Q6@0S81L09b<H02dY7P0d;R80EC/T
06A;;@1eG3<0O68_07QM:01hFRP0Of0d08UW@@29KSl0TGI709=gA`2FN4H0Xh=@0:f<E`2MO4L0Q64[
050n:00h:a/0;BXQ02X`;P0O:BX08RPX02X/9`0[:2409RLQ02PY8`0Y:R@00P0Z:bD01@0Y:R@0:2TS
02HW8@0U9B<09RHT00809bLU00@09RHT02DU8`0S8b408R8P200U9B<05P0V9b409BHP02@U7`0S91h0
92DO02DV800W:280:2TS034Y9P0a:R@0<2/U034]900`;B@0;RhR02`^8@0[;B00<2/U030/8`0c;2@0
=RdT03P^900k;b<203d_8P0?04@g9P13=RD0AcPU04dl:01E@bd0FTD`05M3:`1D?RL0HTdb06iC=P1c
DS40K4XU06A38P1K@bL0D44/0080@cX[01<0B3/Z04Lj:@19>RL0BSTU04`j901@>bH0DclW05Do:01D
?RL0DS`W04lj9@1;>BD0BCHU04Pg9`17=bP0B3PY05<o9P1B?RD0D3`S0080Cc/R00<0D3`S058n9@1C
?bH0101>?RL204lo:00J0510:@1A@BX0A3dS04Dn9017?B@0Bc`U04`l9@1@>bH0DC/V058l9`1A@2H0
DT4U05I29`1IA2L0GTLX0619:@1SBbT0I4`Z05]8:01LBBT0GDX/05e9;P1LB2l0FTH^05Q3;P1G@Rd2
04lo9@0304hn9@1>?RL0CC`X0080C3/Y00L0BcXZ03`g8`0l=b@0>cHS03Xd900i<bD0>38V0080=c0V
0`0e<BD203@`90<0<blS0P0c;bH2038^9@80<BdT0P0`;2<2038/800D03<]8@0d;R80=S0T03La9@0h
<RH0>C<W044e9`0n=BH0?C<W03/c:00i<RP0=C4X03<`9`0c<2T0;bXT02l[8P0`;2<0<BdR038^8P0c
<24203@a8080=S0T0`0e;b<303@^8P06034/9P0a;B@0=2dU03H]900g;B<0>RhR0P0l;R40200l=b@0
?SLU040h9@15>RH0BS/V04dm9P1B?BP0DclW0`1:>R<204/k90<0C3`U0P17=bL01P15>2L0@cPV040h
9@0m=R<0>c@Q03Pc7`80@C@T00L0@cHV04Hi:018>bP0BShX04/o9`1:?RH0BShT0080BCTR0P1:>R<2
04/k9080C3`U0P1=?BH0101>?RD0CShT04ho8P1?@24204m07`0F050o9@1@@2H0DD4X0511:P1<@2X0
AS/W03lg8P0l=240A38V04Hd:018=RP0BcXZ04`k:`1<>bT0C3/W04/j9P19?b@0BclU04a09P1?@BL0
DD4X05=1:@80ET8Z00`0DD<Y0553:01B@RP0E4<W05I59`1KB2P0GTXY061<:`1WBRP0JTd[06]>;01Y
C2X206E89P0?06U<:P1^DBl0NedW07]M:@1jGR`0NEl^07EM;`1bFbl0KUT^06eG;P1/E380JU8`06]A
;P1aEC00N5Xd0080OUhg00l0OE`c07US=01kHcD0O6@f081U>023IcP0QVLi08QW>P29J3/0QV`c08Q]
=P2<LCX0Sg@o099fA02DN4P00P2DN4T0802ELTX0V7E=09UhC`2FMTd0T7=908ebA`2?M4T0T7Q<09Id
A02JNT/0X85C0:23E`2MQ5/0WHIM0:2:H`2RSVT0XY=Z0:>DJ`2VUFX0Z9EZ0:bGJP2^VFX0/9Y[0;6K
JP2mX6H0_Z5W0;nRJ032YF/0aJQ^0<NZL039[780bZec0`38ZW@02`36Z780a:I`0<2RK02mWfT0^ieW
0;^GI@2iUF40]i=O0;BAF`2cT5P0/XmE0080/i5D00D0/Xm?0;BAD@2gU5@0^YMG0;bIF@020;fJFP0M
0;bIF@2kV600^IIN0;VFGP2gU5X0]YAG0;FCE02fU5@0]iEE0;RGE02gUEP0]I=F0;:@D`2`SU40/HmB
0;BBE@2gUEP0^YQK0;JGH02gV640^Y]R0;^MG`2jW5`0]iYF0;BGD@2aU4h0[H];0:b:BP2[RDT00P2Y
QdL06`2ZR4P0[8Y:0:f;B`2^RdL0/8e90;>@C02gU500_9UE0<2MF@33X5`0aJ9N0<BRHP32X600`9iN
0;jLG02mVe/0_YaL0;nMG@30WUh0_YaL0;nMG@30WUh0`ImO0<>QH@34XV80aJ=S0<JTI0020<BTJ@80
`j=X0P32XVL20<6QIP0@0<:RJ@31XFP0`:1U0;nOHP2nWel0_9eL0;^LF`2kW5T0_:=Q0:V@D02HOcl0
UW`o09Qn@`2ENd80U7U209IkA080U7Y10P2CND00302ENd80Uge409Z0A`2KPDP0WhQD0:29E@2QRUH0
XhaH0:J?F`2XTEd0ZI9N0:ZCG`@0Zi5N0P2/TUl20:fCH00@0:bCG@2aV680]i]Y0;bMKP2mW6l0`9ec
0<FRN03<YWl0cJZ00=:_Q@3G]8X0f;F;0=JcR@3E/XP0ekB:0=ZgS@@0e[ZC103E^I806@3@/h/0cK28
0<Z]Q@39[8@0b:^30<>VOP2kWWH0]9M_0:R<FP2VRUP0[91Q0;VLLP32Y7h0a:J20<Z[S03C]9D0e;bJ
0=JnW03H`J40gLJW0=o:[@3Sck@0i=>g0>KE^`3Zfl@00`3[g<D00`3/gLH0kMk70>kOb0020>oPb@04
0?7Ob@3chL/0mN?=0?KTcP80mnG?0P3ehld30?KRa`80mN760`3dh<D20?KM_`030?GL_P3dfkd0m=^m
00<0lmZl00P0lm^i0?;K^@3cg;`0lMbm0?7N`03_g/80k]o20>oOa@@0k]Vn103]f;d01P3]fKh0kMW0
0>gI`03^f/80k]W40>oJa`80km[90`3Yg</00`3ZgL`0jmk=0>_Nc@020>cOcPP0kN3=0`3`hLh20>oP
c@<0k]o<00<0kMk90>kObP3^glX01@3^glX20>kNa@040>gMa03/g<<0k=c30>_K`P80j][100H0k=O4
0>cG`P3/el80k=S00>cH_`3/f;d20>cI^`80k]Nh00@0kMJg0>cE]P3[e;D0jM:c0P3XdK801@3/bZl0
jlV^0>[8[03Yb:T0j<NV0080i/FR01l0iLFO0>O2UP3V`ID0iL2D0>>nTP3P^hl0g[V=0=fhS03L]h/0
fKB80=RcQ`3G/XH0eK240=>^PP3A[800cjYn0<jYO@3=Z7@0c:Mc0<ZUL@37XVh0aJ1/0<:MJ@30VfL0
_iYV0;fHI02kUV80^IAP0;JAG@2eT5`0]8mK0080]I1L0P2`Re@0102`ReH0/HaH0;6<F02aReX20;:<
G@030;:<G`2`S5`0/8aL0080[h]K102^RUX20:b:G@030:^9F`2ZR5P0ZHQE0080Z8MB00@0YhI@0:V5
D@2XQ500Z8A@0P2WPdl20:J2CP040:F1C@2ZQUH0ZXIF0:Z6EP80ZhMG0`2/R5P20:^7E`80[8QH00H0
[HUI0:j:FP2_Re/0[h]K0;:>GP2aSEd30:n;F`030;2<G02bSUh0/hmO0080/hiR0P2dSf<30;F@I003
0;JAI@2gTVH0]i9V00H0]i9V0`2fTFD20;NBIP<0^9=W00T0]9EY0;FFJP2fUf/0]iQ/0;VJKP2jVfl0
^ia`0;bML@2lVFl00`2mVW020;jKL@80_iab00H0_iaf0<2MM`31WWP0`Ymi0<>PNP34XG/20<FRO080
`j1j00<0a:5k0<FRO036Xgd00P37Y7h01@38YGl0b:N40<VXQ@3;ZXL0cJb90080cZf:0P3=[8T20=6a
RP030=:bR`3C/h`0e;B=0080eKF>00<0e[J?0=FgT`3E]i<01P3E]i<80=NgT0060=>cS03D]8d0eKF>
0=JfS`3G]i00f;RA0P3I^I890=FdT@P0e[J=0P3F]Xl20=NgT0<0f;RA00@0fKVB0=fjU03M^Y@0gKZD
0P3N^iD30=nlUP80g;bE0P3M_IH30=jnU`030=noV03P`9T0h<2I00L0h<2I00L0gknH0=fmUP3L_9D0
g;bE0=fmUP3O_iP0h<2I00<0gkbD0P3N^i<30=fjTPP0g;VA203K^9080=biT`P0gKZD00@0f[VF0=^j
U`3K^YL0fkZG0P3L^iP40=flV@<0g;^H0`3K^YL20=nlU080g[^C0`3M^Y80103L^I40f;RA0=RhT@3H
^9420=NgT0D0e[J?1P3G]i00103G]hh0e[J=0=JfS@3F]Xd20=FeS080e;B;0P3G/i<0103G/i40ekB>
0=NdS03G]HP20=NeQ`T0e[>;0P3C/8P20=BaR@040=FbRP3F/h/0e[>;0=JcR`80e[>=0P3G]8h30=Re
S`030=VfT03J]i40fKJ@0080fKJ@0P3H]Hl20=NdSP80eK6=0P3F/Xh40=NcS`80eK::0`3D/HT30=>`
R0P0e;6900@0e[>=0=NdSP3G]8h0ekB>0P3H]Hl20=VfT0P0ekN@203F]Xd0103D/HL0dk260=6^Q03?
[8820<j[P@030<n/PP3@[H<0cjb40080cjb40P3@[HD30=6^QP<0dZn70P3A[XH30=2]Q@050<j[P`3?
[8@0cjb40=2]Q@3B[hL00P3C/8P01`3D/HT0e;B=0=BdS@3C/h`0d[:;0=6aRP3@/8T00P3?[hP30<n/
PP80d:f30`3A[X@20<n/PPH0d:f300P0cjV20<jXP@3;YW`0bJAh0<RSMP38Y7@0bJEe0<VUL`P0aZAd
1036XW850<FQL@X0aj=c0P36XW830<FQL@030<BPL032WVh0`Yi^0080`Ie]0`30W6`02@2oVf/0_IYT
0;fJI02lVF<0^iQR0;ZGH@2iUV00^9EO0;NDGP020;^FG`030;^FH@2kUV80^iET0080^iEV00H0^iEX
0;fII@2mVFD0_YYV0;nKI`30W6P20<6MJ@040<:NJP30W6P0`9aX0<2LJ080_i]W0`2nVVH20;bHJ080
_IUY0P2nVVX20;nKJ`@0_Ya/0P2mVf/20;bJJP<0_9UQ:oooool002[ooooo00H0YGY70:IkB02VNdP0
Yga90:QmBP2YOT/20:YoC0@0Z7i<0P2YOdd20:Z0CPP0Yge;202XOT`30:Z1C@<0ZH1<0P2XOd/80:^2
CPP0[H9?202[PTh01@2[PDl0ZX1>0:Z0CP2ZP4h0ZGm=00<0Z7i<0P2UO4H01@2UO4P0YG]90:AjBP2T
NTX0XWM:0080XGI;0P2MLTD00`2LLD@0Vg1309Y_@P0209U^@@0D09Q]@02DJ3/0TfPk09AY?02CJS`0
T6Xk08eY>@29IcL0R6Hf08YU>`29I3X0R6<i08MR>025H3H0Q5le08=N=022GC<0PE`b081K<@1nFBl2
07eH;P0;07iI;`20Fc40PE`b07IG:01fEbT0MEHX07AE:@1cDbX0LU8[079B;01aDB/0201`Db/03P1h
E300Me<_07MD;P1gE2`0N5D[07]I;01mFbh0Oed_085L;`22GC00Peha08AO<P25H3<0Qf8e0P28HcH0
2`2:I3D0RfDf08aV=`2=IcP0SfTj091Z>`2AJc`0TV`m09EZ?@2FJch0Uf`o0080V6e000<0Uf`o09I[
?P2EJSd00P2HKS`209M]>`<0UV`j00@0UF/i09M/?`2GK3l0Uf`o0P2FJch309EZ?@<0TV`m0P2AJc`3
091Z>`<0UF/i0P2DJSP309=Y=`P0UF/i0P2BK3d3095[?003099/?@2DKSl0UFm000P0TVdi202FK3X3
09E`?080U6lk102CKSX409I/>P@0Ufdk00D0U6lk09=^>P2CKSX0TVdi095/>002091[=`0308mZ=P2@
JcL0TF`h0080TF`h0P2BKCT209=^>P03091/?02AKCd0Tflo00<0UG510P2CKcl00`2CKCh0U6ho09E_
@00209Ma@P0309E_@02DKSl0Tfdn0080TG8l00@0TW4l09A`?02DL3`0UG0l0P2GKc`809A_>`04095]
?@2BKSh0TVhn099^?P<0Tflo00<0U71009=b?@2CLSd03P2CLSd0802BLd@0TG93091a@P2?L440SVm0
08e^?`2<KCh0Rf`m08]Z?`26ICX0PF8f07eP=01mHSD0NF4c07EM;`1_FBX0JEH/06QE;@1TDR`0GDd[
05Q7:@1A@BL0BS`R04Pi8P0n=b@0?3DS03Lb7`0b;ah0;R`M02//7P0/;200:bdP0P0W:QT0100W:A/0
9RPK02HX7@0U9Qh202DV80<08B@M0P0P8a`601lR6`8082<L0`0Q91d0200T9a`08bHK028U700Q91d0
7b4L01hP7@0M7a`071hM0`0I7a/201PN6P@05adI01/071hM01/M6P0K7AX071hI01hQ6P0Q91/092LL
02DX7@0]:QL0<c0M03dh9015?bT0B40Y04Pn9@14>200@3@J040c800o=280>C0O030Z700T8QH07AhF
01hQ6P0O91h0:2@K02TU700[9ah00P0/:1l0100[9ah0:BDL02PT6`0U9Qh202@U7@0302<T700R8a/0
8B8J0080824I400O81X08`0I6aH071hI020Q6`0Q8AT08b0G02HR5`0/:1d0<bdQ04lf801NAbP0L5T`
07EN;01bFB<0LEDS07YK;`23Hc`0R6dn095fA`2DN4P0UgU70:>3D02^SEP0X7m:08UV<01D@R`0>RdM
02dZ8@0Y;bd07bTZ028X:00Z;2L0:bPQ02HW8@0W:280:BXT0080:R/U00<0:BXT02LX8P0V9b400P0U
9B<302LW9@0302DU8`0T92808R8P00P09BDS00<09RLQ02DV800T9Al00P0T9Al00`0V9b40:2TS02TZ
900203H]9P0M03D^9P0a;B@0;bdQ02`/800];B40;BlR030[9@0a;B@0=2dU03H]900i;bD0?30T03h`
8`0o<B@0AcLW04Tj9`1=?2X0E48^05Y8<P1MBC40FT@/05M1:@1LAb`0JU4c07=B;`1]BR@0Hd4L05Xo
8@1>?2@00P12=b<0401=?Bd0C3dZ04`k:@1<>RH0C3XT050l901D?RH0EClW05@n9`1C?BP0CcXU04Xh
9018=B@0AcHV04Lg:018>2T204hl900904dk8`1<>R80CC/S04lm9@1A?bL0Dd4Y04lo:01>?RL0C3`U
0080Bc/T00<0CCdV0510:@1A@BX00P17?B@01019?BD0Bc`U04dm9P1>?2H2050k9P0804lo9P1@@2H0
Dd8X05M3:01JABP0GdPY0619:@1RBBX205U9:00605Y9:`1JBBd0FDP^05M5;@1E@bd0E48/0P1A@BL0
1`1@@2L0CclX04hm:@1=?2X0C3/Y04`k:`0l=b<00P0k=R<00`0j=2@0>C<U03Pb9P0203L`9P<0=C4U
0P0d<2@303<_8`80<blV0P0b;RD2034]9080<2`S0`0a:al00`0b;200<bdQ03<]8@0203@^8P0>040d
9P0n=BH0?C<W03Xb9`0h<BL0=C4X03<`9`0b;bP0;bXT02l[8P0`;2<0<BdR038^8P0c<24203@a8080
=S0T0`0e;b<303@^8P06034/9P0a;B@0=2dU03D/8`0g;B<0>blS0P0m;b80200k<R40?3<R040e8`14
=b@0B3TT04`l9@1>?RL0D3hV0P1:>R<0101;>b@0C3`U04`l9@1=?BH204`l9@0504Lg9`16=RH0@SDT
03ld8P0l=2400P0j<b001`0i=200@3<S040c8`12=BD0A3LV04Lj9`19?BL00P1;?bL00`1;?bD0Bc/T
04/k900304/k900304Xj8`19>B80BCTR0080Bc/T01@0C3`S04hn901?@2<0D44R05528@1B@b80DT4W
0592:01B@RT0DD8[04e1:`18?BT0@CTT03lg9012<2@0A38V04Hd9P18=bL0BCPX04Xi9`80BSTU00H0
BClT04/o9@1;?bD0CT0V05109`1B@2P205E1:@0<0553:@1A@bP0DT8X05=29P1EA2H0FTLW05i::@1P
C2/0IdXX06U<:P1ZCB/0JD`Z0P1WBRP0801ZCB/0KU4_07YL:P1kGB/0NEd]07UN;`1fGS00Le``071K
<01_FRl0JU<a06QA;`1XD2`0K58]07=G<01hFc<0NETb07IF;@1dGC<0MUhb07QP=01lHC@0P6@e08EV
=`28J3T0RVXi08ec>P2?M3d0TWM009EjA@2GNdT0V7a<0P2GNd`0802INDH0W7a;09enC`2IO500U7Q@
091fD@2BN5D0U7aJ09YkC02MOU00Wh=D0:25F02PR5`0XhaR0:NAJ02/UVd0YII[0:RGK02ZVFd0[9Y/
0;2KK02aVfX0/i][0;>LJP2jWF<0^iiT0;jQI`32YF/0ajY`0<^^M03>/GL0ck9h0P3:[GD04`39[7@0
ajYb0<BWK`30Xf/0_9mW0;ZMI@2iUF40^9AP0;FBG02cT5P0/XmE0;6?DP2bT5<0/Y1A0;6>CP2bSdl0
]I9B0;NDE02iUUH00`2jUeL06`2kV5h0^YMM0;ZGG@2iUeX0]iEF0;NEE@2gUU<0^9MD0;RGDP2dTUD0
/i5D0;:@D`2aSe80/Y1C0;FCEP2iUeX0^iUL0;VIGP2jVUl0^i]N0;^LG02iVUT0]YMD0;:CD02`TT`0
[8Y:0:^9B@030:Z8B00;0:^9B@2/RTX0[H];0:n<B02`SDT0/i1<0;NDD02kV5@0_iaH0<6NFP33X5`0
0P32X6003`31Wel0`9iN0<2NGP30WUh0`ImO0<:PH02nW5`0_ieM0<2NGP31Wel0`j5Q0<BRHP35Xf<0
aZAT0<BTI`030<>SIP<0`Z9U0180`J5T0<BTJ@33XfP0`J5T0;nPH02lWE`0^Y]H0;VJE`2hVU@0^J1N
0:J=C@2GOSh0UG/n09Mm@P2DNT40TgQ109Ai@P2CND03099h?`0=09Aj@@2FO4<0VGm609Z0A`2PQU<0
XHMD0::8E@2UReP0YheJ0:V?G02[TEh0[99O0:V?G0030:Z@G@80Zi5N0P2/TUl04@2[TU`0[iIP0;FI
I`2iVV/0^YU/0;jKL@33X7H0bjEn0<fZPP3B[hL0ekB<0=ReS@3F/h/0eK::0=NdS03J]hl0ekZB00<0
e[VA01`0eKR@0=BgS`3D]hl0e;N?0<nbR03<[hD0bZf30<V/PP38Zh40`ZEk0;VLLP2aU6X0YhaG0:F9
E`2/T600^Yea0<:UO@35Yh<0bZb:0=>dU@3E^iP0ekfL0=W1W`3MaZH0glZ[0>?@/P3Vd[L0i]Fi0P3[
fl820>cL``0=0>gMa03^g/D0kmo60>oOaP3`h<L0lMo70?;Pb03dh/X0mN?;0?KTc03ehl/0m>;:0??Q
b@030?CQ``80ln320`3bgl40103dfkd0lmZl0??J_03cf[`30?;I^`090?7H^P3af;T0l=Vi0?3I^P3_
f[d0k]Zo0>gL`P3/g<80k=c300P0kMW000T0jm[00>cK`@3/f/80k=[40>gKa`3]f/T0k]_:0>kKc03Y
g</00`3ZgL`30>_Nc@030>cOcP3^hLh0k^7>00H0k^7>0`3`gld20>oNc0<0k]g;203_glP20>oNa003
0>kM``3]g<80k=_10080jm[00140j]Vo0>cC_@3/e;`0k=Bl0>_C^@3Zd[H0j]>d0>[C/`3Yd[80j]:`
0>WA[`3Xd:h0iln]0>G=Z`3Tc:X0hl^Y0>;:Z0020>?2X`0D0>;1X03P_i`0gknI0=fmUP3L_9D0g;bC
0=jiS03M^8/0fkJ90=RcQP3F/H@0djj10=6/O`3@Zgh0cJQk0<bWNP3;YWT0bJAg0<NRM@36XG@20<BO
LP0<0<2KI`2oVVH0_YUU0;bGH`2iU600]i9N0;JAG@2eT5`0/hiJ0;6<F02_RUH0[HQD0`2[QU80102/
Qe<0ZHA=0:V4C@2ZQE020:Z5D@040:^5E02[QEH0ZhEF0:b6F@<0[HUI0P2/R5P30:^7E`80Z8II00H0
YhEG0:J4E02UQ540Y8=>0:>2C@2SPT`30:B0C080Xgm;0`2ROTX30:R4E080ZHEE1@2ZQUH0102[QeL0
[8QH0:f9F@2]RET20:j:FP090:n;F`2^RUX0[XYJ0:f9F@2^RUX0[h]K0;6=G@2bSUh0/HaO00<0/XeP
0P2cSV420;B?HP/0]I1S0`2fTF@20;NBI@80/iAX00H0]9EY0;FFJP2gV6`0^9U]0;VJKP2jVfl30;^H
KP80_9U_0`2mVW020;jKL`80_iad00@0`9ee0<6NMP32WgL0`Ymg0P31WWH00`32WgL0`j1h0<BQN@02
0<FRNP040<JSN`36YH80ajJ30<ZYQP@0c:^800L0bjZ70<n_R03@/8T0d;290=6aRP3B/X/0dk><0080
e;B=203C]I480=FeSP060=:bR`3C/h`0dk><0=BdS@3E]Hh0e[J?0P3G]i090=BcT0P0eKF<0`3E]Hh2
0=JfS`<0ekN@0P3K^9820=biT`<0gKZD00<0g[^E0=ZjT`3K^i@00P3K^i@20=blU@80gKfF2@3P`9T0
203O_iP0g[jG0=fmUP3M_IH0g[jG0=noV03P`9T0h;fE0`3O_9@20=jkT`80gKZB203L^I480=^hT0P0
g;VC203K^9830=ZiUP80fkZG0`3L^iP0103M_9T0g;^H0=bkV03L^iP20=^jU`80f[VF0`3N^i<20=fj
TP<0g;VA0`3H^9420=NgT0<0e[J?0`3G]i050=JfS`80e[J=0P3E]H`30=BdR`060=>cRP3D/8`0e;2<
0=BaR`3D/HT0e;670P3D/XD00`3D/X@0dk280=>`R0090=>`R0<0e;690`3E/XX0103E/X`0e[>=0=Jc
S@3F/hd20=NdSP80f;F?00@0fKJ@0=ReS`3H]Hl0f;F?0P3G]8h20=JcS@<0eK:<0P3F/hd30=NdSP04
0=FbRP3D/HT0e;690=BaR@80dk280P3B[hL80=>`R0<0e[>=0P3G]8h30=ReS`P0e[J?203E]H`0103D
/HL0dk260=6^Q03?[8820<j[P@030<n/PP3@[H<0cZ^300<0cjb40P3@[HD20=6^QP040=:_Q`3A[XH0
dJj60=6^QP80d:f50P3?[8@20<j[P`030<n/Q03@[HD0dJj60080dZn700D0dk280=>cS03C/h`0d[:;
0=6aRP020=2`R@80cjn800@0cZ^10<n/PP3?[880cjb20P3@[H<20=6^Q0P0cjb200P0cZR10<fXOP3;
YW`0bJAh0<RSMP38Y7@0bJEc0<ZVM0P0aZAd0P37Xg<20<JRLP030<FQL@34X700`im_0080`im_2`36
XW820<FQL@<0a:1`0`31WFd20<2LK0<0_i][0P2lVF<0102kV680^YMQ0;VFH02iUV020;REG`80^YEN
00<0^YEP0;ZEH@2jU6<00P2jU6D00`2jU6L0_IUU0;fII@020;jJIP050;nKI`30W6P0`IeY0<6MJ@30
W6P00`2oVfL20;jJIP80_IUU0`2nVVX20;nKJ`<0`9a/0`2nW6`20;fKJ`<0_9YZ0`2lVF<[ooooo`00
:_ooool20:IkB080Yga900@0Z7e:0:UnB`2YOT/0ZGi;1P2XOT`20:UoC@P0Ygi:202XOT`30:Z1C@<0
ZH1<0P2XOd/80:^2CPP0[H9?202ZPDd20:^1C`80ZX1>00H0ZGm=0:QnC02XOT`0Yge;0:ElB02UNdT2
0:IlBP80YG];00@0XgU90:5gA`2PMTH0WWA40P2MLd<00`2LLT80Vg5109Y`@00209U_?`0?09AX>`2D
JC`0UFXm09A[?@2AJc`0SVXj08YX>028ISH0RVDk08UT>P28HcT0Qf8h08EP=P24GcD0Pehd0080PUdc
00<0PE`b07mJ<01nFBl00P1nFBl2081K<@0607IG:01fEbT0MEHX07AE:@1dE2/0Le</0P1bDR`0101b
EBd0LE@/075D;01`Db/206mB:P80KU4Y0P1gDbl0301fDbd0MU<[07QE:`1jF2/0OE/^07iL;P21G2l0
PUd`08=N<@24Gc80QF0c08MR=@80R6<f0P2:I3D0102;ICH0SFLh08iX>@2@JS/2095[?00309EZ?@2F
Jch0Uf`o0080V6e000<0Uf`o09I[?P2EJSd00`2IKcd209Q^?0<0Ufdk102FJch409EZ?@<0TV`m0P2A
Jc`3091Z>`P0U6Xh202EJcT3095[?080TV`m0P2CKCh00`2DKSl0TVdi099]>@06099]>@P0UV`j0P2E
L3`309A_>`@0Tfhj00D0Tf/h09A/>@2DK3T0UFdj09I^>`0209M_?00709Q`?@2CKSX0Tfhj099]>@2A
K3P0T6/g08mZ=P0208iY=@80T6/g0`2AK3P3099]>@0;091/?02AKCd0Tflo09A`@02ELD40U71009=_
?`2BKSh0Tfdn09A^?`2EKd000P2GLD800`2EKd00U6ho09=]?P02095b?004099a?02DL3`0U70l09E`
?080Ufll202DKc/4099^?P@0Tflo402CLSd2095b@`04091a@P2?L440SVm008e^?`80S6dn01P0RfXo
08MV>`21HSH0OF0d07eR=@1iHC<0M5`^06mI:P1ZEbd0J5D]06=A:`1LC2X0EdHX05519`1;?B<0BCXS
03lh9@0l=B<0=c8O034^7@0]:a`0:b`N02`/800/;R4202P[6P0402LY6`0V:1/09RPM02DV7P8092DO
0`0Q91d2020S70<07b8K0P0N8AX301lR6`<082<L00P092LL02<V6`0R9A`08B@M01lQ700N81d07AlL
01`N7@<06AlK0P0H7QX401LM6@0K01`N7@0K7AX06adJ01`N6@0N8AX08B@K02@W700U:1d0:RTE034^
6`0j>2<0@chX04M1:@15?R@0@CLN03dc600o<Ql0?S<Q03Xa800`:Q`09B<G01hO5`0N8AX07R<M02LS
6P0Y9A`0:RHM0080;2PO00@0:bLN02XV7@0Y9A`09BHN0P0T9Ad00`0S91`08R<K024R6P02020Q6A00
7b0J02<06A/F01`N6@0P8A/08B4I028O5P0U8AH0:bLL038/8018<Qd0FD4U06UC;01_FBP0Je@P06]A
801cER`0O5hh08EZ>`2?M4D0U7Q809MiA`2RPTl0[XeH0:>2C@2>JcD0FTPb03d`800]:R40:2h/01lY
:P0R:2P0:R`W02XW800V9b409bPR02PY8`0202TZ900;02PY8`0W:2809RLQ02@T8P0U9B<09bLU02PX
9P0W9bD09RHT02DU8`0T9280200U9B<00`0W:2809RLQ02DV800202DV800A02LX8P0Y:R@0:b`V03X`
900k<BD0>S8W03D_8`0_:b00;B/O02l/8`0`<2H0<2/U034]900d;BD0=bhU03X`9P0m<BD00P10<RD0
3`1:>bP0CC`X05=1;@1GABl0FdL_05Y4;01H@2H0ECdS05M3:01WCRl0Le<]06m<901WA1`0Gd4M058m
800204Hf7@0A04`m:P1<>bL0C3XV04`j901@?2@0E3hV05Y2:01MAB/0EClX05<m:01>>B@0BCLS04Pe
9017=RH0B3PY04Ti:P1<?2D00`1;>b@01`1<?2D0CShW0551:P1C@b`0CclX04dm9P1:>R<00P19>B80
0`1<?2D0CclX0551:P0204/l9@80C3dV0`1=?BH04@1>?2H0CT0V04m19`1A@BL0E4<Y05Q4:@1KART0
GTLX05m8:@1GB2L0F4TX05Q9:P1HBB`0F4P^05I6;@1C@b`0DT8[0080DT8X00h0DD4X0510:@1>?BT0
CC`Z04`k:@1<>b/0>cHR03/f8`0j=B80>C<S03Pb900g<BD0=c0V03H_9@<0=C4U0P0d<2@303<_8`80
<blV0P0b;RD2034]9080<2`S200c;B403P0o<bD0?C@U03`b9P0i<BH0=c0V03@`9`0b;bH0<BhW02lZ
900_:b80<2`S034]8P0b;R80<c0Q0P0d<B0203H`90<0=BlS0`0d;R804`0b;BL0<RhU03</900e;2<0
=bdS03/_8`0n<2<0?c4T03``800m<B40@3<R048e8P15>B<0BCXS04/l9@1<?R@0BSXS04/k901<?2D0
0`1>?RL02P1=?BH0C3`U04/k:`19>BT0A3LV03ld8P0l=240>c@Q03df8`0m>2@2040c8`08044d9013
=RD0ASTV04Pl9P1:?RH0C40X04a09P1<?2D204dm9P0S04`l9@1;>b@0BCTR04Lg8016=Ql0BCTR04Xj
8`1;>b80CCdS04m08`1A@R<0Dd@S05A5901C@RP0DT8X05=3:P1A@R/0CD4[04Tn:P13>bH0@CTV040`
8`11<B@0@c<T04@d9016=RH0AcPU04Lh8`18>B@0BClT04Xn901;?bD0CClU04lo9P1A?bL00P1C?bL0
2P1A@bT0D48W05519`1C@RH0ED@V05Y79`1NBRT0Gd/Z06M::01XBbT306U<:P0Q06Y=:`1[CR`0KE0^
07MH:P1hFBd0N5/_07QM<01fGS80M5da079M<01aG2l0JEDb06QA;`1VD2/0JU8/06mF;P1dF300LeH^
071C:@1aFS40LUTa07AK<P1iGS40OV8c08EW=@29JCH0S6`i09=i@02ENT<0Uga509YoBP2KOdd0W81@
0080Vgm@01H0WX570:64C02QQU40WX=D09QoEP2FO5T0V7mQ09^1IP2OQ5L0WXIH09n7F@2RRUh0YHiR
0:ZCI`2aVW00]Iid0:bKK`2^Vg00/9i`0;>NK`2eWfh0]Yi^0P2gWF`0202mWf<0_Z1T0<6SI`34YVX0
b:Y^0<^]L@3>/7@0ck5e0P3<[G@04`3;[7<0bJYa0<FVK@31XVT0_IiU0;^LH`2hUEl0]iAN0;BAF@2b
SeD0/HmB0;6?D02bT540/Y1@0;FBDP2fTe<0]iAD0;VFEP2kV5P00P2lVET01P2mVUX0^iUL0;^IG02k
VE`0^YQI0;ZHF080^IQE0P2iV5<0202cTE@0/Y1C0;:@D`2bT5<0]99E0;NEF02jV5/0_9YM0P2mVe`0
1P2mVe/0_9YJ0;VGE`2fUE80/Y5>0;2?C0D0ZXQ80P2[RDT02@2/RTX0[X]70:n<B02bSd/0]I9>0;VF
DP2mVUH0_iaH0<6NFP050<6OG`0;0<:PH033XF40`j5Q0;jLG02oWEd0`9iN0<6OG`33XF40a:9R0<FS
H`36Y6@01033Y6@40<:SH`0A0<FUJ033XfH0`J9R0;jOGP2kW5T0^9UF0;JHDP2eUe40]YeK0:B;B`2E
O3`0U7Xm09Il@@2CND00TGHo09=h@@2BN3l00`2AMch0302BN3l0UG]209MmA02IOdH0WXE?09n6D02Q
R580Y8]E0:J=E`2YT5X0Zi9L0:bCG@<0ZHmL0P2ZT5d30:^AGP0A0:ZAF`2^UEl0/iMU0;JGJ02hUfX0
_9U_0<:OM@39Xg`0c:Z40=6_R@3F]8h0ekF?0=FcS@3D/X`0e[B>0=VgT@3H^8l00P3G]hh01`3F]Xd0
eKF<0=BdR`3D]8/0dk>:0<jaQ@3;[X800P39[8005037ZWh0`JAh0;NJKP2^TFD0YHYC0:B9E02/T5h0
^Yi_0<>VO035Yh40bjf90=>eT`3G^iH0fKbJ0=[0W@3NaZ@0hLZZ0>C?/03Wd[D0j=Fg0P3[f/020>cK
`@040>gL`P3^gL<0kmk40>oNa080l=o500L0lN360??Rb03dhlT0m>?90??Rb03bhLL0lN3600<0l]fn
0P3ag;d30?3K_080lMRj1P3`ekT01P3_e[P0k]Nh0>kF^P3]f;d0k=Ro0>_J`080j][100<0j]Vo0>_J
`03[f/000P3[f/030>cK`@080>_K`P3/g<<0k=c50>cKa`3]g<X0kMc<0>kMc@3^g<h80>_Nc@P0kn;?
0P3`g/X20>oMb@@0k]c8103_gLD40>kLa080lMbo00@0l=^n0>oJ_@3]f;/0k=Nj0P3[e[T09P3]d[L0
k=6d0>cA]03[d;80jLn^0>S>Z`3XcZT0ilfX0>S<Y`3WbjH0i/ZU0>C8X`3Saj80hLFP0>34W`3O`ih0
gK^F0=bjU@3K^I<0fKR?0=RgS03F]HX0eKB70=BcQP3E/H40e;200=:^OP3?Zg/0c:Qh0<VUM@37Xg<0
aZ9b0<>OK`32WVh0`Ie]0<2LK02nVVX0_9QX0P2kUfL0302fTEd0]I1L0;B?F`2cSUX0/HaH0:n:EP2^
RED0[HQD0:b7D`2[QU80Z8=?0:J1C@80YH1<00D0YX5=0:N2CP2VPDX0YX5:0:J1C0020:N2CP050:N1
D02XPU<0Z89C0:R2E@2ZQUH00`2YQED20:R4E080Yh=C0P2SPE@00`2RP580XGm?0:1oC00209mnB@03
09imA`2ONdL0Wg]700H0Wg]700@0Y81@0:F1D@2UPE40YH5A0P2VPU820:N3D`80Z8AD00@0ZHEE0:Z6
EP2ZQUH0ZhMG0P2/R5P30:^7E`030:b8F02]RET0[XYJ00@0[h]K0P2`S5`30;6=G@030;:>GP2cSel0
/hmO00T0/hmO0P2dT6030;FAH@080;6@H`2bTF@0/i9U0;BCIP2fUFP0]iIY0;RGJP2iV6/40;VFK080
^YM]102kV6h20;bIK`040;fJL02nVg40_Y]a0;jKL@80_iab00<0`9ec0<6NM032WgD00P33X7H01@34
XGL0a:An0<FUO`37Yh40bJV30080bZZ40P39ZH<20<f]QP040<j^Q`3?[hP0d;290=6aRP80d[:;203A
/hl80=>cS0030=6aRP3B/X/0d[:;0080dk><0P3D]8d00`3E]Hh0d[:<0=:bS0070=:bS0P0dk>:0P3C
/h`30=BdS@<0eKF>0P3I]Y030=ZgT@<0fkRB0P3H^9420=ViTP<0f[ZC00<0fk^D0=noV03O_iP01P3O
_iP20=jnU`@0gKfF0P3N_YL30=nlU080g[^C0`3M^Y8@0=^hT0P0fkRB203J]i430=ZhT`80fkVD0`3L
^YD30=bkV080fkZG0`3J^IH30=fjTP80g;VA0`3K^9030=RhT@80ekN@0`3F]Xl20=NgT0@0e[J?0P3E
]Hh20=FeS080e;B;103C/hX20=:_Q`<0dZn50`3B/8<90=6^QPH0dk280P3D/HT40=FbS080e[>=1@3G
]8h20=JcS@<0eK:<0P3D/HT20=FbRP80e[>;0P3G]8`30=BaR@80dk280`3B[hL80=>`R0<0e[>=0`3G
]8h20=ReS`P0e[J?203E]H`0103D/HL0dk260=6^Q03?[8820<j[P@040<n/PP3@[H<0cZ^30<j[P`<0
cjb40`3@[HD0103A[XH0d:f50=2]Q@3@[HD20<n/Q0@0cZ^30P3?[8@20=2]Q@80dJj600<0d[:;0=6a
RP3A/HX00P3@/8T20<n_R0030<j^Q`3>Zh40cZ^100<0cjb20`3@[H<30<n/PP@0cZ^100T0cJZ00<fX
OP3<Yg/0bZEi0<RSMP38Y7@0b:Ab0<VUL@3:YW800`36Y7@40<FSL`070<BRLP38Y7@0b:Ad0<NSL`35
XG40a:1`0<>OK`020<:NKP030<6MK@35XG40aJ5a00H0aJ5a0P36XW830<FQL@<0a:1`0P31WFd30<2L
K0<0_i][0P2kV6820;ZGH@80^IIP0P2hUEl20;VDG@030;VDG`2iU600^I=R0080^I=T00L0^I=V0;bH
I02lV6@0_IUU0;jJIP2oVfL0`9aX0080`IeY00@0_i]W0;jJIP2nVVH0_YYV0P2mVFD20;bHI0<0_i][
0P30W6`30<6MK@80_Ya/0P2mVf/20;bJJP80^iUY0`2lV6@[ooooo`00:_ooool30:MlB@@0Z7e:00<0
ZGi;0:QnC02XOT`0102XOT`20:MmB`P0Ygi:202XOT`30:Z1C@<0ZH1<0P2XOd/80:Z1C@P0[H9?202Z
PDd20:b2D0080:^1C`2ZP4h0ZGm=0:QnC02WOD/0YWa:0:EkB`2VO4`20:MmC@80YWa:00<0Y7Y80:9h
AP2PMd<00P2NM4800`2MLd40W79009]a?`0209Y`?P0E09U_?@2EJC`0U6Tl09EZ?@2DJcd0TF/l08iZ
>P2:J3P0RFLg08YU>`29I3X0R6<i08MR>025H3H0Q5le08=N=022GC<0Pehd089M<`20Fc40OeX`0080
OUT_00P0OeX`081K<@1gF2T0MePZ07IG:@1eERX0M5@[07=C;080LU8/0P1bEBd00`1aE2`0L5<[06mB
:P0206iA:@0?06e@:01gDbl0MU8^07IC;@1fDb/0Me@Z07YH:`1lFRd0OU`^085L;`22GC00Peha08AO
<P25H3<0Qf8e0080R6<f00/0RF<d08YT=@2;ICH0S6Hg08iX>@2?JCX0T6Xk095[?02EJSd0UV/n09M/
?`0209Q]@00309M/?`2FJch0UFXm0080VW0n0P2IKcd309Q^?00309M]>`2EJSd0UFXm00H0UFXm0`2B
K3d2095[?0<0T6Xk202DJSP809E[>@80TF/l0P2BK3d409=]?PP0Tfhj202EJcT309A_>`@0Tfhj0P2B
KCT01@2AK3P0TVdi099]>@2CKSX0U6lk0080UG0l00H0UW4m099]>@2BKCT0TVdi095/>02@JcL308mZ
=P<0T6/g0`2AK3P2099]>@0308m[>`2@K3`0TVhn00<0U71000D0Tflo099^?P2CKCh0U6ho09E_@002
09Ma@P0309E_@02DKSl0Tfdn0080TG8l00@0TW4l09A`?02DL3`0UG0l0P2GKc`809A_>`@0Tflo102B
KSh@09=b?@05095b@`2@LD80T75208m`@@2>Kd000P2=KSl08@2<KCh0S6]008MV>`21HSH0OF0d07eR
=@1iHC<0M5`^06iH:@1ZEbd0Ie@/069@:P1KBbT0ETDW05519`1<?R@0Bc`U040i9P0m=R@0=c8O030]
700]:a`0:b`N02`/800];b80:B`K02P[6P0X:Q`09bTL02DW700T9Ad092DO02<T7P03024T7@8082<L
0`0O8Q/201dP6@807R4J100O8Q/0200T9a`08bHK028U700Q91d07b4L01hP7@0M7a`071hM0`0I7a/2
01PN6P@05adI01`071hM01/M6P0K7AX071hI01hQ6P0Q91/092LL02DX7@0W:A@0;bhJ03Lf8@0o?BH0
@clV048l8P0n=ad0>S<G03ha7P0n<b40>S4P034[7@0V91P07QlG01dP6@0M8Q`09b<J02PT6`0Z9Qd0
:bLN0P0/:1l00`0[9ah0:RHM02DV7P0202@U7@0302<T700R8a/08B8J0080824I400O81X08`0I6aH0
71hI020Q6`0Q8AT08AhE02@P5@0Z9Q/0<B/O04<^6`1C?R<0HdlZ06YE9P1VD1h0IDdM06iB:P1gFcH0
PFHg08eb@`2DN4P0UWQ60:61CP2^SEP0YHA?09=`>P1QCcT0@C@T02dZ8@0W;B/07RPY02<Y:@0Z;2L0
:BHO02DV800V9b40:2TS0080:BXT00H0:2TS02HW8@0U9R0092@R02DU8`0W9bD202PX9P0302LW9@0V
9R@09BDS00P09BDS02L09bPR02HW8@0U9R009BHP02HW8@0Y:R@0:b`V02`]9`0n<b40@CDU040g:00k
<bH0<bdQ02dY800_:b80<RlX030[9@0a;B@0=BhV03P_9P0k<BL0?c<W044c9P12=2L0CC`X054o:@1D
@R`0F4@/05M1:@1F?R@0DcTN054g701D@bL0I4d]07=C;01fDBD0M4lS06m>9@1OAB800P1?>Q/0401;
>RH0BcTS04Xh8P1=>B40DS`T05Y2:01QAb`0ID/`05I0:@1C?BP0CSTT04Pf8P17=2<0AcHV04Ph:@1:
>R/204Xk9P80BCXU00L0Bc`W04dn:@1?@2/0DD8]04hn9`1<?2D0Bc/T0080BSXS00D0C3`U04lo:01@
@2T0CcdW04hn9`0204dm9P@0C3dV01T0BclW04a0:01?@BL0DT8X05A39`1HA2T0FTDX05]6:@1EB2H0
ETTW05I9:@1GBB`0ETP]05A6;01A@R/0D44Z05=3:@1B@RP0DD4X04lo:01>?BT0C3/Y04/j:01;>RX0
>cHR0080>SDR00<0>C<S03Pb900g<BD00P0f;bD303Da9@80=30T0`0c;b<203<_9P80<RhU0P0a;B@2
030/8`P0=S0T00h0?S8T03`c900k<BD0>C4V03H_9@0c;bH0<BhU030]9P0_:R@0;b/R030/8`0a;B80
<RhR03<`8@80=34P0P0f<2@303D_8`<0=2hR0200<RdW038^9@0c;2@0=2/R03L]8`0l<2@0@38U048d
9`10<240@C4R048b8P12=B80A3PR04Hj8P16?2<0AcdR04Xj8`1<?2D0CShW04lo:01@@2T0CclX04hn
9`1<?2D0D40`04hn;P18>bX0A3TW044i9P10>BH0@CXW048m:@80@C@T00T0@SDU04<f9@14=b@0Ac/U
04Tm9@1;?bL0C40V04`l9@1=?BH00P1>?RL07@1<?2D0BCTR04Hf7`14=1d0B3PQ04Ti8P1;>b80CCdS
0511901B@b@0E4DT05E69@1C@RP0DT8X0592:@1@@BX0C40Z04Tn:P14?2L0@c/X03h`8`0o<B@0?c8R
040c8P12=B@0@cHS04Di8`16>R@0BClT0080BShT00d0CClU04hn9@1??BD0DCdU058n9P1@@RP0D48W
05519`1B@BD0E4<U05U69P1MBBP0Gd/Z0080IdXX00@0J4/Y06U<:P1[CR`0KE0^0P1/Cbd07P1dE2d0
MED^07EH<01fFS80MEda07AM<@1bGC00LE`]06YH=01XE340IU8]06YD;@1`FC00LeXa07=G;`1`EBX0
LETe079H<`1cFS80N5db07iR<P26J3@0S6dg08m`>@2FO4<0V7e609YoB02MPTd0WX9@09j2DP80WX9C
01P0WXA90::8C`2TReD0XhQI09j5G02LQ600WXMX0:69K@2SSV<0XXeR0:>>H@2VTF@0[9EY0;>MKP2h
XW<0_:Af0;:PLP2eX7<0]j9c0;ZTM@2kXg<0_:9a0;^OK@2jWV`20<BTI`040<FUJ036YVT0ajMZ0<RX
J`80bJU/0P3;Zg003P3:ZVl0b:Q]0<FUJP31XFH0_YiS0;^KH02hUEd0]Y=K0;BAE`2cTE@0/Y1A0;:@
D02cTE40]9=@0P2kV5P0102lVET0_IYJ0;jKF`2oW5`20<6NGP<0_9YK0P2lVUX0102kVUL0^iYE0;ZI
DP2jVE820;:@D`80/i5D00d0]I=F0;RFF@2jV5/0_9YM0;jMF02mW5L0_9]H0;ZIEP2gUU<0]99B0;6?
C`2_SDd0ZXQ800<0ZhU90P2ZR4P20:V7A`080:Z7@`2/RDD0[ha80;:?B`2fTdl0^YMC0;fJEP2oW5P2
0<2NGP80`ImO1032X600202nW5`0_ieM0<2NGP31Wel0`j5Q0<BRHP35Xf<0aZAT1032Xf840<>TH`0@
0<BUI@33Y6@0`J9Q0;jOGP2jVeP0]iUC0;BFCP2cUDd0/iYH0:68B02CNSX0TgTl09Ek@02BN3l0Sg@m
091e?P80T7Hm00h0SgDl091f?@2AMch0TgU009Il@`2GOD@0WH9;09n4C@2QQTl0Y8UB0:N<E@2YSUL0
[95J0:fBF`80ZHmL0P2ZT5d30:^AGP0A0:bBG`2ZTE/0[IAN0;6EH`2dUFH0]YEX0;ZGK@31WW@0bJ=l
0<^[Q@3@/8X0eKF?0=JfT03D]8h0dk>=0=FeS`3H^9800P3G]X/0103F]HX0eKB90=BcR03C/XL20=:a
QP0H0<b`P@3:[Wl0bJen0<R/O@36ZW/0_j=d0;BHJ@2[Sf00Y8YA0:>8D@2/TE`0^im_0<BWN`36ZH40
bjf70=>eT@3H^Y@0f[bH0=boW@3OaJ80h/ZX0>K?[`3Yd[<0jMBe0P3ZfKd20>_J_P080>cK_`3]g<00
k]g10>kM`@3_g/80l=o30?7Pa03bhLD20??RaP040?;Qa@3`gl<0kmk20?;K^`<0lMZj0P3`fKT20>oH
^080kMBf1P3^eKL01P3^e;T0kMFi0>kF_03/ek`0jmNn0>[H`080jMW20P3Zf<020>_I`@040>cJ`P3]
fl<0kM_30>gK``80jmc500H0k=g80>cMbP3]gLd0kMg=0>gMcP3^g]440>cOcP@0jmk=203^hLh40>kL
aP80kM_50P3/f/@00`3^gL<0kMc20>gL`P020>cK`@80jm[000L0j]Vo0?7H^@3`ekP0kmJg0>gD]@3/
dk@0j]6b0080jM2a02P0kM2`0>c?[`3[cZ`0j/jY0>S<Y@3VbZ80iLVQ0>C9WP3VaYd0iLFL0>?3VP3Q
`IP0gknF0=fmU03L_9<0fk^B0=NdRP3F/hT0eK>60=>aQ03A[h40cjem0<j]NP3=[7T0c:Qf0<^WM@39
YG<0aj=a0<BPKP32WV`0`9aZ0;nKJ@2kUfD0^YIT0;VEH`2hU680]i=Q0;JBH02eTEl0]91N0P2_RUH0
102^RED0[HQD0:b7D`2[QU820:Z5D@040:V4D02XPdl0YX5=0:AoB`80Xgi:00D0Y7m;0:F0C02VPDX0
YX5:0:J1C0020:N2CP040:N1D02WPE80Z89C0:R2E@80YX9B0P2UPE430:B0D0090:=oC`2OOE00Wge@
09ilCP2NO4`0WGa909akAP2KNTD0VgY400@0VgM3102LN4@20:5mC@80XWi>0`2SOdl20:B0D080YH5A
00<0YX9B0:N3D`2XQ5@00P2YQED01@2WPe<0Z8AD0:V5E@2ZQUH0ZhMG0080[8QH00@0[HUI0:f9E`2]
REL0[HUG0P2^RUP30:n;F@/0/HeK0P2bSU`30;>?G@80/8iP00@0/HmQ0;>AH`2dTV@0]YAV0P2gUFL2
0;JCJ@80]iAZ102hUF/00`2hUVT0^IMZ0;VGJP020;VGJP<0^YQ[00H0_9Y]0;fKKP2mVfh0_Ya_0;nM
L030WW420<6OLP040<6QNP33Xg`0aJEn0<NWP080b:R100H0ajN00<JVO`3;Zh@0bj^40<b/Q@3=[HH2
0<j^Q`80cjn8203?/Hd80=6aRP80d;29103A/HX20=:bR`T0d;29203A/HP20=6aRP80d[:;103C/h`3
0=NdSP<0f;F?0P3I]Y030=JfS`80ekN@0`3H^9480=fmUP80fk^D103L_9D20=^kU080g[^C0P3M^Y83
0=biT@030=^hT03J]hl0f[N?00h0f[N?203J]i480=VfT0<0f[NA0P3K^9830=biT`80g;^H0P3K^YL2
0=ZiUP80fKRE0`3L^I420=^hT0<0f[N?0`3H^9420=NgT0<0e[J?0P3G]i020=JfS`80eKF>0P3D]8d2
0=BdR`<0dk>:0`3B/XT20=2^P0<0d:j10`3@[H<90=2]Q@<0dk281@3B[hL30=BaR`<0eK:<103F/hd2
0=FbS0<0e;6;00@0dk2:0=BaQ`3D/HL0e;670P3E/XP30=JcR@80e;690P3C/8P20=:_Q`80dJj6203C
/8P20=FbS0<0e[>=0`3G]8h80=JfS`P0e;B;00@0e;670=>`QP3A[X@0cjb20P3>Zh400`3?[880d:f3
0<j[P`020<j[P`<0cjb4103@[HD20<n/Q0<0cZ^300<0cJZ20<j[P`3>Zh<00P3>Zh<40<n/Q080d;29
103?[hP20<j^Q`<0cZ^10`3?[8820=2]P`80cjb20P3>Zh40303=ZX00c:Uo0<bYO`3<ZGl0c:Mk0<^V
N@39Y7L0b:Ad0<NSL@38Y700bJI`0<ZWL@<0aZAd00<0aJ=c0<BRLP34XW800P33XG401P38Y7@0aj=c
0<JRLP35XG40a:1`0<:NKP<0`Ie]2034X7030<FQL@<0a:1`0P33Wfl30<2LK0<0_i][0P2nVVX20;ZG
H@@0^IIP0P2hUEl20;VDG@030;VDG`2iU600^I=R0080^I=T00@0^I=V0;bHI02lV6@0_IUU0P2nVVH0
0`2oVfL0`9aX0<2LJ0020;jJIP80_IUU0`2lV6@0102kUf<0_i][0;nKJ`2oVf/20<2LK0<0`Ie]0`2m
Vf/20;bJJP<0^iUY0`2lV6H[ooooo`00:_ooool80:QmBP@0Z7i<0P2WOD/20:IlBPP0Ygi8202XOT`3
0:Z1C@<0ZH1<0P2XOd/80:Z1C@P0[85>202[PTh01P2]Pe40[89@0:^1C`2ZP4h0ZGm=0:MmB`80YWa:
00@0Y7U>0:IkD02XOE00Z7i>0P2XOT`0102UO4P0XWU309mf@02OMT8209ie@@0309ed@02LLcl0Vg8n
0080VW4m01@0UFTl09EZ?@2FJch0UF`n099/?@2?Jc/0RfTi08UW=`2:IC/0RF@j08QS>@27HSP0QF0f
08AO=@23GS@0PUdc08EP=P23GS@0PE`b07mJ<080OUT_00P0OeX`081K<@1gF2T0MePZ07IG:@1eERX0
M5@[07AD;@80Le<]00@0LUD]075D;01aE2`0L5<[0P1_DRX206iA:@80MU8^00`0ME8/07IC:`1gE2X0
NELZ07aJ;@1nG2h0PE`_089M<023GS40Q5lb08EP<`27HSD208QS=P80RF<d00@0RV@e08aV=`2=IcP0
SfTj0P2@JS/00`2EJSd0UV/n09M/?`0209Q]@00309M/?`2FJch0UFXm00<0VFlm0P2HKS`309M]>`04
09=X>`2DJC`0U6Tl09AY?0<0UFXm00@0UV/n099/?@2BK3d0TV`m0P2AJc`3091Z>`<0TfTg0P2DJSP;
09E[>@05091Z>`2AJc`0TV`m09=]?P2DKSl00P2CKCh00`2BK3d0Tfhj09=^>P0609=^>PP0UF/i0`2D
Kc/209=^>P@0TVdi102BKSX409=_>`@0TF`h102BKCT208mZ=P80T6/g0`2AK3P0302BKCT0Sf/k091/
?02BKSh0Tflo09A`@02CKcl0TVhn095]?@2CKCh0U6ho09E_@080Ug5200<0UFm009A^?`2CKCh00P2@
LC/0102AL3/0Tflk09=_>`2DKc/209I^>`P0U6lk00@0U71009=_?`2CKcl0Tflo0`2BKSh00`2AKCd0
Tg8m09=b?@0>09=b?@80T7520P2?L44208i_@080SFho0200SFa108QW?022HcL0OV4e07aQ=01hH380
Le/]06eG:01ZEbd0Ie@/069@:P1JBRP0ETDW05519`1=?bD0C3dV044j9`0m=R@0=S4N02l/6`0/:Q/0
:R/M02d]8@0^<2<0:RdL02T/6`0X:Q`09bTL02DW700T9Ad08b@N028S7@<08B@M0P0P8a`301lR6`80
71lH0P0M81T301hQ6P0901lR6`0T9a`08bHK028U700Q91d07b4L01hP7@0M7a`071hM00<06AlK0P0H
7QX401LM6@0L01`N7@0K7AX06adJ01`N6@0N8AX08B@K02@W700U:1d0:2/F02d_6P0c=Al0>SXR03dk
8P0o>b00?CLM03/f6@0n<Ah0?S<Q03Xa800b;1h09bDI01hO5`0M81T07B8L02HR6@0W8aX0:BDL02/W
7P80;2PO0P0[9ah01P0U9Qh092DM02@U7@0S91`08R<K024R6P80824I400O81X08`0I6aH071hI020Q
6`0P81P08AhE02<O500Y9AX0<2XN03h[6P1?>b80GddY06EC9@1RCQ`0HD/L06U@:01bF3D0O64b08Y_
@02BMTH0TgE309inB`2/ReH0YXE@09Ic?@1WECl0A3LW02dZ8@0V;2X07RPY02<Y:@0Z;2L0:2DN02DV
800V9b409bPR0080:2TS00/09bPR02HW8@0U9R0092@R02DU8`0W9bD0:2PV02TY9`0X:2H09bLU02HV
900802DU8`0W02LX8P0V9b409RLQ02HW8@0X:B<0:R/U02`]9`0^;bT0?c<M04Di8`18?B/0@CPY03L_
900`:B40;RTS034/:00a;2H0<RhU03D^9P0h;bH0?38X040d:013=BP0A3HY04hl9P1C?RT0ET8Z05M1
:@1F?R@0E3XO05Hk7P1G?1l0EdP[06A=;@1`Db/0O5LZ08EO<024HSD0LE@/0080Fd<O0180CS`V04hi
901=>B40CcTQ05Dm8`1L@RL0I4T/06Q=<01G@BX0E3hY04hi9017=B40AS<R04He9@18>2T0Bc//04Tl
:@18>bP204Lj9`0404Pk:01:?BX0C3l/04e0;@80C3`U0P1=?BH204hn9`80CclX0P1B?BP0101??BL0
CShW04`m9P1:?RH204To9P0P04Tn:01;?bT0C40X04m19`1B@RP0E4<W05M3:01HABL0DTPU05=99P1C
B2P0E4T[05=8;01AAB/0Cd<[04e1:@1B@RP0DD4W05109`1>?RL0C3/W04Xi9`19>2H0B3LW03Xe8@0j
=B80>C@Q03Pb8P0g<B<0=S0T03H_9@0e;R@303Da9@80=30T0`0c;b<203<_9P80<RhU0P0a;B@2030/
8`<0=S0T0P0g<BD203Pb9P0?03Tc9`0n<R@0>c8S03X`900h<2D0=BhT038^9@0`;B@0;b`U02lZ900_
:b80<2`S034]8P0b;R80<c0Q0080=34P0P0f<2@303D_8`<0=2hR01d0<bhX038^9@0c;2@0=2/R03L]
8`0l<2@0@C<V04<e:015<R@0AC<U04Dd9015=R<0A3PR04@j8@13?280@c`P04Xj8`1<?2D0CclX0551
:P1B@R/0D40Y04hn9`1=?BH0D40`04lo;`1;?Rd0B3d[04Dm:P0204<l:@0<048m:@13=RH0@cHV04<f
9P13=RD0A3LT04Di8`17>b<0BCdU04Xn901;>b@0C3`U0P1>?RL0101=?BH0BSXS04Hf7`14=1d204Ti
8P0>04/k8P1=?B<0Cd0S05528`1CA2<0E4DT05919`1A@BL0D40W04ho:01;?bT0B3dY04@l9`13>bP2
03hb900703hb8P0o=280@3DS048g8`14>B<0AS/U04To900204Xn900304`n901=?B@0CS`T0080D3`T
01H0D48X04m19P1@@2H0DT4U05A39@1IARH0GDTX05i::@1XBbT0ITTW06M::01ZCB/0KU4_06mB<01]
D2h0Jdh/06m>;@1aD2d0LU@`07=G<01cFS40Le``0P1aG2d0<@1/G3P0JeTe06UG<@1]FS80Ledd07MP
=P1fGC@0Le/_07AK?01eFcX0MU`g07YO=020I3@0R6Xd08m`=`2BM3P0UG]209MlA@2JOdP0WH9=09n3
D@2PQ5@0X8AE09n3E02OQ4l0XXQE0:J<F`2TS5h0XHYP0:6;I02SSfX0Yi=`0:FFJ`2VUFX0YYEY0:^I
J`2dWg00^ZAc0;jVMP2nYgD0^JAg0;ZUMP2mYgP0`:Qh0<:XM`30Y780`:9^0;jPK039YfP00P38YVL2
0<NUIP80aZAU0180aJ=T0<VWJP39YfX0bJMZ0<RVJ@36Y6L0`j5T0;nMH02mVeh0^IIL0;NDFP2eTeH0
]99C0;>AD@2dTe00]IAA0;JED02oW5`30;jKF`050;nLG031WUh0`j1P0<BQH@2mVe`00P2mVe/01`2n
W5`0_YeJ0;jMF02lVe@0^i]B0;ZJD@2cTE@00P2dTUD03@2eTeH0]YAG0;RFF@2iUeX0^YQK0;jLE02m
Ve<0_9YC0;ZGD`2gU580]95A0;:?C`2`S4h0102/RTX0302ZR4P0Z8I60:J4A02UPd<0Y84m0:J3?`2Z
Qd<0[X]70;>@C02hUE40^iQD0;fJEP80_ieM00D0`9iN0<6OG`31Wel0`9iN0;nMG@020;jLG0080;nM
G@30WUh0`ImO0<>QH@34XV80aJ=S0<JTI031XV430<:SHP<0`jAS0180a:ET0<>TI032Xf80_j1O0;bM
FP2iVeD0]YQ@0;BFC@2cUD`0[iID09j5A@2AN3P0TWPk09Aj?`2AMch0SW<l08md?@2?MC`308id>`0<
091f?@2BN3l0UG]209Il@`2NPDT0Wh9:0:64C02TQdl0Z8]C0:^>EP2]T5P0[Y5I0`2[TEh20:bBG`<0
[I=P0100Zi9L0:jEG`2aUF<0]9EV0;FDI`2jUfd0`Yme0<ZTO@39ZhL0c[2<0=>eT@3D]Y80d[B@0=6c
S`3C]I40e[RD0P3G]8X0203F/hT0e;670=>`QP3B[hD0dJj40=2]P`3;[gl0bJem0P38[7`05036ZWX0
_Z9b0;:FIP2XS5`0XXQ=0::8C`2/TEX0_:1^0<FYNP37ZX00bjj60=>eS`3J^Y@0g;bF0=foV`3Qa:80
hlVV0>O?[@3Yd[80jmBd0P3[f;X20>cI^`0=0>gJ_03^fkd0kmbn0>oL_P3`gKl0kmk00?3O`@3ah<80
l^730?7P`P3`gl40k]fo0>gL_P020?3H]P80kmNe0`3^e[@00`3]eK<0j]6c0>_B]0020>_B]0<0k=>e
00T0kMBf0>kD^@3]eK/0k]Jl0>cF_P3/f<00j]S20>WHa03ZfLD00P3YfL80103Zf/<0jm_40>cLa@3/
g<D20>gMaP80j]k800H0jmk;0>_Nc@3/glh0k=o?0>cNd@3]gm830>gPc`80k=o>0`3[g/d80>gPc@<0
km_30P3^f/830>gI`@80kMW000@0k=Ro0>_G_P3Ze[d0j]Jm0P3YeK`20>kA[`0W0>c?[@3[cZ`0jLbZ
0>O:Z03VbJL0iLRV0>_;Y@3ZbZ@0j<RQ0>K6W@3TaIT0hL:D0>31T`3O`940gkf?0=jlSP3L^X`0f[R:
0=NeQ`3E/hD0e;:40=>aP`3@Zgh0cj]k0<fYN@3;YgD0bJEa0<NTKP35XVX0a:5Y0<6MJ@30W6P0_i]W
0;fII@2kUf<0^IEQ0;RDH02gTel0/hmK0080/XiJ00<0/HeI0;2<F02_ReL00P2^RUH30:V4D080Z8=?
102WPTh02P2UP4`0Xgi:0:9mB@2QO4P0XWe90:=nBP2TOd/0Y7m80:F0B@2UP4/20:F0C0040:J0C`2V
P540Yh5B0:N1E0<0XWi>0P2QODd30:1lC080WG]>00L0W7Y<09]iB@2JNDH0VGQ309Qg@P2HMd40V7A0
00<0VGE10`2JMT80102KMd<0WWY:09ijBP2NNTX209mkB`D0X7a<00<0XGe=0:9nCP2SOdl00P2TP500
1P2UPE40Xgm?0:F1D@2WPe<0ZHEE0:Z6EP80ZhMG00@0ZXIF0:^7D`2[Qe<0ZhMC0P2/R5@30:f9E@P0
[XYF0P2_ReL30;2<F0<0/HeI0P2`S5`01P2aSEd0/hmO0;B@H02eTF40]Y9R0;NCH`<0]95W0P2eTVP3
0;JCJ@P0]YAV00H0^YQZ0;^IJ`2kVF/0_9Y/0;fKK@2nW6h20;nMK`050;nOMP31XGP0`j=j0<FUO036
YWd00P35YG`01`34Y7/0b:R10<VYPP39ZH80bZZ30<^[Q03<[8D00P3=[HH80<f_Ra00cjn82@3>[XD8
0<n_QP80cjn80P3@/8T20=6aRP80d[:;00@0e;6;0=FbS03E/X`0eK:<0P3F/hd20=NdSP<0e;B=0P3E
]Hh30=JfS`P0fKVB00<0ekN@0=RhT@3I^I800P3J^Y<00`3I^I80f;RA0=NgT0030=^hT080f[N?2`3I
]Xh80=ZgS`P0fKJ@203J]i430=^eSP80g;J?0`3M]i030=^jU`80f[VF0`3I^9D30=^hT080f[N?0`3I
]Xh30=RhT@80ekN@0`3F]Xl20=NgT080e[J?00@0eKF>0=BdS@3C/h`0dk><0`3C/hX20=:bR@<0dK68
0P3@[g`00`3@[Wh0d:j00=2^P@020=2]P`030=2]Q@3A[XH0dJj600L0dJj6103B[hL20=6^QP80d:f5
0`3C/8X20=BaR`<0eK:<0`3D/H/20=>`RP<0dZn900@0dk260=BaQ`3D/HL0e;670P3E/XP20=JcR@<0
dk280P3B[hL30=6^QPP0dZn70`3E/X`20=JcS@<0ekB>203E]Hh80=BdR`040=BaQ`3C/8H0dJj40<n/
PP80cZ^100@0cjb20=2]P`3=ZX80cJZ20P3>Zh<30<n/Q0030=2]Q@3?[8@0cjb40080cZ^30`3=ZX80
0`3<ZH40cJZ20<j[P`060<j[P`P0cZj70P3=ZX020<j[P@<0cjb200L0d:f30<n/PP3>Zh40cZ^10<fZ
P03<ZGl0bjQn0080bZMm00T0bjIi0<ZVMP38Y7@0aj=a0<NSK`38YFl0bJI^0<ZWK`37YGD00P36Y7@0
0`35Xg<0a:9b0<>QL@020<:PL080aZ9b00@0aJ5a0<BPL033Wfl0`im_0`32WVh80<>OK`<0aJ5a0P34
X7030<>OK`<0`9a/0P2oVf/30;jJJPD0^IIP0`2hUEl20;RCG0030;RCGP2hTel0^99Q0080^99S00L0
^99U0;^GH`2lV6@0_9QT0;fII@2nVVH0_i]W0080`9aX0P2mVFD20;bHI0<0^iMS00@0^YIR0;jJJP2n
VVX0_YYZ0P2oVf/30<2LK080_I][0P2lVVX30;^IJ@040;ZHJ02lV6P0_9QX0;bHJ2_ooooo000Zoooo
o`H0Z7e:0P2WO4T00`2YOdd0Z7i<0:QnC0020:MmB`80YWa:00<0YG]90:MnAP2WOTH01P2WOTH80:Qn
C0<0ZX5=0`2YP4`20:QoB`P0ZH1<202/PDh80:f4D080[H=A00X0[89@0:Z0CP2XOT`0Yge;0:IlBP2U
NdT0Y7U?0:IkD@2XOE80ZGm?0P2YOdd00`2UO4H0XWU109mf?P0209mf@00409ie?`2MM3h0W7<m09]b
?080VW4k01@0UFTl09EZ?@2FJch0UF`n099/?@2?Jc/0RfTi08YX>02:IC/0RF@j08QS>@27HSP0QF0f
08AO=@23GS@0PUdc08EP=P24GcD0PUdc081K<@80OUT_00<0OeX`081K<@1hFBX00P1gF2X00`1fEb/0
MED/07AD;@0207=C;@D0L5<[0`1_DRX03P1fDRh0ME4]07EB;01eDRX0Me@Z07UG:P1lFRd0OE/]085L
;`22GC00Peha08AO<P25H3<0Qf8e0P28HcH208US=00908YT=@2;ICH0SFLh08iX>@2?JCX0T6Xk09EZ
?@2FJch0Uf`o0080V6e000<0Uf`o09I[?P2EJSd00P2HKS`309M]>`<0UV`j0`2CJ3/00`2DJC`0UFXm
09EZ?@0209I[?P<0TV`m0P2AJc`3091Z>`03099X=P2CJCL0TfTg0080U6Xh0P2EJcT00`2FK3X0UF/i
09E[>@0609E[>@0308mY>P2@JS/0TV`m00<0U6ho0P2BK3d809=^>PP0U6Xh00@0U6lk09=^>P2CKSX0
Tfhj0`2BKCT2095/>0@0TG0k102@KcX0102@JcL0TF`h099]>@2BKCT209A_>`0309E`?02FLCd0SfXf
0080SfXf0P2@JcL3095/>00;08iZ>P2@K3`0TVhn09=_?`2DL400Tflo099^?P2AKCd0Tfdn09A^?`2E
Kd000P2GLD800`2EKd00U6ho09=]?P02091a>`04095`>`2CKc/0Tflk09A_>`80UVhk202DKc/209A`
@080Tflo0P2BKSh2095]?A00Tg8m102?L44408i_@00P08e/@@28Ic`0PV<g07iQ=@1lHC@0N60b07=K
;@1]EbP0JUL]06MD;01QCbT0FTXX05E49P1A@BL0CT0V04dn9`11>RL0?CHT03Ha7P0^:aX0:bTJ02X[
7@0];B40;S0S02X]700Y;1/0:2XL02LY700U9a`092DM02<T7P0R8ad3024T7@8082<L0`0O8Q/0100K
7QL071lH01`O600L7aP201dP6@807R4J00P092LL02<V6`0R9A`08B@M01lQ700N81d07AlL01`N7@<0
6AlK0P0H7QX401LM6@0L01`N7@0K7AX06adJ01`N6@0N8AX08B@K02@W700U:1d0:RdH02`_6P0`<Q`0
=SHN03Tg7P0j>Ad0?3PM03`h6`0m<1d0?C8P03/b8@0c;Al09bDI01lP600M81T0724K02DQ600W8aX0
:BDL02/W7P<0;2PO00L0:bLN02DV7P0T9Ad092DM02<T700R8a/08B8J0080824I400O81X08`0J71L0
7AlJ020Q6`0P81P081dD02<O500X91T0;bTM03`Y6P1<>R80GT`X06=@9@1PBa`0GTTL06I>:01_EcD0
N5d^08I[?02?Ld<0TG=109]kB02ZRE@0YXE@09Qe?`1[FD<0ASTY02dZ8@0U:bT07RPY02@Z:P0[;BP0
9b@M02@U7`0U9R009bPR0080:2TS00H09bPR02DV800T9Al092@R02DU8`0W9bD302TY9`0302PX9P0W
9bD09BDS00L09BDS0P0W:2809@0V9b409bPR02PY8`0[;2H0;RlY02l`:P10<QP0Ac/S04e0;@19?Bd0
>c4U034X8@0_:280<BTV034/9P0b;RD0=RlW03T`9`0m<bT0@CDY04@f:@15=bX0Cc/S058n9P1G@BT0
FD4W05Pn8`1K@2<0H4DX06M:;01LCC00Hdl/071C:@23GBh0Ufll09]eAP25I3T00P1WBb<04`1F@RX0
E40X058l901B>R00EC/P05]08`1QART0IdX/05Q2:`1D?RT0CCPS04Le8@15<R40ASDU04Ti:P1;>b`0
Bch[04Tl:@18>bP00P17>RL01P18>bP0BSdZ04/n:`1;>b@0CCdV0510:@80DT8[00/0DD4Z04lo:01=
?BH0E3hY05<m:01B?BP0CShW04dn9`19?bH0Ad0V04Ho9@0204Tn:P0L04/o:@1=@BT0D48X0592:01D
@bT0E4<W0557901BB2D0DdPX05=8:P1BAb/0D4@Z04i2:P1<@2P0DD4W05109P1>?RD0C3`U04Xi9@18
=bD0AcHT04He9@0j=B40>SDR03Td8@0h<R80=c4S03H`9080=BhT0`0e<BD203@`90<0<blS0P0c;bH2
038^9@80<BdT0P0`;2<2034[7`0D038/800d;R80=BlS03H`900g<BD0>38V03da8`0j<B80>BlS03L_
900d;B<0<BdT02l/8`0_;2D0;bXT02l[8P0`;2<0<BdR038^8P0c<24203@a8080=S0T0`0e;b<303@^
8P0803<^:00b;RD0<R/S03<Z8@0f;280?30T048d9`15=bX204/e:00904Pg9`17>2D0A3TS044j8010
>R00?c/N04Xj8`1<?2D0D40Y0080Dd</00<0DD4Z04lo:01=?BH00P1<?2`01P1:?B`0BCh/04Dm:P12
>bP0@3TV03hi9@80ASTY02d0ACPX04@g9P13=R<0A3PR04Di8@17>b<0B3`R04Ti8P1;>b@0CCdV04lo
:01>?RL0Bc/T04Lg8015=Ah0BSXS04/k901<?2<0CCdS04m08`1A@R<0DT<R05=48`1A@2H0CclU04hn
9@1<?BH0B3`V04Hk9`14?2L0@c/X03he9P0m=2D0?C@S03de8P0n=R<0@CTT04<k9015?BH0BClT04Xn
9019?B<0BcdS04`l8`1=>b<00P1?>b<02@1?@BL0Cd4V05109P1B@BD0E4<U05Q59@1LB2L0GTXY06Q;
:@0206I99`0S06Y=:`1_DS00LE@b06iA;`1ZCB/0JdT]06e<;@1^D2h0L5@_075H;`1aFRh0L5//071L
:P1`H3`0KEdi06iL=P1bGcL0NF<j07aW?01kI3X0NF8f07UP@P1iGT00NElj07eR=`22ISH0RV`f099d
>02EMcT0TWPo09Ai@P2HODH0W85<09j2D02PQ5@00P2PQ5D06@2MPUL0WhMK0:B<H02USV80XhiQ0:>A
H`2WUVP0ZiY/0:RLM02XVg40ZIY_0;6PM02kYWL0`:Yi0<2YM`2oYG80_JMh0;nYN032ZWX0aZak0<JZ
N035Yg<0`J=]0<2QJ`38YFD00P37Y6@20<JSH`<0aJ9R0P36XVH04037XfL0aZ9V0<FQI@33Wf<0`9aP
0;nKG`2jUed0^IMJ0;NEF02fU5D0]I=C0;JEDP2gUU40^9MB0;jKF`2mVUX20;bIF@050;fJFP2oW5`0
`IiN0<:OG`2mVe/00P2nWEX01P2oWU/0`9mJ0;nNE`2nWUD0_9aA0;ZJC`80]I=F0P2fU5L20;NEF080
^9II00H0_i]?0;jJCP2lV4h0^YE?0;RCC`2fT5420;B>D0<0[Xa<00l0[8Y:0:Z8B02VQ4@0Xh510:5o
?`2NNcL0XGhj0:F2?P2ZQd<0/8e90;FBCP2jUe<0_9UE0;jLG02oWEd00P30WUh0302oWEd0_I]K0;^I
F@2jV5P0_YaL0;nMG@30WUh0`ImO0<>QH@34XV80aJ=S0<JTI080`J9O0P32Xf020<>TH@80a:ER00h0
`J9Q0<2QGP2nWe`0_9iH0;VKD`2fV4l0]9M;0;>FBP2]U580W8=3091g=`2AMcX0U7Xo091f?@80SG8k
0100SW@k08ec>P2=LcX0SG<j08me?02AMch0TgU009Ek@P2NOdH0Wh170:62B@2UQTd0Z8U@0:^<D`2^
SeH0[i1G0`2]Tf030:jDH@80[iER0100[9=M0:nFH02bUV@0]9EV0;FDI`2kV6h0`j1f0<bVO`38[8L0
cK6<0=:fT@3C]i80dKF@0=2dS`3B]Y40eKVD0P3F]8L01`3E/hH0dk640=:`P`3@[X40cjf00<j/O`39
[G/00`38[7X05@35ZGL0_J5_0;2DHP2VRUP0XHM<0::8C@2/TEX0_:5/0<JZNP38Zgl0bjj60=:eS@3K
^I<0g;bE0=noV@3Ra:00iLRV0>S>[@3Zd[00k=>d0>_F]`030>cG^0030>gH^@3^fKX0kmZk0080l=^l
0P3_gkh01P3`h;l0lN700?3P_`3^g[d0kMfl0>_K^P80kmFd0P3^e;<30>gC/P040>cB/@3Xck40j<na
0>W@/P80j]6c0`3[d[@01P3_eK`0k]Jn0>kF_P3]el00k=O20>_Ia@80j]W70P3XfL@0103Yf/D0j]_6
0>_La`3/gLP20>gNb@060>_Ob@3[g//0jmk;0>cOcP3/gll0kMoB0P3]gm@20>kQd080kN3?00@0k=o>
0>_Nc@3[g/d0jmk=203[g//30>oI`@80k]S00`3]ekl20>_F^`040>[E^P3Ye;T0j=>h0>OB]`80i]6f
0240j/bX0>W;Y`3WbJD0i/RT0>?5X@3Ra:00h<:N0=o1W@3S`9P0h[nG0>2mT`3N_8l0fkV;0=VgQ`3G
]HD0e[F20=FaO`3D/7h0dZil0=2/NP3=ZGL0bjMe0<VUL`38Y780aZ1_0<FPK033WVX0`IaW0;jIHP2l
V5h0^YIJ0;VEF@2dT5`00P2cSe/00`2bSUX0/HeI0;2<F0020:n;E`040:Z6DP2YQE40ZHEA0:R4D080
Yh=?0P2VPTh30:=nBPH0XWe900L0XGa809mjAP2NNDD0WWU509mjAP2PNdL0XGa80080XGa500@0XGa7
0:9mB@2RODT0XWa;0P2SODh00`2SOE00Wg];09mkB`0209mkB`80WWY:0P2MNDT0202LNTd0VgU<09]i
B`2JN4P0VGQ509Qg@P2GMT40UgI00P2GLcl209Qd@080VGE10P2JMT8309ahB080WGU90`2NNTX01P2L
N4P0WGU909eiB@2NNTX0Wg];0:1lC080XGe=00@0X7a<0:9nCP2UPE40Yh=C0`2YQED0102XQ5@0ZHEA
0:V5D@2YQE420:Z6DP<0ZhMC202]RED30:j:EP80[h]G0`2`S5P01P2_REP0/8YI0;6;FP2bS5/0/heL
0;F?GP80]Y1O0P2bSfD20;>@IP<0]95W00<0]I9X0;BBHP2dTV80102dTV820;>AH@060;RFIP2iUfL0
^IMW0;ZHJ02kVFT0_9YZ0P2mVf/0102mWW80_j1d0<6RMP33Y7P20<BUN@060<>TN032XgL0ajN00<NW
P038Z840bJV20P3:ZX<00`3;Zh@0c:b50<^]R@070<^]R@P0cJf61`3>[XL00`3=[HH0cJj20<f^PP07
0<f^PPP0cZj50`3>[XL20<n_R0<0d;290`3C/8X20=BaR`<0eK:<0`3B/X/20=>cS0<0e;B=203F]Xl0
0`3D]8d0eKF>0=NgT0020=RhT@030=NgT03E]Hh0e;B=0080fKJ>0P3H]Hd30=NdS0030=JcR`3H]Hd0
f;F=00H0f;F=203I]Xh80=ReS`P0fkRB0P3K]8/20=beS0<0gKJ=00<0g[N>0=^jU`3K^YL00P3J^IH4
0=VhU@040=^hT03J]hl0f[N?0=ZgS`80fKJ>0P3H]Hd30=RhT@80ekN@0`3F]Xl01P3H^940ekN@0=Jf
S`3E]Hh0e;B=0=>cS080d[:;0`3B/XT20=6aR0<0d;270P3@[gT0103@[gX0d:in0=2^P03@[H<20=2]
Q@T0dJj60`3B[hL00`3A[XH0d:f50=2]Q@020<n/Q0<0dZn90P3C/8X30=BaR`<0dk2:0P3B[hT30=6^
R080dk640`3D/XD30=FcQP80dk280P3B[hL40=6^QPP0dZn70P3D/H/20=FbS0<0e[>=00<0ekB>0=Fe
SP3E]Hh01P3E]Hh80=>cRP040=BaQ`3C/8H0dJj40<n/PP80cZ^100<0cjb20=2]P`3=ZX800P3=ZX82
0<j[P`<0cjb40`3>Zh<20<fZPP<0c:V1203=ZX840<f]QP@0cZj70`3=ZX020<j[P@@0cjb200D0cZ^1
0<fZP03<ZGl0bjQn0<ZWO@020<VVO0090<ZVMP39YGD0aj=a0<NSK`37Y6h0b:E]0<ZWK`3;Z6h0ajEe
0080aZAd00D0aJ=c0<>QL@32X700`Z1`0<6OK`040<BPL0D0`im_2032WVh01035XG40a:1`0<BPL034
X7020<>OK`80`Yi^00@0`9a/0;nKJ`2oVf/0_i][0P2nVVX20;fIJ@H0^9EO0P2iUV020;NBF`030;NB
G@2gTUh0]i5P0080]i5R00H0]i5T0;^GH`2kUf<0_9QT0;fII@2nVVH20;nKI`040<2LJ02lV6@0_9QT
0;bHI080^iMS0`2jUV820;bHJ080_IUY0P2nVVX20;nKJ`<0_9YZ0`2kVFT20;ZHJ0<0_9QX:oooool0
02[ooooo1@2XODX30:MlB@040:UoC@2XOT`0Z7i<0:MmB`80YWa:0P2UNdT80:MnAPP0Z7i<0`2ZPDd3
0:V0C080Z7m;202YP4`80:b1CPP0[XEA00`0[XAB0:f3D@2/PU00ZX1>0:QnC02WOD/0YWa:0:EkB@2T
N540YW]A0:UnD`2ZP5020:V0C0030:ImA`2RND40WgLl0080WgI000<0WWDo09ed?P2LLcd00P2KLS`0
7`2JLC/0UVXm09EZ?@2FJch0UF`n099/?@2?Jc/0RfTi08YX>02:IC/0RF@j08QS>@27HSP0QF0f08AO
=@23GS@0PUdc08IQ=`24GcD0PUdc081K<@1oFS00OUT_07mJ<020Fc40N5TZ07QI:`1gF2X0MUL[07EE
;01dE2d00P1cDbd206mB:PH0L5<[00h0MU8^07EA;@1eDR`0ME8Z07IC:@1iEbX0NeT/07eK;@21G2l0
PUd`08=N<@24Gc80QF0c08MR=@80R6<f00/0R68c08US=02:I3D0RfDf08eW>02>J3T0SfTj091Z>`2E
JSd0UV/n09M/?`0209Q]@00309M/?`2FJch0UFXm00<0Ufdk0P2FK3X309E[>@80TVLj00@0TfPk09AY
?02DJC`0UFXm0P2FJch3099/?@80TF/l0`2@JS/2099X=P0409=Y=`2DJSP0U6Xh09E[>@80UV`j202E
JcT0202?JCX0T6Xk099/?@2DKSl0UFm009A^?`2BK3d0TF/l202CKSX809AZ>0@0Tfhj0`2BKCT2095/
>00509=b?@2BLC`0TW4l095`>`2@KcX00P2?KST01`2>KCP0T6/g091[=`2BKCT0Tfhj09E`?02FLCd0
0P2HLcl308mZ=P<0T6/g0P2AK3P00`2>JSX0T6`l095]?@0309=_?`05099^?P2AKCd0Tfdn09A^?`2E
Kd000P2GLD800`2EKd00U6ho09=]?P02091a>`04095`>`2CKc/0Tflk09A_>`80UVhk202DKc/309A`
@00309=_?`2BKSh0TFdm0080TFdm402CLSd408m`@@@0SVm001P0SVe208UX?@22HcL0OV4e07aQ=01h
H380LUX/06aF9`1ZEbd0Ie@/065?:@1IBBL0ED@V05519`1>@2H0CSlX048k:00m=R@0=S4N02h[6P0[
:AX0:R/M02d]8@0_<B@202X]700402PZ700W:A`09BLL02@U7@808R<M0`0Q91d2020S70<07b8K0P0K
7QL201`O60<07B0I00T07R4J02@W700S9Q/08RDL024T7@0O8A`07R0M01dO700L7Qd00`0I7a/201PN
6P@05adI024071hM01/M6P0K7AX071hI01hQ6P0Q91/092LL02DX7@0Z;aT0;2lJ02hb6`0a<a/0=SHL
03Th700l>1d0?CTL03d`7@0m<R00>c8Q03<]7`0X9QX07b0H01`O600L8A/09B4H02LS6P0Y9A`0:bLN
02`X7`0]:B00;2PO02/W7P0U9Qh00P0T9Ad00`0S91`08R<K024R6P02020Q6A007b0J02<06Q`G01dO
6P0P8A/0820H020M500R7Q<09b<H02hX700k:QX0BcTQ05];:@1QD2@0GT`L05i9701VCRP0KeLe07EJ
:`25JS/0SW92091b@02JNTL0ZHQC0:J5D02IMT00KUa604Lj:P0]:R4092XX01hX:@0T:RX0:bdX02LT
7@0T9Al09BHP02LX8P0202PY8`0602LX8P0U9R0092DO02@T8P0U9B<09bLU0`0Y:BL00`0X:2H09bLU
02DU8`0702DU8`809bPR02D09RLQ02LX8P0Y:R@0:b`V02h_:@0`<B/0?c4F04Tk8@1@A2h0C44_03hd
:00b:B80;R@R02lW9@0a;2H0<RhU03H_9`0i<2L0?C<Y048f:P14=RT0ACLZ04di8@1B?2@0ET0X05U1
9`1K@BH0HDHY06e@<P1eF3X0Ge4d06A@;@1_DRP0Qf4`0:=jAP2[Pe00T6i00080Ke8X01<0GDTa05Y4
;01E?bL0Dc/Q05@j7`1H?B00Gd8T06959`1H@R/0E3hY04dh8`16=200AC8Q04He9@19>BX0C3`]04]0
;P19?R`0B3d[00<0AS/Y02/0B3d[04Tn;01:>R<0CCdV0592:`1EABh0ETH_05=3;01??bP0C3`U05Hm
:@1D?RT0DSdX050n:01=?RL0BClV04M09P15?bD0AclZ04Tn:P1:?bT0C40X04m19`1A@BP0Dd8X05A3
:@1@B2@0DDTU05589`1BBBX0DDP[04m5:P1=@bX0Bd4X05109P1??bD0CCdT04/k9019>2@0AcHT04Dd
8P14<b<0>SDQ0080>C@Q00<0>38R03La8`0f<2@00P0e;R@303Da9@80=30T0`0c;b<203<_9P80<RhU
0P0a;B@2030/8`0F02`V6P0]9a/0;RPL030Z7P0b;200=2hR03D_8`0f<2@0?30R03Xa8P0i;b<0=blT
03@]8`0a;B@0;b`S02h[900_:R@0;b/R030/8`0a;B80<RhR03<`8@80=34P0P0f<2@303D_8`<0=2hR
0200=2lY038^9@0b:b<0<bXQ03H/8P0m<BD0@cDX04Hh:`1?=b/0CSP[04/h:@18>BH0A3TS044j800n
>Ql0?SXM04Xj8`1=?BH0D40Y05=3;01DA2d0DT8[04lo:01=?BH0AcLW04Ti:@18>bX0Ac`Z04@l:@10
>BH0?3DR03Td8080B3/[00l0ASTY04@g9P13=R<0@cLQ04@h8015>B40Ac/Q04Lg801:>R<0CCdV04lo
:01>?RL0C3`U04Ph8@16=Ql00P1;>b@05`1<?2<0CShT04m08`1@@B80DD8Q05938P1@?bD0CShT04dm
901:>b@0Ac/U04Dj9P13>bH0@c/X03lf9`0n=BH0?C@S03de8P0o=b@0@CTT04@l9@16?RL0BClT0080
BCdS00<0BcdS04`l8`1<>R800P1>>R805P1?@BL0Cd4V05109P1B@BD0Dd8T05Q59@1LB2L0GTXY06Q;
:@1VBBL0IDPV06Y=:`1`Dc40LUDc06mB<01ZCB/0JDL/06]9;@1/CBh0Ke<^06mF;@1`FBd206mK:@0`
075S?P1`H3`0Kf0i07AR>P1kJ3h0P6]0081Y?`1nIc/0O69707aQ@`1lHSl0Of@i08AX>02<KcL0TgDi
09Mi>@2@MSd0TWM009IkA02JOdX0WX9@0:24E02PQ5D0XHEF09UoFP2NQEd0XhaS0:F>HP2UT640YI=Q
0:ZJIP2_Wf/0ZJ1g0:ZNMP2/Wg<0]JAh0<2[O034[W`0`jUf0;jUK`2oZGP0`ZYj0<F^O038[Wd0b:aj
0<NYM@34YFl0`J9/0`34XF420<FRHP<0aZ=S0P33Wf404034X680aJ5S0<BPHP32WV00`9aN0;nKG@2k
VE`0^YQK0;RFE`2gUED0]iIC0;NFD@2iV5<0^YUB0;bIF@2kV5P30;VFEP040;^HF02nVe/0_iaL0;fL
F@80_YeJ00H0`9mJ0<6PF`30WeP0_YiE0;bLD@2kVe020;JDE`D0]iEH00T0]YAG0;jJC02mVD/0^iM;
0;VDC@2gTTh0]Y1A0;F?D@2eSU<00`2_SDd03P2]Rd/0ZXQ80:F3@`2QOcl0WW`l09]h=02MNSH0XWlk
0:R5@@2^RdL0]95=0;VFDP2kV5@0_YaL0`2oWEd0302nW5`0^iUI0;VGE`2gUED0_YaL0;nMG@30WUh0
`ImO0<>QH@34XV80aJ=S0<JTI0<0`J=M00<0`ZAN0<>UG`34YV000P34YV003P30XEh0_j1M0;fOF@2k
WEL0^I]C0;NID02eV4`0]9M;0:^BD02KPT80SgHf091f>@2CNCh0T7Hm0P2<LCX208ec>P0>08ab>@2=
LcX0SW@k091f?@2CND00UG]209enA@2NOdH0XH990:B5C02XRE00ZhaC0:j?EP2_T5L30:jDH@80[iER
0`2`UV<06P2]U5h0[iIP0;:FI02dUFH0]IAW0;^HKP34XGL0cJN00<R[R@3=/8h0d[FC0=>fU03A]980
d;>A0=:eT`3E^9H0f;>60=NbQ@3F/H@0eK230=>^P@3A[7l0d:]n0<nZO@39[G/0b:aj0P37ZgT05035
ZGL0_:1^0:nCH@2UREL0X8I90:67C02/TUT0_J9]0<N[N`38Zgl0bjj40=:eS@3K^I<0gK^E0=noV@3R
a9h0iLVT0>S>Z`3[dK00k=Bb0P3[e[L20>cG^0070>gH^@3^fKX0kmZk0>oJ^`3`fk`0k]jm0>oO_P03
0?3P_`040>kN_@3/g;/0j]Zi0>kD/@<0kM>`0P3/dZl20>_A[P80ilj`00@0j<na0>W@/P3Yd;80j]6c
0P3[d[@01P3`e[l0kmNo0>oF`03^f<40kMS30>cJaP80jm[80P3XfL@01P3Yf/D0j]_60>_La`3/gLP0
kMk90>kObP80j]o;00H0jn3>0>_Oc`3/h=80k>3B0>cPe03]hMD30>kQd0030>gPc`3/glh0jmk=0080
jmk=203ZgLX0103_fL40k]S00>kH`03^f<020>gG_`80k=Jn00H0j]Fh0>WD]`3XdkH0im:e0>KA]03U
d;<20>C?/P0P0>S8XP3Waj40i/JP0>C4WP3R`Y`0h<2J0=jnV03M_IL0g;V?0=^hSP3I]hX0e[B60=>a
P@3@[g`0cZej0<f/M`3=Z7@0c:Mc0<ZUL@38Xfl0aJ1/0<:MJ@31W6P0_iYV0;fHI02lUf80^YEP0;RC
G02eTEL0/hmC0;6=C`2`S4h50:Z7D@<0ZHI@0P2SP4X20:9oB@040:5nB02PODL0X7e70:1mA`P0WWU5
00P0WgY609iiA@2LMd<0VgI209Ye@@2KMT80WGQ409iiA@80WGQ100@0WGQ309iiA@2NNDD0WWQ70P2O
NDX00`2OND`0WWY:09ijBP0309eiB@<0W7Q80P2KND`00`2JN4X0VGM709QgA00209Mf@@0509Ie?`2F
LSh0Ug<o09Mc?`2HM4000P2IMD4209Yf@P80VWI60P2KMdL209ahB080WGU90P2JMTH00`2KMdL0W7Q8
09eiB@0209ijBP80Wg];00<0XGe=0:B0D02WPe<00P2YQED20:R4E0<0Z8E?0P2YQU030:Z7D@P0[8UC
0`2]RU@20:j;E@<0[haF00H0[XQG0:n9F02`RUT0/H]J0;:<F`2dSUd20;F?GP80/HiT0P2bSfD30;>@
IP030;BAI`2cTF40/i5Q0080/i5Q102bT6020;RFIP80^IMW00P0^YQX0;^IJ@2lVVX0_9YZ0;bML@2n
Wg<0`:5e0<:SM`80`jAh00L0`Z=g0<6RMP36YWl0aZIo0<NWP038Z840bJV20080bZZ300<0bj^40<Z/
R03:[8P01P3:[8P80<b/Q@<0cZj7103=[HH00`3<[8D0c:f10<b]P@070<b]P@P0cJf40P3=[HH20<j^
Q`<0cjn800@0d;290=:_R@3B[hT0dZn90P3C/8X30=BaR`<0dK6:0P3B/X/30=>cS0P0e;B=00<0d[:;
0=>cS03E]Hh00P3F]Xl00`3E]Hh0dk><0=:bR`030=NdS080e[>;0`3E/XX80=ReS@P0fKJ>203H]Hl8
0=biT`<0fkB;0P3L]H`30=ffS@80fkZG0P3J^IH30=VhU@040=RgU03J]hl0f[N?0=ZgS`80fKJ>0`3H
]Hd30=RhT@80ekN@0`3F]Xl0203H^940ekN@0=JfS`3E]Hh0e;B=0=>cS03B/X/0dK6:0`3B/XT20=6a
R0<0d;270P3A/GP01P3A/7X0dK1m0=6_P@3A[X@0dJj60=6^R0/0dZn70P3A[XH0103@[HD0cjb40<n/
Q03>Zh<30=:_R@80dk2:0`3D/H/20=>`RP80dZn90`3A[XP0103@[HL0dk630=>aP`3C/H<20=BbQ0<0
eK>50P3C/8P20=:_Q`<0dJj600<0d:f50=:_Q`3B[hL01P3B[hL20=BaR`80eK:<103F/hd80=FeSPP0
dk>:00@0e;670=>`QP3A[X@0cjb20P3>Zh400`3?[880d:f30<fZPP020<fZPP<0cZ^30P3?[8@20<j[
P`80cJZ20`3<ZH400`3;Z800cJZ20<fZPP020<fZPP@0c:V10P3<[8D40<f]QP80cZj70`3=ZX030<j[
P@80cjb20P3>Zh403`3=ZX00c:Uo0<^XOP3:Ygd0bJIl0<RUN`39YGD0b:Ab0<NSL@36XVh0ajA^0<RU
K@3:Yfd0bjQ^0<NUM@020<JTM0030<BRLP33XG40`Z1`0080`Im_0P32WVh30<>OK`@0a:1`2032WVh4
0<BPL080`im_0P32WVh40;nKJ`80_YYZ0P2mVFT20;NDGP@0^9EO0P2iUV020;NBF`030;NBG@2gTUh0
]i5P0080]i5R00D0]i5T0;^GH`2kUf<0_9QT0;fII@020;jJIP80_i]W0P2lV6@20;^GH`<0^YIR00<0
^IEQ0;^GI`2kUfL00P2lV6P30;fIJ@040;jJJP2lVVX0_9YZ0;bJJP80^iUY0`2jV6P30;bGJR_ooooo
000Zooooo`P0Z7i<202WOTP80:V0C0<0YWe90`2WOTX20:QoB`P0ZGm=00P0ZH1<0:QoB`2WOTX0Ygi:
0:QoB`2ZPDd0[8=?0:f4D0P0[8=?202[PT`30:Z1C@<0ZH1<102XOd/20:V0C080Ygi:00<0YGa80:9i
A@2QN4@00P2KMT40102JMD00VG@o09Qc?P2GLSd209Ia?00@09Qc?P2GLSh0UG0l09=]?02AJc`0SfTl
08iW?02=IS/0S68j08]Q>@28HCX0QV0i08MQ?026HSh0QfE208QV@`80P5dc00<0Oe`b07iK<@1mFS00
0P1lFBl02@1kF2h0NEX[07UJ;01hFB/0MeP/07IF;@1eEBh0MED_07AD;P03079D<080LE<_0`1`DRh0
601[Dbl0K58]06eC;P1`E2d0LeH^07IF;@1hEb`0NEP]07mL<P20GC<0PEhd089O=@24HCL0QF8h08IS
>@27I3X0QF4a08IR<P27Hc<0RFDe08]W=`2<J3P0SVXj08m[>`@0T6Xk0P2AJc`00`2BK3d0Tfdn09AZ
>00709AZ>00609=^>@2CKSX0Tfhj099/>`2BK3d0TV`o0P2AJSl209=]?P80U6ho00@0Tfdn095[?02>
J3T0SFLh202CJ3/0202GKC/0V6hl09U_?@2IKcd0V6hl09I/>P2DJSP0TfTg0P2DKSl0102CKCh0TV`m
091Z>`2?JCX208iX>@P0U6ho00<0T6/g095/>02CKSX00P2DKc/0202CKSX0TF`h091[=`2@JS/0TF/l
099/?@2CKCh0U6ho0P2EKd00202FL440Ug5209Ud@02HLcl0UG0l09=^>P2AK3P0T6/g0P2AK3P00`2@
JcL0TVdi09A_>`0209Ia?@0309A_>`2BKCT0T6/g00P0T6/g202BKSh209Ia?@80UG0l102DKc/00`2A
KCT0Tflk09Ea?@0209Ib?P0309Ea?@2CKc/0TFdi00P0TV`o202AKCd0202@K3P0Tflk09Ib?P2DL3`0
TFdi08m[=`2BKSX0UG4m202BL4003P2BM480TG=1091b@02>L3h0S6hl08Y/>P28JSP0QfTg08]_?`28
K3`0PfLg07iR<P1iGBd0MUXZ0P1dF2P03@1WERX0IUDY065B:@1LCRL0ETTV05959@1=@R@0C44U04@n
:011>bD0>SDQ038_700];1X00P0Z:a/01`0Z;1h0:2/J02P[6P0W:A/09RPK02HX7@0U9Qh00P0T9Al2
024T6@03020S6P0O8Q/07R0K00807AlL00<071hM01`N6`0L7Q/00P0M7a`201hP7@807b4N0P0R9AX0
1P0S9Qd08bHO024S7P0O8Ah071hK01/M70<071hK0P0K7AX401XL6@0601XL6`0J71T06adJ01dO6P0N
8AX082<J0P0Q91T04`0/:aT0<2lM03Hd7`0m>280@S`R04<l7`12?1X0@cXI048l900n>280=c8N02h[
6P0X9QT08b<I02<S6`0R8ad09BDK02HV700W9ad00P0Y:Al0100X:1h09bLM02HV700U9Qh302@U7@80
8b@L0P0R8a/A01lP6P807QlI01d07AhH01hO6@0P8A/08b@N02@U7`0c;180A3XO05E:;P1KC2d0FDHU
05a68@1XD2X0M5/c071J<@24KD<0SWI:08ib@`2INDP0[HUE0:f8D`2PND80Oe]305e0;P0i:1h0:2@Q
02HW:@0S9bP09BLT02PW8P0302LW9@809RHT0`0U9B<01P0U9BD09BDS02DU8`0V9b809RLQ02LX8080
9bTN200U9B<09`0Q9ad08bTO02P[8P0X:B409RLO02PX800_;2D0=34Z04@`601EA2P0Fd`[04To6`0f
<100<B`F034]900_:bX0>RlM040c8015>2D0BS/V04/k901=>b<0DCdT05<o9P1@>bH0EClX05e5:`1U
BRd0K4h/075?:@1bCbD0M4lS07eC8`1kDB40PeTW09Ya?@2]Q500ZX5;09E/=002089I8@0A065?=`1K
BC40Ed4Y05Lo9`1L@2P0HD4X06=19P1S?bD0FD4Y050j8P1:=1d0B3@L04/i8`1>?BT0CCh[04/l:@1@
?RH00P1??BD00`1=>b<0C3XR04/i8@0204Xh800804hj8P1@?2@0D3hV05109`1@@RP0CD4W04/o9@19
?b@304Pl90D0BCdU00T0C40X04e1:@1@A2`0DDD]0596;P1AABd0D4@/04i2:P1EAB`00P1FARd01@1G
Abh0ETH]05A4:`1B@RT0D40W0080Cd0[00h0CD0]04]0;P17?b`0@S/Y03lh:00k=BD0>C@P03Td8@0g
=240=SDS03<d900b=2H0<S@W034e9`P0<RhU00H0<c0Q038_800b;R80<BdR030/8`0_:R@202hY9@80
;b/R0`0`;2<3034]900303<]8@0d;R80=S0T0080=c4U00<0=S0T03@^8P0c;B400P0`;200100a;B40
<RhR038^8P0c;b<203@`900P034]900b;RD0<blV03@`9`0c;bH0<RhU030/8`0^:R40<RXW03<[:00d
;BL0=RlW03L`9P0i<bL0>S@V03/e9`0n=B@0@STX04Pm:`18>bP0ASLR04<b7P13<a`0AS@N04/j801=
?280D3lU05919`1A@2H0CSdS04/j8018=ad404/j:P0404Th:016=BD0A3<S048a8@80@CDU00L0@3@T
03hb8P0n<R80?S8R040d9013=bL0A3PX0080CS`T00h0CC/S04`j8P1;>B40BSPP04Tg7`18=Qh0Ac`V
04Lk9@16>R80B3XP04/k8@1>?B40DShS05=08P80CDDQ00P0CTDT04e49@1;@RD0BClT04Hl8`14>R40
@CHT040e8`80?c@R00@0@3DS048g9@15>RP0AS/Y0`1<>R803@1=>b<0CS`T04lm9@1@?RH0DClW0510
:@1??bP0DClW05A09`1G@RL0FTDX0619:P1RBb`00`1VCS800`1UCC40I4``06=;;`0206=;;`0`06=:
;01VBbd0J4h[06iB:`1cERX0NE/Y07aM9`1nGbP0MV4d07MR=@1iI3L0O6Lj07mZ?@21K3l0Pfi108E`
@`1fJT00MfY007a[?`23K400Rfm0095a@02GLd40VWE109AkA@2ENdP0UWa;09UnD@2KP5D0Wh=L0:65
H02SQV@0YY5T0:VDI@2]UfP0[YIV0:nEI02bUV@0^YaX0;nQK@2nXWX0`:Al0<>WO`36ZX80b:b40<V]
Q@3:[XH0bJf50P3:/X801`3:[h00bJen0<RYN`37YWT0aJAg0<FSMP31XV/01@30XFX20<6RJ`060<FS
I034XV<0a:9S0<>QHP32X640`ImP0P30WUl0202lV5X0]i=E0;:>D02cSe40^9AF0;fIF`2lV5X0^YIH
0P2nUe@60;nHE@030;fKD`2nW5@0_YaD0080_ieE00P0_YaD0;^ID@2hUTh0]iE=0;VEE`2gTeD0]I5C
0;>?D@80/Xi@00<0]91B0;FAD`2aTU400P2bTe801@2aTU40[i1?0:f>C@2ZRdX0Z8U80080]XY301@0
]8U40;28@`2[Q440YGln0:5k>P2LNCT0UgI009Ui@02LO4<0XH560:R8B`2_T500]IIE0;RIF02oWUL0
_YeF0;jMF02mW5T0_I]K0;bJF`80^iUL102oWEd40<2NGP0J0;nNF@30WeX0`Z5L0<>RG@34Xeh0`j9M
0<:QG031X5/0`:5P0;jOGP2lWE`0^Y]J0;NHE`2eUUD0]9ED0;>DD`2SQTX0Vgi209=f>P2@LcL0TWDi
09=f>P2AM3P0SW4e08U`>028KcL208M^=P0<08Q_=`2:LCT0SG@l08ie?@2EO4<0V7m609^1B02MP4P0
WWm80::1B`2YR580/XmI0P2/Uf800`2/UV@0[9IU0:fGJ0020:fFJP0c0:jGK@2/TV40[iET0;>GI`2e
UVL0]IEV0;RFJ02nW6h0aZ5d0<^[Q@3A/H/0e;JB0=FhUP3@]Y<0cKFC0<beU@3>]iL0e;:<0=>aR`3B
/HP0d:n40<j]P03<[7d0bj]l0<ZZN@3:Zgd0b:Uk0<JWN035YgD0`ZA`0;^MI`2`TU`0YhYB0:20A`2Y
R580]YEP0<2NKP37YGP0cJZ20=BaR`3J]Y80ekR<0=ViT03K_Y@0g/:J0>78X03Tc:H0im6/0>WC[P3`
eKL0kmJg0080kmJh00d0kmNk0>kI_P3]fL00k=_10>cJ`P3`gl/0kmo80>kLa03]fKh0k=Nh0>_D/P3Z
e:l0j]:/0080i/f^00<0ilj`0>O=/P3Xc[D00P3Xc[L02@3Yc[T0jLb/0>[=[@3Yc[00jM2b0>WA]@3X
dkH0jMBi0>SD^@020>SH_`80jMW00`3Zf/400`3[fl80j]g<0>[Mc0020>_Nc@@0k=o>0`3Zg/h40>_O
c`030>cPd03`g]00l=k@00@0l=k@0P3_gLl03P3_gll0l=o?0>oNc03_gLT0lMc70?7Ka03bfL<0l][2
0?3H`03_ekd0k]Jl0>gE^@3/eKH0j]>c0P3Yd[005P3^c:H0kL^U0>c:Y03Zb:80jLNQ0>O5W`3Va9h0
iL>M0>K0V`3U_iX0hkjD0>6lT03N^XX0fkN30=VfP03H]Gd0dZid0=6]L`3?Zg40cJU_0<ZVK038Y6X2
0<JRJ00<0<6MK@30W6`0_i][0;fIJ@2kUfL0^IEU0;NCH`2fTV80]8mJ0;:=F02_RUD0[8MB0P2ZQE02
0:^6D@<0XWi<0P2SOdd30:B0CP<0VgM50`2JMT@209Ue@`80V7A200@0Ug=109Ib@02FLT00UG4o0P2D
L3h0202FLcd0UG8l09Eb?02ELS`0UW<m09Qe?`2KN480W7U32@2JM4L809IdAP0609Qe?`2GM3h0Ug@n
09Eb?02DLC/0Tg0j0P2BKcT209E^@`0309E_@P2EKd00UFln0080U6lk00`0U6lj09Ma@P2GLD80Ug=3
09IdA02GMdH0UgU709QjB02GNdT0Ug=309YfAP2NNTX20:5mC@0309eiB@2IMDD0UW920080XWi>0P2S
Odl0102TP500YH5A0:J2DP2VPU820:F1D@80YX9B102WPe<01P2WPE00Z89A0:R3C`2YQ4l0ZXE@0:^6
C`80[8Q>0`2YQTh20:Z7C`<0ZhQ@00@0/8]G0:n:EP2_RUH0[XUE0P2]R5@20:b7D`80]8mK0P2cSUX3
0;:=F@030;6<F02aS600/HaP0080/HaP102bSF401@2cSel0]I5Q0;NBI@2jUFT0_9M]0080_9I_00l0
_9Ia0;jQN@2jWGD0]iYb0;VLM02nXGT0`JAl0;jQN@2jWGD0`j1j0<BQN`35XW`0aZ=m0<RUO`3:Yh40
0P3;Z8820<FUOP80aZIo0`37Yh002@38Z840`ZMl0<>XO@33Ygl0`jN00<BXP`34YhD0aJR60<FXR003
0<RXO`80bJV00`3:ZX440<b/QPD0bj^500<0cZj50<f]Q03=[H@00`3=[H@20<b/P`P0cjn6203@[HD2
0=2]P`80dJj40`3B[hD01`3C/8H0dk2:0=:_R@3B[hL0dZn50=6_PP3A[h400P3@[Wh20<n/QP80d:f7
00@0dJj80=:_R@3B[hT0dk2:0P3G/HX20=J`R@0:0=F_R03D[XL0djf60=>]QP3C/H<0dk640=BbQ@3E
/XP0e[>;0=JcS@80ek>?103H]H/40=NdRP80f;F=1@3G]8`0103F/h/0f;B@0=RdT03H]9020=VeT@<0
f[JB0P3I]Xh30=ZgS`<0fkR@203J]i420=VfSP<0f;F=0`3G]8`80=ReS@80fKJ<0`3H]H/30=NdRPP0
dZn70P3C/H420=:`P0<0dJmo00<0d:in0=2]P`3@[H<01`3@[H<80=2]Q@P0dZn700<0dJj60=2]Q@3>
Zh<00P3=ZX800`3>Zh<0d:f50=6^QP080=BaR@P0dJj6203@[H<30=>`R080e;690`3E/XX80=>`R00<
0=6cS@3D]8h0eKF>0=NfS@3H]H/0fKB80=VbQ`3H/XD0ek:50=JaQ03C[X40d:]n103>ZG`90<j[P@<0
cJZ00P3<ZGl20<^XOPP0cJZ00`3>Zh420<n/PPD0d:f300<0cjb20<j[P@3=ZX000P3<ZGl01@3;Z7h0
cZUl0<jYO03=Z7/0c:Mj0080bjIi0P3:YGP80<RSMP80bZ9^00@0bJ5]0<RPK037Wf/0aYiZ0P35WFT9
0;nMK@80`9i^0P2oWFd30;jLK0030;fKJ`2nVVX0_YYZ00H0_YYZ00P0_iad0;jKL`2nW6l0_I]]0;bK
J02lVfD0^i]R0;^KH0H0^IAO0P2hTeh0102bSeD0/i1F0;>@EP2cT5H20;BAE`80]I9H00@0^YIV0;^G
I`2kUfL0^iMW0P2lV6P20;fIJ@040;bHJ02kUfL0^iMW0;^GI`80^YIV0P2iUFD30;bHJ080_IUY0`2n
VVX20;jJIP040;fII@2lV6@0^iMS0;VEH@80^9AP0`2iUV0[ooooo`00:_ooool80:QnC0P0Ygi8202X
Od/30:ImB@<0Ygi:0P2XOd/80:UoC@070:Z1C@2YP4`0Z7m;0:MnBP2XOd/0ZH1<0:^2CP090:b3C`P0
Zh9<0`2ZPDd20:V0C0<0Z7m;0P2WOTX20:QoB`80YWe900<0Y7]70:5hA02PMd<00P2KMT40102JMD00
VG@o09Qc?P2GLSd209Ia?00@09Qc?P2GLSh0UG0l09=]?02AJc`0SfTl08iW?02=IS/0TFLm08mU?@2;
I3/0Qf4j08IP>`24H3`0Pf4n08AR?`80P5dc00@0Oe`b07iK<@1mFS00OEX`0P1lFBl0201iFR/0NEX/
07QI:`1gF2`0MUH]07EE;P1eEBl0M5@^0P1bE303075C;`<0L58^00P0JU8^06aB;@1]Dbh0L5@]07=F
;P1fERd0N5L/07UH;@80O5T_00H0OEX`07mL<P20GC<0PEhd089O=@23H3H208EQ<@0408MS<`29ICD0
RVHf08aX>080SVXj102@JS/2095[?080TV`m202DJSP01P2CKST0Tfhj09=^>P2BK3/0TV`m095[?P80
TFXo0P2BK3d209=]?P04099/?@2@JS/0SFLh08aV=`P0TfPk00h0UF/i09I/>P2GKC/0V6hl09M]>`2F
K3X0U6Xh09=Y=`2DKSl0Tfdn099/?@2AJc`0T6Xk08mY>P80SVPi202CKCh00`2@JcL0TF`h09=^>P02
09A_>`0309=^>P2AK3P0T6/g0080TF/l00<0TV`m09=]?P2DKSl0102EKd00102HLcl0UW4m09A_>`2B
KCT2095/>005099]>@2CKSX0TF`h095/>02BKCT00P2CKSX00`2BKCT0TF`h095/>008091[=`P0TVhn
0P2FLCd209E`?0<0U6lk00@0Tfhj099^>P2CKc/0U70l0P2ELCd00`2DL3`0Tflk099^>P08099/?@P0
TFdm00P0T6`h09=_>`2FLSh0U70l095]>@2?JcL0TVhj09Ea?@P0TW100P2ALd40102@LT00SW0n08e_
?@2;KC/208Y/>P0E08]_?`28K3`0Q6Ph07iR<P1jGRh0Me/[07EI:@1dF2P0JEH[06IE:@1SDBT0GDhW
05Q:9`1CARH0CD8T04a19@14?RP0@C/U03Xe8@0b;a`0;B`J0080:R/K00L0:R`N02P[6P0X:aX09bTK
02HX6`0V:1d09BHN008092DO0P0Q91T00`0P8aX07b8K01hP6`0201dO700301`N7@0L7Q/071hK0080
7AlL0P0N81d201lQ7P808RDJ00H08bHM02<V7`0Q8ah07b4N01`N6`0K7A`201`N6`<06adJ100J71T0
800J71/06Q`I01/M6P0M7aX07R4J01lR6@0P8aP08B@I02`Z6`0_;Q`0=C8O03`g8@11>b40@S/N048l
7013>QT0@3XR03dg8@0h<al0<2dL02XX6`0T91X08R8J020Q6`0T91X09BDK02LW7@0X:1h0:BTO02PX
7P0W9ad09RHL100T9Ad202<T70808R<K4@0O81X07`0N7aT07AhH01dN600N7aT0824K028S7@0T9Al0
<2T?044g7P1AARX0EdPY05I38P1H@Al0HTXT06iD;`1_FC00PV]108adB02>LT<0V7Q70:b8E02]R5<0
XW]4089O@`1O@bh0>b/N02TV8@0V9bT08bLX02DW900X9b800P0W9bD302HV90<09BDS00H09BDU02DU
8`0U9B<09RLR02HW8@0W:20202LY7PP09BDS02L082HL02<Y7`0W:R40:2TQ02HW7`0Y:B40<2dV03Db
:`16<A`0ED@Z05]<:`1;@Ah0>38B038]5`0a;B80<2`Y048g9@19?2T0CT4^0511;01<?2D0BSPP04lk
8P1B?RD0FD@_05]5;P1OAbd0I4T[06i@;01hES00PEhd08MR=@2;HC40S68b091V=02KLSh0Ygi:0:Qo
B@2IL3P00P28GbL0401NCC<0FdL^05M1:@1H@2H0GD4Y0653:@1R@RT0HT0U05a4:P1F?RH0CCLO04/g
7`1<>R@0CSdY04hm:`1;?2T2050n9P0>04lm9@1>?2@0CC/S04`j8P1;>B40BSPP04lk8`1@?2@0D3hV
05109`1?@BL0C40V04/o9@19?b@804Tm9@0304/o9`1<@2P0CT8Z0080D4@/00H0Cd<[04i2:P1=@BT0
Dd<Z05A4:`1EAB`205I6;@0A05A4:`1C@bX0DD4X04ho:P1?@2/0CD0]04Xo;@16?R/0@S/Y03hg9`0k
=BD0>C@P03Td8@0g=240=c@S03Hd9@0c=2H00P0b=2L8038^9@0603<`8@0b;b00<RhR034]8P0`;2<0
;bXT0P0^:BD202l[8P<0<2`S0`0a;B@00`0c;B40=2hR03H`900203La9@0403H`900d;R80<bdQ02l[
7`80<2`P0P0a;B42038^8P0303<_8`0a;B@0<RhU00<0<blV00T0<BdT030/8`0^:R40<BTV038Z9`0c
;2H0=2dU03H_9@0h<RH00P0i<bD0400m=2D0@CPW04Lk:`17>RT0ACHS04<b7P14=1d0AcDO04Th7P1;
>R00CchT05919`1C@RP0DT4W04ln901=?28204/j:00604`k:@1;>RP0BSTW04Lf9014<b40@c8P0P11
=BD01`10=2@0?c<S03hb8P0o<b<0@CDU04<g9`14>2P00`1;>b@204Xj8`<0BCTR00P0AS/U04Lk9@16
>R80B3XP04/k8@1>?B40DShS05A18`80CT@Q00P0Cd@T04i39@1=@RH0BShT04Lk8`16>R80@SLU044f
9080@3DS00@0@CHT04<h9P15>RP0AS/Y0P1:>R40101<?2<0CCdT04hn9@1>?RD204lo9P0904dn9`1>
?RL0CclV05509P1E@BH0FD@W05m8:@1QBR/0IDh_0080I4d^0P1SC2d2069;;00^065::`1QB2X0HdX[
06M=:P1^DR/0LeHZ07YK;01mGb/0P64[07YU=P1kISL0OFPi07mZ>`22KCh0QG1108Mb@`28Ld@0OW57
07iaA@21L4@0QVm308]`@@2BLd@0V7I609ahAP2JPD/0Vh5>09j4D`2QQUL0XhQM0:F9H@2WRf@0Z8aW
0:F@H`2YU6D0[IMX0:nGI`2aUfH0]9QV0;fOJ`32Y700`JMf0<>YN036[7/0b[1o0<fcPP<0c[B300P0
c;F30<fcPP3</X40bZin0<Z[O039ZGX0b:Ih0<NUM`<0`jA[1@32XfX20<6OH0030<2NG`2oWEh0_YaM
0080_I]L00T0_9YK0;bHFP2hU5H0]I5C0;JBE02jUUP0_9QJ0;^GF@2hU5H00P2lUE830;fFD`<0_YMD
0`2lVU820;fKD`0<0;bJDP2jV500]iE=0;JDC02fTU@0]I5C0;>?D@2bSU00/He?0;:>D02cSe40]91B
0`2cU5<05@2bTe80/95@0:f>C@2ZRdX0Z8U80;B7@`2bQd80/HI20:b3@@2WP3l0XW`m09]h>02IMCL0
UWDo09Mg?P2JNT40Wgm40:J6B@2]STh0/iAC0;JGEP020;fLE@040;fLE`2mW5T0_I]K0;bJF`80_9YM
0P2nW5`60;nMG@030;jMF02oWUT0`J1K00<0`j9M0P31X5/04P30XF00_j1O0;fNG@2jVeX0^9UH0;JG
EP2dUE@0/iAC0:64B02JOD40TgHj08mb=P2AM3P0TWDi095d>02>LCD0RW4i08U`>080R6lg00d0RG0h
08]b>P2=M3`0SWDm095h?`2EO4<0VX1709f0B02OP4T0XX5;0:R7D@2`SEL0ZiAN0080[9EQ00<0[IIT
0:fEI@2^UVP00P2^UVX0<P2/TV40[iET0;>GI`2eUVL0]IEV0;RFJ02nW6h0aJ1c0<^[Q@3@/8X0e;JB
0=FhUP3A]i@0cKFC0<ffUP3>]iL0e;:=0=>aR`3B/8X0d:n60<j]PP3<Zgh0bj]l0<ZZN`3:Zgd0ajQj
0<FVM`34YW@0`J=_0;ZLIP2_TE/0YXUA0:20A`2YR580]YEP0<2NKP37YGP0cJZ20=BaR`3I]I40ekN>
0=ViT03K_YH0g/:J0>78X03Tc:H0im6/0>WC[P3^eKH0kmJh0P3^ekP00`3_ek/0k]Vn0>gI`0020>cJ
`P080>oNbP3^g/L0kM_30>gI_P3[e[L0jmBb0>WC[P3YdJ/20>K=[P030>K=[`3WcK80ilfd0080j<jg
00X0j<fh0>S;Z`3WcJ`0j<f_0>S?/@3Xd;@0j=>h0>OC^03Xe;/0j=S10`3YfL820>[J``80jm_40P3Z
gL`20>_Nc@<0k=o>00<0kN3?0>cOc`3/gll00P3/gll40>gPd0D0l=o?0`3_g/h20>gLbP0/0>gKa`3^
fL@0k]S10>oG_`3^e[h0k]Bk0>cB]`3[dKH0j]6c0>W@/P3WcZl0i/j/0>G=Z@3Tc:P0ilJM0>K5W03U
a9/0hl:I0>70U`3P_iH0gkjE0=jmU03N^940gKN@0=^fS03H/hH0eK610=>_N`3A[WP0d:eg0<VUJ`38
Y6X0aZ9X0<BPIP32WV@0`9aR0;jJH02mVEl0^IEU0;RDI02gTf<0]I5Q0;>?G`2aSEd20:n;F`060:f8
E02/Qe<0ZHA@0:J1C@2UP4`0Y7m;0P2UP4`609eiA`80W7Q60P2IMD<209Qd@P80Ug=11@2FLT000`2E
LCl0U70n09A`?P0209=_?@80UG4m0P2DL3`0102ELCd0Ug<o09Ue@@2KMd<909QbA@P0U79400H0Ug<o
09Ib?P2FLSh0U70l09=_>`2BKSX2095]>@0509E^@`2DKD80U6i109A^?`2DKSd00P2DKc/0302DKcX0
UW1109I`@@2FLT80UG=309EeA02DMT@0UGM509=gA@2GLd<0VGE509]gA`80WGU900<0VgM709QdA02F
LT800P2PO4`01P2QODd0XWi>0:=oC`2TP500YH5A0:J2DP<0Y81@0P2UPE430:J2DP060:J0C`2WPE00
Z8=?0:R3CP2YQ4l0ZXE>0P2[Qdd20:R5C@80ZHI>0`2ZQdl0102[R500[hYF0:j9E@2^RED20:f8E080
[8MC00<0ZhIB0;>>FP2cSUX00P2bSET30;6<F0040;2;E`2`Rel0/8]O0;2;G`<0/HaP0P2bSF401P2c
Sed0]91P0;NCH`2iU6L0^iIZ0;^FK080^iE^00T0_imh0;^KM02iVG80^i]d0;nON031XGX0_imh0;^K
M033X7X00P34XG/00`35XW`0aZ=m0<NTOP020<RUO`<0a:Am0P35YGh30<JVO`80`JIk0P32YWh01033
Yh00`jN20<>VQ034YhD30<NWOP80b:Qo0`39ZH080<^[Q@040<ZZQ03=[H@0cJf40<f]Q0D0c:b3203?
[hH80=2]Q@<0d:f30P3A[X@30=:_Q@80dZn900@0dZn70=6^Q03A[h80d:j00P3@[Wh00`3=ZX@0cZ^5
0<j[Q@020<n/QP80d:f700@0dJj80=B_Q@3D[hD0e:n50`3C[X@20=:]P`80d[2200H0dk640=>`QP3D
/HT0eK:<0=JcS@3F/Xh50=NdRP<0e[>91@3H]Hd30=NdS0040=NcS`3H]900f;B@0=RdT080fKFA0P3J
]Y830=VfSP80f[N?0`3K^9080=ZgT@80fKJ>0`3H]Hd30=NdS0P0f;F=0P3I]X`30=ReR`<0ekB:203C
/8P20=>aP@80d[20103A[gl90=2]P`P0d:f52@3A[XH01`3@[HD0cZ^30<fZPP3=ZX80cZ^30=2]Q@3A
[XH0203C/8P80=6^QPP0d:f300@0dZn70=>`R03C/8P0dk280P3D/HT20=FbRPP0dk2800`0d;:<0=>c
S@3E]Hh0ekJ=0=ReR`3I]8P0f;660=NaQ03F/H@0e:n20=:]P03@Zgh20<jYO080cjYm203>Zh440<fZ
P080c:Uo0P3;Z7h80<bYO`040<fZP03>Zh40cZ^10<j[P@80cjb2103@[H<0103?[880cZ^10<fZP03<
ZGl20<^XOP80cZUl00<0cJQk0<bWNP3;YWT00P3:YGP00`39Y7L0b:=f0<RSMP060<RSMP060<ZRK`39
XFh0bJ5^0<RPK@37Wf`0aYi[0P35WFX:0<2NKP<0_ie]0P2nW6`20;fKJ`P0_YYZ00H0_IYb0;fJL02l
VVd0_9Y/0;^JI`2kVVD20;ZJH@@0^IAO102hTeh0102cT5H0]95G0;BAE`2dTEL20;FBF080]Y=I0P2j
UVH20;^GI`<0_9QX00<0_IUY0;^GI`2kUfL00P2kUfL20;ZFIP80^IEU0P2kUfL20;bHJ0<0_IUY00L0
_YYZ0;nKI`2nVVH0_IUU0;bHI02kUf<0^YIR00D0^IEQ:oooool002[ooooo202WOD/80:MnB0/0YWe9
0`2WOTX20:QoB`P0ZGm=00P0[8=?0:^2CP2YP4`0Z7m;0:MnBP2XOd/0ZH1<0:Z1C@P0Zh9>202[PT`2
0:Z1C@80ZH1<0`2XOd/00`2WOTX0YGa80:ImB@020:ImB@80YGa800<0XWU50:1g@`2NMD400P2KMT40
102JMD00VG@o09Qc?P2GLSd209Ia?00609Mb?@2FLCd0UG0l09=]?02AJc`0T6Xm0P2>Ic`01P2DJcl0
TVPn08aU>P28HcT0QElh089O>@80PElj00H0PEhd081M<`20GC<0Oe`b07iK<@1mFS0207aI;`0907UJ
:`1iFR`0N5T[07MH;01fERd0MED^07EE;`1dE2h0LU@`00<0LE<_0P1`DRh206mA;@0606YB;P1/DRd0
KE<^071D;@1bEBd0MUH]0P1hEb`207UF;00407YG;@1lFBl0OEX`07mL<P80P5dc00P0Q60`08EQ<@26
HS80R6@d08YV=P2<J3P0SFTi08iZ>P80SfTj00<0T6Xk095[?02AJc`00`2AJc`809AZ>00809=^>@2C
KSX0TVdi099/>`2AJc`0TF/n095Z?`2@JCh2091Z>`80TF/l00@0T6Xk08iX>@2<ISL0RfDf202CJ3/0
0`2AIcD0TVPf09AZ>00209I/>P0409E[>@2DJSP0TfTg09=]?P80TV`m00<0TF/l091Z>`2?JCX00P2>
J3T8095[?003091[=`2AK3P0TVdi0080Tfhj00<0TVdi095/>02@JcL02@2CKCh00`2EL3`0U6lk099]
>@02095/>003099]>@2DKc/0UG0l0080TF`h00@0T6/g08mZ=P2?JSH0T6/g0P2AK3P8091[=`P0TVhn
0`2EL3`209A_>`<0Tfhj00<0TVhj09=_>`2DL3`00`2DL3`00`2CKc/0TVhj099/?@07099/?@P0TFdm
00P0T6`h09=_>`2FLSh0U70l095]>@2?JcL0TVhj09Ea?@P0TW100P2@LT0208ma?`<0SW0n00L0SFlm
08]_?`29KCd0Q6Ph07mS<`1kGbl0N5`/0080MUXZ00d0JEH[06MD:@1SDBT0GDhW05U99`1DABH0D48U
04i09@14?RP0@C/U03Xe8@0b;a`0;B`J0080:R/K00L0:R`N02P[6P0X:aX09bTK02HX6`0V:1d09BHN
008092DO0P0Q91T00`0P8aX07b8K01hP6`0201dO700301`N7@0L7Q/071hK00807AlL0P0N81d201lQ
7P808RDJ00L08bHM02<V7`0Q8ah07b4N01`N6`0K7A`071hK00<06adJ0P0J71T301TK600P01TK6P0J
71T06adJ01`N6@0N8AX07b8I020S600Q91T0:bTJ02h/7@0d<Ah0>cHR03li8@11>Qh0@CXM04<j6`0l
=Qh0>cDO03Td800c<1l0;B/N02HV700Q8AT07AhH02<S6@0U9A/09RHL02PX7P0Y:Al0:2PN02LW7@0V
9Q`302@U7@808b@L0`0R8a/A01lP6P0P01hO6@0M7QP07AhH01hO6@0P8A/08R<M02<T7P0^9Pl0?S@K
04e19`1DABP0DSlO05@m6`1LA200IT`W06aF;@1nIcd0RW9608ea@P2HN4L0ZHEA0:f8D`2VOdP0QfA6
06A8<00n;Ql0:RLP02HX9`0S9bP092HS02PW8`0W9bD302HV90809BDS0P0T92801P0U9BD09BDS02DU
8`0V9b809RLQ02LX80809bTN200U9B<09`0P9Q`08bTO02LZ8@0X:B409bPP02TY8@0a;RL0=S</04Pc
8P1D@RX0FT/^04e28P0k=1L0<bhH030/8@0`;2T0Ac`Z0513<01GBSL0EDHa04`l9@17=Ad0C3PO058n
9@1PBS<0GdL_05i4:@1RABD0KD`Y07aI<@2<Ic/0UW1309I/?02OMDD0XGM509ed@02QN4@0Ygi809ie
?@0208iU;@0@05i9;01JABP0F40T05Y09@1N@bP0HdD[0653:@1P@2L0HDL/05]3:@1E?B<0DC/S050l
901??BL0CSdY04`k9`80D3hV00@0CcdU04hl901=>b<0CC/S0P1<>R80201@?2@0DCdU050n9P1@@2L0
CT0V04a09P1;?bD0BClT2@19?BD00`1:?RH0BclW04a0:00204e1:@0504a0:01;?bL0DD4X0592:@1D
A2/00`1EAB`205=3:P80CSlZ00h0C3l/04Tn;015?BX0@CXX03hg9`0k=BD0>c@Q03/d8P0j=B80=c@S
03Hd9@0c=2H0<c<W038d9`P0<RhU00H0<c0Q038_800b;R80<BdR030/8`0_:R@202hY9@80;b/R0`0`
;2<3034]900303@^8P0e;b<0=S0T0080=c4U00@0=S0T03D_8`0d;R80;RXN0`0_:al3030/8009034]
8@0`;2<0<BdT038^9@0c;bH0<RhU034]900_:b80;RXQ0080<2PU0180<BXT03</900d;B<0=BlS03H`
8P0g<B<0>c8S03lf9`15>BT0ASTX04@d9013<R00AC@P04Pf8P18=ad0BcXP04ln901C@RP205E4:P03
05A3:@1C@RP0BcXX00<0C3/Y00@0BcXX04Pg9@16=B<0A3<Q0P11=BD2040d900503lc8`10=2@0@CDU
048f9P13=bL00P18>24204Ti8P@0BSXS01`0AS/U04Hj9016>R80B3XP04/k8@1>?B40DclT05A18`1>
A240CdDR04m4901?A2H0CD8V04/o9@19?BD0Ac/S04@i9`13>2H0@SLU044f9012=bD0@cPV04Dj:016
>bT0AcLN04Ti801<?2<0CShU0P1??bH02P1=?B@0C3`S04`m9P1<?BH0CCdT04ln901B@BD0Ed@V05]6
9`1MB2T3069;;080HDX[0`1PBBX07P1NAbL0H4TY06E=:@1[DRX0LeP]07UM;P1oH340PF<a081Z>`21
Jc`0Pfdn08I`@@28LT<0RgE608egB02>N4T0R7]?08IgC025M4P0Qg9508YbA02BMTL0VGY<09emCP2O
QE80XXQE0:J<F`2ZSf00[I9U0:jCJ080[I5Y00h0ZIAW0:bGJ02`VV/0/IUY0;>IJ02fVVP0_Z1/0<BV
LP34ZVl0aZaa0<Z`M@3>]7T0dKMl0=>iOP80e;Yo00T0dKN40=2fP`3?/h40ck5o0<j^O@3<ZWX0bjUi
0<bXN037Yfh00P38Z6l20<NWKP030<JVK@35YF`0a:A[0080_YaM00<0_I]L0;bJF`2kVEX00P2jV5T0
1@2iUeP0_9QJ0;ZFF02iUEL0^YIH0080^iMI00<0]i=E0;B@DP2iTTl00P2iTTl01P2jTe00^iAA0;^D
D@2kU540_9EB0;VGD0@0^YQA00@0^IM@0;RFC`2fU4d0]I=<0P2bSU030;6=C`030;:>D02cSe40]91B
00<0]YAD01D0]I=C0;:@D02_SDd0[8Y:0:Z8B02^Pcl0[H8n0:Z1?`2VOch0XG/l09Yf>02FLSH0Tg4d
09Ac?@2EMC`0V7Po09em@P2SPdH0ZX];0;2AD02cU5<00P2jVE80102kVUD0^iYG0;bJFP2mVe`20;jL
G`P0_YaL01@0_IaG0;jMF030WeX0`J1K0<:QG031X5/0`9mJ0;nNF@2oX5l0_YmN0;fNG@2kW5/0^IYI
0;JGEP2dUE@0/iAC09^1AP2FO440T7Hk08ec>080SW@i00<0SG<h08ab=`29L3P00`29L3P0302:LCT0
Rg8j08ed?02>MCd0Rg8i095h?`2HOTD0WX5909n0B@2RPD/0YXE?0:f:E080Zi9L03P0[99O0:fCHP2^
Tf@0[iAW0;2EJ02`UFX0[99Q0:nEI02cUfL0]IIW0;FEIP2gUFL0_I]]0<BOLP39ZH<0cjn90=BfTP3F
^IL0d[RE0<ngU@3>]iL0ckRH0=>cS@3B/X`0dK6:0<n_QP3=[X80bjan0<Z[O@39ZW/0bJYl0<NXNP34
YGH0`jEc0<2RKP2iVfD0[HmI0:B7C`2PP4L0ZXUC0;NFH@31Wfl0b:Ii0<j[P`3D/H/0f;B@0=NgSP3I
^I80fkjF0=k2V`3Qaj80i<bX0>O@[P3Yd[00k]Fg0>gF]`80k]Jj00d0kMRm0>gI`03/f/80jm_40>cL
a@3_g/X0k]k70>gK``3/f;d0j]Ff0>WB/03WdJ`0ilnY0080iLb]00<0i/f_0>K</@3WcK@00P3WcKH0
2@3XcKP0iLZ/0>K;[@3VcJl0i/jb0>KA]P3Vd[T0im>j0>KD_0020>WI`P80j][30`3[fl@0103/g<D0
jmk=0>_Nc@3[g/d20>cOcP<0kN3?00<0k^7@0>gPc`3]h<l01@3]h<l30?7Nc@80l=g<0P3_g</04@3^
flX0jmW30>cG`P3[ekl0jmFm0>_C^@3[dKH0jm2c0>[?/P3Yc:h0j<^]0>O:ZP3Ub:H0hlJT0>75X03P
a9d0gl>L0080g[^A00@0g;V?0=ZgS@3I]X`0ekB:0P3E/XP05P3B[H40dJb00<nZO@3=ZGT0bZId0<NS
K`35XFd0a:5[0;fHH@2lUf00^iIO0;RCG02fTEX0]8mH0;:=EP2aS5D0[XYJ0:f9F@2/R5P0ZXIF0:R4
E02WPe<20:F1D@050:AoB`2SOTX0XGa809mjAP2NNDD00`2MN4@209Mc@`0409Ib@P2ELD40UG5109A`
@080Tflo0`2DL40209=_?`<0TVhn102CKcl2099^?P80TFdm00P0U70l09=_>`2BKSX0TVhj09=_>`2E
LCd0Ug<o09Qd@0T0UG13202@KT0209A`?080Tflk00@0TVhj095]>@2@K3P0T6`h0P2CK4400`2CKD00
Tfdn09=]?00209=^>P0609=^>@2EKd00UFm009A`@02BL400TG500P2@LT000`2>LT00UW9209Ib@P02
09Ib@P@0Ug=300P0W7Q809eiB@2NNTX0X7a<0:9nCP2SOdl0Y81@0:F1D@<0XWi>0P2SOdl30:B0D080
YGm>00H0YX5=0:N2C@2XPdh0ZHA=0:V5B`2ZQT`30:N4CP80Z8E?0`2YQU030:f8E080[8MC0`2[QU83
0;6<F080/8]G0`2_RUH20:j9G080[hYM0P2`Reh20;6<G`0@0;:>G02cSed0]Y9R0;RCIP2iU6P0^YE[
0;VDJP2iTf`0_9ac0;ZJL@2iVG00^YYa0;fMM02oWgH0_Ied0;^KLP<0`j1h1@34XGT20<6QN0<0`Z9i
0`33XgX20<2SM`030<6TNP31Y7`0`ZAn0080`ZB000<0`jF30<FUO035YG`00P36YWd30<NWOP030<RX
O`39ZH80bJV20080bJV21@3:ZX<80<^[PPP0cZj5203@[HD20<n/PP80d:f30`3A[X@01`3B[hD0dZn9
0=6^R03A[XH0dJj40=2^P@3@[X000P3?[Gd0103;Z800c:V10<bYP@3<ZH430<fZPP040<j[P`3?ZX00
cjZ00<nZP0<0d:^10P3A[8801P3?[Gd0d:in0=2^P03A[h80dZn50=>`R080e;6;203E/XP80=ReS@<0
ekB>0P3H]Hl30=VfT0040=ReS@3I]Xh0fKJ>0=VfSP80f[N?0P3K^9080=ZgT@80fKJ>0`3H]Hd30=Nd
S0P0f;F=0P3I]X`30=ReR`<0ekB:203E/XX30=>aP`80d[220`3A[h490=6^Q0P0dJj6203@[HD00`3A
[XH0d:f50<j[P`020<fZPP030<j[P`3@[HD0dJj600P0dZn7203@[HD80=2]P`<0dZn70P3C/8P30=Ba
R@P0dZn70100d;:<0=>cS@3D]8d0e[F<0=NdRP3H/hL0f;660=NaQ03D[h80dZf00=6/O`3?ZWd0cZUl
0<nZO@3@Zgh0dJao2`3=ZX020<bYO`<0bjQn203:Ygd30<fZP080cZ^10`3?[8801P3@[H<0cjb20<n/
PP3>Zh40cJZ00<bYO`80bjQn0P3=Z7/00`3<YgX0bjIi0<ZUN0020<VTM`030<RSMP37XWD0aj9e00H0
aj9e0P37XVh01036XFd0aJ1/0<BOJ`34Wf/20<>NJPT0`Im_0P2oWFd20;jLK0<0_I][00<0_9YZ0;fI
J@2mVFT01P2mVFT20;^IK0030;ZHJP2jV6P0^IQU0080^IQS00@0^IQR0;VDG`2iU5l0^IAO0P2hTeh3
0;NBG@040;BAF@2eTUX0]I9J0;FBFP80]Y=K0P2gU5`0102iUFD0^YIV0;ZFIP2jUVH20;^GI`80_9QX
0`2kUfL20;ZFIP<0^IEU0P2jUVH20;^GI`<0_9QX00H0_IUY0;nKI`2oVfL0_YYV0;fII@2lV6@20;^G
H`040;ZFHP2iUF40^IEQ0;VEHB_ooooo000Zooooo`P0Yge;202WOTP80:ElB0<0YWe90`2WOTX20:Qo
B`P0Z7i<00@0[HA@0:b3C`2ZPDd0Z7m;0P2WOTX00`2XOd/0ZH1<0:^2CP070:^2CPP0Zh9<0`2YP4`3
0:QoB`80Ygi:00@0Y7]70:ElB02UO4P0YGa80P2TNdL00`2QN4@0WgI209ed@00209]f@@0409Ye@02I
M3l0V7<n09Mb?@<0UW4l00l0UW4m09E`?02CKC`0TF/l091Z?@2?J3d0SVLl099Y?@2@Ic/0Rf@i08QS
=`26HCL0Pf0h089P>P23HC/00P21GS@00`20GC<0Oe`b07iK<@0207eJ<00907aI;`1iFR/0NEX/07QI
:`1gF2`0MUH]07EE;P1eEBl0M5@^00<0LE<_0P1`DRh306mA;@0806YB;P1[DB`0K58]071D;@1bEBd0
MED/07MF:`1hEb`207YG;@0407]H;P1mFS00OU/a081M<`80PEhd00h0Q60`08EQ<@26HS80R6@d08YV
=P2<J3P0SFTi08iZ>P2=IcP0SVPi091Z>`2AJc`0TV`m095[?080T6Xk202DJSP01P2BKCP0TVdi099]
>@2AJcX0TF/l095[?P80T6Tn00P0SVPi08mY>P2@JS/0T6Xk08mY>P2>J3T0S6Hg08]U=PP0TfPk00D0
SV@b091V=02BJ3H0U6Xh09E[>@0209AZ>00409=Y=`2BK3d0TF/l095[?080T6Xk0P2?JCX00`2>J3T0
SfTj08mY>P0608mY>P<0TF`h0P2BKCT3095/>00409A^?`2CKCh0Tfdn09=]?P@0TV`m00`0TF/l099]
>@2BKCT0TF`h091[=`2AK3P0Tfhj09E`?02FLCd0TVdi091[=`2>JCD208aW<`0308iY=@2@JcL0TVdi
00P0TF`h202BKSh209E`?0<0U6lk0`2CKSX00`2BKSX0Tflk09=_>`0409=_>`03099^>P2BK3/0TV`k
00H0TV`k202AKCd0202@K3P0Tflk09Ib?P2DL3`0TFdi08m[=`2BKSX0UG4m202BL40508ma?`<0T790
01D0Rflo08U]?@25JCT0P6@d07aP<01iGBd0N5`/07MK:`1[ER/0JUDZ06EB:P1PCRP0FDTW05E49P1A
@RD0Cd4V04@n:011>bD0>SDQ038_700];1X00P0Z:a/01`0Z;1h0:2/J02P[6P0W:A/09RPK02HX7@0U
9Qh00P0T9Al2024T6@03020S6P0O8Q/07R0K00807AlL00<071hM01`N6`0L7Q/00P0M7a`201hP7@80
7b4N0P0R9AX01P0S9Qd08bHO024S7P0O8Ah071hK01/M70<06adJ0P0J71T401TK600601TK6P0I6aP0
6Q`I01`N6@0M81T07b8I0P0P8aP0500Y9aX0;2XM038_7P0h<al0?CLQ040i7`11>Qd0@cXM03Tc6`0j
=1h0>C@P03Hc8P0`;R409bLM024Q6@0K71H08R8H02@T6P0V9Q`09bLM0P0X:1h0100W9ad09RHL02@U
7@0T9Ad202<T70808R<K0P0Q8QX@01lP6P0P01hO6@0M7QP07AhH01`M5`0M7QP07b0J028S7@0S91h0
;bLB03db701<@2P0Dd<Y05=08P1D?Ad0FT8P06989@1YDbX0NV<i08M_@`2=LD80UgM60:J2CP2/Qe80
ZhA=08e[AP1YCS40@S<P02`Y800W:BP08bLX02@V9@0W9R8302HV90809BDS0`0T92801P0U9BD09BDS
02DU8`0V9b809RLQ02LX80809bTN200U9B<09`0P9Q`08bTO02P[8P0X:B409bPP02XZ8P0a;RL0=S</
04Xd9`1B?bh0EdL^04i39@0n=aX0=2lI030/800`;BP0@cPV04i1;P1FBCH0E4D`04Xj8`15<a/0BcLN
05<o9P1OAbl0GT@[05e29@1R@b@0K4XU07aG;@2:I3L0UF`n099X>02TNTX0ZX1>0:1g@`2NMD40YWe7
0:5h@002091W;`0@065::P1MARH0FT4R05Y18`1NA2T0HDH[0614;01N@RX0IDX_0657;01L@RT0F40V
05@n9P1A?BD0CcdW04hl9P<0D3hV00<0CcdU04hl901>?2@00P1=>b<2058n9P07050n9P1??bH0CT0V
04/o9@1:?R@0BClT04/o9`0404Xn9P<0BCdU00@0Ac/S04Pl9018?2@0BCdU101:?RH01@1>?RD0D40W
0592:@1DA2/0EDD/0080E4@[0140Dd<Z04ho:P1>?bX0BSdZ04Ll:P13>bP0?cPV03df9P0k=BD0?SHS
03dd8`0l=B<0>S@T03Ld9@0e<bH0=C<W038b9P08038^9@0603<`8@0b;b00<RhR034]8P0`;2<0;bXT
0P0^:BD202l[8P<0<2`S0`0a;B@00`0d;R80=BlS03H`900203Pb9P0303H`900e;b<0=2hR00@0;RXN
100_:al0700`;2<0<BdT038^9@0c;bH0<RhU034]900_:b80;BTP02lW900`:2D0<2TS034Z8P0b:b40
=2hR03@^800e;b40>BlS03dc9`13=bT0@cHV04<c8`13<R80ASDS04Xh901=?280CchT05509P1D@bT2
05E4:P80Dd8X00P0C3/W04dl:01=?2P0CC`X04`k9`1:>BD0B3LS04He8@L0@CDU0P12=RH06`14=B00
ACHQ04Hg8P17>2<0B3TT04Tj9@1:>bH0Bc`W04Dj9016>R@0ACTQ04Pj801;>b40CchR05<o901E@R@0
D4<Q05548P1BABD0DT@W0553:01>@2H0C3dV04/l9@17?2X0AS/Y04@i9`0204<h9P0;04@i9`15>RP0
AS/Y04Dg7@18>R00BcdS04i09P1?@BL0CT0V04`n901:?2800P19?BD01P1;?B<0CCdS0550901D@bD0
FDHV05a7:080HDXZ1P1PBBT0;P1LB2D0H4TW06A>:@1ZDR`0LEP_07QM<P1mH3@0Of8f08A/?026KSh0
R71008Yb@P2=MDD0T7Q8099jBP2CNd/0Sh1E08]lD@28Md/0Qg9708UbB02>MTX0UW]@09]nE02QQeH0
Y8YI0:V?GP2^U6<0/IIW0;:GJ02aUVL0/9EX0;:ML02dWg00]j5b0;JNKP2eVfX0]YYX0;fOJ`31Xfl0
a:UV0<J[J03:[f`0ckAa0=:gM03D^GH20=FjM`080=BiPP3C^840dkEo0=:cO@3@[gX0d:ah0<jZMP3?
ZWH20<bYK`80cJY`00@0bjQ^0<ZWK@38YF/0aZ=Y0P2oWEh00`2nW5d0_I]L0;bJF`020;^IFP0:0;ZH
F@2lV5X0_9QJ0;bHFP2mVE/0^iMI0;RDEP2dT580/8a>0;F>B`80]Xm<00<0]i1=0;RACP2iTTl00P2i
TTl40;RED@80]iA@00<0]Y=?0;FBCP2dTDd00P2_Rdd20;2<CP040;6=C`2bSU00/hmA0;B@DP80^9EE
01H0]iAD0;FBDP2bSdl0[X];0:Z7A`2XQDD0YWdm0:El?02RNS`0WWPj09Qd>02CL3H0T6dc08a/<`2A
L3X0Tg<j09Ee?02JNSl0X8130:J7A`2/SD`0[i1?0P2gUTl0102iV5<0^YUF0;bJFP2mVe`20;nMH0@0
_I]K102lVUX00`2kVUD0_9]F0;jMF0020<2OFP030;nNF@2nWEP0_IaG00<0_IiM00T0^iaK0;VJF@2f
UeH0/iAC0;6BD@2FOD@0TgY108mf?@2<LcX00P2;LST208Ya>080R6lg0P29L3P0302:LCT0Rg8j08ed
?02=M3`0QVdd08ed>`2FO4<0W7m709ioB02POdT0Y8==0:V6D080Z8mG03H0ZI1J0:^AGP2]Tf80[Y=T
0:nDI@2`UFP0[99Q0:nEI02cUfL0]9EV0;BDI@2gUFL0_9Y/0<>NL@37Yh40cZj80=BfTP3G^YP0dkVF
0=2hUP3?^9P0d;VI0=6cS`3@/Xh0ck6;0<f`R03;[X@0bJb00<R[O`37Zg`0bJYl0<JWN@33Y7D0`ZAb
0;nQK@2gVF<0ZheG0::5C@2QPDP0ZhYD0;RGHP33XG40bJMj0<j[P`3C/8X0ek>?0=NgT03I^I80fkfG
0=k2W@3Qaj@0i<bZ0>O@/03Yd[820>cD^080jmJk00d0k=Ro0>_I`@3[fl@0jmc50>cMb03^gLT0kMg6
0>cJ`P3[ek`0jMBe0>SA[`3UcjX0iLfW0080i<^/00<0iLb^0>G;/03Vc;<00P3Vc;D02@3Wc;L0hlZ/
0>C;[@3Tc;00i<nd0>GA^03TdkT0i]Bl0>GE_0020>[Ia@80jm[6103/flL20>_Nc@<0k=o>0`3]h<l4
0?3QcP@0kn3=00@0l]g80?7La`3ag<L0l=_60P3_f/D20>kIa00F0>gH_@3/ek`0k=Bh0>_B]03Zck40
j/f]0>[;[03YbjT0iLNU0>C6XP3Ra:00h<:L0=g0V03K_Y@0fKb@0=RkS`3H/hH0ek:50=JaQ03C[X40
dJao0<nZO@80cJQk0100b:Ad0<NSL`35XFl0`Yi/0;nKJ@2lV6@0^YIR0;VEH@2cSUT0/XeH0;6<E`2^
RE@0[8MB0:Z5D02XPdh0Yh9=0P2UPE402P2TP500XWi>0:1lC02ONd/0WWY:09eiB@2NN4L0WGM609af
A@2JM4<209Uc@P80V79100H0U6m209=^@@2BKD00TF`o091[?P2>JC`208eX>`<0SfXm0P2>JC`308eX
>`80T6/n1P2?JSd0202BKS`0TFdk091/>P2?JcT0T6`j099^?02DL3h0UG4o2@2@KT0808aZ?003099^
?02AKC/0TFdk0080T6`j0P2?JcT01P2>JSP0TFXo095Z?`2AJch0TV`m099/>`80TVdi00H0Tfhi09=]
?P2CKCh0TFdm08m]?@2=KC`208a^?00A08Y^?02ELD40U710099^?P2@K3`0TFdm09=_?`2ELD40Ug=3
09UeA@2JMTH0VgM709eiB@2ONd/0XGe=0:9nCP2SOdl00P2ONd/20:1lC0<0XGe=00L0XWi>0:=mC02S
OD`0Y7m;0:AoBP2UP4/0YX5:0080Yh=90P2UPDd30:J2CP<0Yh=?1@2[QU830:Z5D@80[hYF0P2^RED4
0:f8E080[8QH0P2]RET0302^RUX0[h]K0:n;F`2`S5`0/HeI0;:>FP2dT5h0]Y9R0;RCIP2hTfL0]i9V
0;JAI`80^YU^00<0^IQ]0;ZIKP2lVg000P2lVg000`2kVVl0`Yme0<:OM@020<6NM0050<2ML`2oW780
_iab0;nLLP2mWW800`2nWg<20;nPM080`:5e00P0_j1b0<2QL`30XGD0`:1g0<6QNP31XG/0`Z9l0<:Q
OP80`j=j0`34Y7/30<FUO0<0ajMn1@38Z7l30<VYP0@0bZZ10P3;Zh880<b/P`P0cjb40P3>Zh420<n/
PP<0d:f300L0dJj40=6^R03@[HL0d:f50=2]P`3?[H00cjeo0080cZal1P3:Ygd20<^XOP060<ZUN@3;
YWX0bjIj0<bWN`3=Z7`0cZUm0P3?ZWh0203=[7T0cJ]k0<j/O03?[Gl0d:j10=6^Q03A[XH0dZn70`3B
[hD40=>`QP040=BaQ`3G]8`0ekB<0=NdS0@0f;F=00@0fKJ>0=JcR`3F/h/0e[>;0P3G]8`50=ReS@<0
fKJ>0`3J]hl80=ZgT@80fKJ>0`3H]Hd30=NdS0P0f;F=0P3I]X`30=ReR`<0ekB:203G]8`20=BbQ@80
dk640P3B/8<20=6_PPT0dJj4203A[XH80<n/Q0030=6^QP3@[HD0cZ^30080cJZ200<0cZ^30=2]Q@3A
[XH0203A[XH80<n/Q0P0cjb20`3A[XH20=:_Q`<0dk28203B[hL02`3?/H/0d[:<0=>cS03E]8/0e[>9
0=NbQP3G/8D0e[230=:]P03A[7l0cjYm0080cZUl00<0cjYm0=6/O`3B[H002P3=ZX020<bYO`80bjQn
0P3:Ygd80<RUN`<0c:Uo0P3=ZX030<j[P@80cjb200<0cZ^10<fZP03<ZGl00P3;Z7h01@3:Ygd0c:Mj
0<bWNP3;YWT0bZEh0080bJAg0P38XgH80<JQM080aZ9`00@0aJ5_0<BPKP33Wfd0`Yi/0P31WF/90<6O
K`80_Ya/0P2mVf/40;bJJPP0_9QX0P2iUfT30;RFIP<0^9MT0P2iU5l0102hTeh0]i9M0;NBG@2fTE`2
0;F@F`80]I9L0P2fTed40;NDGP@0^IEU0P2jUVH40;^GI`80^YIV0P2iUFD20;RDI0<0^IEU0P2jUVH3
0;^GI`<0_YYV00<0_IUU0;bHI02lV6@00P2kUf<30;RDHR_ooooo000Zooooo`P0Yge;202WOTP80:El
B0<0YWe90`2WOTX20:QoB`P0Z7i<00@0[HA@0:b3C`2ZPDd0Z7m;0P2WOTX00`2XOd/0ZH1<0:Z1C@07
0:Z1C@P0Zh9<0P2YP4`30:QoB`<0Ygi:00@0Y7]70:ElB02UO4P0YGa80P2TNdL00`2QN4@0WgI209ed
@00209]f@@0409Ye@02IM3l0V7<n09Mb?@<0UW4l00D0UG0l09A_>`2CKC`0TV`m091Z?@0208mX?@09
08eT=P2<HcD0RF<f08MR=P27HSP0QV<i08IU?027ISd0PUle0080PEhd00<0P5dc07mL<P1nFc400P1m
FS00201iFR/0NEX/07QI:`1gF2`0MUH]07EE;P1eEBl0M5@^0P1aDbl2071B;P80Ke4]0P1^D2`01P1Y
DBd0Je4/06aB;@1_Db`0LE@/07EE;080MeH[0P1mFS00101nFc40P5dc085N=023H3H208AQ=`0;08=O
;`24H300QF4a08MS<`29ICD0RfLg08aX>02=JCT0S6Hg08iX>@2@JS/00P2BK3d00`2AJc`0T6Xk08iX
>@0809AZ>006099]>02BKCT0TF`h095[>P2AJc`0T6Xm0P2@JCh00`2=IcP0SVPi08mY>P02091Z>`03
08iX>@2=IcP0RfDf00P0TfPk00@0SV@b08mU<`2AIcD0TfTg0P2DJSP00`2CJCL0TVPf091Z>`03091Z
>``0SfTj0`2AK3P2091[=`<0TF`h0`2CKCh2099/?@@0TF/l0P2AK3P2091[=`07095/>02CKSX0UG0l
09Ia?@2BKCT0T6/g08iY=@0208aW<`0308iY=@2@JcL0TVdi00P0TF`h202AKCd309A_>`<0Tfhj0P2B
KCT00`2CKc/0TVhj099^>P04099^>P0309=_>`2BKCT0TVdi00H0TVdi202AKCd0202@K3P0Tflk09Ib
?P2DL3`0TFdi08m[=`2BKSX0UG4m202BL4000`2=Kcd0SW0n08i`?P0208ma?`<0T79000H0S71008U]
?@25JCT0PFDe07eQ<@1jGRh207UM;@0=06eF;01[E2X0Ie4Z065=:01LBBP0ETDW05=29P1@@2H0A3hX
044k9@0j=B40<RlL02d/6P0202X[6`0702X/7P0X:aX0:2/J02LY6`0V:1/09RPM02DV7P0202@U7`80
8B@I00<082<J01lR6`0N81/00P0M7a`00`0L7Qd071hK01`N6`0201dO70807R0M0P0O8Ah2028U6P06
02<V7@0S9Ql08B<N01lQ7P0L7Q/06adL0P0K7AX201XL6@806A/H0`0H6QL0700H6QT06A/H01XL6@0K
7AP07B0I01hQ600O8QL082<H02PV6P0Z:1`0;b`M03Ha7P0k=240?cLP044j7P13>Ah0=c4I03Tc7@0i
=200=S<R034_8P0X:1h08B4I01/L5P0Q8AL08R8H02DU6`0W9ad202PX7P809bLM0`0S91`2028S6`<0
8B8J400O81X0800N7aT07AhH01`M5`0L7AL07AhH01lP6P0Q8Q`08R<M034Y5P0n<al0BclY05A4:`1F
@RL0F44R05a3901QAbH0IU0W07EN=023Jcl0S71109IfA@2SOd/0[8MB0;6:D`2EM4T0KeDb04Hg800_
;B40:2XW02<W:00S9B@09bHT0P0V9R@202DU8`8092@R0P0S8b401P0U9BD09BDS02DU8`0V9b809RLQ
02LX80809bTN200U9B<09`0R:1h09B/Q02T/8`0Y:R809bPP02TY8@0`;BH0=C8[04Tb;01=>R`0DT4]
04i39`11>Qh0=2lI02l[7`0`;BH0>RlM04@g901=@2d0CSlZ04Ph8@17=Ad0CSXQ05E1:01PARd0HTL/
06E8:P1/BbX0ME8/07mJ;P2:HC<0T6Hf08IL;02MLd<0ZGm=0:9iA@2PMd<0Ygi80:5h@002091W;`0A
06Y@:`1TBRD0GT@Q05]28`1NABL0H4H[05i6;01LA2`0JD/_06E:;@1RAb`0GD<Z05Lo9`1B?2@0D3`T
054m9@1A?bL0101@?RH304lm9@80DclW00<0D3hV04hn9@1<?R@00P1:?R@00`19?b@0C40X04a0:002
04/o9`0404Xn9P19?BD0BCdU04Tm9@D0Ac/S00L0B3`T04Tm9@19?BD0CCdT04lo9P1A@BP0Dd<Z0080
E4@[0180Dd<Z0592:@1>?bX0CChY04Tl:@16>bT0@CTV03hg9@0m=RH0>cDU044f9010=2@0?SDT03`e
9@0i<bD0=S8V03Hb9`0d<RH8038^9@0603<`8@0b;b00<RhR034]8P0`;2<0;bXT0P0^:BD202l[8P<0
<2`S0`0a;B@00`0d;R80=S0T03La9@0203Pb9P0303La9@0f<2@0=2hR00@0;b/O100^:Qh00`0_:b80
<2`S034]9002038^9@0C030/8`0^:R40;BTP02lW900`:2D0<2TS034Z8P0b:b40<bdQ03<]7`0d;R00
=bdS03/a9`10=2P0@C<V048b8`13<R80AcHV04dj:@0205A3:@0605E4:P1D@bT0Dd8X05919`1@?bD0
CSdS0P1=?BH01P1>?RL0CclX04hn9`1<?2D0BSXS04Ti8PL0@SHV0P11=BD2044d8@04048e8P14=b@0
ACPU04Lj9`80B3/X01@0A3TS04Di8`15>B40B3XP04/k8@1??R80E40U05I39@1A@R40DT<R05=49@1C
A2L0Dd<Y0551:01??bP0CCdV04Xo;@18?B/0AS/Y04Dj:080A3TW00X0ACXX04Hk:@14>1h0ACTO04Pl
8P1;?bD0C40V04/o9@1:?R@0B3`R0P18?RD01P19?B<0C3hS0511901D@bD0EdLV05]8:0<0HDXX1@1R
BbT07P1MBbL0H4`W06=?:P1ZE2d0KeLa07EL=01jGSL0O60i08E[>P27KC`0RFln08ec@P2AMdH0U7Y9
09MmC02IOdh0Th9F08mnDP29N4`0QW=908QbB@2<MTd0TW]B09InF02OQ5D0XXQG0:N=G02/TV40/9IS
0;:HI@80/iUV00h0_JQk0;jYNP2nZ7T0^j=c0;NMK02eVFL0^I]W0;fOJ`31Y600a:MS0<NZIP3;[VX0
c[5]0=2cK`80dKA`00P0eKQn0=BgO@3D]G`0d[9i0=:_M`3@[GD0cjYc0=2YLP80cJ]^0P3>[6l0103<
ZVd0bJMZ0<JTI`34XVD20<:PH@030<6OH030WUl0_ieN0080_YaM00T0_I]L0;^GF@2lV5X0_IUK0;bH
FP2iUEL0]91B0;6=C`2_Rdd00P2cS4T0102dSDX0]Hi;0;J?C02gT4d20;RACP040;NDDP2fTe40]Y=A
0;JCD@D0]I9@00@0[XY<0:n;C@2`S4h0/He?0P2bSU020;>?D@80^99C01l0]Y1A0;B>C`2`RT/0[8I7
0:R2@`2UOd00WgLj09ee>02JLcP0UG4g095^=P2?K3H0RfXd08UZ=02@KcT0TG4h09Ad>`2HN3d0WWi1
0:B5A@2ZRdX0[Hi=0;FDC@2fUDh0]iIA0;VHE@2kVET0_I]L0;jLG`2oWF00_I]K0080_9YJ0P2kVET2
0;ZHF0040;VGE`2iV5<0^YUD0;bKEP80_YeH00<0_IaG0;bKEP2kVUD00`2kW5/02P2jVeX0^9UH0;BE
E02aTU40[i1?08mi?`2>N3h0SGLm08Yd>P27LCL208I`=P0508Ma=`26KCD0Qfhf08Q_=`29L3P00P2:
LCT208]b>P0N08A[<P2;LST0U7Y109YmA@2KO4D0WGa60:1oB@2UPT`0YH]B0:J<D`2XSEH0ZXmJ0:b@
GP2^TV80/9AT0;2DI@2]Tf80/9IU0;>GI`2dUFH0/i=T0;JDIP2kVF/0`Ye`0<FUO`3=[HL0e;JB0=Rk
V@3E^iP0d[ZH0P3A^YX08P3@/i40ck:@0<jbS@3</8T0bZj60<R]PP37[840aZ]n0<RYN`35YWP0`Z=d
0<6SL@2mWf/0]IMQ0:V;E@2PPd/0XH580:^:E02jVF@0a:9b0<ZXN`3>Zh<0dk2:0=JbSP3G]i40fKVC
0=^mV@3N`Il0hLNV0>C;[03Wd;40jM:c0>WD^@3ZeKX20>[F_@0M0>WG_`3Zf/<0jmc70>[Nb03ZgLX0
k]g90>cLa@3[fL40j]Jk0>OB/`3Vcjd0hlfX0>?;Y@3SbZ/0i<^/0>C;[@3TbZl0iL^b0>G;]03Vc;D0
i/^f0>;:[P3Sbjl0hljc0>C@]@3TdkT0i]Bl0>KF_`3Vel000P3[f/P30>cKb@<0kMc:0`3/glh30>gP
c`80k^7@0P3ah<`20?3Ob`80kmk:0P3^gLT20?3J`P040>oI`@3^f<00kMNo0>cF_P80jmFm0300k]Ff
0>gD]@3/d[40jlj/0>[<Z03Yb:D0j<JQ0>O5X03S`I/0hL2G0=nnU@3L^i00fKR;0=JfQ`3D]8<0dk>2
0=2/NP3?ZgT0cJUg0<^WM@38Y780aZ9`0<BPKP33Wfd0_Y]U0;fJI02kV680^9AP0;JBGP2cSe/0/HeK
0;2<FP2/Qe80ZhIA0:V4C`2WPTd0Y7m:0:9mB02QO4L0X7]609mkB`2NNTX0WGU909ahB02KMdL0VWI6
09UeA@2HM4@409Qb@`0409Ma@P2FL440UFm009A^?`80TVe100D0TFa008mZ?P2>JCd0SFPl08aW>`03
08]V>P80RVDi0`29I3P00`28HcL0RfHj08]V>P0608aW>`03091/?02?Jc/0SFTi0080SFTi00<0SVXj
091/?02AKCd02@2;Jc`808YX>P@0SVXj102=JCT208mX?@0608mY?02@JS/0TF/j095/>02BKCT0TVdh
0P2@JS/03P2?Jc/0S6Xj08][>P2:K3X0RF/i08M[>@2CKcl0TFdm08iZ>P2=JCT0SVXj091/?02DL400
UW920P2GLd<0102IMDD0VWI609ahB02MNDT209mkB`0409ahB02MNDT0WGU909eiB@80WWY:0P2ONd/2
0:1jB@040:5lB02RODP0Xgi90:AoB080YH570P2SOdd20:B0CP@0YH5?1@2YQ5030:Z5D@@0[8MC0P2[
QU820:Z5D@80ZHEC0100ZXID0:^7E@2/R5H0[HUG0:j:F02_ReT0[haF0;6>F02cSe/0]I5O0;FAH@2e
T6<0]8mR0;B?H`2hUVT0^IMZ102jV6/00`2kVF`0_9Y]0<2NL@020;nML0050;jLK`2mVfh0_9Y]0;^I
K02jV6/00`2jVfd20;^LKP<0_9e_0P2nWVl00`2nWG00_iic0;nNM@020<2NN0040<2NN@31XGP0`J5h
0<6QN0<0`Z9i0P33XgX20<BUN@80aJIj0P36Yg/30<NXO080ajMn0P38Z7l20<VYP080bZZ1203;Zh88
0<n/Q0040<fZP03>Zh40cZ^10<j[P@80cjb20P3@[H<20=2]Q`060<n/Q03?[880cZao0<j/OP3>[7`0
cJ]k1@39YgX30<RVN@80b:=f00<0bJAg0<ZUN03;YWT00P3<YgX0203=Z7/0bZUd0<ZYMP3;ZWL0c:Yj
0<f[O@3>[7l0cZ^1103?[8800`3@[H<0dJj40=6^Q0020=:_Q@<0eK::00<0e[>;0=NdS03G]8`00P3H
]Hd30=FbR080e[>90`3G]8X30=ReS@<0fKJ>0P3J]hl80=ZgT@80fKJ>0`3H]Hd30=NdS0P0f;F=0P3I
]X`30=ReR`<0ekB:203G]8`30=BaQ`80dk26303B[hD80=:_Q`P0d:f500<0dJj60=2]Q@3>Zh<00P3=
ZX800`3>Zh<0d:f50=6^QP080=2]Q@P0cjb4203?[8830=2]Q@80dJj60`3B[hL80=6^QP0;0<j`RP3A
/H/0d[:;0=BcRP3E/XP0e[650=J_Q03E[h80dJao0=2[OP3?ZWd00P3>ZG`00`3?ZWd0d:]n0=6/O`0;
0<bYO`80bjQn0`3:Ygd80<RUN`<0bjQn0P3<ZGl30<fZP0060<n/PP3>Zh40cZ^10<fZP03<ZGl0bjQn
0P3:Ygd20<^VN@80bZEh00@0bJAg0<RSMP37XWD0aj9e2035X7<20<FQL@040<BPL033Wfl0`im_0<:N
KP80`Ie]2@30WVh20;fKJ`<0_9YZ0`2kVFT80;^GI`<0]iIS0`2hUVH20;RFJ0050;VDG`2hTeh0^9=N
0;NBG@2eT5/00P2dSeX0102cSUT0]I9L0;FBG02eTU`20;JCG@<0]iAN0`2hU6@30;VEI@D0^YIV0P2i
UFD30;RDI0040;NCH`2hU6@0^9AT0;RDI080^IEU0P2jUVH20;fII@<0_9QT0`2kUf<30;RDI2_ooooo
000Zooooo`P0YWa:202WOTP;0:ImB@<0Ygi:0P2XOd/80:MmB`070:b3C`2[PTh0ZH1<0:QoB`2WOTX0
Z7m;0:V0C0090:Z1C@P0Zh9<00@0ZH1<0:QoB`2XOd/0Z7m;0P2WOTX20:ImB@040:ElB02VODT0YWe9
0:ImB@80YGa800<0XWU50:1g@`2NMD400P2KMT40102JMD00VG@o09Qc?P2GLSd209Ia?00609E`>`2D
Kc/0U6lk09=]?02BK3d0TF/n0P2@JCh0202<I3<0Rf<b08QR<`26HC@0Qf8f08MT>P28Ic`0RFPo0P22
GcD00`21GS@0P5dc07mL<P0207iK<@0907eJ<01iFR/0NEX/07QI:`1gF2`0MUH]07EE;P1eEBl0M5@^
00<0L58^0P1_DBd306i@;00806UA;@1ZD2/0Je4/06mC;01aE2`0M5@[07IE:P1gER/207iK<@0407mL
<P21GS@0PUle08AQ=`80QF8h00/0Pel_08AP<025HC40Qf<c08UU=@2;IcL0S6Ph08eY>@2;ICH0SFLh
091Z>`02099/?@03095[?02?JCX0SFLh00P0U6Xh00H0TVdh095/>02AK3P0TF/j091Z>`2@JSd208mX
?@0308eW>02>J3T0T6Xk0080TF/l00<0T6Xk08iX>@2=IcP0202CJ3/0202@IS@0TFLe09=Y=`2DJSP0
UF/i09AZ>02CJCL0TVPf202?JCX8091Z>`03099]>@2AK3P0T6/g0080SfXf00<0T6/g095/>02BKCT0
0`2AJc`6099/?@80TF`h00H0T6/g08mZ=P2@JcL0TVdi09A_>`2EL3`2095/>004091[=`2?JSH0SfXf
091[=`80TF`h202BKCT8095]?@<0U6lk0P2CKSX3099]>@0309=_>`2BKSX0TFdi00<0TFdi00<0TVhj
09=_>`2BKCP01`2BKCP8095]?@08091/>02CKc/0UW8n09A`?02AKCT0Sf/g099^>P2ELCd8099`@003
08a^?02=Kcd0SFlm0080SFlm0`2>L3h01P2<L400RFdm08IZ>P21ICD0OV8b07aP<080Nel_00d0KUD/
06eD:`1YDB/0I4hY05e9:01HABL0ED4V05919`14?RP0@C/U03Xe8@0b;a`0;B`J0080:R/K00L0:R`N
02P[6P0X:aX09bTK02HX6`0V:1d09BHN008092DO0P0Q91T00`0P8aX07b8K01hP6`0201dO700301`N
7@0L7Q/071hK00807AlL0P0N81d201lQ7P808RDJ00H08bHM02<V7`0Q8ah07b4N01`N6`0K7A`301XL
6@806A/H100H6QL01P0H6QT061XG01TK600K7AP071lH01hQ60807b8G01@09b@K02TW6`0]:Ad0=2hN
03Tb7`0n=R40@3TO04<i800h<QX0>C<M03Pc7`0e<R40<2hQ02PX7P0R8QX07AhH020P5P0Q8AL092@J
02HV7080:2PN0P0W9ad202<T70808R<K0`0Q8QX00`0P8AT07b0J01lP6P0>01lP6P0301dN600L7AL0
71dG008071dG01/07QlI024R700R8ad0;bHE03/`7P19?2T0Dd</05M3:P1I@BD0G4<U05m49P1SCB@0
L5T_081X?02<L440UGE40:1lB02/Qe80]XmH09]kC01eG3@0BS`Q034_8P0Y:bH08bLX02<T9P0V92D0
0`0U9B<202@T8P<08b<Q00H09BDU02DU8`0U9B<09RLR02HW8@0W:20202LY7PP09BDS02L09B/Q02P^
900[;RD0:R/S02LX800X:200;b`U03<`:@15;Bd0AS8[04`k:@1=@BL0@c`P03D`6P0_;1d0<BhU03H[
6@0m<1d0@cHS04Tj9@1;>b@0CC/S05<o9P1G@bX0I4P`06U;;`1_D340N5Hc085K=028HSD0T6Hf099X
=P23FBT0UF/k0:5gA@2QN4@0XWU50:ImA`2PMcl00P2CJS80401hFc40Ke<[06A88`1M@b00G4<T05e5
:@1LARh0FdD]06Q9;01XBbd0IdT]0615:P1I?bH0E3`T054k8`1C?BH7054o9`09050n9P1E@BT0E40X
050n9P1=?B@0C3hT04Tm8`1:?R@0BClT0080CD4Y00<0C40X04/o9`1:?RH00P19?BD00`18?2@0Ac/S
04Lk8`0304Hj8P0I04Lk8`19?BD0BShV04hn9@1??bH0DD4X0592:@1C@bX0DT8Y0551:01@@2L0CSlZ
04dn:@18>bP0A3TW03lg900m=R@0?3DU03/e9@13=RD0@SDU040d900m=2D0>c<V03Pb9P0203Da9PP0
<RhU00H0<c0Q038_800b;R80<BdR030/8`0_:R@202hY9@80;b/R0`0`;2<3034]900303D_8`0f<2@0
=c4U0080>38V00@0=c4U03H`900e;b<0<BdQ0`0`;20302l[7`0902hZ7P0_:b80<2`S034]900b;RD0
<BdT030/8`0^:R40;BTP0080<BTV00@0<BXT038[8`0b:b40<bdQ0P0c;Al0600e:b80>2hU03ha:00o
<BH0@30S04<a8`19=bT0Cc`]05M6;01FAB/0ED@Z05=2:01A@2H0CchT04dl8P1<>b40CCdT04hn9@1?
?bH0D40W04lo9P1>?RD0C3`S04/k8P80@SHV0P13=bL08@14>2P0@cLW048f9P11=BD0@3@T03ld8P10
=B<0@CHT048g9@13>2H0A3TW04Dj:016>bT0A3TS04@h8P15>B40B3XP04/k8@1??R80ED4V05I39@1C
@b80E4@S05E49P1EA2P0ED@Z05=1:@1A?bT0D3hX04a1;`1;@2h0B3d[04Hk:@0304Dj:00504Hk:@15
>b00AC/P04Hl8@17?B800P18?R<02P19?b@0BT0U04M09P17@2H0BClT04]0901@@RD0E4DV05M89`1J
BRT306A>:@80IDlZ0`1VD2/0;@1PDBX0He4[06EC;@1YEC00KELb075I=@1dFSL0ME/h081T<P22IS@0
QVXh08]_?@2@M480UGU709UmB`2KOdd0UXAF09>1D`2>OE40RgY?08]iD@2=NeD0TGmK09B2GP2NPe@0
X8EF0:>9F02XSU/0[IAN0;:IH@2fWFD0^9mV0<>^P@34[h00`jen0;jVMP2iWfh0]YYX0;ZLJ02mWf/0
`J5T0<>SIP36YVT0bJU/0<b/K`030<f]L00:0=BfN03C]GL0d[9e0=:`L`3?[G00cZY^0<jWK03=YV/0
c:QZ0<fYJ`80cZY/00@0bjMY0<NSI@33Wf40`IeO0P33XF800`32X640`ImP0<2NG`020;nMGP0?0;jL
G@2iUEL0^iMI0;bHFP2iUEL0]91B0;2<CP2^RT`0[h]=0;6:A`2bRdP0/ha90;B=BP2eST/0]i1=0080
^95>00@0]iAD0;JCD`2fTe<0]I9B0P2dTE401P2eTU80]Y=C0;NDE02`S4h0/He?0;:>D0<0/hmA0P2b
SU003P2eSDl0]8a>0;>;C@2`R4X0[8A60:Mo@@2RNS`0X7Pj09M`=`2FKcH0TVdf08m/=P2=JS@0RfXe
0P2:JSL0202@KcT0TG4h09Ad>`2HN3d0WGe00:>4A02XRDP0Zha;0P2eU4d01P2gUU40^9MD0;ZHF02l
VU/0_I]N0;jLG`80_9YJ00<0^iUI0;ZHF02iUeL00P2hUUH0102gUED0]iIA0;RGDP2jVE@30;bKEP0;
0;^JE@2jVE@0]iQG0;RIF02iVUT0^9UH0;JGEP2bTe80[Xm>0:^<B`29M3/00P2;MSd02@29M3/0Q6lf
089]=024KcH0QW4h08=Z<P24Jc<0QVde08M^=P0408Q_=`0N08E/<`2:LCP0TGLn09Ii@@2FMd00VGQ2
09akA@2ROdT0Y8M=0:F8CP2WRU80ZXaF0:b>FP2_TEl0/I=Q0;:CI02]Tf80/9IU0;>GI`2dUFH0/i=T
0;FCI@2jV6X0`Ia_0<BTOP3<[8H0e;JB0=VlVP3G_IX0dk^I0P3B^i/0803@/i<0ck:B0<jaS`3</8/0
bZj70<R/Q037Zh<0aZ^00<RYN`35YWP0`Z=d0;nQK`2lWVX0/iEO0:N9D`2NPDT0XH580:b;E@2kVVD0
aZAd0<^YO03?[8@0dZn90=FaS@3G]Y<0fKRE0=^mV`3N`J40hLJX0>C;[@3Wd;40jM6e0P3Xe;/20>SF
_P0M0>SH`@3Yf/D0jMc90>[MbP3Zgld0kMc80>cLa@3Zf<00j=Bi0>KA/P3TcJ/0hL^V0>79X`3RbJX0
hlZ[0>?:[03SbJh0i<Za0>C:/`3Ubk@0iLZe0>;=/03Sc[<0hlnd0>?B^03Ve;`0imO00>SIa03Yf/D0
0`3/fl/20>gLc0<0k]g=0`3/glh20>gPc`<0k^7@0P3aglT00`3`g/P0kmg70>kLaP020>gKa@070>cJ
a03_ek/0k]Jj0>gE^@3/e;P0j]:f0>WA]@020>S@]00X0>_>[03ZcZT0jL^W0>S8XP3U`id0hl2H0>6n
U03R_I<0g;N;0=^fRP3H/hH0eK610=6]N`3>ZWH0bjMc0<ZWL@36XF`0aJ1[0<>NJ@30VfH0_YUT0;^F
H@2iU5l0^9=N0;BBE@2bSeD0/8eE0:j;D`2[Qe<0Z8A@0:J2D02UPE40Y7m;0:=nBP2QO4P0WgY609eh
A02JMD40VGA009Qc?`80V7A400@0Ug=309Ib@P2ELD40U7100P2CKcl0202AJch0TV`o09=]@02CKD00
TV`o095[?P2@JSd0SfTl0P2>JCl0102=J3h0S6Lm08aW?@2;IS`208YU>`80R6<i0P27HSP308IQ=`03
08EP=P28HcT0R6<i0080R6<i0P29I3X208YU>`0308iY?02=J3/0RfHi0080RVDh00<0RfHi08eX>`2>
JC`02@27J3T808QV>0P0RfHi0P2=IS/01P2>J3/0SVPi08mY>02@JcL0TF`h095/=`80SVPi00<0SFTi
08]Y>@2:JST00P29JcT00`27JcT0T6`l08m[>`0308eY>@03091/?02CKcl0U7100080UW9200<0Ug=3
09QdA02IMDD00P2JMTH0102KMdL0VWI609YfAP2JMTH209]gA`<0W7Q80P2NN4L01P2ONTH0X7]60:5l
A`2RODH0XWi40:=oA@80XGe=0P2ROTh20:=oC`80Y81@0`2WPTh20:R3C`<0ZHA@0`2ZQE420:V4D0<0
Z8=?01@0YX9>0:N3C`2XQ500ZHEA0:^7D`2/R5@0[HUE0:j:EP2^Re<0/8eE0;6>F02cSe/0]91N0;>?
G`2bSUh0/HaO0;NBI@2jUFP0_9MZ0;^FJ@80^IAW00D0^iIY0;fHJ`2lVV`0_9Y/0;^IJ`020;ZHJP03
0;VGJ@2hUVP0^9IX0080]YMX0`2gV6T30;RIJP80_9YZ00@0_9Y/0;fKKP2mVW00_Y]c0P2nVgD0102n
WWD0_imf0;nOMP2oWgH20<2PM`80`J5h0P32XgL01@33Y7P0a:Ei0<BUN@34YGT0aJIj0080aZMk0P35
YG`01036YWd0ajMn0<RXO`38Z7l20<VYP0P0bZZ1203>Zh<0103<ZGl0cJZ00<fZP03=ZX020<j[P@80
cjb20P3?[8H01`3>Zh<0cZ^10<f[OP3=Zgd0cJ]k0<bZNP3:Z7X00`39YgT30<RVN0030<NUM`38Y7@0
b:Ad00<0bJEe0`3:YWH01P37YW00b:Mb0<RWLP39Z7D0bZQh0<^YN`80c:Ym0P3<ZGl0103=ZX00cZ^1
0<n/PP3?[8820=2]P`80dZn70P3C/8P0103D/HT0eK::0=JcR`3F/h/30=BaQ`80eK:80`3F/hT20=Nd
S080f;F=0`3I]Xh00`3J]hl0f[NA0=ZgT@060=ZgT@80fKJ>0`3H]Hd30=NdS0P0f;F=0P3I]X`30=Re
R`<0ekB:203G]8`0103E/XX0e;690=BaR@3D/HT20=>`R080dZn72@3B[hD80=:_Q`T0dJj600L0d:f5
0<j[P`3=ZX80cJZ20<j[P`3@[HD0dJj60100cZ^3203>Zh430<n/Q080d:f52`3A[XH0303=[hT0d;2:
0=6aRP3C/XT0e;670=F`Q03E[X<0e:j10=:]P03A[7l0cjYm0<jYO080cJQk0P3?ZWd:0<bYO`80bjQn
0`3:Ygd90<VVO0<0bZMm0P3;Z7h30<bYO`80cZ^100<0cJZ00<bYO`3;Z7h00P3:Ygd01`39YW`0bjIi
0<ZUN03:YGP0bJAg0<RSMP37XWD00P36XG@80<BOLP80`j5c00<0`Z1b0<6OL@30WW000P2oWFl00`2n
W6h0_Ya/0;jLK0070;jLK0<0_9YZ0P2kVFT30;ZHJ0P0^YIV00H0]iIP0;NFH@2hUf80^9MT0;VGI`2i
UfT20;VGJP060;VDG`2hTeh0]i9M0;JAG02dSeX0/hiI0P2bSEP20;>?F`80]91L0`2eTEd0102fTUh0
]i=S0;NCH`2gTf<20;RDI0<0^IEU0P2jUVH20;VEI@<0^9AT00@0]i=S0;JBHP2fTV80]Y9R0P2gTf<3
0;RDI0P0^YIR0`2gTVD[ooooo`00:_ooool80:IlBPP0Ygi8202XOd/30:ImB@<0Ygi:0P2XOd/80:Mm
B`080:Z1C@2YP4`0Z7m;0:MnBP2XOd/0ZH1<0:^2CP2/Pdl80:V0C0P0Zh9<0`2XOd/20:MnBP<0YWe9
0P2WOTX20:QoB`80YWe900<0Y7]70:5hA02PMd<00P2KMT40102JMD00VG@o09Qc?P2GLSd209Ia?00@
09A_>P2DKc/0Tfhj09=]?02BK3d0TF/n095Z?`2@JCh0SfLd08iV<`2:I3<0Qf<c08IQ=025HcH0QF@g
08IU>P80PUle0P21GS@03020GC<0Oe`b07iK<@1nFc40NEX[07UJ;01hFB/0MeP/07IF;@1eEBh0MED_
07AD;P80L58^0P1_DBd406i@;00>06Q@;01ZD2/0Je4/06iB:`1aE2`0M5@[07IE:P1gER/0NeP^07aI
;`1mFS00OU/a07mL<P21GS@2089O=@80Pel_00@0QF4a08MS<`28I3@0RVHf0P2<J3P0202:I3D0S6Hg
091Z>`2BK3d0Tfdn095[?02>J3T0S6Hg202DJSP01P2AK3L0TF`h095/>02@JST0T6Xk08mY?080SfPm
00<0SVPi08mY>P2AJc`00P2BK3d00`2AJc`0T6Xk08mY>P0809=X>`0809=Y=`2DJSP0UF/i09I/>P2E
JcT0U6Xh099X=P2AIcD308iX>@D0SfTj202AJc`00`2BKCT0TF`h08mZ=P0208iY=@0308mZ=P2AK3P0
TVdi0080SfTj00<0T6Xk095[?02BK3d00P2BK3d209=]?P08099]>@2AK3P0T6/g08mZ=P2@JcL0TF`h
09=^>P2DKc/2095/>004099]>@2CKSX0Tfhj099]>@80TF`h202BKCT8091/?00409A_>`2CKSX0Tfhj
09=^>P80TVdi0P2AK3P00`2CKc/0TVhj095]>@02091/>003095]>@2BKSX0Tflk00P0TVdf202AKCd0
202@K3P0Tflk09Ib?P2DL3`0TFdi08m[=`2BKSX0UG4m202BL40408a^?0@0Rfdk00H0S71008Y^?P26
JSX0PVHf07mS<`1mHC4207aP<00=075E;@1]E2/0JU0[06E=:@1PBBT0FTDX05I29`1D@2L0A3hX044k
9@0j=B40<RlL02d/6P0202X[6`0702X/7P0X:aX0:2/J02LY6`0V:1/09RPM02DV7P0202@U7`808B@I
00<082<J01lR6`0N81/00P0M7a`00`0L7Qd071hK01`N6`0201dO70807R0M0P0O8Ah2028U6P0602<V
7@0S9Ql08B<N01lQ7P0L7Q/06adL0P0J71T201TK60D061XG01h061XI01PJ5`0I6aP06Q`G01`O600M
81L07R4F01lR5`0V8a`0:2DL02`X7@0b;1h0=c0N03de8010>240A3XQ03Tc6`0i<ad0=c8N03<`7`0_
;B00:2PN02<S6`0O81X07alE024Q5`0S8aT09RHL02LW7@0X:1h202LW7@<08R<K0`0Q8QX2020Q6A00
7b0J02007AhH01`M5`0K71H06a`F01`M5`0N7aT0824K028S7@0Y80l0=BTI048e8P1>?BT0E40X05Q0
9P1I@280Fd0S061:8@1]ER`0OFDi08a`@@2DM4<0WWY60:^6D@2iTU/0X81=07UQ=@1=?b80<S0Q02T[
9P0S9bP08b@V02HT9`809BDS0P0T928402<S8@0602DU9@0U9B<09BDS02HW8P0V9b409bPP0P0W:Ah8
02DU8`0W02T_9@0[<BL0;C0W02//900W:2009bLO02`Y8P0`;BH0@BP/03lZ9@15<bD0BclW04@m8`0e
<1X0;R/L038_9P0k<1h0?2lL03lb7`18>B@0DD4Z05I4;01HA2/0Ed<Z0697;01VB2`0KTd^07ID;`21
G380S6<e09AZ>02IKS/0SV@d09=Y>@2IKcd0WWE10:=jAP2UO4H0XGQ00080VW4i0100QfPj07UL<01Y
CBD0GD<N05U28P1IA2L0FTH]05U7;`1VAbP0J4TZ06Q;;@1QART0FClT05<k8@1D?280E3hV1@1A?bL3
0590:00905I2:P1D@2P0D3hV04dm901;?B<0BCdS04Xn9019?b@0CT8Z0080CD4Y00@0C40X04Xn9P19
?BD0BCdU0P18?2@02P17>b<0ASXR04Di8@16>R80B3`T04Tm9@1;?bL0CclV05109`1A@BP20592:@0A
05109`1>?RD0CCdT04ho:P1<?BP0AcXW048g9@0n=R<0?3DS03`e9@0k=BD0ASHV04<f9P12=BD0@3@V
03`b9P0i<BH00P0g<2H8038^9@0603<`8@0b;b00<RhR034]8P0`;2<0;bXT0P0^:BD202l[8P<0<2`S
0`0a;B@00`0e;b<0=S0T03Pb9P0203Tc9`0403Pb9P0f<2@0=BlS03<_8`80<RhR0P0a;B42030/8003
02l[7`0_:b80<2`S00<0<BdT00T0;b/R02dY800/:1l0<RXW03<[:00c;2H0<b`T03</8P0d;R800P0d
;R00200c:280=R`S03`_9`0m;bH0?bhT04<a9@1:>2X0D3d_0P1C@RP00`1B@BL0DD0V050o9@0204ln
900904hm8`1>?R@0CclU05109P1A@BL0D40V04lo9@1=?B<0C3`R0080@SHV00L0@cLW04@h:015>BT0
A3PX048f9P10=2@0?c<S0080?SDT00@0?cHU040g9P10=bH0@CPW0P12>BP05@13>280A3PR04@h8018
>R00Bc/Q050o8`1E@BH0Ed@V05E28P1F@b<0Ed@V05Q4:@1G@bX0ET8Z05@o:P1C?RT0Cd@b04e2<01:
?bd0Ac`Z04Hk:@0204Dj:00B04Hk:@15?R80A3dQ048k7`11>Qh0@S/O04Dn8P18@BD0BT<W04M19`18
@BL0BD8V04a39P1?A2H0E4LW05U::@1KC2/0Ie4Z0P1XDR/206UC;080JU@]02d0JeD^06EF;@1VEbh0
J5H`06YF<@1/EC<0KEHd06iE=P1_ESL0NedY07iP;022I300R6Xf08ma?@2EMd<0VWa809eoB`2JR5P0
VHMI09J5F@2DPUX0TX=L09B4H02EQVD0UXMV09n4E`2OQ5D0XXQG0:J<F@2]U5`0]IaS0;bTJ030Z6X0
`jj10<B_P034[Wl0`:Qh0;bRL@2jWV`0_j5]0<:TL034Xfd0aJA^0<RWL@3:ZG<00P3<ZgD20<^ZM00:
0=2bLP3@/G40ck1`0<j/K@3=ZF/0cJMY0<bTI`3;XfH0c:IW0<fWJ080cZQY00@0bjEV0<JPH@31Ve`0
_YQI0P30WUl00`2oWEh0_YaM0;fKG0020;bJF`090;^IFP2gTeD0^IEG0;VEE`2eTE<0[XY<0:^7B@2]
RD/0/He?0080/HY700L0/ha90;B=BP2fSd`0]i1=0;RACP2iTTl0^9EE0080]iAD03@0]I9B0;BAD@2e
TU80]Y=C0;REE@2iUUH0/hmA0;B@DP2eTE<0]Y9D0;FAD`2dT580/Xi@0;6=C`2aRD/0/8Q:0:j6B02[
PdD0YWi00:5i>`2LM3H0VG4c099[=02?JS<0SFPc08]W<`29J3D0RFTh08Y/>P2;K3d0TG0j099b>@2D
M3/0V7Pm09em@02SQ4@0Z8U80:^<B`2eU4d0]YE>0;NFD@2hUe@0^IMG0;ZHF@2kVE`0_9YM0;bJFP2k
VET0^YQH0;VGE`2hUUH0]iEE0P2fU5@02P2fUE00]iIA0;VHD`2jVE@0^iYE0;ZIE02iV5<0^9MB0;>D
D`2eUUD20;JGEP0@0;BEE02_T4l0ZX]:0:N8A`25LSX0R7Dm08Yg?`27M3`0PVlg07m/=021KSH0Q74i
081W;`21J300PfXb08E/=080QVde0200QF`d08A[<`28KcH0Rg8i091f?@2BMCd0TW<l09Ac?@2IN480
X7e70:>5B@2TQD`0YXM>0:V:D`2/SEL0[hmL0;6AH02cTf80[I=R0;2FI@2cUfL0]9EV0;:BH`2dTV@0
^IMY0<2KKP32XW`0bj^50=BfTP3J_I/0f;jK0=FmV`80dkbL0280c[>E0<fcTP3</Y40b[2=0<R^R@36
[HD0aJb30<B[PP37Z7X0a:Eg0<6RL`2nX6h0^ieY0;:DGP2VR580W7m70::2B@2]S5H0_9]V0<NUM@3<
ZWd0cjb40=:_R@3D/8`0ekJE0=VhU`3K_9d0g/6S0>76Z@3Tbjd0ilnc0>WA]@3Udk/0i]Bl0P3Ve[l0
3@3Wf<40im_50>WLb@3Zgld0jn3>0>gLb03[fl@0jMNo0>OC^03Tck00hlbZ0>3:Y@3Oaj400P3RbJX0
0`3RbJ/0hlV^0>?9/0020>C:/`090>C9]03Sc[<0hlnf0>GA^03Ve;`0imO00>SIa03XflP0jMc900<0
kM_=0P3^g<h30>oMc`040>cOcP3]h<l0kN3?0>gPc`80k^7@0P3_h]420?7La`040?3KaP3_f/D0k]W4
0>gH``80k=O20P3[e;D0;P3Zdk@0j=6b0>O@/@3UcZl0i<f^0>?<[@3SaIl0i<BM0>71VP3O_YD0g;V?
0=ZeR@3I/hH0ek640=:/O@3@ZW/0cJMf0<VTL035X6/0`IaU0;jIHP2lV5h0_9EN0;^DG@2hTEX0]XmH
0;><E@2`RE80[XM@0:b5CP2XQTH0YhE60:F3AP2ROdL0Wga609ahA02JMTH0VGE509]eA02JM4<0V791
09I`?`2DKSd0TF/j091Z>@2?JCP2091/?00408m[>`2>JSX0SVXj08eY>@80S6Ph00P0RF8g08YS>02;
I3T0S6Dj08]T>@2:HcP0R64f08MP=@80R6<i1P27HSP308IQ=`80QF0f0`24GcD308EP=P0308IQ=`27
HSP0Qf8h0080R6<i00<0S6Lk08]V>P29I3P00P28HcL00`29I3P0RVDi08]V>P0908EV=`P0QfDg0`29
I3P508YU>@80Rf@i00<0S6Hi08eW>02>J3L00P2@JcL02@2AK3L0S6Hg08aV=`2<J3P0RVPh08YZ>@2:
K3X0Rfdk08U]>`0308eY>@0508iZ>P2?Jc/0TFdm099^?P2CKcl0202FLT8309QdA080VGE50`2JMTH0
1P2LMTD0WGM609ehA02NND@0WgY50:1kA080XGe30`2PO4`20:5mC@<0XWi>00<0YH1<0:J1C@2VPDd0
0P2WPTh20:R3C`80ZHA@0`2XPdl20:N2CP80YX5=0P2UPDd05P2VPTh0Z8A@0:V5D@2[Qe<0[8QD0:f9
E@2^Re40[haD0;2=E@2bSeT0/XiJ0;6=F`2`S5`0[h]K0;J@H@2jU6D0_IMX0;bFI`2hTV<0]i5R0;ZD
I@2nV6T40;RFIP@0]iEU00@0/iES0;BFI02dUV@0]9IT0P2eUfD20;JHIP060;ZIIP2jV6P0^YQX0;^I
J`2kVF`0_9U_0P2lVG430;fMM080_Yie0`2oWgH20<2QL`050<6RM032XgD0`jAf0<>TMP34YGL00P35
YWP01P33XgX0a:Ak0<FUO036YWd0ajMn0<RXO`X0bJV0203>Zh<30<bYO`80cJZ00`3>Zh420<j[Q@04
0<j[P`3=ZX00cJ]n0<bZO080c:Yj00<0bjUi0<ZXN03:Z7P00P39YgL20<RVMP030<NUM@3:YW@0bZId
00<0bJEc0`38Y7801P35Y6h0aZE_0<JUL037YW<0b:If0<VWM`80bZQj00H0bJIl0<ZWO@3;Z7h0c:Uo
0<fZP03>Zh420<n/PP80cjb400@0d:f50=6^QP3B[hL0dk280P3D/HT20=>aQ080e;:50`3E/hH0103F
]8L0ekB<0=NdS03G]8`20=ReS@<0fKJ>203J]i420=VfSP<0f;F=0`3G]8`80=ReS@80fKJ<0`3H]H/3
0=NdRPP0e[>;0P3E/X`30=BaR`<0dk2:2@3C/8H@0=>`R0030=6^QP3@[HD0cZ^30080cJZ200<0cZ^3
0=2]Q@3A[XH0403=ZX880<j[P@80cZ^30P3?[8@30=2]Q@030=6^QP3@[HD0d:f500H0d:f500`0c:j8
0<n_R@3A/HX0dk:90=BaQ`3E/8@0e:f20=>]P03D[h80dZf00=2[OP3>ZG`20<bWNP80cJQk2`3;Z7h3
0<ZWO@80bJIl203:Ygd20<VVO080bZMm0`3;Z7h01`3<ZGl0cZ^10<j[P@3=ZX00c:Uo0<^XOP3:Ygd0
0P39YW`01P3:YGP0bJAg0<VTM`38XgH0aj9e0<JQM080aJ1c2034Wg801P32XG@0`J1c0<6PL`30Wg80
_iia0;jML080_Ia_2@2lVVX30;^IJ@80^YQX0`2iUfL80;ZFIP80^9QO00h0^IQS0;VHI@2jV6X0^YQ[
0;^HKP2kV700^IAO0;RCGP2gTUd0]I1K0;B?FP2bSEP0/HaG0;2;EP80/HeK0P2bSU`30;>?G@040;B@
GP2fTV80]Y9R0;JBHP80]i=S0`2hU6@30;VEI@<0^9AT0P2gTf<30;FAH@80]Y9R0`2gTf<30;NCG`D0
^9AP0`2gTVH[ooooo`00:_ooool80:IlBPP0Ygi8202YP4`30:ImB@<0Ygi:0P2XOd/80:MmB`080:V0
C02XOd/0Ygi:0:MnBP2XOd/0ZX5=0:b3C`2]Q5080:V0C0P0Zh9<0P2XOd/30:MnBP<0YWe90P2XOd/2
0:V0C080Ygi:00<0YGa80:9iA@2QN4@00P2KMT40102JMD00VG@o09Qc?P2GLSd209Ia?00609A_>P2D
Kc/0Tfhj09=]?02BK3d0TF/n0P2AJSl01P2CJcP0TFTf08aV=@28I3@0QV4d089P<P80PF0c00H0Pf0f
089O=@22GcD0PEhd081M<`1oG38207iK<@0807UJ:`1iFR`0N5T[07MH;01fERd0MED^07EE;`1dE2h2
071B;P80Ke4]0`1^D2`01`1]Cb/0J50/06Y@:`1[DB`0KU8[075D;01dE2/00P1fEBX0601gE2X0N5D[
07UF;01jEbd0O5T_07eJ<01nFc40Oe`b089N;P23Gbl0QF4a08IR<P28I3@0RVHf08]W=`2<J3P0RF<d
08aV=`2@JS/0TV`m09=]?P2AJc`0SVPi08aV=`P0U6Xh00H0TF`g095/>02@JcL0T6Xi091Z>`2?JC`2
08mX?@0308mY>P2@JS/0TV`m00<0Tfdn00<0TF/l091Z>`2CJ3/01`2CJ3/0202EJcT0UV`j09M]>`2G
KC/0UV`j09AZ>02BJ3H0TFLe102>J3T408mY>PP0TV`m00<0TVdi095/>02?JSH00P2>JCD00`2?JSH0
TF`h099]>@0208iX>@0308mY>P2@JS/0TV`m0080Tfdn0P2DKSl00`2CKSX0TVdi091[=`0208mZ=P06
091[=`2AK3P0TVdi091[=`2BKCT0U6lk0P2FLCd00`2DKc/0TVdi091[=`08099]>@P0T6`l102CKSX2
099]>@80TF`h00<0U70l099^>P2@K3P00P2?JcL00`2@K3P0TVhj09A`?008099]=PP0TFdm00P0T6`h
09=_>`2FLSh0U70l095]>@2?JcL0TVhj09Ea?@P0TW100P2<KS`208]]>`0908Y/>P29JcT0RF/i08U[
>@2<L400RVhn08IZ>P22ISH0Of<c0080OF4a00h0O60`075E;@1_Db/0JU0[06E=:@1PBBT0FTDX05M2
9`1D@2L0A3hX044k9@0j=B40<RlL02d/6P80:R/K00L0:R`N02P[6P0X:aX09bTK02HX6`0V:1d09BHN
008092DO0P0Q91T00`0P8aX07b8K01hP6`0201dO700301`N7@0L7Q/071hK00807AlL0P0N81d201lQ
7P808RDJ00H08bHM02<V7`0Q8ah07b4N01`N6`0K7A`201XL6@806A/H100H6QL07`0G6AH05aTH01PJ
5`0I6aP06Q`G01`O600M81L07R4F01lR5`0U8Q/09b@M02/W700a:ad0=RlM03`d8@10>240A3TS03Xd
700i<ad0=c8N038_7P0]:ah09bLM02@T700Q8Q`07QhD020P5P0S8aT09BDK02LW7@0X:1h00P0W9ad3
028S6`808B8J0`0P8AT@01lP6P0P01dN600L7AL06a`F01/L5P0L7AL07QlI020Q6`0R8ad091/<02lS
4`0m<1l0BSTU054m9@1E?B<0ES`Q05Ll7`1OBB00Je@Z07aT>02;Kd00Tg=209ahA02[QU40_9EN0:>4
CP1kHcD0Cd8R03<b800Y:bH08bLX028S9@0V92L202DU8`8092@R0`0S8b401`0R8R009BDU02DU8`0U
9B<09RLR02HW8@0W:2000P0W:Ah802DU8`0A02/a9`0/<RP0;S4X02`]9@0W:2009RHN02/X8@0_;2D0
?RD[03/V8`12<2@0BShX04@m8`0e<1X0;R/L03<a9@12=bD00P10<b00501:>bH0ETH_05e;<`1LB2l0
ET8Y05do8`1O@2<0I4<R06e99@1jDbX0R5la09EY>02NL3h0Vg5109I/?02EJcT0Vg8n0:9iA@2SNT@0
XWU10P2PMcl0402@L440PF8d06e@9P1M@ah0Ed0P05Q39P1HAbd0FDL_06I59P1WB2T0JDX]06=5:@1J
?b@0E3XO05@l8P1F?R@3054o9`D0DT0X00P0Ed<[05E1:@1@?RH0CCdT04Xl8P19?B<0BShT04To9080
CT8Z00<0CD4Y04a0:01;?bL00P19?BD01018?2@0BCdU04Pl9017>b<204Hj8P0504Pl901:?RH0C40X
05109`1A@BP00P1B@RT0501A@BP0CclV04dm901<?2<0CSlZ04`m:016>BH0@SLU03de8P0k=280?3DU
03/e9@16=RH0ASHW048e9@10=2H0?38V03Xb9`0h;bH0=c0V200b;RD01P0c<240<RlP038^8P0a;B80
<2`S02lZ9080;RTU0P0_:b83030/8`<0<BdT00<0=BlS03H`900h<RH00P0i<bL00`0h<RH0=S0T03D_
8`0203@`900403<_8`0b;R80<RhR034]8@80<2`P00<0;RXQ02l[8P0`;2<00P0a;B@00`0_:b80;BTP
02`X7`0203@/:@0403@]9`0d;BD0=2dS03@^8P80=BlQ00P0<RLQ03DZ900k;RH0?2hU03l^9013<BD0
BSP/054n<0@0CchT00L0D3lU05509P1A@2H0DT4W04hn901??bD0D40V0080DD4W00<0D40V04hn901=
?B<00P12=RH01`13=bL0ACTY04Di:@15>BT0@cLW040d900o<b<0100o=RD4040g9P0E04<h8P14>280
A3PP04Pj801;>b40D3lS05E19P1GA2H0ED8R05I38`1GA2H0F4@Y05Q4:`1G@b/0ED0[05@o:P1@AC<0
CT<a04]0;P18?B/0AS/Y0080ACXX0140AS/Y04M09015?R80@CXN03lh7010>Ad0A3dQ04U29P1<ABT0
BD<Y04Q2:01:@bL0CD@W05159`1EB2P0FD`Z05a=;00206YD;@80JeD^00X0K5H_06eG<01]Ec00KUPa
06QK<@1YFS40J5Tb06UG<`1ZES<0Je@d0P1[DS@0401fF2@0NE/W07iP;025Ic<0SFlk09Af@P2INdL0
W7i:09f;F`2MRed0WHYO09b:HP2JRVH0VXaY09^<K@2JSFd20:66F@0B0::8E`2VS5T0[IAL0;NOH`31
ZF/0ajm_0;nZO@31[7d0`jen0<6YN@2nY7<0_Z9`0<BVLP38ZWH0bJEe0<^WM`3=ZGT0cZYj0P3?Zg/0
303>ZWX0cJUi0<n`K`3>[fh0cZa/0<fZJP3=YfP0bZAU0<ZRI039XF<0bZAU0<^UIP80c:IW00D0bJ=T
0<BNG`2nV5T0^iEF0;fKG0020;bJF`030;^IFP2jV5T0^IMH0080^9IG0140]Y9D0;RDEP2gTeD0/He?
0:^7B@2YQDL0[HU;0;:>D02aRTL0/X]80;><B@2dSDX0]Xm<0;RACP2iTTl0^Y=@0;VEE`020;NCE@08
0;JBE02eTE<0]I5C0;NCE@2iUEL0^YIH0;FAD`2fTU@20;NCE@0L0;JBE02dT580/Xi@0;2<CP2_QTP0
[XE70:b3A@2YP480Y7/m09ie=`2IL380UVd_08eX<`2<Ic80RVHb08MV<`27IcH0RFTh08]/?@2<KCl0
TW4k099b>@2EMC`0V7Pm09em@02SQ4@0Z8U80:^<B`80]YE>00@0]iIA0;RGE02hUUH0^IMH0P2jV5/2
0;^IF@040;ZHF02iUeL0]iEE0;JDE080]I=C00<0]IA?0;JED02hUe800`2jVE@20;RGDP0D0;6BD@2c
U5<0]9ED0;FFE@2bTe80[Xm>0:V:B@2UQTD0Pg0h08Md?02:Mcl0Qg@l085^=P1nJc<0P6de08Aa>@1n
IBd0OfH^089Y<@24Jc<208E/=01408=Z<P22JC40RW4h08ac>P2?MC`0Sg8j08i_>02AL3X0UgI009ml
AP2QPdL0XhE90:F6C@2XRE80[8eG0:n?G02aTEh0/i=R0:fCHP2`UVD0/iMW0;>DI@2bTV<0]99T0;VG
J@2oVVd0`Z9l0<^[Q@3D]Y80f[fK0=VoW03E_I/0dkbL0=BmW@3=]9D0c;>D0<^cT@39/Hd0ajn90<F^
Q@34[H@0`jb20<NXNP34YGL0`:5b0;jPKP2jW6P0/I=M0:F7D@2LOdL0XX990:f<EP2lVfH0ajEe0<f[
OP3?[8@0dZn90=B`S03G]YD0fKRG0=^lW@3N`J<0hLJY0>C:[`3Wck<0jM6g0>GC^`3Ve;`20>KF_`0M
0>OH``3Wf/L0j=g;0>[Oc@3Yh<l0k=_70>_Ka03Yekl0im>h0>C?/03RbjT0glVT0=k6X03Qb:T0h/VZ
0>;9Z`3Rb:d0hlV`0>?9/P3Tb[<0i<Vd0>??]P3Td;L0i=:j0>KF_@3XfL80j]_60>[MbP3[g//00`3]
fld20>kLcP<0kmg?103]h<l20>kQd080kn;A0P3`g<@0103_fl<0k][20>cH`03[ekl20>[F_P80j]6b
00@0j<n`0>O>[`3Uc:d0i<^/0P3RbJX0:03N_YL0g;bC0=ZiSP3H]H/0e[650=>]P03@ZW/0dJQj0<^S
LP39XG00aYi[0<:JIP2mUUl0^I9I0;J?EP2dSE80/haC0;:;DP2`RE00[HI=0:V2B@2VOdH0Y7e40:=l
@`2POc`0Wgdm09aj>`2JMcd0Ug@n09A`?P2BKSh0TFdm09E_?P2DKSd0TV`k091Z>@2=IcH0RfDd08US
<P28HS4208YV=P80RFDe00L0R6@d08MS<`27Hc<0Qf<c089K<023G340QEhc0080QUld00<0Q5db089K
<021FRl00`22G3D208=M=P<0Q5hg00@0QV0i08EO>025GcP0QElh0P24GSL408=M=P0408AN=`25GcP0
QElh08IP>@80Qf4j00<0RfHj08YU>@28HcL00P27HSH00`28HcL0RF@h08YU>@09089V=PP0QfDg0`28
HcL508UT>00808YS>02;I3T0S6Hi08eW>02>J3L0SfXf091[=`2@JcH208]U=P0;08]W=`2:J3P0Rf/j
08]]>`2<KS`0RVhl08aX>02=JCT0SVXj091/?02AKCd00`2BKSh209Mc@`80UW9200@0UG5109A`@02D
L400Tflo102GLd<209QdA080VGE500H0VgE409afA@2LMd<0WGQ309iiA02ONT<20:1l@P80WgY=0P2P
Ndh30:5lC`050:9mD02TOd/0YH1<0:F0C02VPDd00P2WPTh30:R3C`<0Yh9>0P2VPDd20:F0C080Y85;
00@0YH9<0:N4CP2YQU00ZXMA0P2/RE<0402]RU00[X]A0;2=E@2aSUP0/HeI0;2<FP2_ReT0[XYJ0;B>
G`2iTf@0_IMX0;^EIP2gTF80]Y1Q0;VCI02nV6T60;JDI080]iEU0`2bU6820;>EH`<0]9IT0P2kUfD0
0`2kUfL0_9MZ0;bGJ`020;fHKP040;fGL02lW7<0_9ac0;bLL`80_Ied0`2nWWD20;nPL@050<2QLP31
XW<0`jAe0<>TM@34YGH00P35YWL02032XWT0`j=j0<BTN`35YG`0aZIm0<NWOP38Z7l0bJV02038Z7l8
0<j[P`040<^XOP3<ZGl0c:Uo0<bYO`80cJZ00P3>Zh420<j[Q@050<fZPP3=ZX00c:Ym0<bZO03<ZWX0
0`3;ZGT20<ZXN0040<VWM`38YWH0b:If0<NUM@80bjMe00@0bZId0<VUL`39YG<0b:Ab0P37Xg401P34
Y6/0a:=]0<FTKP36YG00ajIc0<RVMP80bJMi00P0b:Ek0<VVO03:Ygd0bjQn0<bYO`3=ZX00cZ^10<n/
PP80cJZ200<0cZ^30<n/Q03@[HD00P3B[hL0103C/8P0dk630=>aP`3C/H<20=BbQ0<0eK>50`3G]8`3
0=ReS@80fKJ>203J]i420=VfSP<0f;F=0`3G]8`80=ReS@80fKJ<0`3H]H/30=NdRPP0eK::0`3E/X`2
0=BaR`<0dk2:2@3C/8H80=>`R0P0eK::00<0dJj60=2]Q@3>Zh<00P3=ZX800`3>Zh<0d:f50=6^QP0@
0<fZPPP0cZ^10`3>Zh<20<n/Q0/0d:f500d0c:j80<n_R@3@/8T0d[680=>`QP3D[h<0e:f20=>]P03E
/8<0djj10=2[OP3>ZG`0c:Mj0080bjIi00<0c:Mj0<^XOP3;Z7h02@3;Z7h20<ZWO@<0bJIl203;Z7h3
0<VVO080bZMm0`3;Z7h01P3>Zh40cJZ00<fZP03<ZGl0bjQn0<ZWO@80bJIl0P39Y7L20<RSMP040<NR
M@36XG@0aJ1c0<FPL`P0`iia0P31X7<20<2OLP040;nNL@2nWG00_Ia_0;fLK``0^iUY0P2jV6P30;VG
I`P0^IEU00H0^9QM0;VIH02iV680^YUV0;^IJ`2kVF`20;bIL@80^9=N00@0]i9M0;F@F`2cSUT0/XeH
0P2`ReH20;2<FP<0/HeK0`2bSU`30;JBHP80]i=S0`2hU6@30;VEI@80^9AT0`2gTf<0102dT600]I5Q
0;FAH@2eTF420;JBHP80]i=S1@2fTUh30;NCG`<0]i9V:oooool002[ooooo202UNTL80:QoB`80Ygi6
00@0Ygi80:MnBP2WOTX0YWa:0P2VO4`0202WOTX0YWe90:ElB02VODT0Ygi:0:V0C02[PTh0[HA@0P2W
OD/0102XOT`0ZGm=0:Z0CP2ZP4h20:^1C`80ZGiC0P2ZOe@30:^0E@030:b1EP2ZPDd0ZX5=00H0ZX5=
0P2XOd/30:V0C0<0ZX5=00<0ZH1<0:MnBP2UO4P00P2TNdL01`2UO4P0Ygi:0:QoB`2YP4`0Z7m;0:Mn
BP2UO4P00P2SNTH00`2RNDD0XGQ40:1g@`0409]a?`@0W79000T0TVdh099]>@2CKSX0Tfdl099/?@2@
JSd0SVLl08eV>`28ISP00P27ICL00`26I3H0QF<e08AR=00208=Q<`80Of8h00@0OV4g07aO=@1kGS@0
NE`b0P1hFc4207YJ<`0407UI<P1hF340MeL`07MG<080MUH_00D0M5Hb079D<01_DBd0K4hZ06]=:@02
06Y<:00E06]=:@1_CRl0Kdh_06i=;01_CR/0LE4[07AD;@1fERl0N5P_07eE<@1nES80P5Tb085J<@21
FRl0PE/^07mI:P1nF2T0PUda08=N<P26HCD0R6<g00<0RVDi00<0RF@h08mY>P2?JCX01P2?JCX809E[
>@80U6Xh0P2CJCL0102BJ3H0TFLe095W=@2@IS@8099/?@0308aV=`2>J3T0T6Xk0080TV`m00<0TF/l
091Z>`2?JCX00`2?JCX5091Z>`80TF/l0`2@JS/308mY>PP0TF/l0`2EJcT209AZ>0<0TfTg00<0TVdi
095/>02@JcL00P2?JSH2095/>00J09=^>P2DKc/0Ug5209I`@@2EKd00U6ho09=]?P2BK3d0TF/l091Z
>`2AK3P0T6/g08iY=@2=J3@0SVTe091[=`2BKCT0Tfhj09A_>`2CKSX0TVdi095/>02@JcL0SfXf08iY
=@2=J3@3099Y>`80TfXl0`2DJcd309=^>P<0TVdi0P2AK3P308m[>`80T6`l1P2AKCd2091/?0<0Sf/k
00/0S6Xj08e[>`2>K3`0Sfdm091^?P2AKcl0TW1009=a@@2AKcl0T6hn08i/?00208e[>`0308i/?02@
KSh0TFlo0080TFlo0`2BL40309=a@@80T79000@0SW0n08e_?@2;KC/0RV`j0P28JSP06027Jc/0QVXj
08AX>021ICD0Of<c07aP<01jGRh0NEd]06mG<@1ZE2d0I4hY061<:@1OC2/0Fd/Z05A5901@@B80BT4T
04@m8@0n=ad0=S0J034/6@0]:Q/0;B/N02d[7`80:2PN00<09bLM02HV700U9A/00P0T91X0100S8aT0
8RDN028U7P0Q91d2020S700301lR6`0N8AX07R4J008071lH0P0M81T201hQ6P807b8K00P082<L024T
7@0R9Ah08RDN024T7@0P8a`07R4J01`O60T06Q`K0P0G6AH0100I6aP06Q`I01`N6`0M7a`201lQ7P0I
02<U800T9b009RLO02TY7@0_;Ah0=C8O03Tg8P0n>B<0>SDO03Pc7@0h<al0>C@Q03Tc8`0d;R00:R@F
028L400M81T07b8K028S6`0V9Q`0:BLK02XV6P0Z9aP0:bDG02HW6@0202DU6@0302@T6P0S8a/08R4L
00808B0L200N8AX801lP6PP07AdK01P081`A02hV6`0o<bD0BS/X04lk8`1B>1d0ESTK05Tj6`1KB1h0
IU0W07UR=P2<LD80TgE309Ie@P2TPD/0]8mJ0:EnA@2AK3l0K4d`04H_8@0a8b00:RTW02D[:@0M:282
02DW90<092HS0`0S9B80=`0V9RH08b<Q028R800T9B00:2TS02X[8`0Y:b009RPM02PY8`0W:2809RLQ
02DV800V9b409bPR02TZ900Z:bD0:R/M02h^8P0a<BD0<30V02`/900X9b80:BPT02XY9@0[9AT0<bdQ
03`f:00o>BT0?3LT03Td800j=B40>cHP02lY6`0n=bL0CD8`05=3;01HA2T0GdHX05m28P1I>aT0H44R
06U89`1cDBh0NeD`085G;`28Fc40Tf@h09a/?P29GS40Sf@g09Y`@02UO4P0Zh9:0:V1A02PN3X00P2I
LS40602AKCT0Q68b075B901O@a`0E3dM050o9@1B@b`0DdHc05e99P1PC2T0HDd/05i9:P1H@bH0ED0S
05I19P1IA2T0Ed<Z05E1:01C?bH0DCdT050l8`1A?B@0DShU05<o9P80CS`T0`1??BD3050n9P0;04i3
9`1=@RH0CD4W04a0:01;?bT0BSdZ04Tl:@19?2/0Cd8a04`o;P19?2/00P16>BP04@19?2/0C3l^04m2
<@18>bX0BSdZ04`o;01>@R`0Cd<[04m3:@1>@bL0CD8V04]0:P19?RP0AS/W04<h9P11=R@0@3@T0080
@CDW00P0?c@N03hf7`0o=b80?cPU03dh9@0h=B@0=C@R03<a8PP0<BdT100b;RD203<_9P80=30W200d
;R8203<a900303<_8`0e;b<0=RhS0080=R`R00H0>2/R03H^8`0f;R<0=2hR038^8P0`;R4202h_8@04
02`^800`;2<0<2`S030/8`80;b/R0`0^:R40600a:al0<R`P03@^8P0e;b<0=S0T03D_8`0d;R80<bdQ
03D[8P0d:R40=2XP03D[7`0g;Ql0>S4P03he9010>2D0D3d/04ll:`1A?2/0DCXZ05<i:P1C=bT0DSHX
05<f:080E3l/00<0E3lZ05A0:01D@2L00P1D@2D06`1D@B<0BChR04Tn8P19?R80B3`R04Hj8P15>B<0
A3LT04<f8`12=B@0BCTY04Ph:013=RD0@3DS03de8P0l=B80?CHS03dh900n<R80@C@T04@g9P19>RL0
C3/W04dk9@1?>RD0CSXR05919`0205=2:00305A3:@1EA2X0ETD[0080EdH/00H0DT4S05529@1@@B@0
CClT04Tm8`17?B@204<k900l04<n:013?BL0@S`V044i9014>BD0ASTV04Xk:01<?BX0BSPR04`j901@
?2@0EClW05Y2:01OABX0HDPZ06A9;01WBRP0K50[07=G<P1jGSL0OF4i07aQ=P1iGS40MU/^085Q<P1o
H380O5le07IM=01`FS<0J5Hb069B<01NCbh0JE0a06mE<P1hGC80PF<a08UY;P2ELS00Xghg0:b6>`2T
SUD0Z95K0:^GI@2YUV/0Y9A`0:6DM02RUW`0Y9Z109VDK02KU6X0WI9U0:>CHP2ZUV40]9]S0;jQI`33
YFT0bJEW0<^WJ@3=ZF/0d:a^0`3B[W001`3A[Fl0bK5e0<R`M037[g<0aZib0<F]L@36[W800P37[g<0
2P38ZFT0aZIY0<JTI`35XFL0aYmX0<NNJP38Wf/0bYi]0<>QHP32X6420<6OH0040<2NG`2oWEh0_YaM
0;jLG@80_IUU00<0^iMS0;ZFHP2iUF400`2iUF401P2eTU`0/i1H0;2=E@2]RU00ZhU<0:Z8B@80ZXQ8
00T0[he=0:n<C02]RTX0[XQ90;28BP2cRT`0]h]>0;V=D02fSTT00P2gSdX0702gT4/0^9==0;NECP2h
Ue00^IQA0;NID@33WEH0`YaE0<6KE02nV4l0^YA90;F@@P2aS3h0[XTi0:V4@02VP3l0Xgdn09ig?02K
M3/0VG4m09Q`?@2HL3l0Q68b08ES<`26IC80R6Ld08YY=02<JcD208i^=@0=08Ud=@2?McT0U7/k09Uk
>`2LNSX0XGhl0:Z4@`2aRTL0]9=>0;FDC`2iV5<0_9]F0;jMF0030;nNF@060<2NGP2nW5`0^YQH0;JD
E02cTE40/Hm?0P2`STh0502^S4d0[he=0;2>CP2aT4d0/Y5<0;>BB`2dU4/0]IE<0;B?B`2fT4l0/i1>
0;2>CP2bTe<0/YAF0:F7B`2CMSX0R6lg08M^=P25K3@0PfXb0P22JC4208=Z<P04081V<`21Ic@0PfTf
08E[>080QV`i00@0QF/h08AZ=`2:LCT0RG0h0P28KcL06P2:LCT0S7<k08mf?P2AN400VH5309^3A@2N
Q4L0XhI:0:N9C@2[Re00[XiC0;6>E02[T5T0[Y=N0;6FH@2`U680[i=S0;2DI@2fVFd0^iib0<FSMP3>
Zh40ekN>0=^oV03I_i`0eKjL0P3B_il08P3B_J00d;^L0<nhV@3=]9D0b[2?0<R[R@36ZXD0aJN30;nQ
O@30XWh0`:=k0;fPM02eVFX0[91N0::7D02LPDX0XGa80:j:F030W6`0b:Ii0<RWOP39ZH<0c:j:0=:d
TP3G^YX0f;^K0=VnX03Ma:H0h<R/0>?>/@3Wd[L0j=Bi0>?D]`3Ve[`20>[J`@0=0>gLb03_g/h0k]c>
0>cJcP3[fLl0lMVo0>oG_@3[dkL0i/n`0>?<[03QbZP0h<VW0=o9Y0020>C7Z@030>?8Z`3SbJh0hl^a
0080hlfe00h0hlng0>?C^P3Te;d0iMFn0>OF`P3XelD0j]W90>_Ib`3/f/`0jMg?0>[Nd03[gll0k>7?
0>gRcP80k^?=0380knG<0>gPd03]h=00kmo?0>oNcP3`gL`0l]g:0?;Mb03cgLP0k][10>gI_P3]f;d0
kMFi0>cC]@3/dK<0j]2_0>_>[P3[b9h0jLJL0>O4VP3S`9H0h;fC0=biS`3J]hd0fKJ<0=b`P`3K[h80
f:am0=FZM`3AYVl0cZAX0<bSI@3;XV80_IIO0;bEGP2iTU/0]HiG0;6:D`2^Qe00ZhA=0:Z3C02[PU@0
ZX5C0:MnD02SNT`0WgI809]bA02HKd40Ufi009A^?`80Tfdn00<0TV`m095[?02@JS/00P2?JCX208iY
?080SFPk0`2<IcX01@2;IST0PE`b089M<`22GC<0Pehd0080Q5le0P25H3H01023GS@0PUdc089M<`21
G382081K<@80OeX`00<0OEhb07aM<@1jFbl00P1jFbl0101lGC40OUlc07mP=01oF2l3081I<080PEXa
0P22Fc8207]I:`0407aJ;01mFbd0OE/]07iL;P80Oed_0`28HS/208MQ>P<0QV0i0P25GcP308AN=`0<
08=M=P22G3D0PU`e085K=021GSH0PUlg08AQ>@25HSX0QV<k08ER>P24HCT0Pf0h1022H38408=Q<`<0
QfDe1@28ISH608ER>080QV<i0P27HSD01028HcH0RVDh08aW>P2=J3/208mZ?@80S6Lj0P2=J3/308iY
?00:08mZ?@2>JSX0Sf/k091/?02BKSh0UG5109Mc@`2HM4@0VGE509Yf@P80VgM300<0W7Q409eiA@2M
NDD00P2NNTH20:1lC080Wg];00l0WWY:09eiB@2MNDT0W7Q809QhA`2INDP0VgU909ijBP2ONd/0XG]<
0:AkC@2UO4h0X7]70:9mB@2TOd/00P2UP4`0102SOTX0X7]709mjAP2RODT30:5lB0040:=nBP2UP4`0
Z8=?0:V4D0<0[hYF0P2`ReL30;6<F00;0;2=E`2bSUX0]91L0;FAG`2fTV80]Y5T0;F@I02dSf<0/8iP
0;:@HP2dTV@00P2fU6H00`2eTfD0]99T0;>AH`020;:@HP80/i5S0`2dTV@0102eTfD0^9=V0;RCIP2h
TfH20;VDI`<0^YEX00T0_9Y/0;bJK@2lVVd0_9U_0;bIL@2lVG<0_9Qd0;fIM@2oW7@01@2nVg<00`30
WGD0`j1h0<BQN@030<BQN`80aJ9l0`36Xgd00`38YGl0ajAn0<JSO@020<FRO0030<NTOP39YX00bjR2
00<0bZMm0P3;Z7h30<bYO`P0bjQn0`3<ZGl20<^XOP<0bZMm00<0b:Ih0<JTMP34XW@00P32X7801033
XG<0a:9d0<FSM@36Y7H20<FSM@030<BRM033XG<0`j5c0080`Z1b0P33Wfl01`34X700aJ5a0<JRLP37
Xg<0b:Ad0<VUM@37Y7X00`38YG/20<VVO080bZMm0P3<ZH<0103<ZH40c:Uo0<bZO@3<ZW`20<bZNP08
0<b[MP3<ZgP0cZal0<n]P03A[X@0dk2:0=B`S03D/8h20=FaS@040=JbSP3G/hl0f;B@0=VeT@80f[JB
103H]Hd40=NdS0030=ZgS`3I]Xh0fKJ>00<0fKJ>4P3H]Hd01P3E/hD0eK>60=FcQP3E/XP0eK::0=Fb
S080eK6=103D/HT40=>`R080f;F?00<0ekB>0=JcS@3E/X`00P3D/H/00`3C/8X0dZn90=FbRP020=Fb
RP80e;690`3C/8P80=>`RP<0dZf30P3A[8830=2[P@80c:Mm0P3=Z7h40<jYO`<0cJQk00<0cZUl0<nZ
O@3@Zgh00P3@Zgh01P3;Z7h0c:Uo0<bYO`3=ZX00cZ^10<n/PP80d:f300H0djj40=:]P`3A[880d:^1
0<nZP03>ZGl20<fXOP@0cJZ20P3>Zh<20<n/Q00?0<n/PP3@[H<0dZn50=>`QP3B[hD0d:f30<j[P@3=
ZX00d:f30<n/PP3>Zh40c:Uo0<ZWO@39YW`0b:Ek0080ajAj00L0bJIl0<ZWO@3<ZGl0c:Uo0<^XOP3:
Ygd0bJIl00P0bjQn203:Ygd20<bZO0040<^YN`3:Z7X0bZQj0<VWN@80b:Ih0P3:Yh420<VVP0<0b:Eo
00D0ajAn0<RTM037Xg<0aj=c0<JRLP020<FQL@80a:1`0`34Wg830<>NL@80`Ye`00P0`Z1`0<6OK`30
WVh0_Ya/0;fKJ`2kVFT0^YQX0;VGI`<0^IEQ00<0^YIR0;^GH`2lV6@00`2lV6@0102nVVH0_IUU0;fI
I@2lV6@20;^GH`80^YIR0100]I5M0;JBGP2iUF40^YIR0;^GH`2jUV80^IEQ0;RDH02eTEd0^IEQ0<2L
J036XVh0bJEa0<RTL036XVh0a:1/0`2jUF001P2iU5l0]Y5L0;:=F02^RE@0[8MB0;2<F0<0/HeI0P2b
SUX20;>?F`@0]i9N102fTEd02@2kUFP0^YAW0;VCIP2gTF@0]HmR0;>=H02aReh0/8YM0;FAG@020;FA
G`030;B@H02dSf80]8mS0080/hiT0`2eTU`20;BAF`<0/i1J0`2bSeT[ooooo`00:_ooool80:IkB0P0
Z7m;0P2WOTH0102WOTP0Ygi:0:MnBP2WOD/20:IlC0080:MnBP2VODT0YWe90:ImB@2WOTX0ZH1<0:^2
CP2]Q5030:QnC080ZGm=0`2ZP4h20:UnD@80ZWmB102[P5<80:Z1C@80Z7m;0`2YP4`30:Z1C@070:^2
CP2YP4`0Ygi:0:ImB@2UO4P0YWe90:MnBP020:QoB`030:MnBP2VODT0YGa80080XgY600@0XWU50:5h
A02PMd<0WG=10`2LLT0309]a?`0:09Y`?P2BKCP0TVdi09=^>P2CKC`0TV`m091Z?@2>Ic`0SFHk08QV
>080QfDg00<0QV@f08ES=@24HS@00P23HC<2081P=`0407mO=P1mGC@0O5`c07YJ<@80NET`0P1jFS<0
0`1iFC80N5Pa07MG<00207IF;`0707EE;P1aDbl0L58^06i@;01/CRX0JddY06a>:P0206e?:`80LE0a
0180L4l^06m>:`1`D2X0LU8[07AD;@1eEB`0OEDa07iF<P20FC80PEXa085J;`20FRd0OeTZ07iH:@22
GC40Pehb08IQ=@28HcL308YU>@0308UT>02?JCX0SfTj00H0SfTj202DJSP00`2EJcT0U6Xh09AZ>002
09=Y=`80TVPf00<0TFLe095[?02AJc`01P2AJc`01`2=IcP0SVPi091Z>`2AJc`0TV`m095[?02@JS/0
0`2?JCX6091Z>`80TF/l0`2@JS/308mY>PP0TF/l0P2EJcT309AZ>0<0TfTg00<0TVdi095/>02@JcL0
0P2?JSH2095/>00309=^>P2DKc/0UW110080UFm000D0U6ho099/?@2AJc`0TF/l091Z>`02091[=`<0
SVTe00<0T6/g099]>@2CKSX00P2DKc/0102CKSX0TVdi095/>02@JcL208mZ=P<0UF`n0P2FKCl309M^
@0<0Tfhj0`2BKCT2095/>0<0Sf/k0P2@K3`6095]?@80T6`l0`2?Jc/01P29IcL0RVPh08]Y>@2<JSX0
SF/k08i/?080Sfdm00<0TFlo091^?P2>K3`00P2=Jc/00`2>K3`0T6hn095_?`03091^?P80TFlo0`2B
L400102?LCl0SW0n08e_?@2=Kcd208]]>`0J08Y/>P29JcT0Qf/k08IZ>P24J3P0PFDe07iR<P1lH300
NUh^07QL;01_Ec40JU@]06A>:@1PC2T0Gd`[05];:P1DAB@0D44R04Y19014?B40?SLM03La6`0b;AX0
;R/L02d[7P0]:al202PX7P0402LW7@0V9Q`09BDK02DU6`8092@J0P0R9Ah0100Q91d082<L020S700O
8Q/201hQ6P8071lH0P0M81T201hQ6P807b8K00P082<L024T7@0R9Ah08RDN024T7@0P8a`07R4J01dP
6@T06Q`K02405aTF01PJ5`0I6aP06Q`I01`N6`0M7a`07R0M01lQ7P0S9B008bHO02HW7`0Y:Ad0;bdN
03Db7`0i=b80?CPR03Xe7`0h<ad0>3<O03Td8@0i<b<0=2hP02XT5P0S7A407B0I01lR6`0R8a/09RHL
02TW6`0Z9QX0:RLH02/U5`0V9aT00P0U9AT00`0T91X08b<K028Q7002024P70P07R4J200O81X801dM
6`0H028N4`0^:1`0?C@U04Xk:01@?2@0DSXP05Dj7@1J>ah0FTLO06E?9P1gH3H0RVm2099cA02EM440
XWi:0;:=F02VOdH0Tflo06i?<018<B<0<RDO02/Z:00U:bL07BPR0P0U9b@302@V8`<08bDR03L09RHV
02<S8@0R8R0092DP02PY8`0Z:b<0:B/P02HX7@0X:B<09bPR02HW8@0U9R009RLQ02LX8P0Y:R@0:R/U
02X[7@0^;R80<C4U030`9P0[:b<0:2LR02PW8`0Z:BD0:bDI038/800k=BL0?SPZ03`f9P0j=B80>C@P
03Xe8@0a:ad0?3DU04Pm:`1??bP0FDDZ06=:;01TAbL0G3hL06M8:@1`Cbh0NUPe085K=P23FC40PeP]
08MH;02:FR`0REha095V>@2LLT00YGa80:QoB@2WOd@0Y7`o0080XGTk01P0VgM308e[>`1gF2X0HTHO
05@m7@1<>b40CChW04m2;`1MBBH0Gd/X061<:`1MB2T0F4<V05@o901F@BH0F48Z05I2:@1E@BP0DclV
054m901@?2<0DCdT058n9@1C?bH4050n9P@0CcdU00/0CT<W04e29P1=@BL0C40X04/o:@1:?BX0BC`Y
04Tl:`1=@2l0Bch]04Pk:P0204Hi:00K04Pk:P1;?Rd0CD0_04Pk:P19?2T0C3l/04i2;01?@b/0CT8X
04i39`1=@RH0BSlY04Tn:016>bL0@cPV044f9010=2@0@3@V044e9`0o=1h0?SHQ03lg8P0n=b@0?3LT
03Pe900e<b@0<c4R00T0<BdT0`0b;RD203<_9P80=30W200d;R801@0a;b80<S0S03<_8`0e;b<0=RhS
0080=bdS00H0>B`S03H^8`0f;R<0=2hR038^8P0`;R4202h_8@0302d_8@0_:b80;b/R00H0;b/R00P0
<B/O038/800d;R80=BlS03H`900e;b<0=2hR03<]8@80=B/R00H0=B/Q03D[7`0h;b00>c8Q03he9010
>2D204hk:P04050k:P1A>RX0DcTZ058h:@80DcLY0P1B?BX01P1B?BP0DclW05A09`1D@2D0ED4V05E2
9080Bd0T00`0BSlS04Tm8`18?2@0ASXT04Dh9@14=b@0@cHU04Ti:@18>2P0@cHU040e8`0m=B8203df
8`0903dh900o<b<0@SDU04Dh9`19>RL0C3/W04hl9P1@>bH0Cc/S0080DD0V00@0DT4W05=2:01D@bT0
ED@Z0P1FAB/0A01C@R@0DD8U0511901=?b@0BShT04Lm9014?2D0@c/T048m9`12?2H0@C/U044i9013
>2@0ACPU04Tj9`1:>bP0BcTS04dk9@1A?BD0ET0X05]3:@1NARX0HTT[06=:;01WBRP0K50[07=G<P1i
GCH0O60h07aQ=P1iGS40Me`_08EU=P23I3H0P6<g07YQ>01dGSL0K5Xf06EE<`1RDc80JE4e06iE=`1d
FSD0Nehb08=S<02?K380W7Ti0:N2?P2ORDd0YHmE0:^FH@2[VFL0ZIQ/0:JHL@2XVgP0Ziin09nHK02O
UfT0XIAW0:FEHP2/Uf80]9]S0;bOI@31XfL0bjM[0<bXK03>ZVh0d:a`0P3B[W80103A[G40d:a`0<^]
K`3;[Fl40<b^L080bje_00P0ajQU0<JWIP36Y6@0aZ9T0<RRI03:XVL0bj=X0<fSJ@80`j5R00<0`Z1Q
0<6OH030WUl00P2oWEh00`2nW5d0_IYP0;fJH0020;bIG`0:0;ZGG@2iUU`0]iAJ0;JCF@2dTE/0/XmG
0;2=E@2]RU00[8Y=0:b:B`80[8Y:00T0[Xa<0:j;B`2]RTX0[hU:0;69B`2dRdd0^8a?0;V=D02fSTT0
0P2gSdX01P2hTD`0^I9=0;ZEC`2jV540^YUB0;^JD`80`YaE00h0`9YA0;fGCP2iTdP0]8i30;2;?@2]
R3X0YGln0:=m?P2ONC/0W7Dj09Ub>`2HL3`0Ufll09M_?P80R6Hf01<0RVTf08]Z=@2=K3H0Sflf091`
=`2ALCH0S7@f091h>P2DNc/0VG/k09Yk>P2QOS`0ZH=20:n:AP2bTD`0]9=>0;NFD@2jVE@0_9]F00<0
_IaG00H0_ieM0;fKF`2jV5P0]YAD0;>AD@2aSdl20;2>CP0D0:j<C@2^S4`0[he=0;2?C02aT4/0/Y5:
0;>CBP2dU4/0/hi:0;>@CP2bSdd0[he=0;6BDP2aTeD0XhI:095d>028KcL0QVde08A[<`22JC42085X
<00;089Y<@23JS80PFLd089X=@24JSL0QF/h08I/>@25JcP0Q6Xg08=Y=P29L3P00`28KcL0?P29L3P0
S7<k08mf?P2@Mcl0Ugm109R0@P2LPTD0XHA80:J8C02ZRTl0[HeB0;2=D`2]SeT0/99L0;:DH02bU680
/I9S0;>DIP2hVF/0_Iib0<BRM@3=ZX00ekN>0=^oV03I_i`0e[nM0=:oW`3C`:00d[fP0=2kW03@^IX0
cKBE0<Z`S`39[8X0aZZ50<FWP`30XWh0`J=o0<2SN`2lWg<0]9QY0:Z>G02PQDh0VWm80:5mB@2_ReT0
_ie]0<NVN@38Z7l0bJV30<f_R`3B]980e[VI0=JlV`3I_Z00gLBV0>38[03Sc[<0iM6f0>OC^P3Te;X0
i]Jl0P3Zf/407P3]g<P0kmk<0>kLcP3/f/h0j]S<0?3H_P3]eK/0j]:f0>K?/03Rbj/0hLZX0>39Y`3P
bZD0i<NY0>?8Z`3TbJ`0i<Z_0>C</P3ScKD0hlng0>C@^03UeK`0iMFn0>KF_`3Xel<0j]W70>_JbP3/
f/`0kM_=0>_Md080k=o?00<0kN3?0>kQcP3_hld00P3_hl/20>cLc0040>gLbP3]flL0kM_50>kIa080
kmW202P0k=Nj0>_F^@3[e;D0jM2b0>S=[`3WbZX0iLRV0>G7Y@3S`9H0h[nE0=nlTP3L^Hl0f;F;0=Fb
R03B[hD0dJj40=>XN`3AYWT0cZAb0<^RKP37WVP0`i]P0<2HF`2oUeT0]HeI0;>;E`2`R5@0[HEA0:V1
C@2VOTX0Xg]70:9jAP2RND/0XGQ:09mfB02LLdD0V6m109E/?P2BJC/0TFPj0P2=IcP00`2<ISL0RfDf
08YT=@0208US=00408QR<`25HcH0QF<f08ES=P80Q68e0`23HC@207iK<@80Oe`b0P20GC<2085N=080
P5dc00<0Oe`b07iK<@1mFS000P1kF2h00`1jEbd0NU/_07UJ;P0307QI;@0407YK;`1lGC40OEhb07iG
;P<0OeP_0P20FC02085J<@0307]I;01lFRd0O5X]0080OE/^0P1nG2l00`1oGC00PUli085N>002085N
>080P5dg0P1oG3H2089O>@<0PEhh00`0P5dg07mL=P1oG3H0Oe`f081M=@21GSH0Pf0h08AQ>@25HSX0
Q64i08=P>022GcL4085O<P@0PV0c0`24HS8508=Q<@@0Q64g1025HSP01P26HC@0Qf8e08QS=P2:ICP0
RfHi08eX>`80SVTl0`2<IcX208eX>`<0SVTl0P2>JSX01P2@K3`0TVhn09A`@02FLT80Ug=309QdA0<0
VWI200<0VgM309ahA02LN4@00P2MNDD209ijBP0309eiB@2LN4P0W7Q80080VgM700L0VWI609IfA@2F
MTD0V7I609]gA`2LN4P0WWQ90080XGQ:0P2QO4P01P2RODT0Xgi:0:=nBP2RODT0XGa80:1kA`@0XGa8
00@0XWe90:F0C02WPTh0ZHA@0`2^RED20:n:EP<0/8]G00l0[haF0;6=F@2cSe/0]91N0;FAH@2eT6<0
]8mS0;>>HP2^S5h0/8iP0;:@HP2cTF<0]99T0;>AH`2bT6800`2aSf420;:@HP<0/i5S00@0]99T0;NB
I@2gTVD0]i9U0P2hTfH30;VDI`80^YQZ00H0^YQ[0;^HKP2kV700^iQb0;bIL`2lV7@20;jKL@80_IY`
0P2nVg400`30WG<0`Yme0<>PMP030<>PNP80a:5k0`35XW`00`38YGl0ajAn0<FRO0020<FRO0030<NT
OP39YX00bZN10080bJIl0P3:Ygd30<^XOP030<bYO`3;Z7h0bjQn00H0bjQn00@0c:Uo0<^XOP3;Z7h0
bjQn0P3:Ygd20<VVO0030<RVN037YGL0aJ=e00<0`j5c00<0aJ=e0<JTMP35XgD00P34XW@20<>QL`80
`Z1b00L0`Ima0<:NKP33Wfl0a:1`0<FQL@36XW80aj=c0080b:Ad0`37Y7X20<RUN`<0bJIl0P3;Z880
103;Z800bjQn0<^YO03;ZG/20<^YN@060<^ZM`3<ZgP0cJ]k0<j/O`3@[H<0dJj80P3C[h/20=B`S003
0=FaS@3F/Xh0ek>?0080f;B@00<0fKFA0=NdS03G]8`01@3G]8`0103F/h/0fKJ>0=VfSP3I]Xh50=Re
S@P0fKJ>203G]8`01P3E/hD0eK>60=FcQP3E/XP0eK::0=FbS080eK6=203D/HT01@3G]8h0e[>=0=Jc
S@3F/hd0eK:<00@0e;6;0`3E/XX30=BaR@80dk28203C/8X30=:]P`<0dJb20P3@Zh420<bWO@80cJQn
0`3>ZGl00`3?ZX00cJQk0<fXN`020<jYO080cjYm0P3@Zgh40<fZP0@0cZ^10P3B[H<0103A[880d:^1
0<nZP03>ZGl20<fXOP040<bYP@3=ZX80cJZ20<fZPP80cZ^30P3?[8@0603?[880d:f30=6^Q03B[hD0
dJj40=2]P`3>Zh40c:Uo0<n/PP3>Zh40cJZ00<bYO`3:Ygd0bJIl0<RUN`37Y7X0b:Ek0<VVO03:Ygd0
bjQn0<bYO`3;Z7h0bJIl0<RUN`P0bJIl203:Ygd20<^YN`80bZQj0P39YgT20<RVN0<0bJJ00P38YGl3
0<NTOP80aj=c0P36XW801035XG40a:1`0<BPL034X7030<BOLP80`iia0`32WG020<6OK`060;nMK@2n
W6`0_9YZ0;^IJ@2jV6P0^IMW0`2iUF400`2jUV80^iMS0;^GH`030;bHI0030;fII@2lV6@0_9QT0080
^iMS0P2jUV80202iUF40^9AP0;VEH@2iUF40^YIR0;VEH@2gTel0]91L0P2cSe/00`2fTUh0^YIR0;jJ
IP020<2LJ0030;nKI`2nVVH0^IAO0080^IAO00D0^9=N0;F@F`2aS5L0[XUD0:b7DP020;2<F080/HeI
0`2bSUX00`2cSe/0]Y5M0;JAG@060;JAG@80^99S00@0]Y1Q0;F?H02dSUl0/XaM0P2aRe`20;B@G003
0;B@GP2dT600]8mR0080]8mS00@0]8mU0;FBG02eTU`0]I9L0P2dTE/30;>@FP<0/HiH:oooool002[o
oooo202WO4T80:MnBP80Ygi600@0Ygi80:MnBP2WOTX0Yge;0P2WODd20:MnBP80YWe900D0Ygi:0:V0
C02[PTh0[8=?0:Z0CP030:UoC@@0Z7i<0`2YOU420:YoDP<0Zh1C202ZPDd20:QoB`<0ZH1<0`2ZPDd0
1@2]Q500[8=?0:Z1C@2XOd/0Ygi:0080YWe90`2WOTX0602VODT0Y7]70:=jAP2SNTH0XWU50:5hA02P
Md<0WgE309id@P2MLd40W79009]a?`2JL3h0VFlm09Q^?02BKCP0TVdi09=^>P2CKC`0TV`m091Z?@2>
Ic`0SFHk08QV>080QfDg00<0QV@f08ES=@24HS@00P23HC<02@1oGcH0OUhe07eM=01lG3<0NUXa07UI
<01hF2l0MeL^07YJ<`0207UI<P0307QH<@1gEc00MUH_0080MED^00<0KU0/06e?:`1/CRX00P1/CRX0
5`1^D2`0L58^075C;`1eE3D0M5<d075@;`1`Cb`0KdlY06m?:01`D2T0LE4X07]E<01lES40OUPa07mJ
<020Fbl0OeX]07iJ:P1mFBT0PUd`08=N<@26HC@0R6<f00<0RVDh00<0RF@g08mY>P2?JCX01P2?JCX8
099X=P<0UF/i0`2DJSP209=Y=`P0SfTj00<0SFLh08iX>@2@JS/00`2AJc`:091Z>`80TF/l0`2@JS/3
08mY>PP0T6Xk00@0UF/i09AZ>02DJSP0U6Xh0P2CJCL2099X=P03099]>@2AK3P0T6/g0080SfXf0P2A
K3P00`2CKSX0U6lk09E_@00209A^?`0309=]?P2BK3d0TF/l0080T6Xk00P0T6/g08mZ=P2?JSH0SVTe
08mZ=P2@JcL0TF`h099]>@80UG0l00@0U6lk09=^>P2CKSX0TVdi0P2AK3P309E_@080UW110`2GLD83
09=^>P<0TVdi0P2AK3P308m[>`80T6`l1P2AKCd2091/?0<0Sf/k00H0QfDe08QV=P28ISH0RFLg08YX
>02;JCT208aZ>P03091^?P2?KCd0SV`l0080SF/k00<0SV`l08m]?@2@KSh00`2>K3`208m]?@<0T6hn
202<KS`06@27Jc/0QVXj08AX>021ICD0OV8b07]O;`1iGBd0N5`/06mG<@1ZE2d0I4hY061<:@1OC2/0
Fd/Z05A5901@@B80BT4T04@m8@0o>1h0>38L03<^6`0^:a`0;B/N02d[7`0Y:Al00P0X:1h00`0W9ad0
9RHL02DU6`0202@T6P808RDN00@08B@M020S700P8a`07b8K0P0N8AX201`O60807B0I0P0N8AX301lR
6`07020S700Q91d08RDN028U7P0P8a`07R4J01dP6@0901XL6`0Q01LI5P0H6QL06A/H01XL6@0L7Q/0
7AlL01hP7@0O8Ah08R@O02<V7`0U9Qh0:2PL02h/7@0d<Ah0>3HQ03dh8P0j=Al0>C@N03Pc7`0i=240
>C<S03@^800/9QP091hB01dP6@0O8Q/08R<K02HV700Y9a/0:RHJ02XW600[9AL09RLI00809BDI00<0
92@J02<S6`0R8A`00P0Q81`801hQ6PP07b0J200M7A/0600S81L0;2PM03/c9P17>RT0CS`V05@l8P1F
>ah0FC`N05U67P1RC2D0Le`b08M/?`2@LD<0U7920:1lB02_RUH0Yh1509Ib@P1cE3D0CCHV03DX8P0[
:RH09B/W01dX80809BLT0`0T9R<302<U8P0g02HV9P0S8b408R8P02@U800X:B<0:R/S02T[800V:1d0
:2TS02LX8P0V9b409BHP02HW8@0W:280:BXT02X[9@0Y:Q`0;BdQ034a9@0_;bD0:b/S02PW8P0X9b<0
:RTU02/T6P0a:R00>C<W03dg:@0l=RH0>SDR03Td8@0i=200<bdO03Tb8P10=B<0BCTR05U5:P1YD380
JTd]06538@1UB2P0KU0^07YI=P22GcT0QEhe08AI;P22ERT0PU<U08aQ=02FK3`0X7I40:AjB02SNT@0
XWU30:ElA0020:Z2A`0@0:F1C@2GMDD0Of0b06M;901D?Ad0BCPN04Xk901;?R/0FdPW05e::@1NBb/0
FdPZ05I29`1B?RD0E40W05I2:P80ED4X00@0DclV058n9@1B?RD0DShU0P1C?bH20590:004054o9`1@
?RH0CcdU04lm9@80CS`T00/0CT<W04e29P1=@BL0C40X04/o:@1:?BX0BC`Y04Tl:`1:?B`0BC`[04Hi
:00204@g9P0904Hi:019?2/0BSd/04Pk:P19?2T0Bch[04e1:`1>@RX0CT8X0080CD8V00H0BSlY04Pm
9`15>RH0@cPV044f9010=2@2040d9P0803ld800m=B00?SHS03df900k=BD0=c@U03@b8`0c<B@;034]
9080<RhU0`0c;bH803@^8P80<2hQ00H0<RhR03@^8P0f;R<0>2hT03T_9@0k;RD203H^8`0303D_8`0b
;R80<BlR0080;RlQ00H0;BlQ02dY800^:R40;RXQ02l[8P0`;2<2034]9004038^9@0a:al0<R`P03@^
8P80=S0T00<0=BlS03@^8P0c;B400P0f;2<01P0f;280=bdQ03T`8@0k<R40?SDT03lg9080BSTW00/0
C3TX04hi:01@>BT0DcTZ05@j:`1E>B/0CC/W04hl:01??BL0D3hV05509P0205=29P0K05A39@1<@BD0
C44U04a19@1;?bD0BShV04Pl9P17>RL0ASTV04Dh9`19>BT0B3PX04@g9P11=R@0?SHS03df8`0n=b@0
?CPT044e9@13=RH0ACPW04Xk:01=?2P0CcdW054l9`1A?BD0CchT0080D3lU00<0DD0V05919`1C@RP0
0P1D@bT01P1C@R@0DD8U0511901>@2D0BShT04Pn9@80ACdV03/0@C`V044k9@10>R@0@CTT04<h9014
=b@0AcPU04Pi9P1<?2D0CCdV050n9P1E@BP0FTDZ05m7:`1QBR/0HdX/06M::01[CbX0LED`07MK=01k
GcL0Nf0e07YO<P1iGS40RVXi08UZ>`26JS/0P6Pl07YT>`1bH3X0K5`h06QJ=`1ZE3l0KUHn075G?01e
F3H0Ne/b08IT=02DL3`0WWU209R3@P2PRd`0ZIEH0:jKH@2^WFL0[im/0;6QL02bY7D0Z9]^0:RJJ`2X
V6L0ZiMT0:nHHP2eVf80^iiR0;jPI03:Z6/0bjU/0<bZK@020<j/K`060<f[KP3<ZVd0bjU/0<bVI@3=
YfH0d:YY0P3B[6/02`3AZfX0cjUX0<fWIP33YEd0`ZAL0<BSG034XU/0aj9L0<ZSH03=YV<0cjIT0080
`j5R0P32X6405@31Wf00`9iO0;nMGP2oWEh0_9]H0;fLF@2nWEX0_IaI0;bKF02hUe@0]IAA0;>BC`2b
SeT0/HiF0:n<E02^Re40[H]>0:j<C@2_SDd0/8i>0:f;B`020:f:BP060;2:B`2bRT`0]Ha>0;V=D02j
SU40^8e90P2iSTX01P2iTD`0^Y=>0;^FD02kVE80_I]D0;bKE080`9YC0280_YQ?0;^EC02gTDP0/H]2
0:f7?P2ZQ3/0W7Pj09]g>@2HM3P0UG4g09A_>02CKST0Tfhj09A_>`2=K3T0SVdj08m^>@2@KcT0TG0j
099b>@2CLcP0U7@i08ec=P2AMcX0Ug/l09Uk>`2JNcX0Wghk0:N4@P2]RTH0/8m:0;:AC02eU4l0^9MB
102jVE@01P2nW5`0_9YJ0;VGE`2eTe<0/Y1@0;6?C`80/8i>00H0[H]<0:f;B`2^S4`0[Xe:0:n>B@2`
SdP20;6AB00<0;2=B@2aST`0[hi;0:^<B`2^T500[Y9C0:23A`2=LcH0Qfhf08I]=@24Jc<0PVTa0P21
J302089Y<@08089X=@23JCH0Q6Xg08E[>024JSL0PfTf085W=020IS<408M^=P0T08U`>02;LSX0SG@l
08ie?@2BNSh0Tg/o09Mm@P2MP4H0XX=:0:N7CP2ZRU40[X]C0:b?E`2_TE/0/I=M0;6CG`2`TV00/Y=T
0;RIJ`2mWW00`Z1c0<^XOP3E]H`0f[jG0=VoW03F_id0dl2P0=C1X@3C_Z40dKbM0=2iVP3>]IH0bk6@
0<V/RP37ZhH0aZR40P32Y8006030Xg/0^iib0;:FI`2WReT0WH9;09MlA@2SOdd0[heM0<2NL038Yg`0
bJV20<RZQP3<[hd0d[FE0=>hVP3E^Y`0f;nQ0=c4Z03ObZl0h/je0>GA^03Udk/0iMFl0>OG_P80jm_4
00X0k]g90>oNc03]g<`0jmW;0>WGb@3^e[`0k=Bj0>S@]03TcJh0h/^[0P3PbJL03`3PbZD0hlR[0>?8
Z`3SbJh0i<bb0>?=]@3Td;P0iM2k0>?A^`3Wekh0j=S10>WI`P3ZfLD0jm[80>gLc0020>kLcP80kN3@
00<0kN3?0>gPc@3^h/`00P3^h/X0<@3^h/P0jm[60>_JaP3[fL<0k=S00>cF_P3]eK/0k=Bj0>gC^03Z
dk<0j=6a0>K>[03TbZL0h/FS0>32WP3O_iT0gKfG0=^fR@3I]8L0ek:50=>^P@3?ZWd0bjIi0<VTM`37
XWD0aia_0<FKJ`32V6H0_I=Q0;V@FP2dReD0/HQ@0:n7C02VPDd0YH1<0:=nBP2PNdL0W7M309Ud@02G
LSh0UW4m09E_@P2DKT40TV`o091Z?@2=IcX0RfDh08US=P28HSD00P24Gc800`23GS40PUd`085L;`02
081K;P0307mJ;@1nFc40OEX`0080OEX`0P1lFBl207]H;P0407]H<01lFC40O5Ta07aI<@<0OEXb00X0
OU/c07mL=01nFc<0OEXb07]H<01jEbl0N5D]07MD;01fDb/0MUH]0P1eEB`01@1dE2/0MED/07IF;@1g
Ebh0N5P_00<0O5H_0P1mEc0307iH<@80NeP^0P1lFBl407eJ<0<0O5Tc0P1kF38307YG<@<0Oe`f101n
FcD207eJ=00307iK<`1oG3@0PEhf00<0Pf0h0P21GSH00`20GC<0Oe`b07mL<P0507mL<P04085O<@20
GS00P5h`07mM;`80OU`^0P1mFbd2089O=@80Pf0f0P24HCL208ER>080QV4d00H0Qf8e08UT=`2:ICP0
RfHi08aW>P2=J3/308]V>@80S6Lj0`2=J3/208eY>@0408m[>`2AKCd0TVhn09A`@080UW92102IMD42
09Yf@P80VgM30`2JMTH209UeA@<0V7A40P2DM4<0102FM4@0VGE509YfAP2KMDH209ieA`030:5lB02P
NdL0WgY60080WWU500@0WgY60:1kA`2QO4P0XGa80`2PNdL0102RODT0Y7m;0:J1C@2XPdl20:b7D`80
[HQD0`2^RED0302_RUH0[X]E0:n;E`2aSET0/XiL0;>?G`2bSF00/HaP0;2;G`2[RE/0[8YL0:f;G@<0
[heO0P2^S5h0102_SEl0/8iP0;2>H02`SV020;6?H@80/Y1R0P2eT6<20;JAI0<0]i9U00L0^9=V0;RF
IP2hUVH0^9IX0;VGJP2iUV`0^YM_0080^YMa00@0_IY`0;bIK`2kV6h0^iQ^0P2lVFl00`2nVg40`9ec
0<6NM0030<:OM`<0`j1h0P34XGT02036Xg/0aJ9j0<FRNP34XGT0aJ9j0<JSN`37Y7`0b:Em0`38YG/2
0<VVO0h0bZMm0P39YW`30<RUN`030<RVN037YGL0aJ=e00<0a:9d0P35XgD30<>QL`80`Z1b0`31Wg40
1P32WVh0`im_0<>OK`34X700aJ5a0<JRLP80aj=c0`36XgT20<NTNP<0b:Ek0P3:Yh40103:Ygl0bZMm
0<ZXN`3:Z7X40<ZXN0060<^YN`3=Zgh0cZ^10<n/Q03@[HL0dJj80P3B[hT00`3C/8X0e;6;0=FbS002
0=JcS@030=NdSP3E/XX0eK::0080eK::103F/h/80=NdS0P0fKJ>203F/h/01P3D/X@0e;:50=BbQ@3D
/HL0e;690=BaR`80e;2<203E/XX20=BaR`<0eK:<103F/hd20=JcR`80eK::0`3D/HT00`3C/8P0dk2:
0=>`RP060=>`RP80djj40P3B[H<30=6/PP040=2[P@3=Z7h0cJQn0<fXOP80cZUo0`3?ZX00103=Z7/0
cZUl0<jYO03>ZG`30<nZO@040=2[OP3>Zh40cZ^10<j[P@<0cJZ00P3<ZGl20=6/PP80d:^100@0cjZ0
0<jYO`3=Z7h0cJQn0`3<ZH420<fZPP<0cZ^30P3?[8830=2]P`030<j[P@3=ZX00c:Uo0080cZ^100T0
cJZ00<^XOP3:Ygd0bJIl0<RUN`37Y7X0b:Ek0<VVO03:Ygd00P3;Z7h00`3:Ygd0bJIl0<RUN`080<NT
NPP0bJIl0P3:Z7X30<VWN@<0b:Ih0`38YGd20<NTO0<0aZ=k0P36XW820<FQL@@0a:1`0P34Wg820<>N
L@<0`Ye`00L0`Ia_0<2NKP2oWFd0_Ya/0;fKJ`2lVVX0^YQX0080^IMW0`2iUF420;ZFHPL0^iMS0P2j
UV860;VEH@070;RDH02fTUh0/hmK0;6=F@2_ReL0/XiJ0;>?F`020;B@G0040;FAG@2fTUh0]i=O0;NC
G`80^9=N00L0]i9M0;F@F`2cSUT0/8]F0:f8D`2/Qe80[h]G00<0/8aH0P2aSET20;:>FPL0]I1L00@0
]Y5M0;>=GP2cSEh0/heN0P2bS5d30;6;G0060;6>F02aSET0/XiJ0;>?G@2dT600]8mR0P2eT6@30;BA
F`80/i1J0`2bSeT30;2=Eb_ooooo000Zooooo`P0Z7e:202WOTX20:ImA@080:ImA`2WOTX0Ygi:0:Mm
B`2WODd0Z7i>0:QoB`2WOTX20:ImB@050:MnBP2XOd/0ZX5=0:^2CP2[PDl00P2ZP4h00`2YOdd0Z7i<
0:MmB`020:IlBP80Z7i>0P2YOdl20:Z0D080Zh5A202ZPDd20:QoB`<0ZH1<0`2ZPDd01P2_QU80[XEA
0:b3C`2ZPDd0Z7m;0:MnBP@0YWe901P0YGa80:AkA`2SNTH0XgY60:9iA@2QN4@0X7M30:5gA@2PMT@0
WgE309ec@@2JL3h0V6hl09M]>`2FK3X0TVdh099]>@2CKSX0Tfdl099/?@2@JSd0SVLl08eV>`28ISP2
08MU=`0308IT=P25HcD0Q68d0080Pf4c00P0Oehe07iM=01mG3<0O5/b07YI<01iF2l0N5L^07MF;@80
NETb00@0N5Pa07MG<01gEc00MUH_0P1eEBh306]=:@0C06a>:P1]Cb/0L58^07=E<@1eEc<0MeHg07ED
=@1cDS40L4l/06i>:01]CBH0KThW06i>9@1hEBl0NEH`07]H<01mFS00OU`_07eK;@0207aJ:P04089N
;P23Gbl0QV8b08QT=0<0RVHf00<0RFDe08mY>P2?JCX01P2?JCX8095W=@H0UF/i0P2DJSP908iX>@80
SfTj0P2@JS/4095[?0@0T6Xk0`2?JCX2095[?0<0T6Xk0`2?JCX8091Z>`<0U6Xh0P2CJCL3099X=P03
099]>@2AK3P0T6/g0080SfXf0P2AK3P0102CKSX0U6lk09=]?P2CKCh2099/?@80TF/l0P2@JS/408mZ
=P80T6/g0P2AK3P00`2FLCd0UG0l09E`?00209A_>`80Tfhj00<0TVdi099^?P2BKSh00`2CKcl309A`
@0<0Tfhj0`2BKCT2095/>0<0Sf/k0P2@K3`6095]?@80T6`l0`2?Jc/00`29IcL0RVPh08YX>00208]Y
>@80S6Xj00<0SF/k08m]?@2>K3`01@2>K3`00`2?KCd0S6Xj08e[>`0208e[>`80SV`l0P2?KCd208Y/
>P0408]]>`2<KS`0S6hl08e_?@80SW0n01P0QVXj08EY>@23IcL0P6@d07iR<P1kGbl0NEd]07QL;01_
Ec40JU@]06A>:@1PC2T0Gd`[05];:P1DAB@0D44R04U08`14?B40@3TO03Tc7@0d;a`0;b`M02d[7P0]
:al202TY7`0302PX7P0W9ad09RHL00809BDK00@092@J028U7P0R9Ah08B@M0P0P8a`00`0O8Q/07R4J
01hQ6P0201`O60807B0I0P0N8AX301lR6`07020S700Q91d08RDN028U7P0Q91d07b8K01hQ6P0901XL
6`0501PJ5`0I6aP06A/H01XL6@0L7Q/00P0M7a`06P0N81d08B<N028U7P0T9Ad09bLK02d[700c<1d0
=cDP03`g8@0k=R00>C@N03Lb7P0h<b00>C<S03D_8@0]9aT09R0D01dP6@0O8Q/08R<K02HV700Y9a/0
:RHJ02XW600[9AL09RLI0P0U9AT00`0T91X08b<K028Q7002024P70P07R4J200O81X801dM6`0H02<S
6`0]:B00>C4V04Di:@1>?BT0DcdU05Hl8@1G?1l0Ed<N05i88`1^Ebh0PfPm08i_@@2BL480WGU70:^5
E02ZQ4H0VgM507YL>P1C?2X0>B`T02d/9`0V;BH07RXP0P0U9b@302@V8`<08bDR03L09RHV02<S8@0R
8R0092DP02PY8`0Z:b<0:B/P02HX7@0X:B<09bPR02HW8@0U9R009RLQ02LX8P0Y:R@0:R/U02TZ700]
;B40<30T02l_9@0[:b<09bHQ02PW8`0Y:2@0;2DM030Y8@0g<2H0>cDY03`f:00k=BD0>38R03Lb7`0d
;R00=RlO03X_7@15=Ah0FTH[06iE=`1`Dc<0ITPV05e38P1UB2H0Ke4]07]I<`24GcD0RV4e08aQ=02=
HC80UF/k09idA02VO4X0XgU709]a?`2IL3`0X7M30080ZH1<0100YX9>09UgA`23I3H0JThW05Dn7P19
>1h0BS/T04e0;@1GAbH0FTXY05]:;01HAb/0DT4W04ln901@?RH0Dd4Y0`1D@2L405<o9P0705A09`1D
@RX0Dd4Y0590:01A?bL0D3hV04hl900204dk8`0;04i39`1=@RH0CD4W04a0:01;?bT0BSdZ04Tl:@19
?2/0B3/Z04Lj:@15>2L00P14=bH04@15>2L0AcXY04Pk:P17>RT0BC`Y04/n:`1=@B/0CT8Z04i2:01=
@RH0C44U04Xo:@18?BL0ACXV048g9@10=B<0@3@T0080@3@V00P0?c@R03de8P0m=2<0>c@T03Tc9@0f
<RH0=38U03<a9@/0<BdT0`0b;RD203<_9PP0=2hR00P0;R`O02l]800a;B40=2hR03H^8`0i;bD0>S0V
03`_9P80=blT00H0=BlS03<_8`0a;b80;c0R02h_8@0];b4202dY800402hZ8@0_:b80<BdT038^9@80
<blV0100<B/O03<]8@0e;b<0=S0T03La9@0f<2@0=BlS03@^8P0f;2<0=bdT03P^900i;b<0>S4R03`c
8P0n=B@0?cLT0P16=b@01019>2H0BcPW04lj:@1A>RX205Dk;00804Xi9@1;>RH0C3`U04hn9@1@@2H0
DD8U05=49`1CA2D204i39`0704e29P1<@2H0BclW04Xn:018>bP0AcXW04Lj:@0204Ph:00304Dh9`13
>2H0@3PU0080?SLT00T0?CPT048f9P14=bL0ASTX04Xk:01=?2P0CcdW058m:01C?bL00P1>?B<00`1?
?R@0D3lU05509P0205919`0?05=2:01C@R@0DD8U05529@1?@BH0BclU04To9P17?bP0AShW040k9@11
>bD0@3XT044i9013>2@0A3LT0080ASLT00h0C3dV04dn9`1@@2L0E4<Y05U5:P1MB2/0HDX[069;;01X
BbT0JdlZ071D;`1eFC80NEde07YO=080Nf0c0200Sfll08i`?P2;Kd00QVi0081[@01iIcl0Lf@m071R
?@1[F4L0KUU606mI@@1aF3X0MEPf07mO>02<Jd00UWA7099m>P2KQTD0Yi9A0;2KG02cWf80]J5T0;RT
J@2lZ6d0/im/0;6MJP2aW6L0/IYT0;FKHP2iW680_9iR0;jPI080aJEZ01H0aZI[0<NWK036YV/0a:AY
0<:RI`30X6D0aYYI0<VMG03=XF00d:AS0=6UI03>XV40bYiM0<NKFP2kWED0^YaD0;bLD`2nW5@0`YiD
0<JPE@39XeP0c:EJ0P33XF800`32X640`ImP0<2NG`020;nMGP030;jLG@2kVe80_9aC0080_YiE00d0
_9aC0;RHC`2dU4/0/I580;6>F02`SED0[haD0:j;D@2^S4l0/8i?0;6?C`2bT500[8Y:0080[X];00<0
/H]<0;>;C@2fSDl00P2iSE007`2hRdP0^Ha90;V<B@2jSd/0^Y9=0;^DC`2lUe40_IQB0;bJD`2lUTd0
^iE<0;VCBP2fT4T0/HY50:b5@02WP3d0Y7dj09Aa>@2BKcL0TFhf08m/=02?K3H0T6dg095^>02BKcT0
TW4n09=b?@2CLS`0U7<m09Ee?02FMS/00P2FMST0302ALcL0UGLk09Qj?02INc/0VW/j09en>`2SQ440
ZhY50:n>B@2`SdX0/i9=0;FDC`@0]iIA00D0_9YJ0;ZHF02gUED0/i5A0;6?C`030:n=C@060:^9BP2[
RDT0[8Y:0:b;B02]S4L0[Xe60P2^STD0302]S4L0[Xe:0:^<B@2XRdT0ZXi=0:V@D02KPD@0R70b08I]
=@25K3@0PfXb085X<080P6L_0P21J3002@22J3D0PfTf08AZ=`24JSL0PfTf085W=01oIC80OV@a08A[
<`0208E/=00o08I]=@28KcL0RG0h08]b>P2<Lc/0SG@k08ie?02CND00VGa409ioB02SPT`0YXE?0:Z7
D@2ZRe80[XmH0;2AFP2aTU`0/91M0;:BH@2hV6T0_Ie^0<2NL@39YW`0e;B;0=VmUP3I_i`0el2N0=G2
XP3F`j<0dkjQ0=:mWP3A^Y/0ckJG0<bbT@3:[H/0b:b70<NYQ@34YX80`jF10;nRNP2iW700/9AU0:B8
EP2JOdP0U7U20:>1D@2`T640`J1c0<VYP038ZX@0b:^90<^aT03@]IL0d[VK0=FlWP3H`:@0g<N/0>3<
/`3Qd;H0hm6i0>CD^`3VeL40j=O30080k=_701H0k]g90>kMb`3/flT0j]W70>SGa`3[dkT0jM6g0>K>
/P3Sc:d0hLZZ0>39Y`3Ob:H0h<ZU0>;8[@3SbJh0hl^a0>?=]@3Td;P0hm6k0>GC_@3Tdkl0jMW00P3Z
f/<01@3/flL0kMc:0>kMc@3^g<h0kmg?0080kmo?03H0kn3=0>oPb`3_h<T0kn770>kPaP3^h<D0k][2
0>kJ`@3]ekl0kMFk0>cB]`3/dK@0j/na0>c?/@3XcZ/0i/bW0>G9Y03Q`id0g[jG0=^jT@3G]X/0e[>9
0=:/N`3@ZWT0cJMf0<ZTL`35Wfh0`Ya[0;nIJ02mUfH0^i=R0;VAH02eSEX0/HUF0:^3D02VOTX0Xg]7
0:5iA@2KMdL0VWI609QdA02ELD40Tflo091/?02>JSX0SFTi08aW>`2;ISX0RVDi08QS=`26HCD0QF0d
08AO<`23GS8207eK;P0307aJ;@1kFB`0NUP[0080NELZ00@0N5HY07QG;01hEb`0N5L/0P1gER/307IE
:P@0MeD_101hES00201kFC<0NUPb07UG<@1gEBl0ME<]07=A:`1bD2X0LDlY1@1aDBX00`1bDR/0Le</
07=C;00407QE;`80NEH`0P1jEc4207YG;@H0NeP^0`1iEc8207QF<@<0MeD`1@1kFC@407YH<`0307aI
<@1mFS80Oe`d0080PEhf00@0P5de07mL=01nFc<0OU/a101mFS0307aI;`80P5ha00@0Oed`07iL;`1m
Fbh0O5X]0P1kFB`2081M<`04085N=022GcD0Pf0f08=P=P80Q64g00D0QF0c08IQ=026HC@0Qf8e08UT
=`0208YU>00308]V>@29I3L0RF@g0080RVDh0`2;IST02@2<IcX0S6Ph08aX>02=JCT0Sf/k095]?@2B
KSh0Tflo09A`@00409Mc?`@0V7A01@2FLT8309Ea@@80UGE400@0UgE509UeA@2JMTH0W7I70P2NMDL0
2@2PNdL0WWU509ag@`2JMD40VgI209ehA02ONTH0XGa80:1kA`0309mjAP040:5lB02SOTX0YX5=0:N2
CP80ZXEA0`2[QU830:b7D`080:b9D`2]RED0[h]G0;2<FP2`S5`0[hYM0:j9G@2]R5`20:R6F0030:V7
F@2ZR5X0ZXQJ00<0ZXQJ0P2]Red20:j<GP<0[heO00<0/8iP0;>>H@2cSV400`2dSf830;F@H`060;BC
H02dTV80]I=S0;JDIP2gUFP0]iAZ0P2hUFd20;ZHJ`80^IMZ0P2jV6/00`2lVVd0_Ya_0;nML0030<2M
L`80`Iid0`32WgD50<BQM`030<FRN036XgT0aZ=i0080aZ=i0`37Y7X>0<RUN`<0ajAj0P36XgT01037
YGL0aZAf0<JTMP35XgD40<BRM0D0`Ima0`30WW020<:NKP80`im_00@0a:1`0<FQL@35XG40aJ5a1035
XWP20<JSN@80ajAj0P37Y7h01037Y7`0ajAj0<NUN037YGL20<NUM@060<RVN@39YgX0bZQk0<^YO03<
ZGl0cJZ00P3>Zh401P3?[8@0d:f50=2]Q@3A[XH0dZn70=>`R080e;690`3C/8P40=BaR@<0eK::103F
/h/20=NdS0P0fKJ>203E/XX01P3C/H<0dk640=>aQ03C/8H0dk280=>`RP80djn;0P3D/HT40=FbRP80
e[>;00D0dZn90=>`RP3D/H/0eK:<0=JcS@020=NdSP80f;F?0`3F/h/20=FbRP<0e;69203C/8X30=>^
Q080dZf30`3A[8820<fXOP<0cZUo0`3?ZX040<jYO0@0cjYm0P3?[8800`3>Zh40cJZ00<bYO`020<^X
OP050<ZWO@3@Zh40d:^10=2[P@3?ZX000P3>ZGl20<fXOP<0c:V10`3=ZX820<j[P`@0cZ^10P3=ZX02
0<bYO`80cJZ000T0c:Uo0<^XOP3:Ygd0bJIl0<RUN`37Y7X0b:Ek0<VVO03:Ygd00P3;Z7h00`39YW`0
b:Ek0<JSN@080<JSN@P0b:Ek2038YWP20<NTNP80aZ=i1035XWP50<BPL0<0`im_0`33WW430<:ML080
`Ia_0P2nW6`0102mVf/0_9YZ0;^IJ@2jV6P20;VGI`@0^IEQ1@2jUV850;VEH@<0^9AP0`2fTUh00`2e
TEd0]91L0;>?F`020;6=F@030;FAG@2dT5`0/HeI0080/8aH00/0/HeI0;>?F`2eTEd0]Y5L0;F@F`2d
SeX0/hiI0;6<E`2^RE@0[HQC0:b7DP040:n;E`80/8aH0P2aSET40;B?F`@0]I1L1@2`RUT30;6;FP08
0:n<E02_S5H0/8eG0;:>FP2cSed0]91P0;F@H`2fTF@30;>@FP<0/XmI0P2aSUP30:n<ER_ooooo000Z
ooooo`P0Z7e:202WOTX20:ElA0040:ImA`2VODT0Ygi:0:QnC080Z7i>00<0ZH1<0:QoB`2WOTX00P2V
ODT00`2XOd/0ZH1<0:^2CP020:Z0CP030:UoC@2XOT`0Yge;0080YWa:00@0YG]90:QnC02XOT`0Z7i<
0P2YOdd30:Z0CPP0ZH1<0P2XOd/30:V0C0<0ZX5=0P2^QE401@2]Q500Zh9>0:V0C02WOTX0YWe90080
YGa80P2TNdL0102SNTH0XWU50:9iA@2RNDD20:5hA00A0:9hAP2QMdD0WgE309ec@@2JL3h0V6hl09I/
>P2EJcT0TVdh099]>@2CKSX0Tfdl099/?@2@JSd0SVLl08eV>`28ISP00P27ICL00`26I3H0QF<e08AR
=00208=Q<`08081M=@1oG3@0OU/c07eJ<P1kF300NUL_07UF;P1hEBd207UI<P0407QH<@1gEc00MUH_
07EE;P80M5@]0P1/CRX02`1[CBT0K4hZ06i@;01aDbl0LeDa07EG<`1gESL0ME@e079A<01_CR/0KThX
0080KDdV00d0KDdT07EC;@1gEBl0NEP_07]J;`1lFbh0O5`]07aL:`1kFbX0PUh/08=O;@26HS00R6@b
00<0RVHd00<0RFDc08mY>P2?JCX01P2?JCX8095W=@D0U6Xh0`2EJcT808iX>@@0SfTj0P2@JS/5095[
?003091Z>`2?JCX0SfTj0080SVPi0P2AJc`3091Z>`<0SfTj202@JS/209AZ>080TfTg0P2BJ3H2095W
=@03099]>@2AK3P0T6/g0080SfXf0P2AK3P00`2CKSX0U6lk095[?003095[?0@0T6Xk00<0SVTe08mZ
=P2?JSH00P2@JcL3095/>080UG0l102DKc/209=^>P80SVXj0`2?Jc/3091/?0<0Tfhj0`2BKCT2095/
>0<0Sf/k0P2@K3`6095]?@80T6`l0`2?Jc/408i/?0@0Sfdm00<0SF/k08i/?02>K3`0102>K3`00`2=
Jc/0S6Xj08aZ>P0308e[>`<0SV`l00@0RF/i08Y/>P2;KC/0Rfdk0P2=Kcd06`2>L3h0Sg4o08IZ>P25
JCT0PfLg081T=01mHC40NUh^07QL;01gFb/0KeLa06YD;@1TCRT0H4`Y05m<:`1KBbX0E4DT05118P19
@2<0AChR040i7`0k=Al0=C0M030]7P0]:ah0;2XN02XZ800202TY7`0302PX7P0W9ad09RHL00809BDK
0P0R9Ah0100Q91d082<L020S700O8Q/201hQ6P8071lH0P0M81T201hQ6P807b8K00<07R4J01lR6`0Q
91d00P0R9Ah00`0Q91d082<L01lR6`0901XL6`806A/H00@06Q`I01/M6P0K7AX071hK0P0M7a`01`0P
8Qd08B@M02<T700W9a/0;2XK038_700f=1l00P0k=R00400i=1h0=c8N03Pc800i<b<0=S0R02hX6P0X
8QH07B0I01lR6`0R8a/09RHL02TW6`0Z9QX0:RLH02/U5`0V9aT202DU6@0302@T6P0S8a/08R4L0080
8B0L200N8AX801lP6PP07AdK01P092DO02/X8@0e;R@0@3LX04`m:P1B?RH0ECdS05@j7`1E@Ah0FdDP
06UA:`1oHc/0S6e1095_@P2JMTH0YX1?0:b6A`2PO4P0PF<o05Y4;`0l;bH0;RhV02H]9@0O:al202DW
90<092HS0`0S9B80=`0V9RH08b<Q028R800T9B00:2TS02X[8`0Y:b009RPM02PY8`0W:2809RLQ02DV
800V9b409bPR02TZ900Z:bD0:2TK02`/800`<2@0;blU02XZ8P0W9R409bHR02TX900/9Al0;bPR03@]
9@0i<RP0?3HZ03/e9`0h<R@0=2hN03@^800f;al0>BhL04@d7@1IABX0KeHh079E=@1XBRP0GdLU0698
9@1XC2L0Le</07mL<P2<IST0UF`n09U_?`2PMT@0YWa:0:QnC02PMTH0U6Xj08mU=@2EJSd00P2NLdH0
402KMd<0TW10089S=@1/D2T0Ed0P04`k8@1=?RL0DD@a05I59`1HAbT0FDP/05I5:@1A@2H0CS`T04lm
9`1A?bT205<o9P80E40W00@0ED4X05A09`1D@2L0E40W0P1D@RX04@1C@BT0DClW050n9P1??BD0CS`T
04dk8`1>@bL0CD8V04e19`1<@2P0BclY04Xm:P19?2T0BC`[04Lj:@16>BP0ACPW0080A3LV00T0ACPW
04Hi:017>RT0AcXY04Pk:01:?BX0C40Z04e1:@1=@BL00P1<@BD01P19?RP0Ac`V04Dj9P12=bD0@3DS
03lc8`80?c<U00P0?c<S03`c8P0k<R<0>C4T03La9@0d<2D0<c4U03<`9`X0<2`S0`0a;B@3038^9@P0
=2hR00P0;R`O02l]800a;B40=2hR03H^8`0i;bD0>S0V03`_9P80=blT00<0=S0T03<_8`0b<2<00P0_
<280300^<280;BTP02hZ8@0_:b80<2`S034]900b;RD0<blV03@`9`0b;200<bdQ03D_8`80=c4U01/0
=S0T03D_8`0d;R80=bdT03P^9@0i;bD0>c4U03`c900m=2<0?SDT03hf8`12=B80@cHS04Hg9019>2H0
C3TX050k:P1B>b/0Dc`/04Pi9019>RD0BS/T04`n901>@2D0Cd4T05539P1AA2@00`1>@bL01P1=@BL0
C40X04Xn:019?2T0B3/X04Lj:@80B3PX00l0ASTX04@i9`11>BH0?cPU03hg900l=b<0@SHV04@g9`15
>2L0B3TV04/j9P1>?2H0DSdX05<o9`1=?2800P1>?B<00`1??R@0D3lU05509P0205919`0605=2901B
@bH0DD8U04m19P1=@BL0Bd4X0P18@2T01P11?2H0@S`V048l9P12>RD0A3TU04@g9080ACHS0300BCdU
04Xn9P1>@2H0DT8X05I5:@1JAbT0GDPY05i9:P1YC2X0JdlZ06iB;@1bERl0MUXb07YO=01lHC@0OF8e
091`?@2?LCd0SG5108Ua@@25L4<0Ofi307Y[A01gJD80Kf1;075QBP1aH4H0LUe007EL?@1mHC`0R6]3
099bB@2ANCd0VX960:J>D02^UUP0/iYJ0;JMF`2kXV00_ZER0;VPJ02iWfH0^9iU0;ZMH`2kWV@0_ImS
0;nQI@30XVH30<6RJ@080<2QJ02nWfH0^iaS0;RIH02fUeh0_I5D0<2DE`34V5/20<JJG@0<0<>GFP2o
TeH0_91C0;6BD@2aTTl0/i9=0;FCC02jUDh0_iU>0<:MC`35WU40`Z1Q0P31Wf000`30WUl0_ieN0;jL
G@020;fKG00F0;^KDP2lW5<0_9aC0;bLD`2kVe80^9Q?0;BDB`2bTTT0/HiH0;6>EP2_S5@0[haB0:n=
D02aSe00/i5A0;BBDP2^S4`0[ha<0;2=C@2cSDh0]8a>0;J=C`80^8a?0140^8Q60;V9A`2iRDL0^8]8
0;V>BP2hT4/0^I9=0;ZCCP2iU4h0]Hm40;B>@`2bS4<0[hQ30:Z3@02TOC`0WgLi09ad=`0208aX=080
RfLc00D0SFXd08m/=P2AKSP0Tg0j09Ie@00209Ie?`0309If?@2FMS/0UgLj0080UgPh01D0UG8h09If
>`2JNSd0VW/k09Ul>P2KOSX0XXE10:N:A02^SDP0[hi90;:AC02dTdh0]IA?0;JED02eU4l0]9=>0;RF
EP2fU5@0/i5A0;2>CP2^S4`00`2]Rd/01P2YQdP0ZXQ80:Z8B02ZRDH0ZXU40:^:@`80Zh]200`0ZH]5
0:Z;B02WRTH0Y8U60:F<BP2TS4`0Ugm108=^;`25K3@0Q6/c089Y<@20Ibl207mV;P80P6L_00d0PFLd
089X=@23JCH0PfTf089X=@20IS<0OV@a07eS<021J300PVTa08A[<`25K3@0Qfhf0080R6lg03/0RG0h
08U`=`2:LCP0SW@k09Ag?`2INT<0WWe70:60BP2TPD/0Z8Q=0:^;DP2^SEL0[hiH0:j=F02aT5d0]iEU
0;bJJP2mVfh0ajAj0=:bR@3H_9D0fKnL0=S1W`3F`j<0f<FU0=BoXP3C_Yl0d[^L0=2gV03=/i80bjj<
0<R/Q`38ZXH0a:J20<:TP02nXGT0]iY^0:fAHP2RQU@0VGi709=h@@2TQ5D0/I9T0<6RMP38Zh<0b:b7
0<N]RP3;/Y<0d;NI0=:jWP3E_J40fLBY0=g9[P3PckD0hm6i0>CD_@3TeKh0j=O70>[Ia`020>cKb@0:
0>kMb`3^gLT0k=_70>SG``3VeL40j=2f0>K>]03Tc;00hLZ[0=o8Z080glRV00X0h<ZU0>;:/03Sbk40
h/bd0>??]`3SdK/0iM>o0>KE`@3Ue/<0j][10P3[fl@01@3/flL0kMc:0>kMc@3^g<h0kmg?0080l=o=
02l0kmk:0>kNa`3]gL@0kMg30>cL`P3/gL00lMVm0?3I^P3_e[P0k]>e0>g@/03ZcJ/0jL^W0>[9YP3V
bJ40hlJL0>71V03M_940fKN:0=JaQ03B[Wh0dJ]l0<ZRKP39XFd0aIeY0<6II@2mUF40^I5M0;F=F@2d
S5P0[hYF0:f8E02YQ500YGm>09miB02KMD@0Ug5209E_@02CKT80TVe1091[?`2>JCd0S6Lk08YU>@29
I3P0R6<g08MR>00208IQ=`0608AO=@23GS@0PUdc085L<P20Fc40NUT^0P1iF2d00`1hEb`0MeH[07IE
:P0207ED:@<0MED/0P1dE2/307=C:PP0LU8/0P1eEBl0101cDbd0LU8/071@:P1_CbT406e=9`80KThX
101_CbT207AB;@80ME<^101fE2l707QE;@0307MD;01hEc@0N5Ld0080MeHc0`1fEC800`1eE340MUDb
07IE<P0307IE<P@0MeHc00P0NUL_07]H<01mFS80OU/c07mL=01nFc<0OEXb07aI<@<0NeP`00<0NUL_
07UF;P1iERh00P1hEBd2081M<`0407mL<P1nFc40OU/a07eJ<080O5T_0P1nFc401`1oG380P5dc085N
=022GcD0Pf0f08AQ=`24Gc800P25H3<01@26HC@0Qf8e08QS=P28HcH0RF@g00<0R6<f0P29I3L308YU
>080RfLg00@0S6Ph08eY>@2>JSX0T6`l0P2AKCd809Ea?@H0Tflo0P2DL40209QhA`0409UgA`2KMdL0
W7Q809egB080WgI800<0W7M309]f@P2IM4000P2HLcl0102KMT80WWU50:1kA`2ONTH309iiA@040:1k
A`2RODT0YH1<0:J1C@<0Z8=?0`2YQ5020:Z5D@080:Z7D@2[Qe<0[8QD0:f9E`2]RET0[8MJ0:Z5F@2Y
Q5P40:F3E@040:J4EP2WQEL0YhEG0:R6F0<0ZhUK0P2/RU`30:f;G@<0/HaO0`2bSF020;>>H@060;2?
FP2aT5d0/Y5N0;>AH@2dTV@0]I=V0P2fTfT0102hUVP0]iEW0;JDIP2fU6H20;NEI`030;VGJ@2kVF/0
_I]]00<0_Ya_0P2oWG030<2NL@040<6OLP32X7<0`j5d0<>QM0@0a:9e0P34XGL20<FRN0@0aZ=i2037
Y7X40<JSN@80aJ9h0P34XGL50<BRM0030<>QL`32X780`Z1b00D0_ie_0`30WW030<:NKP@0`im_00<0
a:1`0<>PMP33X7H00P34XGL40<FRN080aJ9l00@0aJ9j0<FRN035XgH0aJ=e0P35Xg<20<NTNP80b:Ek
00D0bJMj0<ZXN`3;ZG`0bjUl0<bYO`020<fZP0030<j[P@3?[880d:f30080dJj40P3@[HD20=6^QP03
0=:_Q`3C/8P0dk2800<0dk280P3D/HT20=FbRP80e[>;203H]Hd80=>`R0060=:`PP3B/8<0d[230=:_
Q@3B[hL0dZn90P3B[XX00`3B[hL0dk280=>`R0020=BaR@80eK::00H0e[>;0=6^R03B[hT0dk2:0=Ba
R`3F/hd20=NdSP80fKJ@0P3G]8`20=JcR`80eK::0P3D/HT80=>`RP80e:n50P3C[X@20=:]P`80dJb2
0`3>ZGl30<nZP080d:^1103?ZWd40<jYO0060<n/PP3>Zh40cZ^10<fZP03<ZGl0bjQn0P3:Ygd30<nZ
P0@0cZUo00<0cJQn0<^XP03;Z8000`3<ZH430<fZPP80cJZ00P3<ZGl40<^XOP040<bYO`3;Z7h0bjQn
0<ZWO@80bJIl0`38YG/01P39YW`0bZMm0<^XOP3:Ygd0b:Ek0<JSN@T0aJ9h2037Y7X80<NUM`@0aJ=f
0P34XWD20<>QM080`Yi^1P33Wfl20<>NL@<0`Ye`0`31W6l01@2mVf/0_9YZ0;bJJP2kVFT0^YQX0080
^IMW00<0^9IV0;VEH@2iUF401`2iUF450;NCG`<0^9AP0P2aSET20;:>FP0D0;B@G02eTEd0]Y9N0;NC
G`2iUF40]i=O0;B@G02aSET0/8aH0;:>FP2dT5`0]Y9N0;B?FP2cSUT0/XeH0;2;EP2^RE@0[HQC0:b7
DP2[QU430:j:EP<0[h]G0P2`S5P20;:=F@80/hiJ0P2dSe/20;F@G0<0[XUE00d0[hYF0;2;E`2`ReL0
/8]G0;6<F02^Re40[X]C0:n<EP2aSUP0/XiJ0;>?G@2dT600]I5Q00@0/XmI0P2aSUP20;2=E`<0[HYD
:oooool002[ooooo202WO4T80:ImB@060:Ak@`2UO4@0YGa60:ImB@2WOTX0Z7i<0P2YOdl00`2ZPDd0
ZH1<0:MnBP020:ImB@030:MnBP2YP4`0ZX5=00@0Z7i<0`2WOD/00`2VO4X0Ygi:0:QoB`020:QoB`80
ZH1<0P2ZPDd80:V0C080Z7m;0`2YP4`30:Z1C@@0Zh9>00<0ZH1<0:MnBP2UO4P00P2TNdL30:=jAP<0
XWU50P2QN4@04@2QMdD0X7I409me@`2MLd40VW0n09Q^?02GKC/0UV`j099]>02BKCT0Tfhj09=]?02B
K3d0T6Xm08iW?02=IS/0R6Hh0080QfDg00<0QV@f08ES=@24HS@00P23HC<02023GCH0PU`e085K=020
FS<0OUPa07eG<01lERl0NeD^0P1hF34207MG<00607IF;`1eEBh0M5@]07AD;@1_DBd0KU0/0P1]Cb/0
601^D2`0Ke4]079D<01cEC40Le8c079A<P1`Cbh0KTdZ06i>:01^CRL0KdlX071@9`1cDb`0MED^07MG
;P1jFbl0Ne`^07]L;@1kGB/0NU`Z089N:P23Gb/0QV8^08QT<0<0RVHb00<0RFDa08mY>P2?JCX01P2?
JCX;099X=P<0TfTg0P2DJSP808mY>P07091Z>`2?JCX0SfTj08iX>@2?JCX0T6Xk095[?003099/?@03
095[?02@JS/0SfTj0080SVPi00<0SFLh095[?02AJc`00`2@JS/;08mY>P<0TfTg0P2BJ3H3095W=@03
099]>@2AK3P0T6/g0080SfXf0P2AK3P00`2CKSX0U6lk091Z>`06091Z>`0408mY>P2=J3@0SVTe091[
=`<0TF`h0P2@JcL809=^>P80RVPh0P2;JCT308aZ>P0408e[>`2CKSX0Tfhj09=^>P<0TVdi0P2AK3P3
08m[>`80T6`l1P2AKCd2091/?0<0Sf/k202@KSh00`2<JSX0SF/k08i/?00208m]?@0308i/?02=Jc/0
S6Xj00<0SF/k0P2>K3`308m]?@80RV`j00@0Rfdk08a^?02<KS`0SFlm0P2>L3h06025JCT0Q6Ph089V
=P20I3@0OF4a07YN;P1hG2`0Me/[06mG<@1ZE2d0I4hY061<:@1OC2/0Fd/Z05A5901@@B80BD0S04Dn
8P11>R00?3HP03Ha7P0a;Ql0;B/N02`Z7P80:RXP00<0:BTO02PX7P0W9ad00P0V9Q`0100U9A/08RDN
028U7P0Q91d2020S700301lR6`0N8AX07R4J008071lH0P0M81T201hQ6P807b8K00<07B0I01hQ6P0P
8a`00P0R9Ah00`0Q91d082<L01lR6`0901XL6`<06Q`I0P0K7AX301`N6`0I01lQ700P8a`08R<K02HV
6P0/:Q/0<BhK03Dc7P0j=Al0?3LQ03Td7P0g<Qh0=c8O03Pb8P0f<280<2XL02XT600M81T07b8K028S
6`0V9Q`0:BLK02XV6P0Z9aP0:bDG02HW6@0202DU6@0302@T6P0S8a/08R4L00808B0L200N8AX801lP
6PP07AdK01P092DP02LV8@0`;2<0>c<V04Pk:P1@?RP0DC/S054i7`1C?ah0Ed0N06E=:@1kGcP0RFU0
08m]@02HLdH0XWa=0:j8A`2TPD/0R6Y4061:<`10=2P0;blU02L_900O:ad202DW90<092HS0`0S9B80
=`0V9RH08b<Q028R800T9B00:2TS02X[8`0Y:b009RPM02PY8`0W:2809RLQ02DV800V9b409bPR02TZ
900Z:bD0:2TK02`/800_;b<0;RhT02XZ8P0V9B009bHR02PW8`0/9240;RHS038[9@0h<BT0?3D[03`f
:P0g<B<0<R`N03<]7`0h<B40?S<Q04Lg801IABX0K5<e071C<`1YBbT0JE8`06Q@;01XCRT0L5<[07eL
<@2;IST0TV`m09M_?P2VODT0Z7i<0:EkB@2KLD40Sf@g08UN<`2<HCL00P2AIS`0502<J3@0R6Hf07mP
<P1]DBX0FT<S04hm8`1?@2T0DdHc05=49@1FAbX0EdP[05A4:P1>?RD0Bc/T04`k9`1??RX0DShU05<o
9P1D@2L0ED4X0P1F@RT0101E@BP0E40W05=1:@1C@BT20590:00=054o9`1@?RH0CcdU04lm9@1>@bL0
CD8V04e19`1<@2P0BclY04Xm:P19?2T0BC`[04Lj:@0604Hi:00?04Lj:@16>BP0B3/X04Xm:P1<@2X0
CD4Y04e19`1<@BD0Bd0T04Tn:017?2H0A3TU044f900o=280?c<S00<0?c<U00L0?3<T03X`900g;b@0
=BhT03<_9P0c<2L0<c0Y00/0<2`S0P0a;B@3038^9@P0=2hR0P0`;R403P0b;R80=2hR03H^8`0h;R@0
>BlU03/^9@0h<2D0=blT03H`900d<2@0<S0S030a8`0_<280;S0R0P0_:b80100`;2<0<BdT034]900b
;RD203<_9P03038/800d;R80=BlS00<0=c4U00L0=S0T03D_8`0h;RD0>BlV03/a9`0m<bL0?SDV0080
?SDT0140?CDR044f8P12=B80A3LT04Lh9@1:>BL0CCXY050k:P1A?2/0ASXT04Lk9@18?2@0BCdS04]0
901<@B<0CD8T04e28P0204i39`0704e29P1<@2H0BclW04Tm9`18>bP0AcXW04Lj:@0204Ph:00>04Hi
:015>RP0@SXW040i9P0n=b@0?3LS048f9P13=RH0@cHU04Hg9019>2@0CC/U054l9`1B?RH204hm8`03
04ln901@?bD0DD0V0080DT4W00L0Dd8X05=2901B@bH0DT<V05129`1>@RP0C48Y0080BT8[0300@SdW
04@n:014?RP0ACdX04Hk9`15>2D0ASLT04Df8`17?B@0BCdU04/o9@1?@BH0Dd@W05I59`1JAbL0FdPX
06U<:P1ZCRT0KE4/071D;@1dF300NEhc07eR=@1oI3L0SVli08i`>P2=LCl0Rg=308QcA023LTH0Og17
07e`AP1cJ4X0MFY<07Y[BP1iJDL0NfM2085Z@@29L4L0TGI;099hA`2IOdh0XhQC0:Z=E@2^T5@0/iAD
0;RIF02oWU/20;fMH0060;jNH@2oWf80`J5T0<>SIP33YFL0a:IX0P31Y6`05P30Xf/0_Z5Y0;^NIP2g
VV80/iIN0;6DG02fSeP0^95J0;VBF`2jTe`0^95J0;F>E`2aRU<0[hQA0:^:E02[Re80[HY@0;2<CP2d
STd0^I9=0;bFC`2oUdl20;nMGP040;jLG@2mVe`0_9YK0;bJF`80^iUJ0P2kVUL00`2jVEH0^IQE0;RG
E0020;NFD`0A0;JEDP2cT5X0/XmG0;6>EP2`SE<0/8iA0;:@D@2cTE40]99B0;2>CP2aSTh0/Xm?0;B>
C`2eSDl0]Ha>0;F9C02dR4/00`2gQT@0102gQdD0]HQ50;B9A@2cRdH20;:;AP080:b7>@2[QCX0ZH<j
0:En>@2PNCP0VW8e09E]<P2BJC4208ES=@0708ES<`27IS<0RFPc08e/=P2@L3L0TW8i09Mf@00209Mg
?P0309If>`2FMST0UGHf0080UGHe00`0UW8h09Yf?02LNSd0VW/k09Ul>P2JOcX0WXI00:B<A02^SDP0
/8m:0;:AC02dTdh20;FDC`060;BCCP2cTTd0]99B0;:@D02_SDd0[8Y:102ZR4P01P2XQTL0Z8I60:R6
AP2XQd@0Z8M20:R7@080Z8Po00`0YXU30:N:AP2TRD@0WhI30:6:A`2ORTT0TG`m07iZ:`24Jc<0PfXb
085X<01oIRh207iU;@80OfH^00<0OfDb081V<`21Ic@00P22J3D01`20IS<0OfDb07eS<01oIRh0P6L_
089Y<@24Jc<01@26KCD0=@28KcL0Rg0i091b?02DMCl0V7M209]jA@2NNTH0YH980:V6C02/RE40[HYD
0:b9D`2_ReL0]Y9P0;^GI@2jV6/0aJ9h0=2`Q`3G^i@0fKnL0=W2X03HaJD0f/NW0=G0X`3D_j00dkbM
0=6hV@3>]9<0c:n=0<V]R039ZhL0`jF10<6SO`2lWgL0]IQ/0:^?H02QQE<0V7e609=h@@2UQUP0/iAX
0<6TNP39[HH0b:j;0<N_S@3:/i@0d;VJ0=:mX03F`JH0flN/0=o>]03Td[X0i]Jo0080i]O201X0jMO9
0>_Ib`3]g<`0kMc<0>oNc03^gLT0jm_40>OG_P3UeK`0iLfc0>C</P3QbJd0glRY0=k7Y`3NajD0glRV
0>3:Y@3Qbk<0h/bd0>;>]P3Rd;X0iM>o0>KE``3Wf<D0j=S80>_K`P80jm_400<0k=_70>cKb@3]g<`0
0P3]fld20>oMb@0V0>kLaP3]fl<0jm[00>[I_@3Yf;`0jMRj0>kF]03^e;<0jm6^0>[>Z@3WbJ<0i/JO
0>C2W03S`YT0g[f@0=bkSP3I]hT0e[:20=2/NP3<Yg<0bZ9_0<RPK02oUV00_YEO0;ZAF`2fSEL0/HQB
0:f4CP2YP4X0Ygi80:>0BP2QODT0WWY609Ue@`2ELD40T6/n08eX?02;ISX208QU?@0408MT?025HSX0
Q64i089O=`@0PEhf00L0P5de07iK<`1mFS80NeP`07YG;`1iERh0MUH]0080MED/00<0M5@[07=C:P1b
DRT00P1aDBP2075D;080L5<[0`1_DRX0101^DBT0KDl[06e?:`1]Cb/206a>:P<0JddY00D0KU0/06e?
:`1]Cb/0K4hZ06]=:@0206Y<:00606U;9`1ZBBH0JdXW06a;:01]C2T0KTdZ0P1]C2T0101/BbP0LE0]
075@;@1aD2d2079A;P<0Le8_0`1eDR`307AA:`80Le0Z00@0M5Hd07=E<`1cEC<0LeDc0P1bE385075C
<@@0LU@b0P1cEC<00`1gE2`0NEH^07YG;`0307aI<@0407]H<01jEbl0NEH`07UF<080N5D_00@0Me@^
07IC;@1eDR`0ME8/201mFS8207aI;`0607eJ<01oG380P5dc085N=022GcD0Pf0f0`24Gc8208EP<`80
QV4d00<0Qf8e08IQ=027HSD00P27HSD208QS=P80RF@g00@0RFDe08YV=P2;IcL0RfLg0P2=JCT0102>
JSX0Sf/k09A`?02DL3`309=_>`<0TVhj0`2AKCd2099^?P<0Tflo0P2GMdH0102HMTH0VWI609YfAP2K
MDH209edAP0809Qc?`2GLSh0Ug8n09Mb?P2HLcl0VWE109]f@P2LMd<209iiA@80WGQ400<0WgY60:5l
B02TOd/00P2UP4`30:J1C@80Yh9>0P2XPdl02@2XQDl0ZHEA0:Z6DP2[QeD0ZXIF0:V4E`2WPUH0YX5E
0:B2E0020:>1D`050::0DP2SPE<0Y89D0:F3E@2VQ5H00`2YQeT20:Z8FP<0ZhUK00@0[XUL0:n:G@2_
RUd0[hYM0P2`Reh20;6<G`060:f<EP2^SEP0[hiI0;2?G02aSel0/i5S0P2dTVD0102fU6@0]I=S0;BB
HP2dTV820;FCH`030;NEI@2iUfL0^iUY0080_9Y/0`2mVfd30;jLKP030;nMK`30WW00`Z1b00<0`j5c
0P32X7820<:OM@80`j1f0P34XGL<0<FRN080a:5g0P33X7H20<:OM@080<6OL@32X780`Z1b0<>QL`32
X780`Ima0<2NL02oWFl30;fKK@80_Ya^0`2oWFl80<:NKP<0`Yme0P33X7H30<BQM`80`j1j00@0`j1h
0<>PMP33XG@0`j5c0P33XG420<FRO0040<JSN`36XgT0ajEh0<NUM`80b:If0P3:Ygd00`3;Z7h0c:Uo
0<fZP0020<j[P@040<n/PP3>Zh<0cZ^30<n/Q080d:f500<0dJj60=:_Q`3B[hL00P3A[XH0103B[hL0
dk280=BaR@3D/HT:0=FbRPP0dZn700H0dJn10=6_PP3A[h80dJj40=6^QP3A[XP20=6]R@80d:f500@0
dJj60=:_Q`3C/8P0dk280P3D/HT20=:_R@030=>`RP3E/X`0e[>=0080ekB>00<0f;F?0=VfT03G]8`0
0P3G]8`20=JcR`<0eK::203C/8X30=B_Q@80djj40`3B[H<30<jYO`80cjZ00`3@Zh40103@Zgh0cjYm
0<nZO@3?ZWd30<jYO0030<fXN`3=ZX00cJZ000<0c:Uo0`3;Z7h80<jYO`<0bjR00P3<ZH430<fZPP03
0<fZP03<ZGl0bjQn00<0bJIl0P3:Ygd0103;Z7h0bZMm0<ZWO@3:Ygd20<VVO080b:Ek0P39YW`20<ZW
O@040<VVO038YG/0aJ9h0<BQMa00aZ=i0P35XgD30<JTMP<0ajEg0`34XW@20<>QL`<0`Z1b0`31WFd3
0<:NKP80`im_00@0`iia0<:ML032WG00`Ye`0P31W6l20<2KKP80^iUY0P2jV6P20;VGI`80^9IV00@0
^YIR0;VEH@2iUF40^IEQ102hU600102gTel0]I5M0;FAG@2eTEd20;JBGP<0]i=O0P2`S5P01@2aSET0
/XiJ0;B@G02fTUh0^IEQ0080^YIR00<0^9AP0;JBGP2cSe/00P2cSe/01P2eTEd0]Y9N0;>>F@2aS5L0
[hYE0:f8D`@0ZhIA0`2]RED20:j:EP<0[h]G00H0/8]G0;6<F02aS5P0/XeI0;>>FP2dSe/20;F@G0@0
[hYE102`ReH02@2^Re40[haB0:n<E02`SEL0/HiH0;:>FP2bSU`0/hmM0;:?F@030;6>F080/8eG0P2_
S5H30:b9Db_ooooo000Zooooo`P0YW]8202VODT20:Ak@`090:ElAP2VODT0Ygi:0:QnC02YOdl0ZX1@
0:Z1C@2YP4`0Z7m;0080YWe900<0Ygi:0:QoB`2YP4`00`2VO4X20:MmB`<0Z7i<0P2WOTP30:QoB@<0
ZH1:2P2XOd/30:V0C0<0ZX5=00<0Ygi:0:QoB`2YP4`00P2YP4`00`2WOTX0YGa80:AkA`020:=jAPD0
XWU50P2QN4@04@2PMT@0WgE309id@P2LLT00Vg4o09U_?@2HKS`0Ufdk099]>02BKCT0Tfhj09=]?02B
K3d0T6Xm08iW?02=IS/0R6Hh0080QfDg00<0QV@f08ES=@24HS@00P23HC<208EN=`0408AM=P22Fc@0
PEXc07mH<@80OUL`0P1hF3400`1gEc00MUH_07EE;P0207AD;@0707=C;01cEC40LU@`071B;P1^D2`0
KDl[06i@;00206mA;@80Kdh_0180KTd/06e<:@1^CRP0L50Y079B:`1cDbX0LU8[07AD;@1gEbh0NEX^
07]L;P1kG2d0Ned[07YL:P22GRX0Pel[08IR;P28I30308YV<P0308UU<@2?JCX0SfTj00H0SfTj202D
JSP00`2?IC<0T6Hd091V=002095W=@80TVPf00<0TfTg095[?02AJc`01P2AJc`2091Z>`<0SVPi00T0
T6Xk099/?@2CKCh0Tfdn099/?@2AJc`0T6Xk08mY>P2>J3T00P2=IcP2095[?0<0T6Xk2`2?JCX209=Y
=`80TVPf102AIcD00`2BKCT0TF`h091[=`0208mZ=P80TF`h00<0Tfhj09A_>`2?JCX01`2?JCX0202=
J3@0SVTe091[=`2AK3P0TVdi095/>02@JcL0SfXf102AK3P4099]>@0408][>P2<K3/0S6`k08a/>`80
SFdl0P2>KSd309=^>P<0TVdi0P2AK3P308m[>`80T6`l1P2AKCd2091/?0<0Sf/k0`2>K3`508e[>`03
08]Y>@2<JSX0SV`l0080Sfdm00<0SV`l08aZ>P2;JCT00`2>K3`208m]?@<0T6hn0P2;KC/408a^?080
SFlm01P0QFTi08AX>022ISH0Of<c07aP<01jGRh0N5`/07IJ:P1_Ec40JU@]06A>:@1PC2T0Gd`[05];
:P1DAB@0D44R04Po8P15?R80@S/Q03dg8@0g<Ql0<BhO02d[7P0[:Ad202XZ8080:BTO00@0:2PN02LW
7@0V9Q`09RHL0P0R9Ah0100Q91d082<L020S700O8Q/201hQ6P8071lH0P0M81T201hQ6P807b8K00@0
7B0I01hQ6P0P8a`08B@M0P0R9Ah00`0Q91d082<L01XL6`0801XL6`806Q`I100K7AX201`N6`0I01lQ
700O8Q/08B8J02DU6@0[:AX0<2dJ03Dc7P0i=1h0?3LQ03Td7P0g<Qh0=c8O03Pb8P0f<280<B/M02`V
6P0M81T07b8K028S6`0V9Q`0:BLK02XV6P0Z9aP0:bDG02HW6@0202DU6@0302@T6P0S8a/08R4L0080
8B0L200N8AX801lP6PP07AdK01P08R@O02@U7`0[:1l0>30U04Hi:@1=?2P0Cc/S04`f7P1B?Ah0EChN
06599`1hG3L0R6Q108i[@@2EL4@0WWQ;0;2:B@2XQDd0SG1806A>=P13=bT0<30V02L_8P0P;1h202DW
90<092HS0`0S9B80=P0V9RH08b<Q028R800T9B00:2TS02X[8`0Y:b009RPM02PY8`0W:2809RLQ02DV
800V9b409bPR02TZ900Z:bD0:2TK02`/800_;b<0;RhT02TY8@0V9B009RDQ02PW8`0]9B<0;BDR030X
9@0f;bT0?3D]03`e:`0g<BD0<2XN030Z700j<b<0A3TW04`l9@1HA2T0J4la06e@<01YBbT0K5Dc06YD
;`1/DRd0MUTa08=R=`2<JS`0TV`m095[>P2VODT0XgY609ec@@2EJSd0SF8g08QL=@<0Qe/f01@0P5`X
081N;P1lGBl0KU8[05]4901=?280C3dV04m2;`1A@bH0E4H[05E7;01BA2X0C3dV04Tj9@1:>bP0CCh[
054m901C?bH0ED4X05I2:@80Ed<Z0P1E@BP40590:0@0DClW00P0CT<W04e29P1=@BL0C40X04/o:@1:
?BX0BC`Y04Tl:`P0AcXY00l0ASTX04Lj9`1:?BX0C40Z04a0:01<@2H0C44U04]09018?BL0Ac`V04@i
9@11=R@0?c@R03hb8P0n<R@00P0o<bD01`0k<BD0>BlS03H^8`0d;B<0<RhU038_:00c<2T02P0_:b82
030/8`<0<BdT00<0<RhU03@^8P0d;R801P0d;R801@0a;b80<S0S03<_8`0e;b<0=RhS0080=bdS00H0
>B`S03P`9@0h<2D0=S0T03@`900c<B@2030a8`0302la8`0a;B@0<BdT00@0<BdT0P0b;RD0600c;B40
=2hR03H`900g<BD0>38V03La9@0f<2@0=BlS03T_9P0j<2L0?38X03hd:00o=RL0?SDT03dd8`0m=B80
@CHR048g8`14=b@0ACPU04Pi9P1:>BL0C3TX04dj:@80B3`V00<0B3`T04Tm8`19?R800P1:?b406P1;
@200CD8V04e29P1<@BD0BclU04Xn9P18?2H0AcXW04Hi9P15>2L0AcLW04Ph:017>RT0AS/Y04<k:010
>BH0?SLT03/f8P11=BD0@C@T044d8`14=B80AcHR04Xh8P1?>RD0DCdU0P1??R@0101@?bD0DD0V0591
9`1C@RP205A3:@0605=2901B@bH0DT<V0553:01>@RP0CD<Z0P1;@b`02014?bT0AT0Z04I0:P18@2/0
B3dY04Lj9`17>2D0ACHS0P16?2<0;P19?B<0Bd0T04m1901B@b@0EDDT05I69@1YC2X0JThY06]?:P1^
DR/0LeL_07QM<P1mHSD0P6Dh08Y[=02;KCL0Rg0k08Yc@@29M4D0QWE908=dB@21M4X0MW5907aeB`20
Md`0PgI:08EdB029M4D0SWQ709=kB`2FNEL0VWiG09n2F02TQ5D0YXE@0:b8CP2eSe40^iEF0;fJF02o
W5`0`IiN0<>QHP36Y6D0ajMZ0<VYK03:ZVd20<NYL`0G0<FWL@33YFl0_Z1Z0;ZLIP2eUf40/iEO0;BC
IP2cTVD0/I1S0:n>H@2]S5l0ZXUL0:R7FP2VQEP0ZhQN0:^9G02]R5/0[hYF0;><E@2gSe80^i=E0;jE
E@2mVe`00P2lVU/00`2kVEX0^YQI0;VGF0020;RFE`030;^HGP2iUU`0]iAJ0080]I9H00`0]iAJ0;ZG
G@2kV5h0]I9L0;BAF@2bSeL0/HiD0;6?DP2bT540/i5A0;BBDP2cTE420;BAD@060;J@D@2eSDl0]8]=
0;>7BP2aQDP0]X=20`2dPd400`2bPT00[h8o0:j3?`020:^3?P0@0:F0<P2TOc40XG/b09ef<`2HL380
TFT^08aS;@29H2`0P5ld085P<`22HS<0Q6@c08QY<`2<KCH0T74h09=e>@80UWHm00<0UWHk09Ee>02D
MCD00P2CM3<0302BLc00VG8i09ae?02MNCd0VW/k09Ul>P2HP3X0WHI00::<@`2_STT0/I1;0;>BC@<0
]IA?00P0]9=>0;>BC@2`STh0[Xa<0:^9B@2YQdL0YhE50:J4A080YhE500H0YhE60:N5A@2WQDD0YXE2
0:J5@02VQCh20:J6?@0<0:B7@@2TRD@0XXM209f4@@2OR4D0WHQ708ij>`1lJ2T0Q6/c089Y<@20Ibl0
OVD]0P1mI2`01@1nIBd0OfH^07eS<01nI340P6Hc00<0PFLd00H0P6Hc07mU<P1mI2`0OVD]085X<024
Jc<308E/=00g08A[<`25K3H0QVdg08U^>@2=Kc/0T70m09Ac@02EM440V7A20:9n@P2VPTH0ZHE;0:Z5
CP2ZQE00[HQD0;B?F`2iTf80^9IY0<>PMP3?[hH0ek^D0=VoW03I`Z00fLJV0=_8Z03F`J@0eL2Q0=Bm
WP3A^9T0c[BC0<f`SP3:[XT0bZb80<6SO`2oXGd0^Yee0;>FJP2ZSUl0X8AB09UnA`2DND80YHUJ0;:E
J@32YWh0b:n70<R`S037/900bkBE0<jiW03E`:D0f<B[0=k:/@3SdKT0imO00>SIa0020>KIaP0J0>[H
c03/f/h0k]c>0>kLcP3_g/`0kMc80>[J`@3Ve[`0i=Bj0>?;/@3Rb[00h<R/0=k7Z03NajL0g/NU0=o8
YP3PbZD0hL^d0>7=]@3Sc[T0hm6k0>GD`03Vel@0i]W80>OJb@3Zf/420>[J``0;0>_JaP3[f/P0jm[:
0>_Ib`3/f/`0l=_80>oJa@3^fL@0k=S00>[F_@3YeKX00P3We;H0803YcJP0j<bW0>K8XP3Ta9d0h;nF
0=fjT03J]hd0fkJ:0=6_O`3?[Gd0cZYh0<ZUL@36WVX0`YUS0;nFH02nTe`0/XY?0;28C@2]QDX0Z815
0:=k@02NMS/0Vg<h09Ua=P2DLcd0Tg8l091_>P2<JSX0R6Hh08ER>022GcL0P5de0P1nG3H03`1mFcD0
O5Xd07]I<`1jF380NELa07QF<01lFS@0NeTc07UG<@1gEBl0ME<]07=A:`1bD2X0LDlY075A:P02071@
:@0306m?:01^CRL0KDdV0080K4`U0P1[CbP306Y>9`<0JDdV00<0JThY06U=:01YCBP00P1XC2L206M;
9P0306I:9@1XC2L0J4`W00H0J4`W00<0J4LT06U89@1[BRL00`1]C2T0101/BbP0JdXW06m>:`1_CR/2
071?;0<0LE0]00D0LU4^079>:P1bCRX0LThZ075=:@02071<:080Kd/W0`1]D30206a?;`<0Jdh^0P1]
D30306iA<@0=06mB<P1`Dc<0L5<c071C<`1fDb/0Me@/07UF;P1jEbl0NeP`07YG;`1iERh0N5D]07QD
<00207MC;`0507IB;P1dD2`0Ldl[07=?:`1bCRX00P1fDbd00`1gE2h0N5D_07UF<00207YG<@0707]H
<P1jEbd0NeP^07aI;`1nFc40Oe`b085N=002089O=@80Peha0`24Gc8408EP<`<0QV4d0P27HSD208QS
=P<0RFDe00H0RVHf08]W=`2<J3P0S6Ph08eY>@2CKc/2099^>P80TFdi0P2@K3P0102?JcL0T6`l091/
?02AKCd2099^?P<0Tflo0P2BLT40102CLD40UG5109A`@02EKd0209M^@00409=^>P2DKc/0UW4m09Qc
?`@0VGA00P2MN4@01P2LMd<0WGQ409iiA@2QO4P0Xgi:0:F0C0<0Y7m;0P2UP4`30:J1C@0;0:J3C@2W
Pdl0Z8A@0:V5D`2XQ5@0YX5D0:AoD`2SOU80Y89D0:>1D`2RP5800P2QOe400`2SPE<0YH=E0:J4EP03
0:N5E`80Z8IH0`2YQeT30:f8F`80[XUL0`2_RUd02P2ZRE<0ZhYD0:b;EP2^SEX0[heM0;6?G`2bT680
/i5S0;BCH02cTUl20;:AGP80/i9O00<0]IAQ0;NFH`2iV6D00`2kVFT20;bJJP<0_I][00P0_Ya/0;nM
K@31Wfl0`Z1`0<>QL@32X700`Im_0<2NKP<0`Iid0P32WgD30<>PMPP0a:5g0`33X7H20<:OM@<0`Iid
00T0_Ya^0;nMK`30WW00`Ima0<2NL02oWFl0_I]]0;bJK02kVF/00P2lVV`20;fKK@80_Ya^00<0_ie_
0<:NKP32WVh01P31WFd30<6NM080`Yme0`33X7H20<6NN0040<6NMP31WW@0`Imb0<6OL@80`Im_0P34
X7`01034XG/0aJ9h0<FSMP35Xg<20<JULP80b:Ii00@0bJMj0<ZXN`3;ZG`0bjUl0P3<ZWd20<bYP@04
0<fZPP3>Zh<0cjb40=2]Q@80dJj600H0cjb40=2]Q@3A[XH0dZn70=>`R03D/HT20=FbRPP0dk28203A
[XH01P3A[h40dJn20=6_PP3A[X@0dJj60=6^R080dJf900D0cJZ20<j[P`3>Zh<0cjb40=6^QP020=:_
Q`050=>`R03C/8X0e;6;0=BaR`3E/X`00`3F/hd20=NdSP@0ekB<0P3F/h/20=FbRPP0dk2:103D[hD2
0=>^Q080dZf300@0cZUo0<nZP03?ZX00cjZ00P3@Zh420=6/PP80d:]n0P3?ZWd20<jYO080cJQk103;
Z7h40<bYO`@0cJQn103>ZGl20<ZWO`80bjR00`3<ZH40203=ZX80cJZ00<^XOP39YW`0b:Ek0<NTNP38
YG/0bJIl0`3:Ygd40<VVO080b:Ek0P39YW`20<ZWO@040<VVO037Y7X0aJ9h0<>PMPP0ajAj2035XWP2
0<BRM080aJ=e0P36Y7H20<NUM`<0`j5a0P32X7030<6OK`<0`9a/00<0`Ie]0<:NKP32WVh00P33Wfl3
0<:ML080`Ia_0`30Vfh20;ZHJ0<0^IMW0`2hUVH20;ZFHP80^IEQ00<0^9AP0;NCG`2gTel00P2gTel0
0`2cSe/0]91L0;B@G0020;FAG@80]Y9N00<0]i=O0;FAG@2dT5`00P2cSe/01`2dT5`0]Y9N0;RDH02j
UV80]i=O0;JBGP2eTEd01@2dT5`0102aS5L0/8]F0:f8D`2[QU430:Z5D0040:^6D@2/R5@0[8QD0:b8
E080[HUE0`2^RUH01@2_RUH0/8]G0;2;E`2aS5P0/hiJ0080]8mK00<0]I1L0;6<E@2aS5D01P2`Re@2
0:n=D0030;2=D`2`SED0/8eG0080/8aH00<0/8aJ0;6>F02aSUP00P2`SEL30:n<EP040:j;E@2[R580
ZhQB0:^8DR_ooooo000Zooooo`P0YGY7202VODT20:Ak@`090:ElAP2VODT0Ygi:0:UoC@2YOdl0ZX1@
0:Z1C@2YP4`0Z7m;0080YWe900<0Ygi:0:QoB`2YP4`00P2UNdT20:IlBP040:MmB`2XOT`0ZGm=0:Uo
C@<0Ygi80P2XOdT30:V0BPX0Z7m;0`2YP4`30:Z1C@030:AkA`2UO4P0Ygi:0080Z7m;00<0Ygi:0:El
B02TNdL01P2RNDD30:5hA00A09me@`2NM480WG=109ab@02KLCl0VW0n09U_?@2HKS`0TVdh099]>@2C
KSX0Tfdl099/?@2@JSd0SVLl08eV>`28ISP00P27ICL00`26I3H0QF<e08AR=00208=Q<`80QUlh00@0
QEhg08=L=@22Fc@0P5Tb0P1oF34207QH<@0407MG<01fERl0MED^07AD;@80Le</00H0MUPd07AF<P1b
E300Ke4]06e?:`1/CRX206e?:`0>06e<;@1/Bb`0K4/Z06e<:@1^CRP0LE4Z07AD;@1fERd0L5<[079E
;@1dEbd0MeX^07UM;P1iGBd207UM:`04089O:@23H2X0QV<]08QU;`<0RVLa00<0RFH`08mY>P2?JCX0
1P2?JCX809E[>@80SV@b0P2?IC<0102@IS@0TFLe095W=@2BJ3H8099/?@07095[?02@JS/0SVPi08eW
>02>J3T0T6Xk099/?@0209=]?P80TV`m00<0T6Xk08mY>P2>J3T00P2=IcP2095[?0<0T6Xk2`2?JCX2
09=Y=`80TVPf0`2AIcD0102@IS@0TVdi095/>02@JcL208mZ=P80TF`h00<0Tfhj09A_>`2>J3T00`2>
J3T408mY>P0308aW<`2>JCD0T6/g0080TVdi00<0TF`h091[=`2?JSH0102@JcL4095/>00408i^?@2?
Kch0Sfln08m_?P80T70o0P2ALD0309=^>P<0TVdi0P2AK3P308m[>`80T6`l1P2AKCd2091/?0<0Sf/k
0P2;JCT508YX>00408UW=`2;JCT0S6Xj08i/?080Sfdm00<0SV`l08aZ>P2;JCT00`2?KCd2091^?P<0
TFlo202<KS`06@25JCT0Q6Ph089V=P1oHc<0O60`07UM;@1gFb/0MUXZ06mG<@1ZE2d0I4hY061<:@1O
C2/0Fd/Z05A5901@@B80B3lR04Dn8P12>b40?CLQ03Pc800b;b00;B/N02/Y7@0[:b400P0Z:R000`0Y
:Al0:2PN02LW7@0202HV70808RDN00@08B@M020S700P8a`07b8K0P0N8AX201`O60807B0I0P0N8AX2
01lR6`0401`O600N8AX082<L024T7@808RDN00<08B@M020S700J71/0200J71/00`0J71T06adJ01/M
6P0401/M6P0J01`N6`0N81/07b8K024R6P0U9AT0:RPI030]6P0d<Qd0>C@N03dh8P0i=1h0=S4M03Lb
7`0h<R80=c4S034[7@0]9a/07B0I01lR6`0R8a/09RHL02TW6`0Z9QX0:RLH02/U5`0V9aT202DU6@03
02@T6P0S8a/08R4L00808B0L200N8AX801lP6PP07AdK01P08R@Q028S7P0Y9Ql0=BlS04<g9`1<>bL0
CSXR04/e7@1A?1d0Dc`L05m79@1fFSD0QfM008eZ@P2DKd<0W7I90;6<B02ZQdl0Sg9:06MA>@14>2X0
<30T02L_8P0P;A`202DW90<092HS0`0S9B80=`0V9RH08b<Q028R800T9B00:2TS02X[8`0Y:b009RPM
02PY8`0W:2809RLQ02DV800V9b409bPR02TZ900Z:bD0:2TK02/[7`0_;b<0;RhT02TY8@0V9B009RDQ
02PW8`0]9B<0;2@R02lW900f;bT0?3D]03df;00f;bD0<2XN02lY6`0l=BD0BCh/0510:@1HA2T0I4/]
06Y=;@1XBRP0HTh[06E?:P1/E2h0NUhf08Y[?`2CLD<0U710099/>`2SNT@0WGA009I/>P2@ICP0SF8h
08YN=`26FSL00P23Ec@0601jER80OE/[07aM;`1_Db`0Fd@T04/j8019>R<0Bch[0553:01CABX0E4H/
0553:@1<?BH0BCXU04Xk:01<?BX0DCdT058n9@1E@BP0Ed<Z05Q4:`1G@bX0ET8Y05E1:0<0DClW0`1B
@2P205=1:@0804i39`1=@RH0CD4W04a0:01;?bT0BSdZ04Tl:@19?2/304Pk:P80BC`[0`18>bX01P16
>BP0AcXW04Tl:@1;?bT0C40X04a09P80Bd0T00H0B3dW04Hk9@14>BD0@CHT03ld8P0n<R8203hb9008
03lc9`0k<BD0>BlU03D/8`0c;2@0<RdW038_:00c<2/:02l[8P80<2`S100a;B@803@^8P80<c4T00<0
<blS03D_8`0f;R<00P0f;2801P0h:b80>30U03P`9@0g<BD0=30T03<a9080<34S00<0;c4S03<_9P0b
;RD00P0b;RD3034]9004030/8`0c;B40=2hR03H`9080>38V0140=c4U03H`900e;b<0>BlV03/a:00m
<bT0?cDY040g:00o=RD0?C@S03`d8@10>2<0@SLS04<h9015>2D0AcPU04Th9P0204/h9`80B3dW00<0
B3hU04Pn8`18?b800P18?b006P18?ah0C44U04a19@1;@2@0BShT04Tm9@17>bD0ASTV04Dh9@15>2L0
AcLW04Ph:017>RT0Ac`Z04@l:@11>RL0?SLT03/f8P10=2@0@3<S040c8P12<b00AC@P04Tg8@1>>B@0
D3`T0P1@?bD00`1A@2H0DT4W05=2:00205A3:@0705E4:P1C@R@0DT<V05939P1A@bP0Cd<Y04i4:`02
04]3;01604E0:P17@B/0B48/04U1;01:?b/0B3/X04Pi9P16=b@0@S/Q04Dk8P17?B80BSlS04i08`1A
@R<0Dd<R05A48`1ZCB/0JThY06]?:P1]DBX0LUH^07QM<P1nHcH0PFHi08MX<@28Jc<0RFhi08Ub?P29
MD<0QgI808EfB`23MTX0N7I507ijBP27Odh0RX1=08YmB@2=O4P0TGe809F0B`2HNV00VgiP09mnG@2O
OUD0XWe@0:R0C02aR500^8iB0;jGE030VEH0`ieL0<FRHP38YVL0c:Y[0<b/K`3>[W40bk1i0<Z_N038
[GH0aJYc0<6VK`2kX6T0]iaU0;BIHP2dV740/YI_0:nCK02[SfP0Yh]T0:F9HP80XhMP00P0[HUW0:f9
I@2_RF80/8UN0;B<F`2hSeT0^i=H0;jDF080^iUJ00<0^YQI0;VGF02hUUL00P2gUEH04P2fU5D0_9QT
0;VEH@2eTEd0/XiJ0;>?F`2gTel0_9QT0;nKI`2fTed0]I9J0;>@F02aSU@0/HmB0;6?D02bT500/i5A
0;BBDP80]Y=C00D0]i5B0;F=C`2cRT`0/HE80:n3AP030;B1@00/0;60?P2_Ocd0[7ll0:Un>P2XOCT0
YWhi0:1k:`2ONR`0W7H]09Qa;P2CJbh0S6<[08MN:P24FRP0Oehe07mN<`21H3<0Q6@c08QX=@2=KSL0
TG8i09Af>P2FMSd0UGDj09Ad>@2DM3L0TW<c099c<P2ALRl0T74^09Ya>@2MMSd0WGTm09aj>`2HNcT0
V80j09b5?`2PS4<0/8m:0;6@B`2cTTd0]IA?0;JED02eU4l20;BCCP060:f;B`2/RTX0ZHM70:J4A02U
Pd<0Y8920P2UPd<01P2VQ4D0YXA40:J4A02VQD80YH@o0:F4?@80YHDl00`0XXM00:B9A02OQd40VhA0
09b7A02KR4H0S7Pi07UW9`23JS80PVTa081W;`1nIBd207eT;080OVD]00@0Nf4^07aR;`1oIC80P6Hc
0P21Ic@2081V<`0407aS:`1nIBd0PFP`08=Z<P80QF`d03`0Q6/c08=Z<P25K3H0QVdg08Q]>02<KSX0
SVhk095`?@2BLCh0UG4o0:1l@02SOd<0Yh=90:R4BP2XPd`0ZhIA0;:=F@2gTUh0]iEX0<:OM@3>[XD0
e[ZC0=VoW03J`j40fLJV0=c9Z@3F`J@0eL2Q0=BmWP3B^IX0ckFD0<f`SP3:[XT0bZb80<2ROP2nX7`0
^Iad0;6DJ02YSEh0X8AB09UnA`2ENT<0YHQL0;:GK032YWh0bJn:0<R`SP37/900bKBG0<jiWP3E`JP0
fLF/0=k<]03Te;/0j=W20>[KaP3XflP0im[70>_Ic`3/f/h20>kLcP0K0>oNcP3]g<P0j][10>KF_03S
e;L0h/Z`0>79[`3Oaj/0gLJW0=g6YP3NajD0glRV0>3:Y@3Pc;@0hLfe0>7?^@3Sd[h0iMK30>OGa`3W
f/T0j=_;0>WI`03YfL80j][30>[Ia@3ZfLL0j]W90080j]S:0P3^fL@09P3/f<00j]Jm0>SD^@3VdkD0
iM:d0>CA/@3TaZ00h/BN0>71VP3L_9<0fKR=0=FcQP3D[h80dZf00<VUL`37Xg40aJ1/0<:JIP2nUEl0
^I1H0;N<E@2gRU40ZX160:QnA02TNT00WgDk09Y`=P2FK380TVP^091V;02<K3<0RVTc08QW<P25Hc<0
PElb07iK<@1lFC<0NULa0P1gEC0207ID;`0<07EC;P1dDRd0Le4/07=A;01hES00MeD_07EC;@1bD2X0
L4hX06i<9P1/BR@0JdTS0P1ZCBD00`1YC2@0J4/S06M:8P0206I98@0306E8801WBb@0Id/T0080ITXS
0`1UBB800`1TB240J4/Y06Q;:@0206M::00406I99`1UB2H0IDPV06A79@<0IDPV00<0ITTW06M::01W
BRP00P1XBbT0201XAbH0JDPW06]::@1]C2/0KTd/06e<:`1[BRT0JTTX0P1/CR`206e?;@<0KU0^00<0
Ke4_071<:01`C2P00P1_BbL01@1^BRH0KDTU06e99@1/B2@0JD`/00<0J4/[0P1WBRX206I9:@80K4l_
0`1]D300301^DC40Ke8b06mB<P1`Dc<0ME8Z07IC:`1hEBd0NEH^07YG;`1iERh0N5D]07MD;080Me<_
00@0MU8^07EA;@1cCb/0LThZ0P1aCBT2071=9`06075>:01cD2X0ME8/07IC;@1gE2h0N5D_0P1jEbd0
101kF2h0OEX`07mL<P20GC<2089O=@@0Peha1024Gc8308EP<`80QV4d0`27HSD208QT=00308UU=@2:
ISH0RVHf0080RfLg00<0S6Ph099^>P2BKSX00P2AKCT0102@K3P0Sf/g08m[=`2>JSH2091/?004095]
?@2BKSh0TVhn09=_?`80U7100P2=KC`0102>K3`0T6`l08m[>`2@JS/2099Y>`09091[=`2BKCT0UW4m
09Ud@02JMD40VGA009Qc?`2FLCd0WGQ400<0W7M300@0WWU50:1kA`2SOTX0Y7m;0`2SOTX20:AoB`<0
YH1<00l0YX==0:J2CP2WPdl0Z8AB0:N3D`2UP5<0XgiB0:9mD@2TPU@0Xh5C0:5oD@2POU00XGmA0:>1
D`2UPeD0102VQ5H20:N5E`<0Z8IH0`2/QeX20:f8F`<0[XUL00T0ZHU@0:Z9D`2[RU@0[HaG0:j=FP2`
SUh0/HmQ0;:@HP2cTUl00P2bTEh01P2aT5d0/Y5N0;:AGP2dTf00]YER0;RGI0<0^YQX0P2kVFT30;bJ
JP080;fKJ`2nW6`0`9i^0<:PL033XG40`Z1`0<2NKP2oWFd20<2ML`80`Iid0`32WgD00`33X7H0a:5g
0<BQM`060<BQM`040<>PMP32WgD0`Yme0<:OM@80`Iid0P30WG<01`2lVV`0_I]]0;nMK`30WW00_ie_
0;fKK@2kVF/00P2jV6X20;^IJ`030;bJK02mVfd0_I]]0080_Ya^00<0`Yi^0<6MK@31WFd00P31WFd3
0<2LK080`9ec0P31WW@30<:OM@070<>PMP30WGL0`9eg0<2MM@30WG<0`9ia0<2NL0020<2NKP080<>O
O@33Wg/0a:5k0<BQM`34XWD0a:9b0<BSL034Xfh20<NUM`80b:Ih00@0bJMi0<ZXNP3;ZG/0bjUk0P3;
Z800103<ZH40cJZ20<n/Q03@[HD20=6^QP080<j[P`3?[8@0d:f50=6^QP3B[hL0dk280=BaR@3E/XX8
0=6^QPP0d:f500H0d:j00=2^P@3@[X40d:f30=2]Q@3@[HL20=2/R0090<^XP03<ZH40cJZ20<j[P`3?
[8@0d:f50=6^QP3B[hL0e;6;00@0eK:<103F/hd0103H]Hd0ekB<0=NdS03G]8`20=JcR`80eK::203C
/8X0103E/8H0e:n50=B_Q@3D[hD20=>^Q080dZf3103?ZX020=2[P@80dJb20`3@Zgh00`3?ZWd0cZUl
0<fXN`020<fXN`80bJIl00<0bZMm0<^XOP3<ZGl00P3=ZX000`3>Zh40cJQn0<fXOP030<fXOP<0cZUo
0P3:Ygl20<^XP0@0c:V100P0c:Uo0<^XOP39YW`0ajAj0<JSN@37Y7X0bJIl0<ZWO@D0bJIl0`38YG/2
0<VVO080bZMm00@0bJIl0<NTNP34XGL0`j1f2038YG/80<FRN080`j5c00@0a:9d0<FSM@35XgD0aZAf
0P37YGL01033XG40`Z1`0<:PL032X7020<6OK`80`9i^0P2oVf/20<2LK0040<6MK@32WVh0`Yi^0<>O
K`80`Ye`0`31W6l30<2KKP@0^IMW102hUVH20;ZFHP040;VEH@2hU600^9AP0;NCG`<0]Y9N00@0/XiJ
0;>?F`2cSe/0]91L0P2eTEd20;JBGP030;ZFHP2hU600]Y9N00<0]91L00<0]Y9N0;NCG`2bSUX00P2c
Se/20;B@G0070;>?F`2bSUX0/XiJ0;6<E`2_RUD0[8MB0:Z5D0020:V4C`030:Z5D02[QU40[8QD0080
[8QD0P2]RED30:j:EP080:j9E@2_RUH0/8]G0;6<F02bSET0/hiJ0;B?F`2eT5`30;:=EP80/HaE0P2`
Re@00`2_RU<0/8iA0;2>D@020;2=D`050:n<E02_S5H0[XYF0:j:EP2aSUP00`2`SEL20:n<EP80[X]E
0`2ZQe4[ooooo`00:_ooool0202PMCh0XGHo0:=h@@2TND80YGY30:Ai@P2SN440XWM0102WO4T20:Qm
BP80ZGi;402XOd/80:V0C0<0ZGm=0P2XOT`30:MmB`P0ZGm=00@0Ygi80:QoB@2XOdT0ZH1:0P2ZPD/2
0:^2C0030:MnBP2VODT0YWe90080YGa80P2TNdL01@2SNTH0XGe10:5m@@2QOD<0X7a20080X7]400P0
WgY509mjAP2ONTH0WgY509eh@`2KMT40V7<n09Ia?0<0UG0k00P0Ug8n09Ia?@2DKSl0TV`o091Y@02>
IT80S6A108]R@P80RF@g0P2:ICP01029I3L0Qf8e08EP<`24Gc83089M<`80PE`b0`20Fc402@1nFc40
OEX`07aI<@1jEc40N5@`07IB<01dD2h0Ldl_07E>;@0207=?;@03079@;@1aD2d0Ke4]0080KU8]201_
CR/0401fDb/0Me@/07QE;@1iERh0NeP`07aI<@1mFS80OU/c085K=022GC<0Pehd08EP=027HSD0RFDe
08YV=02;IcD208eW>080SVPi0`2?JCX2091Z>`H0SfTj00@0T6Xk08aV=`2>J3T0SfTj0P2AJc`01P2?
JCX0SVPi08aV=`2?JCX0T6Xk099/?@80Tfdn00H0TV`m091Z>`2?JCX0TfHl099U>`2@HcT208mR>003
091S>@2BIC/0TfHl00P0T6Xm202<ISL408iX>`@0SfTl00H0SVXj08mY>P2?JCX0TFPj099W>P2CIcX2
09EV>P80SVPi0P2?JCX0402@JS/0TF/l095[?02AJc`0TV`m095/>02@JcL0SfXf08iY=@2?JSH0T6/g
099]>@2CKSX0SfXf091[=`2BKCT209=^>P03099]>@2@JcL0SfXf00<0TV`m0P2AJc`3091Z>`0609Eb
?02DL3`0TFdi08m[>@2>JSX0SFPk0P2>JCd808m[>`80Tflk00@0TVhj095]>@2?JcL0SVXf0P2=JCD3
099_>@80TFhh0`2@KCL208aZ>P0908e[>`2>K3`0SF/k08]Y>@29IcL0R6Hf08aX>02>JSX0TVhn0080
U71000<0TVhn08iZ>P2<J3P0202=Jcd2099/?@03091/?02=Jc/0Rf/j0080RF/i01T0QVXh081[?01o
JS/0OFPi07]V=`1iI3D0MV4b07EP<@1dGc00K5LX06aG:P1[ER/0J58[069;:@1LABH0EShR058j801=
@R@0BT4T04@m8@0n>R40=SDP02ha700Y;A`09B`J00<0:2PN0P0W9ad302HV7009020T5@0Q9AL08RHH
02@W700S9Qd08RDN020R7@0N81/06Q`I00806adJ00<071hK01dO700M7a`00P0N81d301hQ6P<07b8K
0P0P8a`00`0M7a`071hK01/M6P0201TK600401XL6@0K7AX06adJ01`N6`P06Q`I0P0O81/01P0P8A/0
8R<K02HX7@0Z;1l0;c4T034c9@80?STU00h0>3<O034/600d;a/0>cHR03Pc7`0_:QH09BHN024R6P0N
7aL07b0H02<T700U9Qh092DM028S6`@08b@L0P0R8a/2024R6PD07AhH0`0N7aT0<P0J7AH06ahG01`O
600M81T07R4J01lR6`0P8a`08B@M020P7P0O7ad07AdK01`L6P0K6aT071`J01dM6`0N7Q`07AlL024R
7@0X:200<RhR03/d8P12=b<0ACTQ04Pj7`17=bL0CC`Z05Q6;P1WDS<0Meli08EZ?`2>LT80U7I40:R7
A02bSU80ZXAE08AP?P1F>bH0=RXL02P[8P0P;bP09RPU02@V8`0R92408B<P020R7`0Q8b008R@Q02<U
8P0V:B809BPQ0P0T9b001`0U:2409bXS02T/9@0Z;BH09RHN02LW7`0Y:B400`0[:b<01P0Y:B40:2PP
02d]9@0/;2@0:b/S02XZ8P80:2PP0P0W9al01P0W8Qh0:RDQ02hY8`0b;RD0=30U03Hb9P80=S<T01L0
:bHB03L`7@17?2P0D4@^05E5;P1HA2`0G4H_0659<@1YAS00KD/b07=A=@1gES<0NET`07]L;@1nH2`0
PF<]09]e=`2ONC/0X7U009ig@02PN4D0XGQ:09M^@P0208UO=@0:07Y>9`1kDB/0Me4]06i=;P1QAR/0
F3lY054l:@1>>bX0CSd[04ln;080D3l]00@0Cch/04dl:P1:>BL0B3LU101@@2L20551:080DT8Y00H0
CT@[04m3:`1?@b/0D44Z0551:P1B@2X205<n:@P0Dd4Y0P19?2T204Pk:0<0AcXW01L0ASTV050k:P1?
>RT0C3TX04/j:01:>bP0B3/X04Tl:@19?RX0ACTY04@h:013=bL0@SHV044e9@10=2@0?c<S03hb8P0m
<1l0?C0P03/_7`0h;b00=RhQ03@^8P02034]8P0;034^7`0_;1d0;BTM02`X7@0[9ah0;BPR02hY9@0`
:bL0<BdT030/8`0^:R400P0]:B000`0^:R40<2`S034]900202l[7`80<2`P100a;B400`0f<2@0=BlS
03<]8@03038/800403@^8P0e;b<0=RhQ03H^8@80=BlQ00L0<RlP034_800^;al0;RlO02l[7`0a;B40
<RhR0080=30T00H0<RhR034]8@0_:al0=c4S03Pb900i<bD203Xd9P0803Tc9@0h<R@0=c4S02l]8@0`
;R80=30T03Pb900k=2@203`c8P0A03db8011<B80@S8S04Dd9018=B@0BSPT04hi901A>bH0DS`U04Lg
7@18>1h0BSXP04`l8P1>?R@0CclU05519`1B@RP00`1A@BX20592:`050551:P1??bP0C3`U04/k9015
>R@00`16>bD204Ll9P80B3dW0100@cHS048e8P11=240@C@Q048e8P15>2D0AcXW04Tl:@1DAR<0DT@Q
0511801>?b00Cd0S05529@1DA2X0ETH/1@1HABL02`1IARP0FTLY05]8:P1??RX0Cd0[0552;@1@A2h0
Cd@^04]3;017@BT0AT0X0080ASTX04H0ACTS04Di8@17?200BChN04a27`1>A200G4HQ061:8`1XDBP0
KeL[07IK;01iGB/0NEhY07]M9`1lISL0OFLh07mY>P22K3d0QW1108afA`2ANd`0Tge>08egB02@NT/0
UGm>09^5D`2ORUD0X8]D0:6<E@2PRe80YY1Q0:B>G`2RS5d0X8YK0:6;G02TSUl0Yi5R0:ZDI@2bSd/0
]i9>0;bGD@33W5L0bZ9L0=:XH03GZf80fJeT0<^]K@3:[Vd0bZi_0<N]L034[700`:Y`0;bXK@2kYVd0
^:=R0;NRH`2fXVL0]:1[0;6OK`2_WW80[9ed0:bMMP2VTf/0YiAZ0:fFJP2aVFT0]Y]V0;VJH@2jVUd0
^iUJ0P2lVfH20;^JI@0L0;ZII02iV6<0^9MR0;RGHP2jUFP0_9MZ0;nKJ`31WF/0`9aX0;fJI02iUV00
]Y=K0;R?E`2kTeP0_IEH0;VBD@2eSTT0]8i70;VCB02oVDh0]9=@0;>BC`2eT4`0]8e:0;B9A@2cQ400
/7lj0:mm>0<0[Gi600X0[7m40:Qo@@2TOCX0WWTc09Qf;`2ELb/0S6lc08Q[;`23IR`0OV4Y0P1lGRP0
1P1nH2`0P68^08IV;@2:JS40Sflf09Ad>`80UgLn00H0UWHm09Ad>`2IMSh0Ug@l09Eb>P2CL3P2095^
=P80TVlg01X0Tg0f09Eb>02GMCP0VGLh09aj>P2OOS/0XH0m0::1?02^SUD0[hmD0;6AE02aTU40/I9?
0;2BBP2_TDP0[I140:^8A02YQT@0YhA20:B1@@2SOd40Xgm30:=oA@2TP4H0XX110:>1@P<0YH=400h0
Xh520:1n?`2OOCh0WHHj09n7?@2PR400WhI309Z1@@2AMc`0QF/b07iS;01lIc80NVD`07QS;P80MV4/
00<0Mf8]07QS;P1iI2l00P1nJC@01`1mJ3<0NfHa07YU<01iI2l0N6<^07MR;@1kIS400`1lIc8207eX
<`80OVTd00P0R6`m08M[?026JSX0QFTg08EZ=@27K3D0RFhg08]a>080UWHk0300VWLm09ij@02SO4<0
Z8580:b3B`2_QTh0^X]M0;nDI`39XWL0dk2:0=VkV@3J`J80f<>V0=K2Z@3La:X0f/:X0=JnXP3B^i`0
cKJF0<VbT036[hd0aJn:0<JYO`2oXWH0^Ia`0;>GJ02VRUX0Ug]909EjA@2KP4/0[i=S0;NMK034ZG`0
b[680<bdSP3=]i80cKVH0<nkVP3Ia;<0g<Nf0=o<^`3Sd/00i]O40>OJa`3Yg<T0j=g90>OIc03Xfl/2
0>cLc0130>cMb03Zf/40i]Fi0>?@/P3PcJd0h<RV0=o6Y`3MaZH0flJW0=_8ZP3JbJd0g<^a0=c</P3N
c;@0glfe0>7?]`3SdKT0i]Bl0>SF_P3Zf<00jmW10>GEa@3Ve/H0j=W60>[KaP3Zfl@0jM[30>SJ`03W
fKl0l=[30>kH`03^e[`0k=>e0>W?[P3Xc:L0i/ZS0>G8X03U`9H0gkZ>0=RcQP3D/7h0dJih0<fZLP36
XfT0`ImR0;nLFP2mVUX0^YMG0;FAD`2_Rdl0ZXI<0:J1BP2TOdP0U7Do099c?@2@L3d0S6`k08UY>P25
I3L0Pf8e085P=@1oGCL0OE/e07]I<`1hES00MeD_07ID;P0207ME;`0606m@901_CbH0KdlX06i>9`1^
CRP0KD`Y0P1]C2/0201/CC00Jd`_06Y;;P1XBB`0ITLZ06A5:01R@bH0HD8U0P1XA2X01P1W@bT0IT8X
06E19`1T@2H0HclU068n90P0H4LY00P0GdHX05m49`1M@RD0GT0T06119@1T@RL0Id<Y06Q4:P80HT8Y
00<0HT<W06=49`1SA2D00P1TAR@00`1TAR80K4/Z06a;:P0206a;:P@0JdXY0P1VBBL00`1WBRP0J4/Y
06U<:P0206Y=:`0:06]>;01XAbH0JTTX06a;:P1^CB`0K4/Z06U89`1T@b80HD0O06E6:P80J4T]00P0
ITL[06939`1Q@RH0IDHZ06U:;P1SBbT0ID/Z06I<:`80JD`/00@0Jd`]06i=;P1`CBl0LDh`0P1fD2`3
07A>:P0707E?:`1gDBd0N58^075C;@1_DB/0KDlY06a>:00206]=9`0306a>:01]CbT0LE0]0080L4l/
00D0Kdh[071?;01bDBh0M5<`07IE<P0307QH;`80NET`0`1jFS4207mM<00407mM;`20GS00P5h^085P
;@80PF0[0100O5`S07iM9`20GbT0PV4/089Q;P21Gbl0P5h`07mM;`1nG2h0P5h`089P<P25HcD0R6Hh
08]Y>`2=Jcd0SV`n0P2<J3P308iZ>P0308aX>02:ISH0RFDe0080S6Ph0P2=JCT308iZ>P0608m[>`2;
Ic<0RfLc08aX=02=JCD0SVXf0P2?JcL2091/>003095]>@2DL3`0UW8n00<0Ug<o00T0UW8n09E_@02F
L440V79309UcA02KMDH0WGM809ihB@2ONDX00P2PNd@0102QO4D0XWe60:AoB02UP4T20:J1BP80Xgm;
0P2ROTX0102QODT0X7a80:1lB02ONdL209mjAP80WWU500@0WgY60:5lB02SOTX0Y7m;0P2UP4/00`2V
PD`0Yh9=0:R3CP020:V4C`030:Z5D02]RED0[HUE0080[HUE102/R5@01`2ZQU80ZhMC0:b8E02]RED0
[h]G0;2<F02aSET00P2bSUX20;>?F`040;B@G02eTEd0]I5M0;JBGP80]i=O0P2hTfL00`2iU6P0^YEY
0;^FJP020;bGJ`070;fHK02jV6X0^iU[0;bJK02nW6h0_ie_0<6OL@020<>QL`<0`9i`0P31Wg430<:P
LPP0`Ima0P30WVh20;nMK@<0_Ya/00@0_I][0;bJK02lVV`0_9Y/0P2kVF/50;ZHJPH0^iU[00H0^iMW
0;bHJ02lV6P0_YYZ0;nKJ`30W6`30<6MK@<0`9a/0P2oVf/20;jJJP80`9a/0P2oVf/0202nVVX0_IUY
0;fIJ@2lV6P0`Ia`0<:ML@34Wg<0aZ5e0P37XWH20<JQM@<0aZ5d0P37XWD30<RSMPP0b:Em00<0cJN0
0<jXP@3>Z8400P3>Z8430<nYPPP0bjj60P3<ZGl00`3=ZX00cZ^10<n/PP020=2]P`0<0=6^Q03>[7`0
cZal0<f[O@3=Zgh0cJZ00<fZPP3=ZX@0c:V30=2]Q@3?[8@0cZ^30P3=ZX80103?[8@0dJj60=:_Q`3A
[XH30=:_Q`<0dk280P3D/HT20=:_R@80dk2:0`3D/H/00`3E/X`0dZn90=:_R@060=:_R@060=JcR`3E
/XX0e;690=>`R03B[hL0dJj60P3@[HD20<n/PP<0cZ^10`3=ZX0;0<^XOP80bZMm0`39YW`80<ZWO@03
0<fXN`3>ZG`0cjYm0080cjYm00/0cJQk0<^VN@3:YGP0bjIi0<ZUN038XgH0aj9e0<JQM037XWD0b:=f
0<VTM`080<VTNPP0b:=f0P36XG@40<NRM@80b:=f2034XGL20<>QL`80a:9d00<0aJ=e0<JTMP37YGL0
0P37YGL02@36Y7H0aJ=e0<>QL`32X780`9i`0;nMK`2nW6h0`Ia_0<:ML0020<>NL@0<0<:ML030Vfh0
_YU/0;bGJP2nV7<0_iUb0<6KM032WG<0`Yea0<2KKP2nVVX0_IUY0P2jUV820;^GH`040;bHI02mVFD0
_IUU0;jJIP80]i=O102hU6030;VEH@80]8mJ0P2cSUT40;:=F080/XeI0P2cSUX0102dSe/0]I1L0;JA
G@2fTEd20;6=F`040;6=F@2`SEL0/8eG0;2=E@80/8eC00P0/8]F0:n:E@2^RE@0[HQC0:b7DP2[QU40
ZXE@0:V4C`80ZhQB00@0[8UC0:f:E02^ReD0[haF0P2`SEL50:n;E`<0/8aH0P2bSeD00`2aSU@0/8eC
0:n<DP020:f:D0050:b9C`2^ReD0[haF0;6>F02cT5X00P2dTE/01P2cT5X0/XmI0;2<F02`S5P0[h]G
0:j:EP80[HUE0P2/R5@30:^6DR_ooooo000Zooooo`030:1e?P2QMSl0XgQ10080YGY300@0Y7U20:=h
@@2RMd00YW]80`2WO4T20:QmBP80ZGi;402XOd/80:V0C0<0ZGm=0P2XOT`30:MmB`P0ZGm=0`2XOdT0
0`2YP4X0ZX5;0:Z1B`020:^2C0030:MnBP2VODT0YWe900@0YWe900D0YGa80:5m@@2QOD40XGe30:1k
A0020:1kAP080:1kA`2ONTH0WgU809mjA@2NND@0VgI109Qc?P2FLC`209E`>`0909Ia?02FLCd0UFln
09A^?`2BK3l0T6U008iW@02=ID40S6A10080RVDh0P2;IST0102:ICP0R6<f08IQ=025H3<3089M<`80
PE`b0`20Fc402@1nFc40OEX`07aI<@1jEc40N5@`07IB<01dD2h0Ldl_07E>;@0207=?;@03079@;@1a
D2d0Ke4]0080KU8]201_CR/207IC:`0407MD;01iERh0NUL_07aI<@80OEXb00P0PE/d089M<`23GS@0
QF0d08MR=@29ICD0RVHd08]W=@80SFLh0P2>J3T408mY>PP0SVPi00<0SFLh08iX>@2?JCX00P2@JS/0
1P2?JCX0SVPi08eW>02?JCX0T6Xk099/?@80Tfdn00H0TV`m091Z>`2?JCX0TVLl095V>`2?I3T208iS
>00308mT>@2AIS/0TVLl00P0SfTl202<ISL308eW>P0308iX>`2?JC`0T6Xm0080T6Xm00H0SVXj08mY
>P2?JCX0TFPj099W>P2CIcX209EV>P80SVPi0P2?JCX3091Z>`80TF/l00/0T6/g08mZ=P2>JCD0SFPd
08iY=@2?JSH0TF`h099]>@2?JSH0T6/g099]>@0209=^>P03099]>@2@JcL0SfXf00<0TV`m0P2AJc`3
091Z>`0809Aa>`2CKc/0T6`h08m[>@2>JSX0SVTl08mZ?P2@Jcl808m[>`0509=_>`2BKSX0TVhj095]
>@2?JcL00P2>JSH0102=JCD0TVhj099^>P2BKSX2095]>@<0T6`h00/0RfTi08aZ>P2=Jc/0SV`l08e[
>`2;JCT0RFLg08QV=P2<J3P0SVXj095]?@0209=_?`03095]?@2>JSX0S6Ph00P0SF/m0P2BK3d07P2@
K3`0SF/k08][>P29JcT0R6Xh08IZ>020Jc`0OfXk07eX>@1kISL0NF@e07IQ<P1eH340M5l`06iI:P1]
F2/0JUDZ06I@:@1QBRP0G4DV05Lo8`1E?B<0CD8T04]09015?R80?SXQ03He800_<A`0:RhM02P/6`<0
:2PN0`0W9ad202HV7008020T5@0Q9AL08RHH02<V6`0S9Qd08RDN020R7@0O8A`301/M6P0301`N6`0M
7a`07AlL00807R0M0`0N8AX301lR6`8082<L00<07R0M01`N6`0K7AX00P0I6aP0100J71T06adJ01/M
6P0L7Q/801XL6@807b0K00H0824K028S6`0V:1d0:R`O02h`8`0a<bD203hi9@0?03Pc7`0b;AT0=2lK
03/f8P0h<al0<2/G02DV7P0Q8QX07AhF01hO5`0S91`09RLO02DV7P0S91`092DM00<08b@L0P0R8a/2
024R6P@07AhH100N7aT01@0K7QL071lH01`O600M81T07R4J00807b8K02@082<L020P7P0O7ad07AdK
01`L6P0K6aT071`J01dM6`0N7Q`07AlL024R7@0X:200<BdQ03Xc8@11=R80ACTQ04Pj7`15=BD0BcXX
05I4;01UD340MEdg08AY?P2>LT80UGM50:J4A02`SE<0ZhED08MS?`1J@2L0>RhN02X]900R;bP09RPU
02@V8`0S9B83024S8004028T8@0S9B809RTR02DX8@8092LP00L09BPQ02LZ8`0Y;2D0:RdV02LW7`0X
:200:RXR00<0;2`T0P0Z:R801P0];BD0;2`T02/[8`0Z:R80:BTQ02PX80809bLO00H0:2<O02XU8@0]
:280<BdT03<_900d<2@203@a8P0G034/600j<b00ACdX04i2;01A@BX0DchY05Do:01I@2X0HD4Z06A4
:`1ZBbh0LeDa07iN=@26IcT0RF/i08][>02NMc`0Xga10:AmAP2RNTH0Xg]80:9iB`2FKD400P27GC<0
2P1kCbP0OE<]07]E<@1`Cc00H4DZ05Dm9@1@>bH0CcdY04dl:P1>?B/204ln;00504hm:`1;>RP0BCPV
04Pg9@1??bH00`1@@2L20551:080DT8Y00H0CD<Z04i2:P1>@RX0Cd0Y0510:@1@?RP2058m:0P0Dd4Y
0P19?2T204Pk:0@0AcXW00D0CSTX04lj:@1=>RT0C3/Y04/l:@0204Tl:@0704Ll:014>2P0A3PX04<g
9`12=RH0@CDU040d900203lc8`0603ha800n<B40?30P03T`8@0g;b80=BlS0P0b;R<02`0a;Ql0<2dN
02hZ7P0/:1d0;2PO02dX8P0^:BD0;bXV034]900`;2<0;RXQ0080;BTP00<0;RXQ030/8`0a;B@00P0_
:al2030/80<0<BdQ00@0<RhR03H`900e;b<0<bdQ0P0b;2003P0c;B40=2hR03D_8`0i;b<0>30S03L_
8P0f<280<c0Q038`8@0`<B40;c0P030/800a;B40<blS0P0d<2@01P0c;b<0<BdQ030/800g<B<0>38T
03Tc9@80>S@V01T0>C<U03Pb900g<B<0;bdQ038^8`0d<2@0>C<U03/d900l<b80?S8R03hc8@13<b@0
A3@U04He9@19=RD0BSPT04hi901@>RD0DC/T04Ti7`1:>R00Bc/Q04dm8`1??bD0D40V0080DT8X0P1A
@BX30592:`040551:P1??bP0CCdV04/k90<0Ac/U0P18?2H304Tm9`0804Dh9@14=b@0@cHS048e8P13
=R<0A3LT04Hi9P18>bP204m07`0604ho7P1>?b00Cd0Q0511901A@RD0DT8X0`1KB2X0;`1JAbT0FDHX
05Q59`1GA2H0ET<U0551:P1B@R/0DD8[04m3:`1>A2/0Bd@Z04U2:018@RP0BSd/04Xm:P19?BL0BCdU
04Xo8`1<@B<0CT<S05168`1JAR<0GdTT06A>9`1ZDbT0L5PZ07IL:`1jGR`0Nf0[07aV=`1mIcP0OfTj
089/?@26L440RgE6091jB`2BO4d0SgU:095kBP2EOdh0VXAB09n:E@2RSEH0Y8mF0:F@E`2YTF<0Z91R
00@0YhmQ0P2YTF<0802`SD/0/Xm=0;RCC`2oV5<0aYiH0<jTG03BZ600eJUP0<bYI@3=ZVH0cZeZ0<j_
KP3<[Vh0bZi_0<R/K@34ZVd0`ZEQ0<6VH`31YFH0_jEZ0;jUK`2kY780^ZAe0;ZSM`2bWG80/ia`0;FM
K`2gWFX0^I]U0;RIH02gUeX0^9IG0`2kVf020;ZJG`<0^IUN01P0_IQS0;nJI@31W6D0`imU0<:NHP2o
Vel0_9QJ0;VEE`2iTEH0_9AG0;bDEP2iTU40]Hi90;B>A`2hTTT0_IM<0;>BB`2dTT/0]I190;B>A`2c
RD40/8@m0:io=`2]OCD30:Um@00B0:El?P2QNC/0W7Hg09Eb<P2@KBd0SF/[085S;@1oHBd0NedY07QJ
9P1hFRP0NU//07aM;P1oH340RFT`08a/<`2ALCP0UGDl0P2HN3l01P2FMSd0UGDl09Qe?@2GM3`0UG8j
09=`>080TFhf02d0TVlg09=`>02ELSP0UW<i09Qf>@2KNCX0WG/k0:1o?02RPCh0Xh8m0:b<D@2^SU<0
[hmB0;6BD@2aTTl0/99:0:nAB02^T4L0ZhQ40:V6A02WQ480YH920:=o@@2SOd<0Xgm50:B0AP2PPD40
XH920::3@`2SQ4@0XX=30:21@@2NOcl0WGhn09f5>`2NQS`0X8Q209n6A02IOd80SgDj08AY<P1mHR/0
NfHa07YU<01hHbh00P1fHB`00`1gHRd0N6<^07UT;`0207aW<P80NfHa00@0NVD`07UT;`1hHbh0N6<^
0`1lIc8207eX<`<0OVTd03X0Qf`m08I[?024JST0Q6Xg08A[=@26KCD0R6lg08U`=`2BM3P0U7@i09Ee
>P2JMcd0Wg]10:IoAP2[PTX0[XE=0;V:G02nTfH0b:5f0=>`R03I^iL0f/6R0=W4Y`3G`jP0g<BZ0=[2
Z03G_j<0d[^L0<jgU`3:/i40ak2>0<F_RP36ZGl0_Z5e0;NJKP2aUFH0Y8QH09MkB@2FNdH0WH9=0;2D
I02iWVl0a:Ul0<ZaR03=]Hl0cKJD0<jjV@3A_9d0f/Fd0=g8]`3Oc;/0hm;00>OHa@3Wf/L0jMc90>SM
b@3Xfl/0jMc<0P3/gLX0@@3/flL0jmW10>SD^@3Sd;00hLb]0>38YP3OajD0gLJV0=g6Y`3KaZT0g<R]
0=c;[`3NcK<0hLfd0>;>]@3Td;L0i]:i0>SD^`3Ze[d0k=Ro0>gI`03We/H0j=O50>[Ia`3[f/H0jm_4
0>[J`@3Xf;h0imNm0>[D_03[dkT0j=2d0>G<[@3Rb:D0hLFP0=o2VP3N`IT0gKR<0=RcQ`3@Zgh0c:Qf
0<VUL@34XFT0_IYP0;NDFP2eTE<0/hmA0:n;C`2ZQTX0YH570:5lA@2MN4<0VgI108a/>@2;JcP0RFTh
08EU=P22HC@0Oehc07aK<01kFS40MeL`07IF;`1cDb`0LE4Z00<0KdlX00L0L50Y06Y=8`1ZCBD0JTdU
06Y<9P1YBbL0JD/Y0080J4TZ00T0J4/]06M:;01VBB/0IDPZ06=6:01RABL0HD@V06139@1U@bP00P1T
@RL01@1S@BH0HClT060n8`1P?R<0GcdR00P0G4DV00P0GD@V05a39@1L@B@0GT0T05m0901S@BH0ID<X
06M3:@80H48X00@0H48V06539`1QA2H0HTDU0P1RAB<306Q7:0D0IdHW0P1VBBT306M::P<0J4/[00T0
ITDV06Q7:01[BR/0K4//06]::`1XAbP0ID@U06918P1SABT00P1VB2`0201TARX0H48V06129P1TARX0
J4X^06=;:@1TBRT0ID/Z0P1XBb/0401ZBb`0KD`]06m<;P1`CBl0Ldl[079>:P1aCBT0L4`X075=:@1c
Cb/0ME4]07IB;P1`DR`0KU0Z06a>:01[CBL206Y<9P80K4hX00P0LE0]071?;01_CR/0Kdh[071?;01b
DBh0M5<`07IE<P80MeL^0P1hF2l307UI<00@07YJ<@1nFc40OU`_07mM<01oGBl0P5h^081O;020GbX0
PF0[07eL9P1nGBL0P5lZ089Q;P22H300PEl_081N<080Oed_00T0P5h`089P<P24HS@0QfDg08UW>@2;
JC/0S6Xl08]W=`2<J3P00`2=JCT0102;IcL0RVHf08QT=02;IcL308aX>080SFTi0P2>JSX208]W<`04
08aX=02=JCD0SVXf08iZ=P<0Sf/g00<0TFdi09=_>`2ELCd00`2FLSh01`2ELCd0UW1109Ma@P2HLT<0
VWA509afA`2MMdP00P2ONDX20:1kA0040:5lA@2RODH0Xgi70:AoB080YH190P2ROTX20:5mB@060:1l
B02ONdL0Wg]709mkA`2ONTH0WWU50P2MN4@01@2NNDD0X7]70:9mB@2TOd/0Y7m:0080YH1;00<0YX5<
0:N2C@2XPdh00P2YQ4l50:b8E0<0ZhMC0P2ZQU801@2[Qe<0[HUE0:j:EP2_ReL0/8aH00<0/HeI00<0
/XiJ0;>?F`2dT5`00P2dT5`00`2eTEd0]Y9N0;NBIP020;RCI`030;VDJ02jUFT0^iIZ0080_9M[00H0
^YQZ0;^IJ`2lVV`0_I]]0;jLKP30WW020<6OL@80_ie_0P30WW030<6OL@030<:PLP30WW00`9i`00H0
`9i`0`2oWFd20;jLK0<0_I][0`2kVF/20;ZHJP<0^IMY1@2jV6X30;^IJ`80^iMW00@0_9QX0;fIJ@2n
VVX0_i][1@30W6`20;nKJ`<0_YYZ0`2oVf/00`2nVVX0_IUY0;fIJ@020;bHJ0040;nJKP30Vfl0`Yea
0<BOL`80aJ1d0P34Wg<30<:ML080`iia0`34Wg880<JSN@80bjIl00@0c:Mm0<fXOP3=Z7h0cZUo0P3?
ZX080<^[Q080c:Uo00<0cJZ00<j[P@3?[8800P3@[H<01`3A[X@0cZal0<j/O03>[7h0cZao0<j[P@3=
ZX800P3=ZX@00`3?[8@0cZ^30<fZPP020<fZPP030<n/Q03@[HD0dZn70080dJj60P3B[hL40=>`R004
0=BaR@3C/8X0dk2:0=>`RP80e;6;0`3E/X`80=>`RP80eK::00@0e;690=>`R03B[hL0dJj60P3@[HD2
0<n/PP<0cZ^10`3=ZX0;0<^XOP<0bZMm0P39YW`80<ZWO@030<bWNP3=Z7/0cZUl0080cjYm00H0cJQk
0<^VN@3:YGP0bjIi0<ZUN038XgH20<JQM0030<NRM@38XgH0bJAg00P0bJAj2038XgH40<JQM0@0aj9e
2033X7H01033XG<0a:9d0<BRM034XW@40<FSM@060<JTMP35XgD0a:9d0<>QL`31Wg40`9i`0P2nW6h0
0`2oVVd0`9]^0<6LK`020<:ML00;0<2KKP2nVF`0_IQ[0;jHL@2oVG80`9]a0<6LL031W6l0_i][0;fI
J@2lV6H00`2jUV800`2kUf<0_9QT0;bHI0020;fII@@0]i=O1@2hU6020;B?FP80/hiI0`2bSEP01`2a
S5L0/HaH0;:=F@2bSET0/hiJ0;B?F`2eT5`00P2fTEd00`2bSU`0/HeK0;6=F@020;2=E`030:n<E02_
S580[haB00<0[XUD00<0[HQC0:b7DP2[QU400P2ZQE020:b9D`040:f:E02^ReD0[haF0;2=E`80/HiH
202_ReL01P2bSeD0/HiD0;2=D`2_S580[X]A0:f:D080[8U?00<0[haF0;2=E`2bSeT00`2cT5X01`2a
SUP0/8eG0;2<F02`S5P0[h]G0:j:EP2]RED00P2/R5@0102[Qe<0ZhIB0:^6DP2[QU8[ooooo`00:_oo
ool00`2PMD00XWM20:=h@`030:EjA@030:AiA02SN4<0YW]80080YW]80P2WO4T30:QmBQ00Ygi:202Y
P4`30:UoC@80Z7i<0`2WOD/80:UoC@80Z7m;0`2YP4`30:Z1C@@0Ygi:102XOd/20:9nA00;0:5lA@2Q
O4L0X7]60:1kAP2PNdL0X7Y909miB02PNdH0WWU409]f@@2HLch0102FLC`02P2FL3l0UFln09A^?`2B
K3l0T6Tn08iW?P2=ISd0S6Dn08]V>@2<IcX208eX>`0408aW>P2:ICP0R6<f08IQ=0<0PUdc0P21G383
081K<@80OEX`00L0NeP`07YG<@1hE300MU8`07EA;`1dD300MDh]0080Ldl]00<0LU0]075@;@1_DBd0
0P1^DRd806m>:`0>07EB:P1fDb/0Me@/07QE;@1jEbl0NeP`07aI<@1mFS80PE/d085L<P23GS@0Q5lc
08IQ=028I3@208YV=0<0SFLh0P2>J3T308mY>P<0SFLh0P2>J3T408eW>00:08iX>@2?JCX0T6Xk091Z
>`2?JCX0SVPi08eW>02?JCX0T6Xk095[?080TV`m00H0TF/l091Z>`2?JCX0TVLl095V>`2@ICX208mT
>@03091U>P2AIS/0TVLl00P0SVPk202=IcP02@2;ICP0S6Hi08eW>P2>J3/0SfTl091Z?@2AJch0TV`o
08iZ>P0208mY>P03095X>P2BIcX0TfLj0080UFHj0P2>J3T308mY>P@0T6Xk00<0SVTe08eX=02<Ic<0
0P2<Ic<01P2>JCD0T6/g095/>02?JSH0T6/g099]>@80Tfhj00<0TVdi091[=`2?JSH00`2BK3d2095[
?0<0T6Xk00P0TVli095]>@2?JcL0SVXh08iZ>P2?JSd0TFa0099]@@P0Sf/k0P2BKSX0102AKCT0T6`h
091/>02?JcL208iZ=P<0TFdi0P2@K3P308m[=`0;08]Y>@2<JSX0SF/k08i/?02=Jc/0S6Xj08YX>029
IcL0S6Ph08iZ>P2AKCd00P2BKSh00`2AKCd0SVXj08aX>00808aZ?00P099/?@2AJc`0T6`l08e[>`2;
JcX0RF/i08QZ>026JSP0PF/l081Z>`1nJ3T0O6Hg07YT=@1gHC80MV0a07EO<01`Fb`0KUT/06UD:@1T
CRL0H4TW05a59P1I@BD0F40V04m1901;@2@0AcdR040j8P0h=R40<38M02`_7P0Y;A`202TY7`80:2PN
0`0W9ad02@0V9Q`08BDF028V600S9aT08bHK028U700Q91d0828M01lQ700201/M6P<071hK0`0M7a`3
01hQ6P<07b8K0P0P8a`00`0N81d07AlL01/M6P0301TK60<06adJ200J71T201lP6`0F020Q6`0R8a/0
9BLL02T[7P0];b80<38T03`g8`0n>BD0>SDQ03<^6P0d;a/0>SDQ03Td800a;1P092DM020Q6@0L7AD0
7QlG028S6`0V9al09bPP02DV7P<092DM0P0S91`3028S6`P07QlI100M81T401hQ6P0Z020P7P0O7ad0
7AdK01`L6P0K6aT071`J01dM6`0N7Q`07AlL024R7@0W9al0<2`P03Tb8010=B40A3PP04Pj7`13<b<0
B3LU0590:01RCBh0Le/e08=X?@2?Ld<0UgU70::2A@2_S5@0[8IE08aY@@1RAbX0@c@Q02h^900T;BP0
9RPU02DW900S9B808R@Q024S800R92408bDR02@V8`0V:B809BPQ0P0T9b002@0U:2409bXS02T/9@0Z
;BH0:RXR02/[8`0/;2@0;BdU02h^9P0202d]9@@0;2`T00/0:b/S02XZ8P0Y:B40:2PP02LW7`0Y9200
:RDQ02dX8P0_:b80<2`Q034]8@02034^7`0G03<`7@0k=R<0@c`Y04Tn:P1;?2L0BcTS04dh8`1>>240
GD4[05e1:@1SABT0Ke8`081S>`2<KCl0SFdl08YZ=`2CKSL0VgHo09mjA@2MN4@0W7I509YdA@2>J3/0
0P1oFB`02@1lDBL0PUP`085K=P1dDc80H4DX05<k8`1?>RD0DCl[04/j:00304`k:@0404/j:01:>BL0
B3LU04Lf90<0CclV0P1@@2L30551:00604]1:01<@2P0C40X04dn9`1>?RL0CS`V0P1@>bH805=1:@<0
BC`Y0P18>bP304Lj9`0904`g9P1=>2L0CS/Z04ln;01>?b`0BSdZ04Lj9`15>RH0A3PX0080@cLW00/0
@SHV044e9@10=2@0@3@T03lc8`0o<R40?c8R03da8@0j<B80>C4T03La9@0203@`9@80<BhO00T0;b/O
02hZ7`0]:B00;RTS02hY9@0_:RH0<BdT030/8`0_:b800P0^:R400`0_:b80<2`S034]9003030/8080
<BdQ0`0b;R800`0f<2@0=BlS03<]8@02038/800403<]8@0e;b<0=S0T03da9@80>c4U00<0>C4T03Pb
900e<R<00P0d<R<00`0a;B40<RhR03<_8`0303<_8`05038^8P0a;B40=c4S03Pb900i<bD00P0j=2H0
4`0i<bD0>38T03La8`0a;B80<blT03La9@0j<RD0?C@U03lc8`10<b<0?c8Q04De9P16=RL0B3LW04Xg
9P1;>BD0CSTT04li901@>R<00P1=?B<01P1>?R@0CclU05519`1B@RP0Dd<Y05A4:P80DD4X00L0DT8Y
05=3:P1C@bX0DT8Y05109`1>?RD0CCdT00<0B3`T0P19?BD304Xn9P0304Pk:017>RL0ASTV00<0A3LT
00H0ACPU04Hi9P1;?1d0C3dN04ho801@@B8305528`0?05118P1MBR`0GDX/05i;;@1MBR`0FdPZ05Q5
9`1D@B<0DSlQ05I4;01DA2/0Dd<Z0553:@1?@bT0CT@Y0080C4DY0P1>@R`0801=@BT0CD4W04e29P1>
@bD0Cd@V05159@1JARD0FdLT05m9901TCB@0Je<W07=H:@1iGbh0OF4_07aV=`1mIcP0OVPi085[?025
Kd00RWA508ihB@2ANd`0TWa;09=mC02FP4h0VXE@09n:D`2UT5L0ZIAK0:bHG@2^U6<0[iET0P2`UVD0
902_UF@0[I=R0:^AH02ZT5l0[8Y;0:n<C02bSdl0^99A0;jGE034W5L0bYmJ0<fRG@3>XUT0dJEL0=BZ
HP3F[VP0eZmZ0=>^J03?[6P0c:UU0<fWGP3>Z640cJQR0<bYI`3<ZV/0bj]`0<b/L`3;[7D0`JIg0<6W
MP31YG<0`:9/0;fNI@2jVUd0]YMG0;FCD`80_9]H1P2kVUL02@2nVe/0`9eK0<:OG@33X5`0`j5J0<6O
E`2nW580_9Y@0;ZBE@020;^CE@0>0;VBD@2eST/0]8e80;J@B@2hTT/0]9120;>?@@2dSd40/X/n0;67
>`2^PSL0ZWhc0:Yl<@2RNCL209mh=@0709ad=P2GLC<0T6`b08UV<023HRd0PF0]07YK;`0307UJ;P08
07aM<@1oH3@0Pf@h08EV>P2=KC@0T70g09Ad>`2GMch209Ui@00809Mg?P2FMSd0V7Dm09Ic>`2DLCT0
TVlg095^=P2BKcL209=`>00>09Md>P2HMC/0VWPk09aj>`2OOCd0XX4n0:B3@02UQ3l0ZXY=0:^;CP2]
STh0[i1?0;2ACP2_TD/20:j@B00:0:^8A02YQT@0YhA20:B1@@2SOd40Xgm30:=oA@2TP4H0Wh100:21
@@<0XH9200l0X85109io?`2MOSh0W8@j09j6?P2PR480WHA209Il?`2<LST0PfPa07eR;@1jIC00NF@_
07QS;P1gHRd00P1fHB`00`1gHRd0N6<^07UT;`0707UT;`0407aW<P1mJ3<0OFPc07eX<`80OVTd0P1o
JSD02025JS/0Q6Tj08AZ>@23JCH0Q6/e08E/=026KCD0Qfhe0P2>KcH0<02@L3L0UG8j09Yg?`2QO4D0
Z85:0:^4C@2gREP0_I=S0<NQM03B[hL0fK^G0=_3X@3JaJH0fLFZ0=_3Z@3I`JL0eknS0=>lW@3?^9P0
bkBB0<N`SP35[hX0aJQn0;fPM02eV6`0[Y9S0::6EP2FNTP0Uga70:25D02cUfP0^j1c0<J[P03</h/0
c[JB0<nhUP3@^i`0dkjO0=c7]P3Ob[T0hLjm0>GD`P3Wf<D0j=_80>WLb@3XgLT0jm_<0>_Kb`80kMc:
01D0kM_50>[I_`3We;H0i<n`0>7=[03PaZ<0glFT0=g5X`3LaJD0flJW0=c9Z`3NbZl0g/fa0>;>]@3S
ckH0i=2g0>KB^@3Xe;/0j]Jm0>_G_P3/f;l00P3Yel<0:P3Zf<80jmW10>[I_`3Yf;`0imJj0>GD]P3T
c;80hl^_0>78ZP3M`j80fknJ0=RkT`3G]hh0eKJ:0=>^P@3=Z7/0aJ5a0<2LJP2lV6@0]iAN0;2=E@2Z
Qdl0YH980:>0AP2PODD0VgQ209Ic?@2BKSX0Sf/i08eY=`22I380PF<a07iO<01kG2h0N5T]07EE;01b
DR/0LE4Z06e?:`1[CBT0JD/W06M99@<0IDLS00L0ITPT06E98P1TB240I4PS06A79@1SAR@0HdHV0080
HTDW0P1SABT20694:080HD<W0P1P@RH205hn9@80GCdT00@0G3`S05/k8P1J>R40FSXQ201H@2@0201J
@RH0FD4U05To901J?b@0GClU05lo9P1R@2L0Hd4X0P1N@2P00`1N@2H0Gd4U05m2900206138`030613
8@1Q@R<0HD8S00H0HD8S0`1VBBT306E8:080I4LW00<0HD8S06=49@1VAbP00P1WB2T01`1UARL0Hd@U
06528`1RA2P0I4HZ06E7:`1RA2P00P1O@BD00`1SABT0IdT]069::00206A::@80IdXZ00@0JDX[06a;
;01]BR`0KT/]0P1_BbT206i::00=071<:P1bCR`0M50^07IB<01]Cb/0K4hZ06Y<:01YBbL0J4XV06U;
9`1ZC2P0JddY071?;00206m>:`0506i=:P1_CR/0LE0]07=B;`1eE3400`1fERd207MG;P<0N5P_00H0
OEXb07eJ<01mFS00OU`_07iL;P1oGBd207mN:`0C07iM9`1nGBP0P5lZ085P;@22H300PEla085O<P20
GS40P5h`085O<@22H380Pf4c08ES=@26I3H0QfDg08QV>029ICD0RVHf08]W=`0208aX>00308YV=P28
I3@0Qf<c0080RVHf0`2;IcL308aX>080RVHb00<0RfLc08aX=02=JCD00P2>JSH208m[=`03091/>02B
KSX0U70l0080UG4m00X0U70l09=_>`2FL440Ug5209Qb@`2JM4D0W7I709ihB@2ONDX0X7Y;0P2ONTD0
0`2PNdH0XGa70:9mB0020:=nB@040:AoBP2ONdL0Wg]709mkA`<0WWY60P2MNDD0202NNDD0WGQ409ag
@`2LMd<0WGQ409mjAP2QO4P0Xgi:0P2SOTT00`2TOdX0YH1;0:J1C0020:N2C@030:R3CP2ZQU80ZXIB
00H0ZXIB0P2YQE401`2ZQU80[8QD0:f9E@2^RUH0[h]G0;2<F02^RUH00P2_ReL0102`S5P0/HeI0;6=
F@2bSUX20;>?F`80]Y5T00<0]i9U0;RCIP2iU6L00P2jUFP0102kUVT0^YQZ0;^IJ`2kVF/20;bJK0<0
_I]]0`2nW6h20;nMK`<0`9i`202oWFl20;jLK080_I][0P2lVVX20;^IJ@80^YQZ0`2iUfT50;RFJ080
^IMY0`2jV6X01`2kVF/0^YIV0;^GI`2kUfL0_9QX0;fIJ@2nVVX01@2oVf/20;jJJP<0_IUY0`2nVVX3
0;fIJ@80_9QX00D0_9MZ0;fHJ`30Vfh0`Ye`0<>NL@020<:ML0040<6LK`2nVF`0_YU/0;jIK080_iY]
0`30Vfh80<>PMP080<NRN038XgT0bJAj0<ZUN`3;YW`0c:Mm0<fXOP3>ZGl80<VYP0060<^XOP3<ZGl0
c:Uo0<fZP03>Zh40cjb20P3@[H<20<j/O0040<j/OP3>[7l0cZ^10<j[P`80cZ^50P3>Zh<30<bYP@04
0<j[P`3@[HD0dJj60=2]Q@<0dJj60`3B[hL20=>`R080dk2:0P3D/H/30=FbS0030=JcS@3D/H/0e;6;
00H0e;6;0P3D/HT20=>`R0040=:_Q`3A[XH0d:f50=2]Q@80cjb20`3>Zh430<fZP0P0bjQn0P3<ZGl2
0<^XOP<0bZMm2@39YW`02`3<YgX0cJQk0<jYO03?ZWd0cZUl0<fXN`3;YWT0bZEh0<^VN@39Y7L0b:=f
00<0aZ5d00<0aj9e0<RSMP38XgT01`38XgT80<NRM@P0aZ5d2033X7H40<BRM0<0`j5c00l0`Z1b0<BR
M034XW@0`j5c0<:PLP30WW00_ie_0;jLKP2mVfd0_IQ[0;jIK02oVVd0`9]^0<6LK`30Vfh00P2oVVd0
202nV740_YU_0;nJL02oVVh0_iY]0;jJJP2lV6H0^iMU102jUV820;^GH`80_9QT2@2gTel30;>>F@80
/XeH0`2aS5L20;6<F0030;:=F@2cSUX0]8mK0080]I1L00T0]Y5M0;>?G@2bSU`0/HeI0;2=E`2_S5H0
[HYB0:f:D02/RDl0202/Qe820:j;E@040:n<EP2`SEL0/8eG0;6>F080/XmI202_ReL20;2=E@80[haD
00d0[X]C0:f:DP2/RE40[8UA0;2=E`2aSUP0/XmI0;>@FP2bSeT0/HiH0:n<EP2^ReD0/8aH0080[h]G
00<0[XYF0:f9E@2/R5@00P2[Qe<30:b7Db_ooooo000Zooooo`080:5f@`2RMd@0Y7U60:EjA`2VNdP0
YGY70:AiAP2SN4D30:IkB0<0Yga90P2XODX@0:MnBPP0Z7m;0`2YOdd20:QnC0<0Yge;3P2YOdd20:Z0
CP80Ygi:0P2XOd/20:V0C080ZX5=00@0XWi40:9mAP2RODP0XGa70P2QO4P0202PNTT0X7Y;0:1jB`2P
NdH0WWU409ag@P2IM3l0Ug8m0`2FLC`02P2EKch0U6hm09=]?P2BK3d0T6Xk08mY?02>J3/0SFLj08aW
>P2=J3/208iY?00408eX>`2;IST0RF@g08MR=@<0PUdc0P21G383081K<@0907eJ<01lFBl0NeP`07YG
<@1hE300MU8`07EA;`1eDC40MTl^0080M50^00<0Le4^079A;P1`DRh00P1_Dbh806m>:`0@07AA:@1e
DRX0MU<[07MD;01iERh0NUL_07]H<01lFC40P5Xc085L<P22GC<0Q5lc08IQ=028I3@0RFDc08YV=080
S6Hg0P2=IcP208iX>@80SfTj00<0RfDf08aV=`2=IcP00P2>J3T00`2=IcP0S6Hg08]U=P0208iX>@@0
SfTj0P2>J3T8091Z>`03091W>`2?ISX0SfHj00@0SfHj00<0T6Lk08eW>P2=IcX01P2=IcX808eW>080
RfDh00@0S6Hi08iX>`2?JC`0TF/n0P2BK3l01P2?Jc/0T6Xk091Z>`2BJC/0TfPk09AX>`80UVLk0P2>
J3T708mY>P0308eX=02<Ic<0RfHb0080RfHb00H0SFPd08iY=@2@JcL0SfXf091[=`2BKCT209=^>P03
099]>@2@JcL0SfXf00<0TV`m0P2AJc`3091Z>`08095^>02@K3P0Sf/g08iZ>02>JSX0T6/n099]@@2C
KT8808m[>`03099^>P2AKCT0TFdi0080T6`h0P2?JcL0102>JSH0T6`j091/>P2@K3X308m[>@80SVXh
00<0RVPh08]Y>@2<JSX00P2=Jc/01P2<JSX0RVPh08UW=`2=JCT0SVXj091/?080TFdm00<0T6`l08iZ
>P2=JCT0202<JS`2095[?00308m[>`2<JSX0RVXi0080R6Xh01T0QFTg089Z?021JC/0OfLi07eU=`1k
HcD0N60b07MO<@1fGS00LUd^06mJ;@1YE2T0HddV05m89P1LABH0G4@X05a4:P1@@B@0CT0U04Pl8P11
>B80>cHR03@c7`0^;al0;2lN00<0:BTO0P0X:1h302LW7@0602<W600S9aT08bLI028U6P0Q91/082<L
0P0O8A`601`N6`807AlL0`0N8AX301lR6`8082<L00@07b4N01dO700K7AX06Q`I0P0I6aP201XL6@03
01/M6P0J71T06Q`I00H06Q`I0P0O81/02@0P8A/08R<K02DW700Y:ah0;2hQ02h`8P0k=R80?STU03/f
8P0203@_6`0903Td800j=B40=2lK02@U7@0P8AT071dE01dN5P0R8a/09RLO00809bPP0`0T9Ad302<T
70808R<K0`0O81X401hO6@0301dN600O8Q/07R4J00807R4J0`0M81T0:`0L7aP0820N01lO7@0M7A/0
71`J01/K6@0L71X07AdK01hN700M7a`0824L02HV7P0^:Qh0=c0N03ld8014>200B3XO044a8@16=B<0
CcdU05i9:P1_Ec40PFHk08ib@P2GNDL0WGi70:f:E02^RED0UG1306i@;P1=>bD0=c4U02T[9P0W:BH0
9BLT02<U8P0R92408B<P028T8@0S9B8092HS02HY8P0U:2400P0T9b00100U:2409bXS02T/9@0Z;BH2
02`/900302d]9@0^;RH0;RhV00<0;RhV0P0[:b<302`/900902XZ8P0Y:B40:2PP02XU8@0[9R80;2LQ
02dY800^:Ql0;b/O0080;b`M0180<S4O03Hc8P0m=R@0@CTV04Dh9@18=b<0B3HP04Xe801LARl0FT8Z
05a29`1YCbh0O5hh08IW>`23Hc@0OE/[081L:02:IS@3099^?00<095]?@27Hc<0NUHV07YF9P1oE2T0
QU`b08IP>@1hEc@0HDHX058j801?>b<0DT0Z101:>BL01019>2H0B3LU04Lf9017=R@304lo9P<0D40W
0P1A@BP0201:@2L0BclW04Xn9P1<?BH0C3`U04dk9@1?>RD0CSTT201C@BT204Xm:P80BC`Y0P18>bP2
04Lj9`0804Xe901=>2L0Cc`[0550;P1@@Bh0Bch[04Lj9`13>2@204<g9`80@SHV0P11=BD2040d9006
040c8P10<b<0?S8R03`c900j<RD0>38V0P0e<BH2038_8004034]8@0`;240;b/R02hY8`80;RTU200`
;2<2030/80<0<BdQ0`0b;R8203D_8`<0<bdQ00<0=2hR03H`900g<BD00P0o<bL0100m<bL0?38V03/c
9P0i<bD203Ld9@80<RhR100c;b<2038^8P0303La8`0h<R@0>C<U0080>S@V00P0>C<U03Pb900g<B<0
=2dS03D^900i<BH0?38V040d9P80@C@T00T0@S8R04Ph:@18>2T0BCPX04/h9`1;>BD0CSTT04li901?
>B800P1@@2H0101A@BL0DT8X0592:01C@bT205A4:P80DD4W00P0DT8X05=3:@1DA2X0Dd<Y05519`1?
?bD0CShT04/m8`<0C3hT0P1=?bD204i09P80BSdZ00@0B3/X04Lj9`16>BH0ACPU0P14=b@0601;>b40
CChQ05529@1DABH0ETLX05E69@1DAB@0Dd@S05Y7:@1LBB/0GT/]05m<;P1NBbd0FdPZ05M49P1E@R@0
FdL/05Q7:`1GARX0E4DX05=5:01AARP0DDPY0599:P80D4@/00<0Cd<Y04i2:01=@BL00`1<@BD0401G
A2H0Ed@T05U5901NB2<0IDhU06iF:P1eGBl0O64b07]U=P1lISL0OFLh081Z>`24KSl0RG=408egB02@
NT/209EoC@0^09N2C@2JQDh0X8]B0:NCF02]VEh0/IeP0;6HHP2cVV@0]YeW0;NNJ02eW6H0/IQR0:bC
G@2YT5X0Z8Q;0:^9C02/RT/0/8e=0;J@C`2lUE@0`IQF0<>KEP3?Vdl0d9mB0=FTF03GYed0ejQP0=:V
G@3=Xe/0bZ1H0=:REP3CXeT0djAL0=>WH03DZF@0e:aW0=F^J`3E[Vd0bJYd0<VZL`38Z6l0aZI[0<6Q
I02nW5`0^YUF0;NFD`80^iUA102jV5020;VGC`080;nKD@31WE<0`YiB0<BPDP33X4l0`Ym=0<2MB`2o
W4P20;VBD@040;RAD02fSd`0/ha90;6:A`80/HY500T0[hXi0:n:>P2_R3T0[HHi0:V2=@2WOC<0XgT_
0:5g;`2HLbd00P2FLBd06@2?K2`0RFH/089Q;01mGBh0NUT`07QH<@1lFcP0OE`i07mO>@23Hcd0QfM0
08a/@`2?KdH0TW99099b>@2DM3/0UWHm09Ui@02JNT40VGU009Qh?`2GMch0Ug@l09Ic>`2DLCT00`2B
KcL03P2CL3P0U74i09Qe>`2IMS`0VgTl09il?@2QOcl0Xh8o0:F4@@2WQT40YhQ70:V:B@2[S4/0[Hi=
0P2^Sd`20:f>B`060:Z7@`2XQD<0YX=10:>0@02ROT00XGe10P2ROT@609j0@080WGlo00T0VX8j09f5
?`2OQT<0W8=3099h?@28KCH0P6D`07eQ;`1iI2l00P1hHbh207MR;@<0MV4/0`1gHRd307QS;P80NF@_
0P1lIc8207eX<`@0OVTd0P21JCT01P21JSP0PFXf085Z=022K3<0Pfdd08=]<`80R6/c0300RV/d08i]
=`2DLC/0VgQ20:9mB02XP4`0]8ID0;Z@GP35Wg00dJj40=RjU03K`il0f/FV0=[7Z@3J`ZP0fL6W0=No
X`3D_Ih0d;VI0<beT`38/Hl0a[2;0<FXOP2kWW80/YEY0:Z>G`2OPe<0UWY809UnB@2SR5<0]YU]0;fR
M@38[8@0cK>>0<ngT`3A^YX0dkjQ0=K1Y03Ob[T0hLbk0>?@_`3VeL<0j=W60>SKb03Yg<T0j=g90>_K
b`3/flT20>gKa`0>0>_I`@3Ze[/0i]6b0>C=[@3RbjT0hLFP0>33X@3M`j00gLFS0=g6YP3Mb:T0h<^^
0>3=[`3Tck@20>G@]@030>OB]`3XdkP0jMBi0080j]Fj02`0j]Bo0>_E_P3[eKd0jmFm0>[E^P3Wd[D0
iM2a0>?>[`3OaZP0gLBU0=[0W`3G^iH0dkJ>0=2aQ@3<[Gl0bj]l0<RTLP32WV`0^YIT0;FAG`2aSET0
[8QD0:B0C02NNdD0UG@n09Ac?P2AL3/0SF`i08UW=`25HcD0PV0c081N<@1iGBh0N5`]07EH;01cER`0
L5<[06e?:@1[CBL0JD/W06E;:01SBBH0HDLT05m58P<0GD<P00L0GT@Q05a47P1LA200G4@P05]38@1K
@R<0FT4S0080FT0U0P1K@2D505a19P0405e29`1G>b<0ESXR05Hj8P80ECTQ0P1D>2000`1C=al0DSdR
058m8P06058m8P0805@o901F?R@0EShT05Lm901I?BD0FcdU05dm9P1N?RL205Tm9`0305Tm9@1J?b@0
FSlR0080Fd0R00<0Fd4P05i18`1N@B<00`1O@R@306139@0506E8:P1TAbT0I4LY06=6:01RABL00P1Q
A2H0101P@bD0GT4S05m2901QA2H206=6:00706959`1QA2H0H4<U05e29@1OA2L0HDHY05m49`0205]0
8`050615:01TBB`0HDTW06989`1SBBP00P1UB2P01@1WB2T0JTTZ06]8:P1[B2X0K4TY00<0JdPX00L0
KDXZ06m<;01bCbl0Le0`06Y<:P1YBbT0J4XX0080ITPV00@0IdTW06U;:@1ZC2X0Kdh[0P1^CBX01@1]
C2T0KTdZ071?;01cDRl0M5<`0080M5@[0`1eEB`307IF;@80NeP`0P1lFBl02P1lFRd0OE/]07eK:`1m
Fb/0OUdX07iM:P1oGR/0Oed]081N<020GS42081M<`<0PEla00<0PV0b08=Q<`23HC<00P24HS@00`28
I3@0RFDe08YV=P0208YV=P0308QT=026HS80QF4a0080R6@d0P29ICD308YV=P0708]W=`29IC40RFDa
08YV<P2;Ic<0S6Pd08eY=@0308iZ=P0308m[=`2AKCT0TVhj0080Tflk00X0TVhj095]>@2EKd00UW11
09Ma@P2ILd@0VgE609egB02NN4T0WgU:0P2MN4@209iiA@0409mjAP2PNdL0X7]70:1kA`@0W7Q4102K
Md<209ag@`80VgI200@0W7M309iiA@2PNdL0XGa80P2QO4L0102RODP0Xgi90:AoBP2UP4/20:J1C0<0
Yh=?102XQ5002@2YQE40Yh=?0:R4D02YQE40ZXIB0:b8E02]RED0[XYF0:n;E`020:b8E0040:f9E@2^
RUH0[h]G0:n;E`80/8aH00L0/HeI0;B@H02dT600]I5Q0;JBHP2gTf<0^9AT0080^IEU202jV6X20;bJ
K0<0_I]]0`2nW6h80;fKK@80_9YZ0P2kVFT40;ZHJ0<0^9IX0P2gUFL50;JDIP040;NEI`2hUVP0^9IX
0;VGJ@80^YQZ0`2jUVH00`2kUfL0_9QX0;bHJ0020;fIJ@040;jJJP2mVFT0_IUY0;fIJ@80_9QX0P2k
UfL20;fIJ@H0_9QX00@0^IEU0;^GI`2mVFT0_i][0P30W6`00`2oVf/0_YYZ0;fHJ`030;jIK080_iY]
0P30Vfh80;nML080a9mc00@0aJ1d0<NRMP38XgL0bZEi0P3;YWX80<NVN`80bZMm00@0bjQn0<bYO`3<
ZGl0cJZ00P3>Zh420<f[N`090<f[O@3>[7l0cZ^10<j[P`3>ZhD0cjb60<j[P`3=ZX80c:V10080bjR0
00<0cJZ20<n/Q03@[HD0103@[HD30=6^QP80dZn70`3C/8X20=BaR`/0eK:<0`3C/8P00`3B[hL0dJj6
0=6^QP020=2]Q@80cjb20`3>Zh430<fZP0P0bjQn0`3<ZGl20<^XOP<0bZMm2039YW`00`3<YgX0cJQk
0<jYO0020<jYO00;0<bWNP3:YGP0bJAg0<ZUN039Y7L0aj9e0<JQM035X7<0aZ5d0<NRM@38XgH02037
XWP:0<JQM0@0aJ1c0P34Wg880<:OM@80a:9d00@0`j5c0<:PLP32X780`Ima0P30WW020<:PLP040<6O
L@30WW00_ie_0;jLKP80_I]]00@0^iIY0;bGJP2mV6/0_YU/0`2oVVd02@30Vfh0_YU_0;jIK@2nVFd0
_IQ[0;fIJ@2lV6H0^iMS0;ZFHP030;VEH@D0^YIR0P2gTel40;JBGP<0]I5M0P2cSUT30;:=F0<0/HaG
0P2aS5P0102bSET0/hiJ0;>>FP2dSe/20;F@G0090;>?G@2bSU`0/HeI0:n<EP2^ReD0[8UA0:^8CP2Z
Qdd0ZXE@00<0ZhIA0`2/Qe801@2]R5<0[haF0:n<EP2`SEL0/HiH0080/XmI0P2cT5X30:n;E`@0[XYF
00<0[HUE0:n<EP2_S5H00P2^ReD01P2]RU@0[8UC0:b9D`2/RE<0/8eG0;6>F080/XmI00@0/HiH0:n<
EP2]RU@0[8UC0P2_ReL0102^RUH0[HUE0:f9E@2/R5@20:^7D`<0ZhIB:oooool002[ooooo00<0XGI3
0:9gA02TNDH00`2VNdP0102UNTL0Y7U60:EjA`2UNTL30:IkB0<0Yga9402WOTX80:QoB`<0ZGm=0P2X
OT`30:MmB`P0ZGm=0P2ZP5060:UoC`@0Z7m;102YP4`0102SOTL0Xgi90:9mB02RODT20:5kBP070:5k
C02PNTd0X7Y=0:5lA`2ONTD0W7M209Ud?`0409Mb?@80U6ho00P0Tfdn099/>`2@JST0SfTh08iX=`2>
JCD0S6Lj08eX>`80SVTl00@0SFPk08]V>@29I3L0Qf8e0`22GC<2085L<P<0P5/a0P1lFBl01`1kF300
NEH`07QD<01gDc40MU8`07EA<@1fCbh00P1dD2h00`1cDBh0LU4^071B;P0206mC;PP0Kdh[00h0Le0X
07AA:@1eDRX0MU<[07QE;@1iERh0NUL_07]H<020FS<0P5/a089M<`24Gc<0QF0c08MS<`80RFDc0`2<
ISL208eW>0<0SVPi00<0RfDf08aV=`2>J3T00P2?JCX00`2>J3T0S6Hg08]U=P0208mY>P@0SVPi0P2?
JCX2091Z>`@0SfTj0P2@JS/308eW>P80SVPk2`2=IcX808iX>@0908]U>02<IST0SFLj08iX>`2?JC`0
T6Xm095[?P2BK3l0Sf/k0080T6Xk00<0TVTk09=X>`2DJ3/00P2FIc/208mY>PL0SVPi00<0SFPd08aW
<`2;IS800P2;IS801P2=J3@0SVTe091[=`2?JSH0T6/g099]>@80Tfhj00<0TVdi091[=`2?JSH00`2B
K3d2095[?0<0T6Xk00P0TFhh091/>02?JcL0SVXh08iZ>P2@Jch0TVe109=^@PP0Sf/k0P2AKCT4091/
>080Sf/g102?Jc/208iZ>P80SFTi00<0RFLg08YX>02<JSX00P2=Jc/01P2<JSX0RfTi08YX>02=JCT0
SVXj08m[>`80T6`l00<0Sf/k08iZ>P2=JCT0202;JC/0802AJc`0T6Xk08m[>`2<JSX0RVXi08QZ>027
JCL0QFTg08AY?023J3/0PFHi07mT=`1mHSD0NUlb07UN<@1hGC00LUd^06mJ;@1ZEBX0I4hW06199`1N
AbP0GDDY05e5:`1B@BD0CclU04/m8`14>B<0?CHS03Hc800b<240;RlO0P0Z:R0202TY7`80:2PN0P0W
9ad01P0U:AX092PJ02<W6@0Q91T082<J01lR6`807b4L0P0M7a`601`N6`<07R4J0`0O8Q/2020S7004
020R7`0N81d071hK01XL6@@06A/H2@0J71T201lP6`0@020Q6`0Q8QX092HK02PZ7@0[;B00;BlQ03Td
800n>BD0?CPT03D`700c;QX0>C@P03Xe8@0f<Ad09RLO024R6P8071dE00@08B8J02DV7P0W:2009bPP
0P0U9Qh302@U7@<08b@L0`0P8A/00`0O81X07QlI01hO6@0201dN600401lR6`0N8AX07R4J01hQ6P<0
7B0I02@071lH020P7P0O7ad07AdK01`L6P0K6aT071`J01dM6`0N7Q`07AlL020Q700T91`0;2PL03D^
700n<al0@cLO04Pj7`10<200A3<Q04`j8P1IA2D0Je<]07iS>02=LD40UgU709UkB@2YR5<0/HaG09ah
AP1kFc80FD@Y03dc9`0/:B@09bTV02HX9@0T9R<2028T8@0502<U8P0T9R<09BLT02HY8P0U:2400P0T
9b00100U:2409bXS02T/9@0Z;BH402d]9@0702h^9P0_;bL0;blW030`:00Z:R80:b/S02`/900202d]
9@0302/[8`0Y:B40:2PP0080:bHR00@0;2LQ02`X7`0]:Ah0;b/O0P0`;Ah01P0_;Ah0<2hO03D_7`0j
<b40@CHT04Lh9@80BSPT00l0D40Y04hl901B?B80HTTZ07EI=01oGcH0O5X]07IA901cCR40P5/^08YU
>02=JCT0Sf/k095]?@2;IcD00P22GR`02@24FB`0RF0d08MR>01iFC<0I4XY05Hn8P1A?B@0Dd4Y04Xi
9`0204Th9PD0B3LU0P1>?RD304lo9P<0D40W00H0BClV04Xn9P1:?RH0Bc`U04`l9@1=>bD204hi90P0
Dd4Y0`1:?BX204Tl:@<0B3/X00P0BSDT04dh9`1??2/0DD0^0511;P1;?R/0AcXW04<h90@0@SHV1011
=BD01P10<b80@3<S03hb8P0l<b@0>S8U03Pb9P80=C4V0P0c<2401P0c;b<0<RhS034]900_:R@0;RTU
02dX9080<2`S100a;B@2030/8`<0<BdQ0`0b;R8203<_8`0803D_8`0d;R80<bdQ03<]8@0d;R80=BlS
03La9@0h<RH2044c:00403lc9`0m<bL0?3@W03/c9P80>S@V200c;b<00`0g<B<0>38T03Tc9@0203Xd
9P0803Tc9@0h<R@0=c4S03H]900g;RD0>c4W03lc9`12=2L204@d9@0904@c8`19>BX0BCTZ04Xi:@1<
>BP0C3XV04lj9@1@>RD0D3XS00P0Dd<Y0P1A@RD01`1B@bH0E4DX05A5:01DABP0Dd@W05529@1@@B@0
0`1>?R@204lo9@<0D40V01h0C3l/04/n:`1;?R/0BC`Y04Pk:016>BH0ACPU04@g901=?B@0D40W05A4
:P1HBB`0FT/Z05Y<:@1IBbH0F4XU05I39@1HABL0FdPZ05i;;@1OC2h0GT/]05e:;01LBB/0H4//05i;
:`1KBbX0FTXY05U::@1HBbT205I<:@80DDHZ03h0D4DY04i2:01<@2H0BShT04Pl9017>b<0E4<Y05=2
9P1D@B<0F4@S05m9901XDBP0LEX`07MO<`1iHc@0NV@e07aV=`1oJCX0Q6ho08UcA02>N4T0TG]<09J1
C02GPTd0V8=<09b7CP2QSE80Z9AI0:nKGP2cWf00]9YQ0;JLH`2iWfH0^Z1W0;RNI@2cVF00[I=J0:Z@
E`2WR4l0Z8Q?0:Z7C@2[RD`0[h]=0;F?D02jTU@0_9ED0<bGB`3=VDd0d9aA0<nME03=WED0b9UA0<6E
CP2nTT/0cYY?0<fLD03>W5<0d:1F0=:SF`3BYUd0djUQ0=BZHP80bjEW00L0bJIV0<RUI@35XV00`J1M
0;jMF02lVeH0^iI?0080^YE>01D0^IA=0;RCC02gTT/0]i9;0;JABP2lUdT0_IQ:0;jIB@2oVTT0_i]7
0;nKA@2nVT@0_IU10;J?BP2eSTT0/X]80;29AP2^Qd@0[8E40:V2@@2WP3l00P2XOS801`2WOC<0Xg/c
0:1h<`2KLS00Ug0_09A];02<JRX00P29IbP04@23HbP0OEhX07UJ:`1eF2h0MELa07EH=P1nGC`0PF0m
08EU?`2:JT<0Sfm609=dAP2FMdT0UgQ909If?@2GMch0V7Po0080VGU000H0V7Po09Mg?P2GMch0UW<k
09Eb>P2CL3P2099_=`0?09=`>02DLCT0UG8j09Qe>`2JMcd0W7Xm09il?@2QOcl0Y8=00:J5@P2WQT40
YXM40:N8A@2YRTL0Zha90080[8e<00P0Zha;0:Z;BP2WQ400YX=10:>0?P2QOSh0Wg/m09mk?`80X7a2
0P2LP3l309]o?P80W80o00T0WH5009R0>P2MQ440WhI409Z0@`2?MC`0Q6Td07iR<01lH3000`1hHbh2
07MR;@80MV4/0`1eH2/307IQ;0<0Mf8]0`1kIS4207aW<P<0OFPc00D0OFLf07iX=`1oJCL0OfXe081[
=002081[<P0^081/<@22J2l0PVP_08AW;`26Ic00S6/e09Eb?02KN480X7]60:n1C@2eS5P0`I]Z0<j/
O`3G^Y80f/:N0=[6Y@3IaZH0fL6W0=S0YP3H`:@0e[nP0=:kV`3=]Y@0bK:@0<J`R`34Ygd0^Ia`0:nB
IP2VRU/0W81@09EiA`2KP4/0YhaG0;VLLP30YGX0bZj70<neTP3A^IL0dkbM0=G0Y@3Ia:T0h/fl0>C?
_P3Vdl80j=O50>[Kb080jMc900<0j=g90>_Jb03/f/H00P3Zf<803@3Ze[d0im:e0>G>[P3SbjT0h<RT
0>32W03P`Yh0g/6O0=g3X03NaZ@0glRX0>;;[03Qc:d00`3Vc[800`3Wck<0j=2d0>S@]0020>WA]@0/
0>[@^@3Zd;L0j]2g0>W?]03VcJl0hlZ[0>38YP3NaZ@0f/2O0=RnV`3F^YD0dKB<0<f^PP38YgX0`j=b
0<:QKP2mVV@0]i=O0;2<F02[Qe<0Yh=A0:9nC02KMdD0UG4o08YZ>@29JCX0QVHg08=R=@20Gc@0O5/b
07YH<P1hES00LeP]079G;01`E2`0KU8[06]?:P1XBbT0IdXX06E8:01QBRX0GdPX05e69P1J@b<405U2
8P0605A07@1D@1l0E40O05<n7`1C?R40DSdR0P1B?2@305Hl8`80EcdT0`1H?RD4050h80@0CcLO201>
>R401P1?>b80DC/S058l901D?2@0ES`U05Lk9@80FCXU0P1E>RD00`1F?2D0ES`S05Lm8P0205Ln8005
05Po801M@RD0GD8U05e29@1N@bH00P1OA2L20615:0050694:01Q@bL0HD<W06129P1O@BD00P1N@2@0
101M?b<0FSlR05]08`1L@B@305i39P0605e29@1L@B@0FD0R05a39@1MA2H0Fd8T0P1I@2800`1MA2H0
HTT[06189P0206579P80I4LW00D0IDHW06M69`1XABL0JDHX06U89`0306Q79P0706U89`1[BRT0KTd/
06m>;@1WBBL0ITPV06E79@0206A6900406E79@1WBBL0J4XX06i=:P@0KD`Y00<0Kdh[079A;P1cDRl0
0P1bDRT207=C:P@0M5@[0P1iES00101jEbl0NUL]07]I;01kFB`207]I:`0607eL:@1mFb/0O5XZ07eK
;@1mFbh0OU/a0P1oG3@4081N<0<0PEla00<0PV0b08IR<P27Hc<00`28I3@01026HS80QF4a08=O;`26
HS8308MS<`80R6@d0P29ICD208QT<00408UU<@2:IS80RfLc08aX=080SFTe00<0S6Pd08iZ=P2?JcL0
0P2AKCT02`2@K3P0Sf/g08iZ=P2CKCh0U6ho09E_@02GLD80VG=409]eAP2LMTL0WGM800<0VWA30`2K
MD@209afA@@0V7A0102IMD40202KMT80VWE109Ud@02IM400VWE109ag@`2NNDD0X7]70P2ONTD0102P
NdH0XGa70:9mB02SOTT20:AoBP<0Y81<00<0YH5=0:J2CP2VPTh00P2WPdl20:J2CP040:N3C`2YQE40
ZXIB0:b8E080[HUE00@0ZXIB0:^7D`2[Qe<0[8QD0P2]RED00`2^RUH0[h]G0:n;E`020;:>G0040;>?
G@2dT5h0]I5O0;JBH080]i=Q202gUFL20;ZHJP80^iU[102lVV`80;^IJ`80^YQX0`2iUfL30;RFIP<0
]YAV0P2eTfD50;BBI0040;FCI@2fU6H0]iEW0;RFJ080^IMY0`2iUFD40;ZFIP040;^GI`2lV6P0_9QX
0;bHJ080^iMW0`2jUVH50;^GI`<0_9QX00@0]i=Q0;VEH`2kUfD0_IUW0P2nVVP0102mVFL0_9QV0;nJ
K@2oVVd20<2KKP<0`Ia_00<0`Ye`0;fKK@2mVfd01P2mVfd20<6LK`040<:ML033WW40aJ1c0<JQM080
aj9e2035XgH20<NTNP060<RUN`39YW`0bZMm0<ZWO@3;Z7h0c:Uo0P3;ZGT0103;ZG/0c:Ym0<fZP03=
ZX820<j[Q@030<fZPP3<ZH40bjR00080bZMo00<0c:V10<j[P`3?[8@00`3?[8@40=2]Q@80dJj600@0
dJj80=:_R@3B[hT0dZn90P3C/8X:0=BaR`<0dZn7103A[XH00`3@[HD0cjb20<n/PP030<j[P@<0cJZ0
203;Z7h20<fZP080c:Uo0P3;Z7h20<ZWO@P0bJIl00/0bjIi0<bWNP3=Z7/0cZUl0<fXN`3<YgX0bZEh
0<VTM`3:YGP0bJAg0<NRM@030<FPL`030<JQM037XWD0aj9h00L0aj9h2035X7<00`36XG@0aJ1c0<FP
L`020<BOLP80`iia00<0`Ye`0<6NM031WW@01P31WW@01@33XG<0`Z1b0<:PLP31Wg40`9i`0080_ie_
00@0_Ya^0<2NL030WW00_ie_0P2nW6h0102mVfd0_9Y/0;bJK02jUFP30;^FJ@0:0;bGJP2mV6/0_YU/
0;nJK@2nVFd0_YU/0;bGJP2kUfL0^YIT0;VEH@80^IIP1P2iUF420;RDH0030;NCG`2fTUh0]Y9N0080
]I5M0`2dT5`0102cSe/0/XeH0;:=F02bSEP30;6<E`80/8]F0P2`ReL0102aS5P0/XeI0;>>FP2dSe/2
0;F@G0080;:>G02aSE/0/8aH0:j;E@2]RU@0ZhQ@0:Z7C@2YQT`30:Z5D080ZhIA0`2/Qe820:n<EP04
0;2=E`2aSUP0/XmI0;:?F@80/i1J0`2_ReL00`2^RUH0[HUE0:f9E@020:b8E0<0[HYD102/RE<00`2[
R580[haF0;2=E`020;6>F0040;2=E`2^ReD0[8UC0:^8DP80[h]G00@0[XYF0:f9E@2/R5@0ZhMC0P2Z
QU830:Z5DB_ooooo000Zooooo`080:9fA@2SMdH0YGU80:IjB@2WNdX0YWY90:EiB02TN4L30:EjA`80
YW]80`2WO4T@0:ImB@P0Ygi:0`2YOdd20:QnC0<0Yge;202YOdd30:YoDP<0ZGiA0P2XOE020:V0C080
Z7m;0P2WOTX20:ImB@040:=nB@2SOTX0Xgi:0:9lB`80XWa=00P0XG]>0:5jC`2QNTl0XGa709mjA@2L
Md80VWE009Qc?P<0Ug8m00X0U6i109=]@02BK3d0TV`k091[=`2@JcH0SfXc08iY<P2;IST0S6Lj0P2=
J3/0102<IcX0RVDh08QS=P26HC@3089M<`80PE`b0`20Fc4207]H;P0307YG;`1iES00N5@`0080Me<a
00L0MU8b07I?;P1dD2h0M50^07=A;P1bDBh0L58^0080Ke<^201_CR/04@1bCbL0Le0X07AA:@1eDRX0
Me@/07QE;@1iERh0NUL_07mI<P20Fc40PE`b08=N<P25H3<0Qf<c08QT<P29IC<0RfDf00<0S6Hg0P2=
IcP208iX>@0308]U=P2=IcP0T6Xk0080TF/l00H0T6Xk08eW>02;ICH0T6Xk08mY>P2>J3T208eW>003
08iX>@2?JCX0T6Xk0080T6Xk00@0SfTj08iX>@2>J3T0SfTj0P2@JS/00`2;IST0S6Lj08eX>`0208iY
?00308eX>`2<IcX0RfHi00P0SVPk202>J3T0102=IcX0SVPk08iX>`2>J3/308mY?007091Z?@2?Jc/0
T6Xk091Z>`2BJC/0TfPk09AX>`0209IW>`80SfTj0`2>J3T408eW>00308iY=@2=J3@0S6Lc0080S6Lc
00H0SVTe091[=`2AK3P0SfXf091[=`2BKCT209=^>P03099]>@2@JcL0SfXf00<0TV`m0P2AJc`3091Z
>`08099_>@2AKCT0Sf/g08iZ>02>JSX0SfXm095/@02BKD4808m[>`P0T6`h00@0SfXm08iY?02>JC`0
SVTl0P2=J3/208aW>P0808UW=`2:J3P0S6Xj08e[>`2>K3`0SF/k08aZ>P2;JCT308iZ>P80Sf/k0`2>
JSX808]Y>`80T6Xk00<0SVXj08]Y>@29JCP00P27JCL06@24J3H0QFPl08AW>`22ICT0P6<g07iQ=@1k
GS80NUda07UL<01aG2d0KeX]06]F:`1WDBX0Hd`Z0619:P1NARX0GDD[05A09@1@?bD0C3`S04Hj900o
=b@0>C@Q03Db8`0b<2400`0Z:R0202TY7`<0:2PN00H09RXK02DY6`0S9aT08B@I01lR6@0O8Q/201lQ
70<07AlL0`0L7Q/201/M6P<07R4J0`0O8Q/2020S7006020R7`0O8Ah071hK01XL6@0I6aP061XG0`0I
6aP801XL6@80824L00L0824K024R6P0S9AX09bTL02X/7`0/;R00>3<O0080?STU00/0=S4M03<^6P0h
<al0>cHR03Td800Y:R808b@L01dN5P0K71@07b0H02@U7@0202HW7`<09BHN0P0T9Ad302<T70808B8L
0P0P8A/0100O81X07QlI01dN600M7QP401dP6@@07R4J02X0820N01lO7@0M7A/071`J01/K6@0L71X0
7AdK01hN700M7a`07b0K02<S6`0[9a/0=2dK03db7P13=al0B3XO044a8@14<b40BCLO05I18P1WCbT0
NUld08Y^?P2EMdD0UGI:0:N7EP2cSUL0Y7m808EU=P1UC2d0A3LW02lW900W:BH09RPU02@V8`0S9B80
8R@Q02<U8P0T9R<09BLT02HY8P0U:24202@W800402DX8@0W:R<0:B`U02X]9P80;BdU0`0/;2@06@0^
;RH0;blW030`:00Y:B40:RXR02d]9@0_;bL0;RhV02d]9@0Z:R80:2PP02`W8`0[9R80;2LQ02`X7`0^
:Ql0<2`P038_800c<240;2dO02//700_;1d0=RlO03he9016>BP00P1;>RP03`10=1h0@c@M04/j801M
ARL0L5<a07YJ<`1jEbd0N54V071=9@1nFc40RVLm08aZ?@2?KCl0U79209Ac@00208i]>P0808UO;`29
H380QF0d07UI<P1YCb`0GDHW05E19P1B@BL204Xi9`0604Th9P18=bD0B3LU04Pg9@19>2H0BSTW0`1>
?RD204lo9P<0D40W00H0BT0W04/o9`1;?bL0C3dV04dm9P1=>bD204lj9@P0Dd4Y00@0Bch[04Xm:P1:
?BX0BSdZ0P19?2T204Pk:00804`g9P1=>2L0CS/Z04ln;01>?b`0BSdZ04Lj9`15>RH4048f9P@0@CDU
00H0?c8Q03lb8P0m<B40>S4R03Ta900g<BD203@`9@80=34R00H0=30T03@`9@0b;RD0<2/U02hY9@0]
:2@2030/8`04034]900b;RD0<RhU034]9080<2`S0`0a;B42038^8P<0<blS00P0=BlS03@^8P0c;B40
<bdQ03@^8P0f<2@0>38V03Xd:080@c8X00<0@38W03lc9`0l<RH00P0k<bH0100i<bD0=C4U03@`900c
;b<2038^8P0603<_8`0d<2@0=C4U03La8`0h<R@0>C<U0P0j=2H04`0i<bD0>38T03La8`0h;RD0>BlV
03ha:011<bP0ACDX04Hd9P15<bD0AS<T04Ph:@19>BX0BSTY04`i:01=>bL0D3/V058l9`1C?BH00P1D
A2X305=3:@<0DT8X0P1B@b@01`1CA2D0E4DV05E69`1EARL0E4DV05=49@1A@R<00P1@?bD205509P<0
DT4W0140Dd8X04`o;01<?b`0C3l/04/n:`1:?BX0B3/X04Hi9P15>2D0CSdY0510:@1C@bX0ETLZ05U:
:@1KCBP0G4hW05a?9@0205Q59`0905Y7:@1LBB/0GT/]061=;`1QCS00HTla069>:`1SCb`0He4]0080
HU8^04/0Ge4/05a@:P1KCbT0EDXZ05E:;01DBB/0DDHZ04i2:01;?bL0Ac/U04Di8`1A@BX0D40W0550
9P1E@R@0FTHU06==:01ZE2d0L5T`07EO<01fH340NF<d07eW>023KCh0RWA508miBP2CODh0UX5:09N2
B`2JQD`0WXY?0:>?E02YUEP0[IUJ0;2LG@2eV5h0]iYP0;VLHP2jWF<0^IaR0;BGG@2_TUP0[8mE0:V:
E02XRE<0Z8MA0:V6CP2[R4h0[h]?0;F>D`2gTE<0aYA=0<FEC@35U4l0`iA@0;nBC`2kT4`0]Xe;0;B;
B@34TTd0a9=>0<JED037V580b9aE0<VOE`39XET0bZ=H0<NLF038WET0aimJ0<NPF`35X5X0`ImH0<2N
E`2mW5D00P2jTe80102hTE00]Xm>0;B=C02cS4/20;6:B@040;J?A02gT4D0]i130;RA@P80^I=201<0
^98o0;RB?@2bS4D0[XQ10:^4?`2YPSl0Z8500:Em?`2PN3X0Vg<f09m_;@2ML2d0W6h`09U/<@2DJC80
SVD_08YR;`27Gbh0P64[0080OEdZ00h0NE/Y07AH:@1cF2/0M5/b07MN=P1iHC/0PF4j08AT?@29JSh0
SVm0099d@02DMT00UGPn09Eh?0@0VGU000L0V7Po09Mg?P2FMSd0UGDl09Ic>`2ELSX0Tg0h0080TVlg
01`0Tg0h09Aa>@2ELSX0V7Dk09Uf?02KNC`0WW`m0:5o?`2SPSl0YHA10:J5@02VR400YhU10:V;A@2Z
RdP0ZX]:0:V:BP2WQdX0YXI90:B1?@2ROcd0X7dk09ej>P2LN3X0W7Pl09ah?P2MNCl0VH0n0P2HOcd0
3`2GOS`0V7lm09V0?P2JPCl0Vh9009Mn>`2LPd40WhI609Qn@`2;L3T0P6@b07]O;`1lH340MV4/07MR
;@0207QS;P0407MR;@1fHB`0MF0[07AO:PP0MF0[0P1hHbh207UT;`<0NVD`01T0NfHa07YV=01kIcD0
OFTf07iZ=@1nJc<0OV/a07eZ<01mJRl0OfH^07iU;@1mHR/0P68/08EV<02<JcH0Tg8m09Ue@@2ZODH0
/8MA0;fHI03:Z7X0e;N=0=S0VP3Ha:40f<FT0080f<2V01/0f<2T0=O0X@3C_9`0c[NE0<VbT036/8/0
a:Mm0;RKK`2[SV80XhMH09UmC@2DN4H0WH9=0:^@F`2lWgL0`ZIn0<b`R`3@]Y<0d[VJ0=FmX@3H`jP0
g<J^0>G@_`3Wd/40j=G40>[Ia`3[g<T00P3Yg<T00`3XgLT0j]S40>_F`@020>WE_@050>OB]`3UcZl0
h/ZX0>36X`3Na9l00P3Q`I/01P3O`Id0g/6O0=k4X@3Pb:H0h/^[0>C=[@@0iLb^103VcJl0;03Xb[00
ilV]0>O9[@3Ub:X0hLBT0=g0WP3J_YT0ek^F0=BhT`3A]I00cK280<VZOP33XWD0_I][0;RGHP2hU600
/8eE0:^8D02TPD/0Wg]709eiA`2HM4@0TF`o08aW>P20HCD0Of0d07eM=01jFS<0MeLa07AC<01bDBh0
LE0_06iB:`1]DBX0K50[06U<:P1WBRP0IDPX06=6:01RABL0FdPZ05U6:01GA2H0E44S0`1C@2802@1D
@B<0CShM04hn7@1=?1h0CC`P04`k8@1<>R80C3XT04/i8`04058j8P@0Dc/S0`1;=al504Xf7PT0BSPP
00d0CCTQ04hj8P1@>R<0DcXT05@i901D>2<0DcLR054h901B>BD0DSTS058j8P1C>b40Dc/O0080E3dN
0P1J@2D00`1K@BH0G48W05e3:00205i4:@0305m5:P1N@2H0GT0V00<0GClU0`1L?R@205To90<0FT0U
0`1I?b@0101F?b00F44R05Y3901I@R<205Ho800305]49@1PBBX0GdLU0080H4HU0P1RABD01`1SA2D0
ID@U06I39@1V@bD0IdPY06I7:01UARL00P1TABH01@1VAbP0J4TZ06U::`1TABH0Hd@U00<0HT<T00<0
Hd@U06E69`1VAbP00P1]C2T206a;:00406e<:@1_CR/0LE0]079A;P80L50W0P1aDBP2079B:@80Le<Z
0P1gDbl03P1hEBl0N5D]07UF;01iEbX0NUP[07YH:P1kFBT0NUPX07UG:@1iEbX0NEH/07]H<01lFC<0
OEXd0P1mFbd207iL;P0<07mM;`20GS00P5h`081N<024H300QF4a08IR<P27Hc<0QV8b08EQ<@23Gbl0
PEd]0`25HC4308IR<P80Qf<c00H0Qf<_08QT<028I300RFDa08YV<P2;Ic<208aX=00308]W<`2<J3@0
SVXf0080Sf/g00/0SVXf08eY=@2<J3@0T6Xk095[?02BK3d0U6ho09I`@@2HLT<0VG=409YdA@0809I`
@@<0UG4m0`2FLSh209Mc?`0909Ye@@2IM400V7<o09Qc?`2IM400VgI209ehA02NNDD0WGQ30080WWU4
00<0WgY50:1kAP2QO4L00P2RODP20:5mB@040:9nBP2SOd/0Y81<0:B0C0@0YH5=00H0YX9>0:N3C`2Y
QE40ZXIB0:^7D`2/R5@20:Z6DP040:^7D`2/R5@0[HUE0:f9E@80[XYF00L0[h]G0;2<F02aSET0/HeI
0;:>FP2cSe/0]91L0080]I5M0`2dTV@20;FCI@80]YAV00<0]iEW0;RFJ02hUVP00P2iUfT20;ZHJP80
^iU[202jV6X30;RFIP80]iEU0`2fU6@30;BBI0<0/i5S102bT6801P2cTF<0]99T0;JDIP2gUFL0^9IX
0;VGJ@D0^9AT0`2iUFD20;^GI`80^YIV0`2iUFD00`2hU6@0^IEU0;VEI@020;ZFIP@0^iMW00@0]i=O
0;RDH02jUV80_9QT0P2mVFD00`2lV6@0^iMS0;nJK@020;nJK@80`9]^0`31W6l80;bJJP<0`9a/0P31
WFd30<:NKPP0`iia0P33X7H00`34XGL0aJ9h0<JSN@020<NTNP070<RUN`38YWH0b:If0<VWN@39YgX0
bZMm0<^XP0020<bYP`070<bYP@3;Z800bZMo0<VVOP3:Ygl0bjR00<fZPP040<j[P`80cjb4103@[HD3
0<n/QP80d:f70`3A[XP80=>`RPP0dJj60P3?[8830<j[P@<0cJZ0203;Z7h30<fZP080c:Uo0`3;Z7h8
0<RUN`030<^VN@3<YgX0cJQk0080cJQk00/0bjIi0<ZUN038XgH0bJAg0<RSMP36XG@0aJ1c0<BOLP35
X7<0aZ5d0<NRM@080<JQM`P0a9mb0P35X7<20<BOLP040<>NL@32WG00`Ia_0<6LK`P0`9ec0`30WW03
0;nMK`@0_Ya^0P2mVfd30;bJK00?0;^IJ`2kUVT0^iIY0;ZEJ02iU6L0^YEX0;^FJ@2lUfX0_IQ[0;jI
K02mVFT0^iMW0;VEH`2hU600]iAN0080]iAL0P2iUF430;RDH0<0]i=O0P2fTUh20;FAG@030;B@G02c
Se/0/XiJ0080/XiJ0`2bSEP20;6<E`<0/8]F0P2`ReL0102aS5P0/XeI0;>>FP2cSUX20;B?F`080;2<
FP2_ReT0[h]G0:f:E02/RE<0ZhQ@0:Z7C@2YQT`50:^6D@<0ZXE@0P2^ReD0102_S5H0/8eG0;2=E`2a
SUP20;:?F@060;2<F02_ReL0[h]G0:j:EP2]RED0[8QD0P2[Qe<00`2/R5@0ZhMC0:^7D`050:^7D`08
0:f:E02^ReD0[haF0;2=E`2_S5H0[X]E0:b9D`2[R5820:j:EP80[HUE00@0[8QD0:^7D`2ZQU80ZXIB
0`2WPTh[ooooo`00:_ooool00`2RMTL0XgM80:EiBP020:MkC0030:IjB`2UNDX0Y7Q90080Y7U60P2U
NTL30:IkB0030:MlB@2VODT0YWe900h0YWe9202WOTX30:UoC@80Z7i<0`2WOD/80:UoC@80Zh1C0P2Z
Oe80302YOU40Z7e@0:QmD02XOE00ZX5=0:V0C02XOd/0Ygi:0:ElB02TNdL0XgY60:9iA@80Xgi:00`0
Xge<0:=mCP2RO4l0XWa?0:9kD02QNTl0XGYA0:5lA`2PNdH0WGQ309Ye@02HLch209Mb?@0709Qc?P2C
K440Tfe0099/?@2AK3P0TF`g091[=00208m[;`80RVDh0P2;IST0102:ICP0R6<f08IQ=025H3<3089M
<`80PE`b0`20Fc402@1kF2h0NUL]07YG;`1iES00N5@`07QD<P1gDc40Me<c07M@;`0207EA;`0307AB
;`1cDRl0LE<_0080L5@_201_CR/2079?9`0407=@:01eDRX0MU<[07QE;@80NEH^00P0OeTb081K<@21
G380Pehb08EP<`26HS80R6@b08UU<`80RfDf0`2<ISL408eW>00:08mY>P2BK3d0U6ho09A^?`2BK3d0
SfTj08eW>02@JS/0SfTj08iX>@80SFLh00H0SVPi08mY>P2@JS/0TF/l091Z>`2>J3T208eW>00608iX
>@2@JS/0TF/l08QV>029IcT0RfTk0P2<JS`00`2;JC/0RFLi08QV>00808mY?0P0SVPi0P2@JSd208mY
?080SVPk0P2=IcX01P2@K3`0TF/l095[?02CJS`0U6Tl09EY?080UfPl0P2?JCX208iX>@<0SFLh0P2<
ISL02`2@JcL0SfXf08iY=@2=J3@0SVTe08mZ=P2AK3P0TVdi08mZ=P2@JcL0TVdi0080Tfhj00<0TVdi
091[=`2?JSH00`2BK3d2095[?0<0T6Xk00P0U74k09=_>`2@K3P0Sf/i08iZ>P2>JC`0SfXn091[?`P0
Sf/k202@K3P208iY?@80SFPl0`2<Ic/02@2;ISX0R6Hf08UW=`2;JCT0SF/k08i/?02=Jc/0S6Xj08]Y
>@0808iZ>PP0RVPj0P2@JS/07P2>JSX0RfTi08UY>027JCL0QVPf08AX=P27J3`0QVLk08AU>@22HcL0
P64e07eN<P1lGC40Ne``06mJ:`1^FB`0K5L/06YD;@1VCbd0HT//05i6:P1LA2X0E40U058n9@1=?B@0
B3TT048g9@0k=280=S<T03@a8P@0:RXP0P0Y:Al202PX7P0602L[700U:A/08bLI020S600O8QT07R4J
0P0O8A`201hP7@807AlL00@071hK01/M6P0K7AX06adJ0`0N8AX301lR6`8082<L00@08B<P01lQ7P0M
7a`06Q`I100H6QL00`0I6aP06Q`I01XL6@0601XL6@80824L01@0824K024R6P0S9AX09RPK02T[7P0[
;Al0=S4M03hi9@0o>RH0=c8N03<^6P0h<al0?3LS03/f8P0/;BD09BHN01hO5`0K71@07QlG028S6`80
92DM0P0V9al202DV7P<092DM00L08b@L028S7@0R8ad08B8L020Q6`0O81X07QlI00807AhH00D06ahG
01`O600L7aP07B0I01hQ6P0201lR6`0T020S700P81h07alM01dM6`0L71X06a/I01`L6P0M7A/07QhL
01dO700O81/08R8J02TU6@0b:aT0?34M048f7P18>Ql0@S8R04@c8@18=Qh0DchO06=;9@1gG340Qf/k
09=e@`2AM4`0YXIG0;B?F02YQDT0SVdh06aB;`1:>BT0<BHR02PZ9`0W:BH09BLT0`0S9B80100T9R<0
9BLT02HY8P0U:24202@W800D02DX8@0W:R<0:B`U02X]9P0];BD0;2`T02/[8`0Z:R80:b/S02`/900^
;RH0;blW02PX800Z:R80;BdU02l_9`0`<2P0;RhV02/[8`0X:20202`W8`0M02`W8@0]:B00;b/P038^
8P0e<R<0=c@U02la8`0];R00;B/L03<]7`0m=2D0ASTY04Ti:@19>2P0?CDN04@j8@1A@BL0GdX]06]A
<01dE2h0Me4Z07I?9P1bD2/0Oedg08UX?`29J3d0Rf/l095a@02DM4400P2BLcd02`2>I3@0RF0b081K
;`1gEbh0KU@_06E>;P1IARP0D3lS04`k:@1;>RP0BCPV0080B3LU00<0BSTW04/j:01=?2X00P1=?B@2
04hn9@<0CclV00L0D40W04]1:01<@2P0C40X04dn9`1>?RL0CS`V0080D3/V201C@BT204/n:`<0BSdZ
0`19?2T01@1>>BP0CcXY04dj:@1<>bT0Bc`Y0080BC`Y00<0Ac`X044e9@11=BD00P11=BD4048f9P06
03ha800n<B40?30P03T`8@0g;b80=BlS0P0b;R<02`0d<B80=C8S03Da9@0e<BH0<blV034/9P0^:BD0
;2LS02l[8P0`;2<0<RhU0080<blV00@0<RhU030/8`0_:b80<BdQ0`0b;R8203<_8`80=30T00P0=BlS
03@^8P0c;B40<bdQ03D_8`0g<BD0>C<W03Xd:080@c4W00<0@S4W03la9P0n<RH00P0k<BD0100j<RD0
=S8V03Da9@0c;b<2038^8P0603<_8`0e<BD0=S8V03La8`0h<R@0>C<U0P0j=2H04`0i<bD0>38T03La
8`0j;BD0?2lW03la:012=2T0ACDX04Le9`17=2H0Ac@U04Lg:018>2T0BSTY04dj:@1>?2P0DSdX05@n
:@1E?bP00P1DA2X0101C@bT0DT8X0592:01A@BL205109P80DT<R00L0Dd@S05E69@1FAbH0ETLV05E6
9@1DAB@0Dd@S0080DclT0P1D@2D305E19P1305I29`1;?R/0Bch[04`o;01=@2d0C3l/04Xm:P18>bP0
AcXW04`k:@1=?2P0CShW0511901CA2<0EdTT05Y=8`1LCb<0GT/]05e:;01KB2X0FTLY05]8:P1MBR`0
HDh`06=@<P1VD2/0J58]06YF<@1/FS@0JEXc06EG<01PDR/0G50X05eC<01LDC40Fe0b05Q=<@1DB300
Cd<]04/n:`18>bX0CSlZ04lo:01@@2L0Dd8V05Q59@1NBRL0IDlZ06QB:`1bG2d0Led^07MQ<P1lISL0
Pfdn08]eAP2ANd`0UGm@09F0B@2GPTT0W8M>0:2<D@2UTE@0Z9AE0:ZGE@2[V5H0]IMI0;JHFP020;NI
F`0/0;JHFP2cUEL0/99D0:j@DP2[SET0ZH]G0:R9D`2WQU00ZXMA0:j9DP2bSU@0]XmF0;fAD02lT4l0
^I1@0;J>D02dSU00/XiB0;>?D`2bSeD0^he?0;^?D02mTE00_IAB0;jGDP30VeD0_ieE0<2NEP36UT`0
aYQ=0<FID035Ve40`YaC0;nKD@2kVE40^IU@0;V@F02hSeL0]XeE0;>:DP2`Qdl0[HA<0:^2BP2ZPDT2
0;66@P0G0;66@@2bR400/XPn0;>9?@2dRSh0]8/l0:b6>`2XPST0Y7hg0:=l=`2RNcX0WWHh09M_<P2A
JBh0UF8Y09AS:`2AHRh0SUla08ML<@22F300O5@`07UC;`1gEbh00P1eEB`06@1aE2X0L5@/079I<01g
H3H0OVTn089]@P2;K3h0Sg1109=e@@2GNT80VGdn09Un>`2GO3D0UW`b09]k@P2JNT40VGU009Mg?P2F
MSd0UGDl09Ad>`2CLcX0UG8j09Aa>@2CL3P00P2BKcL06`2CL3P0UG8j09Ic>`2GM3X0V7Dk09Yh>`2M
Nc`0Wgdm0::1?P2TPd00YH@o0:N9@02XRT40ZH]30:V:A`2XRDP0YXI90:B4B@2RPTL0XGhj09ml>P2M
NSP0VWLg09Ue=`2IMCT0VGDk09Yf?00209N0?@80UGhk00l0UWll09N0?@2IPSl0VhA109Im>`2LPd<0
WhE809MmA028KCP0O60^07YN;`1lGc<0MF0[07IQ;01gHRd00P1hHbh00`1fHB`0M5lZ07=N:@0207IQ
;00407EP:`1dGbX0LehY07=N:@80LUdX0`1fHB`207MR;@<0N6<^03D0MfDc07QV=01jJCD0NfXd07a[
<`1kJc00NVX_07UY;@1mIS00O6<]07YQ:`1jGbX0Of4]08IV<`2>KCX0TW4n0:Eh@@2/Pdd0^IAP0<NU
M@3A]8P0e[nF0=O3WP3GaJ40eknU0=S0YP3H`:@0f<6R0=BmW@3?^9H0b[>A0<NaS033YW`0]YU]0:V<
H02PQ5D0Ug];09AhAP2OQ4l0[Y=N0;nRNP34Z840cK6<0=6gUP3C^Y`0e[jT0=[4[03ObK80im;10>WD
``3Ye/D0jm[80>_Lb@020>[MbP030>SMb@3ZeL00jMBo0080im6i00d0iLfa0>;9ZP3OaJ@0gL>N0=g1
W03Q_iT0h<2I0>30VP3O`Id0h<>Q0>77YP3SbjT0iLb]00@0i<V[103Sb:X20>?4Y`0/0>72X`3O`Il0
fkfK0=JhU03B]8h0d;:<0<^]Q`38Zh<0a:Ak0;fNL02fUVD0/8mJ0:f:E02ZQdl0XWm509ai?`2FLc/0
Tflk095]>`2=J3/0Qf8f089M<@1gEc00MUH_07AD;P1bDBh0Kdh]06e<;@1[BR/0JTP/06I<9`1UBbH0
HdTV06579P1OA2H0GD8U05]08`1J?b@0E4<Y05919`1@?bD0CC`R04`k8@1;>R0204`k8@0604/l7@1;
?1l0BS/N04Xj8019>B00BCTR0P19>2@504hh80<0CCLO1017=Al404Pf80P0B3PQ00@0AcDO04Pf801<
=b80CcTT0P1A>2@00`1A=R<0D3DR04df900204hh8`0304hh8@1?>B40CcXO0080D3/N00H0E3`R05Dm
8`1F?R@0EclU05Q09P1I@BL205Y2:0<0FS`T0`1K?BD205`n9P0505U19`1H@2H0F40V05Lo9@1F?R@0
0`1E?B<0101B?Ah0ED0Q05I18P1E@24205<n7`0305Q3901MB2T0GTHT0080GdDT0P1QA2@03P1R@b@0
Hd8S06A18`1T@B<0ITT[06E8:P1SARP0HTDW06549P1RABL0HdHX06A7:@1R@bH0HD8U0`1P@B@01@1R
@bH0I4DX06E6:@1]C2T0K4/X0080JdXW00@0K4/X06i=:P1`Cb`0LE0]0`1_CbH2071@9`<0LE4X0P1f
DS000`1fDRh0Me@^07MD;00207QE:`0?07QF:@1hERP0MeDW07ID9`1eDRP0MU<[07QE;`1iES00NeLc
07YH:P1kFB/0O5X/07eK;@1nG2h0Oed_0080P5h`0P23Gbl308EQ<@0308=O;`21GBd0P5`/0080Pel_
0P24H30308EQ<@0308IR<P27Hbl0Qf<_0080R6@`00<0RFDa08YV<P2;Ic<00`2;Ic<01P2=JCD0SVXf
08iZ=P2<J3@0RfLc08YV<P80SVPi00H0T6Xk095[?02CKCh0UFm009I`@@2GLD88099/?@80TVhj0P2C
Kc/01P2DL3`0UG4m09Ea?@2ELCd0VGA009Qc?`80Ug8n00@0V7<o09Ye@@2LMd<0WGQ40P2LMd800`2M
N4<0WWU409mjA@020:1kAP070:5lA`2NNTH0Wg]70:1lB02QODT0XWi:0:=oB`040:B0C0080:F1C@2V
PTh0Z8A@0:V5D@2ZQU80ZhMC0:Z6DP2[Qe<20:b8E080[HUE00<0[XYF0:n;E`2_ReL00P2_ReL00`2`
S5P0/HeI0;:>FP020;>?F`080;B@G02`SV00/8iP0;6?H@2cTF<0]99T0;FCI@2fU6H40;NEI`80^9IX
0`2iUfT80;RFJ080]iEU0P2fU6@30;FCH`040;BBHP2cTF<0/i5S0;>AH`80/Y1R0`2aSf401P2`SV00
/HmQ0;:@HP2cTF<0]I=U0;JDIP80^9IX0`2hU6@50;NCH`80^YIV0P2iUFD30;RDI0030;NCH`2hU6@0
^9AT0080^IEU00P0^YIV0;^GI`2kUfL0^iMW0;NCG`2hU600^YIR0;bHI080_IUU0P2lV6@30;^FJ@80
_9MZ0`2mV6/80;bKJ080`9aZ0P2oVfT20;jJJ080_IUW2032W6d01P2oW780`9ec0<2ML`31WW@0`Yme
0<>PMP80a:5g0P35Xg<01036Y7H0ajEh0<RUN`39YWh20<ZWP@070<^XP03:Ygl0bJIn0<RUO@39YWh0
bZMo0<bYP@040<fZPP80cZ^3103?[8@0103<ZH<0cJZ40<fZQ03=ZX@20<j[Q@80cjb6203A[XP40=2]
Q@@0dJj60P3?[8830<j[P@<0cJZ0203;Z7h40<fZP080c:Uo0P3;Z7h80<RUN`030<ZUN03;YWT0c:Mj
0080cJQk00H0bjIi0<VTM`38XgH0bJAg0<RSMP36XG@20<BOLP030<FPL`36XG@0aj9e00P0aJ1f2034
Wg820<FPL`040<BOLP33WW40`Ye`0<6LK`80`9]^202oW7820;fKK@<0_Ya^0`2oWFl50;bJK0<0^iU[
00<0_IQ[0;bGJP2jUFP00P2hTfH0202iU6L0^YEX0;^FJ@2oVf/0_IUY0;ZFI02hU600]Y=M0P2fTe/0
0`2gU5X0^IEQ0;VEH@020;RDH0030;NCG`2fTUh0]Y9N00<0]Y9N00@0]I5M0;B@G02cSe/0/XiJ0`2a
SET0102bSEP0/HaG0;6<E`2aS5L20;2;EP80[hYE00H0[hYF0;2;E`2`ReL0/HaH0;:=F@2cSUX20;B?
F`80[HUG00H0[HUE0:b9D`2/RE<0ZhQ@0:^8CP2ZQdd20:b7DP80ZhIA00@0ZXE@0:V4C`2XPdh0Z8=>
0P2/RE<0102]RU@0[X]E0:n<EP2`SEL20;6>F0050;2<F02_ReL0[h]G0:j:EP2/R5@00P2[Qe<0102Z
QU80ZXID0:Z6E02ZQU@50:^7E@030:Z7D@2/RE<0[HYD0080[haF00<0[X]E0:f:E02/RE<00P2^RUH0
0`2]RED0[8QD0:^7D`020:Z6DP040:V5D@2UP4`0YH1<0:F0C2_ooooo000Zooooo`030:9fA`2SMdP0
YGU:00<0Yg]<00@0YWY;0:EiBP2TNDH0Y7U60P2UNTL40:IkB100YWe9202WOTX30:UoC@80Z7i<0`2W
OD/80:UoC@80Zh1E0P2ZOe@0102YOU<0Z7eB0:QmDP2WO5420:Z1C@040:QoB`2VODT0Y7]70:9iA@80
X7M300@0Y7m;0:=mC02SOD`0Xge>0P2RO4l02@2RNe00XGYA0:5jD@2RODP0X7]609eh@`2JMD00V7<n
09Mb?@0209Qc?P0809=/@@2BK3l0TV`m095/>02AK3D0T6`b091/;P2?Jbd208UT=`80RVDh00@0RF@g
08MR=@25H3<0Q5lb0`22GC<2085L<P<0P5/a0P1jEbd01`1jEbl0NEH`07QD<01hE380Me<a07MC<`1g
D2l00P1eDBl00`1dDRl0Le8_075C;`02071D;`P0Kdh[00h0LDhV079?9`1cD2P0M54Y07IC:`1gE2`0
N5D]07UF;P1oFC80OeX`085L<P23GS80Q5lb08IR<P80R6@b0`2;ICH208aV=`@0SFLh00X0T6Xk09=]
?P2FL440UW1109=]?P2@JS/0SFLh095[?02?JCX0SVPi0P2<ISL01P2>J3T0SfTj095[?02AJc`0SfTj
08iX>@80S6Hg00H0SVPi08mY>P2AJc`0R6Hh08UW>@2;JC/208aZ?00308]Y>`29IcT0R6Hh00P0T6Xm
202>J3T2095[?P04091Z?@2?JC`0SVPk08eW>P80S6Hi00H0T6`l095[?02AJc`0TfXl09AY?02EJC`2
09MX?080SfTj0P2>J3T0402=IcP0S6Hg08aV=`2<ISL0RfDf095/>02@JcL0SfXf08iY=@2?JSH0T6/g
099]>@2CKSX0SfXf091[=`2BKCT209=^>P03099]>@2@JcL0SfXf00<0TV`m0P2AJc`3091Z>`0609Eb
?02DL3`0TFdi08m[>@2>JSX0SFPk0P2>JCd808m[>`80Sf/g102@K3P2095]>@0408iY?@2=J3`0SFPl
08eX?080S6Lk0P2;ISX01P28ISH0RFLg08]Y>@2=Jc/0SV`l08e[>`80S6Xj0P2>JSX408eY>@80SVXj
202:J3X08@2@JS/0SfTj08iZ>P2;JCT0RFTh08MY=`26J3H0Q6Pf08MX?026Ic/0Q6Di089S=`20HCD0
OEhb07aM<@1kG300KEPY06eH:`1]F2d0K5H_06QA;`1SC2d0GTHZ05]3:@1E@2D0DclV04hl9019>RD0
@SLU03`e8`0h<R@0=C8S02/[8@0302XZ8080:BTO0P0X:1h01P0X;1d09RXL02<W6@0P8aP07R4H01hQ
6P807b4L0P0N81d201dO700401`N6`0K7AX06adJ01XL6@<07R4J0`0O8Q/2020S7004024S800O8Ah0
7AlL01XL6@D061XG200J71T2020Q700<020Q6`0Q8QX08bDJ02HX6`0Y:ah0:bdO03Ha7@0n>BD0@3/W
03Pc7`0c;QX0=c8N0P0l=b<0200^;bL09bPP01hO5`0K71@07QlG024R6P0S91`08R<K0P0V9al202DV
7P@092DM00H08b@N028S7@0Q8Q`0824K01lP6P0N7aT201dN600[01XM5P0K7QL071lH01dP6@0N8AX0
7b8K020S700Q91d0820N01lO7@0M7A/071`J01/K6@0L71X07AdK01hN700L7Q/07QlJ028R6P0Y9AT0
<BXH03/`7012=Qh0B3XO04@d9015=280B3HN058m7P1QBB<0MEX_08EY>@2ALd40Sg5;0:F5EP2eT5T0
[XQ:09Aa>`1bES40C3TX03<U8P0X:RL09bTV02DW900202<U8P0502@V8`0U9b@09RPU02HY8P0U:240
0P0T9b001`0U:2409bXS02T/9@0Z;BH0;2`T02/[8`0Z:R800P0Y:B401P0[:b<0;BdU02l_9`0W9al0
:RXR02d]9@80<30X00<0;RhV02/[8`0Y:B400P0/9b<07@0/9b40;BTP030/8@0d<2@0>3DV03Xg:00d
=RT0;c4S02h/7`0a;Ql0>c@T04<g9`17=bL0ACDU04I0:P1>ARl0Fddc06AA<`1YCbh0K4`V06m98P1_
B1l0LDl/07iL=`26I3h0Pf8g08=S=02:JST0SVli0080SFhh00/0TFLe08QP;`1mF2/0MUH]075G<P1Z
Dc<0FdPZ04ln8P1=?2X0BcXX04Xi9`0204Th9P0304/j:01=?2X0CSd[0080CCdT0P1>?RD404lo9P06
04a2:@1=@BT0CD4Y04ho:01??bP0CcdW0P1A?2L805=1:@<0Bch[0P1:?BX304Tl:@08050k:P1?>RT0
C3TX04/j:01:>bP0B3/X04Tl:@19?RX4044e9@@0@SHV00H0?C0O03d`800k;al0>2lP03H^8@0d;R82
034]8P80=C8S00T0=S8V03Hb9`0d<2L0<B`V02hY9@0/9b<0;b/R034]900b;RD00P0d<2L00`0b;RD0
<BdT02l[8P04038^8P80<blS0P0d<2@0200e;b<0=2hR03<]8@0d;R80=BlS03La9@0i<bL0>cDY0P12
<2H01011<2H0?S0U03da9@0l<2@203X`900303Hb9P0e<BD0<blS0080<RhR00H0<blS03Da9@0f<RH0
=c4S03Pb900i<bD203Xd9P0803Tc9@0h<R@0=c4S03/^9P0l;bL0@38Y04@c:@17=BT204Pe9`0904Tc
9@16=RL0AcLX04Xi:@1=>RT0CcdY05<n:@1F@2/0Ed4Z0080E4@Z00@0Dd<Y0592:01A@BL0D40V0P1?
?bD205938P0305=48`1EARD0ETLV0080ETLV00<0E4DT05=48`1D@B<00P1D@B<205E290<0ET<U03h0
BSdZ04/n:`1=@2d0CT4^04e0;@1<?b`0BC`Y04Pk:019>2P0BCPV04Ti8P1:>R00CSlN05947@1GBQh0
FTdP06EB=01QCS00G4T[05U6:01HABL0FdPZ05m<;P1QCS00IU0Y06YD;@1^Fc<0LUlg071N=P1YFS40
HUD[05iA9`1SFCD0HUPe065F=P1NDcL0FDde05A8<P1?@S40C3l^04dn:`1=?RT0D40Y05=2:01HABL0
GDTX061<:@1TCRT0KeTZ075K;01eGc00NfDf08=]?P2;MDH0TWa=09J0D@2DOdH0Uh9909b8C@2RSU40
YY9C0:RDE@80Z9EC102dUUP0;02cUEL0/YAF0;2BE02_TE<0[HmM0:^=F`2YREH0YhQB0:R7D@2]RU80
/HaE0;B@EP2hT5<0]Y1B0;><D@2`S580/8eE0;6@FP2cU5d0]YMQ0;N=D`2gSe@0^91C0;VCE02iUU@0
^YUF0;ZLEP2kWEL0aYE80<JEB@35UdX0`iM<0;nHC@2kUdd0]iE;0;FEC02jSUd0^8aK0;J:F@2bQUD0
[X9A0:]oCP2XO4/0YWY90P2/P4405`2/P3l0[H8n0:f2?@2^Pch0[hDm0;26?P2YPcP0Y7hc0:1j<`2N
Mc80WWLf09Yb=@2BJRl0Rf8Z08mI:P2>FR/0S5T^08MG;`20E340Ndlb07A<<P1bBS40LE8c0080L58`
01@0KE4/06eD;01bFc40NVDh08=^?`27MDD0V7Y609]mA`2OPTP0XhM80:>8@`2QQc`0WXDe09b3<@2K
Nd80VWY109Ui@02GMch0UGDl09=c>P80TW8i00<0UG8j09Aa>@2CL3P00P2BKcL0;P2CL3P0UG8j09Ic
>`2FLcT0Ug@j09Ug>P2LNS/0Wgdm0:60?@2SPSl0Y8<n0:R;?`2YRd80ZH]30:V:A`2WR4L0Y8A70::2
A`2PP4L0Wg`h09ej>02KN3H0V7De09Mc=@2GLcL0Ug<i09Qd>P2GP3d0UWll09En>`2DOCX0UGhk09N0
?@2IPSl0VhA109El>P2LPd<0WhE809Il@`27K3L0Nel_07UM;P1kGS80MF0[07IQ;01gHRd207QS;P09
07IQ;01dGbX0LUdX07MR;@1fHB`0MF0[07AO:P1cGRT0LE`W0080L5/V0P1dGbX207EP:`<0MV4/03H0
Mf8]07IT<P1gIC<0NFPd07]Z=01lJc<0Nf/`07UY;P1hJ2`0O6D_07YS;@1iH2X0N5dX07aN:P23Hc00
RFTf08i]>P2RMC`0ZH180;JAG035Xg<0ck:60=BmU03E`I`0e/BP0=JnY03G_jD0fL6U0=S1XP3E_Yh0
d;VG0<ZcT@37/H`0`jIl0;JIK@2XRel0WX9C09IjBP2CMdD0WhA?0;2EH030XW`0aJV20<jaS`3B^9L0
e;^M0=NoY@3KaJh0h<Zc0>SC`P3ZeL@0j]O60>cKb@3/gLX20>[MbP030>SMb@3Ye;l0j=:k0080iLng
00D0hl^_0>37Z03M`j00g<2K0=^oV0020>6oV@060>30VP3O`I/0h<BO0>77Y03TbZT0iLf[0`3Sb:X2
0>;7Z@80hLJX02d0h<FW0>;0Y03Q`:40h;nP0=flV`3I^9D0e;B>0<n_R03<[8D0`jIn0<2SN`2lWG40
]IEV0:j=FP2YQE40Xh180:5lA@2HMST0Tg0f08eZ<P2:Ic40RFDc08IQ=020Fbl0NeH/06mA:`1^D2X0
K4hZ06Y<:P1XBBX0ITLZ06A5:01SA2P0GdLS05i68P1MAB<0Fd8S05U08P1G?R00EC/P05Dk8P1>?R@0
CCdS04Xj8018>1h00P16=Q`204Lg7@0604Tk7P19>b00BC/P04Pj8018>B80AcPS0P17>2D204hh8@80
CCLP00@0C3HO04/e7P1;=Ah0BcDN1@16=Ql304Lg80P0B3PQ00P0ACDN04Le7`19=b40CCPS04li901@
=b<0Cc@Q04hc8080C3DS00<0CCLR04dg801>>2000P1>>Ah01`1?>Qd0D3PN050h7P1A>Al0DSXP05@l
8P1E?B<00P1F?R@01P1G>B40F3XR05Pj8P1I>b<0FS`T05/m9@80G3hV00H0FT8X05U19`1G?bD0EShT
05Dm8`1D?28205<k8@09054l7@1D?b00ET4R05@o801B?Ah0DchO05Q3901LAbP0GTHT0080GT@S0P1P
@b<0201Q@R<0Hd8S06=08P1S@280IdX/06I9:`1SARP0HD@V0P1P@bD206549P0906529@1P@B@0Gd0S
05m08`1P@B@0HD8U06=49`1UART0K4/X00@0JdXW00<0KD`Y071?;01aD2d00P1^CRD206m?9P<0L50W
00D0LE4X07EA;`1eDBl0MU8^07IC;@0207MD;00:07MD:P1hEB/0MeDW07ID9`1dDRD0Le0V07AA:@1f
Dbd0N5@`07UE<@80NELY00P0NUPZ07aJ;01mFbd0Oed_081N<021Gc40PUh^08=O;`<0Q60`00@0PUh^
085M;@1oFb/0PUh^0`23Gbl208AP<080QF4a00H0QV8^08MS;`27Hbl0R6@`08UU<@2:IS8208]W<`03
08YV<P2;Ic<0S6Pd0080SFTe00<0S6Pd08YV<P29IC400P2<ISL0102>J3T0T6Xk099/?@2CKCh209E_
@0@0T6Xm102?JC`2095]>@80TVhj00H0Tflk09A`?02DL3`0UG4m09Qc?`2GLSh209Ia?@0509Mb?P2I
M400VgI209ehA02KMT400P2LMd800`2MN4<0WWU409mjA@020:1kAP0>09eiA@2NNTH0Wg]70:1lB02Q
ODT0XWi:0:=oB`2TP4`0Xgm;0:B0C02UPDd0YX9>0:N3C`2YQE420:Z6DP80ZhMC00@0[8QD0:f9E@2^
RUH0[XYF0P2_ReL01`2`S5P0[X]E0:n<EP2_S5H0/8eG0;6>F02bSeT00P2cT5X20:j<GP060;2>H02b
T680/i5S0;FCI@2fU6H0]iEW0P2fU6H20;NEI`<0^9IX00<0^IMY0;NEI`2gUFL01P2gUFL30;JDI080
]I=S0`2dTV830;:@HP80/HmQ0`2`SV002@2_SEl0/8iP0;6?H@2cTF<0]99T0;JDIP2gUFL0^9IX0;RD
I0040;NCH`<0]Y9R0`2iUFD20;RDI0@0]i=S0P2hU6@00`2iUFD0^YIV0;ZFIP020;^GI`030;NDGP2h
UEl0^iQR00@0_IYT00@0_9US0;NBI@2gTVD0]i9U0P2hTfH30;VDI`P0_9]X0P30W6X01P2oVfT0_YYX
0;fII`2lV6H0^iMU0;ZFI0P0`I]/00H0_IY`0;jKL@2nVg40_iab0<2ML`31WW@20<:OM@80`j5a00d0
a:9d0<FSMP36XgT0b:Em0<RUO`39YX00bjR00<ZWO`39YWh0b:Em0<VVOP3:Ygl0c:V100@0cJZ20P3>
Zh<40<n/Q0<0bjR20P3<ZH<30<fZQ0P0d:f71@3@[HD30=6^QP80cjb20`3>Zh430<fZP0P0bjQn00@0
cZ^10<fZP03=ZX00cJZ00P3<ZGl20<^XOPP0b:Ek00/0bZEh0<^VN@3<YgX0cJQk0<bWNP3;YWT0bJAg
0<RSMP39Y7L0b:=f0<JQM0030<BOLP030<FPL`36XG@0aJ1f00L0aJ1f2033WW420<FPL`040<BOLP33
WW40`Ia_0<2KKP80_iY]202oW7801P2kVF/0_9Y/0;bJK02mVfd0_Ya^0;nMK`80`9i`0P2lVV`60;^I
J`040;jIK02lUfX0^YEX0;RCIP80]i9U00/0^9=V0;VDI`2oVf/0_IUW0;ZFI02gTel0]I9L0;FBFP2e
TUP0]Y=I0;VEH@020;RDH0030;NCG`2fTUh0]Y9N0080]I5M0P2fTUh0102eTEd0]91L0;:>FP2aSET3
0;2<F0@0/HaG0P2`ReH20:n:E@80[hYF00@0/8]G0;6<F02bSET0/hiJ0P2dSe/20:b8EP040:b8E02/
RE<0[8UC0:^8D080ZhQ>0P2]R5<0102/Qe80ZhIA0:V4C`2XPdh20:N2C@80ZhQB00@0[8UC0:f:E02^
ReD0[haF0P2`SEL01P2`S5P0[h]G0:n;E`2]RED0[8QD0:^7D`80ZXIB1@2ZQU@30:^7E@040:V6D02Z
Qe40[8UC0:j;E@80[haF00P0[X]E0:f:E02^RUH0[XYF0:f9E@2/R5@0ZhMC0:Z6DP80ZHEA0`2SOTX[
ooooo`00:_ooool20:=jAPH0Y7]700<0XgY60:ElB02VODT00P2XOd/00`2VODT0YGa80:=jAP080:9o
B@P0Y7m:0`2VODT30:MnBP80Z7m;0`2WOTX20:QoB`<0ZH1<0P2UNdT20:IlBP040:MmB`2XOT`0Z7i<
0:UoC@80Z7m;0`2YP4`30:Z1C@<0YWe90P2UO4P30:AkA`030:=jAP2TNdL0YGa800<0YWe900T0YGa8
0:=jAP2RNDD0X7]709mjAP2NNDD0WGQ409]f@P2JMD400P2IM40209Y`?P0309U_?@2HKS`0Ufdk0080
UV`j00D0UF/i08eX<`2<Ic80S6Lb08]V<@0208YU<080RF@_00D0RVHd08QT<P25HC40PUd`081K;`02
081K<@09085K=01lGBh0Ne`^07YK;@1iFRh0MeL^07IF;`1eEBl0M5@^0080M58/00<0LU8[071C:`1_
Db/00P1/DbX0101[E2X0K4/X06a;:01]C2T206i=:P0<06m>:`1`Cb`0L4l/075=:@1bCRX0Le0Z07EB
:P1gE2X0NELZ07YH:`1kFB/0OU/a0P1oG3800`20GC<0PEhd085N=002089O=@D0RfDf0`2:I3D00`2<
ISL0SVPi091Z>`02099/?@06095[?02@JS/0SfTj095V>`2BIc`0TfPm0P2EJSl0102CJ3d0TVLl095V
>`2?JCX208iX>@0308eW>02<ISL0S6Hg0080RfDf00P0TFDh091U>02?I3L0SVDg08eW>02?Jc/0Sfdm
091^?P<0SVPi0`2=IcP:08aV=`P0T6Dh202@JSd01@2AIS`0T6Dk091U>`2?I3X0SV<i00<0SF8h00<0
S64g08eW>02=IcP01P2=IcP809EZ?`D0T6Xm0`2?JC`0102CKcl0Sf/k08eY>@2@K3`209A`@00508m[
>`2:ISH0U6lk09=^>P2AK3P00P2@JcL00`2AK3P0Tfhj09A_>`0808m[=`0808eY>@2>JSX0Sf/k091/
?02?Jc/0SVXj08aX>02:ISH808eY>@<0S6Ph0P2;IcL308YV=P@0S6Xj102;JCT308EV=`D0QVLh0200
Qf/i08IZ>024J3P0PFDf07mR=P1lGcD0NUde07UL=01aFCD0K5@`06I?;@1QCB`0H4d]05a;;@1GARP0
DD8U04/l9@1;?2L0B3`V04Dj9P10>2D0>c@R03H_7`0c;Ad0=2hR034]8@0^:Qh0:bTL02PY6`0X:Q`0
9b/L02P/7@809RLO00@09BHN02@U7@0S91`08R<K0P0Q8QX201lQ7P807R0M0P0M7a`201`N6`<07R4J
0`0O8Q/2020S700602<V7@0Q91d07R4J01/M600J71T06A/J0`0I6Q`801XL6`8071hI00L07B0I01hQ
600Q91T092PJ02P/7P0Z;Ql0>CLP0080>SPQ00d0>CLP03Pf7`0e<a`0<c4J038`6@0b<bD0:BTM01lQ
500J7A806b4G01hS700M91d06b8K00809RLO0`0U9Qh302@U7@0502@V6`0S9AX0824I01hO6@0M7QT0
0P0N7Q`00`0O7al07B0I01dP6@0601dP6@03020R7`0N81d07AlL00806adJ01/07AlL01hP7@0P8Ql0
7B0I01dP5`0O8AH08b@F02/Z600c<A`0>CLP040l8`0k=A<0@CPK04Hj8P1>?RL0FTH[06]E<01nJ3H0
RgDk09alC@2KMdD0YGe:0;::E`2XPeL0OfE205E5;00n=R<00P0/:B001P0Y:B409bPR02HW8P0S9B80
82DQ01lS8P808R@Q0`0S9B8302@V8`0H02X[8`0[;2@0:b`T02LX800T9Ad09RLO02`]9@0b<b/0=34R
034^7`0_:al0<2`Q038^9@0a;2H0;2LS02LR7P0S91h092DO02HW8@0X:B<0:b`V02d^:00_<2X0<34[
100^;al04`0`<B40<c@T03Df9P0g>2P0FT8V0698;@1YCS40IT/^06959`1Q@R<0J4LV06m>;@1`DR`0
MeXb07iQ>@20HcT0OF0d07]O<01lH3000P1oHc<06@2:Jcl0PF@j07YM=@1eFC40LUTa06eE;`1UCbX0
GdTT04Pm:`17?2X0ACXX04@i9`13>2H0A3TW04Dj:016>bT0BcXZ04/j:01<>bT0CC`X04dm9P1>?RD0
CShT04lo9@1A@R<00P1A@RD00`1A@BL0DD4X0551:P020550;0<0CShU00<0CclV05109`1A@BP00P1A
@BP804hn9`0@04Hi9P17>RL0BC`Y04Xm:P1;?R/0BSdZ04Tl:@18>bP0ACDV04Hf9`15>2P0A3PX044h
9`0n=bD0?3DS03Td8@<0>C<U1@0j=2H2038`8`80<BlR0`0`;R402`0_;B00;RXQ02l[8P0`;2<0<BdT
038^9@0c;bH0=30W03Da:00c;b<0<RhR00<0<BdQ00<0<blS03Da9@0f<RH00P0c<B800`0e<R<0=c4S
03Ta900203X`900703``900m;RL0?BlV03`_9P0k<BD0>c@T03/d8P0203/f8P0803Xd9P0i<bD0=30T
034_8`0_;bD0;RlW030a:@0`<b`203`g90@0>cHS0P0j=B801P0f<2@0>30U03Ta9P0l<RP0?c8Y044c
:P80@c8Z00h0C3dN04dn7`1>?b00Bc`M04Pi6P1:>a`0D44R05E69`1SAal0H4LO05e57`1HA240E4@S
05959@80DDHZ0P1AARH0401DAbL0ETLX05Q7:@1MB2/0HTP]06A9;P1WBBl0ETDW05E4:01B@bH0D48W
04i2:01?AB`0DDH`0518<@1<@B/204]0:P0304Xo:@19?RP0BChX0080B3dW03P0A3hX04Lo:01;@BP0
C3hS04`k7`1A?Qh0FTHU06A=:`1VB280IDLS0657901OARL0FdHY05M6:P1EAB`0E4H/06==9P1WDBP0
KEH]079I<01eFRl0MEP/07EF:01bDbD0L5de06iK<`1WEc<0HE8a05Q=;@1ABRd0C4P]04Y6:`1CB3H0
D4Dc04e1:`1>?bP0DD4W05Q7:@1OCbh0IU<b06aF;@1^FBh0M5`^07eQ<P28J3L0TG0k09]f@@2ONT<0
XGTn0:In@`2^QT/0]8eB0;NCE`2fU5L0]99E0;2@D`80/YEI01L0/9=G0:nBEP2]T5@0[8mC0:^>DP2Z
SE40[9QM0:ZDFP2XSeL0Z8YF0:R8E`2]RET0/8YM0;B:H02^Qe00[hQA0;29CP2aRdd0/he<0;B?B@2e
T4T0]Y980;VAB`020;ZBC0D0^i==01H0]iIC0;JEDP2eU540]9=@0;>BC`2bTDh0/I1=0;2?C02dS4l0
/XY?0:j7C02ZPdX0Y7m809mlAP2JND@0VGQ309mh?@2ONC/0X7Xl0:1j>`2QNcX0XG`h0P2QO3H04@2X
LS80Y6h`09i/;`2LJc40V6/d099Y<`29HBd0PE`X07EE?P1bDS/0Kddd06a8;P1[AR/0KTLZ0758;01c
BR`0Me/c0080Nehd00H0Of<d08IX=02=KSL0TW8e09Qf=P2JNCH20:B2>`040:B1?@2TPCl0Y8510:B0
@P80Y81402<0Wgm609al@`2HN3l0U7@k099b>@2CLcX0UGDl09Mg?P2DNc/0SgHf08Ya<@2;LS80SgHf
099i>@2@McL0SG@d09Mh>02HNCP0VW/j09en>`2PPS`0XX@l0:F7?P2VR3l0Xh4i0:F3>`2WQSl0YhU3
0:F8A02QQT<0WH8o09Qo?@2IMcP0UgDf09Id=@0209Ab<`0509Ec=02FM3D0UgDf09Ej=`2FNcP00P2G
O3T409Qm>P0809Yk>P2NOcl0WX9309In@P28LST0O6Pc07EU<@1dI348079N:`0@07MP;P1fGbd0MEl]
07=O;01`Gb/0KUhZ06eM:@1[GRT0Leh_07AO<01eH340MV4b07QS=01jICH0NfHg07aW>080MF0[00@0
MV4/07QS;P1jIC00NfHa0P1mJ3<0<P1gIb`0MVH[07MT;01gHRd0NF8`07aR<@1nHc@0P6@e09U`?02T
NTP0]8iO0<JQM@3C/H/0f[bJ0=g0XP3L`J@0f/:V0=O0X@3D_Ih0e;fM0=BmV`3A^iH0bK><0<:/Q@2l
X700]IUY0:R<G02JOTh0U7Q809UmC@2VRUX0/IEU0<NWP03:[8H0d[B@0=FhV03F^ih0f/2U0>38/03V
cKL0g]C80>?Gb@3Vf/X0jMc90>_La@3Zf/40j=Nk0>KE]`3We;H0i=6c0P3Pbj`03P3MaZH0fl>Q0=_1
WP3L`Yl0g/:M0=VjV`3J^i`0fkbM0=foW@3O`Id0h<:L0>;4WP3SaYh0hL>Q0`3Ra:80903Q`j40gl6O
0=foW@3K_I/0f;RA0=JfS`3C/hX0d;650<b]O`38ZGX0aJMe0<BVM033Wfl0_YYZ0;NCH`2]RET0YH5A
09ijBP2IMDD0Ug=308U_?P26K3/0PVHg07mP=01jFS40N5H`07MD;P1gDbl0Je4`06U?;P1WC2h0I4T/
0615:P1M@RL0FShV05Tm9@80F40X00<0EclW05Hn9P1E?BD00P1C>b<01P1B>R80BSPP04Xh8019=al0
B3HN04Le7@80AS@L00<0AC<K04Dc7`15<al00P16=2001017=B40B3HR04Pf8P19=b<2048g8@06048f
8013=1l0A3<O04@b7P13<Ad0AC0M0`11<aP2048d6@<0@cDJ00@0?c0M040a7P10<Ah0@34N0P11<Ql2
048c800H03lc6@10=1X0@cLM04@h7P15>Al0A3PN048f7011=A/0AC@R04Lf8P19>2@0BSXS04Xj8@19
>Al0AcPK04Hg6P1<=Qh0CCLO04hh801?>B40D3XR054k8`1B?2@0DcdU201A?B@01P1??1h0D3/N050k
7P1C>al0E3XO05Hk8080F3XP201B?b4205Q18P@0FD8S0`1J@b@205Q18P0405U28`1J@b@0FT<T05]4
9@80FT<T00T0Gd8T05i18`1M?R40G3dP05lm8@1S@2@0Id8W06U4:@1ZB2D00`1YAb@02P1ZB2D0K4XW
06m=:P1`CR/0J4XX06U;:@1ZC2X0Jdd[06e?;@1^D2h206mA;`80KTl`00<0Ke4_06mA;@1_DB/00P1_
DRX01@1_DRP0MU4W07IA9`1gDRP0N5<Y0080NE@Z0P1jEB/01P1kFB/0O5X/07aJ;01mFbd0OU`^07mM
;`80P5h`00<0P5/a085L<P23GS@00P24GcD02@23GS@0PE`b081K<@1lFBl0OEX`07iK<@1oG380P5dc
089O=@0208=P=P0308MV<025I2h0Pf8/0080PV4[00<0Pf8/08AS;@26IBl00P2<GcH04@2=H3H0Sf<f
095U=P2BISD0U6Pg09AY=P2=J3<0SVTe091[=`2BK3/0TV`m095[?P2?J3d0SVLl095]>`2?JcT0SVXh
0080S6Pf00l0SVXh08m[>@2AKC/0UV/h09EZ=`2DJCH0TfPe09AY=P2GK3T0VFhk09]`?@2@JS/0TF/l
09=]?P2EKd000P2FL44209E_@00609Ia?@2GLSh0V7<o09Ud@02JMD40W7M30P2MN4@209mjA@060:1k
AP2RODP0Xgi90:AoBP2UP4/0YX5<0P2TOdP00`2UP4/0YX5=0:N1D0020:R2D`050:V3EP2VPDX0Z8=<
0:^6D@2]R5@00P2_REP00`2_REX0[XQI0:f7FP080:j:EP80[XaL00@0/8iN0;6?G`2cTF40]I=S0P2f
U6@0102eTfD0]99T0;BBI02dTV@20;>AH`80/Y1R0P2fU6H20;FCI@<0]99T00<0/i5S0;>>HP2cSV80
1P2cSV800`2dT600/hmO0;>?G`020;>?G`@0/XiN00L0/hmO0;FAH@2fTV80]Y9R0;FAH@2dT600/hmO
0080^9AP00l0]i=O0;JBGP2eTEd0]91L0;>?F`2bSUX0/HeM0;>?G`2eTF40]i=S0;RDI02gTf<0]Y9R
0;FAH@2cTF<00`2dTV@20;FCI@80]YAV00<0/i1J0;BAF`2fTed00`2hUEl20;JCG@040;RDI02iUFD0
^IEU0;ZFIP80^iMW0P2lV6P0102nVfD0_IYT0;fJI02lVF<20;^HHP80^YMQ00<0_IUY0;jJJP2oVf/0
0P2oVf/0102mVFT0_9QX0;ZFIP2mV6@20;bGH`030;^FHP2jUF40^YEQ0080^IAP00@0^iMW0;bHJ02l
V6P0_IUY0P2nVVX20;nKJ`080<2KKP31W6l0`Ye`0<>NL@35X7<0aj9e0<RSMP39Y7L20<FRNP030<JS
N`37Y7`0b:Em0080bJIn00@0bZMo0<ZWP@3:Yh40bZN10P3;Z8840<bYP`P0bJIn203<ZH480=2]P`80
cjb20P3>Zh40103=ZX00c:Uo0<^XOP3;Z7h80<bYO`060=2]P`3?[880cZ^10<fZP03<ZGl0bZMm0P39
YW`20<FRN0040<JSN@37Y7X0ajAj0<RUN`80bJIl00P0bj]l0<ZZN`39YgT0bJAg0<NRM@36X7<0aiib
0<JML@P0aJ1c00<0`Ia_0<:ML034Wg800P35X7<00`34Wg80`Ye`0<6LK`030<6OL@80`9i`0`2oWFl2
0<BPL0040<>OK`32WVh0`Yi^0<6MK@80`9a/00<0_IQ[0;nJK@30Vfh00P32WG000`30Vfh0_iY]0;fH
J`030;jJJP80_IUY0`2lV6P0202iUF40^YIR0;bHI02mVFD0_YYV0;fII@2lV6@0^iMS0P2iUFD40;RD
I080]i=S0`2fTUh50;NCG`<0]i9N1@2hTel40;:=F080/hiI0`2dSeX01P2bSF00/HaO0;6<G`2`Reh0
[hYM0:j9G080[HQK0`2^RE820:n:D`<0/8]D102]R5<50:b7DP0G0:^6D@2ZQE00Z8=>0:R3CP2YQ4l0
ZXE@0:^6D@2^RU00[HU?0:b7D02/Qe80[HQC0:n:EP2aReX0/XaK0;2<F02_ReL0[XYF0:b8E02[Qe<0
ZHEA0:R4D02WPdl0202YQU080:f9E@060:n:E@2^RE@0[HQC0:b7DP2ZQE00ZHA?0P2XPdh30:AnCB_o
oooo000Zooooo`<0XgY600<0Y7]70:ElB02UO4P00P2VODT00`2TNdL0YGa80:ImB@020:MnBP030:Im
B@2UO4P0Y7]700P0Xgi9202TOdX30:ImB@<0Ygi:0P2XOd/30:MnBP<0Z7m;0P2YP4`00`2UNdT0YWa:
0:IlBP020:MmB`80Z7i<00<0ZGm=0:QoB`2XOd/00`2YP4`30:Z1C@<0Ygi:0P2VODT30:ElB0030:Ak
A`2UO4P0YWe900<0YWe900/0Y7]70:9iA@2QN4@0X7]709mjAP2NNDD0WGQ409]f@P2JMD40VGA009Qc
?`0209Y`?P0409U_?@2HKS`0Ufdk09I/>P80UF/i0P2=J3@0102<Ic<0RfHb08]V<P2:IC4208UT<005
08UU<`27Hc40QF4a089M<021G3000P21G3802@22G3D0O5d^07]L;P1jFbd0NEX^07MG;P1fERl0MED_
07AD;P0207AB;003079B:`1`Db/0Ke<[0080K5<Z00D0Je@Z06e<:@1]C2T0KD`Y06i=:P0206m>:`80
L4l/00P0LDdY079>:P1cD2X0ME8Z07MD:P1iEbX0NUP[07]I:`80OU/a00@0Oe`b081M<`20GC<0PEhd
0P22GcD608]U=P80RV@e00/0S6Hg08iX>@2@JS/0TF/l099/?@2AJc`0T6Xk08mY>P2AIS/0TVLl09=X
?@0209AY?P0309=X?@2BIc`0TFHk00<0SfTj00<0SVPi08eW>02=IcP00P2<ISL0202AICP0T6Dh08mT
=`2>ICL0SFLh08iZ>P2?KCd0T6hn0`2>J3T308eW>0X0S6Hg202@ICP8091Z?@80TFHl0`2@IC/408mT
>PP0SFLh202DJCh6091Z?@80SfTl00@0TVhn091/?02>JSX0T6`l0P2DL4001@2?Jc/0RVHf09A_>`2C
KSX0TF`h0080T6/g00<0TF`h09=^>P2DKc/0202?JcL0202=JCT0SVXj08m[>`2@K3`0Sf/k08iZ>P2<
J3P0RVHf202=JCT308aX>080RfLg0`2:ISH308aZ>PD0RfTi0P25ISL608IW>00P08IZ>025JCL0PfLg
085U=P1nHCD0O5le07YM=@1iG3@0LETe06aD<01VCbd0I4d]069=;P1NBb/0EdHX05918`1<?BH0Bc`U
04Tm9`16>bL0@3PU03/d8P0g<1h0=2hN03@^8P0a;B40;RXN02/Y700X:A/0:2XL02L[700X;1d202HW
7`0402DV7P0T9Ad08b@L028S6`808B8J0P0O8Ah201hP7@807AlL0P0L7Q/301hQ6P<07b8K0P0P8a`0
1P0S9Qd08B@M01hQ6P0L7QT06Q`I01TK6P<06AXL200J71/201`N6@0701dP6@0N8AP08B@I02@X6P0W
:ad0:BdN03Le7P0303Pf7`0<03Le7P0d<Q/0<S0I034_600d<RD0:RXN024Q5@0L7Q<07B0G01hS700M
91d072<L0P0V9al302DV7P<092DM00D092HK02<U6P0P8AT07QlI01dN6@0201hN700301lO7`0M81T0
7B0I00H07B0I00<07b4N01hP7@0M7a`00P0L7Q/00`0M7a`07R0M01lQ7P0201hQ6P0F01lQ5P0S91H0
:RTG038_700i=b00?cXT03hh5P12>A`0ACTQ04`k9`1G@bX0JE<^07aV=@2:M3/0V7U:09QgA02UODX0
/h]H0:^6F@23JD@0FDT_048g8`80;2TP00H0:BTQ02LX8P0V9b8092HS024V8P0Q9B@202<U8P<092HS
0`0U9b@05P0Z:b<0:b`T02//900X:B409BHN02HW7`0/;BD0<C8Z03@a8P0a;Ql0;b/O030/8@0b;RD0
<B`V02`W8`0W8Qh092DO02DV800V9b40:2TS02X[9@0/;BL202h_:@80;RlO01<0;BhN02h_7`0_<200
<S<S03Df9P0f=bL0DchS05a4:P1SBbl0HdX/06159`1QA2@0JDX[071B<01]DBX0M5Pa07YN=P1lHCH0
NEha0080Me`]0P1iGbh02`1nHCL0NE`d075E;@1/Db/0JU8/06I@:`1PBBL0F4@Q04Pm:`17?2X0ACXX
0080@cPV00`0A3TW04Dj:016>bT0BcXZ04/j:01<>bT0C3/W04dm9P1>?RD0CShT04lo9@1B@b@20552
9@0305519`1@@2L0CclX0080CchZ0P1>?RD204lo9P0405109`1A@BP0DD4X0551:0P0CShW00<0AcXW
04Pk:019?2T00P1;?R/02`1:?BX0BC`Y04Pk:015=BH0ASHW04Dh:014>2P0@CPW03hg9@0l=B<0>C@Q
0080>C<U1P0j=2H3038`8`80<BlR0`0`;R43030/8`03034]900b;RD0<blV0080=30W00<0<blS038^
8P0a;B400P0a;B400`0c;b<0=C4U03Hb9P0203<a8P0303Db8`0g<B<0>C4T0080>S0T00L0?C4U03h`
9`0m<2L0?S8V03dc9`0m=2D0?CHT0080?SLT00P0>cDU03Tc9@0e<R<0<blS038`900`<2H0<34Y034b
:P80?CHT1P0l=B<0600h<R@0>C4T03Ta900k<BD0?S8V044c:014<bT0AC@Z04dn8@1>?b80Cd0S04`m
801:>ah0C3dP05939P1HBB`0JE0X06I>:01RC2L0FdTU05I69@1DABH0D4DW0515:@80DdHV00D0E4LW
05I7:01JAbT0GDP[0698;@0206A9;P0805Q7:@1GARP0E4DX0553:01?@bT0D4@/0516;@1AAS0204i2
;080CD4[03`0C40Z04/o:@1;?bT0BclY04Hn9`18@2T0Bd4X04`n8`1;?1l0D3dM05Q48`1OBbX0IdTU
06E9901SBBP0H4LX05a7:P1JAR/0ETH/05I6;@1OBB80HT`U06UB:@1`Ebh0MU/`07QK;`1jFbl0NEX/
07EO=P1aGSH0K5Xd06EG=01MDS80EDha055<;`1>BRl0Cd@b04a1;@1:?RP0BCdU04do901B@bH0F4LY
05];:P1VDb/0JU@[06iG;@1gG2l0PV<d08a[>02ELCd0VWE00:5i?02VOT00[HM80;F?D02gU580^IID
0;JEDP2eU5420;6EEP0F0;2DE@2_Te@0[Y9C0:fADP2/T540Zhm@0:^EF@2ZTUH0YheD0:J8DP2VQE80
ZHEE0:f7F02`Qe/0[XM@0:j7CP2_R4d0[hU;0;2:B@2aS4P0/Ha60;:=AP@0]i1;102hTD`20;RCC@0>
0;NBC02fTD/0]I1:0;B?B@2cSTP0/Xe70;><B`2bRT`0[XQ90:V5A`2TPTD0WWi309]k@P2INT4209E`
>`0G09E`>@2ELCL0UG4e09Ea=@2ELC<0UG8b09]]<P2FJC00T6D^08eT;P28Hbl0Pel]07YH:01cDb@0
JU0e06U><@1YBbl0J4/]06]<;@1`Cbh0ME<`07QF<`21I3X00P23ISX01P28JCX0S6hj099c>P2GMcX0
W7Xj09el>@80Xh4j0100Xh0l0:9o?@2ROcl0XGdo0:5m@@2PO400W7a309Yj@@2FMSd0Tg<j099b>@2C
LcX0UGDl09Mg?P2FNS/0TGDf0P2=LC805`2AMCH0U7Pi09=g>02@M3D0UgPh09Qi>@2JNcX0WGhk0:22
?02RQ3`0Y8Hn0:F7?P2VQ3`0YhDn0:N6?`2UQd40XXE109b1?P2GNcX0TWTg09Ee>02DM3L0Tg<f0080
TG4d00<0TW8e09Ad=`2EMCP00P2DNCH0102ENSL0UW/h09Ml>@2HOCX209Un>`0809Uj>@2KO3`0V7`m
08if>P21Jc80MV8]071P;01`H2d8079N:`80MUl]00<0M5h/079N:`1_GRX00P1]GBT0@`1ZGBP0L5//
071K;01aG2d0Leh_07AO<01fHC80Mf8c07QS=01eH2/0MV4/07MR;@1iI2l0NVD`07aW<P1mJ3<0OVTd
07MW;01fIR/0Mf@/07MR;@1hHBl0Nf0a07aQ<P1nHCD0V6lk0:=iA`2cSEh0aZ5e0=>aR`3I^iT0g;nQ
0=_0X`3I`JD0el2Q0=BmWP3D_Id0e;fK0=2jU@38/X/0`J^40;ZNKP2cUfL0YXYJ09UmC@2CMdL0VGe=
0:N;F`2cUfL0aJR00<^]Q`3A]I00e;ZI0=JmW`3J`ZP0hLVa0>G?^03Re/X0i=S:0>OJbP3Yg<T0jmc5
0>[J`03We[X0iMBf0>C?/03Qc:d00P3MaZH02`3I`Il0ekfJ0=RlU`3I_IP0fkfG0=ZiV03K^YT0g;^H
0=flV@3N_YP0h<2J0080hL6J0P3K_IT20=bnVP0Z0=^mV@3H^YH0e[RD0=BfTP3B/X/0d;290<f]Q039
ZWh0a:Eg0<2QLP2mWfd0_9i/0;RFIP2cTF40[8YJ0:>1D@2JN4P0Tg5108m]?@2=Jc/0PVPg07mT=@1l
H340MUT]07AD:`1aDBX0L4hY06m=:01UCB/0I4`Z0699:P1OARP0GD<X05Y09`1H?RD0EcdV05Lo9`1F
?RH0ECdU05@l901C>b<0DSXR0P1A>B4204Ph8@0304Lg8016=Ql0ACDN0080A3@M00@0@c<L048a7@12
<Ad0@c8N0P14<al204Dd800904He8@11=R00@3DO044e7`10=1h0@S<N048a7@13<Ad0@S0L00<0@38H
0P11<aT3048d6P<0?c0M0P10<Ah3044b7`0@03hb6P10=1`0@SHN04<g7`14>200@cLO048f7P11=Ad0
AC@R04He8`18=b<0BCTR04Ti8019>Al0AcLM04Hg6P80C3HN00H0CCLO04hh801?>B40D3XR054k8`1B
?2@8050l8`80CSXO00<0D3/P058j801D>R400P1E>B400`1H>R80DShS058n8`06058n8`<0FD8S1P1H
@B8305M08@80F44R0`1I@R<0201K@280GD0R05`o8@1M?R40H3hR06=0901V@BH0Id8W0P1VA24206E3
800406I48@1XAR<0JdTV06a:9`80JD/Y0P1ZC2X0101[CB/0K4h/06e?;@1]Cbd206e>;`0306e?;@1]
Cb/0KDlY0080KU4Y00X0KU4W079?9@1cD2H0M54W07EB:01fDbT0Me@Z07QE:`1iER`0NUP[0P1kFB`0
0`1lFRd0OE/^07iL;`0207mM<003081K<@21G380PUdc0080Pehd00h0PUdc085L<P20Fc40O5T_07eJ
<01nFc40Oe`b085N=022GcD0Pf0f08AQ=`26IC00QF@_08=R;@80PV4/01H0Pf8]08AS;P25I2l0RUle
08]P=P2<HCH0SV<f08mU=@2AIcD0TVPf09=Z=P2<Ic80SFPd08mZ=P2@JST0TF/l091Z?@2>Ic`0SFHk
08m[>@2>JSP0SFTg0P2<J3H01@2=JCL0SVXh08m[>@2DJSP0TfTg00<0TVPf00P0U6Xh09I/>P2HKS`0
T6Xk099/?@2DKSl0UW1109Ma@P80UW1100l0UFm009E`?02FLCd0Ug8n09Qc?`2JMD40VgI209ag@`2M
N4@0WWU409mjA@2PNdH0XGa70:9mB02TOdX00P2UP4/0302SOTL0Y7m80:AoBP2UP4`0YX1?0:N1DP2X
PU<0Z89E0:F0B@2VPDX0ZHA?0:^6DP80[HMF00<0[HMH0:b6E`2/QUT0202^RUH20:j<G0060:n=G@2a
Sel0/Y1P0;BBHP2eTf<0]YAT0P2dTV@20;>AH`<0/Y1R00<0/HmQ0;FCI@2dTV@00P2dTV@20;>AH`80
/Y1R202bSF470;:>GP090;6=G@2`S5`0/XiN0;B@H02eTF40]Y9R0;FAH@2dT600/hmO0080]i=O00@0
]Y9N0;FAG@2dT5`0/hmK0P2bSUX0102aSEd0/hmO0;FAH@2fTV820;NCH`80]I5Q00@0/Y1R0;>AH`2c
TF<0/i5S0P2dTV@20;FCI@080;B@G02eTEd0]i=O0;RDH02iUF40^9AP0;NCG`2fTUh20;RDI0030;VE
I@2jUVH0^YIV00<0^iMW00<0_IUU0;bHI02lV6@00P2kUf<20;ZFHP0:0;VEH@2kUfL0_9QX0;fIJ@2n
VVX0_IUY0;bHJ02jUVH0^IEU0;^FHP80^YEQ0P2iU6020;RCG`030;NBGP2jUVH0^YIV0080^iMW00@0
_9QX0;fIJ@2mVFT0_IUY0P2oVVd01P30Vfh0`Ye`0<BOLP35X7<0aZ5d0<NRM@80a:5g0P35XWP01036
XgT0ajAj0<RUN`38YG/30<VVP080bZN1103;Z8880<ZWO`P0c:V12@3?[8830<j[P@@0cJZ0203<ZGl2
0<j[P@040<fZP03<ZGl0c:Uo0<^XOP80bZMm00<0aZ=i0<NTNP37Y7X00P38YG/20<VVO0090<ZWO@3:
ZW/0bZYk0<VWN@39Y7L0aj9e0<JPL`37WW80aYea00P0aJ1c00<0`Ia_0<:ML034Wg800P35X7<00`34
Wg80`Ye`0<6LK`020<6OL@<0`9i`0`2oWFl30<>OK`030<:NKP31WFd0`Ie]0080`9a/00<0_IQ[0;jI
K030Vfh00P31W6l00`30Vfh0_YU/0;fHJ`020;jJJP<0_IUY0`2lV6P00`2jUV80^iMS0;bHI0020;fI
I@030;bHI02jUV80^IEQ00H0^9AT0P2gTf<40;JBGP@0]i=O1`2gTUh00`2hTel0/hiI0;>>F@070;:=
F080/HeM00<0/8aL0:n;F`2^RUX00P2]RET00`2/R5P0[HQA0:j9DP020:j9DP80[hYC0P2`Re@30:f8
D`<0[8MB0P2[QU400`2/Qe80ZhIA0:Z5D0020:R3CP0<0:V4C`2ZQE00ZhIA0:f9C`2/R4h0ZhI?0:^6
D@2/Qe80[HQD0:n9F02`RUT0[XYF0P2]RED00`2/R5@0ZhMC0:Z6DP020:V5D@P0ZHI@202/R5@01@2]
R5<0[8MB0:b7DP2[QU40ZXE@0080ZHA?00@0Z8=>0:EoCP2UOdh0YGm>:oooool002[ooooo0P2RNDD0
2@2SNTH0Y7]70:ImB@2WOTX0Z7m;0:V0C02TNdL0YGa80:ImB@020:MnBP030:ImB@2UO4P0Y7]700P0
Xgi9202TOdX30:ImB@<0Ygi:0P2XOd/20:ImB@80Ygi:0`2XOd/00`2YP4`0YWa:0:IlBP020:MmB`@0
Z7i<0P2XOd/30:V0C0<0ZX5=0P2YP4`20:QoB`80Ygi:102VODT20:MnBP80YGa800<0XgY60:5hA02O
MT800P2ONTH01`2NNDD0W7M309]f@P2JMD40VGA009Qc?`2JL3h00P2IKcd00`2HKS`0Ufdk09I/>P02
09E[>@0608iY=@2=J3@0SFPd08aW<`2;IS80RVDa0P29I3004026HS00QF4_08AP<023GS40PUda089M
<`23GS@0Pedf07aM;P1kG2h0NU/]07UJ;P1gEbh0MUH_07EE;`1dE2h207AB;003079B:`1`Db/0Ke<[
0080K5<Z00<0Je@Z06e<:@1^CBX00P1^CBX306m>:`0:071?;01aCBT0LThZ07=@:P1eDRX0Me@Z07QF
:@1jF2/0NeT[07eJ<080OU/a00<0Oe`b081M<`21GS@00P22GcD808]U=P0508eW>02>J3T0SfTj091Z
>`2AJc`00P2@JS/0102?JCX0T6Dj095V>`2CJ3d209AY?P0309=X?@2AIS/0T6Dj00<0T6Xk0`2?JCX2
08iX>@08099V>@2@ICP0Sf@g08iU=`2=IcP0SVXj08i/?02@KSh308iX>@<0SFLh0P2<ISL808eW>0P0
T6Dh202@JSd4095V>`@0TVLl00<0TfPm08iX>@2>J3T01P2>J3T8099W?0P0T6Xm00P0TFdm091/?02?
Jc/0TFdm09=_?`2BKSh0Sf/k08]W=`80TVdi00@0TF`h091[=`2@JcL0TF`h0P2BKCT808iZ=P0808eY
>@2>JSX0Sf/k091/?02?Jc/0SVXj08aX>02:ISH808eY>@<0S6Ph0P2;IcL308YV=PP0RfTi2026IcP0
8025JCL0Q6Pf08=W=`21ICH0OV4e07aO=@1jGCD0NE`d07=I=01^E2l0J50/06E>;01RCRd0Gd`/05Y7
9`1C@R@0CClU04`m9P19?BD0AS/U040h8`0k=240>34O03D`7@0d;R80<BdQ02hZ7P0[:A`0:2TK02PZ
700W:a`0:2`M0P0V9al0100U9Qh092DM02<T700R8a/2024R6P807b4N0P0N81d201dO708071hK0`0N
8AX301lR6`8082<L00H08bHM028U7P0O8Q/071hI01XL6@0I6aX201TJ700301XK7@0J71/06Q`K00H0
6Q`K00X07AlJ01`N6@0M81T07R4H020S600S9aT09RXL02P/7@0c<A`0=38M0P0f=1l0300e<ah0<c4L
034_6P0_;AP0<c4T02d[7`0T91P07R0E01lP600O8Q/07R<M01dR70809RLO0`0U9Qh302@U7@0502@V
6`0S9AX0824I01hO6@0M7QT00P0N7Q`00`0O7al07B0I01dP6@0601dP6@0301lQ7P0N81d07AlL0080
71hK01/07AlL01hP7@0O8Ah07R0K01hQ6P0O81P08R8F02TW600a;Q/0=cDP03dh8P11>a/0@cTN04@h
8P18=b<0DShU06A=:`1iHc80R78i095eA@2DM4<0XWe90;>;E`2^RUX0SG5:06=@<P16>R800P0/:B00
1P0Y:B409bPR02HW8P0U9b@08bPT02<W9P<09BLT0`0V:2D202LY9P0@02TZ8P0[;2@0:b`T02PY8@0U
9Qh09RLO02//900a<RX0=C8S038_800`;200<BdR03<_9P0b;BL0;BPT02PS7`809RLQ00@09bPR02PY
8`0Y:R@0:R/U0P0[;2H05P0^;b40;BhP02d^800];R00;RlQ034b900c=2H0=CHX04/i8@1D@2L0G4P_
05i9;P1LA2P0GTDW06I;;@1^DcD0JTd[06mC;P1dF3<0MUXc07AH<01aER/3075F:@0;075C;@1]DBX0
JDdX06A:9`1RBRH0GTLU05M38P1C?ah0B3d[04Hk:@15>RP00`13>2H02014>BL0ACXX04Xi:@1:>BL0
BcXX04`k9`1=?BH0CShU0P1??bD0201B@b@0DT<V05529@1??bD0CShU04dm9P1<>bL0BcXV0`1??bH2
05109`<0DD4X201>?RL00`18>bP0BC`Y04Xm:P0204/n:`0;04Xm:P18>bP0AcXW04De9P16=RL0ACPX
04@h:011>2L0?SLU03`e8`0i=240200j=2H203@`9080<blS0`0b;R800`0a;B40<RhU038^9@06038^
9@0303<_8`0b;R80<BdQ0080<BdQ00<0<blS03Da9@0f<RH00P0d<R<00`0e<R<0>38T03Ta900203/a
9@0703da9@0o<RT0?c<W040d:011=BL0@SHV04<h9P0204@i9@0803df9P0l=BD0>C<U03Da9@0c<BD0
<C4W038b:00a<RX303dd8`D0?SDT01P0>cDW03/c9P0j<RD0>S0T03da9@10<RL0AC@Z04Lf;01>?R@0
CclU05109P1>?R@0CCdS04lo9@1FAR`0G4`b06iH<`1YEC80He4]05i;:P1GB2L0E4DV05949`1?A2H3
05E69`0>05M6:01KB2X0GDP[0618;01RB2d0HdT^05e::P1LBBT0F4LY05E6:@1CABX0D4@Z0514;01?
AB`30514;080Cd<[0`1>@RX0>01;@BP0C48Y04e19`1<?R<0Bc`O04dl7P1D@B40F4DU06E;:01UBbX0
Hd/Y065::P1NBBX0G4T[05]7;01HAb/0FdDP05i88@1VCRP0KUD]07IJ<P1jGC<0OUlc07mP=01jICX0
N6<h079P>01]GSL0IUTf05mF=@1IDc<0EU4c0518<@1?Ac00CdD/04i2:01@@RL0Dd@W05A5:01GARP0
GddY065?:@1WDBX0KeH]07ML;`22Hc@0RVPh08i]>P2NNCD0Xghj0:V7@02aSdL0]iE=0;ZHCP2jVD`0
^IQ;0`2cU5@50;:CD`0@0:fCEP2ZT5<0ZHaB0:J7D02UQ4h0Z8A@0:Z4D`2[QE@0[8Q>0:^7C@2[Qd/0
ZhM90:Z7A`2ZQdD0ZHI40:V6@P<0/XY<0`2aRD/20;::C0060;N=A@2fS4@0]Xa40;F;@`2dRT80/hU1
0P2bR4003P2^RD80[HQ20:V7@02UQ3l0XX4n09en?@2INc/0V7Xj08mZ@02>JCl0SFPl08aW>P2;IcL0
RfLe0P2;Ic<04@26IC80PV0`07eM;01jFb`0Me//079G:P1ZDRH0I4`P06=A;@1RD2`0I50[06UC;01^
Ebh0ME`c07]R>@21IS/0S7110080Sg110140TG=109Ae?`2HN3l0WG/n0:1l?P2QOSh0XX0i0:5o>02P
OCT0Wg`j09ik>`2LN3X0W7Pl09]g>`2GMch0UGDl099b>@02095a>005099b>@2EMC`0UgLn09Ah>@2A
MCH00P2>LS<0302AMCH0U7Pi09Ah>@2CMcP0V7Pk09Ui?02KO3`0WGhm09n0?@2RQ3h0XhDm0:B6?P80
YhDn00T0YXE00::3@02MP3h0UWXi095e=P2;LS80Tg<f099b=@2ALC@00P2@L3<04`2ALC@0TW8e09=c
=P2AMC@0TWHe09=g=P2DN3L0UWXi09Ql>`2JOSd0Vgln09Yk>P2HNCT0TGDf08A/<01hHRT0L5`W06]K
9`1/G2T0201bGR/207EN;00307=M:`1aGBX0KUdY0080K5`X00T0JE`W06eH:@1^FBX0KeX[071K;01a
G2d0LUd^07=N;`1dGc000P1gHRd0>01hHbh0NVD`07]V<@1lIc80OFPc07iY=01hIbl0MVD]07IR;@1e
Gbd0MEd]07QM<01iGS40NUdc09A[=`2PMT@0/H]L0<FPM03B/8X0fK^I0=boX@3K`:<0f<2T0=JoX03D
_Ih0e;fM0=BmV`3?^I@0ak6:0<2ZP`2gVf/0/9AT0:B8F02HO4`0TgM709]oC`2ZSUh0]i][0<JXPP3;
[hX0d[FC0=FjW03G_J80fl>[0>7;]03WdK`0hmO90>KIb@3XflX0jmc70>_K`P3Yf;`0imBf0>CA/@3Q
bZP0g/NU0P3I`Id01@3E^iH0e;RA0=BgS`3F]Xl0ekN>0080f;RA0P3I^I820=ZjT`80fk^D0200dkFA
0=BfTP3D]Y80e;JB0=:dT03@/Xh0cJn;0<^]R@3:ZX<0b:R10<FUO030XGD0^ia^0;JGJ02bU680/99P
0:^9F`2WQEL0X7i@09MeA`2?KCl0RFLi08ES=@23HC<0NUda07QK;`1cER`0KU4Y06Y<9P1WBBD0IDLS
06E79@80GDHV00H0Fd@U05U19@1G?bD0EShV05@l901C>R@2050l900404lk8`1>>R80CSXR04di8@80
C3PP0P16=Ql01015=Ah0A3@M04<c7013<a`2048b6`@0@2lM0P11<1h2048a7`80?3@O00<0?C8N03ha
7P10<Ah00P10;ad01011;Qd0?30H03``600l<1P203da6@<0?S8J0P0k;Qd203`_7P80?C0O0P0n<B00
1@0n<QX0?c<K040d7011=Ad0@SHN0080@CDM00X0@3@L04@c8`15=280ASDS04Lf8P18>240B3PO04Lg
7@16=Q`0BSHN0P1;=al01@1<>200CCTQ04hj8P1>>R80Cc/S00P0C3XR00P0BcXP04di801>>R40CcTQ
058j8P1C>B80E3PR05Di8`P0DCdT0P1I@BD01@1H@2@0EclS05Lo8`1G?b<0EShR0080ECdQ101D?202
05Dm8@0805Hn8P1G?b<0EchP05Tn8@1K@2<0GT0T06119@1R@2D206<o9@80HT4P0P1Q@1l0101R@B00
Hd8Q06I5901WARD806U;:@0506U::`1ZBb`0JT`Z06]=:@1[CBL00P1/CbL02@1/CbD0L4dU075>9P1b
CbL0M54Y07EB:P1gE2`0N5D]07UF;P0207UF;00407YG;@1kF2h0O5T_07eJ<080OU/a00<0OUT_07mJ
<021G3800P22GC<00`21G380OeX`07iI;`0207eJ<00407iK<@20GC<0PEhd08=P=P80Q64g00<0QF@_
08AS;P23HRd00P22HB`04@23HRd0Q6<^08ET;`2:GcD0Rf0f08aQ=P2=HSD0SfDe091V=02AIcD0TFPd
08aW<P2=J3@0SVTe08iX=`2>J3T0SFLj0080S6Dj00<0SFTi08aX>02;IcL00P2:ISH01@2;IcL0S6Ph
08eY>@2CJCL0TVPf00<0TFLe00L0TVPf09=Y=`2DJSP0T6Xk099/?@2DKSl0UW110080Ug5200X0UW11
09E_@02DKc/0UG0l09Ia?@2GLSh0VGA009Ye@@2KMT80W7M30P2MN4<04P2NND@0X7]60:5lA`2RODP0
Xgi90:AoBP2RODH0Xgi70:=nB@2TOd/0YGm>0:J0D@2WPE80Yh5D0:=nA`2TOdP0YX5<0:R3C`80ZXAC
0P2ZQ5D00`2ZQ5L0[HUE0:f9E@060:f9E@060:f;F`2^S5`0[heM0;2>GP2aSel0/i5Q0P2dTV830;:@
HP<0/HmQ0P2`SV00102cTF<0/Y1R0;:@HP2bT6820;6?H@80/8iP202_RUd80;2<G0040:f9F@2_Re/0
/HeM0;B@H0<0]I5Q00L0]91P0;JBGP2eTEd0]I5M0;B@G02cSe/0/XiJ0080/HeI00<0/HeM0;:>GP2d
T6000`2eTF420;B@H0<0/HmQ0P2bT6830;>AH`030;B@G02eTEd0]i=O0080^IEQ00<0^9AP0;NCG`2f
TUh00`2hU6@30;VEI@80^YIV0`2kUf<20;ZFHP<0^IEQ00<0^IEU0;ZFIP2kUfL00P2kUfL0102iUFD0
^9AT0;JBHP2hTel30;NBGP<0]Y5M00@0]I1L0;RDI02hU6@0^9AT0`2iUFD20;ZFIP090;bGJP2mV6/0
_YU/0;nJK@31W6l0`Ye`0<>NL@34Wg80`Iid0080`Yme00<0`j1f0<BQM`35XWP00P36XgT30<NTO080
b:Em1039YWh@0<ZWO`X0cJZ00`3>Zh430<n/PP/0c:Uo1@3;Z7h01038YG/0bJIl0<VVO039YW`30<ZW
O@090<^XOP39ZGX0bJUj0<RVN039Y7L0aj9e0<JPL`37WW80aYea00P0aJ1c00<0`Ia_0<:ML033WW40
0P34Wg801033WW40`Ye`0<6LK`31Wg430<2NL080_ie_0P2nW6h01033Wfl0`Yi^0<:NKP32WVh30<6M
K@040<2LK02nVF`0_YU/0;nJK@80`9]^00@0_iY]0;jIK02nVF`0_YYZ0`2mVFT20;bHJ080^iMW00P0
^iMS0;bHI02mVFD0_IUU0;bHI02jUV80^9AP0;NCG`D0]i=S0`2hU6@80;JBGPP0]Y5M00D0]8mJ0;>>
F@2cSUT0/XeH0;6<E`030;2;EP070:n:E@2aSEd0/8aL0;2<G02_Re/0[XYJ0:f9F@020:b8F0<0[HQA
0P2^RE830:n:D`80[HQC0P2/Qe820:^6D@80ZXE@00<0[8MB0:^6D@2YQ4l00P2XPdh02`2YQ4l0ZhIA
0:b7DP2/R4h0ZhM=0:Z5CP2YQ4l0ZXE@0:^6DP2]QeH0[XQG00P0ZhMC202YQU080:Z6DPD0ZXE@0`2Y
Q4l30:J1CB_ooooo000Zooooo`80XGQ400H0XgY60:AkA`2VODT0Z7m;0:V0C02ZPDd20:ElB0@0YWe9
0P2UO4P80:EmB@P0Y7m:0`2VODT30:MnBP80Z7m;0`2VODT20:MnBP<0Z7m;0P2WOD/60:QnC080Z7m;
0`2YP4`50:Z1C@80ZH1<0`2XOd/30:MnBP0=0:QoB`2WOTX0YGa80:ElB02RNDD0X7M309ie@@2ONTH0
WWU509ehA02LMd<0VgI209Ud@00209Qc?`80VFlm00<0V6hl09M]>`2FK3X00P2EJcT02@2DJSP0SfTh
08mY>02>J3L0S6He08]U=02:I3<0RF<b08QR<@0208AP;P0>08=O;`23GS40Pehb08=N=024GcD0Q5hg
07aM;P1kG2h0NU/]07UJ;P1gEbh0MUH_07EE;`1dE2h207AB;003079B:`1`Db/0Ke<[0080K5<Z00<0
Je@Z06m>:`1_CR/01P1_CR/0201`C2P0LDdY079?:@1dDBT0MU<Y07QF:@1iEbX0NUPZ0P1lFBl01P1m
FS00Oe`b081M<`21GS@0PUle08=P=P<0RV@e102;ICH0102<ISL0SFLh08iX>@2>J3T208mY>P<0T6Xk
00<0T6Dj095V>`2BIc`00P2DJCh00`2BIc`0TFHk091U>P03095[?0D0T6Xk00P0TfLj095V>@2@ICP0
SVDg08eW>02>JSX0SV`l08m]?@<0SVPi0`2=IcP208aV=`P0SFLh202@ICP8091Z?@80TFHi00<0TVLj
09=X>`2DJC`00P2DJC`209EZ?@P0SVPi202AIS/308mY?0@0T6Xm00@0TF/n091/?02@K3`0TFdm0P2B
KSh0102AKCd0SVXj08aX>02AK3P6091[=`03095/>02>JSH0SVXf00H0SVXf00P0SFTi08iZ>P2?Jc/0
T6`l08m[>`2>JSX0S6Ph08YV=PP0SFTi0`2<J3P208]W=`<0RVHf102:J3P408]Y>@0308MX>@26IcP0
QVLh0080QVLh0`25ISL08024J3H0PfLe089V=P20I3D0OV4e07aO=@1kGSH0NUde07IJ<`1aEBh0JU0[
06I>:P1UCR`0HDd/05a7:01F@b<0Cd4V04i09P1:?R@0AS`S040h8@0l=R00>C8O03Lb7P0d;R80<BdQ
02hZ7P0[:A`0:2TK02PZ700W:a`0:2`M0P0V9al0100U9Qh092DM02<T700R8a/2024R6P807b4N0P0N
81d201dO708071hK0`0N8AX301lR6`8082<L00H092LN028U7P0O8Q/071hI01XL6@0J71/301XK7@P0
6Q`K0P0M7aX05P0M81T07B0G01lR5`0R9QP09BTK02L[700_;1T0<BhK03<`7@0e<Ql0=34N038_700_
;1T0;R/H03@`900`;240:BLK028R600O81P0824K01lQ700N8ad202HW7`<09BHN0`0T9Ad01@0T9Q/0
8bDJ020Q6@0N7aT07AhI00807QhL00<07alO01dP6@0M81T01P0M81T201hP7@@07AlL0P0N81d0800O
8Ah07R0K01lP6P0R8QP0:2HI02l/6`0e<Ql0>cHR04<l7`14>R40@SDR04@c8@1=>B40GdPX07AN;`24
KCL0RG51095c@@2ONdL0/HUE0;6=F`2GNU00KUXi04m19P0^:b80;BXQ02XZ8P0W:2809RLR02DW900T
:BD09BTX0`0V:2D302LY9P80:2XW00@0:2TQ02X[8`0[;2@0:BXR0P0V9al02P0[;2@0<34Y03Hc900c
<240<BdQ038^8`0d<2L0<bhX02hY9@0Y920302LX8PD0:2TS00`0;BdQ02`/800/;200;2`P02d]8@0_
;b<0<C4U03<c9`16=b00CSlX05I6;@1GAR`205E19P0905e8:`1TCc00I4XY06M=;01[DBh0KE<`06aB
;@1ZDBT0J4lV0080IdhU01H0Id/V06A:9`1RB2D0H4PV05e69P1H@b@0Dd0R050m7`17?2X0AS/Y04@i
9`13>2H0@SLU04<h9P14>BL0ACXX04Th:019>2H0BSTW04/j9P1=?BH0CShU0P1??bD0201B@b@0DT<V
0511901??bD0CCdT04/k901:>BD0BCPT101@@2L40551:0P0CShW0140BC`Y04Xm:P1;?R/0C3l/04/n
:`1:?BX0B3/X04Lj9`15=BH0ASHW04Dh:014>2P0@CPW03hg9@0l=B<0>C@Q03/e9`0403Xd9P<0>C<U
0P0g<BD203H`90<0=BlS00<0=2hR03@`9`0c;bH00P0c;bH3038^9@03034]900c;b<0<RhR00<0<BdQ
00<0<blS03Da9@0f<RH00P0d<R<00`0f<b@0>38T03Ta900203/a9@0703da9@0o=BT0?cDY048f:013
=bL0ACPW04Tj9`0204Xk9P08040g9P0o=RD0?CHV03Xd9P0g<bL0=C<W03@b9P0b<RP203dd8`@0?SDT
0P0o=RD0600n>2P0?CHV03Xc8`0j<B80?C4S040b9@16=RT0B3P[04hn901@@2H0DD4W04lo9@1>?R@0
DD4W05M7;@1NCS@0I5@c069B<@1NCRd0FDXY05I7:01DABH0DTDU05949`80ETDW00D0FDHX05Y7:@1K
B2X0GDP[05i9;00205m:;@08065=;01PBb`0GDXZ05U8:P1FAbX0DdDZ0514:P1?@bT305A6;0D0DdD[
00h0DT@Y0553:01?@BH0CClT04`m801=?R40Cd0S05919@1TBb`0HdX[069;:`1RBb`0HDX[05i9:P80
GTT/02P0GDHT061:9@1UCBT0K58]07AH<@1iG3@0Oelf081P=`1oJCX0OVPi07YW?01eISd0L68m06YP
?01SGC/0HE/i05aF?01KEC/0FU<g05Y@=@1ICC<0FT`a05U;<01JBS00FDXY05];:P1PCRX0Ie4/06iE
;@1fFc00OUla089Q=02FMC00VgXc0:B2>P2/RT00]I530;VFA@2kUTD0^iM30P2fUE80102gUU<0^9MD
0;VHE@2iV5D20;ZIEP0@0;>DE02aTU80[XiA0:^;D02[R500ZXMA0:^8DP2[Qe<0ZhQ>0:Z7C@2YQdX0
Z8I90:J4A`2UPd@0Y8930:>1@P80ZH9700L0Yh150:IoA02VOd@0YWm40:N0A@2XPDH0[X8i0080[H4h
0P2/P3L20:]o=P0?0:Yn=@2UPCL0XX0h0:20=`2NOCH0VG/e09Ii=@2CN3D0TWLd08YWA`29Id@0QfE2
08ES?P23HC/0Pf8i0080Pf8g0100Mf0f07=L<P1^FBh0KUP_071J<@1]FS00J5D[06AA:@1XFbh0JE`_
06aN;`1aH380MfDe07m[>@25LCh0RG=10`2EMd<01P2FMd40UgI009Yg?@2MNCd0XG/m0:9l?P80Wgdf
0100WGXf09ai=`2JMcL0V7@f09Mc=`2FLSH0TW8i095a>02@L3L0Sflf091`=`2BLST0U7@k09If?@2C
MCL0TG<e0P2@LS@0302BM3H0UGLi09Ih>P2GNC/0VWXo09]k?P2LO3l0WGhn09n0?`2QPSl0XX@n0:>5
?`80Xh0l00h0XH0m09en?@2HNSX0TgLh08ib<`29Kc80Sg4e08i`=02=Kc<0S6hb08e_<`2>L3@0T78f
095c=`<0T7@e00d0TWHg09Ah>@2GNc`0VWho09]o@02NOch0V7Ti08ea<P1oIb/0M5hU06iJ9@1[FbL0
K5`Y00P0LEdZ00T0M5d[07=L:P1bG2X0L5`Y06eL:01[FbL0JUXV06QK9P1^FBX00P1_FR/01@1`Fb`0
LUd^07=N;`1cGRl0M5l`0080N6<^00@0NF@_07YU<01kIS40O6Lb0P1mJ3<0<P1gIS00MF@^07EQ;P1c
GB`0Le/]07EJ;@1eFRl0MeX`091W<`2MLd40[hUJ0<BOL`3B/8X0f;ZH0=^nX03I_Z40eknS0=FnW`3D
_Ih0e;fM0=BmV`3>^9<0aJn80;fWP02cUfL0[91P0:65E@2FNTX0TgM709b0D02^TV80^im_0<JZQ@3:
/8d0d[RG0=JmW`3H`:H0g<J^0>;=^03Xdl00iMS80>OJb@3ZflP0jm_40>[I_`3WdkP0i<n`0>7=[03P
ail0g<>K0P3I_ID01@3D]hd0d[>70=:aQP3C/XD0e;:50080e;>60P3D/hP20=BcRP80e;:<103>/8X0
703<[XP0bJ^50<JXPP35Yh40a:Am0<:RN`2nWWD0^IY^0;>DIP2^Sf00ZXaJ0:N9E`2QP5<0WGa?09Ie
B02>KD00QVDh081O<P1lFbh0NeX]07EH<01bEBd0KU0Z06Q<9`1TAbD0GdDR05i48`1MAB<205=08006
058o8@1A?B80D3`S04lk8P1>>R80CCTQ0P1:>28204Tg8@80B3HP0P17=Al204<d7`03048c7P11<Qd0
@34L0080?c0K00<0?RlJ03`/700l;1`00`0l;1`303d]7@80>34N00<0>30M03X_7@0k;Qd00P0m;Ad0
100n;Ad0>BhJ03T^6P0i;QX203X_6`<0>c0L100i;Ad203X^7P80>blO0P0m<A/00`0n<Q`0?c<M03lc
7@0303lc7@06048`8P13<R80A3<S04Dd8P16=B40ASHO0P17=ah204Le7`80B3HP00@0BCLQ04Xh8P1:
>280BSPR2019>B801P19>Al0BSTO04Xi7`1=>B00CSPP054i8@80DSPQ201?>b800`1I@BL0F40V05Lo
9@0205Hn900305Dm8`1C>b40DSXP00<0DSXP0`1A>Al03@1B>R00E3`R05Dm8`1D>Ql0ES`Q05Xo901M
@RL0H48X06109`1P?RD0GcdT06528`1P@B800`1O@2400`1Q@R<0Hd@U06A59P0306Q::080IdTW0`1V
B2H01@1VAbP0IdPY06M99`1XBRH0JD/U0080JTdU00L0JTdS06e;9@1^C2H0KddW075?:@1cDB/0ME<]
0080MeD_00H0Me@Z07QE:`1hEB/0NEH/07YG;@1kF2h207aI;`0307aG;@1mF2h0OeX`0080P5/a00<0
OeX`07eH;P1lEbd00P1mFS001`1nFc40P5dc085N=022GcD0Pf0f08AQ=`23HRl00`22HBh208=R;`80
Q6<`00D0REle08YP=P2:HCD0Rf8d08eU=00208iV<`0908mW<`2;IS40RfHb08]V<P2;IC@0RfDf08YT
=`2:HcP0RF8g00<0RF@g0P28HcH308UT=`80SfLf1P2>ISD0102@JS/0TF/l09=]?P2EKd0209I`@@08
09E_@02DKSl0Tfhj09A_>`2EL3`0UW4m09Mb?P2IM40209Ye@@80VgI100@0W7M209iiA02ONTD0XGa7
0P2RODP20:5lA@030:9mB02SOTX0Y7i=0080YGm@00D0YX1C0:5lA@2RODH0Xgi90:F0C0020:J0C`03
0:N1DP2XPU<0Z89E00P0[8QD00H0[8YJ0:f;F`2^S5`0[heM0;2>GP2aSel20;:@H0040;6?H@2`SV00
/8iP0;2>H080[heO0P2^S5h20;2>H080[heO0`2^S5h00`2]Red0[8QH0:b8F0060:b8F080[HUI102^
RUX20:n;F`060:^7E`2]RET0[h]K0;:>GP2dT600]I5Q0P2dT6020;>?F`80/XiJ0P2aSET20;2<F0<0
/XiN102cSel00`2bSUh0[heO0:n=G`020:n=G`80/8iP0P2aSf40202dT5h0]I5O0;NCH@2hU680^IES
0;RDHP2gTf40]Y9P102gTf<40;RDI0D0^IES0`2hU680202fTV80]i=S0;RDI02iUFD0^9AT0;NCH`2e
TF40]91P0P2eT5`60;B?F`P0]Y9R0P2jUFP0102kUVT0_9MZ0;fHJ`2nVF`20;nJK@80_Ya_00<0_ie`
0<2NL@31Wg800P32X7<01033XG@0a:5g0<BQM`34XGL20<FRN0@0aZ=i2039YWh80<RUO@P0bjQn0P3<
ZGl20<fZP0040<j[P@3?[880d:f30=2]P`P0c:Uo00@0bJIl0<ZWO@3:Ygd0bZMm0`3;Z7h00`3<ZGl0
bZMm0<ZWO@020<ZWO@@0bjQn0P38Z7T01P38YWP0b:=f0<JQM036X7<0aiib0<JML@P0aJ1c00<0`9]^
0<:ML033WW400P34Wg800`33WW40`Ye`0<2KKP030<2NL080_ie_0`2nW6h80<6MK@80_YU/102oVVd2
0;jIK0<0_IUY0P2lV6P30;^GI`080;^GH`2lV6@0_9QT0;bHI02kUf<0^9AP0;JBGP2dT5`20;JBHP@0
]i=S0P2hU6@00`2gTel0]Y9N0;JBGP020;JBGP<0]I5M00<0]Y5M0;F@G02eT5`00P2eT5`30;B?F`80
]8mJ00@0/hiI0;6<E`2`ReH0[hYE0P2^RE@01`2]R5<0/8aJ0:n;F@2_ReT0[XYH0:f9E`2/R5H00P2[
QeD30:b7D080[HQA0`2^RE801@2]R5<0[8MB0:b7DP2[QU40ZXE@0080ZHA?00@0Z8=>0:^6D@2ZQE00
ZHA?0P2XPdh01P2ZQE00ZhIA0:f8D`2[Qdd0ZXI<0:V4C@80Z8=>00<0ZHA@0:^5E02/QUD00`2YQE40
0`2ZQU80ZhMC0:b8E0020:b8E0P0ZHI@202XQ5020:N2C@<0Z8=>0`2YQ4l30:N2CB_ooooo000Zoooo
o`80X7M300H0XWU50:=jAP2UO4P0Ygi:0:QoB`2YP4`20:ImB@@0YGa82P2VODT80:AoBP<0YWe90`2W
OTX20:QoB`80YGa80P2VODT20:MnBP80Z7m;0P2YOdd60:QnC080Z7m;0`2YP4`50:Z1C@80ZH1<0`2X
Od/30:MnBP070:QoB`2WOTX0YGa80:ElB02RNDD0X7M309ie@@0209iiA@0709ehA02KMT80VWE109Ud
@02HLcl0Ug8n09U_?@0209Q^?00309M]>`2FK3X0UF/i0080U6Xh0P2@JS/01P2?JCX0SFLh08]U=P2:
I3D0RF<d08QR<`80Pel]00h0Q60`08AO<P24Gc<0Q5le08=N=023GCH0O5d^07]L;P1jFbd0NEX^07MG
;P1fERl0MED_07AD;P80M58/00<0LU8[071C:`1_Db/00P1/DbX00`1[E2X0L4l/071?;002071?;0@0
Kdh[00P0L4`X075=:@1bCbT0M54Y07IC:@1hERT0NELZ07YH:P80NeP^00H0O5T_07iK<@20GC<0PEhd
089O=@23H3H208US=080RV@e00@0RfDf08aV=`2<ISL0S6Hg0`2=IcP208iX>@80SfTj00@0T6Xk08mT
>@2AIS/0TVLl0P2CJ3d00`2BIc`0TFHk08mT>@05091Z>`<0TF/l00P0TfLj099W>P2@ICP0SfHh08eW
>02=JCT0SF/k08i/?0<0SVPi0`2=IcP208aV=`P0SVPi202@ICP8091Z?@05095W=`2BJ3P0TVPh09=Y
>@2DJSX00`2EJc/00`2FK3`0SfTj08mY>P0608mY>PP0TFHk0P2>J3/208mY?00:091Z?@2AJch0TF/n
095[?P2?Jc/0T6`l099^?P2CKcl0TFdm08m[>`80SVXj0`2?JSH2091[=`<0SfXf202=JCD0202=JCT0
SVXj08m[>`2@K3`0Sf/k08iZ>P2<J3P0RVHf2`2<J3P208]W=`<0RVHf00<0R6Hf08UW=`29IcL00P2:
J3P208]Y>@0508aZ>P27J3T0QfPi08MX>@26IcP00P25ISL208AU=P0P08=W=@22IS@0PFDe07mS=01n
HCD0O5le07]N=P1jGCD0N5/c07=F;P1]DBX0J4hY06M?:`1TCB/0GdPX05Q48`1@@RD0Cd4V04Xo8`16
?240@3TO03`f7P0j=1h0>3<M03@^8P0a;B40;RXN02/Y700X:A/0:2XL02L[700X;1d202HW7`0402DV
7P0T9Ad08b@L028S6`808B8J0P0O8Ah201hP7@807AlL0P0L7Q/301hQ6P<07b8K0P0P8a`01P0T9ah0
8bHO020S700M7aX06adJ01XL6`806Q/M00<06a`N01XL6`0J71/01P0J71/201dO6P0F01`O600M81L0
7b8G028V600T:1X09RXK02`Y600^:aX0<RlN03@a800e<R40<c0O02l/6`0]:QT0=BlS03</8P0]:Ah0
9b@K024Q6@0O81X0824L020R7@809RLO0`0U9Qh302@U7@0502@V6`0S9AX0824I01hO6@0M7QT00P0N
7Q`00`0O7al071lH01`O600601`O60807AlL100N81d201dO700P01lQ800N81d07b0K024Q6@0W9AT0
;BXK03<`7`0h<b00A3dQ04@i8`12=B@0@S4Q04Td7`1J@b@0KUL[07eV<P23KSl0S79109]jA@2/Qe00
]8mK0::3E@1kICh0FTXY038_9P0`;B@0:b/S02LX8P0V9b809BLT02@Y9@0U:BP302HX9@<09bTV0P0X
:RL0100W:200:R/S02`]9@0Z:b<202LX800:02//900_<2P0=S<T03@a8P0b;R80<blT03Da:00d;bT0
;bXV02XU8@P09bPR0P0/;2805@0[:b40:RXP02/[8@0];B<0;blU030`9P11>B@0B40[04m4;P1?@b/0
BcdS04Xj801@@2H0F4L[05e49P1OARP0HTTZ06E=:`1VCRX0IDdY069:900206188P0;06169@1PAbP0
HDPY05m8:@1JABP0ET8W05509P1??R@0Ac`Z04Hk:@14>BL00`12=bD04P13>2H0A3TW04Lf9P18=bD0
BCPV04/j9P1<?2D0CShU04lo9@1@@2H0DT<T05939P1@@B@0CclU04dm901;>b@0BSTU04Th90P0DD4X
201>?RL00`1:?BX0Bch[04`o;00204`o;00;04Xm:P18>bP0AcXW04De9P16=RL0ACPX04@h:011>2L0
?SLU03`e8`0i=2400`0k=BL00`0j=2H0>C<U03Tc9@0203Pb900403Ta9P0h<2D0>30U03P`9@80=blT
0P0f;R<303@`9`80<blV0`0b;RD00`0c;b<0<RhR034]8@02034]8@0303<_8`0e<BD0=S8V0080=C<T
00`0=S<T03Tc9@0j<RD0>c4U03`b9P0n<RH0?SLW040g:013=bL0ACPW04Tj9`1=>bL2050k9P0804@i
9`13>2H0@3LV03hg9`0l=RP0>3@X03Hb9P0d<RH203lc8`80@3@T0P11=BD2048f9P0H03hi9P0n=bD0
?3DS03`c8P0n<R80@C@T04De9P17=bP0CShU05109`1A@BP0CclV04dm901??bH0ETH]05a<<`1DBBd0
DTLY05=5:01A@bH0DD@T0593901CA2D0E4DV0P1JABP205]6:@0=05a7:P1LBB/0G4T[05e:;01KBR`0
IDh/06A=;@1QCB`0GT/[05U8:P1FAbX0DdDZ0553:00205E5:`H0ETH/00@0EdHZ05A5:01A@RD0D44T
101>@2D205i9;00405i9:P1QBR/0HT//069;:`80I4//02P0Hd`/06A=:`1WCb/0Je4^075E<01fF380
O5`e07iN=`21JSP0PVXj085/?@1nKD40NV]207IZ@P1`J4<0KVI206ER@`1THD80HUdo061I?@1OECX0
GU8h05a@>01MCSL0F4da05Y<<@1LCBh0HDh]06MA;01]Dbh0LeL_07II<@2:K2`0T74`09Mi<`2SPCT0
ZhLk0;6<?02dSS/0]hlj0P2hTdd02`2jUDl0_9MA0;jID`30VeD0`IaF0<:ME`2jUeD0^9EC0;JCD`2d
T580/HmB0080/8eC0140/8eE0:b:C@2[RD`0ZXQ;0:N4BP2UPTP0Xh160:9oA@2QOTH0X7]609mjA@2L
Md80VgI109Ye@02KMT40W7M209eh@`030:1h<`@0WgLb0280WWHa09Ug<02GMRl0UWD`09=d<@2@Lc40
SW8a08]b<P2:LC40PV=6085R@`1nGd00Nedk07YL>01jG3H0Nehf07aO=`1aHS/0KUlf06aM=01`GSH0
MF@i07MV>`1gI3X0M64g07Y]>@1kKST0OVhj085`>P26Lc/0RWDl08ij?`2ANd40V7U20P2GN3l01P2F
MSd0Ug@j09Qd>P2KM3T0WWHk09mg?080W7Xc00H0VWLc09Uf=02GM3@0UG4c09A`=02CKc<408m_=P05
091`=`2BLST0U7@k09Ee?02ALC@00`2BLSD02P2CLcH0UGDh09Ui?02KNch0Vg]209al@@2MOD80WWi1
09n0@02PPD020:62?`80WGXh00P0W7Xj09Qi>@2EMcT0TWDi08mb=P2;LCH0Rfhd08Y]<`<0RF`b00<0
Rfhd08e`=P2>LCL0102?LSH0302BMCT0UGPl09Ul@02KOT80XX=209Yk>`2<L340OVHZ07EO9P1aGBP0
KUhZ06mO;0P0LEdZ0P1bFbT00`1`FRP0KUXW06]J9P0206UI9@0606II901aG2d0LUd^079M;P1cGRl0
M5l`0P1eH3401P1fHC80N6<^07QS;P1hHbh0NF@_07YU<080NfHa02T0O6Lb07AS;`1cHRh0LUh/075K
:P1aFB/0LUL/07=G;`1dEbl0S6<_09U_?@2/QUL0`Yea0=6_R@3H^YP0f[fO0=RmX03F_Z80eKjO0=Bm
WP3E_Yh0e;fK0<fgTP33[HH0^ZAm0:nCH`2XS5`0WH5A09=gA`2BMTH0WX9B0;6EI@30Y7@0aJ^80<Zb
SP3B^IX0eknS0=S2ZP3MbK40hm6m0>WG``020>SHb0080>[Ia@3Zf<00j=Bi0>C?/P3PbJT0gLJV0=o2
UP3K_Y820=NhRP0=0=>bQ@3@[X00d:al0=2/NP3B[7/0cJag0<f/N@3=Zg/0cJ]m0<f[OP3=ZX00cJZ2
0<fZQ0030<Z]Q@0K0<V/Q037ZX80a:Mo0<6TO02oXWX0_Yig0;bLM@2hV6l0/iAX0:f>H02XREX0XhEC
0:63D@2INTh0UWM;08m`A028JCd0PF8f07]L<01hFBd0MUL[07AC<01aD2d0Jdd[06I99`1OAbD0G4DU
0080F4<T0P1;?1d0101:>ah0BCXM04Ti7`18>1l204Lg80@0@c@O1012<ah01P0o<Ql0?S4N03ha7P0m
<1d0?2lL03/^6`80>RdJ200h:aX203<^6P0303@]6P0e;AX0=b`J0080>B`K00<0>b/K03@[6P0e;1/0
0P0e;1/203H]7080=bhM0`0e;1d303H]7P80=bhO1@0l;a`02`0m<1d0?S4N03ha7P11;b<0@BlQ048a
8@13<R80A3<Q04Dd8016=Ql0AcLP00<0AS@P1017=B400`18=R80ASLR04Hg8P0604Hg8P0604Hh7P18
>1l0BCLO04Tg7`1<>200CCLP0P1@=b4804hj8P0305Lo9`1F?RH0ECdU0080E3`T00L0Dc/S054i8@1@
>200D3PP054i8@1@>200CcLO0080CSHN00h0D3PP058j8P1D?2@0DSXP05@l8P1H?RD0G40X05m1:@1N
@2P0GCdV05`l9@1SARP0HTDW06549P80H4<U00@0HTDW06=6:01UB2X0ITPV0`1UAbD306A6900606=5
8`1TABH0IDHW06E79@1VB2@0J4XT0P1YC2@02P1ZCB<0Jd/U06a<9P1]CBL0KdlY075A:`1bDR`0Le<]
07AD;P1eDRX207IC:`0307MD;01hEBd0NEH^0080NUL_00<0NUD[07aG;@1mF2h00P1nFBl02@1mF2h0
O5L]07YE:`1kF2h0O5T_07eJ<01nFc40P5dc085N=002089O=@03081N;P21Gbl0PV0`0080Pf4a0`24
HS8208MP=@0<08QR=@29Hc@0RF<b08YU<@2;IS80RfHa08YU<02:IC40RF@`08QR<@28HS<0Qf4d0P27
H3D00`25H3@0QV4e08IQ=@0408IQ=@0408EP=028HS<0RF<d08US=0@0RV@e00D0RF<d08iX>@2?JCX0
TF/l09=]?P0209A^?`0:09=]?P2BK3d0TVdi099]>@2CKSX0UG0l09Ia?@2GLSh0V7<o09Ud@080VG@o
00@0VWE009ag@P2MN4<0WgY50P2PNdH0202ONT<0X7]40:1kAP2QO4P0XWa;0:=mCP2TOTl0Y7iA0P2Q
O4D01`2QO4L0Xgi:0:AnC@2TOTd0YX1A0:N1DP2XPUD0202[Qe<20:b:FP80[H]K00@0[XaL0:n=G@2`
SUh0/8iN0P2_SEl20:j<GP<0[H]M00@0[8YL0:f;G@2]Red0[H]M0P2/RU`30:^9F`P0ZXID0P2ZQUH2
0:^7E`80[8QH0P2]RET0102YQED0ZhMG0:j:FP2aSEd40;>?G`@0/8aH102_ReL20;:>GPH0/HeM0P2/
RU`20:f;G@@0[XaN00<0/XiN0;B@H02eTF400`2gTf<00`2fTV80]I5Q0;JBHP070;JBHPD0]i=S0`2h
U6@0202eTF40]Y9R0;NCH`2hU6@0]i=S0;JBHP2dT600/XiN0`2bSET50;>>FPP0]91P0`2gTVD01@2h
TfH0^IAW0;ZEJ02jUFP0^iIY0080^iU[00@0_9Y/0;fKK@2nW6h0_Ya^0P2oWFl20<6OLP80`Z1c1033
XG@00`34XWD0ajAl0<NTO00>0<NTO0P0bJIl0P3:Ygd00`3;Z7h0c:Uo0<fZP0020<j[P@030<n/PP3;
Z7h0bjQn00H0bjQn00@0b:Ek0<VVO039YW`0bJIl0`3:Ygd50<^XOP@0bZMm0P37YgP01P37YGL0aj9e
0<JQM036X7<0aiib0<JML@P0aJ1c00<0`9]^0<6LK`32WG000P34Wg800`32WG00`Ia_0<2KKP020<2N
L080_ie_0P2nW6h20;fKK@@0`9a/1031WFd80;jIK080_IUY0P2lV6P20;^GI`80^YIV00P0^YIR0;^G
H`2kUf<0^iMS0;ZFHP2hU600]I5M0;B@G080]I5Q0P2fTV820;NCH`80^9AT0P2gTel20;JBGP040;FA
G@2dT5`0]91L0;B@G080]I1L0P2dSe/0102cSUX0/XeI0;:=F@2bSET20;>>F@040;:=F02`ReH0[hYE
0:j9E080[HQC00L0[8MB0:n;E`2^RUH0[XYF0:f9E@2/R5@0ZhMC0080ZXIB0`2[QTl20:b7D0<0[HQA
0P2/Qe80102[QU40ZXE@0:V4C`2XPdh20:N2C@0;0:Z5D02YQ4l0Z8=>0:R3CP2YQ4l0ZXE@0:b7DP2]
R5<0ZhM=0:Z6C02YQ4d00P2WPTd01@2XPdl0ZXAC0:^5E02WPdl0Z8A@0080ZHEA0P2[Qe<00`2/R5@0
[HUE0:V6D0070:V6D0P0Yh=?0`2VPD`30:N2C@80Z8=>0`2WPTd[ooooo`00:_ooool02`2OMT80X7M3
0:1g@`2RNDD0XgY60:AkA`2UO4P0YWe90:MnBP2VODT0YGa80080Y7]700<0YGa80:ImB@2WOTX0202W
O4T80:AoBP<0YWe90`2WOTX20:QoB`<0YGa80P2VODT30:MnBP80ZX1>0P2YOdd40:QnC080Z7m;0`2Y
P4`30:Z1C@80ZH1<0P2XOd/20:MnBP@0YWe90P2WOTX20:ElB0090:=jAP2QN4@0WgI209iiA@2MN4@0
W7M309]f@P2JMD40V7<o0080Ug8n0P2HKS`00`2GKC/0UV`j09E[>@0209AZ>00909=Y=`2AJch0TF/n
08mY?02>J3/0S6Hi08YT=`29HcH0R68e0080Q60^00h0QF4a08EP<`24Gc<0Pehd089M<`21Fc@0O5d^
07]L;P1jFbd0NEX^07MG;P1fERl0MED_07AD;P80M58/00<0LU8[071C:`1_Db/00P1/DbX0101[E2X0
LE0]075@;@1aD2d2071?;0<0Kdh[00P0Kd/W071<:01bCbT0Le0X07EB:01gEBP0N5HY07UG:@80NUL]
00L0O5T_07eJ<01oG380PEhd089O=@23H3H0R68c0080RF<d00<0RV@e08]U=P2<ISL00P2=IcP02`2>
J3T0SFLh08eW>02<ISL0SFLh08iX>@2?JCX0T6Xk08mT>@2@ICX0TVLl0080TfPm00<0TVLl091U>P2?
I3T00P2>J3T308mY>P<0T6Xk00P0U6Pk099W>P2AIST0SfHh08eW>02=JCT0S6Xj08e[>`<0SVPi0`2=
IcP208aV=`P0SVPi202@ICP8091Z?@<0TVPf102CJCL209AZ>0P0SfTj202BIc`01P2=IcX0SVPk08iX
>`2?JC`0T6Xm095[?P80TV`o00D0SFTi095]?@2DL400Tflo091/?00208iZ>P0408m[>`2=J3@0SVTe
08mZ=P80T6/g00<0SfXf08iY=@2=J3@0202=JCD0202=JCT0SVXj08m[>`2@K3`0Sf/k08iZ>P2<J3P0
RVHf2`2<J3P208]W=`<0RVHf00H0QfDe08QV=P28ISH0RFLg08YX>02;JCT208aZ>P80R6Tj00<0QfPi
08IW>025ISL00P24ICH08@23I3D0PVHd085U<`20I3@0Of<d07eP=01lGcD0Nehf07YM=@1jFS40MUH_
06mB:P1[CbP0JDlZ06I>:P1PBBL0Fd@R05959@1@@RD0Bd0R04Hm8010>Ad0?CLM03`f7P0j=Qd0=2hR
034]8@0^:Qh0:bTL02PY6`0X:Q`09b/L02P/7@0202HW7`0402DV7P0T9Ad08b@L028S6`808B8J0P0O
8Ah201hP7@807AlL0P0L7Q/301hQ6P<07b8K0P0P8a`01P0U:1l08bHO020S700M7aX06adJ01/M70<0
6a`N200J71/201dO6P0F01`O600M81L07R4F024U5`0S9aT09BTJ02XW600]:Q/0<BhO03Db8`0f<b@0
=34R030]7P0^:a`0=RhS03H]900b:b40:bLN02@Q6P0O7QT08B0L028S7P809RLO0`0U9Qh302@U7@05
02@V6`0S9AX0824I01hO6@0M7QT00P0N7Q`00`0O7al071lH01`O600601`O600301`N6`0M7a`07R0M
00807b4N02<07R0M01dO700L7Q/0824S01lQ800O7ad08B0K02HS6P0[9a/0<BhO03H`8013?280A3TU
048e9@12<280Ac8O05Ho801WD2H0MEh/081^@028LCl0UgQ20:N2B`2cSUT0Zh]J08U`A`1WDbh0=S<Z
03<`9`0];BD0:2TS02HW8P0T9R<08bPT02@X9`0302DW90<09RPU0P0W:BH04@0V9al0:R/S02`]9@0[
;2@0:2TQ02LX800Z:b<0;RlW03Ld9@0e<R<0<blS03@`9@0f<RT0=C0Z030[9`0[9R809BHP00L09RLQ
01L0;2`T02/[8`0Z:R80:BTQ02XZ8P0[:b<0;BdU02h^9P0i=R<0?c`Y04I1;@15?bT0?cLP03le7015
>B40C40V05Lo9@1H@2H0FT8V05i7:01RBb/0Hd`Z05m89P0205]5800Q05a39@1OB2T0HTX^05i9;P1I
AB`0DT0X04lo:01>?RL0AS/Y04Dj:013>2H0@SLU044f9012=bD0@cPV04@i9`16=BD0AcHT04Pg9@1:
>BD0C3`U04hn9@1??bD0D40V0593901B@bH0DD8U04lo9@1>?RD0CCdV04`k9`1;>RH0Dd<Z00<0DT8Y
0`1A@BP00`1@@2L0CShW04hn9`0604hn9`0@04/n:`1<?b`0CD0]04e0;@1<?b`0BSdZ04Pk:017>RL0
ACDV04Hf9`15>2P0A3PX044h9`0n=bD0?3DS03Td8@80?3HX00<0>cDW03Xd9P0i<bD00P0h<R@00`0g
<B<0>c4W03X`9P0203X`9P80>BlU0P0h;R@503<_9P<0=30W00<0<blS038^8P0a;B400P0a;B400`0c
;b<0=C4U03Hb9P0203Dc900303Hc900i<bD0>S8U0080?38V00T0?S8V03hg9@0o>2H0@cPV04Pi9P1<
>RH0CcXU05@k9`1E>RD00P16>BH01P15>RP0@STX03lh:00l=RP0=c@U03Hb9P80@3<S0P11=2@02P12
=BD0@cHV04@g9`14=bL0?CPT03hg900o>2D0@3PU048g9@13=RD204De9@0804dm9P1??bP0CclX04`l
9@19>B80Bc/T0551:P1GAc0204M09P0604Pn8`1:?b<0CClR05528`1CA2<0ETHU0`1NA2T01`1MABT0
G4LZ05a9:`1JBB/0FDX[05Y;;01VCRX00P1UCR`01@1QCB`0GT/[05U8:P1FAbX0E4DX00<0ETD[0P1G
AR`305Q7;@0@05a9:@1IARH0E4<U05939P1BA2T0DDD[04e3:P1;@BP0ED@X05Q4:@1JAbT0GDPY065:
:P1UCB/0Idd/06Q>:`80J54a01@0J50^06Y@;@1_DS00M5Hb07YJ=01lG3H0PfXd08=/>025Kcd0Q792
089dA`20LdT0Ng9907U`B@1ZJTH0IfM506AQ@01QG3h0GULk05iD>`80Ge<m01h0Fe<l05aB>@1LD3H0
Ge0c069?;`1WD2h0JU8^06aB;@1mHR/0PfH^08][<02ELc<0WWTc0:Em=@2[P380[84b0;::@P2cRd<0
]Xi60;R@B02lU4`0_iM?0<6ID@32VU80_YIA0;fED02kU540^I=B0;JCD`2dTU<20;:BE@060:b=C@2[
S4`0ZHU<0:N7C02UQD`0Xh9<0P2QP4/0202NNTX0W7Q809QdA02FLT80UG5109Ib@P2HM4@0VGE5202C
LcP0602AKc80Sflb08i^<`2=KSD0Rfhf08Q]=P27KSH0Qfhh07mR@01mH3h0NEdh07MK=01fFS80Me/c
07UN<`1jGc@0NVe307QY@01hIc`0O6Tn08A_@P29Ld@0RG=208Ua@@80SgY100L0T7Y0099j?P2CNC`0
UWXk09Mk?02HNSX0VGTl0080UgLj00`0UW@g09Ea=@2FKc@0V70e09]c>02MLcT0VWPa09Ug<02HMC40
Ug@b09Eb<P2DL38209=_<`80Sflf0P2@L3L01P2ALCP0TW8i09=c>P2CLcX0TFlb09=a=0<0UG<f00@0
UgDh09aj?@2POT40WGa60P2MOD@01@2NOT<0Wgm209n0@02OP3l0X8500080VgPh00L0VGLh09If>@2C
MCT0T7<i08mb>02<LST0QV`c0080QF/b01D0Q6Xa08E[<P27KC@0RFlf08]a>02@LcT0Sg8h08ia=`2=
L3H0Sg8h09=f?02GNT00VGa20::3@P2HNCT0RVh_07eU:@1gHBP0M60[075Q;@1`H2d0201`G2T0201a
FRP0L5TW06mI9`1]FBH0JUTU06QH901WEb<0IEPS0`1cGRl207AO<0<0MF0a0P1fHB`207MR;@80N6<^
0P1iI2l04@1aH2`0Ked[06mK:@1^F2T0KeL[075E;@1bERl0LeD_08QO:`2FK3X0ZXAE0<6LL03@[XP0
ekVG0=VlWP3G_9l0eKfQ0080e;fN01D0eKjN0=>lVP3<]Y40`J^40;RRN`2[Sel0YHUI09YnCP2AMDD0
TWI609n3D`2eVFT0aJUi0<F]R`3;]980d[^L0=K1YP3IaJ`0gL^e0>CC`@3ZfLL00P3XelD0203Yel40
jMFl0>G@]@3QbZ/0f/>Q0=NoW@3J^X/0ekN60P3B/8001@3=ZGL0bJEa0<RSKP3:Xf`0bjA]0080aJ9X
00H0aJ9/0<JRL036XG@0aj9h0<NQNP38XWd30<BWO@0N0<>VO031Y7X0_J1f0;ZML`2hVg40]IE^0;>C
K02`T6L0ZhaP0:J7F@2QPU<0WGm=09]mB`2BMD/0SW5708Q[@@21I3X0Nehd07II;`1cER`0LUD[075>
;P1^CBh0J4TZ0656:01KA2D0ET<U05=29P1B@bH0AS/K0P15>Q`01@14>Ad0@cLM044e7@11=Al0@3@N
00P0?34M0P0k<1h203X_7@0403T^700h;A/0=b`J03L/6P80=b/K0`0f:QX303DY6@80;R/H00@0<2/H
034Z600c:QT0=BTI0P0g:QX2038X7080<bTM0`0d:Qh0100e:al0<bTM03<Y7@0c:Ad203@Z7P<0=B/O
00P0>bhM03X]700j;A`0>B`K03X]700k;Qd0?2lN03d`7`80@2hR00H0@2hP040_7`12<B40A3<Q04He
8@17=R8804@c8@P0@SDR0P15=Ql01016=Ql0B3HP04Pf801;=R4204`f8@P0CCPS00<0E3/U05<j901C
>R@00P1B>B<05`1A>280D3LQ050g8@1?=R00DCPR050g8@1>=Al0C3<M04dd7P1?=R00DSTS05@k9@1A
>b<0DS`T05Hn9P1H?RL0FShX05dn:@1L?BP0GCdX06A6:P1SABT0HD<W0080H48V00<0HD<W06=5:@1T
ARX01P1RA28206=58`0806=49@1TABH0IDLU06I8901WBB<0JD`T06Y=9@1ZCB<206Y<:00306]=:@1/
CRX0KDl[0080KU0/00@0Ke4]07AA:`1dDB/0ME8/0P1fDbd01P1gE2h0N5D_07QE;`1iE2X0NUD[07]F
;080O5L]00<0NeH/07YE:`1iE2X00P1iER`0101jEbd0O5T_07eJ<01oG382081M<`0407iL;P20GS00
PEla08=Q<`80Q68d0P23HC<208IQ=@0308IQ=027Hc<0Qf<a0080R6@`00L0R6D_08YU<029I300Qf8^
08EO;P24GRl0Q5ha0080QEhc00<0PUdc08=N=024GcD00`24GcD02023GS@0PUdc089M<023GS40QF0c
08IQ=027HSD0R6<f0P27HSD0102;ICH0S6Hg08iX>@2@JS/2095[?080T6Xk00h0T6/g095/>02BKCT0
Tfhj09E`?02FLCd0Ug8n09Qc?`2GLSd0V7<n09Ud?`2JMD00VgI109eh@`80WWU40P2NND800`2ONTD0
X7]70:5kBP020:9lC@050:=mD02QO4D0XGa50:5lA`2QO4P00P2SOD`00`2UOe00Yh5B0:R2E@080:Z6
DP80ZhUI0P2/RUX20:f;F`80[XaL0P2]Red30:b:G0<0ZhUK0`2ZR5X20:V7F@<0Z8IH202YQE420:N3
D`030:R4E02YQED0ZXIF0080ZhMG00D0[8QH0:V5E@2[QeL0[HUI0;2<G0030;6=G@030;2<G02^RUH0
[XYF00H0[XYF00D0/XiN0;6=G@2`S5`0[h]K0:j:FP020:n;F`040;2<G02ZR5X0ZXQJ0:Z8FP80ZhUK
0`2/RU`0202`Reh0/HaO0;>>H@2dSf80]I1S0;B?HP2cSV40/XeP0P2fTV820;FAH@@0]91P0`2eT6<2
0;JAI0<0]i9U0P2eTF430;NCH`040;FAH@2cSel0/XiN0;6<F0<0/XeI0`2cSUX0102dSe/0]91P0;B@
H02dT6030;>?G`80/XiN0`2dSf820;F@H`<0]Y5T0P2hUVH20;VGI`050;ZHJ02kVFT0_9YZ0;bJJP2n
W6h00`2oWFl30<2NL080`Ima2034XGT80<FRNPP0ajAj0`39YW`30<ZWO@X0bjQn1@39YW`30<RUN`04
0<^XOP3:Ygd0bZMm0<ZWO@<0bJIl00L0b:Ek0<JVM`35YGH0aZAf0<NRM@36XG@0aZ1c0080aiib2035
X7<00`30Vfh0`Ia_0<:ML0020<>NL@030<:ML031W6l0`9]^00<0_ie_0P2nW6h30;fKK@<0_i][0P30
W6`30<6MK@030;nJK@2nVF`0_IQ[0080_9MZ00<0_IQ[0;jIK02oVVd00`2lV6P20;^GI`<0^YIV00P0
^9AP0;VEH@2jUV80^YIR0;VEH@2gTel0]I5M0;B@G080]91P00@0]I5Q0;JBHP2gTf<0]i=S0P2hU6@2
0;NCG`040;JBGP2eTEd0]91L0;B@G080/hmK0P2dSe/0102cSUX0/XeI0;6<F02aS5P20;2;E`80/HaG
00@0/8]F0:n:E@2^RE@0[XUD0`2]R5<01P2^ReD0[HYD0:f:E02/RE<0ZhQB0:Z7D@80ZHI@0`2ZQDh2
0:^6C`<0[8M@0P2/Qe801P2[QU40ZHA?0:R3CP2WPTd0YX5<0:F0B`80ZHA?0P2XPdh01`2YQ4l0ZhIA
0:f8D`2^RE@0[HU?0:^7C@2ZQDh00P2XPdh00`2XPdl0ZXAC0:^5E0030:R4D0050:V5D@2ZQU80ZhMC
0:^7D`2/R5@0202YQU080:N3C`<0YX5<1@2UP4/30:F0BB_ooooo000Zooooo`<0WgI20P2PMd<20:5h
A0040:9iA@2WOTX0YWe90:ElB080Y7]700<0YGa80:ImB@2WOTX0202YNdT80:AoBP<0YWe90`2WOTX2
0:QoB`@0YGa80P2VODT20:MnBP030:^1C`2ZP4h0ZX1>0080ZGm=0P2XOT`00`2WOD/0Z7m;0:QoB`03
0:V0C0<0ZX5=0`2WOTX20:ImB@<0YGa800<0Y7]70:ElB02VODT00`2VODT02`2TNdL0XWU50:5hA02N
NDD0WGQ409ag@`2KMT80VGA009Qc?`2GLSh0UW4m0080V6hl00@0Ufdk09I/>P2EJcT0U6Xh0P2CJCL2
099[@00F091Y?P2>Ic`0S6Dj08YS>029HSL0R64f08EQ;`26HS00QV8b08IQ=025H3@0PUdc081K<@1n
F340O5d^07]L;P1jFbd0NEX^07MG;P1fERl0MED_07AD;P80M58/00<0LU8[071C:`1_Db/00P1/DbX0
0`1[E2X0LU4^079A;P02075@;@0<071?;01_CR/0Kdh[06m>:`1_BbL0L4`X075>:01cD2P0ME8X07ME
:01hERT0NELY0P1iER`01P1kF2h0OEX`07mL<P21GS@0PUle08=P=P80R68c00D0RF<d08YT=@2;ICH0
S6Hg08eW>00208iX>@0:08eW>02<ISL0RfDf08aV=`2=IcP0SfTj095[?02?I3T0T6Dj095V>`80TVLl
00<0TFHk091U>P2?I3T00P2<ISL208eW>00<08iX>@2?JCX0SfTj08mY>P2EJC`0TfPk095V>@2?ISP0
SFLh08eY>@2<JSX0SF/k0`2>J3T308eW>080S6Hg202>J3T8091U>0P0T6Xm0P2CJCL3099X=P@0TFLe
202@JS/809AY?P80SFLj0140SVPk08mY?02@JSd0TF/n099/?`2CKD00S6Ph095]?@2ELD40U710091/
?02=JCT0SVXj091/?02<Ic<0SFPd08iY=@02091[=`0308iY=@2=J3@0S6Lc00P0S6Pd00P0SFTi08iZ
>P2?Jc/0T6`l08m[>`2>JSX0S6Ph08YV=PP0RfLg0`2<J3P208]W=`<0RVHf00H0QV@d08MU=@28ISH0
RFLg08YX>02;JCT208aZ>P0608UZ>`28JCX0QfPi08IW>025ISL0Q6Df0P23I3D01P21IC<0P6@b081T
=01nHS<0OF0d07aO=@80Nehf00d0O5/b07IF;@1aDBX0KE0X06a@:@1WCBP0HDTU05a4801CARH0DD@T
04]08P16?B00@3TM0080?CLM00T0>cLN03@^8P0a;B40;RXN02/Y700X:A/0:2XL02L[700X;1d00P0V
9al0100U9Qh092DM02<T700R8a/2024R6P807b4N0P0N81d201dO708071hK0`0N8AX301lR6`8082<L
00H09BPO02<V7`0Q91d07R0K01`N6`0K7A`301/L7PP06Q`K01P07R0K01dO6P0L7aP07B0G01hQ5P0P
91H08RHH02@X6@0Y9QL0;2TJ038_800f<b@0>3DV03Hc900b;b00;b`M03H/8P0g;RD0=RdT02lX800U
81X08AhI020O6`0S8Qh202HW7`<09BHN0`0T9Ad01@0T9Q/08bDJ020Q6@0N7aT07AhI00807QhL00<0
7alO01/N5`0K7QL01P0K7QL00`0L7Q/07AlL01hP7@0201lQ7P0S01hP7@0M7a`071hK020Q8`0O8280
7alM020O6`0U8Q/0:RHK02l/7@0d;R00@CXP04<h9012=BD0@c4U04Lb8@1C>al0HT/R06iF9P1lKT40
Qg5009=e?`2ROT@0/XeF0;:AGP2DND`0LU`c03Xg;P0g=2/0;blW02TZ900U9R408bDR024V8P0R9RD0
0P0S9B8302@V8`<09BLT01409RLO02TZ8P0/;BD0:b`T02PY8@0W:200:R/S02d^9P0h=BH0=C8S03<_
8`0d<2D0=S8Y03D`:P0`:bL0:bHR02<T7P0202@U7`0302DV800V9b409RLQ00809bPR01L0:bXU02XY
900Y:2<0:2LR02TX8`0Z:B@0;2/V02d/9`0];Q`0=3DS03`k9`0l>RD0>C@P03Pb700o>B40AclX054k
901A>b<0DcdU05U4:@1OBRd0HD`]05e9:00205Q48`0;05Q0901MAB/0GdX_05a8;`1D@RX0CCdV04/j
9P1:>bH0AS/Y04Dj:013>2H00P11=R@03012=bD0@cPV04@i9`15=2@0ASDS04Pg9@1:>BD0C3`U04hn
9@1??bD0D40V05939080DD8U00<0DD4W05109`1??bP00P1??RX305=3:P030592:@1A@BP0DD4X0080
D40W201>?RL05P1<?b`0CD0]04e0;@1=@2d0C3l/04Xm:P18>bP0ASTV04De9P16=RL0ACPX04@h:011
>2L0?SLU03`e8`0i=240?CLY03`f:00k=BL0>S@V03Tc9@0h<R@203La8`<0>c4W0P0j<2H303T_9@80
<RhU0P0c;bH01P0d<2L0=C4X03Hb:@0f<RT0<blS038^8P<0<BdQ01@0<blS03Da9@0f<RH0=C<T03Hd
9@0g=2D0>C<U03/c9P0l<RH0?C<W03lc9`0l=b<0?SLT048g8`17>2<0CCPS058i9@1F>RD0F3TU04Tj
9@80B3/X00/0AS/Y048i:00n=bL0>S@V03Pb9011<B80@S8S04<c9014=2D0ACDV04Hf9`0204Lg:00H
03`g8@0n>280@C/U04@l9`15>RH0A3LT04@e8P12<b00C3/W04dl:01<>bL0BCPT04Dd8016=B40BcXV
0550;015@2X0A40W04Do9@18?R<0Bd0R05528`1DA2<0ETHT0P1OA2T01@1PABX0GdDZ05a7:P1KB2X0
FDX[0080F4/[0P1VCRX01P1VCbd0IDh^065<;@1NBb/0FDPZ05M6:080Ed<X0P1HA2T0G01IABX0FTH[
05Y6:`1JAR/0Gd/Z05]79P1GA2@0E4DX05I8;@1DBS40CTH_04Y2:`1??bH0D40V05I29`1KART0HTTZ
06I<:`1[CbX0KU0/06QA<P1WD340Idh_06U?;P1^DBl0M5Hb07]J=`1oGcT0PFH_08A[<`27L3`0RGE3
08UiB027NTd0QGU?089iCP1cMDh0L71<06YZB01UHT<0Hee306=KA01WG4P0J5e;065JA`1QFD@0H5Do
061B>01QD3@0He0`06I?;`1VCbd0LUL/07II;@1oGc00R6D_099Z;`2JKRl0X74]0:9a;02YOC@0Zglf
0:j2>@2aQC`0]HU00;V=A02lT4L0_I580;b?B`2kT4/0^I5<0;RACP2eTU00]99B0;:CDP2aTe<0[8m=
0:b>CP2ZS4h0ZHYA0:N8D@2UQU00Y8AC0:>3DP2POU40WG]>09YhB`2FM4L0UG=609IdA`2IMdX0VWQ;
1P2=MT@208igA@0H08i]>P2>K3`0SFdl08a]?P2:KSl0RFi108U^@`27Kd<0Q6e4089[@@1oJ3h0OFHj
07eW>01oJCP0PV`j08A^?02<Ndl0RGM908Mb@`2:M4<0TGM409IkAP2HNT@0UgQ10P2JO4001`2KNch0
W7Xk09ej>P2LNCT0WWPg09eh=02MNc/00P2JN3P01P2HM3H0Ug4c09M_=02ILCH0W74j09ic?080UgD^
00@0UW<_09Ic<@2ELS80UG4c0P2DL3@3095a>0D0TW8i00P0T6``09A`=02GLcL0Ug<g09Ib=P2HM3P0
WWXn0:B0A080WWe700@0WWi509in@`2NOT40WWi10P2OP4002P2ONcd0WWXl09Yh>`2EMCP0TG<g08e`
=P2;KSH0R6he08=Z<P22JC42085X<00D08=Z<P25K3@0Qfhf08U`>02AM3X0T7<i08e`=P2<KcD0SG0f
091c>@2DMcd0UgY009en?@2CM3@0QFTZ07]S9`1gHBP0MF4/071P;01^GR/8071L:@08071I9`1_F2H0
KUPV06aH9@1YF2@0IeLS06IF8P1TEb83071K;0@0LE`]00<0LUd^07EP:`1eH2/00P1eH2/407IQ;00A
06eK:@1/FRX0K5LX06aE:@1]E2/0L5@]079F<@1dES80QE`X09AZ>02XPU<0`9]_0=2^R03F^9H0f;^M
0=JkWP3E_J400P3D_Ih07`3E_Yh0dkbJ0<bfT@30ZX<0]Z1i0:R<G02RQUH0V7a<091dA02AMDD0XHEE
0;NKJ`38[7`0aJj<0<^dU03A_9d0e/:W0=W7[`3NcKT0i]G30>_Kb`3We<<0imG10>SC_P3Vd;P0hl^_
0=c5Y@3F_Y`0d[ZF0=6`O@3=[7L00P39YG403@33WVT0`IYS0<2GG`30V5d0`IMM0;bIF@2mVE/0_YYP
0;nJI@30VV/0`Y]`0<>LM@33VgL00`2lWg<09@2kWW80^9]_0;FHK02aU6P0[i9V0:Z:H`2XR640YHEL
0:62EP2MOU00V7U:09EgA@2DMT@0RVi608M[@`21ICd0Nelg07EI<@1`E2`0KU8Z06a@:01/Ab`0JDHZ
06939`1K@2D0E3lT04ln901<?R<0BShT04Dl7@14>ah0@cXM044g7010=Qd0?S<M03db7P0l<Ad01@0g
;aX303P`6`0603P_7P0g;Qd0=bhM03H]700e;1/0=2/J0P0c:QT303D/7@0303@[700c:Q/0<bXK0080
<RTJ00H0:RTG02/X5`0/:AP0;RPH030Y6@0a:1T203@X6P0402lW700`:1d0<2PM030X7@80<BTN0P0b
:Ql0100`:1/0<BTL034Y700a:A`2038Z7@80<b/N0100>RdM03T/700h:a/0=bXJ03P[6`0i;1`0>bhN
03d`800o;B<0?R`R03h/800n;1h0@2lO04<b8015=280AcHR1@12<b03044b7`P0@3<P0P12=R000`14
=B00ASDQ04Le8@0204Xe8P0304/d8P1<=b@0C3LT00H0C3LT2@1@=b<00`1B>BD0D3LS04dd800204`c
7`0>04lf8P1B>BD0EC`X058n9@1A?B@0DS`T05@l901F?2D0FCdW05/o:@1N?bX0Gd@W05i39P1L@B@2
05]08`0405a1901M@RD0GT<V05i07P80Gd4O00d0H48P06538@1RA280HT@R06=58`1SA2D0I4DV06E7
9@1VB2@0J4XT06U<901[CRH0JdhT0080JdlZ1P1ZCRT01P1bCRX0Ldl[07=?:`1dD2`0ME4]07IB;P80
Me<_00<0Me8X07QC:@1jEB/00P1kER`03`1jEB/0N5<Y07MB:01fDbT0Me@Z07QE:`1iER`0NeP^07aI
;`1mFS00OU/a07eK;P1nG2l0PElb08=Q=00208AR=@80Pf4d0P24HSD00`24HS@0Q68b08ET<@0208ET
;`0708ET;P29I2l0R6<_08EP;023GB`0PU`]089L;`0208=L<@0307mJ<020Fc40PUdc0080Pehd00P0
PUdc081K<@1oFS00NeT/07eK;P20GS40PV0c08AR=@<0QF<f00@0R68c08US=02;ICH0SFLh0P2>J3T2
08eW>00808mZ=P2@JcL0TF`h099]>@2DKc/0UG0l09Ia?@2GLSh209Ia?00609Mb?@2IM3l0VWE009]f
@@2LMd80WGQ30P2MN4400`2NND@0WgY60:1jB@020:5kC0050:9lC`2RODH0XWe60:5lA`2QO4P00P2S
OD`00`2UOe00Z89C0:V3EP080:V5D@@0ZhUI102/RUX0102/RU`0ZhUK0:^9F`2[RE/20:Z8FP80ZHMI
0`2XQUP20:N5E`<0YXAF202YQE420:F1D@040:J2DP2WPe<0Z8AD0:V5E@<0ZXIF00<0ZhMG0:f9F@2_
Re/00P2_Re/00`2^RUX0[HUI0:b8E0040:b8E0<0[HUE00P0/XiN0;6=G@2_Re/0[HUI0:b8F02]RET0
[XYJ0:n;F`80Z8IH0P2YQeT30:Z8FP040:^9F`2]R5`0[hYN0;2;G`<0/XeQ00<0/HaP0;2;G`2eTF40
0P2eTF400`2dT600/hmO0;>?G`020;:>GP030;>>HP2dSf<0]8mS0080]I1T0P2fTFD02P2gTVH0]I5Q
0;JBHP2gTf<0^9AT0;NCH`2fTV80]91P0;>?G`2aS5P20;:=F@80/hiJ0P2dSe/00`2eT5`0]I5Q0;FA
H@020;B@H0040;>?G`2bSUh0/XiN0;:>GPD0/XeP0`2cSV401P2eU640]YER0;JEHP2gUV<0^9MT0;VH
I@80^YUV00@0_9YZ0;fKJ`2mVf/0_I][0`2nW6`20;nMK@P0`Iif2033X7P80<FRN0@0b:Ek0`37Y7X0
0`36XgT0bZMm0<ZWO@080<ZWO@040<VVO038YG/0b:Ek0<NTNP80aZ=i00<0bZMm0<VVO039YW`00P38
YG/20<NTNP040<JSN@35YGH0aJEf0<FSM@80aZ5d00<0aZ1c0<NNLP37WW802035X7<00`2oVVd0`9]^
0<:ML0020<>NL@030<:ML030Vfh0_iY]0080_ie_0P2nW6h40;fKK@80_YYZ0P2oVf/01`30W6`0`Ie]
0<6MK@31WFd0_iY]0;jIK02lUfX00P2kUVT00`2lUfX0_YU/0;nJK@020;bHJ080^iMW102jUVH00`2f
TUh0]i=O0;RDH0020;VEH@030;RDH02fTUh0]I5M0080/hmO00H0]91P0;FAH@2fTV80]i=S0;RDI02i
UFD20;NCG`040;JBGP2eTEd0]91L0;>?F`80/XiJ00H0]8mK0;>>FP2cSUX0/HaH0;2;E`2_RUH20:j9
E@T0[XUD0P2]RU800`2/RE40ZhQ@0:Z7C`020:V6CP030:R5C@2YQ4d0ZHA=0080ZXE>0`2[QTl01`2/
Qe00[8MB0:^6D@2ZQE00ZHA?0:N2C@2VPD`00P2TOdX02`2YQ4l0Z8=>0:R3CP2XPdh0ZHA?0:^6D@2]
R5<0[hYE0:j:D02]RDl0ZhI?0080ZHA?00<0ZHA@0:Z4D`2[QE@01@2YQE430:Z6DPP0ZHI@202XQ500
1@2WPTd0YX5<0:J1C02UP4/0Y7m:0080Xgi900@0XWe80:=oA@2SOdD0Xgm5:oooool002[ooooo202O
MT800`2XOd/0YWe90:ElB0020:=jAP030:ElB02VODT0Z7m;00P0ZG]9202TOdX30:ImB@<0Ygi:0P2X
Od/0102TNdL0YGa80:ElB02UO4P20:ImB@80Ygi:0P2[PDl20:Z0CP040:UoC@2XOT`0Z7i<0:MmB`80
Z7m;0`2YP4`30:Z1C@<0YWe90P2UO4P30:AkA`030:=jAP2TNdL0YGa800<0YWe900<0YGa80:=jAP2R
NDD00P2MN4@01`2LMd<0VgI209Ud@02HLcl0Ug8n09Ia?@2HKS`00P2GKC/00`2FK3X0UF/i09AZ>002
09=Y=`0H09=/@@2BJd00T6Tn08iW?02<ICX0RV<h08UR=`28HCH0QV8`08MS<@27Hc<0Qf8e08EP=022
GC<0OeX`07eG<01lGBh0Ne`^07YK;@1iFRh0MeL^07IF;`1eEBl0M5@^0P1dDR`00`1bDR/0L5<[06mC
:`0206aC:P0606]D:P1bDBh0LU4^079A;P1aD2d0L4l/0`1_CR/0401_BbL0L4`X075>:01cD2P0ME8X
07ME:01hERT0NELY07QE:`1iER`0NeP^07eJ<01oG380PEhd089O=@23H3H208QR<`0308US=02:I3D0
RfDf0080SFLh0P2>J3T02P2=IcP0S6Hg08]U=P2;ICH0SFLh08mY>P2AJc`0SV<h091U>P2AIS/2099W
?003095V>`2@ICX0SV<h0080RfDf0P2<ISL0302=IcP0SVPi08iX>@2?JCX0UFTl09=X>`2AIST0SfHh
08eW>02<J3P0S6Xj08e[>`<0SVPi0`2=IcP208aV=`P0SVPi202@ICP8091Z?@80TfXf00<0TVTe095X
=02@Ic<00P2@Ic<208mV<PP0T6Xk202EJSl208eW>P0308iX>`2?JC`0T6Xm0080TV`o00`0Tfe008aX
>02AKCd0UW9209A`@02?Jc/0S6Ph08eY>@2@K3`0RfHb08aW<`2>JCD2091[=`0308iY=@2<Ic<0RfHb
00P0S6Pd00P0SFTi08iZ>P2?Jc/0T6`l08m[>`2>JSX0S6Ph08YV=PP0RfLg0`2<J3P208]W=`<0RVHf
0P26I3@01027ICD0R6Hf08YX>02;JCT208aZ>P0608UZ>`28JCX0R6Tj08IW>025ISL0Q6Df0P23I3D2
081T<P0407mS<`1nHS<0OF0d07aO=@80Nehf01P0OE`a07QG;P1bDRT0KE0X06a@:@1XCRT0HdTV05e5
8@1DAbD0DTDU04]08016?Ah0@CXM03hi700m=ad0?3PM03@^8P0a;B40;RXN02/Y700X:A/0:2XL02L[
700X;1d202HW7`0402DV7P0T9Ad08b@L028S6`808B8J0P0O8Ah201hP7@807AlL0P0L7Q/301hQ6P<0
7b8K0P0P8a`01P0U:1l092LP024T7@0N81/071hK01/M70806a`N00<071dO01XL6`0J71/01P0J71/0
600N81/07AlJ01`O600L7aH07R4F020T5P0R9QP092PI02PT600/:1`0<RhR03Lc9`0i=BT0=c<W03<_
8`0`;200=R`R03P^9@0g;RD0<2TQ02HQ6`0P7AP08QhK02@S7`809RLO0`0U9Qh302@U7@0502@V6`0S
9AX0824I01hO6@0M7QT00P0N7Q`00`0O7al06ahG01/N5`0601/N5`0301/M6P0M7a`07R0M0080828O
02<07R0M01dO700K7AX0824U01lP8P0O7al081lK02@Q6P0Y9AX0;RXN03<]7`10>240@SLU04<e:014
<RH0B3<R058j801OB1l0JE4Q07e_@P26LT00TG<m09mk@@2aSE<0]9=N09YnC`1hHCL0?CXa03Tf;@0`
<2P0:BXT02DV8@0R924082DQ024U9002028T8@<08bDR0`0T9R<0400U9Qh0:BXR02`]9@0/;BD0:BXR
02PY8@0Z:b<0;BhV03Pe9P0f<b@0=30T03Da9P0g<bX0=S4[034/:00/9b<2028S7@0902<T7P0T9Al0
9BHP02HW8@0W:280:2TS02/Z9@0Z:B@0:BPS0080:2LR0180:BPS02/Z9@0/:bH09BPG02d`7`0e=R@0
=cHR03@b7@0g<Q`0?STS04M1:@1?>B80CSPQ050j8P1G@RL0GTT/065<;@1MB2T205Q48`0;05Dm8`1I
@b/0GDL_05Y6;P1A?bT0BCPT04Hg9017>2D0AS/Y04Dj:013>2H00`11=R@02`12=bD0@cPV04Dd9016
=B<0AcHT04Th901<?2D0CShU04lo9@1@@2H0DD8S0080DD8U00<0DD4W0551:01A@BX00P1A@2`205A4
:`0405=3:P1B@RT0DT8Y0551:080D40W201>?RL204e0;@80CT4^00d0C3l/04Xm:P18>bP0ASTV04De
9P16=RL0ACPX04@h:011>2L0?SLU03`e8`0i=240?CLY0080?3HX00<0>S@V03Tc9@0h<R@00P0g<B<0
100n<BP0?C0W03d`9`0m<2L203`_9P80>bhU0P0a;B@0100b;RD0<blV03Da:00f<RT203Lc:P0303<_
8`0b;R80<BdQ0080<BdQ00<0<blS03Da9@0f<RH00P0f=2D0:P0g=2D0>C<U03/c9P0l<RH0?C<W03lc
9`0k=R80?CHS044f8P16=b80CCPS05<h8`1G>2@0FCTT04Xk9P1;?2L0BC`Y04Ll:P13>RT0?cPX03/d
900h<R@0@C4R048b8`13<b@0A3@U04De9P16=RL0AcLX04Ph:@0j=Al0?SPR048l9P16?RT0B3dY04Dh
9@13=240@34N04/j9P1<>bL0BcXV04Lf8P80@c8N00X0B3LS04dl:016A2l0AD</04Q2:P18@BD0C44U
05528`1DA2<0Ed@S0P1RA2X03`1PABX0GdDZ05a7:P1IB2X0FDX[05Q;:`1FBb/0IT`W06I>:P1WCb/0
ITl]06=?;P1OC2`0FTT[05U8:P0205I39@0405M49P1HABL0F4DW05U6:080FTLY04h0HT/Y05a89`1G
A2@0EdHZ05U;<01GCC@0DDTb04]5;`1:?280CCdT05919@1IA2L0HDPY06M=:P1]Cb/0Ke4[06I?<01U
CRl0ID`]06M<;P1^DC40MELe07iM>P22HCh0P6H]08AY<P27L3X0RgM408alB`2;OE00RGiA08QlDP1o
PET0NWaE07=cC`1^Jd`0JfE;06eUCP1`J5D0M6UG06EPC@1TGDX0HUY5065E?@1QDCL0HThc06=>;`1U
CRh0JDl/06iB;@1fERd0P5/^08YQ;@2BIB`0UfLY09YX:@2PM2T0XGDZ0:Ei;P2YOC80[H4f0;65>P2e
RCh0]XXo0;V:A02hS4D0^8e80;J?BP2eT4`0/i9?0;6BC`2`Te40[Y5?0:f?C`2/SU00ZX]B0:V:E02W
Qe@20:J6E`080:F2F02ROeD0WW]A09]hCP2IMT`0VWM=09ejD02OO58508]jCP<0S7]?00H0Sfa208m^
@`2?KTD0SVi708a^B02<L4/208Y`C@0I095lC@2?NT/0S7Q608Yf@`2:MT40SGU4091mA@2CP4H0VHAE
09B0CP2ANTP0TgY409UkA@2MOD@0WGY009ah?02MNCd0WGTk09mi>`2PN3X0X7Lg0:5e=02QMS80XG@a
09mn>`0209ak>00609Uf=P2HLS@0VG4f09]a=`2NLc`0XWDn0P2FM2d0102FLbl0UW<a09Eb<P2ELC<2
09Ea=@80TW8i0`2CLcX3099b>@0908m[;`2DL3@0V7@h09Mc=`2FLSH0V7@h09mk?`2UPDD0WWe80080
WWe700<0WWi509in@`2NOT400P2NOcl04`2TP480XWi009ek?P2FMS/0T74h08Y]=@27JS80Q6Tb089Y
<@21J300P6L_085X<022JC40Q6/c08I]=@28KcL0TWDm091c>`2=L3P00P2<KcL02`2?LSX0TgHn09Eh
@02GN3L0SVl_085U9P1hH2@0MV0W07AP:`1^GRX0Je/X00P0L5`Y0P1_F2H00`1]EbD0JeLT06QG8`02
06IF8P0306=F8@1]F2T0KEPY00@0KEPY0P1^FBX707AO:P0Y07EP:`1[FBT0JUPX06]F:@1[E2P0KE@[
071D;@1bES40M5Hb08=J9P2BJ3H0Yh5B0;nJKP3?[HL0e[RF0=RkW@3E^Yd0e;bP0=>lW@3D_Ih0eKjN
0=>lVP3;]I00_jV20;FON02WRe/0X8AD09IjBP2?Ld<0TGE50:65E@2iWFd0bZin0<J_S`3:]YD0d[fP
0=O3ZP3Jb;80gljj0>KFaP3/g<`00P3Ve<00203Wdk/0i<nd0>7:Z`3J`J80dk^G0<neTP3:YW80aZ=]
0P31W6L03@2mUUl0^I1H0;N?E02hSU80^XeB0;NDDP2hUED0^IEI0;^FG`2lUVD0_YM/0<2ILP30V7@0
0`2fVFd08`2dUf/0/YEY0:jAI@2[SV80ZHaP0::2F`2PP5T0WGeD09YkC`2FMdT0TW=408ma?`2>L3h0
QFU1089V?P1mHCT0MUXb075E;@1/D2P0JThV06U=9@1X@bP0I40V05ho8`1F?240D3/P04Xj8016>R00
AC/P04<l7`12>ah0@CXN03lh700m=Q`0>c<L0080>C4L0`0d;AX503D^6`0603L^7@0f;A`0=RdL03D/
6`0d:aX0<bXI0P0b:AP0100f;Ah0=B`M03D/7@0d:a`203<Z6`80<RTJ0P0Y:1H00`0Z9aH0;BLG02lX
6002034X6@0303<W6@0]9Q`0;RLM0080;RLM0P0_:1h2030Y7`<0;bTM0P0`:Qh3034[7`0:03X]7@0i
;1`0=bXJ03HY6@0g:QX0>2/K03/^7P0l;al0?bdS03h/8P80?B/O00D0?bdO048a8@15=280AcHT048b
8P05044a8@80@30P200n<b401P11=Al0@SHP04@e8014=B00ASDQ04Le8@80BSDR201;=R<00`1>=B40
CcHR04lf8P0204lf8P@0D3LS00<0DcXV054h901>=B400P1<<al03P1?=R80DcXV05Dl:01C?bL0DShV
054k901B>B<0E3TT05Ll9`1K?bX0GD4/05Y09@1I?b@0EcdR0P1F?2402@1G?B80F3hS05To901L?Q`0
GClM05i07P1O@Al0H48P06948P0206=58`0906=49@1TABH0IDLU06M99@1YBbD0JTdU06]>9P1/CbD0
K4l]0080Jdh/00<0JTd[06U<:P1YC2X00P1XBbT01P1aCBT0LThZ07=?:`1cCb/0M50/07EA;@80MU8^
00<0Me8X07QC:@1iE2X00P1jEB/00`1iE2X0N5<Y07MB:00207EB:00:07IC:@1hEB/0NEH/07YG;@1k
F2h0O5T_07aJ;@1nG2l0PElb08=Q=080Q68e01D0Pf4d089P<`24HSD0Q68e08AR=024HS80Q6<`08AS
;P25I2l0QF@^08UT;`27HRh0Q5l[089L:`21Fb`0PE/^089K<023G340OUPa07mI<P21Fc@00P22G3D0
2021Fc@0OeTb07iH<@1hERT0NUP[07iL;`21Gc80Q68e0`25HcH01@26H340R68c08YT=@2<ISL0SFLh
0080S6Hg00l0RfDf08mZ=P2?JSH0T6/g099]>@2CKSX0U6lk09E`?02FLCd0UG0k09Ia?02GLSd0V7<n
09Ud?`2KMT400P2LMd80302LMd00WGQ109eh@`2NNDD0WgU80:1jB`2QNd`0XG]>0:=nA`2RODH0XGa7
0:5lB080Xge<00<0YX1A0:R2D`2ZQ5L0202YQE420:Z8F0H0ZhUI0P2[RE/20:Z8FP<0ZHMI00@0Z8IH
0:N5E`2WQEL0YhEG0P2VQ5H30:F3E@P0ZXMA0P2TP5002@2UPE40YX9B0:N3D`2XQ5@0ZHEE0:Z6EP2[
QeL0[8QH0:f9F@020:n;F`030:j:FP2/R5P0ZhMG00<0ZhMC1@2/R5@0202bSUh0/HeM0:j:FP2/R5P0
ZhMG0:b8F02]RET0[XYJ0P2WQEL20:R6F0<0ZHMI00T0ZXQJ0:b7F`2]R5`0[hYN0;2;G`2aS600/8]O
0:n:GP2^REd00P2eTF40102dT600/hmO0;>?G`2bSUh20;6=G@040;:=H@2cSV80/hiR0;B?H`80]I1T
0P2fTFD20;JBHP<0^9AT00@0]Y9R0;B@H02cSel0/HaH0P2bSET00`2cSUX0]8mK0;B?F`020;F@G004
0;JBHP2eTF40]I5Q0;B@H080/hmO0P2bSUh30;2;GPD0/HaO0P2dTf000`2eU640]YER0;NFH`020;RG
I0030;VHI@2kVFT0^iUY0080_9YZ102mVf/00`2nW6`0`9ee0<2MM@060<2MM@P0`j1h2034XGL20<RU
N`040<NTNP36XgT0aJ9h0<FRN080a:5g203:Ygd20<^XOP060<ZWO@38YG/0ajAj0<JSN@35XWP0a:5g
0P39YW`01038YG/0ajAj0<NTNP36XgT20<FRN0060<FUMP34Y7D0aJ=e0<JQM035X7<0aZ1c0P37WW88
0<FPL`030;nJK@30Vfh0`Ye`0080`iia00<0`Ye`0<2KKP2oVVd00P2oWFl20;jLKP<0_I]]00H0_9Y/
0;jJJP2nVVX0_YYZ0;nKJ`30W6`30<6MK@030;nJK@2nVF`0_9MZ0080^iIY00<0_9MZ0;jIK02oVVd0
0P2lV6P20;^GI`<0^YIV0140^IEU0;B@G02eTEd0]i=O0;RDH02iUF40^9AP0;NCG`2fTUh0/XiN0;>?
G`2dT600]I5Q0;JBHP2gTf<0^9AT0;VEI@020;NCG`060;JBGP2eTEd0]91L0;>?F`2bSUX0/HeI0P2c
SUX01P2bSET0/HaH0;2;E`2_RUH0[XUE0:f8E0<0[HQC0`2^RE@30:n:E@060:f:DP2/RE40[8UA0:^8
D02ZQdl0ZHI>0P2XQDd30:V4C@80ZXE>0`2[QTl04`2/Qe80ZhIA0:Z5D02XPdh0Yh9=0:F0B`2TOdX0
Xgi90:V4C`2XPdh0Yh9=0:R3CP2YQ4l0ZhIA0:f8D`2_RUD0/8aB0:j:D02/Qe000P2ZQE000`2ZQE40
ZhED0:b6E@080:V5D@P0ZHI@202XQ5020:N2C@060:J1C02UP4/0Xgi90:9mB02QO4L0X7]60`2ROT@[
ooooo`00:_ooool80:=hA@80Y7]50P2UO4H20:ImA`80Ygi800@0Z7e60:MlA@2WO4D0Yga50P2VNd@2
0:Ej@`P0Yg]:202WOTX0102RNDD0XgY60:MnBP2YP4`30:^2CP030:Z1C@2YP4`0ZH1<00H0ZH1<202X
Od/40:IkB080YGY70P2TNDH90:9iA@0409mjAP2MN4@0VgI209Ud@080V7<o00<0VGA009Ye@@2DKSl0
0`2DKSl409=]?P80TF`o00@0T6/n08iY?02=J3/0RfHi0P2:ICP808EP=P<0OEXb0P1lFC4307]H<080
Me@Z0180MU<[07IC;@1eDBd0M50^07=?;@1cCbl0Kdh[075@;@1bDBh0Le8_079A;P1aD2d0Kdh[06e<
:@1ZC2P0JddY06i@;01`DRh2075C;`0:071B;P1_DBd0L5<[07MG<01kFc80OE`a07eK;P20Fbh0QV0a
08YT=@80Qf<c00H0R6@d08UU=@2:ISH0RfLg08aX>02=JCT208QT=0<0RFDe0`2:ISH00`2BK3d0T6Xk
08mY>P0208iX>@0308mY>P2@JS/0TV`m0080TFLe0P2@IS@308mU<`0708iT<P2AICP0T6Dh091U>02?
ISP0SFLh08aX>00208YX>003091Z?@2?JC`0SVPk0080SFLj00<0SVPk08mY?02@JSd00`2=IcP308iX
>@80SfTj00<0SVPi08eW>02;ICH00P2:I3D00`2;ICH0SFLh08iX>@0808iY=@T0SFLj0`2?JCX5091Z
>`80TFlo00<0TVhn09=]?P2EK3h00P2EJSd01P2FJSd0SVLl08iW?02>J3/0SVPi08iX=`80SVTe00@0
SVTd08mZ=P2@JcL0TVdi0P2CKSX00`2BKCT0T6/g08mZ=P08091Z>`P0S6Ho0P2<J3P208eY>@<0SVXj
00H0Sf/k08IT=P26I3H0QfDg08QV>029IcT208YX>P0308]Y>`2;IST0RfHi00H0RfHi00P0RFLg08YX
>02;JCT0S6Xj08]Y>@29IcL0QV@d08ES<`D0PfDc0`24IS@0801oHc40P6@b085U=@21ICH0P6<g07iQ
=`1lGcL0NUde07YM<`1hG3@0M5P`06iE;@1XD2X0HddX05e99P1LB2D0DD@Q04m2801:?al0AC`O040i
7`0m=b40?CHS03`g900f<200<RlN030]7P0]:ah0:RXN02T[800X:b00:B`S0P0V9al0100U9Qh092DM
02<T700R8a/2024R6P808B@M00<082<L01lR6`0N8AX00P0M81T301`O60807B0I0P0N8AX201lR6`06
01hU7@0O9Qh07bHN01hU7@0M91`06R4I0P0G7QH00`0F7AD05adK01LM6`0601LM6`8061TK01H061XI
01TK600L7QT07b8K028U7P0T9ah09BTK02L[7@0/;R00<34Q038a7`0a;Q/0;R/H02hY5@0`:AT0=BhN
03La9@0b;RD0:RLR024P700O7Ah07alO0P0Q8Qd01P0R8ad08b@L02@V6`0U9aX09RPK02HX6P808R<K
00<08B8J020Q6@0O81P00P0N7aL00`0M7QH07AdK01dM6`0601dM6`P07R4J02007QhN01hN700N7Q`0
7b0K024R700U9Qh0:2XO02X/8@0n<QX0ASLP04Xl8P19>Al0AcHJ04dj701IA2L0I4l`07iN>02?KDL0
UgI=09IdA`2ROTh0/8]G0:R0C02@JC80GTT^04Dd800_:Ad0:R`Y02T^<@0T:2/09B<T02`W90<08bDR
0`0T9R<202DW900302@U7@0U9Qh09bPP00<0:BXR00X0:2TQ02LX800c=2H0=CHX03Lh:P0h>B/0=cPZ
03@e9`0`<B<0;BhP0`0U9R0202HW8@<09bPR200Y:R803`0[;2@0;BdS02h^900b<2@0=C4U03Tc9@0k
=2@0?3DU040h8`11>B80AS/U04Xn9P1?@BL0E4@Z05I7:P0205Q7:`80EdD]00<0ET@/05E3:`1D@RX0
0P1C@BT02@1B@2P0BCdS04Pl9016?2<0@SXS03li8`0l=b<0>cHS03Pe8P0204Hi9P0604Dh9@14=b@0
ASTV04Pk:01;?R/0CD0]0P1DABH0101CA2D0DT<T0593901A@R<205118P80Dd4Y0`1D@RX305E3:`80
DD4X0P1@@2L204lo9P80CShU0P1:?b<01`1;@BH0BD8X04Q2:P15@2X0@chX040n:@16>bT00P15>RP0
0`14>BL0@cPV048g9@02044f9080@CHR01H0@3DS03hb8P0m<B<0?30T03/_8`0j;B@0?S@X03dc9`0l
<RH0>c4U03X`900i;b<0>2hR03L]8@0f:bL0=R/U03L/9P0i;bH0>S0V03/a9@0l<b@0?C@U0P0i;b<2
03P^8P80=bdQ0P0f;2000`0o<R80@3<S048e9@0204@g9`0404<f9P11=2@0@3<S03hc8@80?c8Q00d0
@C4Q04@c8`18=BH0C3HX04hh:P1B?RH0DclW0590:01A@BP0Cd4W04/o9@18?280AS`Q0080@c/V00<0
ACXV04Lj9`1:>bP00P1<>bT00`1=>RT0ASTV04Hi9P0204Lj9`0504Hi9P13=R<0@C@Q040c8015>2D0
0P14=b@01`13=R<0A3LT04Hi9P19?2T0BSdZ05919`1A@2H00`1@?bD00`1B@BL0Dd8X05E4:P0205E2
901_05M49P1JAbT0G4T[05e:;01LBB/0FdPZ05Y7:@1_DB/0Ke4]06]A;P1XCc00Hdha05i=<@1KBc80
FT`b05EB:@1DCbT0DTdW059:9P1CB2P0ETP[05Q:;`1JBS00Id/S06E<901UCBL0HTh[05e=;01IBR/0
EDL/0556:P12>bT0Ach]04i3<@1CA2l0ET@/05]7;01RCC00JU<d06]C9@1ZDRH0JE8V06YE:P1[F2h0
L5de07AR>P1gICl0OF4j07mS?023Icl0R6e208icAP2CN4T0Uga=09UoCP2DQEX0TH9G08]nE025NE40
P7M@07meD@1nMU40O7IB07MeC01dLTT0L6a606]U@@1XGch0HeXk069G>@1PECT0JU8f06U@<P1/Cbl0
ME<`07iH<@26Fc40QeP/08IF:028H2l0SfLf09M^>P2LLCX0X7<j0:Af>P2[OSd0/h=30;:5@@2cQd00
]hQ20;Z:@P2nS4<0`Xi30<B@A036TDD0_i540;fAAP2kTDL0^99;0;JAB`2bTDh0/95@0:nAD@2WT4X0
YHi80:><B02QRTL0X8Q80:69B@2SRdd0Y8a>00<0VH=B0`2HPU4209N1D080Vgm?00<0VX1?09R1C`2G
PDl00P2FPTl01`2DPdl0VX9209^3@`2KQ440W8E209f6@P2NQd400P2ORD002@2LR4<0VhM209Z3?`2I
P3d0VWll09ao?@2MP3h0Wh0o09mc=P0209ec=`0309]c>02JLcX0Ug8k0080UW<m0`2IMSh209Qe?@04
09Md?02FLc/0UW<k09Eb>P80Tg4d0P2BL3<2095_<P80TW0c0P2FLc/0302DLCT0TVlg091]=@2>Jc<0
SFXb08aY<@28Ic40Rf/b08m_=P2DM3T0UgLj09Uj>P80VGXi0P2MNc`309il?@80WG/l00T0W7Xk09]n
AP2GNT80TG@l08ia>@2=L3P0RVde08EX<020Hb/00P21IRl01023J340Q6Tb08I[=027K3D208U^=`80
S6le00@0SG0f08ia=`2?LSP0T7<i0P2AM3X0202CN4<0QF`f07IL:@1_F2H0LU`[07AO<01_GBd0JUPZ
0P1ZFRH00`1YFBD0J5PT06MG8`0206IF8P0706EE8@1TDbD0I5<U06ED9P1VEBL0IeHX06QG:@0206UH
:Q00KE`^0380JEd]06MK:`1TERL0He8T06=A8`1WDRD0JE@W06aE:@1oFRd0RfTl0::0D`2jVFh0cJf4
0=JiT@3G^i@0e[ZC0=>iWP3D^id0e[fO0=NnW`3D_9X0bK6=0;VQN`2/U6h0YXYU09^0E@2?MD80SG@l
09QoB@2ZSf80^iil0<FWR`33/i40b;RG0=2oX@3Ib:h0hLni0>KD`03Ye/L0j]O80=kG^P3Pe[/0hm>l
0>C;]@3P`jD0fKJ<0=:^M03>Yf@0a:9U0;^IG080/HeA00d0[8E:0:j6B`2aQdd0/hU?0;F8C`2/Pdd0
[XE?0;28E02dS5T0]HmN0;FAH@2dTV80]99T0080/IAX01h0/9=W0:nBIP2/Sf<0Z8]O0:F8G02RQET0
W8M>09^5C02HPD/0UG]8095eA@2?L440S6/n08]Z?@1oH380Nel`07II;@1`EBX0JU4X06I?9P1SCBH0
HT`U05I18P1E@2<0Dd0R04ln8P1<?280BC/Q04Pi8P15>B4303d`7@80?2lL0`0k;Q/8034_6P0303DY
6`0d:1X0<bLI0080<RHH00<0<bLI03@X6P0e:A/0200_9Ql802LW7@P0:bPI00@0;RPH02lY6@0_:AT0
;bTI0P0`:QX2034[6`0303T]7`0g:ad0=BTK0080<bLI00@0=BTK03L[7@0i;Al0=RdN0P0g;Ql01@0h
;b00>C0Q03Xa8P0j<B80>c8S00P0?C8N1@0o<R8303ha8@<0@3@N0P11=Al3048f800304<b8014<b40
AcHT00<0BCPV00<0AcHT04He8`16=2002016=20404Pc7P0704Xe801=>2<0CcXU054l9`1F>bH0ECXU
05@i900205<h8`0605Dj9@1G?2L0FChY05Xo901H?B80ES/P0P1E>Ql06`1F>b00F3dR05Xo901A>b@0
DS`T05Dm9@1H?RD0Fd0U05m19@1P@bD0HT<V064n801R?b40Hd0R06I39@1XABL0JTLY06a9:`1]BR`0
I4hY06==:01SBbL0HdTV06E89P1XBRP0JdXY06e<:`0306i=:P80Kdh[0`1`Cb`407=@:P@0LTlY0P1g
E2h0101gE2`0Me@Z07QF:@1hERP207QF9P80P5/^00<0PE`_089M<023GS400P24Gc801025H3<0OUT/
085L;`24Gc8208MR=@0308EP<`22GC00OeX]00@0P5/a101oFS0807UF;P80NEDa00/0NULa07aI<@1m
FS00OU`_07mM<020GS00Qel^08QP;`2;Hc80SFDd08iV=@0208eU=00M08aT<`28IBl0RFH`08YW<@2<
JC<0SV/e091]=`2BKcT0Tg0j09Mb?P2FLCd0U6lk09=^>P2DKc/0UW4m09Qc?`2JMD40Vfln09]a?`2N
M480X7Q509mjAP2ONdL0WGa709akAP2NODL0Wgi80:1oB@2QP4X00P2SPT`0102TPdd0YHA>0:J5C`2W
Pdl20:R4D0030:Z6DP2[Qe<0[8QD0080[HUE00<0[8QD0:^7D`2YQE400`2WPdl20:V5D@@0Yh=C1@2V
PU820:F1D@030:B0D02SOdl0Xgm?0080XWi>0P2TOU420:EoDP<0YX1C00D0Yh5D0:AoBP2TOdX0YH1;
0:J1C0020:N2C@80Z8=>202ZQU830:R4E0030:V5E@2ZQUH0ZhMG0080ZhMG0P2[R5000`2[R580ZXIB
0:Z6E0020:V5E@060:V4E`2ZQE40ZXEA0:^6DP2/Qe<0[HQD0P2^RED00`2_RUH0[XYJ0:j:FP090:j:
FP80[h]K0`2`S5`20:n=G`80/8iP01@0/HmQ0;:@HP2bT680/i5S0;6=F@2bSUX0/hmK0;B@G02cSe/0
/HeI0:j:EP2]RED0]HeJ0;>;F02aREH0/8QE0;69EP2cReP0]XiK0;R@G@P0/HaH0P2_S5H20;2=E`<0
/HiH00D0/XmI0;>>FP2dSe/0]8mK0;F@G0020;JAG@80]i9N00D0^IAP0;VCHP2iTf80^YAU0;ZDI`02
0;^DJ@80^iA[0P32V6h01031VVl0`9]_0<6LL02oWG020;nNL@030<6KKP32W6l0a9ia0080aZ1c00<0
aImb0<BNL@33WG000P34WWL40<>MMP80`Yae0P30WW000`31Wg40`Z1b0<>QL`020<BRM0040<FSM@34
XGL0aJ9h0<NTNP80b:Ek00@0ajAj0<FRN034XGL0`ZEm0P34Y7d00`35Xgd0aZ=m0<RRO@020<VQO@P0
aZAf0`36XG@30<FPL`80a9mb0P33WGT01P34WWT0a9ig0<>NM031W700_iY^0;jIK0<0_I][0`2lVVX2
0;^IJ@P0_YQa0P2kVF/30;bJK0<0_I]]0P2oVf/0102nVVX0_IUY0;bHJ02lV6P20;^GI`060;bHJ02k
UfL0^iMW0;ZFIP2iUFD0^9AT0P2gTf<00`2jUVH0^9AT0;FAH@020;B@H0040;FAH@2hU6@0^YIV0;F?
HP80]HmP00<0]8iM0;B?F`2cSUT00P2cSUL20;F@H`060;B?HP2cSV40/XeP0;:=H02aS5l0/8]N0`2`
ReL20:n:EP<0[XUE2@2/QUD0202ZQE00[8MB0:j9E02_RUD0[XUD0:^6D@2XPdh0YX5<0`2[QU420:Z5
D0<0ZHA?00/0[HY:0:b8BP2[QdT0ZHE90:J2B02TOdP0Xgi90:9mB02VPDd0Z8=?0:Z5D@030:b7D`03
0:Z5D@2YQ500[8MB0080[8MB0`2[QU420:Z5D0040:Z7D@2YQU00ZHI@0:R5C`80YhA>0P2VPdd80:N4
CP80ZXAC00@0ZHA@0:V4C`2XPdh0Z8=<0P2XQ4X20:F2C0030:B1B`2SP4X0XWm90080XGi800@0X7e7
0:=nB@2SOTT0Xgi9:oooool002[ooooo202SN4D20:AkA@80YGa60P2VODL20:MnB0@0Yga50P2VNd@2
0:Ej@`P0Yg]:202WOTX0102SNTH0YGa80:MnBP2YP4`20:Z1C@030:V0C02XOd/0ZH1<00L0ZH1<202X
Od/0102WO4T0YW]80:IkB02VNdP20:EjA`80Y7U62@2RNDD01@2PNdL0WgY609ag@`2JMD40VGA00080
VWE100<0VgI209A^?`2DKSl00`2DKSl309=]?P80TF`o00@0T6/n08iY?02=J3/0RfHi0P2:ICP308IQ
=`0508EP=P24GcD0Q5le08AO=@23GS@00`1lFC4207]H<0<0NUL_00X0N5D[07MD:P1gE2`0MU<]07EA
;@1dD2h0Ldl]07=?;`1`Cb`0LE0]0`1bDBh0201`Cb`0KTdZ06e<:@1ZC2P0JddY06i@;01`DRh0LE<_
0P1`DRh02@1_DBd0L5<[07MG<01kFc80OE`a07eK;P20Fbh0QEl`08YT=@0208MS<`0408QT=029ICD0
RVHf08]W=`80S6Ph0P29ICD208YV=P<0RfLg00@0S6Ph095[?02@JS/0SfTj0P2>J3T00`2?JCX0T6Xk
095[?002099X=P80TFLe0`2@IS@01`2?IC<0TFDh091U>02@ICP0SfHh08eW>02<J3P00P2:J3P00`2@
JSd0SfTl08iX>`0208aV>@0308iX>`2?JC`0T6Xm00L0SFLh00@0S6Hg08iX>@2=IcP0RfDf0P2:I3D0
0`2;ICH0SFLh08iX>@0808iY=@T0SFLj102?JCX4091Z>`80SV`l00<0T6`l095[?02DJcd00P2EJSd0
1P2FJSd0SfPm08mX?@2?JC`0SfTj08mY>080SfXf00@0SfXe08mZ=P2@JcL0TVdi0P2CKSX00`2BKCT0
T6/g08mZ=P08091Z>`P0S6Lm0P2<J3P208eY>@@0SVXj0P28ISP308UW>@<0RVPj202;IST208UW=`80
RfTi00@0RVPh08UW=`27ICD0QF<c1P23IC<208AV=00P07mS<@20I380PFDe085U=P20HcL0OV4g07aO
=`1jGCD0NE`b07MK<`1dF300KUD]06Q@:P1SCBP0GTXW05e99P1AA240Cd8P04Xo7`15?1l0@3TO03dg
8@0m=R<0?3LT03H`800c<1l0<2dN02d[7P0Z:Qh0:B/P02P[800Y;2<202HW7`0402DV7P0T9Ad08b@L
028S6`808B8J0P0Q91d00`0P8a`07b8K01hQ6P0201dP6@<071lH0P0M81T201hQ6P807b8K0P0N9Ad0
100O9Qh07RDM01dT700J8AT201PO5`0301HM5@0G7A/05adK00H05adK0P0I6Q`05P0I6aX06A/H01`N
6@0O8Q/08B@M02<V7@0S9aT09RXL02/]7`0_<200<S4O038_700`;AX0<2/G034Z600f;al0>38T03<_
900Z9b008B0L01lN700N7Qh2024R7@06028S7@0S91`092HK02DW6P0V:1/09RPJ0P0R8a/0100Q8QX0
824I01lP600O81P201hO5`P07AdK200N8AX0800N7Qh07QhL01hN700O81/08B8L02@U7@0W:Ah0:B/P
03da6`13=al0BCXS04Ph7`15=1X0BSHK05E2901PBbh0OEdg08a/A@2EM4/0UG=60:5mC@2`ReL0ZHA?
09Qa>P1WD340C3`S03@/7`0[;2L09bd]02@X:@0V9B<0;2LT0`0S9B8302@V8`809BLT00<092DM02DV
7P0W:2000`0Y:R802P0X:B409bPP038c9@0c=2H0=SLY03Lh:P0f=bT0<S<U02l`8P0/;Al302DV8080
9RLQ0`0W:28802TZ8P0?02//900];B<0;RhT038`900e<BD0>C<U03/d900l=BD0?cLR040h8`14>B<0
B3`T04i09P1B@RP0E4@Z0080EdHZ0P1FA2`00`1E@b/0E48Z05=1:@020590:007054o9`1;?B<0BCdU
04Lk8`14>B<0@3PS03hg900203/f8`08048e8P11=240@3<P040c8011=240A3LT04Hi9P18>bP205=4
9`80DT<V0P1A@RD2051190<0Dd4Y0P1D@RX305E3:`80DD4X0P1@@2L204lo9P80CShU00T0CClT04a1
9@1<@2H0Bd4X04Q0:@15?bT0@SdW044l:015>RP00P14>BL00`13>2H0@SLU044f9002040e8`80@3DQ
00H0?c@R03hb8P0m<B<0?C4U03``900l;bH203dc9`0403`b9P0k<BD0>S0T03T_8`80>2hR00P0=R/W
03H[9@0g;2H0>BlV03X`9P0k<BD0?3<T03dd9@80>S0T0P0i;b<403P^8P0303ha8@0o<R80@C@T0080
@cHV00@0@SDU044d9010<b<0@3DS0P10<b801@12<R80AC@T04Tf9`1==bT0CcT[0080DShV00/0DClW
0551:01?@BL0BclU04Tm8`17?B80@c/V04@l9`16>bL0B3/X04Xk:00204`k:@0304hk:P17>RL0AcXW
0080B3/X00D0AcXW04Dh9@13=R<0@C@Q04Hi9P0204Dh9@0=04@g9015>2D0AcXW04Xm:P1;?R/0DT4W
05509P1@?bD0CchT050o9@1A@2H0Dd8X05E4:P0205I39@0305M49P1IARP0FdPZ0080G4T[0P1KB2X0
3@1/CRX0JdlZ06Q>;@1WCRl0Hdha069><`1NCS@0GThe05]C;01IDBX0EdlZ05E;:01FBBT00P1FB2/0
4@1HB2h0I4/S06E;9P1TC2P0HTh[061=;@1KC2d0EdT/05I8;@18@2d0Bd<`04m4<01B@b`0DT8Y05Q4
:@1PBbh0IU4d0080K5D[01<0KEH/06eG;P1^Fc40LEhf07AQ>@1dHSX0O60i07iR>P23Icl0RFi3091e
B02FNd`0Vh5@09f3DP2GQUX0UHAH0962E`2=P5H0RWiF0080QWeF02`0QGeH07mlD@1oNU00NgI>07Ua
C01dK4P0L6I306aQ@@1ZGcl0KEa206]G?01[DcL0Ke@f07EG=@1lF3@0OEH_07aB:P1hDbH0OeTZ08EO
;P2;Hbl0SVD]09=Y;`2KKc80XGDf0:El>P2XOCT0ZWlk0:j1?@2bPcd0]XHn0;V7?P2jR3l0^hXn0;Z:
?P2iRd00^8a50;F=A`2eST/0]8i=0;:?C@2]SdL0[8i80:Z<AP80Z8U600<0ZHY90:Z;BP2[S4/00P2R
R4d20:67C0050:26B`2OQDX0WhE:09j4B@2WQ4`00P2UQD`00`2TQD`0XhI<0:67C0020:28C0060:F7
A`2UR4H0YXU70:J9A@2VRD<0YXY10P2VRT001@2QQT<0WhA109f0?P2KO3/0VWPh0080VWLg00L0W7Hg
09Y`=02JL3@0VG4f09Q`=@2GL3L0U6lh0080Tg0j1P2ELSX309Aa>@D0Tg4d0`2BL3<209Eb>P0409Aa
>@2BKcL0T6de08m/=080SFXb00H0RVTc08a/<`2@L3L0Tg<h09If>@2HNCT209Qi>00309]i>P2LNS/0
WW`m0080X7ho00H0Wgdn09ek?02LNS/0VGa409Ag?`2?LSX208a_=`0308U/=024Ibl0Of8Z0080PFH_
00H0PVL`08AY<P26Jc@0Qf`e08Q]=P29KSL208a_=@0308e`=P2>LCL0Sg8h0080T7<i00T0TG@j08md
?`23JS@0MU`Y075J:01cGB`0M5l`06iL;01XERP0101XF2D306MG900606IF8`1TDbD0I5<U06ED9P1V
EBL0IeHX0P1XEbT00`1YF2X0K5/]06aK;@0>06aK;@0>06MJ;@1UF2/0HeDX069A9@1SD2D0Ie8W06YE
:P1/EB/0OeX]08]Y?02SPE@0^iY_0<f]Q03E^9020=JjT`0R0=>iWP3D^id0eKbN0=NnW`3C^iT0b;2<
0;RPNP2[Tfd0XhMR09YoE02?MD80SWDm09V0BP2/TF@0_9mm0<JXS036]YD0b[VK0=;1Y@3Kb[00h]2j
0>KD`03Ye/D0jMK70=gD]@3Md[H0glfe0=k6[03J^i`0dJn20<VUJ`35WUd0^IMJ0;2>D@80Yh=700<0
Xga10:Em@P2XP4D00P2[PDL0202YP4X0Zh9<0:j6DP2`ReL0/XiL0;:@H02cTF40/Y9S0P2/Sf<07`2[
SV80ZHaP0:N:GP2SQUX0Wh9F09f0E02GPTT0UX17099kA@2@MT<0S71008Y[?@27IST0QF@i07]N<P1i
G300LeP]06aC:P1WD2L0HddV065;901NBRD0DC`O050m7`1>>Ql0BcXP04Ph7`15=Ql0@CDM044e7`0m
<1d00`0l;a`203/^6`80>RdJ200a;Q/00`0c:Q/0<RTJ030W600202lV5`03030W600b:AX0<bXK00P0
;bHO200W9ad802/X6@<0;RPH0P0_:AT3030Z6P0303D/7@0d:a`0<bXK0080<RTJ00<0<bXK03@[700e
;1d00`0f;Ah303L^7`80>2lP200k<1`00`0o<R80?S4Q03ha8@0503ha8@0403lc7@10=1h0@3@N040d
7P80@CDO0P12=R000`13<R00A3<Q04He8`0304Pg9@0304Lf9016=B<0AC@P00P0AC@P1018<ah03`1:
=B00C3LR04lj9@1@>bH0E3/U05<j901B>B<0DCPR058i8`1C>R@0EC`V05Ln:01I?BD0Ec/S05Hj8P02
05Di8@0L05Hj8P1G>b<0FCdU054k901A>b<0ECdU05Pn9@1K@2D0GT0T06139@1Q@RD0Hd0R06A18`1U
@R@0Id@V06Q59`1ZAbT0JdPZ06a9:`1TCRT0HddX06=;9`1SBBH0IDPV06Q::01[BRT0K4/Z06e<:@<0
KTdZ0P1_CR/2071?;0P0LTlY0P1gE2h0101gE2`0Me@Z07ME:01hERP207QF9P80P5/^00@0PE`_089M
<023GS40Peha0P24Gc800`1oFRd0PE`_08EP<`0208MR=@0308EP<`22GC00P5/^0080P5/a0`1oFS03
07iI;`P0N5D]00/0N5@`07UE<@1jEc40NeP`07aI;`1nG2l0Oed`07mM;`26GRd0Qel^08YR<@0408aT
<`0;08]S<P27Hbl0R6@`08UU<@2;Ic<0SFTe08m[=`2AKCT0TVhj09E`?02DKc/00P2CKSX0302DKc/0
UW4m09Qc?`2JMD40Vfln09ab@02OMD<0X7Q50:1kA`2ONdL0WGa709akAP80WWe800L0Wgi90:60B`2R
PD`0XX5<0:>2C@2TPdh0YHA?0080Yh=?00@0Z8A@0:V5D@2ZQU80ZhMC0P2/R5@0202[Qe<0ZXIB0:R4
D02WPdl0YX9>0:N3C`2XQ500ZHEA0P2WPe<30:J2DP@0YH5A0P2TP5020:=oC`80XWi>00<0XGe=0:9l
C@2SODh00P2SODh20:AnC`80YGm@00P0XWe80:=nB@2TOdX0YH1;0:J1C02WPTd0Z8=>0:V4C`P0ZHEA
0P2XQ5@20:V5E@0<0:Z6EP2[QeL0ZhMG0:^7E`2[R500ZXM?0:Z7D@2ZQU80ZHEC0:V5E@2XQ5@0Z8=F
0P2ZQE40102[QU80[8MC0:f8E02]R5@20:j9E@T0[HUI0`2^RUX20:n;F`80/8aL00<0[XaN0:n=G`2_
SEl00P2`SV001@2aSf40/Y1R0;:@HP2_ReL0/8aH00<0/HeI00@0[h]G0:f9E@2/R5@0/h]H102bRUL0
0`2cReP0]HeJ0;J>F`080;6<F0<0[haF0P2`SEL30;6>F080/hiJ0P2dSe/0102eT5`0]Y5M0;JAG@2f
TEd20;RCG`030;RBH@2iTf@0^I=V00<0^Y=X00@0^Y=Z0<6GK@31Ufd0_iQ]0P2oVVh02`2nW6l0_Ia_
0;fLK`30VVd0`I]^0<>ML034WW40aImb0<BNL@33WG00`Ya_0080`iid1P32WG<01P2oWFl0`9i`0<2N
L031Wg40`Z1b0<>QL`80a:9d00<0`j1f0<BQM`36XgT00P37Y7X01036XgT0a:5g0<>PMP32YGd20<BT
O@030<FSO@36Xgd0b:9m0080bJ5m2036Y7H01038XgH0aj9e0<NRM@36XG@20<FPL`80a9mb00P0`Yah
0<>MN034WWT0a9ig0<>NM031W700_iY]0;jIK0<0_I][0`2lVVX20;^IJ@P0_YU_202lVV`0102nVVX0
_IUY0;fIJ@2mVFT40;bHJ080^iMW00<0^YIV0;VEI@2hU6@00P2gTf<0102fTV80]i=S0;NCH`2fTV82
0;FAH@090;JBHP2gTf<0]i=S0;F?HP2eSf00]8iO0;B>G@2dSe/0/hiI0080/hiG00H0]I5Q0;B@H02d
T600/hmO0;:>GP2aSEd20;2<G080/8]G0P2_RUH30:j9E@030:f8E02/QUD0[8IE00L0[8IE00<0ZhIA
0:b7DP2/Qe800P2/Qe800`2ZQE00ZHA?0:R3CP020:^6D@80ZXE@0`2YQ4l01`2XPdh0ZhM90:Z6B02Y
QDT0Z8A80:N3B@2UP4T00P2TOdX0202VPDd0Z8=?0:Z5D@2[QU80[8MC0:^6DP2ZQE40ZHA@0`2/Qe82
0:^6D@<0ZXE@00<0ZXMA0:V6D02YQU000P2XQDl20:N4CP030:J3C@2WQ4h0YhA>00H0YhA>0P2ZQ5<0
1`2YQ500ZHA?0:R3CP2XPd`0Z8A:0:N3B@2UPT`00P2TPD/00`2SP4X0XWm90:5nB0020:1mA`<0XWe8
:oooool002[ooooo202SN4D20:AkA@80YGa60P2VODL20:MnB0<0Yga70P2VNdH30:EjA@P0Yg]:202W
OTX00`2VODT0Ygi:0:QoB`020:V0C0030:QoB`2WOTX0YWe900P0ZH1<202XOd/30:MlB@80YW]80`2U
NTL90:9iA@040:5lB02PNdL0WWU509ehA0@0W7M30`2EKd0209A^?`<0Tfdn0P2AK3l0102@Jch0SVTl
08eX>`2;IST208YU>080R6<i00H0Qf8h08EP=P24GcD0Pehd089M<`21G38307]H<080NUL_0`1iERh2
07QE:`0307MD;01fDbd0ME4]0080M50^00<0Ldl_071?;01`Cb`00`1aD2d01`1`Cb`0KTdZ06e<:@1Z
C2P0JddY06e?:`1_DBd00P1`DRh206mA;@08075D;01gEc00Ne/b07eL<@1mFbh0OeX]08EO<029Hc@2
08MS<`0408QT=029ICD0RVHf08YV=P@0RfLg0P2<J3P308eY>@0408iZ>P2AJc`0T6Xk08iX>@80SFLh
00<0SVPi091Z>`2AJc`00P2CJCL2099X=P<0TFLe00L0T6Hd095U>02@ICP0T6Dh08mV>02=IcP0S6Ph
0080RVPh00<0T6Xm08mY?02=IcX00P2<IST00`2=IcX0SfTl091Z?@0208eW>080S6Hg00@0RfDf08YT
=@29Hc@0RF<d0P2=IcP408]U=P80SFLh202>JCD908eW>PP0SfTj0P2;JCT01P2=JCT0SfTj099Y>`2D
JC`0UFXm09IZ?@80TFXo00<0TF/n095[?02AJcX00P2AK3P0102AK3L0SfXf091[=`2AK3P2099]>@03
095/>02@JcL0SfXf00P0SfTj202<Icd308aX>080SFTi0`2>JSX408]Y>`<0RVPj00<0RFLi08YU>02:
ICP01P2:ICP02028ISH0RFLg08YX>02:J3P0RFLg08QV=P27ICD0QV@d2023IC<0801oHc40P6@b081T
=020I3D0Of8f07eP=P1lGcL0NUde07MJ<01eFC40LUH^06eD;01YDB/0IDlZ061<:@1OBbP0DD@Q04m2
801:?al0AC`O040i7`0m=b40?CHS03`g900g<B40=34P034^7`0^;1l0:RXN02T[800X:b00:B`S0P0V
9al0100U9Qh092DM02<T700R8a/2024R6P808B@M00<082<L01lR6`0N8AX00P0M81T301`O60807B0I
0P0N8AX201lR6`0601dT700N9Ad07RDM01hU7@0M91`06b8J0P0H7aL00`0F7AD05adK01LM6`0601LM
6`806AXL01H06A/J01XL6@0K7AP07R4J024T7@0S9Qd08BDG02@X6P0Y:ad0;RlO038a7`0d<Ah0<c0M
03@_6`0d;A/0=c0N03Pb900d<2D0;2TP02<R7@0N7A/071`J0P0Q8Qd01`0R8ad08b@L02@V6`0U9aX0
9RPK02HX6P0S91`00P0R8a/00`0Q8QX0824I01lP600201hO5`P07AdK200N8AX0800N7Qh07QhL01hN
700N7aX0824K02<T700V:1d0:2XO03X_6@11=Al0ASXR04Hh7P12<QP0A3<G04lk801HABL0N5Xd08QX
@@2ALDP0Tg9509ekB`2]RED0[XUD0:9mAP1eFcX0FTH[03/b8@0[;2@09RXY02<W:00V9R@0:bLT0`0S
9B8302@V8`809BLT00<092DM02DV7P0W:2000`0Y:R801@0X:B409bPP02l`8P0a<R@0<c@V0080=3DW
00<0<C8T02d^800Z:ad00`0U9R0202HW8@<09bPR200Y:R801P0[;2@0;2`R02h^900a;b<0=30T03Pb
9080>c@T00L0?3@Q03de8012=b<0ASXT04/l9@1??bH0DT8X0080E4<Y00H0ED<[05A2:P1D@RX0Dd4Y
0590:01A?bL2050n9P0804`n901<?BH0B3`T04Dj9011>B@0?cPU03df900l=b@204<f8`06048e8P13
=R<0@cHS04Dh9@17>RL0B3/X0P1B@RP305519`<0D40V00@0DT0X05=1:@1C@BT0Dd4Y0P1D@RX205E3
:`80DD4X0P1@@2L204lo9P80CShU0P1?@BH01P1=@BL0C48Y04Q0:@14?RP0@C/U03lj9P80@cPV00<0
@SLU044f9010=B<00P0o=2801P0n<b40?S<O03hc7`0n<b40?S8R03hb9080?S8V00H0?C0W03dc9`0l
<RH0?38V03/a9@0j<2@203T_8`0903P^8P0f:bL0=R/U03L/9P0i;bH0>S0V03/a9@0l<b@0?C@U0080
?38V0P0k<BD303X`900503T_8`0l<200?C4Q03hb8P0o<b<00P10=2@00`0o<b<0?S8R048g9@02048e
900=04@d9016=BD0BSLX04hh:P1@>R`0DCdU058n9P1A?bL0DD4X04m19`1<@2H0BShT04Pn8`0204Dm
:00804Ll:018>bP0Bc`Y04`k:@1=?2X0CS/Z04Pk:019?2T204Xm:P0604Tl:@17>RL0ACPU04<f8`18
>bP0AcXW0P16>BH03017>RL0BC`Y04/n:`1<?b`0DT4W05509P1@?bD0CchT050o9@1A@2H0Dd8X05A3
:@80ET<U00<0Ed@V05U6:01KB2X00`1LBB/09`1KB2X0I4XW06A::@1TC2X0Hd`/06=>;`1SD380IE4f
06=B=P1RERh0HED_05mA;01LCR/0FDXY05M8:@1GB2/0ETLZ069:9P1RBRP0HT/Y065=;01PCBd0GD`^
05]<;`1JBbh0DTLa05=8<P1CAbl0DT@Z05109P1C@RH0FdL/065><01[EB`0K5H]06mI<P1bG3D0M5hg
07EO>00207IP>@0807eQ>@20I3`0QFXo08]`@`2BMdP0VGm>09j4D@2PQU<209V7E`0609V8FP2HRUd0
UhQM09F8GP2CQed0TXIN0P2=QEL07P2=Q5T0Rh9I08MnE@21N540O79>07Q^BP1bJ4l0K69706QJ?`1W
ESX0JUDh06eD=P1[D3<0JTd_06]98`1_CRD0ME8X07YE:01lF2H0PE`W08UR:`2=IRd0Tf`a09A]<P2G
Kc80Vg8d0:1d=@2TMcH0YWTf0:Yj>080/Whc00T0/X0g0;>3>`2dQCl0]8M30;F:AP2fRdL0/he60;:<
A@2aRd@00P2`RT<00`2aRd@0/Xa50;>=AP020:n=AP040:j<A@2]Rd@0ZhU20:Z8@@80ZHM000H0]8U5
0;::A@2aRTD0/HY50;2;A@2^S4D20:f<A@80/8]700l0[hY40:j9@`2/Qd00ZhLm0:^7>`2ZQSX0Xgm1
0:5m?`2ONC/0W7@g09Y`=02IK340VF/`09QZ;`2EJbl00P2DK3400`2BJc80T6/d08i[=@0208a[=P07
08i[<`2?K3@0Sf`d08m/=02@KCD0TFhf099_=`0209=`>00309=a=02DLSD0U78e00D0U78e0P2DLCT0
302CL3P0TFhf091]=@2?K3@0SV/c08eZ<P2<JcD0SVhe091`=`2CLcP0UGDh09Ig=`80UWLf0100UgDf
09Yh>@2OOCh0XX110:>1@P2QOd00WW`m09]i>P2FND40TG@l08a_=`2:KCD0RF`d08MZ<P22IBd0OF0X
0P21IRl01P22Ic00Q6Tb08EZ<`26Jc@0Qf`e08Q]=P80S6le0P2=L3H0302>LCL0Sg8h091c>@2@LcT0
RFhi07mV<01gGBX0Le`Z07AN;@1cGRl0K5XZ06ID9P@0IUHU0`1WEbH00`1XF2L0I5<U06AC9@0206ED
9P0406IE9`1WERP0J5LY06QG:@P0JEPZ201[FR`03P1TEbX0HUDX065C9P1QD2@0HTlT06MB9`1ZEBX0
KEH/07mJ;@2=Jch0YH=F0;^JK`3<[8<0dkJ>0P3E^I805P3C^Ih0e;^M0=FlWP3F_Ih0d[ZH0<J^RP2f
WWP0ZI5[09n3GP2GO540SgE2091g?`2LPdd0[Y=V0;jQO`37ZHd0b[VK0<nnXP3FaJT0g/fc0>CB^P3W
eKl20>SF`P0:0=kA/@3McZl0g<V[0=RoX03@/X`0aZAf0;fHH@2gTE80Z8Q?0:20A`80VGHn00d0UW4j
09Ub>`2NMCl0X7M10:5f@@2RNd@0YGi70:N2C@2[Qe<0[h]I0:n=G@2^SUd0[hmP00<0YHQL01<0XhIJ
0:23E`2MP5@0VGa@09MjCP2@Nd@0SgQ208ae@@2:L3l0QVXk08=T>021H3D0Oehe07QK<@1dF300Ke<[
06Q?9`1SBbD0GdTT0080FdLT00P0C3TK04/g7018=a/0ACDK048d6P0n<QX0?C4K03/`6P<0>RlM0P0i
;Q`303P]6`P0;b`I00<0<RPL034W6`0_9AT00P0^91P00`0_9AT0<BLK038X700802dV7PP09RHL200Z
9QX302dW6@80;RPJ0`0_:A/00`0a9a/0<RPL03<Y7@0203@Z7P0303<Y7@0b:1`0<BLK00@0=B/O0`0d
:Qh00`0c:Ad0>BhL03T^700603T^70P0?C0P00@0?S4N03lb7`0o<Ql0?c8O0P10<b02044d8@0604<b
8014<b40AC@R04He8`17=R@0ASDS0P15=28904@c8@80AS@N0P15<ad01P17=Al0BCLQ04`j901=>bD0
DcXT058i8`80DCPR00L0DSTS05<j901D>bD0EC`V05Hl9@1E>b@0E3XS0080DcTR00/0E3XS05Dk901F
?2D0D3XS054k8`1D?2@0EcdT05Xo901N@2@0Gd8T06529@0306I59P80IdHW0`1XAbP02@1SCBP0HT`W
069:9P1RB2D0IDPV06M99`1[BRT0K4/Z06a;:00306e<:@80KTdZ0P1_CR/7075>:007079?:@1fDbd0
MU<]07IC:`1gE2X0MeDX07QF:00207QF9P0607mJ;@20Fbh0P5/^085L;`22GC00Peha0P24Gc800`21
G2l0Peha08EP<`0208MR=@0308EP<`22GC00PE`_0080OeX`0P1nFBl207eH;P80O5L]201gE2`207MC
;`0:07QE;`1jEbl0NeP^07aJ;@1mFbh0OU`^089L;@23GBh0QEl`08MQ<P80R68c0P27HC801P26HRh0
Qf<_08QT<02:IS80S6Pd08eY=@80Sf/g0`2AK3P02`2BKCT0U6lk09Ia?@2IM400VWE109a`?`2MLd40
WgE30:1hA@2PNdL0Wg]70080W7]60P2MO4L0202NODP0X7m:0:60B`2QP4/0XX5<0:>2C@2TPdh0YX9>
0P2WPdl00`2XQ500ZHEA0:Z6DP020:^7D`080:Z6DP2YQE40Yh=?0:J2CP2UPDd0YX9>0:N3C`2XQ503
0:J2DP80YH5A0P2TP500102SOdl0XWi>0:9nCP2ROTh30:5mC@80X7a<0`2PNT/30:5kC080XWa=00P0
X7]60:5lA`2RODP0Y7m:0:F0B`2WPTd0Z8=>0:V4C`P0Yh=?00@0Z8AD0:V5E@2YQED0ZHEE0`2ZQUH0
1P2[QeL0ZHI>0:V6CP2YQU00Z8A@0:R4DP80Yh=C00H0Yh9E0:V4D02YQ500ZXEA0:^6DP2/Qe<20:f8
E0030:j9E@2/R5P0[8QH00L0[8QH0`2]RET20:j:FP80[h]K0`2^S5h30:n=G`80/8iP00d0[8QD0:f9
E@2]RED0[XYF0:f9E@2/R5@0ZhMC0:Z6DP2^RED0[hYF0;2;E`2aS5P0/XeI0080/HaH2@2`ReL20:j;
E@80[haF0`2`SEL00`2aSUP0/XeI0;>>FP020;>>FP<0]8mK00H0]I1L0;JAG02fTEd0]i9N0;NAH02h
TV<20;RBI@050;RAIP2iTVL0_iIZ0;nFJP2mUfX00P2mV6/02`2lVV`0^i]/0;^KK02nV6/0_iU/0<6K
KP32W6l0`ie`0<:LK`31Vfh0`9Y]00D0`9]a0`31W7820;jLKP030;nMK`30WW00`Ima0080`Z1b00@0
`j5c0<:OM@33X7H0a:5g0P35XWP01034XGL0`j1f0<:OM@31Y7X20<>SNP030<BSNP35XWX0aj5j0080
b:5j2037YGL0403:YGP0bJAg0<RSMP37XWD0aZ5d0<FPL`34Wg80`iia0<:LM`33WGP0a9ig0<BOM@33
WW80`Ia_0;nKJ`2mVFT30;fKJ`<0_9YZ0P2kVFT80;jIK`80_I]]0P2lVV`0102kVF/0^YQZ0;VGJ@2i
UfT30;^GI`<0_9QX0P2mVFT01P2kUfL0^YIV0;ZFIP2iUFD0^9AT0;NCH`80]Y9R00<0]91P0;FAH@2f
TV800`2fTV800`2eTF40]91P0;F?HP020;B>G`030;B>G@2cSUX0/hiI0080/XeF00H0]91P0;>?G`2c
Sel0/XiN0;6=G@2`S5`20:n;F`<0[hYF0P2^RED30:f8E0T0ZhIB0P2/Qe80102ZQE00ZHA?0:V4C`2Y
Q4l50:Z5D080ZHA?0`2XPdh01P2XQ4H0Z8A80:R4B02WPdT0Yh9;0:J1C0<0YX5=00<0Yh9>0:V4D02Z
QE400P2ZQE420:V4D080[8MB0P2[QU430:Z5D0030:V4C`2YQU00ZHI@0080ZHI@0P2XQDl:0:N4CP80
ZH=B00@0ZHA@0:R3CP2XPdh0Yh9;0P2WPdT20:B1B`030:>0BP2ROdT0XGi80080X7e700@0Wga60:1k
AP2PNdH0X7]6:oooool002[ooooo202TNDH20:AkA@80YGa60P2VODL20:MnB080Yga90P2VNdP20:Ej
A`80Y7U6202WNdX80:MnBP@0Z7m;00@0Ygi:0:ImB@2UO4P0YGa8402XOd/30:MlB@<0YW]80P2UNTL9
0:=jAP040:9mB@2QO4P0X7]709mjAP80WWU50P2MN4@01@2GLD80UW1109I`@@2EKd00U6ho0080Tfdn
00L0TV`m095/?`2AK3l0T6/n08iY?02=J3/0RfHi0080RVDh0P29I3X01P27HSP0QV4g08AO=@22GC<0
PE`b081K<@<0NUL_0`1iERh207QE;@80N5D[00H0Me@/07IC;@1fDRh0ME4_07A@;P1dD305071?;003
06m>:`1^CBX0KTdZ0080JddY00<0K4hZ06e?:`1^D2`00`1_DBd0201aE2`0MeL`07]K<P1lFc00O5X]
07mJ;@24GRl0R68c0P27Hc<208QT=00408UU=@2:ISH0RVHf08YV=P<0SFTi0P2>JSX308m[>`03095[
?02?JCX0SVPi0080SFLh00<0SVPi08mY>P2AJc`0102CJCL2099X=P80TFLe00H0TFDh091U>02@ICP0
SfHh08eW>02<J3P208YX>00308mY?02>J3/0SFLj0080S6Hi00T0SFLj08iX>`2?JC`0SVPi08eW>02<
ISL0RfDf08YT=@28HS<00P27HC8808aV=`P0SVTe2@2=IcX00`2@JS/0SfTj08mY>P0208mY>P<0SVPi
0P28ISH01P2;IcL0SFLh095X>P2CJ3/0U6Tl09IZ?@80TV]000<0TV`o099/?@2BK3/00P2BKCT00`2B
KCP0T6/g091[=`06091[=`P0SfTj202<Ic/208]W=`80S6Ph0P2=JCT208iZ>P80SF/m00@0S6Xl08]Y
>`2;JC/0RVPj0P29IcT808YU>0<0R6Hf00<0RFLg08QV=P28ISH00P27ICD308AV=0@0PfDc0240PV@b
081T<P20I380Of<c07mS=01nHCD0OF0f07aO=`1kGSH0MUT_07AH<01bERh0KE@/06UA:`1UCbX0HDdZ
061<:@1AA240Cd8P04Xo7`15?1l0@3TO03dg8@0m=R<0?3LT03Pb8P0e<R40<RlP02h/7`0Z:Qh0:B/P
02P[800X:b800P0V9al0100U9Qh092DM02<T700R8a/2024R6P808B@M00<082<L01lR6`0N8AX00P0M
81T301`O60807B0I0P0N8AX201lR6`807B@L0P0N9Ad01@0M91`06b8J01TP600I81P05ahF00P05adK
0P0J6ad05P0I6aX06Q`I01/M600N8AX082<L028U700O8aD08RHH02LY6`0/;Ad0<S4O03Db7`0f<b00
>3<O03H_700h<Ah0>38R03Da9@0_;2<09BDM01lN6P0J6aH2024R7@06028S7@0S91`092HK02DW6P0V
:1/09RPJ0P0S91`00`0R8a/08B8J020Q6@0201lP600301hO5`0M7A/07AdK00H07AdK200N8AX0800N
7Qh07QhL01dM6`0N7aX07b0J028S6`0T9Q/09RPM03D]600n<al0@cPR048f7P0o<AL0?blE04Lf701?
?R80LED^081S>`2;KT@0T75309UiB02XQe80/8eG0:f:DP28J440K5<d04Lk9@0_;B4092TU02@X9`0W
9bD0:2LS0`0S9B8302@V8`809BLT00<092DM02DV7P0W:2000`0Y:R801@0X:B409bPP02`]7`0^;b40
<C8T0080<S<U00<0;c0R02`]7`0Y:Q`00`0U9R0202HW8@<09bPR200Y:R803`0Z:b<0;2`R02d]8`0a
;b<0=30T03Pb900j<b<0>c@T03Xa800k<b00?c@R04<f8`19>RD0CCdV04lo9P020590:00605A2:P1C
@BT0Dd4Y0590:01A?bL0D3hV0P1??BD0201??bH0CShW04`m9P18?2H0ACXV044i9P10=bH0?SLU101:
?BX0101;?R/0C3l/04`o;01=@2d805109P80DT0X0`1C@BT305A2:P80DD4X0P1@@2L204lo9P80CShU
0P1A@BL01P1@@RP0CD4Y04Xo:@14?2L0@CTT03hg9080@SLU00<0@CHT040e8`0o=2800P0n<b402@0m
<R00?C8N03db7P0m<R00?S8R03hb900n<RH0?c<W03lb:@0203`b9P80>c4U0P0j<2@203T_8`0803H[
9`0f:bD0=b`V03T_9P0j<2H0>c4U03`c900m=2D303dc9`80?38V0`0k<BD203T`7`0303Xa800k<R40
?3<R00<0?C@S0100A3TW04@g9P13=RD0ACDU04Lf9P1:=bP0CcT[050j;01@?2@0DCdU054o9`1A@BP0
D48X04e19`1<@2H0BT0U0P16?RT00`18?BT0BC`Y04`m:P0204dl:P0304hk:P19?2T0BSdZ00<0Bch[
00D0BC`Y04Lj9`16>BH0BC`Y04Pk:00204Lj9`0604Pk:01:?BX0C3l/04i1;P1A@2H0D3lU0`1??R@0
0`1A@2H0Dd8X05A3:@0205M49P0405Q59`1IARP0FTLY05]8:P<0G4T[0P1OARL04P1OB2P0HDX[06A=
;P1UD340JE@g06YE>01[F300JUHa06ID;P1SDBd0GDd[05Y::@1GB2T0ETLX05i9:P1OBR/0H4//065<
;@<0HDh`00l0Gdhb05e?=@1MCcD0FT`a05A6:`1@@2H0D44T05E6:@1LBbl0He4]06ID<01/F3<0LEdh
07MQ>P1iHC/00P1iHST0>023J3d0QFXo08U^@@2>Ld@0TgU809QnB`2LPTl0WXE?09f8D`2PRUP0XXiK
0:>AG`2TU6<0XYAU0:2BI@2NTF@0Vh]J09^=G02MSf00W8mR09V<H02BQU`0S81F08QlE01iMEP0LFe@
06QSAP1RFd40HUHn065B>`1MCCH0FDTb06E;:P1VC2T0JThY06e@:01aDRH0MUHW07YJ:@1nGBX0O5`Y
07iM:P20GbX0QF8/08UT;@2>Ibh0TVTa09=[<02SKRX0YG0/0:Eb<02YMS@0[7Tg0:im>`2aP3h0/X4o
0`2cQ4002`2cQ3h0]8Do0;F6?P2fQcl0]XPm0;J=?P2eS3d0]8/l0;:9>P2aR3T0/8Lh0080[XDf0P2e
QC/0102dQS/0/XHk0;67>`2aQc/20:n8>`0@0:j2@@2]PD00Zh0l0:Yo>P2XOSH0YW`b0:Ek<@2TNRh0
WW@j09ec>@2LKcH0Vf`d09YY<@2IIRl0V6D^09QS;@80SfL/00@0SVL^08]V;`2:Ic40QfHa0P26IS<3
08UV;P0408]X<02<JC40SV/c091]=@80TFhf00<0TW0c09=a=02ELcH00`2FM3L0102ELcH0U78e099_
=`2BKcL2095^=P0:091]=@2?K3@0Sf`d08i[<`2>KCL0Sflf091`=`2BLSL0Tg<f09Ae=@80UGHe00/0
UG<d09Ug>02OOCh0Y8930:F3A02RP440WG/l09Yh>@2BMCd0SG0h08U/=00208MZ<P0408IY<@21I2`0
O5lW085V;`80PVL`00D0PfPa08EZ<`26Jc@0QV/d08M/=@0208]^=00408a_=@2=L3H0SW4g08mb>080
T7<i00T0PVLb07aS;@1gGBX0M5d[07AN;@1bGBh0JUPX06AB901SDb800P1TE2<00`1UEB@0IUHU06MG
9P0206QH9`80He8T00@0I5<U06ED9P1VEBL0IeHX0P1XEbT806MF:0P0JUT[0380HUDY061C9`1OD2D0
GdhS065>901VD2L0JU@[06eF;@20Fbh0SV`o0:N5F02mW740bj^20=6dS03D^940eKVB0=>iWP3C^Y`0
e;^M0=FlW@3@^9H0a:b80;>KM@2VSVP0VgmJ09EjC`2?MD80TgY20:68DP2cV6/0`ZF30<Z/T03?_Z@0
dl:X0=_:/03Rd;P0i]Bl0>SF_P3WeKl0i]Bn0>7>[P3ObjX0f/>Q0=:iT@39ZWh0_9]X0;2=E@2ZQTX0
VGY3099c?080S6/e00<0S6Tc091[=P2FKSX00P2IL3`0202LMCh0WWU20:9oB@2XQ500ZXUF0:Z:F@2Z
S5X0ZHYK0P2RQET07P2QQ5P0X8=G09f0E02IO500UGQ<09=fBP2=N4<0S7E108Ub@026Jc`0PVDi081Q
=@1mG3<0NeXa079F;`1]E2`0J4hY069:9P1MAR@0F4@S05E28@1E@R80BCPL04Pg7@15=A/0@cDK03lc
6`0l<A/0>c0L03P`6`<0=RdL0`0e;1/203@[6PP0;BXI00<0<2PM02hV6`0]9AX00P0/91T00`0]9AX0
;RHK030X7@0802TU70P09BDK200Y9AX402`V6P80;BLK0P0^:1`00`0]9AX0;bLL034Y7P0203<[8003
034Y7P0_9a`0;BDJ0080=2XP00@0<bTO038X7P0a9ad0<BLM0P0`9Q`803HZ6P<0>bhN100l;al00`0m
<200?C0O03d`7`0303ha80<0?c8Q0P13<R0604@c8@T0@C4Q00P0ACDN04@d7@14=1d0A3@M04De7P17
=b00BCTR04/k90<0CSPQ0P1?>B82050j8`03054k901B>R80DSXR00@0DCTQ0P1B>R80201?>B80D3XR
05<k8`1F?2<0FChS05do8`1N@B<0H44T0P1VAbP206E69`80I4DV0P1SA2D0201QBbH0H4XU0618901Q
Ab@0I4LU06M99`1[BRT0K4/Z0P1[BRL306a;:0<0KD`Y101`CBL4075>:00807AA:`1eDR`0ME8Z07IC
:@1gEBP0N5HX07QF9P1iEbL207mJ;@03081K;P21G2l0PUd`0080Peha00@0Q5lb089M<023GS40QF0c
0P26HC@01024Gc80PUd`081K;P1nFBl207eH;P0307aG;@1kER`0NeH/0080NUD[201fDb/207EA;@0:
07IC;@1hEBd0NEH/07]I;01lFRd0O5X/07iI;020Fbh0PUd`08AO<P80QF0c00P0Q5lb08=N<@24H2h0
QF4_08IR<028I380RFDc08]W=@80S6Pf0P2>JCD0302?JSH0TF`h09A_>`2FLCd0V7<o09Ud@02LL3l0
W79009me@`2PN4D0WgY609ijAP80VgY500@0VgY709akB02MO4T0WWe:0P2POd`00`2QP4d0XX5>0:>2
C`030:J2CP030:N3C`2XQ500Z8A@00<0ZHEA00P0Z8A@0:J2CP2TP4`0Y81<0:F1C@2VPTh0Yh=?0:J2
DP80YH5A00D0Y81@0:=oC`2ROTh0XWi>0:5mC@0809mkB`<0WGM60P2NN4L309miB00609iiA02ONTD0
X7]60:9mB02TOdX0YX5<0P2XPdh80:F1C@H0Z8AD0P2YQED20:N4C0060:N4CP2VPTh0YX9@0:J2DP2U
PE40YH1C0P2XPdl0102YQ500ZXEA0:^6DP2/Qe<20:f8E0X0ZhMG0`2/R5P30:f9F@P0[H]M00<0ZHEA
0:Z6DP2ZQU800P2ZQU830:V5D@080:^7D`2]RED0[h]G0;6=F@2bSUX0/8aH0:j:EP2/R5@80:n:EP80
[HYD0P2^ReD30:n<EP030;2=E`2bSET0/XeI00@0/XeI0P2cSUX01@2dSeP0]8mJ0;F@F`2eT5`0]HmN
0080]Y1Q0P2fT6<01P2kTV@0_9=U0;ZDI@2iUFD0^YIV0;RFIP80^9QW00<0^iEX0;bFJ@2nV6/00`30
VVd20;jHJ`030;fHK02nVFd0_YU]0080_YU]0`2oVVh20;bJK0040;fKK@2nW6h0_ie_0<2NL080`Ima
0`31WW@20<:OM@<0`Iid00H0`:=g0<:SM`32XgL0`j9g0<BQM`36XGL20<NPM`P0aZAf00P0bjIi0<ZU
N039Y7L0b:=f0<JQM035X7<0a9mb0<>NL@80`Yae00H0`iid0<>NLP32WG00`9a/0;jJJP2mVFL30;fK
J`<0_9YZ0P2kVFT80;fHK0060;jLKP2mVfd0_9Y/0;^IJ`2jV6X0^9IX0P2gUFL20;VEI@040;ZFIP2k
UfL0^iMW0;bHJ080_IUY00H0^YIV0;VEI@2iUFD0^9AT0;NCH`2fTV820;FAH@030;6=G@2bSUh0]I5Q
0080]i=S00@0]I5Q0;:>GP2aSEd0]8iQ0P2dSUl00`2cSE`0/hiJ0;:=F0020;:=EP80/XiL00@0/HeK
0;2<FP2_ReT0[h]I0P2^RUP30:j9E@80[HQD0`2/Qe<90:Z5D0030:f8D`2[QU40Z8=>0080YX5<00<0
Z8=>0:Z5D02/Qe800`2YQ4l20:R3CP<0Yh9=0P2VPTH0102VPTP0YX5:0:N2C@2WPTh20:N1D0040:J1
C@2WPTh0Yh9>0:R3C`@0ZHA@0`2[QU430:Z5D080ZHA?1P2YQU0:0:R5C`80ZH=B00@0Z8=?0:R3CP2X
Pdh0Yh9;0P2WPdT20:>0BP030:9oB@2QOTP0X7e70080Wga600@0WW]509iiA02NND@0WWU4:oooool0
02[ooooo202TNDH20:AkA@80YGa60P2VODL20:MnB0<0YW]80P2UNTL30:AiAPP0Yg]:202WOTX01P2Z
PDd0ZH1<0:QoB`2WOTX0YWe90:ElB080Y7]7402XOd/20:QmBP<0Yga90`2VNdP90:=jAP060:9mB@2Q
O4P0XGa80:1kA`2ONTH0WWU50P2MN4@01@2HLT<0Ug5209Ma@P2FL440U6ho0080Tfdn00L0TV`m095/
?`2AK3l0T6/n08iY?02=J3/0RfHi0080RVDh0P29I3X01P27HSP0QV4g08AO=@22GC<0PE`b081K<@80
NeP`0P1jEbl307UF;P0:07QE;@1iER`0NEH/07QE;@1gE2h0MU8^07EA;`1dD2h0M50`075@;@80L4l/
00<0Kdh[06i=:P1^CBX00P1^CBX306]=:@0>06a>:P1]Cb/0KU0/06mA;@1`DRh0LE@/07MG<01kFc80
O5/`07]I;01nFB`0PU`]08IP<@27Hc<408QT=0<0RFDe0P2=JCT208iZ>P@0Sf/k00<0T6Xk08mY>P2>
J3T00P2<ISL00`2>J3T0SfTj091Z>`0309=Y=`80TVPf0`2AIcD01P2AICP0T6Dh091U>02?ISP0SFLh
08aX>080RVPh00<0SfTl08iX>`2<IST00P2;ICP02@2<IST0SVPk08mY?02>J3T0SFLh08aV=`2;ICH0
RV@e08QR<`0208MQ<PP0S6Hg202=J3@908eW>P80T6Xk0P2?JCX0302>J3T0SFLh08eW>02=IcP0QfDe
08QV=P2;IcL0SFLh091W>@2CJ3/0U6Tl09EY?080TV]000<0TV`o099/?@2BK3/00P2BKCT00`2BKCP0
T6/g091[=`0408mZ=P80T6/g202>J3T808aW>P<0RfLg0P2<J3P308eY>@0508e[?@2<JS`0S6Xl08]Y
>`2:J3X00P29IcT00`28ISP0RVDh08YU>00608YU>00308QV=P27ICD0QfDe0080QfDe0`28ISH208EW
=@80Q6Hd00X0PfDc089T<P22I380PV@b081T<P1oHc40OV8b07eQ<P1lGc<0O5le0P1kGSH0601fFBl0
M5P`079F;P1]E2`0JE4[06E?:P1QCBX0H4`Y05548@1?@R00BSlO04Dl7`10>Al0?CLQ03df8`0l=b@0
>S@T03Hc8P0c<240;bdP02/[7`0Y:b00:2/P02P[8P809RLO00@09BHN02@U7@0S91`08R<K0P0Q8QX2
024T7@03020S700O8Q/07R4J00807B0I0`0L7aP201dP6@807R4J0P0O8Q/01P0L8a/07B@L01hU7@0N
9Ad07B@L01/R6P806B0H00<061lG01LM6`0G7A/01P0G7A/0600K71h06Q/M01XL6`0J71T06adH01dP
6@0P8a`08B@K01hR500Q9AL09RPJ02//700a<1h0=C8O03Ld8@0j=B40=S0J03L`7@0h<b00=S<T034_
8`0Y:Al081lJ01TJ5@808B8M00L08R<M02<T700T9Q/09BLJ02HX6`0V:1X092DM00808b@L00<08R<K
024R6P0P8AT00P0O81P801dM6`P07R4J02007QhN01dM6`0M7A/07AhI01hO6@0P8AT08bDJ02@V6`0a
:QL0>C4N040h8`11=R00?30H03`^5013<aX0BCTO06Q?9`1hG3@0QV]008ib@`2FN4H0XhA>0:n>F02d
U5/0Ug9507]O>01C@bT0<RlP02HY8P0V:bL0:2XU02HW8@<08bDR0`0T9R<202DW900302@U7@0U9Qh0
9bPP00<0:BXR00D0:2TQ02LX800[;1h0;BhP02l`8P02034b900302h_8@0[;1h0:BXL00<09BHP0P0V
9b4302LX8PP0:BXR00H0:R/S02/[8@0];B<0<BlS03<_8`0g<B<203Xc8`0703P_800j<B00?S<Q048e
9017>2D0C3/W04hn9`02050n:00605A2:P1C@BT0Dd4Y0590:01A?bL0D3hV0P1??BD0201A?bL0D3hX
04hn9`1;?2L0AcXW04@i9`13=bL0@3LV0P1:?BX604/n:`P0CclV0`1B@2P305=1:@80E48Z0P1A@BP2
05109`80CclV0P1>?RD205919`060551:01?@2T0BclY04Hk9`13>2@0?cLT0P12=bD00`11=R@0@3DS
03ld8P0203hc8@0903db800m<Qh0?C8N03db800n<R80?S8T03hb9P0o<bL0?c8Y00@0>c4U100j<2@0
200f:bL0=R/U03L/9P0i;bH0>S0V03/a9@0l<b@0?C@U0P0n=2P203dc9`<0?38V00L0>c4U03Pa7`0h
<Al0>34O03Tb800j<b40?3DS0080?CHT0100A3TW04Dh9`14=bH0ACDU04Lf9P1:=bP0CSPZ04li:`1?
>b<0D3`T050n9P1A@BP0DD<Y04m3:@1>@RP0C48W0P18@2/00`1:?b/0Bch[04`m:P0204dl:P0304hk
:P19?2T0BC`Y00<0Bch[00D0BSdZ04Pk:017>RL0BC`Y04Pk:00204Lj9`0<04Pk:01:?BX0C3l/04i1
;P1A@2H0D3lU04ln901>?B<0CchT050o9@1B@BL0Dd8X101HABL01@1IARP0FTLY05]8:P1LBB/0GDX/
0080FTDX00l0FdHW05m8:@1RBb`0Ie0`06aC=01_ESL0LeL`071F<@1]EC40JE<^06A@;@1NCR`0Fd/Z
05U::@1MC3800P1OBc00G@1PC340HTd`06=><@1TCc80IE0c06AC=@1SE3D0H54d05U:;@1BA2L0D48W
05A6:`1IBc00F4TZ05e=;01VDc80KUXg07IP>`1kHC`0Of<l081T?029KT40RVm208eb@`2@MTD0TgU6
09ImA`2IP4X0VX590::9D02US5@0Yi5H0:^FG`2]VF@0[9]W0:bJJ02ZVVL0YY5L0:RCGP2ZUV<0ZIMU
0:BFI@2NTV80V8iM09F:G023Pel0OGYG079_CP1ZIDP0IEm7061H@`1IDCh0E4/j06=?=P1RCC80HD`_
06=<;01VCRX0JU4Y06iB:P1_E2T0JU4X06eA:@1_E2T0LUDY07MH:P1jFR/0OE/]07iL;02?H2P0T64Y
09=U:P2HIbd0W6/a0:1_=02TLSL0YG<h0:Me>P2XMS/0ZGLj0:Yi=`2/NcP0[7/f0:em=@2]OC<0[X8g
0:f1=P2/P3D0Zgld0:Yn<`2YOC80Z7`a0:Mk<0020:Ug<00>0:Qh<02WN300YGT`0:Ei<02TNS00XW/`
09mb=`2NLCH0WG4d09]_<02JKRd0V6dY09M/:02FJbH209AY<P0609IY<P2GJ380V6Ha09UV<@2HIC00
VF@`0P2;I2/01029I2d0Qf@^08ET;`24I342089T<P<0Qf@/00h0RFH^08]X<02=JS80Sf`d091]=@2A
KSH0T6ha099`<`2DLSD0UW@g09Me>02FM3L0U78e09=a=0H0T6de0P2?K3@02`2>KCL0SVhe08m_=P2@
L3D0TW8e09=d=02EMSD0UWLf09Ab<`2HMSL0WW`m0080Xh5200`0X7ho09]i>P2HMSL0Sg8j08]^=P26
JC40QFP`08IY<@25J300PF@/07eP:021IRl2089W<00508=X<@24JC80QFXc08EZ<`26Jc@00P2;KS@0
102<KcD0SG0f08e`=P2>LCL208mb>00807aQ;01hGbT0MU`Y07AM:`1cGB`0KeX[06QF9P1TDR@206=B
9080I5<U00@0IE@V06IE9`1WERP0IeHX0P1SDR@0101TDbD0IE@V06ED9P1VEBL206MF:0P0IE@V201X
EbT0<P1PDbT0Ge8X05e>9@1NC2@0H4dU06E?:01XDR/0K5@^081K;P2@KT40ZHMJ0;jMLP39ZH00c[69
0=:fS`3E^I80e;ZO0=>jW03D^id0e;^L0<ngU@32ZXH0/9Qb0:>;I@2GNeH0TgQ=095gA02HOdL0YhiH
0;VNL@37ZXP0c[2D0=;0ZP3GaJl0g/bd0>CB^P3WeKd0imJl0>CC^@3RdKL0hlbZ0>38XP3H_iH0c[:3
0<2RKP2bTE/0YX==09ik@`2>L3`0R6Xf0P23Hc000`24Hc00RfLe095[>P0209I^?@0809Mb>`2JMcl0
Wga60:>2C@2VQU<0YXQF0:>7E@2RQUH20:23E`0N09n2EP2NPED0VgiB09MjCP2DMd/0TWE908]e@`2:
Ld40Qflo08AY>P20HcL0OUhe07aJ=01jF380JU0]06M?:`1RBRP0G4DU05I18P1B?b40CSdO04dl8018
>1h0AcLN04Dg7@11=Ad0?S<M03/c7P0i<Ah0=c0M100c;1`2038[6`80<BXJ200/:AX00`0]9Q`0;2DK
02/T6P0202TR600302/T6P0/9A/0;BHL00P09b@K200T91X802PT6`80:R<I0P0[91X402`U6`0302/T
6P0]9Q`0;bPN0080<BXP00@0;bPN02dV700[91X0<bTP0P0b:1l01@0a9ah0<2HM02lU700_9A`0;R@K
00P0=BTK0`0i;1`00`0j;Ad0>bhN03/^7P0203`_7`<0?2lN0`0m<1l203ha8080@c8P1P12<Al903ha
800904@e7P13=1d0@S<L048c7013=1d0A3DN04Lh8@18>B80BcLO0080C3PP0P1=>B4304hj8P80CCLP
101>>24204dg800804hh8@1?>B40DSXR05Dk8P1H?B80G3hR05e08P1O@2<206E8:00406A79`1SARH0
HD@T06138`80Gd8R0P1OBB@01P1OAb<0H4HS06=6901VB2H0JTTX06a;:P<0JTTV0`1[BRL206a;:080
KT/U0P1_C2H2071=9`80LDhX00T0Le0Z07AA:`1dDBT0ME8X07ME:01hERP0N5HV07UG9`1nFB`00P1o
FRd00`20Fbh0PE`_089M<00208=N<@0>089M<023GS40Q5lb08AO<P23GS40PUd`081K;P1oFRd0OEP^
07aG;@1kER`0NUD[07UD:P1hDbT207MB:0P0M54Y0P1cCb/02P1dDB/0MU<[07MD:P1iEbX0NUP[07YH
:P1kERX0OEP/07mJ;P21G302089M<@08085L<020Fbl0Pel_08=O;`24H300QF4a08MS<`28I3@208UU
=@0@08]V<P2<Ic<0SVTe095/>02CKSX0UG0l09Ia?@2GLSh0Vfln09]a?`2MLd40WWI309ehA02KMd<0
VGQ309Qg@P80VWQ800D0VgU909ekB`2NO4`0WWa<0:1nCP020:5oC`<0YH5=102VPTh02P2WPdl0Z8A@
0:J2CP2TP4`0Xgm;0:9nBP2SOd/0Y81<0:F1C@2UPE420:B0D0050:=oC`2QODd0X7a<0:1lC02ONd/0
102LN4P409eiB@<0VgI20P2LMd<309ehA00809eh@`2NND@0WgY50:5lA`2SOTT0Y7m:0:F0B`2VPD`8
0:=oB`L0YX9B00T0YH5A0:F2BP2UPTX0YH9<0:F1C@2TP4h0Y81@0:=oC`2SOU400P2WPTh0102XPdl0
ZHA@0:Z5D@2[QU820:b7D`/0ZXIF0`2[QeL20:b8F0P0ZhUK00<0Z8A@0:N3C`2WPdl00P2WPdl30:R4
D0080:^7D`2]RED0[h]G0;6=F@2`S5P0[h]G0:b8E02ZQU880:n:EP040:b9D`2]RU@0[HYD0:f:E080
[X]E0P2_S5H60;6<F080/8]G00D0/XiD0;:=EP2bSEP0/hiI0;>>FP020;>=G080]8iO0P2hT5l02@2g
TF00]Y9P0;NCH@2eU640]9AQ0;FEHP2hTVD0^YAW0;^EJ0030;fGJP040;bFJ@2kUFP0^YEX0;ZEJ080
^iIY00@0_9MZ0;fHJ`2mV6/0_IQ[0P2jV6X0102kVF/0_9Y/0;fKK@2nW6h20;nMK`<0_iab0P2nVg43
0;nLLP060;jRL`30XG<0`:5c0<6PL`32X7<0a9mc0P35WW<80<FSM@060<VTM`38XgH0b:=f0<JQM035
X7<0a9mb0P33WW402031W780`Yec0<>NLP33WW40`Yi^0<2LJP2nVVP0_9QT0`2mVf/30;bJJP80^iUY
202mV6/01P2mVfd0_9Y/0;^IJ`2jV6X0^IMY0;NEI`80]YAV0P2hU6@0102iUFD0^YIV0;ZFIP2kUfL2
0;bHJ0060;VEI@2hU6@0^9AT0;NCH`2fTV80]I5Q0P2dT6000`2_Re/0/HeM0;B@H0020;FAH@090;B@
H02aSEd0[h]K0;B>H@2dSUl0/heN0;>=G02bSET0/XeH0080/HaE0P2aSET0102`S5P0[h]G0:j:EP2]
RED20:b8E0<0[HQD0P2/Qe<30:^6DPT0ZXE@00<0ZhIA0:V4C`2WPTd00P2UP4/00`2WPTd0ZXE@0:b7
DP030:R3CP80Yh9=0`2VPD`20:F1A`040:F0B@2VPD`0YX5=0:N1D080Yh5B102VPDd0102WPTh0Z8=?
0:R3C`2YQ5020:^6D@<0ZXE@0`2YQ4l60:V6D080ZXMA202XQDl20:R2D@040:R3C`2WPTd0Yh9=0:N2
B`80YX980P2ROdT00`2QOTP0X7e709mlAP0209ikA@0409ejA02NND@0WWU409iiA2_ooooo000Zoooo
o`P0YGY70P2TNdD20:ElAP80YWe70P2WOTP20:IjB@80YGU80`2TN4L00`2SMdH0Yg]:0:MkBP060:Mk
BPP0Ygi:00@0ZH1<0:QoB`2WOTX0YGa80P2TNdL20:ElB0P0Ygi:202XOd/30:QmBP80Yga90`2VNdP9
0:AkA`80X7]70P2QO4P02P2PNdL0WWU509ag@`2KMT80VG=409Qb@`2GLD80UW1109E_@02CKCh2099/
?@80TF`o00@0T6/n08iY?02=J3/0RfHi0P2:ICP208QS>@0608MR>025H3H0Q5le08=N=022GC<0PE`b
0`1lFC4207]H<0<0NUL_0P1iER`02P1hEBd0Me@^07IB;P1fDS00ME4_07EA<@1aD2d0L4l/06m>:`1^
CBX206e<:@0306i=:P1_CR/0JddY00<0JddY00`0K4hZ06e?:`1_DBd0L58^075D;01gEc00Ne/b07aK
<01kFB`0OEP[085K;025Gc0808QT=00408aX>02=JCT0SFTi08eY>@80SVXj0P2?Jc/00`2@JS/0SfTj
08eW>00208aV=`0408eW>02?JCX0T6Xk099X=P<0TFLe0P2@IS@208mU<`06095U>02@ICP0T6Dh08mV
>02=IcP0S6Ph0P2:J3P00`2>J3/0SFLj08aV>@0208]U>00308aV>@2=IcX0SVPk0080SFLh0P2<ISL0
102;ICH0RV@e08US=029Hc@208]U=P@0SFLh0P2;ICH808eX=0T0SFLj0P2@JS/0102?JCX0SVPi08eW
>02=IcP208aV=`80RFLg00<0S6Ph08iX>@2AJ3X00P2CJ3/01P2DJ3/0TFXo095Z?`2AJch0TF/l095[
>P80TF`h00@0TF`g091[=`2@JcL0SfXf0P2>JCD00`2?JSH0T6/g091[=`0808iX>@P0S6Ph00@0RVHf
08]W=`2;IcL0RfLg0P2<J3P208eY>@<0RVPj0`29IcT208QV>0P0RF@g0P27ICD308IT=00408MU=@29
IcL0RFLg08IX=P80QFLe00<0Q6Hd08=U<`22I3800P21Hc408021IC<0Of<a07iR<P1lH340Nehb07]N
=01kGSH0O5lg07MJ<01eFC40LUH^06eD;01YDB/0IDlZ061<:@1OBbP0DD@Q04m2801:?al0AC`O040i
7`0m=b40?CHS03`g900k=BD0=c@S03@a8P0_;B00:b/O02T[800X:b00:2/R0P0V9al0100U9Qh092DM
02<T700R8a/2024R6P808B@M00<082<L01lR6`0N8AX00P0M81T301`O60807B0I0P0N8AX201lR6`06
01/R6P0L8a/07B@L01hU7@0M91`072<K0P0J8AT00`0I81P05adK01LM6`0601LM6`806a`N01H06Q`K
01XL6@0K7AP07B0I01lR6`0Q91/07b<E024U5`0U9aT0:R/K034`7P0e<Ql0>3DR03/f8P0f<1P0=S0J
03Ha7@0f<b80=38U02`/8P0S8a/06Q/E0P0Q8Qd01P0R8ad08b@L02@V6`0U9aX09RPK02HX6P8092DM
00<08b@L028S6`0Q8QX00P0P8AT00`0O81P07AdK01dM6`0601dM6`P07R4J02007QhN01dM6`0L71X0
71dH01dN600O81P08B<H02<U6P0/9a@0=RlM03hg900o=b80?34K03X^5P10<AX0ASPN05i77P1_ERd0
PFTm08eb@`2CMdD0WGm90:b=EP2gV5l0XGU608QY?@1NBb/0>3<P02P[8P0Y;RP0:R`W02DV80<08bDR
0`0T9R<202DW900302@U7@0U9Qh09bPP00<0:BXR00D0:2TQ02LX800Z:ad0;2dO02l`8P02034b9003
02l`8P0/;Al0:R/M00<09BHP0P0V9b4302LX8PT0:BXR00h0:b/Q02`/8P0`;R80<blS03La8`0i<R80
>S<S03P_800i<240?S8R048e9017=bL0BcXX04hm:@80D3hZ00H0ED<[05A2:P1D@RX0Dd4Y0590:01A
?bL2050n9P0:05A0:01D?bX0D3hX04hm:@1;?2T0AcXY04Dh:014>2P0@cHS04@g9080ACPU00@0ASTV
04Dh9@14=b@0@cHS0P1=?BH304hn9`<0CclX0P1A?bL20590:0<0Dd4Y00<0E48Z0551:01A@BP00P1@
@2L204lo9P80CShU0P1C?bH01@1A?bL0D40Y04dn:@18>bP0ACPU00<0@cPV00<0@SLU044f9010=B<0
0P0o=2801P0n<b40?S<O03hc7`0n<b40?S8R03hb9080?S8V00<0?C0W03/a9@0k<BD00P0k<BD403X`
900803H[9`0f:bD0=b`V03T_9P0j<2H0>c4U03`c900m=2D303dc9`80?38V0`0k<BD403Pc800D03Xe
8P0l=b@0?STV03lj9`14>BL0A3LV04<f9@14=2@0ASDU04Tf9`1<=RP0CSPZ04hj8P1@?2@0D3hV0551
:01BA2X0D4@Z04m3:@1>A2T204U1;00904]0;01<?b`0CCh[04hm:`1=?2X0CS/Z04Lj9`18>bP0BSdZ
0080Bch[00D0BSdZ04Pk:017>RL0B3/X04Lj9`0204Hi9P0404Lj9`19?2T0Bch[04`o;080D3lU0`1>
?B<00`1@?bD0DT4W05=2:00205U6:0<0F4DW06X0FDHX05]8:P1MBR`0GT/]05Q7:`1JAR/0FDHX05]6
9`1PBBT0ITh/06aB<@1_EC80ME<^07AD;P1bE300KU@a06YD;`1UDbl0HE4_05i@;@1NCSL0GDdf05i<
=01PC3<0HTdb06E=<@1XCc40JE0b06QE=01YESD0IUHe061A<P1HBRd0DdP/05A;;P1GCC80E4H[05M9
;P1OCS00J5@c075I=@1iGCP0OV4i089R>@2:Kd00Rg1108ec@P2@MT<0TgY409ElA02HOdL0VH170:J9
C@2XRdl0ZY1E0:jEG02_VEl0/IaS0;:OI`2cX6P0/iIN0;>HH@2dVf<0/YeV0:jMI`2YW6L0Y9YU0::H
H`2ETF40SXYK08F0F01nN5@0N75D071XD@1WGd`0H5M606EF@`1PDCh0G4`e05]:<01MC300H4d]065=
:P1PC2T0H4`[065=;01TCB/0IThZ06U?;01/D2/0KE4Z06mA:`1hEB/0NeH/07iG;023FRh0Qe`_08]O
<02=HC00T68a095Q<`2CHc<0UFHb09QY<`2JK340VV`^0P2KKR/0102ILS40V74`09Qa<02HLC0309M`
;`0609I_;P2HIbl0V6L_09IW;`2EJ2l0TfT_0P2BJRl01`2AJRl0SFDd08eU<P2<I340S6@`08aU;P2;
I2/00P2;I2T0202;IRl0S6L`08mX<@2BJC<0TfPc09EW<`2FIc<0UFHb0P29I2d00`27I2h0QF@_08=S
<002089T<P0C07mS<`28IBd0RFH^08UV;P2:Ibl0S6Ta08eZ<P2?K3@0T6de095^=P2=Jbh0Sfd`09=a
=02ELcH0UW@g09Ec=P2CLC@0TW0c08i[<`0308m/=0@0T6de00/0SF`f08e]=02>KSD0Sfld095a=02C
M3@0UWLf09Mh=`2ELc@0V7Hg09aj>`0209mm?P0509aj>`2HMSL0UG<d08e`>029K3@00P25J30208IY
<@03089U;@1nHBT0PVL`0080PVL`0P23J34308AY<P0608Y]<`2;KS@0Rfhd08a_=@2=L3H0SW4g0P2?
LSP0201hGBP0MUdW07EK:01bFbT0KeTX06aG:01XERH0IU@V0`1SDRH306AC9`80IE@X00H0HU4S06=B
901SDR@0I5<U06ED9P1VEBL206MF:0P0IE@V201WERP04@1PDR/0GU0Y05e>9`1MBbD0GTXU06==:01V
D2/0JE4]081K;P2AKd80[8YM0;nNL`38Z7l0c:n70=2dS@3E^I80e;ZO0080dkZL01l0d[VJ0<feT`30
Z8@0[YI`0:69H`2ENE@0TgQ=09AjA`2NQDd0[YEO0<2UN03=/8h0dkFI0=G3[`3Jb;@0h<jh0>KD_03W
e[`0iMBh0>7@]03Mc:h0h/JQ0=c0V03C]hL0ajUc0;NHG`2WQdh0VGQ209=_>`22ISH0P64b0080O5d^
00<0OUh_08ES=@2>JC`00P2AJch02@2ELSX0UgLn09elAP2QPT`0XhEA0:65D`2NQ540W89A09f0E002
09aoD`0M09YmD@2GNTh0U7M;091cA`2>LDD0Qg4o08M_?`23Jc/0PFHi07eP=P1jFS<0N5Ha07ID;`1T
Bb`0HDXZ05a59P1E@2<0D3`Q04/j8018>1h0B3PO04Hh7P15=Ql0@SHN03ld7P0k<ah0>34N03L`7P0e
<1d00P0a:ad2030Z7080;bTK0P0^:1X802XV6P0302XV7@0Y9A`09b<J00809R8I00<09b<J02TU700Z
9Qd0200T91X802<S6@P09b8L0`0Y8QX202XS6`<0:b@L00<0:BDL02XV7@0[9ah00P0/:1l00`0[9ah0
:RHM02TU7003034V80<0<2DO0P0_91h803DY7@80=bXJ0P0h:a/0100i;1`0>RdM03/^7P0k;Qh203X]
7@80>bhN0`0l;al01`0m<200@c8P048a7`11<1h0@2lM03l^7010;ad00P11<1h903``800<048f7P11
=Ad0@3@L03lc6`10=1`0@CDM04<g7`14>200AcDM04Pf7P19=al0BSPP0P1;>B401@1:>200BCLO04Td
7`1:=B00BcHQ0080C3LR0140BcHQ04Xe8019=1l0CCLP04hh801A>B40E3XQ05Ll8@1K?B40G3lQ05ho
8P1SARH0HTDU0654901P@b<0Gd8R05i18@0205e0800805i88`1MAb80GTHR05m58P1RAB<0ITPV06Y9
:01/BbX206Q79080JDPU0`1ZBBH01`1[BRL0K4TS06e:901]BR@0KT/U06m<9P1`CBL00P1aCRP01P1b
CbT0Le0Z07AA:@1eDRP0MU@W07QF:080NELW0P1nFB`00`1oFRd0P5/^085L;`02089M<00308=N<@21
G2l0PE`_0080PE`_00`0P5/^07mJ;@1nFB`0OEP[07aG;@1kER`0NUD[07UD:P1gDRP0MU4W07E@9P1d
CbD807=@:00<075=:@1bCRX0Le0Z07AA:@1eDRP0MeDX07QF:@1hERP0Me@Z07QE:`1jEbd0O5T_0P1m
FS0207aI;`06085L;`22GC00PUd`08=N<@24Gc80QF0c0P26HC@01P2:IC40S6Lc08iY=@2AK3P0TVdi
09=^>P80U6lk00P0VFdl09U_?@2KLCl0Vg=009Ye@@2HM400UG@o09Ac?P80VGM900L0VWQ:09]iB`2M
Ndd0WG]=09ilCP2OODl0X7i@00D0Y81<0`2UPDd0202VPTh0YH5=0:=oB`2ROTX0XGe90:9nBP2SOd/0
Y81<0P2TP5001P2SOdl0XGe=0:1lC02ONd/0WWY:09eiB@80VGE50P2JMTH409]gA`80VWE00`2KMT43
09ag@P80WWU400<0WgY50:1kAP2QO4L00P2RODP00`2SOTT0XGe90:5mB@060:5mB@040:B0D02SOdl0
Xgm?0:=oC`<0XWi>00X0XGe=0:B1B@2TPDT0Xh1:0:=oB`2ROT`0XWi>0:5mC@2QO4l0YX5=0P2WPTh0
0`2XPdl0ZHA@0:Z5D@020:^6DPX0Z8AD0P2YQED30:Z6EP040:^7E`2ZR5X0ZXQJ0:Z8FP<0ZHMI0P2X
QUP02P2WPdl0YX9>0:J2CP2UPDd0YX9>0:N3C`2XQ500ZHEA0:Z9E02[RUD30:b;EP030:^:E@2YR5<0
Z8MB00P0[XUE00@0ZhQB0:b9D`2/RE<0[8UC0P2]RU@20:j;E@040;6<F02`ReL0/8]G0;2;E`<0[hYF
00H0[XUE0:n;D@2`S580/8]D0;2;EP2aS5L20;6<F080/XaK0P2eSEX0102cSUX0/hmK0;>?F`2bTE`2
0;6BG0090;J@H`2gTF@0^I=V0;ZDI`2kUFP0^YAW0;VCIP2hTVD0]i=S0080^9AT00<0^IEU0;ZFIP2k
UfL00P2lV6P01P2hUVP0^IMY0;VGJ@2jV6X0^iU[0;bJK080_I]]00<0_Y]a0;fJL02lVFl00P2kV6h0
102lVFl0_IY`0;jKL@2kWfl20;fNK`030;jNK`2oWFl0`Ia_0080`Ya_2032X7820<FPL`<0a9mb0`33
WW420<6LL0060<:ML032WVh0`Ie[0;nKI`2mVFD0_9US0`2mVf/30;bJJP80^iUY202lV6P01@2kVF/0
^YQZ0;ZHJP2iUfT0^9IX0080]iEW00<0]YAV0;RDI02hU6@00`2iUFD30;ZFIP060;RDI02gTf<0]i=S
0;JBHP2eTF40]91P0P2cSel20;2<G0040;6=G@2bSUh0/XiN0;6=G@80/8aL00H0/heP0;>=GP2cSEh0
/XaK0;:=F@2aS5L20;6<E@060;2=E`2_S5H0[haF0:j;E@2]RU@0[8UC0P2[R5830:b7D`80ZhIB0`2Z
QE490:V4C@030:R3CP2WPTd0YX5<0080YX5<00<0Yh9=0:V4C`2ZQE000`2WPTd20:J1C0<0YH1;0P2U
P4T00`2UP4/0YH1<0:J0C`020:J0D@030:J0D`2VPDd0YX5=00<0YH1<00@0YX5=0:R3C`2YQ500ZhIA
0`2ZQE020:V4C`80Z8=>102YQU020:Z7D@80ZhQB202XQDl20:R2D@040:R3C`2WPTd0Yh9=0:J1BP80
YX980P2QOTP00`2PODL0Wga609ikA@0209ejA00409ai@`2ONTD0WgY509mjAB_ooooo000Zooooo`P0
YGY70P2TNdD20:ElAP80YWe70P2WOTP30:EiBP<0Y7Q90P2SMdP80:MkBPP0Ygi:00<0Z7m;0:MnBP2U
O4P00P2TNdL00`2UO4P0YWe90:MnBP080:MnBPP0Z7m;0P2YOT/20:QmBP<0Yga900<0YW]80:AkA`2T
NdL01`2TNdL03P2NNDD0WgY60:1kA`2PNdL0WgY609ehA02KMT80VGA009YdA@2ILd@0V79309Ma@P2E
Kd00Tfdn0P2BK3d2095/?`04091[?P2>JC`0SFPk08]V>@80RVDh0`26HCL01@25H3H0Q5le08AO=@24
GcD0Pehd00<0OU/c0P1mFS8307aI<@0B07YG;@1iER`0NEH^07QE;`1gDbl0MU8`07EA;`1eDC40LE0]
071?;01^CBX0KD`Y06a;:01]C2T0KTdZ06m>:`1/CRX0JddY0P1ZC2P0301[CBT0KDl[06mA;@1aDbl0
LUD]07MG<01kFc80O5/`07YH:`1lEbX0PE//08AN;`@0R6@d1027Hc<0102;IcL0S6Ph08aX>02<J3P2
08eY>@80SVXj00<0SfTj08iX>@2=IcP00P2<ISL0102=IcP0SVPi08mY>P2@IS@308mU<`80SV@b0P2=
Hc401P2AICP0T6Dh091U>02?ISP0SFLh08aX>080RVPh00<0SVPk08eW>P2;ICP00P2:I3L00`2;ICP0
SFLj08iX>`0708eW>00408aV=`2:I3D0RfDf08eW>080SVPi00<0SFLh08]U=P2:I3D0202<Ic<908eW
>P80T6Xk00@0SfTj08iX>@2=IcP0S6Hg0P2;ICH208aZ>P0308iZ>P2?JCX0TVTk0080TfPk00H0U6Pk
08mX?@2?J3d0SfTl08mY>P2?JCP208mZ=P0408mZ=@2AK3P0T6/g08iY=@80SFPd00<0SVTe091[=`2A
K3P0202=IcP808aX=P80RVHf0`2;IcL308aX>080QV@f0`27ICL308QV>0P0RF@g00P0QfDe08IT=025
Hc<0Q68b08ES<`27ICD0RFLg08YX>080QVPf02H0QFLe08AV=023IC<0PV@b085S<@20HS00PFDc07mS
<@1mHC40Nel`07YM<@1jGC<0Nehf07aO=`1iG380Me/c07AH<01^EBd0J50Z06==:01NBRL0GDTV0554
8@1?@R00BSlO04Dl7`10>Al0?CLQ03df8`0l=b@0?3HV03Pe900d<B80<2hQ02/[7`0Y:b00:2/P02P[
8P809RLO00@09BHN02@U7@0S91`08R<K0P0Q8QX2024T7@03020S700O8Q/07R4J00807B0I0`0L7aP2
01dP6@807R4J0P0O8Q/01P0K8QX072<K01dT700N9Ad07B@L01`S6`806R4I00<06B0H01LM6`0G7A/0
1P0G7A/0600L7Al06a`N01XL6`0J71T06adH01dP6@0O8Q/082<J020T5P0R9QP09BLI02X[6`0`;ad0
=34N03Ld8@0k=R80=2hD03@^5P0e<1X0=S<P03Le9P0`<2@09BDK01`M5@808B8M00H08R<M02<T700T
9Q/09BLJ02HX6`0V:1X202@U7@808b@L00@08R<K024R6P0P8AT0824I200M7A/801hQ6P0P01dM7@0M
7A/071`J01/L5`0L7AL07QlG020R5`0Q8aP0:B<C03<^6`0n=bD0@3PU03db7P0k;aT0?c<K04Hg801G
@1L0J54W07mW>`2>Ld@0TWI409UkA@2WRU80]iQO0:MlA@2@KT00IU8_03dg8@0/;R40;C8[02X_:@0R
9Ah302<U8P<092HS0P0U9b@00`0T9Ad09BHN02LX800302TZ8P0502PY8@0W:200:R/M02d^800`<B<0
0P0b<bD00`0`<B<0;BhP02//7P0302DV80809RLQ0`0W:28902TZ8P0>02/[8@0/;280<2hR03<_8`0f
<280>C8R03Xc8`0h;R80>S0T03hb9012=BD0B3PX04`k:@1>?B/2050n:P80ET@/00<0ED<[05A2:P1C
@BT00P1B@2P01`1A?bL0ET0Y05E0:`1C?RT0D3hZ04dl:P1:>RX00P16>BT00`11=240@SDR04@g9002
04Dh9@0304<f8`12=B80@3<P0080C3/W0P1=?2P204hm:@80CchZ0`1A?bL20590:0<0Dd4Y0P1A@BP2
05109`80CclV0P1>?RD02@1B?2@0DShU058n9P1@?RP0CSdY04/l:@17>RL0ASTX04Dj:00204@i9`03
04<h9P12=bD0@CHT0080@3DS0P10=B401P0o=280?S8R03da8`0m<BD0?30T03`_9P@0>S0T100k<BD0
200f:bL0=R/U03L/9P0i;bH0>S0V03/a9@0l<b@0?C@U0P0l<RH303/a9@<0>S0T01D0>3DR03Ld8@0g
=240=c@Q03Tf8`0k>2D0?S/X040m:P13>2H0@cHU048e9013<b<0A3<S04Ld9@1:=2H0C3HX04di8@1?
>b<0D3hV0551:01BA2X00P1AAB/01P1?ABX0Bd<^04Y2;@1<@Bd0C3l/04ho;080CSd[00P0CS/Z04Hi
9P17>RL0B3/X04Tl:@1:?BX0BC`Y04Lj9`80ASTV0P15>2D03@14=b@0ACPU04Lj9`1:?BX0Bch[050o
9@1??R@0CSdS04dl8P1>?B<0CchT05509P1B@BL00`1IARP205Q59`1/05U6:01KB2X0GDX/05i;;@1J
BS40F4P^05Y6:`1JABP0GdHW06A::@1[CbX0Ke4]07I>:P1fD2/0ME<^07=E<@1_Ec<0JeLd06IF<P1T
ES<0H54n05m@>`1NCSL0H4`d069=<P1VC340JDha06Y?<@1XE2l0JeLb06aJ=P1VEcH0Ge8b05Q?<P1F
Cc<0Ee0d05A:<@1FBS00Fd/a065>;P1ZDS00LUHa07UI<P1lFc80QF/j08M]?02:L3d0SWA109=jA02G
OTH0Vh9909b3BP2XRTX0ZH];0:Z>C`2[TU80[iMI0;6KG`2eWfD0]j=X0;jNH`2nWfH0_J1V0;VSJ@2g
Y6X0]:E/0;6VKP2_YVd0Zj5T0:JKH`2PU680VXiT09F8IP2:Of<0Og=M07IYF01_IET0J5m@065EA@1N
DCh0HE8k069B>01PDC@0Gdh`05a<<`1LC380GD``05m;<01QC2l0Hd`]06=<;01TBb`0IT`a06M><01Y
CS00KTl`075@;@1eDBd0N58]07UC;01kCb`0OE4/081D;@24FB`0QU`Z08MN:027Gb@0QelR0P22GC02
08=N<@<0Q5lb00L0QF0c08IH=025FC@0QETd08AJ=022Fc@0PE/d0080Oe`d0P21GcT03P22HCP0Q6<h
08ET=`26ISL0QfLf08QX=`28Jc40RF`b08]/<`2=KC@0Sf`d08iY<P2<Ic00SFH_0P29IS001`26IC00
QFDb08=U<`23IC<0PFDe081T=02;J3000P2<JC403P2=JS80SV/c08m/=02@KCD0TFhf099_=`2:J2/0
SF/^095_<P2DLSD0UG<f09Ab=@2BL3<0T6ha0P2=JS80102>Jc<0Sf`d08m/=02@KCD2095^=P0:08a[
=@2<K3<0S6`c08e]<P2@L3<0U7De09Mh=`2JNcX0V7Hg09Ug>080VWPi00H0VGLh09Me=P2DLS<0TW0a
08e`>029K3@208EX<080QfXb00<0PfH^07mR:P22Ic000P22Ic0508=X<@80RVdc00<0Rfhd08a_=@2=
L3H00P2>LCL02@2?LSP0Me`W07EL9P1cFBH0KePV06aF9@1ZEBH0J5HV06QF:00306AC:0<0He8W0P1R
DBH2069A8`0306=B901TDbD0IE@V0080IUDW00<0IeHX06ED9P1UE2H01P1UE2H806IE9`0A065C;P1O
DB`0GDdY05a:9P1MBBH0HDXX06=<:P1VCR`0P5/^099`@`2]Reh0`9md0<NWOP3:[HD0ck><0=FiTP3D
^Yl00P3C^Y`07`3B^IX0c;BB0;jVPP2/U6h0WhMQ09AhD`2CN4d0Uge:0::9D@2dVfD0aZ]n0=:eT`3G
^Id0e/>d0=_8]`3Qck/0i]Bn0>OF_03Sd[H0gLb^0=W9Z03K^iD0e[N;0<^]M`2lWV00Zhe=09]k@02=
K3H0QF<c07UL<01eF2`00P1dEBT00`1gF2`0Oehc08MT>P0208aW?@0809Ad>`2HN3l0WGi70:63C@2P
QE00WXAA09^1CP2FOdd309IiC@0M09AgB`2AM4P0SG1408Y]@@28Jcl0PF/j081X>P1mICL0NUld07MJ
<P1dE2h0LU0]071>:`1PBBX0GDHW05I1901@?240BSTO04Hf7@14=1d0@c@M044b6`0o<a/0?C4K03X_
6`0f;Q/0=2dK034/6@0a:a/00`0]:Q/202`Y6P<0:bPI200X91T00`0X9A`09b@K02DR6@0202@Q6003
02DR6@0W91/0:2DL00P08b<I200R8QP802LR7P<0:24I0P0Y8QX302XS6`0302XW7P0Y9Qd0:2DL0080
9b@K00<0:2DL02TV7@0Z9ah0100`9Al3034V8003038W8@0e:Ad0=BTM00H0=BTM0P0e:1P00`0f:AT0
=bXJ03P[6`0203X]7@0303/^7P0i:ah0>B/N0080>R`O0`0k;B00100l;R40@c8P048a7`10;ad303h]
6`0303l^7010;ad0>C0Q00P0>C0Q0P11=Ad04@0o<a/0?S8J03lc6`10=1`0@SHN04<g7`14=1/0ASHM
04Ph7`19>B00BSXQ04Ti8018>1l0AcLN04Lb7`19=240BSDR0080BcHS00/0BSDR04Td8@17<Ql0CCLP
04dg7`1A>B40DcTP05Hk801J?200G3lQ05dn8@0205e38P80G48Q00@0Fd4P05Y07`1I?ah0FClN0P1L
AR401P1MAB40GT@Q06958`1UAbD0JTTX06a;:P80IdHS0P1XAb@306U89@0606Y99P1[B280K4TS06a9
8`1]BR@0Kd`V0P1`CBL2075>:005079?:@1cD2P0M54W07ID9`1hERP00P1iEbL207iI;080OeX]00@0
P5/^085L;`22GC00PUd`0P20Fbh00`1oFRd0OUT/07aG:P0207]F:@0707YE:01kER`0NUD[07UD:P1g
DRP0MU4W07A?9@0207=>90P0LTlW0P1`C2P02P1aCRP0Le0X07AA9`1eDbH0MU@W07ME9`1dDbP0ME@Y
07MF:`1iF2d207YI;P0507UH;@1hEb`0P5/_081K;`21G3000P22GC402023GS80Q5lc08AO<`2;IS80
S6Lc08iY=@2AK3P0TVdi0P2AK3P02@2@JcL0UVXi09I/>P2HKS`0VG4n09Mb?P2ELCd0TW4l095`>`02
09QfB@0709UgBP2JN4/0W7Y=09ajC@2MNdh0WWa?09mmD0030:B0C0D0Xgm;00h0YH5=0:B0C02ROTX0
XGe90:1lB02QODT0XWi:0:=oB`2TP500Xgm?0:9nCP2PO4`0Wg];09eiB@80W7Q80P2GLd<209QdA004
09UeA@2JMTH0VWI609YfAP80VWDn0P2KMSl309ag@00309eh@@2PNdH0X7]600H0WgY5202ONdL20:5m
C@80X7a<00@0Wg];09ijBP2NNTX0WWY:0P2ROdL00`2ROdT0XGe90:5mB`020:1lC0030:1kCP2VPDd0
YX5=0080Yh9>00@0Z8=?0:V4D02ZQE40ZXEA2P2WPe<20:R4E0<0ZHEE00@0ZXIF0:Z8FP2YQeT0ZHMI
0P2XQUP01@2WQEL0YXAF0:J4EP2WPdl0YX9>00<0YH5=00L0Yh=?0:V5D@2ZQU80[8eG0:^<EP2YRU@0
Z8UC0080YhQB00<0Z8UC0:V:E02]R5@01`2]R5@30:^8DP80[8UC0`2]RU@20;2;E`80[hYF00@0[XUE
0:f8E02]R5@0[HQD0P2^RTh00`2^RU00[hYC0:n:E@030;2;E`040;2:F@2cReP0/h]H0;6<F080/HeI
00/0/8mJ0:n@FP2_T5X0]8iQ0;F?HP2gTF@0^99U0;VCIP2hTVD0]i5T0;J@H`020;FAG`060;JBH02g
Tf40^9AR0;VEH`2jUV@0^iMU0P2gUFL00`2hUVP0^IMY0;ZHJP020;^IJ`040;bJK02mVW00_9U_0;ZG
K@80^II/00@0^YM]0;bIK`2mVW00]i]Y0P2iVfT00`2jVVT0^iUY0;fIJ@020;jHJ@P0`9i`00@0`9]^
0<6LK`31W6l0`Ia_0P32WG020<>NL@080<2KKP31W6l0`Yi^0<:NKP31WF/0_i]W0;fJI02kV6830;fK
J`<0_9YZ0P2kVFT80;bHIPH0^9IX0P2gUFL40;VEI@<0^9AT0`2gTf<00`2fTV80]I5Q0;B@H0020;>?
G`030;:>GP2aSEd0/8aL00@0[h]K00P0/8aL0;6=G@2cSF00/heN0;:<G@2bS5/0/HaH0;6<E`80/HaE
00H0[haD0:j;D`2^Re<0[HYB0:b9D@2[R5020:Z7C`040:b7D`2[QU80ZhIB0:^6DP80ZXEA0P2YQ509
0:R4BP030:AoBP2UP4/0YX5<00@0Z8=>0P2WPTd30:J1C080YH1;0P2TOdX20:J1C0040:J1C@2UOdh0
YGm@0:EoD080YGmB00P0YX5=0:F0C02TOd/0Xgi:0:AoB`2UP4`0Yh9>0:V4D0<0ZXE@0P2YQ4l30:R3
CP030:R5C`2YQU00ZHI@0080ZXMA0P2[R5800`2/RE<0ZHI@0:V6D0060:V6D0060:R2D@2WPE00Yh9>
0:N2C@2VPD`0YX5:0P2UPDL01P2QOTP0X7e70:1mA`2OO4H0WW]509ejA080W7U30`2PNdH[ooooo`00
:_ooool80:EjA`80Y7]50P2UO4H20:ImA`80Ygi80`2UNDX20:AhB@<0XgM8202WNdX90:MnBP070:Im
B@2TNdL0XgY60:=jAP2UO4P0Ygi:0:QoB`080:MnBPP0Z7m;0P2YOT/20:QmBP@0Yga92@2TNdL0202M
N4@0WWU509mjAP2PNdL0WgY609ag@`2JMD40V7<o0P2JM4D0102HLT<0Ug5209E_@02DKSl2099/?@80
TF`o00@0T6/n08iY?02=J3/0RfHi0P2:ICP808EP=P<0Oe`d0`1nFc<207eJ<P80NUL]00T0NEH^07QE
;`1gDbl0MU8`07EA;`1eDC40LE0]071?;01^CBX00`1/BbP04P1^CBX0Kdh[06a>:P1[CBT0JT`X06U;
9`1ZC2P0K4hZ06mA;@1aDbl0LUD]07MG<01kFc80NeX_07YH:`1lEbX0P5X[08AN;`<0R6@d1@27Hc<0
102:ISH0RfLg08]W=`2;IcL208aX>080SFTi00<0SfTj08iX>@2=IcP00P2;ICH00`2=IcP0SVPi08mY
>P0308iT<P<0SF<a0P2<HS001P2AICP0T6Dh091U>02?ISP0SFLh08aX>080RVPh00<0SVPk08eW>P2;
ICP00P2:I3L00`2;ICP0SFLj08iX>`0308eW>0<0SVPi0P2?JCX00`2:I3D0RfDf08eW>00208iX>@03
08eW>02;ICH0RV@e00P0S6Lc2@2=IcX2091Z>`0608mY>P2>J3T0SFLh08aV=`2;ICH0RV@e0P2>K3`0
1P2@K3`0TF/l099Y>`2CJ3/0TVLj09=W>P80SVLl00<0SVPk08iX>@2>J3L00P2>JCD0102>JC@0TF`h
08mZ=P2>JCD208aW<`0308iY=@2?JSH0TF`h00P0SFLh202<J3H308YV=P80RfLg0`2<J3P208AR=004
08ES=@26I3H0QV@f08MU=`80R6Hh2029I3L02027ICD0QV@d08ES<`24HS80QF<c08MU=@29IcL0RfTi
0P26J3H00`25IcD0Q6Hd08=U<`02085S<@0Q081R<021IC<0Of<a07eQ<@1kGc00NUda07YM<`1kGSH0
O5lg07YM<`1hG3@0M5P`06iE;@1XD2X0HddX05e99P1LB2D0DD@Q04m2801:?al0AC`O040i7`0m=b40
?CHS03`g900l=RH0>3DT03Db8`0`;R40:b/O02T[800W:Ql0:2/R00809RLO00@09BHN02@U7@0S91`0
8R<K0P0Q8QX2024T7@03020S700O8Q/07R4J00807B0I0`0L7aP201dP6@807R4J0P0O8Q/01P0J8AT0
6b8J01dT700N9Ad07B@L01`S6`806b8J00<06B0H01LM6`0G7A/01P0G7A/201`M7`0F01/M700J71T0
6adH01`O600N8AX082<J028V600S9aT09RPJ02X[6`0_;Q`0=34N03Ld8@0j=B40<bdC03<]5@0d;aT0
=S<P03Pf9`0b<bD09bLM01dN5P808B8M00L08R<M02<T700T9Q/09BLJ02HX6`0V:1X09BHN008092DM
00<08b@L028S6`0Q8QX00P0P8AT801dM6`P07R4J02007AdM01dM6`0L71X06a`G01`M5`0N7aL0828G
024S600V8a80<R`L03`g9010>BH0?3@O03/`6P0o<ad0A3PP054k4P1UCR@0OFHj08eeA@2AMd@0U7U2
0:F8D02eV5h0ZWe409Ea?`1[EC00@CTR02h`8`0_=2d0:c0Z028U7P<08bDR0`0T9R<202DW900302@U
7@0U9Qh09bPP00<0:BXR00D0:2TQ02LX800[;1h0;BhP030a8`0203<d9P03034b900^;b40;2dO00<0
9BHP0P0V9b4302LX8PT0:BXR00D0:RXP02`/8P0`;R80<RhR03H`8P0203Tb8P0703T_8`0j<2@0?c<U
04<e:018>2T0C3/[04ln;002054n;@80EdD]00<0ET@/05E3:`1D@RX00P1C@BT04@1B@2P0Ed4Z05I0
:`1D?bX0D3hZ04dl:P1:>RX0BCTZ04Hi:@16>BH0AcXW04Tl:@1:?BX0BC`Y04Pk:016>BH0A3LT0080
BcXV00@0C3/W04dl:01=?2P0CSdY0P1??RX3054o9`<0DT0X0P1C@BT20551:080D40W0P1??bH204hn
9@80DC/S00L0DShV050n:01??RX0C3dZ04Xk:017>RT0AS/Y0080ACXX00<0A3TW04<h9P12=bD00P11
=R@2044f8P06040e8`0n<R80?C4S03``900k;b<0>RdT100j<2@403/a9@0803H[9`0f:bD0=b`V03T_
9P0j<2H0>c4U03`c900m=2D303/a9@80>S0T0`0i;b<05@0i=R<0>3DR03Ld8@0h=B80>CHS03`i9P0o
?2T0@Ch[048g9@12=B@0@C@S048b8P13<R80AS<T04Tc9@1:=2H0CCTQ04lk8`1@?RH0DT8Y05=5:`02
0555:`060516:`1;@bh0Bd<^04e2;P1=@2d0CSl/0P1>?B/0101??2/0A3LT04Hi9P17>RL204Tl:@04
04Pk:017>RL0ASTV04Dh9@80A3LT00d0@cHS04@g9016>BH0BC`Y04Xm:P1@?bD0CchT04hm8`1=?280
CSdS04ln901A@2H0DT4W0080FTLY05d0FDHX05Q59`1GA2H0F4DW05Y7:@1MBR`0Gd`^05]=<`1JBS40
F4L[05Y5:01NABH0HdTV06Y<:01]CbT0MT/X07I>:P1eDBd0MUH`079H<`1^FSD0JETe06QJ=@1ODT40
H54n05m>>P1OCCD0HD/c06I<<@1XCC00K4la06QB:`1[F300KU`f06]K>@1TEcL0G5<f05QA=@1HDSP0
F4dg05Q<=01JBS00GT/]06A<:P1/CRP0Le4[07MD:P1oIC@0PFLf08I/>@2<Lcd0TgY209Z1B02NQD`0
XHU=0:V:A`2YRTT0ZHa:0:Z>C@2]U5@0/IUK0;NOH`2hXVH0b:AX0<NTJP33YFT0_jM[0;bYKP2jZg00
^:ic0;R_M02iZVL0]ZIX0;6RJ@2^WVd0Z9Ub09j?L02@PVP0QgQS07aeJ`1eKF80Jf=F06MNC@1YGTX0
JEe506QJ@01TES/0FThh05a==P1LC3D0G4`c05a;<@1NBRl00P1NBB`0401JBCD0FdTe05i:<P1RBS80
I4T^06M:;01[BR/0JdXY06a4:P1^AbX0LT/Z07I@:@1hDbH0NEDS07UF801iEQh2079A;P0607=B;`1d
Dc00ME@a07IE<P1gES<0N5Ld0P1lDSX00`1kDcX0NE@j07QD>P0207ME>P0907EF>P1mH400OV5107mR
@022IT40Q6Q108M[@`29KDD0RFi30080R78h00H0Rg8i08]a>02;KSH0RFXc08EV;`24Hbd208YW<@03
08MV<@26IS<0Q6Hd0080PVHf00D0P6Df08i[<`2>Jc<0SV/c08m/=002091]=@0<095^=P2BKcL0TVlg
08QV:@2;JB`0Sfd`09=a=02DLSD0Tg4d091^<@2?KC00S6Ta0P2=JS800`2>Jc<0Sf`d091]=@02095^
=P0808YY<`2:JS40Rf/b08e]<P2@L3<0U7De09Uj>@2KO3/209Ug>00809Qf=`2GMCH0UW@e09Ab<`2B
L340TFl`08a_=`29K3@208EX<00408MZ<P28Jc<0Q6L_081S:`@0PVL`1023J34208Y]<`0408]^=02<
KcD0SG0f08e`=P80SW4g00P0MU/V07AK9@1bF2D0KEHT06UC8P1XDb@0J5HV06YH:P80IE@Y00@0I5<X
06=B9`1RDBH0HU4V0P1QD2D2069A8`0406=B901TDbD0IE@V06ED9PX0IUDW201UE2H04@1RE2l0Ge4/
05e=:@1LBRH0G4PU05m89P1RBbT0I4`Z081K;P2CLD@0[XaO0<2OM037Ygh0bJb40<ncS03E^I80e;ZO
0080dkZL01l0dKRI0<^cT@2mYH40Zi=]09f5G`2DN5<0U7U>09UoC02US5@0^9mY0<V^P@3E^9H0fK^O
0=O4]@3Kb;T0hLnk0>KD_P3VeK/0h]6c0=_;ZP3GajD0eK>>0<n^P@34YFh0]9IF0::5@`2ALcD0QF@_
07eK:`1bEbX0Ke8V0080KE0T00<0Le@X07]J;`24HCL00P29I3X0202EMC`0V7U009enA`2QPdd0X8E@
09f3D02GP4`0U7e;0P2AM4P07`2@LdL0Sg9608a_@`28Jcl0QFPl089U>@1lISL0Nf<e07QP=01eFRl0
LE@/06m?:@1/BRL0JdTV05i6:P1IA2L0E3lT04hj8@18=Qh0A3@M044b6`11<Qd0>blG03X^600h;AL0
=2`G034Z5`0^:AH0;BLG02XW5P0]:Ad00`0/:1`202/W6`80:RHJ200X91T00`0W91d09R<L02DR6`02
02@Q6P0302DR6`0V8a`09b@M00P08B<H200R8QP802HQ7@809b0J0P0X8A/302TR700402XS7@0[:240
:BHO02LT7@809B8K00<09b@M02TV7`0[:2400P0_9200100`9B40<BHR038W8`0b9b<203<X90P0=RTP
00H0=2LG03DX600f:AT0=bXJ03P[6`0i;1`203X]7@<0>B/N0P0j;1l303/]800304<b8012<Al0?bhL
00<0?B`J00<0?bhL040_7@0h;b00200h;b000`10=Qd0?cDL03hd6`0203dc6P0603le7010=Qd0@CLN
04<c6P15=A`0AcLN0P19>B001P18>1l0AcLN04Hf7@14<Qh0AS@P04Pf8P80BCLS00/0B3HR04Hd8014
<Qh0C3HO04dg7`1@>200DcTP05Hk801J?200FchP05dn8@0205Y28080FD4O0P1H@1h205Lo7@0805a6
8@1KAB00G4@P05i48@1QA280IDLU06Y9:01[BRT306M68`80J4LT0`1YB2D01`1ZAb40JdPR06a98`1]
BR@0KT/U06m<9P1`CBL00`1aCRP0101cD2P0M54W07ID9`1gEBL207UG9`0607eH:`1nFB`0OUT/07mJ
;@20Fbh0PE`_0P22GC00101oFRd0OUT/07eH:`1lEbX207YE:080NE@W0P1jEB/0101hDbT0Me8X07E@
9P1cCR@2079=8`P0LDhV00`0Kd/W071<:01aCRP0LTlW07=@9P1eDbH0MU@W07ID9P1bDBP0M5<Z07IE
;01hEbh207UH;`0307QG;P1gERd0OeX^0080P5/_00<0PE``089M<@22GC400P23GS800`2;IS80S6Lc
08mZ=P02095/>00?091[=`2?JSH0SVTe09EY>02EJcT0Ufdk09M_?02EL3`0Tflk091_>P2?KST0UgE8
09QfB@2IMdX0VWQ;0080VgU<00@0WG]>09ilC`2NO4l0Y81<102SOd/30:9nBP030:F1C@2SOd/0XWi:
00<0X7a800P0XGe90:9nBP2SOdl0Xgm?0:9nCP2PO4`0WWY:09eiB@80VgM70P2FLT8209Mc@`0509Qd
A02IMDD0VGE509YfAP2JMCh00`2KMSl209ag@080WGQ100@0XGa70:1kAP2PNdH0WgY50P2NND@209eh
@`P0WWY60P2ONd/209ijBP0=09eiB@2LN4P0W7Q809]gA`2ROdL0XGi60:5nB02QODT0X7a:0:1lC02O
Nd/0WgY=0:F0C0020:J1C@030:N2CP2XPdl0ZHA@0080ZXEA2`2WPe<20:R4E0<0ZHEE0P2YQeT20:R6
F0060:N5E`2VQ5H0YXAF0:F3E@2XQ500Yh=?0`2UPDd02`2WPdl0ZXIB0:^7D`2]SUP0ZhaF0:R9D`2V
Qe40YHI@0:J7D@2XRE<0ZX]E00P0[HQD00@0ZXMA0:^8DP2[R580ZhQB0P2/RE<20:f:E0040;2;E`2_
RUH0[hYF0:j9E@80[HQD0P2/Qe<20:f9C@030:f9C`2^RU00[XUB0080[hYE0P2_RUH20;69E@040;2;
EP2_S5H0/8eG0:j=E`80[XmH00P0/XaO0;B>H@2fT6<0]i5T0;RBI@2gTF@0]Y1S0;F?HP80]91N00@0
]I5O0;JBH02hU680^IES0P2jUV@01P2fU6H0]iEW0;NEI`2hUVP0^IMY0;ZHJP80^iU[00<0_9U_0;^H
KP2iUV`00P2hUF/0102iUV`0^iQ^0;bIK`2eVFL20;NII`030;RHI`2iUfL0^iMW0080_9IW202nW6h0
1P2mV6/0_YU/0;nJK@30Vfh0`Ia_0<:ML080`iia00P0`9]^0<6LK`32WVh0`Yi/0<6MJ@2oW6H0_IYT
0;^HH0<0_I][0`2lVVX20;^IJ@P0_9QV0P2fU6H20;NEI`@0^9IX0P2jUVH20;VEI@050;RDI02gTf<0
]Y9R0;JBHP2gTf<00P2fTV800`2eTF40]91P0;>?G`030;:>GP0?0;6=G@2^RUX0[8QH0:b8F02^RUX0
/HeM0;:>GP2cSF00/heN0;:<G@2bS5/0/HaH0;6<E`2aS5D0/8]D0080[X]C00<0[HYB0:b9D@2[R500
0P2ZQdl0102YQTh0ZhIB0:^6DP2[QU820:Z5D@<0ZHA@2@2XQ4X0202QO4L0Xgi90:J1C02YQ4l0ZXE@
0:V4C`2WPTd0YH1;0`2VPD`20:F0B`<0Y7m:00D0Yh9=0:J1C02VPDd0YGm>0:EoD0020:AnD@030:=l
D@2VPDd0YH1<00<0Xgi:00<0YH1<0:N2CP2YQ5000P2ZQE030:V4C`<0Z8=>00@0Z8E?0:V6D02YQU00
ZXMA0P2[R5820:b9D`P0ZHI@0P2WPE00102WPTh0Yh9=0:J1C02VPDX20:F1A`80X7e700<0Wga609ik
A@2MNT@00P2LND<0102KN480XGa70:5lA`2QO4L[ooooo`00:_ooool80:=iB@0609md@@2PMD80XgQ5
0:EjA`2VNdP0Yga90P2VNdP80:EjA`P0Yga9202WNd`20:EkB@<0YWa:0`2WOD/80:MnB0P0YWe90`2Y
P4`20:QoB`<0Ygi:0P2RNDD0102SNTH0Y7]70:ElB02UO4P20:ImB@0A0:MnBP2SNT80Y7]30:ElAP2U
O4P0XgY60:5gA@2NM4@0W79209Ye@@2IM400V7<o09Mb?P2EL3`0U6lk09=^>P2BKCT01@2@JS/308mY
>P0908YU>029I3L0R6<f08MR=@25H3<0Q5lb08=N<@22GC00OU/a00<0Oe`b00@0OU/a07]H;P1iER`0
Me@Z0`1dE2/407EE;00707IF;@1cDRl0LU4^075@;@1`Cb`0Kdh[06e<:@0206a;:080J4LX00h0JDPW
06]:9`1/C2H0KThW06m?:01_CbH0LU@^07AD;P1fERl0NEP_07aI;`20Fbl0Pe`a08AN<@80QF0c1026
HC@208MR=@80RV<h00<0RfDh08]U=P2<ISD00P2<Ic<00`2=J3<0SF/k08aZ>P0208aZ>P<0RfTi00<0
RVPh08aV=`2<ISL01P2<ISL808mY>P0608eX<`2=J3@0SFPd08eW=P2=IcP0SFLj0P2=IS/02026HC@0
Qf8e08UT=`2:ICP0RfHi08YU>029I3L0R6<f202;IcL208aV=`<0SFLh0`2>J3T01@2BIcX0TFHi091U
>02?I3L0T6Dh0080TFHi00d0TfPk09EZ?@2<ICh0SFHm08mX?`2@JCh0T6Xm08mY>P2=IcH0S6He099/
?@2@JS/0SfTj0080SVPi00<0SfTj091Z>`2BK3d00P2>J3T208mY>P04091Z>`2AJc`0TF/l099/?@P0
SfTj0P2AJ3X0102?JCX0SVXj08iZ>P2<JSX208][>P<0S6Ph0P2;IcL308YV=P0;08aW>P2;IST0RVDh
08YU>02;IST0SFPk08mZ?@2@Jch0Sf/k08aX>027Hc<00P24H3000`26HS80RFDe08aX>00208]W=@06
08]W=`2;IST0RVDi08YU>`29I3X0RF<l0`28IC/00`27I3X0QV<i08ER>00208ER>00>08AM=027H3L0
RF@j08UV?028Ic`0QFHj089S=`1mH3@0PF<a081R<020HC80Of0b07iO<`1mGC@207aL=@0H07eL<@1i
F2d0M5@[075D;01_Db`0JU0[06=9901LA200ETDW05=49`1>@2<0B3lR048m800n?B40?CdS03/n8`0g
=R80=SDS03@c8@0a;b00;R`O02/Y7@0Y9Qd09b@K200U9Qh201lR6`807R4J0`0M81T00`0L7aP071hK
01`N6`0201dO70807R0M0P0O8Ah00`0N8AX07b8K024T7@0302<V7`808RDN00<08B@M01PN6P0H7QX0
0`0G7AT301HL60806A/H00@06Q`I01/M6P0K7AX071hK0P0M7a`0300Q9ad08BLK02@W700W:A`0:bdO
030a8@0f=B<0>CPV03Pb9P0c;B40<B/O03H`9080?CL[00P0<bdQ02PR5P0O81P07b0H024R6P0R8a/0
8b@L02@U7@809BHN0P0S91`2028S6`04024R6P0P8AT07b0H01lP60807b8K0P0N8AX201dP6@@071lH
0P0M81T201hQ6P807b8K00<0820N01lO7@0N7Q`00P0M7A/0900N7Q`07alM020P7P0W91/0:bTM03<_
8`0k=BD0@3TV040h8`0m=Q`0?C<J04di601JAR<0KeLa085U?@2=KT00UWI30:9oB@2YQTh0_8M10:Z0
A024JC`0EDX^03<d9P0Y;RP0:2dY02PZ9`0O8Ah0828O024S800R92408bDR02@V8`0U9b@09RPU02@W
80809BPQ00<09RTR02LZ8`0W:R<00P0X:b@00`0W:280:2TS02TZ900202X[9@0602TZ900X:B<09bPR
02HY8P0T9b008bHO0P0R9Ah00`0S9Ql092LP02HY8P0802LX8P809bLO00@0:2PP02TY8@0Z:R80:b/S
0P0/;2@203Da9P0503La9@0j<RD0?SDV04@h:019?2`00P1<?bh04P1B@RT0Dd<Z05I6;@1HB2l0EdL^
05A4:`1A@BP0CclV04i2:P1=@BT0C40X04/o9`19?BD0B3`T04Lk8`16>R80CC`Z04Th9P80AC@R00T0
BCPV04/j:01:>BL0B3LU04dj;01>>bd0CS//04hk:P1>?2P00P1>?2H0101>?2@0D40Y0510:@1@@2T3
0551:P80DT8[00H0G4<U05Y3901I@BD0ET4V05A09`1B@2P20510:@0804Ti801>?RD0DT8Y0592:@1>
?RD0C3`S04dm901@@2L204Dj9P0704@i9`12=RH0@CDW03lc9`0n<RH0?S4X03la9P0303h`9@80?BlT
0P0l;R<00`0l;bH0>bhU03/^9@0403/^9@0403`_9P0g<BD0=c4U03La9@<0>38V0P0i<bL203hd:0@0
?C<W0P0l<RH08@0g<BD0>C4T03Xb9@0m=2D0@CDU04@g9P17>2D0B3TV04@h:014=bL0@cHU04@e8P15
=200AcDO04/f8@1<>200BcTQ04dl8P1??R@0DD0T05=2901EAB@0ETHT05M79@1KAC00FT@_05Q3;P1D
@R`0DT0Z04lo:01=?RL0C3dV04Tm8`0204Tm9@0304Pl9P17>RL0AcXY0080ASTY0P14=b@01015>2D0
ASTV04Lj9`17>RL204Pk:00804lo9P1>?RD0CS`T050l901B?2D0E3hW05U0:P1K@R`205A3:@0905E4
:P1FAB/0F4L]05U8;P1KBS00G4/a05e<<P1NBbd0GDX/00<0FdPZ00@0G4T[05i;;@1OC2h0Je<_0P1X
D2`06P1]EC40MEdi07YR?P1iHCd0MUhj06YL=`1WEcD0HU8`05m<;01OBRd0HTX`06I>=P1XD3P0KU<V
06eE:@1^Eb/0K5T^06UJ;`1WFS00I5P^061G;P1PDSP0Ge4g05i@=P1LCS@0Fddc0`1JC380=01aD340
MUDb081O=P2;JCT0UW<i09ej>02POSH0Xgle0:^1=`2[Pc/0[XM20;2=B`2cTeH0]iQQ0;RMIP2jWfX0
aImN0<JPG`37XF00bZAS0<bVI@3?ZFP0d:YY0=6[JP39Y6l0bJEa0<JVM@32YgP0_JIl0;JTOP2`XWl0
[J1n09ZFL@2ETFh0RhQW07mnH01gME`0KfmG06Y/E`1XJEL0JVA<06USB`1VH4P0Hee5061J@P1MEcl0
FeDm05YD?01GDcX0EU8i05A@=`1BCSD2055==00:059>=@1CCcH0Ed``05M<<01GBBh0EdL]05U8;P1L
B2l0GTXa061:<P80HTd^01`0I4d]06I>;01ZD2d0L5@_07AH<@1gFC<0Ie4i06UC>`1ZECX0JE@g06QC
=01/F3L0M60o07]WA02<KDh0SFm=08i`BP2AM4P0U7Q609IkA02HOT<0VGm209Il@@2FNCl0TWDm08i_
>@2<JcP0SFTg0P2=IcP02@25HcH0QF<e08AR<P24Hbh0QFD/08QX:`2:Jb/0S6d/08MT;00208MW;P14
08YZ<@2;K3<0Rfhd08Q^<`27KC80QFda08UQ;@2<I300SfXe099_>@2CL3X0Sfhh08Y[=028JC80TVdh
095/=`2>JC@0S6Lb08YU<02;IS40S6Lb08eX<`24Hc00QVDb08QW<P2<JcD0Sfhh09=c>P2EMCX0UgLl
09Ab<`2ELcH0V7Hi09Qe>`2GM3`0Tg0j08iZ=P2;Ic<0SVlh08a]=`28JS@0PVLb07iT<@1kI380Nf<c
07YT<`22HcD0PF8d081Q<P20HS00PV@`08AV<027JC<0RF`d08Y/;P2ALcD0TG<g08]]<@2=KSD0TW<l
08Y[=@1lGBL0LEdX071L9`1/F2D0JEDS06MB8`1VDB@206IA9P0306=B9P1TDbL0IUDY0080IUDY00<0
I5<W069A9@1PCb<0201ODB@806AB9080He8T00<0I5<U06ED9P1VEBL00P1WERP0<`1XEbT0GU0]05i@
;@1LC2P0FTPR05U5801OBB80JE<Z079K<P20H2d0UGE40;2AHP32YGT0bJf50<Z`R`3=/i00d;RF0<Zd
W03?^Yl0eKfQ0=6hV@35ZhP0]YYc0:V=I@2TQed0UW]409QoB@2QQeH0[9AX0;bTOP3;]9@0eL2S0=_6
Z`3NckP0gLjg0=k>]@3RdKL0iM6f0>;=/03Ia:D0e;fM0=ViQP36Yfh0/IEF0::9B@2ANCd0Nf<c06mE
=01[DCP0Hd`]06A=;P0206Q@;P0K06iD<@1fFS<0OV4g08IW>`2:Jcd0UWU=09QkC`2JOE40W7mC09]n
DP2HNdl0U7M;095dB02EMTL0U7E6095b@`2>Kd00RV/l08MX>@24ICH0Pf@e07mO>01jGCD0MELa06mC
;01YCbX0IDdY0080HT/Y00H0ET8Y0590:01=>b<0AcLP04<d7`0o<Ql203db800@03<]5`0c;1T0<R/H
034Z600`:AT0;bLJ02lW700^9Q/09BDK02HV700W9ad0:2PN02LW7@0V9Q`092@J02<S6@<092@L0`0S
8a/2028R6PP08b8M0P0T91X0100S8aT08R8H028R600Q8AL2020P5PP08b<K200R8QX302@T70<08b<K
0P0R8QX802LS6P<0:RDO0P0[9R0302`W8@0302dW6@0^:1X0;bTK0080<2XL00<0;bTK02hX6P0]9aT0
0P0i:AT203XZ6P<0>b/K00@0?2`L03D[7`0f;200=bdQ0P0h;R800`0g;B40=R`P03D[7`0803d]7@03
03D[7`0f;200=R`P0080=R`P0P0g;B4203P^8P0803Lb700h<Q`0>C<M03Xb7@0m<Qh0?S4N040a7P11
<Ql204D_8@0304D`7`16<Ah0AS4L0080Ac<K00D0Ac<J04D_6P16<1/0BC<N04/e800204`f8@0804/e
801:=1l0CS@I04le6P1@=Q/0DSPM05@j7`1E>b0205Lm8P0305e29@1K@2<0FSlR0080FChQ00<0FSlR
05]08`1M@RD00P1NAR8305a4800405i68P1PB2@0HDTU06M8:@@0ITLX0`1UARL0201SAR@0I4LU06Q:
:01/BbX0KT/[06m;:`1]BBT0KTLX0P1dCBH02P1fCbP0N54Z07YC;01lEBh0OUL`07mH<@1mEbP0OUPY
081J:`22G2d208=M;P0B089L;@21Fb`0OE/]07aJ;01kFB/0NELY07QF:01fE2H0ME<U07AB901nCB`0
O4h/07Y>:`1gCb/0Le0Z075A:P1_DRX0KE4Y0P1dCRL0101cCBH0LT`U079<9@1aBb@2071:8`80KDXT
00@0KT/U06m<9P1aCRP0LTlY0P1cD2X00`1dCRL0MU0Y07QB:`0207YD;@0?07UC;01hDR/0Me4Z085L
;`20Fbh0OUT/07eH:`1nFB`0OeX]085L;`22GC00SF4d08iR=@2AICP0U6Pk00<0UFTl00d0U6Pk08m[
>`2@K3`0TFdm09=_?`2ELD40UW9209Mc@`2HM4@0U71009Ea@@2GLd<0VGE50080VgM700D0WGU909mk
B`2ONd/0WWY609mkA`030:1lB00309ijAP2MNDD0VgM300<0X7a<0P2ONd/309ijBP0809ehC02LMd/0
W7M:09YfAP2IMD<0V7A009Mc?`2GM3h809Ib@P0909Qc?02IM3d0VG@o09Ud@02JM4<0VWA509]eAP2K
MDP0VWE10080VgI200<0W7M309ehA02MN4@00P2NNDD309ijAP80WGU50`2LN4@00`2ONTH0WWU509eh
A00209ag@`0609ehA02NNDD0WgY609iiA@2ONTH0X7]70P2RODT01P2QO4P0WgY609iiA@2SOdl0Y81@
0:F1D@80YX9B00<0Y81@0:=oC`2QODd00P2TOTl00`2UOe00YX1A0:N1DP020:V3E0040:Z4E@2XQ500
Yh=?0:J2CP80YH5=00H0YX9>0:N3C`2XQ500[HQL0:^6FP2XPeL20:J1E@0;0:N2EP2YQ5P0ZhIJ0:R4
E02WPe<0YH5A0:B0D02SOdl0Y81@0:F1D@2VPU800P2ZQE420:V4D0<0Z8=?00@0Yh9>0:b4D@2/Q540
ZXEA0P2YQE400`2WQU40YXMA0:J7D@020:Z6DP80ZhMC0`2/R5@00`2]RED0[XYF0:j:EP020:f9E@<0
[8QD00<0ZhMC0:f9E@2]RED03`2]RED30;6<F080/8]G0`2_RUH20;:=F0040;B?FP2fTE`0]i9M0;VD
G`80^iIQ0`2iUF430;ZFHP80^iMS0P30VfL0102oVVH0_YUU0;jII@2mV6@20;bGH`80^YEX0P2kUVT0
1@2lUfX0_IQ[0;fHJ`2nVF`0^YIV00<0^iMW0P2lV6P20;fIJ@<0`9a/3@2oVf/20;jLK080_I][00@0
_9YZ0;^IJ@2kVFT0^YQX0P2mVV@20;bIH`<0^iQR00<0^YMQ0;VEI@2iUFD0102iUFD20;ZFIP060;ZF
HP2iUF40^9AP0;NCG`2fTUh0]I5M0P2dT5`0202bSET0/hiJ0;B?F`2dSe/0/hiJ0;6<F02_RUH0[HQD
0P2`S5P0102_ReL0[XYF0:f9E@2]RED20:b8E080[X]C0`2]RU830:b9D@80/8YM00<0[hUL0:j8F`2]
QeX00P2/QUT0102[QEP0[8MB0:b7DP2/Qe820:^6D@<0ZXE@0P2YQ4d00`2XPd`0Yh9;0:J1BP030:Ao
B0090:=nA`2WPTd0Xgi90:5lA`2TOdX0ZXE@0:^6D@2UP4/0WWU400P0XGa800<0WWe709mnB02QP4X0
0P2QP4X01P2POdT0WWe709elAP2PO4P0XGe90:9nBP80Xgm;00@0XGe90:1lB02NNTH0YH5=0P2VPTh0
0`2WPdl0Z8A@0:V5D@020:Z6DPP0ZHEA00h0YX960:J2B02WPT/0Yh9=0:R2D@2XPUD0Z85F0:V2F@2Z
OdP0ZH180:V0BP2WOd/0YH1;0:=oB`80XH1=00P0Y7m;0:=nBP2RODT0X7]709iiA@2MN4@0W7M309]f
@P<0YGe9:oooool002[ooooo202SNDT0102PMD80XGI30:AiAP2UNTL20:IkB0030:EjA`2TNDH0YGY7
00L0YGY7202WO4T80:MkC080XgU700@0Y7Y80:EkB@2UNdT0YWa:0P2WOD/80:MnB0P0Ygi:0P2YP4`3
0:QoB`<0Ygi:0P2SNTH40:AkA`<0YGa800h0XgY20:Ak@`2UO4H0Y7]70:=jAP2PMT@0WWA409ab@P2J
MD40VGA009Qc?`2GLSh0UG0l09A_>`80Tfhj0P2AJc`4091Z>`80SfTj00H0RVDh08UT=`28HcH0Qf8e
08EP<`24Gc8208=N<@80Oe`b00H0P5dc07mL<P1nFc40NeP^07UF;01gE2X607AD:`80MED/00D0LU4^
075@;@1aD2d0L4l/06m>:`0206i=:P0B06e<:@1XAbP0JDPY06Y9:01[BRL0KDdW06i>9`1_CbP0L50W
079D;P1dE2h0MUH_07UH;`1lFBl0P5/_089K<023GC00Peha0P24Gc800`25H3<0QV4d08MR=@0208QS
=P80Rf@i00<0S6Hi08aV=`2=IcH00P2=J3@00`2=J3<0RfTi08]Y>@0208]Y>@@0S6Xj202<ISL808iX
>@0608eX<`2=J3@0SFPd08eW=P2=IcP0SFLj0P2=IS/02026HC@0Qf8e08UT=`2:ICP0RfHi08YU>029
I3L0R6<f202;IcL208aV=`<0SFLh0`2>J3T01@2BIcX0TFHi091U>02?I3L0T6Dh0080TFHi00d0TfPk
09EZ?@2=ISl0SVLn091Y@02AJSl0TF/n091Z>`2>J3L0SFLf099/?@2@JS/0SfTj0080SVPi00<0SfTj
091Z>`2BK3d00P2>J3T208mY>P04091Z>`2AJc`0TF/l095[?0P0SfTj0P2AJ3X0102?JCX0SVXj08iZ
>P2<JSX208][>P<0S6Ph0P2;IcL308YV=P0308eX>`2<IcX0RfHi0080RVDh00/0S6Lj08iY?02?JSd0
SFTi08]W=`28I3@0QV8b08EQ<@27Hc<0RFDe08]W=`0208YV=00608YV=P2:ICP0RF@h08UT>P28HcT0
R68k0P28IC/208MT>P0B08IS>@25HSP0QF8h08ER>025GSD0Qf0g08UT>P29IS`0R6Ll08EV>P22HcL0
OV4e085S<@20HS00P64b07mP<P1nGc<0OEdd0P1lG3D0601mG340NEP]07AD:`1aE2`0Ke</06Y@:`1S
BB@0G4@P05E49P1B@bH0CT0S04Ln8@12?B00?C`P03`l8P0j?B80>3LS03He8@0d<b40<BlP02h/7`0/
:Qh0:BLK02PU70<09RLO00D09BHN02@U7@0T9Ad092DM02<T700201lR6`807R4J100M81T201`N6`80
7AlL0P0N81d201lQ7P0301hQ6P0O8Q/08B@M00808bHO00@08RDN024T7@0Q91d082<L0`0H7QX201LM
6@<05Q`H0P0I6aP0100J71T06adJ01/M6P0L7Q/201dO700<020V700Q9a/092LL02LY700[;Al0<34Q
03He8`0h=bD0>38T03<]7`0a:ad0=BlQ0P0l=RP0200c;Al0:R@F01lP600P8AT08B8J028S6`0S91`0
92DM0P0U9Qh01P0T9Ad08b@L02<T700R8a/08B8J020Q6@807b0H0P0O8Q/201hQ6P807B0I100L7aP2
01dP6@807R4J0P0O8Q/00`0P81h07alM01hN700201dM6`0K01hN700O7ad0820N02HS6P0[:Ad0<blS
03/e9@0o>2D0@3PS03df700m<aX0BSLG05Q48`1/ES40OF@k08]_@02FMTD0WWe80:J3C@2mRdH0[XA8
08U^@@1JC2l0>3DV02/^9`0Y:bP09bTV0080828O00@08B<P028T8@0S9B8092HS0P0U9b@00`0T9b00
9BPQ02DX8@0202HY8P809bXS00@0:2/T02HW8@0X:B<0:BXT0P0Z:bD01P0Y:R@0:2TS02HW8@0V:B80
92LP02<V7`808RDN00<08bHO02@W800V:B80200W:28202LW7`0402PX800Y:B40:RXR02/[8`80;2`T
0P0d<2D01@0f<2@0>C4T03dd9@13=bL0B3/[0080BSd/00<0D40W0592:@1DA2/00P1FARd0101DA2/0
D40W04hn9@1=@BT204a0:00704/o9`19?BD0B3`T04Pl9017>b<0CSd[04Xi9`0204He8`0404Xi9`1<
>bT0BcXX04Th9P80CCX/00<0CCX[04hk:P1>?2P00P1>?2H0101??BD0D40Y0510:@1@@2T30551:P80
DT8[00H0G4<U05]49@1J@RH0Ed8W05E1:01B@2P20510:@0804/k8P1??bH0Dd<Z0592:@1>?RD0Bc/R
04`l8`1>?RD204Dj9P0604@i9`12=RH0@CDW03lc9`0n<RH0?S4X100n<2D203d_9080?2hS200k;RD2
03D_8`80=S0T00@0=c4U03Pb9P0h<RH0>C<W100m<bL403`b9P0@03La9@0i<B@0>S8U03dd9@11=BD0
A3LV04Lh9@18>BH0A3PX04@g9`13=RD0A3DR04Dd8018=R00BcHQ04di8@80CC/S01@0CchT0550901B
@B<0E4@S05E5901FAR@0FdD`05Y4;`1H@bh0ED<]05=1:`1@@2T0CSlX04dn9`1:?R@0BShV04Tm9@19
?BL0B3/X04Lj:@80ASTY1019?2T304Xm:P0904/n:`1=?bD0CShU04dm901>?2@0DCdU05@n9`1I@2X0
FT4[00<0E4<Y00T0ED@Z05M6;01HAbd0FDP^05Y9;`1KBS00GT/]05e:;01LBB/00P1KB2X08@1LBB/0
GT/]05m<;P1WCb/0IDdY06I>:P1/E300MEdi07]S?`1lI400NV8n06eM>@1ZFSH0J5Dd06AA<@1SCS40
Hdhc06I>=01WCcL0KE@[06mF;@1`FBl0Ke`b06mN<`1/GcD0JUhd06UM<`1TES/0HeDj069D>@1QDcP0
Ge4f05i@=@0205e?=00d075B=P1gESL0OUhh08MW>02@L3L0VGPe09mm=@2QP3<0/8Hj0:n8?@2aRd80
/Y190;BCD02fUeL0]iYN0;RKG`30VUT0`I]J0<>MG035Weh0aj5P0<VSHP3:Y6<0bjET0<ZVJ03:YVX0
bJU`0<FZM@32ZgT0_ZUj0;VXO02fYg`0[JEn0:VQNP2PVWH0Ui9b08j;K026QFT0PGmX07inIP1fKeD0
MFiD079[D@1_J4h0JfA:06QQA`1UGT@0I5e305mI?`1MEcd0FeDk05UC>@<0F58h00T0FE<i05I?<`1E
CS80ET`a05I:<01HBS00FTXa05a<<`1NC3@00P1PCc40201RCbl0IE4`06YC<`1^EcD0Le/g07IL>@1`
F3`0LUXn0P1eGSl04P1eGSh0NV=1089/A`29Ldh0UgM@09MgCP2INT`0VWa:09aoA`2NPDD0Wh=20:25
@P2GOD00UgY009=f?02@LCX0SVdh08iZ>080SfTj00T0R6Hh08MU=@26IC80QVD`08MW;P29JBh0Rf/^
08e^;P27Ibh00P28J2l04@2:JS40RV/b08Y[<P28Jc40QfX`08EX;P29HBd0Rf<_08eX<`2>JcD0Sf`f
08a[=@29JS<0R6Tb095/=`2?JSD0SFPc00<0RfHa0300S6Lb08eX<`25I340QVDb08UX<`2<JcD0T6li
09=c>P2FMS/0UgLl099c<`2CLcH0UGDh09Ee>P2DM3/0T6li08a[=P29J3<0RFXc08MX<P23IBl0OV<^
07]Q;P1hHBl0N60`07QR<@22HcD0PF8d081Q<P21Hc40PV@`08EW<@27JC<0RF`d08U[;@2?LC<0T78f
08a]=02>KcP0T74k08MX<P1iFBH0LUhY071L9`1]FBH0JUHT06QC901WDRD206MB9`0806=B9P1TDbL0
IE@X06IE:@1UE2P0I5<W069A9@1PCb<805mA90P0He0U00H0HU4U06=B9P1SDRH0I5<W06ED:01VEBT2
06MF:P80GU0]0300GDdY05Y88P1IAB00GdTR06QB:@1aFS40PV8_09MgAP2aTV<0`ZEi0<V]Q@39[hX0
cK>@0<ngU@3;]Id0ckZO0=BmWP3@]iP0`jV60;FILP2XS6@0XhIL09AiA02HOT/0Y8UJ0;6IK@30Z880
c[NG0=K1Y03Laj`0gm2i0=o?^03OckH0hM2d0>CA/`3Pbj`0fL:R0=6jV03@/G/0_9mW0:R;C`2IOd80
RG0h07AL;P1XD2h0IT`c069;;01SC2d206M?;@0S06iD<@1gFc@0Of8h08MX?02;K3h0UGQ<09MjCP2I
O500VWeA09UlD02FNDd0TWE908mbAP2?L480SVm108]/?P28JC/0QFHh085R=01oH380OUla07YM=@1g
FS80LED^06Y@:`1UCBT0HDXX06199`1MBBP0Dd4Y050n9P1;>b@0ASLP040d7P0n<Ah00P0l<Al01P0c
;1T0<R/H034Z600a:QX0<2PK02lW6P80;RHK00<09BDK02HV700W9ad00P0W9ad00`0U9A/092@J028R
600302@T70808b<K0`0R8QX802<R7@808b<I0P0R8QP2024Q5`80820F200S8a/8028R6PP08b<K200W
8aX302XU7`80:bHP0`0/9b400`0/9QP0;RPJ02lY6`02030Z700302lY6`0^:1X0;2HH00<0>BTJ0P0j
:Q/303/[700303D[7`0f;200=bdQ0080>2hR00<0=bdQ03H/800e:al0200l;1d203D[7`<0=R`P0`0g
;B401`0h;R80=c8L03Pb700h<Q`0>S8M03`a7@0n<Ah00P10<Ah204@^800;04D`7`15<1d0AS4L04Ha
7016<QX0Ac<K04D_6P16<1/0BC<N04/e801<=R400P1;=B00301:=1l0CSHL04hf701?=ad0DCTO058j
801C>b40E3`R05Dm8`1J?b80FChQ05Ll7`80ES/N00/0Ec`O05Tn8@1J?b80GTHT05e58`1LA280Fd<Q
05a48P1MAB<0GdLU06189P0206=49@H0HT<T00P0HdHT06A79@1WBBL0JdXY06e::P1^BRX0KDTY06m8
:@80M4dV01@0MTlX07QA:P1jDb`0O5D^07eF;`1nEc00OELX07iH:@20FR/0PE//089L;@21Fb`0P5X[
07mI:P1lFRd0NeT/07YH:`1iEbX0MeDX07ID9`80M58U00P0O4h/07Y>:`1iCR/0Mdl[07=@:P1bD2X0
L50Y06iA:@80M4hW00@0LddV079<9@1bC2D0LD/T0P1`BR<01@1]BR@0KT/U06i;9@1_C2H0LDhX0080
LTlY00@0Le0Z07E?:01fD2T0N58[0`1jE2d0401iDb`0N58[085L;`20Fbh0OUT/07eH:`1nFB`0OeX]
085L;`22GC00Rf0c08eR=@2@ICP0TVLj09=X>`2DJC`209=X>`0<08m[>`2@K3`0TFdm09=_?`2DL400
UW9209Mc@`2HM4@0U71009Ea@@2GLd<0VGE50P2KMdL02`2MNDT0WWY:09mkB`2NNTH0Wg]70:1lB02Q
ODT0X7a809mkA`2MNDD0W7Q400<0Wg];0P2NNTX309eiB@0809agB`2KMTX0VgI909UeA@2HM480Ug<o
09Ib?P2FLcd809Ib@P80V7<l00<0VG@o09Ud@02JM4<00P2JM4D00`2KMDP0VWE109Ye@@0209]f@P05
09ag@`2MN4@0WGQ409ehA02ONdL00`2NNTH209eiA@80W7Q400<0WgY609iiA@2LMd<00P2KMT801P2L
Md<0WWU509mjAP2NNDD0WgY60:1kA`80XGa800H0WgY609iiA@2MN4@0XWi>0:=oC`2TP5020:F1D@09
0:B0D02ROTh0XGe=0:AnC`2UOe00YX1A0:N1DP2XPU<0ZH=D0080ZXAE00<0Z8A@0:N3C`2UPDd00P2T
P4`0202UPDd0Yh=?0:R4D02ZQET0ZHAH0:R3E`2WPUH0YX5E0P2WPUH0102XPeL0Yh=C0:J2DP2TP502
0:=oC`040:B0D02UPE40YX9B0:Z5D@<0ZHA@0P2XPdl20:N2CP80[8AA00@0ZXEA0:V5D@2YQE40YhIA
0P2VQe430:Z6DP80ZhMC0`2/R5@0102^RUH0[HUE0:f9E@2]RED20:b8E080ZhMC4@2/R5@30;2;E`80
[hYF0`2^RED02@2]R5<0[XUD0;2;EP2aS5L0/hiI0;F@F`2fTE`0]i9M0;RDH0030;VEH@80^YIR0P2k
Uf<00`2lUf<0^iIR0;^FHP020;ZEH@80^IAP00@0^9=O0;VEI@2iUFD0^YIV0P2kUfL20;bHJ0040;fI
J@2jUVH0^YIV0;ZFIP80^iMW0`2lV6P50;nKJ`<0_YYZ202oVf/30;fKJ`030;bJJP2kVFT0^iUY0080
^YQX00@0_IUU0;bHI02lV6@0_9QT0P2kUf<20;ZFHP80^YIV102iUFD20;RDI080^IEQ00@0^9AP0;NC
G`2fTUh0]I5M0P2dT5`02@2bSET0/hiJ0;>>FP2dSe/0/hiJ0;6<F02^RED0[HQD0:n;E`030:j:EP@0
[HUE0P2^Re<30:f:DP<0[8UA00H0/8YK0:n9FP2_REX0[XQI0:f7F02/QUL20:^5EP80[8MB0P2[QU43
0:Z5D0070:V4C`2XPd`0Z8=<0:N2B`2VPDX0YH190:AoB0030:=nA`040:AoBP2SOTT0Xgi90:F0B`80
Yh9=00<0Y7m:0:5lA`2QO4P01`2QO4P00`2NODL0Wgi80:1oB@020:60BP0;0:1oB@2NODL0WGa60:1l
B02QODT0Xgm;0:B0C02SOd/0XWi:0:5mB@2PO4P00P2UPDd00`2VPTh0Yh=?0:R4D0020:V5D@030:Z6
DP2YQE40ZHEA00H0ZHEA0P2VPTP0102WPT/0Yh9>0:R2D@2XPUD20:R1EP0@0:YoB02YP4P0Z7m90:Mo
B`2TOdX0Xgm;0:60C@2POd`0XWe90:5lB02PNdL0WgY609ehA02LMd<0VgI209Ye@@<0Xg]8:oooool0
02[ooooo202SNDL00`2RMd@0XgQ50:EjA`020:IkB0030:EjA`2SN4D0XWM400P0YGY7202WO4T80:Mk
BP080:1fA02QMdD0XWQ60:=iA`2TNTP0YG]90:IlBP2WOD/80:ImA`T0ZH1<0`2XOd/20:MnBP80YWe9
0`2UO4P40:AkA`80XgY60P2TNd<01P2TNdD0Y7]70:9iA@2PMT@0WWA409ec@`80VWE100@0VGA009Mb
?P2FLCd0U6lk0P2CKSX0102BK3d0TF/l095[?02AJc`2091Z>`80SfTj0P2:ICP01029I3L0Qf8e08IQ
=024Gc8208=N<@80Oe`b0P20GC<01@1nFc40O5T_07UF;01hEB/0M5@[00L0Le<Z201`Cb`0401YB2T0
JTTZ06]::@1/BbP0KDdW06m?:01`D2T0L50W075C;@1dE2h0MED^07QG;P1kF2h0OeX^085J;`22G2l2
085L;`0608=N<@24Gc80QV4d08QS=P29I3L0RVDh0P2<ICX00`2=IcX0SFLh08iX=`0208iY=@0608mZ
=@2;IcL0S6Ph08aX>02=JCT0SVXj0P2?Jc/00`2@K3`0SFLh08eW>00>08eW>00608eX<`2=J3@0SFPd
08eW=P2=IcP0SFLj0P2=IS/02027HSD0R6<f08YU>02;IST0S6Lj08]V>@2:ICP0RF@g202;IcL208aV
=`<0SFLh0`2>J3T01@2BIcX0TFHi091U>02?I3L0T6Dh0080TFHi00d0TfPk09EZ?@2?J440T6U0095Z
@@2BJd00TV`o095[?02@JST0SfTh099/?@2@JS/0SfTj0080SVPi00<0SfTj091Z>`2BK3d00`2?JCX3
091Z>`80TF/l202?JCX2095X>P0408mY>P2>JSX0SVXj08aZ>P80Rf/j0`2<J3P208]W=`<0RVHf00<0
SVTl08eX>`2;IST00`2:ICP00`2<IcX0SFPk08]W=`0208YV=P0308UU=@28I3@0R6@d0080R6@d0P29
IC<00`28I3@0Qf8e08MR=P0208MR>00408MQ>P27I3X0Qf@j08MT>P80QV<i0`25HSP03P25GSD0Qf0g
08UT>P28IC/0QfHk08EV>P22HcL0OV4e085S<@20HS00P64b07mP<P1nGc<0OEdd0P1lG3D0601mG340
NEP]07EE;01bEBd0L5@]06]A;01TBRD0GTHR05M49P1C@RH0CSlR04Pm8@12>al0?SXO03/i800j>R00
>CLR03Pe8P0f<b00<c0O034^7`0^:Qh0;2PM02/W7080:2TQ00H09bPP02DV7P0T9Ad08b@L028S6`0Q
8QX301lR6`807R4J0`0M81T201`N6`807AlL0P0N81d201lQ7P0601hQ6P0O8Q/08B@M028U7P0S9Ql0
8RDN0P0Q91d00`0P8a`06AlK01PN6P0201PN6P805adI0P0F71P201TK600401XL6@0K7AX06adJ01`N
6`807AlL00`082HL024W6`0S9Q/09RPK02X/7P0_<200=C@R03Lf900h<R@0=2hP038/7P0e;b4203/e
9`0303@^800]9aT0824I00<08B8J00@08R<K02<T700T9Ad09BHN0P0T9Ad00`0S91`08R<K024R6P02
020Q6@0301lP600O8Q/07b8K00807R4J0P0M81T401`O60807B0I0P0N8AX201lR6`03020P7P0O7ad0
7QhL00807AdK01`07QhL01lO7@0P81h09R<J02XX700a;B40>C<S03hg900o=b80?CHL03hd6`17<aP0
Dd0P06QA;`1jH3/0R6e209=dA@2LNdP0X7m:0;j>C02bRTl0TGE606AD<`10>BH0;blS02X[9@0U9b@0
828O0P0Q8b001@0R92408bDR02@V8`0T9R<09BLT00@09BPQ0P0V:B8202LZ8`0302HW8@0W:280:BXT
0080:R/U00H0:BXT02LX8P0V9b409RTR02@W800S9Ql2028U7P0302<V7`0T9b009RTR00P09bPR0P0W
9al0100X:200:BTQ02XZ8P0[:b<202`/9007034]8P0b;R<0=BlS03L_8P0k<R<0@CDU04Dh:00204Lj
:@0304dm901??bH0DT8Y0080E4@[00@0DT8Y04lo9P1=?B@0C40X0P1;?bL204Xn9P80BCdU00<0B3`T
04ln;01;>RP00P17=R@0101;>RP0CC`Z04`k:@1:>BL204`i:`0604dj:`1=>RT0CS`X04hl9P1??BL0
CcdU0`1@@2T30551:P80DT8[00d0G4<U05]49@1K@bL0F4<X05I2:@1C@BT0DD4Z0510:@1>?RD0DT8Y
05E5;01C@bX0CShU0080BSXQ00T0C3`S04Dj9P15>RH0A3TW048f9P11=BL0?c<W03hb9P0n<BP00`0m
<BD203``90<0>blS0`0k;RD203`_9P<0>bhU0P0b;2001P0c;B40=BlS03H`900g<BD0>38V03Tc9`P0
?38V01P0=c4U03Ta900j<RD0?C@U044e9@13=RD0AcPU04Pi9P14>2P0A3LW04<f9@14=B80ASDQ04Pf
801<=b80CCTQ04hl9P1??BL0CcdU050o9@1A@2@0DT4S05=38P1DA2<205]5;P0705U5;@1E@b/0E48Z
0592:@1@@RP0Cd4W04a09P0204/o9`0304Xn:019?2T0B3/Z0080AcXZ101=@2d304`o;00904/n:`1=
?bD0CClU04dm901>?2@0CcdU05<o9`1E?bP0Ed4Z00<0E4<Y0P1EA2X205I5:`80EdH/00P0GT/]05e:
;01LBB/0FdPZ05a9:`1MBR`0Gd`^061=;`80Hd/W00@0IThZ06aD<01dG3P0Nf<o0P1mID403P1bH3X0
L5hj06iL>01/FCP0JEHf06MD=P1VDCH0IE0e06aE;01^Ebh0L5Xc075N=P1cHCT0Lf@k0P1cIS`206aM
?P0L06]L?@1ZFc`0J5Tj06IG>01TECH0He@e075B?@1cEC/0N5Xh07mP=028JC80T74^09Mj;P2MORh0
/8Tj0;6:>`2bSCl0/hm30;BBB02fUTd0]YQ@0;NID@2lUE80_IIC0;jGE030VEH0`IYG0<>LF@80a9eJ
01d0bjIP0<bWH@3;ZVL0bZa/0<V_LP36/7@0aK1g0<BaN@2n/8<0_:n20;R[P@2bYWh0ZImk0::IN02J
U7@0Ui1c08b1H@2;P600R7eM08AiF@20MED0O75A07U^CP1gK4`0LFQ706mVA@1/Hd80JV5006QO?P02
06MN?@0906QO?P1NFSl0GETn05eG?@1MES`0GeDl065E?@1RESh0IEHo0080IEXn01@0J5Xm06]L?@1_
Gch0MF9107QV@P1kId@0P6Q608=[B@26KTX0Qfm908QaB02<MD/0U7eC09^4F02RQ500XXA>0:>6C02S
QTX0Y8Q70:B9A080Y8Y000H0V7i109Qk?`2EN3h0Tg@m095`>P2AKCT2095[>P0808aZ>P2;JSL0RVTd
08UX<`2:JS40Rf/b08e]<P2>KS4308UX<P0<08YY<`29J380R6La08IU;`23I2d0PV</08UQ;@2:HRh0
RF@_08UV<02:Ic40RFPb0P28JC8208eZ=00N08]X<P2:Ic40RVLa08]X<P2<JC<0SFXd08MV<`28Ic@0
RVTd08e/=P2AL3X0U7@k09If>`2GMc`0TG8b099b=@2DM3L0U7@i099b>@2>KCL0RVTd08MV<@23I2d0
PV<]07iP:P1jGbX0N5h[07MP;P1gGbl0Mf4`0P21HS@05021HS<0PF<a08=U<@25Ic40QfTc08Q[<`26
JBd0Rfhb08e`=P2=L3P0SW4i08a^>022I300M5HR079N:@1`G2L0KETV06YF901XDb@0J5<V0P1XDbP2
06=B9P<0I5<W00<0He8V065@901PCb<0201ODB@9065@9080HU4U00<0He8V06AC9`1UE2P00P1VEBT0
<P1ODBh0GU0]05e=:@1JB280FDDP05m98P1XDRT0LEXa08IV<`2JNTT0/iAU0<>VNP39[HD0bJn:0<bb
S`3?]iD0bkJK0<njW@3C_9d0cKFC0<2VP@2bUVh0YX]P0::5F@2AMT40VX1=0:V>G`2hWgH0aZj:0=6j
V`3H`jP0gLN_0>;A_@3Pd;T0h<jf0>;>/`3RcJh0g/NU0=BnV@3<]8h0`J=]0:j@FP2HOTD0Rg8j07]T
<P1ZDbT0H4TY05m7;@1OB2T0HDX[0P1WCbd08`1^E340N5`e081S>@29JSh0S6do09AgB`2EN4`0UWU=
09MjCP2EN4`0TWE908iaA@2<Kd<0QfXn08EX?023ISX0P6<g07eP=01iG300MeX^07II;@1eEc40LED^
06eA;01VC2T0H4PT05a58`1IAB@0F4@S04lm9@1<?2D0BCTR04@e800o<Ql0>c0N0080>2lN00H0<2/G
030[600_:QL0;bTI02hX6P0]9a/202`U6`0802@T6P0U9A/09RHL02LW7@0V9Q`09BDK02<S6@0R8QP2
02@T70808b<K0`0R8QX00`0Q8AT08R4L028Q7006028Q70808R8J0`0Q8AT3020P60P08R8J2`0Q8AT0
0`0R8QX08b<K02@T700202DU7@P09b<J0`0Y91h202XU7`<0:bHP00<0;2HJ02dW6`0_:Ad00P0`:Qh0
0`0_:Ad0;BLK02`V6P0303HY6@80=bXJ0`0h:a/00`0d:Qh0=B/O03H/800203L]8@0303H/800e:al0
=2XN00P0>2/K00<0=2XN03D[7`0e:al00P0e:al203H/8080=bdQ00P0=S4M03L`7@0h<Ah0>C4N03`a
7`0m<1l0?blO040`8080@BhP00<0@RlP048_7P13<Ad00P13<A/01@14<QX0A2lJ04D`6`17<Qd0BC@O
0080BSDP0P19=1l204lg7`80D3PP0P1A>B42058j8P0305Lm8P1F?240E3XO0080DcTN00D0E3XO05Hl
8@1G?B80G4@R05]38@0305Y2800305a48P1NAR@0GdLU00P0Gd0Q0180HdHT06A79@1WBBL0JTTX06a9
:@1^BRX0KDTY06m8:@1bC2D0LddV07A>9`1fD2T0N58[07YD;@1kEBh0O5H_07eH:`1nFB`307mJ;@0=
07iI;01lEbX0NeHY07YG;@1iER`0N5D[07MD:P1fDbT0ME8X07AA9`1cD2H0NTh[07U>:`0207I>:P80
LTlY00D0LDlY06m?:01dCRL0M4hW07==9P02079<9@03075;901`BR<0L4XS0080KT/U00@0Kd`V071=
9`1`CBL0LDhX0P1bCbT01@1gDBX0N58[07UC;01jE2d0NeD^0080NU@]00<0NE</07mJ;@1oFRd00`1n
FB`01`1oFRd0PE`_089M<02;H3<0S64d08iS=P2@ICP0102BIcX2091/?00:095]?@2BKSh0U71009Ea
@@2FLT80Ug=309A`@02ELD40UW9209QdA080VWI600/0W7Q809eiB@2NNTX0WWY609mkA`2PO4P0XGe9
0:1lB02ONdL0WGU509ahA00309eiB@80W7Q80`2KMdL209UdB00609QcAP2HM4@0Ug=109Ib?P2ELCd0
UG8l202ELD40202GLS/0V7<l09Qc?P2HLcl0VG=209UcA02JM4D0VWA70P2JMD4309]f@P<0W7M30P2O
NdL209ijAP80WGU50P2LN4@00`2NNDD0WGQ409]f@P0209Ye@@0509]f@P2MN4@0WWU509iiA@2ONTH0
0P2PNdL01`2ONTH0WGQ409]f@P2JMD40X7a<0:5mC@2SOdl00P2TP5000`2SOdl0XWi>0:5mC@020:Eo
D0030:J0D@2WPE80Z89C0080ZH=D00@0ZXAE0:N3C`2VPTh0Y81<0P2SOd/0102TP4`0YX9>0:N3C`2V
PE@20:N2E@080:R3EP2WPUD0YX5D0:F0D`2TOe80YX9B0:F1D@2SOdl20:9nCP030:=oC`2UPE40YX9B
0080ZHA@0P2XPdl30:N2CP040:J1C@2[Pe00Zh=@0:V4D080Z8A@00<0YXE@0:F6D02UQU000`2YQE42
0:Z6DP<0ZhMC0P2]RED20:b8E0<0ZhMC00<0ZXIB0:^7D`2[Qe<03`2[Qe<0102_RUH0[XUE0:j9E@2^
RED20:f8E080[8MC00P0ZHA?0:Z5D02[QU40[HQC0:n:E@2aS5L0/XeH0;>>F@<0^9AP0P2iUF430;ZF
HP<0]i9N0`2fTEd20;F@G0040;RDI02iUFD0^IEU0;VEI@<0^YIV00<0^iMW0;RDI02hU6@00P2iUFD2
0;ZFIP80^iMW402mVFT0102lVVX0^iUY0;^IJ@2kVFT30;ZHJ0030;VGI`2lV6@0_9QT0080^iMS0`2j
UV801@2iUF40^iMW0;ZFIP2jUVH0^IEU0080^9AT0P2gTf<20;RDH080]i=O00@0]Y9N0;FAG@2dT5`0
]91L0P2bSET20;>>FP040;:=F@2`ReL0[XUE0:f8E0<0[8QD0`2]RED20:j:EP80[X]E0`2]RU@30:b9
D`80[hUJ00<0[XQI0:f7F02/QUL00P2[QEH00`2ZQ5D0ZhIA0:^6D@020:Z5D0<0ZHA?00H0Z8=>0:N2
B`2WPT/0YX5:0:F0B@2TOdP30:=nA`030:9mAP2PNdH0Xgi90080YX5<00@0Xgi90:9mB02RODP0Y7m:
202QO4P00`2OO4H0X7e70:9oB@020:>0BP060:9oB@2PODL0Wga60:5mB@2ROTX0Y81<0P2UPDd0102T
P4`0XWi:0:5mB@2TP4`20:F1C@030:J2CP2WPdl0Z8A@0080ZHEA202XQ5020:J1BP040:J1C02WPTh0
Yh5@0:R2D`80Z89E00H0ZGi70:QoA`2XOdT0YWi:0:AoBP2ROTX20:1oC0060:1kA`2ONTH0WWU509eh
A02KMT80VWE10P2IM40309mjAR_ooooo000Zooooo`P0XgY600<0XgQ50:AiAP2UNTL00P2VNdP00`2T
NDH0XWM40:5f@`080:EjAa00Yga90P2OMD<0102PMT@0XWQ60:=iA`2UNdT20:IlBPP0YWe7202ZPDd3
0:QoB`80Ygi:0`2VODT0102WOTX0YWe90:ImB@2UO4P20:AkA`030:=jAP2RNDD0XWU50080YGa400@0
Y7]50:=jAP2QN4@0X7I40P2NM4@02@2KMT80VWE109Ud@02HLcl0UW4m09E`?02DKc/0Tfhj09=]?P02
099/?@03095[?02@JS/0T6Xk0080SfTj00T0RfHi08YU>029I3L0R6<f08IQ=025H3<0Q5lb08=N<@1o
G3800`20GC<0101oG380O5T_07YG;@1hEB/307AD:`@0Le<Z00<0LU8Y06m>:`1_CR/00`1`Cb`3075@
;@80JTTZ01H0JdXY06e<:@1^CRP0L50Y075A:P1aDBP0LE<]07AD;P1eEBh0MeH]07YG;@1nFBd0P5T^
081J;@1nFB`0OeX]085L;`24Gc80QV4d08UT=`2;IST0S6Lj0P2=IS/00`2=IcX0SVPi08iX=`0208mZ
=P0908mZ=@2;ICH0S6Hg08eW>02>J3T0SfTj091Z>`2AJc`0TV`m00P0SFLh202;ICH01P2=J3<0SFPd
08eX=02=IcH0SFLh08eW>P80SFHk00P0R6<f08UT=`2;IST0S6Lj08eX>`2<IcX0RfHi08YU>0P0RfLg
0P2<ISL308eW>0<0SVPi00D0TVLj095V>@2@ICP0Sf@g091U>002095V>@0=09=X>`2EJSd0T6U2095Z
@@2BJd80Tfa109=]@02BK3d0TF/j091Z>@2BK3d0T6Xk08mY>P0208iX>@0308mY>P2@JS/0TV`m0080
SfTj1P2@JS/808mY>P80TFPj00@0SfTj08iZ>P2>JSX0S6Xj0P2;JcX308aX>080RfLg0`2:ISH0102?
JSd0SVTl08aW>P2:ICP208UT=`0408YU>02;IST0RVHf08YV=P80RfLg00`0RVHf08UU=@28I3@0Qf<c
08UU<`28I380Qf<c08IQ=025H3@0QF0f08IQ=`27HCX408IS>@@0QF8h00h0QUlf08MP=`28HcT0Qf@j
08IU>P24ICT0PV<g07mR=P21Hc40P68`081Q<P1oH380OUlc07eM=080O5`e01P0OE`a07YI;P1eEB`0
LUD]075E;P1/DRd0IT`W05m78`1IA2L0ED4V050o8`1:?240@cTN03hh7P0m>B00>SPO03`g8@0k=R80
>C@P03Lb7`0d;Qh0<R`N030Z7P0_:Ad202TZ8P0602LX800V9al092DM028S6`0Q8QX0824I0P0P8a`2
01lR6`807R4J0P0M81T201`N6`807AlL0P0N81d201lQ7P0301dP6@0N8AX082<L00<08RDN0P0Q91d0
0`0P8a`06AlK01TO6`0301PN6P<05adI0P0I6aP0100J71T06adJ01/M6P0L7Q/201dO700A020V700P
9QX08bHK02HX6`0Y:ad0;RlO03<b800e=280>C<S03D_7`0b;1`0=2hN03Tc8`0j=2@0=S0P034[6`0R
8a/0100Q8QX00`0S91`092DM02DV7P0202@U7@0402<T700R8a/08R<K024R6P80824I0P0O8Q/201hQ
6P807B0I100L7aP201dP6@807R4J0P0O8Q/00`0P81h07alM01hN700201dM6`0K01hN700O7ad0820N
02DR6@0Y9a/0<2`P03La8@0l=B80?SHQ03df700n=1/0@S4G04`k7`1OBR/0Le/g08AX@@2?LTH0V7Q9
09]kBP2iT580/hiG09amC`1aGCX0C40X03Pb900[:b<09BHQ00808B<P0P0R924202<U8P8092HS1P0U
:24202HY8P0302HW8@0W:280:2TS0080:BXT00H0:2TS02LX8P0V9b409RTR02@W800S9Ql2028U7P03
02<V7`0T9b009RTR00P09bPR0P0W9al0100X:200:BTQ02XZ8P0[:b<202`/900702l[800`;240<bdQ
03H^8@0j<B80?c<S048e9@0204<f9@0804Xj8@1<?2<0D40W0592:@1C@bX0DT8Y04lo9P1=?B@304/o
9`80BShV0`19?BD0201@?bd0BcXX04Lf9018=bD0BcXX04hm:`1=?2X0BSTW0P1;>2X01P1<>BX0CCXY
04dk9`1>?2H0CcdW04lm9@<0D40Y0`1A@BX20592:`0@05a39@1LABH0G4@X05Y5:P1HA2/0E48Z0551
:P1@@2T0D40W05A4:`1FARd0E4@[04hn9@1:>R40BCTP04/k8P80ACXV00H0A3TW048f9P11=BL0?c<W
03hb9P0n<BP203/a9@80>S0T0P0i;b<203P^8P0303X]900k;RD0?2lV0080?C0W00/0?2lV03/^9@0j
;B@0<2XN034[7`0b;200<bdQ03D_8`0f<2@0=c4U03Pb9P0203X`90@0>c4U0P0l<RH0600f<2@0>30S
03Ta900l<b@0@3@T04<f9@16=b@0AcPU04@h:014=bL0@cHU04Df8`16=B40BCLQ04dh8`1?>b<0D3hZ
04lm9`1>?2H0CS`T04ln901@?b<0DD0R05918`80FdD]00@0FDD/05I5:`1FAB/0E4@Z0P1BA2T02@1>
@RP0CD4Y04a0:01;?bT0BSdZ04Tl:`18>b/0AcXZ04i1;P0204e0;@0504`o;01;?R/0BSdZ04Xm:P19
?2T00P1:?R@01P1<?R@0CShU04lm9@1@?RH0DclW05Do:0T0E4<Y0P1MBR`07P1LBB/0FdPZ05a9:`1N
Bbd0H4d_065><01UCBT0IThZ06Q@;01]EC40Le/g07MO>`1jHSh0Nf<o07QR>`1hHSd0MV8m07AP?@1`
GC`0JePh06ED=P1RDC<0Ie<`06QD<@1/F3<0L5`g07=Q>@1fI3`0NFPm07QY?P@0M6A001X0LV8n071P
?01]GCT0K5`h06mD@@1^E3d0L5Dg07AI;P1kH2/0Q6PW08ea:02AMRT0ZH@f0:Z5=`2]R3X0[h/m0;>@
?`2gU4<0^II50;VHA`2jTTd0^i=>0;bDC`2mUE00_iMB0<2HD`80`IUD01d0bjIH0<bWF@3=ZEd0cZaR
0<j`J03@/fd0d;E`0=6fL@36/GX0a[5l0<FaOP30[Wh0^jYn0;>TN`2]WWL0ZI]f0:BEKP2SU6d0X95Z
09^<I@2GR640ThAM0921FP2>OeP0RWaE08QjD`25Me00PWA=081bB`0207maBP0J081bB`1bLE80Lg1A
075^C`1`Jdd0LFY=07A[CP1fJdl0Mfa@07M^C`1hKe00Ng1@07mbD023ME80QWQC08UiE@2=NeD0V7aD
09YoE02MPUL0W85D09^0D@2MPe80XXQE0:R>F`2ZS4`20:V<BP0@0:R;A@2WRd80YXY00:F:?@2URS/0
V7lo09Um?P2GNSh0UGHm09Ac?@2DLC/0Tfhj09=]?02@KcX0Sfhi08e/=`80RfXd00@0Rf/b08a/<`2=
KC@0RFXd0P28JC<01P28Ic80QfHa08MS;`25HBd0Q5l[08=N:P80RV8^00H0Qf8]08MT;P27I2h0QfH`
08QY<P29JS<608UX<P80RVTc00T0QfHc08UX=@2;JSD0SVdg095`>P2CLcX0UWHk09Mg?02@LS800P2A
LcD03@2@LSH0SVlf08Y[=027J380QFH`089S;020HB/0OV0Z07]P:`1iGb`0N64_07UQ<@1iHc800P20
HC<05P21HS<0PV@b08AV<P25Ic40QfTc08MZ<P23JB`0QV`a08Q^=@2:L3L0Rg0i08I[=P1jGR`0Ke<Q
075M:01_FbH0K5PU06YF901XDb@0J5<V06QC:01YE2T406=B9P04069A9@1QD2@0HE0T061?8`P0Ge4T
201NCb@2061?9003065@9@1RDBH0He8W0080I5<X03<0IE@Y05i@;@1ND2d0G4`X05Y88P1IAB00GdTR
06UC:P1bFc80Rf/h09inC@2fUfP0a:Mk0<V]Q@38[XT0bk6>0<jfU03<]iX0ckZK0=6jVP39/Hd0_:=k
0:jCJ02SR5/0X8AE091d@P2LPU40/9EX0<2WO`3=]I<0eKfQ0=[4[03ObK80iM;10>;@_03QcKD0hLb_
0>39Z@3I`Id0cKJ=0<F/P`2cV640X8E@08]a?P1mICD0LEX`06==:01LABH0FdH[05e69`1PBBX00P1V
CR`01@1^E340NEdf085T>P2:Jcl0SFi00080TWE902h0TgI:099eB@2@LdL0SG1408U/@027JSh0PFHi
081U>01nHcH0Nf0c07QM<01eFRd0LeP[079G:P1^DR/0JU0[06E;:01OAb<0FT<Q05E1801B?al0DChN
04Xj8`18>B80ACHQ040c800l<Al0=bhM03D^7P0d;Ad0;BXG02dZ6@0/:AP0:bPI02XV6P0Y9AX0:BDL
02PT6`0S8aT092@J02DU6`0V9Q`09BDK02@T6P0R8QP08B4G0`0S8a/3028R6P808B4I200Q81/8020O
6Q008B4I0P0O7aL01P0P81P08R8J02<S6`0T91`09BDM02HV7PP09b<J0P0X8ad302TT7P<0:RDO00<0
;2DK02dV700^9ad00P0_:1h00`0^9ad0;BHL02`U6`0203<W6@80=2PJ0`0e:A/0100f:Q`0<bTM03@Z
7P0e:al203L]8@0303D[7`0d:Qh0<bTM00P0=BTK1@0d:Qh203D[7`80=R`P00P0=C0M03H_7@0g<1h0
>2lN03/_7`0l;al0?RhO03l_8080?bdQ00@0?bdO040_7`10;ad0@C0L0P11<AX204<a6`0304@b7015
<ad0AS@N00<0AcDO201>>2000`1G?bD0EShT05@l8P0205<k8@0605@l8P1F?R@0EclU05]28`1J@B80
FD0Q0P1H?b000`1J@B80G4<T05e49@0405m08@@0H44R00D0HdHT06A79@1VB2H0JDPW06]8:00206e9
:@0706m8:@1`CBD0LDhV079?9`1cD2P0ME8Z07MD;00207QE;@0>07YH:`1kFB`0O5X]07aJ;@1kFB`0
NELZ07ME:01fE2L0N5D[07MD:P1fDbT0ME8X07AA9`1cD2H2079?9@80MThZ00<0MDdY07A>:@1cCBP0
0`1aCRP207A>9`0407==9P1bC2D0LT`U075;9080L4XS00<0KT/U06m<9P1_C2H00P1`CBL2075>:003
079?:@1hDR/0N58[0080NE</101jE2d307eH:`0307iI;01oFRd0P5/^0080PE`_00D0RF0b08YQ<`2<
HcD0SF@f08mV>002091W>@0=095X>P2@K3`0T6`l095]?@2BKSh0Tflo09A`@02ELD40UW9209A`@02E
LD40UW9209Mc@`0209UeA@0609YfAP2KMdL0W7Q809eiA@2NNTH0Wg]70P2PO4P00`2NNTH0W7Q409]g
@`0309]gA`80VWI60`2IMDD01@2GLTH0UW5509IaA02ELD40UG4o0080U70l00<0Tg0j09=_?`2CKcl0
1P2CKcl209Mb>`0609Mb?@2GLSh0V79109Qb@`2ILd@0VG=61P2JMD4209]f@P80WWY60`2MNDD309ah
A00309ag@`2KMT80VWE10080VGA000<0VWE109]f@P2LMd<00P2MN4@209iiA@0709ehA02KMT80VGA0
09Qc?`2NNTX0X7a<0:5mC@020:=oC`030:9nCP2QODd0X7a<0080YGm@0P2VP5420:N1DP80Z89C00<0
YH5=0:B0C02SOd/00P2ROTX01P2SOd/0Y81<0:F1C@2ROTh0Y81@0:J2DP80Yh=C00/0YH5A0:9nCP2P
O4`0Y81@0:=oC`2ROTh0XGe=0:9nCP2SOdl0YH5A0:J2DP020:R3C`80Yh9>102VPDd20:Z2C`040:R3
C`2WPdl0Yh=?0:F4C`80Y8E?0P2WPdl20:R4D0<0ZHEA00<0ZXIB0:b8E02/R5@00P2[Qe<E0:Z6DP<0
[8MC0`2[QU820:Z5D@080:R3CP2YQ4l0ZXE@0:b7DP2^RE@0/8]F0;6<E`2bSEP20;JBGP80]i=O0P2h
U6020;VEH@D0]Y5M0`2eT5`30;NCH@D0^9AR102gTf<20;RDI080^IEU102kUfL40;bHJ0P0^iMW0P2j
V6P60;VGI`80^iMU0P2jUV@40;VEH`060;^GI`2jUVH0^YIV0;VEI@2hU6@0]i=S0P2fTV830;NCG`03
0;JBGP2eTEd0]I5M0080]91L00P0/HaH0;:=F@2cSUX0/hiJ0;:=F@2`ReL0[XUE0:b7D`80ZXIB00@0
ZhMC0:b8E02/R5@0[HUE102^RUH30:f9E@<0[8QD0P2^R5L00`2]QeH0[8IE0:^5E0020:Z4D`040:V3
DP2YQ4l0ZHA?0:V4C`<0Z8=>0P2WPTd20:F0B@80Y7m800<0Xgi70:9mAP2RODH00P2RODH0202MN4<0
Xgi90:N2C@2UP4/0X7]609eh@`2QO4L0YX5<202PNdL00`2ONTD0X7]60:9mB0030:=nB@80XGa700<0
XGe90:9nBP2TP4`00`2UPDd30:=oB`80Y81<00<0YH5=0:J2CP2WPdl00P2XQ5080:N3C`040:F0B`2U
P4`0YX5=0:J1C@80Yh5@0P2XPU401P2XODH0Ygi60:MnB02UODT0Xgi90:5mB@80Wgi;00H0WWU509eh
A02LMd<0VgI209Ye@@2IM40209Qc?`<0VgM5:oooool002[ooooo202SNTH00`2SN4D0Y7U60:EjA`02
0:IkB0030:AiAP2RMd@0XGI300P0YGY7402WO4T0202OMD<0X7I40:5gA@2RN4H0XgU70:AjB02UNdT0
YWa:202UO4H80:Z1C@80Z7m;0P2WOTX20:ImB@80YGa800@0Ygi:0:ImB@2VODT0YGa80P2TNdL02@2S
NTH0XWU50:9iA@2VODD0YGa40:AkA@2RNDD0XGQ40:1fA00209meA@80VgI200@0VWE109Qc?`2GLSh0
UG0l0P2DKc/209A^?`0609=]?P2BK3d0TF/l091Z>`2?JCX0SVPi0P2;IST0102:ICP0R6<f08MR=@25
H3<208AO<P80P5dc0P21GS@0101oG380OEX`07YG;@1iER`207IF;@80MED/00@0M5@[07=C:P1cDbX0
Le<Z0`1`Cb`3075@;@80LU4^0P1[BR/09P1/BbX0KTdZ06m?:@1aDBX0LU8[079B:@1aDbd0M5@^07AD
;@1gERd0NEH/07aG:`1nEb`0OeT/07eH:`1nFB`0P5/^08=N<@26HC@0RF@g08]V>@2<IcX0S6Dj08eV
>`2=IcX0SFLh08iX=`2>JCD0SfXf08mZ=@2=I3H0SVDg08mV>02@IcT0TFPj099Y>`2CJS`0U6/m202>
J3T808]U=P0608eX<`2=J3@0SFPd08eW=P2=IcP0SFLj0P2=IS/02028HcH0RVDh08aW>P2=J3/0SVTl
08eX>`2<IcX0RfHi202;IcL208aV=`<0SFLh0`2>J3T01@2BIcX0TFHi091U>02?I3L0T6Dh0080TFHi
00d0TfPk09EZ?@2@JD80TFY1099[@P2CK440Tfe0099/?@2AJcX0T6Xi099/?@2@JS/0SfTj0080SVPi
00<0SfTj091Z>`2BK3d01P2@JS/:08mY>P80TFPj00@0SfTj08iZ>P2>JSX0S6Xj0P2;JcX308aX>080
RfLg0`2:ISH00`2?JSd0SFPk08]V>@0308UT=`80RVDh00<0RVHf08]W=`2;IcL00P2;IcL02`2:ISH0
R6@d08QT=02:IS@0RFDc08IR<P25H3<0Q5lc08EP=P27HSP0R68k00P0QF8h00h0Qf0g08QQ>028HcT0
Qf@j08IU>P24ICT0Pf@h081S=`21Hc40P68`081Q<P1oH380OUlc07eM=080O5`e01P0OE`a07YI;P1f
ERd0LeH^079F;`1^E2l0IddX06599@1LA2P0F4<X0550901<?280ACTO040i7`0n>200?CTP03dg7`0m
=b40>c@Q03Tb7`0g<1h0=BhN03<[7P0b:Qd202TZ8P0602LX800V9al092DM028S6`0Q8QX0824I0`0P
8a`201lR6`<07R4J0P0L7Q/201dO70807R0M0P0O8Ah01P0M81T07R4J020S700Q91d08RDN024T7@80
82<L00@07b8K01TO6`0I7a/06AlK0`0H7QX201LM6@806A/H00@06Q`I01/M6P0K7AX071hK0P0M7a`0
4`0P9Q`082HJ028U6P0U9aX0:2XL02`]7@0b<Al0=3<Q03Td8@0f<Ah0<bhK03@_700g<Ql0>3<P03Lb
7`0f<Ah092DM028S6`0Q8QX00P0P8AT00`0R8a/092DM02DV7P0202DV7P0402@U7@0S91`08R<K024R
6P80824I0P0O8Q/201hQ6P807B0I100L7aP201dP6@807R4J0P0O8Q/00`0P81h07alM01hN700201dM
6`0K01hN700O7ad0820N02@Q600W9AT0;RXN03D_7`0j<b00?CDP03hg7@0o=A`0@30I04Pf7P1G@bP0
JU<c07aR?`2;KdL0UGI:09UhB`2aSE<0]95K0:J6E`22JD40GDX/048g9@0`;2409RDP00@08R@Q100S
9B8602DX8@8092LP00<09BHP02HW8@0X:B<00P0Y:R@01P0X:B<09RLQ02DV800V:B8092LP02<V7`80
8RDN00<08bHO02@W800V:B80200W:28202LW7`0402PX800Y:B40:RXR02/[8`80;2`T00L0;RXO02l[
800c;B40=blR03Xa8P0n<R80@3<S0080@3<R00P0B3PO04/k8P1>?RD0DT8Y05=3:P1B@RT0D40W04hn
9@80C40X00@0BclW04Xn9P1:?RH0BCdU0P18?2@0201??R`0BcXX04Lf9017=R@0BcXX04dl:P1<>bT0
BSTW0P1:=bT01P1;>2T0C3TX04dk9`1>?2H0CcdW04lm9@<0D40Y0`1A@BX20592:`0@05a39@1LABH0
GDDY05a7;01JARd0ET@/0592:`1@@2T0DT8Y05E5;01GAbh0EDD/04lo9P1:>R40BCTP04Xj8@80ACXV
00H0A3TW048f9P11=BL0?c<W03hb9P0n<BP303Ta9080>30S0`0g;b800`0i;2<0>RdT03`_9P0203d`
9`0403`_9P0j;B@0>B`S034[7`80<R`P00<0=2hR03D_8`0f<2@00P0g<BD00`0h;R80>BlS03T_8`02
03X`9080>c4U01T0?38V03H`900h<2<0>C4T03`c9010=2@0@cHU04Hg9017>2D0@cLW04@g9`13=RD0
ACHS04Lf8P1:>280CSTT050l901@?B`0CcdY04dk9`1<>R@0CC/S04ln901A@2@0DT4U0080FdH[00@0
FTH[05Q7:`1GARX0ETLZ0P1EAbX02@1@A2X0Cd<[04i2:P1=@B/0Bch[04Xm;019?2`0B3/[04/n:`02
04Xm:P0504Tl:@18>bP0AcXW04Lj9`16>BH00P19?b@00`1;?bD0CClU04lo9P02050n9P03054m9@1C
@RP0Dd8X00<0Dd8X101D@bT08P1MBR`0G4T[05a9:`1LBB/0GDX/05m<;P1QCS00He0b06UA;@1[Dbl0
KEDa06mG<`1`F3@0LETe07AL>01eGCT0OF@l07eU?`1lIT40NFE007ES?`1]Gc`0IePg06=F=01RDC<0
IE8b06QE=01/FSH0LEdh07ER>P1iIS`0NfPm07Y[@P1kK4<207a]A00J07]/@`1iJT40MVLn07AU?01^
F400K5Ll06aE=@1]ERd0LEXX07UP9`21J2P0QF`Z09]f<P2MN380Xgdf0:R2=`2^RC/0]8hm0;VC@02k
UD00^Xm:0;^@B`2lTD`0_I9=0;nDC`31UU420<:GDP0L0<RRD@39XU<0bjAE0<fXFP3A[5h0djmS0=Jb
IP3F]6X0cJm_0<j`LP3>/GD0bk5h0<R_N@32ZgT0_JMf0;ZTM@2iY7D0]j9c0;FPL@2aW6d0[IQY0:VD
I@2VTF80Y8mP0::BH@2PT5l0WHeL09^;FP@0VHUH0140T8]S0969HP2?Qf00SXEN08n3G@2APeh0Th=O
09B4H02CQf40U8QR09N9HP2JRf80WXaT09n>H`2QSV<0XXmT0:f?G@020:nAG@0;0:b>F02WRU80YXU?
0:R;C`2/Se<0Zhe70:Z<AP2YRdD0YhU10:F7?P2TQSd00P2RQCT03@2HOcd0VGdl09Ql?@2GNCd0UWHm
09Ic?@2EL3/0Tfhj099b>@2@L3L0SVhe08]Z=02:JC<00P2:JC@02P2;JSD0QFLc08EU<P25IC80QF@a
08EQ;`25Gbh0QEd/08EK:`26FR/208]S;`0608QS;P27I2h0R6D_08QW<@29JS<0RV/d1P28JC8208MX
<@0a08MV<`28Ic@0RVTd08e/=P2?KSP0TW8i09Ad>@2EMCX0Sg<b08mc=02>LS<0S6lc08Y]<`27JS80
Q6H`089T;P23I2d0PV<]081R;01mHRd0O68_07]T<P1mICD0OFLf07mP<P20HC<0PF8c08=U<`24IS80
QFLa08IX<P26JC40Q6``089Y<023JS40R6lg08M^>01oIC80M5XY06aB8@1^FRD0KETT06YF8`1XE280
Ie8S06MB9@1WDRL0J5<X06=B9P02069A9@03065@901PCb<0H4lS0080H4lS201ND2<805a=900605i<
901OCBD0GddU061>9P1QCbL0HU0X0P1SDBT205a>:`0`05];9`1JB280FTHQ065;901[EB`0M5dd091`
?@2RPU40^9UZ0<FXO039[HD0b:j90<^aSP3=]I<0cKRI0<jjV@3>]iD0aJf70;NNM@2ZSf80X8EF09j2
DP2CMdL0XXMH0;RMLP38[XT0d[VJ0=S0YP3LaZl0hL^f0>OB`@3Tck`0hL^d0=o7Z`3K`j40d[VA0<F]
O`2mXW<0ZI1H09EkB01oIcT0Le`c06UB<01MB2T0FD@W05]8:P1LABH0GdPY0P1WCbd01@1_EC80NUhg
089U>`29JSh0S6do0080T7=701@0Sg9608e`A02:KD40QfXn08AW>`22ICT0OFDi07aT>01jHSH0Melc
07EM<@1bFRh0L5P/06mG:`1XCRT0I4`X05m78`1I@R00DclN04ll7080BcXL00T0ACHQ048f8010<b00
?C8P03P_7P0d;Ad0<B/M030Z700[:QP00P0Z:1T00`0Y9aX0:2HJ02LT6`0202HS7008028R600S8aT0
92@J02DU6`0T91X08b<I024Q5`0P81H202<S6`<08R8J0`0Q8AT8020O6PP07ahJ200P81P8024Q6@06
01hN5P0O7aL0820H024Q6@0R8QX092@L0P0U9Ad802HR6@809b8L0P0X8ad402TT7P0302/T700/9Ad0
;RLO0080;bPP00<0;RLO02`U7@0[91`00`0`9QX2034W6`@0<RPL00H0<bTM03D[7`0f;200=R`P03D[
7`0c:Ad9038X70<0<bTM100d:Qh203D[7`0603@^7P0f;al0=RlO03L^7`0j;R00>bdP0P0n;R401P0l
:b40?B`R03d]800m;Ah0?RhN03h_7080?c0K0`13<A/01@14<Q`0AC<M04Hd7P17=Al0B3HP00P0C3PP
00<0Ed4Y05I0:01D?RH00P1C?BD01P1D?RH0ET0X05M1:@1I@280F3lQ05Ln8080ESdO00@0F3lQ05Y1
8`1K@R@0H44R0P1Q@R<206939080Hd@U00X0I4DV06A79@1TAbD0IDLU06Q79P1ZAbL0K4PX06e9:@1`
BBX0KdhU0P1`CbH01`1bDBP0Le8Y07AC:P1eE2/0MUD/07MF:`1hEb`00P1iF2d0101hEb`0MUDZ07AC
:01cDRL207EB:P0407AA:@1cD2P0LTlW079?9`80LDhV0P1bCbT00`1aCRP0LddX07==:00307=;9`80
M4hW00@0LddV079<9@1bC2D0LD/T0P1`BR<206m<9P@0L4dW0P1aCRP00`1hDR/0Me4Z07MA:P0207QB
:`0807UC;01jE2d0NU@]07]F:@1lEbX0OEP[07iI;01oFRd2081K;P0:085L;`27HC80Qf4b08QR<`29
Hc@0RV@e08aV=`2=IcP0SVPi091/?080TFdm00<0TVhn09=_?`2CKcl0102DL4001@2ELD40UW9209Qd
A02HM4@0VGE50080VWI60P2LN4@309ijAP0309ahA02JMT80VGE10080VGE50P2HM4@309Mc@`0609Ib
@P2CKT80Tfi209=^@@2CKcl0TVhl0P2BKSX00`2BKcT0TVhn099^?P06099^?P80UW4j00H0UW4l09Mb
?P2GLD00Ug5209Qb@`2HLTD309Ye@@D0VGA00`2LN4@209]g@`<0VWI200<0VgI209Ye@@2HLcl00P2G
LSh01@2HLcl0VWE109]f@P2JMD40VgI20080W7M300`0VgI209Ye@@2HLcl0UW4m09ahB02MNDT0Wg];
0:5mC@2ROTh0XGe=0:1lC02ONd/40:AnC`@0YGm@00<0Y81<0:=oB`2QODT00P2PO4P02`2QODT0Xgm;
0:B0C02PO4X0XGe;0:=oC@2UPDl0Y81>0:9nC02ONdT0WGU70080XWi>00H0XGe=0:1lC02QODd0XWi>
0:B0D02VPU820:N2CP<0YX5=0`2UP4`20:V1CP040:N2CP2VPTh0YX9>0:B3CP80XhA>0`2VPTh20:N3
C`<0Z8A@0P2[Qe<30:Z6DP<0ZHEA4@2XQ5020:Z5D@<0ZHA@0`2XPdl02@2YQ4l0ZXE@0:b7DP2]R5<0
[hYE0;6<E`2bSEP0/hiI0;>?F`030;B@G080]I5M0P2fTUh50;NBGP<0^9=O1P2fTUh20;FAG@<0]I5Q
0`2fTV820;NCH`80^9AT0P2iUFD20;ZFIP80^iMW202jUVH20;NEI@H0^9IV0P2jUVH30;VEI@<0^9AT
00@0^YIV0;VEI@2iUFD0^9AT0P2gTf<20;JBHP<0]Y9N102eTEd00`2dT5`0/HaH0;6<F0020;:=F@04
0;6<F02_RUH0[HQD0:b7D`80ZHEA00@0ZXIB0:^7D`2[Qe<0[8QD0P2]RED20:j:F0<0[HUG0`2/R5H2
0:f8E0030:b7D`2[QU80ZXEA0080ZHA@00<0Z8=?0:R3CP2XPdh00`2WPTd30:J1C0030:=nA`2RODH0
XWe60080XWe6102QO4D0202MN4<0XWe80:F0B`2SOTT0WGQ309]f@@2PNdH0YH1;202PNdL0102PN4@0
XGU50:=kA`2TO4P20:EmB@050:AlB02SNdL0X7a80:5mB@2SOd/00`2UPDd00`2TP4`0Xgm;0:9nBP02
0:=oB`030:B0C02UPDd0YX9>0080Yh=?202VPTh30:EoCP0;0:J0C`2VPDd0Yh9>0:N2CP2WPTd0Yga5
0:ImA@2VODL0Y7a80:9mB02PO4P00P2NODX209ag@`80VgI200@0VWE109Ud@02HLcl0V7<o0`2JMTH[
ooooo`00:_ooool80:=jA0030:9gA02SN4D0YGY70080YW]800<0YGY70:=hA@2RMd@0202UNTL80:Ml
B@P0Yga700@0XWQ60:=iA`2SNDL0XgU70`2TNTP00`2UNdT0YGa60:ElAP060:ElAPP0ZH1<0`2WOTX2
0:ImB@H0YGa8102TNdL20:=jAP060:MnAP2UO4@0XgY40:5hA02PMd<0WgE30P2OMDD0202LMd<0VgI2
09Ye@@2IM400Ug8n09Ia?@2EL3`0U6lk0P2EKd003`2DKSl0TV`m095[?02@JS/0SfTj08iX>@2<IcX0
RfHi08YU>029I3L0Qf8e08IQ=025H3<0Q5lb081M<`03085N=004081M<`1mFS00NeP^07UF;080N5P_
0P1gEbh0101fERd0MED/07AD:`1dE2/8075@;@80K4//01H0KD`[06m>:`1`D2X0LE4Z079B:`1cDbX0
LE<]07=C;@1dE2d0MUD/07QE:`1kERX0OEH[07eG:P1mF2/0OUT/081K;P23GS40QF0c08QS=P2:ICP0
RfHi0P2;I3T00`2;ICP0S6Hg08aV=@0208eX=00608eX<`2?I3L0T6Dh091U>02AIST0TVLj0P2CJ3/0
0`2DJC`0SVPi08iX>@0608iX>@P0SFLh00H0SFPc08eX=02=J3@0SFLf08eW>02=IcX208eV>`0308UT
=`2;IST0S6Lj00<0SVTl00<0SFPk08aW>P2;IcL01`2;IcL208aV=`<0SFLh0`2>J3T01@2BIcX0TFHi
091U>02?I3L0T6Dh0080TFHi00d0TfPk09EZ?@2?J440T6U0095Z@@2BJd00TV`o095[?02@JST0SfTh
099/?@2@JS/0SfTj0080SVPi00<0SfTj091Z>`2BK3d00P2AJc`3091Z>`/0SfTj0P2AJ3X0102?JCX0
SVXj08iZ>P2<JSX208][>P<0S6Ph0P2;IcL308YV=P0808eX>`2<IcX0RVDh08UT=`28HcH0RF@g08YU
>02;IST208aX>00308]W=`2:ISH0RVHf00<0RVHf00T0S6Pf08YV=027Hc<0QF0c08AO<`26HCL0R6<i
08YT?@23H3H00`24HCL308ER>00608IS>@28HCP0R64h08MR>026HcT0QF@i0P23I3P01`21I3P0PF<a
081R<020HC80Of0b07iO<`1mGC@00P1lG3D0601nGC80NUT^07IF;@1dEbl0LeL`06mE<01YCbX0Hd/W
05m7:`1LA2X0ED4V04ln9019>b40@cTP040h8@0o>B40?cLP03hf7`0m=B00>c<P03Ta7P0g;Qd0=RdN
03D/7@80:2TQ00L09bPP02DV7P0T9Ad08b@L028S6`0Q8QX08B@M00<082<L0P0O8Q/201hQ6P8071hK
0P0M7a`201hP7@807b4N00<071lH01hQ6P0O8Q/00`0Q91d2020S700301lR6`0J81`06R0L00806AlK
0`0H7QX0100G7AT06A/H01TK600J71T201/M6P0F01`N6`0M7a`07AlL020V700P9QX08RDJ02@V6@0W
:A/0:b`L030_7@0b<Al0>C@P03Lb7P0d;a/0<bhJ03D`700g<Qh0>C@P03Xe8@0U9Qh08b@L024R6P80
7b0H00<08B8J02@U7@0U9Qh00P0U9Qh0100T9Ad08b@L028S6`0R8a/2024R6P807b8K0P0N8AX201dP
6@@071lH0P0M81T201hQ6P807b8K00<0820N01lO7@0N7Q`00P0M7A/06`0N7Q`07alM020P7P0S81L0
9R@H02`X700d;Qh0>C8O03`d7`0n=ad0@3HM040a7P14<al0CC/S05m:;@1dG3X0Qf]6095dC02GN4`0
Y8E?0;2?FP2^SUd0U7E906iF=01??bP0=S0T02HU8004028T8@@08bDR100U:24202@W80808bHO00<0
9BHP02HW8@0W:2800P0X:B<01P0W:2809RLQ02DV800V:B8092LP02<V7`808RDN00<08bHO02@W800V
:B80200W:28202LW7`0402PX800Y:B40:RXR02/[8`80;2`T00L0;RXO030/8@0d;R80>30S03/b8`0n
<R80?c8R0080?c8Q01P0AcLN04Xj8@1>?RD0DT8Y05A4:`1C@bX0DT8Y05109`1>@RX0CD4Y04a0:01;
?bL0BCdU04Pl9017>b<0ASXR04hm:`19>2H0AC@R04He8`19>2H0C3/Y04/j:018=bD204Tf:00604Xg
:01;>2L0CC/W04hl9P1??BL0D3hV0`1@@2T30551:P80DT8[0100G4<U05e69`1OAb/0GDP]05]7;P1G
ABd0Dd</0510:@1A@BP0EDD/05M7;P1EAB`0CclV04/k8P1:>R40Bc/R0P15>RH01P14>BL0@SHV044e
9`0o<bL0?S8V03ha:080>38T0P0g<B<303H`8P0403D_8@0h:b80>RdT03d`9`80?S4X00<0?C0W03X]
900h:b800P0d;R8303D_8`<0=S0T0P0g;B40100h;R80>BlS03X`900j<2@203/a9@0H03D_8`0g;b80
>C4T03/b8`0o<b<0@SDT04Df8`16=b@0@cLW04<f9P13=RD0ACHS04Pg8`1;>B<0CcXU054m9@1>>b`0
CCXY04/h9`1:>2@0BcTS04hl901A@2H0E4<Y0P1KART0101JAbT0FDPZ05U8:P1HBBX205Q;:`060596
;01AABd0D4@/04i2;01<?b`0Bch]0P19?2`01019?2T0B3/X04Pk:018>bP404Lj9`0804Ho8`17@2@0
BT0U04a09P1>@2H0CShU04dm901=>b<405=2:080E4<Y0P1EA2X00`1FAB/0GDX/05a9:`0205a9:`06
05e:;01PCBl0HTla06AA<`1[Dbl0KEDa0P1`F3@206iF<P0E071H=01cFcL0PFDn085U?P1oId40NVI1
07EV?`1`HSd0J5hj06EM>01SDcT0I5@j06MF>01[F3L0L5`g07IP>@1jHcT0O6Di07i]?`20Kd40PW53
0080Q7=503L0Pg94081_@@1nKCl0Lf=107=Q?@1`GSP0KU/a075L;`1dGRl0NF4a07aU<`2?Ic<0TFXc
09M_=02OMSH0Z7dh0:n3>02dRCX0^8/j0;F9@P2fRT<0^8a50;Z>A`2mTDX0_i=<0<6ECP32UTl0aI]?
0<JLD037WE40bImC0<fQEP3@Y5T0e:QM0=JZG`3E/6T0eK1Z0=BaK@3C/G40dk5d0=2`M`3>[gP0cJih
0<J]M@35[7@0`ZUa0;nVKP2lXf/0^J1X0;NNIP2eW6@0]9mV0;>NI@2aW6<0[iYQ0080[YUP0P2_VV40
5@2/W6T0Zi]X0:ZHIP2ZUV@0ZYAS0:^CH`2/U6@0[iAU0:^IJ@2^VFX0[i]Y0;6KJ@2cW6P0]IaV0;FJ
H`2dVF80]iML0;RHG@2hV5/0/iAD0:f>C@020:V:A`0J0:^=A`2[RTL0ZXU60:R7A02VQD80Y8=00::1
?P2QP3d0X7ll09Im>P2HOCX0V7`k09Qj?02GMc`0UW<k09E`>@2CKST0TG4d08m_=02<K3<0RFT`08MV
<@26IC00QVDb08IT=01oHc42081R<00<081N;P21GBd0Q5/]08MK;P2:FBh0ReX_08aT<02=IC40S6Lb
08aY<`2=JS@0S6/e0P2;K3D408Q[<`0Q08MZ<P25J300Q6L_089U;@26IC80QfHc08UX<`2;JS@0SF`f
091`=`2ALCH0TW8g08ed<P2<Lc<0RW4a08Q^<@25Jc00PVP_081U;P1nHb`0Q6D^08=T;P21Hbd0OV<^
07aR;`1kI380OFDe07eW=P1nGc40P64c089S=024IS@0QFLc0080QVPb00l0QVTa08I]=020Ibl0OfH^
08A[=@23JCH0NEl^06mD9@1/DB80JeLR06YF8@1XE240IU8P06E@8@1UD2<00P1VDBH00`1SDRH0HU4U
061?8`0305m>8P80H4lS201ND2<805Y<9@80GD/U00<0GT`V05m=9`1PCRP00P1QCbT0;P1RD2X0F4XW
05U;:01IBBD0FDLQ05Y68@1SCBH0KUP_07QQ>02EMD80YXIE0;^LK@36ZGd0bJf50<N]R03:/8d0cKFC
0<jjV@3>^YL0c;JA0<:[PP2cVfl0YX]L09j4D`2LP4h0VGe>0:R=H02oXg/0cK>@0=BkW@3I`JT0g/Rc
0>C=^`3XdL<0hlbl0>37/@3K`Z@0eK^F0<^`Q@2mXg80/iQS09f7CP29LT00M5dc06UB<P1PBc0205M3
:00305U8:P1MARL0H4TZ0080J50^01d0L5Hc07YN=`21I3X0R6Tm08Y[?@2>LDD0SG1408]^@P28Jcl0
QFPl089U>@1oHSH0OV4e07QQ=`1gH3H0MEhd07=L<P1`FBl0KUL]06aE:`1[E2X0Hd/W05m89P1KA280
E40O04hk6`19>1X0AcPK04Hg6P0203ha7P0603`a7`0i<1l0=BhN034[7@0]:Q/0:bLK0P0W:1P0100V
9aT09BDI02@T6P0T91`202<R7@09024Q5`0R8QP08b<I02@T6P0S8aT08R8H020P5P0O7aD08b<K00<0
8R8J0P0Q8AT2020P60P07ahI0P0M71X301hM6`<07ahL200O7aL8020P60807alG00<0820H024Q6@0R
8QX00`0S8a/802HR6@809R4K0P0W8Q`302PS7@0402TT7P0[91h0;2DO02dV8080;RLQ00@0;BHP02`U
7`0[91h0;R@J0`0_9A/2030V7080<BLM00<0<BLK038X700d:Qh00P0e:al00`0d:Qh0<RPL034W6`08
038X7P<0<RPL0`0c:Ad303@Z7P0603<]7`0e;B00=BdP03H/800i;B40>R`Q0P0m;2801P0i:b80>B/P
03T[800j;1l0>RdM03/^7@80>bhK1012<Q/01@13<a`0A3@M04Hf7`17=b00AcDO0080B3HP0P19=b43
04Xh8P0305E1:@1D@2P0DShV0080DCdU00`0DShV05A0:01E@BT0EcdR05Hl8@1E>b00E3XO05Dk801F
?240F3hS05To901P@B8206528`050693901SA2D0I4DV06A59P1UARL00P1TAbD01P1TAR@0IdHU06U6
9P1[AbL0KDTY0719:P80KThU00@0KdlV071@9`1aDBP0LU8Y0`1cDbX01`1dE2/0MED/07IF;@1fERd0
M5@[079B:@1aDBP00`1bCbT2075>:0<0L4dW00P0KdlX071>:01aCRP0L4dW07=;9`1bBRH0M4TV07E9
9P80M4hW00@0LddV079<9@1bC2D0LD/T0P1`BR<8071=9`80MU0Y0`1eCbP01`1gDBX0N58[07UC;01i
E2L0NUDX07aG:P1nFB`01020Fbh308EQ<@0608IR<P27Hc<0RFDe08]W=`2=JCT0T6`l0P2AKCd2099^
?P<0Tflo0P2DL400102ELD40UW9209Mc@`2GLd<209QdA00309UeA@2IMD40VWI200<0VgM300@0VGE1
09Mc?`2FLSh0Ug=30`2FLT8209Ea@@80U7100P2@Jcl00`2@Jch0T6`l091/>P02091/>003091]=`2@
K3`0T6`l00H0T6`l0P2EL3T00`2EL3/0UW4m09I`?`0209Ma@P0309MaA02IM400VGA00080VGA00P2H
Lcl209Mb?P<0VGE10P2HM40309Mc?`0309Ud@02HLcl0Ug8n0080UW4m00H0Ug8n09Qc?`2IM400UW4m
09Mb?P2IM40209Ye@@0609Ud@02HLcl0Ug8n09YfAP2KMdL0WWY:0`2PO4`209mkB`P0XWa=00<0XWi:
0:5mB@2PO4P00P2ONdL01@2PO4P0XGe90:9nBP2ONdL0X7a80080XGe900H0X7a809mkA`2NNTH0WGU5
0:5mC@2PO4`209mkB`040:1lC02ROTh0Y81@0:F1D@<0YX5=0P2UP4`30:AoB`80Z81=00@0YX5=0:F1
C@2UPDd0Xh9=0P2RPdd0102TP4`0YH5=0:F1C@2UPDd20:J2CP80Yh=?0`2ZQU820:V5D@<0Z8A@4@2W
Pdl20:R3C`80Yh9>0`2VPDd01`2UP4`0ZHA?0:V4C`2[QU40[8MB0:j9E02`ReH00P2bSEP30;2<F080
/HeI0`2bSUX30;JAG@<0]i9N0P2hTel30;FBG080]95K0`2cT5X30;>?G`80]91P102eTF420;JBHP03
0;NCH`2hU6@0^IEU0080^YIV202hU6@0102eTf<0]YAT0;JDI02fU6@30;NEI@040;RFIP2iU6L0^IAW
0;VDI`80^9=V0`2gTVD80;NCH`P0]I5M00P0/8]G0;6<F02bSET0/XeI0;6<F02_RUH0[HQD0:^6DP80
ZHEA0`2ZQU830:^7D`80[XYJ0`2]RET30:b8F080[8MB00<0ZhIA0:Z5D02YQ4l00P2XPdh20:N2C@<0
YX5<0P2UP4/20:AoBP<0XGa51P2PNd@0102ONTD0X7]60:5lA`2ONTD209eh@`0309mjA@2RODP0WgY6
00L0WgY600@0WgI20:5hA02SNTH0YGa80P2VODT01P2UO4P0Y7]709eiA@2ONdL0XGe90:=oB`80Y81<
00<0Xgm;0:9nBP2QODT00P2ROTX00`2SOd/0Y81<0:F1C@020:J2CPP0YH5=00H0Y7iA0:EoDP2UOe00
YGm>0:J1C@2VPD`20:N2B`060:IkA02UO4@0YGa60:=kA`2QO4L0Wg]70P2MO4T309ag@`80VgI20P2J
MD40102IM400V7I809QfB02HMTP[ooooo`00:_ooool80:=j@P040:1e@P2QMT<0Y7U60:EjA`80YW]8
00<0YGY70:AiAP2UNTL01`2UNTL80:MlB@P0Yga50`2VO4X20:EkB@<0Y7Y8202TNdD:0:MnBP80YWe9
102UO4P20:=jAP@0Y7]70`2UO4P03P2WOTH0YWe50:=jA02QN4@0WgI209me@`2OMDD0X7I609ag@`2K
MT80VWE109Ud@02HLcl0UW4m0P2EL3`03P2FL440UFm009A^?`2CKCh0TF/l091Z>`2?JCX0SVPi08aW
>P2;IST0RVDh08UT=`28HcH0QV4d0P25H3<2085N=006089O=@21GS@0P5dc07eJ<01kF2h0NEH/0P1k
Fc801`1jFS40NET`07QH;`1gEbh0MUH]07EE;01dDc000P1cDRl07@1bDBh0LE0]071?;01`Cb`0Kdh[
06a;;01]C2d0KTd/06m>:`1aDB/0LU8[07=C;01dE2/0LE<]07=C;@1dE2d0ME@[07MD:P1jEBT0Ne@Y
07aF:@1nFB`0OeX]085L;`23GS40QF0c08MR=@28HcH0RF@g0080RF8g00<0RV@g08YT=@2:I3<00P2;
IS800`2;IS40TFHi095V>@02095V>@@0TVLj402>J3T01P2=J3<0SFPd08eX=02=IcH0SFLh08eW>P80
SFHk00<0RVDh08]V>@2=J3/00P2?JSd00`2>JC`0SFPk08aW>P0808]W=`80S6Hg0`2=IcP308iX>@05
099W>P2AIST0T6Dh08mT=`2@ICP00P2AIST03@2CJ3/0UFXm08eV?`2>Ich0T6U0095Z?`2AJch0T6Xk
08iX=`2=IcH0TV`m091Z>`2?JCX00P2>J3T00`2?JCX0T6Xk099/?@03095[?003091Z>`2?JCX0SfTj
0080SVPi202?JCX2095X>P0408mY>P2>JSX0SVXj08aZ>P80Rf/j0`2<J3P208]W=`<0RVHf00<0RfHi
08YU>029I3L00P28HcH01P2:ICP0S6Lj08eX>`2?Jc/0SFTi08YV=P80R6@d00/0RFDe08]W=`2=JCT0
SVXh08aX=P28I3@0QV4d08EP=027HSP0RVDk08aV?`0308=P=P0308AQ=`25HSP0QF8h0080QV<i0P28
HCP00`27HSP0QF8h08AS>00208=T>007085T>021Hc40P68`081Q<P1oH380OUlc07eM=00207aL=@0H
07iM<P1kFRl0MeL^07AG;`1dF340L5Ha06Y@:`1TC2P0HdT^05m7;@1IA2T0DD0V04/m8`16>R80@SXS
040j8P10>Al0?cPN03hf7`0l=1l0>S8O03T`7`0g;Qd0=bhO0`0V9al01@0U9Qh092DM02@U7@0T9Ad0
8b@L00808B@M0`0P8a`301lR6`8071hK0P0M7a`201hP7@807b4N00<071lH01dP6@0O8Q/00P0Q91d0
100P8a`07b8K01lR6`0N8AX301XP70806AlK0`0H7QX201TK600401XL6@0K7AX06adJ01`N6`807AlL
00/082HL01lU6@0R9AX092HI02HX6P0Z:a/0;bhL034`7P0i=1h0=c8L03D`6P0203<^600:03Ha6`0j
=Al0?CPR02HW7`0T9Ad08B8J01lP600N7aL0824I02<T70809RLO0P0U9Qh00`0T9Ad08b@L028S6`02
024R6P807b8K0P0N8AX201dP6@@071lH0P0M81T201hQ6P807b8K00<0820N01lO7@0N7Q`00P0M7A/0
6`0N7Q`07alM020P7P0S81L09B<G02/W6`0b;1`0>34N03`d7`0n=ad0@3HM040c8P11<Ql0ASHO05I2
:@1/ECH0PFM4091dC@2FNE40V7a:0:b<F@2dTf00XGmA07aP>`1IAB`0?38V02XW800402<U8P@08R@Q
00<09RTR02DX8@0U:2400P0T9b0202<V7`04028U7P0T9Al09BHP02LX8P80:2TS00H09bPR02DV800T
9Al09RTR02@W800S9Ql2028U7P0302<V7`0T9b009RTR00P09bPR0P0W9al0100X:200:BTQ02XZ8P0[
:b<202`/900702l[800a;B80=BlS03Ta900l<b@0?S8R03lb8P0203lb8@0404Lg7P1:>R40CclV05=3
:P80EDD/00`0E4@[05=3:P1@A2`0Cd<[04i2:P1;?bL0BCdU04Hj8P15>B40A3PP04`k:@18=bD204@c
8@0404Lf901:>BL0BCPV04Lf9080B3DW00H0BCHW04/h9`1=>bL0CS`V04lm9`1@?RH30510:@<0DD4Z
0P1B@R/0401L@bD0GDHW05m7:`1OBRl0GDT`05Q6;P1C@b`0D40Y05109`1DA2/0EdL^05E5;01@@2L0
C3`S04/k8P1=?B@204Dj9P0604@i9`12=RH0@CDW03lc9`0n<RH0?S4X0`0e<R<303@a8P80<c0Q00<0
>2/R03X]900m<2L00P0o<RT00`0m<2L0>RdT03P[8P0303Pb9P0503La9@0f<2@0=S0T03H`900e;b<0
0P0f;200100g;B40>2hR03T_8`0j<2@203/a9@0H03D_8`0g;b80>30S03/b8`0o<b<0@SDT04Df8`16
=b@0@cLW04<f9P13=RD0ACHS04Pg8`1<>R@0D3/V058n9P1<>BX0BcPY04Tf9@19=b<0BSPR04hl9P1C
@BT0ED<[0P1KARL0101KB2P0FDTX05Y::@1JBbX205Y=:`0905A8;P1CAbl0DDD]04m3;@1=@2d0Bch]
04Xm;@19?2`0BC`Y00<0BSdZ101;?R/02015@2<0Ad0T04Q19@1;@BH0C40V04do9@1<?2<0Bc/R0`1B
@BL01`1C@RP0ED@Z05I5:`1GAR`0F4L]05U8;P1MBR`00`1LBB/0?01NBbd0H4d_06=@<P1UDS@0Idl[
06]C;`1_Ec<0L5Pd06eE<@1^ES80LUXf07IN>P25ICh0PfHn07mV?P1kICh0M6Dn071T?P1[Hc`0J6<m
06YKA01ZG480Je]106mL?01bGS/0N60j07aS>P1nISX0P6hl089`?P26M480RGM508]iA`29MdD0QgE3
08Ec@@1oLd<0O71007Y/?`1hIc`0Mf@l07QR?@1iHT00Nf=108IO>02:H3P0Sf@g09I[=P2NL3@0YWHd
0:]k<`2^OC40[H4j0:j2>`2`Q3d0]8Q10;N;A02jSTL0_I5:0;jBB`80`IAA01T0`iA@0<BED@37UU40
bYUD0<jLE@3@WUL0ejaN0=F[G`3EZf40dj]U0=B]JP3D[Vl0e;1b0=FaM@3<[g<0bjib0<Z]L@37ZVh0
aJQ/0<>VJP31Y6P0`:=W0;bTIP2kXfD0^Z9T0080^J5S01/0^Z9T0;^SI@2lY6H0^j9R0;bPH@2iWEh0
^9YL0;RHF`2jV5/0_9QL0;fIG@2jWF<0^iiT0;fOH`2nWV40_ieN0;nLG02lVEL0_IMF0;JDE02hUUH0
^IQE0;FDC`2^SDH0ZXY10:Z:?`2/S4400P2ZQTP01`2XQ4H0YX960:B0AP2ROT@0XGe30:1kA02DO3H0
0P2GO3T03P2GNCT0UgLj09Ic>@2DKcP0TVdf091a<@2=KC00RVX_08IV;@23HRd0PV4^085O;`21Gc40
NEd[0P1kGB/03P1lFRX0OeTZ08AI;02:FBh0Se`a095L<P2=IC40SfLc095/=`2BKcT0Tg0j091_>@2>
KcP0S6df0P29K3@08`2:KCD0RF`d08MZ<P24Ibl0PF@/07mR:P24Hc00QF@a08MV<@29J380RfXd08e]
=02?Kc@0T70e08]d<@2:LS80R70`08E];`22JRh0OfH]07eT;01lHb/0Pf@]085R;01nH2X0Nf0[07UO
;01gH2h0N60`07QR<@1nGc40Of0b089S=024IS@0QVPd0080QVPb01T0QFP`08Qb>@1mIbh0NF8/07iW
<`1mIS@0LUXZ06YB8P1[DbD0J5@O06MC7P1UDAh0HdlM069=7P1SCR40HdhS06A?901SDRH0HE0T05m>
8P1NCB40GD`P05i=8@1OCR80H4lS00P0GDlR201HC2H205a:9P0305e;9`1NC2P0GddY0080H4hZ03<0
HDl[05E7901FB2D0EdLS05Q6801KAb80IDlX075K<P1kI3/0VGU60:V9F02mWVl0ajYn0<V]Q@36[8L0
bJn<0<bdTP3?^iP0c[ZG0<ZdS@2oZ7l0/9Q/0:B9FP2LPTl0VWi<09n2EP2_U6T0a:R10=2fU@3E^j00
fL6Y0=o9]03Vckd0ilo30>C:^`3Ma:h0ekjP0<nfSP34ZGX0]Y]V0:^@F@2BOT<0OVPf06UC;01OAbd0
Ed4Z054m9@1A@2H0EdHX05i7:01RBb`00P1YDBl07@1aEc@0NUhg085T>P26Ic/0QfPj08e`A02;KT80
R6/o08EX?021I3P0OV4e07]N<P1jGC40L5Xa06mI<01]Ebh0JeD/06UC:P1WDBP0IDlV06A>9@1PBBL0
GDHT05M38P1A?Qh0BSTK04Lh6`15=QT0@cDJ0080>RlM00H0>2lN03H_7`0c;Al0;R/L02/W6`0X9QT2
02HW6@0602DU6@0T91X08b<K02<R7@0R8A`08B0L0P0Q8AL302<S6@03024Q5`0O7aD07QhD00<08R8J
0P0Q8AT3020P60P07ahI0P0L6aT201dL6P807QdK0P0O7Q`801lO5`P0820H200Q8AT802DQ600402DP
6P0V8A/09R4K02HQ6`809b8L0P0X8ad00`0Z8Ql0:b<P02dU8P0202hV8`0402dU8P0[8b00:R8O02`S
6P<0;B@K0P0^9A`202lV7@03030V6P0a9a/0<bTM0080=2XN00<0<bTM034W6`0`9QX0200b:B03034W
6`<0<RPL0`0c:Ad01P0c;Al0=2`O03@/7`0f;200>2`P03X/8@80?2/Q0P0h:R40100h:Ql0>B/P03T[
7P0j;Ad203X]7008048c7011<Q/0@34J040a6P11<Q/0@c@M04Df7`17>24204@c7`0904Dd8017=R80
B3LS04Th901:>BD0BcXV050k9P1?>RD0CCPS0080C3LR00<0CCPS04lj9@1@>bH00P1E>b8305<i8009
05Dk8P1G?B@0F3hU05`m7P1M?Ql0GSlP05m08@1P@B80HD8S0080HT<T0P1TAbD01P1TAR@0ITDT06Q5
9@1[AbL0KDTY0719:P80KThU0P1_CbH0301`D2L0LE4X075A:01bDRT0L50Y075A:P1cDb`0M5@]07EE
;P1dE2d0Le</079B:`@0L4`X101_BbL0201/CbL0KThW06m=9`1_C2H0LTXV07=89@1dB2D0MDLU0P1d
CRL0101cCBH0LT`U079<9@1aBb@2071:8`P0L4dW00h0MDlX07A>9`1cCBH0LT`U07==9P1dCRL0MU0Y
07MA:P1gDRD0NE@W07aG:P1oFRd0P5/^085L;`80P5/^00P0Pf4a089P<022H300PV0`08=Q<@26I3@0
RFLg08YX>0@0TFdm102BKSh0102CKcl0U71009A`@02ELD4209Ib@P<0Ug=300<0UW8n09Mc?`2HM400
0P2HM4000`2FLSh0UG4m09=_>`0209Ea@@80U7100`2CKcl01P2BKSh0SVTm08iY?@2>JC`0Sf/k08m[
>@80Sf/g00<0Sf`f08m[>`2?Jc/01P2?Jc/209A_>00309A_>P2EL3`0UFln0080UW1100D0UW1309Ud
@02IM400VGA009Qc?`0209Mb?P80UW4m0`2FLSh209Ea?@<0U70l00<0V7<o09Mb?P2FLCd00P2EL3`0
1`2FLCd0Ug8n09Qc?`2CKSX0U6lk09Ia?@2HLcl00P2IM40209Qc?`0409QdA02JMTH0W7Q809ijBP80
X7a<00<0Wg];09ijBP2ONDX01P2ONDX0102NN4T0XGe90:1lB02ONdL209ijAP0709mkA`2PO4P0XGe9
0:1lB02ONdL0WWY609eiA@0209ahA00409eiA@2NNTH0X7a<09mkB`80WWY:00@0Wg];0:9nCP2TP500
YH5A0`2UP4`20:AoB`<0Xgi:0P2WOd`0102UP4`0Y81<0:B0C02RPD`20:62C0040:=oB`2TP4`0Y81<
0:B0C080YH5=0P2VPTh30:V5D@80Z8A@0`2WPdlA0:J2CP<0YX5=0P2UP4`30:AoB`080:AoBP2UP4/0
YX5<0:R3CP2ZQE00[8MB0:f8D`2^RE@20:b8E080[HUE0`2^RUH0102_ReL0/HaH0;:=F@2bSET20;>>
FP80]8mK00D0]I1L0;BAF@2dTET0]95I0;>@F0020;:?E`80/HiF00@0/HeM0;:>GP2bSUh0/XiN0P2c
Sel40;B@H0040;FAH@2fTV80]i=S0;RDI080^IEU202fTV830;BBHP030;FCH`2fU6@0]YAT0080]iEU
0`2hTfL20;NBIP<0]Y5U00P0]91P0;FAH@2fTV80]Y9R0;NCH`2hU6@0^IEU0;ZFIP@0]91L102eTEd0
0`2`ReL0/HaH0;6<F0020;6<F0030:n:EP2/Qe<0ZhIB00@0ZXIB0`2YQE400`2XQ500[XYJ0:j:FP03
0:f9F@<0[8QH00H0[8M@0:^6C`2[QTl0ZXE>0:V4C@2XPd`20:N2B`040:J1C02UP4/0YH1;0:F0B`80
Y7m:0P2SOTT509mj@`@0X7]400D0XWe809mjA@2KMT40VgI109eh@`0209mjA@0309iiA02ONTH0WgY6
00H0WgY600@0WgI20:1g@`2RNDD0Y7]70P2VODT01P2UO4P0Y7]709]g@`2MNDD0Wg]70:5mB@80XWi:
102QODT00`2ROTX0Xgm;0:B0C0020:F1C@030:J2CP2TP4`0Y81<00H0Y81<0P2TOE80102UOe80YGm>
0:F0C02VPDX20:J2B0060:IkA02TNd<0Y7]50:=kA`2PNdH0Wg]70P2LNdP209ehA0@0W7M30P2KMT83
09MfBB_ooooo000Zooooo`P0XgY200H0WgA10:1e@P2SN4D0YGY70:IkB02WO4T20:IkB0P0YGY7202W
O4T80:MlA@80ZGm=00@0Z7i<0:MmB`2UNdT0Y7Y80P2SNDL80:AkA@P0YWe90P2WOTX20:ImB@<0YGa8
00D0Y7]70:9iA@2RNDD0XgY60:AkA`020:ElB080YWe900L0Ygi:0:QoA`2VODD0XgY40:1g@`2OMT80
WgE30080X7I60P2LMd<0102KMT80VGA009Qc?`2FLCd209E`?00809Ma@P2FL440UFm009=]?P2AJc`0
T6Xk08mY>P2>J3T208aW>P0408]V>@29I3L0R6<f08IQ=080QF0c0P21GS@03022GcD0PEhd081M<`1n
Fc40NeP^07YG;@1mGC@0O5`c07]K<P1jFS40NET`07QH;`80MeL^0P1eE3401P1dDc00LU4^075@;@1`
Cb`0Kdh[06i=:P80KD`]01H0KTd/071?;01aDB/0Le</07AD;@1dE2/0LE<]07=C;@1cDb`0ME@[07MD
:P1iE2P0Ne@Y07]E:01oFRd0P5/^085L;`23GS40Q5lb08IQ=027HSD0R6<f0P28HCH00`28HSD0RF<d
08US<P0208YU<@0308YU<02DJ3/0TfLj0080TfLj0`2BIST00`2AICP0SVPi08iX>@0608iX>@P0SfTj
00H0SFPc08eX=02=J3@0SFLf08eW>02=IcX208eV>`0308YU>02<IcX0SFPk00<0SfXm00<0SVTl08eX
>`2;IcL01`2;IcL208aV=`<0SFLh0`2>J3T01@2BIcX0TFHi091U>02?I3L0T6Dh0080TFHi00d0TfPk
09EZ?@2<ICh0SFHm08mX?`2@JCh0T6Xm08mY>P2=IcH0S6He099/?@2@JS/0SfTj0080SVPi00@0SfTj
091Z>`2BK3d0TV`m0P2AJc`00`2@JS/0SfTj08mY>P0208iX>@P0SfTj0P2AJ3X0102?JCX0SVXj08iZ
>P2<JSX208][>P<0S6Ph0P2;IcL308YV=P80RF@g0`28HcH01P2:ICP0S6Lj08iY?02AKCd0SVXj08YV
=P80QV8b00/0R6@d08aX>02?Jc/0T6`j08eY=`29ICD0QV4d08IQ=@28HcT0RfHl08eW@002089O=@04
08=P=P24HCL0Q64g08ER>080QV<i00D0RF8i08QQ>027HSP0QF8h08AS>00208=T>007089U>@21Hc40
P68`081Q<P1oH380OUlc07eM=00207aL=@0H07iM<P1kFRl0MeL^07EH<01eFC80LELb06]A;01TC2P0
IDX_0698;`1JABX0E40W04dm9018?2@0ACXT04<k9012>1l0@CLN040e7`0n<ad0?C8N03/`7P0j;Qh0
>BdM200U9Qh3024T7@8082<L0`0O8Q/201`N6`807AlL0P0N81d201lQ7P0601`O600M81T07b8K020S
700Q91d082<L0P0O8Q/0100N8AX06R0L01XP700J81`301TO6`8061hJ0P0I6aP0100J71T06adJ01/M
6P0L7Q/201dO700;01lU6`0O9AT08B@I02<U600U9aT0:BXJ02h]6`0`;ad0>C@N03Pc7@0e<1X00P0c
;QP01P0e<1X0>cHP03hi8`0W:2009BHN024R6P807QlG00<0824I02<T700V9al00P0V9al0100U9Qh0
92DM02<T700R8a/2024R6P807b8K0P0N8AX201dP6@@071lH0P0M81T201hQ6P807b8K00<0820N01lO
7@0N7Q`00P0M7A/06`0N7Q`07alM020P7P0R7aH09B<G02XV6P0a:a/0=c0M03/c7P0n=ad0@CLN044d
9010<200@S4M054m901XDC80OVI4091dC`2GNE<0TGM60:V;F@2gUV<0ZHEE08IV?`1OBRl0?SDV02XW
800402<U8P@08R@Q00@09RTR02DX8@0U:24092LP0P0S9Ql2028U7P0302@U7`0U9R009bPR0080:2TS
00H09bPR02DV800T9Al09RTR02@W800S9Ql2028U7P0302<V7`0T9b009RTR00P09bPR0P0W9al0100X
:200:BTQ02XZ8P0[:b<202`/900702l[800a;B80=S0T03Xb9@0m=2D0?c<S03lb8P0203lb8@0404Lg
7P1;>b80CclV05A4:`80ETH]01X0EDD/05A4:`1BARh0DDD]04i2:P1<@2P0B3`T04Hj8P13=al0@SHN
04/j:016=B<0@S4O04<b8016=B<0BCPV04Pg9@15=280Ac@V04Pe9`19=RL0BcPW04`j9P1>?2H0CcdW
050n9P<0D40Y0`1A@BX20592:`0@05a39@1MARL0H4P/05m:;`1MBC00F4H^05=3;01@@2T0D40W05=3
:P1FARd0EDD/05109`1<?2<0CCdT04hn9@80ACXV00H0A3TW048f9P11=BL0?c<W03hb9P0n<BP303Db
8`80=34R0`0c<2400`0g:R40>RdT03d`9`0203lb:@0903d`9`0j;B@0=bXQ03/e:@0j=2P0>C<W03Pb
9P0g<BD0=S0T0080=BlS0P0e:al0100f;200=bdQ03T_8`0j<2@203/a9@0H03D_8`0g;b80>30S03/b
8`0o<b<0@SDT04Df8`16=b@0@cLW04<f9P13=RD0ASLT04Pg8`1<>R@0DC`W058n9P1;>2X0BCHW04Pe
9P18=B@0BSPT04hl9P1C@BT0EdD]0P1KARL0101KB2P0FTXY05];:P1KC2/205]>;00805A8;P1DB300
DTH^0514;P1>@Bh0C3l^04Xm;@19?2`204`o;080CD0]00`0CT4^04m2;`1@@c00D4<`04@o8P16@B@0
B44U04]19P1<@2H0CClU04/m8`1:>R4205509P0705919`1C@RP0ED@Z05M6;01IB2h0FTT_05]:<004
05a9:`0P05i;;@1QCS00He0b06EB=01SBbL0J50/06iF<P1_Ec<0KUHb06mG<`1dG3P0NV8n08IV?`23
ISh0OVDm07YT>`1dIC`0KfHm06]V?P1ZIch0KV9<071QBP1`H4H0LF1207EQ?P1kI3/0OVDl089W>P1o
KSX0PW4m08Mf@P2;NTH208elB00d08]jAP29N4@0Qgi508IkA@22MT@0Og1507i/B01lIdP0O6A<07aS
C@24Fcl0QUdm08aP>`2AICP0V6Tc09m]<02SL2h0YW4[0:Qi<@2YNS80[7de0;21>@2dQCd0^8U10;^<
A02lSDD0`I5C0<2@DP2oSdl0_he>0<:?CP36TDl0bIA@0<^DD@3CY5@0dJAC0=2RE@3>XUT0cjAO0=2X
H`3C[6/0eZm^0<j`L03=[fl0c:i^0<Z/K038ZVX0ajUY0<JXJ035YfL0_JAR0;bSH@80^j9P03D0_:=Q
0;fTHP2oYV@0`JQV0<6PF@30WUL0_YaE0;jID`2nUe80_iMB0<6FDP32Ue<0_iaL0;nLFP32WET0`iaI
0<:JE@2oUe40_YA<0;bBBP2bSd/0]I9>0;JDC@2cTDT0[Xa20:Z9?02[RSd0[H`m0:^7C@2ZQT`0ZHA=
0:N2B`2UP4/0Xgi:0:9lB`2QNdX0Tg/e09Ej=@2FNcP0UgTi09If>@2ELSP0Tfle095/=@2>Kbh0S6d]
08QX:`24I2/0PF0[07mM;@1nG2h0OU`_07EK:P0207MH:@0>07QH:@1mEbX0Q5L]08]J<@2AG3@0UEhg
08iV<P2AJCD0U6lj09Md?P2HMCl0U7<m08m`>@2=KSL308Q^=@0h08M]=025Jc80PFL^07eS:P1kHBP0
Pf8_08AS<025I2l0QfH`08YY<`2<K3<0SFdb08i^<`2;M340RW8b08M_;`24K2h0PFT]07iU;01lHb/0
Nf8Z081Q:P1oH2X0NedW07ML9`1eFbP0Le`Z07AL;01cGB`0OEh`07mP<P22Hc@0QFLe08IX=026J380
QFLa08EX<029M3/0O6L`07IQ:P1kIS40NF<a06iH9`1XDR<0JeDV06IB7@1UDA`0HdlL065=6`1QC1d0
HD`O069=8P1SCR<0He8V065@901OCR8305e<800305m>8P1PCb<0GDlR00L0GDlR201GBbD01P1KBBD0
G4XV05a:9P1MBbL0GT`X05m=:@80H4hZ0380DT@Q05A68`1FAR80F4HP05]78P1VD2T0Ledd07eV?@2K
NdP0Zh]J0;jOL038Zgl0bJf50<J/Q`39[h`0c;BB0<nkV03>^YD0b[B=0;jWO@2^UVP0XXQG09Z0C@2I
OTT0XhIJ0;>HK@37Zh@0dKNF0=FkX03H_jT0glRf0>O@`03XcL80hlVj0=c1[03F^ih0c[:;0<6UMP2a
UUl0Z8]A08Yf>`1fH2l0HD/V05I0:01@>bP0BSPR04dl8P1CA2D0GdPY06=<;@80JU8`01/0LUPe07YN
=`20HcT0QFHj08IW>@2<Kd<0RVe108MZ?P23ISX0Of8f07aO<`1iG300N5/_06YD:`1YDbX0J58Y06I@
9`1TCRD0HT`S061:8@1OBB00GdPV05]79P1F@R40D3dM04Xi6`16=aX00P13=AX02@0h;A/0=blL03L^
7@0f;al0<R`N02dY7@0Y9aX09bDI02DW6@0202@V6@0302<U6P0R8a/08B8L0080824L00P0820F024Q
5`0R8QP08b<I028R600Q8AL07alE01hN50808R8J0`0Q8AT3020P60P07QdH0P0K6AX0100L6Q/07A/L
01dK700N71d201lM7PP07QhF200P81P2028R6P<08B4I0`0P81P802DQ60809B0J0P0V8A/302LR7004
02PS7@0Z8Ql0:b<P02dU8P80;RHS00<0;BDR02/S800Z8Ql00`0[91X202`U6`<0;BHL00<0<2HJ034W
6`0c:Ad00P0d:Qh00`0c:Ad0<BLK030V6P08038[8@<0<BLK0`0b:1`303<Y7@06038/800d;240=2`Q
03D[8@0h:b80>B/R0P0l:b<01P0f:B40=bXQ03LZ8@0g:al0>2`N03P/7080>BhL00h0@S<L044b6`10
<AX0?c0I040a6P12<a`0ACHO04Lh8@12<Ad0@c8N04@c7`16=B40B3LS04Th9080BcXV00<0BCLQ04Pf
8016=1h00P15<ad02`16=1h0B3HP04Tg8@1E>b80E3XQ05<i801B>1l0DcTP05@j8@1F?2<0EcdT0080
FCXK00h0FS/L05/l7@1L?Ah0GChO05ho801O@240IDPV06A79@1SAB<0ID@S06M4901ZARH0KDTY0719
:P<0K4lU00<0KE0V06iA9`1^DBL00P1_DRP0101/CbL0KE0X06mB:P1aE2`2079E;@03075D;01`Db/0
Kd/W00D0Kd/W0P1^BRH0201[CbL0K4lW06i>9`1_C2H0LTXV07A89@1eAbD0MdHU0P1dCRL0101cCBH0
LT`U079<9@1aBb@2071:8`80LDhX101`CBL206m<9P0B07A>9`1cCBH0LD/T071:8`1aBb@0LddV07E?
:01fD2T0Me8U07UD9`1lEbX0OeX]081K;P21G2l0P5/^07mJ;@23HC40PV0`0P21Gbl01023HC40QF<c
08QV=P2:J3P5095]?@<0TVhn00<0Tflo09A`@02DL4000`2ELD402`2FLT80Ug=309Mc@`2DL3`0UG4m
09Ib?P2GLcl0UW8n09Ea?@2CKc/0TVhj0080U7100P2CKcl3099^?P06095]?@2=J3`0SFPl08eX>`2>
JSX0SVXh0P2>JSH00`2>JcD0Sf/k08m[>`0608m[>`80U6lh00<0U6lj09E`?02EKch00P2FL4400`2F
L4<0VGA009Ud@00209Qc?`0509Mb?P2FLCd0UW4m09E`?02ELCd00`2DL3`209=_>`80TVhj00<0V7<o
09Mb?P2EL3`00P2DKc/01`2EL3`0Ug8n09Qc?`2@JcL0TVdi09E`?02GLSh0102IM400102HM4@0VGE5
09ahB02NNTX209mkB`80WWY:0P2NN4T509egB00409afA`2QODT0X7a809ijAP80WGU500`0WWY60:1l
B02QODT0XGi809mlAP2LND<0VWM109Uf@02KN480WGY409ikA@2ONd/309ijBP0409mkB`2QODd0Y81@
0:F1D@<0YH1<0P2TOd/30:=nBP80Ygm<00@0YH1<0:B0C02TP4`0XX5<0P2QPT`30:=oB`80Y81<0`2U
PDd30:V5D@80Z8A@0`2WPdlA0:F1C@<0YH1<0P2TOd/30:=nBP080:1kAP2QO4L0XWe80:AoBP2VPD`0
Z8=>0:V4C`2ZQE030:Z6DP80ZhMC0`2/R5@20:f8E0040:j9E@2_RUH0[hYF0;2;E`80/HaH0P2dTET0
102cT5P0/XmG0;:?E`2aSUH20;2=E@<0/HeM0P2bSUh50;>?G`060;B@H02eTF40]Y9R0;NCH`2hU6@0
^IEU202fTV820;>AH@80]99R00@0]I=S0;JDI02fU6@0]iEU0`2hTfL20;NBIP<0]Y5U0P2cSel01P2d
T600]Y9R0;RDI02iUFD0^YIV0;^GI`D0]91L0`2eTEd20;2;E`80/HaH00@0/8]G0:j9E@2/Qe<0ZhIB
0P2[Qe<20:Z6DP040:V5D@2XQ500Yh=?0:N3C`80[XUL0`2]R5/30:b7FP80ZhI?00<0ZXE>0:V4C@2X
Pd`00P2WPT/0102VPDX0YH1;0:F0B`2UP4/20:AoBP<0Xgi90`2NND8509mj@`090:1kA02TOdX0WWU4
09Qc?P2IM3l0WWU40:9mB02PNdH0W7M200P0WgY600`0WgA10:5f@`2SN4D0YGY70:IkB02WO4T0YW]8
0:EjA`2JMT80VgM309eiA@2PO4P20:5mB@<0X7a80P2QODT00`2ROTX0Xgm;0:B0C0020:F1C@P0Y81<
00h0Y7eD0:AmDP2TOU40YGm>0:F0B`2VPDX0YX980:J2AP2UNT<0Y7]30:AkA@2RNTH0X7]609ijAP80
W7]81P2MN4@209ag@`<0V7M::oooool002[ooooo0`2UNTL20:AiAP<0XgQ500@0XWA00:=e@@2SMD40
Y7I20P2UMd<20:IhA080XgU70`2TNTP30:EkB@80YWa<00@0YWa:0:ImB@2VODT0YWe70P2VODD30:Ek
B@<0Y7Y80P2SNDL50:QmB0<0Yga700H0Y7`o0:Al@@2TO440Y7]30:AkA@2TNdL20:AjB080ZH1<00<0
Z7m;0:MnBP2VODT00P2UO4P00`2TNdL0Ygi:0:MnBP060:MnBP030:ElB02TNdL0XWU500<0XGQ400/0
XWU50:AkA`2UO4P0Ygi:0:ElB02RNDD0WgI209ie@@2OMT80XGQ40:9iA@0209ag@`0309]f@P2JMD40
VGA00080V7<o00L0Ug8n09Ia?@2FLCd0UG0l09A_>`2CKSX0TVdi0080TF`h0P2:ICP01028HcH0Qf8e
08EP<`24Gc82089M<080PE`_0P22GC001`21G2l0OUT/07]F:@1iE2L0Me@/07QE;@1jEbl00`1lFC40
101jEbl0NEH^071C:`1aE2`307=F;P03075D;01_DRX0KU4Y0080KDdV101^CRL206m?:00807A>:@1e
CbX0MU0[07MA;01iDbh0NeD`07aF<@1mEc8207eJ<080OU/a0P1oG382081M<`0808]W=`29ICD0R6@d
08MS<`28I3@0RVHf08aX>02=JCT308eW>080SVPi0`2?JCX01`2BK3d0TF/l091Z>`2?JCX0SVPi08eW
>02<ISL00P2;ICH01P2<ISL0SVPi08mY>P2?JCX0SVPi08aV=`@0RfDf0P2<ISL308eW>0<0T6/g0P2?
JSH0102>JCD0SFPd08aW<`2;ICH308aV=`80SFLh0P2>J3T00`2=IcP0SVPi08mY>P02091Z>`0308mY
>P2>J3T0SFLh00T0SfTj202=IcP8091Z>`X0TF/l0P2@JS/408mY>P0808]U=P2=IcP0SfTj091Z>`2A
Jc`0T6Xk08mY>P2>J3T2091/?00608m[>`2=JCT0RfLg08YV=P29ICD0R6@d202;IST208QT=080RFDe
00@0RVHf08]W=`2;IcL0S6Ph2027ICL01P2:ISH0RFDe08UU=@28I3@0Qf<c08IR<P80QF4a0P1oHc44
081T<P80PFDc00H0Peha085O<@20GS00OUh_07eN;`1jGRh207QN;@80NU/_01h0N5P_07IF;`1eEBl0
Le8_075@;@1aD2l0J4hY06A<:01MAR@0E44Q04dn8@18?280AS`S04@l9@10>Ad0@3TO03lh7P0n=Ql0
>c<N03L_700d:aX0<RTH02dW6@0/:AX0;BTM02`Z7P0Y:Al09BHN024T7@0O8Q/301hQ6PD07b8K200N
81d301lR6`8082<L100Q91d0200O8QT07R4J01dP6@0L7QT06Q`I01TK6P0H6A/05aPJ200H7QX0200O
8QT082<H024T6@0S9aT09BTJ02HZ6@0X;AT0:BhJ0P0b;a`05P0c<1d0=34N03Db7`0g=240>3DR03Tf
8`0j=B80;b`I02HS500Q7a<0820F024R700O8Ah071hK02LX800V9al09BHN02@U7@0S91`08R<K024R
6P0P8AT2024R7004020Q6`0O81X07QlI01dN608071dG400N8AX0800R9Ah08RDL02@V6`0W:1X0;2/I
038`6`0e<a`0>SHM03`^4@10<QP0B3HR050k:P1MA2h0L5He08IY?@2CN4<0RGYC09^3E@2dS5P0^heB
0:AiA01gEc00BC/Q02h/7@0Q:b`08R/Z020Y:00P9R@082DQ028T7`0T9R409bPS200T9R<302@W8080
9BPQ1P0V:B8202DX8@<092LP200X:B<202`]9`80:b`V00/0:R/U02TZ900Y:R@0:2TS02lX8P0b:B80
=2/T03T_9P0n<BP0@cDZ04Lg:P0204Ph:`0@054k9P1B?2L0DclW05=2:01D@bL0Dd@U0554901@@b40
D4@^04m3;@1<?b`0BSd/04Hi:014=bL0@C<V040b9@P0@SHV00P0Ac`Z04Pk:019?2T0C3dX04hn9`1@
?RH0DShU05<o9PP0DT8X00<0G44V05i3:01PABX00P1RAb`08`1QAR/0H4DZ05m4:@1K@2<0Fd8T05]1
9P1J@RP0Ed4Y05<o9`1??BL0CC/U04Di8`16>R@0ASTV04Hi:014=bH0@C@T03d_8P0k;B00?SL]03/d
:P0f;bD0<BXP030Y7`0b:b40=RlU03Pa9`0k;b<0?30T03da9@0n<RH0?C4U03/_8`0i;B40=b/O0080
>C8Z0`0h<BT303L`:080<bdQ00@0=2hR03D_8`0g<BD0>38V0P0i<bL803d_900H04Xb9P1<=2P0CSLY
04lh:01@>BL0D3XU04li901>>240B3hS04Tm8`18?280BS`R04`l8`1@?RH0E40X05I2:P1B@R40EDDT
05U9:01LC2/0GDd/05a<:`1IBBP0EdLV0P1JA2`01P1HA2/0ED@Z05A3:@1B@RP0D48W04m19P80CT4`
00/0CT8/04e1:@1=@RH0CD8R04a27`1<@Qh0EDD/05=3:P1@@2T0C3/W04Xi9`0204Xi:@0=04/i:`1:
>bH0BS/V04dn:@1C@b`0F4H^05Y9;`1KAb`0FTDZ05U49`1QBR/0H4TZ05m8:@0205i7:0090619:P1R
Bb`0I4d^06YC<`1[E3@0K5Dc06eG<P1^F3<0KeTb0080L5Xa00H0LU/l07AM?P1gH400NV=307aU@`1l
IT4207]U?P0307e`AP1kKT@0NFa20080N6]100/0NVe307a_A@1nLDL0P6To08A/@029LD40T7I309Il
@`2JOSl0WH0n09f0?00209UoC00609MlC@2DND`0T7A<08a`B`29K4X0QfY:0P27IcH05P2:IS@0RV@c
08eS<@2@HS00T64]099P;@2?HRT0TVDZ09Y/;P2SLc40[7`d0;>2=@2hR3H0_8Tf0;Z?@02hSd00]Xm0
0;B@@P2cTTD0/YE90;>HB`2cVDh40<FLG0040<NNGP3;XV80cZEU0=2WI`P0bZAS0P33Y6@01032Xf<0
`J9R0<2QH@2oX6020;jOG`030;jGE02oV5D0`IYG0080`Y]H00<0`IYG0<2IEP2oV5D00`2nUe@03@2m
UU<0_9EB0;^DD@2jTe00^I9?0:j;A`2]RTP0[8U70:^8B02ZQTP0ZHE90:V5B`2XQ4X00P2VPd/0102T
PDT0Xh180:9oA`2QOTH20:1mA@0A09ae=02LM3H0W7@f09Yb=@2GKc@0TfXb08mV<02=I2h0Pf<b089R
<@20H2l0OUh]07aL:`1iFBP0N5PW07MG9P1eEBh00P1gERd03P1jFC00OU/a08=N<P27HC@0Rf8d08eT
=P2EKbh0UW0_09Qb<`2HLS@0V74f09M`=`2EKSD0U6df0P26J3@01025Ic<0Q6Hb089T<021Hbl2081R
;P0>07mR:020HbT0PF@Z089U:`24Ibd0QVT_08MZ<028Jc40PFdb089/<P21Jc40PFP_081V;@21I2`2
081Q:P80O60`101kGbl207YN;P0407YQ:@1lHb/0OfH^085X<0@0PfXb01@0QF/^08I^<P25K3<0Nf@^
06iH9P1UD240HDlQ06=@9@1UDRP0I54W065>901PCB<0Gd`R061=8`1RCbD0He0V061A:P1OD2T0G4dV
05Y;9080FDXS00P0Fd`U05a=9P1LCb<0G4lS05]>901KCBH0FT`U05Y<9`80FT`Y00<0G4lU05Y=8`1H
Bb400P1EB1h02@1FBAl0F4/Q05Y=8`1MCbP0G4hW05]=9P1JC2D0FD/T05M98P0205I88@0b051=601B
BQ`0DdDR05A09@1K@BP0JDX]07aJ=@29IS`0YHIH0:n@I02jWG<0`ZIo0<F[R036[X`0bK:C0<beUP3B
^J<0c[JL0<J]S`2hWWT0Zi1S0::6E02QQ4`0XXE;0:N?J@2iXgh0bkBD0=6lW`3Ha:`0glfi0>7@`03N
c;h0iLVn0=o4[`3F_YX0bkF40<2[LP2`Vf80WhYC09=mB`1cH3P0IU<[05Y88P1C@b40CSdO04Ph7P1;
?B<0E4D^06A77@1YC282071C:@0307MJ<01mH3H0P6<i0080PF@j0200R6Lj08EV>022HcL0OF0f07MK
<`1bFC40KUH`06aD;P1WCS00ITd_06E<;P1SBR`0HDPZ05m6:01MA2H0G4<U05E1:01A?bL0CcdU04Xj
8`15=R40@3<P03`a7`0k<1h0=BhL03@]6`0c;1`0<BTL02hV6`0/91T0:b8I02XQ60<08b@L0P0R8a/3
024R6PP08R4L200N7aT201`L6P<06a/I0`0J6QP801`L6PP07AdK200N7aT801lN6@@081lJ0P0Q81/2
028Q70<092@L0`0S8a/2028R6PP09RLI200Y91h802`X7`P0;RXQ00<0>2/R03LZ8@0g:R400P0f:B00
1@0d9ah0<bHM038U700b9A`0<RPL0080<bTM00<0=2XN03D[7`0e:al00P0f;20203@[6P0603L[6`0i
;1`0?2`M03h/7P0o;Al0@BhP0P0k;Qd303`_7P<0?C0O00P0AS0K04La7018<Qd0BS@O04`f8@1==b80
CSPS04li90<0B3LM0P19>1h304Xi7`0604lf8P1@=b<0D3LQ054i8@1B>R00Dc/O0P1D?Ah305hl8@80
GcdR0`1P?R<306E48`0306I5901WARD0IdHU0080J4LV00<0JT`V06]=9`1^D2X00P1_DB/0101/CRP0
JT`V06Q:901^CB@606m>9@0306i=901`BR<0L4XS0080L4XS0P1aBb@00`1bC2D0LddV06];8P0306a<
8`80KDdT0P1^CRD0201]BBL0K4PV06]79@1ZAR@0JdLU06a89P1^BRP0Kd/Y0`1aBb@5071:8`80M4XT
00L0LT/T075;901cCBH0M54Y07ED:`1gERd0N58[0080N5<Y00D0NE@X07]F:@1mFBT0P5`Z089N;003
08IP<@80Qf4b0`28HS<508eW>0<0SVPi00@0SVTl091[?P2BKD00U6m20P2EL4<01@2DKd80Tfi1099]
@02DL3`0UG4m00<0UW8n00<0U70l09=_>`2AKCT00P2@K3`208m[>`<0SVXj00@0SFTi095]?@2?Jc/0
SFTi0P2;IcL00`2<J3P0SFTi08m[>`0208iX>`0308mY?02@JSd0TF/n0080TV`o00@0Tfe009EZ=`2E
JSL0UFXg0P2FJcP309M/>@0<09Qe?`2FLSh0Tflk095]>`2@K3`0TVe009A_@`2EL4@0V7=609IaA02D
Kd80TVe00P2AK3l01`2CKT40U6m208m]?@2?KCd0TFdm099/?@2DJcd00P2EJSd0102FJSd0UW4m09Ia
?@2FLCd209Mb?P<0V7<o00T0Ug9809QcA`2KMTT0WGU709mlAP2OO4@0Wga209il?`2GM3h00`2HMCl2
09Uf@080VWM10`2JMT8209]g@`<0W7Q40P2KM3d0102IM3d0VGHn09Uf?P2GMch209Ig?PP0WWY60`2P
NdL20:5lB0<0XWe900@0Xgm;0:9nBP2ROTX0XWi:0P2QODT20:1lB0080:B0C02UPDd0YX9>0:J2CP2U
PDd0Y81<0:9nBP2PO4P80:9nBP80ZHEA00<0Z8A@0:J2CP2TP4`00P2SOd/20:5mB@P0YH1;0P2SOd/2
0:9nBP040:5mB@2PO4P0X7a809mkA`80XGa800H0XWe90:=nBP2TOd/0YH1<0:J1C@2WPTh30:^6DP80
ZXEA0`2YQ500202ZQE00ZhIA0:b7DP2]R5<0[XUD0:n:E@2`ReH0/HaG0P2cSeD20;:>E0040;6=D`2`
S580/8aB0:n;D@<0[hYC0P2`Re@30;6<E@<0/XiN0P2cSel30;B@H080/hmK0P2bSUX01@2aSET0/8aH
0:n;E`2_ReL0/hmK0080]91L00<0]I5M0;JBGP2fTUh00P2gTel80;NCH`080;2<F02aSET0/XiJ0;B@
G02gTel0^IEQ0;ZFHP2kUf<20;B?H`030;>>H@2bSUh0/HeK0080/8aH00<0[haF0:j9E@2]R5@00P2]
R5@20:b7D`80ZhIB202^PU420:^5F0040:b6F@2]QeX0[HMJ0:j8F`80[hUL0P2ZQE020:V4C`<0Z8=>
00H0Yh9=0:J1C02VPD`0YH1;0:AoBP2SOTT20:9mB0070:5lA`2SOTX0XWe909mjAP2LMd<0VgI209Ye
@@0309]f@PP0WWY60P2HLch00`2IM3l0VWE009]f@@0209ag@P0309eh@`2RMd@0XWM40080XWM40P2S
N4D20:AiAP090:Ak>@2UO3`0YWdo0:Mm@`2XODH0ZWm<0:]oCP2[Oe00Y7m800<0Xgi70P2RODH20:5l
A@030:9nBP2SOd/0YH5=0080YX9>00/0YH5=0:=oB`2ROTX0Y7m:0:=nB@2RODP0XGa70:9mB02TOdX0
YX5<0:R3CP0309mkA`0309ijAP2MNDD0WGU50080W7Q41@2JMD4309Ud@0<0WGU9:oooool002[ooooo
0`2UNTL30:AiAP80XgQ50P2TMT820:Eg@`80YWQ40P2WNDD00`2UNdT0Y7Y80:AjB0050:AjB080YG];
00@0YG]90:ElB02UO4P0YGa60P2UO4@30:EkB@<0Y7Y80P2SNDL40:QmB0@0Yga700H0Y7`o0:Al@@2T
O440Y7]30:AkA@2TNdL20:AjB080Z7m;0`2WOTX30:ImB@P0Ygi:00<0YGa80:AkA`2RNDD00`2QN4@0
1`2RNDD0Y7]70:ElB02UO4P0Y7]70:=jAP2QN4@00`2PMd<01P2QN4@0W7M309ag@`2KMT80VWE109Ud
@080V7<o0P2GLSh01`2FLCd0UG0l09A_>`2CKSX0TVdi095/>02@JcL00P2:ICP01@29I3L0Qf8e08EP
<`24Gc80Peha0080PUd`0`23GS401`22GC00OeX]07eH:`1kERT0N5D]07UF;P1kF3000P1lFC401P1k
F300NEH^07QE;@1`Db/0LE@/079E;@80LeH^00<0LE@/06mB:P1^DBT0201^CRL0201bCbT0Le0Z07AA
:`1eDR`0Me@^07QE;`1iES00NULa0P1mFS00101nFc40Oe`b081M<`21GS@2089O=@0808UU=@28I3@0
Qf<c08MS<`28I3@0RVHf08eY>@2>JSX308iX>@<0SfTj0P2@JS/2095[?004091Z>`2?JCX0SVPi08eW
>080S6Hg00<0RfDf08aV=`2>J3T00P2?JCX00`2>J3T0S6Hg08]U=P0308]U=P80S6Hg0`2=IcP208eX
=080S6Lc00@0RfHb08YU<@2:IC40RVDa102;ICH208aV=`<0SFLh00L0SVPi08mY>P2@JS/0T6Xk08mY
>P2>J3T0SFLh00T0SfTj202=IcP8091Z>`X0TF/l0P2@JS/308mY>P0:08iX>@2;ICH0SFLh08mY>P2@
JS/0TF/l091Z>`2?JCX0SVPi08m[>`80SVXj00<0SFTi08aX>02;IcL00P2:ISH808]V>@80R6@d0P29
ICD0102:ISH0RfLg08]W=`2;IcL808MU=`<0R6@d0`27Hc<208IR<PP0PV@b00H0Peha085O<@20GS00
OUh_07eN;`1jGRh207QN;@80NU/_01h0N5P_07IF;`1eEBl0Le8_075@;@1aD2l0IT`W06=;9`1NAbD0
ET<S04m08`19?B<0AC/R04<k9010>Ad0@3TO03lh7P0n=Ql0>c<N03P`7@0e;1/0<bXI02hX6P0]:Q/0
;BTM02`Z7P0X:1h09BHN024T7@0P8a`801lR6`P07R0M0`0O8Q/3020S70<08B@M00H07b8I01hQ6P0M
81T071hI01XL6@0I6aX201PI6`P061hJ00P07R4H01lR6@0Q91T08RHH02@X6@0V:QT09b/J02P]6@80
<c0M0P0d<Ah0300e<Ql0=S<P03Ld8@0g=240>cHS034^6`0V8a@081hB01lO5@0P8A/07b4N01hP7@80
9RLO00@09BHN02@U7@0S91`08R<K0P0Q8QX2024R7003020Q6`0O81X07QlI00807AhH00<071dG01hQ
6P0N8AX03P0N8AX2024T7@0N02<U6P0V9aT0;2/I038_700f=1d0>SDO03`a5@11<Q/0AC@R04hi:01J
@B/0K58a089W>P2AMT40QWM@09InD02]R5<0^HYB0:UnB@22HST0E4@Z03La8@0S:BT08RPX024W9@0Q
9B@08BHR02<U8P0S9B0092HQ200T9R<302@W80809BPQ1P0V:B8202DX8@<092LP200X:B<00`0[;2H0
:R/U02X[9@0202TZ9080:2TS00P09bPR034Z900b:b<0=B`U03T_9P0n<BP0@C<X04<e:080ASHY0100
DC`Y058m:01D?bX0Dd4Y05=2:01A@RD0Cd0Q04ho801=@B/0C40Z04/n:`18>bX0ASTX04<f9P12=2L0
@C<V2012=RH02012=bD0A3LT04Dh9@18>B@0Bc/T04dk8`1@?2<0DCdT0P1>?R@0101??bD0DD4W05=3
:@1EAB/205I6;00305e29`1N@bP0H4DZ00<0HTL/00X0HDH[0615:P1K@R@0G4<U05]39`1K@bT0F48Z
05A0:01@?RP0CS`V0P16>R@05P16>BH0ASTX04@g9P11=2@0?S0S03`^8@0n=B`0>c8Y03P_9P0e;2<0
=2/R03D/8`0g;RD0>2lV03/_8`0l<2@0?C4U03hb9P0m<BD0>blS03T]8@0h;20203Pa:@80=c0X0`0f
;bL02@0e;RH0<bdQ03<]8@0d;R80=BlS03H`900g<BD0>38V03Tc9`0803d_900504/c9`1<=2P0CSLY
050i:@1A>RP00P1@>RD04@1?>B80BClT04Xn9019?B<0BcdS04dm901@?RH0ED4Y05I2:P1C@b80EDDT
05U9:01LC2/0GDd/05a<:`1JBRT0F4PW0080FdD]01H0FDD/05E4:P1D@bT0DT8X05129`1?@BH0CD0_
04e0;@1=@B/0CD4Y04e29P1=@R@0CD8R04e3801DA2/0DT8Y04lo:01<?2D0BcXV04Xi9`1:>BT0BcXZ
0P19>RD01`1<?BP0DT8[05I4;01HAbd0FTH[05U4:@1H@bH00P1PBBX205m8:@0:0619:P1RBb`0I4d^
06I?<01ZDc<0Je@d06]D<P1]Ec80KUPc06mI<P80L5Xa00D0LEXk07=L?@1fGcl0NV=107aV@@0207eW
@00A07aV?@1nKd@0OVm407e^@`1lKD80OVm4081aAP22LdP0Q7E:08=/@P26KT80RW92091f@`2ENd80
VGa009]m?@2KOS`00P2PQTd07`2PQDh0Wh=A09f1D@2HNdl0U7M=099eB`25JS/0QFTj08IW>027ICL0
Qf<c08UP<P29Gbl0R5h^08YN;@2<HBh0TVD^09U[<02RLS80ZGPe0:in=P2bP3L0]HDk0;F7?02eRD00
]Xa20;B>A@2dT4H0/i590;:BB@30V5<00P2oUe801@30V5<0`i]F0<JNF@39XE`0bj=N00P0aZ1O00H0
`:5P0;nPG`2nWeh0_IiM0;bMG02jVeX20;VJF@0I0;jGE02oV5D0`9UF0<6JE`32VeP0`IYG0;nHE@2n
Ue@0_IIC0;bEDP2kU540^Y=@0;RACP2gT4d0]Xm<0;F>B`2/RDD0ZhQ60:Z7A@2WQ4@0YH530:=o@`2R
OT@0XGe30:B2A@020:>1A00=0:5o@P2POT40Wge009mm@02NO3l0Vg<f09ad=`2KLcP0VW8g09M^=P2C
JS@0T6Lc08iU<@02081O<P0707iM<01lFbh0NUT/07UH:`1gERT0MUDX07MG;P0207QH;`0>07aK<020
GS40QV4d08YT=@2<ISL0T6Pg09E_;P2FL340Ug4b09Qb=02GL3D0UVlf09A]=P2CK3D208EW<`0408AV
<P23IC40PV@`085S;`80P68^00h0Of8X081S:@21I2X0PVD[08AW;@25J2h0QVT_08MZ<021K3<0PF/b
081Z<@20Ibl0P6D^081R;080P64[1P1kGbl207YN;P0407YQ:@1lHb/0OVD]085X<0<0PfXb01<0PVTa
08E[<026KS80Q6/c07YS;@1_FBL0IU4R069?901SD2D0He0V069?9@1PCB<0Gd`R05i;8@1OC280H4dS
065>901KC2D0FT/T0080FDXS00@0FT/T05a=9P1NCbP0Ge0Y0P1LCb<02`1KCR@0FddV05Y<9@1JC2L0
FT`Y05U;:01JCB<0FD`R05Q;8@1GBR00ETTO0080EdXP00H0F4/Q05]=:01JC2L0FT`W05U;9P1HBRD2
05M9900c05I88`1@CAX0DTTN05=48`1E@BH0G48Y06]<;`1nG3H0RfTl0:J7F@2_T6@0^Yec0<:VO`35
ZhP0aZj<0<VbT`3<]IH0dKVQ0<feV`34Zh`0]Yag0:R=HP2PQ580XH==0::5C@2[Tfd0_:J10<ffUP3C
_Z40fLF]0=o=^@3Qd<00gL^m0>75^@3K`:/0d[ZF0<RbP@2kYVd0ZYEL09J1C029Ld80KU`f065?:@1G
AB40DD4P04dl7P18>1h0CCdT05I6;@1UBB40JDdU0080L5@/00<0MUXb07aP>01nHSX00P1oHc/02024
ICT0Pf@h07iQ=`1iGCD0LeXb06iF<01ZE2d0JE<^0P1QBR/05P1OB2T0GDHW05]49@1I@R<0F44R05M0
8@1@?RH0CS`T04/k9017>240@SHP03lb7`0k<1h0>RlM03@]6`0c;1X0<R/K030X6`0^9Q/0;2<J02XQ
600Z8AX302<T70808R<K0`0Q8QX8028Q70P07QlI0P0L71X301/K6@<06QXH200L71X801dM6`P07QlI
2@0O7QT3020O6P808B0K0P0R8A`802<S6`P09BDI200Y91h802`X7`P0;BTP0P0d:R0303<Y7`80<RPN
0P0a9ad2038X7080<bTM00@0=2XN03D[7`0e:al0=B/O0P0d:aX01P0g:a/0>B`L03`/7@0n;1h0?bdO
040]7`<0>bhM0P0l;ah303d`7`0604H`6`17<A`0B38M04Xd7`1;=B00CCLR0P1>>2<01017=Q`0B3LM
04Pg7@18=ad204Th7P80BSTO0P1?=R801P1@=b40DCTQ058j801C>al0Dc`M05@m7P<0GS`Q0`1O?B82
060n8`0406A38P1UA2<0ID@S06I59080IdHU0P1XAbH206Y<9P0606]=9`1/CRP0K4hX06a>:01[CBL0
JT`V201^C2H606i;9@80Kd`V0P1[Bb@206a<9@<0KDdV00T0KThW06e99`1/B2H0JdLU06Y6901[AbD0
K4PV06i::01_BbT00P1bC2D6075;900907I<9P1eBbD0Ld`U079<9@1dCRL0ME8Z07IE;01hEbh0NE</
0080NE@Z00D0NUDY07aG:P1oFb/0PEd[08=O;@0308IP<@80Qf4b0`28HS<208aV=`@0SFLh0P2>J3T0
102>JC`0T6/n099]@02CKT4309A_@P80TVe000<0U70l09Ea?@2FLSh00P2FLSh00`2DL3`0Tflk095]
>@0308m[>`80SVXj0`2=JCT00`2>JSX0SFTi08aX>00208]W=`0408aX>02>JSX0Sf/k08aV>@80SFLj
00<0SVPk08mY?02@JSd00P2AJch309AZ>080UF/i0`2FK3X01P2FLcd0UG4m09=_>`2BKS`0TVhn099]
@080Tfi200<0UW5409A_@P2CKT400P2AK3l00`2BKD00Tfi109A_@P0208m]?@03095]?@2BK3d0U6/m
0080UFXm00@0UVXm09Ia?@2FLCd0UW4m0P2GLSh309Qc?`0609IaA@2HLdL0VWE809eiA`2NNTH0WW]3
0P2MNT0309Mc?`80V7A0102IMD4309Yf@P80VgM30P2LN4@209ae?P0409Ye?P2HMCd0V7Dm09If?@80
UGHm202MNDD30:1kA`80XGa80`2RODT30:9nBP80XGe90`2PO4P0202SOd/0Y81<0:F1C@2VPTh0YH5=
0:=oB`2QODT0X7a8202SOd/20:R4D0030:N3C`2UPDd0Y81<0080XWi:00<0XGe90:1lB02TOdX01`2T
OdX30:9nBP80XGe900T0X7a809mkA`2ONdL0X7]70:5lB02RODT0Xgi:0:AoB`2UP4`00P2VPDd30:Z5
D@80ZHA@0`2XPdl20:Z5D0040:^6D@2/Qe80[HQC0:j9E080[hYE0P2bSU@20;6=D`040;2<DP2_Re40
[h]A0:n;D@80[XUB0P2_RU<30;2;E0040;6<E@2aSEd0/HeM0;6=G@80/XiN0`2cSel0102cSe/0/XiJ
0;:>FP2bSUX40;6=F@80/hmK0P2dT5`0102eTEd0]Y9N0;JBGP2fTUh80;JBHP0@0:j:EP2_ReL0/8aH
0;6=F@2cSe/0]91L0;FAG@2fTUh0]8mS0;>>HP2cSV40/XiN0;6=F`2`S5P0[h]G0:n<EP<0[HQD0P2/
Qe<30:^6DPP0[H=A0P2ZQ5D20:^5EP80[8IG0P2]QeP30:V4C`80Z8=>0`2WPTd20:F0B`030:AoBP2S
OTT0XWe80080XGa700D0X7]60:5lB02PNdL0WWU509ag@`0209]f@P<0W7M3202JMT8209Ud?`0309Ye
@02KMT40W7M20080WGQ300<0WWU40:1g@`2QN4@00P2QN4@20:9iA@80XgY600P0Y7dl0:Al?P2UOD00
YWi30:MnB02XOd/0Z7i<0:QnCP@0Xgi70P2RODH20:5lA@030:9nBP2SOd/0Y81<0080YH5=00/0Y81<
0:=oB`2ROTX0Y7m:0:=nB@2RODP0XGa70:9mB02TOdX0YX5<0:N2C@0209mkA`80WWY600@0WGU509ah
A02LN4@0VgM3102JMD4409Ud@0<0W7Q8:oooool002[ooooo0P2VNdP20:EjA`<0Y7U600<0XgQ50:Ai
AP2TNDH00P2UNTL40:IkB080YWa:0P2UNdT0102TNTP0XgU70:9hAP2RN4H20:AjBP040:AjB02TNdL0
Y7]70:AkA@80Y7]30`2UNdT30:AjB080XgU7202WO4L01P2TO3l0Y7a10:Al@@2TNd<0Y7]50:AkA`80
Y7Y80`2VODT30:MnBP80Z7m;202VODT00`2UO4P0Y7]70:=jAP030:9iA@030:=jAP2TNdL0YGa80080
XgY600H0Y7]70:=jAP2RNDD0XGQ409mf@P2NMD4209ag@`0309]f@P2JMD40VGA00080V7<o0`2GLSh0
102FLCd0U6lk09=^>P2AK3P2091[=`80RVDh00H0RF@g08MR=@26HC@0QF0c08AO<P23GS4308EP<`05
08AO<P23GS40PE`_07mJ;@1mF2/00P1kF30207aI<@0507]H<01iERh0N5D]07MD;01aE2`00P1bEBd0
0`1cERh0LUD]075D;00206mB:PP0KThW00H0LTlY07=@:P1dDB/0ME8/07IC;@1hEBl207UF<00807aI
;`1mFS00OU/a081M<`21GS@0Pf0f08AQ=`25HSP308IR<P0508MS<`29ICD0RfLg08iZ>P2?Jc/00`2?
JCX2091Z>`@0TF/l0P2@JS/0202?JCX0SVPi08eW>02=IcP0S6Hg08]U=P2<ISL0SFLh0P2>J3T00`2=
IcP0S6Hg08]U=P0308]U=P80S6Hg0`2=IcP208YU<@80RF@`1028Hbl01029Hc@0RV@e08YT=@2:I3D2
08]U=P80S6Hg00<0SFLh08iX>@2?JCX00P2@JS/00`2?JCX0SVPi08eW>00908mY>PP0SFLh202?JCX;
091Z>`80SfTj0`2>J3T0202;ICH0SFLh08mY>P2@JS/0TF/l091Z>`2?JCX0SVPi202<J3P808]V>@<0
RFDe0`2:ISH208]W=`P0QfDg0P26HS8308MS<`<0R6@d2022I3801P23GS40PEla081N<01nGRl0OEh_
07YN;P80N5h]0P1hFbl03`1fFBl0M5L_07=E;`1aDbl0Ke4]06mA;`1TBRD0HTXV05m89P1IARH0DT<V
04Xn9015>b80@3PQ040i7@02040i7`0=03lg800l=1l0>C4N03H]700d:aX0;bTK02dZ6`0]:Ad0;2XN
02PX7P0U9Qh08RDN024T7@0801lR6`P07R0M0P0N8AX201lR6`@082<L00L08B@M01lR6@0O8Q/07R4J
01`N6@0K7AX06A/J008061TK200G7AT01P0N8AX07b8K020S6P0R9AX092PJ02DY6P809b/J00<0<c0M
03@a7P0d<Ah00P0e<Ql303@a7P0603dh9@0c<1d0:2DF024O4`0N7Q@07b0J0P0P8Ql01@0V9al09BHN
02DV7P0T9Ad08b@L00808R<K00<08B8J024R700Q8Q`00P0P8A/0100O81X07QlI01dN600M7QP@01hQ
6P0J01hP6`0O8Q/08B8J02DU6@0[:AX0<BhK03Hd7`0j=Al0?c@H040d7014<b40B3DV05<m:01VCBh0
Nf<g08ab?`25Ld/0TgQ;0:N2CP2fRE80/8MC09=bA`1UDS@0@SLQ02<X900R9b<202<U8P8092HS00<0
8bDP028T7`0S9B801`0S9B8302@W80809BPQ1P0V:B8202DX8@<092LP2`0X:B<302LX8P809RLQ00H0
<2/U034]900e;RH0=bhU03X`9P0n<RH3044c9P0804lm:@1@?RX0DClY0590:01B@BL0DD0T04ln8P1>
?Al204Tm9`0404Pk:016>BP0ACPW04<f9P80@S@W2012=RH05@0n<b40?c8O044d8@15=R40BCTR04`j
8P1?>b80D3`S04Xj801;>b40CShT05109P1DA2X0ETH/05U9;`1JBS00GT@Y05m5:P1PAR/0HDL/0698
;@020657;0090616:`1MA2H0G4DV05e5:@1KAR/0F4@[05A2:P1@@2T0CclX0080Ac/U00H0ASTV04Dh
9`13=RD0@C@T03h`8`0m;b8203`b:00303/a9`0j<2H0>BlU0080>2hT00<0=bdS03``900l<2@00`0m
<BD00`0l<2@0>RhR03T]8@0203H_9`80=BhV0`0d;BD01P0c;2@0<bdQ03<]8@0d;R80=BlS03H`9080
=c4U00<0>38V03``900l<2@01P0l<2@02@1:=2L0BcDX04hh:P1@>bX0DC`Y054l9`1@>bH0Cc/S04]1
9P0204/o9@0J04`n901>?RD0DClW05E1:@1G@b/0E4<U05I59`1IB2X0G4/]05e<;P1LBbd0FTT[05U8
:P1MAbl0G4H^05Y6;@1FAB/0ED@Z0592:01@@RL0Cd4V04/o:@1<@2X0C40X04a09P1<@BD204e29006
04e28P1B@RP0DD4W04lo9P1=?BH0BcXV0P1;>RP02P1;>RX0B3TT04Pi901;?2L0D40Y05A2:P1FAB/0
F4@Y05Q3:01G@RD205m8:@160619:P1QBR/0HT//06E>;`1WD340JE8c06UB<P1ZDc<0Je@b06aF<@1^
F3<0KeTb071J<@1aFc80LEXj07=L?01fGcd0NF<n07aV@@1mId00OVPo07mY@021L480PW5308=bA025
M4H0QgI808YiB`2<Ndd0SWe?08Qb@`2;LdD0SGI4099i@`2DNT40UgY009Uk?@2INc/0XXM40:B8A`2W
RdX0Z8a=0:N:CP2SQT`0WX5909]mA`28LT<0Qg5208I^@025JSd0PfHj089S=`1oH3@0Oehc08EK<`25
Fc40Qe`a08]O<02BI380VFXd09ma=P2TLcT0[GLg0;1j>P2bOch0]HA20;J6A02eR4D0/hQ40;:7@`80
^95400H0^I950;ZCAP2mUTT0`9U<0<>LC`34WE080<:KF00;0;jLG02mVe/0_9YJ0;ZHF02iUeL0]iEE
0;JDE02eTe<0_IIC0;jGE02oV5D00P30VEH02@2oV5D0_YMD0;fFD`2lUE80^iAA0;VBC`2gT4d0]8e:
0;:;B0020;6:A`080:b9A@2[R4H0Z8E30:F2@P2PO3h0W7Pl09Ue>`2GLcT309mn>`0509im>P2MO3T0
W7/h09]j=`2JNCH00P2ELCL01P2DKcP0Tfhi091[=P2>JCD0RfDd08US<P80O5`f00L0Ne/e07UI<`1h
F380MeLa07IF<01eEBl0NE`b0080O5da00h0Of0d08=R=@28ISP0SFTi095[>P2BK3/0TFh^099_;`2C
Kc40U70d09=_=@2BKCH0T6/d08mZ=@80PfDc00@0PV@b085S<@21Hc40P68`0P1oHBl01P1oHRX0P6<[
085T;022IBd0PfH^08EX<080QVTa00P0OfXa081Z<@1oJC00OfH^07mT;@20HR`0P64[07mP:PD0NUh^
0`1kGbl0101jHBT0O6<[07iU;@21J303089Y<@0<085X<026K340QF`c089Y<@1iHRh0KeTX06MB9@1S
D2D0I54W061>9P1OCBD0GD/S0`1LBR8205e;8`<0EdPQ00D0F4TR05Y;901MCRL0H54Z065B:`0205]>
8P0405]>901JC2D0FT`U05U;9P80FD/X00T0EdTR05Q:8`1HBR<0FD/T05Q:8`1GBB80ETPQ05E7801H
BRD01`1GBB@0<P1>BQX0DDPO05=48`1E@BP0GD<Z06e>;`21H3L0SV`n0:R9F`2aTVH0^iid0<:VO`34
ZXL0aZj<0<VbT`3<]IH0ckNM0<ZbUP30Z8H0/IMb0:F:G`2NPU80X89>0:>5C`2aVGD0`Z^90=:kW03G
`ZD0flN_0>3>^03Pckd0g<^k0=c0/P3F_:D0cKF?0<>]O02dWfP0XHaE08]e@`1lISL0I5@b05U99`1@
@1l0CSdO04`k7`1:>Al0CchT05U7;`1WBb<0JdlW0P1aEBd00`1fFS80Nelg07aP>00207aP>00P07eP
=P1jGSH0N5`d079I<@1]EBl0JE<^06A@;@1SCb`0G4@X05]39`1J@RH0F40T05Hn8P1E?B40Dc/O058j
7P1;>B40BCTR04Lg8013=1l0?c8O03`a7`0h;ah0=bhM038/700a:a/0;bTK02hX700/9A/0:R<K02TR
6P0X8A/3028S6`808B8J0`0P8AT8024P6`P07QlI0P0L71X301/K6@<06QXH200K6aT801dM6`P07QlI
2`0O7QT2020O6P<08B0K0`0Q8AT00`0R8QX08b<K02@T700202DU7@P09BDK200X8ad802/W7PP0;BTP
0`0a9ad4038X7P80<bTO0P0b:1`303<Y7@<0=2XN0P0d:aX01`0g:a/0>B`L03`/7@0m:ad0?R`N03l/
7P0j;A`00`0k;Qd203`_7P80?C0O00H0AC0K04Ha7017<Qd0B3<N04Td7`1;=R4204`g8P<0AcDM0P18
=Qh304Tg7`0604he8@1?=R80CcHP050h801A>Al0DSXN0P1C?1d205/l8080G3dQ0`1M?R801`1N?b<0
Hd8Q06A38P1T@b80ID@S06I5901WARD00P1XAbH0201YBbL0J4XV06Q:9P1XBRH0JD/W06Y<:01/CRX0
KDl[0`1/C2D206];90<0K4`U00@0KDXT06i;9@1^BbD0KT/U0P1]BR@206a98`0406Y:8`1[Bb@0Jd/T
06];9080K4`U0P1]CBH0201]BBL0K4PV06]79@1ZAR@0JdLU06a89P1^BRP0Kd/Y201cCBH02@1hCRP0
MddW07E>9`1dCRL0MDlX07IC:`1gERd0NEP_07]E;P0207]F;00507]F:P1mF2/0P5`/08=O;@25HBl0
0`26H34208MQ<P<0R68c00@0RfDf08aV=`2<ISL0S6Hg0P2=IcP208iX>@0308iY?02?JSd0TF`o00@0
TVe00P2AK3l209A`?0<0UW8n00<0U70l099^>P2AKCT00P2>JSX208eY>@80S6Ph0P2;IcL208YV=P06
08UU=@2:ISH0RVHf08aX>02>JSX0Sf/k0P29I3L0102:ICP0RfHi08aW>P2<IcX208eX>`<0TfTg0P2D
JSP309E[>@0:099_>@2CKc/0Tflk09A`?P2CKcl0TVe0095/@02@Jcl0TVe0095/?`<0T6/n00<0TVe0
09=^@@2DKd800P2@KSh00`2BKSh0Tfdn09E/?P0209I[?P0409M[?P2EL3`0UG0l09E`?080UW4m0`2G
LSh0202FLD@0Ug9509UeA@2KMdD0W7Q409ai@`2KN400VWLo0`2FLSh209Mc?`@0V7A00`2IMD4209Yf
@P80VgM300H0WGE109ad@02JMD00V7Do09Md?P2DLcd209=d?@P0WGU50`2ONTH20:1kA`<0XGa800@0
XWi:0:5mB@2QODT0XGe90P2PO4P209mkA`080:9nBP2SOd/0Y81<0:F1C@2TP4`0Xgm;0:5mB@2PO4P8
0:B0C0050:N3C`2VPTh0YH5=0:B0C02ROTX00P2QODT00`2PO4P0Wg]70:=nB@070:=nB@80XGe90`2P
O4P309mkA`060:1kA`2QO4P0XGa80:9mB@2SOTX0Y7m;0P2UP4`30:R3C`80Yh9>0`2VPDd20:R3CP03
0:V4C`2ZQE00ZhIA0080[8MB00@0[HQC0:n:D`2_RU<0[hYC0`2^RE820:f8D@<0[HQC0P2^RE@30:n:
E@<0/8aL0`2aSEd20;:>GP80/HeI0`2bSUX30;>?F`80/XiJ0`2cSe/30;B@G0P0]I5Q00D0[HUE0:j:
EP2^RUH0[XYF0:n;E`030;2<F080/hiR00<0/XeP0;6=G@2`S5X00P2_ReL0102^ReD0[8MC0:b7D`2/
Qe<20:^6DP<0ZXEA202/PU020:R2D`80ZH=D102ZQ5D30:R3CP80Yh9=0`2VPD`20:AoBP040:=nB@2R
ODP0XGa70:1kAP80WgY500<0WWU509ehA02LMd<00P2KMT80102LMd<0WGQ409ehA02NNDD809Qd@080
VWE000<0VgI109ag@P2MN4<00P2NND@0102ONTD0X7M30:1g@`2PMd<20:5hA0<0XWU50P2UOD00102U
OD80YWe50:ImA`2VODT20:IlBP<0Xgi70P2RODH30:5lA@030:5mB@2ROTX0Y81<0080YH5=00<0Y81<
0:9nBP2QODT00P2SOTT30:9mB0030:=nB@2UP4/0YX5<0080Wg]700@0WWY609eiA@2LN4@0VgM30P2J
MT8809Ud@0<0VWI6:oooool002[ooooo0`2VNdP20:EjA`<0Y7U60P2UNdT60:IlBP060:QnC02WOD/0
YWa:0:EkB@2TNTP0XWQ60P2QMdD20:9hB0040:9hAP2RNDD0XWU50:9i@`80XWU10`2UNdT30:AjB080
XgU70`2VNdH40:MlA`070:QmB02TO3l0Y7a10:Al@@2TNd<0Y7]50:AkA`020:AjB0060:AkA`2UO4P0
YGa80:ImB@2WOTX0Z7m;0P2YP4`80:ImB@T0Y7]700P0XGQ40:=jAP2TNdL0YGa80:AkA`2RNDD0WWE1
09ac?`80W7M300<0VgI209Ye@@2IM4000P2HLcl02P2GLSh0V7<o09Mb?P2FLCd0U6lk09=^>P2AK3P0
T6/g08mZ=P2:ICP208UT=`0508QS=P26HC@0QF0c08EP<`24Gc800P27HSD01P26HC@0QF0c08AO<P22
GC00PE`_081K;P80OEXb00H0O5Ta07]H<01jEbl0N5D]07MD;01fDb/4079E;@04075D;01`Db/0L5<[
06mB:P80KdlX101^CRL206e=9P06075?:@1bD2X0Le4[07AB;01eDbd0MU@^0P1gEBl04@1kF2h0O5T_
07iK<@20GC<0PUle08AQ=`26HcT0Qf@j08=O;`24H300QF4a08MS<`29ICD0S6Ph08iZ>P2?Jc/0SfTj
00<0T6Xk0P2AJc`2099/?@80T6Xk0P2?JCX208iX>@80SFLh00<0RV@e08aV=`2=IcP00P2>J3T00`2=
IcP0S6Hg08YT=@0308]U=P80S6Hg0`2=IcP00`2<Ic<0RfHb08YU<@0308UT<00308YU<@2;IS80RF<d
0080RF<d0P2:I3D308]U=P0308eW>02>J3T0SfTj0080T6Xk00<0SfTj08iX>@2=IcP02@2?JCX808eW
>0P0SfTj2P2@JS/308mY>P<0SVPi00T0RfDf08eW>02?JCX0T6Xk095[?02@JS/0SfTj08iX>@2:ISH0
0P2;IcL00`2<J3P0SFTi08eY>@0208iZ>PP0RfHi0P29ICD608YV=PP0QfDg0P25HC400`26HS80Qf<c
08QT=00208UU=@0308YV=P24I3<0Q6@c00@0Pf<b0P22HS401P23GS40PEla081N<01nGRl0OEh_07YN
;P80N5h]0P1gG2l03`1eFRl0LeL_079F;`1`E2l0KU8]06iA;`1SBB@0HTXV06199`1KB2P0E4DX04/o
9@15>b80?cLP040i7@02040i7`0>03lg800m=B00>S8O03L^7@0e;1/0<2XL02h[700]:Ad0:bTM02PX
7P0U9Qh08bHO028U7P0Q91d4020S70<07b8K200N81d301hQ6P807b8K100P8a`0200P8aX07b8K01hQ
6P0M7aX06adJ01XL6`0I6Q`061TK200G7AT02@0M7aX07R4J01lR6`0Q91/08bHK02@X6P0V:Q/09b/L
03<`7@0203@a7P0=03Db7`0d<Ah0<c0M038_700a;Q/0?CPU03@a7P0[:1T08R0D01hN500N7aT0828O
028T8@0202DV7P8092DM0P0S91`2028S6`808R<M00@08B8L020Q6`0O81X07QlI0P0M7QP@01hQ6P0P
01`N6`0M7aX0824K02@T6P0Z:1/0<2dL03Db7`0j=B40?cDJ03ld7P11<B40A34S04dh9@1OB2T0ME`c
08=/>P29LdX0TgQ;0:9nC02_QU00]8YH0:1nD@1eGCT0D3dO02TY8@0V9Qh08b@N02@U7`0U9b809BLT
024V8P0N8al802<U8P<092LP0P0U:24602HY8P809BPQ0`0T9b0802PY8`D09RLQ0`0U9R001P0`;BH0
<RhU03<_9P0f;bD0>30U03X`90<0?C4S00P0AcPU04Xi9`1<>bL0D3hX054o9`1D@2L0DclV05@o9080
ASXT00@0ACPU04Dh9`14=bH0@cHV0P13=BP8048f9P0@03hc8@10<b00@SDR04Hg8P1:>R<0CS`T058n
9@1C?bH0C3`R04dm8`1??bD0DD4W05=3:@1EAB/0EdL]05Q8;P80GTHZ0P1OAb/40618;080GDHW01H0
G4LZ05]7;01GAR`0E4@[0511:P1?@2T0B3`V04Lk9@16>BH0ACPW04<f9@11=2@0?c4T03h`8`0j<2@0
>c4U03dc9`0n=2P0?C<W03/a9@0i;b<0=bdQ0P0l<2@303da9@80?30T00@0>blS03@]9@0d;BD0=2dU
0P0c;2@3038[8`0303<]8@0d;R80=2hR0080=BlS0P0f<2@00`0g<BD0>S0T03X`900603X`900504Ld
9P19=RP0BcPY04hk:P1??BT00P1??BL03@1>?2@0C48W04e19`1<@2H0CClU04lo9P1A?bL0ED4Y05M3
:`1EA2P0ETDY05U8;01KBRh00P1LBbl02P1JBBd0FDP/05i8<01MAbl0FdL^05M6;01EA2X0Dd<Y0553
:01@@RL204a0:080C40V00@0CD4W04e29P1=@RH0CD8V0P1@@B@01P1??bD0CShU04dm9P1=?2P0C3/W
04`k:@80B3TT00l0BS/V04hn9`1B@2P0E4<Y05M3:01G@RL0Ed8U05i7:01OB2T0H4TZ069;;01UCRl0
Ie0a06UB<`1ZDc@00P1YDS808@1[E380K5Ha06iH<`1`FS<0LE/b079L<`1bFc/0Le`j07EO>P1hHSd0
NfDn07iX?`20Jd00PFa108Ea?P27Ld00RWI308ijA`2BOT/0UH5>09N3D02HQ540SgU8095jB02ANTH0
U7]509Ej@`2GNT00UgPo09Mi?@2OPCT0XX@l0:J8@P020:V;A@0G0:J7A02RPd00Wh0m091nCP2>O4`0
SGQ;08UdA`24Kd@0PFY007iW?P1lIC`0Oe/i07iJ=P1nF3<0OUL`08=I<@29GS<0Sf@i09AX>`2SJS<0
YVlg0:ae?02aNT400P2bOT802P2`OCh0[W/l0;:<>`2bS3/0]8hm0;J@?`2iTd80_9I50;jHA`2oVDP8
0<2HD`80_9UG00@0^YME0;VFE02gU580]Y=A0P2dTDl00`2kU540_9EB0;fFD`020;jGE0080;bEDP2k
U540^I9?0;fFD`2lUE80^95>0;F>B`2bRdP20;29AP0:0:n8A@2]RTH0[8U70:V6A02TPD40WWXl09Qd
>02CKcD0T6`b09Mf<@80V7Lb00h0VGPc09Qg<P2GMS40UG@_09Ac;P2<JC<0RfLc08YV<P29IC<0Qf<c
08EP<`24Gc<0Pehb07QJ>0<0MeTg0P1fF3H207EG=@0A07aQ=01nHS<0OV8c085U=P26IcP0RVXi08i]
>P2BKSX0U70l08m];P2@KRl0TFlb095^=02@KCD0SV/e08aY<`2;Ic<00P21HS<2081Q<P0:07mP<@1n
Gc00OUl`07iO<01oHB/0P68/085S;@22I2h0PfD_08AV<080QFLa00P0OFPa07iW<@1mIS00OVD_07iS
;P1oHBd0Oel/07iN:`80NEd]101jGRh207]O;`0407]R:P1lHb/0OVD]081W;`80PVTa00/0PFP`081W
;`25Jc80PVTa07iU;`1eGR`0KUPY06QC:01TDBL0He0X05]<9@0205Y;900305U:8`1HBB80F4TR0080
F4TR0P1GB2401P1HBB80FDXS05Y;901LCBH0GDhW05i?:080FdhR00@0FTdS05Y<9@1JC2D0FD/V0P1I
BbP00`1DAR40ETPS05Q:9@0205U;9P0405M9901DAR40DT@O05A68`<0EDLT0`1FB2D0401GBBH0CDTL
0517801CA2D0ET8Y05m5:P1`DS00Q6<h099a?P2YRU`0/Y=W0;^NM032YWl0a:Z70<J^S039/Y<20<ff
U`0J0<N`T02kXh40[9=[0:66F`2MPE80XXAB0:N9E@2iX840b;6B0=NoX`3JaJX0g<R_0=o=]@3Nc[L0
fLRd0=VnZ`3C^Ih0b[>:0;jXMP2^VF80V8=>085[>P1aFS00FTd]05528`1:>ah204`k7`0504`h7`1B
?RD0GDL_06M>9P1ZDBT00P1_ERh03@1cFS80MUde07MN=P1eG3@0M5/c07=J<P1`FC00KUH`06YD;`1T
D2d0H4d/05];:@1JBRT00P1G@RL03P1F@BH0E3lT05<n8`1A?240D3/P04lj7`15=Ah0@c@M048c7P0n
<Ah0>c0N03L^7@0e;Qh0=2dM0P0]:Q/01P0/:1`0:RHK02TU700W8aX09R4K02DP6P<08B8J0`0P8AT2
01lP60P08B0K200N7aT201`L6P<06a/I0`0J6QP801/K6@P071`J200N7aT;01lN6@<081lJ0P0Q81/2
01lO5`06020P600R8QX08b<K02@T700U9Ad09RHN200T91X802PS7@P0:RHM200/:1l202dU6P0502hV
6`0_9a`0;bLL034Y7P0b:Ql00P0c:b06038X7080<bTM0P0d:aX00`0g:a/0>2/K03/[700203d[7@03
03h[7@0j;A`0>RdL00<0>bhM0`0l;ah204<a6`0604@b7015<ad0AS@N04Le7`18=R00BCLQ0`16=1h2
04Le7`<0B3HP00H0CC@P04he8@1>=Al0CcLO050h7P1A>Ad2058k70<0FS`P0P1K?B4305`n8P0@0691
801S@R40I4<R06E48`1VAB@0IdHU06Q79P1YB2L0IdTW06I89P1UAbD0I4HT06I89P1YBbT0K4h/06i@
;P80JD/U101WBB<206U;9@80JdTT0`1/BRD00`1ZB2<0JDLR06Q68@0406Y:9080Jd/U0P1/C2H0201]
BBL0K4PV06]79@1ZAR@0JdLU06a89P1^BRP0Kd/Y0`1cCBH407A>9`0:07E?:01jD2X0NDlY07I?:01e
CbP0MU0Y07IC:`1hEbh0NEP_07aF;`80O5L]00D0O5L[07iI;021GBd0Q60^08IR<00308IP<@80Qf4b
0`28HS<0102:I3D0RfDf08]U=P2<ISL208eW>080SVPi0`2?JSd5091[?P0408mZ?@2BKSX0Tflk09A`
?080UG4m00<0Tflk095]>@2@K3P00P2<J3P208]W=`@0RVHf00H0QV8b08MS<`27Hc<0R6@d08YV=P2;
IcL208eY>@0608AR=025HcD0QF<e08IT=P27ICL0R6Hh0P29IcT2095Y>0<0TVXi0`2CJcX0202?K3H0
TFdi09=_>`2DL3h0Tflo095/?`2>JCd0SFPl0`2>JC`00`2?JSd0T6/n095/?`02099]@080T6hn00<0
TVhn09=]?P2EK3h00P2FJch00`2GJch0U6lk09A_>`0309E`?0<0UW4m00@0UG4o09Ib@02HM480VGE3
0P2IMD400`2GLcl0UW<m09Ea?`0309Ea?`80UW900P2GLd4209Mc?`<0V7A00`2IMD4209ad@@0409Ud
@02GLcl0UW8n09=b?@80TG8l202LN4@209iiA@<0WgY60`2PNdL0102QODT0X7a80:1lB02PO4P209mk
A`80WWY600<0XGe90:9nBP2SOd/00P2TP4`00`2ROTX0XGe90:1lB0080:F1C@80Y81<00<0Xgm;0:9n
BP2QODT00P2PO4P00`2ONdL0WWY60:9mB0070:9mB0@0Wg]7102NNTH20:1kA`80XGa800@0XWe90:=n
BP2SOTX0Xgi:0`2VPDd20:F0C0<0Y7m;0P2VPD`20:N2C@040:R3CP2YQ4l0ZHA?0:V4C`@0[8MB102[
QU420:^6DP<0[8MC0`2]R5@30:j:FP80[h]K0`2`S5`20;2<F080/HeI00@0/XiJ0;>?F`2dT5`0]91L
102aSET40;:>FPP0/hmO0`2`S5P50:n;E`80/XeQ00<0/HaO0;2<G02_ReT00P2^RUH00`2]RU@0ZhIB
0:Z5D@020:Z5D@80ZHA@0P2XPdl80:^3D0@0Yh5@102XPU420:N2C@80YX5<102UP4/20:9mB0030:5l
A`2PNdH0WgY50080WWU400L0WGQ309]f@P2KMT80VWE109Ud@02JMD40W7M30080WWU500<0WgY609Qd
@02HM4001P2HM40209]f@@0409ag@P2MN4<0WWU409iiA080WgY50`2OMd<30:1hA080XGU50P2UOTL2
0:AmAP040:AlB02SNdL0Xg]70:=kA`80Xgi70P2RODH20:5lA@80X7]400<0X7a80:5mB@2SOd/00P2T
P4`00`2SOd/0XGe90:1lB0020:=nB@<0XWe80P2SOTT02@2TOdX0Wg]709ijAP2NNTH0W7Q409]g@`2J
MT80VGE109Qd@00309Qc?`@0VGA000@0VWE109QdA02HM4@0V7A4:oooool002[ooooo0P2WO4T20:Ik
B080YGY70P2TNDH30:InC@D0YGe<00H0Z7i<0:MmB`2VO4X0YG]90:AjB02RN4H20:5gA@80XWQ800@0
XWQ60:9iA@2RNDD0XWU30P2RND430:EkB@<0Y7Y80P2SNDL30:EjA@030:IkAP2WO4L0Yga70080Z7e8
00H0Y7`o0:Al@@2TO440Y7]30:AkA@2TNdL20:AjB0060:AkA`2UO4P0YGa80:ImB@2WOTX0Z7m;0P2Y
P4`80:ElB080Y7]71@2UO4P20:AkA`080:5hA02SNTH0Y7]70:ElB02TNdL0XWU509ie@@2LLcl209ag
@`0309]f@P2JMD40VGA00080V7<o00X0Ug8n09Ud@02HLcl0UW4m09E`?02BKCT0TF`h08mZ=P2>JCD0
RVDh0P29I3L01@28HcH0Qf8e08IQ=026HC@0QF0c0080R6<f00@0QV4d08EP<`23GS40PUd`0P21G2l0
1P1nFc<0OEXb07aI<@1jEbl0NEH^07QE;@80Me@/00@0LeH^079E;@1bEBd0LE@/101`Db/00`1`D2T0
KdlX06m?:00206i>9`80KDdV00<0K4`U075A:P1aDBX00P1bDR/02P1cDb`0M5@]07AD;@1eEBh0NeP^
07aI;`1mFS00Oe`b089O=@24HCL208IS>@08089N;P23Gbl0QF4a08QT=02:ISH0S6Ph08eY>@2>JSX3
08mY>P80T6Xk0`2AJc`408mY>P@0SVPi00<0RV@e08]U=P2<ISL00P2>J3T00`2<ISL0RfDf08YT=@03
08]U=P80S6Hg0`2=IcP0202@JcL0SVTe08eX=02;IS80S6Lc08eX=02?JSH0T6/g0P29Hc@208YT=@<0
RfDf00@0S6Hg08eW>02>J3T0SfTj0P2@JS/00`2?JCX0SVPi08eW>00908mY>PP0SFLh202>J3T8091Z
>`<0SfTj0`2>J3T208eW>00808]U=P2=IcP0SfTj091Z>`2AJc`0T6Xk08mY>P2>J3T208YV=P0308]W
=`2<J3P0SFTi0080SVXj00<0Sf/k08]V>@2;IST01P2;IST608YV=P80RFDe2027ICL208EQ<@0308IR
<P27Hc<0R6@d0080RFDe00@0RVHf08IT=025Hc<0QF<c0P24HS8208=Q<@07089P<023GS40PEla081N
<01nGRl0OEh_07YN;P0207QN;@80MEd_00l0Le/_075H;`1`Ebl0KU@_06aB;@1/DRl0HdTT06=;9`1Q
BRP0G4TY05A5:01<@2H0AC/R040h8@10>Ad00P11>R003@10>240?SHQ03`d8@0i<1l0=bhM038/7P0_
;1d0;BTM02/Y7@0W9ad09BHN02@W800S9Ql00P0R9Ah2024T7@04020S700O8Q/07b8K01lR6`P07R0M
0P0M81T201hQ6P807b8K0`0P8a`01P0P8aX082<L01lR6`0M7aX071hK01XL6`806AXL200G7AT0600L
7Q/07AlJ01hP6`0P8a`08RDL02@W700U:A/09RXL034^6`0b;a`0=34N03Db7`0d<Ah0<c0M030]6P0_
;1T0?3LT03Hc800_;1d09R@H01lO5@0N7aT07b4N028T8@@092DM100S91`2028S7@04024R700P8A/0
824K01lP6P807QlI400N8AX0800L7Qd071hK01lP6`0R8QX0:BLK02h[700c<1l0=c8O03df700m=B00
?S4Q044_8@17=2<0Ed8U06aE;01iHc80S7E;09AiBP2OODd0ZX9?0;>;F02ZQEP0QFDn05m2800e;b<0
;BTN02LT6`0T91`09RLQ02HX9@0Q9B@07B<Q200R924302@W80809BPQ1P0V:B8202DX8@<092LP200W
:28602DV80809RLQ00L0;RhV034^9@0a;RD0<blT03H`900h<2<0>C0Q0080>S4R00P0?C0O040c8P16
=b@0C3/W05<n:@1G@BX0FT4[05]3:`80ACTS00H0ACPU04Dh9`14=bH0A3LW04@f:@13=BP8048f9P08
044f9013=R<0ACPU04Xk9P1>?RL0DClW05E1:01F@RT305519`80DT8X0`1C@bT00`1LAbX0FdHY05]6
:@0205a7:P0305e8:`1NBB`0GTT/0080FdHW00`0FdPZ05U8;01FAR`0DdD[04i2:P1=@BT0BCdW04Pl
9P17>RL0ACPW04<f9@11=2@2040b9@0303``8P0n<R@0@3@V0080@SHX00<0?c<U03``8P0j;R000P0m
<BD303``9080?C4U00<0?S8V03@]9@0d;BD00P0c;2@4038[8`@0=2hR100e;b<803P`8`0D04Hc9@17
=2H0BSLX04dj:@1>?2P0CcdW04hl9P1>?2@0CD<X04e19`1<@2H0CClU04hn9@1A?bL0E40X05E1:@1D
@bT0ED@Z05M6;01IB2h205Y9;`80FDP^0P1MAbl01P1KAbh0F4L]05M6;01EAB/0DdDZ0594:@80Cd@X
00@0CT<W04i2:01>@RP0CD4W0P1=@BT205118P060511901@@2H0D40W0510:@1??bP0CchZ0P19>RD0
3@1;?2L0CShW0590:01D@bT0Ed<X05Q3:01H@bH0GDHW05m8:@1QBR/0Hd`]06E>;`1WD3400P1YDS<0
1P1XDC40JE8b06YC<@1/ES40KUPc071J<`80LU`c01H0M5dk07AN>@1fH3/0N68k07]U?01nJCh0P6/n
085/?`27LCP0RW@k091j@@2FP4L0VXA;09f7CP2NR4l0WhU@09N2C@2GP4`0UWm909MnB02GO4D0V7Y4
0P2INT<0:02RP3T0YH<l0:V7@02/RT80[H]30:^9@@2XQS`0YX@j09f8D@2KQU40V89@09=oC@2>NDX0
RGA708AaAP22KdD0P690081O?P1lFcP0NUPe07]G<`20FSD0QEdi08QP?02GHc@0VfLg0:5]>`2WLSh0
ZWDo0:Yf?02XM3P0Z78f0:b5=P2]QSL0/8Tj0;><?@2fSd00^9520;ZCA02kU4D80;jCCP0:0;^FDP2j
UE40^YEA0;VDD02hTdl0]i9>0;JAC@2eT4`0^95>0;VBC`<0^Y=@00P0^95>0;J?C02eST/0_IIC0;^D
D@2gT4d0/ha90;29AP<0[hQ501H0[HY60:^8AP2YQT@0Y85109ij?02FLSH0T6`b08aX;P2>K2`0Sfd]
095_;`2BL300TFl_091^;P2>K2`0S6XZ07mO;P1nGRl0OEd^07]J;@1jFBh0NEP_0P1iEc4207IJ=@80
Me/f0`1hG3L04P1iGCP0OVHf085W=P21IcH0PVPg08IZ>02:K3P0SFhh091_>@2AL3X0SF/^08i/;`2?
K380Sf`d08i[=@2;J380RFDa08QT<P<0OUla101mGS000`1lGBl0P68^081R;P02085S;`0:089T<023
IC40PfDa08AV<P1kIS40O6Da07]T<01lHRl0O60^07iP;P80OUh]0P1hG2`207UM;@80NUh^0P1kGbl0
101kHRX0O6<[07iU;@20Ibl2085X<00:081W;`1oIRh0Q6Tb07mV<01hGR/0LETY06aE:@1XDRT0I54Y
069>:@@0FDXS0P1HBB8205M88@0305U:8`1JBb@0FT/T0080FDXS0P1HBB80101GB240FTdQ05Y=8@1J
CB<205U;900<05U;9P1HBRL0F4XW05A68`1EAb@0EdTV05U;:01HBRL0ETPU05=58P1A@b00DT<R0`1C
A2<305A5900c05E69@1;AQh0CdDR05939P1G@bX0HDL/07=E<@28J3T0UgI00:b=G`2cU6P0_9me0<:V
O`33ZHH0aZj<0<VbT`3>]iP0b[>A0<>/RP2gWgT0Z8mW09j3F02MP5@0YXMI0:f>G`30YX/0c[JJ0=c4
ZP3Laj`0gLV`0=k=/`3Kbk80e/J]0=NmYP3@]iT0aZn50;VSL@2WTU/0TG]907UR=P1YDRT0DTH/04Tm
8`16>1d0BSXP04hj8@1>>Ah0EclU0659;`1WCbT0JE4[0080KED_01d0L5Pb079J=01aFC<0KUH`06eE
;`1YDbh0IU8]06A@;@1PCB`0Fd/Z05M8:@1CARH0DT@W05I2:@1E@BP0E40W05<o9P1B?RD0DCdT050l
8`1?>b80@S<N03lc7@0m<1d0>c0N03H]700d;Ad0<B/M030Z700202XX6`0402TW6`0X9QX09R<J02DR
6`80924L100P8AT201lP60807QlG200Q81/801dN608071`J0`0K6aT301XJ60P06a/I200L71X801dN
60X07QdH0`0O7QT3020O6P0601hN5P0O7aL0820H024Q6@0R8QX092@L0P0U9Ad802<S6`P09b8L200Z
9Qd802/W7P0302XT600[9AT0;2HJ0080;BLK00@0;bTM030Z7P0a:al0<R`P0`0b:1`5034W6`0503@[
6P0e;1/0=b/K03P[6`0j:Q/00P0l:Q`0100m:Q`0>RdL03X]700j;A`303/^7@80?2lN0P13<A/204@b
700404Dc7@16=1h0AcDO04Le7`<0AC<O0P16=20304Le8@0604`c7`1==200CC@N04hf7P1?=ad0D3PL
0P1A>Q/205Ll7`80F3dP0P1I?R4205Xo8P0C06507`1R@B00Hd8Q06A38P1VAB@0IdHU06Q79P1YB2L0
ITPV06A6901SAB<0HT@R06A6901WBBL0JT`Z06a>;01WBbH0ITXU06A88`0206=78P0;06A88`1VBRD0
Id/V06M68`1XAb@0JTTV06]:9`1ZBBH0JDPU06M68`1UA2400`1YB2D306Y99P80JdXW00P0KDTW06a8
9P1[AbD0JTHT06]79@1/B2H0KTXX06m;:@80LT`U0P1cCBH0101dCRL0MDlX07E?:01eCbP207Y@:P07
07M@:@1eCbP0MU0Y07IC:`1gERd0N5L^07aF;`0207aG;@0507aG:`1nFB`0PEd]08AP;P26HS000`26
H34208MQ<P<0R68c0P29Hc@01P2:I3D0RfDf08aV=`2=IcP0SVPi08mY>P80SfXm1`2>JC`0202@K3P0
TFdi099^>P2CKc/0TVhj095]>@2?JcL0SVXf0P2:ISH308UU=@<0R6@d0P24H3000`26HS80Qf<c08UU
=@0208YV=P0608]W=`22HS<0PV8c08=S=024I3D0QFDf0P26ISL00`27IcP0SVPi08iX>@0208mY>P@0
T6Xk00`0SV/e08m[=`2AKCT0Tflm099^?P2@Jch0SFPl08]V>P2;IST0S6Lj08eX>`2>JC`208mZ?@80
T6/n0P2?KCd00`2AKCd0TV`m09A[?@0209EZ?@0309IZ?@2CKSX0Tfhj0080U6lk102EL3`0202DLC/0
UG4m09Ib?P2GLcl0Ug=109Ea?`2DL3h0TVhl0P2CKcl209A`@0@0UG510`2FLSh309Mc?`80V7A000H0
Vg=209Yb@@2HLT40UW9009Ea?`2CLSl2095a?PP0VgM30P2MN4@209iiA@@0WgY60P2PO4P209mkA`<0
WWY600@0WGU509mkA`2PO4P0XWi:0P2SOd/00`2ROTX0XGe90:1lB0080:B0C080XGe90P2PO4P01@2O
NdL0WWY609ijAP2NNTH0WGU500P0XGa7202MNDD30:1kA`@0XGa800<0XWe90:AoB`2TOd/00P2SOTX3
0:9mB@040:5lB02TOdX0Y7m:0:AoBP<0YH1;0P2VPD`40:R3CP@0ZHA?0P2YPe820:Z4D`@0ZhED0`2/
R5P20:f9F@<0[XYJ0P2^RUH00`2_ReL0/8aH0;6=F@020;:>FP030;>?F`2`S5P0/8aH0080/8aH102_
ReL80;6=G@<0/hmK00D0/XiJ0;6=F@2aSET0/HeI0;2<F0020;6<H0030;2;GP2_Re/0[XYH0080[HUE
00@0[8UC0:V4D02YQ500ZHA@0P2XPdl30:N2CPP0ZHA@102WPTh40:J1C@@0YH1;0P2TOdX20:=nB@80
X7]600<0WgY509iiA02MN4<00P2LMd800`2KMT40VWE109Ud@00209Qc?`0509Ud@02KMT80WWU509ii
A@2ONTH0202LN4@01P2JMD00VgI109]f@@2LMd80WGQ309iiA080WgY50P2LMd8309eh@`<0WWU40P2R
ODT20:5lB0040:5lA`2PNdH0X7]60:1kAP<0XWe60P2QO4D30:1kA00309mkA`2PO4P0XWi:0080Xgm;
00<0XWi:0:1lB02ONdL00P2RODP30:=nB@80XWe800L0XGa709mkA`2NNTH0WGU509ahA02JMT80V7A0
0080Ug<o0`2GLSh00`2HLcl0VGA009Ud@00209Ye@@<0V7A4:oooool002[ooooo0`2WO4T20:IkB0<0
YGY70P2TOTl20:=mCP@0XWa=0P2VO4X20:EkB@040:AjB02SNDL0XWQ60:9hAP80Y7Y:00@0Y7Y80:Ak
A`2TNdL0Y7]50P2TNd<30:EkB@<0Y7Y80P2SNDL20:AiA080YGY500D0YW]60:MlA`2XODP0Z7e80:Al
?`020:Al@@030:Ak@`2TNdD0Y7]70080Y7Y80`2VODT30:MnBP80Z7m;202UO4P20:AkA`050:ElB02V
ODT0YWe90:ImB@2UO4P00P2TNdL20:=jAP060:AkA`2SNTH0XWU50:5hA02OMT80WWE10P2LMd<00`2K
MT80VWE109Ud@00209Qc?`0709Mb?P2IM400VGA009Mb?P2EL3`0TVdi091[=`0208iY=@<0RF@g0P28
HcH308MR=@0508UT=`27HSD0QF0c08=N<@22GC000`21G2l0101mFS80O5Ta07]H<01iERh207QE;@80
NEH^0P1cERh00`1aE2`0L5<[06mB:P02071C:`04075D;01`D2T0L50Y06m?:080KThW00<0KDdV06a<
9@1/C2D00P1_DRX2071C:`<0LE@/00h0LUD]07YG;@1kF2h0O5T_07iK<@20GC<0PUle08=P=P24HCL0
PUh^08=O;`26HS80R6@d08YV=P<0RfLg00@0SFLh08iX>@2>J3T0SVPi0P2?JCX2091Z>`@0SfTj102>
J3T00`2:I3D0RfDf08aV=`0208eW>00308aV=`2;ICH0RV@e00<0RfDf0P2<ISL308eW>003095/>02?
JSH0SFPd0080S6Lc00<0SVTe095/>02CKSX00`2;ICH208aV=`@0SFLh00L0SVPi08mY>P2@JS/0T6Xk
08mY>P2>J3T0SFLh00T0SfTj202=IcP808iX>@/0SfTj0P2>J3T308eW>00908]U=P2=IcP0SfTj091Z
>`2AJc`0T6Xk08mY>P2>J3T0RVHf0080RfLg00<0S6Ph08eY>@2=JCT00P2>JSX808]V>@80RfLg0`2:
ISH308UU=@P0QfDg0P26HS8308MS<`D0R6@d00@0Qf<c08IR<P26HS80QF4a0P24H3001P23GS40PEla
081N<01nGRl0OEh_07YN;P80N5h]0P1dGRl03`1bFbl0L5T_06mH;`1]EBl0Je<]06]C;`1VC2L0I4`X
065::01JAbL0Dd@W04/o9@16?2<0@SXS040i7@02044j800=044i8P0o=b80?CDR03Xa800i<1l0<bdO
030]7P0]:Ad0:RPL02LW7@0U9Qh092LP02DX8@0202<V7`03028U7P0Q91d082<L00807b8K00<07R4J
01hP7@0N81d01P0N81d301dP6@807R4J100O8Q/0200Q91/082<L01lR6`0N81/071hK01/M700J6ad0
6AXL200F71P02`0K7A`071hK01dO700O8A`08B@M02<V7@0T9a`09BPM02h[600`;AX0<RlL0080=34N
00/0<c0M030]6P0_;1T0>3<P03Hc800c<240;2XN02<S6@0N7aT07R0M020R7`0402@U7@@08b@L00H0
8b@N028S7@0R8ad08B8L020Q6`0O81X201hO6A007R4J020071dO01dO7P0N7Q`08B0K02LT6`0/:1`0
<2dN03@^7P0j=1`0?3@Q03da8`10<2<0AC8Q054m8P1RC2D0KEPY08YbA02ENDX0W7a;0:9nC02/QUD0
[XQI09A_@`1aCR@0@CPY03P^8P0[9AT09B8I02DV800W:BH08RPV01`U90P08R@Q0`0T9b0202DX8@H0
9RTR0P0U:24302@W80P09bPR0`0U9R0302HW8@809bPR00H0;2dU02d]8`0^;R@0<BlS03<_8`0f<283
03Pa8@0803L^7@0l<200@SDT04Xi9`1B?BX0FD0/05]0;@1M@B`204Lk9@0404Hi9P16>BP0ACPW04Dh
:080A3HY2012=RH01P14>BL0ASTV04Lj9`1;?2L0CclX0590:080ET8Y201B@RP205U6:0<0F4DW00<0
FTLY05]8:P1LBB/00P1IARH0301HAbT0EdP[05A6:`1@A2X0CD4Y04]1:01;?bT0BCdW04Lj9`14=bH0
@SDT044d9080@C<V00<0?S4Q040c8`12=BD00P13=RH00`12=BD0@3<S03ha8@0203da9@<0?30T00@0
?C4U03lc9`10=2P0=BhV0`0d;BD203</9080<R/S200d;R8803La8`05048`8P14<R@0AcHV04Th9P1;
>RH00P1<?2D03P1<?2<0C48W04a09P1:?R@0BcdS04dm901??BD0DShV05<o9`1B@2P0Dd4Y05A2:P1E
@b/0ET@/0`1GABd205]5;@0405Y6;@1HAbd0F4L]05M7;@80ETP]00H0E4TY05=8:P1BAbT0DDHZ0514
:P1>@RX204e1:`80DD8Q00H0Dd@U05A5:01DA2X0E4@[05=3;01B@R/204/l9`0<04`m:01??bP0DT0X
05A3:@1G@bP0FD@Y05Y5:01MARL0GTLX065::`1SC2d0IDh_0`1VCc002@1WD300J54a06YC<@1/ES40
KUPc075K=01bG3<0Ledd07MQ?00207MQ>P0:07QR>@1jICX0OFPk07mZ>`20Jc`0RFld08ec>02DNSl0
W8970:67C080XhU>00L0XXQ=09f8C`2MQdh0VhE<09Z1B@2JOdP0Vge70080W7a902H0ZX940:b4AP2^
QdH0/8U60;6:A@2aRd@0/H]20;2:@@2ZS4`0Yh]:0:B7B`2NQ4/0VH1:09AmB`2@NTT0SWQ908E^A@24
Jd<0P6Lo07iR>`1mGcT0Oeli085O>P22H3/0S68h091U>P2DJC`0VFdl09e_>`2OL3P0X6le09m^<`2S
NcD0YWhh0:V1>`2]QCl0/8Q20;::A080]8a6202hS4D80;F>B@0<0;B=BP2eST/0]Xm<0;J?C02eST/0
/ha90;6:A`2_R4D0]i1=0;F>B`2`RDH0[HI30P2ZPd003@2[Q440[8E20:J3?`2VPd40Y84o0:5n?P2K
McT0Tflc08eY;`28I2X0Q64Y08IS:`28IBd00P2:Ibl02`28IBd0QV<[08AQ:@1eF2`0M5L[07=F;01b
EBd0LE<]075C;`1bE300LU@b0080N5d`00L0NEha07]P<`1lHC@0OF8e07iS=P1oI3L0P6Xh0080PFXf
00H0PV/g08E/=P27K3D0RF`d08]/<`2<KC@208YZ;`0608][<P2;JS@0RFPb08MV<@24Hc00Pf8_101l
GC4407]L<080P68`0P21Hc43089T<P0708=U<`1iHc40NV<a07UR<01kHC00Nel_07eN;`0207eM;P80
Me/[00@0N5`/07UM;@1jGRh0NUh^0P1kGbl00`1kHRX0O6<[07iU;@03081W;`0<07mV;P1nIBd0PFHa
07YP;@1cFBP0K5@V06UB:01WDBX0HThY061<:@1GBB@0F4XU0P1IBbH01@1HBRD0EdTT05I88`1EAb80
FDXS00<0FT/T00@0FDXS05M88@1EAQl0E4DN0P1JCB40101JCB<0FD/T05U;901HBRD205Q:9`0805A5
901EARD0ETLV05I79P1EARD0E4DT05=48`1B@b870593900c05528`1:AAl0CT<S0592:01HA2`0HdT^
07IH<P2<K3/0Vg]00:j?H@2eUVX0_9me0<6UOP33ZHH0aJf;0<ZcU03>]iP0ak6<0<2ZP`2cVgD0Y8]S
09f1F@2OPUP0[8eQ0;FFJP35Zi@0dk^S0=o7[`3Nb;00g<R]0=_:[P3Gb:/0dL:U0=>iX03;/i40_JIj
0:jHIP2LQe80Qg50075J<01RBRH0Bd</04Dj9013=al0BSXQ04lk8P1B>R00FClV06A9;P1VD2/0J58]
0080JU@_0P1/ES402`1ZE2l0Ie4/06A>:@1OC2/0GT/Z05Y::@1FAbP0DT@W04i39`1<@BD0BClT0080
DClW00<0D3hV04lm9@1>?2@00P1=>b<04P1<>R80@3<P03lb7`0l<Al0>2lN03@]7@0a:ad0;BXK02`X
700V9aT09RHJ02DU6@0T91X08b<K028Q700R8Ad08B0L020Q6@<07b0H0P0N7aL201dN5PP081lJ200M
7QP201`L6P<06a/I2`0J6QP801/K6@P07AhH2`0N7AP201lN6@<081lJ0P0O7aL00`0P81P08B4I028R
6P0302<S6`P08R4L200W8Q`802TU70P0:RHM0P0X91P01@0Y9AT0:RHJ02XV6P0/:1`0;BTM0080;RXN
100a9a/2030V6P80;bDI0P0e;1/00`0g:a/0>2/K03XZ6`0203/Y6`0303`Y6`0i;1/0>B`K0080>RdL
0`0k;Qd0100l;ah0@S8K048b6`12<Q/204<c70<0A3@M0`14<B0204Db8@<0AS<R00H0Bc8N04`c7`1<
<ad0CCDM04hf701?=a/2050i6P<0ESdO0P1G?R0305Po8@06060o7P1Q@1l0HT4P06A38P1VAB@0IdHU
0P1YB2L506=49@0606E69`1WB2T0J4TZ06I99`1UB2H0HTDS0P1P@b401P1RAB<0IDPV06I99`1Q@b40
HdDS06E79@80J4XX00<0IdTW06E79@1SAB<00`1XAbH206U89`<0JTTX00T0KDTW06a89P1[AbD0JTHT
06]79@1/B2H0KTXX06m;:@1`BR<00P1aBb@00`1bC2D0LddV07A>9`0207E?:00907Y@:P1iCbT0MTlX
07A>9`1eCbP0ME8Z07ED:`1gERd0NeD^0080NeH/00D0NeHZ07eH:`20G2`0Pel]08EQ;`0308IP<@80
Qf4b1@28HS<02P29Hc@0RfDf08aV=`2=IcP0SVPi08mY>P2?JSd0SVTl08eX>`2<IcX208]V>@80S6Lj
00<0SFPk08eY=@2>JSH00`2?JcL00`2=JCD0S6Pd08YV<P0308QT=080Qf<c0`26HS800`22GRh0Pel_
08EQ<@0208MS<`0308QT=027Hc<0Qf<c0080PF8c0P22Hc@01023I3D0Q6Df08EV=`25ISL208aW>P80
SFPk0`2>JC`0302?JSd0SV/e08iZ=P2?JcL0Sf/i08m[>`2>JC`0S6Lk08]V>P2:ICP0RfHi08aW>P<0
SFPk0P2<IcX208e[>`0308m[>`2@JS/0TVTk0080TfPk00<0U6Pk099]>@2BKCT00P2CKSX309A_>`09
09E`?02CL3P0U74i09Eb?02ELCd0U70n099^?P2@Jch0SfXm00<0TVe00P2CKT4309A_@P80U70l0P2E
LCd309Ib?P0409Mc?`2HKd40V6m109I`@@80UG5100<0Tg51099b@@2BLT40202JMT8209ag@`80WGQ4
0`2NNDD00`2ONTH0Wg]709mkA`0209ijAP<0WGU500@0W7Q409eiA@2NNTH0X7a80P2ROTX00`2QODT0
X7a809mkA`080:=oB`80Wg]70P2NNTH309eiA@80W7Q4202ONTD409]g@`80W7Q40P2MNDD80:1kA`04
0:9mB@2QO4P0XGa80:5lB080X7]70P2ONTH80:9mB0<0YH1<0`2VPDd20:N2CP80Yh5B0P2XPU<20:V3
E080ZXAE0P2ZQUH30:^7E`<0[8QH0`2]RED30:j:EP@0[h]G0`2^RUH30:f9E@P0[h]K0`2cSe/40;:>
FP060;6=F@2`Rel0/8]O0:n:G@2^RUX0[HUG0P2/R5@00`2[R580Z8=?0:R3C`020:N2CP<0YX5=00<0
YH1<0:N3C`2WPdl01P2WPdl20:R3CP80Yh9=102VPD`30:AoBP80Xgi90`2RODP209iiA00409eh@`2L
Md80W7M209]f@@80VWE00P2IM400102HLcl0Ug8n09Qc?`2JMD4209ag@`0309ehA02LN4@0W7Q400H0
W7Q40P2IM3l0102JMD00VgI109ag@P2LMd8209eh@`<0VgQ20P2LND<309ejA080WgY=00@0Wg];09mk
B@2ONdL0Wga60P2OO4@20:9mAP80XGa50`2PNd@0102ONT<0WWY609mkA`2QODT20:9nBP030:5mB@2O
NdL0WWY60080XWe80`2SOTT02`2RODP0X7]609mjA@2ONdL0WWY609eiA@2KMd<0VGE109Mc?`2FLSh0
UG4m0080UW4m0P2GLSh0102HLcl0VGA009Ye@@2JMD4309UeAB_ooooo000Zooooo`@0Yga90P2VNdP2
0:EjA`80Xge>0P2RO4d20:5kC080X7Y;00<0YG]90:AjB02TNTP01@2TNTP20:EkB`040:EkB@2UO4P0
YGa80:ElAP80YGa40`2UNdT30:AjB080XgU70P2SN4<0102TND@0YGY50:IkAP2WO4L20:QmB0060:Al
?`2TO440Y7a10:Ak@`2TNdD0Y7]70P2TNTP20:QoB`<0Ygi:0`2VODT80:AkA`030:=jAP2TNdL0YWe9
00<0Ygi:00L0YWe90:AkA`2SNTH0YGa80:AkA`2SNTH0XGQ400<0X7M300H0XGQ409ag@`2LMd<0VgI2
09Ye@@2IM40209Qc?`0909Mb?P2JMD40VGA009Mb?P2EL3`0TVdi091[=`2>JCD0SFPd00<0RF@g1P28
HcH00`26HC@0Q5lb085L;`03081K;P04085L;`1lFC40NeP`07UF;P80N5D]00H0NEH^07]H<01lFC40
M5L_07=F;P1aE2`206mB:P04071C:`1aE2`0LUD]075A:P80L50Y00D0KdlX06e=9P1/C2D0K4`U06];
900206iB:P@0Ke<[0P1`E2`207]H;P0307aI;`1mFS00OU/a0080Oe`b00D0P5dc08=O;`24H300Qf<c
08UU=@0208YV=P0308UU=@28I3@0S6Hg00<0S6Hg0P2=IcP608iX>@@0SfTj00<0RF<d08YT=@2<ISL0
0P2=IcP00`2<ISL0RV@e08US=00308]U=P80S6Hg0`2=IcP00`2?JSH0SFPd08YU<@0208UT<00308aW
<`2@JcL0TVdi00<0SFLh0`2>J3T208mY>P0308eW>02>J3T0SfTj0080T6Xk00<0SfTj08iX>@2=IcP0
2@2?JCX@08eW>0T0SfTj0`2>J3T208eW>080S6Hg00P0RfDf08eW>02?JCX0T6Xk095[?02@JS/0SfTj
08iX>@D0S6Ph0`2=JCT808]V>@<0RfLg00<0RVHf08UU=@29ICD00P28I3@808MU=`<0R6@d0`27Hc<2
08IR<P0508YT=@29Hc@0RF<d08QR<`26H3400P25Gc001`24GRl0Peha085O<@20GS00OUh_07eN;`1j
GRh00P1hGRd207=N;`0O075L;`1_FRl0KUP_06aF;`1ZE2d0JU@_06Q>:@1UCBT0H4TW05Q59@1A@RD0
BclU04Pn9@15?BH0@3TM044j8012>b40@CTR040h8`0n=R<0?3<R03Xa800d;R00<2dN02hZ7P0Z:1`0
9bLM02DV7P0U:2409RTR02@W800202<V7`05028U7P0P8a`07b8K01lR6`0N8AX0200N81d401dP6@80
7R4J0`0O8Q/01P0Q91/082<L01lR6`0N81/07AlL01/M70806Q/M200F71P0600J71/06adL01`N6`0N
81/082<L028U7P0S9Qd092LN02/X5@0]:QL0<BhK03@a7P0e<Ql0<c0M034^6`0_;1T0=C0M03Hc800g
=2D0<BlS02HV700O81X071hK01dO70@08b@L100T9Ad202<T7P03028S7@0Q8Q`0824K00807b0J00<0
7QlI01hQ6P0N8AX03P0N8AX201hO8@0N01lO7@0Q81`09B8K02XV6`0]:Q/0<B/M03Ha6`0i<R00?38V
03la9P14<b<0CSXQ05Y77`1TCb00Q6Tj095eAP2HNDX0VWQ80:N1DP2bRUT0XWY908QN;P1?@S40@3@T
02lU6@0U8AH09BDM02LY9P0S:BT07BHU200Q8b0302@W80809BPQ1P0V:B8202DX8@<092LP200V9b40
0`0U9R009RLQ02HW8@0202LX8P80:2TS00P0:BXT02X[8`0Z;240;BdS030^8P0c;b<0=34R03La8@80
>38R0100>C8R03`c8P12=RH0BSTY050k:P1F>bX0F3/Y05Xk:@1:?RP0BCdW04Tl:@18>bX0ASTX04Dh
:015=bX0A3HY2012=RH02@13>2H0ACPU04Hi9P19>RD0C3`U04hl901A?B@0DShU04lo9@0205109P0M
05519`1C@bT0E4@Z05A4:P1EAB/0F4DW05M49P1F@bD0ED8T05I39@1GA2H0FDHX05Y7:@1EAB@0ETHU
05E69`1DART0DDHZ04i2:01;@BP0BClV04a0:P1:?RP0AcXW04@g9P12=B@0@C@T044c9P12=2L00P13
<b@204@d9@0=04De9P14=2D0A3@U04@d9@0n<RH0?C4U03``900k;b<0?30T03hb9P10=2P0@CDY03H_
9`0303D^9P80=2dU0P0c;2@503@^8P<0<bdQ200d<B801@0n;Ql0@30Q04<c8`16=b@0B3TT0080BCXS
00T0BC/Q04]19P1;?bD0BCdS04Xl8P1;>b80C3XR050l901A?BD00`1A?bT00`1B@2X0Dd4[05A2;002
05E3;@80FD<[01H0FDD/05Q7;@1IB2h0FTX`05U;<01JC340FDl/05Q=;@1GC2h0E4T]0596;P1?@bd0
CD0]04`o;P1BA240Dd@S05E69@1GB2T0F4T/05Q8;P1GAbh0ETH]0P1=?RT02`1>?bX0D40Y05=1:@1E
A2X0F4@Y05]6:`1LAbX0GDHW05i7:01QBR/0Hd`]0080I4d^00X0Hd`]069;;01WD300J54a06YC<@1/
ES40KeTd075K=01cGC@0M5he0P1jI3d0501iHcX0N6<h07UT=`1kISL0OVTj07m[>@29KBh0Sg<d09Mk
?02OPd@0Y8Q90:F9BP2TR4T0XXI70::>D`2QRe40WXQ?09j5C@2MPTd0WX1<0P2PP4l09@2[P4/0Zh19
0:Z0AP2[PDD0[8=30:j5@`2_Qd80/HU30:n9?P2^R3l0ZhI00:J5@P2QPT80W7m509QnA@2FODD0S7Y8
08agB029M4D0QVm308=[?`22ISh0PF@l081S>`24Icl0QVHm08UX?@2<JSX0T6/g09=/=@2EKC80UV``
09U_<`2KLCD0WgDi0:Aj?P2WOD400P2ZP4@00`2[PDD0[H4j0:f1>P060:f1>P80ZX@m00<0ZhDn0:b6
?`2]Qd000P2_RD800`2`RT<0/8U60;6:A`020;:;B00=0;6:A`2^Qd@0[8E20:^4@@2]QT<0ZX=00:Io
?02SO3T0XGXg0:9k>02TOCX0YGhk09ai=@0209ai=`0809Uf=P2DL380SVX^08MS:@23GbD0O5L[07iI
;@21G30208AO<`0;089M<@1oFRh0OEP/07AH<01cEbl0LED^071D;`1`Dc40LE@d079E=@1cESP00P1i
HbX0101kIB`0OFL^07mY<020JS42089/<`<0PF`g00L0PV/e08=Z<P24JS40QVT_08EX;P26J2`0R6X^
0080R6T`00D0R6Tb08IW<@24I340PF4`07mO;P0707YK;`0307]L<020HS00P68`00@0PF<a0P22I380
1P1gHC00N60`07QP<01jGc00NUh_07aM;`80OE`_0P1fFRX02@1gFb/0N5`/07UM;@1jGRh0Nel_07aP
<01kHRX0OF@/07iU;@02081W;`0=07mV;P1nIBd0OF@/07iR<01fG2T0KE8S06M?8`1VCbH0IDlX061<
:@1MBBH0ETTV05M:9`0305U<:@0605M:9`1EB2D0E4LT05E67`1FAb00F4TR0P1IBR<02@1HBB80EdPQ
05I7801JCB40FD`P05U<8P1IBb@0F4XS05Q:9@0205M99P0405I79P1EARD0E4DT05=48`80DT<R00<0
Dd@S05A5901CA2L00P1B@bH0=`1A@RD0D44T04m08`1?@2<0CSlR04U38@1=@R@0DT8Y05Q4;01TBbd0
N5/c08m_?02NOT40[i1R0;JGJ`2lWgD0`JEn0<:XQ@35[H/0b[>D0<nhV@35[hH0_JMn0;2IL02RRF00
WH5I0::5G@2bTVT0_Ied0<R]V03F_JL0h<R`0=k8/03Kaj`0fLR/0=C5YP3=_Yl0c;>E0<:ZQP2bVfl0
XHaG08mjA@1kICH0IdlY05Y28019@Rl0@c/X048g8`1;>b@0D3`T05@j8@1K@2D0ITP^06=?;01TD2d0
0P1VDRl03@1WDc00IU8_06=?;01OBbP0G4PU05Q89`1FAbH0E4DV05129@1<@BD0B3hS04@m8`13?280
0P1;>b@0101:>R<0BCTR04Ti8P18>24204Lg8009040e8`0o=280>c8Q03L`800b;1h0;BXK02/W6`0Y
9aX09BDI008092@J00<08b<K028Q700R8Ad00P0Q81h201lP60807QlG0`0M7QH00`0L7AD081lJ020O
6P06020O6PP071dG0P0L71X301/K6@/06QXH200K6aT801`M5`X07A`G0P0N7AP301lN6@03020O6P0Q
8AT08B4I00H08B4I200Q81`802HQ6`P0:2@K200Y9A`302PV6@80:BLJ00@0:RPK02/Y700[:A`0:bTL
0`0a9a/00`0`9QX0;bDI02lU6@0202hT6080=B`K00<0=b/K03P[6`0i:AX00P0j:1X0100k:1X0>B`K
03T/6`0i;1/203X]70<0>bhM00<0@34J044b6`11<Q/00P11<Q/3048c7080@c0O0P14<B0304Db8@09
04Hc8P1;<Qh0Bc8N04`c7@1==Ad0CSHL04lg6`1?>1T0D3TJ00@0EChO0P1F?b0205M08@0;05ln7@1P
?ah0HD0O06=28@1UA2<0IdHU06U89`1ZBBP0HD8U06939P1SA2L00`1TABP01@1SA2L0HT<V06A::@1Q
AbH0GT@S0080G48Q00L0GT@S06579P1TBRT0FchN05i18@1RABD0ITTY0080IdXZ00<0IDPX06=69P1W
ARL00P1WARL206Q7:0<0JDPY00h0KDTW06a89P1[AbD0JTHT06]79@1/B2H0KTXX06m;:@1^B240KdTR
071:8`1aBb@0LT`U07==9P80M4hW00<0NDlY07Q>:01eCRL00P1cCBH0101cD2P0Le8Y07ED:`1iDb`2
07UD:P0507YE:@1lEbX0Oe/[085M:`23Gbd00`26H34208MQ<P<0R68c00`0Qf4b08QR<`29Hc@0RV@e
08aV=`2=IcP0SVPi08mY>P2?JSd0SVTl08aW>P2:ICP208UT=`0308YU>02;IST0S6Lj0080RVHb0`2<
J3@00`2:IS80R6@`08MS;`0208MS<`80QV8b0`25HC401024H300PUh^08=O;`25HC4208IR<P0308EQ
<@24H300Pel_0080PF8c00<0PV<d08=T=@24ICH00P25ISL00`26IcP0RFLj08YX>`0208YX>`80RfTl
0P2<JSd0402?K3H0SVXf08eY=@2<J3H0RfLg08aW>P2<Ic/0SFPl08YU>02;IST0S6Lj08eX>`2<IcX0
RfHi08UT=`28HcH208]Y>@0308eY>@2>J3T0T6Li0080TFHi00<0TVHi095/>02BKCT00P2BKCT209=^
>P80U6lk0P2CL3H01P2DLCT0U70l099^?02@Jch0SVTm08aW>`<0TFa00P2BKD4309=^@P80Tflk0P2D
L3`309Ea?@0909Ib?P2EK3h0UF`n09A^?`2DL400UG5109Ab@P2CLd80U7A300P0VGE100@0VgI209ag
@`2LMd<0W7M30P2MN4@209iiA@<0WWY60P2MNDD409ahA00709eiA@2ONdL0XGe90:9nBP2QODT0X7a8
09mkA`080:5mB@<0WGU5102LN4@209]g@`P0WWU40P2IMD4209Yf@P0409]g@`2LN4@0W7Q409ahA080
X7]71P2ONTH20:1kA`80WgY60`2NNDD00`2MN4@0X7]60:1kAP060:1kAP80XWa;0P2SOD`0102TOTd0
YGm>0:EoCP2UOdh30:J0D@80Yh5B0`2XPU<30:V5E@80ZXIF0`2[QeL40:b8E0<0ZhMC00<0ZXIB0:j:
EP2^RUH00P2]RED0102/R5@0ZhMC0:^7D`2[Qe<80:j:FPH0[h]G0P2`S5P0202`Rel0[hYN0:n:G@2^
RUX0[HUG0:b8E02[Qe<0ZhQB0P2WPTh20:J1C@<0YH1<00<0Y7m;0:F4C`2UQ4l01P2UQ4l20:V4C@80
Z8=<0P2WPT/20:J1BP<0Xgi90P2RODP30:5lA`80WGQ300<0W7M209]f@@2JMD000P2IM3l0102HLch0
VWE109Ud@02HLcl209Mb?P0409Ud@02JMD40VWE109]f@PP0VWI20P2GLSd00`2HLch0VG@o09Ye@002
09]f@@0309ag@P2HMd40V7M10080VGQ20`2JND<02@2KNT@0VWM=09YhB`2KND/0W7Y:09elA`2MO4H0
WWi509in@`030:5lA@<0X7]40P2ONT<00`2NNTH0Wg]70:1lB0020:5mB@0;0:1lB02ONdL0WWY60:5l
A`2RODP0Xgi90:AoBP2SOTT0XGa709mjA@2NND@00P2NNTH01P2LN4@0VWI209Qd@02FLSh0UG4m09A`
?080UG0l00@0UW4m09Mb?P2HLcl0VGA00P2JMD4309YfAR_ooooo000Zooooo`040:QmBP2WO4T0Yga9
0:MlB@80YW]80P2UNTL0102ROE00XGa?0:5lC`2PNdh209mjC@80WWU<0P2SNDL30:AjB0<0YG]90P2V
O4`0102VO4X0YWe90:ImB@2VODL20:ImA@<0YG]90`2TNTP20:=iA`060:9g@P2SN4<0Y7U40:EjA@2V
NdH0Yga70P2XODP01P2TO3l0Y7a10:Al@@2TNd<0Y7]50:AkA`80Y7Y80P2YP4`00`2XOd/0Ygi:0:Im
B@020:ElB0T0Y7]700<0XgY60:ElB02VODT00`2XOd/02`2VODT0YGa80:=jAP2WOTX0YGa80:9iA@2O
MT80WWE109mf@P2QN4@0XWU50080W7M300<0VgI209Ye@@2IM4000P2HLcl02@2GLSh0VWE109Ud@02G
LSh0UG0l099]>@2@JcL0SVTe08eX=00408UT=`D0R6<f00<0QV4d08=N<@20Fbh00`1oFRd00`20Fbh0
NeP`07YG;`0307QE;@0607YG;`1lFC40OEXb07AG;`1cERh0LE@/0`1_DRX0201aE2`0LUD]075A:P1a
DBX0L50Y06m?:01]CBH0K4`U0P1[Bb@306iB:PD0Ke<[0`1kF2h207aI;`<0OEX`00P0Q60`08EQ<@27
Hc<0RFDe08YV=P29ICD0R6@d08IR<P80RV@e0P2;ICH208aV=`80SFLh102>J3T408mY>P0308US=02:
I3D0S6Hg0080SFLh00<0S6Hg08YT=@29Hc@00`2;ICH208aV=`<0SFLh00P0RfHb08UT<027HRh0QF0/
08IQ;@29I300SFPd08mZ=P<0SVPi0P2?JCX3091Z>`0308eW>02>J3T0SfTj0080T6Xk00<0SfTj08iX
>@2=IcP02@2?JCX@08eW>0P0SfTj102>J3T208eW>080S6Hg00P0RfDf08eW>02?JCX0T6Xk095[?02@
JS/0SfTj08iX>@80SFTi1P2<J3P808]V>@0408aX>02;IcL0RfLg08YV=P80RFDe0P28I3@808MU=`06
08YV=P29ICD0RFDe08QT=027Hc<0QV8b0P25HC4208YT=@0408US=028HS<0QV0a08EO<080Q5h_00H0
Peha085O<@20GS00OUh_07eN;`1jGRh207QN;@80Leh_01h0LE`_06mJ;`1^F2l0K5H_06YD;@1ZE2l0
JU0[06I>:P1OB2H0Ed@T04m08`1:?R@0B3hU04Lo:011>Qh0@CXP048k8@12>R<0@CTT03lg900l<b80
>c8Q03@^800`;Ah0;RXN02XX700V9Q`09BHN02DX8@0V:B8202@W800302<V7`0R9Ah08B@M00807b8K
00<07R4J01hP7@0N81d01P0N81d0100L7aP07B0I01dP6@0M81T201hQ6P<07b8K00H08B@K024T7@0P
8a`07R0K01dO700K7A`201XK7@P05Q`H01H06Q/M01/M700L7Qd07R0M020R7@0R9Ah08bHM02@W7P0Y
9Q<0;2TF030]6P0d<Ah0=C8O03@a7P0b;a`0<2dJ03<^6`0e<Ql0>CHW03@b9P0Y:Al07b0J0P0K7AX4
02<T70@092DM0P0S91h0100R8ad08B8L020Q6`0P8A/201lP6Q007R4J02007b0T01hO8@0O7al08B0L
02@Q6P0X91T0:bLK02hX6P0e<1X0=c8O03`b9P10<RL0A38T04Xi7`1F@Qd0GD/M07iR<`2=LD80UWM8
09EeAP2ROTh0]8aK0:f1D02HJST0F4Tf04Hi:00`9aP09R0D02@T700U:RH092XZ01hX:@P08B<P0`0T
9b0202DX8@H09RTR0P0U:24302@W80X09RLQ0P0W:2802`0X:B<0:BXT02TZ900Z:bD09bXQ02T[800[
;B80;RhR038`8`0e<R<0>38R0080>C<S0100?CLW03lh:014>2P0BcXZ04lj:@1C>2L0ECDV05He901<
@2X0BclY04Xm:P19?2/0AcXY04Hi:@15=bX0A3HY2012=RH01P11=R@0@cHS04<f8`16=b80B3PQ04Xh
8080CCTP01h0Bc/Q04`l8P1>?R@0DD4W05=3:@1FAR`0F4P^05U9;`1EA2H0E4<U05918`1A@280DT4S
05A39@1FABL0EdHX05A48`1EAB@0E4DV05=5:01@ABT0C48W04Y09`16?bD0C40Z04Xn:017>RL0A3LV
048e9011=2@2048d9`H0A3@T00/0ACDU04Hf9P0n<RH0?C4U03``900k;b<0?30T03hb9P10=2P0@SHZ
03L`:00303H_9`80=BhV0P0d;BD403@^8P@0<bdQ200d<B801@0m;Ah0?blP048b8P15=R<0AcPS0080
B3TR00T0B3XP04Y09@1:?R@0B3`R04Tk8@19>B00BcTQ04hj8P1?>b<00P1??BL2050n:00L054o:@1C
@B/0E48/05A2;01G@BT0F48Z05Q4:`1HAbd0FTT_05];<@1KCC80G4hc05eC;`1LDRl0FDh^05I;;`1C
Abl0D4@^04e0;`1<?bh0DdDR05A68`1GB2L0FDX[05Y;;P1JBS00FDT_05Q8;`80CSlZ02<0Cd0[0551
:P1C@BT0ED@Z05U5:P1LAb`0GDP[05e69`1NAbP0H4TZ069;;01SC2d0HT//0619:P1OB2T0ITl_06QA
<@1YDS00K5Ha06mI=01aFc@0Ledd07AN=@1mId00NfDl07YT>`1iI3T0NF@g07YU=P1lJ3H0OVXh08Y]
:`2?LS00V7/i0:23@@020:F8AP0_0:>6A02RQD<0Y91C0:B>E02PRU00X8M?09n4C`2QPe40XX9A0:>3
DP2XND/0YWQ70:AfA02SMSl0XgHm0:Ij?@2ZOSl0[80o0;:5<P2_Q3D0[H<g0:R2>@2SP3`0XGlo09an
@02LOT80TH9;0960BP2?OTX0SGU708Uc@P25KCl0PfPm085V>`20JT<0P6U0085Y?@24J3T0R6Pe08][
<P2?KC00TFd_095V<@2DJC@0V6dh09eb?@2PMD000`2SN4<80:Mh<080Xg/e00@0YGdg0:In>02XP3X0
ZX8l0P2/Q3h04@2^Qd@0[hQ50:n8A@2_R4D0[XM40:b5@P2YPSl0Z84n0:En>`2RNcP0WWLd09]d<@2J
Lc00Vg@a09ig=02PNCH0Tg0/0080U74_00P0Tg0`08m[;@29IBT0PelU07mK8@1gDBd0NU@`07eG<`80
P5Xf01@0OUPd07]E<@1iDbl0M5/c079I<@1aEc80KeDb06mE=01aESP0LePj07AI?01jIRL0NfLX07aX
:@1nJR/0PFd^08=_<024L340QG4b085]>080PF`e00H0P6/d081Z<@21J2l0PFL/089U:@21I2P208MX
;`0608QY<P27J380QFDb08=S<020H2l0OUh]101iFC0407YJ<@<0P64b1@21HS<01P1fH2l0Mel_07MO
;`1iGRl0NUh_07aM;`80O5/^00h0METY07IJ:P1gFb/0N5`/07UM;@1jGRh0Nel_07aP<01kHRX0OF@/
07iU;@1oIRh0P6L_07mV;P80OF@/00/0OF4_07AJ:@1ZCb00I4`P06A=901TCRT0Gd/X05a89`1GBRL0
F4/X05U<:@0205Y=:P0705Q;:01FBBH0E4LT05116P1B@a`0EDHO05Q98P0305Y;900705U:8`1IC200
FD`P05U<8P1IBb@0F4XS05Q:9@0205M99P0805Q9:P1FAbP0Dd@U05528`1@@B80DD8S05A59P1EARL2
05=49`0h05939P1@@B@0Cd0S04ho8P1=?R40C3dP04Q2801=@RH0DT8Y05U5;@1UC2h0NUde095b?02P
P4<0/95S0;JGJ`2mX7H0`JEn0<:XQ@35[H/0b[>D0<nhV@33[H@0^jEl0:jGK@2QR5l0WH5I0:B7G`2f
UVl0`Z9k0<Z_W03G_ZP0hLRb0=k8/03JaZ/0elJX0=72X`3:^iX0aZf?0;^SO`2YTf@0Uh9=08E`>`1b
G2d0H4PR05Dl7@18@c00@S/Y04<h9P1;>RH0DCdU05Dk8P1M?bD0J4T]069>:`1SCb`306EA;P0<06A@
;@1PC2T0FdLT05U58P1DABH0Dd@U05129@1<@BD0B3hS04@m8`11>b40@3XR0P16=Ql204De7P0<04@d
7@13<a`0@c<L04<c7012=bD0?SHS03`c8P0g<200<R`N02dY7@0Y9aX0:2HJ0P0S9AX01`0R8a/08B8J
024R700P8A`0820N01lO7@0O81P00`0N7aL201dN5P8071dE200P7aX801`M5`8071`J0`0K6aT;01XJ
60P06a/I200L7AL:01dL5`807QdH100O7QT2028R6P<08B4I0`0P81P8024P70P09R4K200X91/802TU
7080:2HI100Y9aX302XX6`80<BLK0P0`9QX0100_9AT0;R@H02hT600]8aL203D/6`0303L[6`0g:QX0
>BTJ0080>RPJ00@0>bPJ03T/6`0i;1/0>B`K0`0j;A`203/^7@80@34J1P11<Q/304<`8@80A34R0`15
<R<01P1:<Ad0Bc8N04/b701<=1`0CCDK04hf6P80CcPI00@0E3dN05Dn7`1E?Ql0EChO0P1F?b0205M0
8@0;05hm701O?Qd0HD0O06=28@1UA2<0IdHU06U89`1ZBBP0H44T06939P1TABP00P1UART01P1SA2L0
H44T05ho8P1RBRP0H4PV05a48P80FT8P00L0G4@R06189P1RBRP0FC`L05`o7`1QA2@0IDPX0080IdXZ
00<0IDPX06A79`1WARL00P1WARL206Q7:0<0JDPY00T0KDTW06a89P1[AbD0JTHT06]79@1/B2H0KTXX
06m;:@1]Ab000P1^B2400`1`BR<0LD/T079<9@0207==9P0307Q>:01gCBL0M4dV0080LT`U00@0LTlW
079A:01cDRT0N58[0P1hDbT01@1iE2P0NeHY07eI:@20G2X0PUh/00<0QV0a0P27HC8308QR<`0<08IP
<@27HC80R68c08YT=@2<ISL0SFLh08iX>@2?JCX0SfXm08iY?02;IST0RF@g0P28HcH00`29I3L0RVDh
08]V>@0208QT<0<0RVHb00<0R6@`08IR;P25HBd00`26HS8208EQ<@<0Q60`00<0PUh^08AP<025HC40
0P26HS801@24H300PUh^081L;01oHc<0P6@d0080PFDe00@0PVHf08=W=`24J3P0Q6Ph0P29IcX208YX
>`<0RfTl0140S6Xm095^>02?JcL0S6Pd08YV=029ICD0RVDh08eX?02>JCd0RVDh08]V>@2<IcX0SFPk
08aW>P2:ICP0Qf8e08EP<`0208YX>00308aX>02=IcP0SfHh0080T6Dh00<0TFDh095/>02AK3P00P2B
KCT309=^>P0909A_>`2BL3<0Tg0f09=`>02CL3X0TFdk08mZ?@2<Ic/0RfHl0080T6/o0P2AK403099]
@@0409=^@P2CKc/0Tflk09=_>`80U70l0`2ELCd209=Z?P06099/?`2CKT40UG1309AbA02DM4D0UGE6
202IMD4209]f@P80W7M30`2MN4@00`2NNDD0WWY609ijAP0209eiA@<0W7Q40P2KMd<00`2MNDD0Wg]7
0:1lB0020:5mB@030:1lB02ONdL0X7a800L0X7a8102LN4@509]g@`P0WWU40P2HM400102IMD40VWI2
09Yf@P2KMd<209ahA0030:1kA`2ONTH0WgY60080WgY60`2NNDD209mjAP80WWU50`2MN4@00`2LMd<0
X7]60:1kAP0409mjA@80WWU40P2QNdX20:9lB`040:=mC02TOTd0Y7i=0:EoCP80YGmB0P2VP5<30:N1
E0040:R2E@2XQ5@0Z8AD0:R4E080ZHEE0`2ZQUH20:b8E0040:^7D`2ZQU80ZHEA0:V5D@80Z8A@00@0
[XYF0:f9E@2]RED0[8QD0P2[Qe<20:Z6DPP0[HUI0P2ZQU820:^7D`80[8QD0P2]RED20:n:GP030:j9
G02]RET0[8QF0080ZhMC00@0ZXMA0:J1C@2VPDd0YX5=0P2UP4`30:AoB`P0YHA?0P2ZQDh20:V4C@05
0:R3C02WPT/0Yh9;0:J1BP2SOTT00`2RODP20:5lA`80X7]60P2LMd802@2KMT40VWE009Ud?`2IM3l0
V7<n09Mb?@2KMT80VWE109Qc?`0209Mb?P0409Qc?`2IM400VGA009Ye@@P0UW8n0P2FLC`0102GLSd0
V7<n09Qc?P2IM3l209Ye@080V7M10P2IN48409Yi@`0809QeC@2IMT`0VWQ;09]iB@2MO4T0WWe709mo
AP2OOd@30:5lA@80X7]40`2ONT<00`2MNDD0WWY60:1lB0020:5mB@0;0:1lB02NNTH0WGU50:5lA`2R
ODP0Xgi90:AoBP2SOTT0XGa709mjA@2MN4<00P2NNTH0302LN4@0VWI209Qd@02FLSh0U70l09=_>`2D
Kc/0UG0l09Ia?@2GLSh0V7<o09Ud@080VWE10`2KMdL[ooooo`00:_ooool01P2WO540Yga?0:IkCP2V
O4`0YG]90:ElB080Y7]500H0Z7e:0:MlB@2WO4T0YW]80:EjA`2TNDH20:=hA@080:9fA`2SMdP0Y7Q9
0:IjB`2WNd`0ZGe>0:YnC`2[Oe020:MnBP80YWe90P2UO4P20:AkA`030:MlB@2VNdP0YGY70080XgQ5
00`0YGY70:IkB02WO4T0Z7e:0:MlB@2TNDH0XWM40:5f@`2RMd@0XgQ50:AiAP2WMD@20:EeA0030:Af
A02RMd@0XGQ40080X7Q400D0Z7m;0:MnBP2WOTX0YWe90:ElB0020:AkA`050:=jAP2SN4D0Y7U60:Ai
AP2UNTL00P2VNdP20:MlB@040:AkA`2UO4P0YWe90:ImB@80YGa800<0XgY60:5hA02PMd<00P2QOD<0
0`2PO480Wg]109ij@00209ei?`0309ah?P2HLcl0V7<o0080V7<o102IM400202BK3d0Tfdn09E_@02E
Kd00U6ho099/?@2?JCX0SVPi0P2<IST00`2;ICP0RV@g08US=P0208QR=@0908MQ=025HC40QF4a08AO
<P23GS80PUdc085K=020FSD0OeTd0080NUL_0`1kF30307aI<@0607aE;P1kE2d0Ne@]07YC;01iDR/0
N54Z0P1gD2T01P1eCRd0Ldl]07=?;@1bD2d0L4l/06i@;080KE4/0P1^Cc001P1^D2h0KDl[06e?:@1]
D2P0K4lW06a?9@80N5P_00H0MeL^07QH;`1jFS40O5`c07mO=P21HCP208AO<P0608EP<`26HC@0R6<f
08UT=`2:ICP0RfHi202>J3/3095V>@D0T6Dh2P2>J3/0102=IcX0S6Hi08aV>@2;ICP208YT=`0308aV
>@2=IcX0SVPk0080T6Xm00/0SVPk08eW>P2<IST0T6Xk08]U=P26H340Qf4b08aV=`2@JS/0SfTj08aV
=`0208YS>00608]U>02<ISL0S6He08eX=02>JCD0SVTd2@2?JSH808eX<`80S6Hi0`2=IcX308iX>`03
091Z>`2?JCX0SVPi0080SFLh00h0SVPi08mY>P2@JS/0S6dd08]/<`29JS<0RFXd08UY=P2:JST0S6`k
08e]?P2>J3/0SFLj08]U>080RV@g00<0RfDh08eW>P2>J3/0202<ISL208]U?P<0RV@m0`29Hc`00`2:
ICP0R6<f08IQ=00208EP<`0308IQ=028HcH0RVDh00P0Qf4j00H0QV<k08IS>@25HSP0Q68e08AR=023
HC42089Q;P<0Pf4c00<0PV0b085O<@20GS000P20GS009`21Gbl0PV0`089P<P23HC@0PUle081M=@1m
FS@0O5Tc07eL<`1lFc80NUXa07II;`1cF2d0KeL[06eE:@1[E2P0IU0[069>:`1OBbX0FDHX05919`1<
?2D0AcPS04Hg9011>Qh0@3TO03lh7P0n=Ql0?3@O03/c800j<B00>C0O03<]7@0`;A`0;BXK02TW6P0V
9QX092HK02@W700202@W7P808bHM00<08RDL024T6`0P8aX00P0O8QT401dO70@07R0M2@0L8Qh201lR
6`8082<L00@07b8K01dP6@0J7AH06A`E200G7A/01P0L7Qd07AlL01dO700N81/07b8K020S6P808B@I
00D092PJ02HZ700Z;1h0;RlO03<b800203@a7P0A03D`700c<AP0=C<L03Ld8@0f<RH0<B`V02/V8`0U
7b408Q`P01lP6`0Q8Qd08b@N02DV7P0V:1d09RPK02DW6P0T9QP00P0R8a/202<T7004028S6`0P8AT0
7QlG01dN5PP07b0J200N8AX0800K71H071dG01dN600O81X08B8L028S7@0S91h092DO034V500j;ad0
@cHS04Df8@11<AX0@c4I04`j8P1G@bX0Me/d08AX@@2?LTP0TgM809j0CP2[ReP0ZHQB09imA`1`IS40
CdDQ034X6@0/8bP0;2Hb02DT:@0O8Q/07B@B100R924402<U8PP09BPQ00H09bXS02HY8P0V:B8092LP
02<V7`0R9Ah2024T7@P09BDS0P0T9Al0100U9R009RLQ02HW8@0W:28202PY8`0702X]9P0[;RL0;BhV
02l_9@0b<2@0=C4U03Hc900203Pb900N03da8@0o<b<0A3LV04Tj9`1=?2P0CS`X04hl9P1@>bH0Bd@X
04Y3:@19@RP0AclX04Dm:014?2T0@cXY048i:010=B40@CHR048g9@13=bL0@cLY044e:@10=2P0?c8Y
04Hh:`18>2/0BCTZ04/j:P1<>BX0CcXY0P1A>RP00`1??BL0D3hX054o:@020590:P05054o:@1@?RP0
CcdW0590:P1A?bT00P1??BL07@1@?RP0DT0Z05E3;@1FA2h0GT@Q05i68P1MARH0FTLW05I7:P1@A2X0
CD<Z04U1:P1>@RP0CD4Y04a0:01:?RP0AcXW04Dh9`13=RH0@SDU03d`800o<R80@C@T04<f9P14=bL0
@cHV048e9@11=2@0@3@X00H0?c<W00T0?S8V03`c900k<R<0>S0T03T_9@0g;B@0=R/U03DZ900d:BD0
0P0b;20203<]8@80=2hR0P0e;b<00`0i;2<0>RdT03`_9P0203d`9`0C03`_9P0j;B@0>B`S03Xc:@0k
<RT0?3@Y03hd:011=BL0@cHV04De9P16=RH0ACXV04Hi9P17>RL0BCXW04/j:01<>BP0CSTX04lj:@02
058l9`0N054k9P1B?2L0E3hY05I0:`1I@bh0FdD`05]:;01LBBT0FdPX05e9:01QBRP0IDdY06Y@:`1]
Dbh0IU<b06=@;`1MC2h0F4P^05A5;P1@A2h0D4<b04m4<P1??R@0DT4W05I5:`1IB2h0FTT_05Q7;@1E
A2X0Dd8X0P1A@BX01`1A@R/0Dd@]0596;P1AAbh0CdP^04a6;01;AB/00P1AARX07P1DAR/0EdH/05]5
;@1PARl0HTH`06E6<@1ICb/0G5</069F;P1VFbh0JUh^06eP;01_Gb/0Kf0Y07YV<`1lIc80OFPc081Y
<`25K3@0R6he08]^=02<KcD0RVm408iaA@2BMTH0V7Y409an@P2OP400XH0m0:60>`80/HU<02l0[hU;
0:b:B`2YRd/0YXe;0:F>B`2RSDX0Wh5;09n0BP2POdX0XWi:0:AlB@2VNTT0Z7Y90:UiB@2/Pd40[8@o
0:b4?P2/QCX0[8Df0:b6=@2/QS<0[8Ha0:>0B02POdT0WWm909UnB@2CO4X0SWQ908QfB026LdP0QgE3
08QfA029MdL0RGM908QeBP25LTP0PVm5085^AP24LdD0Pg5308=^@@25KD40RFi3091`A`2EM4/0VWM?
09ad@00209]c?`0309Yb?P2ILCd0V70l0080Uflk00H0VW@e09]e=P2KMCH0W7Hg09ih>@2ONCX20:1j
>`80WGTm0240WWXn09mk?`2NNSh0VgLk09Qd>02GLcL0VWLm09Md>P2CL3H0T6dc08i[<@2@KC<0TVle
09Aa=`23JC00Q6Tb08EZ<`25JSD0PVHd07iR<P1iGBh0MUX[06e><@1_D340LE8c06mA;`1^D2`0LE<]
07QK<`1nHCT0MV0_07MQ<01jI3<00`1lISD02`1jI3<0NF<b07QS:P1kIRd0P6/b08E`=`28LcX0Qg8i
08Ia>024KcH0TG@h0080Sg8f00<0S6le08U/=027JC<00P26J3@03026J3H0SFPk08IT=P20GS00OUh_
07mP<@1nHS80Nf4`07UO;P1hFc<0MUTa07=F;P80LUD]00<0MEP`07UL=01lGcL00P20H2l01P1oHBl0
OV8`07iT<@1lIC40OFHb07aW<P80N5h[01l0NEl^07UN;`1hGC00MEX_079F;P1`E2`0KED_06mG<@1a
FS40Le`b07=L<01bFbl0LE//071J:`1fGcH0Mf0f07QQ=@1iHc80NVD`07UT;@1iIBX0N6@Y06mI:01]
FBL0JeHW06ME9`1SDRH0Ge0U05a?8`1KCR@0Dd@S0080E4DT00<0EDHU05I79P1GB2L00P1HBBP01P1?
?a/0D48M05=5801DB280E4/T05A<9@80DD`T00`0FdhT05Y=8`1IC280F4/Q05M:801FBAl0EDPN05A7
7@1IBBL0EdLU05E58`1B@R0405107P0505I5:`1EA2X0DT4W050o9@1>?B<00`1=?2804`1<@BD0Cd4T
05A48`1MAb80JdlW081Q<`2GMDD0Z8AB0;:CI@2hVFd0^Iab0;^ON032Z8D0bk>A0<ZcU031ZX/0_jQo
0;FNM@2VSVP00P2KPel07@2WSfd0^J210<J]SP3D_jh0fLBa0=o:]@3QcK@0gLZ/0=C1X03;^ID0a[B>
0<FXP02gVVh0WhQF08Qd?`1dI3<0He<_05A6;01<?2d0BCXS04Pi8P1:>200CCTP05<k8@1J?b@0HT<W
06E6:P1XC2D0JdlZ0080JDlZ00d0Hd/W05Y38@1C?ah0DSlO05E28P17?200ASXP04Di7`13=al0@CDO
040c800o<R40?S4P0080@3HM00h0@3@N044b7@11<1h0@BhO044^8012;1l0>RhP03L^7`0e:al0<RXO
02lX7P0Z9Qd0:2DL02LT7@808R4L0`0Q81/3020O6PP07AhH200M7A/201`L6P<06a/I0`0J6QPH01XL
6@<06QXH0`0K6aT<01`L6P<07AdK0`0N7Q`201dN60807QlI0`0O81X0100P8A/07b0J01lP6P0O81X3
020Q6`808B8L200O81P302@T70<08b<K0P0R8QX202<S6`8092@L0`0U9Ad0100V9Qh0:2<P02PS800X
8al202PS7@0502TU700Y9AX0:RHK02XV6P0Z8a/00P0[91`00`0]9Qh0;RLO02lX8002030Y8@0603<W
6@0d:1X0=2PJ03HZ700g:ad0>2`N0P0i;Al203LY7P80>2XO0`0i:b00100j;240>BdM03T]7@0i;Ad2
03X^7P<0>blO00P0>c0N03d`7@0n<Ah0@C8M04@d7@16=1`0BCDL04Xf7@<0B3@L0P19=Ad304Xf7P06
05<h7@1D>Ah0E3TN05Dj7`1F>b00Ec`Q0P1H?B8205Xl8P0805/m8`1L?R@0GT0V05m19`1P@RP0HD<Y
06A6:P1N@2@205Xl800805m19@1RA2P0H48V05do8`1F?Al0F3lQ05]2901MA2H205i59`0305e49P1L
@bD0Gd8R00<0GT4Q00X0H4<S06959@1VBBT0J4/[06188P1QAb80H4HQ0655801Q@al0Hd8O0P1S@Ah2
06]::@0406Y9:01YB2L0JDPW06Q79P80IdHU0P1]BR@00`1^BbD0Kd`V071=9`02075>:005079?:@1e
D2H0Me8X07UD:P1kER`00P1lEbd04@1kER`0NUD[07YE:`1jEB/0NeH/07eH;P1nFBl0OeX`081K<@21
G380Peha081K;P1nFB`0PUd`08YU>02>JC`0S6Lj0080RF@g00H0RfHi08eX>`2>JC`0SfXm08iY?02<
IcX208]V>@0308UT=`27HSD0QV4d0080QV4d00<0Qf8e08UT=`2;IST00`25HSP208AQ=`<0Pf0f0`24
GCH208EN=`<0QUlh0P21GSP01P21GSH0P5dc081N<@20GS00P5h^07mM;@80Pf8/00<0Q6<]08ET;P26
IBl00P27IS000`28Ic40RVHf08YV=P0308YV=P<0RfLg0`2;IcD208YV=0<0RFDc00P0R6Ld08MV<`25
I340QF@a08IU<P28Ic@0RVTf08a[>080QV@f00P0Q68d08=Q<`24HS@0QF<e08IT=P28ISP0SfTj08iX
>@80S6Hg00D0SFLh08mY>P2AJc`0Tfdn08m]?`0208i/?P0308e[?@2<JS`0S6Xl0080RfTk0P2:IS@0
102<J3H0SFTg08m[>@2AKC/2099^?0<0TVe00P2AK3l3091[?P<0TV`m00<0Tfdn09A^?`2EKd000P2E
Kd0209E`>`80U6lj00/0UG0k09Mb?@2IM3l0VWE009Mc@`2HM4@0VWI609]gA`2LN4P0VgM709YfAP02
09UeA@0809YfAP2LN4P0W7Q809ahB02JMTH0V7A409Ib@P2IMD4309Qd@00709Yf@P2MNDD0X7a80:9n
BP2NNDD0WgY60:1kA`020:5lB00309mjAP2MN4@0VgI20080Ug<o00<0V7A009Ue@@2KMd<00P2LN4@2
09eiA@P0W7M300H0Ug8n09Qc?`2HLcl0VGA009Ye@@2KMT8209ag@`80VgI200<0W7M309ehA02NNDD0
0P2ONTH02@2PNdL0WWU409mjA@2PNdH0XGa70:1kAP2ONTD0WGQ309ag@P0309ag@`80VgI20`2JMD42
09ehA080WWU500X0WgY60:1kA`2QO4P0XGa809mjAP2PNdL0XGa80:9mB@2SOTX0Y7m;0P2UP4`20:^5
E0040:^6DP2[QU40ZhIA0:^6C`80[8Q>00<0YX5<0:R3CP2ZQE000P2/Qe800`2[QU40ZXE@0:V4C`02
0:V4C`040:Z5D02[QU40[8MB0:b7DP80[HQC0`2YPe820:Z4D`<0ZhED0P2[QU430:f8D`040:^6D@2Y
Q4l0Z8=>0:b6F@<0ZhEH0P2ZQ5L20:V3EP0>0:=nB@2TOdX0YH1;0:J1C02UP4/0Xgi90:5lA`2ONTD0
Y8160:F1A`2UP4T0YH1;0:J1C02VPDd20:N1D00>0:AnC`2UOe00YX1A0:J0D@2UOe00Xge>0:5kC02O
NDX0XX100:5o@02POSl0Wge009ik@@2LND4209]h@P<0VgM30P2JMT8309Ue@@80VgI20P2JMD4409Ud
@00309Qc?`2GLSd0UW4l0080UG0k00@0UW4l09Mb?@2JMD00VgI10P2FLSh209Mc?`<0V7A000<0VGE1
09Ye@@2JMD401P2JMD4209]f@P<0W7M30`2MN4@809ikA@80Vg]000H0WGY209mjA@2RNTH0XgU70:Aj
BP2UNDX809mjAP0809QbA@2ILd@0VgE609afA@2LMd<0VWE009Qc?02GLS/809Ud@0<0Ug@n:oooool0
02[ooooo00H0YgaA0:MlC`2VNdh0YWa<0:EkB@2UO4P20:AkA@<0YW]80`2UNTL20:AiAP80Y7Q900@0
YGU:0:IjB`2WNd`0Z7a=0P2YODh20:MnBP80YWe90P2UO4P20:AkA`030:MlB@2VNdP0YGY70080XgQ5
00L0YGY70:IkB02WO4T0Z7e:0:IkB02TNDH0XgQ50080XWM40P2TNDH01P2XMTD0YWI50:IfA@2UMdD0
XgQ50:9iA@80XGU5102VODT40:ElB0<0Y7U600<0YGY70:IkB02VNdP00P2WO4T20:ElB0070:ImB@2W
OTX0YWe90:ImB@2UO4P0XgY60:5hA0020:5m@`030:1l@P2ONd40WWY00080WGTo00<0W7Pn09Ud@02I
M4001P2IM400202CKCh0U6ho09E_@02EKd00U6ho099/?@2@JS/0SVPi0P2<IST0102;ICP0RV@g08US
=P29HcH208QR=@0808IR<P25HC40Q5lb08=N<P22GC<0PE/d081J=@1oFC@407aI<@@0NeP`00H0O5D^
07]D;@1kE2d0NU</07UB:`1hDBX207M@:@0607E>;@1cCbd0Ldl]079@;@1`Cb`0KU0/0P1]DB`206e>
;`0306e?;@1]Cb/0KDlY0080KE0X00<0KU4W07QH;`1gEbh00P1gEbh0301iFC00O5`c07iN=@20H3L0
Peha08AO<P25H3<0QV4d08QS=P29I3L0RVDh08]V>@P0SVPk0P2AIST6091U>0P0SVPk0`2=IcX208aV
>@@0RfDh00`0S6Hi08eW>P2>J3/0SVPk08eW>P2<IST0RfDh091Z>`2;ICH0Qf4b08QR<`2<ISL208mY
>P0608aV=`2:HcP0Rf@i08]U>02<ISL0S6He0P2=J3@00`2>JC@0SVTe08iY=@0708iY=@P0SFPd0P2<
IST308eW>P<0SVPk00<0T6Xk08mY>P2>J3T00P2=IcP04`2>J3T0SfTj091Z>`2<KC@0Rf`c08Y[=029
JS@0RFTf08YZ>@2<K3/0SFdn08mY?02>J3/0S6Hi08]U>02:I3L0RfDh08aV>@2=IcX0202<ISL208]V
?0<0RVDk0`29I3X00`29I3L0R6<f08MR=@0208IQ=00308MR=@28HcH0RF@g00P0Qf8h00H0QF8j08ER
>025HSP0Q68e08AR=023HC4208=R;`<0Pf4c00<0PV0b085O<@21Gc400P20GS007P21Gbl0PV0`089P
<P23HC@0PUle081M=@1mFS@0O5Tc07eL<`1lFc80NUXa07II;`1cF2d0KeL[06eE:@1[E2P0IU0[06E>
;01OBbX0FDHX05919`1=?BH0BCPT04Hg9011>Qh0@CXP040i7`0n=Ql0?CDP03/c8080>S4P00L0=2hN
030]700]:Q/0:RPK02HV6P0T9Q/092LL00<092LN00@08bHM028U700Q91/082<J0P0O8QT401dO70@0
7R0M2@0L8Qh201lR6`8082<L00@07b8K01dP6@0K7QL06A`E200G7A/01P0L7Qd071hK01dO700N81/0
7b8K020S6P808B@I00D08bLI02DY6`0Y:ad0;RlO038a7`0203@a7P0B03Ha7@0a;aP0=38K03Ld8@0g
<bL0<blV02dX900U7al08A/M01lP6`0Q8Qd08b@N02DV7P0V:1d09RPK02DW6P0T9QP08R<K100S91`0
0`0Q8QX07QlG01dN5P0801lP6PP07R4J02006a`F01`M5`0M7QP07b0J020Q6`0R8ad08b@N02@U7`0b
9aD0>RlM048e8P12=R00@34J044a6P1:>200DT0X06mE<020I3d0SG5909=fBP2LODh0YhMD0:V8D`2R
PD/0O74k05a@:P0l<200<BLX02hV<@0X9R/08bHO028Y6@@08R@Q100S9B8802DX8@0602LZ8`0V:B80
9BPQ02@W800S9Ql08RDN0P0Q91d802DU8`0302@U7`0U9R009BHP00809RLQ0P0W:280200X:B<0:RdV
02X]9P0/;BD0;blU038`900d<2@0=C8S0P0h<R@01P0l<280?S8R04<f9P16>BP0Bc`Y04dl:080CS`V
01/0BD8V04U2:018@BL0AShW04@l9`13>bP0@STX044h9`0o=200@3DQ044f9012=RH0@SHX040d:00o
<bL0?S4X04@f:@15=bX0AcLX04Th:01;>2T0CSTX04lj9`1@>BL0CS`V04lm9`1A?bT00P1B@2X01@1A
?bT0CcdW04hl9P1A?bT0D3hX0080CcdW01`0D3hX0590:P1D@R`0ET@^05i68P1MAR@0G4PW05Y79`1F
AbX0DT@Y04i2:01;@BP0CD4W04e1:@1;?bL0BCdW04Hi9P14=bH0@SDU044d900n<B40?c8R044d9013
=RH0A3LW04<f9P12=BD0@C@T0P10=2P403lc9`80?S8V00P0?3<T03/b8`0j<2@0>BlU03L]900f:bD0
=BXT03@Y9@80<R`P0P0c;B4203@^8P80=BlS00<0=bdS03P^900j<2H00P0k<BL0300j<2H0>2hT03L]
8`0f;bD0>2lV03Ta9P0j<2@0?C4S03lb8P12<R<0@S8R04Dj9P80ASTV00<0BCXW04Xi9`1<>BP00P1>
>BP2058l9`0N054k9P1B?2L0DcdX05I0:`1I@bh0FT@_05Y9:`1LBBT0GDXZ05m;:P1SC2X0Idl[06]A
;01/DRd0IU@`06AA<01NCRd0FDX]05E7;@1AABl0DD@a0515<`1D@bT0ETD[05Y9;`1LBc40GD`b05a;
<@1IB2h0EdH/0P1B@R/09`1C@b`0E4D^05=7;`1BB2l0CdP^04i7;@1<AR`0DDHZ0597:`1EAB/0EdH/
05]7;P1OAbl0HDL`06=7<@1ICb/0G5</069F;P1XFbl0K5h_075Q;P1bHRh0Lf8/07aV=01mJ3<0OfPd
08=Z=027K3D0Rfhf08a_=@2>KcH0S6m308ib@`2DMT@0V7Y409an@P2NOcl0XH0m0:60>`020:n7BP06
0:f9B`2/RT/0Zha<0:V=C02WST`0YXm<0P2QPT/05P2QP4X0Y7m:0:EmB@2VNdP0Z7Y80:MiA`2UOD00
YWi00:R1@02ZPch0[8Ho0:j8?`2_RS`0/8/m0:J4A@2TQ4L0Y8I:0:>6C02NQDd0VH9<09F0B`2BOT/2
091lB@0>091lBP2@Nd`0SWU<08]fB`29M4T0Qg5808=a@@21Kcl0PF`m089Z?025JSd0Rfa0091_A02C
LTL209Ud@00409Qc?`2GLSh0UW4m09Ia?@80UG0l0`2DKcP209E`>@<0UW4j02`0UW<m09Md?P2HMCl0
Ug@n09Ic?@2DLC/0TFhh091]=`2<JcH0RVTd08IU<024Hbh0Pf8]08ET;`27IS40RFPc089V=023IcD0
PfLg085U=P1mH3@0N5/a079E;@1^DBT0KTl`075B<`1dES@0M5Hb07=E;`1dEbl0NE`d07iQ=`1hH300
NF4a07]S<`1mICD0OVHf07eU=@1lI3@0Nf<c07YT:`1mIbh0PV`c08I`=`80R78i00<0Qg4h08E_=P2?
LSH00P2=L3H05P2:KC<0QfXb08EW<@24IS80Q6Hd08EW=@2<IcX0QF<e081N<01nGRl0P64b07mS<`1l
HS40NV0_07QK<`1fFC40M5L_079E;@1cERh0MUTa07UL=01lGcL2081P;`03081R<01oHc40OfDb0080
OVLc0280OVTd07QN:`1iGb`0NEl^07UN;`1gG2l0MEX_079F;P1aEBd0KUH`06mG<@1aFS40Le`b07=L
<01cGBh0LE//071J:@1dGC<0MUlc07MQ<P1iHc80NVD`07UT;@1hHbX0Mf<X06eG9P1[ERL0JE@U06EC
9@1QD2@0GDhS05Y=8`1IC280E4DT0`1EARD405I79P060510701@@Qd0DdDP05A88P1DBb@0E4`U0P1A
C2@01@1IC280F4/Q05Q;8@1GBR00EDPN0080E4LM00L0DdHL05M99P1FB2D0DdDR05127`1?@Ah0CT0M
0080Cd4N03X0Dd<Y0592:01B@RP0D40V04lo9@1=?B<0Bc/Q04Xj801:?b<0CT0S05A48`1NB2<0K50X
085R=02IMdL0ZXID0;:CI@2hVFd0^Yec0;bPN@33ZHH0c;BB0<ZcU031ZX/0_JIm0;:KLP2SRfD0VH5M
09^3G`2YTFl0_:>40<ZaTP3F`K00f/Fb0=o:]@3Pc;<0g<V[0=?0W`39]i<0`k6;0;fPN02^TfH0V85?
085]>P1^GBl0GDl/0512:016>BP0ASXR04Pi8P1:>R40D3`S05Hn901K@2D0H48V06=4:01TBRD0IddX
0P1VCRX01@1PBBL0Ed<R054n7P1A?Qh0DD0R0080ACTO00H0A3PP048f7P11=Al0?c8O03ha800m<1l2
03le700>03lc7@0n<Ah0?blO03l]7`10;Al0?b/P03P/7P0e;1d0=2XN034Y7P0^9ad0:bLN02PU700X
9Ah2028Q70<08B0K0`0P7aX801dN60P07AdK0P0L71X301/K6@<06QXH600J71T301XJ60<06a/I3@0L
71X201dM6`<07QhL0P0M7QP201hO6@L07b0J0`0P8A/2024R70P0824I0`0T91`202<S6`<08R8J0P0S
8a/202@T70@09BDM00<09b8O02PS800X8al00P0X8ad01@0Y9A`0:BDJ02XV6`0Z9QX0:R<K0080:b@L
00D0;2DM02hW7`0_:200;bPP030Y8@02034X6@04038Y6P0c:Q/0=2/L03D/7@80=RdN0`0g:Ah203PZ
7`<0>B/P00@0>2`L03T]7@0i;Ad0>BdM0P0j;Qh203/_7`0603/`7P0m<1d0?S4N044b7@14=1d0AS@L
0P19=A`304Te7@80BSHN0`1;=al205@i7P0605Dj7`1F>b00Ec`Q05Ll8@1H?B80FChS0P1K?B<205`n
900605do9@1N@2H0Gd4W05m19`1SABT0GT0T0P1J?2002@1N@2@0HD<W05m19@1M?b<0ESdO05Po8@1J
@B<0G4<U05i59`0205e49P0:05a39@1N@B40GT4Q05e0801N@B40Gd8R06959@1UB2P0IdXZ05m78@80
GdDP00<0HDDP06537`1S@Ql00P1T@Ql206Y9:080JDPW0P1XAbH206M69@80K4TS00@0KDXT06i;9@1_
C2H0Kd`V0P1`CBL01@1eD2H0MU4W07UD:P1kER`0O5L]0080NeH/0`1jEB/04@1kER`0OEP^07iI;`1o
FS00P5/a085L<P24Gc80PE`_07mJ;@23GS40RF@g08aW>P2;IST0R6<f08IQ=027HSD0RF@g00<0RVDh
00D0R6<f08MR=@2:ICP0R6<f08MR=@0308IQ=00408MR=@28HcH0RVDh08ER>0<0Q64g0P23H3H2089O
=@<0QUlh1@25GSL2081M=`04081M=@20GC<0P5ha081N<080Oed]00H0PV4/08=R;@23HRd0Q6<^08ET
;`26IC0208MV<@80RVHf1P2;IcL0102:IS@0RFDc08UU<`29IC<208QT<P80Qf<a00/0QVDb08ET<@24
Hc00Q6<`08IU<P28Ic@0RVTf08a[>026I3H0QF<e08AR=00208=Q<`0508ES=@26I3H0R6Hh08iX>@2=
IcP00`2<ISL0102>J3T0T6Xk095[?02>K3h208e[?@80S6Xl0P2;JC/02@2:J3X0RfLe08]W=@2=JCL0
SVXh091/>P2AKC/0TVhl09=_?@02099]@080TF`o0`2@Jch0102?JSd0TF/l099/?@2BK3d209=]?P80
U6ho00<0UFm009E`?02DKc/00P2CKSX02`2DKc/0UW4m09Qc?`2JMD40Ug=309QdA02JMTH0VgM709ah
B02KMdL0VWI60080VGE500P0VWI609]gA`2LN4P0VgM709UeA@2HM4@0UW9209Ue@@<0V7A000L0VWI2
09ahA02ONdL0XGe909ehA02NNDD0WgY60080X7]700P0WWU509ag@`2KMT80UW8n09Mc?`2HM400VGE1
09Yf@P80VgM30P2LN4@809]f@P80Ug8n00<0V7<o09Ud@02JMD400P2KMT801`2LMd<0VWE109]f@P2K
MT80W7M309ehA02NNDD00P2ONTH209iiA0<0X7]600@0WWU409ag@P2KMT40W7M30`2KMT8209Ye@@80
VGA00P2HLcl00`2IM400VWE109]f@P0209ehA080WWU500D0WgY60:1kA`2QO4P0XWe90:=nBP020:Ao
B`80YX1?00@0YX5=0:J1C02WPTd0Yh9;0P2WPdT00`2VPD`0Yh9=0:V4C`030:^6D@030:V4C`2XPdh0
ZXE@0080ZXE@0`2[QU420:b7DP<0ZH=B0`2ZQ5<20:^5E0080:Z5D02[QU40[8MB0:f8D`2/Qe80ZhIA
0:V4C`2XPdh30:Z4E@80ZH=D0`2XPU<20:AoBP80YX5<00@0YH1;0:AoBP2RODP0X7]60P2UPDL0202V
PDX0YX5<0:N2C@2WPTh0Yh5@0:R2D@2TOTl0YGm@0P2VP540102UOe00Xge>0:5kC02ONDX20::0@@06
0:5o@P2POT40WW]109ej@P2LND<0VgQ20P2KMd<209Yf@P<0VGE100@0V7A009Ye@@2JMD40VWE10P2I
M40409Qc?`0809Mb?@2FLC`0UG0k09A_>P2EL3/0Ug8m09Ud?`2JMD0309Ib?P80Ug<o0`2HM40809Ye
@@80VgI20`2LMd<309ehA0P0WGY40P2KNd001P2MNT80WWU40:1hA02QMdD0XGM70:=gB0P0WgY600P0
V79509UcA02KMDH0VgE409]f@P2JMD00V7<l09Mb>`<0Ug8n0P2HLcl309Ud@0<0Ug@n:oooool002[o
oooo00H0YgaA0:MlC`2VNdh0YWa<0:EkB@2UO4P20:AkA@80Y7U60`2UNTL30:IkB0@0YWY9102WNdX2
0:MnBP80YWe90P2UO4P20:AkA`030:MlB@2VNdP0YGY70080XgQ500L0YGY70:IkB02WO4T0Yga90:Ik
B02UNTL0Y7U60080XgQ500<0Y7U60:EjA`2ZN4L00P2XN4L00`2WNDL0YGY70:AkA`020:=kA`@0YGa8
102VODT20:AiAP<0YGY70`2VNdP20:ImB@@0Z7m;00<0YWe90:ElB02SNTH00P2QO4D00`2PNd@0WgY3
09ii@P0209eh@@0309ag@02JMD40VWE100D0VWE100<0VGA009E_@02EKd000P2EKd00102DKSl0Tfdn
095[?02@JS/208eW>P0308aV>@2;ICP0RV@g0080RF<f00T0R68e08MS<`26HS80QF0c08AO<`22GC<0
PE/d081J=@1oFC@00P1nFc<0101mFS80O5Ta07]H<01kF30207YG;`0607]E;P1jE2d0NU@]07UC;01h
DR/0Me4Z0P1fD2T01P1fCbh0M50^07=?;@1bD2d0L4l/06i@;080K50[0P1[C2d01`1/CR`0KDl[06i@
:P1^DBT0Ke8Z06mB:01hF2l00`1gEbh02P1hF2l0Ne/b07eM=01oGcH0Peha08AO<P25H3<0QV4d08MR
=@29I3L208YU>0P0SVPk202@ICP808iX>`<0RfDh0P2<IST308eW>P0308US=P2:I3L0RfDh0080S6Hi
00P0RfDh08YT=`29HcH0SVPi08]U=P28HS<0RF<d08aV=`80SVPi00H0SFLh08]T>@2;I3T0RfDh08aV
=`2<ISD208eX=00308eX<`2=J3@0SFPd00l0SFPd0P2<IST308eW>P<0SVPk00<0T6Xk08mY>P2>J3T0
0P2=IcP03`2>J3T0SfTj091Z>`2=KC@0S6`c08]Z=02:JC@0RVTf08]Y>@2<JSX0SF/m099/?`2@JSd0
SVPk08]U>00308YT=`0308]U>02<ISL0S6Hg00H0S6Hg0P2;IS`308YU>`<0RF@j00<0RF@g08QS=P27
HSD00`27HSD00`28HcH0RF@g08QS>@0708QS>@0608=P>023H3H0Pf0f08AR=@24HS@0QF<c0P25I343
08=Q<`80PV0b0`21Gc402021Gbl0PV0`089P<P23HC@0PUle081M=@1mFS@0O5Tc0P1lFc807@1iFC00
MUT_07=H;@1_Eb/0KUHZ06aE:@1XD2X0IDlZ069;:@1KARL0ET8W04lm9@1;>b@0BCPT048k7`11>R00
@3TO03lg800m=B00?3@Q03/b8@0j<B00=BlO034^7@0^:a`0:bTL02LW6`0U9a`092LL00<092LN00<0
8bHM028U700Q91/00P0P8aX00`0O8QT07R0M01hP7@0201hP7@@07AlL2@0K8Ad201lR6`8082<L00@0
7b8K01hQ6P0K7QL06QdF200G7A/07@0L7Qd071hK01dO700N81/07b8K020S6P0P8aP08B@I02<W6@0T
:1X0:2XL02`]7@0a<1h0<c0M03@a7P0f<Ad0;bdF038`6`0f<b00>3DV03Lc:00`:bD09b8N020K600P
8A`08B8M02<T7P0T9Ad09BLL00809BLJ00<09BLI028S6`0S91`00P0T9Ad0100S91`08B8J01lP600M
7QH801lP6PP07R4J0P0L7AL07P0M7QP07QlI020Q6`0Q8Q`08R<M02<T7P0a:1L0=bhM040e8`11=240
@34L040`6@16=Ql0CC/S06A<9P1gGCP0RG17099gBP2GNd`0XH=A0:N8DP2XRE<0Sgi8075O=`1>?BT0
>B/X030W;00Y9bX09bXS02L]7`@08bDR100R924802@W80809RTR00<09BPQ02@W800S9Ql00P0R9Ah0
0`0Q91d09BDS02DU8`0602DU8`<09BHP0P0V9b4302LX8P0702T/9@0Z;BH0;2dU02h^900a;b<0=30T
03Db8`0203La8`0N03Xa8P0k<R<0@3@T04@g9P18>2P0BcXX04`k9`1=>bL0BClT04To9P18?RD0AS/U
04Dj9P14>BL0@cLW048f9P0o=200@3DQ044f9011=BD0@CDW03lc9`0m<BD0?2lV048f:013=BP0A3LW
04Hf9P18=bL0BSLV0P1=>2D00`1>?2H0CcdW050n:002054o:@03050n:01??BL0CS`V0080D3hX0P1?
?BL05`1@?RP0DT0Z05A2;01E@bd0GDHV05a89`1KB2P0FdPZ05I7:P1C@bT0D48W04a09P1=@BL0C40X
04Xn9P17>bD0ACPU04<f9@12=BD0@C@T03lb8P10<b<0@SDU00<0@cHV0P12=BD3040d:080?c<W0`0n
<RH0200l<b@0>c8S03X`900i;bD0=bdT03H[9@0e:R@0=2TU0P0b;20203<]8@80=2hR0P0e;b<00`0g
;B<0>2hT03T_9@0303T_9@0C03P^900g;B<0=2dS03D/8`0f;R<0>2hR03/_8@0l;al0?blP03l_7`14
>BD0ACPU04Hi9P18>BH0BSTW04/h9`1=>2L0CSTX054l9`03050k9P0:058m:01D?bX0ET4/05Q3;P1H
AbT0FdPX05i;:`1RCRd0Ie0^06UA;@80Je4/0100IeDa06EC;`1PD2l0G4d`05Q:;`1DB300DdHc0597
<`1HAbd0FTT_05e<<P1OCS@0H4le05i=<`1LBc40FTT_0P1E@b/02`1EAB`0ETH]05I8;P1DB2h0DTP]
04m8;01>Ab/0DTL[05E7;01GAbd0F4P^0080G4P_01P0GDL_05m7;`1JCBX0GE4[069D;@1YFRl0KEl`
07=S<01fIC40MfH`07eW=@1oJ3@0P6Te08E/=P28KCH0SG0h08m`=`2@LCP0SG51095c@@2DMT00V7U2
09al@@2POSl20:9o?@080:f5B02]QdT0[8Q:0:f9B`2[S4`0[8e=0:b>CP2/T4l20:F5C00V0:J3B`2U
P4T0YWm80:ImA`2VNdH0YGY50:1g@@2RND<0YGa40:R0A@2/Q4L0/8Q:0;:;BP2dSD`0YhI10:R:A02/
SDX0[Y5?0:fAD02YT500YHe=0:::C02KQTl0VXE>09Z5D02IPe40UX1?09=mCP2ANd`0SgQ<08YeAP29
M4D0Qg5208I^@028KD00Rfi2091aA@2BLdL209Qd@080Ug<o00@0UW8n09Ea?@2DL3`0U70l0P2?Jc/3
08iZ>P<0SFTi102=Jch01`2;JC`0RFLj08MU>026I3L0Pf0f085N=01oG3800P1nFc400`20GC<0Pf0f
08ER>002081S>@0A081S>`1nHCT0NE/e07=E<@1/CR`0JD/Y071B<01eEc<0NU`h07aN>01jGCD0NUdc
07aO<`1oHSH0O68a07eS<P1oIC@00`20ISD207mU=00407iU;@20Ibl0Q6/c08M^=P80RG0h00<0R6lg
08M^=P2<KcD00P2:KC<00`27JS80Q6H`08=U<@02089T<P0A089S=02:ICP0Q68d081N<01oGc00PF8c
081T=01mHc80Nf4`07MJ<01fFBl0M5L]07=F;01dEbd0MeX`07YM<`1lGcD00P21HC000`21Hc40P6@b
081V<`02081Y=@0R081[=P1iGb`0NEl/07UO;P1hGBh0Me`_07EJ;`1cEbl0LED]06mH;`1`FC00LU/a
07=L<01cGBh0Led/079L:`1bG2X0LU/_07AN;`1gHC80NF<b07US<@1iI2l0Mf8[07IQ:P1ZE2D0J5<T
06IA901RCb@0GdhS05Y;8P1HBb40EdTR05I79P<0EDHU101DAB@0201@@1`0DD<N05=5801EBB<0E4/T
05=;901AC2@0D4/S0P1FB240101EAb00E4HO05=57P1CAAh205947@0405I79P1DAB@0DT<R04m07`<0
CSlN00<0Cd0O04lo9@1@@2H00P1B@RP0=P1A@BL0CShT04Xj8018>1h0B3dQ04do8P1DA2<0GdTT06iB
:P24ICL0VgU90:b8EP2bTfD0^IY^0;bOM@2oXg`0aZb90<jfU03:/i@0`JZ;0;ZSNP2^Ufh0WhMQ09Mo
F`2MQF40[YId0<:YRP3?]YL0f<>`0=[5/03Nb[80g/Z_0=[7Y`3A_i/0aK>=0;f[P`2aUV/0XXYL08af
A`1fI3@0I5DZ05M89`19?B<0@SDR04@h8016>R80C3`S05509P1F@BH0Fd4V05e29@1P@RH0HDTU065:
:080H4TW00d0FTHU05=0801=?1h0C3dP04dn8@12>1d0@SPO044g7P0o=1h0?S<O03db800l<200>blO
0080?3@M00h0?C8N03d`7`0n;Qh0?R`N03d[7`0n:Ql0=BTK03<Z6`0b:1`0<2PM02hW7@0[9ah0:BHM
02TV7`808R4L0`0Q81/3020O6PP07AhH200M7A/201`L6P<06a/I0`0J6QP801TK61006Q`I0`0J6QP3
01/K6@8071`J2@0K6aT301`L6P807AdK0P0N7Q`301dN60807QlI1P0O81X3020Q6`808B8L200R8a/2
02@T70808b<K0`0R8QX0100Q8AT08b<K02<S6`0S8a/202@T70<09BDM0P0W8Ql0100W8Qh0:2<M02PS
7@0X91/202TU6P0702TU6@0Z8a/0:b@L02/T700/9Ad0;BHN02hW7`0202lX8006030V6P0a9a/0<BLK
038X700c:Ad0=2XN0P0e:al203DY7@80=RXN0`0g:al0100h;200>2`L03P/700h;1`203T]7@<0>RhN
00H0>c0N03`_700m<1d0@C8M04<c7016=1`204Te70<0BSHN0P1;=al304`h800605<i7P1D>Ql0E3XO
05Dk801F?240EcdR0P1H?R<805`n900506539`1M?b<0FS`P05Xl801L?R800P1N@2@01@1M?b<0EchP
05Po8@1J@B<0Fd8T00<0G4<U00X0Fd8T05i18@1M@200GD0P05i18@1O@R80HD@T06=69P1UB2P0G4@P
0P1M@b000`1P@b40HD<Q06=28@0206E28P80JDPW0`1XAbH306M69@80JTLQ00<0JdPR06a98`1]BR@0
0P1^BbD01@1_C2H0ME0V07IA9`1hDbT0NUD[0080NeH/101jEB/0401kER`0OEP^07iI;`1oFS00P5/a
085L<P25H3<0Peha089M<024Gc80Qf8e08UT=`28HcH0QV4d08AO<P25H3<308IQ=00608EP<`24Gc80
Q5lb08QS=P27HSD0QV4d0`25H3<01026HC@0Qf8e08QS=P24HCL308=P=P80PUle0P21GS@01@27HCX0
QV0i08IP>@25GcP0Q5hg0080Pedf00L0PU`e07mL=P1oG3H0Oe`d07mL<P1oGC00Oed_0080Oed]0P22
HB`00`23HRd0Q6<^08ET;`0208IU<00308MV<@2;IcL0RfLg00H0RfLg0P27Hc<208IR<P80QF4a0P24
H303089P<00708=Q<@25Hc<0R6Hf08YX>02;JCT0QF<e08AR=00308=Q<`0408ES=@27ICL0R6Hh08eW
>080S6Hg00D0RfDf08aV=`2=IcP0SVPi08mY>P0308aZ?080RfTk0`2:J3X01P2<J3P0SFTi08iZ>P2?
Jc/0T6`l099^?P80Tflo0P2AK3l2091[?P<0SfXm00<0SVTl095[?02AJc`00P2BK3d409=]?P0?09A_
>`2CKSX0TVdi099]>@2CKSX0UG0l09Mb?P2IM400UW9209Mc@`2IMDD0VWI609]gA`2JMTH0VGE50080
V7A400L0VGE509YfAP2JMTH0VGE509QdA02GLd<0UW9200@0V7A000H0VWI209ahA02NNTH0Wg]709ag
@`2MN4@309iiA@0309ag@`2KMT80VWE10080UW8n00<0Ug<o09Qd@02IMD400`2JMT800`2KMd<0VWE1
09Ye@@0609Ye@@0609Ia?@2GLSh0Ug8n09Qc?`2IM400VWE10P2KMT801P2IM400VWE109Ye@@2KMT80
W7M309ehA080WWU500<0W7M209eh@`2NND@00P2ONTD0102MN4<0VgI109Ye@02KMT8309Ye@@80VGA0
0P2HLcl01P2BKCT0Tfhj09A_>`2FLCd0V7<o09Ud@080VgI20P2MN4@0102NNDD0WgY60:1kA`2PNdL2
0:5lB0060:1jB@2QNdX0XGa80:5lA`2RODP0XWe60P2SOdD00`2UP4/0YX5<0:R3CP030:V4C`80Z8=>
0`2[QU430:Z5D080ZHA?0P2XPdl20:V4D0<0ZXEA00X0ZhIB0:V4C`2ZQE00ZhIA0:b7DP2[QU40ZXE@
0:R3CP2WPTd0Z89C0`2WPE820:J0D@80YGm@00<0Y7m:0:F0B`2VPD`00P2VPD`00`2UP4/0Xgi90:9m
B0020:J2B0040:J1BP2WPTd0Yh9=0:R3C`80Z89A00h0Y7i?0:EoD02UOe00YGm@0:AnC`2RO4d0XG]<
09miBP2SPD80XX130:5o@P2POD<0Wga409ejA080W7Q40`2JMT8209Ue@@<0V7A00`2IM40209Qc?`@0
Ug8n00<0UW4l09E`>`2DKcX00P2DKcX00`2EL3/0Ug8m09Qc?P0209Ea?@80UW8n0`2GLcl00`2HM400
VGA009Ud@00609Ud@080VgI20`2LMd<309ehA0P0WGY40P2JNSl01P2LND40W7M209if@P2OMD<0WWA4
09mcA0P0WWU50100VG=609UcA02JM4D0VWA309Ye@@2HLch0Ug8k09Ia>P2CKSX0U6lk09E`?02FLCd0
Ug8n09Qc?`2IM400VWE10`2GM3h[ooooo`00:_ooool01P2WO540Yga?0:IkCP2VO4`0YG]90:ElB080
Y7]50P2SN4D00`2TNDH0YGY70:IkB0020:MlB@@0Z7e:00<0Yga90:IkB02UNTL00P2UNTL20:MnBP80
YWe90P2UO4P20:AkA`030:MlB@2VNdP0YGY70080XgQ500<0YGY70:IkB02WO4T00P2VNdP20:EjA`05
0:AiAP2UNTL0YGY70:EjA`2/NTT00P2ZNTT00`2YNdT0Yga90:ImB@020:EmB@050:=jAP2TNdL0Y7]7
0:ElB02VODT00P2WOTX00`2XOd/0YGY70:EjA`040:EjA`80YW]800<0YWe90:MnBP2XOd/00`2YP4`0
0`2XOd/0YWe90:ElB0020:5lA`030:1kAP2ONTD0WWU40080WGQ300<0W7M209]f@P2KMT800P2KMT84
09Ye@@<0UW1100D0UFm009A^?`2CKCh0TV`m095[?00208iX>`0408eW>P2<IST0RfDh08YT=`80RF<f
00H0R6@d08MS<`26HC@0Q5lc089M<`21Fc@207mI=006081M=@1oG3@0OU/c07eJ<P1lFC40NUL_0`1i
ERh207QE;@0307MD;01fDb/0ME8Z0080M54Y00P0Me0_07A@;P1dD2h0LU0]071?;01]Cb/0K50[06]?
:P80JT//00H0Jdd[06e?:`1^D2X0Ke8Z071C:`1aE2X207MG;P80MUH]00@0MeL^07UI<01lG3<0OEdd
0P23GS401P24Gc80QV4d08MR=@28HcH0RF@g08YU>0P0SVPk00<0Sf@g091U>02@ICP00P2@ICP3095V
>@P0SVPk0P2:I3L0102;ICP0S6Hi08aV>@2=IcX208iX>`0308MQ=028HSD0RV@g0080RfDh00P0RV@g
08QR=@27HC@0S6Hg08]U=P2:I3D0RfDf08aV=`<0SFLh0P2<ICX00`2<IST0S6Hg08aV=@0208aW<`03
08aW<P2;IS80RfHb00L0RfHb202<ISD208aV>@<0SFLj0`2>J3/00`2@JS/0SfTj08iX>@0208eW>00?
08iX>@2?JCX0T6Xk091]=@2?K3@0SFXd08aX=02<J3H0S6Ph08iZ>P2>JC`0Tfe0099/?`2?JC`0S6Hi
00@0RV@g202<ISL208]V>P<0RVDi0`29I3P00`29I3L0R6<f08QS=P0408QS=P0308UT=`28HcL0R6<g
00H0R6<g00H0PUlg089O=@23H3H0Q68e08AR=025Hc<208IU<P@0Pf4c1022H380:@21Gbl0PV0`089P
<P23HC@0PUle081M=@1mFS@0O5Tc07aK<P1kFS40NET`07II;`1cF2d0KeL[06iF:P1]ERX0JU4Y06M?
:@1TC2P0GdPX05Q39P1C?bH0CS`T04`j9013?200@S/Q044j8010>240?SHQ03de8P0l<b80>c8Q03La
8@0c<1l0<2dN02`Z7@0W9a/09BLL02@W700T9ah09BPO008092LN00<08bHM028U700Q91/00P0P8aX4
01hP7@@07AlL2@0K8Ad0200N8AX07b8K020S700Q91d082<L01hQ6P0L7aP06ahG200G7A/01P0K7A`0
71hK01`N6`0M7aX07R4J01lR6@8082<H01008RHH02<W6@0W:A/0:R/K02l^700b;a`0=34N03Lb7P0^
;1L0<2hI03@a7P0h=BH0>CDY03<_900Y9A`081/E0P0Q8Qd00`0R8ad08b@L02@V6`0202DW6P0302DW
6@0S91`08b@L008092DM00@08b@L024R6P0O81P07QlG200O81X801hQ6P8071dG01h07AhH01hO6@0O
81X0824K024R700R8ad0;bPH03D^7P0l<b80?c@R03d`7@0o<1/0@S<L04Lg801J@Qh0KEDa08=Z@P2=
MDT0TWM809QlC02SQE40ZheI09j7D@24KD40GTX_048a9`0a9R@0:RHU02PY900X;R@402<U8P@08R@Q
200T9b0302DX8@0302@W800S9Ql08bHO00808RDN200U9B<802HW8@0702P[900Y;2D0:b`T02d]8`0`
;R80<blS03@a8P0203H`8P0>03P`8`0i<B@0?3<T040d9014=bH0B3PX04Tj9`1;>RH0BCdS04Pl9017
>b<0ASXT04Dh9@14=bH204<f9P0C03ld8010=B40@CHT044e9@11=BL0?c<W03da9@0k;RD0?SDV040d
9P11=BD0@cHU04Hf9P18=bD0BCLS04Xh901=>bD0CS`V04lm9`02050n:00304lm9`1>?2H0CC/U00<0
CcdW01<0D3hX054o:@1B@2X0Dd4[05A2;01JAbL0FdPX05]8:P1IB2X0F4LY05A5:01B@bH0D44T04i2
:01<@2P0BCdU04Hj9014=b@0@SDT0080@SDU00<0@C@T048e9@12=BD00`13=RH2048e9@80@CDY00@0
@3@X03lc9`0o<bL0?S8V0P0m<BD0200l<b@0>c8S03X`900i;bD0=bdT03H[9@0e:R@0=2TU0P0b;202
03<]8@80=2hR0P0e;b<303H^8`80=blT0`0f;R<04P0e;R@0=RdT03L_900h;R80>blQ03d`8010<240
@30P04<h9014=b@0ACPU04Lh9@19>2H0BSLV04`g9P1=>2L0CcdW04hl9P80CC/U01L0CS`V054o:@1C
@B/0E48/05E49P1JAbL0Gd`/06A@;`1YDS00JU8^06]A;01ZD2/0J5H`06ME;`1SDc40Ge0a05a><`1G
Bc40ETXd05A9<`1IB2h0FdX`05a;<@0205i=<`0305e<<P1KBS00FTT_0080FDD/03D0F4L]05U8;P1I
BBl0F4X_05E:;P1BBB`0DDP[05E7;01FB2d0F4P^05U9;`1JBS00FTT_05U8;P1HAbd0FTdZ05e?:P1S
E2d0J5T^071O<@1eHc40NfLd07eY=01nIcD0PFLd08=Y=P27K3L0Rfdg08m`>@2BLST0Tg<j091b?02B
M3h0UGHo09Qh?@2MNch0X7`n0:An?`2TOSd0ZH=50:Z4AP2ZQTP0[8Q:0:j:C02_SDh0/8i?0;6?D02Y
QdX0ZXI:0:V5B@2WPdL0Z8560:IoA0020:En@`0L0:5iAP2RNTL0YGe:0:R0C@2[Pdl0[XIB0;69E@2b
RUH0YXHk0:Z:@@2`T4L0/iE<0;JHC`2eUdl0/IE<0:nCBP2XT5@0YhmC0:J=E02TRe<0XHQB09n5DP2L
PTl0Vh5@09Z2DP2HP500UGe=09=kB`80U7U:00D0UGY;09IkC02GMd@0UgM409If@`0209Ee@P0309Ad
@@2CLd00Tg=00080SVe400@0SFa308a[@P2:JD00RFPo0P28Ich208MW@@0808IV@025ICl0Pf<m085Q
>`1oGcT0OUhh085O?020GS/207mM>P0D081N>`23HCh0QVA108MU@P1oHC/0P68l081R?P1oHCl0Ne`m
07IG>01`DC@0K4d`07=E;`1jG3H0PF@l08AW?@22ICT0Of<d07mS<`21ICD3081V<`@0PFLd00D0P6Hc
081W;`22JC40Q6/c08M^=P0208Q_=`0308M^=P26KCD0R6/c0080QfXb0100Q6H`085S;`20HS00Of0a
081Q<P20HC<0R6<f089P<P1oGBl0Oel`085R<`20I3@0OF<b07YP;`1fFBd0MEP/0P1dEb/0101eF2`0
N5/_07]N<P1lGc<2089R<@03089T<P21IC<0PFLd0080PFXf00l0PF`g07UO;01iGb`0N5h]07ML;@1f
Fbh0M5T^07=G;`1bERh0LEX`079K<@1bFbl0Led^07=M;01dGRd00P1dGR`0401aFbX0Led/07IP;`1h
HS00NF<a07MQ;`1eH2/0LehY06I?8`1TCb80HdhS05m<8P1LBR80F4TR05E7801EAb8205I79P0305E6
9@1DAB@0Dd@S0080DT<R00L0DD8Q05517@1A@ah0E4HQ05E98`1DBb@0Dd/T0080D4/S00<0E4HQ05=5
801CAB000P1BA1l205537P0505127@1CARH0DD@T04m28P1=@2000`1<?al0>@1=@200BcdR04do901@
@RL0DT@Y0553:01=?b@0B3XO04Dg7017?200C3hQ05A48`1QBbH0LED]08MX>P2NO4`0[h]I0;:CI@2j
Vfl0_Z5g0<6UOP38[X/0ckNE0<VbT`2oZ8T0]Ymf0:ZCJP2LQ5h0V81L0:69I@2eWG/0bK2A0=FlW@3J
aK00f/J^0=_7[P3Kb:X0elBS0<bjU02n[8@0]:=h0:J>H02HP580PVe006eL<@1NCRX0DT@W04Lm9011
=R00@SPO04Dk8P1<?R@0DT4W05M3:01J@RH0G44T05]08`0205Y69@80Ed@T00D0DT4S04dn8@19>b00
B3XP04Di7`0203df700403`d7@0k<ah0>S8O03T`7`80>2lP0100>C<K03Tc7@0i<Ah0>RlM03X]7@0k
:ah0>bXP03/Y7`0c9aT0<BPI034W6`0_9a`0;BHL02/W7P0Z9ah0:BHO0P0R8A`3024P6`<081lJ200M
7QP801dM6`8071`J0`0K6aT301XJ60P06A/H400J71T301XJ60<06a/I0P0L71X:01/K6@<071`J0`0M
7A/201`M5`807AhH0P0N7aT501lP6P<0824K0P0Q8Q`802<T70<08b<K0`0R8QX2024Q6@808R8J0P0S
8a/202@T70809BDM0P0W8Ql01`0W8Qh0:2<M02PS7@0X91/0:2@I02TU6P0Y9AT00`0[91`00`0/9Ad0
;BHN02dV7P0202hW7`<0;bLL00<0<2PM034Y7P0a:Ah00P0b:Ql2038X7080<bTM0`0d:Qh0100e:al0
=b/K03L[6`0g:a/203P/70<0>BdM00P0>RlM03`_700m<1d0@34L04<c7015<a/0B3@K04Te70<0BcLO
0`1<>20204di8@80DSXN00<0Dc/O05@l801E?B400P1F?R80101G?b<0G3hT05`n901L?R@305/m8`80
FS`R00D0GT0T05`n8P1J?200FC/O05Xl800205`n8P0405do8`1G?R00F3lQ05U08P80FT4S0`1K@R@3
05e0800305i18@1O@R80H4<S0080HTDU00H0FT8P05]1801L@R40Gd8R06118P1S@R<206E290P0IdHU
00H0J4DO06U6801YAR00JTLQ06]88P1/BB<206e:900407A?9@1fDBL0N5<Y07YE:`80NeH/00/0NUD[
07UD:P1jEB/0NUD[07]F;01mF2h0OUT_07mJ<020Fc40PE`b08EP<`0308AO<P<0QV4d0`25H3<208IQ
=080QF0c0P24Gc8208EP<`D0Q5lb0P25H3<3089O=@80PEhd0`20GC<208ER>P0<08AQ>@22GcL0PEhf
081M=@1oG3@0OU/c07eJ=01nFcD0OU/c07iK<@1nG2l0Oed_0P1oGBd2085P;@03089Q;P23HRl0Q6<`
0080QF@a00<0QVDb08aX>02<J3P0102;IcL208YV=P80Q5lb0P23GS43089M<00;085L;`1oGBl0P5h`
085O<@22H380Q68d08IT=P28ISP0RFLi08AR=023HC<00P22H3801@23HC<0QF<e08MU=`28ISP0S6Hg
00@0RfDf0`2<ISL508YX>P<0RFLi0P2=J3/01P2>JC`0SfXm091[?P2AK3l0TVe009=^@@<0SfXm0`2>
JC`208eX>`@0TF/l102BK3d2099/>`80TF/j00L0TV`k09A^?@2FL3l0Ug5009Ea@@2FLT80V7A40080
VWI600<0VGE509QdA02GLd<0102HM4@0102GLd<0UW9209Ib@P2ELD4309Mc?`0309Qd@02IMD40VgM3
0080W7Q400<0VgI209ag@`2LMd<00P2KMT8209Ye@@0409Ud@02ELCd0UW8n09Ib?P80Ug<o0`2HM400
0`2IMD40V7<o09Qc?`0609Qc?`0609E`?02FLCd0UW4m09Mb?P2HLcl0VGA00P2JMD4209Qc?`0409Ud
@02JMD40VgI209ag@`80WGQ400P0VgI109ag@P2MN4<0WWU409eh@`2LMd80VWE009Ud?`<0VGA00P2H
Lcl309Mb?P08095/>02BKCT0U6lk09E`?02GLSh0VGA009]f@P2LMd<209]f@P80W7M30P2MN4@209ii
A@80WWQ700@0WgY60:1kAP2PNdH0XGa50P2ROT@0102TOdX0YH1;0:F0B`2VPD`40:N2C@80ZhIA0P2Z
QE00102YQ4l0Z8=>0:N2C@2WPTd30:R3CP80ZHA?0`2ZQE000`2XPdh0ZHA?0:Z5D0020:Z5D0030:R3
CP2VPD`0YH1;00<0YGm>0P2TOTd30:=mC0H0YH1;0P2TOdX20:J2B0040:N2B`2WPTd0Z8=>0:R3C`80
Z89A0P2UOe020:AnC`0<0:=mCP2RO4d0XG]<0:1jB`2SPD@0XX130:5nA02PODD0WW]509eiA@2LN4H0
VgM50`2IMD4209Qd@0<0Ug<o0P2HLcl209Mb?PD0UW4m00<0UW4l09E`>`2CKST00P2BKCP00`2DKcX0
UG0k09Ia?00209A`?080UG4m0`2FLSh00`2GLcl0VGA009Ud@00609Ud@080VgI20`2LMd<309ehA0P0
W7U30P2INCh01P2JMcl0VgI109ad@02MLd40W79209ea@PP0WWU50100VG=609UcA02ILd@0VG=209Qc
?`2GLSd0UW4j09E`>@2AK3P0TVdi09=^>P2EL3`0UW4m09Qc?`2IM400VWE10`2GM3h[ooooo`00:_oo
ool01P2WO540Yga?0:IkCP2VO4`0YG]90:ElB080Y7]50P2SN4D00`2TNDH0YGY70:IkB0020:MlB@07
0:QmBP2YOT/0ZGi;0:QmBP2WO4T0YW]80:EjA`020:AiAP80Ygi:0P2VODT20:ElB080Y7]700<0Yga9
0:IkB02UNTL00P2SN4D00`2UNTL0YW]80:MlB@030:EjA`@0YW]800L0YGY70:ajB@2ZNTT0ZWY90:Uk
B@2WO4T0YWe90080YGe900D0XgY60:AkA`2TNdL0YGa80:ImB@020:MnBP030:QoB`2VNdP0YW]800H0
YGY700<0YGa80:ImB@2XOd/00`2YP4`00`2XOd/0Ygi:0:ImB@020:5lA`030:1kAP2ONTD0WWU40080
WGQ300<0W7M209ehA02MN4@00P2LMd<209]f@P80VWE100@0V79309Ma@P2FL440UFm00P2DKSl209=]
?P80SfTl00@0SVPk08eW>P2<IST0RfDh0P2:I3L01P29ICD0R6@d08MR=@25H3@0Pehd085K=080OeTd
0P20GCD01`1oG3@0OEXb07aI<@1kF300NUL_07UF;P1hEbh00P1gERd00`1fEB`0ME@[07AC:P0207=B
:@0607M@;`1eDBl0M50^079@;@1`Cb`0KDl[0P1[CbX206Y;;00606]=:`1]Cb/0KU0Z06mB:P1`Db/0
LE@Z0P1gEbh0301fERd0MED/07IF;@1hF2l0NUXa07]K<P22GC00Peha08AO<P25H3<0QV4d08QS=P80
RF@g202=IcX308mT=`03091U>02AIST0TFHi0080TVLj202=IcX208YT=`0408]U>02<IST0S6Hi08eW
>P80SVPk00<0Qf4d08QR=@29HcH00P2;ICP01`29HcH0R68e08MQ=02:I3D0RfDf08aV=`2=IcP00P2<
ISL208eW>080S6Dj00<0S6Hi08aV=`2<ISD00P2<Ic<00`2<Ic80RfHb08]V<P0708]V<PP0S6Hg0P2<
IST308eW>P<0SVPk00<0T6Xk08mY>P2>J3T00P2=IcP0402>J3T0SfTj091Z>`2AKSH0T6de08i[=@2<
J3@0RfLe08aX>02=JCT0SVTl09A^@@2BK3l0SfTl08eW>P2;ICP208YT=`0308]U>02<ISL0S6Hg00H0
S6Hg0P2;IST308YU>0<0RF@g00<0R6<f08UT=`29I3L01029I3L00`28HcH0RF@g08UT=`0608UT=`06
089O=`22GcD0Pf0f08AR=@24HS@0QF<c0P26IC8808=Q<`08085O;`22H300PV0b08=Q=022GcD0P5de
07eJ=01lFC<207]J<@0M07UI<01eF2h0LeP]071H;01_Eb/0KEHZ06a@:01YD2P0IT`Y06599`1LABH0
ET4V058n9@1@?2@0A3dQ04<l8P12>b40@CTR03lg8P0n=R<0?C@S03`c8P0h<R80=34P034^7`0]:ah0
:2PL02HX7@0T9a`00`0U:1l00`0T9ah08bHM028U7002024T6`03020S6P0O8Ah07b4N00807R0M0P0M
7a`201`N6`T06R0L00<07R4J01lR6`0P8a`00P0Q91d00`0O8Q/07R4J01`O600801LM6`0H01/M700K
7AX071hK01dO6P0N8AX07b8I01lR5`0P8aP08BDG028V600U9aT0:2TI02d/6P0a;Q/0=34N03Lb7P0^
:aP0;b`I034^6`0g=2<0>SLX03Hc900/:1`08alC0P0R8ah0200R8ad08b@L02@V6`0U9aX09RPK02HX
6P0S91`092DM0P0U9Qh0100T9Ad08R<K020Q6@0N7aL801lP6PP07R4J00@071dG01dN600M7QP07QlI
0P0O81X2020Q6`0H02dW6@0b;1h0>34Q03/b8@0l<Al0?C0M03hb7012<ah0D3TG065;9P1hH3X0R6m6
08icAP2BMdP0WH5?0:R=F02XRE80TgM806mF=`1;>2L0=2LO02TT800V9b809RPS0P0T9R<202<U8P80
8R@Q0P0Q8b0802@W800302DX8@0T9b0092LP008092LP0`0S9Ql802DU8`P09RLQ00L09bXS02P[900Z
:b<0;2`R030^8P0b;R80<c0Q0080=BlQ0P0f<2@01`0i<B@0?3<T040d9014=bH0ASTX04Tj9`1:?280
0P19>R<00`18>B@0AcPU04Lg9`0204Hf9`0>044f8P12=b<0@cPV04<g9`11=BL0?c<W03da9@0l;bH0
?CHV03he9P0o=RD0@CHT04<f9@16=b@204Pg8`0304`j901=>bD0CS`V0080CcdW00P0CS`V04dk9@1<
>R@0CC/U04hl9P1??BL0D3hX054o:@<0DT0Z00<0EDHY05I7:P1GB2/00P1IB2X02P1IARP0Ed@T05I3
8`1@A2X0CT8Z04Xn9P16>R@0A3LT04<f9@13=RH204@g9`80@cHV0`12=BD204<f9P05048f:P11=BT0
@CDY040d:00n<RH00P0m<BD02@0l<2@0?3<T03/b8`0j<2@0>BlU03L]900f:bD0=BXT03@Y9@02038/
8080<bdQ0P0d;R8303D_8`H0=2hR00X0=BlS03Pa9`0i<2L0>S8W03`b9P0o<bD0@3<S04<c9013<b<0
@SLS0P14=b@00`16=b@0B3LU04Tf9@0204`g9P0304lm9`1>?2H0CC/U0080CC/U01L0CcdW054o:@1C
@B/0E4<U05U69P1MBRX0Hdl^06QA;`1ZDRh0Je4/06Y@:`1YEbl0JELa06IF<P1SE3<0H58e05]@=01I
CCD0Ed`f05Q7;@1IB2h0FTT_05]:<00205Y9;`0505Q7;@1GAR`0GDP]05e8;@1MBBh00P1LBbl01`1K
C2l0F4X]05A9:`1CB2X0EdL]05Q8;P1JBS000P1JC340<@1HBRl0E4T]0597:`1JC2T0GDdY065B:`1X
Eb`0Ked_07MS<@1mIcD0OfXe07mU=022IS@0Q6Pf08U[=`2=KSP0T6li09Eb>P2FLc/0TgDi09Af>P2F
MS/0VWPk09ei>`2QNcd0Y7`n0:Em?`2UPD<0YX940:N3A@2/QTP0[XQ:0;2:C02cRdh0]8a?0:j8B@2]
QdP0[8I70:^5AP2XQDD0YhA40:J3@`2TPT80YX5<0:J1C@2WPTh0Z8=?0:Z4D`2[QE@00P2/QUD0102T
Q3/0Z8Po0:j>A@2dTTX20;RFC00?0;VEB`2gTdL0/YIE0;6EEP2_Te@0[I1D0:^>E02YS5@0Z8YD0:N9
D`2SREP0XXQG0:26E@2MPe80VX=A00<0VH9@00H0VGe;09QlBP2HO4X0Ug]909IjB02ENDL209AhAP0@
09=fCP2BMDd0TGA<091cB`2>LDT0SG1808a_A`2;KTH0Qf]608IZA@24J4<0PVI1081T?`1nHSd0OF4l
07aP>`<0P5ln01<0PF0o089Q@025I4<0QfI508QWAP21I3`0PfHn08AV@024IT80PVA207iP?P1iFS/0
MULj07QK<@1nHCL0QVTm08U]?P27Jc/0Q6Pf0080PfPc0`24JC@408=X<`0508AY=023J340Q6Tb08I[
=027K3D00P28KCH208M/=@0608IX<P24IS00Q6H`089T<01oHBl0OUl`0P1nGc402@1oH3@0QV4d085O
<@1nG2h0OUh_081Q<P1nHS80NV0_07IL:`0407EI:P0407MK;01iGBh0Nel`07eQ<P80Pf<b00<0PfDc
085U<`21Ic@00P20JCD01`1oJSD0NV0]07YP;@1hGRd0Me`]07EJ;@1dFBh00P1cEbl207=L<080Led^
00L0M5h]07AN;01eH2/0MF0[075L9`1cGRT0MV0^0080N68`00/0MEl^075K:P1^F2L0Hd`R069=8P1Q
Bb80GDXR05Y88P1FAb00E4HQ05A68`0205E69@0405A5901CA2<0DT<R05938P80DD8Q00H0DT8N0594
7`1DAR40EDTS05A;901BBR<204m:8P80DT@Q101A@b0205127`0604i39@1=@R@0Bd0R04Tn8018?Al0
BChP0P1:?b40>P17?200BChR04e29P1?A2P0CT<W04Xo8`16>al0@cPL04Hk7`1=?b80EDDT06==:01c
Ebl0RFXl0:1nCP2`S5X0/I9T0;VJKP2oXWP0`jN00<V_S03>]Y@0b;6B0;bUQP2bVg80Yi1W09^3G@2K
Pel0ZI5]0;jVQ03@]iP0f/6R0=_7[`3IaJ`0el>X0=K3X`3B`9`0a[B>0;JUNP2YV6`0W8IE08miBP1i
IS`0IEDa05U::`1?A2P0ASlU044j800o>1h0@S/Q04Tm8`1@@2H0Dd8V05M29@1I@280F3lQ05=2901A
@28204ho8P0504/m8P17>b40A3XQ044f800m=Ah00P0i<a/0100h<Q`0=c0M03L`7P0f;al203D]800@
03Ha6`0f<Ad0=RlL03H]700g:ad0=bTN03LY800h9al0<RHH030W600`9QX0;RHK02dV700Z9Qd0:BHM
02PU7P808R4L0`0Q81/3020O6PP07AhH200M7A/201`L6P<06a/I0`0J6QP801PJ5a006Q`I0`0J6QP3
01/K6@8071`J2`0K6aT301`L6P807AdK0`0L7AL201dN60<07QlI0`0O81X3020Q6`808B8L200S91`2
02<S6`<08R8J0`0Q8AT3028R6P808b<K0`0T91`202HQ7P0402LR7P0W8Q`09b8L02LS6P80:2@I00@0
:2@H02/T700[91`0:b@L100/9Ad0100]9Qh0;BHL02dV700]9Q`402hW7@0302lX7P0`:1/0<BTL0080
<BTL0P0b:Qd203<[7P<0=RXJ0P0g:a/303P/700603X_7@0k;Q/0?2lL040a7012<Q/0AC<K0P18=1/2
04Xf7P80BcLO0`1<>2001`1=>B40CSTL04lj7@1?>Qd0D3/N054l7`1B?B000P1C?R4305/m8`<0FS`R
0P1I>b4205/m8@0605Xl801I>al0F3XN05Pj7P1K?B40GClS1@1H?b4205U08P0505Y18`1L?al0G3lO
05e0801N@B400P1O@R8206138`0605U08@1J?b40Fd0R05i18`1O@2<0HT0T0P1T@BD806I59080J4DO
00<0JDHP06Y78@1[B2800P1/BB<01@1]BR@0M4lU07E@9P1gDRP0NE@Z0080NUD[0P1iE2X207YE:`07
07]F;01mF2h0OUT_07mJ<020Fc40PE`b08AO<P0308EP<`<0Q5lb00D0QF0c08UT=`29I3L0R6<f08MR
=@0408IQ=080PUd`1@23GS42089M<080PEhd0P20GC<307mL<P0907iK<@22HCP0PV4h085P=`20GcH0
OUdd07eL<`1lFc80NeXa0080O5Tc00@0O5Ta07eJ<01nG2l0OU`^0P1oGBd2081N;P03085O;`22H300
Pf4a0080Q68b00<0QF<c08]W=`2;IcL00P2:ISH208UU=@80R6@d0P22GC43085L<0<0P5/_00X0OE/^
07iL;`20GS40PElb08=Q=024HSD0QF<f08IT=`23HC<0PV0b0P21Gc401023HC<0QF<e08MU=`28ISP3
08YT=@0508]U=P2:I3D0RV@e08YT=@29Hc@01@28ISP308UW>@80SFPl0P2>JCd0102?JSh0T6/o095/
@02AK40208iY?0<0SFPk0`2<IcX4095[?0@0T6Xk00/0TF/l091Z>`2?JCX0SfTj091Z>`2BK3d0U6ho
09I`@@2DL400UG5109Mc@`0209UeA@0309QdA02GLd<0UW920080Ug=300<0UW9209Ea@@2ELD400`2E
LD4209Ib?P0309Mc?`2HM400VGE100<0VWI20P2JMD4209Ud@0@0V7<o102ELCd509Ib?PP0UW4m00H0
U6lk09E`?02EL3`0UW4m09Mb?P2HLcl209Ud@080Ug8n00@0V7<o09Ud@02JMD40VWE10P2KMT800`2J
MD00VgI109ag@P0209ag@P0309Ye@02IM3l0Ug8m0080V7<o0P2GLSh309Ia?@0709E`?02DKc/0U6lk
09Ia?@2GLSh0VGA009Ye@@0209ag@`@0VGA0102JMD40202MMdH0WWQ709iiA@2PNdH0XGa70:9mAP2R
OT@0Xgm5102SOTT01@2TOdX0YH1;0:F0B`2VPD`0ZhIA0080ZXE@00<0ZHA?0:R3CP2WPTd00P2VPD`2
0:N2C@80Z8=>0P2YQ4l20:Z5D0090:J1C02WPTd0Z8=>0:V4C`2XPdh0Yh9=0:F0B`2TOdX0Y7m;00<0
Xgi:0P2RODT20:5lB080Y7m:0`2SOTT20:AoBP0=0:F0B`2UPDL0YH570:J1BP2VPD`0Yh9=0:N2CP2W
PE00Z89A0:EoD02TOTl0Xge>0:9lC@020:5kC080X7Y;0P2QOT@0102PODD0WW]509eiA@2KMdD209Yf
AP<0V7A00P2GLcl309Ib?P@0UW4m0P2EL3`309A_>`0309E`>`2DKcX0TVdh0080TF`g00@0TVdh09=^
>@2DKcX0Tflk0`2DL3`209Ea?@80UW8n202HLcl209]f@P<0W7M30`2MN4@809]h@P80V7Pm00H0VWLo
09Ye@02LM400WG=109ec@`2NLT<809ehA00@09YdA`2ILd@0V79309Ma@02FLCd0UG0k09E`>@2DKcP0
TF`h099]>@2CKSX0UG0l09Ia?@2HLcl0VGA009Ye@@<0UW<m:oooool002[ooooo00H0YgaA0:MlC`2V
Ndh0YWa<0:EkB@2UO4P20:AkA@80Y7U60`2UNTL30:IkB0050:UnB@2XODP0Z7e80:MlA`2VNdH00P2U
NTD00`2TND@0Ygi:0:MnBP020:ImB@80YGa80P2TNdL00`2WO4T0YW]80:EjA`020:=hA@030:EjA`2V
NdP0Yga90080Y7U600@0YW]80:MlB@2WO4T0Yga90P2VNdP01P2/NTT0ZWY90:YjB@2YNdT0Yga90:Im
B@80YGe9102UO4P40:ImB@<0YW]80`2UNTL20:AiAP030:=jAP2UO4P0YWe900@0Z7m;0P2VODT20:5l
B0030:1kA`2ONTH0WWU50080WGQ400L0W7M309mjAP2NNDD0WWU509ehA02LMd<0VgI20080VWE100@0
VWA509UcA02GLD80UFm00P2DKSl209E_@006091Z?@2?JC`0SfTl08iX>`2=IcX0S6Hi0P2;ICP0202:
ISH0RFDe08QS=P25H3@0Pehd085K=01oFC@0OUPc0P1oG3@207iK<`0507eJ<P1lFC40NeP`07]H<01g
Ebh00P1fERd00`1eEB`0M5@[07=C:P02079B:@0807QA<01eDBl0M50^079@;@1`Cb`0KDl[06]?:P1Z
CRT206]<;@0806a>;01]Cb/0KU0Z06iA:@1_DRX0Ke8X07MG;P1fERd307EE;00307MG;P1iFC00NUXa
0080PUd`00H0Peha08EP<`26HC@0Qf8e08QS=P29I3L808eW>P80SV<f00<0Sf@g091U>02AIST00P2B
IcX00`2CJ3/0SFLj08eW>P0608eW>P<0RfDh0P2<IST308eW>P0308QR=@29HcH0RV@g0080RfDh00D0
RV@g08US=P28HSD0R68c08]U=P0208iX>@0408aV=`2;ICH0S6Hg08iX>@80SFHk00<0SFLj08aV=`2<
ISD00P2;IS800`2;IS40SFPd08eX=00708eX=0P0RfDh0P2<IST308eW>P<0SVPk00<0T6Xk08mY>P2>
J3T00P2=IcP03`2>J3T0SfTj091Z>`2CKSL0TF`e08mZ=@2=J3@0S6He08aV=`2=IcP0SVPk09=]@02B
K3l0SfTl08eW>P0208]U>080S6Hi202<ISL208]W=`<0RVHf0`29ICD00`28HcH0RF@g08YU>00308YU
>00308UT=`28HcH0RFDe00L0RFDe00H0Pf0h08=P=P23H3H0Q68e08AR=025Hc<208ET<@04089P<P23
HC<0Pf4c08=Q<`<0Q68d00T0QF<e085O;`22H300PV0b08=Q=022GcD0P5de07eJ=01lFC<00P1jFC00
0`1hF2l0MEP^07=H;@02071H;00J06iG:`1^DBT0JdlW06U=:01SBBH0GTDV05U19@1E@2D0DcdU04Dn
8P14?B<0@c`R048j8`10>2<0?cLT03he900m=2<0>S@T03Hc8P0b;b00;R`O02TY7@0V:1d09BPM02DX
7`0V:B0202DX7`0302@W7P0S9Qd08RDL00808B@K00D0828O01lQ7P0O8Ah07R0M01dO700201`N6`03
01/M6P0J81`06R0L00L06R0L00<07R4J01lR6`0P8a`00P0Q91d00`0P8a`07b8K01hQ6P0801LM6`06
01XL6`0K7AX06adJ01`N6@0M81T07R4H0P0O8QL0400P91H08BDG02<U5`0V9aL0;2/I034^6`0d<Ah0
>3<O034^7@0^:aX0;R/H03<`7@0i=R<0>3DR02l/6@0W9142028S7P06028S7@0R8a/08bDJ02@V6@0V
:1/09bTK0P0T9Ad202DV7P0402@U7@0R8a/0824I01lP60P07b0J200N8AX00`0L7AL07AhH01dN6002
01hO6@<07b0J00H0:2@H02`Y6P0c;Al0>34Q03Xa800m<R0203d`7@0A04Te501D@1d0JU@_07mX?`29
LDD0SG9309IlB`2RQU@0[XUB0:1oC022I3h0FTDZ03d]7P0^9al09bHT028T8`0U9b@00P0T9R<01@0S
9B808R@Q024S800Q8b00828O00P08bHO200T9b0802DU8`<09bPR0P0V9b4302DV800702HY8P0W:R<0
:BXR02/[8@0_;B40<BdQ038_800203D_8@80<blT00L0=S0T03P`8`0k<R<0@3@T04@g9`16>BP0Bc/R
0080Bc/T00D0BSTU04Th9P19>2P0BCLY04Pf:00204@i9@0<04Dj:015>BT0@cLY044e:@0n<RH0?C0W
03`f9P0n=bL0?SLU040h9@13>2H0ACPU0P18>B@00`1;>B<0C3XT04dk9@0204hl9P0704dk9@1<>R@0
BcTS04`j901=>bD0CcdW054o:@020590:P80DClY00l0Cd<Y05=5:P1FAR`0F4T/05a9:`1LBBT0G4PW
05e69P1CAbd0D4@/04a0:018?2H0ACPU04Dh9`15>2P00P16>BT00`15>2P0@cHV048e9@02048e9@80
@cHV0100@cL[048f:P11=BT0@3@X03hb9P0m<BD0?30T03/_8`0l<b@0>c8S03X`900i;bD0=bdT03H[
9@0e:R@0=2TU0P0b;20203<]8@80=2hR0P0e;b<00`0c;b<0<RhR034]8@02030/800<034]8@0b;R80
<blS03Tb:00j<BP0>c<X03`b9P0o<bD0@C@T04@d9@14=2@0@CHR0P13=R<00`15=R<0AcHT04Pe9002
04/f9@0304dm9P1<?2D0Bc/T0080Bc/T01<0CCdV04lo:01@@2T0Dd8T05M4901JAbL0Gd/Z06A=:`1X
D2`0JU0[06]A;01[FRl0JeTa06QI<P1VF3D0HeHf05mD>01LD3H0FU0g0080FDP^00<0FTT_05U8;P1I
B2h00P1HAbd08P1GAR`0H4/^061;;P1PBbh0H4d_05i=;`1MC2h0FT//05M::P1FBBT0FDP^05Y:<01K
Bc40Fddb05U><P1EC2l0D4T/04i7:P1KBbT0GddY069@:P1WE2X0KeX]07IP;`1lIC<0OfPd07mS<`22
I380Q6Hd08QX=@2=K3L0TVli09E`>@2FLCX209Ig=`0>09Qf=`2JMSP0WWPj0:9j?@2TO3l0Yge10:5o
@02SOd40YH530:V3A@2/Q4L0[hE90;>6B`2dQd`20:n6A0040:j7A02/Qd<0ZXM30:V8@`80YXQ20P2[
RD`0102[R4h0ZXM?0:Z7D@2ZQU820:Z6E00I0:F3@`2YQTH0[8U70;:=B@2fSdX0^I5;0;^AB@2lTTX0
^9YD0;JGE02dUE80/Y=B0;6BDP2`T5<0/91E0;6AEP2XRUP0YhUG0:>7E@2PQU<0WHIB09Z5D02IQE00
V8A?09j4D`0209f3DP0309b2D@2KPE00VX1?0080VGm>00h0VWmB09UnD@2IOU40Uga?09IkCP2ENTd0
U7U<09=hB`2=MT`0RgA:08QaA`25KT@0Pfa2089[@@80PFY00`20HS`00`21Hcd0PfDo08AV@00208IX
@P0C08M[>`28K3`0RVho08Y]@@28Jd40PfHn07mR>P1lGSP0O60a089V=`29KCd0Rflm08U^>@26Jc@0
QFXc08M]=02:K3H0RF/e08MY<`0308IX<P<0QfTc0P28JS@308U[=@80R6Xd00H0Q6Hb08=U<@23IC40
P68`07iO<01mGS0207iO<`0907mO=P24Gc80Oed_07eK;@1lG2d0OEh_07]O;`1eFbX0L5HU0080M5PX
00H0METY07IJ:P1hG2`0NUh^07aP<01mHC4208EU=00308=U<`21IC<0OfDb0080OFHb00L0NfHa07]Q
;P1jH2d0N5h]07IK;01dFB`0M5T^0080M5P`01P0MEhb07AN;`1cGBh0Led/07AN;01eH2/0MV4Z07MR
:`1bGBH0M5lX07MR;@1hHS00MV0_079L;@1/ERL0JE8V069;8P1PBR40GdTR05a88`1IAb40ETHR05A6
8`1CAB8205=48`<0DT<R0`1A@R40201B@Qh0DdDP05A68@1EBB<0E4/T059:8`1?BR80CTTQ201A@R40
?P1;@RD0BT4T04Po8P17?R40ASdP04Ln8@18?b80BD0S04Hm8018?b80BT4T04]29@1:@B@0B3lR04Dl
7`13>Qd0Ac`P04i08`1HB2L0IDlZ07EI<@2:Jcd0X7i>0;2<FP2^Sf40^9U]0;jQM`33Yh00bJn<0<fe
T`35[Xl0^:620:nHK`2USVD0WHEO0:::IP2bVWH0ajn=0=FlW@3K`Z<0flN^0=O3Z03C`:80dKjM0<fk
U@30[XH0[Ia`09j=H@2AODP0Q6m006mM=`1NCBl0DdD[04]1:014?B<0@3/N03hh7P11>R00AC/P04/m
8P1??R80DSlQ0P1E?Ql02@1>@2D0BcdR04Di7`15>Al0@cTP044i8P0o>B<0>cDO03Lb7P0203D`6P03
03D`700d;a`0=2hN0080<bdO00L0<R`P038`6`0b;a`0<bhK03</700d:Qh0=BPO0080=BHO00P0<bLI
030W600_9AT0;BDJ02/T6P0X91/09b@K02HS70808R4L0`0Q81/3020O6PP07AhH200M7A/201`L6P<0
6a/I0`0J6QP801PJ5a006Q`I0`0J6QP301/K6@8071`J2P0J6QP201/K6@<071`J00<07AdK01/L5P0L
7AL00P0L7AL201dN60807QlI0`0O81X3020Q6`808B8L200R8a/0100S8a/08R8J028R6P0R8QX2024Q
6@80820H00@08B4I028R6P0R8QX08R8J0P0S8a/202@T70809R4N00@09R4M02LR700W8Q`09b<J0P0X
91T00`0X91P0:b@L02/T700602/T70D0:RHM0`0[9ah0100^:1X0;bTK02lY6`0_:A/2030Z7080<B/M
0`0e:AT203HZ6P<0=b/K00P0>BhL03/^6`0l;a`0?c0K048b6`14<QX0Ac<J04Pd6`<0BCDM0P1:=Qh3
04/g7`80BcPJ00<0C3TK04dj701>>ad00P1??1h00`1@?Al0FC/Q05Tk8@0305Tk8@<0FS`R00@0FC/O
05Xl801J?200F3XN0P1F>1`01@1I>al0G3hR05U08P1H?b40EchP0080ESdO00<0EchP05Po8@1I@280
0P1K?Qh00`1M@200GT4Q05m28P0205i18@0705e0801I@280FSlR05]08`1M?b<0GSlS064o9002068n
9080I4<R0`1UA2<306I5900606Q57`1YAR00JDHP06Y78@1[B280K4TS0P1]BR@0101cCR@0ME0V07MB
:01iE2X207YE:`0F07UD:P1hDbT0NUD[07YE:`1kER`0OEP^07iI;`1oFS00P5/a085L<P22GC00Q5lb
08IQ=025H3<0Peha089M<024Gc80QV4d08]V>@2:ICP0R6<f08IQ=080QF0c0P26HC@00`1oFRd0P5/^
085L;`03089M<003085L;`20Fbh0OeX]00<0Oe`b0P1nFc4307eJ<080OEdd00@0O5`c07]K<P1kFc80
NUXa0P1iFC0207YG<@0607]H<01lFBl0OE/^07iL;P1nG2`0Oed]0P1oGBl00`20GS00PEla089P<P02
08=Q<`0308AR=029ICD0RFDe0080R6@d00@0Qf<c08IR<P25HC40QF4a0`21G382081K<@<0OeX`00@0
O5T_07iK<@1oG380PEhd0P22GcD2085N=008089P<P21Gc40PEla085O<@22H380QF<e08MU=`29IcT2
08US=0<0RV@e00<0RF<d08MQ<P26H3400`26I3H208MU=`<0R6Hh0`2<Icd208eX?P<0SVTo00@0SFPk
08aW>P2<IcX0S6Lj0P2;IST208YU>080TF/l0P2@JS/408mY>P0;091Z?@2?JC`0SVPk08iX>`2?JC`0
TF/n09=]@02DKT40Tflo09A`@02FLT800`2HM4@209Ib@P0309Mc@`2FLT80U71000<0Tflo0P2DL400
102ELCd0UW8n09Mc?`2HM40209Ue@@0709Qd@02GLcl0VGA009Ud@02GLSh0UW4m09E`?00209Ia?@03
09Mb?P2DL3`0U70l00L0U70l202EL3`01P2CKSX0U6lk09A_>`2EL3`0UW4m09Mb?P80V7<o00H0UG0l
09Ia?@2FLCd0Ug8n09Qc?`2IM40209Ye@@0809Qc?P2IM3l0VWE009]f@@2JMD00VG@o09Mb?@2FLC`3
09Ia?@80UG0l0`2DKc/01P2EL3`0UW4m09Ia?@2GLSh0V7<o09Ud@080VWE1202GLSh209]eA00609ag
@`2NND@0WgY50:1kA02QOD<0XWi40P2RODP30:5lA`030:9mB02TOdX0YH1;00@0Z8=>0`2WPTd0102V
PD`0Yh9;0:N2B`2WPT/20:R3C0<0ZHA=00<0YH1;0:J1C02WPTd00P2WPTd00`2UP4/0Y7m:0:9mB003
0:=nB@80XWe80`2QO4L0202RODP0XGa70:5lA`2PNdH0XGa70:9mB02SOTT0Y7m:0P2SOdD02P2TOdP0
Y7m:0:F0B`2UP4`0YGm>0:J0C`2VP540Y7i?0:=mCP2QNd`30:1jB`090:5kC02OO4@0WW]309ejA02L
N4@0VWI409UeA@2HM4@0V7=600<0Ug<o0P2FLSh309Ea?@<0UG0l0P2DKc/409=^>P0909A_>P2CKST0
TF`g091[=P2?JSD0T6/f095/=`2BKCP0TVhj00<0Tflk0P2DL3`209Ea?@P0V7<o0P2KMT8309ag@`<0
WGQ4202JMd40202FMS/0UgLl09Uf?P2KMT40WGE109me@`2OMDD0X7A5202MN4@0402KMDP0VG=409Ma
@P2EKch0U6lk09=^>@2CKSL0U6lh09=^>P2DKc/0UG0l09Ia?@2GLSh0V7<o09Ud@02JMD4309Ic?B_o
oooo000Zooooo`060:MlD@2WO4l0YW]>0:IlC02UNdT0YGa80P2TNdD30:IkB0<0YGY70P2TNDH40:Ml
A@@0YW]40P2WOTX20:ImB@80YGa80P2TNdL00`2WO4T0YW]80:EjA`020:=hA@0<0:EjA`2VNdP0Yga9
0:=hA@2TNDH0YW]80:QmBP2YOT/0Z7e:0:MlB@2VNdP0ZgU80P2YNDP00`2XNTP0YW]80:ElB0020:Al
B0@0YWe9102UO4P20:MlB@80YW]800P0YGY70:AiAP2TNDH0Y7U60:5hA02SNTH0YGa80:ImB@80Ygi:
00<0YWe90:ElB02UO4P00P2QNdX00`2PNTT0WgU809ihA`0209egAP0609afA@2PNdL0WgY609mjAP2N
NDD0W7M30P2KMT801`2JMD40VgE609YdA@2GLD80UFm009A^?`2EKd000P2FL442091Z?@80SfTl00`0
SVPk08eW>P2<IST0S6Hi08]W=`2:ISH0R6<f08IQ=@23GS@0PE/d07mI=01nF3<407iK<`@0OEXb00H0
MeL^07IF;@1fERd0MED/07AD:`1cDbX2079B:@0807UB<@1fDS00ME4_079@;@1`Cb`0K4hZ06Y>:@1Y
CBP206e>;`0306e?;@1]Cb/0KDlY0080KE0X00@0KU4W07MG;P1fERd0MED/0P1dE2/02`1fERd0MeL^
07UI<021G2l0PUd`08=N<@24Gc80QV4d08MR=@28HcH0RF@g00P0S6Hi00H0SF8e08iS=P2?I3L0T6Dh
095V>@2BIcX209=X>`P0S6Hi0`2=IcX208aV>@<0RfDh00<0RF<f08YT=`2;ICP00P2<IST01@2;ICP0
RV@g08US=P26H340RfDf0080T6Xk00T0S6Hg08YT=@2<ISL0SVPi08iW?02=IS/0SFLj08aV=`2<ISD0
0P2;IS800`2:IC00SVTe08iY=@0708iY=@P0Rf@i0P2<IST308eW>P<0SVPk00<0T6Xk08mY>P2>J3T0
0P2=IcP04`2>J3T0SfTj091Z>`2EKSL0U6df095Y=@2?Ic@0SVHe08iU=`2?ISP0SfHj099/?`2@JSd0
SVPk08eW>P2<IST0SFLj08iX>`2?JC`0202<ISL208]W=@<0RVHd0`29IC<00`28HcH0RF@g08YU>002
08]V>@0308YU>029I3L0R6<f00P0RVHd00H0QF8j08ER>025HSP0Q68e08AR=023HC4208=R;`80PV0b
0P23HC<08P24HS@0QF<e08ES=@25HcD0PEl_089P<022H380Pf4d089O=@20GCD0OEXd07aI<`1jFC00
NEP_07QH;`1eF2h0LeP]075I;@1`F2`0KeP/06iA9`1]D2P0JDdV06A:9`1OARL0Fd@U05Q09P1E?bL0
AChR04Dn9014?B<0@SXS044i900o=b@203he900803/e9@0g=2<0<c0Q02l]800Y:Ad09bTN02DX7@0U
:1l202HY800402DX7`0T9ah08bHM028U70808B@K0P0P8Ql0100O8Ah07R0M01dO700L7Q/201/M6PT0
6AlK00P07R4J01lR6`0P8a`08B@M028U7P0Q91d07b8K01hQ6PP05adK00H06Q`K01XL6@0K7AX071hI
01dP6@0N8AP201lR5`8082@F01L08R@F02DV5P0[:QP0<2dJ03@a7P0i=200<c0O02h[6P0[:1D0<2dJ
03Pf8@0j>2<0<c4J02/Y4P0S91l08R<N024R700Q8QX08R@I02@V6@0V:1/0:2XL02@U7@0202DV7P05
02HW7`0U9Qh08b@L020Q6@0O81P0200O81X801hQ6P@07AhH100N7aT0600T8QD0:BDI02h[700e;b40
>S<S03`c8P0m<R00>c0N04Hc4`1:=aH0GDTV07MQ>P26KdD0RG5308ifAP2JP4l0/hQA0:j6D`2DLdP0
Je8c04Th9P0g;RD0:RTW028S9@809BLT00@092HS02<U8P0R92408B<P0P0P8Ql:02<V7`H092LP200U
9B<00`0X:B<09bPR02LX8P0202HW8@809BHP00P092DO02HY8P0V:B80:2TQ02XZ800^;200<2`P034^
7`80=2hP00T0<BhU038^8`0b;R<0=BlS03P`8`0m=2D0@SHV04@h:01<?2<00P1<?2D01@1;>RH0BcXX
04/j:P1;>B/0BSPZ0080Ac`X0140Ac`Z04Lk:`15>B/0@cL[040d:00n<BP0?CLW03hh:00o>2H0@CTV
04@i9`16>BH0Ac/U04Tj9@1:>280BcTS04dk9@0204hl9P0704dk9@1;>B<0BSPR04/i8`1=>bD0CcdW
054o:@020590:P0Z054o:@1@?RP0Bd4X04i2:01CABX0EdP[05e::P1OBbX0HDXX069:9P1EBBl0DTH^
04e1:@19?BL0AcXW04Lj:@18>b/0BC`/04Lj:P16>BT0A3LW048e9@11=2@0@SDU04<f9P14=bL0@cL[
048f:P11=BT0@3@X03hb9P0m<BD0?30T03/_8`0l<b@0>c8S03X`900i;bD0=bdT03H[9@0e:R@0=2TU
0P0b;20203<]8@80=2hR0P0e;b<00`0b<2<0<2hQ02l]800202h/7`0<02l]800`;R40<S0S03H_9@0g
;RD0>30U03X`900m<B<0?S4Q044a8P12<R80@CHR0P12=B800`15=R<0ASDS04Pe900204Xe900I04`m
9P1;?2D0BS/T04Tj8`1:>b@0Bc`U04dn9`1>?bP0DT4S05E28P1GA2@0FTHU06199`1UCBT0JDlZ06]A
;01[FRh0K5/`06YK<P1YFcH0IUTg065F>01NDcL0G58g05i=<`0205e<<P0505a;<@1KBS00FdX`05]:
<01JBBl00P1SC2d09`1TCBh0Hdh_069?;`1OCbh0Fd`[05U::@1GBRP0FTT_05]:<01MCC<0Fe0d05Q?
<P1BCBl0CDX[04Y7:01NBbX0GT`X065=:01WDBP0KEHZ07AL;01iHS00OV@a07mP<@20HS00Pf<b08QW
=02=JCD0TVdh09A_>02GL3T0VGPe09Qg=02IMS@0VgDf09if>02QNC`0YG/o0:Mm@`020:1n?`040:=o
@@2WOd80ZX140:n1AP80/X570P2`QD40102_Qd80[HQ20:b:@`2YRd<20:V=A00H0:^=A@2[SDL0Zha9
0:^<B`2[Rdh0Zh]@0:^;DP2[RU@0ZhQB0:b7D02^Qdh0/8Q=0;J:C@2iRdd0_Xi>0<6@CP2jVU40^IQA
0;NFC`2eU4l0]IAA0;JDE02gUEH0^9IG0P2^SU/01P2/SUX0Z8mI0:B=E`2QSUH0WXeE09f<E080XH]J
00@0X8YI09n9F02NR5L0WHMF0P2LQUD309^6D@0309Z5D02IQ4l0V8=>0080V8=>00H0UX9?09B0C@2A
ODX0SGU608]gA02:MT<208Ue@P0408Q]?P29KSl0RFho08Y_@080Rg110P2<LD8208me>P0E08me?02=
LS/0RFhi089V=01lH2h0N5`/081T=025JCL0RVhl08]`>`28KCH0QV`c08M]<P29Kc@0SFhh08a]=`2:
JcD0R6Tc08MX<P28JC<0RFXd00@0RV/e1@29JS@05`24IS80PV@b089T<P20HS00OUl`07iO<@1nGc<0
Oelf081P=`23GS40OU`^07]I:`1kFb`0Ne`]07MK:`1`ERD0JU0O07=G9@1dF2H0METW07MK:@1iGB/0
Nel]0080OF4_0P26ISD09P24IS@0P6@b07eS<01jHbl0NF8^07MR;@1lHRl0NV0]07QN;@1eFR/0M5T/
07=H;@1dF300METa07IP<@1eGbh0M5h]07=M:`1dGbX0MF0Y07MR:@1hHbX0M60U07IQ:01hHb`0NF@_
07EO;P1_FBX0J54U06A=8`1RBb80H4XS05m98P1LB2<0FTPT05M79@1EARD0E4DT0P1@@B0305528@<0
DT<R00P0Dd<O05=5801EAb80EDTS05=:8`1BBR<0CTTQ04e880P0DT<R00P0B44T04M08`15?R40A3dP
04<l7`14?B00AChQ04Ho8P80AChQ0P16?b8204Dn8@80A3dP0380BChR05129@1JBRT0Ie4/07MK<`2;
K3h0X7i>0:n;F@2/SEl0]YM[0;fPMP33Yh00b:j;0<bdTP32Zh`0]9en0:fFK@2USVD0XHUS0:VAK@2k
Xgl0c[JD0=W0X@3K`Z<0flN^0=C0Y@3>^i/0c;VH0<RfT02jZGh0YYEY09F4EP26LSd0MfDe06AB;P1C
@bX0BCdW048j8`0o>Al0?3TJ03hj7`0o>Al0@3TM04@i7@19>Qd0CS/M054l7@1E?Ql0BCdS04Di8@80
?cDL00D0?CDN03hh8P0l=b<0=S<P034^6`02034_6P04034^6`0`;A`0<2dN030]7P80;b/O0100<2lK
034^6`0`;A`0<B/M034Y7P0a9ah0<bHN038U7`0d:1X0<BPI030V6P0]9AX0:R<I02LS6P0T8AP0924J
0P0R8A`3024P6`<081lJ200M7QP801dM6`8071`J0`0K6aT301XJ60P05aTF400J71T301XJ60<06a/I
0P0L71X;01XJ60806a/I0`0L71X201/L5P<071dG0`0M7QP301lP6P<0824K0P0Q8Q`8020Q6@<08R8J
0P0Q8AT3020P60808B4I0`0R8QX302<S6`809B0M00@09R4M02HQ6`0V8A/09b<J0P0W8aP00`0X91P0
:b@L02/T700602/T70<0:BHM1@0X9A`302`Y6P80;BXK0`0^:a`203@X6080=BTI0`0f:QX01`0g:a/0
>BhL03/^6`0l;a`0?c0K044a6P14<QX00P17<aX304Lc6`80B3@L0`19=Ad01P18=AL0BCHH04Xg6@1:
=aT0BcPJ04`i6`80CCXL0`1G>Al00`1H>R00FC/Q05Xl8P0205/m8`0;05Li7@1I>al0FS`P05Pj7P1D
=QX0DcDI05Pj7P1L?R80FD0R05Po8@1F?Al00P1E?1h0301F?Al0EchP05Po8@1J?Ad0FchN05e0801N
@B40Gd8R05i18@1L?al0FchN05Y18`80Fd0S00D0GClS05dn8P1O?B80H3`R05lk8@0206=28@80I4<R
0P1UA2<206I59080JTLQ0P1[B2801`1/BB<0KDXT06i;9@1^BbD0LdhT07A?9@1gDRP0101iE2X0401h
DbT0NUD[07YE:`1kER`0OEP^07iI;`1oFS00P5/a085L<P1oFRd0Peha08IQ=025H3<0PUd`085L;`24
Gc8208QS=P0308MR=@24Gc80PUd`0080PE`_00D0PUd`08=N<@1mF2/0OeX]081K;P03085L;`03081K
;P1oFRd0OEP[00<0OU/a0P1mFS0307aI;`P0N5P_0P1iES001`1jEbl0NeP^07aJ;@1mFbd0OU`/07mM
;@1nG2l00P1oGC000`20GS40PElb089P<`0208=Q=00608QT=027Hc<0QV8b08EQ<@24H300Pel_0P22
GRh3085L<P80P5/a0`1oFS000`1mFS00OU/a07mL<P02085N=00407mL<P1nFc40OEX`085O<@<0P5h`
00d0PV0b08ES=@27ICL0RFLi08MQ<P28HS<0RF<d08YT=@29Hc@0R68c08EO<024GRl0Q68d0080QF<e
0P26I3H208MU=`0408QV>02:IC/0RVDk08YU>`D0RfHl00@0S6Lj08]V>@2;IST0RfHi0P2:ICP208UT
=`03095[?02@JS/0T6Xk0080SfTj0P2>J3T00`2=IcP0SfPm08iW?00208eV>`0708iW?02@JCh0TV]0
09=/@@2BKSh0U71009Ea@@0309Mc@`0509Ib@P2ELD40UW9209Ea@@2CKcl00P2AKCd04`2BKSh0Tflo
09A`@02DL3`0UG4m09Mc?`2HM400VGE109Qd@02GLcl0UW8n09Ud@02GLSh0UW4m09A_>`2CKSX0U6lk
09E`?02FLCd00P2DL3`709=_>`X0Tfhj00<0U6lk09E`?02FLCd00P2GLSh01`2HLcl0U6lk09E`?02E
L3`0UW4m09Mb?P2HLcl00P2IM400202GLSd0V7<n09Ud?`2JMD00VG@o09Qc?P2FLC`0UG0k0`2EL3`2
09A_>`<0Tfhj202DKc/609E`?080U6lk00H0UFln09I`?`2GLSh0VG@o09Ye@02LMd0209ei?`030:9m
B02QO4L0WgY50080WgY500<0XGa70:=nB@2TOdX0102VPD`30:N2C@030:R3CP2WPdT0Yh=90080Yh=9
0P2XQ4X20:V5B`030:AoBP2UP4/0YX5<0080YX5<00<0Y7m:0:=nB@2QO4L00P2TOdP20:=nA`<0XWe6
00T0XGa50:1kAP2ONTD0WWU409eh@`2NND@0X7]60:9mB02SOTT00P2QOD<0102QO4D0XWe80:9mB02S
OTX20:=mC0040:J0D@2TOTl0XWa=0:1jB`80WgU:00/0X7Y;0:5kC02LND<0W7U309]g@`2IMD<0V7A4
09Mc@`2FLD@0UG1309Mc?`0309Ib?P80UG4m0P2DL3`309A_>`80Tfhj102BKCT0202DKcX0Tfhi095/
=`2?JSD0SVTd08mZ=@2@JcH0TF`g0`2BKSX209=_>`<0U70l202GLSh209]f@P<0W7M30`2MN4@809Uf
@00809Ee>P2FMS/0VGHn09]f@@2OMd<0XGM50:9hB02TN4T809ag@`0609]eB02ILd@0Ug5209A^?@2B
KCT0TVdh0P2CKSL309Mb?P80V7<o0`2IM40309Eb?2_ooooo000Zooooo`060:MlD@2WO4l0YW]>0:Il
C02UNdT0YGa80P2TNdD01P2XODX0Yga90:MlB@2VNdP0YGY70:AiAP80XgQ5102VNd@40:MlA@80Ygi:
0P2VODT20:ElB080Y7]700<0Yga90:IkB02UNTL00P2SN4D0302UNTL0YW]80:MlB@2RMd@0Y7U60:Ik
B02XODX0ZGi;0:QmBP2WO4T0YW]80:YhA`80Z7Q700<0YgU70:EjA`2TNdL00P2SNdL01@2XOd/0Ygi:
0:MnBP2VODT0YGa80080Y7]700<0XgY60:MlB@2WO4T00P2VNdP0202UNTL0Y7U60:AiAP2SN4D0X7M3
0:5hA02SNTH0YGa80`2VODT01`2UO4P0Y7]70:5kBP2QNdX0X7Y909miB02NN4L00P2MMdH04P2LMTD0
XGa80:1kA`2ONTH0WWU509ehA02LMd<0VgI209Ye@@2LMTL0VWA509Qb@`2EKd00U6ho09E_@02FL440
Ug52095[?P80T6Xm00<0SfTl08iX>`2=IcX00P2<IST0202;IcL0RVHf08UT=`26HCD0Pehd085K=01o
FC@0OUPc0`1mFS8307iK<`80Oe`d00H0MEP^07AG;@1dEbd0LeH/079E:`1aE2X2071C:@0807UB<@1f
DS00ME4_079@;@1`Cb`0K4hZ06Y>:@1YCBP206i?<00906i@;P1]Cb/0KDlY06e@:01/CbL0K4lU07MG
;P1fERd0MED/0080M5@[00T0MED/07MG;P1hF2l0PE`_089M<023GS40Q5lb08IQ=027HSD00P28HcH8
08aV>@0608eR=@2>HcH0SV<f091U>02AIST0TVLj0P2CJ3/808aV>@80SVPk00@0SFLj08aV>@2<IST0
RfDh0`2:I3L02@2;ICP0S6Hi08eW>P2=IcX0S6Hi08]U>02:I3L0QEl`08]U=P02091Z>`0408aV=`2:
I3D0RfDf08iX>@80SVLl00H0SFLj08aV=`2<ISD0RfHb08YU<@2:IC0908mZ=PP0Rf@i0P2<IST308eW
>P<0SVPk00<0T6Xk08mY>P2>J3T00P2=IcP03P2>J3T0SfTj091Z>`2EKSL0U6df099Z=P2?Ic@0SVHe
08iU=`2?ISP0SfHj091Z?@2?JC`0SVPk0P2=IcX00`2>J3/0SfTl091Z?@0808aV=`80RfLe0`2:IS@3
08UU<`0308MR=@29I3L0RfHi0080S6Lj00<0RfHi08UT=`27HSD0202:IS@01P26Hc/0QV<i08ER>024
HSD0Q68d08=Q<@80PV4^0P22H3801023HC<0Q68d08AR=025HcD208IT=P08085O;`22H300PV0b08=Q
=022GcD0P5de07eJ=01lFC<207UH;`0N07QH;`1eF2h0LeP]075I;@1`F2`0KeP/075B9P1]D2H0JddW
06I:9@1QAbH0GD@V05U19@1H@2H0ASlS04Dn9014?B<0@c/T044i9010>2D0?cHU03he900l=RH0>3DT
03@a8P0_;B00:RXN02LY7P0U:1d09BPO0P0V:B000`0U:1l092LN02<V7@02028U7009024T6`0Q8b00
828O01lQ7P0N81d07AlL01`N6`0K7AX06Q`I00T06AlK00<07B0I01lR6`0P8a`00P0R9Ah00`0Q91d0
82<L01lR6`0801LM6`0801XL6`0J71T06adJ01`N6@0M81T07R4H01hQ5P0O8QL201lS5@0H024S5@0T
9AD0:RTG030]6P0d<Ah0>C@P03Db8@0^:aX0:BHE02dZ5`0f=1l0>SPQ03Dc700]:a808b@O028S7P0Q
8Q`08B8J028T6@0T9QT09RPK02PZ700T9Ad09BHN0P0V9al0100U9Qh08b@L024R6P0O81P801lP6PP0
7R4J1@0M7QP301hO6@0P02<Q5@0U8aH0;2PL03@^800j<b<0?3<R03/c800k<1h0AC8B04Db4@1E@Ah0
LU`e08A]@`27L4@0Rg=309=lBP2fRE00]XeI0:1nD@1gGC`0DT8[03de:P0^;B/08b@X02HX9@0U9b@0
92HS02<U8P0R92408B<P020R7`0O8Ah;02<V7`D092LP200U9B<202PY8`0402LX8P0V9b409RLQ02DV
808092DO00L09BPQ02HY8P0X:B40:RXP02h/800`;200<BhO0080<bdO00T0<BhU030]900a;B80=2hR
03L_8P0l<b@0?cHW04@h:01>?2@00P1>?2H00`1=>bL0CCXY04dj:`0204dj;00>04Pm:@19?RX0BCh/
04Pl;017>bd0A3P/044e:@10<bX0?3TX03li:@0o>RL0@CXW04<k:016>bL204Pl9P0304Xh8P1;>B<0
C3XT0080CC/U00L0C3XT04/i8`1:>280BcTS04`j901??BL0DClY0080DT0Z01X0D3hX04lm9`17?bP0
Bd4X0514:P1GB2/0GDXZ069;:`1TC2P0ID/X05M;<@1DB300Cd<[04Xn:018>bP0B3/Z04Tl;01;?Rh0
B3/[04Hi:@14=bL0@SDU044d9012=BD0@cHV04@g9`80@cL[00@0@CDY040d:00n<RH0?C4U0P0k;b<0
200l<b@0>c8S03X`900i;bD0=bdT03H[9@0e:R@0=2TU0P0b;20203<]8@80=2hR0P0e;b<00`0b<2<0
<2hQ02h/7`0202d[7P0<02h/7`0`;R40<S0S038[8@0d:b80=2`Q03H/800i;Al0>bhN03h^7`0n;Qh0
@3DQ0P12=B800`14=B80ASDS04Ld8`0204Xe900304`m9P1;?2D0BS/T0080BCXS00@0BS/T04`m9P1=
?RL0Dd8T0P1D@B40401G@b80GDHT06=;9`1YCbX0K58]06aK;`1]G340Je`c06YL=`1WFSP0HePh061E
>@1MDcP0HU4g065@=P1PCcD205m>=0<0GTdc0P1TCBh07`1UCRl0I4l`06A?<01QCRh0GDd/05Y;:P1H
BBP0G4P_05a;<@1MCC<0Fe0d05M@<`1BCBl0BdX[04Q7:01NBbX0Gd/X065=:01VD2L0Je@X079J:P1i
Gbh0O68_07eN;`20H2l0PV8a08MV<`2<J3@0TF`g09E^=`2GL3T00P2IN3<05P2IMS@0VgDd09if>02R
N3`0YG]10:Ul@`2MOSh0X7ho0:5m?`2VOT40ZWe20:an@`2`OD@0/Gi50;23?`2`QD00[hM10:j9@P2/
S4<0Zhe40:^?A@2ZT4D20:Z=?`0O0:^=A02/STH0[Hi;0:j?C`2_Se80[hmD0;2<G02_REP0/8QE0;66
D@2eQU00^hY@0<6=D`33Se<0^YQ>0;VGC`2gUDd0]YA=0;JCC`2hUE<0^YMG0;^HF02gUV<0]YIS0;FG
H`2aV680[YMQ0:^HH02WUUh0YYMN0:B@GP020:>?G@030::>G02QSE/0X8aJ0080Wh]I0P2LRDh309^8
C@<0VXM<00D0W8]C09V8D02FQDd0TX5908mnAP0308imA@80UG]80`2FO4T05P2GODX0UWa909IlB@2E
O3X0U7/i099i>@2>M3L0Qfd`07mU:P1gGB@0LUPO089V=027JcT0RVlj08Y_>028KSD0QV`a08Q^<`2;
LC@0SVlh08e^=`2:Jc@308QY<P0508Y[=02;K3D0Rf`f08]/=P2:JcD00P29JS@308QY<`0o08AV=022
I380PV@b081Q<P1oH380OUlc07iN=@1oGcH0P60i08=N<@1mFbd0NeT[07UI:P1iFR/0M5PX06aB8@1W
CA`0LUHT07AH9P1fFRP0N5`Z07YN;01lH2h0OF4_07iR<027IcH0QVHe08AV=01oHc40O68_07QQ;@1f
Gb/0M5lZ07aR;`1jH2d0Med/07EJ:`1cF2/0LeP]07AH<01eFC40Mf4`07IP;`1dGR`0Led[07AO:P1e
H2T0N6<Z07UT:`1eHBH0Mf<X07UT;@1iI2l0MEl^06eF:P1VCbD0HDXQ069:901PBR<0GdTT05a89@1J
AbH0EdLU0080EDHU0P1?@1l20511800<05528@1B@b80Dd@S05=48`1C@al0DdDP05E78P1EBB<0DdXS
059:8`1>BB40CDPP101B@b@405=49@0304M09016?b<0A3dQ0080@c`P00H0A3dQ04Dn8P16?b<0ASlR
04Dn8@14?B0204<l7`0e04@m8015?R40AChQ04Xo8`1A@bH0Fd/Z06QB;@1hG3@0Rf`n09mmC@2^RUP0
ZX]M0;FFJP2mX7H0`ZIo0<R^R`3;/i40`:V:0;:KO02/UF`0YXmV0:>;I@2]UG40`JV50=>kV@3J`J80
fl:S0=[6Z`3C`:80c;VI0<VgT`35/h/0]jIk0:6@HP2@P4l0O6/c06mM;@1KBbT0C3`U04<f9@0m=B00
>CDJ03Pe5P0n>Ql0?CTN03hg6`11=QX0ACHI04Xi6`1@>a`0DchO04Lm9012>1l00P0k<a`01@0j=1h0
>cHR03Tf8`0d<Ah0;RdK0080<2hI00<0;b`I02l/6`0_;1d00P0_:al04@0_:b00;bhJ02l^700_;1/0
<2XL030X7@0a9ah0<2DO034T7P0e:A/0<RTJ030V6P0]9AX0:R<I02DQ600S81L08QlH00808R4L0`0Q
81/3020O6PP07AhH200M7A/201`L6P<06a/I0`0J6QP801LI5Q006Q`I0`0J6QP301/K6@8071`J2`0J
6QP301/K6@8071`J0`0K71H201`M5`<07AhH0`0O81X3020Q6`808B8L200O81P2028R6P<08B4I0`0P
81P3024Q6@808R8J0`0S8a/202DP7@0402HQ7@0V8A/09R4K02LS6P809b<H00<09b<G02/T700[91`0
0`0[91`302XS6`0302TV7`0X9Ah0:2DN0080:2DN0`0W91d0100[:1T0;2TJ02`Y6P0/:AX202dZ6`80
;R/L0`0d:1P203DY6@<0=RXJ00H0>BhL03X]6P0k;Q/0?c0K044a6P14<QX204Lc6P<0AS8J0`17<a/2
04Pd7080AC@F00<0ASDG04Lf6018=aT00P19>1X0501:>A/0ECLM05Dg7@1F>1h0F3XP05Tk8@1J?280
FcdS05`n901E=a/0FC/O05Xl801H>Qh0DcDI058d601G>Ad0G3hR05Y18`1H?b40ESdO0P1D>ad01P1E
?1h0EchP05Po8@1I?1`0FchN05e08080GT4Q00T0GD0P05`o7`1J?Ad0Fd4V05a19P1K@2D0GClU05dm
901N?2<00P1N>R820691800406=28@1T@b80I4<R06E48`80ITDT00H0JTLQ06]88P1[B280K4TS06e:
901^BbD206m<9P0407=>901dCbD0MU4W07QC:@80NE@Z0P1hDbT207YE:`0B07]F;01mF2h0OUT_07mJ
<020Fc40PE`b07eH:`22GC00QV4d08EP<`22GC00PE`_08EP<`2:ICP0QF0c08=N<@21G2l0OUT/0P1m
F2/01@1nFB`0OeX]07aG:P1nFB`0P5/^00<0PE`_00<0P5/^07iI;01lEbX00P1nFc4207eJ<0<0O5T_
00<0NeP^07=F;01cER`00P1dEbd407EH;P0607QE;`1iES00NUL_07]H;P1lFRd0OE/]0P1nG2`207iL
;`0307mM<020GS40PElb0080PV0c00L0Pf4d08IR<P26HS80QF4a08AP<022GRh0PEd]0080P5`/00@0
PU`e085K=021Fc@0PE/d0P20FS<207mI<P0807eJ<P1nFc<0P5de085N=P20GCD0OU/c07]H<01jEbl4
081N<00=089P<P24HS@0QfDg08UW>@27HC80R68c08US=02:I3D0RF<d08MQ<P25Gc00Ped^08=Q<`02
08AR=00308ES=@26I3H0QV@f0080QfDg1@29Hc`308YT?@<0RfHi0P2:ICP308UT=`<0T6Xk00<0SfTj
08iX>@2=IcP00P2=IcP02`2>Ic`0SFHk08aU>P2<ICX0SFHk08mX?@2AJSl0Tfa1099^?P2CKcl0UG51
0080Ug=301/0UW9209Ea@@2DL400UW9209Ea@@2BKSh0TFdm091/?02AKCd0TVhn09A`@02DL3`0UG4m
09Mc?`2HM400VGE109Qd@02FLSh0UG4m09Qc?`2GLSh0UG0l09=^>P2BKCT0Tfhj09E`?02FLCd0102C
Kc/5099^>PT0TVdi0P2CKSX00`2DKc/0UG0l09Ia?@0209Mb?P80U6lk00P0UG0l09Ia?@2GLSh0Ug8n
09Qc?`2IM400Ug8m09Qc?P<0VG@o00<0Ug8m09Ia?02DKcX00P2EL3`209A_>`<0Tfhj0P2BKCT2095/
>003091[=`2?JSH0SfXf0080SVTe1@2DKc/309=^>P80TF/j00@0TVdi09A_>P2FLC`0Ug8k0P2IMC/0
0`2QO4L0X7]609mjA@0209iiA0030:1kAP2RODP0Y7m:0080Y7m:00<0YH1;0:J1C02WPTd00P2XPdh0
0`2YQ4l0YX980:N3B@020:N3B@80Z8A:0P2YQD/0202SOTT0Y7m:0:F0B`2VPD`0YH1;0:AoBP2RODP0
XGa70`2TOdP20:=nA`<0XWe600<0WgY509iiA02LMd800P2LMd800`2NND@0XGa70:9mB0020:1l@P04
0:1kA02QO4L0XGa70:5lB080XWa;00@0YX1A0:AnC`2RO4d0X7Y;0P2ONDX02P2PNT/0XG]<09]h@P2J
Md40VGE109Qd@P2FLT80UG1309A_@P2CKT8309Ib?P80UG4m0`2DL3`0102DKc/0Tfhj09=^>P2CKSX2
099]>@<0TF`h00<0U6lj099]>02@JcH00`2>JC@00`2?JSD0T6/f095]>@03099^>P80Tflk0P2DL3`8
09Mb?P80VgI20`2LMd<309ehA0P0VGI000P0U7@i09Ee>P2IMSh0W7M20:1hA02SNDL0Y7Y:0:IjB`P0
W7M300P0VgE809UcA02FL440Tfdl099]>@2AK3L0TVdf09=^=`P0VGA00`2ELS`[ooooo`00:_ooool8
0:QmBP@0XgU70P2TNTP20:EkB@P0Yga90`2VODT30:MnBP80Z7m;00<0XgY60:AkA`2VODT00P2WOTX0
0`2VODT0Y7]70:=jAP040:IkB0@0Yga9202VO4`30:5hA0030:9iA@2SNTH0Y7]70080Y7]7202WOTX0
102TO3h0Y7`o0:Al@@2TNdD20:AjB0030:AiC02TNDh0Y7U?00<0Y7Y:0P2SNDT30:9hB080XWQ60P2S
NDL0602RN4H0X7I409ec@@2LLT00WG=109ab@02KLCl0VW0n09Q^?02GKC/0UV`j09E[>@2DKSl0Tfdn
095[?02?JCX0SFLh08]U=P29Hc@0R68c08US?027HCX0QElh089L=@<0PE/d00<0PU`e07iH<@1nF340
0P1mEc00301lERl0NeD^07YD;@1jE2d0OUHb07eE<@1kEC00Me@^07AB;01bDR/0LE4Z06iA:@80LU8[
0P1aDBX3071@:@0306m?:01]Cb/0KDl[00H0KDl[01P0MUH]07AD:`1bDRT0LE4X079B:@1fERd0NUXa
07eM=01kFb`0O5`]07mM;`23GS40QV4d08YT=`2=I3P0SVDi08YS>029HSL0RF<f08QR<`29Hc80RfHb
08iY=@2?JSD208QV>00308YU>02<IST0SVDi0080T6Dj00<0TF@j095/>02AK3P01P2AK3P00`2>J3T0
SFLh08]U=P0208YT=@0308]U=P2=IcP0SVPi00P0S6Hg00<0RfDh08aV>@2>J3/00P2?JC`00`2>J3/0
S6Hi08]U>00208]T>@0308]U>02<ISL0S6He0080SFPd00D0SFPc08YT=@2;ICH0SFLh091Z>`03095[
?080T6Xk01P0UVDj09EV>P2BIST0T6Li08aX>029IcL0R6Pg08IX=P2;I3T0S6Dj08eV>`2>Ic`0SfPm
091Y?P2AJSl0TV]008eX=02>JCD0T6/g099]>@2CKSX0TVdi091[=`2?JSH808mY>P80Sf/k0P2>JSX2
08eY>@80S6Ph0P29Hc@0102:I3D0RfDf08eW>02>J3T208mY>P80RVPj00<0S6Lj08eW>P2?ISX00P2@
ICX00`2AI3X0RfDh08]U>00608]U>080QV@f00@0QF<e08AR=024HS@0Pf4c0P22H38308ES=@80Q68d
0`23HC<208AR<P80Pf4a1022H302081Q<P0407mP<@1nGc00O5d^07]L;@80NU//0`1hFc4507MJ<00H
06i@:P1/D2T0JThY06E;:01QBBD0GDHT05U5901HA2<0B3lR04Dn8@13?200@3XP03hj8@0l>R<0?3`T
03`k9P11=R80?SHQ03`d8@0h<Al0=2hN02l/7@0/:Q/0:RPK0`0Y:b0202PZ7`<09bTN0P0Q91d00`0P
8a`07b8K01hQ6P0201dP6@0601`O600I7a/06AlK01TO6`0J81`06b4M100L8Qh8020S70D06Q`I0`0I
6aP301LM6@8061hJ0`0I7a/04`0P8aX08B@I028U6P0T:1X09RXK02P/6`0Y;QX0:RlK03Da9@0`;Ah0
;BXK02l/6`0e<Ql0>SPS03Tg800g=Ah0:BDT02LS8P0R8Ad00P0O81X0100P8aX08BLK02<Y7@0W:202
02HW7`0302DV7P0T9Ad092DM00808b@L0P0P8A/201lP6P<07QlI00<07AhH01hP7@0N81d01P0N81d8
01`N6`0P02LR700V8QT0:R@H038Z7@0l<b80@cPT044f800n<QX0@c<L04He6`1??1`0HT`W07QP=02:
KS`0TgDo09Ef?@2SP4X0ZhIA0:j6DP2JM4D0M5Hb04dk9@0d;BD0:B/Z02H[900S:2408RDN02@U7`0W
:280:2LR02HS7P0R7aX802@V8`P09RLQ200T9R<302PY8`D09bPR00H0:2PP02TY8@0Y:B40:RXR02/[
8`0/;2@302d]9@0H02`]9@0];B<0;RhT034_8`0e<BD0>S@V03lh:011>RX0D3LS04li901@>bH0CcdW
04dn9`1:@2L0ASlU04@n9017>RL0B3/X04Pm:@17?bX0AClY048m9`10>bD0?C/T0P16>bT01015>RP0
A3TW04@i9`13>2H2048g9@@0BSTW101;>RP00`1>?RL0CCdV04`l9@0204/k900C04dm9P1??bP0D40Y
0590:01E@BP0Ed<Z05Y5:P1NARX0HDPZ06A9:`1UBR`0GdPX05e69`1HABL0Dd8X04ho:018?BT0A3`Y
048k:@0204Lg:0<0ASHW0`15=BH2048f9P04044e9@10=2@0?S8R03da8@80?30P0P0k;al403``8080
?C4Q1@0e;b<303@^8PP0=BhV00H0=R/W03L/9P0g;2H0>BlV03X`9P0k<BD203`c900:04Tb9019<bD0
BC@S04Le8@17=b00ASPN04Li7`17>Ah0CCdV04hn9`80D40Y01@0CclX04dm9P1;>b@0BCTR04/j:01<
>bT0CS`V058n9@1G@RL0GDHW065::01UCB/0KeTW075K:P1cGS40Lf0h075O>`1/Fcd0J5Lm06EE?080
IE8a00H0HE4`05m@<@1LCS40FDhb05M<<01FC34205iB>P0]05a==P1IBc40Fd/a061?<`1SD380HTd^
05m::`1MDRD0G5<X05iE;01NES40G5Hb05YE=@1GE3D0EU8e061@;`1SD2l0IE<_06QD;`1]Ebh0KeP/
079J;01bFRX0O60`07mP<@23IC<0QfLd08YY=02=JS@0SVTd08iY<P2LKS<0W6ld09ac=@2LMSD0VgXe
09an=P2LP3L0W88g09Yf>P2KMc/0W7Pl09ij?P2PO400XWi20080Y81400@0YGe00:In@@2YPD@0[8A7
0`2^QTT04@2]QDP0/XU70;::A@2cS4L0]8m80;>AA`2dU4L0]YM70;BGA`2kU4l0^I9=0;J?C02cS4/0
/XY<0;::C@2dS540]HeB0080^I9?00/0^Y=@0;^DD@2lUE80_YMD0;nHE@30VEH0^I]B0;RJD@2hVU80
]iUC0;NHE@020;JGEP030;JGE`2bUUL0/IEF0080/IEF0P2`U5D20:nCE0<0Zhe?00<0[8i@0:f?D@2]
Se400P2^T580<02ZReD0ZXaF0:Z<EP2XSEH0YHaD09n9D02KQTd0VHA;09^1B02MPdX0WXA;09Z0A`2D
NT40TWPo09MmA02LPTT0Vh=309^3A@2FOD@0Rg8l07eR<`1cEbl0LED`079E<`2;J3h0RfTl08aZ?02<
JcP0SF`f08e]=02=KC80SFd`08eU=02;Hc80R68a08UU<`2=K3T0Sfll08e]>P2:K3P0R6Pg08MW=P26
ISD0Pf<b085Q<01oGbh0OEd/07aL:`<0MehX00/0MedZ07IL:`1fFb`0MU/^07EJ;@1eFRl0M5T^079G
;01`EBX0KE8W06]@9@0306Y?900A075E;@1`E2`0LEH[079G:P1fFb`0NV0_07iT<@21Ic@0Q6``08=Z
<@22JC00PFP`07mV<01nI340OF<b07aR<@1dGC400`1eGS801P1cG300L5T]06eF:P1[E2P0Le``079K
;`<0L5T]01h0LU/_07AM<@1eGS80MUl[07IO;@1fH2h0M60^06mM;@1YF2X0HU4U05]=801SD2P0HTlW
065=:01PC2T0GTXY05a7:01KARL0FTDX05E1701F@Qd0EdDO05E67`1DAQl0DDDM04m36`1;@QT0CD8R
04i38`1@ABD205569P0305159@1>@b<0CD8R0080ED@V00@0E4<U05=2901B@B<0DT4S0P1A@2801P16
@1h0AClO04Do7`15?R40AChR04Dn9080ACdV0P17?B8204Hl8@0b04Dk8014>Ql0A3XO04<i7P1E@2<0
FT<T069::01_Db`0P64e095_@@2PO4X0ZHA@0:b<H`2dU6/0_j9j0<V]QP3:/8/0`j^70;NQO02_V7H0
WXUL0:2;H02XTV/0]j1n0<ZbUP3H_jT0g/Bc0=k4]@3K_[00e[ZT0<jfT035/Gh0^:Q/0:JHF`2DQDX0
QGQ106]L?`1QDSD0DdDZ04Pl8P13>B00@3DO03/c700h<1/0@3@N044e7`13=b40ACTS04Hj9015>B<2
04@h8P05040d9P0n<R@0?30R03``8P0i;Al0100g:ad01P0/;a`0;BhL02d^700^;A/0;b`K030Z6P80
<BXJ0100<2dN02l/7@0^:a`0;BXK02`Y6P0[:1T0:RLH02TV5`0Z91P0:BDJ02XV6`0Y9Qd09RHN02<T
7P0O8A`07R0K0P0Q8aP01P0P8AT07b0J01hO6P0M7A/071`J01`L70P07AdK0`0L7Q/201/M6P<06Q`I
200H6QT801XL6@806adL0P0J71/401TK6Q006Q`K0P0G6AH201PJ5`806A/H0P0J71T801`L6P0701hN
700M7A/071`J01/K6@0L71X07AdK01lO7@09020P7PP0824K0`0P7aX3024P6`808R4L0P0O7QT2020O
6P04024P6`0R8A`08R4L02<R7@808R4L100S8Qd302@S7P0602<S6`0T91`092@L02DU7@0V9Qh09bLO
0P0X:20802XV7@<0:b@L0P0/9Ad302dV7P0902h[700_;1d0<B/M038Z7@0c:Ad0=BTM03HX7@0g:Ah0
?R`H00<0?bdI0P10;QX2044_6`80@30I00<0@C4J048b6`13<a`00P14=1d00`15=Ah0BSPP04Xh8002
04/i8@<0C3XR00@0CC/S058h7@1B>1d0DcTN0P1D>Ql01P1E>b00ES`Q05Hl8@1B>A/0DCPJ050g6@80
CcHH00/0DCPJ05<j701E?1h0Dc`L05Dn7P1H@B40FT<S05U28P1F?al0Dc`L050i6@0805Dm8@80FcdQ
0P1L?R8205do8`80GT0T0100HD4Z05lo:01N?RD0GChR05ho8P1Q@R<0IDHW06M99`1`BBP0KTPT06a6
8P1ZA1l0JT@M06e87P1aC200M4lS0P1aCRH2079?9`80Le0X0P1dDBT207QB:`0707UC;01jE2d0NeD^
07aF;`1mEc00OUPa08UJ<00208MJ<00308IK<025G300Ped`0080PUd`00D0PV0b085O<@1nG2h0NeT[
07YH:P0207UG:@0307YH:P1gEc00MeL`00L0N5Pa0P1hF2l307UI<0<0NUXa00d0NULa07]H<P1lFC<0
OEXd07aI<`1jEc40Me@^07IC;@1cCb/0ME4]07QE;`1kF300OEX`0080OE/^00H0O5X/081M<`20GC<0
Oe`b07iK<@1mFS0207aI;`0407]H;P22GC00PUd`089M<080PE`_0`20Fbh0201oGBl0OU`^07aJ;01k
FB/0NUPZ07]I:`1lFR`0OE/]1@1oEc<307iF<P0607]H<01mFS00P5dc089P<`24HS@0QF<c0P24Hc02
08=O;`@0Q60`0P23Gbl207mL=003081M=@21GSH0PUlg0080Pf0h00<0Q64i08]R=P2<HcL00P2<HcL2
08eT>080SVDi0`28HcH508MR=@<0RVDh0P2;IST308aW>P80SFLj00<0SVPk08mY?02@JSd00P2AJch0
0`2BK3l0Tflo09=_?`0209=_?`80U7100P2ELD402`2DL400Tflo095]?@2@K3`0Sf/k091/?02AKCd0
TVhn09E_@02GLD80V7930080VWA500@0VG=409Qb@`2GLD80U7100`2CKcl2099^?P80TFdm00<0T6Xk
095[?02BK3d00P2CKCh2099/?@07095[?02@JS/0Ug<o09Ea?@2BKSX0Sf/g08eY=@0308aX=080T6/f
00H0TF`g09=^>@2DKcX0UG0k09Ia?02GLSd409A^?`@0Tfdn0P2GLD8309UcA00309Ma@P2EKd00U6ho
00<0TFdm0P2@K3`308m[>`<0Sf/i0P2@K3X3095]>`<0Sf`f0P2@KCL3095^>00<09E_B02DKTL0TFa0
08mZ?@2?JcT0TFhh09Aa>@2ELSP0UW<m09Md?P2IMT00VgQ20P2LND<02P2KN480VWM109ej@P2NNd<0
Wga40:1mA@2ROdL0Y8590:F2BP2VPd/50:F0B`<0Y7m:00P0X7]60:9mB02TOdX0YX5<0:F0B`2SOTT0
XGa709mjA@@0WGY4102NNdD0102MN440WWU209ii@P2NND8209mj@`80X7]400P0Vfln09]a?`2MLd40
WgM40:1kA`2ROTX0XX5<0:>2C@80YH1<00@0Y7m;0:=nBP2RODT0XGa80P2PNdL0102JMTH0VGE509Mc
@`2ELD4209A`@00;09Ea@@2FLT80U6Tn09I[?P2GK3l0VFlo09U_?@2GKSX0UVdg09A[=@2EKd800`2D
KT4209=]@0<0TV`o00@0TF`h091[=`2>JCD0S6Lc0P2;IS802P2<Ic<0SFPd08mZ=P2AK3P0Tfhj095/
>02?JSH0T6/g09E`?02JMD4309Ud@0@0VWE100<0VgI209Uf@02IMT000P2JMd40102IMT00V7Do09Md
?P2GM3h209Ea@@<0UW920`2GLd<01P2BKCT0Tfhj09A_>`2FLCd0V7<o09Ye@@80W7M3102JMTH409]g
A`03099^>P2AKCT0T6`h0080Sf/g00H0TFdi09=_>`2ELCd0UW9209Mc@`2HM4@209UeA@0309QdA02F
LT80UG5100<0UG=3:oooool002[ooooo202XODX30:AjB0<0YG]90P2VO4X80:MlB@<0YWe90`2WOTX2
0:QoB`030:AkA`2UO4P0Ygi:0080Z7m;00<0Ygi:0:ElB02TNdL00`2VNdP50:MlB@P0YWa<00<0XWU5
0:=jAP2SNTH00P2TNdL20:ElB0030:ImB@2WOTX0Ygi:00H0Ygi:00@0Y7`o0:Al@@2TNd<0Y7]50P2T
NTP00`2TNTX0Y7U<0:AiCP030:AjBP80XgU90`2RN4P20:9hAP80XgU700@0XWQ60:1fA02NM480W790
0P2MLd40102LLT00VW0n09U_?@2GKC/209I/>P0<09E_@02DKSl0TV`m091Z>`2>J3T0S6Hg08]U=P2:
I3D0RF@j08QS>@25H3H0Pehd0P21G382089M<`0607mI<P1nF340OUPa07eG<01lERl0NeD^0P1jE2d0
201nES80OEDa07]E<01gE2h0ME<]079B:`1aDBX0Ke8Z0P1bDR/2075A:P@0L50Y201]Cb/0601eEB`0
M5@[079B:@1aDBP0LU8Y07IF;@1jFS40OEdd07]K;01lG2d0Oed_08=N<@26HC@0RF<f08eT>02>ICT0
RV<h08UR=`28HSD0R68c08US<P2;IS80SFPd08mZ=@80R6Hf00<0RVHf08aV=`2>ICL00P2@ICP00`2A
ICP0T6/g091[=`06091[=`0308iX>@2=IcP0RfDf0080RV@e00<0RfDf08eW>02>J3T0202<ISL00`2;
ICP0S6Hi08iX>`0208mY?00308iX>`2<IST0RfDh0080Rf@i00<0RfDh08aV=`2<ISD00P2=J3@01@2=
J3<0RV@e08]U=P2=IcP0T6Xk00<0TF/l0100T6Xk08mY>P2EISX0U6Di099V>@2?ISP0SFLh08UW=`28
J3L0QfLf08]T>@2<ICX0SFHk08iW?02?J3d0T6Tn0P2AJSl00`2<Ic<0SFPd08mZ=P03095/>00308mZ
=P2>JCD0SfTj00L0SfTj0P2?Jc/208iZ>P80SFTi0P2<J3P208YT=@0408]U=P2<ISL0S6Hg08eW>080
SVPi0P2:J3X00`2<IcX0SFLj08mV>P02091U>P03095T>P2;ICP0RfDh00H0RfDh0P26I3H208ES=@04
08AR=023HC<0Pf4c08=Q<`<0QF<e0P24HS@308=Q<`80Q68b0P23HC43089P<006085O;`20HC80Of0a
07mP<@1nGc00O5d^0P1kG2d00`1jFb`0N5/a07QK<@0407MJ<080MUT_01P0L58/06iB:`1[CbX0IT`Y
069:9P1NAbD0FTHU05U5901:@B@0B3lR04@m8@10>R00?SXQ03/i8P0l>R<0>cXU040e8@0m=B00>c<P
03L`7P0c;Ad0;R/L02/Y6P0Z:1/302PZ7`809bTN0`0V:1d2024T7@04020S700O8Q/07R4J01hQ6P80
7B0I0P0I7a/201XP70806b4M0`0L8Qh8020S70806adJ100J71T201TK60<05adI0P0H7QX301TO6`80
82<J01H08RDJ02@X6P0V:Q/09b/J02T]700Y;QX0=C4U030]7P0]:Q/0;b`K03Db7`0i=b80>CLP03Le
7P0Z9R<0:2@Q02<R7@0O81X07b0H020S6P0P9QX08RPL0`0V9al00`0U9Qh092DM02@U7@0202<T7080
824K0P0O81X401hO6@P07R0M200L7Q/0800U8Q/09R8I02PT6@0`:Q`0>S<Q03lg8P10=Al0?C<J048b
6`13<aX0CCXL05a89@1bFc40QV`k09=e?`2FND40Wgi90:V6D02_Qe<0WgU:07iN>01G@bX0>C4V02`[
9`0X:b@09BPQ028U7P0T9Al09bPR02TX8`0V9B008R4L200T9R<802HW8@P092HS200W:28202PX8004
02TY8@0Z:R80:b/S02`/90<0;BdU01P0;2dU02d]8`0^;R@0<BlS03Da9@0j=2H0?SLW040i:@1?>B@0
D3XU054l9`1??bP0CSlX04]1:017@2H0ASlU04Xk:018>bP0BC`Y04Tn:P16?RT0@cdW040k9@0o>R@3
04Dj:00304@i9`13>2H0@cPV0080@SLU101:>BL404/j:00H04hn9`1=?BH0C3`U04/k901<?2D0CCdV
04lo:01@@2T0DT0X05E1:01G@bX0FTDZ05i6:P1QB2X0I4T[06E:;01OB2P0GTLX05U6:01D@bT0CSlX
04Pm:@14?2T0@S/Y0P17=bP304Hf9`<0ACDV0P12=RH01P11=BD0@3@T03lc8`0n<R80?C4Q03``80@0
?C4Q100n<R8203H`90@0=BlS0P0d;R8803D^9P0803H[9`0g;2H0=b`V03P^9@0j<2H0>c4U03/b8`0l
<b@204La8`0404Hc8P17=B40AcLP04Ph8@80B3XP01P0CShW04lo:01@@2T0DD4Z0510:@1>?RL0C3`U
04/k901;>RP0C3/Y04hl9P1C?bH0F4<X05m8:@1TCB/0Idl]06mI:01aFb`0Leha07EO>01cGc`0Ke`n
06YI?@1XEcd206YG=P0606MG=P1TECH0HE<f05iC=`1MDSH0Fe4f0P1NDSX07@1KCcL0FT`b05e=<`1Q
D3@0IE8d069?;`1PBb`0Ge@W061D:P1OERd0GeL`05eG<`1KEc@0FE@d05MD=@1RDS00IE8a06ID<01Y
ERh0KEL^071I;@1bFR`0Le/]07YN;P1nGc00PF<a08EU=028Ic@0RfLc0080S6Lb00P0VF`c09Y]=02I
Kc<0VW@e09Yg=@2INcD0VWhe09]o=P<0X7a01@2ONcl01@2SNch0YGe00:Mo@P2ZPTD0Zh=60080[8A7
00L0Zh=60;68AP2aRD@0/X]60;>=AP2dT4H0]9=60080]II60100^I9=0;RAC02fSd`0]Hi=0;F=C`2e
SE00]HeB0;J>D`2hTDh0^I9?0;ZCD02kU540_9EB0;fFD`2nUe@0_iQE0P2gVE000`2gVE40]iUC0;JG
E0020;JGEP040;JGE`2cUeP0/iMH0;>GF080/YIG0`2aUEH80:j@DP80[8eF00L0[8mG0:V?EP2WSUD0
XXaB09n9C`2LR4d0YHQ>0080YhY@01<0XhI<09j1A`2LOdD0X8=90:B7C@2MQDD0Vh=509Ak@P29L3X0
OF8c07ML<@1hG3D0Nelj08aZ?@2=Jch0SF/m08e/>@2=K3L0SFdd0080SFdb00h0SVHe08US<P27HC00
RFDc08]Z=`2=KCX0RV`h08MY=@25IC@0Q6@c08=S<P22HS40P60_07iN;@80OEd/00L0MehX07MM:P1g
GBX0MedZ07IL:`1eFR/0MEX]0080M5T^00@0LeL_079F;P1_Db/0K50X101ZCRH2075E;@0<075F:`1c
F2/0MU//07YP;`1nI340P6Hc08=Z<@22JC00PFP`081W<@1oIC80OF<`0P1lHS402`1bFbl0Le``07AM
<@1dGC40Le``075J;P1_F2`0KEHZ07=L<01bFbl0LEX^0080L5T]00/0LU/_07AM<@1eGS80MEh/07MP
;P1gHC00M5l`06aJ;01UE2P0H4lS05]<8@0205m<900A05e9901LB2D0FTHU05U49@1H@b@0Ed8U05E1
7P1E@al0ET@P05E58@1CAB00DDDO04e47@1;@Q/0CD8R04i38`1?A2@00P1@ABD0101?A2@0CT<S04e2
8P1CA2D3059390@0DD8S00H0AClM04Do7`14?Qh0A3dP04@m8@14?B<204<k90<0AS`Q00<0AC/P04@j
7`14>Ql00P13>Ah0<P1D?b80FD8S06599`1_Db`0PF8f099`@02QODT0ZXE@0:b<H`2eUF`0`:=k0<Z^
QP39/8P0`JV30;BNN@2[UG00XXeP0:F@I@2^V740_JJ40<feV@3G_jL0fL2/0=Rn[@3E^:P0dKFM0<Vb
R@30[7L0/Z9V09nAE02;O4<0Nfhi06EF>@1LC380Cd4V04Di7`11=ah0?CDN03Xb7@0g<A/0?c<M040d
7P12=R00A3PR04Di8`14>280@cLQ048f800m=2D0>c8S0P0h;b001P0f;Ah0=2/L03@[700d:a`0=B`M
02`_7080;2dK00<0;RdK02h[6P0`:QX00P0`:AT01@0_;1d0;R/L02h[700]:Q/0:bPI0080:RLH0140
:BHG02XT600Y9AX0:BDJ02TV7@0V9Qh08b@N01lQ700N81/08B<H020R5`0P8AT07b0J01hO6P0M7A/0
71`J01`L700801dM6`8071hK0`0K7AX301XL6@P061XI200J71T201/M70806Q`K0`0I6aX00`0H6QT0
6Q`K01XL6`0>01XL6`805aTF0P0H6QL201TK60806Q`I200L71X00`0N7Q`07AdK01`L6P0201/K6@03
01dM6`0O7ad0820N00P0820N200P8A/3020O6P<08B0K0P0R8A`201lN6@8081lJ00<08B0K028Q700R
8A`0100R8A`302<R7@<092<N00@092@L02DU7@0U9Ad09BDM100V9Qh802XV7@<0:b@L0P0/9Ad302dV
7P80;R/L00@0<B/M038Z7@0c:Ad0=BTM0P0g:Ah203h]6@80?bhJ0`10;a/01P11<1`0@C4J044a6P12
<Q/0@c<L04@d7@80ACDN00@0ASHO04Xh801:>200BSPP0P1;>B4304`j8P<0DCTO00<0DSXP05<k8@1C
>b400P1D?2800`1A>Q/0D3TJ04lh6@0204hg600;050i6P1B>a`0Dc`M058k6`1D?Ad0Ed0P05U28P1H
@B40ESlO058k6`1@>AT0201E?B4205Xl8080FcdQ101L?R80401O?bP0GShW05hn9@1O@2@0H44T0652
8`1SA2D0I4HT06i::01/B2H0JDDQ06Q57`1XAAd0JdPN06m<8P1bD2<2075>9P80LTlW0P1cD2P207AA
:@80N58[00@0NE</07YD;@1kEBh0O5H_0P1mEc0208=F;@0:08=H;P25FS00QE/a08AM<P24Gc<0QF0d
085O<P20GS40OE/^07]I;0@0NELZ00@0MUH_07MG<01gEc00MeL`1@1hF34507UI<0<0N5P_0100NEH`
07YG<@1kF380O5Tc07]H<P1iES00Me@^07IC;@1dD2`0MU8^07QE;`1kF300OEX`07eK;P1lFRd0O5X/
101nFc4307eJ<00407aI;`1oGC00Oed`07mM<080OU`_0`1mFbh00`1oGC00OE/^07aJ;@0307YH:`03
07]I;01lFRd0OUHb0080OUHb1@1mEC401@1kF300OEXb07mL<P22H3<0Q68d0080Q68b00<0Pf8_08=O
;`23Gbl01P23Gbl207mL=004081M=@21GSH0PUlg089O=`80Pf0h0`2;HSH208aS=`<0SF@h2027HSD3
08YU>0<0RfHi0P2<IcX208iX>@0308mY>P2@JS/0TF/l0080TV`m00<0Tfdn099^?P2CKcl00P2CKcl2
09A`@080UG5100/0Tflo099^?P2AKCd0T6`l08m[>`2@K3`0TVhn09=_?`2FL440Ug5209UcA00209Yd
A@0309UcA02HLT<0Ug5200<0Tflo0P2BKSh3095]?@03091Z>`2AJc`0Tfdn0080U6ho0P2CKCh0202A
Jc`0T6Xk09Ea?@2CKc/0TFdi08iZ=P2=JCD0S6Pd0P2=JCD2095/>080TVdi00@0Tfhj09A_>`2EL3`0
UG0l202CKCh00`2FL440Ug5209Qb@`0209Qb@`0409I`@@2EKd00Tfdn095]?@<0T6`l0P2?Jc/208iZ
>P<0SVXh0P2?JcT3091/>P80SVXf0P2?JcL3091/>00=095]>@2CKDH0TVe3095/@02@Jch0T6`j095]
>@2BKcL0Tg0h09A`?02FLSh0V7A009Yf@P0309]g@`0909Yf@P2LND40W7U109ik@`2OO4@0XGi60:9o
A`2SP4P0Y85900D0Y7m:0`2SOTT00`2ONTD0X7]60:1kAP020:1kAP0409iiA02MN4<0W7M209ai@`L0
WGY40`2MN44209ii@P<0WgY300H0Wg=209id@P2OMD<0WgM409mjAP2ONdL209imB0060:5lB02PNdL0
X7]709mjAP2NNDD0WGQ40P2LMd<00`2JMTH0VGE509Ib@P0409A`@00909Ea@@2DJCh0UFXm09M/?`2H
KSh0V6hl09M^>P2EK3H0U6/e00<0U6ho0P2CKCh4099/?@06095/>02?JSH0SFPd08aW<`2;IS80S6Lc
0P2=J3@02@2?JSH0TF`h09=^>P2BKCT0SfXf091[=`2EL3`0VWE109Mb?P0209Qc?`0309Ud@02JMD40
VWE10080VgI200@0VWI209Ue@@2HM400V7A00`2GLcl0102HM400UG5109Ea@@2ELD4209Ib@P<0Ug=3
0P2CKSX0102EL3`0UW4m09Qc?`2JMD4209]f@P80VWI60P2IMDD409QdA00@099^>P2AKCT0T6`h08m[
=`2@K3P0TFdi09=_>`2DL3`0UW9209Mc@`2HM4@0VGE509QdA02GLd<0UG5109A`@0<0T6hn:oooool0
02[ooooo202WO4T20:EkB@<0YWa:0`2WOD/80:MlB@<0YWe90`2WOTX20:QoB`030:ImB@2WOTX0Z7m;
0080ZH1<00<0Z7m;0:MnBP2VODT0202WO4T80:IlBP80YGa80`2VODT30:MnBPP0YWe900@0Y7a10:Ak
@`2TNdD0Y7]50`2TNTP00`2TNTX0Y7U<0:AjB0020:AjB080XgU71@2RN4H20:=iA`0<0:9hAP2QMdD0
WWA209ec@@2NM480WG=109ab@02KLCl0VFlm09Q^?02GKC/0UV`j0P2FL4402P2DKSl0Tfdn095[?02?
JCX0SVPi08eW>02:IC/0R6<i08IQ=`24GcD3089M<`0708=N=020FS<0OeTb07mI<P1nF340OEL`07aF
;`0207]E;P0807iF<P1mEC40NeD`07QE;`1fE2h0Le</079B:`1`Db/3079B:`80LE4Z0`1`D2T806e?
:`0H07AD:`1cDbX0LU8Y075A:01cDbX0MUH]07UI<01lG3<0Ne//07aL;@1nG2h0PUd`08EP<`28HSD0
S6<g08eT>02:HcP0RF8g08QR=@28HS<0RF<b08]V<P2=J3@0SVTd0P28ISH00`2:ISH0S6Hg08iU=`02
091U>003095U>02>JCD0SVTe00H0SVTe0P2=IcP408]U=P80SFLh202;ICH00`2;ICP0S6Hi08eW>P02
08iX>`0308eW>P2<IST0RfDh0080Rf@i00<0RfDh08aV=`2<ISD00P2=J3@01@2=J3<0RV@e08]U=P2=
IcP0SfTj00<0T6Xk00P0SfTj08iX>@2BIST0TVHi091U>02?ISP0S6Hg08]W=`80RFLg0P2<IST208eW
>P0908iX>`2?JC`0T6Xm091Z?@2;IS80S6Lc08eX=02>JCD0SfXf0080SVTe00<0SFPd08mY>P2?JCX0
1P2?JCX208m[>`80SVXj0P2=JCT208aX>0P0S6Hg0P2:J3X00`2<IcX0SFLj08mV>P02091U>P03095T
>P2:I3L0RV@g00H0RV@g00@0QV@f08ES=@25HcD0QF<e0`24HS@01023HC<0QF<e08ES=@25HcD208AR
=0<0Pf4c0`23HC42089P<0<0PEl_0P1oH340101nGc00OEh_07eN;`1lGBh207]L;@80N5/a0P1gFS03
07II;`0I07EH;P1bE2h0L5@]06eA;01XCR/0I4`X06199`1KAbH0FTHU04e29P1;@2@0AcdR048k8@0o
>B40?CPR03Xh8@0k>B@0?c@P03`d7`0j<Ql0=RlM038/700^:a`0:bTJ02XX6`0302LY7P809RPM0`0U
9a`01P0R9Ah08B@M024T7@0P8a`07b8K01hQ6P807B0I00@06AlK01XP700J81`06R0L100K8Ad00`0L
8Qh07b8K01lR6`0601lR6`0401`N6`0K7AX06adJ01/M6P806Q`I0P0I6aP301LM6@8061hJ0`0I7a/0
600O8Q/082<L024T6`0S9Q/09BTK02L[700X;1/0:BdL03<_8`0a;Ql0;b`M030]700d<Ah0=cDP03Le
7P0f=1d0;BXS02XW800T91`0824I01lP600O8QT07bDK024W7@809RLO0`0U9Qh302@U7@<0824K0P0O
81X301hO6@P07R0M200L7Q/06P0T8A`0924J02LS6P0_:Ad0=c0P03`d8@0l=1l0?C8L040a7P11<AX0
ASDK05E1801ZDbX0P6Df08mc@@2GND<0VWa80:B3CP2^RE@0Yh5@08e/@`1XD3@0ASTX03</8P0Z:bD0
9RLQ0P0S91h0100W:280:2TS02HW8@0T9Al802@V8`P09BHP200T9R<802LX8P80:2PP00<0:BTQ02XZ
8P0[:b<00P0/;2@202d]9@0>02d^9P0];B<0;RhT034_8`0d<2@0>C<U03df9P0o>2P0CcXU050k9P1@
?RP0DD4Z0511:P1>@RX204]1:080Bc`Y00L0BC`Y04Pm:@15?BP0@cdW044k9@0o>R@0ACXX00<0A3TW
0`13>2H00`12=bD0BCPV04Th9P0204Xi9`80BcXX0P1<>bT00`1>?RL0CCdV04`l9@0204`l9@0C04hn
9`1??bP0DD4Z0590:01E@BP0Ed<Z05Y5:P1NARX0HDPZ06A9:`1UBR`0H4TY05m8:@1IARP0E4<Y04m0
:@18?BT0A3`Y048k:@0204Dh:0<0A3LW0`13=RH2048f9P03044e9@10=2@0?c<S0080?S8R00<0?C4Q
040d9010=2@01@10=2@00`0o<b<0=c4U03H`900203H`9080=BlS0P0d;R8803D^9P0603H[9`0g;2H0
=b`V03P^9@0i;bD0>S0T0P0k<R<02@11;b40@S0R04<b8P15=280AcHR04Ph8@19>R<0BC/Q04lo:002
0510:@0E0551:P1@@2T0CclX04hn9`1=?BH0C3/Y04dl:P1??BL0ED4X05Y5:P1RBb`0Ie0^06YB<01a
FB/0LUX^07AM<`1eGcP0Lell071M?@1^Fcd0JUTm0080Ke`k00H0K5`k06YK?01WFC`0I5Tm06=H?01Q
Ec`205mE?00E05eA>@1KCcD0GU0e06=D=`1UE3H0I54a061=;@1SE2/0HeH/06AF;`1TF380HUPd061H
=01LES@0FeDc06IF<P1XES80JELa06YG;`1^F2l0L5T_0080Le/_01`0N5`]07aM;`1oH340Pf<b08IU
<P28I300RF@`08UT;`2BIc00TfPa09A/<@2EKc40UW<c09Mf<`2GN3D0V7Xd0:B0A02SOd<0XWi20:1l
@02NNSh0W7Pl09]g>`2JMSX0X7Pk0:9j?@2TO3l0Ygm20`2XP4<05@2WOd80/HE40;66@P2aRD@0/H]4
0;:>A02bTD@0/i930;>DA02eSTT0]Xm:0;N@C@2hTE00^I5C0;R@D`2hT5D0]hmD0;RACP2iTTl0^Y=@
0;^DD@030;bEDP060;fFD`2gUdh0]iM>0;NFC`2gUU40^9MD0P2hUUH0102hUUL0]iQH0;NHF02gV5P2
0;JGE`<0]IIF0P2cU5@0102bTe<0/I9B0;2AD@2`TE420:n@D00H0;:?E`2`T5L0/91G0:j?EP2/SeD0
Z8iC0:F=D@2TS500ZHaB0:Z=D`2YS580YXU?0::5B`2QQ4X0XXE;0:F8CP2QQdX0Vh54095g?P25JSD0
OF4a07eP=023IS`0RFa40P2?KCl0102>K3`0SF`i08a[=P2<JcD208a/<`0808aV=`29Hc@0QV8b08ES
<`28J3L0R6Xh08IX=P20I38207mP<@80OUl`0`1mGRl02@1lGBh0N5h[07MM:P1gGBX0Med/07IK;01e
FRd0M5T^07=G;`02079F;P03071D;01^DRX0JdlW00<0JThV0140JdlW075E;@1aEBd0LUL/07AI;01g
G2d0NV0_07eS<01oIC80PVT`085X<020Ibl0OfH`07eS<01lHS40Nf0a07YO<002071I;@07075J;P1b
Fbl0LU/_075J;P1`FBd0KeP/079K;`02075J;P03071I;@1aFRh0LU/_0080M5da0100Le`Z07MO;`1i
Hc80Leh_06ME9`1OCR80GD`Q05a=8P1KBB40FTPP05U78@1HAR80ET<R05E28P1D@B40Dd0R0P1D@Qh0
2@1C@al0DT@O05557`1>AAh0C4<L04Y26`1<@B40CD8R04m4900205159@0304m4901=@R80C44Q00<0
D44R0`1A@R<20593900604@n7014?Qh0@cdM04<l7`12>al0@S/Q0P11>B8304Dk80<0A3XO0P13>Ah0
:`1B?Ah0F44Q06599@1`E2`0PV<e09=a@@2ROTX0ZhIA0:b=H@2fUf/0`jIl0<^_Q`38[hL0_JEo0:nI
LP2VT6/0YY1W0:bFK@2gXG`0aJj>0=6iW@3F_ZH0eKbV0=:iY@3>/Y`0bZnA0<:[P@2hY6l0ZIUN09B5
C01nKS/0KEl`05]=<P1CABX0Ac/Q040f7@0l=1d0>S@N03Pb700e<1`0?34M03hc7`10=B400`11=R80
1010=B40?c@P03X`900i;b<203H/800303@Z7P0c:Ad0<RPL0080<bTM00H0:bhM02//700[;1`0;B/L
02dZ6`0_:A/202lW6P0602hZ7P0]:Ad0;BTM02`X700[9a/0:RHJ0P0Y9AT0200Z91P0:2@I02TU6P0X
9A`09BDM028S7@0O8A`07R0K0P0P8QL01P0O81P07QlI01dN6@0M7A/071`J01`L70P07AdK00@071hK
01/M6P0K7AX06adJ0P0J71T201TK60P061XI200I6aP301XL6`806A/J0`0H6QT@01TK6P805aTF0P0H
6QL201TK60806Q`I200K6aT00`0M7A/071`J01/K6@0201/K6@0301dM6`0N7Q`0820N00P07alM200P
8A/3020O6P<08B0K0P0R8A`3020O6P<08B0K0P0R8A`00`0Q81/08R4L028Q7002028Q70808b8M0P0T
8ah0100V9Qh09BDM02DU7@0U9Ad402@T70P0:BDL0`0[91`202`U7@<0;BHN0P0^:a`0100`:Q`0<RXM
03<Y7@0f:Qh203LY7P<0?bhL0P10;ad3044`7P80@S8K00<0@c<L04@d7@15=Ah00P16=Ql01017=b00
BCLO04Tg7`19=al204Xh80<0BcTQ0P1@>202054i8@@0DSXR0P1?=a/304hf6P06050h701A>Ad0DSXN
058k701D?Ah0ESlP0P1G@2400`1D?Ah0DS/L050i6P0805@l8080F3XN0P1I>al305Xl800605/m8@1L
?2D0GCdV05lo9P1P@BD0HD8U0P1Q@R<02@1Q@b40K4PX06Y6901XA280J4@P06U6801[B200Kd`R075>
9002075>9P80LTlW0P1cD2P207AA:@80N58[00@0NE</07YD;@1kEBh0NeD^0P1lERl0301oDR/0Oe</
081D;@22F300PU/b08AO=@23H3H0Q64g081M<`1nFc40NeP^07UF;0<0N5D[00@0NEH/07EE;P1eEBh0
MED^0`1fERl0101gEc00N5Pa07QH<@1jFS4207UI<00607QH;`1gEbh0MUH]07IF;@1eEB`0N5D_0P1i
ES002P1jEc40NEH`07QE;`1gE2h0MU<]07EA;@1fDRh0N5D_07YG;`1kF2h207aJ;@0307aJ;01lFBl0
O5T_0080O5T_0`1mFS00101nFc40OEX`07eJ<01mFS0207aI;`<0NeP^00P0OEX`07aI;`1jEbd0NEH/
07QE:`1iER`0NUL]07]H;PP0NU@_00P0NePb07eJ=01oG3@0PEhd08=Q=023HC<0Pf4a089P<0<0PUd`
0P21G2l3089M<080OU/c00<0Oe`d081M=@21GSH00P22GcL01023H3P0R68e08QR=@28HSD208US=P<0
RV@g2027HSD208UT=`80RVDh0`2;IST01`2<IcX0SfTj091Z>`2@JS/0TF/l099/?@2CKCh00P2DKSl3
099^?P80Tflo0`2DL4000`2CKcl0TVhn091/?00208m[>`06095]?@2BKSh0Tflo09Ma@P2HLT<0VWA5
0P2KMDH0102ILd@0V79309Ma@P2CKcl3099^?P80TFdm0P2@K3`00`2AJc`0TV`m09=]?P0209A^?`80
Tfdn00X0TV`m095[?02AKCT0T6`h08iZ=P2=JCD0S6Pd08eY=@2>JSH0Sf/g202BKCT7099/?@0409=]
?P2DKSl0UFm009I`@@80Ug5200@0UFm009=]?P2BK3d0T6`l0`2?Jc/208iZ>PD0SFTi0`2>JSX208m[
>`80SFTe0P2>JSH308m[=`0=091/>02?JSh0T6/o095/?`2AKCd0TFdk095]>@2@K3P0Sf`f095]>@2C
Kc/0UG4m09Qd@00409Yf@P0609Yg@@2KN480W7U309ejA02NNdD0X7e70P2QOTP00`2QO4L0XWe80:9m
B0050:9mB0040:1kAP2NND@0WGQ309]f@@@0VG@o102LND<409]h@P80VgI10P2LMd8209eh@`80WWU4
00P0XWI50:5gA@2PMT@0WgM409ehA02LN4@0VWU409Uh@`80W7M30P2KMT80202JMD40VGA009Qc?`2H
Lcl0VGE509QdA02FLT80U7100P2CKcl209A`@00909AY?P2EJSd0UV/n09M]?@2GKC/0UVdi09E/=P2D
JcD0U6ho00<0Tfdn0P2BK3d3095[?00<091[=`2?JSH0SFPd08aW<`2;IS80S6Lc08eX=02>JCD0SfXf
095/>02DKc/0TVdi0P2@JcL04`2DKc/0V7<o09E`?02FLCd0Ug8n09Qc?`2IM400VWE109]f@P2LMd<0
VgM309Ue@@2GLcl0UG4m09A`?02ELCd0Ug<o09Qd@02DL4000`2ELD4209Ib@P80Ug=300H0Tfhj09A_
>`2EL3`0UW4m09Mb?P2IM40209Ye@@80VGE500H0V7A409Ib@P2ELD40U71009=_?`2BKSh2095]>@<0
T6`h00/0TFdi09=_>`2DL3`0UG5109Ib@P2GLd<0V7A409Mc@`2FLT80U71009=_?`0308YX>2_ooooo
000Zooooo`P0Yga90P2VO4X20:MmB`@0Z7i<202WO4T30:ImB@<0Ygi:102XOd/40:V0C080Z7m;102X
ODX40:MlB@P0YWe9202XOd/80:ImB@<0XgY40`2SNTH30:=iA`<0Y7]70P2SNTH30:9iA@0F0:5gA@2R
N4H0XgU70:AjB02SNDL0XGM509me@`2NM480WgE309id@P2MLd40W79009Y`?P2IKcd0V6hl09M]>`2H
LT<0Ug5209I`@@2DKSl0Tfdn095[?080T6Xk00@0RfHj08UT>027HSH0Q5lc0`23GS800`24Gc<0P5Xc
081J<`0207mI<P0407iH<@1mEc00O5H_07aF;`80OUHb00H0O5Ha07UF<01gEBl0MED^07AD;@1aE2`2
07=C;080LU8[0P1aDBX2071@:@P0KDl[01P0Le<Z079B:@1bDRT0LU8Y07=C:P1fERd0NET`07YJ<@1j
FR/0Ne//07iL;P22GC00Q5lb08MQ=02:HCD0Rf8f08UR=`28HCH0R68e08MQ<P28HS40RVDa08eX=02>
JC@208QW=00308YV=02<ISD0SVHe0080T6Hf00<0TFDf08aW<`2<Ic<01P2<Ic<808aV=`P0RfDf00<0
RV@g08aV>@2=IcX00P2>J3/00`2=IcX0S6Hi08YT=`0208]T>@0308]U>02<ISL0S6He0080SFPd00H0
SFPc08YT=@2;ICH0SFLh08mY>P2@JS/208mY>P0408iX>@2=IcP0SfHh08mV>080SVDg0`2<ISL00`2;
IcL0S6Hg08aV=`0208eW>080SVPi0P2?JCX208YU<@0308]V<P2<Ic<0S6Lc0080SFPd00<0S6Lc08mY
>P2?JCX01P2?JCX208m[>`80SVXj0P2=JCT208aX>0<0SFLh0P2<ISL308]U=P80RFLi00<0RfHi08aV
>@2>ICT00P2?I3T00`2@HcT0RV@g08YT=`0608YT=`/0QF<e0P24HS@308=Q<`80Pf4a0`22H303085O
;`0307mP<@1nGc00OUl`0080OEh_0P1lGBh00`1kG2d0N5/a07QK<@0207MJ<00L07II;`1eF2h0MEP^
07AG;@1dES00LUH_06mC;P1ZD2d0IDdY065::01LB2L0FdLV0553:01=@RH0BCdS04Dk8P10>240?CLQ
03`g8@0l=b<0?S<O03/c7P0i<Ah0=RlM038/700^:a`0:bTJ02XX6`<09RPM0`0U9a`202@V6`808RDN
00<08B@M020S700O8Q/00P0N8AX00`0M81T06R0L01XP700201XP70D06b4M200O8Q/0100M7a`071hK
01`N6`0K7AX201XL6@806A/H0`0G7AT201PN6P<06AlK00h07R0K01lR6`0P8a`08RDL02@W700V:Q`0
9b/L02P/7@0a;B40<BhO030]7P0b;ah0=34N03Dc7P80=S@M00P0<2hQ02d[7`0W9a/08R@I020R5`0O
8QT07bDK020V70H09BHN0P0T9Ad2024R7080824K0P0O81X201hO6@P07R0M200L7Q/07@0Q81`08R4L
02HS6P0[9a`0<R`N03L`7P0i<Ql0>S8M03d`7`0n;a`0@C4H04dj701OBB@0MEda08Q]?P2DN4H0U7Y9
09j0C02[Qe<0[HQD09mjCP1mH3h0F4@/03ha800`;BP0:BPS02@S7P0R8ad09RLQ00809bXS00<08bPQ
02@V8`0T9R<01P0T9R<802DV80P092HS00<09BHP02HW8@0V9b400P0V9b4302LX8P0602LW7`0X:200
:2PP02TY8@0Z:R80:b/S0`0/;2@0300];RH0;RhT02h^900`;R80<blS03Pb900l=BD0?SLW04dk9@1>
?RL0D40Y0551:P80DD8[00X0D44Z04m0:@1=?2X0CC`Z04`m:P19?2T0AS/W04<k9P12>RD0@3XT2013
>2H01@18=bD0BCPV04Th9P1:>BL0BcXX0080C3/Y00@0CC`Z04lo:01>?RL0CCdV0P1<?2D04`1>?RL0
D40Y0551:P1B@2P0ED4X05M3:P1JABX0GTHZ0658:P1TBB/0IDX/065::P1PBBX0FTLY05E4:P1?@2T0
B3dY04@l:@11>RP00P14>2P304<g9`@0@SHV0P11=BD2040d9080?c<S00<0?S8R048f9P12=RH00P12
=RH4044e9@0403Pb9P0g<BD0=c4U03H`9080=BlS0P0d;R8803D^9P0603L/:00g;2H0=b`V03P^9@0i
;bD0>BlS0P0j<B80200k;b40?30R03ha8@11=2<0ACHS04Pg8`1:>R<0Bc/T0P1??bP30510:@80CclX
01T0CShW04dl:P1>?B/0DClY05I2:@1LAb`0I4d^06UB<01/E380LUH^07AH<01dFc<0MEdg07EN?01b
GSd0L5/l06iK>`1aGSd0L5dl06eM?01[G3d0JE/n06IK?`1UFSh0I5Xo0080GePn0100GU@k05eC>01P
ECT0IELj06MH>@1TE3<0H50_06ME;`1XES00IePa06UJ<`1XFSD0IUXd069I<P1QF340Je`e0P1/FS80
8@1/FC40KeT`075J<@1cFS80M5/c07MJ;P1jFbl0OEh`081P<@23HC40QF4_08IP;`26HBd0S6@`08eU
<@2>Ic00TFXa095]<@2CKc40UG4c09Ec<`2ROT80XGe10:1l@02ONcl0WGTm09ah?02KMc/0VWHj09if
>@2OMcX0XWXm0:Al?`020:Em@00E0:Al?`2SNch0[h910;23@02`QD40/8Q20;6;@P2aSD40/hm10;:A
@P2bRdH0]8e80;N@C@2jTe80^i=E0;^CEP2iTEH0^91E0;RACP2iTTl0^Y=@00<0^iAA00L0^Y=@0;VB
C`2fU4`0]YA<0;JDC@2gU500^9EC0080^9EE00<0^IEG0;ZHF02jV5P00P2iUeL30;RFEP090;NEE@2h
UUH0]iEE0;JDE02dTU80/i5A0;6?C`2`STh0[he=0080]91D00H0/i5D0;:@D`2`T5<0[Y1B0:b@D@2[
Se020:N9C@0C0:J8C02TQTX0XH=70:22AP2OPDD0X8960::5B`2JOD<0SW4i08=U;`20HS00Q6Df08i_
@@2FMdT0TW4n091_?02>KCX0S6/h08]Z=@0208YY=00908YY<`2;IST0Qf8e089P<P22HS<0Q6Df089V
=P1oHc<0Nf4`0080N5`]0P1iGBh0101jGRl0Nel`07]O<01kGc0307QN;@0<07ML;@1eFRd0LeP]079F
;P1aEBd0L5@]06mC;01^DR/0K50Y06Y>9`1YCBH0JThW0P1[CbP03P1aEBd0LUH^07=H;@1fFbh0N5d^
07]Q<01mHc00OV@a081W;`1oIS00OVD_07eS<01kHC00NUl`0P1iGS4206iG:`0306mH;01`FBd0LEX^
00L0LEX^00`0LU/_07=L<01cG300M5da079J:P1gGc40N68c071K;P1SD2D0FTTN05Y8801LCB@205Q9
800605M88@1FAR80EDDS05A48`1C@b80Dd8T0P1B@R000`1A@b00D4<P04e37`0204]37P0404Q37@1;
@200C44Q04i38`80Cd@T00<0CT<S04a18@1;@2000P1=@200101>@B40Cd8R04m28P1@@b<205549008
04@n7013?Ad0@cdM048k7P11>Qh0@3TO040h8@0o=b0204@j7`H0@cTN0380DCdL05Q17`1RBR@0LEH[
08=T=P2EM440Xh1:0:^6C`2/SEl0^9U[0<BWN`3;/8D0aJb30;RQN02ZU6/0XXaU0:NAJP2`VWD0_ZN5
0<beU@3E_Yl0eknU0=>kX`3>]Yh0bJjA0<F[R02lYWL0/IiV0:2@E@2:NTH0Lf8d065B:@1@A2X0BCdS
03le700i<AX0>38L03Pa7P0f<Ad0=2lL03Ta7P0j<Ql0>c<P03`d8@0m=B80?3@Q03Xb7`0i<Ah0=blT
03D]8P80<b/P00H0<BTN030X7@0`:1d0<2PM034Y7P0Y:ad202X[7@0302/Y700/:1`0;BLK0080;RHK
0P0/:1d202/W7080:RHK0P0Y9AX01P0Z91P0:2@I02PT6@0V8aX08b<K024R70807b4L0P0P8QL01P0O
81P07QlI01dN6@0L71X06a/I01/K6`P071`J0`0K7AX201XL6@<06A/H200H6QT801TK60806Q`K0`0I
6aX301PJ6A006A/J0P0G6AH201PJ5`806A/H0P0J71T801/K6@0701dM6`0L71X06a/I01XJ600K6aT0
71`J01hN700901lO7@P0824K0`0P7aX3024P6`808R4L0P0P7aX8024P6`@08R4L0`0S8Qd202HV7P03
02DU7@0T91`08b<K00808R8J00<08B4I02PT6`0X91/01P0X91/302/T7080;2DM0`0]9Qh202dZ6`04
030Z700b:Qd0<bTM03HZ7P80>2XO0P0n;Qh203l_7`@0@30P0P13<a`01014=1d0ACDN04Hf7`16=Ql2
04Lg8080AcDM0P18=Qh304Tg7`0304Xh801>>200CSPP00H0CSPP1@1<=a`02`1=>1d0CSTN04hi7P1A
>Ad0Dc/O05@l801E?B40E3`P05<k7`1A>Ad0CcLK00P0DSXN0`1G>Ad205Pj7P<0FC/O0100FSXS05`l
9@1O?bH0HD8V06939P1Q@R<0Gd0Q05do7@1XABL0Id@T06I38`1VA240J4HQ06Y88P1]C2<0KdhU0P1a
CRH2079?9`80Le0X0P1dDBT207QB:`80NE</00X0NU@]07]E;P1kEBh0NeD^07iB:`1oDb`0OeD]07iG
;P1oFS00OU/a0P1oGS<0101mFS00O5T_07UF;01gE2X207IC:@80Me@Z0P1dE2d207=C;080M5@]00T0
MUH_07MG<01hF340NUXa07UI<01hF2l0MeL^07IF;@1dE2/00P1cDbX607MD;P80MU<]0P1fDRh00`1h
EBl0NEH^07YG;@0207]I;00707]I:`1iER`0NUL]07YG;@1kF2h0O5T_07eJ<00207iK<@<0NUT^0P1i
F2d307QG;00807]H;P1jEbd0N5D[07MD:P1fDbT0Me@Z07QE:`1iER`207EB;0<0MU<]0`1gE2h02`1k
Ec<0O5Tc07mL=P21GSH0PUle089P<`21Gc40P5h`089M<@21G300P5/_0080OeX^00<0P5/_085L<022
GC400P1mFS80101nFc<0Oe`d081M=@21GSH2089O=`@0QV4d0P27HSD208QS=P0308EP<`26HC@0QV4d
0080QV4d0`27HSD308UT=`80RVDh0`2;IST01P2@JST0TF/j095[>P2BK3/0Tfdl09A^?@80UFln0`2B
KSh309=_?`80U71000P0TVhn095]?@2@K3`0Sf/k091/?02AKCd0Tflo09A`@080V7930`2JM4D0102I
Ld@0Ug5209I`@@2BKSh3095]?@80T6`l0P2?Jc/00`2@JS/0TV`m09=]?P0209A^?`80Tfdn00D0TV`m
091Z>`2>JSH0SFTe08aX=00208]W<`0408eY=@2>JSH0Sf/g099/>`<0TF/j0`2@JST00`2?JCP0TF/l
095[?002095[?0@0TV`m00<0Tfdn09A^?`2EKd000P2EKd000`2CKCh0TF/l091Z>`0308iZ>P80SFTi
0`2<J3P308]V>@80S6Lj0`2=J3/308aX=P80SFTg0`2>JSP00`2;IST0SFPk091/?002095]?@08091/
>P2=JCL0RfLe08iZ>02@K3X0Tflm09Ib@02HM48209Ue@`0709Qd@P2HM400V7A009Ue@@2JMT80VgM3
09ahA00209eiA@<0WWU40`2ONTD20:1kAP090:9mB02PNdH0W7M209Ud?`2GLSd0V7<n09Ud?`2JMD00
VgQ200@0VWM10`2IMT0409Ye@@80VgI20P2LMd<01P2OLd80WWA209id@P2NMT<0W7M309]g@`80VGQ3
00H0W7M309]f@P2KMT80VWE109Ud@02HLcl209Mb?P0409QdA02GLd<0UG5109=_?`80TVhn00P0Tflo
09A`@02DJCh0U6Tl09EZ?@2EJc/0UF/i09E/>080U6/e00@0Tfdl099/>`2BK3/0TV`k0P2AJcX3091Z
>@0<08mZ=P2>JCD0SFPd08aW<`2;IS80S6Lc08iY=@2?JSH0SVTe099]>@2DKc/0Tfhj0P2@JcL04P2C
KSX0Ug8n09A_>`2DKc/0UW4m09Mb?P2HLcl0VWE109]f@P2LMd<0VWI409Qd@P2ELCl0Tflm099^?02D
L3h0UW9009Qd@P80U7100`2ELD4309Ib@P0409A_>`2EL3`0UG0l09Ia?@80Ug8n0P2HLcl209QdA006
09Ib@P2DL400TVhn091/?02>JSX0SFTi0`2@K3P2095]>@80TVhj00T0Tflk09Ea@@2ELD40UW9209Mc
@`2FLT80U710099^?P2AKCd00`29IcL[ooooo`00:_ooool80:IkB080YWa:0P2WOD/40:QnC0P0Yga9
0`2VODT30:MnBP80Z7m;0P2YP4`40:QoB`80ZH1<00<0ZWm<0:UnB`2YOT/00P2XODX20:MlB@030:Ik
B02VODT0YWe900H0YWe9202YP4`80:ElB0<0XgU70`2SNTH30:=jA0<0Y7]70P2SNTH30:9iA@030:5g
A@2RN4H0XgU70080Y7Y801L0XWQ60:5gA@2OMD<0X7I409me@`2NM480WG=109]a?`2JL3h0VFlm09Q^
?02HLT<0Ug5209I`@@2EKd00U6ho09=]?P2BK3d0TF/l08aW>P2:ICP0R6<f08EP<`0308AO<P0508EP
<`21Fc@0PE/d081J<`1oFC800P1nF34207eG<080OUHb00H0O5Ha07YG<@1hES00MUH_07EE;P1cERh3
07=C;080LU8[0`1aDBX806e?:`0>079B:@1aDBP0LE4X079B:@1cDbX0MUH]07QH;`1iFC00NUX[07]K
;01mFbd0PE`_08=N<@25Gc8208UP=00808UR=`28HCH0Qf4d08MQ<P28HS40RVDa08aW<`2=J3<208QW
<P0308YV<P2<Ic<0SVHc0080T6Hd00<0TFDd08]V<P2;IS801P2;IS8808aV=`P0RfDf00<0RV@g08]U
>02<IST00P2>J3/00`2<IST0RfDh08YT=`0208]T>@0308]U>02<ISL0S6He0080SFPd00@0SFPc08YT
=@2<ISL0SFLh0P2?JCX208iX>@0408eW>02<ISL0RVHf08]U=P80S6Hg102>ICL208aV=@@0SFLf0P2>
J3L308YU<@80RfHb0P2<Ic<00`2=J3@0SfTj08mY>P0608mY>P80Sf/k0P2>JSX208eY>@80S6Ph0`2=
IcP208aV=`<0RfDf0P29IcT00`2;IST0S6Hi08iU>@0208mT>@03091S>@29HcH0RF<f00H0RF<f1025
HcD408IT=P<0QF<e0P24HS@308=Q<`<0PV0`0`21Gbl2081N;P80OUl`101mGRl207aM;P0607UL<P1h
Fc40MeX`07II;`1eF2h0M5L]0P1cER`0601fF380LeL`071D;`1[DBh0IThZ065::01LB2L0FTHU0592
:01?@BH0C3hT04Hj8P12=b40?cLR03dg8@0m=R<0?S<O03`d7`0j<Ql0=c0N03@^7P0_;1d0;B/L02`Z
7@809bTN0P0V:1d302DW700702@V6`0S9Ql08RDN028U7P0Q91d082<L01lR6`0201hQ6P@06b4M1@0J
81`801lR6`807R0M00H07AlL01`N6`0K7AX06Q`I01TK600H6QL301LM6@8061hJ0`0I7a/0600M7a`0
7R0K01lQ700Q91d08bHM02DX7@0V:Q`09b/M02l[7`0a;Ql0<RlP03<`7`0c<1d0<c4L03@b6`0e<a`0
<c8P030_7@0Y:QX08bDG020R5`0O8QT07R<L01lT7@8092DM1P0U9Qh3024R7080824K0`0O81X801hP
7@P071hK02007QlJ020Q700T91`0:BHM02`X700b;1`0=C0L03Tb7`0k;b40?2lO03h_6P16=A/0ED4P
06YC:P1nISP0S75208ehB@2FO4T0Y8=>0;28E02[QE@0TW5806aA<`1@>b00=C0/02lZ9P0W91l08b8M
02@W800U:R<092/S02<Z8PP092HS200U9R0802@V8`8092DO0P0U9R00100V9b409bPR02LX8P0W:282
02LW7`0302PX800Y:B40:RXR0080:b/S0P0/;2@0300];RH0;RhT02d]8`0`;R80<blS03Pb900k=2@0
?CHV04Xk901<?BH0CSlX0511:P<0DT8[00T0DT0Z050m;01??2/0CC`Z04Xk:016>BH0A3TU04<h9011
>B@01012=bD404<h9P80B3LU00@0BCPV04Xi9`1;>RP0C3/Y0P1=?2X0601??bP0CShW04dm9P1<?2D0
CCdV04hn9`1@@2T0DT8[0590:01E@BP0Ed<Z05Y5:P1NARX0HDPZ06A9:`1UBR`0HT/[065::`1KB2X0
ED@Z04m0:@19?RX0A3`Y044j:080@STX0`11>2L3040g9P@0@CDU1010=2@204@h:080@cLW0P12=RH2
044e9@80>C<W00H0>38V03La9@0f<2@0=BlS03@^8P0c;B4803D^9P0@03L/:00g;2H0=b`V03P^9@0h
;R@0>2hR03P_800i<240=S0R03P`8`0j<B80?c<S048e9017=R@0BSPT04/i9@H0CShW0P1??bP03@1>
?B/0Cch/054o:@1G@bX0G4L/06A=;P1XDBl0K5@b079D;P1cEC40M5Pc07AJ=`1dG3P00P1cG3X02@1a
GC`0Ke`k06iK>P1/G3/0JU/l06QJ?@1VFcl0IEXn06AJ?`02061J@00;05mH?P1NEc/0HeXm06ML?P1Y
G3`0IULf065B<@1ZE2l0K5Ha06aH<`1]FcD00P1/GC@06P1ZGC<0JE`b075R=`1aH3D0Kehc06iK<@1`
FS<0LUXd07AJ=@1eFcP0MUT_07UI<01lGC40Oeha085O<@24H300Q5h_08=M;025HBl0Qf4`08UT<02;
IS40SfPa095Z<@2CK3<0U6db0P2JMSX209]g>`0809ah?02MNCd0WGTm09ei?@2LM3L0WWHi0:1h>`2Q
NC`20:9j?@0E0:5i?02PN3/0[Whn0:mo?@2^PCh0[h@o0:n7?`2`RSl0/H`n0;6=?`2`RD@0/ha70;J?
C02jTe80^i=E0;^CEP2iTEH0^91E0;RACP2iTTl0^Y=@0080^iAA00<0^Y=@0;N@C@2fSd`00P2gTT/0
0`2gTT`0^9=?0;RBD@020;RBD`040;RBE02kUE@0^iED0;^EE080^YAC0`2iTe80202gUU<0]YEB0;FD
D@2cTTl0/I1=0:n>B`2^SDX0[Ha90P2fSU004@2eSe00/Xm?0;6?C`2aSdl0[i1?0;2AD02ZRTd0Z8Q;
0:J6B@2UQDP0Y8A70::2A@2PP4<0WWi109ioAP2EMSl0RFXc0080PV<]00P0RVXg09Ad@@2KNdP0U7<m
095`>`2>KCP0RVTd08QW=080QfHc00T0R6Ld08MU>023HC@0Oeha07iO<@1oHc@0OV<d07]P<@1eGBd0
0P1eFRd01`1fFbh0Me`_07QM<01iGS40NUlb07]P<`1iGRl00P1hGBh02@1fFbh0M5T^079F;P1`E2d0
Ke</06iB;@1]DB`0K50[06Y>:@0206U=:00A06Y>:@1[CbX0K50[079F;P1cEbl0MEX_07ML;`1iGRl0
Nf4`07aR;`1mHc00OVD_07eS<01lHRl0Nf4`07YO<01hGC000P1gG34306eF:P0606iG:`1_F2`0L5T]
075J;P1bFbl0L5T]0P1aFRh00`1bFbl0Le``07=L<00207=L<008079J;01dG300LU/_06]F:`1OC280
FDLO05Y88P1KC2D205Y;8P0;05U:8`1HB2@0F4PV05M79P1FARD0ETDW05528@1@@B00Cd8P04a27`1:
@Qh00P18@Qh01017@ah0BSlO04]0801=@R8204i38`0304e28P1;@200BSlO0080BSlO00@0Bd0P04a1
8@1<@B40CD8R0P1>@b<01P14?Q`0A3hN04<m7@12>ah0@CXN040i7`80?cLP1@12>1d304<i7P0[058n
6`1I@ah0Hd`S07=H:`25ISL0UG@o0:9oA`2ZQT`0[HiO0;VJJ`35ZGX0b:f00<2XO02bVg40YY5V0:6;
HP2XTFl0/iaj0<>/S03A^YX0el2Q0=JnXP3A^Id0cKFI0<J/Q`2oYg/0]9i/0:NDFP2FQDd0P70o06YH
<P1IBBP0AcdT044g7P0h<1T0=RhI03H_700f<Ad0<RlL030]700e;Q/0=RlL03Pa7P0203Tb7`0503L`
7@0f;a`0=BhK038[8@0a:R000P0_:1h00`0]9Q`0;2DK02dV700202hW7@0802PZ7@0Y:Ad0:2PL02XX
700Z9Q/0;2DK02dT6`0/8aX402XV7@@0:BDL00H0:bDI02PT6@0W8aP09B8I028R6P0P8A/201lQ7080
7b4F00H07QlG01dN600M7QT071`J01/K6@0K6a/801`L6P806adJ0P0J71T201TK608061XG200G6AP8
01PJ5`<06A/J0`0H6QT201LI610061XI0P0G6AH201PJ5`806A/H0P0J71T801/K6@0301`L6P0K6aT0
6QXH00806QXH00<071`J01hN700O7ad0200N7Q`8020Q6`<081lJ0`0Q81/2028Q70H08B0K0P0P7aX3
024P6`@08R4L0P0S8Qd202DU7@0402@T700S8a/08R8J028R6P808B4I200W8aX302/T7080;2DM0`0]
9Qh0200/:AX0;BXK02lY6`0a:A`0=2XN03L[7`0h:Ql0>B/P0P0k;Qd203`_7P<0?C0O00L0?S4P048b
6`13<a`0@c<L04@d7@15=Ah0ASHO0080AcLP0`16=1`204Le7@<0B3HN101<>20404/g7`80BCDL00<0
BSHM04/g7P1;=ah00`1;=ah0201A>Al0DSXP058j801C>b40DSXP054i7`1?=ad0CSHL201A>Ad205Hh
7080EcTM0`1H>Qh04@1I>al0FSXS05`l9@1O?bH0HD8V06529@1O@240GChO05`n701U@bL0I4<T06A3
8P1UA2<0IdHS06U98`1[Bb@0KDdV0080LDhV0P1bCbL207=@:080M54Y00<0N58[07UC;01iDb`00P1i
Db`307YD;@80PELa00@0OUL`07eG<01jEbl0N5L^0P1gEbh01P1jEbl0NEH^07MD;01eDRX0M54Y07EB
:P80MU<[00@0Le</079B:`1aDBX0LE4Z0P1bDR/00`1dE2d0MeL`07UI<P0207QH;`0707MG;P1eEB`0
M5@[07=C:P1bDRT0LE4X07IC;@0407EB;0<0MU<]0P1gDbl01P1gE2h0N5D]07QE:`1iEbX0NUP[07]I
:`80NEH/0P1jEbd0101kF2h0O5T_07eJ<01mFS0207MG;P80MUH]0`1eEB`02@1dE2/0NUL_07QE;@1f
Db/0ME8Z07AA:@1eDRX0MU<[07MD;00307=A:`0307AB;01eDbd0ME<]0080MU@^00/0NeLe07aH=01n
FSH0P5dg085N=P20GC<0P5ha07mM<021G380P5/a07iI;`0207eH;P0307iI;`20Fc40PE`b0080O5Ta
00@0OEXb07iK<`1oG3@0P5de0P21GSH208AO<P80QF0c1026HC@208AO<P80QF0c00@0QV4d08MR=@27
HSD0Qf8e0P28HcH208UT=`80RVDh0P2;IST01P2@JcL0TF`h095/>02BKCT0Tfhj09A_>`80UG0l0P2A
KCd3099^?P<0Tflo0P2AKCd0202@K3`0Sf/k091/?02AKCd0Tflo09Ea@@2GLD80V7930`2ILd@00`2G
LD80UFm009A^?`02095]?@80T6`l0`2?Jc/0102>JSX0SfTj091Z>`2BK3d209=]?P80TV`m00X0T6Xk
08mY>P2<J3@0RfLc08YV<P29IC40RVHb08aX=02=JCD0Sf/g0`2@JS/208mY>P<0SVPi0P2?JCX2091Z
>`80TF/l0P2BK3d00`2AJc`0TV`m09=]?P0209=]?P03095[?02@JS/0SVPi0080SFTi0P2<J3P308]W
=`0408YV=P29I3P0RF@h08UT>080RVDi0`2;ISX0102:ISH0RfLg08]W=`2;IcL208aX>080SFTi00<0
RVHd08]W=@2>JSP00P2@K3`02@2>JSX0RfHi08YU>02<J3P0SVXj095]?@2CKcl0UG5109Ib@P0209Ea
@@80UG4o00@0UW9009Mc@@2GLd40V7A20P2IMD<00`2JMD00VgI109]f@@0209ag@P80WGQ300D0WWU4
0:=nB@2QO4L0WWU409]f@@0209Ye@00309ag@P2MN4<0VGI00080VGI000<0V7Do09Md?P2GM3h00P2F
Lcd309Qb@@<0VG=20P2JM4<02@2JKSd0VW0n09]a?`2KLd00VgI209ahA02KNTD0W7]609ehA00209ag
@`0309]f@P2JMD40VGA00080V7<o00@0V7A409Ib@P2DL400TVhn0P2AKCd0202BKSh0Tflo09AY?P2D
JC`0TfPk09=Y>@2CJCL0TfXf0P2DJcD2099]>@80TF`h102@JcL208mZ=P0?08iY=@2<Ic<0RfHb08aW
<`2=J3@0SVTe08mZ=P2>JCD0TVdi09E`?02DKc/0TF`h091[=`2BKCT0UG0l0080U6lk00<0UG0l09Ia
?@2GLSh00P2IM400102JMD40V7A409Ib@P2DL402099^?P0309=_?`2DL400UW9200<0U7100`2ELD42
09Ib@P80UG0l1P2FLCd0202GLd<0UW9209Ea@@2BKSh0T6`l08eY>@2<J3P0RfLg0P2@K3P2095]>@@0
TVhj00P0U71009Ea@@2ELD40UG5109A`@02BKSh0T6`l08iZ>P<0RfTi:oooool002[ooooo202VNdP2
0:EkB@<0YWa:0`2WOD/80:MlB@<0YWe90`2WOTX20:QoB`030:V0C02XOd/0Ygi:0080YWe900@0Ygi:
0:QoB`2YP4`0Zh1=0P2ZOd`00`2YOT/0Z7e:0:MlB@020:IkB0P0YWe70P2ZPDd30:V0C0<0Z7m;202U
O4P0102RMdX0XWQ80:9hAP2RN4H30:9i@`030:9i@@2RNSl0Y7]50080Y7]50P2SNT@30:9i@`030:5g
A@2RN4H0XgU70080Y7Y800/0XgU70:9hAP2QMdD0XGM50:1fA02OMD<0WWA209ab@02KLCl0VW0n09U_
?@0209Ma@P0409I`@@2EKd00U6ho09=]?P80TV`m00@0SFTi08]W=`29ICD0QV8b0`25HC401P26HS80
PU`e089L=@21Fc@0P5Xc07mI<P80OUPa00H0OEL`07iF<P1nES80OELb07YG<@1iEc4207MG<00307EH
<01dE2d0Le</0080Le</0P1bDR/2075A:PP0KDl[01P0L50W075A:01aDBP0LU8Y07AD:`1eEB`0MeL^
07QH;`1jFR/0Ne//07eK;@20Fbh0PUd`08AN<@27GS80R5lc08QQ=P27H3D0Qf4d08MQ<P27HC00RF@`
08aW<`2=J3<208QW<@0308YW<@2<Ic80SVHb0080T6Lc00<0TFHc08]V<P2;IS801P2;IS8208]U=P@0
SFLh0P2;ICH808YT=@0308YT=`2;ICP0S6Hi0080SFLj00<0S6Hi08]U>02:I3L00P2;I3T00`2;ICP0
S6Hg08aV=@0208eX=00408eX<`2;ICH0S6Hg08eW>080SVPi0P2=IcP0202<ISL0RfDf08MU=@27ICD0
RVHf08]U=P2>ICL0Sf@g0P2@I3L308aW<`D0SFPd00P0S6Lc08]V<P2;IS80RVDa08]V<P2<Ic<0SFPd
08iY=@P0SfTj0P2?Jc/208iZ>P80SFTi0P2<J3P808aV=`80R6Hh00<0RVDh08]U>02=I3P00P2>HcP0
0`2?HSP0RF<f08US=P0608US=P<0QF<e0P26I3H308MU=`<0QF<e0P24HS@308=Q<`<0PV0`0P21Gbl3
081N;PP0OEh_00H0NE`b07QK<@1gFS00MUT_07EH;P1cER`2079E:`0H07IH<P1cEc00L5@_06Y@;@1U
CBT0H4TW05]79P1IAB@0Dd8X05109P1<?2<0B3TR04@h8P12=b<0@3PS040h9@10=B40?CDP03/c800i
<R00=S0P038_800_;Ah0;bdP0`0X:Ql202LY7P<09RPM0P0S9Ql00`0R9Ah08B@M020S700201lR6`03
01hQ6P0L8Qh06b4M00806b4M100J81`00`0I7a/07R4J01hQ6P0601hQ6P807b4N00H07R0M01`N6`0K
7AX06Q`I01TK600H6QL301LM6@8061hJ0`0I7a/0600L7Qd07AlL01hP7@0P8Qd08RDN02@W7P0U:1d0
9RTN02hZ7P0a;Ql0=34R03@a800b;a`0<BlJ038`6@0d<Q/0=SHN03<b7@0[;AP092LF024S5P0N8AP0
7B8K01dR70<092DM0`0U9Qh202HW7`04028S7@0Q8Q`08B8L024R7080824K0P0O81X801hP7@P071hK
02006adJ01hP7@0S91h09BDK02PV6P0/:AX0<BhK03Pc800j<2H0?30T03d`7`12<QT0CCXL05i88`1b
Fc40OfLk08MiBP2>N4H0Vga60:f6C`2dReD0Xge>085Q>P1TAbD0?C<a03D]:P0Z9B408b8M028U7P0R
:B408R`S020/8PP092HS200T9Al802@V8`808b@N00<092DO02DV800V9b400P0W:2801`0X:B<09RHN
02LW7`0W9al0:2PP02TY8@0Z:R800`0[:b<03P0];RH0;RhT02d]8`0`;R80<RhR03La8`0j<b<0?3DU
04Hl8`17?B@0BclW04m0:@1A@BX0Dd4[0P1D?bX01@1C?Rd0DSd/04hk:P1:>BL0AcPU0080A3LT00@0
@cPT044f9011=R@0@CHT0P12=bD304<h9P0;04Lf9018=bD0BCPV04Xi9`1;>RP0C3/Y04dl:P1>?B/0
D40Y04lo:01>?RL00P1=?BH04`1??bP0DD4Z0592:`1B@2P0ED4X05M3:P1JABX0GTHZ0658:P1TBB/0
IDX/06=<;01RBb`0G4T[05I5:`1@@BX0BChZ04@l:@11>RP00P12>BP3044h9`<0@3LV2011=BD01P15
>BT0A3PX04@h:013=bL0@SHV044e9@80@3@T0P0j=2P01P0i<bL0=c4U03H`900e;b<0=2hR03<]8@P0
=BhV00H0=b`X03L/9P0g;2H0=bdT03L]8`0g;B4203L^7`0:03<a900e<R<0>38T03`c9011=2@0AC@T
04Pe901:=B@0CCdV04`l9@<0Bc/T0140C3`U04hn9`1??bP0Cch/050o;@1B@2X0ET8Y05]6:`1RBb`0
ITl]06YB<01aD2l0LU4`079D<P1cES@0LeTf07=K=`0207=M>080KU/j00H0Je/j06YK?01XFSd0IU/o
06EJ?P1TFSl2061L@@15061J@01PFch0I5e006YQ@P1ZGcl0IeXh069E<`1/DS40KU@c071H=01bG3D0
LUle07=R=P1cHS@0LF<d07IX>@1eI3H0LV4e071M<`1aFc@0LUXf07EK>P1fG3/0MUTa07YJ<`1lG3<0
Oehc085O<P23GS40Ped^089L;@20GS00PEl_08EQ<@28HS40SFDb091W<`2CJ3<0U6Td09=_<`2DL3@0
UG4e09Mc=`2IMCT0VgLk09ei?@2NNSh0W7@g09ee>02OMcX0X7Pk0:5i?02PN3/0WgLj09if>@2/NS/0
[G`j0:em>`2]P3`0[X@l0:j7?02^RC/0[hXl0;6:A@2cS4L0]8e:0;J?CP2hT580^91C0080^91E00P0
]i1=0;VBC`2kU540_9EB0;^DD@2hTDh0]Hi;0;><B@80^I=<00H0^95<0;RACP2gT4l0]hmA0;J>D02f
SU420;ZAC`80^I1>0`2hSdd04`2gST`0]95=0;>@C02bSd/0/Hi:0:n<B02]RTH0[8U50:^8A02gRdX0
]XY90;>:B02bRdP0/Ha80;6>BP2bSd/0/Y5<0;2>C`2^S4d00`2[RDX06`2YQdP0Y8930:1n?`2FMCl0
SVdg08ET;P22HB/0QVD_08i]=`2EM3h0VGQ209Ad>`2ALCP0S6/e08MV<@24Hc00Pf4a08=Q<`24HS@0
PV4f07mN<`1kG300NE``07]P<`1jHS@0Mela079L;@0207EJ;`0407IK<01gG340N5db07YO=080Nf0e
00T0NEha07QM<01hGC00MU/`07AH<01aEBh0KU8]06a@:`1[CR`00P1ZCB/306Q;:@0906U<:P1[CR`0
K4l]079F;P1cEbl0MU/`07QM<01jGc00O68a00@0O68_00@0Nf4`07UN;`1hGC00MU/`0P1eFC4206eF
:P80K5DY00@0KEHZ06mH;01`FBd0LEX^0P1`FBd00`1bFbl0Le``07AM<@0207=L<009079K;`1cFbl0
L5L^06YC:@1TCRD0GT/S05a:901KBBD0FDTU0080FD`R0140F4XS05Q:9@1GBBH0EdPW05I79P1FAbP0
D4<S04m28P1;@200BD0O04M17`16@Ql0Ad<P04I38019?Qh0BSlO04a18@0204e28P0304a18@1:?al0
BChN0080BD0O0`1:@B0304]28@0804I07P15?al0A3hN04<l7`12>al0@CXP040h8@0o=b02040f6`80
@CLL1012>1d0:`1C?aX0FT@M06E>901dFB`0QFLe09Ed?P2QOT@0Z8A80:j@GP2jW6X0`jMg0<BYNP2i
XG<0[IIZ0:F@I@2SSV<0[IIg0;RQPP38/I80dkbM0=FnW`3A^Y/0c;FF0<VbT`2oYg/0]im_0:VDG@2J
Qdd0R7M107AS=`1PCB`0DD0V048g8@0k<a`0=BdH03</6@0c;QX0<RlL030_7@0];1X0<RdJ03<^6`0d
;a`00P0e<1d01@0c;Q/0<B`I030[600]:B00;2PO0080:RHM00H0:BDL02PT6`0Y9A`0:RHM02/W7P0V
:1d202LW7@0302PU700Y9A`0:R<K0080:b8K1`0Y91h01`0X8ad0:bDI02PT6@0V8QL0924H024Q6@0P
8A/00P0O8A`201lQ5P0301hO5`0M7QP071dH00806a/I00<06QXJ01/K6@0K6aT01P0K6aT301XL6@80
6A/H0`0H6QL801LI60P061XG0`0I6aX201PJ6@<05aTH400H6QT201LI5P8061XG0P0I6aP201XL6@P0
6QXH00L071`J01/K6@0J6QP06ATG01XJ600K6aT07AdK00T07QhL200P8A/3020O6P<08B0K100R8A`3
024P6`D081lJ0`0Q81/3028Q700302<R7@0S8a/08b<K00<08R8J0`0Q8AT802HR6@<0:b@L0P0/9Ad3
02dV7P0802/X6@0/:AX0;bTK034Y700d:Qh0=b/O03T[800j;24203P/7080>BdM0`0j;Qh01@0k;al0
@C4J044a6P12<Q/0@c<L0080A3@M0P15=Ah01014<QX0AC<K04Dc6`15<a/204Hd7080AcDM0`19=b43
04Pf8080AcDO00<0AC<K04Hd7017=Ad00`19=al204Pf7P80D3PP00@0DCTQ050h801@>200CcLO0P1>
=Qh8050h70<0EcTM0P1H>Qh305Tk7`80G3`U00h0GCdT05ho8`1N?b80GChO05`m7P1L?Q`0H44T0652
9@1Q@R<0HdDS06E79@1WBBD0JD/U06Y<9P80LDhV0P1bCbL207=@:080M54Y201iDb`207mG<`0907eG
<P1iES00MeD_07AD;@1cDb`0LE@/07QE;`1gE2h0ME8/00<0Le0Z00H0M54[07EB;01bDR/0L50Y06m?
:01^CRL2071@:@0407=C;01fERl0NETb07IF;@80MED/00D0M5@[07=C:P1bDRT0LU8Y075A:00207AA
:`<0Le0Z00/0M54[07IC;@1gE2h0N5@`07MC;`1gE2h0Me@/07MD:P1hERT0NUP[07]I:`0307UF;0<0
NUL]0P1kF2h0101cERh0LUD]079E;@1bEBd2075D;080L5<[00<0N5D_07MD;P1eDR`00`1cD2X01`1d
DB/0ME8/075A:P1aDBX0LU8[07=C;01dE2d00P1eEBh0301fERl0NUHf07aH=P1nFSP0Oe/g081M=`1o
G3@0OU/a07eJ<021Fc@0OeTb07aF;`80NeD^00@0O5H_07mI<P21Fc@0NeP`0P1lFC400`1mFS80OU/c
07mL=002081M=@<0PEla0P22H38308=Q<`80Peha00<0Q5lb08EP<`26HC@00P27HSD408QS=P80RF@g
0`2:ICP01P2?JSD0T6/f091[=P2AK3L0TVdh09=^>@80U6lj0`2AKCd2099^?P<0Tflo00X0TFdm091/
?02?Jc/0Sf/k091/?02BKSh0U71009Ea@@2EKd00UW110P2GLD80102FL440U6ho099/?@2AJc`2091/
?080Sf/k0`2>JSX0102=JCT0SFLh08iX>@2?JCX2091Z>`80SfTj00X0SVPi08eW>02;Ic<0RVHb08UU
<@28I300RFDa08YV<P2<J3@0SFTe0P2=IcX608iX>`0608eW>02>J3T0SVPi08mY>P2@JS/0TF/l0P2B
K3d0202?JCX0T6Xk095[?02BK3d0TF/l091Z>`2>J3T0S6Hg0`2;IcL208YV=P<0RFDe0P27HSP308QS
>@<0RF@j0`29I3L208YU>0<0RfHi00H0RVLa08YV<P2;Ic<0S6Pf08aX>02;IST208YU>@0508aW>P2>
JC`0T6/n099]@02CKT400P2BKD00102AK3l0Tflo09=_?`2CKcl209A`@0<0UG510P2GLSd00`2HLch0
VG@o09Ye@00209]f@@0409ag@P2PNdH0WgY509eh@`<0W7M20P2MN4<209Qe?`0409Md?P2FLcd0UW<m
09Eb?080U74k0`2FL44209Ma@P<0V79300H0V6`k09M]>`2IKcd0VW8o09Ye@@2KMd<209]jA@0609ag
@`2KMT80VgI209Ye@@2IM400V7<o0P2GLSh0102GLd<0UG5109=_?`2AKCd2091/?00:095]?@2BKSh0
U6Tn09=X>`2BIcX0TFLg095W=@2BJCD0TfXd09A[=@80TF`g0P2@JcH408mZ=@0A08iY=02>JCD0SFPd
08aW<`2;IS80S6Lc08eX=02?JSH0T6/g08iY=@2BKCT0UW4m09E`?02BKCT0T6/g095/>02DKc/00`2E
L3`309Ia?@80Ug8n0`2DKd8209=^@@<0TVe00P2CKcl209A`@0<0UG5100<0UW9209Ia?@2FLCd00P2F
LCd309E`?00709A_>`2FLT80UG5109=_?`2AKCd0Sf/k08eY>@0208]W=`0508m[=`2@K3P0TFdi099^
>P2CKc/00P2BKSX00`2AKCT0Tflo09A`@00209A`@00409=_?`2@K3`0SVXj08aX>0<0RfTi:oooool0
02[ooooo202VNdP20:EkB@<0YWa:0`2WOD/80:MlB@<0YWe90`2WOTX20:QoB`030:V0C02XOd/0Ygi:
0080YWe900@0Ygi:0:QoB`2YP4`0Zh1=0P2ZOd`00`2YOT/0Z7e:0:MlB@020:IkB0P0YWe70P2ZPDd3
0:V0C0<0Z7m;202UO4P0102RMdX0XWQ80:9hAP2RN4H30:9i@`030:9i@@2RNSl0Y7]50080Y7]50P2S
NT@30:9i@`030:5gA@2RN4H0XgU70080Y7Y800/0XgU70:9hAP2QMdD0XGM50:1fA02OMD<0WWA209ab
@02KLCl0VW0n09U_?@0209Ma@P0409I`@@2EKd00U6ho09=]?P80TV`m00@0SFTi08]W=`29ICD0QV8b
0`25HC401P26HS80PU`e089L=@21Fc@0P5Xc07mI<P80OUPa00H0OEL`07iF<P1nES80OELb07YG<@1i
Ec4207MG<00307EH<01dE2d0Le</0080Le</0P1bDR/2075A:PP0KDl[01P0L50W075A:01aDBP0LU8Y
07AD:`1eEB`0MeL^07QH;`1jFR/0Ne//07eK;@20Fbh0PUd`08AN<@27GS80R5lc08QQ=P27H3D0Qf4d
08MQ<P27HC00RF@`08aW<`2=J3<208QW<@0308YW<@2<Ic80SVHb0080T6Lc00<0TFHc08]V<P2;IS80
1P2;IS8208]U=P@0SFLh0P2;ICH808YT=@0308YT=`2;ICP0S6Hi0080SFLj00<0S6Hi08]U>02:I3L0
0P2;I3T00`2;ICP0S6Hg08aV=@0208eX=00408eX<`2;ICH0S6Hg08eW>080SVPi0P2=IcP0202<ISL0
RfDf08MU=@27ICD0RVHf08]U=P2>ICL0Sf@g0P2@I3L308aW<`D0SFPd00P0S6Lc08]V<P2;IS80RVDa
08]V<P2<Ic<0SFPd08iY=@P0SfTj0P2?Jc/208iZ>P80SFTi0P2<J3P808aV=`80R6Hh00<0RVDh08]U
>02=I3P00P2>HcP00`2?HSP0RF<f08US=P0608US=P<0QF<e0P26I3H308MU=`<0QF<e0P24HS@308=Q
<`<0PV0`0P21Gbl3081N;PP0OEh_00H0NE`b07QK<@1gFS00MUT_07EH;P1cER`2079E:`0H07IH<P1c
Ec00L5@_06Y@;@1UCBT0H4TW05]79P1IAB@0Dd8X05109P1<?2<0B3TR04@h8P12=b<0@3PS040h9@10
=B40?CDP03/c800i<R00=S0P038_800_;Ah0;bdP0`0X:Ql202LY7P<09RPM0P0S9Ql00`0R9Ah08B@M
020S700201lR6`0301hQ6P0L8Qh06b4M00806b4M100J81`00`0I7a/07R4J01hQ6P0601hQ6P807b4N
00H07R0M01`N6`0K7AX06Q`I01TK600H6QL301LM6@8061hJ0`0I7a/0600L7Qd07AlL01hP7@0P8Qd0
8RDN02@W7P0U:1d09RTN02hZ7P0a;Ql0=34R03@a800b;a`0<BlJ038`6@0d<Q/0=SHN03<b7@0[;AP0
92LF024S5P0N8AP07B8K01dR70<092DM0`0U9Qh202HW7`04028S7@0Q8Q`08B8L024R7080824K0P0O
81X801hP7@P071hK02006adJ01hP7@0S91h09BDK02PV6P0/:AX0<BhK03Pc800j<2H0?30T03d`7`12
<QT0CCXL05i88`1bFc40OfLk08MiBP2>N4H0Vga60:f6C`2dReD0Xge>085Q>P1TAbD0?C<a03D]:P0Z
9B408b8M028U7P0R:B408R`S020/8PP092HS200T9Al802@V8`808b@N00<092DO02DV800V9b400P0W
:2801`0X:B<09RHN02LW7`0W9al0:2PP02TY8@0Z:R800`0[:b<03P0];RH0;RhT02d]8`0`;R80<RhR
03La8`0j<b<0?3DU04Hl8`17?B@0BclW04m0:@1A@BX0Dd4[0P1D?bX01@1C?Rd0DSd/04hk:P1:>BL0
AcPU0080A3LT00@0@cPT044f9011=R@0@CHT0P12=bD304<h9P0;04Lf9018=bD0BCPV04Xi9`1;>RP0
C3/Y04dl:P1>?B/0D40Y04lo:01>?RL00P1=?BH04`1??bP0DD4Z0592:`1B@2P0ED4X05M3:P1JABX0
GTHZ0658:P1TBB/0IDX/06=<;01RBb`0G4T[05I5:`1@@BX0BChZ04@l:@11>RP00P12>BP3044h9`<0
@3LV2011=BD01P15>BT0A3PX04@h:013=bL0@SHV044e9@80@3@T0P0j=2P01P0i<bL0=c4U03H`900e
;b<0=2hR03<]8@P0=BhV00H0=b`X03L/9P0g;2H0=bdT03L]8`0g;B4203L^7`0:03<a900e<R<0>38T
03`c9011=2@0AC@T04Pe901:=B@0CCdV04`l9@<0Bc/T0140C3`U04hn9`1??bP0Cch/050o;@1B@2X0
ET8Y05]6:`1RBb`0ITl]06YB<01aD2l0LU4`079D<P1cES@0LeTf07=K=`0207=M>080KU/j00H0Je/j
06YK?01XFSd0IU/o06EJ?P1TFSl2061L@@15061J@01PFch0I5e006YQ@P1ZGcl0IeXh069E<`1/DS40
KU@c071H=01bG3D0LUle07=R=P1cHS@0LF<d07IX>@1eI3H0LV4e071M<`1aFc@0LUXf07EK>P1fG3/0
MUTa07YJ<`1lG3<0Oehc085O<P23GS40Ped^089L;@20GS00PEl_08EQ<@28HS40SFDb091W<`2CJ3<0
U6Td09=_<`2DL3@0UG4e09Mc=`2IMCT0VgLk09ei?@2NNSh0W7@g09ee>02OMcX0X7Pk0:5i?02PN3/0
WgLj09if>@2/NS/0[G`j0:em>`2]P3`0[X@l0:j7?02^RC/0[hXl0;6:A@2cS4L0]8e:0;J?CP2hT580
^91C0080^91E00P0]i1=0;VBC`2kU540_9EB0;^DD@2hTDh0]Hi;0;><B@80^I=<00H0^95<0;RACP2g
T4l0]hmA0;J>D02fSU420;ZAC`80^I1>0`2hSdd04`2gST`0]95=0;>@C02bSd/0/Hi:0:n<B02]RTH0
[8U50:^8A02gRdX0]XY90;>:B02bRdP0/Ha80;6>BP2bSd/0/Y5<0;2>C`2^S4d00`2[RDX06`2YQdP0
Y8930:1n?`2FMCl0SVdg08ET;P22HB/0QVD_08i]=`2EM3h0VGQ209Ad>`2ALCP0S6/e08MV<@24Hc00
Pf4a08=Q<`24HS@0PV4f07mN<`1kG300NE``07]P<`1jHS@0Mela079L;@0207EJ;`0407IK<01gG340
N5db07YO=080Nf0e00T0NEha07QM<01hGC00MU/`07AH<01aEBh0KU8]06a@:`1[CR`00P1ZCB/306Q;
:@0906U<:P1[CR`0K4l]079F;P1cEbl0MU/`07QM<01jGc00O68a00@0O68_00@0Nf4`07UN;`1hGC00
MU/`0P1eFC4206eF:P80K5DY00@0KEHZ06mH;01`FBd0LEX^0P1`FBd00`1bFbl0Le``07AM<@0207=L
<009079K;`1cFbl0L5L^06YC:@1TCRD0GT/S05a:901KBBD0FDTU0080FD`R0140F4XS05Q:9@1GBBH0
EdPW05I79P1FAbP0D4<S04m28P1;@200BD0O04M17`16@Ql0Ad<P04I38019?Qh0BSlO04a18@0204e2
8P0304a18@1:?al0BChN0080BD0O0`1:@B0304]28@0804I07P15?al0A3hN04<l7`12>al0@CXP040h
8@0o=b02040f6`80@CLL1012>1d0:`1C?aX0FT@M06E>901dFB`0QFLe09Ed?P2QOT@0Z8A80:j@GP2j
W6X0`jMg0<BYNP2iXG<0[IIZ0:F@I@2SSV<0[IIg0;RQPP38/I80dkbM0=FnW`3A^Y/0c;FF0<VbT`2o
Yg/0]im_0:VDG@2JQdd0R7M107AS=`1PCB`0DD0V048g8@0k<a`0=BdH03</6@0c;QX0<RlL030_7@0]
;1X0<RdJ03<^6`0d;a`00P0e<1d01@0c;Q/0<B`I030[600]:B00;2PO0080:RHM00H0:BDL02PT6`0Y
9A`0:RHM02/W7P0V:1d202LW7@0302PU700Y9A`0:R<K0080:b8K1`0Y91h01`0X8ad0:bDI02PT6@0V
8QL0924H024Q6@0P8A/00P0O8A`201lQ5P0301hO5`0M7QP071dH00806a/I00<06QXJ01/K6@0K6aT0
1P0K6aT301XL6@806A/H0`0H6QL801LI60P061XG0`0I6aX201PJ6@<05aTH400H6QT201LI5P8061XG
0P0I6aP201XL6@P06QXH00L071`J01/K6@0J6QP06ATG01XJ600K6aT07AdK00T07QhL200P8A/3020O
6P<08B0K100R8A`3024P6`D081lJ0`0Q81/3028Q700302<R7@0S8a/08b<K00<08R8J0`0Q8AT802HR
6@<0:b@L0P0/9Ad302dV7P0802/X6@0/:AX0;bTK034Y700d:Qh0=b/O03T[800j;24203P/7080>BdM
0`0j;Qh01@0k;al0@C4J044a6P12<Q/0@c<L0080A3@M0P15=Ah01014<QX0AC<K04Dc6`15<a/204Hd
7080AcDM0`19=b4304Pf8080AcDO00<0AC<K04Hd7017=Ad00`19=al204Pf7P80D3PP00@0DCTQ050h
801@>200CcLO0P1>=Qh8050h70<0EcTM0P1H>Qh305Tk7`80G3`U00h0GCdT05ho8`1N?b80GChO05`m
7P1L?Q`0H44T06529@1Q@R<0HdDS06E79@1WBBD0JD/U06Y<9P80LDhV0P1bCbL207=@:080M54Y201i
Db`207mG<`0907eG<P1iES00MeD_07AD;@1cDb`0LE@/07QE;`1gE2h0ME8/00<0Le0Z00H0M54[07EB
;01bDR/0L50Y06m?:01^CRL2071@:@0407=C;01fERl0NETb07IF;@80MED/00D0M5@[07=C:P1bDRT0
LU8Y075A:00207AA:`<0Le0Z00/0M54[07IC;@1gE2h0N5@`07MC;`1gE2h0Me@/07MD:P1hERT0NUP[
07]I:`0307UF;0<0NUL]0P1kF2h0101cERh0LUD]079E;@1bEBd2075D;080L5<[00<0N5D_07MD;P1e
DR`00`1cD2X01`1dDB/0ME8/075A:P1aDBX0LU8[07=C;01dE2d00P1eEBh0301fERl0NUHf07aH=P1n
FSP0Oe/g081M=`1oG3@0OU/a07eJ<021Fc@0OeTb07aF;`80NeD^00@0O5H_07mI<P21Fc@0NeP`0P1l
FC400`1mFS80OU/c07mL=002081M=@<0PEla0P22H38308=Q<`80Peha00<0Q5lb08EP<`26HC@00P27
HSD408QS=P80RF@g0`2:ICP01P2?JSD0T6/f091[=P2AK3L0TVdh09=^>@80U6lj0`2AKCd2099^?P<0
Tflo00X0TFdm091/?02?Jc/0Sf/k091/?02BKSh0U71009Ea@@2EKd00UW110P2GLD80102FL440U6ho
099/?@2AJc`2091/?080Sf/k0`2>JSX0102=JCT0SFLh08iX>@2?JCX2091Z>`80SfTj00X0SVPi08eW
>02;Ic<0RVHb08UU<@28I300RFDa08YV<P2<J3@0SFTe0P2=IcX608iX>`0608eW>02>J3T0SVPi08mY
>P2@JS/0TF/l0P2BK3d0202?JCX0T6Xk095[?02BK3d0TF/l091Z>`2>J3T0S6Hg0`2;IcL208YV=P<0
RFDe0P27HSP308QS>@<0RF@j0`29I3L208YU>0<0RfHi00H0RVLa08YV<P2;Ic<0S6Pf08aX>02;IST2
08YU>@0508aW>P2>JC`0T6/n099]@02CKT400P2BKD00102AK3l0Tflo09=_?`2CKcl209A`@0<0UG51
0P2GLSd00`2HLch0VG@o09Ye@00209]f@@0409ag@P2PNdH0WgY509eh@`<0W7M20P2MN4<209Qe?`04
09Md?P2FLcd0UW<m09Eb?080U74k0`2FL44209Ma@P<0V79300H0V6`k09M]>`2IKcd0VW8o09Ye@@2K
Md<209]jA@0609ag@`2KMT80VgI209Ye@@2IM400V7<o0P2GLSh0102GLd<0UG5109=_?`2AKCd2091/
?00:095]?@2BKSh0U6Tn09=X>`2BIcX0TFLg095W=@2BJCD0TfXd09A[=@80TF`g0P2@JcH408mZ=@0A
08iY=02>JCD0SFPd08aW<`2;IS80S6Lc08eX=02?JSH0T6/g08iY=@2BKCT0UW4m09E`?02BKCT0T6/g
095/>02DKc/00`2EL3`309Ia?@80Ug8n0`2DKd8209=^@@<0TVe00P2CKcl209A`@0<0UG5100<0UW92
09Ia?@2FLCd00P2FLCd309E`?00709A_>`2FLT80UG5109=_?`2AKCd0Sf/k08eY>@0208]W=`0508m[
=`2@K3P0TFdi099^>P2CKc/00P2BKSX00`2AKCT0Tflo09A`@00209A`@00409=_?`2@K3`0SVXj08aX
>0<0RfTi:oooool002[ooooo202UNTL30:AjB0<0YG]90P2VO4X80:MlB@<0YWe90`2WOTX30:QoB`0=
0:MnBP2UO4P0Y7]70:AkA`2UO4P0Ygi:0:QoB`2/PDh0Zh1=0:YoC02YOT/0Z7e:0:MlB@020:IkB0P0
YWe500<0ZX5=0:V0C02YP4`00P2XOd/20:MnBP030:ImB@2TNdL0Y7]700H0Y7]700@0XWM<0:9gBP2R
N4P0XWQ60P2RND<00`2RND40XWXo0:9j?@030:Ak@`80XgY20`2RND401`2QMdD0XWQ60:=iA`2TNTP0
YG]90:AjB02RN4H00`2QMdD0102PMT@0WWA209ec@@2KLCl209Y`?P0509I`@@2EKd00UFm009A^?`2C
KCh00`2BK3d01P2>JSP0S6Pf08UU<`27Hc40QV8`08EQ;`80QV8`0P23GCH00`22G3D0PE/d081J<`02
07mI<P0607iH<@1oEc<0OUHb07eG<P1kF380NUPb0P1hF3400`1fFC40M5@]07AD;@0307=C;0<0LU8[
201]Cb/0201_CbH0L50W075A:01cDbX0M5@[07EE;01fERd0MeL^0P1jFR/0101lFR`0P5/^085L;`23
GC0208IM<@0808QQ=P27H3D0QV0c08IP<@27HC00RF@`08]V<P2=J3<208QX;`0308YW;`2<Ic00SVL`
0080T6La00<0TFHa08aW<`2<Ic<01P2<Ic<00`2:I3D0RfDf08eW>00208iX>@0308eW>02;ICH0RV@e
00P0RV@e00<0RF<f08YT=`2<IST00P2=IcX00`2<IST0RV@g08US=P0208]T>@0308]U>02<ISL0S6He
0080SFPd00@0SFPc08]U=P2<ISL0SFLh0P2>J3T208eW>00:08]U=P2:I3D0QFDd08IV=@27ICD0RfDf
08eT=P2@I3L0TV<g09=T>080SFPd1P2<Ic<00`2>JCD0SFPd08]V<P0208]V<P0308eX=02?JSH0T6/g
00P0SfTj0P2?Jc/208iZ>P80SFTi0P2<J3P208YT=@0408]U=P2<ISL0S6Hg08eW>080SVPi0P28ISP0
0`2:ICP0RfDh08eT>00208iS>00308mR>028HSD0R68e00H0R68e0`25HcD00`26I3H0QfDg08MU=`02
08QV>0<0QF<e0P24HS@308=Q<`04089P<021Gbl0PEl_085O;`80P5h^0P1oGBd807eN;`0P07UL<P1h
Fc40MeX`07II;`1dEbd0LeH/079E:`1aE2X0MELa079F;`1_Dbh0JDl/06A<:01NAbD0FDDT05M38P1A
@2H0CchT04`l8`18>B80ACTS04@g9014>BD0A3TW044f8P0o=b80?CDR03/d8P0h<R80=34R038`8@0a
;b8302X/8@80:B/P0`0X:Ql202<V7`808RDN00@08B@M020S700O8Q/07b8K0P0L8Qh201/Q7@806R0L
0`0I7a/801hQ6P08020R7`0O8Ah07R0M01dO700K7AX06Q`I01TK600H6QL301LM6@8061hJ0`0I7a/2
01`N7@0401hP7@0O8A`08B@M02<V7`809BPO0100;2PL034^7`0f<b@0=C8Q038_700_;AP0<BlH03@b
6`0h>1`0=CDK02d_6@0U:1D08B<F01hQ600L8A/0724M0P0S91`202@U7@0402DV7P0V9al09RLO02HW
7`808R<M0`0Q8Q`3020Q6`P07R0M200L7Q/0800H71/07R0M024S7P0S91`08b<G02PV5`0_;1/0=C8O
03Xa:P0l<RP0?c8R040a7016=AT0E40M06I@:@1cG380QgY=08Id@P2ALcd0Yh170;N<E@2`Qe<0TF`o
07ED:`13>3H0>Bl]02hV8`0S8Qd08B@M01lY800O:b407R/Q200T9R<802@U7`P092HS00D08R<M02<T
7P0S91h092DO02HW8@0202LX8P0702PY8`0V9Qh09RHN02LW7`0X:200:BTQ02XZ8P0302/[8`0>02h_
9`0^;R@0;BdS030^8P0b;R80=S0R03Tb8P0k=2@0@S/Q04<l8P18?RD0CChW0510:@1D?bX205@n:@06
05Ho;`1C?Rd0D3/Z04/h9`18=bD0ASLT0P14=b@2040e8`80@CHT02<0@SLU04<h9P13>2H0@cPV04He
8`17=R@0B3LU04Xi9`1;>RP0CC`Z04hm:`1??R`0D40Y04lo:01>?RL0CCdV04hn9`1??bP0DD4Z0592
:`1B@2P0ED4X05M3:P1JABX0GTHZ0658:P1TBB/0IDX/06A=;@1SC2d0G4T[05I5:`1@@BX0BChZ04<k
:003044j:0<0@3TW0`0o>2H5044e9@<0@SHV0P14>2P01013=bL0@SHV044e9@10=2@203lc8`0803/e
:@0j=2P0>C<W03Pb9P0f<2@0=BlS03@^8P0c;B4803D^9P0603L/:00g;2H0=b`V03L]900g;B<0=bdQ
0P0g;Ql0200b=2H0<c@V03Ld9@0k<bH0?c<U04@b9017<B<0B38T0P1:>R<204Ph8@0404Ti8P1:>R<0
C3`U04hn9`80DD0^00h0DT0Z05I2:@1JABX0GdPY06=<:P1VCR`0Kd`^06m>;`1aD340LE<a079E<`1b
F3<0Le/e07AL=P80L5dl00<0KUhm06aM?P1[GD000P1YGT80:P1XGT<0HUi3069N@`1QGD80HUe006MP
@`1/Hd@0KF9206MM>P1TEcD0KDha06mB<P1cES@0ME/f07QQ=`1jICP0NFLg07UW=@1jK3/0NFTh07AS
=@1aGS@0LE/d07=K>@1fFcd0Me`n07MI<`1kFc@0OEdf081O=P21GS@0Pehb08=M<022G2l0OUd`07mN
<@22H380Qf4b08]S<P2@I3<0TfDd09AV=080TFda01H0Tflc09A`=02FLSH0V7@h09Ue>@2JMSX0W7@g
09ee>02OMcX0X7Pk0:5i?02PN3/0WgLj09if>@2[N3T0ZgXh0:ak>@2]OSX0[H4j0:j4>P2]QST0[XLj
0P2cS4L03P2bRdP0/X]:0;>;C@2eSE00]XiC0;N?E02gT4d0^I9?0;^DD@2lUE80^iAA0;N@C@2cS4T0
/8U60P2jU4d01P2iTTd0]i1=0;J?CP2dS4h0/h]=0;>;CP80^Ha90P2hRdP30;N:A`070;J9AP2aS4H0
/8]50:n:A02^RD<0[HQ20:b7@@020:^6@00:0;J6A02dQd@0/hI30;66@P2`R4<0/HY50;:=A`2cSTP0
[ha<0:b9B@80ZHI600X0ZXM70:R5A@2ROcl0W7Ti08a[=P26IC00PF0Z089Q:`29JC00Sflf0P2BLSL0
1P2DM3T0T70e08YZ<@25I2l0PF0]07mM;`80P5ha00T0Oehc07]L<01hFBd0MeX^07UN<@1hH380MEl`
075K;01dFc800P1eG3<00`1fGC@0Mehe07QO=P0207UP=`0;07YO=01iGS<0NEhc07IJ<P1cEbl0L5@]
06eA;01[CR`0JTd[06U<;01XBb/00P1WBRX02P1XBb/0JD`/06]>;P1]D300LUH^07AH<01gG340NUlb
07]P<@1lHS4207]Q;P0C07]Q<01jH2l0NEh_07QM<01fFc00METa07AH<01cEc00KeP/06iG:`1/EBT0
Je@X06aE:@1]ERX0KeP/071I;@1_F2`0L5T]079K;`0207AM<@0;07=L<01bFbl0LEX^07EL<`1/DbX0
HDXQ05i88@1OBbH0H4hZ05e;9`1FAR@00P1DB1h00`1DB200DdLQ05=68`0205=6900<05=69P1@@RD0
C44S04Xo8@18?b00AClO04E08015@R40AT<R04Tn7P1:?al0Bd0P0P1<@B400`1;@200BSlO04Tn7P04
04Q280<0Ad4O00T0AT0N04Q28017@B40AT0P04Dn8@13?200@S/Q044i8P10>2400P0o=AX2040f6`0^
044g7012>1d0@SPM048h7@1F@Qd0GDLP06M@9P1fFb`0QVPd09Ad>`2OOD00YH530:nAG@2jW6X0`JEc
0<2VM@2dW6`0ZI=T0:F@H`2WTVD0]Yj20<6YS@3>]YX0e;fN0=6jVP3:/i<0`jb<0<6ZR02gX6h0[9EO
09^7C02:Mc`0N6La06IE:P1F@RL0BCLS03hf7`0h<Q`0<bdG034/600a;Q/0<C0N02`]7@0Y:QX0;b`K
030]70<0<BhM00D0;b`K02dZ6@0/:AP0:RLN02TV7@0202LT6`<09R<J00<0:2DL02TV7@0U9a`00P0V
9Q`00`0W91/0:2@K02TR6P0202XQ6PP0:2<O0100;2HJ02PT6@0V8QL08b0G020P600O81X07b4L020R
7@0O8AH07R0E01hO5`0M7QP071dH01/K6@0J6QP06QXJ200K6aT201XL6@806A/H100H6QL801HH5`P0
5aTF00@06A/J01PJ6@0H6QT061XI0P0G6AP201HH5a005aTH0P0G6AH201PJ5`806A/H0P0J71T801XJ
600301`L6P0K6aT06QXH00806ATG00<06a/I01dM6`0N7Q`0200M7A/8020Q6`<081lJ0`0Q81/5028Q
7003024P6`0P7aX081lJ00807ahI0`0P7aX3024P6`<08R4L0P0P81P3024Q6@<08R8J200U8AP302/T
7080;2DM0`0]9Qh0200[:1T0;2TJ02lY6`0a:A`0=2XN03L[7`0i:b00>R`Q0`0d:a`203D/7@<0=RdN
0P0o;aP00`10<1T0@C4J048b6`0204<c700304@d7@13<AT0A38J0080A38J0P15<a/204Hd7080B3LS
00<0AcHR04He8@16=B400`15=2000`13<a`0A3@M04Hf7`0204Ph8@0304Lg8016=Ql0ACDN0080D3PP
0P1?=al404hf7PP0CcLK0P1H>Qh305Tk7`<0FS`P0100GShW05dm9P1L?2<0Fc`P05/l7`1K?1d0G3dN
05do7@1M?b<0GT0T06139@1RABD0I4LU06I:9@1WBbH0J4`U0P1aCRH2079?9`80Le0X0P1dDBT407UC
;0@0N58[0P1jE300101hE300MU@_07EE;`1dE2h2079D;P0:07IB;P1eDBd0Ldl[079>:P1aCBT0LThZ
07=?:`1dD2`0LE4Z06m?:080KDdV0P1^CRL00`1bDR/0MUH_07UI<P0307=C:PD0LU8Y0P1cD2X2075>
:00<079?:@1cD2X0ME8/07MD;P1iEC40N5@`07IC;@1fDb/0MU<Y07ME:01iEbX0NUPZ0`1jEbd307UF
;080N5D[0P1`E2d206mC;0<0KU8[00l0KE4Z07IB;P1eDBd0Ldl[079>:P1aCBT0LThZ07=?:`1dD2`0
LE4Z079B:`1cDb`0M5@]07EE;P1fERl00P1gEc002`1jESH0O5Ph07eI=`1oFcL0Oe`f07iK=@1mFS80
O5Ta081J=@1nF3<0NeD`0080NE<^00<0NeD`07iH<`20FSD00P1kF30207aI<@0407eJ<P1nFc<0Oe`d
07mL=0<0Oel`0P20H343085Q<P05089M<023GS40Peha08AO<P26HC@00P27HSD508QS=P80RF@g0P2:
ICP208iY<P0308mZ<`2@Jc@0TF`e0080TVdf00<0Tfhg091/?02@K3`00P2AKCd3099^?P0309=_?`2@
K3`0T6`l0080Sf/k00H0T6`l099^?P2DL400UW9209=]?P2DKSl209E_@00409=]?P2AJc`0SfTj08eW
>0<0Sf/k0P2>JSX308eY>@0308YT=@2;ICH0SFLh0080SVPi0P2=IcP01@2;ICH0RV@e08]W<`2:IS80
RFDa0080Qf<_00@0R6@`08UU<@2:IS80RV<h0P2;I3T01P2<ICX0SFHk08iW?02>Ic`0SfPm08aV=`80
SFLh00D0SVPi091Z>`2AJc`0TF/l099/?@0208iX>@<0T6Xk00<0SVPi08aV=`2;ICH00`2:ISH208UU
=@<0R6@d0`26HCL208MR>0<0R6<i0`28HcL208UT>0<0RVDi00/0RfP`08YW;`29IC40R6@b08QS=P29
I3P0RVDk08]U?P2=J3`0SVTm08mZ?P02091[?`0308mZ?P2>JCd0SFPl00@0TFdm102BKSh01P2DKcX0
UG0k09Ia?02GLSd0V7<n09Ud?`80VWE000<0Ug8m09Qc?P2JMD000`2KMT4209Ye@080Ug@n00@0UW<m
09Eb?02DLC/0Tg0j0P2BKcT0102DKSl0UFm009E_@02EKd0209I`@@80Ug5200T0VVhm09Y`?P2JL3h0
VW8o09Qc?`2HM400UWE009Mf@@2HLcl00P2GLSh00`2FLCd0UG0l09A_>`0209=^>P0509Ib@P2DL400
TVhn091/?02?Jc/00P2@K3`02@2AKCd0U6Tn09=X>`2AIST0T6Hf091V=02AJ3@0TfXd09A[=@03091[
=080SfXc102>JC8208eX=00808aW<`2;IS80S6Lc08eX=02?JSH0TF`h08iY=@2BKCT209Ia?@05099]
>@2@JcL0T6/g09=^>P2GLSh00P2FLCd209E`?0<0U6lk00<0T6/o099]@@2DKd<00P2EL4@00`2CKT80
T6/o08iY?@0309=_?`80U7100`2ELD4209Mb?P0409Ia?@2EL3`0UG0l09A_>`80Tfhj00/0UG5109A`
@02CKcl0TFdm091/?02>JSX0SFTi08aX>02>JSH0Sf/g095]>@0309=_>`80TFdi0P2CKcl01P2DL400
Tflo099^?P2?Jc/0S6Ph08]W=`<0RFLg:oooool002[ooooo202UNTL40:=iA`80Y7Y80P2UNdT80:Ml
B@<0YWe90`2WOTX20:QoB`030:MnBP2VODT0Y7]70080XgY600<0Y7]70:ImB@2WOTX00P2/PDh0102[
P4d0ZWm<0:QmBP2WO4T20:IkB0P0YWe50P2YP4`20:QoB`040:MnBP2VODT0YWe90:ElB0P0Y7]700@0
XWM=0:9gC02RMdX0XWQ60P2RND<00`2RNSl0XWXm0:9j?0030:Ak@`80XgY20`2RND400`2PMT@0XWQ6
0:=iA`020:EkB@0<0:AjB02SNDL0XWQ60:9hAP2QMdD0X7I409me@`2MLd40W79009]a?`2JL3h0UFm0
0P2DKSl209=]?P07099/?@2AJc`0TF/l08iZ>02<J3H0RVHd08MS<@0308IR<00508MS<@23GCH0Pedf
089L=@21Fc@00P20FS<207mI<P80OeLc00<0OELb07]H<P1jF3800P1iFC80101gFS80M5@]07AD;@1d
E2d207=C;0<0LU8[201]Cb/01P1_CbH0L50W075A:01cDbX0M5@[07EE;080MUH]0P1jFR/03P1lFR`0
OeX]081K;P22G2l0QE``08IM<@28HCH0Qf0e08IP<`26H340Qf4`08UT<02;IS80SFPc0P28J2l00`2:
Ibl0S6L`08iW<002091W<@03095V<@2=J3@0SFPd00H0SFPd00<0RV@e08]U=P2=IcP00P2>J3T00`2=
IcP0RfDf08YT=@0808YT=@0308US=P2:I3L0S6Hi0080SFLj00<0S6Hi08YT=`29HcH00P2;I3T00`2;
ICP0S6Hg08aV=@0208eX=00408eX<`2;ICH0S6Hg08eW>080SVPi0P2<ISL02P2;ICH0RV@e08AV=025
IC@0QfDe08UU=@2=I3H0T6@g099S=`2DHcP208eX<`@0S6Lb0P2;IS40202?JSH0SVTe08aW<`2;IS80
S6Lc08iY=@2@JcL0TF`h202?JCX208m[>`80SVXj0P2=JCT208aX>080RF<d00@0RV@e08]U=P2=IcP0
SVPi0P2?JCX208QV>00308YU>02;ICP0SF@h0080SV<h00<0Sf8h08QR=@28HSD01P28HSD308ES=@03
08IT=P27ICL0R6Hh0080R6Hh0`25HcD208AR=0<0Pf4c1021Gbl2081N;P80Oed]0P1lGBh407eN;`80
OUl`0200NE`b07QK<@1gFS00MUT_07AG;@1bEB/0LE@Z071C:@1eEc40LUH_06iB;@1XCR/0Hd/W05e6
901HA2<0ET8Q058n9@1>?B<0C3XR04Ti8P17>2<0ACPU04Dj9P16>bT0@SLS040h8`0o=b@0?3DS03Tc
8`0f<b@0=38S03<a90<0:bdR0`0Z;24202T[800602@W800S9Ql08bHO028U7P0Q91d082<L0P0O8Q/3
01`R7P0301/Q7@0J81`06AlK00<06AlK200N8AX0200Q8b00828O01lQ7P0M7a`06adJ01XL6@0I6aP0
61XG0`0G7AT201PN6P<06AlK01P06a`N01`N7@0M7ah07b4N024S7P0S9Ql092LN02DX7`0[9a/0<BhO
03Hc900f<b80<RlL02l]600`;QL0<c4J03Xk700f=QX0;BlG02HY5P0Q8aD07R4H01`Q6`0L8Ad202<T
708092DM00@09BHN02HW7`0V9al09bPP0`0R8ad2024R70<0824K200N81d801`N6`0P01PL6`0L81l0
8B<N028S7@0R8QP09R@G02d/6P0e<R40>c8[03dc:P0o<bD0@C8O04@c6@1?>aX0H4XS06aE;026Ndh0
Pg5108a^>02SO440^HaC0;F:E@2LLdD0P5/_04Pj>@0m<S00;bLT02<R7@0P8a`07RPO01dZ800K:b08
02@V8`P092DO200T9R<2028S7@0302<T7P0T9Al09BHP00809bPR00H0:2TS02HV7P0V9Qh09bLO02PX
800Y:B4202XZ8P80:b/S01P0;RlW02h^900];B<0;bdQ038^8P0f<280>C8R03/d900o>Al0@S/Q04Lm
901<?BH0D3hX05<n:@1C?BP0EC`X05Ho;`1D?Bd0D3/Z04Xg9P17=R@0ACHS04Hg9014=b@3040e8`03
044f9012=bD0@cPV0080@cPV0200ASDS04Lf9018=bD0BSTW04/j:01=?2X0CSd[04ln;01@@2T0CclX
04hn9`1=?BH0CShW04lo:01A@BX0DT8[0590:01E@BP0Ed<Z05Y5:P1NARX0HDPZ06A9:`1UBR`0IDh^
06=<;@1MBR`0EdH/0511:P19?RX0@c/X044j:080@3/X0`0o>RL303hi9P@0@CDU1012=RH204@h:004
04<g9`11=BD0@3@T03lc8`80?S8R00P0?3HZ03/e:@0j=2P0>38V03H`900e;b<0=2hR03<]8@P0=BhV
00H0=b`X03L/9P0g;2H0=bdT03L]8`0f;20203H]7P0@034e9`0c=BL0=S@W03Xd9P0n<R@0@c4S04H`
8P17<280BCTR04Ph8@17=b00ASHO04Lg8019>B80Bc/T04dm9P80DD0^00H0DT0Z05E1:01H@bP0GTLX
065::01SBbT206i;;`0606m>;`1_DBl0L5<a075G<P1cFS80Le`c0P1cH3l00`1aHD00L65206iP@`02
06aQA@0Z06]QAP1QH4@0HF14069N@`1SGd80If9406aVAP1]I4<0J5hk069H=@1/CC00Ke0a07=F=01f
GCD0NV<i07aW>01nJSP0O6/g07a_>`1kJcX0MVDg079O=@1bG3L0Le/i07IK?@1gG3l0N5Xd07]K=@1m
GCH0P5lf089O=@23GS80Pe`a08=M<01mGS80Oehc085O<P26HC@0Rf8d08mS=02CIC@0UFDe0P2AKC40
102BKS80Tflc09A`=02DL3@209Ea=@0X09ad=`2NMST0WgLj0:1h>`2QNC`0X7Pk09if>@2MMCP0ZWLh
0:]h=`2[NSP0[7di0:b0>@2]PcT0[X@h0:f6>@2eSTT0/ha70;6:A`2`RDP0/8Q:0;::C@2eSE80]hmD
0;N@C@2iTTl0^iAA0;bEDP2jTe00]i1=0;:;B02_R4D0_9A>0;^CC@2jTTd0^8m=0;J=C@2dRdd0/XU;
0;67B`<0]XU60P2eR4D30;B7A080[HQ200@0[8M10:^6@02[QT00ZXDo0P2YQ3h02P2dQD40/hA00;23
?`2_Q3l0[XI00:n9@P2bS4D0/Xe60:R5A@2TPD420:5n?P0L0:>0@02QOSh0VWLg09=`<028I300Q60/
085N:025HRX0S6Ta099_=@2AKc80Sfd`09=c=P2?Kc@0RFT`08=R;01oGR/0OE/]07eK;P1nFc40O5`c
07UI<01dEbd0MEX_07IN<P1gH3@0M5da071K;P<0MEhd00<0MUle07MP=P1gH3H00P1hHCL02`1jGc@0
NEhc07UN<`1fFS80LeL`071D;`1/Cbd0JTd[06U<;01XBb/0IdXZ0080ITTY00X0IdXZ06U<;01/Cbl0
KE0`079F;P1dF300Me`a07YO<P1lHC80O68a0P1kHBh01P1jH2l0NEh_07QM;P1gG2l0MU/`07AH<080
LeL`00<0L5T]06iG:`1/EBT00P1[E2P01P1/EBT0KUL[06mH;01_F2`0L5T]079K;`<0M5da00X0LU/_
075J;P1fGC@0JE0X05]46`1JA1d0H4`W06=A;@1NBbX0EDDS0P1@A1X00`1@A1`0D4@N0513800204m2
800<04m28P1>@bD0C44S04U08@15?al0A3lO04=07`15@R40A4@R04Pm7@19?Qh0Bd0P0P1<@B400`1;
@200BChN04Pm7@0204U38@80B48P00X0Ad4O04I07P15?ad0AClM04U38@19@b<0Ad4Q04Ho8P14?B40
@c`R0P11>B80100n=1T0?cDJ03le6P10=Q/2044g7080@SPM02X0Ed@L05i87`1XDBD0Me`]08IX=02C
LcX0WW`o0:=o@@2`TUh0^YaX0<2TLP2mXg80/9QX0:NAHP2VTF80ZYEX0;nWS@38/9H0d[ZN0=FnW`3>
]iL0`jb<0;bUP`2iXX00/9UU0:B>E@2AOD80OV/`06eL:01MBb<0CSXQ04<`7`0l=R00>38L038]6@0a
;1T0<BhM030_7@0/;Ad0:BXJ02h[6P0_;1/2030]700602l/6`0^:aX0;2TH02XW5P0Y9Ql0:2DN0P0V
8a`202DR6`0;02HS700W91d0:2DN02DV7P0V9Qh09BDM02LT7@0W8Q`0:B8L02XQ700Y81/0100W8Qh4
02PS7`0802`V6P0X91T09B4F028O5P0O7aL07b0J01lQ700P8Qd201hP5@0601dN5P0M7QP071dH01/K
6@0J6QP06QXJ200K6aT201XL6@806A/H0`0H6QL00`0G6AH05QPG01HH5`0601HH5`P05aTF100H6QT2
01LI60805QPG400G6AP201LI5P8061XG0P0I6aP201XL6@P06QXH00<06a/I01XJ600I6AL00P0I6AL0
0`0K6aT07AdK01hN700801dM6`P0824K0`0P7aX3024P6`808R4L00@08b8M028Q700R8A`08B0K0P0P
7aX201lN6@<081lJ100Q81/2028Q70807alG0P0P81P0100Q8AT08R8J02<S6`0S8a/802DQ60<0:b@L
0P0/9Ad302dV7P80:bPI00@0;bTK034Y700d:Qh0=b/O0P0j;24303<Z6`<0=2/L0P0e;1d203h^5`04
03l_6010<1T0@30I044a6P80@S8K0`13<AT204@b6P<0AC<K00@0B3LS04Lf8P17=R80ASDQ0P15=202
04@c7`03048b6`14=1d0ASHO0080B3PQ00@0AcLP04Hf7`15=Ah0D3LQ0P1?=R000`1>=Al0CC@N04dd
7P0204dd7PP0CSHJ0`1I>al205Xl80<0FcdQ00h0GclX05hn9`1K>b80FCXN05Tj7@1J>a`0G3dN05i0
7P1L?R80GClS05m2901RABL0I4LW06I99`80Id/V0P1aCRH2079?9`80Le0X0P1dDBT307UC;0D0N58[
0P1fD2`02@1eDBd0ME<^07EE;`1dES00MELa07AH<@1eDBd0M50/079>:P02075=:@05079>:P1cCb/0
M50/071@:@1_CbP00P1/C2D206e=9P03075A:P1fERl0NETb00<0LE4X0`1bDRT207=C:P0@07=@:P1b
CbT0LDhX071=9`1aCRP0Le0Z07EB;01gE2h0NEDa07QD<01fDbd0ME8Z07EB:01gEBP0NELZ07YH:P80
NeP^00@0NUL]07UF;01hEB/0N5D[0P1gE2X206mC;080KU8[0`1]DBX0101/D2T0MU8^07A@;01cCb/3
075=:@08079>:P1cCb/0L5<[071C:`1aE2`0LUD]07=F;P1eF30207II<@0;07YE>01kEcL0OETi07iJ
>01nFSH0OU/e07aI<@1kF300P5Xe07iH<`1jE2l00P1hDRd0101jE2l0OUPc081J=@1jEbl207]H<003
07aI<@1mFS80OU/c0080Oe`d0P1nGRl207mO<0<0P60a00H0PF4b089M<022GC00Peha08AO<P25H3<2
08MR=@0308QS=P27HSD0R6<f0080R6<f0P29I3L208YU>080SFPa00<0SVTb08mZ<`2@Jc@00P2AK3D0
0`2BKCH0T6`l091/?002095]?@@0TVhn00P0T6`l08m[>`2?Jc/0Sf/k091/?02BKSh0UG5109Ib@P80
TV`m0P2CKCh0102BK3d0T6Xk08eW>02<ISL208m[>`80SVXj0`2=JCT0102<J3P0RF<d08YT=@2;ICH2
08aV=`80RfDf00X0RV@e08US=02<J3@0RfLc08UU<@27Hbl0QV8^08MS;`28I300RFDa0P29HSL0402:
HcP0Rf@i08eV>`2>Ic`0SfPm091Y?P2;ICH0S6Hg08eW>02>J3T0SfTj091Z>`2AJc`0TV`m08eW>02>
J3T308mY>P0308eW>02<ISL0RV@e0080RVHf0P29ICD308QT=00408MS<`25GcP0QElh08EO>080QV0i
0`27HCX01027HSH0R6<g08QS=`28HcL208UT>080RVDi00P0S6T_08YW;`27I2h0QV8`08IQ=027HSH0
RV@m08aV?`80SVTm00H0SfXn091[?`2?JSh0SFPl08]V>P2:ICT5091[?P<0TF`o00H0Tfhi09A_>P2D
KcX0UW4l09Mb?@2HLch209Ud?`08091[=P2BKCP0UW4l09Qc?P2JMD00VG@o09Mb?@2FLC`209Md?P04
09Ic?@2ELS`0Tg0j099_>@80TFhh0`2DKT4209E_@P<0UW1300P0WW9109ec@@2LLT00VW8o09Mb?P2E
LCd0TW4l095`>`80Tfhj0P2BKCT0202AK3P0T6/g08mZ=P2?JSH0UW9209A`@02BKSh0T6`l0P2?Jc/0
2P2@K3`0TFdm09AY?P2BIcX0TFHi08mU=@2?IC<0TFPd099Y<`2DJcD2091[=080SfXc102>JC800`2=
J340SFPd08aW<`0208]V<P0908aW<`2>JCD0T6/g095/>02>JCD0Tfhj09Mb?P2FLCd0Tfhj0080T6/g
00L0TVdi09Qc?`2GLSh0Ug8n09E`?02DKc/0Tfhj0080TVdi00P0SFPl091[?`2DKd<0Ug9609IaA@2C
KT80SVTm08]V>P<0Tflo0`2DL40209Ea@@80Ug8n00<0UW4m09E`?02DKc/00P2CKSX04@2BKCT0U710
09=_?`2CKcl0TFdm091/?02?Jc/0SVXj08eY>@2>JSH0Sf/g095]>@2CKc/0U70l09=_>`2AKCT0T6`h
00@0Tflo00@0TFdm08iZ>P2<J3P0RVHf0`26I3@[ooooo`00:_ooool30:=h@`80Y7U40`2UNTD20:9g
A0060:=hA@2UNTL0YW]80:MlB@2XODX0ZGi;202WO4T20:QmBP80Yga90P2VNdP20:EjA`P0Yga90P2X
ODX0102WO4T0YW]80:IkB02UNTL20:AiAPP0ZGi;0P2YOD`20:QlB`@0Yg]:00P0Y7]70:ImB@2WOTX0
Z7m;0:MnBP2VODT0Y7]70:9iA@80XGQ400D0XWU50:=jAP2SNTH0XgY60:AkA`020:ElB0P0YGY5202T
NdL01P2MN4@0W7M309]f@P2JMD40VGA009Mb?P80UW4m0P2FLSh0102ELCd0Tflk099^>P2@K3P208m[
=`0808aW<P2<Ic<0S6Lc08]U=02:I3D0RV@g08YS>029HSL208=Q<`04085O<@20GS00OU`^07eK;@80
NeT[0P1lFC40101kF300NUL_07YG;`1iERh207QE;@0307QE;`1gE2h0ME8/00<0Le0Z00X0ME8/07IC
;@1fD2/0Le0Z075>:01^C2H0K4`U06Y=9@1ZCRH0JdlW0P1`D2T306i>9`09071@:@1bDR/0Le</07]H
;P1lFBl0OEX`07iK<@1oG380P5dc0080PEhd00P0Q5h_08EO<026H340Qf4b08US=02;ICH0S6Hg08eW
>080Rf@i00<0RfDh08aV=`2<ISD00P2=J3@00`2=J3<0RF<d08US=00208YT=@0408]U=P2<ISL0S6Hg
08eW>0<0SFLj0P2<IST308]U>080RFDe00@0RVHf08]W=`2;IcL0S6Ph0P2=JCT00`2AJc`0SfTj08]U
=P0208QR<`0308YT=@2=IcP0SfTj00@0S6Hg102;ICH01@2>JC@0S6Lc08]V<P29Hc80RF<d0080RfDh
00<0S6Dj08iW?02<Ic800P2<Ic<00`2<ISD0S6Hg08aV>@0208aU>PP0S6Hg202@ICP03P2?JSH0SVTe
08aW<`2;IS80S6Lc08iY=@2@JcL0TF`h08YT=@2;ICH0S6Hg08eW>02>J3T0SfTj0P2@JS/3095U>080
T6@g0`2?HcH00`26HC@0R6<f08UT=`0208]V>@0308UT=`28HcH0QV4d00P0QF0c2025HcD01023HC<0
Q68d08AR=025HcD208IT=P80QfDg0`23HC<00`22H380PEla081N<002081N<0<0OUlc0P1mGS8307aM
<@0607YM<`1iG380NE`b07QK<@1gFS00MUT_0P1eF2h0401fERd0MED^071C:`1[CbP0IT`W06599@1N
AbD0GDHT05=48`1>@Al0BSdM04Ll7P17?R40A3dQ03li7`0k=A/203/f8P0403Xe8@0i=200>3<O03Lb
7P80=S4M00P0:c0L02X_6`0X;1/09RXK02DY6`0V:Ah09bXO02P[8P<08b@L0`0R8a/2024R6P@07B0I
0P0L7aP301/N5`X07R0M00H07b4N020R7`0O8Ah07AlL01/M6P0J71T801/M700K01XL6`0K7AX07AlL
01lQ700Q91d08bHM02DX7@0V:Ah09BLJ02PX700];R00<S0Q03@a800e<1d0<b`J038[600c<AP0=C<L
03Db7`0_:al09b8L02<N6`0U7b40:B<W01lQ5P0R91T09RPM0080:B/P00T09bTN02@V6`0R91T08bDG
02<U600R91L08R@I024R6P0P8A/00P0O81/2020S70<07b8K0`0N8AX801`O600P01`N7@0M7a`07R0M
020R7@0R9Ah092LN02HY7P0W:Ql0>S8M03hf8@12=b40?S@K03/_5@13=AX0E4DX069C=P1jIBh0RG8l
09=h@`2CMD40XH1=0;F?GP2aREP0WWA4081A<`1G=b80;24K01`U:P0K;SD072/^020W7`0Y9aP802<U
8P04024T7@0R9Ah08RDN028U7P808bHO0P0T9b0802LX8PP09RTR00L09RDP02LV8@0X9b80:BPS02XY
900[:RD0;2/V0080;B`W0180;RTS02lZ900`:bD0<RdW03@_:@0e<2X0=S4[03Lb;00n>BD0@3TV04@i
9@17>bD0Bc/T050l901B?2D0ECdU04Ti8P1:>R<404/k900704Xj8`19>B80>cTT03/i900k>2D0>cPW
03`i:P0203`h;00T03di;P0l=RH0?SLW03lh9P11>BH0ACXX04Lj9`1:>bH0Bc`W0550;P1>?B/0BcXX
04Pg9@17=R@0BCPV04`k:@1??R`0CclV04lo9@1@?bD0DclT05I1901LABH0GdPX0699:P1NBbX0GDXY
05U9:01FAbP0DdDX0553:01>@bL0CD4W04<g8@14>280A3LT0P15>2L00`16>BT0AcT/04Li;002044d
9006048e9@13=RH0A3LW04Dh:016>BT0AcXZ0`14=bL00`13=RH0@SDU044d9002044d900603ha:00l
<RP0>S0V03P`9@0e;b<0<RhR0P0_;B0803D^9P<0<RhU0`0c;bH203@`9`P0>S@T0P13=RH01014=bH0
A3LT04Di8`16>R@204Lk8`0H05129`1?@BH0CShT04hm8`1??R@0E40W05Q2:P1JA2`0FT8X05e5:@1T
Bbd0Je4`079F<@1fF380N5/a07]L<01aHD00L60o071P?P1aHCd0M6Dn07MX?`1kK4<0OFi30P1eKCl0
1`1cJSl0L6Ll06iU?01]I3d0KVA0071V@`1aId@00P1cGc`02`1dGST0MUlf07UQ=@1nHc@0PFLf08AX
=P1nK3h0O6Xl07YU>01gH3@0MUhb0080Me`a00L0NE`b07YK;`1kG300Ne``07aM<@1nGc<0Of0d0080
P64e02@0Oel^07iN;@1nGRd0OUh]081P;`23Hc80QFDd08MW=P2;IcL0RfLe08YV=02:IS80RfPb08eZ
<P2?K380T6dc09I[>02HKCX0Vg0k09ic?02OMC/0X7Hj09me>@2NMCL0VW8g09]c>02NMST0XGTk0:En
?@2XPCh0ZX=00:^4?`2ZPcH0[HHi0;6:?@2dSD020;J?@P0L0;F>@@2cS3l0]8a70;F=B02gSdX0^91;
0;N?BP2eSDP0/HU40:n7@P2bRdH0]8e80;N@B`2hTD`0]i1;0;><A`2_R4<0[8E00:Qo?@2YPT40ZhA3
0:b6A`2[QdT0ZHM:0:J6B`2UQDX0YH900:J3@@80YhA200D0YX=10:B1?`2ROcd0X7dk0:=m?0020:=n
>P0M0:Ao>@2VPCX0ZHDk0:b8?02^RSh0[HD`0:V3<P2VPSH0Y88k09io?`2DMcd0QFXe07]Q;P1[EBH0
MUh`089[>@29L3X0RFhg08MZ<027JB/0R6X/08AY=023J3<0PFDc07mS<`1lH340NUda07QK;`1gFS00
1@1lH30307]O;`0907]L9@1mGRL0PF8/08AT<@24I3<0PV8a07iN;`1lG2d0M5dW0080LU/W0180KeTX
06]F:@1VDb/0HTl^05m<;01LBbl0I4/]06Q?<@1ZDC80JE0a06I>;01UCBT0IdlY06]C;@1dFRT0ME/Z
07QN;@1jH2l307aR<@0507]Q<01gGB`0Med/07IL:`1eFbX00P1dFRT207=I:00306]J;P1/Fbl0KE``
0080KUda01h0KE``06aK;`1[FRh0Le`Z071I9`1]EbD0Ke/X079Q;@1cHbl0LV8^06iQ;01WDc00HTh[
05e99P1KAb@0GDTV05i:9`1LB2D0FDDR05126`1BA1d0E4HO05E7801FB240EDLP05=57P1BA1d0B3lN
04U07`1:@B0204]28@0404U07`17?Qd0ASdL044j7@80@S/N00<0@c`O04@m8014?B000P15?R4204M0
8`80ASlR0`15?R401014?B00A3dQ04@m8@14?B4204<l80<0@S/O02`0?cPN03hg7@0o=A`0?cDL044e
7@15=Ql0B3PQ04Xj8`1H@B40H4PV06Y@:`1fFBl0PF4b08m[=`2LMd00YWm60;6EI@2jWVl0_j=d0;JI
K@2WRV00XXEM0:b>J02hVW@0a[>E0<^fU`3A^YP0dkZB0<ndR@38ZGX0_im/0;ZII02YTTl0V89607iZ
=@1XEBX0ETHT04/l9@11=2@0>blS03@^800b;1h0;bTK02dW6@80;2HH00@0;BLI02hX6P0Z:ad0:R/M
0P0Y:Q`302PY6`0302LX6P0R8a/08R<K00L08R<K0P0O9A/0100Q91/08R<K028S6`0S8a/202DR6`04
02DV7P0T9Ad092DM02@U7@808b@L0P0R8a/2028S7@03024R700P8A/07b0J00807QlI00<07AhH01`L
6P0L71X01P0L71X@01TK6QP05aTH200F61L@01LI60P06A/H200J6QP301XL6`806adL0`0L7Qd801`L
6PP07QhL200O81X201dM6`<07QhL0P0O7ad2020P7P<08B4I0P0R8QX302<S6`<09b8L1@0V8A/402PT
6`80:BDL0P0Z9Qd3030V7080<BLM0`0b:1h01P0a;1T0<R/I03</6P0d:aX0=RXJ03P[6`80>RXK0P0l
;a`203d`7@<0?S4N00<0?c8O03lc7@0o<ad01P0o<ad02@12<Al0@c8P04@c8@14<b40@c8P044`7P0o
;Q`0?RdK04Db8@0204Hc8P0304Pe9019=RD0BSLV0080BcPW00H0DC/T050j8`1?>B80CSPQ04dg801<
=Ql204/e7P0804/j9P19>2@0B3HP04Pd7019<a/0CCDK04lg7@1B>1d205Ph8`80EcLR00@0FCTT05/k
9P1M?BP0GclZ0P1J?2@03P1K>b80Fc`P05dk7`1N>ad0GcXM05lk6`1G?a/0FClL05]17P1O@R00HdDS
06M69@1ZAbL0JdPX201[CB/307MA:P80N58[0`1iDb`207=C;080LU8[0`1aDBX02@1`D2T0LU@`06mA
;@1ZC2P0IdTU06I8901YBbL0KDl[071B;P0306a?9@0306]>901/CbD0K4lU0080K4lU00<0KE0V079B
:`1bDR/01P1bDR/0101[CBT0K4hZ06a>:P1/CRX206e?:`80KU0/1@1eE2T307AC:00407MH;01fEb/0
MUL[07EF:P80M5DY0P1cE2P02@1gDB`0Le0Z075>:01^C2H0KDdV06a?9`1/D2P0KE4Y071C9`0206mB
:00306iA:@1]CbT0K4hZ0080Jdd[00P0L4l`06m>;`1_CRd0LE0]07=C;@1gEc00Ne/d07eM=080NeT[
0P1lFR`01@1kFB/0NUPZ07UG:@1hERP0M5@]0080MED^00<0MUH_07MG<01hF3400P1iFC80201fDb/0
NEH^07aI<@1oG3@0P5de07mL=01nFc<0OEXb0P1nFc400`1oG380P5dc085N=002089O=@0;08=P=P21
G2l0Peha08EP<`28HcH0RF@g08QS=P27HSD0QV4d08MR=@26HC@00P25H3<01`26HC@0R6<f08YU>02;
IST0S6Hg08iX>@2@JS/00P2BK3d01P2AJc`0T6Xk08mY>P2?Jc/0SVXj08eY>@80S6Ph00h0SFTi08iZ
>P2?Jc/0SFTi08iZ>P2AKCd0Tflo09A`@02CKcl0TVhn095]?@2AJ3X0TVTk09A[?@80UF`n00/0U6/m
099Y>`2AJ3X0Tfi1095/?`2>JC`0RfHi08YU>029I3L0RVDh08]V>@0908YV=P0308UT=`2:ICP0S6Lj
0080SFPk00D0S6Lj08YU>028HcH0R6Hf08MU=@0208ES<`0408IT=028ISH0RfTi08aZ>P80S6Lj0`2>
JC`00`2<IcX0RVDh08UT=`0508YU>0<0RF@g0`28HcT00`27HSP0QV4g08EP=P0208EP=P0808IO>026
GcH0Qf0g08QQ=P29HcH0RV@e08YT<`2;IC@208EP<`0408IQ=028HcH0RF@g08]V>@80S6Lj2029I3L0
4@2<Ic/0RfHj08YU>029ICD0RFDc08]W<`2=JCD0SV/e09=Z?02AJ3X0SfHh08eT=P2<HcD0SF@f08iU
=`2?ISP0Tg0h0080Tg0j00<0Tflk09=_?@2CKcl00`2CKT40302DKd80UW9209Qd@P2HM400UW<m09Aa
>`2CL3P0T6Xi09A^?@2HLT40Ug5009=]?080TF/j00@0Tfdl099]=P2DKcP0UW4j0P2GLS/0102FLCX0
U6lh099]=P2BKD0209=^@@0309A_@P2EL4<0UG130080UW540`2EK3h209A[?@<0TfXl00@0TFdm091/
?02@K3`0Sf/k0P2>JSX208eY>@03091/?02>JSX0S6Ph0080RVHf00T0RfLg08aX>02=JCT0TVTk095X
>P2@IcT0SVDg08aS=@2:HC<00P28Gc402@27GS00SV8e08eQ=02=HC@0S60c08eQ=02?HcH0TVHi09=W
>P0309=^>PD0TVdi0P2CKCh209A^?`0409E_@02FL440UW1109Ma@P80UW4m0P2EL3`409A_>`80TV`m
0P2CKCh209A^?`80UFm000H0VG=409Qb@`2HLT<0Ug5209I`@@2EKd0209A^?`0;091/?02AKCd0TFdm
091/?02>JSX0RfLg08QT=026HS80T6`l08m[>`2=JCT00P2;IcL0202<J3P0SVXj08m[>`2CL3X0TVli
091]=`2=JS@0RfPb0`2:Ic4308IS>b_ooooo000Zooooo`80XgQ30`2TND@30:EjA@80XgQ500@0Y7U6
0:EjA`2VNdP0YW]80P2WO4T80:IkB080Z7e:0P2WO4T20:IkB080YGY7202WO4T00`2YOT/0Z7e:0:Qm
BP020:MlB@80YW]800<0YGY70:UnB`2YOT/01P2YOT/20:UmC080Z7a;0`2WNdX00`2VNTT0YGa80:Im
B@030:MnBP040:ElB02SNTH0XWU50:5hA080XWU50`2SNTH20:AkA`030:ElB02UNTD0YGY500H0YGY5
202TNdL209iiA@0409ehA02KMT80VWE109Qc?`@0Ug8n00@0UW4m09A_>`2CKSX0TF`h0P2@JcL01P2=
J3<0SFPd08aW<`2;IC@0RV@e08US=P80R64f0P23HC<01P22H380P5h`07iL;P1mFbd0O5X/07]I:`80
O5Ta00@0NeP`07YG;`1jEbl0NEH^0P1hEBd00`1hEBl0Me@^07EB;00207=@:P0=07AA:`1eDR`0MU<]
07E?:P1bCbT0L4dW06i<9P1/C2D0JdhV06]?9`1/D2P0LE4Z071@:@0306m?:004075A:P1cDb`0M5@]
07]H;P80O5T_0P1mFS002`1nFc40Oe`b07mL<P24GRl0QEl`08IP<@27HC80RF<d08YT=@2;ICH0S6Hg
0080Rf@i00<0RfDh08aV=`2<ISD00P2=J3@0102=J3<0RF<d08YT=@2:I3D208]U=P80S6Hg00@0SFLh
08eW>P2=IcX0SFLj0P2<IST308]U>00308UU=@2:ISH0RVHf0080RfLg0P2<J3P0102=JCT0SfTj08eW
>02:I3D208QR<`0308]U=P2>J3T0T6Xk00@0SFLh102<ISL01@2>JC@0SFPd08aW<`2;IC@0RfDf0080
S6Hi00<0SFHk08iW?02<Ic800P2<Ic<00`2<ISD0S6Hg08aV>@0208aU>PP0S6Hg202@ICP00`2>JCD0
SFPd08]V<P0208]V<P0308eX=02?JSH0T6/g00<0S6Hg00D0SFLh08iX>@2>J3T0SVPi08mY>P03091U
>080Sf@g0`2>HcH00`27HSD0R6<f08YU>00208]V>@0308YU>028HcH0Qf8e00P0Qf8e2025HcD00`23
HC<0Q68d08AR=00208ES=@80QV@f00<0QfDg08=Q<`23HC<00P22H382085O<@80P5h`0`1nGc<207eN
<P<0O5da00H0NUdc07UL<P1iG380N5/a07MJ<01fFBl207EH;P0@07IF;@1eEBh0L5<[06a@:@1VC2L0
HTXV05m89P1MAR@0E4DT04m07`1:?Ad0Ac`N04Ln8@15?R80@3TO03/e6`80>cHR00<0>SDQ03Td800h
<al00P0g<Qh02@0f<Ad0;34M02X_6`0X;1/09RXK02HZ700V:Ah09bXO02P[8P0302<T70<08R<K0P0Q
8QX0100N8AX07B0I01dP6@0M81T201`O60<06ahG200N81d0200M7a`07R0M01lQ7P0P8Ql07b4N01dO
700K7AX06Q`I200K7A`06`0J71/06adJ01dO700O8A`08B@M02<V7@0T9a`09BPM02HX6`0Y:Ad0;BhP
03<a8P0e<R40=S4N03D^700c;1T0<S0I03Dc700f<b00<BdQ02XV7@0U81`09AlO02LQ8`0P8QL08R@I
02DW700202PZ7`0402LY7P0T9Q/08R@I02@V60808bDH00<08R@I024R6P0P8A/00P0O81/2020S70<0
7b8K0`0N8AX801`O600601`N7@0M7a`07R0M020R7@0R9Ah092LN0P0V:Ah0600h<Ah0?CDP03hf8@0l
<A/0>BdE040b601??bD0G4`b07=M:`25KS`0TGM409=e@`2OODd0/XaK0;69F02SNDT0RU`k0610:@0f
:B008BHY01`[<00L:R/08BHO02TW60P08bDR100R9Ah202<V7`8092LP200W:28802HY8P809bHQ00@0
:2LR02TX8`0Z:B@0:bXU0`0/:bH01P0^:B<0;bXT030[9@0b;BL0<bhX03D`:P80=S4[00P0?3LS03hg
9010>2<0ASXT04/k901@>bH0DcdV05Hm9`80C3`U101;>b@204`l9@80?3XU00@0?3TV03`i:00l>BX0
?3TZ0P0l>2`02`0l=RH0?SLW03lh9P11>BH0ACXX04Lj9`1:>bH0Bc`W0550;P1>?B/0BcXX0080B3LU
00<0BSTW04`k:@1>?B/00P1??bH03P1@?bD0DclT05I1901KA2D0GTLX0658:@1PC2/0GT/Z05a9:@1H
AbT0EDHY0594:@1?A2P0CT8X0P15>B<01015>2D0ACPW04Dh9`15>2P204Dg:P05048e9@13=RH0@cHV
04<f9P14=bL00`15>2P204@g9`80@cHV0P12=BD2044d900803ha:00l<RP0>c4W03P`9@0e;b<0<RhR
030^8@0_;B0803D^9P<0<RhU0`0c;bH203@`9`P0>C<S00H0@S@W04<f9P13=RH0A3LV04Dh9@16>R@2
04Lk8`80CT0U00h0CShT04ln901@?bD0E40W05M1:@1H@RX0Ed4Y05a4:P1RBb`0J4l`06iD<@1dF340
MeXb07QK<@80Lf0o00H0Lf4m07AR?01fI3h0NFLo07a[@01nKD8207M_@@0707E]?`1cJSl0LVU0075X
?`1aJ440LfU507AZAP0207EQ?00<07IP>@1gH3H0NF4e07eR<`20ISD0PVHf07aZ>P1mJ3T0NVDf07QR
<`1hH380NEha0P1kGS80101lGC40OEhb07eN<P1mGS8207iO<`80Of0d01@0Oel^07iN;@1nGRd0OEd/
07iN;@20H2l0Pf<b08AT<`2;IcL0RVHf08UU<`29IC40RVLa08aY<@2>Jc<0T6dc09A[=`2FKCT0VG0j
09]b>P80WGDj00l0WGDh09ad=`2JLCT0Vg<h09ee>P2PN3/0Xg/m0:Io?P2YPSl0ZX=00:R1=P2ZPcP0
[8Dj0:n8?@2aRSl00`2cS4440;J>B@0D0;F=B02cRdH0/HU40;28@`2`RD@0/HY50;><A`2dSDP0/X]6
0:j7@P2ZPch0Yh0k0:El>P2VOch0Yh0o0:R2@`2VPT@0Y8950:61AP2OOd@20:F1A@80YX9600@0YH55
0:=o@`2QOD40X7a00P2QNSl05P2QNcd0XW`m0:=m?02VPCd0ZH@n0:^6@02WP3D0YGlf0:9m=`2NO3`0
UgPo08]]>@1iGRl0K5@V06M@9`1aF2l0OFDi08EZ>`26JSP0QVPb08MX<@28JC02089W<P06081T<P1n
HS80OF4b07]N<P1iG300NE`b1@1lH30307eQ<@0907aM9P1oH2X0PF8/08=S<023Hc80P60a07eL;`1j
FB`0M5dY0080LU/Y0180KeTX06]F:`1UDRX0HDl[05i;:`1KBR`0HTT[06I=;`1YD340J50^06I>:P1U
CBL0J50Z06aE;01eFbX0Med/07UO;P1kHC0207eS<P80O68a0P1gG2d02@1fFb`0MEX[07AI:P1cF2T0
LULX075F9`1[FRh0K5/_06eL<00206iM<@0F06eL<01/Fbl0JeX^07AL;01aFBT0KUPW06mK:@1bH2h0
Lf<`079R;`1]H2`0IE4^061<:@1KAb@0FTHS05a89@1MBBH0FTHS05Q48@1@@Qd0DT@O05=58080EDLR
00H0E4HQ05947`1A@ah0B3lN04U07`1:@B0204]28@0304U07`17?Qd0ASdL00<0@S/N00<0@c`O04@m
8014?B000P15?R401017@2<0ASlR04Ho8P16?b8204Dn8@80A3dP0`14?B4204<l80<0@S/O02`0?SPN
03hg7@0m=Q`0?cDL044e7@15=Ql0B3PQ04Xj8`1H@B40H4PV06]A;01fFBl0PV8c08m[=`2MN440Z858
0;:FIP2hW6`0^Yi_0;6DJ02TQed0XhIN0;2CJ`2mWgT0a[6B0<RdT`3<]Y40c;>;0<R]P032Xg@0^IUV
0;BEG`2PRd`0T7a107UU<P1RDBH0DT<R04Hj8P0n<R80=bdQ034^7`0_;1d0;BXK02XW6080:BHG00<0
:RLH02/X6@0X:1`00P0X:1`202LW6`<09RHJ2@0R8a/201lU6`04024T6`0R8a/08R<K02<S6`809B8K
0`0T9Ad202<T70<08R<K00H08R<M024R700Q8Q`0824K01lP6P0N7aT201dN60P071`J400I6aXH01LI
60P05QPG400G6AP801TK60P06QXH0`0J71/301/M708071hM200L71X801hN70P07b0J0P0M7A/301hN
70807alM0P0P81h3024Q6@<08R8J0P0S8a/802HQ6`0402LS6P0X91/0:2@K02PT6`80:BDL0P0Z9Qd3
02lU6`80<2HL0`0a9ad01P0a;1T0<R/I03</6P0d:aX0=RXJ03P[6`80>RXK0`0l;a`203d`7@<0?S4N
200n<Q`02011<1h0@S4O04<b8014<b40@c8P044`7P0o;Q`0?RdK0P14<B001P15<R40AS<R04Ld8`18
=B@0BCHU04Xg9P80CcTR00h0CSPQ04dg801<=Ql0BcDN04Xd7@19<a`0B3LS04Lf8P17=Al0BCDM04/e
7@1>=Q`0D3PN054g7080ESLR0P1E=R404P1F=b80F3TT05/l9`1L?BP0F3`T05Xl901J?280G3dQ05lm
8@1P?Al0HC`O068n7P1J@Qh0Fd4N05e3801QA280HdDS06M69@80JTLW0P1YBbT206Y<:P80Jdd[0P1/
CR`207AA:`80ME8/0`1fDbd00`1gE2h0Le</079B:`02079B:`80LE4Z0P1`D2T0201`DRh0KU0/06]=
:@1YBbL0J4XV06Y<:01/CRX0KDl[0P1ZCBD206]>9P<0K4lW0P1]D2P8075A:P80K4hZ0P1]Cb/306i@
;00306mA;@1dDbP0ME@Y00@0ME@Y0P1fEBX00`1eERX0M5DY07AE:@0207=D:080LU<W00T0LE8V07I@
:`1cD2X0LDhX06i<9P1]CBH0JdhV06a@:01]DBT00P1_DRP01P1^DBT0KE0X06a>:01[CBT0Jdd[06Y<
:P80Kdh_00h0Kdh]075@;@1cDbd0MeL`07YJ<`1lG3<0NUP[07]I;01mFbh0OU`_07eK;P1kFB`0NELZ
07ME:080M5@]00<0MED^07IF;`1gEc000P1hF3401@1iFC80N5D]07UF;P1kF300O5Ta00<0OU/c00L0
OEXb07eJ<01nFc40OU/a07mL<P20GC<0PEhd0080PUle00@0PE`_08=N<@25H3<0Qf8e0P28HcH01027
HSD0QV4d08MR=@26HC@208EP<`0708IQ=028HcH0RVDh08]V>@2<ISL0SFLh08mY>P03095[?005091Z
>`2?JCX0Sf/k08iZ>P2=JCT00P2;IcL01P2=JCT0SVXj08m[>`2>JSX0Sf/k095]?@<0TVhn00D0T6`l
08m[>`2@IcT0TFPj09=Z?00209A[?@0709=Z?02AJ3X0T6Li091[?P2>JC`0S6Lj08YU>00208UT=`03
08YU>02;IST0RFDe00P0RFDe00<0R6<f08UT=`2;IST00`2<IcX0102:ICP0RF@g08MU=@26I3@208ES
<`0<08IT=028ISH0RVPh08aZ>P2;IST0S6Lj08eX>`2>JC`0SFPk08aW>P2:ICP0RF@g0`2:ICP308UT
=`80R6<f00<0Qf8h08IQ=`26HCL00P25H3H208AO=@0708=N=026GcP0QUlf08MP=`28HCH0RF<f08US
=00208YT<`0808EP<`26HC@0QV4d08QS=P29I3L0RVDh08]V>@2<IcX808YU>00@08]V>P2:ICT0RF@g
08UU=@29IC<0RfLc08aX=02>JcD0TfXl099Y>`2?ISP0SVDg08eT=P2>ICL0SfHh091W>@80TFhh00@0
TFdi095]>`2AKCd0TFdm0`2AK3l04P2BKD00U71009Ea@@2ELCl0U70l099_>@2AKSP0SfTh09=]?02G
LD00UW0o09=]?02@JST0TF/j09=]?02BKCH0Tfhg09E`>@80UW4j00<0UG0i09=^=`2BKCH00`2AK3l0
0`2BKD00Tfi109=^@@0209A_@P0409E/?P2DJcd0U6/m09A[?@80TfXl0P2BJC/00`2@K3`0Sf/k08m[
>`0208iZ>P80SFTi00@0S6Ph08m[>`2>JSX0S6Ph0`2:ISH0202<J3P0SFTi091W>@2@IcT0SVDg08eT
=P2<HcD0RV4c0`29H380202=HSD0S64d08]P<`2;H3<0S64d08iS=P2@ICP0TVLj202BKCT0202AJc`0
TV`m09=]?P2DKSl0UFm009I`@@2GLD80V7930P2FLCd209E`?0<0U6lk00<0Tfhj099/?@2BK3d00P2C
KCh209A^?`80UFm00P2GLD800`2FL440UFm009A^?`0209=]?P03099/?@2@K3`0T6`l0080T6`l00L0
Sf/k08aX>02:ISH0R6@d091/?02>JSX0SFTi0080RfLg00@0S6Ph08iZ>P2?Jc/0T6`h0P2?JcL01@2>
JSH0SFTe08]W<`2:IS80RFDa00<0QV<i:oooool002[ooooo00@0XgQ30:AiA02TND@0Y7U40P2UNTD2
0:IkAPL0YGY700<0YW]80:EjA`2UNTL01P2UNTL20:QmBP80Yga90P2VNdP20:EjA`P0Yga900@0ZWm<
0:UnB`2YOT/0ZGi;0`2XODX00`2WO4T0Z7e:0:QmBP090:QmBP80Yga90`2VNdP20:ElB0<0YWe900<0
YGa80:=jAP2RNDD00`2RNDD30:=jAP<0Y7]7202UNTD80:AkA`060:1kA`2ONTH0WWU509ehA02LMd<0
VWE10P2IM40209Mb?P0409Ia?@2DKc/0Tfhj095/>080T6/g00P0SfXe08mZ=P2=J3@0S6He08YT=@28
HSD0Qf0e08IO=080Pf4c00H0PV0b081N<01oGBl0OU`^07eK;@1lFR`207aI<@0407]H<01jEbl0NUL_
07UF;P80N5D]0P1gE2h00`1eDR`0M54[07=@:P0207AA:`0<07EB;01cCBP0L4dW06m<9P1^C2H0KDdV
06a?9`1]DBT0KU8Z07=C;01bDR/0LE4Z0P1`D2T00`1bDR/0M5@]07EE;P0607]H;P80O5T_00H0Q5h_
08EO<026H340Qf4b08QR<`2:I3D208]U=P80Rf@i00<0RfDh08aV=`2<ISD00P2=J3@00`2=J3<0RV@e
08YT=@0208]U=P@0S6Hg0`2=IcX208aV>@<0RfDh0`2:ISH208]W=`<0S6Ph00<0SFLh08]U=P2:I3D0
0P29Hc@00`2<ISL0SfTj095[?00808iX>@0508mZ=@2?JSH0SFPd08eW=P2=IcP00P2=IcX208mX?@08
08eX<`2<Ic<0S6Lc08]U=02;ICH0S6Hi08aU>P2=IS/808aV=`P0T6Dh00P0S6Lc08]V<P2;IS80RVDa
08]V<P2<Ic<0SFPd08iY=@<0SVPi0`2=IcP208aV=`<0T6Dh0P2?I3L308iS=P0308QS=P29I3L0RVDh
00<0RVDh00<0RF@g08QS=P28HcH01`28HcH808ES=@@0Q68d0P25HcD208IT=P0408=Q<`22H380PV0b
089P<P<0PEla00@0P5h`07iO<`1nGc<0OUlc0P1mGS8307aM<@0607YM<`1iG380NE`b07QK<@1gFS00
MUT_0P1eF2h0401fERd0MED^075D;01]DBX0J4hY06=;9`1PBBL0GTLU05E5901@@B00C3dN04Xl7`19
?R80AcdR044j800m=Q`203/f8P80>SDQ00`0>C@P03Pc7`0g<Qh0=c8N02d`7@0/;a`0:RdL02PZ700W
:A`09bTN02PZ7`0X:B4302<T70<08R<K0P0Q8QX301hQ6P807B0I100L7aP801hP7@0801dO700N81d0
7b4N020R7`0O8Ah07R0M01`N6`0K7AX901/M700J01/M6P0M7a`07R0K020S700R9A`08bHK02@W700W
:A`0:RXN02h_8@0c<B80=C8Q03Lb7`0g<1h0=BhK034_600d<Qd0=c@Q03@a8P0^:Ql0:2<M02@O6`0S
7Q/0828G028T6@0U9a`202LY7P0;02HX7@0T9Q/08R@I02@V600T9QT08bDH028T6@0Q8QX0824K020Q
700O81/00P0P8a`301lR6`<07R4J200M81T01P0L7Qd07AlL01hP7@0P8Qd08RDN02<V7@809BPM01P0
=C0M03Tb800k=240>30K03L/5P0k;aL0B3TR0553:@1WDR<0O6Hg08adA02AMDH0Vg]<0:^7E`2^R5L0
Z81?09U[A`1cDCD0ASHW02X[9P0O:BX07BLV02@W7P0X:A/802<U8P<08RDN0P0S9Ql302@W80P09bPR
200V:B801@0W9R40:2LR02PW8P0Y:2<0:RTT0080:bXU0P0/:bH01P0^:B<0;bXT030[9@0a;2H0<RdW
03@_:@80=C0Z00/0=S<P03Xe8P0m=R<0@cPT04Tj9@1??BL0DchY05Do:01A@BX0CclX04`l9@0204/k
900304`l9@1??bP0DD4Z0080@C`V01H0@3/W040k:00o>BT0?SPZ03dg:@0m=b/0?3HV03hg9`0o>2H0
@CTV04Dj:017>RL0BS/V04/l9`1@?bd0CSd[04/j:019>2H0B3LU04Xi9`1<>bT0CSd[0P1??bP03P1@
?RH0DShU05E09@1J@RH0GDHW0617:@1QCB`0H4`[05i;:`1KBR`0FDP/05I6;01CABX0DT@Z0P18?2H0
1P17>RL0ASTX04Dh9`14=bL0A3HY04<e:080ACPX0`14=bL304<f9P0404@g9`13=RH0@cHV04<f9P<0
@SDU00T0@C@T03ha:00l<RP0>c4W03P`9@0f<2@0<blS034_8P0`;R40200e;RH3038^9@<0<blV0P0d
<2L803La8`06044c9P12=2L0@SDU04<f9@14=bH0ACPU0P16>R@0401:?280BcdS04hn9@1A?bL0DT0X
05A0:01E?bP0E3hW05I0:01IA2T0GdL[06E<;@1[DBh0LED`07=G;`1eF30207=Q?@0607=Q>`1dHSX0
MfHk07UX?01lJcl0OVdo0P1mLD401`1lKd80Nfi107Y]@@1jKD<0NVa507Y/A`1kKDP00P1hIC/0301i
I3T0NF8f07YR=01mHS<0OV<d07mS<`1mJ3T0O6Lh07]U=P1kHcD0OF8e07iQ=@80PF8f0P20HCD207mP
=0@0OUlc00<0Of0a07iO<01lGBh00P1kG2d0401lGBh0OUl`07mP<@29I3L0RFDe08QT=028I380RFDa
08]X<P2=JS80SV/c09=Y=`2EJcT0Ufhj09U`>P2JLCT209]c>00F09Yb=@2IL3P0VW4i09ad>@2NMST0
XGTk0:Am?02VOch0Yh0m0:Al=02UOCD0YWhf0:R0>02ZPSX0[XHn0;28@02bRT80]hi<0;F<BP2dRdT0
/XU70;68AP80/8M500<0/HQ60:f6@`2^Qd@00P2_R4D03P2]QT<0ZH8o0:En>`2RNcP0XgXh0:=l>`2T
OC`0Xgdn0:5m?`2OOD00W7a109]k@02SOd/0Y81<0P2UPDd0702TP4`0XWi:0:1lB02NNTH0WGM609eh
A02LMd<0W7M209eh@@2PO480XWi20:B0A02QNC/0WgLj09]g?@2IMD40T711085T>01_Db/0HDLR06=;
:@1/DS40Medh081T?@24Icd0QFHh08IV=@27IcH2081U<00607mS<@1nHS80OF4b07aO<`1kGS80Nehd
0P1kGbl0101lH300OF4a07iR<P1nHS8207mS<`0907iP;01oHBd0P68`081Q<P1oH380O5da07UJ;P1g
Ebh0Le/[0080LETY01<0KUL[06YD:`1TD2/0H4hZ05e::P1JBB/0H4LX06A;;01WCbd0J50/06I>:P1W
CbT0JU<Z06iG;P1gGB`0NEl^07]Q<01mHc80OV@c0080OF<b00`0O68a07QM<01gG2l0MU/^07AI;01b
EbX0LEHY071E:01_E2L0JUT]06]J;P1/Fbl206eL<00=06aK;`1[FRh0JUT]07EM;`1bFR`0L5X[075L
;@1bH300Lf<b071P;`1[GB`0HDl[05a:9P0205M58@0605U78`1JB2@0F4HR05E37`1A@ah0DT@O101C
AB0205537P0304Po7P19@1l0BT4P0080Bd8Q00<0BD0O04Ln7@16?A`00P12>ah304<l7`<0A3dP0P16
?b8204Dn8@<0A3dP00@0@c`O04<l8013?200@c`P0P12>al3044j7P0/03`h7@0m=ad0?3HL03df7010
=Qd0@cLO04Lh8@18>B80FD8R06599`1[DB`0MeX`089R<`2@K3P0WWU20:Z3BP2bUV@0/iMU0;6EI@2X
S5d0X8=G0:F8GP2fVG40aJR00<RaS`37/H`0aZj80<>ZP@2oY7L0]i][0;2BH02ZS5P0TGi408=_>P1/
Fbd0F4TR04/m8010=B40>2lP03<[800^:Qh0;BTM02`X700Z9QX302TU6@0302XV6P0V9Q`09RHL0080
9BDK0`0T91X00`0S8aT08R<K028S6`07028S6`807bDK00@08B@K028S6`0R8a/08b<K0P0U8Q/0100T
9Ad08b@L02<T700S91`2028S6`808B8J0P0Q8Q`00`0P8A/07b0J01hO6@0201dN600301`M5`0K6aT0
6a/I00H06a/I400I6aXH01LI60P05QPG400G6AP801TK60P06QXH0P0I6aX201XL6`<06adL00<071hM
01`L6P0L71X01P0L71X801hN70P07b0J0P0M7A/301hN70807alM0P0P81h2020P60808B4I0`0R8QX0
0`0S8a/09R4K02HQ6`0602HQ6`<09b<J0P0X91/302TU7080;B<I0P0^91X202lU6`80<2HL00H0<B`I
038[6@0c;1X0=2/J03HZ6P0h:a/203XZ6`<0>bhM0P0l;ah303d`7`P0?S4N00<0@2lM044`7P13<R00
0P13<R001011<1h0@2lM03h]6`12;ah204<`7`0304@a8015<R40AS<R0080Ac@S0P1;=al204Xf7P09
04Te7@18=1`0Ac<K04Lc6`13<Qh0A3<O04Le7`1;=al0CCLO0080D3PN01T0DCLL05Df8@1D=B00E3DP
05<d7`1D=B00ESLR05Pi901J>bH0ES`S05Pl901I?R<0G3hR05ho8P1R@B80I44S06A18@1MAB40GdDR
06168`1RAB<0IDLU06M69@1YARH0JTLW0080IdTW00H0J4XX06Y<:P1[CB/0K4h/06e?;@1^D2h307=@
:P80M54[0`1eDR`2079B:`80LE4Z0`1`D2T0101_CbP0K4hZ06a>:P1/CRX206]=:@<0JT`X00@0IdXR
06Q;8`1YC2@0JdhV0P1/CbL00`1]D2P0KU4Y06iA:@08071@:@<0KDl[0P1^D2`306mA;@<0Le<Z00H0
M5@[07EE;01fERd0MUH]07MG;P1bDRT3075A:0<0L50W00L0KdlV07E?:P1bCbT0L4dW06i<9P1]CBH0
JdhV0080JdlW01T0KU4W06iA:@1]D2P0K4hX06]=:@1ZC2X0JT//06U::`1^CBh0Kdh_06m>;@1aD2d0
Le<]07IF;`1iFC80NUXa07QE:`1jEbd0OEX`081M<`1oG380O5T_07QE:`1eDRP0Le</0080M5@]00<0
MED^07IF;`1gEc000P1hF340201jEbl0NEH^07UF;P1iERh0NUL_07aI<@1mFS80OU/c0P1mFS000`1n
Fc40Oe`b081M<`02085N=005089O=@21G2l0PUd`08AO<P26HC@00P27HSD208IQ=00;08MR=@26HC@0
QF0c08EP<`26HC@0R6<f08YU>02;IST0S6Hg08eW>02>J3T00`2@JS/208mY>P0308m[>`2>JSX0S6Ph
0080RfLg00<0S6Ph08iZ>P2?Jc/00P2?Jc/3091/?00608m[>`2>JSX0SFTi08eW>02>J3T0SfTj0P2@
JS/01P2?JCX0SVPi08eW>02;IST0RVDh08UT=`80R6<f00<0RF@g08YU>02:ICP02@29ICD01026HC@0
Qf8e08UT=`2:ICP308]V>@0308YU>025Hc<0QF<c0080QF<c00@0QV@d08MU=@29IcL0RVPh0P2;IST3
08eX>`0308]V>@29I3L0R6<f00<0RF@g0P28HcH308MR=@80Q5le0`23GS@3089M<`0608EN=`26GcH0
QUlf08MP=@28HSD0RF<d0P2:I3<208IQ=00408MR=@28HcH0R6<f08UT=`80RVDh202;IST208YU>@06
08QS=P28I3@0R6@b08YV<P2<J3@0SFXd0P2@JS/0102>J3T0SFLh08eW>02=IcP208iX>@0608eZ=02=
JCD0SFTe08eY=`2=JCT0SFPk0P2=J3`02P2>JCd0SfXn091[?P2@K3`0T6`j091/>02?JcL0SV/e08eW
>02AJc`209E_@007095[?02?JCX0T6Xk099/?@2AK3L0TVdh09=^>@0209A_>P0409=^>@2BKCP0TF`g
08iY?0<0SfXm0`2@Jch0102AK3l0TF/l095[?02AJc`2091Z>`<0SfTj0`2>JSX208eY>@<0S6Ph00<0
SVXj08eY>@2;IcL00`2:ISH208]W=`80RfDf0P2:I3D208US=0<0R68c00P0SF8e08aQ=02;H3<0Rf0c
08aQ=02>HcH0T6Dh095V>@P0TVdi0P2@JS/01P2BK3d0Tfdn09E_@02GLD80V79309UcA0<0UG0l0P2D
Kc/309=^>P80TV`m0P2CKCh209A^?`<0UFm00P2DKSl00`2CKCh0TV`m095[?002091Z>`0308iZ>P2?
Jc/0T6`l0080T6`l00D0SVXj08aX>02;IcL0SVXj08eY>@0408aX>080SVXj00<0RVHb08aX=02>JSH0
0P2?JcL00`2<J3@0RFDa08MS;`0308ER>2_ooooo000Zooooo`<0Y7U40P2UNTD30:IkAP<0YW]80`2U
NTL20:AiAPP0XgQ50P2XODX20:MlB@80YW]80P2UNTL80:MlB@@0ZWm<102YOT/80:QmBP80Z7e80`2W
O4L30:IkAPD0YGa800<0Y7]70:=jAP2SNTH02@2SNTH80:EjA@P0Y7]70P2QO4P01P2PNdL0WgY609eh
A02LMd<0VgI209Ye@@80VG4n00@0V70m09I^>`2EKCX0Tf/h0P2BJSL02@2AK3L0T6/g08iY=@2<ISD0
RV@e08MQ=026Gc@0QEhc08=Q<`02089P<P05085O<@1oGBl0OU`^07iL;P1mFbd00P1lFC40101kF300
NUL_07YG;`1iERh207QE;@0407MD;P1fDbd0MU<]07EB;0@0M54[0100LddX071=9`1_C2H0KT`V06i>
9`1^DBT0Ke<[071D;01cDb`0LU8[075A:P1`D2T0LE4Z079B:`1dE2d0MUH_1`1jEbd01`1iER`0Q5h_
08EO<026H340Qf4b08QR<`29Hc@00P2:I3D208]T>@0308]U>02<ISL0S6He0080SFPd00<0SFPc08]U
=P2;ICH01P2<ISL308eW>P80S6Hi0`2;ICP808]W=`0808]U=P2:I3D0RF<d08US=02:I3D0SFLh091Z
>`2BK3d208iX>@@0SfTj0P2@JS/01@2?JSD0SfXf08mZ=P2?JCP0SfTj0080SfTl0P2?J3d01P2=J3<0
SFPd08]V<P2;IC@0RfDf08]U>080SFHk202<ISL808mT=`<0RVDa0P2;IS8208aW<`0908eX=02@JS/0
T6Xk08mY>P2>J3T0SFLh08aV=`2;ICH0RV@e00<0SfHh0P2>ICL308eT=P80RF@g102:ICP:08UT=`P0
QF<e1P24HS@208ES=@@0PV0b1021Gc4307iO<`80OEhb0`1lGC401P1jGC<0NE`b07UL<P1hFc40MeX`
07II;`80MEP^0100MED/07EE;P1bEBd0Ke</06Y@:`1UCBT0HDXX05m89P1HABD0DT8Q04hm7`1<?B00
C3hS04Tm8`14>R40@3HM0P0l=b<0100k=R80>SDQ03Td800h<al203Lb7P05030a7`0^;ad0;2dM02TZ
700X:1`00P0X:1h0100Y:B408b@L02<T700S91`3028S6`808B8J0`0N8AX301dP6@<071lH200N81d0
0`0L7Q/07AlL01hP7@0201lQ7P0301hP7@0L7Q/06adJ00T06adL01X071hK01dO700N81/082<L024T
6`0R9AX08bHK02PZ7@0[:al0;RlQ03<a8P0e<R40>3<P03Pa7`0h<Ah0<2hI03<a700g=240=c@U03<_
8`0/:1d09B4H024L5P0P8QL08R@I02@V6`809RPM00T09BLL02@V6`0S9AX092HH02@V6@0S9AP08R@I
028S6`0Q8Q`00P0P8A`2020S70<07b8K0`0N8AX801dP6@0601`N7@0M7a`07R0M01lQ700Q91d08bHM
0P0T9a`0600b;1h0=BlO03Pa8@0e;Q`0<b/H03L/600n<Q`0ACTS05Y77`1aFc80QFa308aaAP2EMTP0
Xh5C0:^7E`2ZQ5<0Z7]B08MU@P1LB300>C<W02LZ8`0R9b409RLO02TY7@P092HS0P0R9Ah202<V7`80
92LP0P0U:24802LX8PP09RTR0P0X9b8202TX8`80:RTT0`0[:RD202hY8`0A02lZ900`:bD0<B`V038]
9`0c;RP0=2lY038a7`0e<R40>c@R03lg9017>RL0CC`X054o:@1E@2/0E4@]0592:`1>?RL00P1;>b@0
:`1>?RL0DT8[05A4;@15?bL0A3hV04<m9`12>bP0@CXX040i:@0o=bX0?SHY03`f9P0n=bL0?cPV044i
9P15>RP0AcXW04Xk9P1;?2L0Cch/04hm:`1<>bT0BSTW04Th9P1:>BL0C3/Y04dl:P1??RX0CclX04lm
9`1B?RH0E3hV05U19`1K@bL0GT@Y069;:`1SC2`0HD`]05m<;P1KBRh0FDP^05I6;01CAB/00P1:?RP0
1018>bP0AcXY04Dh9`14=bL2048d9`0604Lj:P16>BT0ACPX04@g9`13=RH0@SDU0P11=2@404<f9P@0
@SDU00P0?S4X03/a9`0k<BL0>C4V03H`900c;b<0<S0S034_8PP0=BhV0`0b;RD303<_9P80=30W200e
;b<2044c:00N048d9`12=BD0@cHU04@g9P15>2D0ACTS04Lh8@19>R<0CShW054o:@1B@2X0DchY05<m
:01A>bH0E40X05I2:@1JABX0HDX[06I>;01[DBh0KUD]075E;@1bGcL0Lf0h07AQ=`1fHcP0NFLi07]Y
>@1mJc/0OV`j0P20Lcl2085c@P03089dA@22M4L0PG970080P7580P1lJS`01P1mJ3T0O6Hg07aT=P1n
Hc@0OF8c07iR<`80O6He00H0OFDe081U=P21ICH0Q6Dg08EV>026ICP208=T>004089S=`21HSH0Of0d
07iO<`80OEhb00H0OF4b07aP<@1jGRl0N5`]07MK;01hG2d207UM;P0>08QS=`27HSD0QV4d08IR<P27
Hc40RFDa08]X<P2<JC<0TFTh099Z>@2CJcP0U6`h09E^=`2FKcH209M`=@0809M^>02HKcT0VW4i09ad
>@2NMST0X7Pj0:9j?02SO3/20:1h<`0>09mg<P2PN3<0Xg/f0:R0>`2/Q3l0[hM20;F<C02cRTX0[hI6
0:f4A02/Pd<0[HA40:n6AP2`QdL30:j7AP060:f6A@2[Q4<0Yh0o0:Am?02QNST0YG`j0P2TOC`01`2S
OCh0X7`n09mm@02LO440Vg]00:5oD@2RP5800P2SPE<0702RP580X7i@09ilCP2LNT`0VgI<09YeB@2I
M4P0VGA709UeA@2KMdD0W7Q409ijAP2KLSh0VG4n09Ib@P2DLTD0SVi507mS?01^E340HDTW0698;@1Y
CS40LUPg07aO?@22I3h0QFDl08IU>P26ICP207iS;P0307iR<01nHS80OF4b0080OF0d00L0OF0f07]O
;`1kGbl0O60`07eQ<@1nHS80Of<c0080P6@d00T0OF4_07eQ<@1lH340NUh_07QK;`1fFBl0LeH^079E
;@1aFBd00P1_ERd04@1/EB`0J58[06=?:P1OCBT0G4TX05U9:01NABH0Hd/Y06M?:`1XD2`0IdlY06QA
:01]ER`0LEX`07UO;P1kHC00O68a0080OV@c00h0OF<b07aR<@1kHC00Me`_07IK;P1eFRd0LeP[075F
:@1_E2L0KU<V06eB9@1YF2`0JUT]06]J;P80KE``01<0JeX^06YI;@1YF2`0MUh`07=K;@1`FR/0LE`]
079P<01aHC00KEd/06MI:01MCBT0F4PT05=37`1B@Qh0EDDQ05I68P1DA200DT8N00D0DT@Q00H0DD<P
05127`1@@Ql0B3lN04U07`1:@B0204]28@0304U07`17?Qd0ASdL00H0@c`O0P14?B0204Dn8@80A3dP
1013?1l3048k7`<0@CXN0P10>Ad0:`0l>1d0>cLL03/e6`0k=A/0?CHL044g7P14>200ASXR05Y38`1Q
BBL0JU0[07II;`22HS<0TFdi09mj@`2[Q4/0/9EP0:fAG`2WReT0X8AD09j2D`2XRel0^iid0<Z]P`3;
/XX0ajj60<6XO`2kXgL0]ia]0:nEI02UReP0WXAA07i/?01aH380GDhU04e07P11=ah0>34N038/7P0/
:1d0:bTM02XX700Y9a/00P0X9QX302LU6@<08b<I0P0R8QP3024Q5`T08B8J0P0N91X0100P8aX08B8J
024R6P0R8QX202@Q6P0402<T700R8a/08R<K028S6`808B8J0P0P8AT2020Q6`0301lP6P0N7aT07AhH
008071dG00<06a`F01/K6@0K6aT01P0K6aT@01TK6QP05aTH200F61L@01LI60P06A/H200J6QP301TK
6P806Q`K0`0K7A`801`L6PP07QhL200O81X201dM6`<07QhL0P0O7ad2020P7P<0820H0P0Q8AT3028R
6P0302@O6@0U81X09B0J00809B0J0`0V8A/302LS6P<0:2@K0P0Y9A`202`R6080;B<I0`0^91X01`0_
9A/0<B`I038[6@0c;1X0=2/J03HZ6P0h:a/00P0j:Q/203T/7080>RdM0`0k;Qh00`0l;al0?C0O03d`
7`0603d`7`0803l^7010;ad0@S4O04<b8012<Al0@C0N040_7@0o;Q`2044^7@80@RlN00@0@c0O04@a
8014<B00A34P0P17=Ad204Hd700<04Dc6`14<QX0A38J04@b6P0o;QX0@S4M04Le7`1<>200CcTQ054i
7`1@>1h0D3HK0P1B=R003`1A=Al0D3@N054e7`1B=R00E3PR05Hj901F?2<0EcdT05Tn8`1K@2<0Gd8T
06528`1UA2D0ID@S0618900206989@0306A79@1UAbD0IdHU0080JDHV00H0IDLU06I89P1WBBL0JD/Y
06]=:`1/CR`206i@;P80L4hY0`1aCbX3079@:`80LE4Z0P1`D2T406m?:00<06U;9`1ZC2P0K4hZ06e?
:`1/CRX0JT`X06Q:9P1VB2@0I4HP06E78@1XBR@0JT`V0P1/CRP306e?:@P0KdlX0P1]Cb/206i@;0@0
Ke4]0P1`Db/0101aE2`0LUD]07=F;P1dEbl207EH<080KdlX1P1^CRL01P1cCBP0L4dW071=9`1^C2H0
KDdV06Y=9@80JDdU00H0KE0X06a?9`1/CRP0JddY06Y<:P1YBR/206Q9;00A06e<;@1^CBh0Kdh]075@
;@1cDbd0MED^07MG<01hF2l0MU<Y07UF;01mFS00P5dc07mL<P1lFBl0Me@Z07AA9`1bDR/00P1cDb`0
0`1dE2d0MED^07IF;`0207MG<00807]H<01iERh0Me@/07IC:`1gE2`0NEH^07aI<@1nFc<207aI;`03
07eJ<01nFc40Oe`b0080P5dc00H0PEhd085L;`22GC00Peha08AO<P25H3<308IQ=00908MR=@26HC@0
QF0c08EP<`26HC@0R6<f08YU>02;IST0S6Hg0080SFLh0P2>J3T208mY>P0408iX>@2>JSX0SFTi08aX
>080RfLg00<0S6Ph08eY>@2>JSX00`2?Jc/00`2>JSX0SFTi08aX>00208]W=`P0S6Ph1026HC@01027
HSD0R6<f08UT=`2:ICP908QT=00508EP<`26HC@0Qf8e08QS=P29I3L00`2:ICP308AR<P0708ES<`26
I3@0QfDe08QV=P29IcL0RVDh08]V>@0308aW>P0408YU>028HcH0Qf8e08UT=`80R6<f00<0Qf8e08IQ
=026HC@00P25H3<8085L<P0808EN=`25GSD0QUlf08MP=@28HSD0RF<d08US<P2:I3<408MR=@@0R6<f
202;IST0202:ICT0RF@h08QS=P27Hc<0Qf<a08UU<@2;Ic<0S6Tc0P2>JSX608eY>@0608UU<@29IC<0
RFDc08UU=@29I3L0RF@h0P29I3X01@2:IC/0RfHl08]V>P2;IST0RfLg0080RfLe00<0RVHb08YT=`2?
JC`00P2CKD001@2@JSd0SVPk08mY?02AJch0T6/g00H0TF`h00@0T6/g08aW>P2<IcX0S6Lj1@2=J3/3
08iZ>P<0SFTi1`2<J3P308]W=`0308aX>02;IcL0RfLg0080RVHf0`29ICD308MS<`H0R6@d00T0Rf8d
08YQ<`2:HC<0RF0b08YQ<`2<HcD0SfHh091W>@2@JcL0102AK3P3099]>@80SfTj00H0TF/l09=]?P2E
Kd00Ug5209Qb@`2ILd@209E`?0<0U6lk0`2CKSX2099/?@80Tfdn0P2DKSl209E_@080TV`m00@0TF/l
091Z>`2?JCX0SfTj0P2>J3T00`2<J3P0SFTi08m[>`03091/?00308iZ>P2=JCT0S6Ph00@0S6Ph0P2=
JCT0102>JSX0QV8`08UU<`2=JCL208m[>@0308aX=P28I380QV8`00<0Pf4d:oooool002[ooooo0P2T
ND@20:EjA@80YW]60P2WO4L30:IkB0<0YGY70P2TNDH80:=hA@80Z7e:0P2WO4T20:IkB080YGY7202W
O4T40:UnB`@0ZWm<202XODX30:MlA@<0YW]40P2UNT<0102VODT0YGa80:ElB02TNdL=0:=jAPP0YGY5
202TNdL01P2RODT0XGa80:1kA`2ONTH0WWU509ag@`80VgI20P2JL3h0102IKcd0Ufdk09I/>P2DJSP2
09=Y=`09095/=`2@JcL0SVTe08aV=@2:I3D0Qf4d08IO=025GS<0Pf4c0080PV0b00D0PEla081N<01o
GBl0Oed_07iL;P0207aI<@0407]H<01jEbl0NUL_07UF;P80N5D]101fDbd0501eDR`0M54[07AA:`1c
D2X0LddX071=9`1_C2H0KT`V06i>9`1^DBT0Ke<[075E;@1cDb`0LU8[075A:P1`D2T0LE4Z079B:`1d
E2d0MED^1@1iER`307YG;@80QEl`0P26H3401027HC80R68c08QR<`29Hc@208]T>@0308]U>02<ISL0
S6He0080SFPd00<0SFPc08eW>02=IcP01P2<ISL308eW>P80S6Hi0`2;ICP808]W=`80RV@e00L0RF<d
08YT=@2;ICH0SFLh08mY>P2AJc`0SFLh0080SVPi0P2?JCX2091Z>`06095[?02?JSD0SfXf08mZ=P2?
JCP0SfTj0P2?JC`208mX?@0808iY=02=J3@0RfHb08YT<`2:I3D0RfDh08eV>`2>Ic`808aV=`P0Sf@g
0P2:IC400`2;IS80S6Lc08aW<`0208eX=00908aW<`2AJc`0TF/l08mY>P2>J3T0S6Hg08]U=P2:I3D0
RF<d00<0SFLh0P2<ISL308]U=PP0RVDh2029I3L808ES=@H0Q68d0P23HC<4085O<@@0PV0b0`1nGc<2
07eN<P<0O5da00H0NUdc07UL<P1iG380N5/a07MJ<01fFBl207EH;P0@07AD:`1eEBh0LeH^071D;@1/
DRd0Idl[069;:@1PBBL0FTDV05E28P1??R00CSdQ04hn901<?R@0ASXR048f7P80?3LS00@0>cHR03Xe
8@0j=B40>C@P0P0h<al01@0c<R00<C0N02l]7P0/:Qd0:RPL0080:RLN00@0:bPQ02<T700S91`08b@L
0`0R8a/2024R6P807b8K0`0N8AX401dP6@P07R0M00<06adJ01`N6`0N81d00P0O8Ah00`0N81d07AlL
01`N6`0901/M700L01`N6`0M7a`07R0K01lR6`0P8aX08B@I028U6P0W:A`0:RXN02`]7`0a;b00=34P
03Lb7`0i<R00>C8O02l/6@0a;Q/0=C8O03Ld8`0f<b@0<2dN02PT600R7Q808B<H028T6@0S9AX092HK
02DW708092HK00L08bDJ02DW6@0U9aX092HI02<U6P0R8a/08B8L0080824L0P0P8a`301lR6`/07R4J
00H071hM01dO700N81d07b4L020S700R9A`202<V6`0H02dY7P0`;200=2hR03@/7`0c:Q/0<bXI03P]
6`0k<1h0D3/L069>;@1iHCd0Q6]308mbB02LNdh0YX9B0:V5D`2`QUH0V7E;079K>`1<?b`0<blS02XZ
800Y:B40:2PN200T9R<302<V7`8092LP0`0U:24802LX8PP09RTR100Y:2<502XY9080;RTS0P0_:R@0
3`0`:bD0<B`V038]9`0b;BL0<2hO038`8@0h<R80?CHT04@i9`1;?2T0D3hZ0590;01EABh0Dd</04lo
:00204`l9@0304lo:01C@b`0EDD^0080Ad0V00@0AShW04Dm:013>bP0@STX0P11>2T03@0l=RH0?SLW
03lh9P11>BH0ACXX04Lj9`1:>bH0Bc`W04hm:`1=?2X0C3/Y04/j:01:>BL00P1;>RP07`1<>bT0Cch/
04hm:@1??BT0DC`W05<m9P1G?bL0FT8X05a2:@1RBBX0HdX[06=<;@1QC2l0Gd/`05Y9;`1HAbd0EDD/
04a0:P1;?bT0BC`Y04Pk:P15>2L0A3LW048d9`11<bH0B3/[04Lj:P16>BT0ACPX04<f9P12=BD00P10
<b<4048e9@@0@cHV00P0?S4X03/a9`0k<BL0>C4V03La9@0d<2@0<c4T038`8`P0=BhV0`0b;RD303<_
9P80=30W200d;B<2040b:@0N044c:012=2L0@cHV04<f9@14=bH0A3LT04Hg8P18>B@0C3/W050n:P1A
?b/0DSdZ054j:01@>BL0D3hX054o9`1F@RT0FdHY065::P1VCRX0JE4[06aC:`1aG340LUdb07EP<`1h
Hc@0O6Pf07m[>@21KCX0PVhi0P25M3h01`27MT80RGM508]iA`2;NDT0RWQ:08MdB@26LdP00P20Kc/0
2`21KC/0PF/j081X>020ICP0Of@g07mR=P1mIS@0OVLe085W=P24J3P0QfPi0080RFTj00L0RVPj08EV
>P25ISX0Q6Di089S=`21HSH0Of0d0080OUlc00@0O64d07]P<`1iGS40Me`_0`1fFbh02@1gG2l0QV4g
08EP=024Gc<0Q5lb08EQ<@27Hc40RFDa08]W<`0208iX>@0?08iX=`2?JSH0T6/f095/=@2AKC<0TVhd
09I]>@2GKSX0V6li09U`>02KLcP0W7@g09if>@2NMSP0W7<c00<0Vg8b00L0WWDe0:9i>@2WOSh0ZH10
0:j5A`2/PdD0ZX530080Z7m100<0ZX530:b3A@2^QDL00`2_QdT01P2^QTP0Zh=50:V1@`2VOT00Y7`n
0:V0?P80Yh0o00H0YGm00:=o@@2RP4<0X8150:61AP2RPU<40:>3E00K0:61DP2NOTl0WGe>09egD02K
MT`0VWE;09QcA`2HLdH0V7A409Ue@`2JMT@0Ufi009E_@P2DKd<0TW5608iaB@24Jd<0Meli06aF<@1W
CS00K54c07=I=P1lH3/0PfHn08MX?027IST0QFDf0080OF8]00<0OF4_07eQ<@1nHS<00P1nHCD01@1n
HCL0NUh^07]O;`1kGbl0O60`0080OF4a0P1nHS802@1kH340NEha07ML;`1dFBh0LED]071D;@1_Dbh0
KU8]06eC;P0206aB;@0>06UA;@1VD2/0HTh[05m=:@1MBRT0FTXX06189P1TC2P0JE4]06YB;01YDRT0
Je@Z06mH;01dGC4207]Q<00A07eS<P1nI3<0OF<b07aR<@1jH2l0NEl^07EJ;`1dFBh0LeP]075F:`1`
EBX0KU<X06eB9`1/DBH0J5L[06UH;01[FRh00P1/Fbl04`1[FRh0JEP/06QG:`1eGC40Le/_071I;@1a
G2l0LEla06iM;`1YF2X0HU@U05];9`1FAR80DT8N05517@1DA200ETHR05A4801B@Qh00P1B@b800`1A
@R40D44P0511800304m07`0304Po7P19@1l0BT4P0080Bd8Q00<0BD0O04Ln7@16?A`00P14?B0604<l
7`80A3dP0`13?1l3048k7P@0@CXN0P10>Ad203lh7080>CPL02L0>SHK03/e6`0m=Q`0?cPN04<i8014
>R40FD8R06189P1YCbX0M5L]081P<@2@K3P0WgY30:b5C02[T5T0YX]F09n4C`2KOdd0Wh=C0:fAHP2n
XGD0bjj20<fbQ`36Zgh0_J9e0;NLK@2_UfL0YHiL09V2D02?N4H0Je`e05mA;01?@R00@3HK03La6`0a
;Qd0;2XN02LW7@0U9A/00`0V9Q`202DU6`8092@J0P0R8QX2024Q6@@0820H2@0Q8QX201hT6P04020S
6P0Q8QX08B8J028R6P80924J0P0R8a/2024R6P<0824I00H07b0H01lP6P0O81X07QlI01dN600L7AL2
01/L5P0301XK5@0K6aT06a/I00H06a/I400I6aXH01LI60P05QPG400G6AP801TK60P06QXH0P0H6QT2
01TK6P806Q`K0P0K7A`801`L6PP07AdK200O81X201dM6`<07QhL0P0O7ad2020P7P807alG0P0P81P2
024Q6@808R8J0P0S7QP202@O6@0402DP6P0V8A/09R4K02HQ6`809R8I0`0W8aX302PT6`80;28H0P0]
8aT302hT6P0702lU6`0a;1T0<R/I03</6P0d:aX0=RXJ03P[6`0203XZ6`<0>2XM0P0i:ah303X/7`P0
?2lN00<0?RdK03l^7011<1h00P12<Al00`11<1h0@2lM03l^7003044^7@@0@RlN00@0@c0O04Dc6`15
<a/0AC<K1014<QX03013<AT0?bhJ044`7016=1h0C3PP04hh801@>1h0CcLM04le6P1B>240DCLP050f
7`80CcDN00`0D3HO058h8@1C>B80ECdS05Hn901H?R<0Fd0S05m2901P@b<0Hd@U06=58`1QBBD20698
9@0306A79@1UAbD0IdHU0080J4DU0P1UAbD01P1WBBL0J4XX06Y<:P1/CR`0KDl]06i@;P80KD`Y0P1^
CBX406m>:`80L50Y0`1_CbP306i>9`0<06M99@1YBbL0JddY06e?:`1/CRX0JT`X06M99@1TAR80HT@P
06A68P1WBBD0JT`X0P1/CRX00`1]Cb/0K4hZ06]=:@0806e=9P80K4hZ0P1]Cb/306i@;00306mA;@1^
DR/0KU8[0080Ke</00@0L5@]075E;P1aEBh0LUH_0`1/C2H506e=9`06075;9P1_C2H0Kd`V06i<9P1/
C2D0JTdU0P1XC2@206]=9`0G06Y<:01YBbT0J4TZ06M8:`1WB2`0ITL[06a;;01]C2d0Kdh]075@;@1c
Dbd0M5@]07EE;P1eEB`0ME8Z07QE;@1kF300OEXb07aI<@1iERh0MU<[07=@:01aDBX00P1bDR/00`1c
Db`0M5@]07EE;P0207IF;`0307YG;`1iERh0MU<[0080ME8Z00<0Me@/07YG;`1lFC400P1kF2h00`1l
FBl0OEX`07iK<@0207mL<P0;081M<`21G2l0PE`_085L;`22GC00Peha08AO<P25H3<0QV4d08MR=@26
HC@00P25H3<01026HC@0R6<f08YU>02;IST408aV=`80SFLh0P2>J3T00`2>JSX0SFTi08]W=`0208YV
=P0708]W=`2=JCT0SVXj08iZ>P2=JCT0S6Ph08]W=`0308YV=P0308UU=@2:ISH0RVHf00H0RVHf00D0
Peha08AO<P25H3<0QV4d08MR=@0308QS=PT0Qf<c0`25H3<208IQ=00708MR=@28HcH0RF@g089P<023
HC40Q68b08ES<`0208IT=080QfDe00<0RF@g08YU>02;IST00P2;IST00`29I3L0R6<f08IQ=00208QS
=P0608MR=@26HC@0QF0c08AO<P23GS40PUd`2020Fc401P24GCH0QEhe08EN=@26Gc@0Qf4d08QR<`80
RF<b0P28HcH408MR=@80QV4d202:ICP02@29I3P0R6<g08MR=@26HS80QV8`08QT<02:IS80RfPb08]W
=`0208aX>0<0SFTi0P2<J3P01P27Hc40Qf<c08MS<`27HSD0Qf8f08MR>080Qf4j0P28HS/03P27HSP0
Qf8f08MR=@27Hc<0R6@d08QT<P27H3D0S6Dj091Y?P2AJSl0SVLl08aU>P2>Ic`0T6Tn0`2?JCP208iX
=`<0SfTh1P2;IST208YU>0@0S6Ph0P2;IcL708YV=P<0RfLg102:ISH208UU=@80R6@d00D0QF4a08IR
<P26HS80QV8b08MS<`0408QT=00808US=028HS<0Qf4b08MQ<P28HS<0RV@e08aV=`2=IcP208mZ=P80
T6/g00`0TF`h099]>@2BKCT0TVdi08mY>P2@JS/0TF/l099/?@2DKSl0UW1109Ma@P2HLT<309A_>`<0
Tfhj0P2BKCT2099/?@80Tfdn0P2DKSl209E_@080TF/l00@0T6Xk08mY>P2>J3T0SFLh0P2<ISL0202:
ISH0S6Ph08eY>@2?Jc/0T6`l08m[>`2>JSX0SFTi0P2:ISH00`2;IcL0S6Ph08eY>@0308eY>@0308AP
<027Hc<0RfLg0080SVXj00<0RfLg08MS<`24H3000`22H38[ooooo`00:_ooool30:EjA@80YW]60`2W
O4L70:EjA`030:IkB02UNTL0YGY700H0YGY70P2XODX20:MlB@80YW]80P2UNTL90:MlB@<0Z7e:0`2Y
OT/00`2ZOd`0Yga90:MlB@060:MlB@<0Yge30P2VO4830:Ek@@040:ImB@2UO4P0Y7]70:=jAP80XWU5
00<0XgY60:AkA`2TNdL00P2TNdL30:=jAP<0XWU5202UNTD80:AkA`80XGa800H0X7]709iiA@2MN4@0
W7M309]f@P2JMD4209]_?P0409Y^?@2HK3/0Uf/j09EY>080U6Pg00P0SfXe08mZ=P2=J3@0S6He08YT
=@28HSD0Qf0e08IO=0<0PV0b0P21Gc43081N<080O5Ta00@0NeP`07YG;`1jEbl0NEH^0P1hEBd01P1e
DR`0MU<]07IC;@1gE2h0MU<]07EB;080Le0Z00X0MDlZ079?:@1aCRP0KddW06i>9`1^DBT0KU8Z071D
;01aDBX0L50Y0`1_CbP0101aDBX0LU8[07AD;@1gE2X207QE:`0307UF;01jEbd0NeP^0080O5T_0P25
Gc0208IP<@<0Qf4b00H0R68c08]T>@2;I3T0RfDh08aV=`2<ISD208eX=00308eX<`2>J3T0SVPi0080
SFLh102<ISL308eW>P80S6Hi0`2;ICP308aX>080RfLg0`2:ISH208YT=@80RfDf00@0S6Hg08eW>02>
J3T0SfTj0P2<ISL0102=IcP0SVPi08iX>@2?JCX2091Z>`0508eX<`2=J3@0SfXf08mY>02?JCX00P2?
JC`208eV>`0808mZ=@2=J3@0RfHb08US<P29Hc@0RfDh08eV>`2?J3d808aV=`P0SV<f00D0RfHb08aW
<`2=J3@0SVTe08mZ=P0208iY=@0708eX=02AJc`0T6Xk08mY>P2>J3T0SFLh08]U=P0208YT=@<0S6Ph
0P2;IcL308YV=P0308aW>P2;IST0RVDh0080RF@g00<0RVDh08]V>@2<IcX02028HcH808ES=@@0Q68d
0P23HC<2089P<P04081N<021Gc40PEla085O<@<0PV0b00@0Pf4c07iO<`1nGc<0OUlc0P1mGS8307aM
<@0607YM<`1iG380NE`b07QK<@1gFS00MUT_0P1eF2h04@1dE2/0MED^07=F;P1bERl0KE<^06Q@;01S
C2X0H4TW05]69`1G@R<0DSlQ04ln8P1@?bD0CShU04Tj8`15=Ql0?CPT0080?3LS00<0>cHR03Xe8@0i
=2000P0h<al01@0e<R40<c0O030]7P0^:Qh0;2PM0080:bLN00@0;2LQ02<T700S91`08b@L0`0R8a/2
024R6P<07b8K0P0N8AX401dP6@P07R0M00P06adJ01`N6`0N81d07b4N020R7`0O8Ah07R0M01dO70P0
6adL01T071hM01`N6`0M7a`07R0K01lR6`0P8aX082<H024T6@0V:1/0:2PL02X[7@0_;Ah0<RlN03Ha
7P0h<Al0>C8O02l/6`0`;A`0<RlL03Hc800g=240=34N02`Y5P0V8a008B<H00808R@I00/08bDJ02@V
6`0T9Q/092HK02<U6P0U9aT09BLJ02@V6@0S9AX08R<K028S7@02024R7@8082<L0`0O8Q/;01hQ6P0P
01dO7P0M7a`07R0M01lQ700P8a`08B@K024T6@0R9AX0:BHO02/X7`0_:b80<b`R03<[800c:Ad0<bXK
03DY6`19=A`0ET8W06YC=01lHSl0RVi609MhBP2OODd0XH1=0;:9E@2VPU80Qf]405m><P13>2@0<blS
02dZ8@0W9al802@V8`808bHO0P0T9b0302DX8@0302HY8P0W:2809bPR00H09bPR200V:B8402TX8`D0
:RTT0`0^:B<202lZ90<0<2/U00/0;BhP02l`800e<R<0?3DU044h9`18>bX0CSd[04ln;01C@b`0DT8[
04lo:00204dm9P0404lo:01B@R/0Dd</04To9080BClV00<0B3dW04Ll:016>bT00P15>BT0200l=RH0
?SLW03lh9P11>BH0ACXX04Lj9`1:>bH0Bc`W0P1=?2X00`1<>bT0BcXX04/j:00304/j:00@04ln;P1>
?B/0CS/Z050k:01B?2L0ESdW05Q0:01K@BX0HDHX06=8:P1SBR`0Hd/_061;<01MBC00FDD/05E3:`80
BclY00H0BC`Y04Pk:P16>BP0A3LW04<e:012=2L204Lj:P0704Hi:@14=bL0@cHV048e9@11=2@0@3<S
044d9003048e9@<0@cHV00L0A3LW03d`9`0k<BL0>c4W03Ta9P0h<RH0=C4U0080=38U200e;RH3038^
9@<0<blV0P0d<2L803@]9@80?c0Y00<0@38Y044c:012=2L00P13=RH01`14=bH0ASLT04Lh9@1:>BL0
CCXY04hk:P1@>bX00P1@>BT0401=?2P0CShW054o9`1F@RL0FdHW065::01UCbX0J50Z06eF:P1`FR/0
M5h_07YT<`1nJ3H0PVdh08A_>026LCX208Ud?@0708]f?`2?NTD0TWa:09=mC02ANd`0SGM808]dB002
08Ac>`0;08Ib?@26L3h0QFdm08EZ?@23J3/0PVDk085W=022J3D0QFTg08U[>@2;JcX00P2<JSX01`2>
JSX0QVLk08IW>`25ISX0Pf@h089S=`21HSH00P20HCD01P1lHCH0Nf0e07UN<`1gG340MU/`07ML<@80
N5db00T0Q5hg08=N=022GC<0PUda08=N<@25HC40Qf<a08UU<`2<IcX00P2;IcL00`2:IS@0RfLc08aY
<`0208i[<`80UF/i00H0UVdi09M^>02HKcL0VG4f09Yb=`2JLSD309U_<`0509Y`=02LLSH0WgDi0:5g
>`2RN3`0102TNSh0102VO400Z7i20:Z0A02[PDD20:f5B00@0:b4A`2[PdH0ZX950:R0@`2WOd80YWi1
0:Z1?`2YPT40Z8500:N1@P2UPD<0YH=60:F5BP2VQT/0XhE?0:B6D080YHMA00X0Y8I@0::4CP2PPT`0
WX1:09ilC`2LNT`0VWQ809QfAP2FMD80UWE00P2GMT00402GLD80U710095_@@2ALT<0SgA508UcA020
Jch0N6Hh075I<`1dFc<0N5lf081U>027Jc/0RV`h08UZ=025IRl207iS;P0307iR<01nHS80OF4b0080
OF0d00<0OF0f07]O;`1jGRh01P1jGRh0201gG340METa075E;@1^DR/0JdlZ06]>;01[CRh0K4l_0`1X
CBl00`1VCR`0I4d[065=:P0205m=:@0;05a<:01SBbL0IdlY06aD;P1]ERd0K5D[06eF:P1bG2d0MV0a
07YP;`1kHC000P1lHS40101kHC00NV0_07MM;01fG2/2075E;@80L5@/00L0Ke<[06iB:P1]DBT0KE4Y
06MF:P1XEb/0JUT]0080JeX^01L0JUT]06QG:`1WERX0M5/b075H;`1_F2h0KeX_06iK<01[FRh0I5<W
05a>8@1IBbH0EDLR05537P1@@Qd0DdDP05E78P1DAR40DD<N05=49@1B@b@0D44R04m08@0404ho8003
04Po7P19@1l0BT4P0080Bd8Q00<0BD0O04Ln7@16?A`00`14?B0304<l7`80@S/N0`13?1l2048k7P<0
@CXM00@0@CXN040i7@10>Ad0@3TM0P0o>1`203hg6`0X03Ph700g=a/0=cHJ03Te6P0k=A/0?SLM040i
7`14>R40Ed0P05e58`1VC2L0LE@Z07eM;P2>JSH0WWU20:b5C02URe80WhA=09YoB02JOdX0XhME0;6E
I@2oXg@0aj]l0<VZN`31XW<0]YYZ0:jDH`2VSed0VXAB08Qd@@1lJ3D0Fdh^04m49P12>1d0=S0J02l/
6@0[;1h09bTN02<V7@808R<K00L08b@L02@U7@0T9Ad08b@L028S6`0Q8QX08R4L00<08B0K0P0P7aX2
01lN6@T0824I0P0M8aT0100O8QT0824I020Q6@0Q8AT202<P6@808B8J0P0P8AT301lP600601hO5`0N
7aT07QlI01dN600L7AL06a`F0P0J6aD00`0I6Q@06QXH01XJ600601XJ61006A/J600G6AP801HH5a00
5aTH200I6aP801XJ60<061XI0P0I6aX301XL6`P071`J200M7A/801lP6P807AdK0`0N7Q`201lO7@80
820N0`0O7aL2020P60<08B4I0P0R7AL00`0S7QP091lI02DP6P0202HQ6`0402LR700V8QT09R8I02HR
6@809b<J0`0X91/202dS6@80;R@J0P0_9A/2030V7006034/6@0b:aT0<b`J03@[6P0f:QX0>2/K0P0j
:Q/0100f:1d0=bTN03LY7P0g:Ah203PZ7`80>B/P200k;Qh0200m;1X0?RdK040_7@11<1h0@S4O044`
7P10;ad0?bhL2012;ah00`14=1/0@c<J04<c6P0504<c6P05044`7013<Qh0AS@N04Xf7P1<=Qh00P1>
=Q`04P1?=AX0DSXR054i8@1?=al0CSHN04lg7`1@>200DCTQ058j8P1C?R<0E3lT05Lo8`1I@280Fd0R
05m28P1P@b<0HD<Q06189080HDLT00<0HdHT06A6901VAB@00P1WA2@01P1UAbD0ITPV06M99`1XBRP0
JD/Y06]=:`80K4h/0P1YBbT206Y<:P80Jdd[0P1/CR`306m?:080KThW0`1]CBH0301WBBD0J4XV06Y<
:01[CBT0JT`X06Q:9P1VB2@0I4HR06948P1TAR@0IdTW06]=:`80K4h/00<0Jdd[06Y<:P1XBRP0201/
C2D206Y<:080JddY0`1/CRX0101]Cb/0KU8]06iB;@1^DRd506eA;00406]:9`1/BbP0K4/X06a;:0<0
KD`Y01H0KTdZ06m9901^BbD0Kd`V06i<9P1/C2D0JD`T06M;8`1VBR80JT`X06U;9`1YBbT0J4TZ06M8
:`1VAb/0IDHZ06E5;01[BR/0KD`]06m>;@1aD2d0LU8/0P1cDb`00`1cDbX0ME8/07IC;@0307MD;P04
07IC;@1dDB/0Le0Z071@:@80LE4Z00<0LU8[07=C;01dE2d00P1eEBh00`1hEBd0Me@/07IC:`0207EB
:P0307IC:`1gE2`0N5D]0080NUL]00<0NeP^07aI;`1mFS000P1nFc400`1oG380PE`_085L;`02081K
;P06085L;`23GS40QF0c08IQ=027HSD0QV4d0P25H3<01@26HC@0R6<f08YU>02;IST0S6Hg0080RfDf
00P0RV@e08]U=P2<ISL0SFLh08iX>@2=JCT0S6Ph08]W=`80RVHf00H0RfLg08aX>02=JCT0S6Ph08]W
=`2:ISH308QT=00508UU=@2:ISH0R6Hf08MU=@26I3@00P25Hc<01`26I3@0QfDe08QV=P23GS40Q5lb
08IQ=027HSD00`28HcH00`27HSD0QV8b08IR<P0708IR<P0308MR=@26HC@0QF0c0080Q5lb00L0QF0c
08IQ=026HC@0P5h^085O;`23HC40QF<c0080QV@d0P25Hc<00`28HcH0RF@g08YU>00208YU>00308QS
=P27HSD0QF0c0080Qf8e00H0QV4d08EP<`23GS40PUd`085L;`20Fbh207mJ<0<0P5/a0`21G3802@24
GCH0Q5dd08EN=@26Gc@0Qf4d08QR<`28HS40RF<b08UT=`0208QS=P0508MR=@26HC@0QF0c08EP<`24
Gc802028HcH03028HcL0Qf8f08IQ=025HC40QV8`08MS;`29IC40RVLa08IT=027ICD0R6Hf08UW=`80
RVPh00P0RFLg08QV=P25HC40QF4a08EP<`25H3@0QF0f08EO>080QElj0100Qf4l08IP>`25GcP0Q5le
08AO<`25H3<0QV8b08MS<`25GSD0RV<j08iW?P2?J3l0S6Dl08]T>`2<IC`0SfPo0P2>J3T408aV=`80
SVPi0`2;IST208YU>0<0RF@g0P29IcL208QV=P80QfDe0P26I3@308QT=080RFDe0`2:ISH02028I3@0
RFDe08YV=P2:ISH0RFDe08QT=027Hc<0QV8b0`23HC4308AR<P<0QF<c00<0Qf<c08IR<P26HS800P26
HS800`28I3@0RfLg08aX>00208iY=@0308mZ=P2@JcL0TF`h0080TVdi00<0Tfhj095[?02AJc`00P2B
K3d0102CKCh0U6ho09E_@02EKd0309A_>`80Tfhj0`2BKCT2099/?@80Tfdn0P2DKSl209E_@006095[
?02@JS/0T6Xk08mY>P2>J3T0SFLh0P2<ISL03029ICD0RVHf08aX>02=JCT0SVXj08eY>@2<J3P0RfLg
08QT=029ICD0RfLg08aX>0@0SFTi00P0QV4d08QS=P2:ICP0RfHi08YU>028HcH0QF0c08=N<@<0PEl_
:oooool002[ooooo0P2UNTD20:IkAP@0Yga70P2SN4D0102TNDH0YGY70:IkB02VNdP20:MlB@P0YW]8
0P2XODX20:MlB@80YW]80P2UNTL80:MlB@030:EjA`2VNdP0YW]80080Yga90P2XODX00`2YOT/0Yga9
0:MlB@060:MlB@040:Mm@`2VO480YWa20:Il@P80YG]10P2TNT002@2VODT0YGa80:=jAP2RNDD0XGQ4
0:9iA@2SNTH0Y7]70:ElB0020:AkA`<0XgY60P2RNDD00`2QN4@0YGY50:EjA@060:EjA@P0Y7]70P2P
NdL0102ONTH0WGQ409ag@`2JMD4209Ud@080WFln00@0W6hm09Y/>`2IJcX0UfTh0P2FJ3L01P2=J3<0
SFPd08aW<`2;IC@0RV@e08US=P80R64f0`22H385085O<@80O5Ta00@0NeP`07YG;`1jEbl0NEH^0P1h
EBd00`1dDB/0ME8/07IC;@0207MD;P0=07EB;01cD2X0LTlY07MA;01dDB/0LTlY071>:01^CRL0KE0X
06eA:@1^DRX0KdlX06i>9`0306e=9P0;06m?:01`D2T0LU8[07IC:@1gE2X0N5D[07YG;@1lFBl0OU/a
07mL<P20GC<00P25Gc0408IP<@80Qf4b0P2;I3T00`2;ICP0S6Hg08aV=@0208eX=00408eX<`2?JCX0
SVPi08iX>@80SFLh0P2<ISL0102;ICH0SFLj08eW>P2=IcX208aV>@<0RfDh00<0SFTi08aX>02<J3P0
0P2;IcL208YV=P0308UU=@2<ISL0S6Hg00H0S6Hg0P2:I3D0102;ICH0S6Hg08eW>02>J3T208mY>P05
08]V<@2<Ic<0SFPd08iX=`2>J3T00P2=IcX02P2<ICX0Rf@i091[=P2>JCD0RVDa08QR<@28HS<0RV@g
08iW?02@JCh808aV=`P0SV<f00<0S6Lc08eX=02?JSH00`2AK3P0102?JSH0SVTe08mY>P2?JCX208iX
>@0408eW>02<ISL0S6Hg08]U=P<0RVPh0P29IcL308QV=P0308eX>`2<IcX0RVDh0080RF@g00<0RVDh
08aW>P2=J3/02027HSD908ES=@80Q68d0P23HC<2089P<P03085O<@20GS00P5h`0080PEla0P22H382
08=Q<`<0OUlc0P1mGS8307aM<@0607YM<`1iG380NE`b07QK<@1gFS00MUT_0P1eF2h0401cDbX0MED^
07AG;`1cEc00KeD`06YB;P1TCB/0HDXX05i7:01J@b@0DchQ058n8`1A@2H0CclV04/k9015=Ql203dh
900303`g8`0k=R80>SDQ0080>C@P00H0>3<O03Hc8P0d<B00<BhO02hZ7P0/:1d202/W7P0402/V800S
91`08b@L02<T70<08R<K0P0Q8QX2020S70807b8K100N8AX00`0M81T07R0M01hP7@0601hP7@0801XL
6@0K7AX07AlL01lQ7P0P8Ql07b4N01hP7@0M7a`801/M700H01`N7@0L7Q/07AlL01dO6P0N8AX07b8I
01lR5`0P8aP092HI02HV6P0X:A/0;2XK030]700d;a`0=c0N03Pa7P0_;1/0;R/J02l/6@0c<1d0>3HQ
03Le800a;aP0:bTB0P0Q8aP2028T6@808bDJ0P0T9Q/01P0V:1X09BLJ02DW6P0T9Q/08b@L028S7@80
8B8M0P0P8a`301lR6`<07R4J200O8Q/01P0M7ah07AlL01hP7@0O8A`07b8K020S6P808B@I01P092<N
02LV8@0/:B80<BdT03@]8`0d;240<BTL030V6P14<Qh0C3PP05a7;01cFS/0R6a509AeB@2HN4T0VWU6
0;27C`2]R5@0V7U=075J>01A@BP0?CHV030]900U91l802DW90<092LP0`0U:24202HY8PP09bPR200V
:B8402XY90D0:BPS00<0;BPR02hY8`0^:B<00P0^:B<302lZ900802`^800_<280<c4R03Xd9P0o=RL0
ASTY04Xj:P1=?2`20510:@@0CclX0P1@@2T204Xn9080BCdU00`0BCdW04Tl:@19?2/0BC`[03`f9P0n
=bL0?cPV044i9P15>RP0AcXW04Xk9P1;?2L204dl:P<0C3/Y0P1;>RP04@1:>BL0CSd]04hm;@1>>bX0
CcXW054k9P1E?2P0EchX05Tn:@1QA2H0HDHX06=8:`1TBRl0HTX`05e7;`1HA2/0ET8Z0080BShX00L0
BC`Y04Pk:P17>RT0ASTY04Dg:P14=RT0ASTY0080ACPX00<0A3LW04<f9P13=RH00P12=BD2044d9080
@SDU0P13=RH204@g9`0603d`9`0k<BL0>c4W03Ta9P0h<RH0=S8V0P0e<bH803D^9P<0<RhU0`0c;bH2
03@`9`P0=BhV0200?RlZ03h_:00o<2T0@38Y044c:012=2L0@SDU04<f9P18>BH0AcPU04Pg9@19=RD0
BSLV04hi:01@>BT0DS/[04/l:@1<>bL0CShW05509P1F@bD0G4PW069;:@1UCbX0JU8R06iF9P1dGB/0
Nf@`085Z=025KcH0R78i08Uc>@80Rg8i01P0SgHn09Ak@`2HOdT0VGm<09IlB`2BMdP0SgA508If>P27
Mc/0RGHl08Ye@02:Ld40RFi108M/@@26JCl0PfPc08EZ=@29JcL0Rfdi08e]>P2>KCX0Sf/i08iZ>026
Ic/208EV>P0308AU>@23I3P0Pf@h0080PV<g00<0NV4h07UP=`1gGSD00P1fGC@00`1gGSD0N5lf07UP
=`02089L=@0?085L<P21G300PUd`08AP<026HS80Qf<a08UW>@28ISP0QfDe08IT=026IC80QfHa08UX
<P2;JS@0U6Xj0080U6Xh00<0UF`h09I]=`2FKCD00P2GKc@0102GKC<0V6hd09Y`=P2KLCL409ab>006
09U_=@2KLCL0WW@j0:5g?@2TNT00YWa20P2WOD<30:MoA080YWi30`2UOD80202WOS`0YWln0:En?@2T
OSl0Y8120:F3AP2VQT/0Z8Q=0P2VRT/20:N;C0090:J:B`2TR4T0XXI70:65AP2QPT`0Wh1:09amAP2I
NT40UgTm0080UgTk0140UgTi09Yg@@2EM3h0T74k08eb>`2;M3h0R7Dm089a>@1mKSD0OFLf07eV=01n
Ic<0QF`d08]a=P2>LS<0RV`/08EX9P0207mT;`0707iR<01nHS80OF4b07eP=01lGc<0O5le07]O;`02
07YN;P0307UM;@1hG2`0Me/[0080MUXZ00P0LEP`06iE;@1ZD2/0IT`Y06A:9`1UBbX0Id`^06Q=;`<0
I4T/00h0HdX/069;:`1QCB`0H4hZ065?:`1OCb/0IdlY06]C;@1_F2l0L5T_06mH;01_FBX0Led^07QR
<@80NV0_0P1kHC00101iGbh0Med/07EK:P1cFBP806iB:`0306IE:@1WERX0JEP/0080JUT]00d0JEP/
06MF:P1VEBT0LUTa071G;`1]ERd0KEL^06aI;`1WER/0GdhS05M87@1ICBL0E4PR0080D4@N00P0DdLQ
05E98`1DB280DTHP05=49`1B@bH0D44T04dn8@80C3dP00D0CChQ04ho8P18?ah0BD0O04Y1800204]2
8@0304U07`17?Qd0ASdL0080AChQ0P14?B000`13?1l0@S/N048k7P04048k7P80@CXM0`10>A`2040i
7@80?cPL0`0n=a/0<@0m=QX0=STL03Dh6`0f=QX0=cHJ03Xf6`0m=ad0?cTO044j801E?Qh0Fd<Q06=9
901^DBL0Ne//08aX=02MN440ZhA;09j4B`2JP4L0Uga509b1C02YSE/0]IUW0;fQL@30Y7@0`:1]0;NG
I02]Sed0Y8YG09b5D`2=NDH0MV@b06ID8P1?@bT0AC/R03Ta700`:aP0:bTJ02PZ7@0U:1l08BHO01hQ
6P0O8Q/08B@M028U7P0S9Ql08RDN020S700O8Q/00`0R8Ad2024P70<081lK2@0P8AT201dS6@0401lR
6@0P8AT0824I024Q6@808b0I0`0P8AT201lP60<07QlG00H07QlI01dN600M7QP071dG01/L5P0J6aD2
01TJ50P06QXH400I6aXH01LI60P05QPG400G6AP801TK60P06QXH100H6QT201TK6P806Q`K400L71X8
01lP6P807AdK0`0N7Q`201lO7@80820N100O7aL2020P60808B4I00D08A`F028M5`0R7AL08ahH02DP
6P0202HQ6`0302LR700U8AP09B4H00809R8I0`0W8aX0100X91/0;bDK02lU6`0_9A/2030V70<0<BLM
00H0<B`I038[6@0c;1X0=2/J03HZ6P0h:a/203XZ6`0403DW700f:1d0=RPM03HX7@80=bTN0P0h:Ql8
03X/7`0803`[6@0m;1X0?bhL044`7P12<Al0@C0N040_7@0o;Q`504<`7`<0@RlN1P13=A/204@f7080
AC@P00T0AC<M04Lc6`19<a/0C3@J04de6`1?=AX0DS`T054k8`1?>B400`1>>2001`1@>R80DC/S05<o
901C?b@0E3lR05M08@1I@2400P1J@1l01`1M@1h0GDDQ05i48@1OAB80HD@R06=58`1UA2<00P1WA2@2
06M99`80J4XX0P1YBbT206Y<:P<0IdXZ0P1XBb/306U<;0<0KThW0P1]CBH306a<9@D0J4XV00H0IdTU
06I8901VB2@0HT<T06E69`1XBBX306]<;@0306Y;;01WB2T0IDHW00P0Jd/T0`1XBRH206U;9`<0JT`X
0P1[DB`00`1ZD2/0JDlZ06Q>:@0206M=:00406I<9`1[BRL0K4/X06a;:080KD`Y0P1^CBX03`1_CR/0
KTPS06e:901^BbD0KT`V06a<9@1YC2@0ITXR06E98@1YBbT0J4XX06Q9:P1WB2/0ITL[06E6:P0206A4
:`0506]::`1/Bb`0Kdh]075@;@1bDR`00P1bDR/01@1aDBP0ME4]07A@;01cCb/0LThZ0080LDdY00L0
LThZ07=?:`1`D2T0L50Y075A:P1bDR/0Le</0080M5@]00@0MED^07EB:P1fDb/0MU<[0P1gE2`0101f
Db/0ME8Z07AA:@1iER`207YG;@0307]H;P1lFBl0OEX`0080OU/a00X0PE`_081K;P1oFRd0OeX]081K
;P22GC00Q5lb08IQ=027HSD0QV4d0P25H3<03`26HC@0R6<f08YU>02;IST0S6Hg08]U=P2:I3D0RF<d
08YT=@2;ICH0SFLh08iX>@2=JCT0S6Ph08YV=P0208UU=@0608YV=P2<J3P0SFTi08UU=@28I3@0Qf<c
0P26HS801P28I3@0RVHf08]W=`26ISD0QFDd08=S<P80PV8a00H0Pf<b08EU=026ISD0QF0c08IQ=028
HcH208UT=`0308QS=P27HSD0QV4d00T0QF4a00@0RF@g08MR=@25H3<0Peha0P22GC002023GS40Q5lb
07mM;@20GRh0Pf4a08ES<`26I3@0QF<c0P24HS803P27HSD0R6<f08UT=`2:ICP0RF@g08QS=P26HC@0
QF0c08MR=@26HC@0QF0c08AO<P22GC00PE`_0P1oFRd00`1oFS00P5/a081K<@02085L<P80PUdc00L0
Pehd08AM=P24GC@0QEhe08EN<`26H3<0Qf4b0080R68a0P29I3L01028HcH0Qf8e08IQ=024Gc8208=N
<@P0QV4d00/0Qf8f08IQ=@25H3<0Q60`08EQ;`26HRh0R6@`08UV<022HS40Pf<b08EU=00308MW=P07
08IV=@25IC@0Q5lb08AO<P24Gc<0Q5le08AN=`0208AN>@0;08AN>P26H3`0QElj08AN>@23GCH0Pehd
08AO<`25H3<0QV4d08=L<`28HCP00P2=ISd01`2;I3/0RV<j08]T>`2>Ich0SVPi08aV=`2;ICH00P2:
I3D00`2;ICH0S6Hg08iX>@0208aW>P0308]V>@2:ICP0RVDh0080RF@g00@0R6<f08IV=@26ISD0QVHe
0P25IC@308AT<`0308IR<P27Hc<0Qf<c0080R6@d0P29ICD02@2:ISH0Qf<c08QT=029ICD0RVHf08UU
=@28I3@0QV8b08EQ<@0208=S<PL0PV8a00T0QF<c08AR<P23HC40Pf4a08AR<P26I3@0R6Hf08YX>02=
J3@00P2>JCD01@2?JSH0TF`h099]>@2BKCT0Tfhj00<0Tfdn1@2BK3d0102DKc/0Tfhj09=^>P2CKSX2
099]>@80TF`h0P2BK3d209=]?P80U6ho0P2EKd02095[?003091Z>`2?JCX0SVPi0080SFLh00@0S6Hg
08QT=029ICD0RVHf0P2;IcL01`2:ISH0R6@d08MS<`26HS80R6@d08YV=P2=JCT00P2>JSX00`2=JCT0
S6Ph08UT>00208UT>00508QS=`27HSH0QF0d08AO<`23GS800`20Gb`[ooooo`00:_ooool20:EjA@80
YW]60`2WO4L02@2XODP0XWM40:9gA02SN4D0YGY70:IkB02WO4T0Z7e:0:UnB`080:MlB@80Z7e:0P2W
O4T20:IkB080YGY7202WO4T20:AiAP040:EjA`2VNdP0YW]80:MlB@80Z7e:202WO4T40:Il@080YG/o
0P2TNSh00`2VODT0YGa80:=jAP030:5hA0050:=jAP2TNdL0YGa80:ElB02TNdL00`2SNTH00`2RNDD0
XGQ40:5hA0080:EjA@P0Y7]70P2ONTH01P2NNDD0W7M309]f@P2JMD40VGA009Qc?`80WFln00@0W6hm
09Y/>`2IJcX0UfTh0P2FJ3L0202<Ic80S6Lc08aW<`2;IC@0RV@e08YT=`2:HcP0RF8g1022H384085O
<@80O5Ta00@0NeP`07YG;`1jEbl0NEH^0P1hEBd00`1dDB/0ME8/07MD;P0207MD;P0K07EB;01cD2X0
LTlY07UC;P1eDR`0Le0Z071>:01^CRL0K4lW06a@:01]DBT0KThW06e=9P1/C2D0Jd/T06a<9@1]CBH0
KdlX075A:P1eDRP0MU<Y07QE:`1kF2h0OEX`081M<`21GS@0PUle00<0QEl`1@26H34208]T>@0308]U
>02<ISL0S6He0080SFPd00<0SFPc08mY>P2?JCX00P2>J3T0102=IcP0S6Hg08aV=`2;ICH308eW>P80
S6Hi0`2;ICP208eY>@0408aX>02;IcL0RfLg08YV=P80RFDe102=IcP208aV=`80RfDf00d0R68c08US
=02:I3D0RfDf08aV=`2=IcP0SVPi08mY>P29I2l0RfHb08aW<`2>J3L0SVPi0080S6Hi00X0Rf@i08UR
=`2@JcH0SVTe08YU<@28HS40R68c08YT=`2>Ic`0T6Tn202<ISL808iS=P0808eX=02>JCD0T6/g099]
>@2CKSX0TVdi091[=`2?JSH308iX>@@0SFLh00@0S6Hg08YX>02:J3P0RVPh0P29IcL308QV=P0308eX
>`2<IcX0RVDh0080RF@g00<0RVDh08aW>P2=J3/02025H3<908ES=@80Q68d00<0Pf4c089P<P22H380
0P21Gc43081N<003085O<@22H380Pf4c0080Pf4c0`1nGc<207eN<P<0O5da00H0NUdc07UL<P1iG380
N5/a07MJ<01fFBl207EH;P0@07=C:P1eEBh0M5L_07AH<@1`ES40JU8^06A=:`1QBRP0GTLX05Y3901D
?b80DchS05<o9P1@?RH0Bc/T04Lg8080?CPT00@0?3LS03/f8P0j=B40>SDQ0P0i=2001@0h<R80=S0P
03<]7`0`:Qh0;RLM0080;BHN00@0;BHP02<T700S91`08b@L0`0R8a/2024R6P8082<L0P0O8Q/501hQ
6PP07R0M00H06Q`I01/M6P0M7a`07b4N020R7`0O8Ah201hP7@P06adL00H071hM01`N6`0M7a`07AlJ
01hQ6P0O8QT201lR5`0902<U600U9AT09RLI02XX6@0^:aX0<bhK03H_7@0g<1d0;b`K0080;BXI00H0
<BhK03Le800h=Ql0=38K02h/4`0R91T2024S60808R@I0P0S9AX01`0T9Q/09RPJ02HX6`0U9aX092HK
02<T700R8ad00P0Q8Qd2020S70<07b8K0`0N8AX801lR6`0P01dO7P0M7a`07R0M01hP6`0O8Q/082<J
020S600Q91T08b8N02DT7`0/:B@0<B`V03D^9P0d;B<0<BTN02hV6`13<1l0AC<O05Do9`1^EcP0QF]6
095dB02EMDH0U7A10:j6B`2_RU<0X81A07]Q?01HAb/0@STX03<_9P0T8ah802DW90<092LP0P0U:243
02HY8PP09bPR200V:B8402XY90D0:BPS0P0]:28602hY8`0802d_8P0^<280<c4T03Ld9@0n=bL0A3PX
04Ti:@1:>RX204hn9`0404lo:01@@2T0D40Y04lo:080CShW00H0BChR04Tm8`19?B<0BShV04Xn:01:
?BX204/n;@0803`f9P0n=bL0?cPV044i9P15>RP0AcXW04Xk9P1;?2L304dl:P80C3/Y0P1;>RP06P1:
>BL0CS`^04hm;@1>>b`0CcXY054j:01E?2P0EchX05Tn:@1O@R@0HD@V0697:P1SBBh0HDT_05a6;P1I
@b/0ED4Y04Xn:019?BL0BC`Y04Pk:P17>RT0ASTY04Hh:`15=bX0ACPX1014=bL304<f9P<0@C@T00<0
@SDU04<f9P14=bL00P14=bL01P0m<2L0>c4W03/a9`0j<RL0>38V03Hb9P80=C<V200e;RH3038^9@<0
<blV0P0d<2L803D^:080?RlZ01h0?c0Y040b:@11<bP0@C<V048d9`12=BD0BCTY04Ph:017=RH0Ac@U
04Pe9P1<=RP0DCX/05<l;P1:>bP0Bc`W04`l9@1??R@0ED8T05Y69@1OBbP0I4hY06QA7`1/EB<0Le`X
07YS;`22JcD0Qg4h08Yd>P2;MC/208]b>@0708mf?@2EO4@0VH1:09Z0C@2GODX0TWQ708meA00208Qh
>P0>08ai?P2=N440SGI408aaA02:Kd@0RFa408EZ=@26JcH0Rfdi08e]>P2?KS/0T6`j08m[>@2?JCP4
08EV>P@0Q6Di00<0NF8h07QQ=`1gH3H00P1fGcD04`1gH3H0NF8h07YS>@22G3L0PE/d081J<`20Fc40
PE``08=N<@25HC40Qf<c08QV>@27ICL0QF<e08AR<P25I340QVD`08QW<@29J3800P2CJCT00`2DJSP0
U6/g09A[=@0209E/=00409E]<P2FJc@0V6df09]`>@80WG8k00P0Vg0i09U^=`2GK3D0TfT_09I/<P2K
LCL0X7Hl0:Aj@0<0YG]100<0XWXo0:5i?P2QNCh00P2QNCh20:9j?`0;0:=k@02TNcT0XW/j0:9k>P2R
O3d0XWi00:B2A@2UQDX0Z8Q=0:F=A`2VSTP00P2WSdT02P2VSTP0Y8a60:::A02PR480XhE90::4B02N
P480Vgdm09Uk>`2HNcT209Qk=`0@09ik@@2GMc`0T74h08Y`=@28LSH0QW@f085a<`1mKc00QG0g08A^
=@23KC40RG4c08mf=02@MC00S6lY08IZ8@80P6D`00`0Of<a07iR<P1mHC80O5lc07]N<P1kGS@0Nel_
07YN;P1iGBd0N5`/07IJ:P1dF2P207=G9`0906eF;@1ZDR`0IDdW06599@1PB2H0HTTZ06A;;@1VCBl0
HDD]0080HDH[00l0HDL/065::`1QCB`0HDl[069@;01PDBX0JU8/06iG;P1bFc80LU/a071I;@1aFb`0
M5h]07QR<@1iGbh00`1jH2l0101hGRd0MU`[07=I:01aEbH206a@:@80KE4Z00L0KU8[06mC;01_Db`0
Ke</06IE:@1WERX0JEP/0080JUT]00d0JEP/06MF:P1VEBT0LEP`06iE;@1/EB`0K5H]06YG;@1UE2T0
GD`Q05A56P1ICBL0EDTS0080DDDO00X0E4PR05I:901EBB<0DdLQ05A5:01B@bH0Cd0S04dn8@1;?1l0
C3dP0P1=?R400`18?ah0BD0O04Y1800204]28@0304U07`17?Qd0ASdL0080AChQ0P14?B001013?1l0
@S/N048k7P11>Qd3048k7P80@CXM0`10>A`01010>Ad0?cPL03lh700o>1`203hg6`80?CHJ0P0e>1/0
500f=QX0=cHJ03Xf6`0l>1d0?cTO040j801D?Ad0FD4O06988`1/CbD0NETZ08YV<P2LMd00ZX=:09^1
AP2GOD@0UWa309j3C02/TE`0^9aZ0P2lX7004`2hUf80[i1J0:F7D`2MPe00UGi:08A`?@1[FBL0F4PE
04Pm9`0o=b80=2dJ02`Y600X:A/09RTN02<X8@0P9al07B0I01lR6`0Q91d00P0R9Ah0100Q91d082<L
01lR6`0S8Qh3028Q7@808B0L0P0P7a/9020Q6@807B<I00@07b8I020Q6@0P8AT08B4I0P0S81T2020Q
6@807b0H0`0N7aL01P0M7QH07AhH01dN600L7AL06a`F01XK5@806AXD00<061TC01XJ600J6QP01P0J
6QP@01TK6QP05aTH200F61L@01LI60P06A/H200J6QP0100G6AP061XI01PJ6@0H6QT201TK6P806Q`K
400L71X801lP6P807AdK0`0N7Q`201lO7@80820N00@07QhF01lO5`0O7aL07alG0P0P81P2024Q6@80
8A`F00<08QdG02<N600T7aT00P0V8A/00`0W8Q`09B4H02DQ600202HR6@@09b<J0`0`9Q`2034W7@<0
<RPN00H0<B`I038[6@0c;1X0=2/J03HZ6P0h:a/203XZ6`<0=BLN0P0f:1l303LY80P0>R`O00<0?2/I
03d/6P0o;Q`00`11<1h00`10;ad0?bhL04@a800304@a80@0@c0O0`13=A/404@f700A04Dg7@18=b<0
AcHR04Dc7@16<QX0Ac4I04Xb601==A/0D3HK05<m9@1B?2@0D3XR04li8@1>>200CcTQ050j8P1A>b<0
0P1C?b@0301D?b80ESlP05Ln7`1G?ad0F3hM05Pn6`1K@al0G48O05e3801P@b40HT@R06E48`80Id@T
201XBRP206I9:@80IdXZ0`1XBb/0101YC2`0KThW06i>9`1^CRL206e=9P<0K4`U00@0JD/W06Q:9P1W
BBD0IdTU0`1VB2@0101WBBD0Hd@U06E69`1YBR/306]<;@0306U::`1VAbP0Hd@U00P0JTXS0`1WBBD3
06Q:9P80JD/W00T0Je<_06YB;P1YDBd0Idl[06E=:@1TC2P0Hd/W069:9P1[BRT00P1/BbX00`1]C2/0
KTd/06i=;00206m>;@0806e78P1/BB<0KT/U06i<9P1/C2D0JD`T06E98@1TB20206Q::00306M8:@1V
AbX0IDHZ0080I4@[0180Hd</06Y9:P1/Bb`0Kdh]075@;@1bDR`0LU8[075A:P1`D2L0MU8^07=?:`1`
C2P0KTXV06e99@1_BbL0LDdY07=?:`1_CbP2071@:@03075A:P1bDR/0Le</0080M5@]00<0Le0X07AA
:@1gE2`00P1hEBd00`1fDb/0Le0X075>9P0207UF;00307YG;@1kF2h0O5T_0080OEX`00/0OU/a085L
;`20Fbh0OeX]07iI;01oFRd0PUd`08AO<P26HC@0Qf8e08IQ=00208EP<`0?08IQ=028HcH0RVDh08]V
>@2<ISL0RfDf08US=028HS<0RF<d08]U=P2=IcP0SVPi08eY>@2<J3P0RVHf0080RFDe00D0RVHf08aX
>02=JCT0Qf<c08IR<P0208EQ<@0708IR<P28I3@0RVHf08aX>025IC@0Q6@c089R<@02085Q<006089R
<@24I3<0QFDd08IQ=027HSD0RF@g0P2:ICP00`29I3L0Qf8e08EP<`0908EQ<@0B08YU>028HcH0QF0c
089M<021G2l0P5/^085L;`22GC00OU`/081N;P22H300QF<c08IT=025Hc<0Q68b08=Q<@27HSD0R6<f
0`29I3L02`27HSD0QV4d08AO<P27HSD0QV4d08EP<`23GS40PE`_081K;P1oFRd0OUT/0080P5/a0P21
G3801@22GC<0Pehd08=N=024GcD0Pe`e0080Q5dd00<0QEhc08IP<`27HC800P28HS40202:ICP0RF@g
08QS=P27HSD0QF0c08AO<P23GS40PUd`2024Gc802`27HSH0QV4e08EP<`24H300QF4_08IR;P28I300
RFH`081P;`21HC00Q6@c00<0QVHe00<0Q6@c08=S<P24Gc800P24Gc<00`24GcD0Q5hg08AN>@0208AN
>P0C08MQ?@25Gc/0Pedh089L=@22GC<0Pehb08EP=027HSD0PU/d08MP>@2<ICh0SFHo08YS?029HS/0
Rf@m08iW@02=IcX0S6Hi08YT=`0208US=P0308YT=`2<IST0SFLj00<0S6Lj00<0RfHi08YU>029I3L0
0P29I3L01026ISD0QFDd08EU=025IC@208AT<`80Pf<b00@0QF4a08IR<P26HS80Qf<c0P28I3@208UU
=@0808IR<P27Hc<0RFDe08YV=P29ICD0R6@d08EQ<@24H30308=S<P80PV8a00H0PF4`081P;`20H2l0
P60_08ES<`24HS8208=Q<@0408AR<P26I3@0R6Hf08YX>080SFPd00<0SVTe08mZ=P2@JcL00P2BKCT0
0`2CKSX0U6ho09A^?`0209=]?P04099/?@2AJc`0TF/l095[?0@0Tfhj0P2BKCT2095/>080TV`m0P2C
KCh209A^?`80UFm000H0TV`m095[?02AJc`0T6Xk08mY>P2>J3T208eW>00308QT=029ICD0RVHf0080
RVHf00L0R6@d08IR<P25HC40QV8b08MS<`2:ISH0SFTi0080SVXj00L0SFTi08aX>02<Ic/0RfHj08QS
=`26HCD0Q5lc00<0Pehb0`1oGR/[ooooo`00:_ooool01@2TNDH0YGY70:EjA`2VNdP0Yga90080Z7e:
00<0ZGi;0:IkAP2VNdH01P2VNdH80:UnB`80Yga500@0Yga70:MlB@2WO4T0Yg]:0P2WNd`01P2TNTX0
YG];0:EkB`2VO4`0Yge=0:QnCP80ZGm?00/0[7e?0:YkC@2WNDP0YGM50:AfA02UMd<0YgY30:QkA02Z
OdX0Z7e80:MlA`020:IkAP030:MlA`2XODP0ZWm:0080Z7a;00<0Z7e:0:QmB02XODH00P2XOT@00`2X
OT80Z7e:0:QmBP020:MlB@80YW]80P2UNTL0102YP4`0Z7m;0:MnBP2VODT20:ElB0030:AkA`2SNTH0
XWU500@0YWa:102UNdT00`2RN4H0XgU70:EkB@020:IlBP090:EkB@2TNTP0XgU70:=iA`2RN4H0XGM5
0:1fA02OMD<0WG=10080W7900P2JL3h00`2IKcd0V6hl09M]>`0209I/>P0309E[>@2;JCT0RfTi0080
RVPh01P0RFLg08QV=P27ICD0QfDe08QN=P27GCD0Pe`c085L<P20Fc40Oe`b07mN<`20Gc@0P5dc07iK
<@1lFBl0NeP^07YG;@1kF2h0O5T_07iK<@1iFC80MeL`07AD;@1bDR/2071@:@0@075A:P1bDR/0MTl`
07=?;`1aCBd0Kd`/06e<:`1/CR`0K4l]06e@;P1ZCBD0K4`U06i>9`1`CRP0LTlY07E?:P80Mdl[00h0
M54Y07EB:P1fDb/0N5D]07YG;`1kF300O5Ta07eJ<P22G3D0PUdc08=N=023GS80Q5lb08AP<080QF4_
0P2:I3D208]U=P0708aV=`2=IcP0SVPi08iX>@2>JSX0SFTi08]W=`0208YV=P0308]W=`2=JCT0SVXj
00<0SFLj0P2<IST308]U>080RF<f0P2:I3L01`2;ICP0S6Hi08aV>@2=IcX0SVPk08eW>P2;ICP00P2:
I3L02@2;ICP0SFLj08iX>`2@I3L0Sf@g091U>02?ISP0SFLh08eY>@0208]Y>@0308eW>02>J3T0T6Xk
0080TF/l0P2@JS/00`2>J3T0SFLh08eX<`0208eX=00308eW=P2=IcP0SFLj0080SFHk0P2:I3L0102;
ICP0S6Hi08aV>@2=IcX208iX>`0<08aU>P2;I3T0RF<f08QR<`29Hc80RfHb08eX=02>JC@0RF<d08YT
=@2<ISL0SVPi0P2?JCX00`2>J3T0SFLh08aX>00408aX>0<0SFTi00H0R68c08US=029Hc@0RV@e08]U
=P2<ISL208eW>0<0S6Ph0P2;IcL308YV=P80QV4d00H0Qf8e08QS=P29I3L0RVDh08]V>@2<IcX208MS
;`0408MS<@26HS80QV4d08EP<`80QF0d2023GS@208=Q<`80PV0b0P21Gc42081N<0<0OU/a0`1mFS02
07aI;`80OU/a0P1mFS0207aI;`80NeP^01H0ME<]07ID;P1fERl0MEP`07=G;`1_ERd0KE@[06YC:@1T
AbT0H4DW05a39@1E@2<0CSdQ04`l8P18?B40B3`R04@h7P14>200@cTP040h8@0n>280?CPT0P0j=b@0
200g=B00=c@Q03Ld8@0e<R40<c0Q02l[7`0/:1d0:RHK0P0W:Ah00`0V:1d09BLL02@V6`0202<U6P06
028T6@0Q91d08B@M020S700O8Q/07R4J0`0M81T00`0L7aP07R0M01hP7@0601hP7@0401lR6`0N8AX0
7R4J01hQ6P<07B0I00L071lH01PJ5`0H6QL06A/H01XL6@0L7Q/07AlL00807R0M0P0L7Q/201dO70<0
7R0M00T07b4N02LX800V:1d09RPM02HX6`0W:A/0:RdL02`_700^<Ah01@0g<1d0100i<Ql0>S<P03/d
8@0P9aL201lU5`0301lU6@0O9A/07b@M008082DO200T9Ad2020Q6`807b0J0`0N7aT00`0M7QP07R0M
01hP7@0601hP7@P07alM00H07alC02@R5P0X9QT0;BTM038/7P0e;Qh203H]700H03XW;@0o;2H0CCPS
05m98P1fFb`0S6`k09eiB@2UOe80TW]?09b3C@2VR4X0XX1008EV;`1NAR00@30P038X9P0X;bP08RTR
028W8@0X:RD09RPS028S7P0T8b40:bXX200T9R<202HY8P809bXS0`0X:b@02@0Y;2D0:BXT02PY8`0W
:2809RLQ02LX8P0X:B<0:R/U02//9P0202LX8P80:2TS0`0Y:R@202X[9@<0:RXR0`0[:b<202`/900<
034/9P0b;RD0=2dU03L^9@0k<BL0@CDY04Di:`18>Rd0Bc/Q04dm8`1??bD0DD4W0P1B@RP00`1A@BL0
D40V050n:00204hn9`0304`m9P19?BD0AcdT0080A3dS03@0A3PZ04Di:`16>R`0Ac/]04Hj;015>B/0
@cLY048f:01<@2H0BclW04Xn9P18?2H0AcXW04Dh9`14=bL0@cHV04dk<@1<>Rh0BcT[04/j:P1<>bL0
CCdT04lo9@1A@RD0GT<V0615:01SB2/0IDX]06A9;01QART0GD8U05Xo8P1E@2/0Dch[04lm:@1;>RP0
BCTY04Lj:P17>B`0Ac/]04Dc7`15=200AcHT04Hf9P14=bH0@SHV03he9P0m=2D0@RlQ04@a8`16<bD0
B3DW0P19=RP02018=BL0Ac@V03`g8`0l=b@0>cHS03Tc8`0h<R@0=S0T0P0e;R@0300e;b<0=S0T03H`
900g<BD0=S0T03@^8P0a:al0<2XN02lX800a:R80<b`T03D^9P80=RlW00<0=2dU03</900c;bH00P0c
;bH203@`9`<0=C4X00H0>blQ03``8P0l<280?C4S03hb900o<bD2040d9P0604Lf;P17=R`0AcH/04Lg
:P18>2T0B3PX0P18>BH204hm:@0>04hn9`1@@2L0DT8X05E6:@1IBRd0Fd`]0617<@1TC380K5<e07EK
=P1nHcH0QFTg08]^=P2<KcD209E`>@0709Qc?02KN480WGa709imBP2LO4T0V7Y809IhAP02095g?P06
08mf?P2=MT00RgI108Ue@029MD80QgE3202>Lch0102?KCl0SF/m08]Y>`29IcT208QV>00:08YX>P2;
JC/0SW0n08MY=`1oHBl0O5h/07iP;P21Hc40Of4_07eO;@80PFLf00<0P6He07mU=01nI3<00`1mHc80
2@27HC80R68a08US<P2;IS80S6Lb08iY<P2>JS00Sf/a08IT=00308MU=@80R6Hf0P29IcL03029IS00
RVLa08iY=02CJcL0UF`h09I[>02EJSL0UVPf09E^=`2FKcP0V74j09Yc?0@0Vg@m00<0W7P^09ei;`2O
Nc400P2PO3804`2NNS00W7P^09]g;@2XL3d0Yg8l0:Qe?P2WNCh0Ygi00:R1@02WQ400Z8E10;66@P2b
Qd<0/hQ40;:7@`2aQT80[hA00:f2?P2[P3`00P2QOSh0102OO3`0WW/k09ai>@2KN3P209Uf=P0A09A]
<P2GL3D0V7@j09Uf?P2EM3h0T74k08Y[=@25Ic<0RFDa08YV<P2<J3@0SFTe08aX=02;Ic<0RVHb08UU
<@1mGS000`1nGc40501lGBl0NEX/07IG:@1dEBL0N5Ha07ME<01eEBl0LE<]06iB:`1[DRX0JU4Y06QA
:01aDSD0KTlb06I;;@1OARL0FDDT05A48P1CAB80DTDR0`1OBC40101PBc00HD`_069=;P1SCbh206A@
;@80MEl`101dGRl207EO<080Led^00T0LU/_075J<01`FC00KeLa06iF<01^ES80Ke4_06i@;P1/CR`0
0P1[CB/01@1/CR`0KU0^06mA;`1YDb`0J58[0080Ie4Z00`0J58[06YD;@1/ERl0KUPa06YD9@1_FRd0
M5lb071M<P1VEBX0Fd`S05I88@1EAb0205938P<0Dd@S0`1DAB@0101?ART0C4<V04Po8P19@2<204a3
9P0804U08`15?1l0B3dQ04Pm8@17?R40A3dP04<n8011?Ql203ln7`P0@c`P200l>1d03P0n?1H0?c`I
040m6P10?A`0?c`M03di700j=Q/0>CDJ03Pf8@0h=Ql0>cHP03hh8010>Al0A3XO0P16>al08019=QD0
Ed<P069:901XCB80N5PY08mY>02KLSh0V6dh08a^?02CLd00Wgi90:b9D`2gT5L0_99F0;jBE@2nT580
[8U70:V7B02QPTT0TgY407mZ>`1YEbl0EDLR04Xm6`0_<Ql0;C0M02T/6`0V:1X08bDH024S600P8QL0
824I200Q8Q`201lO7@807QhL00@07AdK01`L6P0L71X06a/I0P0L71X401dM6`<07QhL2@0P8A/301lP
6P807QlI0P0M7QP201`L6P<06a/I0`0J6QP801TK61005aTH400F61Lb01LI608061XI0P0I6aX201XL
6`P071`J200L7Q/801`L6PT07AdK0P0L7AL301dN60<07QlI200Q81/202<S6@8092@J0P0U9A/202HV
7080;BLK0P0^:1`302lY7@<0<2XN00@0<B/O038/800c;B40<bdQ0P0d;R80100b:1`0<bTM03<Y7@0d
:Qh203D[7`80=R`P200g:al8040]7`0803d`7`0l;ah0>bhM03X]700k;Qd0?2lN03ha800o<R48048a
7`80AC<M0P14<Q`01@15<ad0AcDO04Xh8P1;>B<0EShV0080ECdU00<0E3`T058j8P1A>B400P1@>208
05Ln7`0605m17@1P@Qh0HD<O06537`1RA200HdDQ0P1TAR8306I89P80IdTW0`1XBRP00`1YAb@0JTPU
06e;:00206i<:@0>06a:9`1ZB2D0J4HS06U<:P1XBbT0ITTW06E89P1TAbD0IDPV06I99`1WBRP0JTTV
06Q7901UA24206917P0706E48@1XAb@0JdXW06Y=;@1WBRX0HdHV06138`0205m28P050654901SARH0
IDPX06Q:901WBB<00`1VB2800`1XBR@0JddW06e?:@0206Y>9`0406U=9P1XC2D0Id/T06M;9080ITXS
0`1UB2H206I99`<0IdXX00P0J4LV06U89`1XBRP0J4/Y06I<:@1SBbL0H4XU05m99080HdHV0P1TAbL0
401UB2P0ITTY06I9:@1VBBT0HdHT06958`1QA280H4<Q06548P1RAB<0I4LU06E89P1UAbD0IdTW06Y<
:P1]Cbd306mA;`<0KU0^00@0KDl]06a>;01/CR`0Jdd[0P1ZC2X02@1/BB/0KDX/06i;:`1_CBX0LDlZ
07=A:`1dDR`0ME@[07ED<`0207ED<@0;07AD;P1dE2d0M5@[07AE:@1cE2P0Le<Z07AD:`1gEbh0NET`
07YJ<@1kFc800P1jFS401@1lFRX0OE/[07iL;01oGBd0P5h^00<0PEl_0P23H3H00`24HCL0QF8h08IS
>@0208MT>P0308QU>`29IC<0RFDc00@0RVHd0P29IC<808QS=P80QV@f0P25HcD308AR=00308=Q<`25
HcD0Q68d0080Pf4c00@0Q68d08IT=P28ISP0RFLi0P27ICL01026I3H0QF<e08=Q<`22H382085O<@T0
Pf0f00<0PEhd081M<`1nFc400P1mFS001@1nFc40P5dc085N=023H3H0PUle00<0PEhd00<0Pf0f08AQ
=`26HcT00P26HcT02@25HSP0Q64g08=P=P23H3H0PUle085N=01jF2P0O5XZ07mM;@02089P<00307mM
;@1lFRX0NUPX00<0OU/a00<0OEX`07aI;`1kF2h00`1kF2h00`1mFS00PEhd08AQ=`0208ER>00808=P
=P22GcD0QF<c08ES<`24HS80Pf4a085O;`20GRh207mM;@0;08=L=@22Fc@0PEXc081I<P21FS<0PU/d
08AM=P25GSL0Qf@j08IS>@23H3H00`21GS@02`23H3H0Q64g07eN<P1oH3@0PF8f08=T>024ICT0PV<g
081Q=@1nGc<0Q64g0080Pf0f00<0PUle085N=020GC<00P1oG380401mEbX0OeT/085K;P24GS40QElb
08AN<@23GC00PU`_07mM;@20GRh0PEl_089P<023HC40Q68b08ES<`26I3@208ET<@80QVDb0`27IS<0
1`28Ic@0RfHi08YU>02:ICP0RF@g08QS=P27HSD00P26HC@00`28I3@0Qf<c08EQ<@0208AP<00308EQ
<@27Hc<0R6@d00P0Pf0f0P26HcT208MT>P0:08IS>@25HSP0PUle085N=01nGC80Oehc085N=024GcD0
QF0f08QQ>0<0Rf4i00T0QF0c08IQ=027HSD0R6<f08YU>02;IST0S6Lj08eX>`2=JS@00P2=JCD00`2<
J3H0S6Ph08aW>P0208aW>`80T6/n0`2AK3l3099]@003099/?@2AJc`0TF/l00<0TF/l0P2@JS/2095[
?080T6Xk102?JCX208eX>`0408aW>P2;IST0RVDh08YU>080RF@g00h0SFTi08]W=`27Hc<0QF4a08AP
<026HS80RVHf08aX>027Hc<0RFDe08aX>02>JSX0T6`l08m[>`80SVXj0P2=IcH00`2<ISD0RfDd08YT
<`0208US<P0408QR<@20GRh0P5h^081N;R_ooooo000Zooooo`80YGY70`2VNdP30:MlB@P0YW]6202Y
OT/20:MlA@040:MlA`2WO4T0Yga90:MkBP80Yg]<0`2VO4`30:MmC@80Z7i>00H0ZW]=0:UjC02XNTT0
YgU70:IhAP2VN4@20:Mj@`030:YoBP2XODP0Yga70080YW]600<0Yga70:QmB02ZOdX00P2XO4/00`2X
ODX0Z7e80:QmAP020:QnA0030:Qn@P2XODX0Z7e:0080Yga90P2VNdP20:EjA`80Z7m;00D0Ygi:0:Im
B@2UO4P0YGa80:AkA`020:=jAPD0YWa:0`2UNdT01`2RN4H0Y7Y80:EkB@2VO4X0Yge;0:IlBP2TNTP0
0`2SNDL0102RN4H0X7I409me@`2MLd4209ab@080VW0n00@0VFlm09Q^?02GKC/0Ufdk0P2FK3X01P2<
JSX0RfTi08]Y>@2:J3P0RFLg08QV=P80QfDe00<0RElg08MM=@24GC@00P21G3801P1oG380Oehc081O
=020GC<0Oe`b07eJ<0<0NeP^00H0O5T_07eJ<01iFC80MeL`07EE;P1bDR/3075A:P0?079B:`1fCbh0
Ldl]075=:`1_CBX0KD`Y06a>:P1/D2/0KE4/06Y=9@1]CBH0KThW071>:01bCbT0MDlZ0080Mdl[00h0
M54Y07EB:P1fDb/0N5D]07UF;P1kF300O5Ta07eJ<P21Fc@0PE`b089M<`23GS80Q5lb08EQ<@80QV8`
00H0RF<d08YT=@2:I3D0RfDf08aV=`2=IcP208iX>@0308iZ>P2=JCT0RfLg0080RVHf00<0RfLg08eY
>@2>JSX00`2=IcX208aV>@<0RfDh00<0RF<f08YT=`2:I3L00P2;ICP208aV>@0408eW>P2>J3/0SFLj
08]U>080RV@g00@0RfDh08eW>P2>J3/0TVHi0P2@ICP00`2?ISP0SFLh08aX>00208YX>00308aV=`2=
IcP0SfTj0080T6Xk0P2?JCX00`2=IcP0S6Hg08eX<`0208eX=00308eW=P2=IcP0SFLj0080SFHk0`2;
ICP308aV>@80SFLj0P2;I3T03029HcH0RF<d08US<P2;IS80SFPd08iY=02:I3D0S6Hg08iX>@2?JCX0
T6Xk08mY>P80SVPi1P2<J3P208eY>@<0RV@e0`2;ICH208aV=`<0S6Ph0P2;IcL308YV=P0408MR=@28
HcH0R6<f08QS=P80RF@g0P2:ICP208MS;`0608MS<@26HS80QV4d08IQ=@25H3@0QF0f2024GcD208=Q
<`80PV0b0P21Gc42081N<0<0Oe`b0`1nFc4207eJ<080OU/a0P1mFS0207aI;`80NeP^01H0ME<]07ID
;P1fERl0MEP`07=G;`1_ERd0KE@[06YC:@1UB2X0HDHX05a39@1E@2<0CchR04`l8P18?B40B3`R04Di
7`14>200@cTP040h8@0n>280?CPT0P0j=b@0200f=1l0=S<P03Hc800e<R40<RlP02hZ7P0[9a`0:BDJ
0P0W:Ah0100V:1d09BLL02@V6`0T9Q/202<U6P06028U7P0Q91d08B@M020S700O8Q/07R4J0`0M81T8
01hP7@@07B0I100N8AX301XL6@806adJ0P0L7Q/00`0M7a`071hK01`N6`0201dO70@07R0M0P0V9al0
2@0U9a`09BLJ02LY6`0Y;1/0;2lN02d`7@0h<Al0=c0N03H_7@0203D^700;03L`7P0j<b40?3DS028Y
6@0Q9aT07bDG01dS5`0M8aT07R<L020U7`0R9b40200T9Ad2020Q6`807b0J100N7aT801hP7@P07alM
02007alE028R5P0W9AT0;2PL034[7@0d;Ad0=BhL03H]700g9bX0?B`U04Le8@1J@b40L5DX08EV=`2G
MDL0XGa@099kC`2LPTl0YXQ<0:>4A02>KcP0Je8Z04Tg8`0f:B40:2dV028W800S9Ql0:2XU02PY900S
8b409B@R02/Z:0P092HS0P0V:B8202LZ8`@0:2/T00P0:BXT02PY8`0W:2809RLQ02LX8P0X:B<0:R/U
02//9P809bPR0P0X:B<502TZ90<0:RXR0`0[:b<202`/900<030]9P0a;B@0<RhU03H_9@0j<RL0?cDY
04@h:P17>bd0Bc/Q04`l8P1>?R@0D40V0P1A@BL205109P0S04lm9`1>?RL0CCdV04/l9@18?2@0AS`S
04@m8`13?280?c<U040d9P13=bT0ACT[04Hj;017>bd0ASX/04Di:`1:?R@0BShV04Tm9@18?2H0AcXW
04Hi:016>BT0ACPX04dk;`1<>Rh0BcT[04/j:01;>RH0CCdT04lo9@1@@2H0G44T05i39P1QART00P1S
B2/0201QART0GT<V05a1901F@B`0ED0[050n:P1=?2X0BSXZ0P18>b/02`18?2h0AS@P04He8@17=R@0
AcLW04Dh9`12=RH0?cHW03he9P16=2H0AcDW0080B3HX00h0AcDW04Dc9@13<B<0@S0R03df8`0m=R@0
?3DS03Xc8`0i<B@0>30U03L^9@0f;B@0=S0T03La9@80>38V00`0=c4U03D_8`0c;B40<B/O030Y8@0a
:R80<b`T03D^9P0f;bL0=BhV03@]9@0c;2@303<_9P<0=30W0P0e<BP203T`8@0<03Xa8P0k<R<0?3<T
03`c900m=2D0?SDV04Dd;015=2X0ASD[04Hf:@16=RL0AcLW0P17>2D204hm:@0>04hn9`1??bH0DD4W
05A5:01GB2/0FDX[069:<P1UCC<0K5<d07=I=01kH3D0P6@b08EW<@26JC42091/<00309=_<`2GM3X0
VgPn0080W7a300X0VGY309Qi@P2FNCl0UWTo09=i@02AN400SWM108eh@`2;Md80RgM40P2CMD42099d
@008095c?`2@LSh0T78n091b?P2AKcl0Sfdm08e[>`2:J3P308UW=`0308YX>02:K3X0QfTg0080Q6Hd
00@0QfTg08IX=P22I380OEl]0P21IcH00`20ISD0OfDd07iT<`0207eS<P0907aR<@25Gc00QV0a08MQ
<029I300RfHa08eX<@2>JC80SVX`0080QV@d0P27ICD308QV=P0508UW=`28I300RFDa08eX=02AJCH0
0P2CJCL00`2CIcH0TVHe091Y<P02095Z<`08099[=02CK3D0U6df09E^=`2FKcP0VG<b09Yd<`2KMC@2
09af=@0;09]e=02ILc80V78a0:=^>P2SL3/0Y7<k0:Af>`2TNcd0YGhm0:J0?`2UPSh00P2^PT420:n3
@P040:j2@@2/P3l0ZGdl0:Ql>`80WGTk0100W7Pj09Yf>02HM3H0Ug<e09Ib=02ELC<0Tf`c099^=02D
KcP0U74k091_>@2<KCL0R6Xf08IX=027IS40R6Lb0`29J3<06@27IS40QF@_08AS;P1gF2`0N5T]07YK
;`1kG300NU/_07UJ;P1hFBd0MUL[07ID;`1dE2h0Le<]071B;01]DBX0JU4Y06QA:01WD2L0KDha06Y=
;`1VBbd0I4//05m;:P1NBbX00P1KCBX02@1PBc00HD`a065<<@1QC2l0HTd^06=?;P1TD2d0IE4^06EA
;00207EO<0@0M5h_0P1eGc002`1dGRl0Led^079K;`1aFS00KeP_06iF<01]EBl0K5@`06iA;`1]D2h0
Jdh/0080JTd[00D0Jdh/06e@;P1^DBl0JE</06QB:`0206MA:P0:06QB:`1ZE2d0K5H_06iH<@1/EBT0
KeX]079M<P1/FBh0He8W05Y;8P80EdTR201CA2<0201?ART0Bd8U04Po8P19@2<0Bd8U04a39P19@2<0
AC`O0P19?R801017?R40AChQ04@o8@12?b02040o80P0@c`P200l>1d0;P0m>QL0?S/H03ll6`0o?1d0
?SXM03`h7@0j=Q/0>3@K03Le800h=Ql0>cHP03dg7`10>Al0@cTN04Dj7P16>al0BCTG05I4801QBb@0
JDdU07QG:P2<ISD0Ufhj09I[=P29JCH0T70m09akAP2ZQDh0/X]B0;J<D02fRTd0]8Q;0:B2@`2OOd80
UWU108Q^?@1dGc80GTlX04e07P12=aL0;S4N02`_7P0X:aX09BLI028T5`0P8QL2020Q6@P08B8L00<0
7alM01hN700N7Q`00P0M7A/201`L6P0301/K6@0L71X071`J008071`J0P0M7A/301hN70P0824K100O
81X201hO6@807AhH0P0L71X301/K6@<06QXH200I6aP@01LI61005QPG<P0G6AP201PJ6@806A/J0P0J
71/801`L6PP071hK200L71X901dM6`8071dG0`0M7QP301hO6@P08B0K0P0S8aT202@T6P809BDK0P0V
9Q`202dW6`80;RPL100_:Ad3034[7`<0<R`P0P0c;B400`0b:1`0<bTM03<Y7@0203@Z7P80=B/O00<0
=R`P03L[7`0g:al01P0g:al803l]7`0303d`7`0l;ah0>bhM0080>RdL00<0?2lN03ha800o<R402012
<Al204Dc7@80A38L00@0AC<M04Le7`19=b40BcTS0P1D?2@205<k8`80DSXR0P1A>B4805Po8080Gd4M
00<0H48N06537`1RA2000P1SAB400`1TAR80IDLU06I89P0206I89P80IdTW0P1XBRP206U7900306]9
9P1/BRL0K4XW0080JdTV00@0JTPU06Q;:`1VBBT0IDPX0`1SARH01@1TAbL0IDPX06Y99P1XAb@0ID@Q
0080HT4N00L0I4<P06M68`1YB2D0J4/[06I9:@1RABD0H4<S0080Gd8R00D0HD@T06A79`1VBBT0IdTS
06I88P0206E78@0406M98`1YBbD0JddW06e?:@@0JDdV0`1XC2D00`1WBb@0ITTW06I99`0306I99`<0
IDPV00P0IdHU06Q79P1WBBL0IdXX06E;:01SBbL0HD/V061:9@P0I4LW0P1RABD306138`0706959@1T
AbL0IDPX06E79@1WBBL0JD/Y06a>;00306i@;P<0KDl]0P1/CR`0101[CB/0JT`Z06Y<:P1ZC2X206a9
:`0706i;:`1_CBX0LDlZ079@:P1cDB/0M5<Z07AC<P0207AC<00307AD;P1dE2d0Le<Z0080Le@X00H0
LU8Y07AD:`1fERd0NET`07YJ<@1kFc8207YJ<@0607aJ:P1mFb/0OE/[07iL;01oGBd0P5h^0P21Gbl2
08=P=P0408AQ=`25HSP0QV<i08IS>@80Qf@j2029IC<808QS=P0408MU=`26I3H0QV@f08IT=P80QF<e
0P24HS@00`25HcD0Q68d08=Q<`0208=Q<`0308ES=@27ICL0R6Hh0080QV@f00@0QF<e08AR=023HC<0
PV0b0P21Gc49089O=@03081M<`1oG380OU/a0080OEX`00`0OU/a07mL<P20GC<0Pf0f089O=@21GS@0
P5dc085N=022GcD0Q64g08ER>026HcT208ER>00308AQ=`23H3H0PUle0080PEhd00<0NUPX07aJ:P1o
GBd00P21Gbl00`1oGBd0O5XZ07YH:00207iK<@80OEX`0P1lFBl207]H;P0307eJ<01nFc40P5dc0080
PUle00<0Pf0f089O=@22GcD00P23HC401022H300PEl_081N;P1oGBd207iL;00;089K=021FS<0P5Tb
07mH<@20FC80PEXc08=L=@24GCH0Q64g08=P=P22GcD00P20GC<01P21GS@0PUle08=P=P1nGc<0Of0d
081Q=@<0PF8f00L0P64e07mP=023H3H0Pf0f089O=@21GS@0P5dc0080Oe`b00@0OU/a07iG;020FBh0
PEX_0P23G3400`22Fc00PEX_081I;P0207mM;@06081N;P21Gbl0PV0`08=Q<@24HS80QF<c0P24Hc02
08ET<@<0QVDb00<0QfHc08UT=`29I3L00`28HcH308MR=@0308MS<`26HS80QF4a0080Pel_00<0QF4a
08IR<P27Hc<02022GcD208AQ=`<0QV<i00<0QF8h08=P=P22GcD00P1oGS<01021GS@0Pehd08AO=@26
GcH308UO=`0608AO<P25H3<0QV4d08MR=@29I3L0RVDh0P2;IST01P2<JC<0S6Pd08aX=02<J3H0S6Ph
08aW>P80S6Lk102>JC`408eX>`<0TF/l1@2@JS/2095[?080T6Xk0`2?JCX01P2>J3T0SFPk08eX>`2<
IcX0RfHi08YU>080RF@g00d0R6<f08aX>02:ISH0Qf<c08EQ<@24H300QV8b08UU=@2<J3P0Qf<c08UU
=@2;IcL0SFTi0080SVXj0P2=JCT01P2:I3<0RF<b08US<P28HS40Qf4`08IP;`80QEl^0`20GRh[oooo
o`00:_ooool20:MlB@<0YW]80`2UNTL80:IkAPP0Z7e:0P2WO4D0102WO4L0Yga90:MlB@2WNdX20:Mk
C080Z7i<0`2WOD/30:IlBP80YWY;00@0Yg]:0:MlB@2WO4T0YW]60P2TND800`2ZOdX0Z7e80:MlA`02
0:IkAP030:MlA`2XODP0ZWm:0080Z7a;00<0Z7e:0:QmB02XODH00P2XOT@00`2XOT80Z7e:0:QmBP02
0:MlB@80YW]80P2UNTL0102XOd/0Ygi:0:MnBP2VODT20:ElB080Y7]700<0XgY60:IlBP2VO4X01P2V
O4X00`2TNTP0YG]90:IlBP020:MmB`030:IlBP2UNdT0XgU70080XgU700L0XWQ60:5gA@2OMD<0WWA2
09ec@@2LLT00Vg4o0080VW0n00<0VFlm09Q^?02GKC/00P2FK3X208iZ>P0308eY>@2<J3P0RfLg0080
RVHf00`0RFDe08UO=`28GSH0Q5dd089M<`21G380P5dc081O=021H3D0P5dc07mL<P1mFS0307aI;`80
OEX`00@0NETb07QH<@1fERl0M5@]101bDR/01P1gD2l0M50^079>;01_CBX0KTdZ06a>:P80KE4/00P0
JdhV06i>9`1^CRL0KddW075>:01dCRT0MThZ07M?:`80ME8Z00h0MU<[07MD;01iERh0NUL_07]H<01l
FC40OUPa07mJ<020Fc40PUda08AO<P26HS80Qf<a08QT<P80RF<d00<0RV@e08]U=P2<ISL00P2=IcP0
102>J3T0SVXj08eY>@2<J3P208]W=`0308aX>02=JCT0SVXj00<0SFLj0P2<IST308]U>080RV@g0P2;
ICP408aV>@80SFLj102;ICP208eW>P0609=W>P2BIcX0TFHi091W>@2=IcP0RfLg0P28ISH00`2;ICH0
S6Hg08eW>00208iX>@80SFLh00<0S6Hg08]U=P2=J3<00P2=J3@00`2=IcH0SFLh08eW>P0208eV>`@0
S6Hi0`2;ICP0302:I3L0Rf@i08YS>02:I3L0RF<d08YT<`2;IS80S6Lc08eX<`2<ISL0SVPi08mY>P<0
TF/l0P2?JCX808aX>080S6Hg0`2;ICH308YT=@<0S6Ph0P2;IcL308YV=P<0RVDh0P29I3L308QS=P80
R6@b00<0Qf<c08MR=@26HCD00P26HCL00`25GcP0QV4g08IQ=`0608IQ=`80Pf4c0P22H382085O<@80
P5h`0P21GS@3081M<`<0Oe`b0P1nFc4207eJ<080O5T_0P1kF2h207ME;`0D07IF;`1dEbl0LUH^06iE
;01]E2/0JU<Y06M:;01RAbT0GTDW05I1901@?b<0CCdS04Tn8P19?B<0ASXP04Di8@14>R40@CTR03li
8`0m>2@203Xg900903Dc7P0e<Ql0=C8O03@a800a;Ql0;RXN02/W700Y9AX0:2XO00809bTN00<09RPM
02DW700T9Q/00P0S9AX2028U7P03024T7@0P8a`07b8K00<07R4J00<07B0I01hP7@0N81d01P0N81d0
1@0K7QL071lH01`O600M81T07R4J00807b8K00<082<L01dO700L7Q/00P0L7Q/301/M6P0401XL6@0L
7Q/071hK01`N6`807AlL0`0N81d02`0U9R0092DO02@U7@0T9Q/09RPK02PZ700[;Qd0;2lN03Td8@0f
<Ah0<bhK0080<B`I00/0=2lL03Pc800k=R<0:BdN02HZ700Q9AL07R4F01dP5`0P8a`08bDP02HX8`08
02@U7@<0824K0P0O81X301hO6@P07R0M200O7ad0800N7aL08B4G02@T6P0Z:1`0;RXN034[7@0c;1`0
=2dM038W9@0g:240@C0N04hk7@1RBR@0NE`b08i]@P2JMdd0Tg]?09^1D02TQdd0YXQ:09YmA@1mI3/0
FT@/040]7`0[;B8092HK02<T700Y:R@0:R/V02DU8`0T9280:BTY200T9R<302HY8P809bXS0`0X:b@0
0`0Y:R@0:2TS02LX8P0202HW8@0302PY8`0Z:bD0:b`V00<09bPR0P0X:B<402TZ90<0:RXR0`0[:b<2
02`/900=030]9P0`;B@0<BdT03D^900i<BH0?C<W044h:@15>B/0BSXQ04`l8`1>?RD0D40W0551:002
05109`0>04lo9P1>?2H0CCdV04`l9@1:>b@0Ac/S04Dk8P13?280@S/Q03/_7`0m<B40@3@T04@h:016
>RX304Pl;00604Pl8P18?2@0B3`T04Pl9P18>bP0B3/Z0P18>b/0801=>bd0C3X/04/j:P1:>BL0BcXV
04`l9@1>?RD0CclV05Pn8`1J@2D0GT@Y0616:`1QAb`0H4H[05i4:@1M@bP0F4@/05I1;01B@2X0CSdY
04`m:P1:?B`0BSd]04Xn;P18=R80B3LS04Th9P18>2P0ASTX04<g9`0o=RL0?SDV0`1:>2X03P18=RP0
AS@V04@b9011;b40@2hP03lg900n=B@0?C@S03`c900j<2@0>BlU03P^9@0g;B@0>38V0P0i<bL0200j
=2P0>C<W03La9@0e;b<0<bdQ034Z8P0b:b<0<b`T0`0e;RH0100d;BD0<b`T038^9@0b;RD203<_9P<0
=30W00D0=C4X03P^8P0h;R80>BlS03X`900203/a9@80?38V00H0@C<Z044c:011<bP0@S@W048e9@13
=RD204<f8`80CSdY00h0CShW04hn9@1@@2H0DT<V05E6:@1FAbP0HTX`06E=<@1ZDS00LELb07ML<@1k
Gbl0OV0/07mQ:`80RFLW00@0S6XZ099`<02GMCD0W7Xj0`2NO3`209an@P0609Ym@`2GOD@0U7]2095k
@P2@ND<0SgY30P2GND<02`2FN480U7I009=e?`2BM3h0TG<m091b?02DLT80Tg51091^?P2=Jc/0RfTi
0080RFLg00T0R6Hf08EW=@26J3H0R6Xh08]]>`2=Kcd0Rfdk08AV=01oHBl00`22ISH03P21ICD0P6@d
07mS<`1nHS80OF4a089M<022GRh0Pel_08EQ;`27Hbl0RVLa08aY<@2=JS80QF<c0`26I3@208MU=@80
R6Hf01<0Q6<^08ET;`29IC40S6Lc08mW=02@IS@0SfDc091T<`2:IC00RF@_08MR;@26HB`0Qf8]08YU
<02=J3<0SfXe095/=@2BKCH0Tfhg0080U6lh00d0Tfhg099]=P2AK3D0W6Xi09]/>02MKSX0WW4j09id
>P2OMcX0X7Xk0:5k?02UO3h0YWdo0080Ygi000X0YWdo0:Ak?@2RNC/0XGPj09Id=`2ELcH0U78e09=a
=02AKc80T6ha0P2?KC0208eX<@0608aY<`29J3<0R6Pe08IX=P25IcD0PfLg0P26I3@02P27ICD0QV@d
08ES<`23HC40P5h^07mM;@1_DRP0L5<Y079E:`1dEbd407EH;P0607=B;`1bDBh0Ke4]06eA;01YCbX0
IdlY0P1UCbP01@1TBRT0ID/Z06I>;01WD2h0IU8_0080IE<_00<0He<_06A<<01UCRl00P1UCRl00`1V
Cbl0Ie0^06QB;@0206UC;080M5h_101eGc0207AN;`0;07EO<01dGRl0LU/_071I;`1^Ebh0K5@^06YB
;01YDBd0KE0^06a?;@1[CR`00P1ZCB/00`1[CR`0K4l]06e@;P0206QB:`80Ie4Z00`0J58[06YD;@1/
ERl0KEL`06mH;01^FBh0KEP]06IC:@1OCBD0FDXS05M9901HBRD205E69@0305A5901CA2<0DT<R00<0
DD8Q00@0CdHY04]29@18?b80B3lR0P1;@RD02018?b80AC`O04Xo8`1:?b<0BD0S04Ho8P15@280@d0Q
0P11@24804<l80P0?3PM02h0?CXG03dj6@0n>aX0?S/L03di700k=a`0>CDL03Pd6`0g=B00=cDN03Xe
7`0m=al0?cPN048h7@14>Ad0ACXN04`l6`1F@b80H4XU06M>9@1eERP0Qf<c091X=@2AJ3@0QVD`08e/
=`2KN480YX5:0:f6C@2]QDX0ZGm30:Ek?`2HN3l0TW<l08IZ>01eGc00HU0X05118011=QP0>34E02/^
7@0Y;1/09RPJ02<U600Q8aP0824I2P0P8A/201hN70807AdK100L71X00`0K6aT071`J01`L6P0201`L
6P807AdK0P0N7Q`;01lP6P807QlI0`0M7QP201`L6P<06a/I0`0J6QP801TK61005aTH400F61Lb01LI
608061XI0P0I6aX201XL6`P06a/I200L7Q/801`L6PT07AdK0P0L7AL301dN60<07QlI200Q81/202<S
6@8092@J0P0U9A/202HV70<0;BLK0P0^:1`302lY7@<0<R`P0`0a:al2030Z7P@0<bTM0P0d:Qh203D[
7`P0=b/O200n;1h00`0l;ah0>bhM03X]700203X]700303`_7P0m<1l0?c8Q00P0@C0N0P15<ad204@b
700404Dc7@16=1h0BCLQ04Xh8P<0DCTQ0`1B>R8205<k8`P0FD0R0P1N@1h00`1O@Al0H48P06538@02
06948P0406=58`1UAbD0IDLU06E79@80ITPV0`1WBBL02`1XAbH0IdHU06M69@1WARD0J4LV06U89`1[
BRT0K4/Z06E8:01TAbL0HTDU00<0H4<S00d0HD@T06959@1XBRP0ITPV06=58`1P@R00Gd4O0612801R
A280I4HT06E8:01SARH0HD@T00<0H4<S00<0HTDU06E8:01WBRX00P1TAR801P1UAb<0ITPT06M99@1Z
C2P0K4hZ06e?:`<0J4`W0`1YCBP206Y>:@80IdXX00@0ITTW06E89P1TAbD0I4LU0P1SAR@0201T@b80
ID@S06E79@1VBBL0ID/X06A<:01RC2L0HD/V0P1UB2P206A79`0A06=69P1RABD0HD@T0654901RABD0
HD@T06138`1O@R80H4<S0654901SARH0I4LW06A6901VB2H0J4XX06Y<:P1[CB/00P1/CR`506]=:`80
JT`Z0P1YBbT206]::`0706a;:P1]C2T0KdlY071@:@1aDBX0LU8Y079A<002079A;P0307=C;@1cDb`0
Le<Z0080Le@X00@0LU8Y07AD:`1fERd0NET`0`1jFS400`1iFC00OE/]07eK;@0207eK;@0507iL;P20
GS00PEla085O<@22GcD00P23H3H00`24HCL0QF8h08IS>@0208MT>P0308UU=@28I3@0R6@d00@0R6@d
00<0RFDe08QS=P28HcH01P28HcH308MU=`80QV@f1025HcD01`24HS@0Pf4c089P<P23HC<0Q68d08IT
=P27ICL00P25HcD01024HS@0Pf4c089P<P22H382085O<@X0P5dc00T0Oe`b07eJ<01lFBl0O5T_07eJ
<01oG380P5dc089O=@21GS@00`20GC<01022GcD0Pf0f08ER>025HSP208AQ=`0308=P=P22GcD0PEhd
0080P5dc00<0NUPZ07]I:`1nG2h00P20GS00101nG2h0NeT[07YH:P1nFc4307eJ<0<0O5T_00<0NeP^
085N=020GC<0101oG382085N=006085O<@20GS00P5h`07mM;`1nG2h0OE/]0P1lFR`207iH<@<0O5H_
00D0OUPa081J<`21Fc@0PEhd081M<`0307mL<P03081M<`21GS@0PUle0080P64e00H0Of0d07iO<`1n
Gc<0OUlc07mP=020HCD2089O=@03085N=020GC<0Oe`b0080OU/a00<0OEX`07iI;`1oFS000`20Fc40
0`1oFS00OEP^07eH;P0207iL;P80Oed_00D0P5h`085O<@22H380PV0b089P<00308=Q<@80Q68b0P25
Hc<308IQ=0<0Qf8e0P28HcH00`26HC@0QF0c08AO<P0208=N<@0308AO<P25H3<0QV4d00P0PEhd00<0
P5dc085N=023H3H00P25HSP00`24HCL0Pf0f089O=@0207mN<`04081M<`22GC<0Pehd08AM=0<0QU`d
00T0PUd`08=N<@24Gc80QF0c08MR=@28HcH0RF@g08YU>02<JC<00P2<J3@00`2<J3H0S6Ph08aW>P02
08aW>`80S6Lj00@0RfHi08YU>02:ICP0RF@g0P28HcH808mY>P<0T6Xk0P2?JCX308iX>@80S6Lj00<0
RfHi08YU>029I3L00P28HcH01027HSD0RfLg08UU=@27Hc<208EQ<@0708MS<`29ICD0RfLg08MS<`28
I3@0RFDe08]W=`0308aX>00408]W=`25HC40QF4a08AP<080Pel_00<0PUh^085M;@21GBd00`21Gc4[
ooooo`00:_ooool01@2XODX0Yga90:MlB@2VNdP0YGY70080Y7U600<0XgQ50:IkAP2VNdH01P2VNdH8
0:MlB@80Yga500@0Yga70:MlB@2WO4T0Yg]:0P2WNd`20:V0C0030:QoB`2WOTX0YWe90080YGa800@0
Y7]70:=iB@2TNTX0Yge;0P2XOd/01P2VODL0Y7]30:9i@@2ZOdX0Z7e80:MlA`80YW]600<0Yga70:Qm
B02ZOdX00P2XO4/00`2XODX0Z7e80:QmAP020:QnA0030:Qn@P2XODX0Z7e:0080Yga90P2VNdP20:Ej
A`80Ygi:0P2VODT30:ElB080Y7]7102VO4X40:MmB`030:EkB@2VO4X0Yge;0080Z7i<00T0Yge;0:Ek
B@2TNTP0Y7Y80:=iA`2RN4H0XGM50:1fA02NM4800P2MLd4209]a?`0309Y`?P2IKcd0V6hl0080Ufdk
00@0UV`j08mY>P2?JCX0SVPi0P2=IcP02`2<ISL0RfDf08]U=P2:H3P0RElg08EN=@23GS@0PUdc085N
=021H3D0PV4f0080Oe`b00<0OU/a07eJ<01mFS000`1mFS001P1iFC80N5Pa07MG<01eEBh0M5@]07=C
;080LU8[00T0Me4]07A@;01bCRX0L4hY06i>:01]CbT0KE4Z06iB:`1]D2P00P1^CRL01@1_CBL0L4dW
07A>:@1fCRX0Mdl[0080ME8Z00h0MU<[07MD;01hEBd0NEH^07YG;`1kF300OEL`07iI;`1oFS00PE``
08AO<P26HS80Qf<a08QT<P80RF<d00@0RV@e08]U=P2;ICH0S6Hg0P2=IcP00`2=JCT0S6Ph08aX>004
08aX>00408eY>@2=IcX0SFLj08eW>P80S6Hi1@2;ICP>08aV>@0609EY?02CJ3/0TVLj091W>@2=IcP0
RVHf0P27ICD208]U=PD0S6Hg0P2;ICH01P2<Ic80S6Lc08aW<`2<ISD0S6Hg08aV>@80S6Dj0P2=IcX0
102<IST0RfDh08]U>02:I3L208US=P80RV<h00T0RV@g08YT=@2;IC@0RfHb08aW<`2<Ic80SVPi08mY
>P2AJc`00P2BK3d00`2AJc`0T6Xk08mY>P0308eY>@@0S6Ph00H0RfLg08eW>02=IcP0S6Hg08]U=P2:
I3D208US=00408QR<`2<J3P0S6Ph08aX>080RfLg0`2:ISH0202=J3/0S6Lj08]V>@2:ICP0RF@g08QS
=P27HSD0QV4d0P28I3@01028HcH0Qf8f08MR>026HCL208IP>@P0R6<i0P23HC<2089P<P80PEla0P20
GS02089O=@<0PEhd0`20GC<207iK<@80OEX`0P1lFBl207]H;P80N5H`01L0MUH_07=F;P1aEBd0KUD/
06aC:P1[E2X0JD`^06A9:`1OARP0F4<V0550901>?R@0BSlS04Tm8`17>b40ASXR04@j8@11>B80?cTS
03dh900j=b@0>CHS03@b7@0203@a7P0503<`7`0a;Ql0;RXN02/W700Y9AX00P0X:Ql00`0W:Ah09RPM
02DW700202@V6`0602<U6P0S9Ql08bHO028U7P0Q91d082<L0`0O8Q/00`0N8AX07R0M01hP7@0601hP
7@0801XM5P0K7QL071lH01dP6@0N8AX07b8K020S700Q91d201lQ7P0401hP7@0M7a`06adJ01XL6@80
6A/H0P0K7AX201`N6`807AlL0P0N81d02`0T9B008b@N02<T7P0S91`092HK02LY700Y:ad0:bdO03Ld
8`0d<B00<2dL0080;BXI00/0<2dL03Db8@0h=B@0;S0R02T[7P0S9AP07R0E01dN5P0P8A/09BHQ02PY
900802@U7@808B8L0P0P8A/201lP6P807QlI200N81d801lO7@0601hQ600P8AT08R@I02HV700Z:1`0
;BTM0P0a:ad0600^9B00<RPN03T/6`14<QX0DchO06U?:P20Hc/0T717099fCP2IODh0X8E>0:J9C`2R
Qe00TWM:071F=@1B>1l0<S0Q02XX6`0V91P0:RXR02`[9P0V9R@09BDU02LY:0P09BLT0P0U:24202HY
8P809bXS0P0X:b@0200X:B<09bPR02HW8@0U9R009RLQ02LX8P0Y:R@0:b`V0P0V9b4202LX8P80:2TS
0`0Y:R@302XZ8P<0:b/S0P0/;2@0300];BD0;BdS02l/8`0b;R<0=S0T03/c9P0n=bL0@CPY04Ti8P1;
>b@0CCdV04lo:080D40Y00h0CclX04hn9`1>?2H0CCdV04`l9@1:>b@0Ac/S04Dk8P13?280@S/Q03`a
7`0n<b40@CHT04@i9`@0AS/Y00H0Ac/Q04Lk8`17>b<0B3`V04Tl:@1:?B`204Xm;@0Q04dl;01<>bT0
BcXX04Xi9`1:>BD0BcXV04dl:01>?BT0ECdS05Lo9@1J@RP0GDD[05i6;01OAbd0GTH/05e5:`1JARd0
F4@/05=1:@1@@2T0CSlZ04/n:`1<?bh0Bd0^04Xh901:>BD0BSTW04Xj:P17>RT0A3PX040g:00o=RL0
BCTZ0080B3PY00<0AcLX04De9P14=2D00P12<R<01P0o=b@0?cHU03he900l<b@0>c4U03T_9@80>2hU
00P0>C<W03Xd:00k=BT0>cDY03Xd:00h<RH0=S0T03D_8`<0<b`T100d;BD0100c;2@0<RhU038^9@0b
;RD203<_9P<0=30W00H0=BdR03H^8`0f;R<0=blT03P`9@0i<BH203Xb9`0603d`9`0m<BD0?S8V03lc
9@0o<b<0@3DS0P11=R8204hm:@0>04dm9P1=?B@0CclU05529@1DABP0EDHW05m8:@1RBb/0J50^06iE
;@1dFBh0N5`]07aN;01mGb/208AU900708YY9P2?KR/0Ug@`09ai=@2ROCL0Y7li0:F0>P020::0@@06
09mo@P2MOd<0Vgi409QnA@2GOD@0UGa40P2LODH05P2JNd@0VGY309Mh@@2EMSl0U7Dn09=d?@2HMd@0
UWE209Ac@02@Kc`0SF`i08]Z=`29J3D0R6Ld08AV=025IcD0QfTg08U[>@2:K3X0RF/i08MY=`24IS@2
08EV=`80QVLh00D0QFHg08=T=@21HS<0P64b07mM<00207mM;`05081N;P22HBh0QF@_08QW<@29J380
1025Hc<208IT=080QfDe00H0PV8_08=S<025I340R6@b08US<P2<I3<208eS<`0808UU<@26HRh0Pel[
081L:021GBT0QF4]08UU<@2<J3@208]V>@H0S6Lj00H0TVHe09=W=P2DJCH0UF`h09M^>02IL3P209Yc
>080WGDh00L0WWHi09mg>P2NMST0WGDh09]c=P2ILC@0SFdd0080S6`c00d0Rf/b08YZ<@28J2l0R6P_
08MW;P29IC40Qf<_08=R;`20H2l0Of0a07iR<`20I3D0P6Dh00@0PV4d00@0P5lb07eL;`1jFB`0N5LZ
0P1]DBX00`1^DR/0Ke</06mC;00306mC;00@06mA;`1^D2h0K4l]06U?;01WCb/0IDlZ06A>:@1RCRT0
H4PT069:9P1UCbX0J58]06YD;`1WDbh0IU8]06EA;0<0J4l`00<0JE4_06YB;P1[Dbd00P1/EB`0101]
ER`0Led^07AN;`1eGc0207IP<@0<07EO<01dGRl0Led^07EO<01dGRl0LU/_06mH;P1/EB`0JU8/06Q@
:P1WCb/0JU0]1P1YCb`00`1ZD2d0J58[06MA:P0206I@:@0B06MA:P1YDb`0JeD^06eG<01`FBl0KEP]
06MA:01PCBD0FTPR05M78`1GBBH0FD/X05I79P1EARD0E4DT05=48`1B@b80D44P0P1?@1l0101>ABP0
Bd8U04Po8P18?b8204]29@0:04Po8P14>ah0Bd0T04]09019@2<0Ad0S04E08P14@B80@T4R04508@P0
@S/O200l>1d01P0l>AP0?3TJ03`i6P0k=aX0>SHK03Te7080>3<M00H0=S@O03Hd7@0i=1h0?3HN03hg
7@12>1d204@i7@0M04ho801DA2<0GDTV06M>9P1bEBT0Oed_08QR<@2;Hbl0R6D_091[=02JMCh0Xgi7
0:R1B02TOD@0WGHm09Qa>02<KSX0Q6Ph07EM;`1SD2P0DT8Q04<h700h<1T0<b`I02PZ700V:1X092HI
024S600O81P00P0O81X00`0O81/07b0J01lP6P0601lP6P807AdK1P0L71X201/K6@@071`J0`0M7A/:
01lP6P807QlI0P0M7QP201`M5`8071`J0`0K6aT301XJ60P06A/H400G6AP@01HH5c805aTH0P0H6QT2
01TK6P806Q`K200K6aT801/M6PP071`J2@0M7A/201`M5`<07AhH0`0N7aT8024P6`808b<I0P0T91X2
02DU6`809RHL0P0/9QX202dW6`80;RPL0P0_:Ad2038/8080<B/O00@0<2XN02lY7@0^:1`0;RPL1P0c
:Ad203@Z7PP0=b/O200l;1d0200l;ah0>bhM03X]700i;1/0>RdL03/^7@0m<1l0?S4P2011<1h02016
=1h0AC<M04@b7013<A/0A38L04Hd7P18=R00BCLQ0P1>=Qh0101?=al0D3PP058j8P1C>b<205@l90P0
FClT0P1M?Ql205ho800405m08@1P@B80HD8S06528`<0I4HT0P1UAbD306I89P0;06I7:01TABH0HT<T
0693901SA2D0IDHW06U::`1[C2d0HTDW06549P1O@R@00`1M@28205m2900406E8:01TAbL0HD@T05m2
8P80GT4Q00@0Gd8R06138`1RABD0HTDU0P1P@b<20654900306=69P1UB2P0IdXZ0080HdDS00L0I4HT
06I89P1XBRP0JT`Z06a>;01]Cbd0ITTW0080IdXX00D0J4/Y06U<:P1ZCB/0JTd[06]>;00206M::004
06I99`1UB2H0HdHT06958`80HD@R00H0HT4P06=28@1TAR@0IDPV06A:9`1TC2P2069<9`0@06I9:@1U
B2P0I4LW06=69P1QA2@0Gd8R05i18@1M@200HD@V06139@1O@R@0GT4S05m2901P@bD0HTDW06=6:080
I4HT00<0ITPV06M99`1XBRP02`1YBbT02@1XBBX0JDX[06Y<:P1[CBT0K4hX06e@:01^DBT0KU4W071?
;P02075@;@03075A:`1aDBX0LU8Y0080LU<W00@0LU8Y07=C:P1fERd0N5P_0P1jFS4207UI<080OE/^
0P1lFRd0101mFbh0Oed`085O<P22H3<2089O=@0308=P=P24HCL0QF8h0080QV<i00@0Qf@j08QS=P27
HSD0QV4d0P25H3<00`26HC@0Qf8e08QS=P0808QS=P@0QfDg0P26I3H308ES=@0808AR=022H380PEla
085O<@23HC<0Q68d08ES=@24HS@208=Q<`80PV0b0P21Gc400`20GS00OU/a07iK<@0707iK<@0307mL
<P1nFc40O5T_0080NeP^00D0O5T_07iK<@1oG380PEhd081M<`0307mL<P03085N=022GcD0Q64g0080
Pf0f00@0PUle085N=020GC<0P5dc0P1oG3800`1iEbX0NeT/07eK;P0207iL;`0307eK;P1kFB`0NELZ
00@0OEX`101lFBl02022GcD0PEhd07iK<@1lFBl0NeP^07eJ<01oG380P5dc0P1nG2l207eK;P80O5X]
0P1kFB`00`1kF300NUL_07UF;P0207QE;@0307YG;`1lFC40OEXb00@0OU/a0P1oG3801@20GC<0PEhd
089S=`20HCD0OEhb0080Ne``00<0O5da07iO<`20HCD00P21GS@01020GC<0Oe`b07iK<@1mFS0207aI
;`80OEX`0P1lFBl0101kF2h0NUL]07UF;01hEB/207aJ;@80OE/^00@0OU`_07mM<01oGC00Oed`0P20
GS02085O<@<0PV0b00H0Pf4c08=N<@24Gc80Q5lb08EP<`26HC@208MR=@0308QS=P23GS80Pehb00H0
Pehb2020GC<00`1mFS00Oe`b085N=00308=P=P80PUle0P1oGS<0101oG380PE`b085L<P21FS4308=I
<@80PE`_00@0PUd`08AO<P25H3<0Qf8e0P28HcH01P2:Ic40RfLc08]W<`2;IcD0RfLg08aW>P80S6Lk
0P2=J3/0102<IcX0RfHi08UT=`28HcH208MR=@80SFLh102>J3T208mY>P80T6Xk0`2?JCX308iX>@80
RfHi00@0RVDh08UT=`28HcH0R6<f0P27HSD00`29ICD0R6@d08IR<P0208EQ<@0408MS<`29ICD0RfLg
08MS<`80R6@d00<0RFDe08YV=P2:ISH00P2:ISH208AR=00408=Q<`22H380PEla081N<080Oed_0`21
Gc8[ooooo`00:_ooool20:MlB@040:IkB02UNTL0YGY70:AiAP80XgQ5202UNTD80:IkB080Yga500@0
Yga70:MlB@2WO4T0Yg]:0P2WNd`20:V0C0030:QoB`2WOTX0YWe90080YGa800@0Y7]70:5iB02SNdX0
YWi;0P2XP4`01P2VOdP0Y7e40:9k@P2ZOdX0Z7e80:MlA`80YW]600<0Yga70:QmB02ZOdX00P2XO4/0
0`2XODX0Z7e80:QmAP020:QnA0030:Qn@P2XODX0Z7e:0080Yga90P2VNdP20:EjA`@0YWe91@2UO4P0
0`2UNdT0YWa:0:IlBP020:MmB`80Z7i<00<0ZGm=0:MmB`2XOT`00`2YOdd00`2WOD/0YG]90:AjB002
0:AjB0070:=iA`2QMdD0X7I409me@`2NM480WG=109ab@00209]a?`0309Y`?P2IKcd0V6hl0080Ufdk
0P2BJC/0102AJ3X0T6Li08mV>02>ICL208eT=P0808]Q>@2:H3P0QUlf08AO=@23GS@0PUle089Q=P23
HSL407mL<P0407iK<@1mFS00OEX`07aI;`80NETb01L0N5Pa07MG<01fERl0M5@]07=C;01bDR/0N58]
07EB;01cD2X0L4hX06m?:01]D2P0KE4Y06iB:P1_DRX0KdlX06i>9`1^C2H0Kd`V07==:01fCRX0Mdl[
07EB:P0207IC:`0307MD;01hEBd0N5D]0080NEH^00P0O5H_07eH;P1oFS00PE``08=N<@25HC40Qf<a
08QT<P80R68c00@0RF<d08YT=@2;ICH0S6Hg0P2=IcP308aX>080SFTi0`2<J3P308eW>P80S6Hi0`2;
ICP208eW>Ph0S6Hi00H0UFTl09=X>`2BIcX0T6Li08eW>02:ISH208MU=@80S6Hg1@2;ICH208aV=`06
08aW<P2<Ic<0S6Lc08aV=@2<ISL0S6Hi0P2<ICX01@2=IcX0S6Hi08aV>@2;ICP0RV@g0080RF<f00H0
R68e08UR=`2:HcP0RV@g08]U=P2;IC@208aW<`0408aW<P2?JCX0T6Xk095[?080TV`m00<0TF/l08mY
>P2>J3T00P2>JSX208eY>@0408aX>02;IcL0RfLg08]W=`80SFLh00<0S6Hg08]U=P2:I3D00P29Hc@0
1028HS<0S6Ph08aX>02<J3P208]W=`<0RVHf00P0SVTl08eX>`2<IcX0RfHi08UT=`28HcH0Qf8e08IQ
=080RF@g0P28HcL01027HSP0Qf4j08IP>`26H3/808QS>@80Pf4c0P22H382085O<@80P5h`0P22GcD3
085N=0<0P5dc0P1nFc4207eJ<080O5T_0P1kF2h08@1jF380NELa07IF;`1cERh0L5@/06eD:`1/DbX0
Je@Z06]><01WC2h0HDPZ05U49`1B@BD0CclU04Xo8`1:?R@0B3`R04Lk8`15>b80@SXS03li8`0m>2@0
>SLT03Tf8`0d<Qd0=34N03Db7`0d<B00<RlP030/800]:Ah0:bLL02T[800202PZ7`0302LY7P0V:1d0
9BLL008092HK0P0T9b000`0S9Ql08RDN024T7@03020S700301lR6`0N81d07R0M00H07R0M00P06QdF
01/N5`0L7aP07B0I01hQ6P0O8Q/082<L024T7@80828O00@07b4N01dO700L7Q/06Q`I0P0I6aP301/M
6P8071hK0`0M7a`0600R8R008R<N024R7@0R8ad08b@L02DW700X:Qd0:B/N03@b8`0b<240;R`M02`Z
6`0[:AX0;R`M034_800d<R<0<38T02`^8@0U9aX0828G01hO5`0P8A/092DP02LX8`P092DM0`0Q8Q`2
020Q6`<07b0J200N81d801lO7@0P01`Q6P0N8AX08B8J028T6@0V9QX0:RPL02dY7@0^:Qh0:RHK02hX
700c:Q/0?2`L04Hd701J@b@0LELd089V?`2=L4P0UGQ<09^1CP2PQdl0YXeE0:65E@28Ich0JTPU044j
:00e;Qh0;2HH02`X7@0[:RD09bLU02@V9@0V9bT802DW90<09BPQ0P0V:B8302LZ8`0302PY8`0W:280
9RLQ00809BHP00<09bPR02TZ900Z:bD00`0V9b4202LX8P@0:2TS0`0Z:R8302/[8`80;2`T00`0:b`T
02/]8P0/;280;bdQ03<_8`0h<R@0>cDU03hg9`18=b<0BSTU04`k9`1>?BT204ln:P0=04hm:@1=?2P0
CcdW04hn9`1=?BH0Bc`U04Pl9016?2<0A3dS04<l8P12=bD0@cPV04Dj:00204Hk:@0I04Dj:013>2H0
@SLU04Hj8017>b<0B3`T04Pl9P1:?BX0BSd/04/n;P1<?bl0CSdY04dl:01;>RH0BSTU04Xi9`1;>RP0
C3/Y04dl;01A>b<0DcdU05Do9`1H@RX0FT@/05]5;@0205a6;P0@05Y6:`1HA2/0E4<Y05109`1>?bP0
C40Z04`o;01<@Bd0C3XV04`k9`1<>bT0Bc/[04Pk:P15>BT0@CPY03lf9`@0@cHV0P14=bL02`15>2P0
ASTY048g9@11=BD0@3@T03lc9@0m<BD0?2lV03/^9P0j;BD0>S@X0080>cDY00D0?3HZ03/e:@0i<bL0
=S0T03D_8`0303@]9@@0<b`T00<0=2dU034]900a;B@00P0b;RD203<_9P80=30W0P0c;2800`0d;B<0
=BhT03H_9@0203L`9P0903Pa9`0i;bD0>S0T03X`900k<R<0?C@S03hf8`0n=R40?cLR0080CSdY00h0
CCdV04hn9@1??bD0DT<V05E6:@1FAbP0GDHT06199`1VCRP0KE@/07AI;P1iG300OEh`07iO<080Q6@W
00L0QfLZ08i/;@2ELS80WWLd0:Al=`2YOST0ZWlj0080YGln00<0Xh100:5o@02OOd800P2MOd<01`2K
OT@0XH1:0:1oB@2OOTP0WGa609]jA02JND<00P2HMd402`2JND@0VGQ309Mf@@2DLch0T6lj08e/=`2:
JC@0RFPc08MY=`26J3H0QFLe0080PfDc00D0QFLe08QZ>02;KC/0R6Pi08UY>P0208YZ>`0508UY>P27
IcP0QFDf08=S=01oGS<00P1nGC001@1nGRl0Oel^089R;`25IS00QfPb00<0Q68b0`25Hc<208IT=006
089T<P21Hc40PV8a08=Q<@26HS80Qf4b0P2:HC<00`2;IcD0R6@b08AP;P02089N;00308EQ;`29IC<0
S6Pf00@0Qf8h00X0R6<i08UT>P2:IC/0RVDk08US=02<HcD0SFDd08mW=02AJCD0TfXf0P2EK3H02@2E
KSD0UVlf09M`=`2HLCP0Ug0g09I_=P2DKC@0Tf`c08MX<P0208IW<@0308EV<024IBl0Q6D_0080Pf@^
00T0Q68b085O;`1mGBh0NEX/07MJ;P1gG2l0NEhc07UP=`1lGC400P1mGS801@1lGC40NU/_07QI;@1e
ERX0Le@X0080KE<`00<0Je4^06Y@;@1XCR/00P1WCBX0301VC2T0K4l]06a?;@1YCb`0J50/06I@:`1S
CbX0HThY065?:@1NBRD0Gd/V069>:@80IU0[00<0IDlZ06A<:01RBRH00`1/DRl00`1]Dbh0KUD]06mF
;@02071H;004075I:`1bG2d0M5h_07EO<080Mf4b00`0MEl`07AN;`1bG2d0Led^079L;@1`FBd0KUL]
06]D:`1XD2X0IThX06E=:@1WCb/606Q@;00306M?:`1WDBX0Ie4Z0080IU0Y00`0Ie4Z06UC;01[EBh0
K5H_071I<01ZE2/0HT`U05Y68@1GAB40ETHT05I79P1HBBP205E69@0805A5901B@b80DD8Q0511801?
@1l0CSlN04i5:01:@B@204Ln8@80BT4T00P0AchQ04@k7P1:?b<0BSlS04U08`16?b80AD0R04=08@80
@D0Q2012>al803`h7@0603`i6P0k=aX0>SHI03Te6P0h=1/0=c8L0P0g<Qh01P0e<ah0=C<L03Pc7@0k
=Ad0?CHL044g7080@cPL01d0CT0S05528`1IARD0IDdW06mD:@1iF2/0PEd]08IQ;@2=IRd0Tf`c09]d
>`2QNT40X7]409Ye?P2BKCH0S6Tc07mT=`1fGS80J58[05I69@18>R00>S8M038/700^:a`09BLJ02<U
600Q8aP07b0H01hO6@0201hO6P0301lO7@0N7aT07QlI00H07QlI0P0K6aT601`L6P@06a/I0`0L71X2
01dM6`/07QlI0P0M7QP301`M5`8071`J0`0K6aT301XJ60P06A/H400G6AP@01HH5c805aTH0P0H6QT2
01TK6P806Q`K200K6aT801/M6PP071`J2@0M7A/201`M5`<07AhH0`0N7aT8024P6`808b<I0P0T91X2
02DU6`809RHL0`0/9QX202dW6`<0;RPL00H0<R`P034[7`0a:al0<2XN02lY7@0^:1`202dW6`H0<bTM
0P0b:1`803HZ7PP0>B`L00<0>bhM03X]700i;1/00P0i;1/00`0k;Qd0?C0O03ha8008040_7@0304Hd
7P15<ad0A38L0080@c4K00/0AC<M04Hd7P18=R00C3@L04de7@1>=Qh0CcLO054i8@1B>R80Dc/S05@l
900805Pn9@80Fc`O00@0G3dP05dn8@1N?b80Gd0S0P1P@B@306=58`80I4HT0`1UAbD02`1TAbT0HTDW
06139@1O@R@0H4<U06=6:01VBB/0J4/]06129P1O@BD0GClS0080FcdQ00L0G3hR05do8`1N@2@0H4DW
05m49P1N@bD0G44S0080Fd0R00@0G44S05e2901QA2@0HD@T0P1P@b<20654900;06=69P1TAbL0ITTY
06948P1SAB<0IDLU06I89P1XBRP0JD/Y06Y<:P1[CB/00P1UB2H0101VBBL0IdXX06Q;:@1XBbT206U<
:P80ITTW00@0IDPV06A79@1RAB<0HD@R0P1P@b401P1Q@1l0HT4P06=58`1TAbD0I4XW06=;9`80HD/V
0P1UB2P03P1SARH0HD@T05m28P1M@200G3lO05/n7P1P@RH0Gd4U05i0901M?b<0GT0T05m19@1Q@bL0
HT@X0`1SAB<206A6900306E79@1VB2H0IdTW00@0IdTW101XBRP03P1WBRX0J4/[06Q;:@1YCBP0JThW
06Y>9P1[CbL0Je0U06i=;01^CBX0Kdh[06m?:@1`D2T0LE4X0P1aDRH0101aDBP0Le<Z07EE;01hF2l3
07UI<00307QH;`1mFS00O5T_0080NeP^00D0O5T_07iK<@20GC<0PUle085N=002089O=@0308=P=P24
HCL0QF8h0080QV<i00<0R6<g08IQ=@24Gc<00P23GS800`24Gc<0QV4e08QS=`0808MR=@0408MU=`26
I3H0QV@f08IT=P80QF<e0`24HS@01`23HC<0PV0b085O<@20GS00PEla08=Q<`24HS@00P22H384085O
<@80P5h`2@1mFS000`1nFc40OEX`07]H;P0207YG;@0507]H;P1mFS00OU/a081M<`1oG3800`1nFc40
0`20GC<0PUle08=P=P02089O=@04085N=020GC<0Oe`b07iK<@80OEX`00<0NEH/07YG;@1kF2h00P1l
FBl00`1kF2h0NUL]07UF;00407aI;`@0OEX`00<0PEhd07mL<P1lFBl00P1jEbd00`1kF2h0OEX`07mL
<P0407aI;`@0NeP^00<0NEP_07QG;P1gERd00P1fEB`00`1hEbh0NUT`07]J<@0207eJ<00307iK<@1o
G380Oe`b0080Oe`b00T0OU/a085R=P1oH3@0O5da07YK;`1iFRh0NU/_07aM<@1nGc<00P1oG38207iK
<@0807eJ<01lFBl0NeP^07]H;P1kFS40NUT`07UH;`1hEbh207MF;@80MUD/00<0NUL]07]H;P1kF2h0
0P1kF2h307aI;`<0OU`_0P1oGC03081N<@80PUd`00@0Peha08AO<P24Gc80QF0c0P26HC@2085L<P@0
PUdc0P21G38807iK<@0607]H;P1mFS00Oe`b085N=022GcD0PEhd0P20GC<207eL<@0407eJ<01oFS00
OeX`07mH;`<0PEL_00h0P5/^085L;`22GC00Peha08EP<`26HC@0Qf8e08QS=P29IS00RFDa08YV<P2:
IS@0RfLg08aW>P80S6Lk0P2?JSd0102>JC`0SFPk08]V>@2:ICP208UT=`80RfDf0P2<ISL208eW>080
SVPi0`2?JCX308iX>@80SFLh0P2:ICP208UT=`0508QS=P27HSD0QV4d08IQ=027Hc<00P26HS801@25
HC40QV8b08MS<`29ICD0RVHf00H0RFDe0P2:ISH208ET=`80Q6<f00@0Pf8e089Q=021H3<0PF0c0`20
GC<[ooooo`00:_ooool0102VNdP0YGY70:EjA`2UNTL40:AiAPP0YGY5202UNTL20:MlA@040:MlA`2W
O4T0Yga90:MkBP80Yg]<0P2XOdT30:MnB0<0YWe700/0XG]:0:9lB`2SOTX0Y7m:0:F0B`2TOdP0Y816
0:=oA@2ZOdX0Z7e80:MlA`020:IkAP030:MlA`2XODP0ZWm:0080Z7a;00<0Z7e:0:QmB02XODH00P2X
OT@00`2XOT80Z7e:0:QmBP020:MlB@80YW]80P2UNTL40:ImB@D0YGa80P2UNdT00`2VO4X0Yge;0:Qn
C0020:UoC@030:Z0CP2YOdd0ZGm=0080ZX1>00X0ZGm=0:QnC02UNdT0Y7Y80:EkB@2TNTP0XgU70:9h
AP2PMT@0WgE30P2NM48209ab@00309]a?`2JL3h0VFlm0080V6hl00D0Ufdk09=X>`2CJ3/0TVLj095V
>@02091U>080Sf@g00X0S68j08]Q>@27H3L0QF0f08AO=@23H3H0Pf8g08AS>01nFc40Oe`b0P20GC<0
101oG380OU/a07eJ<01lFBl407UI<P0E07MG<01eEBh0Le</079B:`1hDR/0ME8Z07=@:01aD2L0KdlV
06iA9`1^DbP0Ke@Y071C:`1`D2T0KThW06e;9@1^BbD0LT`W07I>:P1gCb/0ME8Z0080MU<[0P1gE2`3
07QE;@0807eG<01nFBl0OeX`085L<022GC00Q60`08EQ;`26HS0208QR<`0408US=02:I3D0RfDf08]U
=P80S6Hg00<0RfLg08aX>02=JCT00P2>JSX00`2=JCT0S6Ph08]W=`0308eW>P80S6Hi0`2;ICP208iX
>`80SFLj102<IST208]U>0@0SFLj0P2;ICP01P2CIcX0TVLj095V>@2@IcT0SFLh08]W=`80R6Hf00<0
SVPi08eW>02<ISL00P2;ICH208aV=`0308eW>02>J3T0RfHa0080RfHb00<0RfDd08]U=P2;ICP00P2;
I3T308]U>0<0RV@g0P29HcH02028HCH0RF8g08]U>02<ISL0S6He08aW<`2;IS80RfHa0P2?JCX3095[
?00408mY>P2>J3T0S6Hg08m[>`80SVXj00<0SFTi08aX>02;IcL00P2:ISH208aV=`<0RfDf0`2:I3D3
08aX>080RfLg0`2:ISH02@2>JC`0SFPk08aW>P2;IST0RVDh08UT=`28HcH0Qf8e08UT=`0208UT>003
08QS>@28HS/0Qf4l0080Qf4m2027HSP208=Q<`80PV0b0P21Gc42081N<080PEhd0`20GC<307mL<P80
OU/a0P1mFS0207aI;`80NeP^00D0NeTc07YH<P1fERl0LUD]06mC:`0206aC:P0?06]D:P1]D380J4d_
06=:;01KART0E4<W05109P1;@2@0BclU04Tm8`18?2@0AS`S048j8`0o>B<0?CPT0080>CHS00P0=C<N
03Hc800f<b00=S<R03@a8P0b;R80;b/P02hZ7`80:B/P00<0:2XO02LY7P0V:1d00P0U9a`01P0T9Q/0
9BPQ02DX8@0T9b008bHO028U7P<08B@M00<082<L01hP7@0N81d01P0N81d01@0K7QL071lH01`O600M
81T07R4J00807b8K00L082<L020R7`0P8Ql07b4N01hP7@0L7Q/06adJ00<06Q`I0`0K7AX201`N6`80
7AlL01P08B4Q020P7P0P81h0824L028S7@0T9Ad09bTN02PZ7`0_<280;RlQ02`]7`0[;1h0:R/M02//
7P0/;Al0;BhP038c9@0^;R80:2PL02<S6@0Q8AT08R4L02@S7`0V9B4802@U7@04028S7@0Q8Q`08B8L
024R7080824K0P0O81X801hP7@P07alM0P0L8A/07P0N8AX0824I028T6@0V9QX0:RPL02`Z7@0V9aL0
;2XK038/800f:Qh0?RdM04di8@1SC2`0M5Xe08UW@P2AM4X0UW]<09N0C02RRE<0ZheI09ihB@27G2l0
EDTc048g8`0b:AP0;RPL02`Y8P0V9R@08BDV02@X:`P09RPU00@092LP02DX8@0U:2409BPQ0P0V:B82
02LZ8`0302LX8P0V9b409BHP00809BHP00@09bPR02PY8`0Z:bD09BHP0`0V9b4202LX8P<0:2TS0`0Z
:R8302/[8`80;2`T00`0:RdT02T/8@0Z;240;2`P030^8@0d<B80=c@S03/e9@17=R@0BCPV04/j:01=
?2X204hm:`0<04dl:P1<>bT0DClY0510:@1??bP0CChW04Xn9P18?RD0ASlU04Dn9016>bL0Ac`X0P18
?BT01@17?2P0AS/W04@i9@12=b<0Ac/Q0080B3`T00<0BCdW04Xm:P1;?Rd00P1;?Rh03P1>?RD0CCdT
04/k9019>2@0BCPV04Xi:@1;>B/0C3X/050l901A?BD0DclW05E1:@1G@b/0F4@/0P1IABd0401IARP0
F4@Y05=29P1@@2H0CClU04/o9`1<@2X0Bd0Z04hl:01>?BT0CSd[04dm;@19?2/0ASXZ048i:P10=bP2
048f9P0<044e9@12=RH0@cLW04Di:@16>RX0B3`/04<f9@13=RH0@SDU040b9@0o<BH0?BlV0P0l;BH0
2`0i<bL0>S@X03/e:@0k=BT0>S@X03Pb9P0f<2@0=2hR03H_9`0e;RH0=2dU00<0<R/S00<0<b`T03@]
9@0a;B@00P0a;B@2038^9@<0<blV0P0`;2<2034]900J038^9@0c;bH0=30W03@`9`0i;bD0>BlS03X`
900k<R<0?C@S03hf8`0o=b80@3PS04hm:@1=?2P0CShW04lo9P1A@BL0EDHY05Q9;01JBb`0HD/V06A>
9`1YDB/0KeH^07EI<@1iG38207eN<P80PF4`00d0Q6@a08]W<`2CK3D0VW0f0:5c=`2VMSP0ZGLh0:Al
=`2SO3L0Xg`i0:=m?02QOSh0XGm00080Wgm200H0YH9:0:B1B@2SP4P0XWm70:5nAP2OO4@209ik@`08
09]jA02JND<0VGQ209Mf@02DLcd0T6li08e/=P2;JS@208Y/>P0F08QZ>024IS@0PV@b08AV=02:K3X0
T79008aZ?02=Jcd0Sfdo091^@02?KCl0S6Xl08UW>@27ICL0PV8i081Q=@1nGc<0OEh`07eN;`1oHBl0
PV@`08AV<P<0Pf4a0P24HS8308ES<`0;085U=@22Hc@0PF8c085Q<P22H380QF0c08MQ=028HSD0RFLg
08MU=@25Hc<00P23HC400`25Hc<0QfDe08UW=`0408=Q=00?08AR=@25HcH0QfDh08QV>@23HC@0Q68e
08MR=@29Hc@0SFDd08mU<`2AIC@0TVLd08eX<`2>JC@0T6/f0080TF`g00<0SfXe08iY=02=J3<00`23
IC<2089T<P80PF<a00X0P68`081P<@1nGC00NU/]07EH;01cF2d0LEP_079I<@1bFc80MEP`0`1fFC40
2@1eF300LUD]071C:`1^DBT0KEDc06aD<P1YDBl0Idl]06E=:`0306=;:@80JU0_00<0JE4_06M@;P1U
DBh00P1SDBd01`1PD2`0GDhU061>9P1QCbL0HTlW06A>9`1TC2H00P1SBB@0301`E2d0LED^075E;P1a
EBd0LUL/07=H:`1dFBX0MEX[07EK:P1aFb`0Led^07IP<@80N68c00h0MV0a07=M;P1aFb`0LE//071J
:`1^Eb/0K5D[06YC:P1XD2X0IThX06E=:@1UCbX0IU0[06MA;080J58]00D0Ie4/06I@:`1UCbX0Ie4Z
06I@:@0206E?:00<06I@:@1XDR/0JU@]06aF;`1_Ec40Ie4Z05i88`1G@b00ET<R05E5901EARD0EDHW
0`1CA2<00`1B@b80DD8Q0511800204m07`0404e49`1:@B@0AchQ04Ln8@80BT4T00X0AchQ04<j7@19
?R80BChR04Ln8@15?R40@chP048o8010?b00?chO2011>Qh803`h7@0>03/g6P0j=Q/0>CDJ03Lc6P0f
<A/0=S4M03Ha7P0g<Ql0=38M03Dc700h<ad0>S@L03`e6`10=Q/2048g6`0P04a19@1=?b80E4@S06A>
:@1_Db/0M5DW07]I:@24H2h0TFL[09AZ;P2HL3D0VG8i09E`>@2>JcD0QF@_081O:P1_EC00Ie4/05Y7
9`1;>b40?C8N03<]7`0/:Qh0:2PP028T6@0P8QL07QlG01dN600L7AP07AdK01hN700O7al801dN6080
6QXH0P0K6aT401`L6P806QXH0`0K6aT301`L6P0301dM6`0N7aT07QlI00P07QlI0P0M7QP301`M5`03
01/L5P0L71X071`J00<06a/I0`0J6QP801TK61005aTH400F61Lb01LI608061XI0P0I6aX201XL6`P0
6QXH200J71T801`L6PT07AdK0P0L7AL301dN60<07QlI200Q81/202<S6@8092@J0P0U9A/202HV7004
02/U6@0/9QX0;2HJ02`V6P80;BLK0P0^:1`402lY7@<0;RPL00<0;BLK03<Y7@0c:Ad00P0c:Ad2038X
7080<BLK200f:Qh803L[6`0803/^7@0j;A`0>B`K03P[6P0i;1/0>RdL03`_7P0m<1l8040_7@0304Hd
7P15<ad0A38L0080@c4K00<0A38L04Dc7@16=1h00P1<=1`0101==Ad0CSHN050h801A>B42058j8PP0
ES`U0P1J>al00`1K?200G3dQ05dn8P0205ho8`0405m0901RA280HT@R06948P80HdDS0`1TAR@00`1S
ABT0HT@X06539`0206129P0;06539`1RA2P0HdDY05m19`1N@2H0G3hT05/m8`1J?280FcdS05`n901M
?bD00P1K@R@305Y18`<0Fd8T1P1QA2@01`1RABD0HdHV06=69P1SA2D0I4DV06I7:01WB2T00`1XBBX0
0`1WB2T0I4LW06A79`0206A79`<0IDPX00<0ITTY06A79@1TAbD00P1SAR@0301RAB<0HD@R06138@1P
@b40HD0O06=28@1SAB<0HdHT06989@1QBBD0GdTT05i88`80HdHV00h0HD@T06138`1N@B40G3lO05/n
7P1J?Ad0Gd4W05i09P1M?bD0G3hT05do9@1N@2H0H48X0653:@80HT@R0`1Q@b400`1SAB<0I4HT06E7
9@0206E79@<0ITPV0`1WBBL206M::P0B06Q;:@1XC2L0JDdV06U=9@1ZCRH0JTlT06a;:P1/BbP0KD`Y
06i>:01_CbP0L50W071A9@1aDRH0LE4X079B:@1eEB`0MeL^0P1iFC0207QH;`0307iK<`1lFC40NUL_
0080NUL_00<0OEXb081M=@23H3P00P21GS@00`22GcD0Pf0f08AQ=`0208ER>00408IS>@27HSP0QF0f
08=N=080PE`b00<0Pehd08EP=P27HSP02027HSD01025HcD0Q68d08AR=024HS@208=Q<`80PV0b00P0
Q68d08=Q<`21Gc40P5h`07mM;`20GS00PEla089P<PP0P5h`2P1mFS001`1lFBl0NUL]07UF;01iER`0
NUL]07aI;`1mFS000P1oG38307eJ<00407mL<P21GS@0PUle085N=080P5dc00<0Oe`b07iK<@1mFS00
0P1lFBl00`1iERh0NUL_07YG;`0407YG;`0307UF;P1kF2h0O5T_0080O5T_0`1mFS001@1nFc40OEX`
07aI;`1kF2h0NUL]0080NeP^00<0O5T_07eJ<01lFC401P1lFC402@1kF300N5P_07MG;P1fERd0MED/
07IF;@1gEbh0NET`07YJ<@0207mL<P<0P5dc00L0Oe`b07eJ<01lFBl0OUlc07eN<P1lGC40NU/_00<0
NEX^00H0NU/_07iK<@1nFc40OEX`07aI;`1kF2h207YG;@0407UF;01gEc00MeL`07EE;P<0M5@]00<0
MED^07IF;`1iERh01`1iERh307aI;`80OEX`0`1nFc44089M<0<0Peha00<0Q5lb07mI<P20FS<01021
Fc@00`20FS<0OeTb07eJ<00707eJ<00307]H;P1lFBl0OU/a00<0Oe`b00D0OU/a07eJ<01jFBh0NUT^
07]H;P0207eH;P0407iG;P20ERh0P5H^081F;P80PE`_00@0PUd`08AO<P25H3<0Qf8e0P28HcH02028
IBl0R6@`08UU<@2:IS@0RfLg08aW>P2<Ic/0SFPl0P2>JC`0102=J3/0S6Lj08aW>P2;IST208YU>080
RF<d00@0RV@e08]U=P2<ISL0S6Hg0P2=IcP308mY>P80SVPi0`2=IcP01P2:ICP0RF@g08UT=`28HcH0
Qf8e08IQ=080QF0c0`25HC4208IR<P0308QT=029ICD0RFDe0080RfLg00H0RVHf08UU=@29ICD0RVHf
08]W=`2<J3P208EV>P0408AU>@23I3P0PV<g085R=P80P64e0`1nFc<[ooooo`00:_ooool20:=hA@<0
Y7U60`2UNTL80:AiA0P0Y7U60P2WO4D0102WO4L0Yga90:MlB@2WNdX20:MkC0<0YWe50`2WOTH20:Qo
A`80Xge<00T0XWe90:9mB02SOTT0Y7m80:F1A`2VPTP0ZWm:0:QmB02WO4L00P2VNdH00`2WO4L0Z7e8
0:YoBP020:QlB`030:QmBP2XODP0Z7e60080Z7i400<0Z7i20:QmBP2XODX00P2WO4T20:IkB080YGY7
102UO4P50:ImB@80YG]900H0YWa:0:MmB`2XOT`0ZGm=0:Z0CP2[PDl20:Z0CP80Zh5?00@0ZX1>0:Qn
C02VO4X0Y7Y80P2UNdT0102TNTP0XWQ60:5gA@2OMD<209id@P80W7900P2KLCl01@2JL3h0VFlm09Q^
?02HKS`0U6Tl0080TfPk00<0TVLj095V>@2@ICP00P2?I3L00`2=Hc/0S68j08QQ>00208EP=P0<08=P
=P24HcP0Q6<h07iK<@1oG380P5dc085N=020GC<0Oe`b07eJ<01lFBl0NETb0`1jFS<0501iFC80MUH_
07AD;@1bDR/0NE@Z07EB:01cD2H0LE0U06m@901^DBD0KU<V06mD9`1aE2`0LE4Z06i>9`1]BbD0KDXT
075;9P1eCBT0N50/101fDb/407MD;00907mI<P1oFS00P5/a085L<022GC00Pel_08=O;@24H2h0Qf4b
0080R68c00<0RF<d08YT=@2;ICH00P2<ISL00`2:ISH0RfLg08eY>@0208iZ>P0308eY>@2;IcL0RVHf
00<0SFLj0P2<IST308]U>00308mY?02>J3/0SVPk0080SFLj0P2<IST0102;ICP0RV@g08]U>02=IcX2
08iX>`0408eW>P2;ICP0RV@g099V>@80T6Dh00<0SfHh08eW>02<J3P00P2:J3P00`2@JS/0SfTj08eW
>00208aV=`80SFLh00<0SfTj091Z>`2;IS400P2;IS800`2;IC@0RfDf08]U>00208]T>@<0RF<f0`2:
I3L208]U>00808QQ=P29HSL0RfDh08aV=`2=IcH0S6Lc08]V<P2:IC0208iX>@0608mY>P2@JS/0SfTj
08iX>@2<ISL0RV@e0P2?Jc/01P2>JSX0SFTi08aX>02;IcL0RVHf08UU=@<0RV@e0`2;ICH208aV=`<0
S6Ph0P2;IcL308YV=P0408eX>`2<IcX0S6Lj08]V>@80RVDh0P29I3L01P29I3P0RF@j08UT>P29Hc`0
R68m08QR?P80Qf0o2026HCL208=Q<`80PV0b0P21Gc42081N<0<0Oe`b0`1nFc4207eJ<080OU/a0P1m
FS0207aI;`80NeP^01T0O5Xd07]I<`1fERl0LE@/06iB:P1[DRT0K5<Z06]D:P1_DS@0JTla06A;;@1L
AbX0ED@X05109P1<@BD0BclU04Xn9019?BD0AcdT04<k9010>R@0?CPT03Tf8`0h=B80=cDP0080>3DR
00D0>3DT03Ld9@0d<2@0<RhS034]8P0202T[8080:2XO00D09bTN02HX7@0U9a`09BLL02HY8P0202DX
8@0302@W800S9Ql08RDN00<08B@M200N81d401dP6@@07R4J0P0O8Ah201hP7@0401dO700L7Q/071hK
01/M6P806Q`I0`0K7AX301`N6`08020P800O7al07alM01lP6`0Q8Q`08b@N02DV7P0W:20202`/8080
;BdQ00X0;2`P02/[7`0Y:Ad0:2PL03<a900a;b<0;B/O02TV7@0V8a`09B8M0P0U8Ah802@U7@808R<M
0`0Q8Q`3020Q6`P07R0M200O7ad201/Q7@0N01/P6P0N8AX08B8J02@T6P0W9ad0:bTM02DX4`0[;1`0
<BdR03<Z8`0g:Ah0@c0O05M29@1WD2h0PUhj08i^A`2@N4X0SWQ609V2C02^SeP0[XE?09i_>`1XF3l0
D44Z03P]6`0_9aX0:RLP02@T8P0P92D08RL[200V:2D202@W80<09BPQ0`0V:B80200W:2809RLQ02DV
800T9Al09BHP02HW8@0X:B<0:BXT0P0U9R0302HW8@@09bPR0`0Z:R8302/[8`80;2`T00`09bdS02T/
8@0Y;240:R`O02d^800b<240=C8Q03Ld8`17=R@0B3LU04Xi9`1<>bT204dl:P80C3/Y00/0Dd4[0592
:`1A@BX0Cd0Y04a0:01:@2L0B44W04M09P15>R@0AS/U04Pm9`0304Xo:@0304Tn:018?BL0BCdS0080
BCdU00<0BShX04Xm:P1:?B`00P1:?Bd05@1>?R@0CCdS04/k8P19>2@0BCPV04Tg:@1:>2`0BcT]054l
9`1B?BP0DchY05@o:P1E@2/0ET4/05M2;@1H@bh0F4DW05M49P1B@BD0CclU04`n900204Xn9P0<04Xo
:@1@?RX0CchZ04ln;01>?Rh0BSd/04Lk:`12>BX0@3LX04@k:P13>RT0@CPW0P10=bH03@11>2L0@STX
04<j:@15=BD0ACDV04@d9@13<bH0@C0V040_9`0o;RL0?RdV03Pb9P0i<bL00P0j=2P0300i<bL0=c4U
03D_8`0c;B40=c0X03H_9`0d;BD0<R/S034Z8P0b:b<0<b`T03@]9@@0<BdT0P0b;RD203<_9P0602dZ
8@0^:b80;b`S02l/8`0`;B@0<BhU0P0b;bH0200h<2D0>30S03Xb9@0k=2@0?CHT03hg900o>B<0@3XT
0P1=?2P03P1>?RL0D40W05A4:P1HBB`0G4d`05i?<01[EB`0KEL^071I<01cFS40Me/c07QK<`1iFC00
N5P_0P1lG3H03`1nG3H0Q5le08YQ=@2BHcD0VFLd09eX<P2QJS80XGHa0:9g<P2QNC@0XGXg0:9l>`2Q
OSh0Xh100::0@@030:J2B0030:F1A`2TP4H0Y8160080Xgm50200VWY109]k@P2JNT40VGU009If?@2C
LcX0Sflf08e]=02<KS`0Sg4o095c@@2?LCl0RV`j08U[>@2=Kcd0TG=108m]?`2@KT00Tg5309AbA02C
LD<0T6i008aZ?02:J3X0QVHm08AT>`20HCD0OEh`07eN;`1nH2h0PF<a08=U<@<0PV0`0P23HC4308AR
<P0908=W>021ICH0PV<e081Q<`21H3<0Pf4d08MR=P28HcL0QFDd0080Q6@c0`23Hc8208AT<`0C08=S
<022HRl0PF4^085Q;P22HRl0QFDb08MW=029JCH0Oelf081Q=@23H3H0QV4e08QR=@2=HSD0SV8c095R
=02:IC40RfHb08aW<`0208iY=@0308eX=02;IS80RfHb00D0PV<d0`21HS<0501oGS<0OEhb07YJ<@1f
FC40LUH_06iD;`1/E2h0K5@`06mC;P1`E2l0LED`079F<@1aEC00Ke<^06iB;@1/D2/0JE8c06QA<P1V
Cc00I4d^0P1SC2d0101TCBh0IDh_06YA<P1ZDC8206QA<@0<06IB<@1UDS40HU8`069B<01PDbL0Ge8V
069A9P1RCbD0ITlV06Q?9`1/D2T0KU0Z0`1cEbl0101dFBh0M5T/07EJ:`1fG2/207MM:P03075K;01c
GBh0MV0a0080N68c00h0MV0a07=M;P1aFb`0KUPY06eG:01/EBT0Je@Z06UB:@1XD2X0IdlY06I>:P1R
CRT0HdlZ06EA;080IU8]00D0IE4/06=?:P1RCRT0Ie4Z06I@:@0206E?:00<06I@:@1XDR/0JU@]06]E
;P1/E300I4hY05]48P1F@R40ET<S05I69@1DABH0DD8S201A@R40201=A2L0BD0S04Hm8017?R40BD0S
04Y19017?R40@cXM0P17?2001015?1l0@c`O044l7P10?Ah203hm7PP0@CXN200l>1d0<00k=a`0>SHK
03Lc6P0e<1X0=2lK03@_700e<1d0=S0P03<a700d<Q/0=c8L03Tc6`0l=A/0?cDJ044f6P12=a/0Bd4V
04Pm7`1@@B00HDdZ06aC:`1aDRH0N5HX08=O;`2AIBP0TVHY091V:P2=IRd0R6</07mN:@1hF2D0M5@Q
05e6901G@R<0C3/O03lc7@0c;1`0:bLL02@S7P0R8R007b0H01hO5`0L7AL06a`F01/L5`0L71X07AdM
01hN7PP071dG00<06ATG01XJ600J6QP00P0K6aT201`L6P0301dM6`0J6QP06QXH00806QXH0P0K6aT3
01`L6P/07AhH0`0L7AL201/L5P8071`J0`0K6aT301XJ60P06A/H400G6AP@01HH5c805aTH0P0H6QT2
01TK6P806Q`K200J6QP801XL6@P071`J2@0M7A/201`M5`<07AhH0`0N7aT8024P6`808b<I0P0T91X2
02DU6`809RHL0P0[9AT302`V6PL0;BLK0`0^:1`0100_:Ad0=2XN03<Y7@0c:Ad2038X7080<BLK00<0
<2HJ03DY7@0e:Ad01P0e:Ad803D/6`0303/^7@0j;A`0>B`K0080>2/J00<0>RdL03`_7P0m<1l0200o
;Q`02016=1h0AC<M04@b7013<A/0@S0J04<a6`15<ad0AS@N0`1==Ad00`1>=Qh0CcLO050h8002050h
80P0E3XS0P1I>Qh00`1J>al0Fc`P05`m8@0205dn8P0305ho8`1Q@b40HD<Q0080HT@R0`1SAB<00`1T
AR@0H4DX0615:0020615:00<05m49`1M@RD0G44T05]08`1O@BT0GT0X05`n9P1K?BD0FS`T05/m9@1L
?RH0GClW0P1F?b00101G@240F44R05U28`1J@b@205]49@@0HTDU0`1QA2@206138`0306A5:01UART0
IdP[0080J4T/00<0IdP[06E6:@1TABP00`1SARP306959`80HD@V0`1RAB<506548P080691801S@R40
HdDS06=6901QAb@0GdLS05e78P1LAR420654900406138`1O@R80GD0P05`o7`80FchN00<0GT0X05do
9`1L?RH00P1L?RH01@1N@2P0Gd4Y0653:`1RA280HD<Q00<0Gd4O00<0H48P06948P1SAB<00`1TAR@2
06E79@0306I89P1WBBL0IdTW0080ID/Z00<0ID/X06I<9`1VCBD00P1VCB@01`1VCR80JdXY06]:9`1/
BbP0KDdW06i>9`1_CbH00P1`DBD01P1`D2L0LU8Y07AD:`1gEbh0N5P_07UI<080N5P_00<0OU/e07aI
<`1jEc400P1iES000`1mFS@0P5dg08=P>P02085N=080PUle00L0Pf0f08AQ=`25HSP0QF8h08MR>024
GcD0PE`b0080OeX`00<0PE`b08AO=@27HSP02026HC@3089P<P80PEla0`20GS000`24HS@0Pf4c085O
<@0307mM;`03081N<021Gc40Oed_00<0Oed_1020GS0907iK<@0307aI;`1kF2h0NUL]0080NEH/00`0
NUL]07]H;P1lFBl0Oe`b07iK<@1mFS00O5T_07eJ<01nFc40P5dc085N=020GC<207mL<P0307iK<@1m
FS00O5T_0080NeP^201iES0207]H;P80O5T_0P1mFS0207iK<@0407MD:P1hEB/0NUL]07]H;P@0O5T_
101lFC<407eJ=00307UI<01hF2l0MeL^0080MUH]00<0N5P_07YJ<@1kFc800P22GcD208=P=P04085N
=01oG380O5T_07YG;@@0O5da00@0Ne``07UJ;P1gF2`0MUL[0P1mFS000`1lFBl0NeP^07YG;@0207UF
;00407QE:`1eEBl0M5@^07=C;@80LU8/00<0M5@^07EE;`1gEc400`1hEBl507MD;P<0NUL]0P1kF2h3
07aI;`0408=N<@22GC00PUd`089M<0@0PE`_00<0OELb07iH<`20FSD00P21FcH00`20FSD0OUPc07eG
<P0807aI;`0307]H;P1lFBl0OEX`0080OU/a00T0O5T_07]H;P1iER`0MUDZ07MF:`1hEB/0NeH/07aG
;@1nEbh00P20ERh01`21Ebl0PUd`08=N<@24Gc80QF0c08IQ=028HcH00P29I3L02027I2h0R6@`08QT
<029IC<0RfLg08aW>P2<Ic/0SFPl1029I3L408QS=P0608MQ<P28HS<0RF<d08YT=@2;ICH0S6Hg0P2=
IcP0102?JCX0SVPi08iX>@2>J3T208eW>080S6Hg00H0RF@g08QS=P28HcH0Qf8e08IQ=025H3<208AO
<P0608=O;`24H300QF4a08IR<P27Hc<0R6@d0P29ICD00`2>JSX0SFTi08]W=`0208YV=P0408]W=`2<
J3P0SFTi089S=`80PF8f00<0P64e07mP=01nGc<00P1mGS8307aI<b_ooooo000Zooooo`80XWM400@0
XgQ50:AiAP2TNDH0YGY70P2VNdP80:AiA0P0Y7U60P2WO4D0102WO4L0Yga90:MlB@2WNdX20:MkC006
0:Ak@`2UO4@0YGa40:ImA@2WOTH0Z7m70P2YP4P02`2TP4h0XWi<0:1lB02OO4H0X7e70:>0B02VPdT0
Z8E;0:YoBP2XODP0Yga70080YW]600<0Yga70:QmB02ZOdX00P2XO4/00`2XODX0Z7e80:QmAP020:Qn
A0030:Qn@P2XODX0Z7e:0080Yga90P2VNdP20:EjA`@0YGa81@2VODT20:EkB@040:IlBP2WOD/0ZGm=
0:Z0CP@0Zh5?0P2/PU00102ZP4h0Z7i<0:IlBP2TNTP20:EkB@070:AjB02RN4H0XGM50:1fA02OMD<0
WWA209ec@@0209ab@00309]a?`2JL3h0VFlm0080V6hl0P2EJC`0102DJ3/0TfLj099V>@2AICP2091T
=`0:08eS>`2<HSX0R64h08IQ=`25H3H0Q64g08AS>025I3T0OU/a07mL<P<0PEhd00D0Oe`b07eJ<01l
FBl0NETb07YJ<`0207]K=00D07UI<P1gEc00M5@]079B:`1iE2X0ME8X07AA9`1aD2D0L54U06iA9@1^
DbH0Ke@W079E;@1bDR/0KThW06a:901]BR@0LD/V07E=:@1hD2`507IC:`<0Me@/00H0P5Xc081K<@20
Fc40PE``085L;`22GRh2089N;080Qf4b00@0R68c08US=02:I3D0RfDf0P2<ISL00`2:ISH0RfLg08eY
>@0208iZ>P0308eY>@2;IcL0RVHf00<0SFLj0P2<IST308]U>080SfTl0P2>J3/01`2=IcX0S6Hi08aV
>@2;ICP0RV@g08]U>02=IcX00P2>J3/02@2=IcX0RfDh08YT=`2@I3L0Sf@g091U>02?ISP0SFLh08eY
>@0208]Y>@03095[?02@JS/0SVPi0080SFLh0P2>J3T00`2@JS/0TF/l08]V<@0208]V<P0308]U=02;
ICH0RfDh0080Rf@i00D0Qf4d08QR=@28HSD0RF<f08YT=`0208]U>00;08aV>@27H3D0RF8g08]U>02=
IcP0SFLf08aW<`2;IS80RVD`08eW>02>J3T00P2?JCX0102>J3T0S6Hg08YT=@29Hc@208m[>`0308iZ
>P2=JCT0S6Ph0080RVHf00L0RFDe08QR<`29Hc@0RF<d08YT=@2;ICH0S6Hg0080SFLh0`2<J3P208]W
=`<0RVHf0P2<IcX308]V>@<0RVDh00H0RVDk08UT>P29Hc`0RF<l08QR?@28HSh208MP?`P0QF0f0P23
HC<2089P<P80PEla0P20GS0307iK<@<0OEX`0P1lFBl207iK<@80OEX`0P1lFBl207]H;P0507eK=@1k
FC<0MUH_075D;01^DRX00P1[DRT0201[E2X0L5<e06]@<P1UC2h0GDP[05E4:01A@BL0C44U0P1;?bD0
201:?RH0AcdT04<k9010>R@0?CPT03Tf8`0h=B80>3HQ0P0i=R<01P0i=RD0>3DV03Hb9P0d<2D0<RhS
02X/8@80:B/P00<0:2XO02LY7P0V:1d00P0U9a`202HY8P0302DX8@0T9b008bHO00<08RDN00<08B@M
01hP7@0N81d01P0N81d0100O8Q/07R4J01hQ6P0N8AX301dP6@0301`O600N81d07R0M00807R0M100M
7a`301XL6@806adJ0`0L7Q/0600O7b407alO01hN7P0O7ad0824L028S7@0U9Qh09bPP02PZ7@0Z;1l0
;2hQ02h`8`0];b80:R`O02LY700T9QT0<S0S034_8`0^;200:bPO02PU7P0V8ah0920M02<O70P092DM
0`0R8ad2024R70<0824K200N81d801lO7@0P01/Q7@0J81`06b0J01/P6@0O8QT08b@L02LW7@0Y:Al0
92TB02/^7@0b;bH0=2/V03HW800n;Ad0D3`Q05m;:01nFSH0S6a608aeB@28M480U7e70:j>E@2fS580
[GY1079QA`1HB2l0?2lL02hV6@0Y9Qd08b<Q020T9@0R9b/802HX9@<092LP0P0U:24302HY8P0302LX
8P0V9b409BHP008092DO00<09RLQ02PY8`0Y:R@00`0U9R0202HW8@@09bPR0`0Z:R8302/[8`80;2`T
00`09bdS02L]8@0X:b00:R`O02`]7`0a;b00=3<Q03Hc8P16=BD0B3LW04Xi:@1<>b/204dl;00304`k
:`1;>RX0ED<]0080Dd</00<0DD8[04i2:P1<@RT00P19@RP01@12=b40A3TS04Ll9P1:?bT0C44[00<0
CT<]00H0BShT04Xn9P1:?RH0BShX04Xm:P1:?B`204Xm;@0804ho8P1=?B<0Bc/R04Th9018=bL0BCLY
04Xh;01:>2h3050n:003054o:@1B@2X0Dd4[0080E48/0280Ed@T05I39@1A@280CSlR04/m8P19?B<0
BShV04To9P1@?RX0D3l[050o;@1??bl0Bch]04Lk:`12>BX0@CPY04U0;`17?Rd0A3/Z044h9`0o=RD0
?SDT03lf9@10=bH0ASHV04De9P14=2D0@c<V044`9P10;bL0?bhW03h]9P0g<BD0>38V0P0i<bL0200h
<RH0=S0T03@^8P0b;200>34Y03H_9`0d;BD0<R/S0P0a:R800`0c;2@0=2dU030/8`03034]9080<RhU
0P0c;bH202dZ8`0302h[900_;2D0<2dV0080<BhW00T0<RlX03La9@0h<R@0>C<U03/e9@0l=b@0?STU
03lj9010>bD00P1=?2P03P1>?RL0DD4X05E5:`1JBbh0GTlb065B<`1dGSD0MElf07IO=@1gGSD0Me/c
07II<@1eEBh0M5@]0P1hESX03`1jEcT0OULf08AI=P2;Fc<0TE``09MO<02IGbl0WW8[09mc;02PMC00
X7Pc0:9k>02SOC`0Xh0n0:B1@@080:J2B080VWY101h0Vg]209Yj@@2HN3l0U7@k095a>02?KcH0SFlm
09=e@`2INdT0VWa:09AfA02@LT00Sg4o091b@02BKD00U6m209MbA@2IM4L0V7=609A_@P2@Jch0SVTl
08MZ@P24Icd0P6<i07aO<`1kGc00O60`07iR<020I383089P<080Pf4a0`24HS802P23J3T0PVHg081T
=@21HS@0PF0c08=Q=027HSH0R6<g085Q<P22HS<308=S=003089R<`21HC80P60a0080Pf@]0P22Hb`0
1023I2d0QFH_08QY<P2:Jc@207eP=P09085P=@23HC@0Qf4d08]P<`2=HC@0T64c08MS<@28I380RVHd
00<0RfLe00@0RFDc08QT<P21ICH0PFDf1P20I3D02`1nGSD0OEdd07UL=01fFS80LEP`06aD;P1YDBd0
Ie4/06a@:`1]DB`0Ke<^0080L5@_00D0KU8]06eA;01/D2/0IDh_06A=;P0306=<;@0306I?<01XDC80
JU<d0080JU4b00h0JE8b06MC<P1VDc80I5@b06=C<@1RE340HEHY065D:01PDBH0I54W06UB:@1]E2`0
M5H`07MI<`<0MEP^00T0MUT]07MK;01hG2`0N5`Z07UM:`1iGRT0L5X[07=M;P1fH3400P1iHc@00`1f
H340Led^071J:`0206aF9`0906]D:01ZDbT0JE8Y06Q@:P1WCbT0Idl[069>:@1SCbX0IE4/0080IU8]
00<0IE4/06=?:P1RCRT00P1VD2T206E?:00<06I@:@1XDR/0JU@]06]E;P1ZDRh0HT`W05Y38@1F@R40
Ed@T05I59`1CA2D0Cd0S0`1@@B0305528@80DT<R00P0CD@W04U08`16?B00ASdP04U08`1:@B@0ASdP
04<j7@80AS/O00@0A3/N048k7P10>ad0?c`M0P0l>a`8044j7PP0?3PM00h0>cLL03Te700g<aX0=2lI
03<^6P0d;a`0=BlO03H`800c<A`0<c4J03Ha6`0i<a/0>c@J03le6P80@CHJ0200BT0U04Hk7`1>?b00
HDdZ06aC:`1^DBL0MUDX089P<02?HB<0SF4T08YP9024GB@0OEXT07ED7`1_Ca`0JddK050k701<>A/0
@c<J03T/6`0^9QT09B8K01lO7@0L7Qd07QlG01dN5P0K71H06Q/F01XJ600L71`07AdM01hN80P071dG
0P0I6AL201XJ600401/K6@0L71X071`J01dM6`@06QXH0`0K6aT201`L6P/07AhH0P0L7AL301/L5P80
71`J0`0K6aT301XJ60P06A/H400G6AP@01HH5c805aTH0P0H6QT201TK6P806Q`K200J6QP801XL6@P0
71`J2@0M7A/201`M5`<07AhH0`0N7aT8024P6`808b<I0P0T91X202DU6`809RHL0`0[9AT202`V6P<0
;BLK0P0[9AT00`0/9QX0;BLK02hX700202lY7@05030Z7P0d:Qh0<bTM03<Y7@0b:1`00P0a9a/2030V
6PP0=BTM200d:aX00`0j;A`0>B`K03P[6P0203P[6P0303X]700l;ah0?C0O00P0?bhL00<0AcDO04Dc
7@14<Q`00P12<1X00`13<A/0A38L04Dc7@0204de7@<0CSHN0`1?=al8058g8P0605Ph7`1I>B00FCTP
05Xj8@1K>b80G3`S0P1M?B@306538@80HT@R0`1SAB<02`1NA2T0GdDZ0616:`1QAb`0GdDZ05a29`1H
?R<0ES`Q0612:P1N@2P0GClW00<0FcdU00L0G3hV05do9`1C>al0E3`P05Hn8P1H@2@0FD4U0080Fd<W
00<0G4@X06=69P1SARH00P1RABD20654900506138`1O@R80GT4Q06E6:@1VAbX00`1XBB`0101VAbX0
Hd@W06939P1SARP206959`0506549P1P@bD0Gd8T05m2901N@B<00`1P@b4206548P<0HTDS00P0Hd8Q
06A38P1SAB<0HdHT0657901NAR80FdDP05Y47`<0Gd8R01D0GT4Q05e0801L?al0G3lO05/n7P1N@2P0
GClW05`n9P1K?BD0G3hV05do9`1O@BT0H48Z06538@1P@R00GT0N05do7@1N@1h0Gd4O06538@1RA280
0P1SAB<206A6900406E79@1VB2H0ITPV06M99`80I4`Z00<0I4`X06A<9P1TCB@00P1UCR@03@1UCR80
JTTX06Y99P1[BRL0K4`V06e=9P1_CbH0Ke0T071A9@1`D2L0LU8Y07AD:`1gEbh00`1hF2l02P1gEbh0
OU/e07aI<`1iES00N5D_07UF<01lFC<0P5dg08=P>P20GC<2085N=003089O=@23H3H0Q64g0080QF8h
00<0QV0i08AN=`21Fc@00P1nF3400`21Fc@0Q5hg08IP>@0808IQ=080PEla0`20GS0307mM;`0408AR
=023HC<0PEla07mM;`80OU`^00@0Oed_081N<01nG2h0OU`^101oGBl2081N<0T0OU/a00<0O5T_07]H
;P1iER`00P1hEB/00`1iER`0NeP^07aI;`0207iK<@<0O5T_00<0OU/a081M<`21GS@00P1oG3800`1n
Fc40OEX`07aI;`0207]H;P0407YG;@1iES00NEH`07UF<080N5D_0`1iES0307]H;P0307aI;`1mFS00
OU/a0080OU/a00T0M54W07IC:@1iER`0O5T_07iK<@1mFS00O5T_07]H;P1lFC<0101mFS@307iK=@03
07MJ<01fFBl0MEP^0080MEP^00@0MeX`07QK<@1jGC<0Q64g0P25HSP03`24HCL0PUle07mL<P1kF2h0
NEH/07UJ;P1kG300O5da07eN<P1lGC40NEX^07EF:P1cE2P0OEX`07aI;`0207]H;P0<07YG;@1iER`0
N5D[07QE:`1aDbd0L58/06mA:`1^D2X0Ke4[079D;P1dES00MUPb101gE2h407IC;@<0NEH^0P1jEbl3
07]H<080Peha0P22GC001`21G2l0P5/^07mJ;@1oFRd0O5Ha07iH<`20FSD00P21FcH00`20FSD0OUPc
07aF<@0807]H;P0>07aI;`1mFS00OEX`07iK<@1mFS00NeP^07UF;01gE2X0M5<X07ED:@1gE2X0NUD[
07aG;@1nEbh3085G;`0608=N<@24Gc80QF0c08IQ=027HSD0RF@g0P2:ICP02027I2h0Qf<_08QT<029
IC<0RVHf08aW>P2<Ic/0SFPl0`24Gc8308EP<`80QV4d00P0QV0a08MQ<P28HS<0RF<d08YT=@2;ICH0
S6Hg08eW>0@0SVPi0P2=IcP208aV=`80R6<f0P27HSD02@26HC@0QF0c08AO<P24Gc80PUh^08=O;`24
H300QV8b08MS<`0208QT=00908UU=@2@K3`0SVXj08aX>02;IcL0RVHf08]W=`2=JCT0SVXj0080O5le
00<0Nehd07YM<`1iG3800P1hFc40101gFS00NePb07]H<P1kF38[ooooo`00:_ooool80:9iA@H0Y7Y8
0P2UNdT0202UNd40YGY30:IkAP2VNdP0Yg]<0:MjD02WNU40Z7]D102VODT40:ElB0@0XGQ40`2RNDD0
102SNTH0Y7]70:AkA`2TNdL20:=jAP<0XWU500H0Y7]70:ElB02UO4P0YWe90:MnBP2XOd/20:V0C080
Y7Y800<0Y7]70:AkA@2TNd<00P2TO4400`2TO3l0YWe90:ImB@060:ImB@T0Ygi:2`2YP4`20:QoB`<0
Ygi:00d0ZH1<0:QoB`2WOTX0YGa80:=jAP2RNDD0XGQ40:1g@`2ONTH0WGQ409]f@P2HLcl0UW4m00<0
UG0l00@0UV/n09AY?02BIcX0T6Dh0P2?I3L0402@ICP0TFHi08MQ<P28HS<0RV@e08]U=P2:I3D0RF<d
08MQ<P26H340QV4g08EP=P24GcD0Pehd089M<`20Fc4207mJ<080O5XZ00@0NeT[07]I;01jEbd0NEH^
0P1hEBl307AA:`<0Le0Z0P1bCbT08@1[CbL0JThV06Y=9@1/C2D0KT`V071=9`1bCbT0MU0[06iA:@1_
DRX0L5<[075D;01cERh0MEP`07II<@1gFS80NeLc07aH=01lFC<0OEXb07iK<@1oGC00P5ha081N<021
G2l0PUd`08=N<@26HC@0RF@g08]V>@2=J3/0SVTl08YT?@0208YU>`0308]V>P2;IST0S6Ph0080S6Pf
00<0RF<f08YT=`2<IST00P2=IcX0102<IST0RV@g08US=P2@HcT208mT>@0308iU>@2<IST0RfHi0080
RFLi00<0RF<d08]U=P2=IcP00P2?JCX00`2=IcP0RfDf08US=00308YT=`<0RfDh0P2<IST208aW<P<0
SFPc102>JC@308eW>080S6Hg0`2;ICH208QR<`0308US=02:I3D0RfDf0080SFLh00@0SVPi08IT=027
ICD0RFLg0`2;JCT00`29IcL0R6Hf08]U=P0308]U=P@0S6Hg00<0RfDf08YT=@29Hc@00P28HS<00`29
Hc@0RV@e08]U=P0808aX>0P0RVDh0`27HSD00`28HcH0RF@g08YU>00208YU>080RF@g0P28HcH01027
HSD0QV4d08IQ=026HC@808EP<`80Pf8_00H0PV0`089P<P21Gc80PEhd081M<`20GCD3081N<080Oed_
0`1nG2h06@1mFbd0OE/^07aJ;@1kF2h0NUL_07UF<01iEC40N5@`079J;01aFB/0L5T]06mH;P1]Ebh0
JUL_06QF;P1XES00JE8`06UB<P1WD300I4d^05m7:`1J@RP0ECdU058j8P1:>2000P1:>R402`19>b40
ASXP04<i7P0o>1`0?CHJ040d7P0o<ad0?C8N03Xb7`0h<Ah0=C0M0080<RlN00H0<B/O02l[7`0_:al0
;B/N02X[7@0Y:ad202L[700602HX6P0V:1/09BLJ02@V6`0S91`08R<M0`0Q8Qd2020S700401lR6`0N
8AX07B0I01`O60806ahG200N81d0100N8AX07B0I01dP6@0L7aP201/N5`806QdF0P0I6aP0100J71T0
6adJ01/M6P0L7Q/201dO700H01XK7@0K71h071hM01hP7@0P8Qd08B@M028U7P0S9Qd08b@L02@V6`0W
:Ah0:R`O02/]7`0[;Qd0:bhK02X]6P0c;b<0<RhR034]8@0^:Qh0:bLK02LS5`0T81@08QhB0P0O81P0
1`0P8AT08B8J028S6`0T9Ad09RLO02LX800U9Qh00P0T9Ad00`0S91`08R<K024R6P02020Q6@<07R4J
1@0O8Q/8020P7P807QlI00@07b0J020Q6`0R8ad08b@N0P0T9Al0600[9a`0;2PM02lY7@0^9Q/0;R@H
03HZ7012=RH0CD0`061=8P1`GS00QW1109AiBP2INT/0WGe<0:R4DP2`S5X0W7Db07QH9@1<>1d0<BXT
02h]<P0_<3@0:2TT01hN4P809BLT0`0T9R<302<U8PP092HS200W:28A02PY8`0>02HX8`0W:B@0:BXT
02/[8`0_;2<0<BdR038^8`0e;b<0>2lN03/b8@11=R@0ACXV04Tm9`1<?BP204dm9P0304hn901??bD0
D40V0080D40V00h0CShT04`l8P1;>b40A3TU04Hk9`1:?b/0CD8^04m4<01>@bl0CD8^04a1;@1=?2X0
C3/Y04/j:080BSTW0`19>2H01P19?BL0B3`V04Hi9P14=bH0@cHU04<f9P80A3HY01P0ACHS04Lh8`1<
>bL0DClY05=1:@1F@RT0ET4V05E09@1J?bX0FD0Z05Ln:01C?BH0D3`T04`j8P1:>R40BCTP04Th9P1;
>RP0CC`Z04hm:`1??R`0CSd[04`k:@1;>RP2044i8P04044i9011>BH0@CTV044h9`80@CPY0P11=BT0
1P10=2P0?c<W03da9@0l<2@0>blS03X^8P80=bdT00<0>2hU03T_9P0j<2L00P0k<BP02P0l<RT0>SP[
03Tg:P0h=RT0=S@W03@b9@0b<2<0<2hQ02l]800/;R0202d_8@0302h`8P0_<B<0;c4S0080<38T00@0
=S8V03Da9@0e<BD0=C4U100d<2@01P0d;R80=blR03Xb9@0n=BH0@SHV04@g9P80ACHS0100D40W05=1
:@1EA2P0FdPX061<:@1UCbX0JE8Y06YC:P1ZES<0K5Pc06mI=01bFS@0LeXb07AH<01bEb`0LUD[0P1b
G2/03`1cFbd0Me`_07aL<`1oGCL0QElk08MN?P2:Gcl0UfX_09Y/<@2NL3@0Y7@f0:Qf=`2ZMcH0[7Hf
0:ag=@020:Z3=P0I0:Z3>02YPC/0Z7lm0:Qo@@2XOT80Yge30:61AP2QPDP0X85809n2BP2KP4T0Ugi8
099kA`2ANTH0V74j09Ub>`2IM3l0VGE109Ue@`2FMD80Tg=2095a@02FLT00UG4o09A`?P02099^?009
09=_?@2DL3h0UG4o08m[=`2;JSL0QfHc085Q<01mGRl0NUh_0080NEha0P20Gc@01P1oGS<0OUdb07mN
<`21H3D0Pf8g08AS>080PV8a0P23Hc807`24I3<0QFDd08EU=026ISD0R6<i08MR>022HCH0Of0d07YO
<P1eGc00Leh_071N;P1dEb/0MEP/07MJ;P1iG300O5lc07iQ=@20HcL0PF@h07MR:`1iI2d0OF<`081T
=024HcH0QV4g08IO=P27GCL0PV8a08=S<P25IC@00P26ISD07025IC@0Pf<b089R<@20GS00PV0b089R
<`22Hc@0Of<c07aP<01hGRd0MU`[07US=01cGBh0KUL[06eF;01_F2l0KUH`06UA:`1TC2P0ITh/06Q@
;P1[Dc40KEDc06aD<P1YDBl0IDd[069::01^DC4306e@<080K4l_0P1[CRh00`1`Dc40Ke8`06mB<002
06iA;`0306e@;P1^DBl0KU4_00<0K5@`0P1]EC4306iF<P0I07=H;@1dFBh0M5T^07IK<01hGC80NUld
07aQ=P1mHSL0OV<h07]K:01lG2T0O5h/07]O;`1iGRl0MEd_07=K;@1`FBd0KUHb06QF<01RERh0G5D[
05]B:@1QCbT0J4/Y06a9:@0206I=;P0406I>;01VCRX0IDdY06E=9`80IDhU00P0HE8W069C:01UERd0
IUL`06EF;`1RDRh0Gdl]05a<:P80Cd@T00@0CT<S04e28P1;@200BSlO0P19?Qh0201;@200C44Q04a1
8@1=@R80C44Q04Xo7`18?Ad0Ac`L0`19@2<01@18?b80AchQ04Ln8@17?R40ASdP00<0@c`P0P12>al3
044j7P0804@m8`13?280@S/Q040i7`0o>1h0?CHL03`e6`0k=1X203Xf6`@0>cLL0P0l>1d203Hd7`04
03Dc7P0d<Qd0=38M03<a7080<S0K0200=c@Q03Hc800h<al0>38L03Xb6`0n=1/0@SHN04<g7@18>R00
Bc/Q058o8@1L@b@0IdTU075@9`1iE2P0OELZ07aL:@1iFBP0LeLW06mG:@1]ER`0I54Y05M88@1@@1`0
>S@J03Ha6`0b;AT0:bPI02HS6P0R8A`07alM01lO7`P06adJ200I6aP801XL6@T06adL200K7AX801`L
6P806Q`I0P0I6aP201PJ5`805aTF6`0G6AP201HH5`<05ALF0P0I6aX201PJ6@0401LI600F61L05QPG
01DG5Q005QPG0`0E5aH201HH5`<05aTH200F61L801LI60805QPG0`0G6AP301PJ6@P06A/J0P0G6AP2
01PJ6@806A/J1@0J71/201/M70<071hM200K7AX901`L6P807AdK0P0N7Q`201lO7@80820N0`0Q81/2
028Q70<08b8M00<08B4I028R6P0T91`00P0U9Ad00`0T91`08R8J024Q6@0402PT6`80:BDL2P0Z9Qd2
02/W6`@0:RHJ0P0Y9AT202dY7@0402lY7@0`:1d0<RPN03@W7P80=RPO0`0g;1X203P]6`<0>BhL00P0
<R`N038Z7@0a:A`0<BLK03@X700h:Ql0?2/Q03h]8`80?S4P0`0m<1l303`_7P<0@S4O0P13<R0304@c
8@80A38L00@0AC<M04Hd7P18=R00BCLQ0P1:>28204/f8@0604/g7`1<>1l0CCTN04dj701=>QX0CS/K
0P1D?b801P1F?R80EcdR05Tn8`1K?B<0G3hT05dm9080GT4S0P1O@R@01@1P@bD0HD@V06549P1RABL0
Ec`Q0080F3dR00<0FChS05Xo901J?b@00P1K@2D805hn9@<0FClT0P1J@2D305]19P0405hn9@1M?bD0
GT0V05a19P80G48W00<0Fd<W05U49`1JABP00P1LA200101MAB40GTHR05i68P1OAb<20618900:05e4
9P1NABL0H4LY0699:`1QB2X0GdHX05a39@1J@B<0GDDQ05a48080FT8N00D0Fd<O05e58@1OAb<0HDTU
0692:@0306=3:P050692:@1P@2L0GCdT05`l8`1L?2L00P1J>bH00`1H?2H0ES`U05Dm9@02058l9080
Ec`Q00@0F3dR05Tn8`1K@2D0G44V0P1M@RL206=0:P0606A2:@1U@bP0ID<W06E49@1T@b@0I4<R0P1U
@R@306I39@<0Id@V201VBBT306A88`0606E9901VBRD0JDdX06a@:`1^DRd0M4hY0P1eCbX00`1fD2/0
Me4/07MA;00207QB;@80NEH^00<0NUL_07]H<01lFC400P1mFS801P1nFc<0NUHb07aH=01oG3H0PEhf
08=P=P80Pf4d00L0Pf4c08ES<`24HS80PV0b081N<@1oG380P5de0080PEhh0P25ISX03P24ICT0Pf@h
085R=P20HCD0Of0d07iO<`24Gc80P5/^07eH:`1oFRd0Peha08EP<`22GC00OEP[0P1jGC400`1iG300
N5/_07QK;`0307QK;`<0OU/a00<0OEX`07aI;`1kF2h00P1kF2h407]M:`D0O5h/101jF2X407UG:@P0
O5Ta0P1mFbd307aJ;0<0NeT[00@0OU/c07aI<@1iERh0Me@/0P1fDb/0:`1gE2`0N5D]07iO<01iFR`0
MULY07MH;01kFc80OEdf07UI<`1dE2h0M54W07QE:`1kF2h0NUL]07MD:P1hEB/0OU/a08AQ=`1nFcD0
O5Tc07YG<@1iES00N5D_07UF<01jEc40NePb075I;@1`F2`0LEH[079E:`1eEB`0N5L^07]J<@1nFc<0
OELb07eJ=01oG3H0Oedg07aL=@1gFS80LED]06iB:P1gEc000`1fERl207EE;P80M5@]01P0MUH_07MG
<01hF340NETb07QH<@1gEc00MED^07AD;@1]CR80Ke0T079C9`1dEBT0MEHZ07AE:@1bDbL0LE8V07YC
;01iDR/0Me4Z07AA:@1bDBP0L50W06m?9P1]D2H3079B:`<0Le</0P1dE2d307aG;@0307]F;01jEB/0
NE@Z0080NE@Z00<0N5<Y07YE:`1lEbd00P1nFBl00`1mF2h0O5L]07]F;00807]E:080O5D^00<0NeD^
07UF;P1hEbh00P1gEbh00`1eF2h0NEH^07QE;@0207IC:`0A07MD;01iERh0O5Ta07aI<@1mFS80PUd`
08AO<P25H3<0QV4d08MR=@26HC@0Q5lb08=N<@22GC00Q5lb08IQ=028HcH00P29I3L01@27HSD0QV4d
08QT=028I3@0Qf<c0080QV8b00<0QF4a08AP<024H3000P2<HcL0102;ICP0RVDh08YU>029IcT208QX
>@<0R6<i0`27HSP208IQ=`0308AQ>@23H3P0PUlg0080PEhf00T0PUlg08=P>024HCT0PU`e089M<`24
GcD0QF0d08MR=@28I3@00P2:IS@01P2=IcX0S6Hi08]U>02:I3L0RF<f08MQ=080QV0c00@0OU/c07eJ
<P1mFS80OEXb0P1lFC4207]H<0<0OeX]:oooool002[ooooo202QN4@20:EkB@@0Y7Y80P2SNDL20:Ej
@`040:IkAP2VNTT0Yg]<0:MjD080YgYA0`2VODT=0:ElB0P0XgY60`2VODT30:MnBP80Z7m;0P2TNTP0
0`2TNdL0Y7]50:Ak@`020:Al@@030:Al?`2VODT0YWe900l0YWe92`2YP4`20:QoB`<0Ygi:0P2XOd/0
2`2WOTX0YGa80:=jAP2RNDD0XGQ40:1g@`2ONTH0WWU509]f@P2HLcl0UW4m0080UG0l00D0UW4m09I[
?P2EJSd0TfPk095V>@02091U>080TFHi00P0Qf4b08QR<`2:I3D0RfDf08YT=@29Hc@0Qf4b08IP<@80
QV4g00@0QF0f08=N=022GC<0P5/a0P1oFS001P1mFb/0O5XZ07aJ;01kFB`0NUL]07UF;P80N5D_00@0
MU<]07EB;01eDR`0ME8/0P1dDB/207=@:P0@06a@:01[CbL0JdhV06a<9@1^C2H0LDhX07=@:P1fD2/0
KU4Y06mB:P1`Db/0LE@/07=F;P1dEbl0MEP`07II<@80NeLc00<0O5Tc07eJ<P1nFc400P1oGC002P20
GS00PUd`08=N<@24Gc80QV4d08QS=P2:ICP0RfHi08aW>P2:I3d208YU>`0308]V>P2;IST0RfLg0080
S6Pf00<0RF<f08YT=`2<IST00P2=IcX0102<IST0RV@g08US=P2@HcT208mT>@0308iU>@2<IST0RfHi
0080RFLi0P2;ICH408eW>080RfDf0`2:I3L308]U>080S6Hi0P2<Ic<308eX=0@0SVTe0`2=IcP208aV
=`<0RfDf00D0R68c08US=029Hc@0RV@e08aV=`0208eW>00408iX>@26I3@0QfDe08UW=`80RfTi00<0
RVPh08UW=`28ISH0102<ISL408eW>00308iX>@2=IcP0S6Hg0080RfDf00<0S6Hg08eW>02>J3T0202<
J3P808YU>080Qf8e0P28HcH208UT=`80RVDh0`28HcH508MR=@P0QF0c0P23HRl01P22H300PV0b085O
<P21GS@0P5dc081M=@<0P5h`0P1oGBl407iL;P0?07iL;`1mFbh0O5T_07]H<01jEc40NUHb07UE<@1d
FB`0LUX/075I;@1_F2h0KEL^06YG;`1XERh0J5H`0080JE8`00h0Ie0`06A=;P1OAb/0FT8X05Hn901C
>b<0BcTQ04Xj8@1;>b80BS`R04Lk8@13>Ah0?cPL03df6P80@3@N00@0?S<O03Xb7`0h<Ah0=C0M0P0b
;ah01P0b;200;b/O02l[7`0]:ah0:R/M02T[7@809b/L00H09RPJ02HX6`0U9aX092HK02<T700R8ad2
028S7P06024R7@0P8a`082<L01lR6`0N8AX07B0I0P0L7aP00`0K7QL07R0M01hP7@0601hP7@0301lR
6`0N8AX07R4J00807B0I0P0L7aP0100K7QL06A/H01XL6@0J71T201/M6P8071hK01407AlL01XK7@0K
71h071hM01hP7@0O8A`08B@M028U7P0S9Qd08b@L02@V6`0W:Ah0:B/N02/]7`0[;Qd0:bhK02X]6P03
030/800;02l[7`0]:Ad0:BDI02DQ5@0S7a<07QlG01lP600P8AT08R<K02@U7@0U9Qh00P0V9al202DV
7P0402@U7@0S91`08R<K024R6P80824I0P0N8AX601lR6`P0820N0P0N7aT07P0O81X0824K024R700R
8ad08b@N02@U7`0Y9Qd0;2PM02dY7P0^:1`0;RHI03@[700o<b<0Ac/[05I56P1XEBX0OVTl08ifB02E
NDX0Vg]<0::0D02ZQU@0Z89308QX=`1MB2/0?38X02d/:P0[:b/0:RTT02TW6`<09BLT0P0T9R<302<U
8PP092HS200W:28A02PY8`0>02HX8`0W:B@0:BXT02/[8`0_;2<0<BdR038^8`0d;R80=c0P03Xa800n
=B@0A3TW04Pk:01;?2L204dm9P0304hn901??bD0D40V0080D40V00L0CShT04`l8P1;>b40AS/W04Ll
:019?RX0BSl[00@0Bd0/0P1<>bT204/j:080BSTW0P19>2H01P19?BL0B3`V04Hi9P14=bH0@cHU04<f
9P80A3HY01<0ASLT04Pi9P1;>RH0CcdW054o9`1D@2L0ET0X05I19P1J?bX0F3lY05Ln:01C?BH0DCdU
04dk8`1;>b80BSXQ04Th9P1:>BL0C3/Y00<0CC`Z00D0BcXX04Xi9`13>b@0@SXS048j9@02044i9P03
040g9P10=bP0@3LX0080@3@X0P0o<bL0100n<RH0?C4U03``900l<2@403T_9P<0>S0W00T0>c4X03Pf
:@0g=BP0=S@W03Dc9P0c<B@0<S0S034_8P0`;R400P0];R0202h_8@0402l`8P0`<B<0<34S030a8`80
<blS1P0d<2@0600d;R80=blR03Xb9@0n=BH0@SHV04@g9P16=b@0ACHS054o9`1C@RP0F4@Y05a7:01R
BbT0IU0Y06YC:P1[E2X0JED`06aF<@1_FC80LU/b07AK<P1fFS80MeX`07II;`80Mf0^00d0NEh_07]O
<01nGc<0PEhf08EO>P26GS/0REhl099X;P2GJS40VVdb0:1b=P2UMCL0Z7Hg0080ZWLf0P2XPCH0102X
P3P0Z80k0:Mn?02WOT020:Mm@@0E0:1m@`2NOT<0Wgm609ioB02KOTH0Uga509=jA02BND<0WWLn09mh
@@2NND80WW]509ijAP2JNDH0V7Q709IfA@2IMD<0Ug=109Ea?`2CKcd0TVhl0080Tflm00/0U70n095]
>@2=K3L0RFPe08AT<`1oH340Nel`07YO<01iGS40Pf8g089Q=P03085P=@0308=R=`25I3T0QVDj0080
PF4`0P22HS407`23Hc80Q6@c08AT<`24I3<0R6<i08ER>023HSL0P64e07]P<`1gGc40M5h_079M;P1d
Eb/0MEP/07MJ;P1iG300Nehb07eP=01oHSH0P6<g07IQ:P1hHBd0O68_07iR<P21H3<0PEhd08=L=@22
Fc@0Oel`081P<@22HS<00P23Hc@00`22HS<0P60a07mO<00208AR=@0A089Q=01oH380Nel`07ML;@1d
FBX0L5PX07QR<`1cGBh0KeP/06iG;@1_F2l0KeLa06YB;01VCRX0Idl]06UA;`1/E3800P1]EC<00`1Z
DS00ITh/06A<:P0306iA<@80KE0`0`1/Cbl806iB;@0406aD;P1]EBl0KED_06eE;`80KUH`0P1_Ec43
07EJ;`0407IK<01hGC80NEhc07]P=@80O64f0100Ne/X07]M:`1lGR`0NUh^07QM;P1eGBl0LEX^071I
;@1^ES80J5H`065E;@1LEB/0Fe8Y065?:@1XBbT0KDXZ0P1UCRh0101UCR`0IDlZ06A>:@1TCRL206A>
9@0>065B9`1RDbP0I5D/06EF;`1TEBh0HE4]05e=:`1KBbT0D4DU04m4901>@b<0CD8R04a18@1;@202
04Xo7`0804]0801<@B40CD8R04i38`1=@R80Bd0P04Tn7P18?Ad204Y1900404U08`18?b80AchQ04Hm
8080AC`O0P13?203048k7`<0@CXN00P0A3dS04<l8P12>b40@3TO03lh7P0m=Q`0?3DK03/d6PP0>cLL
00<0=S@O03Dc7P0e<ah00P0d<Qd203<a700Q038`6`0g=240=S<P03Lb7P0h<Q`0>S8K03hd6`11=Ad0
@cLM04Ti801;>b40DSlQ05a3901UBB@0KThW07AA9`1hDbL0MELU079C901[D2<0Ie0T069?9@1KBB<0
CT0K04Li5P0g<Q`0=C0J02l/6@0Z9QX09R<J024P6`0O7ad07alO00P06adJ200I6aP801XL6@T06adL
200K7AX801`L6P806Q`I0P0I6aP201PJ5`805aTF6`0G6AP201HH5`<05ALF0P0I6aX201PJ6@0301LI
600F61L05QPG01405QPG0`0E5aH201HH5`<05aTH200F61L801LI60805QPG0`0G6AP301PJ6@P06A/J
0P0G6AP201PJ6@806A/J1@0J71/301/M708071hM200K7AX901`L6P807AdK0P0N7Q`201lO7@80820N
0`0Q81/3028Q70808b8M00<08B4I028R6P0T91`00P0U9Ad0100T91`08R8J024Q6@0W8aX302PT6`80
:BDL2P0Z9Qd802XV6P0602`X700]:Ad0;bTM030X7@0b:1h0=2LN0P0f:1l0100e:AT0=RXJ03HZ6P0f
:QX203L[6`80>2`L00P0<R`N038Z7@0a:A`0<RPL03DY7@0h:Ql0?2/Q03d/8P@0>bhM100l;ah3048a
7`<0@c8P0P14<b401@13<A/0A38L04@b7015<ad0AcDO0080B3HP00L0BCLQ04Xe801:=B00BcLO04`h
7`1=>Ah0CS/M0080Cc`L00T0DchQ05@o8P1F?R80EcdR05Tn8`1K?B<0G3hT05dm901M@2800P1N@B<2
05m29080H4<U00@0HD@V05Pm8P1I?R<0FChS0P1J?b@205]09@0305a19P1M?bD0GClU00H0GClU0`1I
?b@205Y09@<0Fd4V00@0GShU05do9@1M?bD0G44V0P1K@BH00`1K@bL0FD@W05U49`0305a48P0305e5
8`1NAR@0GTHT0080GdLU0P1MA2H305i59`0605e49P1K@R@0FT4S05e58`1LA280Fd<Q0P1J@R00101L
A280GTHT05m79@1P@RP30653:@050612:01N@2H0G3hT05Xl8P1K>bH00P1J>bH00`1H?2H0ES`U05Dm
9@02058l9080Ec`Q00@0F3dR05Tn8`1J?b@0Fd0U0P1L@BH206=0:P0606=1:01S@BH0Hd4U06A3901U
A2D0ID@S0`1U@R@206I39@<0Id@V0P1WBRX206I9:@80IDPX0P1TAbL306A88`0606E9901WBbH0JDdX
06a@:`1^DRd0Le0Z0P1dDB/207EB;080MU<]00L0Me@^07QE;@1iERh0NEH^07YG;`1kF300O5Ta0080
OEXb00D0NUHb07aH=01nFcD0PEhf08=P=P0208=Q=00:089P<P25Hc<0Pf4a085O<@20GS40Oe`b07mL
=020GCL0PEhh08AU>@80Pf@h00d0PV<g085R=P20HCD0P64e07mP=023HC@0Oed`07]I;01lFRd0P5ha
085O<P1nG2l0NUP[00<0Ne``0P1jFbl307UJ;P80OU/a0P1mFS001@1lFBl0NeP^07]H;P1kF2h0NU`Z
00P0Ned[0P1hERT607ME:0@0O5Ta101mFS8307eK;P80O5X]0`1kFB`0501lFC40NUL_07QE;@1gE2`0
MU<[07MD;01hEBd0NEH^07eN;`1iFR`0MULY07MH;01jFS40Ne/d07QH<P1dE2h0LTlU07EB:01gE2X0
MU<Y0P1dDBL06P1jEbd0Oe`b07aI<`1kF380NEH`07QE;`1gE2h0N5D_07UF<01jEc40L5P/079G;01a
ER/0LUD[07IF;@1iF2l0OEXb07iK<`1mEc80O5Tc07iK=@1nG3H0O5`e07II<@1aEBd0KU8Z0`1fERl2
07EE;P<0M5@]0P1fERl307QH<@0307IF;`1dE2d0Le</0080Ke0T00@0LE8V079C9`1cE2P0Le@X0P1b
DbL207UA;@0707MA;01dDB/0LU0Z071@:@1_CbP0K4lW071@:@02075A:P03079B:`1cDb`0Le</0080
M5@]0P1iER`207QE:`80Me@Z0`1fDbT00`1gE2X0NEH/07]H;P0207]H;P0307UF;01hEB/0O5DZ00L0
O5DZ0P1kE2d00`1jE2d0N5D]07MF;@0207IF;@0707AG;@1hEBd0Me@/07MD;01fDb/0Me@/07UF;P02
07aI<@0407eJ<P22GC00Peha08EP<`80QV4d00/0QF0c08AO<P23GS40PUd`08=N<@25H3<0Qf8e08QS
=P27HSD0QV4d08EP<`0208MS<`<0QV8b0`25HC4208]R=P0408US=P29I3L0RF@g08QV>080QfLh00@0
RF@j08QS>@28HcT0Qf8h0P26HCL208EP=P0308AQ>@23H3P0PEhf0080P5de00/0PEhf08=P>024HCT0
PU`e089M<`23GS@0QF0d08MR=@28I3@0RFDc08YV=00208aV>@0608]U>029HcH0R68e08MQ=026H3<0
QElb101mFS8207aI<@80NeP`0`1nFBd[ooooo`00:_ooool80:1g@`040:IlBP2UNdT0YG]90:AjB080
XgU70P2RN4H20:EjA@040:EjA`2VNTT0YWY;0:MkCP80YgY@202UO4P01@2ZPDd0ZH1<0:V0C02XOd/0
Ygi:0080YWe900H0YGa80:5hA02RNDD0XWU50:=jAP2TNdL20:ElB0030:ImB@2XOd/0Z7m;00<0Ygi:
0`2VODT20:EkB@030:ElB02UO4H0YGa40080YGe200<0YGe00:ImB@2VODT01P2VODT90:ElB0/0ZH1<
0P2XOd/30:MnBP060:QoB`2WOTX0YWe90:ElB02TNdL0XWU50P2QN4@0102PNdL0WWU509]f@P2HLcl4
09Ia?@0509M/?`2EJSd0TfPk095V>@2@ICP00P2AIST00`2BIcX0RF<d08US=00308YT=@0308US=027
HC80QV0a0080QV4g00H0QF0f08AO=@22GC<0PE`b081K<@1oFS0207eK:`0507aJ;01kFB`0NUL]07UF
;P1iES000P1hEBl307MD;P80MU<]0P1eDR`03P1]DBT0K50X06a?9`1]CBH0KddW075>:01cD2X0MU0[
06iA:@1_DRX0L5<[075D;01bEBd0M5L_0P1eF3002@1jES80NeLc07]H<P1lFC40OEX`07iL;`1oGC00
Oed_08AO<P0208EP<`0308IQ=027HSD0R6<f0080RF@g00/0RF<l08UT>P2:IC/0RVDi08]V>@2;IcL0
RfLe08aX=P2:I3L0RfDh08aV>@0208eW>P0408aV>@2;ICP0RV@g091S>@80Sf@i00<0SVDi08aV>@2;
IST00P29IcT208eW>0@0RfDf0P2=IcP308YT=`<0RfDh0P2<IST208aW<`<0SFPd102>JCD308eW>080
S6Hg0`2;ICH208US=00308YT=@2;ICH0S6Hg0080SFLh00H0SVPi08UU=@29ICD0RfLg08aX>02=JCT2
08aX>00308]W=`2>J3T0SVPi00H0SVPi00<0TF/l091Z>`2>J3T00P2=IcP00`2>J3T0T6Xk095[?008
08aX>0P0RVDh00@0Qf8e08QS=P28HcH0R6<f0`29I3L00`2:ICP0QV4d08MR=@0308MR=@<0R6<f2025
H3<208=R;`06089P<022H380PElb085N=020GC<0P5de0`20GS0207mM;`<0OU`^00H0P5h`07mM<01o
GC00OU/a07eJ<P1lFC<207]G<`0A07EH;01dFB`0LeP]071G;P1^Ebh0K5H_06YG;`1YEC00JU@_06UB
<01WD2h0IDh^0619:P1K@bL0EclU05@l8P1<>R800P1<?2<01@1;?B<0Ac/Q04@j7`0o>1`0?SLK0080
@3@N01@0?S<O03/c800h<Ah0=S4N03<`7`0b;ah0<R`P030/800_:al0;B/N02X[7@0X:Q`09b/L02HZ
6`0V:1X09RPK02DW6P0U9a`092DM02<T7P<08R<N0P0P8a`201lR6`0401hQ6P0M81T071lH01`O60P0
7R0M0P0P8a`301lR6`<07R4J0`0J71T201/M6P<071hK0P0K71h06P0L7Qd07AlL01lQ700P8a`08B@M
028U700S91`092HK02HX7@0X:Qd0:R`N02/^7@0[;Q/0:RdJ02`X700^:Qh0<2`P034]8@0`;200;2PL
02LS5`0T81@07AhF01lP600R8a/09BHN0P0V9al01`0U9Qh092DM02DV7P0U9Qh092DM02<T700R8a/0
0P0Q8QX00`0P8AT07b8K01lR6`0601lR6`P0820N0P0N7aT00`0O81X0824K024R7002028S7@0J02<T
7P0X9Ah0:RLN02dY800_:1h0<2PM03@Z7P0i<240?c<U04Xh501LBR@0MV0i08Q_AP2AMTT0UgQ909ek
B`2QP4d0/XiB09anC01hHCl0DT<`03D/8`0Z9Al0;BTP038^8P0V:2D302DW908092HS0P0S9B8802@V
8`P09bPR4@0X:B<202HX8`0<02PY8`0[:b<0;R/R034]8P0b;R<0=2hR03H`800i<R80?3DS040h9@15
>RP0B3/X0P1;?2L00`1>?RD0CclV05109`0205109`0604hn9@1<?2<0Bc/R04Tn:P18?BT0Ac`X0P16
>bL00`17?2P0B3dY04Tn:P0504/j:00904Xi9`19>2H0BCPV04Tm9`18?2H0ASTV04@g9P13=RD0@cHV
0080A3HY01<0BCTY04Tj9`1:>BL0C3XV04hl9P1B?RH0ET0X05M1:@1I?RT0F3lY05Ln:01C?BH0DCdU
04hl901<?2<0Bc/R04Th9P1:>BL0BcXX0080C3/Y00<0BcXX04Xi9`19>2H00P17?2H01P16>bL0ACXX
04<h9P12=RH0@CDW040d9PP0?c<W100k<BL303X`9P0303T_9@0f<RH0=S8V0080=C4U0P0d<2@203<_
8`80;BhP0`0^;b4302l`8P05030/800a;B40<BdQ038^8P0c;b<00P0d<2@01`0e<BD0=BlS03P`8`0j
<RD0?SDV048f9P14=bH00P16=b@03P1B@BL0ED4V05Q59`1NBRT0I4hY06UA:`1]E2/0KeH]06YD;`1/
ERl0L5Pb07AK<`1hG3@0Nehd0P1nGc<3081T<P04089S=023HSD0Pf0f08EO>080QUhj00P0SF@/091W
;`2DJS00Vfhc0:1b=P2UMCL0YgDh0:Qf=`80YGdg00<0YGdh0:El>P2UO3`00P2UO3h05@2UNcl0Wg/m
0:1l@02POT40WWi309amA02IO4@0UgU309Ai@P2TOD@0YGi50:AoB02SP4X0XWm909mnB@2MODX0W7a9
09eiA@2KMd<0V7A009Ea?@0409=_>`0A09Eb?02AL3/0SF`g08QX=@23IC<0Of<c07aQ<P1kH340Q6Di
08=T>022HcL0PF8f089S=`23I3P0QFHj08IW>`1oH3400`20HC83085R<`0L089S=025I3T0Q6<h089S
=`1nHCD0Nf0c07QP<P1fGS00MEl`07EH;01fFBd0MeX^07UL<01jGC40O5lc07eP=01nHCD0MU`Y07MM
:P1jGRh0OEh`07iM<P1nFc<0O5Tc07eG<P1iFRh0NU/_07aM<@80OEhb0180O5da07YK;`1iFRh0QF@i
08=R=`1nGc<0NE``07AI;01`F2X0KUHX06eG:01fH340Led^071I;@1_F2h0L5T`06mG<@1/E2h206UA
;@0706]C;`1]EC40KeLc06iF<P1/E300JE4]06M?:`02071C<@80Ke8`0P1^DBl206e@;P80K50[00<0
KE4/06iB;@1_Dbh00`1`E2l0101]EBl0KUH`06iF<01^ES0206mG<@80L5Pb101gG34207QM<P80NEhc
0140NUld07YL:P1jG2X0NEd]07QM;P1eGBl0LU/_06mJ;`1^FBh0KEDa06ME;`1QEBd0Fe@Z05]B:@1Q
CbT0J4/Y06e::P0206A=;@0406A=:`1TCRT0IDlZ06E?:080IDlV00P0HE8W069C:01TEB`0IEH_06=D
;@1PD2`0G4`Z05U99`80D4DU00@0Cd@T04i38`1=@R80CD8R0`1<@B401`1=@R80CT<S04m4901>@b<0
CD8R04]0801:?al00P1<@bH01`1:@B@0BD0S04Ln8@15?1l0A3/N04<j7@13?2000`12>al2044j7P80
@3TM00P0@c`R048k8@11>R00@3TO03lh7P0n=ad0?CHL03`e6`P0>cLL0`0e<ah203@b7@<0<c4L0200
=c@Q03Hc800g<Qh0>38L03Xb6`0n=1/0@CDM048f7018>1h0C3/Q058o8@1J@b<0HDLT06Q:9P1]CBH0
L4lV06]@8`1UCB40GdPN05Y77`1DA200CChM044f5P0j;a40=2lK030]6P0/:AX09bDH028R6P0O81X0
7AlL01dO7PP06Q`I400I6aP901XL6`P06Q`I200L71X201XL6@806A/H0P0H6QL201LI5Q/05aTH0P0F
61L301DG5P<061XI0`0G6APB01HH5`<05ALF0P0F61L301LI60P05QPG200G6AP201HH5`<05aTH0`0H
6QT801TK6P805aTH0P0H6QT201TK6P806Q`K0P0I6aX201XL6`<06adL00<071hM01XL6@0J71T01P0J
71T901`L6P807AdK0P0N7Q`201lO7@80820N0P0P7aX2024P6`<08R4L00@08b8M024Q6@0R8QX08b<K
0P0T91`00`0S8a/08R8J024Q6@0302LS6P80:2@K2`0Y9A`802XV6P80;2PL00@0;RPL030X7@0a9ad0
=2LN0P0e9ah203<W5`80=2PH0`0e:AT02@0f:QX0<B/M034Y700a:A`0<RPL03DY7@0h:Ql0>bXP03`[
8@0303P[6P0303T/6`0j;A`0>bhM0080?2lN0P11<1h2048a7`<0@c8P00H0A3<Q048`6P13<A/0@c4K
04@b7015<ad204Hd7P0904Le7`18<ah0B3<N04Xf7P1;=ah0CCTN04ll7P1@?Ad0DChN0080DchQ00<0
ECdQ05Lm8P1H?B800P1K?B<0101L?2<0GClS05do8`1M?b<205i090<0Gd4U0`1I?b@305Y09@80Fd4V
201L?R@305Pn8`80FClT0`1J@2D0101M?B@0G3hT05do9@1K@2D205]19P0305Y29P1H@bH0FD@W0080
Fd<Q0P1LA28405e58`0305e49P1L@bD0FT4S00<0FD0R0P1J@B<00`1MAB<0G4@R05]38@0305Y28080
Fd<Q0P1O@BL20612:00505m19`1N@2H0FcdS05Xl8P1K>bH00P1J>bH00`1G>bD0ES`U05@l9002058l
9080ES`Q0P1G?B803@1H?R<0FClT05Y09@1J@2D0HT8[0651:P1O?bH0GSlS05m08`1Q@R<0Hd@U06E7
9@1S@R<00`1T@b@206E49@80ITDV0P1XBb/01`1WBRX0ITTY06A79`1SARH0HTDU0654901UBB@00P1T
B2<01@1UBB@0Id/V06Y>:@1]DB`0KU8]00<0ME8/0`1fDbd207MD;P80N5D]00<0NEH^07YG;`1kF300
0P1lFC401P1mFS80NUHb07aH=01nFcD0PEhf089O=@80PV0c00T0PEla08=Q<@22H300P5h`07mM<01n
Fc40Oe`d081M=`21GSP00P21HSH6081Q=@04089O=@1oG380O5T_07aI;`80OEX`00<0NUL]07MD:P1j
Fbl0101jFbl00`1iFRh0N5T]07QI;@0307eJ<080O5T_0`1kF2h407YK;0D0NEX[201fDbT01@1kF300
O5Ta07aI<@1mFS80OU/c00<0Oe`d0P1mFS0207aI;`<0NeP^00<0NUL]07QE;@1hEBd00`1gE2`06`1h
EBd0NUL_07]H<01kG2d0N5T[07IG:@1gF2`0NET`07UI<P1gEc40M5@^079?9`1dDBT0ME8Z07=@:01a
CRH0LTlW07EB:P1iERh0NULa07UF<01gE2h0MU<]07EB;01fDbd0Me@^07QE;`02075F:`0?079E:`1e
EB`0MeH]07]H<01mFS80P5Xc07aF<@1kF380OEXd07aJ=01jFS<0MEP`071D;01^DRX0MUH_00<0MED^
0P1dE2d207=C;00307AD;@1eEBh0MUH_0080MeL`00<0MED^07=C;01bDR/01@1`D2L00`1aDBP0LU8Y
079B:@0207Q@;00307I@:`1cD2X0LDlY0080KdlX00T0K4lW06i>9`1_CbP0KdlX075A:P1bDR/0Le</
07AD;@1eEBh0101fDb/207EB:P80M54Y00<0ME8Z07IC:`1hEBd00`1iERh207QE;@P0NeH/0P1kE2d0
0`1jE2d0N5D]07MF;@0207IF;@0307AG;@1hEBd0Me@/0080Me@/0100N5D]07YG;`1kF300NeP`07aI
<@20Fbh0PUd`08AO<P25H3<0QV4d08EP<`24Gc80Peha089M<023GS40Q5lb0`25H3<208AO<P0408AP
<025HC40QF4a08EQ<@@0QV8b00H0R5lc08UP=027HC@0QV4d08MR=@25HcD208EU=P80RF@j00@0R6<i
08MR>025H3H0Q5le0P23GS@00`22GcL0PEhf081M=@0207mL=00A081M=@21GSH0PUlg089L=@22GC<0
Pehd08EP=026HC@0Qf<c08QT<P29IC<0RVDh08UT=`28HcH0Qf8e08IQ=024Gc800P23GS4307eJ<P80
O5Ta0`1kF30307]F;2_ooooo000Zooooo`P0X7M300H0YWa:0:EkB@2UNdT0Y7Y80:=iA`2RN4H20:5g
A@040:AiAP2TN4L0YGU80:EiB080YWY;0P2WNd`40:AkA`@0YGa80P2YP4`0102XOd/0Ygi:0:ElB02T
NdL20:=jAP80XGQ400@0XWU50:=jAP2UO4P0YWe90P2WOTX20:V0C0030:QoB`2WOTX0YWe90080YGa8
00H0Y7]70:EkB@2UNdT0YGa80:ElAP2UO4@20:Em@P030:Em@02VODT0YWe900H0YWe92@2UO4P;0:V0
C080Z7m;1@2WOTX02`2VODT0YGa80:AkA`2SNTH0XWU50:5hA02PNdL0WWU509ag@`2IM400Ug8n00<0
UW4m00@0V6e009I[?P2DJC`0TVLj0P2AIST00`2BIcX0TfPk08]U=P0208]U=P0308YT=@29Hc@0R68c
0080Qf4b00H0Qf8h08IQ=`25H3H0Q5le08=N=021G382081K<@80OE/[00@0O5X/07]I;01kF2h0NUL_
1@1iES0207QE;`<0Me@^00h0KU8Z06eA:@1]D2P0KThW06m=9`1bCbT0Le0Z07I@:`1^DBT0Ke8Z071C
:`1aE2`0LUD]07=F;P80M5L_00P0NEDa07YF<P1jEc40NeP`07aI;`1mFbh0OU`_07iL;PD0QV4d0`27
HSD01P29Hc`0RF@j08UT>P2:ICT0RVDh08]W=`80RfLe00<0RfDh08aV>@2<IST0102<IST01`2;ICP0
T6<i08mT>@2?I3T0SVDi08aV>@2;IST00P29IcT00`2?JCX0SFLh08]U=P0208US=00308]U=P2=IcP0
SfTj00<0RV@g0`2;ICP208aV>@80S6He0`2=IcH408iX=`<0SFLh0P2<ISL308]U=P80RV@e0P2;ICH0
1@2<ISL0SFLh08eW>02=IcP0RV@e0080RfDf00<0S6Hg08eW>02=IcP00P2=IcP2091Z>`@0SfTj0P2>
J3T00`2@JS/0SfTj08eW>00208aV=`0308eW>02?JCX0T6Xk00P0RfLg202:ICP408QS=P@0RF@g0`26
HC@01@27HSD0R6<f08QS=P28HcH0RF@g00P0QF0c0P23HRl01P22H300PV0b085O<P21GS@0P5dc081M
=@<0P5h`0P1oGBl307iL;P06085O<@20GS40P5ha07mL<P1nFc<0OEXd0P1lF3@04@1fFBd0MEP/07AI
;P1cEbl0L5L_06iF<01/ERl0K5Ha06YD;@1YDbh0J58]06E>;01QBRX0GDHW05Q0901F?R80CS`T0080
CCdT00/0C3hT04Pl8P14>Ql0@3TM03hg6`11=Al0@3@N03hc7`0k<b00>C8O03Ha7P0203<`7`0>03<]
8@0a;B40<2`P02d[7P0Z:ad0:2XL02HZ6`0U:AX09bTK02LY700V:1/09BLL02@U7@0S91h3028S7P80
8B@M00@082<L01lR6`0N8AX07B0I0P0L7aP801hP7@<08B@M1@0P8a`801/M6P806a`N01l071hM01dO
700N81/07b8K020S700Q91/08b@L02@V6`0V:1d09bTL02T[7@0Z;A`0:RdJ02/^6`0Y9AT0;2PL030/
800c;b<0<RhR02l[7`0Z9QX09b<G01dN5P0O81P08b@L02HW7`0W:2009RLO02@U7@0S91`09RLO0080
9BHN00<092DM02<T700R8a/00P0Q8QX00`0P8a`07b8K01lR6`0201lR6`<07R4J200P81h00`0N7aT0
7b0J01lP6P02020Q6`808B8L01T08R<M02DU7@0W9al0:bPO02hZ8@0a:R00<RXO03@/7`0f;200@C0B
0551801[Ec@0P6Q208ebA`2CMdP0VWY909emBP2^SEL0YhUG091gC`1/FC/0AcPS02hU500]9AP0<bdQ
00809RPU0`0U9b@;02@V8`P09bPR4@0X:B<04P0U9b809RPS02PY8`0Z:R80;R/R030/8@0a;B80=2hR
03D_8@0g<B<0>S<S03df9011>BH0ACXX04Pk:019?BL0CShW04lo:0<0D40Y00/0CShW04`l9@1;>b@0
Bd0/04Tn:P16>bL0A3TU04<h9014>BD0AS/W04Ll:00204Xi9`0<04/j:01<>bT0C3/Y04/j:01:>BL0
BCPV04Tm9`18?2H0ASTV04@g9P13=RD0@cHV0P14=RT0401:>R/0BCTY04Th:019=RD0BcTU050k9P1E
?bP0Ed4Z05Pm:01G?RP0ESdW05@n9`1B?RH0CcdU04hn9@1=?B@504Xi9`80BCPV00T0B3LU04Xn:01:
?RP0B3/X04Lj:@15>2L0@cHV048d9`11<bH00`0o<bL3040d:080@CDY00H0?S@X03dc9`0m<bL0?38V
03/a9@0j<2@203T_8`D0=S0T0`0g<BD4030^8@@0<BlR0P0_:al0100`;200<BdQ03<_8`0d<2@203Da
9@0603La9@0i<B@0>S8U03dd9@11=BD0A3LV0P17>2D0401D@2D0Ed8W05Y59P1QBRP0Idl[06eD;01b
Eb`0M5T^06aD;P1]ERd0LEP`07MK<`1lGcD0PF8f08=T=P26ICP208YY=00508YY=P29J3D0R6Hf08QS
=P27HSH00P26HCL02`28Hbh0S6@`08mX<@2DJc<0VFle09ia=P2RM3T0XgDi0:1g=@2QN3H0XGPh0080
XWTi0P2SNS`02@2TNcd0Xg`k0:=m?P2UOd00Y8120:>1A02PP4D0WGi509amA0020:N0A@0;0:F1A`2T
PDT0Xh1:0:1oB@2NOdT0WGe:0:1mA`2NNdD0VgQ209Md?P2ELS`00`2CL3X02`2HMCd0UG@n099a>`2=
KSP0RF/g08AX=P20ISD0OfDd089U>@21I3P0P6<g0080Of8f00<0P6<g089U>@23ISX0201nHS<208AU
>@06085T>01oHSH0OF0d07]P<`1jGc80NEha0P1gFRh00`1hFbl0NE``07YM<@0207aO<`0<07eP=01f
FRX0Me/[07YK;@1kG300NUXa07UG<@1gEBl0MU@_07=F;01dEbd0MUT_0P1gFS001`1fFBl0M5L]07=F
;020HCD0OEhb07MJ;P1bEbX00P1^ERP03@1^F2T0KeTZ07=M;P1bG2d0LEX^071I;`1`FC00L5Pb06iF
<01]EC40K5@^06eE;`1_Ec400P1`F3800`1_Ec40KED_06]C;@04075E<080L5@_0P1_Dbh0101[CbP0
K50Y06iB:`1`E2d4079F;`<0KeP_0P1`FC03075J<@H0N5db0`1gG34207QL;00>07IK;01dG2h0LEX^
06mJ;`1^FBh0JeP^06aD<01VE2h0H5@/05]D:P1KDRT0HDlY06Q;:@1]BRX2069>;@04069>:`1RCRT0
HdlZ06=@:080He0V00P0HE8W069C:01SE2/0I5D^069C;01MCBT0FDTW05I69080D4DU0P1?A2@204i3
8`80CD8R00<0C44Q04e28P1>@b<00P1?A2@02`1>@b<0C44Q04]0801>ABP0CD@W04]29@19@2<0AchQ
04@k7P13>Qd0@STL00<0@S/O0P11>Qh3040i7@80@S/Q00@0@CXP040i7`0o>1h0?SLM0P0m=Q`203`h
7@@0>cLL0P0j=Q/803@b7@0P03Hc800e<Ql0=c8N03La6`0i<AX0?C<J044e7@12=Q`0BCPN04/j7P1A
?R00F44R05e49@1PAR<0I4PS06E78`1RBR@0GDLP05E37`1??ah0BcdP048i700g<1H0;bT?02l/7@0]
:Ad0:2HJ02<S6@0O81P07B0I01XO6@0J7a/801XL6A006A/H2@0J71/801XL6@P071`J0P0J71T201TK
608061XG0P0G6AHK01LI60805QPG0`0E5aH201PJ6@H05aTH400F61L301DG5P805QPG0`0G6AP801HH
5`P05aTH0P0F61L301LI60<061XI200I6aX201LI608061XI0P0I6aX201XL6`<06A/J0P0J71/301/M
70P06Q`I2@0L71X201dM6`807QhL0P0O7ad2020P7P<081lJ0P0Q81/3028Q70<08R8J0P0S8a/3028R
6P<09b<J0`0X91/:02TU7080:BDI100Z9QX202/W6`80;2PL00@0;RPL030X7@0a9ad0<bHM0P0e9ah2
034U5`80<RHH0`0c9aT02@0d:1X0;bTK030X6`0a:A`0<RPL03DY7@0g:Ah0>RTO03/Z800203DX5`06
03HY600g:QT0>B`K03X]700k;Qd0?2lN0`11<1h2048a7`<0@c8P0P12<1X204<a6`80A38L0P15<ad0
2016<A`0Ac8M04Te7@1;=ah0CCTN050m7`1A?Qh0DSlO0P1C?R401P1E?B40EcdR05Pm8P1J?280FcdS
05`l8`<0G3hT1@1M?bD805U19@P0F3dR0P1G?B8305Pn8`<0FClT00@0G3`S05/m8`1L?R@0FSlT0P1J
@2D00`1I@BD0Ed8U05Q39P0805]28`0305a39@1J@B<0EchP0080EC`N00<0ESdO05Po8@1J@B<00P1L
@b@00`1K@R<0FT4R05U08@0305Po8080Fd0U00`0G44V05e29`1L@BH0Fd0U05Tn8`1G?240Fc/V05Xk
9P1I>RD0Ec/U05Dk901D?2@2054k8`0305@l801E?B40ECdQ0080EShR0P1G?b<02@1H@2@0H48Z05m1
:@1L?R@0FcdQ05`o8@1O@R80HTDU06A79@0206528`<0HT<T0`1SA2D0201YC2`0J4/[06M::P1UB2P0
HdHV0654901P@b<0Gd8R101UBB@0101WBbH0JThY06eA;01_Dbh807EC;@80Me@/00<0N5D]07UF;P1j
Ebl00P1kF3004@1lFC40NeLc07aH=01nFcD0P5de089O=@22H3<0PElb081N<022H300PEl_07mM;`1n
G2l0OU/a07mL=020GCL0PEhh00<0OUlc0P1oH3@3081Q=@0307mN<`1nGC80O5/`0080NUT^00D0N5L/
07IE:P1eE2T0NEP]07YI;P0307]J;`0307UH;@1hEb`0MeH[00@0O5T_101kF2h00`1iFR`0N5T[07QI
:`0207QI:`@0MePZ0`1gE2X407QE:`0707UF;01kF300NeP`07aI<@1mFS80OU/c07mL=002081M=@80
O5T_0P1kF2h207YG;@80NEH/0P1eDRX0101fDb/0Me@/07QE;@1iERh207]H<00907QI:P1gF2X0MULY
07IG:`1fERd0MUH_07EE;`1dE2h0MU<]0080ME8/00P0Le0Z079?:@1cD2X0ME8/07MD;P1iES00N5D_
07IC;@80M54[00<0ME8/07IC;@1gE2h00P1aE2X03`1dE2/0MUD/07UF;P1mEc00OeTb081I<P1lES40
NULa07]H<P1jF380N5Pa07=F;P1_Db/0KE4Y07EE;P0307AD;@80Le</0P1bDR/01`1cDb`0M5@]07EE
;P1fERl0MED^07AD;@1bDR/00P1aDBX01`1`D2T0KdlX06i>9`1^CRL0KdlX075A:P1bDR/00P1fCR/0
3P1eCb/0LThZ071>:@1_CbT0KThX06a>:01/C2D0KDdV06i>9`1_CbP0LE4Z079B:`1cDb`0M5@]1@1b
D2X3075?:@0407=A:`1dDR`0M58/07EC;@@0MU@^201iER`207YC;00307UC;01gE2`0MUD/0080MED/
00L0LeH/07MD;01gE2`0Me@/07QE;@1iERh0NUL_0080NeP`00D0O5Ta07mJ;@20Fbh0PUd`08AO<P02
08EP<`0408AO<P23GS40PUd`089M<0H0Peha0P23Gbl01024H300QF4a08EQ<@26HS8208MS<`0608IM
<@27GS80QElb08AO<P25H3<0Pf4c0P23Hc@02`29I3X0R6<i08MR>026HCL0Q5le08=N=022GC<0PE`b
085N=P1oG3@0OU/c0080OEXb00@0OU/c07mL=021GSH0PU`e0P23GS@01@24Gc<0QV4d08MS<`27Hc40
R6@b0080QV@f00@0QF<e08=Q<`22H380P5h`0P1oGBl207eJ<P80O5Ta0P1kF30207YG;`<0NE@Z:ooo
ool002[ooooo202PMd<0102UNdT0Y7Y80:AjB02SNDL20:9hAP80XGM50`2TN4T01P2UNDX0YGU80:Ij
B@2VNTT0YW]80:9iA@80XgY60P2TNdL20:ElB080YWe900l0YGa80:AkA`2SNTH0XWU50:5hA02PMd<0
WgI20:5hA02RNDD0XgY60:AkA`2UO4P0YWe90:MnBP2XOd/00P2YP4`00`2XOd/0Ygi:0:ImB@020:El
B0060:AkA`2VO4X0YWa:0:ImB@2VODL0YWe50P2VOT<00`2VOT40YWe90:ImB@060:ImB@T0YGa82`2Y
P4`20:QoB`<0Ygi:0P2VODT20:ElB0080:AkA`2SNTH0XgY60:9iA@2QO4P0WgY609ag@`2IM40409Mb
?P0409U^@@2GK3l0UFXm09=X>`80TVLj00L0TfPk09AY?02=IcP0S6Hg08]U=P2:I3D0RF<d0080R68c
00T0Qf4b08MR>027HSP0QV4g08AO=@23GS@0PUdc085L<P20Fc400P1nG2`0101mFbd0O5X]07]H;P1j
Ebl607UF<080N5D_0P1gE2h0201`E2`0Ke<[06iA:@1_CbP0L4hX079?:@1cD2X0MU0[0P1_DRX2071C
:`0<075D;01bEBd0LUD]07=F;P1hE300NEDa07UF<01jEbl0NeP^07aJ;@1mFbh0OE/]2026HC@01P28
HS/0R6<i08UT>P29I3P0RVDh08YV=P80RfLe00<0SFLj08aV>@2<IST0102<IST01`2=IcX0T6<i08mT
>@2?I3T0SVDi08aV>@2;IST00P29IcT00`2?JCX0SFLh08]U=P0208US=00308]U=P2=IcP0SfTj00<0
RV@g0`2;ICP208aV>@80S6Hg0`2=IcP408iX>@<0SFLh0P2<ISL408]U=P@0S6Hg0`2=IcP408eT=P05
08iU=`2?ISP0SfHh091W>@2AJc`00P2@JS/208mY>P80SVPi00@0SFLh08aV=`2;ICH0RF<d0P28HS<0
0`29Hc@0RfDf08aV=`0808]W=`P0RVDh1029I3L408QS=PD0Qf8e0`28HcH808EP<`80Pf8_00H0PV0`
089P<P21Gc80PEhd081M<`20GCD3081N<080Oed_0`1nG2h01P21Gc40P5ha081N<@1oG380OU/c07eJ
=080O5Pd0P1hFBd03`1eF2h0LeL_071G;`1_EC00KUH`06eE<@1ZE2/0JU@]06QB;@1VD2/0HT/Y05i7
9`1J@b@0Ed0Q04lm9@0204lo9P0504do9@19?B<0AC/P040i7@0n=a/00P11=Al0300o=200>c<P03Tb
7`0g<Ql0=34P03<`7`0d;R80<BdQ030/800^;1l0:R/M02LY6`809BTJ00H09bTK02LY700V:1/09BLL
02DV7P0T9Al302<T7`808B@M00@082<L01lR6`0O8Q/07R4J0P0M81T801hP7@8082<L1P0Q91d801/M
6P0P01/L7P0L7Al071hM01dO700N81/07R4J01lR6`0O8QT092DM02@V6`0U9a`09RPK02LY6`0Y;1/0
:RdJ02/^6`0Y9AT0;2PL030/800b;R80<blS030/800]:Ad0:RHJ01lP600Q8QX092DM02HW7`0W:200
9RLO02@U7@0S91`202HW7`0302DV7P0T9Ad08b@L00808R<K00D08B8J020S700P8a`082<L01lR6`02
01hQ6P807B0I200P81h401lP6P@0824K01P08b@N02@U7`0V9Qh0:bPO02hZ7`0a:R00<2XN030X7@0n
;QL0C3XR065><01fGcd0Q6]308mdA`2HNDX0WGe:0:63D@2URET0X8EF08M^A@1PC2T0@30G038U5@0`
9Q`302HX9@<09BLT2P0T9R<I02LX8P809BLR01009bPR02XZ8P0]:R40<2`Q034]8P0c;B40<blS03@`
900g<B<0>c@T03lf9@11>BH0AS/Y04Ll:01>?BT0CchZ0`1@?b/03P1>?BT0C3/W04/j9P1;@2`0BChZ
04Hk9`13>2@0@SLS04<h9015>RH0AS/W04Pg9@19>2H0BcXX0P1=?2X02@1<>bT0BSTW04Th9P19?BL0
B3`V04Hi9P14=bH0@cHU04<f9P0204@f:@0904Xj;@19>BX0B3LW04Tf9`1:=bH0CcXW05<m:01F@2/0
Ec`W0080ESdW00<0E3hW05<o9`1A?bL00P1??bH204`k:@0304/j:01:>BL0BCPV00<0BCPV0P1=?RT0
1P1;?2T0BSXZ04Ph:016=RL0ACDX04@d9`<0@3@X0`11=BT2048f:P80?SDV0P0m=2D0100l<b@0>c8S
03Xa8P0j<B8303L_9080>30U0P0i<BH00`0j<RL0<blS03<_8`0603<_8`80;b/O01h0<2`P038^8P0c
;b<0=30T03Da9@0f<RH0>38V03Xb9@0k<bH0?C@U044e9@14=bH0B3TV04Tj9`1E@2<0FD4U05e69P1T
C2P0JU0[075E;@1fFBd0NE``071G;`1bFC00MUXb07YM<`20HCD0QF@g08QX>@2:J3X2095/=@05095/
=`2@JcH0SfXf08aX=P2;IcL00P2:ICP09P28Ic@0RVHd08aX=02?JSD0U6df09M^=P2KL3T0W78h09]a
=@2LLSH0WG@f09ie=`2OMSP0X7Lg0:5h>02RNCT0Z7di0:Qo?@2ZPD40ZhA30:^5AP2YQDL0YhE80:J4
A`2XPT@0Yh530:B0A02QOT@0X7e509elAP2LODH0W7e70:>0BP2QOTP0WGY409Uf@02FLcd0UG8l0P2D
LC/02`2KN3h0V7Po09Ie?`2CM3d0Sg4k08Y_>P26K3T0QF/h085V>@20ICP0OV<f0080OF8e00<0OV<f
07mT=`20ICP0101nHcH407eR=@80PFHi00@0P6Dh081S=`1oHSH0OF0d0P1nGc<307YM<@0307]N<P1l
Gc<0O5lc0080OF0d00/0NUT/07]J;@1kFRl0NUXa07UI<P1gEc40LU@^075C;`1`E2d0LED^079F;`02
07=G<00;079F;`1aEBh0L5@]07II;`1dEbd0LEH[06mD:@1]EBT0KUL[071K;P1bGC000P1aFb`02@1b
Fbl0LU/a075J<@1`F380LETc079J=P1_F2l0L5T`075J<@03079K<P03075J<@1`FC00LeL`0080LeL`
0`1bERl2075E;P0406a@:01^DRX0LED]07=G;`80METa00@0M5P`07=G;`1`FBl0L5T_0P1aFS03079K
<@0307=L<P1iGS<0N5db00<0N5db01@0Me`a07IK<01fFc00MU/`07QM;P1gG2d0Le/]071I;@1^FBh0
JeP^06YG;@1XERh0JU8^06EC;@1ODb/0FU<Y05YA:01QCbT0JD`Z06e::P80H4d/00@0HDl[065?:@1R
D2X0HU0X0P1SDRL0201QDRL0HU<X06=D:`1RDb`0H54Z05];9`1FAR@0Dd<Q0`1?A2@304i38`80CD8R
00<0Bd0P04a18@1=@R800P1?A2@02`1>@b<0C44Q04]0801>ABP0CD@W04]29@19@2<0AchQ04@k7P13
>Qd0@STL0080@S/O0P11>Qh2040i7@80?cPL00D0@S/Q044j8011>R00@3TO03lh7P0203hg7@0403df
700m>Ah0?3PM03`h7@80>cLL0P0j=Q/00`0i=AX0=38M03@b7@0603@b7@0N03Hc800e<Ql0=S4M03La
6`0i<AX0?C<J040d7011=A/0BSHK04di7P1@?Al0E3lR05Q18P1I@R80FT4R05U08@1JAbL0Dd<R04dn
8@16>al0@CXP03Xe7`0`;AX0:2LC02XW7P0X9A`08b<I01lP600L7aP06AhG0P0H7aP801XL6@P06A/H
200H6QL901XL6`P06Q`I200L71X201XL6@806A/H0P0H6QL201LI5Q/05aTH0P0F61L301DG5PH05aTH
0P0H6QT@01HH5`<05ALF0P0F61L301LI60P05QPG200G6AP201HH5`<05aTH0`0H6QT801TK6P805aTH
0P0H6QT201TK6P806Q`K0P0H6QT201TK6P806Q`K0P0K7A`801XL6@T071`J0P0M7A/201hN70807alM
0P0P81h201lN6@8081lJ0P0Q81/2028Q70<08R8J0P0Q8AT3028R6P809R8I0`0W8aX302PT6`P0:BDL
00<0:2@H02TU6@0Y9AT00P0Z9QX202/W6`0702`X700[9a/0:bLK02hX700_9a`0<2HL03<V7@0203@V
7@80<2@H0P0a9AT3038V6P0703<W6`0^:1X0<2PK034Y700c:Ad0=RXN03LY7P0203XY7`0603@W5P0e
:1L0=RTH03LZ6@0h:aX0>RdL0P0k;Qd2040_7@80@C0N0P12<Al204<b80@0@c4K1014<Q`02016<A`0
Ac8M04Te7@1;=ah0CCTN050m7`1A?Qh0DSlO0P1B?B000`1E?B40ES`Q05Ll8@0205Xl8P0405/k8P1L
?RH0G3hV05`n9PD0FcdU201F@B@:05Hl8@80EcdR101H?R<0101K>b80FcdS05/m8`1I?R<205To9003
05Q0901G@RD0Ed8U00@0FT4S101I@280201K@R@0FD0R05Hm7`1D>ad0DcXL05Dl7P1G?R00F3lQ0`1J
@B<00`1I@280F3lQ05Ln800205Hm7`0305Lm8P1H?R<0FClT0080FT0U00@0FClT05Lm8P1F?240FSXU
0P1I>RD00`1F>R@0EC/T05<k8`02054k8`80DSdP101C?R4205@o8P0805a0:01K?bL0FChS05Tn8@1J
?b40GD<R05m5901QAb@306138`<0HD@T0P1RABD02@1XBb/0IdXZ06I9:@1TAbL0HTDU06138`1O@R80
GT4Q06I:9@0206E9900506I:9@1XC2L0JdlZ06iB;@1_Dbh0201cDb`207IC:`0307MD;01hEBd0NEH^
0080NUL_0180NeP`07]G<`1lF3@0OU/e081M=@21GS@0PElb081N<@1oGBl0P5h^07mM;@1nG2h0OE/^
07eJ<01nFc<0P5dg085N>01lGC4307eN<P<0OUlc00L0Of0d07]K<P1kFc80Ne/b07QH;`1fERd0M5@[
0080Le<Z00<0N5D[07YG;@1kF2h00P1lFBl00`1jEbd0N5D[07IC:@0807]H;P<0MeP/00@0MUL[07EF
:P1eERX0MEHZ0P1dEBT207UF;P80NUL_00@0NeP`07aI<@1lFC40O5Ta0P1kF30207aI<@0407eJ<P1n
Fc<0OU/c07iK<`<0NEH^0P1hEBd307MD;00507=@:01dDBT0ME8Z07MD;01hEBd00P1jEbl01`1kF300
MEHW07IG:@1fEbT0MEHZ07AD:`1cDb`00P1dE2h01P1jES80N5@`07IB;P1eDBd0MU8^07QD<080NEDa
00P0N5D_07MD;P1eDR`0M54[07=@:P1dDB/0ME8/07IC;@80M5@[00L0MUD/07UF;P1lERl0O5H_07iG
<020ES00NeD`0080NEH`00D0N5H`07EE;P1aE2`0KU8Z06eA:@0207AD;@80Le</0`1bDR/00`1aDBX0
LU8[07=C;00307AD;@04079B:`1aDBX0KdlX071@:P80KdlY0`1^CRP206m?:@0507E<;01dBb/0Ld`[
075=:`1`CR/00P1^CBX02@1/CRX0Jd/T06a<9@1]CBH0KThW06m?:01`D2T0LE4Z079B:`0206e=9`H0
KThX101aDB/0101bDR`0Le<]07=C;@1dE2h807IE;080NE8[00<0N58[07IC:`1eE2/00P1dE2/01@1b
EB/0MU<[07MD;01hEBd0NEH^0080NUL_0`1kF300101mF2/0OeX]085L;`23GS4208AO<P80Peha00D0
Q5lb08=N<@23GS40Peha089M<00308=N<@05089N;P23Gbl0Pel_08AP<025HC400P26HS801`27Hc<0
QUda08IM<@24GS40Peha08AO<P22H3800P22HS<208MR>00908IQ=`25H3H0Q5le08=N=022GC<0PE`b
07mL=01nFc<0O5Ta0080NeP`00@0O5Ta07iK<`1oG3@0PU`e0P23GS@01@24Gc<0QF0c08IR<P26HS00
Qf<a0080Pf<d00@0PV8c081P<@1oGc00OEd^0P1lG2d307aI<@80NeP`0`1jEbl307QB:b_ooooo000Z
ooooo`P0XWU5202RN4H01P2SMT`0Y7M=0:AhB`2TN4T0YGU80:EjA`80YW]600H0XGQ40:9iA@2RNDD0
XgY60:AkA`2UO4P20:ImB@80XgY60P2RNDD0102QN4@0X7M309mf@P2OMT820:=jAP040:AkA`2UO4P0
YGa80:ImB@80Ygi:0P2XOd/30:MnBP<0YWe90P2VO4X00`2VODT0YWe70:ImA@020:In@`030:In@@2V
ODT0YWe900H0YWe92@2WOTX;0:V0C080Z7m;0`2WOTX01@2VODT0YGa80:ElB02UO4P0Y7]700<0XgY6
00D0XGa809mjAP2LMd<0VWE109Qc?`0309Mb?P0409Y_@P2HKD00UV/n09AY?080TfPk00H0U6Tl09EZ
?@2?JCX0SVPi08aV=`2:I3D408QR<`0608QS>@27HSP0QV4g08EP=P23GS@0PUdc0P21G38207iL;004
07eK;@1lFRd0NeP^07]H<080NULa0P1iES0207QE;`<0Me@^00T0MU<]079F;P1aEBd0L5<[071@:@1a
CbT0Le0Z07AA:`1gDB`00P1_DRX2071C:`<0LE@/00T0LUD]07MC;`1hE300N5D_07UF;P1jEbd0NeT/
07aJ;@1lFR`01@25H3<308IQ=00608QR>`28HcT0R6<i08UT>029I3L0RVHf0P2:IS@00`2>J3/0SFLj
08aV>@0208]U>00408aV>@2=IcX0SVPk091S>@80Sf@i00<0SVDi08aV>@2;IST00P29IcT208eW>0@0
RfDf0P2=IcP308YT=`<0RfDh102<IST308eW>P@0SVPk0`2=IcP208aV=`<0RfDf202=IcP01P2?I3L0
SV<f08iS=P2=HSD0SV<f08mT=`80TFHi0P2@JS/0102?JCX0SVPi08iX>@2=IcP208aV=`0308]U=P2:
I3D0R68c0080Qf4b00<0R68c08YT=@2;ICH0202:ISH908YU>0<0RF@g0`28HcH00`27HSD0RF@g08QS
=P0208QS=P0408MR=@26HC@0QV4d08IQ=0P0QF0c0P23HRl01P22H300PV0b085O<P21GS@0P5dc081M
=@<0P5h`0P1oGBl307iL;P06081N<01oGC00Oed`07iK<@1mFS80O5Tc0P1kEc<0201jFBh0NEP]07QH
;`1eF300LeL`071F<@1_EC00KUHb0P1ZE2/01`1YDb`0Ie4/06==:01OB2H0Fd@T05U28P1A?bL00P1@
@2L02`1>@2H0BCdS04Dk8010>Ad0?SLK048f8011=Al0?c@P03`d8@0i<Ql0=c8O0080=34P00T0=2hR
038^8P0`;200;R`O02X[7@0W:A/09BTJ02@X6@0X:Q`00P0W:A`00`0V:1d09BHN02@U7`0302<T7`06
028U7P0Q91d08B@M020S700O8Q/07R4J0P0M81T801hP7@807b8K0`0P8a`3024T7@<071hK0P0K7AX3
01XL6@0501/L7P0L7Al071hM01dO700M7aX00P0N8AX0300N8AP092DM02@V6`0T9Q/09BLJ02HX6P0X
:aX0:RdJ02/^6`0]:Ad0;RXN02l[7`80<BdQ00<0<2`P02l[7`0^:Qh00`0S91`202@U7@809BHN00L0
9RLO02LX800V9al09RLO02DV7P0T9Ad08b@L00808R<K0P0Q91d00`0P8a`07b8K01hQ6P0201dP6@03
01`O600P81h0820N00H0820N200O81X0600R91l08B<N024R700U9Ad0;2TP02l[800]:Ah0;BLK03d]
7@15=280Dd4Y06E@<@1fGSP0Qfa109=gA`2KODT0U7U<09n3D`2VR5@0W7i:07mT=@1MAR@0@C0L03<W
6`809bTV0P0V:2D302DW90T092HS6@0W:2804P0T9R409BLR02LX8P0Y:B40;BXQ02l[800`;240<bdQ
034_8`0b<2@0=30T03La8`0k=2@0@3LV04<j:@17?2X0CSd[04ln;0<0D3l]00H0CSd[04`k:@1;>RP0
BSl[04Tn:P17?2P404Dj9P0?04Hk9`16=B<0B3LU04/j:01=?2X0CSd[04`k:@1:>BL0BCPV04Tm9`18
?2H0ASTV04@g9P13=RD0@cHV0080A3HY0P18>2/03018=RP0BSLX04/h:@1>>BP0DCXX058k:@1F>bH0
EC`V05Hm9`1D?RL0DclW0590:080DD4X00@0Cch/04hm:`1<>bT0BcXX0`1:>BL02@1;>RP0CSdY04dl
:01=?2X0BcXZ04Xi:@19=bT0B3HZ04Le:@05048f:P<0@CDY0`0n=B@303dd8`80?3<R0P0j<2H303/a
9`<0?38X100h<RH203La9@80=S0T0P0b;R80100c;b<0=30T03@`900e<BD203Hb9P0@03Tc9`0j<RD0
>c<V03dd9@11=BD0A3LV04Tj9`1:>bP0F44R05Y3901OAbD0IT`Y06iB:`1eF2h0Ne``07iO<@80NEde
00H0Nehd07mP=022HC@0QV@f08UW=`2=JCT309I[=00409E/=P2DK3P0TF`g091/>080SVdj00H0S6`m
08a/>`2<JSX0SVXh08iZ=P2@JcH209A]=P0N09M/=@2HKCH0VFle09]a=@2LLcD0WWDe09mf=P2PMcD0
ZW/g0:Ym>@2]P3d0[h=20:j5A@2^QTP0[HM80:b6B02XPT<0Yh520:=o@@2POT40Wga209al@`2KO4<0
Vga50:B1B@2ROdL0Wga409]h@02HMCd0Ug@l0P2FLc/0402LNCl0VWXo09Ui@02GN440U7Lo091e?P2=
M3h0Rg8l08EZ?@24JC`0PVLj085V>@20ICP0PFHi089W>P23J3/3081U>P80Of@i0`1nHcP01P1oJCX0
OfLi07mW>@20ICP0P6<g085R=P80PF0e0`1mH3@507iQ=@07081K<@1oG380Oe`d07eK=@1jFS@0MUPd
079F<@02071C<@08075D<P1bEC<0LeHd07=F=01bEC<0LE@b071C<@1`Db/206mC:`0=06iE;01^Ebd0
KeX_06mL<@1aGS<0KUPY075K;01cG300Le`b075J<@1aFC<0Le/e07IN>P02079K<@0307=L<P1dGC<0
M5dc00<0M5dc0`1eFC4207AH<0<0LeL_00P0L5DZ079G;01eFRl0N5db07UN<`1hGC80MU/`07AI;P<0
LU/_0P1cG30307AM<@<0N5db0`1gG34307IK<00507IN<01dG2h0LEX^06eH;@1YER`00P1WEBd06@1U
ERl0JE4]06AB;01NDRX0FU<Y05YA:01QCbT0JD`Z06i;:`1MCB/0GTh/05i>:P1OD2T0H54Z065B:@1Q
DRL0HU<X065B9`1RDbP0HU<Z065B:`1NCbP0FDTU05A48P1@@1h01@1=@R8304a18@0304Pm7@1:?al0
Bd0P00<0CD8R0P1;@20204a39P0604Y19019@2<0AchQ04Dl7`14>ah0@cXM0`11>Qh2040i7@<0?cPL
0P11>R02040i7`80?cPN0P0n=ad203di7P0403`h7@0k=a`0>cLL03Xf6`80>CDJ0`0c<A`203@b7@<0
=C<N00/0=C8O03@a7P0f<Ad0=c4K03P`6@0l<QT0@3@L044e6`1;=QT0CCPK04ll7P02058o8@0@054n
801??1h0CS/M05129`19?B<0@SPO03`f800h=B80<C8R02T[7@0R9QP092<N02<R7@0O81X071lH01PM
5P805ahF00<05AlF01TK600I6aP03P0I6aP801PJ5`T06A/J200I6aP801`L6P806Q`I0P0I6aP201PJ
5`805aTF6`0G6AP201HH5`<05ALF0P0F61L301LI60<061XI400F61L301DG5P805QPG0`0G6AP801HH
5`P05aTH0P0F61L301LI60<061XI200I6aX201LI608061XI0P0I6aX201XL6`<061XI0P0I6aX301XL
6`P06A/H2@0L71X201dM6`807QhL0P0O7ad2020P7P<07ahI0P0P7aX3024P6`0302<S6`0R8QX08B4I
0080820H00<08B4I028R6P0S8a/00`0V8QT202LS6P/0:2@K0P0X91P0100Y9AT0:RHJ02XV6P0[9a/2
02`X7080:bLK00@0;BLK02lW700`9Q`0<bHM0P0d9Qd0100`8aX0<B@K034T6`0a91/2038U7080<bHM
00P0;BLI02lW6P0`:1/0<bTM03HZ7P0g:Ah0>BPN03PW7@80=RTH00<0=bXI03P[6P0i;1/00`0j;A`3
040_7@80@C0N0`12<Al404@b70@0AC<M0P18<ah01P1:=Qh0BcLN04di7P1??1h0D3dM054n7P80DSdP
00<0E3`P05Hl8@1G?2400P1J?280101K>b80Fc`W05/l9`1K?2L205Xk9P<0FCXU0`1D@B<305=08P80
DSlQ201C>al205Dk8080ES`Q0`1G?B801@1H?R<0FSXQ05Xl8P1J?280F3dR0080F3hS00<0EclS05I1
901F@B@00`1I?b@305Pn8`80EcdR00<0FD0R05Po8@1F?Al00`1E?1h205Hm7`80EcdR0`1H?R<01P1G
?B80ES`Q05Dk801D?200ECdQ05Lo8`80F40T00/0EclS05Dm8@1D?200FSXU05Tj9@1H>B@0ESXT05@j
8`1C>b<0DC/S050j8P08054n8080EcdT00H0F3hS05U08P1K@R<0G4@R05e58`1NAR8205m28P80H4<S
0`1QA2@01`1RABD0ITTY06E8:01TAbL0HdHV0654901P@b<00P1O@R8406I:9@0406Q<9`1[CbX0KU8]
071D;`<0L5<[0`1_DRX206iA:@80ME8Z00<0MU<[07MD;01hEBd00P1iERh04@1jEbl0NeLc07aH=01n
FcD0P5de081M<`20GS40Oed`07iL;P1nG2`0OE/[07aJ;01lFRd0O5T_07eJ<P1oG3H0PEhh00P0O5da
0140MEP`07MJ<P1gFS80MEP`075D;01_DRX0L5<[079E;@1iE2X0NUD[07eH;P1nFBl0OEP^07]F;01h
DbT0MU4W07UF;00307YG;@<0NeP^00@0O5T_07IF;@1fERd0MED/0P1dE2/207=C:P80LU8Y00H0N5D_
07UF<01iES00NULa07]H<P1lFC<207eJ=0L0NeP`00@0NUL_07IC;@1fDbd0MU<]0P1eDR`307AA:`04
079?9`1dDBT0ME8Z07MD;0@0NEH^00X0Le@U07EF:01fEbT0MEHZ079B:@1`D2T0LU8/07AD;P1kEcD0
N5@b0P1eDBl0301hE380NeLe07]G=@1jES@0NEH`07QE;`1fDbd0ME8/07AA:`1eDR`0MU<]07MD;P80
MeH]00L0NEH^07aF;`1lERl0O5D^07eC;@1lDR`0NeD`0080N5D_00D0MU@^07=C;01`Db/0KE4Y06a@
:00207=C;080LU8[0`1aDBX2071@:@0?075A:P1bDR/0Le</079B:`1aDBX0KdlX06i>9`1]C2T0KTdZ
06m>:`1`Cb`0Kdh[06i=:P1/BbP0JdXW0080LdX/00<0LT//071<;01_C2`00P1^CB`00`1/CR`0K4`U
06a<9@0306e=9P<0KThW0P1XBRH306U;9`<0JT`X0P1^D2`306e?:`0306i@;01`DRh0LE<_00P0Le</
0P1hDBX00`1gDBX0ME8Z07AC:P0207=C:P04075D:P1eDRX0MU<[07QE;@80NUL_00X0NeP`07YG;`1j
Ebl0NUL_07aG:P1mF2/0P5/^089M<023GS40Q5lb0P23GS400`26HC@0QF0c08AO<P0308=N<@80Q5lb
0P23Gbl308AP<0<0QF4a0P26GC401024GS40Q5lb08AO<P23HC<2089R<`@0Q5le0P23GS@2089M<`03
07eJ<P1lFC40NUL_0080NEH^00@0NUL_07aI<@1mFS80Pedf0P23GS@00`24Gc<0Q5lb08EQ<@0208EQ
;`80P64b00H0Of0a07eN;`1lGBh0Ne`]07YK;01iFR/207aI<@80NeP`0`1jEbl0101iERh0NE<^07UC
;P1iDbh[ooooo`00:_ooool80:AkA`0809me@`2PMT@0XGM50:5gA@2RN4H0XgU70:AjB02UNdT20:=f
C@040:AgC@2TN4T0Y7Q70:EjA@80YGY300H0X7M30:5hA02RNDD0XgY60:AkA`2UO4P20:ImB@D0Y7]7
0`2SNTH60:ElB0D0YWe90`2WOTX20:QoB`80Yge;00<0Ygi:0:MnB02WOTH00P2WOd@00`2WOd80YWe9
0:ImB@060:ImBA@0ZH1<0P2XOd/30:MnBP<0YGa8102TNdL01P2SNTH0XGa80:1kA`2MN4@0VWE109Qc
?`80Ug8n00D0V7<o09Y_@P2IKT40Uf`o09EZ?@0209AY?080UFXm00H0TF/l08mY>P2<ISL0RF<d08QR
<`27HC8208QR<`80R6<i00@0Qf8h08EP=P24GcD0PUdc0P21G3801P1oGBd0OU`/07iL;P1mFbh0O5T_
07]H<080NULa0P1hEBl207MD;P<0MU<]00T0ME8/07=G;`1bERh0LE@/075A:P1aCbT0Le0Z07AA:`1g
DB`00P1_DRX4071C:`80LE@/0P1gDbl00`1hEBl0NEH^07YG;@0207]I;00407aJ;023GS40Peha08AO
<P80QF0c0P26HC@01`27HSD0R68k08QS>@28HcT0R6<g08UT=`29ICD00P2:IS@00`2?JC`0SVPk08aV
>@0208]U>00408aV>@2>J3/0SfTl091S>@80Sf@i00<0SVDi08aV>@2;IST00P29IcT208]U=P@0SFLh
0P2;ICH308YT=`<0RfDh0P2<IST208aU>P<0SFHk102>Ic`308eW>080S6Hg0`2;ICH808eW>003091U
>02?I3L0SV<f0080SF8e00<0Sf@g095V>@2BIcX00P2?JCX0102>J3T0SFLh08aV=`2;ICH208YT=@03
08eW>02<ISL0RfDf0080RV@e00<0RfDf08aV=`2=IcP0202:ISH:08YU>080RF@g0P28HcH208MR=@08
08]V>@2:ICP0RF@g08QS=P26HC@0QF0c08AO<P23GS4808EP<`80Pf8_00H0PV0`089P<P21Gc80PEhd
081M<`20GCD3081N<080Oed_101nG2h01`1nG2l0OE/^07aI;`1kF300NULa07YF<P1iEC400P1kF2h0
1P1iF2l0MeL`07AF<01bES40LED`06mE<P80JUDZ00L0JE<Z06MA:P1TCRT0H4TW05a58`1J@b<0DT0X
0080DD4X00D0Cd4W04Xn9016?240@3TM03hg6`02048f8004040e8@0l=240>S<P03Lb7`80=34P00h0
=BlS038^8P0a;B40;R`O02X[7@0W:A/092PI02<W600X:Q`0:2XM02LY700V:1d09BHN02@U7`8092DP
00H08b@O028U7P0R9Ah08B@M020S700O8Q/201hQ6P0301dP6@0N81d07R0M00H07R0M00<07B0I01hQ
6P0N8AX00P0O8Q/2020S7004024T7@0M7a`071hK01`N6`806adJ0P0J71T01P0I6aP071dO01`M7`0L
7Qd071hK01dO6P807B0I00`07B0G02@U7@0T9Q/08bDJ02@V6@0U9aT09bXI02X]6P0/;a`0<BdQ030/
800_:al202hZ7P0;02l[7`0`;200<BdQ02LX800U9Qh08b@L024R6P0R8a/092DM02HW7`0X:B400P0W
:200100V9al09BHN02@U7@0S91`2028S6`06028U7P0Q91d082<L01lR6`0N8AX07B0I0P0L7aP8020P
7PD07b0J0`0N7aT0600P9B407b4N01`N6@0P8A/09bLO02dZ8@0^:R40;2PM03X/8@0n;Ql0A3<O058n
8`1UCR`0NF4e08]a@02FNTP0T7U@09Z0C`2UQTd0Z8I909Qi@P1iH3L0F4@/03la9P<09bTV0P0V:2D3
02DW90P092HS200W:28A02HW8@0B02@V8@0U9b809bPR02TY8@0/:B00;b/P030/8@0b;200;blU02l_
8`0a;b<0=30T03Tc9@0m=RH0@CXX04@k:P1>?B/0Cch/0`1@?bd0101>?B/0C3/Y04/j:017?2P204Pm
:@80BChZ0140B3dY04Hk9`16>bL0AC@R04Pg9@1;>RP0CSd[04ln;01=?2X0BSTW04Pg9@19?BL0B3`V
04Hi9P14=bH0@cHU04<f9P0204@f:@0904Dd:P16=B/0BCL[04`i:`1<>BX0CSTX04lh:01>=bD0ECXU
0080EC`V00T0E3hW05A0:01C@BT0DT8Y05=3:P1B@Bl0DD0^04hm:`1<>bT00P1;>RP0201<>bT0CC`Z
04dl:01=?2P0C3/Y04`k:`1;>RX0BSPZ0P1:>2`304@h;00304<g:`12=RX0@CDY0080@3@X0`0m=2<3
03he9080?cHU0`0n=2X503dc:@<0?3@Y0P0k<bP00`0j<RL0>C4V03Ta9P0803Hb9P0H03Xd:00k<bH0
>c<V03`c9010=2@0A3LV04Tj9`1;?2T0FD0R05a3901QAbH0JDdX075D;01iFRh0OUla085Q<P20HcT0
Of8h085R=P21HS@0Pf<d08IT=02;IcL0S6Pf0P2HJRl07@2HJc80UV`b09M^=P2EL3T0UG8l09Ac?P2C
M3h0T7A5091a@`2=KSl0Rf/j08YY=P2<J3@0SFPd08eX<`2CJ3D0U6Tf09I[=P2HKS@0VW0d09ac<`2N
MC<0WgHd0:Mg;`2YN3<0Zg`f0:ao>`2]PSh0[HA20080[8E400d0[8I50:Z4A@2VPd<0XX110:1n@@2N
OT<0WGi509ioAP2TPDL0XWm509ml@P2LNCl0VWLm00<0VGHl00/0VgTl09Yj?@2KNd00Vga309UlA02E
NT<0TWU1095h@P2;LdD0RW9408Q`@P0308I^@00308M_@@28L480P6Ln0080P6Ln00<0OfHm07iU?01n
IC`00P1mI3/0201nJCX0OfTj07mW>@20ICP0PV<g08=R=`23H3H0QF0f0`21I3P3081S=`80Of8f0P25
GSL02@22GcT0P5hh07]M=`1gFcH0LUPe06mG<`1_EC@0L5He075G=P02079H=`0C075G=P1`ESD0KeDd
06mC;01^EBd0KeH^071I<01_FC00KEX`06aK<01[FRl0K5HW071J:`1dGC40M5dc079K<P1aFC<0MEdg
07UQ?@0207AM<`80MEhd00D0MUle07MP=P1gH3H0Mf0f07MK<`0307IJ<P80METa0P1dF3000`1dFB`0
Me`_07YO<P0207aQ=00307YO<P1gG2l0MEX]00<0Led^0P1dGRl307EO<0D0MU/`101gG3401P1eGS80
Le``06mJ;`1/Eb`0J5D[06ID;080I5D^00P0J50/06=A:`1MDBT0FE8X05YA:01QCbT0JD`Z06i;:`80
G4h[00@0GDlZ05i@:@1ODBX0H5<Y0P1QE2P0201QDRL0HU<X069C:P1QDR/0GDhW05M78`1B@R00CShL
0`1:?al504]0800804Hk6`17?1`0BChN04]0801<@B40Bd0P04Xo7`19?Qh204Y1900404U08`18?b80
AchQ04Hm8080AC`O0P11>Qh2040i7@@0?cPL1010>Al403lh7P0503hj7`0m>Ah0?CTN03`h7@0j=Q/0
0P0i=AX0100h=1T0<S0K03<a700c<A`203@b7@80=C<N0240=S@O03Db7`0d<Ah0=C0L03H`6P0h<1T0
?38I03lc6`11=A/0BcHG04dh6`1??1h0D3`Q04hm8@1<>b40AcLM04De6`15>R@0?SHQ03L`7@0b;ah0
;RlQ02T]7`0R:1h072<K020P7P0O7ad071hK01PM5`0E71D05QdE01@N5@0E7aH0400I6aP801LI5PT0
6A/J200I6aP801`L6P806Q`I0P0I6aP201PJ5`805aTF6`0G6AP201HH5`<05ALF0`0F61L00`0G6AP0
61XI01PJ6@0201TK6Q005QPG0`0E5aH201HH5`<05aTH200F61L801LI60805QPG0`0G6AP301PJ6@P0
6A/J0P0G6AP201PJ6@806A/J0P0J71/401PJ6@806A/J0P0J71/801TK60T071`J0P0M7A/201hN7080
7alM0P0P81h401lN6@8081lJ0P0Q81/00`0S8a/08R8J020P600201lO5`03020P600R8QX08b<K0080
9B4H0P0V8QT302LS6PT0:2@K00D09b<G02PT600X91P0:BDI02/W6`0202`X700902dY7@0Z9QX0:RHJ
02dW6`0^9Q/0<2HL038U700c9A`0=2HM0080<B@L0P0b9Ad303<V7P0903@W7`0/9QP0;RHI030X6`0c
:Ad0=RXN03LY7P0h9ad0=bHL00@0>B`K100j;A`4040_7@80@C0N0P12<Al804Hd7P80BSDP00@0BcLO
04`h7`1=>Ah0CS/M0P1??1`2054l7`0305@l801E>b00Ec`Q0080FC/Q00@0Fc/R05/l9`1J>bH0FS/V
0P1I>RD205Pi900405Lh8`1C@280DSlQ058o8@80DChP0P1@?Al00`1??1h0D3/N050k7P06050k7P04
05@j7`1E>b00EC/P05Dk8080ES`Q0P1G?B80101J>R40FC/Q05Tk8@1H?B8205Lm8P0305Lo8`1E@2<0
ED0S0080FClV00<0F3hU05Lm901G?B@00`1F?2<205Ln80<0F3lQ00H0ESdO05Dl7P1D>ad0DcTP05@j
8@1F?2<205Pn9@0605Lm901F?2<0EC/R054l7`1B?B00DchQ0P1E@2<0101D?b80DchQ058m801I>B@2
05Pi900305Di8`1D>R<0Dc/S0080D3XR101A?R04050m7`08054i7`1D?280EclS05]49@1LABD0G4DS
05]48P1I@ah305e38P80GT@S0`1OAB@206=69P80HTDU0P1QA2@206138`<0ITXU00H0Id/V06U=:01/
D2/0KU8]071D;`1^DRX206eA:@80K50X0P1[CbL01`1ZCRH0M54Y07EB:P1eDRX0MU<[07MD;01hEBd0
0P1iERh0401kEc<0OETe07iK=@20GCD0P5dc07mM<01nG2l0OE/]07eK:`1lFRX0NeT[07]I;01kF2h0
OEXb07mL=P20GCL207eN<P80O5da01@0Ne``07YK;`1iFRh0NEX^06mC;01cEc00METb07=G<01_Db`0
KE4Z06mC;01bERl0N54X07YC:P1mERd0OeP_07iG;P1lEB`0N54X07I?9P<0NEH/00<0NUL]07]H;P1k
F2h00P1lFBl207EE;P0307AD;@1cDb`0LU8[0080LE4Z0P1`D2T01P1cCb/0M50/07EA;@1fDRh0Me<_
07QD<080NEDa0P1kF300101jEbl0NEH^07QE;@1gE2`207IC:`80Ldl[0P1bCRX3075=:@0F071<:01c
D2P0M54Y07IC:`1hEBd0NEH^07QE;@1gE2`0MU<[075B8`1dEBL0MePZ07EF:P1`D2L0KThW075A:`1d
E2h0Me<a07=?;@1`C2X0LDd[07MC<@80NUHd01L0N5@b07YG<@1iES00Me@^07IC;@1eDR`0MU<]07MD
;P1hEBl0NEP_07YG;`1kF300OEL`07eF;`1mDbd0NdlZ07Y>:@1jE2l0N5D_07IC;@1dDR`0LU8[06iA
:@0206a@:0<0LU8[0P1aDBX3071@:@0;06m?:01`D2T0LE4Z079B:`1aDBX0L50Y06i>9`1]CBH0JTTV
06e<:@1`Cb`00P1bDBh00`1^CBX0JTTV06M68`020799;@06075:;@1_BRd0KT/]06e<;@1^CBh0K4d^
0`1]CBH206a<9@<0Jd/T00<0I4PS06E9901UBB@00P1VBRD206M;9P0306Q<9`1]DB`0K50[00<0JThY
00<0K50[06iB;@1_Dbh0201`D2X207M@:@0307I@:@1dDBT0Le8Y0080LU8Y00D0L5<Y07AA:@1fDb/0
N5D]07YG;`0207]H<080NUL_00D0NEH^07YE:01lEbX0OeX]085L;`0308=N<@09089M<029I3L0R6<f
08IQ=024Gc80Peha08AO<P25H3<0QV4d0080QF4a0`24H30308=O;`0608IM<@27GS80QElb08AO<P25
H3<0Pf4c0P23Hc@01021G380PUdc089M<`22GC<208=N=080Q5le00<0NeP`07YG;`1iERh00P1hEBd0
101iERh0NUL_07]H<023GCH208=N=00308AO<`24Gc80Q60`0080Q60^00H0Of0a07iO<01mGRl0O5d^
07]L;@1iFR/207QI:P<0NeP`0`1jEbl207UF;P<0NE<_:oooool002[ooooo202UO4P209id@P0>09me
@`2QMdD0XgU70:AjB02UNdT0YWa:0:=fC`2SMTd0XgI<0:AhB@2TNDH0YGY50:Ej@`2UNd420:1g@`04
0:5hA02RNDD0Y7]70:ElB0D0YWe90`2WOTX20:QoB`040:MnBP2VODT0YWe90:ImB@<0YGa80P2TNdL2
0:ElB0030:ImB@2WOTX0Z7m;0080ZH1<0P2WOD/00`2WOTX0Ygi80:MnAP020:MoA0030:Mo@P2VODT0
YWe900H0YWe92@2ZPDd;0:V0C080Z7m;0`2WOTX30:ElB0D0Y7]700H0XWe90:1kA`2MN4@0VWE109Qc
?`2GLSh209Qc?`0409]`@`2IKT40Uf`o09EZ?@80U6Tl00X0UFXm09I[?P2AJc`0SfTj08aV=`29Hc@0
R68c08MQ<P28HS<0RF<d0P28HcT01P27HSP0QF0f08AO=@23GS@0PUdc085L<P80Oed]00@0OU`^07eK
;P1lFBl0NeP`0P1jEc4207MD;P80MU<]0`1eDR`02@1dDB/0M5P`079F;P1aE2`0LU8[079@:P1cD2X0
M54[07MA;00306mB:PD0L5<[00P0MU8^07MC;`1gE2h0N5D]07UF;01jF2/0NeT/07]I:`80PUd`00L0
Peha08AO<P25H3<0QV4d08MR=@28HcH0Qf4j0080R6<i00<0R6<g08UT=`29ICD00P2:IS@00`2?JC`0
SVPk08aV>@0208]U>00408aV>@2>J3/0SfTl091S>@80Sf@i00<0SVDi08aV>@2;IST00P29IcT00`29
Hc@0RfDf08eW>00208mY>P0308eW>02;ICH0RF<d00<0RV@g0`2;ICP208aV>@80S6Dj0`2=IS/408iW
?0<0SFLh0P2<ISL308]U=P<0SVPi1@2=IcP00`2AICP0T6@g08iR=@0208iR=@0>091T=`2BIST0TfLj
08mY>P2>J3T0SFLh08aV=`2;ICH0RV@e08US=028HS<0T6Xk08mY>P2>J3T208eW>00308iX>@2?JCX0
T6Xk00P0RVHf2`2:ICP00`29I3L0R6<f08MR=@0208MR=@0808eX>`2<IcX0RVDh08QS=P26HC@0Q5lb
08=N<@22GC0808EP<`80Pf8_00H0PV0`089P<P21Gc80PEhd081M<`20GCD3081N<080Oed_0`1nG2h0
201mFbd0OE/^07aJ;@1kF2h0NUL_07UF<01iEC40N5@`0P1kF2h01P1iF2l0MeL`07AF<01cEC40LUHa
075D<P80JUDZ00L0JU@[06QB:@1UCbP0HD/V05e6901KA280Dd4Y0080DT8Y00D0Cd4W04Xn9016?240
@3TM03hg6`02048f800D040e8@0l=240>S<P03Pc800e<R40=34P03D_8`0b;R80<BdQ02h/7`0Z:ad0
9bTK02@X6@0S9aP0:2XL02PZ7@0W:A`09RPM02DV7P0U9R0302@U80808RDN00@08B@M020S700O8Q/0
7b8K0P0N8AX801hP7@0401`O600M81T07B0I01hQ6P807b8K0P0P8a`201dO700401`N6`0K7AX06adJ
01XL6@806A/H0P0L7Al00`0L7Qd071hK01`N6@0201dP6@0<01dP5`0U9Qh092HK02<U6P0S9AP09BLI
02LZ6@0Z;AX0;2lL03@`900b;R80;b/O0P0]:Ad02`0^:Qh0<BdQ03<_8`0Y:R809RLO028S6`0O81P0
824I02<T700W:200:b`T00809bPP00<09RLO02DV7P0T9Ad00P0S91`01`0R8a/08RDN024T7@0Q91d0
7b8K01hQ6P0M81T00P0L7aP8020P7P@07b0J100N7aT0600P9B406b0L01XL5`0N7aT09RHN02dZ8`0^
:b80;BTP03PZ8@0h9ad0>RTG04Da601H@Al0KeP^08E[>P2BMT@0Tg]E09QmCP2SPdP0ZhQ60:N5B02=
L4@0J58j04`k<@<09bTV0`0V:2D202DW90P092HS200W:28A02HW8@8092HQ01009RLQ02TY8@0/:B00
;b/P030/8@0b;200;blU02h^900a;b<0<blS03Pb900l=RH0@CXZ04<l:P1>?Bd0Cch^0`1@?bl01P1>
?Bd0C3/[04/j:P15>RH0Ac`X04Tn:P80Bd0/0140BSl[04Ll:016>bL0AC@R04Lf901;>RP0CSd[04ln
;01=?2X0BSTW04Pg9@19?BL0B3`V04Hi9P14=bH0@cHU04<f9P0204@f:@0>04@c:@16=B/0BSP/04di
;P1>>bd0CcT[04hg9`1<=BD0ECXU05@k9@1E?2H0E3hW05A0:01C@BT205=3:P0405A3<@1B@Bl0D3l]
04dl:P80C3/Y00D0CC`Z04hm:`1=>bL0CC/W04dj:@0204dj:`0304dj;01=>Bh0CCT^0080ASX^00H0
ACT]04<g:`12=RX0@CDY040d:00o<bL203`d8@0403de8P0n=R<0?cLT03lg9080@3PU0`12=B`00`11
=2/0@3<Z040c:P0203lb:@<0?SH[00<0?CDZ03`d:@0k<bP00P0k<bP303Pd:080=c<W0`0f<RH0600k
=BT0>c<V03/c9P0l<b@0@3@T04@g9P1:>bP0C3dZ05U08@1M@R@0HTPU06Y>:@1bEBd0NU/_081P<@23
Hc@0Q6Lm08=V>P23I3P0Pf8e08AR=028I3@0RFDc08aV=@80VFP]00d0V6X_09Q[<P2HL3D0VG8i09Qe
?@2HMd40UgQ109=hB`2BMDT0Sg1208]/?@28J3L0R6Ld0080RFDa00h0TFDd099V=@2DJCH0UV/d09U_
<`2KLS80WG@b09if<@2SLBX0Y7@/0:Mf<@2ZNcL0Zghk0:^0?080ZX4o00h0/8Y90:j8A`2XQDD0YH=4
0:>1A02QPDH0X8960:62B@2TPDL0XWm509ml@P2MNT00VgPn09Yg?@80VgPn00`0VgTl09Yj?@2LO440
WGm309aoA@2HOTD0UGa409Ak@`2ANd`0T7Y;08ihB@2<MTL208]eAP0508afA`2=MdP0PFY0085Z@020
JCl00P1oJ3h02`1nIcd0OFHl07eV?01lJSX0OVTj07iX>@21IST0Pf@h08=R=`26HCL0QF0f0080PfHj
0P22ICT2085T>080P6<g00/0RV0j08QQ>P26H3/0PV0k07eO>`1hFcT0LUXf071H=P1_ESL0L5Lh079I
>P0207=J>`0C079I>P1`EcP0KeHg06mF;P1`Ebl0LEXa079K<P1aFc80K5T_06QG;01VEBX0JeDV071J
:`1eGS80MEhd079K<P1bFS@0MUhh07]S?`0207EN<P80MUlc00@0Mf0d07QQ=@1iHSH0NF8f0`1gG342
07IK<0<0MEX_00P0Me`_07YO<P1mHSD0Of@g07iS=P1kH3<0N5d`07EJ;@80Led^0P1dGRl307EO<003
07IP<@1eFRl0MEX_0080MEX_00<0MU/`07ML<@1gG3400P1hGC801@1eGS80Le``06iI;P1YER`0IU@/
0080He@]01T0HeD`06Q@;01SDB/0GE4Y05UB:01JDBP0H4hX06U<:P1^Bb/0FddZ05a>:`1MCbX0GU0Y
05mA:P1PDbT0HE@X069E:@1QDRL0HU<X069C:P1PDBX0G4dV05I68P1A@Al0CCdK00@0BChN101:?al0
0`15>QX0AS/K04Pm7@0304Xo7`0304Tn7P18?Ad0BD0S0080BD0S00D0B3lR04Ln8@17?R40AchQ04Hm
8002044j7P80@3TM0`0o>1`00`0n=a/0@3TO040i7`02040i7`@0?cPN0P0n>Ql0100m>Ah0?3PM03Xf
6`0i=AX203Pd6@80<S0K00@0<c4L03@b7@0d<Qd0=C<N0P0f=1l0800e<Ql0=34N03D`700f<1X0>30I
03`b6@0o<a/0@CDK04/f5`1=>1T0CcXM050l8@1=?280BCTO04De7011<aT0?3@O03L`7@0`:aP0:bTJ
02PZ7@0S:Al07B@L01LQ6@0O7al07QhN01XL6`0G71P05A`E01<M500D7QD0520D400I6aP801LI5PT0
6A/J200I6aP801`L6P806Q`I0P0I6aP201PJ5`805aTF6`0G6AP201HH5`@05ALF0P0F61L00`0G6AP0
61XI01PJ6@0201TK6Q005QPG0`0E5aH201HH5`<05aTH200F61L801LI60805QPG0`0G6AP301PJ6@P0
6A/J0P0G6AP201PJ6@806A/J0P0J71/0100G6AP061XI01PJ6@0H6QT201TK6P806Q`K200I6aP901`L
6P807AdK0P0N7Q`201lO7@80820N00@07QdH01lN6@0O7QT07ahI0P0P7aX2024P6`0302<S6`0R8QX0
820H00807alG00<0820H028R6P0S8a/00P0U8AP202HR6@@09b<J200X91/202LS5`0402PT600Y9AT0
:bLK02`X7080;BTM0P0Z9QX0100]9a/0;RHK030V700b9A`203<U70<0<RDM0P0c9Qh303@W7`0802/U
5`0^9QT0<2PK03@Z7P0g:al0=bTN03PW7@0g9Q`403/^7@80>RdL0P0i;1/0100o;Q`0@2lM040_7@10
;ad2044`7P80@S4O0P18=R0404Le7`80AS@N0P1;=R401P1;=al0C3PO04di7P1=>Q`0CCXJ04hk6`80
DC`O00<0E3`P05Dk801G?2400P1I>b400`1J>R40FS/W05Xk9`0205Tj9P0405Pi9@1G>2@0EcPT05Hg
8`<0CchP00<0CSdO04dl7P1<>ad00P1<>ad8050k7P80E3XO0P1E>b0305Hl8@0505Lm8P1I>B00FC/Q
05Tk8@1G?2400P1G?B80101F?R80ED0S05E08`1I?bH205Pn9@0305Lm901F?2<0ES`S0080EC/R00<0
EC`N05Ln801I@2800P1J@B<01`1H?b40EC`N05<j701A=ah0DcTP05Dk8P1G?B@00P1H?RD01@1F?2<0
EC/R050k7P1A?1l0DchQ0080E3lR00@0DchQ058m801A?1l0FCTT0P1H>B@00`1E>B<0E3XS058j8P02
050j8P80CchP101>?Al204dl7P0804hf701B>R00F40T05a59P1NAbL0GDHT05Y38@1G@A`305a48P<0
GDDS0P1NAR@80654900806M;9P1VBRD0ITXU06M;9P1YCBP0K50[06mC;P1`E2l306a@:00306]?9`1Z
CRH0JDdU0080JDdU0P1dDBT00`1eDRX0MU<[07MD;00207QE;@0907UF;P1kEc<0OETe07iK=@1oG3@0
P5dc07mM<01mFbh0OE/]0080O5XZ00H0NeT[07YH:`1kF2h0OEXb07mL=P20GCL207iO<`0F07eN<P1k
G300NU/_07UJ;P1hFBd0MeP/06eA:P1aEBh0M5Pa079F;`1^DR/0K50Y06mC;01cEc00N54X07YC:P1m
ERd0OeP_07iG;P1lEB`0N54X07E>9@80N5D[00@0NEH/07YG;@1jEbd0NeP^0P1lFBl207EE;P0307AD
;@1cDb`0LE4Z0080L50Y0P1_CbP206m;9`03071<:01aCBT0LThZ0080M50/00L0ME4]07]H<01kF300
NEH^07QE;@1fDb/0ME8Z0080Le0X0P1aCBT2071<:0<0Kd/W01H0KTXV07=@:01eDRX0Me@/07QE;@1i
ERh0N5D]07IC:`1eDRX0L54R07AE9`1gF2X0M5DY06m?9P1]CBH0L50Z07AD;P1cCbl0KTXZ06]79`1]
BBT0M50`0P1hE3@05`1eDC40NePb07YG<@1hEBl0Me@^07IC;@1gE2h0N5D_07UF<01kF300O5Ta07iH
<@1oF340OeD_07aB;01jCRT0N4`W07YD;`1gE2h0MU<]07=A:`1aDBX0KU4Y0080K50X0P1bDR/2075A
:P<0L50Y0P1_CbP03`1`D2T0LE4Z075A:P1aDBX0KdlX06i>9`1/C2D0J4LV06a;:P1aD2l0M5<b07=B
<@1_CRd0J4LV06A38P020758;0030719;01_BRd0KT/]0080KD`]00L0K4d^06m?:01^CRL0KDdV06a<
9@1[Bb@0JTXS0080JDTR0P1SAR@0101TAbD0IDPV06E89P1VBBL206M::00306a?;@1[CR`0JTd[0080
JD`Z00<0Jdh/06e@;P1_DS00201]CbT207M@:@0307I@:@1dDBT0Le8Y0080LU8Y00@0L5<Y07AA:@1f
Db/0N5D]0`1kF30207YG;`0607UF;P1jEBP0NeHY07iI;021G2l0PUd`0P23GS402P22GC00RfHi08UT
=`27HSD0QF0c08AO<P25H3<0QV4d08MR=@26HS8208EQ<@0508AP<023Gbl0PUh^089N;P21GBd00P27
GS803026H3<0QF0c08IQ=024HS@0Pf<d08AT=@1oFS00P5/a085L<P22GC<0Pehd08AO=@80QF0f00<0
NeP`07YG;`1hEBd00P1gE2`0101hEBd0NUL_07]H<023GCH208=N=00308=N<P24Gc80Q60`0080Q60^
0P1lH3001P1kGbl0NEd]07QL;01gFb/0MUXZ07EI:@<0NeP`0P1jEbl307UF;P<0NU@`:oooool002[o
oooo0P2WNdX20:IjB@040:EiB02TN4L0Y7Q70:=gAP<0XWM<0P2SN4d30:AiCP0;0:MoB`2UODT0XgY6
0:9gA02SMD<0YGE40:IfA@2YMdH0XgQ50:EjA`2VNdP00P2WO4T00`2VNdP0YGY70:=hA@020:MlB@80
YW]800@0YGY70:AiAP2TNDH0XgQ5202WO4T00`2YOTL0Z7e60:IkA0020:Ai@P030:Ej@`2WO4D0Z7e6
0080Z7m90`2WOTP30:ImA`/0Yga7102XODP20:UnB@80Z7m;0P2YP4`0102ZPDd0Zh9>0:b3C`2/Pdl8
0:QoB`80Ygi80P2VODL30:ElAP060:AkA@2KNTD0VWU409ahA02MN4@0WWI30P2NM4801P2OLd80Ug8n
09Mb?P2FLCd0UG0l09A_>`80Tfhj00L0TVdi08mZ=@2?JSH0SVTe08iX=`2=IcP0S6Hi0080S6Dj0P29
HcH208QR=@0408MQ=026H3<0QElb08EO<P80Q5Xb00@0PEXa07mJ<01nFBl0NeP^0P1iF2d0401fFBl0
MeX`07MJ<01gFS00MEP^079E:`1_DRP0KE0V07AD;@1bDR/0L50Y06m?:01^CRL0KdlX071@:@1bDR/3
071@:@<0KdlX0P1^CRL2071@:@06079B:`1dE2d0MeL`07UI<P1jFS<0Ne/d0P22GC0208=N<@80Q5lb
0P25H3<208YT=@<0RfDf0`2<ISL808]W=`80SfTj00@0SVPi08eW>02;ICH0RV@e0P29Hc@00`2:ISH0
RfLg08aX>00208eY>@0308]W=`2:ISH0RFDe00P0S6Hi0P2<ISL308eW>0@0SVPi202>JCD308YU<@D0
RfHb00H0U6Pk09=X>`2CJ3/0TFPj08iX>@2<J3P208YX>0<0TfPk00<0TVLj095V>@2@ICP00P2@ICP0
1@2<ISL0SFLh08eW>02>J3T0SfTj0080T6Xk00d0TF/l08mY>P2<ISL0RF<d08IP<@25Gc00Qf4b08YT
=@2<ISL0SVLl08aU>P2:HcP0R64f0080Qf0e00<0RF8g08YS>02:ISH00P2:ISH00`29ICD0R6@d08MS
<`0208MS<`0808aW>P2;IST0RVDh08UT=`28HcH0Qf8e08IQ=025H3<208IT=00408ES<`24HS80Q68b
08=Q<@80PV0`0P25H3<208AO<P<0Peha00<0PUd`07iK<`1mFS800`1lFC401@1nFc<0P5de085N=P1m
FS00O5T_00<0NUL]02/0O5T_07iK<@1oG380N5/_07MJ;P1fFBl0M5L_07=E;`1aDbl0L58^06mA;`1a
Dbl0L58^06mA;@1]Cb/0JddY06U;9`1XBRH0IdTU05I2:@1D@2L0CcdU04/k8P18>B80ACTS04Dh9@14
>BD0A3PN04<g7`0o=A`0>c<L03Pb700g<Qh0=C8O03Hc800h<Q`0=c4K03@_6`0`;AX0;2/I02PY6@0V
9aL092HH00<0:2PN0P0W9ad402HV70808RDL0P0Q91/0100P8aX07b8I01hQ600N8AP801hQ6P807B0I
00@07R4J01lR6`0Q91d08RDN0P0S9Ql0200Q91T07b8G01dP5`0K7QL06Q`G01XL6@0K7AX071hM0P0L
7Q/201dO70<07R0M00`07b4N01lP600P8QL08R@I02@V6@0V:1X0:2/J02T/6@0Z;AX0<34Q02l`800]
;Qh202//700;02`]7@0^;al0;c0P02lX800Z9Qd09b8L02<P6@0Q81/08b@O02HX9@0Y:bP00P0X:Ql0
100W:Ah09RPM02HX7@0U9a`202@V6`<08RDN0`0Q91d2020S70P07b4N200O8Q/2024S600N020R5`0Q
8aP08bDJ02DW700X:Ql0:R`Q02XY900^:b@0=2hP03`a7@17>A`0FdTU075L<@20JCd0S74j099g@02J
O4P0XH5@0:V7E`2WPUD0SfXn07E>8`10@2P0<BlP02DT7`0W9bT09RL[01lS8P0Q:200:S8S200T9R<8
02HW8@0302DX7`0W:R40:2/R0080:RdT00@0:2/R02LZ8@0U:1l09BPO0`0V:B800`0W:R<0:2/T02T/
9@0202T/9@809bPP0P0X:B4202TZ8P80:R/S0P0`:bL0300`:bD0<BdT03<_900f<RH0>CHW03/h:@1:
>BT0BSTW04/h9`1=>2D0CcTT050j8`80Dc/S201<?2D02@0o=RD0@3LV044h9`12>BP0A3/Z04Hm;017
?Rd0B3l^04dj:`0204`k:`0304Xj:P18>bX0AS/Y0080A3`Y00H0AC@T04He9@17=RH0B3LW04Xi:@1<
>b/204dl;00:054l9`1B?BP0DShV05<o9P1D@2D0ED8T05I39@1F@b<0DD4Z0592:`80Dd</01d0DT8[
0551:P1>?RL0CCdV04a0:01:?RP0B3`V04Tj9`19>2P0C3T[04di;P1A>c00C3l^04/n;@1:?B`0BC`[
04Lj:@16>BP0ACPW04@g9P0m<2L0?c<W044e:@13=bT0ACTY04Dj:014>BD0@cPT03dj:@0703`i:00:
040h9@11>BH0@SXW048j9`11>BH0?SHS03/c800i<Ah0=C4U03@`90<0<RhR01/0=30T03Lc9`0h=2P0
?C8^03db;00o<RX0@S@Y04Hf9`1;>RP0CSdY054o:@1NAC40GTD_0616:`1UBbP0KE4Y07IJ:P1oHBd0
Q6L_08Y_>02;KCL0RF/e08QY<`29J3<0S6Pd08mZ=P2@JcL00P2EJCX02@2BISL0TVLd09EZ=@2KLCL0
WgHh09mf=P2LLc40UVlf09M`=`0209Qa>00409M`=`2DKC@0TFXa091Y<080TFHc01H0TVLb09=X<@2D
JS00UF/a09E[;`2FKBl0Wfhd0:1_=@2RLCH0YGDg0:Qh>02[NcT0[Whl0:n0?02`NS@0/7/g0:im>P2/
Och0Yh0o0::0@@2MOd40Vgi2102ONd440:1l@P0409]h@02LND40WGY009mm@080Wgdn0P2OOCd0402G
Od40VX9609b4B02IP4L0TWU108ie?`2@MT<0U7Y7095iB`2=MDL0R71208E]?`23Jcd0QFdo08Q`@P2:
LT@408EY>P@0QVXk0P28K3d02@29KCh0R6`m08M[?025JCX0PVHg081T=@1lH300OF4a07mS<`02081T
=00307iR<P1lH300Nel_00D0MUXb0`1gFc<2081Q<`0@07iR<`1mHS<0Nf<c07YT<`1iHc80N6@b07UU
<`1mIcH0OfTh07eU=@1jGc00NUh_081Q<`25ISP0OfDd07iT<`<0OF<b00/0OV@c07mU=020ISD0O6Dk
07QQ=@1fGc<0Mf4b07YT<`1kIC<0N68`07EP:`0307YP;`0307UO;P1hGRd0N5h]0080Med/00@0NEhc
07QM<P1gG340MU/`101eFRl04@1gER/0N5L/07QG;01jFbl0NUda07YO<P1hH380Mela07EO<01ZGRh0
JUd`06QK;P1WFRh0IEP^06=E;P1RE2l0HE<^0080H4`W0`1QCBP3069>:@0>065C;01ND2T0G4hW05i@
:@1SEBh0IUPa06EG<01RE2d0Ge8X05e?:01IBb@0EDLR0553801?@1l204ho80P0BSlS0P1:@B@604]2
9@0604M17`17@B40AT0P04Ho8P15?R80A3dS0P13>b@0100o>b00?SXO03hj7`0n>Ql203di7P80?3PM
0P0m?1h203`k7@0403/j700j>A/0>STK03Th6P80=SPP00@0=CLO03@f7P0c=Ad0<S@L0P0a<a/8034c
7P0H02d_8@0^;al0;BhN030_7@0c<1d0>3<O03`f800n>280ASDK04Le7@17=ah0AcPQ04@h8P12=B80
?c@R03db800h;1h0=B`M038Z7@0]:Ad0:BLK02@V6`0Q91T07R@J0`0L7Q/201/M6PD06Q`I0P0I6aP2
01PJ5`805aTF400I6aP0100G6AH061XG01TK600I6aP201XL6@0301TK600H6QL05aTF00P06QXH200I
6aP201/M70806Q`K100I6aXH01LI60<061XI0`0G6APj01HH5`805aTH0P0H6QT301TK6P0301XL6`0I
6aX06A/J00H06A/J200J71/801TK6P8071`J100M7A/301hN708071`J0`0M7A/;01hN70807QdH0P0O
7QT2020O6P808B0K0P0R8A`302<R7@<092<N0P0U9Ad202@T700402<S6`0R8QX08R8J024Q6@<0;RDP
0P0]91l302`S7P<0:BDL0P0Z9Qd302/W7P04034T7P0b9Al0<RDO038U7`<0<bHP00L0=2LQ030U8@0`
9Al0<2DO030V7@0a9ad0<BLK0080<BPI00H0=RTI03LZ6P0h:a/0>B`L03X]7@0l;al203d`8003048a
7`11<1h0?bhL0080?B`J00/0?RdK040_7@11<1h0@c4K04@b7015<ad0AS@N04Le7`18=R00BCLQ04Xh
8P02050e8080DCHQ0`1B=b800`1C>2<0EC`N05Dl7P0605Dl7P80FcdS00<0F3dR05Hl8@1D?2000P1@
>ah0101>>ad0BcXP04/j801;>R0304Xi7`80BCPN00P0BcLO04di8@1@?2@0DShV05<o9`1B?RH0DCdU
050l9080D3PP00@0DCTQ058j8P1D?2@0ECdU0P1F?RH205@l9080ECdU101F?RH01P1G?bL0FT8Z05Y2
:P1I@BT0F40X05Lo9`80ECdU00@0E3`T04hj8@1>>R40Cc/R0P1@?2<00`1A?B@0DShU058n9@03058o
8@@0DChP00<0D3dO05Hn9P1F?RH00P1F?RH405Dm9@<0ECXM1@1D>A`00`1G?2L0ES/V05@i900205<h
8`0305@i901F>bH0Ec`W0080E3/W00@0EC`V05Hn9P1F?R@0EclS0P1H@B800`1I>b40FcdS05do9@02
05m19`0305do9@1K?B<0FC/Q00@0Gd0Q101P@B8206Q7900406U89@1[BRL0K4/X06i=:P80Kdh[00P0
JdlZ06Y>:@1ZCRT0JThY06]?:P1]DB`0L5@_075E<080LUD]0P1cERh307AG;`0307EH<01kG300Ne``
0080NU/_00X0NEX^07QI;@1hFBd0MeP/07MG;P1hF2l0NUXa07aL<`1mGC@0O5`c0P1kFc80101kGS80
NUda07UL<01hFbl207MJ;P80MUT]00D0LE4Z079B:`1cDb`0M5@]07EE;P0307IF;`80LU8[00H0Le</
07EE;P1fERl0MeL`07QH<@1iFC8207IF;`80MED^00@0M5@]07=C;01cDb`0LU8[0P1aDBX2071@:@0=
06m?:01^CRL0KThW06i>9`1]CBH0NE<^07EB;01dDB/0LU0Z075A:P1`Db/0LED]07=G;`03079D<080
LE<_0`1`DRh0201YDB/0JU0[06]A;01]DB`0Ke4]075@;@1bD2d0Le4^0P1^DBT00`1_DRX0L5<[075D
;002079E;@0307=F;P1^DBL0KU4W0080Ke8X0P1`DbT2075D:P80KE4/00<0KU0/06m>:`1`CR/00P1a
CB/01`1cC2/0KdlX071@:@1`D2T0LE4Z079B:`1cDb`00P1dE2d02@1eEBh0N5H`07UG<@1lFC<0OELb
07eE<@1mDRl0Ne0]07=B;`0507AC<080ME@a00P0MUDb07AC<01aD2d0Kdh[06i=:P1_CR/0L4l/075@
;@<0LT`X1@1aBbL00`1[BBH0KD/X075?;00207=A;P0=075?;01]BbP0JdTV06e;:01/BRL0JTTV06M9
9@1VBRD0I4XU06E;9P1UCBL0J4`T06U=9@0206Y>9`0406U=:01WBRP0IDPX06=69P80Gd/V00<0HD/V
069:9P1SBBH00P1UB2H02P1VB2H0JTTV06]:9`1]C2T0KTdZ06e<:@1/BbP0JTTV06U89@1ZBBH406]:
9`<0K4/X00`0JD/W06Y<9P1]CBL0KddW079?9`1eD2H0MU4U07QA9P1cD2X0M54[07EB;01fDbd207MD
;P<0MU<]0P20ERh01`21Ebl0PeTa08AJ<P25Fc<0QU`d08MM=@20GC<00P21GS@00`22GcD0Pf0f08AQ
=`0208ER>0<0OU/a0P1oG383081M<`0407iM:P1oGR/0Oeh[081O;080PF0]0P22HBh01P1oGBd0OU`/
07iL;01mFb/0O5XZ07]I:@80NUPX01/0LEHY079G:P1cERX0MUL[07QG;01jEbd0NeP^07eH;P1hEBd0
NEH^07]H<01mFS80Oe`d085N=P22GcL0Pf0h07QH<@1jFS<0O5`e07eM=P1lG3D0NETb07IF;`1cDb`0
M5<`07IE<P1hEc@00P1iF3D00`1hEc@0MUDb07AC<00307EE;2_ooooo000Zooooo`80Yg]:0P2VNTT0
102UNDP0Y7Q70:AhA`2TN4L30:9gBP80XgQ;0`2TND`02`2UODT0Y7a80:=jAP2RMd@0Y7I40:IfA@2W
MdH0ZWQ70:=hA@2UNTL0YW]80080Yga900<0YW]80:EjA`2SN4D00P2WO4T20:IkB080YGY70P2TNDH8
0:MlB@080:UnA`2XODH0YW]40:Ej@`2TND80YGY30:MlA@2XODH20:QoB@<0Ygi80`2VODL;0:MlA`<0
Z7e80`2YOTT30:QoB`80ZH1<0`2ZPDd80:QoB`80Ygi80P2VODL40:ElAP80W7]600H0WGU509ehA02N
MT<0WWA209ec@@2NLT4209Mb?P0409Ia?@2EL3`0U6lk09A_>`80Tfhj00T0SfXe08mZ=P2?JSH0SVPg
08eW>02<IST0S6Dj08]T>@2:I3L00P29HcH00`28HSD0Qf4d08IP<`0208EO<P80Q5Xb00T0PEXa07mJ
<01nFBl0NeP^07YI;P1iF2d0M5@[07EE;01gEbh00P1hF2l01P1fERd0MED/07=C:P1dE2d0Le</075A
:P<0KdlX00<0L50Y075A:P1`D2T00P1`D2T306m?:080KThW00d0L50Y075A:P1bDR/0M5@]07IF;`1h
F340NETb07YJ<`20Fbh0PE`_089M<023GS40Q5lb0080QF0c00@0QV4d08US=029Hc@0RF<d0P2:I3D3
08]U=PP0RfLg0P2;ICH408aV=`80SFLh00<0RVHf08]W=`2<J3P00P2=JCT00`2;IcL0RVHf08UU=@08
08aV>@80S6Hg0`2=IcP408iX>@P0SVTe202;IS801P2DJ3/0TfPk099W>P2AJ3X0SVPi08aX>080RVPh
0P2CJ3/2099W>P04095V>@2@ICP0T6Dh091U>080SFLh0`2>J3T308mY>P0308iX>@2<ISL0RF<d0080
QV0a00H0Qf4b08YT=@2<ISL0SFHk08]T>@29HSL308QQ=P0408YS>02;I3T0RVHf08YV=P80RFDe0P28
I3@208MS<`80RfHi00@0RVDh08UT=`28HcH0Qf8e0P26HC@00`26I3@0QF<c08ES<`0208AR<P80Pf4a
00<0PV0`08EP<`25H3<00P24Gc8408=N<@0307iK<`1mFS80O5Ta0080O5Ta00H0OU/c081M=@21GSH0
Oe`b07iK<@1lFBl207]H;P0;07aI;`1nFc40Oe`b07QK;`1gFRh0MUT_07EH<01cEBl0LE<_071B;P1`
DS000P1aDbl0101_DBd0KDl[06]=:@1ZC2P206Q:9P0>05M3:01E@BP0D3lU04`l8`18>B80ACTS04Dh
9@15>RH0ACTO04<g7`10=Qd0>c<L03Tc7@0g<Qh203Hc800803Tc7@0h<Q`0=S4M034^6`0^;A/0:BXJ
02LX600U9aT302PX7P<09bLM0`0V9Q`01P0S9Qd08RDL028U700Q91/082<J01lR6@807R4H200N8AX2
01dP6@0>01hQ6P0O8Q/082<L024T7@0R9Ah08bHO024T6@0O8QL07B0G01/N5`0J71L06Q`I01/M6P0L
7Qd201`N6`807AlL100N81d02`0O81P0824I024S600S9AP09BLI02LZ6@0Y;1/0:RdJ02l`800^;al0
;2dM0080:b`L00/0;2dM02d^7P0_<200<2TO02`X7`0X91/09B8K028Q700S91l09BLT02LY9P0302LY
7P0302HX7@0U9a`09BLL008092HK0`0R9Ah3024T7@8082<L200O8Ah801lR6`0P024S600P8QL0828G
020R5`0R91T09BLL02LY7P0Y:b00:2LR02`Y8P0b;200=blJ04<e6P1C@b40J5D]07MR=`2<LC`0TWM2
09QjB02KOD/0XX9C0:B2E02GLTH0QF0d04U5:P0i=200;2PO02/Z:00Z:R`092HU020U7P0S:ah802@V
8`P09RLQ00<09RTP02LZ8@0X:b800P0Y;2<0100X:b809bXQ02HY800V:B0202HY8P809bXS0P0X:b@2
02T/9@809bPP0P0X:B4202TZ8P80:R/S0P0`:bL0300`:bD0<BdT03<_900f<RH0>CHW03/h:@19>BT0
BSTW04/j:01=>bL0CcXU054k9080E3`T201<?2D01P11>2L0@STX048i:013>RT0A3/Z04Dl:`80ASd/
00H0C3TZ04/j:P1;>RX0BCTY04Lj:@15>RP204<k:080AcHV00<0B3LW04Th:01:>BT00P1;>RX0:@1<
>b/0DC`Y054l9`1B?BP0DclW05A09`1E@BH0ED8T05I39@1A@BX0DT8[05=3;01DA2d0Dd</0551:P1?
?bP0CShW04a0:01;?bL0Bc`W04Xk:01:>BT0BcT[04hk;@1?>c00Bch]04Xm;019?2/0B3/Z04Hi:015
>2L0A3LV04<f9@0m<2L0?S8V040d:012=RP0A3PX04@i9`13>2@0@SLS0080?CXY0P0l>BP403/h9`03
03`d8@0n=R<0?cLT0080@CTV00D0@3PU03lg900n=R<0=S<T03Db8`0303@a8P0K03Hc900h=BH0>CHW
03db;00m<bX0@3<Z048d9`17=bL0C3/Y04lo:01B@2X0GdH`05m7;`1QAb`0ID/X06eA:@1fFR/0Of4]
08=U;`29KSL0RV`f08QZ=028JC<0RFPc08aX=02>JCD0SfXf0080TfTi00T0T6Hf08mU<`2CJS@0V6lg
09ad=`2KLcD0V70b09=/=@2DKCH00P2EKSL07@2DKCH0TFXc08mX<@2=IRl0SV@b08mU<`2?IS80T6La
095X<02BJRl0Tf/`09=[;P2GJ300V6Ta09Y/<@2MKc<0X78d0:=f=@2UN3D0YWTf0:ag<`2[N3H0ZgXh
0:Ql>`2UOCl0XGdo09em@02KOD40VgLm0080W7Pn0P2MNCl309ij@080WWU201H0Wg]10:1l@02QOCl0
Xh100:B1@@2UPT00XhU<0:J<C`2WSE80Y8YA09j4B`2KP4T0WH9=0:25D02DNDX0TWM808icA02<LD80
RVm008]`@@2=LT<0SW=41P2;K3d208a]?P80RFdn00T0RVho08U]?P28K3d0QVXk08=W>021ICH0OV8b
07mS<`20I3@00P21ICD00`1oHc<0OF4a07aP<00507]O=`<0NUhf0100PF0c081Q<`20HC<0Of<d07iS
=01lI3@0NfDd07aV=@1kIC@0OVPg081X>01oI3D0O60a07eN<022HcD0QfHi0P1oIC800`20IS<0PFLd
085W=003085W=004085Y?@1mICT0NV8d07YR=080O6@d00@0N64_07AM:`1jGc00NUl`0P1iGRl0101h
GBh0Me`]07IK;01fFb`207QM<P80Me`a00D0MU/`07EJ;`1eFRl0MEX_07MF:`0207QI;@0>07YK;`1i
G300NEha07MO<@1eGc00M5h_06]O;`1ZGC00J5/^06II;@1TEbd0HU@]065C;P1PDRd2061<9`<0HDdX
0`1RCRT03P1ODBX0GDlX05]=9P1ND2T0HeD^06IH<@1UEc00HU@]05e?:01KCBH0EdTT05=58P1@@B00
CSlN0P1=?Ql804Xo8`@0BT4T1019@2<01P16@1h0AT0P04Do7`14?B00A3dQ04<l8P80@SXS100n>Ql2
03di7P80?3PM0`0l>al203/j7P0403Xi7@0i>1`0>CPL03Hh8080=CLO00<0=3HN03<e7@0b=1`00P0a
<a/8034c7P0H02d_8@0];Qh0;BhN030_7@0c<1d0>3<O03`f800m=b40AcDM04Hf7@17=b00ASLP048f
800o=200>S8O03Ta7P0d:a`0<RXM030Z700[9a/09RHJ028T6@0O8QT0728H0P0L7Q/301/M6PD06Q`I
0P0I6aP201PJ5`805aTF400I6aP0100G6AH061XG01TK600I6aP201XL6@0301TK600H6QL05aTF00P0
6QXH200I6aP201/M70806Q`K0`0I6aX00`0H6QT05aTH01LI600F01LI60<061XI0`0G6APj01HH5`80
5aTH0P0H6QT<01TK6PP06Q`K200I6aX301`L6P<07AdK0`0N7Q`201`L6P<07AdK2`0N7Q`201hM6080
7ahI0P0P7aX2024P6`<08R4L0P0S8Qd302@S7P809BDM0P0T91`0100S8a/08R8J028R6P0R8QX302`S
7PD0;B@O0`0Y9A`302XV7@80:bLN0P0a9R06030U7`06030U8@0`9Al0<2DO030V7@0a9ad0<BLK0P0a
:1T01@0g:QX0>2/K03P[6`0i;1`0>RdM0080>bhN00@0?2lO048a7`10;ad0?bhL0P0m;1X00`0n;A/0
@2lM044`7P0204@b700304Dc7@16=1h0AcDO00<0B3HP0`1?=R02050g8@<0DCPR201D?Ah01P1J?2@0
F3`T05Lk8`1E>b80Dc/Q050k8080CSXO0`1;>R0204Xi7`<0BCPN00P0CCTQ04hj8P1@?2@0DCdU058n
9P1A?BD0D3`T04lk8`80D3PP00H0DCTQ058j8P1C>b<0E3`T05Dm9@1F?RH305@l90<0ECdU0`1F?RH0
1P1I@BT0F40X05Lo9`1F?RH0ECdU05@l9080Dc/S0P1>>R4204lk8P80D3`S0P1A?B@5054m8P<0D3`Q
201E?BD305Hk7P<0ECXM0P1D>A`00`1F?BL0E3/U05<j9002058i8`0905<j901D>bD0ESdW058i9@1C
>RH0DcXT05@l901E?B<0EShR0080Ed0Q0P1K?B<405do9@80FcdS101O@24406118P80J4LT00L0JDPU
06]:9`1/BbP0KD`Y06i=:P1_CR/0JdlZ00<0JThY00@0JdlZ06eA;01_Dbh0LED`0`1bEBd207=F;P<0
M5L_0`1jFbl00`1iFRh0N5T]07QI;@0207MH;00307MG;P1hF2l0NUXa00<0O5`c00<0Ne/b07YJ<@1f
FBd00P1fFBd307EH;080M5L[0`1cDb`307AD;@80MED^0P1cDb`0101dE2d0MED^07EE;P1fERl207MG
<080MUH_00@0MED^07AD;@1dE2d0Le</0P1bDR/00`1aDBX0L50Y071@:@0206m?:0<0KThW00X0KDdV
07QB;@1eDR`0Le0Z075?:@1aDBX0L5<[075E;@1bERh0LU@`0`1aDbl2071B;P80Ke4]00H0JE4[06Y@
:`1ZD2/0KE4/06i@;01aD2d2079@;@80Ke8Z00@0L5<[075D;01bEBd0LUD]0P1cERh00`1^DBT0Ke8Z
06mB:P0206mB:P<0L5<[0P1/D2/00`1]Cb/0Kdh[071>:`02075=:`0707=<:`1_CbP0KdlX071@:@1a
DBX0LU8[07=C;00207AD;@0807EE;P1fERl0N5H`07YG<@1lES40Ne<_07UA;@1jCb`507=B;`@0M5<`
00<0LU4^071?;01^CBX00P1]C2T00`1^CBX0Kdh[06i:9P0706i:9P0306]99P1]BbP0L4h[0080LU0]
00/0L4h[06e;:01[BBH0JdTV06a:9`1[BRL0JD/W06Q<9`1UBbH0I4XU06=;9@0206M;8`0606Q<9@1X
C2L0IdXX06E8:01SARH0HTDW0P1LB2D0201OB2H0H4PV06989`1TAbL0IDPX06I7:01YB2D0JTTV0`1/
BbP0101[BRL0JDPU06Q7901XAb@206U89@0306Y99P1[BRL0JdXW0080K4/X0P1YBbL02P1/C2H0KThW
071?9P1bCbD0ME0V07IA9@1aCRP0Le0Z07IC;@1hEBl207UF<080Me@^00L0MU<]081F;P21Ebl0PUP`
08=I<@25Fc<0QU`d0080Qede0P21GS@3089O=@<0Pf0f0`1nFc4307mL<P80P5dc0P1nGBX207mN:`04
081O;021H2d0PF0]085P;@80OU`/00<0OE/[07aJ:P1kFBT00P1jF2P01P1iEbL0LEHY075F:@1cERX0
MUL[07QG;080NUL]00L0OEP^07YG;`1jEbl0NeP`07eJ<P1nFc<0Oe`d0080PEhf00/0NETb07YJ<`1j
FS<0NUXc07UI<P1hF340MUH_07EE;P1dDc00ME@a07MF<`0207QG=00307MF<`1eE340M5<`00<0MED^
:oooool002[ooooo0`2VNTT30:EiB080Y7Q70`2RMdX20:=hB`<0Y7U<00/0Xg]70:9jAP2RNDD0XgQ5
0:EgA@2XN4L0ZGU80:ajB@2SN4D0YGY70:IkB0020:MlB@030:IkB02UNTL0XgQ50080Yga90`2VNdP3
0:EjA`P0Yga900<0Z7e80:MlA`2VNdH00P2UNTD00`2VNdH0Yga70:QmB0020:QoB@<0Ygi80`2VODL:
0:MlA`80Z7e8102YOTT00`2ZOdX0ZH1<0:V0C0030:QoB`<0Ygi:202XOd/30:MnB080YWe70`2UO4H2
09imB00709ijAP2NNDD0WWI309ec@@2LLT00W70o09Qc?`0209Mb?P0309Ia?@2EL3`0U6lk0080Tfhj
00P0T6/f091[=`2?JSH0SVPg08eW>02<IST0S6Dj08]T>@80RV@g00<0RF<f08QR=@27HC@00P26H3<0
1`25Gc80Q5Xb08AJ<P21FS40P5/a07mJ<01lFBl00P1jFBh0101bDRT0Le<Z07EE;01gEbh407QH;`03
07AD;@1cDb`0LE4Z00<0L50Y0P1aDBX3071@:@<0KdlX0P1^CRL2079B:`0407=C;01dE2d0MED^07IF
;`80MeL`0P1nFB`01P20Fbh0PE`_08=N<@25H3<0QV4d08MR=@<0Qf4b0P28HS<308US=0P0RfLg00/0
R68c08US=02:I3D0RfDf08eW>02>J3T0SfTj091Z>`29ICD0RVHf08aX>00208eY>@0308aX>02:ISH0
RFDe00P0S6Hi0P2<ISL308eW>0@0SVPi202>JCD808]V<P0609=W>P2BIcX0TVLj091W>@2>J3T0S6Ph
0P2:J3P3099W>P80TFHi0`2@ICP208mY>P<0SVPi0`2=IcP0202>J3T0S6Hg08US=027HC80QV0a08QR
<`2:I3D0RfDf0P2:I3L308US=P0408YT=`2;ICP0S6Hi08YV=P<0RFDe0`28I3@01P27Hc<0RfHi08YU
>02:ICP0RF@g08QS=P80Qf8e00@0QV4d08ES<`25Hc<0QF<c0P24HS8308=Q<@<0QF0c0P24Gc8308=N
<@0307iK<`1mFS80O5Ta0080O5Ta00L0OU/c081M=@21GSH0PUle085N=01oG380OU/a00<0OEX`01l0
OU/a07QK;`1gFRh0MUT_07EH<01cEBl0LU@`075C;`1aDc40LU@`075C;`1`DRh0KU0/06a>:P1ZC2P0
JD/W06Q:9P1HABL0ET8W0550901=?B<0BC/Q04Hj8P16>R@0ACXT04Di7`14>200@3HM03`d7@0i<ad0
>3<O0080=c@Q00P0>cDO03Xd7P0g<Qh0<c0M030_7@0/;Ad0:R/K02PZ7080:BTO0P0X:1h402LW7@06
02HV700S9Qd08bHM028U700Q91/082<J0P0O8QT00`0N8AP07R4J01hQ6P0601hQ6P807B0I00<07R4J
01lR6`0P8a`00P0Q91d01P0R9Ah08B@I01lR5`0N8AP071lH01/M60806adJ00@071hM01`N6`0L7Q/0
71hK0P0M7a`301hP7@0601lP6P0P8A/08B8J02<U6P0U9aX09RPJ0P0X:aX00`0^;al0;BhN02`]7@02
02//700<02`]7@0];Qh0;RlO038/800^:Ql0:bLL02LT6`0T91`08b@N02<U800T9R409bTN0`0V:1d3
02DW700402@V6`0R9Ah08RDN028U7P<08B@M0P0P8a`801lQ7PP07b8K02008B8J020Q6@0P8AT0824I
024R6P0T9Ad09RLO02PY8@0X9240:bHP02lY7@0c:QT0>blG04Tj6`1IBBD0IU@^08E[>P2>M4<0U7Q8
09IgB02KNd`0XX1B0:5oD@2LMdX0GEDa04Y09@0f;al0<RXW02l[;00X:2H08B@M01`R5PP092HS200W
:2800`0V:B009bXQ02P[8P0202T/8`0502P[8P0W:R409RTP02HY800V:B800`0W:R<302P[900302T/
9@0W:2009bPP0080:2TQ0P0Y:R8202X[8`0>034/:00`:bL0<2/U034]900c;b@0=C4U03Pe9P0j=bP0
BCTY04Xk:01<>bT0CS`X04lm9`1B?RH205<m9@P0C3`U1`16>bT01`17?2X0BcPY04Xi:@19>2P0B3PX
04Dh9`14>BL00P11>BH804Th:00:050k:01A?2T0DC`W058n9P1C?bH0E40U05E19P1E@R@0Dd4Y05A2
:P<0ED<[00T0E48Z0590:01A?bL0Cd4W04ho:01>?RL0C3/W04`k:@1<>b/00P1=>bd204Tl:`0404Pk
:P16>BP0ACPW04<f9@80@SDT00H0?2lV03da9@10=2P0@CDW048f9P12=bD2044f8P80?cXW0P0n>BH0
200m>2D0?3LT03`g900k=R<0>S8O03`d8@0n=R<0@3PU0P12>RL01013>bP0@SXW03/e9`0j=2H303Tc
9@0K03/e9`0l=RP0?CLY03le;00o=B/0@CDY04@g9`19>RL0CShW0551:01EA2X0HDTa0659;`1SBR`0
IT`Y06iB:P1eFBX0OV0^089T<026Jc@0R6Xd08MY<`27J380R6Lb08]W<`2=J3@0SVTe0080TVLj00L0
SfDe08eS<@2@IS@0UF`f09M^>02EK3@0Tf/`0080S6Lc0P2=J3@02P2<Ic<0RVDa08UT<027HRh0Rf4a
08aR<P2<HS00SF@`08iU<@2?IS02091W;`0@091Q:`2AHR`0Tf@/09IX;@2IJbl0Vfd_09e_<@2NLC00
Y74`0:Ac<@2UMCD0Y7Pi0:9j?02NNS`0W7Xm09Ui?080V7@h01H0VGDi09]g>`2LN3`0WGTm09ij?P2O
Ncl0XGe30:1l@P2ONcl0X7`n0:9o?`2VPd40ZXM50:f:AP2[Sdh0[91A0:fADP2[SU80YhY@0:F8D02V
R580Z8YD0P2GNdT00`2FNTP0U7Q609=gA@0309=gA@P0TG=100P0Rflo08a`@02<L400S71008Y^?P28
K3`0QFTi08AX>080PFDe0`22ISH00`21ICD0Of<c07iR<P02085V>`80P6Dj00@0Of@i07iS>01nHcP0
OF8g0P22HS<01`22Hc@0P6@d081V=@1oJ3H0P6Tg07mY=`1mIcD00P20JCL05@20ISD0OV8b085R<`25
ICH0R6Pi081T<P22IS@0QFTg08Q/>P29KC/0Qf/i08EY=`24J3H0RFi108AY?020ICP0OV<f07iS=01m
HS<0N5d^07AI:P0207YO<P0407UN<@1hGC00MU/^07EJ;@80M5T/00D0Me`a07QM<P1hGC80N5db07ML
<@0207IK<00807EJ;`1gF2`0N5T]07QI;@1hFbl0N5d`07IN<01eGc02079M;P0806aN;`1[GC00JE/^
06MH;@1TEB`0HE8[05m?:`1NCRX205m=9`<0H4hX0`1QCbT03P1OD2T0G4dV05a=9P1OD2T0I5D^06MH
<@1UERl0HU</05Y<9@1HBRD0E4HQ05127`1>?ah0C3dN0P1<?B0804Tn8P0404Y19019@2<0BD0S04Po
8P80AchQ0P16?B001P15?ad0AClO04@n7P13?1l0@S/O044j8080@3PQ0`0n>Ql203di7P<0?3PM0P0k
>Qh303Xi7@<0>CPL0P0e=al0100d=Qh0<cDM038d700b=1`2034c6`P0<38M01T0;2hP02d^7P0];Qh0
<2lM03<`7@0g<Qh0>cDO03dg8@15=ad0ACHO048f7P10=Al0?3@O03Pa7P0e;Q`0<RdJ02lY6`0^:1X0
:RHJ02LU6@0S8aT0824I01dP6@0L7aP071hK00<06adJ0P0J71T201TK60806Q`I0P0I6aP201PJ5`80
5aTF400I6aP0100G6AH061XG01TK600I6aP201XL6@0301TK600H6QL05aTF00P06QXH200I6aP301XL
6`806A/J0`0H6QTH01LI60<061XI0`0G6APj01HH5`<05aTH0P0H6QTK01TK6P0301/K6@0L71X071`J
008071`J0P0M7A/201hN708071`J0`0M7A/;01hN70807QdH0P0O7QT2020O6P<08B0K0`0R8A`202<R
7@8092<N0`0T91`302<S6`808R8J0P0Y8Q`202XS7@0402/T7P0/9Al0;BHP02dV8080:2@K0P0Y9A`3
02XV7@0402/W7P0b9b40<RLQ034V8080<2DO00T0;b@N02hS7@0^8ad0;b@P02lT7P0`9Al0<2HM034W
7@0a9a/00P0b:AX803T/7080@2lM00H0?bhL03h]6`0n;A/0?bhL040_7@11<1h804Hd7P80CSDO0P1?
=R03050g8@03054h8P1C>al0Dc/O00H0Dc/O0P1G>bD00`1E>b@0Dc/S050j8P0204hj8@<0BcXP0P1:
>Al304Th7P0304Pg7@1?>b<0Cc/S00<0D3`T00<0Cc/S04hj8P1=>B400P1@>2000`1A>B40DSXR05<k
8`0205@l900305Dm9@1C>b<0Dc/S0080E3`T101E?BD305Hn9P0305Dm9@1D?2@0Dc/S0080DSXR00@0
DCTQ04hj8@1>>R40CSXQ0`1?>b82050l8`<0Cc/R1@1@?2<705@l900405Dm9@1F?240ES`Q05Hl8@80
EC/P0`1D>Ql00`1D>bD0DcXT058i8`02054h8P03058i8`1C>R@0E3/U0080DCPT00@0DSTS058j8P1C
>b40E3`P0P1E?Ql205do9@@0FcdS0P1M?bD205ho8080Gd0Q0P1P@B8206528`0906M68`1XAb@0JDPU
06Y99P1/BbP0KD`Y06i=:P1_CR/0K4hZ0080JddY00D0JT`X06]=:@1]Cb/0Ke4]075C;`02075D;080
LUD]0`1cERh00`1dEbl0NET`07QH;`0207QH;`<0MeL^0P1fERd00`1hF2l0NUXa07]K<P0207]K<P05
07YJ<@1iFC00LUD[079E:`1cER`01@1dEbd0101eEBh0M5@]07=C;01cDb`2079B:`80Le</1@1dE2d3
07EE;P80MUH_00<0MED^07AD;@1cDb`00P1bDR/00`1aDBX0L50Y071@:@0206m?:0D0KThW00H0MU0[
07=@:P1cD2X0LDlY075A:P1`Db/2075E;@04075C;`1`DRh0L58^071B;P80Ke4]0P1^D2`02@1XD2X0
JDlZ06Y@:`1/D2/0KU0/071?;01aCb`0LU0]06mB:P02071C:`03075D;01bEBd0LeH^0080M5L_1@1_
DRX306iA:@80K50[00<0KDl[06m>:`1`CR/00P1aCB/01P1cC2/0KdlX06m?:01`D2T0LE4Z079B:`80
Le</00T0M5@]079E;@1dE2d0MED^07ID;P1gE2h0Me4/07M?:`1fCRX0201bDBh0101aD2d0Kdh[06i=
:P1/BbP306]:9`0306a;:01/B2H0K4PV00H0K4PV00<0JTTV06a;:01^CBX00P1`Cb`04`1^CBX0K4/X
06Y99P1ZB2D0JdTV06a;:01/CRX0JThY06I<9`1SBB@0H4PR06A88@1UBB80ITXU06I99`1UB2H0HdHV
06549P1O@R@00P1HA2401P1KA280GDDS06169@1SARH0I4LW06E69`80IdTW0`1XBRP00`1VB2H0IDLU
06A6900206=58`0406A6901UAbD0IdTW06Q::080JD/Y00h0ITTW06M;9P1YBbL0K4`V06m=9`1aCRH0
LTlU07E@9P1^BbD0LDhX07IC;@1jEc40O5Tc07]H<P80NEH`00T0Me@^07mH;`1oF2l0P5T`089K<P23
G3<0Q5dd08EN=@26GcH00`22GcD3085N=080P5dc0P1mFS0207iK<@<0Oe`b00<0P5dc07iL;01nG2`0
0`1oGBd3081N;P80OE/]00<0O5X/07]I:`1jF2X00P1iEbT02@1hERP0L5DZ075F:`1bEB/0MED/07MF
;@1iERh0NUL_07aF;`0207]H<080O5Ta0P1mFS8207iK<`0407]K=01jFS<0N5Pa07IF;`80MED^0P1f
ERl00`1cDRl0M5<`07ED<@0207IE<P0307ED<@1dDc00Le8_00<0MED^:oooool002[ooooo0P2VNTT6
0:EiB0<0XWQ80P2SNDT30:AjBP80XGU500T0XgY60:AiAP2WNDL0ZGU80:YjB@2]NdX0XgQ50:EjA`2V
NdP00P2WO4T00`2VNdP0YGY70:=hA@020:MlB@H0YW]8202XODX50:IkB080Yga900<0Z7e:0:QoB@2X
OdT00`2WOTP30:ImA`/0Z7e8102YOTT20:YoBP80ZH1<0P2XOd/0102WOTX0YWe90:ElB02UO4P80:Qo
B`80Z7m90P2WOTP20:ImA`80YGa600P0X7m:09mnB@2PO4P0WWU509if@`2MLd40Vg4o09]_?P80V7<o
00<0Ug8n09Ia?@2EL3`00P2DKc/01`2CKSX0TVdh095/>02@JcL0SfTh08iX>@2<IST00P2;I3T208YT
=`0408US=P28HSD0R68e08MQ=080QV0c0P25Fc<01022Fc80P5/a07mJ<01lFBl207YI;P80MUD/00<0
MeH]07QG;P1hEbh00`1hEbh207=C;003079B:`1aDBX0LE4Z00<0LE4Z0`1`D2T306m?:080KThW0P1b
DR/207=C;080M5@]0P1eEBh207aG:P0707iI;020Fbh0Peha08EP<`26HC@0Qf8e08EO<00308IP<@80
Qf4b0P28HS<808]W=`80RV@e00@0RfDf08aV=`2<ISL0SFLh0P2>J3T00`28I3@0RVHf08]W=`0208eY
>@0308aX>02;IcL0RVHf00P0S6Hi0P2<ISL308eW>0@0SVPi202>JCD00`2=J3@0S6Lc08aW<`0208aW
<`<0RfHb00H0TVHi095V>@2AIST0T6Li08eW>02<J3P208YX>0@0TFHi102@ICP01@2@JS/0SfTj08mY
>P2>J3T0SFLh0080S6Hg00@0RfDf08eW>02;ICH0RF<d0P27HC800`28HS<0RF<d08]U=P0308US=080
RV@e00<0S6Hg08eW>02=IcP01029ICD408QT=080RVDh0P29I3L208QS=P80Qf8e2024HS8208IQ=080
QF0c0P24Gc8208=N<@0307iK<`1mFS80O5Ta0080O5Ta00<0OU/c081M=@21GSH00P23H3H00`21GS@0
P5dc07iK<@0307eJ<080MeX^01h0MUT_07EH<01dES00LeDa079D<01bE380LeDa079D<01aDbl0Ke4]
06e?:`1[CBT0JT`X06U;9`1JAbT0F4DW05=29P1>?b80BcdR04Lk8@17>b<0AS`S04Hj8015>B40@CLN
03de7P0j=1h0>C@P03Ld8@0h=B8203`f800603Td800e<Ql0<S4O02h_7`0];Qh0:bdO0`0Y:Al202PX
7P@09bLM0P0S9Qd0100R9A`08B@K024T6`0P8aX201lR6@P07R4J00<07B0I01hQ6P0N8AX00P0O8Q/2
020S7009024T7@0P8aP07b8G01hQ600M81T071hI01`N6`0K7AX06adL00806adJ0P0L7Q/201dO7080
7R0M00P07b0K01lP6P0P8A/08R<K02@V6`0U9aX09RPJ02LY6`D0;2dM0P0];Qh01`0^;al0<bdQ030/
800^:Ql0:RPL02HV700S91`00P0Q91d802DW70<08RDN0`0Q91d2020S70P07b4N200O8Q/2020Q6`80
7b0J01`0824K028S7@0U9R009RLQ02LR7`0Y91h0;BHL02hW5`0d:AD0?C4G04/n7P1DAbD0MEda08=[
?@2AMTT0U7Q909QiB`2RPU<0YhMH0:R6F01kJSh0He<a04Lh8`0g:R40<BTW02dY9P0T9Al07R4H200U
9b@802LX8P809bXQ100X:b8302LZ8@@09bXS100X:b@202LX8080:2TQ0P0Y:R8202X[8`0@034/:00`
:bL0<2/U030/8`0b;R<0=C4U03Ld9@0i=RL0ASTX04Lj9`1;?2T0CSdY054o:@1A?bL0DclV05@n9PP0
CCdV0P1:?BX204Tl:@0504Pk:017>RL0AcXW04Hi9P1:=bP00P18=bL00`17=bL0A3LV04<h9P02040h
9@80BcXZ0P1:>BT03`19>2P0B3LW04Pg9`17=RH0CcXY050k:P1@>bP0DC`W058n9P1C?bH0E40W05A0
9@1E@BP0ET8Y05Q4:`0205U5;00905M3:P1F@RT0ED4X05919`1B@2P0D40W04lo:01=?RT0C3dZ0080
BSd/0P18>bX01017>RT0ACPW04@g9P12=B@2044d8`0803`_9P0m<BD0?c<W044e9`12=RH0@CHT040e
8@0o=203040i9P0303lh9@0n=b@0?CHS0080?CHS0P0o=b@00`10>2D0@CTV048j9`0304<k:0H0?cPX
0P10>BT02011=b/0@STZ04@h:017>RL0CChW0592:01EART0FDPZ0P1TC3001`1UC2d0J4h[06iB:P1e
F2`0OEh`085R<`23J3400P25Ic401@26Ic40QfHa08YV<P2;IS80S6Lc0080SfHh00L0S6<e08UQ<02;
Hc80SVHe091X=@2>IS<0RV8_0080QF0c0`24Gc808@23GS40PUd`085L;`26GC40Qehb08MN<028H2l0
RF4^08YR;P2;Hbl0Rf@]08aN;02=Gbd0SV0/095T;@2CIRd0UVT^09Q[<02IKC00W6`^09i]<P2NL3@0
Wg<f09if>@2MMcT0VgLi09Yf>02HM3H0VGDg09Yf>02LN3X0WWXl09mk?@020:5m?`090:En@`2SO440
XW`n0:9l?@2UOch0ZhE40;6<B02eT4`0Z8U60080ZHY900H0Z8U90:J6B@2UQDX0YHE<0:J6C@2MOTL4
09ioB00309amAP2KO4D0VW]400@0VGY4102HND<208mc@@80T7A200@0SW9008a`?P29KC/0R6`j0`25
JCT208AX>00308=W=`22ISH0PFDe0080PfPk00@0PVLj085V>@20ICP0Of@g0P1nHcH208ES<`0A08EU
=025IcD0Q6Pf08AZ=`25JcP0Pf`h085Z=P23JCH0PVPe089V=024IS@0QVHe08UW=`2;JCT0Q6Hb08MY
=@2;KCT00P2?LCd04@2=Kc/0RV`h08MY=@2=Ld80R6hm089W>01oI3D0OV<f07]P<`1eFRl0L5DZ07UN
<@1hGC00Me`_07IK;P1eFRd0M5T/0080LeP[00<0MU/`07ML<@1hGC800P1iGS<0101hGC80MU/`07IK
<01eF2`207II;@0>07IK;P1eGBl0M5h_079M;P1`Fb`0KE/[06eL;P1/Fbl0JUT]06MF:`1TDRX0HU0Z
061>:P1NC2P205e>9`<0GTlX0`1OD2T0401PCRP0GT`V05e;9@1QCbT0IU@^06QF<01UDbd0HDlY05I8
8`1DAR<0DD<P04ho7P1<?Ah0Bc`O04Xj801;>b4804Tn8P0604U08`18?b80B3lR04Ln8@16?B00AC`O
0P14>ah01P14?Q`0A3hN04<m7@12>ah0@CXN040i7`80?cLP0P0n>Ql203di7P80?3PM0P0k=a`403Tg
7P@0>3HM0P0e=al0100d=Qh0<cDM038d700a<a/2030b6PP0<38M0100;2hP02d^7P0];Qh0;bhL038_
700g<Qh0>cDO03dg8@13=al0@CLN03de7P0j<Qd0=RlL038]6P0^:aX0;2TH0P0V9aT01P0T91P08R8H
01lP600M7QP071dG01/L5`<06adJ0P0J71T301TK60806Q`I0P0I6aP201PJ5`805aTF400I6aP0100G
6AH061XG01TK600I6aP201XL6@0301TK600H6QL05aTF00P06QXH200I6aP201XL6`<06A/J0`0H6QTH
01LI60<061XI0`0G6APl01HH5`805aTH0P0H6QTJ01TK6P806a/I100L71X301dM6`8071`J0`0M7A/;
01hN70807QdH0P0O7QT2020O6P@08B0K0`0R8A`302<R7@8092@L1P0S8a/202DP6P0402HQ6`0W8Q`0
:B@N02XU7`80:bHP0`0X91/202TU70<0:RHM00T0<RTR034X8@0`9b00;bHO02hU7P0]91d0;2<L02/R
6`0^8al00P0_91h01@0`9Qd0<BLM038X700b:AX0<bXK0080>RdM0`0i;1`303P[6`D0?bhL0P10;ad0
0`11<1h0AcDO04Hd7P0204Hd7P<0AC<M00<0A38L04/e7P1;=Ah00P1<=Ql304dg800304hh8@1?>Ql0
CcXO00H0CcXO0P1D>R<00`1B>R80D3XR04hj8@0204/j800404Xj801:>Al0BSTO04Xi7`<0BCPN0P18
=ad2050l9080Cc/S00D0CSXR04di8@1<>200BcLO050h8002054i8@80DSXR0P1C>b<00`1D?2@0DSXR
058j8P0205<k8`@0E3`T00D0ECdU05<k8`1C>b<0Dc/S058j8P02054i8@80D3PP201>>R400`1=>B00
CSXQ04hj8@0204hj8@<0Cc/R101C>b<405@l9080EShT00@0ECdS05@l8P1D?280Dc/Q0P1B>R000`1@
>R<0CcTR04li8P0404li8P0<050j8`1?=R80CcHR050g8@1A>B40DSXP05<k7`1C?1d0E3dN05m19`1M
?bD0FcdS0P1I>b40101K?B<0GClU05m19`1M?Ql205ho800505m08@1P@B80HD8S06528`1R@b@00P1W
AR<0101XAb@0JTTV06]:9`1]C2T406i=:P0606e<:@1/BbP0KD`Y06i=:P1`Cb`0LU4^0P1`Db/2075D
;0<0LUD]00<0LeH^07MG<01gEc001P1fERl00`1fERd0MeL^07UI<00207YJ<@0707UI<01hF2l0MeL^
075D;01bEBd0M5L_07EH<00307II<@0507EH<01fERl0MED^07=C;01aDBX00P1`D2T2075A:P0407EE
;P1dE2d0M5@]07AD;@<0Le</00L0LU8[07MG<01fERl0MED^07AD;@1cDb`0LE4Z0080L50Y0P1_CbP7
06i>9`0607==:01aCRP0LTlY075?:@1aDBX0L5<[0P1`E2`306mA;@80KU0/0`1]Cb/0201WCbT0J4hY
06U?:P1[CbX0KDl[06m>:`1`CR/0LDl/0P1`Db/0101aE2`0LUD]07=F;P1cERh207AG;`<0Ke4[00<0
KU0Z06e?:@1]CbT00P1/CRP01@1ZCRT0JdlZ06a>:P1^CBX0KddZ0080LDd[00L0Ld`[06i>9`1_CbP0
KdlX071@:@1aDBX0LU8[0080Le</00P0L5@/075D;01aE2`0Le</07=A:`1cD2X0M4hY07==:0<0LE0]
101`Cb`0101_CR/0KD`Y06e<:@1/BbP206Y99P80JDPU00@0J4LT06U69P1YARH0JDHV101ZAbL0101[
B2P0J4XV06U;9`1[CBT206a>:P0=06]=:@1YBbL0J4XV06U7901[BBH0KD`Y06e?:`1/D2/0IT`W0698
8`1MAAl0HTHO06=78P0206=6900<06=69P1QA2H0GT0T05do8`1D@1l0ED4P05Q18@1K@R<0GT<U0654
9P1SARP0I4DX0`1UB2P206A79`0306=69P1RABD0HD@T0080Gd8R00@0H4<S06959@1SARH0IDPX0P1V
BBT03P1SBBP0HdTV06I99`1XBRH0K4`V06i<9P1_CRD0LDhV06]88P1_C2H0ME8/07YG<@1mFS@0O5Tc
0P1iES002@1gE2h0OEP^07iI;`1oFS00P5/a089M<`23GS@0Q5le08EP=P02089O=@03085N=020GC<0
Oe`b0080OU/a101mFS0207iK<@<0Oe`b1P1nG2h207mM;`80O5X]00@0NeT/07YH:`1iEbX0N5HY0P1g
EBP0201_Db/0L5@/075D;01dE2d0MU@^07QE;`1iES00NeD`1@1lFC4307]H<00907aL=@1iFC80MED^
075A:P1`D2T0LU8[07EE;P1gEc00LU4^00H0Le8_00@0LU4^07EE;`1eEBl0MED_:oooool002[ooooo
1P2UNDP20:IjB@<0XWQ60P2SNDL30:AjB080XGU500<0XgY60:IkB02XNTP00P2ZNTT0102/NTT0XgQ5
0:EjA`2VNdP20:MlB@030:IkB02UNTL0XgQ50080YW]81P2WO4T80:QmBP030:AiAP2UNTL0YW]80080
Yga90`2XODX20:QoB@<0Ygi80`2VODL:0:QmB0@0ZGi90`2ZOdX20:Z1C@030:V0C02XOd/0Ygi:0080
YWe900<0YGa80:QoB`2XOd/01P2XOd/30:QoB@80Ygi80`2VODL02@2QP4/0X7m:0:1lB02ONTH0WgM4
09ec@@2LLT00W70o09Ud@00209Qc?`0309Mb?P2FLCd0UG0l0080U6lk00H0Tfhi099]>@2AK3P0T6Xi
08iX>@2<IST208]T>@80RfDh00@0RV@g08US=P28HSD0Qf4d0P26H3<208EK<`04089K<P20Fc40P5/a
07eJ<080NeX_00H0OEXb07aI<@1kF300NEH^07QE;@1gE2`207IC:`@0Le</00<0LU8[075A:P1aDBX0
101`D2T306m?:080KThW0P1aDBX2079B:`80Le</0P1dE2d01P1kERT0O5LZ07eH:`1oFRd0PUd`08AO
<P80QV4d0P25Gc0308IP<@<0Qf4b202;IcL208iX>@0408eW>02<ISL0S6Hg08]U=P80RV@e00@0R6@d
08UU=@2;IcL0S6Ph0P2=JCT00`2<J3P0RfLg08aV>@0708aV>@80S6Hg0`2=IcP408iX>@P0SFPd0P2>
JCD208eX=00508aW<`2;IS80RfHb08]V<P2AICP00P2@ICP00`2?ISP0SFLh08aX>00208YX>0P0T6Dh
0P2?JCX0102>J3T0SFLh08eW>02<ISL208]U=P0308aV=`2;ICH0RV@e00<0R68c00H0RF<d08YT=@28
HS40RF<b08YT<`2;IC@208aV=@80SFLf1028I3@408UU=@@0RF@g1028HcH808AR<P<0QV4d0P25H3<3
08AO<P0307iK<`1mFS80O5Ta0080O5Ta00@0OU/c081M=@21GSH0Pf0f0P22GcD00`21GS@0Oe`b07iK
<@0207aI;`80MeX^01h0MUT_07EH<01eEc40M5Hb07=E<@1cEC<0M5Hb07=E<@1bE300L58^06i@;01/
CRX0JddY06Y<:01MBRX0FTLW05E49P1@@B@0C3hS04Pm8@17>b40AS`Q04Lk8@16>R80@SPO03hf7`0k
=Al0>SDQ03Pe8P0i=R<203`f800603Xe8@0f<b00<c8P030a8@0^;al0;BlQ0P0Z:R0202TY7`80:2PN
0`0W9ad202@W7P0402<V7@0R9A`08B@K020S6P807b8I300N8AX401lR6`8082<H00H07b8I01lR6`0N
81/07AlL01`N6`0K7A`301/M6P8071hK0`0M7a`01P0O7ad07b0K020Q700Q8Q`08R<K02@V6`809BLJ
0P0Z:a/00`0[;1`0;2dM02d^7P0302d^7P0803<]7`0a;Ql0<2`P02d[7`0X:1h09BLL024T6`0P8aX4
02@V6`@09BLL0`0R9Ah3024T7@8082<L200O8Ah801lR6`80824L01h07b0K01hO6P0O81/08B8M02<T
7`0T9B00:20N02XR7`0/9Ad0;2@I02dV500b:QD0>c@J04Dk801QBR40MEhe08U`A`2BMd`0Ug]<0:62
D`2WREL0YhMF09V0BP1oJ3`0GDP[044_8@0e:280<RXX02XY900U9Qh802DW90P0:2TS0P0X:b8402LZ
8@<0:2/R100X:b@402LZ8`809bPP0P0X:B4202TZ8P80:R/S0100<B`X030[9`0`:bD0<2`S034]8P0d
<2@0=S<T03Pe9P13>2H0ACXV04Tl:@1>?bX0D40Y0590:01A@2H0DShU201=?BH01P1>?bX0CChY04dn
:@1<?BP0Bc`W04Xk9P80BCXU00H0BSLX04Pg9`18=bL0AcLW04@g9P13>2H2040h9@0604`k:`1;>RX0
BcXZ04Xi:@19>2P0B3LW0P17=RH02`1>>2X0CcT[04lj:@1@>bP0DC`W058n9P1C?bL0DclV05M29`1H
@bP0FTDZ0080FdH[00@0FTDZ05U4:@1H@bP0Ed8W0P1E@BP01@1A@BP0Cd0Y04a0:P1:?b/0AclZ0080
B3/Z00@0AcXY04Dh9`14=bH0@SDT0P11=2<0200m<2L0?S8V040d:012=RP0@SHV044f9010=B40?c@P
2011>BH01017?b`0ASh[04Dm:P14?2T204<k:080@SXW1P14>bX204<j:@0F04Hm;016?R/0BChZ04a0
:01BA2T0EdP[05]<:`1NCR`0Ie0a06M@<01WCbd0JDlZ06mC;01eF2h0O5da081Q=@1oI2d0PV@^08=U
;`25IS00QVD`08UU<@80RVDa0P2;ICH00`28HS<0Q5h_08EO<P0208MQ=00408AN<@20FBh0OEL`07eG
<0<0O5H_00<0NeD^07aF;`1lERl00P20FC000`21FRl0PU`_08=M;P0208AN;@0>08EP;029GBh0RUh_
08aP;`2>Hc00T6D`099W<02DJC80U6X`09AU;@2EJ2l0V6/b09Y`=P2LLSH209ad=`0C09ad=P2KN3P0
VgPh09ej>P2NNc/0X7dm0:9o?`2SP400Y8510:Em@02TO3l0XWXl0:=k?@2VOch0[8E20;:;AP2gT4/0
Z8Ho0:N4@0020:J3@@040:N4A02WPdD0Yh=70:J2AP80Xh540`2TPTD00`2SPD@0XX130:5o@P0309mo
AP0309inA@2MOD@0WGe40080W7a300`0U7U409EjA@2ENTD0UGY509=h@`2AMT40Sg@o08eb?@2:KSh0
RFdm08Q/?027Jc/208EY>@80Q6Ph0P22IcP01021ISL0P6Df081U=P1oI3D207iS=080RfLe0140RFPe
08UY=P29JcL0Qf`g08Q]>027KSP0QVdg08EZ=@24JC@0QVPd08QX=@2;JSL0SVXh08m[>@27J380RV/e
08i_>@02095b?00;08i_>@2:JcD0R6Tc08aa?027JcT0PFDe07iR<`1mH3@0NUdc07AG;`1_DB/00P1f
Fc0207EJ;`0707AI;P1cF2d0LeP]07=H;@1eFRl0MU/`07QM<P0207YO=00307UN<`1gG340MU/`00<0
MEX]00h0M5`^07AN;`1bGBh0KU`/06aJ:P1ZFRT0K5X/06]H;@1YER/0Ie@Z06AA:@1RCRT0H4`Y05m;
:080GDhW0`1NCbP305m@:@0@065=:01PC2L0Gd/V069>:@1VDRd0Ie<^06=?:P1NBRD0DdDR05528@1?
@1l0C3dN04Xk7P1:>R00BSXQ04/k8PP0BChR00@0B3lR04Ln8@17?R40ASdP0P15?1l204@k7P0604@n
7014?Qh0@cdM048k7P11>Qh0@3TO0P0o=b0303di7P80?3PM0`0k=a`803Le7P80=3HN00@0<cDM038d
700b=1`0<C<K0P0`<QX8030b7@0H02/]7`0/;Ad0;2dM02l^700b;a`0=c8N03Xd7P0l=R00?SHO03`f
7P0i<ad0=2lK02l/6@0[:QP09bPH02HW5`0R9QP08BDG020S600N8AP07AhH01`M600J6aH06QXH0P0K
7AX201XL6@806A/H0P0H6QL201XL6@806A/H0P0H6QL201LI5Q006A/H00@05aTF01PJ5`0I6aP06A/H
0P0J71T00`0I6aP061XG01LI5P0801XJ60P06A/H0`0I6aX301PJ6AX05aTH0`0H6QT301LI63d05QPG
0P0G6AP301PJ6@P06A/J200H6QT801TK6P<06a/I100L71X201dM6`8071`J0`0M7A/301hN70P07AdK
0P0N7AP201lN6@8081lJ1@0Q81/3028Q70808b8M1P0S8a/202@T70808b0I00@0924J02DR6`0W91d0
:2DN0P0Y9Ql202LS6P80:2@K0P0Y9A`202XV7@80<2TQ00@0;bPP02hW7`0/9Ad0:b@L0P0Z8a/01P0^
8al0;R<M02lT7P0`9Qd0<BLM038X7080<bXK0`0i;1`303P[6`80=bXJ00@0?B`J03h]6`0o;Q`0?bhL
1010;ad304Hd7P80AC<M0`14<Q`01019=Ad0BSHN04Xf7P1:=Qh204/g7`80C3PP201=>B00201A>280
D3LQ04hh8@1=>B40BcTQ04Xh8019>B00B3XP0P1:>Al304Th7P<0B3LM00@0D3`T04lk8`1>>R80CCTQ
0P1<>20204/g7`@0DCTQ101B>R80101A>B40DSXR058j8P1B>R8305<k8`80E3`T00<0DSXR054i8@1A
>B400P1A>B43050h80P0CCTP0P1;=al204`h800404di8@1>>R80CSXR04hj8P80DCTQ0P1B>R8205<k
8`80E3`T00D0E3hV05<m9@1C?BD0DS`T054k8`0204li8@0304hh801<>200CCTQ00D0CCTQ00L0C3PP
04lf8P1?=R80D3LQ050h801A>Al0DSXN0080Dc`M00<0Gd4W05do9@1K?B<00P1I>b400`1K?B<0GClU
05m19`0205dn7`0405ho801O@240H44R06528`80HT<T00/0ITDR06M68`1XAb@0JDPU06]:9`1/BbP0
KD`Y06i=:P1`CR/0KddZ06i<:@0206e;:00406i<:@1`CR/0LDl/06mB:P<0L5<[0P1aE2`2079E;@80
M5@^1P1eEBl00`1fERd0MeL^07QH;`0207UI<00707QH;`1fERd0MED/079D;P1dES00MUPb07QJ=002
07UK=@0507MI<`1fF380MUH_07AD;@1bDR/00`1_CbP00`1`D2T0LE4Z07AD;@0307=C;0<0LU8[00L0
LE4Z07MG<01fERl0MED^07AD;@1bDR/0L50Y0080KdlX0P1]CBH706i>9`06075;9P1_C2H0LDhX075?
:@1aDBX0L5<[0P1_Db/206i@;080KDl[0`1/CRX01`1[CBT0IThX06Q>:@1XCRT0JThY06a>:P1^CBX0
0P1`CR/206mB:P04071C:`1aE2`0LUD]079E;@80LeH^0P1`DRh0101_DBd0KDl[06a>:P1[CBT206Y<
:080JDdX00<0JddY06e<:@1_CBX00P1aCB/01P1cC2/0KThW06i>9`1_CbP0L50Y075A:P80LU8[00T0
Le</06mF;@1`E2`0Ke<[06mB:P1`D2T0L4hX075>:01`CBL00P1`Cb`206m>:`0406i=:P1]C2T0KD`Y
06e<:@<0JdXW00D0JTTV06U89@1XAb@0IdHS06I58P0306M69@0306Q79P1YB2L0JDPW0080JTTX0P1W
BbH406U=:080Id/V0100JDLT06a:9`1^CBX0KU0/06]?:P1VC2L0HDLR05e57`1PA1l0HD@R06958`1R
ABD0HD@V05m19@1M?bD0FcdS0P1C?Ql01P1G@240FD0R05a1901P@RH0HD<W06=4:080HTLY00<0H4DW
05m49P1N@bD00`1M@R@0501J?b40Fd0R05a18`1M@R@0GT<U05m49P1PABL0HDHX0617:01PB2H0HTPU
06I99`1XBRH0Jd/U06a<9@1^C2H0JdPR06i;9@1cD2X0N5D_0P1jEc4207QE;`0707IC;@1lEbd0O5L]
07eH;P1oFS00P5/a089M<`0208=N=006085N=020GC<0P5dc07mL<P1nFc40OEX`101lFBl207eJ<080
OU/a0P1oG38307iL;`D0OE/^0P1jEbd207UF;00<07QE:`1gE2X0MU<Y07IC:@1^DR/0Ke</071B;01c
Dbd0ME<^07MC;`1hE300NU@`0`1lFC403@1kF300NUL_07YG;`1jEbl0NEH^07]K=01hF340LU8[06m?
:01^CRL0L50Y07=C;01fERl00`1aD2d2071?;0<0LE0]0`1cDRl[ooooo`00:_ooool20:AhA`<0YGU8
0`2VNTT30:9iA@80XgY60`2TNdL02`2RNTH0Xg]70:ElB02WO4T0ZG]90:YjB@2YNDP0ZgU80:=hA@2U
NTL0YW]80080Yga900<0YW]80:EjA`2SN4D00P2VNdP30:MlB@/0Z7e:00@0XgM60:AhA`2VNTT0Yg]:
102XO4/20:QoB@<0Ygi80`2VODL90:QmB0<0ZGi90`2ZOdX20:^0B`<0ZX5=0`2YP4`:0:QoB`040:V0
BP2XOdT0Z7m90:QoB@80Ygi80P2VODL0202POdX0Wgi90:1lB02ONTH0WgM409me@`2MLd40WW910P2I
M4000`2HLcl0Ug8n09Ia?@0209E`?00909A_>`2DKcX0Tfhj099]>@2@JST0SVPi08eW>P2;I3T0RV<h
0080RfDh00@0RV@g08US=P28HSD0R68e0P27HC@01P26G3@0QE/c08=L<`21G380P5/a07eJ<080NeX_
00H0PU`e081J<`1nF340NeD^07UC;01hDR/207MA:P07079B:`1cDb`0M5@]07AD;@1cDb`0LU8[075A
:P04071@:@<0KdlX0P1^CRL206m?:004071@:@1aDBX0LU8[07=C;080M5@]00H0NeHY07aG:P1mF2/0
OeX]085L;`22GC0208AO<P<0QV0a0P27HC8308QR<`P0RfLg00`0T6Xk08mY>P2>J3T0SFLh08]U=P2:
I3D0RF<d08QR<`27Hc<0R6@d08YV=P2<J3P208eY>@80S6Ph202<IST208aV=`<0SFLh102>J3T808eX
=080SfXf00<0SVTe08eX=02<Ic<00P2;IS802P2:IC40Sf<f08mT=`2?I3L0SVDg08eW>02<J3P0RVPh
08]Y>@2>HcH308mT=`<0T6Dh00<0TFHi08iX>@2=IcP00P2=IcP408aV=`80RfDf00<0RV@e08US=029
Hc@00`29Hc@00`29I300RVDa08]V<P0308eX=00308aW<`2;IS80Qf<c00<0R6@d0`29ICD00`2:ISH0
RF@g08UT=`0208UT=`@0R6<f0`23HC4208AR<P<0QF<c00@0Qf8e08IQ=026HC@0QV4d0P25H3<208AO
<P0307iK<`1mFS80O5Ta0080O5Ta00@0OU/c081M=@21GSH0Oe`b0`20GC<0101oG380OU/a07aI;`1k
F2h207MJ;P0V07II;`1fFC40MELa07EG<`1dES80M5Hd07EG<`1dES80LeDa075C;`1_DBd0KDl[06a>
:P1[CBT0Gd`[05a9:01GAbH0DD8S04do8P19?R80B3dQ04Lm8P18?280ASXR04<i800o=b00?3HP03/f
8P0i=R<0>SLT03`f800k=Al0>C@P03Hc800c<R00<34Q02l`800];b4302XZ8080:BTO100X:1h202@W
7P0402<V7@0R9A`08B@K024T6`8082<J400N8AX02@0O8QL082<H020S6P0P8a`07b4L01dO700L7Q/0
6Q`K01XL6@0301/M6P8071hK0P0M7a`01P0N7Qh07alM01lO7@0P8A`08B8L028S6`808bDJ00@0:2TI
02TZ6P0[;1`0;2dM0`0];Qh02@0/;Ad0<R`L030]700a;Ql0;bdP02/[7`0V:1d08RDJ01lR6@0302<U
6P8092HK0`0U9a`3028U7P<08B@M0P0P8a`801lQ7PP07b8K00<0820N01lO7@0N7Q`00P0N7Q`06`0P
81h08R8P02<S8@0X81h0:R8O02`U7`0[91X0:R@F02dX5@0c;QX0>C@N058k6@1WDB`0OVI008YaB02D
ND`0WX9B0:>5D`2PPTh0Zha<09UkA@1iGCP0E3hY040_9`0g;B/0<RdY02XY900802HX9@P0:2TS00<0
:B`S02P[8P0W:R400P0V:B001@0W:R40:2/R02T/8`0Y;2<0:B`U00<0:2/T0`0W:R<00`0V:B809bPP
02LX800202PY8@80:BXR0P0Z:b<2034/:00>030[9@0`;2<0<BdR03<_8`0e<R<0=S<T03hf8`11>B@0
AS/W04/o:@1?@2T0D40W04lo9@1>?B<804hn9`80CclX0P1>?RL02P1=?BH0C3`U04/k901;>b@0BcPY
04Xi:@19>2P0B3PX04Dh9`14>BL2044i9P80BcXZ0P1:>BT07019>2P0B3LW04Pg9`17=RH0CCLZ04hh
:`1>>2X0CcXY050k:01A?2L0DSdX058n9P1J@RH0Fd<W05e5:@1NARX0GdL[05i6:P1MABT0G4@X05]1
9P1J@RP0Ed<X05E4:P1A@bT0C48Y04M1:@16@2P204Tl:`0404Pk:P16>BP0ACPW04<f9@80@SDT00P0
@3<Z044e:@12=RX0@cLY04<g9`12=bD0@CHR040e8@80@cPT00<0A3TU04Dj9P16>bL00P17?2P01P18
?BT0CDDb04a4<@1:@Rl0Acl/04Hn:`<0ACdZ00<0BCh/04Xo;@1;@2h00P1;@2h06@19?R`0B3d[04Ll
:P1:@Rd0Bd<^04i4:`1AARX0EdT/05e>;@1QDbh0IEDa06]D<P1YDS00JE4]06Y@:`1_Db`0MEP`07]K
=01nGSD0O64Z07mQ:`21Hbd0Q6D_08ET;`28I3000P28Hbl208UU=@0:08AP<020Fbh0P5/_085L<P20
FS<0O5Ha07QB;@1eDBl0M50^07=?;@80LTh/00<0Ldl]07A@;P1eDBl00P1kEC00501lERl0OEP^07iI
;@1oFRd0Oe/[081L;027G340R5d`08UN<@2;HC40SF<a08mV<P2@Ic40TFPb08eR;`2?I2l0TfPc09M/
=@2JL3H0W78f0P2MM3H01P2KN3P0W7Ti09ej>P2NNc/0Wg`l0:5n?P80XWlo0140XgTm0:9i>`2RNC/0
XgXj0:Mn?02[Pch0/8Q20;>;A@2]Qd00ZhDn0:V2?@2[Q440[XM60:n7B@2^QTP0Zh=60:J3@`030:F2
@P040:B1@@2UPT80YH920:J3@`80Y89500<0Xh540::0@`2QOd800P2POT400`2OOD00VWm809^0B@02
09^0B@0809UnA`2GO4D0U7U209=h@@2>LT80SG5108]_?`29KCd408M[>`P0PFLf0P2@JcL00`2?JcL0
SF`g08a]=`0208]]=`0;08U^=`2:KcP0RF/e08IX<P28JC<0S6/f095]>@2CKSX0TVdi08]Z=02=K3H0
0P2?KSP0302>KCL0S6/e08UX<P26IBl0RF`d08AV<01nH2h0O5d^07]K<P1iFC80M5<`06m>;@<0LUH^
0P1cEbl307AH<00307AI;P1fFc00NEhc0080Nf0e00@0NUld07QM<P1fFc00Le/]0P1dG2h03P1cGBh0
LUd^06mM;@1[FbX0JETX06EG9P1[ERT0JUDZ06UD:@1WDBP0IDlX06A>:@1RBbT0HDXX0P1LCRL305e?
:0<0GU0Y0100IDlZ06==:01SCBP0IDlZ06MA;01VD2/0H4XU05]5801A@R40D44P04dn7`1;?1l0BSXP
04Xj8@1;>b@0C3`U2018?B4804Hm800604Do7@15?al0A3hN04<l7`12>al0@CXP0P10>24203di7P80
?3PM0`0k=a`00`0j=Q/0=C<N03Dc7P0203Dc7P80=S@O0P0g=B0203@f7P0303<e7@0b=1`0<C<K0080
<38J00<0;c4I02la700_<A`01P0_<A`0400[;Al0;2dM02`]7@0^;A/0<BhK03Ha7@0j=1h0?3HP03Td
7P0e<a`0<S0K02d/600X:AL09BPG02<W5P0R9QL201/V600601`T6@0K81T071hI01/K6@0K6QP06aTJ
0`0J71T201TK60<061XG0P0J71T201TK608061XG0P0G6AH@01TK600401LI5P0H6QL06A/H01TK6080
6Q`I00<06A/H01PJ5`0G6AH0200J6QP801TK60<06A/J0P0H6QTK01LI60<061XI0`0G6APj01HH5`04
01DG5P0F61L05QPG01HH5`805aTH0P0H6QT801TK6PP061XI200I6aX201XJ60<06a/I0`0L71X00`0M
7A/071`J01`L6P0301dM6`<07QhL200M7A/201hM60807ahI0P0P7aX2024P6`8081lJ0P0Q81/3028Q
700302<R7@0R8QX08R8J00<08b<K0`0T91`2024Q6@04028R6P0S8a/092@L02@T70809BDM0`0W8aX2
02PT6`<0:BDL00D0;BTP02`X7`0/:1l0:bLN02XV7@0202TU700902PT6`0]8Qh0;R<M02lT7P0`9Qd0
<BLM038X700c:Q/0=2/L00P0>2/K00@0?2/I03d/6P0n;A/0@2lM0`11<1h01010;ad0A38L04@b7014
<Q`504Dc7@0404Hd7017=Ad0AcDM04Le7@80B3HN2P19=al204dg8P0404`g8P19=b40BCLQ04Ph8@80
AcPQ00@0BSTO04Th7P19>1h0BCPN0P18=ad204Lf700304hj8P1=>B40C3PP00<0BcLO0P1<>208054i
8@04050h801A>B40DCTQ054i8@<0DSXR0P1C>b<8054i8@<0CCTP0`1<>1l204/g7P80BC@O00<0BSDP
04/f8@1<=b800P1=>2<01`1>>B@0CcLO050h801@>200DCTQ058j8P1C>b<00P1D?2@01P1B?RH0DCdU
050l901?>b<0CCTQ04`h8080BcLO00<0B3HN04Tg7`1:>2000P1;>B402@1:>200BCLO04Pf7P1?=R80
D3LS050g8@1A>B40DSXP05<k7`0205@m7P80GClU101K?B<205do9@0805`m7P1M?Ql0GSlP05m08@1P
@B80HD8S0693901SA2D206I58P0406M68`1YB2D0JTTV06a;:080KD`Y00T0LDd[071<:P1^BRP0KDTW
06i::01_BbT0L4`Z075=:`1^DBT00`1_DRX2071C:`80LE@/00@0LU4^07=B;`1cDRl0Le8_0`1dDc00
6@1eE340MUH]07MG;P1hF2l0NET`07QH;`1gEbh0MED/07AD:`1aDbl0LeDa07IH=01hFSH0NE/g07MI
=@1eEc<0LeDa07AD;@1bDR/0L50Y06i>9`1]CBH0KdlX075A:P1bDR/00`1aDBX5079B:`0607MG<01f
ERl0MED^07=C;01aDBX0L50Y0P1^CRL206a<9@80KDdV1@1^CRL0201^B2<0KT/U071=9`1aCbT0LE4Z
071C:`1_Db/0KU8Z0`1/CRX206]=:@<0JT`X00H0IDdW06M=:01WCBP0JDdX06]=:@1]C2T206m=:P80
KE0X00<0KU4Y06mB:P1`Db/00P1aE2`02@1bEBd0L58`071B<01^D2h0KDl]06]=:`1YBbT0J4XX06M9
9`0206Q<9`0306Y<:01]C2T0KddZ0080LDd[00L0M4d/06e=9P1^CRL0KThW06m?:01`D2T0LE4Z0080
LU8[00T0L5T_06mF;@1]E2/0KE4Y06e@:01^CRL0KddW071>:01_CR/00P1^CBX0101]C2T0K4/X06]:
9`1[BRL306Y99P0606]:9`1ZBBH0JDPU06Q7901VAB80ID@Q0P1UARL206I7:00406M8:@1XBBX0JDX[
06U::`<0Id/V0P1XC2L306M;9P0@06a:9`1]BbP0KD`Y06a>:P1ZCRT0ID/V06578P1NAR00H4<Q0654
901RABD0HTDW06539`1O@BL0GClW05/m9@80E3lR00/0EclS05To901L@BH0Gd4W0612:01Q@BP0HDPZ
05m6:01MA2H0Fd8T05Y18`0205U08P0405Y18`1I@280FD0R05U08P<0FT4S0P1K@R@205e69P0405m7
9@1RB2D0IDPV06Q:9P80Jd/U00D0K4TS06i;9@1aCRP0Le0Z07EB;00307IC;@0907EB;01hEB/0N5D[
07UF;01jEbd0O5T_07eJ<01nFc40Oe`b0080OU/a0`1mFS0607aI;`80OEX`0`1nFc4407eJ<080O5T_
0P1kF2h207UF;P0307QE;@1gE2`0MU<[0080ME8Z00T0M54Y06eA;01^DRd0Ke4]079A;P1dDRl0MU8`
07MC<@1iDS400P1kF30307YG;`<0NEH^00P0N5Pa07EE;P1aDBX0KThW06e=9P1^CRL0LE4Z07=C;080
L4l/101^CBX2071?;0<0L4l^:oooool002[ooooo0`2TN4L00`2UNDP0YWY90:IjB@020:MkBP<0XWU3
0P2SNT@30:AkA@0;0:=kA`2TO4P0Ygi:0:QmBP2ZO4X0ZWY90:QhA`2XMTD0XgQ50:EjA`2VNdP00P2W
O4T00`2VNdP0YGY70:=hA@020:IkB080Yga90P2XODX:0:UnB`040:9fA`2SMdP0YWY;0:QlC@80ZGe>
00@0Z7a=0:MkC02XOdT0Z7m90`2WOTP30:ImA`/0ZGi90`2ZOdX30:^0B`<0ZX5=0P2[PTh30:b3C`P0
Z7m;0P2YP4X30:QoB@<0Ygi80P2NODP01P2ONdL0WgY60:1hA@2PMT@0WgE30:1d@`80VGA00P2HLcl0
3@2GLSh0UW4m09E`?02EL3`0UG0k09A_>`2CKSX0TF/j08iX>@2=IcX0Rf@i08YS>02<IST00P2;ICP0
0`2:I3L0RF<f08QR=@0208MQ=080QU`d01D0Pe`c085L<P20Fc40OEX`07aK<01kFRl0PEXc07mH<@1m
ERl0Ne@]07YC;01kE2d0O5D^07eF;`1bDR/0Le</07AD;@1eEBh0M5@]07=C;01aDBX0101`D2T306m?
:080KThW00T0K4`U06e=9P1^CRL0L50Y079B:`1dE2d0MED^07IF;`1lEbX00P1mF2/01@1nFB`0OeX]
081K;P21G2l0PUd`00<0Qf4b0P28HS<308US=0P0RfLg0P2=IcP408aV=`80RfDf00@0QV8b08QT=02:
ISH0S6Ph0`2=JCT00`2<J3P0S6Hi08aV>@0608aV>@80S6Hg0`2=IcP408iX>@P0S6Lc00D0T6/g08mZ
=P2?JSH0SVTe08aW<`0208]V<P0708YU<@2?HcH0SV<f08iS=P2>ICL0SFLh08aX>00208]Y>@<0SV<f
00<0Sf@g091U>02@ICP00P2AIST208]U=P<0S6Hg0`2=IcP0102;ICH0RV@e08YT=@2:I3D208US=080
R68c00<0RfHb08aW<`2=J3@00P2>JCD00`2<Ic<0RVDa08UT<00208MS<`80R6@d0P29ICD208YV=P@0
R6<f1029I3L00`22H300Pf4a08=Q<@0208AR<P80QF<c00<0QV@d08MR=@27HSD00`26HC@308EP<`03
07iK<`1mFS80O5Ta0080O5Ta00H0OU/c081M=@21GSH0NeP^07aI;`1nFc4207mL<P0807iK<@1lFBl0
NeP^07MJ;P1fFBd0MUT_07II<@1fF38207EG<`0707EG=@1eEc<0MELc07=E<@1bE300L58^06i@;002
06a>:P0>061>:P1NC2P0F4PV05=48`1>@B40BSlQ04Tn8017?R40BCdS04Lk8`14>R40?cLP03dg8@0l
=b<203Xg9080>S@N00H0>3<O03Db7`0b<Al0;c0P02h_7`0];b4402XZ8080:BTO0`0X:1h01P0U:1l0
92LN02@W7P0S9Qd08RDL024T6`8082<J3@0N8AX301dP6@0801lR5`0P8aP08B@K024T7@0P8Qd07R0M
01`N6`0J71/201XL6@<06adJ0`0L7Q/201hN7P0401lO7@0P8A`08B8L024R70808R<K00@09RLG02PY
6@0Z:a/0;2dM0`0];Qh02@0/;Ad0<2/H02l/6@0a;Qd0<BlP02d^800X:Qd08bLI020S6002028T6@80
8bDJ00@092HK02DW700U9a`09BLL0`0R9Ah3024T7@8082<L200O8Ah801lR6`03020P7P0O7ad07QhL
00807AdK01/07alM020P7P0R8R00:AlN02`R800]9R00;BHN02TU6P0Z9QX0;R`M038a7`1:=AH0GTLW
075K=P1nIch0Rg=509UoCP2MPTd0V7e60;2;A02[Qd/0Tg=:06eC?01@?3<0@C<`03H^;00[9b@0200V
:2D802PY8`0302T/8`0X:b809bXQ00809RTP00@09bXQ02P[8P0Y;2<0:B`S0P0Y;2D202P[90809bXS
0P0V:B8202LX8080:2TQ0P0Y:R8202X[8`0@038]:@0a;2P0<2/U030/8`0`;240<RhR03@a8P0f<b@0
>S<P03hf8@13>bH0BChX04a0:01>@2H0CCdS04`l8PP0CShW00<0CclX04hn9`1>?RL00P1>?RL304dm
9P0604`i:P1;>RX0BcXZ04Ti:@17>RT0ACXX0P13>bP304Xi:@D0BCPX03X0CCL/04dg:P1>>2/0CcT[
050k:P1A?2T0DC`W058m:01J@b@0Fd@U05e69`1OB2T0H4TZ05m8:@1NAbP0GDHW05e29`1L@RL0FTDZ
05I5:`1AAB/0Bd@Z04I29`13@BP0Bch]04Xm;019?2/0B3/Z04Hi:015>2L0A3LV04<f9@12=B`0@cL[
04@h;015>B/0ACTY04@i9`12=b<0@CHR04<g8@14>280ASXT04Pl9P1:?RP0C40Z04e1:`1>@R`0CTHc
04e5<P1;@c00BT8_04U1;P1:@Rl0C4@a04e5<P1=@2d0CT4^0`1?@Rl06`1=@2d0Bch[04Xm:P1?Ac00
CdP^05=9;P1FBbd0G4l]069D;`1VF340JU/b06eG<P1[EBh0Je<]06aB;@1_Db`0M5H`07]K=@1mGCL0
NUlX07eO:@20HR`0Pf@^08ET;`27Hbl0Qf8^08IQ;@0208ES<`0:085O<@1lFRd0NeP^07]H<P1jES80
ME4_075=;@1_C2h0KT/]06a9:`80JdPZ00<0KDX/06i;;@1`CBl00P1fDRh00`1gE2h0N5D]07UF;002
07YH:`0A07]I:`22F2h0PeT_08AK;`25G2h0Qel^08UQ;P2:HRl0Rf<_08UO;`2<HS00T6Lc09I[=P2J
L3H0WW4f0:1d=`2QLcD00`2IMS@209Yg=@80VgPf01l0W7Tg0:5e>02RMSL0XgLh0:Ei>02XOCT0Zh0k
0:f3>`2^Q3`0[XLl0:^3>`2YPCT0Zh<m0;28@`2bRDL0/8M70:b3@`2ZPch0Z84l0:Io>P2TOCP0YGhi
0:Io>P2YPSd0Zh@o0:J2A02UPD<0Y8120:=o@@2ROT00XGdo0080X7`n00`0WhA=0:25CP2PQDh0X8E>
09n4C@2LPDX0VWm809QmAP2AMDD0Sg=308ea@@2:KSh208Q/?080RFdm00H0PfTf08AZ=`24JSL0QF/h
08I/>@27KCX208Q^>`0609M_?02DKc/0U6lk099^>P2?KST0SFhh0P2;KCL0202>L3X0RV`f08MX<P2:
JC@0TFdi09Ia?@2EL3`0UFdj0P2>KSD03P2=KC@0Rf/b08UY<027Ibh0QFD/08AT:`22HbX0OUlX07UI
9P1hF2T0NEP_07QF<@1cD300Kd`^0P1^DR/03P1`E2d0LED^07=G<01dF340METb07IJ<`1cF2d0MU/`
07UN<`1lHCH0OF8g07]P=@1hGC80MU/`0`1cGBh2079M;P0:06iL;01ZFRT0IELV06AF9@1WDRD0Ie8W
06IA9P1VD2L0IDlX06A>:@80Hd`Z0P1KCbL305a@:0<0GE4Y0100Ie4/06E?:P1TCRT0IU0[06MA;01T
CRT0GDLR05I06`1A@R<0Cd0Q04dn8@1<?280Bc/R04`l9@1=?BH0CC`X2018?B4204Dl7`0404Hm8017
?R40B3lR04U08`80BT4T00H0AT0N04I08015?al0A3dP04@m8@13?282048j8`<0?3PM0`0k=a`203Xf
6`80<c0M0P0d<Ah01@0e<Ql0=S<P03Hc800f<b00=3HN0080<cDM00<0<S@L034c6`0`<QX00P0_<AT8
02la700>02/]7`0[;1`0:b`L02h]6`0a;Q/0=S4M03Xd7P0k=Al0<c8M034`6`0/;QT09bXG02@W5P0R
9QD2020W5`0801TW6P0I9AT06B<J01XQ6@0L7QT071`J01`J6`0M6AX201XL6@806A/H100H6QL201XL
6@806A/H0P0H6QL201LI5Q006A/H00@05aTF01PJ5`0I6aP06A/H0P0J71T00`0I6aP061XG01LI5P08
01XJ60P06A/H00@06A/J01PJ6@0H6QT061XI0P0G6AP201HH5aP05aTH0`0H6QT301LI63X05QPG0P0E
5aH301HH5`<05aTH200I6aX801LI60P06A/J0`0J6QP301/K6@D071`J0`0M7A/301hN70P071`J0P0N
7AP201lN6@8081lJ0P0Q81/3020O6P808B0K0`0R8A`3028R6P0302<S6`0T91`092@L00809BDM1@0R
8QX302<S6`@09b<J0P0X91/202TU70P0:BHM00T0;24M02dR700^8ad0<2HM034W7@0c:Ad0=2/L03D/
7@0e:1P00P0f:AT02@0g:QX0>2/K03T/700i;1`0>RdM03XY5`0l:aT0?RdK044`7P02048a7`06044`
7P10;ad0@S0J048`6P13<A/0A38L0P15<ad204Hd7P<0ACDL0P16=Qd304Lg7PP0AcLP00H0Bc@R04Xe
8P1:=B80B3HR04Lf8P17>2<204Di8`<0BCPN0P18=ad304Lf700804`h801;=al0BSHN04Te7@1:=Qh0
BcLO04di8@1>>R85054i8@H0D3PP0`1A>B43058j8P<0DCTQ1@1B>R8204di8080C3PO0P1;=ah204Xf
7@80B3<P00@0BC@Q04Xe8P1;=R<0C3LT0P1=>2D01@1>=Qh0CcLO04lg7`1@>200DSXR0080Dc/S00L0
E3`T050k9P1?>RD0CSTT04dh8`1;=R40BSDP0080B3<N00<0ACDL04Lg7P18>1l00P19>B002@18>1l0
AcLN04De701@=b<0DCPT054h8P1B>R80Dc/Q05@l800205Dn7`80FcdS101M?bD205/m8`0805/l7@1L
?Ah0GChO05m08@1P@B80HT<T06=49@1TABH206I58P0906M68`1XAb@0JTTV06]:9`1/BbP0KD`Y075=
:`1`C2X0KTXX0080KDTW00<0KTXX06m;:@1`C2X00`1^DBT206mB:P<0L5<[0`1aD2d00`1bDBh0Le8_
07=B;`0207AC<00;07IF;@1gEbh0N5P_07QH;`1gEbh0MUH]07AD:`1bDRT0KU0/071B;P1bE3000P1d
ES801P1aDbl0KU0/06a>:P1bDR/0L50Y06i>9`80K4`U00<0KdlX079B:`1dE2d00P1_CbP0101`D2T0
LE4Z075A:P1bDR/207=C;00607MG<01fERl0MED^07=C;01aDBX0KdlX0P1]CBH00`1[Bb@0K4`U06a<
9@0206e=9P<0KThW00L0KdlX06a68@1/BB<0Kd`V075?:@1aDBX0L5<[0080KU8Z0`1[CBT206Y<:0<0
JD/W00H0IDdW06I<9`1VC2L0JDdX06Y<:01]C2T206i<:@80JdhV0P1/CbL02P1]D2P0KU4Y06mB:P1_
DRX0LE8c071A<P1^Cc00K4d^06Y;;01XBBX206I7:00506M;9P1XC2L0JD/W06a;:01_CBX00P1aCB/0
1`1dCB`0KDdV06e=9P1^CRL0KdlX071@:@1aDBX00P1bDR/01@1bFc40L5T_06iE;01^DRX0KE0X0080
KdlX00T0LDlY06i=:P1^CBX0KD`Y06a;:01[BRL0JTTV06U89@1XAb@00P1ZBBH01`1[BRL0K4/X06]:
9`1YB2D0ITDR06E48@1TAbT00P1UB2X01P1VBB/0J4/]06U<;P1YC2h0JTd_06E;9PH0I4XU00T0ID/V
06m=:P1^C2T0KD`Y06Y<:01WBbH0HdTT06988`1PB2800P1QA2@01P1RABL0HT@X0653:@1O@BT0GClW
05`m:080ET4V00X0FD4W05Y09`1L@2P0GT0X05m1:@1P@2T0GdPY05e69`1KA2D0F44R0`1F?b00101G
@240F44R05Q18P1H@B8205M08@80ESlP00X0EChO05U49@1LABH0GDHV05m79@1RB2D0IDTT06M99@1X
BR@0Kd`V0`1^BbD02`1_C2H0LDhX07=@:P1cD2X0M54[07AC:01eE2T0MUDZ07MF:`1hEb`0NUT^0080
NeX_0`1kF2h307aI;`80OEX`101lFBl207eJ<080OU/a0`1mFS000`1lFBl0NeP^07]H;P0207YG;@80
N5D_00<0Me@^07IC;@1eDR`00P1dDB/01P1cD2X0KE4/06eA;01_DBd0LU4^07AB;`80MU8`00<0NE8a
07UF;P1iERh0101iERh207YG;`0;07EE;P1cDb`0L50Y06i>9`1]CBH0KThW06m?:01`D2T0L4l/06i=
:P1]C2T00P1/BbP00`1]C2T0KTdZ071?;00306e<;B_ooooo000Zooooo`040:=gAP2TN4L0Y7Q70:Ei
B080YWY90P2WNdX30:9i@`80XgY40`2TNdD02`2TO4P0YGe90:QoB`2YOT/0ZWa:0:UiB02WMdH0YgE4
0:=hA@2UNTL0YW]80080Yga900<0YW]80:EjA`2SN4D00P2VNdP20:MlB@040:QmBP2YOT/0ZGi;0:Yo
C0P0ZGi;00@0XGE60:=gB02VNT/0Z7a=0P2YODh0102XO4d0Yg]<0:QoB@2XOdT30:MnB0<0YWe72P2Y
OTT40:YoBP<0Zh1;0P2ZPDd00`2[PTh0[8=?0:f4D0020:j5D@030:n6DP2XOd/0Z7m;00H0Z7m;0`2Y
P4X20:QoB@<0Ygi80P2MO4L00`2ONdL0WgY60:1hA@020:5gA@070:5eA02JMD40VGA009Ud@02HLcl0
Ug8n09Ia?@0209E`?00809E`>`2DKc/0Tfhj095[>P2?JCX0SFLj08]T>@2:HcP208aV>@0408]U>02:
I3L0RF<f08QR=@80Qf4d0P26G3@01023G3<0PE`b081K<@1nFc4207aK<00:07eF;`1lEBh0Ne@]07YC
;01kE2d0OEH_081I<P21FS<0LU8[07=C;0<0MED^00<0Le</075A:P1`D2T00`1`D2T306m?:080KThW
00H0Jd/T06a<9@1]CBH0KdlX079B:`1dE2d207IF;`80OEP[0P1nFB`207mJ;@80P5/^0`28HS<208US
=0<0RV@e202;IcL208US=00408YT=@2;ICH0SFLh08iX>@80SfTj00P0QV8b08QT=02:ISH0S6Ph08eY
>@2>JSX0SFTi08aX>0P0S6Hi0P2<ISL308eW>0@0SVPi202<Ic<2091[=`0308mZ=P2>JCD0SFPd0080
RfHb00L0RVDa08iR=@2=HSD0SV<f08iU=`2<ISL0S6Ph0080RfTi0P2=HSD0102>HcH0Sf@g08mT=`2@
ICP2095V>@80RV@e00@0RfDf08aV=`2<ISL0SFLh0P2>J3T508YT=@0;08US=028HS<0R68c08aW<P2=
J3<0SVTd08mZ=@2>JC@0S6Lb08UT;`27HRd00`27Hc<00`28I3@0RFDe08YV=P0208YV=P@0R6<f1029
I3L2089P<00408=Q<@24HS80Q68b08ES<`80QV@d0`27HSD208IQ=0<0QF0c00<0OU/c07eJ<P1lFC40
0P1lFC401P1nFc<0P5de085N=P1iER`0NUL]07aI;`80OU/a00<0OEX`07aI;`1kF2h00P1fFBd00`1f
FBl0MUTa07IH<P0207IH=00I07EG=@1fF3@0MELc07AF<P1bE300L58^06i@;01]Cb/0K4hZ065?:`1O
CBT0FDTW05=48`1?@R80BSlO04Tn8018?b00BCdS04Pl9014>R40@3PQ03dg8@0l=b<0>SLT03/h9@02
03Tc7@0703Lb7P0d<Ah0<S4O02l`800^;al0;2hP02/[8@0302XZ8080:BTO0`0X:1h202DX7`0402@W
7P0S9Qd08RDL024T6`8082<J300N8AX401dP6@0801lR5`0P8aP08B@K024T7@0P8Qd07R0M01`N6`0J
71/301XL6@806adJ0`0L7Q/03P0N7R007QhN01lO7`0O7ad0824L024R700Q8QX08R<K02DV5P0W:1P0
:R/K02`]7@0^;al0;BhN0P0/;Ad0200^:AH0;b`I034^7@0b<240;c0R02X/7P0T:1X08BDG0`0R91T0
0`0S9AX092HK02DW700202DW70<08RDN0`0Q91d2020S70P07b4N200O8Q/00`0P82007alO01hN7P02
01dM7@0K01hN7P0P82008B4Q02TO7P0]8b80;RHS02`W8@0Z9Qd0:BLK02//7P0_<200BcHI05Q3901X
DBl0Le`c08=[?`2ENdX0VH1:09IkA02_R3/0/he>0:B2E@21Hd/0GDLl04Hh=@0g;bd0:BDR00P09RPU
200X:B<00`0Z;B@0:2/R02LZ8@0202DX7`0402LZ8@0X:b80:RdT02X]90<0:B`U00<0:2/T02LZ8`0V
:B800P0V:B8202LX8080:2TQ0P0Y:R8202X[8`0@038]:@0a;2P0<2/U02l[8P0`;240<RhR03@a8P0e
<R<0>34N03/e7`11>B@0B3dW04/o9`1=?bD0BcdR04Xj80P0CShW1`1??BD01`1@?RH0CCX[04`k:`1<
>b/0BSXZ04Pk:P16>bT00P14?2T604Th:080BSTY00/0C3H[04dg;01==bX0CSPZ04lj:@1@>bP0DC`Y
054l9`1K@R@0GD@V05m6:0030658:P0R0617:@1OARP0Gd4U05i3:01MABT0EdHZ0597:`1<ABT0Ad<X
04=29P1<?bh0Bch]04Xm;019?2/0AcXY04Hi:015>2L0A3LV04<f;@14>2`0ASX^04Hj;016>RX0ACXX
04<h9012=b<0@cLQ04@h8P16>R@0BCdW04a0:P1?@bd0DDD_0596<080C4@a0P1;@c001P1<A340CdLd
0559=P1CBcP0CT4^04m2;`<0DD@a01T0Cd8_04`o;01;?R/0DDX`059;<@1EC2l0FDh^05mB;`1UEc80
JUdc06eN=@1^F340KEL`06aD;P1/DRd0L5@_07AF<01jFS@0OEdg07QM9P1lGRP0Of4[089S;@25I2l0
QV8^0080QV4]0P25Hc<02P20GS00NeT/07UF;P1iES00Me<a079>;P1^BB`0K4T]06]8;01YARX206Q5
:@0A06Y7:`1/BBd0KDX^07A@;P1eDBl0ME4]07IC;@1gE2`0N5D[07UF;01iEbX0OU@/07mE;@20ER`0
PEP/08=J;025GB`00P26GR/02027GS00RV8a091V=02EJSD0W6lf09mb=`2QLcD0XW@f1P2ELRh209Ic
;`0609ib<`2PM3D0XWHe0:Ei>02WO3P0ZGhi0P2YOcL02`2/PSP0Z7hd0:Ek<`2XOCP0[X<o0;66@P2^
PT40ZWhm0:^5?P2XPS/0Y7hg0080XW`e00<0YGlh0:V3?02/QSl00P2UPT801P2TPD40Xh100:9o?`2Q
OSh0X7dm09ml?0@0XhU@00P0XXQ?09n5C02MPdX0Vh5809=gA`2AMDD0SW9208]_?`80RFdm0P2:KSh0
1P26K3T0Qfdj08Q^>`29Kc`0Rg4n08ec@080SWA10P2ILCd0502FLC`0Tg0j08m^>02=KSL0S6df08Y]
=@2?LSX0Rf`e08MX<@2:JC<0TVli09Mb?@2HL3`0UVhj099_=`2AKSH0SV/c08YW;`27I2`0QF8Z0P24
HBT03P1mGRD0NEXS07EE8P1eEBH0MUD/07ID;`1bCbl0KT/]06]?:01/D2T0KU8[071D;@1cEc00METb
0P1gFc@0201cF2d0MEX_07UN<`1lHCH0OF8g07]P=@1iGS<0Me`a0`1cGBh01`1bGBh0Ked]06aL:`1W
FBP0IELV069F901VCb<00P1VCbD00`1VCbH0IDdW06E=:@0206E=:`80FdlW0`1LD2P305eA:@0306YB
;P1XD2`0IThZ0080Idl[00T0Hd/W05]37`1D?1P0D44R04m08`1=?R40C3`R04`l8`1<?2D00P1>?BT8
04Pm8@0>04@k7P15?1l0ASdP04Po8P19@2<0Bd8U04a39P1=A2L0Ad4O04M18@16@200ASlR04Dn8P14
?B<204<k90<0?3PM0P0k=a`303Xf6`80<RlL00@0<c0M03@a7P0d<Ah0=C8O0P0f<b0203<e7@80<S@L
00@0<C<K030b6P0_<AT0;c4I200_<A`0600Z;1h0:b`L02//700^;A/0<BhK03Ha7@0i<ad0>cDO034`
6`0];aT0:R`G02DX5@0R9QD07bHF01hW5P0O9aP05bLJ01PV6@0I9A/06b8K01XO6`0L71`071XK01hI
7@806Q`I0P0I6aP301PJ5`0301LI5P0J71T06Q`I00806A/H0P0H6QL201LI5Q006A/H00@05aTF01PJ
5`0I6aP06A/H0P0J71T00`0I6aP061XG01LI5P0801XJ60P06A/H100H6QT201LI60805QPG600G6AP3
01PJ6@<05aTH>P0F61L301DG5P805QPG0`0G6AP801TK6PP05aTH200I6aX301XJ60@06a/I100L71X3
01dM6`<07QhL200L71X201hM60807ahI0P0P7aX2024P6`<081lJ0`0Q81/2028Q7004024Q6@0R8QX0
8R8J02<S6`8092@L0P0U9Ad3028S6`808B8J0`0P8AT0100V8QT09b<J02LS6P0W8aX202PT6`80:BDL
0`0X9A`202TV7@<0:RLN00P0;24M02dR700^8ad0<2HM034W7@0c:Ad0=2/L03D/7@80=2LG00X0=BPH
03LZ6P0h:a/0>B`L03X]7@0k;Qh0>RTG03`[6@0n;A/0@C0N0P12<Al02011<1h0@2lM044_6@11;aT0
@S0J04<a6`15<ad0AS@N0P17=Al01014=1/0ACDL04De7015=A`204Hf7@80AcLN2017=b0204Td8@06
04Le8@17=R80ASLR04Hg8P14>280ACTS0P19>1h304Pg7@<0AcHL00P0BcLO04Xf7P19=Ad0B3@L04Te
7@1;=al0CSXR050l90@0DCTQ101@>200101?=al0D3PP050h801@>203054i8@H0DSXR101C>b<204di
800404`h7`1;=ah0BcLN04Xf7@80BCDL0P17<Ql00`18<b00BC@Q04Xe8P0204`g900D04dh9@1==Ad0
CSHN04lg7`1@>200DCTQ058j8P1C>b<0E3`T04dk9@1<>R@0BcTS04Tg8@18=R00AS@N04Dc7@14<Q`0
ACDL04Hf7@18>1l204Ti800904Ph7`16=Qd0ACDL054h901B>BD0DSTS05<k8`1D?280ECdQ0080ESlP
00<0FC/Q05/m8`1M?bD00P1O@BL05P1M?bD0FcdS05Tk8@1K?1d0G3dN05dn7`1O@240H44R0693901S
A2D0I4DV06E48@1VAB80IdHS06Q7901ZBBH0JdXW06a;:01]C2T0Ld`[079;:P1`BBP206m89`040719
:01aBRT0LT/Z06e@:0<0KU4Y0P1_DRX2071C:`80L4l^0P1aD2l0101bDC00Le8a07=B<@1dDc8207IF
;@0L07MG;P1hF2l0MeL^07EE;01cDbX0LU8Y06Y<:P1/CR`0KU0^071B<01_DBl0K4h/06Q::01UAbD0
LE4Z06m?:01/C2D0Jd/T06a<9@1_CbP0Le</07IF;`1]CBH0KThW06m?:01`D2T0LE4Z07=C;080M5@]
00P0MeL`07IF;`1eEBh0Le</075A:P1_CbP0KDdV06a<9@80Jd/T0P1/C2D03@1]CBH0KThW06i>9`1^
CRL0KdlX06]5801[B280Kd`V071>:01aDBX0Ke8Z06iB:P1]DBT00P1[CBT206Y<:0<0JD/W00L0J4XV
06A<9P1VC2L0IT`W06Q<9`1ZC2P0K4/X0080KT`Y0P1YC2@0101ZCBD0JdhV06a?9`1]D2P206iA:@06
075B<`1`DC80KTl`06a=;P1ZBb`0IdPY0P1UARL206M;9P0306U;9`1/BbP0KT`Y0080LDd[00H0M4d/
06e=9P1]CBH0KThW06m?:01`D2T2075A:P07079B:`1bGC80LEX`06iG;@1/DbX0K50X06e@:002071@
:@0:06i=:P1]C2T0K4/X06]:9`1ZBBH0JDPU06Q7901WAR<0JTTV06]:9`80K4/X00@0JdXW06U89@1W
AR<0ID@Q0P1UB2X00`1VBB/0IdX/06Q;;@0206Y=;`0306]><01TC2H0Hd/U00D0Hd/U00H0I4`V075?
;01_CBX0K4/X06Q:9P1UBB@206988`0906598`1QA2@0HTDW06=6:01SABT0HT@Z0612:P1N?bX0G3dX
0080F4<X00<0FT8X05]1:01L@2P00P1N@2P01@1O?bP0GdL[05e5:@1J@RH0EclS00<0ECdQ00L0EShR
05U19@1H@2@0EclS05Hn8P1E?B40E3`P0080Dc/O0P1IA2D02@1LABD0GdHW06579P1TAbD0IDTT06M9
9@1`CBL0Kd`V06a98`0206]88P0<06i;9@1aCRP0LDhX07=@:P1bDBH0Le8W07AC:01eE2T0MeH[07QG
;01iF2d0NUT^0P1iER`00`1jEbd0NeP^07aI;`0207eJ<00307iK<@1kF2h0O5T_0080O5T_0P1mFS02
07iK<@80OEXb0P1lFC401P1kF300NUL_07YG;`1iERh0N5D_07MD;P80MU<]00`0ME8/07AA:`1cD2X0
Le0Z06a?;@1]D2h0KU0^075@;`1cD300ME4a07IB<P1hDC8207MD;00307QE;@1iERh0NEH^00<0NUL_
00@0Le</079B:`1`D2T0KdlX101^CRL00`1_CR/0KTdZ06a;:00206]:9`0306a;:01^CBX0Kdh[00<0
JdX[:oooool002[ooooo202TNDH01`2YOT/0Z7e:0:IkB02UNTL0Y7U60:EjA`2VNdP00`2WO4T30:Qm
BP<0ZGi;202UNTL80:IlBP80Z7i<0P2WOD/40:IlBP040:=gAP2TN4L0Y7Q70:EiB080YWY90P2WNdX0
1P2TNTX0YG];0:EkB@2UO4P0YWe90:ImA`80Ygi60P2VO4X0102WOD/0Z7i<0:QnC02YOdd20:Z0CP<0
Yge;0`2XOT`30:UoC@P0ZH1<00@0YWe70:MnB02YP4X0[8==0P2]Q4h20:b3C@80Yh9;00L0YX5<0:F0
C02TOTd0Y7i?0:=mCP2SOE00YG];0080Y7Y:00<0XgU90:9hB02QMdL00P2PMTH01P2MLd40W79009ab
@02KLCl0VW0n09U_?@80V6hl0P2CKCh0102BK3d0TF/l095[?02@JS/208mY>P0808iX>`2=IcX0S6Hi
08YT=`29HcH0Qf4d08IP<`25Gc8208MR>00408EP=P24GcD0PUdc081K<@80OeX`00<0NeP`07YG;`1j
Ebl01@1jEbl00`1dDB/0ME8/07MD;P0207QE;`0307MD;P1fDbd0ME8/00<0KU4Y0`1]D2P206a?9`80
LE4Z0P1bDR/01`1cDb`0M5@]07EE;P1eEBh0NeP^07aI;`1nFc400P20GC<02@1oG380OEX`07aI;`1j
GC<0OEhb07iO<`21H3<0Q68d08MS<`0208YT<`<0RVHf0P2;IcL308aX>0P0SFLh202<ISL00`2>J3T0
S6Hg08]U=P0208US=00308]U=P2<ISL0SVPi0080Rf@i00<0RfDh08aV=`2<ISD00`2=J3@0302=J3<0
SF4d08aQ=02=HSD0S6<e08]U=P2;IcL0RFLg08YX>02:I3D0RfDf08eW>080SVPi00<0SFLh08]U=P2:
I3D00P2@ICP408mT=`80SV<f202=IcH8091S>@80Qf8]00H0R6<^08YU<02<Ic80SFPc08iY=02?JSD2
08iX>@80SFLh0`2<ISL00`2;ICH0R6@d08QT=00608QT=00408MR=@26HC@0QV4d08EP<`80Q5lb0P23
GS400`22GC00Peha08EP<`0208MR=@0408IQ=024Gc80Peha08QS=P80Qf8e00<0QF0c08AO<P23GS40
0P22GC0208EP<`0308AO<P23GS40PUd`0080P5/^00@0OeX]085O<@20GS00OU`^0`1lFR`01@1mFbd0
OU`^07]H;P1lFBl0OU/a0080Oe`b00T0OEX`07aI;`1jEbd0Le</07=C;@1`DR`0KU8]06]A;P1YDBl0
0P1WD3007P1YCbh0Id`^0658:@1KA2D0ET4T05<o901B?RD0D3lU04dl8P1;>b40BSXQ04Pi8P14>280
@SLS03lg8P0n=R<0?CPT03`g8`0j=B40>C@P03Pc7`0i=200>SDQ03/f8P0c:b00<bXQ034Z800]:B00
:bPQ02LV8@809RDQ00T09BHQ02DV7P0T9Ad092DO02<T7`0R8R008B4Q020P800P82800P0P8a`00`0O
8Q/07R4J01dP6@0201`O600301/N5`0N8AX07R4J00H07R4J0P0P8a`301lR6`<07R4J00<06adJ01XL
6@0I6aP00P0H6QL00`0I6aP06adJ01`N6`0201`N6`807AlL0`0N81d01`0O8Ah08BHO028W800V:B00
:B/P02X/7`0/;Al00P0^;1d0300/:AX0:bPI02`Y6P0b;b00=c@U03Hc900_;1d09b@E01hO6@0P8A/0
8B8L02<T7P@092DO0P0V:1d302DW70<092HK0P0P8A/4024R70808R<M200P8a`801lP6P0P024S7P0R
91l092DO02HV7P0Z9ah0;2PM02dY7P0`:Qh0@BhP04`g9P1JA2l0JU0e07QK>@28J440UWE80:1nCP2?
LU00Z8UM0;VDH02VOdP0P5`/05m09019<R`0?B`d02HU;@0R8BL08R<W02PZ:@0V:2<082<L020S6P0V
:Ah:02LX8P80:2TS0P0Y:R@302X[9@P0:b`T200Z:b<2030X9@04034Z900c;2@0=2dS03H`9080=c4S
00H0?cDY03lf9`12=RP0A3PX04Hi:01:>bP204`k9`P0DC`[0P1??bP0101>?RL0CCdV04dm9P1<?2D2
04/k9080CclX00@0CShW04dm9P1=?BH0C3`U0P1;>b@0101:?bd0AS/Y04<h9P13>2H204Dj:003048g
9@0n<b40ACPW0080ACPW01/0ASTX04Pk:P1<?bh0D4<b0595=01IA2L0FTDX05a59P1OARL0HDLV06A7
9@1UB2H0ITPT06U;9@1WBbH0HDTW05i7:01IAB`0E4<_0551<@1?@S80CD<Z04e2;01<@B/0BSl[04Tn
;017>b/00P15>B/03P18>b/0AcXZ04Dh:014=bL0@cHV04@g9`15>2P0ASTY03`^8`0o<BH0A3HY04Tk
;P1=@300D4<b0P1AA340:018@Bh0Bd@a04m9<`1CCCD0EDle05A>=01BCC00D4/^05A5<P1EAS<0ETXd
05U==@1ICc@0Ee0c05A?<@1DCbl0Ge8_065C;P1TES40J5Tb06eK<`1aGS@0MF0e07IQ=P1dF2H0LeTX
07AI:P1bFRh0LEXa06mI=01[Ec@0JUHe079@:P1eDbd0NETb07]N=P1lH3P0NV4h07QO=P1fGcD207QG
=00/07EG<`1cEC<0Ke8b06]@<P1WCS00I4d^06=;;`1JBBl0FdL^05]7;01LAbX0GdPY0699:P1UBR`0
Idd/06M69`1[BRT0Kdh]071?;01_CbT0L50Y07EE;01jFS40LUD[07IG:`1jFbl0Oeha089P<P25HC40
QEl^08AN;@1nGBL0Pf8/08aY<@2DL3H0VG8g09Ua=02FKS40UF`^09M[;02IKBh0VG0b09]c=P2KM3T2
09Ue>`0709Md?02FLSH0Ug<g09Ue>@2KMc/0W7Pl09]g>`0209Yf>P80XGHo00H0XWPl0:=j?02TNcT0
YGdg0:In=P2WP3D40:5i=080XWXe00@0Xg/f0:Al=`2TO3L0Xg/f0P2RNSD01@2SNcH0Yglj0:^3?P2]
QD00YX@m0080YhA000X0YhA20:J3@`2SOd40XGe109mk?`2ENd00U7Xo095g?02>M3T0S78g0P2;LCH0
502<LSL0SVlf08ma=@2ALcL0TgDg09=e=@2CMS@0TWDa095d<02ELS00UG8b09Ec=02BLSL0T74j08a^
>P2:K3X0QVXj08mU=@2@ISH0TVPh0P2CJCT03P2AIcL0T6Hf08iT=02@JSd0SVLl08aU>P28HCP0Pe`e
07mG<`1lE340NU8_06UA;`1XD2h0Idl]0P1VCR`02@1XD2h0JE4_06]C<@1XDBL0JE8X06YC:@1/EB/0
KEH/06mH;P02071I;`0907QN>@1bF3<0KUD/06mG:`1dG2`0N64]07MP:P1dGRD0MUlf0080M5dd00<0
LEXa06iG;P1/EB`00`1[E2/0101UDbl0I58^06=A;@1SDBd2065?:`03061>:P1OCBT0Fd`U0080G4dV
00<0GDhW05i?:01OD2T00P1PDBX0401NB1l0Ie4X06aI<@1VDRd0EdDQ04`l6P1<?Q/0Dd@S04hm8`1=
?280BcXP04Xi7`1;>R00C3/Q04hm8`1@?bD8048k7`0;04Dn8P14?B40@S/O048k7`13?200AChR04M0
9019@RH0@c`P04@m8@15?R800P16?b<00`15?R80A3dQ048k7`0303/i8P0=03Xh8@0i=b00>3HO03Le
7P0f=1d0?CLQ03/e7`0h<ad0<c4J038b6P0`<QX0<C<K034e700302la7080;S0K0`0];aX302d^7P80
;2dM0`0[;1`0400]8Qh0;b@P034X7`0b;200<RlN038a700b<QX0<3<H02L/600V:aL09BTH02<W600R
9QP082<H01lR5`0N8AP301`N6`806adJ0`0J71T201XL6`806A/J0P0H6QT201LI60805QPG0`0G6AP3
01PJ6@P06A/H2P0G6AP301PJ6@806A/J0P0J71/801TK60P06A/J400G6APH01HH5`P05aTH200F61L8
018H60<05ALF0P0F61L301LI60P05AHH4P0F61L301LI60<061XI100I6aX201XL6`806adL0P0G6AP2
01PJ6@806A/J0P0J71/801TK6P<06Q`I0`0K7AX301`N6`P07AlL200L7Q/201dN60807QlI0P0O81X2
020Q6`P08R4L200S8a/8028R6PP09b8L0P0Z9QX302/W6`<0;2PL00@0=2XN03<Y7@0c:Ad0<RPL0P0a
9a/2030V6P0803<W5`0e:AT0>2`L03X^7P0k;al0>BdM03L[6`0f:QX203/_6@0303``6P0m<A/0?S8L
0080?c<M00<0@3@N03lb7`0o<Ql01P0o<Ql804He8`80Ac8M00<0AC<M04@d7@13=1d00P11=Ad00`10
=Qd0ACDN04De7P0604De7PP0AS@N0`1<>20204/g7`<0BSHN0P17=Ad01018=Qh0BCLO04Tg7`1:>202
04/i8@0404`g6P1=>1/0CCPK04hi70<0CcXM0P1@>ah01P1?=al0D3PP050h801A>B40DSXR05<k8`80
E3`T1016=Ql204Lg8080B3PQ201:>28204hj8@0304di8@1=>2<0C3LT0080C3LV00D0C3HX04Xj8`19
>B80ASHO04@d7@0204<c7080A3@M00<0AC<M04Le7`19=b400`1;>B<02019=b40B3HP04Tg7`1;=al0
C3PP04dg801?=R00DCHQ0P1B=R4205Dk900405Hl9@1G?BH0F3hW05Pn9`80FClX0100FS`P05/m8@1L
?R80GT0T05m19@1Q@bL0HT@X06=5:@1SAR@0HTDS06948P1T@b80IT<S06U59@1/B2P0KdPY0`1^BRP3
06m;:@80L4`Z00<0Ke4]071B;P1aDbl00P1bE3002`1aDbl0L58^06mA;@1[CbL0KE4Y071D;01bERh0
LeL_079F;P1aEBd0L5@/0080ME@a0P1fEC80201gES<0N5Ld07QG=01hEc@0M5Hb079D<01`DRh0KDl[
0`1/CRX206e?:`0706a>:P1[CBT0JddY06a>:P1^D2`0L58^075C;`0806e?:`80KE4/00T0Ke4]075@
;@1bD2d0Ldl]07A@;P1fCbh0JD/Y06Q::01WBBL00P1VB2H206Q::00506Y<:P1/CR`0K4/Z06a;:P1]
C2/00P1^CB`00`1_CRd0L4l^071?;P0506]=:@<0JT`X00H0JU<Z06]B:P1ZDBT0JdlX06]=9`1]CBL2
06e;9P0406]=:`1ZC2X0JT`Z06Y<:P80JD/Y0P1XBRP04@1/D2/0Id/V06968@1SAb80J4`W06]?:P1Y
CBP0ITXU07E8:`1cAbX0L4LY06a8:01/BbX0K4h/06aB;`1]Dc00JddY0080K4hZ00<0KDl[06i@;01^
D2`00P1_DBd00`1ZCRT0JdlZ06eA;00206iB;@0306eA;01[CbX0JThY00<0JDX[0P1XBBX306M8:@80
IdXZ00@0ITTY06E8:01SARH0HTDU0P1QA2@00`1XBBX0ITLX06A59P020693900306A59P1VAbP0J4TZ
00P0J4/[00h0ITPV06I99`1VBBL0I4XW069:9P1NB2<0FDDP05M37P1FABL0Ed@V05I39@1G@RD0F40T
05To9080Fd0U0200ID8V068o8`1N?200GChQ05m2901N@bD0Fd0R05Hm7P1N@2@0FS`P05Dj7@1F?Al0
FT<T05]69`1H@b@0DSlO04dm8`1>?R@0DD0V05A09`1D?RH0ECdU05<k8`1B>240E3lR05E08@1I@R<0
G4<T05m5901SAR@0IDTT06I89080JT`Z1`1[CB/0201^CRP0L50Z07=C;01fERd0MeP/07QI:`1gF2X0
MULX0P1mFS8207aI<@0507]H<01jEbl0NUL_07UF;P1hERP00P1iEbT00`1kFB/0O5X/07eK;@0207iL
;P06081J=@1mFS@0OEXd07]I<`1iFC80MUTa0P1dF300101bEB/0LE@Z06mB:01]D2H206a?9@80KE0V
00<0MED^07IF;`1iFC800P1jFS<02`1gEc00MED^07=C;01`DBD0LU<W07=F:P1eFRd0Le/]06mI:P1[
ERL0J5<T00<0KDl]0P1/CR`306]=:`80KDh_0P1^Cc00101/CBh0JDX[06I7:01TABH306I892_ooooo
000Zooooo`P0Y7U600P0ZGi;0:QmBP2VNdP0YGY70:AiAP2UNTL0YW]80:MlB@<0YW]80P2WO4T30:Qm
BPP0YGY7202VO4X20:QnC080Yge;0`2VO4X00`2UNdT0Y7Q70:AhA`020:EiB080YWY90P2WNdX20:Ek
B`040:EkB@2UO4P0YWe90:ImA`80Ygi600<0YWa:0:MmB`2WOD/00P2XOT`20:UoC@030:Z0CP2XOT`0
Z7i<00L0Z7i<202YP4`0102VODL0Ygi80:Z1B`2/Pdd20:f4CP80[8==0P2WPT/00`2VPD`0YH1<0:An
C@020:=mCP070:9lC`2TNTX0Y7Y:0:=iB@2RN4P0XGM70:1fAP0209meA@0609ec@@2LLT00W79009]a
?`2JL3h0VFlm0P2HKS`209=]?P04099/?@2AJc`0TF/l091Z>`80SfTj00H0SVPk08eW>P2<IST0RfDh
08US=P27HC@208IP<`80QV4g00H0Q5le08=N=021G380P5/a07mJ<01nFBl307]H<0@0NUL_00@0NEH^
07AA:`1eDR`0Me@^0P1hEBl00`1gE2h0MU<]07EB;00306iA:@<0KE0X0P1/CbL01P1`D2T0LE4Z075A
:P1bDR/0Le</07AD;@80MED^00<0NeP^07aI;`1nFc400`1oG380201mFS00O5T_07]N=01nGc<0Of0d
085P<`23HC<0Qf<c0P29Hc8308YV=P<0RfLg0P2<J3P808eW>0P0S6Hg00<0SVPi08eW>02<ISL00P2;
ICH00`2<ISL0SFLh08iX>@0208]T>@0308]U>02<ISL0S6He00<0SFPd00`0SFPc08eQ=02=HSD0SF8e
08eT=P2;ICH0RfLg08UW=`2:J3P0RV@e08]U=P2=IcP208iX>@0308eW>02;ICH0RV@e00P0Sf@g202=
IcH808mT>@0608QS;`29I300RF@`08YU<@2;IS80S6Lc0P2=J3@208eW>080S6Hg0P2;ICH208YT=@P0
R6@d00<0Qf8e08IQ=026HC@00P25H3<208AO<P80Peha00d0Q5lb08IQ=027HSD0Qf8e08IQ=025H3<0
Peha08QS=P27HSD0QV4d08EP<`24Gc80Peha0080PUd`0P25H3<02@24Gc80Peha089M<021G2l0P5/^
07mJ;@21Gc40P5h`07iL;P0307aJ;00:07eK;@1nG2h0NEH/07YG;@1kF2h0O5T_07]H;P1iER`0Me@Z
07IC:@80Le</02@0L58/06iB;@1[DBh0JE4_06QA;`1WD300JDl^06M=;01RBBX0G4DV05M29@1D@2D0
DclT050o9@1=?280Bc/Q04Xj8@18>B80A3PR048g8`0o=b80?cLT03`g8`0k=R80>C@P03Pc7`0g<Qh0
>3<O03Td800j=B40=2`Q03<[800a:R00;RXQ02/X8@0X9b8202LV8@0902DV8@0U9Qh09BHN02@U7`0S
91h08R<N024Q7`0Q8B40820P008082<L00@07b8K01hQ6P0M81T07B0I0P0L7aP901hQ6PL07b8K00<0
6adJ01XL6@0I6aP00P0H6QL00`0I6aP06adJ01`N6`0201`N6`807AlL100N81d2028W800702DX7`0W
:Ah0:2XM02//7P0^;1d0;bdN02h[700202`Y6P05030]7P0d<B80=34R02l/7@0Z9aP00`0Q8Q`00`0R
8ad08b@N02@U7`0202DV80809RPM0`0U9a`302@V6`H08B8L0P0R8ad8020S70P07b0J0P0Q8ah07P0S
91h09RHN02TV7@0/:1d0;BTN02lY7@0j:1X0@c0Q054l9`1OAbd0KE<b07iQ>@2?L4@0Vg]<08mcB`2Q
PU<0[HYB0:F1A@2BKSX0N5Xf05U2<P11;b/0:2H[02HT9`0/:R/0=3@b03<d;`0Z;BH09BPO02P[8PX0
9bPR0P0X:B<202TZ90<0:R/U200[;2@802X[8`80;RTU00l0;bXT034]900b;R<0<blS03@a8P0e<R<0
?3@W03hd:00o=RL0@SHV04Dh9`18>BH0BSTW04Xi9@1?>RT00P1@>bX2054l:`<0DSd/0P1??bP204hn
9`0504dm9P1<?2D0C3`U04`l9@1??bP00P1>?RL204dm9P80C3`U00T0Bc/T04Xo;@16>bT0@SLU04<h
9P15>RP0AS/Y048g9@0n<b400`14=bH05@15>2L0AcXY04Xm;01>@C00D4<b05M29@1H@bH0Fd@U05i5
9`1QARP0I4LW06I99`1XBRP0JT`V06Q<9`1TBRT0H4TZ05Y6:`1EABh0DT<^0513<00204m3:`0904i2
;01<?b`0BSd/04Tl;017>RX0AcT/04Tl;018>b/0ASTY00<0A3LW0P16>BT01@12=2T0A3H[04Li;01:
?Bd0C3l^0080CD0]01T0CD4[04]3<01>AS40DTXe05I>=`1HDCL0Ee0d05E><@1DCC00ETLb05M8<`1H
C3@0FThd05YA=01KDS<0F58b05MA;`1SEC00IELb06QI<P1]Fc<0LEhd07IQ=P1hHcP0NV<g0080O60^
00h0Nf0a07QP=01fGcH0LU`e06mH=P1/F3D0Le4[07ID;P1hF340NUde07UM=@1fGC@0M5/b075J<080
LU@`00P0LE<_06mB<01ZD2l0Idh_06A=;P1RBb`0GdX]05U8;P80FTH[01<0FdHY05i7:01RBBX0ID/Z
06I<:`1VAB@0JdXY06m>:`1`D2X0KdlX071@:@1dE2/0NET`07=F;01gF2`0NEX^07eL;`20GS00Pel_
0080QEl^01H0OehX08AS;@2<JC40Tfle09Ub=`2ILCH0Uflb09E[;`2HK2d0VFd`09U`<P2JLSD0VG8g
09Mc>@2FLCX0U74i09Ib=P2GLcL0VGDi09]g>`2LN3`0VgLk0P2JMSX209ie?@0409mg?02OMcT0X7Th
0:1i=080XG/d102NMc@209mh=@80X7Tf0`2QNSL01@2RNcP0Xg`i0:Io?02XPCh0ZH8o0080YH8n00/0
YX=10:F2@P2TP480XGe109mk?`2MNCl0UWTo09Ag?@2AM3X0Sg8h08e`=P0308a_=@0S08e^=@2>KcH0
TG<g09=e=`2DMSH0U7Le09=f=02BMC40UW<a09Ic<`2ELcH0Tg<h08m`>@2<KSX0RF/i08EY>@2>I3@0
SfDe091V=P2AIcL0T6Hf08iT=02<HS80Rf4a08QS=P27HSH0QF0d085L<P1nF340NU@_07QB;P1fD2`0
JU8`06UA;`1XD2h00P1WCbd00`1XD2h0JU8`06]C<@0206UB:00406]D:P1]ER`0KUL]071I;`80LU/a
00T0N5hi07=J<P1_ERd0L5P/07AL;01gH2h0MUl[07AM9`1cGC@00P1aFc800`1^F2l0JeD/06UC:P03
06QB:@80He4]00@0HU0/065?:`1PCRX0H4hZ0P1OCBT01P1LCBH0GDhW05e>9`1NCbP0Ge0Y061A:P80
HE8[00X0HT`S06MA:P1XEBd0HDlY05A4801<?Q/0CChM04m2801=?B<0C3`R0`1:>R000`1;>b40CCdS
04hn9008048k7`0:04<l8012>al0@S/O048k7`13?200AChR04Q19@19@RH0A3dQ04Dn8P<0ASlS00<0
A3dQ048k7`11>Qh00P0k>B800`0j>240>CLP03Pf7`0203Le7P0903Hd7@0m=b40>cDO03Pc7@0d<Q/0
<S8J030b6P0a<a/0<CDL0080<38M0`0_<A`302h`6`80;BhN0`0/;Ad302//7006030U8@0`9b00<RTP
03@^8P0c<1l0<S4M0P0_<AT0200V:aL09RXI02@X5`0S9aP08BDG020S600O8QT07R4H0P0L7Q/301/M
6P<06Q`I0P0J71/201TK6P8061XI0P0G6AP201HH5`<05aTH0`0H6QT801TK60X05aTH0`0H6QT201TK
6P806Q`K200I6aP801TK6Q005aTH600F61L801LI60P05QPG200B61P301DG5P805QPG0`0G6AP801DF
61805QPG0`0G6AP401PJ6@<06A/J0P0J71/201/M70805aTH0P0H6QT201TK6P806Q`K200I6aX301XL
6@<06adJ0`0L7Q/801dO70P071hK0P0M7QP201hO6@807b0J0P0P8A/8028Q70P08b<K200R8QX802LR
70<0:RHJ0P0[9a/302`X7080<bTM0P0b:1`2034W6`80<2HJ00D0=BTI03HZ6P0g:a/0>2`L03T]7@02
03P/700503L[6`0k;aT0>blI03``6P0m<A/00P0n<Q`203lc7@P0?c8O2015=28204Lb7@0304Dc7@14
=1d0@c@M0080@CDM00<0@3HM04Hf7`16=Ql01P16=Ql804Le7`<0C3PP0P1;=al304Xf7P<0B3HN0`19
=al204Xh8080C3LL00@0CCPM04hi7P1>>Ah0CSTN0`1?>Ql3050h80<0DCTQ0P1B>R801015=Ah0ASHO
04Hf7`16=Ql204Lg8080B3PQ2018=R007P1=>B00C3PO04`h801<=b80BcHS04/f9@1:=B@0BS@V04Ph
8@17=b00ACDN04@d7@13<a`0A3@M04De7P16=Ql0AC<M04Le7`19=b40BSPR04/i8`1:>280BCLQ04Pf
8019=al0BcLO04`h801==b00CcHP054f8@80DSHQ0P1D>R<0101E>b@0ES`U05Hl9@1G?BH205Pn9`0@
05Xl801K?B40G3hR05i0901O@BD0HD<W0694:01SABT0HdHT06958`1SAB<0I4<R06I38`1YABD0K4PX
06m8:@<0KTXX0P1_BbT3071<:P0306i@;01_DBd0L58^0080LE<_00L0L58^06mA;@1^D2`0JdlW06eA
:@1_Db/0LED]0080LUH^00<0LED]071D;01fEC801`1fEC80101bE300LE<_06mA;@1]Cb/206a>:P04
06e?:`1^D2`0KDl[06a>:P<0JddY00<0KDl[06mA;@1`DRh0201]Cb/206a@:`0306e?:`1_CR/0L4h[
0080LTh/00@0M4d/06U;:@1XBRP0IdTW0P1VB2H206Q::00306Y<:P1[CB/0K4/Z0080K4/Z00<0KD`[
06i=;01^CB`00P1_CRd00`1YBbL0JT`X06Y<:00306Y<:080JddY00P0J54X06U@:01YD2P0JdlX06]=
9`1]CBL0KT`W06e;9P<0JT`Z0P1YBbT306Q::00@06]?:P1VBRD0HTHQ06=78P1WBbH0JThY06Q<9`1V
BRD0LdLZ0717:@1^AbP0K4PX06Y9:01ZC2X0Jdh/06Y@;@80JddY0P1/CRX01`1]Cb/0KU0/06i@;01^
D2`0JDdX06Y>:@1/D2/00P1]DB`00`1/D2/0JThY06U=:00206U::`80J4TZ0`1WB2T0101VAbP0IDPX
06E8:01TAbL206=69P0506959@1QA2@0HD@T06M8:@1VAbP0101UARL00`1VAbP0IdPY06I9:@0706I9
:@0906E69`1UB2P0IDPX06=9:01QBBL0GDHT05U58P1G@b00E4<U0080ET<U00<0F4<V05U19@1J@2D0
0P1J?b@0801T@BD0H3hR05dk7`1L?B00GT4S05e2901I@240ESdN05i0901I?R40ES/N05Hm7`1I@R<0
F4<T05E28P1A?Qh0CCdS04hn901@?bD0DclV05@n9P1E?BD0Dc/S05<i8P1C?R40E3lP05Q18P1K@R<0
GdDT06A79@1UBB@0J4XV101ZC2X506]=:`0506i>:01`D2X0Le</07EE;01gF2`00P1gF2X01@1fEbP0
O5Ta07aI<@1lFC40NeP`0080NUL_0P1iERh01@1hERT0NELZ07UG:P1jF2/0O5X]0080OE/^00d0OU`_
07mI=01mFS@0O5Tc07YH<P1hF340MEP`07AH<01cEbl0LeH^075D;01_DRX0KE0X0080K4lW00@0KE0X
06iA:@1bDR/0LU8[101dE2d02P1cDb`0LU8[079C9`1dEBT0M5L[07EJ;@1cFbd0KeTZ06YE9P1XDb@2
06e?;@80K4h/0`1[CB/02@1ZC2X0JTd]06Y=;@1[CRh0K4l_06]>;P1XBb/0ITTY06E8:00306I:9B_o
oooo000Zooooo`P0Y7U600<0ZGi;0:QmBP2VNdP00P2TNDH00`2UNTL0YW]80:MlB@030:AiAP80YGY7
0`2VNdP80:EjA`P0YWa:0`2WOD/20:IlBP<0YG]90`2UNDP30:IjB@80Yg]:0P2UNd/0102UNdT0YWe9
0:ImB@2WOTP20:MnAP<0Yge;0P2XOT`30:UoC@80ZX1>00D0ZGm=0:QnC02XOT`0Z7i<0:MmB`020:Il
BPP0ZH1<00@0YWe70:QoB@2ZPD/0[8==0P2]Q4h02`2/Pdd0Zh9<0:N2B`2VPDX0YX5<0:F0C02TOTd0
Xge>0:9lC@2RO4l0XgU70080XWQ600<0XGM50:1fA02OMD<00P2NM4801P2MLd40W79009ab@02KLCl0
VW0n09U_?@80V6hl0P2CKCh0102BK3d0TF/l095[?02@JS/208mY>P0608iX>`2=IcX0S6Hi08]U>029
HcH0R68e0P27HC@01P25H3H0Q5le08=N=022GC<0PE`b07mJ<080OUT_0P1lFC4207]H<080NUL_0P1i
ERh00`1eDR`0MU<]07MD;P0207QE;`0307MD;P1eDR`0M54[00<0KU4Y0`1]D2P206a?9`80L50Y00<0
LE4Z079B:`1cDb`00P1dE2d0101eEBh0NUL]07]H;P1lFBl307iK<@80OEX`00H0OF0f081Q=@20HCD0
PF0c08=Q<`26HS8208MQ<080RFDe0P2:ISH308]W=`0308aX>02=IcP0SFLh00H0SFLh202<ISL208mY
>P@0SFLh0P2?JCX208]T>@0308]U>02<ISL0S6He00<0SFPd00L0SFPc08iR=@2=HSD0SV<f08eT=P2<
ISL0RfLg0080RFLg0P2;ICH408eW>080RfDf202?I3L808eW>0P0Sf@i202;IS8308]U=P80RV@e0`29
Hc@808QT=0@0QV4d0P25H3<308AO<P0708EP<`26HC@0Qf8e08MR=@26HC@0QF0c08AO<P0208MR=@03
08IQ=025H3<0Q5lb0080Peha00L0PUd`08EP<`24Gc80Q5lb08=N<@22GC00PE`_0080P5/^00<0PEla
081N<01nG2h00`1lFR`00`1mFbd0OU`^07UF;00307UF;00:07MD:P1eDRP0Le0V079?9@1cDbX0Le</
071C:`1_Db`0K58]06YB;P80J54_01P0JDl/06M=;01SBbT0GTLW05U49@1E@R@0E40U0550901=?280
C3`R04/k8P18>B80ACTS048g8`0o=b80?cLT03/f8P0j=B40>3<O03Lb7P0f<Ad0=c8N03Pc7`0i=202
03@/7`04038/800^:Ql0;2TP02TY8@80:2LR00T09RLQ02HX7@0U9a`09BHN02@U7`0S91l08R8P024Q
7`0Q8B400P0Q91d00`0P8a`07b8K01hQ6P0201dP6@0301`O600N8AX07R4J00H07R4J0P0M81T201hQ
6P0;01lR6`0P8a`08B@M024T7@0L7Q/06adJ01XL6@0I6aP061XG01TK600K7AX0100L7Q/201dO70<0
7R0M01P08bPQ028W800R9A`08bDJ02DW6P0Y:Q`0;R`M030^7`0`;Ah0;BXK02`Y6P0]:Q/0<BhO038_
800`;Ah0;R/L02DV7P0T9Ad08R<K020Q6@0Q8QX08b@L02DV7P0W:20202HX7@<09BLL0`0T9Q/5028S
7@<08B8L200P8a`801lP6P0N020R7@0Q8ah08b@N02DU7@0Y9Qd0:bLL02`X7@0_:Ad0<b8H03XX6P14
<B00DC/S05m69`1bES40QFPn09=dAP2BN4L0VGa409n0@02RPd00XhE709EiB@1aFSX0CSTT030X9P0]
:2D0=2l[03ll=`0n?CP0<S<]0P0Y;2D:02LX8P80:2TS0P0Y:R@302X[9@P0:R/S200Y:R80400]:2@0
;RTU02lZ900`;2<0<RhS03<_8`0d<B80=C8S03Tc9`0j<RD0>c<V03he9P11=BD0@cHU04Hg9017>2D2
04/h9`0704`i:01=>RT0Cc`[050m;01A?Rd0DSl^04lo:00304hn9`<0CCdV00@0C3`U04hn9`1>?RL0
CShW0P1=?BH304`l9@0804Tn;015>RP0@SLU04<h9P15>RP0AS/Y04<h9P0o=28304<f9@0[04@g9P16
>BP0B3/Z04/n;@1<?bh0E3lT05E09@1I@BD0GD@V0656:01UB2P0IdXZ06U;:@1_CbT0K4hX06U<:P1T
Bb`0GdX]05U8;P1FARd0Dd@]0596;01AABd0Cd<[04e1:`1;?R/0BSd/04Tl;018>b/0BSd/04Tl:`17
>RT0ASTX04Dh9`16>BP0AcXY04Pk:P17>B`0B3X]04Xm;@1;?Rd0C3l^04`o;00204/o:@0>0556<01C
B380Eddd05]A=P1ME3L0GE@e05aC=01KDS40F4`d05U==@1KCcD0GE8f05mD=P1OE3@205mE<P0H06]L
=@1]Fc<0Kede079O=@1gHSL0Nf@h07iV>020J3X0R6Xf08QZ>025JCT0PVLj07aS>P1fGSP0LE/f06iG
=@1eDbd0MeD_07QH<@1gFS80METa071G;P1]E2/0JU<Y0P1^D2`0<`1/D2/0JTd[06I<:`1SBR/0H4TZ
05e8:@1LAbX0F4L[05U5:P1IARP0FTDV05i79`1QBBL0ID/Z06I<:@1YB2L0KD`Y079A;P1cDbd0LU8[
079B:@1fEb/0NU/_07EH;P1gF2`0N5T]07YI;01mFbd0PEd]08AN;@26H2l0PF0[08ET;`2<JC<0TVdf
09M`=`2HL3D0Ufld09I/<02IKC00VVha09U_<`2HL3D0Ug0g09A_>02BKCH0Sf`f09A`=02FLSH0V7@h
09Yf>P0209]g>`0<09Yf>P2IMCT0Vg8j09]b>P2KLcP0Vg<f09Yb=02JLc80VG8a09Ub;`2ILC<0VW8d
0P2KLcD409ad=P0409ee=`2NMSP0X7Pj0:9j?0@0Y7`n00`0XGhj0:9o?@2ROcd0XWlo0:1l?P2NNSh0
W7Pn09Yf?02DMcl0TWDm08mb>P2<KcL408Y]=@0608a[=@2>KSD0T70g09=c>02EMCP0UWLg0P2EMSD0
202GM3@0Ug<e09Id=`2BLST0Sg0j08Y/>P26IcP0PVHg102:I3D03`28HS<0QV0a08AN;`23GBh0Oed_
07iL;`1lFRd0NEH/07MD;01eDR`0M50/07=?:`1/E300Je<_06YB;P0206Q@;00D06UA;@1[Dbl0K5@`
06UB:01ZDbT0K5D[06iG;@1`FBl0LU/a07AM<`1eGS@0MUlf07=L<`1`FBl0L5T]07=M;P1eGbh0M5h]
079L:P1_FC8206eG<00306YD;@1XDR/0IU0Y0080IDlX00<0IU0Y061>:P1PCRX00`1OCBT305i<:080
GTlX00<0Ge0Y061A:P1QDR/00P1RDb`0301SE2d0Ie@/06AA:@1OCBL0F4PT05=38@1?@1l0C3lM04/n
7P1=?B<0C3`R04/k8@80BSXP00<0Bc/Q04`l8P1<?2802`11>Qh01@12>al0A3dQ04Ho8`18@BD0BT<W
0080AChR0P16?b<01014?B40@S/O040i7@0n=a/203/i8P0303Xh8@0h=Ql0=cDN00<0=cDN00P0?3HP
03/e7`0h<ad0=38K03<c6`0`<QX0<C<K030d6`<0<C<N0P0`<Qd302la700402d^7P0/;Ad0;2dM02`]
7@80:b`L0P0Z:a/03P0b:B00<bXQ03@^8P0c<240<S4O02la700];aX0:blH02DY600T:1L08bLH028V
600Q91T07b8I0P0N8AX0100L7Q/06adJ01/M6P0K7AX201XL6@806A/H0P0J71/201TK6P8061XI0P0G
6AP201HH5`<05aTH0`0H6QT801TK60X05aTH0`0H6QT201TK6P806Q`K200I6aP801TK6Q005aTH600F
61L801LI60P05QPG200B61P301DG5P805QPG0`0G6AP801DF61805QPG0`0G6AP601PJ6@806A/J0`0J
71/201LI608061XI0P0I6aX201XL6`P06A/J0`0J71T301/M6P<071hK200M7a`801`N6`807AhH0P0N
7aT201lP6P80824K200R8A`802<S6`P08R8J200W8Q`0100Y9AT0:RHJ02XV6P0Z9QX202/W6`80;2PL
0`0b:1`3034W6`80<2HJ00P0=b/K03HZ6P0f:QX0=BTI03HZ6P0g:a/0>2`L03T]7@80>RdJ00<0>bhK
03`_700m<1d00P0n<Ah00`0o<Ql0?S4N03ha7P0603ha7PP0@c8P0P17<Qd00`15<ad0A3@M04<d7@02
044e7@03040f7@16=Ql0ASHO00H0ASHO2018=R0304`h8080BcLO0`1:=Qh404Tg7`<0B3HN00@0AcDM
04/g7P1;=ah0BcLN101<>1l204di80@0CCTQ101<>20304De7P80ASHO0`17=b0804Hd7P80B3LM00<0
B3HN04Le7`17=B400P16<b801016<b@0ASHO04De7P14=1d204<c700604De7P17=b00B3PQ04Dc7@16
=1h0B3HP0`19=b4204Pf800604Tg7`1;=al0C3PP04dg801?=R00DCHQ0P1B=R42058h8@0405<i8P1D
>R<0EC/T05Hl9@80EcdV00P0FcdQ05`n8P1M?b<0GT0T05m19@1P@RH0HD<W0694:080HdHT00H0HdDS
06E48`1WA2@0JTHV06a8:01_B2T206i::080Kd/Y0`1`C2X0101aCB/0KDl[06i@;01_DBd2071B;P07
06mA;@1^D2`0KDl[06e@:01^DBT0L5<[075D;004079E;@80MeHc0P1fEC801`1eE340M5<`07=B;`1c
DRl0Ke4]06i@;01]Cb/00`1/CRX02P1^D2`0Ke4]06e?:`1/CRX0JddY06Y<:01[CBT0K4hZ06i@;01_
DBd806e?:`80JThY00<0JddY06e<:@1^C2T00P1_BbT00`1aBRT0J4XX06M99`0206I89P0506M99`1X
BRP0J4XX06U;:@1ZC2X00P1[BRT206a;:P@0KD`[0P1WBBL0101XBRP0JD/Y06U;:@1ZC2X206]=:`06
06E=9`1WCBP0IddX06U=:01[CBT0KD`Y0P1^C2T0101ZC2X0JD/Y06U;:@1YBbT206Q::080IdTW00D0
JD`Z06I99`1SAR@0HTDS06E89P0206M::00906E89P1_B2T0K4PX06]79`1YARH0J4LV06M99`1WBRP0
J4/Y0080JddY0`1/CRX306e?:`0306Q;:@1YC2X0JTd[0080Jdh/00<0JTd[06U<:P1XBbT00P1XBBX2
06M8:@<0ITLX00<0IDHW06959@1RABD00P1RABD40654900306E69`1VAbP0IdPY0080J4TZ00<0IdPY
06I7:01UARL0201TAbL0<01UARL0I4LW06A79`1QAbH0GdLU05a58`1HA240ET8O050o8@1D@B<0ET<U
05U49`1K@bL0FT0U05Tn8`1H?B80HT0U05lm8P1J>al0FS`P05]08`1K@R@0Ed0Q05@m7P1L@BH0FChS
05Hl8@1E?B40ED0S05A18`1A?R00CC`N04`l8P1=?B<0CchT058n9@1C?BD0E3`T05<k8`1D>R<0DSdP
05<n7`1G@240Fd8S05m5901TAbD0Id/V06U;9`@0JD/Y00<0JT`Z06]=:`1/CR`00P1/CR`01@1_CbT0
L50Z079B:`1dE2/0MUL[0080MULY00<0MULX07]H<01jEbl00P1jEbl307UF;P0707QE;@1hEB/0NEH/
07UF;01jEbd0NeP^07aI;`0207eJ<00<07iH<`1lFC<0NePb07UG<@1gEc00M5L_07=G;`1bERh0M5L_
079E;@1`Db/0KU4Y0P1]D2P0101^DBT0Ke8Z06m?:01_CbP206i>9`0<06m?:01aDBX0LU8[07=C;01e
EB`0MUH]07II;`1eFRl0LUX^06iG:`1YE2L0Ie8U0`1/CR`206]=:`<0JT`Z00<0IdXZ06Q;:`1YC2`0
0`1YC2`206M::P<0IdXX:oooool002[ooooo202TNDH02@2YOT/0Yga90:EjA`2TNDH0XgQ50:AiAP2U
NTL0YW]80:9gA0030:=hA@80Y7U62P2UNTL80:IlBP80Yge;0`2VO4X30:EkB@H0YWY90P2WNdX20:Ek
B`040:IlBP2VODT0Ygi:0:MnB080Z7m7202XOT`20:^1C`050:Z0CP2YOdd0Yge;0:MmB`2VO4X00P2U
NdT80:QoB`080:MnB02XOdT0ZX5;0:b3C@2]Q4h0[8==0:^2C02ZPD/20:J1BP060:F0B`2TOd/0Y7i=
0:=mCP2RO4d0XWa?0P2RNDD00`2QN4@0X7M309mf@P0209ie@@0709ed@02MLd40W79009ab@02KLCl0
VW0n09U_?@0209Q^?080Tfdn00@0TV`m095[?02AJc`0T6Xk0P2?JCX208eW>P0408aV>@2;ICP0RV@g
08US=P80R68e0P24GcD01P23GS@0PUdc085L<P20Fc40OeX`07iI;`80OEXb00@0O5Ta07]H<01kF300
NUL_0P1iERh00`1eDR`0MU<]07MD;P0207QE;`0307MD;P1eDR`0M54[00<0KU4Y0`1]D2P206a?9`80
L50Y00@0LE4Z079B:`1bDR/0Le</0P1dE2d0101iER`0NUL]07]H;P1lFBl407eJ<00607mR>021HSH0
PF8f089Q=023HC<0QF4a0P26H2l308UU=@80RVHf0`2;IcL@08aV=`P0SfTj0P2;I3T00`2;ICP0S6Hg
08aV=@0308eX=00708eX<`2?HcH0SV<f08mT=`2>ICL0S6Hg08]W=`0208UW=`P0S6Hg0P2>HcH408mT
=`80T6Dh202=IcX808iU>@0408eW=P2<ISD0S6He08]U=080RV@c0P29Hc8308YT=@80RF<d0`28HS<8
08QT=0H0QV4d0P25H3<508IQ=080QF0c00D0Q5lb08IQ=026HC@0QV4d08EP<`0208AO<P80Peha0P24
Gc8208=N<@07089M<021G2l0PE`_085L;`21Gc40P5h`07iL;P0307aJ;00@07eK;@1nG2h0O5T_07aI
;`1kF2h0NUL]07QE:`1fDbT0M54W07=@9P1dEBT0M5@[075D:P1_Db/0K5<[06YB;080J58]01<0JDlZ
06M=:P1TC2P0H4TW05]79P1GA2@0ED8T05=2901>?B<0C3`R04/k8P19>R<0ACTS04<h9010>2<0?cLT
03/f8P0i=200>3<O00<0=S4M00P0=c8N03Pc7`0e;Qh0=BdP03<]7`0_:al0;B/O02TY7`80:2PP00T0
9bPP02LY700V:1/09RPM02DV7P0T9Al08b@O028S7P0R8R000P0R9Ah0100Q91d082<L01lR6`0N8AX2
01dP6@P07R4J00H06ahG01`O600M81T07R4J01lR6`0Q91d2028U7P0301dO700L7Q/06Q`I00806A/H
00<06Q`I01/M6P0L7Q/00P0K7AX201`N6`807AlL0P0N81d02P0T:B808BHO020S6P0P8QL08B<F02LX
6P0^;1d0<BlP034^7`0_;1d202`Y6P0<02dZ6`0_;1d0<BhO038_800Y:b009bTN02<U6P0P8QL07b4F
028T6@0V:1d0:B/P0P0V:1d302DW70<092HK0P0S91h4028S7@808B8L200P8a`801lP6P0P01lQ700P
8Qd08R<M02@T700X9A`0:RHK02/W700^:1`0;R4I03<U6P0k:a/0AC<M05<n8@1VCRX0Nf8j08Y_A02F
Nd@0UW`o09Qm>P2NPc`0ZHi90:B:C`28KD00J4hY03hb9P0h:b80=RdT03df;P0k>340<2lZ02TZ9@0X
:RL:02LX8P80:2TS0P0Y:R@302X[9@P0:R/S200Y:R8202`Y900402dZ8`0_;2<0<2hR038`8`80<c4R
00P0=RlU03La9@0i<BH0>S8U03dd9@10=2@0@SDT04<f9@80B3LU00H0BSTW04/j:01=?2X0Cch/050o
;@1A@2h804hn9`P0CCdV00P0B3d[04Dj:012=bD0@cPV04Dj:016>bT0@cPV040e8`80@SDT00@0@cHU
04@g9P15>2L0ASTX0P18>bX05P1A>b<0DS`T05Lo9@1K@BH0H4DX06E8:P1XBbd0JT//079@:`1`D2X0
KE4/06Y@;@1UCRh0Gd`/05]:;01HBBX0F4X_05I8;P1DAR`0DD8[04m0:`1=?R/204dm;@0304`o;01;
?R/0BC`Y0080AcXW00T0B3/X04Tl:@1:?BX0B3X]04Tl;01:?B`0C3l^04e0;@1>@R`00P1>@RX01P1H
BC80FT`b05i@=@1QDcP0HeDh06AG=`80I5Le00P0GE8f05iC=`1OE3H0HeHf06EH=P1WFCH0J5Xg06YJ
=P80MF8h01H0Mf8g07YS=`1nISP0PfPi08M[>`28K3`0Sg0j08i`?02=Kcd0R6`m085V>`1iH3P0LETc
06eE<@1gEBl0N5H`07MG<01dEbl0LED]06aC:P1YD2L0ITlU0P1[CbX0<`1XCRT0IT`Y06=;:@1PBBT0
G4LX05U69P1IARP0EdHX05Q59`1HABD0FTHU05i79@1QBBD0ID/X06M=:01^CBX0Le<]07QH<P1iFC80
N5P_07QI;@1kG2h0OUla07QK<@1iFRh0MeP/07QG:P1kFB/0P5`/08AN;@27HC00Pf8_08ET<@2;Ic<0
T6/f09E^=`2GKSH0UVhc09M]<`2JKC80Vfhc09U_=@2HKcL0UFhg091[=P2>JC@0RfLc09=_<`2DL3@0
Ug<g09Ue>@0309Yf>P0709Ue>@2HLCX0Ug0g09I_=P2EKSD0U6db09=/<@02099[<00309A^<02EKc40
UW0b00<0V78d01P0Ug4c09I`<P2HLS@0VW@f09eg>@2PNS`0XG/m0:1j?02ONC/0WGLi09ej>02MNSX0
WW/k09ei>`2LN3`0VWHl09Mb>`2EL3T0TW<m091a>`2=KSP0RV/e08QY<`27J38208QY<`0608]W<`2=
JS@0T6dg09Aa>@2FLcT0UgDh0P2GMCH0202GLcD0Ug<g09Eb>02AL3X0SFdj08QY>P24ICL0Of8f0P27
HSD03026HC@0QF0c08=N<@21G2l0OeX]07iI;01kG2d0NU/]07MH:P1eERX0M5@[07AD;@80M5@^00<0
KeLa06eE;`1/E2h00P1ZDR`00`1[Dbd0K5@^06eE;`0206]D:P0406eF;01_F2h0LEX`07=L<P80MEhd
00<0M5he07=M=01aG3400P1aG340101aG2l0L5/^06mJ;@1YEC0206MC;P0306EA;01RCRT0HDdX0080
H4`W00<0HDdX05e;9`1MBbL00P1MBbL405i<:080Ge0Y00<0H54Z065B:`1RDb`00P1SE2d02@1TEBh0
JUHa065?:@1FAR80DT8P05528@1@@b<0BSlO04Dj700204/m8P0304Xl8@19>b00BC/P00<0BC/P2011
>Qh203lh7007040i7@12>al0A3dQ04Ho8`18@BD0BD8V04Dn8P0204Ho8`0904Dn8P13?200@CXN03hg
6`0l=AT0?3XS03/i8P0i=b00=cDN0080=S@M0P0g=Ah0200k=Al0>S@N03Pc7@0e<a`0<c<K034c6`0`
<QX0;c<J0P0b=1l2034c7P<0<38M00@0;c4L02`]7@0/;Ad0;2dM0P0[;1`302X[6`0803@^8P0e;b<0
=34R03<a8P0`<B40;2lL02X]6P0X;AT202<W6006028V600Q91T082<J01lR6`0N8AX07R0K0`0K7AX2
01XL6@<06A/H0P0J71/201TK6P8061XI0P0G6AP201HH5`<05aTH0`0H6QT801TK60X05aTH0`0H6QT2
01TK6P806Q`K200I6aP801TK6Q005aTH:00F61L8018H60<05ALF0P0F61L301LI60P05AHH4P0F61L3
01LI60H061XI0`0I6aX201XL6`805aTH0P0H6QT201TK6P806Q`K200I6aX301XL6@<06adJ0`0L7Q/8
01dO70P071hK0P0M7QP201hO6@807b0J0P0P8A/8028Q71008R8J200W8Q`202TU6@<0:RHJ0`0[9a/6
034W6`80<2HJ00P0>2`L03L[6`0e:AT0<bLG03@X600f:QX0>BdM03/_7`80>B`K00@0>RdL03/^7@0l
;ah0?C0O0P0n<B0803ha7PP0@C0N0P17<Qd00`15<ad0A3@M04<d7@02044e7@03040f7@17=b00AcLP
00H0AcLP2019=b4304`h8080BcLO0`1:=Qh204Xh800404Tg7`18=Qh0B3HN04Le7@80AS@L1018=ad5
04Th7P80BcTS00<0BSPR04Tg8@18=R000P17=Al01016=1h0ACDN04De7P15=Ah304Hf7`80AcLP2015
<ad204De6`0304De7014=1d0A3<O0080@c8P00<0@c8R04<c7013<a`00P12<Q/01@13<a`0ACDN04Ph
8@19>B80AC<M0080AS@N00<0AcDO04Pf8018=R000P18=R001P19=al0BcLO04`h801==b00CcHP054f
8@80DSHQ0P1A=b00101B>240DcTR05@j8`1E>b@205Hl9@80G3hR00@0GClS05i0901O@BD0H48V0P1Q
@bL206=6900606A6901WARD0JDHV06]79`1/B2P0KTLX0`1_BbT3071<:P80LDd[00<0K4hZ06e?:`1^
D2`00P1`DRh0201^D2`0KDl[06a>:P1_CbP0L50Y075A:P1bDR/0Le</0`1dE2d04`1hEc@0MeHc07IE
<P1eE340Le8_075@;@1`Cb`0Kdh[06e?:`1/CRX0JddY06Y<:01[CBT0K4hZ06i@;01_DBd0KDl[06a>
:P1ZC2P00P1YBbL00`1[CBT0K4hZ06e?:`0806a>:P80J4`W00<0JD/W06]:9`1[BBH00P1/B2H0101^
AbH0ITPV06I89P1VB2H206M99`<0J4XX00<0JD/Y06]::@1[BRT01P1[BRT206E69`0406I7:01WB2T0
J4TZ06U::`80JT//00H0Hd/W06A:9`1UBbP0J4/Y06U;:@1/BbX206i;:`0406U;:@1XBRP0J4XX06Q:
:080IdTW0P1VB2H01@1XBb/0IDPX06=69P1RABD0HdHV00<0I4LW0`1XAbH01@1WARD0IDLU06E79@1V
B2H0IDPV00H0JddY0P1/CRX00`1UB2P0ITTY06Q;:`0206U<;00306Q;:`1VBBT0IDPX00<0ITLX0`1U
ARL206A59P0405m28P1P@b<0H4<S06138`<0HD@T00@0HTDU06A59P1VAbP0J4TZ0P1ZBb`00`1XBBX0
ITLX06A59P0806959@0P06A5:01RABL0HTDW05m49P1L@b@0FT<S05I28@1E@B00CSdO058o8@1E@R@0
F4<V05]39`1J@2D0F3dR05Ll8@1O?bH0G3`S05Pj801G?240FClT05U19@1F?R80D3/N05To9P1H?RD0
ECdS058m8P1A?B80CSdQ04`k7`1:>ah204`l8P0304hm8`1A?B@0DS`T0080E3`T00T0EC/T054l7`1B
?Ah0Ed0Q05]28`1OAB@0IDPV06M;9P1YBbL00P1YBbT206Q::00:06U;:@1ZC2X0K4h/06a>;01]Cbd0
L50Z075A:`1bDR/0Le<Z07AE:@80MEHX00<0MULX07UF;P1iERh01P1hEBd307UF;00307YG;@1kF2h0
NeP^0080O5T_00H0OELb07YG<@1jEc40N5H`07IF;`1cERh2075E;@0407AF<01bE2h0L58/06i@:P80
KDlY00@0KU0Z06mA:`1`D2T0KdlX0P1]CBH00`1^CRL0LE4Z07EE;P0307MG<00607II<@1dF300LEP_
06eF;01XDbP0IU4V0`1[CB/206Y<:P<0JD/Y00@0HTPW06=9:01TBRT0ID/Z1`1VC2/[ooooo`00:_oo
ool80:AiAP030:QmBP2WO4T0YGY70080XgQ500<0Y7U60:EjA`2VNdP00P2RMd@30:=hA@<0Y7U6202U
NTL;0:IlBP<0YG]90P2TNTP60:MkBP80YWY90P2VO4`0102VO4X0Ygi:0:MnBP2XOdT20:QoA`P0Z7i<
0P2[PDl01@2ZP4h0ZGm=0:MmB`2WOD/0YWa:0080YG]9202XOd/00`2XOdT0ZH1:0:^2C0030:b3C@80
ZX5;0P2VPDX01`2UP4/0Y7m;0:=mC02RO4d0XG]<0:5kCP2SNTH00P2RNDD00`2QN4@0X7M309mf@P02
09ie@@0609ec@@2LLT00W79009]a?`2JL3h0VFlm0P2HKS`209=]?P04099/?@2AJc`0TF/l091Z>`80
SfTj0P2=IcX0102<IST0RfDh08]U>02:I3L208US=P80Q5le0P23GS@01022GC<0PE`b081K<@20Fc42
07iK<`0407eJ<P1lFC40NeP`07YG;`80NEH^00<0MU<]07MD;P1hEBl00P1hEBl00`1fDbd0M54[07=@
:P0306iA:@<0KE0X0P1/CbL206m?:004071@:@1aDBX0LU8[07=C;080M5@]00T0N5D[07UF;01iER`0
NUL]07]H;P1lFBl0OEX`07iK<@1oHSP00P21HSH00`22HC@0Pf4c08EQ<@0208IP;`80R6@d0P29ICD2
08YV=P80RfLg402<ISL808mY>P80Rf@i00<0RfDh08aV=`2<ISD00`2=J3@01`2=J3<0TFDh091U>02?
I3L0SVDg08aV=`2;IcL00P29IcL808aV=`0308eR=@2>HcH0SV<f0080Sf@g0P2@ICP00`2AIST0SFHk
08eV>`0608eV>`P0S6Hi0P2=IcP00`2<ISL0RfDf08YT=@0208US=00408QR<`2:I3D0RV@e08YT=@80
RF<d0`28HS<808MS<`H0QV4d0P27HSD208QS=P0308MR=@26HC@0QF0c00<0QF0c00<0QV4d08EP<`25
H3<00P25H3<308AO<P<0Peha1022GC001021G2l0PEla081N<01nG2h307aJ;00807eK;@1nG2h0PEhd
081M<`1nFc40O5T_07YG;@1iER`207QE:`0607AE9`1dEBT0LE@X06mD:@1]E2/0Je@[0P1YDb`07P1Y
D2P0J4hY06E=:@1RC2L0GDTV05Y79P1GA2@0E4@S04hm8`1=?B<0C3`S04Tj8`16>R@0@cPT040h8`10
>2D0>cHR03Xe8@0h<al0=c8N03Ha7@0g<Qh0>3<O03Td800f;ad0=RlO03@^7P0`;Ah0;R`O02XZ7P80
:BTO00T0:2XO02PZ700W:A/09bTL02HX7@0U9Qh092DO02<T7P0S91l00P0S9Ql0100R9Ah08B@M020S
700O8Q/:01hQ6P0601/N5`0L7aP07B0I01hQ6P0O8Q/08B@M0P0R9Ah01P0O8Ah07AlL01/M6P0J71T0
6A/H01XL6@D06adJ0P0L7Q/301dO700H028W800P9Ah07b8I01lQ5P0P8QD09BHH02`Z6`0_;Ah0<BhO
030]7P0^:a`0;2TJ02/X6@0]:Q/0<BhO03@a8P0/;R40:B/N02@V6@0Q8aH0828E028T5`0V:1/0:2XM
0P0V:1d302DW70<092HK0P0T9Al202<T7P808R<M0P0Q8Q`8020S70P07b0J02007R0K01lQ700Q8Q`0
8b<K02LT6`0Y9AX0:RHK02dW6`0]91l0<BLN03L[7@0o<1d0BCPN05a89`1`FSD0OVLn09=h@`2FO4<0
UWhn09R1>`2OR4@0XXU909Mi@`26ISD0ED<_04Dd8P0g:QX0<bTM034Z8P0Y9R4092@R02HX9`X09bPR
0P0X:B<202TZ90<0:R/U200Z:b<802PY8@0>02TX8`0Z:B@0:b/S02`/8P0^;R80;c0R030a8@0a<R80
<blV03<_900f;bD0>C4V03/a9@0m=2D2040d9080ASLT00H0B3TV04Tj9`1;?2T0CCh[04ho;01?@2d4
04hn9`@0CclX201=?BH02@17?2X0A3TW044f9012=bD0AS/Y04Ll:P14>BL0@CHT048e900204<f9@03
04@g9P15>2L0ACPW0080ACPW01H0CcTR054k901F?RH0FT0W05m4:@1UAb/0J4X^06Y;;P1bD2/0Le4/
075C;@1`E2l0Je<]06IB;@1PDBX0GThZ05e><@1KBc40EdL]05A4:`1A@BX0D3l[0P1@?bd00`1>@R`0
CD4[04/o:@0204Tm9`0K04Xn:01;?bT0C40Z04Lj:P18>bX0BC`[04/n:`1>@R`0DDD]05=7;@1DB2h0
GTdc05m><P1RDCD0IUDg06QH=`1ZFSP0JUXf06]K=`1QF3L0HUTh06AJ=`1WFSL0K5`h071N>01cGcX0
M64i0080OVLk00h0OVHh085V=`24J3P0RV`j08i^>`2@L3d0TW4k095b?02@L3d0S6dn08AW>`1kGcL0
LUTa06eC;P80NELa00H0MeL`07AG;`1`E2`0Je8Y06Q?9P1VCbD206]A;00W06UA:`1WCb/0Hd`Z05m;
:P1KB2P0EdLV05I59`1GAbH0FDHV05U69@1KAb@0GdTT06=;9`1WCBP0J4lW07AD;P1iFC80Oelh081P
=`1oH3@0OUla081Q<P22Hc@0NE`b07YK;`1iFRh0NEP[07]I:`20G2`0QEl^08MQ<023HC40QF<c08UU
<`2=J3@0TFTe09=Z=02DJc<0UV/d0080Vfhe00`0VFhg09M^>02DK3P0SfXe08aW<`29IC<0TFda09=_
<`2ELCD0V7@h09Ue>@2JMSX209Ue>@0;09A_>02CKSL0TVdf091[=02?JSD0SVTd08aW<P2<Ic<0SVX`
091/<P2BKS@00P2DL3H0602CKcD0TVhd091/<P2BKS@0U70f09Mc>@2IMC/0VWHl09Ue>`2GLcT0UW8h
09Qe=@2HM3H0VGDg09Ue>@2GLcT0UG0i099]>02AK3L0Sfhk08e/>@2;JSL0R6Ld08IU<P80QF@a00L0
QVDb08UU<`2;Ic<0SV/e095^>02DLCT0UG8h0080UG<f00h0U70d09A`=P2BKcL0SVdh08YZ>@25ISP0
PF8f07aO=@22HC@0PF0c081O<P1nGC00O5/^07YI;080NEP[00/0NV0_07QM;P1fFb`0M5T/07=H;@1d
F300METb07IJ<`1aFS40L5T`06iG;P0306aE;00;06eF;@1^Ebh0K5D[06eF;01^Ebd0KeP^075J<01b
Fc40Le`b07AM<`1_G3400P1`GC801P1_G380KEX`06]H;P1ZEbd0JUL_06EC;@80He4[00@0HDlY05m=
9`1MBbD0GD/U0P1NC2H205]99@0405a:9P1MBbL0GD/W05i<:080GddY0P1OD2T00`1PDBX0HE8[069C
;00206=D;@0906AE;P1WEC40G4`X0592801>?ah0D4<S04i39@18?b00@STL00@0B3dQ0P17?2000`16
>al0ACXN044j7P07044j7P0503hg6`0o>1`0@CXN04<l8014?B400P16?b<03@17@2@0A3dQ04Dn8P15
?R80A3dQ048k7`10>Ad0?CHJ03/d600l>R<0>SPQ03Pf7`0f=1d00P0e<a`02P0f=1d0=cDN03Xd7P0j
=1h0>C@N03Hd7@0d=1`0<C<K030b6P0^<QT3034c7P80<38M0`0_<A`202`]7@80:b`L0P0Z:a/202TZ
6P80<c0O00/0<S4O030a8@0]<1l0:bhM02L[700S:QX08RHH024U5`0Q91T082<J01lR6`0201hP6`03
01dO700K7AX06adJ00806Q`I0P0I6aP201PJ5`806Q`K0P0I6aX201PJ6@805aTH0P0F61L301LI60<0
61XI200I6aP:01LI60<061XI0P0I6aX201XL6`P06A/H200I6aX@01LI62P05QPG200B61P301DG5P80
5QPG0`0G6AP801DF61805QPG0`0G6AP301PJ6@805aTH0`0H6QT301TK6P805aTH0P0H6QT201TK6P80
6Q`K200I6aX301XL6@<06adJ4`0L7Q/201dN60807QlI0P0O81X2020Q6`P08R4L400R8QX802HQ6`<0
:BDI0`0Z9QX202/W6`H0<2HJ0P0a9a/00`0h;1`0=RXJ03@X600203<W5`0303DY6@0h;1`0>RhN0080
>2/J00@0>B`K03X]700k;Qd0?2lN0P0m<1l803d`7@P0@C0N0P17<Qd00`15<ad0A3@M04<d7@02044e
7@03040f7@16=Ql0ASHO00H0ASHO2018=R0304`h8080BcLO0`1:=Qh01@1:>200BCLO04Tg7`18=Qh0
AcDM0080AS@L00<0AC<K04Le7@17=Ad01`17=Ad204Lh8`0404Hg8P15=R40A3DP04@e8080@c@O0P14
=1d304De7P<0ASHO2014<Q`204<e6P0704<e6`12<a`0@S<N048c8011<Ql0@C4Q048b6`03044a6P04
04<c7015=Ah0B3PQ04Xj8`@0AC<M00X0AS@N04Le7`17=Al0B3HP04Tg7`1;=al0C3PP04dg801?=R00
DCHQ0P1B=R42054g8004058h8@1C>B80E3XS05Dk9080ES`U00D0G3hR05do8`1M?b<0GT0T05m19@02
06129P0606539`1RAB<0HdHT06E79@1XAbH0JTLW0P1/B2P00`1^AbP0Kd/Y06m;:@03071<:P<0LDd[
00<0K4hZ06e?:`1_DBd00P1`DRh00`1_DBd0KDl[06a>:P03075?:@03079@:P1cDB/0M58/0080ME<]
0P1gES<0201eE340Le8_075@;@1_CR/0KTdZ06e<:@1/CRX0JddY0`1ZC2P02P1[CBT0KDl[06i@;01/
CRX0JddY06Y<:01YBbL0J4XV06U;9`1[CBT906a>:P0506Q<9`1WBbH0J4XV06U89@1ZB2D00P1ZAR@0
101[A2<0IDLU06I89P1VB2H206M99`@0J4XX101ZBBP406U89`0406A5:01UART0IDHY06I7:P80IdP[
0P1XBB`0201QBBD0HdTV06=99P1VBBL0J4XX06]::@1/BBT0KDXZ0P1XBRP206M99`<0ITPV00D0IDLU
06E8:P1UB2X0I4LY06959`0206139@0406959`1TAbT0HDLT06=69080I4LU101UAbD306]=:@D0JT`X
00<0HdHX06A7:@1VBB/00P1WBR`00`1VBB/0I4LY06=6:00206E69`<0I4DV0`1SA2D0101O@R80H4<S
06138`1P@b<30654900406959@1SA2D0IDHW06M8:@80JDX[00<0IdPY06E69`1SA2D0201QA2@0601S
A2P0HD<W05m19@1L@B@0FD0R05M08@1E@240E3lP04dl7P1A?R00Dd0R05I1901I@BD0FClT05Tn8`1G
?240GClW05Tk8`1D>200E3XQ05Hn901E@2D0DSdR04hj7`80ECdU00H0DcdU050l8`1<>b40BSTO04Ti
7`18>Ql204`l8P0D04dl8P1?>b80DC/S05<k8`1D?2@0ES`U058m801C?Ql0Ed0Q05]28`1OAB@0I4LU
06I:9@1YBbL0JD/Y06Q::01WBBL0ITPV06Q::01ZC2X206e?;@0906i@;P1aDB/0LE4[075A:P1bDRT0
Le@X07AE9`1eERP0MEHW0080MU<[1P1gE2`307UF;P@0NUL_00d0NeP`07]E<01iES00N5D_07ID;P1d
E2d0LE@/071D;01_Db/0LeDa075C;`1_DBd0KDl[0080K4hZ00X0KDl[06i@;01cDb`0LE4Z071@:@1_
CbP0LE4Z07AD;@1gEc00NETb0P1fES001P1dES00LUH_06iE;@1[E2/0Ie4X06I@9`<0JT`Z0P1YBbT3
06Q::080H4PV0P1QBBL0101RBRP0I4`Z06E=:`1UCB/306E<;B_ooooo000Zooooo`P0Y7U600<0Z7e:
0:IkB02UNTL00`2SN4D00`2TNDH0YGY70:=hA@020:=hA@80Y7U62`2UNTL;0:IlBP80YG]90`2TNTP3
0:QlB`<0Yg]:0P2VNTT20:IlC0060:MmB`2WOTX0Z7m;0:QoB@2XOdL0ZH180`2YOdd20:QnC0<0Yge;
0P2ZP4h01@2YOdd0Z7i<0:QnC02XOT`0Yge;0080YWa:202WOTX00`2YP4X0ZX5;0:^2C0020:b3C@03
0:^2C02ZPD/0ZH1:0080YH1900H0Y7m:0:AoB`2SOD`0XWa=0:5kC02QNdh20:AkA@030:=jA02RND<0
XGQ20080X7M100L0WgI009ec@@2LLT00W79009]a?`2JL3h0VFlm0080V6hl0P2CKCh0102BK3d0TF/l
095[?02@JS/208mY>P80SFLj0P2<IST208]U>080RV@g0`25H3H208AO=@<0Pehd0P1oG3@01P1nFc<0
OEXb07]H<01jEbl0NEH^07QE;@80Me@^00H0N5D_07UF<01hEBl0MU<]07AA:`1bCbT306iA:@<0KE0X
0P1/CbL206m?:004071@:@1aDBX0LU8[079B:`80Le</00T0N5D[07MD:P1gE2X0N5D[07UF;01kF2h0
OEX`07mL<P1mH3H00P20HCD00`21H3<0Pf4c08IR<P0208MQ<0<0R6@d0P29ICD308YV=PP0RfDf202<
ISL208eW>0@0SfTj0P2=IcP208]T>@0308]U>02<ISL0S6He00<0SFPd00L0SFPc099V>@2AIST0T6Dh
08mV>02<ISL0RfLg0080RFLg0P2=IcP408]U=P80SFLh0P2=HSD0102>HcH0Sf@g08mT=`2@ICP2095V
>@P0SFHm202;IST0102=IcX0S6Hi08aV>@2;ICP208YT=`80RF<f0`2;ICH208YT=@<0RF<d2027Hc<4
08IQ=080Qf8e0P28HcH0102:ICP0RF@g08MR=@26HC@308EP<`0308IQ=025H3<0QF0c00H0QF0c2022
GC000`21Gc40P5h`07iL;P0307aJ;00607eK;@1nG2h0PUle085N=01oG380OEX`101kF2h01P1eERL0
M5DW079F9`1`EBP0KEDY06]D:P80JE<Z0P1XCbL04@1WCbT0I4hY061<9`1LBRH0FDHU05E58`1??R@0
CCdS04`l8`1:>b@0ASXT04@i9@11>B@0@3PU03dh900k=R80>SDQ00<0>3<O00P0>C@P03Xe8@0g<1d0
=RlM03@_700a;Qd0;bdN02//7P80:RXN00L0:B/N02T/6`0X:aX0:2XL02LY700V:1d09BHN008092DO
00H092LP02<V7`0S9Ql08RDN024T7@0P8a`201lR6`P07R4J0P0M81T201hQ6P0901lR6`0P8a`08B@M
024T7@0P8Ql07R0M01`N6`0J71T06A/H00806Q`I00<06adJ01XL6@0K7AX00P0K7AX201`N6`807AlL
01P07b@M01hS700N8AP07b4F020R5@0T9AL0:RPI02`Z6`0^:a`0;b`M030]7P0^:a`0:bPI02`Y6P0a
;Ql0=C8S02d_8@0Z;1h09bTK02@V600R91H08bDG02DW6@0V:1X202HX7@<09BLL0`0T9Q/202DV8004
02@U7`0S91h08R<M028S7@808B8L200P8a`801lP6P0P01dO6P0N81/0824K028R6P0V8aX0:2@I02TU
6P0/9QX0;2LS030Y8`0d;240>BdM048c701@?b40HU0/06iJ=@26JS/0SgE409=nA@2@OT00TWho09b2
A@2PP4L0WgM307=K?`1JABX0@2hH03<V5P0/8aX09B0L02<Q8P0U9RX:02LX8P80:2TS0P0Y:R@302X[
9@P0:BXR200X:B4202PY8`0402TZ8P0[;B80;2hQ02h`8P80;c8Q00T0<RlX038_9P0d<2L0=c0V03Xb
9`0l<RH0?C@U040d9P14=b@00P15>2D01@17>RL0B3/X04Tl:@1:?BX0Bch[00<0CShW0P1??bP30510
:@<0C3`U0P1=?BH304hn9`0;04Ll:P13>2H0@CHT048g9@16>bT0Ac`Z04Dj:011=R@0@cHU04@g9P15
>2L00P16>BP204Dh9`0L04@g9P1?>B@0D3XU05Dl9P1J@2T0GT8Z06A6;01VB2`0JDX^07=@:P1dDB/0
MED^07AH<01bFC00KUT^06QG:`1VEBT0HU4c05m><P1JBBd0ETD[05=1:@1B@2X0Dd4]05A2;P1@A2`0
Cd<[04e1:@<0BclW02X0C40X04e1:@18>bX0B3/X04Xm:P1<@2X0Cd<[0596;01FBbl0F4da069?<@1S
D300IU<c06UF=@1/FSH0KU`f06mM=@1`GSH0I5li06IN>@1XGcP0K5hg079P>P1hHS/0Nf@k07iU?@26
Jc`0QFXk08EY>@27JCL0RVXg08i]>02BLC`0Ug@n09Eb>P2DLcd0U7<n095a@02:Jcd0P6<i07QL=01c
Ec0207YH<P0607QH<@1eF300LUH^06iE;01]E2/0Je@Z0P1aFC<0601^F340K5Ha06IB;`1QCRd0G4`[
05Q9:01FAbP0F4PV05Y79P1JB2@0G4PS065;9P1UCBL0JE0X06]B:P1eEBh0Ne/d085Q>023I3P0PF8d
07mP<@20HS00PV@b07YM<`80O5da00d0OE`_07mM;`23Gbl0QEl^08IP;`23HC<0Pf4a08IR<P28HS40
S6@a091W<`2BJC<0U6Td0080W6lh00X0VVlj09Q_>`2EKCT0T6/g08eW=P2:IS@0Sf/_095]<@2DL3@0
Ug<g102IMCT2095^=P04091]=`2?JcL0SFTg08aX>080RfHi00<0RfPb08eZ=02?K3H00P2BKcT00`2A
KSP0Sf`f08eZ=00208i[=@03091]=`2AKSP0TVli0080TFhh00h0T6dg09=_<@2DL3@0U70d09A`=P2C
KSL0T6/f08iY=@2<Ic<0SVXj08aX>029ICD0Qf<c08EQ<@<0Q60`00H0R68a08YT<`2<Ic<0SfXe095/
=`2BKCH2095]<`0=08m[<@2?JS<0SV/e08YY=P26ISL0PV<g07iN=@1jGCD0OF0d07aO<`1jGC40N5/_
07MJ;P0207II;@0?07MJ;P1iHc40Mf4`07AN;@1bG2d0LEX^079K<@1dGC@0MUlf07AM<`1bFc40L5T_
06iG;@1]ER`0KUL]0080KeP^0`1^Ebd206mH;P<0L5T_00T0JeX/06eL;P1_GS80KE`a06UG;`1UDbd0
IE<_06ID<01QDBd00P1OCb/03P1MCBT0Fd/W05Y:9P1JBRH0Fd/W05a<:01JB2@0FdTU05a:9P1MBbL0
GT`X05m=:@1PCRX0HDl[0P1NCbP00`1OD2T0H54Z065B:`02069C;00906=D;@1NCR`0ETPU0511801=
@200CD8T04a39P16?b80@CXN0080AchQ0P18?b801017?R40AC`O04<j7@12>A`8040i7@0403lh7010
>Ad0@S/O04<l80@0A3dQ00/0@S/O04<l8013?200@c`P048k7`0o>1`0?CHJ03/d600m>b@0>SPQ03Le
7P0303@b6`0:03Hd7@0h=Ql0>C<M03Xd7P0i=1h0=cDN03De7@0a<a/0<38J02hb6@80<38M0P0_<A`3
02h`6`0402d_6P0[;1`0:b`L02//7080:R/K0`0Y:QX0200`;aX0<2lK02la700]<1d0:bhM02P/7@0S
:A/08BLI0P0P8aP01P0O8QT07b8K01hP6`0N81d07AlL01dO7P<06Q`I0P0I6aP301PJ5`806Q`K0P0I
6aX201PJ6@805aTH0P0F61L301LI60<061XI200I6aP:01LI60<061XI0P0I6aX201XL6`P06A/H200I
6aX@01LI61P05QPG200E5aH801HH5`P04QPH0`0E5aH201HH5`<05aTH200E5QPB01HH5`<05aTH0`0H
6QT301LI608061XI0`0I6aX201LI608061XI0P0I6aX201XL6`P06A/J0`0J71T301/M6Q<071hK0P0M
7QP201hO6@807b0J0P0P8A/8028Q70P08B4I200R8QX802HQ6`80:2@H0P0Y9AT302XV6P0402/W6`0_
9AT0;bDI02lU6@<0<2HJ0P0a9a/02@0f:QX0=BTI03@X600d:1P0=BTI03HZ6P0g:a/0>2`L03LZ6P02
03P[6`0303T/700j;Ad0>bhN0080?2lO200m<1d8048a7`80Ac8M00<0AC<M04@d7@13=1d00P11=Ad0
0`10=Qd0A3@M04@d7@0604@d7@P0AcDO0`1<>20204/g7`<0BSHN0`18=Qh304Le7@80AS@L0P16=Ql2
04De7PD0A3@M0`11=R82040e8@<0?c@P0`14=1d204De7P<0ASHO2015<ad02012=a/0@CHJ044e6`11
=Ad0@3@N040c800o<Ql0?c8Q0P12<Q/2044a6P04048b6`15=Ah0AcLP04Ti8P80AC<M0`14<Q`02@15
<ad0AcDO04Pf8019=al0BcLO04`h801==b00CcHP054f8@02058f8@80DSPQ00@0DcTR05@j8`1E>b@0
ES`U0P1G?BH205do8`80GT0T0P1O@BD206129P0506958`1SAR@0ITPV06U89`1[B2P00P1/B2P00`1^
AbP0Kd/Y071<:P02071<:P80LDd[0P1bCR`00`1^D2`0Ke4]071B;P02075C;`03071B;P1_DBd0KU0/
0080LTlY0P1aCRP0101bCbT0M54[07IC;@1gE2h207ED<@0907=B;`1bDBh0L4l/06i=:P1]C2T0K4/X
06e?:`1/CRX0JT`X0080JD/W00/0JT`X06]=:@1/CRX0K4hZ06]=:@1YBbL0J4XV06M99@1XBRH0JD/W
06Y<:00806]=:@80J4`W00<0J4XV06U89@1YAb@00P1YAB<01@1Z@b80I4HT06E79@1VB2H0IdTW00<0
J4XX00<0IdTW06I89P1YB2L00P1YB2L306Q79P80IdHU201UARX01P1QBBL0HTPW06=9:01UB2P0ITLX
06U8:@80JTLY0P1WBBL206I89P<0IDLU0140I4HT06A6:P1UAb/0I4HZ06539`1N@2@0GClS06129P1S
ABT0G4HQ05e78P1PB2@0HdTV06I99`1WBBL0JDPW06Q79P0406Y<:080JD/W0P1XBRH00`1Q@bL0HT@X
06=5:@0206A6:P0406=5:@1RA2P0HD<W06A59P<0Hd@U0P1R@b@206528`@0HTDU101QA2@206=49@04
06A59P1UARL0IDHW06A59P80Hd@U201QA2@01P1R@RT0Gd4W05do9@1I?R<0EcdR05Dm8@80DchQ01P0
CSdO050m7`1A?R00DchQ05Hn8P1H?R<0FChS05Xo901I?BL0ESXT058h8@1B>R80DcdU05<o9P1@?2<0
BcXP04hh8@1A>b@0DCdU04dk8`1:>200AcLN04Li7`19>b4204/k8@0D04/j801>>R40D3XR05<k8`1E
?BD0EcdV05@o8P1E@240F44R05a3901OAB@0HdHT06E9901WBBD0J4XX06M99`1VB2H0IDLU06I89P1Z
C2X206e?;@0:06mA;`1bDR`0LU8/075A:P1aDBP0LE8V07=D9P1dEBL0MEHW07AA:@<0ME8Z0`1fDb/0
0`1gE2`0NEH`07UF<00607UF<00607YD;`1gE2h0Me@^07EC;@1cDb`0L5<[0P1^DRX01@1aDc40Ke4_
06e?;@1[CB/0JT`Z0080Jdd[00<0K4h/07=C;01bDR/00P1bDR/0101cDb`0M5@]07IF;`1gEc0207=B
;`04075C;`1_Dbh0Je4/06UA:`80IU0Y0`1YBbT206Q::0<0IdTW0P1OB2H205i79@0405m89P1QBRP0
HT/Y06=<:P<0HT//:oooool002[ooooo202TNDH0202WO4T0YW]80:AiAP2SN4D0XWM40:=hA@2TNDH0
YGY70`2TNDH20:EjA`<0YW]8202UNTL90:IlBP<0YG]90P2TNTP20:=iA`80ZGe<0P2XO4/20:MkBP80
YWY90P2WODd0102WOD/0Z7m;0:QoB`2XOdT20:V0B0030:Z0CP2YOdd0ZGm=0080Z7i<0P2WOD/00`2V
O4X0Z7i<0:QnC0070:QnC0P0Ygi:00<0ZH1:0:Z1B`2[PT`00P2/Pdd00`2[PT`0ZH1:0:QoB@020:F0
B@030:AoBP2SOTX0XWa;0080XG]<00L0X7Y=0:ImA@2VODD0YGa40:Ak@`2SNT80XWU10080XGQ000H0
WG=109ab@02LLT00Vg4o09Y`?P2IKcd209Q^?080Tfdn00@0TV`m095[?02AJc`0T6Xk0P2?JCX00`2=
IcX0S6Hi08aV>@0208aV>@<0RfDh0`27HSP508IQ=`80P5de00P0Oe`d07eJ<P1kF300NUL_07UF;P1h
EBd0Me@^07QE;`80NEH`00@0Me@^07EB;01cD2X0LTlY0`1^DBT306e@:080K4lW00H0KThW06m?:01_
CbP0L50Y075A:P1bDR/207=C;080Me@Z0P1fDbT02P1hEB/0NeP^07eJ<01oG380Nehd07iO<`1oH3@0
PF0c08=Q<`27Hc<208US<P@0R6@d0P29ICD208YV=PP0RfDf202<ISL00`2;ICH0S6Hg08eW>00208iX
>@0308eW>02<ISL0RfDf0080Rf@i00<0RfDh08aV=`2<ISD00`2=J3@0302=J3<0TfLj095V>@2AIST0
SfHh08eW>02;IcL0RFLg08QV=P2>J3T0SFLh08]U=P80RV@e00@0RfDf08eW>02>J3T0S64d0P2=HSD0
1@2>HcH0T6Dh095V>@2AIST0TVLj00P0SFHm2029IcT508]T>@<0RV<h0P2=IcP208aV=`80RfDf0P2:
I3D808IR<P0308EP<`26HC@0QV4d0080Qf8e0P28HcH01@29I3L0S6Lj08YU>028HcH0QV4d00<0QF0c
00<0QV4d08AO<P24Gc801P25H3<6089M<080Peha00<0PEla081N<01nG2h00`1lFR`02P1mFbd0OU`^
07iK<@1mFS00NeP^07UF;01hEB/0NEH/07YG;@1kF2h207EF9`0T079F9`1`EBP0KEDY06]D:P1ZEBX0
JE<Z06Q?9P1YD2L0J54X06I@:@1QCBP0GD/W05Y8901FAR@0CchT04dm8`1<?2<0BS/T04Lk9@14>BD0
@CTT044i9P0o>RH0?CPT03/f8P0j=B40>C@P03Xe8@0k=R80?3LS03Pa7P0g<1d0=C0M038_7P0_;Ah0
;2dM0P0[;1h02@0Y:ad0:B`I02T/6`0X:aX09bTK02HX6`0U9a`09BHN02@U7@0202@W80808bHO00@0
8RDN024T7@0P8a`082<L2@0N8AX701lR6`04024S800O8Ah07AlL01/M6P<06Q`I00<06adJ01XL6@0J
71T00`0K7AX301`N6`80724J01@07R4H020R5`0R91L092DG02PV5`0Y9aP0;2TJ02l/7@0a;Ql0<2dN
02dZ6`0/:AX0<2dN03@a8P0/;ah0:bhM02T/6`0W:QT09BPG02@W5P808bHE0P0V:1d302DW70<092HK
0P0V9b401P0U9R0092DO02<T7P0R8ad08B8L020Q6`P082<L200O81X201dO6P0N01lP6P0R8QX09B8I
02PT6@0Y9AX0:bDI02XV9@0]:2@0<BXR03@[700j;QP0ACHI05928@1MBbL0M5<`08=W@02<MdX0S7a9
091lA`2KP4T0YX5<0:UnB@2@Le40LePj05<n8`12<Al0=bXQ02XU8P0U8bH09RD[2P0W:28202PY8`80
:BXT0`0Z:bD802TZ8PP09bPP0P0W:R<03P0X:b80:B`Q02/_8@0/<240;C4P02hb8@0`<2P0<C4Y03@a
:00f<RL0>C<W03`d9`0m=BP0?SDV0P15>2D204Hi9P0404Lj9`18>bP0B3/X04Pk:0<0CShW00<0CclX
0510:@1@@2T00P1A@BX00`1;>b@0C3`U04`l9@0204dm9P80CShW00`0CclX04Hk:@13>2H0@CHT048g
9@16>bT0Ac`Z04Dj:012=bD0ACPW04Hi:017>RT204Pk:P0S04Hi:014=bH0@cHU050i9`1A>bH0EC`X
05Tn:@1M@B/0HT@/06A6;01WAbh0LddX07AA:`1gEBl0MeX`07IN<P1cGRl0Ked]06aL:@1WE3H0He0b
05i:;`1IAB`0ET8Z05E0:`1F@B`0Ed8_0555;@1@A2`0CT8Z04e1:@1<@2P0CD4Y04i2:P1?@b/00P1=
@2d09P1=@B/0CD4Y04i2:01AARX0E4T]05I;;@1VCbl0Ie0`06UB<01/ES40KeTd079L=@1dGSD0MElf
06MT>`1XHc/0Jf8i06mR>01fHcT0O6Dk08=W?`26JCl0RVhn08]]>`29JcT0RFTf08a[=P2BKcT0Ug8k
09Ye?P2HMCd0VGHn09Uh@`2GMd@0TG9308Y[?`20Hc/0O5lg0P1jF3801P1iFC80MUTa07EI<@1cFS40
LUT`075J<080N68k00P0MV0i071L=`1[FCD0I5@b05i?;P1KC2/0F4/[05Y::080G4XV01<0GTXU06==
9P1XDBP0K5<Z06iE;01aDBP0MeL^07iO<`20HC<0OUl`07]M:`1lGR`0OEl[07]N=01nGc<0Of0d089Q
=023HC<0QF4a0080QV0_01D0PV0b085O<@23Gbl0Q5h_08QP;`2<HS00SfHb099W=02LKcP0WFlk09]`
>`2IL3`0UVhk095[>P2>J3T0S6Ph08iZ;P2@K300Tflc09Ib=P2HM3P00`2IMCT208m_=P0908i]>02=
K3T0SF/m08aZ?@2;J3h0RfQ008MV<@2:JC@0SF`g0080T6lj00D0Sfhi08a[=P2:JC@0RVTd08UX<`03
08QW<P0?08UX<`2:JC@0RfXe091/<02AKC40TFdc095/=@2?JSD0SFPd08YU<@29Hc80SFLh08]U=P28
HS<0QEl`00@0Ped^00D0RF0b08YQ<`2<I3<0SVHc08mW<`0208mX<@0<08iW;P2:IBh0RVD^08UU<@26
IC80Pf<d07mP=01lG3D0N5/c07YO<P1iGS40Me`_0`1eFRd03P1gG2l0N5d`07QT<@1eHBl0LEd[06iI
:P1]F2/0KeX_075K<P1cGC@0MUle07AM<`1bFc40L5T_0`1_F2h01P1`FBl0KeP^06mH;P1_F2h0KUL]
06eF;0<0K5D[00T0IeLV06]J;01^GC40K5Xb06EC;@1QCb/0H4d]069?;`1ODBh00P1ND2d0301LCR/0
FT`Y05U;:01IBbP0FT`Y05]=:P1JB2@0FdTU05a:9P1NC2P0H4hZ065?:`80He4]00H0G4dV05e>9`1M
CRL0GTlX05m@:@1PDBX2065B:`0:05=58P1B@b80D4<Q04e28P1<@b@0BD8U04Dn8P11?1l0A3dP04Dn
8@80ASlR00@0AChQ04<l7`10>A`0?cPK2@10>Ad01P12>al0@c`P04@m8@14?B40@c`P044j7P<0@3TM
0P12>al01`11>Qh0@3TM03hg6`0m=QX0?C/T03Xh8@0g=Ah00P0c<AX02`0d<Q/0=S@M03Pf7`0i<ad0
>S@N03Td7P0h=Ql0=SHN038d700_<AT0;C4H0080;S0K0P0];aX402`^6@80:b`L0P0Z:a/402TZ6P08
02d]5@0[;AD0;2hI02/^6`0X;1d092XL020X6`0O9a`201lR6@807R4J00@07R0K01dO700M7ah07AlN
0P0J71T201TK60@061XG0P0J71/201TK6P8061XI0P0G6AP201HH5`<05aTH0`0H6QT801TK60X05aTH
0`0H6QT201TK6P806Q`K200I6aP801TK6Q005aTH600F61L801DG5PP05QPG200B61P301DG5P805QPG
0`0G6AP801DF61805QPG0`0G6AP301PJ6@805QPG0P0G6AP301PJ6@0301TK6P0G6AP05aTH008061XI
0P0I6aX201XL6`P06A/J0`0J71T301/M6P<071hK200K7AX801`N6`807AhH0P0N7aT201lP6P80824K
200R8A`8024Q6@P08R8J200U81X302PT6080:BDI0`0Z9QX202hT6080;bDI0P0`9QX2034W6`0503<W
5`0d:1P0=BTI03HZ6P0g:a/00P0f:QX00`0e:AT0=bTL03LY700203PZ7@0403T[7P0j;1l0>bdP03/]
80P0?2lL2013<R0204Lb7@0304Dc7@14=1d0@c@M0080@CDM00<0@3HM044a6P11<AX01P11<AX804Dc
7@<0C3PP0P1;=al304Xf7P<0AS@L0`17=Ad204Pf7P<0A3DP00@0@c@O048c7P12<ah0@S<N0P11<Qd4
03`d7`<0?CDP00<0?SHQ04<c7013<a`00P14=1d304De7P0304Hf7`16=1h0AS@N00H0AS@N0P12=a/0
0`12=Q`0@CDM044e7`02040c8003040c8P13<a`0@S8K0080@C4J0180@S8K04@d7@16=Ql0AcLP04Dc
7@14<Q`0@c4K048`6P13<A/0A38L04Hd7P18=R00BCLO04/g7`1<>200CCLP04lf801A=R42058f8@80
E3XS00@0EC/T05Hl9@1F?2D0EcdV0P1H?RL405i090@0Gd4U00P0HD@R06=6901VB2H0JTTX06a9:@1]
BBT0K4PX06e69`<0L4`Z0P1aCB/3079>;003071B;P1aDbl0LU@`0080LeDa00@0LU@`075C;`1`DRh0
LTlY0P1aCRP01@1`CBL0LDhX07=@:P1fDbd0Me@^0080Le8_00@0LU4^075@;@1_CR/0KTdZ0P1]C2T0
101^D2`0KDl[06Y<:01YBbL206Q:9P0506U;9`1ZC2P0K4hZ06]=:@1YBbL00`1WBBD00`1XBRH0JD/W
06]=:@0706]=:@80JDdX00T0JD/W06Y99P1ZB2D0JTHT06U58`1Z@b80HdDS06A6901VB2H00P1XBRP2
06M99`0506I89P1UAbD0JDPW06U89`1XAbH00P1WARD306I59080ITL[00<0IDHZ06A5:@1SA2P00P1R
@bL01`1Q@RH0HTTZ06=8:P1SB2X0I4LY06E6:@1WABT00P1WA2P306I89P80IDLU0`1TAR@0401RA2P0
I4HZ06E7:`1Q@bL0G3hR05/m8@1N@2@0HT@X05M57`1JAR40GdTT06=;9`1XBbT0JD/Y06]::@1/BBT3
06Y<:00306U;9`1XBRH0J4XV0080IdTU00<0Gd4U06129P1RA2P00P1SABT0101RA2P0H48V05m19@1S
A2D306939080HD8S0P1P@B8206E8:00406A79`1SARH0HdHV06959@80HD@T00<0Hd@U0693901Q@R<0
0P1P@B800`1Q@R<0HT<T06=49@0806959@0f0651:P1N@2P0G3hV05Lk8`1E>b80E3`R058m8P1C?R<0
D3lQ054n801??1h0CcXM058j7P1F?240FSlT05e29`1G?BH0E3XS050h801A>B40DS`T058n9@1=?280
BSTO04Xd7`1=>2<0CcXU04`j9017=b00A3DN04Di8@19?BD0Bc/Q04Xj801;>R00C3PO04li8@1C>b<0
ECdU05Pn9`1F@B@0Ed8S05Y3901L@b@0GT@S06958`1SAb80I4HR06Q::01WBBL0IDLU06A6901VB2H0
JD/Y0P1]Cbd02@1`DS00Le<]079B;01aDBX0L50W071A9@1bDbD0Le@V07EF9`0307=@:00307AA:@1e
DRX0ME8Z0080MU<[201iEC401P1iDbh0MU<]07IC;@1dDR`0LU8[06mB:P80KE4Y00@0Ke0a06e>;`1[
C2d0JDX[0P1XBBX0101YBR/0JT//06m?:01`D2T2075A:P0:079B:`1aDBX0L50Y06m?:01`Cb`0Kdh[
06e?:`1[CbX0J4hY06M?:@80IU0Y00@0JD/Y06Q::01XBRP0J4XX0P1WBBL206I89P0305i:9`1MBBH0
G4PU0080FdLT00<0GDTV05i:9`1PC2T00`1NBBX[ooooo`00:_ooool80:AiAP030:MlB@2VNdP0Y7U6
0080XWM400<0XgQ50:AiAP2UNTL00`2UNTL20:IkB0<0Yga9202UNTL80:IlBP@0YG]90P2TNTP20:=i
A`040:YnC@2YOD`0ZGe<0:QlB`80Yg]:0P2VNTT20:MmC@040:MmB`2XOd/0Z7m;0:V0BP80ZH180P2Z
P4h0102YOdd0Z7i<0:QnC02WOD/20:IlBP<0Yge;0`2XOT`30:UoC@P0Ygi:00<0ZH1:0:Z1B`2/Pdd0
0P2/Pdd00`2[PT`0ZH1:0:QoB@020:F0B@060:AoBP2SOTX0XWa;0:5kC02PNT/0X7Y=0P2WOTH00`2V
ODD0YGa40:Ak@`020:=j@P070:9i@@2MLd40W79009ab@02KLCl0VW0n09U_?@0209Q^?080Tfdn00@0
TV`m095[?02AJc`0T6Xk0P2?JCX708aV>@0308]U>028HcT0R6<i00<0R6<i0`27HSP02021GSH0P5de
07mL=01mFS80O5Ta07YG;`1iERh0N5D]0P1hEBl207UF<00407MD;P1eDR`0Le0Z075>:0<0KU4Y0`1]
D2P206a?9`80KThW00@0KdlX071@:@1aDBX0LU8[0P1cDb`03P1gE2X0MU<Y07EB:01fDbT0Me@Z07YG
;@1mFS00Oe`b07YM<`1mGS80OUlc085P<`24HS@0Qf<c0P2:I3<01027Hc<0R6@d08QT=028I3@208UU
=@80RVHf202;ICH808aV=`0308US=02;ICH0S6Hg0080SVPi00<0S6Hg08]U=P29Hc@00P2;I3T00`2;
ICP0S6Hg08aV=@0308eX=00<08eX<`2CIcX0TVLj095V>@2@IcT0SFLh08]W=`29IcL0R6Hf08iX>@2=
IcP0RfDf0P2:I3D00`2;ICH0SFLh08iX>@0208aQ=00408eR=@2>HcH0T6Dh095V>@80TVLj202=ISl8
08UW>@80RV<h1P2;I3T208iX>@80SFLh0`2<ISL00`2;ICH0QV8b08IR<P0608IR<P0408EP<`26HC@0
QV4d08MR=@80R6<f0P29I3L01P2=J3/0RfHi08QS=P26HC@0Q5lb08EP<`80QV4d0`24Gc8508EP<`D0
PUd`0`23GS400`21Gc40P5h`07iL;P0307aJ;00507eK;@1nG2h0NUL]07QE:`1gE2X00P1eDRP02@1f
DbT0N5D[07UF;01eEbD0MEHW079F9P1`EBH0KEDW06aE:@0206YE:P0C06Q?9P1YD2L0J54X06I@9`1R
CbL0GT`V05]99@1GAb<0CchT04hn901=?B@0BS/T04Lk9@14>BD0@CTT044i9P10>bL0?cXV03dh9003
03/f8P0803`g8`0m>2@0>38L03Pa7P0f<Ad0<RlL030_7@0/;Ad202//7P0:02X/7P0Z;AX0:B`I02T/
6`0X:Q`09bTL02HX7@0U9a`09BHN02DX8@8092LP00<08bHO028U7P0Q91d00P0P8a`801hQ6P8082<L
0`0O8Q/301hQ6P04024S800P8Ql07AlL01/M6P<06Q`I00@06adJ01XL6@0J71T06Q`I0P0K7AX301`N
6`0601TN5`0K81T07b8I028T6@0S9AP09BHH0P0W9AH0200Z9aP0;R/L03<`8@0b;b00;R/L02`Y6P0_
;1d0<c0Q0`0[;Qd01@0Y;1/09bXI02DX5`0R9A@08B@C00809RPM0`0U9a`302@V6`0802LX8P0V9b40
9BHP02@U7`0S91h08R<M024R700P8A/8020S70P07b0J020071hI01dO6P0O81X08B4I02DR6@0W8aP0
:2@I02/U6@0V9B<0:bLT02dY800`:1/0=2TE03d_5017>1L0D40N06E39`1eFcX0QG5<08]jCP2@OTh0
WX9@0:Z2C`2]OD`0XXAN08EXAP1TC300D3hZ048f:P0d;2X0:BL/02LV;PX09bPR0P0X:B<202TZ90<0
:R/U200Y:R8802LX800@02HY8P0W:R<0:2/R02T/8@0[;b40;30Q02da800^<R40<C0[034a:@0d<BX0
=S8Y03Xc:@0k=BT0?CDX03hf:@P0ACXV0`1>?RL00`1??bP0D40Y0551:P020551:P80Bc/T00@0C3`U
04dm9P1=?BH0CShW0P1??bP02P16>bT0@cPV040e8`12=bD0AS/Y04Pm:`15>RP0@SLU04Hi:017>RT3
04Tl:`0N04Lj:@15>2L0@cHU050i9`1A>RP0EC`X05Tn:@1M@B/0HD<[06=5;@1UAB`0LT`W07E?:P1g
ERd0Ne/b07YO<P1gHC00LV4]071O:`1XECD0IE8d05m<;P1JAR/0Ed<Z05I2:P1G@Rd0F4<^0596;01A
AB/0Cd<Y0`1=@BL204m3:@0X05=6<`1BAS00D4@^04i2:P1>@RP0Cd@X0556:01BAbT0ITl_06M@;P1Y
DS00K5Ha06mI<P1bG3<0MF0e07IQ=P1YIS/0JVDk06eT>@1bHcP0N6Dj07mV?@26JCl0Rfa008e_?@2<
KS`0Rf/h08]Z=@2>JcD0Tfhg09Qc?02MMSd0VgLm09ej@P2OO4H0WGa909QhB@2ALTH0QfY0089U?@80
NUPb00H0NETb07QK<`1gFc<0MUdd07MN=@1fGcD207eW@00d07UV?P1eHC`0Kedi06MG=@1QDS40Fdh/
05U<;01KBbL0GD/W05e;9@1PCBD0IDlV06UB:@1]E2/0L5L^06e=901cE2P0NU/_07aM;`1iFR/0MeTW
07MI9@1hFRH0Nehd07mP=021HSH0QF@g08MU=`27Hc<0QV0_08EO;P21Gc80P5h`085L;`22G2d0QEd/
08YP;P2=I300T6Db09a^>P2MKc/0Vg0m09Y`?P2GKch0Tfdl091Z>`2=JCT0SFT]08m[;`2BKS80UW8f
09Qd>0<0VGDi00l0Sflf08m^>02?KST0SV`l08i/?P2>Jd40SFY208eZA027IS<0RVTf08e/>@2@Kc`0
TG0m08m^>`2<JcP00P29J3D02027IS<0QF@a08=R;`23HRl0QF@a08QW=02:JCH0SVX^0P2?Jc402P2?
JS<0SFPc08]V<P29Hc80Qf4`08]U>02:I3L0Qf4d08AN<@22G2l2085K;P0D089L;`28Gc40RF0b08]S
<P2=IC@0SFDb08eU<@2<IBh0Rf@]08IQ:P27HRd0QV8^08AR<P21H3<0OUhe07]K=01hFS@0Melc07IN
<P1dG30207=K;`0?07AL<01fGS80Melc07AS;`1aGbd0KE/Y06YH:01XERP0JEH[06aI;`1^Fc40Mf0d
07EN<P1cG300LEX^0080KeP/00P0L5T]075J;P1`FBl0L5T_06mH;P1]ER`0K5D[06YC:@80JE8X00T0
HeDT06QJ:`1[GC00JEXa069B;P1LC2X0G4/]05i=;`1ODBh00P1ND2d01P1LCR/0FT`Y05U;:01JC2T0
FddZ05a>:`80FdTU00L0GD/W05m=:@1QCb/0HU0/06AB;P1UDbl0Fd`U0080G4dV00<0GDhW05i?:01O
D2T00P1PDBX02P1=?Qd0CT4O0554901?A2H0C4<V04M09014?b80@cdS04@m8015?R4204Ho8P0404Dn
8@12>ah0@3TL03hg6PP0@3TM00L0@S/O04<l8014?B40AChR04@m8@12>al0@3TM0080?SLK01L0?cPL
040i7@11>Qh0@CXN040i7@0o>1`0?SLK03dk900j>240=S@M03<a6P0b<1T0<c4J03Hd7@0h=Ql0>38L
03Tc7@0j=Al0>3HO03Hf7P0b=1`0;c4I02da600202d_6P80;2hI0P0[;AP202X/5`80:b`L0P0Z:a/3
02TZ6P0902PY6@0Y;140:B/C02T]5P0X;AT09B`L02<Y6`0P:1d07RHK00807R4H00<07R4J01hP6`0M
7a`00P0M7ah00`0M7R006Q`I01XL6@0201TK60<061XG00<05aTF01XL6`0J71/00P0I6aX201PJ6@80
5aTH0P0F61L301LI60<061XI200I6aP:01LI60<061XI0P0I6aX201XL6`P06A/H200I6aX@01LI61P0
5QPG200E5aH801HH5`P04QPH0`0E5aH201HH5`<05aTH200E5QPB01HH5`<05aTH0`0H6QT201HH5`80
5aTH100H6QT201LI608061XI0P0I6aX201XL6`P06A/J0`0J71T301/M6P<071hK200K7AX801`N6`80
7AhH0P0N7aT201lP6P80824K200R8A`8024Q6@P08R8J200U81X302PT60<0:BDI0P0Z9QX0100]8aL0
;R@H02hT600_9AT2030V6P80<BLK00<0<BDE03<W5`0f:QX00P0h;1`0100g:a/0=BTI03<W5`0f:1/2
03LY700303PZ7@0i:ah0>R`O0080>bdP200l;a`804@c8@80Ac8M00<0AC<M04@d7@13=1d00P11=Ad0
0`10=Qd0@30I040`6@06040`6@P0A38L0`1<>20204/g7`<0BSHN00D0A38J04Dc6`15<a/0AS@L04Le
7@0204Pf7P0404Tg7`14=B00A3DP04<d7`<0@S<N00<0@C8M040a7010<A`00P0i<Ql203Xc800403/d
8@0l=B80?CHS03df8`80@c<L0P14=1d404De7PP0AcDO0P12>A`00`12>1d0@CLN044f8002040e8@04
040e8`14=1d0@c<L048b6`80@C4J00D0@c<L04De7P16=Ql0AC<M04@b7003048`6P0904@b7016=1h0
B3HP04Tg7`1;=al0C3PP04dg801?=R00DCHQ0080DSHQ0P1E>b@0101F?2D0EcdV05Pn9`1H?RL205To
:0@0GT0T101O@BD0201QA280HdHT06M99`1[BRT0KDXZ06e9:@1/B2P0KDHW0P1`C2X3075=:`<0LTh/
00<0LE<_079D<01cEC400P1eEc<01@1cEC40LU@`075C;`1dCRT0LddX0080LT`W00@0LddX07E?:P1h
DRd0NE<^0`1aD2d02@1`Cb`0Kdh[06i=:P1^CBX0KD`Y06mA;@1]Cb/0JddY06Q:9P0306M99@0506Q:
9P1/CRX0JddY06U;9`1WBBD00P1VB2@00`1WBBD0J4XV06]=:@0706]=:@0;06Y>:@1YCBP0JD/W06Y9
9P1ZB2D0JTHT06U58`1[A2<0HT@R06A6901VB2H00P1XBRP206M99`0306I89P1UAbD0JDPW0080J4LV
00<0IdHU06I5901VAB@00P1UA2<0401XB2l0IdL^06I6;@1TA2/0Hd<Z0651:01P@2L0GclV06=::`1T
BB/0HdPZ06A7:@1TABP0ID<W06I39`1U@RH206I89P80IDLU0`1TAR@04@1SAB<0HD<Y06A6;01UAbd0
HD<Y05/m8`1I>b40GClU0694:P1CA1d0F4HP05e9901SBbL0IddZ06]=:`1]C2/0KT/[0080JT`X0P1Y
BbL01`1XBRH0IdTU06M99@1VB2@0GT0V05m19`1Q@bT00P1RA2X00`1Q@bT0Gd4W05i09P0306939080
HD8S0`1P@B8206M::P0406I9:@1UB2P0HdHV06959@80HD@T00<0Hd@U0693901O@2400P1M?Ql00`1O
@240HT<T06=49@0806=69P0f0651:P1N@2P0FcdU05Hj8P1D>R40Dc/Q054l8@1B?B80DD0R054n801=
>Q`0C3LJ050h701E>b00Fd0U05m4:@1G?2L0DcPS04lf801>>240D3`T04lm9@1<>R80B3PO04Lb7@1;
=R40CC/U04Xj8`15=Ql0A3DN04Di8@1:?RH0Bc/Q04Xj801:>Al0C3PO04hh801C>b<0ECdU05Pn9`1H
@bH0F4<T05]49@1L@b@0GT@S06548P1QAB00HdDQ06Q::01VB2H0I4HT06=58`1UAbD0JD/Y0P1^D2h0
2@1aDc40M5@^079B;01aDBX0KdlV071A9@1aDR@0Le@V07EF9`02079?9`80Le0X00@0M54Y07EB:P1e
DRX0MU<[1@1iEC4307QD<00<07QB;@1fDbd0ME8/07=A:`1aDBX0KU4Y06eA:@1/D2P0KDh_06a=;P1Z
Bb`0J4TZ0P1WB2T206Q9:P0806];901/C2D0KdlX071@:@1_CbP0KDdV06];901YBB8206e<:`0606Y<
:P1YC2X0IddZ06I>:P1UCbX0IU0[0`1XBRP206M99`<0ITPV00<0Gd/X05i:9`1LB2D00P1JAR<00`1K
Ab@0GDTV05i:9`0305e8:b_ooooo000Zooooo`040:=hA@2TNDH0Y7U60:AiAP80YGY70P2VNdP80:=g
AP060:9h?02SNCd0XgTm0:Ek?`2VO400Yge10P2XOT880:EjA@P0Z7e:00P0YW]80:EjA`2TNDH0XgQ5
0:AiAP2UNTL0Yga90:QmBP80Ygi:0P2VODT30:ElB0030:AkA`2XOd/0Z7m;00H0Z7m;0`2VO4`00`2W
ODd0Z7i>0:UoC`020:UoC`T0ZX1>2`2YP4`00`2ZPDd0Zh9>0:b3C`020:b3C`P0ZH1<00X0ZGm=0:Qn
C02VO4X0Y7Y80:9hAP2PMT@0WWA209ec@@2LLDH0WG970P2NLdP01P2MLTL0Vg1509U^@`2GK440V6e3
09U^A080VVm500@0V6e309EZ@02CJ3h0TFHl102?J3d408iW?080R6<f00@0Qf8e08IQ=026HC@0QF0c
0P24Gc8207mM;@0>07iL;P1mFbh0O5T_07]H<01kF380NULa07=@:01hEBd0MU<[07QE;@1mFS80L4dU
06Q57@1eDRX2079B:`06075A:P1`D2T0KdlX06i>9`1]CBH0K4`U0P1[BRL0101/BbP0KD`Y06m>:`1`
Cb`2075@;@0607QC:@1iE2X0NE@Z07YE:`1kER`0O5L]0P1mF2h207aI<`0607aI<@1mFS00Oed`08=Q
<`26I3@0R6Hf0P23Hc801025Hc<0Qf<c08MS<`29Hc@208]R=00708QR<`29Hc@0RfDf08aV=`2=IcP0
S6Hg08]U=P0208YT=@H0RfDf00<0RV@e08eW>02=IcP01P2=IcP0102@JS/0SfTj08mY>P2?JCX308iX
>@80SFLh00P0RF<d08YT=@2;ICH0S6Hg08eW>02>J3T0SfTj091Z>`80SfTl00@0SVPk08eW>P2;ICP0
RV@g0P29HcH00`2<ICX0Rf@i08YS>00208QQ=P0308YS>02;I3T0S6Dj00<0SFLh0P2<ISL508]U=P04
08YT=@29Hc@0RF<d08QR<`80Qf4b0P2;ICH408aV=`80SFLh0P2<IcX00`2;IST0RVDh08UT=`0208QS
=P0908MR=@2<IcX0RfHi08YU>029I3L0R6<f08MR=@26HC@0QF0c0080QV8b0`27Hc<308QT=00408YU
>028HcH0QV4d08AO<P80PUd`0P23GS4808MR=@P0Peha0P1oG38307iK<@<0OEX`0P1oG380101nFc40
OEX`07aI;`1kF2h207YG;@0607MG;P1fERd0MUH]07EE;01dE2/0Le<Z0P1bDRT02@1_D340KE0`06a?
;`1XCRd0I4`Z065::01NBRL0GDTV04m08@0204do8P0304Tn8P17?B80A3dS0080@S`T00H0?S`U03dk
900l>R<0>cTR03Xh8@0h=Ql203Le7P80>SDQ00@0=S@O03<b7@0_<A/0;30I0P0Z;QL02P0X;AH0:b`N
02TZ700X:A/09bPJ02HW6@0W:1X0:BXL02X[7@0U9Qh202@U7@0302<T700R8a/08B8J0080824I00<0
8B@M01lR6`0N8AX00P0M81T00`0N8AX07b8K024T7@0801hQ6P0801dP6@0N8AX07b8K020S700O8Q/0
7R4J01`O600K7QL801`N6`8071lH00@07B0I01lR6`0Q91d08RDN0P0T9b0202LZ7`0302T[800Z:R00
;BXQ0080;b/R00`0<BXR034_6P0d<Qd0=34P02l/7@0X91T091lI02HQ7@0Z9B808b@L02DV7P0W:202
02TZ8P0;02PY8@0V9al09BHN02LX800V9al09BHN02@U7@0S91`08R<K024R6P0P8AT00`0O81X5020Q
6`0401`O600M81T07B0I01dP6@<07R4J01H07b8K01/L5P0L7AL07AhH01hO6@0O81X0824K024R700R
8ad09b<H02PT6@0/9QX0<2PM03@Z7P0i;Al0?30P03ha8@1NAR@0J50/07QP>P28LDP0TgaB0P2GP5@0
4@2EOe00/XmI0:V4C`2EL3/0MU@T05<k5@0h;QD0:2/P02<_:`0Y9BH09BLV020Y9P0K:R<07BXQ02<X
8@0/9b<0<bPT00T09RTR200Y:R@402PY8`809bPR0P0V9b402@0[;2@0:R/S02TZ8P0Y:R80:R/S02//
900];RH0;c0X038e8P0203<d8P0303Dd8P0g=2<0>C<S0080>S<S00H0@3X^044i;011>B`0@cX[04Hj
:P17>RT204Xk:00>04<l:@14?RP0AShY04Tn:01;?bL0Cd4W05129`1A@BL0C3`]04`l;01=?2`0CS/Z
04hl:01@>bH2058l9@0;04hn9@1=?bD0C3dV04Pl9P16>bL0@c/X044j9`10>BL0BC`/04Pk:`17>RX0
0P16>BT04@17>RX0B3/[04Tl;00n>BH0@S/X04Tn:01B@RT0FDHX05m69`1SAR@0I4HR06I:9@1YCBH0
KU0Z07=F;P1jFS40OE`a0080Oed`00P0Ke/Y06eH:@1WE2X0HTl^05]:;P1FAC40Dd8b0551=0D0DdT`
0P1BB2l0<@1AAbh0CcdY054o:`1C@Bd0ET@`05M5<@1FA300ED<_05A2;P1PBc00HTd`06M@<@1[Dc40
LELb07MK<`1jGc@0O5lc07EY=@1hK3P0Nfhj07aZ>01lISD0OF8c085U=P27J3X0PV/o08=[?@24KC/0
R6li08ec>02CMcH0V7/g09]n>02NN3X0WWLl09ah?02JMcd0V7Dm09=b?02?L3X0SFhh07eQ<P1oH380
OUl`07mO;P21H2d0QF4]08QS;`29I2l00P26KCL04024KCT0PF/j07YX>P1bHcX0JUdj06=H>01OESL0
HDli05m==@1QBc<0Hd/_06M<;`1_D340MUDd07YH=@1eEB`207IE:P0507ME:01kERT0OeTZ08EM;027
Gbh00P23IC<01022I380P68`07mQ;`1mGbd207aN;006081P;`20H2d0PV4^08EQ;@26Hbd0R6</0P2:
HbX0502>J2L0T6X[099^<02CL3H0Tg0j08m^>@2;JcP0RFTh08]V;`2@Jc@0UG0i09Mb>`2FLCX0UG0i
09Qc?02KMSl0UW<k09Eb>P2DLCT0TVlg102AKSH00`25HcD0QV@f08QV>00208YX>P0508UW>@27ICL0
QV@f085V=`20ICH00P1oI3D01@20ICH0PFHg08=X>@25JS/0Sfhk0080SVhk00D0S6hj08M/=`22JC<0
OFH`07]T;P02085Q>P<0P60i0`1oGcP00`1lHC@0OF8e07mT=`02081U>00;07mT=`1mHSD0O64d08=U
<`22I380Of0a07eN<01lGC40OEdd07iN=@1oGcP00P1mHSL0101kH3D0NUld07QM<P1fFc0207EJ;`08
081O=01oGS<0OUlc07]N<P1iGS40MUh`07EM;`1dGRl207UN<`0407QM<P1gG340MEX_07AI;P80LeP]
00<0LE`_06mJ;@1]F2/00P1[ERT0301/EbX0KEP[06iI;01_GS80K5/_06EF:`1ODRH0FThT05I=901F
CBH0EDdV05Y;:P80FDXY0P1HBBP0101IBRT0Fd`[05e>;@1NCbh205m=9`80H4hX00`0HDlY069@:P1R
D2X0He4[05]>8P1NDBD0HUD[06AF;`1RE2l0FddZ05A68`1?@1l204Xo7`<0BChN0`18?Ad02015?R80
ASlS04M09018@BD0ASlS04<l800o>1`0?3DI200j>Ad00`0o>b00?SXO03di7P0203di7P0403lk8011
?B80@ShS03lk80<0?SXO0P0m>Ah203`h7@0F03Dg7`0d=Qh0<S@L034c6`0`<QX0<C<K038d700c=Ad0
<C@O030c7P0_<Qd0;S4L02d`6`0/;aX0:bhI02X]600_<a`0;S4L02d`6`0[;Q/0:B`K02PZ70809RPK
0`0Z;A`202T/6`<0:RdL00P0;S4N02d`7@0[;Qd0:2XL02HX6`0S9AX08B<H020Q6@807b4N00<07R0M
01dO700L7Q/00P0J71T00`0I6aP06Q`I01XL6@0201TK608061XG0P0G6AHP01LI60T06A/J0P0F61L3
01LI60<061XI200I6aXH01LI61005QPG200E5aH@01HH5`P05aTH200E5aH801HH5`P05AHH0`0E5aH2
01HH5`/05aTH400I6aX201LI60<061XI0P0I6aX201XL6`P06adL200K7AX301/K6@8071`J1@0M7A/2
01hN70<07alM00<0820N01lO7@0O7ad01P0O7ad8020Q6`P08R8J00P091lI02DP6P0V8A/0:2<M02XU
7`0[9R00;2LQ02dX8P@0:2@K0P0Y9A`202XV7@0602lU6`0`9Q`0<2HL034W7@0b:1h0<bTO0P0d:R04
03P/80@0=b/O00H0=RTP03HZ7P0h;200>BdO03/_7`0l<Al203hc7`<0?RlL00<0?c0M040a7P11<Ql0
0P11<Ql203`_7080?C0M0`0n<Ah00`0o<Ql0?c8Q03lb8@0303lb8@<0?S4P0`13<24204@a8P<0AC8S
2014<b4304Pg9@80AcHT0`16=B<2040d7P80?c<M1@0n<Q`803`a7`@0@C0P0P12<B4204<b8P80A3<Q
0P15=28304He8`0704Lf9017=Ad0AcDM04Hd7015<a/0@c4I048`6002044_5`P0@3<P00/0@C@Q04<d
8@14=B80AC@R04Ld8`19=2<0BS<S04/d9018>R00AcTO04Hf7@0204Le7@0304/g7`1>>240CcTR0080
Dc/O0`1D?20305Dm8@80G3hR00@0GClS05i0901O@BD0H48V0P1Q@bL02@1L@b@0GD8T05e38P1P@b40
I4HT06Y99P1_CBP0LU0[06e<:@0706i=:P80K50[00<0KDl[06m>:`1`CR/00P1aCB/0101cC2/0Kdh[
06m>:`1`Cb`2075@;@03079A;P1cDRl0Le8_00<0Kdh[0P1^CBX306e<:@P0Id/V00P0JD`/06Q;:`1V
BBT0I4LW06=69P1TAbL0ITTY06M::PD0IdXX00<0J4/Y06U<:P1ZCB/00P1YC2X01P1XBbT0IdXX06E8
9P1TAbD0HdHT06958`80I4LW0`1UB2P406I9:@80HD@T00<0HTDU06=69P1TAbL00P1UB2P01`1VBBT0
GdPY05m8:@1PAbT0H4DX0694:01R@bL00P1T@RL205i7:00605i59`1N@bH0Gd4U05m0901Q?b@0H3hS
0P1M?b<0101N@2@0Gd4U06129P1P@RH206539`80GS`Q00@0GChR05do8`1L@B@0Fd8T0P1KA2D0401P
@2L0H44U06529P1R@bH0I4DV06E79@1VB2@0IdTU06I48@1XAR<0JTTV06Y<:01XC2L0I4XU06168@1L
A1h20658:@040617:01OARL0GD@U05a39080Fd8S0100GT@Y05e3:01J@2D0FClT05Pn8`1I?b@0Fd4V
05a29`1RAQl0HDDN05i27@1L?ad0FchN05`o8@1M@280GT0T0P1KART00`1LA2P0GD<X05e29`0205m1
9`0906109`1P?R80Gd0S06529@1QA2H0Gd@V05a3901I@R80F44Q00<0EcdV0P1F?2D305Dk9080EcdL
00@0Ec`N05Ll7`1H?B80F3dR0P1H?2@01P1F>b00EC/R05@j8@1A>B40CSPQ04/f8@80B3HR00<0BSXS
04Ph8@16=Ql00P15=Ah02017=b00BSXS04`l9@18=Qh0BCLO04/i8@1=>b<0CS`T0P1=>b<01`1<>R80
EC/P05Lm8P1J@2D0G48W05i4:@1OABX00P1NA2T01P1T@RL0Hd4V06=19P1T@RL0ID<X06Q6:`80JdT^
00@0KD/`06a@:`1/D2/0K50[1@1]DB`306m=:00C071>:@1aCbX0LU0[07=A;01dDRd0NEP[07MF:@1e
E2T0Le8Y07=A:`1cDB`0ME<^07ID<@1eEBl0Le<]06i@:P1ZCRL0ITdU06A=900206==900905m78`1R
B2D0ID/V06U=9P1/CbL0KThU06i=901]C240KTdT0080KdhU00<0L4lV075@9`1aD2L00P1bDBP0201a
D2d0L4l/06a>:P1YCBP0I4XU06188P1MAb00G4HO0P1P@RH03P1Q@bL0HdDY06A6:P1UAb/0ITP/06M9
;@1YBR/0J4/[06M::P1SBBP0HDTW05m89P1LB2D0FdLT0`1L@RT[ooooo`00:_ooool0102TNDH0YGY7
0:EjA`2UNTL20:IkB080Yga9202SMdH01@2RN3h0XgTo0:=i?`2TNT00YWa20080Yge300<0Z7i40:Ej
A@2UNTD01P2UNTD80:QmBP080:IkB02UNTL0Y7U60:=hA@2TNDH0YGY70:MlB@2XODX20:MnBP80YWe9
102UO4P80:QoB`80Yge=0P2XOTh20:UoC`80ZX1@2@2ZP4h:0:V0C080ZX5=0P2[PTh20:b3C`P0ZH1<
00P0ZGm=0:QnC02VO4X0Y7Y80:9hAP2PMT@0WgE309id@P80WG950P2NLdH0302MLTD0Vg1309U^@@2H
KD00V6e309U^A02JKdD0VFi409Q]@`2EJT00TfPn095V?0@0SfPm102>Ic`208QS=P0408MR=@26HC@0
QV4d08EP<`80Q5lb0P1oGBd0101nG2h0OE/^07aI;`1lFC4207]H<P0807QE;@1lFC40NUL_081M=@29
ISh0O5Ta06m<901gE2`2079B:`04075A:P1`D2T0KdlX06i>9`80KDdV0P1/BbP0101]C2T0KTdZ06m>
:`1_CR/2071?;080MU<Y00<0Me@Z07QE:`1iER`00P1jEbd02@1kF2h0O5Tc07aI<`1lFC40OEX`07mM
<022H380QF<c08MU=@0208=S<P0408AR<P27Hc<0Qf<c08US=080Rf8d00P0R68c08US=02;ICH0S6Hg
08eW>02<ISL0RfDf08YT=@P0RfDf202=IcP408mY>P<0SVPi0P2=IcP208US=00608YT=@2;ICH0S6Hg
08eW>02>J3T0SfTj0P2>J3/208eW>P0708aV>@2;ICP0RV@g08YT=`2=IS/0S6Dj08]T>@0208YS>003
08]T>@2<ICX0SFHk00<0SFLh0P2<ISL308]U=P80S6Hg0P2;ICH0102:I3D0RF<d08US=029Hc@808aV
=`80S6Lj00<0RfHi08YU>029I3L00P28HcH01`27HSD0RfHi08]V>@2:ICP0RF@g08QS=P27HSD00P26
HC@208IR<P<0Qf<c0`28I3@0102:ICP0R6<f08IQ=024Gc8308=N<@0308AO<P26HC@0QV4d00H0QV4d
2023GS4207mL<P<0OU/a0`1mFS001P1oG380OU/a07iK<@1mFS00O5T_07]H;P80NUL]0P1fERd207EE
;00D07AD:`1cDbX0LU8Y079B:@1_D340KE0`06a?;`1XCRd0IDd[069;:@1NBRL0GDTV05118P1?@240
CClR04Xo8`18?R<0AChT04@m8`12?2@203hl9@0603dk900k>B80>SPQ03Tg800h=Ql0=cDN0P0j=B40
100f=1l0=38M034`6`0];aT202/_600402X^5`0[;1h0:R/M02PY6`<09bPJ0P0Y:Q`202DV7P0402@U
7@0S91`08R<K024R6P80824I00<08B@M01lR6`0N8AX00P0M81T00`0N8AX07b8K024T7@0901hQ6P07
01lR6`0P8a`082<L01lR6`0M81T06ahG01XM5P0801`N6`0V01/N5`0L7aP07B0I01lR6`0P8a`08RDN
02<V7`0T9b009RTN02LZ7`0X:Ql0:RXP02dZ8@0^:R40;b/R034Z8P0_;AP0<RlL03@a800a;Ql0:RHK
02HR6@0W8Q`0:B@P028S6`0S91`09BHN02LX800X:B409bPP02HW7`0U9Qh09bPP02HW7`0U9Qh092DM
02<T700R8a/2024R6PP0824K1P0N8AX201dP6@8071dG00@07AhH01hO6@0O81X0824K0P0Q8Q`0800V
8aX0:2@I02XV6`0_:Ad0<b/N03L^7`0k;al0?30P05<o7P1NAbL0K5Dc07aV?`29LTT0T7U?09=lD02C
ODh0Z8MB0:^8DP2UP4/0SF/k06YA:@18>Ql0<34S02H`:00]9bL0:BTW028[9P0O;2<082/S02@Y8P0/
9b<0<2DS2@0V:B8902TZ90<0:2TS0P0W:28202HW8@0302//900Z:b<0:BXR0080:BXR00T0:b`T02d^
9P0^;bL0<C@Q038c8@0c=280=C@R03Hc8P0i<b<00P0j<b<01P0l=RX0?CDX03hf:@10=bP0@SHV04@g
9P80AcPU00H0A3dZ04Dm:016?RT0BSlY04a0:01@@RP20592:080C3`/00@0CC`Z04lm:@1??BL0DC`W
0P1B?2D204lo9P0904dn9`19?BD0Ac`V04@l9`13>bP0@CXW04Xm;@18>b/0AcXZ0080ASTY01/0AcXZ
04Pk:`1:?Bd0@CXX04@l:@1:?bT0DT8Y05Q59`1NABH0H4HS06968@1SBB@0J4`W06a@:@1bEBd0N5P_
07aK<01nFc40OU`_07AN;@1aG2d0KEL^06IB;`1PCBl0FDLa05A3<@1C@S80201CAbl01P1A?b/0DT0/
05E3;`1GAC40F4Hb05M5<@80ET@`02P0GdX_065<;`1WD340K5@b075G<P1hG3@0Nf0e07iQ=@1iK3P0
O6lk085a?P23Kcd0P6Xi089W>026JS/0RFdn085Z?P23Jcd0Pf`j08M^>02<LSL0TWHg09Ii=`2IO3P0
W7Hh09ef>`2KMc/0VWLm09Qe?@2DLcd0T74k08m`>P26JS/0R6Tk08MX>@28J3L0RVTf08iZ=P2AK3P0
TVdh0P2:KcP03`28KcT0Q6dk07mZ>`1hIc`0L68k06YM>P1UFcP0I58j06A@=`1SCS<0I4``06Q=;`1^
DC40LeDa07MF<`0207AD:`0607IE:P1iEbX0OUT/08AN;`28HS<0S6@c0P22I3801021Hc40Of4_07iP
;P1mGbd207aN;00H07mO;P20H2l0PV4^08EQ;@26Hbd0R6</08]T;@2<IB`0T6X[099/;@2CKc40Tg0f
09=`>02?KST0RVXg08QX=@2;IRl0T6/d09E`>@2FLCX0U6lh09=^=`2EL3T0V7<l0`2DLCT209=`>006
095^=P2@KCD0T6de08IT=027ICD0RFLg0P2:J3P01@29IcL0R6Hf08MU=@21ISL0P6Df0080Of@e00@0
P6Df085V=`23J3T0QFXk0P2?KS/01P2>KS/0SFlk08U^>@25K3H0PVTc07iW<@@0PV8i0P21HCP2081P
=`0307iS=P1oI3L0P6Dh0080PFHi01/0P6Dh07mT=`1nHcH0Q6Hb08=U<`21Hc40Of0a07iO<@1oH3@0
P60g085Q>01oI3T0OV<h07eR=`1kH3D0NUld07QM<P1gG340MU/`081O=01oGS<0OUlc07]N<P1iGS40
MUh`07EM;`1dGRl00P1hG3@02@1gFc<0MUXb07EI<@1dF300LeL_079F;P1`Fc00KeX_06eH;@0306]F
:`0;06eH;@1^FBh0K5/_06YI;@1UER/0H5<Y05]?9`1GCRL0ED`U05=;9P1JBbX00P1IBRT01P1HBBP0
EdPW05M89`1IBRT0Fd`[05a=;080GT`V00@0GddW061>:01PCRP0HDlY0P1RD2X0201NDBD0H5<Y069E
:`1QDb`0GU0[05Q:9`1B@b80CSlN0P1:?al304Tn7P<0B3dM0`16?b<01@15?R80@c`P044j7P0o>1`0
?CHJ00P0>STM0P0n>Ql01P0m>Ah0?3PM03di7P0o>b00@3`Q048n8`@0?SXO0P0m>Ah203`h7@0803Dg
7`0d=Qh0<S@L034c6`0`<QX0<C<K038d700c=Ad2030c7P0<02lb7@0^<A`0;C0K02`_6P0[;QT0:RdH
02hb6`0^<A`0;C0K02`_700Z;A`0:B/M0P0X:Qd202X]70@0:B`K0P0Z;A`02@0]<1d0;2lN02X]700X
:Q`09BLJ02<U6P0Q8QX0824I01lQ7P0201hP7@0501dO700K7AX06Q`I01XL6@0I6aP00P0J71T201TK
608061XG0P0G6AHP01LI60T06A/J0P0F61L301LI60<061XI200I6aXH01LI61005QPG200E5aH@01HH
5`P05aTH200E5aH801HH5`P05AHH0`0E5aH201HH5`/05aTH400I6aX201LI60<061XI0P0I6aX201XL
6`P06adL200K7AX301/K6@8071`J1@0M7A/201hN70`07alM200P8A/8028R6P0902@O6@0U81X09R4K
02PS7@0Y91h0:bHP02`W8@0]:2809b<J00<0:2@K0P0Y9A`202XV7@80;bDK00@0<2HL034W7@0b:1h0
<bTO0P0d:R0303P/80D0=b/O00T0=RTP03HZ7P0g:al0>BdO03/_7`0l<Al0?C8N03hc7`0m;Q/00P0n
;a`203l`7@80@34N00@0@C8O03`_700l;a`0?2lL0P0m<1d303ha7P@0?c8Q100n<B001011<200@S4Q
048a8@12<B4204<b8P80A3<S2`14<b4204<b80<0@S4O0P10=1h203lc7@@0?S8L00<0?C4K03`a7`0l
<Al01P0l<Al01010;al0@C0P044`8011<202048a8@80@c8R0`14<b4204Dd8P<0ASDS0P15=Ah01014
=1d0@c<L048b6`11<AX2040`6@P0@3<P0P11=2400`13=240AC@R04Hc8P0204Td8`0404Xc8`18>R00
AcTO04Lg7P80AcDM00<0BcLO04hh8@1?>B800P1C>al305@l80<0ECdQ0P1L?R800`1M?b<0GT0T05m1
9@0206129P0906539`1NABH0Gd@V05m5901RAB<0IDLU06]:9`1_CBP0LDlZ00<0KD`Y101^CBX01P1_
CR/0K50[06a@:`1]Cb/0Kdh[071>:`80LDd[00<0Ld`[06i=:P1^CBX00P1_CR/0101`Cb`0LE0]075@
;@1aD2d206m>:`80KTdZ0`1]C2T00`1/BbP0Id/V06M;9P0606M;9P0;06U<;01WBRX0IDPX06A79`1S
ARH0I4LW06E8:01VBBT0ITTW06M::01XBbT01@1YC2X01@1XBbT0IdXX06M::01VBBL0IDPV0080I4LU
00<0HdHT06A79`1TAbL01`1TAbL20654900406959@1SARH0I4LW06A79`80IDPX0P1OB2T0101PAbT0
H4DX0694:01R@bL206A29`80GDHW00@0GD@V05i39P1P@RH0H44U0P1R@2D305m19@<0H48V0P1Q@bL2
05lm8P0405dn8P1M?b<0Fd0S05Y18`80FT<T0100GclV06119@1Q@RH0HT<V06A59P1UAbD0ITPT06M9
9@1WAB80JDLT06Y99P1ZC2P0Id/V06988`1NA1l0Fd<M0P1PAbP02@1OARL0GTDV05e49@1L@b@0Fd8S
05Y18P1K@BH0FT0U05To900205Pn8`0;05To901K@BH0G48W06557P1PA1l0GT8M05e07P1L?al0GD0R
05m19@1P@RH00P1IA2L03`1K@bL0G48W05e29`1O@BL0H48X0651:01N?b80Gd0S05m2901N@bD0GD@U
05Y38`1I@R80ED4P05Lo9`0305Hn9P80ECdU0P1D?2@205Lm700305Ll7P1G?1l0Ec`Q0080Ec/S00X0
Ec/U05Dk801D>R40DSXP054i8@1==b00BcHQ04Pf8P17=B40B3PQ0P17=b002@16=Ql0AcLP04Ph8@19
>B80BSXS04Le7@18=Qh0BcTQ04dk8`0304hl900504dk8`1E>b00EcdR05To901L@RL00`1NA2T00`1M
@bP0I48W06=19P0206=19P0506E3:01WABX0JTP]06Y8;@1/BRl00`1ZCRT306]?:P80K50[0P1_CBP0
0`1`CRT0LDlZ079@:`0207=A;00I07AB;@1hEbX0MUDZ07AC:01cDRT0LU0Z07=A;01dDRl0ME<`07AD
;P1bDR`0KDlY06U=9P1UC2@0Hd`S069<8`1SCB@0H4PT06989@1UBbH0JThW06a?9`1^CRL0KdhU06i=
900206i<9P80KddW00`0L4hX075?:@1aCbT0LDlY071?;01_CR/0JddY06Q<9`1SBB@0H4PR05e7801L
AQl206539`040694:01SABT0HdDY06A6:P80IDL[00P0JDX[06M::P1VBBT0HdTX06189P1NAbD0FdLT
05Y68`<0G48Y:oooool002[ooooo00@0YGY70:IkB02VNdP0YW]80P2WO4T20:QmBPP0XgM600H0XWPn
0:=i?`2SNCl0Y7Y00:Ek@@2VO4820:Mm@`P0YGY5202WO4T0202VNdP0YGY70:AiAP2SN4D0Y7U60:Ej
A`2WO4T0Z7e:0`2WOTX20:ImB@<0YGa8202XOd/30:UoC@80ZX1>0`2[PDl90:Z0CPT0ZH1<0`2ZPDd3
0:^2CP030:b3C`2YP4`0ZH1<00H0ZH1<0P2XOT`0202VO4X0YG]90:=iA`2QMdD0X7I409me@`2MLTD0
WW=60P2OM4L01@2NLdH0W75409Y_@P2HKD00VFi30080VVm400D0VFi309Q]@P2FJd00TfPm099W?002
091Z?@80SfTl0P2>J3/208eW>P80R6<f00@0Qf8e08IQ=026HC@0QF0c0P24Gc82081N;P0>07mM;`1n
G2l0OEX`07aI<@1lFC<0NePb07aI<@1oG3@0OU/c08UV?P2GM4`0RVLo07MD;01hEBd2079B:`04075A
:P1`D2T0KdlX06m?:080KThW0`1^CBX506m>:`0607EB:P1fDb/0MU<[07MD;01hEBd0NEH^0P1jEbl2
07aI<`0<07aI<@1lFBl0OU`_085O<@24HS80QV@d089R<@23Hc80Q68b08IR<P27Hc<0R68c0P2;HS@0
2028HS<0RF<d08]U=P2<ISL0SFLh08aV=`2;ICH0RV@e0`2;ICH208YT=@<0RfDf202=IcP308mY>P80
SVPi102=IcP01P28HS<0RF<d08US=02:I3D0RfDf08aV=`80SFLh1@2=IcX308aV>@0308mY?02>J3/0
SFLj0080S6Hi00<0SFLj08iX>`2?JC`00`2=IcP208aV=`<0RfDf0`2=IcP208aV=`<0RfDf202<ISL2
08aW>P0308]V>@2:ICP0RF@g0080R6<f00H0Qf8e08]V>@2:ICP0RVDh08UT=`28HcH208MR=@0308IQ
=026HS80QV8b00<0Qf<c0`28I3@01029I3L0R6<f08IQ=024Gc8208=N<@0308AO<P25H3<0Q5lb00L0
Q5lb2023GS4207mL<P<0OU/a0`1mFS0207iK<@0407eJ<01lFBl0NeP^07]H;P80NUL]0P1fERd00`1e
EB`0M5@[07=C:P02079B:@0?075A:01_DBl0KE0^06a?;@1XCR/0IDdY069<9`1OBbH0GTXU05928@1A
@R40D44R04do8P1:?b<0AcdR0080A3dS00H0@C`V040k9@0o>R@0?STS03dh8P0k=R0203Xe7`0603`e
8P0k=240>C@P03Dc7P0b<A`0;S0J0P0];aT0100[;aP0;2dO02//7P0Y:Q`302LX6P0702PY6`0Y:Q`0
9BHN02DV7P0T9Ad08b@L028S6`02024R6P04020Q6@0Q91d07b8K01hQ6P807B0I00<07R4J01lR6`0Q
91d0200N8AX2020S70808B@M00@07b8K01dP6@0K7QL06A`E200L7Q/01P0K7QL071lH01dP6@0N8AX0
82<L024T7@808RDN0P0U:1d04P0W:Ah0:BTO02`Y800^:R40;b/R034Z8P0]:QT0<2dL03<`8@0b;R80
;BTN02TU700X91/0:2<M01lP600Q8QX08b@L02DV7PH09RLO0P0U9Qh0100T9Ad08b@L028S6`0R8a/8
020Q6`8082<L00@07b8K01hQ6P0N8AX07B0I0P0L7aP01@0L7AL07AhH01dN600N7aT07b0J0080824K
01`08B8L02DR6`0V8aX0:BDL02hW7@0b:Ql0=B/O03L^7`0j;R00AC@H04hk7@1JAbL0JUHc07YT?@26
KdD0SgM;09=kC@2JNTL0YX9>0:f8D`2SOdd0Q6Lm05i;;@0l=B80:R`O038X9P0]:RD09R/T0P0Q;B<0
0`0U:R<0:RLR02dS8@0902HY8P/0:BXT0P0X:B<302LX8P0>02//900Z:b<0:BXR02PY8@0Y:R80:R/S
02`]9@0];RH0<3<R034b8P0b<b<0=38S03Hc900h<R@203Xb9@0F03Tc9`0j<RD0>c<V03dd9@10=2@0
@SDT04@e8P15=R<0ASh[04Lo:P1:?b/0C40Z04m0:@1B@RT0Dd<Y05A3:@1<?2`0CCh[04hm:`1??BT0
D3hX058n9P80E3hV00/0DT4W05109P1??bH0CChW04Xn:017?2P0A3`W04@l:@1:?B`0BC`[04Lj:@02
04Hi:00A04Lj:@19?2/0BSd/04Dm:P19?RX0C40X0592:@1GA2H0Fd@U05a48P1M@b00HDTU06A:9@1X
CRT0KU8[07=F;P1hF2l00P1kFRl0201jHS80N60b07=L<P1]Ec80IE0a05m;<P1JAC00ED<_0P1CAbd2
0596;080DdL]0P1DB2h0101D@R`0ED<]05M5;`1HAS0405U7<@0X05m:;`1QC2l0ITl`06aD<P1bF3<0
NEde07eR=`20HcL0OVdi089a?@28M440R79008I_?@27KC`0RW0o08ib@P21Jc`0PVXl089[>@26KCL0
RW0g08mb>02DMSP0UWPh09Uc=@2JLcP0VGDi09Uf?02HMCd0UG@n099c?@2ALS`0S71108e^@02;K3d0
S6`k08i]>P2BKSX0UW4m09Qc?P80T74j01L0Sg4k08a`?P27L3h0PF`o07YY?@1cI3/0L68k06aG>P1[
EST0JU<d06U@<@1ZD2l0KU4_071D;`1cEC40L5<[07=C;01eEB`0NEP]07mM<025H3<0RfDf08eW>002
081Q<P0407mP<@1nGc00OEh_07eN;`80O5d^0180Oel`07mO;P21Gbl0Q60^08IR;P29I2l0SFH_08iW
<02BK2h0Tfd_09=_<`2CL3H0TVlg08i]=`2:JcD0R6Tc08aW<P2AK3L209E`>`0<099]>02@JcH0TVdh
09A_>P2@KCD0TVlg09Aa>@2ELSX0U74i099_=`2@KCD0SV/c0P28ISH02029IcL0RVPh08YX>029IcL0
R6Hf08MU=@22ISH0PFDe0P20I3@01@21ICD0PfLg08IZ>P27Jc/0TFdi0080T6lj00D0Sg0j08e_>@29
KSL0QVde08E/=00308EV>P80Q6Di0`23I3P00`21ICD0PfLg08AX>00208EY>@0;08AX>023IcL0PFDe
08EW<`24IS80PfDc089S=022HcD0PV<g08=T>024I3/00P20ICX01P1oI3T0OV<h07aQ=P1kH3D0NUld
07UN<`80Oehe00<0OEdd07YM<`1hGC800P1eGC401`1cG300MUXb07EI<@1eFC40M5P`07=G;`1bERh0
0P1aEBd00`1_FRl0KUT^06aG;00306]F:`80K5L/0P1XEb`01`1TEB`0HE</05eA:@1GCRL0DdTU0518
8`1JBbX00P1IBRT01`1GB2L0ETLV05I79P1FAbH0EdPW05Q9:01LBR@00P1MBbD00`1NC2H0GddW061>
:002065?:@0806=F;01REB/0H58[05e?:P1IBbP0Dd@S04m07`1<?Ah204Xo7`<0BChN0`18?Ad01016
?b<0AChR04<l8011>Qh403lh70P0>STM00<0?SXO03di7P0l>1d00P0l>1d00`0m>Ah0?c/P044m8P03
03hj7`80?CTN0`0l>1d0200e=al0=3HN038d700a<a/0<38J034c6`0b=1`0<cDM0P0_<Qd0100^<A`0
;C0K02`_6P0/;aX202/^6@0802da6P0]<1/0;C0K02`_700/;ah0:bdO02/]800Z;1l302T/6`80:RdL
0`0Y;1/0200[;Qd0:RdL02PZ700V:1/092HK028S6`0P8A/07b0J0P0N81d00`0M7a`071hK01/M6P02
01XL6@0301TK600J71T06Q`I00806A/H0P0H6QL201LI5R005aTH2@0I6aX201HH5`<05aTH0`0H6QT8
01TK6QP05aTH400F61L801DG5Q005QPG200G6AP801DG5PP05QPG200E5QP301DG5P805QPG2`0G6AP@
01TK6P805aTH0`0H6QT201TK6PX06Q`K200K7AX301/K6@8071`J1P0M7A/201hN70/07alM200P8A/8
028R6P809B0J00H09R4K02LR700Y91h0:RDO02/V800/9b4302LS6P80:2@K0`0Y9A`202lU6`03030V
700a9ad0<RPN0080<bTO00<0=2XP03L[7`0g:al01P0g:al0200f:B00=RXN03L[7`0i;Al0>RhN03/`
7P0l<Ad0?C8N0P0k;Qd203`_7P@0?C0O0P0k;Q/203`_70<0?C0M00<0?S4N03ha800n<B001P0n<B03
044`8080@S4Q0`13<R8804@c8@<0@C0N0P10;ad303l^70<0?c8O0`0n<Ah303d`7@P0?34O0`10;al2
044`80<0@S4Q0P13<R0204@c8@<0AC@R00D0ASDS04@d7@14=1d0@c<L048b6`02044a6P80@30I200o
<Ql03P0o=200@3<P044d8@13=240AC@R04Hc8P18<b80BC@S04Li7`16>1h0AcLN04Le7@18=Qh0BcLO
0P1>>24205<k7`<0E3`P0`1E?B4205`n8P80GClS00`0GT0T05m19@1P@RH0H48V0658:@1QARP0HDLV
06A79@1WBBL0JdXW06i<9`1_CBP206a;:080KD`Y0P1^CBX206m>:`80K50[00<0KDl[06m>:`1`CR/0
0P1aCB/0101cC2/0KD`Y06e<:@1]C2T206i=:P<0Kdh[0`1^CBX206e<:@<0K4/X201XBbT01@1WBRX0
ITTY06E8:01TAbL0HdHV0080I4LW00@0IDPX06E89P1VBBL0JD`Z0P1[CR`00`1ZCB/0J4/Y06M::008
06E89P80I4LW0P1SARH00`1RABD0HD@T0654900406138`030654901RABD0HdHV0080I4LW00L0IDPX
05i7:01NAbP0GdHX05m49`1Q@bL0HD8V0080Hd4V0P1KA2D0101L@bD0GT<V06129P1Q@RH206A29`04
0694:01Q@bL0HD<W06539`@0H48V0P1P?R<0101N?b<0G3hR05Xo8P1I@28205M08@0605lo9P1P@BD0
HD8V06939P1SA2D0IDLU0P1VB2@02@1YARH0JTLW06Y9:01YBbT0ITTW06168`1L@Ql0FD4M05m6:002
05i59`0305e49P1L@bD0Fd8T0080FT4S0P1G?B804`1F?240EcdR05Lm8P1I?b@0Fd4V05a29`1PA1l0
Gd<N05i17`1N@B40GT4S05m19@1Q@bL0HT@Z05I1901G@RD0FD4U05]19P1M@RL00P1P@RP02@1R@RT0
GSlS05i0901O@BD0GD8U05]2901I@R<0ET4R05E08@0305Lo9`80EShV0`1E?BD01@1F?Ah0EC`M05Dl
7P1E>b00EC/R0080EC/T00L0ECXU05@j7`1B>R00DCTO04hh801<>200B3HP0080ASDQ00@0ACDN04Hf
7`17=b00B3PQ0P19>B801P18>240AcLP04Hd7018=Qh0BSPP04dk8`@0CcdU00@0EC/P05Lm8P1I?b@0
Fd4V0`1M@bP00`1L@RL0HD8V06529P0206119@0506939`1TABT0IdP/06M8;01XBBd00`1WBRP206Q;
:@<0JD`Z00@0KTdZ06m>:`1`Cb`0LE0]0P1bDBh207=B;`80M5DY00<0LU8Y075A:P1`D2X00P1aD2d0
4P1bDC00LU4^071?;01/CRX0J4`W06A:9@1RBR@0HD/T069<9@1QBBL0HdTX06E;:01YCBP0K4hX06i>
9`1_CBL0KdhU06a<9@<0KDdV0`1^CRL02@1_CbP0Kdh]06i=;01ZC2X0IdXX06989@1OAb<0GDLR05a6
8@050694:0<0HdDY00P0J4TZ06I9:@1UB2P0HTPW05m79@1MAR@0FTHS05U58P<0G48W:oooool002[o
oooo0P2VNdP20:MlB@@0Z7e:202SMdH30:=h@@030:Ai@P2UNT<0YGY30080YW]4202UNTD80:MlB@08
0:IkB02UNTL0Y7U60:=hA@2TNDH0YGY70:MlB@2XODX20:QoB`80Ygi:0P2VODT20:ElB0P0Z7m;202[
PTh90:Z0CPP0ZH1<102ZPDd40:^2CPP0ZH1<00X0Z7i<0:MmB`2VO4X0YG]90:=iA`2RN4H0XGM50:1f
A02NM4@0WgE50P2PMTH01@2OMDD0WG=309]a@@2IKcl0Vg130080VVm200H0VFi109M/?`2FJch0U6Tl
09=X>`2AJc`2091Z>`0508mY>P2>J3T0SFLh08eW>02<ISL00P28HcH01027HSD0QV4d08IQ=025H3<2
08AO<P80PEl_00@0P5h`07mM<01nFc40OEXb0P1lFC<0201mFS80OU/c07iK<`2<JD40WW]C095^AP1j
Ebl0Me@/0P1bDR/2075A:P04071@:@1_CbP0KdlX06m?:0<0L4l/0P1_CR/306i=:P0607=A:`1dDR`0
M58/07EC;@1fE2h0MeD_0P1hES0207aI<`0607]H<01lFBl0OE/^081N<022H300Q68b0P22HS401024
HS80QV8b08IR<P28HS<208YQ<`0;08QR<`29Hc@0RfDf08aV=`2=IcP0S6Hg08]U=P2:I3D0S6Hg08]U
=P2:I3D00P29Hc@00`2:I3D0RfDf08aV=`0808eW>080SfTj0P2>J3T308eW>080S6Hg00<0R68c08US
=029Hc@00P2:I3D208]U=P0408aV=`2<IST0S6Hi08aV>@80SFLj0`2>J3/00`2AJc`0T6Xk08iX>@02
08eW>00308iX>@2@JS/0TF/l00<0SFLh0P2<ISL308]U=P@0SVPi1P2=IcP408aV=`80RfDf0P2<IcX0
0`2;IST0RVDh08UT=`0208QS=P0308MR=@2:ICP0RVDh0080RF@g0P28HcH208MR=@80QV8b0`27Hc<3
08QT=00308UT=`28HcH0QV4d00<0Q5lb00<0QF0c08IQ=023GS403`23GS4207mL<P<0OU/a0`1mFS02
07iK<@0407eJ<01lFBl0NeP^07YG;@80NEH/00H0MUH]07EE;01eEB`0M5@[07=C:P1bDRT2075A:00F
06mA;@1]DB`0K50[06Q>:@1VCRP0HddV061=9@1OC2@0ET<R05A48`1B@R40D44R04do8P19?R80AcdR
04Hl8@13?BL0@S`V044k9@10>R@0?cTS03dg8@80?3HP00H0?CDR03`d8@0j<b00>3<O03@b7@0a<1/2
030_6P0502h`6P0];R00;2dO02X[7@0X:A/00P0W:1X00`0X:A/0:BXL02HW7`0202DV7P0302@U7@0S
91`08R<K00808B8J00<08B@M01lR6`0N8AX00P0M81T00`0N8AX07b8K024T7@0801hQ6P@08B@M00@0
82<L01dP6@0J7AH06A`E200L7Q/01@0K7QL071lH01`O600M81T07b8K008082<L00H08B@M02<V6`0T
9a`09RPM02PX7P0[:1l202hZ8@0?034Z8P0/:AX0;R/L034]8@0b;R80<2`P02dY7P0Z9Q/0:2@I01lP
600P8AT08B8J02<T700T9Ad09BHN00@09RLO0P0U9Qh202@U7@808b@L00<08R<M024R700Q8Q`00P0Q
8Q`3020Q6`08028U7P0Q91d082<L01lR6`0N8AX07B0I01`O600K7QL201dN60807QlI0P0O81X2020Q
6`808b<K01009b@K02/W7P0_:1h0<b/P03@/7`0f;200?BhG048d6P1=?200G4TY06iG=@1nIch0Rg=7
09AiC02BLd@0VWY70P2VPDd0302FM4L0Le/g04do9@0b:aP0=BPR02hW7`0U9a`07bTN024[8P0U:R<0
:RHS02/S8@T09RTR2`0Y:R@302PY8`809bPR00<0:b`T02X[8`0Y:R800P0X:B40100Y:R80:b`T02`]
9@0^<282030a8`0;03<a900e<BD0>38V03Ta9P0j<RL0>C<W03Xb9@0k<bH0?C@U044e9@13=RD00P16
=b@03P19?R`0BChZ04/n:`1?@2/0DD4Z05=1:@1D@bT0Ed<Z04dn:`1=?RT0CchZ054o:@1A?bL0E40W
0P1F@BH02`1F@RL0E4<W05=2:01@@2L0CSlX04Xn:018?BL0B3dY04Xm:P19?2T0B3/X0080AcXW01/0
B3/X04Tl:@1:?BX0BclY04a0:01?@BL0DD4W05E19P1F@B@0FD8S05U28P1PB2H0HTXV06I<:@1YCbX0
Ke</07=F;P1gEbh0N5P_085U=P1oHSH0Nf0e07EL=01^ES@0Ie0a05m:;@1LAb`00P1FB2d02`1EAb`0
E4H[05E7;01FB2d0EdT^05Q:;`1FA2`0EdD]05Q6;P1IAbl0FTP`00<0FdTa00X0GTT^061;;P1VCc00
K5@b079H<`1iGCD0OF8g081S=`1oJSD0Pfhi0P29LSh07027L3`0R6hk08Y`?@2=Ld00PF/l085Y>@22
JcT0QF/h08Q]>02=L3P0TG8i09=d>`2GLC<0V74f09Qd>02HMC/0V7Dm09Ie?`2CM3h0TW<m08]_@02;
K3h0RFXk08UY>02;JSL0T6`h09A_>`2FLC`209Mb>`0<09Ic?@2DLch0TG<o08]a?P25Kch0PF`m07aZ
>P1fGcd0M5hi079J=P1_Ec<0KED_0P1^E2l02@1_EC00Ke</075D;01cERh0MeL^07]J;`20GS40Q5lb
08IQ=00407eN<0@0O5d_01/0OUd`07iN;`20GS00Pel_08EQ;`28Hbl0SFDa08iV<P2BJc80Tf`c099^
=02BKcD0TFhf08a/<`29JS40QfPa08aW<`2@JcL0U6lk09=^>P2@JcL0SFPd08iY=@2@JcL0SV/c091]
=@2CL3P00P2ELSX00`2CL3P0T6de08m/=00608YY=P80RFPe0100QFLe08AV=024IS@0Q6Hd08EW=@27
JCL0RV`j08]]>`2CKST0Tg0j09Aa>`2CLS`0TW<l091c>`2<LST0Rg4h0P29JS/208QY>P<0QfPi00@0
QVLh08MY=@28JSH0RV`h0P2;KCT0202:K3P0R6Xf08MY=@27JC<0QVPb08IX=025IcD0QFHg0P25ISP0
1P25ISX0PFHk081U>P20ICX0Of@i07iS>080O64f00T0Nf0e07eK=@1mFcD0Ne/d07QK<`1gFc<0M5/b
07=J<@1bFc400P1cEc02079F;`05075E;P1`E2d0L5@]071D;@1]Ebh00P1/ERd206]E;0<0JU@[00T0
I5<X06EC:`1SE2d0HE</05eA:`1GCBT0DTPU04i68P1KC2/00P1IBRT01P1GB2L0EDHU05A5901DAB@0
EDHU05I79P80FdTS00@0G4XT05i<9P1OCBL0H4hX0P1QCbT0201UEc00HeD^05i@:`1IBbP0E4DT04m0
8@1<?Ah0BS/N0P1:?al304Tn7P<0B3dM00@0ASlS04@m8@11>Qh0?SLK0P0m=QX00`0o>1`0@3TM03Xi
7@0703Xi7@0303hj7`0m>Ah0?3PM0080>cLL00<0?3PM03hj7`0o>b000P0n>Ql203di7P80?3PM0P0k
=a`0200e=al0=3HN038d700a<a/0<38J034c6`0b=1`0<cDM0P0^<A`202d`6`80;2lJ0P0[;QT01P0/
<1T0;2lJ02`_6P0/;a`0;2lN02`^8080;2hQ00<09bXI02P[6P0Y;1/00P0Z;A`00`0Y;1/0:2/J02LZ
6@0202PZ700602HX6`0T9Q/08R<K020Q6`0O81X07QlJ0P0M7a`201`N6`0301/M6P0J71T06Q`I00<0
6Q`I0P0I6aP201PJ5`805aTF800G6AP901TK6P805QPG0`0G6AP301PJ6@P06A/J600G6AP`01HH5`P0
5ALF200F61L801DF60<05ALF0P0F61L;01LI61006A/J0P0G6AP301PJ6@806A/J2P0J71/801/M6P<0
6a/I0P0L71X301dM6`8071`J0P0M7A/201hN70X07alM200P8A/8028R6P809B0J00H09R4K02LR700X
8ad0:B@N02XU7`0[9R0302LS6P<0:2@K0P0Y9A`01P0^91X0;bDK02lU6`0`9Q`0<BLM038X7P80<bTO
100f:Qh403L[7`0803HY800g:al0=b/O03P/7P0j;Qh0>c0N03/`700l<Ad403X^7P@0>blO0P0j;AX2
03/^6`<0?2lL00@0?C0M03d`7`0m<1l0?C0O100n<B00100o<R40?blO03l_7`0o;al2040`80<0@C4Q
2013<R001012<Al0@C0N044`7P11<1h2040_7@80?bhL0P0o<R4403ha80<0?C0O200l<Al3040_7`<0
@C0P0P12<B42048a7`80@c8P0`14<b401015=280@S<N044b7@11<Qd2040a7080?c0K00<0?RlJ03lb
7`0o<Ql01P0o<Ql0200l=1l0?S<O03ld8010<b00@c@Q04@c8@15<R40AS<R0P16>1h01P17=ah0B3HN
04Tg7`1<>200CCLP04hh8@80Dc/O0`1D?20305Dm8@80FcdQ00@0G3hR05do8`1N@2@0Gd4U0P1P@RH0
201RBBX0HdPZ06=9:01VBBL0J4XX06]:9`1]BbH0KT`W0P1[BRL0101/BbP0KD`Y06e<:@1^CBX206m>
:`80K50[00<0KDl[06m>:`1`CR/00P1aCB/00`1cC2/0K4/X06a;:00206a;:0L0KD`Y0P1/BbP306]:
9`P0IdXZ00@0ITTY06E8:01TAbL0I4LW101SARH00`1SAR@0IDPV06Q;:@0206]>;00306Y=:`1WBRP0
IDPV00<0HdHT0P1TAbD306E89P80I4LW00<0HdHV0654901P@b<00P1O@R80201N@B40GD0P05m28P1O
@R80H4<S0654901RABD0HdHV0P1TAbL205e69`0405i59`1N@bH0H48V06529P80HT0U00H0FD8S05Y3
901K@R@0GD8U06129P1R@bL206E3:080HdDY00@0HT@X06539`1P@RH0H48V0P1O@BD2060n8`0405dn
8P1L?R80FChQ05Ln8080EChO0140GclV05m0901P@BD0HT<V06=49@1TAR@0IDLS06I8901ZAbT0JdPZ
06Y9:P1WB2T0I4LW05i48`1K@B00F40N05e3:00205a29`80Fd4V0P1J@2D02@1I?b@0E3XO05@j7`1E
>b00ES`Q05Lm8P1I?b@0FT0U05]19P0205i17`0?05i18@1O@R@0H48V0653:@1RA2X0HT@/05@o8P1E
@2<0F40T05Y09@1L@BH0H48X0653:@1R@RT0GT0V0080G44V00D0FT0U05U19@1F@B@0E44S05=08P02
05Do9`80E3hV0`1C?BD01@1B?2@0E3dN05@m7P1D?200E3`R0080Dc/S0P1C>R@01P1B>Qh0DSXP04lj
7`1<>1l0BCLO04Hf7`80A3DP00<0@c<L04De7P18>2400P1:>R<02019>B80AcLP04De7P16=1`0AcDM
04Xh801=>b<0CcdU0`1@?RH0101E>b00ES`Q05To901K@BH205a29`0405]19P1J@2D0Gd4U05m19@80
GT0T00D0Gd4U06539`1TARX0I4HZ06E7:`0206=69P0406A79`1UB2P0ITTY06I9:@80IdXZ00@0Jdd[
06a>;01^D2h0Ke4_101`DS001@1`DbT0Ke8X06mB:P1^D2X0KU0/0080KDl]0140KDh_071?;P1^CB`0
JT`Z06I99`1RB2D0HDTU061:9@1QBbH0HDPY06=8:P1UBbX0J4/Y06]=:@1^CRP0KddW071>:00606Y<
9P80JddW0P1/Bb`01`1XBBX0IDPX06579P1NAR@0G4DS05]48P1SABT00`1RA2P306539`0906129P1V
AbP0IDPX06A79`1PARD0GTHT05a58`1IAB80F4@Q00<0GD@V:oooool002[ooooo0`2VNdP20:MlB@<0
Z7e:202SMdH30:=h@`@0Y7U42@2UNTD90:IkB0070:EjA`2TNDH0XgQ50:AiAP2UNTL0Yga90:QmBP03
0:QoB`80Ygi:0`2VODT80:QoB`P0Zh9>2@2YOdd80:V0C0@0Zh9>102ZPDd80:V0C00:0:QnC02WOD/0
YWa:0:EkB@2TNTP0XgU70:9hAP2QMdD0WgE30:1fA080XGM500X0X7I409id@P2LLT00VW0n09ab@P2K
LD40VW1009Q^?P2GKCd0UV`l0P2EJc/2095[>P04091Z>@2?JCP0SVPg08eW=P80S6He0P28HcH01027
HSD0QV4d08IQ=025H3<208AO<P80PV0`00@0PEla081N<@1oG380OU/c0P1mFS@02@1kF300O5Ta07]H
<028ICd0VWM?08i[@`1gE2`0M54Y079B:`04075A:P<0L50Y00@0LE0]071?;01`Cb`0L4l/0`1_CR/0
1`1^CBX0LE4[079B;01bDR`0Le<]07AD;P1eEBl00P1fES00201lFC<0NePb07]H<01kF2h0O5X]07iL
;P21Gbl0PV0`0P22HS401023HC40QV8b08IR<P27HC8208YQ<`0;08QR<`29Hc@0RfDf08aV=`2=IcP0
S6Hg08]U=P2:I3D0SFLh08aV=`2:I3D00P29Hc@00`2:I3D0S6Hg08eW>00808eW>0<0SVPi0P2=IcP4
08aV=`@0RV@e102;ICH0102<IST0SFLj08eW>P2=IcX308iX>`0408mY?02AJcX0T6Xi08mY>080SFLf
00<0SfTh091Z>@2AJcX00`2=IcP208aV=`<0RfDf2@2>J3T208eW>080S6Hg0P2;ICH01P2:I3D0S6Lj
08aW>P2;IST0RVDh08UT=`80R6<f00<0Qf8e08UT=`29I3L00P29I3L408QS=P80QV8b0`27Hc<308QT
=00808UT=`28HcH0QV4d08EP<`24Gc80QF0c08IQ=027HSD808=N<@P0PUd`0P1oG38307iK<@D0OEX`
00@0O5T_07]H;P1kF2h0NUL]0P1iER`207EE;00307AD:`1cDbX0LU8Y0080LE4X00L0L50W06i@:P1]
DBX0K50Y06U@:01VCbH0I4hU0080HDhT00h0FDDR05Q5901DA280DT8Q04m08@1<?R40BChR04Pm8@15
?BP0A3`W04<k9P12>RD0@3PS03lg8P80?SHQ00H0?c@R03hc8@0l=240>C8O03Lb7P0d<Qd203<a7005
034`6`0^;b40;BhP02//7P0Y:Q`00P0W:1X01`0X:A/0:BXL02HW7`0V9al09BHN02@U7@0S91`00P0R
8a/0100Q8QX08B@M01lR6`0N8AX201dP6@0301hQ6P0O8Q/08B@M00P07R4J00P082<L024T7@0Q91d0
8B@M020S700N8AX071lH01XM5PP071hK0P0K7QL0100L7aP07B0I01dP6@0N8AX201lR6`808RDJ00l0
92HK02LW7@0[:1l0;BTP02hZ8@0a:R80;2PM02dY7P0^:Ql0<2`P034]8@0`;200;BXK02/X6@0P8AT0
0P0Q8QX00`0R8a/08b@L02DV7P0402HW7`@09BHN0P0T9Ad202<T7P808R<M00@08B8L020Q6`0P8A/0
824K0P0R9Ah0100Q91d082<L01hQ6P0M81T201`O60@07QlI100O81X0800Q8Q`08R<M02@T700X9A`0
;2PM030Y7`0a:al0<b/P03H]700k<1h0ACHO05919@1SCbh0MUhh08M[@`2@LdT0U7U<09EgA@2LMd<0
YGa80:=mC02?KdH0Je@d04hm8@0n;280<bHM02DS5`0M9AP07bTN02DZ8`0X9b<0:b8S2@0V:B8802TZ
9080:R/U0`0Y:R@302PY8`0302`]9@0[;2@0:BXR0080:2TQ00T0:BXR02X[8`0[;2@0;BlR02h^8P0_
;b<0<S0T03@`9@0g<2H00P0i<2L05P0k=BT0?CDX03hf:@10=bP0A3PX04Hi:019>RL0BS/X04Tl:`1:
?BX0CCh[04ln:P1B@2X0Dd4Y05I2:@1G@BT0CSlZ04ho:01@@2T0DT0X05=2:01F@RL205Q39P0705Y5
:01HABL0ED@X05A3:@1A@BP0Cd0Y04a0:00204/o:@0G04Xn:018?2H0Ac/U04Lk9@18?2H0BShX04/o
:@1?@BL0D40W05109P1A@2H0DD0T05A09@1D@B<0ET4T05i79`1OB2H0HTXV06I<:@1[CbX0KU8[079E
;@1cERh00P23HSD03P21HSH0O5lg07IJ<`1_EC80JE4_06E<;@1LCC00FT/^05Q9;01GB2/0ETLZ05M8
:`1IBRd0FT/^0P1HAbd205U8;P0R05Y9;`1KBS00GD`b05e<<P1MB2d0GdX]06E>;`1ZDS00L5Ha07MK
<`1kH3D0OV4e07eR;@22Ic80Qfhh08Q_>@27KSP0Q6dg08E^>028LC/0PV`k089Z>P22JcT0Q6Xi08M[
>@2<KSX0Sfll095a?P2FL380Ug0e09Mc=`2HMC/0V7Dm09Ie?`80Tg@n00P0S71108a]?`29JS/0RFTh
08]Z=`2@K3P0UG0l09Qc?P80W74j01D0W7<m09Ud?@2HMCl0U7Dn08ic?02;LSX0Qg4h07mV?@1mI3/0
NV4h07EN=01cG3<0LEXa06mI<01^F340KU@_075E;P1bERl0M5L_07IF;@1hEb`00P1iEbX207YK;`@0
Ne``0P1lGC408P1nGC80OE`_07iL;`20Fbh0PUh^08IP;`2;Hc00SFDb095Y=@2AJS<0T6/d08m/=02>
Jc40Rf/`08QZ;P27JBd0RV@c08iX=`2BK3/0TF/j08eW=P2:I3<0RfDd08eW=P2<JC40SV/c095^=P2C
L3P0U74i09=`>02BKcL0T6de08e/=`2<JcH208]Z=@@0RVTd0140R6Pe08MW=027Ic@0R6Pe08UY=P2<
K3T0SVhk091`?@2HL3`0Ug8m09Md?P2HMCl0UgI009Ef?`2BMCd0TG@l08e_>`0308a^>P80Rfdi0P2:
K3P00`2<KCH0SFhg08i_>00208m`>@0308i_>02=KSL0S6df0080RF`d00H0R6Xd08QZ=P27JCL0QVLh
08EV=`24ICL207mT>@80OV<h00d0OF8g07aQ=P1kH3D0Nf0e07]I=01jF3<0N5Pb07IH<P1dF340LEP`
071G;`1_F2l0L5@_00@0Ke<^0`1^DRd406]E;P80JU@]0P1YDb`02@1RD2P0He4[065B:`1PDRd0G4l/
05I<:@1AARH0CD@S05]<:`0205U::@0605M89`1EARD0E4DT05A5901EARD0ETLV0P1KBB<03P1LBR@0
GT`V05m=9`1QCbT0HU0Z06=A:`1SEC00H58]05]=:P1EARD0D44R04dn8@1:>ah0BSXP0P1:?al304Tn
7P<0B3dM00P0AChR04<l8010>Ad0?SLK03df6P0n=a/0@3TM044j7PP0>STM00<0?SXO03di7P0k=a`0
0P0j=Q/00`0k=a`0?3PM03di7P0303di7P80?3PM0`0k=a`0200e=al0=3HN038d700a<a/0<38J034c
6`0b=1`0<cDM0P0]<1/402`_6P80:bhI00H0:blH02/^6@0[;QT0:bhK02/^7@0[;Al202/]800302HY
600W:QT0:B`K0080:RdL00`0:B`K02LZ6@0V:AP09RPK02DW6P0T9Q/08R<K020Q6`0O81/07AhI01dM
6`0L7Q/401/M6PD06Q`I0P0I6aP201PJ5`805aTF800G6AP901TK6P805QPG0`0G6AP301PJ6@P06A/J
600G6AP`01HH5`P05ALF200F61L801DF60<05ALF0P0F61L;01LI61006A/J0P0G6AP301PJ6@806A/J
2P0J71/801/M6P<06a/I0P0L71X301dM6`<071`J0P0M7A/301hN70P07alM200P8A/8028R6P0402DP
6P0V8A/09R4K02LR7080:2<M0P0Y91h202HR6@<09b<J0`0X91/202hT6P0302lU6`0`9Q`0<BLM0080
<RPN00@0<bTO03@X700e:Ad0=BTM0P0f:Qh203L[7`0903P/800f:B00=b/O03L[7`0h;1h0>BdM03X_
7@0j;a/0>c0L00@0>2lP100g;Ql0100i;1T0>RdJ03X]6P0j;AX203/^6`80?2lL0`0l;ah00`0m<1l0
?S4P03ha800203lb8@<0?2lN0P0m<1l303ha80P0@c8P0`14<b4204<b80<0@S4O0`0n<B0403d`7`80
?2lN200k<1h203l^7P<0@2lO0`11<2001011<1h0@S4O048a7`12<Al204<b8080A3<Q0P0n<Ah403d`
7@80?2lL200o<Ql01P0j=1h0?3@O03`d7`0n<al0@3<P048c8080A3<Q00H0ACLM04Hh7P17=ah0BCLO
04Xh801<>20204dg8080Dc/O0`1D?20305Dm8@80FcdQ00@0G3hR05do8`1M?b<0GT0T0P1O@BD01P1P
AbP0HTLY06=9:01VBBL0J4XX06]:9`80K4XU0P1ZBBH0101[BRL0K4/X06e<:@1^CBX206m>:`80K50[
00<0KDl[06m>:`1`CR/00P1aCB/00`1cC2/0K4/X06a;:00906a;:080JdXW0`1ZBBH806I9:`@0I4LW
0P1SARH01@1RABD0HD@T06958`1TAbD0ITTW0080J4/Y00<0IdXX06I99`1TAbD00`1RAB<206=690<0
I4LU00D0I4LW06=69P1RABD0HD@T06138`0205i18@80GD0P0P1N@B40101O@R80H4<S0654901RABD2
06=69P80G4DV00@0GD@V05i39P1O@BD0H44U0P1Q?b@01P1I@R<0FT<T05]2901M@RD0H48V06939`80
ID<X0P1RA2P0101Q@bL0H48V05m19@1O@BD205i09006060n8`1O?B80GChR05/m8@1H?B00ESdO0P1D
?Ah01P1N?RD0Gd0T06119@1Q@RD0HT<T06A69080IDLS0P1ZAb/01P1YAb/0IDHY06959`1M@R@0FSlQ
05Po80@0FT0W101I?bH01P1C>Ah0E3XO05Dk801G?B80F3hS05To9080FT0U0P1L?al00`1M@280Gd4U
05m19`020612:P0?0611;01C?R40E3lR05Lo8`1I?b@0Fd0U05m19`1P@RP0HD4X05e1:@1K@BP0FT0W
05Q09P1E@2D0DclT0080D3lS0`1B?RD2054m90<0D3`S0P1B?B02054l8@0:050j8P1@>R<0CcTT04li
901?>Qd0CcXO04di7P19>1h0AcLN04@e7P80@CDO00`0@S8K04@d7@17=b00BCTR04Xj8`18>240ASHO
04De7P17=Ad0BCLO04/i8@1>?2@3050n9P0604lm9@1E>b00ES`Q05Pn8`1J@2D0Fd4V0P1J@2D00`1I
?b@0GD8U05a1900205]08`0;05a1901M@RD0H4DX0615:01QART0H4<U06549P1RABL0HdHX06A7:@1U
B2X00P1VBB/0201WBRP0JD`Z06a?;@1^DBl0Ke8`06iA;`1]D2h0K4l]0P1/D2P05P1/D2T0K50[06]>
;01[CR`0JTd]06Y=;`1]C2/0K4/Z06M99`1TAbD0HDLT05m78`1OBB@0H4XU0658:P1RAbX0HdPZ06I9
:@1XBRP0K4/X06i<9`1_CBP606Q<9`80Id/V0P1ZB2`01`1VAbX0I4LY06159`1MA2D0Fd@T05Y38`1R
A2P00`1Q@bL306129P0705m19@1UARL0HdHV06959@1OAB@0GDDS05Y38@0205M380<0GD@U:oooool0
02[ooooo0P2TNDH20:EjA`<0YW]800<0Yga90:=gAP2SMdH01P2SMdH80:=hA@P0YGY52@2VNdP0202U
NTL0Y7U60:=hA@2TNDH0YGY70:MlB@2XODX0ZH1<0`2XOd/20:MnBP80YWe9202XOd/30:^2C080ZX5;
0`2YP4X90:UoC@P0ZH1<00@0[8=?0:^2CP2[PTh0Zh9>0`2ZPDd90:V0C080Yge;00<0YWa:0:EkB@2T
NTP00P2SNDL03@2RN4H0X7M30:5hA02QN4@0XWU50:5hA02OMT80WGA009]b?P2MLd40W79009Y`?P2H
KS`0102FK3X0202BKCT0TF`h091[=`2?JSH0SVTe08eX=02<Ic<0RfHb0P28HcH01027HSD0QV4d08IQ
=025H3<208AO<P0608=Q<@22H300PV0b085O<P20GC<0Oe`d0P1nFcD0201jEbl0NeP`07QE;@22GcL0
T6e508AQ>@1cD2P0MU<[201aDBX8071?;00606i@;01_DBd0Ke4]071B;P1aDbl0LU@`0P1cEC40201l
FC<0NePb07YG;`1jEbd0NeT/07eK;@1oGBd0PEl_0P21HC004@23HC40QF4a08IR<P27HC80RF0b08YQ
<`28HS<0RF<d08]U=P2<ISL0SFLh08aV=`2;ICH0RV@e08iX>@2<ISL0RF<d0080R68c00<0RF<d08aV
=`2>J3T0202=IcP208iX>@80SFLh102<ISL00`2;ICH0S6Hg08aV=`0608aV=`P0SVPk00<0T6/g08mZ
=P2>JCD00P2=J3@00`2>JCD0SfXf091[=`0308eW>080S6Hg0`2;ICH0102<ISL0SFLh08eW>02=IcP3
08iX>@0408mY>P2>J3T0SVPi08eW>080S6Hg00<0RfDf08YT=@2:I3D00P2<IcX00`2;IST0RVDh08UT
=`0208QS=P0308MR=@29I3L0RF@g0080RF@g1028HcH208IR<P<0Qf<c0`28I3@00`29I3L0R6<f08IQ
=00208EP<`0308IQ=027HSD0R6<f00P0Q5lb2022GC0207mL<P<0OU/a1@1mFS000`1lFBl0NeP^07YG
;@0207UF;00707QE:`1eEB`0M5@[07AD:`1cDbX0LU8Y075A:002071@9`0606iA:@1]DBT0K50X06U@
9`1WD2H0IE0U0P1RCb@0401LB2<0FdLT05Q68P1DA280DD4P04ho801<?R40BcdP04Pm:@17?2P0AS/W
04Dj9P13>2@0@SLS044f8P10=B42040c8P0403hc8@0k<b00>C8O03Lb7P<0=38M00H0;c0R02h_8@0[
;1h0:BXL02PY6`0W:1X202PY6`0602LX800V9al09RLO02DV7P0T9Ad08b@L0P0R8a/00`0Q91d07b8K
01hQ6P0201dP6@0301hQ6P0O8Q/08B@M00P07R4J00<07b8K020S700Q91d00P0Q91d00`0P8a`07R4J
01dP6@0801`N6`<06ahG0P0L7aP301dP6@0@020S600Q91T08bDJ02HV700Z9ah0;BTP02hZ8@0a:R80
;RTS02`X7`0[9ah0;BTN030/800b;b00<BhM02l/6`8092DM0`0S91`00`0T9Ad09BHN02HW7`0302HW
7`D09BHN0P0T9Al00`0S91h08R<M024R7002020Q6`0601lP6P0R9Ah08B@M024T7@0P8a`07b8K0P0N
8AX00`0M81T07QlI01hO6@0201hO6@@07b0J02007b4L020R7@0R8ad09BDM02TV7@0/:1d0;BTN030Z
7P0d;R80=blR03ld8P1;>b80FTLY06eE<@1mHCT0QFPn09N0E02ENDT0VWE10:IkAP2^Pdh0YX1A08i^
A`1gGCX0E3d_04<c900^:1X08BDF024Y7P0V:b@0:BPV02XT9PT09RTR200Y:R@302X[9@80:BXT0`0X
:B<00`0/;BD0:b`T02TZ8P0202LX800902PY8@0Y:R80:R/S02/]8P0];B<0;RhT034^9@0c;bH0=c0X
0080>C0Y01H0>cDY03de:00n=RT0@CPY04Di:@18>bX0Bc`Y04`m:P1:>RX0BS/X04`k:@1??BT0D3hX
05<o9`1E?bL0ET0X04ho:01?@2T0DD4X05=2:01EA2P0F4DW0P1JABH01P1LAbP0FdHW05U6:01FABT0
E4<Y0592:@80D44Z00<0BclW04Xn9P19?BD00P18?2@01@19?BD0BShV04/o9`1B@BD0DD0T0080D3lS
00@0D3lU05509P1B@BL0Dd8X0P1KAbH04P1NAbD0HDTU06E;:01[CbX0KU8[075C;@23GS80PV0c089O
=@21H3D0OUhe07QK<`1bERl0L5@]06=B=01QD380GD`^05Y9:`80FDPZ00@0FdX/05a;;@1IB2h0FDP^
0P1HAbd0;01IB2h0FdX`05e<<P1NCC<0GDP]05i9;01SC2d0J50^06iD;`1dF300Me`a07UL<01kG2H0
PF8/08MY<`28KCH0QF`d089/<`24KSD0QG0g08A^?024KC/0Pf`j08E[>P27Jc/0Rf`m08m_@02@L440
UW0b09M`=@2GLcL0Ug@j09Qe?@2EM3h0Tg@n099c?@2@M4D0Sg1208a]?P2;JcX0SF`i09=_>`2HLcl0
VgI10P2NKcL05`2NLCP0WG<i09ae>P2IMcX0UGDh099f=`2AMCH0RFdm08I[?023J3T0OVHh07UR=P1e
H3D0LEhd071M<`1`F3@0LELb079H<`1dF340M5L_07EE;01eE2T0M5<X00<0N5P_00<0NET`07YJ<@1k
Fc800P1lG3<0201nGC@0OE`a07aI;`1mF2`0OUT/085K;026GRd0RF4`0P2=IC80102;IS40RfP`08]X
;P29JB`208MY:@0D08MQ<P2<ISL0SfTj08mY>P2;ICH0R68c08US=02;ICH0SFXb08i[<`2?K3@0T6de
095^=P2BKcL0Tg0h09Aa>@2?KSP0SVdg08a[=@2;JS@308YY<`0<08]Z=02<JcH0S6/f08]Z=@2<JcH0
SVdh095`>`2DLch0UG@o09]d?@2LMCh0W7M00P2LND400`2HN3l0UWLn09Ef?@03091c>`80Sg8j0`2>
LCT00`2@L3L0TW8i09=c>P0209Ad>`0309=c>P2BLST0T70g0080Rfhd00H0Rfhf08Y/=P28JSH0QFLe
08=U<`21HS<307]P=@80NUld0`1iGS<0201gEC80MU@a07ED<@1bE300L5@_06eC;P1/DRd0Je<]1@1]
D2h306a?;@0A06UC;P1ZE2l0JeD`06]E<01ZE2l0JE<^06QB;@1WDB`0HU0Z069@;01OCb/0G4h[05U<
:P1DBBT0DDHX04m69`1JBbX00P1IBRT05P1GB2L0ETLV05I79P1FAbH0EdPW05Q9:01KBB<0G4XT05i<
9P1OCBL0HDlY06=A:`1TDR`0IE<]05a>:`1JC2T0EdPW05=49@1@@B@0CCdS04/k8@1:>R4204Xo7`<0
BChN0`18?Ad00`14?B40@c`P048k7`03040i7@80@CXN200j>Ad00`0n>Ql0?CTN03/g700203Te6P03
03Xf6`0k=a`0?3PM0080?CTN0P0l>1d303/g700903Xf6`0e=al0=3HN038d700a<a/0<38J034c6`0b
=1`0<cDM00D0;2lJ0`0[;QT01P0[;aP0:RdH02X]600Y;1T0:B`K02PZ7080:2XM00<09BPG02LZ6@0Y
;1/00P0[;Qd00`0Y;1/09bXI02DX5`0202<U6P06028S6`0P8A/07b0K01dM6`0L71X071`L2P0J71T2
01TK608061XG0P0G6AHP01LI60T06A/J0P0F61L301LI60<061XI200I6aXH01LI61005QPG200G6AP@
01HH5a005ALF200F61L801DF60<05ALF0P0F61L;01LI61006A/J0P0G6AP301PJ6@806A/J0P0J71/8
01TK6PP06adJ0`0K6aT201`L6P<07AdK00@06a/I01`L6P0L71X071`J0P0M7A/201hN70P07alM200P
8A/8028R6P0302DP6P0V8A/09R4K00809b8L0`0X8ad302HR6@809b<J0`0X91/01P0]8aT0;R@J02hT
6P0_9A/0<2HL034W7@80<RPN00H0<bLK03@X700d:1`0=BTM03HZ7P0g:al203P/800603LZ8@0g:al0
=b/O03P/7P0h;1`0>BhL0P0i;QX203P^8P80=bdQ100f;200100h:aP0>B`I03T/6@0i;1T203X]6P80
>bhK0P0k;Qd203`_7P0403d`7`0n<B00?c8Q03lb8@<0>RlM0P0k<1h303`a7`P0@S4O0P15=28204@c
8@80@c8P0P12<Al303ha8@<0?C0P0`0l;al803/`7P<0?bhN0P10;al3044`8004040_7@11<1h0@C0N
044`7P80@S4O0P13<R0803/`7PP0?S4N00H0>3<M03Xd7P0j=1h0>c<N03hc7`0o<Ql2048c8080ACLM
00H0B3PO04Xh801;>B40C3PP04dg801<=Ql205<k7`<0E3`P0`1E?B401P1J?200FcdQ05/m8@1L?R80
GClS05i09080Gd4U00P0GD@U05m49P1QAbH0IDPV06Q::01[BRL0K4XU06]99080JDPU00H0JTTV06]:
9`1]C2T0KTdZ06m>:`1`Cb`206a@:`0306e?:`1_CR/0L4h[0080LDd[00<0Ld`[06i=:P1]C2T00P1]
C2T306a;:0@0JdXW0P1ZBBH306U89@P0HdDY00P0HTDU06=69P1SARH0I4LW06=69P1RABD0HD@T0613
8`@0HTDS0P1SAR@206A79@P0HTDS0P1SARH00`1RABD0HD@T06138`0206138`80Gd8R00H0GD0P05i1
8@1N@B40Gd8R06138`1QA2@206959@0605a59P1KA2D0G4<U05e29@1N@2@0Gd0T0P1P?R<205]49@04
05a39@1N@bH0H48V06529P80I48W0P1O@BD305i090<0GClS0P1M>b003P1K?200FS`P05Ll7`1F?Al0
EChO05@m7P1N?RD0GSlS05m0901Q@RD0HT<T06=58`1TAR80IDLS0P1YAB/01P1WABX0Hd@X06129P1L
@B@0Fd0S05U08PP0F3hW00@0EC/P05Hl8@1H?R<0FClT0`1J@2D02@1I?b@0FSdO05/n801M?b<0GT0V
05i0:01N?bX0GChY05`m:@0205@o8P0<05Lo8`1H?R<0FSlT05do9@1N@2H0GclV05a2:`1J@RX0F40X
05@n9P1B?RD0CchT0P1>?R@204hm8`80CC`R0`1<>b405P1;>R00DChP054m8P1@?240Cc/R04hj8P1=
>2<0CCPU04`g901=>Q`0CCTN04Xi7@17=ad0ACLM048f7P11=Al0?c@N04@d7@15=Ah0ASHO04Lg8018
>24204Lg800604Hf7`19=al0BcTQ04dk8`1??BD0D3hV0P1??BD02`1>?2@0E3XO05Hl8@1H?R<0FClT
05Y09@1I?b@0F3hS05Lm8P1K@R@0FT4S00<0FD0R01L0Fd8T05e49P1MA2H0GTDW05m19@1P@RH0HD<W
0694:01SABT0I4HZ06E7:`1VB2`0I4LW06I9:@1ZCBd0K4l_06e@<01/Cbl0JTd]06U<;01YCBH0JThW
06]?:P0206]>;00906U<;01XBbd0IdX/06]::`1YB2T0IDHW06959@1OAB@0GTHT0080GTLU00T0GdDZ
0615:01PABP0HdHX06E69`1YB2L0K4XW06i<:@1XBbT00`1WBRP306I99`0706E89P1XAR/0J4H[06E6
:P1RA2P0Gd@W05a39@0205Y390<0Gd4U1@1P@RH0201TABH0HTDU0654901NA2<0Fd<Q05U2801F@Ql0
ED4N0`1MAB<[ooooo`00:_ooool20:9gA080XgQ50`2TNDH00`2UNTL0XgM60:=gAP0>0:=gAPP0YGY5
202UNTL0202VNdP0YGY70:AiAP2SN4D0Y7U60:EjA`2WO4T0Z7e:0P2YP4`30:QoB`<0Ygi:202XOd/2
0:Z1B@80ZH180P2XOdL20:MnAPT0Z7i<202YP4`20:b3C`80Zh9>0P2ZPDd:0:V0C080Yge;0P2VO4X0
102UNdT0Y7Y80:AjB02SNDL20:5h@P80XWU300P0XGQ209mf@02MM3h0W7<m09id@P2MLd40VW0n09Q^
?0<0UV`j00T0Ufdk09=^>P2BKCT0TF`h08mZ=P2>JCD0S6Lc08]V<P2:IC400P28HcH01027HSD0QV4d
08IQ=025H3<208AO<P80Pf4a00@0PV0b089P<`21GS@0P5de0P1oG3H0201lFC40OU/c07YG;`1mFS80
QV<k07]H<01bCbL0O5Ta101aDBX4079B:`80KTdZ00<0Kdh[071?;01aD2d00`1bDBh206eA;00306iB
;@1_Dbh0L5@_0080LED`00T0LUHa07]H<P1kF380NUL_07UF;01jF2/0O5X/07iL;01oGBd00P21HC00
1022H300QF4a08EQ<@27HC8208UP<P0;08QR<`29Hc@0RfDf08aV=`2=IcP0S6Hg08]U=P2:I3D0SVPi
08aV=`29Hc@00P27HC800`29Hc@0S6Hg08iX>@0;08eW>0@0S6Hg0P2;ICH608iX>@80SFLh0`2@JSd0
0`2?JC`0SVPk08eW>P0208aV>@0308mZ=P2>JCD0SFPd0080S6Lc00<0SFPd08iY=@2?JSH00`2=IcP2
08aV=`H0RfDf00<0S6Hg08eW>02=IcP00P2>J3T01@2?JCX0SVPi08iX>@2=IcP0RfDf0080RV@e00H0
RF<d08aW>P2<IcX0RfHi08YU>029I3L208QS=P0308MR=@28HcH0R6<f0080R6<f1029I3L208IR<P<0
Qf<c0`28I3@00`28HcH0Qf8e08IQ=00208EP<`0308MR=@28HcH0RF@g00P0QV4d2021G2l207mL<P<0
OU/a101mFS0207aI;`0307]H;P1jEbd0NEH/0080N5D[0P1dE2/0101cDbX0LU8Y075A:01aDBP2071@
9`0606iA:@1/D2P0K50X06U@9`1WD2H0IU4V0P1SD2D0201OBB@0GTPS05Y68`1GA2<0DT8Q04m07`1=
?Ql0BchN0P19?2T03018>bP0AcXW04Dh9@14=b@0@cHS048e8P12<R80@3<R03lb8@0n<b40>c<P03Tb
7`80>3<O00L0=c8N030a8`0_<280;2dO02X[7@0X:A/09bPJ0080:2TK0P0W:200100V9al09BHN02@U
7@0S91`2028S6`03024T7@0O8Q/07R4J00807B0I00<07R4J01lR6`0Q91d0200N8AX0200M81T07R4J
020S700Q91d08RDN024T7@0P8a`07b8K200L7Q/401/N5`@071lH01P07b8G020S600R91T09BDK02TV
7@0/:1l0;RXQ030Y8@0a;2P0;2LQ02PT6`0Y9AX0;R/L03<`7`0d<Ah0<c4L02TZ8P0W:2009BHN02@U
7@0S91`092DM02DV7P0V9al202DV7PH09RLO00D09BHP02@U7`0T9Al08b@N024R7002020Q6`0301lP
6P0P8a`082<L00H082<L100O81X401hO6@0P01dR7P0O8Ah08B<N02<T7P0V9Qh0:RLN02`X7`0]:Ah0
<2dV038^8`0h<B40A3DP058n8`1RBRP0L5<[07UI<02;MT/0T7E609]g@`2VNd@0[Wm90:b1CP2ROE00
VWU@079FB01JAcH0?CHT02T[7@0T;1l09b`U02TY9`0Y9BH902HY8PP0:BXT0P0[;2H202X[9@<0:BXT
00@0:2TS02`]9@0[;2@0:BXR0`0W:200400X:B40:BXR02X/8@0[:b40;BdS030]900c;bH0=RlW03P_
:00i<2T0>38V03Xb9@0k<bH0?SDV048f9P15>2L204Tj9`0604Ph:019>2H0BSTW04dk9`1@>bH0DcdV
0P1F?RH204m19`0A0592:01D@bL0ETDW05U69P1KARL0G4PW0619:@1OB2T0G4LX05Y7:@1FABT0E4@Z
05=3:P1A@bT0C40X04/o9`19?BD00P18?2@02`19?BD0BclW04a0:01C@280DSlQ054m8P1??R80CchT
05109P1B@RT0Dd<Z0080FDHV0180FTHU05i79@1QBBD0IT`W06U?:P1^DR/0OUL/085J;`23GS80Pf4d
089Q=P1nGc<0Ne``07MJ;P1/FCT0JEHf06AA<@1OC2`205a9:@0405e::P1NBb/0FDP/05Q7:`80EdHZ
02`0F4L[05Y9;@1LBbl0GTda05e8;@1NBB`0HT//06I>;01[DB`0L5@/079G;01dEb/0OUXV08AP;02:
JC@0Rfdg08Q]=P24KSD0QG0g08Mb>@26LC`0QVlm08E^?027K3d0R6`m08a]@@2?KT<0T6m409Ma<`2H
LCH0Ug<g09Md>P2GM3`0U7<m095b?02@LC/0S71108]/?P27J3T0QVHe08QW=02>JSH0U6lk09Qc?P80
WV/d00D0X6dd09ma=P2MM3H0W7Hg09Uf=00209Ef<`0P091b?P2<LC`0RFll08A/?01nJCX0N6Dj07ET
>@1aHSL0LETe079J=P1eFcH0N5`e07UL=01kFc@0NET`07UH;`1eEBh0MUH_07MG<01hF340NETb07YJ
<`1kFc@0O5`e07iM=01lFc80NUL]07YE:@1jEBP0OELX089I:`24G2/208QP;`0408MR;P27I2`0R6D[
08MX:080QfXX00X0Q5h_08US=02=IcP0SFLh08US=027HC80R68c08]U=P2?K3@0SV/c0P2<JC40202>
Jc<0TFhf09Eb>P2HMCd0TG4h091`=`2=KC@0Rf/b0P2:JS4208][<P<0Sfhi00d0T6lj099a?02EM3l0
V7M209Uh@`2PMcl0XGQ00:5j@@2ONd40WW]109Yj?`2HN3d0UWPl0080TgHl0P2BMC/4095d>P0309=c
=P2DM3L0UWHi0080UgLj00/0UWHi09Ad=`2CLcH0SG0d08e`=P2<KcD0RVde08MY<`23IC40Of4_07eO
;@0407ML<@@0MU/`0P1cDBh00`1aD2d0KU0/06a@:`0206U?:P0306M?:@1ZCBd0JTd]00H0Jdh^00d0
J54_06UB<01ZDc40Je@b06YC<@1YDS00Ie0^06I?;@1SDBd0HDl[05e=:`1IBRT0ETTY0080DTLY00D0
D4LZ05Y;:P1IBRT0FDXY05Q9:00205M89`0905U::@1KC2/0G4d/05e;9@1NC2H0GddW065?:@1SDB/0
IE<]0080IeD_00P0E4HS05A5901DAB@0Dd@U05529@1>?R@0C3`S04/k8P80BSlO0`19?Qh304Pm7@03
048k7`13?200A3dQ0080A3dQ00<0@c`P048k7`11>Qh0200j>Ad01P0n>Ql0?3PM03Xf6`0i=AX0>3@I
03Te6P80>SHK0`0l>1d303/g7080>SHK00P0=CLO03@f7P0b=1`0<C<K030b6P0a<a/0<S@L03<e7@H0
:bhI0P0/;aX01P0Z;QL0:RdH02T/5`0X:aP09RTH02DW6@8092HI00<092LF02HY600Y;1/00P0[;Qd0
0`0Y;1/09RTH02@W5P02024R6P04020Q6`0O81X07AhI01`L6P806a/K2P0J71T201TK608061XG0P0G
6AHP01LI60T06A/J0P0F61L301LI60<061XI200I6aXH01LI61005QPG200G6AP@01HH5a005ALF200F
61L801DF60<05ALF0P0F61L;01LI61006A/J0P0G6AP301PJ6@806A/J0P0J71/801TK6PP06adJ0`0K
6aT201`L6P<07AdK0P0K6aT301`L6P<07AdK200O7ad8020Q6`P08R8J100V8A/402LR70809B4H0P0V
8QT302LS6P0702PT6`0]8aT0;B<I02hT6P0_9A/0<2HL034W7@02038X7P06038V6P0c9a/0=2PL03DY
7@0f:Qh0=b/O0P0h;2001P0g:R40=b/O03L[7`0h;1h0>2`L03P]6`80>2dI00<0=blR03H^8@0f;R40
0P0e;B0203@/7`0403<[7P0h:aP0>2/H03P[6080>B`I0`0j;AX203X]700403/^7@0l;ah0?C0O03ha
8080?c8Q0P0g;a`203P`7@<0>C4N00<0>S8O048a7`12<Al01`12<Al3044`7P80@2lM0P0o;Q`0100n
<2<0?BlR03d_8P0m;b8303`^8@80>bdP200j;ad203h]7@80?bhN0`10;al01011<200@2lM040_7@10
;ad2044`7P<0@S4O100h;ah403T`7`P0?S4N0P0h<ad00`0i<ad0>c<N03db7P0203lb7`04044b7`14
=Q`0ACLM04Ph7`80BcTQ00<0C3PP04`f7`1;=Ah00P1C>al305@l80<0ECdQ0P1J?2000`1K?B40G3hR
05do8`0205i0900705m19@1H?b00Fd0R05i48`1TAbD0IdTW06Y99P0206]99080J4LT00H0JDPU06]:
9`1]C2T0KTdZ06m>:`1`Cb`206a@:`0306e?:`1_CR/0L4h[0080LDd[00D0Ld`[06m>:`1_CR/0Kdh[
06i=:P0206e<:@80K4/X00@0JdXW06Y99P1ZBBH0JTTV0P1YB2D206Q790P0HD<W00l0HD@T06959@1S
ARH0I4LW06=69P1RABD0H4<S05i18@1RAB<0H4<Q05i17`1L?ad0GD0N05m2801RAB<00P1TAbD206=6
900506958`1QA280H4<Q06138@1O@R002@1RABD205e08080GT4Q00@0Gd8R06138`1QA2@0HD@T0P1K
A2D01P1K@R@0G44T05do8`1N?b<0H3hS05lm8P80GDHW00@0GD@V05i39P1P@RH0H44U0P1R@2D405/m
8@<0G3hR0140GClS05/i7P1K>Ah0FCXN05Pj7P1G?1l0ESdO05Dn7`1F?b00GCdT05ho8`1O@2@0H44T
0693901SAB<0I4HR06E78`0206M3:@0606E3:01R@bL0H48V05e29@1L@B@0Fd8T1P1G?BH205Pn9`03
05Pn8`1I?b@0FT0U0080G48W00/0Fd4V05To901H?R<0FC`N05Xl801L?R80GClU05`n9P1K?2L0FCXV
05Pi9@0205E08`0305Lo8`1H?R<0FChS0080FcdS00H0G3`S05a4;01J@RX0EClW058n9@1>?B<204dm
8`0404do901:>R00BSXP04Xj8080BCTO0`18>1h04@1A?B80D3`S050l8`1?>b<0CCPS04`g901<=bH0
BcHU04/j701:>Ad0B3TL04Hh7@12=Q`0@CDM03ld7P0n<ad0ASHO0080ACDN00P0A3@M04De7P16=Ql0
AcLP04Ph8@1<>R80CC/S04lm9@80D3hV00H0CS`T04dk8`1<>R80E3XO05Hl8@1G?B8205To900505Pn
8`1G?B80ES`Q05Y3901I@R<00`1G@240101H@B80FT<T05Y3901KA2D205m19@0V06129P1RA2P0HdDY
06E7:`1VB2`0IdT]05m49P1RAbT0IDX/06Q=;`1YCS00J4d_06I;;@1TBB/0ID`T06I<9`1XCRT0J4h[
06Q>;@1VBbd0I4T/06=8:`1YAb/0IdDY06=49`1P@bD0GT<U05e49@1MARH0GTLW05e3:01N@bP0GD8U
06129P1R@bH0ITDV06Y79`1/BBT206E;:P80I4XY00`0HdTX06989`1RB2L0HTPW06M5:P1VA2T0Hd@X
06539`1N@bH0G4<U05Y3901I@R<205do8`0405i0901O@BD0Gd4U06129P80HD<W00P0Hd@U0654901P
@b<0GD<R05Y2801H@Al0ED4N05A07@<0GTHT:oooool002[ooooo0P2QMT<30:9gA0<0XgQ53@2SMdH3
0:9fA@P0YGY5202UNTL0202VNdP0YGY70:AiAP2SN4D0Y7U60:EjA`2WO4T0Z7e:0`2YP4`20:QoB`<0
Ygi:202XOd/30:V0B0030:QoA`2WOTH0YWe50080YWe52@2XOT`80:V0C0<0[8=?00<0Zh9>0:Z1C@2Y
P4`02P2YP4`20:MmB`80YWa:00H0YG]90:AjB02TNTP0Y7Y80:5h@P2RND<20:=jA0080:9i@`2PMd40
WWDo09ac?@2OMT80WGA009Ya?@2GKSX209I]>@0:09M^>P2HKc/0Tfhi099]>02AK3L0SfXe08iY=02<
Ic80RfHa08YU<080R6<f00@0Qf8e08IQ=026HC@0QF0c0P24Gc801P24HS80Pf4a08=Q<`22H3<0PEhd
081M=@80Oe`f00P0Oe`d089O=`1lFC40O5Ta081M=@1fDb/0LTlW085N=P<0LE4Z1@1bDR/02@1]C2T0
KTdZ06m>:`1`Cb`0LE0]079A;P1cDRl0M5<`06a?;@0206e@;P0306iA;`1_DS00L5<a0080LE@b0P1k
F3801P1jEbl0NEH/07YH:`1lFR`0OU`/07mM;@80PF4`00@0PV0`08EQ<@25HC40QV0a0P29H3802`28
HS<0RF<d08]U=P2<ISL0SFLh08aV=`2;ICH0RV@e08mY>P2<ISL0RF<d0080Qf4b00<0RF<d08aV=`2?
JCX02`2=IcP208aV=`@0RfDf0P2@JS/408mY>P80SVPi00/0TV`o095[?P2@JSd0SfTl08iX>`2=IcX0
S6Hi08]U>02>JC@0SFPc08aW<P0208]V<@0308aW<P2=J3<0SVTd00<0SFLh0P2<ISL308]U=P0408US
=02:I3D0RV@e08]U=P80S6Hg0P2=IcP208mY>P0408iX>@2=IcP0RfDf08YT=@80RF<d0P2<IcX00`2;
IST0RVDh08UT=`0208QS=P0308MR=@28HcH0R6<f0080R6<f1029I3L208IR<P<0Qf<c0`28I3@02028
HcH0Qf8e08IQ=025H3<0QV4d08MR=@29I3L0RVDh2027HSD8085L;`80Oe`b0`1nFc4307eJ<080O5T_
0P1kF2h0101jEbd0NEH/07QE:`1hEB/207AD:`0307=C:P1bDRT0LE4X0080L50W00L0KdlV06iA9`1/
DBH0K54V06UA9@1XDBD0IU4T0080He4S00h0H4XS05m9901KAb80FDDR05E28@1@@1l0CChO04`m7P1:
?BX0BC`Y04Pk:017>RL0ACPU04@g9080@cHS0P12<R801010<b80?S<Q03/c800j<b0203Tb7`0503Pc
7`0a<R@0;c0R02`]7`0Z:ad0100X:A/202LX800302HW7`0U9Qh092DM00808b@L00@08R<K024T7@0O
8Q/07R4J0P0M81T00`0N8AX07b8K024T7@0801hQ6P0401/N5`0M81T07b8K024T7@<08RDN00<08B@M
01`N6`0L7Q/01P0L7Q/601/N5`8071lH01@07R4F01lR5`0R91T09BDK02TV7@0/:1l0;RXQ030Y8@0c
;R/0;2LS02HQ6`0V8QL0;BXK03<`7`0f=1l0=C<N02`]9@0Z:b<09bPP02DV7P8092DM00@09BHN02HW
7`0U9Qh09BHN100V9al202LX80809BHP00<092DO02<T7P0R8ad00P0P8A/0100O81X07b8K01lR6`0O
8Q/2020S70<08B@M100O81X401hO6@0P01`Q7@0M8Qh0828M02<T7P0U9Ad0:BHO02XW7P0/:1l0;2/V
02l/9@0e;B00?S4N04`h7@1J@R00ITPR06i>9@1hIC/0R6e009Yf@P2VND00Z7Lo0:IhA02WOU00ZXEI
08Q[F@1^FDP0BT8_030c8P0W;b80:2dV02TY9`0Y9BH902HY8PP0:BXT0P0[;2H202X[9@@0:BXT00H0
;2dU02//900Y:R809bPP02HW7`0W:20202PY8@0P02TZ8P0[:b<0;2`T030]9P0b;BL0=RlY03P_:P0i
<2/0=2hR03H^8@0g;b80>c8S03lc8`12=B@0ACHS04Hg9018=bL0B3LU04Xg9P1>>BH0D3XU054k901D
?2@0ECdU04m19`1@@RL0DT8X05E4:01FABL0FTLW05a89`1MBBP20619:@0905e8:@1LAbX0FDDZ05I5
:`1DA2X0Dd<Z04a09P1;?bD0BCdS0080B3`R00/0BCdS04/o9@1<@2H0E3lP05<n8@1@?Al0CSdQ04ln
901@@2L0DD<Y05=4;@0205Q59@0B05U5901LABD0H4PV06A<:01XCRT0Je4/07eD:01nEb`0PU/`08EP
=024HSD0PV4d07mP<P1mGS00L5dm06aI>@1VDc<0HDh^0P1MBRX0101NBb/0Gd`/05Q7:@1GARP205I5
9`0/05M6:01IB2X0G4/]05e<;P1MB2d0GTT/069;;01UCB/0JDlZ06eA:@1_E2T0LE@X081K9P27HRd0
SV/e08i_>02;LCP0Qg4g08Mc>028MCX0Qg8m08M`?026Kcd0R6dn08U/@02<KD40Sfi5091_AP2HLS@0
VG8g09Qd>02GM3X0Ug@l09=b?02@LC/0Sg0j08AX>@23I3H0Of0a07eM;01oGR/0QV8^08aW<`2@JcH2
09eY<01309m[<P2OKS<0WW8e09ed=02KMS80V7L`09Mf;`2CM3d0TG<m08eb?@27L3h0PF`m07aZ?01f
Ic`0M6Dj071I=`1cFcL0MUhj07YP>`1nHS/0Of8j085Q>020H3L0M5@]07EE;P1fERl0MeL`07UI<P1j
FS<0Ne/d07aL=@1nG3H0O5/b07UF;P1hDbT0Me8V07YD9`1oERP0PEPZ08EL;P25GB`0Q5l[08AQ:`26
HbT0QVLW08IY9`27JRH0PU`_08MQ=02;ICP0S6Hi08US=P27HC@0R68e08]U>02@KCD0SV/c08]X<02:
Ibl0S6Ta095^=P2GM3`0VWLo099b>@2@L3L0SVhe08][<P0208YZ<@0308][<P2<K3<0Tg0j0080Tg0j
00L0U74k09Ic?@2IMT00W7U309ikA@2RND40XgY20080Xga300@0X7a209ej@02HN3d0UgLl0`2DMc/3
09=f>P80TWDi00<0UgDh09Qf>@2IMcX00P2JN3/00`2IMcX0V7Hi09Me>00208ia=@0608e`=P2;KSH0
QfTc089T<01mGb/0NU`Z1`1dFBh01P1cF2d0LDh^075>;P1_CRd0K4h/06Y=:`80IddZ00<0IDdY06U<
;01YC2`0101ZCBd206]>;P0A06M@;P1XDBl0JU<a06]D<P1ZDc40JE8`06I?;@1UCR`0I58^065>;@1K
BbT0ETLV05=69P1AARP0DTL[0599;01JBbX00P1IBRT205Q9:00D05U::@1KC2/0GDh]05i?;P1NC2H0
GddW061>:01RD2X0I58/06ID;P1XES00JELa04m07`1@@B00DT<T05=49`1B@RP0D40W04dm901;>b@2
04Xo7`<0BChN0`18?Ad00`11>Qh0@c`P04Dn8P0204M0900304Dn8P12>al0@3TM00P0>STM00<0?SXO
03`h7@0j=Q/00`0h=1T00`0i=AX0>SHK03`h7@0203`h7@80>cLL0`0j=Q/0200e=al0=3HN038d700a
<a/0<38J034c6`0b=1`0<cDM0P0Z;AP402/^6@80;2lJ00/0:RhG02T/5`0X:aH09RTF02DX5`0S9AL0
8R@G024S5P0S9QD09RTH02T/6`0202/^7@0302T/6`0V:AP08bHE0080824I00H07b0J01hO6P0M7A/0
71`L01/K6`0J6Q`301TK60L06Q`I0P0I6aP201PJ5`805aTF800G6AP901TK6P805QPG0`0G6AP301PJ
6@P06A/J600G6AP@01HH5`P05aTH400F61L@01DG5PP05QPG200E5QP301DG5P805QPG2`0G6AP@01TK
6P805aTH0`0H6QT201TK6P806Q`K200I6aX801/M6P<06a/I0P0L71X301dM6`<06a/I0P0L71X301dM
6`P07alM200P8A/8028R6PD09R4K0`0W8Q`202DQ60809R8I100W8aX202dS6@0302hT6P0_9A/0<2HL
0080<BLM00L0<RPN038V6P0b9QX0<bLK03@X700f:Qh0=b/O0080>2`P00H0=bXQ03L[7`0g:al0=b/M
03P/700h;A/203P]6@<0=BlS00<0=2hR03<]8@0b;2000P0b;200100g:QL0>2/H03P[600h:aP203T/
6@80>RdJ00H0>B`K03X]700k;Qd0?2lN03d`7`0n<B0203lb8@<0=blL0P0h<1d303Ta7PP0@S4O0P0n
;A/203d/6P<0?2/I00<0>bXH03d_8P0m;b800P0m;b8303`^8@80>bdP200j;ad203h]7@80?bhN1010
;al0100o;Q`0@2lM040_7@10;ad2044`7P80@S4O0P0g;Qd403P_7P80>C0O200n<Ah01P0e<a`0>3<M
03Pc7@0i<ad0>c<N03db7P80?c8O00<0A3HL04Dg7@18>1l00P1;>B400`1=>B40C3HO04/e7P0205<k
7`<0E3`P0`1E?B4205Xl800405/m8@1L?R80GClS05do8`80GT0T00H0EC`M05Tn801M@b80HdHT06I8
9P1ZBBH206]9900806M68`1XAb@0JDPU06]:9`1/BbP0KTdZ06m>:`1`Cb`206a@:`0306e?:`1_CR/0
L4h[0080LDd[00D0Ld`[075@;@1`Cb`0L4l/06m>:`0206i=:P80KD`Y0`1ZBBH206U89@<0J4LT201O
@BL02`1P@b<0HD@T06=69P1TAbL0HdHV0654901O@R80GT4Q06958`1O@R00FchL0080FC`J00T0GD0N
06548P1UB2H0IDPV06A79@1SAR@0HTDS06138@1O@R000P1N@Al306959@@0HdHV0P1TAbL01P1L?al0
GD0P05e0801N@B40Gd8R06138`80HD@T00H0Fd@U05Y3901K@R@0G44T05do8`1N?b<205lm8P80GTLX
00H0GTDW05i39P1O@BD0Gd0T064o901P?R<205Pj7P0305Tk7`1J?200FcdQ0080G3hR00l0GClS05Tg
701I=a`0F3TM05Pj7P1G?1l0EchP05Ho801G@240GCdT05ho8`1O@2@0H44T0693901SAB<00P1TAR80
1@1V@RX0ID4Y06=1:01Q@BP0Gd4W0080GD8W00<0G48W05Hk9P1F>bH00P1F>bH405Ll9`0305Y09@1K
@BH0G48W0080GD<X00/0Fd4V05To901G?B80FC/O05Xl801K?B<0G3hV05/l9`1I>RH0ESLS05Df9002
05I1900305Lo8`1H?R<0FChS0080FS`R00L0Fc/R05a3;@1H@R/0EClX054m9@1=>b<0C3`S0080C3hT
0P19>Al204Ph7P<0AcLM01/0ASHL04ln901>?B<0CC/S04`j8P1;>B<0BSPT04Tf9@18=B@0BSTK04Xi
7@18>A`0ACLL048f700o=A`0?S<M03`d7@17=b00ASHO04@d7@12<Q/0@c<L04De7P18>240BSXS04hl
901??BD00P1@?RH01`1??BD0CS`T04`j8P1:>200E3XO05Dk801G?B800`1H?R<01@1F?240EC/P05U2
8`1H@B80Ed0Q0080ESlP00@0F44R05U28`1I@R<0FT<T0P1O@BL0101P@RP0HT@Z06A6;01UAbd206M9
;`0I05a3901OARL0HdX[06I=;P1WCRl0ITd^06=::`1QB2T0Hd/U06E=9`1VCRX0Idl]06I=;P1UC2d0
HTT[0658:P1XARX0IT@X06939P1P@bD0GD8T05a3901LABD0GDHV05a2:@0205a19P0605i0901P@B@0
ID@U06U69P1ZAbL0I4`Z0P1SBbT00`1RBRP0HDTW06599`0206189P0606I4:`1U@bX0Hd<Z0612:01M
@RL0Fd4V0P1I@BD01P1K?B40G3hR05do8`1N@2@0Gd4U06539`80HT@X00H0HT<T06138`1O@R80G48Q
05Y2801G@1h205A07@<0GTHR:oooool002[ooooo0`2SN4D20:AiAP<0YGY70P2WO4L0102VNdH0YGY5
0:=h@`2RMd820:5f@@<0X7E20P2QMT<30:9gA0P0Y7U4202WO4T20:=iA`0<0:AjB02VO4X0Z7i<0:Uo
C@2ZP4h0Zh5?0:Z1B@2YP4P0ZH1:0:MnBP2VODT0YG]90P2TNTX80:MmB`P0ZH1<2@2ZPDd80:V0BP<0
[8=?00<0Zh9>0:Z1C@2YP4`00P2YP4`80:UoC@060:anC02[OD/0ZWa:0:YlBP2YNdT0Z7Y80P2WNDL2
0:ElB00?0:AkA`2RNDD0XGQ40:1g@`2OMT80WWE109ec@@2LLT00VW0n09Q^?02FK3X0U6Xh09=Y=`2B
J3H0TV`m00L0TF/l00<0QF<c08IT=027ICD00P27ICD00`24HS80PV0`081N;P0208MR=@0408IQ=024
Gc80Peha085L;`80P5/^00X0OU/a07mL<P1oG380Oe`b07iK<@1kF2h0NEH/07MD:P1cD2X0LTlY0`1a
CRP02@1bCbT0M54[07EB;01/BbP0KD`Y06i=:P1_CR/0L4l/075@;@02079A;P0906iB;@1]DB`0KU0/
06m>:`1aCb`0M50^07MC<@1jDc80NeP`0080O5Ta00<0OEXb07iK<`1oG3@00P20GCD308EP=P80QV4g
0`27HSP508]U=P<0RV@e00@0RFDe08YV=P2:ISH0RVHf102;IcL00`2:I3D0RfDf08eW>00208iX>@04
08eW>02;ICH0RV@e08iS=P80Sf@g00@0T6Dh095V>@2AIST0TFHi0P2BIcX8091U>00308eW>02<ISL0
RfDf0080RV@e00<0S6Hg08iX>@2?JCX00P2=J3<408aW<P80RfHa0P2=Hc401P2>I380T6Hd095W=@2B
J3H0TfTg09AZ>0P0T6Dh202=IcP208YT=@0408]U=P2<ISL0S6Hg08eW>080SVPi0`2:I3D508]U=P08
08US=P28HSD0QV0c08EO<P26H3<0Qf4d08YT=`2;ICP808EO>0P0Peha0P1oGBl2081N<0@0PEla00<0
P5dc07mL<P1mFS000P1lFBl0101mFS00Oe`b081M<`1kF30307aI<@<0OEXb00L0OU/c07QB:`1fDb/0
MU<[07ED:`1dE2/0LeH/0080LUL/00@0Ke8b06iA<@1/Cbl0JTd]0P1YC2`206Y=;@0@06U::`1VBB/0
HDPY05Y59P1CA2D0Bd8S04I18`13@240CC`N04dn8@1>?b80CClT04Tm8`15>b80@CTR03lg8080?CLO
00@0>cHP03Td800f=1l0<c8N0`0`<Al01P0d<Qd0<c0M038_700a;Qd0<2dN02hZ7P80;BTN0P0V:1d3
02DW70<092HK0P0Q8Q`3020Q6`<07b0J00<071lH01hQ6P0O8Q/00P0P8a`02`0N8AX071lH01XM5P0J
7AH06ahG01`O600M81T07R4J01lR6`0P8a`08B@M00806ahG0`0L7aP301dP6@<06Q`I0P0K7AX301`N
6`8082<L00<08B@M028U7P0S9Ql00P0T9b004@0U:240:2TI02X[6`0[;1`0;2dM02d^7P0/;Ad0:R/K
02TZ6P0e;al0;b`K02XW600U8aH08b<G02@V6`0W:Ql0:B`S00<09BHN0P0V9al302LX80809BHN00H0
92DM02<T700R8a/08B8J020Q6@0O81P8024R70P07b0J0P0N7aT0100O81X0824K028S7@0S91h202@U
7`0O02h/7`0]:ah0<B/M03D/7@0n<B40AcLW050m;P1E@S40LeTX07iT<`2=LD40V7a:09eoC@2NOTd0
X7i>0:5oC`2SRdd0SW<l075B9P1F=aX0@b`L03H[9@0Z;Rd08c4b02P^;00W;B/09RXY02LY9P0X:RD0
:b`V02l^:@02030`:0P09bXS200Z:bD402TZ8P@0:2TQ0100:BTQ02XZ8P0[:b<0;BdU02l_9`0`<2P0
<C4Y038b:P0g<R`0=c<Z03Pa:@0i<2L0?38X040d:013=bT0ACLZ0P15>RH604Hk9`80Bd@X00X0CD<X
04i2:01BA2X0EDD/05Q8;`1KBC40E44S05E2901GA2H0FDHX0P1KB2X01@1JAbT0FDHX05U5;@1G@b/0
ED4Y00<0DclW00H0ED4Y05I2:P1??R@0DD0V05919`1D@bT305E4:P0I05A3:@1KB2L0FTHU05Q48`1I
@R80G4<T0656:01XBbd0Jdh`06UA:`1]E2`0LUT`07YO<P1oHc<0Q6Hb08IW<@27J340QFXe07mU=01h
GC00KU@_06I=;`1QBC40GDHd05e6=P0205Y79`0605Q7:@1HBB`0EdT^05M9;`1EBBl0EDTa0P1IBRd0
6@1IB2X0G4TY05m;:P1TCB/0Ie0^06YB;P1cEB<0N5PU07mP:P27Ibh0T6ha09Ic<`2KMC@0W7Lc08i_
@@2?L440T790095c?@2BMC/0U7Pi09Ej=`2ENSD0Sfll095a?P2DM4400P2EMD800`2ALCh0SVhk08][
>00208I/>@0308E[>P25JS/0Q6Tl0080PfPm01@0PVHn08QS=P28HcH0S6Ph095]?@2ELCl0V7A009]h
@P2LND40WGY208md?`2>Lch0SG8m08]`>`29KST0Qf`g08I[=P25JSD0NF8h07YS>@<0O6Dk00D0Nf@j
07UR>01hHCL0LE<]07AF<00207MI<`0<07AF<01cEBl0MUPb07YL=P1[F3P0K5Lh06eF=P1]Dc80KU4_
071?;P1`CR/0L4`Z0P1nDbT01P20EBX0PEH[08=H:`25Fb/0QU`Z08MM:`80PV4/00@0Q60/08EP;027
Gb`0Qel/0P28GR`05P28H2d0Rf<`08mZ=@2CL3P0UW<i09Ad>@2BM3H0TG<e09Ea=@2FKc@0Tf`a09=[
<02CJBl0UVT`09QY<@2IJS80VG<d09Yd=@2KMCH0W7Hg09eg>02ONCX20:1j>`0809mj<`2NNC<0WGPb
09ag<`2KMC@0VW@e09Uc=@2HLS@209Aa=`0309Ea=`2GL3L0V6lg0080VFhg00<0Vfhg09Ea=`2ELCL0
1P2ELCL04@2@JS/0RVDh08EP<`21Gc80PV4f085Q>01mH3P0NUde07EH;P1cEbl0LUH^06iE;@1/E2h0
JU@_06QD<@1WDc00J54a0080Ie0`00<0ITl_06E>;P1TCBd00P1SC2`01@1QCRd0HTl^06=@;`1TDC00
IE8a0080IU<b00T0Ie@c06I>;01XD2h0JU8`06aD<P1]EC<0K5@b06]C<@1ZDS000`1KC2/00`1JBbX0
FDXY05Q9:00205Q9:00B05I89@1GBBH0EdTV05];9`1OCBL0HThY06E?:01VD2L0Ie0W05e:7`1QCR<0
Ie@Z06YG;@1YERh0HdlZ05a89@1G@b00CD@W0P1<@bH00`1;@RD0BT4T04U08`0504Po8P80BD0S0`1:
@B@204i17`0704]08018?b00AChQ04<n8@12?280@3`Q03dl800203`k7`0303/j7P0j>Ad0>CPL0080
>3LK200l=Q`0100h=Ql0=cDN03Le7P0g=Ah203Hd7@80=C<L0P0e=al01P0c=Al0<S@O030a7`0^;al0
;BhN02d^8080;2lN00<0:bhM02X]700Y;1/00P0X:aX00`0W:QT0:2XL02PZ700602PZ70809BXF00h0
9BTH02@X6@0S9aT08bHK028U6P0R9A`08B<P020R7`0O8Ah07R0M01dO700L7Q/06adJ01XL6@P06Q`K
200G6AP801TK6RT05aTH200H6QT801LI60P05QPG200G6AP@01HH5`P05QLI400F61L@01DG5Q005QPG
0`0E5aH201HH5ad05aTH0`0H6QT201TK6PX06Q`K200L7Qd301TK6P<06Q`K0P0K7A`801/M6P8071`J
0`0M7A/301hN70807AhH0P0N7aT201lP6P80824K200S8a/202DP6P<09R4K0`0W8Q`202HR6@809B4H
00@09R8I02PT6`0[9ah0;2PO0P0^8AP202lR6@<0<2<J00@0<B@K030S6P0b9A`0=2LN0P0f:B00100e
:1l0=2LN03<V7@0_:A/2034Y700303@Z7P0g:al0>B/P0080?2/Q0`0g;a`203P`7@<0>C4N200h;1`0
0`0k;1T0?2dJ03h_700203l`7@0603h_700l;AX0>b`I03l_7`0n;Qh0>b/K0P0j:QX00`0l;1`0?blO
044a8@0803d`7@<0?c0M0P0n;a`303d^6`0303`/7@0m;Ah0?blP00<0@30Q00<0?blP03d]7P0l;1d0
1P0i;B4203P/80P0=bhM0P0l;1`0100m;Ad0?RhN03l_7`0o;al2040`8004030V6P0b:1`0=2XN03L]
8@80>2hR0P0g;B403P0c;Q/0=BhL03L`7P0j<B00?30P03d`800m;Ah0?2`M03T]7`0j;1l0>bhN03h^
7P11<200@c0O0P16<Ah03P18<Q/0BC<L04/e7P1<=Ql0CCLP04`f7`1;=Ah0BS@M04Tj8`1:>b@0Bc/R
04`k8@1=?200D3dO0P1A?1d205U1:@80FT8Z0`1K@b/02@1LA2`0G4@Z05]3:@1K@BH0G44T05m2901S
A2D0J4LX06Y9:00206Q:9P80JD/W0`1ZC2P00`1[CBT0J4`U06Q<9@0206M;90<0ITXS00<0IDTR06U<
;01YC2`00P1XBb/00`1WBRX0ITTY06E8:00606E8:0<0I4LW0P1M?b<00`1N@2@0Gd4U05m19@0305m1
9@0405e3:01L@RL0G48W05a29`80Fd4V0P1J@2D205Y18`0:05]2901L@bD0GD@V05i59`1OARP0H4LY
06E5;01S@bX0H40W05dm90<0Fc/R00@0G3`S05@l901F?RH0F40X0P1I@BT205Q0:00405Hn9P1D?2@0
EchP05Po8@<0FT4S00H0FD0R05Ln801F?Al0Fd4V05To901G?B8205Hl8@0905Lm8P1I?b@0Fd4V05hl
8`1O?B@0HClV06=1:01T@RT0Hd4X0080HT0W201E>b@01P1A>280DSXR058j8P1C>b40E3`P05Dn7`80
ESlO00@0FcdQ05do8`1O@BD0HT@X0`1TARX02@1SABT0JT4[06Q2:`1T@RT0H48X05Y29P1D@bD0D4<S
04i38`02050h8004054i8@1B>R80E3`T05Dm9@80EShV0P1E>Ql305Hk80<0Ec`Q00H0CchT054m901A
?B@0DS`T05@l901E>b@205Hj900305]1:P1I?bP0F3hW00<0ES`U00<0EcdV05Pn9`1F>bH00P1F?BL0
1P1D?RL0DclW04lm9@1;>b80BSXQ04/g7P80C3PO00T0CCTP04hj8@1?>b80Cc/R050l8`1B?RH0DCdU
04hj8P1;=al00`19=Ad04@1:=Qh0?S4N048e8P15>2D0@cHS03d`7@0k;Q/0?S4N048e8P0j<b00>S@N
03/c7P0m<Q`0?S8J044c6@11<aP0@S8H00P0E3TT0P1A>280101B>B<0DcXT05<j901D>bD205Dl9P03
05i4:@1M@bP0GD<X0080G48W0`1K@BH00`1J@2D0Fd4V05a29`0205a29`80GD<X0P1NA2T0201OARP0
HDPY06=::`1UCB/0IDdY06E=9`1SC2<0HT/R201QBR/01P1PAR/0GdDZ05i4:@1M@bP0G48W05]19P80
FT0U0P1I@BD01P1J@RH0Fd<W05a4:01MABT0GTHZ05m7:`80GTDW0P1OARP0301PAbT0HDPZ0658:P1R
BB/0I3lT06A19@1T@RH0HD@V05e49@1J@b<0E44P058o7P80ES/P00h0F3dR05Xo901L@BH0GD8W05m4
:@1PABX0I4@[06=5:`1Q@bT0G44V05To901F?R80DSdP054l7`<0FD4U:oooool002[ooooo0`2SN4D3
0:AiAP80YGY700D0Yga70:IkAP2VNdH0YGY50:=h@`020:9g@P030:5f@@2QMT<0XGI300<0XWM40`2S
N4D80:AiA0P0Yga900H0Y7Y80:EkB@2UNdT0YWa:0:MmB`2XOT`20:UoC@060:Z1B@2YP4P0Z7m90:Mn
BP2VODT0YG]90P2TNTX80:MmB`P0ZH1<2@2ZPDd80:V0BP80[8=?0P2[PTh20:Z1C@80ZH1<202YOdd0
1P2[OD/0ZWa:0:YlBP2YNdT0Z7Y80:MiA`80YWQ60P2TNdL0102SNTH0XWU50:5hA02QN4@20:1g@`08
09id@P2MLd40W79009Y`?P2HKS`0UV`j09AZ>02CJCL3099/?@@0TF/l00<0T6Xk08IT=027ICD00P28
ISH01027ICD0QF<c08=Q<@22H30208MR=@0708IQ=024Gc80Peha089M<021G2l0P5/^07iK<@0307mL
<P0707iK<@1kF2h0NEH/07MD:P1eDR`0M54[079?:@02075>:003079?:@1cD2X0M54[0080KTdZ0P1_
CR/2071?;080LE0]00P0KU8]06eA;01]Cb/0Kdh[075?;01dD2h0MU8`07YC<P80N5D]00<0NEH^07YG
;`1kF3000P1lFC400`1mFS80Q5le08EP=P0208EP=P80QV4g0P27HSP408]U=P@0RV@e0P2<J3P608]W
=`0308YT=@2;ICH0SFLh0080SVPi00<0SFLh08]U=P2:I3D00`2?I3L0102@ICP0TFHi095V>@2AIST2
099W>PP0T6Dh00P0SFLh08aV=`2;ICH0RV@e08]U=P2<ISL0SVPi08mY>P80SVTe00@0SFPd08aW<`2<
Ic<0RfHb0P2:IC4208iT<P0408mU<`2@IS@0TFLe095W=@80TVPf202@ICP808YT=@<0RfDf0P2<ISL3
08eW>080RV@e1P2;ICH208US=P<0Qf4d00<0RF<f08]U>02<IST02025H3H808AO<P80Oed_0P20GS03
085O<@04089P<P20GC<0Oe`b07eJ<080O5T_00<0OEX`07mL<P20GC<00P1mFS8607aI<@0607QB:`1f
Db/0MU<[07ED:`1dE2/0LUD[0P1bEb`0101_DS80KU4a06a?;`1ZCBd206U<;00A06Y=;@1[CRh0JDX[
06M::P1QB2T0FdHW05=49@1=@R@0B48R04E08P1=?1h0CChQ04ho8P1<?R<0BCdS04Dk8P11>B800P0o
=b001@0m=al0?3HP03Xe8@0f=1l0=3<O0080<C8P00L0<34O03@b7@0d<Ah0<c0M034^7@0`;Ah0;RXN
0080;BTN0`0V:1d202DW70<092HK0`0Q8Q`2020Q6`<07b0J00P07B0I01hQ6P0O8Q/082<L01lR6`0N
8AX071lH01XM5P806ahG00@071lH01dP6@0N8AX07b8K0P0P8a`401dP6@@071lH0`0J71T201/M6P<0
71hK0P0P8a`0100Q91d08RDN02<V7`0S9Ql202@W800302PY6@0Y:QX0:b`L00<0;2dM0P0Z:a/0200d
;Qh0;b`K02`Y6P0X9QT09BDI02@V6`0U:1d09RTP0`0U9Qh302HW7`809bPP0P0U9Qh0100T9Ad08b@L
028S6`0Q8QX2020Q6@P08B8L200O81X01@0N7aT07b0J01lP6P0P8A/08R<M00808b@N020092DO02//
7P0]:ah0;R/L03<[7P0j;R00A3@U04/j:P1@?Bh0JE4Q07IK;025JS/0TWI609UjB`2LO4d0X7i>0::0
D02YTE<0W85:08MX?01ZBb`0CcHR03LZ8@0X:RD08B`X02T^:P0X;BT0:B/X02PZ9@0X:B@0:BXT02XY
9080:bXU200W:R<802X[9@D0:BXR0`0X:B4202TY8@0702XZ8P0/;2@0;RhV02l_9`0`<2P0<C4Y03Db
:`0203Hb:@0503Pa9`0j<RL0?S@X048f:014>2X01016>bL404Ll:080BT<W00T0Bd4V04e19`1@@RP0
E4@[05M7;P1IAbl0ET<U05M49P1IARP00`1KB2X01P1JAbT0FDHX05a8;`1JARd0Ed<Z05E1:0@0DclV
101B@BL08P1C@RP0ED@Z05I5:`1FAB/0FdPW05U69@1HA2<0FT<S05a3901QARP0IDX/06Y=;`1WCbT0
Je4/071G;P1hGC00OV8c08=U<`26Ic40QfPb08EZ=@22ISH0Nf0c079I<@1[DS<0IDdc0658<P1NAcD0
GTXY05e::P1NBb/0G4/]05]<;`1KCC8205U=<`80FT/^01@0FTT[05e::P1PC2/0I4d[06M@;P1ZDRh0
LeDS07MI9`1nGbT0QVD_08m/<P2FLS@0VGHf09af=@2EMd<0UGM109Af@02CMSh0TWDk095d>080T7@e
00<0Sfll095a?P2DM4400P2EMD802@2BLSl0SVhk08a/>@27KSP0Qfdj08I/>@25JcX0Q6Tj08AY?002
08=X?@80SFPk00P0SFTi095]?@2JMT@0XWi:0:>0BP2LND40UG8j091b?P80Sg4m00<0SFlk08a^>P2;
KCT00P2:K3P207mW>`80P6Pl00`0OfLk07eU>@1kHcL0NV8f07QH<@1kFc@0OUhg07eM=P1jFS<0NETb
07aL=@20H3T206mK>004071I=`1aEc@0LUDc07AC<080M58_00T0PED^085F;023F2h0QEX_08ML;`29
Gbl0RV0^08]Q;`24IBl00P25I2l00`27Hbl0R6<_08YR;`0208]Q;`0P08UQ<02<I340SfXf09=`>P2E
LSX0U7@i099d=P2@LS@0U70d099^<P2CK340TVX_09=Y;`2FJC00V6/b09Y[<`2GLC<0V78d09Uc=@2J
M3H0W7Hh09eg>@2NN3X0WgTk09ii<`2MN380W7Lc09Yd<`2ILc@0Ug4c09I_=02EKS<2095^=P04099]
=P2DKCH0UF`f09E/=P80UV/f202BKCH03P2<IcX0Qf8e081N<@1mG340OUhe07iN=`1jGCD0MeTc07=F
;01aEBd0L5@/06eD;01[Dbd0JE<^0P1VDRl206M@<080ITl_00@0IDh^06A=;@1TCBd0Hd`/0P1SD2l2
06AA<00506EB<@1VDc80IU<b06MD<`1ZDc400`1[E380101ZDc40Ie0^06E>;01SC2X205]<:`80FT/Z
0P1IBRT205Q9:0<0F4XW00h0FTXV05i<9P1QCBP0IDlX06MA:01YDRT0HTlT06AA9P1WE2X0J5D]06IB
;@1RCR/0G4PU05Q48`80C4<V0P1;@RD00`1:@B@0BD0S04Po8P0404Po8P<0BD0S0P1:@B@204i17`06
04]08018?b00AChQ048m8011>b40@3`Q0P0l>al203/j7P0403Xi7@0i>1`0>3LK03Pg6`P0?3HL100g
=Ah203Hd7@80=C<L00P0=CLO03@f7P0c=Al0<C<N030a7`0^;al0;BhN02`]7`80;2lN00@0:bhM02X]
700Y;1/0:2/J0P0W:QT802PZ700902DZ5P0U:AP092PG02@X6@0S9aT08RDJ028U700Q91/0828O0080
7b4N00D07R0M01`N6`0K7AX06adJ01XL6@0801XL6`P05aTH200I6aXY01LI60P061XI200G6AP801HH
5`P05aTH400F61L801HG6A005QPG400E5aH@01HH5`<05ALF0P0F61LM01LI60<061XI0P0I6aX:01XL
6`P071hM0`0I6aX301XL6`806adL200K7AX201`L6P<07AdK0`0N7Q`201dN60807QlI0P0O81X2020Q
6`P08b<K0`0U81X202HQ6`<09b8L0P0V8QT202DQ600402HR6@0X91/0:RHM02`X7`80;B<I0P0^91X4
02lU6`0902hT6P0`9Q`0<RPN03<Y7`0d:R00<bTO038X7P0a9ad0;bTK0080<BTL00D0<bTM03L[7`0i
:b00>bXP03`[8@0203H]7080=bhM0`0h;ah00`0i<1l0>2`L03P/700603P/700303//6@0l;AX0?BhK
0080?RlL00T0?BhK03`]6P0k;1T0?RhN03d]7@0l;1`0>b/K03`/700m;Ad00P0n;Qh803d`7@80?c0M
0P0n;a`303d^6`0403`]6P0l;1d0?BdN03h^7`<0@30Q00<0?RhO03d]7P0l;1d0100h;20403T]8@P0
=bhM100m;Ah303h^7`0703l_800a9a/0<bTM03D[7`0g;B40>2hR03L]8@0203H/800H03<^6`0e;Q`0
=c0N03T`7`0l<200?2lO03d]7P0l;1d0>2`N03X/7`0k;Qh0?blO048a8@14<B00Ac8O04Pc8018<Q/0
BC<L04/e7P1<=Ql0CCLP04`f7`1;=Ah0BS@M0P18>B80101:>R40C3/Q04dl801@?Al2058m7P<0FD4Y
0P1J@RX305]3:`80FT8X00H0Fd4V05a1901P@bD0Hd@U06Q7:01ZBBP306Q:9P80JD/W0`1ZC2P0101Y
CBH0J4`U06Q<9@1XC2D206M;9080ITXS0`1UB2P01@1VBBT0IdXZ06Q;:`1XBb/0JD`/00<0IDPX1@1T
AbL205do8`80GT0T101O@BD305a29`80Fd4V0`1J@2D01P1I@280FT4S05]2901L@bD0GD@V05i59`80
GdHX00@0HdD[0653:@1N@2H0G3hT0`1J?280101K?B<0E3`T05Hn9P1G?bL205Q0:080EclW00D0EShV
05@l901H?b40FD0R05Y18`0205]2900605Y18`1H?b40EchP05To901H?R<0ES`Q0P1E>b001P1F?240
F3hS05To901N?2<0GcdT064o9P<0Hd4X00<0HT0W064o9P1E>b@01`1E>b@01P1B>B<0DSXR05<k8`1D
?280ECdQ05Ho8080Ed0P00@0G3hR05i0901P@RH0HT@X0P1SABT02`1RA2P0HD<W06M1:P1U@BT0Hd4X
05a19P1I@BD0E44S05118P1>@B40D3PP0080DCTQ00D0DSXR05@l901E?BD0ECdU05Hn9P0305Dj7`80
ES/P0`1G?2401P1??R@0DCdT054m901B?2@0E3`T05Dk9080ESXT0100FD4Y05Q0:01F?RH0ECdU05@l
901E?BD0EShV05Lo9`1E>RD0EC`V05Hm9`1D?RL0DShV04hl901;>b80BSXQ0P1<>1l304di80<0CSXQ
00H0DC`W050k9P1=>2<0BSDP04Td7`18<ah204Td7`0903ha7P11=240A3LT048e8P0n<Ah0?2lL03ha
7P12=B80>c@Q0080?3@O00<0?S<M040d7012=1X00P13<aT805<j9080DCPR00@0DSTS05<j901C>R@0
E3/U0P1E?2H505]19P@0FT0U0`1K@BH205a29`<0GD<X00P0GdHX0658:P1RBBX0I4`Z06E=:@1TC2H0
Hd/U069;8PP0H4TZ0P1OABX0301NA2T0GD<X05a29`1K@BH0FT0U05To901H@2@0FD4U05Y29P1K@bL0
G4@X05e5:@80GTHZ00<0G4<U05e49P1MA2H00P1NABL205m6:00I0617:@1S@2@0HT0T06529@1P@bD0
G4<T05U28P1E@B00DSlN05Ll8@1H?B80FChS05Xo901L@BH0GT<X05m4:@1PABX0Hd<Z0694:P1P@RP0
G44V05To901F?R80DSdP054l7`0305Q092_ooooo000Zooooo`80XWM40P2SN4D30:AiAP040:EjA`2V
NdH0YW]60:EjA@80Y7U400<0XgQ30:9g@P2RMd800`2SN4D20:AiAP<0YGY7202UNTD80:MlB@P0Yge;
0P2YP4P01P2XOdT0Ygi:0:ImB@2UNdT0YG];0:AjBPP0Yge;202YP4`90:Z1C@P0ZH1:00@0[8=?0:^2
CP2[PTh0Zh9>0`2ZPDd00`2YP4`0ZGm=0:UoC@060:UoC@80Yga90P2VNdP0102UNTL0Y7U60:=hA@2S
N4D70:9iA@090:5hA02PMT@0WgE309id@P2LLT00VW0n09Q^?02GKC/0UV`j0080Tfdn0P2BK3d2095[
?080T6Xk0P2;IcL208aX>00=08]W=`29ICD0Qf<c08IR<P28HcH0Qf8e08IQ=025H3<0Peha089M<021
G2l0P5/^07iK<@0307mL<P0:07iK<@1kF2h0NEH/07MD:P1hEBl0MU<]07AA:`1bCbT0LDhX079?:@80
Le0Z0P1aD2d3071?;0<0Kdh[00T0KU8]06eA;01]Cb/0Kdh[075?;01dD2h0MU8`07UB<@1eDRX00P1f
Db/00`1gE2`0N5D]07UF;P0207YG;`<0Q5le0P25H3H308IQ=`P0RV@e00D0Sf/k08iZ>P2>JSX0SFTi
08aX>00208]W=`0408YV=P2:I3D0RfDf08eW>080SVPi00<0SFLh08]U=P2:I3D00P2?I3L3091U>0@0
TFHi202@ICP00`2=IcP0S6Hg08]U=P0208]U=P0308eW>02>J3T0T6Xk0080SfXf00@0SVTe08eX=02;
IS80RVDa0P29I307091V=003095W=@2@ICP0T6Dh00H0T6Dh2028HS<308eW>080S6Hg2`2;ICH208YT
=`<0RF<f00<0RV@g08aV>@2=IcX02025H3H808IQ=0<0P5h`0P21Gc43089P<P0307mL<P1nFc40OEX`
0080O5T_00<0OEX`07iK<@1oG3800P1nFc<0101mFS80O5Ta07aI<@1kF30207YG;`0607QB:`1fDb/0
MU<[07ED:`1dE2/0LUD[0P1aER/0101`Dc40KU4_06a?;@1ZCB/206U<:P0;06Y=:`1[CR`0JD`Z06M:
:P1RBRP0G4PW05I69@1A@R<0C44S04Y18P1>?Al00P1>?b802`1<?R<0BCdS04Hl8`11>B80@3PQ044f
800o=b00?SHQ03/d8@0i=200=S<P0080=3<Q00X0<c8P03@b7@0d<Ah0<c0M038_7P0`;Ah0;b/O02hZ
7`0]:Ah09bTN0`0V:1d202DW708092HK00@08R<M024R700Q8Q`08B8L0P0P8A/201lP6P0301dP6@0N
8AX07b8K00807b8K00@07B0I01`O600K7QL06ahG0P0L7aP01@0M81T07R4J01lR6`0O8Q/082<L0080
7b8K00@07R4J01dP6@0L7aP071lH0P0K7QL301XL6@806adJ0`0L7Q/201lR6`03020S700Q91d08RDN
00808bHO00@092LP02LX6P0X:A/0:R/M0`0/;Al02P0[;1h0:R/M038/700`;A`0;R/L02`Z7@0X:1`0
9BLL02<V6`0R9A`202@U7@809BHN0`0V9al01@0W:2009BHN02DV7P0T9Ad08b@L00808R<K0P0Q8QX8
024R70X07b0J00@0824K024R700Q8Q`08R<M0P0S91h0600Z:Qh0:BTM02`X700a:A`0=B`M03d`8015
<bD0B3LW05e6701YDBD0N60d08I[?P2?Ld@0UgQ909inC`2RPU40YXiB0:J8DP2KNTd0Pf910657<013
<b<0;bdP02H^8`<0:R/U00<0:BXT02PY8`0W:2800`0U9R0802LZ8`P0:BXT200Y:R8202PX800>02TY
8@0[:b<0;2`T02d]9@0^;RH0;blW03@a:P0d<BP0=C4X03L`9P0i<BH0?C<W03lf9`13=bT204Hk9`80
Ac`X0P18?BT204Tn:P80B44U01@0BClT04/o9@1>@2H0DD4X05A4:`1FA2`0FDHX05Y7:@1KB2X0G4T[
05e:;01LBB/0FTLY05U6:01NBS40G4P_05U5;01G@bX0E40W05<o9P80DShU0200ED@Z05=2:01A@2H0
DD0V05919`1D@bT0EdH/05Y9;`1HB2L0FDHV05M4901H@b@0Fd@U05m6:01TBB`0IT/^06E=:`1YCb`0
KE<^07EI<@1kGS80PF8c08AT<`26IS<0QfTe08EW=@21ICH0Nelg07=I=P1/DcD0IDdc069:<P80HDd/
00H0H4d]05m><01PCc<0H50f05mA=P1ODCL205a=<00V05a;;@1NBb/0HDd/06E>;01WD2h0JU8^071D
9@1fEbP0O5h/08AU;`2<K3<0U78e09Qd=P2JMcL0WWlo09al?`2JNSd0UgLl09Ad>`2AL3X0Sfhi08i]
>02AL3/0Tg8m09Ed?`2GMT40UWE009Ac?P2AL3/0Sfhi08Y_>P29KST0RFdk08Q/?027Jc`0QVTm08EX
?025J3h2095/?`0708m[>`2BKSh0WGU70:R4D02WQ4h0VgQ008i[<`0808i`>P0F08M/?`28KD00R6e0
08M/?`25JSd0PVLj081U>01nHcH0P64e08=T>026Ic/0Q6Di085R=P20HCD0Pf@h08IW>`1iHc`0N68k
07QP>P1gGCP0N5`g07MI=@80N5Pb00P0P5Tb085J<@23G3<0QEhc08MQ=029Hc@0RV@c08]U=080QfLf
00@0R6Hf08YV=P2:ISH0RfDf0P2=I3H03P29HC00S6@c08iY=@2AKSP0U74k099b>@2@LSH0Sg4e091]
=@2@Jc@0SfXc095Z<`2BJC<0U6Td0P2HJSH0402BKS80Tflc09A`=02ELCD0Ug<g09Qd>02IMCT0VWHj
09Yg<`2IMS@0Ug@b09Eb<P2CKc40TFda08m[<@2>JS0208QW<@0308YW<@2;IS40SFDa0080SVDa00<0
Sf@a08eZ=02=JS@01P2=JS@02@27HSD0P5ha07]I;01hEb`0NET`07QK<`1dF340LED^071C:@0206mC
:`0506aC:`1ZDR`0J58]06EA;P1TD2d00P1WD2h306I?;@<0IDh/101UDbl306ID<00:06ME<@1_F3H0
KULe06eF=01ZDc40Ie0^06=<:P1OB2H0GDHT05]<:`<0FT/Z0`1IBRT02P1HBBP0FddZ05Y<:@1JC2T0
FTXV05a:901OBbH0I4hW06QB:@1[E2/206MF:`0606ID;01TDR`0HDlY05i<:01KB2L0FDHU0P1<@bH0
0`1;@RD0BT4T04U08`0204Po8P<0AchQ0P18?b8304U08`0904Y1901>@Al0CD0N04Xo7`18?b00A3dP
048m8011>b40@3`Q0080?3/O00<0>cXN03Xi7@0i>1`00P0h=a/00`0g=QX0>SHK03Xf6`0603Xf6`<0
=cDN0P0f=1d303Dc7080<cDM00L0<S@N034c7P0_<1h0;RlO02d^7P0/;Al0;2lN0080:bhM00<0:RdL
02T/6`0X:aX00P0W:QT802LY6`809BTH00@092PI02<W6@0R9AX08B@K0P0P8a`01P0O8Ah07R0M01hP
7@0M7a`071hK01/M6P806Q`I200I6aX801LI60P06A/J:@0G6AP801PJ6@P05aTH200F61L801LI6100
5QPG200F5aT@01HH5a005ALF400F61L301DG5P805QPG7@0G6AP301PJ6@806A/J2P0J71/801`N7@<0
6A/J0`0J71/201/M70P06adJ0P0L71X301dM6`<07QhL0P0M7QP201hO6@807b0J0P0P8A/802<S6`04
02@O6@0U81X09B0J02DP6P809R4K0P0W8Q`202HR6@809B4H00@09R8I02LS6P0Z9Qd0:bLN0P0^91X2
02lU6`<0<2HL00H0<BLM02lU6`0`9Q`0<BLM038X7P0c:Al2038X7P07034W7@0_:A/0<BTL034Y700c
:Ad0=RXN03PZ7`0203/Z8080=B`K0P0f;A`303L^7@0303P_7P0h;1`0>2`L00H0>2`L0P0i;1/0100j
;A`0>bhM03/^7@0j;A`303T/6`0703X]700k;Qd0?2lN03`_7P0k;Qd0>RdL03T/6`0:03`_7P80>bhM
0`0j;A`0100i;1/0>B`L03X]7@0k;Qh303`_7`0303/^7P0j;Ad0>B`L0080=RXN00@0=b/O03P/800i
;B40>BdQ0P0j;R8803H]700403`_7`0k;Qh0>bhN03/^7P@0>RdM00<0<bTM03@Z7P0e:al00`0f;200
5@0e:al0=2XN03<^6`0e;Q`0=RlM03P_7P0k;al0?2lO03d]7P0l;1d0>2`N03X/7`0l;al0@30P04<b
8P16<b80BSDR04/f8`16<QX0Ac<K04Te7@0304/g7`80BCDM0P16=b001P19>B00BcXP04dl801A?R00
DchO05@o8080F40X0P1I@BT305Y2:P0905]3:`1H@2H0F40V05Y09@1L@B@0H4<U06A59P1YB2T0JTTX
0080IdTU0P1XBRH306U;9`0406Y<:01YCBP0JDdX06U=:080J4`W0`1WBbH0201P@b<0HD@T06=69P1U
B2P0IdXZ06U<;01ZCBd0Jdh^0P1UB2P206A79`80HdHV0P1RABD405do8`80GT0T00<0Gd4U06129P1L
@RL00`1K@BH205Y09@80FClT00H0FD0R05Y18`1J@B<0Fd8T05a39@1MA2H205i59`040653:@1P@RP0
GT0V05`n90@0FS`R00<0E3`T05Dm9@1F?RH00P1G?bL205Hn9P0505Dm9@1D?2@0F3lQ05U08P1K@R@0
0P1L@bD01P1K@R@0FD0R05Po8@1G?B80ES`Q05Dk8080E3XO00H0EC/P05Hl8@1G?B80Fc/R05dm901O
?bH306109`0305lo9P1N?RD0EC/T00L0EC/T00H0DcXT05@l901D?2@0ECdS05Hn8P1G@24205Q18@03
05i0901O@BD0HD<W0080HT@X00/0HD<W05m19@1N@2@0HclW064o9P1N?RD0FSlT05Lo8`1B?b40CchP
04ho8002054i8@04058j8P1C>b<0Dc/S05@l9080ECdU00@0DcTN05@j7`1D>Ql0E3XO0P1E>b0205Hl
8@0604ln901A?B@0DCdT058l901D?2@0EC/T0P1F>R@00`1I@BT0EclW05Hn9P0305@l900:05Dm9@1F
?RH0ECXU05@k9@1E?2H0DcdV054m9@1=>b<0BSXQ04Ti80@0BcTQ0`1:>2001`19=al0CC/U04`j9019
=b40AcDO04Hd7P15<ad00P16=1h0400o<Ql0@C@Q048e8P11=240?S4N03`_700n<Ah0@3<P03de8P0m
=B00@3DQ044e7`14=Ah0ACDL04De6`17=Q`805<j9080DCPR00@0DSTS05<j901C>R@0E3/U0P1E?2H3
05Pn8`<0FClT1P1J@2D205]19P<0G48W00P0GdDZ0617:@1QB2X0HTTZ06=;:@1SBbL0HTXT06598`P0
GdPY0P1NA2T00`1M@bP0G48W05]19P0205Y09@0705To901H@2@0FD4U05U19@1J@RH0Fd<W05a4:002
05e5:@0405Y18`1K@R@0Fd8T05]290<0G4<U00T0GD@V05m0901N@2@0Gd4U05e29@1K@R@0F44R05@o
801C?Ql00P1H?R<0301I?b@0FT0U05a29`1M@bP0GT@Y05m5:P1R@RT0H48X05m19`1K@2D0F3hS05Hn
8P80DSdP0`1F?R8[ooooo`00:_ooool30:9gA080XgQ50`2TNDH00`2VNdH0YGY50:EjA@020:AiA080
XgQ300<0XWM20:AiAP2UNTL00P2UNTL20:IkB080Yga9202UNTD80:MlB@040:UoC@2XOT`0Z7i<0:Mm
B`80YWa:0P2UNdT20:QoA`040:QoB@2WOTX0YWe90:IlBP80YG];202XOT`80:V0C0T0ZX5=202YP4X4
0:^2CP@0ZX5=202YOdd20:ImB@040:ElB02TNdL0XgY60:9iA@D0XGQ40`2RNDD20:=jAP060:5gA@2P
MT@0WgE309id@P2LLT00Vg4o0P2IKcd209A^?`0409=]?P2BK3d0TV`m095[?080T6Xk0`2>J3T01@2=
IcP0S6Hg08]U=P2:I3D0RF<d0080R6<f00@0Qf8e08EP<`24Gc80PUd`0P21G2l0301nFc40Oe`b07mL
<P1oG380OU/a07]H;P1iER`0Me@Z07YG<@1hEBl0MU<]07=@:P<0LTlY0140Le0Z07=B;`1cDRl0LU4^
075@;@1`Cb`0Kdh[06i=:P1]C2T0KE4/06a@:`1]Cb/0KTdZ071>:`1cCbd0MU8`07UB<@0207IC:`04
07MD;01hEBd0NEH^07YG;`80NeP`0`23GS@208AO=@<0QF0f0`29Hc@408YT=@0708]U=P2@K3`0T6`l
08m[>`2>JSX0S6Ph08]W=`0208YV=P0308YT=@2;ICH0SFLh0080SVPi00<0SFLh08]U=P2:I3D01`2@
ICP2095V>@P0T6Dh00<0SVPi08eW>02<ISL00P2;ICH02`2=IcP0SfTj091Z>`2@JST0SfTh08iX=`2=
IcH0RfDd08YT<`29Hc80R68a00<0TFLe0`2@IS@208mU<`P0T6Dh202:I3D208iX>@0408eW>02<ISL0
S6Hg08]U=P80RV@e00<0S6Hg08]U=P2;ICH00P2;ICH308YT=@0308]U>02:I3L0RV@g0080RfDh0P2<
IST00`2=IcX0QV4e08IQ=@0608IQ=@P0Qf8e0P20GS03085O<@<0PV0b0`1nFc4207eJ<0<0OU/a00T0
Oe`d07iK<`1mFS80O5Ta07]H<01jEbl0NEH^07QE;@1iDb`00P1gE2`02@1eE2/0M5@[079E:`1aER/0
L5DZ071D;`1_Dbh0KE4/06]?:P0206Y>:@80JdlZ00T0JDdX06I<:@1SBbL0GdPV05Y69@1DA2<0DD8S
05118P1@?b400P1>?b801@1<?R<0B3`R04Hl8`12>R<0@CTR0080@SLQ00@0?cLR03de8P0k=240>3<P
0`0e<R401P0e<ah0=34N03<`7@0b;ah0<BhO02l[7`80;RXO0P0W:Ah302HX7@<09BLL0P0R8ad3024R
70<0824K1@0N8AX00`0M81T071lH01`O600201`O60807B0I0P0N8AX201lR6`06024T7@0P8a`07b8K
01hQ6P0M81T06ahG0P0J7AH301XL6@806adJ0`0L7Q/201hQ6P0401lR6`0P8a`08B@M028U7P808bHO
00@09RHJ02LW6`0Y:Ad0:b/O0P0/;2002P0[:al0:RXN034[6`0`;A`0<2dN02l]800[:al09RPM028U
6P0P8aX302@U7@809BHN0`0V9al202DV7P8092DM00@08b@L028S6`0R8a/08R<K200Q8Q`8020Q6`03
01lP6P0P8A/0824K00808B8L0P0R8ad0800S91h09bTN02LY7P0Y9a/0;BLK038X700g:ad0?BdP040`
8@1A>AD0G4@P06]A;01hGcH0PfPk08ea@P2HNDX0Wh5?09^2B@2PPT`0Wge@099^BP1iFSd0FTH^03li
8`0`<Qd0:RLN02/X7`0/:B00:b/S02XY900X:B<09RLR0P0T9R4802LZ8`P0:BXT100Y:R8402X[8`06
02LW7`0X:200:BTQ02XZ8P0[:b<0;2`T0P0];BD02@0a<BT0<C4W038_9P0c;b@0=c4U03Xb9@0m=RH0
?cHW04Dj9P0204Hk9`0504Ll:018?BT0BChZ04Tn:P1:?b/00P17@2@02@18?R<0BCdS04`n901??bH0
DD4X05A2:P1JAbT0FdPZ05e:;00205i;;@0805a9:`1KB2X0FTLY05]7;01JAR/0FDDZ05Q4:@1G@bP3
05I29`1305M6;01EA2X0DT4W050o9@1A@2H0E4<Y05U8;P1LBc40EdPY05M6:01FABL0Ed@V05Y5:01N
ARX0HTP]06=9;P1SBR`0IT/]06Y@;@1aEC00MeXb07eN<P22HC@0Pf<d08MW=026J3H0QfPj08=V?01m
HCX0M5Xg06aC=01XCc40Hd`Z06A=:`1RCRd0HTl_065@<P1QD3@0HE8e061B=`1OD3<0GTlb05i=;`1P
CBd0HTh]06E>;01WD2h0JU8^06mD:@1cERX0N5`]081R<028JC<0Sflf09Eb>02GMCP0Wghg09im>02L
NSX0VWPk09Md?02DL3`0Tflm099^?P2ELS`0UW<m09Qe?`0209Uf@00309Md?P2FLcd0U74k0080SW0j
00H0SFlk08a^?02:Jc`0RFXl08QY>`28JCd2099]@008095]?@2CKcl0VGE309ijAP2NNdD0Ug@l091]
=@2>KcP208m`>@05091a>P2BLc`0Tg@m09=d?@2DMCh00P2>M4<0702=Ld80S79108U_?P26K3/0PVPg
081V=@28J3L0Rf/j08i^?@2=KC`0RVXi08QX=`2;JcX0SVhm08Q`@P26KT80Q6a0081W?P1nHSX0NUhg
07MK=01fFS<0OeTb081J<`21G380Pehd08EP=026HC@208QT=080Pf@f00l0Q6<f08ES=P27HSH0Qf8f
08QQ=P2:H3H0RV4c08aS=@2=IcH0Sf/g091]=`2?KSP0SFhe08a^<P2:JC<00P2<JC<00`2>JC@0T6Pd
099Y=@0209AY=P0@08eZ<P2>Jc<0Sf`d091]=@2BKcL0Tg0h09Aa>@2ELSX0UG<c09Ab<`2BL340T6ha
08eZ<02;J300RFH`08QU;`80PF4^00@0PV4^08AP;P25Gbh0Qel^0P28GRh808IU<P0@085O<P1kFRl0
MUDZ07=C:P1cERh0LUH_06iD;`1[DB`0KU4W06eA:@1^DRX0K5<[06]C;@1XDRd0IE4^06A@;@@0Ie4/
101XDRd806ME;`0806]G=01ZES<0J5@a06IB;`1RCR/0Gd/X05a89@1KAb@405Y;:P@0FDXY0180GDl/
05]=:P1KCBX0FDTU05Y88P1MBB@0I4hW06UC:P1^Ebh0JU/`06MH;`1SE2d0GTlX05];9`1HB2H0F4PW
05M79P1<@bH204]29@0304Y19019@2<0B3lR00D0AchQ0P18?b8304U08`80CD0N00L0BSlO04Ln7`14
?B00@SdP044k8@0o>b00?3/O0080>cXN00<0>STM03Th700h=a/00P0g=QX803Pg6`80=cDN0P0f=1d2
03Dc7080=38K00D0<S@L034c6`0a<ad0<38M02h_7@0202d^7P0602`]7`0[;Qd0:bhM02X]700Y;1/0
:2/J0P0W:QT00`0V:AP09RPJ02HX6P0602HX6P0802DY6P0T:1T092PJ028U6P0Q91/082<L01lR6`0N
81/201dO708071hK0P0K7AX201XL6@P06A/J200G6AP801TK6RT05aTH200H6QT801LI60P05QPG200G
6AP@01HH5`P05QLI400F61L@01DG5Q005QPG0`0E5aH201HH5ad05aTH0`0H6QT201TK6PX06Q`K200K
7A`301TK6P<06Q`K0P0K7A`801/M6P8071`J0`0M7A/301hN70807AhH0P0N7aT201lP6P80824K200R
8QX202@O6@<09B0J0`0V8A/0200W8aX09R8I02DQ600T81L09B4H02LS6P0Y9A`0:RHM0`0^9Q/202lW
70<0<2PM00<0;RHK02lW700_9a`00P0`:1d3034Y7P06030Z700a:A`0<BTL03<Y7@0f:Qh0=bTN0P0j
:Al303@[7080=B`M0`0f;Ah@03P/700303L/6P0h;A/0>c0N0080?34O00<0>RlM03L/6P0e:QP0200j
;Ad303T]7@<0>2`L0P0g:a/303P/70<0>BdM0`0h;1`01P0e:Ad0=RXN03HZ7P0g:al0>2`P03T]8@80
>RhR200f;A`203X^8080>BdO00@0>2`N03L[7@0f:Q`0=RXL1@0e:al0100d:Qh0<bTM03<Y7@0c;Q/2
03D^700303L^7@0j;Qh0>bhN0080?BdN01P0>2`N03X/7`0l;al0@30P04@c8`17=2<0BcHS04`g9014
<QX0AC<K04Le7@18=Qh0BCLO04Pf7P17=Ad0AS@L04@e7P15=Ql0AcLN04/j801=?200DChP05@o801E
@24205Lo9`80F40X0`1I@BT02@1J@RX0EShT05Lo9@1I?b@0G44T06549P1TABH0JDPY06Y9:00206I8
9080IdTU0`1XBRH00`1YBbL0JD`Z06U<:P0206U<:P80J4/Y0P1WBRP20654900706959@1TAbL0IDPX
06I9:@1WBRX0J4/[06E8:00206A79`0306=69P1RABD0HTDU0080HD@T00<0GT0T05do8`1L?R800P1L
?R80101N@2@0Gd4U06129P1K@BH305Y09@80FClT0P1H?R<205U08P80FT4S00@0Fd8T05a39@1L@bD0
G4<U0P1L@BH00`1K@2D0FChS05Pm8P0305Ll8@0305@l901E?BD0ECdU00D0ECdU00@0E3`T05Ln801I
@280FT4S0P1L@bD00`1K@R@0FT4S05U08P0305Dk8080E3XO0`1E>b000`1J?280FcdS05do9@0205i0
9P0305do9@1L?R@0FcdS00P0E3XS00X0E3/U05@l901E?BD0EShT05Lo8`1H@B80F44Q05U28P1O@BD0
H48V0P1Q@bL0101P@RH0Gd4U05do8`1K?B4205dm900405/m8`1H?B80ECdQ058m8080D3dO00<0DCTQ
058j8P1B>R800P1C>b<205@l900305Dm9@1B>Qh0DSXN00<0Dc/O0`1D?2001P1??R@0DCdT054m901B
?2@0E3`T05Dk9080ESXT00<0ET0X05@n9P1C?BD00`1A>b<00`1B?2@0DcdU05@i900205@k9@06058l
9@1A?BD0CC/S04Ti8018>1l0Bc/T0P1:>R<02@19>B80B3PQ04Lg8017=b00ASHO04Xi9@18=b<0ASDQ
04@c7`0204<b7P80A3<O0P10<b001011=240@3<P03ha7P0m<1d203ha7P08040e8`10=B40@SDR04@e
8016=Ql0B3HN04Th7P1;=ah8054k9080DCPR00@0DSTS05<j901C>R@0E3/U0P1E?2H205Hl8@80EcdR
0P1H?R<705To9080FT0U0P1K@BH01P1NA2/0GdDZ05m5:P1PAbT0HDPY06599`80HDTU201MARL305a2
9`0305]19P1J@2D0FT0U0080FClT0P1H@2@205U19@0405Y29P1K@bL0Fd<W05]39`H0FD0R0P1J@B<3
05Y09@80F40T00@0EclS05@o8P1C?R40F40T0P1I@BD00`1J@RH0Fd<W05]39`0205a4:00605lo9P1N
@2H0GClU05Xo901H?R<0ECdQ0P1B?B0305Dm8B_ooooo000Zooooo`80XGI30P2RMd@20:=hA@80Y7U6
0P2UNTD40:AiA080XgQ30`2UNTL20:IkB0<0Yga9202VNdH80:MlB@80ZGm=00<0Z7i<0:MmB`2VO4X0
0P2UNdT0102TNTP0Z7m70:MnAP2WOTP20:MnBP030:IlBP2VO4`0YWa<00P0Z7i<4@2YP4`80:V0BP@0
ZX5=102[PTh80:UoC@80YGe900@0Y7a80:=kA`2RNTH0XWY60P2QNDD30:5hA0<0XWU50P2SNTH20:5g
A@040:1fA02NM480WG=109ab@080Vg4o0P2EKd00102DKSl0Tfdn099/?@2AJc`2091Z>`05099Y>`2A
J3X0T6Li08mV>02>ICL00`2=I3H02@29I3L0R6<f08MR=@26HC@0Q5lb08=N<@22GC00PE`_07iK<@03
07mL<P0807iK<@1kF2h0NEH/07MD:P1kF380NEH`07MD;P1dDB/307=@:P0707AA:`1eE340M5<`07=B
;`1bDBh0L4l/06m>:`0206e<:@0806eA;01/D2/0K4hZ06i=:P1`CR/0Ldl]07EA;`1hDC0207UF;P04
07YG;`1kF300O5Ta07eJ<P80OU/c0`22GC<208=N=0<0Q5le0`28HS<00`29Hc@0RV@e08YT=@0208]U
=P80T6`l00T0Sf/k08eY>@2<J3P0RfLg08YV=P29ICD0RV@e08]U=P2=IcP00P2>J3T00`2=IcP0RfDf
08YT=@02095V>@l0T6Dh00P0SVPi08eW>02<ISL0RfDf08aV=`2=IcP0SfTj095[?080SfTj00@0SVPi
08eW>02;ICH0RV@e0P29Hc@3095W=@<0T6Hd0P2?IC<8091U>0X0SVPi00@0SFLh08aV=`2<ISL0RfDf
0P2:I3D308aV=`0308]U=P2:I3D0RV@e0080RF<d0P2:I3L208]U>0@0S6Hi2026HC@808MR=@<0PEla
0`22H38208=Q<`0307eJ<01nFc40OU/a00@0OU/a00L0OEX`07iK<`1nFc<0OEXb07aI<@1jEbl0NEH^
0080N5D]00H0NU@]07QE;@1gE2`0MUD/07AD:`1aE2X2071E:P04075E;P1_Db`0KE4Z06]?:080JThW
0100JdlX06a@:@1XCbL0IddX06A<:01QBBD0GTLU05U5901G@R<0ET4R05508P1?@2<0CSlR04/m8P18
?280AS`S0P13>b@204@h8P04048g8`0n=R<0?3DR03Xc8@<0>38R00P0=C<N03Db7`0d<Ah0<RlN034^
7`0`;200;b/P02hZ7`<09bTN0`0V:1d202DW70<08R<M0`0Q8Q`2020Q6`807b8K00<07R4J01dP6@0M
81T01`0M81T401hQ6P808B@M00H082<L01hQ6P0M81T071lH01/N5`0J7AH301XL6@806adJ0`0L7Q/2
01dP6@0401hQ6P0O8Q/082<L024T7@808RDN00@09BDK02HV700X:1h0:RXP0P0/;2802P0[:b40:RXP
030Z6P0_;1/0<BhO030^8@0/;200:2XO02<V6`0P8aX202<T708092DM0P0U9Qh202HW7`0302DV7P0T
9Ad092DM008092DM0`0S91`8024R70X0824K100Q8Q`2028S7@0O02@W7P0U9Qh09RHL02XV6`0^9Q/0
<RPL03LY7P0j:Qd0B30D054j6`1NAR@0Je4/07MK<`21IST0SW9209IjB02FOD@0V7Y409YeB02FL4T0
R6I306iE=P1>@B40>3<C02lW6P0`:1d0<2TO02hZ8@0[:b<0:R/U02T[9P0202PZ9`P09RTR200X:B<0
0`0X:B40:BXR02TZ8P0202X[8`80:b`T00D0;2dU02PX800X:200:BTQ02XZ8P0202/[8`80;2`T00P0
;c0X02h`9@0_;bD0<BlS03<_8`0h<R@0>S@T03df9P80A3TU00@0ACXV04Hk9`17?2P0B3dY0P19?RX0
4017@2@0ASlS04Lm8P18?280BcdS04hn9@1@@2L0DT0X05U6:01KB2X0G4T[05e:;01NBbd0GDX/05a9
:`1KB2X205M49P0305Q59`1IARP0FTLY00<0FdPZ00X0F4L]05I5:`1C@RP0DD0V05919`1EA2X0FTT_
05e<<P1EAbX0ETLZ0P1FABT0501IABX0FdH[05m7;@1PB2h0HTP]06A9;P1WC2h0KE0`079D<01iFC80
OE`a07mN<`26IC80QfLf08UY>P29JS`0Q6Lm07eQ>@1eG3@0LELb0P1VCRX00`1UCR`0Hdl^069?;`02
061?<@0K05m@<`1RDcH0HE8e061?<@1RCbl0Hdl^06I?;@1XDBl0JU8^06eD;01aEBd0M5T/07YN;`22
I380RFXd08i]=`2ALCP0VgH_09]f<02KMC@0VgDg09]d>`2KLcl0Vg=009]c@P2FLcd0Ug@n0080VGI0
00`0VWM109Uf@02HMCl0Ug@n099c?02ALS/0T74k08m_?02=KC`0S6`m08][?02:JC`208mZ?@07099^
?P2DL400TFdk08eY=@2=JS@0TVlg09Md?002091_>@04099a>`2CLS`0UG@n09Ie?`80V7M10`2CN4<0
6`2AMT40SW<n08Y_>P27K3L0Q6Td08e/=P2AL3X0U7<m09=b?02AL3X0T6li09=b?02GMT00Uge:09Aj
A`2@MTD0RVm0085Y?@1lHcX0Mehf07EL=01kFC<0O5Xd07aK<P1mG340OUd`07mN<@02081P<@80Nehb
00<0OEhb07iM<P1oG3800P21G3802`22Fc80RF0d08YQ=@2:I3D0RfLe08aX=02:JC<0RFXc08QY<026
IS<0QfHc0080RVHd00@0RfDd08eU=02>I3@0SV@d0P29IC40102:IS80S6Pd08eY=@2?JcL2091/>008
08m]<02?K380SFX`08]X<029IS00Qf<_08EQ;`24H2h207]L;@0407aL;@1mFbd0OeX]081J;@80PUT]
2020H3404@1mG340MeL^079B:@1_DRX0Ke</06iD;`1ZDRh0Idl[06iA9`1^DRX0L5@/06mF;P1^ES00
JeD`06MC<01VDRl0J58]0080JE<^00<0JU@_06]E<01/ES400P1/ES4306YH<P0:06UG<@1XES00IeD_
06ME;`1VE2h0IE<_06AB;P1RD2`0HDl[05m=:@80GT`X00<0GD/W05U::@1IBRT00P1IBRT405Y;:P0A
05e?;01KCBX0FddZ05Y:9P1KBB<0GTXU06A>9`1ZE2/0KUL^06YK<P1WF340HE8[05];9`1GAbD0EDDT
05I59`1GARP00P1;@RD00`1:@B@0BD0S04Po8P0204Ln8@<0ASdP0P17?R4204Po8P80BD0S00P0CD0N
04`o7@19?Qh0AchO04@m8011?1l0@3XP03lk8080>cXN00<0>STM03Th700h=a/00P0g=QX00`0f=AT0
=cLK03Lg6`0603Lg6`<0=S@M0P0e<a`303@b6`80<38J00L0;c4K02h`6`0^;ad0;BhN02`]7@0/;Al0
:bhM0080:RdL00<0:B`K02P[6P0W:QT00P0V:AP802HX6P0802DY6`0T:1X08bHK028U700P8a`07R0K
01dO6P0M7a`401/M6P@06Q`I200H6QT801LI60P06A/J>@0G6AP801HH5`P05aTH400F61L801HG6A00
5QPG400E5aH@01HH5`<05ALF0P0F61LM01LI60<061XI0P0I6aX:01XL6`P06adL0`0I6aX301XL6`80
6adL200K7AX201`L6P<07AdK0`0N7Q`201dN60807QlI0P0O81X2020Q6`P08R8J0`0T7aT302DP6P80
9R4K00<09b<J02HR6@0U8AP00P0T81L0100V8QT09b<J02TU700/9QX302dW6`80;RPL0P0_:Ad302dW
6`80;RPL0P0_:Ad02P0`:Qh0<2XL034Y700a:A`0<bTM03DY7@0f:1d0>2LM03TX7P0b:1`303<Y7@80
=2XN0P0e:al803P/70P0=B`M00P0=BdJ03L_700i<Ah0>S8O03Ta7P0g;a`0=2`I038Z5`P0>B/N0P0f
;Ah303D/7@<0=2/L0`0e;1/303@[6P<0=B`K00@0=BTM03HZ7P0f:Qh0=b/O0P0h;20203T]8@P0=B`K
0P0g;B40100f;200=B/O03@Z7P0d:Qh203<Y7@80=B/O0P0d:Qh403<Y7@0603@_700e;Q`0=BhL03H]
700h;1`0>RdM0P0m;Ah02`0i;Al0>R`O03`_7`10<200@c8R04Hc8P1:=B80BcHS04<a6@14<QX0AS@L
00<0B3HN00/0AcDM04Hd7013=1d0A3DN04Lg7P1:>Al0C3/O054n801C?Ql0E3lP05Hn9P0305Lo9`80
F40X0P1I@BT02@1F?R@0EclU05Y09@1M@RD0HD@V06A59P1WARL0J4LV06E78`0306I89080IdTU0P1X
BRH0101YC2X0J4/Y06Q;:@1XBbT206M::080ITTW0P1TAbL306=69P<0HTDU00H0IDPX06A79`1SARH0
HTDU0654901P@b<205m28P0305i0901M?b<0FcdQ0080FcdQ00<0GClS05m19@1P@RH00P1J@2D205To
90<0F3hS00@0EcdR05U08P1I@280FD0R101J@B<01`1K@R@0FClT05To901I?b@0F3hS05Lm8P1F?240
0P1E>b0305@l9080Dc/S101D?2@00`1F?Al0EchP05U08P0305]2900305Y18`1I@280E3XO00H0EC/P
00@0E3XO05Pm8P1I?R<0FSlT0P1K@2D00`1J?b@0F3dR05Ll8@0805@j8`0605<j901D?2@0E3`T05Dm
8`1F?R80Ed0Q0P1H@B402@1O@BD0H48V06129P1P@RH0Gd4U05do8`1K?B40FS`P05/m8`0205Pm8P05
05Hl8@1E>b00Dc/O05<k7`1B>Qh00P1B>R8405<k8`80E3`T0`1@>ah3054l7`80DSdP00H0CchT054m
901A?B@0DS`T05@l901E>b@205Hj900305A09`1C?bH0DCdT00<0Cc/R00<0D3`S054m901C>2<00P1C
>R@01P1B?2D0D3`T04`j8P18>1l0AcLN04Tj9@80B3TT00T0AcPS04Hg8P15=R40ACHQ04@e8016=b@0
ACHS04<d8@11<Ql00P10<Ah01011<Ql0@S<P040c800o<Ql203ha7P80?c8O00X0?S4N03d`7@10<b80
@C@Q04@e8P16=B40B3HP04Tg7`1<>1l0CCLO201@?2@2054h8P04058i8`1C>R@0DcXT05@k9@80EC`V
0P1F?24405Lm8P<0F3hS0P1G?B8205Pn8`@0FClT00H0GT@]05i4:`1NA2/0GT@Y05i59`1OARL20618
9PP0Fd@U00<0Fd4V05Y09@1J@2D00P1J@2D305To90<0F40T101I@BD00`1J@RH0F3lQ05Po8@0305Po
8@<0EchP00H0E40U05E09@1D?b@0E3lT05<n8`1E?B<205Hn90D0Ed8U0`1H@bH01P1M?B@0G3hT05/m
8`1I?R<0EcdR05Dm8@80DchQ0`1E?B4[ooooo`00:_ooool30:5f@`80XWM40`2SN4D80:AiA080Y7U6
0P2UNTL30:IkB0030:MlB@2VNdH0YW]600H0YW]6202WO4T0102YOdd0Z7i<0:QnC02WOD/20:IlBP80
YG]90P2WOTH0102WOTP0Ygi:0:MnBP2WOD/20:MmC@P0ZGm=4@2YP4`80:V0BP040:V0C02ZPDd0ZX5=
0:Z1C@<0Zh9>00<0[8=?0:UoC@2YOdd01P2YOdd01P2UP4/0Y7m:0:AoBP2SOTT0XWe80:5lA`80X7]6
1`2RNDD01`2QN4@0X7I40:1fA02OMD<0WWA209ec@@2LLT000P2KLCl209I`@@0:09E_@02DKSl0TV`m
095[?02@JS/0SfTj09=X>`2BIcX0T6Dh08iS=P80SF8e0P2>HcH208UT=`0408QS=P26HC@0QF0c08=N
<@80PUd`00`0OU/a07mL<P1oG380Oe`b07iK<@1kF2h0NEH/07MD:P1jEc40NEH`07MD;P1eDR`207AA
:`0807EB;01fDbd0M5<`07AC<01cDRl0LU4^075@;@1_CR/206i=:P0806a@:`1[CbX0K4hZ06i=:P1_
CBX0LTh/07EA;`1hDC0207YG;`0307]H<01lFC40OEXb0080OU/c00@0Oe`d085L<P21G380PE`b0P22
GC<308=N=080Qf4b0P28HS<01029Hc@0RV@e08]U=P2;ICH208eY>@0408aX>02;IcL0RfLg08YV=P80
RFDe00<0RV@e08]U=P2=IcP00P2>J3T00`2=IcP0RfDf08YT=@03095V>@@0T6Dh0P2?I3L8091U>003
08mY>P2>J3T0SFLh0080S6Hg00<0SVPi091Z>`2AJc`00`2=IcX208aV>@<0RfDh1`2@IS@00`2AIcD0
T6Dh091U>006091U>0P0T6Xk0`2=IcP208aV=`<0RfDf0P2=IcP00`2<ISL0RfDf08YT=@0208US=006
08QR<`28HSD0RF<f08YT=`2;ICP0S6Hi0P2;ICP00`2:I3L0Qf<c08MS<`0608MS<`P0QV4d0`21Gc42
089P<P<0Pf4c00<0O5T_07eJ<01nFc400P1oG380101nFc40OEX`07aI;`1mFS8207aI<@0607]H<01j
Ebl0NEH^07UF;P1hEBd0NeD^0P1hEBd00`1fEB`0M5@[075D:P0206mD:@04075E;@1`E2`0KU8Z06a@
:080JdlW0P1/D2P03P1XDBP0Ie0W06E=9`1SBbL0H4PT05i6901L@b@0Fd8S05918`1@@B@0CSlR04/m
8P17>b40AS`S0P14?2D01P17>2<0ASLR04<f8`11=R@0?SHS03/d8P80>S<S00L0>C<S03Hd7`0e<Ql0
=34N03<`7`0a;Ql0<2`P0080;b/P0P0X:Ql202LY7P<09RPM00<09BLL02<T7P0S91h00P0R8ad3024R
7004020Q6`0P8a`07b8K01hQ6P<071lH00<07B0I01hQ6P0M81T00`0M81T401hQ6P8082<L0P0O8Q/0
100N8AX07B0I01`O600L7aP301XL6@806adJ0`0L7Q/01P0L7aP07B0I01dP6@0N8AX07b8K020S7080
8B@M00H092@L02DU7@0X:200:RXR02/[8`0/;2@202/[8`0802lY6@0^:aX0<2dN02l]800/;200:B/P
02DX7@0S9Qd302<T708092DM0`0U9Qh802@U7@P08B8L200P8A/8024R700O01lT7@0R9Ah092DM02PU
700/9A/0<2HL03@X700f:1d0@bdF04Tc6`1E?B40GTHT06Q>:@1eFRl0PVLh08a`@02GOTH0UgM409Qb
@`2HKT@0SfY007QL=01JBAh0@ST>03ha800k;al0=bdQ038/800^:b@0:b`V02T^:P0202T];0P09RTR
200X:B<202PY8@0302TZ8P0Z:b<0:b`T0080;2dU00D0;BhV02XZ8P0Z:R80:RXR02/[8`0302`/900?
02d]9@0/;bH0;2lT02`^8`0^;R80<BlR03Db8`0g=2<0>cDU044f8P12=b<0@cPT04@i9@15>RH0Ac`X
0080B3dY00`0B44U04M09018?R<0B3`R04/m8`1=?B@0CclV0590:01F@bD0F4DW05Y7:@1LBB/205e:
;080G4T[00@0Ed@T05Q59@1JAbL0G4TY0P1MBRX205a9:@0805M6;01FAB/0E4<Y05=2:01D@bT0EdH/
05Y9;`1LBc4205A6:`0405E5:`1GAR`0EdH/05Y6;@80G4H^0100HTPa06A8<01UBRl0JD`^06i@;P1d
Dc00N5H`07YH<P26HS00QVDb08UW=`2:JS/0R6Tk08=W>01nHcH0Nf0c0P1/DRd07P1ZDRh0J54_06EA
<01TDC40He0`061?<@1UEST0He@g06=B=01SD300I50_06M@;P1XDBl0JU8^06aD;P1^E2l0L5L^07EJ
;@1jGRl0PF<a08IW<@29JS@0UF`/09I];@2HKc40VW4c09ec=`2OMC/0XGHo0:9g@080VG@m00<0VWDn
09]f?`2KMSl00`2KMSl209Ee?00609=b?02BLC`0T6ll08i/?02=Jc/0S6Xl0P2=J3/03`2BKSh0U710
08eY=`24H2`0QF8/091]=@2KN400Tg0h09Aa>@2ELSX0Ug@l09Uf?P2JMcl0VgQ009ai@@0309Mj@P07
09Eh@02CMSh0Sg8j08a_=`2:KCD0T6ha09Ab=@0209Qf>@0<09Id=`2GMCP0VgTl09mm@02PPdT0WH18
09IkA02?MD80Qflo07mX?01jICX0Mf4h0P1kGCL00`1jGCD0NUdc07YM<@0207UM;P0607UM;@1eFC40
METa07II<@1hF340NELa0P1jEc402@1lES40Qedc08MM<`26H3<0QV8b08MS<@25I2l0Q6D_08AU;P02
08=S=00608ES=@27HSD0Qf8e08IP<`27GS80QUda0P23HC401024HS80QV@d08MU=@29IcL208YX>009
08MW;P26IRd0QF@^08AS;P23HRl0PEl_081N;P20GS00MUT]0080N5T]00<0NEP]07YG;@1lEbd00P1m
ERd807aM<@0@07aL<`1gEc00L5<[06eA:P1]Dbh0KEDa06UB<01VCbd0LE@Z075E;@1dF300M5/c07=K
=@1`FSD0JeLd06UE<P80JeD^00H0K5H_06eG<01_FC80L5Xc075K=01bG3D206eK<`0606aJ<P1ZF300
JEL_06QF;P1WEBd0IU@/0P1NCRX205a<:00505];9`1LC2P0GDdY05i>:P1HBBP00`1IBRT305Y;:P0C
05]<:`1LCR/0FddZ05]=:P1KBbL0GD/U061<9`1UCbP0JE<Z06eF;@1VF340HU@_05a>:@1GBBH0Dd@S
0593901B@bH0Dd@W04]29@0204Y1900304U08`18?b80AchQ00D0ASdP0P17?R4304Po8P80C3lM00L0
BChN04Ln7`13?1l0@C`O040j800n>Ql0>cXN0080>STM00<0>CPL03Pg6`0g=QX00P0f=AT803@g6P80
=S@M0P0e<a`303@b6`0603<a6P0^<1P0;S0H02h`6P0];aX0;BhL0P0/;Ad01P0/;Al0:RdL02X]700Y
;1/0:2/J02LZ6@809RTH00<09BPG02DW6@0U9aT01P0U9aT0200U:1d092LL02<V7@0Q91d07b4L01dO
700L7Q/06adL1`0J71T00`0I6aP061XI01PJ6@0601PJ6@P05aTH200I6aXi01LI60P05QPG200G6AP@
01HH5`P05QLI400F61L@01DG5Q005QPG0`0E5aH201HH5ad05aTH0`0H6QT201TK6Q806Q`K0`0I6aX3
01XL6`806adL200K7AX201`L6P<07AdK0`0N7Q`201dN60807QlI0P0O81X2020Q6`P08B4I0P0S7QP2
02@O6@<09B0J00@09R4K02LS6P0V8QT09B4H0P0T81L00`0U8AP09R8I02LS6P0302TU6@80:RHJ0`0[
9a/02@0/:1`0:bLK02/W6`0Z9QX0:bLK02`X700]:Ad0;RXN030Z7002034Y7003038X700d:1`0=BLL
0080=bHL0`0a9ad2038X7P<0<bTO200h;1`203D[7`0403@Z7P0c:Ad0<bTM03@Z7P80=B/O00P0=blL
03P`7@0h<1d0>30M03L_700e;AX0=2`I03<[60P0>2XO00@0=B/O03@Z7P0d:Qh0=2XN0P0c:Ad2038X
700303D/6`0d:aX0<bXI00<0<RTH00<0<bXI03@[6P0e;1/0200g:al803D/6`@0=2XP0`0c:Al0100b
:1h0=B/O03@Z7P0c:Ad2038X700A03<Y7@0d:Qh0=B/O03@_700e;Q`0=2dK03D/6`0g:a/0>B`L03d]
7P0n;Ql0>BdO03/]800l;al0?blO044`8014<B000P17<Ql03P12<QT0@c<J04De7016=Qd0AcLN04Hf
7@15=A`0A3@K04@e7P15=Ql0AcLN04Xi7`1<>al0Cc`N0P1B?Ah0101E?BD0EShV05Hn9P1F?RH205Lo
9`80F40X00T0EShT05Q09P1K@BH0GT<V06549P1SA2D0ID@U06A38P1TAR800`1UAb<206I89080IdTU
00@0IdXZ06I9:@1VBBT0ITTY0P1UB2P406A79`0406=69P1RABD0HD@T06138`80Gd8R0P1TAbL03P1S
ARH0HTDU06138`1O@R80GT4Q05e0801N@2@0GClS05/m8@1I>al0FS`P05`n8P1O@BD0HD<W0P1I?b@2
05Pn8`<0EcdR00<0ES`Q05U08P1I@2801P1I@2802P1E?B40EShR05Lo8`1G?b<0EShR05Dm8@1D?200
Dc/O05@l901C>b<5058j8P0605<k8`1D?2@0DcXL05@k7@1G?R00F3lQ0P1I@28205Po8@0305@j7`1E
>b00ES`Q0080EcdR00/0ES`Q05Dk801D>Ql0EcdR05Pn8`1I?b@0FT0U05To901H?R<0ES`Q05Dk8008
05<i8P0:058i8`1B>R80Dc/S05@l8P1E?B40ESlP05Ho7`1G@200GClS05i090<0Gd4U00<0GClS05/m
8@1I>al00P1G?B8205Hl8@80EC/P0P1D>Ql805<k8`80CS/M0P1??1h3050m7`07054n801??R@0DCdT
054m901B?2@0E3`T05Dk900205Hj900305509P1@?bD0CSdS00<0C3/Q0P1>?B<02@1B=b80DSTS058i
8`1A>b@0Cc/S04/i8@18>1l0ASHM04Dh9@0304@g90@0@cHS01H0@SDT040c8P0o<R40?C0O03`_7P0m
<1l0?S4P03lb8@11=240?c8O03`_700m<1d0?c8O040c800m<1d0>bhK044a8@12<b00A3<Q04Hd8017
=Al0BcLO0P1==al804hl9080DCPR00@0DSTS05<j901C>R@0E3/U0P1E?2H205To9080F3hS0P1G?B86
05Hl8@80EcdR0`1H?R<0201M@Rd0GD</05a2:`1L@RT0G48W05e49P1OARL0H4LX201I@R<805To90P0
F40T00@0FD0R05Po8@1H?b40F3lQ0`1G?R002@1F?Al0D40V04lo9@1??R@0D3`S054k8`1D?2@0ES`U
05Lm9P0405E290<0E44S00L0Dd0R05/k8P1J?280FS`R05Ll8@1F?240ECdQ0080DchQ0`1F?R8[oooo
o`00:_ooool40:5f@`80XWM40P2SN4D80:AiA080XgQ50P2TNDH40:EjA`P0YW]6202WO4T50:MmB`<0
YWa:0P2VODD0102WOTP0Ygi:0:MnBP2WOD/20:MmC@P0ZGm=202YP4`90:QoB`P0ZH1:0P2YP4`20:Z1
C@80Zh9>0P2/Pdl80:UoC@060:N2C@2VPD`0YX5<0:F0B`2TOdX0Xgi90P2RODP20:AkA`040:=jAP2R
NDD0XGQ40:5hA080X7M30P2OMD<0102NM480WG=109ab@02LLT0209]a?`80Ug5200X0UW1109A^?`2B
K3d0TF/l091Z>`2?JCX0TVLj095V>@2?I3L0SF8e0P2<HC@02`2=HSD0SV<f08UT=`29I3L0R6<f08MR
=@25H3<0Q5lb08=N<@22GC00OU/a00<0Oe`b00L0OU/a07]H;P1iER`0Me@Z07UF<01hEBl0MU<]0080
ME8/00<0MU<]07QE;`1iES000`1cDRl00`1bDBh0LE0]071?;002071?;00906a@:`1[CbX0JddY06e<
:@1_CBX0LTh/07A@;P1hDC00Me@/0080N5D]00<0NEH^07YG;`1kF3000P1lFC42081K<@80PE`b0`22
GC<01`23GS@0QV0a08IP<@27HC80R68c08US=02:I3D00P2;ICH808UU=@0308YT=@2;ICH0SFLh0080
SVPi00<0SFLh08]U=P2:I3D00P2BIcX2095V>@03091U>02?I3L0Sf@g0080Sf@g202@ICP0202?JCX0
SVPi08eW>02<ISL0SFLh08iX>@2@JS/0TF/l0`2;I3T208aU>P<0SFHk0P2>I380102?IC<0T6Hd095W
=@2AIcD2099X=PP0T6Dh202>J3T308]U=P80S6Hg0`2=IcP01P2>J3T0SFLh08aV=`2;ICH0RV@e08US
=080R68c00P0QV0c08MQ=029HcH0RV@g08]U>02:I3L0RF<f08QR=@P0Qf<a2024Gc801021Gc40PV0b
089P<P22H38208=Q<`80Q68d00<0O5T_07eJ<01oG3800P20GC<00`1oG380OEX`07aI;`0807YG;`0<
07]E;P1iERh0N5D]07IE;01dE2/0LE@Z06mD:@1^DbP0LUH^071D;01^DRX0K50X0P1[CbL0601/D2P0
KE4Y06MB9`1WD2H0ITlV06A:9@1RB2D0HTDU0654901P@bD0Dd8T05529@1>?b80BcdR04Lk8@16?2<0
A3`U04Dm9P19>2@0B3LS04Hg9013=RD0@3DS03dd8`80?3<T00L0>S<S03Hd7`0f<b00=C8O03<`7`0b
;b00<2`P0080;b/P0`0X:Ql202LY7P<09RPM0`0S91h2028S7@<08B8L00L08B@M01lR6`0M81T071lH
01/N5`0L7aP07B0I00D07R4J100M81T401lR6`@07R4J0`0J71T201/M6P<071hK0P0L7aP201dP6@0:
01hQ6P0O8Q/082<L020S700S8Qd092<N02LV8@0Y:2<0:bXU02`[9P80:bXU00P0;bTI02dZ6@0^:a`0
;B/N02/[7`0Z;240:2/P02P[8P@08b@L0P0T9Ad202DV7P@092DM100U9QhH024R700O01`S700N8a`0
8RDN02HV7P0[9ah0;bHM038X7P0d9ah0@B`K04Ha7P1>>200EChO05e58@1XD2@0MEd]085W=P2?M3d0
TW8o09Ma@02HKD00TVTm081Q<`1]FBL0H5<O0550;P1;?2T0@CDU03H^8`0]:R40:BXT02H[9`0202H/
:PP09BPQ200W:28202PY8@0602TZ8P0Z:b<0:b`T02`]9@0];RH0;RlW0`0/;2@402d]9@0N02h^9P0Y
;bD0:bhS02X]8P0/;R40;RlQ038`8@0f<b80>3DT03hc7`0o=200@3DQ048g8`13>2@0ACXV04Hk9`17
?2P0BD8V04Q19@19?b@0BCdS04`n901>?RD0D40W0590:01B?b40E44S05M49P1JAbT0G4T[0P1MBR`0
0`1LBB/0G4TX05e::@0205i;:P0405e::@1KB2L0FDHU05M48`<0ETD[0P1GAR`00`1IB2h0FTT_05]:
<0020597:`0B05E7;01FAR`0EdH/05U5;01JARd0FdD]06=8=@1TB3<0I4Pb06M9;`1ZBbh0Kdh]07AB
;`1eDbh0Q60^08IR<027IS<0RFTh0P29JcT08P26JSX0QFTi07QL=@1eFcH0LeTd071H=01]ES@0JEDd
06MD=01VDc<0IePk06EF>@1TDcD0I54a06EA<01WD2h0J54_06YB;P1/E380K5@`06iD;`1aEBd0MEP/
07]L;@1oHBl0PV8_09AU;@2EIRh0UfT^09]]<P2NL3@0XG<e0:Ag=P2UN3L209ae?080WGHm0P2NMch2
09mh?`0809Mg?02GMch0UGDl09=b?02AL3/0Sfhk08i/?02=Jc/208iY?007095]?@2CKcl0Sf/i08]W
<`2;J380TFhf09Qe?@0209Mc>@0609Qd>P2IMC/0VgLm09ah?P2MNCl0WWY00`2HND005@2GN3l0UGHm
099c>P2?L3L0SFhe08m/;02CL300V7De09Yg=`2IMSH0VgPh09ml?02TPD40WX1009an@02HNd40TGQ0
08]d@P25L440P6e207i[@@02081T?`0707iR>`1mHCT0Nf0e07UN<@1hGC00Me`]07=I=00207EI=003
07IH=01hEc@0NELd0080NUHd00H0QE/c08EK<@23G340PUd`089N;P20Gb`207mP:P80P64e00H0PV4f
089O=@23GS@0PEXa07mH;`1oEBd207mO<004081P<@22HS<0Pf<d08EU=P80QVHg00H0P64Z081Q:`20
HB/0Oel/07mO;P1nGRl207iM<080MUT_0P1hF2l0101iF2l0NUL_07aF;`1lERl807]K<P0H07aO=`1g
FS80L5@]06eC;P1]EC40KEHd06]D<P1VDS40M5L]07EI<@1hG3@0N5lg07QP>P1eGcX0L5`i06iJ=`1]
Ebh0KUP_06mI<01aFc80Ledd07AN=@1eGcH0MV0g0P1_GS<02P1]G340K5/`06YI;P1XEb`0IeH[06IE
:P1ND2/0GDlZ05]=:01IBbH205Q:9@80FT`W0P1HBBP205U::@80FT/Z0P1KC2/305Y<:@0;05a<:01P
CRP0HdlZ06MA:P1YDbX0Je@[05mC;@1MDB/0F4/X05A79@1AA2@00P1?@B@01@1@@RL0BT4T04Y19019
@2<0B3lR0080AchQ1P16?B0204Ln8@80B3lR0P1<?ad01P19?Qh0ASdN04<l7`10>ah0?cTO03hj7`80
>STM00@0>CPL03Pg6`0g=QX0=cHJ0P0f=AT803@g6P<0=C<L0`0d<Q/203<a6P80;BlG00<0;BlI02d_
6P0/;A/00P0/;Ad01`0/;Al0:RdL02X]700Y;1/0:2/J02LZ6@0V:AP00P0U:1L802@V608092LN00H0
8RDN020S700N81/071hK01/M700J71/801TK61005aTH200I6aXY01LI60P05QPG200G6AP801HH5`P0
5aTH400F61L801HG6A005QPG400E5aH@01HH5`<05ALF0P0F61LM01LI60<061XI0P0I6aXB01XL6`<0
6A/J0`0J71/201/M70P06adJ0P0L71X301dM6`<07QhL0P0M7QP201hO6@807b0J0P0P8A/8024Q6@<0
8ahH0P0T7aT302DP6P0802LS6P0V8QT09B4H02@P5`0S7aH0920G02HR6@0W8aX202HT5`<09bDH0`0X
9QT02@0[:A`0:RPK02TW6P0X9QT0:BLJ02XX6`0/:Qd0;R`O030Z7002034Y7003038X700d:1`0=BLL
0080=bHL0`0`9Qd2034W7P<0<RPO200h;1`00`0d;1l0<b/N038Z7@02034Y7007038Z7@0c:ah0=2`O
03Tb7`0h<Ah0=RlL03@]6P0403</6@P0=bTN00@0<b/N038Z7@0b:Qd0<RXM0P0a:A`2030X6`0303</
6P0b:aT0<BXH00<0;bPF00<0<BXH038[6@0c;1X00P0i;B40100h;200=b/O03HZ7P0e:Ad203@X70P0
=2/J00@0<2LN034X7`0a:1l0<BPO100b:B005P0c:Ad0<RPL034W6`0a9a/0<RPL03@Z7P0f;200=bdQ
03@_700d;A/0<b`J03@[6P0f:QX0>B`L03d]7P0n;Ql0>RhP03/]800k;Qh0?RhN03l^7P10;A`204<^
6`08040b6012=1X0A3HL04Dg7@16>1h0ACLM04@f7013=A/204Hg800404Ph7`1:>Al0BcXN04hk7@80
D3/L0`1E?BD205Hn9P<0EclW00P0F40V05U19`1L@RL0GT<V06549P1Q@R<0HT4R06507`<0I4HR0P1U
Ab<306I890<0I4LY0P1SARP306959`D0H4<S0`1QA2@206A79`0>06959@1QA2@0Gd8R05i18@1M@200
G3lO05m19@1M?b<0FS`P05Pj7P1I>al0FcdQ05m19@1Q@bL305Pn8`80EcdR0`1F?24205U08PH0F3lQ
00/0DSdP05<n8@1D?b80ED0S05@o8P1C?R40DC`O050k7P1D?2@0Dc/S054i8@02050h8080DCTQ00H0
Dc/S05@l901@=aT0DSTK05@k7@1F?Al305Ln800405Hm7`1E>b00ES`Q05Pn8`80FClT00D0F3hS05Hl
8@1E>b00EShR05Lo8`0205Q0900405Lo8`1F?R80E3`P058j7PP0DcTR00H0D3LQ050h801A>B40DSXP
05<k7`1D?Ah205Dn7P0305/m8@1L?R80GT0T0080GT0T00<0GClS05/m8@1J?2000`1F?R801@1G?B80
ES`Q05Ll8@1G?240FC/Q00P0Dc/S0`1>>ad204ll7P<0D3dO00H0CchT054m901A?B@0DS`T05@l901E
>b@205Hj900@04lo9@1>?R@0C3`R04/k8@1:>R00Bc/Q04`l8P1=?B<0DCHQ054h8P1B>B<0D3XS04hj
8P1:>200AcLN04De70<0@SDR0`13=R<204@g9003040c8`0o<R80?C0P0080>bhN01<0?2lO03d`800n
<B40@SDR03ha7P0k;Q/0?2lL03lb7`10<b00?C0M03X]6P0o;al0@C0N048a7`15<al0B3<N04/e7P1>
=Qh0CcLO00P0CCdT0P1A>280101B>B<0DcXT05<j901D>bD205Dl9P80G48W00@0Fd4V05To901H?R<0
EcdR0P1F?24405Dk8080ES`Q0`1G?B80201M@Rd0G44/05]1:P1J@2L0FT0U05a39@1NABL0GdHW201H
@B8605Pn8`80FClT0P1H@2@605Lo8`0305Y18`1I@280FD0R0080F3lQ0P1G?R002@1F?Al0C44U04]0
901=?B<0CC`R04lk8P1C>b<0ES`U05Pl9P0205A18`80Dd0R00D0DSlQ054n801@?Al0D3dO05Ti8002
05Pj800505Ll8@1F?240ECdQ05<n8@1D?b800`1H@2@[ooooo`00:_ooool0102PMD80XGI30:5f@`2Q
MT<20:9gA080XgQ50P2SN4<40:AiA080YGY50P2RMd@20:=hA@<0Y7U600<0YGY70:IkAP2VNdH01P2V
NdH80:MlB@80YWa:1P2WOD/20:ImA@040:ImA`2WOTX0Ygi:0:MmB`80Yge=202YOdd80:V0C0T0Z7m;
202YP4X30:V0C0030:Z1C@2[PTh0[8=?0080[8=?202YOdd20:N4CP040:J3C@2UPT`0Y85;0:>0BP80
XWm90P2UO4P01P2TNdL0XWU50:5hA02PMd<0WgI209ie@@80WWA200<0WG=109ab@02LLT000P2KLCl0
6P2JL3h0V79309Ma@P2FL440U6ho09=]?P2AJc`0T6Xk08mY>P2CIcX0TFDh08mS=P2<H3<0Relb08aP
<`2=HC@0SV8e08YU>029I3L0R6<f08MR=@25H3<0Q5lb08=N<@22GC00OU/a0`1oG3803@1nFc40NeP^
07UF;01gE2X0N5D_07MD;P1fDbd0ME8/07IC;@1gE2h0NEH`07YG<@1cDRl0101bDBh3075@;@0806a@
:`1[CbX0JddY06e<:@1_CBX0LTh/07A@;P1hDC0207AA:@0307EB:P1fDb/0Me@/0080N5D]00@0NEH^
081K<@20Fc40P5/a0P21G383089M<`0608EO<026H340Qf4b08QR<`29Hc@0RV@e0P2;ICH308MS<`80
R6@d0`29ICD00`2:I3D0RfDf08eW>00208iX>@0308eW>02;ICH0RV@e0080TVLj0P2AIST01@2@ICP0
Sf@g08mT=`2?I3L0SV<f00P0T6Dh00P0SfTj08iX>@2=IcP0S6Hg08eW>02>J3T0T6Xk095[?080RF8g
00@0RV<h08]T>@2=IS/0SVLl0P2?J3d208eS<@0608iT<P2@IS@0TFLe099X=P2CJCL0U6Xh202@ICP8
08]U=P80RV@e00@0RfDf08aV=`2<ISL0SFLh0`2>J3T208eW>00308]U=P2:I3D0RF<d0080R68c00<0
Q5ha08IP<`28HSD00P2:I3L00`29HcH0R68e08MQ=00808MS<@P0Peha1022H38208=Q<`80Q68d00<0
O5T_07eJ<01oG3800P20GC<00`1oG380OEX`07aI;`0307UF;P80NUL_0`1kF300301kEBh0NEH^07QE
;@1fEB`0M5@[071C:@1_E2T0KU<X079G;01`EBX0KU<X06aA9P80Je0U00P0K54V06eB9`1WDRL0IU4V
06I?9P1UC2@0IDTT06=69080HT<T00P0E4<U05529@1>?b80BS`Q04Lk8@16?2<0ACdV04Hn9`80BCPT
00@0AcPU04<f9@11=R@0?c<S0`0l<b@0200f=1l0=S<P03Db7`0c<1l0<RlP034]8@0`;240;b/P0`0X
:Ql302LY7P809RPM0`0S91h3028S7@808B8L00<08B@M01lR6`0M81T00P0K7QL00`0L7aP07B0I01lR
6`0401hQ6P@07B0I0`0N8AX301lR6`8082<L0`0J71T201/M6P<071hK00H06ahG01`O600L7aP07B0I
01hQ6P0O8Q/2020S7004028Q700T8ah09bHQ02TX8`@0:bXU00T0;bTI02dZ6@0/:AX0;2XM02XZ7P0Z
;240:bhS02/^9@0R8a/00`0S91`202@U7@809BHN0`0T9Ad502DV7Q008B8L0P0R8ad4024R7080824K
01l06b8K01hS7@0Q91d09RHN02/W7P0_:1h0<RPO03DX7`12;1h0AS4P04/e7P1A>Ad0EclK065:801_
EbL0N64_081U<02:JSL0Ufln09U]?P2BJST0R6Hf085Z=P1nKcP0Gddg05M6=018>bX0>C4T02dZ8@0V
9b408bPT00808bTW200U:24802LX8P80:2TQ00@0:BXR02X[8`0/;BD0;BhV0P0^;bL302d]9@D0;RhV
00P0:BlU02P^8P0Z;B80:bdP02h_8@0b<240=3<Q03Ld8`80?C8N00@0?c@P040e8@12=b<0@cPT0P15
>RH03@1:@bL0BD8V04Y09@1:?R@0C3hT04hn9@1@@2L0DT0X050m7`1B?b40ED8T05U6:01KB2X00`1M
BR`3069?;P09061=;01MBRT0FDHU05E28@1B?ah0E4<Y05E4:P1GAR`0FDP^00<0FTT_00<0FDP^0596
;01BAR`00P1EAbd0=01FARd0EdD]05U5;@1IABd0I4Tf06E8=P1TB380ITP^06Q9;@1]C2d0LDl/07=A
;P24GRd0Q60^08MS<@28Ic@0RVXg08Y/>029KST0RVlj07mS?01nHS/0NV0k07IN>P1bFcT0KUXi06aH
=`1ZEcL0J5Tl06IG>P1UE3H0IE8b06EA<01WD2h0J54_06YB;P1[E380K5@b06]C;@1]E2`0LEH[07EI
:P1kGB/0OEl]09=S<P2DIC40UfPb09Y/<@2MKc40X7<`0:9f;`2SMbh409ef?@0409ig?P2ON3l0X7U0
0:5j@@80VWLm00H0V7Dm09Ic?@2DL3`0TVhl091/>P2?Jc/2091[?P07091/?02BKSh0U70n09Ea?@2E
LS`0U74i09=`>00209Qd>P0609Ue>`2JMS`0VgLm09ah?P2MNCl0WWY0102HNSh0702FN3`0TgDi091b
=P2?LCD0SFXX099_;@2GM380VGHd09Yg=@2LNCL0XGhl0:J3@@2JNcX0V7Xj09Ii?@2BND40SWM308Ye
AP27M4T0QGA908AZA@23JD@0PFQ007iU?01lI3P0NF4e07MO<@1fGS0207AJ=@0307IJ=@1gFCD0NEPe
0080NUPe00T0NeLe08=I<@23FC40P5T^07mJ;@1oFb/0OE`Y07aL:@1mGRP00P1oH3@2081O=00:07mL
<P1mF2h0Ne@[07UB:@1mG2l0OUd`07mN<@20Gc80PV4d08=R=@80Q6<f0P1mGRP0101mGBX0OEd/07eM
;P1mG2l207iM<P0607EI<@1fFC40MUTa07QH<@1iEc40NULa0P1lES4807QK<`0H07eP>01gFc@0LED^
06iD;`1_Ec<0KULe06YF=@1WDc80MUT_07MK<`1kGcL0O6<k07]S?@1hHSd0Lell071L>@1_FC00L5Xa
075K<P1cGC@0MElf07MQ>01hHST0NF<j0P1`Gc@02P1^GC80K5/`06YI;P1YF2d0IeH[06IE:P1QDbh0
Ge4/05]=:01HBRD305I88`0605M9901HBBP0F4TX05Q9:01IBRT0FT/Z0`1KC2/03`1HBRL0FT`Y05Y<
:@1MCBT0HU0Z06EA;01XDR/0J58Y06UB:@1LD2X0FTdZ05I99P1CAR@0D4<S04m1900204i09@80BT4T
00<0BD0S04Po8P17?R400P16?B0204Dl7`<0ASdP0P17?R4204Po8P0804`o7@1;?Q`0B3dM04Hm7P13
?1l0@3/N03li7`0n>Ql203Xi7@0303Th700h=a/0=cHJ0080=SDI00<0=C@H03<h6P0c>1X01P0c>1X3
03Dc7080=38K0`0c<AX202d_5`0302`^600/;QT0;2dK0080;2dM00L0;2dO02X]700Y;1/0:B`K02P[
6P0W:QT09RTH00809BPG200T9QP202@W7P06028U7P0P8Qd07R0M01`N7@0J71/06AXL100H6QL401TK
61005aTH200I6aXY01LI60P05QPG200G6AP801HH5`P05aTH400F61L801HG6A005QPG400E5aH@01HH
5`<05ALF0P0F61LM01LI60<061XI0P0I6aXB01XL6`<06A/J0`0J71/201/M70P06adJ0P0L71X301dM
6`<07QhL0P0M7QP201hO6@807b0J0P0P8A/8024Q6@<08ahH0`0T7aT202DP6P0302PT6`0V8QT09B4H
00808alF00<0920G02DQ600V8QT00`0U8aH202HT5`<09bDH00<0:bTL02XX6`0Y9aX00P0X9QT0100Z
:1/0;2XM02h/7`0`:Q`2034Y7003038X700d:1`0=2HK0080=RDK00@0;bDL030V7@0`9Qd0<2HM0P0a
9ah2038X7`P0>2`L00<0<bdQ038/800`:Qh00P0_:Ad02`0`:Qh0<R`P03<]8@0j=B40=c8N03@_6`0a
;1P0<2/G034/600b;AT0<bhJ00P0=RPO0`0a:al2030Z7P<0;bTM00<0<RdJ034/6@0_:QL00`0^:AH0
0`0_:QL0<B`I038]6P0203X^8P0603T]8@0g:al0=BTM03@X700c9a/0<RHJ200d:aX202hW7@80;bPN
00H0<2TO034Z800b:b40<R/Q038X700a9a/2030V6P0B034W6`0d:Qh0=bdQ03T_8`0e<1d0=2dK03</
6P0c:QT0=RXJ03P[6`0l;1d0?RhO03X^800k;B00>bhN03d]7@0m;1`0?R/J0P10:aP00`10<QP0@S@J
04<e6`0304Dg7@0;04@f7013=A/0AcPQ04Lh8@18>1l0BSTO04/j7P1=>Q`0CSTJ04lj6`1D?2@00`1E
?BD205Hn9P80EclW00T0FD4W05Y2:01M@bP0Gd@W06549P1P@B80H3lP05ln7@1SAB400`1TAR8206E7
8`80ITPT0P1SARP306959`<0HD@V01<0FchN05`o7`1M@200Gd8R0654901RABD0I4LW06E8:01TAbL0
HdHV06959@1QA2@0Gd8R05e0801L?al0FchN05m19@1M?b<0FS`P0080F3XN00<0FcdQ05m19@1Q@bL0
0P1H?R<205Lm8P<0ES`Q00<0EC/P05U08P1H?b400`1H?b4305Ln800;054l7`1B?B00E3lR05E08`1D
?b80DchQ054l7`1@>ah0E3`T05<k8`1A>B400P1@>202054i8@0605<k8`1D?2@0CcHH050g6@1C>Q`0
EC`N0P1F?Al205Dl7P0305Hl8@1G?B80FClT0080Fd4V00<0FClT05Lm8P1F?2400P1F?R801P1G?b<0
F40T05Lo8`1E?B40Dc/O058j7PP0DcTR00/0CcHP04lg7`1@>200DCTO058j7P1C?1d0Dc`L05@m7@1J
?200FcdQ05do8`0205i0900305do8`1L?R80FcdQ0080ED0S00@0EShR05Lm8P1H?B80F3dR0P1J?282
05@l90@0Dc/S0P1B>R8304`k7@<0CC`N0P1>?Al01P1??R@0DCdT054m901B?2@0E3`T05Dk9080ESXT
00<0CclU04hn901<?2800`1:>R0204`l8P09054f8@1A>280DCPR050j8`1>>R80BSPP04Lg7P15=A`0
?c@R0080@3DS00P0@CHT048g9@13>2H0@cPV04@i9`0n<R80?C4Q03/_7`<0>RhN0180?30P03da8@12
=B80?S4N03X]6P0k;Q/0@3<P044d8@0m<1d0>B`I03l^7P10;ad0@RlN04Ha7P19<ah0BS@M04de7@1>
=Qh804dm9080DCPR00@0DSTS05<j901C>R@0E3/U0P1E?2H01P1OABX0GT@Y05e3:01K@BH0FClT05Lm
8P80EC/P0`1D>Ql205Dk80<0ES`Q00T0EcdR05e2;`1K@2/0FSlZ05To:01J@2L0Fd4V05i59`1OARP0
201G@24305Lm8P@0F3hS00<0FClT05Q0901G?b<00`1G?b<305Hn8P80FT4S0P1I@280301H?b40EchP
05Ln801F?Al0Bd4V04To901;?B<0Bc/R04hj8P1C>R@0ES/V05Pl9`80DD0R00<0D3lQ04ln801>?Al0
0P1=?1h01`1<>ad0F3PO05Li7`1H>R00ES/P05Hl8@1E?B400P1D?b8305U19B_ooooo000Zooooo`03
0:AhA`2SMdH0XGE400<0X7A30P2RMTD02@2TNdD0XgY40:5h@P2PMd40WgI00:1g@@2QN480XWU30:=j
AP020:AkA`050:ElB02VODT0Ygi:0:MnBP2XOd/00`2SMdP20:AhB@<0YGU:0P2XOdL30:MnAP<0YWe5
0`2UNTL00`2VNdP0Yga90:QmBP020:QmBP80YW]60P2WO4L0102XODP0ZGi90:UnB@2ZOdX80:YoC0<0
[8=?00<0Zh9>0:Z1C@2YP4`07P2YP4`00`2ZPDd0Zh9>0:b3C`020:b3C`060:^2CP2ZPDd0ZH1<0:Qo
B`2VODT0Y7]70P2SNTH20:QoA`040:MnB02VODT0YGa80:AjB080XgU90P2MN4@209ag@`0509]f@P2J
MD40VGA009Ud@02HKS`00P2GKC/00`2FK3X0UF/i09AZ>00209=Y=`@0SVTe0P2=J3@208aW<`80R6@d
0P27Hc<01026HS80QF4a08AP<024H30208=N=003089M<`21G380PE`b0080P5/a00H0OeX`07YG;`1j
Ebl0NEH^07QE;@1gE2`207IC:`0707EB:P1`Cb`0L4l/06m>;@1_CRl0Kdda06i<<00206i<<@P0LE0]
00h0M4d^07E>;@1fCbh0N58^07]E<01mEc00OUT_07mJ<01mERd0OUL^07mH;`20FC00PEXa08=L<`80
Q5dd00/0Q6@e08=S=023HC<0QF0c08IQ=029HcH0SF@h08iU>@2;ICH0RV@e08US=00208QR<`0308US
=02:I3D0RfDf0080SfTj0P2>J3T01`2=IcP0S6Hg08aV=`2;ICH0T6@c099V=@2CIcH00P2EJCP209=W
=P03099V=@2@I3<0TFHi0080TFHi0`2@ICP208mT=`P0SVPk202;I3T03029Hc@0RV@e08aV=`2>J3T0
SfTj08iX>@2<ISL0RfDf09U^@@2FJch0TfPk08mT=`80SV<f00<0Sf@g091U>02CIcX00P2BIcX00`2A
J3X0SfTj08iZ>P0208aZ>P0608YS?02:HcX0RV<j08]T>@2;ICP0RfDf0P2<ISD208aV=`<0RfDf0`2:
I3D408YT=`H0RF<f00@0R68e08MQ=027HC@0QV0c0P25Gc800`21G2l0Peha08AO<P0208EP<`0908AO
<P21G2l0P5/^08AQ=`23H3H0PUle085N=020GC<0OU/a0080OEX`0P20GCL00`1oG3H0OU/e07eJ=002
07aI<`0407]H<P1mFS00OEX`07eJ<0<0OU/a0P1oG3800`1mGCH0Ne/d07QH<@0307EE;P0@07MG<01i
FC80L5/`06eH;@1YE2T0IU4V06E@9@1VDBH0JE@Y06]F:`1`DS00KE0^06Y=:`1UBbP0HTXV061:9@80
Gd/V00h0ET<U05E19P1D@2D0DCdT04lk8`1=>2<0BcHS04Xe8P19=al0BCTP04Xj8@1:?280B3`R04Dk
8080@CXN0180?cPL03Xh7`0i=ah0>CLP03Pf8@0f=1l0=C8O03<`7`0b;ah0<2PM02lV7@0^9ad0;2PO
02XW800X9b809bHR02HW8P0X:Ql202LY7P0302DW700T9Q/08bDJ00808R@I0P0P8a`301lR6`<07R4J
100M7a`201`N6`806adJ0`0Q91d2020S70<07b8K0P0K7QL301`O60<07B0I0P0L7aP201dP6@807R4J
0P0O8Q/202@Q700402DR7@0V8ah09b@O02PU8080:BHQ00H09BHN02LW7@0X:1h0;2XN02l[7`0b;1h2
03D^7P0902TZ700X:1`09RHJ02DU6`0U9Ad09RDP02PW8`0Y:2@0:2PN00809bLM00<09RHL02DU6`0U
9A/00P0T91X0200X:B409bPP02HW7`0T9Ad08b@L024R6P0P8AT07b0H0P0Q8Q`3020Q6`<07b0J200Q
8Q`0100P8A/08B8L024R700R8ad202<T7P8092DO01L0=BPR03TZ8`10<2<0BCLS05<m9@1LABD0HdTV
06M;901gFb/0Of<c08a]?P2CLd80UWA409YfAP2LN4P0X7Y;09ibA@2=HcT0JTPU04H^500e9AH0<BXT
02/[:`02028U:P08024U9P0T9BL09RLY02LW9`0X9bD0:RHS02/W900/:B@802P[8P<0:BXR0`0Z:b<2
02//90P0;2dU200_;bD04@0i<B@0>S<S03/d900m=R@0@3TV048l9P13?BD0A3hV04Lk:`18?2`0BSl]
04]0;01;@2X0Bd4X04To9P18?R<0CD<X0080CT8X00L0D48X05=3:P1E@b/0FDD]05]7;`1KBbX0G4`[
0080GDd/00@0Fd/Z05Q89`1EAB@0E4@S101EAB@405I69@0h05=08P1F@bD0FDHX05a9:`1MBR`0G4T[
05U6:01GA2H0G4T[05]8:P1OAb/0HDL/06M9;`1^C3<0Ldlg07I@>@1hFc<0NUde07mP=025ICH0RfXg
095]>@2DLCT0UW4j09E]<P2AJS40RfHa08EQ;`1mG2l0MeXb07=G<P1`ES<0GUH_05mG<01RES00HeD`
06ME<@1ZDc40JU8`06]A<01/G3X0I5@`065=:01WDBP0M5``07eP=01mGRl0N5PY08AL:@27GRX0RV4]
091U<02HJc@0X74i0:Mf?02ZNCl209ig<P0609ef=@2LM3H0Vg<h09Ya>`2JLCd0VFlm0`2CLcH01@2B
LSD0TG4d095a=02ALC@0T70c0080RW4h00L0Rg4h08e_>@2>KCX0TF/l09AY?P2FJCl0V6Q00080VgTj
00<0W7Pj09ih>P2OMcX00P2PMSX07`2RMCX0W7He09af=`2JMSP0V7Dk09Ic?@2AL3/0SVhk08a/>`2<
JcH0SF`f095^=02ELS80VWD_09ei;`2ONR`0X7/[0:Qf>`2XMc`0Yg/n0:Al?P2OOCd0VGhk09Am>@2@
O3L0TgU8091eAP2;L4<0QVY2089V@@1oHT000P1nHD<02P1cH3H0MV0g07QQ>01lH3T0OUhh07iL=`1o
FCD0OUPd07aP<01mHC4207iR<P0I07eQ<@1lH300NUh^07QL;022ISH0Of@e07eR<`1iHC<0Mf0d07IQ
=P1dHCL0MF8h07aQ=01kH3<0NEhc07QM<P1fFS80METb07EI=01dF3<0MUPT07QJ9P1jG2P0OEl[07mQ
;@02081R;P0:07mQ;@1fGcD0ME`c07=J<@1cEbl0LeH^07IF;`1gEBl0N5H`06mH;`<0L5T`0P1aFS42
079K<P0406QF<01^G3H0M64i07EO=P80LU/a00<0N60d07iV>P1lGcL00P1lH3P00`1kHST0Nf@j07YU
>P0207UV>`0L07mR>P1mHSL0OF8g07]S=@1iHc80N6@a07IU<@1fIBl0M68b079P<P1^GBl0J5X]06AE
:P1ODRP0FdlW05Y>9P1SE3<0GTl^05Q9:01FAbH0EdPW05Q9:01FAbH0Dd@S05E78P1GBB@0FD/V05]=
:080G4hY00<0FddX05Y<9`1KB2000P1OC2@0401UDRX0JUL_06]H<01WE2`0HTlW05i;8`1IBBL0EdTV
05E69@1BABD0CT<U04]29@17@2<0ASlS04/m8P1<?R<204i09@0704do901:?240AcTN04@f6`0m=QX0
?cPL044j7P0204<l8003044j7P0o>1`0?CHJ00<0@CXN0P12>al304<l8008040o8`0o?R80?C`P03/j
7P0i>1`0=cHJ03He6@0e=1P2038d7080<cDM0`0d=Qh00`0e=al0<3@M030d7@0302lc70<0;S8K00H0
;30I02`_6P0/;aX0:bhK02/^7@0Z;1h202X/7`0802LY7P0X:Ql0:R`Q02X/8@0Y:b009bTN02@V6`0S
9AX202/X8@0402XW800Y9Ql0:2DN02PU7P809b@M00P08B@M020S700O8Q/07R4J01dP6@0L7aP06ahG
01XM5PP06Q`I0P0J71/201TK6P8061XI6P0G6AP0100J71/06A/J01TK6P0I6aX201PJ6@805aTH500H
6QT301LI60805QPG200G6APH01HH5`P05aTH200F61L801DG5PP05AHH200F61L@01DG5PP05QPG200E
5QP801HG6@P05QPG0`0H6QT301LI60805QPG200G6APA01TK6PP06adL0`0I6aX301XL6`806adL200J
71T201`L6P<07AdK0`0N7Q`801hO6@P0824K200Q81/2028R6P<08b<K0`0T91`802XS6`<0:BDL0P0Z
9Qd;02/W7P80;BLK0P0^:1`302lY7@03030Z7P0e:Ad0=BTM00H0=BTM200f:1l2038X7P@0<bTO0P0d
:R0203<V7@0403@W7P0e:1l0=BPO03HY8080=bXQ0P0g:ad0100f:Q`0=BTK03DY6`0d:1X203<W6@04
02/U6@0/9QX0;2HJ02dW6`<0;RPL0P0_:Ad803@]7@<0<bdQ0P0b;203034[7`80;RPL0P0_:Ad0100`
:Qh0<B/O034[7`0b;20803<Y7`80;RXO00H0;bTM034Y700c:Q/0>2`L03/^7P0m<1l203/^7@80?2lN
100m<1l204Lb8@0604Hc8P15=280ACHS04<f8`14=b@0@cPT0P18=R000`19=b40BSPR04/i8`0204`j
900704dk9@1>?2H0CS`V04lm9@1@?bD0DD0T05918`0205=38P0305i0901O@BD0HD<W0080HT@X00D0
HD<W06129P1O@BD0FC`J05m2800206E89P0306548P1O@R00HD@R0080I4LU00L0IDPV06I99`1VBBL0
IDPV06=6901QA280H4<Q0080GDDQ00@0GTHR05m78`1OAb<0H4PT0P1QBBD205a29`80Fd4V101J@2D8
05Pn9`P0EclS00<0DcTR05@j8`1F?2D00P1G?BH02`1F?2D0EC/T05@j8`1F@B@0ED0S05@o8P1B?B00
D3/N04hi701<=aX0BcHI0080B3PN00<0BSTO04di801?>B400P1B>R802P1C>b<0E3XS058c7P1B<ah0
DCDO058h8@1C>b<0DS`T05<m9@1C?bH804hm8`0405M3:P1E@BP0DShU050l8`80CSXQ00D0Cc/R050l
8`1=>B40CCTQ04`h800204/g7`0;04Xf7P19=Ad0BCDM04`c7`1==200CcHP054i8@1C>b40ECdQ05Ho
801G@2400P1K@2<02@1K@BH0FT8X05M1:@1D@2P0DSdX04lm9`1<=Ql0CCLP050j8`03058l9@03050j
8`1?>B80Cc/R00L0Cc/R201>?2@305@j7`80EC/P0`1F?240201E@B00E40O058o7`1>?Al0C3/O04Ti
7`17>Ah0ASPN0`1;>B<00`1:>280BCLQ04Pf800204Pf8080@C@Q00<0@3<P044d8@11=2400P12=B80
0`13=R<0?c@R03ld8P0203hc8@@0?C8P01<0?S4N03d`7@0l;a`0>bhK03`_700m<1d0?c8O044d8@11
<AX0@S8K04<c7015=Ah0ASHO04Ph8@19>B80BSXS04lm9@1>?2@0CC/S0080C3XR00H0CS`T050n9P1A
?bL0Dd8T05918`1??R0304dl7P0304ln801@?b40E40W00<0DclV0P1B?RD3054m90<0EchX00<0ESdW
05Dl9P1D>bD00P1D>bD0201G?R00Ed0Q05Q18P1G@R<0ET<S05928@1?@1l0CChM0P1B?RH0101C?bL0
E40X05E1:@1E@BT205I2:P0@05A18@1E@R80Ed@T05Q59@1IARH0F4DU05M4901F@b<0F3hS05To901J
@2D0Fd4V05Y09@1I?b@0EcdR05Hl8@P0F3lQ00<0DShU054m901?>b800P1>>R401P1?>b80DCdT058n
9@1A>B40Dc/S05Dm9@80EShV00L0ECdU05<k8`1A>B40BcPJ04dj701@?Al0DSlQ0080E44S00<0Dd0R
058o8@1C?bH00P1C?bH[ooooo`00:_ooool01P2UNDP0Y7Q70:9fA@2PM4<0Wg=20:1d@`80XGE400P0
YGa60:AkA@2RND<0XGQ20:1g@@2QN480XWU30:=jA080Y7]70`2UO4P30:ImB@80XgM80`2TN4T30:Ei
BP@0YWe5102WOTH20:EjA`80YW]80P2WO4T20:QmBP80YW]60P2WO4L0102XODP0ZGi90:UnB@2YOTT8
0:YoC080[8=?0P2[PTh00`2ZPDd0ZH1<0:V0C00L0:V0C080ZX5=0P2[PTh20:b3C`040:Z1C@2YP4`0
Z7m;0:MnBP80YWe900P0YGa80:AkA`2XOdL0Z7m70:MnB02VODT0YGa80:AjB080XgU900H0WWU509eh
A02MN4@0W7M309]f@P2JMD4209Ud@080V6hl00L0Ufdk09I/>P2EJcT0UF/i09AZ>02CJCL0SfXf00<0
SVTe0P2=J3@208aW<`0608UU=@28I3@0R6@d08MS<`26HS80QF4a0P24H30208=N=080PUdc00@0PE`b
081K<@20Fc40OeX`0P1jEbl0101iERh0N5D]07MD;01gE2`207IC:`06075A:`1aD2d0LE0]071?;P1`
Cc00Kdda0P1_CC88075@;@06079>;P1cCbd0M50^07IB;P1hEBl0NUL_0P1lFBl207eF;@0607iG;P20
FC00PEXa089K<P23G3<0Q5dd0P23Hc@02@23HC<0QF0c08IQ=029HcH0SF@h08iU>@2<ISL0RV@e08US
=00208QR<`0308US=02:I3D0S6Hg0080SfTj0P2>J3T01`2=IcP0S6Hg08aV=`2<ISL0SfDc091V=02B
J3H00P2CJCL2099X=P03091V=02?IC<0TFHi0080TFHi0`2@ICP208mT=`P0SVPk202;I3T00`29Hc@0
RV@e08aV=`0308iX>@80S6Hg00@0UFXm09AY?02BIcX0TFHi102@ICP01P2CIcX0TVLj099W>P2AJ3X0
SfTj08iZ>P80S6Xj00H0RV<l08YS>P2:HcX0Rf@i08]U>02<ISL208aV=@<0S6Hg0P2;ICH308YT=@80
RfDh0P2:I3L208US=P80R68e0P29HcH208QR=@0708MQ=026H3<0QV0c08IP<`23GS40Q5lb08EP<`02
08IQ=00408EP<`23GS40PUd`08=P=P80PUle00D0PEhd081M<`1oG380Oe`b07iK<@02081M=`0407mL
=P1nFcD0OEXd07eJ=080O5Tc101nFc4407eJ<00407]K=01jFS<0NETb07MG<0<0MUH_00l0MeL`071K
<01]F2d0JE@Y06IA9P1UD2D0Ie8W06UD:@1[ER/0Ke4_06a?;@1YC2X0I4XW06599@1PBRD00P1NBRD0
3P1GA2H0ET<U05A09@1B?RD0D3`T04dh8`1<=b80BcHS04Pf7P18>1l0BCTP04Tk8@17>b40A3XO0P10
>Ad02@0o>1`0>SPO03Xh7`0i=b00>3HQ03Hd7`0e<Ql0=34P03<`7`02034Y7P0<02lX7P0/:1l0:RLP
02LV8@0V9B009BHQ02PZ7`0W:Ah09RPM02DW700T9Q/08bDJ0P0R91T3020S70807b8K0`0N8AX0100N
81d07AlL01dO700M7a`201`N6`806adJ200P8a`401dP6@H071lH0P0M81T201hQ6P807b8K0P0T8A`0
0`0U8Qd09R<N02LT7`0202PU800B02TV8@0V9al0:2PN02TY7`0/:Qh0;RXN034[7@0c;1`0=2dM02//
7P0Y:Q`09bLK02HV700U9Ad09RDP02LV8@0X9b<0:2PN0P0W9ad202HV70809BDK00L092@J02PY8@0W
:2009RLO02DV7P0S91`08B8J0080824I0`0Q8Q`2020Q6`<07b0J200Q8Q`00`0P8A/08B8L024R7002
028S7@808b@N01P092DO038W8@0g:R80?BlR04He8`1@?2@0FD8S05m79@1SBBH0KU8S07IJ:`23I3H0
Rf`m091`@@2DLT@0VgM709mkB`2TND`0VgA908AR?@1RB2d0B3LU03/c:00c;b`202XZ:P809bTX0P0Y
:BL0100Z:BD0:BPT02XW8P0Z9b8802P[8P<0:BXR0`0Z:b<202//90P0;2dU200_;bD203Ta900D03/d
900m=R@0?cPU044k9@12?2H0@cdU04Hj:P17>b/0BCh/04Xo:`1:?bT0BT0W04Pn9@17?B80C48W04e1
9`1?@bT0DT@Z05A4:`1FA2`205Q4;00805U9:01JBRT0Fd/Z05];:P1IBBP0EdLV05E5901C@b8205M4
90<0F4DU0`1IARH00`1D@B<0ET<U05Y7:@0205e:;00K05a9:`1IARP0Ed@V05a9:`1MB2/0GdL[0657
;01VB2h0JTXa06m==01bCSH0M5H`07II<@1lG3<0PF8d08MW=P2<JcH0TVli09Aa>@2DKC80Tf`c08iY
=027IS<0PV4d07]N=01fFS<0M5Pc0080IE`c01H0J5Xc06YK=01/FS@0L5Xe075I=@1bF3D0KUhj06UG
<`1TDBT0JE<Z07=K;`1kH3<0NEd^07IG:026GRd0QUh[08UO;@2=HRl0TfDa09QY<`2MKSH0XG0h0P2L
MC80102LMC@0Vg<f09]c>02KLS`209]b?P<0U7@g0`2CLcH2099b=@80SW@k00L0Sg8j091a>`2@Kc`0
Tfdn09A[?@2EJSl0UVTo0080VGLj00@0VWHj09ae>P2MMCX0WGDj0P2NM3X07P2JM3D0VgDf09Ue=`2G
M3X0UW<k095`>`2=KCX0Rf/h08UY>P2;JCT0SF`g095^=02DL380V78a09]d;`2KMBh0YG<h0:Ed>@2T
N3/0XWXl09il?02KOS`0UWdj09Am>@2CNT@0TGQ208ab?`27K3d0Q6Tl085U?@80P6@m00T0Mf8g07UR
>01kHST0OV8j085Q>P20GSP0Oe`f081J=@1nHS800P1oHc<02P20I3@0Of<c07eQ<@1kGbl0NUh^089V
=P20I3@0OF8c07QP<P1fGc<207EP=@0707AQ=`1gG2d0Me`_07ML;`1gG340MUXb07IJ<`0207IJ=@04
07EF:01fEbT0NEX/07]L;P80OEh`0P1lGBl0201eGS@0ME`c07=J<@1dF300M5L_07MG<01iEc40NUPb
0P1cFS4207AK<P<0ME`c00T0MUdd06aJ=01_GCD0Lf0h07IP=`1gH3H0N60d07]S=@20ICP00P1oHSP0
301nHcP0OFDi07eV>P1lIcX0OFPk07]Y>`21I3X0P6Dj07mT=`1mICL0NfDd07UU<`80MfHb01@0M68d
079P<P1^GC40JE/^06EF:`1PDbT0G50X05Y>9P1PDC00Fd`[05I79P1EARD0EdPW05Q9:01FAbH0Dd@S
05E78P1GBB@0FD/V05]=:080G4hY00<0FddX05Y<9`1NBb<00P1PCBD03`1UDRX0J5D]06QE;@1UDRX0
HDhV05i;8`1HB2H0ETPU05E69@1BABD0CT<U04]29@17@2<0ASlS04/m8P0304`n8`0704/m8P1:?240
B3XO04Li7P10>Ad0@CXN048k7`0204<l8003048k7`11>Qh0@3TM00P0@S/O0P0o?R801P0m?200>cXN
03Th700g=QX0=SDI03Dd6080<S@L0P0c=Ad403@f7P80<3@M0`0_<a`302hb6`0602``6@0/;aX0;2lJ
02/^6`0[;Qd0:R`N0P0Z;1l202PZ7`80:B/P00@0:2XO02HX7@0T9Q/08bDJ0P0[:2400`0Z9b00:BHO
02PU7P0202LT7@0902HS700P8a`082<L01lR6`0N8AX07B0I01`O600K7QL06QdF00P06Q`I0P0J71/2
01TK6P8061XI6P0G6AP401TK6P8061XI0P0G6APD01PJ6@<05aTH0P0F61L801LI61P05QPG200G6AP8
01HH5`P05ALF200E5QP801HH5a005ALF200F61L801DF60P05QLI200F61L301PJ6@<05aTH0P0F61L8
01LI61406A/J200K7A`301TK6P<06Q`K0P0K7A`801XL6@8071`J0`0M7A/301hN70P07QlI200P8A/8
024P6`<08R8J0P0S8a/302@T70P0:R<K0`0Y9A`302XV7@X0:bLN0P0]9a/202hX70@0;bTM200c:Ad8
03HX7`@0<RPN100c:Al2034W7@80<RPN0P0c:Al203@Z8080=2/L0P0c:Q/2038Y6P80<BPI0`0/9QX0
100]9a/0;RPL02hX700^:1`202lY7@P0<R/K0`0c;B42038/80<0<B/O0P0^:1`202lY7@04030Z7P0a
:al0<B/O034[7`P0<bTO0P0^:Ql01P0_:Ad0<BTL03<Z6`0h;1`0>bhN03d`7`80>bhM0P0l;ah303d`
7`0603ha8018<b80B3<R04Hc8P15=280A3DR0P13=R<01@12=b<0B3HP04Pf8019=b40BSPR0080BcTS
0P1<>R@2050k9P09054m9@1B?RD0DclT05A18`1D@B40ED8R05`n8P1M?b<0Gd4U00<0HD<W00@0H48V
05m19@1J?Ad0Gd8R0P1TAbL0101QA2@0Gd8R06138`1SARH206959@<0I4LW00<0HdHV0654901P@b<0
0`1MAB<00`1NAR@0GdLU05m79@0206189P0405]19P1J@2D0FT0U05Y09@80FClT0P1H?R<805Lm9PP0
EShR00<0DSXR05<k8`1D?2@00P1F?RH00`1E?BD0Dc/S058j8P0205@o9004058m8P1A?240D3/P04hi
7P80CCPM0P18>1h00`1:>Al0CCTP04li8@02058j8P0805<k8`1D>R<0Dc@O054e7`1B=R00DSPQ058j
8P1A>b<2054m90P0CSdS00@0ET8Y05A09`1B?RD0Cc/R0P1>>R40101?>b80D3`S04di8@1=>B4204`h
800404/g7`1:=Qh0BSHN04Xf7P80CC@P01H0CcHP054i8@1C>b40ECdQ05Ho801G@240FSlR05]08`1J
@2D0FT8X05M1:@1D@2P0DSdX04hl9P1<=Ql0CCLP04li8P1A>b@0DS`U054k901@>R<0CcTR201>>R48
04hl90<0Dc/Q0P1D?28305Dm8`0905A07`1C?Ql0DChN04dl7P1;>Qh0B3PN04Hh7P15=ad0BCTR0080
B3PQ0P17=b0204Hf7`0304De7P12=B80@SDR00H0@C@Q0P0o=28203hc8@<0?C8P01<0?34O03ha7P0m
<1d0?2lL03/^6`0l;a`0?C0M03lb7`11=240@C4J048b6`13<a`0ACDN04Hf7`18>240BCTR04Xj8`1>
?2@0CC/S00<0C3XR00/0CS`T04lm9@1A?bL0ED8T05=08P1A?R00D3dO04ll7P1@?Al0DChP058o8@03
05<o9P80DShU101A?B@205Lo9`80EShV0P1E?BD205@l900905Hm7`1F?b00F44R05I18P1E@R80DD4P
04ho7P1=?Qd0DCdU00<0DShV101C?bL0201B?al0Dd0P05E28P1F@b<0Ed@T05I38`1E@R80E44Q0P1G
?bD305U19`0305Lo9@1E?B<0E3`R00P0ESlP00<0D3`S04lk8P1>>R400P1>>R401P1@?2<0DShU05<o
9P1C>b<0E3`T05Hn9P80EclW00L0EShV05@l901C>b<0CS/M04ll7P1B?b40Dd0R0080E44S00<0Dd0R
058o8@1A?B@00P1A?B@[ooooo`00:_ooool0102WNdX0YGU80:=gAP2PM4<309mc@P040:1d@`2WOTP0
YWe70:AkA@<0XWU300@0XgY40:AkA@2VODT0YWe90`2UO4P30:AkA`040:=gAP2TN4L0Y7Q70:AhA`80
YGU80P2VNTT20:AkA@040:ElAP2VODL0Ygi80:MnB080Z7m900@0YGY70:IkB02VNdP0YW]80`2WO4T0
102XODX0Yga70:MlA`2WO4L30:QmB080ZGi9202ZOd`30:^2CP80ZX5=7@2YP4`30:Z1C@<0Zh9>00<0
[8=?0:MnBP2WOTX01P2WOTX20:QoA`040:MnB02VODT0YGa80:AjB080XgU900H0WgY609iiA@2NNDD0
WGQ409ag@`2KMT8209Ye@@80VFlm00@0V6hl09M]>`2FK3X0UV`j0P2EJcT308mZ=P80SVTe0`2=J3@0
1P2:ISH0RFDe08UU=@28I3@0Qf<c08IR<P80QF4a0P24GcD01023GS@0PUdc085L<P20Fc4207mJ<080
NeP`00<0NUL_07UF;P1hEBd00P1gE2`0101fDb/0Le<]07=C;@1cDRl2079A<003075@<@1aCc<0LDlc
00P0LE0]00h0LTh^079>;01dD2h0ME4]07MD;P1iERh0NUL]07]H;P1kER`0O5L]07eH;P1nFBl0OeX`
085L<P80PUdc00/0Pf<d089R<`23HC<0Q5lb08EP<`28HSD0S6<g08iU>@2<ISL0RfDf08US=00208QR
<`0308US=02;ICH0S6Hg00<0SVPi0`2=IcP208aV=`80T6Hd00<0TFLe099X=P2BJ3H00P2AIcD2091V
=0<0TFHi0`2@ICP208mT=`P0SVPk202;ICP00`2:I3D0RfDf08aV=`0308iX>@80SFLh00<0T6Dh095V
>@2BIcX00P2CJ3/0102BIcX0TFHi091U>02CIcX2099W>P03095X>P2?JCX0SVXj0080S6Xj00T0RV<l
08YS>P2;I3/0Rf@i08aV>@2<ISL0S6He08eW=P2=IcP00`2<ISL208]U=P80RV@e00T0SFLj08aV>@2;
ICP0RV@g08US=P28HSD0Qf4d08IP<`29HcH00`28HSD308MQ=00408IP<`24Gc80QF0c08IQ=080Qf8e
00<0QV4d08EP<`24Gc802021GS@01P21GSH0P5de081M=@1oG3@0OU/c07eJ<P80O5Ta0P1oG38207iK
<@0407eJ<01lFBl0NeP^07]H;P@0NETb0180N5Pa07MG<01eEBh0M5@]071I;`1^Ebd0Je@Z06QA9`1W
D2H0J54W06YC:@1[E2X0KU0^06]>;01XBbT0I4XW06599@1OBB@205e9900905Q59@1GA2@0ET<U05<o
901A?B@0Cc/S04dh8`1<=b80B3HN0080B3PO00<0B3XP04Di7`13>Ah00P10>Ad01`0o>1`0?CTP03`h
7`0k=R00>C@P03Pc7`0g<Ql00P0f<200200d;1l0<b/N034[7`0]:Ah0:RLN02LW7`0U91l092DO0P0W
:Ah00`0V:1d09BLL02@V6`0202<U6P03028T6@0Q91d082<L008082<L0P0O8Q/201hQ6P<07R0M0P0M
7a`301`N6`0501dP6@0N8AX07R4J01lR6`0P8a`00P0Q91d01@0R9Ah07b8K01lR6`0N8AX07B0I0080
71lH0P0K7QL201`O60807B0I0P0N8AX201lR6`808R4L0P0S8Qd01@0T8ah09B@O02HU800V9B00:2TQ
0080:BTO00/0;2XN02dY7@0`:Q`0<BXJ038[6`0];Qh0;2dM02X[7@0X:1`09RHL02HV7P0202HU80@0
9bLM0P0V9Q`202DU6`0602PY8@0W:2009RLO02DV7P0S91`08R<K0P0Q8QX0100R8ad08B8L024R700Q
8Q`2020Q6`807b0J300Q8Q`2028S7@808b@N01L0<2LP03<Y800i;B40@S8R04Xh8P1B?R<0FD8S05a5
9@1QAAd0JTlT07II;`21HSH0RFPk091^@02GMDL0Wg];0:=jC02WPUH0W7aE081UA`1RCSH0C3l^03`d
:@02038[8`D0:bXU00<0:RTT02XW8P0X9B00200X:b8302TZ8P<0:R/S0P0[;2@802`]9@P0;blU01T0
=c4U03Pb900i<bD0>cDU03dh9@0n>BD0@3/U044l9P14>2P0ACTY04Ll:P19?RX0BChX04To9P17?B@0
AcdR04To901<@2H0D4@Z05A6;01FARd0ET@/05I2:P1E@BT0ETDW00<0EdHX00@0ETDW05E49P1C@R@0
DT4S0`1HABD205U69P80FTLW00@0FdPX05I39@1HABL0FdPZ0P1MBR`00`1LBB/0FTLY05Q59`0205e8
:`0>05m7:`1PAR/0HTL/06I8;P1WBBl0JDT`06eA;01_Dbh0M5L_07]L<021H3<0R6Hf08a[=P2AKCT2
09=_=@06099_>@2>KCX0RFTj08=T>01kGS@0N5/c0P1^HCL03`1_H3L0LV0h07=P>01fH3T0N60j07UQ
>`1dH3/0KEXb06YD;@1/EB`0LeXa07QM<P1eFRd0LE@X089M<002089L;@0>08AL:`27GB/0S64^095S
;`2CIC40Ufla09Q`<P2HL3<0VG4f09Ya>@2KLS`0W7<m09ac?`2FM3L709Me>080TgHl00L0Tg@k09Ac
?@2CLSd0UFln09=]?P2DJcd0U6Tn0080Tg<f00<0UG<f09Ib=P2HLCH00P2ILCH07`2JL3H0V78d09Uc
=@2GLcL0UW<i09Eb>P2@KcT0SFhh08]/=P28Ich0R6Ll08YX>`2<J3P0SFTe08mZ<`2CK3<0Tf`a09e_
=02NL3D0WG<g09ih>P2LNS/0Vg`l09Um?02GOS`0U7Xm099h>`2?MCX0Rg4h08Q]=P26JcH00P24J3H0
2P1lICT0OVHj07mW>`22Ic`0PVDk08=S>P22HCP0PF0g085U=@22ISH208=W=`0:089V=P20I3@0OV8b
07aP<024IS@0PV@b07iR<P1jGc00MUh`07EN<P80M5ld00H0M5XY07EJ:`1eFR/0MU/^07IK<01fFS82
07IJ<`03079D;P1cEBl0MELa00<0MeTc00X0MUPb07EG<@1eGS80MEda07AL<01eFRl0MUT_07YJ<@1l
Fc80OUdd0P1jGc@207]P=@<0O64f00H0OF8g07AQ=`1cH3H0MF0e07UR=P1nISP208=X>@0?08=W=`24
ICT0QFHj08=V>P22IcX0PFTk081Z>`1oJS/0P6/l08AW>`23J3/0PVLj07mW>@1mIcH0NfLe0080N6Hd
00X0Lf4c079O=01^GC40JEX_06EF;@1PDR/0GE4[05]?:@1LCB`0F4TX0P1DAB@0201GB2L0FDXY05M8
9`1DAB@0ETPS05M9901IBbH0FddX0P1LCRT205]=:003061>:01QCbT0HDlY0080HU0Z00l0HDlY05m=
9`1MBbD0G4XT05M79@1EAb@0E4DT0554901=@R@0Bd8U04M08`17@2@0BSlS04Tn8P18?B400P17?202
04Pm8@0404Tn8P15?R80A3dQ04<l8080@S/O00@0@c`P04@m8@15?R80A3dQ0P13?2001@12>al0@CXN
040i7@10>Ad0?cPL0080?SdQ00H0?3/O03/j7P0i>1`0=cHJ03He6@0e=1P3038d7080<cDM0`0d=Qh2
030d7@<0;c<L0`0^<Q/01P0/<1T0;2lJ02`_6P0[;Q/0:bhM02X/7P80:R`O0P0X:Ql01P0Y:b00:2XO
02LY7P0V:1d092HK02<U6P80:2PP00<09bLO02HV7P0U9Ad00P0T91`01@0S8a/07b8K01lR6`0N8AX0
7B0I008071lH0P0K7QL801XL6@806Q`K0P0I6aX201PJ6AX05aTH0`0I6aX201PJ6@<05aTH500H6QT3
01LI60805QPG200G6APH01HH5`P05aTH200F61L801DG5PP05AHH200F61L@01DG5PP05QPG200E5QP8
01HG6@P05QPG0`0H6QT301LI60805QPG200G6APA01TK6PP06Q`K0`0I6aX301XL6`806adL200J71T2
01`L6P<07AdK0`0N7Q`801hO6@P07b0J200P7aX0100Q8AT08R8J028R6P0R8QX202<S6`8092@L200Z
8a/202PT6`80:BDL0`0Z9Qd902/W7P<0;BLK0P0^:1`302lY7@P0<RPL200d9ah8038X7P<0<BLM0`0b
:1h203<Y7`80<bTM0`0b:1`3034W6`80;2HJ100]9a/302hX70P0;bTK0`0b;202034[7`<0<2XN0`0_
:Ad3030Z7P80<B/O200b:1h202hZ7`0602lY7@0a:A`0<bXK03P/700k;Qh0?C0O0`0l;ah203d`7`<0
?S4P0P19=2<00`16<b80AC@R04@e8P02044d8@07040e8@17=Al0B3HP04Pf8019=b40BSPR04/i8`02
04`j9080D3/V00@0DCdU054m901B?R<0Dd0R0P1D@B40101I>al0FS`P05do8`1O@BD306129P0305m1
9@1L?al0Gd8R0080HTDU00`0H4<S05m28P1P@b<0HTDU05e0801N@B40H4<S0654901RABD0HD@T0613
8`1O@R8305a48P80GDDS0`1NAR@305Pn8`80EcdR0`1F?24805Lm9PP0EShR00<0DCTQ058j8P1D?2@0
0P1E?BD0101D?2@0DSXR054i8@1@?2<304lk8P80CSXQ0P1=>B0204Ph7P0304Xi7`1=>B00CcTQ0080
DSXR00L0Dc/S05@j8`1C=b40DcLQ058h8@1A>B40CcTQ0080CSXQ00<0C3/Q04dl8P1=?2801P1=?280
101D@2L0DclV054m901?>b8204hj8@80Cc/R00@0CCTQ04`h801<>200C3PP0`1;=al0501:=Qh0CSDQ
04he8@1@=b40DCTQ05<k8@1E?B40ESlP05M08@1I?R40FSlR05To901I@BL0ET0X05<o9`1A?2L0CC/U
04/g7`1<>200CSXR0`1?>b<00`1>>R80CCTQ04hj8@0704hj8@P0CC/S0`1B>R8205<k8`<0E3`T0P1A
?1d01P1>>ad0BcXN04Th7P16=Qd0A3DN04<d7@80ASHO0`15=Ah304@d7@<0@cHS00<0@SDR044d8@10
<b000P0o<Ql303hc8@80?C8P0`0l<Al0400n<Ah0?C0M03`_700k;Q/0?2lL03d`7@0o<Ql0@C@Q048b
6`13<a`0A3@M04De7P16=Ql0AcLP04Ph8@19>B8204dk8`<0BcTQ00H0CC/S04lm9@1@?RH0E44S05=0
8P1A?R03050m7`80DChP00@0DclV058n9@1B?RD0DShU0P1A?B@3050l8`0405Lo9`1F?RH0EShV05Hn
9P<0ECdU00T0E3`T05Hl8@1F?R80EShR05E08`1C@280D3lQ04ho801=?Ql0101>?2@404dk8`0304ll
7P1@?Al0DSlQ0080E44S00/0Dd0R058o8@1A?R00ECdU05Hn9P1G?bL0F40X05Lo9`1F?RH0E3`T05<k
8`0805Dm8@0;04hj8@1=>B00CCTP04di801>>R40DCdT05<o9P1E@BP0ECdU05Hn9P1G?bL00P1H@2P0
1P1G?bL0EShV05Dm9@1B?b40Dd0R05A18`80ED8T0P1D@B<0101C@280DCdT054m901A?B@[ooooo`00
:_ooool0102WNdX0YWY90:=gAP2PM4<409mc@P030:QoB@2WOTP0YGa600<0XgY400<0Y7]50:ElAP2W
OTX00P2VODT01@2UO4P0Y7]70:=jAP2SNTH0XWU500<0Y7U60P2UNTL30:IkB0060:9iA@2SNTH0Y7]7
0:ElB02VODT0Z7m;0P2YP4`40:IkB0@0Yga90P2WO4L60:QmB0P0ZGi;102ZPDdM0:V0C0@0ZX5=102[
PTh20:ImB@80Ygi:00@0Z7m;0:V0C02YP4`0ZX5=0P2XOdL0102WOTP0YWe90:ElB02TNTP20:=iB@80
WgY60P2NNDD01@2MN4@0W7M309]f@P2KMT80Vg4o0080VW0n00<0VFlm09Q^?02GKC/00P2FK3X308mZ
=P<0SVTe0P2=J3@208YV=P80RFDe00@0R6@d08MS<`26HS80QV8b0P25H3H01024GcD0Pehd085L<P20
Fc4207mJ<080O5Ta00@0NeP`07YG;`1iERh0N5D]0P1gE2`0101eEBh0M5@]07AD;P1dDc0207=B<@03
079A<P1bD3@0LE0]00L0LE0]00H0L4d]075?;01bD2d0M58]07EC;@1gERd207QG;00607QE:`1iER`0
NUL]07]H;P1lFBl0OU/a0P1oG3802`23Hc@0PV8c089P<P24Gc80QF0c08QR=@2<HcL0SF@h08aV=`2;
ICH0RV@e0080RF<d00<0RV@e08]U=P2<ISL00P2>J3T608eW>080SfLd1@2@J3D208mW=0<0TFHi0`2@
ICP208mT=`P0SVPk202<ISL0102;ICH0S6Hg08aV=`2=IcP408iX>@0908eR=@2?I3L0TVLj09AY?02E
JSd0U6Tl099W>P2@ICP0TfLj0080TVLj00<0TFPj08mY>P2>JSX00P2<JSX01P2;I3d0Rf@k08]T>`2<
ICX0S6Hi08aV=`80SFLf0P2=IcP308aV=`<0RfDf00P0SVPk08eW>P2<IST0RV@g08US=P27HC@0QV0c
08EO<PP0R68e00<0QF0c08IQ=026HC@01@27HSD2081M<`<0PEhd0`22GcD2085N=003081M<`1oG380
OU/a0080OEX`00/0O5T_081M<`20GC<0Oe`b07eJ<01lFBl0NeP^07YG;@1iER`0MUH_07QH<@0207YJ
<`0807UI<P1gEc00M5@]079B:`1`Ebh0KUD/06aC:P1ZDBP206U@9`0806YA:01[DRT0KU0^06]>;01X
BbT0HdTV0618901OBB@205e9900905Y79P1IARH0Ed@T05E2901C?b@0DCdT04lk8`1>>R80BCLO0080
B3PO00<0AcTO04@h7P12>1d00P10>Ad01`0o>1`0?cTQ03hh800l=R00>S<P03Pa7P0h<Al00P0h<B40
200f;al0=BdP03<]7`0^:Qh0:bTM02LW7@0U9Ad08b@L0`0V:1d00`0U9a`092HK02@V6`0202<U6P80
8B@M0`0P8a`301lR6`<07R0M0`0M7a`201`N6`8071lH00@07B0I01hQ6P0P8a`08B@M0P0R9Ah01P0Q
91d082<L01lR6`0N8AX07B0I01/N5`806QdF0P0L7aP201dP6@807R4J0P0O8Q/2020Q6`04024R700R
8ad08b@N02@U7`809BHP00H0:BXR02XZ800Z:R00;2XN02dY7@0_:A/2030Y6@0602h_7@0];Qh0:b`L
02X[7@0X:1`09RHL0P0U9Ad602LW7@809RHL0P0W:200100V9al09BHN02@U7@0S91`2028S6`808R<M
0`0Q8Q`3020Q6`h08B8L0P0R8ad05`0Z9Qd0;RLM03<[800k;b40@c@Q04Xh8P1@?2@0DcdU05Hl6@1O
AB80K50[07MJ<P21HSH0RfXm09EeAP2NO4`0VgM50:>1D`2TQET0TgMB07]TA01UDCP0CShW0080?2dJ
00P0<2TO02hW7@0[9ah0;2PO02dZ8`0[:b<0:2LR02DT7`P0:2/R0`0Y:R8302X[8`80:b`T200/;BD8
02l_9@0603@`9@0e<BD0=S8V03Pe9P0i=RD0>cPU0P0l>RD04012=RH0@cLW04Hk:@17?2P0B3dW04Pn
9@17?B@0AS`Q04Pn8`1<@2H0D4@Z05I8;P1GAbh0ET@/05E1:@1B?RH405A39`80Dd8V0P1B@BD01@1I
A2D0FTDV05Y59P1KARL0G4LX0080GDPY00@0GTTZ05Q59`1JAbT0FdPZ0P1MBR`00`1LBB/0FTLY05U6
:00205i9;0<0GdL[0`1PAR/04P1VC2/0J4h[06eA;01bEBd0NU/_085P<`27IcH0RfXg095^=P2ALCP0
Tg8l09=b?@2?Kch0RVXk08AS=P20Gc80MF@h07IS>080MF8g00h0MV<h07UT>@1kIS/0O6Ll07QR>@1c
GC@0KeP_071I;`1cG380M5/b071H;01/E2P0NUL]07UF;080NE@X00@0O5HY089I:`27GBd0RV0`0P2B
JRl01`2DJc<0UVde09Q_=`2JLC/0Vg8l09ac?@2FLSH00P2GLcL209Qd>080VGDi00X0VWHj09Mg?02G
Mc`0UgLl09Mg?P2HMCl0UW8n09A^?@2BK3d0T6Xk0P2?LCD0102@L3D0TVle09=_=@2EKSD209I]=@0P
09I_=P2GL3L0UW8h09Eb>02DLCT0TG4h08i_=P2<KCH0QfM108IV@026I3h0QV<k08QS=`29I3L0RfDf
08iU=`2GJS40Ufdc09Q`=@2JLcP0VgLk09Yj?@2KNch0Vgdo09Ei>02DN3L0TWHe08mc=02=LC80Rfl`
08Y]<@29K30208AY>P0608I[?027Jc`0Qf/l08EY>P25ISP0Q6Dg0P25JCT208IZ>P0>08AX>022ISH0
P6@d07iR<P25IC80PfDc081R<01kGbl0NEh_07IN<01eGS80MUlc07MM;01hGRd207QM;P0707ML;`1e
FRl0M5P`079F;P1aE3@0LeHf07AG=`0207EH>00;07AG=`1cESH0LUDe07IP<@1gGc40MUh`07QM<01i
G300OEhb081O=022HCH00`20ICH2085V=`<0PVLh00T0OFPm07UT=`1hHS<0OFDg08M/?@2;LD00RFdk
08EY=`29JCX00P29JS/00`27Jc/0QV`k08A]>`0208=]>`0608M[>`25JcX0Q6Tj085Y>@1nJ3T0O6Lh
0P1hISP0501bGc@0LEhc06eL<@1XFC00I5D^061B;@1LCb`0Fdh[05U::@1EARD0Dd@S05A5901HBBP0
FT/Z05Q9:01EARD0ETPS05Q:9@1JC2L0G4hY0P1MCbX00`1LCRT0FddX065A;@02061@;00405i>:P1L
C2P0FTXV05U99@80F4PT00/0ETHT05A68`1CA2<0DD@T04e2901;@RD0B44T04M09019@2<0AchQ04Dl
7`0204@k7P0604Hm8019@2<0Bd8U04Q19@16?b<0A3dQ0P12>al00`14?B40ASlS04Q19@0204@m8@04
04<l8012>al0@3TM03lh7080?SLK0P0m?2001P0l>al0>STM03Pg6`0g=QX0=SDI03Dd6080<C<K0P0b
=1`203<e7@80=3HN0P0`=1d302lc70<0;S8K00H0;30I02`_6P0/;aX0:bhK02/^7@0Z;1h202X/7`<0
:2XO00D09bTN02HX7@0U9a`092HK02<U6P0202HW7`0402DV7P0T9Ad08b@L02<T70808R<K0P0N8AX2
01dP6@8071lH0P0K7QL801XL6@806Q`K0P0I6aX201PJ6AX05aTH0P0I6aX201PJ6@805aTH0P0F61LD
01PJ6@<05aTH0P0F61L801LI62P05QPG200E5aH801DF60P05QPG400E5aH801HH5`P05AHH200F5aT8
01HH5`<061XI0`0G6AP201HH5`P05aTH4@0I6aX801XL6`<06A/J0`0J71/201/M70P06Q`I0P0L71X3
01dM6`<07QhL200N7aT801lP6PP081lJ0P0Q8AT3028R6P<08b<K200Z8a/302PT6`80:BDL2`0Z9Qd2
02`V6P80;BLK0P0^:1`202lY7@P0<BTL200a9ad2038X7P@0<BLM0P0`9Q`@030X7@L0;BLK0P0^:1`8
02/W6`<0<B/O0`0`:Qh402lY7@H0<2XN200b:1h202hZ7`0602lY7@0a:A`0<bXK03P/700k;Qh0?C0O
0P0l;ah303d`7`<0?S4P0P19=2<01P16<b80AC@R04<d8@11=240@3<P03ld8080AcDO00<0B3HP04Tg
8@1:>2800P1;>B<01`1<>R@0D3XU050j9@1A>b@0DS`T05<n8`1D?b800P1E@2401@1F>1`0F3XN05/m
8@1N@2@0Gd4U00<0H48V00@0GD0R05m2901P@bD0H4<U0`1O@R@01P1P@bD0FC`N05/n801M@280Gd8T
06139@80Gd8T00<0GT4S05]28`1K@R<0101K@R<205a390<0ES`Q0P1E>b0305@j7`P0ES`U201E?B40
0`1?>B40D3XR054k8`02058l9003050j8P1?>B40CSPP0080BSTO101;>R0204`k8@80B3PN00<0BSTO
04di801?>B400P1B>R802P1C>b<0E3XS05@j8`1C>B80DSXR04li8@1=>B00BcXP04Xi7`19>Al804`k
8@80DCdT00<0D3`S04lk8P1>>R400`1>>R4804`h8080CcHR00H0D3LQ058j8P1D?280ECdQ05Ho801G
@24205Pm800605Pn8`1G?bD0E3hV054m9@1?>RD0C3XT0P1:>20604/i8@P0CCTP201<>R8204li8@<0
D3XR0`1A>b<0201@>ah0CcXM04`h7@19>1h0AcDM04@d7@12<a`0@C8M2012<a`02013=R<0A3LT04@g
9013=R<0@SDR040c800n<Ah0?2lL0P0n<b4303db80<0?34O00P0?S4N03d`7@0l;a`0>bhK03`_700m
<1d0?c8O044d8@80@c<L00@0A3@M04De7P16=Ql0AcLP0P18>2400`1=>b<0C3XR04/i8@0204Xh8003
04`j8P1>?2@0CcdU0080DchQ1P1B?B00101B?RD0DCdT054m901A?B@2050l8`<0Cc/R101F?R@405Dm
8`0805Dk8P1E?B<0ECdS058m8P1A?B80CSdQ04dn8@1<?B0204`l8`0304/k8P1:>R40BCTP0080B3PO
00@0AcLN04`h7@1=>Ah0Cc/P0`1A?B8204lk8003054k8`1B?2@0DcdU0080E3hV00<0DS`T050j8P1?
>B40201A?24404`h7`0404hj8@1A?B@0E40W05E1:0<0EclW0P1H@2P305Lo9`D0ET<U00<0ED8T05A1
8`1D@B<00`1D@2L[ooooo`00:_ooool0102VNTT0YGU80:9fA@2PM4<209mc@P80X7A300<0Z7m90:Mn
B02UO4H00`2SNT@01@2TNdD0YGa60:ImB@2VODT0YGa80080Y7]700<0XgY60:9iA@2RNDD00P2TNDH2
0:EjA`80YW]80P2WO4T20:9iA@060:=jAP2UO4P0YWe90:MnBP2XOd/0ZH1<102WO4T40:IkB0H0Z7e8
0P2WO4L80:UnBb40ZH1<102[PTh40:Z1C@80YWe900<0Ygi:0:QoB`2YP4`00P2ZPDd01`2[PTh0Z7m7
0:QoA`2WOTP0YWe90:ElB02TNTP00P2SNDT20:1kA`0409mjAP2NNDD0WGQ409ehA080W7M30P2LLT00
0`2KLCl0VW0n09U_?@0209Q^?00309M]>`2@JcL0T6/g00<0SfXf0`2>JCD208]W=`0408YV=P29ICD0
R6@d08QT=080Qf<c00P0Qf8h08IQ=`25H3H0Pehd089M<`20Fc40OeX`07iI;`80OEXb00@0O5Ta07]H
<01jEbl0NEH^0P1hEBd207EE;00307AD;@1dE2h0M5<`0080Le8a00<0Le8c075@;@1aD2d01P1aD2d0
3P1_CRd0L4l/075@;@1bDR`0Le</07AD:`1eERX0MUL[07IE:P1gER/0N5L/07UH;@1kFRl0O5/`0P1m
G3402`22HS<0PF4b089P<P23GS40Q5lb08MQ=02<HcL0SF@h08eW>02<ISL0RV@e0080RF<d00<0RV@e
08aV=`2=IcP01P2=IcP208iX>@T0SFPd0`2AIST3091U>080Sf@g202=IcX808aV=@D0SFLh00`0SVPi
08mY>P2?JCX0S64d08iS=P2AIST0U6Tl09EZ?@2DJC`0TfPk095V>@2CIcX2099W>P03095X>P2?JCX0
SVXj0080S6Xj00H0Rf@m08]T>`2<IC`0S6Dj08aV>@2=IcP208eW=P<0SFLh0`2<ISL208]U=P0808iX
>`2=IcX0S6Hi08YT=`29HcH0Qf4d08IP<`25Gc8408QR=@@0RF<f0`25H3<208IQ=00308MR=@28HcH0
RF@g00<0PEhd0`22GcD208=P=P06089P<`21Gc80PElb081N<@1oGC00OU`_0P1mFbh01P20GC<0Oe`b
07iK<@1mFS00O5T_07YG;@80NEH/00`0MUH_07MG<01iFC80NUXc07UI<P1fERl0Le</075A:P1aEBd0
L5@/06iB:P1]DBT406a@:00606mA;`1/Cbd0JD`Z06A:9`1QBBD0H4XU0P1NBRD03P1LBRH0FdPW05U6
9@1GA2@0ED8T05<o901A?B@0D3`S04/i8@19>B00B3PO04Li7`14>1h0@cTN0`11>Qh04@12>R<0@3PQ
03de800j<Ql0>C4N03T`7`0j<B80>c8S03L`7P0f;al0=2hN02l/7@0/:Qd0:2PL02HV700T9Q/09RPM
00@09BLL0`0T9Q/3024T7@<082<L0P0O8Q/201lQ7P<07R0M0`0M7a`0200K7QL071lH01dP6@0N8AX0
7b8K020S700Q91d08RDN0P0Q91d01P0P8a`07R4J01dP6@0L7aP06ahG01XM5P8071lH0P0M81T201hQ
6P807b8K0P0P8A/0100Q8Q`08R<M028S7@0S91h202@U7`0602PY8@0Y:Al0:BTO02/Y7@0/:1`0;RPJ
0P0_:1P0200^<1/0;RlM02d^700[;1`0:BXL02PX700V9Q`09BDK1P0W9ad202PX7P809bPP00@09RLO
02DV7P0U9Qh092DM0P0S91`3028S7@<08B8L0P0P8A/>024R7080824K01L09BDK02TV7@0]:Ah0=2`O
03/_8@12<R80ASDS04Tg8`1A=a`0FD0R06A::@1_Dbh0NE`d08EV>P2ALT<0VWY909Ie@P2NOTd0XH9D
09aoE@2DN540QVa906aD<P0205Dn7P0803X^7P0b:AX0;2@G02/U6@0/:1d0:b/Q02PY8@0U9R0802P[
8P<0:BXR0`0Z:b<202//90P0;2dU200_;bD01P0c<2L0<c4U03@b9P0e<bH0=cDV03Pg9@80>CPT00D0
@CDU04<g9`15>RP0Ac`X04Pm9`0204Pn9@0904Lm8P18?R<0C40V0514:P1EAbd0EdL^05E3:`1C?bL0
DCdU00D0DD0V00@0DT4W05=2:01C@RP0G4DV0P1MARL01@1NAbP0H4TZ065::`1QBR/0HT//0080FdPZ
00H0G4T[05e:;01MBR`0G4T[05]8:P1JAbT30618;00H05i9;01MB2/0G4LZ05]6:@1IARP0HTT[06=:
:`1VC2/0K50[079E;@1kG300PF8d08EU=P2;K3<0SVlh095b>`2CM3h0Tg8m08m^>`2;JSL0RVHd07aV
=`1kICH0NF<d0P1gHS<01P1hHc@0N6Hf07YX>01kHcL0N60d07EL<`80Le`b01<0LU/b06eG;P1YDbX0
LE4[071@:P1_CBL0LDhV07IA9`1kER`0PEX_08EN<`2<Hbl0SF@`08mV<P2AJ380U6/e09I]=`2HKcL0
VG0h0080UFhc00@0UVld09M`=@2ILSL0VW<h0P2KM3T209Ue>@0709Yf>P2JMS`0VGHn09Md?P2BLC`0
Sfhk08e/>@0208e`=P0408i_=P2?KcH0TFhf099]=P80U6df01P0UFdi09I_>02EL3T0UG8j09Eb>02B
LSL0Sg4e08i`=027JT80QVU108EU?P24HcX0QF8j08MR>029I3X0Rf@i099Y<@2CJS80U6dd09I_=P2G
LcT0VWHl09]h?P2LNCl209Af>00?09=e=@2BM3@0T78b08mb<02=L2h0S6l]08Y/>P2;KC/0RVhl08]_
?@2:KS`0R6hk08I/>@24JSL0Qf/k00<0R6`l00`0QVXj08AX>021ICD0Of<c08IU<024I340PF4^07iP
;P1kGbl0NUl`07UQ<`1jHS@207iT<@0907iT<`1mHS<0NUlb07IK;P1bEb`0L5DZ079H=`1cFCP0M5Xi
0080MU`k00/0ME/j07=I>01bF3L0NfDd07]S<`1jHS80O64b07iR<`22HcD0QF@g08IU>00408IZ>080
Qf/i0P28K3X03P24KSl0OfTh07eU=@21JSP0RW0m08md?`2>L3X0RF/e08i]>P2=KCX0S6`i08]]>@29
KST0R6li0P26KcT07028KCP0QV`i08AZ>@20J3P0OFLh07YU>01fHcP0MF8h06mL<P1^Fc40JeTa06IG
<01RDRh0Ge4^05]>;01JCB/0EdPW05E69@1CA2<0EDHU05U::@1KC2/0F4TX05E69@1GBB@0F4XU05Y<
9`1LCRT205e?:P80G4hY00H0H50^05i>;01NCR`0Fd/Y05U99`1GAbD305I6900;05E58`1CAB80DT<R
05138`1=@R@0Bd8U04Q19017@2@0ASlR04Dn8@12>ah00P11>Qd01P14?B00ASlR04Q19018@BD0Ad0T
04@m8@80@S/O00/0A3dQ04M09018@BD0A3dQ04<l8012>al0@CXN040i7@0o>1`0?SLK03df6P0203`k
7`0603/j7P0i>1`0>3LK03Lf6P0f=AT0=C@H0`0a<a/2038d70<0<cDM0P0`=1d302lc70<0;S8K00H0
;30I02`_6P0/;aX0:bhK02/^7@0Z;1h202X/7`0502T[800X:Ql09bTN02HX7@0U9a`00`0T9Q/202DV
7P8092DM00@08b@L028S6`0Q8QX08B8J0P0M81T401`O60806ahG200J71T201XL6`806A/J0P0H6QTJ
01LI60<061XI0P0G6AP301HH5a405aTH0`0H6QT301LI60805QPG200G6APX01HH5`P05ALF200E5QP8
01HH5a005ALF200F61L801DF60P05QLI200F61L301PJ6@<05aTH0P0F61L801LI61406A/J200J71/3
01TK6P<06Q`K0P0K7A`801XL6@8071`J0`0M7A/301hN70P07AhH200N7aT801lN6@<08B4I0`0R8QX2
02<S6`P0:R<K0P0W8aX202PT6`80:BDL2P0Z9Qd302`V6P80;BLK0`0^:1`8030Z70P0;bLL00<0<RPN
034W7@0a9ad00P0`9Q`202lU6`0302hT6P0^:1`0;RPL00H0;RPL200^9ad202hX70L0;BLK200Y9a/4
030Z7P80;bTM0P0^:1`6030Z7P80;bTM200b:1h202hZ7`0502lY7@0a:A`0<bXK03P/700k;Qh0100m
<1l303ha8080?c8Q0P18<b801`15<R40A3<Q04<d8@11=240@3<P03ld8016=1h00P17=Al00`18=R00
BCLQ04Xh8P0204/i8`80DSTU00@0DcXT05@l901D?280ECdQ0P1F?b001@1F>1`0F3XN05/m8@1N@2@0
Gd4U00@0H48V00<0GT0T05do8`1M?b<00`1N@2@01@1M?b<0F3XN05Tk7`1K?B40GClS0080GT0T00<0
GClS05`n8P1J@B<00P1J@B<505U08P<0EC/P0`1D>Ql205<i7PP0EC/T201D?2000`1>>R40Cc/R050l
8`02050l8`0304hj8@1<>1l0BcLN0080B3HN0P19=al204Xh8080BcTQ0P18>1h00`1:>Al0CCTP04li
8@02058j8P0:05<k8`1D>R<0Dc/S058j8P1@>R80CSXQ04/j801:>Al0B3PN04Li7PP0BcXP1@1?>b80
0`1>>R40CCTP04di800404`h80@0CCTQ0P1@=b<03`1A>280Dc/S05@l8P1E?B40ESlP05M08@1F>ah0
Ec`O05Lm8P1F?R@0DcdU050l901>>B@0BSPR04/i8@0204Xh80<0BCLO0P1:>20804`h7`P0BcTQ0P1=
>B4204hj8P@0Cc/S00P0CcXO04hi7P1;=ah0B3HN04Hd7P13<Qh0@C8M040a7PP0?c<K00P0@SDR04<f
8`14=b@0A3LT04<f8`10<b00?C0M03`_70<0?C8P0`0l<Al203/`7P0903ha7P0m<1d0?2lL03/^6`0l
;a`0?C0M03lb7`11=240@c<L0080A3@M00P0ACDN04Hf7`17=b00AcLP04Ph8@1<>R80BcTQ04Xh8080
BCLO00@0BcTQ04dk8`1>?2@0Dc/O0P1D?20305Dm8@80E3`P0P1A?B@2050l8`@0Cc/R00<0CSXQ05Dm
8@1E?B400P1E?B4405Hn8P0805Dk901C>b<0Dc/S050j8P1?>b80C3/Q04/k8@1<?28204Tk8@0304Pj
8017>Al0ASPN0080ACLM00@0A3HL04Xf7@1;=ah0CCTP0`1?>b801@1>>R40CCTP04hj8P1?>b<0D3`T
0080DCdU00<0Cc/S04di8@1<>200201>>R402@1<>1l0BcLN04/g7P1<>1l0CSXQ050l8`1C?bH0ED4X
05Q0:00605Lo9`0305Q0:01GA2H0Ed@V0080ET<U101E@R@305Q4:b_ooooo000Zooooo`0;0:AhA`2S
MdH0XGE40:1d@`2OLd80X7A30:5eA02RMTD0Ygi80:ImA`2TNdD00`2RND<00`2SNT@0Y7]50:ElB003
0:AkA`@0XgY60`2UNTD20:IkAP<0Yga70P2SNDL20:AjB0050:EkB@2VO4X0Yge;0:MmB`2XODX00`2W
O4T30:IkB0030:EjA`2YOTT0ZGi900<0Z7e80`2WO4L80:QmBP040:MnBP2XOd/0Z7m;0:QoB`<0ZH1<
00<0ZX5=0:V0C02YP4`05`2YP4`0102/Pdl0Zh9>0:^2CP2[PTh30:Z1C@030:V0C02WOTX0Ygi:0080
Z7m;00@0ZH1<0:Z1C@2ZPDd0Zh9>0P2XOdL0102WOTP0YWe90:ElB02TNTP20:=iB@80XGa800<0X7]7
09mjAP2NNDD00P2MN4@00`2LMd<0WG=109ec@@0209ab@00409]a?`2JL3h0VFlm09U_?@<0T6/g0P2?
JSH308iY=@80S6Ph00<0RfLg08YV=P29ICD00P28I3@02P27Hc<0R6<i08MR>026HCL0Q5le089M<`20
Fc40OeX`07iI;`1nFc<207eJ<P0307aI<@1kF300NUL_0080NEH^0P1dEBT00`1dE2/0Le</07=C;@02
079A;P03079A<01aD2d0LE0]00H0LE0]00H0KDl]06e?:`1^D2`0Ke4[071C:`1aE2X2079E:@0C07AE
:@1eERX0MUL[07MH;01iFRh0NU/_07]L<01lGC40PV8c085Q<P21Gc40Peha08AO<P27HC@0Rf8f08eT
>02=IcP0S6Hg08]U=P0208YT=@0308]U=P2<ISL0SFLh0080S6Hg0`2=IcP308iX>@0308eY=@2<J3@0
RfLc0080RVHb0P2;Ic<00`2<J3@0SFTe095V>@02095V>@<0T6Dh0P2?I3L808eW>PP0SFPd00`0SVPi
08eW>02=IcP0S6Hg08eW>02>J3T0SfTj091Z>`2>HcH0Sf@g095V>@2BIcX309=X>`07099W>P2CIcX0
TVLj099W>P2AJ3X0SfTj08iZ>P0208aZ>P0608]T?@2<IC`0S6Dl08aU>P2=IcX0SFLh0P2>J3L208iX
>@80SFLh0`2<ISL02@2;ICH0SFLj08aV>@2;ICP0RV@g08US=P28HSD0Qf4d08IP<`0308QR=@80RF<f
0`2:I3L408AO<P0408EP<`26HC@0R6<f08UT=`P0PUle0P22H3800`21Gc40P5h`07mM;`0207iL;P05
07eK;@1nFc40OU/a07eJ<01lFBl00P1kF2h207YG;@0807MG<01hF340N5Pa07QH<@1gEc00MED^07=C
;01bDR/2075D;003071C:`1^DBT0KE0X00<0KE0X00H0LE<a06iA;`1[CR`0IT`Y06=;9`1RC2L2061<
9`0>05i<9P1MBbL0FdTU05U69@1GA2@0E44S05<o901B?R<0CC/S04/k8P1:>R40B3XP04Di7`15>b02
04<l800A04@m8@15>R@0@cPR03ld800l<Al0>c0N03/_7`0m<B<0?S8T03L`7@0f;ad0=2lL030]700]
:a`0:R/M02PX700W:A`0200U9a`2028U7P808B@M0`0P8a`0100O8Q/07b4N01lQ7P0O8Ah201hP7@<0
7AlL0P0L7aP0100M81T07R4J01hQ6P0O8Q/4020S70807b8K00<07R4J01dP6@0L7aP00`0L7aP201dP
6@807R4J0P0O8Q/01P0N8AX07b8K01lR6`0P8a`08B@M028U7P808bHO00H09RLO02PX7P0X:1h0:bTM
02`X700_:A/2030Y6@0802d_6@0];aX0;BlJ02d^700[;1`0:BXL02LW6`0V9QX402LW7@80:2PN0P0Y
:Al202LX80809RLO0P0U9Qh202@U7@808b@N0P0R8ad3024R7003020Q6`0Q8Q`08B8L00X08B8L0P0P
8A/201lP6P0G020S600S9AX09RHJ02dY7P0c:b00>BdQ03d_8P10<2<0CC@N05<k8`1L@RL0I4XY06iB
;@1iG380QfPj091a@P2DMT80Vge909n1C`2QPU<0Y8EG0:62E02?KT<00P1kFRl0201?@2/0@SHP03DZ
600]9QH0;BTM02`/8P0Y:R809BPQ200X:b8302TZ8P<0:R/S0P0[;2@802`]9@P0;blU00H0<30X034a
9`0a<BL0<S8V03<d9P0d=BD203Df900A048f9P13=bL0AS/Y04Pm:@19?RP0BT0W04To9P19?b@0BT0U
04e19`1?@bT0DdD[05A4:`1D@RX0DclW054m9@1A?bL00`1@?RH0101A?bL0DT0X05A2:P1E@b/205i5
9`0605m6:01QB2X0HTT[06=:;01TBbd0ID`^1@1MBR`00`1LBB/0FdPZ05]8:P020657;00f0659;@1O
BRd0GDX/05Y9:`1GB2T0ETLX0618;P1PB2`0HTT[06I<:`1]DB`0M5L_07aL<`1oH3@0Q6Xa08M]=02<
KcL0T74j099a>`2DLC/0Tfhi099]>025JCT0PVPg07mU=01jHc40N68`07QT<@1hIc<0NFPd07eP=01k
H3<0NUld07IM=01dGC@0L5Xc06YG;`1XE2l0K4l_06]>;P1ZC2X0JdXW06m=:01eDR`0NePb085K=027
G2l0R5h^08UO;@2<HS00SfH`095X<P2CJS80U6`a0P2AJBh01P2CJc00U6`a09I^<`2HL3D0VG4f09Yb
=`80VW8e00P0VW<h09Ue>@2JMS`0UWHm09=b?02>KcT0Rfdg08ab>@80SW4i00<0Sg0i091_>@2BKcT0
0P2CKST0402EKCX0UVhk09Ia?02GM3`0Ug@j09Ad=`2BM3@0TG<c08Y_@028KCh0QVXk08EV>025I3L0
QfDh08UW>P2=J3`3091[=00E095/=@2CKSL0UG0i09Ub>`2KM3d0TW4l099a>`2CLcX0Tg<h099b=@2A
LS80Sg0`08m`;`2=KSP0SVli08i`>P2=LS/0Rg8j08Qb>@26L3L0Q6lf00@0RFdm01L0Qf/k08AX>021
ICD0Of<c08QU;`25I2l0Pf8]085Q;P20HS00Of<c081U=P21ISL0PVTc08=Z=023JCH0PVPg07mT=@1k
H3<0MU/^07=H;@1eGSD0MUlf07QQ>00307YS>P0:07UR>@1hHCP0PF/i085Z>020JCL0PFLf08=W=`26
IcP0RFTj08YZ>`<0Rfdg0P2<KSP308e_>@0908Ma?`26Kc/0Q6di08Q_>@2;L3T0Sg8j08i_=P2<KC@0
TVli0080Sfhh0240SVlh08a_=`2:L3L0RG0g08Q_=P26K3<0Q6/c089X=@1mIS@0NF8f07IQ=P1bGcL0
LEdh06aI<@1[F300IeD_06=C;`1PD2h0G4d/05U<:P1HBb/0FDXY05I79P1EARD0F4TX05]<:`1LCB`0
FDXY05E69@1GBB@0FD/V05]=:01MCbX00P1ND2/00`1MCbX0G4hY05]<:`0205Y;:P0305Q9:01FAbH0
E4DT0080Dd@S00T0DT<R05A48P1BA240DT<R05138`1=@R@0Bd8U04Q19018@BD00P15?R4404<l7`05
04@m8015?R40ASlS04Dn8P14?B400P13?2000`14?B40AChR04Ho8`02048k7`04044j7P10>Ad0@3TM
03lh7080?SLK00H0>cXN03Xi7@0j>Ad0>CPL03Pg6`0g=QX203He6@04030b6P0a<a/0<C<K034c6`80
<S@L0P0c=Ad2030d7@<0;c<L0`0^<Q/01P0/<1T0;2lJ02`_6P0[;Q/0:bhM02X/7P80:R`O00H0:B/P
02PZ7`0V:1d09BLL02@V6`0S9AX202@V6`0602@W7P0S9Qd08bHM028U700Q91/082<J0P0O8QT501`O
60<06ahG200J71T201XL6`806A/J0P0H6QTJ01LI608061XI0P0G6AP301HH5`0301DG5P0G6AP05aTH
00l05aTH0`0H6QT301LI60805QPG200G6APH01HH5`P05ALF200F61L801DG5PP05AHH200F61L@01DG
5PP05QPG200E5QP801HG6@P05QPG0`0H6QT301LI60805QPG200G6APL01TK6P<06Q`K0P0K7A`801XL
6@8071`J0`0M7A/301hN70P07AhH200N7aT801lN6@80820H0P0Q8AT3028R6P0302<S6`0Z8a/0:R<K
00H0:R<K0`0W8aX202PT6`/0:BDL00@0:bDI02`V6P0/9QX0;2HJ0P0]9a/202hX70P0;BXK200]9a/2
034W7@80<2HL00@0;bDK02hT6P0]8aT0;B<I0`0/:1`302/W6`80:RHJ0P0Z9Qd302/W7P<0;2PO0`0^
:1`402dW6`80;2HJ200W9ad0100`:Qh0;bTM02lY7@0_:Ad202hX7080;BLK0P0a:al3030Z7P<0;bTM
200a9ad202hZ7`0502lY7@0a:A`0<bXK03P/700k;Qh0100m<1l203ha80<0?c8Q0P15<1l01P14<B00
@c8P04<d8@11=240@SDR044f8P80AS@N00<0AcDO04Pf8019=b400P1:>2801`1;>B<0DSLT05<h9@1C
>2<0E3XS05Dk8P1F?2400P1G?R00101I>al0FS`P05do8`1O@BD306129P0305m19@1Q@bT0GT0V0080
FcdS00d0GClU05i09P1M?bD0FcdS05Tk8@1J?280G3hT05do9@1N@2H0GClU05`n901K?B<0FClT00<0
F3hS0`1G?B8205Hl8@<0EC/P0P1D>Ql205<i7PP0E3XS201C>al0201<>b40CC`R04dl8P1>?B<0CC`R
04/j8019>1h0AcHL0P16=Ql304Lg80<0B3PQ0P18>1h00`1:>Al0CCTP04li8@02058j8P0805<k8`1D
>R<0D3XR050j8P1>>R40BcXP04Xi7`19>Al204Li7PP0BSTO00<0C3PO04di801>>R400P1?>b800`1>
>R40CCTP04`h7`0304`h8080CCTQ0`1>>R801P1A>2@0DSTU058i8`1C>b<0E3`R05Dm8@80ESlP00d0
ECXM05Hk7P1E>b00E3`R058l901?>b<0C3LR04Tg8@1:>R40BCTP04Ph7`17=ah0ASHM0080AcLN00<0
B3PO04/g7P1;=ah01P1;=ah804Xh8080BSPR0P1;>B<304`j900904dk9@1?>B40CSPP04`h8018=R00
AS@P04<b8011<Ql0@30P0080?C<J0`0n=1/303le7008040c8012=B80A3LT04Dh9@14=b@0@C@Q03ha
7P0l;a`303db8080?34O0`0k<1h0200n<Ah0?C0M03`_700k;Q/0?2lL03d`7@0o<Ql0@C@Q0P14=1d2
04De7P80ASHO0P17=b003@1;>B40BSPP04Tg7`18=Qh0BCLO04Xh801<>R80CC/S05<i7P1D>Ql0EC/P
05Hl8@1G?B800P1F?2400`1E>b00D3`S050l8`0204lk8P@0CSXQ00<0CCTP05@m7P1E?Ql00P1E?Ql3
05Ho800905M08@1D>B@0DSTS054h8P1>>240C3PP04/i8@1:>R40Bc/R00<0ACTO0P14>1h304<g7@0:
04Te7@1;=al0CCTQ04hj8P1?>b<0CSXR04di8@1<>200BcTS04`j90<0CC/U00<0BcTS04Tg8@18=R00
201:>20204`h7`0904/g7P1<>1l0CCTP04lk8P1B?RD0DclV05Q0:01G?bL0EShV0080ECdU00@0EShV
05Lo9`1H@2P0ET<U0P1E@R@205A18`0305E2901F@bD0Ed@V00<0F4@[:oooool002[ooooo0100XWI5
0:5eA02PM4<0Wg=20:1d@`2RMTD0XgM60:EiB02UO4H0Y7]50:9i@`2QN480X7M10:5h@P2RND<0XgY4
0P2RNDD30:=jAP<0Y7]70P2UNT<20:IkA0@0Yga5102TNTX40:EkB`80Z7e:0P2WO4T20:IkB080YGY7
0`2YOTT00`2XODP0Yga70:MlA`020:IkAPP0Z7e:0`2WOTX00`2XOd/0ZH1<0:V0C0020:Z1CAT0ZH1<
0P2/Pdl20:^2CP80ZX5=0P2YP4`20:QoB`@0ZH1<0P2ZPDd20:QoA`040:MnB02VODT0YGa80:AjB080
XgU90P2RODT00`2QO4P0X7]709mjAP0209iiA@0309ehA02OMD<0WWA20080WG=100@0W79009]a?`2J
L3h0VW0n0P2AK3P2091[=`<0SfXf00H0SVTe08eY>@2=JCT0S6Ph08]W=`2:ISH208UU=@0908QT=029
I3X0R6<i08IQ=`24GcD0PUdc081K<@1oFS00OUT_0080OU/c0P1mFS801@1lFC40NeP`07YG;`1jEbl0
Le@V0080Le@X00<0LU8Y079B:`1aDB/02P1aD2d01P1/Cbd0K50[06eA;01^DR/0KU8Z06mD:@80L5DX
0P1dEBT01P1eERX0MUL[07QI;@1iFRh0NU/_07]L<080PF4b00T0PEla08=N<@24Gc80Qf4d08]R=P2<
HcL0SVPi08eW>02;ICH00P2:I3D00`2;ICH0SFLh08iX>@0308aV=`0308eW>02>J3T0SVPi0080SfTj
00<0RfXe08YY=028Ic800P27IS4208QW<P0308YY=02;JSD0TFHi0080TFHi0`2@ICP208mT=`P0S6Hi
202=J3@02@2?JCX0SVPi08eW>02<ISL0SFLh08iX>@2@JS/0TF/l099W>P02095V>@80T6Dh00@0TFHi
09=X>`2CJ3/0TfLj0P2BIcX00`2AJ3X0SfTj08iZ>P0208aZ>P0608aU?P2<IC`0S6Dl08eV>`2=IcX0
SVPi0P2>J3L308iX>@80SFLh0`2<ISL208]U>080RV@g0P29HcH508QR=@0308US=P2:I3L0RV@g0080
RfDh00T0Peha089M<022GC00PUd`08=N<@25H3<0Qf8e08UT=`25HSP00P24HCL01@23H3H0PUle085N
=021GS@0P5dc0080PV0`0P21Gbl01020GRh0Oed]07iL;01nG2`407aI;`@0NeP^00@0NETb07QH<@1g
Ec00MED^0`1dE2d01`1eEBh0Le</07=C;01bDR/0LE4Z071@:@1_CbP00P1^CRL01P1cEC<0L5<a06e@
;P1XCR/0IThZ06A>:@80HThY00h0GddW05i<9P1MBbL0FTLV05Q59@1F@b<0E44S05=08P1@?RH0CShU
04`l8`19>b40Ac/Q04Lm8P80ASlS00T0Ad0T04Lk9@14>280@3<P03d`7`0k;Qd0?2lO03h`8`10<RD0
0P0e;Q/01P0c;Q/0<2dL02h/7@0[;1`0:b`N02T[7@8092HK1P0U9a`3028U7P808B@M0`0P8a`2020R
7`807b4N0`0N81d00`0M7a`07B0I01dP6@0601hQ6P@07b8K100N8AX201`O60807B0I0P0N8AX201lR
6`80724J00<07B8K01hS700O91d00P0P9Ah04P0Q9Ql092DM02HV700W9ad0:RPL02`X700_:A/0<BXJ
038[6`0[;AL0;2hH02d_6P0^;ad0;BhN02`]7@0Z:ad0:2TK02HV70809bLM0P0X:1h202TY7`0302XZ
800W:2009RLO00<09RLO0`0U9Qh302<T7P808R<M2`0Q8Q`00`0R8ad08B8L024R7002020Q6`807b0J
01P07QlI01dS5`0P8aP08bDJ02TV7@0^9ad0<bTP03LZ8P0i:R<0B34Q04hd8`1C>b<0FD0R05m58P1Z
Cb@0Me//081T=02<LC`0UGY509anBP2MODX0X7m:0:J2CP2QO4P209Yb?`0806aK@@1KBc80A3PR03D]
6P0b;1h0;RhR02T/8`0U:24802P[8P<0:BXR0`0Z:b<202//90P0;2dU200_;bD2030`:003034a9`0a
<BD0<S<U0080<c@T00X0=3DS04<g9`14>2P0Ac`Z04Tn:P1;@2X0C48Y04]1:01;@BH0CD<X0P1>@RP0
0`1A@bT0DD4X0590:00205<o9`0>054o:@1@?RP0CcdW04lm9`1A?bT0Dd4[05E3;@1GABl0Gd@W0615
:01QART0HdP[06A9;01VBbh206M<;`80Gd`^0P1NBbd0A01MBR`0G4T[05a9:`1LBB/0HTL/0698;@1R
BRh0H4d_05e<;P1KC2d0ET/[05A9:@1PBS80HDT_0659;@1SBR/0J4h[06mC;P1fFC40NUde07mV;P21
J300Q6Xa08]/=@2?KcH0UG0i09Ub>@2JLcX0Sfln08]]>`25JCL0OfDb07YU<01jIS40NFPb07UZ<`1n
Gc00OF4b07aQ=01hH3@0M5he06iK<`1ZF3@0IUHb06iE=`1/DC@0J4d_06Q;:`1ZC2X0L4l/07ID<@1i
Ec80PeP^08AI;P25FRd0R5h/08YQ;@2<Hbd0SVH[08mW;02;HbP0S6@Y08iV:`2@J2d0TVX_09A/<@2F
KS<0Ufld0P2GKC401`2HL3<0VG8g09Ue>@2EMCX0TW<j08e`>029KcH00P2>Lc`2091b?00]095b?02B
LC`0U70l09A`?02FKSd0Ufln09Mb?P2HMCd0VGHl09Mh>02EN3H0U7Le08af?02;LST0R6lg08I[=028
JSH0Rf/h08m]?@2AKcl0TFhf091]=@2@Jc@0SfXc095Z<`2CK3D0UF`f09M^>02?KD00T6i1095_@@2B
LCh0TW4l095a>02@L3D0Sfld095^>02@KcT0T74j091c>`2<LcX0RG<i08Ib=`23L3D0RFdm0080RVhn
00D0RFdm08M[>`24J3P0PFDe07mS<`0208MT;P0B08AS;P23Hc00PfDc08IX=P26JSX0Qf/k085X<023
JS80QVdg08M]>P26K3/0PfPi07mT=@1mHSD0N6@b07YV=01lJ3H0OVXh0P20K3X207m[>@0808Qc?P27
L3`0QVlk08I/>@27JcT0RF/i08a/>`2=KC`308i_>080Sg0i0`2@LCX02028LC/0S7<m08ed?02=LcX0
S6lg08]/<`2=KC80Sfld0P2BKcL0102@L3L0SVlf08a_=@2<KcD208U_=00D08=Y;P21J2l0OfH`07YS
<@1fGc<0LU`c06eI=01/F3D0J5@_06MC;P1TDRh0H50^05e=;01IBRT0EdXZ05I9:@1KC2/0FDXY05Q9
:01JBbX205i?;P0605U::@1EARD0F4XU05U;9P1KCBP0GDlZ0P1ND2/00`1MCbX0G4hY05E89P0305I9
9`0>05E89P1DAbD0DTDS05138@1?@R00Dd<Q0553801A@R40Cd8R04a18`1;@RD0B44T04Q19@13?R03
04@o8@0704<n8012?Al0@3/M03lj7012>al0@c`P04@m8@0204Dn8P0304@m8@13?200@S/O00H0@3TM
0P0o>1`203Xi7@0403Th700h=a/0>3LK03Lf6P80=SDI0P0`<QX3034c6`<0<S@L0P0`=1d302lc70<0
;S8K00H0;30I02`_6P0/;aX0:bhK02/^7@0Z;1h202X/7`0402T[800X:Ql09RPM02@V6`808bDJ0P0T
9Q/01P0Q9ad082HL020V700O9A/07R@J01dS6@80728H1P0K7QL201`O60P06Q`I0P0J71/201TK6P80
61XI7@0G6AP301HH5`805ALF4@0F61L301PJ6@<05aTH0P0F61L801LI61P05QPG200E5aH801HH5`P0
5ALF200E5QP801HH5a005ALF200F61L801DF60P05QLI200F61L301PJ6@<05aTH0P0F61L801LI61`0
6A/J0`0J71/201/M70P06Q`I0P0L71X301dM6`<07QhL200L7AL801dN60P07QdH0`0P81P2024Q6@<0
8R8J200Z8a/402LS6P80:2@K2P0Y9A`202/U6@<0;2HJ0`0]9a/802`Z6`P0:RHJ0P0a9ad0100`9Q`0
;bDK02hT6P0]8aT202`R6080:bTL0P0Z:1/202TW6P80:2HI0P0X9A`202TV7@80:RLN0P0[:1l202lY
7@80;RPL0P0]9a/302`V6PP0:2PN0P0_:Ad202hX70<0;BLK00D0;2HJ034[7`0a:al0<B/O030Z7P02
02lY7@80;RPL200a9ad202hZ7`0502lY7@0a:A`0<bXK03P/700k;Qh00P0m<1l303ha8080?c8Q0P10
<b802012;A`0@bhM048_7P12<Al0@c@Q048e8P13=R<0@cPT0P16=1h204Le7`0404Pf8019=b40BSPR
04Xh8P80DcHT00T0E3PS05Di8`1F>R80Ec`Q05Ll7`1H?B00G3hR05do8`1O@BD00`1Q@bL0101P@RH0
Gd4U06=5;@1N@2P205Tk8`0705`n9P1N@2P0GClW05Xl901K?BD0G3hV05do9`0205i0:00305`n9P1K
?BD0FC/S0080F3hU00<0EcdT05Hl8`1F?2<00P1E>b80101D>R40ES`Q05Hl8@1F?24205Dk80<0E3XO
201C>B88058j7P80Bc/Q0P1<?280101;>b40BCTO04Lg7@15=A/204Hg8PH0ACHQ0P18>1h00`1:>Al0
CCTP04li8@02058j8P0305<k8`1D>R<0CSPP0080CCTP00<0BcXP04Ti7`18>Ql00P16>al804Th7P03
04Xf7@1<>1l0CCTP0080Cc/R00<0CSXQ04`h7`1;=ah00`1<>2000`1=>B40CSXR04hj8P0204lk8`80
DSTU00@0DcXT05@l901D?280ECdQ0P1F?b0205@i700:05@j7`1C>b40D3XR04hj8P1;=R40B3HP04Xl
8P18>R00ASPN04Dg7@80A3HL0P16>1h804Xf7@P0BCLO00@0B3LS04Th9019>2@0BCPT0P1:>BD204/j
9P09050j8`1?>B80C3LR04Tg8@17=B40A3<Q048b8P11<B40>c@J0080?3DK0P0m=Q`203hg7@0403lh
7P0n<Ah0@3<P04<f8`80ACPU00@0@cHS03lb7`0m<1d0?C8P0`0l<Al203/`7P80>RlM00P0?S4N03d`
7@0l;a`0>bhK03`_700m<1d0?c8O044d8@@0ACDN1016=Ql02`1:>200BCLO04Pf7P17=Ad0B3HN04Tg
7`1;>B40C3XR05<h7@1D>Ah0ES/P00<0F3dR00<0Ec`Q05Hk801?>b800P1?>b8204hj8@@0CCTP0P1D
?Ad205Dn7P80ESlO0P1G@200201D>BH0DSTU050g8`1<=R40BcHQ04Tg8@1:>R<0Bc/T0P13=ad304@h
7P<0ACTO0100BSDP04/f8@1=>2<0CSTT04lj9@1>>B@0CCPS04`g8P18=b<0BCPT04Xi9@1;>RH0BSTU
04Th9017=R80ASDQ2018>2400`1>>R40CCTP04`h7`0204`h7`0604hj8@1@?2<0DCdT05Lo9`1F?RH0
E3`T0P1C>b<01@1D?2@0EShV05Lo9`1D@B<0Dd0R0080DSlQ00@0Dd0R05A18`1GA2H0F4DW0`1E@BP[
ooooo`00:_ooool20:1d@`80Wg=200`0X7A30:9fA@2UNDP0YWY90:AkA@2SNT@0XGQ20:1g@@2OMT00
X7M10:5h@P2RND<20:5hA0040:9iA@2SNTH0XgY60:AkA`80YGa80P2UNT<20:IkA0<0Yga500@0Z7e6
0:EkB`2UNd/0YG];0`2TNTX20:=iB@<0Z7e:00<0Yga90:IkB02UNTL00P2UNTL0102ZOdX0ZGi90:Un
B@2XODP20:MlA`80YW]6202XODX20:ImB@040:MnBP2XOd/0Z7m;0:V0C080ZX5=6@2YP4`30:b3C`03
0:^2CP2ZPDd0ZH1<0080ZH1<0P2ZPDd60:V0C080Z7m700@0Ygi80:ImB@2UO4P0Y7Y80P2SNDT20:9m
B@040:5lB02PNdL0WgY609mjAP80WWU50P2OMD<00`2NM480WG=109ab@00209]a?`0309Y`?P2AK3P0
TF`h0080T6/g102?JSH208eY>@0408aX>02;IcL0RVHf08YV=P80RFDe00T0RF@j08QS>@27HSP0QF0f
089M<`20Fc40OeX`07iI;`1oG3@00P1nFc<00`1mFS80O5Ta07]H<00207YG;`80LU<U00<0LU<W075A
:01aDBX00P1`D2X00`1`Cb`0LE0]075@;@06075@;@0606a?;@1/D2/0KE4/06eA:P1^DRX0Ke@Y0P1_
E2L01P1aE2P0LUDY07=F:P1dEb/0MUT]07MJ;P80N5/_00<0PF4b081P<@21Gc400P23GS401P26H3<0
Rf8f08aS=`2>J3T0SFLh08]U=P80RV@e00@0RfDf08eW>02>J3T0RfDf0P2<ISL00`2=IcP0SVPi08iX
>@0208mY>P0308]Z=@2:JC@0R6Lb0080QfHa0P28Ic800`2:JC@0RfXe095V>@02095V>@<0T6Dh0P2?
I3L808aV>@P0SFPc00<0T6Xk08iX>@2=IcP00P2<ISL0302>J3T0T6Xk099/?@2EJSd0TfPk091U>02?
I3L0SV<f091U>02BIcX0U6Tl09=W>P80TVLj00<0TFPj08mY>P2>JSX00P2<JSX01P2<ICh0S6Dl08eV
?@2=IS/0SFLj08iX>@80SVPg0`2>J3T308eW>080S6Hg102:I3L408US=P<0R68e00<0RF<f08YT=`2;
ICP00P2;ICP02022GC00PE`_081K;P20Fbh0PE`_08AO<P27HSD0R6<f0P26HcT01`25HSP0Pf0f089O
=@21GS@0P5dc07mL<P23HC400P22H3000`21Gbl0P5h^07mM;@0207iL;080NUL]0`1kF2h307aI;`08
07]K=01iFC80MUH_07=C;01bDR/0Le</07EE;P1fERl3079B:`03075A:P1`D2T0KdlX0080KThW01H0
M5Hd079E<`1_DS00JU0]06M?:`1UCbX0HdlZ06A@:`1PCRH0GddW05e;9@1KBBD0FDHU05I38`1E@R@0
E44S0590:01??bH0CCdT04Xl8P18?280B3hS0P17@2@04@19@RH0B3`V04Di8`10<b00?C0O03/^7@0l
;al0?c4T040b9@0e;aT0=2dJ03<^6P0`;AX0;bhL02`]7@0/;Al0:bdO00<092HK1@0U9a`3028U7P<0
8B@M0P0P8a`2020R7`807b4N100N81d0100O8Q/07R4J01hQ6P0N8AX301dP6@0401`O600N8AX07R4J
01hQ6P<07b8K0P0P8a`201`O60807B0I0P0N8AX201lR6`80724J00@07B8K01hS700O91d07b@M0P0P
9Ah04@0S91`092@J02HV700Y9a/0;2PL030Z700b:a/0<b`L02X/500[;AL0;BlI02h`6`0^;ad0;BhN
02//7P0Z:ad09RHL00809bLM00<0:2PN02TY7`0Y:Al00P0Z:R0702HW7`0402DV7P0S91h08b@N02<T
7P<08R<M2P0Q8Q`0100R8ad08B8L024R700P8A/201lP6P807QlI01L06b<H01dS5`0Q91T09BDK02XV
7@0`9b00<bPR03DX8P14;Al0B34Q04he7`1A=a`0ES`I0614701[D240METY085X<P2>Lc`0UgU309Ae
?P2ELS`0WWM00:Ak@`020:IkA00808A`E@1^GD<0DT</03hc7`0f<200<30T02X]900S:24802P[8P<0
:BXR0`0Z:b<202//90P0;2dU200_;bD01P0^;bT0;c0X02l`:00`<RL0<38U034c9@80<SDT00h0@cLW
04Di:@18?B/0BSl[04a1:`1=@bX0C48Y04a29`1?ABX0Cd<Y04i2:01?@BL0CclV054o9`80E40X00P0
DClY050n:01??BL0CcdW054o:@1D@R`0EdD_05U7<@80H4DX00@0HDHY06=8:`1UBRd0IT/^0P1XCC00
1@1PCBl0Gd`^05m<;P1NBbd0GDX/00<0G4T[0400HDH[0698;@1RBRh0HDh`05i?<01KCRh0ETd/05E<
:`1QBc@0H4Xb0618;P1RBB/0IT`[06eA;01cEc00N5/c07YT:`1mI2`0PFL^08MX;`2?K3@0U70f09]d
>@2NMS/0UWE2099b?`2;KCT0PfXd07eX<@1lJC40NV/b07a]=01nGRl0Of0a07iQ=@1iHCD0M5he06iJ
=@1XF3@0IeLe07AJ?`1`ES/0Je0c06U<;P1XBBX0KD`[071?;P1dDRl0PED^089G;@23F2d0QE/[08MN
:P29H2P0RV8W08]S:029GbD0RV0V08aR:02>I2X0T6H/09=Y;`2DJS00UF/a0P2FJRd0202GKC40VG4d
09Qd>02EMCX0TG@j08]a>028KcH0SgHn0P2@MCh00`2BM3h0Tg@n09Ac?P0209Ib?P0O09M^@02HL3l0
V7<o09Uf@02JMcd0V7Ti09Ii=`2FNCD0SWTh08ag=P2:LS@0RFlb08]^=02>KcP0TG8l09Ed?`2AL3X0
TVli08m/=P2>JC@0SfLc095X=02BJCD0TfXf08mYA@2@JTD0TVa509A_@`2DL400Tflk099_>@02095^
=P0@099_=`2@LCP0T7<i08ad>028M3L0QG<e089b=029KCd0RVhn08U]?@28K3`0QVXj08=W=`20I3@0
OV8b08QS;080Qf@^0180QF@_08IV<`28JSP0RFdm08]_?`1oIRh0PVTa08I]=`2:L3d0Rg5008Y`?`27
K3d0QFXk07]X<01mJS80P6de089_=`24LCT208Eb>P0908Aa>@2<Md80RgA008Ub?P29Kc`0RFdk08]]
>`2=KC`0SVhm00<0Sg0g0P2@LCP3095b>@0908Ya>`2?MSh0TgQ108me?02:KC<0R6X^08a/;`2@L3<0
Tfle0080TVle00<0Sfld08e_<`2;KS800P29Kc807021Ib`0OfH]07eT;P1gH2h0Le``06mI<01ZES40
JEDb06IB;@1UDB`0HU0/05i>;01KBbX0F4TZ05E8:01DART0GDh]05]<:`1JBbX0G4d/05m@;`1NCbh0
FT/Z05E69@1HBRD0FD/V05]=:01MCbX205i@:`80GDlZ00<0DTDU05=69P1CARH00`1EB2P05P1BABD0
D4<S04i18@1B@R00DD<P05528@1?@R80C44S04]29@18@B@0B44U048o8013@240A44R04E28`14@B80
@ChO03dj6`0k>1T0@3TM044j7P14?B4204Ho8`0404@m8@11>Qh0@3TM03hg6`<0?cPL0`10>Ad01@11
>Qh0>STM03Th700i>1`0>3LK0080=cHJ0P0f=AT3030b6P80<C<K0`0b=1`2030d7@<0;c<L0`0^<Q/0
1P0/<1T0;2lJ02`_6P0[;Q/0:bhM02X/7P80:R`O00@0:B/P02PZ7`0U9a`08bDJ0P0R91T0100T9Q/0
9BLL020V700P9Q`201lU6`0401hT6P0M8aT0728H01`R60806QdF100K7QL201`O60P06Q`I0P0J71/2
01TK6P8061XI7@0G6AP201HH5`<05ALF4@0F61L301PJ6@<05aTH0P0F61L801LI61P05QPG200E5aH8
01HH5`P05ALF200E5QP801HH5a005ALF200F61L801DF60P05QLI200F61L301PJ6@<05aTH0P0F61L8
01LI61`06A/J0`0J71/201/M70P06Q`I0P0L71X301dM6`<07QhL200L7AL801dN60P07QdH0`0P81P3
024Q6@808R8J200Z8a/0100V8QT09b<J02LS6P0W8aX202PT6`X0:BDL0`0[9AT202`V6P<0;BLK200/
:Q/802XV6P80<BLM00@0<2HL02lU6`0]8aT0;28H0P0[8AL202/Y700402XX6`0Y9aX0:BLJ02PV6@80
9bDH0P0W91d0100X9Ah0:BHO02TV7`0Z9b0202/X8@80;bTM0P0^:1`202dW6`80;2HJ00<0:bDI02PY
8@0X:B401P0X:B40100_:Ad0;RPL02hX700^:1`202dW6`80;2HJ00@0<R`P034[7`0a:al0<2XN0P0_
:Ad202hX70P0<BLM0P0^:Ql01P0_:Ad0<BTL03<Z6`0h;1`0>bhN03d`7`@0?S4P0P0o<R42040c8P80
@B`K00L0@BhM048a7`13=240@cHS04Dh9@14>BD0AC<M0080AS@N00<0AcDO04Pf8019=b400P1:>282
05<f900405@h8`1E>B<0ESXR05Hk8080Ec`O00<0GT0T05m19@1Q@bL00P1RA2P01@1Q@bL0H48V05m1
9@1TARh0GT0X0080F3XR00H0G3hV05i0:01L?RH0FC/S05do9`1N@2P205m1:@0405i0:01L?RH0FS`T
05Tk8`80EcdT0P1F?2<0101E>b80E3XQ05@j8@1C>B0305Lm8P80ES`Q0`1E>b0805<i8PP0DSXN0P1;
>b4204`l8P0404Xj8018>1h0ASHL04@d6P80ASLR0P15=R4204@e8080@c@O0P18>1h00`1:>Al0CCTP
04li8@02058j8P0605<k8`1D>R<0C3PO04`h7`1:>Al0BCTO0P18>Ql204Ll80P0BCPN00P0BCDL04/g
7P1=>B00CSXQ04lk8P1>>R40C3PO04/g7P<0C3PP00<0CCTQ04hj8P1?>b<00P1?>b<01P1B>BD0DcXV
05<j901D?2@0ECdS05Dm8@80ESlP0100DcPK05@i701D>Ql0Dc/Q050j8P1=>B40BcHQ04Le7`1:?280
B3XP04Hh7P14=Q`0@cDK04@f7015=ad0ASPN201:=Qd804Tg7`80B3LS0P19>2@304Xi9@0904/j9P1@
>R<0CcTR04dh8`19=b<0Ac@S04Dd9012<R80@S8S0080?3DK0P0m=Q`01`0n=ad0?cPN03lh7P10>Al0
?2lL03lb7`12=B800P15>2D00`14=b@0@3<P03ha7P0403`a7`80>c0N0P0j;ad0200n<Ah0?C0M03`_
700k;Q/0?2lL03d`7@0o<Ql0@C@Q1015=Ah404Hf7`0@04Xh8019=al0B3HN04Le7@18=Qh0BCLO04/i
8@1<>R80DSLL05@i7P1F>b00F3dR05Tn8`1H?B80Ec`Q05Hk8080Cc/R0P1>>R4404di800604`h7`1D
?Ad0E3dM05@m7@1E?Qh0ESlO0`1G@2002@1D>BH0DCPT04lf8P1;=B00BSDP04Tg8@19>B80BSXS044g
7002048h7@0=04<i7P14>Ql0AC/P04Dk8016?240BSDP04/f8@1=>2<0CSTT04lj9@1>>B@0CCPS04`g
8P0204Pg8`<0BSTU00<0B3LS04He8@15=2002017=b000`1?>b80CSXQ04di800204`h7`0604di801>
>R40D3`S05Hn9P1E?BD0Dc/S0P1A>B401@1C>b<0ECdU05Hn9P1B?b40DChP0080D3dO00@0DSlQ05A1
8`1GA2H0FDHX0`1A?B@[ooooo`00:_ooool0202QMdD0X7I409id@P2MLd40WWA20:1fA02RN4H0XgU7
0`2RNDD20:=jAP<0Y7]7202WOD480:In@@<0YWe90`2WOTX20:QoB`030:MmB`2VO4X0YG]90080Y7Y8
00<0YG]90:IlBP2WOD/01@2YP4`50:Z1C@040:V0C02XOd/0Z7m;0:MnBP<0YWe900L0Ygi:0:V0C02Z
PDd0Zh9>0:Z1C@2YP4`0Z7m;00<0Ygi80`2XOdT30:V0BP080:B1B`2VPD`0Z8=>0:^3C`2[PTh0ZWm<
0:YlBP2YNdT20:QoB`<0ZH1<0`2ZPDd20:UoC@80ZX1>0P2[PDl20:b2D0030:MmB`2XOT`0ZX1>0080
Zh5?00H0ZX1>0:QnC02WOD/0Ygi:0:V0C02ZPDd20:^2CP060:Z1C@2YP4`0Ygi:0:1kA`2QO4P0XWe9
0P2SOTX01`2QO4P0WgY609ehA02PMDP0WW=609aaA02JKd800P2IKT400`2JKd80Vg1309E`?00209A_
>`0309=^>P2BKCT0TF`h0080T6/g0P2=JCT04P2<J3P0RfLg08UU=@28I3@0Qf<c08IR<P22HBh0Pf8_
08AR<P24HS@0Pf4d085N=01oG380OEXb085K=`1oFCD0OELc07YD<0@0N58^0P1`E2`306mC:`<0KU8Z
00<0LE<_06mA;@1]Cb/00P1[CBT06@1/CRX0KDl[06i@;01_DBd0KU0/06e?:`1/CRX0KDl[06i@;01`
DRh0LE<_07AD:`1eEB`0MUH]07MG;P1iFC00NUXa07]K<P1lG3<0Oe`f081M=`21GSH0PUle08=Q=025
HcD00P26I3@208QR=@80RF<f0`2:I3L00`2;ICP0RfDf08YT=@0208QR<`0408US=02;ICH0SVPi08mY
>P80S6Hg0P2;ICH0202:I3D0RF<d08US=029Hc@0R68c09=]?P2AJc`0T6Xk0`2>J3T0102?JCX0T6Xk
099W>P2BIcX2095V>@07091U>02?I3L0Sf@g08iS=P2DJC`0TfPk095V>@0308mT=`80TFHi0100TfTg
099X=P2AIcD0TFLe099X=P2DJSP0UV`j09M]>`2@JD80SfQ108eV?`2<ICh0Rf@m08aU?P2=ISl0SVM0
202@ICP0102=IcP0S6Hg08aV=`2<ISL208]U=P@0RV@e00@0RfDf08aV=`2<ISL0SFLh0P2>J3T02@2=
IcX0S6Hi08]U>02:I3L0RF<f08QR=@27HC@0QV0c08]U=P0208YT=@0308US=028HS<0Qf4b0080QV0a
2024GSL01027HSD0QV4d08IQ=025H3<208AO<P80Peha0P21Fbh00`20Fbh0OU`^07eM;P0207aM;P09
07YN;P20GRh0P5h^07mM;`1nG2l0OEX`07aI<@1lFC<0NePb0080NUL_00@0NEH^07QE;@1gE2`0MU<[
0P1eDRX0101dE2d0Le</07=C;01bDR/2075A:P80L50Y00<0JThY06]?:P1]DB`00P1^DRd04@1]DB`0
K50[06]?:P1LC2P0Fd/Y05U99`1GAbH0E4<U05919@1@?bD0CchT04`l6`1>?Qd0CchP050o8`1@?bD0
CcdU0080CC/U00H0BcTS04Dg7015=a`0@SHL044g7P0n=Ql203`f800:03/f8P0i<ad0>C<M03Pa7P0h
<Al0=c0P03H^8@0e;B00=BdR02/[8@80:RXP00<0:BTO02PX7P0W9ad00P0V9Q`202HX7@<09BLL0`0T
9Q/3028S7@808B8L0`0P8A/801hP7@@07R4J0P0O8Q/2020S700801dO700L7Q/06adJ01XL6@0K7AX0
71hK01hP7@0O8Ah301lR6`8082<L0`0Q91d202DW6@0302HX6P0W:A/0:2XL0080:B/M00`0:R`N02dY
7P0]:Ah0;RXN02l/7@0a;Qd0<RlL03<`7@0d<Qd0:b/S02TY8@0W9al302DU7@0302LW7`0X:200:2PN
0080:2PN0P0W9ad302HV70809RHN0P0U9Ad302@T700302<S6`0Q8Q`08B8L00<0824K0`0O81X0100R
8ad08B8L024R700P8A/201lP6P807QlI01L08BLM020V700Q91/08B8J02<T700W9al0;BXS030]9P0k
;2D0?bhT04@c8`1=>2<0ECdQ05e38P1SAb00ITTQ075K:@1iHS00Q6dk095gA02IOD/0WX1>09emC002
09alB`080;5nB@2PLT00PV0c06==:017?R40<CHP02Dc900O<bP202H^7`809blP00@09RhO02D]7P0S
:a`08RXK200V:2<0100Z:b<0:b`T02//900/;BD202d^9P80;RlW00H0<S8Z038b:00a<BL0<C4U034b
900a<R82030a7`0C02l_9@0^;R@0;BdS02d]8`0_;bD0<C4W03<c:@0e=B/0>CHS03Xg900n>BD0@C/U
04Dm9P19?RP0Bd4X04e1:@1=@bP0Bd4V04To900204Lm8P0304Pn8`1:@2D0Bd4V0080CCdT0P1>?RD0
1`1??bH0D40W0551:01A@BP0HTTZ06=::`1UC2d00P1VCBh01P1UC2d0HdX[0699:P1OC2`0GT/[05e:
:P80G4TY02T0GT/[065>;P1RCbl0I50e06=?=01PCc<0GDha05Y<;`1HBRd0EDX/05A9:`1KB2X0GDP[
05e8:@1RBb/0ITh/06]A;P1aE380LeLb07YI;P1mFbh0Oed`08AO<P28HS<0SVHe095W=@2BJ3H0W6lf
09Y`=P2ILCH0U70f08m_=P2;KSH0Qfdd08E/=028Ic@0QVHe08=S<P1oH340Nel`07UN<@0207MO<`0;
07MJ;P1dFB`0LUL/06iF:P1/EB/0JeD/06]H<01/FC40Me8X07YE:`1oFS000P23GS@02`21G380OEP^
07YE:`23FBL0Q5XX08MM:`2:H2h0SV@b095W=@2DJSP0UV`j0080TV<]01X0UFH`09Y[<`2NL3D0X78f
0:1b=02NLC00WG0_09Ad=`2CLcH0Tg<j099a>`2AL3d0TFm1091^@@2@KD<0T6li095`>P2CLS`0UG@n
09Qg@@2KNT@0W7]509imA`2GMT40UG@o09=b?@80TW4l00/0Tg8m09Ed?`2GMT40V7A209Mc@@2DLd00
TG4n08i`?02;L3/0RFhi08M^>002091_?080TG0m00@0TW4n09=b?`2CLSl0U7=01029KcH0302:L3L0
S78i08id>`2?MC`0TW4k095`>P2?KST0SF`i08YX>028ISP0QV@f08ES=P80RFDe0P27Hc<02P28I3@0
RVHf08eY>@2?Jc/0RW8f08]a=P2<LSL0SW4g091a>02ALCP209Aa>@0@08ec>02<LSL0RW0e08U_=02:
L3D0S78g08id>@2@MS/0TgHj095d>02>LCD0S6lc08e`=02@LcL0U7Lk09Mj?P80Ug8k00<0UW4j09E`
>@2DKcP00P2CKSL02@2BKCH0TG8k095b>`2?L3T0SVlh08a]=P2:Jc@0RFXc08QY<P0208I]=@0308E/
=024Jc<0PfXb0080PVTa0240PFP`07iO<`1lGcD0Nehd07QL=01bFC40K5@^06I@:`1SCBP0GDlb05a>
<@1KCC00FD/^05Q:;@1FB2/0EDLZ05A6:@1ECbd0ETd/05I;:`1MCRl0I54c06M?<`1SBBh0H4DZ061<
9`1RCRT0IE4/06MC;P1UDB`0H4`W05Y68@1G@ah00`1DAB@05P1CA2<0DT<R05528@1@@B00Cd0O04ho
7P1@?bD0CchT04dl8P1<>b40BcXP04`k8@1=?280CSdS04Xn9018?280AC/P044j7P10>ah0@3`O03ln
8010?b43044m8PD0@ShS00P0?S@K03df700o>1h0?cTO03hj7`0k>Qh0>CTM03Ph7080=SPR00@0=CLQ
03@f800c=Al0<S@N0P0a<ad00`0]<AX0;c<L030d7@02038f7`03034e7P0`=1d0;c<L00<0;c8M00<0
;S4L02d`6`0/;aX00P0/;aX0200X:aP0:B`I02/^7@0/;R00:bdP02X/8@0Y:b009bPP0P0U:1l0100T
9ah08bHM028U700Q91/2020S6P807RDM00<07B@L01`S6`0K8QX00P0J8AT0100I81P06AlK01TO6`0I
7a/201PN6P<05adI200I6aPP01LI60P05QPG200G6AP401DG5P805QPG0`0G6AP801HH5`P05aTH0`0H
6QT301LI60805QPG0`0E5aH201HH5`H05aTH0P0F61L301DG5QP05QPG200E5QP801HH5b005AHH200F
61L801HG6@P05QPG200G6AP901PJ6@805aTH0P0H6QT201TK6QX06Q`K200L71X201`M5`<07AhH0`0N
7aT301dN608071dG0`0K71H201`M5`<07AhH0`0N7aT401lP6P80824K0P0Q8Q`8028R6PP08b<K00@0
:BDL02PT6`0X91/0:2@K0`0W8aX0100V8QT0:BDI02TU6@0Y9AT202XV6P<0:bLK200^:1`01P0a:al0
<2XN02lY7@0^:1`0;BLK02/U6@80:R@H0`0^:1P302dW5`80;2HF200Z9Qd202dV7P@0;2DM0P0[91`2
02`V6P@0;BLK0`0^:1`802dV7P0;02HR6@0W8aX0:RHM02`X7`0]:B00;2PO02/W7P0Z9Qd0;BHN02hW
7`0_:2000P0`:B400`0_:200;RLO02dV7P0302hX70D0;BLK00H0;2HJ02hV6@0_9aX0<BPI03DY6@0g
:QT203X[60<0>bhK100l;a`00`0m<1d0A3<S04<b8P03044`800?04<b8P15=2@0ASDU04<k:013>2@0
@SLS044e7`14=Ah0ASHM04Th7P1;>R00E3@O05De801H>2<0FSXU00<0Fc/V00L0FSXU06I39`1T@RH0
HT<V05i39@1KA2@0FDDT0080EDDS0P1J@RX0101I@BT0F40X05Q0:01G?bL205Hn9P0305@l901F?RH0
F40X0080FD4Y00`0F40X05Hn9P1D?2@0FSlR05Tn8@1G?B80ECdS058l901?>b<0CSTT04`j901@>R<3
04li8P80CSPQ0P1==b00101;>B<0CC/U04hl9P1;>B<204Pf800:04`j901@?RP0E44S058n8`1A?B80
Cc/R04hj8P1>>B@0CSTV04lj9`D0CCTP0`1>>R400`17=b00ASHO04@d7@02048b6`0304<c7015=Ah0
ASHO0080AS@L00<0AcDM04Pf7P1:>2000P1;>B4204`j8PP0BcLN0`17=ah204Ph7`<0BCTP0P1:>202
04/i8@<0C3XR00@0CC/S04di8@1<>200BcLO0P1:=Qh02@1<>200CSXR050l901F?2D0ECdU05@l901A
>b<0Cc/R04dl8P0204/k8@0804dm9P1;>b@0BCTR04Lg8016=Ql0ACDN04Hf7`17=b0804Dd8PP0A3@M
00H0@C@Q048e8P12=B80@cHS04@g9015>2D204Hi9P<0B3LU0P19>2H304Xi9`0804@h8P13=b40@SHP
044e7`0o<ad0?S8L03da6`0l<1X203/_8@0503``800l<Al0?C8P03db7P0m<Q`00`0n<ad503ld7P03
040e7`0g;aX0=blJ00H0=blJ00P0>C0O03Xa800l<Al0?S4N044b7@13<a`0A3@M04Dc6`80@CDM0P12
=Qh204<g7`80A3PP00T0?cLP04<h8P16?2<0BCdS04`n8`1;?1l0BSTM04Th6P1H?RL00P1G?BH00`1F
?2D0EC/T05@j8`0205<i8PT0CSXQ201@?Al01@1A?2L0CcXU04/i8`17=b00A3DN0080@SHN00<0@CLN
044d8@11=2401P11=24804Hc8PP0BCHU00T0@SXU04<k9P16>bL0B3/X04Tj9`18=bD0AC@R04@a801=
>B000`1>>R4204lk8P80D3`S0P1@>ah00`1A?1l0DSdP05<n8@0205@o8P0305E08`1D@2L0E40W00H0
E40W0`1B?RH[ooooo`00:_ooool00`2RN4H0XGM50:1fA00209me@`030:5gA@2SNDL0Y7Y800<0XWU5
0P2SNTH30:AkA`P0Yge3202VOT<30:ImB@<0Ygi:0P2XOd/00`2XOT`0YWa:0:EkB@020:AjB0030:Ek
B@2VO4X0Z7i<00/0ZH1<0P2XOd/30:MnBP080:AkA`2VODT0Z7m;0:V0C02ZPDd0ZH1<0:QoB`2WOTX3
0:MnB0<0Z7m90`2YP4X02@2UPT`0YX5<0:R3CP2ZPTh0Zh9>0:YoC02ZO4X0ZG]90:Z1C@070:V0C080
ZGm=0P2ZP4h20:^1C`80[89@00<0Yge;0:QnC02ZP4h00P2[PDl01P2ZP4h0Z7i<0:MmB`2WOTX0ZH1<
0:Z1C@80Zh9>0100ZX5=0:V0C02WOTX0WgY60:1kA`2QO4P0XWe90:5lB02PNdL0WWU509ehA02PMDP0
WgA709aaA02JKd80VFi10P2JKd801`2KL4<0UG0l09E`?02DKc/0Tfhj099]>@2AK3P00P2@JcL05@2>
JSX0SFTi08aX>02;IcL0RFDe08QT=027Hc<0QV8b089Q;P23HRl0Q68b08AR=023HC@0PEhd07mL<P1m
FS80PE/g07mI=@1mEc<0NU@`07UC;`0207QB;P0407UC;`1`E2`0L5@/071D;080Ke<[0`1^DRX0401`
DRh0Ke4]06e?:`1/CRX0JddY06a>:P1]Cb/0KU0/06mA;@1^D2`0KDl[06a>:P1]Cb/0KU0/071B;P1a
Dbl207AD:`0407EE;01gEbh0N5P_07YJ<@80Ne/b0P1oG3H01P20GCD0PUle08=Q=024HS@0QF<c08IT
=080R68e0P29HcH408YT=`0808YT=@29Hc@0RF<d08QR<`29Hc@0RfDf08iX>@2?JCX208eW>080S6Hg
0`2;ICH208YT=@0809=]?P2AJc`0SfTj08iX>@2=IcP0SVPi08mY>P2@JS/2099W>P80TFHi00L0T6Dh
08mT=`2?I3L0Sf@g09=X>`2BIcX0T6Dh0080SV<f00D0Sf@g091U>02AIST0TVPf095W=@02091V=00<
095W=@2BJ3H0U6Xh09E[>@2@JD00SfPo08eV?@2<IC`0Rf@k08aU?02=ISd0SVLn202@ICP208iX>@80
SFLh0P2<ISL208]U=P80RV@e0P2;ICH0102<ISL0SFLh08eW>02=IcP208aV>@0408]U>02:I3L0RF<f
08QR=@80Qf4d0`29Hc@308QR<`80Qf4b2024GcD308IQ=00308EP<`24Gc80Q5lb0080Peha0P23GC00
0`22GC00P5h`07mO<00207iO<00907aP<020GRh0P5h^07mM;`1nG2l0OEX`07aI<@1lFC<0NePb0080
NUL_00@0NEH^07QE;@1gE2`0MU<[0P1eDRX207AD;@0407=C;01bDR/0LU8[075A:P80L50Y00<0JThY
06]?:P1]DB`00P1^DRd04@1]DB`0K50[06]?:P1OCBT0GT`X05a9:01IARH0Ed@V05A09@1C?b@0DShU
04dm701>?Qd0CchP050o8`1@?bD0CcdU0080CC/U00H0C3XT04Dg7015=a`0@cLM044g7P0n=Ql203`f
800903Xe8@0j=1h0>C<M03Tb7`0h<Al0=c0P03H^8@0e;B00=BdR0080:b/Q00@0:RXP02TY7`0X:1h0
9bLM0P0V9Q`302HX7@809BLL0`0T9Q/3028S7@808B8L0`0P8A/801hP7@0401dP6@0N8AX07R4J01hQ
6P807b8K0P0P8a`00`0N81d07AlL01/M6P0201/M6P0301`N6`0N81d07b4N00<07b8K0`0P8a`2024T
7@0602@V6@0U9aX09BLJ02HX6`0W:A`0:2XM0P0Y:ah0300/:1d0;BTN02hZ7P0_;1d0<BhM038_700c
<1d0=38M02`/8P0[:b40:2PN02HV70809BDK00<09RHL02LW7@0X:1h00P0X:1h202LW7@<09RHL0P0V
9Qh202DU7@@092@L0`0Q8Q`2020Q6`<07b0J00<08R<M024R700Q8Q`00P0P8A/201lP6P0G01hO6@0N
91X07R@J020S6P0R8a/092DM02LW7`0[:240;2TR03TZ8`0k;B80@S0R04Tg8`1B?B80FT4R05m5801T
B240KELV07AL;01nISH0RW0o09=gA`2JNd`00`2MOD`02@2^O4L0XWM4095/@01jGST0GTda04Dn:`0b
<bD0:2/P02d`9@0202`_900502P^900W;B<092`Q02<Z8P0R:B40200W:B@00`0Z:b<0:b`T02//9002
02`]9@80;BhV00L0;RlW034a:@0a<BL0<C4W034a9@0a<R@0<C8R0080<34O00<0<30V02l_9@0^;R@0
0P0^;R@03P0`<2H0<S8X03<c:@0f=B<0>3DR03Xg900o>RH0@S`V04Hn9`19?bH0BT0W04a2:@1;@BP0
BT0W0P18?RD00`19?bH0Bd4X04a2:@0204hn9@0404lo9P1@@2L0D40W0551:080DT8Y00D0Fd@T05e6
9P1PBBT0Hd`/06E>;P0306I?;`0@05m<;01NBb/0GDXZ05e::P1NBb/0H4d]069?;`1TDC40IE0e06=?
=01RCS<0GTda05a=<01IBbh0ET/]05E:;080G4T[01/0GDPY065::`1TBb`0JDl^06aB;`1`Dc40NEP_
07YI;P1mFS00Pehb08IQ=02:I3D0SVHe091X=`2IKcD0VG4f09Ub>@2GLcT0Tg<j08m`=`2;KSH0Qfdd
08UX=@28Ic@0Q6@c081Q<P1mHC800P1kH3<06@1jHSH0NEd^07MJ;P1dFB`0KeL[06eF;01/ERd0K5H_
06]H<01fDbT0N5D[07]H;P1mFS00OU/a07eJ<01jEbd0NEH/081F9021EbD0Q5XX08MM:`2:H2h0SF<a
091V=02AIcD00P2@HBd01`2CI300V6Tc09a]=@2NL3D0WW0d09a^<P2KKBl00P2BLc804@2BLc<0TW8g
099b>@2BLC`0TW4n099`@02BLST0Tg<j09Ad>`2GMch0VGU009al@`2NOTD0Wgm609Qg@P2GMT40UG@o
0080U7<n00T0UG@o09Mf@@2HMd80V7A209Mc@@2EM440Tg=0091b?P2?LCd00P2<LC`8099a?P0408a_
=`2=L3P0SG0h08ia>@@0Sg8j00X0TG0j091_>@2?KST0SF`i08]Y>@29IcL0R6Hh08MU=`28ISH0QfDe
0P26I3@01027ICD0RFLg08]Y>@2<JSX208ab=`80SW4g00H0Sg0g095a>02CL3P0Tg0h08mb>02>LCL2
08e`=P0708ia=`2@LcT0TWDk09=f?02CMSX0TG@h08ia=@0208a_<`0308mb=P2BMCT0UGPl0080UG0i
0`2DKcP309=^=`80Sg0j00H0SVli08a]=`2;K3H0RV/e08UZ=028JC<208I]=@0608A[<`23JS80PFP`
081W;`1oIRh0OVD]0P1kGS@01P1iGCD0M5/b071I<01ZE2d0IU0[065=:080Fdd`00<0FT`_05U;;P1H
BRd00P1GBB`02P1FB2/0F50/05M=:P1GBRP0Fd`[069?;`1UD340I4d^0658:P1TD2d206EA;P0606=?
;01PC2T0FdLT05I27`1C?a`0EDHU0`1DAB@05@1CA2<0DD8Q0511801@@B00Cd0O05109P1??bD0CCdS
04`l8P1;>b40C3`R04dm8`1>?R@0BCdS04Pl8P15>b00@S/O040k7P10?1l0?chP040o8@04040l8@@0
@CdR00P0?S@K03df700o>1h0?cTO03hj7`0k>Qh0>CTM03Ph7080=SPR00@0=CLQ03@f800c=Al0<S@N
0P0a<ad0200^<Q/0;c<L030d7@0a=Ah0<SHO034e7P0_<a`0;S8K0P0_<Qd202ha700402d`6`0/;aX0
;2lJ02`_6P80:B`I00L0:bhM02/]7`0[;B00:R`Q02PZ7`0W:2009BPO008092LN00<08bHM028U700Q
91/00P0P8aX201hU7@0401dT700L8a/06b8J01XQ6@806B0H0P0I7a/301PN6P<05adI200I6aPP01LI
60P05QPG200G6AP401DG5P805QPG0`0G6AP801HH5`P05aTH0`0H6QT201LI60<05QPG0`0E5aH201HH
5`H05aTH0P0F61L301DG5QP05QPG200E5QP801HH5b005AHH200F61L801HG6@P05QPG200G6AP901PJ
6@805aTH0P0H6QT201TK6QX06Q`K200L71X201`M5`<07AhH0`0N7aT301dN60<071dG0P0K71H201`M
5`<07AhH100N7aT301lP6P80824K0P0Q8Q`8028R6PP08b<K100W8aX402PT6`<0:BDI0P0Z9QX302/W
6`P0;RPL0P0_:Ad202hX700402dW6`0/9QX0:bDI02/U6@<0;RPH0P0]9aL302`V5PP0:RHM1P0/9Ad2
02/T7080;2HJ100]9a/302hX70P0;BHN00<09b<J02PT6`0Z9Qd00P0/:1l01P0[9ah0:RHM02TU700/
9Ad0;RLO02lX8080<2TQ00<0;bPP02hW7`0/9Ad00P0^:1`702dW6`0702hV6@0_9aX0<BPI03DY6@0g
:QT0>R/H03//6@0203/^6`80?2lL00L0?C0M03ha7P0n<Ah0?c8O04@c8`13<R80@S4Q0080@C0P00l0
@c8R04Dd9016=BD0A3TW04<h9013=R<0@SHP04@e7P17=ah0BCPN04/j801D=B00ECHQ05Pi901J>bH0
0P1K?2L205Xk9P0806A29P1Q@RD0H4<U05e2901KA2@0F4@S05I38P1DA28205U1:@80F40X0P1G?bL2
05Hn9P0305@l901F?RH0EclW0080F40X00<0EclW05Hn9P1D?2@00P1H?B001P1F?240E3`R058l901@
?2@0CcXU04dk9@@0CcTR0P1>>24204dg800404Xh8P1<>R@0CC/U04/i8`80AcDO00<0BcTS050n:01A
?R000P1A?B800`1A?B@0D3`T04hi900204dh9@<0C3PO1@1=>B000`17=b00ACDN04@d7@02048b6`03
04<c7015=Ah0ASHO0080AS@L00<0AcDM04Pf7P19=al00P1:>2000`1;>B40C3XR04/g7P0704/g7P<0
AcLN0`18>1l204Ti8080BSPP0P1;>B4404`j8P0304di8@1<>200BcLO0080BSHN00l0C3PP04hj8P1?
>b<0ES`U05Dm9@1D?2@0DC/S04lk8P1<>b40Bc/Q04Xj801<?2D0Bc/T04Ph8@16=Ql00P15=Ah204Hf
7`P0ASDS2014=1d01012=B80@cHS04<f8`13=R<404@g900404Lf9018=bD0B3LU04Pg9@80BCPV0P1:
>BL204<g8@06048f8011=Al0?c<M03hb700m<A/0?30J0P0k;b40100l<200?34O03db800m<Qh203db
70D0?S<M0`0o=1h803L_6P0803T`7`0j<B00?34O03ha7P11<Qd0@c<L04@d7@15<a/2044e7@80@SHN
0P13=al204@h8008048g8@13>280ACTQ04Lk8@1:?240Bc`O04`k7`1<>ad205Hn9P0305Dm9@1D?2@0
Dc/S0080DSXR00<0DCTQ04hj8@1>>R401`1>>R48050l8@08050k9P1?>RD0BSPR04Hf7`14=Ah0@CDM
048f7P11=ah8044d8@P0AC@R2017=R@02010>2<0@CTT04Dj9P16>BH0B3TV04Pg9@16=B<0AC8Q0`1=
>B0204hj8@<0Cc/R00H0CcXO050k801@>b00DC`Q058m8P1C?R<205@o90P0DclV0`1B?RH[ooooo`00
:_ooool00`2SNDL0XWQ60:5gA@020:5gA@030:=iA`2TNTP0YG]900<0XWU50P2SNTH30:AkA`P0Yge3
202VOT<30:ImB@<0Ygi:0P2XOd/00`2XOT`0Yge;0:EkB@020:AjB0030:EkB@2WOD/0Z7i<00P0ZH1<
0`2WOTX20:QoB`<0ZH1<00<0XgY60:AkA`2VODT00P2XOd/00`2WOTX0YWe90:ElB0030:MnB0<0Z7m9
0`2YP4X0202UPT`0Yh9=0:N2C@2ZPTh0ZX5=0:YoC02[OD/0ZWa:0P2[PTh20:Z1C@040:V0C02XOd/0
Ygi:0:MnBP80ZGm=0P2ZP4h20:^1C`80[89@00<0Z7i<0:UoC@2ZP4h00P2[PDl01P2ZP4h0ZGm=0:Qn
C02WOTX0ZH1<0:Z1C@80Zh9>00<0ZX5=0:V0C02WOTX00P2ONTH30:1kA`0709iiA@2MN4@0W7M30:1e
B02OM4L0WG9509]`@`0209Y_@P80Vg130P2EL3`00`2DKc/0Tfhj099]>@02095/>007091[=`2>JSX0
SFTi08aX>02;IcL0RVHf08QT=00208MS<`0<08=R;`24Hc00Q68b08AR=023HC@0PEhd07mL<P1nFc<0
PE/f081J=@1mEc80NeD`0P1iDbh207YD;`04079E;@1aE2`0LE@/075D;080L5<[0P1_DRX00`1`DRh0
Ke4]06e?:`0306a>:P80KDl[00<0Ke4]06i@;01]Cb/00P1/CRX04@1^D2`0L58^075C;`1cDbX0M5@[
07EE;01fERd0N5P_07UI<01jFS40Ne/b07iK=@1oG3H0P5de085N=022H3<0Q68d0080QF<c0`28HSD2
08US=P<0RV@g00L0RV@e08US=029Hc@0RF<d08YT=@2<ISL0SFLh00D0SVPi0`2=IcP208aV=`08099/
?@2AJc`0SfTj08iX>@2=IcP0SVPi08mY>P2@JS/3095V>@<0T6Dh0P2?I3L00`2BIcX0TFHi08mT=`03
08eR=@80Sf@g0100TFLe091V=02?IC<0SV@b08mU<`2@IS@0TVPf09=Y=`2@JD00SfPo08eV?@2<IC`0
Rf@k08aU?02=ISd0SVLn202@ICP308mY>P80SVPi0`2=IcP0102:I3D0RfDf08]U=P2;ICH308aV=`06
08eW>02<IST0RfDh08]U>02:I3L0RF<f0P28HSD00`27HC@0Qf4b08MQ<P0308QR<`<0RF<d2024GcD2
08IQ=0<0QF0c0`24Gc8208AN<@0308=N<@21Gc40P60a0080Of0a00T0OF4a081N;P20GRh0Oed_07iL
;`1mFS00O5Ta07aI<`1kF3800P1jEbl0101iERh0N5D]07MD;01fDb/207EB:P0607EE;P1dE2d0M5@]
07=C;01bDR/0LE4Z0P1`D2T00`1[CbX0K50[06eA;00206iB;@0;06eA;01[CbX0JThY05m=9`1NC2P0
GD/W05Y79P1HABD0ET<U05A09@1C?b@00P1??ah0101@?b40D3lS050o9@1>?2@204dk9@0604`j9016
>1d0ASPM04<g7@11=ah0?SHO0P0l=R001P0j=B40>C@N03Td7P0h<al0=c8O03H`8080=BlQ00H0=2hR
02/[8@0[:b40:RXP02TY7`0X:1h202LW7@0302HV700W:Ah09RPM00809RPM0P0U9a`202@V6`<08R<M
0P0Q8Q`3020Q6`P07R0M0`0M81T201hQ6P<07b8K00<07b4N01hP7@0L7Q/00P0K7AX00`0L7Q/07AlL
01hP7@0201hQ6P807b8K0`0P8a`01P0Q91d092HK02@V6`0U9a`09RPM02LY7P80:2XO00l0:B/P02`X
7@0]:Ah0;RXN02l/7@0`;A`0<RlL03<`7@0c<A`0;blU02d]8`0[:b40:2PN02LW7@0V9Q`00P0U9A/3
02PX7P809bLM0`0V9Q`302HV7P809BDM0`0T91`0100R8ad08B8L024R700Q8Q`2020Q6`807b0J100Q
8Q`2020Q6`807b0J01L06R0F01`R600P8aX08b@L02@U7@0V9Qh0:2DN02LT7@0b:1l0=bXQ03`_7`14
<b40CCTQ05Hn8P1K@R<0GdDT06I?9@1/E2P0Le/_07mT=`29KCh0TgA509YjB`0209alB`0>0:IkAP2V
ODT0XWa?09IdC`21I4H0ITdg04dg:@0m:Q`0=34Z03<`:@0^;BP0:R/V02PY900V:2D202@X9`P09bXS
100[;2@202`]9@80;BhV00H0<30X030`9P0`<2H0<30T030a8`0a<R82034b800303<c:@0a<BL0<30V
00<0;RhT0P0`<2H02`0d<b40=C@R03Pe8P0l=b<0?cPU048j9@14?2D0Ac`V04a2:@1;@BP0BT0W0080
BClV00<0BT0W04]1:01<@RT00P1??bH0101@@2L0DD4X0592:@1C@bX205A4:`0605Ho801H@B80G4DV
0619:P1TCBh0Ie0a0P1YDS<305e::P0;05i;:`1PCBd0He0`06EB<P1VDc<0IE0c06A?<P1RCc40Gdh`
05e<;P1KC2d00P1IC2`09P1KBRh0GDT^05a9:`1MB2T0HDXZ06A<:P1XCRd0JDl/07=F;P1fERl0NET`
07eL<@21Gc80QV4d08YT=@2;ICH0UVde09Qa>02IM3d0VgHo09Qh?`2EMC`0TG8i08e`=P2=JS@0RFPc
08MV<@23Hc00PF<a07mS<`20ICH0PFHg07mP<@1mGS00N5`]07EJ;@1`F2`0KUL]0P1/ERd207MD;0<0
N5D]0`1iERh0201iDb@0NU@U07eG:01oFBX0PU`]08AN;`26H340Qf4b0P2:GRd01`2=HC00TFHc09AY
=02FJc@0UV`b09E[<@2DJRh00P2AL2/0402BLBh0U78b09Ec=02GMCP0V7Hi09Qe>`2FLc/0Ug@l09Qe
?@2KN400WGY209mlA02QOTH0XWm709Yi@`2IN48409Qg@@0709Uh@P2JND<0V7<o09Qc?`2GLcl0UG@o
09Ae?`0209=e?`05095f?`2EM3l0UG@o09Ac?P2CLSd00P2BLC`2095`>`0308ia>@2?LSX0TWDm0080
TgHn00<0T7<k08ia>@2<KcL00P2?KcH01P2>KCL0SF`g08a[>02;JCT0RVPh08YX>P80RFLg00`0R6Hf
08MU=@28ISH0RFLg08YX>02;JCT0SG<h08mb>02>LCL0Sg0g091`=`2AKSH2099]=P0;08mb>02>LCL0
SW4g08mb>02@LcT0TWDk09Ag?@2EN3h0TWDk091c>@2=L3H00P2;KS@00`2<KcD0Sg8h091c>@04095^
>0@0TVli0P2:K3H208U[=@80R6Xd0P27JC<04025JcP0Q6Xg08=Y=P21Ic@0OV@a07aR;`1kHBh0NV0]
07QK<@1gFc<0MUXb075H<01]EBl0J58]06=?;01QCBX705]<;@0A05Y;;01JD2d0F4/Y05M89`1IBRT0
HDh^06AA<@1TCc00I4d^06ID<01TDRh0HDl[05e;9`1IAb<0E48N054o6`1??AT00`1EARD0101DAB@0
Dd@S05938P1B@b8205528@0305519`1@@2H0CShT00<0C3`R0P1>?R@01P19?B<0B3`R04Dk8012>al0
@C`O040l7`80?chP200o>b00200o=A`0?SLM03lh7P0o>Al0?SXO03/j7P0h>1`0=cLK0P0f>280100e
=b40=3HP03<e7`0b=1h2034c7@0302hb6`0_<a`0<3@M0080<CDN00<0<3@M02lc700^<Q/00`0^<A`2
02d`6`<0;2lJ00P0:B`I02X]6P0[;Qd0:bdO02/]800Y:b009bTN02HW7`8092LN00@08bHM028U700Q
91/08B@K0P0P8aX01P0N9Ad07B@L01dT700L8a/06b8J01XQ6@806B0H00@06AlK01PN6P0H7QX061hJ
0P0G7AT201HL60P06A/H800G6AP801HH5`P05aTH100E5aH201HH5`<05aTH200F61L801LI608061XI
0P0G6AP301HH5`@05ALF0P0F61L601LI60805QPG0`0E5aHH01HH5`P05AHH200F61LP01DF60P05QPG
200F5aT801HH5`P05aTH2@0H6QT201LI608061XI0P0I6aXJ01XL6`P071`J0P0L7AL301dN60D07QlI
0P0M7QP301`M5`0301/L5P0L7AL071dG00<07AhH1P0N7aT201lP6P<0824K200Q8AT802<S6`0502DQ
600V8QT09R8I02LS6P0X91/00P0Y9A`0100Z9Qd0:BDI02TU6@0Y9AT202XV6P<0:bLK2@0^:1`702dW
6`80;RPJ0P0]9aT302`V600302/U5`0Y9A`0:BDL00H0:BDL1@0[91`302`U7@80;2HJ100]9a/302hX
70P0;BHN0P0Z9Qd302/W7P0602XV7@0Y9A`0:2@K02`U7@0]9Qh0;bPP0P0`:B400`0_:200;BHN02`U
7@0902dW6`0702lW6P0`:1/0<RTJ03HZ6P0h:aX0>b`I03`]6P0203/^6`0703`_700n<Ah0?c8O040c
8011=240@SDR04<b8P02048a8@03044`8012<B40@c8R0080AC@T00`0@cPV04@g9013=R<0ACHQ04Hf
7`19=al0C3PO04di801F=b80EcPS05Tj9@1K?2L205`m:00305/l9`1J>bH0H44U0080GT0T00D0G44T
05Y18`1I@R<0Ed8S05I18P0205Q0:0<0EclW0`1F?RH00`1D?2@0ECdU05Hn9P0205Lo9`0305Hn9P1E
?BD0E3`T0080ES/N00H0EC/P05@l8P1B?2@0DCdU050k9P1>?2H304hj8P80CCTQ0`1<>200101:>280
C3XT04dk9@1:>28204Le7`0:04Xh8P1??BL0CS/M050l8@1B?R<0DShU054m9@1?>RD0C3LT04Td8@P0
BCLO0P15=Ah01P14=1d0@c<L04<c7014=1d0ACDN04Hf7`80AS@L00<0AcDM04Pf7P19=al00`1:>200
0`1;>B40B3HN04Pf7P0604Pf7P80ASHM0P17=ah304Ph7`0404Ti801:>200BSPP04Xh8080BcTQ0`1<
>R80501<>200BcLO04Xf7P1:=Qh0BcLO04`h801=>B40CSXR05Dk901D?2@0Dc/S050j8P1>>R40BcXP
04Xj8019>Al0Bc/T04Xj8`17=b00ASHO0P15=Ah204Hf7`P0AcHT2014=1d01014=b@0@cHS04<f8`13
=R<4048e8P0404He8`17=R@0AcHT04Lf9080B3LU0P19>2H204<f8`04048e8P10<b00?c8O03d`7@80
?2lL0P0k;b40100k;al0?34O03`a7`0m<Qh203db70P0?C8N200f;Q/0200i<1l0>S4P03`a7`0n<Ah0
@C8M04<c7014=1d0AC<K0P11=Ad2048f7P80@cLO0P14>2002@12=b40@cLQ04@h8017>Al0BSXP04dl
801A?B80Dd0R05Hn9P0205Dm9@0305@l901C>b<0DSXR0080DCTQ2@1>>R4804lk8P0504lj9@1=>2<0
BCLQ04De7P13=1d00P11=Ad00`11=ah0@C@Q044d8@06044d8@P0A3<Q2016=B<01@0n=R40?cLR048g
8`14=b@0AcPU0080AcHT00@0Ac@S04Xh801:>200BSPP0P1;>B4304`j8P0604di801>>R40CSXQ04lk
8P1@?2<0DCdT0P1B?RD805<o9P<0DClW:oooool002[ooooo1@2SNDL00`2TNTP0YG]90:EkB@030:9i
A@80XgY60`2TNdL80:MlA@P0YWe50`2VODT30:MnBP80Z7m;00<0Z7i<0:MmB`2VO4X00P2UNdT00`2V
O4X0Yge;0:QnC0030:V0C0@0Z7m;00@0Ygi:0:ImB@2VODT0Ygi:0P2XOd/01P2YP4`0ZX5=0:Z1C@2R
NDD0XgY60:ElB080Ygi:00<0YWe90:ElB02TNdL00`2WOTP30:QoB@<0ZH1:00H0YX==0:N2C@2WPTd0
ZH5=0:V0C02ZOd`20:]mB`060:f4D02/Pdl0Zh9>0:Z1C@2YP4`0Ygi:0P2VODT20:UoC@80ZX1>0P2[
PDl20:b2D0<0ZGm=0P2ZP4h30:UoC@030:MnBP2YP4`0ZX5=0080Zh9>00<0ZX5=0:V0C02WOTX0102O
NTH0202NNDD0WGQ409ehA02LMd<0XGI909mdA`2MLTD0Vg130P2JKd800`2KL4<0W75409Ia?@0209E`
?00309A_>`2CKSX0TVdi0080TF`h0P2>JSX01P2=JCT0RfLg08YV=P29ICD0R6@d08MS<`80Q6<`00X0
Q68b08=Q<`22H3<0PEhd081M<`20GCD0PE/d081J<`1nF340O5H_0P1jE2d0101kEBh0O5H_07AD;@1d
E2d307=C;0<0LU8[00<0Ke4]06i@;01^D2`00P1]Cb/306a>:P0F06i@;01]Cb/0K4hZ06]=:@1/CRX0
KDl[06mA;@1aDbl0LU8Y07=C:P1dE2/0MED/07MG;P1hF2l0NET`07YJ<@1mFS@0OU/e07mL=020GC<0
PElb08=Q<`80Q68b0P27HC@208QR=@80RF<f0P2:I3L308US=00508YT=@2;ICH0S6Hg08eW>02>J3T0
1`2?JCX208iX>@03099/?@2AJc`0SfTj00<0SFLh00@0SVPi08mY>P2AIST0TFHi1P2@ICP02`2AIST0
T6Dh08iS=P2=HSD0S64d08eR=@2>HcH0Sf@g091V=02?IC<0SV@b0080SF<a00/0SV@b091V=02AIcD0
T6Tn08mX?@2=IS/0S6Dj08]T>@2<ICX0SFHk08iW?00808mT=`<0T6Xk0P2?JCX308iX>@P0RfDf0P2;
ICP208YT=`80RF<f0P28HSD208IP<@0308MQ<P28HS<0RF<d0080RV@e00<0RfDf08EP=025H3@01P25
H3@608EP<`80Q5lb0P25Gc800`24Gc80PV0b085Q<P02081Q<P0907iR<P20GRh0P5h^07mM;`1nG2l0
OEX`07aI<@1lFC<0NePb0080NUL_00@0NEH^07QE;@1gE2`0MU<[0P1eDRX207IF;`0907EE;P1cDb`0
LU8[075A:P1`D2T0KdlX06]?:P1/D2/0KE4/0080KU8]00/0KE4/06]?:P1ZCRT0HDhV061<9`1OBbH0
GDTV05Y69@1IA2D0Ed8U05I1900205518004050o8@1@?b<0CchT04hl90<0CC/U00P0B3XO04Li7P14
>1h0@SPO03lg800l=R00>cDO03Xe8@80=cDN00L0=S@O03Db7`0e<R40=34R03<`8@0c;b<0;2`R0080
:b/Q00<0:RXP02TY7`0X:1h00P0W9ad202LY7P<09RPM0`0U9a`3028S7@808B8L0`0P8A/801hP7@<0
7B0I0`0N8AX201lR6`08020R7`0O8Ah07AlL01`N6`0K7AX071hK01dO700N81d301hQ6P807b8K0`0P
8a`202<U6P0302@V6`0U9a`09RPM00809bTN00l0:2XO02`X7@0/:1d0;BTM02l/7@0`;A`0<BhK038_
700c<A`0<30T02l_8`0];B40:b/O02PX700W9a/00P0U9AT302PX7P809bLM0`0V9Q`202LW7`809RHN
0P0U9Ad202@T70808R<M0`0Q8Q`3020Q6`H08B8L0P0P8A/05`0H7Q@06R0F01lR6@0S91`092DM02DU
7@0U8Q/0924J02dV700`:1d0=B`M03d`7`16=B40CSXR05<n8`1G?b<0GTHR06989@1WCBP0LUH^07eP
=029JS`0Tg=40080V7Q70100X7U20:EmBP2YPe@0Z85J09]dD`26GT@0KTPc060j9`0n<BT0>BhX03<Z
9@0/9b<0:BDT02LW9`0W:2`0:BX^200X:b8602//9080;2dU00H0;blW02l_9@0`<2H0<30T030a8`0`
<B42034b800403De:`0c<bT0<C4W02l_9@80;BdS0P0^;R@0200`<B40<C8R03@c8@0g=240>cHR03hg
9010>R@0@CTR1@1:?bT204]0:P0704a1:`1@@2L0D40W0551:01B@RT0Dd<Z05A4:`0205E5;00805@o
8P1F@B@0FD@W05a7:P1OBRd0HTd`06A?<P1UD3<205a9:@0605i;:`1OC2`0HTl_06AA<@1VDc<0Ie@d
0P1VCc00<@1SCRl0HDh^05m?;P1NCRd0G4d/05]>;01KBc40FdX`05Y9;@1KB2X0GDPY0619:@1SBR/0
I4`Z06aB;@1`E2d0LUH_07II<@1lG3<0P5ld08=Q=024HSD0T6/f09A_>P2IM3d0W7U109ej@02INCh0
UWHi09=c=P2BKCH0Sf`d08aY<`27IS00QFH`08EW<`25JCL0QVXh08AT=@21HS<0Of0b07UM;P1eFRd0
LET]06iG;@1]ER`0MeD_07ID;P1dDR`00P1cDB/02@1dDR`0MeD_07QF<01dCb<0ME0T07QC9`1jEBT0
O5L[07eH;00207iI;@80Q5/_01D0QUd_08UP<P2<I3<0SVHc08iV<P2=IRl0S6D^08e[902>K2D0T6dY
09=`;02ELRh0V7Dc09Yg=@2KN3H0V7@j09Ue>`2JMS`0W7Pn09ij@02PO4800P2ROT@209]k@P@0VWY1
0P2KNd8209Yb?P0F09Ud?`2IMT00V7M109Qi@P2HNd<0VGa409Qg@@2GMT00UWDo09Ed?P2CLS`0TG0j
091_>@2?KSP0TG8k09=d?@2FMd00V7U209Ig@02CM3d0SVlh08Y[=080SVhc00@0SVhe08i]=`2=K3L0
SF`i0P2=Jc/00`2:JST0RFTh08UY>00308QX=`80RFTh0P2?LSP0102?L3L0T70g095^=P2BKCH209=/
=@80T74h0P2ALST03@2CM3/0U7Dl09Ef?@2FMch0T7<k08mb>P2<KcL0RVde08U/=02:KCD0Rfhf08a_
=`2;JSD00P2<JcH00`2=K3L0SVdh08m^>@02091_>PP0Q6Td0100PfPi089W>020ICH0OF8c07]P<@1h
GBh0MU//07EJ:`1dF300LEP_071G;`1/E2h0JE<^06A@;@1QCRd0Gd`[0`1KBbX00`1LC2/0GDd/05i>
;@0205i>;@0505e?;01JC2T0EdTV05Y::01OCbd00P1UDS401P1SD2l0HE4_05i>;01JBRP0EDDS0592
80<0D40N00@0EDHU05A5901DAB@0E4DT0P1CA2<205938P0405528@1@@RL0Cd4V04do9080BcdR00T0
C3hS04do901>@2D0B3`R04Lk8@16?240@c`P048m8010?1l00P0n?Al303hj7`<0?CTN0P0l>1d0200o
=A`0?SLM03lh7P0o>Al0?SXO03/j7P0h>1`0=cLK0P0f>280100e=b40=3HP03<e7`0b=1h2034c7@03
02hb6`0_<a`0<3@M0080<CDN00<0;c<L02hb6`0/<1T0100]<1/402`_6P0802T/6@0Z;AX0:bhM02/]
7`0Z;1l0:2XO02HX7@0U9Qh202@W7P0402<V7@0R9A`08B@K020S6P807b8I0P0M91`00`0L8a/06b8J
01XQ6@0201TP600401PO5`0H7QX061hJ01PN6P805adI0`0F71P801TK62005aTH200F61L801LI60@0
5ALF0P0F61L301LI60P05QPG2`0G6AP301HH5`D05ALF0P0F61L601LI60805QPG0`0E5aHH01HH5`P0
5AHH200F61LP01DF60P05QPG200F5aT801HH5`P05aTH2@0H6QT201LI608061XI0P0I6aXJ01XL6`P0
71`J0P0L7AL301dN60H07QlI0P0M7QP501`M5`<07AhH1P0N7aT301lP6P80824K200Q8AT8028R6P08
02@P5`0U8AP09R8I02LS6P0X91/0:BDL02XV7@0[9ah302TU6@80:RHJ0`0[9a/802hX7080;2HJ0`0]
9a/302hX70<0;BLK0`0/9QX202/U6@P0:BDL0P0Z8a/402/T7080;2DM0P0/9QX402dW6`<0;RPL200/
9Ad202`X7`80:bLN00L0:RHM02TU700X91/09b<J02`U7@0]9Qh0;RLO0080;bPP00@0;RLO02dV7P0/
9Ad0;2HJ100]9a/402hX7005030X6`0a:A`0<bXK03L[6`0i;1/00P0l;AX01P0k;Q/0?2lL03d`7@0o
<Ql0@3<P044d8@80@cHS1012<B402P13<R80A3<S04@c8`15=2@0@cHU04<f8`15=R<0AcHR04Tg8@1<
>20204hh800305Di8`1F>R@0F3`V00<0FShX00<0FCdW05Pl9P1J?b@00P1J?b@205To900305Pn8`1G
?b<0EclS00P0EShV00<0E3`T05Dm9@1E?BD0101E?BD02@1D?2@0E3TL05@i701D>Ql0Dc/Q054k8`1A
?BD0DC`W04lm9`0204`j8P80BcTQ0P1:>20204Tg7`0404Tg8@1;>B<0C3XT04Tg8@80AS@N00X0BSPR
04hl9P1<>A/0CSXO054m8P1C?bH0DShV04lj9@1:=B80Ac8O1017=b0404Hf7`D0A3@M0P15=Ah01016
=Ql0AS@L04Le7@17=Ad204Pf7P<0BCLO00<0BSPP04Hf7`16=Ql01P16=Ql304Hf7@80AcLN0`18>1l2
04Tg7`80BSPP0P1;>B4204`j8P<0BSHN0P1;=al204`h800704di8@1D>R<0Dc/S058j8P1?>B40CCTP
04/j800204Ti7`0304Ti8P18>240ASHO00<0A3@M00<0ACDN04Hf7`18=bD01`18=bD804@d7@80A3LT
00<0@cHS048e8P11=2400P10<b000`0o<Ql0AC@R04Dd8P0304He8`<0AcHT00P0@cHU048e9011=2<0
@3<R03ha800m<1l0?2lN03/^7@80>RhP00@0>blO03/`7P0l<Al0?34M0P0m<Q`203db80@0?34O0P0k
<1h803H]700803T`7`0j<B00?34O03ha7P11<Qd0@c<L04@d7@15<a/2044e7@80@SHN0P13=al204@h
800904@h8P13=b40ACHO04Hf7@19>1h0Cc/P05@o901G@RD0DcdU0080DS`T00<0DC/S050j8P1?>B40
0P1>>20A04hj8@0504dh8`1;=R40AcDO04@d7@12<a`00P10=1`00`10=Qd0@3<P040c8006040c80P0
@S<P2014=B80200l=1l0?CDP040e8@12=B80ACHS04He8`17=R@0B3DT1018>24204Ti8P80BSXS0P1:
>Al00`1;>R00C3/Q04dl8P0204hm8`0304ln901B?RD0DShU00H0DShU0`1@@2L[ooooo`00:_ooool2
0:9hAP030:=iA`2TNTP0Y7Y800<0Y7Y80`2RNDD20:=jAP<0Y7]7202WO4L80:ImA`<0YWe90`2WOTX2
0:QoB`030:UoC@2XOT`0YWa:0080YG]900<0YWa:0:QnC02YOdd00`2YP4`00`2XOd/0Ygi:0:MnBP04
0:ImB@040:MnBP2XOd/0Z7m;0:V0C080ZX5=00<0XWU50:=jAP2UO4P00P2WOTX00`2VODT0YGa80:Ak
A`030:MnB0<0Z7m90`2YP4X01P2WQ4h0Yh9=0:N2C@2XP4`0ZH1<0:UnB`80Zge;00H0[HA@0:b3C`2[
PTh0ZX5=0:V0C02WOTX20:ImB@80ZGm=0P2ZP4h20:^1C`80[89@00<0ZX1>0:UoC@2YOdd0102YOdd0
102ZP4h0Ygi:0:V0C02ZPDd20:^2CP030:Z1C@2YP4`0Ygi:0080X7]700<0WgY609iiA@2NNDD00`2N
NDD0102QMTT0X7E809icAP2LLD@209]`@`80W7540P2FLCd00`2EL3`0U6lk09=^>P02099]>@07095/
>02?Jc/0SVXj08eY>@2<J3P0RfLg08UU=@0208QT=00508IU<P25I340Q68b08=Q<`22H3<00P21GS@0
1021GSH0PUdc081K<@1nFBl307aG;@80OEP^0`1eDbd307AB;080Le4[101^D2`206e?:`80K4hZ00<0
KU0/06e?:`1/CRX00P1[CBT04@1]Cb/0Ke4]071B;P1aDBP0LU8Y07=C:P1dE2/0MUH]07MG;P1hF2l0
NET`07aI<`1mFS@0OU/c07mL<P21Gc80PV0b0080Pf4a0`27HC@208QR=@<0RF<f00@0R68c08US=02:
I3D0RfDf0P2<ISL208eW>0D0SfTj102@JS/0202AJc`0T6Xk08iX>@2=IcP0S6Hg08eW>02>J3T0SfTj
1P2@ICP2095V>@03099W>P2@ICP0Sf@g00<0SF8e00D0SV<f08mT=`2@IS@0SfDc08iT<P0208aR<00;
08eS<@2?IC<0T6Hd091Z?@2?JC`0SFLj08aV>@2;ICP0S6Hi08eW>P2>J3/0202?I3L3091Z>`80SfTj
0`2>J3T408]U=P@0RV@e102:I3L408US=P80QV0a00<0Qf4b08QR<`29Hc@00P2:I3D00`2;ICH0QF0c
08EP<`0608EP<`80Q5lb1P25H3<208EO<P0308AO<P22H380PF4b0080P64b00T0OV8b081N;P20GRh0
Oed_07iL;`1mFS00O5Ta07aI<`1kF3800P1jEbl0101iERh0N5D]07MD;01fDb/207EB:P80MeL`00P0
MUH_07AD;@1bDR/0LE4Z071@:@1_CbP0K50[06eA;0<0KU8]00T0K50[06Y>:@1YCBP0HddT06==9P1Q
BbH0H4XU05i79@1LABD00P1KA2D01P1C@b80DT8Q05508P1@?b<0CSdS04hl90<0CC/U00P0BC/P04Pj
7`15>Al0@cTP03lg800l=R00>cDO03Xe8@80=cLO00H0=SDP03Dd800d<b40<c4R038`8@0b<2<202`/
8P0302/[8@0Z:R00:BTO0080:2PN00@09bLM02LY7P0W:Ah09bTN0`0V:1d202DW70<08R<M0P0Q8Q`3
020Q6`P07R0M0P0L7aP301dP6@<07R4J00<08B<P020R7`0N81d00`0L7Q/0100M7a`07R0M01dP6@0M
81T201hQ6P807b8K0P0P8a`2028S6`0302<T700T9Ad09BHN00809RLO01409bPP02/W700/:1d0;BTM
02h[700_;1/0<BhK038_700b<1/0<C8T030a8`0_<280;BhP02//7P0X:A/09RLI02DV600302PX7P80
9bLM0`0V9Q`302LW7`809RHN0`0U9Ad3028S7@<08B8L0P0P8A/6024R70808R<M01L061hD01XP5P0O
8QT08b@L02@U7@0T91`0924J028O600W9AT0:RHJ030X6`0f;Ah0?C0O04Dd8P19=b<0CCPS05Lm8P1I
?R40GD<R06I:9@1aE2`0OUlc08UY>P0208m_?P0@09Ie?`2KNTD0Xgm=0:N1E02TNU@0VVe<08eP@@25
ESX0CCX/04Le9`0n;B<0=2LO02dU8P0[9bH0;2X[02h^<0P0:B`Q1P0[;2@202X[8`0602h^9P0^;R@0
;blU02l_8`0`<B<0<34Q0P0a<R00100e=B/0=3@Z034a9`0_;bD302d]8`0902h^900^<280;S0R034b
8P0d<b40=c@Q03/f8P0l=b<0?SPR0080Ac`X00<0B3dY04Tn:P1:?b/00`1:?b/205109`040551:01B
@RT0Dd<Z05A4:`80EDD/0`1HA2T03@1IABX0FTH[05a8;@1MBBh0GTX_05Y79`1KB2P0GDXZ061=;@1R
Cbl0I54a06EB<P1VDc<00P1VCBh00`1UCRh0Hdl^069?;P02061@;P0/05mA;P1KCC<0Fd/b05]:<01I
B2`0FdPZ05e8:@1PBBX0HDXZ06M@;P1YDBd0K58_06mE<01eFC80NE`d07eM=01oGcH0RVTf08i]>02C
LSd0VWLo09ej@02NNSh0W7Pj09]h>02ILSL0UG4e08m/<P2<JC40RFPb08UZ<`2;KCL0S6hh08MU=@25
IC@0Pf<d07mP<P1jGC40MEX]075I;@1_Eb/0MeLa07EE;`1bDR`2071@:P07079B;01dE2h0MUH`06m>
8`1aD2D0Le8W07ED:@0207IE:P0907ED:@1dDbP0OEL`07eG<01oFS00PE`b08=N<P24Gc80Q60`0080
Q60^00P0RF<T08YT9@2=IbP0T6XY09A^;@2HLS40VWDa09ag<`80VG8g00H0Vg@i09ae>P2NMc`0X7Tn
0:5j?`2RNd0309Yj?`80Vg]00`2JNSl03P2KLSh0W7<o09ad@02KMT40W7U309akA@2LODH0WGi709Yi
@`2IN480V7M109Ie?`2DLcd0TW4k0P2@KcT0202CLS`0UG@n09Qg@@2IN480V7M109Ac?@2?KSP0RfXd
0P2>KS40102>KS<0SVhe08m^>02?KST208m^>`@0RV`j00@0RF/i08QZ>027JCL0QVPf0P2?L3L0102?
KcH0TFhf099]=P2DKCH209A[=@80TW8i00<0Tg<j09Ad>`2DM3/00`2EMC`0102=L3P0S6lg08Y]=@29
K3@308Q[<`0308U/=029JCH0RFTf0080RVXg00@0Rf/h08a/>@2=KCX0SFdj2020IS<0401oI3L0OV<f
07aQ=01iGS40Me`_07AI;01bEbX0LEHY06mF;P1/EB`0Je<]06MA;01SCb`0HDh]05i>;@1MCB`205];
:@0405a<:P1MCB/0GTh/05m?;@80H50^0100HDl[05i<:01KBBD0Fd/W061@;01RE2l0HE<^05mA;01K
BbX0F4PW05A48`1A@B00D40O0551801C@b80E4@S101CA2<305938P80DD8Q00P0CD8V04a19@1:?b<0
BChR04Pm8@19?R80BSlS04]09080Ac/Q00@0AS`Q04@m8@12?B00@CdP0P0n?Al303hj7`0303di7P0l
>1d0?3PM0080>cLL00P0@3HM03lh7P10>Al0?cTO03hj7`0j>Ad0=cLK03Hf6P80=SPR00@0=CLQ03@f
800c=Al0<S@N0P0a<ad0200^<Q/0;c<L030d7@0a=Ah0<3@M02hb6`0/<1T0:blH200/;aX0200Y;1T0
:RdJ02/^7@0[;Al0:B/N02LY7P0U9a`092DM0P0S9Qd0100R9A`08B@K024T6`0P8aX201lR6@0601dT
700L8a/072<K01/R6P0J8AT06B0H0P0H7aL201PN6P805adI0P0F71P201DK5`P06A/H800G6AP801HH
5`P05aTH100E5aH201HH5`<05aTH200F61L:01LI60<05QPG1P0E5aH201HH5`H05aTH0P0F61L301DG
5QP05QPG200E5QP801HH5b005AHH200F61L801HG6@P05QPG4`0G6AP201PJ6@806A/J6P0J71/801`L
6P8071dG0`0M7QP301hO6@807b0J0P0N7aT201dN60@071dG0`0M7QP301hO6@807AhH0`0N7aT301lP
6PP08B4I200R8QX0200T81L09B4H02HR6@0W8aX0:2@K02TU700Z9Qd0:bLN0`0Y9AT202XV6P<0:bLK
200]9a/202`V6P<0;BLK0`0^:1`202dV70<0;2DK0`0[91X802TU7080:B8J0P0Z8a/202/T7080;2DM
0P0/9QX402dW6`<0;RPL200/9Ad0100]:B00;2PO02/W7P0Z9Qd202TU7080:2@K00<0:b@L02`U7@0^
9al00P0_:2000`0^9al0;2DM02/T700302`V6P0302dW6`0^:1`0;RPL00<0;bTM00D0<BTL038Z7@0d
:a`0=b/K03X]700203d^6`0603`_700m<1d0?S4N03lb7`10<b00@C@Q0P12=B801011<200@S4Q048a
8@13<R8404@c8`0@04@d9015=R<0AcHT04Tg8`1<=b80CSPQ050h801A>B40E3XS05Dk901G?BH0F3hW
05To:01H?RL0EcdV05Hl9@80ECdS0`1G?B@305Pl90P0ECdU0`1D?2@205<k8`<0E3`T0P1D>A`01P1C
>Ah0Dc/Q054k8`1@?2@0DC`W04lm9`<0BcTQ0P1:>20304Tg7`0404Pf801:>280BcTS04Tg8@80AC<M
00X0BCLQ04dk9@1;>1X0CCTN050l8@1B?RD0DCdU04hi9019=240AS4N0P15=R4204@e8080@c@O0P12
<ah01012<Q/0@c<L04@d7@14=1d404De7P@0AcDM1@18=Qh804@e8080ACDL0P16=Qd204Lg7P80B3PO
0`19=al204Xh80<0BcTQ00<0BCDM04Xf7P1:=Qh00P1;=al304`h800605<i8P1B>R80DCTQ04li8@1=
>B00BSTO0P18>1h00`18>240ASHO04De7P0204<c700304@d7@15=Ah0ASHO00P0AcHT2014=1d204<f
8`04048e8P11=240@3<P040c8080?c8O0`14<b4304Dd8P80ASDS0P12=B@01011=2<0?c8Q03ha800l
;ah203/^7@80>RhP00@0>RhN03/`7P0k<1h0?34M0P0l<A/203`a7`80>c0N0P0j;ad203T^70P0=B`M
00P0>C0O03Xa800l<Al0?S4N044b7@13<a`0A3@M04Dc6`80@CDM0P12=Qh204<g7`80A3PP00T0AcPS
04Hg8P16=Ql0B3HN04`h7`1A?240EclU05Y29P1A?B@00P1@?2<00`1?>b80CSXQ04di800204`h7`T0
CSXQ201=>B40201:=B00BC@O04Dc7@12<Q/0@34J03lc6`10=1`0?cDL4010<b08044d8@80?3@O00H0
?S<O040c8013=240AC@R04He8`17=2<204Df8@80ASLR1017>2<01P18=Qh0BCLO04Tg7`1:>200BcTQ
04`j8P80CC/S201A?B@304do9B_ooooo000Zooooo`030:1fA02QMdD0XWQ600<0Y7Y800<0XgU70:9h
AP2RNDD00P2RNDD20:=jAP<0Y7]7202WO4T;0:ImB@<0Ygi:0P2XOd/00`2YOdd0Z7i<0:MmB`020:Il
BP040:MmB`2XOT`0ZGm=0:Z1C@80ZH1<00<0Z7m;0:MnBP2VODT00P2UO4P30:MnBP80Z7m;0`2YP4`0
0`2SNTH0Y7]70:ImB@020:QoB`030:MnBP2VODT0YGa800<0Ygi80`2XOdT30:V0BP060:R5C`2XPdh0
YX5<0:MoB`2XOd/0ZGi;0P2/OT`20:^2CP80ZX5=00@0ZH1<0:QoB`2WOTX0Ygi:0P2YOdd20:Z0CP80
Zh5?0P2/PU000`2[PDl0ZX1>0:UoC@020:QnC0060:UoC@2ZP4h0Zh5?0:MnBP2YP4`0ZX5=0P2[PTh0
202ZPDd0ZH1<0:MnBP2RODT0XGa80:1kA`2ONTH0WWU50P2ONTH01@2PNdL0XWM:0:1eB02NLdH0W754
0080Vg1300<0W75409ebA@2GLSh00P2FLCd00`2EL3`0U6lk09=^>P02099]>@80Sf/k00/0SVXj08aX
>02;IcL0RVHf08UU=@28I3@0QfHc08IU<P24HS80Pf4c089P<`02089O=@04089O=`22GC<0PE`b07mJ
<0<0OEP^00@0OUT_07mJ<01gE2h0Me@^0P1fDbd307EB;00;07AA:`1]Cb/0KU0/06i@;01_DBd0KU0/
06e?:`1/CRX0JddY06e?:`1/CRX00`1[CBT0501]Cb/0KU0/071B;P1`D2L0LE4X079B:@1cDbX0MED/
07IF;@1gEbh0N5P_07]H<P1lFC<0OEXb07iK<@20GS40PEla089P<023HC40QV0c0`27HC@208QR=@80
RF<f00<0Qf4b08QR<`2:I3D00P2<ISL00`2=IcP0S6Hg08aV=`0408iX>@<0SfTj0P2@JS/00`2AJc`0
T6Xk08iX>@0308aV=`80SVPi0P2?I3L3091U>0<0TFHi00/0TfPk099W>P2@ICP0Sf@g08iS=P2?I3L0
T6Dh095V>@2BJ3H0T6Hd08mU<`0308eS<@0:08mU<`2@IS@0T6Xk08mY>P2=IcP0S6Hg08]U=P2<ISL0
SFLh08iX>@P0SV<f0`2?JCX208iX>@<0SFLh0`2;ICH208YT=@<0RF<d102:I3L408US=P80Qf4b0`28
HS<308US=0P0QF4a0`24Gc8308EP<`80QV4d0P24GS400`23GS40PEla081P<@0207mP<@0907eQ<@20
GRh0P5h^07mM;`1nG2l0OEX`07aI<@1lFC<0NePb0080NUL_00@0NEH^07QE;@1gE2`0MU<[0P1eDRX2
07QH<@0607IF;`1eEBh0Le</075A:P1`D2T0KdlX0P1]DB`01P1^DRd0Ke<^06iB;@1/D2/0JThY06Q<
9`80IDhU00@0Hd/U069:9P1QBBD0GdLU0P1NABH01P1EAB@0Dd<R05508P1??R80CSdS04dk8`80CC/U
00T0CS`V04Xl8@19>b00ASXP04<i800o=b00?CLQ03/e7`0i=2000P0e=al01`0d=R00<cDP038c8@0b
<b<0<C8R034b900];B<00P0/;2800`0[:b40:RXP02TY7`0202PX7P80:2XO0P0W:Ah302HX7@0402DW
700R8ad08R<M028S7@808B8L0`0P8A/801hP7@<071lH0P0M81T301hQ6P04028T8@0Q8b007b4N01dO
708071hK00<07AlL01hP7@0M81T00P0M81T201hQ6P<07b8K0P0Q8Q`00`0R8ad08b@N02@U7`0202DV
800902HW8@0[9a`0:bLL02`X700^:a`0;b`K030]6P0a;Q/0<S0K00<0<34Q00D0;c0P02d^7P0[;1`0
:2TI02LX600302PX7P809bLM0`0V9Q`0100X:2009bLO02LW7`0W9al202HV7P809BDM0P0S91h2028S
7@<08B8L00<0824K024R700Q8Q`00P0Q8Q`2028S7@808b@N00<06b4G01`R600P8aX00P0R8a/04P0S
8a/0924J02@Q6P0T91P09BDI02/W6`0a:A`0=B`M03/^7P11;b40@S4Q054f8@1C=b40ES/P05e0801W
BBD0Le<Z07eL;`80Pf<d0100SFli095c?@2GMd@0W7]80:1lC02OND`0WG=909]aA`1/DCH0HdT`058n
9P13<R00=b/M038[8@0a;RL0<S4/200Z;B8402//9080:R/S0P0Y:R801P0];BD0;BdS02h^900_;b<0
<34S030a8@80<C8P00@0=CD[03<c:@0a<BL0;blU0P0];B<202h^9080;C4S00X0;c4S038c8`0e=280
>3DR03Tf8`0k=R80@cPV04@i9`16>bT0Ac`Z0`18?B/01`17?2X0CclV04lo9P1@@2L0DD4X0592:@1C
@bX00P1DA2/205Q7;@0405I5:`1EA2X0ED@Z05I5:`80EdH/00D0FDHV05]8:01MBRX0Gd`/065>;P03
069?;`80Idd/0340ITh/06I?;@1TD2d0He4]06AB;P1RDRh0G4df05]<=@1JBS40FTT_05Y9;@1LBB/0
GdX[061;;01QCB`0HTh]06M@;P1[Dbl0KeDb07AH<`1gFc@0NE/e08AU=P28J3L0SF`g099a>`2IMC/0
W7Pj0:1j>@2QNST0X7Xk09af=`2ELC<0Sfd`08eZ<02<K3<0SVlf091a>P2;IcD0R6Ld08MU=@24I3D0
P64c07YM<@1eFRd0M5T^07EG<`1cEC40LE<_0080Ke4]00H0L58^079D<01cEC40K4lW06iA:@1aE2`2
07=F;P03075D;01_DRX0KE0X0080Me<_00@0N5@`07UF<01kF300O5T_0P1lFRd0501mFbd0PeTW08EL
:028GbT0Rf8Z091X;@2CJbh0UVha09Q`<P2FKS40Uflb09Q`<`2ILC@0Vg<f09ad=`2MMCP0WWHi09If
>@2GMcX0V7Pk0P2INC`0702HN3/0UgLj09If>@2LLC`0W7<m09ed?P2NMd00WGQ109ik@`2MOD@0WWi5
09Yj@@2IND00V7Po09Mg?P2EMC`0Tg<j099b>@2ALCP0UG8l09Md?P2HMCl0VGI009Qe?`2ELS`0TFhh
08m/=P2@LC42091`<`0308m_=02?KcH0Sfhh0080Sfhi102:KS`01028K3X0QVXh08AX=P23IcD208e]
=008091]=@2AK3D0U6df09E/=P2FKCL0Uf`g09Aa>@2ELSX309Ic>`0409Aa>@2CL3P0TVlg08U[=@80
R6Xd1@27JC<308MY=`80R6Xh0`29JcT207mU=080OV@c0P1mHc8207aR<@0A07YN=P1iGCD0N5`d07IJ
<P1cEbl0LED]071D;01_Db/0JU8/06QB:`1VD2/0HTh[05m<:`1LC2/0Fd`[05]<;@1NC2P00P1OCBT0
0`1PCRX0HDl[069@;002069@;00406A>:@1PC2L0GT`V065?:@80HU@]00D0GU8Z05Q?9P1FAbP0E4DV
0593900205118P0305528`1CA2D0E4DV00T0D44P0140BT4T04U08`17?R40ASdP04Dl7`16?B00AchQ
04Po8P16>R00Ac/Q04Hl8@15?R80@chQ044m800n?Al0?C`N040l8@0203lk800303hj7`0m>Ah0?3PM
0080>cLL00P0@CLN03lh7P10>Al0@3XP03hj7`0j>Ad0=cLK03De6@80=SPR00@0=CLQ03@f800c=Al0
<S@N0P0a<ad202lc7080<3@M00D0;c<L02hb6`0[;aP0:RhG02X]600302/^6@<0;2lJ00T0;C0K02X]
6P0Z;AX0:bhM02X/7P0Y:ah09bTN02@V6`0S91`00P0S9Qd00`0R9A`08B@K020S6P0201lR6@0601hQ
600L8a/072<K01/R6P0J8AT06B0H0P0H7aL0100G7QH05adI01LM6@0G7AT201HL60<05A/G200I6aPP
01LI60P05QPG200G6AP401DG5P805QPG0`0G6AP801HH5`T05aTH0`0F61L201DG5P8051HE0`0E5aH2
01HH5`H05aTH0P0F61L301DG5QP05QPG200E5QP801HH5b005AHH200F61L801HG6@P05QPG4`0G6AP2
01PJ6@806A/J6P0J71/801`L6P8071dG0`0M7QP301hO6@<07b0J0P0N7aT301dN608071dG0`0M7QP3
01hO6@<07AhH0P0N7aT301lP6PP0820H200Q8AT01@0U8AP09R8I02HR6@0W8aX0:2@K0080:BDL00@0
:RHM02TU6@0Y9AT0:BDI0P0Z9QX302/W6`P0;BLK00<0;RPL02dW6`0]9a/01@0]9a/0100]9Qh0;2DM
02`U7@0/9Ad202/T7080:R<K200X91/202PQ6@0402TR6P0Z8a/0:b@L02/T7080;2DM0P0/9QX402dW
6`<0;RPL200[91`00`0/:1l0:bLN02XV7@0302TU7080:RHM00<0:b@L02`U7@0]9Qh00P0^9al00`0]
9Qh0;2DM02/T700202/U6@0302`V6P0]9a/0;RPL0080;bTM0P0`:Qh01@0b:Qd0<b/N03D/7@0h;1`0
>bhM0080?RlL0P0m<1d303ha7P<0?c8O0P11<2000`13<R80A3<S04Dd900204@c8`0<04<b8P14<b<0
AC@R04Pe901<=b@0CcTT054h8P1A>B40DSPQ058j8P1C>b<0ECdU0P1F?RH00`1E?BD0E3`T05<k8`02
054k8`0305<k8`1E>b@0ESXT0080FCXU00<0FSXU05<k8`1C>b<00`1D?2@305Dm9@0305@l901C>b<0
DSXR00<0DSXR00X0Dc/S05@l901E>Qd0ECXM05<i7P1B>R00D3XR04lk8`1?>RD0CC/U0P1:>R4204Ti
80<0B3PO00D0AcLN04Le7`19=b40BSPR04Pf800204@b700:04Pf801<>R@0C3TK04di7P1?>b00D3`S
04lk8`1<=b80BC@Q04Lb7`80@SDR00<0@C@Q040c800o<Ql00P0n<Ah01@0m<1d0@C4J048b6`13<a`0
ACDN00<0ASHO00<0ACDN04Le7@17=Ad01`17=Ad8044d8@<0ACDL0P16=Qd304Lg7P0404Pf7P19=al0
BCLO04Tg7`80BSPP0P1;>B401018=1`0BCDM04Xf7P1;=al204`h800304/g7`1:=Qh0DcTR0080DCTQ
00<0CSPP04`h7`19>1h00P17=ad00`16=Ql0ACDN04<c7002048b6`0304<c7015=Ah0ASHO00P0ASDS
2014=1d2044d8@<0@3<P0`0o<Ql2048a7`80@c8P0`14<b403`15=280@SDU044d9010<b<0?c8R03d`
800l;al0>bhN03X]7@0i;Al0>RhP03X^7P0j;ad0>c0N03/`700203`a6`80>blO0P0j;Qh0100i;Ad0
>2`L03L[6`0g:a/803D[7`0803T`7`0j<B00?34O03ha7P11<Qd0@c<L04@d7@15<a/2044e7@80@SHN
0P13=al204@h8080B3LS00L0BCLQ04`h801?>B40Dc/Q05Hn901H?R<0CSdS0080CC`R00<0C3/Q04/j
801:>Al00P19>1h904hj8@P0C3LR00P0B3<N04Lb7@13<A/0@C4J03l`6@0n<QX0?c<K03le70P0?c8O
400n<al203`d7`0603db7P0n<Ah0@34N048a7`14<b40AC8Q0`12=B8204<f8`<0A3LT0P16=Ql00`17
=b00B3PQ04Ti8P0204Xj8`0304/k901@?2<0D3`S00H0D3`S0`19?B<[ooooo`00:_ooool00`2NM480
WgE30:5gA@020:=iA`030:9hAP2QMdD0X7I400<0XWU50P2SNTH30:AkA`P0Yg]:202VO4X30:ImB@<0
Ygi:0P2XOd/00`2ZP4h0ZGm=0:MmB`020:IlBP040:MmB`2YOdd0ZX1>0:Z1C@80ZH1<00D0Z7m;0:Im
B@2UO4P0YGa80:AkA`030:V0C080Z7m;0`2WOTX0202TNdL0YWe90:QoB`2YP4`0ZX5=0:V0C02XOd/0
Ygi:0`2WOTP30:QoB@<0ZH1:00T0Z8E?0:R3CP2VPD`0Ygm;0:MnBP2YOT/0[7i<0:eoC@2ZPDd01`2Y
P4`20:UoC@80ZX1>0P2[PDl20:b2D0030:^1C`2ZP4h0Z7i<0080Yge;00H0Z7i<0:Z0CP2[PDl0Ygi:
0:V0C02ZPDd20:^2CP060:Z1C@2YP4`0Ygi:0:F0C02TOd/0XWe90`2PNdL20:9mB@030:9gBP2QMTT0
WW=600@0W75400L0WG9509Mb?P2GLSh0UW4m09E`?02DKc/0Tfhj0080TVdi01P0T6`l08m[>`2>JSX0
SFTi08]W=`2:ISH0RFDe08QT=028Ic@0QfHc08AR<P22H380PElb089O=@23H3H0Pf0h089M<@21G300
OeX^07iI;@1mF2`0OUT]07mJ;P20Fbl307MD;P80MU<]0`1eDR`206e?:`<0Ke4]00/0KDl[06]=:@1Z
C2P0KDl[06a>:P1[CBT0JT`X06]=:@1/CRX0KU0/06mA;@02071@9`04075A:01cDbX0M5@[07IF;@80
MeL^0P1kF3801P1lFC40OEX`07mM<020GS00PEl_089P<080QV0c0`27HC@308QR=@0408IP<@28HS<0
RV@e08aV=`80SFLh00@0S6Hg08]U=P2<ISL0S6Hg0P2=IcP308iX>@80SfTj00P0T6Xk08mY>P2=IcP0
S6Hg08]U=P2<ISL0SFLh08iX>@<0Sf@g00<0T6Dh095V>@2AIST00P2BIcX00`2EJSd0U6Tl099W>P02
091U>006095V>@2BIcX0TfPk09=Y=`2BJ3H0T6Hd0`2>I3802P2?IC<0T6Hd091Z>@2?JCP0SFLf08aV
=@2;IC@0S6He08eW=P2>J3L808iS=P80SVPi0P2=IcP208aV=`D0RfDf00<0RV@e08US=029Hc@00P28
HS<408US=P@0RV@g0`29Hc@308QR<`80Qf4b2026HS0208=N<@80Q5lb00@0QF0c08IQ=026HC@0QV4d
0P23GC000`22GC00P5h`07mO<00207iO<00907aP<020GRh0P5h^07mM;`1nG2l0OEX`07aI<@1lFC<0
NePb0080NUL_00@0NEH^07QE;@1gE2`0MU<[0P1eDRX207UI<P0807MG<01eEBh0Le</075A:P1`D2T0
KdlX06eA;01^DRd206mC;P0B06eA;01[CbX0JDdX06Q<9`1WCRD0ITdT06E<901TBRD0HdTV06989`1Q
AbH0H4DW05I69@1EAB@0DT4S04ln8P1>?B<0CC/S0`1>?2H0401;?B80BS`Q04Lk8@14>R40?cLP03dg
8@0k=Al0>C@P03Hh800e=al0=CLQ03@f8@0c=280<S<S034b8P0a<R@202d]8`0402`/8P0[:b40:RXP
02TY7`80:2PN0`0X:Ql202LY7P<09RPM0`0R8ad2024R70<0824K200N81d201/N5`8071lH0`0M81T0
1@0N8AX08bDR028T8@0O8Ah07AlL008071hK0P0M7a`401dP6@807R4J0P0O8Q/01P0P8A`08B8M024R
7@0R8ah08b@O02@U80809BHQ00P0:RHK02/W700/:1`0;BXK02l/6`0`;AX0<BhK038`6`80;c0N0P0`
<Al0100_<1h0;BhL02//6P0Y:QP302PX7P809bLM0`0V9Q`202PX80<09bLO0`0V9Qh302<T7P808R<M
0`0Q8Q`00`0P8A/08B8L024R7002028S7@808b@N00@092DO01lU6`0O9A/082<J0P0Q8QX04P0S8a/0
9R<L02LT7@0R9QP092HI02HV6P0[9a/0<2PM03DX7`0h:Ql0>RTO04da8`1?<R80DCDO05Pj7P1P@R00
JTXQ079A9080MUHW00H0PfXb08I]=@2;LSX0TWM009MlA@2IOdH209Z0A`0809=cC025Id40KUHd05M4
9P15=ad0>38L03Db8@0e<b@802/_8@0302`]9@0[;2@0:b`T0080:R/S0P0Y:R80300X:B40;2`T02`/
8P0];B<0;RhR02l`8P0`<B40<C8P038c8@0c<bT0<S8X030`9P<0;RhT00h0;blU030`9P0[<BD0;S8T
02lc9@0a<bD0<c@T03He8`0h=B80>CHS03lc8`11=BD0@cLW04Di:@<0ASXZ00@0ACTY04hn9@1>?RD0
CclV0P1@@2L01P1A@BP0DT8Y0592:@1FAR`0EDD[05=3:@80DT8X00L0Dd<Y05E5:`1FAR`0FDHV05Y7
9`1LBBT0Gd`/0080H4d]00<0Gd`/05i;:`1YC2`00P1WCB`09@1WCbd0Ie0^06IB;`1UDbl0IU@`05Y>
>01ICCD0FT/d05Y:<@1KBS00GTX_061=;`1RCC00FdX/05m<;01QCRh0IE4`06YC<@1_Ec<0LUPc07=I
=020I3D0Pf@e08IV<`2;JS@0Tflc09]e=P2QNSL0YGdh0:N0?@2RNcX0VgDd09=`<02?KBh0SFd`091`
=@2ALcL00P2;Ic<02P29J3D0QVHe08=T=@1oH380NEd^07MJ;P1dF3<0LeLb079F<@1aEC04071D;`03
06eA;01_Dbh0LUHa0080LeLb00<0L5@_06eA;01ZCRT00`1cDS403P1cDRl0M5@^07EE;P1eEBh0MUH]
07MG;P1nDRd0Oe</089G;@26Fc00RV0`08eS<@2@Ic<0TVTc0P2CJbd0102DK2h0UFd_09M_<@2HL382
09Ua<`03099b=@2CLcH0UGDh0080UWHi00<0UGDh09=c=P2BLSD00P2MLS/01P2MM3`0WWDm09mh?`2N
NT00WW]109ml@P80VGTn00H0V7Pm09Mg?02FMS/0UGDj09Ad>@2CLcP409Ia?00409E`>`2DKcX0Tfhi
09=^>@80TW<c00H0TG4d091`<`2@L3D0Sflf08m^>02>KCL208Y`?@0?08]a?P2:L3d0R6hk08I/>@23
JCH0PFLd08aY<@2=JS80SfXc099[=02EK3H0UVdg09Q]>02IKST0UW4j00<0Ug8k00@0UG0i099]=P2@
Jc@0SVTb0`25Ic<508IX=00408QZ>027JCL0QfTg08MY=`@0QVPf00H0OFDe07aT=01kHc<0NV8b07UQ
<@1gGbl207IN;P0607IJ=@1eFC@0M5Pc07=G<P1aEC00L5@_0P1^DRd0201WDB`0IDlZ065=:P1NBbX0
Fd/Z05Y;:P1JBb`0FTd]0P1QCBX4069>:`80Hdl/00d0I4`V06==9P1RCbL0IE<[06EH;P1RER`0FE0U
055:7P1FB2/0EDLZ05=5:01A@bH0D48U0080Cd4T00<0CT0S04ho7P1>?ah01`1>?ah00`16?b80AChQ
04<l7`02044j7@03048k7P13?1l0A3dP0080ASXP00H0AcdR04Dn8P14?b80@CdP03dl7P0l>ad2044m
8P04040l8@0o>b00?SXO03di7P80?3PM00P0@CLN040i7`11>R00@3XP03di7P0i>1`0=SHJ03De6@80
=SPR00@0=CLQ03@f800c=Al0<S@N0P0a<ad202lc7080<3@M00@0;c<L02da6P0[;aP0:BdF0`0Z;AP0
0`0[;QT0;2lJ02`_6P0202d`6`80:RdJ00L0:bhM02X/7P0X:Qd09RPM02<U6P0R8a/08bHM00808RDL
00<08B@K020S6P0O8QT00P0N8AP201`S6`0401/R6P0J8AT06B0H01PO5`805ahF0P0G7AT201HL60@0
5A/G200I6aPP01LI60P05QPG200G6AP401DG5P805QPG0`0G6AP801HH5`P05aTH0`0F61L201DG5P<0
51HE0`0E5aH201HH5`H05aTH0P0F61L301DG5QP05QPG200E5QP801HH5b005AHH200F61L801HG6@P0
5QPG200G6AP901HH5`805aTH0P0H6QT201TK6QX06Q`K200L71X201`M5`<07AhH0`0N7aT401lP6P80
7QlI0P0M7QP201`M5`<07AhH0`0N7aT201`M5`807AhH0`0N7aT00`0O81X0820H020P6006020P60P0
8B4I100W8aX402PT6`<0:BDI0P0Z9QX302/W6`P0;2HJ0P0_:Ad202hX700402dW6`0/9QX0:bDI02/U
6@<0;2DM0P0[91`302XS6`P0:2@K0P0W81P01P0X8AT0:B8J02XS6`0[91`0;2DM02dV7P80;2HJ100]
9a/302hX70P0:b@L00<0:bLN02XV7@0Y9A`00P0X91/01P0Z9Qd0;2PO02dY800Z8a/0:b@L02dV7P80
;RLO00T0;BHN02/T700Z8a/0:R@H02/U6@0/9QX0;BLK02hX700_:Ad00P0`:Qh0200a:al0<RXM03<[
7P0f;Ah0>BdM03/^7@0n;a`0?c0M0`0n<Ah0200m<1d0?2lL03`_700l;a`0>bhK040_7`11<200@c8R
0P15=2@03P14<b<0@c8R048a8@14<B80AS<R04/f9@1>=bD0DSTU058i8`1C>B80DSPQ04li8@1@>R80
DC/S0P1B?2@02`1A>b<0CcTQ04hh801<>b40CSXQ050j8P1B>R80ECTS05Pi901I>B@0FcPT0080DSXR
0P1C>b<205@l9080ECdU00<0E3`T05<k8`1A>B400P1@>2000`1A>B40Dc/S05@l900205Hk7P0605@j
7`1B>R00D3XR04hj8P1=>2<0BcTS0`18>R0304Li7`80ASPN00@0AS@N04Pf8019=b40AcDO0P13<A/0
0`17=Al0BcTS04dj700204di7P0504`h7`1<>200BSDP04Td8@18<b000P11=2401010<b00?c8O03ha
7P0m<1d203`_700403l_6011<AX0@c<L04Hf7`80AcLP00<0ASHO04De7P17=Ad01017=Ad404Hd70P0
@3<P1015=A`204Hf7@80AcLN0P18=Qh304Tg7`<0BSPP00<0Ac<K04Pd701:=Qh00P1<>200101;=al0
BSHN04Te7@1B>242050h800304dg7`1;=ah0B3LM0080ASHL00<0ACDN04@d7@12<Q/00P12<Q/00`13
<a`0ACDN04Hf7`0804@c8@P0A3@M0P0n<Ah303lb7`<0@3<P0P11<1h2048a7`<0@c8P00T0A3<Q044c
9P11<bH0@38U03h`8`0m;b80?2hQ03/]800j;1l00P0i;Al0100j;Qh0>RlM03X_7@0k<1`203/`6P80
>blQ00H0>RhP03T]7`0h;1h0=b/M03HZ700e:A/803@Z7P0803T`7`0j<B00?34O03ha7P11<Qd0@c<L
04@d7@15<a/2044e7@80@SHN0P13=al204@h800804Tg8`1:>2@0CSTT050j8`1C>b<0E3`R05@j8@1D
>Ql204`l8P0304/k8@1:>R00BCTO0080B3PN00<0AcLM04hj8@1>>R401`1>>R4804/f8`0804Lb7@16
<A`0@S0J040`6@0n;aP0?C4I03hb6P0n=1/803lb7a00>c<N00P0?SHQ03de800m<Qh0?2lL03h_7010
;ad0@C0N04<`7`<0@C@Q0P12=B8304<f8`80A3DP00<0ACHQ04Hg8P17>2<00P18>B@00`19>RD0Cc/R
04lk8P0604lk8P<0ASXP:oooool002[ooooo00<0WG=109id@P2PMT@00`2RN4H00`2PMT@0WgE30:9i
A@020:9iA@80XgY60`2TNdL80:MkBPP0YWa:0`2VODT30:MnBP80Z7m;00<0ZX1>0:UoC@2WOD/00P2V
O4X0102WOD/0ZGm=0:Z0CP2ZPDd20:V0C0030:MnBP2VODT0YGa80080Y7]70P2ZPDd0102YP4`0Z7m;
0:QoB`2WOTX30:ImB@070:MnBP2YP4`0ZX5=0:^2CP2ZPDd0ZH1<0:QoB`030:MnB0<0Z7m90`2YP4X0
202YQU00Z8=>0:J1C02VOTX0Ygi:0:UnB`2/OT`0[Gm=0P2XOd/30:V0C0<0ZX5=0P2YOdd20:Z0CP80
Zh5?0P2/PU000`2[PDl0ZX1>0:QnC0020:MmB`060:QnC02ZP4h0Zh5?0:MnBP2YP4`0ZX5=0P2[PTh0
1P2ZPDd0ZH1<0:MnBP2VPDd0YH1<0:=nBP<0XGa800H0Xgi:0:AoB`2RMdX0XGI909mdA`2MLTD209aa
A080WG950P2GLSh00`2FLCd0UG0l09A_>`0209=^>P07099]>@2@K3`0Sf/k08iZ>P2=JCT0RfLg08YV
=P0208UU=@0;08UX=@27IS<0Q68b089P<P21Gc80PUle08=P=P24HCT0PUd`085L;`1oFRd00P1nFB`0
0`1oFRd0P5/^085L;`0307UC;P<0N58]0P1gDB`02`1/CRX0KDl[06mA;@1`DRh0Ke4]06e?:`1[CBT0
JT`X06e?:`1/CRX0JddY0080JT`X0140K4hZ06i@;01_DBd0KdlV071@9`1aDBP0LU8Y07AD:`1eEB`0
MUH]07MG;P1jEc40NePb07aI<@1mFS00Oed`081N<002085O;`<0QV0c0P27HC@308QR=@0308IP<@28
HS<0RV@e00<0SFLh00@0S6Hg08]U=P2;ICH0RfDf0P2<ISL03P2=IcP0SVPi08iX>@2>J3T0SfTj091Z
>`2?JCX0SFLh08aV=`2;ICH0S6Hg08eW>02>J3T0SV<f0P2?I3L00`2@ICP0TFHi095V>@02099W>P0;
09I[?P2EJSd0TfPk099W>P2AIST0TVLj09=X>`2DJC`0UF/i09=Y=`2AIcD00`2?IC<02P2@IS@0TFLe
091Z>@2?JCP0SFLf08aV=@2;IC@0S6He08eW=P2>J3L808iS=P0408eW>02<ISL0S6Hg08aV=`80RfDf
0P2:I3D308]U=P0308YT=@29Hc@0R68c0080R68c1029HcH408YT=`0608]U=P2:I3D0RV@e08US=028
HS<0Qf4b0P26H34808IR<080Peha0P24Gc801025H3<0QV4d08IQ=027HSD2085K;P03081K;P1nG2h0
OEd^0080O5d^00T0NUh^081N;P20GRh0Oed_07iL;`1mFS00O5Ta07aI<`1kF3800P1jEbl0101iERh0
N5D]07MD;01fDb/207EB:P0807YJ<`1iFC80MeL`07EE;P1cDb`0LE4Z071@:@1_CbP206iB;@80Ke<^
00X0KE4/06]?:P1YCBP0Id/V06M>9@1VCB@0ITdU06A;8`1SBB@0HTPU0P1QAbH01P1GAbH0EDDT0591
8`1??R80CC`R04dk8`<0CS`V00P0BcdR04Xl8@17>b40A3XQ040h8@0m=b40>cDO03Td8080=CTP00H0
=3PQ03<f8@0b=B80<C@S030c8P0`<R@202d]8`0302`/8P0[:b40:RXP0080:BTO00@0:2PN02PZ7`0X
:Ql0:2XO0`0W:Ah202HX7@<08R<M0P0Q8Q`3020Q6`P07R0M0P0K7QL201`O60@07B0I00@092HS028T
8@0P8Ql07R0M0P0L7Q/201dO700401`O600M81T07B0I01dP6@807R4J0P0O8Q/2020Q7003024R7@0R
8ah08b@O008092DP01409BHQ02XV6`0[9a`0;2PL02dZ6`0_;1/0<2dJ034^6`0a;aX0;RlM02l`7P0`
<Al0<C8P030a7`0_<1h0;2dK02//6P0302PX7P809bLM0`0V9Q`302PX80809bLO0`0V9Qh302<T7P<0
8R<M0P0Q8Q`0100P8A/08B8L024R700R8ad202<T7P8092DO00<08RPN024W7@0P8aX00P0P8AT02@0S
8a/0:2DN02TV7`0R9QP08bLI02HV6P0Y9a/0;BHL030V7@0203@U7P0704/_8`1=<280D3@O05Hh7P1M
?ad0IDDN06]:7@0206i>7`0607aV;@20JS40QW0g08ah?@2AOD00U8130P2EPd<0202^S5`0WWm@08=X
?@1UDB`0CSlN03df6P0f=1/0=C@O200[;b00100/;BD0:b`T02//900Z:b<202TZ8P80:2TQ00/0:b/S
02`/8P0];B<0;RhR02l`8P0`<B40<C8P038c8@0b<RP0<C4W02l_9@0202h^900302l_9@0`<2H0<C4W
0080;38V00<0;c<U034c9@0d=BD00P0g=R@01@0i=R<0?C4Q03lc8`11=BD0A3PX0080ACTY00@0A3PX
04<g9`1=?B@0CCdT0P1>?RD01P1??bH0D40W0551:01A@BP0Dd<Z0592:@80DD4X03`0DT8Y05A4:`1G
Abh0FDT`05Q59@1JAbL0G4TY05i;:`1OC2`0GT/[05a9:@1KB2P0J4/Y06U<:P1WCBX0Idl[06MA;01V
DRd0Ie<^06ME;`1KCcT0FThh05Y;=01JC380Fd/a05e<<01QCC80HTla05Y9;@1KBR`0Gd`/06A?<01Y
DS80K5Dc06mG<`1aFCD0OF8e07iR<`21Hc40QfH`08m[;`2JLS@0XWTg0:Qm>@2ZPd00YGhk09eg=P2F
L340TFd_091^<@2@L3<0TW8g08aW<`2;Ic<0RfLe08QV=P25ICH0PF8c07]O<01iGBh407=F=00<079E
<`1aE380L5<a06mB<01/DRd0KU@_075G<P1cFC@0LUPc06mE<01[DB`0J4hY0`1aD342075@;`0=079A
;P1cDbd0M5@]07AD;@1lCC40ODh`081B<@23EC40QeXa08]N=02=HC80Sf<d095X:P02099Y:`0309=Z
;02EK2h0UVd_0080Ufh`00<0T74a095b<P2CM3@00P2DMCD02@2CM3@0TG8b091a<@2OLS/0WG8k09ic
?02NMCd0WWLn09ei?`0209ej@00409Ui?P2HN3d0V7Pm09Mg?080UWHk0P2EMCX00`2FLC`0UG0k09A_
>P0309=^>@80U6lj00H0Tg@c09=d=02BLc<0TG4d091`=@2?KcH208i]=`@0Rg4n00@0RFll08I/>@22
J3D0P6Hc0P2;J3001P2>JC80TV/d09E/=P2HKCP0VVlj09a^>P<0Ug8k00T0UW4j09A_>02@Jc@0SFPa
08]V;`22I300PfDa08AV<P25Ic<01026J3@208IZ>P0408EY>@24J3P0PfLg08=W=`80PVHf00H0O6He
07]U=01jI3<0N68a07IP;`1eGbh207=M;00607=G<P1bES40LUHa075E<01`E2l0Ke<^0P1^DRd0201U
CbX0HThY05m;:01LBBP0FDTX05U::`1IC2`0FT`_101SCbX4069>:@0@06E;9P1TC2H0IU0Y06ME;@1W
FS00H5L/05I?8`1<B1/0FD/^05Q:;@1FB2/0E4HY05539P1>@2<0BcdP04Tk7PD0C3dL101=?Qd04015
?R40@c`O044j7@10>A`0?cPK040i7011>Qd0@S/N04Di7`16>R00AcdR04Ho8`14?b80@CdP03dl7P0l
>ad2048n8`0>044m8P10?240?c/P03hj7`0m>Ah0?3PM048h7`10>Al0@CXP040j800m>Ah0>CPL03Hf
6P0d=1P203Hh8P0403Dg8@0d=R00<cDO038d7P80<C<M0P0_<a`2030d7@0402lc700]<AX0:RhG02T]
5P80:B`G00@0:RdH02/^6@0[;QT0;2lJ0P0]<1/202X]6P0602X]700Z;1h0:2XM02HX7@0S9AX08B8J
0P0R9A`2024T6`05020S6P0O8QT07R4H01hQ600L8a/00P0K8QX00`0J8AT06B0H01PO5`0201LN5P80
5adI0P0F71P301DK5`0301@J5P0I6aP06A/H00H06A/H800G6AP801HH5`P05aTH100E5aH201HH5`<0
5aTH200F61L801LI60805QPG0`0E5aH301@F5@<05ALF0P0F61L601LI60805QPG0`0E5aHH01HH5`P0
5AHH200F61LP01DF60P05QPG200F5aT801HH5`P05aTH2@0F61L201LI608061XI0P0I6aXJ01XL6`P0
71`J0P0L7AL301dN60<07QlI00@0824K01lP6P0O81X07b0J0P0N7aT201dN608071dG0`0M7QP301hO
6@8071dG0P0M7QP401hO6@P0820H200Q8AT0100Y9A`0:2@K02PT6`0X91/302LS6P0402HR6@0Y9AT0
:BDI02TU6@80:RHJ0`0[9a/802`V6P06034[7`0`:Qh0;bTM02hX700]9a/0:bDI0P0Z91P202`U7`<0
:b@N0`0Z8ad802PT6`0802HO5`0W81P0:24I02TR6P0Z8a/0:b@L02`U7@0]9Qh202`V6P@0;BLK0`0^
:1`802/T700;02XV7@0Y9A`0:2@K02LS6P0X91/0:RHM02dY800^:R40:R<K02/T700]9Qh00P0^9al0
100]9Qh0:b@L02XS6`0Z91P202/U6@0302dW6`0^:1`0;bTM0080<2XN00H0<B/O03<[7P0d;1l0=RdN
03T]7@0l;ah203l`7@0603lb7`0n<Ah0?C0M03`_700k;Q/0>RdJ0P0i;1T00`10;al0@C0P04<b8P03
04Dd900=04<b8P12<B40A34R04Hc8P1;=RD0CcPV058i9@1D>B@0DcTR05<g8@1>>200CcTQ050j8P02
054k8`03050j8P1>>200CCLO0080BcTQ00H0CcTR058i8`1D>2<0F3LT05/h9@1L=bD2054i8@04058j
8P1C>b<0Dc/S05@l9080ECdU00<0E3`T05<k8`1A>B400P1@>2000`1A>B40Dc/S05@l900205Ll7`06
05Dk801B>R00CcTQ04di8@1<=b80BCLQ0`18>R0204Li7`<0ASPN00@0AS@N04Pf8019=b40AcDO0P13
<A/04017=Al0BcTS04ll7P1>>Ql0C3PM04Xf7@19=Ad0BC@O04Td8@1:=B80@3DS03ld8P0n<b40?C8P
03`a7`0k<1h203X_7@0403l_6011<AX0@c<L04Hf7`80AcLP00<0ASHO04De7P17=Ad00`17=Ad504Hd
70P0?c@R00@0A3@K04De7015=A`0ACDL0P16=Qd204Lg7P<0B3HN0P19=al304Xh800304Hb6P18=1`0
BSHN0080C3PP00T0BcLO04Xf7P19=Ad0DCLP050h801?=al0CCLO04/g7P18=ad00P16=Q`00`14=1d0
@c<L048b6`02044a6P0304<c7014=1d0ASHO00P0@c8P2014=1d203d`7@80?S4N00@0?c8O040c8011
=240@C@Q0`11<1h2048a7`<0@c8P0P11<bH01010<RD0?S0S03d_8P0k;B0203X/7`80>BdO00@0>BdM
03X_7@0j;ad0>c0L0P0k<1X0200k;b40>RhP03T]7`0h;1h0=b/M03HZ700e:A/0=2PJ200d:R00200i
<1l0>S4P03`a7`0n<Ah0@C8M04<c7014=1d0AC<K0P11=Ad2048f7P80@cLO0P14>2002@18=R80BSPT
04lj9@1B?2D0ECdU05Dk8P1C>B00DSLL04`l8P0204/k8@0304Xj8019>Al0B3PN0080AcLM2@1>>R48
04/f8`0804Ha7015<1/0@BlI03l_600n;aP0?C4I03hb6P0n=1/803lb7a00>c<N00P0?cLR03de800m
<Qh0?2lL03d^6`0n;A/0@2lM048_7P80?c@R0P10=B<3044f9007048g9@13=1l0A3DP04@e8015=R40
ASLR04Lh8`0204Pi90P0Cc/R0`14>Ql[ooooo`00:_ooool00`2TNTP0XWQ60:5gA@020:1fA0030:5g
A@2RN4H0Y7Y80080Y7Y:00@0Y7Y80:AkA`2TNdL0Y7]50P2TNd<20:=hA@030:AiAP2UNTL0YW]80080
Yga900<0Z7e:0:Ak@`2UO4@00P2UO4@20:ImA@80Ygi6202UNdT20:QjB@80ZG]:00@0ZWa;0:]mC02[
OD`0[7i=202XOd/20:AkA`030:ElB02VODT0Ygi:0080ZH1<00<0ZX5=0:V0C02ZPDd00`2[PTh00`2Y
P4`0Ygi:0:ImB@020:UnB@@0ZWm:0`2[P4/30:Z1C@<0ZH1<0P2XOd/20:V0C080ZX5=0P2[PTh20:b3
C`P0ZHA?202YOdd80:^1C`80Z7i>00@0Yge=0:IlC02UNd/0Y7Y:0P2SNDT209miBP0609egB02KMDH0
VG=409Ma@P2EKd00U6ho0P2FLCd00`2EL3`0U6lk09=^>P02099]>@07095/>02@K3`0T6`l08m[>`2>
JSX0SFTi08aX>00208]W=`80QFDf0P24I3D01023Hc@0PV8c085Q<P21HC8307iL;P80Oed_0`20GS00
1P1iDbH0NE8W07UB9`1iDRT0NE8[07Q@;080N50]0P1cDb`3079B:`<0LE4Z00<0KDl[06a>:P1[CBT0
0P1ZC2P00`1/CRX0KU0/06mA;@0207MA;080MU0[00@0N58]07YD;`1lES40OUPc0P1jF2X00`1kFB/0
O5X/07eK;@0207iL;P0307mM;`27GS80Qehb0080R5lc00@0RF0d08YQ=@2;HSH0Rf8f0`2;ICH208aV
=`H0SFLh0P2<ISL408]U=PP0S6Hg202=IcP208aV>@<0SFLj0`2>J3/308eX=00308iY=@2?JSH0T6/g
0080T6/g202CJ3/0102@JS/0SfTj08mY>P2?JCX208iX>@80SFLh202=JCT208QT=080Qf<c1026HS82
08MQ?00408MQ>P27HSP0Qf8f08MR=@80Qf<c2028HcH808IR<PP0Q5lb00H0QF0f08AO=@24GcD0Pehd
089M<`21G382081K<@80Oe`b0`1nFc4307eJ<080O5`c00<0Ne/b07YJ<@1iFC000P1gEbh01`1fERd0
OELc07YF<P1hE300ME<^079B;01^D2X00P1[CbP0201bD2X0Le4[07=C;01aE2`0Ke<[06]B:@1YD2L0
ITlU0P1XCR/0101VCRX0I4`X065;9P1NBRD205]98`0605U6:01HA2T0E4<W05519`1=?bD0Bc`U0`17
>bD01P1;>B40BSXQ04Ti8018>R00ACTO04<i7P80@3TM0100?cPL03hg7@0k=1X0>C4J03P`6`0h<1d0
>C0O03Xa800h=Ql0=S@M03<a700`;AX0;R/J02h[700_;1d0;b/O0`0X:1h202LW7@<09RHL100S91`2
028S6`808B8J200O8Q/;01hQ6P<07b8K0P0P8a`401dP6@@07R4J0P0P8a`3024T7@<08RDN0P0U9aT0
0`0V:1X09bTK02PZ700202T[7@0602X/7P0[;ah0:blN02`_7P0^;al0<2hO0P0b;b002@0d;R00:2TK
02LW6`0V9QX09BDK02DU7@0W9R40:BPT02XY9@0802DU7@8092DM0P0S91`00`0R8a/08B8J024R6P03
020Q6@@08B8J0P0R8a/8024R700?028U700Q91/08B8J028R6P0U8Q/0:2<M02XU7`0^9b40>RXJ03d/
7011<1h0AS@P04dh8`1A>bH0ESdW0080F40X01P0JdTV075A:`1lG3D0QFPl08id@`2ANT@0U7i509=o
A02SP4H0YhA<0::2C`2DMDT0NEdh05i59`1<=1X0@bdF030i=P0[=340:2hZ02L/9P0[;RL0;2dU02/[
8@0X:1h302//900302X[8`0Y:R80:BXR0080:2TQ0P0[;2@302`]9@<0;BhV00H0=2hP03D_8@0e;b40
=c4S03Pb900i<bD203Xd9P@0<C8T100`<B<0600k=2X0?CH/044k;`14?S00ACl_04E0;@14?b`0@chZ
04Pk:P19?2/0BSdZ04/o:@1<@2P0CT8X04m3:@1?A2P0ESla05@o;P1A?Rd0Cd0[04e3:P1=ARX0CT//
051=;P80EDD[00@0ETH/05M7;@1HB2h0FDT_0P1JBS00>P1LC2P0HU0/06ID;P1WE2`0Ie4X06UB:@1^
EB`0LUT`06E>;P1UD340Ie8c06QE=`1WESX0IEDk06=E>`1RE3X0HEHf069E=@1QDS<0HU4c06E@<`1Z
D3D0KE8g075C>@1dF340MUXc07YM<`1oHc@0QVPf08a/>@2AL3X0Tg8l09Yh;P2PNc@0Xghg0:9k=P2N
MC<0W70a09a^<02MKc<0UW<a095^;P2;JB`0QVD_08EU<P24HcH0OUhe07YJ<`1eGS@0Le`c071I<01]
EBl0JU8^06YB<01ZDC80Je8c07UH;`1jFC0207]J<@0407YI<01gERd0M5<Z079A:080Le8_00l0LU4^
06i@;01/D2/0JDlZ06M?:@1VD2T0Ie4Z06Q8<@1WB2`0J4HZ06]99P1aCRH0NUDY085M;@26H2l00`2<
HS803@2=Hc<0S68b08aR<P2<HS80Rf4a091a;P2ALS40U78b09Ib=02HLCH0V6lg09M^=P2GK3L00`2G
LcD01@2HM3H0VGDg09Yf>02KMcT0W7Pj00<0Vghl01/0VWdk09Qk>@2EN3H0TWDc095d<P2AKSH0TVlg
09=`>P2CKc/0TVhl091/?02>JSX0S6Lj09Qc?02DKcP0TVdf09=^=`2GLS/0V7<l09Ia>P2CKSL0V7Do
09Qd@02GLcl0UG4o09=_?`2BKD000P2@Jcl01028K2d0RVh_08a`<@2?Lc@2091d=@0808mc=02>LS<0
TVli095^>02@KCL0Sf`f08i[=@2=JS@208aY<`<0QFDb0P24I34308=S<080Q6Df00<0Pf@e089S=021
HS<00P20HC801P1oH340LUh/079N;01aG2d0L5/^06mJ;`80KUP_00<0KEL`06YG;`1ZEbl00`1ZEbl3
06]H<00305Q;:`1GBRX0F4TZ0080FDPZ01<0FTLY05]6:@1KART0Ge<[061B:`1QDR/0IE4/06UA;@1/
DRl0L58`075C<@1WE2`0IU<[06A@:`1QCBX0GTXY05Y59P1G@R<0ED0S0080DTH/0P1CAbd0101AAB/0
CT8X04/o9@19?B<304Hm8080AchQ00@0B3lR04U08`19@2<0BT4T0P14?B401013?200@S/O048k7`11
>Qh2040i7@08044k6@12?1`0A3hN04@m8014?B40@S/Q040h8@0o=b02040l8@80?c/P0`0n>Ql00`0m
>Ah0=SPP03Hh800203Dg7`@0=3HN100`<Q`4034c7@80<S@L00<0<C<M030b7@0_<1h00P0^;al01`0]
;R00<c8M038a700`<Q`0;S8K02da6P0[<1T00P0X<1P202LZ7`0602HY7P0T9a`08bHK028U6P0Q91T0
82<H0P0N9Ad00`0M91`072<K01/R6P0201XQ6@0301TP600H7QX061hJ00H061hJ0P0K7AX301XL6@<0
6A/H0P0F61L301LI60<061XI600G6AP@01HH5`P05aTH:@0F61L801DG5Q005QPG200E5QP801HH5`P0
5AHH200F61LH01DF60P05QPG400F5aT801HH5a405aTH0`0I6aX301XL6`806adL00<06A/J01PJ6@0G
6AP00P0G6AP00`0H6QT06Q`K01/M700801XL6`<06QXH0`0K6aT201`L6PP07AdK0P0N7aT0100M7QP0
71dG01`M5`0K71H201XK5@P071`J200L7AL801hM60<0820H0`0Q8AT2028R6P<092@L0`0S8a/2028R
6P0802<S6`0T91`09RHN02LW7`0X:2009bLO02HV7P0U9Ad802/W7P0302TY7`0X:1h09RHL00809BDK
00H09RHL02PX7P0Y:Al0;BPR02/V800Y91h202LR700302PS7@0Y91h0:RDO00P092@L0P0R8QX302<S
6`<092@L0P0T91X202DU6`809RHL0P0W9ad00`0X:1h09RHN02HV7P0602HV7P808R8J0`0S8a/302@T
700302/V800Z9Al0:2<M00809b8L00T0:2<M02XU7`0[9R009bTN02PX7P0Y:Al0:bPO02dY800_:200
0P0a:2402P0f:aT0=b`J03T^700j;ad0>c0N03X_7@0i;Q`0>2dK03/^7P0l;al203d`800403`_7`0k
;Qh0>B`L03LZ6P80>bhK00@0?2lL03d`7@0n<Ah0?c8O0P10<b001P10=Qd0@CDM044e7@14=Ah0ACDN
04Le7`80BC@O00@0AcDM04Tg7`1;>B40CC/S0P1>?2@01@1<>R80BcTQ04Li7P17>Ah0BCTO0080BSTO
00@0CCTP04hh801>>200C3XT101=>bD304hl9P0605@h8`1C>2<0DcPS058i8`1@>R<0Cc/S0P1=>b<2
04`l8`0304/k8P1:>R40BCTP0080AcLN00@0ASHM04<f8`13=R<0@cHS1@14=b@00`17<Qd0BC@O04/f
8@0204`g8P0>04/f8@19=1l0Ac8M04Lf6P18=a/0BCPN04Tg7`18=R00AS@P04<a7@12;ah0@cHV044d
9010<b<203ha8@03040c8`11=2@0@cHV0080@RlQ00H0@c0Q04<`7`14<Qh0AC<M04Hd7P16=1`204Dj
700304@i7@14>1h0@cLO00<0@cLQ00<0@SDR040c8P10<b801P10<b8404<f8`@0@SDR0P14=1d204De
7P<0ASHO00D0AcLP04Pd6`19=A`0BCDL04Xf7@0204/g7P80C3PO00H0AcTO04Hh7P16>1h0ACLM04@f
7013=A/2048d6PD0?c8Q0`0n<B000`0m<1d0?S4N040c8002048e8P03044d8@10<b00?c8O00<0@SHL
0`11=A/2040d6P80?C8P00@0?S<Q03ld8P0o=280@3DS0P11=R@2044e7`07040c800o<R40?S4P03d`
800m;b80?2hQ03/_7`0303X^7P80>BdM0P0h;1`01P0h:Ql0>B/P03P/800f;200=BdP03D_8@80<c0Q
100a;B40300`;200;RXN02`X700[9a/0;2HJ02lW6P0a:A`0=2/L03L[6`0h:aX0>BXG03PY5P80?C0O
00@0?S4P03lb8@11=2<0@SDT0P13=RD02@0n<b40@3<P044d8@15=R40B3PQ04Xh801=>B00CSXQ05<h
8`03058g8P80DCHQ0P1@=B0204Xj8`80BCTR0`18>2401@17=b00BcLO04`h801>>R80D3`T0080DCdU
0P1@?2@01`1?>b<0CCTP04`h7`1<>1l0BcLN04Xf7@19=A`00P18=1/02015<R40A34P048_7P11;Qd0
@RlN04@a8016<b80Ac@S0`0n<B0203d`7`<0?2lN00@0>2lN03T`7`0i<1l0>S4P0P0k<R4203`c8P03
03L]8@0i;b<0>c4U0080?38V00<0>c4U03T_8`0g;B400P0n<R802@0m<B40?30P03/_7`0j;Qh0>BdM
03P/7012=bD0@CHT03ld8P0203hc8@0303ld8P11=R@0@SLU0080ACTQ0`14>20304<g7`P0C3LV0`1:
=bH[ooooo`00:_ooool00`2TNTP0XWQ60:5gA@020:1fA0030:5gA@2RN4H0Y7Y80080Y7Y:00@0Y7Y8
0:AkA`2TNdL0Y7]50P2TNd<20:AiAP<0YGY70`2VNdP40:ElA080YWe50P2WOTH80:IlBP030:QjB@2Y
NdX0ZG]:0080ZWa;0P2[OD`00`2/OTd0Z7m;0:QoB`060:QoB`050:AkA`2UO4P0YGa80:ImB@2XOd/0
0P2YP4`00`2ZPDd0ZH1<0:Z1C@030:^2CP030:V0C02WOTX0YWe90080ZGi9102ZOdX30:^0B`<0ZX5=
0`2YP4`20:QoB`80ZH1<0P2ZPDd20:^2CP80[8=?202YQ4l80:UoC@P0Zh5?0P2XOTh00`2WODd0YWa<
0:EkB`020:AjBP090:=iB@2ONDX0WgU:09egB02KMDH0VG=409Ma@P2FL440UFm00080UW4m00@0UG0l
09A_>`2CKSX0Tfhj0P2BKCT2091/?00308m[>`2>JSX0SFTi0080S6Ph00L0RfLg08IV=`25ICH0QFDf
08AT=@23Hc@0PV8c0080PF4b201oGBl01P1kEBP0NU<X07YC:01jDbX0NU</07UA;@80NE4^0`1cDb`2
079B:`<0LE4Z00<0KDl[06a>:P1[CBT00P1ZC2P00`1/CRX0KU0/06mA;@0207AA:`80Le0Z00@0M54[
07IC;@1hEBl0NULa0P1jF2/0101kFB`0O5X]07eK;P1mFbh207iL;`0608IM<@27GS80Qehb08QO<`29
H3@0RV4e0P2;HSH0102:I3D0RfDf08]U=P2;ICH208aV=`D0SFLh0P2<ISL408]U=PP0S6Hg202=IcP2
08aV>@<0SFLj0`2>J3/208eX=080SVTe0P2?JSH2091[=`P0TfPk102?JCX208iX>@80SFLh202<J3P2
08UU=@<0R6@d0`27Hc<208MQ?00408MQ>P27HSP0Qf8f08MR=@80Qf<c2028HcH808IR<PP0Peha0`23
GS@3089M<`80PE`b0P1oG38307iK<@<0OEX`0P1lG3<0901kFc80NUXa07UI<01hF2l0MeL^07IF;@1m
Ec<0NUHb07QD<01eDbh0LU8/06i@:P1/D2T0JdlX079@:P1cDB/0Le</075D;01_Db/0Je8Y06U@9`1V
CbD0Jdh/06Q>:`1WCBX0I4`X069<9`1NBRD0G4XT05]98`1JABP0F4DW05M3:01B@BL0CclV04`m9P80
B3`T00L0Ac/U04`j8P1:>R40BSXQ04Pj8015>Al0@cTN0080@3TM00H0?cPL03hg7@0l=A/0>S8K03Ta
700i<Ah203Xa800503Pf7`0f=1d0<c4L034^6`0_;1/00P0_;1d0100`;200:2PN02PX7P0X:1h302LW
7@809RHL00@092DM02<T700S91`08b@L0P0R8a/2024R6PP07b8K2`0N8AX301lR6`8082<L0`0M81T5
01hQ6P<082<L0P0Q91d3028U7P0602@V6@0U9aX09BLJ02HX6`0W:A`0:2XM0P0Y:ah202``7`0>02d`
7`0_<200<BlP038_800c<240=BlQ02`]7`0Z:ad0:2PL02HV700V9Qh09RDP02LV8@0X9b<802DU7@80
92DM0P0S91`2028S6`P08B8J0P0R8a/8024R700?028U700Q91/08B8J028R6P0U8Q/0:2<M02XU7`0^
9b40>BTJ03XZ6`0o;Qh0@c0O04Pf8P1=>2<0DC/V0080DcdV01P0IdHU06Y<:01cEBl0OF8g08M/?@2;
M400SgQ2095k@P2QODT0WWe:09]kC02DMDT0QVY307=I=P1QB2T0EChO03@d:P0`<2H0;2`R02//900]
;RH0;S4Z02/^9`0X:b@702X[8`0402TZ8P0[;2@0:b`T02//9080;2dU0`0];RH2038_800603<`8@0d
<B80=C8S03Hc900g=2D0>3DV100b<bD4034b900803Xc:@0l=B/0?SP/040j;012?2`0@ch[04@o;014
?b/204Pk:P0404Tl:@1:?RP0BclW04/o9`80C40V00P0Dcd_058m;01??R`0CSlZ04a2:@1<ABT0CTT[
04i;;080E4@Z00<0EDD[05I6;01GAbd00P1HB2h09P1IBBl0Fd/Y065?:`1UDbl0IU8]06MA:P1XDBP0
KE@[075H;`1WD300J54a06QC=01YESP0J5Lk06IF?01UEC/0I5Hl06=F=01REC<0HU<b06AA<@1VDC80
JU4c06eB=@1^DcH0LELb07EI<P1hG3@0OV4e08EV=`2:JSL0SVdh091_>@2HMRl0W7Xc0:5l=P2QNSL0
WWDc0P2MLC803P2PLSH0VW@c09=`<02>JRh0RVL_08QW=025ICH0Of0d07YJ<@1eGS@0Le`b071I<01]
EBl0Je<_0P1ZDS00101ZDC80M58/07EC;@1gEBl307QF<00307ID;P1eDbd0LU4^0080LU4^00l0L58^
06iB;@1ZD2/0J50Z06E?:01TCRL0IdL^06M8;01YB2T0JdXW06m=9`1fE2L0OEP[081L;026Fbh00P27
G2l03@28GC00REha08YO<P2:Gc80Rf0c08Y[:`2;K2`0Sfd^095]<@2CK3<0TfXb099Y<@2BIc800P2F
LSH0102GLcL0V7@h09Ue>@2JMSX209]g>`@0VWdk00@0V7/i09Eh=P2CMS@0TG@b0P2CL3P0502DLC/0
Tflk099^?02?Jc/0SFTi08]V>@2FLCX0Tfhg095/=@2CKSL0Ug8k09Ud?@2GLS/0U6lh09Qe>`2GM3X0
UW<k09Eb?02CKc/0TFdi0P2@K3X02028K2d0RVh_08a`<@2=LC80SW8c08ea<P2<L340Rfl`0P2;JSD0
1`2:JC@0RFPc08QW<P27IS40QVD`08ET;`25IC800`24I34208=S<080PV8_0P23I3H00`22HcD0PF8d
081Q<`0207mP<P0907iO<@1aGB/0LE`]071K;01_FRd0KUT^06eG;P1]Ec00K5H_00@0JEH^101XEBd2
05U<:P0405Y;:P1KBbX0Fd/Z05a9:@80GDPY0140Ge4Z061B:`1SDB/0IE4/06YB;P1/DRl0Ke8`075C
<@1ZEbl0J5D]06A@:`1PC2T0FdLV05Q3901E@240E3lR0514:P030555:`0404m3:@1<@2H0BShT04Pl
8P@0ASdP00<0AchQ04Po8P18?b800P19@2<304<l8003048k7`11>Qh0@CXN0080@3TM00T0@C/I048l
7013?Ad0A3dP04<l8012>b40@3PQ03lg8010?2400`0o>b0203hj7`80?CTN0P0f>20203Dg7`<0=3HN
00<0<cDM034c7@0a<ad00`0a<ad3038d7P80<S@L00H0<C<M030b7@0_<1h0;RlO02d^7P0];R02038a
7@0402la700^<A`0;C0K02/`6P80:30I0P0V:Ah0100U:1d092LL02<V6`0S9Q/2028U6P807RDM00@0
7B@L01`S6`0K8QX06R4I0P0I81P801PN6P806adJ0`0J71T301TK60805QPG0`0G6AP301PJ6AP05aTH
400F61L801LI62T05QPG200E5aH@01HH5`P05AHH200F61L801DF60P05QPG600E5QP801HH5a005QLI
200F61LA01LI60<06A/J0`0J71/301/M700601XL6`0H6QT05aTH01LI600H6QT06A/J2@0J71/301XJ
60<06a/I0P0L71X801dM6`807QlI0P0M7QP0100L7AL06a`F01/L5P0K71H801`L6PP071dG200N7AP3
020P60<08B4I0P0R8QX302@T70<08b<K0P0R8QX0200S8a/092@L02HV7P0W9al0:2PP02LW7`0V9Qh0
9BDM200[9ah00`0X:1h09bLM02HV700202DU6`0602HV700W9ad0:2PN02/V800Z9Al0:2<M0P0V8A/0
0`0W8Q`0:2<M02TT7P0802@T70808R8J0`0S8a/302@T708092@J0P0U9A/302HV70809bLM200V9Qh2
028R6P<08b<K0`0T91`00`0[9R00:RDO02PS7@0202LR700402PS7@0Z9Al0:bHP02PZ7`80:BTO00<0
:bPO02`X7`0_:2000P0`9b00200f:QX0=b/K03T]7@0j;Qh0>blO03X^7P0i;Ad0>2`L0P0k;Qh01`0l
;al0?C0P03`_7`0k;Qh0>B`L03LZ6P0k;Q/00P0l;a`00`0m<1d0?S4N03lb7`02040c8006044g7P12
=Qh0@SHN04Df7`16=Ql0B3HP0P1:=B000`18=Qh0BSPP04`j8P0304dk8`0504/i8@1:>200AcTN04Li
7P19>Al00P1:>Al00`1=>B00CSPP04hh800204Xh8P0404/i8`1<>R@0C3XT04dk9@80CS`V0P1B=b82
054h8P0:04li8P1>>R80C3XR04`j8P1<?2<0Bc/R04Xj8@19>B00B3PO04Lg7P80ASHM0`14=b@504<f
8`0304Pc7P19=1l0BSDP0080BcHQ00h0BSDP04Td7`18<ah0ASLJ04Hf7017=ad0AcLN04Hf7`14<al0
@S4O044`7P11=2@0@3<S03ha8@80?C0P00`0?S4Q040c8`11=2@0@2hP044_8@11<200@S4O04<b7P14
=1d0ACDN04De7014>A/204@i7@0404<g7@13=al0@SHP048f8080@SDR2010<b88048e8P80A3@M0P15
=Ah404Hf7`0304Te701:=Qd0BSHM0080BcLN0P1<>1l01P1=>B00ASLP04Hg8015=Ql0A3DN04<d7@80
@S<L00@0@C8K03lb8@0o<R40?c8Q1@0n<B00200m<1d0?S4N040c8011=240@SDR044d8@10<b00?c8O
0`12=Qh2044e7@<0@3@L0P0m<R0203hc8@0403ld8P10=B<0@3DS040e8`80@CDO00@0@3<P03lb8@0n
<B00?C0P0P0l;R4403/_7`80>RhN0P0i;Ad203T[800403T]8@0g;B40=RhQ03D_8@80<c0Q00D0<RhR
034]8@0`;200;b/O02hZ7P0202dY7@0902`X700]9a/0<2PK038Z7@0e;1d0>2`L03T/6`0j:aP0>BXG
0080?C0O00h0?S4P03lb8@10<b80@C@S048e9013=RD0?c@R040c8011=240ACHQ04Ph8@1:>200CCTP
04hj8@<0DCPR0P1@=b4304lf8080BCTR0P18>24204Lg8080ASHO00H0BcLO04di8@1?>b<0D3`T054m
9@1@?2@304lk8`80CCTP0P1<>1l0101;=ah0BSHM04Te7019=A`204<b80<0@C0N00<0@c8P04Dd8P16
=B<00P0o<R4303ha80<0?C0O0P0h;ah00`0i<1l0>S4P03Xa800303/b8@0303H/800h;R80>BlS0080
>S0T00<0>BlS03P^8P0f;2000`0l<20203/_7`<0>RhN00<0@SLU044f900o=2800P0n<b400`0o=280
@CHT048g9@0404<g7`@0A3PP201<=bH304Lf92_ooooo000Zooooo`030:AjB02RN4H0XGM50080X7I4
00<0XGM50:9hAP2TNTP00P2TNTX0102TNTP0Y7]70:AkA`2TNdD20:Ak@`<0YW]80`2UNTL20:AiAP<0
YGa60P2VODL30:MnB0P0Z7i<0P2WNdX20:QlB`@0ZGe<202XOd/20:ElB0030:ImB@2WOTX0Z7m;0080
ZH1<00<0ZX5=0:V0C02YP4`00`2[PTh00`2YP4`0Z7m;0:ImB@020:UnB@@0ZWm:0`2[P4/30:Z1C@<0
ZH1<0P2XOd/20:V0C080ZX5=0P2[PTh20:b3C`P0ZHA?202ZP4h80:^1C`80Z7i<0P2WOD/0302VO4X0
YG]90:AjB02TNTP0X7Y;09miBP2NN4T0W7I709YdA@2HLT<0Ug5209I`@@80Ug8n00<0UW4m09E`?02D
Kc/00P2CKSX00`2BKCT0T6`l091/?00208m[>`0408iZ>P2=JCT0S6Ph08aX>080QfDg00<0QV@f08ES
=@24HS@00P23HC<2089P<P80PEla00H0P5h`07mM;`1nG2h0OU`^07eK;@1lEbX207]F:P0307]F;01j
E2d0NE<^0080NE<_00@0M5@]07=C;01cDb`0Le</0P1bDR/2075A:P0306e?:`1/CRX0JddY0080JT`X
00D0K4hZ06i@;01_DBd0Le0Z079?:@02075>:004079?:@1dDB/0MU<]07MD;P80NEH/00<0NUL]07]H
;P1lFBl00P1mFS001`1nFc40Ped`08AN<@24GS40QElb08IP<`27HC@00P28HSD308YT=@80RfDf0`2<
ISL308eW>080S6Hg102;ICH@08eW>080S6Hi0`2=IcX308iX>`0408eX=02>JCD0SVTe08iY=@<0SfXf
00<0T6/g099W>P2BIcX01P2BIcX308mY>P80SVPi0`2=IcP;08YV=P<0RFDe0P28I3@208QR?@0408QR
>`28HcT0R6<g08QS=P80R6@d2028HcH808IR<PP0PUd`0P21G383089M<`<0Pehd0P1oG38307iK<@<0
OEX`00H0O5`c07]K<P1kFc80NUXa07UI<01hF2l207MG;P0807eG<P1jEc40NEH`07ID;P1cDb`0Ke8Z
06eA:@1/D2P207=A:`0<079B:`1`Db/0KU8Z06]B:@1YD2L0Ie0V06a>;01ZCB/0JD`Z06I<:@1SBbL0
HD/V0P1NBRD01P1KARL0FTDV05Q59`1C@RH0DD0V04hn9@80Bc`U00L0BS/T04dk8`1;>b80Bc/R04Tk
8@16>R00A3XO0080@CXN00H0?cPL03hg7@0l=A/0>c<L03Xb7@0j<Ql203Xa800503Le7P0f=1d0=38M
034^6`0`;A`00P0`;Ah00`0`;200:BTO02TY7`0202PX7P<09bLM00@09RHL02@U7@0T9Ad092DM0P0S
91`3028S6`P082<L2`0N8AX301lR6`8082<L200N8AX0100O8Q/082<L020S700P8a`2024T7@808RDN
0P0T9Q/00`0U9a`09RPM02LY7P0202PZ7`0602T[800]<B00;C4P02ha800`<B40<S0Q0P0d<B801`0f
<280<34Q02h_7`0/;Al0:BTM02LW7@0V9Qh00P0U91l802DU7@8092DM0`0S91`8028S6`<08B8J200P
8A/2024T6`0=024R6P0R8QX09B8K02PS7@0Z9Al0;BHP03<W6@0e9aX0>2/K03d]7@12<B40AS<R04/f
8`0204dh9@0I05i18`1RABD0J4/Y075E;P1hH3@0PFTi08Qa?`2;M400V7M>09IeC02DM4/0UGQ>09Ej
C`2<M4P0OVHj071I;@18>240@C8M03P]6`0a:ad0;RhT02d`:@0Y;b/09Bh[02TZ8P0402X[8`<0:b`T
00@0:R/S02//900[;2@0:b`T0P0/;BD202d^9P80<RhR00@0<blS03@`900e<BD0=C4U0P0f<RH803<d
9P80>C8X00H0>S@X03/e9`0m=bL0@3/X04<n:`14?b/204Hj:P0304Hk:@17?2P0Ac`V0080AcdT00T0
AcdR04hk;01=?2X0CC`Z04`m:01<@2P0CD<X04e6:@1>AbX00P1B@RP00`1C@bT0E4@Z05E5:`0205I6
;00?05M7;@1JBRP0H4d/06AB;P1UDB`0IU0[06M?:@1/Db/0L5L_06YB;P1ZDc40K5Dc06]G=P1[F3P0
JUTk0080J5Tl0P1TEC@0901TE3<0IU<c06MB<`1ZDc@0KE@f06iE=`1_Ec40LUPc07EL<`1jGc80P6@e
08IX=P29JS@0Rf`f09=b;`2IMS@0WGXh09ih=`2LM3H0W7<e0:1d=`2RMST0WGLh09Qb=02AKC40SV/c
08eY=@28ISH0PV8c07aK;P1eGS80M5dc075J<01^Ebh0Je<]06YB;P80JE4_00@0KDdV06m?:01aDBX0
Le</101eEBh2075@;@0?079A;P1bE300LED`06eC;P1YDB/0I4hW065;901UAbd0ITP/06Q9:P1/BbX0
KddX07=@:01eDbH0N5<W0080NeDX01<0O5HY07iH:`20FRd0Ped`08EO<P26H3<0Pf<X08EU:P28IBd0
RfH_08iW<02>IBl0SF@^08eR;@2DL3@0UG4e09Ib=P2GLcL0V7@h00<0VGDi0P2INSX209Yk>`0409Qi
>@2FMcL0U7De099c<`80UG8j01H0UG8l09A`?02BKS`0SVXj08]W=`29I3L0TVli08m/=P2=JS@0T6dg
09Eb?02HMCl0UW<m09=`>P2FMC80UG@a09Ab<P2CLC80TW0c095^=02@KCD0Sf`d0P29K38308Y]<`03
08U/<P27JS00QVT_0080QVD`00<0QF@_08AS;P23HRd00P22HB`01021H2/0PV@b089T<P22I382085S
<@<0P68`0P1oHSH00`1nHCD0OF0d07aO<`0207]N<P0:07YM<@1`Fb`0L5//06mJ;@1^FBh0KEL^06aF
;`1[EBh0JeD`06ME;`80IU@^00<0IE<]06AB;01TDR`00P1SDB/205]>;00405a=;01MCB`0GTh]061=
;@80HD`]0100H54Z06=A:`1TDR`0IU8]06UC;P1[Dbl0K58_06eC<01ZF300IeD]065?:@1LBRH0Ed@S
05E28P1C@200Dd0R0`1>@RP01@1=@BL0C40V04Xn9018?280Ac/Q00D0ASdP0P17?R4204Po8P0404<l
8012>al0@S/O048k7`<0@CXN00T0@3TM044k6@12?1`0@cdM04<l7`12>al0@CXP040h8@0o=b000P0o
>b0203hj7`<0?CTN00@0?3PM03Dg7`0e=al0=CLO0P0d=Qh303<e7@<0<cDO1@0b=1h03P0b=1`0<C<K
034c7@0`<Qd0;c0N02h_7`0];Qh0;BhP038a7@0a<1`0;c4L02d`6`0/;aX0:RlI0P0W;aP702@W7007
02<V6`0N9Ad07B@L01dT700L8a/06b8J01XQ6@0201TP60P061hJ0P0K7AX301XL6@<06A/H0P0F61L3
01LI60<061XI600G6AP@01HH5`P05aTH:@0F61L801DG5Q005QPG200E5QP801HH5`P05AHH200F61LH
01DF60P05QPG400F5aT801HH5a405aTH0`0I6aX301XL6`806adL00@07AlN01`N7@0J71/061XI0P0G
6AP00`0H6QT06A/J01XL6`0701XL6`<06QXH0`0K6aT201`L6PP07AdK00@07QlI01dN600M7QP07AhH
0`0L7AL00`0K71H071`J01`L6P0601`L6PP07AhH200O7QT3020P60<08B4I0P0R8QX302@T70<08b<K
0`0R8QX00`0S8a/09BDM02LW7`0202LW7`809BDM200Z9Qd00`0X:1h09bLM02DU6`0202@T6P0602DU
6`0W9ad0:2PN02TT7P0X8ad09R4K0`0U81X202HQ6`P092@L0P0R8QX302<S6`<092@L0P0T91X402DU
6`<09RHL200U9Ad2028R6P<08b<K0`0T91`00`0Z9Al0:B@N02PS7@0202LR700902PS7@0Y91h0:RDO
02T[800Z:R00:BTO02/X7`0/:1l0;BHN0080;RDN00<0=BTI03HZ6P0h;1`00`0j;Qh203P/700303X]
7@0k;Qh0?2lO0080?2lO00<0>bhN03T/700h:a/00P0l;a`0100m<1d0?S4N03lb7`0o<Ql2040c8006
048h7`13=al0A3PP04Hg8018>240BCLQ0P1<=b8204/i8@<0C3XR00<0BcTQ04Xh8019=al00P17>Al0
1019>B00BSPP04Xh801=>B4204hh8@80AcDO00@0B3HP04Xh8P1;>B<0C3XT0P1=>bD01P1B=b80DCPR
054h8P1?>B80CSXR04`j8P80Bc/R0P1:>R4204Ti800504Ph7`17=ah0ASHM04Hf7@15>2D00P14=b@0
0`13=R<0@SDR044d8@02044d8@0304Hd7P17=Al0B3HP00<0B3HP00`0AcDO04Hd7P16=Q`0ASHL04Hf
7@16=Ql0AC@P04@c8@12<Al0@C0P03ha8@0m<20403`_7`0703d`800n<B40@2hP040^8011<200@S4O
04<b7P0204@d7@0604De7013>1`0@cPL04<g7@12=Qh0@SHP0`11=2400`11=2<0?c8Q03lb8@0603lb
8@L0@C@Q00@0@SDR04@d7@14=1d0A3@M0P15=Ah304Hf7`<0BCLO0`1:>20204/i8@80@cLO00<0@SHN
044e7@10=1`00P0o<a/00`0n<QX0?C0O03ha800603ha800303`_700n<Ah0?c8O00<0@C@Q00@0@3<P
03lb7`12=Qh0@SHN0P11=Ad3040d700303lc6`0m<R00?S<Q0080?S<Q0`0o=2801`10=B<0@CDO040d
7P10<b00?c8Q03ha800m<2000P0l;R40100m<B40?30P03``800l<20203/_7`80>RhN0P0k;B80500j
;R80>2hR03L_8P0f<280=34R03<`8@0d<2@0<RhR02hZ7P0/:1`0:bLK02`X700^:Qh0;b/O030Z7P0b
:Qd0=2`O03H]7P0i;Ad0>RdL0P0l;AX203d`7`0303ha800o<R40@3<R0080@C@S00L0@SDT03ld8P11
=240@SDR04Df8@17=b00BSPP0080CCTP00@0DCPR050g8@1@=b40D3LQ0P1?=R0204he7`<0AcLP0P16
=Ql304De7P0604`h801=>B40Cc/S050l901A?BD0D3`T0P1?>b<01P1>>R80C3XR04`j8P1;>B40BSPP
04Tg7`80B3HN00<0AcDM048a7`12<Al00`11<1h00`13<R00A3<Q04Dd8P03040c8P80?c8Q0`0n<B03
03P_7P<0>C0O0P0j<B000`0e:al0=R`P03L]8@0303L]8@0303H/800e:al0>RhN00<0>RhN0P0k;al2
03``8003044f9010=B<0?S<Q0080?C8P00<0?S<Q040e8`11=R@00P11=Ad01012=Qh0@cLO04@h8014
>20204Di8@P0BCHU0`15=28[ooooo`00:_ooool00`2TNTP0XWQ60:5gA@020:1fA0030:5gA@2RN4H0
Y7Y80080Y7Y:00@0Y7Y80:AkA`2TNdL0Y7]50P2TNd<01P2XODX0Yga90:MlB@2VNdP0YGY70:AiAP80
XgQ50P2UO4P20:ImB@80Ygi:0P2XOd/80:Z0CP80Yge;1P2XOT`80:QoB`80YWe90P2WOTX01`2XOd/0
ZH1<0:V0C02YP4`0Z7m;0:V0C02ZPDd00P2[PTh00`2ZPDd0Z7m;0:MnBP020:UnB@@0ZWm:0`2[P4/3
0:Z1C@<0ZH1<0P2XOd/20:V0C080ZX5=0P2[PTh20:b3C`P0ZHA?202ZP4h80:^1C`80ZH1<00@0Z7m;
0:MnBP2VODT0YGa80P2TNdL01P2PNT/0WgU:09ihB@2MMdP0VgE609UcA080V7930P2HLcl0102GLSh0
UW4m09E`?02DKc/209=^>P80TFdm00@0T6`l08m[>`2>JSX0SFTi0P2<J3P208UT=`0408QS=P27HSD0
Qf8e08IQ=080QF0c0P23HC<01022H380PEla07mM;`1nG2h207eK;@0807]I:`1kFB`0NUP[07YG;@1i
ERh0N5D_07QD<01gDbl207AD;@<0Le</0`1bDR/00`1]Cb/0K4hZ06]=:@0206Y<:00306a>:P1^D2`0
Ke4]0080L4hX00H0KddW06i<9P1_CBL0L4hX079@:P1dDR`207QE:`0407UF;01jEbd0NeP^07aI;`80
OEX`0P22GC0208=N<@0408AO<P25H3<0QV4d08IQ=0<0RF<d0P2:I3D308]U=P<0SFLh0P2<ISL408]U
=Q00SFLh0P2<IST308eW>P<0SVPk102>JCD408mZ=PP0TVLj0P2?JCX208iX>@80SFLh0P2<ISL808UU
=@@0RfLg0P2:ISH208UU=@80R68m00@0R68k08QS>@28HcL0R6<f0P28I3@808QS=PP0QV8b2021G2l2
081K<@03085L<P22GC<0Pehd0080Q5le00<0QF0f07mL<P1oG3800`1nFc4307eJ<080Ne/b0P1jFS40
301iFC00N5P_07QH;`1hF2l0OEL`07YG;`1iERh0MeH]07AD:`1aE2X0Ke@Y06iC:080Le4[01@0LU8[
06mB:P1]DBT0JU4X06U@9`1XDBL0K4h/06]=:`1ZCB/0JD`Z06E;:01SBbL0HT`W065;9P1OB2P0GTLX
05Y59P1GA2H0DT4U050o9@80CCdT00L0BcdS04dk8`1<?2<0Bc/R04Xl8P17>b40AC/P0080@S/O00H0
?cPL03lh7P0n=ad0?CDN03`d7`0k<b0203/b8@0803Hd7@0e<a`0=38M03<`7@0a;Qd0<BhO030]7P0`
;20302TY7`80:2PN0`0W9ad302@U7@<08b@L0P0R8a/8024T7@/07R4J0`0O8Q/2020S70@07b8K100N
8AX201lR6`<082<L0`0Q91d202<U6P0302@V6`0U9a`09RPM00809bTN0140:2XO02da800^<R40;c8Q
030a8@0c<B80=34R03Db8`0g<B<0=3DS038c8`0_<200;2dO02TY7@0V9Q`092@L02<S6`0802HV7P80
92DM200S91`4028S6`808B8J200P8A/03`0Q91/082<J020Q6@0Q8AT0924J02LR700Y91h0;BHP02hV
6`0_9A/0<2HJ03DY6`0i;1`0?blO04<b8P0204Dd8P0I05<k8@1E?B40FT4S06599`1[DB`0M5/b07iS
>023J3/0SVe:091_C02CMDl0VWeC09j2D`2KPDh0TgY408ac>`1/CR`0GT<U04/f6`0l;AP0<B/M02//
900U;R/08bd/02TZ8P0302X[8`0402//900/;BD0;2dU02`]9@80:R/S0`0[;2@302`]9@<0<BlS00<0
<S0T03<a9@0c<BD00P0d<RH203<d9P@0=3DW0P0e=RP0200i<RP0>34W03La9@0g<B<0>C<S03dh9@11
?2T0A3l[0P13>R/01013>RT0@SXW048j9@12>R<2044j800804Ti:@19>RL0BS/X04Xn:01;?bL0CD4W
04i5:01?ART205519`80DT8X0180Dd<Y05A4:P1EAB/0EDD[05U9:01OC2`0He0_06A@;@1TCRT0IThZ
06]A;01_ERh0KE<^06eE;`1^ES80KUPc06iJ=`1^FcX206aL>`0506IF=01XEC@0J5Dd06UF=@1ZESD0
0P1[EcH07`1/F3L0KeLc071H=01cFS80Melc07aQ<P20I3@0Q6Hb08IX=02=KC80Tg0f09Qf>@2IMCT0
VW@f09]c=@2OMSP0XgXl0:1h>`2LM3L0Ug0e09=_=@2BKcT0SVXf08IU<P1oGb`0MV0a07EN<P1cG300
L5T_06eF;@1[Dbd00P1YDBd0101[CBL0K4hX06e?:@1^D2X306mA:`0B071B;01`Cb`0L4l/079A;P1c
EC40LeLb06mE<01ZDR`0I4hW061:8`1SB2/0I4T[06Q;:`1ZC2X0KD`Y06i<9`1^C2H0Kd`T0P1cCR@0
4P1dCbD0MU4W07UD:P1mF2h0P5/a089M<`1oGR/0P5l/08EQ;@28Hbl0Rf<_08aS;`2;HR`0Rf0[095]
<`2BKS@0U70f09Ib>080Ug<i0P2FLSP00`2GMCP0V7Hi09Ug>P0209Ug>P0309Me>02ELcH0Tg4d0080
UW<k01H0UG8l09=_>`2AKC/0SFTi08UU=@27HSD0S6/f08UX<`28Ic80RfXe095`>`2DLch0Tg8m091_
>P2CLR/0TW4Z099a;02AL2d0Sfd]08i/;@2>K2l0SF/^0P28Jc<01027JS80QVTa08EX<024Ibl2089U
;@80Pf<`0P22HRl2085Q;P80P60]0`1nHS8307eQ<@80O60`0P1kH3<0101jGc80NEha07QM<01hGC02
07ML;`80KUT/00<0KEP]06aF;@1[EBh00P1ZE2l01P1YDS00He<_069B;P1QDBd0H50/05m?:`80GThZ
00L0GDdY05iA;P1NDBh0Ge4^061@;P1QDBl0He0_0080I50_00@0I50[06EA;01VDRd0JE<^0P1ZE2l0
2P1ZDRh0JE4]06=D:`1PDBP0Fd`U05M78`1DA280Dd<R05A48`1EA2H304/o9@0304Xn9019?B<0B3`R
0080ASXP1015?1l504Hm80P0@CXN00P0@S`J048l7012?1`0@S/N044j7P10>Al0@3PQ03lg8080?SXO
0P0m>Ah403`h7@80=CLO0`0d=Qh303<e7@80=3HP100c=Al2038d7P80<C<K00<0<38L02la700^;ad0
0P0];Qh01`0/;Al0<C0N034`7P0^;ad0;2lL02/^6`0Y;QX00P0V;QT302<V6`<092LL0P0U:1d201dT
700301`S6`0K8QX06R4I00806B0H00<061lG01PN6P0H7QX01P0H7QX201/M6P<06Q`I0`0I6aP201HH
5`<05aTH0`0H6QTH01LI61005QPG200G6APY01HH5`P05ALF400F61L801DF60P05QPG200E5QP801HH
5aP05AHH200F61L@01HG6@P05QPG4@0G6AP301TK6P<06Q`K0P0K7A`0100O8B007AlN01/M700H6QT3
01LI600301PJ6@0J71/06Q`K00H06Q`K0`0J6QP301/K6@X071`J200M7QP801`L6PP07AhH200O7QT3
020P60<08B4I0P0R8QX302@T70<08b<K0`0R8QX01`0S8a/09BDM02HV7P0W9al09RHN02DU7@0T91`0
200Y9A`00`0W9ad09RHL02@T6P0202<S6@0302@T6P0V9Q`09bLM00809R4K00<09B0J02@O6@0T7aT0
0`0T7aT802@T70808R8J0`0S8a/302@T708092@J1`0U9A/802DU7@808R8J0`0S8a/302@T70<0:B@N
0P0X8ad302TT7P0602T[800Z:R00:BTO02/X7`0[9ah0;BHN0P0]91d02`0e:A/0=RXL03P/7P0i;Al0
>RhP03T]7`0h;1h0=b/M03T/700j;Ad0>bhN0080?2lO00<0>bhN03T/700h:a/00P0l;a`0100m<1d0
?S4N03lb7`10<b02044d8@0604<i8015>B40ACTQ04Lh8@19>B80BSPR0P1=>2<304`j8P80BcTQ00<0
BCLO04Pf7P18=Qh00P17>2401019>B80BSPR04Xh8P1=>2<204hh8`80AC<M00H0AcDO04Pf8019=b40
BcTS04`j901=>bD2050g8@0404hh8@1=>B40BcTQ04Xj8@80BC/Q0P19>B0204Ph7`0404Lg7P16=Qd0
ASHM04Hf7@80A3LT00@0@cHS048e8P11=240@3<P0P0o<Ql00`15=Ah0ASHO04Hf7`0404Hf7`0904De
7P14=Q`0A3HL04@e7P13=1l0@S<P044a8@10<200@30Q00<0>bhN0P0j;Ad303/^7P80?blP00H0@30P
044b7`11<Qd0@S<L04<d7@13=A/2048f7003044e7@11=Al0@3<P00<0@3<R00<0@3<S03lb8@0o<R40
1P0o<R44040c80@0@C@Q0P13<a`204@d7@80ACDN0P16=Ql804Ti8P80@CHP00@0@3DO03ld7P0n<ad0
?C8L0P0l<A/303`_7P@0?C0O00@0?S4P03`_700m<1d0?c8O0P11=2400`10<b00?c8O03ha7P03044e
7`<0@3@N0P0o<ad803hc8@80@3@N00H0?c8O03ha800m<1l0?2lO03`^8@0k;B0303da8@80?30P0`0k
;al01P0l;R<0>bdR03X^8P0h;R80=blR03D_8@80<c0Q00h0=30T034]8@0]:Ad0:RHJ02TU6@0[9a/0
;b/O034]8@0b;200=2`O03D]800g;Ql0>RhN03`_7P80?RlL00<0?C0O03ha800n<B000P0o<R42040c
8P0:044d8`10=B<0@C@Q048e8P15=R40AcLP04Tg7`1<>1l0CCTP04hh8@<0CCLP0P1<=Ql204/e7P<0
ASHO0P15=Ah304@d7@0604di8@1>>R80Cc/S050l901A?BD0D3`T0P1>>R800`1=>B40Bc/T04/k9002
04Xj8`0404Ti8P18>240AcLP04Lg80@0@34N00@0@C8O048c8012<b00@c@Q0P11=2<2040c8P<0?c8Q
00<0?S4P03L^7@0g;Qd00P0g;Qd403P_7P<0=2XN0P0e:al303@Z7P0603L[6`0h;1`0>BdM03X^7P0k
;al0?30P0P0m<B400`10=B<0?c@R03db800203`a7`0903db800o=280@3DS03lc6`10=1`0@CDM048f
7P13=al0ACTQ0080ASXR2016=B<304<d8B_ooooo000Zooooo`030:AjB02RN4H0XGM50080X7I400<0
XGM50:9hAP2TNTP00P2TNTX0102TNTP0Y7]70:AkA`2TNdD20:Ak@`060:QmBP2WO4T0Yga90:IkB02U
NTL0Y7U60P2SN4D30:ImB@80Ygi:0`2XOd/80:Z0CP80Z81=1P2WOd`80:QoB`030:MnBP2XOd/0Z7m;
0080Z7m;0`2YP4`00`2WOTX0Z7m;0:Z1C@020:^2CP030:Z1C@2YP4`0Z7m;0080ZGi9102ZOdX30:^0
B`<0ZX5=0`2YP4`20:QoB`80ZH1<0P2ZPDd20:^2CP80[8=?202YQ4l@0:^1C`80ZH1<00@0Z7m;0:Mn
BP2WOTX0YWe90P2UO4P0202PNT/0WgU:09miBP2MMdP0W7I709]eAP2JM4D0VG=40P2IM400102HLcl0
Ug8n09Ia?@2EL3`209A_>`80TFdm00@0T6`l08m[>`2?Jc/0SVXj0P2=JCT208YU>00408UT=`28HcH0
Qf8e08IQ=080QF0c0100Q68d08=Q<`22H380PEla081N<01oGBl0OU`^07eK;@1kFb`0NeX]07YI;01i
F2d0N5L^07ME;`1fE2l0ME<^0`1dE2d307=C;080LU8[00<0KDl[06a>:P1[CBT00P1ZC2P02`1/CRX0
KU0/06mA;@1_CbP0KThW06e=9P1/C2D0KDdV06i>9`1`D2T0LE4Z0080Me@/00@0N5D]07UF;P1jEbl0
NeP`0P1lFC42085L;`04089M<023GS40Q5lb08AO<P80QF0c0`28HS<208US=0<0RV@e0`2=IcP208aV
=`@0RfDf202>J3T808eW>080S6Hi0`2=IcX308iX>`@0SfXf102>JCD8095V>@<0SVPi0P2=IcP308aV
=`P0RFDe102;IcL208YV=P80RFDe0P29Hch01029Hc`0RF@j08UT>029I3L208UU=@P0Qf8e2026HS88
089M<080P5/a00<0PE`b089M<`23GS@00P24GcD00`25H3H0Oe`b07mL<P0307iK<@<0OEX`0`1jFS44
07UI<00707QH;`1mF2h0NeP^07YG;@1hEb`0MEHZ079E:@02071E:080M58/00<0LU8[06mB:P1]DBT0
0P1ZDBP01`1YDRP0KTd/06i=;01[CB/0JD`Z06M=:P1VC2T00P1TC2P01P1QBBL0H4LX05e69P1IA2D0
ET<U05919@80D3lU00L0CShT04hl901=?B@0C3`S04Xl8P17>b40AS`Q0080@c`P00H0?cPL03lh7P0o
>1h0?SHO03de800l=24203/b8@80=C<L00H0=38M03@a7P0c<1l0<RlP034^7`0a;B4202XZ8080:BTO
0P0X:1h202LW7@809BHN0`0T9Ad302<T70P08RDN2`0N8AX301lR6`8082<L00<08B@M020S700P8a`0
0P0O8Q/201hQ6P0401dP6@0O8Q/07b8K01lR6`<082<L0P0Q91d2028S6`0302<T700T9Ad09BHN0080
9RLO00H09bPP02da800]<B00;S4P030a8@0b<24203@a8P0903H`8P0e=b80=3DS038c8@0_<200;2dO
02TY7@0V9Q`092@J00P09RHN0P0S91`802@U7@808b@L0P0R8a/2024R6PP0824K0P0P8aX03@0P8AT0
8B4I02@Q6P0W8Q`0:B@N02`U7`0Z9Qd0:b@L02`S6P0]9AX0<BLK03L[7@0k;B000P0n<B406018=R00
BcLO04hh801E?B40GD@U06U<:P1bES40N5Xd081S@@29KDP0U7QA09aoD`2LP500Vh1909f0B02NPDL0
UVa208=M=P1VB2H0C3LL03T^6P0^;1l0:B`U02D[9`D0:b`T0`0/;BD302X[8`<0:b`T0P0/;BD00`0^
;R@0;blU02l_9@0202l_9@<0<30V00<0<S<U03<d9P0c=2H00P0d=BL203Df:00903Hg:@0i<RP0>34W
03H`900f<280>38R03/f8`0n>BH0@C`X0080@CT/00@0@3TY040i9`10>BH0?cTS0P0o>B401P14>BL0
ACXV04Pk:01:?RP0C40X0512:080DD<X0P1@@2H0101A@BL0DT8X05=3:@1DA2X205E5:`0@05M6:01M
BR`0HDh^06=?;P1SC2X0I4`X06U?;01]Dbh0L5@/06iE;01_ERh0KeLa071J=@1`G3L0L5hj075O>`80
K5Pe02H0KETf06iJ=`1]FcL0KU`h06eK=`1[FcL0KePf071J=@1bFS@0ME`c07YO<P1lHC80Of<a081U
<028J3D0SF`g09=`>P2DLCT0U70f09Qb=02NMSP0XWXl0:=i?`2OMC/0Vg<h09Yc>P2HM3X0U74i08eZ
<P25I2h0NF<b07QR<`1fH340Le``071I;`1]ERd0Je<]06UA:`80KE4/00<0K50[06]?:P1ZCRT00`1Y
CBP206m>:`0?075@;@1bE300LeLb071F<@1[Dbd0IDlX069<9@1SBR/0I4//06I<:`1YC2`0JT`Z06]:
:@1ZBBH0JdTV00<0KT`V00X0KddW075?:@1eDbd0NELa07]I<`1lFBl0OU`_089M<026H340RV8a0P2;
HRh0302<HB`0S6L`08iY<P2@Jc@0Tfhg09A_>02CKSL0TVdf095/=@2BKcD0Tg0f09Eb>080UW<i00<0
U74g09=`=P2BKcD00P2DLCT03P2CL3X0TVhj08m[>@2;IcL0R6@d08EP<`27Ic@0QFDb08=S<026IS<0
S6`i08m_?02>KS/0Rf/h0P2>KBP0302=K2T0SF/[08aZ:`2;JB`0RVP[08YW;@26J3@0QFLc08=U<@22
I300P68^07mQ;@80OV0/0`22I383085S<@80P68`101kH34207YO<080NEh_0P1fGS8207EM<@0407AL
<01cFbl0LUX^079J;P80K5L/00H0JeD/06YD;@1YDbh0J58]06QA;`1WD302061@;P0405m?;@1NCR`0
GTh/05e=:`80G4`Z0P1ODbd0101PDRd0HU8^06=C;`1UDbl206MC<00C06UA;@1ZDRh0JU@_06]E<01Z
E2l0IU8]06A@:`1RCRT0Fd`S05U:8@1GB240EDDQ05E58`1FARD0F4PW05U8:P1:?R@0BCdS04Pl8P02
04Lk8@<0ASXP1`15?1l204@k7P@0@3TM1011>Qh01P12?1X0@S`L044k6`10>A`0@3TM040i7`80@3PQ
0P0m>Ah303`h7@<0>cLL0`0d=Qh303<e7@80<S@L0P0d=R0203<e7`80<S@N0P0a<ad0200a<a/0<38J
030b700_<A`0;RlM02d^7P0/;Ad0;2dO0P0`;Ql0100];Qh0:bhM02X]700X;1/202D/6P<08bHK0`0T
9a`202DX7@0601dT700L8a/072<K01/R6P0J8AT06B0H0P0H7aL801PN6P806adJ0`0J71T301TK6080
5QPG0`0G6AP301PJ6AP05aTH400F61L801LI62T05QPG200E5aH@01HH5`P05AHH200F61L801DF60P0
5QPG600E5QP801HH5a005QLI200F61LA01LI60<06A/J0`0J71/201/M700601lQ800N81l06adL01TK
6P0H6QT05aTH0P0H6QT801XL6`<06QXH0`0K6aT:01`L6P@07AhH100N7aT801`L6PP07QlI200P7aX3
020P60<08B4I0P0R8QX302@T70<08b<K0P0R8QX00`0Q8AT08R8J02@T700302HV7P0302DU7@0T91`0
:2@K00L0:2@K00<09RHL02DU6`0S8aT00P0R8QP00`0S8aT09BDK02HV700402DP6P8091lI0P0S7QP8
02<S6`808R8J0`0S8a/302@T70809BDK1`0T91X802@T70808R8J0`0S8a/302@T700302PS7@0Y91h0
:B@N00@0:B@N00L0:2<M02PZ7`0Y:Al0:2PN02XW7P0[9ah0;BHN0080;B@M00<0=2PL03DY7@0g:al0
0`0i;B401@0h;200=b/O03LZ6P0h:a/0>RdM0080>bhN00<0>RdM03T/700h:a/00P0m<1d0100n<Ah0
?c8O03lb7`10<b02044d8@0604<i8015>B40ACTQ04Lh8@19>B80BSPR0P1=>2<0101=>b<0C3XR04/i
8@1:>20204Tg7`80B3HN0P17>2<01019>2@0BSPT04Xh901=>2D204hg9@0604Dc7@16=1h0AS@N04Pf
8019=b40BSPR0P1;>B<204dg800404`h801:>200BCTP04Pj8080ASXP0`17=ah404Hf7@0504De7013
=R<0@SDR048e8P11=2400P10<b0203lb7`0304Df7`14=Ah0A3DN00@0A3DN00T0ACHO048f7P12=Qh0
@CDO040c800o<R40?S4P03ha8@0n<2<0200j;Ad203`_7`0603d`7`0n<Ah0?c<M040d7011=Ad0@CDK
0P10=1`00`10=1h0@3<P03lb8@0203lb8@0303ha8@0n<2<0?c8Q00L0?c8Q0P0n<Ah203lb7`80@3<P
0P11=24304<c7080A3@M0`15=Ah804Lh8`80?CDP0P0l=1l0100k<ah0>S8M03Ta700i<A`203X]7080
>bhM00`0?2lN03d`7`0m<1l0?C0O03/^6`0m<1d0?c8O040c8011=240@3<P03lb7`0n<Ah2044d8@<0
@3<P0`0o<Ql403hc8@@0?C8P00H0@3@N03lc7@0o<Ql0?S4P03d`7`0l;al203/]8080?C4Q0P0l<203
03/_7`0703X^7P0k;B80>bdR03X^8P0g;B40=BdP03@^8002034^7`0303<_8`0`;200;2PL0080:BDI
00@0:bLK02l[7`0a;B40=2hR0P0e;B000`0g;Ql0>RhN03`_7P0203l`7@@0?S4P100o<R402011=R@0
@SDR04<f8`15=R40AcLP04Tg7`1;=ah0C3PO0P1<>20204/g7`<0BSHN00@0BCDM04Hf7`16=Ql0ASHO
0P15=Ah304@d7@0604di8@1>>R80D3`T054m9@1@?2@0Cc/S0P1>>R800`1=>B40BCXU04Tj9@0204Pi
900404Lh8`16=b80ACHQ04Df8@80?C0M00<0?S4N03lb7`0o<Ql00`0o<Ql3040c8P80?c8Q0`0n<B08
03H]700303@Z7P0c:Ad0<bTM00@0<bTM00`0=2XN03HZ6P0f:QX0>2`L03T]7@0k;al0?30P03da8@0n
<R80?c@R03hc8@0m<R0203/`7P0303db800n<b40?c@R0080?c<K00H0@3@L048f7P13=al0A3PP04Di
8@16>R8804@e8P<0@3<P:oooool002[ooooo00<0Y7Y80:9hAP2QMdD00P2PMT@00`2QMdD0XWQ60:Aj
B0020:AjBP040:AjB02TNdL0Y7]70:AkA@80Y7]30`2VNdP30:EjA`80Y7U60P2VO4X20:MmB`<0Z7i<
2@2YOdd20:N2CP80YX5=102UP4`80:QoB`P0ZH1<00<0YWe90:QoB`2YP4`00`2[PTh20:V0C080ZGi9
102ZOdX30:^0B`<0ZX5=0`2YP4`20:QoB`80ZH1<0P2ZPDd20:^2CP80[8=?202YQ4l@0:^1C`060:Z1
B`2YP4X0ZH1:0:QoB@2WOTP0YWe70P2UO4H20:1jB`0409miBP2NN4T0WGM809afA`80VgE600H0VWE1
09Ud@02IM400V7<o09Mb?P2FLCd209E`?006099^?P2AKCd0TFdm091/?02?Jc/0SVXj0P2=JCT208]U
>00408YT=`29HcH0R68e08QR=@80Qf4d0P23HC<01022H380PEla085O<@20GS0207mM;`0607YK;01i
FR`0N5T[07MH;01fERd0M5@]0P1cDbd207EE;P80M5@]0`1cDb`0101bDR/0KDl[06a>:P1[CBT206Y<
:00606a>:P1^D2`0Ke4]06iA:@1]D2P0K4lW0P1[CRH0101/CbL0KE0X06iA:@1fDbd207MD;P0307QE
;`1iES00NULa0080NePb0P1nG2h00`1oGBl0P5h`085O<@02089P<P0408=Q<`27HC80Qf4b08MQ<P80
R68c0`29Hc@308eW>080S6Hg102;ICH808iX>@P0SFLh0P2<IST308eW>P<0SVPk00@0T6/g08mZ=P2?
JSH0SfXf0`2>JCD00`2=J3@0TFHi095V>@06095V>@80SVPi0P2=IcP308aV=`0308]U=P2:ISH0RVHf
00T0RVHf0`29ICD208QT=080RF<n00@0RF<l08UT>P29I3P0RF@g0P29ICD808MR=@P0QV8b2023GS42
085L<P<0PUdc0`23GS@207mL<P<0OU/a0`1mFS0807UI<00=07eH;P1kF2h0NUL]07QG;01fEb/0LeHZ
079G:P1aERT0ME<]07AB;01aDBX0KU4Y06a@:00206YA:00606UB:01_C2`0Kd`/06i=;01[CB/0JTd[
0P1WCBX01`1VCRX0HdTV06989`1PB2H0GDHV05Q3901E@R@00P1C?b@02P1@?b<0CcdU04hn9@1=?B@0
BcdS04Pl8P16?240A3dQ04<l8010>Ad2040i7`05040h8@0o=b80?SHS03`c8P0k<R400P0d<Q/01P0e
<ah0=C8O03@a800c<240<RlP034]8@<0:RXP0P0Y:Al302PX7P<09BHN0P0T9Ad302<T70P08bHO2`0N
8AX301lR6`8082<L00H08RDN024T7@0Q91d082<L01lR6`0N8AX201dP6@807R4J0P0O8Q/3020S7006
024T7@0Q8Q`08B8L028S7@0S91h092DO0P0U9R004@0V9b40:blN02``7`0]<1l0;RlO034_800b;b00
<c0Q03D_8@0c=Al0<cDP038d7`0a<R00;c0P02`]7`0Z:Qh0:2PL00P09RHN0P0S91`302@U7@D09BHN
00@092DM02<T700R8a/08R<K0P0Q8QX801lP6P0?020S6P0O8QT07b0H020P600S81T09R4K02PS7@0/
9Al0:2DP02LT7`0W8Q`0:B8J02`S6P0a9ad0=B/O0080>BdQ01P0@34N044b7`15<ad0C3HN05Dk8P1O
@BD0ITLX06a;;01cG3<0OfHm08eeB@2ENT/0UWY809Mi@`2LODH0X8580:YnD@2IKdD0Oe`f06E:;01A
?bL0@SLU03@a8P0^;20202d^9P80;2dU0`0[;2@00`0Z:b<0:BXR02TZ8P0202X[8`<0:b`T00<0;2dU
02d^9P0];RH01@0];RH0100^;bL0<C8T034b900b<bD203<d9P0303@e9`0e=RP0=CHX0080>C8X00L0
>38V03Pb900h<R80>SDR03/f8`0l=b<0?SP/0080?SPZ00<0?SPX03hi9P0o>RH00P0o>R@02011>BH0
@c/V04Ll:01;?bT0D44Z0592:@1C@bT0E4<Y0P1A@BL0101B@RP0Dd<Y05A4:P1DA2X205E5:`0F05I5
:@1LB2d0H4d_065<;@1RBb/0Hd/Y06Q>;@1/DRl0LE@X071E:01`EBX0KeH]071I<01bG3D0LUlg07=O
>P1bFSH0Le/g07AN>@1cGcX0LV0j071Q>P80KV0i02D0KUXi06mK>01bG3L0MEhe07MO<`1kH340O68a
07eQ;`24HcH0R6Pi08e[>`2?JcL0Sf`d099^<P2JM3H0WgTj0:Eh?`2RMC`0WgDk09if>`2ON3d0VWHj
09=_<`2<JRd0O6Hd07]U=01jI3<0N68c07AM<@1`FBl0KEH]06]D:`1_DS00KU4_06a?;@1ZCB/0J4/Y
00<0IdXX0P1^CBX0;`1`Cb`0L58^075E<01_EC00K5@^06UC;01WDBX0IDh/06A=:`1UCB/0ID/Z06M:
:P1XBBX0JTP/06]9;@1^D2`0K4hZ06]=:@1ZC2P0JddY06i@;01bE300M5Hb07MC;`1iES00OUPa08=L
<@27GS00REl]08UP;02:GbX0Qf8]08UT;`2<Ic80SfXe091[=P2?JSD0SFPc08aW<P2>JC80SfXc095/
=@2BKCH0Tfhg099]=P2AK3D0T6/d0080T6de00h0T6dg08iZ=P2<J3H0RFDe08IR<P24Gc80PfDc081R
<01nH2h0PF<a08IX=P29JcT0QfTg08AV=080RFLZ00`0R6D[08QU;@27I2h0Qf<_08IR;P26HS00PV<d
085R<`1oH340OEh_07aM;P1kG2d207aM;PP0OV8b0P1jGc8207UN<@80N5d`0P1gG2l01P1cG380LU/a
079K<@1aFS00L5T_06mH;P80KUL]0P1ZE2/0101YDb`0J58]06QB;@1WD2h206I?;`P0G4d/0P1ODb/0
101QDb`0He@]06=D;@1VE2h206QD;`0806eC<01^E340KUHb06aF<@1XE2l0He4[05m=9`1JBb@205A7
7@0305A67`1EAb80EDLT0080ETLV00@0ETLX04Xn9019?B<0Ac/Q0`16>R0204Lk8@<0AC`O0`14>ah3
04<j7@<0?cPL0P10>Ad3044j7P0604<m6`12?1`0@3XJ03lh6`0o>1`0?cPN0P10>24303`h7@80>cLL
0`0j=Q/303@f7P80<cDM0`0b=1`203<e7`80<S@N00@0<C<M030b700_<A/0;c4K0P0`<QX00`0_<A/0
;S0K02d^700202`]7@0902//7P0_;B00;bdP02`]7`0Z;1h0:B/M02L[700U;1`092/K00L092LL00H0
8bHK01`S6`0L8a/06b8J01XQ6@0I81P201PO5`0301LN5P0H7QX061hJ00H061hJ0P0K7AX301XL6@<0
6A/H0P0F61L301LI60<061XI600G6AP@01HH5`P05aTH:@0F61L801DG5Q005QPG200E5QP801HH5`P0
5AHH200F61LH01DF60P05QPG400F5aT801HH5a405aTH0`0I6aX301XL6`806adL00@07R0O01dO7P0K
7A`06A/J0P0H6QT00`0I6aX06Q`K01XL6`0701XL6`<06QXH0`0K6aT201`L6PP06a/I0`0M7QP201hO
6@<07b0J200L71X801hO6@P081lJ0`0P81P3024Q6@808R8J0`0T91`302<S6`808R8J00P08B4I028R
6P0T91`09BDM02HV7P0U9Ad092@L02<S6`P09b<J00<09BDK02@T6P0R8QP00P0Q8AL00`0R8QP092@J
02DU6`0202DP6P<09R4K00<09B0J02<N600R7AL0200S8a/2028R6P<08b<K0`0T91`202DU6`@092@J
0`0S8aT802@T70808R8J0`0S8a/302@T700302LR700X8ad0:B@N0080:RDO00T0:B@N02PS7@0W8Q`0
9BLL02HV700W9ad0:BHM02/W7P0]9Qh00P0_9Ql02`0d9ah0=BPO03LZ8@0h:b80>B`S03P[8P0g:R40
=RTP03HY6@0g:QX0>B`L0080>bhN00<0>RdM03T/700h:a/00P0m<1d00`0n<Ah0?c8O040c8002044d
8@07048e8P12>1l0@cLO04@h8016=b00B3PQ04Tg8@0204`g8P0304`j8P1;>B40BSPP00<0B3HN00D0
BCLO04Xh8017>2D0AcPU04Th9P0204Xg9P0304dh9`1>=bL0CSLW00<0B3HP0`19=b4204Xh8P80BcLO
00<0BCLO04Ph7`17>Al00P15>Al00`14>Ql0ASHM04De700604De70P0@3<P00<0@cLO048f7P11=Ad0
0`11=Ad02012=Qh0@cLO044f8010=Al0?S<O03db800l<Al0?30P0P0l<2800`0i;1`0>RdM03/^7P03
03/^7P0:03X]7@0i;1`0>blO03/_7`0l<Al0?C8N03hc7@0n=1/0?cDL03le6P80?c<M00<0?c8O03ha
800n<B000P0m<20203d_8PP0?S4P00H0?2lL03d`7@0m<1d0?S4N03lb7`10<b02044d8@04048b6`13
<a`0@c<L04<c7080A3@M0P15=Ah304@g90<0@cHS0P12=B8203`d8@0303/c800j<Ql0>C4N0080>30M
00<0=blL03T/6`0i;1/00P0j;A`01`0k;Qd0?2lN03d`7`0m<1l0>bhK03`_700n<Ah00P10<b00100o
<Ql0?S4N03d`7@11=2<3040c8P80?c8Q0P0n<B0303hc8@80?C8P0`0l<Al203lc7@0603ha7P0m<1l0
?2lN03/^7P0k;B00>R`O0`0k;al203X^7P<0>BdM0P0j;240100h;200=B/O03<[7P0b;1h202l/7@03
030/800^:Qh0;2PL0080:RHJ00@0;2PL02hZ7P0`;200=2hR0P0d;1l01@0e;1d0>2`L03/^7@0o<1d0
@34N00P0?S4P00H0@CHT04<f8`13=R<0ACHQ04Lg8019=al204/g7P80BCLO0P18=Qh304Le7@0404Hd
7017=b00AcLP04Lg8080ASHO0`15=Ah01P1>>R80Cc/S050l901A?BD0D3`T04lk8`80CCTQ00L0C3PP
04Hi9P15>2D0ACPU04@g9013=R<0@SDR0080@C@Q00D0>c0L03`a7@0m<Qh0?S<O03ld800203hc7`03
03db7P0o<R40?c8Q0080?S4P0`0m<1l00`0l;ah0=RdL03H]700203D/6`@0=2/J00<0=B/O03@Z7P0c
:Ad00P0b:1`0100c:Ad0=2XN03D[7`0f:QX203L[6`0803T]7@0j;Qh0>blO03``800m<B40?S<Q03db
800l<Al203/`7P0303`a7`0m<R00?S<Q0080@3@L0P11=Ad01012=Qh0@cLO04@h8014>208040c80<0
@3DQ:oooool002[ooooo00<0Y7Y80:9hAP2QMdD00P2PMT@00`2QMdD0XWQ60:AjB0020:AjBP040:Aj
B02TNdL0Y7]70:AkA@80Y7]30P2TNDH30:EjA`<0YW]80`2WODd30:QnCP80ZGm?202XOT`00`2XPdl0
Yh9>0:N2CP020:J1C@80YH1<00<0Y7m;0:QoB`2XOd/01P2XOd/80:V0C0030:ImB@2WOTX0ZH1<00<0
Zh9>00@0ZX5=0:V0C02YOTT0ZGi9102ZOdX30:^0B`<0ZX5=0`2YP4`20:QoB`80ZH1<0P2ZPDd20:^2
CP80[8=?202YQ4l80:b2D0P0Zh5?0P2ZPDT00`2YP4P0Z7m70:MnAP020:ImA@030:ElA02PNT/0X7Y;
0080WgU:00@0WWQ909egB02MMdP0W7I70P2JMD4209Ud@00409Qc?`2GLSh0UW4m09Ia?@80TVhn00<0
TFdm091/?02?Jc/00P2>JSX01`2=JCT0SVDi08eT>02=I3P0S6<g08]R=P2:HCD00P29H3@2089P<PH0
PEla00H0NEX[07QI:`1gF2X0MUL[07AD:`1bDR/2075A:`<0MED^0P1dE2d307=C;00306e?:`1/CRX0
JddY0080JT`X00H0K4hZ06i@;01_DBd0KU8Z06eA:@1/D2P206Y>9P0306]?9`1]DBT0KU8Z0080MU8^
0P1gDbl0101hE300NEDa07YF<P1jES8207aL;@0307eM;P1nGRl0Oel`0080P60a00<0PF4b08IP<@26
H3400P27HC8308QR<`0408US=02=IcP0SFLh08eW>080S6Hg102;ICH808iX>@P0SFLh0P2<IST308eW
>P<0SVPk0P2@JcL208mZ=P80SVTe0P2=J3@8091U>0<0SFLh0`2<ISL208]U=PP0S6Ph0P29ICD308QT
=0<0Qf<c0P2:I3l0102:I3d0RVDk08YU>@2:ICP208YV=PP0QV4d2026HS8808EP<`<0Pehd0`22GC<2
085L<P80Oe`b0`1nFc4307eJ<0H0NET`0P1jFS401P1nFBd0NeT/07]I;01iF2/0MePZ07AH:@80LePY
00P0MU@^07AB;01aDBX0KE0X06]?9`1YD2L0JU4X06YC:@80L4`/00<0Kd`/06i=;01[CB/00P1ZCB/0
1`1XCR/0ITTW06=99P1RB2L0GdHW05]49@1G@R<00P1D@B<06@1C@280D3hV04lo9P1>?RD0C3hT04Tm
8`17?B80AChR04@m8@10>Ad0@3TO044j8011>B80@3PS03hf8`0l<b80>c8Q03<a6P0d<Q/0=C<N03Hc
800f<b80=34R038_800a;B40100Z:R0202TY7`80:2PN0P0V9al202DV7P<092DM00<08b@L02<V7`0S
9Ql01P0S9Ql;01hQ6P<07b8K0P0P8a`01P0S9Ql08RDN024T7@0P8a`07b8K01hQ6P807B0I0`0N8AX2
01lR6`<082<L00H0824L024R7@0Q8Qd08R<N02<T7`0T9B0202DV8@80:RhM00h0:bhM02`]7@0_;Ah0
<2dN034^7`0c;Al0<38L034c7@0b=1l0<S<Q038c8`0`<B40;RlQ02`]7`P09bLO0P0S91`202@U7@80
9BHN100V9al01P0U9Qh092DM02<T700R8a/08B8J020Q6@P07b0J00l082<J01lR6@0O81P0820H02<P
6@0V8A/0:2<M02/T7P0V9b809B@P02<R7@0T8AX09b<J02dV700b:B000P0e;B80800i;Ad0?2lO044`
7P18<b00CcHP05Li8@1L?B40H3hS06UE8`1aFbX0OFHd08U_?P2BM480UgM609UhA@2LN4H0YGY?09id
BP2BK4D0PVA2079I>`1MC380BS/V03`_700`<BT0;c0X02h_9`0];RH0:b`T02X[8`0Y:R80:2TQ0`0Y
:R8202X[8`<0:b`T1@0/;bP302/^9`80;c0R00@0<34S034b900b<bD0<c@V0P0d=BL0200j<bT0>c@Z
03/e:@0k=BL0>cDU03Td8@0h<b00=c8N0P0k=b/203`i:P0:03dj:@0n>bP0?cdX03lm:00o>RH0@S`V
04Hn:@1<@B/0DD8[05A4:`80Ed<Z0P1B@RP00`1C@bT0E4@Z05E5:`0205I6;00a05M7;@1EA2X0FdL/
05m;<01PBbh0HDX[0699:P1WCB`0Je4`071D901`E2D0Ke@U06iF:01_F2`0LE`a07AN=@1dHCL0Medh
07QN>@1iHC/0Mf@l07MU?@1cIS`0LFDk071T>P1`GCd0L5dl079N>`1dGSL0MUle07QP<P1iHC40Nf4`
085Q>P24I3/0R6Lj08UW=`2;J380SVX`09A`<P2LMSL0YGI00:9e?P2RMC`0XWPn0:Al?`2QNcd0V7De
099_;`0207mY=`0907iX=`1lISL0N64e07AM<`1`FBl0KEH]06]A<01ZD2l0J4h]0080IT`[00<0Idd/
06Q>;@1YCbh00P1^CBX01@1_CR/0KU0/06mC;P1^E2l0KED_0080KEL`02@0IU8_06I?;@1SC2X0HTTZ
06=8:P1WBBd0JT/_06a=<@1bEC<0Ke8`06a?;@1ZCB/0JD`Z06]>;01^DBl0L5<a071;;P1cCbl0N58^
07eF;`21F2`0Q5XZ08AK9`25FRD0PUdY08AO:`28Hbl0RfHb08aW<`2;IS80RF@`08MR;P2;I2d0S6D^
08iW<02@JC82095Z<`0B091Y<P2?J340RfP`08]X<02<JC<0RfLc08YV=027Hc<0QF4a08=N<@20HS00
OEl]07]M:`1mGbd0PF<a08=U<`21Hc40OV0^0P24H2h00`24H300Peha08=N<P0208=N=00408=M=P1o
H3@0OEhb07]L<0<0NEX^00<0NU/_07]L<01hGBh01@1hGBh207UN;`<0MUh`0P1eGBl307AL;P06071J
<@1_FC00KeT`06iH;`1]Ebh0K5H]0P1[EB`0201YDbX0JE</06QB:`1WDB`0ITl]06E>;P1UCRl0I4d^
0P1IC2X0101JCB/0Fdh/05a?;@1MD2h205iA;`80GU8X01T0H5<Y069C:P1SE2/0IU@/06QE;@1YERh0
LeDc07=F=01aEc@0KeLc06QD;`1QCbT0F4XS05E7801CAad0E4PN05I:8P1GBbD0EDPU05=6901?@R00
CD0P04Xn9019?B<0Ac/Q00<0ASXP00<0B3`R04Tm8`15?1l00P15?1l204@k7P0404<j7@12>A`0@STL
048i7080?SLK0P0o>1`03010>Ad0@CXN044j7P11>Qh0@cdK048l7010>QX0?SLJ03hg6`0n=ad0?cLP
040h8@<0>cLL0P0j=Q/303Te6P0403@f7P0c=Ad0<cDM03<e7@80<S@L0P0a<a/2038d7P06034c7@0`
<Q`0;c4K02h`6P0];aT0;2hH0P0`<QX01P0_<A/0;S0K02d^700/;Ad0:b`L02//7P80;R`P00@0:b/O
02T[7P0X:Qd09b/M0P0T:Q`202HY7P0402DX7@0T9a`08bHK02<V6`808RDJ0P0L8a/0100K8QX06R4I
01TP600H7aL201LN5PP061hJ0P0K7AX301XL6@<06A/H0P0F61L301LI60<061XI600G6AP@01HH5`P0
5aTH:@0F61L801DG5Q005QPG200E5QP801HH5`P05AHH200F61LH01DF60P05QPG400F5aT801HH5a40
5aTH0`0I6aX301XL6`806adL00<07AlN01`N7@0J71/00P0I6aX00`0J71/06adL01`N7@0801XL6`<0
6QXH0`0K6aT201`L6PP06a/I0`0M7QP00`0N7aT07b0J01lP6P02020Q6`P071`J200N7aT8024P6`<0
820H0`0Q8AT2028R6P<092@L0`0S8a/2028R6P08020P600R8QX092@L02DU7@0V9Qh09BDM02@T700S
8a/802LS6P0302@T6P0S8aT08R8H00808B4G00H08R8H02<S6@0T91X09B0J02HQ6`0W8Q`202PS7@03
02HQ6`0T7aT08ahH00X08R8J0`0S8a/302@T70809BDK0P0T91X302<S6@808R8H200S8a/2028R6P<0
8b<K0`0T91`00`0W8Q`0:2<M02XU7`0202/V800I02XU7`0X8ad09b8L028T6@0T91X09BDK02PU700[
9ah0;RLO030W800a:240<bHN03DX800g:R80>2/S03T/900h:b<0=bXR03HY8@0e:1P0=bXJ03T/700j
;Ad0>bhN03X]7@0203T/700603d`7@0n<Ah0?S4N03lb7`10<b00@C@Q0P12=B801P11=ah0@SHN048f
7P15=Ql0ASHO04Pf8080BSDP00<0BSPP04Tg7`18=Qh00P17=Ad00`19=al0BcTQ04`j8P0204Lh9@04
04Th9P1:=bH0BSLV04dh9`80CSLW0`1;>B<204Xh8P<0BCLQ0P18=Qh01017=ah0ASPN04@h7P14>1h2
04<i7P<0A3@K1@15=A`203d`7@0303ha7P0o<Ql0@3<P0080@C@Q00@0@SDR04<g7`12=Qh0@CDM0P10
=1`02@11=Ad0@SHN04<g7`0o=b00?SHQ03`d7`0j<Ql0>C0O03T`8@0203X`900303T/700j;Ad0?2lO
0080?C0P00`0?2lO03X]7@0i;1`0>2lN03T`7`0i<Ah0>S8M03/c700l=A/0?CHL03df6P0n<Q`203ha
7P0403d`7`0m<200?2hQ03`^8@80?2hS200n<B001@0k;Q/0?2lL03`_700m<1d0?c8O0080@3<P00<0
@C@Q048b6`12<Q/00`13<a`304@d7@0304<f8`12=B80@SDR0080@C@Q0P10<b001P0o<Ql0>S<Q03Xc
8@0i<R00>34O03L`7P80=RlM00L0=BhL03LZ6@0h:aX0>B`K03X]700k;Qd0?2lN0080?C0O00P0>bhK
03`_700n<Ah0?c8O040c800o<Ql0?S4N03d`7@<0@3<S0P0o<R8303ha8@<0?S<Q00<0?C8P03`a7`0l
<Al00P0k<1h203lc7@0403ha7P0m<1l0?2lN03/^7P80>R`O0`0i;Ad303P/7080=b/K00H0>B/P03PZ
7`0f:Qh0<bTM034Y700_:A/202`Y6P80;BTM0`0/:1`202dY7@0902hZ7P0c;B40=2`O03<[7P0c:Q/0
=RXJ03T/6`0n;a`0?c0M00D0?S4P0`0m<1l02012=bD0@cHS04<f8`16=b80AcLP04Pf7P1:=Qd0BcLN
0`17=ah204Hf7@<0ACDL0P19>B8204Ph8@80AcLP0P16=Ql204lk8`04050l901A?BD0D3`T04lk8`80
CCTQ00D0BcLO04<f8`13=R<0@SDR044d8@02040c8080?c8O00P0>30K03Ta700k<ah0?3@O03de800l
=1l0>c<N03Xb7@80?C0O0P0l;ah403/^7@<0=B`K00<0=2/J03<Z6@0c:QT00P0b:AP00`0f;200=B/O
03<Y7@02038X700303<Y7@0e:al0=R`P0080=b/K00@0>2`L03T]7@0i;Ad0>RhN0P0k;al00`0m<R00
?34O03/`7P0203X_7@0303/`7P0l<Al0?C8P00@0@CDM1012=Qh803lb7`<0?cLR:oooool002[ooooo
00<0Y7Y80:9hAP2QMdD00P2PMT@00`2QMdD0XWQ60:AjB0020:AjBP040:AjB02TNdL0Y7]70:AkA@80
Y7]30P2SN4D00`2TNDH0YGY70:IkB0020:MlB@040:QmBP2WODd0Yge=0:MmC@80Z7i>0`2YOdl80:Mm
B`80Yh=?0P2VPTh0102UPDd0Y81<0:B0C02SOd/80:QoB`<0ZX5=1@2YP4`00`2VODT0Ygi:0:V0C003
0:^2CP040:Z1C@2YP4`0ZGi90:UnB@@0ZWm:0`2[P4/30:Z1C@<0ZH1<0P2XOd/20:V0C080ZX5=0P2[
PTh20:b3C`P0ZHA?202/PU080:^1C`80ZX5900@0ZH180:QoA`2WOTH0Ygi60P2VODD30:1jB`0309mi
BP2NN4T0WWQ90080WGM800H0VgI209Ye@@2JMD40VGA009Qc?`2GLSh209Ia?@80TVhn00@0TFdm091/
?02?Jc/0Sf/k0P2>JSX208iU>@0408eT>02<HcL0Rf8f08YQ=@80RF0d00@0P5h`085O<@21Gc40PEla
0`22H3802@23HC<0MUXZ07EI:P1dF2T0LeHZ075D:P1_DRX0KU0Z06e?:@0307EE;P<0M5@]0P1cDb`0
0`1]Cb/0K4hZ06]=:@0206Y<:00606a>:P1^D2`0Ke4]06mC:`1^DRX0KE4Y0P1[CbL0101/D2P0KE4Y
06iB:P1eDBd207IB;P0307MC;`1hE300NEDa0080NUHb0P1lG2d0101mGBh0OUh_07mO<01oGc02081P
<@<0QV0a0P27HC8308QR<`<0SFLh0P2<ISL408]U=PP0SVPi202=IcP208aV>@<0SFLj0`2>J3/3091[
=`0308mZ=P2>JCD0SFPd0080SFPd202@ICP308eW>080S6Hg0`2;ICH808eY>@80R6@d0P27Hc<408IR
<P80RV@o00@0RV@m08YU>`2:ICT0RVDh0P2:ISH808IQ=0P0QV8b2027HSD01P25H3H0Q5le08AO=@23
GS@0PUdc085L<P80P5/a0P1oG38307iK<@<0OEX`1@1iFC0307YJ<@0607iI;01kFB/0NeT[07UI:P1h
FBX0METY0P1cFBP0201fE2h0M58/075A:P1]D2P0JdlW06U@9`1ZDBP0JU<Y0P1`C2`0101_C2`0KTd/
06a>;01/CR`206Y=:`0606M;9P1VBBL0HTPU05m79@1LABD0Ed8S0P1F@B@01`1D@B<0D3hV04lo9P1>
?RD0C3hT04Tm8`18?R<00P15?R804@10>Ad0@CXP048k8@12>R<0@CTT03lg900l<b80>c8Q038`6@0c
<AX0=C<N03Hc800f<b80=C8S03<`8@0a;B40:b/Q00<0:RXP0P0Y:Al202PX7P809RLO0P0U9Qh402@U
7@P092LP2`0N8AX301lR6`8082<L0P0S9Ql0100R9Ah08B@M01lR6`0N8AX201dP6@<07R4J0`0O8Q/2
020S7080824L00<08B8M028S7P0S91l00P0T9B004@0U9R40:2`K02P/6`0Z;A`0:b`L02h/7@0_;1d0
<2dN038/7P0^<1P0;c4K034c7@0c=B00<c@R038c8`0a<R@0<34S00P09bLO0P0S91`202@U7@0302DV
7P0V9al09RLO00809bPP00L09RLO02DV7P0T9Ad08b@L028S6`0Q8QX0824I00P07b0J0P0O8QT03@0O
81P0820H02<P6@0V8A/0:2<M02/T7P0V9R@092@R02<R7P0T8A`09R4K02XV7@0`:B400P0c;280800e
:al0>BdO03l_7`14<B00CC@P05<d7`1H=Al0FSHN06=B6P1VDa/0KUTT07iT<@2@LT00V7Q909YeB02F
LD@0VG1409UbA`2JM4d0UWEB08]^CP1dG400FTDZ04Pd6`0b<b/0<C8Z02l`:00];RH0:b`T02TZ8P0X
:B409bPP0`0Y:R8302X[8`80:b`T0`0/;bP502/^9`0P02d^800^;b40;c0R030a8`0a<R@0<S<U03<d
9P0d=BL0>c@Z03`e:`0n>2`0?SPZ03dg9`0j=B80=S4N03@_6`0j=R/0>SHZ03/g:`0m>R/0?S/Z03ll
:@10?RT0@ClZ03lj9P11?2H0AclZ04e2;01CA2d0ET@/05Q4:`1I@b/205=3:@0o05A4:P1EAB/0ETH/
05I6;01GAbd0F4P^05A3:@1JARd0GTX_061;;P1PBBX0HDPY06I;;@1ZD2l0LU<T06mC8`1_Db@0Ke@W
06mG:`1aFS00M5ld07IP=`1kGcX0NV0k07]S?@1jIcl0N6U007IY?`1cIcd0L6Ll075N?P1aGSd0Lell
07EO>01gH3H0Mf0d07UQ<@1iHS00Oeli089R>`26ICX0QVHe08IU<02;J2h0TVh`09Qe=@2TMCl0Xg@n
0:9e?02TNT00YWi10:=m?P2MMcH0UG8`085/=`21JcT0P6Xh07iX=`1jI3D0MUlc075J<01^Ebd0ITh/
00<0IDd[00@0ITh/06Q@;P1[Dc40KEDc0`1^CBX0:P1/CRX0KE4/06eC;P1^ES00KeTb075K=01XE2l0
IE4^06=<:P1QB2T0HTLZ06M9;`1[CC<0Kdlh07AJ>@1aEcH0K58a06Q>;@1WCB`0J4h]06Y@;`1/DS40
JdH[06e8:`1bBbX0Mdl[07aB:01oEBD0P5LS085F8@1oFRH0PUdY08IQ;@29I300RVDa08UT<026HBd0
Q5l[08QP;029HBd0S6@`08iV<P80SfLc0180SVHb08eU<@28IBd0R6D]08UV<029IC40R6@b08IR<P24
H300PUd`07eQ<@1jGRh0N5`/07UM;@1mHC40OV8b07aP<01hG2`2085L<004085L<P21Fc@0PE/f081J
=P80P5Th00<0OEhb07]L<01iFRh00P1gF2`00`1hFBd0NU/_07]L<00307=H:@@0M5TZ00<0MEX[07EN
<P1dGC400P1dGC4207=L<080LU/_00H0KeT`06iH;`1^F2l0KEL^06aF;@1[EB`206YD:`80J58[01H0
Ie4/06I?;@1UCRh0IDh^06A=;P1SC2d0EdXZ05Q;:`1IC2`0Fdh^05e@<01NDC40Ge8b061C<`1MDBL0
GU8X061C:@1RDbX0He@[06ID;01XEBd0JEH^0P1fF3H04@1cFCH0L5Pd06QD;`1NCbP0ETPQ05557@1E
BAl0Ed/Q05U=9@1ICBL0ETTV05138@19?1X0ACPH04/o9@1:?R@0B3`R0080ASXP00@0Ac/Q04Tm8`1:
?R@0AC`O0`14>ah00`13>Qd0@STL048i7002044h6`<0?SLK00<0?cPL040i7@11>Qh00P11>Qh02013
?A/0@C/K03li6@0n=aX0?CHJ03hg7@0o=b00@CTR0`0k=a`203Xf6`<0>CDJ100c=Ad2038d7080<C<K
0P0a<ad0100`<Q`0;c4K02d_6@0/;QP202/]5`08030b6P0_<AT0;c4K02h`6`0];Q`0;2dM02//700[
;1h202h/800602/[7`0Y:ah0:2XM02HZ700T:Q`08bTK0P0W:Ql01`0V:Ah092LL02<V6`0R9AX08B@I
020S600L8a/00P0K8QX00`0J8AT06B0H01PO5`0201LN5PP061hJ0P0K7AX301XL6@<06A/H0P0F61L3
01LI60<061XI600G6AP@01HH5`P05aTH:@0F61L801DG5Q005QPG200E5QP801HH5`P05AHH200F61LH
01DF60P05QPG400F5aT801HH5a405aTH0`0I6aX301XL6`806adL00<071hM01/M700J71/00P0I6aX0
0`0K7A`07AlN01hP7`0801XL6`<06QXH0`0K6aT201`L6PP06a/I0`0M7QP00`0N7aT07b0J020Q6`02
020Q6`P071`J200N7aT8024P6`<0820H0`0Q8AT2028R6P<092@L0`0S8a/2028R6P03020P600R8QX0
8b<K00<09BDM00<092@L02<S6`0V8QT01`0V8QT00`0T91X08b<I024Q5`02020P5P06024Q5`0S8aT0
92@J02HQ6`0W8Q`0:2<M0P0Y91h00`0W8Q`09B0J02<N600:028R6P<08b<K0`0T91`202DU6`8092@J
0P0S8aT2028R6003024Q5`0S8a/08b<K00H08b<K0P0R8QX302<S6`<092@L00<09b8L02PS7@0Z9Al0
0P0[9R002@0Z9Al0:2<M02LR700Q8aP08R8H02@T6P0X9A`0:bLN02lX8002038Y8P0303<V7P0e:200
=RTQ00<0>2/S00P0=bXR03HY8@0e:1P0=RTI03P[6`0j;Ad0>bhN03X]7@80>B`L0P0n<Ah203lb7`05
040c8011=240@SDR048e8P10=Qd00P11=Ad00`14=Ah0ACDN04Le7`0204Td7`0804Tg7`18=Qh0AcDM
04Hd7017=Ad0BCLO04`j8P1>?2@204Lg9`0404Th:01:=bP0BSLX04dg:@80CSLY00H0CS`V04dk9@1=
>bD0BcTS04Xh8P19=b4204Pf8080B3HN00<0AcLN04Hh7P14>1h00P13>Ah00`11>Qh0A3@K04@d6`03
04@d6`<0ACDL0P0k;Q/02@0l;a`0?S4N040c8011=240@SDR04<f8`13>B00@CLN03le700203hd6`07
03le7011=ah0@cTP03lg8P0n=R40>c<P03T`7`0203P_800503T_8`0j<2@0>B`L03/^7P0m<2000P0n
<B400`0m<200>bhN03T/700203P_7P0:03Ta7P0j<Qd0>c<L03`e6`0m=Q`0?CHJ03ha7P0m<1d0?C0O
03d`80<0?2hQ0P0k;B8803ha800803X]6P0k;Q/0?2lL03d`7@0n<Ah0?c8O040c8011=243048b6`80
@c<L0`14=1d3040e8`0303ld8P0n<b40?C8P0080?C8P00H0>C@Q03Pc800g<Ql0=c8O03Ha7P0e<1d2
03@_7080=bXI00<0>2/J03T/6`0j;A`00P0l;ah02@0m<1l0>bhK03`_700n<Ah0?c8O040c800o<Ql0
?S4N03d`7@02040c8`<0?c8R0`0n<B4303hc8@0303db800l<Al0>c0N0080>c0N00H0?c<M03hb700n
<Ah0?C0O03`_7P0k;Qh203X/7`<0>2`L0P0g:a/303HZ6P80=bTN00H0=BTM038X700`:1/0;RPJ02/X
6@0Z9aP202/W6`0302dY7@0^:Qh0;RXN0080;BTM00T0;2PL03<]8@0c:ah0<RXM038Y6P0e:AT0>2/J
03d^6`0o<1d0100n<B0403d`7`06048g9@13=R<0@cHS04Hg8P17=b00B3HN0P1:=Qd204Lg7P80ASHM
0`15=A`00`14=1/0BSXS04Xj8`0204Ti8P<0B3PQ00<0AcLP04lk8`1@?2@00P1A?BD01@1@?2@0CSXR
04`h801<>200BcLO0080@CHT00@0@3DS03ld8P0n<b40?C8P0P0l<Al00`0g;aX0>C4L03/c7P0203de
800303`d7`0k<ah0>C4L0080?2lN0P0k;Qd203X]7080>B`K0P0e;1/0100d:aX0<bXI03<Z6@0b:AP2
034X5`0303L]8@0f;200=2XN0080<bTM00<0=2XN03H/800g;B400`0h;1`303T]7@80>RhN00<0?C8P
03`a7`0k<1h00P0j;ad00`0k<1h0?34O03db8003048f7P<0@CDM0P10=1`803hc7`<0@3PS:oooool0
02[ooooo00H0WgA909mdA`2OM4L0X7I60:1fA02QN4@20:5h@PP0XgY600/0XWU50:AkA`2VODT0Ygi:
0:QoB`2WOTX0YWe90:AkA`2WOTX0YWe90:ElB0020:AkA`030:ElB02VODT0Ygi:0080YGY70P2VNdP2
0:MlB@D0Z7e:0P2YOT/30:YoC0P0ZGm=0P2XOd/30:V0C0<0ZX5=0P2XODX00`2YOT/0ZWm<0:^0C@02
0:b1CP030:f2C`2XOd/0Z7m;00L0Z7m;00@0[8=?0:Z1C@2XOd/0Ygi:0P2VODT01@2WOTX0Z7m;0:Z0
CP2YOdd0Yge;0080YWa:00<0Yge;0:UoC@2ZP4h0202[PTh00`2/Pdl0Zh9>0:Z1C@020:V0C0030:Z1
C@2[PTh0[8=?00P0[8=?0P2[PTh0102ZPDd0ZH1<0:MnBP2VODT20:ElB080XGa800<0X7]709mjAP2N
NDD00P2MN4@01P2LMd<0WgE309me@`2NM480WG=109ab@080Vg4o00<0VW0n09E`?02EL3`00`2EL3`3
09A_>`04095[?02?JCX0S6Hg08YT=@@0R68c00P0RV@g08US=P28HSD0Qf4d08EO<P23GC00PU`_085K
;P80OELX00P0O5LZ07YH:`1hEb`0MeL^07MG<01eF300ME8Z07IC:`80Me@/00@0MU<[07AA:@1bCbL0
L4dU1@1_CR/3071?;00A071B<01]Cbd0JT`Z06M99`1VB2H0J4XX06]=:`1^D2h0M50`07A@;P1cCbd0
Ldl[07AA:`1fDb/0N5D[07UF;01lFC400P1lFBl03@1lFRd0OU`^085O;`23HRl0QF@a085P<`20Gc80
PEla08=O;`23Gbd0Q5l[08EM:P25GBT02@2;ICH02`2<Ic80SVTe08mZ=P2AJcX0TF/l08mY?02>Ic`0
S6Dj08eW>02>J3T0SfTj0080T6Xk00<0SfTj08iX>@2=IcP00`2=J3@208aW<`<0RfHb00P0SFPd08aW
<`2;IS80RfHb08aW<`2>JCD0T6/g095/>080RV@e00@0RfDf08aV=`2<ISL0SFLh0P2>J3T00`2=IcP0
RfDf08YT=@0208US=00308]U=P2=IcP0SfTj0080RfHi0`2:ICP308UT=`P0R6@d2029ICD808UT=`<0
Qf<c0P26HS8308EQ<@<0QV4g00<0QF0f08AO=@24GcD00P23GS@3085N=0@0P5dc00<0Oe`b07mM;@1o
GBd00`20GRh3085O;`80Oe`f0`1nFcD307eJ=080NETc00<0N5Pb07MG<@1fES000P1eEBl02@1dE2h0
LeH^079E;@1aE2`0L5<[06iA:@1]D2P0K4lW06]>9P0206I>:P80Idl[00X0IThZ06A<:01RBRH0HDTU
06578P1SBB@0IDdY06E>;01RCRd0GT/[0P1JAbL02@1EA2H0DT8P05107P1>?Qd0CC`N04`k7`1<>b40
CC`R04hl900204Hh7@0304@h7P13>B00@CTR0080?cTS00H0?STU03`g8@0l=b40>cHP03Xe7`0i=1h2
03Pc7@0903Lb700d;1l0=2`O038/800_:b00;2TP02TY8@0X:2009RLQ00<09bTN0P0V:1d302DW7080
9BHN0P0T9Ad302<T7003028S6`0O8Q/07b8K00h07b8K200R9Ah201dP6@807R4J00d07b8K020S700P
8a`08B@M01dP6@0N8AX07b8K020S700R9Ah092LP02DX8@0V:B80:2PN0080:bPO00<0;BTP030Y8@0b
:B800P0d:B<00`0b;AX0=2lL03D`7@0303Lb7`0303Ha7P0e<1d0:2/R00<09bXQ0P0V:B0202DX7`03
02DU6`0V9Q`0:2PN0080:BTO00<0:2PN02HV700U9A/00`0X:1h202LW7@<09RHL0`0Q8Qd2020Q70<0
7b0K0`0O81P3020Q6@808B8J0`0R8a/00`0S91`092DM02DV7P0302DV7P0X02dX9@0^:BD0<b`T03L_
8P0k<b00@CHP04<i7P15>Qh0E40M05a68@1TCRL0Je@Z079J;01mHc80RFdk095f@@2LODL0U7Do08m_
?02BLT40UgM6099b@`22HC@0Le8U04U3;@13?BL0>SDQ02l^700Y:QX0:BdO02/a9@0]=BP08R/X024Z
9`0S:BD08RTR02DZ900Y;2D0;2dU02h_9`80:b`T0`0/;BD302d^9P80;S0S0P0_<B<0100`<b80<C@Q
038e800b=B0203Lc9`0603Pe9P0i=RD0>CHS03Xh8`0k>B@0>cTR0P0i>2@05P0i=b80?3LQ03hh8011
>B80A3dS04Pn9@14>BD0ACXV04Tl:@1=?R/0CSd[04ll:`1=>RT0CSTX04e19`1>@RP0D4@Z0596;01C
Abd0DTH/0514:P1?@bT205U5;00305Y6;@1KAbh0G4P_0080GDT`01X0GTXa06M=;01ZCBd0K4l]06mA
;@1dE2h0N5Ha07]H<P1lFC<0O68_07iT<`1mIcD0OVXh07a/>`1hK3`0MV`k07=[?020LCP0OFhe07UY
=@1fIS<0M6<e07AS>01fI3`0N6I007mS=080Of8f00/0P6<i08=V?P27JD<0Rfe908e_B`2GLSh0VGA0
09]f@@2NND80Wg]109ij@00209ei?@0@09Ia:`2EL2`0TVl_08i/;`2:Ic40Q68b07iM<01lFc00LUPe
075G=01]EC40Je<]06UC:P1WE2T0IeHZ06QG:@80Ke4]00X0JddY06U;9`1[CBT0Ke4]075C;`1_DBd0
K4hZ06]G=01ZES<0J5@a0P1WDc002`1XE340JUHc06]G=01/FR`0JUPZ06MD:@1TDBL0He0X069>:@1S
CbX0I50]0080H50/02H0I50]06M@;P1ZD2l0KDh_071?<01aCS00LE@Z079E:`1eEB`0N5L^07YG;`1n
F340OeTb085J<`20G2X0PEd[089N;023Gbd0Q60^08EQ;`26HS00Qf<a08UU=@26I3@0Q68b089R<@1n
H2h0Nel]07QN:`1gGBX0MV@f07MR=@1fGc<0Me`a07YJ<@1kFS40P5Xc085K=080MeX`00<0N5/a07UL
<P1jGC<00P1lGcD01`1mH3H0LU`Z079L:`1bG2/0LU`]075J;P1aFS000P1aFS40201eI3P0LV4e071K
<01_F2h0LUH^07QH<@1nG3H0PUli0P1cG3<207AM=00407=L<`1`FC00KEH]06]D:`80Ie@Z00<0Ie@/
06IB;@1VDRl00P1UDC003@1UD340HeHd069E<`1PDC00Gdl^05i>;@1PCBd0HTd^06=>;`1RCbh0Gd`[
05i;:P1PCB`00P1SD2l02P1OC2/0FTLV071J<@1/ERd0Ie4X06==901TCRD0JE<Z06mI<01dGSD206IC
:`0606AB:P1QDRT0H54X05iA9`1MDBL0G50V0P1CBBD01P1BB2D0DDHV05159`1?A2P0CT<W04e19`<0
A3dQ1@13?2002P16?2<0@c`R04<l8P12>b40?cTO03di7P0i>1`0=cLK03Hf6P13>B03048h7`80@CLN
0P10=Qd0100m?200?3/O03`k7`0l>al203/j7P80>STM0P0h=Ql203Le7P80=S@M0P0e<a`00`0c<A`0
=38M03Hd7`0203Le800403Hd7`0d<Qd0<c4L030b7@<0;c4L0P0^<1/202d_6P0302ha800]<1l0:bhM
0080:RdL00`0;2lN02ha800_<R40;2hP02/]7`0Z;1h0:2XL02HX6P0U9aT092HH02<U5`0T:1T202<W
6@03028U6P0Q91/082<L00807b4L0`0L7Q/201/M6P<06Q`I0`0L7Q/201/M6P<06Q`I200H6QT801HH
5a/05aTH0P0F61L301DG5P<05aTH0P0F61L301DG5T405QPG200E5QP@01DG5P<051DG0`0E5QP201HG
6@0601@F5@0E5aH05ALF01LI600H6QT06A/J0P0J71/201TK6P0401PJ6@0G6AP05ALF01@F5@804aDD
0`0E5aH201HH5`<05aTH200F61L801LH6PP05QPG200F5aT201HH5`<05aTH0`0H6QT901TJ70P061XI
100I6aX201XL6`806adL200J71/801XJ6PP06A/J200K6aT801`N6`P06adJ0P0L71X301dM6`<07QhL
0P0M7QP201hO6@807b0J0P0P8A/3020O6P<08B0K0P0R8A`802<S6`P08R8J0`0T8ah302<R7@X08R4L
0`0S8Qd2028Q70<08B0K200Q8AT802<R7@T08R8J0P0R8A`302<R7@<092<N00P09RHN02DU7@0S8a/0
8B4I028R6P0T91`09bLO02TY8@<0:BDL0P0Z9Qd302/W7P808bDG00@092HH02DW6@0W:A/0:2XL0P0Y
:ad203<Y7@<0=2XN0`0e:al01P0_;QX0<BhK03<^6`0f;A`0>RdM03d]7P80@2dO00@0>2/J03X]700m
<1l0@3<R0P12=B@2044d8`0504<c7014=1d0A3@M04De7P16=Ql00P17=b001P18>240AcHT04Lf9017
=R@0ASDS04Dd8P<0A3<Q2018=R00301<=b80BcHQ04Tg8@17=b00ACHO04<g7`12=Qh0@CLN04Xj8`18
>240ASHO04@d7@80@c<L00<0A3@M04De7P10=B400P10=B4203ld80<0?S<O00<0?34M03db7P0o=200
0P11=R800`10=B40?c@P03hc7`03040e7`80?c@N0`0n<ad203ld8P0303hc8@0m<R00?C8P00<0?C8P
200n;Ql02`0h;QD0>BlF03X_6@0k<1X0>RlK03T^700g:a/0=RXJ03Pc800g<Ql0=S4N0080=2lL0P0e
<1d00`0f<Ah0=c8O03`a7`0203`a7`80?C8P0`0n<b4303`a7`80?C8P0`0n<b48040c8008044f6P11
=A/0@3@J03lc6`0n<Q`0?C0M03d`7`0l;ah203d`800403/_7`0h;ah0=c0N03D`7@80<RlL00/0>C4N
03H^6`0f:aT0>B`K040`8013<R80@S4Q040]7P0j;ad0?34O03db800203ld8P0303db800l<Al0>RlM
00P0?S<Q200n<Ah203P_7P0603T`7`0j<B00>2lN03H]700c:QT0<BPG200h:aX02@0a:ad0<R`N03<]
7`0d;R00<bdO030Z700^:1X0;2HH02T[7@0202X[7@0302`Z7@0/:1`0;RPL0080;bLL00/0<B/O03<[
7P0f;R40>C0Q03``800n<B00?c0M03h_700k;al0>RhN03T]7@0203P/700303X^7P0l<200?C4Q00P0
ACDN00/0@CDM048f7P14>200ACTQ04Hj8P15>B40A3PP04<g7`16=Ql0AcLP04Ti8P0304/k9080BCTR
0`14=b@204<f8`@0@SDR00<0@CHP03ld7P0n<al00P0l<Al04`0l<200?C4S03hb900m<1d0?2lL03X]
6P0i;1T0>RdJ03/^6`0n<Ah0?c8O040Z7@0o;1h0@BhP040^800o;b00>bhN03P/700g:a/0100`:Q`4
034[7@80;RPL00@0;bTM030Z7P0b;200<bdQ0P0d;R8203D/6`80=RdL00l0=bhM03P_7P0h;ah0>C0O
03H[6@0g;1X0>BhL03/`7P0l<Al0>c0N03X_7@0i;Q`0?C4Q03hb8P10=2@00P11=BD00`10=2@0?S8R
03da8@0203`a7`80?C8P00@0?S<Q03ld8P0o=280@3DS0`10=Al[ooooo`00:_ooool01P2PMDX0X7E8
0:1eB02QMdL0XGM50:9iA@80XWU3202SNTH00`2RNDD0XgY60:ElB0030:MnBP050:ImB@2UO4P0Ygi:
0:ImB@2UO4P00P2TNdL00`2UO4P0YWe90:MnBP020:EjA`80YW]80P2WO4T50:QmBP80ZGi;0`2ZOd`8
0:UoC@<0Z7m;0P2YP4`30:Z1C@80ZGi;0`2ZOd`30:^0C@T0Z7m;00H0[8=?0:Z1C@2XOd/0Ygi:0:Im
B@2WOTX20:QoB`030:Z0CP2YOdd0Yge;0080YWa:00<0Yge;0:UoC@2ZP4h0202[PTh00`2/Pdl0Zh9>
0:Z1C@020:V0C0030:Z1C@2[PTh0[8=?00P0[8=?0P2[PTh01`2ZPDd0ZH1<0:QoB`2WOTX0YWe90:El
B02RODT00P2QO4P00`2PNdL0WgY609iiA@0209ehA080WgE300@0WWA209ec@@2LLT00W7900P2KLCl0
0`2FLCd0UG0l09E`?00209E`?0<0U6lk00@0TF/l08mY>P2=IcP0RV@e0`28HS<02@29Hc@0RV@g08US
=P28HSD0Qf4d08EO<P24GS40Ped`089L;`0207mI:P0807eH:`1kFB`0NUT^07QH;`1hF340MUTa07IC
:`1gE2`207QE;@0407MD;01eDRX0Le0X075>9P@0Kdh[101`Cb`00`1`DS00KDl]06Y<:P0206M99`04
06U;:@1[CB/0KDl]07A@<080Ldl]00D0Ldl[07=@:P1eDRX0N5D[07UF;00207aI<@0607]H;P1lFRd0
OE/]081N;P23HC40Q6<`0P21H3<01`22H380Q60`08AP;P25H2`0QUh[08IN:P29Hc@00`2:I3D00`2;
ICH0S6Hg08aV=`0208aV=`0;08eX<`2>JCD0SfXf091Z>@2@JS/0SfTl08iW?02=IS/0SFLh08iX>@2?
JCX00P2@JS/00`2?JCX0SVPi08eW>00808aW<`80SFPd00L0S6Lc08]V<P2<Ic<0SFPd08mZ=P2AK3P0
RV@e0080RfDf0P2<ISL208eW>00908iX>@2=IcP0S6Hg08]U=P2:I3D0RfDf08aV=`2>J3T0T6Xk00<0
RfHi0P2:ICP308UT=a00RFDe2029I3L308MS<`<0QV8b0P25HC4508EP=P<0Q5le0P22GcD2085N=004
081M<`1oG380Oe`b07iK<@80Oed]0`20GRh3085O;`80Oe`f0`1nFcD307eJ=080NETc00@0N5Pb07MG
<@1fES00MUH`0P1eEBl01P1bEBd0LE@/071C:`1_DRX0KE0X06a?9`80JdhV0P1WCb/206Q@;00:06M?
:`1UCBT0Hd/W069:9P1QAb80HdTT06E=:@1UCR`0HTh]05i;:`80FTLW00H0ETDW0592801A@Al0CclN
04dl7P1<>al204dl8P0904hl9017>Ah0AcTN04@h7P13>B00@CTR040j900o>B<0?STU0080?3LQ00@0
>cHP03Xe7`0i=1h0>C@N0P0h<ad0200e;Qh0=2`O038/7P0_:al0;B/O02TY7`0X:2009bPP0`0W:Ah3
02HX7@809BLL0P0U9Qh202@U7@@08b@L400O8Q/8028U7P807B0I0P0N8AX0300O8Q/082<L020S700P
8a`07B0I01hQ6P0O8Q/082<L028U7P0S9Ql092LP02DX8@80:2PN00<0:bPO02dY800`:B400P0b:B80
100d:B<0<bhK03@_700f<Ah203Pc800303Lb7`0f<Ah0=C0M0080:B`Q00@0:2/P02LZ7`0V:Ah09BPM
0P0T9a`00`0U9A/09RHL02PX7P0202TY7`0302PX7P0V9Q`09BDK00<0:2PN0P0W9ad302HV70<08B8M
0P0P8A`301lP6`<07b0H0P0P8AT3024R6P<08R<K00<08b@L02@U7@0T9Ad00`0U9Qh08P0Z9b80;BPR
02l[8P0d;R00>34O03`d7`10=Qd0@SPM04hj6@1C?a`0G4HQ06=<8`1YDBD0LeP[07eS<P26JSP0U7A1
095a?P2ALD00UgM609emCP2LO4d0Tg9508YY?01[Ec`0H4le0511:P0o=200<R`L02d[7P0/;R<0;C0W
02L]:@0W;RL202L/9P0402T/9@0Z;B@0:b`T02`]9@<0:b`T0P0/;BD302d^9P0602d_900^<2<0;S0S
02la8`0`<b80<C@Q0P0b=B0203Lc9`80>3DV01P0>CHU03Tf8`0j>2<0>SPS03Xi9`0i>2@0>SLT03`g
8`0o>B<0@SXS04@m8`18?RD0ACXV04Hk9`19?2T0BSdZ04dn:`1=?2X0C3TX04/h9`1;?bD0CD4W04m3
:@1AAB/20596;080DDD[00H0F4@[05U5;01IAB`0FTH]05]7;P1LB2l205e9<00F06I=;P1XCRd0JDl^
06iA;`1aDbl0MUH`07UG<@1jF380O68a07]T<P1mIcH0OVXh07e]?01kKC`0NFdm07Q^?@21LST0Og0g
07e^=`1kJcP0NFTh07QW>`80N6Ll0200Of<c07mS=01oHc@0P6<g089U>`25J400R6Y408Y/AP2DKSd0
UW4m09Qc?`2KMT40W7M009ah?P2LN3`0VgLk09ag<@2KMS80UW<c095_<P2;J380Pf8_07eM;P1iF2/0
METd075G<P1_EC00Je@[06UC:P1WE2T0IUDY06MF:P80KDl[00T0JT`X06U;9`1[CBT0L58^079D<01`
DRh0KDl[06QD<@1WDc000`1VDRl04`1XE340JUHc06]G=01^G2h0K5X/06UF:`1WE2T0IE8X06EB:P1U
DB`0IU8]065A;@1SDBd0IE4^06M@;P1ZD2l0KE0`06i?<01`Cc000P1aE2X01`1dE2/0MUH]07QG;P1k
F300OUPa07mI<P1nGBX00P1oGR/06`20Gb`0PV4^08=R;`23HRl0Q6<`08QT=025Hc<0Q68b085Q<01o
HBl0Nel]07UO;01hGR/0MV4b07EO<01dG2h0MEX]07MH;01iF2d0NeP^07iI;`1gFRh0N5/_07UL<01j
GC40Nehb07aO<`0207eP=00607=M:`1cGB`0Led/07=M;P1bFbl0LU/a0P1bFc80201`Gc<0Ke`a06mJ
;`1^Ebd0LED]07AG;`1iFC80O5Xd0P1`FS42075K<P0:06mI<01]Ebh0JU@[06UC:P1XEB/0J5D]06MD
;01VDRd0IE4^06A@;`80Hdh_00H0H5<a05mB<01NCbh0GDd/05a<:`1OC2`2065<;@04069?;P1PCB`0
Gd`[065>;@80IE8a00P0HTl^05e::@1WDBP0Ie4X06QB:@1YDbX0JU@[06aF;@80KEL^00H0He0X069?
9`1QCbL0GTlV05e>9@1KCR@205U=8`80DdTU00H0DTPU05159@1?A2H0CT<W04e29P1=@BL204@m8@@0
@c`P0P12>al02@15>b80@c`R04<l8P12>b40?cTO03`h7@0i>1`0=cLK03Hf6P03040i7`80?cPN0`0n
=ad303`k7`80>cXN0`0j>Ad203Pf7`80=cDN0P0f=1d203Dc700303<a700d<Qd0=S@O0080=cDP00<0
=S@O03@b7@0c<A`0100_<A`202h`6`80;BlJ00<0;S4P02`_7P0[;Qd00P0Z;A`04@0[;Qd0;C0O02ha
800[;Al0:R`N02T[7@0X:Q`09RPJ02DW6@0T9QP08bDG02<W600S9aT08RHH028U6P0Q91/082<L0080
7b4L0`0L7Q/201/M6P<06Q`I0P0L7Q/301/M6P<06Q`I200H6QT801HH5a/05aTH0P0F61L301DG5P<0
5aTH0P0F61L301DG5T405QPG200E5QP@01DG5P<051DG0`0E5QP201HG6@0501@F5@0E5aH05ALF01HH
5`0H6QT00P0I6aX01P0J71/06A/J01PJ6@0H6QT05aTH01DG5P8051HE00@04aDD01DG5P0E5aH05ALF
0P0F61L301LI60P05QPG200G61X801HH5`P05QLI0P0F61L301LI60<061XI2@0I6Q`901PJ6@<06A/J
0P0J71/201/M70P06Q`K200J6QX801TK6PP06a/I200L7Q/801/M6P8071`J0`0M7A/301hN70807AhH
0P0N7aT201lP6P80824K0`0P7aX3024P6`808R4L200S8a/8028R6P<092<N0P0S8Qd;028Q70808b8M
0`0R8A`3024P6`P08B4I200S8Qd9028R6P808R4L0`0S8Qd302@S7P0802DU7@0T91`08b<K02<S6`0T
91`09BDM02HV7P0W9al302TU7080:RHM0`0[9ah202DV600402HW6@0W:1X0:2TK02TZ7080:R/M0`0c
:Ad203@Z7P<0=B/O00h0<2dJ03<^6`0d;A/0=RdL03X]7@0m;Ah0?bdO040]7`0i;1/0>RdL03d`7`10
<b80@C@S048e9080@C@S1015=Ah404Hf7`80AcHT0P16=B<01015=280A3<Q04@c8@14<b4804Pf8080
BcHQ00X0B3HP04Lg8015=Ql0@cLO048f7P11=ah0BSXS04Ph8@16=Ql0A3@M0P13<a`01014=1d0ACDN
040e8@10=B4303ld80<0?S<O00P0?34M03db7P0o=200@3DQ044f8P10=B40?c@P03hc7`80@3DO0P0o
=1h303hc7@0403db700o=280?S<Q03hc8@<0?C8P0P0l<Al803h^7`0;03/a600l<QT0?C8L03db7P0m
<R00>blO03X^7P0h;1h0>C8P03Pa7`0f;ad00P0e;Q`203H_7@0303L`7P0h<Al0>c0N0080>c0N0`0l
<Al203db80<0>c0N0P0l<Al303db80P0@3<P00H0@CDK040d6P10=1`0?c<K03hb700m<1d203`_7P80
?2lO00@0>RhN03P_7P0g<1h0=C0M0P0c<1d02`0j<Ql0=blL03L/6P0j;A`0@C4Q04@c8`12<B40@BhO
03X_7@0k<1h0?C8P0080?S<Q00<0?C8P03/`7P0j;ad0200m<R0803d`7@0803L^7@0h;ah0>C0O03T`
7`0h;ah0=RdL03<Z6@0b:AP803P[6`0902l/7@0`;Ah0<BhO034^7`0`;Ah0;R/L02/X6@0Z9aP0:B/M
0080:R/M00<0:bTL02`X700^:1`00P0_9a`01P0`:Qh0<b/N03D]800i<240?C4Q03ha8080@34N00P0
>blO03X^7P0i;Ad0>2`L03T]7@0j;Qh0?30P03da8@P0ACDN0100@CDM048f7P14>200ACTQ04Hj8P15
>B40A3PP04<g7`16=Ql0AcLP04Ti8P1:>R<0Bc/T04Xj8`19>B80B3PQ0`15>2D204@g90@0@cHS00P0
@CHP03ld7P0m<Qh0?34O03/`7P0l<200?C4S03hb9080?C0M0`0k;Q/02`0m<1d0?c8O040c800n:ad0
?b`N03l]7`0o;b00?2lO03/^7P0h;1`0=b/K00D0<B/M0`0b;1h01@0^:1`0;bTM02lY7@0`:Qh0<R`P
0080<bdQ00<0=2hR03D/6`0e;1/00P0f;A`203L^7@80>2lN00<0>2dK03T^700k<1h00`0l<Al01@0j
;ad0>BhL03da8@0n<R80?c<S0080@3@T00<0?c<S03hb8P0m<B400`0l<Al00`0m<R00?S<Q03hc8@02
03ld8P<0@3DO:oooool002[ooooo00H0XGI;0:5fB@2RMdX0XWQ80:=iA`2SNTH20:AkA@P0XgY600<0
XWU50:=jAP2UO4P00`2VODT20:ElB0030:MnBP2VODT0YGa80080Y7]700<0YGa80:ImB@2WOTX00P2U
NTL20:IkB080Yga91@2XODX20:UnB`<0ZWm<202YP4`0102WOTX0Z7m;0:QoB`2XOd/20:V0C080ZX5=
0`2[P4d30:YoC080ZGi;2@2YP4`00`2[PTh0ZX5=0:QoB`030:MnBP050:QoB`2YP4`0ZX1>0:UoC@2X
OT`00P2WOD/00`2XOT`0ZGm=0:Z0CP080:^2CP030:b3C`2[PTh0ZX5=0080ZH1<00<0ZX5=0:^2CP2/
Pdl0202/Pdl20:^2CP030:Z1C@2YP4`0Z7m;0080Ygi:00H0YWe90:9mB@2RODT0XGa80:1kA`2ONTH2
09iiA@0709ehA02PMT@0WgE309me@`2NM480WG=109ab@00209]a?`<0UW4m00T0UG0l09A_>`2DKc/0
U6lk09=^>P2AJc`0SfTj08eW>02:I3D00`29Hc@01`2:I3D0RV@g08US=P28HSD0Qf4d08IP<`24GS40
0P23GC02085K;006081K;P1mFbh0O5/`07YJ<@1jFS<0N5/c101iERh0101hEBd0Me@/07EB:P1dDBT8
071?;00H06mA;`1]Cbd0JT`Z06Q::01WBBL0JD/Y06]=:`1]Cbd0M50`07=?;@1bCR`0LThZ07=@:P1e
DRX0Me@Z07UF;01lFC<0NePb07]H<01kF2h0O5X]07mM;`21Gbl0Pf4a0P22HC@02`23HC<0QF4a08EQ
;`26HBd0R60]08QP;027HC80R68c08US=02:I3D0RfDf0080SFLh0P2>J3T02`2=J3<0SVTe08mZ=P2@
JST0T6Xk08mY?02>Ic`0SFHk08eW>02>J3T0SfTj0080T6Xk00@0SfTj08iX>@2=IcP0RVDa0P2;IS80
3@2<Ic<0SFPd08iY=@2>JCD0SfXf08iY=@2=J3@0S6Lc08]V<P2<Ic<0SFPd08mZ=P2@JcL00`2;ICH2
08aV=`<0SFLh00H0SVPi08eW>02=IcP0S6Hg08eW>02>J3T2091Z>`0408aW>P2;IST0RfHi08]V>@80
RVDh0P29I3L808]W=`P0RFDe2029I3L208QT=080Qf<c0`26HS801025HC40Q5le08AO=@24GcD408EP
=P0708IQ=`24HCL0Pf0f089O=@21GS@0P5dc07iK<@0207eJ<080Oed_0`20GS03085O<@80Oe`d0`1n
Fc<307eJ<P0607YJ<`1iFC80NETb07QH<@1gEc00MUH_0P1eEBh02P1aE2`0L5<[06mB:P1^DBT0K4lW
06]>9P1ZCBD0JD`T06Q@;01YDBd206YB;P0:06UA;@1WCb/0IDdY06=;9`1RB2<0I4XU06A<:01TCB/0
HDd/05i;:`80FTLW0180ETDW05=38@1B@R00D40O04hm7`1=?200CC`R04hm8`1>?2@0B3XO04Li7P15
>Al0A3XQ044i8P10>R@0?cTS03hi9@0m>28203`g8@0303/f800j=Al0>C@N0080>3<M0P0f;al01P0d
;R00<2`P02h/800Z:R00:BTO02PY8@80:2XO0P0W:Ah302HX7@0402DW700U9Qh09BHN02DV7P8092DM
0`0S91`@01lR6`P08RDN0`0N8AX301lR6`8082<L00H07B0I01hQ6P0O8Q/082<L024T7@0S9Ql202@W
800602HX7@0X:1h0:2PN02/X7`0]:B00<2TQ0P0b:B803P0d;a`0=C0M03Lb7`0h<b00>C@Q03Pc800g
<Ql0=S4N02d_900/;R<0:bdR02T[800W:Ah09RPM0P0T9Q/00`0U9A/09RHL02PX7P0202TY7`0302PX
7P0V9Q`09BDK00<0:2PN0P0W9ad302HV70<08R<M0P0Q8Q`3020Q6`807b0H0P0P8AT3024R6P@08R<K
0P0S91`402@U7@0P02PU800Y9Ql0;2PO030Z7P0d;Ad0>30M03Xb6`0m<Q`0A3<G04Xg6@1A?Qh0ET8O
05]57P1SC280KEDY07AL;P28JCX0Rf`m095b@`2GN4T0VW]<09]lC@2INT/0UgQ909A`CP28IDD0LU@h
05]3:`16=B<0=bdQ030/8@0^:b@402`]9@<0:b`T0P0Z:b<302//9080;2dU0P0];RH01P0/;BD0;BlT
02d_900^<2<0;c4S030c8P80<C@Q0P0g<bP01P0g<bL0>3DV03Pe900h=B80>CHS03Tg8P80>STW00H0
>SLT03dh900o>2D0@SXU04Dm9P19?RP204Dm:00;04Pm:@1:?BX0Bc`Y04/j:01:>BL0BSLV04Tm8`1;
?bD0CD4W04m3:@1AAB/00`1BAR`205I5:`0305M6;01HAbd0FDP^0080FTT_0140FdX`06A=;@1UCRh0
Idl]06]A;P1_DS00LU@`07IF<01gEc40NF4a07]S<`1lISD0OVXh07m]?@1oKch0P70o07i`?`0208Eb
>P0D08Ib?@25LCh0Pflm085/?@1nJCX0OFPk085U<`20I380P6@d081T=@21I3P0PfHl08AW?`26JD40
Sf/i091/>P2BKSX0UG8l09Ic?@2GM3`209Md>P0@0:5k>P2PNST0VWHh09Aa=`2>JcD0QF@_07eM;01j
FR/0N5/c07EI<@1bERh0KE@[06YC:@1XDbP0IU<X06MD:@80JddY00P0JD/W06Q:9P1[CBT0L58^07=E
<@1bE300Ke4]06UC;P<0J58]00T0JE<^06aF<@1^F3<0L5Xe079M;P1aG2d0KeX]06aG;01[EB`00P1[
EBh04@1[EC00IU8]06IB;@1XDRd0JE4]06Y@;@1]D2h0KU4_06mA;`1_E2T0L5DZ079E:`1eEB`0N5L^
07YG;`1kF300OEL`0080OU`/00<0Oed]081N;P21Gbl00P22H3003`23HC40Qf<c08AR<P23HC40PF4`
07mQ;`1lH2h0NV0]07UO;01eGc00MEd_07AL;P1dFB`0MEP/07MH;00207UH;@80NE``0P1jGC401@1k
GS80O5lc07eP=01mH3@0MEl]0080MEl^00<0M5h_07AM<@1cG3800P1cG3<206eJ;`0306mJ;`1`FBl0
LEP_0080LeL_01@0M5L_06eG<01^F340KUPa06eG<01[EBh0JE</06MA:P1VD2T0J5H^06ME;@1VE2h0
I58^069?;P1PCBd0Gd`/05i;;@1LCbd0Fdh/05Y;:P80FTXY01<0G4TY05i9:P1OBR/0He4]065?:`1P
CRX0I58^06QF<P1YEc<0IU@`069@;01PBR<0I4hW06YD;@1^F340KeTb06aF;`1XDR/0I4hW0080H4dU
00h0GT`T05]<8`1JBb80F4/Q05M;8@1FBR00DdTU0598901AAb@0D4DU04i39@1=@RH0C44U04/o9@80
A3dQ0P13?203048k7`0;044j7P14>R40@S/Q048k8@11>R00?cTO03`h7@0i>1`0=cLK03Hf6P10>Al0
0`0o>1h203hg7@80?CHL00@0?3/O03/j7P0k>Qh0>cXN0P0j>Ad203Th7080>3HO0P0g=Ah203Hd7@80
=C<L00<0<c4L03@b7@0e<ah00P0f=1l00`0e<ah0=38M03<a700302la7080;S0K0`0];aX00`0]<1l0
;2lN02/^7@0202X]700302/^7@0/;ah0;C0O0080:R`N00h0:B/M02LY6`0V:1X09BLI02@V600S9AL0
8bLH02<W6@0R9QP08B@I020S6P0O8Q/07b4L01hP6`<071hK0P0K7AX301XL6@0401`N6`0K7AX06adJ
01/M6P806Q`I0P0I6aP801PJ6B<05aTH0P0F61L301DG5P<05aTH0P0F61L301DG5T405QPG200E5QP@
01DG5P<051DG0`0E5QP201HG6@0601@F5@0E5aH05ALF01HH5`0G6AP061XI0P0I6aX201PJ6@0401LI
600F61L05QPG01DG5P8051HE0`0E5aH201HH5`<05aTH200F61L801LH6PP05QPG200F5aT201HH5`<0
5aTH0`0H6QT901TJ70/061XI0P0I6aX;01XL6`P06QXJ200I6aX801/K6@P071hK200K7AX201`L6P<0
7AdK0`0N7Q`201dN60807QlI0P0O81X2020Q6`<081lJ0`0Q81/2028Q71008b<K0P0T8ah202<R7@<0
8R4L2@0Q81/0100S8Qd08R4L028Q700R8A`2024P6`8081lJ200Q8AT802<R7@T08R8J0P0R8A`302<R
7@<092<N00@08R8J02<S6`0T91`09BDM0P0V9Qh00`0U9Ad092@L02TU700202TU7080:RHM0`0[9ah2
02HW6@0402LX6P0X:A/0:BXL02TZ7080:R/M00@0<RPL03<Y7@0c:Ad0<bTM0P0d:Qh203D[7`06038]
6P0d;A/0=2dK03H]700i;Ad0>bhN0P0n;Ql01@0i;1/0>bhM03d`7`0o<R40@3<R0080@C@S00<0@3<R
04Hf7`16=Ql00P16=Ql404De7P<0ASDS0P15=28304@c8@P0B3HP0P1:=B002P18=R00ASHO04Df7`13
=al0@SHN044g7P19>B80B3PQ04Hf7`14=1d304<c700304@d7@10=B40?c@P0080?c@P0P0n<al203db
7P0303/`700m<Qh0?S<O00<0@3DQ00<0?c@P03hc7`0o=2000P0o=20203hc7`<0?C8N0P0m<R00100n
<b40?C8P03db800l<Al203/`7PP0>bhN00<0?C8L03hc7@0o=2000P0o=2801P0m<B40>blQ03X^800i
<1l0>2lN03L^7@80=RdL0P0g;Qd00`0h;ah0>C0O03T^700203T^7080>RlM0`0k<1h203T^7080>RlM
0P0k<1h203`a7`P0?c8O00h0@3@J040d700o<a/0?S8L03d`7@0l;ah0?2lO03/^7P0i;1`0>RdM03T]
7@0g;Qd0=c0N03Ha7P80=34N00P0>c<P03P`7@0i;Q`0?C0O04<c8`16=BD0A3<S048_8080>c0N00@0
?34O03db800m<R00?34O0P0k<1h803db80P0>BhL00P0=bhM03P_7P0h;ah0>2lN03L^7@0e;1/0=2/J
03<Z6@P0=RXJ00T0;RXN02l[7`0_:al0;b/O02hZ7P0/:1`0:bLK02XV6P0X:Q`00P0Y:Q`00`0[:A`0
;2PL02hX700202lW700602lY7@0a:A`0=BdP03T`8@0m<B40?c8Q0P11<Ql00`0k;al0>RhN03T]7@02
03T]7@0303/_7`0l<200?S8R00P0ACDN00<0@3@L044e7@13=al00`15>B4204<g7`0304De7P16=Ql0
B3PQ00<0BSXS0P18>24204Hi9P80ACPU1014=b@02@13=R<0@3DO03ld7P0m<Qh0?34O03/`7P0l<200
?C4S03hb900203ha7P<0?C0M00/0?S4N040c8011=240?R/M03h/7P0o;Al0?RhO03/^7P0i;Ad0=RdL
03D/6`0303<]7`D0<R`N0P0_:Ad0100`:Qh0<B/O034[7`0b;20203<]8@80=B`K0`0f;A`303L^7@03
03/`7P0l<Al0?C8P0080?S<Q00<0?34O03/`7P0i;Q`00P0m<B40100n<R80?c<S03lc8`0n<R8203da
8@@0?34O0P0m<R0203hc8@<0@3DQ:oooool002[ooooo00H0XWM<0:=hB`2SN4/0XgU90:AjB02TNdL2
0:ElAPX0XgY600<0Y7]70:ElB02UO4P00`2UO4P00`2WOTX0YWe90:ElB0020:AkA`030:ElB02VODT0
Ygi:0080YGY70P2VNdP20:MlB@D0Z7e:0P2YOT/30:YoC0P0Z7m90P2WOTX30:QoB`<0ZH1<00H0[H9?
0:b1CP2/PDh0Zh1=0:YoC02YOT/20:QmBPT0ZH1<00<0Zh9>0:Z1C@2XOd/00P2WOTX01P2XOd/0ZH1<
0:Z1C@2[PDl0ZX1>0:QnC080Yge;00<0Z7i<0:Z0CP2[PDl0202[PTh00`2/Pdl0Zh9>0:Z1C@020:V0
C0030:Z1C@2[PTh0[8=?00P0[8=?00<0Zh9>0:Z1C@2ZPDd00P2YP4`20:QoB`060:MnBP2SOTX0Xgi:
0:9mB@2QO4P0X7]70P2ONTH01P2NNDD0X7I40:1fA02OMD<0WWA209ec@@80W79000D0Vg4o09Mb?P2F
LCd0UW4m09E`?00209A_>`80Tfhj00@0T6Xk08mY>P2=IcP0RfDf0P29Hc@0202:I3D0RfDf08YT=`29
HcH0R68e08MQ=026H3<0QElb0P24GS4208AN;`06089M<01oGC00OUdb07aL<`1kFc@0NE`d0`1kF300
1@1jEbl0NEH^07QE;@1gE2`0MU<[00<0LE0]101`Cb`04P1_CR/0KU0^06e?;@1[CB/0JD/Y06Q::01Y
BbT0Jdd[06a>;01cCbl0Ldl]079>;01bCRX0Le0Z07EB:P1gE2X0N5D[07]G<`80NULa00D0NUL_07]H
;P1mFbh0Oed_085O<@02089Q=00;08=Q<`25HC40QV8`08MR;P29HBh0RF4]08IP<@27HC80R68c08YT
=@2<ISL00P2=IcP208mY>P0608iY=02>JCD0SfXf08mY>02?JCX0SfTl0P2>Ic`00`2=IcP0SVPi08mY
>P02091Z>`0308mY>P2>J3T0SFLh0080RVDa00@0RfHb08aW<`2>JCD0SfXf0P2@JcL0202?JSH0SVTe
08aW<`2;IS80S6Lc08eX=02>JCD0SfXf202<ISL408iX>@0408mY>P2@JS/0T6Xk095[?080S6Lj0`2;
IST308YU>0P0S6Ph2029ICD808UT=`<0R6@d0P27Hc<308IR<P0508=N=024GcD0Q5le08AO=@25H3H0
0`26HCL208AQ=`06089O=@21GS@0Oe`b07iK<@1mFS00O5T_0P1oGC03081N<@<0PElb0P1oG38307iK
<@<0OEX`0P1jFS400`1iFC00N5P_07MG;P0207IF;@0707EE;01`Db/0L5<[06mB:P1]D2P0K4lW06Y=
9@0206U<900>06UA;@1ZDRh0Je<_06]C;`1ZDRh0J50/06I>:P1TC2P0HdTT06A:9@1TC2P0Hd`Z065=
;01MBRX205]8:00A05M6:01EAB<0E4@R0551801??R00CSdQ04dl8P1>?B<0CcdU04Tk8018>Ql0ASXP
04@j8@11>B80@3XT03li8`0n>BD00P0m>2800`0l=b40>cHP03Xe7`0203Td7P0903Pc7@0g<1h0=c0N
03D_7`0b;b00;bdP02`/800[:al0:B/P00<0:2XO0P0W:Ah302HX7@809RLO0P0U9Qh202@U7@808b@L
200P8a`801lR6`P08RDN0P0N8AX601lR6`0601dP6@0N8AX07b8K020S700Q91d08RDN0P0S9Ql01P0T
9a`09RPM02HX7@0X:1h0:bPO02dY8080<2TQ00<0=2lL03D`7@0g<Ql00P0i=2403P0h<b00=c8O03Ha
7P0`<2@0;blS02h^8P0[:al0:BTM02LW6`0U9AT092@H02DU6`0V9Q`0:2PN0P0Y:Al00`0X:1h09RHL
02DU6`0302PX7P809bLM0`0V9Q`202<T70<08R<K0`0Q8QX3020Q6@<08B8J1P0R8a/502<T700P02@T
700T91X0:2DL02/W6`0_:A/0<R/K03@]6`0f;Q/0?RhG04<c7019>1h0BcXN04ll701E@Ah0GdTR06E?
:01kGS@0PVDi08Y]@@2=LD80S71108]_?`2?Ld<0TgM70:ijDP2SLd/0TVM407]H?01SBC80CS/Z03la
900g;B<202hZ7P0502l[7`0^;200;2`P02/[8@0Z;2400`0Z:b<302//90D0;2dU0P0];b@0100^<2<0
;c4S030c8P0`<b8203Lc:P0303Lc:00g<bL0=c@U0080=c@S00T0=c@Q03Xh:@0i=bP0>SLV03`g900o
>2D0@SXW04Dm:018?BL00P15?bT03P16?RT0Ac`X04Pk:019>RL0B3TV04Th9P18?280BCdS04/o9@1=
@BL0D4@Z0596;01CAbd0E4P^0P1DA2X00`1EAB/0ETH/05M7;@0205Q8;P0g05U9;`1PCBd0HTd^06=?
;P1WD2h0JU8^06eC<01`E2l0LED^07MO<`1hHCD0NV@e07eW>020K3X0PVhl08A`?@25LCh0Qg4h08Ub
?02<MCl0SGI008ae@@29LSh0Q6di085Z=P23J340PfPc089W<P22IS@0PVHf089V=`22ICT0PfHj08YX
>02;JCT0SF`i08i]>02@KcT0TG0j099b>@2CLcP0X7Xk09mi>`2KMc/0UW<i095^=P2:JC@0Q6D_085Q
;P1lGc<0NUda07EJ;@1aER/0K5<Z06YC:@0206QB:@80JT`X00L0J4XV06M99@1ZC2P0L58^07AF<P1c
EC40L58^0080K5@^0100Je<]06aD;P1^ES00LETc07AL=P1eGCL0MEl^07AN;@1cGBh0LEX^071I;`1`
FC00KeP_06mG<@1[EBh0JU@]0`1ZDR`00`1/DRd0KE<^06iD;`0206iF:P06075F:`1cER`0MUH]07QG
;P1iF2l0NeP`0P1mGBh207iN;`80Oel`0P20H3401P25HC40Pf4a08=Q<@21HC00Of4_07aP;P80Nf4^
0P1jGc00101iGRl0NEd^07UM;P1iGBh207]L;P80NUh_0P1kGc002P1lH340OF4b07eQ<P1mHC80Mf4_
07MQ<01fH2l0MEl`07EN<P1dGC<207=L<`0306eJ;`1^Fc00LUdb0080Lehc00<0LU/a071I;`1^Ebd0
0P1YEC00101XE2l0Ie<^06EA;01TD2/2069>:@0;06EF;`1TEBh0He<_061@;P1NCRd0G4/]05Y9:`1I
B2`0FD`Z05Q;:@1GB2L00P1HB2L0101KB2P0GTTZ05m::`1TDR`2069@:P0=06ID;P1[FC<0K5Xd06UG
<@1UDbd0I4hY06MA;01[EC00KELb06aF<@1WDB`0HT`W05i88`02065>9P0405m=9@1LCB@0Fd`S05U<
8P80Ed/Q00P0DdTU0598901AAb@0Cd@T04e2901<@BD0BSlS04Xn9080A3dQ0P13?2001@12>al0@CXN
044j7P10>Ad0@cTP0080@CXP00@0@3TO03hh7P0l>1d0>CPL0P0g=a/0100n>1h0?CLM03dg7@0m=ad2
03`f7080>cDK00@0>cXN03Xi7@0j>Ad0>STM0P0i>1`203Pg6`80>3HO0P0g=Ah203Hd7@80=C<L00<0
<S0K03@b7@0e<ah00P0f=1l00`0e<ah0=38M038`6`0202la7080;S0K0P0];aX202`^6@0302d`7`0/
;ah0;2lN00D0:bhM0P0Y:ad01`0X:Q`09bTK02HX6P0U9aT092HH02<U5`0S9aP00P0R9QP00`0Q91T0
82<J01lR6`0201hP6`<071hK0P0K7AX301XL6@<06adJ0P0J71T301TK60P061XI8`0G6AP201HH5`<0
5ALF0`0G6AP201HH5`<05ALF@@0F61L801DF61005ALF0`0D5AL301DF60805QLI0`0E5aH00`0F61L0
5aTH01LI600301PJ6@805aTH0P0F61L201DG5P0401@F5@0E5aH05ALF01DG5P805QPG0`0G6AP801HH
5`P05QLI200F61L801HG6@805QPG0`0G6AP301PJ6@T06AXL2`0H6QT301TK6PX06Q`K200J6QX801TK
6PP06a/I400K7AX201`L6P<07AdK0`0N7Q`201dN60807QlI0P0O81X2020Q6`<081lJ0`0Q81/2028Q
71008b<K0`0S8Qd3028Q70X08B0K0`0R8A`2024P6`<081lJ200Q8AT8028Q70T08R8J0P0R8A`302<R
7@<092<N00P0820H028R6P0U9Ad09bLO02PX800V9Qh092@L02<S6`<0:BDL0P0Z9Qd302/W7P0302TW
6P0Z:1/0:RPK0080:bTL0P0/:Qd00`0]:ah0<RPL038X700303<Y7@<0=2XN00H0=2/J03D/6`0e;1/0
>2`L03T]7@0j;Qh203`_7`0503X]700k;Qd0?2lN03ha800o<R400`10<b801@18>240AcLP04Lg8016
=Ql0ACDN0080A3@M00<0@c<L04Dd8P15=2800P15=28404@c8@P0B3HP0P19=1l01P17=Al0ASHO04Df
7`13=al0@SHN044g7P80AcLP00<0ASHO04De7P14=1d00`13<a`303ld8080?S<O0`0m<Qh00`0k<1`0
?34M03hc7`02040e8@0303ld800n<al0?C8N00<0?S<Q0P0m<R0503`a7`<0?C8P00<0?34O03X_7@0i
;Q`0200i;Ad02`0j;aT0>c0L03`a7`0m<R00?C4Q03/_8@0i;B40>2`P03P_7P0g;Qd0=RdL0080=B`K
0P0g;Qd0100h;ah0>S4P03L/6P0g;1X203P]6`<0>BhL00<0>RlM03P]6`0h;A/00P0i;Q`303X_7@03
03/`7P0o<Ql0?c8O00H0?c8O0P0o<a/01P0n<Q`0?C0M03`_7P0k;Qh0>bdP03X/7`80>2/K00@0>2`L
03L^7@0f;ad0=S4N0P0e<Ql0200k<b00>C4N03X_7@0n<B00ACDU04Lf9P14<b<0@RlP0P0k<1h403`a
7`80>c0N200l<Al803D/6`@0=bhM00@0=RdL03D/6`0d:aX0=2/J200c:Q/302d[7`0602`Z7P0[:Ad0
:RPL02TW6`0X9QX09bTK0P0X:A/00`0Z:1/0;2PL02hX700202lW700;02hX700a:A`0=2`O03T`8@0m
<B40?c8Q048c8011<Ql0?30P03/_7`0j;Qh00P0i;Ad00`0k;al0?C4Q03hb8P0804De7P0;040d7011
=Ad0@cLO04@h8015>B40A3PP04<g7`12=Qh0A3@M04De7P17=b000`19>B801018>240AcLP04Hi9P16
>BH304Dh9@@0A3LT00<0@3DO03ld7P0m<Qh00P0k<1h0100k;al0?30R03da8`0o<Ql203ha7P80?c8O
0P10<b002@11=240?R`N03d]7P0m;Ah0>bhN03T]7@0f;A`0=BhL03@]6`0203@^80@0<bdO0P0b;1h0
0`0_:Ad0<2XN030Z7P02034[7`80<R`P00<0<bdQ03D/6`0e;1/01P0f;A`203db80<0?c@R00<0?C8P
03/`7P0j;ad0200m<B4303/`7PD0?34O0`0o=28[ooooo`00:_ooool01P2RMd`0XgQ;0:=hB`2SNDT0
Y7Y80:AkA`80YGa6302SNTH01`2TNdL0YGa80:ElB02VODT0Ygi:0:ImB@2UO4P00P2TNdL00`2UO4P0
YWe90:MnBP020:EjA`80YW]80P2WO4T50:QmBP80ZGi;0`2ZOd`80:QoA`<0Ygi:0`2XOd/20:V0C006
0:f2C`2/PDh0[85>0:^0C@2ZOd`0ZGi;0P2XODX90:Z1C@030:^2CP2ZPDd0ZH1<0080Z7m;00H0ZH1<
0:^2CP2/Pdl0Zh5?0:Z0CP2YOdd20:QnC0030:UoC@2ZP4h0Zh5?00P0Zh9>00<0[8=?0:^2CP2ZPDd0
0P2YP4`00`2ZPDd0Zh9>0:b3C`080:b3C`@0ZX5=102YP4`20:AoB`030:=nBP2RODT0XGa80080X7]7
00L0WgY60:5gA@2PMT@0X7I409me@`2NM480WG=10080W79000H0V7<o09Mb?P2FLCd0UG0l09A_>`2C
KSX2099]>@04091Z>`2?JCX0SFLh08]U=P80RV@e00@0RfDf08aV=`29HcH0RF<f0P28HSD03027HC@0
QV0c08IP<`25Gc80QV0a08EO<024Gc80PElb07iM<P1lG3<0O5`e07UL=080O5Ta00<0NeP`07YG;`1i
ERh00`1hEBd3079A;P03075@;@1`Cb`0L4l/0080Kdh[00D0KDl]06a>;01[CB/0JT`Z06U;:@0206Y<
:P0N06]=:`1cCbl0LTh/075=:`1aCBT0LTlY07AA:@1fDbT0N5D[07YF=01jES80NEDa07QE;`1iERh0
NeP^07eK;P1nG2l0P5lb085P<`22H380QF4a08EQ;`27HRh0RF4^08YR;P26H340Qf4b08QR<`2:I3D0
S6Hg0P2=IcP208mY>P0608mZ=@2?JSH0SVTe08iX=`2>J3T0SVPk0P2?J3d00`2=IcP0SVPi08mY>P02
091Z>`0C08mY>P2>J3T0SFLh08YU<@2;IS80S6Lc08eX=02>JCD0SfXf091[=`2AK3P0SfXf08iY=@2=
J3@0S6Lc08]V<P2<Ic<0SVTe08mZ=P0808aV=`0408eW>02>J3T0SfTj08mY>P@0T6Xk0`2<IcX308]V
>@80RVDh202<J3P808UU=@P0RF@g0P29ICD208QT=080Qf<c0P26HS8308AO=@D0QF0f0P23H3H01P22
GcD0PEhd081M<`1oG380OU/a07eJ<080Oe`b0`20GC<3085N=080Oed`0`1nG2l307eK;P0607]L<01j
Fbl0NU/_07UJ;P1hFBd0MeP/0P1fEb/02P1aE2`0L5<[06mB:P1^DBT0K4lW06]>9P1ZCBD0JD`T06UA
;@1ZDRh206]C;`0406YB;P1XD2`0IThZ06A<:080I4XU00@0I4`X06=<:P1PC2/0GDXZ0P1KB2P01P1H
AbT0EdLU05E58`1C@b80D3lQ04hm8@80CSdS00X0CcdU04Xl8@1:?240Ac/Q04Dk8P12>R<0@3XT03li
8`0m>2@0?STS0P0m>2800`0l=b40>cHP03Xe7`0203Td7P0803Tb7`0h<Ah0=S4N03<`7`0`;Ql0;BhP
02`]7`0[;B0202T[8080:2XO0P0W:Ah202HX7@<09RLO0P0U9Qh302@U7@P082<L200O8Q/8024T7@H0
7b8K100N8AX201lR6`0:020S700Q91d08B@M028U7P0Q9a/092LL02DW700V:1d0:2PN02/X7`80;BTP
00<0<bhK03@_700f<Ah00P0h<b003P0g<Ql0=S4N03D`7@0c<B@0<S0S034_8P0^;1l0;2XM02XX6`0X
9QT09bDH02DU6`0V9Q`0:2PN0P0Y:Al00`0X:1h09RHL02DU6`0302PX7P809bLM0`0V9Q`202@V6`80
8bDJ100R91T2020Q6@<08B8J300R8a/0:00Q8aP08R@I02@T600W9AT0:RHJ02hX700_:A/0<2PK03X]
7@0n<B40A3DR04Hf7`18=ad0C3/O05E28P1KB2P0K50Y07EI<P1oHc/0PVLl085V=`24JST0S78o09=i
AP2ZMTL0YgM90:1cBP2CKDP0Of1106Y@=@1F@RX0BSPR03L/6P0f:aT0<bXI02lY6@0]:Ad0;B/O02`/
8P0[;B8302X[8`<0:b`T0P0/;BD202//9P0402`]9@0];b@0;S0S02h`8`80;c4S0P0f<B/00`0f<RT0
=S8W03Hb9P0203Hc900903Hc8P0h=RT0>3HY03Tf9`0k=BD0?CHT044i9P13>bP0Ac`X0080@chX00<0
@cdW04@l9`16>bL00P17>RL02@19>RL0B3`R04Pl8P1:?R@0C40V04i2:01@A2X0DTH/05A8;P020594
:@0305=5:P1DAR/0EDL/0080ETP]01X0EdT^05a=;P1MC2h0Gdl^069?;P1UDBh0JE<^06]C;`1[Dbd0
Le`c07AM<`1gH3@0NF<d07iV=P21JSP0Q6di08Q_>@27KSH0RW4i08ie?@2AN400TWU008mf?@2;LST0
R70d08M]<P80Qfdd00D0QV/d08EZ=@24J3H0Q6Ph08=W=`0208YZ>`0F08][>P2;JcP0SFhh08i_>02?
L3T0T74h09Ub=`2JLcP0V7@j09Md>P2ELSX0T70g08e^=`2;K3D0PfDc085R<`1jGRl0MEX]06mG:`1/
DbX0JU<Z06YB;080JT`X00L0J4XV06M99@1ZC2P0L58^07AF<P1cEC40L58^00<0L5L_00D0LEP`07=J
<P1eG3@0N5lg07YQ>@0207IO;@0907IN;P1fGS00MEda07AK<P1cFS40LUTa071G;`1_ERh0KE@/0080
JU<Z00<0Je@[06aF;@1]Ebh00P1_F2`00`1aFBd0LeP]07EH;P0207QH;`0307YI<01lGBl0O5d_0080
O5d_101mGS001P24H300PV0`089P<021HC00Of4_07eQ;`80O68_0P22Hc@2081T=00407mS<`1mHc80
OF<b07aR<@<0O60`101mHC404@1nHS80N68`07MQ<01gHC00MV0a07AM<@1cG380Le`c079K<P1aG340
Lehc07EP=@1eHSL0M64f075N<`1^Fc00JeX^0080IU@^00@0I58/06=A:`1QCbT0H4hX0P1OCBL04@1S
Dbl0HU8^065A;`1NCRd0G4/]05Y9;@1HAb/0EdH/05M::01FBBL0EdPW05M79P1HB2L0G4TY05m::`1P
Bb`0IE<]0080He4[00d0IeD_06aJ=01^G3H0JeTc06ME;`1]Ec80K5Ha06YD;`1WDB`0HddX061:9@1N
B2<0G4HQ0080I54Y00@0HU0X05m@9`1NCbH0G4lU0P1JCR@03P1CBBD0DTPT05168`1>@b<0C44S04Xo
8`19?R80B3`R04Dn8P14?B40@c`P048k7`11>Qh0@3TM0P0o>1`01`12>1l0@3TO040i7`0o>1h0?CLM
03`h7@0i>1`00P0g=a/203`h7@80>cLL0`0j=Q/00`0i=AX0>STM03Xi7@0203Th70<0>3LK00<0=cHJ
03Pf7`0h=Ql00P0g=Ah203Hd7@80=C<L00<0<S0K03<a700d<Qd00P0f=1l00`0d<Qd0<c4L038`6`03
02h`6`80;BlJ0`0/;QT402`_7P0502/^7@0Z;A`0:B`K02T/6`0X:Q`00P0W:A/00`0V:1X09BLI02DW
6@0202@V6008028V5`0R9QP08BDG020S600O8QT07R4J01hP6`0M7aX301`N6`806adJ0`0J71T201/M
6P806Q`I0P0I6aP201PJ5`P05aTH200H6QTK01LI60805QPG0`0E5aH301LI60805QPG0`0E5aI101HH
5`P05AHH400E5aH301@E5`<05AHH0P0F5aT301DG5P@05QPG0`0G6AP401HH5`D05ALF0P0F61L301LI
60P05QPG200F5aT801HH5`P05QLI0P0F61L301LI60<061XI2@0I6Q`:01LI60<061XI0`0I6aX801XL
6`P06QXJ200I6aX801/K6A006adJ0P0L71X301dM6`<07QhL0P0M7QP201hO6@807b0J0P0P8A/3020O
6P<08B0K0P0R8A`802<S6`P092@L0P0S8Qd3028Q70/08B0K0P0R8A`2024P6`8081lJ0P0O7QT8024Q
6@P08R4L2@0R8QX2028Q70<08b8M0`0T8ah0200P81P08R8J02DU7@0W9al0:2PP02HV7P0T91`08b<K
0`0Y9A`202XV7@<0:bLN0P0/:1`402dY7@80;RXN0`0b:1`303<Y7@80=2XN00H0=bXJ03P[6`0g:a/0
>2`L03T]7@0h;ah203T`7`@0?2lN00D0?C0O03ha800o<R40@3<R04Ph8@0204Lg800504Hf7`15=Ah0
A3@M04@d7@13<a`02014<b4804Pf8080B3<N00H0AS@N04De7P14=Ah0@SHN04<g7`12>1l304Hf7`05
04De7P14=1d0@c<L048b6`11<AX00P0o=20203hc7`80?C8N0P0l<Ad0200j;a/0?34M03hc7`0o=200
@3DQ03ld800n<al0?C8N0`0m<R0203`a7`<0>c0N00<0>RlM03/`7P0l<Al00P0m<R000`0k<1h0>BhL
03L/6P0803H]700=03H[5`0g;1X0>2dK03T]7@0h;1h0=b/O03DX7`0c9Qd0>BdM03P/700g:a/0=RXJ
03L[6`0203T]7@0303/_7`0l<200=b`J0080=b`J0P0h;A/303T^7080>2dK0P0i;Q`303X_7@0303/`
7P0o<Ql0?c8O00H0?c8O0P0n<Q`05P0m<1d0?2lN03/^7P0j;1l0>R`Q03T[800g:QX0>2/K03L[6`0f
;A`0=RlM03Ha7P0d<Ah0=C8O03Xb7`0i<Ah0>c0N03lb8@16=RH0B3LW04@c8`11;Ql@03/`7PP0<b`L
00<0=bhM03H]700f;A`01@0e;1/8038Z7@80:RXP00<0:BTO02PX7P0W9ad00`0V9Q`03P0U9aT09bPJ
02LX6P0Z:1/0:bLK02hX700_9a`0<2PM02lY7@0b:Qd0=BdP03T`8@0m<B40?c8Q0P11<Ql0200l<200
>blO03X^7P0i;Ad0>RhN03/_7`0m<B40?c<S2014=1d00`0o<a/0@3@L048f7P0304@h800504<g7`12
=Qh0@c<L04De7P16=Ql00`18>2400`17=b00ASHO04Dh9@0204Dh9@80A3LT1013=R<0200o=1h0?S<M
03`a7@0k<1h0>RlM03/_7`0l<280?C4S0P0n<Ah203lb7`@0@3<P00H0?BdN03/^7P0j;Ad0>2`L03H]
700e;Q`203@_7080=2hP0P0c;Al2038/7P80<B/M0P0`:Qh4034[7`80<R`P0P0f;A`603D/6`0303`a
7`0m<R00?S<Q0080?c@R00<0?C8P03`a7`0k<1h0200l<20603/`7P80>RlM0`0m<R0[ooooo`00:_oo
ool01P2QMT/0XGI90:9gBP2RN4P0XgU70:=jAP80Y7]5202SNTH02`2TNdL0XgY60:9iA@2RNDD0XgY6
0:AkA`2UO4P0YWe90:MnBP2VODT0YGa80080Y7]700<0YGa80:ImB@2WOTX00P2UNTL20:IkB080Yga9
1@2XODX20:UnB`<0ZWm<202WOd@20:ImB@80Ygi:0`2XOd/0102YP4`0Zh1=0:^0C@2[P4d30:YoC080
ZGi;2@2ZPDd00`2[PTh0ZX5=0:V0C0020:QoB`060:Z1C@2/Pdl0[HA@0:b2D02[PDl0ZGm=0P2XOT`0
0`2YOdd0Zh5?0:b2D0080:^2CP030:b3C`2[PTh0ZX5=0080ZH1<00<0ZX5=0:^2CP2/Pdl0202/Pdl8
0:Z1C@80YH1<00<0Y7m;0:=nBP2RODT00P2QO4P01P2PNdL0XGM50:5gA@2PMT@0WgE309id@P80WG=1
00`0W79009Qc?`2HLcl0Ug8n09E`?02DKc/0Tfhj099]>@2AK3P0T6Xk08mY>P2=IcP308]U=P0408aV
=`2=IcP0RF<f08US=P80R68e0`27HC@03@26H3<0QV0a08IP<@24Gc80PElb07iM<P1lG3<0Ne/d07QK
<`1mFS80O5Ta07YG;`1hEBd00`1gE2`00`1hEBd0Le8_07=B;`02079A;P04075@;@1`Cb`0Kdh[06m>
:`80K4h/00<0Jdd[06Y<:P1ZC2X00`1ZC2X07@1bCRh0LTh/075=:`1aCBT0LTlY07AA:@1fDbT0Me@Z
07YF=P1iEC<0N5@b07MC;`1hEBl0NEH^07]H;P1lFBl0OUd`07mN<@20GS00Pel_08AP;P26HBd0RF4^
08UQ;@27HC80R68c08US=02:I3D0RfDf0080SFLh0P2>J3T02`2@JcH0SfXf08iY=@2=IcH0SFLh08iX
>`2?J3d0T6Tn08eW>02>J3T0SfTj0080T6Xk00<0SfTj08iX>@2=IcP00P2<Ic<0102=J3@0SVTe08iY
=@2?JSH3091[=`0708mZ=P2=J3@0S6Lc08]V<P2<Ic<0SFPd08iY=@0308eW>080S6Hg0`2;ICH208aV
=`0308iX>@2?JCX0T6Xk0080SfTj00<0SVPi08eX>`2=J3/00P2<IcX308]V>@0308YU>02;IcL0RfLg
00H0RfLg2029ICD808UT=`<0RFDe0P28I3@308MS<`<0QV4g00D0QF0f08AO=@24GcD0Q5le08=N=003
085N=0<0P5dc0P1oG38207mL=0<0P5de0`21GSH207mM;`<0OU`^0`1mFbd207]L<00307YK;`1iFRh0
N5T]0080MeP/00L0MUL[079E;@1bEBd0LE@/06mB:P1^DBT0K4lW0080JdhV00P0J50/06UA;@1ZDRh0
JU8^06UA;@1WCb/0IDdY06=;9`80ID/V00@0Hd/W069;:@1OBbX0GDXZ0P1KB2P02@1IB2X0F4PV05M7
9@1DA2<0DD0R04ln8P1>?B<0CchT04lm9@0204/m8P0604Pl8P15>b80@SXS040j900o>B<0?CPT0P0n
>B<00`0m>280?3LQ03/f800203Xe7`0903Td7P0j=1h0>S@N03Pc7`0d<Ah0<S4O02h_7`0];Qh0;2hP
00<0:B/P0P0X:Ql302LY7P0402LX800V9al09RLO02HW7`809BHN0P0T9Ad8024T7@P07b8K200Q91d2
020S70<07b8K1@0N8AX201lR6`<082<L00L08B@M020V6P0Q9a/08bHK02DW700V:1d0:2PN0080:bPO
00<0<B`I038]6P0d;a`00`0f<Ah203@_700603@a8P0c<240<RlP030]7P0^:a`0;BXK0P0[:1T00`0U
9A/09RHL02PX7P0202TY7`0302PX7P0V9Q`09BDK00<0:2PN0P0W9ad302HV70809BLL0P0T9Q/302<U
6P03028T6@0P8AT08B8J00808B8J0P0R8a/302<T70<08R<K0`0Q8QX2020Q6@8082@F02H08R@G02@T
600W91/0:BDL02XV7@0/9Ad0=2XQ03P^900m<BD0?c8R044b7`16=Ql0C3`S05=2:01O@R80IdXX075E
<01hG3@0OF8e08E[>P2@MT<0VH1:09Q`?@2LM4<0WWQ909]iC02ALTH0PFDm071G;`1VCRP0C3XR04Lg
800n<Ah0=b`J030Z6P0^:Qh0;2`R02d_9080:BXR0P0Z:b<302//900602`]9@0Z:bH0:R/V02//9P0/
;BD0;BlT0P0^<2<01`0_<B<0=S4]03Ha;@0f<B/0=C4X03Da9P0e<BD00P0d<B8203Hd:00>03Hb9P0h
<R@0>c@T03he9011>2L0A3TW040n9`0o?BH0@C`V044k9@13>bH0AS/W04Pk:019?2T304Tm8`0504Xn
901<@2H0CT8X0555:`1BAR`00P1?A2P00`1@ABT0DDHZ0597:`0205=8;00I05A9;@1IBbh0FT`_05a=
;P1NCRd0H50^06=A;@1UDBh0IU8]06mI=01`FS<0LU/a07EM<@1jH2l0Of<a08AV<026JC40QVPb08U[
=@2>LCT0TWDk09Ag>`2CMcP0TGDd08mc<P0208]a=00608ab=`2<LST0Rg4h08Y_>028KCP0Qf`g0P2=
KT005P2<KCh0Rfdk08]]>@2<KSP0SFli08e`>02CK3D0UFhg09E`>@2FLc/0Ug@l09Ee?02CMCT0TW@h
08Y[=027J380PF<a07YN;P1dFBh0KeH]06eC;P1[Dbl206]=:@0806U;9`1XBRH0JddY071B;P1cEC40
LU@`06mA;@1cEbl3079F;P0D07=G;`1fFS80N5`d07YN=P1hGR/0NEl/07UO;P1iGRl0NEha07QM<P1f
FS80METa07II<@1cEbl0L5@/06aC:P1[E2X0JeH[06]H;@1]FRl2071K;P04079K;`1cFbl0MU/`07MJ
<080NUXa00<0NE``07YM<@1jGC401@1jGC401P23Gbl0PEl_085O;`20H2l0P68`07iR<080OF<`00T0
QFDd08IV=@25IcD0Q6Pf089X=@1oJ3@0OVLc07aW<P1mHBl01`1nHS005@1hHS00Mf4`07IP;`1eGc00
Le``079K<@1aFS40L5T`07=L<P1dGC<0MF0e07=P=@1aH3@0KElb06UL;`1WFRd0I5@`06=C;`1QDBd0
Gdl[05e=:@0205a<:00O05e=:@1ODBh0GU0]05e>;@1KC2d0FT/^05Q8;P1GAbd0ETH]05Q;:@1GBRP0
F4TX05U9:01JBRT0Gd`/069=;P1TCc00IeD]06EC:`1TDRX0J5H^06aJ<P1]Fc<0JUP`06ID;01_F3H0
K5Dc06I?;@1QBRP0GTLU05e6900205i79@0606EB:P1TDBT0He4Y061A:01OD2L0GE0V0P1KCbD03P1B
B2@0DDLS05168`1>@b<0Bd0R04Tn8P17?200ASXP04Dn8P14?B40@c`P048k7`11>Qh0?cPL0P0n=a/0
1`11=ah0?cPN03lh7P0n=ad0?CLM03/g700i>1`00P0g=a/203Th7080>3LK0`0g=QX00`0f=AT0>CPL
03Th700203Pg6`<0=cHJ00<0=SDI03Pf7`0h=Ql00P0g=Ah203Hd7@80=C<L00<0<S0K03<a700d<Qd0
0P0e<ah00`0d<Qd0<c4L038`6`0202h`6`80;BlJ0`0/;QT00`0[;AP0:bhM02`_7P0202`_7P0502/^
7@0Z;A`0:2/J02LZ6@0W:A/00`0V:1X202DW6@8092HH00H08RHG024U5`0Q9AL082<H01lR6@0N8AX2
01dO6P<071hK0P0K7AX601XL6@806A/H0`0H6QL801LI60P061XI6`0G6AP201HH5`<05ALF0`0G6AP2
01HH5`<05ALF@@0F61L801DF61005ALF0`0D5AL301DF60805QLI200E5aH801HH5`<05ALF0P0F61L3
01LI60P05QPG200E5QP801HH5`P05QLI0P0F61L301LI60<061XI2@0I6Q`;01LI608061XI0`0I6aX8
01XL6`P06QXJ200I6aX801/K6@P06Q`I200K7AX201`L6P<07AdK0`0N7Q`201dN60807QlI0P0O81X2
020Q6`<081lJ0`0Q81/2028Q70P08b<K200T91`0100S8Qd08R4L028Q700R8A`2024P6`X081lJ0`0Q
81/2020O6P<07ahI200Q8AT8024P6`T08R8J0P0R8A`302<R7@<092<N00@08R8J02<S6`0T91`09BDM
0P0V9Qh00`0U9Ad092@L02TU700202TU7080:RHM0`0[9ah8030Z7P80<BLK0P0b:1`303<Y7@0:03@Z
7P0i:AX0>RXK03P[6`0h;1`0=bhM03L`7P0h<Al0=c8O03d`7`80?2lN00D0>bhM03`_7P0m<1l0?S4P
03lb8@0404Hf7`@0ACDN00@0@S4O04<b8013<R00@c8P0`14<b400`15=280B3HP04Pf800604Pf8080
Ac8M00H0AC<M04De7P14=Ah0@SHN04<g7`12>1l404De7P0404@d7@13<a`0@C4J040`6@<0?S<O0P0m
<Qh303`a7@0303X_6`0k<1`0?C8N0080?c@P00<0?S<O03db7P0l<Ad00`0l<20203/_7`<0>RhN00<0
>2dK03X_7@0l<Al00P0m<R000`0j;ad0>2dK03H[6@0803D/6`0:03@Y5`0e:AT0=RXJ03HZ700f:Qh0
=2LN038U7@0a91`0>B`L03P[6`80=bXJ00H0>2/K03X]7@0j;Ad0?2lO03d`800g;1X303P]6`80>BhL
0P0j;ad203T^7080>RlM0P0k<1h203`a7`P0?S4N0P0m<1d00`0l;ah0>bhN03X/7`0203T[800703PZ
8@0h:a/0>2/K03P/700f;A`0=BhL03D`7@0203<`7@0;03P`7@0g;a`0>RlM03lb8@16=RH0AcHV04<b
8P0o;1d0?34O03/`7P0j;ad00P0i;Q`00`0j;ad0>c0N03`a7`0803X_7@P0<bdO00<0=RdL03D/6`0d
:aX00`0d:aX00`0e;1/0=RdL030Z7P07030Z7P0402TZ8P0X:B409RLO02@U7@808b@L0P0T9Ad01P0T
9QP09RLI02HW6@0Y9aX0:bLK02hX7080<2PM00H0<B/O03<[7P0f;R40>C0Q03``800n<B0203l`7@03
03da8@0l<200>blO0080>RhN00<0?30P03hb8P0o<b<02014=1d02`0o<a/0@3@L048f7P13=al0A3PP
04<g7`12=Qh0@CDM048b6`14=1d0ACDN00<0AcLP00<0ASHO04De7P13=R<00P13=R<2048e8P@0@C@Q
00<0?c@N03hc7@0l<Ad00P0j;ad0200j;Qh0?30R03``8P0l;a`0?C0M03ha7P0o<Ql0@3<P0P0o<Ql0
1`0n<Ah0?2lO03/^7P0h;1`0=B`K03@]6`0c;Q/00P0b;a`203<]7`80<R`N00@0<B/M030Z700_:A/0
;bTK200a:al203H]70<0=B`K0`0d:aX00`0i;Q`0>RlM03`a7`0303hc8@80?34O0P0l<200100k;al0
>RhN03X^7P0k;al203``8080>c0N0`0j;ad303T^70<0>blO:oooool002[ooooo00H0X7E:0:1eB02P
MDP0XGM70:5gA@2RNDD20:9i@`P0XgY600/0Y7]70:=jAP2RNDD0XGQ40:9iA@2SNTH0YGa80:ImB@2W
OTX0YWe90:ElB0020:AkA`030:ElB02VODT0Ygi:0080YGY70P2VNdP20:MlB@D0Z7e:0P2YOT/30:Yo
C0P0Ygm40`2VODT20:MnBP<0Z7m;0P2YOT/30:YoC0<0Zh1=2`2ZPDd02@2YP4`0Z7m;0:V0C02ZPDd0
[8=?0:j5D@2/PU00Zh5?0:Z0CP020:QnC0030:Z0CP2[PDl0[89@00P0Zh9>00<0[8=?0:^2CP2ZPDd0
0P2YP4`00`2ZPDd0Zh9>0:b3C`080:b3C`D0ZX5=0`2[PTh01P2VPDd0YH1<0:F0C02TOd/0Xgi:0:9m
B@80XGa80P2QMdD20:1fA00:09me@`2NM480WG=109ec@@2IM400V7<o09Mb?P2FLCd0U6lk099]>@80
TF`h00<0T6Xk08iX>@2=IcP00P2;ICH00`2<ISL0SFLh08iX>@0208US=P@0R68e0P27HC@208IP<@0<
08=N<@20GS40OE`a07]K<P1jFS<0MeXb07aI<@1kF300N5D]07IC:`1eDRX0MU<[0P1gE2`207AC<004
07=B;`1bDBh0LE0]071?;080Kdh[0P1/CR`306]=:`80JT`Z0140JD/Y079>;P1aCB/0LDd[071<:01a
CRP0Le0X07IC:@1gE2X0NEDe07QD=01gDc40MU8^07MD;P1hEBl0NUL_07]H<00207aK;P0707iL;P21
GBd0PUh/08AO:`27Gb`0R60/08US=00308YT=@0308]U=P2<ISL0S6Hg0080S6Hg00/0T6/f08mZ=P2>
JCD0SFLf08eW>02>J3/0SfPm091Y?P2=IcP0SVPi08mY>P02091Z>`0308mY>P2>J3T0SFLh00H0SVTe
0P2?JSH01P2AK3P0SfXf08eX=02<Ic<0RfHb08aW<`80SFPd00<0SVPi08eW>02=IcP00P2<ISL208]U
=P0908YT=@29Hc@0RfDf08eW>02>J3T0SfTj08iX>@2=IcP0S6Hg00<0SFPk0P2<IcX308]V>A00RFDe
2029I3L408UU=@80R6@d0P27Hc<02029I3X0R6<i08MR>026HCL0Q5le08=N=022GC<0PE`b0`1oG380
1@20GC<0PEhd085N=021GS@0PUle0080Oe`f0`20GCL3085N>080Oed]0`1nG2`307eK:`80Ne`^0P1j
Fbd02P1iFR`0N5T[07MH:P1gF2X0M5L_07=F;P1bEBd0LE@/071C:`1^DBT206e@:080Idl[0P1XD2`0
101WCb/0IDdY06=;9`1RBRH206E;9P0306=;9`1QBRP0GTXY00<0G4TY00H0FDPZ05Y::01HB2H0EDDT
05918`1@?b<204ln900904lm9@1<?R<0BcdR04Pl8P16?2<0@SXS040j900o>B<0?CPT0080?STS0P0m
>280300l=b40>cHP03Xe7`0j=Al0>cDM03/e7`0i=1h0=C<N03<b7P0`<Al0;c0P02d`7`@0:B/P0P0X
:Ql202LY7P809bPP0`0V9al302DV7PP08B@M200O8Q/;020S700301lR6`0N8AX07R4J00807B0I0P0N
8AX401lR6`8082<L0P0O9aX00`0Q9a/092LL02HX7@0202PX7P0902/X7`0_:QL0<2/H038]6P0c;Q/0
=2lL03<^6`0b;AX0<B`I0080<RlN00<0<BhM030]700_;1/00P0^:aX0100]:QT09BDK02HV700X:1h2
02TY7`0302PX7P0V9Q`09BDK00<0:2PN0P0W9ad302HV700402HX6`0U9aX09BLJ02DW6P8092HI0P0S
9AP3024R6P808R<K1@0S91`2028S6`03024R6P0P8AT0824I0080824I02P07R@F024U5`0Q9AL08bDJ
02@T6P0W91d0:2<M02TT800]9B80<RTT03D/8`0g;B<0>BdO03d`7`16=b@0Bc`W05@i701I?R00GdDR
06M>9P1`F2X0NV<a08A]=`2;MC`0RFll08ab?`2AMd@0UGY509=h@`2@LS`0R6Xd08=U;`1YE3T0H4`c
05109`10<b00=B`K02l[7`0_;B40;blU0`0Y:R8202X[8`<0:b`T0P0Y:BL00`0Z:bH0:b`V02`]9@02
02d_900702h`8`0f<Bh0=S4]03D`;00e<2X0=30W03@`9@0203<_8`0903@a:00c<BD0=30U03H`900h
<2<0?3<T03he9012=RH0?CdU0080?C/T00L0?cXT044k9@15?BP0BChZ04]0;01;?bD0BShT0080BCdS
00D0BShT04a09P1?@bT0D4@Z04i39`0204m4:0030515:@1AARX0DTL[0080DdP/00H0ETd`05M<;P1H
CBl0Fdh^05i?;P1PD2h206=A;@0V06YF<`1/ES40KEH]071H;01eFBT0NedY07mP:@23HbX0Q6<^08MV
<@2;Jc80T70e09Ae=@2EMSD0UWLd09Ih<P2>MC<0SgHf095h>02AMcX0TGLl08me?02=LS/0S74j09=d
B02ALT@0Sg1208e^?`2<KS`0S6hj08a^>02=KcT0TVXf09A/>02DKcP0UW<k09Md>P2FMS/209Af>008
091`=`2=KC@0QfPb081Q<P1hFbl0M5P`075E<01^E34206e?:`0706Y<:01YBbL0JddY071B;P1bE300
L58^06e?:`0206mC:`0G06iB:P1]DBT0KU8Z06mC:`1aEBd0LUH^07MN:01hGR/0NEl/07YP;`1jGc00
NEha07ML<@1eFRl0NUXc07II<@1aEBd0K5<Z06YE:P1YER/0JeX^06]M<01aGc400P1cGS401@1eGS80
MUhb07QM<P1iG380NUdc00P0N5d`0100PEd]081N;P20GRh0P60_081R<01oHc40OV@a07mU<P26HS00
QF@a08EU<P25Ic<0PVTc07iW<@1kIRl0NFH^0`1oI2l507iS;P0D07MQ;`1fH2l0MEl^07=M;P1bFbl0
L5T_06mH;`1^Ebh0LUT`075J<01_FRl0K5/_06UK;P1VFB`0HUX[065I:P1SEC80HU@a05mA;P1MCb`2
05]=:P80G4h[0200Fdh[05Y=:`1JCB/0FD`/05Q:;@1GBBh0ETP^05E7;@1JCB/0FD`Z05Y;:P1LC2/0
GTh]069?;`1VDC80J5<d06QG;01VEBX0IE@Y06QG;01[FRl0K5/`06QG;01SDRL0ITl_06A=;@1RBb/0
H4TY05m8:01PBBT0HDXZ069;:`80HTlW01L0H4hV05e>9@1LCB@0FTdS05U=8`1HC280DTPT05578`1?
AB80CD8R04Xo8@18?B40AS/O04Di7`15?R80A3dQ04<l8012>al0@3TM03lh700n=a/0?CHJ040f7@03
03hg7@0403`f700k=a`0>CPL03Ph70@0=cLK0P0f=QX303De6@<0>3LK0P0g=QX303He6@80>3HO0P0g
=Ah203Hd7@80=C<L00<0<BlJ038`6`0d<Qd00P0e<ah00`0d<Qd0<S0K034_6P0302d_6P<0;2hI0P0[
;AP0200[;Qd0;2lN02`_7P0/;ah0:bhM02T/6`0W:QT09BPG0P0V:1X402DW6@8092HH00H08BDF024U
5`0P91H07b8G01hQ600N8AX201dO6P<071hK0P0K7AX501XL6@806A/H100H6QL801HH5`P061XI6`0G
6AP201HH5`<05ALF0`0G6AP201HH5`<05ALF@@0F61L801DF61005ALF0`0D5AL301DF60805QLI200E
5aH801HH5`<05ALF0P0F61L301LI60P05QPG200E5QP801HH5`P05QLI0P0F61L301LI60<061XI2@0I
6Q`:01HH5`805aTH0`0H6QT00`0I6aX06Q`K01XL6`0601XL6`P06QXJ200I6aX801/K6@P06Q`I200K
7AX201`L6P<07AdK0`0N7Q`201dN60807QlI0P0O81X2020Q6`<081lJ0`0Q81/2028Q70P08b<K200T
91`3028Q70808B0K2`0P7aX2024P6`8081lJ100O7QT8024Q6@P08B0K2@0R8QX2028Q70<08b8M0`0T
8ah0200U9Ad092@L02<S6`0S8a/092@L02DU7@0V9Qh09bLO0`0Y9A`202XV7@<0:bLN100b:Ql4034Y
7P<0<BLK0P0b:1`303<Y7@0@03/X6P0k:A/0>RXK03T/700g;Qd0=c0N03Lb7`0e<Ql0?S4P03d`7`0k
;Qd0>RdL03/^7@0l;ah0?S4P03lb8@@0ACDN1016=Ql3048a7`0304<b8014<b40A3<Q0080AC@R2018
=R0204Ha700604Dc7@14=1d0A3DN048f7P13=al0@SPO0P14=1d01P15=Ah0ASHO04De7P13<a`0@30I
03l_6080?S<O0P0m<Qh403`a7@0903X_6`0k<1`0?C8N03hc7`0o=200?S<O03db7P0l<Ad0?30R00<0
>blQ0P0j;R0203T]7`0303L/6P0i;Q`0>c0N0080?C8P00<0>RlM03L/6P0d:AL0200d;A/02P0e:AT0
=RXJ03L[7@0h;200>2/R03HY8@0d9al0<bHP03XZ6`0i:AX203PX6@0503TY6P0l;1d0?2`M03h^7`0o
;b00100i;Q`203X_7@D0>c0N0P0l<Al303db80P0?S4N00H0?C0O03`_7P0l;al0>bdP03X/8@0i:b02
03PZ8@80>RdM00@0>2`L03H]700e;Q`0<bhK0P0a;Q/203H^6`0903T^700n<B00ACDU04He9@11<200
?BXK03`a7`0k<1h0>BhL0080>2dK00<0>BhL03/`7P0l<Al0200i;Q`8034^7`0803H]700e;1/0<bXI
038Y600c:QT0=2/J03H]700g;Qd802dY7P0402P[900V:B8092LP028U7P808B@M00P08RDN02<V7`0S
9AL09BHH02HW6@0Y9aX0:bLK02hX7080<2PM0100<bdQ03D]800g;b80>S4R03``800l;ah0?BhK03`]
6P0m<B40?30P03/_7`0j;Qh0>blO03``800n<R80?c<S2013<a`0400n<QX0@3@L048f7P13=al0A3PP
04<g7`12=Qh0@CDM048b6`13<a`0ACDN04Hf7`17=b00ASHO04De7P14=1d2044d8@80@3<P100o<Ql0
6@0n<Ah0?S<M03db700k<1`0>RlM03T^700j;Qh0>blQ03``8P0j;AX0>bhK03d`7@0n<Ah0?c8O03ha
7P0m<1d0?2lL03/_7`0j;Qh0=RdL03</6P0b;AX0<2dJ034^6`0a<1`00P0b;1h01P0a:ad0<2XL02lY
6`0^:1X0;BLI02`V60P0<B/O0P0f;A`203D/6`80=2/J0P0c:QT0100e:QP0=b`J03T^700l<Al303db
800403`a7`0l<200>blO03X^7P80>BdM00<0>RhN03/_7`0l<2000P0k<1h203X_7@0403T^700h;A/0
>2dK03P]6`<0>2`N:oooool002[ooooo00H0WgA909mdA`2OM4L0X7I60:1fA02QN4@20:5h@PP0XgY6
00<0Y7]70:=jAP2QN4@00P2QN4@01P2SNTH0YGa80:ImB@2WOTX0YWe90:ElB080Y7]700<0YGa80:Im
B@2WOTX00P2UNTL20:IkB080Yga91@2XODX20:UnB`<0ZWm<202WOd830:ImB@<0Ygi:0P2XOd/20:Qm
BP030:UnB`2ZOd`0Zh1=0080[85>00<0[H9?0:Z1C@2ZPDd02@2ZPDd02@2YP4`0Z7m;0:V0C02[PTh0
[HA@0:j5D@2/PU00Zh5?0:Z0CP020:UoC@030:Z0CP2[PDl0[89@00P0Zh9>00<0[8=?0:^2CP2ZPDd0
0P2YP4`00`2ZPDd0Zh9>0:b3C`080:b3C`@0ZX5=102[PTh20:J1C@030:F0C02TOd/0Xgi:0080XWe9
00L0XGa80:9hAP2QMdD0XGM50:1fA02OMD<0WWA20080WG=100h0VGA009Qc?`2GLSh0UW4m09A_>`2B
KCT0TF`h091[=`2@JS/0SVPi08eW>02<ISL0RfDf08aV=`80SVPi0`29HcH508QR=@0F08IP<@25Gc00
Peha07mM<01mG340NUXa07UI<P1fFC40O5Ta07YG;`1gE2`0ME8Z07AA:@1eDRX0MU<[07MD;01eE340
M5<`07=B;`1bDBh0LE0]071?;080Kdh[0`1/CR`206]=:`80JT`Z01T0JD/Y079>;P1aCB/0L4`Z071<
:01aCRP0Le0X07EB:01gE2X0NE@g07QD=01gDc<0MU8`07IB;P1gE2h0NEH^07YG;`1jFB`0NeX]07eK
;@20G2`0PEd[08=N:P26GR/0Qel[00T0RfDf00/0TF`g08mZ=P2>JCD0S6He08aV=`2>J3/0SfPm095Z
?`2=IcP0SVPi08mY>P02091Z>`0408mY>P2>J3T0SFLh091[=`<0SfXf0`2>JCD01@2=J3@0TF`h091[
=`2>JCD0S6Lc0080RfHb00D0S6Lc08eX=02>J3T0SVPi08eW>00208aV=`0;08]U=P2:I3D0RV@e08QR
<`2:I3D0S6Hg08eW>02>J3T0SFLh08aV=`2:I3D00`2=J3/308aW>P80RfHi2028I3@808UU=@P0RF@g
00@0RVHf08UU=@29ICD0RFDe0P28I3@208MS<`0>08YU>`29I3X0R6<i08IQ=`24GcD0PUdc081K<@1o
FS00OEX`07iK<@1oG380P5dc085N=022GcD208=P=P80Oe`f0`20GCL3085N>080Oed]0`1nG2`307eK
:`0607aM;P1kG2d0Ne`]07YK;01iFR/0N5TZ0P1gF2T207EH<00407AG;`1bEBd0LE@/06mB:P80KU4Y
0P1VCRX206M?:`0906I>:P1TC2P0HTXV06599@1VC2L0ID/V06=;9`1QBRP0GTXY00<0G4TY00H0FTT[
05Y::01HB2H0EDDT05918`1@?b<204ln900:04lm9@1=?b@0C3hS04Tm8`16?2<0@SXS040j900o>B<0
?CPT03lj9080?STS00<0?CPR03`g8@0k=R000P0j=Al02@0l=Qh0>cDM03Td7P0f=1l0<c8N030a7`0_
<1h0;S4P02X/8@0302T[8080:2XO0P0W:Ah302LX80809RLO0`0U9Qh8024T7@P07b8K200P8a`0100Q
91d082<L020S700O8Q/201hQ6P807B0I0`0N8AX501lR6`0601hV6@0O9aX082HJ024W6`0T9a`09RPM
0P0X:1h02@0^:AH0;bXG034/6@0b;AX0<bhK038]6P0a;1T0<2/H03@^7P0203<]7@80<R`L0`0a:a/0
0`0U9A/09RHL02PX7P0202TY7`0302PX7P0V9Q`09BDK00<0:2PN0P0W9ad302HV70809RPJ0P0U9aT3
02@V600302<U5`0Q8QX08B8J00<08R<K1@0S91`0100R8a/08B8J024R6P0P8AT301lP600501lV5P0O
9AL08BDG02<U6P0T91`00P0W91l08@0X8b00:B4O02`T8@0a:2<0<bTP03DY7@0i;1`0?c8Q04Lh9@1B
>1d0DSTK05@l6P1I@QT0HDXN06YD8P1`Fb@0M5lV07mb?P23Ld00QgI008ag?P2@N3`0U7Pi09Af=P2E
MSD0PFQ:07EM@@1PC3<0BS/V03P_7P0b;1h0;bdQ02l_9@0302TZ8P<0:R/S0P0[;2@202TY9`0402X[
9P0[;2H0;2dU02`]9@80;BlT0P0f<Bh03P0e<2`0=2lY03@`9`0c;b@0<RhS038^8P0b;bH0<BhU038^
8`0d;R80=blR03Xa8P0m=2D0@3@T0P0k>b<02@0k>B80?STS044k9@15?BP0BD4/04e2;P1<@2H0BclU
04Xn900204Tm8`0304/o9@1=@BL0Cd<Y0080CD@W00<0CTDX04m6:@1@AbX00P1AB2/09P1BBB`0Dd`_
05I=<01GC2h0FDh^05a?;@1ND2d0H50^061@;01XE340JU@_06YC:P1^DbP0LUHV07QH9@1lFbD0PEhV
089Q;024Hbd0R6P_08e]<02ALS80UGHc09Mi<`2HNS80TGPe099i=`2DNc/0UG`l09Ek?P2CNCh0TGLn
091f?@2EN4`0TgI:091dA@2<L400RVhl0P2:KcX04@2;L3T0Tf/h09E]>@2EL3/0UW<k09Md>P2DM3L0
TgDg099d=P2CLcH0T70g08UZ<`22I380NUda07II<@1cEc80LUDc0080Ke4]00X0JddY06U;9`1[CBT0
Ke4]075C;`1_DBd0K4hZ06a?9@1[CR@0JTdS0P1YC2804`1ZCB<0K4lU06e@9P1gG2L0NEhY07YN;01k
Gbl0Nel`07YM<@1hFbl0MUT_07aK<P1iFC00LeH/06eE:@1ZEBP0JUPZ06UK;01/GRl00P1cHC<00`1e
H3<0MUlc07MO<`0207YO=00307]N=01hGC80N5db0080N5db101gG3401P21GBd0Oed]081N;P20H2l0
P68`07mS<@80OfDb00P0Pel]08EQ;`23Hc00PfDa07mV<01kIRl0N6D]07AS:`D0Of@_0`1nHbh0501f
H2h0MEl^07AN;@1bG2d0LEX^06mH;P1^Ebh0KEH]06mF;@1]ER`0JUDZ06IE:@1REBP0H5DW05eG9`1L
ERH0I5Hc069D<@1ODBh0G4h[0P1KCBX02P1LCR/0GDl/05U<:P1IC2X0F4/[05Q:;@1GBBh0EdT_05I8
;P1FAc0205]>;00:05a=;01NCRd0H50_06EB<P1YE3D0JUDf06UH;@1WER/0IE@Y06MF:`80JUT^00P0
IUDZ069A9P1KA2@0G4DU05m8:01QBRX0Hd`/06A=;@80IDh^00H0Gd`T05i;8`1MBb<0FT/R05U:8@1G
BR0205E97`0A0598901AAb<0CdDR04e28P1:?b40Ac`P04Hk7`15>Al0AChR04@m8@13?200@S/O040i
7@0n=a/0?CHJ03`e6@10=Qd00`0m=Q`00`0l=Q`0>cLL03Th700203Ph7080=cLK0P0f=QX303De6@03
03@d600h=a/0>3LK0080=cHJ0`0f=AT00`0e=1P0>3HO03Pf7`0203Le7P80=S@M0P0e<a`00`0a;aX0
<S0K03@b7@0203Dc7P0303@b7@0b<1/0<BlJ00<0;BlJ0P0/;QT302/]6080:bhM00H0;2lN02d`7`0[
;Qd0:B`K02HY600T9aH502DW6@<092HH00P08BDF024U5`0P91H07b8G01hQ600M81T07AlJ01`N6@<0
71hK0P0K7AX501XL6@806A/H0`0H6QL00`0G6AH05QPG01HH5`0601HH5`P061XI6`0G6AP201HH5`<0
5ALF0`0G6AP201HH5`<05ALF@@0F61L801DF61005ALF0`0D5AL301DF60805QLI1@0E5aH301@F5@80
5ALF100F61L201LI60<05ALF0P0F61L301LI60P05QPG200E5QP801HH5`P05QLI0P0F61L301LI60<0
61XI2@0I6Q`:01HH5`805aTH100H6QT801XL6`P06QXJ200I6aX801/K6@P06Q`I200K7AX201`L6P<0
7AdK0`0N7Q`201dN60807QlI0P0O81X2020Q6`<081lJ0`0Q81/2028Q70P08b<K200T91`2028Q70<0
8B0K2`0P7aX2024P6`8081lJ0`0O7QT00`0N7AP08B4I024Q6@06024Q6@P08B0K2@0R8QX2028Q70<0
8b8M0`0T8ah0200V9Qh09BDM02<S6`0Q8AT08R8J02@T700W9al0:BTQ0`0Y9A`202XV7@<0:bLN0P0c
:b04038Z7`80<BTN0`0a9a/3038X7080<bTM00/0>bPJ03`Y6`0j:Q/0>B`L03L^7@0f<Ah0=C8O03@c
7`0n<B00?C0O03/^7@0203X]700403`_7P0n<B00?c8Q04<c7080A3@M00D0ACDN04Hf7`17=b00AcLP
04Ph8@02044`7P04048a7`13<R00@c8P04@c8@80AC@R2018=R004015<1/0AS4L04@b7014=1d0A3DN
048f7P13=al0@SPO04<c7014=1d0ACDN04Hf7`15=Ah0@c<L040`6@0n;QL203hc7`80?C8N0`0l<Ad0
2@0k<1`0>RlK03/`700m<Qh0?S<O03ld800n<al0?C8N03`a7@0303/_8@80>RhP0`0i;Al00`0f:aT0
>2dK03/`7P0203db800303X_7@0f:aT0=2TG00P0<RdJ00P0>2`L03T]7`0j;R00>blS03/^9@0i;2@0
=bXT03HY8`80>BTJ0P0h:1T01P0i:AX0?2`M03`/7@0n;Ql0?blP03T^70<0>RlM0P0k<1h503`a7`80
?C8P0`0n<b4803ha7P80?2lN00<0>bhN03X/7`0i:b000P0h:R40500g:240>bhN03X]7@0i;Ad0=RdL
03@]6`0b;AX0<2dJ02l/6@0e;AX0=2`I03P]6`0n<B00A3@T04Dd9010;al0>bPI03`a7`0k<1h0>BhL
0P0h;A/00`0i;Q`0>c0N03`a7`0803T^70P0<RhR00<0=RdL03D/6`0c:QT00P0b:AP00`0d:aX0=RdL
03L^7@0802dY7P0402LZ8`0V:B808bHO024T7@8082<L00P08B@M028U7P0S9AL092DG02DV600X9QT0
:bLK02hX7080<2PM0100=BlS03L_8P0h<2<0>S4R03``800k;Qd0?2dJ03//6@0m<B40?30P03/_7`0j
;Qh0>blO03``800n<R80?c<S2013<a`00`0n<QX0@3@L044e7@0304<g7`05048f7P11=Ad0@C4J04<c
7014=1d00`16=Ql00`15=Ah0A3@M03lb7`0303lb7`80?S4N0`0m<1d02`0n<ad0?C8L03/`700j;ad0
>BhL03X^7P0k;b40?30R03P[600j;AX0?2lL0080?S4N00/0?C0M03`_700k;Q/0>blO03L^7@0e;1/0
<b`J034/6@0`;AX0<2lK038a7@02034[7@04030Z700_:A/0;BLI02`V6080:bDG0P0b;204034[7`80
<2XN0P0f;A`203D/6`0903@[6P0c:QT0<bXI038Y600b9aD0=2TG03L/6P0j;ad0?34O00<0?C8P00<0
?30P03/_7`0i;Ad00P0h;1`0100i;Ad0>blO03``800k<1h203X_7@0303T^700h;A/0>2dK0080=b`J
0`0f:Q`[ooooo`00:_ooool0202RMd@0XgQ50:AiAP2UNTL0Y7U60:=hA@2QMT<0X7E20P2SNTH30:9i
A@<0XGQ400P0XgM60:AhA`2UNDP0YWY90:MkBP2XO4/0ZGe<0:YnC@<0Z7e:00<0Yga90:IkB02UNTL0
0P2UNTL20:=jAP80Y7]7102UO4P20:QnCP040:QnC02XOd/0Z7m;0:QoB@80Z7m700P0YGa80:ImB@2W
OTX0Z7m;0:V0C02ZPDd0Zh9>0:b3C`<0Ygi:0P2XOd/30:V0C0030:QoB`2WOTX0YGa80080Y7]700<0
YWe90:MnBP2YP4`02@2[PDl00`2^QE40[HA@0:b3C`030:b3C`050:f4D02^QE40[H=C0:^1D@2XOTh0
0P2UNd/00`2XOTh0Zh5A0:f3D`020:V0C080ZX5=0P2[PTh20:b3C`060:j5D@2]Q500Zh9>0:V0C02X
Od/0ZH1<0P2ZPDd80:f4D0@0Yh9>0P2VPDd20:F0C0080:AoBP2UP4/0YX5<0:N2C@2VPD`0Xgi90:5l
A`2ONTD20:9iA@80XGQ40`2PMd<01`2OMT80VWE109Ud@02IM400V7<o09Mb?P2FLCd00P2EL3`208iZ
>P0308eY>@2<J3P0RfLg0080RVHf00<0RFDe08US=029Hc@00P29Hc@408YT=@0808UO=`26G3@0PEXa
085L<P24GcD0Pf0f07mN<`1kFRl307aI;`D0NeP^201eDR`406i@;080KDl[0P1/CRX00`1]Cb/0K4hZ
06]=:@0206Y<:00A06]=:@1/CRX0KDl[06iB:P1`E2`0LeH^07IF;`1hES00Me@^07IC;@1fD2/0NUL_
07aI;`1oG380PV0c08=Q<`23HC400P22HBh00`29IC<0R6@b08IR<00208EQ;`80Qf<a00D0RFDc08YV
=02>HSD0Sf<f095U>00309=W>P05099V>@2AICP0RfDf08eW>02>J3T00P2?JCX00`2>J3T0SFLh08]U
=P0808iX>@P0S6Hg0`2=IcP208aV=`<0RfDf0P28HcH208UT=`0408YU>02;IST0S6Lj08aW>P80RF@g
00@0RVDh08]V>@2;IST0S6Lj0P2=J3/208]V>@<0RVDh0`29I3L01P28HCX0R64h08QQ>028HCH0R68e
08QR<`80R68a2029ICD308aV>@<0RfDh0P2:I3L:08IQ=0<0QF0c0`24Gc801025H3H0Q5le08AO=@24
GcD208=N=080PUdc2020GC<307]L<080NU/_0`1iFRh0101eF2h0M5L]079E:`1`DbT206mB:080L5<Y
00/0KU4W06e@:01/CbL0JT`V06U;9`1YBbT0JDX[06Y;;01OCb/0GThZ05a<:00205];9`0:05a<:01N
CRX0GThZ05m?:`1MA2H0G4DV05]49@1G@R<0E44Q05518080CSlN101:?b<05019?R80B3dQ04Ll8017
?200AcPQ04Pi8P17>b<0AcdT04@m8`11>b40?SPN03/g700n>R40>cLN03Ha6`0c;QX0<B`H038]6P0e
;al0=S0P0P0]<1d01P0/;ah0:bdO02T[7P0X:Ql09bTN02HW7`809RHL100W9ad202PX7P0402<V7@0R
9A`08RDL028U70808B@K0P0P8aX3024T7@8082<L0`0O8Q/8024T7@<07R4J0`0O8Q/2020S70<08B@M
0P0P8a`301lR6`808B@M0P0R9Ah302<V7`0902@W800W:Ql0:2/P02T[800Z:R00;BXQ02hZ8@0_:b80
<BXR0080<RlP00h0<bdO03@/7`0d:Qh0=BTM03HX7@0e9a`0<c0Q030^7`0/:Qd09bLK02DW700T9ah0
92XP02DZ8`809bLM00@0:2PN02TY7`0[:b40;2`R0P0];B<802PX7Q408R<K200T9Ad09P0V9QX0:2HJ
02LU600Y9AT0;RPJ03</700g;Qd0>C0O03/a5P0o<aT0ASPM04hm8@1H@bH0HDX[06Q=<01]D380Ne``
081Q=@27J3X0SFho091b@02@LSh0SW0l08a^>02FM4@0SVe0089R>`1aE3@0HDD_058h:@16;R@0@2TS
02`b9P0[<BD0:BlU02L/9@0W:R<09RPS0P0V:2D01P0S:2`08bP[02DY:P0Y:bP0:B`U02//9080;2`P
0P0_<2P01`0`<BT0<C8Z038c:`0c=2`0=3D]03Df;P0c=2800`0d=B<203Df9080=SLU0P0i=b800`0j
>2<0>cTT03`j9@0203dk9P0703hl9`1=?RT0CChW04dn9`1>@2H0CT0U04i08`0204i18@80DD4W00@0
DT8X05A4:P1EAB/0EdL]0P1HB2h0801JDbT0FE0W05E;9`1EB2H0EDHY05U7;`1NBC@0H4/h05Y<9`1M
CbX0HU8^06AB;P1SCb`0IDh/06QA;`1]EC<0MUXX07UM:`20HRh0QVLa08a[=@2AKSH0TVlg09A`=P2@
LCX0SVlh08m_=P2FLcT0W7Xm09mk?@2MMcT0V78c0P2FN3`609Eg>`80SW900P2?Ld40302@M480TGE3
099fA02BMT@0Ug9509=a@`2?KCl0RFTj08=T=@1lH300Med/07EK:P80KE0^00X0K4l]06Y=;@1XBbd0
J4X^06U;;`1[CC<0K4hf071>:`1_CBX0KT`Y0P1]BbP0101^C2T0L4h[075?;01eF2h207II;`0507MJ
<01fFBl0M5L]079E:`1`DbT00P1gEc0307IF;`<0MED^00P0LET[071H:P1_EbT0KUHX06mG:@1`F2X0
LUX/07=K;@<0Led^0`1bG2d2075K;00C07QG:P1iF2/0NUT/07]J;@1mG2l0Oeha081O<P21H3<0PV4/
08=R;@23I2h0PfD_081U;P1mHR/0NV4Y07QO9`1mGRl0OUl`081Q<P02085R<`03081Q<P1nGc00OEh_
00<0MUh^00T0MEd]07AL;01cFb/0LUXZ075I:@1YER`0J5D[06IC:@1TDBL00P1SD2H206AA9`04069=
;P1QC2d0GdX[05a7:080FdHW0P1LAbP0301IBBL0F4PV05Q89P1HB2H0FTXX05a<:P1OCbd0H50^06I>
:P1WCb/0JE4]06YB;P<0Je<_00<0JU8^06MH<@1YFS<00P1ZFc@0101WF340HU</05a=9P1IBR<805m=
9`0>061>:01OCBT0GT`X05e::@1KB2P0FDHX05Q4:@1G@bP0Cd@X04i39`1=@RH0C44U04Xo8`19?R82
04Pm8@0304<o9012?R<0@3`Q00<0?SXO00<0?c/P040l8@0k>B800P0j>240100i=b00>3HO03Le7P0f
=1d203Dc70P0>3HO0P0`<Q`4034c7@80<S@N200b=B00100c=B00<S@O030b7@0];aX202`^6@80;BlJ
0P0]<1l0100/;ah0:bhM02X]700Z;A`202T/6`<09RTN0P0U:1d302@W700602DX7`0T9ah092LN02<V
7@0R9A`08B@K0P0P8aX0200N92007B<O01`R7P0K8Ad06R0L01TO6`0H7QX05adI0P0H7QX301LM6@<0
5Q`H200F71XH01LI60P05QPG200G6AP@01HH5`<05ALF0P0F61L301LI60T05QPG0`0G6AP201HH5`<0
5ALF200F61L801DG5P<051DG0`0E5QP201HG6@P05QPG200E5QP801DG5QP05AHH200E5aH@01DF60P0
5QLI200E5QP@01HG6@<05ALF0P0F61LL01LI61006A/J00<061XI01LI600G6AP00P0G6AP00`0H6QT0
6A/J01XL6`0@01TK6P<06A/H0`0J71T201/M6P8061XG00@06A/H01XL6@0L7Q/07AlL0P0N81d201`M
5`<07AhH0`0N7aT2028Q70808B0K100P7aX;020Q6`808B8L0`0R8ad2024R7080824K100O81X801hO
6AP0824K2@0Q8Q`8028Q70<0824K0P0Q8Q`3028S7@@0:2<M0P0Y91h202XU7`06030T600a9AT0<RHJ
03<W6`0d:1`0=RXN0P0g:al01P0a:al0<2XN030Z7P0_:Ad0;BLK02`V6P80:bDI0100=RXJ03L[6`0i
;Ad0>RhN03/_7`0j;Qh0>BdM03P/700o<R40?blO03h^7P0n;Ad0?b`M04<]7`16;b40B34S0P16=B<3
04Dd8P<0A3<Q00D0@B`K04<^7@15<1l0Ac8Q04Pc8P0204Lb8@0404Ha8012=B80@SDR048e8PD0@C@Q
0P11=R@2040e8`80?c@R0P0n<b402`0m>2@0?CHS03Xc800j<Ql0>c0N03d`7`11<B40@S8R03ha8@0m
<200>bhN0080>RdM00h0>bhN03d`800n<B40?BdM03h^7P0l;ah0?34O03/c800j<b00>c@Q03Xe8@0l
=240>S8O03P`7@<0=RhK00<0=blL03P`7@0k<BD00P0j<2@01`0i;b<0>2hR03L]8@0g;B40=R`P030Z
7P0a:al00`0c;B400`0a:al0;bTM02hX7008030Z7P0503LY7P0f:1d0=BLL03DW700f:1d00P0i:b00
1@0l;R<0?BlT03/a9@0j<2@0=bdQ00<0=B/O00<0=bdQ03P^8P0g:a/00P0h;1`01P0i;Ad0>blO03``
800l<200?C4Q03hc7@<0?C8L0P0l<A/203/`6P0803H`900d;R80<R`P030Z7P0_:Ad0;RPL02lY7@0`
:Qh203L]8@0<03H/800e:al0=2XN03<Y7@0b:1`0<BLK038X700d:Qh0=bdQ03T_8`0j<2@0>c4U0P0j
<2@02`0c;QX0<RdI034/600a;1P0<RdI03@_6`0f<Ad0>3<O03<Y7@0d:Qh0=B/O0080=R`P00H0=2XN
038X700`9QX0=c4U03H`900d;R8203<]8@0303@^8P0f<2@0=c4U0080<RhR0P0a;B40300`;200;b/O
02hZ7P0^:Qh0:RHM02/W7P0/:1l0;BTP02`X7`0[9ah0:BDL02PT6`P09RHN00P09b@M02LT6`0Y9A`0
;BHL02lW700a9a/0<RTJ03DY6`80@30Q0P0o;b00300n;Ql0?BdN03d]7P0l;1d0?34O03ld8P11=R@0
@3DS03`a7`0k<1h0?S<Q044f9080@3PU0P0o=b@0100n=R<0?CDR03de8P0l=24203lb7`03040c8011
=240@SDR0080@cHS00T0A3LT04Hh6`16>1/0ACLL04Dg7@14=Ah0A3DP04<d7`13=2400P12<R800`0o
<R40?S<Q03/c800303Xc800403Pc7`0i;Q`0>BhL03T^7080>RlM0`0k<1h303`^8`80>bdR0`0j;240
100e;b<0=2hR03@^8P0d;R8203<]8@80<R`P0P0_:Ad0100`:Qh0<B/O034[7`0b;20203<]8@<0<2XN
0P0a:al3038/80P0<B/M00T0;2TF02l/6@0e<1d0>C8P03/b8@0l<200>RdM03P[6`0m<1l00`0l;ah2
03/^7@80>RdL200i<Ah303H/82_ooooo000Zooooo`030:9gA02SN4D0Y7U60080YGY700<0XgQ50:9g
A02QMT<00`2SNTH20:9iA@<0XGQ40P2TN4L0102UNDP0YWY90:MkBP2XO4/20:UmC080Z7e:0P2WO4T2
0:IkB080YGY70P2SNTH20:AkA`<0YGa800@0YWe90:QnCP2XOTh0Z7i<0P2XOd/00`2XOdT0Z7m70:Qo
A`020:ElB0040:ImB@2WOTX0Z7m;0:V0C080ZX5=0`2WOTX30:QoB`80ZH1<00P0ZX5=0:V0C02WOTX0
YWe90:ElB02VODT0Z7m;0:V0C0T0Zh5?00<0[8=?0:f4D02]Q500102]Q500102/Pdl0[H=C0:^1D@2X
OTh20:IlC0030:QnCP2[PE40[H=C0080ZH1<0P2ZPDd20:^2CP80[8=?00P0[XEA0:f4D02[PTh0ZH1<
0:QoB`2YP4`0ZX5=0:^2CPP0[HA@00@0Z8=?0:N2CP2WPTh0Yh9>0P2VPDd20:F0C0080:AoBP2UP4/0
YX5<0:J1C02UP4/0Xgi90:5lA`2PNdH30:9iA@80XGQ40`2PMd<209Ye@@0409Ud@02HLcl0Ug8n09Ia
?@80UG0l00H0T6`l08m[>`2?Jc/0SVXj08eY>@2<J3P208]W=`H0RV@e0P2;ICH02029GcL0QU`d085J
<@21G380Q5le08=P=P1oGS<0O5/`101lFBl407]H;P80NEH`00@0N5D_07IC;@1eDR`0Le0Z0P1bCbT0
101_DBd0KU0/06i@;01^D2`206e?:`80K4hZ00<0KU0/06e?:`1/CRX00P1[CBT05P1/CRX0KDl[06i@
;01^DRX0L5@/079E;@1fERl0MeD_07MD;P1fDbd0Me4/07YG;`1lFBl0OU/a085O<P22H380PV0`089Q
;P21H2d0R6@b08MS<@26HS0208EQ;`80Qf<a00D0R6@b08YV=02=HSD0SV<f091U>002099W>P06095V
>@2@ICP0Sf@g08]U=P2=IcP0SVPi0P2?JCX00`2>J3T0SFLh08]U=P0808iX>@P0S6Hg0`2=IcP208aV
=`<0RfDf0`29I3L208YU>0<0RfHi00<0RF@g08YU>02:ICP00P2;IST208aW>P0308eX>`2;IST0RfHi
00<0RVDh0`29I3L01P28HCX0R64h08QQ>028HCH0R68e08QR<`80R68a2029ICD308]U>080RV@g0`29
HcH208EP<`@0QV4d0P27HSD208IQ=0<0QF0c0`24Gc8408AO=@80Pehd0P22GC<807mL<P<0NU/_0P1i
FRh307QI;@0407EH;P1dEbd0LUD[071C:@80Ke8X00<0L5<Y075D:P1]D2H00P1]D2P0201/CRP0JddY
06Y<:P1YBR/0J4TZ065?:`1PCRX0GT`X0P1MBbL02P1NC2P0H4hZ061>:P1QCb/0GTDW05a59P1KA2D0
Ed8S05E28P1A@B0204m07`H0BChR0P18?B4204Pi8P0F04Lk8`16?2<0@c`R040j800n>1h0?3PM03hj
8@0k=ah0=c8L03<^6P0b;AT0<bhK03D_7`0g<B40;c0N02h_7@0];Qh0;2dO02XZ7P0Y:Al0:2PN02PX
80H09bLM0P0X:1h202<V7@808RDL0`0Q91/0100P8aX08B@M024T7@0Q91d3020S70807b8K200Q91d3
01hQ6P<07b8K0P0P8a`3024T7@8082<L0`0O8Q/2024T7@808RDN100S9Ql202LZ7`0302T[800Z:R00
;BXQ0080;RXQ00L0<BXR030]7P0`;Ah0<R`N03<[7P0d:Qh0=RXN0080=bTN00P0<c0O034^7`0^;1d0
:R/M02LY700U:1d09BPO02<Y7`P0:BTO200W9adA028S6`P092DM03H09BDK02DU6@0W9AT0:BDI02dW
6@0a:QX0=2dK03L^7@0h<AL0?C<J048f701;>b40E40U05e5:@1RBB/0IDX]071C:@1dEbd0Nehb089V
=`28K3`0S70n08ib@02>Lch0S6dg08e]>P2;K3h0PfM007ML?P1WCcL0Ed0^04hg9`0c<1d0<S4O034_
800^;R80;2dU02X/9`0W;2P09B/Y02P/;`0X;2d0:R`[02X/:@0[;2H0:b`T02`/8P0/;200;BhV02h_
9`0_<2P0<34Y034b:P0b<b/203<d;0<0<c@R0P0d=B<303Df900603Pe8P0i=R<0>CHS03Xg900k>2D0
?3TV0P0m>RL204`m:00T04dn9`1=?bD0CT0U04m1901@@RD0D4<S05109P1A@BL0DT8X05=3:@1EAB/0
ETH/05M7;@1HB2h0F54W05M>9`1DBRH0EDPV05I7:P1JBBl0Gd/c065<=`1KCBP0Ge4/06=C;`1TDRh0
Hdl/06A=:`1WD2h0K5@b07IJ:P1iGB/0Of4_08AV<P29JS@0S6/e0P2@KCD0202?L3T0SFhg08i^=@2E
LSP0VgTl09ij?P2NN3X0VW@f0`2GNCd309Qj?P80VG/o00@0TWA209=e@`2CMD<0TgE3102DMT@0202C
Kcl0T6hn08i/?02;JcX0QfTg089V=01oIC80OV@a0P1bES402P1`E2l0KU4_06a?;`1[CS00Jdda06a>
<P1/CS@0LE0]071?;01_CR/206e<:@0<06i=:P1`Cb`0LE0]071D;01aEBd0LUH^07=G;`1bERh0LED]
06mC:`1^DRX0LeH^0`1bEBd2075D;080L5<[00<0KeL[06iF:P1]EBT00P1]EBT00`1_Eb/0L5P/079J
;P02071K;P80KeX]00`0KUT/06eH:`1]F2/0K5LZ07=D:01dEBT0MEHZ07MH;01hFBd0NU/_07]L<01l
GC42081O:P09081Q:`20HR`0OF8[07YQ:@1hGbL0M5hU07YK;@1kG2h0OEh`0080OUla00<0OEh`07]L
;P1jFbd00P1eGBl00`1dG2h0Le/]079J;002075I:`05071H:P1YER`0Ie@Z06EB:01SD2H00P1RCbD0
1P1SD2H0I54W069=;P1QC2d0GTTZ05a7:080FdHW0P1LAbP0301LBBP0FdPW05]89`1KB2L0GDXY05m<
:`1QCRd0He0_06==:01UCbX0J58]06]E<080KELb0P1/ES401@1ZF380JELa06ID;P1TDR`0HU0Z0080
H4hX00<0GddW05i<9P1NC2H0101OCBL2061>:00C05m=9`1NC2P0GD/W05]89`1JAbL0F4DW05M3:01F
@RL0Cd@X04i39`1=@RH0C44U04Xo8`19?R80B3dQ04Ll8012?R<0@CdR03lk800203hj7`0303lk8010
?240@CdR00<0>SPQ00@0>CLP03Pf7`0g=Ah0=S@M0P0e<a`803Pf7`H0<C<M0P0b=1h8034d7`0403<e
800b=1l0;c4L02d_6P80;2hI0P0];aX202d`7`0302`_7P0[;Qd0:RdL0080:B`K00<0:2/J02HY7P0V
:Ah00`0U:1d302@W708092LN0P0S9Qd0100R9A`08B@K020S6P0P8aX201dS7`0601`R7P0K8Ad06R0L
01TO6`0H7QX05adI0P0H7QX301LM6@<05Q`H200F71XH01LI60P05QPG200G6AP@01HH5`<05ALF0P0F
61L301LI60T05QPG0`0G6AP201HH5`<05ALF200F61L801DG5P<051DG0`0E5QP201HG6@P05QPG200E
5QP801DG5QP05AHH200E5aH@01DF60P05QLI200E5QP@01HG6@<05ALF0P0F61LL01LI61006A/J00@0
5aTH01PJ6@0I6aX06A/J100J71/@01TK6P<06A/H0`0J71T201/M6P806A/H00@06Q`I01/M6P0K7AX0
71hK0P0M7a`201`M5`<07AhH0`0N7aT2028Q70808B0K0`0P7aX00`0O7QT0824K020Q6`09020Q6`<0
8B8L0P0R8ad2024R7080824K0`0O81X901hO6AP0824K2@0Q8Q`8028Q70<0824K0P0Q8Q`3028S7@04
02LR700X8ad0:2<M02PS7@80:B@N0P0Z9Al202lU6@03030V6P0a9a/0<RPL00<0<bTM0`0`:Qh202lY
7@80;RPL0140;BLK03HZ6P0g:a/0>BdM03X^7P0k;al0>RhN03T]7@0h;1`0?S4P03d`7`0n;Qh0?RdM
040]7P13;Al0ABlQ04L`8P0604Dd8P80ASDS00<0A2lN04D`7`16<B000`18<b800`16<B00AC0O044d
8@07044d8@@0?c@R0P0n<b4203db800;03dh900l=B80>S<P03Xb7`0k<1h0?C0O040`8011<B40?S4Q
03d`800k;Qh00P0j;Ad00`0k;Qh0?C0P03ha8@0203d]7P0303`_7`0k;al0>S4P0080>S<Q00L0>C@Q
03/b8@0i<1l0>2lN03H]700e;1/0=RdL0080=bhM0`0h;R8303L]8@80=R`P00P0<2XN034[7`0b;200
<bdQ038/800a:al0;bTM02hX70P0<2XN00D0=bTN03HX7@0e9a`0=2HK03DW700203LY7P0B03T[800k
;B80>S0T03P^8P0f;200=B/O03@Z7P0e:al0=R`P03L]8@0f:QX0=b/K03P/700i;Ad0>blO03``800m
<B40?S8R0`0m<Q`203`a6`<0>c0J00@0=BlS03@^8P0b;200<2XN0P0^:1`00`0_:Ad0<2XN03H/8003
03D[7`0:03@Z7P0c:Ad0<bTM03<Y7@0d:Qh0=B/O03L]8@0i;b<0>S0T03T_8`80>2hR0P0b;AX2034/
6@0?038]6P0d;a`0=S4N03Lb7`0d:Qh0=B/O03H/800g;B40=R`P03D[7`0c:Ad0<BLK03<]8@0b;200
<B/O0080;bTM00<0<B/O038/800c;B400P0a;B43030/80<0;b/O00P0:bLN02`X7`0]:B00;RXQ02dY
800/:1l0:RHM02TU70P09RHN00P09b@M02LT6`0Y9A`0;BHL02lW700b:1`0<bXK03DY6`<0?blP00<0
?RhO03d]7P0m;Ah00P0l;1d0200j;ad0?S<Q040e8`0o=280>c0N03X_7@0l<Al0@3DS0`0o=b@00`0n
=R<0?CDR03de8P0203`d8@80?c8O00@0@3<P044d8@12=B80@SDR0P13=R<01P15=aX0ACLL04@f6`14
=Q`0A3DN04@e8080A3DR00H0@S8R044a8@0o<R40?S<Q03/c800j<b0203Tb7`0403Pc7`0i;Q`0>BhL
03T^7080>RlM0`0k<1h203`^8`<0>bdR0`0j;24303@^8P80<bdQ0`0b;203030Z7P<0<B/O0P0b;203
030Z7P80<B/O0`0b;208034[7@0802dZ5`0_;1T0=C0M03Tb800k<R40?30P03X]7@0h:a/303/^7P80
>RdM0`0i;1`803T`7`<0=R`P:oooool002[ooooo00<0XGI30:9gA02TNDH00P2UNTL0102TNDH0XgQ5
0:9gA02TNdL30:=jAP80XWU50P2QN4@01@2TN4L0YGU80:EiB02VNTT0Yg]:0080Z7a;00<0ZGe<0:Qm
BP2WO4T00P2WO4T30:IkB0040:EjA`2TNdL0Y7]70:AkA`80YGa80`2VODT20:QnCP040:QnC02XOd/0
Z7m;0:QoB@80Z7m70P2TNdL0102UO4P0YWe90:ImB@2WOTX20:QoB`80YWe90P2WOTX30:QoB`040:V0
C02]Q500[8=?0:Z1C@@0Z7m;00<0ZH1<0:^1C`2[PDl01`2[PDl00`2YP4`0Zh9>0:j5D@020:n6DP06
0:j5D@2[PTh0ZH1<0:b2D02[PDl0Z7i<0P2VO4X00`2XOT`0Zh5?0:b2D0020:V0C080ZX5=0P2[PTh2
0:b3C`080:f4D02/Pdl0ZX5=0:V0C02XOd/0ZH1<0:Z1C@2[PTh80:b3C`<0Z8=?0P2WPTh30:J1C@08
0:F0B`2VPD`0YX5<0:J1C02UP4/0Xgi90:9mB02QO4L20:=jAP80XWU50`2QN4@01P2PMd<0VWE109Ye
@@2IM400V7<o09Mb?P80UW4m00L0UG0l099^?P2AKCd0TFdm091/?02?Jc/0SVXj0080SFTi202;ICH0
202:H3P0QU`d085J<@21G380Q5le08=P=P1oGS<0O5/`0`1mFS0207aI;`80NeP^00/0NUL]07aI<`1l
FC<0NULa07MD;P1eDR`0Le0Z075>:01`CBL0L58^06mA;@0206i@;0@0KDl[00<0L58^06mA;@1]Cb/0
0P1/CRX04@1]Cb/0Ke4]071B;P1^DRX0Ke<[075D;01eEBh0MU@^07MD;P1fDbd0N58]07YG;`1kF2h0
OEX`07mM<021Gc40PEl_0080PF0]00D0Qf<c08IR<P25HC40QF4a08IR<P0208MS<`0=08QT=029ICD0
SF8e08iS=P2@ICP0TFHi099W>P2AIST0T6Dh08mT=`2;ICH0SFLh08iX>@0208mY>P0308iX>@2=IcP0
RfDf00P0SVPi2`2=IcP208aV=`<0RfDf102;IST308YU>00408UT=`2:ICP0RVDh08YU>080RfHi0`2<
IcX208]V>@<0RVDh0`29I3L01P28HCX0R64h08QQ>028HCH0R68e08QR<`80R68a2029ICD308US=P80
R68e0`27HC@208AO<P0408EP<`26HC@0QV4d08MR=@80R6<f0P26HC@308EP<`<0Q5lb0`24GcD208=N
=0<0PUdc201mFS0307UJ;P80N5T]0`1gF2`0101fFBl0M5L]079E:`1`DbT206mB:00=071C:@1aE2X0
JdhT06a?9`1^DBT0Ke4[06i@;01[CB/0J4TZ06I7:01QCb/0H4hZ05i<:00205e;9`0<05i<:01PCRX0
H4hZ065?:`1NABL0GDHW05a59P1H@b@0ET<S05=38P1A@R40D44P1@19?R8204Xo8`0I04]09018>B80
BCXS04Lk8`16?2<0@c`R040j800n>1h0?3PM03hj8@0k=ah0>3<M03D`700c;QX0=2lL03D_7`0g<B40
<34O02l`7P0^;al0;BhP02/[7`0Z:R00:BTO02PX800502PX7P<09bLM00@092LN02<V7@0S9Qd08bHM
0P0R9A`2024T6`808RDN0P0Q91d3020S700301lR6`0Q91d08B@M00H08B@M0`0N8AX301lR6`8082<L
0`0Q91d2020S70<07b8K0`0Q91d2028U7P<08bHO00P09RTN02LZ7`0X:Ql0:BTO02`Y800]:B00;RXQ
030Y8@80;R/L00l0<B/M03<[7P0e:al0>2`P03T[800j;240=BlO038_7P0b;b00<2hQ02/[7`0W:Ah0
92LL028U700Z:R000P0Y:Al01@0X:1h09bLM02HV700V9Q`09BDK00P09RHL4@0S91`802@U7@0^028S
6`0S8aT08b<I02HT600Y9AT0;BLI034Z6P0b:a/0=S0H03P`6@0n=1/0ACLM04`k8@1B?R<0FD4W05]3
9`1RAQl0ITXS06a@:01dFBh0O64d08AY>P2:Kd00SWA308Y]<`2>LCT0T7E0095fA`2:LDP0OfM1079K
>`1[E3D0CChO04Li7P0n=1/0=2lL02`/800Z;BH0:Bl]02Tb<@0^;Rh0;Bd[02`/:P0/;BP0:b`V02//
9080:bdR0P0/;BD0100];RH0;RlW02l`:00_<2P2030a:@<0<S<S0P0c=2@303@e9@0603Ld8@0h=B80
>3DR03Tf8`0j=b@0>cPU0P0l>BH01P17>RT0B3/X04Tl:@1;?bT0CD4Y04i2:080D4DY0P1@@2H07P1A
@BL0Dd<Y05A4:P1EAB/0ETH/05M7;@1ECBP0ED/W05=99P1EB2P0EdP[05]:<01QCC@0Hdlg05e?:P1Q
Dbh0I5@`06EC;`1SCb`0Hd`Z06I?;@1ZDS00MU//07ML;@1lH300PF<a08EU<P28Ic80RFPc08]X<P80
Rf`f00X0SF`f09=`>02HMC/0W7Pl09ef>`2KMCL0V7Pk09Ui?02KNch0W7`o0P2NOT4209mo@P80UgU3
0`2FN48309Eg@@06099^?P2?KCd0Sfdm08i^?@2=Kcd0RVhl0P29Kc`207YN=`0507QL=@1eFC@0LUDc
071C<@1^DC400P1]D3800`1`DS00Ke4_06e?;@0306]=:`0506a>;01]Cbd0JDdU06]?9`1/D2P00`1^
DRX0101/D2P0JdlW06iB;@1^DRd206eA;0<0K50[00@0JdlZ06aE:`1[E2X0JU<Y0P1YDRP02`1[E2X0
KEH/06iG;@1]F2d0K5L/06]F:`1ZEBX0JE@Y06QC:01WDRL0IU4V0080K4lU0100KE0V06mB:01`DbT0
LE@Z079E:`1cER`0NUXY07]K:P1kGB/0NEd[07QN:`1eGRX0Le`X075L9`1fFBd0MeX^101hFbl01P1g
FRh0MUT]079K;`1bFbl0L5T]06mH;080KUL[0P1]ERX0101WEBd0IE<[06=A:@1QCbL2061>9P06065?
9`1RD2P0HDh^05m<;01MBRX0FdPX0P1JAbL00`1KB2P0G4TY05e;9`0305e;9`0D05i<:01QCb/0He4]
06EC;`1SCBP0Ie4/06]E<01_FC@0LE/f071J=@1]Ec80JeD`06QF<01TDR`0GddW05a:901KBB<0GD/U
061>:01SDB/205e;9@0405i<9P1OCBL0GddW061>:080HDlY00P0FT/T05Y:9P1IBBD0EdLU05I69@1E
A2H0E4<W05=29P80CD@W00h0C4<V04Y19019@2<0B3lR04Ln8@16?B00@3`Q03lk800n>Ql0?CTN03hj
7`0o>b00@CdR048n8`<0>CLP0P0h=Ql0100g=Ah0=S@M03Dc700e<a`803Le7PD0<S@N0`0a<ad802lb
7@0403<e800a<ah0;c4L02d_6P80;2hI00<0;BlJ02h`6`0]<1l00P0/;ah00`0[;Qd0:RdL02T/6`02
02P[6P0402HY7P0U:1d09BPM02DX7@8092LL0P0S9Q/01P0T9ah08bHM02<V7@0R9A`08B@K020S6P80
7b8I0P0L8Qh0100K8Ad06R0L01TO6`0I7a/401PN6P<05adI0`0F71P801HL6QP05aTH200F61L801LI
61005QPG0`0E5aH201HH5`<05aTH2@0F61L301LI60805QPG0`0E5aH801HH5`P05ALF0`0D5AL301DF
60805QLI200F61L801DF60P05ALF600E5QP801DG5Q005AHH200F5aT801DF61005QLI0`0E5aH201HH
5a`05aTH400I6aX01`0F61L061XI01/M700M7ah07R0O01`N7@0J71/04@0I6aX301TK60<06Q`I2P0K
7AX201`M5`<07AhH0`0N7aT3024P6`8081lJ0`0O7QT:01lP6P80824K0`0Q8Q`0100R8ad0824K020Q
6`0P8A/201lP6P/07QlI600O81X9020Q6`P08B0K0`0P8A/2024R70<08R<M0`0W8Q`202PS7@<0:B@N
0`0`9Q`5034W7@<0;bTM0P0`:Qh3034[7`0903HZ6P0g:a/0>BdM03X^7P0k;al0>RhN03T]7@0h;1`0
?34O0080?2lN00D0?BdM03l^7P11;Ql0A2hP04D_8@0204@c8@80AC@R00H0ASDS04Lf9018=bD0B3LU
04Db8@16<b8304Ld8`0304Hc8P14<B00@c0O00P0@C@Q00@0?S<Q03db800m<R00?C8P0P0l<Al203/`
7P0603`g8`0l=B80>S<P03Xb7`0l<Al0?C0O0P10<2000`0m<200?2lO03/^7P0203X]7@0303/^7P0l
;al0?C0P0080?2`M00<0>bhN03X^7P0h;ah00P0h<Al02@0g<Ql0>C0O03P_7P0f;A`0=B`K03@[6P0e
;1/0=RdL03L^7@0303@Z7P<0=B/O0P0f;200200`:Qh0<B/O038/800b;200<B/O030Z7P0_:Ad0;RPL
200_:Ad203DY7@0303@X700c9a/0<bLK0080=2PL00L0=BTM03HZ7P0g;B40=R`P03D[7`0d:Qh0<bTM
0080=2XN00L0=B/O03HZ6P0f:QX0>2`L03T]7@0k;al0?30P0080?S8R00@0?C8N03`a7@0l<Ad0?34M
0P0k<1`203X_6`0403D_8`0c;B40<B/O02lY7@80;RPL00@0;bTM030Z7P0c:Ad0<bTM0`0d:Qh303D[
7`0:03H/800g;B40>2hR03T_8`0h;R80=bdQ03D[7`0d:Qh0<RdJ034/6@80<2/H00@0<B`I03<^6`0e
<1d0=c8O0P0f;20303L]8@0603H/800d:Qh0<bTM030Z7P0_:Ad0;RPL0P0]9a/00`0^:1`0;bTM030Z
7P0202hZ7P<0;b/O0`0`;200200/:1l0;BTP02hZ8@0_:b80;RXQ02dY800[9ah0:RHM200V9Qh0200W
91d0:2DL02XV7@0]9Q`0<2PM038X700c:Q/0=BTK0`0l;al303/^7P80>RdM00P0>BhL03`a7`0n<b40
?C8P03T^700h;A/0>c0N03hc8@<0?SHS0`0m=B8203`d8@0603ha7P0o<Ql0?c8O040c8011=240@SDR
0P13=R<2044f6P03044e6`11=Ad0@SHP0080@SDR00H0@SDT044a8@11<B40?S4P03db800j<Ql303Tb
7`0403Lb7P0i;Q`0>BhL03T^7080>RlM0`0k<1h0100k;b<0>RhR03X^8P0j;R8203T]8@80>2`P00@0
=2hR03<]8@0c;B40<bdQ0P0b;206034[7`<0<2XN00@0;bTM030Z7P0`:Qh0<2XN0P0a:al3038/80P0
<B/M00P0;BXG02l/6@0e<1d0>34O03Xa800k;al0>bhN03T/70<0>2`L0P0g:a/303HZ6PP0>2lN0`0f
;20[ooooo`00:_ooool0202QMT<0XWM40:AiAP2UNTL0YW]80:EjA`2TNDH0XgQ50P2TNdL30:=jAP<0
XWU50P2UNDP20:IjB@80Yg]:0P2XO4/40:MlB@@0YW]80P2TNdL30:ElB0<0YWe90P2XOTh0102XOT`0
Z7m;0:QoB`2XOdT20:QoA`030:=jAP2TNdL0Y7]70080YGa80P2VODT0102WOTX0YWe90:ImB@2VODT2
0:MnBP<0Z7m;00D0[XEA0:f4D02/Pdl0Zh9>0:Z1C@030:V0C0T0Zh5?00<0Ygi:0:Z1C@2^QE400P2a
R5@01P2^QE40ZX5=0:MnBP2[PTh0ZX5=0:QoB`80Ygi:00<0Z7m;0:Z1C@2[PTh00P2YP4`20:Z1C@80
Zh9>0P2/Pdl00`2]Q500[8=?0:Z1C@020:V0C0030:Z1C@2[PTh0[8=?00P0[8=?0`2XPdl30:N2CP80
YX5=0P2WPTd20:J1C0040:F0B`2TOdX0Xgi90:9mB080Y7]70P2SNTH30:9iA@070:5hA02KMT80VWE1
09Ye@@2IM400V7<o09Mb?P0209Ia?@0609A`@02CKcl0Tflo099^?P2AKCd0T6`l0P2?Jc/408eW>0@0
S6Hg00P0RV0h08MM=@22Fc80PUdc08EP=P24HCL0P5ld07aK<080OU/a0P1mFS003`1lFBl0NeP^07]H
;P1jEbd0NePb07YG<@1iES00N5D_07IC;@1eDR`0M54[07=@:P1aDbl0L58^06i@;00306e?:`80KU0/
00<0LE<_071B;P1^D2`00P1]Cb/00`1^D2`0L58^075C;`0206iB:P03071C:`1cDb`0ME<]0080Me@^
00L0NE<^07UF;P1jEbd0NeP^07eK;P1nG2h0Oed]0080P5l/1025H3<02026HC@0Qf8e08MR=@28HcH0
RF@g08]R=02<HcD0SVDg0`2@IcT01@2?ISP0SVDg08]U=P2=IcP0SVPi0080SfTj00<0SVPi08eW>02;
ICH0202>J3T;08eW>080S6Hg0`2;ICH208eX>`0308aW>P2;IST0RVDh0080RF@g00<0R6<f08]V>@2;
IST0202;IST308YU>0<0RF@g00H0R64j08QQ>028HCP0R64f08QR=@28HS<208QR<@P0RFDe0P28HSD2
08MQ=0<0QV0c00<0QElb08=N<@24Gc800P25H3<208MR=@0408QS=P29I3L0QV4d08IQ=0<0QF0c0`24
Gc8208AO=@80Pehd0P22GC<2085L<PP0O5T_0`1hFBd307MH;080MUL[00@0MUT_07EH;P1cER`0LE@Z
0P1`DbT2075D:P0;06U<8P1/CbL0Ke8Z075C;@1`DRh0K4h/06Q9:P1UARL0HTh[065=:P1OBbP00P1N
BRL01@1OBbP0HDdZ065=:P1RCR/0GdHX0080GDHW00L0FTDV05M4901DA2<0Dd@S05938P1:?b<0BChR
0080B3dQ00@0BChR04Xo8`1<@BD0CD8V0P19>R<03P17>b<0AC/R048k8@10>R00?cTO03di7P0n>R40
?3PO03Td7P0g<Qh0=C0L03D`7@0f<200=c4Q0P0b<Al01P0a;b00<2hQ02h/800]:R40;2TP02/X8@80
:BTO100X:1h202LW7@@092LN0P0S9Qd2028U70<08RDN0P0Q91d;020S70<07R4J0`0O8Q/2020S70<0
8B@M0P0P8a`301lR6`8082<L0P0Q91d2028U7P808bHO0P0V:Ah05P0W:Ah0:2PN02/X7`0/:1l0;BTP
02lX800/:AX0;BXK030Z700b:Qd0=B/O03T]8@0k;B80?2hS03H_7@0f<Ah0=S0P03@a8P0`;R40:RXN
02DW6P0R91T402HV70@09bLM200U9A/A02<T70P092DM02T082<J024R6P0Q8aP08b<I02LU6@0Y9AT0
;2HH02dW6@0`;QT0<bhJ03La6`0m<Q`0@c@M04Pf7P1=>B40CcTQ05Lo7@1I@Al0GDDQ06=;9@1/EB`0
MUle07iW?@23K400Rg<e08ee>@2?MSd0T7Lo08ef@P2;Ld<0R71208E]@@1cEbl0IThX05A18010=1X0
<bhK02/]800[<2X0:c@a02dZ9@0202`Y900502TX8`0Z:R80:R/S02//900[;R<00`0[;2@00`0/;BD0
;BhV02d^9P0202h_9`@0<C8T0P0b<bD203<d9P80=S<R00@0=c@S03Pe900i=RD0>SLV0P0k>2L02013
=bL0A3PX04Hk:@18?B/0Bd0/04e2;01?AB`0D4H]0P1??bD0101@@2H0DT8X05=3:@1EAB/205I6;00N
059:9P1CBBH0DTLW05E8:01HBBX0GD``069><`1TD3D0Ge4/069D;`1UEC40IU@`06=?;01SC2X0IDh/
06UA;`1cFbl0M5``07QM<01kGc00Of0a089R<@23Hc00QF@a08MW=028J3D0RfXe091]=`2DLCT0V7@j
0P2KM3T01@2IMcP0VgTj09il?@2POSl0Xh5200<0Y89300H0W7e609]lA@2KO4D0VW]409Uj@`2HND82
09Mh@@0609Ib@02DLd00U7=009=c@02BM400T7E00P2?MT0208=X?@0;085V>`1nHSX0NUhg07MK=P1c
ES@0LE@b071C<`1/DS40JU0_06Q>;@1VC2/00`1UBbX01P1VC2/0HTTQ06A;8`1VCBD0J4lW06U@:080
J4lW00<0IdhV06M?:`1VCRX00P1VCRX206E=:@80I4`X0100Ie4Z06I@:@1UCbP0I4hW06E?:01VD2T0
J58[06UC;01VDb/0IE8Z06AA:@1SD2P0HDhV061=9@1OC2@0GT/S0P1TBb<0101UC2@0ITdU06M>9P1X
CbL206U@:080MEHX00H0LeLX07=H:@1aFBT0LETY071J:@1_FBP307IK;P80Me`_0`1fFbh0101_FC00
KUP_06aF;@1ZE2/206UC:P80JU@[00@0He@]069C;01PDBX0GTlX0P1MCRL205i?:00905i>;@1MCB`0
Fd/Z05U9:01HB2L0FDTX05Y::@1KBbX0HDdX00<0H4`W00L0HDdX06A@:`1VDRd0J5@_06MC;P1YEC00
KETd0080L5`g00H0K5Pc06MC;P1TD2/0HDdX05m;9P1MBB@205]78P0505e9901PC2L0HDdX05a:901M
BbD00P1NC2H2061>:00@065?:@1RD2X0EdTR05M9901FB2<0EDLT05A5901CA2D0DT<V05529@1;A2L0
BT<V04U29@18@B@0Ad0S04Dn8@80A3dP0P0o>b0303di7P0303lk8011?B80@ShS00@0>3HO00<0=cDN
03Hd7@0f=1d00P0e<a`803Le7P80<cDO100b=1h2034c7@P0;S4L00P0<S@O034c7P0_<A`0;BlJ02`^
6@0];aX0;S0K02la7080;2lN00@0:bhM02X]700Z;A`0:B`K0P0X:aX302DX7@8092LL0`0S9Q/202<V
7@04028U700Q91/082<J01lR6@807R4H0P0K8Ad201XP70806AlK100H7QX301LM6@<05Q`H200F71XH
01LI62005QPG0`0E5aH201HH5`<05aTH2@0F61L301LI60805QPG0`0E5aH801HH5`P05ALF0`0D5AL3
01DF60805QLI200F61L801DF60P05ALF400E5QP801HG6@P05ALF400E5QP801HG6@P05AHH400F5aT3
01DG5P805QPG700G6AP@01TK6P0801HH5`0I6aX07AlN020R8@0Q8b807R0O01/M700H6QT@01TK6P<0
6A/H0`0J71T201/M6P<071hK0P0K7AX301XL6@8071dG0`0M7QP301hO6@808B0K0`0P7aX301lN6@/0
7b0J0P0P8A/3024R7080824K0`0O81X;01hO6AP07b0J2@0P8A/8024P6`<0824K0P0Q8Q`3028S7@<0
9b8L0`0X8ad202TT7P80<2LN0`0_9Qd302hU700A02dW6`0^:1`0;bTM030Z7P0a:al0<R`P03<]8@0d
;R80=RXJ03L[6`0i;Ad0>RhN03/_7`0j;Qh0>BdM03P/700i<Ah00P0k<1h00`0l;ah0?RhN040_7`02
048_800:048a7`13<R00A3<Q04Dd8P16=B<0AcHT04Pg9@19>2H0AC@R04He8`80AcHT00D0ASDS04@c
8@12<Al0@C0N03lb7`04040c80<0@C@Q0`0l<Al203/`7P<0>RlM00H0>SDQ03/d8@0j<b00>c<P03`a
7`0m<1l203l_7`0303`_7`0k;Qh0>bhN00@0>bhN00H0?2lO03/[7P0k:ah0>B/N03P/7P0g;Ql203H_
7`0403D_7`0g;Ql0=RdN03@[7080<bXK00<0=2/L03D/7@0f;Ah00P0a9a/2038X700403<Y7@0d:Qh0
=B/O03D[7`@0<B/O00@0<2XN02lY7@0_:Ad0;RPL200_:Ad00`0c:Ad0<RPL038X7002034W6`80<2HJ
0P0a9a/00`0e:al0=2XN03@Z7P0303<Y7@80=2XN0P0f:QX0100h;1`0>BdM03/_7`0l<20203hb8P04
03`a7`0k<1h0>c0N03/`7P80>RlM0P0i;Q`0100c;B40<R`P030Z7P0_:Ad202hX700802lY7@0`:Qh0
<BLK038X700c:Ad0=2XN03D[7`0f;20203L]8@0:03P^8P0i;b<0>BlS03T_8`0g;B40=2XN038X700`
9QX0<B/K030Z6P80;bTI00@0<2XJ038/700d;Qh0=S0P100g;B4203H/8080=B/O0P0`:Qh402lY7@80
<2XN0P0/:1`0100]:Ad0;RXN02l[7`0_:al2030/800302dY800^:R40;b/R0080;b/R00<0;BTP02`X
7`0Z9Qd0200V9Qh0200X9Ah0:2DL02XV7@0^9ad0<2PM038X700c:Q/0=RXL0P0j;Qh603T]7@0803L/
6P0j;ad0?C8P03/`7P0h;A/0=b`J03T^700l<Al203de8PH0?3@Q0P0n<Ah00`0o<Ql0@3<P044d8@02
048e8P0904<f8`0n=1T0?S@I03le700o=1h0@3DQ040e8`11=R@0@CDU0080@30P00<0?C0O03`a7`0i
<Ah00`0h<Ah0100g<Qh0>BhL03T^700i;Q`203X_7@<0>c0N0`0h;R8203L]8@<0=R`P00@0<bdQ038/
800b;200<R`P0P0a:al2030Z7P80<R`P00@0<B/O030Z7P0`:Qh0;bTM0P0^:1`3030Z7P80<B/O0`0b
;208034[7@0802h[600`;AX0=2lL03Pa7`0i<1l0>blO03/^7P0j;Ad303@[7080<bXK0`0b:AX803H]
7P<0=R`P:oooool002[ooooo00<0XGI30:9gA02TNDH00`2VNdP00`2UNTL0Y7U60:AkA`020:AkA`<0
XgY60P2RNDD40:IjB@@0Yg]:102VNdP40:MlB@<0YGa80`2VODT20:MnBP80Z7i>00@0Z7i<0:QoB`2X
Od/0Z7m90P2XOdL20:AkA`@0YGa80P2VODT20:ElB080YWe90P2WOTX20:QoB`<0[HA@00D0[8=?0:^2
CP2ZPDd0ZX5=0:V0C0090:^1C`030:MnBP2ZPDd0[HA@0080/8MC00H0[HA@0:Z1C@2WOTX0Zh9>0:Z1
C@2YP4`20:QoB`030:V0C02ZPDd0Zh9>0080ZH1<0P2ZPDd20:^2CP<0[8=?00L0Zh9>0:Z1C@2YP4`0
ZH1<0:Z1C@2/Pdl0[HA@00P0[8=?0P2YQ5030:R3C`<0Yh9>00@0Z8=>0:N2C@2VPD`0YH1;0P2TOdX2
0:=nB@040:ElB02TNdL0Y7]70:AkA`80XgY60P2RNDD209]f@P0309Ye@@2IM400V7<o0080Ug8n00L0
UW4m09Ea@@2DL400U71009=_?`2BKSh0TFdm0080T6`l00<0T6Xk08mY>P2?JCX00P2>J3T208eW>00?
08aV=`2;HCT0Qede089K<P22GC<0QF0f08AQ=`20Gc@0OE`a081M<`1oG380OU/a07eJ<01lFBl0NeP^
0080NUL]00<0MU<]07MD;P1gE2h00P1hEBl307UF<00;079D<01aDbl0Ke4]06e?:`1/CRX0KDl[06mA
;@1`DRh0LE<_071B;P1^D2`00P1]Cb/0601^D2`0L58^075C;`1]DBT0KU8Z06mB:P1bDR/0M58/07IC
;@1gE2h0NU@_07UF;P1iER`0NUL]07]I;01lFR`0OU`/07mN:`20Gb`0PUda08=N<P24Gc<0QV4e08MR
=P@0R6<g00L0RF<d08YT=@2<ISL0SFLh08iX>@2=IcP0S6Hg0080RfDf00L0SFLh08iX>@2?JCX0SfTj
08iX>@2=IcP0RfDf00P0SFLh202>J3T308eW>080S6Hg0`2;ICH01P2>JC`0SFPk08eX>`2<IcX0RfHi
08YU>080RF@g2P2;IST308YU>0<0RF@g00H0R64j08QQ>028HCP0R64f08QR=@28HS<208QR<@P0RFDe
0`27HC@308IP<`80QElb0P24Gc801025H3<0QV4d08IQ=027HSD208QS=P80QV4d0`25H3<308AO<P<0
Pehd0P22GC<3085L<PP0O5T_0P1iFRh207QI;@<0MeP/00D0MUL[07MJ<01eF2h0LeH/075D:P02071C
:@0=075D:P1bEB/0JTdS06a?9`1`Db/0LU@^075C;`1]Cbd0J4TZ06E69`1TCB/0Hd`Z065::0020619
9`05065::01SC2X0Hd`Z06A=:`1PAbT00P1NAbP0201KARL0FDHV05I69@1EARD0E4DT04a19@1;@2@0
BChR0P18?B40201:?b<0C44U04e29P1:>b@0BCXS04Hj8P14>R40@CXP0P0o>Al02@0n>Ql0?SXQ03di
800j=Al0>3<O03Lb7P0f<Ah0=S0P03La8@0203@a800603<`8@0a;B40<2`Q02l[8P0^:R40;BPR0P0Z
:R0202TY7`80:2PN0P0W9ad302DX7`<092LN0P0S9Qd202<V7`808RDN0P0Q91d:020S70<07R4J0`0O
8Q/2020S70<08B@M0P0P8a`301lR6`<082<L0P0Q91d3028U7P809BPM00`09RPM02PX7P0Z9ah0:bLN
02`X7`0^9al0:bPI02`Y6P0_:A/0<RXM03D[7`0i;B4203`^8`0@03L_700g<1d0>34O03La8@0c<240
;R`O02PY6`0U9AT08R8H02<S6@0T91X09RHL02LW7@0Y:Al0:RXP02/[8@P09BDK6@0T9Ad01P0M8Q/0
82<L028S6`0S9AX092@H02LU6@80:2@H02T0:R/I02d/6P0`;AX0=BhK03/`7010<A`0@c8N04Dc7@1@
>ah0D3/L058m7P1F@R40G4PU06EA;01/FC40L5de08=]=025KcH0R78i08Yd>`2>MCd0SWDo08ed?P2<
Lcd0RVXi089S=@1aF2l0GT/Z04/o9@0k=R<0;c0R02/]8P0^9A`0;B@M02/T700Y9A`09bLO02TZ8P0Z
;B@0;2lV02X[8`0402//90<0;2dU0P0_;b<2030`90@0<C4U0P0e<R<0100f<b@0=c@U03Pe9P0h=BH2
03Tf9`0803hd:00o=BT0@CPY04@k:P17?b`0BD4^04]3;P1=AC0204hn900404lo9@1A@BL0DT8X05A4
:P80EDD[0100DDPY0597:@1BAbT0ETTY05U::`1NCBl0HTl_06AA<@1PDRd0HeD`06IF<P1VE300Hdl/
06A=:`1VCbd0JU8`0P1`FC004`1bFC00MEX_07QK;`1lGBl0OUl`081P<@23Hc80QFDd08QW=02<J3@0
SV/e095/=@2FKcH0V74h09Id=02HMSH0W7Xj0:1n?P2RP4000`2SPD4209in@`0409em@P2LO440Vg]0
09]k@080VWXo00P0WGU509]jA@2JND@0V7U309Ih@P2CN440TGQ0091g?`80S75200/0RVm008M/?`23
J3d0OV8j07YN=`1fFS<0M5Pc06QA<@1VCbl0I4d]065::P0405m8:00505m78@1QBB<0Hd/U06E=9`1V
CRP00P1UCBL0101TC2H0H4`[061<:`1PC2/205m;:P<0GTXY00<0HDdZ061<:@1OBbP00P1OBbP00`1Q
CBX0HTh[06A@;@0205m=:@0405i<:01MBbL0FdTU05Y89080FDLS0P1NB2<0101OBB@0H4XU061:9@1Q
BbH2069<9`80KU4U0P1^DbH0101]EBL0KELX06eH:@1]F2T207IN<P@0MEda0P1fGS80301ZES40JED`
06IB;@1TD2/0HdlZ06A@:`1UDB`0IU8]069C;01PDBX0GTlX05a=9P80Fd`U00D0G4dV05e>9`1MCB`0
G4`[05Y::@0305U9:080Fd/Z0P1UCbX206A>:@0?06I@:`1XDRd0JeD`06aF<@1/FS@0KE/e06mM=`1^
G3H0JeTc06EC;@1OCBL0G4XT05]5801LAR40GdTT0080HT`W00<0HD/V061:9@1NB2<00P1MBbD0101N
C2H0GddW05m=9`1PCRP2065?:@0605E98@1DB280E4PR05=68`1BAB<0DTDU0P1A@bH204U49P0804Q3
9@16@B<0AD0R04@o8@13?R00@SdO040l8@0o>b0303di7P0303hj7`10?240@CdR00@0=cDN100f=1d0
0`0e<a`0=S@M03Hd7@0603Hd7@80=3HP0P0c=Al2038d7P80<C<M200^<A`00`0a<ah0<38M02h`6`03
02d_6P80;c4L0P0/;ah0100[;Qd0:RdL02T/6`0X:aX202LZ6@809BPM0P0T9a`202<V6`808RDJ0P0R
9A`0100Q91/082<J01lR6@0N8AP201dP5`806R0L100I7a/401PN6P<05adI0`0F71P801HL6QP05aTH
800F61L301DG5P805QPG0`0G6AP901HH5`<05aTH0P0F61L301DG5PP05QPG200E5aH301@E5`<05AHH
0P0F5aT801HH5`P05AHH200E5aH@01DF60P05QLI200E5aH@01DF60P05QLI200E5QP@01HG6@<05ALF
0P0F61LL01LI61006A/J00P05QPG01TK6P0M7ah0828Q024S8P0N81l06adL01PJ6A006A/J0`0I6aP3
01XL6@806adJ0`0L7Q/201/M6P<06Q`I0P0L7AL301dN60<07QlI0`0P7aX301lN6@807QdH2P0N7aT2
01lP6P80824K0P0Q8Q`301lP6P<07QlI2P0M7QPH01hO6@T0824K200Q81/3020Q6`808B8L0`0R8ad2
02HQ6`<09b8L0`0X8ad202hW7`<0;BHN0`0/9Ad04@0/9QX0;BLK02hX700_:Ad0<B/O038/800c;B40
=2hR03HZ6P0g:a/0>BdM03X^7P0k;al0>RhN03T]7@0h;1`0=RlL0080>30M00<0>c0N03d`7`0o;al0
0P10;al2044`7P08048a7`13<R00AC@R04He8`17=R@0B3LU04@e8P15=R<204Hg900404Df8`13=240
@C8O040a7P80?S4N0P0o<Ql01@10<b00@C@Q044d8@11=240?34O00<0>c0N0P0j;ad203T^700603Td
800j<b00>S<P03/c800l<Al0?C0O0P0n;Qh00`0j;Ad0>bhN03/^7P0403/^7P0603X]7@0j:Al0>RTO
03PZ7`0g:al0=2XN0P0c:ah0100b;1h0=B/O03@Z7P0c:Ad2038X700303<Y7@0e:al0=R`P0080<2HJ
00@0<BLK038X700b:1`0<bTM0P0d:Qh2034[7`03030Z7P0_:Ad0;bTM00<0;bTM200^:1`4034Y70<0
<2PK0P0_9aX203<Y7@H0=2XN00D0=b/K03P/700h;1`0>BdM03/_7`0203``800303da8@0k<1h0>c0N
0080>RlM0`0i;Q`0100h;A/0<R`P034[7`0_:Ad302hX7080<2XN00H0<2HJ034W6`0b:1`0<bTM03D[
7`0f;20203P^8P<0>BlS00L0>2hR03H/800c:Ad0<2HJ02hT600`:Q`0;bTK0080;RPJ00@0;bTK034[
7@0c;Al0=BlQ0P0g;B4203H/80@0=B/O0P0b;20403<]8@80<R`P0P0[9a/00`0/:1`0;BTM02hZ7P02
02l[7`09030/800/:1l0;BTP02hZ8@0_:b80;RXQ02dY800[9ah0:RHM00P09RHN00P0:2DN02TV7@0[
9ah0;RLM030X7@0c:Ad0=2/L03HZ70D0=RdL0`0g;Qd0200g;1X0>RlM03`a7`0k<1h0=b`J03H[6@0i
;Q`0?34O1@0k<b0303`d8@0603d`7@0n<Ah0?S4N03lb7`10<b00@C@Q0P12=B8203`e6`0603`d7@0l
=1l0?CDR03de8P0m=2<0?C@U0P0o;al00`0l;ah0>c0N03Ta7P0303L`7@0403Ha7@0i;Q`0>BhL03T^
7080>RlM0`0k<1h203L_8P80=RhQ0P0e;B0203@/7`80<R`P0P0a:al3030Z7P0602lY7@0b;200<B/O
034[7`0`:Qh0;bTM0P0^:1`0100]9a/0<2XN030Z7P0`:Qh2034[7`<0<R`P200a:ad01P0_;1T0<2dJ
03@_700g<1h0>C0O03/_7`80>bhN0`0b:Qd2034Y70<0<2PK200e:al303H/82_ooooo000Zooooo`04
0:5f@`2RMd@0Y7U60:IkB080Yga900@0YW]80:EjA`2UO4P0YGa80P2TNdL30:=jAP030:9iA@2VNTT0
YWY90080YWY9102WNdX0102UNTL0YW]80:IkB02VNdP30:MlB@040:QmBP2UO4P0YGa80:ElB080YWe9
0`2WOTX20:QnCP040:QnC02XOd/0Z7m;0:QoB@80Z7m7202VODT30:ElB080YWe90`2WOTX00`2YP4`0
ZX5=0:^2CP020:b3C`030:^2CP2ZPDd0ZX5=00T0Zh5?00<0Z7m;0:Z1C@2/Pdl00P2^QE40102/Pdl0
ZX5=0:QoB`2ZPD/60:V0BP030:Z1B`2YP4`0ZH1<0080ZX5=0P2[PTh20:b3C`080:^2CP2ZPDd0ZH1<
0:QoB`2YP4`0ZX5=0:b3C`2]Q5080:^2CP<0ZHA@0P2XPdl30:N2CP040:V4C`2XPdh0Yh9=0:F0B`<0
Y7m:00<0YH1;0:ImB@2UO4P00P2UO4P20:AkA`80XgY600H0W7M309]f@P2KMT80VWE109Ud@02HLcl2
09Mb?P0609Ea@@2DL400U71009=_?`2BKSh0TFdm0P2@K3`01P2BK3d0TF/l095[?02@JS/0SfTj08iX
>@80SFLh00h0Rf4i08QN=P23G3<0Pehd08IQ=`25HSP0PF0e07eL<@21GS@0P5dc07mL<P1nFc40O5T_
07]H;P80NUL]00/0ME8/07IC;@1gE2h0N5D_07YG<@1kF380O5Tc07eJ=01cEC40LE<_06mA;@0206a>
:P0606e?:`1_DBd0LE<_071B;P1_DBd0KDl[0P1/CRX00`1]Cb/0Ke4]071B;P0206eA:@0706iA:@1`
D2T0Le4[07IC;@1hEBl0NeD`07QE;@0207QE:`0:07QF:@1jF2X0O5XZ07iM:P1oGR/0PE`b089M<`24
GcD0QV4g08MR>0@0R6<i00<0Qf<c08UU=@2:ISH00`2<J3P01@2;IcL0RVHf08]U=P2=IcP0SVPi0080
SfTj00<0SVPi08eW>02;ICH0202=IcP808iX>@<0SFLh0P2<ISL308]U=P0408eX>`2<IcX0S6Lj08aW
>P@0RfHi0`2<IcX208]V>@<0RVDh0P2;IST308YU>0<0RF@g00H0R64j08QQ>028HCP0R64f08QR=@28
HS<208QR<@P0RFDe0`28HSD208MQ=0<0QV0c2P26HC@308EP<`<0Q5lb0P23GS@2089M<`<0PE`b00<0
P5/a07eJ<01mFS001P1mFS0307YK;`80NEX^0`1hFBd0101gFS00MUT_07AG;@1bEB/2075D:P80LUD[
00/0K4lU06e@:01_DRX0L58/06mA;@1]Cbd0JDX[06M8:@1UCB/0I4`Z069::00206599`05069::01T
C2X0I4`Z06E=:`1PAbT00P1OB2T04P1LAbP0FdPX05Q89`1GB2L0ETLV04m4:01=@RH0BSlS04Pm8@17
?200BChR04]0901<@BD0Bc`U04Xk9016>R80@cTP040i7`80?cTO00L0?c/P03hj8@0m>B00?3LQ03Xe
8@0i=200>3<P00@0=c4Q00H0=S0R03@^8P0c;280<R/S034Z8P0`:B<202/[8@0402XZ800Y:Al0:2PN
02PX7P809bLM0`0V:B0202DX7`<092LN0`0S9Ql2028U7P<08B@M200O8Q/301hQ6P<07b8K0P0P8a`3
024T7@8082<L100O8Q/3020S70808B@M0P0R9Ah202@W700302DW700W9ad0:BHM0080:bLN0140;BHN
02`Y6P0/:AX0<2XL038Z7@0e:al0>BdQ03/]8P0l;R<0>c0L03Ta700i<Ah0=c0N03D_7`0a;Ql0;R`M
02d[7P0202@T6P0402DU6`0W9ad0:2PN02XZ8080:b/Q200W9adI02@U7@0`01hS7@0O91h08RDN02@U
7@0T9Q/092@H02DS5`0U8aH09BTJ02LZ6@0Y:QX0;R/J03@]6`0i;Q`0>bhK03h_7018=Qh0B3LM04Th
7P1<>al0DD0R05I69@1KBbT0Gdl]071K;01fHC80OfTh08M`?P2=Ld00SG8m08]]=`28JS@0SF`g08e]
?029K400OfPo06iK>P1IBRd0A3PP03P]6@0h:Ql0=BTM030V700]9Q`0:RLN02TZ8P0X;BH0:RlX1`0[
;2@0100/;BD0;RhT02h^900^;R@202l_9@<0<30V00H0<blS03@`900d<2@0=C4U03Hb9P0g<bL203Pd
:00>03/a:00l<RT0?S@Z040f:P13>R/0ASd/04Po;P19@Bh0CCdS04hn901??bD0D40V05519`1C@bT2
05A4:P0X0516:`1BAb/0DdP/05M9;01JBb`0GDd/069?;P1SD2l0Ge4/069D;`1VES80IU@`06A@;@1U
CR`0Ie0^06aD<P1[EC00JeD^06eE;`1_ERh0LeL_07MJ<01kG300OEhb081P<@22HS40QF<c08MS<@26
HRh0RF@_08mX<@2CK3D0TVl_09Eb<P2IMSH0WGXj09ml?02POCd0Wg`l09ik>`<0Wgdn0`2NO3d209ek
?0060:9oB@2OOTP0WWe709]lA@2HNd<0UG]20P2BND02099hA@0<095gA02?MD@0Rg1108I[?P20ICX0
O60h07UM=@1XECD0IU<c06=@<01OC2`0GDXZ0`1LBBT0201PBRD0HD/V06==:01TCRT0IDlZ06A>:@1S
CBP0HT`W0`1KBR`205Y9:`<0FDPZ00<0GDXZ05a9:@1KB2P00P1JAbL00`1LBBT0GT/[05m<;00205Q8
9`80EdLV101FARD305Y89080FdTU0`1LBRH02`1/CbL0JdlW06Y>9P1YD2L0JE8X06YE:P1ZEb`0K5T^
07AM<`1cG380LU/a0080LEX`00l0LU/a07=L<P1dGC<0IeDa06EC;`1RD2`0GddY05i<:01OCBT0HDl[
069@;01ODB`0GU0[05a>:@1JC2L00P1IBbH01@1JC2L0FddX05]<:`1JBbX0FDXY0080F4TX00<0FDXY
05Y;:P1KC2/00P1XD2X05P1WCbT0J50Z06UA:`1/E2h0KUH`071H<P1/GCH0Je`e06UJ<`1WF340HU</
05e>9`1IBR<0ETLP05Y27P1NAR80HTXV06I>:P1WCb/0IDdY06599@1NAR8805m=9`0605=:8@1BBB80
DTTR0598901AAb@0DDHV0P1@ABL01P18ABH0Ad@U04I39015@R<0A44R048o8080@ChO00P0@CdR040l
8@0n>Ql0?CTN03`h7@0m>Ah0?SXO03lk8140=S@M0P0e=b40100d=R00<cDO038d7P0b=1h2034c7@P0
;c8M00<0<38M02la700^<1/00P0];aX00`0^<1/0;c4L030b7@0202/^7@80:RdL00@0:B`K02P[6P0W
:QT09bXI0`0T9a`202<V6`<08RDJ0P0Q91/00`0P8aX07b8I01hQ600201dP5`0301`O5P0I7a/06AlK
00<06AlK1@0H7QX301LM6@<05Q`H200F71XH01LI60P05QPG200E5aH@01HH5`<05ALF0P0F61L301LI
60T05QPG0`0G6AP201HH5`<05ALF200F61L801DG5P<051DG0`0E5QP201HG6@P05QPG200E5QP801DG
5Q005AHH200G61X801DG5Q005AHH200F5aT801DF61005QLI0`0E5aH201HH5a`05aTH400I6aX01`0F
61L061XI01/M700M7ah07R0O01`N7@0J71/04@0I6aX301TK60<06Q`I2P0K7AX201`M5`<07AhH0`0N
7aT3020O6P807ahI0`0N7AP;01hO6@807b0J0`0P8A/301lP6P807QlI2`0M7QPH01hO6@T07b0J200P
7aX3020Q6`808B8L0`0R8ad302HQ6`809b8L0`0X8ad802XU7`0F02/U6@0/9QX0;BLK02hX700_:Ad0
<2XN034[7`0b;200=RXJ03L[6`0i;Ad0>RhN03/_7`0j;Qh0>BdM03P/700d;a/0=RlL03L`7@0j<Ql0
?34O03d`7`80?RhN0`10;ad00`11<1h0@S4O04<b800204@c8@0303lb7`10<b00@C@Q0080@SDR00<0
@3<P03lb7`0m<1d00P0m<1d00`0n<Ah0?c8O040c8002044d8@04048e8P0l<Al0?34O03`a7`80>c0N
0`0j;ad02`0h<al0>C8O03Xc800k<b00?C8P03d`7`0m;Ad0?2`L03T/700j;Ad0>bhN0080?2lO00<0
>bhN03X]7@0i;1`00P0i:2000`0f:1l0=BPO03<Y7`02034Y7P09030Z7P0c:Al0<RPN034W7@0`9Q`0
<BLM038X7P0d:R00=B/Q0080<BLK0`0b:1`303<Y7@03038/800a:al0;bTM00<0;RPL0P0_:Ad802hX
700502lY6`0`:Q`0<B/M034[7@0b;1h00P0a:ad01@0`:Q`0;bTK038X700c:Ad0=B/O00<0=R`P0P0e
:al:03X^7P80>BdM0`0h;1`0100g:a/0<B/O030Z7P0^:1`202dW6`0302hX700`:Qh0<B/O0080<BLK
00D0<RPL03@Z7P0e:al0=R`P03L]8@0403P^8P0603L]8@0e:al0<RPL02lU6@0]8aL0;bTM0P0^:1`0
200]9a/0;RPL030Z7P0b;200=2hR03L]8@0f;200=2XN0`0c:Ad203@Z7P03038/800c;B40=2hR0080
=BlS00@0=2hR03<]8@0b;200:bLK0`0/:1`402dY7@0302/W7P0/:1l0;BTP0080;BTP00<0:bLN02XV
7@0X91/0200V9Qh0200Y9Ql0:BHM02/W7P0^9ad0<BTN03<Y7@0d:a`0=b/M0P0d:aX203D/6`@0=RdL
00P0=b`J03X_7@0m<R00?34O03P]6`0g;1X0>BhL03`a7`80>C4N0P0j<Ql403/c8080?C0M00<0?S4N
03lb7`10<b000P11=2401`12=B80?CDN03de7P0l=1l0?3@Q03/c800k<R400P0j<B8203h^7P0303`_
7P0j;ad0>30M00<0=RlL00@0=C0L03T^700i;Q`0>BhL0P0j;ad303/`7P<0=BlQ0P0d;R0303<]7`80
<B/O0P0`:Qh302lY7@0402hX700`:Qh0<2XN030Z7P<0;bTM0P0^:1`3030Z7P80<B/O0`0b;208034[
7@80<2dJ00@0=2lL03H_7@0h;ah0>RhN0P0l;al3034[7`80<2XN0`0_:Ad803<Y7`<0=R`P:oooool0
02[ooooo00@0X7E20:9gA02TNDH0YW]80`2WO4T0102VNdP0YGa80:ElB02UO4P20:AkA`<0XgY6102W
NdX40:IjB@80YGY70P2VNdP20:MlB@80Z7e:00@0YGa80:ImB@2VODT0YWe90P2WOTX20:QoB`80Z7i>
00@0Z7i<0:QoB`2XOd/0Z7m90P2XOdL40:QoB`@0Ygi:102UO4P20:ImB@80Ygi:00@0YGa80:MnBP2Y
P4`0Zh9>0P2/Pdl00`2[PTh0ZX5=0:^1C`080:^1C`80ZX5=102[PTh20:Z1C@P0ZH180P2YP4`20:Z1
C@80Zh9>0P2/Pdl0202[PTh0ZX5=0:V0C02XOd/0ZH1<0:^2CP2]Q500[XEA202[PTh20:Z5D@80ZHA@
0`2XPdl01@2WPTh0ZXE@0:V4C`2WPTd0YH1;0080Y7m:00<0YH1;0:J1C02VODT00P2VODT20:ElB0<0
Y7]70P2LMd<0102KMT80VWE109Ud@02HLcl209Mb?P0609A`@02CKcl0Tflo099^?P2AKCd0T6`l0P2?
Jc/209=]?P0G099/?@2AJc`0T6Xk08mY>P2>J3T0SFLh08]Q>@28GSH0Pe`c08=N=026HCL0QF8h085P
=@1nGC80PUle085N=020GC<0OU/a07eJ<01kF2h0NUL]07UF;01hEBl00`1iES0207YG<@80NePb00<0
M5Hb079D<01_DBd00P1/CRX01P1]Cb/0L58^079D<01^D2`0KDl[06a>:P80JddY00`0K4hZ06e?:`1^
D2`0KE4Y06a@:01]D2P0KdlX079@:P1eDR`0N5D_07aF<@1hEBd207MD:P0907ME:01hERP0NeTY07eL
:@1oGR/0OeX`085L<P23GS@0QV4g00@0R6<i00@0Qf8h08ES<`26I3@0R6Hf0P2:J3P01P29IcL0R6Hf
08MU=@2;ICH0SFLh08iX>@80SfTj00<0SVPi08eW>02;ICH0202<ISL808iX>@<0SFLh0P2<ISL308]U
=P<0RfHi0P2<IcX408eX>`80S6Lj0P2;IST208YU>00308UT=`2;IST0RfHi00<0RVDh0`29I3L01P28
HCX0R64h08QQ>028HCH0R68e08QR<`80R68a2029ICD308US=P80R68e0`27HC@01029I3L0R6<f08MR
=@27HSD208EP<`0408AO<P23GS40QV4d08IQ=0<0QF0c0`24Gc83089M<`<0PE`b0P20Fc4807mL<P<0
O5da0P1kG30307YK;`0407QK<@1fFBl0M5L]079E:`80LE@Z00<0LUD[07=F;01_DRP00P1_DRX0201^
D2X0KDl[06a>;01[C2d0JT//06I<:`1UBbX0HdTX0P1RB2L02P1SBBP0ID/Z06E;:P1VC2/0HDPZ0619
:P1OB2T0GDPY05a9:@1IBBP205Q9:00405=8;01@ABT0C44U04Pm8@80Ac`P00X0BChR04]0901;?2D0
BS/T04Hj8P13>B00@3TO03li7`10>R00?c/P0P0n>R40100m>280>cHR03Xe8@0i=24203La8@0803Tb
8P0h<B40=blR03H^8`0e;2<0<bXS038Y8P0b:B@202`/8P0602/[8@0Z:R00:BTO02PX7P0W9ad09RHL
0`0W:R4202HY80<09BPO100S9Ql2028U7P808B@M200O8Q/301hQ6P<07b8K0P0P8a`3024T7@8082<L
1@0O8Q/3020S70<08B@M0P0S9Q/00`0T9Q/09RHL02PU700202XV7@0702`U7@0]:Q/0;R/L030Z700c
:ah0=B/O03P/800203X/8@0803`a6`0k<1`0=blJ03D^6`0d;a`0<RlN03<`8@0b<24202/[8@0402XZ
800Y:Al0:BTO02PX7P809bLM200Y:AlA02DV7PP092DM01h07R@P01lU8@0R9b409BPQ02DV7P0U9A/0
8b<I02@R5P0P9QP08bLI02HX6P0[:AX0<2XJ03@[6P0h;1`0>RdL040_6`11<AX0A3@M04Lg7P1;>b40
Cd0S05=49@1EARL0I50]06UE<01cGCH0OF@k08AY?02:Jc`208a/>@0@08a^?02?LCl0T7A508ebA`24
Jd<0MUhh06M@;P1OB2P0BSPZ04Hf:@0m<BD0=BdR02h[8P0Z:b<0:2dV02P_:080;BhV1P0/;BD302d]
8`80;RhT0`0_;bD01P0b;R<0<blT03<_900d<2D0=C4V03Hb9`80=c<X03@0>2lZ03T`:@0j<BX0?C@[
03lg;011>B`0@S/[04<l;01<?280CCdS04hn901??bD0DD4W0592:01C@bT0E4@Z0557;P1CAbd0E4T]
05Q:;@1JBbX0GDd[061>:P1QCbT0GDlZ065C;P1UEC40IU@`06EA;P1VCbd0JE8`06iF=01VDRl0J54_
06QB;@1ZDR`0KUD]07=G;`1hFc<0NUdc07eM;P20H340Pf4a08=O;`20G2X0PUdY08UQ;@2>IS80T6XY
099/:`2GLC00VgDd0P2LMSD00`2JM3<0V78a09ik>`0309ik>`<0Wg`l00L0X7dm0:5nAP2OOdH0WWi5
09amA02JOD<0V7i30080UWi20`2FODL02`2DNTL0T7I508]`@@26Jch0PFHi07iS>01]GC`0JUXi06MG
=P1SDc80HE4`00<0Gdl^0P1RCR/306A@;@0306=?;01QCBX0H4`Y00<0FDT_0P1HB2h305M7;@0905Y7
:@1IARP0F4DW05M49P1HABL0FDHX05]8:P1LBB/0DT<T00<0Dd@U0P1DABH205E69`80F4PW101IBBP2
05Y::@0;06U=:01WCBP0IddX06I>:01WDBX0J5D]06YH<01[FC40KUP_06eG;P1[EB`00P1ZE2/03`1[
EB`0KEL^06iH;`1UDS80He0`05m<;01LBBT0FdPX05a9:@1OC2`0HDh^05e@;@1LCb`0FTdZ05Q;:002
05M:9`0505Q;:01IC2T0FTd[05U<:P1HBbT00P1GBRP00`1HBbT0FTd[05]>;00206]B:P80JU4Y00X0
K5<[06iE;@1aF300LUTa06IH<@1TERl0HE</05i@:@1KCBH0FD/T0P1HBR<206=99P0406A:9`1UBbP0
IT`Y06I<:@80ID/X00@0HU0Z065?:@1PCRP0H4hX0P1NC2H00`1MBbD0G4XT05=:8@0205=:8`0305=9
9@1BB2D0DTLW0080DTLY00`0ATDV04E49@14@b@0@d8S04508@10?b00?chO03hm7P13?b@0@ShS03lk
800m>Ah303/g700303`h7@0e<a`0=C<L00<0=C<L100f=1d803Dc7080=SPR00H0=CLQ03@f800c=Al0
<S@N034c7@0`<Q`8034d7`03030b7@0_<A`0;S0K0080;BlJ00<0;S0K030b7@0a<ah00P0[;Qd00`0Z
;A`0:B`K02P[6P0202LZ6@0302HY600T9a`092LL00808bHK100R9AX2020S6P0401lR6@0N8AP07B0G
01dP5`8071lF1P0H7QX201TO6`8061hJ0`0G7AT301HL60P05Q`J600G6AP801HH5`P05ALF400F61L3
01DG5P805QPG0`0G6AP901HH5`<05aTH0P0F61L301DG5PP05QPG200E5aH301@E5`<05AHH0P0F5aT8
01HH5`P05AHH200E5aH@01DF60P05aPJ200E5aH@01DF60P05QLI200E5QP@01HG6@<05ALF0P0F61LL
01LI61006A/J00@05aTH01PJ6@0I6aX06A/J100J71/@01TK6P<06A/H0`0J71T201/M6P806A/H00@0
6Q`I01/M6P0K7AX071hK0P0M7a`201`M5`<07AhH0`0N7aT0100P7aX07ahI01lN6@0O7QT201hM6080
7A`G200M7QP401hO6@807b0J0P0P8A/0100O81X07QlI01hO6@0N7aT201dN60X071dG600M7QP901lP
6PP081lJ0`0P8A/2024R70<08R<M0P0U81X202HQ6`<09b8L00D0:2<M02HS7P0V8ah09b@O02PU8002
02TV8@80:RLR0P0[9AT202`V6P0D02dW6`0^:1`0;RPL02lY7@0f:QX0=b/K03T]7@0j;Qh0>blO03X^
7P0i;Ad0>2`L03<^6P0d;a/0=c0M03Xb7`0l<Al0?C0O03/^7@0m;Ad803l^700303/^6`0m<1d0?S4N
00<0@3<P00<0?S4N03d`7@0l;a`00P0m<1d01@0n<Ah0@3<P044d8@11=240@SDR00<0?C8P0`0l<Al2
03/`7P0;03Lb7P0i<Ql0>S<P03`d8@0m<R00?C0O03d]7@0k:a/0>2/K03T/700k;Qh00P0l;al00`0k
;Qh0>B`L03P[6`0203PW800303DV7`0d9al0<BLN0080;bHM00<0;RLM034W7P0a9ah00P0_9A`0100`
9Qd0<BLN03<Y800e:b8203@Z7P<0<bTM0`0b:1`00`0b;200<B/O02lY7@0302dW6`0302hX700_:Ad0
;BLK00L0;BLK00@0;2TJ02dZ6`0_;1d0<BhO0`0b;b001@0a;Ql0<2dN03<Y7@0d:Qh0=R`P00<0>2hR
00P0=bdQ03H/800m<B40?C4Q03``800k;al0>BdM03P/7080=b/K0`0i;Al203P/7P<0=b/M00<0<2XN
02lY7@0^:1`00P0]9a/0100^:1`0<2XN034[7`0b:1`203<Y7@0303@Z7P0e:al0=B/O00<0=R`P0P0g
;B401@0f;200=2XN034W6`0_9AT0;B<G0080;RLM0P0]9Q`03`0^9ad0<2TO038[8@0c;280=R`P03@Z
7P0b:1`0<BLK030V6P0a9a/0<RPL03<Y7@0_:Ad0<2XN034[7`0203<]8@04034[7`0`:Qh0;bTM02dY
7@<0;2PL100[9a/0200Y9A`0:RHM02/W7P0/:1l0:bLN02XV7@0X91/09R8I200V9Qh0200Y9Ql0:BHM
02/W7P0_:1h0<BTN03@Z7P0e;1d0=b/M0P0b:aT203</6P0<03@]6`0e;Q`0=BhL03D^700h;A/0?34O
03hc8@0m<R00>BhL03P]6`0j;ad0?S<Q0P0h<1d203Ta7P0403Xb7`0k<b00>c<P03/c8080?C0M0P0n
<Ah0300o<Ql0@3<P044d8@11=240?SPP03dg8@0l=R00>c@Q03Tb800h<B40=blR03H^8@80?BdM00<0
>bhM03T^700g;a`00`0e;Q/0100d;a/0>BhL03T^700i;Q`203X_7@<0>c0N0P0c<242038_80@0<BhO
0`0`:Qh202lY7@H0;RPL0`0_:Ad5030Z7P80<B/O0`0b;208034[7@06030]6P0a;Q/0<bhK03D^700g
;Qd0>RhN0P0l;al3030/8@80;b/P0`0^:Ql8038X7`<0=R`P:oooool002[ooooo00@0X7E20:9gA02T
NDH0YW]80P2XODX20:MlB@<0YGa80`2TNdL20:=jAP@0Yg]:102VNTT30:EjA`030:IkB02WO4T0Z7e:
0080Z7e:102VODT20:MnBP80Z7m;0P2XOTh0102XOT`0Z7m;0:QoB`2XOdT20:QoA`@0ZH1<102XOd/0
102TNdL0YGa80:ElB02UO4P20:ImB@80Ygi:00@0XWU50:AkA`2WOTX0ZX5=0P2/Pdl20:^2CPT0Zh5?
00<0[8=?0:^2CP2ZPDd00P2YP4`00`2ZPDd0Zh9>0:b3C`030:V0B080ZX590`2YP4P20:V0C080ZX5=
0P2[PTh20:b3C`80ZX5=00H0ZH1<0:QoB`2YP4`0Zh9>0:f4D02^QE480:^2CP80ZXEA0P2YQ5040:R3
C`090:^6D@2YQ4l0Yh9=0:AoBP2SOTT0Y7m:0:F0B`2VPD`0Ygi:00<0YWe90P2UO4P20:AkA`80W7M3
00<0VgI209Ye@@2IM4000P2HLcl01P2GLSh0Tflo09=_?`2BKSh0TFdm091/?080Sf/k00L0SVXj09A^
?`2DKSl0Tfdn099/?@2@JS/0SfTj0080SVPi0140S68j08QN=P23G3<0Pehd08IQ=`25HSP0PF0e07iM
<P22GcD0PEhd081M<`1oG380OEX`07]H;P1jEbd0NEH/07eJ=00207aI<`0@07YG<@1iES00N5D_07QE
;`1gE2h0MELc079D<01_DBd0K4hZ06]=:@1]Cb/0L58^07=E<@1]Cb/0K4hZ06]=:@80JT`X01L0JddY
06a>:P1]Cb/0KE4Y06a@:01/CbL0KdlX075?:@1eDR`0N5D_07aF<@1gE2`0Me@Z07IC:@1fE2L0MeDW
07YH:01mG2T0Oeh[07iH<@20FS<0Pedf08IP>@0408QR>`0<08MQ>P25Hc<0QV@d08QV=P29IcL0RVPh
08UW=`28ISH0QfDe08]U=P2=IcP0SVPi0P2?JCX00`2>J3T0SFLh08]U=P0808aV=`P0SVPi0`2=IcP2
08aV=`<0RfDf0P2:ICP0102;IST0S6Lj08eX>`2=J3/208iY?080SFPk00@0S6Lj08]V>@2;IST0RVDh
0P29I3L208]V>@<0RVDh0`29I3L01P28HCX0R64h08QQ>028HCH0R68e08QR<`80R68a2029ICD308YT
=`80RF<f0`28HSD208YU>00408QS=P27HSD0QF0c08AO<P80PUd`0P26HC@308EP<`<0Q5lb0`22GC<2
085L<P<0P5/a2020GC<307eN<P<0O5da0P1kG300101hFc40MUT_07AG;@1bEB/2075D:P08079E:`1c
ER`0LE@Z071C:`1^DBT0KDlY06a>:P1[CB/206a=;P0306I<:`1UBbX0HdTX0080HTPW00D0HdTX06E;
:P1UBbX0IT`[0658:P020619:P0305i9:P1LBBT0FTXY0080FDXY00@0EDX^0556:P1=@RH0B3dQ0P16
>al02P18?B40BSlS04`m9P1:>b@0ACTQ048h7`0o>1h0?cTO040j8010?24203hj8@0603dh8P0l=b<0
>cHR03Td8@0h<R80=c4Q0P0i<R803P0h<2<0=RhS03D/8`0d:b@0<bXS038Y900];B<0;2`R02/[8@0Z
:R00:BTO02PX7P0W9ad09RHL0`0W:R4202HY80<09BPO00@092LP02<V7`0S9Ql08bHO0P0R9Ah2024T
7@P07b8K0`0N8AX301lR6`8082<L0`0Q91d2020S70H07b8K0P0P8a`3024T7@808bHK00<092HK02HV
700X9A`00P0Z9Qd01`0/9Ad0;R/L02h[700a:ad0<b/N03D[7`0g:al00P0i:b00400m<A/0>c0J03P]
6@0e;AX0=2dK03D_7`0f<b80=c@U038b:00a<BL0;RhT02`/8P0Y:Al09RHL02@T6P0R8QP802XZ8140
9BHN200T9Ad0<@0O9B4082HR02<X8P0T:B809BPO02@U7@0S8aT08B4G01hV6@0P9QX092PJ02PY6`0]
:Q/0<b`L03D/6`0h;1`0>R/H03`]6010<A`0A3DN04Tk8@1=?b@0Cd4T05539P1TD3D0IE0c06QA<@1^
E340NEde08IW>`2ALD80VGM708id@`2=Ld80S71108Y^?`28Jcl0QVTo08EX?P27Id00FDHg05A2=019
>bh0?3@Y038`900[;2@09b`U02H]9P0^;bL0100];RH302`]9@80;2`T0P0];BD302h^9P0502l_9`0b
;R<0<RhS03<_900d<2D00P0e<BH02P0f<RL0=c<X03H_:@0g<2X0>34Y03Xc:@0l=RX0?CLY03hh:P0o
>BT204`l8P0404dm8`1??bD0D40V0592:080Dd<Y00H0DTLa05A8<01EBBl0F4X]05]<:`1MCB/205m=
9`0P05a>:@1PDRd0I5@`06ID<01UDBh0Ie0^06]D<P1_EcD0I50_06=?;01VCbd0J50/06aB;@1bERl0
MUXb07YM=@1lFbh0Oel`089P<P21GBd0O5PV07eH9024G2P0RV8^08eX902@JbL0U6l[09Mb;P2IM300
V7<_09E`;02CKRX209ai=`0409ej>02NNcT0Wg`j09ml>P80X7dk00H0WW]309al@`2MOD@0W7e409ao
A@2JP4D209Z2AP<0V7m700/0UWe709=iAP2?MD@0RFho08AY>P20ICP0LV=4071Q@P1/GCh0J5Tj06EF
=`0306=D=@0806A@;@1UDBh0IU8_06IB;`1UDBh0Hdl/065=:P1PC2T305Q:;`80EdT^0`1FB2d00`1F
ABT0ED@X05A39`0205A39`0305I5:@1HAb/0FDP/0080D44T00<0DD8U05939P1DABP00P1EART00`1F
AbX0F4TX05Q9:00205Q9:0@0FDXY00/0IddX06I<9`1UCBL0IThX06MA:P1XEBd0JUP`06aJ<P1YDbX0
Ie4X06I@9`0206A>9@0?06I@9`1WDBP0JE<Z069B<@1PD2l0G4`[05Q89`1GAbH0FDTX05a<:`1NCRd0
GE0]05]>:`1IC2T0EdXW0080ETTV00@0EdXW05Q;:01JCB/0FD`Z0`1GBRP0101HBbT0FTd[05]>;01/
Db/306]B:P0?06eD;01_ERh0LUTa07=J<P1QDb`0Ge4Z05]=9P1HBR<0EdTR05Q:8`1JC2D0G4hW06Y@
;@1XCR/0I4XW0080HTPU00<0ID/X06Q>:`1[DBh00P1SDB/0101QCbT0H4hX05i<9P1MBbD205]98`06
05=<8P1CBb@0Dd/T059:9@1BBRH0DTTX0P1BBBX204E49@0;04A39013@R<0@D0Q040o800o?Ql0?SdN
04E19P13?b@0@3`Q03di7P0k=a`00`0j=Q/603Dc70<0=S@M200e<a`0200g>B<0=SPR03Dg8@0d=R00
<cDO038d7P0a<ad0<38L200b=B000`0`<Qd0;c4L02d_6P0202d_6P0302h`6`0`<Qd0<C<N0080:bhM
00@0:RdL02T/6`0X:aX09bXI0P0V:AP202@W70808bHK0`0R9AX01P0Q91T082<J020S6P0O8QT07R4H
01dP5`8071lF00<06ahE01LM6@0G7AT0100H7QX201TO6`8061hJ0`0G7AT301HL60P05Q`J600G6AP8
01HH5`P05ALF400F61L301DG5P805QPG0`0G6AP901HH5`<05aTH0P0F61L301DG5PP05QPG200E5aH3
01@E5`<05AHH0P0F5aT801HH5`P05AHH200E5aH@01DF60P05aPJ200E5aH@01DF60P05QLI200E5QP@
01HG6@<05ALF0P0F61LL01LI61006A/J00<061XI01LI600G6AP00P0G6AP00`0H6QT06A/J01XL6`0@
01TK6P<06A/H0`0J71T201/M6P8061XG00@06A/H01XL6@0L7Q/07AlL0P0N81d201`M5`<07AhH0`0N
7aT401lN6@807QdH0P0M71L901dN60<07QlI0P0O81X2020Q6`@07QlI0P0M7QP:01`M5aP07AhH2@0O
81X8020O6P<0824K0P0Q8Q`3028S7@809B0J0P0V8A/402LR700602@Q700U8Qd09R<N02LT7`0Y9R40
:RLR0P0[:2<402/U6@@0;2HJ0140=RXJ03L[6`0i;Ad0>RhN03/_7`0j;Qh0>BdM03P/700a;aX0=2lK
03Ha7@0i<Ql0>c<P03`a7`0k;Qd0>RdL03l^700303h]6`@0?B`J00@0>2dI03T^6P0k<1`0?C8N0P0n
<al01`0m<Qh0?34M03`_700l;a`0?C0M03ha7P0o<Ql00P11=2401012=B80?S<Q03hc8@0n<b4203db
80<0?34O00/0=S4M03Pa7P0j<b00?3@Q03db800m<1l0?2`L03/[6`0h:a/0>B`L03/^7P0203`_7`0;
03/^7P0i;1`0>2/K03PW800g9Ql0=BHO03<V7P0`9Qd0;bHM02hU700]9Q`00P0`9Qd01P0_9A`0;R@K
02lU700a9ah0<bTP03@Z8@80=R`P00<0=B/O03@Z7P0c:Ad00P0b:1`02@0a9a/0<R`P030Z7P0^:1`0
;BLK02`V6P0]9a/0;RPL030Z7P0802dW6`0402/X6@0]:Q/0<2dN038_80<0=34R0180<c0Q038_800c
:Ad0=B/O03L]8@0i;b<0>S0T03T_8`0h;R80=bdQ03lc8`0n<R80?C4Q03/_7`0i;Ad0=b/K03HZ6P0e
:AT203T]7`80>2`N0`0g:ad00`0f:Q`0<2XN02lY7@0302dW6`0402hX700`:Qh0<B/O03<Y7@@0=2XN
100e:al303H/800603@Z7P0b:1`0;bDI02dS5`0^9ad0;BHL0P0/9A/01`0]9Q`0;bPN034Z800c;280
=B/O03<Y7@0a9a/00P0_9AT01P0`9QX0<BLK038X700[9AT0;2HJ02hX7080;bTM00@0;RPL02`V6P0[
9AT0;RXN0P0]:Ad00`0/:1`0:bLK02XV6P0202TU6@0302PT6`0Y9A`0:RHM0080:RHM00<0:2@K02HR
6@0U8AP0200V9Qh02@0Y9Ql0:RLN02`X7`0_:1h0<BTN03@Z7P0e;1d0=b/M030[6002034/6@03038]
6P0c;Q/0<bhK0080=2lL00T0>BhL03`a7`0o=280?S<Q03X_7@0i;Q`0>c0N03hc8@0g;a`00P0h<1d0
0`0i<Ah0>S8O03Xb7`0203/c800603`_700m<1d0?C0M03ha7P0o<Ql0@3<P0P11=240200n>B<0?CPR
03`g8`0j=B80=c4Q03D_7`0d;R00<bdO0P0m;Ad00`0k;Qd0>BhL03L_700303D^6`0403@_6`0i;Q`0
>BhL03T^7080>RlM0`0k<1h203<`8@80<RlP0`0a;Ql00`0`;Ah0<2XN030Z7P0202lY7@<0;RPL00H0
;BLK02`V6P0]9a/0;BLK02hX700_:Ad2030Z7P04034[7`0`:Qh0<2XN030Z7P80<B/O0`0b;208034[
7@80<BhK00H0<bhK03D^700g;Qd0>RhN03`_7`0m<202034]8P80<2`Q0`0_:b000`0^:Ql0<RPO038X
7`06038X7`<0=R`P:oooool002[ooooo202SN4D01P2SN4d0XgQ;0:=hB`2SNDT0XgU70:=jAP80XgY4
00<0XGM50:=iA`2TNTP00`2VO4X00`2UNdT0Y7Y80:9hAP020:=iA`030:AjB02UNdT0YG]90080YWa:
0`2XODH00`2WO4D0YW]40:Ej@`020:Ej@`P0Z7m;00@0ZH1<0:QoB`2XOd/0Ygi:0P2VODT20:ElB0<0
Z7e:0P2YOT/30:YoC080Z7m90`2YP4X30:Z1B`T0ZGm=202[PTh00`2/PDh0Zh1=0:YoC0020:QmBP03
0:YoC02[P4d0[85>0080ZGm=0P2ZP4h20:^1C`80[89@0P2/PU80102/PU00[8=?0:b3C`2/Pdd20:b3
B`040:j5D@2]Q500[HA@0:b3C`80Zh9>0P2ZPDd30:b2D0030:^1C`2ZP4h0ZGm=0080ZGm=102XPdl4
0:N2CP@0YG]90P2TNTP20:=iA`80W7M300<0VgI209Ye@@2IM4000P2HLcl01P2GLSh0UW1109I`@@2E
Kd00U6ho09=]?P80TV`m0P2AJc`05`2@JS/0SfTj08iX>@2<ISL0RV@e08US=028HS<0SfHj08iU>@2;
ICP0R6<f08IQ=023HC<0PF4b081P<@26HCL0QF0f08AO=@22GC<0P5/a07iI;`1mF2h0O5L]0080O5T_
0P1kF2h0501jEbd0NEH/07QE:`1hEB/0M5@]07=C;01bDR/0L50Y06i>9`1]CBH0K4`U06];901`CR/0
LDl/075@;@1_DBd0KE4/06U?:P1VC2L0Hd/U0P1`CR/00`1_CR/0KU0/06iB;@0206eC;P0>06aD;P1a
E380LED`07=E<@1gEc40NUPb07aI<@1nFc40P5/a085K=P22G3L0Pedf08AO=@25H3@208MR=@80R6@d
00<0QV4d08QS=P2;IST00P2=J3/00`2<IcX0RVDh08QS=P0208eX?00308eX>`2>JSX0SVXh0080Sf/g
00<0Sf`f08aU>P2<ICX01P2<ICX00`2;ICH0SFLh08iX>@0208mY>P0308iX>@2=IcP0RfDf00P0S6Hg
00<0RV@e08aV=`2>J3T00P2@JS/00`2>J3T0S6Hg08YT=@0208mY>P80SVPi00@0SFLh08aV=`2<ISL0
RfDf0P28I3@208UU=@0408YV=P2;IcL0RfLg08aX>0P0S6<g00/0P60a089R<`24I3D0QVHg08MW>026
ISL0QFDf08AT=@2:ICP0RF@g08MR=@0208IQ=00308QS=P2:ICP0RfHi00P0QV4d00<0QF4_08AP;P23
Gbd00P22GR`00`23Gbd0Q60^08EQ;`0208=Q<`80PV0b0P21Gc42081N<080PEhd00@0P5dc07mL<P1o
G380OU/a0P1mFS0307]H<00307aI<@1mFS80OU/c0080OU/c201hEBd0201eDbd0M58/079B:`1^DBT0
JdlW06Q?9P1WCRD0IDhT0P1YB2L0101WBBL0ITTW06A:9`1SBbL3069<9`@0GDXZ00P0FdPX05Q59@1F
@b<0E44Q05Q59`1F@bD0DD0R04dn7`80BSdM0P19?Qh204Tm8`80B3`R0`17>b401016>R00@CXP044j
8011>R02040i7`<0?cPN200i<Ah0200j;B@0>2hT03L]8`0e;B80<bdQ030/800_;B00;R`O0P0W:a`2
02HZ6`0402DY6P0T:1T08bLH02<W60809RLO00@09BHN02@U7@0S91`08R<K0P0Q8QX8024T6aP082<L
200S91`02@0Y:Q`0:R/M02//700[;1X0;2hI02d_6@0^<1X0;S0H03Hc900203Db8@0303@a7P0d<Qd0
<c4J0080<S0G0100>SDR03Td8@0g<Ql0<bhK030[600]:1D0:bHC02TT4@0V82809b<R02XV8`0[:b<0
;2hS02X^7`0W;Q`09BdH0P0W9ad202HV700402DU6`0T91X092@J02<S6@809bLM0`0V9Q`402DU6a00
8R<K0P0S91`0100T9Ad09BHN02LX800X:B4202TZ8P0P02hZ7P0_:al0<bdO03L`800k<R40@3DS048g
9@14=b@0CD<P05548P1FB2D0GT`X06MA;01^E340M5Pc07MI=@26KT80RFi108aa@P2?Ld40TG<m099c
?02BLSL0T70c09I]C`2:HdH0ME4g0610:`1><b80@b`N03dY7P0l:R0202`_9P0>02d^9P0^;bL0;BhV
02`^8`0Z;240:B/P02TZ700];Qh0<S0Q038_7P0`;AX0<bhJ03/d8@11>bD202l`:P0402l`:00`<RL0
<38U034c9@@0<C@S00@0<SDT03@g9P0f>BP0=cXY0P0i?2/01P11>B@0@c/T04Pm9`1;@BP0CT8X0553
:080DD8U00P0CT<U05E7:P1IC2`0Fd`]05Y::@1MBRT0Hdl/06MC<080GTlX00`0Ge0Y061A:P1QDR/0
HU</06=D;@1TEBh0KE0^06eA;01^DRd0Ke</071D;01aER/2079G:P0@07EI<@1dF300LeL_07=G;`1e
FC40Me/c07YN=P1lH3P0PVLb08=X<@25Ic40QfPa08UY<02<JBl0SF/^08iZ;P80T6``00H0TFda099^
<P2FLSH0VWHj09ij?P2QOD4209]l?00309]l>`2KO3T0Vgdg0080VW`d0180VW`c09]nA02KOT@0VWe3
09Qk@@2FNCl0TgHl095d>P2?LSP0SW4g08=V?P21ICd0OV8k07UO>P1dG3P0L5Tg06]G=01ZESD206M=
:00406I>:01WCbT0IU0Y06AA:@80He4Y00P0GTda05m><P1NCc80GDlb05U><01GC2h0DdX[051::P80
EDHY0P1FAbX0501GB2/0F4T/05Q9;01IBRd0EdD_05=1:`1A@2H0E4<W05Y::@1MCBT0Fd`U05M87`1H
AR00FdTU05e=:@1PDRl0H5<a05]@<01HCBl0E4//0P1SEBh0101SE2d0I58/06A@:`1RCRT206==:080
J4h]101WCB`206I<:`80H4d_0P1OC2h0301NBbd0GDX/05e:;01LBB/0DDX]05=:;@1DBb`0EDXZ05Q;
:@1IBbP0FTXX05];9`L0IU0[00T0IDlZ06iF<P1_Ec<0L5Pd075I=@1_Ec<0K5@`06Q@;01VCRX00P1O
CBL305i<9P<0GD/U201NCb@01P1ICBL0F4`V05Q:9@1HB2@0EdLS05M58@80Ed<P0100ET<R05A48P1C
@b80DT<T05539P1?A2P0CD@W04e3:01:Ab@0Ad@S04A18010?Ah0?c/N03lk8010?2<0@CdT0P10?240
100n>Ql0?3PM03Xf6`0h=1T203Hb5`0303Dc700f=1d0=S@M0080=S@M0`0g=Ah0100h=Ql0<cDO03<e
7`0b=1h2034c7@03030b700_<A/0;c4K0080<cDO00@0<S@N034c7@0a<ad0<38L0P0_<A/802lb7@04
02LZ6@0X:aX0:2/J02T/6`80:RdL0P0[;Qd0100Z;1h0:B/M02T[7@0Y:ad202PZ70809bTK00T09RXK
02HZ700U:A/092LL02<V7@0R9Ah08R@O024S7P0L8a/00`0K8QX201XQ6@806B0H200G7AT201LM6`80
5Q`J0P0E6aT:01@J60P061XI200G6AP@01HH5`P05ALF400F61L801DG5PT05QPG600F5aT801DF60P0
5QPG200E5QP801HH5a005AHH200E5aH801DF63005QLI00@05ALF01HH5`0F61L05QPG0P0G6AP201PJ
6@T05aTH200C6AT801LI60P06A/J200G6AP@01TK6P805aTH0P0H6QT201TK6P806Q`K0`0J71T201/M
6P<071hK0`0K6aT201`L6P/07AdK200L71X801dM6`P07QhL200L7Q/301dM6`8071`J0`0K6aT801/M
6P<07AdK0P0L71X301/K6@806adJ0`0L7Q/301dO70T07AhH100O81X2020Q6`808B8L0P0R8QX302<S
6`<092@L0`0S8a/00`0T91`09BDM02HV7P0202HV7P0602DV800W9R409bLO02XW7P0/:1d0;bTM0P0a
:A`203<Y7@<0<RPL0`0a9a/203@Z8@0>03H/8P0g;B40>C0Q03Xa800l<b80?3@Q040c8`0n<B40>bhN
03T/700j;Ad0?2lO040c8`13=RH303lb8@0303ha800m<1l0?2lN0080?2lN100i;Q`403X_7@<0?30P
0P0k;al303X^7P80@2lO00@0?blO03d`7`0l<Al0?34O0P0j<Ql203`a7@0403/`700j;a/0>BhJ03T^
6P80>2dI0P0k:Al0100j:Al0>B/P03P/800i;B4203L]8@<0<2XN0P0_:Ad302hX7080;2/I00h0;BXI
030Z6P0a:QX0<RTJ03<Z6`0e:A/0=bPS03HY8`0e:280<RLQ030W800^9al0;2PO02/W7PP0;2PL200^
:1`202dZ6`0302lY6`0a:A`0<RPL0080=2PL0P0f:1d803<Y7@0803X/8@0k;B80?2hS03d_900l;R<0
>bdR03T[800h:Ql8030Z7P0802`Z7@0[:A`0:bLK02`V6P0^9Q/0<2HL038X7P0f:B0203X]9@0303T/
8`0i;B40>2`N0080>2`L00T0>2dK03D_7`0e;al0<bdO038/800`:Al0;bPP02dV7P0]9R000P0a:240
1P0_:200;BTP02/X7`0Y:Al0:2PN02LY7PP0;2PL200[9ah302PY6`809bPJ0`0V9aT0100U9Qh092DM
02@U7@0T9Ad202<T70808R<K100T91`402DU7@0502TS5`0[9AT0;bTM038/800d;R800P0e;b<0100d
;R80<bdO03<]7`0c;Al203@^80<0=BlQ00T0>RhN03T]7@0h;1`0=b/K03P/700j;Qh0?C4Q03hb8P0e
<1d00P0f;ad00`0h;ah0>RhN03`_7`0203h^7`80?C8P00@0?S<Q03ld8P0o=280@3DS0P11=R@203lb
7`0603lb8@0o<R80?BlR03/]8P0h:Ql0=RPO2@0i;B402010;R@0?bdS03/Z800h:Ql0=RXN03L[7`0g
;B40>2hR0P0a;Qd01P0`;Ah0;b/O02hZ7`0^:R40;BTP02dX8P80:RHM0`0[9ah502`X7`80;BTP00@0
;RXQ02l[8P0_:b80<2`S0P0k;RD0100j;B@0>B`S03LZ8@0f:B0203DX7`X0<R`N0P0c;Al01`0d;R00
=BlQ03D_8@0f<280<2`P02hZ7P0]:Ad00P0/:1`02@0]:Ad0;RXN030/800_:280;bPP030Y8@0a:R00
<B/O038/7P0203<]7@<0>2`P:oooool002[ooooo202SN4D01P2SN4d0XgQ;0:=hB`2SNDT0XgU70:=j
AP80XgY400P0XGM50:=iA`2UNdT0YWa:0:MmB`2VO4X0YG]90:AjB080XgU70P2TNTP20:EkB@80YWa:
0P2XODH20:MlA@80YW]40P2UNT<80:QoB`030:V0C02XOd/0Z7m;0080Ygi:0P2VODT0102UO4P0Z7e:
0:QmBP2XODX20:UnB`<0ZWm<0P2XOdT30:V0BP<0ZX5;2@2YOdd80:^2CP030:b1CP2[P4d0ZWm<0080
Z7e:00<0ZWm<0:^0C@2/PDh00P2YOdd20:Z0CP80Zh5?0P2/PU020:b2DP040:b2D02/Pdl0[8=?0:b3
C@80[8=;0`2]Q5000`2/Pdl0Zh9>0:^2CP020:Z1C@<0[89@00<0Zh5?0:Z0CP2ZP4h00P2YOdd30:V4
D0030:R3C`2WPTh0YX5=0080YX5=00@0YWa:0:EkB@2UNdT0YG]90P2TNTP20:=iA`0609ehA02LMd<0
W7M309]f@P2JMD40VGA00P2HLcl209I`@@0409E_@02DKSl0Tfdn09=]?P@0TV`m00`0T6Xk08mY>P2=
IcP0S6Hg08]U=P2:I3D0SfHj08iU>@2;ICP0R6<f08MR=@23HC<2085Q<P0608EP=P24GcD0Pehd089M
<`21G380OeX`0P1nFBl01P1mFS00O5T_07aI;`1kF2h0NUL]07UF;080N5D[00H0M5@]07=C;01bDR/0
L50Y06m?:01]CBH206a<9@80L4h[00H0L4l/06i@;01/D2/0J4hY06E;9P1SBbD2071>:`0C06m>:`1^
D2`0KU8]06aB;@1]Dbh0K5@^071C<@1aEC00LeDa07MG<@1iEc40O5Ta07eJ<020Fc40P5Xe085K=P22
G3D0Pehd08EP=00208IQ=00508MS<`28I3@0QV4d08MR=@29I3L00`2:ICP208UT=`80S6Lk00H0S6Lj
08eY>@2=JCL0SFTe08iZ=P2>JcD808aU>P0308]U=P2=IcP0SVPi0080SfTj00<0SVPi08eW>02;ICH0
2@2<ISL00`2=IcP0SVPi08iX>@0208iX>@0308eW>02<ISL0SfTj0080SVPi0P2=IcP208aV=`0308]U
=P28I3@0R6@d0080RFDe00@0RVHf08]W=`2;IcL0RfLg202<HcL00`21HC80PV8c08AT=@0308IV=`05
08EU=P24I3D0RVDh08UT=`27HSD00P26HC@00`28HcH0RF@g08]V>@0808IQ=00308EQ;`24H2h0Pel]
0080PUh/00<0Pel]08AP;P25HBl00P23HC<2089P<P80PEla0P20GS000`21GS@0P5dc081M<`0207mL
<P80OU/a00D0OEX`07]H<01kF300NeP`07aI<@0207eJ<P80OU/c201hEBd0201eDbd0M58/079B:`1^
DBT0K50X06Q?9P1WCRD0IDhT0P1[BRT0101XBRP0IdXX06A:9`1SBbL3065;9P0@05a9:@1MBRX0GDXZ
05e::P1KB2P0FDHV05I38`1D@B40FD@W05I39@1C@280CchP04`m7P1;?Qh0BChN04Xo7`80BCdS0P18
?28404Lk8@04044j8010>Al0@3TO040i7`80?cPN0P0n=ad803Xb7`0603X^8P0h;R80=bdQ03D]800c
;Al0<BhO0P0_;Ah01P0X;1d09b/L02L[700V:Q/09BTJ02@X6@808bLH0P0V9al00`0U9Qh092DM02<T
7002028S6`03024R6P0Q91/08B@K00H08B@K600P8a`802<T7080:BXL00H0:R/K02//700/;A/0;BlJ
02d_6@0^<1X203@a8P0303@a800d<Ah0=38M0080<c4J0140<c4H03Xe8P0i=240=c8O03D`7@0b;AX0
;bXG02hY5P0]:1D0:28R02TT8@0Z9b80:BTQ02T[7P0X;1d0:2`K02H^6@0202PX7P809bLM00@09RHL
02DU6`0U9A/09BDK0`0W9ad202HV70@09BDK0`0T9Ad00`0S91`08R<K028S6`02024R6PP08R<K0P0T
9Ad202DV7P0j02HW7`0W:200:2TQ02PY8@0/:Qd0;RXN030]7P0d;R00>34Q03/b8@0o=280@3DS04Hk
6`18?Ad0CSlN05A48`1MBBP0IDd[06U?;01]D2h0N64g07aS>P20J3X0Qfdl08aa?02ALcd0Tg@k09Ae
?02@J4@0SVQ408QUA@1oH4<0LELn069<=@1C@Bd0BcXX038/700c;Al0<RlP038`8`0_;b<0;2hS02T/
8`0X:b809BPM02T[7P0[;B00:R`N02PY6`0Z:1T0;bdN03@b8`0^;bT0;c0Z02l`:00_<BH0<38U030b
9080<C@S01P0<3<R034d8`0b=B@0=3LV03Dh9`0g>RT0>3/Z03Tl:`10>R@0@c/V04Dm9P1:@2L0CD4W
05129`1A@BL0D44T04i39`1CB2X0FD/^05]<;@1KBbX0GDXY069@;01WDc02065B:`80HU</00X0He@]
06AE;P1TEBh0I5D^06iA;`1^DRd0Ke<^071D;@1aEBd0LUL/0P1cF2/03P1fFS80METa07AH<01cEbl0
M5P`07IJ<P1hG3@0NUhf07mT;`20IC00PV@^08=V;P25IRl0QfL^0P2:Ibd308iZ;P05091/<02CKc<0
Ug<g09Yf>P2MNCd00P2INC`0102INSX0VGXi09Yk>02JO3H209]m=@80VWe30100VGa209Qk@@2FNCl0
U7Lm099e>`2AM3X0T7<i08IZ>P25JCX0PVLj07eU=`1iHSH0MV4f07=M=01`GC<0Ke<^0P1]Dbh00`1/
E2h0JU@]06QE;@0206ME;@0806AA<@1UDS80He<b069C<P1PDc40Fe4^05U?;01FCRX805U::`0H05Y8
<01FA2`0ED@Z05M6:01MCB`0Gdl[05e>9`1JBb@0G4XT05i<:01NCRX0Ge4^05iA;`1JCbl0F4d_05E<
;@1PE2h0HE<^061B;@1PD2`0HDl[065=:P1RBbT0HDXX101VC2/406E;:P<0Gd`/00<0GT/[05e::P1M
BRX00P1LBBT01P1DBbh0E4//05E:;01FBb/0F4/Y05Y<:@80Fd/W0P1TCRT03P1UCbX0Ie4/06QB;@1Y
Dbh0JU@_06]E<01`FSD0KeTd06iH<`1/ES40JE<^06E?:P1RC2L0H4XU0P1OCBL305i<9P<0GD/U201N
Cb@205Q<9P0405U;9P1IBBD0F4PT05U78`80FDDR0P1EAB<0301CA2<0DD@T04i39@1=@RH0C4<V04]1
9P18AB80AT<R04A18012?b00@3`O03lk8080?c/R00P0?c/P03hj7`0m>Ah0?3PM03Xf6`0i=AX0>3@I
03Lc60D0=cDN100f=1d00`0c=Al0<S@N038d7P02034c7@80<38L00D0;c4K038d7P0b=1h0<S@N034c
7@02030b7080;c4K200_<Qd302T/6`0302X]700[;Qd0:bhM0080;2lN100Y:ad202PZ70809bTK00H0
9RXK02DY6`0U:A/092LL02<V7@0R9Ah2024S7P@06b8J0P0J8AT201TP60P05adI0P0G7A/201HL6P80
5A/I2P0D6QP801PJ6@P05aTH400F61L801DG5Q005QPG200E5aH901HH5aP05QLI200E5QP801HH5`P0
5AHH200F61L@01DF60P05ALF200E5QP`01HG6@0401HH5`0G6AP05aTH01LI608061XI0P0I6aX901LI
60P04aTI200G6AP801TK6PP05aTH400I6aX201LI608061XI0P0I6aX201XL6`<06Q`I0`0K7AX201`N
6`<06a/I0P0L71X;01dM6`P071`J200M7A/801hN70P071hK0`0M7A/201`L6P<06a/I200K7AX301dM
6`8071`J0`0K6aT201/M6P<071hK0`0M7a`901dN600401hO6@0O81X07b0J01lP6P80824K0P0Q8Q`2
028R6P<08b<K0`0T91`202<S6`8092@L0P0U9Ad202HV7P0602@U7`0U91l09RHN02TV7@0[9a`0;RPL
0P0`:1/00`0a9a/0<RPL038X7005038X7080=2XQ00h0=B/Q03L]8@0i<240>S4P03/b8@0l=240@3<S
03ha8@0k;Qh0>B`L03X]7@0l;al0@3<S048e9@80?c8Q0P0n<B0203d`7`80?2lN100j;ad403/`7P<0
?30P0P0k;al303X^7P80?R`N00<0?BdN03/^7P0j;Qh00P0h;ah01P0g<1h0?34M03`a7@0k<1`0>RlK
03T^6P80>2dI00H0=b`H03/Y7`0k:Al0>RTO03PZ7`0g:al203D[7`0403@/7`0a:al0<B/O034[7`80
<2XN0`0_:Ad202`[6@0>02dZ6@0`:QX0<BXJ038Y6P0c:Q/0=BTK03HY8`0e:280<bPR034X8@0_:200
;2PO02/W7P0Z9ah802`X70P0;RPL0P0]:Q/00`0_:A/0<BTL038X700203@X7080=RPM200c:Ad00`0j
;240>bdR03`^8`0203`^8`0303X/8@0i:b00=bTN00P0<2XN00P0;2XM02/Y700[9a/0;2HJ02hV6`0`
9Q`0<RPN03HY8080=R`S00h0=R`R03H/800f;Ah0=RdL03L^7@0g;a`0=BlO03@^7P0c;Al0<R`P030Y
7`0^9al0;BHN02dV8080<BPQ00H0;bPP02dY800[:1l0:BTO02PX7P0W:Ah802`X70P0:bLN0P0X:1`2
02LW6`<09RHJ00<09BDI02@U7@0T9Ad00P0T9Ad202<T70808R<K100T91`402DU7@0602/U6@0]9a/0
;bTM038/800c;B40=2hR0P0c;B43038/7P80<bdO0`0d;R000`0j;Qh0>BdM03P/700203P/700403X^
7P0l<200?S8R03D`7@80=RlM00<0>2lN03X^7P0k;Qh00P0n;Ql203db8080?S<Q0P0o=282040e8`08
03ha7P0o<Ql0?c8Q03lb8P0m;b80>R`Q03PZ7`0f:1l903H/8008040^900n;280>bXP03PZ7`0f:Qh0
=B/O03H/800f;R42034^7@03030]7P0_:al0;RXO0080;BTP00@0;2LQ02XV7@0Z9Qd0:RHM0P0[9ah5
02`X7`80;BTP0P0^:R4202l[8P80=bdS00@0=R`R03D[8@0d:R00<bTO0P0b:1h8034[7@<0;bTK00<0
<2XL034[7@0a:ad00P0b;1h00`0_:al0;RXN02dY7@0202`X700902dY7@0^:Qh0;b/O02lX8P0_:200
<2TQ034Z800a:al0<R`N0080<bdM0`0h;20[ooooo`00:_ooool80:=hA@060:=hC@2SN4/0XgQ;0:=i
B@2SNDL0XgY60P2SNT@01`2RN4H0XgU70:EkB@2VO4X0Yge;0:IlBP2UNdT0102TNTP30:EkB@80YWa:
00@0Z7e80:MlA`2WO4L0Yga70`2VNdH00`2UNTD0Ygi:0:MnBP060:MnBP@0Z7m;0P2WOTX20:ImB@<0
Z7e:0P2YOT/30:YoC080Z7m90`2YP4X30:Z1B`T0ZGm=202[PTh00`2/PDh0Zh1=0:YoC0020:QmBP03
0:YoC02[P4d0[85>0080ZGm=0P2ZP4h20:^1C`80[89@0P2/PU80102/PU00[8=?0:b3C`2/Pdd20:b3
B`80[HA@0`2/Pdl30:^2CP<0[89@0P2[PDl30:Z0CP080:^6DP2ZQE40ZHA@0:R3C`2WPTh0YX5=0:F0
C02TOd/30:IlBP80YG]90`2TNTP209ehA00309ag@`2KMT80VWE10080VGA000H0V7<o09Ma@P2GLD80
UW1109E_@02DKSl209=]?P07099/?@2DKSl0Tfdn099/?@2AJc`0T6Xk08iX>@0208eW>00608mV>P2>
ICT0RfDh08UT=`28HcH0Q68d0P22HS<208=N=080PUdc0P21G382081K<@0607iK<@1mFS00OEX`07aI
;`1kF2h0NUL]0P1iER`01P1dE2d0Le</079B:`1aDBX0L50Y06i>9`80KDdV0P1_CBX01P1^CBX0K4hZ
06Y>:@1WCBP0ID/V06=;9@80L4h[00<0Kdh[06i@;01]DB`00P1/DRd03P1[Dbd0L5<a075E<01cEC40
MUH`07UG<@1kF300O5T_07iI;`1oFC@0P5Xe085K=022GC<0Q5lc0P25H3<01026HS80Qf<c08MR=@26
HC@208EP<`0408IQ=027HSD0R6<f08UT=`80RVDi00<0RVDh08]W=`2;IcD00P2<J3@00`2<JC<0S6Hi
08aV>@0608aV>@0308]U=P2=IcP0SVPi0080SfTj00<0SVPi08eW>02;ICH0202<ISL208iX>@0408eW
>02<ISL0S6Hg08eW>0@0SVPi0P2=IcP408aV=`<0RFDe0`2:ISH208]W=`P0RV@g00D0Pf4c08AR=025
HcD0QV@f08MU=`0208IT=P0308ES=@29I3L0RF@g00@0Qf8e00<0R6<f08UT=`26HC@01`26HC@00`25
HC40Q60`08=O;`02089N;P0308=O;`24H300QF4a0080Pf4c0P22H382085O<@80P5h`0`20GC<207mL
<P<0OU/a0`1kF30207aI<@<0OEXb201hEBd207AB;00<079B:`1_DRX0K50X06U@9`1XCbH0ITlU06i=
;01]C2/0JT`Z06Q;:@1TBRL0HTXV0`1PBRD0401LBBT0GDXZ05e::P1MBRX0G4TY05U69P1GA2@0ED8R
05U49`1G@RD0E44S050o8@1??R00CChO04`o7`1=@20304Tm8`80B3`R0`17>b42040i7`80?cPN0`0n
=ad00`0m=Q`0>S8O03Xb7`0603Xb7`0903/_8`0i;b<0>2hR03H^8@0d;R00<BhO030^7`0_;Ah0:R`N
0080:B/M00<0:2XL02LY6`0V:1X00P0U9aT202HW7`809BHN00@092DM02<T700R8a/08R<K200R9A`@
020S70P08B@M200S91`202PX700302TZ700Z:a/0:b`J0080;2hI00L0;BlI034]8@0a;Ql0<RlP038_
7P0c<1d0=38M0080=C<L00H0>C@Q03Pc800g<Ql0=S4N03D`7@0c;Q/2038]6P0802dU8P0[9R80:RDO
02TV7@0W9a/09bTK02L[6P0X;1/202TY7`<0:2PN0`0W9ad0100X:1h09bLM02LW7@0W9ad202HV70<0
9BDK00D09bPP02HW7`0U9Qh092DM02<T7002024R6P03020Q6@0R8a/08R<K00H08R<K1@0U9Qh302HW
7`0Y02TW6`0Z:1`0;BTM034[7@0d;Ad0=bhM03T`7`0l<Al0>S<G03he6012=a/0BCXM054n801H@B80
GD@U06159`1WDBX0JeD^079K<@1kHcD0Q6Tj08a`?P2BM3h0U7I008aW>P2?KD00U7E909AgC`2;Ldd0
OfQ606mL>`1TE3<0BcXN04Lg7@0o<a/0=blL030]7P0[;B00:BlU02T`:00W;2D00P0X;BH01@0V:b@0
8bPQ02<Y7`0V;280:BlU0080;RlY00@0;RlW02la9P0_<B@0<38T0`0`<b801@0a=2<0<SDT03<f9@0e
>2L0=STX0080=cXY00H0?CPT040j9013?BL0AclX04]1:01<@2H204i09@0904e3:01BAb/0Ed``05U;
;P1IBR/0Fd/Z065>;@1VDc80I5D^00L0IEH_00H0L5<a071D;`1aEC00LUH_079F;P1cF2d207AI;003
07IJ<P1eFC40M5P`0080M5P`00/0METa07IJ<P1gFc<0NV0_07YP;@1lH2h0OV0/081Q:`22HB/0Pf<Z
08ER:P0208UV;P0>08YW;`2;J300SFXb091]=@2CL3P0U74i09=c>02DM3T0UGDh09Ig=`2HNCP0VGXg
09Yk>02KOCL309Mj@00309Ii?`2EN3h0U7Lm0080TgHl00l0TWDk08a_=`2<KcL0R6df08E/=P21JSH0
OfXe07aX=@1kIc@0NE`d07QL=01gFc<0M5/b07=L<P1aG3400P1^Fc002@1/F3D0KETf06aJ=P1ZFSH0
J5Pd06EG<P1QEBl0H5@^065A<002061@;`0E05m?;P1NCRd0GDd/05e=;01LC2/0GTda05a;;`1KBR`0
GDd/061@;P1RDRh0HE4]05i?:01RD2X0HU0/05m?:`1ND2d0G4l]05U>;P1HCBl0ETd^0080G50Z00@0
G4hY05a<:01KBbL0GD/W0P1MBBH7069::00306=;:@1NBb/0GT/[00<0GDXZ0`1LBBT03`1EC2d0ET/]
05M<;01IC2X0FddZ05a<:01OCBT0GddW06==:01TCRT0IU0[06QB;@1[EC00KELb06mI=002071J=@07
06iH<`1ZE2l0IU0[069<9`1OBB@0GDLR05a68@0205m=9`<0GT`V0`1MBbD805e>9@80F4`V00@0FD/V
05U99@1IBBD0FdTU0P1LB2D02@1GAbD0EDLT05A5901AA2@0CD8T04]29@17@2<0Ad0T04A17P0204A1
800504A18P12?R40@3`Q03hj8@0m>B000P0m>Ah203`h7@80>cLL0P0j=Q/01P0i=b00>3HO03Pf7`0h
=Ql0=cDN03Hd7@80=C<L00@0=38K038d7P0b=1h0<S@N0P0a<ad3030b7004038d7P0a<ad0<C<M034c
7@<0<38L00<0;c4K02ha700^<A`01P0^<A`302/^7@<0;2lN0P0]<1l302T[7@80:2XL0`0W:A/0200U
:AX09BTK02@X6P0S9Q/08RDL024T7@0Q8ah0828M0`0K8QX201XQ6@<06B0H200G7AT201LM6`805Q`J
0P0E6aT:01@J60P061XI200G6AP@01HH5`P05ALF400F61L801DG5PT05QPG600F5aT801DF60P05QPG
200E5QP801HH5a005AHH200E5aH801DF60P05QLI200E5QPP01HG6@0401LI600H6QT061XI01PJ6@80
6A/J0P0J71/901LI60P04aTI200G6AP801TK6PP05aTH400I6aX201LI608061XI0P0I6aX201XL6`80
6A/H0P0J71T301/M6P0401`N6`0K6aT06a/I01/K6@8071`J2`0M7A/801`L6PP07AdK200N7Q`801`N
6`<07AdK0P0L71X301/K6@P06adJ0`0M7A/201`L6P<06a/I0P0K7AX301`N6`<07AlL2@0M7QP301hO
6@807b0J0`0P8A/2028R6P<08b<K0`0T91`0100S8a/092@L02@T700T91`302DU7@0702HV7P0R8ad0
92<N02@T700W91/0:BDJ02`V6P0202hV6@80<2HJ0P0a9a/0100b:1`0<bTM03@Z7P0d:Qh203@Z8@09
03D[8@0g;B40>2lP03T`7`0j<B00>c<P03lb8P0m<200>bhN0080>RdM00@0?2lO03lb8P11=2@0?c8Q
0`0n<B0303d`7`0303`_7P0l<Al0?34O00H0?34O0`0k;al203X^7P<0>BdM0P0k:a`00`0i;1`0>2`L
03H]700203D^700603@_700k<1h0>c0N03X_7@0i;Q`0>2dK0P0g;1X02@0f:aT0>RTO03XY7`0g:Ah0
=BTM03<Y7@0a:A`0<2PK02lY6`03038/8080<B/O0`0`:Qh202`Z6`0>02dZ6`0`:Q`0<BTL038X700c
:Ad0=BTM03DX8P0c:280<RLQ030W800^9al0:bLN02XW7P0Y9Qd802`X70P0;RPL0P0]:Q/00`0_:A/0
<BTL038X700203@X7080=RPM200c:Ad00`0h;200>BdQ03X^8P0203X^8P0303P/800g:al0=BTM00P0
;bTM00d0;2XM02/Y700[9a/0;2HJ02hV6`0`9Q`0<RPN03HY800c:B00=2XQ03@Z800e:al0=RdN0080
=bhM00T0>30M03@^7P0c;Ad0<R`N034[7`0`:Al0;RLO02dV7P0]9R000P0a:2401P0_:200;BTP02/X
7`0Y:Al0:2PN02LY7PP0;2PL200[9ah302LW7@809RHL0`0U9A/302@U7@808b@L0`0R8a/202<S6`80
92@L0P0U9Ad202HV7P0402hX700_:Ad0<2XN034[7`80<R`P0P0a:al2030Z7080<B/M0P0b;1h203<]
7`80>RhN0`0i;Ad02`0j;Qh0>blO03``800d;a`0=BhL03H_7@0g;Qd0>RhN03/^7P0m;Ah0?RhO00<0
?C8P0`0n<b4203ld8P0803`a7@0m<Qh0?C8P03da8@0l<280>BdQ03L[7`0e:1l903H/800A03h]8`0m
;280>B/P03L[7`0e:al0=2`O03D]800d;R00<BhM030]700`;Ah0;b/O02hZ7`0]:B00;2PO02`W8@0Y
9A`00`0Z9Qd202/W7P@0;2PO0`0]:B0302hZ8@0603D[8@0d:R00=2XP03<Y7`0b:1h0<BLM0P0`9Q`8
02lY6`<0;BLI0`0^:1X202lY6`0302l[7`0^:Qh0;2PL0080:bLK00T0;2PL02hZ7P0_:al0;bPR02lX
800`:B40<BXP034[7`0b;1h00P0c;Ad303P/82_ooooo000Zooooo`P0Y7U600H0XgQ=0:=hB`2SN4/0
XgU90:=iA`2SNTH20:=jA0030:9hAP2SNDL0YG]900<0Yge;00<0YWa:0:EkB@2UNdT01@2UNdT20:Il
BP@0Yga9102VNdP80:MnBPH0Z7m;0P2WOTX30:QmBP80ZGi;0`2ZOd`20:QoB@<0ZH1:0`2ZPD/90:Uo
C@P0Zh9>00<0[85>0:^0C@2ZOd`00P2XODX00`2ZOd`0Zh1=0:b1CP020:UoC@80ZX1>0P2[PDl20:b2
D080[89B00@0[89@0:b3C`2/Pdl0[8==0P2/Pd/60:b3C`80Zh9>102/PU040:^1C`80ZhIB00@0ZXEA
0:R3C`2WPTh0YH1<0P2TOd/30:IlBP<0YG]90P2TNTP209iiA@0309ehA02LMd<0VgI20080VWE100L0
VGA009Qb@`2HLT<0Ug5209I`@@2EKd00U6ho0080Tfdn0P2EKd001P2DKSl0Tfdn099/?@2AJc`0T6Xk
08mY>P80SfHj00H0S6Hi08YU>029I3L0QV@f08AT=@23Hc@8089M<`80OU/a0P1mFS00101lFBl0NeP^
07YG;@1jEbd207AD;@0607=C;01bDR/0LE4Z071@:@1_CbP0KThW0P1^C2T01P1]C2T0JddY06U=:01V
C2L0ID/V06A<9P80L4h[00<0Kdh[06e?:`1]DB`00P1[DB`03P1ZDR`0L5<a075E<01bE300MED_07QF
<01jEbl0NUL]07eH;P1nF3<0OeTd081J<`21G380PUda0P24Gc8208EQ<@0808IQ=025H3<0Peha085L
;`22GC00Q5lb08MR=@29I3L208QS=`0308UT=`29ICD0RVHd0080RVHb00<0RfPb08aV=`2<ISL01P2<
ISL00`2;ICH0SFLh08iX>@0208mY>P0308iX>@2=IcP0RfDf00P0S6Hg00<0T6Xk08iX>@2<ISL00P2:
I3D00`2<ISL0SVPi091Z>`0208eW>0H0S6Hg0P29ICD608YV=PP0RF@g00<0QV4d08MR=@27HSD00`28
HcH208MR=@0308UT=`28HcH0R6<f00D0Qf8e2026HC@00`25H3<0Q5lb08=N<@02089M<00308=N<@24
Gc80QF0c0080Pf4c0P22H382085O<@80P5h`201oG38407]H<0@0O5Ta201hEBd207AB;00<079B:`1_
DRX0KE4Y06YA:01YD2L0Ie0V071?;P1_CRd0K4h/06U<:P1UBbP0HTXV0P1PBRD00`1OBB@0G4TY05e:
:P0205e::P0<05a9:@1JAbL0F4DU05I38`1K@bL0FT8V05M29@1D@B<0DD0R050o8@1?@240CT4Q0P1:
?R@204Tm8`80B3`R0P17>b401010>Al0?cPN03lh7P0o>1h203hg7@80?CHL200k<b001P0l<280>S4R
03T`8@0g<200=BlO038_7P80<2lM0P0[;1h202X[7@0402TZ700X:A/09bPJ02LX6P809bPP00@09RLO
02DV7P0T9Ad08b@L0P0R8a/8028U710082<L200Q91d802<T70809bLM00`0:2PL02PY6`0Y:QX0:R/I
02//6P0[;AP0;RXO02hZ7P0`;200<BhO03<`7`0d<Ah203Hd7`<0>3<P100g<Ql02@0f<Ah0<RTR030Y
7`0]9Q`0:2@I02LU600V9aT09bTK02T[7@0602TY7`@0:2PN0`0W9ad402HV700602TZ8P0X:B409bPP
02DV7P0S91`08R<K0P0P8AT8028S6`<09RLO0P0U9Qh302@U7@809BDK02H0:BLK02/W6`0_:A/0<R/K
03</700e;1/0<blF03H`600i<QP0@3@J04Lg7@1=>Ah0DC`Q05@l801HAB@0G4PU06=?:P1]Ebh0MUlc
07mW=`26K3/0RFll08a]=`2=KcT0SW<n08id@@2;Ld<0Qg52089]@01mJcd0MELa06U?:P1I@R80ASHL
03P`6`0a;b00<3<X02lg;080:c0Y00H0:RlY02L^9`0T;BP09Bh[02Ha;@0X<bl202d^:00402d^9P0^
<2D0;S0S02la8`80;c8Q00D0<3<R034d8`0a=2<0<SDT03@g9P0203Dh9`0A03Hi:00l=b@0?CPT044j
9`14?RP0AclX04Y09`1;?bD0BShT04Y39`1@AR/0E4/^05I;;`1GBB`0FDX[05i>;@1RDS40201VEc00
1P1aE380LED`079F<@1cEc00M5P`07AI;P80MEX]00<0MUXb07EI<@1eFC400P1dF3002`1cEbl0M5P`
07AH<01cFbd0M5`/07IK;01hG2`0Ned[07eM:P1nGbT0OehY0080Pf8/00h0Q6<]08ET;P26IBl0R6La
08UX<P2:JC<0SF`f08i]=`2@L3L0TW8g09Ad=`2FMcL0UgPh09Qi>080U7Lm1P2CMS`03`2BMC/0T78b
08mc<P2>LS<0Rg4d08Ua=@26L3H0Q70e08=^=@21I3P0P6<g07mT=`1nHcH0Nf<e07US=00207MR<`08
07IN>01gGcT0MV0i07AQ>@1aGcL0KEhe06YK<P1XFc4206UG<`0406QF<P1VE300I58^06=A;@80HDl[
00D0HU8a065A<01QDBl0HU8`06=C<@0206=C;`09069B;P1VE2h0I58^061@;01MCb`0FTd[05M<;01G
C2h0ETd^0080ET`X00H0F4/X05Q:9`1HB2H0F4PV05U69@1JARD405m89P@0H4TW1@1MBRT305a9:080
F4d]0180Fdh/05a>:`1NCRX0H4hX065=:01QCRH0IU0[06MA;01XDRd0JE<^06]E<01/ES40KELb06iH
<`1YEC00Ie<^069>:@1NBRD305]78P0305a88`1OCBL0GddW00<0GT`V0`1MBbD805]<9@80Ed/U00@0
F4XU05Y:9P1JBRH0GD/W0P1NBRL0401HBRL0ETTV05A79@1?A2@0C4<T04M08`14?b40@chQ044n6`13
@1l0A44P04E28`14@2<0@CdR03hj8@0l>1l203/g70@0?3PM0P0m>Ah02@0j>240>CLP03Tg800h=Ql0
=cDN03Hd7@0e<a`0=38K03<a6P08034c7@P0<38L200^<A`202`_7PH0;C0O0P0Y:ad202PZ70809bTK
0P0V:1X0200T:1T092PJ02<W6@0R9AX08B@K020S700P8Qd07b4L0P0K8QX201XQ6@806B0H0P0H7aL8
01LM6@805adK0P0F71X201DK6@X051XH200H6QT801LI61005QPG200E5aHQ01HH5aP05QLI200E5QP8
01HH5`P05AHH200F61L@01DF60P05ALF200E5QP801HG6@P05AHH800F5aT201PJ6@806A/J100J71/9
01LI60P04aTI200G6AP801TK6PP05aTH400I6aX201LI608061XI0P0I6aX201XL6`<06A/H0P0J71T3
01/M6P<06a/I0P0L71X301dM6a0071`J200M7A/801hN70P071hK0`0M7A/201`L6P<06a/I200K7AX3
01dM6`8071`J0`0K6aT201/M6P<071hK0`0M7a`901dN60<07QlI0`0O81X2020Q6`808R8J0`0S8a/7
02@T70@09BDM00h08B8L028Q700S8a/09R<J02PT6@0[9AT0;2@G02dU600^91P0;bDI030V6P0a9a/0
<RPL03@Z7P80=B/O00D0=2XQ03D[8P0e:b40=R`P03P_800203T`7`0403Xb7`0n<B40?2lO03/^7P80
>RdM00<0?2lO03ha8@10<b<0100n<B0403d`7`80?S<Q100m<R0203`a7`<0>RhN0`0i;Ad203P/7080
=bTL00@0=RXL03@[700c;1`0<b`L0P0b;1`203X^7P0403T]7@0h;1`0=b/K03L[6`80=RXJ00H0>2XO
03LY7P0e:Ad0<RPL030X6`0^9QT202`V6080<bdQ0`0b;203034[7`80;2XM00h0;BTM030Z7P0a:Ah0
<RPN03<Y7`0e:1l0<RLQ034X8@0`9b00;RLO02/W7P0Y9Qd09bLM02HV70P0;2PL200^:1`202dZ6`03
02lY6`0a:A`0<RPL0080=2PL0P0f:1d803<Y7@0303@Z7P0e:al0=R`P0080=bdQ00<0=B/O03<Y7@0b
:1`0200_:Ad05@0/:Qd0:bTL02/W6`0/9QX0;RHK030V700b:1h0=RTP030W7P0a:1l0<RXO03<[7P0d
;Ad0=RlM03L`7P0g<1d0<bdM038/700b;1h0<B/O02lX7P0202hW7`0902dV800a:240<BPQ02lX800]
:B00:bPO02TY7`0X:1h09bTN00P0;2PL200Z9Qd302HV70809BDK0`0T91X202@U7@808b@L0P0R8a/2
024R6P05028R6P0S8a/08b<K02@T700U9Ad00P0V9Qh00`0W9al0<2XN030Z7P02034[7`80<2XN0P0_
:Ad202lY6`80<2XL0`0a:ad01@0b;1h0>RhN03X^7P0j;Qh0>BdM0080>RhN0P0k;al01P0d;a`0=BhL
03D^700g;Qd0>BdM03/^7P80?BdN200m<R00200i<A`0>S8M03/c800k<R40>C0Q03L]8@0e:al0=2XP
2@0d;1l203X/8@0403P/800f;200=2`O03@/7`80<bdO0P0`;A`01P0_;1d0;RXN02hZ7`0]:B00;2PO
02`W8@80:BDL0`0Z9Qd302/W7P80;2PO1P0]:B02034Y7P80<2PM0P0_9a`202hV6`P0;RPJ1P0_:A/2
030Z700302l[7`0]:Ad0;2PL0080:bLK00T0;2PL02dY7@0_:al0;bPR02lX800`:B40<BXP034[7`0b
;1h00P0c;Ad303P/82_ooooo000Zooooo`P0Y7U600H0XgQ=0:=hB`2SN4/0XgU90:=iA`2SNTH20:=j
A0080:=iA`2TNTP0YWa:0:MmB`2XOT`0Yge;0:IlBP2UNdT60:IlBP80YG]9102VNdP40:MlB@P0Ygi:
1P2XOd/20:V0C0<0Z7e:0P2YOT/30:YoC080Z7m90`2YP4X30:Z1B`T0ZGm=202[PTh00`2/PDh0Zh1=
0:YoC0020:QmBP030:YoC02[P4d0[85>0080ZGm=0P2ZP4h20:^1C`80[89@0P2/PU80102/PU00[8=?
0:b3C`2/Pdd20:b3B`80Zh9>1P2/Pdl80:b2D0080:^6DP2ZQE40ZHA@0:R3C`2WPTh0YX5=0:F0C02T
Od/20:MmB`<0YWa:0`2UNdT209mjAP0309iiA@2MN4@0W7M30080VgI200L0VWE109UcA02ILd@0V793
09Ma@P2FL440UFm00080U6ho0P2EKd0209A^?`0409=]?P2BK3d0TV`m095[?080SfHj00@0S6Hi08]V
>@2:ICP0QfDg0P25ICH408=N=0@0PUdc0P1oG380101nFc40OEX`07aI;`1lFBl207]H;P80M5@]0P1c
Db`02@1bDR/0LE4Z071@:@1`D2T0KddZ06i<:@1]C2T0JT`X06U=:00206M=:00606I>:01`CR/0L4h[
06m>:`1]Cb/0K50[0P1ZD2/02@1YDB/0L5<a071D;`1bE300MED_07ID;P1hEBd0NEH/07]F;00207eG
<P0307iH<@20Fc40PE``0080PUd`00X0Pel_08AP<025H3<0Q5lb089M<020Fbh0PE`_08=N<@26HC@0
R6<f0P28HcL00`28HcH0RFDe08UU<`0208YV<P0308YW<@2<ISD0S6He00H0S6He00<0RfDf08eW>02>
J3T00P2?JCX00`2>J3T0SFLh08]U=P0808aV=`03091Z>`2>J3T0S6Hg0080RV@e00<0S6Hg08iX>@2@
JS/00P2;ICH608aV=`H0RVHf0P29ICD808UT=`80R6<f1P27HSD408QS=P0408MR=@26HC@0QF0c08EP
<`P0QV4d00<0QF0d08AO<`23GS800P22GC400`23GS80Q5lc08EP=00208=Q<`80PV0b0P21Gc42081N
<0P0Oe`b201kF30807QE;@0>07AB;01cDB/0LU8[06mB:P1]DBT0Je8Y06YA:01YDRP0LE0_071?;P1]
Cbd0JTd[06I<:@1SBbL2065;9P09061:9@1LBBT0G4TY05e::P1NBb/0GDXZ05]8:01IARH0F4DU0080
Fd4V00H0FT8V05Q39P1F@bD0Dd8T05918`1@@B8304Xn9080BCdS0`18?2801011>R00@3TO040i7`10
>Al203lh7P80?SLM200l=2401P0m<B40>c8Q03Xa800h<Al0=S4N03<`7@80<C0L0P0^;1l0100]:ah0
;2XM02/Y700[:A`202XX6`809bPP00@09RLO02DV7P0U9Qh092DM0P0S91`802<V7A0082<L200R9Ah8
028S6`809BDM00h09RHL02LW6`0X:A/0:BXJ02X[6`0Z:aT0;2PO02dY7P0^:Ql0<2`P038_800d<B00
=C8O03Hc80D0>3<P0`0i=240200g;B40=2`O030X6`0/9QP0:BDI02PV6@0X:A/0:BTM0P0X:1h602TY
7`<0:2PN0`0W9ad302HV700602X[8`0Y:R80:2TQ02HW7`0T9Ad08b@L0P0Q8QX8028S6`0402HW7`0U
9Qh09BHN02DV7P<092DM03408b@L028S6`0S91`09BDK02PV6P0Z9QX0;BLI02hX6P0_:1P0;bhJ034^
6`0f;a`0>S8M040d7P16=Ql0BCLQ04`h801?@2<0DT4S05I69@1NC2P0IU<[06iI;P1dGC40Mf4b08U^
=`28KCH0QVde08I]=`24KCT0QVlk08Ma?`29Ld40TF`o08MV>@1hG3@0ITl]05A5:015?BH0>cPU03Df
900c<BD0;blU02d]9@0Z;BH0:BhX02T_;@0X<C009c4`0080;2dW00@0;2dU02d_900];b80;S0R0P0^
<B02030c8P04034d8`0b=B@0<SDT03<f9@80=3LV0100>3DT03Tf8`0n>BD0@S/X04Dm:016?RL0B3hU
04Lm9017@BL0C4D[0519;@1CBRd0DdPZ05I8:`1KC2d0Ge0a1P1UERl206IG<006075D<P1aEC00LUHa
07=G<01dF300M5T^0P1eFRd507AH<00<07=G;`1bERh0LUH^071I;`1`FBd0LUX/07EJ;@1gFb`0NU//
07YL:P1lG2/0OUh[0P1oGb`00`20H2d0PF4^085Q;P02085Q;P0808MV<`28Ic@0RFPc08a[=@2>KSD0
T70e099b=`2CLcH308ia=`H0Sg8h00P0TW<b091c<@2@LS80SW8c08]a=029LCD0Qg4e08I`=P80QVLi
00@0Q6Pi089W>01oIcL0OfLg0P1mIcH04@1nHcP0Of@i07eU>@1lICT0NVDh07ES=@1cHC<0L5la06mL
=01^Fc<0KEXb06]H<01YERh0Ie@/06IC:`1UDRX0I5D^0080IEH_00d0IEDa06=C;`1SDbl0He<a06AD
<P1UDbd0I58^05m?:`1LCR/0FD`Z05I;:`1EBR`0E4//0080DTXV00<0DdTV05A79@1EARD00P1FARD0
0`1GA2@0FdLT05]7900205a89@80GDTV0P1NBRL305e;9`D0GT`X0P1LCbd01P1ND2d0Gdl[065?:@1S
CbX0IDlX06E?9P80JU@_0P1YDbh206QB;@80Ie4/00<0HDlY05m=9`1LBR@00P1JB2800`1LBR@0GT`V
061>:00205m=9`<0GT`V0`1MBbD805Y;9080Ed/U01H0F4XU05U99@1JBRH0G4XV05e99P1NBRL0EdXW
05A:9P1BB2D0CTDT04U38`15@280@SlP044m8010?AX0@ChM04=07`14@B80A40S044m8P0n>R40?3PO
0P0k=a`203`h7@80?CTN0P0n>Ql02@0j>240>CLP03Tg800h=Ql0=cDN03Hd7@0e<a`0=38K03<a6P08
034c7@@0;c4K100`<Q`802d`6`H0;C0O0P0/;ah302PZ70809bTK0`0V:1X0200S9aP08bLI028V600Q
91T082<J01lR6`0O8A`07R0K0`0J8AT201TP60<061lG200G7AT201LM6`805Q`J0P0E6aT:01@J6100
5aTH400F61L801DG5R405QPG600F5aT801DF60P05QPG200E5QP801HH5a005AHH200E5aH801DF60P0
5QLI200E5QPP01HG6@<061XI0P0I6aX301XL6`T05aTH200C6AT801LI60P06A/J200G6AP@01TK6P80
5aTH0P0H6QT201TK6P806Q`K0P0H6QL201TK60806Q`I0P0K7AX301/K6@8071`J0`0M7A/@01`L6Q00
7AdK200L7Q/301dM6`8071`J0`0K6aT801/M6P<07AdK0P0L71X301/K6@806adJ0`0L7Q/301dO70/0
7AhH0`0N7aT301lP6P808R8J0`0S8a/302@T70@09BDM100T91`01P0P8A/08R4L028R6P0U8QT09b<H
02XT6080;2@G00H0;R@H02lU6@0`9QX0<BLK038X700d:Qh203D[7`0503@Z8@0e:b80=B/Q03H/800g
;Ql00P0h;ah02@0i<Ah0?2lO03`_7`0k;Qh0>RdM03/^7P0l;al0?S4Q03lb8P0403d`7`@0?S4P00<0
?c@R03hc8@0n<b400P0m<R0203`a7`0303/`7P0i;Ad0>BdM0080>BdM0P0h;1`203L[6`80=BTM0P0c
:Ad0100b:Qd0<B/M02l/7@0_;1d203T]7`80>2`N00@0=b/M03HZ700e:A/0=BTK0P0f:Qh0100c:Ad0
<RPL02lW6P0]9aT202XW600403<]8@0b;200<R`P038/8080<B/O0P0`:Qh202`Z7P0>02dY7P0`:Al0
<BPO038X7`0c:B00=BPP030W800_:200;RLO02/W7P0Y9Qd09RHL02DW700T9Q/802/W6`P0;BLK0P0]
:Q/00`0_:A/0<BTL038X700203@X7080=RPM200c:Ad0200b:Qd0<b/N03@/7`0e;B00=2`O03<[7P0a
:A`0<2PK200^:1`05@0/:Qd0:bTL02/W6`0/9QX0;RHK030V700b:1h0=RTP02hW7@0_:1h0<2XN034[
7@0b;1`0=2lL03D`7@0e<1`0<R`L034[6`0a:ad0<2XN02lX7P0202hW7`0902dV800a:240<BPQ02lX
800]:B00:bPO02TY7`0X:1h09bTN00P0:bLK200Z9Qd302DU7@8092@L0`0S8a/302<T70808R<K0`0Q
8QX2028R6P0402<S6`0T91`09BDM02HV7P809bLO0P0a:al01P0`:Qh0;bTM02lY7@0_:Ad0;RPL02lY
7@80;bTK0P0`:Q`3034[7@05038/7P0j;Qh0>RhN03X^7P0k;al00P0j;Qh203T]7@0603<^6`0d;A/0
=BhL03H]700i;Ad0>RdM0P0m;Ah803`a7`0803La6`0h<Q`0>C8O03Tb800h<B40=RhQ03@/7`0c:b09
038/7P80>2`P0P0f;200100d;1l0<bdO030]7P0`;Ah2030]700602l/7@0^:Qh0;BTN02`X7`0[9ah0
:bHP0`0Y9A`302XV7@80:bLN0P0]:B0602`X7`@0;RPL100]9a/802hX6PH0<bdO0P0b;1h00`0^:Qh0
;BTM02`X700202XV6P0902`X700]:Ad0;RXN02lX8P0_:200<2TQ034Z800a:al0<R`N0080<bdM0`0h
;20[ooooo`00:_ooool80:EjA`060:=hC@2SN4/0XgQ;0:=iB@2SNDL0XgY60P2SNT@00`2SNDL0Y7Y8
0:IlBP030:QnC080YWa:0`2WOD/30:IlBP80YG]900@0YGU80:IjB@2VNTT0YWY90`2WNdX00`2XO4/0
YWe90:ImB@060:ImB@@0Z7m;0P2YP4`20:Z1C@<0Z7e:0P2YOT/30:YoC080Z7m90`2YP4X30:Z1B`T0
ZGm=202[PTh00`2/PDh0Zh1=0:YoC0020:QmBP030:YoC02[P4d0[85>0080ZGm=0P2ZP4h20:^1C`80
[89@0P2/PU80102/PU00[8=?0:b3C`2/Pdd20:b3B`<0Zh9>0`2/Pdl20:f4D0040:^1C`2/PU00[89@
0:b2D0<0[H=A00<0[XAB0:V4D02XPdl00P2XPdl30:N2CP040:J1C@2WOD/0Yge;0:MmB`80YWa:0`2U
NdT20:1kA`0309mjAP2NNDD0WGQ40080W7M300L0VgI209YdA@2ILd@0VG=409Qb@`2GLD80UW110080
UFm00`2DKSl209=]?P<0TV`m0P2?ISX0102=IcX0RfHi08]V>@28ISP208MW>0<0Q5le0P23GS@2089M
<`06085L<P20GC<0P5dc07mL<P1nFc40OEX`0P1lFBl0101kF2h0M5@]07AD;@1dE2d207=C;0<0LU8[
0P1`CR/02`1]C2T0JddY06Y>:@1XCRT0JDlZ06UA:`1aCb`0L4h[06m>:`1]Cb/0JdlZ0080JDlZ00h0
IdlY071C<@1`E2l0LE<_07AD;P1eDbd0Me@/07MD:P1iE2X0NeD`07aF<@1mEc00OUT_081K;`80PE`_
00<0PUh^08=O;`24Gc800P23GS403@22GC00Peha08AO<P25H3<0QV4d08QS=`29I3P0RF@g08UU=@2:
IS@0RVHb08]W<`2;J380202<Ic<00`2;ICH0SFLh08iX>@0208mY>P0308iX>@2=IcP0RfDf00P0S6Hg
0P2>J3T0102=IcP0S6Hg08aV=`2=IcP208iX>@80RV@e0P2;ICH408aV=`80RfLg0`2:ISH308UU=@P0
QfDg00<0RfDh08YT=`28HSD00`27HC@208QR=@@0R6<f00@0Qf8e08IQ=024Gc80Peha2026HC@00`25
H3H0Q5le08=N=002089M<`0308=N=024GcD0QF0f0080Pf4c0P22H382085O<@80P5h`0`1nFc4207mL
<P<0P5dc00@0O5Ta07]H<01kF300NeP`0`1jEbl00`1iERh0N5D]07QE;@0607QE;@0507AB;01cDB/0
LU8[06mB:P1^DRX00P1[DRT01`1ZDbT0L4l^071?;P1]Cbd0Jdh/06M=:P1UCBT00P1SCBP04P1RC2L0
FdPX05a9:@1MBRX0GT/[05e::P1LBBT0FTLW05U69P1L@BH0GD8W05a29`1LA2P0FD@W05M49P1E@R@0
DT4S04/o9@<0BShT0P19?B<204Pl8P0404<l8P12>b40@S/Q048k8@80@CXP0P10>Al803de8P0603hc
8@0k<b00>c<P03Tb7`0g<Qh0=38M0P0b<A`2030/800302l[7`0^:Qh0;BTM0080;2PL00L0:bLK02PY
8@0W:2009bPP02HW7`0U9Qh092DM00808b@L200S9Qd@020S70P08RDN200R8a/202@S7P0?02DU7@0V
9Q`09bLK02PY6`0X:AT0:BXJ02`W8@0/:1l0;RXQ02l[800a;B40<c0Q03@a800e<R40=c8O00@0>3<P
0`0i=2401P0l<Al0>2lN03H]700b:a/0;bTK02/W6`80:RPL0`0W9ad302PX7P@0:BTO0P0X:1h302LW
7@809RHL00H0:R/S02TZ8P0X:B409bPP02DV7P0T9Ad202<T70P08R<K200T9Ad2024T7@0L02<T700T
91X09bDI02PT600Y9QL0:bDG02d^800];Qh0<RlP03L`800j<B00?c8Q04<b8014<b40BS/T04/m8`1>
?R@0DT4S05I6901MBbD0HTlW06AA9`1jHc40O6Dc081Y=`23K3P0Qfdj08Q^>`80RFll0100Tflo099`
@P2?L4@0Qf]307QR?@1SDc80DT@W04Ll8012=B@0?S4Q03H]7P0b;200;b`S02d/9`0Z;2L09BXV0P0[
;2H0100[;2@0;2hS02`^8@0];b4202d`7`<0<3<R0P0a=2<3038e900@03Dd8P0g=R@0>SLT03lj9P12
>bP0A3`W04@l9@16>bD0@ShU04Q2:P1<AR`0CTL[04m6:@1@ABL0EdT/05]>;P80H54Z00<0HE8[069C
;01SE2d00P1TEBh01`1UERl0L5<a071D;`1aEC00LUH_079F;P1cF2d00P1dFB`00`1aEBd0LUH^07=G
;`0207AH<00307=G;`1bERh0LED]0080KeT`00P0LEX`07=K;`1fFbh0Me//07YK;@1jFb`0Ne`]07aM
;P<0OEh_00/0O5d^07YK;01jFb`0PEla089P<023HC40QF@a08QW<P2:JC<0Rf/b08a/<`0508U/<P@0
R6/a00P0TFlb08i^<@2>KS<0S6dd08Y]=@26Jc@0QF`d08A[=@80QVHe02H0QFLe08=W=@22J3D0P6Te
085Z=P20JcH0Q6Df08EV=`23IcL0PVPg07iW=@1kIC<0Mf<`07IR;`1cGS<0LUdb075L<@1_FRl0KUT^
06aG;01[ER/0JUDZ06AF:@1VEb`0IeP_06EF;@1RDRh0H50/065A;`1TE3<0HDlY065?:`1NCRX0G4h[
05U<:P1EBRX0DdPZ0558:@80CTPV00<0D4LV05569P1CARH00P1DABH01`1EA2H0FDLS05Y8901JB2@0
FdTU05a:9P1MBbL00P1NC2P405m=9`80H4hX0P1QCbT205mA;P06061@;01SDB/0I50[06MA:P1WDBP0
J54X0P1YDbh01`1WDB`0IU0[06A>:@1SCBP0HT`W065;9P1KC2D00`1JBb@0101KC2D0GDhW05m@:@1P
DBX205m=9`<0GT`V0`1MBbD805Q89080ETXT00@0EdTT05Q8901HB2@0FTPT0P1KAb@0401DBRH0DdTU
0518901;AB<0B4<S04A18P10?b00?chP044n6`11?Qd0@SlN048o8012?R40@3`Q03lk8P0n>R4303`h
7@<0?CTN0P0n>Ql01P0i=b00>3HO03Pf7`0h=Ql0=cDN03Hd7@80=C<L00@0=38K030b700`<Q`0<38L
0P0a<ad3038d7P<0;S0J0P0_<A/3030b70P0;C0K0P0]<1l302`_7P<0:bhM0P0X:Q`202LY6`<09RPJ
00T09BLI028V5`0R9QP08BDG020S600O8QT07R4J01hP6`0M7aX00P0J8AT201TP60<061lG00<05ahF
01LM6@0G7AT01P0G7AT201LM6`805Q`J0P0E6aT:01@J61005aTH400F61L801DG5Q005QPG200G6AP9
01HH5aP05QLI200E5QP801HH5`P05AHH200F61L@01DF60P05ALF200E5QP801HG6@P051DG800F5aT2
01HH5`805aTH0`0H6QT00`0I6aX05aTH01LI600701LI60P04aTI200G6AP801TK6PP05aTH400I6aX2
01LI608061XI0P0I6aX201XL6`<061XG0P0I6aP301XL6@<06a/I0P0L71X301dM6`P06a/I200L71X@
01dM6`P071hK0`0M7A/201`L6P<06a/I200K7AX301dM6`8071`J0`0K6aT201/M6P<071hK0`0M7a`<
01dN60807QlI0`0O81X2028R6P<08b<K0`0T91`0100V9Qh09BDM02DU7@0U9Ad302@T700902<S6`0Q
8Q`08R4L02<S6`0V8aX0:2@I02/U6@0/91L0;BDH0080<2HJ0P0a9a/0100b:1`0<bTM03@Z7P0d:Qh2
03D[8P0303D[8@0f;200=RdN0080=bhM00<0=blL03/^7P0k;Qh00`0k;Qh0100l;al0?C0P03d`800l
;ah303d`7`<0?S4P00@0?c8Q03hc8@0n<b40?C8P0P0l<Al0100k<1h0>RlM03X_7@0i;Ad303P/7080
=b/K0P0f:QX01P0e:1l0<bTO03<Y7`0b:Ql0<B/O02l[7`80;R`O00H0>BdQ03P/800h;200=b/O03HZ
7P0e:Ad203@X700803HZ7P0c:Ad0<bTM034Y700_:A/0;2TJ02/Y6P0Z:1T3034[7`80<2XN0`0_:Ad2
02`Y800>02dY800`:B40<BPQ038W8@0c:280=BPR02hW7`0/:1l0:bLN02TV7@0V9Q`092HK02<V6`0R
9AX802/W6`P0;BLK0P0]:Q/00`0_:A/0<BTL038X700203@X7080=RPM200c:Ad2030Z70<0<R`N00<0
<2XL02hX6P0]9aT0200^:1`0200/:Qd0:bTL02/W6`0/9QX0;RHK030V700b:1h0=RTP0P0]:Ah01P0^
:Qh0;R/L02l/6`0`;AX0<BhK034_6P80<2XJ00<0<2XL02lY7@0_:1h00P0^9al02@0^9b40<BPQ034X
8@0_:200;BTP02/X7`0Y:Al0:2PN02LY7P0802/W6`P0:BDL0`0T8ah202<R7@<08R4L0P0S91`2028S
6`<08B8J00`0824I024Q6@0R8QX08b<K02@T700U9Ad09RHN02LW7`0X:200<B/O030Z7P0_:Ad302hX
700402lY7@0`:Qh0<2XL030Z7080<B/M0P0b;1h203<]7`80>RhN0`0k;al0100j;Qh0>BdM03P/700c
;Q/203@]6`0303H]700h;1`0>RdM0080?2`M0`0l<Al303/`7P80>RlM00P0=C0J03Ha6`0g<Qh0=c8O
03La8@0e;b40<bdO038/80T0;b`M00P0=b/O03D[7`0f;200=BdP03@^800a;Ql0;R`M02d[7080;b`K
00H0;R/L02hZ7P0]:Ah0;2PO02/W7P0[9R0202PT6`80:BDL0`0Z9Qd00`0[9ah0;BTP02dY800302`X
7`<0:bLN1`0/:1`00`0[9a/0;bTK02lY6`0602lY6`<0=BlQ0`0d;R0203<]7`0302hZ7P0]:Ad0:bLK
0080:RHJ00T0:bLK02dY7@0^:Qh0;bPR02lX800`:B40<BXP034[7`0b;1h00P0c;Ad303P/82_ooooo
000Zooooo`P0YGY700H0XgQ=0:=hB`2SN4/0XgU90:=iA`2SNTH20:=jA0080:AjB02UNdT0Yge;0:Qn
C02YOdd0Z7i<0:MmB`2VO4X20:QnC080Yge;0P2VO4X20:EkB@80YGU:0P2VNT/20:MkC080Z7a=202V
ODT00`2WOTX0Z7m;0:QoB`020:V0C080ZX5=00@0Zh9>0:QmBP2XODX0Z7e:0P2YOT/30:YoC080Z7m9
0`2YP4X30:Z1B`T0ZGm=202[PTh00`2/PDh0Zh1=0:YoC0020:QmBP030:YoC02[P4d0[85>0080ZGm=
0P2ZP4h20:^1C`80[89@0P2/PU80102/PU00[8=?0:b3C`2/Pdd20:b3B`80ZX5=0P2[PTh0102/Pdl0
[HA@0:f4D02]Q5020:^1C`80[89@00@0[H=A0:j4DP2^Q580[XAB0P2VPDd20:N2CP80Z8=?0P2YQ502
0:QnC080Yge;0`2VO4X01`2UNdT0XGa80:1kA`2PNdL0WgY609iiA@2MN4@00P2LMd<209YdA@80VG=4
00@0V79309Ma@P2FL440UW110`2CKCh5099/?@03091W>`2?ISX0SFLj0080S6Lj00T0RFLi08QX>@28
J3T0Qf8h08IQ=`25H3H0Q5le08=N=021G3800P20Fc42085N=003081M<`1oG380OU/a0080OEX`00<0
O5T_07EE;P1dE2d00`1dE2d307=C;008079@;@1aCb`0Kdh[06a>:P1[CbX0JU0[06aB;@1/E2h2075?
;00306m>:`1]Cb/0JdlZ0080J4hY00h0IdlY071C<@1`E2l0LE<_07=C;@1eDbd0MU<[07IC:@1hDbT0
NU@_07]E<01lERl0OEP^07mJ;P80P5/^00D0PEd]089N;P22GC00Peha08EP<`0308IQ=080QF0c0P2:
ICT01P2:ICP0RVHf08]W=@2;Ic<0S6Pd08aY<`P0S6Lc00<0RfDf08eW>02>J3T00P2?JCX00`2>J3T0
SFLh08]U=P0908aV=`0308eW>02>J3T0SVPi0080SVPi00<0SFLh08aV=`29Hc@00P2:I3D208]U=P80
S6Hg00D0SFLh08]W=`2;IcL0RfLg08YV=P0208UU=@80R6@d2026ISL02P2>ICT0S6<g08YQ=@29H3@0
R5lc08UP=02:HCD0Rf8f08MR=@28HcH208UT=`0408QS=P25H3<0Peha085L;`P0QV4d00<0QF0f08AO
=@23GS@00P22GC<00`23GS@0Q5le08EP=P0208=Q<`80PV0b0P21Gc42081N<00307eJ<01nFc40OU/a
0080Oe`b0P20GC<00`21GS@0O5Ta07aI<@0207]H<00407YG;`1iERh0NEH^07UF;PP0N5D]0P1cDB/0
0`1bDR/0L5<[06iB:P0206aC:P0706]D:P1_CRd0Kdh]06a>;01[CR`0J4h[06M?:`0306E?:P0305]8
:01LBBT0GDXZ0080GT/[00/0GDXZ05]8:01JAbL0GT0V05e29`1N@bP0GT@Y05e5:@1IA2L0Ed@V05E2
900204/o9@<0BShT0`19?B<204Dn9080A3dS0`13?2800`12>b40?SHS03hf8`0603hf8`0603hc7`0l
=1l0>c<N03Xd7P0h<ad0=C<L0P0c<a/2034]8@03030/800_:al0;RXN0080;BTM00H0;2PL02PY8@0X
:B409bPP02HW7`0U9Qh202@U7@0302<T700T9ah092LN00H092LN400P8a`8028U7PP08B8J01008b8N
02<R7@0T8ah09BDM02HV700W9a/09bPJ02PY6`0/9b40;BPR02hZ8@0_:b00<2`P034^7`0b;b00<c0O
200g<Ql0200n<ad0?C8N03Xb7`0g<1h0<bdO02hZ7P0[9a`0:2DL0`0U9A/00`0V9Q`09bLM02LW7@02
02PX7P<0:BTO0P0X:1h402LW7@<0:2TQ0P0W:20202HW7`0302DV7P0R8a/08R<K00T08R<K00<08b@L
02@U7@0U9Qh00P0V9al01P0P9Al08RDN028U7P0S91`092@J02HT60809b<G01H0:2/P02T[7P0[:al0
<2`P03@/7`0i;Al0>bhN03d]7P11=R80@cLQ04<g7`17>Ah0C3dN05517`1GAB40FDLQ06QA9`1/EBT0
Le/_07YR=P21IST0PfPi0P25JCX0402;Jc`0SVho091a@`2>LDD0RFi307iU?01dFc80KEH]06=9<01J
@RX0D3XS04He8`11=2@0>S8W03</8P0/:1l202X[9@0602//900[;B80;2hQ02`^800/;ah0;C0O100`
<b84034d8`0F034b8P0c=2@0>3LU03`i9P10>bL0@S`V044k9@12>R<0?cXT04<n:019@b/0BT<Y04]1
9P1=@RH0DDHZ05Q:;@1IBR<0FT/T05a=9P1MCRL0Ge0Y065B:`80He@]00H0KU4_06iB;@1_Dbh0L5@]
075E;@1bEb`207=H:`0406iB:P1_Db/0LED]07=G;`80M5P`00`0LeL_079F;P1^FSD0L5Xc075K=01c
G3<0ME`c07QM<P1iG300NUda07YK;`1kG30207aM<@0407]L<01iFRh0MeP/07EF:P80OE/^00H0OU`^
081N;P22HBh0Pf8]08ET;`25I2h308AW;@80PfH/0P22IB/2085T:P0608eZ=02<J3@0RFPc08MW=024
IS@0PV<d0P1oHc@02023HRd0Q6<^08AU;`24IS00PfPa089Y<@23JS80PV`c0P26IS<01`26J3@0Q6Td
085X<P1mIS00NV<]07QS;01cGS400P1bGC000`1`Fbh0KeX]06iI;00206eH:`0F069D8`1VF2T0IeT/
06EF;@1PDBX0GDdY05m?;P1RDS40FdTS05a:9P1LC2P0G4h[05U<:P1DBBT0DDHX04i59P1<AbL0CDLW
04i8:01@AbP0DDHX05=5:080E4DX0P1JB2@0101KBBD0G4XV05e;9`1NC2P205m=:@80H4hV0P1QCbL0
301RD2P0He4Y06=A:@1SDBT0HE4_065A;@1TDRh0IE4/06QB:`1XDRT0JE8X06YC:@<0HT`W0P1QBbH3
061:9@0305]=9P1LCRL0GDlX00<0GU0Y00@0GDlX05a>9`1OCBL0GddW0`1NC2H305e;9@P0EdLU0P1F
BR@0101FB2<0EdLS05I68P1GAB4205M3800@0559901@B2<0CDLS04Y68`17A2<0@d8S04508@0o@240
@SlL044n7@10?A`0?c`M03lk7P0o>b00@3`S044m90<0?SXO1@0m>Ah503Le7P@0=S@M00<0;c4K030b
700`<Q`00P0a<ad2038d7P0303<e7`0];aT0;BlI0080;S0J00@0;c4K030b700`<Q`0<38L200/;aX2
02`_7P80:bhM00@0:RdL02T/6`0Y;1/0:B`K0`0W:A/302HX6P809BLI00H08RHG024U5`0Q9AL082<H
01lR6@0N8AX201dO6P<06B0H0`0H7aL201LN5PP05adI0P0G7A/201HL6P805A/I2P0D6QP801HH5`P0
5aTH400F61L801DG5Q005QPG200G6AP901HH5aP05QLI200E5QP801HH5`P05AHH200F61L@01DF60P0
5ALF200E5QP801HG6@P051DG800F5aT201@F5@805ALF0`0F61L:01LI60P04aTI200G6AP801TK6PP0
5aTH400I6aX201LI608061XI0P0I6aX201XL6`@061XG0P0I6aP201XL6@<06a/I0P0L71X301dM6`P0
6a/I200L71X801dM6`P071`J200L7Q/301dM6`8071`J0`0K6aT801/M6P<07AdK0P0L71X301/K6@80
6adJ0`0L7Q/301dO70T07AhH0P0L7AL201dN60<07QlI00<07b0J028R6P0R8QX00`0S8a/302@T7080
9RHN0P0U9Ad202@T70808b<K00H08R<M02<R7@0T91`09b@K02TU6P0/9QX202hV6@03034W6`0b:1`0
<RPL00D0<RPL0P0e:b800`0e:b40=R`P03H]7P0203H]700303H^6`0j;Ad0>RdM0080>bhN100l;al2
03`_7P80?C0O0P0n<B0203lb8@80?C8P00@0?34O03/`7P0j;ad0>BhL0P0h;A/203P/7080=b/K0`0f
:QX01`0e:AT0=2XQ03<Z8@0c:R40<R/Q030/8@0_;B400P0];B401P0h;200=b/O03L[7`0f:Qh0=BTM
03@X7080<bLK00H0<bTM038Z7@0b:Qd0<B/M02l/7@0^;1d202//70<0;bTM0P0^:1`302dW6`80;2TP
00h0;BTP030Y8@0a:240<RLQ03<X8P0e:280;2PO02/W7P0Z9ah09bLM02DW700S9Q/08RDJ020V6PP0
:RHJ200/9QX202dZ6`0302lY6`0a:A`0<RPL0080=2PL0P0f:1d803<Y7@80;BXK0`0_;1d00`0]:Q/0
:bPI02XW600802dW6`0802`Z7@0[:A`0:bLK02`V6P0^9Q/0<2HL038X7P0f:B0202d[7`0302d[7P0]
:a`0;B`J0080;B`H00H0;B`G02lY6@0_:AT0;bTK02lY7@0_:1h202hW7`0902hW8@0a:240<BPQ02lX
800]:B00:bPO02TY7`0X:1h09bTN00P0:RHJ200Y9A`0100T8al08b8N02<R7P0S8Qh2028Q7@808B0L
0`0R8a/3024R6P80824I00/0820H024Q6@0R8QX092@L02DU7@0W9al0:2PP02TY8@0`:Qh0;bTM02hX
700202dW6`0302hX700`:Qh0<B/O00<0<R`N0P0c;Al303@^800303X^7P0k;al0?30P0080?30P00@0
>RhN03P/700f:QX0<bhK0P0d;A/00`0e;1/0>2`L03T/700203`/7@80?34O0P0k<1h203X_7@80>BhL
00P0<S0I03<a6P0d<Qd0=C8O03Db8@0c<240<RlP030/80T0;B/L00P0=2XN03@/7`0e;B00=BlQ038_
800`;Ql0;2dM02X[6`80;b`K00<0;R/L02dY7@0/:1d00P0[9ah0100Z9Al0:2@K02PT6`0X91/202TU
70<0:RHM0P0]:B0202`X7`80:bLN0P0Z9Qd402/Y70@0;2XM200a:ad303<]7`03038/7P0a:ad0<B/M
0080<2XL00<0;BTM02`X700[9a/00P0Z9QX02@0[9a/0;2PL02dY7@0_:280;bPP030Y8@0a:R00<B/O
038/7P0203<]7@<0>2`P:oooool002[ooooo202UNTL01P2SN4d0XgQ;0:=hB`2SNDT0XgU70:=jAP80
XgY400T0Y7Y80:EkB@2WOD/0Z7i<0:UoC@2XOT`0Yge;0:IlBP2YOdd00P2XOT`00`2WOD/0YWa:0:Il
BP020:EkB@<0YGU:00<0YWY;0:MkC02XO4d00P2XO4d80:ImB@040:MnBP2XOd/0Z7m;0:V0C080ZX5=
0P2[PTh30:QmBP80ZGi;0`2ZOd`20:QoB@<0ZH1:0`2ZPD/90:UoC@P0Zh9>00<0[85>0:^0C@2ZOd`0
0P2XODX00`2ZOd`0Zh1=0:b1CP020:UoC@80ZX1>0P2[PDl20:b2D080[89B00@0[89@0:b3C`2/Pdl0
[8==0P2/Pd/20:Z1C@80Zh9>00@0[8=?0:f4D02]Q500[XEA0P2[PDl0102/PU00[H=A0:f3D@2^Q582
0:n5D`80YH1<00@0YX5=0:N2CP2XPdl0ZHA@0P2ZQE420:QnC080Yge;102VO4X20:5lB0030:1kA`2O
NTH0WWU50080WGQ400L0W7M309]eAP2JM4D0VWA509UcA02HLT<0Ug520080UW111@2BK3d3095[?080
T6Lk00@0SFLj08aW>P2<IcX0RVPj0P29JCX02028HcT0Qf8h08IQ=`24GcD0Pehd085L<P20Fc40OeX`
0P21GS@01020GC<0Oe`b07iK<@1nFc4207eJ<080MED^1P1dE2d0201dDRl0LU0]071?;01]Cb/0K50[
06]A;01^E2l0KUH`0P1aCb`03P1_CR/0K4hZ06]?:P1XCRT0IddX06I>:01`Dc40L5@_075C;`1cDbd0
M58/07EB:P1fDbT0N5<Y0P1jE2l00`1kEBh0OEP^07iI;@0207mJ;@0B081L;021GBd0PE`_08=N<@26
HC@0R6<f08UT=`27HSD0QF0c08AO<P2:ICT0RfHj08]V>@2;IcL0S6Pf08aX=02=JCD0SFXd202<Ic80
0`2;ICH0SFLh08iX>@0208mY>P0308iX>@2=IcP0RfDf00P0S6Hg00<0RV@e08aV=`2>J3T00P2@JS/0
0`2>J3T0S6Hg08YT=@0208US=080RV@e00D0RfDf08aV=`2<ISL0SFLh08aX>00208]W=`0308YV=P29
ICD0RFDe0080R6@d2026ISL00`2>ICT0SF@h08YQ=@0308QO<`0408YQ=@2;HSH0Qf8e08QS=P80RF@g
00@0R6<f08EP<`22GC00PE`_2026HC@00`25GcP0Q5hg08=M=P02089L=@0308=M=P24GSL0QElh0080
Pf4c0P22H382085O<@80P5h`0P1mFS00101nFc40Oe`b07mL<P20GC<2085N=080O5Ta00@0NeP`07YG
;`1jEbl0NEH^2P1hEBd207=A:`03079B:`1`Db/0Ke<[0080K5<Z00L0Je@Z06i=;01^CB`0K4h/06]>
;01YCb`0J50/00<0Ie4/00<0FdPX05a9:@1NBb/00P1NBb/02`1MBRX0FdPX05Y79`1N@2H0Gd4W05m4
:@1OABX0GTHZ05Y5:01H@bH0ET<U00<0BclU0P1:?R@304Tm8`<0ASlU0P15?R@304@m8`P0?SHS00H0
?c@P03`d7`0l=1l0>S@N03Pc7@0e<a`203<c6`80<bdQ00@0<R`P034[7`0`:Qh0<2XN0P0_:Ad202PY
8@0402LX800V9al09BHN02DV7P8092DM200T9ah@020S70P08RDN200Q8QX03P0R8Ad08b8N02<R7@0T
91`09BDK02HV6P0W9a/09bPJ02dX900]:280;RTS02l[8P0_:b00<2`P0P0a;Ql403Lb7`@0=S4N00T0
?c<K03ld7P0o=200?3<R03P`8`0b;200:bLN02PT6`0S8aT00P0T91X00`0U9A/09RHL02HV700202LW
7@<0:BTO0`0X:1h302LW7@P09bPP200R8a/0200P8AT08B8J028S6`0S91`092DM02DV7P0V9al09bPP
0P0P9Al00`0R9Ah08b@L02@T6P0202HT600702LS5`0U:1l09BPO02PX7P0[:Ad0;bTM038X700203HX
6`0P03/c800m<Qh0?c<M044e6`16>1/0C3dL05517`1DA200FdDP05m78@1SBbD0JU4Y07=G;`1jGC<0
P6<i08EV>P29JS`0R6Tk08MX>P27J3T0RFXk08e]?P2ALD80Tg=4085N@01gECT0JD/a05a4;01B@2`0
BSX[03hb9P0e:b4202X[9@0402X[8`0[;B80:bdP02`^8080;2lN1P0`<b82034d8`0N034b8P0c=2@0
=cHT03/h9`0o>RL0@3/W044k9@10>R@0>cTR044l9P16@RT0Ad4W04M0901:@2D0Cd@X05A9;@1EAQl0
ETLP05Q98P1KC2D0GDhW061A:P1RDb`0He@]06e@;P1]DB`0KU8]06mC;01`E2`0LEH[0P1bEbX0101/
D2P0KE4Y071D;01cEbl207AH<080LeL_0P1_FcH0201bG3D0M5dd07IM=01iGCD0NUld07]N=01hFbl0
NE``0P1jGC40301hFbl0MUT]07=F:P1aE2P0NUL]07]H;P1lFRd0OE/]07iL;01oGR/0P5lZ085P:`<0
PF@Z00@0P6<Y07mR:01nHBL0OF0V0P1lGbD0402;ICH0RFDe08QS=P24HSD0PF0e07iN=@1kGS@0NUde
081O:P21H2/0PF8/089T;P21IRl0PfPa08=Z<P24Jc<208MV<@0608MX<P26J380PVL`07mV;P1lHb/0
NF<Z0P1cGBh2079L;@0D075K;01`FR/0KeTZ06mI:P1QE200IELV06MI:P1TEBX0GTlX05Y::01MCB`0
H50_05M57`1IAb<0Fd/W05a>:`1JCB/0E4TY05159`1<@b@204a79`0604i8:01@AbP0DDHX05=5:01D
ART0EDHY0P1HB2@0101IBBD0Fd/W05a<:01MCBT205i>:P04065?9`1RD2P0HU0X06=A:@80I58Z0P1U
Db/2069B;P0606AB;01VDb/0J58Y06YC:P1ZDbT0Je8Y0P1LAR40101MAb80GTPS05m9901PBRD2065;
9P0805mA:P1PDR/0HU@]069D;@1QDb`0GU0Y05Y<9@1HBR<205m=9`<0GT`V0`1MBbD805M79@80ETXT
00@0ETPS05I68P1DA200ED<O0P1E@Ah0401@B2<0CDPR04a68P19AB80Ad@S04=28`11@R80@44R04A1
7P12?ah0?c`K03dj6`0m>A`0?c/P044m9012?RD203lk8080?SXO0P0m>Ah203`h7@0303Dc700f=1d0
=S@M0080=S@M0`0g=Ah0100h=Ql0;c4K02la6`0`<Q`2034c7@03038d7P0c=Al0<cDO00<0;BlI00<0
;S0J02la6`0`<Q`00P0`<Q`802`_6P80:bhM0P0Z;A`0100Y;1/0:2/J02P[6P0W:QT302LY6`809RPJ
0`0U9aT0200Q9AH08BDG020T5P0O8QL07R4H01dP6@0M7aX071hI0`0I81P201PO5`<05ahF200G7AT2
01LM6`805Q`J0P0E6aT:01@J60P05QPG200G6AP@01HH5`P05ALF400F61L801LI60T05QPG600F5aT8
01DF60P05QPG200E5QP801HH5a005AHH200E5aH801DF60P05QLI200D5ALP01HG6@804aDD0`0D5QD3
01DG5PT05aTH200C6AT801LI60P06A/J200G6AP@01TK6P805aTH0P0H6QT201TK6P806Q`K00@05aTF
01PJ5`0H6QL061XG0P0I6aP201XL6@<06a/I0P0L71X301dM6`P06a/I200L71X801dM6`P071`J200L
7Q/301dM6`8071`J0`0K6aT801/M6P<07AdK0P0L71X301/K6@806adJ0`0L7Q/301dO70T07AhH0P0L
7AL201dN60@07QlI0P0R8QX302<S6`<092@L0`0V9Qh00`0U9Ad092@L02<S6`0202<S6`0802<T7P0T
8ah09BDM02PU700Z9Q/0;BLK02hV6@0_9aX203<Y7@<0<RPL0`0a9a/203D[8P0303D[8@0e:al0=RdN
0080=RdL00<0=RhK03T/700j;Ad00P0k;Qh403`_7`<0?2lN00<0?C0O03ha800o<R400P0o<R402@0m
<R00?34O03/`7P0j;ad0>BhL03P]6`0g;1X0=R/I03P/700303L[6`80=RXJ0P0e:AT203@[8P80<b`R
00@0<BdR030^8P0^;R80;RhR0P0g:R4203HY800403DX7`0d9ah0<bHM03<V7@80<RXM0P0a:ad0100`
;Ah0;bdN02d^7P0^;al202hX70<0;BLK0`0/9QX202`Y8P0>02dX8P0`:B<0<BPS038W8`0c:2@0=BLT
02/W7P0Z9ah0:BHM02HV700T9Q/08RDJ020V6P0O9AT802XV6PP0;2HJ0P0]:Q/00`0_:A/0<BTL038X
700203@X7080=RPM200c:Ad0200/:AX0;BXK02h[700_;1d0;R/L02dZ6`0[:1T0:RLH200]9a/0200/
:Qd0:bTL02/W6`0/9QX0;RHK030V700b:1h0=RTP0P0^;2000`0]:ah0;B/L02d/6P0202`[5`0602`[
5P0_:AT0;bTI02lY6`0_:Ad0;RLM0P0^9al02@0^9b40<BPQ034X8@0_:200;BTP02/X7`0Y:Al0:2PN
02LY7P0802XV6PP0:BDL0`0S8Qh2028Q7@<08B0L0`0R8a/2024R6P<0824I0100820H024Q6@0R8QX0
92@L02DU7@0W9al0:2PP02TY8@0_:Ad0;RPL02dW6`0/9QX0;BLK02hX700a:al0<R`P0`0c;Al203@^
80<0=BlQ00T0>RhN03/_7`0l<200?C4Q03``800j;Qh0=b/K03HZ6P0b;AX00P0d;A/00`0e;1/0>2`L
03T/700203`/7@80?34O00@0>c0N03X_7@0j;ad0>BhL0P0h;A/2038`6@0603@b7@0e<Ql0=34P03<`
8@0b;b00<2`P2@0]:a`0200b:Qd0<b/N03@^800e;b40<RlP030^7`0[;1`0:R/K0P0_;1/01P0^:a`0
;BTM02`X7@0[9ah0:RHM02XU7`<0:2@K0`0Y9A`202XV7@80;BTP0P0/:1l01@0[9ah0:RHM02XV7@0Y
9A`0:bTL00@0;2XM0`0]:ah8038/7P80<2XL0P0_:A/01`0^:1X0;BLI02dW6@0/9QP0;BTM02`X700[
9a/00P0Y9AT02@0[9a/0;2PL02dY7@0_:280;bPP030Y8@0a:R00<B/O038/7P0203<]7@<0>2`P:ooo
ool002[ooooo202SNT820:ElB0040:AkA`2SNTH0XgY60:9iA@80XGQ40P2TNTX0102UNdT0YGa80:Im
B@2VODL20:MnAP080:QnC02WOD/0YWa:0:EkB@2VO4X0Z7i<0:^1C`2]Pe480:IlBP80Z7m;0`2WOTX3
0:ImB@030:AjB02VO4X0ZGm=0080Zh5?00<0ZX1>0:QnC02VO4X00P2ZP4h0102YOdd0Z7i<0:QnC02W
OD/20:IlBP0;0:MnBP2XOd/0Z7i<0:UoC`2ZOe80ZWmD0:^0E@2[P5H0[HA@0:^2CP2XOd/00`2UO4P0
0`2XOd/0Zh9>0:f4D0020:^2C080ZX5;00@0ZH1:0:QoB@2XOdT0Ygi8202YP4`01P2WO4T0Z7e:0:Qm
BP2ZOd`0Zh1=0:b1CP80[H9?00<0[hIB0:j5D@2[PTh00`2YP4`00`2ZPDd0Zh9>0:b3C`040:b3C`<0
Zh9>0P2]Q4h00`2]Q500[H=A0:f3D`020:f2E@030:f2E`2WPTh0Yh9>0080Z8=?00@0ZHA@0:Z5D@2Z
QE40ZhIB0`2XOd/20:MnBP<0YWe90P2RODT20:5lB00<0:1kA`2ONTH0WWU509iiA@2GLSh0V7<o09Ye
@@2KMT80W7M309]f@P2JMD40VGA00P2JKd80102IKT40Uf`o09I[?P2DJC`209=X>`06099U>`2AIS/0
T6Dj08mV>P2<IST0RVDh0P27ICL00`2:I3d0R68k08EO>00208=M=P0308AN=`26H3T0R68k0080PEla
0P20GS00101oGBl0OU`^07eK;@1mFbd207=E8`0407=D9@1cE2H0Le@X07=C:P80Le</00H0M4d/079>
;01bCR`0L4h[06m>:`1]Cb/206a@:`0306a>:P1[CBT0JD/W0080JD/W00/0JddY06a>:P1^D2`0IdlY
06U?:P1ZD2/0KU8]075C;`1dDc00MU@a07ME<P0207YF<P0307UF<01iERh0NUL]0080OE/^00X0P5ha
089P<P1nFB`0OeX]081K;P22GC00QF0c08MR=@28HcH0RF@g1@29HcH308YT=`80RfDf00<0S6Hg08eW
>02>J3T00P2?JCX0102@JS/0SVPi08iX>@2>J3T308eW>080S6Hg0P2:I3D0102;ICH0S6Hg08aV=`2=
IcP208iX>@<0U6He0`2CIC@2099T<`0608aW<P2<Ic<0RfHb08]U=02;ICH0RV@g0P2:HcP808YU>003
08MR=@28HcH0RF@g0080RVDh00/0RF@g08QS=P27HSD0Qf4j08IQ=`25H3H0Q5lc08AO<P26HS80R6@b
08UU<`0208ET<@0308ES<`24HS@0Q68e0080Pf0f00H0Pf0h08MP=@27H3D0QV0c08IP<@26H2l208EP
;00308EP:`22H380PV0b0080PEla00D0P5h`07mM;`1oGBl0OU`^07iK<@0207eJ<00507iK<@1oG380
PUle08ER>026HcT0201mFS002P21Fb`0OeTZ07]F:@1gEBP0MUDZ07IF;@1hF340N5/c07MG;P1hF2l3
07YJ<@0307QH;`1fERd0MED/00<0M5@[0P1cDbX3079B:@80Je<a0P1ZDS001P1YDBl0J50^06Q@;P1X
D2h0Idl]06I>:P80IDdY00H0I4`X069:9P1QBBD0HDTU0618901IABX205Q4:@0305M3:01F@RL0ED4V
0080E40U00P0ETHT05A48P1@@1l0CC`N04`k7`1<>b40CC`R04lm9@<0B3hS00<0AcdR04Hl8@15>b00
0P15>b002013>B00@CTR040h8@0o>B<0?CPT03/h9@0j>BL0>CPV0P0n<al203db7P<0?34M00<0>c0L
03Ha7P0f<Ah00P0f<Ah0100c;Q/0<2/H02dX5@0[9Q<202TX8`80:2LR00@09bHQ02HU800U91l09B@O
0P0V:1d302DW70<092HK0`0Q91/2020S6P<07b8I0P0N8AX0100O8Q/082<L020S700Q91d2028U7P80
92LN0P0S9Qd2028U70808B@K0P0T9Al202<T7P04028S7@0Q8Q`08B8L020Q6`@08b@L100T9Ad0400P
:1T08RPJ02DY6P0X:Q`0;2XK034[6`0c;1X0=B`K03H^8@0f;al0=c0P03Pa7`0i<Ql0>C<M03Xd700k
=Ad203Ld8@80=S<P01<0=C8O03@a7P0d<Ah0<c0M034`700_;Q`0;B`J02XX6@0Y9aX0:BLK02XW7P0[
:1l0:BXL02X[7@0[;1h0;2dO02//7P0Z:ad09bPJ00809RLI200X:A/302LV8@809RDP0`0U91l202DV
5P0402DV600V9QX09RHL02HV7P809bHQ00@08R<K02<T700S91`092DM100U9Qh202HW7`0l02DV7P0T
9Ad09BHN02LX800Y:R80:R/S03@^800f;al0>34Q03`c8P11=R@0ACPU04Tj9@1:>bH0DT8Q05A48`1H
AB@0GDTV06==:01WDB`0JU8/06eC;P1kGcL0OF8g081U>023J3/0Q6Tj08AZ>@24JSL0PfTf08a`@@2<
Kd<0RFa208=U?`1hFSH0Jd`]05ho8P1G>1`0@C4R03d_8P0g;B<0<R/S02h]:@0^;c40;S<f02df>`0R
;QH0930H02Tb7@0/=1l0;c<R02la8`0^;R80;R`P034^9@0d<2D0=c<W03dg9`10>BH0@SXU0P11>R02
03`j8`0N03/i8P0l>R<0?S`U040n9`13@BX0AD</04Y39`1;A2P0CdHY0558:@1DBBT0F4/Y05]<:`1L
CR/0HD/T06==9P1VD2T0J58[06UC;01XDR/0Ie4Z06I@:@1^EBd0K5<[06U@:01WCRH0J4lW06YA:@1^
EBd0LEP`0P1_FBX00`1`FR/0LE//079L;@0207=M;P0707AN;`1dGRd0Led/07=M;01bG2/0LE/Z071J
:@0206mI:0@0NUXa00@0O5`c07mO=P21HCP0Pf<j0P25ISP04@23I3H0Of0b07aM;`1kG2h0O5d_07eN
<01nGc40P5ha07mM<01nGC00Ne`^07QL;@1fFb`0MEX[07=K:`1jG2P0OV0/0080PV@`00D0P68^07mQ
;@22I300QFLc085W=P02081V=@0307iT<`1mHc80O68a0080Nf4`01P0OF4_07YP;`1fGRh0LE`_06aI
;P1VEbh0HU@]061D;P1VCc00I4l`069?;`1NCRd0Fdh/05I>:P1CCBT0DThY05=38P1FARD0Fd/Z05m?
;P1NCRd0FTXY05E5901A@B0305Q9;0<0FDX]0P1JBbh405a;;@@0FdX/101RD2X406=A:`0:06ID;P1U
Dbd0He4[065?:@1NC2H0G4XT05Y88P1IAb40FDLO05a:8P80GddU00@0G4XR05]98@1NC2@0HU0X1P1M
CBT205a<:0<0FDXY0`1HBBP205M89`0H05E69@1DAB@0DD8Q0511801A@R40EDHU05U::@1LCB`0H4TY
05m8:01MB2T0G4LZ05Y6:`1GAR`0EDD[05E5;01A@bP0D48W04e29P1:@B@0Ad0S04@o8@13?R00@ChO
0`0o?R8203hm8@<0?C`P00<0=CLO03Hh800g>B400P0h>R800`0f>200=3HN03<e7@09038d7P<0<CDN
0P0`=1d302lc70P0<38M0`0]<1l302`_7P80:bhM0P0[;Al0100Z;1h0:B/M02PZ700W:A/202HX6P80
9BTJ0P0T:1T302<W6003028V5`0P8a`082<L00807b8K100N8AX301TO6`8061hJ0`0G7AT201LM6`80
5Q`J0P0E6aTB01@J61P05aTH200F61L801HG6@P05AHH200G61X801LI60T05AHH600F5aT801DF60P0
5QLI200F61L801HG6A005AHH200B61P0100B51<04aDD01<E500D5QD201DG5PX05QPG400E5QPH01HG
6A405QPG400F5aT@01LI60P06A/J200G6AP801TK6PP06Q`K0`0I6aP301XL6@806adJ400L71X801dM
6`807AlL00@071hK01/M6P0K7AX06Q`I0P0I6aP801/M6Q0071hK200L71X301XL6@806adJ0`0L7Q/;
01dM6`807QhL0P0O7ad2020P7PP08B8L0P0U9Ad302HV7P<09bLO0P0/9Ad302dV7P<0;RLO200/9QX2
034[7`<0<R`P0`0c;B40200`:Q`0<RXM03<[7P0e:al0>2`P03X/8@0m;280?RdS0P0h;200100i;B40
>RhR03X^8P0k;b<203``9080>RdL00@0>BhL03L_700f;a`0=C0L0P0c<A`803LY7P<0<bdQ0`0b;202
034[7`0603DY6`0c:Q/0=2/L03</700b;1`0<BhM0P0`;ad00`0]:B00;2PO02XV7@0202TU700302XV
7@0/:1l0;BTP00P0:bHP200W9al0200X:2009bLO02HV7P0U9Ad092@L02<S6`0R8QX08B4I0P0S8a/0
1P0T91`09BDM02HV7P0W9al0:2PP02TY8@P0:RHM00<0<B/O02lY7@0^:1`00P0/9QX202hX700302lY
7@0a:al0=2PJ0080=BTK00<0=RXL03L[7@0g:ad00P0h;1h0200c:R<0<RTR034X8@0`9b00;bHO02hU
7P0]91d0;2<L200/:1l202`V6P0402dW6`0^:1`0;RPL02lY7@80<2XN00/0;RDN030W800a:240<RTR
034X8@0`9b00;RDN02`S700X91/0:BDL02/W7P0302dY800302`X7`0[9ah0<2TQ0080<2TQ0P0_:203
02hW7`<0:bLN0P0Z9Qd302TU70@09BDM0P0V9Qh202LW7`<08b@N0`0R8ad2024R70<0824K0P0Q8Q`3
028S7@0602<S6@0T91X092@J02DU6`0V9Q`09bLM0P0X:1h202hV6`80;bLL0`0`:1d0500a:Ah0<BLN
038X7`0c:Al0=B/O03H]7P0h;ah0>C0O03Xb7`0e<1`0=2lL03<^6`0b;1`0<R`N03<]8@0d;B<0=BhT
03D]6P0f;Q/0=blL0P0i<Ah00`0g;a`0=RhK03D]6P0203`[6`0403`/700k;Qd0>RlM03/`7P80>S8O
00D0>CDY03Lc9`0d<2@0<BdQ02l[7`0302hZ7P80;b`K00<0;R/L02hZ7P0^:Ql00`0]:B00100]:280
<blS03<_8`0c;b<2038^8P<0<BdQ200W9al0100V9Q`09bLM02LW7@0X:1h202TY7`80:RXP200]:Ad8
02hZ7PP0<BTN00@0;RDN02lV7`0_9Ql0;bHO0`0`9b000`0a:2409BHN02DV7P0602DV7P0802PT600Y
9AT0:bLK02`X700^:Qh0<2`P034]8@0b;R8303<]7b_ooooo000Zooooo`P0XgY200<0YGa80:AkA`2T
NdL00P2SNTH20:9iA@070:5hA02TNTX0Y7Y:0:EkB@2UO4P0YWe90:ImA`020:MnAP080:QnC02WOD/0
Yge;0:IlBP2WOD/0Z7i<0:UoC@2ZP4h80:EkB@030:ImB@2WOTX0Ygi:00D0Ygi:0P2VO4X00`2XOT`0
ZGm=0:UoC@020:UoC@040:QnC02ZP4h0ZGm=0:UoC@80Z7i<0P2WOD/0302VO4X0Ygi:0:QoB`2XOT`0
ZGm?0:UnD@2ZOe80ZWmD0:^0E@2]Q500Zh9>0:QoB`<0YWe900<0Z7m;0:^2CP2]Q5000P2[PT`20:Z1
B`040:V0BP2XOdT0Z7m90:QoB@P0ZH1<00H0Yga90:QmBP2YOT/0ZWm<0:^0C@2/PDh20:f2C`030;27
D`2^QE40[8=?00<0ZX5=00<0Zh9>0:b3C`2/Pdl01@2/Pdl20:^2CP80[HA>00<0[HA@0:f3D@2]Pe<0
0P2]PUD00`2]PUL0Yh9>0:N2CP020:R3C`040:V4D02ZQE40ZXEA0:Z5D@<0Z7m;0P2WOTX30:ImB@06
0:=nBP2RODT0XWe90:5lB02PNdL0WgY60P2NNDD00`2HLcl0VGA009Ye@@0209ag@`0309]f@P2JMD40
VGA00080VVm200@0VFi109M/?`2FJch0U6Tl0P2CJ3/01P2CIS`0TFHk095V>`2?ISX0S6Hi08YU>080
QfDg00<0RF@j08QS>@26HCL00`25H3H208IQ=`06089P<P21Gc40PEla081N<01oGBl0OU`^0P1mFbd2
07EG9@0407AE9P1dEBL0Le@X07=C:P80LU8[00H0M4d/079>;01bCR`0LDl/06m>:`1]Cb/206a@:`03
06e?:`1/CRX0JT`X0080JD/W00T0JT`X06]=:@1]Cb/0IdlY06U?:P1ZD2/0KU8]071B;P1dDc000P1f
E3401@1iEC40N5@`07MD;P1hEBd0NEH/0080O5X]00X0OU`_081N<01nFB`0OUT/081K;P22GC00Q5lb
08IQ=027HSD0R6<f1@29HcH308YT=`80RfDf00@0S6Hg08eW>02>J3T0SVPi0P2?JCX308iX>@<0SFLh
0P2<ISL308]U=P80S6Hg0`2=IcP809=U=00608aW<P2<Ic<0RfHb08]U=02;ICH0RV@g0P2:HcP808YU
>00308MR=@28HcH0RF@g0080RVDh00/0RF@g08QS=P27HSD0Qf4j08IQ=`25H3H0Q5lc08AO<P26HS80
R6@b08UU<`0208ET<@0308ES<`24HS@0Q68e0080Pf0f00H0Pf0h08MP=@27H3D0QV0c08IP<@26H2l2
08EP;00308EP:`22H380PV0b0080PEla0P20GS0207mM;`80Oe`b0P1nFc40101oG380PEhd08=P=P25
HSP807eJ<00;081J:`1oFBX0O5LZ07UG:P1hEb`0MeL^07QH<@1fFC40MeL^07QH;`1iFC000P1jFS40
0`1hF2l0MUH]07EE;00307AD:`<0Le<Z0P1bDRT01P1^E3<0KE<b06aB<@1[DC00JU0_06U?;P80J4h]
00@0Idd/06E=:@1TC2P0I4`X0P1SBbL2069:9P0606599@1IABX0FDDZ05Q4:@1G@bP0ET8W0P1E@BH0
1P1D@2D0EDDS05=38@1A@B00CchP04hm8@80CC`R00D0CC/S04Pn8`18?R<0B3hS04Lm8P0204Hl8@80
AC/P0P13>B000`11>B80?cTS03hi9@0203/h9@0303Xi9`0n<al0?S<O0080?C8N100l<Ad403Ha7P05
03@_700`:aP0;BPE02/V4`0Z:B@00P0Y:2<00`0X9b809bHQ02HU800202DT7`<09RPM0P0U9a`302@V
6`<08B@K0`0P8aX201lR6@<07b8K00<082<L024T7@0Q91d00P0R9Ah202@W7P808bHM0P0R9A`2024T
6`8092DO0P0S91h0100R8ad08B8L024R700Q8Q`3028S6`0302<T700T9Ad09BHN00809BHN00H08BLK
028X6P0U:A/0:2TK02`Z6`0`:QX203</6P80=BdP00<0=RlO03L`7P0h<Ah00P0i<ad0100j=1`0=c@Q
03Hc800f<b0203Db7`80=34N00H0<c0M03<b7P0a<1`0;RdK02/Y6P0Z:1/202TW6`0802XW7P0X:A/0
:BXL02//7P0/;Al0:b`N02X[7@0X:A/202LX6PP0:BXL0`0W9R4202HU80<09B@O0P0V9aL0100V9aT0
9RHJ02HV700V9Qh202HU80@08b@L100T9Ad07P0V9al09BHN02@U7@0S91`092DM02HW7`0X:B40:BXR
038/7P0c;Al0=RlO03Xa800o=280@SDR04@g9017>2<0Bc`M04dn7`1@@1l0ET<S05Y69@1PBBL0HT`W
06E=:@1eFC80Me/c07YN=P1mHSL0Of@g081U=P80P6He0240Q6Xg08I/>`29KSl0RFi108IZ@P20I3d0
NUhi07EH=P1OBc<0ET@^04Xi9`0m<B40=BdR03<_9P0c<Rd0=SLb034d8@0b=B80<SDT038d9P0a<bH0
;c4T02h`9@0];b@0;2`T02h^9P0`<2H0=38U03Dc900f<b00=C<N03Ha7@0k>B800`0j>2404@0l>R<0
?cdV044o:013@BX0Ad4W04U2:01;A2P0CdHY0597:@1FBBT0F4TX05U::@1QBbH0HT`W06E?:P1WDB`0
J58]0080Ie4/00T0IU0[06iF<01/E2h0JE4[06M?:@1XD2X0JU8/06iF<01`F3800P1]F2/0101^FB`0
KeX]071K;P1aG2l2079M<080LUd^00@0LE`]071K;01`Fb`0KeX[0P1^FBX0201fFC40MEP`07AG;`1d
Ebl0MEP`07MJ<P1iG3@0Nehf0P1lGc<00`1kGS80NE``07QK;`0307MJ;P0A07QK;`1nGC80OE`a07]L
<01hFbl0MU/^07=K;@1bFR`0LE//07QL:P1kGbd0OV8`07eQ;`1jGR`0NEd[07aP;P20I3800P1mHS<0
6@1lHC80Nf0a07YO<01iGRl0N5d^07ML;@1gGB`0M5`/075K;01]F2/0IeH[06=D:`1PDRd0GE4[06=>
;`1RCBh0H4d]05a=;01JCB/0EDdY05==:@1BC2P0EdLV05Q89`1IBBP00P1JBRT00`1IBBP0F4PW05Q8
9`0305U:;@D0F4T/0P1HB2L205U9:080FTXY0P1KBbX506EC;@<0I58/00X0He4[069@:P1QCbT0GddW
05i<9P1LBR@0FdTS05Y88P1JB200GD/S0P1PCRH0101MBb<0G4XR05m=9@1SDBT405e=:@@0G4`X00@0
FT/Z05U::@1IBRT0F4TX0P1GB2L205I79P0805E69@1DAB@0DD8Q0511801A@R40EDHU05Q9:01KC2/2
05i79`0305]69`1IARP0ETDY0080E4@Z00T0DT@Z0553:01A@bP0CT<W04]29@18@B@0AD0R04@o8@12
?b000P0o?R8303hm8@<0?C`P00<0=CLO03Hh800g>B400P0h>R800`0f>200=3HN03<e7@09038d7P<0
<CDN0P0`=1d302lc70P0<38M0`0]<1l202`_7P<0:bhM00H0:bdO02X/7P0Z;1h0:B/M02PZ700W:A/2
02HX6P0402DY6`0T:1X092PJ02@X6P808bLI0P0R9QP2020S70807b8K0`0N8AX0100M81T06AlK01TO
6`0I7a/201PN6P<05adI0P0G7A/201HL6P805A/I4P0D6QPH01LI60P05QPG200F5aT801DF60P05aPJ
200G6AP901DF61P05QLI200E5QP801HG6@P05QPG200F5aT@01DF60P04QPH00P051HE01<E500C5A@0
5ALF01/M700R92<0:R`[02la<0P05QPG400E5QPH01HG6A405QPG400F5aT@01LI60P06A/J200G6AP8
01TK6PP06Q`K0`0I6aP201XL6@<06adJ400L71X801dM6`0301dO700L7Q/071hK00806adJ0P0J71T0
0`0I6aP06adJ01/M6P0601/M6Q0071hK200L71X301XL6@806adJ0`0L7Q/;01dM6`807QhL0P0O7ad2
020P7PP08B8L0`0T91`202DU7@<09RHN0P0/9Ad302dV7P<0;RLO1@0/9QX302dW6`<0<B/O0P0b;203
03<]8@06030Z700b:Qd0<b/N03D[7`0h;200>R`Q0P0m;28203P/8080>BdQ0P0j;R8203/_8`80>B`L
00@0>2`L03H]700e;Q`0=2lL0P0b;a`803LY7P<0<bdQ0P0b;203034[7`0603HZ700d:a`0=2/L03</
700b;1`0;b`K0P0^;A/00`0]:B00;2PO02XV7@0202TU700302XV7@0/:1l0;BTP00P0:bHP2P0W9al0
1P0V9Qh09BDM02@T700S8a/08R8J024Q6@808b<K00@092@L02DU7@0V9Qh09bLO0P0X:20802XV7@03
030Z7P0_:Ad0;RPL0080;BLK0P0^:1`0100_:Ad0<2XN038Y6P0b:AX203<Z6`0503@[700e;1d0=B`M
03D/7@0b:B800P0a:2401@0`9b00;RDN02dT7@0]91d0;2<L00P0;2PO0P0]9a/202hX700602lY7@0`
:Qh0<2XN030Z7P0_9Ql0<2LP0`0a:2401P0_9Ql0;B@M02`S700X91/0:BDL02/W7P<0;BTP00@0;2PO
02/W7P0]:B00;BTP0`0/:1l502/W7P<0:RHM0`0Y9A`0100T91`09BDM02DU7@0U9Ad202HV7P809bLO
0`0S91h2028S7@<08B8L0`0P8A/2024R70<08R<M00H08b<I02@T6P0T91X09BDK02HV700W9ad202PX
7P80;RHK0P0_9a`4030X7@0C034W7P0b:1l0<bTO03@Z7P0f;Ah0>2lN03T`7`0i<Ah0=c8N03D`7@0c
;Q/0<R`L034[7@0b;200<b`R03@]8`0e;1/0=RdL03L^7@0203P_7P0303L^7@0f;A`0=B`K0080?2XL
00X0>b/L03X]7@0j;Qh0>2lN03T`7`0h<Al0=S8V03Da9@0b;R80<2`P0`0^:Qh01P0_:al0;b`K02l/
6`0^:a`0;RXN02hZ7`<0;BTP00<0;BPR038^8P0b;R800P0a;B43030/800302l[7`0W9al09bLO00H0
9bLO00<09RHL02LW7@0W9ad00P0X:1h202TY7`0302XZ800]:Ad0;BTM00H0;BTM200^:Qh8034Y7P80
<2LP1P0_9Ql802DV7P80:bLK00@0;2PL02dY7@0_:al0<2`P0P0a;B4303<]7b_ooooo000Zooooo`P0
XgY40`2TNdL20:=jAP<0XWU50P2TNTX0102UNdT0YGa80:ImB@2VODL20:MnAPD0Z7i<00<0Yge;0:Il
BP2VO4X0202TNTP20:ElB080YWe900D0Ygi:0:QoB`2YP4`0ZH1<0:QnC0040:MmB`030:QnC02ZP4h0
ZX1>00<0ZGm=0P2XOT`30:MmB`80Z7m900T0Z7m;0:QnC02YOdl0ZGiA0:YoDP2ZOe@0[8=?0:^2CP2X
Od/00`2VODT00`2XOd/0Zh9>0:b3C`030:Z1B`<0ZH1:0P2XOdT80:V0C080Z7e:00<0ZGi;0:YoC02[
P4d00P2/PDh0102]PTl0/8MC0:n6DP2]Q5030:b3C`80[HA@202/Pdl20:f4CP030:f4D02]Pe40[H=C
0080[H9E00@0[H9G0:R3C`2XPdl0Z8=?0`2YQ5020:Z5D@<0ZH1<0P2XOd/30:MnBP80Xgi:00<0XWe9
0:5lB02PNdL00P2ONTH0102NNDD0VGA009Ye@@2KMT8209ag@`0309]f@P2IM400V7<o0080VVm200@0
VFi109M/?`2FJch0U6Tl0P2CJ3/0202CIS`0TVLl095V>`2?ISX0S6Hi08YU>028ISP0QfDg0P27HSP3
08QS>@0308IQ=`25H3H0Q5le0080PV0b00<0PEla081N<01oGBl00P1nG2h01`1mFbd0N5XX07MI9`1f
EbP0MEHX07=D:01bDRT00P1aDBX0301eCRd0Ldl]07=?;@1aCb`0L4l/06e?:`1/D2/0JdlZ06mA;@1^
D2`0K4hZ06Y<:080JD/W00P0JT`X06]=:@1WCbT0JDlZ06Y@:`1]DB`0Ke4]07=B;`80ME<`0P1fDRh0
0`1fDbd0MU<[07QE:`0207YH:`0;07aJ;@1mFbd0OEP[07iI;01oFRd0PE`_08=N<@24Gc80QV4d08MR
=@27HC@00P28HSD00`29HcH0RV@g08YT=`0208YT=`0608YT=@2;ICH0RfDf08aV=`2=IcP0SVPi0P2?
JCX308iX>@<0SFLh0P2<ISL308eW>080S6Hg0`2;ICH308mS<P03091T<`2AIC@0TVHe0080TfLf00H0
S6Lb08aW<`2;IS80RfDd08]U=P2:I3L208YS>0P0RVDh00<0Qf8e08QS=P29I3L00P2:ICP02`29I3L0
R6<f08MR=@27HCX0QV4g08EP=P24Gc<0Q5lb08IR<P28I380RFDc0080QF@a00<0QF<c08AR=024HSD0
0P23H3H01P23H3P0Qf0e08MP=@26H3<0QV0a08IP;`80QF0/00<0QF0[089P<P22H3800`21Gc43081N
<003089O=@21GS@0Oe`b0080OU/a00<0P5dc085N=022GcD0201mFS0207iH:@0707iI;01lFRd0NeX_
07QH;`1gEc00M5L_07QH;`0207UI<00307YJ<@1iFC00N5P_0080MUH]0P1eEB`207AD:`<0Le<Z00L0
LU8Y075D<P1aE380Ke8`06iA;`1/Cbd0JTd[0080JD`Z00<0J4/Y06=;9`1SBbL01P1SBbL01P1JAbT0
FDHX05U6:01HABL0Ed@V05I39@80ED8T0P1C@b401P1C@b80DT4S0550901??R@0CC`R04`j8P<0B3hS
0P17?B8304Hl8@0804Di7`15>B40@cTP044i8P0o>B<0?STU03`i9P0k>2D303hc7`80?C8N0`0l<Ad3
03Lb7`0603Ha7P0d;a`0<B`I02lZ5`0]:1D0:b/S0P0Z:R800`0Y:B40:2PP02LW7`0202HV7P0402LY
7P0V:1d09RPM02HX7@809BLL0P0T9Q/2028U70808B@K0`0P8aX00`0O8QT07b8K020S7002020S70<0
8B@M00<08RDN02@W7P0T9ah00P0S9Qd2028U70808B@K0`0S91h3028S7@808B8L01H0824I024R6P0R
8a/08b@L02@U7@0U9Qh09RLO02LX800S9Qd08bHK02DW700X:1`0:bTL02dZ6`0`:QX0<B/K03<]8@0c
;Al0=2hP03D_7`0e<1d0=S4M0P0g<Q`203Hc8080=C8O100d<Ah01P0f=1l0=34N034^6`0_;1/0;2TJ
02/W6`80:RHK00<09bPJ02PY6`0Z:ad00P0[;1h202X[7@80:BXL200Z:ad302PX80809bLO0`0V9Qh2
02PY6@0402PY6`0W9a/09RHL02DU7@8092<N0P0T9Ad00`0S91`08R<K028S6`03028S6`0302DV7P0T
9Ad08b@L00808R<K00T092DM02HW7`0W:200;RXN02l/7@0b;1h0=BhN03T`7`0m<R000P10<b003P13
=A/0A3HK04Ph7P1<>al0CchP05A18@1G@b80FDDT06Q@;01ZDR`0KED_075J<@1cG380MEhb0P1fH340
801mI2`0PFP`08I]=`2<LSl0SWA308icA02<LD@0RVm207iQ@@1eFS`0JU4c05]6:`1??BD0AcPS048g
8`11=R@0?S8T03``900h<2<0=BlS034_8`0^<2D0;C0W02`b:00Z;2L0:bhW02`_:00]<2L0;S4V02da
8`0]<B80;30Q0P0i=b8203Pf8@0@03Xh8`0l>RD0?cdX040n:@13?bH0AClW04I09P19@RH0CD@W04m4
9P1CABP0E4LW05e;9`1NC2P0H4hZ065?:`@0HU0/00<0K5Ha06YD;`1XDRd00P1WDB`00`1ZE2l0KELb
06mI=00206aG;080KEP]00@0KUT^06mJ;`1`Fc00L5/`0`1`Fbh306mJ;@80KUT/00<0LUH^075E;@1`
E2`00P1_Db/00`1`E2`0LED]079F;P02079G;00307=H;@1dFBh0MEX_0080M5T^0180LeP]079G;01j
FS40NUXa07MJ<01eFRl0LUX^071I;@1_FRd0KUT/07EJ;@1hGC00NEha07ML;`1cF2/0LULZ07EJ;@1h
GC0207=L<004079K;`1aFRh0L5T]071I;@80KeP/01<0KEHZ06aE:@1YE2T0IE8X069@:01NCbP0FddX
05Y<9`1OC2`0GT/[05a<:`1JBbX0F4/Y05E;:01DC2P0Dd/W05];:P1IBBP0EdLV0080ETHU00<0FDTX
05e=;01PD2l00P1JBb`0101IBR/0F4TZ05Q9:P1GB2T205I7:080EDDT00L0ETHU05Q89`1IBBP0Fd/Z
05a<:`1MCB`0J5H`0080IeD_00<0IU@^06EC;@1TDR`00P1TDR`305i<9P80GD/U0`1LBR@0201LBR80
GddU069@:01QCbL0GT`T05e;8`1PCRH0He4Y0`1MCBT205a<:0<0Fd/W0P1JBbX0101IBRT0F4TX05I7
9P1EARD205A5900I05E69@1DAB@0DT<R05528@1B@b80EDHU05Q9:01JBbX0FTHU05U5901HABD0ED@V
05A39`1B@RP0D48W0512:01BA2T0DD<X04i39`1<@bH0B44T04I18`15@280A44R03ln8P0303hm8@80
?C`P0P0l>al00`0e=al0=SPP03Li8@0203Pj8P0303Hh800d=Qh0<cDM00T0<S@N0`0a=Ah2030d7@<0
;c<L200`<Qd202d`7`80;2lN0`0[;Qd01@0Z;A`0:R`N02X/7P0Y:ad0:2XL00809bTK0P0V:1X202@W
70808bHK0`0R9AX0100Q91T07b8K01lR6`0O8Q/201hQ6P<07B0I0`0I7a/201PN6P<05adI0P0G7A/2
01HL6P805A/I4P0D6QPH01LI60P05QPG200F5aT801DF60P05aPJ200G6AP901DF61P05QLI200E5QP8
01HG6@P05QPG200F5aT@01DF60P04QPH00P061XI01DG5P0C5A@04aDD01TK6P0T9RD0;c4`03Hh=`P0
5QPG400E5QPH01HG6A405QPG400F5aT@01LI60P06A/J200G6AP801TK6PP06Q`K0P0I6aP201XL6@<0
6adJ00<071hK01`L6P0L71X03P0L71X801dM6`<071hK0P0K7AX301XL6@P06adJ400L7Q/801`L6P<0
6Q`I0P0K7AX301`N6`/07AdK0P0N7Q`201lO7@80820N200Q8Q`3028R6P808b<K0`0T91`202`U7@<0
;BHN0`0^9al302/U6@0602`V6P0]9a/0;RPL02hX700_:Ad0<2XN0`0a:al2038/8080<bdQ00H0<B/M
038Z7@0c:ah0=2XN03L[7`0i:b0203`[8@<0>2`P0`0i;B4203X^8P80>B`L00@0>2`L03H]700e;Q`0
=2lL0P0b;a`803HZ7P80<bdQ0P0b;203034[7`0<030Z7P0g:al0=2XN03@Z7P0b:Qd0<2XL02dZ6`0/
:Q/0:bTJ02`X7`0[9ah0:RHM0P0Y9A`00`0Z9Qd0:bLN02`X7`0802/V80X09RHN00@09BDM02@T700S
8a/08b<K0P0R8QX202<S6`0402@T700U9Ad09RHN02HV7P809bLO200Z9Qd00`0`:Qh0;bTM02hX7002
02dW6`80;RPL00@0;bTM030Z7P0b:1`0<RPL0`0c:Ad303@Z7P06030Y8@0_:200;bPP02hW7`0]9Qh0
;2DM0P0[91`802/W7P<0;bTM0P0`:Qh3034[7`80;RLO0`0_:2002`0^9al0;2DM02/T700X91/0:BDL
02/W7P0/:1l0;BTP02`X7`0[9ah0:RHM00<0:bLN0P0Z9Qd302TU700402/W7P0Z9Qd0:RHM02XV7@80
:BDL0P0X91/302@T70809BDM0`0V9Qh202<T7P808R<M0`0Q8Q`4020Q6`808B8L0`0R8ad01P0S8aT0
92@J02@T6P0U9A/09RHL02LW7@80:2PN0`0]9a/202hX70<0;bTM00h0<BLN038X7`0c:Al0=2XN03H]
7P0g;Qd0>2lN03P`7@0h<al0=c8O03@_700b;1`0<2XL030Z7P80<BXP00<0=2/J03D/6`0g;Qd00P0h
;ah00`0g;Qd0=B`K03@[6P0203XZ6`0303T/700h;1`0=bhM0080=RlM00T0=C0M038^8P0`;200;RXN
02dY7@0/:1`0;BTM02hZ7P0_:al00P0_;1/00`0^:a`0;RXN02hZ7`0302dY800302dX8P0`;200;b/O
0080;b/O0P0^:Qh202dY7@P09RHN100W9ad202PX7P80:BTO400]:Ad802lY7@80<2TQ00@0;bPP02hW
7`0^9al0;BHN0P0/9Ad802DV7P<0;RXN0P0_:al2030/8004034]8@0c;Al0<bdO03<]7b_ooooo000Z
oooooa00XgY60P2TNTX0102UNdT0YGa80:ImB@2VODL20:MnAP80Z7i<0P2YOdd00`2XOT`0YWa:0:Aj
B0090:=iA`060:=jAP2TNdL0YGa80:ImB@2WOTX0ZH1<0P2ZPDd00`2ZP4h0Z7i<0:IlBP020:EkB@03
0:MmB`2ZP4h0[89@00P0Z7i<0P2XOdL0102XOdT0Z7m;0:QnC02XOTh20:UnD@030:^2CP2ZPDd0Z7m;
00<0Ygi:00<0Z7m;0:Z1C@2[PTh00P2ZPD/60:V0BPP0ZH1<0`2YOT/00`2ZOd`0Zh1=0:^0C@020:b1
CP030:n6DP2^QE40[XEA00<0[HA@0P2^QE430:^2CP@0[8=?00H0[HA@0:f4CP2]Q4h0[HA@0:f3D@2]
Pe<20:f2E@030:f2E`2XPdl0Z8=?00H0ZHA@0P2ZPDd30:V0C0<0Z7m;0P2SOTX0102RODT0XGa80:5l
B02PNdL209mjAP0809Ye@@2KMT80W7M309ehA02LMd<0VgI209Ud@02HLcl209Y_@P0409U^@@2GK3l0
UV/n09AY?080TfPk00H0TfHl099W?02AIS/0SfHj08eW>P2;IST208QV>00308EP=027HSH0RF@h0080
RVDi00<0R6<g08EP=023GS800P22H3801021Gc40P5h`081N<01oGBl207iL;P0D07YL:P1iFbT0N5TZ
07IG:@1dEBT0LU8Y075A:P1`D2T0MTl^07A@;P1cCbd0LU0]071?;01]Cb/0K50[06]?:P1aDbl0Ke4]
06e?:`1[CBT206U;9`80JT`X00P0IdlY06Q>:@1YCbX0K50[06i@;01aD2d0Le4^07AB;`80Ldl[00<0
M54[07EB:P1fDbT00P1hERT0201iEbX0NUPZ07aG:P1mF2/0OUT/081K;P21G2l0Peha0P24Gc801025
Gc80QV0c08QR=@29HcH308YT=`0608US=P2:I3D0RV@e08]U=P2<ISL0SFLh0P2>J3T0102?JCX0SVPi
08iX>@2>J3T308eW>080S6Hg0P2>J3T0102=IcP0S6Hg08aV=`2;ICH208YT=@80S68`00`0SF<a08mU
<`2@IS@0TFLe099X=P2CJCL0S6Lb08aW<`2;IS80RfDd08]U=P2:I3L208YS>0P0RVDh00<0Qf8e08QS
=P29I3L00P2:ICP02`29I3L0R6<f08MR=@27HCX0QV4g08EP=P24Gc<0Q5lb08IR<P28I380RFDc0080
QF@a00<0QF<c08AR=024HSD00P23H3H01P23H3P0Qf0e08MP=@26H3<0QV0a08IP;`80QF0/00<0QF0[
089P<P22H3801P21Gc401024HCL0Pf0f085N=01oG38207iK<@0307mL<P20GC<0OU/a00L0OU/a00P0
O5HW07iH:@1oFRd0OU`_07eL<@1jFS40MeL`07=F;P@0NET`00@0N5P_07MG;P1gEbh0MUH]0`1eEB`2
07AD:`<0Le<Z0P1bES40101`E2l0KU8]06a@:`1ZCRT206U=:00306Q<9`1SBbL0Hd/W00H0Hd/W00H0
FdPX05Y79`1JAbL0FDHV05Q59@1GA2@205I38`080592801C@b40EDDT05E49P1D@bL0D3lU04dl8P1;
>B4404Pn8`@0AcdR00P0B3XO04Hj8015>Al0A3XQ044i8P10>R@0?cXV03hi9@80?c@P0P0n<al203db
7P80?34M0P0h<b001P0g<Ql0=S4N03@_700b;AX0<B`I030[6080:b/Q0P0Z:R00100Y:Al0:2PN02LW
7@0W9ad202LY7P<09RPM0`0U9a`3028U70808B@K0`0P8aX8024T7@8092LN0P0S9Qd2028U70808B@K
0P0S91h6028S7@80824I00@08B8J02<T700T9Ad09RLO0P0W:2001P0T9Ad09BDM02HV700W9ad0:RPL
02/Y7080;2XK00P0;b/P02l[7`0`;200<BhO038_7P0c<1d0<c4L03@b7@80=C8O1P0d<Ah01P0i=1h0
>3<O03Ha7@0c;Q/0<B/K02lY6`80;BLK0P0X:A/01@0Y:Q`0:R/M02X[7@0Z:ad0:b`N0080:R/M200[
;1h202TY7`<0:2PN0`0W9ad202X[6`0902TZ700W9a/09RHL02DU7@0T8ah08b8M02DV7P0T9Ad08b@L
00<08B8J0P0R8a/00`0T9Ad08b@L028S6`02024R6P09028S6`0T9Ad09BHN02XX700/:1`0;BTM034[
7@0d;Ad0=RdL0080>RlM01@0?34K03hc7@10=1`0ACLM04Ti7`1<>al0CSdQ054n801KAbH0G4PW05m;
:01RCRT0IE8Z06QE;@1ZEbd0JeP^07EO9@1hHRT0OFL^089/<`80Q6dg01/0Pf`f085Z=028Ic`0QfLn
08AW?`1nHS/0M5Xe06M?;@1KA2@0DclN04X_9015;B40?b/P03PZ7`0c:b00;bdQ02d_8P0/<RH0;BhX
02d`:@0^<BX0;C8[02hd:P0]=BX0;SH[02hf:@0h=B800`0g=240100h=B80>SLT03`i9P0n>bP2040k
9`0;048l9P14?RH0ASlU04Y09@1<@2H0CD8V05Q89`1IBBP0FTXY05];:P1LC2/00`1MCB`0201WE3<0
IU<b06AA<01SD2l0I54`06IC<P1XEC@0JEHe0P1WE2`206QE;@0406UF;P1ZEbl0JeP`06]H<0P0JeP^
00<0KeP_06iG;P1/EB`00`1ZDbX01P1[E2/0K5D/06YC:P1ZDbX0K5D/06mH;`80LEXa00<0L5T`06iG
;P1/EB`00P1bERl03P1`Ebl0KUL^06aF;@1ZEbd0JEH/06QG;01^Ebd0L5T_075J<01^Ebd0JE8X06M@
9P1ZDbT0KUL]0`1XEBd00`1WE2`0IU<[06IC:`0206EB:P06065?9`1PCRP0GddW05i<9P1KBbL0FDTU
0P1HB2@01@1JBRT0FDXY05Q9:01HBBP0EdXX00<0ETTW00h0FTXY05U9:01HB2L0F4PW05U9:01LC2/0
Gdl^065A<01LCB`0Fd`[05Y;:P1IBRT0F4TX05I79P80EDHU00d0ETHT05M79@1IBBL0FTXX05e=:`1O
Cbd0H50^065A;`1UDbd0I58/06=A:`1RD2X0HDlY0080H4hX00@0GddW05Y88P1KBB<0FdTS0P1LBR@3
05e;9@0805i<901QCbL0I58Z069@:01OCBD0GT`T061>9P1TDRX205e=:@0405a<:01KBbL0Fd/W05Y:
9P80FDTU01P0FT/Z05U::@1HBBP0EdPW05E69@1DAB@0Dd@S05938P1EARD0E4DT05=48`1B@b80Dd@S
05A5901GB2L0F4TX05M38P1F@b80Dd<R05918`1@@B@0Cd4V04a19@1<@2H20553:00604i39`1<@bH0
BD8U04M29016@B<0A44R0`0n?B4203dl80<0?3/O00<0=CLO03Hh800g>B400P0h>R800`0f>200=3HN
03<e7@09038d7P<0<CDN0P0`=1d302lc70P0<38M0`0/;ah302/^7@80:RdL0P0Z;1h0100Y:ad0:2XL
02LY6`0V:1X202DW6@808bHK0P0R9AX4024T6@807b8K0`0N8AX301dP6@<06AlK0P0H7QX301LM6@80
5adK0P0F71X201DK6A8051XH600G6AP801HH5`P05QLI200E5QP801HG6@P05QPG2@0E5QPH01HG6@P0
5AHH200F5aT801HH5`P05QLI400E5QP8018H600801TK6P0F61L04aDD014C4P0B51<05QPG01/M700O
8B0801HH5a005AHH600F5aTA01HH5a005QLI400G6AP801TK6PP05aTH200I6aX801XL6`<06Q`I0`0K
7AX201`N6aP071`J800K7AX801`L6P<06Q`I0P0K7AX301`N6`/07AdK0P0N7Q`201lO7@80820N200Q
8Q`0100P81P08B4I024Q6@0Q8AT2028R6P808b<K0P0/9Ad302dV7P<0;RLO00@0:R@H02/U6@0/9QX0
;2HJ0P0^:1`0100_:Ad0<2XN030Z7P0`:Qh3034[7`<0<R`P00H0<B/M038Z7@0c:ah0=2XN03L[7`0h
:Ql203/Z80P0>2`P0P0h:Qd0100g:ad0=B`M03@]7@0c;Ad2034^7@P0<bTM0`0b;203034[7`80<2XN
00H0=bXQ03@Z800c:Al0<BTN02lY7@0[9a/202TW6P0302`X7`0[9ah0:RHM0080:2@K00<0:RHM02/W
7P0/:1l0200Z9Al:02DU7@8092@L0P0S8a/2028R6P808b<K0P0T91`0100U9Ad09RHN02HV7P0V9Qh8
02XV7@80;bTM1@0^:1`202lY7@H0<BTN0P0b:Ql202`X7`80:bLN0P0Z9Qd202TU70P0:RHM100`:Qh4
034[7`D0;2PO00H0:bLN02XV7@0Z9Qd0:2@K02TU700[9ah202`X7`0402/W7P0Z9Qd0:BDL02TV7@<0
:2DL0P0W91/202HS6P<0:RHM0P0Y9A`302PT6`<092@L0`0U9Ad202HV7P<08R<M0`0Q8Q`5020Q6`80
8B8L0`0R8ad01P0S8aT092@J02@T6P0U9A/09RHL02LW7@80:2PN0P0Z9QX202/W6`80;2PL0P0]:Ad2
038X7`0A03<Y7`0d:Qh0=B`M03H]700g;Qd0=blL03Td800g<Ql0=2lL038/700`:Q`0;bTM02lX7P0`
:Al0=2/L03D/7@0f;Ah00P0h;b000`0f;Ah0=B`M03@[700203PZ7@0403L[7@0e;1d0=2dM03@]7@80
<bdM00<0;RXN02dY7@0[9a/00P0[9a/00`0/:1`0;RXN02l[7`0202l/6`0302h[700^:Qh0;RXO00<0
;BTP00<0;BPR02hZ7P0]:Ad00P0]:Ad202`X7080:bLK200V9Qh602LW7@80:2PN600]:Ad0200_:b80
;RXQ02dY800/:1l0:bLN02XV7@0Y9A`0:2@K200U9Qh8030/80<0<bdO:oooool002[ooooo402SNTH2
0:AjBP040:EkB@2UO4P0YWe90:ImA`80Ygi6102XOT`00`2WOD/0YWa:0:AjB0090:AjB0060:=jAP2T
NdL0YGa80:ImB@2WOTX0ZH1<0P2ZPDd00`2ZP4h0Z7i<0:IlBP020:EkB@030:MmB`2ZP4h0[89@00P0
Z7i<0P2XP4D0102XOdL0Z7m90:QoB`2XOT`20:MmC@030:^2CP2ZPDd0ZH1<00<0Z7m;00<0ZH1<0:Z1
C@2[PTh01P2YP4X20:Z1B`P0ZH1<00<0ZGi;0:YoC02ZOd`00P2ZOd`30:^0C@030:b3C`2]Q500[HA@
00<0[XEA0P2]Q5020:Z1C@80Zh9>00@0[8=?0:f4D02]Q500[HA@0P2]Q4h00`2]Q500[H=A0:f3D`02
0:f2E@030:f2E`2YQ500ZHA@00@0ZHA@0P2XPdl20:^2CP80ZX5=102YP4`20:AoB`040:=nBP2RODT0
XGa80:1kA`80WgY600<0VgI209ag@`2MN4@00P2MN4@00`2KMT80VGA009Qc?`0209Y_@P0409U^@@2G
K3l0UV/n09AY?080TfPk00H0U6Lm09=X?@2BIc`0T6Lk08eW>P2;IST208QV>00808IQ=027HSD0RF@g
08]V>@2:ICP0R6<f08EP<`23GS4208=Q<`04089P<P21Gc40P5h`07mM;`80OU`^00h0Ned[07YL:P1i
FR/0MePZ07EF:P1cDbX0LU8[075A:P1hDC00ME4_07A@;P1bD2d0L4l/06e?:`80JdlZ00@0LU@`071B
;P1]Cb/0JddY0`1ZC2P01`1[CBT0IdlY06Q>:@1YCbX0JdlZ06e?:`1`Cb`00P1bD2d01@1aCBT0LThZ
07=@:P1eDRX0MU<Y0080MeDX00P0N5HY07QF:01lEbX0O5LZ07eH:`1nFB`0P5/^085L;`80PUd`00@0
Ped`08EO<P27HC@0RV@g0P2;ICP208US=P0608US=02:I3D0RV@e08]U=P2<ISL0SFLh1@2>J3T308eW
>080S6Hg0P2>J3T0102=IcP0S6Hg08aV=`2;ICH208YT=@0608YR;`2;Hc00S6@a08eU<P2>IS<0T6Pe
0P2AJCH01P2<Ic80S6Lc08]V<P2;IC@0RfDf08YT=`80RV<h202:ICP00`27HSD0R6<f08UT=`0208YU
>00;08UT=`28HcH0Qf8e08MQ>P26HCL0QF0f08AO<`24Gc80QV8b08QT<P29IC<00P25I3400`25Hc<0
Q68d08AR=@0208=P=P0608=P>027H3D0Qf0e08IP<`26H340QV0_0P25H2`00`25H2/0PEla085O<@06
089P<P0408ER>023H3H0PEhd07mL<P80OU/a0P1oG38807iK<@0907eG:01nF2T0OeX]07mM<01mG340
NUXa07MG<01cERh0NUXa0080NET`00<0N5P_07MG;P1gEbh00P1gEbh207IF;@80MED/0P1dE2/207=C
:P0607=E;`1bE2h0LE<]071B;01^D2X0K4hX0P1[CBL00`1ZC2H0I4`X06=;9`0506=;9`07069:9P1L
BBP0FdPW05]89`1JAbH0FDHU05Q5900205M48`0805=38@1DA280ETHU05I59`1D@bL0DD0V04hm8`1<
>R8804Pn8`0604Xk7P18>Ql0B3XO04Hj8014>R40@SXS0P10>R@303ld8080?S<O0`0m<Qh01@0i=240
>3<P03Lb7`0e<1d0=2lL0080<bhK00D0<RdJ02`/800/;200:b/O02XZ7P0202TY7@80:2PL0`0W:Ah3
02HX7@809BLL0P0S9Qd2028U70808B@K0P0P8aX4028U7P@08B@M0P0T9ah202<V7@808RDL0P0Q91/6
028S7@808b@N01P0824I024R6P0R8a/08b@L02@U7@0U9Qh09RLO02LX800V8ah09b@O02LT7@0X9A`0
9bLK02PX700X:A/0:2XL02`Y800/:Qh0;B/O02h/7`0_;Ah0<2lM030_6`0a<1`203<`7@H0=34N00P0
>cDM03Xd7P0i<Ql0=c0M03D^700c;1`0<BTL030X6`D0:BXL0P0Z:ad:02//7P80:RXN0P0Y:Ad402PX
700602//700Z:a/0:BXL02PX700W9ad09BDM0P0T8ah00`0V9al09BHN02<T7002024R6P06028S6`0T
9Ad09BHN02DV7P0T9Ad08R<K0P0Q8QX0100R8a/08b@L02@U7@0W9ad202XX700]02`X700`:Q`0<R/K
03<Z6@0d:aX0>C8P03Xc8@0l=240@3DQ04<g8@17>240BCXS04Xj8@1>?B40CchR05508P1DA2<0EdLU
05];9`1MCBT0Ge0Y06]F8@1^FB@0LehY07MR:`1iI2d0NVD^07UT;@1hHbX0QVHe08UY>P2<KCh0SVm1
08Q/?@21I3P0Me`_075F:@1UA340HD8^05Ll:@1<=b@0@S<P03Xb7`0f<Ah0<c8N0080<BdR00P0<BlS
030`900`<bP0;cDY030h:`0a>B`0>3DT03Ld8`80=S<R00@0=c@S03Pe900j=bH0?3TX0P0k>2L01P0n
>BH0@CXW04<k9P14?2D0Ac`V04Pn9@80DT@W0P1CABP01@1DART0EDLZ05I8:`1GBB`0Ge0a0080GTl`
00H0GDh_05i?<01OD340H54b065B<`1QCb/2069@;00306=A;@1TDRh0IE<_0080IU@`0`1UDbd02P1V
E2h0IeD_06QF<01XES00JELa06eJ<P1/FC40JUL_06QE;@1VDb/206MD;00506QE;@1VDRd0IU8]06QD
;`1[Ec800P1]FC@00`1/F3<0JUHa06QD;`0206UA;@0306QB;@1VDRd0I58/0080HU</00T0HE</06IB
;@1XE2l0Ie<^06=?:P1NBRD0GDTT061<9`1TD2/00P1NCRX305e=:@<0G4`X0P1HBBP205M89`80EdLU
00<0ETHT05I68P1FBBL00`1FBBL305Q9:00705U9:01GAbH0FDTX05];:P1NCRd0H50_05m?;P0205i>
;@80GDl/00H0G4h[05Y<:@1IBbP0F4XW05M99P1FB2D205a<:00405e=:@1OCb/0H50/069B;P80He<_
0P1NC2H0101MBbD0G4XT05a:901KBB<205Y88P80FDLQ00@0FTPR05]98`1MBbD0GT`V0P1OCBL02@1O
CBD0HU0X06AB:P1SDBT0GddU05e;8`1PCRH0He4Y05e=:@0205a<:00505];9`1IBBD0F4PT05Q8901G
Ab<00P1HBBP0201GB2L0ETLV05E69@1DAB@0Dd@S05938P1EARD0E4DT0`1CA2<02`1DAB@0ETLV05M8
9`1E@R40Dd<Q05928@1@@B80CT0S04]09019@2<0BClT0080Cd4V00<0C44U04]29@18@B@00P16@B<0
0`14@B80?SdQ03hm8@0203dl8080?3/O0P0k>Qh00`0e=al0=SPP03Li8@0203Pj8P0303Hh800d=Qh0
<cDM00T0<S@N0`0a=Ah2030d7@<0;c<L200`<Qd202`_7P<0:bhM0`0Z;A`202T[7@0402PZ700W:A/0
9bTK02HX6P809BLI0P0R9A`3024T6`<082<J0`0N8AX301dP6@8071lH0`0I7a/201PN6P<05adI0P0G
7A/201HL6P805A/I4P0D6QPH01LI60P05QPG200F5aT801DF60P05QLI200F61L901DF61P05QLI200E
5QP801HG6@P05QPG200F5aT@01DF60P04QPH0`0E5aH01@0D5QD04aDD014C4P0>40l03@l>00P05QPG
400E5QPH01HG6A405QPG400F5aT@01LI60P06A/J200G6AP801TK6PP06Q`K0P0J71T301/M6P<071hK
600L71XP01/M6PP071`J0`0J71T201/M6P<071hK2`0M7A/201hN70807alM0P0P81h8024R7080820H
0`0Q8AT3028R6P80;2DM0`0]9Qh302hW7`<0;2HJ00<0;BLK02hX700_:Ad00P0_:Ad3030Z7P<0<B/O
0P0b;2001P0a:ad0<RXM03<[7P0d:Qh0=RXN03LY7P80>RTO200g:al203LY7P0403HZ7P0d:Qh0<b/N
038/7P80<2dN200b:Qd2038/80<0<B/O0`0`:Qh02`0e:200<bTP038X7`0_9Qd0;BHL02XV6`0X9QX0
9bDI02`X7`0Z9Qd0:BDL0080:2@K00<0:BDL02XV7@0/:1l0200Z9Al:02@T70@08b<K0P0R8QX00`0S
8a/092@L02@T700202@T70<09BDM200Z9Qd202hX70D0;bTM0P0^:1`3030Y7`D0;bPN100Y9Qd402PU
70P0:RHM200`:Qh0100/:B00:bPO02/X7`0Z9ah402TV7@0802PT6`0Y9A`0:bLN02`X7`0[9ah0:RHM
02TU700X91/302HV70809BDK0`0T91X202XV7@80:BDL0P0X91/202LS6P808b<K0`0T91`302DU7@80
8R<M0`0Q8Q`6020Q6`808B8L0`0R8ad01P0S8aT092@J02@T6P0U9A/09RHL02LW7@80:2PN0`0Y9aX2
02XX6`<0:bTL0P0b:1l0300c:Al0=2XN03@[700e;1/0=RdL03H^6`0h<al0=c8O03@_700a:a/0;bTK
02lY7@80;bPN00<0<bTM03D[7`0f;2000P0g;B400`0f;200=B/O03<Y7@0203HZ7P80=2XN00`0<RXM
034[7@0_;1d0;b`M02`X700[9a/0:RHJ02TU6@0Z9QX0;2PL02dY7@0_:al202l/6`0302h[700^:Qh0
;RXO00<0;BTP00<0;BPR02dY7@0/:1`00P0/:1`202/W6`80:RHJ200V9Qh602LW7@809RHL200]:Ad8
02`X70P0:bTL0P0]:R40100/:B00:bPO02TV7@0X9A`202LT6`P09BHN200_:al3038/7R_ooooo000Z
ooooo`P0XgU70`2RNDD20:=jAP<0Y7]70P2TNTX0102UNdT0YGa80:ImB@2VODL20:MnAP030:UoC@2X
OT`0YWa:0080Y7Y800<0YG]90:IlBP2WOD/0202UNdT20:ElB080YWe900D0Ygi:0:QoB`2YP4`0ZH1<
0:QnC0040:MmB`030:QnC02ZP4h0ZX1>00<0Yge;0P2XOT`30:UoC@060:R0@`2XP4D0Z8150:QoA`2W
OTP0Ygi:0P2VO4X00`2ZPDd0ZH1<0:V0C0050:V0C0030:Z1C@2XOdT0Z7m900<0ZH1:0`2ZPD/80:V0
C0P0ZWm<00<0ZH1<0:Z1C@2/Pdl00`2]Q5020:b3C`060:V0C02ZPDd0ZX5=0:^2CP2/Pdl0[HA@0P2^
QE420:f4CP030:f4D02]Pe40[H=C0080[H9E00<0[H9G0:Z5D@2ZQE400`2YQ5030:R3C`80[8=?0P2[
PTh30:Z1C@050:V0C02TOd/0Y7m;0:=nBP2RODT00P2QO4P20:1kA`0809ag@`2MN4@0WWU509iiA@2M
N4@0VgI209Ud@02HLcl209Y_@P0409U^@@2GK3l0UV/n09AY?080TfPk00H0U6Lm09=X?@2BIc`0T6Lk
08eW>P2<IcX208UW>@80R6@d0`29ICD00`28I3@0QV8b08EQ<@0208=Q<`04089P<P21Gc40P5h`081N
<080Oed_0P1jG2X0301iFR/0N5T[07IG:`1eEB`0M5@]07=C;01iDS40MU8`07EA;`1cDBh0L4l/06e?
:`80JdlZ00H0LE<_06mA;@1]Cb/0JddY06Y<:01[CBT206a>:P0606M?:@1XCRT0J4hY06]?:P1/CRX0
Kdh[0P1`CR/01@1`C2P0LThZ07AA:`1fDb/0Me@Z00<0N5HY00L0N5HX07]F:@1lEbX0O5LZ07eH:`1n
FB`0OeX]0080P5/^00@0PE/^08=M<027HC@0RV@g0P2;ICP01`29HcH0R68e08US=029Hc@0RV@e08]U
=P2<ISL00P2=IcP408iX>@<0SFLh0P2<ISL308eW>080S6Hg0`2;ICH208UT<00308YU<@2;IS80S6Lc
00<0SFPd00H0S6Lb08aW<`2;IS80RfDd08]U=P2:I3L208YS>0P0RVDh00<0Qf8e08QS=P29I3L00P2:
ICP02`29I3L0R6<f08MR=@27HCX0QV4g08EP=P24Gc<0Q5lb08IR<P28I380RFDc0080QF@a00<0QF<c
08AR=024HSD00P23H3H01P23H3P0Qf0e08MP=@26H3<0QV0a08IP;`80QF0/00<0QF0[085O<@21Gc40
0`22H38308=Q<`0408AQ=`23H3H0PEhd07mL<P80OU/a00<0Oe`b081M<`1nFc401`1nFc4207mI:P06
07mJ;@1mFbh0O5/`07YJ<@1hF340MEP`0P1jFS400`1hF2l0MeL^07IF;@0207MG;P0407QH;`1fERd0
MUH]07IF;@80MED/0`1dE2/207=C;080LU8[00<0LE4Z071@:@1_CbP00P1_CbP0101VCRX0IDdY06A<
:01TC2P2069:9P0306599@1PB2@0GD/W0080G4XV00<0FdTU05Y8901IAb<00P1HAR8205I6900705I6
9@1EA2H0E4<W05919`1@?bD0CS`T04Lm8P0304Pn8`<0BClT00L0BT0U04`k7@1:>ah0BS/N04Tk8016
>R00AC/R0080@SXS00@0@3DQ03ld800o=200?c@P0P0n<al203db7P0403Xe8P0i=240=c8O03D`7@<0
=2lL00H0=C0M02d^800];R00;2dO02//7P0Z:ad202TZ700302PY6`0X:Ql0:2XO00809bTN0`0V:1d0
100U9a`08bHM02<V7@0S9Qd2028U70<08B@K0`0S9Ql2028U7P<08B@M0P0T9ah202<V7@808RDL0P0Q
91/2024R70<08R<M0`0S91h0100R8a/08b@L02<T700S91`302@U7@0?02DV7P0Y8Al0:B4O02PS7`0W
91d09RHL02DW6P0U:A/09BTJ02PX800X:1h0:BTO02XZ7P0[;1h0;2dM0080;BhL0P0b;a`203<`7@@0
=34N00`0>S8K03/c700k<ah0>S8O03Ta7P0g;Qd0=B`M03<Z6`0/;Al0:b`N02X[7@0Y:Q`202PY6`<0
:BXL200Z:ad202//7P80:R/M0`0Y:Q`01`0X:A/0:R/K02X[6`0Y:Q`0:2PL02LW7@0V9Qh00P0V9B00
2`0W:2009RLO02<T700R8a/08b@L02DV7P0X:B40:R/S02LX800V9al092DM00808R<K00T08b@L02@U
7@0U9Qh09RLO02LW7@0X:1h0:RPL02`X700^:1X00P0`:AT0200d<2@0=C8S03Pb900j<b<0?C@S040e
8`12=B80@cHS0P17=b003018>1l0BSXP04dn8@1@@B80Dd@S05E69@1PBR40HdhS06QC:01]F2/0LUd^
07EQ;`80MV8_02P0OfDd081V=@21IcH0PVPe08AZ=`25JcP0QV`i08M]>P24IT@0Of4o07EK>P1[DS<0
GTTZ05A48`1=?Ql0BC/N044`700o<1d0?2lL03Ta7P0g<Ql0=C@R03@e9@0d=bH0>CHW03Pe9P0g=2D0
=S<T03Ld9@0h=BH0>SLX03/h:@0i=bX0>CLX03/h:@0n>2P0@3TW048j9`12>RD0ACXV101:@2D01@1;
@BH0C48W04i4:@1?ABX0ET/_00<0EDX^00D0ET/_05M<<01GC300F4da05Y::@0205];:P0305a<:`1M
CB`0GTh]0080Gdl^00`0GDdY05i>:P1OCb/0H50/065A;@1RDRh0He<_06AD<01XFC80IePa06AE;P1S
E2d2069C;00306=D;@1TEBh0HU8^0080HU8^00H0He<_06AD<01TE300He<_069B;P1QDBd2061<:@04
05m=:@1LC2P0G4`X05]=:080FThX00P0GDd/05i>;@1MCB`0FDTX05A48`1C@b80F4PW05a<:`L0EdPY
00L0ETLX0516:`1@AbX0DTL[05A6:@1EARL0ETHU0080FDHU0P1BBRH0101DBRL0EdXX05Q9:01JBRT2
05e::P0805Q89`1JBRT0GTh]065A<01RDS40HE4`05i>;@1LC2/205i@:`0405e?:P1LCRT0G4hY05]=
:080FT`W0P1QDR/6061A:PD0F4HP0`1IAb4205Y88P0405]98`1LBR@0GT`V05m=9`80H4hX00h0GT`T
065?9`1SDBT0HU0X05i<901LBR80GT`T065?9`1MCBT0G4`X05];9`1JBRH0F4PT05M78`80ETHR101E
ARD205A59080Dd@S0P1EARD405A59080EDHU00P0Dd<Q0553801A@R40Cd8R04a18`1:@B@0Ad0S04M0
9080CClT00H0BSlS04U08`16?b80AD0R04@o8@13@24303dl8080?3/O0`0k>Qh00`0e=al0=SPP03Li
8@0203Pj8P0303Hh800d=Qh0<cDM00T0<S@N0`0a=Ah2030d7@<0;c<L200`<Qd0100/;ah0:bhM02/^
7@0[;Qd202X]7080:B`K0P0Y:ad00`0X:Q`09bTK02HX6P0202DW6@0402@V600Q91d08B@M024T7@80
82<L0`0O8Q/301hQ6P807B0I0`0L7aP301TO6`8061hJ0`0G7AT201LM6`805Q`J0P0E6aTB01@J61P0
5aTH200F61L801HG6A005AHH200E5aH901DF61P05QLI200E5QP801HG6@P05QPG200F5aT@01DF60P0
4QPH00<04A<B01<E500G6AP00P0J71/00`0G6AP051HE014C4P0801HH5a005AHH600F5aTA01HH5a00
5QLI400G6AP801TK6PP05aTH200I6aX801XL6`0401XL6@0K7AX06adJ01/M6P8071hK0P0M7a`@01`L
6PP06a/I0`0J71T201/M6P<071hK200K7AX@01XL6@P071`J0`0J71T201/M6P<071hK2`0M7A/201hN
70807alM0P0P81h8024R70<08B4I0P0R8QX302<S6`80;2DM0`0]9Qh302hW7`P0;RPL0P0_:Ad2030Z
7P<0<B/O00L0<R`P034[7@0b:Qd0<RXM03@Z7P0f:Qh0=bTN0080>BPN0`0g:al303HZ7P80=BTM0P0f
:1l0100e:1l0<bTO038Z7`0a:al202l[7`P0<2XL00@0<R`P034[7`0a:al0<B/O0P0`:Qh202lY7@0;
03<V800`9Al0<2DO02hU7P0/9Ad0:BDL02PU700W91/0:bLN02XV7@0Y9A`00P0X91/00`0Y9A`0:RHM
02/W7P0802TT7Pd08b<K0`0R8QX802@T70P0:RHM00<0;BLK02hX700_:Ad00P0`:Qh202lY7@0302hX
700]9a/0;BTP00<0;BTP0P0/:1l202/W7PL09RHL00<09BDK02TU700Y9A`01P0Y9A`0100`:Qh0;bTM
02lY7@0_:Ad302hX700502dW6`0Z:R00:BTO02PX7P0W9ad00P0V9Q`0100W9ad0:2PN02TU700Y9A`3
02/W7P0302TU700X91/09R8I00809RPM0P0U9a`302@V6`0402<U6P0Y9A`0:BDL02TU7080:2@K0`0W
8aX302<S6`8092@L0`0U9Ad0100R8ad08B8L024R700Q8Q`2020Q6`807b0J0`0P8A/2024R70<08R<M
00H08b<I02@T6P0T91X09BDK02HV700W9ad202PX7P0402HW6@0W:1X09bPJ02LX6P80:2TK0P0Y:Q`2
038X7`0A03<Y7`0c:Ad0=2/L03@[6P0e;1/0=BdJ03Lb7P0e<1d0<bhK030Z6P0_:A/0;bTM02lX7P0`
:Al0<bTO03@Z800f;2800P0g;B<0100f;280=2XP03<Y7`0e:1l203<Y7`03034Y7P0`:Qh0;RXN0080
;2XM00<0;BTM02`X700Z9QX00P0Z9QX00`0[9a/0;BTM02hZ7P0202l/6`0302h[700^:Qh0;RXO00<0
;BTP00<0;BPR02dY7@0]:Ad00P0/:1`302/W6`0302XV6P0U9Ad09BDM00H09BDM100W9ad202HV7080
9BDK200]:Ad802`X70P0:BXL00D0:RXP02TY7`0Y:Al0:2PN02LW7@0202HV700302DU6`0U9Qh09BHN
00H09BHN00<0;2PL02dY7@0]:Ad00P0^:Qh302l[7`<0<R`N:oooool002[ooooo202SNDT00`2QN4@0
XWU50:9iA@020:=jAP80Y7]700L0YGa80:AjBP2TNTX0YG]90:ElB02VODT0YWe70080Ygi600<0ZX1>
0:MmB`2SNDL00P2QMdD00`2TNTP0ZGm=0:b2D0080:MmB`030:ImB@2WOTX0Ygi:00D0Ygi:0P2VO4X0
0`2XOT`0ZGm=0:UoC@020:UoC@040:QnC02VO4X0Yge;0:MmB`80Z7i<0P2YOdd02@2ZP4h0ZH540:R0
@`2XP4D0Ygm40:MnAP2VODL0YWe90:ElB0090:V0C0<0Z7m900<0ZH1:0:Z1B`2ZPD/00P2[PT`80:V0
C080Zh1=1P2ZOd`00`2VODT0Z7m;0:Z1C@030:b3C`0:0:^2CP2ZPDd0ZH1<0:V0C02ZPDd0Zh9>0:b3
C`2]Q500[XEA0:n6DP80[HA>00<0[HA@0:f3D@2]Pe<00P2]PUD01@2]PUL0ZXEA0:Z5D@2ZQE40ZHA@
0080Z8=?0P2WPTh0102]Q500[8=?0:b3C`2/Pdl20:^2CP80ZX5=00H0YH1<0:AoB`2TOd/0Xgi:0:9m
B@2QO4P20:1kA`0809ehA02NNDD0WWU509iiA@2MN4@0VgI209Ud@02GLSh209Y_@P0409U^@@2GK3l0
UV/n09AY?080TfPk00H0UFPn09=X?@2CJ3d0TFPl08iX>`2<IcX208UW>@0308]W=@2:IS@0R6@b00<0
Qf<a0P28I3801P24HS@0Pf4c08=Q<`22H380PEla081N<080Oed_0P1iFbT0101hFBX0N5T[07MH;01g
Ebh207IF;`0;07YC<P1gDc40MU8`07=A;P1aD2d0KDl[06]?:P1ZCRT0Ke4]06i@;01/CRX00P1[CBT0
101/CRX0KU0/06mA;@1VCRP206Q>:@0306Y>:@1[CBT0KTdZ0080KddZ00D0LDdY079>:P1eDR`0Me@/
07UF;00207UG:P0407QF:@1hERP0NeHY07]F:@80O5LZ00`0OEP[07iI;01nFB`0OeX]07mI;022G2l0
QV0c08YT=`2<IST0RfDh08US=P28HSD208US=080RV@e00@0RfDf08aV=`2=IcP0SFLh0`2>J3T308eW
>080S6Hg0`2;ICH208aV=`<0SFLh202;IS801P2<Ic80S6Lc08]V<P2;IC@0RfDf08YT=`80RV<h202:
ICP00`27HSD0R6<f08UT=`0208YU>00;08UT=`28HcH0Qf8e08MQ>P26HCL0QF0f08AO<`24Gc80QV8b
08QT<P29IC<00P25I3400`25Hc<0Q68d08AR=@0208=P=P0608=P>027H3D0Qf0e08IP<`26H340QV0_
0P25H2`00`25H2/0PEla085O<@02089P<P80Pf4c0P24HS@02023H3H0PUle081M<`1oG380OU/a07mL
<P20GC<0PEhd201oG3802`22G2d0PE//07iI;01kFB`0NUT^07UI<01jFS<0N5/c07]K<P1jFS40N5P_
0080MUH]00<0MeL^07QH;`1iFC00101fERd207EE;080M5@[0`1bD2X607=A:`0806Q@;01WCb/0IThZ
06A<:01RBRH0H4PT05m78`1NAR8205e;9`0305a:9P1KBBD0FTPT0080FDLS00H0F4HR05U99`1GAbD0
EDDT05=2901B@BD205509P03054o9`17?B80AcdR0080B3hS00@0BClT04Y09@1:@2D0BT0U0P1<>ad0
1P1;?1l0BC/P04Lk8@16>R80AC/R04Dj9080@3DQ0`0o=20303hc7`0803/f8`0i=240=c8O03D`7@0d
;a`0=C0M03Ha7P0g<Ql202h_7`0302d^7P0/;Ad0:b`L0080:R/K00@0:BXJ02PZ7`0X:Ql0:2XO0P0W
:Ah302HX7@@08bHM0P0R9A`2024T6`8092LP0P0S9Ql0100R9Ah08B@M024T7@0Q91d202@W7P808bHM
0P0R9A`2024T6`<08B8L00<08R<M02<T7P0S91h00P0T9Al202DV7P8092DM0P0S91`2028S6`80:R0Q
00H0:B4O02LT7`0U9Ad08bHK028X700R:1X202LW7`0302PX7P0Y:Ad0:R/M0080:b`L00@0;2dK034^
6`0b;a`0<RlL0P0c<1d203@a7P0=03Db7`0i<QP0>S<I03/c700l=1l0>c<P03Xa800h;ah0=bhO02l`
8P0];R00:b`N02PY6`0302LX6P80:2TK200Y:Q`0100/;Ad0:b`L02//700[;1`202X[6`80:BXJ0P0X
:AT0100X:A/0:2PL02PX7P0X:20202PW8P0?02PY8@0V9al092DM02<T700U9Qh0:2TQ02`]9@0_<2P0
:BXR02PY8@0V9al092DM02<T700T9Ad09BHN00<09RLO00h0:2PN02XX700[9a/0:bPI02dW6@0]9aL0
;b`S030^8P0a;B80=2hR03L_8P0i<240>C0O03``8080@C@Q02T0@3@N044e7@13=ad0AS/O04Tn8P1;
@280ET4T05U49@1MBBP0HTh[06IC:`1YER`0JUL/06]I:`1_GBd0L5h/07=O;@1eHBh0NF<a07aW<P20
JCD0PV/g08M]>P25JcP0PfTh07mT=@1hH380Le/_06mF;@1/DbX0HTDW05e29@1G?b<0D3`Q04Pj8013
>B00?cTQ03hi8`0j=bP0>CHW03Pe9P0203Ld9@0<03Tf9`0j=bP0?3TZ03Hf:P0g=b/0>CLZ03/h:@0n
>2P0?cPV040i9`11>BH0A3dS0P13?2801@12>b40@c`R04Dn9018@BL0BD8X0080CT@Y0P1?ABX20516
:`80DDL/0P1EARL0101FAbP0EdPY05M8:@1HBBX205U::`0;05M89`1HBBP0FDXY05]<:`1LCB`0GTl^
05m@;`1PDC00HE<^05mA;01ND2/00P1LCRT00`1MCbX0GU0[05mA;00205i?;P0305e>;@1KC2/0FT/Z
00@0FDXY0P1IARH02P1GAbH0ETLV05E89P1CBBH0E4XW05=;9`1GB2/0F4T/05M8:`1B@bH204ho8P03
05=49`1HBB`0D4DY00@0D4DY0`1AARX0201<ARh0CDD^0516;@1BAb/0ETLZ05Q89`1JAbH0G4PW0P1@
BRH0101CBbL0F4/Y05Y;:P1NBb/2061;;003061@;`1OCbh0GTh]0080GTh]0P1OCbh00`1PD2l0Ge4/
05mA;00305mA;0<0GU0[00P0HU<Z065B:@1PDBP0GTlV05a=901JBb80F4TP05M87`80EdDO00<0F4HP
05U78@1JB2800P1KBB<205a:9080GD/U01H0GT`V05m=9`1PCRP0H4hX065?:@1MBb<0H4hV069@:01P
CRH0G4XR05Y8801LBR80GddU05e=:@1LC2P0Fd/W05U99@1HB2@0ETHR05E58@1DA200DT<R0`1CA2<2
05A590L0EDHU0`1DAB@205948@0305138@1=@R80Bd8S0080B44T00H0AT4T04Xl8@1:?240B3dQ04Hm
8014?B0204<n8003044n7`0m?200?C`P0080?3/O100k>Qh00`0e=al0=SPP03Li8@0203Pj8P0303Hh
800d=Qh0<cDM00T0<S@N0`0a=Ah2030d7@<0;c<L200`<Qd302/^7@80:RdL0`0Y;1/01P0Y:ad0:2XL
02PZ700W:A/09RPJ02DW6@8092HH0`0P8Qd201lQ70<07R0K00@07R4J01dP6@0M81T07B0I0P0L7aP2
01/N5`<06AlK0P0H7QX301LM6@805adK0P0F71X201DK6A8051XH600G6AP801HH5`P05QLI400E5QP8
01DG5PT05AHH600F5aT801DF60P05QLI200F61L801HG6A005AHH200B61P0100D5QD05ALF01LI600H
6QT201TK6P8061XI200F61L@01DF61P05QLI4@0F61L@01HG6A005aTH200I6aX801LI60P06A/J200J
71/301/M6P8071hK0`0M7a`@01`L6PP06a/I00<06A/H01XL6@0J71T00P0K7AX201`N6`0301dO700K
7AX06adJ00H06adJ400J71T801`L6P<06Q`I0P0K7AX301`N6`/07AdK0P0N7Q`201lO7@80820N200Q
8Q`3028R6P808b<K0`0T91`202`U7@<0;BHN0`0^9al01P0a:al0<2XN030Z7P0_:Ad0;RPL02dW6`80
;2HJ0`0_:Ad2030Z7P<0<B/O00H0<R`N03<[7P0b:Qd0<bTM03DY7@0f:1d203PW7@80=b/O0P0f:Qh2
03DY7@80=2PL0P0e9Ql0100d9al0<RPO034X7`0`:Al202hZ7`P0;R/L0`0a:al2030Z7P<0;bTM00H0
<2<M02hS7@0^8ad0;2<L02/T700Y9A`202PU700302/W7P0Z9Qd0:2@K00809b<J00<0:2@K02XV7@0[
9ah0200Y91h>028R6P808b<K100T91`402<S6`P0:RHM00<0;BLK02hX700_:Ad00P0`:Qh202lY7@03
02hX700]9a/0;2TP0080;2TP00<0:bPO02XW7P0Z9ah00P0Y9Qd802DU6`P0:2@K0`0^:1`00`0]9a/0
;2HJ02`V6P0202/U6@0:02XZ800Y:Al09bLM02HV700U9A/09RHL02LW7@0X:1h0:BDL02XV7@80:bLN
00@0:RHM02TU700W8aX09R8I0P0V:Ah202DX7@@092LL0P0Y9A`202PT6`@09b<J0P0R8QX202<S6`<0
92@L00@09BDM024R700Q8Q`08B8L0P0P8A/301lP6P<0824K0P0Q8Q`3028S7@0602<S6@0T91X092@J
02DU6`0V9Q`09bLM0P0X:1h202HW6@<09bPJ0`0X:A/01@0b:1l0<bTP03<Y7`0c:Ad0<bXK0080=2/J
00`0=2`I03@_6`0c;Q/0<B`I030Z6P0_:A/0<2XN034Z800b:b40<bTP03@Z8@0e:b8203H/8`0903D[
8P0d:R40<bTP03<Y800b:B00<BPO02lX7P0]:Ah0:bTM0080:BTM00<0;b/O02hZ7P0/:1`00`0[9a/0
1`0]:Ad0;RXN02l/6`0_;1/0;R/L02hZ7P0^:Ql00`0]:B000`0]:280;RXN02dY7@0202dY7@80;2PL
0P0[9a/802DU7@0302PX7P0W9ad09bLM00809RHL0P0U9A/00`0T91X0;BTM02dY7@0602dY7@P0:bLK
200X:A/802LW7@P09BHN0P0Y9AT0100Z9QX0:bLK02dY7@0^:Qh202l[7`<0<B/M:oooool002[ooooo
202SNDT20:5hA0040:9iA@2SNTH0XgY60:AkA`80YGa80P2TNTX0102UNdT0YGa80:ImB@2VODL20:Mn
AP080:Z0CP2WOD/0XGM509id@P2OMD<0Y7Y80:Z0CP2_QE<80:UoC@80Z7m;0`2WOTX30:ImB@030:Aj
B02VO4X0ZGm=0080Zh5?00<0ZX1>0:QnC02VO4X00P2VO4X0102WOD/0Z7i<0:QnC02YOdd20:Z0CP06
0:V1@`2XP4<0Z8130:MoA02VODD0YWe70P2UO4P30:V0C0<0ZX5=0`2YP4`0102WOTP0Z7m90:QoB@2Y
P4X20:Z1B`80Zh9<202YP4`30:^0C@D0ZWm<00<0YGa80:ImB@2YP4`00`2[PTh01`2YP4`0Z7m;0:V0
C02YP4`0ZX5=0:^2CP2/Pdl00P2^QE401P2_QU80[HA>0:f4CP2]Q500[H=A0:f3D`80[H9E00D0[H9G
0:^6DP2ZQE40ZXEA0:V4D0020:R3C`80Yh9>0P2]Q5020:b3C`<0Zh9>00L0ZX5=0:F0C02UP4`0Y7m;
0:=nBP2RODT0XGa80080X7]70P2NNDD209mjAP0409ehA02KMT80VGA009Mb?P80VVm200@0VFi109M/
?`2FJch0U6Tl0P2CJ3/01P2EJ3h0U6Tn09=X?@2AJ3`0SVPk08aW>P80RFLi00P0SFTg08]W=@28I380
QV8`08EQ;`27Hc40RFDc08YV=080Q68d00@0Pf4c089P<P21Gc40P5h`0P1oGBl207QJ:00407QI:P1h
FB/0N5T]07QH;`80N5Pa01H0NU<b07MC<@1fDS00M58_075@;@1]Cb/0JdlZ06Y>:@1^D2`0KDl[06a>
:P1[CBT0K4hZ06e?:`1_DBd0L58^06I>:01WCBP0J4hY06Y>:@1[CBT0KD`Y0P1^C2T01@1aCBT0Ldl[
07IC;@1hEBd0NUL]0080NUP[00<0NELZ07QF:01jEBP00P1kERT207aG:P0<07eH:`1nFB`0OUT/07mI
;022G2l0QV0c08YT=`2<IST0RfDh08US=P27HC@0R68c0P29Hc@00`2:I3D0RfDf08aV=`0208eW>0<0
SVPi0`2=IcP208aV=`80RV@e00@0RfDf08aV=`2<ISL0SFLh0P2>J3T208]W<`<0RVHb0`29IC401P2<
Ic80S6Lc08]V<P2;IC@0RfDf08YT=`80RV<h202:ICP00`27HSD0R6<f08UT=`0208YU>00;08UT=`28
HcH0Qf8e08MQ>P26HCL0QF0f08AO<`24Gc80QV8b08QT<P29IC<00P25I3400`25Hc<0Q68d08AR=@02
08=P=P0608=P>027H3D0Qf0e08IP<`26H340QV0_0P25H2`00`25H2/0PEla085O<@02089P<P0<08=Q
<`24HS@0Q68d08ES=@22GcD0PEhd07mL<P1nFc40Oe`b081M<`21GS@0PUle201oG3802`24GRl0PU`]
07iI;01jF2/0N5L/07UI<01kFc@0NUde07]K<P1jFS40N5P_00<0MUH]00<0N5P_07UI<01gEbh00`1f
ERd207EE;080M5@[0P1aD2L2079A:00307=B:@1dDbX0M5<Z0080M5<Z00T0JU8^06UA;@1WCb/0I4`X
069:9P1OAb<0GDDQ05a4801NC2H00P1MBbD00`1LBR@0FdTS05Y88P0205U78@0805];:@1IBBL0EDDT
05918`1@?b<0DD0V05919`1D@RX204Lm8P0404Pn8`19?b@0BClT04Y09@80Bd4V00H0Cc`L04`k7@1<
>ad0Bc`O04Tk8017>b4204Dk8P<0@3DQ0P0o=20303hc7`0303/f8`0j=B80=c8O00<0=C0M00H0=c8O
03Pc800^;al0;RlO02d^7P0/;Ad202//7080:R/K0`0X:Ql302LY7P809RPM00@092LN02<V7@0S9Qd0
8bHM0P0R9A`2024T6`<092LP00<08bHO028U7P0Q91d00P0Q91d202@W7P808bHM0P0R9A`2024T6`04
020Q6`0Q8Q`08B8L028S7@808b@N0P0T9Al202HW7`0402DV7P0T9Ad08b@L028S6`808B8J0100:alQ
02XP8@0Y8Al09R<N02@U7@0S9Qd08BLK020X6`0U9R009BHN02HW7`0W:Ah0:2XM02T[7@0Y;1/0:RdL
0P0a;Q/2038_700@03<`7@0d<Ah0=34N03Db7`0j<1L0>c4H03db700n<ad0?c@P03hc8@0l<200>blO
034b900_<280;2dO02PY6`D09RLI200X:A/202`]7@80:b`L0`0Z:a/01`0Y:QX09bPH02LX600X:A/0
:2PL02PX7P0Y:B400P0Y:2<03P0X:B409RLO02@U7@0T9Ad09RLO02X[8`0_<2P0<S<[02X[8`0Y:R80
9bPP02DV7P0T9Ad09BHN0P0V9al01P0V:B809bPP02LX800X:1h0:RPL02/W6`80;BLI03<0:BTQ02XZ
8P0/:B00;RXO034[7`0c:ah0<b`L03D/7@10<b80?c8Q03ha7P0n<Q`0@3@L04<g7@15>Al0Ac`P05@n
:@1E?bP0Ed4Y05U49`1KAbH0FdLT05]78P1JAal0Ge<S069F9P1YFb`0LF4`07AR<01cHRh0LUh[071L
9`1cGb00MV8U07aV:P23JS40RF/e08][>02<JSX0RfTi07iJ=P1jF3D0L58`06A;;01KARL0DT<V04a1
9@1:@2D0>cL[03Xf:P0i=BT00P0h=2P02@0i=BT0>cL[03`h;00f=R`0=cL]03Tg:`0k=b/0?CLY03hh
:002040i9`09044k8`10>R80?cTQ03hh800o>B40@C/S04@n9P15?bL0B44W0080BD8X00<0BT<Y04]4
:P1;A2X00P1;A2X205939P0305=49`1DABP0EDHY0080ETLZ00L0EdP[05A5901EARD0ETLV05Q9:01J
BbX0G4d/0080GTl^00<0FThX05U=9`1HC2H00P1GBbD00`1HC2H0FThX05]?:@0205Y=:`0;05M::01D
AbD0DD@R04m2801@@b40DD@R05=6901C@b80E4@S05=48`1BAB<00P1@AR<02P1@B2@0CTPT05=5:P1C
ABX0DT@Y04i09@1:?240BcdR0553:01FB2d304i2:0@0Cd<Y01@0D4@Z04]6<P1<AS00CTH_0596;01F
B2/0FDPZ05a9:01MBBP0Cd/V055;9`1DC2P0F4/Y05a<:`1OC2`0HD`]06A=;P1WEcH0He<b05e=;080
FDTX00<0G4`[065A<01UEC@00P1ODBX3061B:`<0HE</0100HE8Y061A:01MCRD0FT/R05M87`1DAA`0
DD8I0511601GAAl0F4HP05U78@1KBB<0G4XT05i<9P1OCBL0H4hX0P1NC2H205m=9`80H4hX0P1QCbT0
201LBR80GddU065?9`1OCBD0FdTQ05U77`1KBB40GT`T0P1LC2P0101KBbL0FDTU05M78`1FAR8205A4
80060511801A@R40DT<R05=48`1DAB@0EDHU0P1FAbH505E69@80E4DT00T0Dd@S05=58P1AA240DD@R
04i38`1<@b@0BD8U04M29017@RD00P18>Ql00`16>al0AC`O04<l7`02044l7P03040m7P0m?200?C`P
0080?3/O0`0k>Qh0100j>Ad0=CLO03Hh800g>B4203Pj8P0303Hh800d=Qh0<cDM00T0<S@N0`0a=Ah2
030d7@<0;c<L200`<Qd202/^7@<0:RdL0`0Y;1/202PZ70809bTK00@09RPJ02DW6@0T9QP092HH0`0P
8Qd201lQ70<07R0K100M81T201`O60806ahG0`0I7a/201PN6P<05adI0P0G7A/201HL6P805A/I4P0D
6QPH01LI60P05QPG200F5aT@01DF60P05ALF2@0E5QPH01HG6@P05AHH200F5aT801HH5`P05QLI400E
5QP8018H600701/M700I6aX05ALF014C4P0@4Q404Q@C01@F5@0901HH5a005AHH600F5aTA01HH5a00
5QLI400G6AP801TK6PP05aTH200I6aX801XL6`806adJ0`0L7Q/301dO710071`J200K6aT201TK6004
01XL6@0K7AX06adJ01`N6`807AlL200K7AX@01XL6@P071`J0`0J71T201/M6P<071hK2`0M7A/201hN
70807alM0P0P81h8024R70<08b<K0P0T91`302DU7@80;2DM0`0]9Qh302hW7`0803<]8@0b;200<B/O
02lY7@0^:1`0;2HJ02/U6@0Z91P302lY7@<0<2XN0P0a:al01P0b;1h0<b/N038Z7@0c:Ad0=BTM03HX
7@80=bHL0P0g:al0100f:Qh0=BTM03DY7@0d:1`203<W6`80=BHO00@0=2LO038X7`0a:1l0<2TO0P0^
:Ql802h[7080<B/O0`0`:Qh302lY7@0602hP7@0/8Ad0;24M02`S7P0[91h0:B@N0P0Y9Ql00`0[9ah0
:RHM02PT6`0202LS6P0302PT6`0Z9Qd0:bLN00P0:B@N200R8QX2024Q6@@08R8J0P0S8a/302@T70D0
8b<K200Z9Qd00`0/9QX0;RPL02lY7@02034[7`80;bTM00@0;RPL02`V6P0/:B80;2TR0P0[:240100Z
9b00:BHO02TV7`0X9Ah402<U6P@092HK200X91/302dW6`0302`V6P0[9AT0:R@H0080:R@H00<0:B/P
02PZ7`0V:1d00`0T9Q/0100V:1d09bTN02TU700Z9Qd202/W7P0402XV7@0X91/09R8I02DQ60809bXO
0P0V:Ah302DX7@0302@W700Y9A`0:BDL0080:2@K0`0W8aX00`0V8QT08R8J028R6P0202<S6`@092@L
0P0Q8Q`3020Q6`<07b0J0`0P8A/2024R70<08R<M00H08b<I02@T6P0T91X09BDK02HV700W9ad202PX
7P<09BLI0P0V:1X302LY6`80<bTP00<0<bTO03<Y7@0c:Q/00P0c:QT0300d;1T0<bhJ038]6P0`:aP0
;bTI02lY6`0`:Qh0<R/Q03</8P0b:1l0=2XQ03D[8P80=R`S00T0=B/R03@Z8@0b:1l0<RTP034X7`0`
:Al0;bPN02`X7@0[:Ad00P0X:1`0100`;200;b/O02dY7@0/:1`202/W6`80;BTM0P0_;1/00`0^:a`0
;RXN02hZ7`0302dY800402dX8P0^:Qh0;RXN02hZ7P80;BTM0`0/:1`802DU7@0402PX7P0W9ad09bLM
02HV70809BDK0P0T91X802dY7@P0:bLK200W:A/302DW70809RPM0`0W:Ah802DV7P0602HR5P0W8aL0
:2@H02XV6P0/:1`0;BTM0P0_:al3034[7B_ooooo000Zooooo`<0XWM21@2SN4<30:IkAP<0YGY50P2T
ND@0102UNdT0YWa:0:IlBP2VO4X20:MmB`80Z7i<00P0YWm80:EnA`2UO4H0YGY50:MiA@2YNTH0ZW]7
0:ekB080ZWQ70P2[NDP20:ajB@80[G]:00D0XgY60:AkA`2TNdL0YGa80:ImB@020:MnBP090:QoB`2U
NTL0YW]80:QmBP2YOT/0ZWm<0:UnB`2XODX0Yga900P0ZGi;00<0Zh9:0:Z1B@2XOdT00P2WOTX00`2X
OT`0ZX1@0:^1D@090:UoC@030:j3D02]PTl0ZWm<00<0Z7e:00<0ZWm<0:^0C@2YP4`02@2YP4`20:Z1
C@80Zh9>0P2/Pdl30:b2DP030:^1D@2ZP500ZGm?0080ZGm?202[PDl30:R3CP<0ZHA?0P2ZQE030:^6
D@80ZXE@0`2YQ4l80:R3C`80YH1900<0Y7m80:=nA`2RODH00P2QO4D02@2PNd@0X7a20:1l@P2NND80
WGQ309]f@@2IM400V79109Ma@00209Qc?`80Ug8n00@0UW4m09E`?02DKc/0U6lk0P2EL3`0102DKc/0
TVdi091[=`2?JSH208eX=00808YT=@2>J3T0T6Xk08iX>@28HS<0QEl`08QR<`2<ISL208EP<`06089P
<P20H340Of0a07aP<01kGbl0NV0_0P1kF30607YG;`<0M5@[0P1cDbX3079B:@0E07MA:P1dDB/0Le0Z
071>:@1]C2T0JD/Y06M::P1VBBT0I4/]06E:;@1VBbd0JD`^06]<;@1_CRd0L4h[075?;01]CBH0KThW
06m?:01bDR/0M5@]0080MeL`00<0N5Pa07UI<P1iFC000P1kFS400`1mFS80P5Xc089K=00208EK=@0;
08AQ=`23H3H0PEhd081M<`21GS@0PUle08ER>026HcT0RF@g08QS=P26HC@00P24Gc800`26HC@0R6<f
08UT=`0808eW>0P0RfDh0P2<HcD0102;ICH0RfLg08]W=`2:J3P208YZ>@<0SFLh0P2<ISL308]U=P@0
RFDe0P2:ISH208]W=`80RF<f0P2:I3L0102;ICP0S6Hi08aV>@2=IcX808IQ=`0608]S;`2;Hc00R6<_
08IR<026HS80Pf4c0P21H3<208IQ=0<0QF0c0`24Gc88085P;@<0PEhd0`20GC<207mL<P0807mM;`1m
Fbd0NELY07ME9`1hERP0O5X/081N<023HC<407aI;`@0OEX`00H0O5`c07]K<P1kFc80NUXa07UI<01h
F2l207MG;P0607YJ<@1iFC00NET`07MG;P1fERd0MED/0P1dE2/01P1fERd0MED/07AD:`1cDbX0LE4X
06m?9P80KThU00L0KDdT06m>:`1_CR/0K4hZ06U=:01VC2L0Hd/U0080HD/T00H0GDdY05a<:01KBbL0
FTXV05U99@1GAb<205I68P0605]2901J@b@0FD8S05M28`1E@R80DT8Q0P1@@B0205109P0404lo9@1>
?R@0C3`R04/k8@80BSXP00P0B3`R04Tm8`1:?R@0BShT04Tm8`16>R00@cLM048f70<0@cLM1014>1h0
1015>Al0?cLR03hf8@0l=1l303Xb7@0=03/c7P0l=1l0>c0L03Ta700h<1d0=RlM03@^7P0a;Ql0<2hO
02l]800W:1X0:2TK02X[7@0202`]7`0302//7P0Y:Q`0:2TK00809bTN00<09RPM02DW700T9Q/00P0S
9AX00`0R91T08B@M024T7@06024T7@P09BHP2@0T9Ad202<T7003028S6`0Q8QX08B8J00<0824I0P0Q
8QX00`0R8a/08b@L02<T700202@U7@<09BHN0P0V9al302LX8080:R/M00H0:b`L02//6P0/;QT0;BlI
02h`6P0^<1P203Dc700303Lb700h<Q`0>C4L0080>c0L00P0?2lL03Lb7`0i=240>SDR03Td8@0f<Ah0
<RdJ02lZ5`80;BPE0P0T9Ad0300U9Qh09RLO02LX800X:B40:BXR02X[8`0^:B<0;RXQ02l[8P0_:b00
<2`P030]7P80<BhM0100:2`M02L[700X:Q`0:2TK02TW6P0Z9QX0:BDI02/U6@0Y:B409RHN02<S6`0U
9Ad0;2`T03Ph<015ACd0CDe50P0U:1l00`0T9ah08bHM028U7002024T6`03020S6P0V9al09RLO00H0
9RLO0`0[:b4202XZ80<0:BTO0240<RT/03<Z:`0d;2T0=RlW03La8`0i=200>SHM03/g7012=R00@cLO
04Di8@17>b40BChR04]08P1<@B40CD8R05a89`1MBBP0H4`Y06=?:P1VDb/0JEH/06aI;`1]FRl0L5db
06mM;`1_GBd0L5h^079P;P1eI300N6La07UX<P26IcT00P27J3X03@26IcT0Pf@f07mP<P1lGBl0NU/]
05m87`1KAAh0Ed0N050k7P1<>1l0BCLS04Pg9`19=bT00P19>BX03P15>BT0@cXY044l:@0n?BT0?ClZ
03`o:P0j>R00?CdS03i0:010@R`0?T4/03]0:P0e?BP0<STW0P10?RT00`0o?BP0?S`W03dk9P0303dk
9P80BdDQ0P1<AR80101=Ab<0CTPT04i8901>B2@204e49`80CTDX00@0CdHY0517:P1@AbX0DDP[201A
ARX304i3;@80CD8/00`0C44[04]0:P1:?bT0BSlY04a1:`1=@R`0CdD/0516:`1?ART0CTDV04a3901:
@B0204Y6;@0304U5;018A2/0Ad<Z0080AT8Y00<0AD4X04m19P1?@BH01P1?@BH20592:`0405=3:P1E
AB/0EdP[05Q9:P80FT/Z0`1IAb4305Y88P80FdTS00<0FDXS05]<9@1MCRL00P1NCbP02`1MCRL0Fd`U
05Y;901HBRD0FT`W05i@:`1PDRd0Ge4/05a>:@1GBB@0E4HQ00<0Ed@V1@1HABL02@1IAal0FTPP05a:
8P1MBb<0GddU065?9`1SDBT0I58Z065>9P03061=9@80Gd`T0P1NBb<305];9`80FTXV0`1IBBD01P1J
BRT0FDTX05Q89`1GAbH0ETHU05E59080E4@S1@1DABH00`1CA2D0DT<T05528`0205A39@<0ETDW00/0
E4<U05918`1A@280CT4O04m2801=@R80C4<T04Y39P17@RD0A3hT048n8`08040l7`0303`k7`0m?200
?SdQ0080?chR00<0?C`P03/j7P0i>1`00P0h?2<203Lk8P0503Hj8@0e>B00=CTP03@h7`0a<ad00P0b
=1h01P0d=R00=CLQ03@f800b=1h0<38L02la6`80<3<N0`0_<Qd302ha70<0;2lN0P0[;Qd302X]70D0
9RTN0`0W:Ql202DX7`0402@W7P0S9Qd08RDL024T6`8082<J0P0L8a/201/R6P806R4I0P0I81P301XP
70<06AlK0P0H7QX801HL6P805adK0P0F71X201DK6A8051XH200C6AT801HH5`P05QLI200F61LH01DF
60P05QLI2@0E5QP801HG6A005QPG200E5QP801HH5a805QLI0`0E5QP301@E5c005AHH200E5aH801LH
6QT05QLI200F61LX01LI61006A/J600K7AX301`N6`806adJ4`0J71T801TK60P06A/J200K6aT801`L
6PT07AdK0P0L71X301dM6`<07QhL0`0O81X3020Q6`808B8L200U9Ad302TU7080:RHM0`0[9ah202dW
6`80;RPL0P0_:Ad2030Z7P0402/U6@0/9QX0;bTM034[7`<0<R`P00<0<B/O038/800b;2001P0b;200
200a;B40<2`P034[7`0a:Ah0<bTO03HY800i:b80>R`S200`:Qh0200b;200<B/O030Z7P0_:Ad0;RPL
02dW6`0/9QX0:bDI0`0_:Ad202hX70<0;BLK0`0/:AX202/X6@<0:RLH00<0:2PP02LW7`0U9Ad00P0S
8a/00`0U9Ad09bLO02PX800302<R7@0302@S7P0U91l09RDP00809RDP200R8ad802@T70P08b<K00/0
7bXL020X6`0R9AX09BDK02/T700a91h0=R@P03TV8P0Z9Qd0:bLN02`X7`0202dY8080:bLN00@0:BDL
02LS6P0W9ad09bLM0`0V9Q`302DU6`0402DV7P0T9Ad092DM02@U7@808b@L0P0R8a/302/T7080;2DM
0`0]9Qh0100`:B40;bPP02lX800_:20202hW7`80;BHN200W9al0200Z:R80:BTQ02PX800W9al09BDM
02<S6`0R8QX08B4I200T91`8028Q70808B8L0P0P8A/401lP6PP07QhL1@0P8A/301lP6P809R4K0P0W
8Q`202PS7@80:B@N00@0:BDL02XV7@0Z9Qd0:bLN0P0/:1l202dY80P0;2PO00H0:B/M02X[7@0Z:ad0
;2XM02hZ7P0`:Qh2038Z7`P0=RTP200Y:Al202HY7P0302PZ7`0Y:Al0;2TP0080;BTP00@0<2TQ02TY
7`0Y:Al0:BTO0`0X:1h302LW7@809RLO0P0U9Qh402@U7@808R<K0P0S91`302@U7@0302DV7P0Z9Al0
:RDO00H0:RDO0P0Z9Qd302/W7P<0;2PO200a;B40100^:R40;BTP02dY800]:B0202`X7`80:bLN200W
9al202DU6`809RHL0`0W9ad402PX7P0302TY7`0Z:R00:b/Q0080:b/Q0`0];B<[ooooo`00:_ooool3
0:9g@P@0XgQ300@0Y7U40:IkAP2VNdH0YW]60P2UNTD30:AiA080YG]90P2VO4X30:MmB`090:QnC02V
OdP0YGi70:ElAP2TND@0YWQ40:UjAP2ZNdL0[G]80080Z7Q70P2YNDP20:YjB@80Zg]:102UO4P40:Im
B@080:EjA`2VNdP0Z7e:0:UnB`2ZOd`0ZGi;0:QmBP2WO4T80:UnB`030:^2BP2ZPDT0Z7m90080Ygi:
00<0Z7i<0:Z0D02[PE402@2YOdd0202^Pe00[85>0:YoC02YOT/0Z7e:0:UnB`2ZOd`0Zh1=2P2YP4`2
0:Z1C@80Zh9>0P2/Pdl20:b2DP80Zh5A0P2ZP5020:UoC`P0Zh5?0`2XPdh30:V4C`80ZXE@0`2[QU42
0:Z5D0<0ZHA?202XPdl20:F0B@040:AoB02SOTL0XWe60:9mAP80XGa500H0XGe30:1l@P2ONT<0WWU4
09eh@`2KMT8209Yd@`0609Ud@02HLcl0V7<o09Mb?P2FLCd0UG0l0P2DKc/05P2FLCd0UG0l09A_>`2B
KCT0TF`h08mZ=P2>JCD0SFPd08]U=P2>J3T0T6Xk08iX>@29Hc@0QV0a08QR<`2<ISL0Qf8e08IQ=024
HS@0PV8c081Q<P1oH34207aP<0@0NeP`101jEbl0101eEB`0M5@[07AD:`1dE2/207=C:P80LU8Y01D0
MU0Y07=@:P1bCbT0L4hY06i=:P1[CB/0JD`/06Q;:`1TBbd0IT/^06I;;@1YC2`0K4h/06m>:`1`CR/0
LDlZ06e=9P1^CRL0L50Y079B:`1dE2d00P1fERl207QH<@80NET`0140NeXa07eJ<P20FS<0PEXc089K
=025FcD0Pf0f089O=@21GS@0P5dc085N=022GcD0Q64g08ER>02:ICP0RF@g08MR=@0208IQ=00308MR
=@29I3L0RVDh00P0SFLh202;ICP00`2<HcD0SF@f08]U=P0208]W=`0308YX>029JCP0RVXi0080SFLh
0`2<ISL308]U=P0408QT=029ICD0RFDe08UU=@80RVHf0P2;IcL208US=P80RV@g0P2;ICP208aV>@P0
QV4g00P0Rf<_08YR;`28Hbl0QV8`08IR<P23HC<0PV4d085P<`80QV4d0`25H3<308AO<PP0PF0]0`21
GS@3081M<`80Oe`b00P0OU`^07eK;@1kFB/0NELY07YH:P1lFR`0Oed_085O<@@0O5T_101mFS001P1l
G3<0Ne/b07]K<P1jFS40NET`07QH;`80MeL^00H0NUXa07UI<01hF2l0MeL^07IF;@1eEB`207AD:`80
MUH]00@0M5@[07=C:P1aDBP0L50W0P1_CbH02@1^CRD0L4l/06m>:`1/CRX0JThY06I<9`1TC2H0HT`U
065;900205m=:@0405i<:01LBRH0FdTU05U78`80F4HR00H0G4<U05Y3901J@b@0Ed8S05E28P1B@R42
05118080D40V00L0CclU04hn901=?B<0C3`R04/k8@1:>R00BCdS00<0BShT00@0BCdS04Lk8@15>Al0
@cLM1P14>1h204Di7`0303lg8P0n=R40?3@O0080>S8M00h0>c<N03`d7`0m=B00?34M03Ta700i<Ah0
=c0N03D_7`0b;b00<2hO030^8@0X:A/0:BXL02X[7@80;2dO00<0:b`N02X[7@0X:A/00P0W:Ah0100V
:1d09BLL02@V6`0T9Q/202<U6PP08B@M200U9R0;02@U7@0302<T700R8a/08R<K00D08B8J00<08R<K
02<T700S91`00P0T9Ad302DV7P<09RLO0P0W:2001P0Y:Q`0:R/M02X[6`0[;1`0;2dK02d_6P80;S0J
00H0<S8J03<a6P0d<Q/0=S4K03Pb700i<A`203`a7@0703Pc800i=240>C@Q03Lb7`0e<1d0<RdJ030[
600202lZ5`809RHL0P0W9ad202PX7P80:BTO00H0;BPR02dY800^:R40;RXO02l[7`0_;1d202l/6`05
02T]7P0X;1d0:B/M02TZ700[:A`00P0[9a/00`0/9QX0;BdS02`/8P0202/[8@0402`/8P0^;R@0<C4W
038b:0809RTN00<09BPM02@W700S9Q/00P0R9AX00`0Q91T09RPM02HX7@0602HX7@<0:RXP0P0Y:Al3
02PX7P0I02lY:@0_:RL0<B`X038^8`0d<B80=C8O03Hd7@0g=A`0@3@N044e7`12=Qh0A3PN04Hk7`18
?Al0BSlQ04]0801D@B40ED8R05M48`1JB2@0GD/U061>9P1SDBT0I5<X06]H;P0206]H;@0806aJ;01^
G2`0LEl]07=R;P1eI300Nehb07eP=01nHCD3081S=`0H07iQ=@1mH3@0PV/o07eX?@1gHCX0KETf06=@
<01KBS00EDD/05=3;01E@2/0Dd4[0510:@1=?RL0BClV04Dn9013?B<0@CdR04]19P18@BL0AClU04<m
9@11?2H0?S`W0P0m?2P3048m9`<0@chX0P14?bT01P18@R80BD<S04U38`1:A2@0BdDU04a69P80CDLW
00<0C4<V04e49`1=A2L00P1>ABP204m6:@030517:P1@ABT0D4DY00H0D4DY101<@B/304]0:P<0BSlY
00L0Bd0Z04e3:P1>A2T0CTDX04e49@1<@b@0Bd8Q00<0Ad4Y0P16@2P304Do9`P0D48W00H0D40Y0551
:P1B@RT0Dd<Y05E6:@1GB2T205Q9:0<0GD/W0P1NC2P305m=:@0305a<:01MCBT0GThZ0080Gdl[00/0
GDdY05a<:01JBRH0E4HQ05I88`1HBRD0FD/V05Q:9@1FB2<0DdDP05537P0305M49080F4DU0P1IARH0
2@1JAbL0FdTQ05a:8P1MBb<0GddU061>9P1RD2P0He4Y06AB:P04065>9P80H4dU0P1OC2@205a<:080
Fd/W0`1JBRH01`1IBBD0FDTX05U9:01HB2L0EdLV05I69@1EAB@00P1DA2<0101EARL0E4DV05=49@1C
A2D30593900905=49@1B@b@0Dd@U05A59P1EARL0E4DV05=49@1A@R<0D44R0080CT4O00H0CD8R04a3
9019@RD0AT4T04@n9012?R<8040l7`0803`k7`0m?200?SdQ03ln8P0n?B40?C`P03/j7P0i>1`203Tk
8`80>3XR00@0=cTQ03Hh800f>200=SPP0`0b=1h303@f8003038d7P0`<Q`0;c4K0080<3<N0`0_<Qd3
02ha70<0;2lN0P0[;Qd302X]70H09RTN0P0W:Ql01P0U:1l092LN02@W7P0S9Qd08RDL024T6`8082<J
0P0L8a/201/R6P806R4I0P0I81P301XP70806AlK0`0H7QX801HL6P805adK0P0F71X201DK6A8051XH
200C6AT801HH5`P05QLI200F61LH01DF60P05QLI2@0E5QP801HG6A005QPG200E5QP801HH5a805QLI
0`0E5QP301@E5c005AHH200E5aH801LH6QT05QLI200F61LX01LI61006A/J600K7AX201`N6`<06adJ
4`0J71T801TK60P06A/J200K6aT801`L6PT07AdK0P0L71X301dM6`<07QhL0`0O81X3020Q6`808B8L
200U9Ad302TU70<0:RHM0P0[9ah202dW6`80;RPL0P0_:Ad2030Z7P0402/U6@0]9a/0;bTM034[7`80
<R`P0P0a:al8038/8080<2`P00H0<2XN034Y7P0b:1h0=RTP03T[8P0j;2<8030Z7P05034[7`0`:Qh0
<2XN02lY7@0^:1`00P0]9a/00`0/9QX0<2XN030Z7P0302lY7@<0;RPL0`0/:AX202/X6@<0:RLH00<0
9bLO02HV7P0U9Ad00P0T91`00`0U9Ad09RHN02LW7`0302<R7@0302@S7P0U91l09B@O00809RDP200R
8ad802@T70P08b<K00d07bXL020X6`0S9Q/09BDK02/T700_91h0=2DP03PV8P0[9ah0;2PO02dY800^
:R40;BTP0080;2PO00@0:RHM02PT6`0W9ad09bLM0`0V9Q`302DU6`@092DM0P0S91`2028S6`<0:BDL
0`0Z9Qd202/W7P<0;BTP0P0/:1l302/W7PP09bLO00P0:RXR02TY8@0X:2009RHN02DU7@0S8a/08R8J
024Q6@P092@L200R8A`2024R7080824K0`0O81X00`0N7aT07QhL01hN700601hN70H0824K0P0O81X2
02HQ6`809b8L0P0X8ad202TT7P<0:RHM00<0:bLN02`X7`0/:1l00P0]:B0802`X7`0602PZ700Z:ad0
:R/M02`Z7@0^:Qh0<2XN0P0b:Ql803@Z80P0:BTO0P0V:Ah00`0X:Ql0:BTO02`Y800202dY800402lX
800Y:Al0:BTO02TY7`80:2PN100W9ad202HW7`809BHN0`0T9Ad00`0S91`08R<K028S6`0202<T70@0
92DM200Z9Al302XV7@80:bLN0`0/:1l802l[7`@0;BTP0P0/:1l202/W7PP09bLO0P0V9Q`202LW7@L0
:2PN00<0:BTO02XZ800Z:R000P0[:b4302PX7R_ooooo000Zooooo`050:5f@@2RMd80XWM20:9g@P2S
N4<00`2TND@20:IkAP80YGY50`2TND@00`2SN4<0Y7Y80:EkB@020:EkB@80YWa:0P2WOD/0202VOdP0
YGi70:AkA@2TND@0YWQ40:QiA@2ZNdL0[G]80P2XN4L20:UiB080ZWY90P2[NdX40:ImB@@0YGa800P0
YGY70:IkB02XODX0ZGi;0:YoC02YOT/0Z7e:0:MlB@P0ZGi;00<0ZX590:V0B02XOdT00P2WOTX00`2X
OT`0ZGm?0:Z0D0090:UoC@030:f2C`2/PDh0ZWm<00<0ZGi;0P2ZOd`:0:V0C080ZX5=0P2[PTh20:b3
C`040:b2D02[PDl0Zh5?0:^1C`<0ZX1>00<0ZGm=0:^1C`2[PDl01P2[PDl30:R3CP<0ZHA?0P2ZQE03
0:^6D@80ZXE@0`2YQ4l80:R3C`80YX5<00<0YH1;0:AoBP2SOTT00P2RODP01`2QO4L0XGe30:5m@`2P
Nd@0X7]609mjA@2ONTH00P2NN4L01P2JMD40VGA009Ud@02HLcl0Ug8n09Ia?@80UG0l00H0UW4m09E`
?02DKc/0Tfhj095/>02@JcL208mZ=P0808aV=`2>J3T0T6Xk08iX>@2:I3D0R68c08US=02;ICH208US
=P0608MR=@25HcD0Pf<d085R<`20HC80OV8b0`1lFC4207]H<0<0NUL_0`1eEB`207AD:`<0Le<Z00H0
MDlX079?:@1bCbT0L4hY06m>:`1/CR`206]>;P0=06E<;@1VBbd0Idd/06Y=:`1/CR`0Kdh[071>:@1a
CbX0KThW06m?:01`D2T0LU8[07=C;00207EE;P0807IF;`1gEc00MUT_07QH;`1iFC00NeXa07eJ<P1o
FC82085J<`0;089O=@21GS@0P5dc081M<`21GS@0PUle08=P=P24HCL0RfHi08YU>029I3L00P28HcH0
0`29I3L0RVDh08]V>@0808eW>0P0RfDh0P2=I3H0102;ICH0RfLg08]W=`2:J3P208UY>00408eW>02<
ISL0S6Hg08aV=`80RfDf0P2:I3D308QT=080RFDe0`2:ISH208US=P<0RV@g0`2;ICP808IQ=`0608YR
;P2:HRl0R6<_08IR<026HS80Pf4c0P22HC@208IQ=0<0QF0c0`24Gc88085O;`<0PEhd0`20GC<207mL
<P0407eK;@1lFR`0O5X/07aJ;080OE/]00<0OU`^07mM;`1mFS000`1mFS0407aI;`0607aL<`1kFc80
Ne/b07YJ<@1iFC00N5P_0P1gEbh207UI<00307QH;`1gEbh0MUH]0080MED/00L0M5@[07IF;@1fERd0
MED/07AD:`1bDRT0LE4X0080L50W00T0KdlV071?;01`Cb`0KDl[06Y>:@1WCBP0IDdW06==9P1RC2D0
0P1OCBT03P1NC2P0GD/W05]99@1JB2@0FDLS05Q68P1L@bD0Fd@U05Y3901G@R<0ED8R05928@1A@R40
D44P0P1@@2H00`1??bD0CShT04dm8`0204`l8P0304/k8@1;?bD0BclU0080BclU00@0BShT04Tm8`17
>b40ASXP2015>Al04`0o=b80?SHQ03`d7`0k<ah0>S8M03/c7P0l=1l0?CDP03`a7@0j<Qd0>C4N03L`
7P0e;al0<RlP034_800`;R40:BXL02X[7@0[;1h00P0/;Al0100[;1h0:R/M02TZ700X:Ql202LY7P03
02HX7@0U9a`092HK00808bDJ200R9Ah802@U7`P092DM0`0U9Qh302@U7@808b@L0P0Q8QX3028S6`<0
8b@L0P0T9Ad202DV7P<09RLO01D09bPP02PX700Y:Ad0:BXL02X[6`0[;1X0;2hI02d_6P0];aT0;bhI
030_6P0b<1/0=C0L03L`7@0i<Ah0>S8O03db800j=B80>3<P03Ha7P0e<1d00P0d;a`00`0c;Q/0<RdJ
038]6P0302PX7P<09bLM0P0V9Q`0200[9R00:bLN02`X7`0/:1d0;BTM02dZ6`0]:QT0;R/J0P0Z;Ql0
0`0Z;1h0:b`N02d[7P0202dY7@0:02lY7@0Z:R00;2`R02h^900_;bD0;BdS02PX7P0S8aT07alE02T[
8080:2XO00<09bTN02HX7@0U9a`00P0T9Q/802LY7P80:BTO0P0X:1h202LW7@809RHL01T0;BPU02dX
900^:B<0<2`Q034^7`0b;a`0<c4L03@b6`0k<1h0?34M03db7P0o=1h0@CLN04<i7P14>ah0AC`O04Th
701:>Ad0C3/M04hn7@1A@Al0E4@P05I68P1GB240He4[0080He4Y00/0He8W06ED:01XEbT0Je/Z06eM
;01_E2T0LUL/07EJ;`1iGS<0O64f07mT>@02081U>P0H08Ma?`26LT00QG11081]@P1lJT80MfM307=U
@P1aHT40KU<e06aC=01ZDC80ITl_065=;01MBRT0F4PV05E7901MB2/0F4@Y058n8`1;>R00AcLN04Hg
8017>bD0BCdW0P12>b400`13?280A3dS04Dn900304Ho9@0604Ll9P18?BL0B3dW04Xo:@1;@2X0C44[
0P1=@R`204a39P<0CD@W0`1>ABP804i39`<0BClV0`1:@2L304]1:00504Pm9`19?RP0Bd4X04a29`1=
A2L00P1=A2D00`1<@b80AChT04Dn900204Dn90<0ASlU00<0Ad0V04m4:01?A2P01P1?A2P01P1@@2T0
DD4Z0592:@1C@bT0E4DX05I7:080EdPW0`1PCRX2065?:`<0HU0/0P1MCBT205i>:P0405e=:@1KBbL0
FTXV05U99@D0DT8N00<0DD4M0510701@@1`00P1F@b<01P1GA2@0FDHV05Y79`1KB2P0G4TY05e::P80
GT`T00@0GddU061>9P1RD2P0He4Y0P1TDRX0101RD2P0HDlW065?9`1QCbL2061>9P80GddU00@0GDdY
05a<:01LC2P0G4`X0P1KBbL205Y:9P80F4PW0P1GAbH01`1FARD0EDDT05A48`1DA2<0ETLX05E69`1B
@b@00P1@@B800`1A@R<0Dd@U05A59P02059390<0E4DV00/0DT<T05118P1?@240CD0N04i17`1=@R80
C4<T04U29@16@B@0A3hT044m8P08040l7`0803`k7`0m?200?C`P03hm8@0m?200?3/O03/j7P0j>Ad3
03Pj8P<0=cTQ0P0f>2002@0b=1h0<cDO03<e7`0c=Al0=3HP03<e7`0b=1h0<C<M030b7002030c7P<0
;c8M0`0^<A`302`_7P80:bhM0`0Z;A`802HY7P8092LN00@08bHM028U700Q91/08B@K0P0P8aX201`S
6`806b8J0P0J8AT201TP60806R0L0P0I7a/301PN6P0301LM6@0F71X05Q`J00H05Q`J0P0G7A/201HL
6P805A/I4P0D6QP801<I6@P05QPG200F5aT801HH5aP05AHH200F5aT901DF60P05QLI400F61L801DF
60P05QPG4P0F5aT301DF60<051DG<00E5QP801DG5PP05aPJ6@0F5aT801HH5bP05aTH400I6aXH01XL
6@0401`N6`0K7AX06adJ01/M6P806Q`I0P0I6aP@01XL6@P06A/H200I6aX801/K6@P071`J2@0M7A/2
01`L6P<07AdK0`0N7Q`301lP6P<0824K0P0Q8Q`802DU7@80:2@K0P0Y9A`302XV7@0302/W7P0]9a/0
;BLK0080;RPL0P0_:Ad2030Z7P0402`V6P0]9a/0;bTM034[7`80<R`P00<0<B/O030Z7P0c;B401`0c
;B40200`;200;b/O030Z7P0`:1d0<RPN03DX7`0h:R40>B/R200`:Qh402lY7@@0;RPL0`0a:al2030Z
7P<0;bTM0`0[9a/202XV6P<0:BDI0P0V9Qh0100U9Ad092@L02@T700U9Ad202HV7P<08b8M0P0T8ah3
02DT7`P08R<M200T91`802<S6`808RPL00H092HK02LT6`0[91`0;b@N03<V800e9R4202dY80<0;RXQ
0P0]:B00100[9ah0:RHM02LW7@0W9ad302HV70<09BDK0`0T9Ad202<T70<08R<K0P0X91/202TU70<0
:RHM00<0:bLN02dY800/:1l00P0/:1l202/W7P80:RHM200V9Qh01P0Y:B40:2PP02LW7`0V9Qh092@L
02<S6`808R8J200T91`8028Q70<0824K0P0O81X301hO6@P07QhL200P8A/202HQ6`809b8L0P0X8ad2
02TT7P80:RHM0`0[9ah;02`X7`0602PZ700Y:Q`0:BXL02`Z7@0]:Ad0<2XN0P0a:Ah803<Y7`P0:BTO
0P0V:Ah00`0W:Ah0:BTO02/X7`0202dY800302lX800Y:Al0:BTO0080:2PN100W9ad0100V9Q`09BHN
02DV7P0U9Qh202@U7@<08b@L0`0R8a/202<T70<092DM200Y91h0100Y9A`0:RHM02XV7@0Z9Qd202/W
7P80;2PO200]:Ad302dY8080;2PO0`0[9ah802HV7P809bLM0P0X:1h302TY7`0402XZ800X:1h0:2PN
02PX7P80:BTO0`0Z:R0302@T6R_ooooo000Zooooo`80XGI10P2RMd800`2SN4<0Y7U40:AiA0040:Ej
A@<0Y7U40P2SN4<40:AjB080YG]90P2VO4X0202UOTL0Y7e60:AkA@2TND@0YWQ40:QiA@2YNTH0[7Y7
0P2WNDL20:QjB080ZG]90P2ZO4X01@2XOd/0Ygi:0:MnBP2VODT0YGa80080Y7]700T0XgY60:EjA`2V
NdP0Z7e:0:UnB`2ZOd`0ZGi;0:QmBP2WO4T0202YOT/00`2ZPDT0ZH180:QoB@020:ImB@030:QnC02Y
Odl0ZX1@00T0ZGm=0P2[P4d60:YoC0X0ZH1<0P2ZPDd20:^2CP80[8=?102[PTh40:Z1C@P0Zh5?0`2X
Pdh30:V4C`80ZXE@0`2[QU420:Z5D0<0ZHA?202XPdl20:N2CP040:J1C@2UP4`0Y7m;0:=nBP80XWe9
0P2QOD<0102QO4D0XGa70:5lA`2QO4P20:5kBP80VWE10P2IM4000`2HLcl0Ug8n09Ia?@0209Ia?@80
UG0l00D0U6lk099]>@2AK3P0TF`h091[=`0308mY>P0308iX>@2<ISL0RfDf0080RfDf0P2=I3P01P2:
I3L0R6<f08ES=@23Hc@0PV<d085R<`80OU/c00@0OEXb07aI<@1lFC40NeP`0P1jEbl307IF;@80MED/
0`1dE2/01P1dCRL0LTlY079?:@1aCbX0L4l/06i@;P80KE0`00H0ITd^06M=;01XCR/0JTd[06a>:P1_
CbT2071>:080KdlX00<0L50Y075A:P1cDb`00P1dE2d207EE;P0607=H;@1eF2h0MEP^07QH;`1jFC00
O5Ta0P1oFC84081M<`80PEhd0P22GcD00`2;IST0RVDh08YU>00408YU>00308]V>@2<ISL0S6Hg00H0
S6Hg202<IST208iU=`0408aV=`2;IcL0RfLg08UW=`80R6Pg0`2<ISL208]U=P<0RV@e0`28I3@308UU
=@80RVHf0P29HcH608YT=`P0QV4g00H0RF4]08UQ;P27HRh0QV8`08IR<P24HS@208=R=@80QV4d0`25
H3<308AO<PP0PEla0`21GS@3081M<`80Oe`b00<0O5X/07eK;@1nG2h00P1oGBl00`1nG2h0OE/]07eK
;@0407eJ<0@0O5T_00H0O5`c07]K<P1kFc80NUXa07UI<01hF2l207MG;P<0N5P_00<0MeL^07IF;@1f
ERd00P1eEB`01P1gEbh0MUH]07EE;01dE2/0Le<Z079B:@<0LE4X0P1aD2d0101^D2`0JdlZ06Q>:@1U
CBL206==9P06065=:P1PC2T0Gd/X05i:9`1MBBH0FdLT0P1JAR<01P1L@bD0Fd@U05Y3901G@R<0ET<S
05=38P80DD8Q00<0D40V04lo9@1??bD00P1>?R@204dm8`0404`l8P1<@2H0C40V04a09P80BclU00@0
BShT04Tm8`18?280Ac/Q1016>R0304Di7`03040h8`0o=b80?CDP00<0>c<N00X0?3@O03de800m<Qh0
>c<N03Xb7`0h<Al0=S0P03<`8@0b<240<BlR1@0/;Al202//7P0602X[7@0X:Ql0:2XO02LY7P0V:1d0
9BLL0P0T9Q/00`0S9AX08RDN028U7P06028U7PP092DO200T9Ad302HW7`D09BHN1P0R8a/202<T70<0
92DM0P0U9Qh302HW7`80:2PN00H0:BTM02TZ700Z:a/0:b`J02`]6`0/;QT202/]600802l^6P0a;Q/0
=C0M03Pa7`0i<R00>c8Q03Xe8P0g<Ql203<^6`0303D`7@0g<Ql0=S4N0080=2lL0P0]:al0100/:Qh0
:bTM02TW6`0X9QX202LU6@0602XU7`0Z9Qd0:RHM02/W700[9a/0;2TJ0P0/:AP202/_800302`^800/
;Al0;R`O0080;b/O00@0<B/O02@T600W9a/0;2`P0P0_;b<00`0/;200:2PL02DU6@0202`/800402/[
7`0Z:Qh0:BTM02PX70809bLK200X:Qd0100X:1h09bLM02LW7@0W9ad202HV70809BDK00h0:RLP02/X
8@0[:1l0;2XN02d[700_;Q`0;bhJ030_6`0e;1/0=RdL03L_700i<Ah0>S8M03`d7@80?CHL0200@S<L
04<e6`14=Q`0ASPM04Pj7@1:?Ad0C3lM04e07P1IBBL0F4PV05Q8901IBR<0Fd`S05i?9P1PDBH0HU<X
06I?9P1WD2L0Je@[06mH;`1cG3<0MUlf07UR>@1jHcX0LehY07EQ;01jIS<0OF/i081_@@20LTD0Og96
07iaA@80Q6Lm00h0PfPm085V>`1oI3T0NV8f07MO<`1fGS80KDh_06Y;;01TAbT0GD8U05Xo901G?B@0
EShT05Lo9`80AchQ0P18?b801017?R40ASdP04@k7P13>Qd204Pk:P0604Tl:`1:?B`0Bch]04`o;P1=
@2l0CT4`201=A2L804e29P80AcdR0P18?R<02P19?b@0BT0U04]19P1;@BH0C48W04Ll9P18?BL0BClV
04Y09@1<@bH204e49@0604i59016?b<0ASlS04M09018@BD0BD8V0P1:@bL00`1;A2P0CdHY04m6:@06
04m6:@80Dd</00L0E4@[05E5:`1FAbX0EdPY05Q9:01IBRT0GDXY00<0GT/Z0P1OC2/2061=;0<0FDTW
00<0F4PV05M79@1FAR@00P1DA2800`1E@al0E48N05=17@030590700:05=17@1D@Qh0ET<R05M48`1H
AB@0FTLV05]89`1MBRT0GT/Z05m<:`80H4hV00@0HDlW069@:01RD2P0He4Y0P1TDRX3061A:080Ge0W
0`1NCbH205e=:@80G4`X0`1KBbL01@1JBRH0EdLV05M79P1GAbH0ETHU0080EDDT0P1DA2<00`1GB2T0
EDHW0593900204m08@0505118P1CA2D0E4DV05138`1AA2@00`1BABD02`1@@b<0CT4Q04e0801=@1h0
CT4O04a18@1<@b@0BD8U04I19013?B<0@CdR00P0@3`O0`0m?20203`k7`80>cXN00<0>STM03Xj8P0j
>R801P0i>B4503<e7`80<S@N0P0a<ad2030c7P<0;c8M0`0^<A`302`_7P80:bhM0`0Z;A`302LZ7`@0
9RTN00L09BPM02@W7P0T9ah08bHM028U700Q91/082<J00807b8I0P0L8a/201/R6P806R4I0P0I81P3
01TO6`<061hJ0P0G7AT801HL6P805adK0P0F71X201DK6A8051XH200C6AT801HH5`P05QLI200F61LH
01DF60P05QLI2@0E5QP801HG6A005QPG200E5QP801HH5a805QLI0`0E5QP301@E5c005AHH200E5aHQ
01HG6@P05QPG:00G6AP@01TK6QP06Q`I0`0K7AX201XL6@<06A/H400J71T801TK60P06A/J200K6aT8
01`L6PT07AdK0P0L71X301dM6`<07QhL0`0O81X3020Q6`808B8L200U9Ad302PT6`80:BDL0`0Z9Qd2
02dW6`80;RPL0P0_:Ad2030Z7P0602`V6P0^:1`0<2XN034[7`0b;200<B/O0P0`:Qh803<]8@0802l[
7`0^:Qh0;bTM02lW700a9ad0=2LN03LY800h:R48030Z7P0402dW6`0^:1`0;RPL02hX70<0;bTM00<0
<2XN038/800b;2000P0a:al3030Z7P0402lY7@0Z9Q/0:RHK02XV6`<0:BDJ0P0X91T302DU7@8092@L
0`0U9Ad402<R7@@092<N200Q8Q`802@T70P08b<K00P09BPM02DW700U9A/09b@K02TU700]91d0<2DO
034V80@0;RXQ0`0]:B0202`X7`809bLM0`0V9Q`302DU6`8092DM0P0S91`2028S6`808B8J0`0W91/2
02PU70<0:BHM00@0:bPO02XW7P0Z9ah0:RLN0P0Y9Qd202PU70P09RHN00H0:2PP02LW7`0V9Qh09BDM
02@T700S8a/2028R6PP092@L200R8A`2020Q6`<07b0J0`0N7aT801hN70<07b0J100P8A/00`0Q8Q`0
9R4K02HQ6`0202LR7080:2<M0P0Y91h602/W7PX0;2PO00H0:2XL02TZ700Y:Q`0;2XM02dY7@0_:Ad:
034Y7PP0:BTO0P0U:1d01P0W:Ah0:2PN02/X7`0/:1l0;BTP02lX80<0:2PN0`0W9ad302HV70809BHN
0`0T9Ad302<T70808B8J0P0R8a/202<T708092DM200Y91h202TU70<0:RHM0`0[9ah802/W6`80;BTP
0P0/:1l202/W7P80:RHM200V9Qh302PX7P80:BTO0`0Z:R0402PX7P@0:BTO0`0T91X[ooooo`00:_oo
ool20:1e@0060:5f@@2RMd80XgQ30:AiA02UNTD0YW]60P2UNTD30:AiA0<0XgQ30`2SNDL30:AjB080
YG]900P0YGi70:AmAP2SNT@0XgQ30:Eg@`2WN4@0ZGY60:ajA`80YGY70P2VNdP20:MlB@80Z7e:00D0
Z7m;0:MnBP2WOTX0YWe90:ElB0020:AkA`090:=jAP2UNTL0YW]80:QmBP2YOT/0ZWm<0:UnB`2XODX0
Yga900P0ZGi;00<0ZX590:QoA`2WOTP00P2VODT00`2WOD/0Z7i>0:Z0D0090:UoC@030:UnB`2ZOd`0
ZWm<00<0Zh1=0P2ZOd`:0:V0C080ZX5=0P2[PTh20:b3C`@0ZX5=102[PTh80:^1C`<0Z8=>0`2YQ4l2
0:Z5D0<0ZhIA0P2ZQE030:V4C`P0Z8=?0P2XPU40102WPE00YX1?0:EoCP2TOTd20:=mC080XWi400@0
XWe60:9mB02RODP0XWe90P2RO4/209]f@P0409Ye@@2IM400V7<o09Qc?`80Ug8n0P2FLCd0102EL3`0
U6lk09A_>`2CKSX2099]>@03095[?02@JS/0SVPi0080SVPi00<0SFLh08aV=`2;ICH00P2>HcP0102<
HcL0RV@g08QS=P25HcD208=S=005081M=@1oG3@0Oe`d07iK<`1lFC400P1kF300101jEbl0MeL^07MG
;P1gEbh207IF;@<0MED/00H0MDlX07=@:P1cD2X0LU0[075@;@1_DBl206iA<@0606M?;@1YCb`0JDl/
06]?:P1/CRP0KdlX0P1`CbH2071@:@80LE4Z0`1bDR/207=C;009071H;01bEb`0LeP]07EH;P1hF2l0
NUT`07]H<01lFC40OU/a0080Oe`b0P20GC<3085N=0<0RVDh0P2;IST308YU>0P0S6Hg202<IST208iU
=`0408aV=`2;IcL0RfLg08UW=`80R6Pg0P2<ISL208]U=P80RV@e0P29Hc@208MS<`<0R6@d0`29ICD2
08YT=`H0RF<f2026HCL01P29HBd0RF4^08MR;P26HS00QV8b08AR=080Pf8e0P26HC@308EP<`<0Q5lb
2020GS43085N=0<0P5dc0P1oG3800`1mFbd0OU`^07mM;`0207mM;`0307iL;P1mFbd0O5X/0080OU/a
0P1mFS0207aI;`80NeP^00H0O5`c07]K<P1kFc80NUXa07UI<01hF2l207MG;P0307QH;`1gEbh0MeL^
0080MeL^0`1fERd0101gEbh0MUH]07IF;@1eEB`207AD:`<0Le<Z0P1bDBh0101_DBd0K50[06U?:P1V
CRP206A>9`80Hd`Z00`0HT/Y06199`1OB2H0GTLU05e6901LAB<0GD@V05a59P1KA2D0F4<T05I38`1C
@b8205528@@0CclU101>?R@00`1<@2H0BclU04/o9@0504Xn90<0B3`R00<0Ac/Q04Hj8016>R000P15
>Al04`10>2<0?cLR03de800l=1l0>c<N03`d7`0m=B00?SHQ03hc7`0l=1l0>c<P03Tb800g<B40=34R
03<a8P0b<2<0;c0R02h_8@0];R000P0/;Al302//7P0602T[800X:Ql0:2XO02LY7P0V:1d09BLL0P0T
9Q/802<V7`P08b@N200T9Ad502DV7P<09RLO0P0S91`6028S6`808b@L0P0T9Ad202DV7P809RLO0P0W
9al05@0X:1h0:BTM02X[7@0Z:a/0:b`L02//6P0X:aP0:B`I02//6P0_;Q`0<RlN03D_7`0g<B40>34Q
03Td8@0e<1d0<B`I03<^6`0h<b00>cHS03Pc800203D`7@0@034]8@0`;200;b/O02hZ7P0/:1`0:bLK
02XV6P0Y9AT0:B@N02TU700Z9Qd0:RHK02/W6`0[:1T0:bPG02`Y6080:RhO00<0;2hP02d^800_;B00
0P0`;2001@0b;200:BXL02X[7@0/;Al0;BhP0080;c0R0P0`<B<2030^8@0402l]800^;1l0;B/N02d[
7P80;2XM200Y:ad0100X:1h09bLM02LW7@0W9ad202HV70809BDK00D09bLM02PX700X:1`0:BXL02X[
7@0202//700A02`]7@0a:A`0<RXM03</700d;A/0=BhK03H_700g<A/0>38L03db800n<al0?c@P044f
8012>1l0A3XO04Dl7`16?B000P1@?b<01P1@?b40DD4P05=38@1EAB40F4PT05Y;9080H4`W01h0HThY
06A@:`1VDRd0JED`06]G<P1/F3<0KELU06iJ:01bGR`0Lf4a07=S<P1`HS<0KF4a06aP<025JS/0QV/l
08Q]?P2;Kd00S71108]_@02;K3h0RV/m07eJ=01nFcD0OE/f07]J=`1fF3H0L5<c06]>;P1WC2h305U<
:P0505M::01DAbD0D4<Q04`o7@1:?A/00P1>?b`204m0;@80D44^0P1A@Rl804i5:0P0CD8V0`18?b82
04U08`0404Y1901;@RD0C4<V04a39P80B3dW00H0BClV04Y09@1;@RD0CD@U04i59P1?ARD204e49`03
04i5:01?ART0D4LZ0080DDP[00<0DTT/04a5:01<ABP01P1<ABP205I6;`0405M7;P1GAbd0F4T/05U:
:`80FT/Z00@0ET<S05M4901GA2@0Ed@T0P1HABD205U69P0305=38P1B@R40DD4P0080D40O0`1??ah0
0`1IAB80F4@Q05M3800205M3800;05Q48@1IAB80FTHS05M58@1HAR80FDLS05]99@1MBbL0GddY061>
:P1QCb/0201RD2P2061A:080Ge0W0`1NCbH00`1MCRD0G4`X05a<:00205];9`<0FTXV00@0FDTU05I6
9@1FARD0ETHU101EAB@0101DA2<0EDHW05A59P1A@R<204m08@0505118P1B@b@0Dd@U04e28P1>@b<0
0`1?A2@02`1=@R80C44Q04Xo7`1<?ad0CD0N04a18@1;@R<0B44T04E08`13?B<0@CdR00P0@3`O00<0
?C`P03`k7`0l>al00P0k>Qh303Xi7@H0>SPQ0P0k>B80100d=R00<cDO03<e7`0c=Al2038d7P<0<C<M
0P0`<ah302lb7@<0;S4L0`0/;ah202/^7@<0:RdL0P0X:b0202LZ7`0402HY7P0U:1d09BPM02DX7@80
8bHM00@08RDL024T6`0Q91/082<J0P0O8QT201`S6`806b8J0P0J8AT201TP60806AlK0`0H7QX301LM
6@P05Q`J0P0G7A/201HL6P805A/I4P0D6QP801<I6@P05QPG200F5aT801HH5aP05AHH200F5aT901DF
60P05QLI400F61L801DF60P05QPG4P0F5aT301DF60<051DG<00E5QP801DG5R405QLI200F61LX01LI
61006A/J600J71T201/M6P806Q`I0P0I6aP201PJ5a006Q`I200I6aP801TK6PP06a/I200L71X901dM
6`8071`J0`0M7A/301hN70<07b0J0`0P8A/2024R70P09BDM0P0W8aX202PT6`80:BDL0P0Z9Qd202dW
6`80;RPL0P0_:Ad2030Z7P0802dW6`0^:1`0<2XN034[7`0b;200<B/O030Z7P0_:Ad8038/800802hZ
7P0]:Ad0;RPL02hV6`0`9Q`0<bHM03HX7`0g:B08030Z7P0402dW6`0^:1`0;RPL02hX70<0;bTM00@0
<2XN034[7`0a:al0<B/O0P0`:Qh302lY7@@0:BDL0P0X91/202LS6P<092@L0P0U9Ad302@T70P08b8M
200Q8Q`@02<S6`0802PX7P0W9ad0:2DL02LT6`0X91/0;2DM02dV7P0_:20202hZ8@80;BTP1@0/:1l2
02LW7@<09RHL0`0U9A/302<T70808R<K0`0Q8QX202@T6P809BDK0P0V9Q`202LW7@80:2PN0P0W9ad3
02HV700302DU6`0V9Qh09RHN00P09RHN0P0U9Ad0100T91`08b<K02<S6`0R8QX802<S6`P08R4L0`0O
81X301hO6@807AhH200M7A/201hO6@807b0J00@0824K024R700Q8Q`08B8L0P0V8A/202LR7080:2<M
0P0Y91h202`X7`h0:bLN00H09bTK02PY6`0Y:Q`0:bTL02`X700_:Ad2030X7@P0;bTM200X:1h202DX
7@0302HX7@0X:1h0:RLN0080;2PO00<0;RLO02PX7P0X:1h00`0W9ad402HV70<092DM0`0S91`2028S
6`<08B8J0P0R8a/302<T70P0:B@N0`0Y9A`302XV7@80:bLN200Z9QX302`X7`80:bLN0`0Z9Qd802HV
7P0402LW7@0X:1h0:2PN02PX7P80:BTO0P0Z:R0802PX7P<09bLM:oooool002[ooooo00H0Wg@o0:1e
@02QMT40XWM20:=h@`2UNTD20:IkAP040:EjA@2TND@0Y7U40:AiA080XgQ30P2RMd830:9hAP80XgU7
0`2TNTP0202TODH0Xga50:=jA02SN4<0YGM30:MhA02XNDD0ZgU60P2TNdL20:ElB080YWe90P2WOTX4
0:ImB@@0YGa800P0YGY70:IkB02XODX0ZGi;0:YoC02YOT/0Z7e:0:MlB@P0ZGi;00<0ZH180:QoA`2W
OTP00P2VODT00`2WOD/0Z7i>0:UoC`090:UoC@050:QmBP2YOT/0ZWm<0:^0C@2/PDh00P2[P4d00`2Z
Od`0ZH1<0:V0C0080:V0C080ZX5=0P2[PTh20:b3C`040:V0BP2ZPD/0ZX5;0:Z1B`<0Zh9<00<0[8==
0:^1C`2[PDl01P2[PDl30:R3CP<0ZHA?0P2ZQE030:^6D@80ZXE@0`2YQ4l80:R3C`060:V3E02XPU<0
Z89C0:N1DP2VP540YGm@0P2TOTl00`2TP4H0Xgm50:=nA`020:9mB0030:5lB02QNdX0XG]:0080W7M3
00<0VgI209Ye@@2IM4000P2HLcl0102GLSh0UW4m09Ia?@2FLCd209E`?0<0U6lk00T0Tfdn091Z>`2>
J3T0SVPi08mY>P2@JS/0SFLh08YT=@2?HSP00P2=HSL00`2;HSH0R68e08IQ=00208=Q<`80PEhf00H0
P5de07mL=01mFS80O5Ta07]H<01jEbl307QH;`80MeL^0`1fERd02@1gDBX0ME8/07EB;01cDB`0LU4^
06mA;`1^DC40KE0`06UA;@0206Y@:`0306a@:@1]D2P0KdlV0080L4lT2@1aDBX01P1^Eb/0KeL[071H
;01bEb`0M5L]07MG;P80NEP_00<0O5T_07eJ<01oG3800`20GC<207mL<P0308QS=P29I3L0RVDh0080
RfHi00<0RVDh08UT=`28HcH0202;ICH808eW>P80SfHh00@0SFLh08]W=`2;IcL0R6Hf0P27IcH308]U
=P80RV@e0`29Hc@308MS<`80R6@d0`29ICD208YT=`<0RF<f0`28HSD808IQ=`0608QP;028H2d0QV4]
08IR<026HS80QF<e0P24HcH208IQ=0<0QF0c0`24Gc88081M<`<0PEhd0`20GC<207mL<P80P5h`00<0
Oed_07iL;P1nG2h00`1nG2h01@1oG380OU/a07iK<@1mFS00O5T_0080NeP^00L0NUL]07aL<`1kFc80
Ne/b07YJ<@1iFC00N5P_00`0MeL^0P1fERd207EE;0<0M5@[00H0Le8_079A;P1_DBd0KE4/06Y@:`1W
CbT206E?:00606E=:`1TC2X0Hd/Y069::01PB2H0GdLU0P1NAR@01P1MA2H0G4DV05]49@1H@b@0ET<S
05A48`80DT<R201??bD00`1;?bD0BShT04Tm8`0204Pl8P0304Tm8`1:?R@0BclU0080BShT00<0BCdS
04Pl8P17>b400P16>R001015>Al0@CTT03lg8P0n=R4303`d7`0>03de800n=R40?c@P03de800l=240
>S<Q03Pb8P0e<R<0=38S03<a900a<R@0<34S02h_8@0];R0402`]7`80:B/P00<0:2XO02LY7P0V:1d0
0P0U9a`00`0T9Q/08bHO02<V7`0602<V7`P08b@N200T9Ad202<T70<092DM0`0U9Qh302<T70<08R<K
0P0Q8QX302<T708092DM0`0U9Qh202HU800E02LW7`0X:1h0:BTM02X[7@0Z:a/0:b`L02L[6P0X;1/0
:RdL02`]7@0_;Ah0<BhO038_800e;b40=S4N038]6P0`:aP0=C0M03`g900o>RL0>SDR0080=2lL0P0e
;b401`0d;R00<R`N034[7@0`:Q`0;bTK02hX6P0Z9Al00P0Z9Qd00`0[9a`0:bLK02`Y6P0202`Y6080
:BdN00<0:bdO02`]7`0^;1l00P0`;200100b;200=3DU038c8`0_<20202d^7P0402h_7`0_<200<C8R
03@a8P80<c0Q00<0<RlP034^7`0`;Ah00P0_;1d802X]7080:BTO0P0X:1h202LW7@809RHL0`0W:A/2
02PZ7080:B/M00T0:R`N02hW7@0_:1h0<2XN030Z700b;1`0<RdJ03<^6`0d;a/00P0k<R<03P0l<b80
?CDR03hf8`0o=b80?cLP040h8@19>B80B3PQ04Ph7`19>Al0Bc`O04ho801A@R40DT<R0P1IBBD205Q8
900M05U99@1KBbL0GDdY05i>:P1ZDbX0JE<Z06YD:`1XEB/0IeH[06AE:P1QE2P0H5<W06mM:`1dH2h0
N6@b07iX=`21JCT0Q6Tj08AX>@23IcP0QV@f08QV>@2:JC`0RV/o08IY?`21ICd0Nelh07IM=@1ZFc@0
0P1[G3D01P1ZFc@0IUL`065B:`1LCBH0FDXS05Q8;P<0EdL]0P1FAR`205E5:`80DDP[0`1@AbX304m6
:@P0CT<W0P1:@B@304]29@@0C4<V00P0C44[04]0:P1;@BP0Bd4V04a39P1=A2D0CdHW05179P<0DTL[
0`1CB2`205A9;@P0Bd@W00H0E4@]05E5;P1EAB`0ETH/05I7:P1GB2T205M89`<0D3dO0P1A?R03058o
8@0304ln801>?Al0CC`N0080C3/M00D0CC`N04hm7`1??R00G4DS05e6900205i79@@0GdPV0P1JB280
1P1KBB<0GD/U05i<9P1OCBL0H4hX065?:@<0HU0X0P1QCbL3061>9P<0GE0V0P1LCbD305]>9080FTXV
0P1IBBD305Q8900305M78`1EAB@0EDDT00H0EDDT101B@b@205528`80D44R00<0Bd8Q04a38P1=A2<0
0P1=A2<02`1;@R40BT4P04Po7P1<?ad0CD0N04]0801;@R<0B44T04E08`13?B<0@3`Q00P0@3`O00D0
?C`P03`k7`0k>Qh0>STM03Th700203Xi7@0303/j7P0k=R00>cHP00<0?3LQ0`0m>280100e=b40=3HP
03@f800b=1h3034c7@80<S@N0P0`<ah302lb7@<0;S4L0`0/;ah202/^7@<0:RdL00H0:B`Q02P[800X
:b009bXO02HY7P0U:1d202@W70808bHM00<08RDL024T6`0P8aX00P0O8QT00`0N8AP072<K01`S6`02
01/R6P806R4I0P0I81P0100I7a/061hJ01PN6P0H7QX201LM6@805Q`H200F71X201LM6`805Q`J0P0E
6aTB01@J60P04aTI200F61L801HG6@P05QPG600E5QP801HG6@T05AHH200F5aT@01HH5`P05AHH200F
61LB01HG6@<05AHH0`0D5AL`01DF60P05ALF200E5QPI01HG6@P05QPG:00G6AP@01TK6QP06A/H0`0J
71T201TK60<061XG400J71T801TK60P06A/J200K6aT801`L6PT07AdK0P0L71X301dM6`<07QhL0`0O
81X3020Q6`808B8L200U9Ad302LS6P80:2@K0`0Y9A`202dW6`80;RPL0P0_:Ad2030Z7P0302hX700_
:Ad0<2XN0080<R`P00<0<B/O02lY7@0^:1`0200`:Qh0200]:Ad0;2PL02dW6`0]9AX0;bDK038U700e
9ah0=RPO200`:Qh402lY7@@0;RPL0P0`:Qh202lY7@<0;RPL00<0;BLK02TT7P0X8ad00P0X8ad202LR
70809R4K0P0S8a/0100T91`09BDM02DU7@0T91`202<S6`0402@S7P0S8Qd08b8M02<R7@<08R4L00<0
8B0K020Q6`0P8A/01P0P8A/@02<S6`0302`X7`0[9ah0:BDL0080:2@K00H0:BDL02/W7P0/:1l0;RXQ
02dY800[9ah402XV7@80:bLN0P0W9ad302HV70<09BDK0P0S91`2028S6`<08B8J00@0824I02<U6P0S
9AX08bDJ0P0T9Q/302DW70809RPM0P0U9a`302@V6`0302<U6P0U9Ad09BDM00T09BDM0P0T91`202<S
6`03028R6P0S8a/08b<K00H08b<K200R8A`301lP6P807QlI0`0M7QP801dM6`0601dN600N7aT07QlI
01lP6P0P8A/08B8L0P0R8ad202HQ6`809b8L0P0X8ad202TT7P<0;2PO0`0[9ah202XV7@P0:bLN00H0
9bTK02PY6`0X:A/0:bTL02`X700_:Ad2030X7@P0;2PL200X:1h02@0T9a`09BPM02HX7@0W9ad0:RLN
02/W7P0/:1l0;RLO02PX7P0302LW7@809RHL0`0U9A/302@U7@808b@L0`0R8a/0100P8AT08B8J024R
6P0Q8QX2028S6`808b@L200X8ad202PT6`80:BDL0`0Z9Qd00`0[9ah0:RHJ02XV6P0602XV6P80;2PO
0P0[9ah302XV7@0302TU700U9Ad09BDM00H09BDM0`0V9Q`202LW7@<0:2PN00@0:BTO02PX7P0X:1h0
:2PN0`0W9ad0100V9Q`0:BTO02TY7`0Y:Al[ooooo`00:_ooool209md?`060:1e@02RMd80Y7U40:Ej
A@2VNdH0Yga70`2TND@20:=h@`<0XWM20`2QMdD20:9hAP<0XgU700P0Y7e60:=lA@2RND<0XWM20:Af
@P2VMd<0Z7U50:]iAP80Xg]70P2TO4P20:EmB@80YWi:102UO4P40:ImB@080:EjA`2VNdP0Z7e:0:Un
B`2ZOd`0ZGi;0:QmBP2WO4T80:UnB`030:V0B02XOdL0YWe70080YGa800<0YWa:0:QnCP2YOdl02@2Y
Odd00`2WO4T0Z7e:0:YoC0030:b1CP030:^0C@2ZOd`0ZH1<00T0ZH1<0P2ZPDd20:^2CP80[8=?0P2Y
P4P20:Z1B@80Zh9:0P2/Pd/80:^1C`<0Z8=>0`2YQ4l20:Z5D0<0ZhIA0P2ZQE030:V4C`P0Z8=?0P2Y
Pe@20:R2D`0:0:N1DP2VP540YGm@0:EoD02UPDL0Y8160:=nA`2RODP0XGa709mjAP80WWQ70P2MN4@0
0`2LMd<0VgI209Ye@@0209Ud@00309Qc?`2FLCd0UW4m0080UW4m102EL3`0102EKd00TF/l08eW>02>
J3T2095[?00808iX>@2:I3D0SV4g08eP=P2<HCH0Rf0e08UP=026H3<208AO<P0808=P>022GcL0PEhf
07mL=01nFc<0O5Ta07]H<01jEbl207UI<080N5P_0`1gEbh04P1fERd0NU@]07MD;P1fDbd0M58]079A
;P1_DBl0KE0`06a?;`1YDB/0JU0[06YA:@1/D2P0KE0V06m@901`Cb@0L4lR079B:`@0LE4Z101`D2T0
2`1/EBT0KEHZ06mG:`1aER/0LeH/07IF;@1gEbh0N5L^07]H;P1lFBl0OU/a00<0P5dc00D0OU/a07eJ
<026HC@0Qf8e08UT=`0208YU>00308UT=`27HSD0QV4d00P0RfDf202=IcX00`2@IcT0SfHh08eW>002
08]W=`0308QV=P27IcH0QVHe0080RfDf0P2:I3D408US=080QV8b0P27Hc<308QT=00308UU=@2:I3L0
RV@g0080RF<f0P28HSD208MQ=0P0QV4g00P0Qel[08QP;@26HBd0QV8`08IR<P25HcD0Q6<f08ET=`80
QV4d0`25H3<308AO<PP0Oe`b0`21GS@3081M<`80Oe`b00P0Pf4c085O<@1nG2h0O5X/07]I:`1mFbd0
Oed_081N<080Oe`b00@0OU/a07eJ<01lFBl0NeP^0P1jEbd01P1lG3<0Ne/b07]K<P1jFS40NET`07QH
;`80MeL^0P1fERd907MG;PH0MUH]00P0M5<`07=B;`1`DRh0KU8]06Y@:`1XD2X0IU0Y06E?:080IT`[
00@0ID/Z06=9:01RB2L0H4HU0P1OAB@01P1NABL0G4DV05a59P1IA2D0Ed@T05A48`80DT<R1@1??bD3
05109P0304Tm8`18?280Ac/Q0080ASXP00<0Ac/Q04Tm8`1:?R@00P1;?bD02@1:?R@0BCdS04Pl8P17
>b40ASXP04Di7`11>B@0@3PS03hf8@0203`d7`0?03de800n=R40?cLR040e8@0m=B00?CDR03/d8P0i
<b<0=S<T03@b8`0d<RD0<c@V034b900_<280;BhP00<0;2dO00<0;BhP02T[800Y:b000P0X:Ql0100W
:Ah09RPM02DW700U9a`802@W80P08R<M200T9Ad2024R6P808R<K00<08b@L02@U7@0T9Ad00`0T9Ad2
02<T7004028S6`0Q8QX08B8J024R6P@08b@L0P0T9Ad202DV7P0>02DT800U91l09RDP02LW7`0X:1h0
:BTM02TZ700Z:ad09RdK02P/6`0Y;A`0:RdL02`]7@0^;1d2030]7P0703<^6`0`:aP0<2/H03Lb7`11
?2T0@SdZ03Xe8P02034/6@0403Pa8@0g<200=c0P03H_7`80=BhN0P0d;Ad01P0[9R00:bLN02`X7`0/
:1d0;2PL02dZ6`80;BXI00D09b/L02P/7@0Y:ad0:b`N02d[7P0202l[7`06038/800a<R00<C8P030a
7`0_<1h0;RlM0`0];Q`203Db8@0603@a800c<1l0<RlN038_7P0a;Qd0<2dL200[;Q/302XZ8080:BTO
0`0X:1h302L[6P80:2`M0P0X;1h02@0X:b00;2LQ02`X7`0]:B00;BTN02hZ7P0_;1d0;b`K030]7002
03H`900403H`8P0g<B<0>38R03Pc8080>C@P0P13=2402013=1l0A3DN04Hh7P19>b00BcdR04do8P1B
@b80DD8Q0P1@@B001@1A@R40Dd@S05E69@1GB2L0H4H[0080GdPY01L0GTXY05i;:P1NCRX0H58]065C
;P1JDR40GeDT06EI:@1]G2h0LEla07AM<@1dG300LUX^07eO:`1lHB`0OF4_07aR<@1jHS80N68c07MR
<`1fHC@0K5/`06iM<P02071O=00:06mN<`1[FRl0IeH[06AC:01QDbh0H58]05mA;01ND2/0G4hY05]=
:080FD/V00<0E4/^05=:;@1CBRd00P1BBB`20558:`030517:P1@ABT0D4DY00H0D4DY101>ABH304e4
9@80C4<T00P0D4D_04m4;P1>A2/0CD<X04e49`1>ABH0D4LX05589`@0E4HY101CABP804Q39@80CclX
00@0CclV04lo9@1?@2<0D44R0P1@@B0304di7P80CSXO0`1?>b002`1??R80CSdQ04dl801=?200CSdQ
050o8`1B@BD0E4<W05Y38@1LAB<0GdPV0080HT/Y00<0HDXX05m89P1NAbD00P1MBb<205i<9080GddU
0P1PCRH01@1RD2P0HDlW065?9`1PCRH0GddU0080GT`T00@0GD/S05Y>901JCR@0FThT0`1ICB<205Q<
8P0405Q8901GAb<0EdLS05M78`80ETHR0P1EAB4405A48`@0EDDT00<0Cd0Q05528`1CA2D00P1DABH0
2`1B@b@0Cd0Q04dn7`18@R00BD<Q04Y48P1;AB<0BT@R04U38@17@Al0AT0N0080C3lM00H0Bd0P04Y1
8P17@2<0A3lR048l8P10?248040l7`0803hm8@0l>al0>STM03Th700h=a/0>CPL03Xi7@0k>Qh303`f
800303dg8@0n>280?SPR0080?cTS00T0=CLQ03@f800d=R00<S@N034c7@0`<Q`0<C<M038d7P0c=Al0
0P0`<ah302lb7@<0;S4L0`0/;ah202/^7@<0:RdL0P0Y;2401`0X:b009bXO02HY7P0U:1d092LL02<V
6`0S9Qd00P0R9A`00`0Q91/082<J01lR6@0201hQ608072<K0P0K8QX201XQ6@806B0H0`0H7QX201LM
6@<05Q`H200F71X201LM6`805Q`J0P0E6aTB01@J60P04aTI200F61L801HG6@P05QPG600E5QP801HG
6@T05AHH200F5aT@01HH5`P05AHH200F61LB01HG6@<05AHH0`0D5AL`01DF60P05ALF200E5QPI01HG
6@P05QPG:00G6AP@01TK6QP06A/H0P0J71T201TK60@061XG400J71T801TK60P06A/J200K6aT801`L
6PT07AdK0P0L71X301dM6`<07QhL0`0O81X3020Q6`808B8L200U9Ad402LS6P80:2@K0P0Y9A`202dW
6`80;RPL0P0_:Ad2030Z7P0702hX700_:Ad0<B/O038/800a:al0<2XN02lY7@0902hX700802`X700[
9a/0;2HJ02dU6P0^91X0<RDL03@V7@0f:1l8030Z7P05034[7`0`:Qh0<2XN02lY7@0^:1`00P0]9a/0
0`0/9QX0;RPL02hX700202dW6`@0;2HJ0P0X8al202LR7P<09R4M00@09B0L028R6P0S8a/092@L0P0U
9Ad00`0T91`08b<K028R6P0202@S7P808b8M00@08R4L024P6`0Q81/08B0K200P8A/8028R6PP08b<K
00d0;RLO02dV7P0/9Ad0:2@K02LT6`0X9A`0:BHM02PX7P0]:B00:bLN02TU700X91/09b<J0080:2@K
00@0:BDL02XV7@0W9ad09bLM0`0V9Q`302DU6`<08R<K0`0Q8QX2020Q6@@08RDJ0P0S9Q/502@W7080
8bHK0`0R9AX802DU7@@092@L100S8a/8028R6PP08R4L00@07b0J01hO6@0N7aT07QlI0P0M7QP201`M
5`P071`J0P0M7QP01P0N7aT07b0J020Q6`0Q8Q`08R<M02<T7P809R4K0P0W8Q`202PS7@80:B@N0P0]
:B0202`X7`0302/W7P0Z9Qd0:RHM00T0:RHM00P09RPJ02LX6P0X:A/0:RPK02`X700^:1`0;bLL030X
7@P0:bTL200W9ad202@W700302HX7@0W9ad0:BHM0080:bLN00@0;BHN02LW7@0W9ad09bLM0P0V9Q`4
02DU6`0402@U7@0S91`08b@L02<T70808R<K0P0Q8QX2020Q6@<08B8J0`0R8a/802PS7@<0:2@K0P0Y
9A`302XV7@P0:bLK0`0[9ah302XV7@80:BDL200U9Ad202@T6P<09BDK0`0V9Q`202TY7`80:2PN00@0
9bLM02HV700V9Q`09RHL0`0W9ad[ooooo`00:_ooool0202NLch0Wg@o0:1e@02RMd80Y7U40:EjA@2V
NdH0Yga70P2TND@30:=h@`<0XWM20`2QMdD20:9hAP<0XgU700P0Y7e60:=lA@2RND<0XWM20:Af@P2V
Md<0Z7U50:]iAP80Xg]70P2TO4P20:EmB@80YWi:00D0XgY60:AkA`2TNdL0YGa80:ImB@020:MnBP09
0:QoB`2UNTL0YW]80:QmBP2YOT/0ZWm<0:UnB`2XODX0Yga900P0ZGi;00<0ZH180:QoA`2VODL00P2U
O4P00`2VO4X0Z7i>0:UoC`090:UoC@080:IkB02XODX0ZWm<0:b1CP2]PTl0[85>0:^0C@2ZOd`:0:V0
C080ZX5=0P2[PTh20:b3C`<0ZH1800<0ZX590:^2BP2/Pd/00P2/Pd/80:^1C`<0Z8=>0`2YQ4l20:Z5
D0<0ZhIA0P2ZQE030:V4C`P0Z8=?00H0ZXAG0:V3EP2YPeH0Z89E0:N1E02VP5<20:EoDP80YH5700H0
Xgi70:9mB02PNdH0WWU509egAP2LMTD209ehA00409ag@`2KMT80VWE109Ye@@80VGA01P2FLCd209E`
?00409I`@@2AJc`0SFLh08iX>@80TV`m00<0SVPi08YT=@2?H3H00P2<GcD00`2:Gc@0R5lc08EO<P02
08=N<@80Pf0h00@0PEhf081M=@1nFc<0O5Ta0P1kF30307UI<080N5P_0`1gEbh02@1lERl0NEH`07QE
;`1eDbh0LU4^06i@;P1/Cbl0Jdh^06YB;00206]B:P0306a@:01]D2H0Ke0T0080L4lR0P1bDR/2075A
:P<0L50Y0P1_CbP02`1[ERT0K5DY06eF:P1_Eb/0LUL/07AG;@1fERd0MeL^07YG;@1lFBl0OU/a0080
P5dc00H0Oe`b07iK<@1mFS00Q5lb08IQ=028HcH208UT=`0308QS=P26HC@0Q5lb00P0RfDf202=IcX2
091W>@0408eW>02;IcL0RfLg08QV=P80QVHe0P2;ICH208YT=@<0RF<d00<0R68c08IR<P26HS800P27
Hc<408QT=080RV@g0P29HcH01028HSD0Qf4d08MQ=026H3<808IQ=`0608MO:`27Gb`0QV4]08IR<026
HS80QF<e0P25I3L208IQ=0<0QF0c0`24Gc8807mL=0<0PEhd0`20GC<207mL<P0A08IT=P23HC<0OU`^
07]I:`1jF2X0O5X/07mM;`22H380P5dc07mL<P1nFc40OEX`07aI;`1kF2h0NUL]07UF;01lG3<00P1k
Fc800`1jFS40NET`07QH;`0207MG;P<0MUH]2P1gEbh407IF;@80M5<`00@0LE<_06iB;@1[DB`0J50Z
0P1VD2T206I<:`0<06E;:P1SBBP0HTPW06579P1PARD0GdDT05i59`1MARL0G4DV05U49@1GA2@0E4@S
0P1B@b8404lo9@@0D40V00<0BCdS04Lk8@16>R000P15>Al02@16>R00B3`R04Xn901<@2H0BclU04Xn
9019?B<0B3`R04Lk8@0204Hj800D044i9010>2<0?SHQ03de800l=1l0?CDP03hf8@0o=b80@3DQ03hf
8@0m=B80>c@R03Tc8`0f<b@0=C<T03@b9@0d=BL0<S<U02l`8P0];R0202`]7`0302d^800^;b40:R`Q
0080:B/P00<0:2XO02LY7P0V:1d00P0U9a`802@W80P08R<M200T9Ad2020Q6@808B8J00<08R<K02<T
700S91`00`0T9Ad202<T7005028S6`0Q8QX08B8J020Q6@0R8a/00`0S91`202@U7@809BHN0P0U9200
1P0V9B009bLO02PX7P0X:1`0:BTM02TZ70809bhN00<0:BdN02X/7P0[;1h00P0]:ah0200^:Qh0<2/H
02hY5P0`:aP0>C@Q04@o;015@2d0>cHS0P0`:aP403Pa8@@0=c0P00H0;2LQ02`X7`0/:1l0;BTN02dY
7@0^:a`202h[6P0@02HZ6`0W:a`0:2XL02X[7@0]:ah0;RXN02l[7`0a:al09BHD02PY5`0/;A/0;c0N
034b800`<Al0;RlM02d^7080>38R00<0=c4Q03H`800e;al00P0d;Qh00`0c;Ad0:bhK02/^6`0602/^
6`<0:b/Q0P0Z:R0302TY7`80:2dI00@0:2`K02P/7@0X;1h0:2`N0P0Y;24202`W8@0702`X7`0]:Ah0
;RXN02h[700_;1d0;b`K034]9002034]8P03034]8@0b;b00<RlN0080<c0M0P11<B401`11<Ql0@S<N
04@e7P16>1h0BC/Q04/m8P1;?Q`00`1:?A/07`1<?ad0Cd8P05958`1DAbD0Gd@_05a3;@1J@RX0Ed8W
05I29`1GARP0FDXY05]<:`1BD200EU8S05eF:01TFB`0IeP]06UH;@1ZE2/0J58Y06eD6`1[DQX0IU0G
06A?601TD1/0IUDQ06YH9P1/G2T0I54V06IC:01ZEb`00P1]FRl02`1[F2d0J5DZ06IC:01XFBh0IeP]
06IG;01SE2T0HE8W05m@9@1MCR<0G4dR00<0ED`_00<0E4/^05=:;@1BBB`00P1BBB`80556:P80DDPW
0P1@AbH03@1?ARD0CTDT04e48`1=A2<0C4<R05=8<P1BAc40CdD/04i4:@1=A2L0CTDV0517:01AB2L0
0P1CARH00`1BABD0DD@T05138`0204m28P0304i18@16@b@0AT<T00H0AT<T0P19>B801019>B00BCTO
04Tj7@1:>a`204Xk6P<0CCTN0P1>>Ql304lk800@0550901@?b<0CchR050o8`1A@2@0E4<W05M6:P1I
B2`0F40N05]38@1PB2H0Hd/Y06A<:P1RBRP0GdLU05a48PP0GddU0P1QCbL0101PCRH0GddU05i<901M
Bb<205a:8P<0FDdS0P1HC28305M;8@<0ETHR0P1EAB4305A480D0E4@S0`1EAB@00`1=?Ql0D44R05A5
9P0205I7:0050593901>?b00BS/L04Q28019@b400`1:A2802`18@R00Ad4O04Do7@1;?Q`0C3lM04]0
801:@B80Ad0S04@o8P12?280@3`Q00P0@3`O00<0?SdQ03`k7`0j>Ad00P0h=a/0100i>1`0>STM03/j
7P0k=Al203`f800303dg8@0n>280?SPR0080?cTS00@0=SPR03@f800d=R00<S@N0P0`<Q`00`0a<ad0
<S@N03<e7`02030c7P<0;c8M0`0^<A`302`_7P80:bhM0`0Z;A`202T/8@0302P[800W:Ql09RTN0080
92LL00<08bHK028U700R9A`00P0Q91/0100P8aX07b8I01hQ600N8AP201`S6`806b8J0P0J8AT201TP
608061hJ0`0G7AT301HL60P05Q`J0P0G7A/201HL6P805A/I4P0D6QP801<I6@P05QPG200F5aT801HH
5aP05AHH200F5aT901DF60P05QLI400F61L801DF60P05QPG4P0F5aT301DF60<051DG<00E5QP801DG
5PP05AHH6@0F5aT801HH5bP05aTH400I6aXH01TK60806Q`I0P0I6aP301PJ5`0301LI5P0J71T06Q`I
00h06Q`I200I6aP801TK6PP06a/I200L71X901dM6`8071`J0`0M7A/301hN70<07b0J0`0P8A/2024R
70P09BDM00@09R8I02LS6P0W8aX09b<J0P0X91/202TU7080;BLK0P0^:1`202lY7@80<2XN00L0;bTM
030Z7P0a:al0<R`P034[7`0`:Qh0;RPL00T0;BLK00P0;2PL02/W6`0/9QX0;2@I02hT6P0a91/0=2HM
03DW7PP0<2XN00P0<R`P034[7`0`:Qh0;bTM02hX700]9a/0;2HJ02/U6@80;BLK0P0/9QX202/U6@80
:R@H00@0:2<O02LR7P0W8Qh09b8N0P0V8Ad202DP7003024Q6@0R8QX092@L00809RHN00<092@L028R
6P0Q8AT00P0T8ah0100S8Qd08R4L028Q700Q81/2020O6PP0824K200R8QX802<S6`0;02lV7`0^9Ah0
;2DM02PT6`0W91/0:2DL02LW7@0X:1h0;2PO02XV7@0X91/00P0V8QT202LS6P0402PT6`0Y9A`09bLM
02LW7@<09RHL0`0U9A/3028S6`808B8J0`0P8AT0100Q91T08RDJ028U6P0R9AX202<V6`@092LL0P0S
9Q/3028U6P03024T6@0U9Ad09BDM00H09BDM0`0T91`502<S6`P08R8J200R8A`401hO6@807AhH0P0L
7AL801`L6P807AhH00<07QlI01lP6P0P8A/00P0R8ad00`0S91h09R4K02HQ6`0202LR7080:2<M0P0Y
91h202dY8080;2PO00@0:bLN02XV7@0Z9Qd0:BDL200Z9Qd01P0V:1X09bPJ02PY6`0Z:1/0;2PL02hX
7080;bLL200Z:1/802LW7@8092LL00<09BLL02LW7@0Y9Qd00P0[9ah00`0]9Qh09bLM02LW7@0302HV
70@09BDK100S91`2028S6`808B8J0`0P8AT2024R6P<08R<K200X8ad302PT6`<0:BDL0P0Z9Qd802`X
70<0:bLN0P0Z9Qd302TU70P09BDM0`0S8aT202@T6P<09BDK0P0Y:Al0100X:1h09bLM02LW7@0V9Q`5
02DU6b_ooooo000Zooooo`0809me@`2PMT@0XGM50:9hAP2SNDL0Y7Y80:EkB@2VO4X20:MnBP030:Im
B@2UO4P0Y7]70080XgY600@0XWU50:5hA02RNDD0Y7]70P2UO4P01P2TNdL0XWU50:5hA02TNdL0XgY6
0:9iA@80XGQ400<0XgY60:ElB02VODT0102UO4P20:AkA`80XgY600<0YW]60:MlA`2YOTT00`2[P4/0
0`2YOTT0Z7e80:V0BP020:QoB@030:MnB02VODL0YWe70080YGa600P0YGa40:ImA@2YP4P0Zh9:0:b3
B`2[PTX0ZX590:V0B0P0ZGi92@2ZPDd30:Z0CP<0ZGm=0P2XOT`00`2YP4X0ZX5;0:^2C0020:b3C@03
0:^2C02ZPD/0ZH1:00P0ZWm:0P2YP4`20:Z1C@80Zh9>0P2/Pdl20:^5F0030:Z4E`2YPeH0Z89E0080
Yh5D00<0YX1C0:V0C02YP4`01P2YP4`30:b2D080[H=A0`2^Q5880:^1D@@0Yh9=0P2VPD`20:F0B`0@
0:UoC@2XOT`0Yge;0:IlBP2UNdT0Y7Y80:=iA`2RN4H0Xgi:0:9mB@2QO4P0WgY609ag@`2JMD40VGA0
09Qc?`80UG0l0P2DKc/309=^>P06099]>@2BK3d0TV`m095[?02@JS/0SfTj0P2>J3T02@2=IcP0SfHj
08mV>P2<IST0RVDh08UT=`26I3H0QFDf08AT=@02085O<@80P5h`00@0Oed_07iL;P1mFbd0OE/]0P1i
ER`207UF;P0:07UF<01iEC40NEDc07UE<`1kE3D0N5@d07MC<`1dDC40LE0_06i@;P80Jdh/00P0Kdh[
06i=:P1^CBX0KTdZ06m>:`1bDBh0M5<`07IE<PT0KDl[00H0Le0Z07AA:`1dDB/0MU<]07MD;P1hEBl2
07UF<080O5Pd00<0OEXd07iK<`1oG3800P20GS400`21Gc40R6<f08MR=@0308EP<`0508IQ=028HcH0
RF@g08YV=P29ICD00`28I3@00`2:ISH0RfLg08eY>@0308UU=@<0RVHf0P2;IcL208]U=P80RV@e0`29
Hc@00`28HS<0RfDf08]U=P0608]U=P80S6Hg00@0RfDf08YT=@29Hc@0R68c0P27HC802029HSL0R64f
08IP<`26H340QV0_08QS;`2;IS80S6Lb2027HSD808IP<`0608QS>@27HSP0Qf8h08EP=P24GcD0Pehd
0P22GC<3081K;P80PE`_0`22GC0807mM;`80Oe`b0`1nFc4307eJ<080OU/a00L0OEX`07aI;`1kF2h0
NUL]07UF;01hEB/0OUT/0080O5X]00<0NeX_07YJ<@1hFc<00P1gFc@2081I<P0407mH<@1nEc00O5D^
07]D;@80NU</0P1iERh207QE;@80Me@/0`1fDb/03P1/DB@0KU<V06mD:@1`E2`0L5@]06iB;@1/D2/0
JTd[06UA;`1WCbd0I4`Z069::01QBBL0H4PV0P1QBBL0201Q@b40Gd8R05i18@1K@280F3lQ05Hn8P1C
?R<0DSdR0P1B?b400`1A@280D44R05138`0204m4900304m69@18?b80B3lR00H0B3lR201=?B<0201;
?Qh0BS`O04Ll7P15?1l0@CXN03li7`0n>200?3PO0P10>2<203lg8P0503hf8@0m=B00?CDP03`d7`0c
<R000`0b<Al2034`7P80<2lM0P0`9b800`0_:280;BPR02`Y8P0202TY8@0402PY8@0S:2408bPQ02<X
8@808RLP0`0Q9Ql0100R8a/092DM02HW7`0W:20202PY8@0302LX800V9al08bHM00L08bHM200Q91/4
02<V7@8092LN0P0U:1l402<T70@092DM0P0R8a/00`0S91`092DM02DV7P0202LX800302PY8@0U9Qh0
92DM00808b@L00D092DM02LX800Z:b<0:b`T02X]700202/^7@0302`_7P0]<1l0;S4P00<0;c8Q00@0
<2XL034[7@0a:ad0<B/M0P0b;1h203<]7`0603H^8@0e;B00=2`O03<[7P0b:Qd0<BTL0P0`:1/202TY
8@0302XZ8P0[:b<0;2`T0080;BdU00T0;RhV02dZ6`0^:a`0<BhO03<`8@0d<B80<c0Q038_800a;Ql0
0`0g<Qh00`0f<Ad0=C0L03@_6`0203@_6`0@03<^6`0d;a`0=C0M03Ha7P0e<1d0=2lL038]6P0a;1T0
;bdP02h/7`0[:A`0:RPK02TW6P0Z:1/0;2XM02d[7P80:bTM0P0/:Qh01@0]:al0;R`P02h/800_;B40
<2/U0080;bXT00<0;RTS02dX8P0/9b400P0[9R0202P/6`0602T]700Z;Qd0:blN02``7`0]<B00;S8Q
0P0d<Ah0100e<Ql0=S<P03Pe8P0i=R<203Xg900H03/i800l>R40?c/R048l9015?BH0BChX04a0:P1=
@B/0Ad@U04Q39@19A2H0BT<V04e49`1>@bL0D48W0553:01<A200D4HS05E;:01LCbd0H54`065A<01Q
CRh0H4d]0P1KBbT205Y::0<0FDTW00@0F4PV05Q89`1HB2L0EdLV0P1FARD0101EAB@0E4@S05A48`1B
B2d20557;0030516:`1?ABX0CT@Y0080CD<X00h0DT/a055:<01@BBl0CTL]04e6;01;A2X0BT<Y04U2
:01;A2X0C4D[04e6;01>Abd0CdP^055:<080DT/a0`1AAbh20516;@0704m5;01>A2/0CT@[04e3:P1>
@bd0C44[04Ll9P0204@i8`0K04Ll9P1:?bT0CD8/04Pm9`17?2H0ACXT04<h8P11=R00?c@N03hc7@0m
<Q`0?30J03da6`0n<Q`0?c<M040d7P11=Al0@SHP04<g8@13>Qd0A3/N04Dl7`16?B00AchQ04Po8P19
@2<0BT4T00@0BcdS101<?R@0301=?R40CChO04m08@1A@R40DdDR05E78P1GBB80F4XS05i88@1PBR<0
HT`U06==9P80I4hW00<0HddV069<9@1LBb000P1MC2400`1NCB80GdhS05m>8`02061?90L0GT`X00<0
GD/W05Q89`1IBBP00P1IBBP0101HB2L0EDDT05=38P1A@B0205A59P<0EDHW00/0Dd@U05528`1?@240
Dd@U0593901A@R<0D44R05528`1DABH0ETLX05Q9:P0305=3:@80DT8X0`1A@BL204i09@0304a19@1;
@RD0BT<V0080BD@V00H0B4DV04Tm8`19?B<0BCdS04Pl8P17>b4304Hj8080@ShS00@0@CdR040l8@10
?240?c/P0P0n>Ql403dh8P80?3LQ0P0k=R0203Tg80<0>3HO0`0g=Ah04@0m>2@0>SPS03Xh8`0i=b80
=SDP03<e7`0`=1d0;S<L02db6`0a=Ah0<C@O030c7P0_<Ql0;S4P02d_8@0];b80;2hQ00<0:2`M1@0Y
;Ah0200T:1T09BTJ02HZ6`0V:Q/09BTJ02<W600Q9AH07b<D0P0M91`201`S6`@06b8J0`0J81`301TO
6`8061hJ0P0H7Q`301LM6`/05Q`J200D6QP801LI60P05QPG200C6AT801HH5`805QLI0`0E5QP601@E
5`<05AHH2P0F5aTQ01DF61005QPG0P0F5aT301DF60H051DG0`0E5QP:01HG6E005AHH200F5aT801DF
60P05QPG4@0F5aT801LI60P05QLI400G6AP801PJ6@805QPG0`0G6AP301PJ6@P06A/J0P0G6AP201PJ
6@806A/J100J71/201TK6P8061XI100G6AP201PJ6@806A/J0P0J71/801XL6A006Q`K400I6aX301TK
60<06Q`I0P0K7AX801`L6P807alM0P0N7Q`201dM6`8071`J00<06a/I01lP6P0O81X02@0O81X3020Q
6`808B8L0P0T8al01`0T8ah08b<K02<S6@0S8aL08R8F028S5@0[9R000P0Z9Al00`0Y91h0:2<M02PS
7@0202LR70809RHL00<09bLM02PX7P0Y:Al00P0Z:R000`0[:b40<BXJ034Z6P06034Z6P04030Z7P0_
:Ad0;bTM02lY7@80;RPL0P0]9a/302`X7`<0:bLN0P0Z9Qd0100Y9A`0:RHM02XV7@0Z9Qd202/W7P80
;2PO00P0<2`S02l[8P0^:R40;BTP02`X7`0[9ah0:RHM02TU7080:b@N0P0Z8ad202TR7080:24K200R
8a/802<T70P08B8L200O81X8024R70808R8J0`0S8a/302@T7080:b@N0P0Z8ad202TR7080:24K2@0Y
8Q`302<T7P<08R<M2P0Q8Q`201hO5`0401lP600P8AT08R<K02<T708092DM200S91`802<T7P807QlI
0P0O81X00`0P8A/08B8L024R7002028S7@808B8L00<0824K01lP6P0O81X00P0N7aT2024R7080824K
100O81X801`N6`8071`J0P0M7A/401hN7080820H00@08B4I028R6P0R8QX08b<K0P0T91`202<S6`80
92@L0P0U9Ad202HV7P<0:bLN0P0Z9Qd302TU70P0:2PN0P0Y:Al0100X:1h09bLM02LW7@0V9Q`202DU
6`<0:BTQ0P0X:20302LW7`0302<T700T9Ad09BHN00809bPP00<09BHN02@U7@0S91`00`0W9al202PX
80<0:BTQ00@09RHN02DU7@0U9Ad09BDM0P0T91`302<S6`808B8L0`0P8A/301lP6P03028S7@0Q8Q`0
7b0J00807b0J00<08B8L02<T7P0T9Al00`0T91`302<S6`808R8J0P0R8a/202<T708092DM0P0U9Qh3
02PX80809bLO200V9Qh;02DU7@P09bLO0P0V9al202DV7P@092DM0`0T9Al[ooooo`00:_ooool01@2Q
MdD0XWQ60:9hAP2SNDL0Y7Y80080YG]900H0YWa:0:ImB@2VODT0YGa80:AkA`2SNTH20:9iA@80XGQ4
00T0XWU50:AkA`2UO4P0YGa80:AkA`2RNDD0XGQ40:=jAP2RNDD00P2QN4@01@2RNDD0Y7]70:ImB@2W
OTX0YWe900<0YGa80P2TNdL20:=jAP080:IkAP2WO4L0ZGi90:YoBP2[P4/0ZWm:0:UnB@2XODP30:Qo
B@030:MnB02VODL0YWe70080YGa600<0YWe50:QoA`2ZPDT00`2[PTX00`2YP4P0Z7m70:UnB@070:Un
B@T0ZX5=0`2ZP4h30:UoC@80Z7i<00<0Z7m90:Z1B`2[PT`00P2/Pdd00`2[PT`0ZX5;0:QoB@080:Yo
BP80ZH1<0P2ZPDd20:^2CP80[8=?0P2ZQ5D30:V3E0<0Z89C202YP4`30:b2D080[H=A0`2^Q5880:^1
D@040:R3CP2WPTd0Yh9=0:N2C@80YX5<0P2UP4/0402ZP4h0ZGm=0:QnC02WOD/0YG]90:=iA`2RN4H0
XGM50:=nBP2RODT0XGa809mjAP2MN4@0VgI209Ud@02HLcl309E`?080U6lk0`2CKSX2099/?@04095[
?02@JS/0SfTj08mY>P80SVPi0P2?ISX0102<IST0RVDh08UT=`27ICL208EU=P06089P<P21Gc40PEla
081N<01oGBl0OU`^0P1mFbd01P1kFB`0NeP^07YG;@1jEbl0NEH`07UE<@80N5@b00H0NE8a07MC<@1f
DS00M58_075@;@1^D2`206a@:`08071?;01_CR/0KTdZ06i=:P1_CR/0LE0]07=B;`1eE34906e?:`80
Le0Z0140M54[07EB;01fDbd0Me@^07QE;`1iES00NUHb07]G<`1kF380O5Ta07eJ<01nG2l0Oed`07mM
;`26HC@0QF0c08AO<P0208=N<@0;08EP<`26HC@0R6<f08YV=P29ICD0R6@d08MS<`28I3@0RFDe08]W
=`2<J3P00`29ICD308YV=P80RfLg0P2;ICH208YT=@@0RF<d202;ICH208aV=`0408]U=P2:I3D0RF<d
08QR<`80Qf4b00P0RF8g08QQ=P27HC@0QV0a08MQ<028Hbl0RVDa08aW<PP0Qf8e2026H3<01P28HcT0
Qf8h08IQ=`25H3H0Q5le08=N=080PUdc0P20Fbh3085L;`<0PUd`201oGBl307mL<P80OU/a0`1mFS02
07iK<@0407eJ<01lFBl0NeP^07YG;@80NEH/00H0OEP[07]I;01kFB`0NUT^07UI<01gFS8207IJ<`05
081I<P1oF340OePa07iG<01lEBh00P1kE2d00`1jDb`0NEH^07UF;P0207QE;@80Me@/0`1fDb/0301]
DRD0KU<V06mD:@1`E2`0Ke</06iB;@1/D2/0Jdh/06Y@;`1XCRd0IT`[06=9:0<0HTPW00h0HdTX0653
8@1P@b<0Gd8R05]08P1I@280EclS05@o901C?R<0DSlQ05=08P1A@280DD8S05138`80Cd@T00@0CdHU
04]0901:?b<0BSlS0P19?R8304Pm8@P0CCdS00P0BchN04Xl7`17?1h0AC`O044j7P0o>Al0?SPP03di
8080@3PS0P0o=b8203hf8@80?CDP0`0d<b4203<b80<0<S4O00D0<RTR034X8@0`:B40;BTP02`Y8002
02TY7`0402PZ7`0S:2408bPQ02<X8@808RLP0`0Q9Ql0100S91`092DM02HW7`0W:20202PY8@0302LX
800V9al08bHM00L08bHM200Q91/0100R9A`08bHM02<V7@0S9Qd202@W7P809BPO1@0T9Ad302<T7080
8R<K00P08b@L02@U7@0U9Qh09RLO02LX800X:B409BHN02@U7@808b@L00@092DM02LX800Y:R80:b`T
0P0Y;1/00`0Z;A`0:bhM02`_7P0202d`7`80;S4P0P0_;1d2030]7P<0<BhO00L0<RlP03H^8@0f;R40
=BdP03@/7`0c:ah0<RXM0080<BTL100Z:R0302/[8@0502`/8P0]:Q/0;R/L034^7`0c<2400P0d<B82
03<`8@80>3<O0P0g<Qh203Ha7@80=C0L0P0d;a`303Ha7P0;03@_700b;AX0<B`I030^7`0^;1d0;2XK
02/Y6P0Z:1T0:bTJ02`Z6`0]:a`00`0/:Qh00`0]:al0;R`P02h/800202l]8@80;b/R00<0;RXQ02dY
800/:1l00P0[9ah01P0Z9Qd09b/J02P/6`0X;1/0:BdL02/_7P80;30O0180;C4P03<`7@0c<1d0=34N
03Db7`0f<b00=c@Q03Pe8P0i=R<0>3HM03Tg7P0m>B00@3XR04<k9017?2H0BCdW04Xn:014@B8204I1
8`0304M08`1:@B@0Bd0T0080CT0U00P0BT8N04i48@1BB2D0FD`Z05a=;01MCB`0GDXZ05a9:@80FDTW
0P1HB2H305M79@0405I6901FARD0ETHU05E59080E4@S0P1C@b801`1B@R40C48W04]19P1;@BH0BT0U
04To9018?R<00P17?B801P15?R@0A3dS04@m8`13?280@S/Q044j8080@3TO0P11>R001012>b40@c`R
04@m8`14?B<204Dn9080AS`S0P15>b8204@j8@80@cTP00@0@SPO04Ll9P15>R@0@cPR0P11=R000`12
=b40ACXT04Hk9@0204Dj900404@i8`12=b40@CHP040e7`80?S<M0P0o<ad01010=1h0@CDO048f8013
=b4204@h8P0504Dj7P16>al0AS/O04Ll8019?R800P1:?b<00`1;@2@0BcdR04/m8P0304/m8P<0C3hS
00H0CSlP04m08@1@@B00DT<R05A68`1FB2<205Q:8`0305m98P1PBR<0HT`U00<0I4hW00D0HddV069<
9@1MC240GD`Q05i=8P0205m>8`<0H4lT00<0GddY05i<:01NC2P00P1MBbL305a:9P80EdLV00T0F4PW
05U9:01HB2L0ETHU05A48`1B@R40DT<T05=49@1DABH00P1EARL01@1CA2D0DD8S05118P1DABH0Dd@U
00<0DD8S00<0Dd@U05A59P1FAbP00P1C@bT20592:0<0DD4W00H0D40V04i09@1>@2D0C44U04]29@19
@RD204Q39@0304M49@19?B<0BCdS0080B3`R0P17>b4204Hj8080@ShS00@0@CdR040l8@10?240?c/P
0P0n>Ql403dh8P80?3LQ0P0k=R0303Tg8080>3HO0`0g=Ah01`0l=b<0>CLR03Tg8P0h=R40=SDP03<e
7`0`=1d00P0^<a`01P0a=Ah0<3<N030c7P0_<Ql0;S4P02d_8@80;2hQ100X;1d402T]7P0802@X6P0U
:A/09BTK02HZ700U:A/08bLI020T5P0O8aD201dT708072<K0`0K8QX0100J8AT06R0L01XP700J81`2
01TO6`<061hJ0P0H7Q`301LM6`/05Q`J200D6QP801LI60P05QPG200C6AT801HH5`805QLI0`0E5QP6
01@E5`<05AHH2P0F5aTQ01DF61005QPG0P0F5aT301DF60H051DG0`0E5QP:01HG6E005AHH200F5aT8
01DF60P05QPG4@0F5aT801LI60P05QLI200H6QT801LI60P061XI0P0F61L301LI60<061XI200I6aX2
01LI608061XI0P0I6aX401XL6`806A/J0P0H6QT401LI608061XI0P0I6aX201XL6`P06Q`I400J71/@
01TK6P<06A/H0`0J71T201/M6PP071`J0P0O7ad201hN70807AdK0`0L71X;01lP6P<0824K0P0Q8Q`2
02<R7P0302<R7@0S8a/08b<I00808b<G00<092DG02XU7`0Z9Al00P0Y91h202PS7@809b8L0P0V9Q`0
100W9ad0:2PN02TY7`0Y:Al202XZ80P0<2TI100_:Ad202hX7080;BLK0`0/:1l202/W7PD0:RHM0P0[
9ah302`X7`0702dY800^:R40;RXQ02hZ8@0]:B00;2PO02/W7P0202XV7@80:B@N0P0X8ad202LR7080
9R4K200R8a/802<T70P08B8L200O81X8024R70808R8J0`0S8a/302@T7080:B@N0P0X8ad202LR7080
9R4K2@0W8Q`302<T7P808R<M2`0Q8Q`01@0N7aL07b0H01lP600P8AT08R<K00808b@L00<092DM02<T
700S91`01P0S91`802<T7P807QlI0P0O81X00`0P8A/08B8L024R7003024R7080824K0P0O81X201hO
6@808B8L0P0P8A/301lP6P0301hO6@0L7Q/071hK00H071hK0P0L71X201dM6`<07QhL00D07alM024Q
6@0Q8AT08B4I028R6P0202<S6`8092@L0P0S8a/202@T70809BDM0P0V9Qh802XV7@P0:2PN00<0:BTO
02PX7P0X:1h00P0W9ad202HV700402DU6`0Y:B40:BTQ02TY8@80:2PP0`0W9al00`0S91`092DM02DV
7P0202HW7`0302DV7P0T9Ad08b@L00<09bLO0P0X:20302TY8@@09BDM0P0T91`302<S6`808B8L0`0P
8A/301lP6P08028S7@0Q8Q`0824K01lP6P0P8A/08B8L02<T7P0T9Al302@T70<08b<K0P0R8QX2028S
6`808b@L0P0T9Ad202DV7P80:2PP0`0W9al702HV7P`09BDM200W9al202HW7`809BHN0`0T9Ad0100S
91`08b@N02<T7P0S91h[ooooo`00:_ooool80:EkB@060:ElB02TNdL0Y7]70:=jAP2RNDD0XGQ40P2P
Md<00`2QN4@0XWU50:AkA`020:ElB0040:AkA`2RNDD0XGQ40:9iA@80XGQ400D0XWU50:=jAP2UO4P0
Ygi:0:QoB`030:ImB@80YGa80`2TNdL0102VNdH0Yga70:QmB02YOTT20:YoBP040:UnB@2XODP0Z7m9
0:QoB@<0Ygi80`2VODL0202YP4X0ZX5;0:Z1B`2[PT`0ZX5;0:V0BP2XOdT0Ygi8202YOTT90:Z1C@<0
ZX1>0`2YOdd20:QnC0030:QoB@2YP4X0Zh9<0080[8==00<0Zh9<0:V0BP2XOdT0202ZOdX20:V0C080
ZX5=0P2[PTh20:b3C`<0Z89C0`2YPe@20:Z4E@P0ZX5=0`2/PU020:f3D@<0[XAB202[PDl30:R3CP80
Yh9=0`2VPD`0402/PU00Zh5?0:UoC@2WOD/0YG]90:=iA`2QMdD0X7I40:=nBP2RODT0XGa809mjAP2M
N4@0VgI209Ye@@2IM40309Ia?@80UG0l0`2DKc/01P2CKCh0TV`m099/?@2AJc`0T6Xk08mY>P80SVPi
00H0T6Lk08mV>P2=IcX0RfHi08YU>027ICL208EU=P0608=Q<`22H380PV0b085O<@20GS00Oed_0`1n
G2h03@1mFbh0O5X]07]H;P1jEbl0NEH`07QD<01gDbl0Me0_07EA;`1dD2h0Le4^075@;@1_DBd00P1]
DB`00`1bDBh0LE0]071?;00206m>:`03071?;01aD2d0LU4^00T0KDl[0P1cD2X0101dDB/0ME8/07IC
;@1fDbd207MD;P0:07QD<01iEC40NEH`07YG;`1kF2h0O5X]07eK;P1mFbd0Peha089M<0<0PE`_00D0
Peha08EP<`26HC@0RFDe08QT=00308MS<`0308UU=@2:ISH0S6Ph00<0RFDe0`2:ISH208]W=`<0RfDf
0P2:I3D308US=0P0RfDf0P2<ISL0102;ICH0RV@e08US=028HS<208MQ<P80R64f00H0Qf4d08MQ<P27
HC00R6<_08YU<@2;IS4808QS=PP0QV0c0P27HSP00`26HCL0QF0f08AO=@0208=N=003089M<`20Fbh0
PE`_0080PE`_0P22GC0208=N<@P0P5h`00@0P5dc07mL<P1oG380Oe`b0P1nFc4207eJ<080OU/a00@0
OEX`07aI;`1kF2h0NeP^0P1jEbd01P1lEbX0NUP[07YH:`1iF2d0N5P_07II<@80METb0P1nF340101m
Ec00O5H_07aF;`1kEBh207YD;@80NEH^0P1hEBd207MD;0<0MU<[00h0KU<V06mD9`1_E2T0L5@/06mC
;01^DRd0KE4/06a?;@1]D2h0Jdh/06Q;:@1VBBL0IDPV06A79@80IDPV00P0HT@R0654901P@b<0G44S
05Y18`1H@2@0ED0U05@o9080Dd0R00<0DT4S05528`1AA2@00P1?A2@02@1>AB@0CD8V04e29P1<@BD0
Bd0T04Tn8P18?B40Ac`P04Hk7`0804dm8`0804/n7P1;?B00B3dO04Dl7`12>al0?cTO03hh800m>B02
040h8`<0?cLR0`0n=R40100h=B80=c@Q03Ld8@0g=24203Hc8080=C8O00P0=B`U03@[900b:b<0;b/R
02dZ8@0Y:Al0:2PN02LY7P<09RTP0P0U:1l302@W7P0302<T700T9Ad09RLO0080:2TQ00<09bPP02HW
7`0U9Qh0200S9Qd8024T6`<08RDL0P0S9Qd302@W7P809RLO00@09BHN02@U7@0T9Ad08b@L0`0R8a/2
02<T700302@U7@0U9Qh09RLO00809bPP100T9Ad0100U9Qh09RLO02PY8@0Y:R8202LY6`0302PZ700Y
:ad0:R`N0080:bdO0P0/;R03030]7P80<BhO0`0b;b0203H`8P0303D_8@0d;R00<bdO0080<R`N00<0
<B/M02/[8@0[:b400`0Z:R0302TY7`0402dZ6`0^:a`0<2dN03<`8@80=C8S0P0f<b@303Td8080>3<O
0`0g<Qh203D`7@<0=c8O00H0=C0M03<^6`0b;AX0<RlP034^7`0_;1d302h[7080;b`M00@0;RXN02l[
7`0_:al0;b/O0`0`;2001`0a;B40;b/R02hZ8@0^:R40;BTP02`X7`0[9ah00P0Z9Qd202P[6P0402T/
6`0Z;A`0:bhM02/^7@80;2lN0P0b;a`203<`7@0:03@a7P0e<Ql0=S<P03Hc800e<a`0=S@M03Td7P0l
=R00?cLR048g8`80ACPU00H0@3`O044l7`12?B00@c`P04Dk8017>b4204Tk8@0904Hm701:?al0CT<S
05=69P1FAbP0EdHX05Q59`1GA2H0ETHU00<0EDDT0P1DA2<205=38P<0DT4S0`1A@282050o8@0604Hl
8@15>b00AC/P04@j7`13>Ah0@SPM0P11=a`:03`e6`H0?CHL0P0o=A`303hd6`<0?C<J00<0?38I03le
700n=1/0100n=1/203le700304<i8012>1l0@SPO0080@CLN0`10=Qd2048f7P0304<g7`14>200ACTQ
0080ASXR00L0Ac/S04Hk7`17?200Ac`P04Pm8@19?R80BSlS0080Bd0T0P1;>b4204`l8P80CCdS0P1>
?R@0401A@280DT8Q05=38P1EAB<0EdLS05Q98P1JBb80Fd`S061:8`1QBb@0HddV06A>9`1UCbP0I4hW
06==9P1RC2D205i<9080GddU101PCRH205m=:@0405i<:01MBbL0FdTU05Y89080FDLS00<0E4@S05E5
901GAbH00P1GAbH03P1FARD0EDDT05A48`1@@B80DD8S05=49@1DABH0EDHW05A59P1CA2D0DT<T05A5
9P1CA2D0DT<T0`1A@R<2059390<0DT8X0P1A@BL305109P0504i09@1=?b@0Bd0T04Y19018@B@00P17
@R@00`16@b@0B3hS04Lm8P0204Lm8P<0AS`Q00@0AC/P048n8`12?R<0@CdR0P10?240100o>b00?SXO
03hj7`0n>B<203dh8P0603`g8@0k=R00>cHP03/f800l=b40>SPQ0`0i=b0203Pf7`80=cDN0140>C@P
03Le800g=B00=cDP03Dd7`0c=Al0<CDN030e7P0_=1d0<3@M030c7P0_<Qd0;S4N02d`7`0/;R00;2hQ
02/]800802P/7@8092LL00H09BPM02@W700S9Q/08RDJ020S600O8QL301`S6`806b8J0`0J8AT201XP
70806AlK0`0H7QX00`0G7AT061hL01PN700301LM6`/05Q`J200D6QP801LI60P05QPG200C6AT801HH
5`805QLI0`0E5QP601@E5`<05AHH2P0F5aTQ01DF61005QPG0P0F5aT301DF60H051DG0`0E5QP:01HG
6E005AHH200F5aT801DF60P05QPG4@0F5aT801LI60P05QLI200I6aX801LI60P061XI0P0F61L301LI
60<061XI200I6aX201LI608061XI0P0I6aX401XL6`806A/J0P0H6QT401LI608061XI0P0I6aX201XL
6`P06Q`I800I6aX301TK60<06Q`I0P0K7AX801`L6P<07QhL100M7A/201`L6P/07b0J0`0P8A/2024R
70808B0L00H08R4L02<S6`0T91X092@H02DU6@0U9QP302TT7P<0:2<M0P0W8Q`01P0U9A/09RHL02HV
700W9ad0:2PN02TY7`80:RXP200_:A/302lY7@80;RPL0`0]9a/202`X7`80:bLN0`0Z9Qd0100Y9A`0
:bLN02/W7P0[9ah202`X7`<0;BTP200/:1l202TT7P80:2<M0P0W8Q`202HQ6`P08R<K200S91`8020Q
6`P07b0J200P8A/2028R6P<08b<K0`0T91`202TT7P80:2<M0P0W8Q`202HQ6`T09b8L0P0S91h2028S
7@<08B8L00<0824K024R700Q8Q`01P0Q8Q`201lP6004020Q6@0Q8QX08B8J028S6`X08b@L200S91h3
01lP6P<0824K0P0Q8Q`3020Q6`<07b0J0P0N7aT3020Q6`807b0J0`0N7aT801`N6`<07AdK0P0N7Q`3
01lO7@04024Q6@0R8QX08R8J028R6P<08b<K00<092@L02<S6`0S8a/00P0T91`202DU7@809RHN0P0X
91/0100Y9A`0:RHM02XV7@0[9ah202`X7`/0:2PN0P0W9ad302HV70<0:2PP0P0W9al302HV7P03028S
6`0S91`09BHN00809RLO00<09BHN02<T700R8a/00`0V9Qh202LW7`<0:2PP0`0U9Ad202@T70@08b<K
0P0Q8Q`3020Q6`<07b0J00P08R<M024R700P8A/0824K024R700R8ad08b@N02@U7`<092@L0`0S8a/2
028R6P808R<K0P0S91`202@U7@809BHN00@0:2PP02LW7`0W9al09bLO0P0V9QhB02DU7@P09RHN0`0U
9Qh202@U7@<08b@L0`0Q8Q`[ooooo`00:_ooool30:MmB`80YWa:0`2UNdT01P2TNdL0XgY60:=jAP2R
NDD0XGQ40:1g@`80WgI200<0XGQ40:9iA@2TNdL00P2UO4P00`2TNdL0XWU50:5hA0020:5hA0060:9i
A@2SNTH0Y7]70:ImB@2WOTX0Z7m;0`2VODT30:ElB080Y7]700@0YW]60:MlA`2WO4L0Z7e8102YOTT6
0:MnB080YWe70`2[PTh00`2ZPDd0ZH1<0:QoB`020:MnBPP0ZGi92@2ZPDd30:Z0CP<0ZGm=0P2XOT`0
0`2XOdT0ZH1:0:Z1B`020:^2C0030:Z1B`2YP4X0Z7m900P0ZWm:0P2YP4`20:Z1C@80Zh9>0P2/Pdl0
1P2VP4l0Yh5@0:N1D02XPU40ZH=B0:Z4D`80ZhED202ZPDd30:b2D080[H=A0`2^Q5880:b3C`<0Z8=>
0`2WPTd20:J1C00@0:f3D@2/PU00ZX1>0:QnC02UNdT0XgU70:5gA@2PMT@0Xgi:0:9mB@2QO4P0WgY6
09iiA@2LMd<0VgI209Ye@@80V7<o0P2GLSh309Ia?@0609E`?02CKCh0Tfdn099/?@2AJc`0T6Xk0P2?
JCX02@2>J3T0T6Lk091W>`2=IcX0RfHi08YU>027ICL0QVHg08EU=P0208=Q<`80PV0b00@0PEla081N
<01oGBl0Oed_0P20GS001`1nG2l0OE/^07]H;P1iERh0N5D_07MD;P1fD2`00P1dD2`00`1cDB`0LU8/
071B;00206mC;080LU4^00<0LE0]071?;01`Cb`00`1`Cb`906e?:`<0Le0Z00<0M54[07EB;01eDR`0
0P1fDbd02P1fDRh0Me<_07MD;P1hEBd0NEH/07YH:`1kFB`0NeT[085L;`20Fbh207mJ;@06081K;P21
G2l0Peha08EP<`28I3@0Qf<c0`26HS800`28I3@0RFDe08]W=`0308UU=@<0RVHf0P2;IcL208aV=`80
RfDf0P2:I3D208US=0P0RfDf0P2<ISL0102;ICH0RV@e08US=028HS<208MQ<P80R64f00H0R68e08QR
<`28HS40R6<_08UT<029I2l808QS=PP0QV0c0`26HCL00`25H3H0Q5le08AO=@0208=N=0<0PE`_0P22
GC0308=N<@P0P5h`0P20GC<307mL<PD0OU/a0P1mFS001@1lFBl0NeP^07]H;P1kF2h0NeHY0080NELZ
00<0N5L/07MG;P1eF3000P1dF3400`1lFC40NeP`07]H<00207YG;`80NEH^00<0N5D]07UF;P1iERh0
0P1hEBd207MD;0<0MU<[0P1_E2L0301_E2T0Ke<[06mC;01^DRd0KE4/06e@;P1]DB`0K50[06U=:01W
BbH0ITXU06E99080ITXU00P0I4HT06959@1QA2@0GT<U05]2901I@BD0ET4V05E09@80E44S00<0Dd8T
0593901AA2@00P1?A2@02@1>AB@0DD<X0553:01?@BH0CT0U04`n8`1:?240BC/P04Pj7`0804dm8`08
04`o7`1;?B00B3dO04Hm8012>al0@3XP03li8@0m>B02040h8`H0?cLR0`0l=b<203/f8P<0>SDQ00P0
=bhU03H]900d;B<0<2`Q02h/800Z:Qh0:BTM02LY7080:2XO0`0W:Ah302HX7@0302@U7@0U9Qh09bPP
0080:2TQ00<09bPP02HW7`0U9Qh0200T9ah8024T6`<08RDL0`0S9Qd202@W7P809bPP00@09RLO02DV
7P0T9Ad08b@L0P0R8a/202<T708092DM00@09BHN02HW7`0V9al09RLO100T9Ad0100U9Qh09RLO02LX
800W:20202DW6P0302HX6`0W:A`0:2XM0080:B/N0P0Z;1l202l]7P80<2hO100a;b0203@a8P80<c0Q
00@0<RlP034^7`0a;Ql0<BhO0P0/;2000`0[:al0:RXN02TY7@0202PX700702LW6`0]:Q/0;R/L030]
7P0b;b00=34R03Hc900203Ld9@P0>C@P00P0=S4N03Lb7`0h<b00>C@Q03Pc800g<Ql0=C0M03@_7080
=BlO00<0=2hN03<]7@0c;Ad00`0c;Ad2038/7PH0<bdO0P0_:b00100^:Ql0;BTN02`X7@0[9a`202XV
6`0302TZ6P0Z:a/0:R/K0080:b`L0P0/;Ad00`0];Qh0<BhK034^6`02038_7080<c0M0P0d<Ah01P0b
<1/0<c4L03Ha7@0h<Ah0>c<P03hc8@80@C@S0100?3PM03dg7@0n>1h0?cPN048h7`13=al0ACHO04Hg
8014>a`0Ac`N04Tn801>@2<0D44T0550901B?R<0DCdR0`1B@B<205508P<0D3lQ0`1??R8504hm8@80
A3XO00<0@cTN048h7@11=a`00P10=Q/0100o=AX0?SLM03hg7@0o>1h2040i7`80@CXP00@0@S/Q044j
8011>R00@CXP0`10>Al203lh7PP0@CLN00H0@3HM03/a5P0l<QL0?C<H03hd6@0o=AX203hd6@0303dc
6011=a`0@CLL0080@CLL1012>1d00`15>Al0ASXP04Hj800204Lk8@80B3`R00<0BCdS04Xl8@1:?240
0P1;?B8204`n8`80CClT0P1=?20204hm8@0?04ln8P1@?b<0D3lS0550901F@b<0Ed@T05Q5901IAb<0
FdTS05a:8P1MC240GTdR065;901RC2D0I4hW0080IDlX00<0I4hW06==9P1RC2D0201OCBL205m=:@0A
05e;9`1LBRH0FTPT05Q68P1GAB40ET@P05928@1C@b80EDDT05I69@1GAbH0ETHU05E5901DA2<0CSlP
05118P1B@b@00`1DABH205=49@0405A59P1CA2D0DT<T05528`80D44R0P1?@24305519`80D40V0`1?
?bD204do900304]0901:@B@0Ad0S0080AT4S00<0AD8S04Dn8P15?R800P15?R8404@m8@80@ShS00@0
@CdR040l8@10?240?c/P0P0n>Ql00`0o>R@0?STS03`g8@0303/f8080?3LQ0P0j>24303Tg80<0>3HO
00L0>3<O03Hd7`0f=1l0=S@O03Dd7`0b=1h0<CDN0080<3DN00T0;c<L02lb7@0^<A`0;C0M02`_7P0[
;Al0:bdP02X/7`0Y;Ah0100X;1d302L[708092LL0P0S9Q/0100R9AX08B@I01lR5`0O8QL201`S6`<0
6b8J0`0J8AT301TO6`<061hJ0P0G7AT201PN70<05adK2`0F71X801@J60P05aTH200F61L801<I6@P0
5QPG0P0F5aT301DF60H051DG0`0E5QP:01HG6B405AHH400F61L201HG6@<05AHH1P0D5AL301DF60X0
5QLID00E5QP801HG6@P05AHH200F61LA01HG6@P05aTH200F5aT801XL6`P05aTH200H6QT201HH5`<0
5aTH0`0H6QT801TK6P805aTH0P0H6QT201TK6P@06Q`K0P0I6aX201PJ6@@05aTH0P0H6QT201TK6P80
6Q`K200J71TP01TK6P<06A/H0`0J71T201/M6PP071`J0P0N7Q`701dM6`/07b0J0`0P8A/2024R7080
81lK00H08B0K02<S6`0T91X09BDI02HV6P0W:1X602PS7@809b8L0P0U9A/00`0V9Q`09bLM02PX7P02
02TY7`0302XZ800/:1`0;2PL00H0;2PL0P0_:Ad202hX7080;BLK0P0/9QX302/W7P<0:RHM0P0Y9A`2
02/W7P80;2PO100]:B00100Z9Qd0:bLN02/W7P0[9ah302`X7`0302dY800X9Ah0:2DN00809b@M0P0V
8a`202DR6`P08B8J200S91`H020Q6`808R8J0`0S8a/302@T7080:2DN0P0W91d202HS70809B8K2@0V
8a`3028S7@<08B8L0P0P8A/8024R700301lP600P8AT0824I00808B8J0P0R8a/902<T70P08b@N0P0O
81X6020Q6`H07b0J0P0N7aT2020Q6`<07b0J0`0N7aT801`N6`807AdK0`0N7Q`301lO7@X08b<K0P0T
91`202DU7@809RHN0P0W8aX0100X91/0:BDL02/W7P0/:1l202dY81009bLM0`0W9al302HV7P809BDM
00<08R<K02<T700T9Ad00P0V9al00`0T9Ad08b@L028S6`0202DU7@<09RHN0`0W9al202DU7@8092@L
0P0S8a/3028R6P808B8L0`0P8A/301lP6P@08B8L00@08R<M02<T7P0S91h092DO0`0T91`302<S6`80
8R8J0P0R8a/202<T708092DM0P0U9Qh302LW7`809RHN0`0U9Ad302@T70@09BDM00<09RHN02DU7@0U
9Ad01P0U9Ad802HV7P809BHN0`0T9Ad302<T70<07b0J:oooool002[ooooo0`2WOD/20:IlBP<0YG]9
00H0Y7]70:=jAP2SNTH0XWU50:5hA02PMd<209mf@P030:5hA02RNDD0Y7]70080YGa800L0Y7]70:9i
A@2QN4@0XGQ40:9iA@2SNTH0Y7]70080YWe9102WOTX30:ImB@<0YGa81@2WO4L00`2XODP0ZGi90:Un
B@020:ImA`H0Ygi800@0[8=?0:^2CP2ZPDd0ZH1<0`2XOd/00`2WOTX0ZGi90:UnB@060:UnB@T0ZH1<
0`2ZP4h30:UoC@80Z7i<00<0Ygi80:QoB@2ZPD/00P2[PT`00`2ZPD/0Z7m90:MnB0080:YoBP80ZH1<
0P2ZPDd20:^2CP80[8=?00H0YX5=0:N2CP2WPTh0Z8=?0:V4D02ZQE420:^6DPP0Zh9>0`2/PU020:f3
D@<0[XAB202/Pdl20:V4C`<0Z8=>0`2WPTd0202]Pe40[89@0:Z0CP2XOT`0YWa:0:AjB02RN4H0XGM5
0P2RODT0102QO4P0X7]709iiA@2MN4@209ag@`<0VGA00P2HLcl309Mb?P0609A^?`2CKCh0Tfdn099/
?@2AJc`0T6Xk0P2?JCX01P2AJ3`0T6Lk08iX>`2<IcX0RfHi08QV>080QVHg0P24HS@01023HC<0PV0b
085O<@21Gc42081N<006089P<021Gbl0P5h`07iL;`1lFBl0NeP^0P1iERh01P1gDB`0ME8/07EB;01d
DR`0Le</075D;080L5@/1@1aD2d00`1`Cb`0Kdh[06m>:`0906e?:`03079?:@1cD2X0Le0Z0080Le0Z
0`1dDB/02@1eDBd0MU8^07IC;@1gE2`0N5D[07UG:P1jF2/0NUPZ07mJ;@0307iI;00607mJ;@21G2l0
Peha08EP<`27Hc<0QV8b0`25HC400`27Hc<0RFDe08YV=P0308UU=@<0RVHf0P2;IcL308aV=`80RfDf
0`2:I3D808]U=P80S6Hg00@0RfDf08YT=@29Hc@0R68c0P27HC8208QQ=P0308US=P29Hc@0RF<b0080
R6<_00<0Qf8]08UT=`29I3L01P29I3L808IP<`0308IQ=`25H3H0QF0f0080QF0f0`24GcD2085L;`80
PUd`0P23GS4208AO<PP0PEla0`20GC<307mL<P<0OU/a101mFS0307aI;`0607aG:P1jF2/0NUP[07UH
;@1hF2l0MUTa0P1eFC8207YI<0@0NEP_0P1hEbh207UF;P80N5D]0P1gE2`307IC:`05075F:@1`EBP0
L5DZ06mC:`1^DR/00P1^DRd01@1^DBl0Ke4[06i@:P1[CBL0JD/U0080IdTS0P1XBR@01P1UAbD0I4LW
06=69P1OA2H0GD@V05Y29P80Ed8W0P1F@bD00`1C@R@0DT<T0554900204m4900904i5901C@bT0Dd<Y
05519`1@@2H0CShT04`l8P1;>b40BSXP00P0CCdS00P0C3lO04`n8@19?R00ASdP04<l8010>R00?cTQ
03hj8@80?cLR1P10>2<403hg9080?CHS0P0l=B80200i<BH0>30U03H`900b;R80;bdP02//7P0Z:ad0
:2XL0P0Y:ah202PZ7@@09bTL00<09BHN02HW7`0W:2000P0X:B400`0W:2009BHN02@U7@0802@W7PX0
8B@K0`0R9A`302<V7@809bPP00@09RLO02DV7P0U9Qh092DM0P0S91`302@U7@@09BHN00@09RLO02<T
700T9Ad092DM1@0U9Qh202@V6`0302DW700V:1d09bTN0080:2XO0P0Y:b0202`]7@80;BhN0`0^;al0
0`0_<200<S0Q038`8@03034_80<0<2hO0P0];R000`0/;Al0:b`N02X[7@0202TZ700902PY6`0^:a`0
;R/L02l/7@0`;Ah0<RlP03@a8P0e<R<0=S<T00P0>C@P00<0=c8O03Pc800i=2400P0j=B800`0h<b00
=S4N03D`7@0403Pa7`0403L`7P0f;ad0=RlM03D^7080=RlO1P0e;Qh2030/800402l[7`0^:Qh0;BTM
02dY7@80;2PL0`0]:a`302h/7@80;bdN0P0a;Q/4038_7080<c0M01H0<BlJ038`6`0e<1`0=c0M03Ta
7P0m<R00?S4P03lb8@0j=Qd0>cDM03`f7P0m=Ah0@3DO044e7`13=1l0A3DP04<j7@16>al0Ac`P04Xl
8@1<?280CC`R0P1>>R42050o8`<0CchR0`1>?B4404`k8@@0CC`R00H0AcdR04Hl8@16?240AC/P04@j
7`13>Ah2048h7@80@3TO00@0@CXP048k8@13?280A3dS0P15?R@304<l8P<0@S/Q0P11>R0904<i8003
03he600o=QT0@CPK00@0@STL00@0@CPK048i7012>A`0@STL0P13>Qd304@k7P80B3dQ1019?R8204Xo
8`@0CCdS101>?R@01P1>?Al0CchP050o8@1A@280DT4S05=29080E4<U00/0FTHU05]79P1LB2D0GDTT
05i;8`1OC280H4dR065>8`1RC2D0HddV06A>9`0206E?:00306A>9`1RC2D0HD/T00@0GT`V101MBbD0
1P1NC2P0GD/W05a:9P1JB2@0F4HR05M58@80ED<O00`0DD4P05928@1DA2<0EDDT05I69@1EAB@0E4@S
05=38P1>?b00Cd0Q05528`1CA2D205A59P0305=49@1B@b@0DT<T0080DT<T00<0DD8S05118P1?@240
0P1>?b0305109P80CclU0`1>?R@204do900604Xo8`19@2<0ASlR04E08P14?b40@d0Q1013?R4404@o
8P80@ShS00@0@CdR040l8@10?240?c/P0P0n>Ql00`10>bD0?STS03`g8@0203Xe7`0303/f800l=b40
?CPR00<0>SPQ0`0i=b0203Pf7`0703Lb7P0e<ah0=C<N03Dc7P0d<ah0<S@N034e7P02030e7P0802hb
6`0^<A`0;C0K02`_700[;Qd0:R`N02X/7`0Y:ah202T]7P80:2`M00T09b/L02HZ6`0V:Q/09RXK02@W
7P0S9Qd08RDL024T6`0P8aX00`0O8QT301/R6P<06R4I0P0I81P201TO6`<061hJ0`0G7AT201PN70<0
5adK2`0F71X801@J60P05aTH200F61L801<I6@P05QPG0P0F5aT301DF60H051DG0`0E5QP:01HG6B40
5AHH400F61L201HG6@<05AHH1P0D5AL301DF60X05QLID00E5QP801HG6@P05AHH200F61LA01HG6@P0
5aTH200F5aT801XL6a005aTH0P0F61L301LI60<061XI200I6aX201LI608061XI0P0I6aX401XL6`80
6A/J0P0H6QT401LI608061XI0P0I6aX201XL6`P06Q`I400H6QT@01TK6P<06A/H0`0J71T201/M6PP0
71`J1`0M7A/201hN70/07b0J0`0P8A/2024R708081lK00H08B0K02<S6`0T91X09BDI02HV6P0W:1X6
02LR7080:2<M00H092@J02DU6`0U9A/09RHL02LW7@0X:1h202TY7`P0:RPL0`0^:1`202dW6`<0;2HJ
0P0[9ah302XV7@<0:BDL0P0Z9Qd202/W7P<0;2PO00@0;BTP02XV7@0Z9Qd0:RHM0P0[9ah302`X7`80
9RHN0P0U9Ad202@T70808b<K200Q8QX8028S6aP0824K0P0R8QX302<S6`<092@L0P0V9Qh202DU7@80
92@L2`0S8a/2028S7@<08B8L0`0P8A/8024R7080824I100Q8QX:028S6`P08R<M1P0P8A/201lP6PH0
7QlI1@0O81X301hO6@807AhH200L7Q/301hN70<07alM0P0P81h402@T70H08b<K0P0T91`202DU7@80
9RHN0P0W8aX0100X91/0:BDL02/W7P0/:1l202dY81009bLM100V9Qh202DU7@8092@L00<08B8J02<T
700T9Ad00P0U9Qh00`0T9Ad08b@L024R6P0202@T70809BDM100V9Qh302@T70808b<K100R8QX2024R
70<0824K0`0O81X2024R7003028S7@0S91h08b@N00<08b@N0`0T91`302<S6`808R8J0P0R8a/202<T
708092DM0P0U9Qh202LW7`809RHN0P0U9Ad202@T70<08b<K00<092@L02DU7@0U9Ad00P0V9Qh802DU
7@P09RHN0`0T9Ad302<T70808R<K0`0O81X[ooooo`00:_ooool80:EkB@060:ElB02TNdL0Y7]70:=j
AP2RNDD0XGQ40P2PMd<00`2QN4@0XWU50:AkA`020:ElB0030:AkA`2RNDD0XGQ40080XgY600@0YGa8
0:ImB@2VODT0YWe90P2UO4P30:MnBP80YWe90`2UO4P20:MlA`<0YW]600<0Yga70:UnB@2ZOdX00`2V
ODL30:MnB080Z7m90P2[PDl01P2YOdd0Z7i<0:QnC02XOT`0ZGm=0:Z0CPP0ZGi92@2YP4`30:Z0CP<0
ZGm=0P2XOT`00`2WOTP0Z7m90:V0BP020:Z1B`030:V0BP2XOdT0Ygi800P0ZWm:0P2YP4`20:Z1C@80
Zh9>0P2/Pdl30:R3CP<0ZHA?0P2ZQE080:^2CP<0[89@0P2]Pe430:j4DPP0[8==0`2YQ4l20:R3CP<0
Yh9=00H0Zh5?0:Z0CP2YOdd0Z7i<0:MmB`2UNdT20:AjB080XWe900@0XGa80:1kA`2ONTH0WWU50P2M
N4@0102KMT80VWE109Ye@@2JMD4209Ud@080V7<o0P2DKSl00`2CKCh0TV`m095[?002091Z>`0908mY
>P2AJ3`0TFPl08iX>`2<IcX0RfHi08QV>027IcP0QVHg0080QF<e00<0Q68d08=Q<`22H3800P21Gc40
3`20GS00PV4^085P;@20GRh0Oed_07iL;`1mFS00O5T_07]H<01kEBh0NEH^07QE;@1gERd0MED/07=F
;002075F:`0306m>:`1`Cb`0LE0]0080LU4^00<0LE0]071?;01_CR/02@1]Cb/7079?:@0907=@:P1e
DBd0MU8^07IC;@1gE2`0N5D[07UG:P1jF2/0NUPZ0080OUT/00H0OEP[07iI;01oFRd0PE`_08AO<P25
H3<208IR<P<0Q60`00<0QV8b08QT=029ICD00`29ICD308YV=P80RfLg00@0SFLh08aV=`2<ISL0S6Hg
0P2;ICH208YT=@P0RfDf0P2<ISL0102;ICH0RV@e08US=028HS<208MQ<P0808QQ=P29HSL0RF<f08YT
=@29Hc80R6<_08MR;P26HB`808UT=`P0QV0c2025H3H3089M<080Peha0`24Gc88085O<@80PEhd0P20
GC<307mL<P0307iK<@1mFS00OEX`00H0OEX`00H0OEP[07]I;01kFB`0NUT^07UI<01gFS8207IJ<`P0
N5P_0P1iERh207QE;@80Me@/0`1fDb/0301bEbX0LEHY071E:P1^DRX0KU8[06iB;@1_Dbh0Ke8`079B
:`1aDBX0KThW06a<9@80JTXS0P1[Bb@0201VB2H0IDPX06A79`1QARP0GTDW05a4:01IA2T0F4<X0P1G
A2H00`1D@bD0Dd@U0554900204m4900904i5901D@bT0Dd8X05=2:01A@2H0D3lU04ln901>?B<0CC`R
00P0CCdS00P0CD0P04`n8@19?R00AchQ04<l8011>b40@3XR03hj8@80?cLR0`10>2<3044i9080@3PS
0P0o=b8303hf8@0903de800i<B@0>30S03H`8P0c<240<BlP02d^7P0/;Ad0:bhM0080:b`N0P0Z:ad3
02TZ700402PY6`0U9Qh09RLO02LX8080:2TQ00<09RLO02@U7@0S91`0200T9ah;024T6`808RDL0`0S
9Qd502DV7P<09RLO200U9Qh202<T70@09BHN00L092DM02<T700T9Ad092DM02DV7P0V9al09bPP0080
:2TQ0P0Y:R8202T/6`80:RdL0`0[;Qd00`0/;ah0;BhN02d^7P0602d^7P0402h_7`0];Qh0;BhN02d^
7P@0;2dM00P0;b`M02h[700^:a`0;R/L02l/7@0`;Ah0<RlP03<`8@<0=c8N0P0h<al303Td800303Td
8@0j=B80>cHS0080>cHS00@0>C@Q03Pc800f<Ah0>S8O0P0k<b001P0l=240>c<P03Xb7`0i<Ah0>30M
03T`7`<0>2lN0`0g;Qd01`0f;A`0<c0Q038_800b;b00<BhO030]7P0_;1d00P0^:a`8034^7`<0<RlL
1`0c<1d0100f<Ah0>34O03Xa800m<B4203lb8P0603/f800l=R00?3HP03hf8@10=B40@C@Q0P14=B80
1P15>b00ASXP04Lk8@19>b40BSXQ04/i8@80CCTQ0P1??R@204hm8`<0CC`R00@0C3/Q04/i8@1;>B40
BcTQ0`1<>R8204dk8`80BClT00<0B3hS04Lm8P16?2400P15>b001P14>Ql0?CHL03hg7@0n=ad0?cPN
040i7`80@CXP00<0@S/Q03lh7P0o>1h01P0o>1h203hd6`<0?cDL0`10=Qd00`11=ah0@cXM04<j7@02
04<j7@0504@k7P15?1l0AchQ04Ln8@14>ah01015?1l304Hm80P0BSlS1`1??R@0501@?bD0Dd0P05=0
801D@B40ET<S05M4901HABD0FDHV05Y79`1OB2H0H4TW061:9@1QBb@0HT`S06=>8`1TCb@0I4lR06==
9P1TCRL0IDlX0P1VD2T00`1TCRL0HT`U065;900305a:9P<0FdTU0P1JB2@205]99@0405Y8901IAb<0
EdDQ05I48080ED<O00<0DD4P05928@1DA2<00P1EAB@01P1C@b80DT8Q0551801?@240D44R059390<0
Dd@U00<0DD8S05118P1?@2400P1@@B801@1A@R<0D44R04m08@1>?b00CChO00<0CclU0P1>?R@304dm
8`80CClT00<0BSlS04Po8P15?R400P13?R000`11?Ql0@CdP048n8@02048n8@<0@clR00@0A40S048n
8`12?R<0@CdR0P10?2401P0o>b00?SXO03hj7`11?2H0?cXT03`g8@80>C@N00<0>SDO03`g8@0n>B<0
0P0k>B8203Xh8@<0>CLP00P0>3HO03Pc7`0f=1l0=S@O03Dc7P0d<ah0<C<M030d7@80;S<L00P0;C4J
02d`6`0/;aX0:bhK02X]700Y:ad0:B/N02PZ7@80:BdN00@0:2`M02L[700V:Q/09RXK0P0U:AX0100T
9b008RDN024T7@0O8Q/301hQ6P0401lR6`0K8QX06b8J01/R6P806R4I0`0I81P0100I7a/061hJ01PN
6P0H7QX201LM6@805Q`H0P0H7Q`301LM6`/05Q`J200D6QP801LI60P05QPG200C6AT801HH5`805QLI
0`0E5QP601@E5`<05AHH2P0F5aTQ01DF61005QPG0P0F5aT301DF60H051DG0`0E5QP:01HG6E005AHH
200F5aT801DF60P05QPG4@0F5aT801LI60P05QLI200I6aX@01LI60805QPG0`0G6AP301PJ6@P06A/J
0P0G6AP201PJ6@806A/J100J71/201TK6P8061XI100G6AP201PJ6@806A/J0P0J71/801XL6A0061XI
400I6aX301TK60<06Q`I0P0K7AX:01`L6P@07AdK0`0N7Q`;01lP6P<0824K0P0Q8Q`2024P7006028Q
700S8a/092@J02@T600U9AT09BHH0`0V8A/302LR7080:2<M0P0T91X00`0U9A/09RHL02LW7@0202PX
7P0302TY7`0W9ad09bLM00H09bLM0P0^:1`202dW6`<0;2HJ00<0:bDI02/W7P0Z9Qd00P0Z9Qd202TU
70@0:2@K0P0Y9A`302XV7@H0:bLN0`0Z9Qd202DV7P8092DM0P0S91`2028S6`P0824I200R8a/801lP
6PP0824K200O81X2028R6P<08b<K0`0T91`202DV7P8092DM0P0S91`;028S6`04028S7@0Q8Q`08B8L
024R7080824K0P0O81X8024R70P08B8J200R8a/8028S7@808B8L0`0P8A/301lP6P<07AhH0`0N7aT5
01lP6P807QlI0`0M7QP801`N6`<07QhL0P0O7ad3020P7P<09BDM0P0T91`502<S6`8092@L0P0U9Ad2
02HV7P80:2@K00@0:BDL02XV7@0Z9Qd0:bLN0P0/:1l;02HV70809bLM0`0X:1h0100V9Qh09BDM02DU
7@0U9Ad202@T70808b<K00<08B8J028S6`0T9Ad00P0U9Qh00`0T9Ad08R<K024R6P0202<S6`8092@L
0`0U9Ad00`0V9Qh092@L02@T700202<S6`@08R8J00<08B4I024R700Q8Q`00`0P8A/301lP6P03020Q
6`0Q8Q`08b@N00<092DO0P0S91h302@T70<08b<K0P0R8QX2028S6`808b@L0P0T9Ad202DV7P<09RHN
0P0U9Ad302@T70808R8J0P0S8a/0100T91`09BDM02HV7P0V9Qh@02DU7@<092DM0P0S91`3028S6`<0
824K:oooool002[ooooo00D0XGM50:9hAP2RN4H0XgU70:AjB0020:EkB@060:IlBP2VODT0YWe90:El
B02TNdL0XgY60P2RNDD20:5hA0090:9iA@2TNdL0YGa80:ElB02TNdL0XWU50:5hA02UO4P0YWe900<0
Ygi:00<0YGa80:=jAP2RNDD00P2XOd/20:MnBP<0YWe900<0YGa80:MlA`2VNdH00`2UNTD00`2WO4L0
ZGi90:YoBP020:ElAP80YWe700`0Ygi80:QoB@2XOdT0Z7m90:Z0D02YOdl0Z7i>0:MmC@2XOTh0ZGm?
0:^1D@2/PU880:UnB@T0Z7m;0`2ZP4h30:UoC@80Z7i<00<0YWe70:MnB02YP4X00P2ZPD/00`2YP4X0
Ygi80:ImA`080:YoBP80ZH1<0P2ZPDd20:^2CP80[8=?0P2ZQDh30:V4C@<0Z8=<202/Pdl30:b2D080
[H=A0`2^Q5880:f4C080ZXE@0P2YQ4l30:R3CP030:N2C@2YOdd0ZGm=00<0Z7i<0`2WOD/0102RODT0
XGa80:5lB02PNdL209mjAP80WWU500@0W7M309]f@P2KMT80VgI20P2JMD4209Ud@080U6ho0P2CKCh0
102BK3d0TF/l091Z>`2@JS/2095X?00408iX>`2=J3/0S6Lj08UW>@80QfLh0P26I3H00`25HcD0Q68d
08=Q<`02089P<P0?085O<@21H2/0PF0[081O;020GRh0Oed_07mM<01nG2l0OU/a07mJ<01mFS00O5T_
07YI;P1gF2`0M5L[0080LULZ00@0K4/X06i=:P1`Cb`0LU4^0P1cDRl00`1bDBh0LE0]06e?:`0806e?
:`D0LTlY0`1aCRP02@1fDRh0Me<_07MD;P1hEBd0NEH/07YH:`1kFB`0NeT[07mJ;@0307iI;00<081K
;P23GS40QF0c08MR=@26HS80QF4a08AP<023Gbl0Q60`08EQ<@27Hc<0R6@d0`29ICD308YV=P80RfLg
0P2=IcP308aV=`/0RfDf0P2<ISL0102;ICH0RV@e08US=028HS<208MQ<P0808QQ=P29HSL0RV@g08YT
=@2:I3<0R6<_08IQ;@25H2/808YU>0P0QV0c0P24GcD608EP=P80PUd`0P23GS4408AO<PP0PEla0`21
GS@2081M<`<0Oe`b101mFS0407iK<@0607mJ;@1mFbh0OE/^07aK<01kFc80NE`d0P1hG3D807QH;`80
NEH^0P1hEBd207MD;0<0MU<[00`0LeP[079G:P1`EBX0KU8Z06iB:`1^DRd0L5@_071C<@1dDR`0LU0Z
071>:01]BbD306a:900>06e;9@1WBBL0ITTY06E8:01RAbT0GdHX05e5:@1JABX0FD@Y05Q59`1GA2H0
ED@V05=49@1BABD204m4900304e48`1E@BP0ED4X0080E40W00@0DclV058n9@1B?RD0DShU201=?B<0
201=@200C3hQ04Tn8017?R40A3dQ044k8@10>R80?c/R0P0o=b82040h8`80@CTT0P12>RD303lg8080
?SHO0`0m=Ah203Pa8@0703H`800d<B00<S4O030a7`0_<1h0;S4N02h/7@0302d[7080;2XK0P0[:AX0
200V9al09bPP02PY8@0X:B409bPP02HW7`0T9Ad08b@L200U:1l8024T6`8082<J0P0Q91/3028U7007
02<V7@0S91`092DM02@U7@0U9Qh09RLO02LX800202PY8@H09BHN0P0T9Ad00`0R8a/08b@L02DV7P02
02HW7`0302@U7@0S91`08B8J00809BHP00<09RLQ02LX8P0X:B<00P0Y:R@202X[9@<09RXI0P0W:aX3
02P/6`@0:b`L100/;Ad302h_7@<0;c0N0P0`<Al0200_;1d0;R/L02dZ6`0/:AX0:bPI02dZ6`0^:a`0
;b`M0P0e<1`203Ha7@80=c8N0P0h<al00`0j=B80>cHS03`g900203`g900603Xe8P0i=240=c8O03/c
7P0l=1l0?CDP0P0n=R400`0l=1l0>S8M03Ta700303Xa800303T`7`0h;ah0>2lN0080=bhM0P0e<R40
0`0d<B00<c0O038_7P02034^7@03030]700c<240<c0Q00H0<c0Q1@0d<Ah303<`7@0603Db8@0f<b80
>38R03Xc8`0l<b@0?c<U0P10<RD03P0l=b40?CLQ03hh8P0o=b80@SLS04<f8`15=R<0ASLT04Pn9@19
?BD0B3`T04Xk901;>b@0BcTS0P1=>2<0101??R@0CSdS04hm8`1>?B<204dl8P80C3/Q0P1:>2800`1;
>B<0C3XT04`j900204dk9@0604hl9P19?b@0BClT04Pn8`17?B80AS`Q0P15>b000`14>Ql0?cPN03lh
7P0303lh7P<0@3TO0P0l=A/00`0m=Q`0?SLM03lh7P03040i7`80?C<J0P0n=1/203le7080@3HM00T0
@CLN04Dl7@14>a`0@STJ044h6@12>AX0AC`M04U08@1;@R<01P18?b0204Ln7`D0BSlQ0`19?R08058n
9@80Ed<R00`0F4@S05Y69@1KAbH0GDTX05i::@1OBbX0HD/V069<9`1RC2D0HddT06A?901UD2D206E@
8`0306A>9`1UCbP0IU0Y0080IU0Y00<0I4hW069<9@1QBb@00`1JAbH00`1IARD0F4DT05Q5900205M4
8`<0F4HR0P1GAB4205I4800305E37`1C@b80Dd<R00<0E4@S00H0DT8Q05107`1>?Qd0D44R05528`1B
@b@205=49@0<05528`1?@240CSlP04`m7P1=?Ql0Cd0Q05118P1A@R<0D44R04m08@1>?b00CclU0`1>
?R@204dm8`80C3`R00D0CClT04`n8`1:?b<0B3lR04@m8002048m7`03040m7P0o?R00?chP0080@3lQ
0P11@28204918`80@ShS00@0@CdR040l8@10?240?c/P0P0n>Ql02011?2H0?cXT03/f800i=1h0>3<M
03Xe7`0m>280?cXT0`0k>B8203Xh8@<0>CLP00L0>SDQ03Le800g=B00=S@O03@c7P0a<ad0;S8K0080
;34J00H0;C4J02`_6P0/;aX0:bhK02X]700Y:ad202PZ7@80:BdN00@0:2`M02L[700V:Q/09BTJ0P0T
:1T0100T9R408R@O020R7@0N81/201dO6P0301hP6`0O8A`06b8J00<06R4I0P0I81P201PO5`<061hJ
0P0G7AT301HL608061hL0`0G7A/;01HL6PP051XH200G6AP801HH5`P04aTI200F61L201HG6@<05AHH
1P0D5AL301DF60X05QLI8@0E5QP@01HH5`805QLI0`0E5QP601@E5`<05AHH2P0F5aU@01DF60P05QLI
200E5QP801HH5a405QLI200G6AP801HG6@P061XI200G6AP:01HH5`<05aTH0`0H6QT801TK6P805aTH
0P0H6QT201TK6P@06Q`K0P0I6aX201PJ6@@05aTH0P0H6QT201TK6P806Q`K200J71T@01LI61006A/J
0`0I6aP301XL6@806adJ2`0L71X0100M7A/07QhL01hN700N7Q`201lO7@/07b0J0`0P8A/2024R7080
8b8N00<08b8M02<S6`0S8aT00P0S8aL00`0T9AL09B0J02DP6P0202HQ6`809b8L0P0X8ad202@T6P80
9BDK00@09RHL02LW7@0X:1h0:2PN200V9Q`302dW6`<0;2HJ0P0[9AT302XV7@80:BDL0`0X91/302HR
6@809b<J0`0X91/202`X7`80:bLN00@0:RHM02TU700X91/0:2@K0P0T9ah202<V7@808RDL0P0Q91/8
020Q6@P08B8J200O81X8024R70P07b0J0P0R8QX302<S6`<092@L0P0T9ah202<V7@808RDL0P0Q91/9
020S6P<08B8L0P0P8A/301lP6PP08B8L400Q8QX;024R7003020Q6`0O81X07b0J00807QlI0P0L7AL2
01dN60807QlI0`0O81X301hO6@807AhH0P0L7AL801`N6`0401hN700O7ad07alM01lO7@80820N0P0Q
8Al202HV7P809BDM00<092@L02<S6`0S8a/00`0S8a/202@T70809BDM0P0V9Qh802XV7@P09RHL00<0
9BDK02HV700V9Q`00P0W9ad202PX7P0302TY7`0U9Ad09BDM008092@L0`0S8a/0100R8QX08B8J028S
6`0S91`202@U7@0402<T700R8a/08B8J028R6P<08b<K0P0T91`202DU7@<08b<K0`0R8QX3024Q6@80
8B8L0`0P8A/301lP6P03020Q6`0Q8Q`08b@N00<09BHP00<092DO02<T7P0T91`00P0T91`302<S6`80
8R8J0P0R8a/202<T708092DM0P0U9Qh202HV7P809BDM100T91`2024Q6@04028R6P0S8a/092@L02DU
7@809RHN400U9Ad0100T9Ad08b@L02<T700S91`2028S6`808B8J0`0Q8Q`[ooooo`00:_ooool0202O
MD<0X7I40:5gA@2RN4H0XgU70:AjB02UNdT0YWa:0P2WOTX00`2VODT0YGa80:AkA`020:=jAP040:9i
A@2QN4@0XWU50:AkA`80YGa800D0Y7]70:9iA@2QN4@0YWe90:MnBP020:QoB`040:MnBP2UO4P0XWU5
0:1g@`80Z7m;0P2WOTX40:ImB@080:QmB02VNdH0YGY50:AiA02UNTD0YW]60:QmB02ZOdX20:ElAP80
YWe700H0Ygi80:QoB@2XOdT0ZH1:0:UoC`2XOTh30:MmC@030:Z0D02/PU80[XAD00P0ZGi92@2XOd/3
0:Z0CP<0ZGm=0P2XOT`00`2VODL0Ygi80:V0BP020:Z1B`030:V0BP2WOTP0YWe700P0ZWm:0P2YP4`2
0:Z1C@80Zh9>0P2/Pdl20:^6C`030:Z5CP2YQ4d0Z8=<0080Yh9;00<0YX5:0:b3C`2/Pdl01P2/Pdl3
0:b2D080[H=A0`2^Q5880:f4C080ZXE@0P2YQ4l40:R3CP80Yge;1@2XOT`0102YOdd0XWe90:5lB02Q
O4P20:1kA`0309mjAP2NNDD0WWU500<0W7M30P2KMT8309Ye@@0609E_@02DKSl0U6ho09=]?P2BK3d0
TF/l0P2@JS/01P2BJCd0TFPl08mY?02=J3/0S6Lj08UW>@80QfLh0P26I3H01025HcD0Q68d08=Q<`23
HC<2089P<P80P5lZ00@0P5l/081N;P20GS00P5h`0P20GS403022GC<0P5dc07iK<@1lFc00NEX^07EH
;01cF2/0LULZ06]:9`1]C2T0Kdh[079A;P<0Le8_00<0LU4^06e?:`1]Cb/01`1]Cb/3079?:@D0LDhX
0P1gDbl00`1hEBl0NEH^07YG;@0207]I;00907aJ;01oFRd0OeX]07iI;01oFRd0PE`_08=N<@26HC@0
R6<f0080QF4a0`23Gbl00`25HC40Qf<c08QT=00308UU=@<0RVHf0P2;IcL308eW>080S6Hg2`2;ICH2
08aV=`0408]U=P2:I3D0RF<d08QR<`80Qf4b00P0R64f08UR=`2:I3L0RfDf08YT<`28Hbl0QV4]08AO
:PP0RVDh2026H3<308AO=@D0QF0f0P22GC0208=N<@<0Q5lb00<0QF0c085O<@21Gc401P21Gc43085N
=0<0P5dc0P1oG38307eJ<0D0OU/a00H0P5/^07iL;`1nG2l0OE`a07aL<`1jGCD207UM=P80MEP^101f
FBl207MJ<080NEH^0P1hEBd207MD;0<0MU<[00`0LeP[079G:P1`EBX0KU8Z06eA:P1^DRd0L5@_075D
<P1dDbX0Le8Y071?9P1^CB@206a;8P80KD`S00H0J4XX06I9:@1UB2P0HTLY0617:@1MABT205Y5:P80
F4DW00<0ED@V05A59P1BABD00P1?A2@00`1=A2<0E40W05A09`0605A09`P0CCdS00P0CD0P04do8P1:
?b40AchQ04@m8@11>b40@3XR03lk8P80?cLR0P10>2<01011>B@0@SXU048j9@13>bH2044f8080@3DO
0`0o=1h01P0n<ad0=c0P03L`800f<200=34P03<b8080<C8P00<0<3<P02h/7@0^;1d00P0]:a`302`Z
6`0302/Y6P0V9al09bPP0080:2TQ00@09bPP02HW7`0T9Ad08R<K200U:1l8024T6`8082<J0P0Q91/4
028U70808R<K00@092DM02DV7P0W:200:2TQ0P0Z:b<502DV7P<092DM00<08R<K02<T700U9Qh00P0V
9al0100T9Ad08R<K024R6P0U9R0202HW8@0302LX8P0X:B<0:BXT00<0:R/U0`0U:AP302HZ6@809b/J
1@0Y;1/302X]7080;RlM00@0;c0N030a7`0a<R00<C8P0P0b<b40200`;Ah0;R/L02`Y6P0Z9aP0:BHG
02XW600[:1T0;2TJ0`0d;a/00`0e<1`0=S4M03Lb7P0203Lb7P0;03Xe8P0k=R<0?3LT03dh9@0l=b@0
>cHS03Td8@0h<b00?S<O03ld8010=B400P11=R800`0o=200?C8N03/`700203db8080?34O00D0>c0N
03X_7@0j;ad0>BhL03Ld8`0203Hc8P0303Db8@0d<B00<c0O0080<RlN100g<B<403H`8P@0=C8O100d
<Ah203Ld8`0703Xd900l=BD0?C@U040d9P11<bH0@S@W03hi9@0203lh9@03044i9P13>2H0A3LV0080
AcLW00H0BT0W04Xn9P19?BD0Bc`U04/k901<>R@204hi900404lm9@1>?2@0CS`T04hl9080CC/S0P1<
>R80101:>280BcTS04/i8`1<>R@204dk9@80CS`V0P17?B8204Hl8@0404Dk8014>Ql0@cTN04<i7P80
A3dS1P13?28203lh7P06040i7`11>R00@c`R04@m8`15?R@0ASlU0`11=ah2048h7`0<04<i8014>R40
A3XQ04Dk8P15?1/0@cXI040g5P0n=A@0@3LF04<j6@18?ah0C4<R0P1;@R4204Y18080BD0O0P18?ah3
04Xo7`D0BChN101C?bH4058n9@0805Q48`1IAB@0FTHU05a89`1MBBP0Gd/Z061<:`1QCB`206A<:006
06A<9P1UCRD0ITlU06I?8`1WD2@0Ie4R0P1UCbP01P1VD2T0Ie4Z06I@:@1TCRL0HT`U065;9080FDHU
00@0F4DT05M48`1GA2<0ET<R0P1E@R400`1GAB40ET@P05I4800505I4800:05=38P1DA2<0EDDT05A4
8`1C@b80DD4P04hn7@1=?A`0DD8S05939080Dd@U00P0DT<T05118P1>?b00CChO04Xk701;?1d0CSlP
05118P80DD8S00<0Cd0Q04ho801>?R@00P1>?R@204dm8`<0C3`R00P0CClT04`n8`19?R80AchQ04@m
8012?Al0@C`N03ll7@<0?chP00<0@3lQ04508P12@B<00P12@B<2048n8`04044m8P10?240@3`Q03lk
8080?SXO00<0@SdW03lj900k=R000P0h<ad00`0j=Al0?CPR03lj900303/i8P<0>SPQ0P0i=b004@0k
=R80>3HQ03Pf8@0g=B00=3<N030b700]<AX0:c0I02X_600/<1T0;2lJ02/^6@0Z;AX0:B`K02PZ700X
:Qd09bTL0080:BdN00h0:2`M02L[700V:Q/09BTJ02@X6@0S9aP08bDP028T7`0O8A`07AlJ01`N6@0M
7aX07R0K01lQ70@06R4I0P0I81P201PO5`8061hJ0`0G7AT301HL608061hL0`0G7A/;01HL6PP051XH
200G6AP801HH5`P04aTI200F61L201HG6@<05AHH1P0D5AL301DF60X05QLI8@0E5QP@01HH5`805QLI
0`0E5QP601@E5`<05AHH2P0F5aU@01DF60P05QLI200E5QP801HH5a405QLI200G6AP801HG6A005aTH
2P0F61L301LI60<061XI200I6aX201LI608061XI0P0I6aX401XL6`806A/J0P0H6QT401LI608061XI
0P0I6aX201XL6`P06Q`I400G6AP@01TK6P<06A/H0`0J71T201/M6PP071`J00@06a/I01`L6P0L71X0
7AdK0`0N7Q`201lO7@/07b0J0`0P8A/2024R708092<O00L092<N02<S6`0S8aT08b<G028R5P0R8aD0
91lI00809B0J00<09R4K02LR700W8Q`00P0X8ad01P0S8aT092@J02@T6P0U9A/09RHL02LW7@80:2PN
200U9Qh302dW6`80;2HJ0`0[9AT202XV7@<0:BDL0`0X91/302DQ60<09R8I0P0W8aX202dY800402`X
7`0[9ah0:BDL02PT6`809b<J0P0T9ah202<V7@808RDL0P0Q91/8020Q6@P08B8J200O81X8024R70P0
7b0J0P0R8QX302<S6`<092@L0P0T9ah202<V7@808RDL0P0Q91/9020S6P808B8L0`0P8A/301lP6PP0
8B8L0P0R8a/4024R6P80824I200Q8QX8024R7004028S7@0Q8Q`08B8L020Q6`807b0J0P0N7aT0100K
71H071dG01`M5`0M7QP201hO6@807b0J100N7aT201dN608071dG200L7Q/401lO7@80820N0P0Q8Al3
02HV7P0302DU7@0T91`08b<K00@08b<K0P0T91`202DU7@809RHN0`0[9ah202XV7@<0:BDL200V9Q`2
02DU6`0402HV700W9ad09bLM02PX7P80:BTO00@09BDM02@T700T91`092@L0P0S8a/2028R6P03020Q
6@0R8a/08b@L008092DM00<08b@L028S6`0P8AT00P0R8QX202<S6`<092@L00@09BDM02<S6`0S8a/0
8b<K0P0R8QX4024Q6@808B8L0`0P8A/301lP6P08020Q6`0R8ad092DO02DV800V9b409BHP02@U7`0R
8ad302@T70<08b<K0P0R8QX2028S6`808b@L0P0T9Ad202DV7P809RHN0P0U9Ad302@T700702<S6`0P
81P08B4I028R6P0S8a/092@L02DU7@0202HV7Q009BDM100S91`2028S6`808B8J0`0R8ad[ooooo`00
:_ooool01P2RMd`0XWM:0:9gBP2SNDT0XgU70:AkA`80Y7]50P2UO4P0102TNdL0XgY60:=jAP2RNDD2
0:5hA080YWQ600<0XgQ50:9iA@2QNDD00P2NND@00`2MNT@0XgU70:=iA`030:AjB0<0YG]90`2VNdP3
0:EjA`80Y7U6202WOTX30:ImB@<0Ygi:0P2XOd/80:V0C080ZX5=00@0ZH1<0:QoB`2XOd/0Ygi:0P2V
ODT90:MmB`060:YoE@2ZOe@0ZWmD0:UnD@2YOdl0ZGm=0P2XOd/20:QoB@<0ZH1:0`2ZPD/02@2/PEH0
Zh1C0:YoDP2YOdl0ZGm=0:Z1C@2[PT`0[8==0:b3C`030:^2CP<0ZX5=00@0ZH1<0:Z0D02[PE40[89@
0P2^QE401P2/Pdd0Zh9:0:Z1B@2ZP500Zh5A0:b2D080[XEA00<0[8==0:^2BP2ZPDT0202/Pdl20:b7
DPH0ZhIA0`2YQ5020:R3C`<0Yh9>0P2YQD/0102YQ4d0Z8=>0:N2C@2VPDd20:J0C`0@0:=nBP2TOd/0
YH1<0:AoB`2SOTX0X7]709ehA02KMT80WgY609]f@P2GLSh0VGA009ehA02ONTH0VgI209Mb?P80UVm4
00<0UFi309A]@P2CK4400P2BJd02095Z?`05091Y?P2?J3d0SVLl08eV>`2;I3T00P2:HcP05P27HC@0
R68e08YT=`2;ICP0RV@g08US=P26H3<0QElb08EQ;`24H2h0Q60`08=N<@22GC40PE`b081K<@20FS<0
P5H^07mE;@1mERd0NeH/07YE:`1gE2X207ED:@0907EB;01dDB/0Le0Z07=@:P1dDB/0MU<]07QE;`1i
ES00Ke8X0080Ke8Z00@0KU0Z06i@;01]Cbd0KDl]0P1]CRl806a>:P08079A;P1dDRl0MU@a07UE<`1k
E3<0Ne8b07aA<@1jCbl207aI;`80OEX`00@0OU/a07mL<P1oG380Oe`b0P22GC0208=N<@<0Q5lb00H0
QF0c08UP<P29H380RV4c08]R=02<HcD208eT=P0308iU=`2<ISL0S6Hg00<0RfDf0`2:I3D808]U=P@0
QV@f0P25HcD208AR=0P0RFDe00<0S6<e08]R=029H3800P28Gc401`29H380Rf8d08aS=@2=J3/0RfHi
08QS=P25H3<00`23GS400`24Gc80Pf0f089O=@02089O=@80PEhd0P20GC<807mL<P80OEd/00L0Oed]
08=O;`24H300QV0a08UP<P2:HC<0PEhd0080P5dc00<0Oe`b07iK<@1mFS000P1lFBl307eJ<0<0OU/a
0`1oG38207iK<@0807eJ<01lFBl0NeP^07]H;P1jEbd0OEX`07aI;`1kF2h207UF;00907]H;P1lFBl0
OEX`07iK<@1mFS00NeP^07UF;01hEB/0NEH/00<0NUL]00<0LUD]07AG;`1eF3000P1fFC400`1dEbl0
LUD]071C:`0206mB:P0406iA:@1]D2P0JdhV06Y=9@80JD`T01<0L4TZ06e9:@1YB2T0I4LY05i7:01G
ARP0DdHV05159`1IARP0F4@Y05E4:01B@RP0Cd4W04dn9`1:?RP0BCdW05519`1@@2H0CShT0080CCdS
00`0CShT05109P1A@BL0D40V04hn901<?280Bc/Q04`l8P1>?R@0DD4W0592:01>?RD204dm9080C3`S
0P1=?B@0501>?RD0@SPM04<i7P16?240AcdR04Pn8`17?B80AC/P04@j7`0m?B40?SdQ03lk8010>Al0
@SHN04<d7@15<ad0A38L03Xb7@0k<ah0?3@O0P0m=B000`0k<ah0>C4L03L_6P0202d`7`0602h`8P0^
<2<0;2hS02X[8`0W:2009RLQ0`0V9Q`202LW7@<0:2PN0P0S9AX302@V6`<09BLL200S91`301lR6`80
82<L0`0Q91d2024T6`808RDL0P0S9Qd202@W7PP09RTN00D08B8L028S7@0R8ad08b@N02@U7`0202DV
800302HW8@0U9a`09BLL00L09BLL0`0T9Ad502DV7P809bTN0P0X:Ql302T[800402X/8@0d;a/0=2lK
03@_6`80=C0L0`0f<Ad203L`800403H_7`0e;Qh0=2dM03</7080<R/K00H0<BhO038_800c<240=34R
03Hc900g=2D203Pe9PD0>SDR0`0k=R<2044i9P03040h9@0o=b@0?SHS0080?3@Q00@0>c<P03Ta7P0i
<Ah0>C4N0P0j<Ql303/c800303P`6`0i<A`0>c<N0080?3@O00<0>c<N03Ta700h<1/00`0e<Ql203Hc
80<0=c@Q00<0=S4M03Lb7P0i=2000P0j=B403P0i=200=c8N03Ha7@0o<b<0@3DS04<h9P15>RH0AS/U
04Hl8`15>b00A3XO04/k8P1:>R40B3PO0P17=ah03`18>1l0BSXQ04/k8P1A@RD0D44T04hm8@1>>Ql0
CcXO054i7`1C>b40EC/R05]39`1I@BD0EclS05@l800205<k7`0305@l801E?B40E44S0080E44S0`1C
@282058o8@0605Dk8P1D?280E3`R054l8@1@?240CSdQ0P1<?B0204do9@0604`n901:?280BC/Q04Pj
8017>Al0ASPN0P19?b@00`18?R<0AcdR04Hl8@0204Dk800=04@j7`14<QX0A38J04@b6P16=1`0B3HN
04/i8@1=>b<0CcdU050n9P1>?b00Cd0Q05528`020593900305528`1?@240CSlP00P0CS`T0P1>>Ql0
101?>b00D3`Q050l8@1A?B82058n8`80Dc/O00@0E3`P05Dm8@1F?R80EShR0P1G?b<04P1MAB40GTHR
05m78`1PB2@0HDTU069:9P1SBbL0I4`X065B9`1PDBH0HU4V06=@9P1TCRD0IDhU06A=901UC2@0GT`T
05m=9@80H4hV00H0GddU05e;8`1KBB40FTPP05M8:@1HBBX205U::`0405Q9:P1EARL0Dd@U05528`80
E44S00H0DD0R05118P1>@B40C44Q04]0801:@B0805528`<0Bd8U0`1:@B@204U08`0304Xo8`1;@2@0
Bd0T0080Bd0T00<0BSlS04Pm8@18?B400P1<?R@00`1:?R@0BClT04M0900204I1900904A08`1:?R@0
BclU04a09P1=@BL0C40V04Xn9017>b40ASXP00P0@c`R00<0?cdV03dk900l>R<00P0k>B800`0l>R<0
?C/T03lm9P0303Xh8`80>CLR0`0h=R40100i>bD0>3XT03Pj900h>R@203Li8`80=SPR00T0=c4S03@a
8P0d<B80<c0Q034_800^;al0;2lN02X^7@0Y;A`00P0`;ad03P0_;Ah0;R`O02d[7`0]:R40;2TP02`Y
8P0V:B009BPO02@W7P0S9Qd08RDL024T6`0P8aX07b8I0`0N9Ad201dT70<072<K00@0728N01/Q7@0K
8Ad06b4M0P0J81`201TO6`P05adI200G7A/801TK6PP051XH200G61X00`0L7Al06AXL01@E5`02010A
4`0301<D5P0G61X06Q/M00P05QLID@0E5QP801HG6A005AHH200F5aTh01DF60P05QLI200B61P@01DF
60P05QLI2@0E5QP801HG6@P05aPJ200F5aT801HH5b005aTH:00I6aX801LI61006A/J0P0G6AP00`0H
6QT06A/J01XL6`0201`N7@0301dO7P0K7AX06adJ00H06adJ2@0L71X801dM6`P0824K200R8A`802<R
7@0302LS6P0X91/0:BDL0080:bLN00<0:BDL02PT6`0W8aX0200V9Qh@02TU70T09RHN0`0U9Ad202@T
70808b<K400Q8Q`3028S7@808B8L0`0P8A/801lO7@807AhH0P0N7aT201lP6P80824K0P0R8ad4024R
7080824K00@07AhF01lP600Q8QX08R<K0P0S91`00`0R8a/08B8J02<R7@0202<R7@808R4L0`0Q81/9
024R700301hO6@0O81X08B8L00808R<M00<08B8L01lP6P0N7aT0200P8A/2024R70<0824K0`0O81X8
020Q6`P08B8L400P81h801`N6`P06adJ00P071hK01dO700O8Ah0828O024S800P8Ql07b4N01hP7@80
8R<K0P0S91`302@U7@0302DV7P0S8a/08b<K008092@L0P0U9Ad202HV7PP08b<K200U9Ad302LX8080
9RLO0`0U9Qh8028S7@P08R8J200R8ad9020Q6`807AhH0P0N7aT201lP6P80824K200Q8Q`3020Q6`80
8B8L0`0R8ad3028S6`0302<T700T9Ad09BHN00809BHN0`0R8ad2024R70<0824K200R8ad2020Q6@03
024R6P0R8a/08b@L008092DM00<09BHN02PY8@0W:2000P0W:20202HW7`809BHN200Q8Q`3024T7B_o
oooo000Zooooo`060:9gC02RMdX0XWM:0:=iB@2SNDL0Y7]70P2TNdD00`2UO4P0Y7]70:AkA`020:=j
AP80XWU500H0XGQ40:IhAP2VN4H0Y7U60:9iA@2QNDD209iiA00409ejA02SNDL0XgU70:=iA`80Y7Y8
0`2UNdT40:EjA`@0YW]8202WOTX30:ImB@<0Ygi:0P2XOd/80:V0C0030:Z1C@2YP4`0ZH1<0080Z7m;
0P2WOTX00`2VODT0Yge;0:MmB`070:MmB`80ZWmD00@0ZWmB0:UnD@2YOdl0ZGm=0P2XOd/20:QoB@<0
ZH1:0`2ZPD/0202/PEH0Zh1C0:YoDP2XOTh0Z7i<0:Z1C@2[PT`0[8==102ZPDd40:^2CP030:Z0D02[
PE40[89@0080[HA@00H0[8==0:^2BP2ZPDT0ZX1@0:^1D@2/PU020:j5D@030:b3C@2[PTX0ZX5900P0
[8=?1@2[QU430:b7DP<0ZXEA0P2YQ5030:R3C`80ZHE;00@0Z8=<0:R3CP2WPTd0Yh9>0P2VP4l20:Ao
B`0>0:F0C02TOd/0Xgi:0:1kA`2MN4@0VgI209mjAP2KMT80V7<o09Ud@02MN4@0WWU509]f@P2GLSh2
09I_A00409E^@`2DKD80Tfa109=/@@80TV]00P2AJSl03P2@JCh0SVLl08eV>`2<ICX0Rf@i08YS>028
HSD0RF<f08YT=`2;ICP0RV@g08US=P27HC@0QElb0P25HBl01P24H300Peha089M<@21G380P5/a081J
<`80PEL_00l0OUL^07aG;@1kER`0N5D[07MF:`1fEBX0MU<]07EB;01dDB/0Le0Z07AA:`1eDR`0Me@^
07QE;`1^DBL00P1^DBT0101]CbT0KDl[06a>;01/CR`206a=;PP0K4hZ00P0Kdh[075@;@1dDRl0Me<a
07YC<P1jDC40NE0`07Y?;`80NeP^00@0O5T_07eJ<01mFS00OU/a0P1oG382089M<080Peha1024Gc82
08UP<P0408YQ<`2;HS@0S6<e08aS=@80SF@f102:I3D<08]U=P0408MU=`26I3H0QV@f08IT=P80QF<e
0P24HS@808UU=@0308aS=@2;HS@0RF0b0080R5la00L0RF0b08]R=02<HcD0S6Lj08YU>028HcH0QF0c
00<0Peha00<0Q5lb089O=@22GcD00P22GcD2085N=080P5dc201oG38207iN;@04081N;P23Gbl0Pel_
08EO<080R5la0P20GC<0101oG380OU/a07eJ<01lFBl207]H;P<0OEX`0`1nFc4207mL<P@0OEX`101l
FBl00`1mFS00O5T_07]H;P0207UF;00907]H;P1lFBl0OEX`07eJ<01lFBl0NUL]07QE:`1gE2X0N5D[
0080NEH/02@0NUL]07=F;P1dEbl0MEP`07II<@1eF300M5L_079E;@1`Db/0LE@/071C:`1_DRX0KE0X
06a?9`1ZCBD0JD`T06Q;8`1^BRX0K4TY06Y9:P1SB2X0H4TZ05]8:01GB2T0EDPX05Y5:01IARP0Ed<X
05=2:01@@2L0CSlX04Xn9P1:?RP0D40V04lo9@1=?B<204`l8P0304dm8`1??bD0D40V0080CShT0`1=
?B<0101>?R@0D40V05519`1<?2<204dm9080CShU0P1=?B@0101<?2<0A3XO04Dk8016?24204Lm8P0>
04Hl8@14>Ql0@cTN03hm8@10?240@3XP040i7`12=Qh0A3DN04@d7@15<ad0>S8M03/c7P0l=1l203de
800403/c7P0i<A`0>30K02l`7P80;c0P00D0;c0R02h^8P0[:b40:BTQ02LW7`0302PX7PD09bLM100V
:1d402DW70P092DM200P8a`2024T6`808RDL0P0S9Qd202@W7PP09RTN0`0S91h302@U7`809BHP2@0U
9a`202@U7@H09BHN0`0W:Ah202PZ7`<0:B/P00@0<2dJ034^6`0a;Q/0<BhK0P0b;a`203<`7@80=RlO
0P0e;Qh203@]7@80<b`L00D0<2dN034^7`0a;Ql0<RlP03<`8@0203@a8P0303Db8`0h<b00>3<P00@0
>C@Q0P0j=B8303lg9080?SHS0P0m=B800`0l=240>S8O03Xb7`0303/c80<0?3@Q00<0>S8M03/c7P0l
=1l00P0m=B00100l=1l0>c<N03Xb7@0f<b0303Ld8@80>3DR0P0i=R<00`0i<ad0>S@N03`f800203dg
8@0703`f800j=1h0>C<M03ld8P10=B<0@cPT04Dj900204Hl8`0504Dk8014>Ql0Bc/Q04Xj8018>1h0
0P17=ad03`18>1h0BSXP04/k8@1B@bH0DD8U04ln8P1@?240D3/P05<k8@1D?280ES`S05a59P1J@b@0
F44R05Dn7`0205@m7P0305Dn7`1F?b00ED8R00<0E44Q0P1C@202058o7`0605Lm901E?B<0ECdS05<n
8`1A?B80CchR0P1=?R4204do900404`n8`1;?B80BS`Q04Xl8@80BC/P0P1:?b<304Tn8P<0B3dQ0P1:
>Al02P1;>R00C3/Q04dl8P1??R@0DD0V05919`1C@RP0CSlP04m08@1@@B8205528`0305118P1?@240
CSlP00P0CchT00<0E40U05E19P1E@BH00P1F@RL0101G@bP0F4@Y05Q4:@1D?Ah205Dn7`0305Ho801G
@240F44R0080FD8S00H0G4HQ05e78P1NB2<0GdTT061:9@1QBbH2069<9`80H54V00L0HE0U069?9@1S
CB@0HddT06A=901SC2<0GT`T00<0GddU00@0GT`T05a:8P1IAal0F4HN0P1FAbP205M8:@0405I7:01D
ABH0DT<T05118P80E44S00H0DD0R05118P1>@B40C44Q04]0801:@B0805118P<0Bd8U0P1:@B@304U0
8`0304a19@1;@2@0BSlS00D0BChR00D0CClU04`n901:?R@0BClT04M0900204E08`0904A08`19?B<0
BShT04/o9@1<@2H0BclU04Tm8`17>b40ASXP00P0@c`R00<0?S`U03dk900l>R<00P0k>B800`0l>R<0
?C/T03hl9@0203Xh8`<0>CLR0`0h=R4303Dg8@80=3HP0`0c=Al01`0e;b40<c0Q03<`8@0c<240<BlP
02h_7`0/;ah00P0Z;Qd2030_7@0302l]7P0^;1l0;B/O0080;2TP00T0:bPQ02DX7`0U:1l092LN02<V
7@0R9A`08B@K020S6P0O8QT00P0N9Ad301dT70<072<K100K8Ad201XP70806AlK200G7AT801LM6`P0
6A/J200D6QP801LH6P0502d^<00Y:R`08b@V01dN800I6Q`02`0F5aUA01DF60P05QLI400E5QP801HG
6CP05AHH200F5aT8018H61005AHH200F5aT901DF60P05QLI200G61X801HG6@P05QPG800G6APX01TK
6PP05aTH400I6aX201LI600601PJ6@0I6aX06Q`K01/M700L7Qd07AlN200K7AX901`L6PP07AdK200P
8A/8028Q70P08b8M00<09b<J02PT6`0Y9A`00P0[9ah00`0Y9A`0:2@K02LS6P0802HV7Q00:BDL200V
9Qh402DU7@8092@L0P0S8a/@024R70808R<M0`0Q8Q`3020Q6`P07alM0P0M7QP201hO6@807b0J0P0P
8A/8024R700301hO5`0O81P08B8J00<08b@L00<08R<K024R6P0S8Qd00P0S8Qd2028Q70<08B0K2@0Q
8Q`00`0N7aT07b0J024R7002028S7@03024R700O81X07QlI00P0824K0P0Q8Q`3020Q6`<07b0J200P
8A/8024R7100820N200L7Q/801/M6P0801`N6`0M7a`07b4N020R7`0Q8b00828O01lQ7P0N81d2028S
6`808b@L100T9Ad202<S6`8092@L0P0U9Ad202HV7PP092@L200U9Ad202LX80809RLO0`0U9Qh00`0T
9Ad08R<M028S7@06028S7@P08R8J200R8ad9020Q6`807AhH0P0N7aT201lP6P80824K200Q8Q`3020Q
6`808B8L0`0R8ad3028S6`0302<T700T9Ad092DM00809BHN0P0R8ad3024R70<0824K200R8ad2020Q
6@03024R6P0R8a/08b@L008092DM00@09BHN02HW7`0V9al09RLO0P0U9Qh302@U7@P08B8L0`0Q91d[
ooooo`00:_ooool01P2RMd`0XWM:0:9gBP2SNDT0XgU70:AkA`80Y7]50`2TNdL20:=jAP<0XWU500T0
YgU70:IhAP2TNDH0XgY60:5iA@2ONTD0WWU409ejA02RN4H00`2SNDL20:AjB080YG]90P2TNDH20:Ej
A`040:IkB02WO4T0Z7e:0:QmBPP0Ygi:0`2VODT30:MnBP80Z7m;2`2YP4`20:QoB`<0Ygi:2@2WOD/0
1P2ZOe@0ZWmB0:YoDP2YOdl0ZGm=0:V0C0@0Z7m90`2YP4X30:Z1B`090:b1EP2[P5<0ZGiA0:QnCP2X
OT`0ZH1<0:^2C02/Pdd0Z7m;0080ZH1<00P0ZX5=0:^2CP2/Pdl0[8=?0:f4D02YOdl0ZX1@0:b2D080
[HA@00H0[8==0:Z1B@2YP4P0ZX1@0:^1D@2/PU020:j5D@030:b3C@2[PTX0ZX5900P0[8=?00@0ZHA?
0:Z5D02ZQE00ZhIA0P2/Qe820:f8D`<0ZhIB0P2ZQE430:V4D0080:V5B`2XQ4X0Z8=<0:R3CP2WPTd0
Yh9>0:N1D02VP4l40:AoB`080:9mB@2PNdL0WWU509ehA02ONTH0W7M309Ye@@2KMT8209ehA00709]f
@P2HLcl0Ug5409MaA02FL4<0UFm209A^@@0209=]@080TV`o00D0TF/n091Z?@2?JC`0SVPk08aV>@02
08]U>080RF<f0`2:I3L00`29HcH0Qf4d08IP<`0208EQ;`0308AP<023GS40PUda0080PE`b00`0P5Xc
08=I<@23FC40P5T`07iI;`1mF2h0NUL]07UH;@1hEb`0N5D_07MD;P1eDR`307AA:`0307EB;01fDbd0
KU4W0080KE0X00@0KDlY06a>:P1/CR`0K4h/0P1[C2d806a>:P0606]=:@1^CBX0L4l/07=A;P1eDBl0
Me0_0P1hCbl207YG;@0307]H;P1lFBl0OEX`0080OU/a00@0Oe`b089M<022GC00PUd`0P23GS4308AO
<P80QV0a00<0Qf4b08QR<`29Hc@00P2:I3D01@2;ICH0R68c08QR<`29Hc@0RV@e0080RfDf0P2<ISL8
08]U=P<0RF@g0P28HcH308MR=@P0RFDe00<0RV@e08US=028HS<00P27HC802@28HS<0RF<d08YT=@2;
IST0RVDh08MR=@25H3<0Q5lb08=N<@0208AO<P<0PUle0P21GS@3081M<`P0Oe`b0P1oGc001020GS00
PUd`089M<024GS4208IM<@0607mL<P1nFc40OU/a07eJ<01lFBl0NeP^0P1jEbd307eJ<0<0OU/a0P1o
G38407aI;`D0OEX`00X0O5T_07]H;P1iER`0NEH/07]H;P1lFBl0OEX`07]H;P1jEbd0N5D[0P1fDbT0
1P1gE2X0N5D[07QE:`1iER`0LeH^07AG;`<0MEP`01<0LeH^079E;@1aE2`0LeH^079E;@1`Db/0KU4Y
06a?9`1ZCBD0J4/S06M:8P1]BbP0K4/X06U;:@1UBbX0HT/[05i;:`1KBbX0FT//0080FdHW00@0F4DW
05A39`1B@BL0D40W0P1=?RL00`1??bD0CShT04`l8P0204/k8@0804`l8P1>?R@0CclU04`l8P1=?B<0
CShT04lo9@1@@2H204lo9@0404hn901:>R40C3`S04hn9@80D40W00<0CShU04`l8`1:>R400P17?B82
04Pn8`0<04Lm8P15>b00@cTN048h7@11?B80@S`R044k8@11>R00@SPO048f7P14=Ah0@c@M0P0l=1l3
03de800303/c7P0j<Qd0>C4L0080<34O00H0<34Q030a8`0_;b<0;2`R02XZ800X:20202XZ8080:BTO
00@0:2PN02LW7@0V9Q`09RHL0`0Y:b000`0X:Ql09bTN02HX7@0202DW70P09RLO00D08bHO028U7P0R
9Ah08B@M020S700201lR6`0301hQ6P0Q91/08B@K00808RDL0P0S9Qd202@W7PP09RTN00@09RLO02DV
7P0U9Qh09BHN100T9Ad902DW70P09BHN0P0V:1d202LY7P<0:2XO00@0:B/P02h[600^:aP0;R/H0P0_
;1T3030]6P04038/7P0c;Al0<bdO03<]7`<0=2hP00<0=BlQ034^7`0a;Ql01P0a;Ql303Ha7P80=c8O
0P0h<b000`0i=240?3@Q03`d8@0303de8P<0?SHS0`0l=24203de8P<0?SHS00<0?3@O03de800n=R40
0P0o=b800`0n=R40?CDP03`d7`0303/f8P80?3LS0`0m>2@00`0n=R40?cLR040h8`02044i9009040h
8`0o=b80?SHQ040e8`11=R80@cPT04@i8`15>b80AC/P0080AC`O00<0C3`R04/k8@1:>R000P19>Al0
3`1:>R00Bc/Q04`l8P1CA2D0DT<T05508P1B?b40DchQ05Dm8@1F?R80F3hS05a59P1KA2D0FT<T05Q1
8P0305M08@0405Q18P1E@R80ED8R05E28P80E44Q0`1C@2001P1I?b@0EclS05Lo8`1E@2<0Dd0R0550
8P80Cd0Q201>?R@304Xo8`<0Bd0T0P1<@BD405919`80Dd8X0`1D@bT00`1=?Ql0CSlP04m08@020511
8P0304m08@1>?b00CChO00P0D3lU00@0ET<U05M49P1GA2H0Ed@V0`1HABL01P1IARP0Ed0Q05M08@1H
@B80FD8S05Y39080Fd@U00<0G4DV05e78P1MAb800P1NB2<0101OBB@0H4XU065;9P1QBbH205e@9P07
05i?9P1OCBD0H4dU069<9@1QBb@0HTXT05i<9P0205m=9`0505i<9P1LBR@0FTPR05M57`1E@ad0101D
ABH0101CA2D0DT<T05118P1?@24205A18`0605508P1@@B80CT4Q04a18@1;@200BT4P201@@B8204]2
9@80BT4T0`19@2<02@18?b80CT<W04a19@19?R80Ac`P04Hk7`17?200BSlS04]0900204do9@0604Xn
9019?b@0ASlS04E08`14?b80@clR0P18?R<304To900304Pn8`16?240AS`Q00P0@c`R00<0?S`U03dk
900k>B800P0j>240100k>B80?C/T03hl9@0j>2<303Tg8P80>3HQ0P0g=B03038d7P80<C<M0`0`<Q`0
1`0c;Al0<BhO034^7`0a;Ql0<2hO02h_7`0]<1l00P0/<1l202d^700302`]7@0[;1h0:RXN0080:BTO
00D0:2PP02@W7P0T9ah08bHM028U7002024T6`8082<J00@07RDM01dT700M91`07B@L0P0L8a/201/R
6P<06b4M0P0J81`301TO6`P05adI200G7A/801TK6PP051XH200G61X0200/;Bl0:R/]02HW:@0R8bD0
7AhP01TJ700F5aT051DG200F5aUA01DF60P05QLI400E5QP801HG6D005AHH200B61P@01DF60P05QLI
2@0E5QP801HG6@P05aPJ200F5aT801HH5b005aTH:00I6aX801LI61006A/J00H05aTH01PJ6@0H6QT0
6A/J01XL6`0K7A`201`N7@P06adJ2@0L71X801dM6`P0824K200R8A`802<R7@0302LS6P0X91/0:BDL
0080:bLN00<0:BDL02PT6`0W8aX0200U9Ad@02PT6`/09BDM0P0T91`302<S6`P0824K200Q8Q`0100R
8ad08B8L024R700Q8Q`2020Q6`807b0J200O7ad201dN60807QlI0P0O81X2020Q6`P08B8L00P07b0H
020Q6@0R8a/08b@L02@U7@0S91`08R<K024R6P<08b8M0P0R8A`3024P6`T0824K00<07QlI01lP6P0P
8A/00P0Q8Q`00`0P8A/07b0J01hO6@08020Q6`808B8L0`0P8A/301lP6Q00824K400O7ad801`N6`T0
6adJ00<071hK01hP7@0P8Ql00P0P8Ql201hP7@<08R<K0P0S91`302@U7@808b<K0P0T91`202DU7@80
9RHN400U9Ad302HW7`809BHN0`0T9Ad8028S7@P08R8J200R8ad901lP6P807AhH0P0N7aT201lP6P80
824K200Q8Q`3020Q6`808B8L0`0R8ad3028S6`808b@L0`0T9Ad0100R8ad08B8L024R700Q8Q`2020Q
6`807b0J200R8ad2020Q6@03024R6P0R8a/08b@L008092DM00@09BHN02@U7@0T9Ad092DM0P0S91`3
028S6`P08B8L0`0Q91d[ooooo`00:_ooool01P2RMd`0XWM:0:9gBP2SNDT0XgU70:AkA`80Y7]5202S
NTH20:MiA`030:AiAP2SNTH0XWY60080WgY500<0WW]50:9hAP2RN4H00`2SNDL30:AjB080XgQ500H0
Y7U60:IkB02WO4T0Z7e:0:UnB`2ZOd`80:MnBP<0YWe90`2WOTXB0:QoB`T0Z7i<0P2ZOe80102ZP500
ZGm=0:V0C02YP4X20:QoA`80Z7m90`2YP4X30:Z1B`0C0:^0E@2ZOe80ZGiA0:QnCP2XOT`0ZH1<0:Z1
B`2[PT`0Ygi:0:QoB`2YP4`0ZX5=0:^2CP2/Pdl0[HA@0:j5D@2YOdl0ZX1@0:^1C`020:f4D0060:^2
C02ZPDT0ZH180:Z0D02[PE40[89@0P2^QE400`2/Pdd0Zh9:0:Z1B@080:b3C`80ZHA?00<0ZXE@0:^6
D@2/Qe800P2]R5<00`2^RE@0[8MC0:b7D`030:^6DP<0ZXEA0P2XQ4X0102XPd`0Z8=>0:N2C@2WPTh2
0:N1D0070:F0C02TOd/0Y7m;0:=nBP2RODT0XGa80:1kA`0209mjAP0309iiA@2LMd<0W7M30080W7M3
00P0VWE109Ud@02HLT<0V79309Ma@P2FL440UFm009A^?`<0Tfdn00D0TV`m095[?02@JS/0SfTj08eW
>00208aV=`@0RV@g0P29HcH208QR=@0808IR<025HBl0QF4a08AO<P23GS80PUdc085L<P21Fc@208EK
<`0:089K<P20Fc40OeX`07aI;`1kFRl0NUT^07YG<@1iES00Me@^07EB;080M54[00<0ME8/07IC;@1]
D2H00P1]D2P0101/CRP0K4hZ06a>;01/CR`206]<;@P0K4hZ00d0J4`W06Y<:01[CBT0Kdh[075?;01d
D2h0MTl^07M@;`1gE2X0N5D[07UF;01jEbd0NeP^0080OEX`00<0OU/a085L;`21G2l00P22GC0208=N
<@80Q5lb0P24H3001025HC40QV8b08MS<`28I3@208UU=@0608IP<@27HC80R68c08US=02:I3D0S6Hg
0P2=IcP808]U=P<0RV@g0`29HcH208QR=@P0RFDe00<0R6@d08MS<`27Hc<01027Hc<01P28I3@0RF@g
08UT=`27HSD0QV4d08EP<`<0Q5lb0P22GcD2085N=080P5dc2P1oG3802020Gc80Oeha081N<@22GC40
PE``089K<024FS00PeT_0P1nFc400`1mFS00O5T_07]H;P0207YG;@0407UF;01mFS00OEX`07eJ<0<0
OU/a0P1oG3801@1jEbd0NeP^07]H;P1lFBl0OEX`0080OU/a00@0Oe`b07eJ<01lFBl0NeP^0P1iER`0
1P1kF2h0O5T_07eJ<01iER`0N5D[07IC:@80ME8X00@0MU<Y07MD:P1gE2X0N5D[1@1dEbl02`1cERh0
LUD]079E;@1dEbl0LeH^079E;@1_DRX0KE0X06Y=9@1YC2@0J4/S0080JddW00@0JDdX06M=:P1TCB/0
HTh]0P1PCBd02`1OB2P0GTLX05]69`1HABL0E4<W05919`1@@2L0CT0V04hn901=?B<0Bc/Q0080BSXP
00H0Bc/Q04dm8`1>?R@0BSXP04`l8P1??bD205519`0605109P1>?R@0C3`R04Ph7`1;>b80CclV0P1B
@RT00`1??bH0Bc/R04Ph7`0204To900604Pn8`17?B80AS`Q04@j7`13>Ah0@SPM0P14?B<01013?280
A3XQ04<i8012>1l2048f7PD0?CDP00<0?3@O03/c7P0k<ah00P0c<Qh01P0d<b40=38S038`8`0`;R80
;B/O02`Y8080;2`R00@0:b/Q02XZ800X:1h09bLM0P0V9Q`202`^8`0602/]8P0Z;240:2XO02LY7P0V
:1d09BLL200W:20202@W800402<V7`0R9Ah082<L01lR6`807R4J0P0Q91/2028U70808bHM0P0T9ah8
02DX7@0502PZ7`0W:Ah09bTN02HX7@0U9a`00P0T9Q/00`0S9AX09BLL02DW700702DW700302HW7`0U
9Qh09BHN00809BHN0`0T9Ad202DW70809RPM0`0W:Ah00`0X:Ql0:RTG02/Z600202/Z6080;2/I0P0]
;1X0200^:Qh0;b/O030/800a;B40<RhR03<_8`0d<2@0=C4U0`0d<B8203<`8@<0<RlP0P0d;a`203D`
7@0503Ha7P0g<Ql0=c8O03Pc800i<Ah00P0j<Ql00`0l=240?CDR03hf8`0203lg900403de8P0n=R<0
?SHS03hf8`80?cLT0P10>2D203lg8P@0@3PS0P0o=b80100n>280?cTS03li8`0o>B<2040j9080@C/U
0P12>R<404<k9080@SXS00H0@SLS04<h8P14>B<0AC/R04Hl8@16?B0204Ln7`P0CChQ0P1DAB@00`1D
A2<0ET<S05M28`0205U28`0405Y18`1NAbL0GDHV05a59@80Fd@T0`1J@b<205M48`80ET<R0P1E@R42
05A1800605]2901J@b@0FT<T05M28`1F@b<0Dd<R0P1B@b84055090<0DT4U00H0Dd8V04do8P1>@2<0
CT0S04m1901@@RD205539P0405949`1EA2P0ED@X05E4:080E4<W0P1C@RH205919@0304dn7`1>?b00
Cd0Q0080D44R00<0Cd0Q04ho801=?Ql0201A@2@205=080H0E44Q00H0FD8R05Y38`1J@b<0Fd@T05a5
9@1MARH205i79`80FdLR0P1LB2<205e99080GTXU00H0FdlW05Y>9P1KCBH0G4dV05e;9@1NBRD205m9
90@0GD/W00@0FdTU05Q68P1E@al0Dd4M0`1B@b@205528`0305118P1?@240Cd0Q0080E44S00H0DD0R
05118P1>@B40C44Q04]0801:@B0804m08@<0BT4T0`19@2<204Po8P0304m4:01<@BD0B3dQ0080A3TM
00<0AS/O04Xo8`1=@RH00P1=?bD01P1:?R@0B3hS04Ho8`14?b80@chQ048n8@H0AChR0P14?B4804<l
8P0303hl9@0l>R<0>cTR0080>SPQ00<0>cTR03`j8`0n?2D00`0i=b8203Pf8@<0=cDP0`0c=Al2038d
7P<0<C<M00T0<B/M030]7P0`;Ah0<2dN02l]7P0^;al0;C0O02``7`0]<B000P0[;Q/01P0Z;A`0:B/M
02PZ7@0X:Ql09bTN02LX80808bHM0P0R9A`2024T6`8082<J0`0M91`201`S6`<06b8J0P0K8Ad201XP
70806AlK0P0H7QX801LM6@P05adK200I6aX801@J60P05aPJ00L05AHH01HG6@0I6Q`06Q/M01/L7P0I
6Q`061TK00T05QLID@0E5QP801HG6A005AHH200F5aU001DF60P04QPH400E5QP801HG6@T05AHH600F
5aT801HH5b005aTH:00I6aX801LI61006A/J0P0H6QT201TK6P0401XL6`0K7A`06adL01/M70P06adJ
2@0L71X801dM6`P0824K200R8A`802<R7@0302LS6P0X91/0:BDL0080:bLN00<0:BDL02PT6`0W8aX0
200U9Ad@02PT6`X09BDM0P0T91`202<S6`808R8J200P8A/;024R7080824K0`0O81X801lO7@807AhH
0P0N7aT201lP6P@0824K100Q8Q`2028S7@03020Q6@0Q8QX08b@L008092DM00<08b@L028S6`0Q8QX0
0`0S8Qd2028Q70<08B0K2@0P8A/00`0O81X0824K020Q6`04020Q6`0301lP6P0P8A/0824K00H0824K
0P0Q8Q`3020Q6`<07b0J400P8A/@01lO7@P071hK2@0K7AX01`0L7Q/07R0M01lQ7P0P8Ql07b4N01hP
7@0M7a`00P0Q8QX2028S6`808b@L0P0T9Ad202<S6`8092@L0P0U9Ad:02HV7PP09BDM0`0U9Qh202@U
7@<08b@L200Q8Q`8028R6PP08B8L2@0O81X201dN60807QlI0P0O81X2020Q6`P08B8L0`0P8A/2024R
70<08R<M100R8a/402<T70<08B8L0P0P8A/301lP6PP08B8L0P0P8AT00`0Q8QX08R<K02<T700202@U
7@0402DV7P0R8a/08R<K028S6`808B8J0`0P8AT8024R70<082<L:oooool002[ooooo00H0XWM<0:9g
BP2RMdX0XgU90:=iA`2TNdL20:AkA@P0XgY60P2WNDL01P2UNTL0XgY60:9jAP2PNdH0WgY509ikA@<0
XWQ60`2SNDL20:AjB0060:=hA@2TNDH0YGY70:IkB02WO4T0ZGi;0P2ZOd`80:MnBP<0YWe90`2WOTXB
0:QoB`T0Z7i<0P2ZP500102ZP4h0ZH1<0:V0BP2YP4P20:R0A@80Z7m90`2YP4X30:Z1B`0C0:^0E@2Z
Oe80Z7e@0:MmC@2WOD/0Z7m;0:Z1B`2[PT`0Ygi:0:QoB`2YP4`0ZX5=0:^2CP2/Pdl0[HA@0:j5D@2X
OTh0ZX1@0:^1C`020:b3C`060:^2C02ZPDT0Z7m70:Z0D02[PE40[89@0P2^QE400`2/Pdd0Zh9:0:Z1
B@080:b3C`040:V4C`2ZQE00ZXE@0:^6D@80[8MB0P2]R5<0102/Qe<0ZhIB0:^6DP2[QU820:Z5D@80
ZHA@0P2WPdT0102WPT/0Yh9=0:R3CP2XPdl20:R2D@80YH1<00<0Y7m;0:=nBP2RODT00`2QO4P309mj
AP0309iiA@2KMT80VWE10080VWE10P2ILd80102HLT40Ug5009I`?`2EKch309A^?@0509=]?02BK3/0
TF/j08mY>02>J3L00P2=IcH208]U>080RV@g1029HcH208IR<00308EQ<@24Gc80Pehb0080PUdc00d0
PE/d08IL=026G3@0Pe`c085L<P20Fc40OEX`07aK<01kFRl0NePb07UF<01gE2h0ME8/0080M54[00<0
ME8/07IC;@1^DBL00P1^DBT0101]CbT0KDl[06a>;01/CR`206a=;PP0K4hZ00h0IddX06U=:01YCBP0
JddY06i=:P1aCb`0Ldl]07A@;P1eDRP0MU<Y07MD:P1hEB/0NUL]07aI;`80OEX`0`21G2l2089M<0<0
Peha0P23Gbl01024H300QF4a08IR<P27Hc<208QT=080QV0a00H0Qf4b08US=02:I3D0RfDf08aV=`2=
IcP808]U=P80SF@h0`2<HcL308]R=PP0RFDe0`27Hc<208QT=0<0Qf<c0P28HcH208MR=@0408IQ=025
H3<0Q5lb08AO<P<0PEhd0P20GC<;07mL<P0907mN<`1nGC80Oe`b085L<P20Fc40PEXa08=I<@22F300
Oe`b0080OU/a00<0OEX`07aI;`1kF2h00P1jEbd307eJ<0<0OU/a0P1oG3801@1jEbd0NeP^07]H;P1l
FBl0OEX`0080OU/a00@0Oe`b07eJ<01lFBl0NeP^0P1iER`01P1kF2h0O5T_07eJ<01hEB/0Me@Z07IC
:@80ME8X00@0MU<Y07QE:`1hEB/0NEH/0P1eF3000`1dEbl0LeH^07=F;P0307=F;P80M5L_00`0LUD]
071C:`1^DBT0K4lW06Y=9@1YC2@0JdlW06U@9`1XCbL0IdlY06I>:P1UCR`206A=;@0;06599`1PAbP0
GTLW05Y59P1GA2H0Dd8V05919`1@@2H0CShT04dm8`1<?2800P1;>b401P1<?280CCdS04hn901:>R00
C3`R04lo9@80DD4W00H0D40V04hn901<?280B3PO04/k8P1??bH20592:@0904lo9P1;>b80B3PO04]1
9P1:@2D0BClT04Lm8P16?240AC/P0080A3XO0P18?2@01016?2<0AC/R04@j8@11>R02040i7`80?cLR
00<0?SHQ03de800m=B000`0m=B00200e<ah0=S@O03Hc800f<b80=C8S038^8P0`;200;RXO0P0];B<0
100/;280:b/Q02TY7`0X:1h202LW7@0602d_900/;R<0:bdR02X/8@0Y:b009bTN0P0V:1d802LX8008
02DX8@0T9b008bHO028U7P0Q91d082<L01lR6`0N8AX2024T6`808RDL0P0S9Qd202@W7PP09BPM00D0
:B/N02PZ7@0X:Qd09bTL02HX6`0202DW6P0302@V6@0U9a`09BLL00L09BLL0`0V9al00`0U9Qh092DM
02@U7@0202<T700402@V6`0U9a`09BLL02DW70809RPM0P0W:Ah202LX60<0:2TI0`0Y:QX202d[7`04
02h/800`;R80<BlS03<a9@80=38V0`0g=2D203Hc90<0=C8S00H0<RdJ03<^6`0d;a`0=C0M03Ha7P0g
<Ql203Pc800603L_700h<1d0>C4N03/c800l=240?CDR0P0o=b@303hf8`80?cLT0`10>2D2044i90@0
@3PS0P11>B@3044i8P80@SXS0`13>b@804Lm900904Dj9015>b80AS`S04Hl8@17?R40B3lP04U07`1:
@B00D44R00H0DD8S00H0D44R05E7901EAb@0EdLU05U69@1JARD205a59@0305e49@1OB2H0GdPV00<0
GdPV0P1NAbD00`1MAR@0FTPT05U78`0205U78`80F4HR0P1GAB401P1NABH0GDHV05e69P1JARD0FDHU
05I69080EDLT00@0Dd8T05A39@1D@bD0E4<U101EA2H01@1A@R<0DT<T0593901CA2D0E4DV0080EDHW
00P0ETLX05A39@1D@bD0E4<U05=2901B@B<0D3lQ04ln8080CSdO00<0CSlP04m08@1@@B800P1A@R<0
0`1@@B80Cd0Q04ho800805918`D0ET<R0`1E@R4205]48P0405a58`1MAR@0GTLU05i79@80GdPV0P1J
B28405]98`80G4XT0P1GCRD01`1HC2@0FD/T05U:8`1KBB<0G4PS05]78P1JAbH00P1KB2L01@1JAbH0
FDHU05I38P1C@1l0DSlN0080DD8S00<0D44R04m08@1?@2400`1?@24205A18`0605508P1@@B80CT4Q
04a18@1;@200BT4P201>?b0204Y190<0BD0S0`18?b80201>@bL0C44U04Ll8014>Ad0@cPL04Hk7`19
?R80C44U0P1=?bD01P1:?R@0B3hS04Dn8P13?R40@SdP044m80H0@chQ0P14?b8804<l8P0303dk900l
>R<0>cTR0080>CLP00<0>cTR03`j8`0m>b@00P0i=b8203Pf8@80=cDP0P0f=1l303Hh8P80=CLQ0`0d
=R001`0a:ad0;b`M02l/7@0_;1d0;bdN02d^7P0]<1l00P0/<1l202X]6P0602T/6`0Y:ad0:2XM02LY
7P0V:1d09RLO0P0R9A`4024T6`8082<J0P0M91`201`S6`806b8J0P0J8AT301XP70806AlK0`0H7QX8
01LM6@P05adK200I6aX801@J60P05aPJ00P02@X<00`=3`0A4Q@05QLI01PI6`0I6Q`061TK01LH6PP0
5QLID@0E5QP801HG6A005AHH200F5aU001DF60P04QPH400E5QP801HG6@T05AHH600F5aT801HH5b00
5aTH:00I6aX801LI61<06A/J100J71/00`0K7A`06adJ01/M6P0601/M6PT071`J200M7A/8020Q6`P0
8R4L200S8Qd00`0W8aX0:2@K02TU700202/W7P0302TU700X91/09b<J00P092@L400W8aX;02@T7080
8b<K0`0R8QX8020Q6`X08B8L0P0P8A/201lP6P807QlI200O7ad201dN60807QlI0P0O81X2020Q6`03
01lP6P0P8A/0824K00808B8L0P0R8ad0100S91h08B8J028S6`0S91`202@U7@0302<T700Q8QX0824I
00<08b8M0P0R8A`3024P6``0824K0P0O81X;020Q6`808B8L0`0P8A/301lP6Q00824K400N7Q`801`N
6`P06adJ00<06Q`I01/M6P0M7a`00`0O8Ah00`0N81d07AlL024R6P02024R6P808R<K0`0S91`202<S
6`8092@L0P0U9Ad:02HV7PP09BDM0`0T9Ad202<T70<08R<K200Q8Q`8028R6PP08B8L2@0N7aT201dN
60807QlI0P0O81X2020Q6`P08B8L0`0P8A/2024R70<08R<M200R8a/2024R7080824K0P0O81X201hO
6@P08B8L0P0P8AT00`0Q8QX08R<K02<T700202@U7@0402DV7P0Q8QX08B8J024R6P80824I0`0O81P8
024R70<082<L:oooool002[ooooo00H0XWM<0:9gBP2RMdX0XgU90:=iA`2TNdL20:AkA@<0XWU50P2S
NTH30:AkA`80Z7Y800<0YGY70:AkA`2RNTH00P2PNdH00`2NNdD0XGM50:5gA@020:9hAP<0XgU700D0
Y7Y80:EjA`2UNTL0YW]80:MlB@020:QmBP80ZGi;202WOTX30:ImB@<0Ygi:0P2XOd/;0:MnBP80Z7m;
0`2YP4`90:UoC@80ZX1>00H0ZX5=0:V0BP2YP4P0ZH560:R0A@2XP4<20:QoB@<0ZH1:0`2ZPD/02@2Z
Oe@0ZGiA0:QmD02WODd0Yge;0:QoB`2YP4X0ZX5;0:QoB`020:V0C0080:Z1C@2[PTh0[8=?0:b3C`2]
Q500Z7i>0:UoC`2[PDl20:b3C`060:^2C02YP4P0Z7m70:Z0D02[PE40[89@0P2^QE400`2/Pdd0Zh9:
0:Z1B@080:b3C`P0ZhIA0`2ZQE420:V4D0<0Z8=?00/0YX980:N3B@2WPT/0Yh9=0:R3CP2XPdl0Z89A
0:V3DP2VPDd0YH1<0:=nBP030:9mB@80Xgi:00T0WgY60:1kA`2QO4P0WgY609]f@P2IM400VWE109]f
@P2JMD400P2IM4000`2HLcl0Ug8n09Ia?@0309E`?00:09A_>`2CKSX0TVdi091[=`2?JSH0SVTe08eX
=02=IcX0S6Hi08YT=`<0RF<f0P2:I3L02027Hc40QV8`08IR<P25H3<0Q5lc08=N=022GC<0PU`e0P26
G3@02@23G3<0PE`b081K<@1mFS00O5/`07]J;`1jEc40N5D_07MD;P0207EB;00407IC;@1gE2h0N5D_
071C:@80L5<[00@0Ke4[06mA;@1^D2h0KU0^0P1^Cc0806a>:P0A06UA:`1YCbX0J4hY06Y>:@1[CBT0
KTdZ075?;01bD2d0Le0V07AA9`1eDRP0Me@Z07UF;01kF2h0O5T_07eJ<020Fbh00`21G2l2089M<080
Peha00H0P5h^085O;`21Gbl0PV0`08=Q<@24HS8208ES<`80Qf4b0P28HS<00`29Hc@0RV@e08]U=P09
08]U=P<0SV<h0P2=HSL308aQ=PP0RFDe00<0Q68b08ES<`26I3@00P27ICD01026I3@0QF<c08AR<P26
HC@208MR=@0508QS=P27HSD0QV4d08AO<P23GS400P21GS@2081M<`<0Oe`b00<0OU/a07mL<P1oG380
1P1oG38207aK<P0407eJ<P20FS<0P5Xc085J<`80PeTc0P20GC<00`1oG380OU/a07eJ<00207aI;`04
07]H;P1mFS00OEX`07eJ<0<0OU/a0P1oG38407aI;`D0OEX`00X0O5T_07]H;P1iER`0NEH/07]H;P1l
FBl0OEX`07UF;01hEB/0Me@Z0P1fDbT01`1hEB/0NUL]07YG;@1kF2h0MUTa07EH<01dEbl00`1bEBd0
401cERh0M5L_07=F;P1cERh0LUD]075D;01_DRX0KU4Y06e@:01/CbL0JE8V06UB:01XDBL0Ie0W06I>
:01UCBT206A<:P0;06=99P1SBBP0H4PV05i79`1JABH0Ed@V05E19P1C@RH0D40V04lo9@1=?B<00P1<
?280201=?B<0CclU05109P1<?280CCdS04hn901??bD0D40V0P1??bD0101>?R@0BSXQ04`l8`1>?RD2
05109`0704hn9@1<?2<0BSXQ04]19P1:@2D0B3hS04Hl8@0204Dk8080AS`Q00/0Bc`U04Xk9018?2@0
AS`S04<l8P11>b40@3XP03lk8011>B@0@3PS03lg8P0303de8080?SHQ0P0i=1h01P0j=B40>C@Q03Pb
8P0e;b40<bdO034[7`80;BdS00@0;2`R02/[8@0Z:R00:RXP0P0Y:Al202/]8P0302X/8@0Y:b00:2XO
00<09bTN200V9al202@W800402<V7`0R9Ah08RDN024T7@8082<L0P0Q91/2028U70808bHM0P0T9ah8
02@W70@0:2XL0`0W:A/00`0V:1X09BLL02DW700702DW70809bPP00<09RLO02DV7P0T9Ad00P0S91`0
0`0R8a/08bDJ02@V6`0202@V6`809BLL0P0V:1d302HX6P809bTK0`0X:Q`0200[:b40;2`R02d]8`0^
;R@0;blU030`9P0a<BL0<S8X200f<b@01P0b;AX0<bhK03@_700e<1d0=c8O03Pc8080>C@Q00P0=blL
03P`7@0i<Ah0>S8O03/c800l=240?CDR03hf8`80?CDR0P0n=R<303lg9004040h9@12>RD0@CTT040h
8`80?cLR00<0@3PS044i9012>RD00P13>B0204@j8@<0AC/R00@0AS`S04Xn901:?R@0BCdS0P18?280
0`19?B<0BShT04Xn900204To9P0904To9019@2<0BT4R04]28@1=AB40CTHR05A5901EARD0ETLV0080
EdPW00d0ETLV05E69@1DAB@0ETPS05M9901JBRH0GD/W05i:9`1PBBL0GdPV05m79@1PBRD0HD/V00@0
HT`W0P1PBRD305e;9@80G4XT0`1KBB<0201QBBL0H4TW05m89P1MBBH0FdTU05U99@1HBRD0EdTT201I
ARH205I69@<0EdLV0`1HB2L205=38P0:05928@1A@B00D40O04lo7P1>?Qd0CCdL04`l6`1@@B80DD8S
05939080Dd@U00<0DT<T05528`1@@B80201DA2<305i<:080GD/W0`1LBRH205]5800305a68@1MAb80
GTPS0080GdTT00@0H4XU05Q98P1HBB80F4TR1@1IBR<01P1DC2D0ED`U05A;901FBR@0EdTT05M78`80
FDLS0P1GA2@205Q59@0405M4901E@R80Dd0P058o7`80DD8S101?@2402P1@@B80DD8S05A18`1D@B<0
DD0R05118P1>@B40C44Q04]0801:@B0804dn7`0404Y19019@2<0BD0S04U08`80B3lR0P17?R400`1<
@BD0BSlS04Ll800204Dj7P0;04Hk7`18?B40BSlS04i09P1=?bD0BShT04Pn8`14?B40@SdP044l7`10
?1l00P11?B03040l7`03044m8013?b80@clR00P0@c`R00<0?C/T03`j8`0j>2400P0i=b000`0j>240
?3XS03dk900303Pf8@80=cDP0`0f=1l303Li8`80=SPR0`0e=b401`0b;1h0<2dN030]7P0`;Ah0;bdN
02d^7P0[;Qd00P0Z;Qd0200Y;QX0:2dI02P/6`0W:a`09RXL02DX7@0T9a`092LN1@0Q91/3020S6P<0
72<K0P0K8QX301XQ6@806R0L0P0I7a/301PN6PT05adI200G7A/801TK6PP051XH200G61X00`0C51H0
5AHH01LH6P0201TJ700301PI6`0F5aT05AHH00P05QLID@0E5QP801HG6A005AHH200F5aTh01DF60P0
51DG200B61P@01DF60P05QLI2@0E5QP801HG6@P05AHH200F5aT801HH5b005aTH:00I6aX801LI6100
6A/J200J71/801/M6PT071`J200M7A/8020Q6`P08R4L200S8Qd00`0W8aX0:2@K02TU700202/W7P03
02TU700X91/09b<J00P092@L400W8aX:02@T70808b<K0`0R8QX00`0Q8AT07b0J01lP6P0601lP6PP0
8B8L0`0P8A/201lP6P<07QlI200O7ad201dN60807QlI0P0O81X2020Q6`807b0J00@0824K024R700Q
8Q`08R<M0P0S91h00`0R8a/08b@L02@U7@0202DV7P0302<T700Q8QX0824I00<08b8M0P0R8A`3024P
6`T07b0J00<08B8L020Q6`0O81X00P0N7aT00`0O81X0824K024R7008020Q6`808B8L0`0P8A/301lP
6PP0824K200O81X@01hN70P071hK200K7AX02@0J71T06adJ01dO700N81d07b4N01hP7@0M7a`071hK
020Q6@03024R6P808R<K0P0S91`202<S6`8092@L0P0U9Ad202HV7Q009BDM0`0S91`2028S6`<08B8J
200P8A/8028R6PP0824K2@0N7aT201dN60807QlI0P0O81X2020Q6`P08B8L0`0P8A/2024R70<08R<M
00@08b@L028S6`0R8a/08R<K0`0Q8QX0100P8AT0824K020Q6`0P8A/201lP6P<07QlI200P8A/2020Q
6@03024R6P0R8a/08b@L008092DM00@09BHN024R6P0Q8QX08B8J0P0P8AT301lP60P08B8L0`0O8Q/[
ooooo`00:_ooool01P2RMd`0XWM:0:9gBP2SNDT0XgU70:AkA`80Y7]500<0XGQ40:9iA@2RNDD00P2S
NTH20:AkA`060:ElB02XNTP0Z7Y80:IkB02TNdL0Xg]70P2PNdH0102OO4H0XGM50:5gA@2QMdD20:9h
AP<0XgU7102WO4T40:QmBPP0Ygi:0`2VODT30:MnBP80Z7m;202WOTX00`2VODT0Ygi:0:MnBP020:Qo
B`80ZH1<00<0ZX5=0:UoC@2YOdd01`2YOdd20:Z1C@040:Z1B`2YP4P0ZH560:V1AP80Z8130P2XOdT3
0:V0BP<0ZX5;00P0ZWmD0:UnD@2WO4l0YWa<0:IlBP2WOTX0ZH1:0:Z1B`@0ZX5=102[PTh00`2XOTh0
ZGm?0:Z0CP020:^2CP060:Z1B`2YP4P0Z7m70:Z0D02[PE40[89@0P2^QE400`2/Pdd0Zh9:0:Z1B@08
0:b3C`060:j9E02]R5<0[HQC0:b7DP2[QU40ZXE@0P2YQ4l30:R3C`80Yh9>0`2VPDd20:J2B0040:N2
B`2WPTd0Z8=>0:R3C`80ZH=B0100YX5=0:F0C02SOTX0XWe90:5lB02RODT0Y7m;0:F0C02NNDD0XGa8
0:=nBP2PNdL0VgI209Qc?`2IM400W7M30P2JMD4209Ud@00409Qc?`2GLSh0UW4m09Ia?@80UG0l00h0
U6lk09=^>P2AK3P0T6/g08mZ=P2>JCD0SVPk08aV>@2:I3L0RF<f08QR=@29HcH0RV@g08]U>080Qf<a
00H0QV8b08EP<`24Gc<0Pehd089M<`22G3D208EK<`0?089K<P20Fc40OeX`07aI;`1kFRl0NUT^07QE
;`1gE2h0MU<]07EB;01fDbd0Me@^07UF<01jEc40LeH/0080LUD]00@0LU@^075C;`1aDc40LE<a0P1`
DC8806a>:P0806aD;P1[Dbd0JU0[06]?:P1[CBT0KTdZ06m>:`1aCb`2079?9@0607AA9`1fDbT0N5D[
07YG;@1kF2h0O5T_0P20Fbh3085L;`<0PUd`0P1oGbh2081P;`04085Q<022HS40Pf<b08=S<P@0R68c
1029Hc@808]U=P80Sf@i0P2>HcP308eR=`0308aQ=P29ICD0RFDe00H0RFDe00<0PV8a08=S<P25IC@0
0P26ISD01P25IC@0Pf<b089R<@25H3<0QV4d08MR=@80R6<f00<0QV4d08EP<`23GS400`20GC<307mL
<P80OU/a201oG38207YH<P0407aI<`1oFC@0OeTd085I=@80Q5Tf0P22GcD01021GS@0P5dc07mL<P1n
Fc4507eJ<0<0OU/a0P1oG38407eJ<0@0O5T_00<0OEX`07aI;`1kF2h00P1iER`02@1kF2h0O5T_07eJ
<01jEbd0NEH/07QE:`1gE2X0N5D[07YG;@0207aI;`0:07eJ<01gFS80MEP`07=F;P1bEBd0LE@/079E
;@1cERh0M5L_079E;@<0LE@/0`1`Db/03`1_DRX0JE@W06QC9P1WDRL0ITlU06E>9@1TBRD0HdTV06A7
9@1VBBL0I4XW06989`1PAbP0GDHW05U49@0205I39@030592:01A@BL0CclU0080CShT00<0CclU0551
9`1B@RP00P1>?R@304dm8`0404hn901@@2H0DD4W04`l8`80CCdT0P1>?RD204dm900404`l8`1:@2D0
BClT04Lm8P80AS`Q00h0AcdR04Pn8`19?b@0CC/U04`l9@1:>b@0B3`T04@m8`12?280@3`Q03hm8@12
>RD0@CTT03lg8P80?CDP00/0?SHQ03lg8P10>2<0>cDM03/e7`0l=R00>c@Q03Xc8@0h<B40=BdP03<[
7P0502`/8P<0:b/Q100X:Ql402LY7PP092DM0P0S9Ql6028U7P808B@K0P0R9A`202<V7@8092LN200T
9a`202LZ6@<0:2/J0`0Y;1/902DW700602PY8@0W:2009RLO02DV7P0T9Ad08b@L0P0R8a/302<U6P80
92HK0`0U9a`202DY6`809RXL0`0W:ad01P0X;1h0;BdS02d]8`0];B<0;RhT02l_9@<0<30V00D0;b`M
030]7P0`;Ah0<BhO038_800203<`8@0903@a8P0c;Q/0=2lL03D`7@0f<Ah0>3<P03Td8@0j=B80>cHS
0080>30M0P0i<Ah00`0j<Ql0>c<P03/c800303`d8@80?CDR100n=R<00`11>B@0@3PS03lg8P0203hf
8@0303lg8P10>2<0@CTT00<0A3PP0P15>B4304Hj8P0304do901<?R<0BcdR0080BC/P00h0BcdR04`n
8`1=?b@0CD<X04a29`1;@RD0Bd8S04a38P1>AR80D4PT059:9@1HBRL0FD/X05]=:P80G4h[00h0FddZ
05U;:01HBRL0EdTT05Q:9@1LC2P0GddY065=:P1RBbT0HDXX06599`1QBb@0HT`U06A>9`80IDlX00<0
I4hW06==9P1RC2D00P1QCbL2061>9P<0GddU00T0GT`T06=;:@1RBbT0HDXX05m;:01MBbL0Fd/W05Y<
9`1IBbH00P1NBRT205e9:00405a89`1KAbH0FTHU05Y69@<0G4TX0`1KB2L205Y79P80E4@R0P1C@b40
0`1B@R00DD4O05107P0204lo7@030593901CA2D0E4DV0080EDHW00<0E4DV05=49@1B@b@0201EAB<2
061>:P80GddY00D0GT`X05e;9`1MBbL0GD/W05Y47@0205]57P0305a67`1MAb00GTPQ0080GdTR0P1H
BR<605M98P0605=;9P1BBRD0DdTU05=99@1DAb@0EDLT0P1EAB<00`1C@200E44Q05E28P0205I38`06
05E28P1D@B40Dd0P0593901A@R<0D44R0P1?@2400`1@@B80DT<T05=49@0205A18`0605508P1@@B80
CT4Q04a18@1;@200BT4P201<?Ah304U08`80B3lR0`17?R400`1:?b<0BChR04Pm8@0504Ll800@04i0
9P1=?bD0BShT04Pn8`14?B40@C`O040k7P0o>ah0?chP03hm7`0m?1h0?3/M03dl7P0o?R00@D0R0491
8`P0@c`R00<0?3XS03/i8P0j>2400P0i=b000`0j>240>cTR03`j8`0203Pf8@80=cDP100f=1l303@f
8080<cDO0`0b=1h01`0c;Al0<BhO034^7`0`;Ah0;bdN02`]7@0Z;A`00P0X;1/0200V;QT09BdH02D/
6P0T:a/08bTK028X700Q9a/08BLM1P0P8aX2024T6`8072<K0P0K8QX401XQ6@<06AlK0`0H7QX:01LM
6@P05adK200I6aX801@J60P05aPJ0`0K71h00`0J6ad06AXL01LH6P0201DF60P05QLID@0E5QP801HG
6A005AHH200F5aTh01DF60P051DG200B61P@01DF60P05QLI2@0E5QP801HG6@P05AHH200F5aT801HH
5b005aTH:00I6aX801LI61006A/J1P0J71/201TK6PP06adJ2@0L71X801dM6`P0824K200R8A`802<R
7@0302LS6P0X91/0:BDL0080:bLN00<0:BDL02PT6`0W8aX0200S8a/@02HR6@/08b<K0`0R8QX2024Q
6@P07b0J200Q8Q`2020Q6`807b0J100N7aT801lO7@807AhH0P0N7aT201lP6P80824K00D07QlI01lP
6P0O81X0824K028S7@0202<T7P0302@U7`0S91`092DM00<09BHN00<08b@L024R6P0P8AT00`0S8Qd2
028Q70<08B0K2@0O81X00`0R8ad08B8L01lP6P0201hO6@0301lP6P0Q8Q`08R<M00P0824K0P0Q8Q`3
020Q6`<07b0J200P8A/801lP6Q007AdK200L7Q/801/M6P0801TK600K7AX07AlL01hP7@0O8Ah07R0M
01dO700L7Q/2020Q6@<08B8J0`0R8a/202<S6`8092@L0P0U9Ad202HV7PP092@L200U9Ad0100S91`0
8R<K028S6`0R8a/2024R6P80824I200P8A/8028R6PP0824K2`0M7QP201hO6@807b0J0P0P8A/8024R
70<0824K0P0Q8Q`3028S7@808b@L0P0R8a/0100Q8QX0824I020Q6@0P8AT2020Q6`807b0J100N7aT8
020Q6`80824I00<08B8J028S6`0S91`00P0T9Ad0100U9Qh08R<K028S6`0R8a/2024R6P<0824I200Q
8Q`301lR6b_ooooo000Zooooo`060:9gC02RMdX0XWM:0:=iB@2SNDL0Y7]70P2TNdD20:5hA0040:9i
A@2SNTH0XgY60:AkA`80YGa80P2XNTP01P2VNdP0Y7]70:=kA`2QO4L0X7]609mlAP<0XGM50`2RN4H2
0:=iA`80ZGi;0`2XODX30:MlB@P0Ygi:0`2VODT30:MnBP80Z7m;202WOTX20:ImB@040:MnBP2XOd/0
Z7m;0:V0C080ZX5=2@2YOdd20:Z1C@060:Z1B`2YP4P0ZH560:V1A02XP4<0Z8120P2XOdT30:V0BP<0
ZX5;00T0ZWmD0:UnD@2WO4l0YWa<0:IlBP2WOTX0ZH1:0:Z1B`2/Pdl00`2[PTh30:Z1C@040:V0C02W
ODd0ZGm?0:Z0CP80Zh9>00H0ZX5;0:V0B02WOTH0ZX1@0:^1D@2/PU020:j5D@030:b3C@2[PTX0ZX59
00P0[8=?0P2_RUD01P2^RE@0[8MB0:Z5D02YQ4l0Z8=>0:N2C@80Yh9>0`2VPDd30:F0C080YX9800@0
YX5:0:N2C@2XPdh0ZHA@0P2YPe804@2VPDd0YH1<0:=nBP2RODT0XGa80:9mB@2TOd/0YH1<09iiA@2R
ODT0Y7m;0:5lB02JMD40Ug8n09Ud@02MN4@0VgI10080VWE000<0VG@o09Qc?P2GLSd00`2FLC`01@2E
L3/0U6lj09=^>@2AK3L0T6/f0080SfXe00P0SVPk08eW>P2:I3L0RF<f08QR=@29HcH0RfDh08aV>@80
Qf<a00<0QV8b08EP<`24Gc<00P23GS@01`22G3D0QE/c08AJ<P22Fc80P5/a07mJ<01lFBl00P1jFBh0
3@1gE2h0MU<]07EB;01eDR`0MU<]07QE;`1jEc40O5Tc07AG;@1dEbl0LeH^07=E;`1bE3000P1bE382
079C=0P0K4hZ0100KUPa06eE;`1[Dbd0JDlZ06Y>:@1[CBT0KTdZ06m>:`1aCR@0LTlU07=@9P1eDRP0
Me@Z07UF;01kF2h0O5T_0`20Fbh2085L;`<0PUd`00H0OUh]07mO;P1oGbh0P60_085Q<022HS4208=S
<P<0RF<d0`28HS<208MQ<PP0RfDf0P2@HcT208mR>0@0SV4g2029ICD00`22HS40Pf<b08EU=00208IV
=@0608EU=023Hc80PV8a08AO<P26HC@0Qf8e0P28HcH00`27HSD0QF0c08=N<@03081M<`80Oe`b0`1n
Fc4807mL<P0607QF<01iEc40NePb07iH<`1oFC@0PUXf0P25FSL208=P=P03089O=@21GS@0P5dc0080
Oe`b00@0OU/a07eJ<01mFS00OEX`0`1nFc4307mL<P80OU/a00P0OEX`07aI;`1kF2h0NeP^07YG;@1m
FS00O5T_07]H;P80NEH/00<0NeP^07aI;`1mFS000P1jEbd0101iER`0N5D[07UF;01kF2h207eJ<004
07iK<@1gFS80MEP`07=F;P80LE@/00<0LUD]07=F;P1eF3000P1`Db/5075D;00D079E;@1XERH0IeDW
06MB9@1VCbD0ID`T06=9901SAR@0HTDS06M;9P1VBBL0HdTV06189P1MARH0FD@U05Q39P1F@bD0Dd<Y
0592:01A@BL204lo9@0<05519`1B@RP0Dd<Y05109P1>?R@0C3`R04/k8@1<?280CShT05519`1B@RP0
CShU0P1=?B@204`l8`80CCdT01@0CShU04To9018?R<0AS`Q04Dk8016?240AcdR04Y09@1;@BH0CS`V
04dk9@1;?2D0B3`T04@m8`11?B80?SdQ03dm8@13>bH0@CTT03lg8P80?CDP00/0?SHQ03lg8P10>2<0
>cDM03`f7P0l=R00?3DR03Xc8@0h<B40=RlO03@/7`0302/[8@80;2`R0`0];B<402HX7@809bTN0P0X
:Ql802<T7004024T7@0R9Ah08RDN028U7P<08bHO00<092LP024T6`0Q91/00P0R9A`202<V7@8092LN
200T9a`01@0V:AP09bXI02LZ6@0X:aX0:B`K0080:RdL00<0:bhM02DW700U9a`01`0U9a`01P0X:B40
9bPP02LX800U9Qh092DM02<T70808R<K00@08R@I02<U6P0S9AX08bDJ0P0T9Q/202DW70<09RXL0P0W
:ad302P/7P@0;BhV100^;bL202XW600602/X6@0/:AX0;R/L02l/7@0`;Ah0<BhO0P0d;a`0100e<1d0
=c8O03Td8@0j=B8203`g900303P`7@0i<Ah0>C4N0080>C4N0`0j<Ql203/c8080?3@Q0`0m=B80100n
=R<0@CTT040h8`0n=R4203de800303hf8@10>2<0@CTT0080@cLM0P14>1h304Di7`0404Hj801>@2D0
C3hS04Xl8@80BC/P00h0BS`Q04`n8`1>@2D0CdDZ04i5:01=A2L0CD@U04i5901@B2@0Dd/V05A<9`1J
C2T0FddZ05e?;080GU0]01<0GDl/05]=:P1JC2T0F4XS05U;901MCRL0HDlY069>:@1TCRT0HT`W069:
9P1QBb@0HddV06E?:01VD2T0Ie4Z06I@:@1TCRL0HddV00<0He4Y0P1RD2P3065?9`0606A<:01SCBP0
HT`W061<9`1OCBL0G4dV0P1KCBH01P1QCB`0H4`[05m;:P1NBRT0GDTX05]79P80FTHU00H0Gd`[05i;
:P1NBbX0GDXY05a9:01KB2L205Y79P@0EDDS00<0E4@R05=38@1C@b400P1B@R000`1CA2D0E4DV05I7
:00205M8:@0305I7:01DABH0Dd@U00P0EDDS00@0G4XT05]98`1KBB<0FTPR0P1IAb4205Q68080FT@M
00<0FdDN05a67`1MAb000P1NB2400`1OBB80F4XS05Q:8`0405M98P80ETPQ00`0D4/U059:9@1ABB@0
DTPT05=68`1DAR<0EDDS05A48P1@?Al0DSlQ05A18`1E@R@205I39@0505E2901D@B<0Dd@U0593901@
@B800P1?@2400`1A@R<0Dd@U05A59P0205A18`0605508P1@@B80CT4Q04a18@1;@200BT4P201<?Ah2
04U08`<0B3lR0`17?R4204Pm8@80BChR01@0B3dQ04Ll8016>al0ACXN04i09P1=?bD0BShT04Lm8P14
?B40@C`O040k7P0n>Qd0?SdO03dl7P0l>ad0>cXL03`k7@0n?Al0@D0R04918`P0@c`R00<0?3XS03/i
8P0j>2400P0h=Ql00`0j>240>cTR03`j8`0203Pf8@80=cDP0`0f=1l00`0e<ah0<C<M034c7@02030b
70<0;c4K00P0;S0J03@^800b;b00<RlP034^7`0_;Ah0:b`L02T/6`809b/J0P0U;AP01P0T:aT092/K
02<Y6`0R:1`08BLK024W7@807b8I100P8aX2024T6`8072<K0P0K8QX301XQ6@0401TP600I7a/06AlK
01TO6`8061hJ2`0G7AT801LM6`P06A/J200D6QP:01LH6P0401HG6@0E5QP05AHH01DF60X05QLID@0E
5QP801HG6A005AHH200F5aTh01DF60P051DG200B61P@01DF60P05QLI2@0E5QP801HG6@P05AHH200F
5aT801HH5b005aTH:00I6aX801LI61006A/J1@0J71/301TK6PP06adJ2@0L71X801dM6`P0824K200R
8A`802<R7@0302LS6P0X91/0:BDL0080:bLN00<0:BDL02PT6`0W8aX0200S8a/@02HR6@/08b<K0P0R
8QX3024Q6@P07b0J200Q8Q`2020Q6`807b0J0`0N7aT00`0M7QP07alM01lO7@0601lO7@807AhH0P0N
7aT201lP6P80824K0P0N7aT0100O81X0824K028S7@0S91h202@U7`8092DM00H09BHN02HW7`0U9Qh0
8b@L024R6P0P8AT302<R7@808R4L0`0Q81/901lP6P03028S7@0Q8Q`07b0J00807QlI00<07b0J024R
700R8ad0200P8A/2024R70<0824K0`0O81X8020Q6`P07b0J400M7A/801`N6`P06adJ00<06A/H01/M
6P0L7Q/00`0N81d00`0M7a`071hK020Q6@02020Q6@808B8J0`0R8a/202<S6`8092@L0P0U9Ad202HV
7PP08b<K200U9Ad3028S6`808B8J0`0P8AT8020Q6`P08R8J200P8A/;01dN60807QlI0P0O81X2020Q
6`P08B8L0`0P8A/2024R70<08R<M0P0S91`0100R8a/08B8J024R6P0P8AT201lP6080824K0P0O81X3
01hO6@0301dN600P8A/0824K00H0824K0P0P8AT00`0Q8QX08R<K02<T700202@U7@0302DV7P0S91`0
8b@L00808R<K0`0Q8QX00`0P8AT08B8L024R7006024R70<07b8K:oooool002[ooooo00P0YWe90:Ak
A`2RNDD0XGQ40:9iA@2TNdL0Ygi:0:QoB`80Y7U60`2UNTL30:IkB080X7I60P2QMdL01`2RN4P0XgU9
0:=iB@2TNTX0YGY?0:AiCP2RMd`00P2QMT/04`2RMd`0Y7U>0:EjC`2ZPDd0ZH1<0:ImB@2UO4P0Y7]7
0:ElB02WOTX0Z7m;0:UoC@2WOD/0YWa:0:AjB02UNdT0YWa:0:QnC02YOdd00P2UPT`40:B1B`80Xh1:
00P0Zh5A0:Z0D02WODd0YG];0:AjBP2UNd/0YWa<0:MmC@P0ZGi;0P2ZP5001@2ZP4h0ZX5=0:Z1C@2Z
PDd0ZX5;0080ZX59202YP4`80:QnC080ZH1<0P2ZPDd20:^2CP<0[8=?0P2[PTh00`2ZPDd0ZH1<0:Qo
B`020:MnBP80ZGm=00H0ZX1>0:^1C`2/PU00[H=A0:j4DP2_QE<20:V0C080ZX5=0P2[PTh20:b3C`80
[HA<00@0[HA>0:f4D02]Q500[H=A0P2]Pe<80:V4D00;0:R3C`2YQ500ZXEA0:^6DP2ZQE40ZHA@0:N2
CP2VPDd0ZGm=0:Z0CP2[PDl00P2/PU000`2[PDl0ZX1>0:UoC@030:J1C080YH1;0`2TOdX209imA`03
09elAP2LNdD0VgY40080VWU300H0VGQ209]f@P2KMT80VWE109Ud@02HLcl209Mb?P0:09Ia?@2HLcl0
V7<o09Mb?P2EL3`0U6lk09=^>P2BKCT0TF`h091Z>`80SfTj00<0SVPi08eW>02<ISL00P2;ICH01P29
I3L0R6<f08IQ=025H3<0Q5lb08EP<`80QV4d201nFc400`1iERh0N5D]07MD;00207MD;00307UF;P1k
F300O5Ta0080M5@[00<0Le<Z079B:@1aDBP00P1aDBP2071@9`04079A;P1`Cb`0KTdZ06a;:080JdXW
00D0K4/X06e<:@1ZC2P0JT`X06]=:@0206a>:P0306e?:`1^D2`0KU0/0080KE4Y00X0L5<Y07=D:01f
EBP0NELY07YH:P1lF2P0MeTW07UK:@1kGB/0OEl]0P1nH2h00`1mGbd0O5h/081N<002081N<080PEla
0`22H38208QV>0@0QfDg0P26I3H208MR=@80R6<f0`29I3L02@2:ICP0QV0c08MQ=028HSD0RF<f08YT
=`2;ICP0S6Hi08eW>P0808MS<`0608IS;@26HRh0QV8^08IR<026HS80QV4d0P26HCD01P26I3@0QF<c
08ES=@23HC@0PUle085N=P80P5dg0100QF8h08AQ=`23H3H0PUle085N=020GC<0Oe`b07iK<@25HSP0
Q64g08=P=P22GcD0PEhd081M<`1oG380OU/a0`1nFc<207mL=0<0P5de0`20GS0207mM;`<0OU`^00@0
NeP^07aI;`1lFBl0O5T_0P1mFS0207iK<@0807iK<`1mFS80NeP`07YG;`1kF300OU/c085N=P23H3P4
07aI;`@0OEX`0P1mFS8207aI<@0607]H<01jEbl0NUL_07YG;`1iERh0N5P_0P1gEbh04`1fERd0MED/
07AD:`1dE2/0Le<Z071E:P1aER/0LeP]07AI;P1cF2d0LUL/06mD:@1^DbP0JE</06QB:`1XD2X0IddX
06Q<9`1YBbL00P1[BRL0201UB2P0I4LW06959@1QA2@0Gd8R05e0801L?al0FchN0P1KAbH01P1IARH0
ETDW05E4:01B@RP0Cd4V04i09P80CCdS0`1<?28304/k8@0304e19`1<@2H0BCdS0080B3`R00<0BclU
04e19`1?@bT00P1:?b<304]090<0C44U00@0BclU04Tm8`17>b40ACTO0P14>1h01015>Al0ASXP04@i
9@14>BD304<h90<0@SLS0`0l=1l303/c7P80>S8M00T0?34O03T`7`0h;ah0=BhN03<]7`0_:al0;B/O
02`Z7P0Z:ad00`0Y:Q`202PY6`809bPJ0`0W:Ah202HX7@@09BLL00P09RPM02PZ7`0X:Ql0:2XO02HX
7@0T9Q/08bDJ024T6`<08RDL0P0S9Qd202@W7PP08bHM200U:1l202HY60<09bXI100X:aX302DV7P03
02@U7@0S91`08R<K00808R<K0P0W:Ql01P0V:Ah092LL02<V6`0R9AX08B@I020S60<09BLL0P0V:1d3
02LY7P0302//900/;BD0;RlW0080<34Y00<0;RlW02`]9@0[;2@0200X:Ql0200]<1d0;S4N02lb7`0`
<b00<C@Q038e8P0c=R<0=3LT0P0h<ad203Td7P0703Pc7@0f<A/0<bhH038]5`0l<Al0?C8P03hc8@02
03ld8P0303hc8@0l<Al0>RlM0080?CPR00@0?STS03lj9011?2H0@SdW0P13?RP02014>Ad0ACXN04Hk
7`17?200B3dQ04Tn8P1:?b<0Bd0T101<@b8304]28@0504Y1801BAB80DTDR05=68`1DAb@00P1EB2D2
05I99P0505Q;8@1IC280FTdS05]>901LCbD00`1MD2H01P1RDBH0He8W06AC:01UE2T0IUDZ06MF:`80
J5L/0P1VDB@00`1WD2@0IdlS06U>8`0206Y=8`0606];8P1UDb/0IE<[06AB:P1SDBT0HU0X0P1PCRH0
0`1OCBD0G4dV05a=9P0205]<9@<0FT/T00L0FDXS05Y:9P1JBRH0FDTU05Q8901GAb<0ETHR0080EDDQ
201IAb<405M78`80ETHR0`1EAB400`1KB2L0FTLV05Q5900205M48`0305Q5901IARD0FTLV00<0FTLV
101IARD00`1HAB@0Ed8S05M28`0205Q390<0FD@U00<0FTDV05U69P1IARH01@1JAbL00`1KB2P0FTHU
05Y69@0605Y69@80FDHX00<0F4DW05M49P1F@bD00P1D@B<0101C@280DT<T0593901A@R<205118P05
04m08@1>?b00CSlP05A48`1EAB@00P1FARD0101DA2<0DT8Q04lo7P1=?A`804]09008058l901A>b<0
D3`S04dl8P1;>b40BS`Q04Tk8017?20204Y1900304U08`18?b80AchQ0080ASdP00<0AC`O048n8@12
?R401P12?R43048n8`<0@CdR2P10?2401011?Ql0@3dN040m7P10?Ah203ll7@80?S/L0`0k>B8303Xh
8@80>CLP0`0g=24303Pe8P80>CHS0`0b=1l2034c7P80<38M00/0;c4L02lb7`0^<Ah0;S4N02d`7@0[
;Q/0:B`I02LZ5`0U:1D092LD02@W7P0302<V7@808RDL0P0Q91/8028U70807B@L0P0L8a/401/R6PP0
61hJ0P0H7Q`301LM6`/05Q`J400G6AP801HH5`P05QLI200B61P801HG6@04020Q8`0N7b406Q/M01HG
6@8051DG4P0E5QP801DG5R405AHH200F5aT801DF60P05ALF200C6AT801DF60P05QLI200E5QP801@E
5bP05AHH200C6AL801HG6@P05AHH0`0D5AL301DF60805QLI2@0E5QPH01HG6@P05QPG200F5aT801HH
5`<05ALF0P0F61M301LI60P06A/J200I6aP301/K6@8071`J0`0M7A/901`L6P807alM0P0N7Q`0100M
7A/071`J01`L6P0K6aT801lP6PP0824K00@09BHN02@U7@0T9Ad092DM0`0S91`00`0R8a/092@L02@T
700>02@T70P08b8M0`0S8a/00`0T91`09BDM02HV7P0202HV7PP0824K00<07b0J020Q6`0R8ad00P0S
91h00`0R8ad0824K01lP6P03020Q6`0301lP6P0N7aT07AhH00807AhH0P0Q8Al2020P7P@07alM200L
7Q/801dM6`/07b0J0`0P8A/2024R70<08b@N0`0R8ad2024R7080824K0P0O81X201hO6@807AhH0`0L
7Q/201/M6P@06Q`I00<07AdK01hN700O7ad00P0P81h00`0O7ad07QhL01dM6`0801dN60@07b0J0P0P
8A/2024R70<07B0I0`0L7aP201/N5`P071hK0`0M7a`301`N6`806adJ0`0M7a`301`N6`806adJ200J
71/501XL6@<06A/H0P0L7AL201dN60@07QlI200P8A/802DV7P0402<P6@0T8AX0924J02DR6`809R<L
0P0W91d8028S7@<08b@N0P0R8ad3024R70P07R0M200Q8Q`3020R7`<07b4N0P0N81d901dO7004024T
7@0P8a`082<L01lR6`807R4J0P0M81T8020S700301lP6P0P8A/08R<M00808b@N00<08R<M020Q6`0O
81X00`0R8ad2024R70<0824K200O7ad8020P7P<0824K0P0Q8Q`3028S7@P08B@M0P0R9Ah0100Q91d0
82<L020S700O8Q/201hQ6P<07R0M:oooool002[ooooo0P2TNdL30:=jAP030:AkA`2VODT0Ygi:0080
Y7U60`2UNTL30:IkB080X7I60P2QMdL01`2RN4P0XgU90:=iB@2SNDT0YGY=0:AiC02RMdX00P2QMTT0
4`2RMdX0Y7U<0:EjC@2ZPDd0Z7m;0:ImB@2UO4P0Y7]70:ElB02VODT0Ygi:0:UoC@2XOT`0YWa:0:Ek
B@2TNTP0YG]90:MmB`2XOT`01P2UP4/20:AoBP030:Z0D02XOTh0YWa<00<0YG];00<0Yge=0:QnCP2Y
OT/01`2YOT/20:Z0D0050:Z0CP2ZPDd0ZX5=0:Z1C@2ZPD/00P2ZPDT80:V0C0P0Z7i<0P2YP4`20:Z1
C@80Zh9>0P2/Pdl30:Z1C@<0ZH1<0P2XOd/20:UoC@040:Z0CP2[PDl0[89@0:f3D@80[XAB0P2YP4`2
0:Z1C@80Zh9>0P2/Pdl20:f4C0040:f4CP2]Q500[HA@0:f3D@80[H=C202YQ5000`2XPdl0ZHA@0:Z5
D@020:^6DP060:V4D02WPTh0YX5=0:UoC@2ZP4h0Zh5?0P2]Pe40102[PDl0ZX1>0:UoC@2WPTd30:J1
C080YH1;0P2TOdX01P2OOTP0WWe709imA`2MO4H0W7]509]jA080VWU30P2KMT80102JMD40VGA009Qc
?`2HLcl409Mb?P0409Ia?@2EL3`0UG0l09A_>`80Tfhj0P2@JS/02P2?JCX0SVPi08eW>02=IcP0S6Hg
08]U=P2;IST0RF@g08MR=@25H3<208AO<P0308EP<`26HC@0OU/a00L0OU/a00<0NeP`07YG;`1hEBd0
0P1gE2`00`1iERh0NUL_07]H<00207EE;00307AD:`1cDbX0LE4X0080L50W0P1_CbH01@1cDRl0LU4^
06m>:`1]C2T0K4/X0080KD`Y00@0KTdZ06Y<:01[CBT0JddY0P1/CRX206e?:`0=06i@;01]DBX0KE4Y
06mB:P1cDbX0ME@Y07QF:@1iEbT0O5LZ07MI9`1hFRP0NU`Z07aN;00207eO;@80O5h/00@0P5h`085O
<@21Gc40PEla0P22H38208=Q<`H0QV@f0P25HcD208MR=@80R6<f1029I3L01@27HC@0R68e08QR=@29
HcH0RV@g0080RfDh00<0S6Hi08QT=028I3@01P28I3@01P26Hbd0QV8^08IR;P26HS00QV8b08IQ=080
QV4e00H0QV@d08ES<`24HS@0Pf4d089O=@21GSH2081M=`80Q64g00@0Pf0f089O=@21GS@0P5dc0P1o
G38208AQ=`0608=P=P22GcD0PEhd081M<`1oG380OU/a0`1nFc<207mL=0<0P5de0`20GS0207mM;`<0
OU`^101lFBl207eJ<080OU/a00<0OU/c07eJ<P1lFC400P1lFC400`1nFc<0Oe`d081M=@0407aI;`@0
OEX`00<0OEXb07aI<@1lFC400P1kF30307YG;`0307UF;P1gEbh0MeL^00<0MUH]0`1eEB`0801aER/0
LUL/07=H;@1dFBh0LeP]079G;01`EBX0KU<X06]E;P1YDb`0J50Z06I<9`1WBbH0JD/W06a;:01]C2T0
J4/[06M::P1VBBT0I4LW06959@1QA2@0Gd8R05i18@1KAbH0FTHU05Q59@1D@bD0Dd8V05519`1?@BH0
Cd4W0`1=?B<204`l8P<0Bc/Q00<0CD4W04a09P1;?bD00`1:?R@0101;?bD0C40V04Xo8`1:?b<304]0
90<0C44U00D0BclU04Xn9017>b40ACTO04@h7P0204Di7`0404Hj8014>BD0A3TU04@i9@80@cPT0`12
=b<0100n=R40?CDP03de800m=B0203`d7`80>c<N00P0?34O03Xa800h;ah0=RlO03<]7`0`;200;R`P
02d[7`80:R/M0P0Y:Q`302PY6`0402LX6P0W:Ah09bTN02LY7P<09RPM0`0U9a`01`0V:1d09bTN02PZ
7`0X:Ql09RPM02@V6`0S9AX0100R9A`202<V7@8092LN200S9Qd802DX7`<09RTH0P0W:QT402P[6P<0
9BHN00<092DM02<T700S91`00P0R8a/202HY7P0402DX7@0T9a`092LL02<V6`808RDJ0`0U9a`202HX
7@<09bTN00<0:b`T02`]9@0];RH00P0_<2P00`0];RH0;2dU02//900802PZ7`80;2lL00@0;C0M02ha
7P0_<Ql0<3<P0P0a=240400d<Q/0=C<L03Hd7@0g=Ah0=S@M03Dc700c<AX0<S0I03Xb7`0k<b00?CDR
03hf8`0m=B80?3@Q03Xb7`0i<Ah203Xe7`0403/f800l=b40?CPR03hi8`80?cXT0P14>Ad01P15>Qh0
AS/O04Ll8018?B40BChR04Xo8`P0Bd8S0P1BAB800`1CAR<0E4LT05E89@0205I99P0705M:9`1IC280
FTdS05Y=8`1KCR@0G4lU05e@9P0205iA9`80GdhS00@0H4lT065@9@1RDBH0He8W0P1TDbP01P1TDBH0
IU4V06IA9P1WD2H0J4lV06Y>9P80JTdU00D0IU@/06EC:`1UDb/0I58Z069@:002065?9`03061>9P1N
CbP0GTlX0080GDhW0`1LCBH01`1KC2D0Fd/W05];9`1JBRH0FDTU05Q8901GAb<00P1FAR8805Y890@0
F4PT0P1GAb<305I68P0305Y79P1IARD0F4DT0080ET<R00<0Ed@S05Q5901IARD01@1HAB@305M48`<0
Ed8S0P1H@b@305U49@D0FDHV0`1JAbL805U5900605U6:01HABL0Ed@V05I39@1E@R@0E44S0P1C@280
0`1A@R<0D44R05118P0204m08@80CSlP00T0CChO05938P1B@b80Dd@S05A5901CA2<0DD8Q04m07`1=
?Qd0201;@2@01P1A>b<0D3`S050l8`1=?280Bc/Q04Xl8@80Ac`P0P1:@B@01019@2<0B3lR04Ln8@16
?B0204Dl7`P0@ShQ0`12?R<2044m8P/0@3`Q1011?Ql2040m7P80?c`M0`0k>B8203Xh8@<0>CLP100h
=B8403Ld8@@0<C<N100`<Qd02@0_<Ql0;S4N02ha7P0/;a`0:RdJ02P[600V:AH09BPE02@W500402<V
7@808RDL0P0Q91/8028U70807B@L0P0L8a/301/R6P0301XQ6@0H7QX061hJ00H061hJ0P0H7Q`301LM
6`/05Q`J400G6AP801HH5`P05QLI200B61P801HG6@0501hO8@0L7Al06Q/M01PI6`0G61X00`0F5aT@
01DF60P05ALF8@0E5QP801HG6@P05AHH200E5aH801<I6@P05AHH200F5aT801DF60P051DG:00E5QP8
01<I5`P05QLI200E5QP301@E5`<05AHH0P0F5aT901DF61P05QLI200F61L801HG6@P05QPG0`0E5aH2
01HH5d<05aTH200I6aX801TK60<06a/I0P0L71X301dM6`T071`J0P0O7ad201hN700401dM6`0L71X0
71`J01`L6PP07b0J200P8A/602<T708092DM400T91`802<R7@808b<K0P0T91`202DU7@809RHN200P
8A/00`0O81X0824K028S7@0202<T7P03028S7@0P8A/07b0J0080824K0P0O81X201hO6@807AhH0P0Q
8Al2020P7P<07alM00<07QhL01`N6`0L7Q/01P0L7Q/801dM6`/07b0J0`0P8A/2024R70<08b@N0P0R
8ad3024R7080824K0P0O81X201hO6@807AhH0`0L7Q/201/M6P@06Q`I00<07AdK01hN700O7ad00P0P
81h00`0O7ad07QhL01dM6`0801dN600401hO6@0O81X07b0J01lP6P80824K0P0Q8Q`301dP6@<071lH
0P0K7QL?01`N6`@07AlL0P0L7Q/301/M6PP06Q`K200J71T201`M5`807AhH0`0N7aT00`0O81X0824K
020Q6`06020Q6`P09BHN0`0T8AX00`0U8Q/09R<L02HS700202LT7@P08R<M0`0S91h2028S7@<08B8L
200N81d8024R70<07b4N0P0N81d<01dO708082<L0P0O8Q/201hQ6P807B0I200P8a`00`0O81X0824K
028S7@0202<T7P03028S7@0P8A/07b0J00808R<M0`0Q8Q`3020Q6`P07alM200P81h3020Q6`<08B8L
0P0R8ad;024T7@03020S700O8Q/07b8K00807R4J0`0N81d[ooooo`00:_ooool01@2RNDD0XgY60:Ak
A`2UO4P0YWe90080YGa800<0Y7]70:AiAP2TNDH00`2UNTL30:IkB0<0XGM50`2RN4H20:=iA`80Y7U<
102RMdX20:AiC0030:V0C02XOd/0YWe900<0YGa80P2VODT00`2YOdd0Z7i<0:MmB`050:EkB@D0Y7m:
0`2UP4/0202WOD/0YWa:0:IlBP2UNdT0YWa:0:MmB`2XOT`0ZGm=202YOT/20:Z0D0050:Z0CP2ZPDd0
ZX5=0:Z1C@2ZPD/00P2ZPDT80:V0C0P0ZGm=0P2YP4`20:Z1C@80Zh9>0P2/Pdl20:QoB`<0ZH1<0`2Z
PDd20:UoC@040:Z0CP2[PDl0[89@0:b2D080[H=A0P2YP4`20:Z1C@80Zh9>0P2/Pdl20:j5C@040:j5
C`2^QE40[XEA0:j4DP80[XAD2@2YQ5002P2ZQE40ZhIB0:^6DP2[QU80ZHA@0:R3C`2VPDd0ZGm=0:Z0
CP2/PU020:f3D@030:b2D02ZP4h0ZGm=00<0Yh9=0P2VPD`30:F0B`80XGi800<0X7e709mlAP2NNdD0
0P2MNT@01P2LND<0W7M309ag@`2KMT80VWE109Ud@080V7<o00<0Ug8n09Ia?@2FLCd01P2EL3`2095[
?004091Z>`2?JCX0SVPi08iX>@80SFLh00@0SVTl08aW>P29I3L0QV4d1024Gc8807mL<P0407iK<`1m
FS80NUL_07UF;P80N5D]0P1iERh01@1gEbh0MUH]07EE;01cDbX0LE4X0080L50W00H0KdlV06i>9@1d
Dc00Le8_075@;@1`Cb`406m>:`<0JddY0P1/CRX306e?:`0<06a@:@1]DBX0Ke8Z079B:@1dDbP0MeDX
07QF:@1jEBP0MULX07MH:@1iFR/0Ne`]0P1lGBh207]L;@80PEla0P22H38308=Q<`T0Q68d0`27HSD2
08QS=P<0RF@g1029HcH408YT=`P0RFDe00H0Qf@^08MS;`27Hbl0Qf<a08MS<`27HSD208MR=P80QF<c
00L0Q68d08=Q=022GcD0PEhf085N>020GCL0Q64g0080Pf0f00D0PUle085N=020GC<0P5dc07mL<P02
08=P=P04089O=@21GS@0P5dc081M<`80Oe`b0`1nFc<207mL=0<0P5de0`20GS0207mM;`<0OU`^0`1l
FBl207eJ<0<0OU/a0P1mFS801P1nFc<0Oe`d07iK<`1mFS80O5Ta07]H<0@0OEX`101lFBl207aI<@80
NeP`1@1jEbl207EE;0<0MUH]0`1gEbh207=F;0<0M5L]00/0LeH/075D:P1`DbT0KUPa06]E;P1WCbT0
ID/V06I:9@1YBbL0KTdZ071?;00206]>;P0406U<;01WBRX0ITTY06A79`80HTDU00T0G4PW05Y69@1F
@b<0DD0R050o8`1??bD0Cd4V0512:01>?R@00`1=?B<204`l8P80Bc/Q101<@2H0101;?bD0BShT04Pl
8P17>b4204Xo8`<0Bd0T0`1<@BD01P1;?bD0BShT04Pl8P17>b40ASXP04Di7`80ASXP00@0ACXV04@i
9@14>BD0A3TU0P13>2@2048g8`04040h8`0o=b80?cLR03lg8P80?SHQ0P0m=B001P0m<R00>S4P03T`
7`0g<200=2hP034]8@80;bdQ00@0:b`N02X[7@0Z:ad0:R/M0P0Y:Q`202PY6`80:2XO0P0W:Ah302HX
7@0702DW700V:1d09bTN02LY7P0X:Ql09bTN02HX7@0202@V6`<08RDL0P0S9Qd302@W7PP08bHM200T
9ah0100U9aT09RPJ02HX6P0V:1X202LY6`<0:2XL0`0U9Qh202@U7@<08b@L0P0U:1d602@W70<09BLL
0P0V:1d302LY7P0302X[8`0[;2@0;2dU0080;BhV00<0;2dU02//900Z:b<0200X:Ql01P0Y;1/0:RdL
02X]700[;Qd0;2lN02d`7`80;S4P00<0<S0K03<a700e<ah00P0g=B000`0f=1l0=C<N03@b7@0203/c
80@0?CDR00L0?3@Q03/c800g<Q`0=c8L03Pc7@0i=1h0>SDO0080>cHP00<0?3LQ04<i7P13>Ah00P14
>Ql01015>b00AS`Q04Lm8P17?B8204Po8P80BD0S00@0BT4T04]29@1<@bH0C4<V0P1@AR<0101AAb@0
DTPU05=99P1DBRL205E;:0<0FT`U00D0FddV05a>9`1MCbP0GU0Y05mA:P0205a:8P80GD/S00T0GT`T
05m=9@1PCRH0H4hV06AA9P1UDRL0Ie8W06QA9`1YD2L00P1[CbL00`1/CbL0IU@/06ID;00206EC:`04
06AB:P1SDBT0HU0X069@:0<0H54Z0P1OD2T305i?:080G4`X00@0Fd/W05Y:9P1JBRH0FDTU0P1HB2@8
05]99@<0FDTU0P1HB2@305M78`0905I68P1HB2L0ETHU05E5901C@b80DT8Q05=38P1DA2<0EDDT00P0
Dd<R0P1E@R8205I38`<0Ed@T2@1HABD805M49080ED@V0P1D@bD01@1C@R@0DT4S05508P1A@280Cd0Q
00<0CSlP0`1=?Ql0101<?Ah0Cd0Q05118P1A@R<20593900305528`1@@B80Cd0Q00P0Bd0T0P1@?2<0
0`1=?280C3`R04/m8P0204Pm8@0704Ln8@1:@B@0BD0S04U08`18?b80AchQ04Hm800204Dl7`P0@ShQ
0P12?R<2044m8P<0@3`Q00<0?c/P044m8P11?B801P11?B801013?b80@ShQ048n8@12?R42044m8080
@3`O0P0k>B8203Xh8@<0>CLP00<0>3HO03Tf8`0i=R<00P0h=B80100g=240=S<P03Db7`0e<Ql302la
70<0<38M0P0a<ah302d`7`0602/^7@0Z;A`0:2/J02HY600U:1L092LF0`0S9Qd2028U70/08B@K0`0L
8a/201/R6P<06R4I200H7QX201PN70<05adK2`0F71X@01LI60P05QPG200F5aT8018H60P05QLI00P0
6AXL01XK7@0K71h06a`N01XK7@0I6Q`061TK01LH6Q005AHH200E5aHR01DF60805QLI0P0G61X201HG
6@T05AHH200E5aH801<I6@P05AHH200F5aT801DF60P051DG:00E5QP801<I5`P05QLI200E5QP301@E
5`<05AHH0P0F5aT901DF61P05QLI200F61L801HG6@P05QPG0`0E5aH201HH5d<05aTH200I6aX801TK
60<06a/I0P0L71X301dM6`T071`J0`0N7Q`301dM6`8071`J200O81X8020Q6`808B8J00@08R<K02<T
700S91`092DM0P0U9Qh@02@T70P08b8M00@08b<K02@T700T91`092@L0`0U9Ad00`0V9Qh0824K020Q
6`06020Q6`0301lP6P0P8A/08B8L00808R<M00@08B8L020Q6`0O81X0824K0`0O81X301hO6@0401dN
600P81h0820N020P7P807alM0`0N7Q`801`N6`P07AdK2`0O81X3020Q6`808B8L0P0S91h2028S7@<0
8B8L0`0P8A/201lP6P807QlI0P0M7QP301`N6`806adJ100J71T00`0M7A/07QhL01lO7@02020P7P03
01lO7@0N7Q`07AdK00P07AhH0`0N7aT201lP6P<0824K0`0M81T301`O60806ahG200L7Q/201XL6@04
01/M6P0L7Q/07AlL01dO70807R0M0P0M7a`201`N6`<06adJ00<06Q`I01XL6`0J71/01P0J71/801XL
6@<07AhH0P0N7aT301lP6PP0824K200T9Ad2028R6P<08b<K0`0T91`;028S7@808B8L0`0P8A/801hP
7@P0824K0`0M7a`201`N6`<06adJ2@0M7a`301lR6`<07R4J0P0M81T801lR6`0301lP6P0P8A/08R<M
00808b@N00@08R<M020Q6`0O81X08R<M0`0Q8Q`2020Q6`807b0J400O7ad201lP6P80824K0`0Q8Q`0
0`0R8ad082<L020S7006020S7004024T7@0P8a`082<L020S70<07b8K00@07R4J01hP7@0N81d07R0M
:oooool002[ooooo00<0X7M30:9iA@2UO4P00P2WOTX00`2VODT0Y7]70:9iA@020:AiAP<0YGY70`2V
NdP20:5hA0H0XWU5202SNDT20:MnBP80YWe9102UO4P01@2YOdd0Z7i<0:MmB`2VO4X0YG]900<0Y7Y8
0P2UODT40:InBP80Ygm;0`2UO4P00`2VODT0Ygi:0:QoB`020:V0C0P0ZGi;0P2ZP5001@2ZP4h0ZX5=
0:Z1C@2ZPDd0ZX5;0080ZX59202YP4`80:UoC@80ZH1<0P2ZPDd20:^2CP80[8=?0P2WOTX00`2XOd/0
ZH1<0:Z1C@020:^2CP030:b3C`2YOdd0ZGm=0080ZX1>00@0Zh5?0:b2D02/PU00[89@0P2YP4`20:Z1
C@80Zh9>0P2/Pdl20:j5C@040:j5C`2^QE40[XEA0:j4DP80[XAD202ZQE402`2YQ500ZXEA0:^6DP2/
Qe<0ZhIB0:Z5D@2XPdl0Yh9>0:Z0CP2[PDl0[89@0080[H=A00<0[89@0:^1C`2ZP4h00`2XPdh20:N2
C@<0YX5<0P2SOTT00`2RODP0XGa70:1kAP0209mjA@0709iiA02MN4@0WGQ409ag@`2KMT80VWE109Ud
@00209Qc?`<0UG0l0`2FLCd209Mb?P0609=]?P2BK3d0TV`m095[?02@JS/0SfTj0P2>J3T01@2@Jch0
SVTl08]V>@27HSD0QF0c00<0Q5lb2020GC<01021GSH0Oe`d07aI<@1jEbl407QE;@0507QH;`1gEbh0
MUH]07AD:`1bDRT00P1`D2L206i>9@0407ED<@1dDc00Le8_079A;P80LE0]0P1`Cb`806a>:P0<06]?
:P1/D2/0KU0Z075A:P1cDRT0ME8X07IC:@1hDbL0M5DW07IG:@1hFB/0NU/]0P1kG2h00`1jFbd0NEX/
085O<@03089P<P80Pf4c0P24HS@4089P<P@0Pf4c0P26HC@208MR=@80R6<f0P29I3L0102;ICP0RV@g
08YT=`2:I3L308US=P0308QR=@2:ISH0RVHf00H0RVHf00H0Qf@^08MS;`27Hbl0Qf<a08MS<`27HSD2
08MR=P80Q68b00@0Q68d08=Q=022GcD0PUlg0P21GSP208=P=P80PUle0P21GS@2081M<`80PUle0P21
GS@2081M<`80Oe`b0`1nFc<207mL=0<0P5de0`20GS0207mM;`<0OU`^0P1lFBl207eJ<080OU/a0P1o
G380201lFC40OEXb07mL=020GCD0Oe`d07eJ<P1jEbl0N5D]101mFS0407aI;`80NeP`1`1jEbl01@1d
E2/0MED/07EE;01fERd0MeL^0080N5P_00<0NET`07IF;@1fERd00P1fERd207EE;080M5@[01P0KeTb
06aF;`1XD2X0ID/V06I:9@1YBbL0Kdh[079A;P1[CRh0JTd]06U<;01WBRX0IDPX06=69P1RABD0HD@T
05a89`1JARD0ED8R050o8@1>?B40CShT04m19P1@@RP204hn90<0CCdS0`1<?280201;?bD0C40V04e1
9`1>@RP0CD4W04Xn9016>R00A3PN0P1:?b<304]090<0C44U0P1;?bD01019?B<0B3`R04Lk8@17>b42
04Hj8080ACXV0`14>BD304<h90<0@CTT0P10>2<303lg8P0603db800k<R40>S4P03Pa8@0f<280<blS
0P0a;b<402//7P80:R/M0P0Y:Q`302PZ7`809bTN0`0V:1d402LY7P0402HX7@0U9a`09BLL02@V6`80
8RDL0P0S9Qd202@W7P809BPO200S9Qd802@W7P809BLJ0`0V:1/402LY70@09BHN100T9Ad302@W70<0
9BPM0P0V:Ah302DW70809RPM0`0W:Ah202TZ8P@0:R/S0P0Y:R8802PZ7`0302LY6`0X:Q`0:2XL0080
:B/M0P0Z;1h01@0[;Al0;RdI030_6`0b<Ad0=3<O0080=SDQ0P0e=20203Xc80H0>c@Q0P0h<ad203Td
7P0403Xe7`0k=R00>cHP03/f8080@3TO0P11>R02048k8@80@c`R00T0AC`O04Hm8017?R40B3lR04U0
8`1:@B@0Bd8U04a39P1>AB@00P1?ARD00`1@AbH0DDPW0599:00205=::@80FT`W0P1IBbH01@1JC2L0
G4hY05i@:`1ODB`0G4XT0080GD/U0P1NC2H205m=9`06061>:01SDRL0He8W06AA9`1WDBP0J54X0P1Y
D2P01@1/D2T0IU@/06ID;01VE2`0IE<[0080I58Z0P1SDBT3069C;080HE8[0`1PDBX205e=:@80G4`X
00@0Fd/W05Y:9P1IBBD0FDTU201LBRH305U99@<0F4PT0`1GAb<00`1FAbP0E4DV0593900305118P80
DD8S0`1?@24405118P0305528`1B@R40DT8Q0080Dd<R0`1DA2<00`1EAB@0F4DU05Q59@0405M49080
ET<S201C@R@205=49@80DT<T00@0DD8S05118P1@@B80D44R101=?Ql404`m7P0404`n8@1=?b80CT0S
04i08`@0Cd4T201:?b<204dl8P0604`l8P1;?B80BChR04Po8P17?R40AChQ0P19@2<00`18?b80AchQ
04Hm800204Dl7`0304@k7P12?R40@ShQ00H0@ShQ0`11?B83040l8@80?c/P2011?B8304<o9080@ShS
0`11?B8303Xh8@<0>CLP0P0h=Ql203Xg900603Tf8`0g=240=S<P03Db7`0d<Ah0<c0M0`0^<1/202la
70<0<38M00L0;2hP02/]7`0[;Al0:R`N02T[7@0W:A/09BLI008092HH0P0S9Qd2028U70808B@K2P0P
8aX201`S6`<06b8J0`0J8AT801PN6P8061hL0`0G7A/;01HL6Q005aTH200F61L801HG6@P04QPH2@0F
5aT01`0H6A/06Q/M01`M7`0M7R006a`N01TJ700G61X0400E5QP801DG5R<05AHH100G61X:01DF60P0
5ALF200C6AT801DF60P05QLI>00E5QP801<I5`P05QLI200E5QP301@E5`<05AHH0P0F5aT901DF61P0
5QLI200F61L801HG6@P05QPG0`0E5aH201HH5d<05aTH200I6aX801TK60<06a/I0P0L71X301dM6`T0
71`J0P0N7Q`601dM6`P0824K200Q8Q`0200O81P0824I024R6P0R8a/08b@L02@U7@0U9Qh09RLO400T
91`8028Q70@092@L100U9Ad@020Q6`@07b0J100N7aT2020P7P<07alM0`0N7Q`801`N6`P07AdK2`0O
81X3020Q6`808B8L0`0R8ad3024R70@0824K0P0O81X201hO6@807AhH0`0L7Q/201/M6P@06Q`I00<0
7AdK01hN700O7ad00P0P81h00`0O7ad07QhL01dM6`0801dN60<07QlI0`0O81X2020Q6`<07B0I0`0L
7aP201/N5`P06adJ0P0I6aP01P0J71T071hK01dO700N81d07b4N020R7`<071hK0`0K7AX201XL6@P0
6Q`K0`0J71T401/M6P0301`N6`0M7QP07AhH00<07QlI0`0O81X8024R70P092DM1P0R8a/202<T70/0
8B8L0`0P8A/201lP6PP07R0M200P8A/201`N6`806adJ0`0J71T00`0I6aP07AlL01dO700701dO70H0
7R4J0P0M81T801lR6`0301lP6P0P8A/08R<M00808b@N00<08R<M020Q6`0O81X00`0Q8Q`2020Q6`<0
7b0J400O7ad301lP6P80824K0`0Q8Q`@01lR6`<07R0M:oooool002[ooooo00<0X7M30:9iA@2UO4P0
0P2WOTX00`2VODT0Y7]70:9iA@020:AiAP<0YGY70`2VNdP60:9iA@80XGQ4202SNDL40:ImB@80YGa8
0P2TNdL20:MmB`80YWa:00@0YG]90:AjB02SNDL0XgU70P2UO4P20:ImB@80Ygi:0P2XOd/0102TNdL0
YGa80:ImB@2WOTX30:QoB`030:V0C02YOT/0ZGi;00H0ZGi;0P2YOdl01@2YOdd0ZH1<0:V0C02YP4`0
ZH1:0080ZH18202YP4`80:Z0CP80ZH1<0P2ZPDd20:^2CP80[8=?0P2WOTX00`2XOd/0ZH1<0:Z1C@02
0:^2CP030:b3C`2YOdd0ZX1>00<0ZX1>0`2[PDl20:V0C080ZX5=0P2[PTh20:b3C`80[hI>00@0[hI@
0:n6DP2_QU80[hEC0P2_QED90:Z5D@0:0:^6DP2/Qe<0[8MC0:b7D`2ZQE40Z8=?0:N2CP2ZP4h0Zh5?
0:f3D@80[XAB00<0[H=A0:^1C`2ZP4h00`2YQ4l20:R3CP<0Yh9=0P2VOTX00`2UODT0Y7a80:=kA`02
0:9jAP070:5iA@2NNDD0WWU509ehA02LMd<0VgI209Ye@@0209Ud@080UG0l0`2FLCd309Mb?P80U6ho
00<0Tfdn099/?@2AJc`00P2@JS/01P2?JCX0TF`o08mZ?@2<IcX0R6<f08IQ=0<0QF0c2021GS@01@23
H3P0PEhf07iK<`1kF300NEH^00<0N5D]00D0N5P_07MG;P1fERd0M5@[079B:@02075A:003071@9`1_
CbH0ME@a0080M5<`00<0Le8_079A;P1aD2d00P1`Cb`806a>:P80Jdh/00/0KDl[06m?:@1aCbT0Le0X
07AA:@1fDBL0Le@X07AE:@1gF2`0NEX^07YK;`0207UJ;P0307QI;@20GS00PEla0080PEla0P22H382
08=Q<`03081N<021Gc40PEla0080PV0b0P23HC<01024HS@0QV4d08IQ=026HC@208MR=@<0R6<f00@0
RfDh08YT=`2:I3L0RV@g0`29HcH00`28HSD0RVHf08YV=P0608YV=P0608QU;`28I300R6@`08QT<P28
I3@0R6<f0P28HcL01P24HS80Pf4a08=Q<`23HC@0Pf0f089O=`80PUli1022GcD6085N=0@0P5dc0P1o
G38307iK<`80Oe`d0`20GCD3081N<080Oed_0`1nG2h307eJ<080OU/a0`1oG380201lFC40OEXb07mL
=020GCD0Oe`d07aI<@1iERh0Me@/0P1nFc4207eJ<080O5T_0P1kF2h207UF;PL0NUL_0P1eEB`0101f
ERd0MeL^07MG;P1hF2l207UI<080N5L^0P1gERd407IE;00806mI<P1]Ec00JE4[06M=:01XC2L0JddY
06m>:`1bDBh206Q;:`0406I9:@1TAbL0HdHV06549080Gd8R00P0G4PW05Y69@1F@b<0DD0R04ln8P1?
?bD0Cd4V0512:0<0CShT0`1=?B<204`l8P0804Xn901;?bD0CD4W04e19`1<@2H0BCdS04Hj8013=ad2
04Xo8`<0Bd0T0`1<@BD304/o9@0504Xn9019?B<0B3`R04Lk8@16>R000`15>RH304@i9@80@cPT1011
>B@2040h8`80?cLR00H0?S<Q03`c8P0k<R40>C8R03Pb900e<BD203<a9@<0;2dO0`0[;1h202X[7@80
:B/P0P0X:Ql202LY7P809RPM00@0:2XO02LY7P0W:Ah09RPM100U9a`302<V7@8092LN0`0U:1l802<V
7@P092LN0`0U9a`302HX7@<09bTN200U9Qh202@W70<09BPM0`0V:Ah302DW70809RPM0`0W:Ah202PY
8@@09bPP0P0X:B4802LY7P809RPK100W:A`202PZ7@0402X[6@0[;1X0;RlM030a7`<0<S<Q00@0<C8P
03Lb7P0g<Qh0=c8N0P0h<al0100i=200>SDQ03Xe8@0k=R0403`g8@<0?CPR0P0n>20403li8@80@3XR
0P14>Ql01015>b00AS`Q04Pn8`19?b@204Y09@0604Y4901;ABD0BdDU04a69P1=AbL0CTPX0P1?BBT0
201IBbP0F4XW05M99P1FB2D0EdTV05Y<:@1LCR/0GU0]0P1OCBL4061>:080HDlY0P1OD2L00`1RD2P0
He0X06I@:@0206Q@:P0406U?:P1UDb/0IE<[06EC:`@0I58Z00<0He4Y069C;01QDR/00P1QDR/2061A
:P80Ge0Y0P1MCBT205a<:00405];9`1JBRH0FDTU05U99@P0G4XV101HB2@205M78`<0ETHR00@0DdDX
05949`1@@RD0CT0S0P1<?R400`1=?b80CT0S04`n8@0204`n8@0304do8P1>@2<0CT0S0080Cd4T00@0
DD4P05928@1B@R40DT8Q0P1C@b8205A48`80Ed@T0P1F@b<205E28P80E44Q201A@2@305138`@0Cd8R
00<0CT4Q04`m7P1<?Ah00P1<?Ah404dn7`D0BSlS00<0Bd0T04a19@1<@BD0201:?b<204/k8@0304/m
8P19?R80B3lR0080ASlR00L0AD0R04U08`18?b80B3lR04Ln8@16?B00AC`O0080A3/N2011?B02044m
8P<0@3`Q0`0o>b08048n8`80@clV0P12?RD3044m9003040l8`0j>240>SPQ00<0>CLP0`0h=Ql01P0j
=b@0>CHS03Pe8P0g=240=S<P03@a7P80<c0M0P0];aX402h`6`80;c4L0`0Z;1l0100Y:ah09bTL02HX
6`0U9aX202@V6@<08RDL0P0Q91/;020S6P<06b8J0`0J8AT201TP60P061hJ0P0H7Q`301LM6`/05Q`J
400G6AP801HH5`P05QLI200B61P801HG6@0801@E5`0F5aT06AXL01/L7P0L7Al06a`N01TJ700G61X@
01DF60P05ALF8@0E5QP00`0D5AL05AHH01LH6P0201PI6`0301LH6P0E5QP051DG00P05AHH200E5aH8
01<I6@P05AHH200F5aTh01DF60P04aTG200F5aT801DF60<051DG0`0E5QP201HG6@T05AHH600F5aT8
01HH5`P05QLI200F61L301DG5P805QPG@`0G6AP801TK6PP06A/H0`0K6aT201`L6P<07AdK2@0L71X6
01dM6`807QhL200P8A/8024R70807b0H00@0824I024R6P0S91`092DM0P0U9Qh@02<S6`P08R4L100U
9Ad402@T70X0824K100O81X2020Q6`@07QlI100O81X301lO7@<07QhL0P0M7A/801`N6`P07AdK2`0O
81X3020Q6`808B8L0P0R8ad3024R70D0824K0P0O81X201hO6@807AhH0`0L7Q/201/M6P@06Q`I00<0
7AdK01hN700O7ad00P0P81h00`0O7ad07QhL01dM6`0:01dN60<07QlI0`0O81X301dP6@<071lH0P0K
7QL801/M6P806A/H00H06Q`I01`N6`0M7a`07R0M01lQ7P0P8Ql201`N6`<06adJ0`0J71T801XL6`<0
6Q`I00<06adJ01`N6`0L7Q/00P0M7a`301hO6@<07b0J0P0P8A/8024R70X08b@L1P0R8a/8024R70@0
824K0P0O81X201hO6@P07R0M200P8A/301/M6P<06Q`I0P0I6aP901`N6`H07B0I0P0N8AX801lR6`03
01lP6P0P8A/08R<M00808b@N00<08R<M020Q6`0O81X00P0Q8Q`2020Q6`807b0J0P0N7aT801lO7@P0
7QhL0P0N7aT201lP6P80824K0P0Q8Q`<01hQ6P@07b8K0`0N81d[ooooo`00:_ooool01@2RNDD0XgY6
0:AkA`2UO4P0YWe90080YGa800<0Y7]70:AiAP2TNDH00`2UNTL30:IkB080XgY40`2RND<30:5h@P80
XWU5102TNdL20:9iA@80YGa80`2VODT01P2UO4P0XgY60:9iA@2SNDL0Y7Y80:EkB@80YWa:00<0YG]9
0:AjB02TNTP00P2UNTL0102VNdP0Yga90:QmBP2XODX20:UnB`80YGa600H0Ygi80:QoB@2XOdT0Z7m9
0:MnB02VODL80:UnB`80ZGm?00D0ZGm=0:V0C02YP4`0ZH1<0:V0BP020:V0B0P0ZH1<202ZP4h20:V0
C080ZX5=0P2[PTh20:b3C`80Z7m;0`2YP4`30:Z1C@P0ZX1>0P2YP4`20:Z1C@80Zh9>0P2/Pdl20:n6
CP040:n6D02_QU80[hIB0:n5D`80[hEE202[QU802`2ZQE40ZhIB0:b7D`2]R5@0[8MC0:^6DP2YQ500
Z8=?0:^1C`2/PU00[H=A0080[XAB00<0[H=A0:b2D02[PDl00`2ZQE020:V4C`<0Z8=>0P2XOd/00`2W
OTX0YWe90:ElB0020:AkA`070:=jAP2ONTH0WWU509iiA@2MN4@0W7M309]f@P0209Ye@@H0Ug8n0P2F
LCd209E_@080U6ho00P0Tfdn099/?@2AJc`0TF/l091[?P2?JSd0S6Lj08UT=`@0Qf8e2022GcD01P23
H3P0PEhf07iK<`1lFC40NUL_07UF;P80NUL_0P1fERd00`1eEB`0M5@[07=C:P03079B:@03075A:01c
DRl0Le8_0080M5<`00@0Le8_075@;@1_CR/0KTdZ0`1]Cb/206a>:P<0JddY0P1ZCBd02P1/CR`0KTdZ
071>:@1aCRP0LTlY07A>9`1bDRT0Le<Z07EE;01gEbh207QH;`80MeL^00@0OU`^07mM;`1oGBl0Oed_
0P20GS02085O<@06081N<021Gc40PEla089P<P23HC<0Q68d0P25HcD01025H3<0QV4d08IQ=026HC@2
08MR=@80R6<f1029HcH408YT=`P0RFDe00H0R6D_08QT<028I300R6@b08QT=028HcH208QS=`80Pf4a
00@0Pf4c08=Q=023H3H0Pf0h0P23H3X4089O=@@0PEhd1@20GC<307mL<P<0OU/c0P1oG3@3081M=@<0
P5h`0P1oGBl307iL;P80OEX`0P1nFc4307mL<P03081M<`1lFC40O5Ta00<0OEXb00@0O5Ta07YG;`1j
Ebl0Oe`b0P1nFc401@1mFS00O5T_07]H;P1kF2h0NUL]0080N5D]0P1iERh507YG;`0407IF;@1gEbh0
MeL^07MG;P@0N5P_00<0NeP`07YG;`1hEBd00`1gE2`207QE;@0H06iH<@1/ERl0Je<]06Y@:`1[CbX0
KDl[06m>:`1`Cb`0J4/[06M::P1VBBT0I4LW06959@1P@b<0Gd8R05i18@1KAbH0FTHU05Q59@1EA2H0
E4<W05519`1?@BH0Cd4W0P1??bD204hn90<0CCdS00<0C3`R04Xn901;?bD00P1;?bD0101:?R@0BCdS
04Lk8@16>R0204Xo8`<0Bd0T0`1<@BD0201;?bD0C40V04a09P1<@2H0BclU04Tm8`18?280ASXP0P16
>bL204Dj9P<0A3TU00<0@cPT044i9011>B@00P10>2<303lg8P0703hf8@0o=280?3<R03`c8P0k=2@0
>C<U03Lc9`0203Dc9`<0;BhP0P0/;Al302//7P<0:B/P0P0X:Ql302LY7P80:2XO00<09RPM02DW700T
9Q/00P0U9a`00`0V:1d08bHM02<V7@0202@W7P<09BPO00<09RTP02<V7@0S9Qd03P0S9Qd202@U7@80
9BHN0`0V9al202LX800402@U7@0U9Qh09BHN02DV7P<09RLO00<09bPP02HY7P0V:Ah0100V:Ah202DX
7@<09BLL0P0V:1d302LY7P0302LX800V9al09BHN008092DM00<09BHN02HW7`0W:200200W:Ah802HX
7@0402HY600X:aX0:RdL02d`7`<0;S4P00<0;C0O03<a700c<A`00P0b<1/0100c<A`0=C<N03Hd7`0h
=R4@03dh8P<0A3XQ00<0AC/R04Hl8`17?B@00P18?RD204Q1900404U29@1:@bH0BT<V04]49`80C4DX
00P0EdPW05E69@1DAB@0Dd@S05A5901FAbH0FT/Z05a=;0P0H4hZ0P1LCRL01P1NCbP0H4hX069>:@1U
CbX0IU0[06M?:`P0He4Y0`1OD2T205i?:0<0GDhW0P1LC2P0101KBbL0FTXV05Y:9P1IBBD205Q890P0
FTPT101FAR8205E58@<0E4@P00H0D4DY04m4:01<@BD0BSlS04Tn8P18?B4404Tn8P80BSlS00D0Bd0T
04a19@1=@RH0CD8V04m07`0305118080DD8Q0P1B@b8205I38`80ED8R00@0E44Q05=0801B?al0DSlO
201>?R@00`1=@R80C44Q04a18@0504a18@0404`m7P1=?Ql0CChO04dn7`<0CSlP00@0Cd0Q04Y09@19
?b@0B3hS0P17?B8204Pn8`0304To9019?R80BChR00H0BChR0P1:?2401P18?B40B3lR04Ho8P15@280
AT4S04E28`80B3lR00<0AchQ04Hm8015?1l00P14>ah00`13>Qd0@CdP044m8006044m8004044m8P10
?240@3`Q040l8@80?c/P0P0n>Ql8048n8`<0@C`V0P10>bD303lj900403Xh8@0i=b00>CLP03Tg8080
>3HO0P0g=Ah203Pe8P0403Ld8@0f<b00=C8O03Db7`80=34N0`0^<1/202d_6P<0;2hI0`0X:Ql00`0W
:Ah09RPM02DW700202@V6`0302<U6P0R9A`08RDL00808B@K0`0P8aX901lR6@<06b8J0P0J8AT301TP
60P061hJ0P0H7Q`301LM6`/05Q`J400G6AP801HH5`P05QLI200B61P801HG6@805AHH00H05aPJ01PI
6`0H6A/061TK01LH6P0F5aT@01DF60P05ALF8@0E5QP00`0C51H05AHH01LH6P0201TJ700301LH6P0E
5QP04a@F00P05AHH200E5aH801<I6@P05AHH200F5aTh01DF60P04aTG200F5aT801DF60<051DG0`0E
5QP201HG6@T05AHH600F5aT801HH5`P05QLI200F61L301DG5P805QPG@`0G6AP801TK6PP06A/H0`0K
6aT201`L6P<07AdK2`0L71X301dM6`<07QhL200P8A/8028S7@0501lP600P8AT0824I024R6P0R8a/0
0P0S91`00`0T9Ad08b<K02<S6`0>02<S6`P08B0K00@09RHN02DU7@0U9Ad09BDM0`0T91`00`0S8a/0
824K020Q6`08020Q6`0401lP6P0N7aT07QlI01lP6P80824K00@07AhH01hO6@0N7aT07QlI0`0O81X0
100P8A/07alM01lO7@0O7ad201hN70<07AdK200L7Q/801dM6`/07b0J0`0P8A/2024R7004028S7@0Q
8Q`08B8L024R7080824K0P0O81X2020Q6`807b0J0P0N7aT201dN60<071hK0P0K7AX401XL6@0301dM
6`0N7Q`07alM0080820N00<07alM01hN700M7A/02`0M7QP201hO6@<07b0J0`0M81T301`O60806ahG
2P0J71T0100K7AX071hK01dO700M7a`201hP7@0401`N6`0K7AX06adJ01/M6P806Q`I0P0I6aP801XL
6`0601TK600J71T06Q`I01/M6P0L7Q/07AlL0P0N81d301hO6@807b0J0`0P8A/8028S7@P08b@L0`0R
9A`3024T6`8082<J2@0P8A/301lP6P807QlI0P0M7QP801hP7@P07b0J0`0L7Q/201/M6P<06Q`I2@0L
7Q/301`O60<07B0I2P0N8AX00`0O81X0824K028S7@0202<T7P03028S7@0P8A/07b0J00<0824K0P0O
81X301hO6@P07alM200N7Q`301hO6@807b0J0`0P8A/;01dP6@807R4J0`0O8Q/301hP7B_ooooo000Z
ooooo`80Y7]70`2SNTH00`2TNdL0YWe90:MnBP020:AiAP<0YGY70`2VNdP30:=j@P030:9i@@2QN400
XGQ00080X7Lo00<0XGQ20:9i@`2TNdD00P2UO4H03`2TNdD0XWU30:5h@P2TNdL0YGa80:ImB@2WOTX0
YWe90:ElB02SNTH0XGQ40:1fA02RN4H0Y7Y80:IlBP020:MmB`0B0:IlBP2UNdT0YWQ60:IhAP2WNDL0
Z7Y80:UkB@2ZO4X0Zge;0:anC02VODD0Ygi60:QoA`2YP4P0Z7m70:MnAP2UO4@0Y7]3202YOT/20:Qn
CP050:QnC02XOd/0Z7m;0:QoB`2XOdT00P2XOdL80:V0C0P0ZX1>0P2YP4`20:Z1C@80Zh9>0P2/Pdl3
0:Z1C@<0ZH1<0P2XOd/40:Z0CP@0ZGm=0P2YP4`20:Z1C@80Zh9>0P2/Pdl20:n6CP040:n6D02_QU80
[hIB0:n5D`80[hEE202[QU800`2ZQE40ZhIB0:b7D`020:f8E0060:^6DP2YQ500Z8=?0:^1C`2/PU00
[XAB0P2_QE<00`2^Q580[89@0:^1C`020:^6D@80ZXE@0`2YQ4l01`2XPdh0ZH1<0:QoB`2XOd/0Ygi:
0:ImB@2UO4P00P2TNdL209mjAP80WWU500@0WGQ409ag@`2KMT80VgI20P2IM400102HLcl0Ug8n09Mb
?P2FLCd209E`?00609Ma@P2FL440UFm009E_@02DKSl0Tfdn0P2BK3d0102?JSd0SVTl08]V>@29I3L2
08QS=P0308UT=`2:ICP0PUle00L0PUle00@0PUlg085N=P1nFc<0O5Ta0`1kF3000`1lFC40M5@[07AD
:`0707AD:`09075@;@1bDBh0Le8_07=B;`1bDBh0L4l/06i=:P1/BbP0KU0/0080KDl[0P1/CRX206]=
:@0=06Y<:01ZCBl0JTd]06]<;@1]C2/0KddZ071<:01`CBL0LT`W075A:P1bDR/0M5@]07IF;`0207MG
<080MUH_0P1lFR`207eK;@<0OU`^00T0Oed_085O<@21Gc40PV0b08=Q<`24HS@0QF<e08IT=P27ICL0
0P25H3<308IQ=0<0Qf8e00D0Qf4d08QR=@28HSD0RF<f08YT=`0208]U>00308aV>@28I3@0R6@d00H0
R6@d00H0R6D_08QT<028I300R6@b08QT=028HcH208QS=`80PV0`00@0Pf4c08=Q=023H3H0Pf0h0P23
H3X4085N=0@0PUle1P1oG382081M<`<0OU/c0P1oG3@3081M=@<0P5h`0P1oGBl307iL;P<0OU/a0`1o
G382081M<`0307aI<@1kF300NUL_0080NUL_00<0O5Ta07eJ<P1nFc<00P1oG380101nFc40OEX`07aI
;`1kF2h207YG;@0307MD;01hEBd0N5D]0080NEH^0`1jEbl00`1kF300NET`07UI<00307QH;`<0MeL^
0200O5Ta07YG;`1hEBd0Me@/07IC:`1gE2`0N5D]07UF;P1[EBh0K5H_06eE;`1^E2l0Ke<^06i@;01_
CR/0KTdZ06]>;P1ZCBd0JD`/06M::P1UB2P0HdHV06959@1QA2@0FTHU05]79P1KB2P0FTT[05Q7:`1D
A2X0D48W04do9@<0CclU0P1>?R@304dm8`80BShT00H0BCdS04Pl8P18?280B3`R04Tm8`1:?R@204Xo
8`<0Bd0T0`1<@BD0201;?bD0C40V04e19`1=@BL0C40V04Xn9018?280ASXP0`16>bL204Dj9P<0A3TU
0P10>2<203lg8P<0?SHQ00L0?CDP03ld8P0m=2<0?C@S03/d900j=2H0>3@X0080=cDY0`0^;b4202d^
80<0;2dO100Y:b0202PZ7`809bTN00<0:B/P02PZ7`0V:1d00P0T9Q/00`0U9a`09RPM02LY7P0302@W
7P<09BPO0P0V:B0@02<V7@<092DO0P0U9R0402HW8@8092DM0P0U9Qh0100V9al09bPP02LX800W:202
02P[800402LZ7`0V:Ah09RTN02DX7@8092LL0`0U9a`202HX7@<09bTN00<09RLO02DV7P0T9Ad00P0R
8a/00`0T9Ad09BHN02HW7`0802HX7@<09bTN1@0V:1d01P0T:1L09BTH02L[6P0Y;A`0:RhM02T]7080
:2`K0P0_;QT202h]600402l^6@0a<1/0=3<N03Dd7`@0>SDO100i=1h503Xh8@<0>CLP0P14>B<604Dj
9080A3lQ00<0AD0R04I18`17@R@00P18@bD02@19A2H0EDHU05=48`1@@B00Cd0O0511801CA2<0EdPW
05Y;:P0405e::@@0G4TX00P0F4`V05U;9P1JC2L0G4`X05m=:@1QCBX0I4d[06E>;0P0HDlW00@0G4dV
05]<9@1KC2D0Fd`U0P1JBb@205U:8`80Fd/W00@0FTXV05U99@1HB2@0EdLS0P1FAR8805Q68P<0E4@P
0P1C@al305927P0505517@1?A2P0CT<W04]09019?R801017?20204Tn8P0404Xo8`1;@2@0C44U04e2
9P80CT<W0`1>@Al204m280<0D4<Q0P1F@b<01P1E@R80E44Q05=0801B?al0DChN050m7@P0C3hS0`1;
@20504a18@0304dn7`1>?b00CSlP0080Cd0Q0P1@@B801@1A@R<0BD8X04Q19`16?bD0A3dS0080@c`R
00<0A3dS04Dn9019?R801`19?R801P19>b00Ac`P04Pm8@17?R40ASlR04I18`80AD8S0P18?b801017
?R40ASdP04Dl7`14>ah204<j7@P0@3`O0`10?24203lk80<0?SXO2012?R<303lj90<0?STS0P0m>283
03Tg8080>3HO0`0g=Ah403Hc80@0=C8O0P0`<Qd0100_<A`0;BlJ02`^6@0Z;1L202T[5P<09bTN0P0V
:1d0100U9a`092HK02<U6P0S9AX3024T6`<082<J0P0O8QT801hQ600401/R6P0J8AT06R4I01XQ6@80
6B0H0P0H7aL801PN6P8061hL0`0G7A/;01HL6Q005aTH200F61L801HG6@P04QPH2@0F5aT01@0E5QP0
51DG01<D5P0C51H051DG01805AHH200E5aHQ01DF6003018C5@0D5AL061TK00806Q/M00<061TK01@E
5`0B4aD0200E5QP801DG5PP04aTI200E5QP801HG6@P05AHH200F5aTX01DF60P04aTG200F5aT801DF
60<051DG0`0E5QP201HG6@T05AHH600F5aT801HH5`P05QLI200F61L301DG5P805QPG@`0G6AP801TK
6PP06A/H0`0K6aT201`L6P<07AdK300L71X00`0M7A/07QhL01hN700201lO7@P08B8L200R8ad8024R
6Q008R8J200Q81/202HV7P809BDM0P0T91`202<S6`P0824K00<08B8L020Q6`0N7aT00P0M7QP00`0N
7aT0824K024R700201dN60807QlI0P0O81X2020Q6`0401lO7@0N7Q`07QhL01hN70807AdK0P0L71X8
01`N6`P07AdK2`0O81X3020Q6`D08B8L0P0P8A/301lP6P80824K0P0O81X201hO6@807AhH0`0L7Q/2
01/M6P@06Q`I00<07AdK01hN700O7ad00P0P81h00`0O7ad07QhL01dM6`0801dN608071dG0P0M7QP3
01hO6@0401lP6P0M81T07B0I01dP6@<071lH0P0K7QL801XL6@L071hK00@07AlL01/M6P0K7AX06adJ
0P0J71T301TK60P06Q`K00D06A/H01XL6@0J71T06adJ01dO700201hP7@0301lQ7P0N7aT07b0J0080
7b0J0P0P8A/2024R70P08R<M200R8a/2024W7@8082HL00@07bDK01hT6P0N91X07R@J200P8A/201lP
6P807QlI0`0M7QP00`0L7AL07R0M01hP7@0601hP7@P07b0J0`0M7a`201`N6``06adJ0P0K7QL201`O
60807B0I2P0N8AX00`0O81X0824K028S7@0202<T7P03028S7@0P8A/07b0J0080824K0P0O81X401hO
6@P07alM200M7A/401hO6@807b0J0P0P8A/801dP6@8071lH0P0M81T0100N8AX07b8K01lR6`0O8Q/3
01hP7B_ooooo000Zooooo`080:ImB@2TNdL0XWU50:5hA02RNDD0Y7]70:MnBP2XOd/20:AiAP<0YGY7
0`2VNdP0102TNd<0XgY20:=j@P2RND420:5h@080X7Lo00<0XGQ20:9i@`2TNdD00P2UO4H07@2TNdD0
XWU30:5h@P2SNTH0Y7]70:ImB@2WOTX0YWe90:ElB02RNDD0XGQ409id@P2PMT@0XgU70:IlBP2WOD/0
Z7i<0:MmB`2VO4X0YGM50:IhAP2WNDL0Z7Y80:UkB@2ZO4X0Zge;0:anC02WOTH0Z7m700<0ZH1800<0
YWe50:Ak@`2RND40202YOT/20:QnCP050:QnC02XOd/0Z7m;0:QoB`2XOdT00P2XOdL80:V0C0P0ZX1>
0P2YP4`20:Z1C@80Zh9>0`2/Pdl20:^2CP030:Z1C@2YP4`0Z7m;0080Ygi:0`2ZP4h50:UoC@80ZH1<
0P2ZPDd20:^2CP80[8=?0P2_QTh0102_QU00[hIB0:n6DP2_QE<20:n5E@T0ZhIB00X0[8MC0:f8E02]
R5@0[HQD0:^6DP2YQ500Z8=?0:^1C`2/PU00[XAB0P2_QE<00`2^Q580[89@0:^1C`030:^6D@80ZXE@
0`2YQ4l20:YoC0030:UnB`2XODX0Yga90080YW]800L0YGY70:1kA`2ONTH0WgY609iiA@2MN4@0W7M3
00<0VgI200D0VWE109Ud@02HLcl0Ug8n09E`?00209A_>`80Ug5200<0UW1109E_@02DKSl00P2CKCh0
102BK3d0SVTl08eX>`2;IST308UT=`80RfHi2023H3H01P22GcL0P5de07iK<`1lFC40NeP`07aI<@80
OEXb00@0LU8Y07=C:P1cDbX0M5@[0`1eEB`207IF;@08071?;01aD2d0LU4^07=B;`1bDBh0Kdh[06e<
:@1[BRL206i@;00406e?:`1/CRX0K4hZ06]=:@80JT`X0P1YC2h00`1[C2d0KD`[06i<:@0206m;9`06
075;9P1`D2T0LU8[07AD;@1fERl0MeL`0P1fERl0101eEBh0NeT[07]I:`1kFB/207aJ;0<0OE/]00P0
PEla089P<P23HC<0Q68d08ES=@26I3H0QfDg08QV>0<0QF0c0P26HC@308MR=@0808IP<`27HC@0R68e
08US=P2:I3L0RfDh08aV>@2=IcX808MS<`0608QU;`28I300R6@`08QT<P28I3@0R6<f0P28HcL2089P
<004089P<P23HC@0Pf0f08=P>080Pf0j1021GS@4089O=@80OU/a101oG382081M<`<0OU/c0P1oG3@3
081M=@<0P5h`0P1oGBl307iL;P<0OU/a0P1oG383081M<`0@07aI<@1kF300NEH^07QE;@1iERh0NeP`
07iK<`21GSH0P5dc07mL<P1nFc40OEX`07aI;`1kF2h0NUL]07UF;080Me@/0P1hEBd01@1iERh0NUL_
07YG;`1jEbl0NeP`0080NUXa00@0NET`07QH;`1hF2l0MeL^0P1fERd0801nF340OEL`07YD;@1iDb`0
N58[07UC;01kEBh0O5H_06YD;@1[EBh0KUH`075G<P1bES40L58^06i=:P1/BbP0Ke8b06iA<@1]D300
Jdh^06U<;01WBRX0ITTY06E8:01IAB@0FdLV05e::P1MC2h0G4/_05I6;01@@RL0C3hT0`1??bD304hn
9080CCdS00<0BclU04Tm8`17>b400P16>R000`18?280BclU04e19`0204Xo8`<0Bd0T0`1<@BD0201;
?bD0C40V04e19`1>@RP0CD4W04/o9@18?280Ac/Q0`16>bL304Dj9P80A3TU0P0o=b8203hf8@<0?CDP
00L0?3@O03ld8P0m=2<0?C@S03`e9@0k=BL0>CDY0080=cDY0`0^;b4202d^80<0;2dO00@0:R`Q02T[
800Y:b00:B/P0P0X:Ql202LY7P0302T[800X:Ql09RPM00<092HK00<09RPM02LY7P0T9ah00P0T9ah2
02DX7`<09RTP400S9Qd302@U7`<09BHP0`0V9b4202@U7@0402DV7P0V9al09RLO02LX8080:2TQ00H0
:RdR02T/8@0X:b009bXO02HY7P0T9a`202<V6`<09BLL0P0V:1d302LY7P0302HW7`0U9Qh08b@L0080
8B8J00<08b@L02DV7P0V9al0200V:1d502LX80<09RLO00X08bLH02@X6@0V:Q/09b/L02P/7@0W:a`0
9RXK02DY6P0^;AP0;B`G0P0/:aH0100];1L0<2lJ038a700d<ah203Lb70@0=S4K0P0e<1X203Xh8`D0
>CLR00@0>3HQ04Dj9015>R@0ACXT0`14>B<204<h8P80@CdP00<0@ShQ04<o8P14@2<00P15@B@02@16
@RD0Dd@U05528`1?@240CChO04ho801A@R<0EDHW05Q9:P0505U69@<0F4DT00P0ETXT05M;9@1IBbH0
Fd/W05i<:01PC2T0HDdZ06=<:P<0GddU1@1PCRH305U:8`80F4TR0`1GB24205Y:9P0405U99@1HB2@0
EdLS05I68P80EDDQ201GAB4505927P80DD4M0P1@@1`0101>A2T0C48W04Y09@17?B8404Dk8080B3hS
00@0BClT04Y09@1<@RL0CD<X0P1>A2T0101=@1h0CT4O04i17`1>@Al204m28080D4<Q00P0ET<S05E2
8P1D@B40Dd0P058o7`1A?Qh0D3dM04ll70P0BcdS1@1:@B0304]28@80CSlP00@0Cd0Q05118P1@@B80
DD8S0P1B@b@0101:@bT0B44W04Ho9@13?282048k8@80@c`R2019?R8204Ll800304Ln8@15?R40AD0R
0080AD8S00L0A4<T04Po8P17?R40AchQ04Hm8015?1l0A3/N0080@cXM2010?1l2040l8@<0?c/P0`0n
>Ql8048n8`<0?STU0P0m>2@303`g8`80>CLP0`0h=Ql303Le7P80=34N0`0e<Ql303Hc8080<C<N00@0
;c4L02d_6P0[;AP0:B/F0P0W:A@01@0W:2009RLO02HW7`0V9al09BHN008092DM0P0S91`3024T6`80
82<J0`0O8QT801hQ60@06R4I0P0I81P201PO5`P061hJ0P0H7Q`301LM6`/05Q`J400G6AP801HH5`P0
5QLI200B61P801HG6@0301PI6`0F5aT04a@F0080414C00<04A8D01<D5P0D5AL0400E5QP801DG5R40
5AHH00<04Q<E01@E5`0H6A/00P0J6ad00`0H6A/051DG018C5@0801DF60P05ALF200C6AT801DF60P0
5QLI200E5QP801HG6BP05AHH200C6AL801HG6@P05AHH0`0D5AL301DF60805QLI2@0E5QPH01HG6@P0
5QPG200F5aT801HH5`<05ALF0P0F61M301LI60P06A/J200I6aP301/K6@8071`J0`0M7A/901`L6P04
01/K6@0L71X071`J01dM6`807QhL0P0O7ad8024R70P08R<M0`0R8a/2024R6P<0824I400R8QX8024P
6`<09RHN00<09BDM02@T700S8a/00P0S8a/8020Q6`03024R700O81X07QlI008071dG00<07QlI01lP
6P0Q8Q`00`0M7QP00`0N7aT07b0J020Q6`02020Q6`@07QhL0P0M7A/201`L6PP071hK200M7A/;01lP
6P<0824K100Q8Q`3020Q6`<07b0J0P0P8A/201lP6P807QlI0P0M7QP301`N6`806adJ100J71T00`0M
7A/07QhL01lO7@02020P7P0301lO7@0N7Q`07AdK00P07AhH0P0L7AL201dN60@07QlI0`0M81T301`O
60806ahG200J71T301dO70<071hK100K7AX301XL6@<06A/H200J71/01P0I6aP06Q`I01XL6@0L7Q/0
7AlL01hP7@807b4N100O81X2020Q6`808B8L200R8ad8028S6`808BLM0P0P9Q`0100O9A/07R@J01hT
6P0M8aT8020Q6`0401lP6P0N7aT07QlI01hO6@807AhH0P0L7AL801hP7@P07b0J0`0N81d201dO70<0
71hK2@0K7AX0100J7AH06ahG01/N5`0L7aP201dP6@X07R4J00<07b0J020Q6`0R8ad00P0S91h00`0R
8ad0824K01lP6P02020Q6`807b0J0`0N7aT00`0M7QP07alM01lO7@0601lO7@P07AdK00@07AhH01hO
6@0N7aT07QlI0P0O81X2020Q6`/071lH00<07B0I01hQ6P0O8Q/00P0O8Q/301hP7B_ooooo000Zoooo
o`030:ImA@2TNd<0XgY40080XGQ400H0XgU70:AjBP2VO4`0X7I40:5gA@2SNDL20:AjB0030:=iA`2Q
MdD0X7I400P0Y7Y80P2NLd00102OM440X7E20:9gA02SN4D20:AiAP080:5gA@2SNDL0YG]90:MmB`2X
OT`0Yge;0:IlBP2UNdT80:9nBPP0Ygi:00@0XgQ50:AiAP2TNDH0YGY70P2VNdP20:MlB@P0Z8132@2Y
OT/20:QoB`<0ZH1<0`2ZPDd80:V0C080ZH1800@0ZX5;0:Z1C@2[PTh0Zh5?0P2/PU880:V0C080[8=?
0P2[PTh20:Z1C@80ZH1<0`2/Pdd00`2[PT`0ZX5;0:V0BP020:V0BPP0ZhIB202_QU800`2XPdh0ZHA?
0:^6D@020:b7DP040:^6D@2YQ4l0Z8=>0:j9E@80[HQD00<0[8MC0:^6DP2ZQE400P2YQ5020:^1C`06
0:f4D02^QDl0[HA<0:b4B@2[PdP0ZH540`2YP4X20:QoB@<0Ygi80P2RNDD20:5hA0<0X7M300@0WgI2
09]f@P2IM400Ug8n0P2EL3`01@2FLCd0Ug8n09Qc?`2AKCT0TVhj0080U70l01@0Tflk095]>@2>JSH0
SFTe08mY>P2@JS/0TF/l091Z>`2?JCX0S6Hg08US=027HC80S6<e08eT=P2;ICH0RVHf08QT=024HS80
P60_07mO;P80P5h`1P1oGBl01@1gF2T0MePZ07MH:P1gF2`0MeL^0080MeL`0P1gEc4307=C;080LU8[
0`1aDBX206iA:@80KE0X101/CbL00`1ZC2P0JddY06e?:`0206i@;00C06e?:`1[CBT0JT`X06e=9P1^
CRL0KdlX075A:P1cDb`0M5@]07EE;P1fERl0N5db07EJ;`1bEB/0LU8Y07AC:P1iERh0OU/c08AN=`02
081K<@H0PE`b2025H3<01P23GS80Q5lc08EP=026HCD0R6<g08YU>@80RfHj0`28I3@508MS<`0408]U
>02:I3L0RV@g08YT=`80RF<f0`28HSD01`29HcH0RV@g08YT=`29HcH0QV0c08=M<022G2l00`22H383
08=Q<`80Q68d00P0Pf4c089P<P20GS00Oed_07iL;P1oGBl0P5h`085O<@80N5d`00@0NEha07YO<P1j
Gc80Nf0c0P1lHC@00`1mFS00OU/a081M<`02085N=00;081M<`1nFc40OEX`07]H;P1lFBl0OU/a081M
<`1oG380OEX`07YG;@1hEB/00P1nFc4207eJ<080O5T_0P1kF2h01021GS@0Oe`b07eJ<01kF2h207YG
;@80O5T_0`1kF30207YG;`@0NEH^00D0MeLa07IF<01fERl0MUH]07EF:P0207EF:00307EF9`1gEbh0
MeL^00H0MeL^0`1bEBd2075D;0<0L5<[00<0Jdh/06Y=:`1XBbT00P1VBBL02`1WBRP0JD`Z06Y=:`1R
BRP0HDPY05m8:01KARL0F4DW05A39`1C@RP0DD4W0080ED0S00L0ED8T05=2901A@280CSlP04Xm7@19
?1`0C40V0080BclU00<0BCdS04Pl8P17>b400P16>R0204Xn9080BclU00@0C40V04e19`1=@BL0CT8X
0P1<@2H01P1;?bD0BShT04Tm8`18?280Ac/Q04Hj8080CD4W00H0BclU04Xn9018?280ASXP04Di7`14
>1h204Hk7`0304Hj8015>B40ACTS0080A3LT00@0A3LV03`c8P0m=2<0?SDT0P0o=RD00`0m=2<0>c8Q
03Xa800203Pd6`0<03Dc700c<Qd0<38L02ha700]<1d0;34M02/[8`0Z:R80:BXR02LZ8@0T:R008bTO
0P0Q:Ah0200Y:b00:2XO02HX7@0U9a`092HK02DW700V:1d09bTN200V:1d202@W7P808bHM0`0R9A`0
1`0Q91/092LN02<V7@0S9Qd08RDL024T6`0P8aX00P0O8QT302DV7P0302@U7@0S91`08R<K00<08R<K
0P0R:1h0100T9ah09BHN02DV7P0V9Qh202PU7P@08bLH0P0T:1T202DY6P<0:R`Q00<0:B/P02PZ7`0W
:Ah00P0W:Ah802PZ7`P09RPM0`0U9a`202HX7@D09bTN00@0:2XO02T[800Y:b00:R`Q0P0[;B80200Z
;A`08bHE02@W5P0^<B00;c8Q02T/6`0Z;A`0<SDT200^;b4303Td8080>SDQ0`0k=R80100k=Al0?CLQ
03li8`12?2H204<m9`05048l9P11>bD0@SLQ04<h8P14>B<00P16>bD00`15>R@0@cPR048g8@0304U0
8`80BT4T0`1;@RD0401?B2/0CTLZ04e6:@1;A2L0BT<V04Q19017@2<0ASlR05=37`1DA200EDDQ05I6
8P1GAb<0F4PT05U99@1JBRH205a9:0@0FdPW0P1JAbH01P1HB2L0EdPW05M89`1EB2H0DdTV05599@80
CdTU0`1IARH205Q59@<0Ed@T0`1C@b8205928@<0DD4P0`1<@2H204/o9@80BShT0P19?B<504Tn8P<0
B3dQ00D0@SHL04e19`1=@BL0A3PN04/o9@0205eA=`0404e19`1;@RD0Bd8U04]29@80C4<V0`1=A2L2
05A4:P80Dd<Y00@0DT8X05519`1@@2H0D40V201@?bD204a39P0404]29@1:@B@0B3lR04Ln8@80ASdP
00H0DD@R05138@1?@R00CT4O04e07P1<?ad204/n700;04M09016?b<0A3dQ04<l8012>al0@c`P04@m
8@15?R80B3hS04Lm8P16?2400P15>b000`16?240AcdR04Pn8`0304Y09@80BClT0`18?R<304@m8@<0
@c`P0P12>al303lk8080@3`Q0`11?B83044j8080@S/Q0`13?28604Ho8P80AChQ00H0@T0Y044o:011
?bP0@3hW03lm9P0n?2D203dk90<0<cDP0`0b=1l2034c7P<0<CDN0P0`=1d302lc7080:bhM00@0:R`N
02T[7P0X:Ql09bPP0P0V9b4302DX7`8092LN100S9Qd2024X8003020W7`0O9Qh07RDM008072<K00<0
6b8J020S700P8a`00P0O8Q/401hQ6P0401`R7P0K8Ad06b4M01/Q7@806R0L0P0I7a/201/M6P<06Q`I
0`0I6aP201XL6`806A/J0P0H6QT201LI60P06A/J200G6AP801HH5`P05QLI200F61L801HG6@P04QPH
200E5QP00`0C51H051DG01HG6@0201HG6@0301DF600D5AL04Q<E00P05AHH200E5aH801DF614051DG
200F5aT801@E5`0>01DF600I6Q`071dO01/L7P0H6A/05QLI01PI6`0K71h061XI01XL6`0I6aX051HE
01<E500E5aH201LI60P05AHH400F5aT@01DF60P04QPHB@0E5QP@01HG6@P05AHH200F5aT301DF6080
5QLI0`0G61X801HG6@P05aTH00<06A/J01PJ6@0G6AP00P0E5aH00`0G6AP061XI01TK6P0H01PJ6A00
5aTH00@05ALF01HH5`0F61L05aTH0P0H6QT:01TK6P805aTH0P0H6QT201TK6P806Q`K200I6aX801XL
6@806adJ100L7Q/301dO70P07QhL100O81X2020Q6`808B8L0`0P8A/2024R70<08R<M00<08b@L028S
6`0P8AT00P0O81P00`0P8AT08R<K02<T7008028S6`<08R<M0P0Q8Q`3020Q6`0302<T7P0R8ad0824K
00807b0J00<0824K028S7@0S91h00P0U91l202@S7P0:02<R7@0R8A`08R4L024P6`0S91h08R<M024R
700P8A/07b0J01hO6@807AhH200P81h301hN70<07AdK0P0L71X301`N6`806adJ0`0J71T801/K6A00
7AdK0P0N7Q`201lO7@04020P7P0Q8Al08B4O028R80P07QhL00@07b4N01hP7@0N81d07R0M0P0M7a`2
01`N6`T06adJ0P0L7Q/201dO70<07R0M0P0O8Ah301hP7@807AlL0P0L7Q/01@0N81d071hK01/M6P0K
7AX071hK00807AlL2@0L7Q/801/M6PP06adL200I6aX301TK60<06Q`I0P0K7AX0200J7AH06ahG01`O
600M81T07R4J01lR6`0P8a`08B@M200P8A/8024R6P03028S7@0Q8Q`07b0J00807QlI00<07b0J024R
700R8ad0200P8A/2024Q7`<0820N0`0O7ad801`N6`P07R0M0P0N7aT201lP6P04020Q6`0Q8Q`08B8L
028S7@<071hK0P0K7AX301XL6@T071hK00@0820N01lO7@0O7ad07alM0P0N7Q`201dM6`0301/M6P0M
7a`07b4N00808B<P00/0828O01lQ7P0N81d07AhH01hO6@0P8A/08B8L028S7@0Q8Q`0824K01lP6P03
01dM6`0301hN700O7ad0820N0080820N0P0N81d201dO700401`N6`0K7AX06adJ01XL6@P07AdK0`0L
7Q/00`0M7a`07R0M01lQ7P0201lQ7P806A/H00@06Q`I01/M6P0K7AX071hK2P0M7a`301`N6b_ooooo
000Zooooo`030:Ak@`2SNT80XWU30080XGQ400H0XWQ60:=iB@2TNTX0X7I40:5gA@2SNDL20:AjB003
0:=iA`2QMdD0X7I400P0XgU700D0WgA10:1e@P2PMD80XGI30:=hA@020:AiAP090:EjA`2RN4H0XgU7
0:EkB@2WOD/0Z7i<0:MmB`2VO4X0YG]900P0Xgi:202WOTX20:AiAP80YGY70P2VNdP20:MlB@P0Z815
2@2YOT/20:QoB`<0ZH1<0`2ZPDd80:V0C080ZH1800@0ZX5;0:Z1C@2[PTh0Zh5?0P2/PU880:V0C080
[8=?0P2[PTh20:Z1C@80ZH1<0P2/Pdd20:^2C080ZX5;0P2YP4X80:^6DPP0[hIB00<0Z8=>0:V4C`2[
QU400P2/Qe800`2[QU40ZHA?0:R3CP030:b7D`<0ZhIB0P2ZQE40202[PDl0[89@0:f4D02^QDl0[XE=
0:b4B@2[PdP0ZH540`2YP4X30:QoB@80Ygi80`2RNDD20:5hA0<0X7M300<0VgI209Ye@@2HLcl00`2F
LCd0102HLcl0VGA0099^>P2CKc/209A`?00409=_>`2AKCT0Sf/g08eY=@80T6Xk00H0TF/l091Z>`2?
JCX0S6Hg08US=028HS<208eT=P0608]U=P2:ISH0RFDe08AR<P21HC00Oel^1020GS0407mM;`0507UJ
:`1hFB/0N5T[07MH;01gEbh00P1fERl207IF<0<0Le</0P1bDR/3075A:P80Ke8Z0`1^DBT306e@:003
06Y<:01[CBT0KDl[0080KU0/00T0KDl[06]=:@1ZC2P0KDdV06i>9`1_CbP0LE4Z079B:`1dE2d00P1e
EBh0201eFRl0M5T^07=F;01dE2/0MUD/07YG;`1mFS80PE/d1020Fc44085L<P80Peha0P24Gc8208EP
<`80QV4d00@0Q5lc08EP=026HCD0Qf8f0P28HcL01029I3P0RVDi08QT=028I3@608MS<`@0RV@g0P29
HcH308QR=@<0RF<f00@0R68e08IP<`24GS40PU`_0`22H38308=Q<`80Q68d00T0PV0b085O<@20GS00
Oed_07iL;P1oGBl0PEla089P<P1hGC000P1iGS4207YO<P80Nf0c00@0O64d07eJ<01nFc40P5dc0P21
GS@01@20GC<0OU/a07eJ<01lFBl0OEX`0080OU/a00@0OEX`07aI;`1kF2h0NUL]0P1nFc4207eJ<080
O5T_0P1kF2h0201oG380OU/a07aI;`1kF2h0NUL]07]H;P1lFBl0OEX`0`1kF30207YG;`@0NEH^0P1f
ES000`1fERl0MUH]07IG:`0207IG:@0307IG:01gEbh0MeL^00H0MeL^0`1bEBd3075D;080L5<[00<0
K4l]06Y=:`1YC2X00P1WBRP00`1XBbT0JD`Z06Y=:`02069::00?05m8:01MARL0FD@W05M3:01C@RH0
Dd8X05I1901G@RD0ET<U05A39@1B@B<0Cd0Q04/n7P1:?Ad0C40V0080BclU00D0BShT04Pl8P17>b40
Ac/Q04Hj800204Tm8`80BShT00<0BclU04a09P1<@2H00P1<@2H304/o9@80BShT0P19?B<204a09P04
04/o9@1:?R@0B3`R04Lk8@80ASXP0P16>al02016>R00ACTQ04Di8`15>2D0A3LT04@g9P0m=2<0?SDT
0`0o=RD00`0m=2<0?3<R03Xa800203Te700403Hd7@0e<ah0<c8M034c7P80;c8O0100;BXQ02/[8@0Z
:R00:2XO02HY7P0T:Qh08RXM024Y700Y:b00:2XO02HX7@0U9a`092HK02DW700V:1d09bTN200V:1d2
02@W7P808bHM200R9A`4024T6`809BHN0P0T9Ad202<T70<08R<K0P0R:1h0100T9ah09BHN02DV7P0V
9Qh202PU7P04028V600S9aT08bLI02<W6@8092PJ0P0U:A/202X/8@80:B/P00@0:2XO02LY7P0W:Ah0
9bTN200X:Ql802HX7@<09BLL0P0V:1d602LY7P80:2XO0`0Y:b00200Z;A`092LF02@W5P0/;ah0;C0O
02P[6P0Y;1/0<3<R200];R0203Db7`80=S<P0`0g=2401@0h=B80>C<M03/e7`0m=b40?cTS00<0@3XT
00L0?cTS03hf7`0o=b00@CTR048j8`13>b@0@SXS0080@CTR0`16?b8204M08`<0B44T0P1<ABP0101;
A2L0BT<V04U29@18@B@204M08`0605537P1BA1l0DdDP05A68@1EAb80ETPS0P1GBB@505Y79P<0FDHU
00H0ETHU05E69@1EARD0DdHT0557901?Ab<204e78`<0Ed@T0P1F@b<305E28P80DD8Q0P1@@B0304m0
7`0304ho7P1:?R@0BShT00<0BShT0P19?B<204Pl8P@0BChR1018?B402013=ad0CD4W04a09P14>1h0
BShT05Y>=01ICC<0BclU0`1:@B@304]29@80C4<V00@0D40V04lo9@1??bD0CclU101>?R@804lo9@80
Bd8U00@0BT4T04U08`18?b80B3lR0P17?R4204m2800A04i17`1=@1h0C3lM04/n701:?A/0BC`J04M0
9016?b<0A3dQ04<l8012>al0@c`P04@m8@15?R80B3hS04Lm8P16?2400P14>Ql00`16?240AcdR04Pn
8`0204Y09@80BClT0`18?R<01017?B80A3dQ04@m8@14?B4204<l80<0@S/O0`0o>b02040l8@<0@CdR
0P11>R03048k8@<0@c`R1015?R4404Ho8P80@ClX00<0@3hW03lm9P0n?2D00P0m>b@0100l>R<0<cDP
03<e800c=B03038d7`80<C<N0P0a=1l2030c7P<0;c8M00L0;S4L02/^7@0Z;A`0:R`N02T[7P0X:Ql0
9bPP00809RLQ0`0U:1l202@W7P<08bHM00H08RDL024X800P9al082LO01lV7P0M91`201`S6`0301/R
6P0P8a`082<L00807b8K0`0N8AX00`0M81T06b4M01/Q7@0201/Q7@806R0L0P0I7a/201/M6P<06Q`I
0`0I6aP201XL6`806A/J0P0H6QT201LI60P06A/J200G6AP801HH5`P05QLI200F61L801HG6@P04QPH
200E5QP0100B4aD051DG01HG6@0I6Q`401XK7@P05AHH200E5aH801DF614051DG200F5aT801@E5`04
00h?4@0B4aD05QLI01LH6P805AHH00L06AXL01dN800G6AP061XI01LI600E5aH051HE00<05QPG200E
5QP@01HG6A005AHH200B61Q901DF61005QLI200E5QP801HG6@<05AHH0P0F5aT301LH6PP05QLI200G
6AP00`0I6aX061XI01LI600201DG5P0301LI600H6QT06A/J01P061XI400G6AP301HH5`0301LI600H
6QT061XI00X06A/J0P0G6AP201PJ6@806A/J0P0J71/801TK6PP06Q`I0`0K7AX301`N6`<07AlL200N
7Q`0100N7aT07b0J01lP6P0O81X2020Q6`808B8L0`0P8A/2024R70<08R<M00<08b@L028S6`0P8AT0
0P0O81P00`0P8AT08R<K02<T7008028S6`<08R<M0P0Q8Q`3020Q6`0302<T7P0R8ad0824K00807b0J
00@0824K028S7@0S91h09B@O0P0T8ah202<R7@808R4L00L08B0K028S7@0R8ad08B8L020Q6`0O81X0
7QlI00807AhH200P81h301hN70<07AdK0P0L71X301`N6`806adJ0`0J71T801/K6A007AdK0P0N7Q`2
01lO7@80820N0P0Q8Al801hN70@07R0M0P0M7a`201`N6`T06adJ0P0L7Q/201dO70P07R0M0P0M7a`2
01`N6`0401dO700L7Q/071hK01`N6`<07AlL2@0L7Q/801/M6PP06adL200I6aX301TK60<06Q`I0P0K
7AX201/N5`0401`O600M81T07R4J01lR6`8082<L200P8A/8024R6P03028S7@0Q8Q`07b0J00807QlI
00<07b0J024R700R8ad0200P8A/2024Q7`<0820N0`0O7ad801`N6`P07R0M0P0N7aT201lP6P80824K
0P0Q8Q`301`N6`806adJ0`0J71T901`N6`@07alM0P0N7Q`201dM6`0@01/M6P0M7a`07b4N020R7`0Q
8b00828O01lQ7P0N81d07AhH01hO6@0P8A/08B8L028S7@0Q8Q`0824K01lP6P<07AdK00<07QhL01lO
7@0O7ad00P0P81h201hP7@807AlL00@071hK01/M6P0K7AX06adJ200M7A/301`N6`0301dO700N81d0
7R0M00807b4N00<06A/H01XL6@0J71T00P0K7AX201`N6`T07AlL0`0L7Q/[ooooo`00:_ooool20:9i
@@040:1g@@2PMd<0X7M30:1fA080XWQ800<0XGM50:9hAP2SNDL00P2TNTP00`2SNDL0XWQ60:5gA@08
0:5gA@050:5f@`2RMd@0XWM40:=hA@2TNDH00P2UNTL0102VNdP0XgU70:=iA`2UNdT30:IlBP80YG]9
202SOTX80:ImB@<0YGY70`2VNdP20:MlB@P0Z8152@2YOT/20:QoB`<0ZH1<0`2ZPDd80:V0C080ZH18
00@0ZX5;0:Z1C@2[PTh0Zh5?0P2/PU880:V0C080[8=?0P2[PTh20:Z1C@80ZH1<00@0[8==0:^2C02[
PT`0Zh9<0`2ZPD/00`2YP4X0ZhIB0:^6DP060:^6DPP0[hIB0P2YQ4l40:^6D@80ZHA?0P2ZQE430:^6
DP<0[8MC00P0[89@0:f3D@2^QE40[XE?0:j5C@2/Q4T0ZX970:V1A080ZX5;0P2YP4X30:QoB@030:Mn
B02SNTH0XgY60080XWU50`2QN4@01P2PMd<0VgI209Ye@@2IM400V7<o09Mb?P80V7<o00<0VGA009A`
?02DL3`00P2DL3`0102CKc/0TVhj091/>02?JcL3095[?00=091Z>`2?JCX0SFLh08]U=P2:I3D0SF@f
08iU=`2<ISL0RfLg08UU=@25Hc<0PV8a081P;`03085O<@80P5h`0`1oGBl01@1kG2d0Ne`^07YK;@1i
FRh0MeL^0080MUH_00<0MED_07AD;P1dE2d00P1dE2d207=C;0<0LU8[0`1`Db/306mB:P80KU4Y0P1[
CBT406e?:`80JddY00H0KDdV06i>9`1_CbP0L50Y075A:P1cDb`207AD;@08075F:`1bEb`0LeH/07IF
;@1hEbh0NUL_07]H<01mEc0307mJ<080P5/a0`21G382085L;`06089M<024Gc80QF0c08IQ=027HSD0
R6<f2027HSD808MS<`<0RV@g0P29HcH508QR=@80RF<f00@0R68e08IP<`25Gc80Ped`0`22H38308=Q
<`80Q68d00<0PV0b085O<@1oGBl00P1nG2h00`20GS00PEla089P<P0307YM<@80Nehb0`1lGc<207iK
<@@0P5dc0P1nFc40101oG380OU/a07eJ<01lFBl207]H;P0407aI;`1mFS00OU/a07iK<@80OEX`0P1l
FBl207]H;P0307eJ<01lFBl0NeP^0080NeP^00<0OEX`07iK<@1oG3800`1kF30207YG;`@0NEH^00D0
M5@^07EE;`1eEBh0MUH]07MH;00207QI:`0307UJ:`1gEbh0MeL^00H0MeL^0P1cERh2079E;@<0LE@/
00D0L5<[06a?;@1[CR`0JTd[06U<:P0206Q;:@0:06U<:P1ZCB/0I4XW06A::@1QBBL0GTLW05Y59P1H
ABL0ET8W05A39`80F4<V00L0F4DW05I59`1D@bD0DD8S04e0801<?al0C40V0080BclU00<0BShT04Tm
8`18?2800P17>b4204Pl8P<0BCdS101:?R@304/o9@<0C40V00<0CD4W04/o9@1;?bD00P1:?R@01019
?B<0B3`R04Pl8P18?28204Ll800304Hj8016>R80ACTS0080ACPU00<0A3LV03hf8`0n=R<00`10>2D0
2`0n=R<0?3@Q03/c800m=al0?3HN03/f800h=R40=SDP03<e800b<b40<C@Q0080;R/R00@0:b/Q02T[
800X:Ql09bXO0P0T:Qh0200Z;240:B/P02LY7P0V:1d09BLL02HX7@0W:Ah0:2XO200W:Ah302@W7P80
8bHM0`0R9A`3024T6`<08RDL0P0S9Qd0100U9Qh092DM02@U7@0T9Ad302<T70808R<K0P0Q9ad0100S
9Qd092DM02@U7@0U9Ad202LT7@<08RDJ0P0S9Q/302@W70<0:B/P0P0X:Ql302LY7PP0:2XO200V:1d3
02DW70809RPM1`0W:Ah402HX7@0502T[7@0U9aT09BLI02X/7P0[;Al00P0W:A/00`0/;R00:b`N02//
7P0602//7P80<RlL0P0c<1d203@a7P80=C8O00@0=S4M03Lb7P0i=200>SDQ0`0k=R801@0j=B40>S8M
03`d7`0n=R40@3PS0080@SXU0P11>B@304@m8@80AChR0`16?b<00`18@BD0Ad0T04M0900504M09080
D44P0P1A@R40101B@b80Dd@S05A5901DAB@805E5900605=2901B@b@0DT<T05138`1>@b<0C4<R0P1:
A28305918`<0DD0R0P1@?b4304ho8080CChO0`1<?Ah204Tm8`<0B3`R0P17>b4204Hj80P0B3dQ00P0
ACTO04a09P1:?R@0@cLM04Pl8P1EBBl0DdL]04Lk8@<0B3lR0P19@2<304Y190<0Bc/Q0`1<?28204dm
8`P0CShT0`19@2<504Po8P80BSlO0P19?Qh01`18?Ad0Ac`L04Hk6`16>a/0Ad0T04Ho8`14?B400P12
>al01P13?200A3dQ04Dn8P18?R<0AcdR04Dk8080A3XO00<0AC/P04Lm8P18?R<00`19?b@204Pn8`<0
AcdR0P14?B4204<l80<0@S/O00@0@CXN03lk800o>b00?c/P0P10?243044m8P04044j8012>b40@S/Q
048k8@80@c`R0P14?B<204<l800404@m8@15?R80ASlS04Ho8`80Ad0T0P10?RL00`0o?BH0?S`U03dk
900203`j8`0403/i8P0c=B00<cDP03<e80<0<S@O0P0a<ah3030c7P80;c8M0`0^<A`202X]700402T[
7@0X:Qd09bTN02LX80809RLQ100T9ah202<V7@<08RDL0P0P9al00`0O9Qh07RDM01dT700201`S6`04
01/R6P0O8Q/07b8K01lR6`807R4J0`0M81T301/Q7@806R0L0`0I7a/201/M6P<06Q`I0`0I6aP201XL
6`806A/J0P0H6QT201LI60P06A/J200G6AP801HH5`P05QLI200F61L801HG6@P04QPH200E5QP01@0B
4aD051DG01LH6P0J6ad07AhP00<07QlQ200E5QP801DG5PP05AHH4@0D5AL801HG6@P051DG00@0414C
01<D5P0E5QP051DG0P0B4aD00`0F5aT06Q/M01LI600201DG5P0301HH5`0G6AP05QPG00805ALF200E
5QP@01HG6A005AHH200B61QA01DF60P05QLI200E5QP801HG6@<05AHH0P0F5aT301LH6PP05QLI200G
6AP00`0I6aX061XI01LI600201DG5P0301LI600H6QT06A/J01P061XI400G6AP201HH5`<05aTH0`0H
6QT801TK6P805aTH0P0H6QT201TK6P806Q`K200I6aX901XL6@<06adJ0`0L7Q/201dO70P07QhL0`0N
7aT201lP6PH0824K0P0Q8Q`3028S7@0302<T700R8a/0824I00807b0H00<0824I028S6`0S91`0200R
8a/3028S7@808B8L0`0P8A/00`0R8ad08B8L020Q6`0201lP6P03020Q6`0Q8Q`08R<M008092<N0P0S
8Qd4028Q70808B8L0P0P8A/0100O81X07QlI01dN600M7QP801lO7@<07QhL0`0M7A/201`L6P<071hK
0P0K7AX301XL6@P06a/I400M7A/201hN70<07alM0`0P81h801hN70<07R0M0P0M7a`301`N6`T06adJ
0`0L7Q/201dO70H07R0M0P0M7a`401`N6`0401dO700N81d07R0M01dO708071hK00<07AlL01`N6`0L
7Q/01P0L7Q/801/M6PP06Q`K200I6aX301TK60<06Q`I0P0K7AX01@0K7QL071lH01`O600M81T07R4J
00807b8K00<082<L020Q6`0P8A/01P0P8A/8024R6P03024R700P8A/07b0J00807QlI00<07b0J020Q
6`0Q8Q`0200P8A/2024Q7`<0820N0`0O7ad801`N6`P07R0M0P0N7aT301lP6P<0824K0`0L7Q/201/M
6P<06Q`I2@0L7Q/301lO7@807QhL0`0M7A/01@0L7Q/07AlL01hP7@0O8Ah0828O00807b4N00T07R0M
01dN600N7aT0824K024R700R8ad08B8L020Q6`0O81X00`0M7A/201hN70<07alM0`0M7a`301`N6`80
6adJ200M7A/301`N6`807AlL0`0N81d301XL6@806adJ0`0L7Q/801dO70<071hK:oooool002[ooooo
0P2PMcl0102PMd40X7M30:1g@`2PMT@20:1fAP030:5gA@2RN4H0XgU70080YG]900<0XgU70:9hAP2Q
MdD0202PMT@20:=hA@80Y7U60P2UNTL20:IkB0<0Y7Y8102UNdT00`2TNTP0YGe:0:EmBP060:EmBPP0
YWe91P2VNdP20:MlB@P0Z7m72@2YOT/20:QoB`<0ZH1<0`2ZPDd80:V0C080ZH1800@0ZX5;0:Z1C@2[
PTh0Zh5?0P2/PU880:V0C080[8=?0P2[PTh20:Z1C@80ZH1<102[PT`40:Z1B`P0ZhIB202_QU880:Z5
D080ZHA@00<0ZXEA0:^6DP2/Qe<00P2]R5@02@2^RED0[H=A0:j4DP2_QU80[hI@0:j5C@2/Q4T0ZX97
0:V1A0030:Z1B`80ZH1:0`2XOdT20:AkA`80XgY60`2RNDD0102QN4@0W7M309]f@P2KMT8209Ye@@80
VGA000X0VWE109Ea?@2ELCd0UG4m09A`?02CKc/0TVhj095]>@2@K3P0TV`m0P2AJc`03@2@JS/0SfTj
08iX>@2=IcP0S6Hg08iU=`2?ISP0SFLh08aX>02:ISH0QV@d089R<@21HC000P23HC<01022H380PEla
085O<@20GS0207mM;`0507eN;`1mGS00Ne`^07YK;`1hF2l00P1fERl0101eEBl0M5@^07EE;P1eEBh3
07AD;@<0Le</101aE2`2071C:`80Ke8Z201/CRX206e=9P0>06i>9`1_CbP0L50Y075A:P1bDR/0Le</
06iC:01`EBX0M5L]07QH;`1jFC00NUL_07UF;P1jE2d207eH;P0407iI;`1oFS00OeX`081K<@80PE`b
00H0OeX]081K;P21G2l0Peha08EP<`26HC@208QS=P80R6@d0P27Hc<01@26HS80QF4a08EQ<@24H300
QV8b00@0Qf<c0`28I3@208YT=`80RF<f0P28HSD208MQ=0@0R68e00@0Qf4d08IP<`25Gc80QElb0`22
H38308=Q<`80Q68d00P0PEla081N<01oGBl0OU`^07mM;`20GS00PV0b08=Q<`P0OEhb201oG3801`21
GS@0Oe`b07aI;`1jEbd0NEH/07]H;P1mFS000`1nFc4207eJ<080O5T_1@1kF2h207aI;`0307iK<@1o
G380Oe`b00<0NeP`0P1jEbl407UF;P0807AD;P1eEBl0MUH_07MG;P1hFBd0NEX/07YK;@1kG2d807QH
;`<0LeH^0P1bEBd3075D;00306e@;P1/Cbd0Jdh/0080JTd[0`1YC2X0401XC2L0IdXX06A:9`1QBBL0
GTLW05Y59P1IA2L0Ed@V05U49`1JABP0FDHX05M6:01FABL0DT<T04m28P1=@20304/o9@0304Xn9019
?B<0BCdS00P0B3`R1019?B<0101:?R@0BclU04e19`1>@RP204m3:@P0BShT0P17?2000`17>b40ASXR
04Hj900204Dh9@0404Dh9`0n=R40?cLR040h8`80@CTT00<0?cLR03de800l=1l00P0o=b004@0m=b40
?3LS03Tg8P0g=R80=SDS03@e8`0a;B80<2`Q02l]8@0/;200:R`O02T[7P0W:ad09B/M02/]8P0Z;240
:2XO00809RPM00<09bTN02PZ7`0Y:b00200W:Ah202DX7`8092LN0P0S9Qd2028U708082<J00<08B@K
028U700S9Qd00P0T9ah00`0U:1l092DM02@U7@0202@U7@D08b@L0P0Q9ad0100S9Qd092DM02@U7@0U
9Ad202LT7@<08RDJ0`0S9Q/202@W70@0:2XO100W:Ah802PZ7`P09RPM0`0U9a`202HX7@<09bTN00D0
:2XO02LY7P0W:Ah09RPM02DW700202@V6`0602<U6P0X:Qd09RPK02HX6`0X:Qd0:B/N0P0X:Qd00`0Y
:ah0:BXL02TZ700602TZ700402h]6`0_;Q`0;bhL02l^7080<2lM0P0a<1h2038_700303<`7@0d<Ah0
=34N00<0=C8O00@0=BhK03L`7@0j<b00?CHS100o>2D3040j8080@C/Q0`12?28204<l8P80A3dS00@0
AChT04Ho9@16?bD0Ad0V0P1<?R4204do8P0404i08`1?@B@0Cd4T04m19080D44R0`1A@R<305939009
050o8`1?@2<0CSlR04do8P1:?b40BD0Q04M18@16@200Cd0S00<0CSlR0P1=?R4204`m8080BcdP0P1:
?1l304Tk7P0304Pj7@17>b40Ac/Q0080Ac/Q0P16>R0304Di7`<0Ac`P1018?B402@19?R80Ac/Q04/o
9@19?B<0@cLM04Lk8@1@A2X0CT8X04<g7@0204Hm8080AchQ0`18?b801`19@2<0BSXP04/k8@1;>b40
C3`R04dm8`1>?R@00P1??bD804`n8`<0AchQ0P18?b8304U08`80AchO0P16?Ah03`15?1d0A3/L04@k
7014>a`0Ad0T04Dn8P13?200@S/O044j7P12>al0@c`P04@m8@17?B80AS`Q04Dk800204@j7`0304Dk
8016?240AcdR00<0B3hS0P17?B8304Hl8@<0@c`P0`12>al2044j7P<0?c/P0P10?243044m8P<0@S/Q
0P13?28304@m8`06048k8@13?280@c`R04@m8`15?R@0ASlU0P17@2H01P0o?BH0?S`U03hl9@0m>b@0
?3XS03/i8P80>SPQ0`0c=B03038d7`80<C<N0`0_<Ql202ha7P<0;C0M0P0Z;A`0100Y:ad0:2XM02LY
7P0V9al202DV80<092LN0`0S9Qd3028U70807bHN0P0N9Ad0100M91`072<K01`S6`0L8a/201lR6`<0
7R4J0`0M81T201/Q7@806R0L0P0I7a/201PN6P806adJ0`0J71T301TK60806Q`K0P0I6aX201PJ6@80
5aTH200I6aX801LI60P05QPG200F5aT801HH5`P05QLI200B61P801DF6004018C5@0D5AL05aPJ01TJ
70<06a`N00<06Q/M01DF600E5QP01P0E5QP801DG5QT05AHH200F5aT801DF600401TJ700J6ad06Q/M
01HG6@804A8D00X05AHH01TJ700K7A`05ALF01<E500G6AP06A/J01HH5`0C5A@051HE200E5QP@01HG
6A005AHH200B61QA01DF60P05QLI200E5QP801HG6@<05AHH0P0F5aT301LH6PP05QLI200G6AP00`0I
6aX061XI01LI600201DG5P0301LI600H6QT06A/J01P061XI5P0G6AP201PJ6@P06A/J0P0G6AP201PJ
6@806A/J0P0J71/801TK6PX06Q`I100K7AX301`N6`P07QhL0`0N7aT301lP6PD0824K0P0Q8Q`3028S
7@0302<T700R8a/0824I00807b0H00<0824I028S6`0S91`0200Q8QX3028S7@808B8L0`0P8A/00`0R
8ad08B8L01lP6P0201hO6@0301lP6P0Q8Q`08R<M00808b8M1P0R8A`3020Q6`0301lP6P0N7aT07QlI
00807AhH200O7ad301hN70<07AdK0P0L71X301`N6`806adJ0`0J71T801`L6Q007AdK0P0N7Q`601lO
7@P07QhL0P0N81d201dO708071hK3@0K7AX201`N6`807AlL100N81d201dO708071hK0P0K7AX01@0J
71T07AlL020R7`0P8Ql07AlL008071hK00<07R0M01/M6P0K7AX03P0K7AX801XL6`P06A/J0`0I6aP3
01XL6@806adJ0P0L7aP201dP6@807R4J0P0O8Q/8020Q6`P08B8J0`0P8A/201lP6P/0824K0P0Q8Al3
020P7P<07alM200L7Q/801hP7@807QlI1P0O81X301`N6`806adJ0`0J71T901`N6`807alM0P0N7Q`2
01dM6`8071`J00<071hK01dO700M7a`00P0N81d301lQ7P0801dN600N7aT0824K024R700R8ad08B8L
020Q6`0O81X401dM6`@07QhL0P0M7a`601`N6`P07AdK100L7Q/401dO70P06adJ200M7a`301/M6R_o
oooo000Zooooo`80X7Lo00@0X7M10:1g@`2PMd<0X7I40P2PMTH00`2QMdD0XgU70:AjB0020:EkB@03
0:AjB02SNDL0XGM500P0X7I4102TNDH40:EjA`80YG]90P2TNTP0102SNDL0Y7Y80:AjB02TNTP80:Il
BPP0YGa81P2WO4T20:IkB0P0Z7m92@2YOT/20:QoB`<0ZH1<0`2ZPDd80:V0C080ZH1800@0ZX5;0:Z1
C@2[PTh0Zh5?0P2/PU880:V0C080[8=?0P2[PTh20:Z1C@80ZH1<102ZPD/40:^2C0P0ZhIB202^QE48
0:Z5D080ZHA@00<0ZXEA0:^6DP2/Qe<00P2]R5@02@2^RED0[XAB0:n5D`2`Qe<0/8MA0:j5C@2/Q4T0
ZX970:V1A0020:^2C080ZX5;0P2YP4X20:QoB@040:ElB02TNdL0Y7]70:AkA`80XgY60P2RNDD00`2L
Md<0WGQ409ehA00209ag@`80VgI200D0VWE109Mc?`2FLSh0UG4m09A`?00209=_>`80TVhj00@0Tfdn
099/?@2AJc`0T6Xk102?JCX02@2?ISP0T6Li08iX>@2=JCT0RfLg08MU=@23Hc80PV8a08ES=@0208AR
=00:08=Q<`21Gc40P5h`081N<01oGBl0OUl`07iO<@1lGBl0Ne``07UI<080MeL`00@0MUH`07EE;`1f
ERl0MUH_0P1eEBh407AD;@@0LE@/0P1`Db/206mB:PP0K4hZ0P1]CBH206i>9`0=06m?:01`D2T0LE4Z
075A:P1/DBH0Ke@Y07=F;01hF2l0NUT`07YG;`1hEBd0N58[07]F;00207aG;@0507eH;P1oFS00P5/a
081K<@21G3800P1oFRd01P21G2l0PUd`08AO<P26HC@0Qf8e08QS=P80R6@b00<0Qf<a08IR<025HBl0
0P24H2h01@23Gbd0QV8b08IR<P26HS80Qf<c0080R6@d0P29ICD308US=P80R68e0`27HC@208QR=@80
Qf4d0`26H3<01027HC@0PV0b089P<P22H38308=Q<`80Q68d0P20GS001P1oGBl0OU`^07mM;`20GS00
PV0b08AR=0P0OUdb201oG3801`21GS@0Oe`b07aI;`1jEbd0NEH/07]H;P1mFS000`1nFc4207eJ<080
O5T_0P1kF2h207YG;@0307]H;P1mFS00OEX`00<0OU/a0`1kF30207YG;`@0NEH^00P0MED_07IF<01g
Ec00N5P_07UJ;P1jFbd0Ne`^07aM;PP0N5P_0P1dEbl207=F;P80LUD]0P1aE2`206iA;`0>06e@;P1/
Cbd0Jdh/06Y=:`1YC2X0J4/Y06Y<9P1YBbL0IdXX06=99P1PB2H0GDHV05a59P1IA2D205Y5:00605Y7
:@1HAbT0ETDW05=49@1?@R80CT4Q0`1;?bD404Xn90<0BCdS2018?2801019?B<0BclU04a09P1>@RP2
04m3:@P0BShT0P18?B402@17>b40Ac/S04Hj9016>BH0ACPU04Dh9`0o=b00@3PQ044i8P02048j8`03
040h8@0n=Ql0?CDN0080@SLQ00H0?cLR03hg900l=b<0>CHS03Pe900g=R@203@^8P03034]8@0_;B00
;2dO0080:R`N00@0:2`M02`^8`0[;B80:B/P0P0W:Ah00`0X:Ql0:B/P02X/8@0802PZ7`<09BPO0P0T
9ah302<V7@06020S6P0Q91/08B@K028U700S9Qd092LN0P0U:1l402<T70D092DM0P0P9Q`0100R9A`0
8b@L02<T700T91`202HS70808B@K0`0R9A`302<V7A009bTN200V:1d302DW70809RPM0`0W:Ah01@0X
:Ql09bTN02LY7P0V:1d09BLL008092HK00H08bDJ02HX7@0W:Ah0:2XO02LY7P0X:Ql202X/8@0302T[
800Y:Q`0:BXL00H0:BXL0`0[;1`302`]7@80;BhN1@0_;Q`0200`;ad0<C0N034`7P0b;AT0=2lK03Lb
7P0i=200>cHR0P0l=b<00`0k=R80?3PO03`h7`0203di80<0?SXQ00L0?c/R03lg8010>240@3PQ044i
8P12>R<0@c/T0080A3`U00<0Ac`P04Pm8@18?B400P18?B4304Tn8P80BcdP0P1<?R401@1=?b80CT0S
04i08`1>@2<0CC`R0080C3`R00<0BS`Q04Pm8@17?R400P14?B0204`n8`80BcdR0P1:?24204Tk80<0
Ac`P0`16>al204Dj7P80Ac/Q0`16>R0204Di7`80A3PN0`16>al00`17?200B3dQ04Pm8@0204Tn8P08
04Tm8`1:?R@0Ac/Q04@h7P17>b40C40V04Xn9012=Q`304Hm8080AchQ0`18?b8204hn9080CclU00@0
D40V05519`1B@RP0DT8X201:?b<01016?B00AchQ04Ln8@17?R4304Po8P0404U08`13?1l0@c`O04<l
7`@0@S/N00@0@CXM04Ho8`15?R80@c`P0P11>Qh01P12>al0@c`P04@m8@17?B80AS`Q04@j7`80@cTN
00<0A3XO04Hl8@17?B800`17?B8204Hl8@<0AC/P0P13?203048k7`<0@CXN0`0o>b02040l8@<0@CdR
0P12>b4204<l8P80A3dS0P15?R@01012>R<0@c/T04<k9014?2D204Dm9P80AShW0P0m>b@00`0l>R<0
>cTR03Xh8@0203Tg800403Pf7`0c=B00<cDP03<e80<0<S@O0P0a<ah302ha8080;C0O0`0/;ah202T/
6`0402PZ700W:A`09bTN02HW7`809BHP100S9Qd3028U70808B@K00<07RDM01dT700M91`00P0M91`3
01`S6`<07R4J0`0M81T201`O60<06R0L0P0I7a/301PN6P806adJ0`0J71T301TK60806Q`K0P0I6aX2
01PJ6@805aTH200I6aX801LI60P05QPG200F5aT801HH5`P05QLI200B61P801DF600301@E5`0E5QP0
5QLI00805QLI00<051DG018C5@0A4Q@0200E5QP801DG5QT05AHH200F5aT801DF600@01TJ700J6ad0
6Q/M01LH6P0E5QP061TK01lP8P0V9bT092HU01LI600A4a8061XI01/M700E5aH04Q@C01DG5PP05AHH
400F5aT@01DF60P04QPHD@0E5QP801HG6@P05AHH200F5aT301DF60805QLI0`0G61X801HG6@P05aTH
00<06A/J01PJ6@0G6AP00P0E5aH00`0G6AP061XI01TK6P0X01LI608061XI1P0G6AP801TK6P805aTH
0P0H6QT201TK6P806Q`K200I6aX;01XL6@@06adJ0P0L7Q/801dM6`807AhH0`0N7aT301lP6P<0824K
0P0Q8Q`3028S7@0302<T700R8a/0824I00807b0H00<0824I028S6`0S91`0200Q8QX3028S7@808B8L
0`0P8A/00`0Q8Q`0824K01lP6P0201hO6@0301lP6P0P8A/08B8L00808B0K1P0R8A`301lP6P@07QlI
00<07AhH01hN700N7Q`02@0N7Q`301dM6`8071`J0`0L7Q/201/M6P<06Q`I200L71X@01dM6`807alM
1P0N7Q`801dM6`<07AlL0P0L7Q/?01/M6P8071hK1P0M7a`201`N6`<06adJ00P061XG01hP7@0S9B80
8R@Q01hP7@0K7AX071hK01lQ7Q006adJ200J71/801TK6P<06A/H0`0J71T201/M6P@07B0I100N8AX8
020Q6`P08B8J00<07b0J020Q6`0P8A/0100P8A/00`0O81X0824K020Q6`06020Q6`808B4O0`0P81h3
01lO7@P071hK200N81d201lP6PH07QlI0`0L7Q/201/M6P<06Q`I2@0L7Q/301hN70807AdK0`0L71X3
01`N6`807AlL0P0N81d02@0O8Ah07AhH01hO6@0P8A/08B8L028S7@0Q8Q`0824K01lP6P0801dM6`H0
71hK0P0M7a`801dM6`P071hK200K7AX801`N6`<06adJ:oooool002[ooooo0P2PMcl0102PMd40X7M3
0:1g@`2PMT@20:1fAP030:5gA@2SNDL0Y7Y80080YG]900<0Y7Y80:=iA`2QMdD0202PMT@40:AiAP@0
YGY70P2UNdT20:AjB0040:=iA`2TNTP0Y7Y80:AjB0P0YWa:202UO4P60:MlB@80YW]8202XOdT90:Un
B`80Z7m;0`2YP4`30:Z1C@P0ZH1<0P2YP4P0102ZPD/0ZX5=0:^2CP2[PDl20:b2DPP0ZH1<0P2/Pdl2
0:^2CP80ZX5=0P2YP4`40:Z1B`@0Zh9<202[QU880:j5D@P0ZXE@0P2YQ5000`2ZQE40ZhIB0:b7D`02
0:f8E0090:j9E@2^Q580[hEC0;27D`2`Qe40[XE=0:b4B@2ZPTL0ZH540080Zh9<0P2ZPD/20:V0BP80
Z7m900@0YGa80:AkA`2TNdL0Y7]70P2SNTH20:9iA@0309ag@`2MN4@0WGQ40080W7M30P2KMT801@2J
MD40Ug<o09Ib?P2ELCd0U70l0080Tflk0P2BKSX0102CKCh0TV`m095[?02@JS/408mY>P0908mV>02@
IcT0SVPi08eY>@2;IcL0QfDe08=S<P22HS40QF<e0080Q68d00X0Pf4c085O<@20GS00P5h`07mM;`1n
Gc00OUla07aM;`1kG300NET`0P1gEc00101fES00MED_07IF;`1fERl207EE;P@0M5@]101aE2`2071C
:`80Ke8Z201/CRX206e=9P80KThW00d0KdlX071@:@1aDBX0LE4Z06aA9P1_E2T0LeH/07QH;`1jFC00
NUL_07QE;@1hDR/0NeH/0080O5L]00D0OEP^07mJ<020Fc40P5/a085L<P0207mJ;@06085L;`22GC00
Q5lb08IQ=027HSD0R6<f0P28I3800`27Hc40QV8`08EQ;`0208AP;P0508=O;@26HS80QV8b08IR<P27
Hc<00P28I3@208UU=@<0RF<f0P28HSD308MQ=080R68e0P27HC@308IP<`0408MQ=022H380PV0b089P
<P<0Pf4c0P24HS@2081N<00607mM;`1nG2h0Oed_081N<022H380Q68d201nGC8807mL<P07085N=01o
G380O5T_07YG;@1iER`0NeP^07eJ<00307iK<@80OEX`0P1lFBl207]H;P80NUL]00<0NeP^07eJ<01m
FS000`1nFc4307]H<080NUL_101iERh0201eEBl0MUH`07MG<01hF2l0NEX^07YK;@1kG2h0O5d^201h
F2l207AG;`80LeH^0P1bEBd2075D;080KU4_00h0KE0^06a?;@1[CR`0JTd[06U<:P1XBbT0JT`V06U;
9`1WBRP0HdTV06189P1MARH0G4DV05U49@80FTDX00H0FTLY05Q7:@1FABL0Dd@U04m28P1>@B4304/o
9@@0BShT0`19?B<804Pl8P0404Tm8`1;?bD0C40V04i2:080Cd<Y201:?R@204Pm8@0904Lk8@17>b<0
ASXT04Hi9P15>2D0ACPW03lg8010>240@CTR0080@SXS00<0@3PQ03hf7`0m=Ah00P12=b401P0o=b80
?SLT03`g8`0i=R<0>3DT03Lf9080=2hR00<0<BdQ02l]800/;Al00P0Z;1h0100X;1d0;2hS02/]8P0Y
:b0202LY7P0302PZ7`0Y:b00:R`Q00P0:2XO0`0U:1l202@W7P<08bHM00H082<J024T6`0Q91/08RDL
02<V7@0T9ah202DX7`@08b@L1@0T9Ad2020V7004028U700S91`08b@L02@T70809R<L0P0Q91/3028U
70<08bHM400W:Ah802HX7@<09BLL0P0V:1d302LY7P0502PZ7`0W:Ah09bTN02HX7@0U9a`00P0T9Q/0
1P0S9AX09RPM02LY7P0X:Ql09bTN02PZ7`80:R`Q00<0:B/P02TZ700Y:Q`01P0Y:Q`302//70<0;2dM
0P0];Qh502l^7008030_7@0a<1h0<C0N038]6@0d;a/0=c8N03Td800k=R8203`g8`0303/f8P0l>1l0
?3PO0080?CTP0`0n>R401`0o>b80?cLP040h8@10>240@CTR048j8`13>b@00P14?2D00`17?200B3dQ
04Pm8@0204Pm8@<0BChR0P1;?B0204`n8@0504do8P1>@2<0CT0S04i08`1=?2800P1<?2800`1:?240
B3dQ04Ln8@0204@m8080C3hS0P1;?B8204Xl8@80BC/P0`17?20304Hk7`80ACXN0P17>b4304Hj8080
ACTO0P14>1h304Hk7`0304Ll8018?B40B3dQ0080BChR00P0BCdS04Xn9017>b40A3PN04Lk8@1<@2H0
BShT048f70<0ASdP0P17?R4304Po8P80CShT0P1??bD0101@@2H0DD4W0592:01B@RP804Xo8`0404Hm
8017?R40AchQ04Ln8@<0B3lR00@0BD0S04<l7`13?1l0@c`O1012>ah01011>Qd0ASlS04Dn8P13?202
044j7P06048k7`13?200A3dQ04Lm8P16?240A3XO0P13>Ah00`14>Ql0AS`Q04Lm8P0304Lm8P80AS`Q
0`15>b0204<l80<0@S/O0`11>Qh303lk8080@3`Q0`11?B82048k8@80@c`R0P14?B<204Dn9004048j
8`13>b@0@c/T04@l9@80ACdV0P16?RL203dk900303`j8`0k>B80>SPQ0080>CLP00@0>3HO03<e800c
=B00<cDP0`0b=1l2034c7P<0;S4P0P0]<1l302`_7P80:B`K00@0:2XL02LY700W:Ah09RLO0P0U9R04
02<V7@<08RDL0P0Q91/00`0N9Ad07B@L01dT700201dT70<072<K0`0N8AX301dP6@8071lH0`0J81`2
01TO6`<061hJ0P0K7AX301XL6@<06A/H0P0J71/201TK6P8061XI0P0G6AP801TK6PP05aTH200F61L8
01HG6@P05QPG200F5aT8018H60P05AHH00<051DG01DF600F5aT00P0F5aT00`0D5AL04Q<E014B5008
01DF60P05ALF6@0E5QP801HG6@P05AHH01006AXL01XK7@0J6ad05aPJ01DF600H6A/07b0R02HW:@0T
9RD05aTH014C4P0H6QT06adL01DG5P0B51<05ALF200E5QP@01HG6A005AHH200B61QA01DF60P05QLI
200E5QP801HG6@<05AHH0P0F5aT301LH6PP05QLI200G6AP00`0I6aX061XI01LI600201DG5P0301LI
600H6QT06A/J02P05aTH0P0H6QT601LI60P06A/J0P0G6AP201PJ6@806A/J0P0J71/801TK6P/06Q`I
100K7AX201`N6`P07AdK0P0M7QP301hO6@<07b0J0`0P8A/2024R70<08R<M00<08b@L028S6`0P8AT0
0P0O81P00`0P8AT08R<K02<T7008024R6P<08R<M0P0Q8Q`3020Q6`03024R700P8A/07b0J00807QlI
00<07b0J020Q6`0Q8Q`00P0Q81/6028Q70<07b0J100N7aT00`0M7QP07QhL01hN700901hN70<07AdK
0P0L71X301`N6`806adJ0`0J71T801`L6Q007AdK0P0O7ad601hN70P07AdK0`0M7a`201`N6`l06adJ
0P0L7Q/601dO708071hK0`0K7AX0200H6QL07R0M02<U8P0R92407R0M01/M6P0L7Q/07b4N400K7AX8
01XL6`P06A/J0`0I6aP301XL6@806adJ100M81T401hQ6PP0824K200Q8QX00`0O81X0824K020Q6`04
020Q6`0301lP6P0P8A/0824K00H0824K0P0Q8Al3020P7P<07alM200L7Q/801hP7@807b0J1P0N7aT3
01`N6`806adJ0`0J71T901`N6`<07QhL0P0M7A/301`L6P<071hK0P0M7a`201hP7@0901lQ7P0M7QP0
7QlI020Q6`0Q8Q`08R<M024R700P8A/07b0J00P07AdK1P0L7Q/201dO70P07AdK200L7Q/801/M6PP0
71hK0`0K7AX[ooooo`00:_ooool20:1g?`040:9i@`2RNDD0XWU50:9hAP80X7I600<0XWQ60:=iA`2T
NTP00P2UNdT00`2TNTP0XgU70:9hAP080:5gA@@0XgQ5102TNDH0102VO4X0YG]90:AjB02SNDL20:9h
AP030:=iA`2TNTP0Yg]:00L0Yg]:202UO4P30:QmBP<0Yga90P2VNdP80:QoB`T0ZGi;0P2XOd/30:V0
C0<0ZX5=202YP4`20:V0B0040:Z1B`2ZPDd0Zh9>0:^1C`80[89B202YP4`20:b3C`80Zh9>0P2ZPDd2
0:V0C0040:V0BP2ZPD/0ZX5;0:Z1B`<0Zh9<00<0[8==0:^6DP2[QU801P2[QU880:j5D@80ZhIA102Y
Q4l20:^6D@80ZXEA0`2[QU830:b7D`080:n5D`2`QU@0/8MC0;27D@2_QTh0[8A90:Z2A`2XP4<30:^2
C080ZX5;0`2YP4X0102VODT0YGa80:ElB02UO4P20:AkA`80XgY600`0WGQ409iiA@2NNDD0WgY609ii
A@2MN4@0W7M309]f@P2IMD40V7A009Ib?P2DL3`209=_>`80U70l00<0U6ho09=]?P2AJc`00`2@JS/2
095[?080T6Li00H0SfTj08iZ>P2<J3P0R6Hf08AT<`23Hc8208IT=P0708ES=@24HS@0PV0b085O<@20
GS00Oed_07iO<00207eN<00607]L<01jFS40NETb07UI<P1hF380MeLa0P1gEc0207IF;`<0MED^00@0
M5@]071C:`1`Db/0L5<[0`1_DRX206iA:@80KDl[101[CBT206e?:`<0KDdV0P1^CRL306m?:00806aA
9P1^DbP0LUD[07IF;@1hEbh0NEH^07MD;01hDR/207YE:`0<07]F;01lEbd0OUT_07mJ<020Fc40PE`b
07mJ;@20Fbh0PE`_089M<023GS40QF0c0P26HC@208MS;`80QV8^00@0QF4]08AP;024H2`0Pel[0P25
HC400`26HS80Qf<c08QT=00208UU=@0308YV=P29HcH0RF<f0080R68e0`27HC@01026H3<0R68e08QR
=@27HC@308IP<`0308MQ=028HSD0PV0b0080PV0b0`23HC<208AR=008081N<01oGBl0OU`^07iL;P1o
GBl0PEla08=Q<`24HS@3081M<`80Oe`b0`1nFc42081M<`@0OU/a0P20GC<0101oG380OU/a07eJ<01l
FBl207]H;P0407aI;`1mFS00OU/a07iK<@80OEX`0P1lFBl207]H;P0307YG;@1kF2h0O5T_00<0OU/a
00<0OEX`07aI;`1kF3000P1kF30207YG;`@0NEH^00D0MeLa07QH<P1hF340NET`07YK;`0207]L;P03
07aM;P1iFC00NET`00H0NET`0`1dEbl207=F;P<0LUD]0`1_DS001@1^DBl0KE0^06]>;01YC2X0J4/Y
0080KDdW00@0JD/W06M::01SBBH0H4PV0P1MARH0201IA2L0FTDX05U6:01GARP0ETDW0593901?@R80
CD0P201;?bD304Xn90<0BCdS0P18?28204Lk8@0404Pl8P19?B<0BclU04a09P80CD4W0`1<@2H00`1;
?bD0BShT04Xn900204Tm8`80B3dQ00<0B3`R04Lk8`17>bD00P16>BH02@16>BP0@3TO044j8012>b40
@c`R048k8@11>R00?cPN03hg7@0204<g8@06044f8P0n=R<0?3DR03Xe8P0h=B@0=c@S0P0f;R402@0d
;R00<RlP030^7`0];Qh0;2dM02/^7@0];b@0;2hS02X/8@0302PZ7`80:R`Q200X:Ql0100V:B009BPO
02DX7`0U:1l202@W7P808bHM0P0R9A`302<V7@<092LN00@08R<K02<T700S91`08b@L0`0T9Ad202DV
7P8082HL00@08RDL02<T700S91`092@L0P0V8a`3024T7@808RDN0`0S9Ql0100U9a`09RPM02HX7@0V
:1d302LY7P0302PZ7`0W:Ah09bTN00H09bTN200V:1d302DW70809RPM1`0W:Ah402HX7@0802@U7@0Y
:R80:R/S02LX800X:B40;RlW02l`:00[;2@802TZ70<0:B/M0P0Z;1h302/]7`80;BhN00X0;2dM02//
700[;1`0;2dM02d^7P0^;al0;b`I034^6`0c<1d0=C8O0P0g=24203Hc800403Le7P0h=Ql0>3HO03Pf
7`80>CLP0P0j>24203de800403hf8@0o=b80@3PS040h8`80@CTT2014>R401P15>Qh0AS/O04Hk7`17
?200B3dQ04Tn8P80BSlS00H0C3XR04/k8P1;>b80BC/Q04Lk8@15>b0204<l8080BCdS0`18?28304Lk
8@<0AS`Q0P15>b0304@j7`@0Ac/Q0P16>R0304Di7`80ACXN0P16>al01P17?200B3dQ04Tn8P19?R80
BclU04Pl8P80ASXP00D0BCdS04/o9@18?280A3PN04Hm800304Ln8@80B3lR0P19@2<405109P<0DD4W
00<0DT8X04Po8P18?b801P18?b8804Ln8@0304<l8012>al0@S/O00D0@S/O00<0ASlS04@m8@13?200
0`11>Qh01@12>al0@c`P04Hl8@15>b00A3XO0080@cTN00<0A3XO04Dk8016?2400`16?24204Dk80<0
A3XO00@0@c`P048k7`12>al0@S/O0P11>Qh2040i7@<0?c/P0P10?243044m8P<0@c`R0P14?B<304Dn
90P0A3`W00H0?3XS03/i8P0k>B80>SPQ03Tg800h=Ql203Le7P<0<cDP0`0b=1l2034c7P<0;BlQ0P0/
;R0302/]7`80:B`K00H0:2XL02LY700V:1d09BHN02DV800T9Al402<V7@808RDL0`0Q91/801`S6`<0
7R4J0P0M81T301`O60806R0L0P0I7a/301PN6P0301LM6@0K7AX06adJ00<06Q`I0`0I6aP201XL6`80
6A/J0P0H6QT201LI60P06A/J200G6AP801HH5`P05QLI200F61L801HG6@P04QPH200E5QP0200D5AL0
5AHH01DF600E5QP04a@F014B500>3a4030d?200E5QP801DG5QT05AHH200F5aT801DF600@014B500C
51H05AHH01HG6@0H6A/0824S02`];`0e=SP0<38a01`N7@0A4a8061XI01`N7@0D5QD04Q@C01PJ6@P0
5AHH400F5aT@01DF60P04QPHB@0E5QP801@E5`P05QLI200E5QP801HG6@<05AHH0P0F5aT301LH6PP0
5QLI200G6AP00`0I6aX061XI01LI600201DG5P0301LI600H6QT06A/J02P05aTH0`0H6QT301LI6080
5QPG200I6aX201LI608061XI0P0I6aX201XL6`P06A/J200J71T201TK60806Q`I100K7AX00`0L7Q/0
7AdK01dM6`0601dM6`<07AhH0P0N7aT301lP6P<0824K0P0Q8Q`3028S7@0302<T700R8a/0824I0080
7b0H00<0824I028S6`0S91`0200P8AT3028S7@808B8L0`0P8A/00`0Q8Q`0824K01hO6@0201dN6003
01hO6@0P8A/08B8L008081lJ0P0Q81/4028Q70P07QlI2`0N7Q`301dM6`8071`J0`0L7Q/201/M6P<0
6Q`I600M7A/201lO7@<07QhL2`0M7A/201dO708071hK0`0K7AX00`0J71T06adJ01/M6P0701/M6P04
01XL6@0K7AX06adJ01/M6P8071hK100M7a`201`N6`<06adJ00T06Q`I01LI5P0N81d09BLT02@V8`0N
81d06Q`I01`N6`0P8Ql0200J71T801/M6Q006A/J0`0I6aP301XL6@806adJ100M81T401hQ6PP0824K
200Q8QX00`0N7aT07b0J020Q6`02024R7003020Q6`0O81X07QlI00P0824K0P0Q8Al3020P7P<07alM
200L7Q/801hP7@807b0J0`0N7aT301dN60<071hK0P0K7AX301XL6@T071hK0P0N7Q`201dM6`<071`J
01806a/I01dO700L7Q/071hK01/M6P0L7Q/07AlL01hP7@0O8Ah07AhH01hO6@0P8A/08B8L028S7@0Q
8Q`0824K01lP6P0N7Q`301dM6`<071`J00<06a/I01/M6P0K7AX00`0L7Q/301dO70P07AdK00@07AlL
01`N6`0L7Q/071hK0`0K7AX0100J71T071hK01`N6`0L7Q/201/M6P<06Q`I200L7Q/301XL6B_ooooo
000Zooooo`030:5h@02RND40XgY40080Y7]700H0XgU70:9hB02QMdL0XWQ60:=iA`2UNdT20:IlBP03
0:EkB@2SNDL0XWQ600P0XgU7202RMd@0102WOD/0YG]90:=iA`2RN4H20:5gA@80XgU7202YNdX80:Ak
A`80ZGi;0P2XODX20:MlB@80YW]8202XOT`90:UnB`80Z7m;0`2YP4`30:Z1C@P0ZH1<0P2YP4P0102Z
PD/0ZX5=0:^2CP2[PDl20:b2DPP0ZH1<0P2/Pdl20:^2CP80ZX5=0P2YP4`20:V0BP80ZX5;0P2[PT`2
0:b3C@P0ZhIB202]Q5000`2/Qe80ZhIA0:V4C`020:R3CP030:V4C`2[QU40[8MB00<0[8MC0`2[QU82
0:Z5D@080;26E02aQeD0/HQD0;68DP2_QTh0[8A90:Z2A`2XP4<40:^2C080ZX5;0P2YP4X30:ImB@80
YGa80`2TNdL00`2MN4@0WWU50:1kA`020:1kA`0909iiA@2LMd<0VgI209Yf@P2IMD40UW8n09A`?02C
Kc/0U70l0080UG4m00<0UFm009=]?P2AJc`00P2@JS/00`2AJc`0TV`m09=]?P02095X>P0C091Z>`2>
JSX0SFTi08QV=P25IC@0Pf<b08QV>027ICL0QV@f08AR=023HC<0PEla081N<01oGBl0OEh_07eN<01l
GBl0O5da07]K<P0207YJ<`80NUXd00@0N5Pa07MG<01gEc00MeL`0P1fERl207EE;P80Ke8Z0`1^DBT3
06e@:00306i@;01]Cb/0JddY0080JT`X00@0JddY06e?:`1^D2`0K4`U101]CBH306i>9`0506eB9`1^
DbP0L5<Y07AD:`1fEB`00P1gE2`02@1iDb`0N5<Y07UD:P1jEB/0O5L]07eH;P1oFS00P5/a085L<P02
085L;`80PUd`0P23GS4208AO<P80QV8^1025HBd208AP;00608AP<025HC40QV8b08MS<`28I3@0RFDe
0P2:ISH308QR=@<0Qf4d0P26H3<00`28HSD0Qf4d08IP<`0208EO<P0308IP<`28HSD0RF<f00<0PV0b
0`23HC<208AR=080Oed_0P1nG2h01@1oGBl0PEla08=Q<`25HcD0PEhd0080P5dc0P1oG38207iK<@04
07eJ<021GS@0P5dc07iK<@80OEX`00D0OU/a081M<`21GS@0O5T_07eJ<00207iK<@0407eJ<01lFBl0
NeP^07YG;@80OU/a0P1mFS0207aI;`80NeP^00P0O5T_07eJ<01nFc40Oe`b07iK<@1mFS00NeP^07YG
;@<0NeP`0P1jEbl407UF;P80NUXd00<0NUXc07YJ<@1jFbl00P1jFbd00`1jFb`0NET`07UI<00607UI
<0@0M5L_0P1cERh2079E;@0H06mB<01`Dc40L5<a071C<@1^DBl0K4l]06U<:P1WBRP0KddW06i>9`1/
C2H0JD/W06I99`1RB2L0GdLU05m69`1H@bH0FD@W05Q59`1FABL0E4<U05528`1=@200C3lO201;?bD3
04a09P0304/o9@1:?R@0BShT0080BCdS00@0ASXP04Lk8@17>b40B3`R0P19?B<204Xn9080CT8X00@0
CD4W04a09P1:?R@0BCdS0P18?28204Pm8@0D04Pl8P18?2@0Ac/U04Lj9`16>BH0ASTX044j8012>b40
@c`R04@m8`13?280@S/Q040i7`0o>1h0A3DP048f8011=240@3DS03de8P0k=28203Tc8`0603T`8@0g
<200=RlO03D_7`0b;ah0<2lM0P0];Q`00`0^<2D0;2hS02/]8P0302T[800302X/8@0[;B80:2XO00L0
:2XO0P0V:B0302DX7`L092LN100S9Qd2028S6`808b@L0P0T9Ad302DV7P807bDK00@08B@K028S6`0R
8a/08b<K0P0U8Q/2020R7@808B<N0`0R91l01@0S9B009BLL02DW700U9a`09RPM00809bTN0P0X:Ql@
02HX7@<09BLL0P0V:1d602LY7P80:2XO0`0Y:b00200R8ad0:R/U02//9P0W:280:BXT038c;@0d=Bl0
;RlY200Z:ad302P/7P80:BdO0`0Z;R000`0^;al0;BhN02//700202X[6`0<02//700/;Ad0;BhN02h]
6`0`;ad0<S4O03<b800d<b40<c8P038a7`0a<1h0=3@L0`0e=Ad203Hf7P80=cLO0P0l=1l403de8080
?SHQ1P10>2<203lg8P06048g6`13>1`0A3TM04Dj7P16>al0Ac`P0P18?B401P1<>R@0Bc/T04/k9019
>R<0Ac/S04Dk8P80@c`R0`19?BD204Pl90<0Ac/S00@0AChT04@m8`14?B<0A3dS0P13?282048k8@@0
B3`R0`17>b4204Hj8080A3TM00@0ACXN04Hk7`17?200B3dQ0P19?R80101<@2H0Ac/Q04Di7`18?282
04/o9@0304Tm8`17>b40B3lR00<0B3lR0P19@2<204Y19080CclU0`1>?R@304dm8`P0AChQ0P19@2<0
0`18?b80AchQ04Hm800304Dl7`H0@S`R0P13?B<02`15?R80A3dQ048k7`11>Qh0@3TM044j7P12>al0
@c`P04Hl8@15>b00@cTN0080@SPM00@0@cTN04Dk8016?240AS`Q0`15>b0204@j7`80@cTN0`12>al2
044j7P<0@3TM0`0o>b02040l8@<0@CdR0P13?28204@m8`@0AChT0P16?RT01015?BP0A3`W04<k9P12
>RD2044i900603/i8P0j>240>SPQ03Tg800h=Ql0=cDN0P0f=1d303<e80<0<S@O0P0a<ah0100];b80
;2hQ02`^8@0/;R4202/]8080:R`O00H0:B`K02P[6P0X:Q`09bTL02HX7@0U9Qh202@U7`0302<V7@0R
9A`08RDL00808RDL0P0Q91/2020S6PP072<K00@07R4J01dP6@0M81T07B0I0P0L7aP201/N5`<06AlK
0`0H7QX201LM6@806adJ0`0J71T301TK60806Q`K0P0I6aX201PJ6@805aTH200I6aX801LI60P05QPG
200F5aT801HH5`P05QLI200B61P801DF600301@E5`0E5QP05QLI00805QLI00<051DG01<D5P0A4Q@0
200E5QP801DG5PP05AHH8@0F5aT0400C51H051DG01@E5`0C51H05AHH01`M7`0Y:R`0<S<e03/m?00R
92<04Q@C01PJ6@0K7A`04aDD018D4`0K7A`801DF61005QLI400E5QP8018H64T05AHH200D5AL801HG
6@P05AHH200F5aT301DF60805QLI0`0G61X801HG6@P05aTH00<06A/J01PJ6@0G6AP00P0E5aH00`0G
6AP061XI01TK6P0H01HH5a005aTH0P0I6aX201PJ6@0401LI600F61L05QPG01HH5`P06A/J0P0G6AP2
01PJ6@806A/J0P0J71/801TK6PP06Q`I0`0I6aP301XL6@<06adJ200L71X201`M5`807AhH0`0N7aT0
100O81X0824K020Q6`0P8A/2024R70<08R<M00<08b@L028S6`0P8AT00P0O81P00`0P8AT08R<K02<T
7008020Q6@<08R<M0P0Q8Q`3020Q6`03024R700O81X07QlI00807AhH00@07QlI01lP6P0Q8Q`07ahI
0P0P7aX2024P6`808R4L00<08b8M01dN600M7QP00P0M7QP401hO6@P07AdK0`0N7Q`301dM6`8071`J
0`0L7Q/201/M6P<06Q`I600M7A/201lO7@807QhL0P0M7A/:01`L6P<071hK0`0K7AX201XL6@T06adJ
0P0J71T301/M6PH071hK0`0K7AX201XL6@0801DG500N81d09bTV02HX9@0O8Ah06A/H01`N6`0P8Ql8
01XL6@P06adJ400I6aX301TK60<06Q`I0P0K7AX401hQ6P@07B0I200P8A/8024R6P0301hO6@0O81X0
8B8L00808R<M00<08B8L01lP6P0N7aT0200P8A/2024Q7`<0820N0`0O7ad801`N6`P07R0M0P0O81X2
01hO6@807AhH0P0L7AL301`N6`806adJ0`0J71T901`N6`<07AdK0`0L71X201/K6@0@01dO700L7Q/0
6adJ01XL6@0K7AX071hK01hP7@0P8Ql07AhH01hO6@0P8A/08B8L028S7@0Q8Q`0824K01lP6P807QhL
0P0M7A/0100L71X06a/I01/K6@0K6aT301/M6P0301`N6`0M7a`07AlL00807R0M200M7A/201dO7080
71hK00D06adJ01XL6@0J71T06Q`I01dO700201`N6`806adJ0P0J71T00`0I6aP06adJ01/M6P0601/M
6P<06Q`I:oooool002[ooooo00<0XGQ00:=j@P2TNdD00P2VODT01P2TNTP0XgU90:5gA`2RN4H0XgU7
0:EkB@80YWa:00<0YG]90:=iA`2RN4H0202TNTP20:9gA0@0XGI30P2PMD80202WOD/0YWa:0:=iA`2Q
MdD0X7I40:5gA@2RN4H0XgU7202YNdX80:AkA`040:YoC02YOT/0ZGi;0:QmBP80Yga90P2VNdP80:Qn
C0T0ZGi;0P2XOd/30:V0C0<0ZX5=202YP4`20:V0B0040:Z1B`2ZPDd0Zh9>0:^1C`80[89B202YP4`2
0:b3C`80Zh9>0P2ZPDd20:V0C0<0ZH1:00<0ZX5;0:^2C02/Pdd00P2/Pdd80:^6DPP0[HA@00<0[8MB
0:^6D@2YQ4l00P2XPdh0102YQ4l0ZhIA0:b7DP2^RED20:f8E0030:b7D`2[QU80ZXEA0080ZHA@0P2a
QeD01`2aR5@0/HQB0:n6CP2]QDX0ZX970:R0@`2/Pdd00`2[PT`20:Z1B`80ZH1:00@0Ygi:0:ImB@2V
ODT0YWe90P2UO4P20:AkA`0309iiA@2ONTH0X7]70080XGa800h0WgY609ehA02KMT80VgM309Ue@@2G
Lcl0U70l09=_>`2DL3`0UG4m09Ib?P2EKd00U6ho099/?@80T6Xk00/0TF/l09=]?P2DKSl0TFPj099Y
>`2@JS/0Sf/k08eY>@29IcL0QFDd08AT<`0208QV>00408IT=P25HcD0Pf4c085O<@80P5h`00D0O5d^
07aM;`1lGBl0O5da07aL<`0207aL=@80O5`f0P1hF34207MG<0<0MUH_00<0MED^06iA:@1^DBT00P1]
D2P406a?9`0306i@;01]Cb/0JddY0080JT`X00<0JddY06e?:`1^D2`00P1/C2D606e=9P80KU<X00H0
Ke8X079B:@1dDbX0MU<[07MD;01jE2d207QC:@0407YE:`1kER`0OEP^07mJ<080P5/a2022GC0208AQ
:`H0QF8/00H0Q60`08EQ<@25HC40Qf<c08QT=029ICD208YV=P<0R68e0P27HC@308IP<`0308US=P27
HC@0QV0c0080QElb00<0QV0c08US=P2:I3L00`22H38308=Q<`80Q68d00P0Oed_07iL;P1nG2h0OU`^
07mM;`21Gc40Q68d08ES=@80Pehd00@0PUdc085L<P21G380P5/a0P1oFS000`21GS@0P5dc07iK<@02
07eJ<00;07iK<@20GC<0PEhd07]H;P1lFBl0OU/a081M<`1oG380OEX`07YG;@1hEB/00P1nFc4207eJ
<080O5T_0P1kF2h207eJ<080Oe`b00@0OU/a07aI;`1jEbd0N5D[0`1kF30207YG;`@0NEH^0P1kFcD0
0`1kFc@0Ne/b07YK;`0207YK;@0307UJ:`1iFC00NET`00H0NET`00@0MEP`07AG;`1dEbl0M5L_0P1c
ERh2079E;@80L5<a0P1aE380501_DS00K4l]06U<:P1WBRP0L4hX06m=9`1]CBL0JD/U06I:9@1RB2D0
HDLV05m79@1G@RD0F4<V05M49P1EA2H0Dd8T05118P1=@200BchN1@1;?bD304a09P0404i2:01=@BL0
CD4W04a09P80BclU0P1:?R@204Hj80@0Ac/Q0P18?2801P1@A2X0Cd<Y04i2:01<@2H0BShT04Tm8`80
Ac/Q01P0BChR04Pm8@18?280B3`T04Lk9@17>RL0ASTV04Hi:011>Qh0@S/O04<l8014?B40@c`P048k
7`10>Ad0?cPL04@e8013=1l0@C@Q03ld8P0l=240>S<Q03Tb8P0h<R8203T`8@0303L`800e;al0<RlN
0080<2lM00@0;BhL02h`9@0];b@0:bdR0P0Y:b000`0Z;240:bdR02`^8`0802PZ7`<09RTP0P0U:1l3
02@W7P809RTP00<09BPO02@W7P0S9Qd00P0R9A`01P0Q91/08R<K028S6`0R8a/08b@L02@U7@@09BHN
0P0O9A/0100Q91/08R<K028S6`0S8a/202DR6`80828M0P0Q8ah4028T7`8092HK00@09BLL02HX7@0V
:1d09bTN0P0X:Ql@02HX7@<09BLL0P0V:1d502LY7P0402PZ7`0Y:b00:B/P02X/8@80:bdR00P08B8L
02X[9@0/;BL09bPR02X[9@0e=S00=cPb034b;0P0:b`N0P0X;1h202T]7`<0:RhP00@0:blQ02d_8@0/
;R00:R`N0P0X:Q`02`0Y:ad0:bdO02`^800_;Q`0<2lM034`7P0b<Al0<c8P038a7`0`;ad0;bhL0080
<c8M0P0d<ah303Dd7`0303He800l=240?3@Q00H0?3@Q100o=b8403hf8@80@3HK00@0@CLL048h7@14
>Ql0AC/P0P16?2401P1<>R@0Bc/T04/k9019>R<0Ac/S04Dk8P80@c`R0`18?RD204Lm90<0AS`S0`15
?R@204@m8`<0@c`R1019?B<204Pl8P<0Ac/Q00H0@cPL04@i7@15>Qh0AS/O04Ll8018?B4204Tn8P06
04a09P17>b40ACTO04Tm8`1=@BL0C40V0P19?B<01018?b80BD0S04U08`19@2<204Y19080Bd8U00H0
CCdS04`l8P1<?280Bc/Q04Xj8019>Al204Ph7PP0AChQ00P0BT4T04U08`18?b80AchQ04Hm8015?1l0
A3/N04<j7@<0@CdR1012?R<01013?b@0AChR04@m8@12>al2040i7@06044j7P12>al0@c`P04Hl8@15
>b00@cTN0P12>1d00`13>Ah0AC/P04Hl8@0304Dk8080A3XO0`13>Ah2048k7`<0@CXN0`10>Ad303lk
8080@3`Q0`11?B8204<l8P80A3dS0`15?R@02@16?bD0Acl/04Lo;016?R/0A3`Y048j9`11>BH0@3PU
03lg900203Xh8@0303Tg800h=Ql0=cDN0080=S@M00@0=C<L03<e800c=B00<cDP0`0b=1l2034c7P<0
;2hQ0P0[;B0302X/7`80:2/J00@09bTK02LY700V:1d09BHN0P0T9Al5028U70808B@K0P0P8aX301/R
6PD072<K100M81T201`O60806ahG0`0I7a/201PN6P<05adI0P0K7AX301XL6@<06A/H0P0J71/201TK
6P8061XI0P0G6AP801TK6PP05aTH200F61L801HG6@P05QPG200F5aT8018H60P05AHH00@04a@F01@E
5`0G61X06AXL0P0J6ad00`0I6Q`061TK01DF600701DF60P05ALF200E5QPQ01HG6@0=01dN800K71h0
5aPJ018C5@0?41804a@F01`M7`0T9BL0@dE402DW9P0C5A@061XI01/M7002018D4`0301dO7P0E5QP0
5AHH00H05AHH400F5aT@01DF60P04QPHB@0E5QP801@E5`P05QLI200E5QP801HG6@<05AHH0P0F5aT3
01LH6PP05QLI200G6AP00`0I6aX061XI01LI600201DG5P0301LI600H6QT06A/J01P05QPG400G6AP2
01TK6P8061XI00@05aTH01HH5`0F61L05ALF200I6aX201LI608061XI0P0I6aX201XL6`P06A/J200J
71T301TK60@06Q`I0P0K7AX801`L6P8071dG0P0M7QP401hO6@<0824K0P0Q8Q`3028S7@0302<T700R
8a/0824I00807b0H00<0824I028S6`0S91`0200P8AT3028S7@808B8L100P8A/01`0O81X07QlI01dN
600M7QP07QlI01lP6P0P8A/00P0O7QT2020O6P04024P6`0R8A`08R4L02<R7@D07AhH0`0N7aT801dM
6`<07QhL0`0M7A/201`L6P<071hK0P0K7AX301XL6AP07AdK0P0O7ad201hN700401dM6`0L71X071`J
01/K6@P071`J0`0L7Q/201/M6P<06Q`I2@0K7AX301XL6@806adJ1P0L7Q/201/M6P<06Q`I00P05ALD
01hP7@0X:RL09bTV01lQ7P0I6aP071hK024S80P06Q`I200K7AX@01TK6P<06A/H0`0J71T201/M6P@0
7R4J100M81T8020Q6`P08B8J00<07QlI01lP6P0Q8Q`00P0R8ad00`0Q8Q`07b0J01hO6@08020Q6`80
8B4O0`0P81h301lO7@P071hK200N81d201lP6P807QlI00@07AhH01`M5`0L7AL06a`F0`0L7Q/201/M
6P<06Q`I2@0L7Q/301dM6`8071`J0`0K6aT00`0M7a`071hK01/M6P0201XL6@0;01`N6`0N81d0828O
01dN600N7aT0824K024R700R8ad08B8L020Q6`0O81X00P0N7Q`0100M7A/071`J01`L6P0K6aT201XJ
600401XL6@0K7AX06adJ01`N6`807AlL0P0N81d801dM6`807AlL00@071hK01/M6P0K7AX06Q`I0P0I
6aP201dO700401`N6`0K7AX06adJ01XL6@806A/H200K7AX301XL6B_ooooo000Zooooo`80XgQ50P2R
Md@30:5f@`030:1e@P2RNTT0XWY900<0XGU80`2PN4L0202QN4@0X7M309mf@P2OMT80X7M30:=jAP2V
ODT0Ygi:202QMT<80:9hAP80YGY70P2VNdP20:MlB@80Z7e:202VODT0402TNdL0YWe90:MnBP2XOd/0
ZH1<0:QoB`2VODT0YGa80:Z1B`2WOTP0Y7]50:ImA`2YP4X0ZX5;0:QoB@2UO4H20:IkAP80Yga70P2X
ODP20:UnB@030:YoBP2/PD`0[85<0080Zh1;00@0ZWm:0:UnB@2YOTT0Z7e8202YP4`02`2_PT/0[X5:
0:b1C02ZPDd0Z81<0:F0C02TOTd0Xgm=0:^0C@2ZOd`0Z7e:0080Yga900H0Z7e:0:YoC02[P4d0Zh9<
0:Z1B`2XOdT20:MnB00;0:QoB@2ZPD/0Zh9<0:MnB02XOdT0ZH1:0:Z1B`2[PT`0[8==0:f4CP2^QDl0
0`2YQ5020:Z5D@<0ZhIB202ZQE020:^6C`030:^6D@2[QU80ZhED0080ZhEF00T0ZhEH0:V3DP2[QE@0
[HMF0:j8E`2_REP0[XQG0:f7EP2/QUD00`2[QU420:Z5D0<0ZHA?0P2/PU020:^1C`<0ZX1>00<0ZGm=
0:MnAP2WOTH00P2VODD30:ElA0090:Ak@`2ONTD0X7]60:5lA`2RODP0XGa709iiA02LMd80VWE00080
VG@m00<0V7<n09Qc?`2GLD000P2FL4401@2FL4<0VGA009Qc?`2EL3`0Tfhj0080TVdi00@0U6lk09E`
?02AJc`0TV`m0P2CKCh0102AJc`0SfTj08aV=`2:I3D208QX>@0308MW>026ISL0QFDf0080Q6@e00H0
Pf<d085P;@20Gb`0OU`/07eK;@1mFbh207iK<@08081M<`21GSH0OF4j07aP>@1iGCH0MUXc07=G<01a
EBh2071D;@<0Ke8X0P1^DBL306e@9P80LU8[01H0LE4Z071@:@1_CbP0KThW06e=9P1/C2D0JU<Y06UB
:01WD2H0IDhT06A=8`1UCR@0Ie0V06QA9`1/D2/0KE4/06i@;01bDBh0M58_07IB<01gDc40NE8a0P1h
ERP01P1jF2X0O5X/07iL;P20GS00PV0b08=Q<`80OU/a0P1mFS00101nFc40P5dc089O=@23H3H4089Q
;P@0PF0]0P26HS000`26HS80Qf8e08MR=P0208QS>@0408QR>`24Gc80QF0c08MR=@<0RF@g0P27HSD0
0`28HcH0Qf8e08EP<`0308=N<@0508AO<P25H3<0PUd`08=N<@24Gc800P25H3<00`24Gc80Peha089M
<00307mO<080OUh_0`1mGBh0201kFBT0OE/[07mM;`21Gc80PEhd07mL=01mFS@0NePb2022GC<207mM
;@0407iL;P1nG2l0OU/a07eJ<P80OEXd0P1kF30207aI<@80OEXb0P1nFc<00`1kER`0O5L]07iI;`02
07mJ<00907iI;`1lEbd0NeH/07iK<`1mFS80NeP`07YG;`1iERh0NUL_0080NeP`00<0O5Ta07IF;@1f
ERd01`1fERd02P1iFC00O5`c07iN=@1mGC@0NUXa07MG;P1dE2/0MUH]07MG;P1hF2l207UI<00607MG
;P1eEB`0Le<Z06Y>9P1^DRX0M5P`0P1hG3@06`1dF300KU8Z06Y>9P1/DBH0K50X06]?9`1ZCRL0JDdX
06Q;:@1XBb/0IdXZ05i79@1NAbL0GDHV05a59P1K@bL0Fd<Y05Y2:P1I@BT0F3lQ05Q18P1I@BD0F4<X
05M3:P1C@BT0DD4Z0510:@0805109P08050m7`1@?240CSdQ04`l8P1;?B<0B3`T04Pl9P17?2H204Hl
8@80AcdR00@0B3hS04To9019?b@0BT0U0P1??BD00`1>?2@0CC/S04`j8P0204/i8@0:04Xh8018?R<0
B3hS04Lm8P16?240AC/P04@j7`13>Ah0@SPM04@m8@80@c`R00<0@CTR040h8`0o=b@00P0n=B@02@0i
<b<0>38R03La8@0e;al0<bdM038/700a:a/0<2XJ038^8`03034]8P80<2`Q0P0_:b0402`X7@@0;BTN
0`0U9A/502HV71408bHM0`0T9Ad302DV7P809RLO00H082<J024T6`0R9A`08bHM02@W7P0V:B0202LZ
8@P09BPO200S9Qd802L[700602@V600U9aT09BLI02LY6`0X:Q`0:B/M0P0Z;1h0100X:aX0:B`K02T/
6`0Y;1/202X]7080:bhM1@0Z;1h302T[7@0A03<a900a;b80;BhP02X/7P0Y:ad09b/L02H]7@0W;Qh0
9bTK02PZ700Y:ad0:R`N02/]7`0/;R00;BlQ02h`8P0];B400`0/;20302/[7`0302XZ7P0]<B80;C4R
0080;C4R100/<24803Td7P0603Lb700h<ad0>C@N03Xe7`0k=R00?3LQ0P0m>28303hg7@80?CHL0`0l
=A/00`0n=1/0?cDL044g7P0204<i8009044g7P0o=A`0?S@K03hd6@10=Q/0A3XO04Lm8P18?R<0BClT
0080B3hS00<0BcXP04`k8@1=?2800P1??R@00`1=?280C3/Q04/j800804/m8`80ACTO00P0ASXP04Pl
8P18?280B3`R04Hj8013=ad0@SHL03`k7@80?C`N00<0?chP040o8@11@2800P12@B<00`1=?bD0C3hT
04Xl8P0204Pj800604Xl8P1<?R@0CClU04M09015?R80A3dQ0P12>al00`14?B40AChR04M0900204`o
7`80BchN0`1:?Ad01019?1`0ASlU04Ho9@16?bD204Dn90<0A3dS0P14?B401013?200@S/O048k7`11
>Qh2040i7@P0@c`P2013>Ah01011>Qh0@S/O048k7`13?20204@m8@80AChR0P15?R@204Ho9@0404@m
8`12>b40@3TO03hg7@<0?SXO0`0o>b02040l8@80?SLM00<0?cPN040i7`11>R000P12>b401P13?280
BChR04Tn8P18?280B3`T04Pl9P80B3/X00T0B3/Z04@m:P13?2T0@S/X044j9`0o>2D0?CHS03`e8P0k
=2400`0d=Qh503Dg7`0803<f9@0b=B@0<C@S030c8P0^<B00;2lN02/^7@0Z;A`802T/8@0802L[700V
:Q`092PJ028U6P0R9A`08RDN02<U800T9R43028U7004024T6`0P8aX082<J01lR6@807R4H0P0R9Ah2
024T7@8082<L0P0O8Q/801`O60<071hK0P0K7AX301XL6@8061hL0`0G7A/301HL6P806Q`K0P0I6aX2
01PJ6@805aTH200I6aX801LI61005QLI200F61L801DF60P05QPG200F5aT801DF60805QLI0`0E5QP3
01@E5a005AHH4@0F5aT@01DF60P05QLI00P0;2d_02HW:@0M7R0051DG010A4`0?41804Q<E01@E5`P0
5AHH200F5aTH01DF60P04QPH@00E5QP901<I6@P051DG200E5QP801HH5aP05QLI200F61L301PJ6@<0
5aTH0P0F61L301LI60805QPG0`0E5aH801HH5a005aTH0P0F61L301LI60<061XI200I6aX0100E5aH0
5QPG01HH5`0G6AP201PJ6@X06A/J0P0G6AP201PJ6@806A/J0P0J71/A01XL6@P06adJ00@06a/I01`L
6P0L71X07AdK0P0N7Q`201lO7@<0824K0P0Q8Q`3028S7A008B8L200P8A/2024R7080824K100O81X8
01hN70<07AdK0P0L71X301/K6@<071hK0P0K7AX301XL6@P071hK200J71/801/M6P8071hK0P0M7a`3
01hP7@0301lQ7P0M7a`07AlL00H07AlL200L7Q/201/M70<071hM0`0M7ah0100J71T06adJ01/M6P0L
7Q/201dO70807R0M2@0K7A`201/M6P<071hK0`0M7a`@01/M71006Q`K400I6aX301/K6@8071`J0`0M
7A/201`N6`807AlL0`0N81d00`0O8Ah07R0M01hP7@0601hP7A00824K0P0P81h201lO7@807QhL0P0M
7A/0100O8Ah07R0M01hP7@0N81d201dO708071hK0P0M7A/201hN70<07alM00<0820N01`N6`0L7Q/0
1P0L7Q/801/M6PP06Q`I0P0I6aP0100J71T06adJ01/M6P0L7Q/301dO70P071`J200N8AX0100O8Ah0
7R0M01hP7@0N81d201dO708071hK2P0M7A/201hN70<07alM00<0820N01`N6`0L7Q/01P0L7Q/801/M
6Q006adL0`0K7AX[ooooo`00:_ooool20:=hA@80XWM4102QMT<20:9jB@<0XGU80`2PN4L0202RNDD0
XGQ40:1g@`2OMT80X7M30:9iA@2TNdL0YWe9202RMd@80:9hAP80YGY70P2VNdP20:MlB@80Z7e:202U
O4P0402TNdL0YGa80:MnBP2XOd/0ZH1<0:QoB`2WOTX0YWe90:V0BP2VODL0XgY40:ElAP2XOdT0ZX5;
0:MnB02TNdD20:IkAP80Yga70P2XODP30:UnB@80[85<0P2[P4/0102ZOdX0ZGi90:UnB@2YOTT80:V0
C080[H1900T0Zh1;0:V0C02XP4`0YX5=0:EoCP2TP4h0Zh1=0:YoC02XODX00P2WO4T01P2XODX0ZWm<
0:^0C@2[PT`0ZX5;0:QoB@80Ygi800<0Z7m90:Z1B`2[PT`00P2XOdT0102YP4X0ZX5;0:^2C02/Pdd2
0:f4CP<0ZHA@0P2ZQE430:^6DPP0ZXE@0P2[QTl00`2[QU40ZhIB0:^5E0020:^5EP040:^5F02YPe80
ZhED0:b6E@<0[XQG00<0[HMF0:b6E@2[QU400P2[QU430:Z5D080ZHA?0P2/PU020:^1C`@0ZX1>0`2W
OTH20:ImA@<0YGa40P2PNdH04P2QO4L0XWe80:5lA`2ONTD0W7M209]f@@2JMCh0VG@m09Ud?`2HLcl0
Ug5009Ma@P2FL440UW1309Ud@02HLcl0UW4m09A_>`80Tfhj0P2DKc/2099/?@80Tfdn00@0TF/l08mY
>P2<ISL0RV@e0P28J3T01027IcP0QVHg08EU=P25ICH208AT=@0508=R;`21H2d0Oed]07iL;P1mFbh0
0P1nFc402`1oG380P5de07UM=P1iGCH0N5`e07MK=01eFC80LUH_071D;@1_Db`0Le<Z00<0LU8Y0P1a
DBP2071@9`80LU8[00@0LE4Z071@:@1_CbP0KThW0P1]CBH03@1[DRT0JU4X06Q?9P1WCRD0ITdT06M>
9@1XCbH0JE0W06]?:P1/D2/0KDl[071?;01cDBh00P1eDBl02`1hDC00Le4T07AB9@1eDbH0MeDX07UG
:P1kFB`0OE/^07iL;`1nFc40OEX`0080O5T_00@0OEX`07mL<P21GS@0Pf0f2021H2d04`25HBl0QV8`
08IR<P26HC@0Qf8f08MR>028HcT0R68k08AO<P25H3<0Qf8e08QS=P29I3L0R6<f08MR=@26HC@0R6<f
08MR=@25H3<00`23GS401@24Gc80QF0c089M<023GS40Q5lb0080QF0c00<0Q5lb08=N<@22GC00201n
GRl207eK:`0407iL;P1oGC00Oe`b07iK<`80OEXd2021G38207mM;@0407iL;P1nG2l0OU/a07eJ<P80
OEXd0P1kF30207aI<@80OEXb0P1nFc<00`1kER`0O5L]07iI;`0207mJ<00607iI;`1lEbd0NeH/07iK
<`1mFS80NeP`0P1iERh0101jEbl0NeP`07]H<01lFC4907MG;P0B07UI<01kFc80OEdd07eM=01jFS40
MUH]07AD:`1fERd0MeL^07QH;`1iFC00N5P_07MG;P1eEB`0M5@[06a@:01_Db/0LeL_0P1fFS80101c
Ebl0Ke<[06a@:01]DRL206a@:00306]?:01ZCRT0JD`Z0080J4/[0P1OB2H00`1NAbL0GDHW05a4:002
05]3:@0905Y2:P1H?b40F44R05U19@1H@bP0Ed<Z05A2:P1A@BX0D40Y00P0D40V00T0D3dO050l8@1>
?B40C3`R04/m8`18?2@0B3`V04Ll9P16?2400P17?B8204Pn8`80BClT00<0BT0U04dm901=?B@00`1<
?2<304/k8P80B3hS00@0AcdR04Hl8@15>b00A3XO0P13>Ah03P14?B40@c`R04<l8P12>R<0@3PS03lg
900o=RD0?SDT03Xd900i<b<0>38R03La8@0e;al0=2hN0P0b;1`3038^8`80<BdR0`0`;24602dY7P80
;RXO200V9Q`A02<V7@<092DM0`0U9Qh202HW7`808RDL0P0S9Qd0100T9ah09BPO02HY800V:B0802DX
7`P08bHM200V:Q`01@0T9QT09BLJ02DW6P0V:1/0:2XM0080:B/N00<0:R`O02P[6P0X:aX00P0Y;1/3
02X]700302/^7@0Z;1h0:R`N00@0:R`N0P0Y:ad0200c<B@0<BlR02d^800Z;1h0:B/M02P/7@0V;Ad0
9bhN0P0Y:ad0100Z;1h0:bdO02`^800];b4202h`8PP0;BdQ0P0^<R4602da80P0>C@N0P0g<Q`01P0h
<ad0>C@N03Xe7`0k=R00?3LQ03dh8PD0?CHL0`0n=ad00`0o=A`0@3HM044g7P0204<i8007044g7P10
=Qd0?cDL040f6`12>1d0A3XO04Hl8@0204Pn8`80AcdR00<0BSXP04/k8@1<?2800P1>?R@00`1<?280
Bc/Q04Xj800804Xl8P80ASXP00P0Ac/Q04Pl8P19?B<0B3`R04Hj8014>1h0@cLM03`k7@80?C`N00P0
?SdO040o8@11@280@D0R04918`1<?R@0BcdS04Xl8P80B3XP00H0BS`R04/m8`1<?R@0ASlS04Dn8P13
?202048k7`0304<l8015?R80ASlS00<0BcdP0P1:?1l304Tk7P80AChT0P14?B<304<l8P03048k8@13
?200@c`P00<0@S/O0`11>Qh804<l80P0@cTN00<0@CXN048k7`12>al00P13?20204@m8@0304Dn8P14
?B<0AChT0080AChT00@0A3dS048k8@10>Al0?SLM0`0n>Ql303lk8080@3`Q1011>R04048k8@0504Xo
8`19?R80BCdS04Tm9@19?BL00P18>bP02@18>bX0@c`Y04<l:@12>bP0@3TV03lh9@0m=R<0?3DR03/d
8@0503@f7P<0=CLO0P0b=B@01P0a=2<0;c8Q02ha800/;ah0:bhM02X]70P0:B`Q00P09b/L02HZ700T
:1X08RDJ028U700R9Ah08bDP02@V8@<08RDL00@08B@K020S6P0P8aX07b8I0P0N8AP4020S70807b8K
0P0N8AX801`O60<071hK0P0K7AX301XL6@8061hL0`0G7A/301HL6P806Q`K0P0I6aX201PJ6@805aTH
200I6aX801LI61005QLI200F61L801DF60P05QPG200F5aT801DF60805QLI0`0E5QP301@E5a005AHH
4@0F5aT@01DF60P05QLI00@08b@V01lP8P0I6Q`051DG0P0B4aD00`0E5QP05aPJ01DF600701DF60P0
5QLI600E5QP8018H64005AHH2@0C6AT801@E5`P05AHH200F61LH01HG6@P05QPG0`0H6QT201LI60<0
5QPG0`0G6AP201HH5`<05ALF200F61L@01LI60805QPG0`0G6AP301PJ6@P06A/J0`0F61L00`0G6AP0
61XI01PJ6@0:01TK6P805aTH0P0H6QT201TK6P806Q`K4@0J71T801/M6P<071`J00<07AdK01hN700N
7Q`00P0O7ad3020Q6`<08B8L0P0R8ad@024R70P0824K0P0Q8Q`2020Q6`<07b0J00<07QlI01hN700N
7Q`01P0N7Q`301dM6`8071`J0`0K6aT301`N6`806adJ0`0J71T801`N6`P06Q`K200K7AX201`N6`80
7AlL100N81d801dO70P071hK0`0K7A`201`N7@<07AlN00<06Q`I01/M6P0K7AX00P0L7Q/201dO7003
01hP7@0K7A`06adL00L06adL0`0K7AX201`N6`<07AlL400K7A`@01XL6a006A/J0`0K6aT201`L6P<0
7AdK0P0L7Q/201dO70`07R0M400P8A/2020P7P807alM0P0N7Q`201dM6`@07R0M0P0M7a`201`N6`80
7AdK0P0N7Q`401lO7@P071hK200K7AX801XL6@0301TK600J71T06Q`I00806adJ0`0L7Q/00`0M7a`0
71`J01`L6P0601`L6PP07R4J100N81d201dO708071hK2P0M7A/201hN70@07alM200L7Q/801/M6Q00
6adL0`0K7AX[ooooo`00:_ooool30:=hA@80XWM40`2QMT<20:=iA`<0XWQ60`2QMdD0102SNTH0XWU5
0:5hA02PMd<20:5hA0030:9iA@2SNTH0Y7U600L0Y7U6202RN4H20:EjA`80YW]80P2WO4T20:QmBPT0
Y7]700l0YGa80:MnBP2XOd/0ZH1<0:QoB`2WOTX0YWe90:QoB@2UO4H0XWU30:AkA@2WOTP0Z7m90:Im
A`2SNT@00`2WO4L40:QmB080ZGi90`2[P4/30:YoBP80ZGi9202YP4`20:]nA`090:YoBP2YP4`0Z81<
0:N2CP2WPE00YX9@0:^0C@2ZOd`0Z7e:0080Yga900H0Z7e:0:YoC02[P4d0Zh9<0:Z1B`2YP4X20:Qo
B@040:V0BP2ZPD/0Zh9<0:QoB@80ZH1:00D0ZX5;0:^2C02/Pdd0[8==0:f4CP030:V4D080ZXEA0`2[
QU880:Z5D080ZhI?00<0ZhIA0:^6DP2[QE@00P2[QEH02@2[QEP0ZHA@0:Z5D@2/Qe<0[HQD0:j9E@2]
R5@0[8MC0:^6DP020:b7DP80ZhIA0`2ZQE00102YQ4l0[89@0:b2D02/PU020:^1C`<0ZX1>0P2XOdT2
0:MnB0<0YWe700<0YGa60:5lA`2QO4L00P2RODP0102QO4L0WgY509eh@`2LMd8209]f?`0<09Ye@02I
M400V79109Ma@P2FL440UW1309Ud@02HLcl0UW4m09E`?02DKc/0Tfhj0P2DKc/309=]?P05099/?@2A
Jc`0SfTj08eW>02;ICH00P2:J3X00`29IcT0R6Hh08MU=`0208IT=P0608ES=@25I340Q6<`089P<020
GS00OU`_0`1nFc402@1nFc<0MEP`07II<@1hFc<0NE`d07QK<`1eF300LUD]071C:`0207EE;080M5@[
0`1cDbX01@1bDRT0LU8[079B:`1aDBX0L50Y0080KdlX0P1^CRL01@1]DBT0K50X06]?9`1ZCRH0JDdU
0080JThV01<0JdlW06Y>:@1ZCRT0K4hZ06m>:`1aCb`0LTh/07=?;@1eCRd0KT/Q06m<8P1aCR@0LTlU
07AA9`1fDbT0Me@Z07QE:`1mFS00O5T_0080NeP^00@0O5T_07iK<@20GC<0PUle1`20GRh03021Gbl0
Q60^08EQ;`25HC40QF0c08IQ=@26HCL0Qf8h08MQ>P23GS40Q5lb08IQ=0<0R6<f0P26HC@00`28HcH0
QV4d08EP<`0308=N<@80QF0c00<0PUd`08=N<@24Gc800P25H3<01024Gc80Peha089M<01mFbd207iL
;P0=07mM;`20GS00PEla085O<@22H380Oed]07iL;01mFbd0OE/^07eJ<01mFS80OU/e07mL=P0807mJ
<080Oed]00@0OU`^07iL;`1nFc40OEXb0P1mFS@207]H<080O5Ta0P1mFS8207iK<`0307aG;@1mF2h0
OUT_0080OeX`00H0OUT_07eH;P1lEbd0OU/c07aI<@1kF30307UF;P80NUL_00<0NeP`07UI<01iFC00
1P1iFC000`1gEbh0N5P_07]K<P0207aL<`0307UI<01fERd0M5@[0080MeL^0`1hF2l01P1gEbh0MED/
07AD:`1_Db/0L5@/079F;P80LeL_0140LUH^071D;01_Db/0KE8W06eA:@1/D2P0JdlX06Y>:@1YC2X0
JD`/06Q;:`1PBRD0H4TW05m89P1NAbL0GTLX05e5:@0205a4:P0805U08P1I@R<0FT8V05U4:@1G@bX0
E48Z0551:P1??bP805109P08054n801A?B80CchR04dm8`1<?R@0BCdU04Tm9`18?BL204Lm8P80B3hS
1019?b@304/k8P<0C3`S0P1=?B@204Pn8`0404Lm8P16?240AC/P04Dk8080A3XO00H0A3dQ04<l8P13
?280@SXS044i9010>2D203lf9@0603`g900k=R<0>SDR03Td8@0h<b00=S4N0P0e<1d303<_8`80<RhR
0`0a;B4802hZ7PP09RHL4@0S9Qd302@U7@<09BHN0P0V9al00`0S9Qd092LN02@W7P0=02@W7PP08bHM
200T9a`01P0T9Q/09BLL02DW700V:1d09bTN02PZ7`80:B/P00@09bTK02PZ700X:Q`0:2XL0P0Y:ad:
02X/7P06038`8`0a;b80;BhP02X/7P0Y:ad0:2`M0P0W;Qh202/]7`0402`^800];b40;BlQ02h`8P80
;c4S0P0];R00100^;b40;c0R030a8`0`<B<2034b90P0;c8Q200j=Al203Lb7080>3<M00@0>C@N03Xe
7`0k=R00>cHP0P0l=A/0100m=Q`0?SLM03lh7P0o>1h2040i7`03040f7@11=ah0@SPO0080@cTP00<0
@SPO044g7P10=Qd00P13>Ah02@15>b00AS`Q04Lm8P17?B80AS`Q04Dk801:>R00Bc/Q04`l8P0204hn
900304`l8P1;>b40BSXP00P0B3`R0`17?B8304Pn8`0404Lm8P15>b00A3XO03hj7@80?c/N00<0@3`O
044m8012?R400P13?b800`19?B<0B3`R04Lk8@0204Hj800604Lk8@18?280BCdS04Dn8P14?B40@c`P
0P12>al00`13?200A3dQ04Dn8P0304Pm8@80Ac`P0`16>al01013?280@S/Q048k8@12>b42044j8080
@3TO00@0@3TM044j7P11>Qh0@CXN3012>al804<i7P@0@S/O0P13?20204@m8@0804<l8P14?B<0AChT
04Dn9014?B<0@S/Q040i7`0o>1h303hj7`<0?c/P0P10?24404@m8`<0@c`R00T0@S/Q04Y1901:@B@0
BClT04To9P18?BL0B3dY04Ll:017?2X00P11?2P01P10>bL0?STU03dh900l=b<0>cHR03Xe8@L0=3HP
00T0<cDO034d8`0a=2<0<3<R02ha800]<1l0;2lN02/^7@0Z;A`0200X:b00200W:a`09RXL02@X6P0R
9AX08RDL028U7P0S9B0092HQ0`0R9A`0100Q91/082<J020S6P0O8QT201hQ600401lR6`0N8AX07R4J
01hQ6P807B0I2P0L7aP301`N6`806adJ0`0J71T201PN70<05adK0`0F71X201XL6`806A/J0P0H6QT2
01LI60P06A/J200G6AP@01HG6@P05QPG200E5QP801HH5`P05QLI200E5QP201HG6@<05AHH0`0D5AL@
01DF61405QLI400E5QP801HG6@0301LH6P0F5aT05AHH008051DG00<05AHH01LH6P0H6A/0200E5QP8
01HG6AP05AHH200B61Q001DF60T04aTI200D5AL801DF60P05QPG600F5aT801HH5`8061XI0P0G6AP3
01HH5`0401DG5P0G6AP05aTH01LI60805QPG0`0E5aH801HH5a005aTH0P0F61L301LI60<061XI200I
6aX201HH5`<05aTH0`0H6QT801TK6P805aTH0P0H6QT201TK6P806Q`K4@0J71T801/M6P8071`J0`0M
7A/301hN70807b0J0P0P8A/3024R7003028S7@0P8A/0824K00h0824K200O81X3020Q6`807b0J0`0N
7aT801hN70<07AdK0P0L71X301/K6@<071hK0P0K7AX301XL6@P071hK200J71/801/M6P<071hK0P0M
7a`301hP7@P07AlL200L7Q/0100J71/06adL01/M700K7A`201`N7@807AlN100K7AX201`N6`807AlL
2@0J71/0100J71T06adJ01/M6P0K7AX201`N6`807AlL400K7A`801XL6aP06A/J0`0K6aT201`L6P<0
7AdK0`0L7Q/201dO70/07R0M400P8A/2020P7P807alM0P0N7Q`201dM6`<07R0M0P0M7a`301`N6`<0
7AdK0P0N7Q`301lO7@P071hK200K7AX;01XL6@806adJ100L7Q/801`L6PP07R4J0`0N81d201dO70<0
71hK2`0M7A/201hN70<07alM200L7Q/801/M6Q006adL0`0J71T[ooooo`00:_ooool20:AiAP80XgQ5
0P2RMd@20:5f@`80Y7U60`2SN4D30:9gA080XgY60P2RNDD40:5hA0P0YGY7202SNDL20:EjA`80YW]8
0P2WO4T20:QmBPP0XWU500@0XgY60:AkA`2VODT0Z7m;0P2YP4`02P2XOd/0Ygi:0:MnB02TNdD0XWU3
0:=jA02VODL0Z7m90:ElAP2RND<20:MlA`L0Z7e80P2[P4/60:YoBPP0ZH1<0P2ZODH02@2YOTT0ZH1<
0:V1C@2XPdl0Z89A0:R4DP2[P4d0ZWm<0:QmBP020:MlB@040:QmBP2ZOd`0Zh1=0:Z1B`H0ZH1:00<0
ZX5;0:V0BP2YP4X00P2ZPD/20:^2C080[8==0`2YQ5020:Z5D@<0ZhIB202ZQE020:^6C`030:^6D@2[
QU80ZhED0080ZhEF00T0ZhEH0:R3CP2ZQE00[8MB0:f8D`2^RE@0[HQC0:b7DP2[QU400`2/Qe820:^6
D@<0ZXE@0P2]Pe420:b2D080Zh5?0P2ZP4h20:V0C080Z7m;0`2WOTX00`2VODT0Xgi90:=nB@020:9m
B0090:5lA`2PNdH0WgY509iiA02MN440W7M009]f@@2JMD40VG=20080Ug5200H0UW1309Ud@02HLcl0
Ug8n09Ia?@2EL3`309A_>`80U6ho00@0Tfdn099/?@2@JS/0SfTj0P2=IcP208eX>`0408aW>P2;IST0
RVDh08UT=`80R6<f00D0QVDb08ET<@23HC40PV0b081N<@0207iK<@0507eJ<01mFS80Le<Z07EE;01i
FC000P1lG3<00`1iFC00MED/079B:@0207QG;P80MeH]0`1fEB`00`1eE2/0LU8[079B:`02075A:P04
071@:@1_CbP0KdlX06m?:080KE4Y0P1/D2P406]?9`80JDdX00<0JddY06e<:@1_CBX00P1aCB/01`1c
C2/0KT/Q06m<8P1`CB<0LDhT07=@9P1dDBL00P1fDbT207]H;P80NUL]00@0NeP^07eJ<01oG380P5dc
101oGBl4081N<080Pel]00<0Q60`08AO<P24Gc<00P25H3H01025GcP0PUd`08=N<@25H3<308MR=@05
08IQ=025H3<0Qf8e08IQ=024Gc800P23GS401P24Gc80QF0c08IQ=022GC00Peha08AO<P80QF0c00<0
Q5lb08=N<@22GC000P1oFRd01020Fbh0PE`_08=N<@24Gc8208EP<`08085O;`1oGBd0OE/]07]I;01k
F2h0OEXb07mL=P21GSP807iI;`80Oed]00@0OU`^07iL;`1nFc40OEXb0P1mFS@207]H<080O5Ta0P1m
FS8207iK<`<0OEP^0P1nFBl307eH;P0607eJ<P1lFC40NUL_07UF;P1hEBd0NEH^0P1jEbl00`1kF300
NUXa07YJ<@0607YJ<@0807MG;P1hF2l0NUXa07]K<P1jFS40N5P_07IF;@1eEB`307QH;`80MeL^0P1f
ERd00`1eEB`0LUH^079F;P04075E;@80LUH^01P0KU<X06iB:P1]DBT0K50Y06]?:P1ZCB/0JTd]06U<
;01RC2D0HT`W065;9P1PBBL0GdPX05i7:01NARX0GDDY05Y18`1J@b@0Fd<W05U4:@1G@bX0E48Z0551
:P1??bP805519`08058o8@1B?R<0CchR04hn901=?bD0BShV04Xn:019?RP204Pn8`H0BClT00H0B3XP
04Tk8@19>b40BS`R04/m8`1<?R@204do9@80B3hS0P17?B801@16?240AC/P04Dk8015>b00@c`P0080
@c`R00<0@SXS044i9011>BH00P10=bH01P0n>BD0?CPT03`g8`0k=R80>SDQ03Td8080>3<O100d<B82
03<`8@80<RlP100`;Ah402l/7@0302PX7P0W9ad09bLM00809bLM0`0V9Q`A02@W7P<092DM0`0U9Qh2
02HW7`809BPO0`0T9ah302<V7@P092LN200S9Qd8028U6P<09BLL00<09RPM02LY7P0W:Ah00P0X:Ql4
02LY7080:2XM0P0Y:ah302T[7@@0:R`N00X0:bdO034_8P0`;R40;2dO02X/7P0Y:ad0:2`M02L^7P0X
;al0;2hP0P0];b4202h`8P80;c4S00T0<38T02h_7`0^;al0;c0P030a8@0b<b<0<c@T03@e9@0e=RH0
100a<R04038c8@P0>cHP0P0g<Q`203Pc7@0403Td7P0j=Al0>SDO03Xe7`80?3DK00@0?CHL03hg7@10
>Al0@CXP0P12>b43048h7`80@cTP0`12>1l304Dk80<0AS`Q0P15>b000`19>b00BS`Q04/m8P0204do
900304/m8P1:?240BC/P00P0AS`Q0`15?R8304Ho8`80AChR00D0A3dQ040k7P10>ah0@3/N044l7`02
048m8080@chQ0`16?24204Dk80<0AS`Q0P13?204048k7`80@c`P0P16?B0204Dl7`@0A3/N00@0@CXP
040i7`10>Al0@3TO0P0o>1h203hg7@80?cPL00@0@3TM044j7P11>Qh0@S/O0P13?208044j7PP0@cTN
1P12>al204<l8003048k8@13?280A3dS0080A3dS00<0@S/Q040i7`0o>1h00`0n>Ql303lk8080@3`Q
0P17@2H01016?bD0AChT04@m8`14?B<204<l8P80BD8U00`0B44U04M09P16?RL0AShY04Dm:015?BX0
?S`W03dk9P0l>RD0>cTT03Xh8`0i=b8203Pf8@0303@f8@0c=B00<cDP0080<cDP0`0b=1l01P0`<b80
;c8Q02ha800]<1l0;2lN02/^7@80:RdL200X:b00200W:a`09RXL02@X6P0R9AX08RDL028U7P0S9B00
92HQ0`0R9A`0100Q91/082<J020S6P0O8QT201hQ60<07B0I0P0L7aP301/N5`P071lH0`0L7Q/201/M
6P<06Q`I0P0H7Q`301LM6`<05Q`J0P0J71/201TK6P8061XI0P0G6AP801TK6PP05aTH400F5aT801HH
5`P05AHH200F61L801HG6@P05AHH0P0F5aT301DF60<051DG400E5QPA01HG6A005AHH200F5aT00`0B
4aD04a@F01@E5`0201DF600301HG6@0E5QP05AHH00P05AHH200F5aTH01DF60P04QPH@00E5QP901<I
6A005AHH200F61LH01HG6@P05QPG0`0G6AP301HH5`805ALF0`0G6AP201HH5`<05ALF200F61L@01LI
60805QPG0`0G6AP301PJ6@P06A/J1P0G6AP201PJ6@P06A/J0P0G6AP201PJ6@806A/J0P0J71/A01XL
6@P06adJ1P0M7A/201hN70<07b0J0P0P8A/3024R7100824K200O81X2020Q6`<07b0J0`0N7aT801hN
70<07AdK0P0L71X301/K6@<071hK0P0K7AX301XL6@P06adJ200J71/:01/M6P8071hK0P0M7a`201hP
7@P07AlL200K7AX201XL6`<06adL0`0L7Qd601/M6P8071hK2@0J71/201XL6@<06adJ0`0L7Q/@01/M
70P06Q`K600I6aX301/K6@8071`J0`0M7A/201/M6P8071hK0P0M7a`:01hP7A00824K0P0P81h201lO
7@807QhL0P0M7A/201hP7@807AlL0P0L7Q/201/M6P8071`J0P0M7A/201hN70807alM200L7Q/801/M
6PP06Q`I2@0K7AX801`L6PP07R4J0P0N81d201dO708071hK0P0K7AX801dM6`8071`J0P0M7A/201hN
70807alM200L7Q/801/M6Q006adL0`0J71T[ooooo`00:_ooool30:AiAP80XgQ50`2RMd@20:IhAP<0
YGM50`2TMT@20:9iA@030:=jAP2RNDD0XWU50080XGQ400<0X7M30:EjA`2UNTL01P2UNTL80:=iA`80
YGY70P2VNdP20:MlB@80Z7e:2@2RNDD00`2TNdL0YWe90:QoB`020:V0C080Z7m;00P0Z7m90:ElAP2R
ND<0XgY40:MnB02XOdT0YWe70:=jA0L0Z7e80P2WO4L60:YoBP80Zh1;202YP4`20:YmAP090:UnB@2Y
P4`0ZH5=0:R3C`2XPU40Z8AB0:^0C@2ZOd`0Z7e:0080Yga900<0Z7e:0:YoC02[P4d00`2YP4X20:Z1
B`<0ZH1:102ZPD/40:^2C0<0ZHA@0P2ZQE430:^6DPP0ZXE@0P2[QTl00`2[QU40ZhIB0:^5E0020:^5
EP040:^5F02XPdh0ZHA?0:^6D@80[HQC00<0[8MB0:^6D@2ZQE000P2]R5<20:b7DP80ZhIA0P2ZQE03
0:f3D@80[89@0`2[PDl0102ZPDd0ZH1<0:V0C02YP4`20:QoB`80Ygi:00D0YH1;0:AoBP2SOTT0XWe8
0:5lA`030:1kAP80WWU200H0WGQ309]f@P2ILd80V79309Ma@P2FL4<309Qc?`0509Mb?P2FLCd0UG0l
09A_>`2CKSX00P2EKd00102CKCh0TV`m091Z>`2?JCX208iX>@80SVTl00@0SFPk08aW>P2;IST0RVDh
0P29I3L208IU<P0308ES<`23HC<0PElb0080P5dc00D0OU/a07eJ<P1dDbP0MeH[07]J;`0207iM<P03
07]J;`1gER/0M5<X0080NUL_0P1iERh307QE;@0307MD;01bDR/0LE4Z00<0LE4Z0`1`D2T00`1^DBT0
Ke8Z06mB:P0206iA:@80KE0X00H0K4lW06U=:01ZCRT0JddY06e<:@1^C2T2071<:P0;079;:P1aCRH0
LDhV079?9`1dDBT0ME8Z07IC:`1gE2`0N5D]07YG;@1iER`00P1hEB/0101iER`0NeP^07eJ<01oG382
07eK;P80OU`_0P1oGC02081N<@80PUh/00T0PUh^08=N<@23GS80Pehd08AO=@24GSL0PE`_08=N<@24
Gc800`26HC@01@25H3<0Q5lb08IQ=025H3<0Q5lb0080Peha00H0Q5lb08IQ=027HSD0PUd`08=N<@24
Gc8208EP<`0C08AO<P23GS40PUd`07mJ;@20Fbh0PE`_089M<023GS40Q5lb08EP<`26HC@0PEl_07mM
;@1mFbd0NeT/07]H;P1mFS80Oe`f085N>00807iI;`80Oed]00@0OU`^07iL;`1nFc40OEXb0P1mFS@2
07]H<080O5Ta0P1mFS8207iK<`0307iI;`1mF2h0OEP^00@0OEP^00@0OUT_07eJ<P1lFC40NUL_0`1h
EBd207UF;P0307YG;`1jFS40NUXa00H0NUXa0P1hF2l307UI<00307QH;`1fERd0MED/0080N5P_0P1g
Ebh407IF;@0307=G;`1bERh0LED]0080L5@/01/0LED]079F;P1cEbl0Ke@Y06mC:`1^DRX0KE4Z06a@
:`1[CR`0Jdh^06Y=;@1TCRD0I4hW06==:01RC2L0HDXX0619:@1PBBX0GdPY05a39@1KA2D0G4@X05Y5
:P1HA2/0E48Z0510:@1??bP0201A@BL0201C@280DclT050o8`1??bD0CClU04/o9`1;?bT0BSlY0P1:
@2D604To900604Hj8017>b40Ac/Q04Pl8P19?B<0BShT0P1;?bD00`18?R<0AcdR04Lm8P0204Lm8P<0
AS`Q00P0@c`P04<l8P13?280@SXS048j9@12>RL0@STX044h9`80?STU0P0m>2@0100l=b<0>cHR03/f
8P0j=B4203Hc8P80=C8Q100d<B000`0c<1l0<RlN038_7P02034^7@80<2dL00<0;b`K02TY7`0Y:Al0
0P0X:1h0100W9ad09RHL02HV700V9Q`A02@W7P<092DM0`0U9Qh202HW7`809BPO0`0T9ah302<V7@P0
92LN200S9Qd8028U70<09BHN100V9al0100W:2009RPM02HX7@0V:1d302LY7P80:2XO0P0X:Q`202T[
7@0702X/7P0[;Al0:bdO02/]7`0a;b80;bdP02`]7`0202T[7@0302T]7P0X;al0:C0P0080;BlQ100^
<28202la8`80;c0N00@0<34O034b800c=280=3DS0P0e=R@00`0c<Qh0=3<O03@c7`0203Dd8080=SDQ
00<0=cHR03/f800k=R001P0k=R0303Td7P@0>SDO00L0>cHP03df700m=Q`0?SLM03lh7P11>R00@S/Q
0080@c`R00<0A3XQ04<i8013>B001013>B000`14>R40AS`Q04Dk800404Dk8080AS`Q00<0Ac`P04Pm
8@19?R800P1;@2@00`19?R80B3dQ04Ll800804<l80<0A3lR0`13?R4204@o8P0404E08`11>Qh0@CXN
044j7P@0@S/O00<0@c`P048k7`13?2001@13?2000`12>al0@CXN044j7P04048k7`80@CXN1012>al2
044j7P80@3TM00@0@3TO03lh7P0o>1h0?cPN0P0n=ad203df700503hg6`0o>1`0?cPL040i7@11>Qh0
0P12>al00`13?200@3TM040i7@06040i7@P0@cTN1P12>al2044j7P08044j8012>b40@c`R04@m8`13
?280@S/Q040i7`0o>1h303hj7`<0?c/P0P10?2401P18@BL0Ad0V04M09P16?bD0AChT04@m8`80@c`R
00P0B4<U04M29016@B@0AClU04@n9P13?BL0@S`V048k:080>cXU00@0>STT03Th8`0h=b80>3LR0P0g
=R4303<d8P03038c8@0a<R00<C8P0080<34O0P0^<B00100]<1l0;2lN02/^7@0[;Qd202X]70P09bXO
00P09b/L02HZ700T:1X08RDJ028U700R9Ah08bDP02@V8@<08RDL00@08B@K020S6P0P8aX07b8I0P0N
8AP0100M81T071lH01`O600L7aP201/N5`806QdF200L7aP301`N6`806adJ0`0J71T201PN70<05adK
0`0F71X201XL6`806A/J0P0H6QT201LI60P06A/J200G6AP@01HG6@P05QPG200E5QP801HH5`P05QLI
200E5QP201HG6@<05AHH0`0D5AL@01DF61405QLI400E5QP801HG6@0801@E5`0E5QP05QLI01HG6@0E
5QP051DG018C5@0A4Q@801DF60P05QLI600E5QP8018H64005AHH2@0C6AT@01DF60P05QPG600F5aT8
01HH5`805aTH0`0F61L301DG5P<05aTH0P0F61L301DG5PP05QPG400G6AP201HH5`<05aTH0`0H6QT8
01TK6P8061XI1P0G6AP801TK6P805aTH0P0H6QT201TK6P806Q`K4@0J71T801/M6P807QhL1P0M7A/2
01hO6@807b0J0P0P8A/2024R7100824K200N7aT301lP6P<07QlI0P0M7QP;01dM6`8071`J0`0K6aT3
01`N6`806adJ0`0J71T801/M6PP06Q`K2`0K7AX201`N6`<07AlL200L7Q/801/M6P<06Q`K0`0K7A`2
01`N7@H06adJ0P0J71T901XL6`<06Q`I0`0K7AX201`N6a006adL200J71/801PJ6A006A/J0`0K6aT2
01`L6P<07AdK0`0K7AX201`N6`<07AlL200N81d@020Q6`80820N0P0O7ad201hN70807AdK0`0M7a`2
01`N6`<06adJ0`0L71X201dM6`<07QhL200L7Q/801/M6PP06Q`I2@0K7AX801`L6PP07R4J0`0M7a`2
01`N6`<06adJ200M7A/301`L6P807AdK0`0N7Q`801`N6`P06adJ400K7A`301XL6B_ooooo000Zoooo
o`040:EjA`2TNDH0Y7U60:AiAP80XgQ50P2RMd@20:MhA0<0YWM30`2UMT800`2PMd<0XGQ40:9iA@02
0:=jAP030:9iA@2QN4@0XGQ400P0Y7U6202TNTP20:EjA`80YW]80P2WO4T20:QmBPP0Y7]700@0XGQ4
0:=jAP2VODT0Z7m;0`2YP4`02@2XOd/0ZH1:0:ImA`2TNdD0YGa60:QoB@2ZPD/0Ygi80:AkA@020:Un
B@@0Z7e80`2WO4L20:UnB@<0ZWm:0`2[P4/80:V0C080Zgi700T0ZWm:0:V0C02XP4`0Yh9>0:N1D02V
PU00Zh1=0:YoC02XODX00P2WO4T01P2XODX0ZWm<0:^0C@2XOdT0ZH1:0:Z1B`80Zh9<00<0ZX5;0:V0
BP2XOdT0102ZPD/40:^2C0<0ZHA@0P2ZQE430:^6DPP0ZXE@0P2[QTl00`2[QU40ZhIB0:^5E0020:^5
EP090:^5F02XPd`0ZHA=0:^6C`2/Qe00[HQA0:b7D02[QTl0ZXE>00<0[HQC0P2/Qe830:^6D@040:j4
DP2]Pe40[H=A0:f3D@80[89@0`2[PDl30:Z0CP80ZGm=0P2XOT`0102VPD`0YH1;0:=nB@2RODP40:5l
A`080:1kA02ONT<0WWU409ag@`2JM4<0V79309Ma@P2FL4<209Qc?`0;09Ud@02HLcl0Ug8n09Ia?@2D
Kc/0Tfhj09Ma@P2EKd00Tfdn095[?02@JS/00`2?JCX01P2@JSd0SfTl08mY?02>J3/0SFLj08aV>@80
RfDh0P25I3400`25Hc<0QF<e08=Q=002085N=00507mL<P1nFc<0NEH/07]H;P1mFS000P1oG380101m
FS00NUL]07QE:`1lERl307]E;P80NU@]0P1iDb`:075A:P<0LU8[00<0L50Y06m?:01^CRL00P1[CbX0
0`1/CRX0KTdZ06m=:P02071<:P06079;:P1cD2X0Le0Z07AA:`1eDR`0MU<]0P1gE2h00`1hEBl0NEH/
07QE:`0207MD:P0507QE:`1jEbd0O5T_07eJ<01kF2h00P1lFBl00`1mFS00OU/a07mL<P02081M<`80
P5`Z00<0PEd]085L;`22GC400P22GC<01023GCH0P5/^089M<023GS4308EP<`0408AO<P23GS40QF0c
08EP<`<0Peha00H0QF0c08IQ=028HcH0PUd`08=N<@24Gc8208EP<`0308AO<P23GS40PUd`0080PU`_
00@0Ped`08AN<@24GS40QElb0P26H3<0201oGBd0OU`/07eK;@1mFbh0OEX`07eJ<P1nFcD0Oe`f201o
FS0207mM;@0407iL;P1nG2l0OU/a07eJ<P80OEXd0P1kF30207aI<@80OEXb0P1nFc<00`1oFS00OUT_
07eH;P0207aG;@0907eH;P1nFBl0OeX`07aI<@1kF300NEH^07QE;@1gE2`0N5D]0080NEH^00<0NUL_
07UI<01iFC001P1iFC0507QH;`0807MG;P1fERd0MUH]07UI<01hF2l0MeL^07IF;@1eEB`207IF;@03
07MG;P1bERh0LUH^00@0LED]0P1bERh0201`EBX0L5@/06mC:`1^DR/0KE4/06a?;@1/Cbl0Jdh^0P1V
D2L0101UCbP0I4hY06==:01RBbT2065::P0805e49P1LABH0GDDY05Y5:P1HA2/0E48Z0510:@1??bP8
05519`0805A18`1D@2D0DD0T05109P1>@2H0C40X04a0:P1:?bT204]19P80BT0U1019?b@304Lm8P<0
B3hS0P19?b@804Lm8P0604<l8013?280@c`R04<k9013>bH0@c/X0P13>RT203hi8`80?CPR0P0l=b42
03/f80<0=c@Q0P0f<b0403Db7`80=34N00<0<c0M038_700a;Q/00P0`;AX202XZ800302TY7`0X:1h0
9bLM00809RHL00<09BDK02@W7P0T9ah03`0T9ah302@U7@<09BHN0P0V9al00`0S9Qd092LN02@W7P05
02@W7Q008bHM200R9Ah802DV80<09BHN0P0V9al302LX800602LY6`0X:Q`0:2XL02T[7@0Z;1h0:bdO
0P0/;R000`0`;R40;bdP02//7P0202T[7@0302T]7P0Y<200:S4Q00P0;BlQ0P0`<Qd2034c7P04038d
7`0c=B00=3HQ03@f8@80=C<N00<0=S@O03Le800h=R400P0i=b800`0j>2<0?3LQ03`g8@0603`g8@03
03/f800l=b40?3LQ00D0?3LQ0P0o>1h2040i7`04044j8012>b40@c`R04<l8P80AC/R00@0A3XQ04<i
8013>B00A3XQ0P15>b8204Dk80<0A3XO00H0AS`Q04Lm8P18?R<0ASdP04Ln8@18?b8204Y1900304Po
8P17?R40ASdP00P0@S/O0`11?B03040l7`03044m8013?b80A40S00P0@cTN0P11>Qh01012>al0@c`P
04<l8012>al2044j7P0303lh7010>Ad0@CXN0080@S/O00<0@CXN040i7@0o>1`00`11>R02040i7`<0
?cPN0P10>Al203lh7P<0?SLM00<0?CHL03lh700o>1`00`10>Ad3044j7PP0?cPL2013>Ah4048k7`80
@CXN0P10>Ad00`10>Al0@CXP048k8@0204<l8P03048k8@10>Al0?cPN00<0?SXO0`0o>b02040l8@04
04Ho9@15?R@0AChT04Dn90@0A3dS0P15@R<01P14@2<0@clT044m9010>bD0?cXT03hi9@<0=cTS0P0f
>28303Dg8@80<c@T00@0<S<S034b8P0`<B40<34Q0P0_<20302`_7P80:bhM0`0Z;A`802LZ7`0802L[
700V:Q`092PJ028U6P0R9A`08RDN02<U800T9R43028U7004024T6`0P8aX082<J01lR6@807R4H0`0M
81T201`O60<06ahG200L7aP301`N6`806adJ0`0J71T201PN70<05adK0`0F71X201XL6`806A/J0P0H
6QT201LI60P06A/J200G6AP@01HG6@P05QPG200E5QP801HH5`P05QLI200E5QP201HG6@<05AHH0`0D
5AL@01DF61405QLI400E5QP801HG6@<05aPJ00D05QLI01DF600C51H04A8D010A4`0801DF60P05QLI
600E5QP8018H64005AHH2@0C6AT@01DF60P05QPG600F5aT801HH5`0401LI600F61L05QPG01HH5`80
5ALF0P0D5QD301LI60805QPG0`0E5aH801HH5a005aTH0P0F61L301LI60<061XI200I6aX301PJ6@<0
5aTH0P0F61L801TK6P805aTH0P0H6QT201TK6P806Q`K4@0J71T801/M6P<07QhL0`0M7A/201`L6P<0
7QlI0P0O81X3020Q6a007b0J200N7aT301lP6P807QlI0`0M7QP;01dM6`8071`J0`0K6aT301`N6`80
6adJ2`0J71T801XL6`P06adJ00@06Q`I01/M6P0K7AX06adJ0P0L7Q/201dO70P071hK200J71T201TK
6P806Q`K0`0K7A`00`0L7Qd06adJ01/M6P0201/M6P806Q`I0P0I6aP901TK6P806A/H0P0J71T301/M
6P0301`N6`0K7A`06adL00h06adL200J71/801PJ6A006A/J0`0K6aT201`L6P<07AdK00@06Q`I01/M
6P0K7AX06adJ0P0L7Q/201dO70P07R0M400P8A/2020P7P807alM0P0N7Q`201dM6`807AlL0P0L7Q/3
01/M6P0301XL6@0K6aT071`J008071`J0P0M7A/201hN70P071hK200K7AX801XL6@<071hK0P0K7AX4
01XL6@P071`J200N8AX201dO708071hK0`0K7AX00`0J71T07AdK01dM6`0601dM6`0401/K6@0L71X0
71`J01`L6P807AdK0P0N7Q`801`N6`P06adJ400K7A`301TK62_ooooo000Zooooo`80YGY70`2TNDH3
0:=hA@80YgQ20`2VMd430:Ef@00409ie@@2OMT80XGQ40:=jAP80Y7]700<0XgY60:9iA@2RMd@01`2R
Md@80:AjB080YGY70P2VNdP20:MlB@80Z7e:202UO4P01P2QN4@0XgY60:ElB02XOd/0ZH1<0:Z1C@80
ZH1<00P0Zh9<0:QoB@2UO4H0Ygi80:Z1B`2/Pdd0ZH1:0:ImA`<0ZGi900@0Z7e80:MlA`2WO4L0Yga7
0P2VNdH30:UnB@030:YoBP2[P4/0Zh1;0080[85<202YP4`20:f0B@090:^0B`2YP4`0Z81<0:J1C@2U
Odh0Y81>0:^0C@2ZOd`0Z7e:0080Yga900H0Z7e:0:YoC02[P4d0Ygi80:QoB@2ZPD/20:^2C0030:Z1
B`2XOdT0Ygi800@0Zh9<102ZPD/30:V4D080ZXEA0`2[QU880:Z5D080ZhI?00<0ZhIA0:^6DP2[QE@0
0P2[QEH0102[QEP0Yh=90:R4BP2ZQT`30:b8CP030:^7C@2ZQT`0[HQC00<0[HQC0P2/Qe820:^6D@80
[XAB0`2]Pe430:b2D0<0Zh5A0P2ZP5030:UoC`040:R3CP2VPD`0Y7m:0:9mB080XGa700X0XWe80:=n
B@2QO4D0X7]409mjA@2MN4@0VgE409UcA02GLD80Ug540P2HLcl209Ud@00809Qc?`2FLCd0U6lk09=^
>P2HLT<0UW1109=]?P2AJc`208mY>P80T6Xk0P2BJCd2095X?009091W>`2?ISX0SVDi08iU>@23HRl0
Q6<`08ES<`26I3H0QF<f0080Q64g00<0PUle081M=@1oGC000`1oGC00101nG2l0OE/^07aJ;@1lFRd2
07aE;P80Ne@]0`1jDb`00`1iDR/0LE4Z075A:P02075A:P@0LU8[00<0LU0Z07=A:`1dDR`00P1dDR`0
0`1bD2X0L4hX06m=9`0206a@:`0306e?:`1_CR/0L4h[0080LDd[00D0Ld`[075=:@1bCRX0LThZ07=?
:`0207A@;080ME4]00T0N5D[07MD:P1fDbT0MU<Y07MD:P1iER`0NeP^07aI;`1jEbd00P1kF2h01@1l
FBl0OU/a07mL<P1oG380P5dc0080Oe/Y00<0P5`/081K;P21G3000P21G3802`22G3D0P5/^085L;`23
GS40Q5lb08EP<`24Gc80Peha089M<025H3<0Q5lb00<0Peha00H0QF0c08MR=@28HcH0PUd`08=N<@24
Gc8208EP<`0308AO<P23GS40PUd`00H0QUda0P27GS8207eK:`0407iL;P1oGC00Oe`b07iK<`80OEXd
2021G38207mM;@0407iL;P1nG2l0OU/a07eJ<P80OEXd0P1kF30207aI<@80OEXb0P1nFc<00`1oFS00
OUT_07aG;@0207]F;00607aG;@1nFBl0OeX`07aI<@1kF300NEH^0P1gE2`0101hEBd0NEH^07UF;P1j
Ebl807MG;P<0N5P_0P1gEbh307IF;@0307YJ<@1iFC00MeL^00<0MED/0P1gEbh00`1`E2`0LED]079F
;P03079F;P03075E;@1`E2`0LEH[0080L5@/00<0Ke</06iB;@1]D2h00P1/Cbl206MB9`0306I@9`1U
CbP0I4hY0080Hd`Z00T0HT/[05i59`1MARL0GDDY05]6:`1HA2/0E48Z0510:@1>?RL0201B@RP02@1E
@R@0E40U05919@1A@BL0Cd4W04e1:@1<@2X0Bd0Z04a29`0204]19P80BT0U0P19?b@00`18?R<0Ad0T
04M0900304Ho8`<0AChR1017?B8404Pn8`0604<l8013?280@c`R04<k9013>bH0@c/X0P13>RT303di
80<0?3PO0P0k=ah303Pe8P80=c@Q1@0f<b001`0e<Ql0=34N03<`7@0b;a`0<BhK030]6P0[:b400P0Z
:R001@0Y:Al09bLM02HV700V9Q`09BDK01409BPO0`0T9Ad302DV7P809RLO0P0R9A`202<V7@0402@W
7P0U:1l09RTP02HY81008bHM200S9B0802DV8@<092DO0P0U9R0302HW8@809bTK00T0:2XL02T[7@0Z
;1h0:bdO02`^800];b40;bdP02h/7`0[;1h00P0Y:ad00`0Z;Ql0:C0P02Xa8@0402`^80@0:bdO200a
<ah01P0e<a`0=S@M03Le7P0h=Ql0>CLP03Xh8@80>cTR200m>28603hi8`80?CPR0`11>R05048k8@03
04Lm9016?2<0A3XQ0080@cTP00@0A3XQ04Hl8`17?B@0A3XO0`13>Ah01`14>Ql0AS`Q04To901;@BH0
A3dP04Dn8@16?b800P18@B@00`16?b80AChQ04@m8008040k7P80?SdO00L0?C`N03`k7@0k>Q`0?3/M
03hm7`10?b40@D0R00P0A3PN00<0?STL03lj7@11?1l00P12?B001P11?1l0?cXM03hi700n=a/0?cPL
044j7P80@S/O00<0@CXN03lh700n=a/00`0o>B4203hh80<0?CLO00@0@CXP040i7`10>Al0@3TO0P0o
>1h203hg7@80@CXN0`10>Ad;03lh70P0@cTN00<0@c`P048k7`12>al00P11>Qh2040i7@0403lh700o
>1h0@3TO044j8080@c`R00<0@S/Q044j8010>Al00`0n>Ql303lk8080@3`Q1013?28404@m8`080491
8P11@240@3lQ03hm8@0m>b80>cTR03Xh8@0j>2<303Hh8P@0=CLQ00T0=3HP03<d900c=2@0<S<S034b
8P0`<B40;c0P02h_7`0];Qh00`0[;Qd402X]700302T/6`0V:Ah09RTN00H09RTN00P09b/L02HZ700T
:1X08RDJ028U700R9Ah08bDP02@V8@<08RDL00@08B@K020S6P0P8aX07b8I0P0N8AP301hQ6P<07B0I
2P0L7aP301`N6`806adJ0`0J71T201PN70<05adK0`0F71X201XL6`806A/J0P0H6QT201LI60P06A/J
200G6AP@01HG6@P05QPG200E5QP801HH5`P05QLI200E5QP201HG6@<05AHH0`0D5AL@01DF61405QLI
400E5QP801HG6@0501PI6`0G61X05QLI01DF600D5AL00P0E5QP00`0F5aT05AHH01DF600601DF60P0
5QLI600E5QP8018H64005AHH2@0C6AT801HG6@P05AHH200F61LH01HG6@/05QPG0P0E5aH301@F5@<0
5aTH0P0F61L301DG5PP05QPG400G6AP201HH5`<05aTH0`0H6QT:01TK6P8061XI00@05aTH01HH5`0F
61L05QPG200I6aX201LI608061XI0P0I6aX201XL6a406Q`I200K7AX201lO7@807QhL00@07AdK01`L
6P0L71X071`J100N7aT201lP6P80824K400O81X801dN600401lP6P0N7aT07QlI01hO6@807AhH0P0L
7AL801`L6P<07AdK0P0L71X301/K6@<071hK0P0K7AX;01XL6@P06Q`K200K7AX201XL6@<06adJ0`0L
7Q/801/M6PP06Q`I0`0I6aX201XL6`<06adL00<071hK01/M6P0K7AX00P0J71T201TK600301PJ5`0I
6aX06A/J00L06A/J0`0I6aP201XL6@<06adJ400K7A`801XL6`P05aTH400I6aX301/K6@8071`J0`0M
7A/201XL6@<06adJ0`0L7Q/801hP7A00824K0P0P81h201lO7@807QhL0P0M7A/301`N6`<06adJ0P0J
71T201/K6@<071`J0`0M7A/801`N6`P06adJ200J71T00`0M7a`071hK01`N6`0201/M6P<06Q`I00<0
6A/H01`L6P0L71X01P0L71X801hQ6P<071hK0`0K7AX201XL6@P07AdK0P0K6aT301`L6P<07AdK200L
7Q/801/M6Q006adL0`0I6aP[ooooo`00:_ooool30:EjA`80Y7U60`2SN4D20:Ug@P<0Z7I10`2WMD00
102LLcl0WWE10:5hA02SNTH20:ElB0030:AkA`2SNTH0XGI300L0XGI3202TNTP20:EjA`80YW]80P2W
O4T20:QmBPP0YWe900D0XGQ40:9iA@2UO4P0Z7m;0:V0C0020:Z1C@0:0:V0C02/Pdd0ZH1:0:MnB02X
OdT0[8==0:f4CP2ZPD/0Ygi80:YoBP80ZGi900@0Z7e80:MlA`2WO4L0Yga70P2VNdH0102XODP0ZGi9
0:UnB@2ZOdX20:^0B`80[85<202YP4`02`2_PT/0[X5:0:b1C02ZPDd0Z81<0:F0C02TOTd0Xgm=0:^0
C@2ZOd`0Z7e:0080Yga900H0Z7e:0:YoC02[P4d0Ygi80:QoB@2ZPD/20:^2C0030:Z1B`2XOdT0Ygi8
00@0Zh9<102ZPD/30:V4D080ZXEA0`2[QU880:Z5D080ZhI?00<0ZhIA0:^6DP2[QE@00P2[QEH0102[
QEP0Yh=90:R4BP2ZQT`20:b8CP040:^7C@2ZQT`0ZHE;0:j9E0<0[HQC0P2/Qe820:^6D@<0[XAB0P2]
Pe430:b2D0040:b2DP2[PE40Zh5A0:^1D@80ZX1@0P2YOdl0102XPdh0Yh9=0:AoBP2RODP20:5lA`0<
0:=nB@2TOdX0XWe60:5lA@2ONTD0WGQ409]eA02ILd@0Ug5209MaA02GLSh0V7<o0P2JMD40202IM400
Ug8n09A_>`2CKSX0V79309I`@@2CKCh0TF/l0P2?JCX00`2@JS/0TF/l09=Z?P02099Y?@03095X?02@
Ic/0SfHj0080SVDi00D0PV4^08=R;`25Hc<0QV@f08IT=`0208ER>00808=P=P22GcL0QF0c08AO<P23
GS40PE`_081K;P1oFRd2081K;P<0Ne@]0P1jDb`307UB:`<0LE4Z1@1bDR/00`1bD2X0Le4[07AB;002
07EC;@0807=A:`1aCbT0KddW06iB;@1]DB`0KU0/071?;01aCb`2075=:`0307=<:`1_BbL0Kd/W0080
L4`X0P1aCBT2079>:P0@07MD:P1fDbT0ME8X07EB:01fDbT0N5D[07YG;@1lFBl0NEH^07YG;`1kF300
O5Ta07eJ<P1nFc<0Oe`d081M=@80Oe/Y00<0Oe/[081K;P20Fbl00P21G3801021Fc@0OeX]085L;`22
GC0308AO<P0408=N<@22GC00QF0c08AO<P<0Peha00H0QF0c08MR=@28HcH0PUd`08=N<@24Gc8208EP
<`0408AO<P23GS40PUd`08QO<`<0Qehb0`26GC402@25G300NeTY07eK:`1oGBl0PElb085N=01oG3@0
OEXd07]H<P08089M<`80Oed]00@0OU`^07iL;`1nFc40OEXb0P1mFS@207]H<080O5Ta0P1mFS8207iK
<`0307mJ<01nFBl0O5L]0080NeH/00H0O5L]07iI;`1oFS00O5Ta07]H<01iERh307MD;080N5D]00<0
NEH^07IF;@1fERd01P1fERd207QH;`80MeL^101fERd02`1jFS40NET`07MG;P1eEB`0M5@[07EE;01g
Ebh0N5P_06mC:`1`E2`0LUH^0080M5P`00/0LUH^071D;01_Db/0LEH[075E;@1`E2`0Ke</06iB;@1]
D2h0KE0`06a?;`0206QC:00>06MA:01VD2L0IDlX06A>:@1TCB/0Hd`Z05i59`1MARL0GTHZ05]6:`1H
A2/0E48Z0510:@1>?RL80592:00805E2901E@BH0DT4U05519`1?@BL0CD4Y04e1:`1;@2X204a29`80
Bd4V00@0BT0U04To9019?b@0B3hS0P18@BD00`17@2@0ASlS04Dn8P0204@m8@0404<l8017?B80AcdR
04Lm8PD0B3hS00H0@c`P04<l8P13?280@c/T04<k9P14?2T204@k:P@0?3PO100k=ah203Tg8P80>3HQ
0`0g=B001`0f=1l0=cDP03Le800f=1l0=C<N03<a700b<1/00P0a;aX202/[8@0302XZ800Y:Al0:2PN
00809RHL00<09BDK02DX7`0U:1l03`0U:1l302@U7@<09BHN0P0V9al01P0P8aX08B@K028U700S9Qd0
92LN02HY80809bXQ400S9Qd802@V8@D09BHQ0`0T9B0302@U7`809BHP0`0V9b4202LY6`0302PZ700Y
:ad0:R`N0080;2hP00@0;BlQ02l]800^;1l0:b`N0P0Y:ad00`0Z;Ql0:C0P02Xa8@0402/]7`@0:R`N
100a<ad2030b7080;c4K0P0h<ad0100i=1h0>SDO03`g8@0m>28203hi8`P0?CPR0`10>bD503lj90<0
@c`R0P12>b43044j800304Lm9016?2<0A3XQ0080@cTP00@0A3XQ04Hl8`17?B@0@cTN0`12>1d01`14
>Ql0AcdR04Y09@1<@RL0A3dP04Dn8@16?b800P18@B@00`16?b80AChQ04@m800803lk7P80?C`N00L0
?3/M03Xi6`0j>A/0>STK03`k7@0o?R00@3lQ00D0A3PN0`13=ad00`0m>A`0?SXM040l7`02044m8006
040l7`0n>Qd0?CTL03df6P0o>1`0@3TM0P12>al01010>Ad0?cPL03df6P0n>R4303di8080?3PO0P0k
=ah3044j8080@3TO0`0o>1h01@12>al0@CXN044j7P10>Ad0?cPL0080?SLK00<0?CHJ03hg6`0n=a/0
1P0n=a/804<i7P0404<l8012>al0@S/O044j7P80@3TM0P0o>1`0200n=ad0?cPN044j8012>b40@c`R
048k8@11>R00@3TO0`0n>Ql303lk8080@3`Q00H0@3TO044j8011>R00@S/Q04<l8P14?B<204Dn9008
04508@10?b00?chP03dl800k>B00>SPQ03Tg800h=R4603@h8@80<cLP00H0<c@V038c9@0b<bD0<34S
02l`8P0^;b4202d^80H0:RdL0P0Y;1/802HY7P0802L[700V:Q`092PJ028U6P0R9A`08RDN02<U800T
9R43028U7004024T6`0P8aX082<J01lR6@807R4H0`0O8Q/201hQ6P<07B0I200L7aP301`N6`806adJ
0`0J71T201PN70<05adK0`0F71X201XL6`806A/J0P0H6QT201LI60P06A/J200G6AP@01HG6@P05QPG
200E5QP801HH5`P05QLI200E5QP201HG6@<05AHH0`0D5AL@01DF61405QLI400E5QP801HG6@0801LH
6P0E5QP051DG01@E5`0E5QP05aPJ01XK7@0L7Al801DF60P05QLI600E5QP8018H64005AHH2@0C6AT8
01HG6@P05AHH200F61LH01HG6@X05QPG0`0E5aH301@F5@<05aTH0P0F61L301DG5PP05QPG400G6AP2
01HH5`<05aTH0`0H6QT:01TK6P8061XI00@05aTH01HH5`0F61L05ALF200I6aX201LI608061XI0P0I
6aX201XL6a406Q`I200K7AX201lO7@807QhL00D07AdK01`L6P0L71X06a/I01dN600301hO6@807b0J
0P0P8A/@01lP6PP07AhH100N7aT201dN608071dG200L71X301dM6`8071`J0`0K6aT301`N6`806adJ
2`0J71T801XL6`P06adJ0`0J71T201/M6P<071hK200K7AX801XL6@<06A/J0`0J71/201/M700401`N
6`0K7AX06adJ01XL6@806A/H0P0H6QL901TK6P<06A/H0`0J71T201/M6Q006adL200J71/801LI6100
6A/J0`0K6aT201`L6P<07AdK0`0J71T201/M6P<071hK200N81d@020Q6`80820N0P0O7ad201hN7080
7AdK0`0L7Q/201/M6P<06Q`I0`0K6aT201`L6P<07AdK200L7Q/801/M6PP06Q`I0P0M7a`0100L7Q/0
6adJ01/M6P0J71T301TK60P071`J200N8AX301`N6`806adJ0`0J71T801dM6`<06a/I0P0L71X301dM
6`P071hK200K7AX@01/M70<06A/H:oooool002[ooooo00<0WGQ309iiA02ONTD00P2QO4L01P2ONTD0
WWU409eh@`2PMD80XGI30:=hA@80Y7U600<0XgQ50:5f@`2PMD800`2SNCd20:Aj?P<0YG/o202TNDH0
102RNDD0WgI209ie@@2QN4@20:MnBP030:=jAP2MM400XWU50080XgY600<0Y7]70:ElB02UO4P00P2V
ODT80:ElB0050:AiAP2UNTL0YGY70:IkB02WO4T00P2XODX0102YOT/0Ygi:0:MnBP2WOTX20:QoB`<0
ZH1<0`2ZOdX30:UnB@<0Z7e80P2WO4T0102XODX0ZGi;0:UnB`2ZOd`20:^0C@040:MnBP2XOd/0Z7m;
0:V0C080ZX5=0P2[PTh00`2YOdd0ZX1>0:^1C`020:b2D0030:^1C`2ZP4h0ZGm=0080Z7m;0`2YP4`3
0:Z1C@P0ZH1800@0[8=?0:^2CP2[PTh0Zh9>0`2ZPDd00`2YP4`0ZhI?0:^6C`060:^6C`<0ZhIA0`2/
Qe820:f8D`80ZXE@0`2[QU430:b7DP080:f8D`2^RE@0[hYE0;2;EP2_RUD0[HQC0:Z5D02YQ4l80:j9
E@<0ZhIB0P2ZQE430:V4D0<0ZhI?0P2ZQDh30:V4C@80Yh=90P2VPTP0302UPDL0Y8160:=oA@2SOdD0
Xgi90:9mB02QO4L0X7]609iiA02LMd80VgI109Ye@0<0VWE100<0VGA009Qc?`2HLcl00P2GLSh01P2F
L4<0UW1109E_@02DKSd0Tfhj099]>080TF`e00P0Tfhj099]>@2AK3P0SfXf08iY=@2<Ic<0RfHb08YU
<@80R6@d0P27Hc<00`26HS80QF4a08EQ<@0208AP<00608EP<`25H3@0Q5lc089M<`20FS<0OeTd0P1m
Ec<207aI;`0707]H<01jEbl0N5D_07MC;`1fDS00ME4_07EE;`0207AD;P03079B;01aDB/0L50Z0080
KdlY0P1_CR/00`1^CBX0KD`Y06a;:00206]:9`0906Y99P1/BbP0KD`Y06i=:P1_CR/0KTdZ06e<:@1[
BRL0JTTV0080KDl[0P1^D2`0101_DBd0L58^071B;P1aDbl206m>9@07075@9`1bDBP0M5<Z07IE;01g
ERd0N5L^07EH;P0207MG;P0307UH;`1jEbl0OEL`0080OUL`00/0OU/a07eJ<01lFBl0O5T_07eJ<020
GC<0Pf0f08ER>025HcD0Q68d089P<P02085O<@03089P<P23HC<0Q68d0080R68e00<0Qf4d08IP<`25
Gc800P24GS400`23GC00QV4g08IQ=`0208EP=P@0Q5le00<0PUd`08=N<@24Gc800P25H3<00`24Gc80
Peha089M<003085N=0<0P5dc301oG380101nFc40OEX`07]H;P1jEbd207UF;00507YG;`1kF300NeP`
07aI<@1mFS800P1nFc<02`1oG3@0PE//081J:`1mF2/0NUP[07QG;01hF2l0NETb07QK<`1_DRP0LeH/
0080MUT_00d0M5L]07=F;01gFS00MeX`07YM<`1iFC00N5P_07MG;P1fERd0MED/07AD:`1cDbX0LU8Y
00P0MUH_201mEc0207IF;@0707MG;P1hF2l0MeL^07EE;01cDbX0LU8Y079E;@02075D;003071C:`1_
DRX0Ke8Z0080KU4Y00<0K4l_06]>;P1[CRh01@1[CRh0301NAR80GdLS06189P1PAbP0H4LY05i4:@1L
@RL0Fd4X05m8:@1MARL0FT<T05Q18P@0ESlP0P1E@R@305A18`<0Dd0R201@@RL0201>?RD0C3hT04Tk
8@16>R00A3XO04<l8013?R40AD0S0`16?2<404Dk8P0404@j8@13?280@c`R04<l8P80@S/Q0`11>R0:
03hf8@0303de800l=1l0>c<N0080>S8M00@0>C4L03La8@0g<B40=c4Q0P0f<20303D_7`80<BhO0P0`
;Ah01@0_;1d0;R/L02dZ6`0]:Q/0:2/R00<09bXQ0P0V:B0202DX7`<09bTN0P0V:1d402DW70P092DM
200S9Qd802@W7Q008B@K2`0S9Qd302@W7P809BPO0P0W:Ah202PZ7`<0:B/P00<0:R`Q02T[800Y:b00
0P0Y:b0202X/8@80:bdR200[;Al202h`8`0602la8`0_<R40<3<P034d7`0b=B00<SHO0P0b=1l203<e
80<0=3HQ00<0=CLR03Hh8P0f>2801P0f>2801P0f>a/0=cXK03Lj6`0i>Q/0>STK03`h6`80?CPK0P0m
>28203hi8`0703lj9010>bD0@3/U040k9@12?R<0@3`Q03lk800203hj7`03040l8@12?R<0A40U0080
@c`P1012>al2044j7PP0B3`R00P0?SLM03lh7P11>R00@S/Q04<l8P12>b40@CXP040i7`80@SPM0140
@cTN04Dk8016?240AS`Q04Dk8013>Ah0@SPM048g6`13>1`0@SPM040i7`0o>B40?cXT03dk900m>bH0
@cTP04@j8@0304Hl8`0404@j8@12>1l0@3HM044m8P80@3`Q00<0?c/P03hj7`0n>Ql00P0m>Ah803hg
7@P0?SXO200o>b0303hg7@0303lh7P10>Al0@CXP0080@CXP0`0o>b000`0n>Ql0?CTN03`h7@0203`h
7@0303/g700m>Ah0?SXO0080@3`Q00/0?SXO03di7P0k=a`0=cHJ03Th700l>1d0?cTO040i7`12>1l0
@SHN044e7@0304<l8080@S/O0`11>Qh204a19@0604]09019?R80B3dQ04Ll8016>al0ACXN0P11?1l2
040k7P<0?cXM00D0?STL03Pj9@0f>2<0=3HQ038d7`02034c7P05038d7`0c=B00<S@V034c9@0_<B<0
0P0];b400`0^<280;c4S034c9@0202d_8@0402`^800[;Al0:R`N02X/7P80:B/M00@0:R`Q02T[800Y
:b00:B/P0P0X:Ql202LY7P809BPO0P0T9ah402<V7@@08B@M0P0P8a`301lR6`P07R0M2`0L7Q/201/M
6P<06Q`I2P0J71/201TK6P8061XI2P0G6AP@01HH5a005AHHB@0F5aT301@E5`<05AHH2P0F5aT801DF
60P05QLI200F61L801HG6@P05AHH200F61LH01DF6003010A4`0C51H05AHH00805QLI00<05aPJ01PI
6`0J6ad0600E5QP801HG6@<051DG0`0E5QP201HG6@P05AHH6@0F5aT801HH5a005QLI200F61LH01HG
6AP05aTH200D6QPJ01LI608061XI0P0I6aX201XL6`P06a/I0`0J71T301/M6P/071hK200L71X201dN
60807QlI0P0O81X4020Q6`807b0J0P0N7aT201dN60P07alM200N7Q`301`N6`806adJ0`0J71T801/M
6P<071hK0P0K7AX301XL6A006Q`K0`0I6aP301XL6@806adJ200L71X801/M6PP06Q`K200K7A`@01TK
6P806adL0`0J71/401TK6PP06Q`K200K7AX:01/M70806Q`K100I6aX801PJ6@X05aTH0P0H6QT201TK
6P806Q`K400L7Q/201/M6P<071hK0`0M7a`2020R7`807b4N100N81d8020R7`<07AlL0`0L7Q/201/M
6P<06Q`K0P0K7A`301`N7@P06adJ0`0M7a`301`N6`806adJ400J71/901XL6@P06adJ200M7a`801`N
6`<06Q`I0P0K7AX;01`N6`<071hM0P0K7A`301XL6`P061hL200J71/;01TK6R_ooooo000Zooooo`03
09eh@`2NND@0WgY50080XGa700H0WgY509iiA02MN4<0XGI30:=hA@2TNDH20:EjA`030:AiAP2SN4D0
XGI300<0XgTo0P2TNT030:Ek@@P0Y7U600P0XWU509mf@P2OMT80XWU50:ImB@2WOTX0XgY609ie@@<0
XgY600<0Y7]70:ElB02UO4P00P2VODT80:ElB0@0YW]8102WO4T30:MnBP<0Z7m;0P2YP4`30:YoBP<0
ZGi90`2XODP00`2WO4T0Z7e:0:QmBP020:UnB`80ZWm<00D0Zh1=0:QoB`2XOd/0Z7m;0:V0C0020:Z1
C@80Zh9>00<0Z7i<0:Z0CP2[PDl00P2/PU000`2[PDl0ZX1>0:QnC0020:QoB`<0ZH1<0`2ZPDd80:V0
B0@0ZX5=102[PTh80:^6C`<0ZXE@0`2[QU420:b7DP<0ZXE@0P2[QU430:b7DP030:^6D@2/Qe80[HQC
0080[XUD00<0[8MB0:Z5D02YQ4l0202^RED30:^6DP<0ZXEA0P2YQ5030:^6C`80ZXE>0`2YQ4d01P2X
Q4X0Yh=90:N3B@2VPTP0YH570:B0AP80Xgm50P2SOTT01P2QO4L0X7]609iiA02MN4<0W7M209]f@@80
VgI200@0VWE109Ud@02IM400V7<o0P2GLSh03P2FL4<0UW1109E_@02DKSd0Tfhj099]>02BKCH0TF`e
09=^>P2BKCT0TF`h091[=`2>JCD0S6Lc0P2;IS801@29ICD0R6@d08QT=027Hc<0QV8b0080QF4a0P24
H3003P26HC@0QF0c08AO<`22GC<0PE/d07mI=01nF3<0OELc07eK;P1lFBl0NeP^07YG;`1iES00Me<_
0P1fDS0207EE;`0707AD;P1cDbd0LU8/075A:`1`D2X0KdlY071?;00206m>:`0306i=:P1]C2T0K4/X
0080JdXW00<0K4/X06e<:@1^CBX00P1_CR/00`1]C2T0JdXW06Y99P0306Y<:080JddY00<0K4hZ06e?
:`1]Cb/00P1aD2L0101bDBP0Le8Y07ED:`1fEB`207MF;@0607EH;P1gEbh0MeL^07UH;`1jEbl0O5H_
0P1nEc0207iK<@0>07eJ<01lFBl0OEX`07mL<P21GS@0Pf0f08ES=@23HC<0PV0b085O<@20GS00PEla
08=Q<`24HS@208MQ=0<0QV0c0`25Gc8208IQ=`80QF0f0`24GcD01023GS@0PUd`08=N<@24Gc8208EP
<`0308AO<P23GS40PUd`00<0PEhd0`20GC<207mL<P80OU/a101oG383081M<`80Oe`b00D0OU/a07aI
;`1kF2h0NeP^07YG;@0407aI;`@0OEX`00h0PE//081J:`1mF2/0NUP[07QG;01hF2l0NETb07QK<`1a
E2X0M5L]07MJ<01fFBl0LeH/079E:`80MEP^00L0NE`b07QH;`1hF2l0MeL^07IF;@1eEB`0M5@[0080
Le<Z201fERl807]H<00907EE;01fERd0MeL^07QH;`1gEbh0MED/07=C:P1bDRT0LUD]0080LE@/0P1`
Db/206mB:P0406iA:@1/Cbl0K4l_06a?;`@0Jdh^00d0JTd]0618901PB2@0HDTW0658:@1PAbT0GTDW
05a29`1J@2D0GDHW05]49@1I@R<0Ed0Q0080ESlP0P1G@24305E29080E44S0`1C@28804m19P0804hn
9@1=?B@0BS`R04Hj8015>b00@c`P04Dn8P15@2<204Lm9080AS`S00@0AC/R04@j8@14>R40@cTP0`13
?282048k8@<0@CXP200o=b8203hf8@0403de800l=1l0>c<N03/c7P80>S8M00@0>38R03La8@0g<B40
=c4Q0P0f<20203D_7`06038_800a;Ql0<BhO030]7P0_;1d0;R/L0P0]:Q/202P[80809bXO0`0V:Ah0
100U:1d09bTN02LY7P0W:Ah302HX7@<09BLL200T9Ad802<V7@P092LN400Q91/;02<V7@<092LN0P0U
:1l202LY7P80:2XO100Y:b00100X:Ql0:B/P02T[800Y:b0202X/8@80:bdR200[;Al0200];b80;S0S
02h`8P0_<R40<3<P034d7`0b=B00<SHO0P0b=1l203<e80@0=3HQ200f>2801P0f>ad0=cXM03Lj7@0i
>Ad0>STM03`h7@80?CLM1@0n>B<303lj9008040l8@0o>b00?SXO03di7P0n>Ql0?c/P044m8P12?R<8
048k7`P0Ac/Q00<0?SLM03lh7P11>R000P13?2800`12>b40@CXP040i7`02048h7@0704<i7P15>b00
AS`Q04Hl8@15>b00@cTN048h7@0204@i7@0>04<i7P11>R00@3XR03lj900m>b@0?C/V044j8012>b40
@c`R04@m8`13?280@S/Q040i7`0n=ad2040l8@80?c/P0P0n>Ql203di7PP0?SLM200n>Ql803lk8080
?SLM0P0o>1h2040i7`80@CXP0P0o>b0203hj7`80?CTN0`0l>1d03`0m>Ah0?SXO03lk800o>b00?SXO
03di7P0l>1d0>3LK03Th700m>Ah0?cTO044j8012>1l0@SHN044e7@08048k7`0804a19@1;@2@0BSlS
04Tn8P17?200AS/O04Dj7P14>Ad3040j8080?cTO0`0n>1h0100g>B@0=SPS03@f8@0b=1l2034c7P05
038d7`0c=B00<S@V030b900^<2800`0/;R001`0];b40;S0R02d_8@0];b40;2hP02/]7`0Z;1h00P0Y
:ad00`0X:Q`0:B/P02T[800202T[8080:2XO0P0W:Ah202DX7`8092LN0`0S9Qd00`0R9A`08B@M024T
7@02024T7@8082<L0`0O8Q/801hP7@/071hK0P0K7AX301XL6@X06Q`K0P0I6aX201PJ6@X05aTH400F
61L@01DF64T05QLI0`0D5AL201DF60/05QLI200E5QP801HG6@P05QPG200F5aT801DF60P05QPG600E
5QP0100C51H05AHH01HG6@0C51H2010A4`0301DF600J6ad05AHH01L05AHH200F5aT301@E5`<05AHH
0P0F5aT801DF61T05QLI200F61L@01HG6@P05QPG600F5aTH01LI60P051XH6P0G6AP201PJ6@806A/J
0P0J71/801/K6@<06Q`I0`0K7AX;01`N6`P071`J0P0M7QP201hO6@807b0J100P8A/201lP6P807QlI
0P0M7QP801lO7@P07QhL0`0L7Q/201/M6P<06Q`I200K7AX301`N6`806adJ0`0J71T@01XL6`<06A/H
0`0J71T201/M6PP071`J200K7AX801XL6`P06adL400I6aX201/M70<06Q`K100I6aX801XL6`P06adJ
2P0K7A`201XL6`<06A/J2@0H6QT:01LI608061XI0P0I6aX201XL6a0071hK0P0K7AX301`N6`<07AlL
0P0P8Ql201lQ7P<07R0M00<07AlL020R7`0P8Ql01P0P8Ql301dO708071hK0`0K7AX301XL6`806adL
0`0L7Qd801/M6P<07AlL0P0L7Q/301/M6Q006Q`K2@0J71T801/M6PP07AlL200L7Q/301XL6@806adJ
2`0L7Q/301`N7@806adL0`0J71/801PN70P06Q`K2`0I6aX[ooooo`00:_ooool00`2MN4<0WWU409mj
A@020:5lA`0609mjA@2NND@0WGQ30:=hA@2TNDH0YGY70P2WO4T00`2UNTL0Y7U60:=hA@030:=i?`80
Y7Y00`2UNd480:AiAP080:9iA@2PMd<0X7M30:9iA@2UO4P0YWe90:=jAP2PMd<20:=jAP<0Y7]72`2U
O4P40:MlB@@0YW]80P2VODT20:MnBP<0Z7m;00@0ZH1<0:YoBP2ZOdX0ZWm:0`2YOTT30:QmB0<0Z7e:
0P2YOT/30:YoC080Z7m;0`2YP4`30:Z1C@030:QnC02YOdd0Zh5?0080[89@00<0Zh5?0:UoC@2XOT`0
0P2XOd/30:V0C0<0ZX5=202YP4X01@2XOd/0ZH1<0:V0C02ZPDd0Zh9>0080[8=?00<0[HA@0:^6D@2[
QU401P2[QU420:R3CP<0ZHA?0`2ZQE00102YQ4l0ZXE@0:Z5D02ZQE020:^6D@80[8MB00<0Z8=>0:V4
C`2ZQE000`2/Qe800`2[QU40ZXE@0:f8E0070:f8E080[8MC0P2[QU830:Z5D@040:V4D02[QU40ZhIA
0:^6D@80ZXE@0`2YQ4l20:R3C0030:N2B`2VPDX0YH190080Y7m800T0Xgi70:=nB@2SOTT0XWe80:5l
A`2ONTD0WWU409eh@`2LMd800P2LMd<0102KMT80VWE109Ud@02HLcl209Mb?P0609I`@`2FL440UFm0
09E_?P2DKc/0Tfhi0P2BKCH01P2CKSX0TVdi095/>02@JcL0SVTe08eX=080S6Lc00D0RVHf08UU=@29
ICD0R6@d08MS<`0208IR<P80QF4a00H0QV8b08EQ<@24Gc80Pehb085L<P20FS<207mI=00607iL;P1n
G2l0OE/^07]H;P1jEbl0N5D_0P1gDbl207EE;P0407AD;@1cDb`0LU8[079B:`80LE4Z0P1`Cb`00`1_
CR/0KTdZ06e<:@0206a;:00306]:9`1]C2T0KTdZ00<0Kdh[00<0KD`Y06a;:01ZBBH00P1WBBD206Q:
9P@0JD/W00<0LU8Y07=C:P1cDbX00P1dE2/307EE;00:07AG;@1fERd0MeL^07QG;P1jEbl0O5H_07eF
;`1nEc00Oe`b07iK<@@0OEX`0P1oG3800`23HC<0PV0b085O<@02081N<003085O<@22H380Q68d00<0
Q5lb0`25H3<208IQ=0<0QF0f0P24GcD308=N=003089M<023GS40Q5lb0080QF0c00<0Q5lb08=N<@22
GC000`21GS@3081M<`80Oe`b0P1mFS00101nFc40Oe`b07mL<P20GC<3085N=080P5dc00D0Oe`b07iK
<@1mFS00OEX`07aI;`0407eJ<0@0O5T_00h0PE//081J:`1mF2/0NUP[07QG;01hF2l0NETb07QK<`1c
ER`0MUT_07QK<@1gFS00LeH/075D:P80LeH/00H0MUT_07QH;`1gEbh0MeL^07IF;@1eEB`207AD:`03
07=C:P1fERl0MUH_00H0MUH_201jEbl0201eEB`0MUH]07MG;P1hF2l0MeL^07IF;@1dE2/0Le<Z101a
E2`2071C:`80Ke8Z0P1]D2h206a?;@80Jdh/0P1ZCB/02`1RBR@0Hd/U06=;9`1RBRP0HDPY05i59`1K
@R@0FClT05Y3901I@R<0Ed0Q0080ESlP00@0Ed0Q05Q18P1I@R<0ET<U0`1E@R@205A18`80Dd0R201?
?bD03P1??BD0CCdT04`l8`1:?280Ac/Q04Hl8@15?R80ASlS04To9P18?RD0AcdT04Hl8`15>b80@cTP
0P12>1l304<l8P80@S/Q0`11>R08040h8`0603lg8P0n=R40?SHQ03de800l=1l0>c<N0P0j<Qd303Pc
8080=c8O0`0f<Ah01P0c<240<RlP038_800a;Ql0<2dN02l/7@80;R/L00@0:R`Q02T[800Y:b00:B/P
0P0X:Ql202LY7P80:2XO0P0W:Ah302HX7@809BLL200T9Ad802<V7@P092LN200R9A`8024T6`/08bHM
0`0T9ah202DX7`<09bTN0P0X:Ql302T[80<0:2XO0P0Y:b0302X/8@P0:bdO0P0];b800`0^<280;c8Q
030c8002034d7`04038f7`0b=1l0<S@O038d7`80<cDP0`0d=R4803Dg8@0603Dj700f>A`0=STL03Ph
700i>1`0>cLL0P0l=Q`403hi8`@0?CPR0P0m>Ah303`h7@0303hj7`0o>b00@3`Q00P0@S/O2015>b00
0`0n=ad0@3TO044j800304<l8P06048k8@11>R00@cTN04<i7P14>Ql0AC/P0P16?2400`15>b00A3XO
04<i7P0204Dj7P0604@j7`12>b40@C/S040k9@0n?2D0?S`W0P11>R03048k8@03044j800o>1h0?SLM
00<0?c/P0`0n>Ql203di7PP0?SLM400n>Ql0100n=ad0?cPN03lh7P0o>1h3040i7`03044j800o>b00
?SXO0080?SXO0`0m>Ah203`h7@0@03di7P0n>Ql0?c/P03lk800n>Ql0?CTN03`h7@0h=a/0>STM03di
7P10>R00@CXP04<i8013=al0@SHN040i7@80@CXN00d0@S/O04<l8014?B40A3dQ04Dn8P1:@2D0BClT
04Pn8`17?B80AC/P04@j7`13>Ah0@SPM00<0?SXO0P0m>Ah303`h7@0603Hh8`0e=b80<cDP038d7`0a
<ah0<38M0P0a<ah0100a<bD0;c4S02h`8P0/;R0402X/7P0602d_8@0/;R00;2hP02/]7`0Z;1h0:B/M
0P0X:Q`302T[8080:2XO0`0W:Ah302@W7P808bHM0`0R9A`4024T7@8082<L0`0O8Q/801hP7@/071hK
0P0K7AX301XL6@X06Q`K0P0I6aX201PJ6AX05aTH400E5QQ901HG6@8051DG0P0E5QP301HG6@0301LH
6P0F5aT05QLI00H05QLI200E5QP801HG6@P05QPG200F5aT801DF60P05QPG6@0E5QP00`0F5aT05AHH
018C5@0200l@4P0301@E5`0H6A/05AHH01L05AHH200F5aT301@E5`<05AHH0P0F5aT801DF61T05QLI
200F61L@01HG6@P05QPG600F5aTH01LI60P051XH6P0G6AP201PJ6@806A/J0P0J71/801/K6@<06Q`I
0`0K7AX;01`N6`P071`J0P0M7QP201hO6@807b0J100P8A/201lP6P807QlI0P0M7QP801lO7@P07QhL
0`0L7Q/201/M6P<06Q`I200K7AX301`N6`806adJ0`0J71T@01XL6`<06A/H0`0J71T201/M6PP071`J
200K7AX@01XL6a006A/J0P0K7A`301XL6`@06A/J200J71/801XL6@/06Q`K0P0I6aX;01PJ6@X05aTH
0P0H6QT201TK6P806Q`K400L7Q/201/M6P<071hK0`0M7a`301lQ7P807R0M0`0M7a`801lQ7P807AlL
0P0L7Q/301/M6P0401XL6@0J71/06Q`K01XL6`806adL0`0L7Qd801/M6P807AlL0P0L7Q/301/M6P03
01XL6@0J71/06Q`K00h06Q`K2@0J71T801/M6PP07AlL200L7Q/301XL6@806adJ2`0L7Q/301`N7@80
6adL0`0J71/801LM6`P06Q`K2`0I6aX[ooooo`00:_ooool00`2MN4<0WWU409mjA@020:5lA`0609mj
A@2NND@0WGQ30:AiAP2UNTL0Yga90P2XODX00`2WO4T0YGY70:AiAP030:=h@@80Y7U20`2UNT<80:Ai
AP040:9iA@2QN4@0XGQ40:9iA@<0Y7]700<0XgY60:AkA`2TNdL0102TNdL:0:ElB0050:UnB`2XODX0
Z7e:0:MlB@2VNdP00P2UNTL0102TNDH0YWe90:ImB@2VODT20:MnBP<0Z7m;0`2ZOdX30:UnB@<0Z7e8
202YOT/60:V0C080ZX5=00<0Z7i<0:UoC@2ZP4h00P2[PDl00`2ZP4h0ZGm=0:QnC0020:QoB`<0ZH1<
0`2ZPDd80:V0C0080:MnBP2XOd/0ZH1<0:Z1C@2[PTh0[8=?0:f4D02^QE480:Z5D@80Yh9=0`2XPdh5
0:V4C`<0ZXE@0`2[QU420:N2C@030:R3CP2YQ4l0ZXE@00<0ZhIA202]R5@30:b7D`80ZhIB0`2ZQE43
0:^6DP80ZXEA0`2YQ5020:R3CP040:N2C@2VPD`0YX5<0:F0B`<0Y7m:00D0Xgi90:9mB02QO4L0X7]6
09mjA@0209iiA00>09iiA@2MN4@0W7M309]f@P2JMD40VGA009Qc?`2GLSh0Ug5409Ma@P2FL440UFln
09A_>`2CKST2099]=P80TVdi00@0TF`h091[=`2?JSH0SVTe0P2=J3@208YV=P80RFDe00<0R6@d08MS
<`27Hc<00P26HS802026HS00QF4a08EQ<@24Gc80PUda085L<P21Fc@0P5Xc0P1oGBl01P1nG2l0OE/^
07]H;P1jEbl0NEH`07QE;`<0MED/00<0M5@[07=C:P1cDbX00P1bDRT2075@;@03071?;01_CR/0KTdZ
0080KD`Y00T0K4/X06e<:@1^CBX0Kdh[071?;01_CR/0KTdZ06a;:01[BRL01P1YBbL206Y<:0P0LUD[
00H0M5L]07IF;@1fERd0N5L^07UF;P1lERl207eF;`80OU/a0P1mFS0407aI;`03089P<P21Gc40P5h`
0080Oed_00@0P5h`089P<P23HC<0P5h`0P21Gc400`22H380Pf4c08AR=00208ES=@80QF0f0`24GcD3
08=N=003089M<023GS40Q5lb0080QF0c00<0Q5lb08=N<@22GC000`21GS@3081M<`80Oe`b00@0O5T_
07eJ<01nFc40OU/a0P20GC<01021GS@0PUle085N=021GS@2081M<`80Oe`b0P1nFc401@1oGC00OU`_
07iL;`1mFbh0O5X]0080NeT/00l0NUP[085K;020FR/0OEP[07YH:`1hEb`0N5P_07UI<P1hFc<0MEP^
07QK<@1jGC<0MeX`079E:`1`DbT00P1bEB/00`1dEbd0MeL^07MG;P0207IF;@80MED/0P1dE2/807IF
;`P0N5L^00<0M5@[07EE;01fERd00P1gEbh00`1fERd0M5@[07=C:P06075D;080L5<[0P1^DRd0101]
DB`0K50[06a@:`1[CbX206Y>:@80IDhU00P0IDdW06A<:01RBRP0GTDV05]2901I@280F44R05M08@80
ESlP00@0Ed0Q05Q18P1J@b@0G4DV0P1F@bD305E290<0E44S201@?bD01P1A?BD0CcdU04hl901<?2<0
BcdS04Tm8`80B3hS0P19?bH01P17?B@0AS`S04@j8@13>B00@SPO044g7P<0@c`R0P12>b43044j80P0
@CTT0P0o=b800`0n=R40?CDP03`d7`0203/c7P0403Xb7@0i=200>C@P03Td8080>3<O0`0g<Qh203<`
8@80<RlP00@0<BhO030]7P0_;1d0;b`M100[:al202XZ7P80:BTM0`0X:Ql202LY7P@09RPM200U9Qh@
02@W7PP08RDL200Q91/;02<V7@<092LN0P0U:1l202HX7@809bTN0P0X:Ql202T[80<0:2XO0`0Y:b02
02X/8@P0:bdO0P0];b801P0^<280;c8Q02lb7`0`<ah0<C@O034e7P80<C<N0P0b=1l203<e8080=3HQ
200d=R001P0d>1d0=CPM03Dh7@0g=ad0>3HM03Xf7@80>cDM0`0n>B<01@0m>280?3LQ03`g8@0l=b40
>cHP00@0>cLL0P0l>1d0100m>Ah0?SXO044j7P11>Qh4048k7`80@c`P2011>Qh0200o>1h0@3TO048k
8@13?280A3dS04<l8P12>b40@CXP0P13>Ah03`14>Ql0AS`Q04Lm8P17?B80AS`Q04@j7`13>Ah0Ac`P
04Hk7`15>b00@c`R048l9010>bD0?S`U03hl9`04040j800403li7`0n>1h0?SPN03dg7@H0?SXO0P0m
>Ah803hg7A00?SXO100o>1h4040i7`@0?SXO1P0m>Ah403hj7`80?CTN00P0>CPL03/j7P0n>Ql0@C/Q
048k8@14>R40A3PP04<g7`80@3TM00@0@CXN048k7`14?B40AChR0P16?b<204Ho9@0604Dn9013?280
@S/Q044j8010>Al0?cPN0P0k>B0203Xh7`@0>CLN0P0d=R400`0c=B00<S@O034c7P02030b7@0602la
700_<B<0;S0R02d_8@0[;Al0:B/M0P0X:Q`0100W:A/0;2hP02`^800[;Al202X/7P0302T[7@0X:Q`0
:2XL0080:B/P0P0X:Ql202LY7P809RPM0P0T9ah302<V7@<08RDL100Q91d2020S70<07b8K200N81d;
01`N6`806adJ0`0J71T:01XL6`806A/J0P0H6QTJ01LI65T05QLI0`0E5QP301HG6@805aPJ600F5aT8
01HH5`P05QLI200E5QP801HH5aP05AHH00P05QLI01<D5P0B4aD05AHH01/L7P0M7R006AXL01@E5aP0
5AHH200F5aT301@E5`<05AHH0P0F5aT801DF61T05QLI200F61L@01HG6@P05QPG600F5aTH01LI60P0
51XH6P0G6AP201PJ6@806A/J0P0J71/801/K6@<06Q`I0`0K7AX301`N6`P06adJ200L71X201dN6080
7QlI0P0O81X4020Q6`807b0J0P0N7aT201dN60P07alM200N7Q`301`N6`806adJ0`0J71T801/M6P<0
71hK0P0K7AX301XL6A006Q`K0`0I6aP301XL6@806adJ200L71X801/M6R006Q`K0P0K7A`301XL6`@0
6A/J200J71/801XL6@X06Q`K0`0I6aX;01PJ6@X05aTH0P0H6QT201TK6P806Q`K400L7Q/201/M6P<0
71hK0`0M7a`201lQ7P<07R0M0`0M7a`801hP7@<071hK0`0K7AX201XL6@<06Q`K0P0K7A`301`N7@P0
6adJ0`0L7Q/301/M6P806Q`I400J71/901XL6@P06adJ200M7a`801/M6P<06Q`I0P0K7AX;01`N6`<0
71hM0P0K7A`301XL6`P05adK200J71/;01TK6R_ooooo000Zooooo`0309eh@`2NND@0WgY50080XGa7
00H0WgY509iiA02MN4<0Y7U60:EjA`2WO4T20:QmBP030:MlB@2UNTL0Y7U600<0XgQ30P2TND@30:Ej
A@P0Y7U600<0XWU50:=jAP2SNTH00`2SNTH0102TNdL0YWe90:ElB02UO4P>0:AkA`050:UnB`2XODX0
Z7e:0:MlB@2VNdP00P2UNTL00`2TNDH0YGa80:ElB0020:ImB@80Ygi:0P2XOd/30:YoBP<0ZGi90`2X
ODP80:UnB`80ZX5=1P2YP4`00`2WOD/0Z7i<0:Z0CP020:^1C`030:Z0CP2XOT`0Yge;0080Z7m;0`2Y
P4`30:Z1C@P0ZH1<00P0Ygi:0:QoB`2YP4`0ZX5=0:^2CP2/Pdl0[HA@0:j5D@P0ZXAC0P2WPTd30:R3
CPH0ZHA?0`2ZQE020:^6D@<0Z8=>0P2YQ4l00`2[QU40[8MB0:b7DP080:b7D`80[HQD0P2/Qe<20:^6
DP80ZXEA0`2[QE@20:Z4D`<0ZH=B0P2YQ4l0102XPdh0Yh9=0:J1C02UP4/30:AoBP80Xgi900<0XWe8
0:5lA`2QO4L00P2PNdH209mjAP0<09iiA@2LMd<0VgI209Ud@02HLcl0Ug8n09MaA02GLD80UW1109E_
?P2EL3`0U6lj0P2CKSL2099]>@04095/>02@JcL0T6/g08mZ=P80SVTe0P2;IcL00`2:ISH0RFDe08QT
=00208QT=080Qf<c00H0QV8^08IR<025HBl0Q60`08AO<P23GS82089M<`06085O;`20GRh0Oed_07iL
;`1lFBl0NeP^0P1jEbl00`1fEb/0MEHZ07EF:P0207EF:P<0M5DY0P1bDBh00`1aD2d0L4l/06m>:`02
06i=:P0306e<:@1^CBX0Kdh[00<0L4l/00<0KTdZ06a;:01[BRL00`1]Cb/506a>:PP0L5DZ00H0LeH/
07EE;01fERd0MeH]07UF;P1kEBh207eF;`@0OEX`0P1lFBl207]H;P03081N<01oGBl0OU`^0080OU`^
00@0P5h`089P<P23HC<0Oel`0P20H3400`21HC80PV8c08=S=00208AT=@<0Q5le0`23GS@2089M<`03
089M<023GS40Q5lb0080QF0c00<0Q5lb08=N<@22GC000`21GS@3081M<`80Oe`b0P1mFS00101nFc40
Oe`b07mL<P20GC<2085N=0@0P5dc101oG3801@1oGBl0OU`^07iL;P1mFbd0O5X/0080NeT[00l0NUPZ
085K;020FR/0OEP[07YH:`1hEb`0N5P_07UI<P1hFc<0MUT_07UL<P1jGC<0MeX`079E:`1_DRP00P1a
E2X00`1dEbd0MUH]07IF;@0207IF;@@0MED/201fERl807IF;@0307=C:P1dE2/0MUH]0080MeL^00<0
MUH]07EE;01dE2/01P1aE2`2079E;@80Ke</00@0KU8[06eA:P1/D2T0JdlX0P1ZCRL206M@9P0806M@
9`1UCBL0Hd/W06189P1MA2D0Fd8S05U28`1H@B8205M08@0405Q18P1J@b@0G4DV05i7:0<0ET<U0`1E
@R@205A18`P0D3lU00H0DS`U054m9@1??BD0CcdU04hn9@1<?R@204Tm8`80B3hU00H0AcdT04Hl8`15
>b80A3XQ04<i8012>1l304<l8P80@S/Q0`11>R08044i9006040h8`0o=b80?cLR03hf8@0m=B00?3@O
0P0k<ah303Xe8@80>C@P0`0h<al203@a8P0403<`8@0b;b00<BhO034^7`80<2dN0`0^;1l302d[7P80
;2XM0P0Y:b0202PZ7`809bTN0`0V:1d802DV7Q0092LN200S9Qd8024T6`/08bHM0`0T9ah202DX7`<0
9RPM0P0W:Ah302PZ7`809bTN0`0X:Ql302T[80P0:bdO0P0/;R401P0];b40;S4P02lb7`0`<ah0<C@O
034e7P<0<C<N0P0b=1l303<e80P0<cDO00H0<cLN03@f7P0d=Qh0=SHN03Le7P0i=1h203Xd7PD0?3LQ
0`0k=R0203Xf6`0303/g700l>1d0?3PM00<0?3PM00<0@3TM044j7P11>Qh00P12>al204<l800304@m
8@10>ah0@3/N00H0@3/N00<0?cPN040i7`12>b400`14?B<01P13?280@S/Q04@j7`14>Ql0AC/P04Hl
8@80AcdR00<0AS`Q04Dk8014>Ql00P17?2001`15>b00@c`R044k8`0o>R@0?C/T03dk9P0o>b000P0n
>Ql00`0m>Ah0?3PM03`h7@0203`h7@H0?CTN0P0n>Ql803hg7@P0?SXO200m>Ah4040i7`@0?cPN100m
>Ah603hj7`@0?CTN0P0n>Ql05P0j>Ad0>cXN03lk8012?280@c`R04Dk8P15>B40A3PP040i7@11>Qh0
@S/O04<l8014?B40AChR04Ho8`17@2@0A3hV04<m9@12?2@0@C/S040j8P0n>20203dg7`@0>3PP0P0g
=al203Hf7P0603<e800b=1l0<S@O034c7P0`<Qd0;c4L0P0^<1/202d_8@0402`^800[;Al0:R`N02T[
7@809bTK0P0/;R00100[;Al0:R`N02T[7@0X:Q`202LY6`<0:2XO0P0W:Ah302HX7@<08bHM0`0R9A`2
024T6`@08B@M0P0P8a`301lR6`P07R0M2`0L7Q/201/M6P<06Q`I2P0J71/201TK6P8061XI2P0G6AP@
01PJ6ET05QLI0P0E5QP301HG6@<05aPJ600F5aT801HH5`P05QLI200E5QP801HH5aP05AHH00P05QLI
010A4`0?41806a`N02`];`0_<380824S010A4aP05AHH200F5aT301@E5`<05AHH0P0F5aT801DF61T0
5QLI200F61L@01HG6@P05QPG600F5aTH01LI60P051XH6P0G6AP201PJ6@806A/J0P0J71/801/K6@<0
6Q`I0`0K7AX301`N6`P06adJ200L71X201dN60807QlI0P0O81X4020Q6`807b0J0P0N7aT201dN60P0
7alM200M7A/301`N6`806adJ0`0J71T801/M6P<071hK0P0K7AX301XL6A006Q`K0`0I6aP301XL6@80
6adJ200L71X801/M6R006Q`K0P0K7A`301XL6`@06A/J200J71/801XL6@P06Q`K0`0I6aX301PJ6A@0
5aTH0P0H6QT201TK6P806Q`K400L7Q/201/M6P<071hK0`0M7a`301hP7@<07AlL0P0L7Q/801dO7080
71hK0`0K7AX301XL6@<06Q`K0P0K7A`301`N7@P06adJ0P0L7Q/301/M6P<06Q`I400J71/901XL6@P0
6adJ200L7Q/801/M6P<06Q`I0P0K7AX;01`N6`<071hM0P0K7A`301XL6`P05adK200J71/;01TK6R_o
oooo000Zooooo`0309eh@`2NND@0WgY50080XGa700H0WgY509iiA02MN4<0XgQ50:AiAP2UNTL20:Ml
B@030:EjA`2TNDH0XgQ500<0XgQ50P2TNDH30:EjA`P0Y7U600P0XWU50:AkA`2UO4P0XgY60:5hA02R
NDD0YGa80:QoB`<0YGa80`2TNdL20:=jAPP0Y7]7102WO4T40:IkB0<0YGa80P2VODT30:MnBP<0ZWm:
0`2YOTT30:QmB0<0ZWm<0P2YOT/30:QmBP<0ZX5=0`2YP4`20:QoB`030:MmB`2XOT`0ZGm=0080ZX1>
00<0ZGm=0:QnC02WOD/00P2XOd/30:V0C0<0ZX5=202YOdd01@2XOd/0ZH1<0:V0C02ZPDd0Zh9>0080
[8=?00<0[HA@0:V3E02YPe@01P2YPe@20:R3CP<0ZHA?0`2ZQE020:R3CP80ZHA?0`2ZQE020:^6D@07
0:Z5D02YQ4l0ZHA?0:V4C`2[QU40[8MB0:f8D`080:b7D`<0[HQD0P2/Qe<30:^6DP<0ZhEF0P2ZQ5D3
0:V3E080ZHA@00@0Z8=?0:N2CP2VPDd0YX5=0P2UP4`20:AoBP80Xgi90P2RODP20:5lA`060:5lB02P
NdL0WgY609ehA02KMT80VWE10P2HLcl01P2HLTD0Ug5209Ma@P2FL3l0UG0l09A_>P80Tfhg0P2BKCT2
095/>080T6/g0P2?JSH208aX>00308]W=`2:ISH0RFDe00<0R6@d00L0Qf<c08IS;@26HRh0QV8^08EQ
;`25HC40Q5lb0080Q5lc0P22HBh01P21Gbl0Oed_07iL;`1lFBl0NeP^07]H<0L0MUL[00H0MEHZ07=B
;`1cDRl0LU4^075@;@1`Cb`206m>:`80KTdZ00L0Kdh[071?;01aD2d0L4l/06m>:`1]C2T0K4/X00<0
KU0/0`1]Cb/206a>:P<0KE8W0P1^DbP206mD:@07071E:P1cER`0MED/07EE;01gERd0N5D]07]E;P02
07aE;P80NUL]101lFBl0101kF2h0NUL]07iL;P1nG2h207eK;@0407iL;P1oGBl0PV0b08=Q<`<0P64b
0`21HS<2089S=0<0Q5le0P23GS@3089M<`03089M<023GS40Q5lb0080QF0c00<0Q5lb08=N<@22GC00
0`21GS@3081M<`h0Oe`b101nFc4407eK:`@0O5XZ00h0PE//081J:`1mF2/0NUP[07QG;01hF2l0NETb
07QK<`1eF2h0N5/a07YM<`1gFS00LUD[071C:@80LE@Z00<0M5L]07IF;@1fERd00P1fERd407EE;0P0
MUH_201cER`0201cDbX0M5@[07IF;@1gEbh0N5P_07MG;P1fERd0MED/101aE2`2079E;@80LeH^0P1`
E2`01`1_Db/0KU8Z06a@:01[CbL0JThV06U=9@1WD2@00P1WD2H01`1WD2L0IDdW069:9P1OAbD0GDDS
05a59P1KA2D00`1J@b@00`1LABH0GTLX0619:P0205M49P80ET<U0`1E@R@00`1D@B<0E40W05A09`06
05A09`08058l9@1C?BH0DclW054o9`1@?RH0CShU04`n901;?B<304Hl8`<0AC/R0P14>R4304<l8P80
@S/Q0`11>R0:040h8`0303lg8P0n=R40?CDP0080?3@O00@0>c<N03/f800k=R00>cHP0P0j=Al303Td
7P80=C8S00<0=34R03<`8@0b;b000P0a;Ql4030]7P80;b`M0`0^:a`302T[8080:2XO100W:Ah802DV
7Q0092LN200S9Qd8024T6`/08bHM0`0T9ah202DX7`0402DW700V:1d09RPM02HX7@809bTN0P0X:Ql3
02LY7P80:2XO0`0Y:b0802/]7`80;2hQ00L0;BlQ02ha800_<Ql0;c8M030c7P0`=1d0<38M00<0<C<N
0P0b=1l203<e80P0<S@N00H0<SHO03<e7`0c=Al0=C@O03Hd7`0h<al203Tb7`<0>SDO0P0k=R0303`g
8@0503Xf6`0k=a`0?3PM03di7P0n>Ql00P0m>Ah0100l>1d0@3TM040i7@11>Qh2048k7`0304<l8014
?B40A3dQ00P0@CdP00P0@3TO044j8013?280A3dS04Dn9014?B<0@c`R048k8@80A3XO00L0AC/P04Lm
8P18?R<0B3hS04Lm8P15>b00A3XO0080AS/O00T0A3XO044j800o>B40?STS03/i8P0k>B@0?C`P03`k
7`0j>Ad00`0i>1`203Xi7@<0?3PM0`0m>Ah203hj7`P0?SLM200n>Ql803di7P04044j8010>Al0@3TO
040i7`<0?cPN00<0?SLM03`h7@0m>Ah00P0m>Ah303hj7`80?c/P00d0?SXO03di7P0l>1d0?3PM03di
7P0n>Ql0?c/P03/j7P0l>al0@3`Q04<m8`14?B<0AS`S0080ACTQ0P12>al01013?200A3dQ04@m8@15
?R8204Ho8`08048m9`11?2H0@3/U03lj900m>280?3LQ03/f800j=Al303Dg8@80=3HP0`0c=Al2034c
7P06038d7`0a<ah0<38M02la700];aX0;2hI0P0[;Al302`^800302/]7`0Y:ad0:2XL0080:bdO0P0Z
;1h0100Y:ad0:2XL02LY6`0W:A/202PZ7`809bTN0`0V:1d0100U9a`08bHM02<V7@0S9Qd2028U70<0
8B@K100Q91d2020S70<07b8K200N81d;01`N6`806adJ0`0J71T:01XL6`806A/J0P0H6QT:01LI6100
61XI400G61Y901HG6@0401DF600F5aT05QLI01HG6@805aPJ0P0H6A/801HG6@P05aPJ200F5aT801HH
5`P05QLI200E5QP801HH5aP05AHH00P05aPJ010A4`0?41807AhP02l`<P0b<cD08R<U010A4aP05AHH
200F5aT301@E5`<05AHH0P0F5aT801DF61T05QLI200F61L@01HG6@P05QPG600F5aTH01LI60P051XH
6P0G6AP201PJ6@806A/J0P0J71/801/K6@<06Q`I0`0K7AX301`N6`P06Q`I200L71X201dN60807QlI
0P0O81X4020Q6`807b0J0P0N7aT201dN60P07alM200M7A/301`N6`806adJ0`0J71T801/M6P<071hK
0P0K7AX301XL6A006Q`K0`0I6aP301XL6@806adJ200L71X801/M6PP06Q`K200I6aX@01XL6`806adL
0`0J71/401TK6PP06Q`K200I6aP;01TK6P8061XI5@0G6AP201PJ6@806A/J0P0J71/@01`N6`806adJ
0`0L7Q/301dO70<07R0M0P0M7a`<01`N6`<06adJ0P0J71T201TK60<06Q`K0P0K7A`301`N7@P06adJ
00@071hK01/M6P0K7AX06adJ0P0J71T201TK61006Q`K2@0J71T801/M6PP071hK2`0J71T201/M6P/0
71hK0`0L7Qd201/M70<06Q`K200F71X801XL6`/06A/J:oooool002[ooooo00<0WGQ309iiA02ONTD0
0P2QO4L01P2ONTD0WWU409eh@`2QMT<0XgQ50:AiAP80YGY700<0Y7U60:=hA@2QMT<00`2SMdH20:Ah
A`<0YGU8202TNDH0102RNDD0Y7]70:ImB@2TNdL20:1g@`040:ElB02ZPDd0YWe90:ImB@80YGa800<0
Y7]70:=jAP2SNTH02@2SNTH40:IkB0@0Yga9102UO4P20:ImB@80Ygi:0`2ZOdX30:UnB@<0Z7e800<0
Zh1=0:YoC02ZOd`00P2YOT/20:QmBP030:MlB@2[PTh0Zh9>0080ZX5=00L0ZH1<0:QoB`2XOd/0Z7m;
0:IlBP2WOD/0ZGm=0080ZX1>00<0ZGm=0:MmB`2VO4X00P2XOd/30:V0C0<0ZX5=202YOdl40:Z1C@@0
Zh9>202YPe@30:Z5D0<0ZhIA0P2/Qe830:R3CP80ZHA?0`2ZQE000`2_RUD0[XUD0:b7DP020:Z5D003
0:^6D@2/Qe80[HQC00P0ZhIB102]R5@20:b7D`80ZhIB0`2[QEH20:Z4E@<0ZH=D00H0ZXAC0:V3DP2Y
Pe80Z89A0:N1D02VP4l20:EoCP<0Y7m:1@2SOTT20:9mB@0?0:1kA`2NNDD0W7M309Ye@@2IM400V7<o
09QbA@2HLT<0Ug5209I`?`2EL3`0U6lj09A_>02CKSL0TVdi00@0TF`h0`2@JcL208eY>@0308aX>02;
IcL0RVHf00<0RFDe00D0R6@d08IS;@26Hbd0QV8^08IR<00208EQ<@80QF0c0P23HRd01P22HBh0P5h^
07mM;`1nG2l0OE/^07aI;`D0MULY0`1gF2X01P1dDc00Le8_07=B;`1bDBh0LE0]071?;080Kdh[00<0
KTdZ06m>:`1`Cb`00P1aD2d00`1_CR/0KD`Y06a;:00206a>:P80JddY00@0JT`X06U;9`1YBbL0JD/W
0P1WCb<0101XD2@0JE4U06]C9`1/E2P206eE:@0607=F;01eEB`0MED/07IE;01hEBd0NU@]0P1lEBh0
1P1fDbT0N5D[07YG;@1lFBl0OEX`07aI;`80NeP^0P1mFbd207aJ;00407eK;@1oGBl0PEla08=Q<`80
PV<d0`21HS<3081Q<P0408AO=@23GS@0Pehd08=N=080PUdc0P21G3800`22GC00Peha08AO<P0208EP
<`0308AO<P23GS40PUd`00<0PEhd0`20GC<207mL<P04089O=@21GS@0P5dc081M<`80OU/a00<0OEX`
07aI;`1mFS001`1mFS0407aK:0@0OE`Y00h0PE//081J:`1mF2/0NUP[07QG;01hF2l0NETb07QK<`1d
Ebd0MeX`07UL<P1gFS00LeH/075D:P80LeH/00<0MEP^07EE;01eEB`00P1eEB`407IF;@P0MUH_201b
Eb`02@1bDRT0Le<Z07EE;01gEbh0N5P_07MG;P1fERd0MED/071C:`02075D;080LUD]0P1cERh02@1d
Ebl0LED]075E;@1`E2`0KU8Z06a@:01[CbL0JThV06U=9@0206I?8`80Ie0V00`0ITlV06A<9P1RBRH0
H4PT05m8:@1NAbP0GDHW05a59P1MARL0GTLX0619:P1QBR/305M49P80ET<U0`1E@R@805M1:@0805@k
9@1E?2H0EClX05A0:01B@2P0CclV04dm901;?B<304@j8@0504Dk8P16?2<0AS`S04Hl8`17?B@00`13
?282048k8@<0@CXP200o=b82040h8`80?cLR00@0?SHQ03de800l=1l0?3@O0P0l>1l203/g7P<0>SHM
00H0>CDL03Hc900f<b@0=C8S03@a8P0c<242038_8004034^7`0a;Qd0<BhM034^7@80<2dL0`0_;1/4
02T[8080:2XO0`0W:Ah802HW7`P09BPO400T9ah8024T6`/08bHM0`0T9ah202DX7`809BLL0`0V:1d3
02LY7P809RPM0P0W:Ah302PZ7`0302T[800[;Al0:bdO00H0:bdO00P0:bdP02`^8@0/;R00;C0O02ha
7P0_<Qd0<3<N030d7@80<38M0`0a<ah3038d7`P0<C<M00H0<SDP03<e800c=B00=C@P03Hc800h<b02
03Tb800;03Ha6`0g<Q`0>3<M03Td7P0k=R00?3LQ03dh8P0n>B<0>SHK03/g700m>Ah00`0o>b0203di
7P0503lh7010>Ad0@3TM044j7P13?2000P14?B400`15?R80@3lQ040o8@06040o8@03040i7`11>R00
@c`R0080AChT00<0A3dS04<l8P12>b400P14>Ql05`16?240AcdR04Pn8`18?R<0AcdR04Hl8@14>Ql0
ACXN04@i7@13>Ah0@3TO03dg7`0k=R00>CLP03Pf8@0l?200>SXN03Ph700g=a/0=SHJ03Lg6`0h>1`0
>CTM0080>cLL0P0l>1d203di7P80?SXO200n=ad803hj7`P0?3PM0P11>R02040i7`80?cPN0P0n=ad2
03`h7@80?CTN0P0n>Ql303lk800?03hj7`0m>Ah0?3PM03`h7@0m>Ah0?SXO03lk800l>al0?C`P044m
8P13?B<0AChT04Hl8`16>R80ACTQ00H0A3dQ0P15?R80200o?BH0?S`U03dk900l>R<0>SPQ03Tg800h
=Ql0=cDN0`0d=R4203<e80<0<S@O00/0;c4L030b7@0a<ah0<C<N030b7@0^<1/0;2hI02/]600Y:ad0
:R`N02`^800302h`8P0702`^800[;Al0:bdO02/]7`0Z;1h0:B/M02PZ700202LY6`0402HX6P0W:Ah0
9bTN02LY7P<09RPM0P0U9a`0100S9Qd08RDL028U700R9A`2024T6`8082<J100Q91d2020S70<07b8K
200N81d;01`N6`806adJ0`0J71T:01XL6`806A/J0P0H6QT:01LI610061XI400G61Y<01HG6@805aPJ
0`0H6A/801HG6@P05aPJ200F5aT801HH5`P05QLI200E5QP801HH5aP05AHH00P061TK01DF600D5AL0
6AXL020Q8`0R8bD06a`N01<D5QP05AHH200F5aT301@E5`<05AHH0P0F5aT801DF61T05QLI200F61L@
01HG6@P05QPG600F5aTH01LI60P051XH6P0G6AP201PJ6@806A/J0P0J71/801/K6@<06Q`I0`0K7AX3
01`N6`P06Q`I200L71X201dN60807QlI0P0O81X4020Q6`807b0J0P0N7aT201dN60P07alM200L71X3
01`N6`806adJ0`0J71T801/M6P<071hK0P0K7AX301XL6A006Q`K0`0I6aP301XL6@806adJ200L71X8
01/M6PP06Q`K200I6aXB01/M70<06Q`K100I6aX801XL6`P06A/H2@0I6aX301PJ6@805aTH2P0F61L:
01LI608061XI0P0I6aX201XL6a0071hK0P0K7AX301`N6`<07AlL00@07R0M01dO700M7a`07AlL0P0L
7Q/=01/M6P806Q`I0`0I6aP301XL6`806adL0`0L7Qd;01/M6P806Q`I0`0I6aP@01XL6`T06Q`I400K
7AX;01XL6@806adJ2`0L7Q/301`N7@806adL0`0J71/801HL6PP06Q`K2`0I6aX[ooooo`00:_ooool0
0`2MN4<0WWU409mjA@020:5lA`0609mjA@2NND@0WGQ30:1e@P2QMT<0XgQ50P2TNDH00`2SN4D0XGI3
0:1e@P030:=gAP80Y7Q70`2UNDP80:AiAP040:9iA@2UO4P0Ygi:0:AkA`80X7M300@0YGa80:^2CP2V
ODT0YWe90P2UO4P0102TNdL0XgY60:=jAP2RNDD80:=jAP050:AiAP2UNTL0YGY70:IkB02WO4T00P2X
ODX00`2YOT/0Y7]70:ElB0020:ElB080YWe90P2WOTX30:YoBP<0ZGi90`2XODP20:^0C@040:YoC02Y
OT/0ZGi;0:QmBP80Yga90P2[PTh20:Z1C@070:V0C02XOd/0Z7m;0:MnBP2VO4X0Yge;0:UoC@020:Z0
CP030:UoC@2WOD/0YWa:0080Z7m;0`2YP4`30:Z1C@P0ZGm?00@0[8=?0:^2CP2[PTh0Zh9>0`2ZPDd0
0`2YP4`0ZH=F0:V3EP060:V3EP<0ZhIA0`2/Qe820:f8D`<0Z8=>0`2YQ4l20:Z5D0080;:=F02`ReH0
[HQC0:^6D@2ZQE00ZhIA0:b7DP2]R5<80:^6DP040:j9E@2]R5@0[HQD0:f8E080[8MC0P2[QU830:^5
F080ZXAG0`2YPeH20:Z4D`040:V3DP2XPU40Yh5@0:J0C`80YGm>1@2TOdX30:=nB@0>0:=nBP2RODT0
XGa809mjAP2LMd<0VWE109Ud@02HLcl0V79509Qb@`2GLD80UW0o09E`?02EL3/209A_>0L0TF`h00D0
T6/g08eY>@2=JCT0S6Ph08]W=`0308YV=P80RFDe00H0QV<[08IS;@26Hbd0QV8^08IR<026HS8208EP
<`0608AS;P23HRd0PV4^085O;`1oGBl0OU`^0P1mFbh307IG:0D0MePY0P1dDc000`1cDRl0LU4^075@
;@02071?;080Kdh[00P0L4l/075@;@1aD2d0LE0]06m>:`1]C2T0K4/X06U;9`80J4XV00<0IdTU06I8
901VB2@00P1UAb<02@1SC200I4dQ06E>8P1WD2@0J54U06YC9`1[E2P0K5DY079E:`0207EE;00307IE
;01hEBd0NU@]0080O5D^00@0M54W07IC:@1iER`0O5T_0P1mFS00101lFBl0NeP^07aJ;01lFR`207]I
:`0407eK;@1oGBl0PEla08=Q<`80PFDe00<0P6@d07mS<`1nHS800P1mHC400`1lH300Pehd08=N=002
08=N=080PUdc0P21G3800`22GC00Peha08AO<P0208EP<`0308AO<P23GS40PUd`00<0PEhd0`20GC<2
07mL<P80Pf0f00@0PEhd081M<`1nFc40OEX`101kF2h407aI;`80OEX`00D0NUTV07]J9`1kFRL0O5/X
07eL:@0207iM:P0?07mN:`21Fb`0P5X[07eH:`1jF2/0N5L/07QH;`1iFC80N5/c07=F;01fFBl0N5/a
07MJ<01cER`0LE@Z0080LeH/00<0MeX`07EE;01eEB`00P1eEB`407IF;@P0MUH_201aER/01P1bDRT0
Le<Z07EE;01gEbh0N5P_07MG;P80MUH]00@0L5<[075D;01aE2`0LUD]0P1cERh207AG;`0C079G;01a
ER/0L5DZ06iC:01]DRL0Je0U06Y?901YCR<0IDlP06I?8`1WD2@0Ie0V06M@9`1UCBL0Hd/W069:9P1R
Bb`0HDX[05m8:@0205i7:00305m8:@1PBBX0HDX[00<0Ed@V0`1F@bD205E290P0F48Z00h0E3/U05Hm
9`1E?bP0ET0Y05A0:01A?bL0CCdT04`l8`12>1l0@cTP04@j8@15>b80AS`S04Lm9080B3hU0`13?282
048k8@<0@CXP200n=R401P11>B@0@3PS040h8`0o=b80?SHQ03de8080?3@O0`0l>1l203/g7P<0>SHM
0P0f<b@0100e<R<0=34R03<`8@0c<242038_80<0<bdM0P0b;1`3034[6`0402X/8@0Y:b00:B/P02T[
8080:2XO0`0W:Ah802HW7`P09BPO400T9ah8024T6`/08bHM0`0T9ah202DX7`<09BLL0P0V:1d302LY
7P809RPM0P0W:Ah402PZ7`P0:bdO0P0[;B001P0/;R00;C0O02ha7P0_<Qd0<3<N030d7@<0<38M0P0a
<ah3038d7`P0<C<M00H0<C@O038d7`0b=1l0=3<O03Db7`0g<Ql203Pa7`0@03@_6@0e<1X0=c8L03Td
7P0k=R00?CPR03hi8`0o>R@0>cLL03`h7@0n>Ql0@3`Q044m8P10?240?SXO03di7P80?cPL00@0@3TM
044j7P13?200A3dQ0P15?R8804508P03040i7`11>R00@c`R00<0AChT00H0A3dS04<l8P15>b00AC/P
04Hl8@17?B8204Pn8`0>04Lm8P16?240AC/P04@i7@13>1`0@SPM03hg7@0l=Qh0>SDO03Le7P0g=B00
?3`P03Xj7P0h>1`303Hf6P0303Ph700i>Ad0>SHK0080>cLL00<0?3PM03di7P0m>Ah00P0n>Ql803hg
7@P0?SXO200l>1d3044j8003040i7`0o>1h0?SLM0080?SLM0`0l>1d00`0m>Ah0?SXO03lk800203lk
8003040l8@0n>Ql0?CTN0080>cLL00T0?CTN03hj7`10?240?3/O03dl8011?B80A3hT04Dn9017?B@0
0P16>R801016?b<0AChR04Dn8P15?R8304@m8@0704<l800n?2L0?C/V03`j9@0k>B@0>SPS03Pf8@02
03Le800403<f8@0b=B00<SDP038e8080<C@O0P0`<ah03P0_<A`0<38M034c7P0a<ah0<38M02h`6`0/
;QT0:R`G02PZ700Y:ad0;2hP02h`8P0`<R@0;c4S0P0^<28202/]7`0402X/7P0Y:ad0:2XL02LY6`80
9RPJ0`0W:Ah202HX7@<09BLL100R9A`2024T6`8082<J100Q91d2020S70<07b8K200N81d;01`N6`80
6adJ0`0J71T:01XL6`806A/J0P0H6QT:01LI610061XI400G61Y;01HG6@<05aPJ0`0H6A/801HG6@P0
5aPJ200F5aT801HH5`P05QLI200E5QP801HH5aP05AHH0P0J6ad01P0H6A/051DG010A4`0@4A<04a@F
01LH6QP05AHH200F5aT301@E5`<05AHH0P0F5aT801DF61T05QLI200F61L@01HG6@P05QPG600F5aTH
01LI60P051XH6P0G6AP201PJ6@806A/J0P0J71/801/K6@<06Q`I0`0K7AX301`N6`P06Q`I200L71X2
01dN60807QlI0P0O81X4020Q6`807b0J0P0N7aT201dN60P07alM200L71X301`N6`806adJ0`0J71T8
01/M6P<071hK0P0K7AX301XL6A006Q`K0`0I6aP301XL6@806adJ200L71X801/M6PP06Q`K200I6aXB
01/M70<06Q`K100I6aX801XL6`P06A/H200I6aX401PJ6@805aTH2P0F61L:01LI608061XI0P0I6aX2
01XL6a0071hK0P0K7AX301`N6`L07AlL0P0L7Q/<01/M6P<06Q`I0`0I6aP301XL6`806adL0`0L7Qd:
01/M6P<06Q`I0`0I6aP@01XL6`T06Q`I400K7AX;01XL6@806adJ2`0L7Q/301`N7@806adL0`0J71/8
01HL6PP06Q`K2`0I6aX[ooooo`00:_ooool80:1g@`P0XWU500P0Y7U60:=hA@2QMT<0WgA109ic@02O
M440XGI30:9gA0<0WgI20P2PMd<30:5hA0P0Y7]30P2UNTL40:AiAP80XgQ500<0XGI30:9gA02TNDH0
0P2VNdP00`2UNTL0Y7U60:=hA@020:EjA`80YW]80P2WO4T20:QmBP040:AkA`2UO4P0YGa80:ElB080
YWe90P2WOTX20:^0C@@0[85>00<0ZWm<0:QmBP2VNdP00P2XOd/30:V0C0<0ZX5=202ZOTl30:V0C080
Z7m;0`2WOTX20:ElB0040:ImB@2WOTX0ZH1<0:Z1C@@0Zh9>0P2ZPDd00`2YP4`0Z7m;0:QoB`020:Mn
BP070:V0C02[PTh0[8=?0:f4D02/Pdl0Zh9>0:Z1C@020:QnCP040:UoC`2ZP500ZX1@0:^1D@80[89B
0`2^QE430:n6DP80/8MC202/Pdl80:b2D080[HQC0P2/Qe801@2[QU40ZXE@0:Z5D02YQ4l0/HQD0080
/8MC00<0[hIB0:j5D@2]Q5000P2/Pdl80:Z4D`040:b0C`2[Odh0Zgm>0:]oCP80ZWi=0P2YOD`20:Qo
B`<0Ygi:0`2VODT01@2[PTh0Z7m;0:ElB02QN4@0WWE100<0WGA000P0VGA009Qc?`2FLCd0UG0l09A_
>`2EL3`0UW4m09Mb?P80Tfdn00<0TV`m095[?02@JS/00P2?JCX01P2>J3T0SfXn08iY?@2<Ic/0RfHj
08YU>@80RfHj00P0S6Lk08eX?02;IcL0RVHf08UU=@28I3@0Qf<c08EQ<@80Q60`00H0PV0b085O<@20
GS00P5h`07mM;`1nG2h207eK;@0607mJ<01nFBl0OEP^07eH;P1lEbd0NeH/0P1jEB/207YC:P0607QB
:`1eDR`0LU0[071?;01_CR/0K4h/0`1[CBT206a>:P<0KDl[00@0IdHS06U89@1[BRL0K4/X0P1]C2T0
2P1/BbP0JdXW06M99`1WBBL0J4XX06Y<:P1/CR`0KDl]06i@;P1_DBl307=D:080M5DY0`1eERX0201l
ERT0OELZ07eG:P1nF2/0OELZ07]E:01iDbH0N58U0P1jEbd00`1kF2h0O5T_07eJ<00207iK<@0407mL
<P21H2d0PF0]085P;@<0P5l/0P1oGR/208AP;P0908EQ<@26HC@0QV4e08EP=P24GcD0Q5hg07]H;P1n
Fc40PUle0080QF8h00<0PUle07iK<@1kF2h02024Gc8807aP<080OU/a0P1mFS0307aI;`0407]H;P1n
Fc40OEX`07aI;`80NeP^00L0O5T_07iK<@1oG380Pf0f089O=@1nFc40O5T_00<0NUL]00L0NeP^07]H
<01lFC40OEXb07aI<@1kF300NEH^0080Me@/00<0ME8Z07UF;P1iERh00P1hEBd307MD;00307IC:`1e
EBh0MED^0080MED^0P1dE2d207=C;009079B:`1cDb`0M5@]07EE;P1fERl0MeL`07QH<@1iFC80NeD`
0080NU@_00<0NE<^07QB;@1gDB`00P1fD2/607AD;@80MED^0P1dEb/05`1cER`0LUD]071B;01_DBd0
KU0/06i@;P1VCRX0JU8^06aD<01YDBd0HTXV05m78`1QBBD0IDdY06A<:P1SBbT0HTXX06599`1PB2H0
GdLU05i6901MAB<0DT8N0080Dd<O00<0E4@P05E58@1EAB400P1FAR8205U69P80F4DU0`1GA2@00`1F
@b<0D4<S05138`0204m28P<0CT4Q00L0CD0P04/j9P19>RD0BCXU04Hj9014>B<0@CTR0080?cTQ100o
>b04040l8@0804/l9@19>R<0ACTQ048h7`0n=ad0?CLM03hh7P0m>Ah203Xb7@80>c<N100l=1l803de
80P0>C@Q00<0<bhJ03D`700g<Qh00P0h<al0100g<Qh0=S4M03D`700]:Ad302hZ7P<0;b/O0P0`;202
02TZ7080:R/M00@0:b`N02`]7`0];R00;BhP0`0V9b4202DV80<092DO0`0V:1d202DW70<092HK0P0S
91`202@U7@0402DV7P0V9al09RLO02LX80<09RTN0P0U:1d302@W700402HY800U:1l09BPO02@W7P80
8bHM0P0R9A`802<V7@0@028U700S9Qd092LN02DX7`0V:B009bXQ02P[8P0Y;2<092LL02HY7P0X:b00
:B`Q02X]8P0Y;240:2/P02HY7PP0:BdN100];b4402h`8P0602`_7P0]<1l0;C0O02ha800_<R40<3<R
0P0a=2<303Db7`0303Hc800g=240>3DR0080>3DR0P0i=b8203Pf8@0403Le800f=1l0=C<N03Dc7P80
>3<M0`0i=1h303Xe7`80?CTN0P0l>1d0100n>Ql0@3`Q048n8`14@2D204Ll7080B3dM00@0BChN04Xo
7`1:?al0Bd0P2013?20503lk80<0?SXO0P0m>Ah01`0n>Ql0?c/P044m8P11?B80?c/P03hj7`0m>Ah0
0P0n>B<203dh8P0403`g8@0k=R00>cHP03Xe7`80>CPS00<0>SPS03/f8P0l=B800P0l=2401P0n<b40
?3DK03`e6`0m=Q`0?SLM03lh7P80@3TO00@0@CXP040k9@10>bD0@3/U0`0o>R@203hi8`80?cXT00<0
?STS03dh8P0l=b400P0j=Al303Td7P0403Xe7`0k=R00>cHP03`g8@H0?CPR100n>B<304<h9003048g
8`11=R80@3DQ0080@3DQ0`11>R000`10>Al0?cPN03hg7@0203hg7@<0@CXP0P12>b4304<l8P<0@3`Q
1@11?B801P0c>b<0=CXS03@i8P0e>B80=SPR03Pg8P80>3HQ0100<3<P03<f8`0e>2D0<cHS030c800^
<Ah0<3<P03<f8`0d=2P0<c<W038b9P0a<BD0;blS02h^8P0];B40;2`P200/<1l302X/8@0302T[800X
:Ql09bTN00809bTN00D0:bdR02X/8@0Y:b00:2XO02LY7P0202HX7@0302DW700T9Ad092DM00H092DM
00@09bPP02HW7`0V9al09BHN0P0T9Ad302<T700602@M5`0S7QP08ahH02<P6@0R8QX08R<K0P0R9A`0
0`0Q81`07ahJ01dL600201`K5`0301dL600N7AT07ahJ00P071hK00<06adJ01`N6`0M7a`00P0M7a`0
0`0K7AX06Q`I01PJ5`0401LL608061dI0P0I7QX301/L7P806Q/M0`0I6Q`0100I7B0061`O01PL7`0H
71l201LK7P805QXM1@0D71h301DM7`D051dL0`0C71/0200F7AD05A`D014K4P0?6a403Q/A00dM4P0>
7Q<03R0D0`0G5Q@501PG5@0801DD4P0F5A<061LE01TH5P0J6AL06APF01PG5@0G5Q@301XF4`@06aLD
00@071PE01XF5@0J5QD06QHE1@0K5aH801/H4`<061LC0P0G5Q8301HE4@805a<@0P0H5140100I5A80
6QHC01XF4`0K5a@801XG4PT06A@J200B5aX801<F6`805QXK00@05ATJ01@H6@0D61T04aLH0P0B5QL3
01DE5`8051@F0`0C4aD301DF60805QLI0`0G61X8018J70P05aPL0P0H6QT201LI60<05QPG2@0E5aH8
01LI60<05QLI0P0E5QP301@E5`P05QPG200E5aH801DF60P05ALF200E5QP801DG5PP05QPG4@0E5QP8
01HG6@P05QPG600F5aT801DG5PP05AHH200G61X@01LI60D05aPJ0`0H6A/801HH5a005aTH0P0F61L3
01LI60<061XI0`0I6aX301XL6`806adL0`0L7Q/201/M6P<06Q`I2@0J71/801/M6PP07AdK200L71X8
01dM6`P07QhL200M7A/201/M70<06Q`K0`0I6aX801/M70P06Q`K200I6aX801TK600401LI600H6QT0
61XI01PJ6@806A/J0P0J71/201/M70<06Q`K0`0I6aX801XL6aP06A/J0P0J71/401/M708071hM4@0I
6aX@01XL6`<05A/I0`0D6QP201<I5`P05aTH0P0F61L301LI60<061XI0`0I6aP301XL6A806adJ200L
7Q/801dM6`P071hK400J71/801/M70P06Q`K2`0I6aX301XL6`806adL4@0K7AX@01XL6@<06A/H0`0J
71T201/M6PP07AlL0P0K7A`301XL6a<06A/J200J71/301LM6b_ooooo000Zooooo`P0XGQ4202RNDD0
0`2UNTL0Y7U60:9gA0020:1e@P030:5f@`2RMd@0XgQ500<0X7M30P2QN4@30:9iA@P0Y7]3202TNDH0
0`2RMd@0XgQ50:EjA`020:IkB0030:EjA`2SN4D0XWM40080YGY70P2VNdP20:MlB@80Z7e:102UO4P2
0:ImB@80Ygi:00<0ZGi;0:YoC02/PDh00`2/PDh00`2ZOd`0ZGi;0:MlB@030:QoB`80ZH1<0`2ZPDd8
0:YnC`<0ZH1<0P2XOd/30:MnBP050:ElB02VODT0YWe90:MnBP2YP4`00P2ZPDd30:^2CP80ZX5=00`0
ZH1<0:QoB`2XOd/0Z7m;0:MnBP2YP4`0Zh9>0:b3C`2]Q500[8=?0:^2CP2ZPDd30:Z0D080Zh5A0`2/
PU80102/Pdl0[HA@0:f4D02]Q5020:j5D@80[hIB202/Pdl80:b2D080[HQC0P2/Qe80102[QU40ZXE@
0:Z5D02ZQE030:n6DP<0[XEA0P2]Q5080:Z4D`80Zh5?0P2ZP4h30:UoC@040:QnC02XOd/0Z7m;0:Qo
B`80Ygi:0`2VODT01P2YP4`0Ygi:0:AkA`2QN4@0WgI209ie@@80WgI200<0VWE109Qc?`2GLSh00`2E
L3`00`2FLCd0Ug8n09E_@00209A^?`0309=]?P2BK3d0TF/l0080T6Xk00<0T6/o08iY?@2=J3`0102;
ISX02P2<Ic/0SFPl08]W=`2;IcL0RVHf08QT=027Hc<0QV8b08EQ<@24H302089P<P03085O<@20GS00
Oed_0080OU`^00H0OE/]07mJ<01oFS00OUT_07eH;P1lEbd207]F;00907YE:`1kE2/0NU<Z07QB:`1e
DR`0LU0[071?;01_CR/0KDl]00P0K4hZ00<0JDPU06Y99P1/BbP00`1^CBX0201]C2T0K4/X06Q::01X
BRP0JD/Y06Y<:P1[CB/0K4h/0P1]Cbd0101bDbL0Le@X07=D:01cE2P207AE:@80MEHZ00<0Ne@Y07aE
:P1mER/00P1mER/00`1kE2T0NE8W07QA9P0207YG;@0407]H;P1lFBl0OEX`07eJ<080OU/a2020Gb`2
08EQ;`0908AP<024Gc80Q5lc08AO=@25H3H0QElh07eJ<01oG380PEhd0080Pf0f00<0PEhd07mL<P1m
FS002024Gc8807iO<080OU/a0P1mFS0407aI;`0307mL<P1nFc40O5T_0080NeP^00L0O5T_07eJ<01n
Fc40P5dc07mL<P1mFS00NeP^0080NUL]0P1kF2h01P1kF300O5Ta07aI<@1lFC40NeP`07UF;P80Me@/
00<0ME8Z07UF;P1iERh00P1hEBd407MD;00407IF;`1eEBh0MED^07EE;P80M5@]0P1cDb`01P1bDR/0
Le</07AD;@1eEBh0MUH_07MG<080N5Pa101gE2h407IC;@<0MED^1@1dE2d01@1dEb/0LeHZ07=F;01b
EBd0L58/0080Ke4]00X0KU0^06M?:`1ZDRh0Je<_06Q@;01SBbL0H4PT069:9P1UCBT0I4`Z0P1SBbT0
1P1RBRP0H4PV05m79@1OAbD0GTHT05E37`80ET@P0P1GAB4205Q68P0305U78`1IARH0FDHV0080F4DU
101GA2@305138`80Cd8R0`1>@B4204/j9P0304Tj9@16>R@0A3TS0080@CTR00<0?cTQ03li7`10>R00
1P10>R002@1:>b@0B3TR04@h8011=ah0?cPN03hh7P0o>Al0?SXO03/c7P0303`d7`80?CDP0P0n=R48
03de80P0>C@Q00<0=2lK03D`700g<Qh00P0h<al00`0g<Qh0=S4M03D`7009030]7P80:R/M0`0[;1h3
02`]7`0402LX8P0V9b409RLQ02HW8@809BHP0P0T9Al302HX7@809BLL0`0T9Q/00`0S91`092DM02@U
7@0202DV7P809RLO00@09bPP02HY7P0V:Ah09RTN0P0U:1d302@W70<09BPO00<092LN02<V7@0S9Qd0
0P0R9A`802<V7@808RDL00@08bHM02@W7P0U:1l09RTP0P0W:R400`0T9a`09BPM02LZ7`0302T/8@03
02P[800W:Ql0:BdN00L0:BdN1@0];b4302h`8P0602`_7P0]<1l0;C0O02ha800_<R40<3<R0P0a=2<3
03Db7`0303Hc800g=240=c@Q0080>3DR0`0i=b8203Pf8@<0=cDP0P0i=1h303Xe7`<0>cHP0P0m>Ah2
03`h7@0503di7P0o>b00@ShS04<o9016>ad00P17?1h204Pm7`80BChP00<0BSlQ04<l8013?2001P13
?20403lk80@0?SXO0P0m>Ah01`0n>Ql0?c/P040l8@10?240?c/P03hj7`0m>Ah00P0n>B<203dh8P04
03`g8@0k=R00>cHP03/f8080>3LR00<0>CLR03/f8P0l=B800P0m=B800`0o=280?CHL03df700303hg
7@<0?cPN0`0o>R@203hi8`<0?CPR0P0o>R@01@0n>B<0?CPR03`g8@0k=R00>SDO0080>C@N0P0j=Al2
03/f8080?3LQ1P0m>28303hi8`80@CTT0P10>2<0100o=b80?SHQ03hf8@0n=R42044j8080@3TO0P0o
>1h203hg7@<0@CXP0P12>b4304<l8PD0@C/Q0`10>R0203<i7`0303@h7`0e=al0=cLO0080>3HO0140
>SDO030b7@0c=B00=SPS03@f8@0`<Qd0;c4L034c7P0d=R40=S@U03Dc900d<R<0<c4R038`8@0a;b00
<2hO02l]7P0802ha7P80;RlQ0P0];R00100/;Al0:b`N02//7P0[;1h202d^8080;2dO00@0:b`N02X[
7@0Z:ad0:BXL200X:1`402`Z7P0302/Y7@0Z:1`0:RPL0080:BLK0P0[8QT00`0Z8aT0:2@I02PV6P02
02HV6P0402HX6`0[9R00:B@N02PS7@809R4K00<09b8L02TT7P0Z9Al0200R8A`0200P7aX08B0K028Q
700S8Qd08R4L024P6`0O7QT07QdH200N8AX3020O7@<07ahL0P0N7A/401`N7@806adL0P0J71/201PL
6`H06AdL00<061dI01LL600G71P00P0G71P301HK5`0801XL6@0I6aP05AXF01<I5@0@6A@041/E018M
5`0A7QL501PJ6@<06A/J00<05QPG01LI600H6QT00P0J71/00`0I6aX061XI01LI600401TI5`@06QXH
200I6A/801TI5`8061XI0P0G6AP301HH5`<05ALF0P0F61L201LI608061XI200G6AH901LH6PP051XJ
200E61d201PL7@805a/L00@05QXK01DI6P0E6AX05ATJ0`0H61X201LG6@<05QHH0`0G61X301PI6`80
6AXL200C61/801HG6`<05aTH0P0F61L;01DG5PP05QPG0`0F5aT201DF60<051DG200F61L801DG5PP0
5AHH200E5aH801DF60P05ALF200F61LA01DF60P05QLI200F61LH01HG6@P05ALF200E5QP801LH6Q00
5aTH1P0G61X201PI6`P05QPG400G6AP201HH5`<05aTH0`0H6QT301TK6P<06Q`K0P0K7A`301`N6`80
6adJ0`0J71T901XL6`P06adJ200M7A/801`L6PP07AdK200N7Q`801dM6`806adL0`0J71/301TK6PP0
6adL200J71/801TK6PP06A/H100H6QT201TK6P806Q`K0`0K7A`201XL6`<06A/J200J71/H01TK6P80
6Q`K1P0K7A`A01TK6Q006Q`K0`0E6aT301@J60804aTG200G6AP201HH5`<05aTH0`0H6QT301TK60<0
6Q`I4P0K7AX801`N6`P07AdK200L7Q/@01XL6`P06adL200J71/;01TK6P<06Q`K0P0K7A`A01/M6Q00
6Q`I0`0I6aP301XL6@806adJ200M7a`201/M70<06Q`K4`0I6aX801XL6`<05adK:oooool002[ooooo
202SNTH80:5hA0030:IkB02UNTL0Y7U600<0XWM400@0XgQ50:AiAP2QN4@0XGQ40P2RNDD20:=jAP80
Y7]7202UO4H90:AiAP070:EjA`2VNdP0YW]80:EjA`2TNDH0XGI30:1e@P020:EjA`80YW]80P2WO4T2
0:QmBP<0YGa80P2VODT30:MnBP030:MlB@2YOT/0ZWm<00@0[85>00<0ZWm<0:UnB`2WOTX00`2XOd/2
0:V0C080ZX5=202ZOTd30:V0C080Z7m;0`2WOTX20:ImB@040:MnBP2XOd/0Z7m;0:V0C0D0ZX5=0`2Y
P4`20:QoB`080:MnBP2YP4`0Zh9>0:b3C`2]Q500[8=?0:^2CP2ZPDd40:f3D@@0[89@00@0ZX5=0:^2
CP2[PTh0Zh9>0P2/Pdl20:f4D0P0[8=?202/PU030:b7DP<0ZhIA0P2ZQE020:f4D0<0[XEA0`2_QU88
0:^6DP040:b2D02[PDl0Zh5?0:^1C`80ZX1>0P2YOdd0102YP4`0Z7m;0:QoB`2XOd/20:MnBP<0YWe9
00D0YGa80:=jAP2RNDD0XGQ40:1g@`020:5hA00309]f@P2IM400V7<o00<0UW4m00L0Ug8n09Qc?`2G
LD80Ug5209I`@@2EKd00U6ho0080Tfdn00H0TV`m091[?P2?JSd0SFPk08aW>P2;IST208aW>P0808eX
>`2>JC`0S6Ph08]W=`2:ISH0RFDe08QT=026HS8208EQ<@80Pf4c00<0PV0b085O<@20GS000P1oGBl0
1P1nG2h0P5/a081K<@1oFS00OUT_07eH;P80O5L]00X0NeH/07aE;01kE2/0NE</07IC;@1cDB`0LE0]
071?;01]Cbd0Ke4]0P1^D2`0201]Cb/0K4hZ06]=:@1[CBT0JT`X06]:9`1/BbP0KTdZ0P1`Cb`00`1_
CR/0KTdZ06e<:@0806Y<:P04075A:01bDRT0LU8Y079B:@80Le<Z0P1dE2/00`1hDbT0NE@Z07YE:`02
07]F;00307UD:P1gDRP0MU4W0080NEH/00<0NUL]07]H;P1lFBl00P1mFS001@1nFc40OE/[07eK:`1n
G2`0Oed]0080P5h^0P21Gbl02027Hc40QF4_089N;P21G2l0PE``089M<`25H3H0Qf4j2020GC<808AO
<PP0OUl`0`1nFc4207eJ<0<0O5T_00@0PEhd081M<`1mFS00O5T_0P1kF2h01@1lFBl0OEX`07aI;`1k
F2h0NUL]0080NEH/00<0NUL]07]H;P1lFBl00P1kF30207aI<@0507]H<01iERh0Me@/07MD;01fDb/0
0`1iERh207QE;@<0Me@/0`1fERl207EE;P<0M5@]0P1cDb`207AD;@0407EE;P1fERl0MeL`07MG<0<0
MU<]0`1gE2h207QE;`80MUH_0P1eEBh0101dE2d0Le</07=C;01bDR/207=F:P0>079E:`1aE2`0LE<]
071B;P1_DBd0Ke4_06Q@;01YDBd0JU8^06Q@;01TC2P0HTXV06=;9`1TC2P206A<:P0306=;:@1RBRP0
HDTW0080H4PV00@0GdLU05M58@1GAB40EdDQ0P1HAR8305U78`<0FDHV0P1HABD305M49080DT<T0P1A
@R<305118P0704m08@1>?2H0C3`U04`l9@1:>b@0Ac/S04Dk8P02048k8@<0@CXP1@10>Al02018>B80
AcPQ04<g7`11=ah0?cPN03li7`10>R00@3`Q0`0n=R4203lg8P<0@3PS200n=R4803Xe8@0303Ha7@0g
<Qh0>3<O00<0>3<O0P0f<Ad203@a8P80<c0Q00<0<RlP034^7`0`;Ah00P0`;Ah202d^80<0;2dO0`0[
;1h0100X:B409bPP02LX800W:20202HW7`809BHN0`0W:Ah202HX7@<09BLL0P0T9Ad202DV7P@09RLO
0`0V:Ah202DX7@<092LL0P0U:1l302@W7P/08bHM0P0Q91/0100R9A`08bHM02<V7@0T9ah202DX7`03
02@W700U:1d09bXO00<0:2/P0P0W:Ql802T]7P<0;2hP0P0];b4302h`8P0602`_7P0]<1l0;C0O02ha
800_<R40<3<R0P0a=2<303Db7`80=S<P0`0g=24203Pf8@<0>CLR0`0j>2<303/f80<0?3LQ0P0m>280
200n>Ql0?CTN03`h7@0l>1d0?CTN03lk8011?B80@ShS0`15?1l204Hm80<0AchQ2012>al803hj7`80
?3PM00L0?CTN03lk8010?240@3`Q03lk800m>Ah0?3PM00<0?CPR0`0l=b4203/f8080=SDP00H0>3HQ
03/f8P0l=B80?SHS03lg9011=R@303lh7P<0?SLM0P0m=Q`303dh8P80?3LQ0`0k=R001P0o>R@0?STS
03hi8`0m>280?3LQ03/f80D0>SDO0P0k=R0303`g8@P0?CPR0`10>2<203lg8P<0?SHQ00@0@CXP040i
7`10>Al0@3TO0`0o>1h0100n=ad0@CXP044j8011>R02048k8@@0@c`R0P12>b400`11>R00@3TO03lh
7P0203lh7P0603<g7P0d=Qh0=3HN03Hf7P0g=Ah0>C@N0P0j=1h02@0c<A`0=S@O03Tg8P0g=B00=38M
03<a700e<ah0>3HQ03Xe8P0203Td8@0503Pc800g<Ql0=S4N03Ha7P0e<1d0200e<ah303Pc8080=c8O
1`0f<Ah403D`7@P0<bhK1P0g;Qd00`0f;A`0=B`K03D/6`0203P[6`0403L[6`0e;1/0<b`J038]6P80
<2dJ00<0>2hR03L]8@0f;2000`0f;20203P^8PP0<2XN00P0;BLK02hX700_:Ad0<2XN02lY7@0^:1`0
;2HJ02/U6@80;RXN00@0;BTM02`X700/:1`0:bLK0P0Z9QX0100]9Qh0;2DM02`U7@0/9Ad202/T7080
:R<K0P0W8Q`202HQ6`<09B0J00@091lI028R6P0R8QX08R8J1@0Q8AT00`0P81P07alG01hN5P0501dM
5@03028N7@0Q7A`07A`J00806QXH00<06A/H01PM6@0I7QX0200J7Ql00`0G6a`061`M01XN7`0201/O
800301XN7`0H71d05a/L00806AdN1P0H71d801LK7PP05a/L00@05a`O01HK7P0F6ah05Q/N0P0E6Qd5
01@I70<05AXM0P0F6ah801@I70T05Q`J200H6QT801PI6`806adL0`0J71/301TK6P806a/K0P0J6QX3
01TI6@0301PH600G6AP061XI008061XI0P0I6aX201XL6`P04aTI200F5aT301HH5`805ALF0`0D5QD8
01HH5`P05ALF0`0G61X201HG6@<05AHH200G6AP801DG5PP05AHH200E5aH801DF60P05ALF200F61LA
01DF60P05QLI200F61LH01HG6@P05ALF200E5QP801LH6Q005aTH200G61X801HH5a005aTH0P0F61L3
01LI60<061XI0`0I6aX301XL6`806adL0`0L7Q/201/M6P<06Q`I2@0J71/801/M6PP07AdK200L71X8
01dM6`P07QhL200M7A/201/M70<06Q`K0`0I6aX@01XL6`P06A/J200I6aP301PJ6@806A/J0`0J71/0
100L7Qd06adL01/M700K7A`201XL6`806A/J200J71/H01TK6P<06adL1@0J71/Q01TK6P<05A/I0`0D
6QP201<I5`P05aTH0P0F61L301LI60<061XI0`0I6aP301XL6A806adJ200L7Q/801dM6`P071hK600J
71/C01TK6P<06Q`K0P0K7A`A01/M6Q006Q`I0`0I6aP301XL6@806adJ200M7a`201/M70<06Q`K6`0I
6aX301HL6R_ooooo000Zooooo`P0Y7]7202QN4@20:IkB0030:EjA`2TNDH0Y7U600<0Y7U600@0XWU5
0:=jAP2SNTH0XgY60P2TNdL:0:ElB080XgQ5102TNDH20:EjA`80YW]800H0Yga90:IkB02UNTL0XgQ5
0:1e@P2OM4420:EjA`80YW]80P2WO4T20:QmBP80YGa80P2VODT20:MnBP80Z7m;00<0YW]80:QmBP2Z
Od`0102/PDh20:^0C@80Ygi:0`2XOd/30:V0C0P0ZWm<0`2YP4`20:QoB`<0Ygi:00<0YWe90:MnBP2W
OTX00P2XOd/20:V0C0<0ZX5=1P2YP4`02@2WOTX0ZH1<0:^2CP2/Pdl0[HA@0:b3C`2[PTh0ZX5=0;27
D`020:n6DP050:j5D@2]Q500[8=?0:b3C`2[PTh00`2YP4`20:Z1C@<0Zh9>202/Pdl80:f3D@80[8MB
1P2[QU420:b3C`030:f4D02^QE40[hIB0080/8MC00<0/HQD0:^6D@2[QU401P2[QU440:^3D080ZX9?
0P2YPDh20:V0C0<0Z7m;0`2WOTX00`2TNdL0XgY60:=jAP040:9iA@040:=jAP2LMd<0VgI209Ud@080
Ug8n00<0V7<o09Ud@02JMD400P2ILd@209Qb@`0909Ma@P2FL440UFm009E_@02AKCd0T6`l08iZ>P2=
JCT0S6Ph0080SFTi00P0SVXj08m[>`2=JCT0S6Ph08]W=`2:ISH0RFDe08MS<`80QV8b0P24HS@208=Q
<`04089P<P21Gc40P5h`081N<080PE`b0P20Fc40101oFS00OUT_07eH;P1mF2h207aE;00607YD;@1g
E2h0M58]079A;P1aD2d0KU0^0P1`DRh0101_DBd0KU0/06a>:P1[CBT206Y<:00306e<:@1^CBX0L4l/
00<0LE0]00<0Kdh[06i=:P1/CR`00P1[CB/00`1ZC2X0JD/Y06U;:@0206Q::080L50Y0`1aDBX3079B
:`0807AA9`1eDRP0Me@Z07QE:`1gE2X0MU<Y07EB:01dDBL207QE:`0407UF;01jEbd0NeP^07aI;`80
OEX`0P1kFB/04@1lFR`0OU`^07mM;`20GS00PEla089P<P27Hc40QF4_085M;@1nFB`0OUT]085L<P25
H3H0Qf4j089O=@20GC<0OU/a0080OEX`00<0OU/a081M<`22GcD02024Gc8807iN;`80Oe`b0P1nFc42
07eJ<080O5T_00@0PUle081M<`1nFc40O5T_0P1kF2h00`1lFBl0OEX`07QE:`0207QE:`80NEH/00D0
NUL]07]H;P1lFBl0NUL_07]H<00207aI<@0507]H<01jEbl0N5D]07QE;@1gE2`00P1jEbl207UF;P80
N5D]0P1gE2`307IF;`<0MED^0P1dE2d207=C;080M5@]0P1eEBh207IF;`80M58/00<0ME<]07ID;P1g
EBl00P1hES001`1iEc40MeL`07IF;`1fERl0MED^07AD;@1cDb`00P1bDR/01@1cERX0LUDY079E:`1a
E2`0LE<]0080L58^00H0Ke4_06UA;@1YDBd0JE4]06Q@;01UCBT306A<:080I4`Z0P1SBbT2069::080
HDTW1@1JAR<305]79080FTLW0P1IARH205Q59@80Ed@T0P1D@bD205=290<0DT4S00L0DD0R054m9@1?
?BD0CS`T04dm901;?B<0B3`R0080AS`Q00<0@S/Q044j8011>R000P11>R03040i7`0804Lh8@16=b00
@SHN044g7P0o>1h0@3XP044k8@12?R<3040h8`80@CTT0`12>RD803hf8@P0>cHP00@0>3<O03Td800i
=200>C@P0P0h<al203Lb7P0603Pe900g=2<0=S<R03Db8@0c<1l0<RlN0`0a;Qd202l`8P0402h_8@0]
;R00;2dO02`]7`80:b`N0P0Y:b0302PZ7`<09bTN0P0X:Ql302LY7P<09RPM0P0U9Qh602HW7`<09RTN
0P0U:1d302@W70H092LN0P0S9Qd802@W7P03020S6P0Q91/08B@K00808RDL0P0S9Qd0100T9ah09BPM
02DX7@0V:Ah502LZ7`P0:BdN00D0:R`N02/]7`0[;Al0;2hP02d_8@0202h`8P0702la8`0/;ah0;C0O
02d`7`0^<B00;c8Q030c8P02034d8`@0=C8O100f<b0203Pf8@80>CLR00@0>SPS03/i900l>RD0?3XU
0`0l=b4303dh8P80?STS00<0?SXO03di7P0l>1d00P0l>1d00`0n>Ql0@3`Q044m8P03048k7PD0@c`O
2011>Qh303di7P@0?SXO00D0?c/P03`h7@0l>1d0?CTN03hj7`02040l8@0303hj7`0m>Ah0?3PM0080
?CPR1P0l=b4203Dd7`0703Le800j=B40?CHS03lg9010>2D0@SLU044j8002040i7`0303lh7P0n=ad0
?CHL0080?3DK0P0l=b4203/f80<0>SDO00<0>C@N03hi8`0n>B<00P0m>2800`0l=b40>cHP03/f8009
03/f80@0?CPR100l=b4403hh8P@0?CLQ1010>Al403lh7P<0@CXP0P12>b4404<l8P04048k8@11>R00
@3TO03lh7P80?SLM0140?CHL03Hf700f=Q`0=cDL03Xf7@0k=Ad0?3@M03hc7@0o=1h0>38J03/e7@0n
>200?CLO03Tc6`0h<QX0>cDM03hh8004040e8@@0?c@P200n=ad304Di8`D0A3PR1`13=b400`14>280
@SHN048f7P06048f7P0404Hf7`17=b00AcLP04Ph8@80BCTR00<0B3PQ04Lg8016=Ql00P1:>2801P18
>240AcLP04Df7`12=Qh0@CLN040f7@H0AcPQ0P18>B8804@e8P0A044b7`12<b00@c@Q04@e8P13=240
@S<P040a7P0o<1d0@cPT048g8`11=R80@3DQ03ld800n<al0?C8N03`a7@10<2000`0o;al203h^7P80
?BdM0`0g:ad203HZ70<0=BTK0`0c:Q/3038Y6P80<BPI00@0<2LH02lV5`0]91D0;2<D0P0[8Q<202`S
5006034S8`0`8R80;20P02TO7P0W7ad09R4N0P0V8Ql4024S80@0828O00<07AlL01hP7@0P8Ql00P0P
8Ql0100O8Ah07AlL01`N6`0L81l401/O7P<06QhM00<06QhQ01TM800I7B000P0I7B0301PL7`P061`M
00@05QhP01DM7`0E7Al05AdO0P0D71h201<K7@@04Q`M100C7Ah8014K7@T04ahF200H6A@801PH60P0
6QXH0P0K6aT201XJ60806ATG0P0H61H301HH5@805aTF0`0H6QL801@H5`/05QPG0P0E5aH301@F5@P0
5aTH200E5aH201PI6`<05aPJ0`0F5aT801LI60P05QPG200F5aT801HH5`P05QLI400F61LI01HG6@P0
5QPG600F5aT801HH5`P05QLI200G61X@01LI60<061TK100G61X00`0F5aT05QPG01HH5`0601HH5a00
5aTH0P0F61L301LI60<061XI0`0I6aX301XL6`806adL0`0L7Q/201/M6P<06Q`I2@0J71/801/M6PP0
7AdK200L71X801dM6`P07QhL200L71X201/M70<06Q`K0`0I6aX@01XL6`P06A/J200J71T201PJ6@80
6A/J0P0J71/201/M708071hM0`0K7A`;01XL6aP06A/J0P0K7A`401XL6b<06A/J0`0E6aT301@J6080
4aTG200G6AP201HH5`<05aTH0`0H6QT301TK60<06Q`I4P0K7AX801`N6`P07AdK200K7AXH01XL6a<0
6A/J0`0J71/201/M71406adJ400J71T301TK60<06Q`I0P0K7AX801dO70806adL0`0J71/K01TK6P<0
5Q`J:oooool002[ooooo202TNdL80:1g@`D0YGY700@0Y7U60:=hA@2SN4D0XWU50`2SNTH20:AkA`80
YGa8202TNdL00`2RMd@0XgQ50:=hA@020:AiAP80YGY70`2VNdP01P2WO4T0YW]80:EjA`2SN4D0X7E2
09md@@80YGY70P2VNdP20:MlB@80Z7e:0`2VODT20:MnBP<0Z7m;00<0YW]80:QmBP2ZOd`0102/PDh2
0:^0C@<0Ygi:0`2XOd/20:V0C0P0ZWm<0`2YP4`20:QoB`D0Ygi:102XOd/80:V0C080ZX5=00T0Ygi:
0:V0C02[PTh0[8=?0:f4D02/Pdl0Zh9>0:Z1C@2`Qe<00P2_QU801@2^QE40[HA@0:b3C`2/Pdl0Zh9>
00@0ZH1<0P2ZPDd20:^2CPP0[8=?202]Pe460:^6D@80[8MB0P2/Pdl00`2]Q500[XEA0:n6DP020;27
D`030;68E02/Qe80[8MB00H0[8MB0`2ZQE430:V4D080Z8=?0`2YP4`30:QoB`80Ygi:0`2SNTH30:Ak
A`80XgY600P0WGQ409ag@`2JMD40VGA009Qc?`2IM400VWE109]f@P80VgE600@0VWA509UcA02HLT<0
Ug520P2FL4401@2BKS`0TFdk08m[>@2>JSP0SFTg0080SVXh00P0Sf/i091/>P2>JSX0SFTi08aX>02;
IcL0RFDe08QT=080Qf<c0P26I3H01025HcD0Q68d08=Q<`22H382085O<@80Pehd00@0PUdc085L<P20
Fc40OeX`0P1nFBl207eF;@0A07]E;P1gE2h0ME<^07=B;`1bDBh0Ke4_075C;`1`DRh0Ke4]06i@;01]
Cb/0K4hZ06]=:@1ZC2P0Kdh[071?;01aD2d00P1bDBh0101aD2d0Kdh[06i=:P1/CR`206]=:`0306Y<
:P1YBbT0J4XX0080IdTW0`1_CbT3071@:P80LE4[00<0LE0W079A:01dDbX00P1eE2/00`1dDbX0Le8Y
079A:00207MD:P0407QE:`1iER`0NUL]07]H;P80O5T_0P1jF2/04@1kFB`0OE/^07iL;`1oGC00P5ha
085O<P27Hc40Q60^081L;01mF2/0OEP/081K<@24GcD0Qf4j089O=@20GC<0OEX`0080NeP^00<0OEX`
081M<`22GcD02024Gc8807mM;`<0Oe`b0P1nFc4307eJ<004089O=@20GC<0OU/a07eJ<080O5T_00P0
OEX`07iK<@1fDbT0Me@Z07QE:`1iER`0NUL]07]H;P80O5T_00<0NEH^07YG;`1kF3000P1lFC40101j
Ebl0NEH^07UF;P1gE2`307YG;`80NEH^0`1hEBd207MG<0<0MUH_0`1eEBh207=C;0@0M5@]0P1eEBh0
1P1cDb`0M5@]07AD;@1eEBh0MUH_07MG<080N5Pa0P1fERl207EE;P0407AD;@1cDb`0Le</079B:`80
LUDY00P0LE@Z075D;01aDbd0LE<_071B;P1`DS00JU8^06UA;@@0Idl[00<0IDdY06A<:01TC2X00`1T
C2X406=;:@D0GTLU0`1MAR@305Y79`80FDHV0`1HABD0101EA2H0E4<U05A39@1D@bD205=29080DT4S
00H0E3hV05<o9P1@?bD0CchT04dm8`1<?R<204Tn8P80AS`S0P15>b803014>R40@cTP04<i8013>B00
AcPQ04Hg8012=Qh0@CLN03lh7P10>R00@C/Q048n8`<0@CTT0`12>RD204<k9PP0?cLR200k=ah203/f
8P0303Xe8@0i=200>3<O00<0>3<O0P0h=B80100g=240=S<P03@a7P0c<1d3038_7080<34S00<0;c0R
02h_8@0];R000P0/;Al0100[;1h0:R`O02X/7`0Z;1l302T[7P80:2XM0P0Y:b0202PZ7`@09bTN0P0W
:20602HW7`<09RTN0P0U:1d302@W70808bHM3P0T9ah2024T6`@08RDL0P0S9Qd402DX7@0402HY7P0W
:Ql09bXO02P[80P0:BdN00D0:B/M02X/7P0Z;1h0:bdO02d_8@0202h`8P0702la8`0/;ah0;C0O02d`
7`0^<B00;c8Q030c8P02034d8`P0=C8O0P0g=B000`0h=R40>CLR03Xh8`0203/i900403`j9@0l=b40
?3LQ03`g8@<0?CPR0P0n>B<0200n>Ql0?CTN03`h7@0k=a`0?3PM03di7P0o>b00@3`Q0`11?1l5040k
7PP0@3TM0`0l>1d00`0m>Ah0?SXO03hj7`0203lk8080>cLL00L0?CTN03hj7`0o>b00?c/P03hj7`0m
>Ah0>cLL00H0?3LQ0P0m>28203Dd7`0703Le800j=B40?CHS03lg9010>2D0@SLU044j8002040i7`03
03lh7P0n=ad0?CHL0080?3DK0`0k=R0303Xe7`80>C@N0`0m>28403`g8@T0>cHP00<0?STS03dh8P0m
>2800P0l=b4203/f800303Xe7`0l=b40?3LQ00H0?3LQ100o>1h4040i7`<0@CXP0P12>b4304<l8P80
A3XQ0P13>B001012>1l0@CLN044g7P11=ah203/g700403dg7@0n=ad0@CLN04<g7`80ACHO00@0@3@J
04<g7@16>R00ACTO0P12=Q`00`15>Al0B3`R04Xj8@0404Xj8@<0Bc/R201<?B0405A09@@0ED4V0P1C
?b@205A09@0405E19P1F@RL0ET8W05M3:0P0ED8R00@0FT4S05]2901K@R@0GD@V0P1OARP00`1NABL0
G4<U05]2900205m6:00405e69`1KARL0FDHV05Q59@80EDDT0P1G@R<00`1H@b@0FD@U05U49@0305Y5
9PP0FD@W00<0Ed8U05Q39P1IA2L00P1JABP02@1H@bH0ET4T05E08`1KB2X0FTLY05U6:01HABL0Ed@V
05E2900205A18`<0ED0U0P1D?b@305<n8`<0CSXR0P1=>B4304`h800304Xh8019=al0BCLO0080B3HN
0P17=Ad04P16=1`0AcDQ04Hd8013<Ad0@BlK03l]6@10;QX0@BlK048`7016;bT0@blX040/9@0m:R<0
>bXR03T[8P0i;2<0>RdT02l]8@80;R`P0P0]:al202`Z7P0302/Y7@0Z:1`0:bTM00<0;2XN00<0:RPL
02PV6P0W9AT00`0V9Qh00`0U9Ad092@L02@T700202<S6`<08b8N0P0R8Ad00`0Q81`081lK020O6`08
020O6`<07R0O0P0M7ah301`N7@D06AlM0`0H7Q`801DK6`T05alD200K614801PI50D06AXE100J6aH3
01TJ5@8061TD0P0G61<201@F4@805ALB0`0F61<00`0G6A@05aTH01LI600A01LI60805QPG0`0E5aH8
01PJ6@P05QPG0P0I6Q`201PI6`@05aPJ200H6QT801HH5`P05QLI200F61L801HG6A005QPG6@0F5aT8
01HH5aP05QLI200F61L801HG6@P05aPJ400G6AP201TJ708061TK00@05aPJ01HG6@0F5aT05QLI200F
61L@01LI60805QPG0`0G6AP301PJ6@<06A/J0`0J71/201/M70<071hK0P0K7AX301XL6@T06Q`K200K
7AX801dM6`P071`J400M7A/801`L6P806adL0`0J71/301TK6Q006Q`K200I6aX801XL6@<06A/J0P0J
71/301/M70<071hM0`0K7A`:01XL6aP06A/J0P0K7A`201XL6`806A/J0P0H6QTA01TK6Q0061XI0`0E
6aT301@J60804aTG200G6AP201HH5`<05aTH0`0H6QT301TK60<06Q`I4P0K7AX801`N6`P07AdK200K
7AXH01XL6`P061XI2`0I6aX301XL6`806adL4@0K7AX@01XL6@<06A/H0`0J71T201/M6PP071hK0P0K
7A`301XL6a<06A/J200H6QT301DK6B_ooooo000Zooooo`P0XgY6202PMd<00`2SN4D0Y7U60:EjA`02
0:EjA`030:=hA@2RMd@0XGI30080XGQ40P2RNDD20:=jAP80Y7]7202RN4H20:9gA0040:=hA@2TNDH0
Y7U60:EjA`80YW]800P0Y7U60:EjA`2VNdP0YW]80:EjA`2TNDH0XGI30:1e@P80YGY70P2VNdP20:Ml
B@80Z7e:0P2VODT20:MnBP<0Z7m;00@0ZH1<0:MlB@2YOT/0ZWm<102/PDh0102ZOd`0ZGi;0:ImB@2V
ODT20:MnBP<0Z7m;00<0ZH1<0:YoBP2ZOdX01P2ZOdX30:V0C080Z7m;0`2WOTX:0:QoB`<0ZH1<0`2Z
PDd0202WOTX0ZH1<0:^2CP2/Pdl0[HA@0:b3C`2[PTh0ZX5=102]Q4h40:b3C@80ZH1<0P2ZPDd30:^2
CPT0[8=?202^Q5820:Z5D0<0ZhIA0`2/Qe820:f4D0<0[XEA0`2_QU880:b7D0<0ZXIB0P2YQE430:R4
D080ZX5=0P2YP4`30:QoB`040:MnBP2SNTH0XgY60:AkA`80YGa800H0Y7]70:=jAP2RNDD0WgY609ii
A@2LMd<309Ye@@80W7M30P2KMDH00`2JM4D0VG=409Qb@`0209Ma@P0609I`@@2CKc/0TVhj091/>02?
JcL0SVXf0P2?JcL02P2@K3P0TFdi08m[>`2>JSX0SFTi08aX>02:ISH0RFDe08QT=027Hc<208MU=`03
08IT=P25HcD0Q68d0080Pf4c00H0PV0b08AO=@24GcD0Pehd089M<`21G382081K<@0907mJ<01nEbh0
OUL^07aF;`1hEBl0MU@_07AC<01cDRl0L58`0080L58^00@0Ke4]06i@;01^D2`0KDl[0P1/CRX00`1_
CR/0L4l/075@;@02075@;@03071?;01^CBX0KD`Y0080Jdd[00@0JT`Z06U;:@1XBRP0J4XX0P1WBBL2
06e<:@80KTdZ0`1_CR/0101`Cb`0KThW06m?:01aDBX207=C;004079B:`1aDBX0L50Y07IC:@80Me@Z
00<0N5D[07UF;01jEbd00P1kF2h01@1jEbd0NeP^07]H;P1lFBl0OEX`0080OU/a00`0Oe`b08AP;P22
GR`0P5`/07iI;01nFBd0P5/a089M<`24GSL0PEhd07mL<P1mFS0207aI;`0307eJ<01oG380PEhd00P0
Q5lb2020Fbh01020GC<0Oe`b07mL<P1oG38207iK<@80OEX`00<0P5dc07mL<P1nFc400P1mFS001`1n
Fc40Oe`b081M<`1gE2X0N5D[07YG;@1kF2h00`1lFBl0101kF2h0N5D]07UF;P1kF30207aI<@0507]H
<01iERh0NEH^07QE;@1kF3000`1jEbl207UF;P80N5D]0`1gEc0207IF;`<0MED^0`1cDb`507AD;@80
LeH^0`1dEbl307EH<0P0M5@]0P1aE2P00`1aE2X0LE@/075C;@02075C;`03075C<@1[Dbl0J50/0080
IThZ00D0J50/06UA;@1WCb/0I4`X06E=:`0706A<:P<0HDTW0P1PB2H305m79@0405]8:01JAbL0FTLW
05Y79`80FDHV0P1HABD0101HABL0Ed@V05M49P1GA2H205I39@80ED8T0P1F@2P01P1D@2L0DD0V050o
9@1>?R@0CClT04`n8`80BShV00<0BCdU04Pl9017>b<00P16>R802P15>B40B3TR04Lh8@13=al0@CLN
03lh7P0o>Al0@3XP040l8@10>2<3044i9080@SXU0P13>bH803lg8PP0?3PM00@0?CPT03`g8`0k=R80
>C@P0`0h<al01@0i=200=cDP03Le800f=1l0=C<N0080=38M0`0c<A`0100`<B<0;c0R02l`8P0_<284
02h_8@80;2hP0P0[;Al302X/7P0302T[7@0Z;240:R`Q0080:B/P0`0X:Ql00`0W:Ah0:2TQ02PY8@02
02LX80@09RLO0`0V:Ah202DX7@<092LL0`0S9Qd302@W7P809BPO200T9ah802<V7@0802HY7P0U:1d0
92LL02@W700U:1d09RTN02LZ7`0X:b0802T]7P0602PZ700Y:ad0:R`N02/]7`0/;R00;S0R0P0_<B<0
1P0/;ah0;C0O02d`7`0^<B00;c8Q030c8P80<C@S00@0=S<P03Db7`0e<Ql0=C8O0`0d<Ah0100c<1d0
=cDP03Le800g=B0303Pf8@80>CLR0`0k=R0303`g8@80?CPR00<0?SXO03di7P0l>1d00P0k=a`00`0l
>1d0?SXO03lk800303lk8080?SXO0`0m>Ah803lh7080>cLL0P0l>1d0100m>Ah0?SXO03lk800o>b02
03/g700703`h7@0n>Ql0?c/P03lk800n>Ql0?3PM03/g700203/f80<0?3LQ0`0m>28203He800603Pf
8@0k=R80?3DR03hf8`0o=b@0@CHT0`0o>1h303hg7@80?CHL0`0l=b4203/f80<0>SDO2`0l=b4203/f
80<0>SDO0P0n>B<00`0m>280?3LQ03/f800203Xe7`0303Td7P0h=Ql0>CLP0080>CLP0`0j>2400`0k
>B80?SLM03lh7P0203lh7P<0@3TO1011>R02048k8@<0@c`R2015>B42044j7P0304@j7`16>R00BC/Q
0080Bc/R00<0CC/S04Th7P1=?2800P1@?bD204dl8P03050o9@1C@RP0Dd0R0080E44S00D0ED8T05I3
9@1GA2H0Ed@V05Q59`0805a59P<0HTXX0P1SBbT306A<:P08069::01SBbT0I4`Z06E=:`1VCR`0Idl]
06Q@;P1YDBl806Q@:P0906e<:@1_CR/0Kdh[079A;P1dDc00ME@a07=B;`1aD2d0Kdh[0080M5<`00@0
LU@`075E<01^E2l0KED_0P1/ERl0101[CbL0K50X06eA:@1_Db/3071D;00306mC:`1bE300LU@`00L0
LU@`00L0LeDa07AF<P1dES80M5Hb079D<01aDbl0Ke4]0080LUHa00@0LED`071D;`1`E2l0Ke<^0P1^
DRd306i@;P80KDl]0`1/CR`306Q;:`80IdXZ0`1VBBT2069::080HDTW01@0H4PV05m79@1NAR@0GTHT
0657;01OABX0G48W05To901G?B80F3hS05To901J@2D0G3l]05/n;01G?2T0E3/W050j9@1?>RD0D3/V
04hl9P80B3TT0P17>2<01016=b80ACHQ04@e8014=B0204<d7`<0A3DP00<0@S<N040a700n;aX00P0k
<R400`0j<B00>C0O03P_7P0203L^7@0603H]700g;Ql0=bhO03H]7P0e;1d0=2/L0P0c:Q/00`0b:AX0
<bTM03<Y7@0603<Y7@80<2LN0P0_9Qd402hU7080:RPL0`0Y9a/302PV6PP0924L2@0T8AP802<L50P0
7QhF0`0M71L301hM60807ahI00@071dG01/L5P0K71H06a`F0P0J6aD201TJ50<05aXC0P0H6a@301TL
5@P06a/I200J71T301TK6P8061XI0`0G6AP801TK6PP061XI0P0J6ad201TJ70<061TK00<05aPJ01PJ
6@0H6QT01P0H6QT801LI60P05aPJ200G6AP801LH6PP05aTH200F61LA01LH6PP05QLI200F61LH01HG
6@P05aTH400G61X@01LI600601XK7@0I6Q`06AXL01PI6`0G61X05QLI0P0E5QP801HH5a005aTH0P0F
61L301LI60<061XI0`0I6aX301XL6`806adL0`0L7Q/201/M6P<06Q`I2@0J71/801/M6PP07AdK200L
71X@01dM6`P06a/I0P0K7A`301XL6`/06A/J200J71/801TK6PP06Q`I0P0I6aX201XL6`<06adL00<0
71hM01dO7P0M7ah00P0L7Qd301/M70T06Q`K600I6aX201/M70806Q`K00@06A/J01PJ6@0G6AP05aTH
4@0I6aX@01PJ6@<05A/I0`0D6QP201<I5`P05aTH0P0F61L301LI60<061XI0`0I6aP301XL6A806adJ
200L7Q/801dM6`P06Q`I400J71/801TK6PP061XI2`0I6aX301XL6`806adL4@0K7AX@01XL6@<06A/H
0`0J71T201/M6PP071hK0P0K7A`301XL6a<06A/J200H6QT301DK6B_ooooo000Zooooo`P0XGQ4202O
MT800`2QMT<0XWM40:=hA@020:AiAP030:9gA02PMD80WgA100<0X7M30P2QN4@30:9iA@P0X7I600D0
XGI30:9gA02RMd@0XgQ50:EjA`020:IkB0040:MlB@2RMd@0XgQ50:EjA`80YW]800<0YGY70:=hA@2R
Md@00P2UNTL20:IkB080Yga90P2XODX30:MnBP<0Z7m;0P2YP4`00`2YOT/0ZWm<0:b1CP030:b1CP03
0:YoC02YOT/0Yga900<0YWe90P2WOTX30:QoB`P0ZWm80`2YP4`20:QoB`<0Ygi:2`2XOd/00`2YP4`0
ZX5=0:Z1C@020:^2CP080:MnBP2YP4`0Zh9>0:b3C`2]Q500[8=?0:^2CP2ZPDd30:Z1B@80Zh9:0`2/
Pd/20:Z1C@80Zh9>0`2/Pdl00`2]Q500[8=?0:b3C`060:b3C`P0[XAB0`2ZQE000`2[QU40[8MB0:b7
DP020:f8D`<0[hIB0`2^QE420:f4D0P0[8Q>0`2YR5<20:R7DP<0YhIA0`2ZPDd20:V0C0<0Z7m;00<0
Y7]70:ElB02VODT00P2VODT01P2TNdL0XWU50:1g@`2PNdL0WgY609ehA0<0VgI20P2MN4@01P2KMDH0
VWA509YdA@2ILd@0V79309Ma@P80UW1100<0U70l09=_>`2AKCT0102?JcL2095]>@80Sf/k00H0SVXj
08eY>@2;IcL0RVHf08UU=@28I3@208QV>00308MU=`26I3H0QF<e0080Q68d00H0Pf4c08EP=P25H3H0
Q5le08=N=022GC<2085L<P09081K<@1oF2l0OUL^07aF;`1iES00MeD`07AC<01cDRl0LE<a0080Ke4]
1P1^D2`00`1^CBX0Kdh[071?;002071?;00306i=:P1/BbP0JdXW00@0JD/Y101XBRP206a;:080KD`Y
0`1^CBX01@1_CR/0K4`V06i>:01`D2X0LE4[0080LU8/00@0LE4[071@:P1fDbT0MU<Y0P1gE2X0101h
EB/0NEH/07YG;@1jEbd207]H;PH0O5T_00D0PEd[081L:P20G2`0P5/^081K;`02081K<@04085K=01o
G380OU/a07iK<@80OEX`0P1nFc400`1oG380Q5lb08AO<P0608AO<PP0PE/^0P20GC<307mL<P@0OU/a
0P1mFS00201lFBl0OEX`07mL<P22GcD0Pf0f07UF;01kF2h0O5T_0P1nFc401P1mFS00O5T_07]H;P1h
EBd0NEH^07YG;`80O5Ta00@0NeP`07YG;`1jEbl0NEH^0P1kF30307YG;`<0NEH^0P1hF34207MG<0<0
MUH_00<0MED^07AD;@1dE2d01P1cDb`407AH<0@0LeL_0P1bDR/00`1cDb`0M5@]07EE;P0207IF;`06
07MG<01aE2P0LE@X075D:P1aE2`0LE<]0P1aDbl02@1aDc40K5@`06Q@;01UCBT0IThZ06YB;P1[Dbl0
J50/06A<:00806E=:`0306A::@1SBBP0HdTX0080HTPW0P1QAbH00`1PARD0FdPX05]8:00305Y79`<0
FDHV0`1IA2L205Q39P<0Ed8U00P0FT8X05U19`1G@RL0ED4V05919@1@@B@0Cd0S04i08`80Cd0Y00<0
CSlX04dn9`1<?BH00P1:>b@02@19>R<0BS/T04Pi8P14>200@CLN03lh7P0n>1h0?cTO03hj7`03040h
8`80@CTT0`12>RD803lg8PP0?CTN00@0?cXV03hi9@0k=R80>C@P0P0h<al00`0i=200>SDQ03@b6`08
03@b6`0402h_8@0_<280;c0R02l`8P@0<34S0P0]<1l202`_7P<0:bhM00<0:RdL02/]8P0Z;2400P0Z
;24202T[8080:2XO00<0:BXR02PY8@0X:B400P0W:20202HW7`0402DV7P0V:Ah09RTN02HY7P809BPM
0`0T9a`2028U70808bHM00<092LN02DX7`0U:1l03@0U:1l402@W7P0802HY7P0U:1d092LL02<V6`0T
9a`09BPM02LZ7`0X:b0802T]7P0602LY6`0X:Q`0:B/M02X/7P0/;R00;S0R0P0_<B<01P0/;ah0;C0O
02d`7`0^<B00;c8Q030c8P80<C@S0P0f<b0203Db7`0403@a7P0c<1d0<c0M03<`7@<0=cDP0P0f=1l3
03Dc7P80>C@N0`0j=Al303/f800303lk800n>Ql0?3PM00<0>cLL00<0?CTN03hj7`0m>b800P0l>R42
03/i8080>SPO00<0>CLN03lh700o>1`01P0o>1`203Xf6`0403/g700l>1d0?CTN03hj7`80?c/P0P0k
=a`01`0l>1d0?CTN03hj7`0n>Ql0?CTN03`h7@0k=a`00`0k=R000`0l=b40?CPR03dh8P0203hi8`80
>3LR00<0>CLR03/f8P0l=B800P0m=B800`0o=280?CHL03df700303hg7@<0?cPN0`0m>28203`g8@<0
>cHP1P0l=b4303dh8P80?3LQ0P0k=R0203Xe7`0903Td7P0n>B<0?STS03dh8P0l=b40>cHP03Xe7`0i
=1h0>3<M00<0=cLO00<0>3PP03Ti8@0i>B400P0j>R8203hg7@80?cPN0P10>Al5044j8080@S/Q0`13
?2801P16=b00AcPQ04Lh8@18>B80BCXS04Xk9080Bc`U00H0B3lR04Tn8P1:?b<0CClT04lo9@1A@2H2
05A09`0@058m801F@B@0FD@W05U49`1G@RD0ET4T05Y5:01MB2/0GDHV05i79`1OB2P0H4TY065::P1R
Bb/0Hd`/06A=;@P0Idd/0P1^D2`206mA;@0<071B;P1aDbl0LE<_075C;`1`DRh0LE<_079D<01dES80
MUPd07MI=@1hFSH0NE/g201hFbl0101nEbh0P5T`081I<024GC@208MP=`0408IO=P23G3<0PEXa08AO
=@80Pf0f00<0PV4f089S=`20HcL00P1oI3L0101mGRl0Of0a085R<`23I3D208AU=P80Pf@e2024HCL0
0`26HcT0Qf@j08QU>`0208UV?00308MT>P25HSP0Q64g00P0Pf8g0`22GcL3085N=P80P5de0`1mFcD2
07aJ=0<0NeTc0P1iFC80101hF340MeL`07IF;`1eEBh207AD;@0@07YI>P1hEcP0Le8c071?<01^CBh0
Kdh_075@<@1bDC80LTl_06m>;@1]C2/0J4XX06E89P1SBBH0HTXV06=;9`80I4XY00@0HdTX06989`1Q
AbH0H4HU0P1OAB@0201NA2<0GdDT05m5901OAB@0GT@S05a28@1J@1l0F3hM0P1E@BH0101D@2D0DclT
058n8`1A?B82050l8@06054m901@?2<0Cc/R04hj8@1=>B00C3PO0P1;=ah804`g8P@0AC8Q0P14<B02
04<`7`03040c800o<Ql0?c8O0080?S4N0P0m<1d00`0l;a`0>2XM03PZ7@0603PZ7@T0=bTP200_9A/8
02XW7P<09R<N00<09b@O02PU800X9B000P0Y9R43024R7080824K0`0O81X401hQ6P807b8K0P0P8a`8
01hM6@P071hI0`0K7A`201XL6`/06A/J200J71/0100K71h06Q/M01XK7@0J6ad201TJ708061TK200H
6QT801LI60P05aPJ200G6AP801LH6PP05aTH200F61LA01LH6PP05QLI200F61LH01HG6@P05aTH400G
61X@01LI60806Q/M00H06AXL01PI6`0G61X05QLI01DF600D5AL801HH5a005aTH0P0F61L301LI60<0
61XI0`0I6aX301XL6`806adL0`0L7Q/201/M6P<06Q`I2@0J71/801/M6PP07AdK200L71X801dM6`P0
71`J200K6aT201/M70<06Q`K2`0I6aX801XL6`P06A/J200K7AX301XL6`<06adL0P0L7Qd301dO7P80
71hM0`0K7A`801XL6aP06A/J00H071hM01/M700J71/06A/J01PJ6@0G6AP201HH5a406A/J400G6AP3
01DK6@<051XH0P0C6AL801LI60805QPG0`0G6AP301PJ6@<06A/H0`0J71TB01/M6PP071hK200M7A/8
01XL6A006Q`K200I6aX801LI60/06A/J0`0J71/201/M71406adJ400J71T301TK60<06Q`I2P0K7AX2
01/M70<06Q`K4`0I6aX801LI60<051XH:oooool002[ooooo202PMd<809mf@P030:1e@P2QMT<0XgQ5
0080XgQ500<0XGI309md@@2NLd000`2OMT820:1g@`<0XGQ4202OMDD20:5f@`040:9gA02SN4D0YGY7
0:IkB080Yga900<0XGI30:9gA02TNDH00P2VNdP00`2UNTL0Y7U60:=hA@020:EjA`80YW]80P2WO4T2
0:QmBP<0Ygi:0P2XOd/30:V0C080Zh1=102/PDh00`2ZOd`0Z7e:0:IkB0030:ImB@<0Ygi:0P2XOd/8
0:YoB0<0ZH1<0P2XOd/30:MnBP80ZH1<102XOd/30:MnBP80Z7m;00<0ZH1<0:Z1C@2ZPDd00P2[PTh0
202WOTX0ZH1<0:^2CP2/Pdl0[HA@0:b3C`2[PTh0ZX5=0P2XOdL0102YP4P0ZX590:Z1B@2[PTX20:b3
B`80Zh9>0P2/Pdl30:f4D0030:j5D@2/Pdl0[8=?00H0[8=?202^Q580102YQ4l0ZXE@0:Z5D02[QU42
0:b7DP80[HQC00H0/HQD0;27D`2`Qe<0[hIB0:j5D@2]Q5020:b3C`P0[8Q>0`2YR5<20:R7DP<0YhIA
0`2ZPDd30:V0C080Z7m;0100YGa80:ImB@2WOTX0Ygi:0:ImB@2TNdL0XGQ409mf@P2PNdL0WgY609eh
A02LMd<0VgI209ag@`2MN4@0WWU50P2JM4D00`2ILd@0V79309Ma@P0209I`@@0609E_@02DLC/0Tg0j
095^>02@KCL0Sf`f0P2@KCL0202AKSP0TVli091/?02?Jc/0SVXj08eY>@2;IcL0RVHf0P29ICD01P29
IcT0R6Hh08QV>027ICL0QV@f08ES=@80Q68d00H0QV4g08EP=P25H3H0Q5le08=N=022GC<2085L<P80
OeP_00L0OEL`07UF<01gEC00ME@a07AC<01aDc40KDl[00<0KU0/0`1_DBd02@1`DRh0KTdZ06i=:P1_
CR/0L4l/06m>:`1]C2T0JdXW06Y99P0606Q::080JD/Y0`1/BbX206e<:`<0KTd/00T0JT`V06]=9`1]
CbT0Ke4[071B;01_DB/0KU0Z06e?:@1eDRP00P1fDbT00`1gE2X0N5D[07UF;00207YG;@@0O5Ta0P1k
F30207YG;`80Oe/Y00H0P5`/085L;`21G300P5/a07mJ<01oFC8207eJ<00407iK<@1oG380Oe`b07iK
<@80OEX`2024Gc88085K;P<0P5dc0P1oG38307iK<@0;07eJ<01lFBl0O5T_07aI;`1nFc40PEhd08=P
=P25HSP0NeP^07aI;`1nFc400P1oG3801P1nFc40O5T_07YG;@1hEBd0NEH^07YG;`80O5Ta00@0NeP`
07YG;`1jEbl0NEH^0`1kF30207YG;`<0NEH^0P1hF34207MG<0@0MUH_0P1dE2d407=C;080LU8[0P1f
FS800`1eFC40M5P`07=G;`02079F;P07075E;@1`D2T0LE4Z079B:`1cDb`0MED^07MG<00207QH<@80
L5<W00h0LE@Z075D;01aDbd0LE<_079D<01bE380K5@`06Q@;01TC2P0IThZ06YB;P1/E300J50/06A<
:0@0IDd[101VCR`0101UBbX0I4XY06A::@1SBBP206989`80HDLV0`1KB2P205Y79`<0FDHV00@0FTDX
05U49`1IA2L0FD@W0P1H@bH205M29@80FT8V00`0Ed8U05I1901D@B<0DD0R05118P1?@240DD8[0511
:P1?@2T0CSlX04dn9`1<?BH304/l9@0704Tj8`15>B40@SPO03hg7@0m=ad0?SPN03di7P0303lg8P80
@3PS0`11>B@803lg8PP0?CTL00@0@3/W03lj9P0l=b<0>C@P0P0h<al0100i=200>SDQ038`6@0b<1T2
03<a6PD0=38K00H0;BhP02h_8@0^;b40;c0R030a8`0a<R@2038c9@<0;C0O0P0/;ah302/^7@80:bdR
0P0Z;24302T[800302PZ7`0Y:R80:BXR0080:2TQ00@09bPP02HW7`0V9al09BHN0`0V:Ah202DX7@<0
92LL0P0R9A`202<V7@0402@W7P0U:1l09BPO02HY80P09BPO100V:B0402DX7`0302HY7P0U:1d08bHK
00808bHK00<09BPM02LZ7`0X:b00200Y;Ah202LY6`0402T[7@0Z;1h0;2hP02d_8@80;c4S00H0;2lN
02d`7`0]<1l0;S4P02lb8@0`<b82034d8`80=S<P00@0=C8O03@a7P0d<Ah0<c0M0P0b;a`203Le8003
03Hd7`0e<ah0=38M0080<c4L00<0<S0K03Pc7@0h<ad00`0i=1h303Xe7`0803lk800n>Ql0?3PM03/g
700j=Q/0>cLL03`h7@0m>Ah203`j8@80>cTP00@0>SPO03Tg7P0i=ah0>3HM200n=a/01P0i=AX0>SHK
03/g700l>1d0?CTN03hj7`80?c/P0P0j=Q/0200l>1d0?CTN03hj7`0n>Ql0?CTN03`h7@0j=Q/0>SDO
0P0k=R000`0l=b40?CPR03dh8P0203hi8`80>CPS00<0>SPS03/f8P0l=B800P0l=2401P0n<b40?3DK
03`e6`0m=Q`0?SLM03lh7P80@3TO00@0@CXP03hi8`0n>B<0?STS0P0m>28803`g8@D0?CPR00@0?3LQ
03/f800k=R00>SDO0P0i=1h203hi8`0403dh8P0l=b40>SDO03Td7P80>3<M0P0f=Qh0100g=al0>3PP
03Ph800i>B4203Xj8P<0?SLM00<0?cPN040i7`11>R001@11>R02048k8@<0@c`R0P16=b001018>B80
BCXS04/l9@1<?BH204ho:080C44U00P0Cd4V05519`1C@RP0ET8Y05M3:P1I@b/0F44R05a59P80GdPY
00`0GDHW05a59P1PBBX0Hd`]06=9:01TBRT0ID/Z06I<:`1XCRd0JDl^06Y@;`1[DC0806mA;`<0MED^
00<0MUH_07MG<01hF3400`1hF3401@1iFC80NUXc07aL=@1nGSL0P60i0080PV8k2021HS<03P28GC80
RUld08YO=02>HcP0TFHk099W?02AIS/0SV<h08aQ=P2<IST0SFLj08aW>P2;JC/0Rf/l0P2;K3d01@2:
KSh0RVTf08a[>02>KCX0TG0m0080TW4n00<0TG0m091_?02@JS/01`2@JS/0202CKCh0U6ho09E_@02F
L440UFm009A^?`2BK3d0TF/l102>JSX308m[>`03091/?02?J3d0SfPm0080SVLl0`2=IS/00`2<ICX0
RfHl08]V?00208YU>`80RF@j0P28HcT03025I3T0Q6<h08=R=`22HCH0PF0e081O=01oGS<0OUdb08MU
@P24HSl0Oedj07]I=P80NUPe0100O5Xg07iL>@1lFBl0NeP^07MF:`1cE2P0LU<W06mB9P1^DbH0Ke@W
07QF<01gEBl0MU@^07EC;@1dDR`0Le4[0P1bD2X03P1aCbT0LU0Z079@:P1bD2X0LDlY06m=9`1/BR@0
JdTS06M=:P1VC2T0ID/X06A:9`1SBBH0HTPU0P1QAb@01P1RAbT0HDHX06159`1OA2H0GT<U05e29080
G44S201L@BH205Hl9@80EC/T0`1D>R<0101C>B80CSdS04hm8`1=?28204`k8@0304/j801:>Al0BSTO
00P0AS@P2@13;bH803L]8@P0<S0T0P0/:B8202dZ8`0402h[900_;2D0;b`U030]9P<09RLO0`0U9Qh2
02@U7@<092LN0P0U:1l302HY80P081lK200N81/0100M7ah071hM01`N7@0L7Qd201/M70X06Q`K200K
7A`201/L7P806Q/M0`0I6Q`00`0H6A/061XI01PJ6@0601PJ6@P05aTH200G61X801LI60P05aPJ200G
6AP801HH5a405aPJ200F5aT801HH5aP05QLI200G6AP@01LH6Q005aTH0P0J6ad00`0I6Q`061TK01LH
6P0201DF600301@E5`0F61L05QPG00H05QPG400G6AP201HH5`<05aTH0`0H6QT301TK6P<06Q`K0P0K
7A`301`N6`806adJ0`0J71T901XL6`P06adJ200M7A/801`L6PP07AdK200L71X801/K6@806adL0`0J
71/;01TK6PP06Q`K200I6aX801/M6P<06Q`K0P0K7A`301`N7@<07AlN0`0L7Qd201/M70P06Q`K600I
6aX0200L7Qd06adL01XL6`0I6aX061XI01LI600F61L05ALF4@0I6aX@01LI60<05A/I0`0D6QP201<I
5`P05aTH0P0F61L301LI60<061XI0`0I6aP301XL6A806adJ200L7Q/801dM6`P06Q`I400J71/801TK
6PP05aTH2`0I6aX301XL6`806adL4@0K7AX@01XL6@<06A/H0`0J71T:01/M6P806adL0`0J71/C01TK
6PP05aTH0`0D6QP[ooooo`00:_ooool00`2PMd<0WgI209ie@@0209ed@00309mf@P2QN4@0XgY60080
YGY700<0Y7U60:=hA@2RMd@00P2QMT<0302PMD80XGI30:1e@P2NLd00WG8o09ic@02PMD80XWM40:=h
A@2TNDh0XWM<0:1eBP80WgA900@0XGI;0:AiCP2UNTl0WgE50P2PMTH00`2QMdL0XWQ80:=iB@020:Aj
BP<0XgQ50P2TNDH30:EjA`060:QmBP2WO4T0Yga90:IkB02UNTL0Y7U60P2SN4D20:EjA`80YW]80P2W
O4T20:QmBP80ZWm:102YOTT20:QmB0T0Z7m900<0ZWm<0:UnB`2WO4T00P2VNdP01P2WO4T0ZGi;0:Yo
C02YOT/0Zh1=0:b1CP80[X=@00<0[85>0:^0C@2YOT/00P2XODX40:UnB`80ZWm<202YOT/20:ElB004
0:ImB@2WOTX0ZH1<0:Z1C@80Zh9>0P2XOd/30:V0C0<0ZX5=0P2YP4`01P2ZPDd0Zh9>0:b3C`2]Q500
[XEA0:n6DPP0[H=A202/Pdl30:^2CP<0[8=?0P2]Q5030:b3C`80[HA@2`2^QE400`2YPe80ZXAC0:^5
E0020:b6E@030:Z4D`2XPU40Yh5@0080/HMG00<0/8IF0:n5E@2^Q5@00P2/PU80102[PE40Zh9:0:^2
BP2[PT`20:^2CP030:^1C`2[PE40Zh5A0080YH1<00<0Y7m;0:=nBP2RODT00P2QO4P0102PNdL0XWQ8
0:5gA`2OMDD209idA0030:1fAP2RN4P0Y7Y:0080W7M300<0VgI209Ye@@2IM4000P2HLcl0102GLSh0
Vg4o09]a?`2JL3h209U_?@80V6hl0P2GKC/408mT=`@0SV<f0P2<IcX00`2;IST0RVDh08UT=`0208QS
=P0608MR=@27HC80Qf4b08IP<@25Gc00Q5h_0P23GBh02P22G2d0P5`/07iJ:P1kERT0NE@X07QC:@1i
Db`0NU@_07]E<01iERh207QE;@0307MD;01fDb/0ME8Z0080M54Y0P1cDb`207AD;@05079B:`1_CbP0
K4`U06Y:8`1WBBD00P1XBRH0201YBbL0JT`X06]=:@1[CBT0K4hZ06i@;01/CRX0JddY0`1YBbL02P1[
CBT0K4hZ06Y<:01[CBT0KDl[06mA;@1`DRh0Ke4]06e?:`1/CRX307=B9`80M5<X0`1eE2T0101gEbh0
MUH]07IF;@1fERd307EE;00407AD:`1kF2h0O5T_07eJ<080OU/a00/0OEX`07aI;`1kF2h0Oe/[089N
;P24H300Pel_07mK:`1mFBT0P5`/08=O;`02089O=@80PEhd00@0P5dc07mL<P1oG380OU/a0`20GC<2
07mL<P<0OU/a0`1mFS0507iK<@0307YG;`1lFC40OU/c0080P5de00<0Oe`d07iK<`1mFS80101lFBl4
07eJ<0<0NU/_0`1iFRh307QI;@80OEXb00@0O5Ta07]H<01iERh0N5D]0P1gE2`807UI<PP0LE4X00P0
L54U075B9P1dE2/0MED^07EE;`1dDc00Le8_075@;`<0L58^0P1aDbl3079D<00306mB:P1`Db/0L5<[
00@0L5<[0P1_DRX606iA:@0906e@:01/D2/0JdlZ06Y>:@1YCBP0J4`W06M;9P1VBRD0IDTT0080HT/R
00@0Hd/U06=;9`1SBbL0Hd/Y0P1TBb`206189P80GdLU00D0GTHT05e58`1LA280G4@R05E2900205I3
9@0505M49P1HABL0FDHX05U6:01JAbT0201C@280101D@bT0Dd8X05=2:01B@BL205509P80D3lU00P0
D3TW04hi9P1;>RH0AS/U044m900m?B<0>CdR03Pn8PP0?3LQ00<0?cLR03hf8@0l=1l00P0k<ah00`0l
=1l0?SHQ03lg8P08040h8`<0?3LS0P0k=R8<03Xe8@0303Dc7P0f=1l0=cDP0080>3HQ01<0=cDP03Hd
7`0e<ah0<2/H038]6P0d;a`0=c8O03Pc800g<Ql0=S4N03D`7@0Z;aP0:c0J02`a6`0]<Qh0;30O02X^
7`0W:ad09BTK0080:blP00<0:RhO02T]7P0X;1d00P0W:a`01`0V:Q/0:bXU02XY900Y:2<0:2LR02HU
800U91l00P0T8ah802HX7@P092HK200T:B8802HX7@P0:B`Q0`0Y;Ah202X^7`<0:blP200^<B002`0_
<A`0<38M038d7`0d=R40=CLR03@f8@0b=1l0<C<N02/^6@0/;aX0;c8M00<0<C@O00P0;c8M02ha700e
;al0=S0P03Lb7`0g<Qh0>3<O03Td7P80>SHM00H0?S<O03de800m=B00?CLQ03dh8P0k>B8203/k8`P0
?3LQ0`0l>1d00`0m>Ah0?SXO03lk800203lk80P0?3PM100l=A/203df70<0?SLM0P0k=R0303Xe7`<0
>C@N0`0h=Ql203Tg80<0>SPQ200l=b4203`j9@80>cTT00@0>SPS03Tg8P0i=b80>3HQ0P0j=QT0100k
=aX0?3PK03di700m>A`203hj7@0803Tg800j>240>cTR03`j8`0k>B80>SPQ03Pf7`0f=1d803Dg7`06
03Ha7@0g<Q`0>SDO03`h7`0n>Ql0?SXM0P0m>Q/2044i8P03044j8012>al0@S/N0080@cdM00D0@cdK
04Xm7@1;?Qh0BchN04`o7`0204e08080CT4Q00H0D3lS050o8@1A@280DD4P0592801B@Qh205=47@04
05I27@1HA1l0FTHQ05a88`80GDTT01/0G4PS05]78P1RBb/0HDXZ06199`1OBB@0H4XS069<8`1TCRD0
IU4V06a=;P1]Cbd0Ke4_075C;`1dES00MUTa07QK<@1iG380LUL/07=H;@1dEbd0MeL^07UH;`1kF300
O5Ta07iH<@1lFC400P1mFS800`1nFc<0Oe`d081M=@02085N=P80PV0b00@0Q68d08ES=@27ICL0RFLi
0P2:J3X208MT?00308QU?@29ISh0RVLo0080RfQ000P0S6U108m]@02?KD00Sfe0091^@02AKcl0TW4n
09=b?`80U7<n0P2DLT@309EcA@<0UWA600<0UgE509QfAP2JN4P00P2KNDT00`2JN4P0V7I609MeA@02
09IdA00409MeA@2HMTH0VWQ809]iB@80W7Y:0P2LNT`0102KND/0VWQ:09YhBP2IMdT209QfB0P0V7U=
00P0VWMA09]hDP2LNE40W7U?09]iC02IMdT0UWA409Ab@P<0V7E;0P2GM4X309IcB@80Tg8o0P2BLCh3
095`?@05091_?02@KD<0T6e308m/@P2>Jd400P2=JT0208aY?`<0RVLm0P29IS`308QU>`0<08YX>P29
IcT0R6Hh08MU=`26I3H0QF<e08AR=023HC<0QF<e08=Q<`21Gc40OU`^0P1mFbd02P1nG2h0Oed_07mM
;`1lFR`0N5HX07EC9@1dDR@0ME<U07QF:01jF2X207UD:P80N5<Y00@0Me8X07IA9`1fDBL0ME0V0P1_
CRd206i=;00406e<:`1/BbX0JdXY06]::@80K4L/00@0JdH[06Y5:P1ZABX0JD@Y0P1X@bP00`1ZB2d0
J4H[06I4:@0206A29`0;06E3:01VA2T0IdDZ06I7:`1S@bX0H40W05dm9P1K>bH0FSTV05Xi:01K>RT0
0P1L>Ql205Xk7`0505Pj7P1F>ah0E3/M05@k7@1C?1d0201C>Q`00`1<?a`0BSdJ04Tl6@0204Pk600;
04Tl6@1:?AX0C3lL04Pj7`16>1d0A3HK048d6@11<aP0@38G044c6012=1T02010;2401P0f<QD0=S8G
03Hb5`0e<AP0=C0J03@_6`80=2lL00@0?BdM03`/700i:AT0=bLG0`0f9QH0100g9aL0=BXH03DZ600e
:QP203@Y5`<0<bPF0`0d9aL203<V5P<0<RDE1@0T9aH302DX5`809b0J0P0V7aT0100U7QP091dG02@M
5`0S71H202PQ6`809b0J100V7aT02`0S6Q<091/D02@M5@0T81L08b0G020P5P0O7aD07AlD01dL600N
7AT081lK00808B0L00<081lK01hM6@0M71P00`0N7AT201dL60<071/G200J6aD401PJ5`@06A/H200J
6ad00`0E5aH05QPG01HH5`0401HH5`0301DG5P0I6Q`06AXL00L06AXL0`0D61T201<G60<04QHG00<0
5a@K01PE700J5ah00P0K61l02@0J5ah061DL01LD6`0K6AX06QXJ01TI6@0H6QT05ATH01@J6002018K
60P05AXM0`0L6A@201/H4`<06QLB200L6A@2018G6P804aPK00@051TL01DJ7@0E6Qd05Q/N0`0G6ah2
01HJ7@<05ATL200E6Qh8018H600301<H6`0B5aX04AHI008041DH00<04AHI01<H6`0D6A`0200E5QX2
018G6P@04aPK0P0D6A`801<H6`<05aPJ0P0F5aT301DF60<05a/J0P0H71/301TM70<06Q`K0`0I6aX2
01PJ6@P061`K2@0F6QT301TM70806QhM0`0K7ah201hL7@0401dM7@0L7Qd06QhM01XN7@806AlM200J
7Qd00`0M8Qh06b0L01XO6`0301PM6@0301TN6P0J7a/07AdK00L07AdK00@06a/I01`L6P0L71X071`J
0P0M7A/201hN708071`J0`0K6aT301XJ60P06A/J200J71/801TK6PP071hK2P0K7AX301XL6@<06A/H
400J71/@01TK6P806Q`K0P0I6aX301PJ6@0301LI600I6aX06A/J00l06A/J200G6AP801@J60P061XI
200G6AP201HH5`805aTH100H6QT801XL6a<071hK0P0K7AX301XL6@P071hK200I6aX801XL6`806adL
0`0J71/;01TK6PP05aTH200J71/301TK6P<06Q`K0P0K7A`901`N7AP06Q`K0`0J71T201/M6PH071hK
0P0K7AX301XL6@P06Q`K100E6aT401HL6P805adK0P0F71X201DK6@8051XH2`0D6QX[ooooo`00:_oo
ool0202PMd<0WgI209ie@@2MM400WWE109mf@P2QN4@0XgY60P2TNDH30:=hA@@0XWM400L0XGI309md
@@2OM440WgA10:5f@`2SN4D0Y7U60080XWM:00L0XGI90:1eB02PMDP0XGI90:9gBP2SN4/0WgE50080
X7I600<0XGM70:9hB02SNDT00P2TNTX30:=hA@80Y7U60`2UNTL30:IkB0<0YGY70P2TNDH20:EjA`80
YW]80P2WO4T20:QmBPH0ZGi90P2XODP90:QoB@030:YoC02YOT/0Yga90080YW]800H0Yga90:UnB`2Z
Od`0ZGi;0:YoC02/PDh20:f2C`030:b1CP2ZOd`0ZGi;0100ZGi;0`2WOTX20:QoB`80ZH1<00<0ZX5=
0:QoB`2XOd/00`2YP4`30:Z1C@80ZH1<00@0ZX5=0:^2CP2/Pdl0[HA@0P2^QE480:f3D@P0[8=?0`2[
PTh20:b3C`<0[HA@0`2/Pdl20:f4D0/0[XEA00<0ZXAC0:^5E02/QUD00P2/QUD00`2ZQ5<0Z89A0:N1
D0020;67E`060;26EP2_QED0[XAD0:f3D`2/PU80Zh5A0P2[PTX0102[PT`0Zh9>0:^2CP2[PDl20:^1
D@80YH1<00@0Y7m;0:=nBP2RODT0XWe90P2QO4P00`2RN4P0XGM70:1fAP0209meA@030:1fAP2RN4P0
XgU90080W7M300@0VgI209Ye@@2IM400VGA00P2HLcl209]a?`0309Y`?P2IKcd0VFlm0080V6hl0P2G
KC/3095V>@<0T6Dh0P2?I3L208aW>P0408]V>@2:ICP0RF@g08UT=`80R6<f0P27HC801026H340QEl`
08AN;`24GRl208=M;P08081L;01nFRX0O5LZ07YE:@1iE2X0NE</07YD;`1kEC0207UF;P0407QE;@1g
E2`0MU<[07EB:P80M54Y0P1cDb`01P1dE2d0Le</079B:`1_CbP0K4`U06];90<0JD/W0`1ZC2P206]=
:@0306a>:P1[CBT0JT`X0080JD/W00`0JT`X06a>:P1]Cb/0JT`X06]=:@1]Cb/0KU0/06mA;@1^D2`0
KDl[06a>:P1bDBH307=B9`80M5<X0P1eE2T607EE;080MUH]00<0NUL]07]H;P1mFS000P1nFc40301m
FS00NeP^07YG;@1nFRX0PUh^08AP<022GRh0Oe/[07eI:@20G2`0Pel_089O=@80PEhd0P20GC<207mL
<P0407iK<@20GC<0P5dc081M<`80Oe`b0`1nFc4207eJ<0H0OU/a00P0NUL_07aI<@1nFc<0Oe`d081M
=@1oG3@0OU/c07eJ<P<0NeP^00<0O5T_07eJ<01nFc400P1nFc4307YK;`<0NEX^0`1hFBd207aI<@04
07]H<01jEbl0NUL_07UF;P80N5D]201hF348079B:@08075B9P1bDbL0M5@[07EE;P1eEBl0M5<`07=B
;`1bDC03071B;P80LE<_0`1bE30;071C:`@0Ke8Z00H0KU4Y06]?:P1[CbX0JThY06U=:01XC2L306M;
9P80Hd`S00@0Hd/U06=;9`1SBbL0Hd/Y0P1TBb`01P1QBBL0H4PV06189P1OAbD0GTHT05e58`80G4@R
101GA2H405Q59`P0Dd0R0`1C@RP00`1B@BL0DD0V05509P02050o9@80CcXW00H0BcXV04Hk9@12?2@0
?S`S03/n8`0i?B8803hh8P0303lg8P0n=R40?3@O0080>c<N00<0?3@O03hf8@0o=b802010>2<303`g
8`80>cHR300j=B4203Le80@0=S@O0P0g=B000`0b;AX0=2lL03D`7@0303Lb7`0;03D`7@0d;a`0:c0I
02`a6`0]<Q`0;C8N02``7`0Z;Ql0:2`N02HZ700/<2400P0[;b000`0Z;Ql0:BdN02P/7@0202L[7005
02XY900Y:2<0:BPS02PW8P0W9R400P0V9B000`0U91l09RPM02HX7@0602HX7@P09BLL200S:24802HX
7@P0:2/P0`0Y;Ah202X^7`<0:blP200^<B000`0_<A`0<38M038d7`0303@f8@0@038d7`0a<ah0:bhI
02d`6`0_<Qd0<3<N034d7`0`<ah0;c8M02ha700f<200=c4Q03Lb7`0h<al0>C@P03Xe7`80>cLN00P0
?S<O03de800m=B00?CLQ03`g8@0k>B80>SXR03/k8`P0?3LQ0`0l>1d00`0m>Ah0?SXO03hj7`0203lk
80P0?3PM2@0m=Q`203/f80<0>SDO0`0i=1h303Pf7`<0>CLP0P0j>24803`g8@<0>cTT00<0>SPS03Tg
8P0i=b800P0h=R4303/g70<0?3PM0P0m>Ah00`0h=Ql0>CLP03Xh8@0203Xh8@0303Pf7`0g=Ah0=C<L
00P0=3HN00P0=S4M03Lb700j=Al0?3PO03hj7`0n>Qd0?S/L03dj6`80@CTR00<0@S/Q048k7`13?1l0
0P13?Ad00`14?Q`0BchN04/n7P0204`o7`0404e0801>@B40Cd8R04m28P80Dd0R00@0E44Q05E28P1F
@b80EdDQ0P1HAR00101LBB40GDXR05m<901QCRH2069?9`0B065>9P1PCBD0Ie0`06M@;P1UCR`0IDlZ
06I@:@1XDRT0JUDZ06]F:`1^D2h0Ke4_071B;P1cEBl0MEP`07QK<`1jGC<0Nehd0P1hGC000`1jGC40
OEhb07mN<`02085N=00608AO=@22GcD0PUle08=P=P24HCL0QF8h0P26HcT02@27I3X0R6Hh08QV>02:
J3X0RfTk08e[?@2>K3h0Sfdo091^@00208i[@@0308m/@P2@KD<0TFi40080TVm500H0Tg16099`@P2B
L480TW1209=a@`2DLT8209Ed@@0309Ie@P2FMD00UgE70080UgE70`2HMTP209UgB@0309YhB02KNDT0
W7Y:0080WG];00<0W7Y:09]iB@2JN4P00P2IMdL0102JN4P0VgU909ajBP2MNd/209ilC0030::0DP2Q
Oe40XGmA0080X7i@0P2OODl00`2NO4h0Wh1D09n0E00609n0E080XWmI00L0Xh1H0:>0EP2RP5<0X7i@
09ekB`2LNTX0X7eC00<0WgaB0P2NNe4209ejD0<0VgY70P2JNDH309UhA@80V7E;0`2GM4X309IcB@<0
Tg160`2BKdD2095^A00509=a@`2BL480TW12095_@@2?KCl00P2>K3h01@2=Jcd0Sfdo08i/?P2;JC/0
RFLi0080R6Hh00X0RFLi08YX>P2:J3X0QfDg08=Q<`20GS00Oed_085O<@23HC<0QF<e0`23GS@00`22
GC<0PE`b085L<P02081K<@80NUXc00<0NETb07QH<@1gEc000P1fERl01@1eEBh0MU8`07IB<01fDS00
ME4_0080M50^0P1cCbd00`1cDS40LU4`071?;P0206i=;00706m>;@1`Cbh0LE0_071?;P1^CB`0JdX[
06U7:`0206M5:P0306Q6;@1XABl0J4DY00<0IT@X00<0I4DX06959`1PABL00P1NABH805e2900305Y6
8`1IAB80Ed<P0080ET8O00L0Ed<P05U58P1JAR<0Ed8W05I19P1C?R<0DC`Q0080D3/P0P1A?24204hi
9P80CCPU0P1<=b@204/f8`80ACXN00<0A3PN04@h8013=b400P13=R<01@12=B@0AcHT04He8`13<R00
@C0N0080@2lM00<0@C0N048a7`10<b000`0o<Ql203ha7P80?C0M00@0?blO03h^7P0n;Qh0?RhN0P0m
;Ad203`/70D0<b`J0`0d;A/203@Z8@80<bTP0P0b:1l2034W7P80;bDL0P0^91/402dS6P0;02hQ600]
8aT0;R@J02lW700^:1`0:bLK02TW6P0X9QT09B0L02HQ7@0W8Qh00P0X8al00`0W8Qh09R4M02DP7002
02PS7`809b8N0`0V8Ad00`0U81`08B4I024Q6@06024Q6@P0824K200N7Q`801dM6`T071`L0`0K7A`2
01XL6`<06A/J00<06AXL01XK7@0K71h00P0L7Al02@0K71h06Q/M01TJ700N6QT071/I01/J600J6QP0
6A/H01HK5`0201DK5`P05a/L0P0I6AL301PH5P<05aLE200I6AL201HJ6`805a/L0P0H71d201TM7P<0
6a`N0`0J6ad201TJ70P051TL200E6aT00`0F71`05A/K01@J6P0201<I6@0301@J6P0F71`05adM00P0
61TK0`0E6a/=01HL70<06AXL0P0H6A/301LH6P<05Q/G0P0G71P301PM6@0401/M6P0J71T06Q`I01XL
6@806A/H0P0H6QL801PM6@T06AhJ0`0K81`201`Q7@<07B8N00H07a/J01dL6P0M71X071`J01/M6P0I
7QX201PN6PP06AhJ00P0724M01/P700I7QX061dI01LL600H7AT06AhJ01XO6`P071`J0`0K6aT201`L
6P<07AdK0`0L71X201/K6@<06QXH200I6aX801XL6`P06A/J4`0K7AX201XL6@<06A/H400J71/@01TK
6P806Q`K0P0I6aX401PJ6A406A/J200G6AP801@J60P061XI200G6AP201HH5`805aTH0`0H6QT00`0I
6aX06Q`K01XL6`0601XL6a<071hK0P0K7AX301XL6@P071hK200I6aX801XL6`806adL0`0J71/;01TK
6PP05aTH200J71/301TK6P<06Q`K0P0K7A`901`N7AP06Q`K0`0J71T201/M6PH071hK0P0K7AX301XL
6@P06Q`K100E6aT401HL6P805adK0P0F71X201DK6@8051XH2`0D6QX[ooooo`00:_ooool0202PMd<0
WgI209mf@P2NMD40WgI20:1g@`2QN4@0XWU50`2RMd@30:=hA@80Y7U600X0XgQ50:9gA02RMd@0XGI3
0:9gA02SN4D0Y7U60:EjA`2PMDP0XGI9102RMdX00`2QMTT0X7E809me@`020:1fA0030:5gA@2RN4H0
XgU70080Y7Y80`2SN4D20:AiAP<0YGY70P2TNDH30:EjA`<0YW]80P2UNTL20:IkB080Yga90P2XODX5
0:QmB0<0ZGi92@2XOdT00`2ZOd`0ZGi;0:QmBP020:MlB@030:QmBP2YOT/0ZWm<0080ZWm<00@0Zh1=
0:b1CP2/PDh0Zh1=0P2ZOd`@0:UnB`040:Z1C@2YP4`0ZH1<0:V0C0<0Z7m;00<0Ygi:0:QoB`2XOd/0
0`2YP4`30:Z1C@80ZH1<00@0ZX5=0:^2CP2/Pdl0[8=?0P2]Q5080:b2D0P0[8=?0P2[PTh20:b3C`<0
[HA@00@0[XEA0:b3C`2/Pdl0[8=?0P2]Q50;0:j5D@090:Z5D@2[QU80[8MC0:f8E02/Qe<0ZhIB0:V4
D02XPdl0/HME0080/8ID00<0[hEC0:j4DP2]Pe400P2/PU020:^2BP040:^2C02[PTh0Zh9>0:^1C`80
Zh5A0P2VPDd00`2UP4`0Y7m;0:=nBP020:9mB@040:5lB02SNDL0XWQ60:5gA@80X7I400@0XGM50:9h
AP2SNDL0WGQ40P2LMd<00`2KMT80VWE109Ud@00209Qc?`80Vg4o00<0VW0n09U_?@2IKcd00P2HKS`2
09M]>`80U6Tl0P2CJ3/3099W>P07095V>@2=J3/0S6Lj08aW>P2;IST0RVDh08UT=`0208QS=P80R68c
00<0Qf4b08IP<@25Gc000P24GRl01`23GBh0P5`/07mK:`1mF2/0O5L[07]F;01kEBh00P1kEC0207UF
;P0307QE;@1gE2`0MU<[0080ME8Z00X0M54Y07=C;01dE2d0M5@]07=C;01bDR/0L50Y06i>9`1/C2D0
K4hZ0`1[CBT606Y<:0<0JD/W00P0JddY06e?:`1_DBd0JT`X06]=:@1/CRX0KDl[06i@;080KDl[00@0
K4hZ075A:01aDBP0LE4X0P1bDRT507=C:P0407AD:`1eEB`0MED/07IF;@80MeL^00<0NUL]07]H;P1l
FBl00P1mFS002`1lFBl0NeP^07YG;@1mF2/0P5/^08=N<@22GC00OUT/07eH:`1oFRd0Peha0080PEhd
0P20GC<407mL<P<0P5dc0P1oG38;07iK<@0507]H<01lFC40OEXb07iK<`1oG3@00P1nFc<02@1mFS80
NEH/07YG;@1kF2h0O5T_07eJ<01nFc40Oe`b081M<`0307YK;`<0NEX^0`1hFBd807YG;`P0MUH_201d
E2/0201bDbL0Le@X07AD:`1dE2d0M5@^07=B;`1bDBh0LU4`0`1`DRh2075C;`<0LU@`0P1aE2`4071C
:`80LE@/0`1bEBd2075D;0<0L5<[201YCBP206A=900406A<9P1TC2P0I4`X06=;:@80HdX[0P1QBBL0
0`1PB2H0GdLU05i6900205e58`0305a48P1HABL0F4DW0080F4DW101GA2H805A18`80Dd8X0`1B@BL3
05509P08050k9P1=>bD0C3`U04Pl9014?B<0@CdR03hm8@0m?B4903lg8P0703hf8@0m=B00?3@O03`d
7`0m=B00?SHQ03lg8P08040h8`<0?3LS0P0k=R8<03Xe8@0303Xh8`0h=R40=C<N0080<c4L00<0=C<N
03Pf8@0j>2<00P0f<Ah303Lb7`0403Ha7P0e<1d0=2lL02da6P80;S4L00D0;S4N02d`7`0[;Al0:R`O
02PZ7@0202d_8@0302`^800[;Al0:R`N0080:B/M00<0:2XL02PX800X:2001P0X:20@02LY7PP092LN
200W:Ah802LZ7`<0:BdN0P0Z;Ql302/_80P0;S4P00<0;c4L030b7@0b=1l00`0c=B02038d7`0302`_
6P0]<1/0;c8M00<0<3<N0P0_<Qd203Pb8P0403Td8@0i=200>SDQ03/f8080?3PO00H0?c@P03de800m
=B00?3HP03`g8@0j>24203Xj8PP0?3LQ0`0l>1d203di7P<0?SXO200l>1d2040i7`80?cPN00D0?SLM
03df700l=A/0?3DK03/d6P0203/f80<0>SDO0`0i=1h203Le7P80>3HO0`0i=b000`0j>240?3LQ03`g
8@0603`g8@<0>SPS0`0i=b8203Pf8@<0?3PM0`0k=a`203Xf6`0303Hd7@0g=Ah0>3HO0080>3HO00<0
=S@M03Dc700c<AX0200c=Ad0200f<Ad0>3<M03Xe7`0m>B00?SXO03hj7@0n>a`0?CXK0P14>B<00`14
>R40AC/P04Dl7`0204Hm7P0604Hm701=?Ql0CChO04ho801?@240D44R0P1A@R<03@1B@b@0ED8T05E2
8P1GA2@0F4DT05Y8901LBR@0GD/S05i<901TCRL0IDlX06MA:P1YDb`00`1ZE2d04@1YDb`0KUHd06eE
<`1]EC40KED_06iG;P1`FBl0LU/a07=L<01aDc40LU@`07=E<@1fF380N5/c07YM<`1lGc<0OF0d0080
Of@g00<0PF@h08AU>@26ICX00P28IC/01P2;IS`0RFHl08UV?02:Icd0RfPn08aY?`80SFY000L0SV]1
08m]?`2@KT00TFm1099`@P2CLD<0UG=50080UWA60P2FLdT00`2GM4X0V7E;09UfC00209YgC@0709]h
CP2FM4@0UWA409IdA02GMDD0V7I609UgA`0209YhB00409]iB@2KND/0VgU;09]iB`80W7Y<0`2MNdd0
0`2NO4`0Wge=0:1nCP020:5oC`040:1nCP2OODd0WWa<09ekB`80WWa<00<0Wge=0:1nCP2QOdl00P2R
P5020:R6F080YhEG102VQ5H80:N8G0080:Z7H@2[R680ZhQP0:^8GP2ZR5/0Z8IH0:N5E@2VQ5@30:R5
F`<0YhAJ0P2VPeT20:J4E0<0YH=C0`2TPU820:5nE0<0XWmE0`2SP5H409mlDP80WW]A0P2MNU001P2O
ODl0WWa>09ilCP2MNdd0W7Y<09]iB`80VWQ:00@0WG]=09ajC02JN4X0V7I80P2GMDL309QfB00709Id
AP2CLD<0T6i008m]?`2@KT00TW1209=a@`03095/@P<0T6]10P2?JT0208U[>@0408QZ>027JCL0QVPf
08EW=@80Q6Hd00@0QF<f08AR=@24HSD0Q68e0`23HC@01022H3<0PF8f081Q=@1nGc<307eN<P80OUlc
00H0Ne`^07YK;@1iFRh0MeL^07MG<01gEc4207QG=080MU<c0P1eE3<01@1bE380LE@b06iD<@1^E340
KEDa00P0KE0^00<0L4l^06i=;01]C2/00P1/BbX01`1]C2/0KTd/071?;P1^C340KD/`06]9;P1YAb`0
0P1XAR/00`1YAb`0JTP]069;:`02065::P0505m8:01NAbL0GDHV05a59@1KA2@00P1KA2D0101K@bL0
FT8X05Y2:P1I@2X205U0;00305M3:`1F@RX0DclW00<0DCdU0P1B?RH2054o9`80D3hV0`1??BD0101>
?2@0C3XT04`j901<>R@204/i8`<0BSPR2019=2<404@g9`80@cHV0P12=BD303/^7P80>RdM0`0i;1`0
2`0l;1d0?BdN03d`800m<B40>c8Q03Tb800g<1h0=C0M034W7@0b:1h0<bTO0080=2XP00<0<bTO038X
7P0a9ad00`0e:b4203@Z80<0<bTO200_:Ad802dY80P09R4K0P0Y91h402PS7@80:B@N2@0T7a/302<R
7@808R4L0`0Q81/00`0K81`0724M01hS7`0201lT800;01hS7`0L8Ad06b0L02@L6@0R7AT08A`H020M
600M71L071dG01/N5`0J7AH0200L71X201LK70<05QXK0`0E6AX801LK708071`J0`0M7A/301hN7004
01lO7@0N7Q`07QhL01hN70807AdK0P0L71X801LI60P06adJ00<07AlN01`N7@0J71/00P0I6aX00`0J
71/06adL01`N7@0801/K6a006adL0P0L71`301/K6`<06QXJ0`0G6AH201PJ5`<06A/H0`0L71X201/K
6@<06QXH200K7AX<01hP7@807b4N0`0P8Ql201lK6P0401dL6P0L71X071`J01/M6P806AhJ200K7AX0
0`0N81d071hK01/M6P0301TK600301XL6@0K7AX06a/I00L06a/I0`0J6QP201/K6@<071`J00@07AdK
01`L6P0L71X071`J0P0K6aT201XJ60P06A/J200J71/801TK6PP06Q`I200K7AX0100L7Q/06adJ01/M
6P0K7AX201XL6@806A/H400J71/@01TK6P<06Q`K0P0I6aX301PJ6A406A/J200G6AP801@J60P061XI
2`0G6AP201PJ6@<06A/J200J71/C01`N6`806adJ0`0J71T801`N6`P06A/J200J71/201/M70<06Q`K
2`0I6aX801LI60/06A/J0`0J71/201/M70T071hM600J71/301XL6@806adJ1P0L7Q/201/M6P<06Q`I
200J71/401HL6P@05A/I0P0G7A/201HL6P805A/I0P0D6QP;01@J6R_ooooo000Zooooo`<0WgI20P2P
Md<20:5hA0070:9iA@2PMD80XGI30:5f@`2RMd@0XgQ50:AiAP020:EjA`030:AiAP2SN4D0XgQ50080
Y7U600H0YGY70:IkB02VNdP0WgE50:1fAP2RN4P20:AjBP040:9hB02OMDD0WG=309mf@P80X7M300<0
XGQ40:9iA@2SNTH00P2TNdL30:=hA@80Y7U60`2UNTL20:=hA@030:AiAP2UNTL0YW]80080Yga900<0
Z7e:0:EjA`2UNTL00P2VNdP20:MlB@80Z7e:0P2WO4L40:QmB080ZGi92@2XOdT30:UnB`80Z7e:0`2Y
OT/20:YoC0@0Zh1=102ZOd`40:UnB`80Z7e:202YOT/20:b3C`040:^2CP2ZPDd0Z7m;0:MnBP80YWe9
0P2XOd/30:V0C0<0ZX5=0P2YP4`20:Z1C@040:^2CP2/Pdl0[8=?0:b3C`P0[89@202]Q5030:b3C`<0
[HA@0P2^QE430:b3C`80[HA@2`2^QE400`2ZQE00ZhIA0:b7DP020:f8D`030:^6D@2YQ4l0Z8=>0080
/8MC0P2_QU80102^QE40[HA@0:f4D02]Q5020:b3B`040:b3C@2/Pdl0[8=?0:b2D080[89B0P2WPTh0
102VPDd0YH1<0:AoB`2SOTX20:9mB@030:AkA`2SNTH0XgY600D0XWU50P2MN4@00`2LMd<0VgI209Ye
@@0209Ud@00409Qc?`2KLCl0Vg4o09Y`?P80VFlm0P2HKS`209M]>`80Uf`o00@0UV/n09EZ?@2EJSd0
U6Tl0P2CJ3/208eX>`0308aW>P2;IST0RVDh0080RF@g00L0R6<f08US=029Hc@0R68c08MQ<P26H340
QEl`0080Q5h_00H0PEd]081L;01oFRd0OUT]07eH;P1lERl207aF<@0607YG;`1iERh0NEH^07QE;@1g
E2`0MU<[0P1eDRX207AD;@80Le</00D0LE4Z071@:@1_CbP0KThW06i@;00206e?:`0406a>:P1[CBT0
JT`X06Y<:0<0JD/W0P1XBRH0101ZC2P0K4hZ06i@;01`DRh206Y<:080JddY101/CRX306iA:@80Ke8Z
0`1`Db/02`1aDBP0LU8Y07=C:P1dE2/0MED/07IF;@1gEbh0N5P_07UF;01jEbd0NeP^0080O5T_00/0
NeP^07YG;@1iER`0NeHZ07mJ;P22GC40PE``07eH;01lEb/0OeX^089M<@02081M<`H0Oe`b0`20GC<2
07mL<P<0OU/a00<0Oe`b07iK<@1nFc400P1nFc4307eJ<00307]H<01lFC40O5Ta0080OEXb0`1nFc<2
07UF;00407YG;@1lFBl0OEX`07mL<P80P5dc0`1jFbl307UJ;P<0N5T]0`1iERh207YG;`<0NeP`201e
EBh807IF;@0807=D:01dEBT0M5@[07AD;@1cDbd0Le8_079A;P1bDC03071B;P80LE<_0`1bE3000`1b
EBd0LE@/071C:`0206mB:P04071C:`1aE2`0LUD]07EH<080M5L_00<0LeH^079E;@1aE2`00P1aE2`0
101XC2L0JDdX06U=:01YCBP306Y>:@0406]?:P1UCRD0IDhU06A<9P80I4`X00<0I4`Z06=::`1SBR/0
0P1QBBL0101PB2H0GdLU05m79@1NAR@205e58`0505Y7:@1IARP0FDHX05Q59`1GA2H00P1F@bD905E2
90H0DT4W0P1A@2H0201??BD0CS`T04dm9019?B<0AcdR04@m8@12?B00@CdP2010>2<803hf8@P0@3PS
0`0l=b<203/f8P`0>SDQ00<0>cTT03Pf8@0e<ah00P0b<1/00`0e<ah0>3HQ03/i900203Td8@80>3<P
00D0=c8O03Ha7P0e<1d0=2lL030b7002030b7@0502l`7P0^;al0;BhP02`/800[:al00P0_<2800`0^
;b40;BhP02`]7`0202//7P0402X[7@0X:1h0:2PN02PX7P80:BTO0`0Z:R0802PZ7`P0:B/P200U9a`8
02LY7PP09RTN0`0Y;Ah202X^7`<0:blP200^<B02030b7@80<C<N100b=1l202ha70H0;c8M0P0h<R80
100i=240>SDQ03/f8P0l=b4203di800603ld800m=B00?CDP03`f800k=R00>CLP0P0i>B4803`g8@@0
?3PM100m>Ah803`h7@<0@CXP00@0@3TO03lh7P0m=Q`0?3DK0P0k=1X203/f80<0>SDO0`0i=1h303Le
7P80>3HO0`0i=b0803/f8080>CLR1P0h=R4203`h7`80>cLN00`0>SHM03Te700h=1/0>3@K03@b6`0e
<a`0=S@M03Le7P0f=1d0=C<L03<a6P0b<1T8038d700603Lb7P0h<ad0>cHP03di800o>b00?c/N0P0n
>a`204Hj900304Hj8P17>b40Ac`P0080B3dO00L0B3dM04ln801??R00D3lQ05508P1C@R@0E4<U0080
ED@V00d0F4<T05U49@1KAbH0GDTV05m;9P1QCRH0He0V06AA9`1XDBP0JE8Y06YC:P1[E2/0K5D/00<0
KEH]0P1aEc@03P1aEc80LUTa07AK<P1eGC40MUhb07MO<@1eEc<0MUPb07MI<`1iG3@0Nehd07eP=01o
Hc@0P6@e0P22IcP00`24J3T0QfPj08UX>`0208]Y?00608iY?@2<JSd0S6Xm08e[?P2>K3l0Sfe00P2@
KT402P2AKd80Tg5309=a@`2DLT@0UG=509IdAP2GMDL0V7I809UgB@2JN4/209]iC00309ajC@2MNdh0
WWa?0080Wge@00L0VWU409]jA@2KNTD0VgY709akB02MNd/0WWa>00<0Wge?0`2POU020:5oD@80XX1B
0P2TPU840:F3D`80Y89B0`2SPE400`2TPU80YH=C0:F3D`020:J4E0L0ZXQJ00<0ZHMI0:b=H@2/SF40
1P2/SF420:n<IP040:n<I02_S680[XaO0:f;G@80[8YJ00@0[X]Q0:f:H02]RV00[HYP0P2/REl20:^8
GP80[H]M0P2/RU`20:^9F`80ZXQJ0P2XQE/20:V6G0040:Z7G@2[R5h0[8UO0:b9G`80Z8EK0`2WQ5X3
0:J3F@80YhEG0P2VQ5H0102UPeD0Y89D0:B2E02TPU@20:J4EP030:F3E@2TPU@0Xh5C00@0Xh5C00<0
XX1B09mmC`2MNdd00P2LNT`00`2MNdd0WWa>09agC@0609agC@0609]fC02EN400UGQ009Ag?`2CMSh0
TWDm0P2AM3`00`2@Lc/0T6lj091_>P03091_>P<0Sfhi00@0S6hj08]]>@2;KCT0RV`h1029JcL01P26
Ic00QFH`08EV<025IC80QVHe08IV=`80QfHi0P24HC/208=Q>`05085Q>P1oHSX0OF4i07eQ>@1kHST0
201hG3@00`20F3D0OeLd07eE<P0207aD<@0607eE<P1oEc@0P5Pe07mF>01nECL0O5<e0`1jDC<0301k
DS@0O5<e07=K;`1bFRh0L5P/06mG:`1]EBT0Je<W06YB9P1YDBD0L4d]06m<;080Kd`^00`0KT/_06i:
<01]BC40KDTa06I=;`1UC2h0HdX/0658:P1PAbT0HDPZ0699:`1SBR`40699:`80HDPZ0P1PAbT205a4
:P<0Fd<Y0`1J@RP205`l9`@0Fc/V0P1J>RD205<n:@H0DSdX0`1=>2<204`g8P<0BcHQ00P0C3DS04`g
901=>2D0C3XV04Xi9@18>B@0A3PR04<g8@80@S8R1013<b<5048b8P80@C4Q0`10<20803d`80@0>C0Q
100h;b0803<Z6`0303D[7`0d:Qh0<bTM0080<RPL00<0<bTM03@Z7P0e:al02@0^91/302dV7080;2DK
0`0[91X00`0Q91T08RDJ02@W700202DX7@0302@W700R9AX08B@I0080:b0J00@0:R4J02TP6@0X8AT0
9B4H0P0T8AP802DP6P806alP0`0J7Ql301TM7PP06alP200S7QP3028O60<08AhG0P0P7AH801XK5@P0
7QlI00<07b0K01hO6P0L7AP00P0K71L00`0L7AP07AhI01hO6P0801dL60807AhI100L7AP201/L5`P0
71dH0`0L6aT201/J60<06QTG0P0H6A@201TJ5@<06Q/F00<06a`G01lN6P0O7QX00P0N7AT201dL6080
71/G200M7QT901lP6`807AhI0`0N7aX301lP6`808A`I00H081`I01hM6@0M7QT07AhI01`N6@0J7aT8
01dN6@0301lO7@0N7Q`071`J00806QXH00<06a/I01`L6P0M7A/0200K6aT301XJ60806a/I0`0L71X2
01dM6`<071`J0`0K6aTH01XL6`P06A/H200K7AX201`N6`<06adJ0`0J71TH01XL6`P06A/J0P0K7A`2
01XL6`806A/J0P0H6QTA01TK6PP05aTH200D6QP801PJ6@X05aTH0`0H6QT301TK6PP06Q`K400K7AX3
01`N6`806adJ0`0J71T801/M6PP06A/J200J71/201/M70<06Q`K2`0I6aX801LI60/06A/J0`0J71/;
01/M71P06Q`K0`0J71T201/M6PH071hK0P0K7AX301XL6@P06Q`K100F71X401DK6@805adK0P0F71X2
01DK6@8051XH2`0D6QX[ooooo`00:_ooool00`2OMT80X7M30:1g@`020:5hA0<0XWU500H0X7E20:5f
@`2QMT<0XWM40:=hA@2TNDH20:EjA`030:=hA@2TNDH0Y7U60080YGY70`2VNdP02@2OMD<0X7I40:9h
AP2TNTP0XgU70:5gA@2NM480W79009mf@P020:1g@`030:5hA02RNDD0XgY60080Y7]70`2SN4D20:Ai
AP<0YGY70P2SN4D00`2TNDH0YGY70:IkB0020:MlB@030:QmBP2UNTL0YGY70080YW]80P2WO4T20:Qm
BP80YW]60P2WO4L20:QmB080ZGi92@2XOdT30:UnB`80ZWm<0`2YOT/80:YoC0030:^0C@2ZOd`0ZWm<
0080ZGi;0P2XODX00`2WO4T0ZGi;0:UnB`060:UnB`80[HA@00@0[8=?0:Z1C@2YP4`0Ygi:0P2VODT2
0:QoB`<0ZH1<0`2ZPDd00`2YP4`0ZX5=0:Z1C@020:Z1C@<0Zh9>202/PU080:f4D080[8=?0`2]Q503
0:j5D@<0[8=?0P2]Q50;0:j5D@080:^6D@2/Qe80[HQC0:j9E02]R5<0[8MB0:Z5D02XPdh30:n6DP@0
[XEA00@0[HA@0:b3B`2/Pd/0[8==0P2/Pdl00`2/PU00[89B0:b2DP020:R3C`040:N2CP2VPDd0YH1<
0:AoB`80Xgi:0`2UO4P20:AkA`040:=jAP2RNDD0XGQ409iiA@80WGQ400<0W7M309]f@P2JMD400P2I
M40209]a?`0309Y`?P2IKcd0VFlm0080V6hl0P2GKC/209U^@@0409Q]@02GK3l0UV/n09EZ?@80U6Tl
00H0SVTl08eX>`2=J3/0S6Lj08]V>@2:ICP208UT=`80RV@e00@0RF<d08QR<`27HC80QV0a0P25Gc02
085M;@06085L;`20Fbl0OeX`07iH<@1mEc80O5Ha0P1jEbl00`1iERh0N5D]07MD;00207IC:`0507EB
:P1dE2d0M5@]07=C;01bDR/00P1aDBX2071@:@0506mA;@1^D2`0KU0/06e?:`1/CRX00P1[CBT00`1Z
C2P0JD/W06U;9`0206Q:9P0506Y<:01/CRX0KU0/071B;P1ZC2P00P1YBbL206Y<:080JddY00@0K4hZ
06a@:@1/D2T0K50Y0P1]DBX306iB:`80LE4X00@0LU8Y07=C:P1eEB`0MUH]0P1gEbh00`1hEB/0NEH/
07YG;@0207]H;P0;07YG;@1iER`0N5D[07YE:`1mF2h0P5/a07mJ<01mF2h0O5L]07mJ<022GC<00P1n
Fc4607mL<P<0P5dc0P1oG38307iK<@<0Oe`b00<0OU/a07eJ<01mFS000P1lFBl307]H<080O5Ta0P1m
FS802@1nFc<0NEH/07YG;@1kF2h0O5T_07eJ<01nFc40Oe`b081M<`0307YK;`<0NEX^0`1hFBd307UF
;P80NUL_0`1kF30807EE;PP0MUH]0P1eERX00`1dE2/0Le</079B;002079A;P04079A<01`DRh0L58^
071B;P80LE<_0`1bE3000`1cERh0LUD]071C:`0206mB:P04071C:`1bEBd0LeH^07II<@80MEP`00D0
M5L_079E;@1aE2`0LE@/071C:`0306U=:080JThY0`1[CbX206I?9P0406E=9`1UCBT0I4`X06A<:P80
HdX[0P1RBRP0101QBBL0H4PV05m79@1NAR@205e58`0505Y7:@1IARP0FDHX05Q59`1GA2H00P1F@bD9
05E29080DD0V1P1B@BL01P1??bD0CShT04hn901<?R<0BChR04Pm8@80ASdP2013>2@203hf8@@0?cLR
0P0n=R48040h8`<0?3LS0P0k=R8<03Xe8@0303/i900h=R40=C<N0080<S0K00<0=C<N03Pf8@0k>B@0
0P0j=B800`0i=240>3<P03Lb7`0303Ha7P0603@c7P0c<Qh0<S4M034`7P0`;Ql0;bdP0P0_;B42038`
8`03034_8P0`;R40;bdP0080;R`O00@0;B/N02TY7@0Y:Ad0:BTM0P0Z:Qh302/[7a00:B/P200V:1/8
02PZ7`P09RTN0`0Y;Ah202X^7`<0:blP200^<B04030b7@80<C<N0P0b=1l00`0`<ah0;c8M02lb7@03
02ha7080;c8M0P0h<R80100i=240>SDQ03/f8P0k=R0203`h7`0603ld800m=B00?CDP03`f800k=R00
>CLP0P0g=al803`g8A00?3PM0P12>b401`11>R00@3TO03lh7P0n=ad0?CHL03`e6`0k=1X00P0k=R03
03Xe7`<0>C@N0P0f=1d203Le7P80>3HO0P0i=b0803/f80D0=cDP0`0h=R401P0l=b40>cHP03/f800j
=Al0>C@N03Pc7@80=c8L00P0=38K03Dc700f=1d0=cDN03Hd7@0e<a`0<c4J034_60P0<S@L00P0=c8N
03Td7P0k=R00?SXQ03lk800o>ah0?c`M03hk7080BCXU00<0BCXS04Xl8P1:?2400P1;?B004@1;?Qh0
D3lQ05508P1B@B<0Dd8T05E49P1FABL0EdHX05Q7:@1MARH0GTLW05m89P1RC2L0I4hW06I@9`1XDbP0
JE@Y00<0JU4X01h0Je8Y06aC:P1]E2/0KUD/06mF;@1aEC00LUHa07AH<@1eFC40Me`a07QM<01iGS40
NEh_07YL=P1jGCD0O5lg07eP=P1oHSH0PFDf089V=P23IcL0PVPg08=Y>024J3P0QfPi08UY>P2;JC/0
S6Xl08iY?02<JS`208e[?@0308i/?P2?KCl0T6i00080TFm10P2DLT@0102ELdD0UWA609MeA`2GMDL2
09QfB080VgU;00@0W7Y<09ekC@2MNdd0WWa>0P2OODl01`2NOTD0Wgi809mnB02OOTT0X7m<0:5oC`2R
P5<00P2SP5H20:>1D`80Y89D0`2UPeD00`2VQ5H0ZHMG0:R6EP050:R6EP030:V7E`2WQED0Z8IF00<0
Z8IF0`2YQeL60:Z8FP80ZhUK202]SV820;2=I`040:n<I02^Rf40[XaO0:j<GP80[XaL0P2_S6830:j;
H@<0[HYP102^S5l20:f;GP80[8YM00D0ZXMM0:^8GP2[R5h0[8UO0:f:H0020:j;H@030:n<HP2/REl0
[8UO0080ZhQN0P2ZQed20:V6G0@0ZXQJ102YQeT50:Z8FP070:V7F@2XQUP0Z8IH0:V7F@2WQEL0YXAF
0:B2E0030:>1D`030:B2E02SOU@0XgiD00H0XgiD00H0WH1809aoA`2LOdL0Vgi609YmA@2IO4@209Qk
@`H0UgI00P2HMd4509=e?`09099d?P2ALcd0TG<m08i^<`2>KSD0Sflf091_>@2AL3/0TG0m0080TFlo
00T0T6/o08mZ?P2=Jch0SF/n08a[?P2:Jcd0R6`m08M[?026Jc`02023IcP00`2<H3/0Relj08UM>002
08QL=`0C08UM>02;GcX0S60k08]O?02:GS/0R5`i08MK>026FSL0Qe/h08QL>@29GCX0PV@b085S<@1o
HBl0OV0^07aN;01jG2X0NE/Y07QJ:00207eF;`0407eE<@1mEC80O5<c07aC<`80Ne8d00<0LeDa075C
;`1`DRh00P1^D2`00`1_DBd0L58^075C;`02071B;P<0Ke4]0`1^D2`306U<;0<0J4/[0P1WBRX00`1/
A2X0Jd<Y06]3:@0206Y2:080JD4W00<0J40V05a1901L@B@01P1M@RD305m49`80GT<V0`1M@RD0201K
?BD0FShV05/o9`1J@2L0FD4W05E09@1B?R<0DCdR201C?BD304li8@<0CSPP0P1==al804/f8@80B3LS
0P17=R801016=B40AC@P04Dd8015=20804@c7`03044`7P10;ad0?RdK0080?B`J00<0?RdK040_7@11
<1h02@0n;1h0100g:a/0=RXJ03HZ6P0f:QX203DY6@80=2PH00<0:bXH02`[6@0];1X00P0^;A/00`0]
;1X0;2/I02/Z600203PW7@0403HX7@0d:1`0<RPL038X7080<2PK200a9ad0100W9R809RDQ02HU8@0V
9B4202DT808092<O200W9R8202/Q5`H0:R0F0P0X8QH202LQ5@809R0D0P0U7a<802<Q5@P08b0G00@0
924J02<P6@0Q7QL081dF0P0O71D00`0P7AH08AhG020M5P07020M5P808AhG0P0P7AH0100O71D07Q/D
01hK500N6a@801lL5@0401hJ5`0M6AH07ATF01dI5P8071PE0P0K5a@201/L5P8071dG0`0M7QP00`0N
7aT0924L02<P6`0202<P6`808QlJ0P0Q7QT801lP6PT07AhH00@06a`F01`M5`0L7AL071dG0P0M7QP2
01hO6@809AdJ00<08ahJ028O6P0P7aX00P0O81X00`0N8AX07b0J01lP6P0601lP6P08020P7P0O7ad0
7AdK01`L6P0K6aT071`J01dM6`0N7Q`801`L6P<06a/I0P0L71X601dM6`<071`J0P0K6aTH01XL6`P0
6A/H200K7AX301`N6`<06adJ0P0J71TH01XL6`P06A/J0`0K7A`201XL6a@06A/J200G6AP801@J6100
5aTH0`0H6QT301TK6PX06Q`K400K7AX301`N6`806adJ0`0J71T801/M6PP06A/J200J71/201/M70<0
6Q`K2`0I6aX801LI60P061XI0`0I6aX301XL6`/06adL600J71/301XL6@806adJ1P0L7Q/201/M6P<0
6Q`I200J71/201LM6`805Q`J0P0E6aT201@J60805adK0P0F71X201DK6@8051XH2`0D6QX[ooooo`00
:_ooool01@2OMT80X7M30:5hA02RNDD0XgY60080XWU500@0XGQ40:9gA02RMd@0XWM40`2SN4D20:Ai
AP050:9gA02SN4D0Y7U60:EjA`2VNdP00P2UNTL0102TNDH0XGQ40:5hA02RNDD20:5hA00409mf@P2M
M400W7<o09mf@080X7M100<0XGQ20:9i@`2SNT@00P2TNdD30:=hA@80Y7U60`2UNTL20:AiAP<0YGY7
0`2VNdP20:EjA`80YW]80P2WO4T20:QmBP80YGY500@0YW]60:MlA`2XODP0Z7e80P2YOTT90:QoB@03
0:QmBP2YOT/0ZWm<0080Zh1=00H0ZWm<0:UnB`2XODX0Zh1=0:YoC02YOT/20:QmBP030:UnB`2ZOd`0
Zh1=0080Zh1=00@0ZWm<0:UnB`2YOT/0Z7e:0P2WO4T80:UnB`80[HA@00@0[8=?0:^2CP2YP4`0Z7m;
0P2WOTX20:QoB`<0ZH1<2`2ZPDd80:^1C`P0[XEA00@0[8=?0:f4D02]Q500[HA@0P2^QE420:n6DP<0
[8=?0P2]Q50;0:j5D@080:^6C`2/Qe00[HQA0:j9DP2]R540[8M@0:Z5CP2YQ4d80:j5C`80[8=;00@0
[8==0:b3C`2/Pdl0[89@0P2/PU801P2YQ500Z8=?0:R3C`2WPTh0YX5=0:F0C080Y7m;00P0YGa60:Im
A`2VODL0YWe70:ElAP2TNdD0XWU30:5h@P80WWU500<0WGQ409ag@`2KMT800P2JMD40102IM400Vg4o
09]a?`2JL3h209U_?@80V6hl0P2GKC/209Y_@P0609U^@@2HKD00UV/n09EZ?@2DJC`0TfPk0P2>JC`0
0`2=J3/0S6Lj08]V>@0208YU>00708UT=`2;ICH0RV@e08YT=@29Hc@0R68c08MQ<P0208IP<@80PUh^
00L0PUd`089M<@21G380P5Xc07iH<`1mEc80NeP`0080NUL_00<0NEH^07QE;@1gE2`00P1fDb/00`1e
EBh0M5@]07=C;003075A:P80LU8[101^D2`306e?:`0306a>:P1ZC2P0JT`X00<0JD/W00<0JddY06e?
:`1_DBd00P1YBbL306Q:9P0306Y<:01[CBT0K4hZ00<0JdlZ0P1/D2/306eA;005075A:01bDRT0LU8Y
07=C:P1dE2/00P1eEB`0101fERd0Me@Z07QE:`1iER`207YG;@0;07UF;01hEB/0Me@Z07QB:`1lERl0
OeTb07iH<@1lERl0NeD^07iH<@22G3D00P1mFS0207iK<@@0Oe`b0`20GC<207mL<P<0OU/a0P20GC<0
0`1oG380OU/a07eJ<00207aI;`0:07]H;P1lFC40NeP`07]H<01jEbl0NeP`07aI<@1mFS80OU/c07]H
;P<0O5T_0`1mFS00101nFc40NU/_07YK;`1jFbl307UJ;P<0N5T]201jEbl807IF;`P0MUH]00P0MeP/
07EF:P1dE2/0LU8[075A:`1aD2d0LU4^079A<0<0L58^0P1aDbl3079D<00307EH<01cERh0L5<[0080
Ke8Z00T0L5<[07=F;P1eF300MUTa07EH<01dEbl0LeH^079E;@1`Db/00P1_DRX306]?:PD0JThY0P1W
D2L0101VCRP0IDdY06A<:01TC2X206=::`80HTXX00@0HDTW06189P1OAbD0GdLU0P1NAR@405Q59`@0
Ed@V201F@bD305509P<0DT4W0P1C@RP01P1?@BH0CT0U04lo9@1>?R@0CCdS04`l8P80Bc/Q2015>2D2
03hf8@0403lg8P10>2<0@3PS03lg8P80?SHQ2010>2<303`g8`80>cHR300j=B400`0j>2<0>3HQ03Dc
7P0203<a700803Dc7P0h=R40>SPS03/f8`0j=B80>C@Q03Pc800g<Ql203Pc800903Td8@0g=B00=C8O
03@a7P0b;ah0<BhO034]8@0a;B80<RhS0080=30T00<0<blS038^8P0a;B400P0`;2000`0_:al0:b`N
02//7P0602//7PP0:R`Q200Y:b0802TZ70P0:2XO200W:Ql302T]7P80:RhO0`0[;b0802ha8080<38M
0`0_<A`0200`<Qd0<S@O03<e800a=1l0<3<N02lb7@0^<A`0;C0K0P0^<A`01`0_<Qd0=S0P03La8@0g
<Ql0>3<O03Td800j=Al00P0k=ah01P0o=200?CDP03de800l=R00>SDO03Pf7`80=SHN200l=b40100m
>Ah0?3PM03`h7@0l>1d303/g700303Xf6`0l>1d0?3PM00H0?3PM0`11>R001010>Al0?cPN03lh7P0n
=ad203df7080>cHP0`0j=Al303Td7P<0=S@M0P0g=Ah303Pf7`P0>SDO0P0e<ah203Hd7`@0=cDP100i
=20303Pc7`0403Lb7P0d<Q/0=C<L03Hd7@80=cDN00<0=C<L03<a6P0b<1T0200c=Ad01P0g<Qh0>C@N
03`g8@0n>R40?c/P040l7`80?c`M0P1;>RH00`1;>b@0C3`S04`l8P0204dn8@0704dn7`1C@280E44S
05E2901GA2H0FDHX05Y7:@0205a9:`80HDTW00L0Hd/W06A<9P1VCbH0J54W06UB:01ZDbL0KE8W00<0
K54V00T0KE8W06mD:@1aER/0LUL/079D;P1cEBl0MUTa07QK<@1jGC400P1kGc004P1kGbl0OV4i07mR
>P20HcT0PF@h08=W>024J3P0QFTg08IZ>023JCH0Q6Xg08EY=`28JSP0RVXi08aZ>P2=Jc/0Sf/k08e[
>`80SV`l00<0Sfdm091^?P2AKcl00P2BL40209IdAP80UgE70P2HMTP209UgB@80VgU900<0W7Y:09ek
B`2NO4`00P2OODd02P2POTh0XH560:61AP2QPDH0XX5;0:>2C`2TPU@0YH9H0:F2FP2VPed30:J4EP80
YhEG0`2XQUP00`2/RUX0ZhUI0:Z8F0020:V7E`030:Z8F02[RET0[8YJ00P0ZhUI0P2ZR5X20:^9F`@0
[8YL202]SV801P2aSVP0/8eW0:n<I02^Rf40[XaO0:n=G`80/8iN0P2`SF<30:n<HP<0[X]Q0P2_S682
0:j;H@<0[HYP00@0[8UO0:f:H02]RV00[HYP0`2^Rf420:n<HP80[X]Q0P2]RV030:b9G`030:^8GP2/
RU`0[8YL00H0[8YL0P2[RE/02`2/RU`0[H]M0:f;G@2/RU`0ZhUK0:Z8FP2[RE/0ZXQJ0:V7F@2XQUP0
YhEG00<0YXAF0P2WPUP30:R3F@<0ZHAJ0P2RQ580102QPe40X89@09n1C`2OPDl209j0CP<0W7]80P2M
O4T309imBP0<09YlBP2KOD/0W7i<09anC02KOD/0VWa:09UkB@2HNTP0V7Do09Uf@02JMT80VgM50P2K
MdL209YeB080VG=40P2HM4@01@2ELd<0U7A3099d@P2BM480T7A200P0SW0n00<0U6Y209=Y@@2BJ400
0P2@ISh01P2BJ400TfU109AZ@P2BJ400TFLo08mU?@80SV@l00<0SfDm095W?`2BJ4000P2=JCL0302<
J3H0RfLe08UU<`28I380Qf<a08IR<028HS<0Qf4b08MQ=027H3D0QUlf08IO>080QEdi00<0P5de07mL
=01mFS800P1lFC40101mFS80OU/c07mL=020FS<307mI<P80OUPa0P1mEc0307MG<080MUH_0`1eEBh0
1P1hCbl0Mdh^07M>;P1fCBd0MD`/07A;:`80LdXZ101ZBBH206]:9`80K4/X0`1`Cb`206m>:`<0KTdZ
0P1ZAbT02@1ZBBX0J4TZ06I9:@1SBBP0H4HU05i6901UB2P0I4LW06=69P0206959@0306=69P1TAbL0
IDPX0080H4<S0P1O@R8305i18@0305e0801I?b@0FClT00H0FClT0P1H@2P205Lo9`0405Hn9P1E?BD0
E3`T05@l90P0EShR00<0DCPR04lf801==1h00P1;<Q`00`1==1h0CcHP054h8P0904lf8P80A3@M0P13
<a`4048b6`0303l`7@10<Ah0@S<P0080@c@Q00<0@S<P040a7P0o<1d00P16<2800`14<B80@S4Q044a
8@0203ha800303db800m<200?C0P00H0?C0P0P0h;R8303L]8@<0=R`P200h;R8303HY6@<0=BPH0P0d
9aL2034X5`80<2LF0`0_9QD00`0^9A@0;RPJ02hX6P0602hX6PP0:bDI00@0;BHN02`U7@0Z8a/0:24I
0P0W81P00`0X8AT0:B8J02DQ600702DQ6080:B8J00<0:24I02LP600V7aL00P0U7QH00`0T7AD09b0H
02LP600602LP60808QdI0`0Q71P3020K5`<08B4I0P0R8QX302<S6`<0:2<M0P0W8Q`302HQ6`P08b<K
2@0P81P301lO5`80820H0`0Q8AT202TP6`0302PQ6`0V8A/09B8K00808b<K00<08R<K02<S6`0S8a/0
1P0S8a/00`0T8b408b8P024P7P0301lN70808B0N200N7Q`301dM6`807QhL0`0O7ad201hN70807AdK
0`0L71X00`0K6aT06Q`K01XL6`0F01XL6a006adJ0P0M7a`201`N6`<06adJ00<06Q`I01XL6`0J71/0
5P0J71/801TK6P0401`N7@0K7A`06adL01/M70806Q`K4`0I6aX801LI60P051XH400G6AP301PJ6@80
6A/J2`0J71/@01XL6@<071hK0P0K7AX;01XL6@P06A/J200J71/201/M70<06Q`K2`0I6aX801LI60P0
61XI0`0I6aX301XL6`806adL8@0J71/301XL6@806adJ1P0L7Q/201/M6P<06Q`I200J71/01@0H7Q`0
5adK01LM6`0F71X05A/I008051XH00<04aTG01LM6`0G7A/00P0F71X201DK6@8051XH2`0D6QX[oooo
o`00:_ooool0202NMD40X7M30:9iA@2SNTH0Y7]70:=jAP2RNDD0XGQ40P2TNDH30:=hA@<0XWM400<0
X7E20:5f@`2SN4D00`2UNTL0202SN4D0XWM40:AkA@2RND<0XGQ209mf@02NMCl0WG@n0P2NMCl01P2O
MSh0X7Lo0:1g?`2QN400XWU10:=j@P80Y7]30`2SN4D20:AiAP<0YGY70`2VNdP30:EjA`80Y7U60P2U
NTL20:IkB080Yga90P2XODX20:AiA0060:EjA@2VNdH0Yga70:QmB02YOTT0ZWm:2@2XOdT00`2XODX0
ZGi;0:^0C@020:b1CP060:^0C@2YOT/0Z7e:0:^0C@2ZOd`0Z7e:0P2WO4T0102XODX0ZWm<0:^0C@2/
PDh20:^0C@050:YoC02XODX0Yga90:MlB@2VNdP0202YOT/20:b3C`80Zh9>00<0ZX5=0:V0C02YP4`0
0`2XOd/30:V0C0L0ZX5=102YP4`80:^1C`P0[XEA0`2]Q5020:j5D@<0[hIB0`2/Pdl20:f4D0/0[XEA
00<0[8Q>0:f9C`2^RU000P2^RU000`2/R4h0ZhM=0:V5B`060:j5C@80[hI>0P2]Q4`0102]Q4h0[HA@
0:f4D02]Pe420:f3D`80ZHA@0P2XPdl01@2WPTh0YX5=0:F0C02UP4`0YWe50080Ygi600D0Z7m70:Im
A@2TNd<0XWU10:1g?`0209iiA@80WGQ400@0W7M309]f@P2JMD40VWE10P2KLCl00`2JL3h0VFlm09U_
?@0209Q^?080Ufdk0P2JKd801P2IKT40Uf`o09I[?P2DJC`0TfPk099W>P80SVTl0P2=J3/0102<IcX0
RfHi08YU>02:ICP208]U=P80RV@e00`0RF<d08QR<`27HC80Qf4b089N;P23Gbl0Q5lb08AO<`23GS@0
PE/d07mI=01mEc8207]H<00407YG;`1iERh0N5D]07MD;080MU<[00<0MED^07AD;@1bDR/00P1aDBX0
0`1bDR/0Le</07AD;@0206e?:`<0KU0/0`1_DBd00`1/CRX0JddY06Y<:00206U;9`0506Y<:01/CRX0
KDl[06U;9`1XBRH00`1WBBD00`1YBbL0JddY06a>:P0206Q>:@80JDlZ0`1ZD2/00`1[DB`0Le<Z07=C
:P0607=C:P0307IC:@1gE2X0NEH/0080NUL]00D0NEH/07MD:P1fDbT0Me4/07]E<00207iH<`80NeD`
00<0OUPc089L=`1lFBl00P1mFS0207iK<@80Oe`b1020GC<207mL<P<0OU/a00H0PEhd081M<`1oG380
OU/a07eJ<01lFBl207]H;P0807aI<@1kF300NUL_07UF;P1jEbl0NeP`07eJ<P1oG3@207iK<@80OEX`
0P1lFBl207]H;P<0NU/_0`1iFRh307QI;@80O5Ta00@0NeP`07YG;`1jEbl0NEH^0P1hEBd807QH<@P0
MED/00D0N5T]07IG:`1dE2/0LU8[075A:`02075@;@04079A<01`DRh0L58^071B;P80LE<_0`1bE300
0`1fFC40M5L_071C:`0206iA:@03071C:`1dEbl0MUTa0080MEP`00H0M5L_079E;@1`Db/0Ke8Z06iA
:@1]D2P206eA;00406a@:`1[CbX0JThY06Y>:@80JDdX0P1XDBP01`1WCbT0IThZ06E=:@1TC2X0HdX[
0699:P1SBbT00P1RBRP00`1QBBL0H4PV05m79@0205i690@0Ed@V101HABL805M49P80D3lU0P1A@2H0
101B@BL0Dd8X05=2:01C@RP204m1900604m08`1>?b80CSdQ04dl801?>b00CSXO2018>BH00`0m=B00
?SHQ040h8`02044i9003040h8`0n=R40?CDP00P0@3PS0`0l=b<203/f8P`0>SDQ0P0g=B0403Hd7`80
=cDP0140>SDR03Td8@0h<b00=c8O03Pc800i=240>cHS03`g900h=R40=S<P03@a7P0b;ah0<BhO034]
8@0b;R<0<blT03Da9@0203@`900303<_8`0b;R80<BdQ0080<2`P00D0;RlO02d^7P0];Qh0;2dM02//
700202X[6`0302TZ6P0[;B80:bdR00H0:bdR200X:Ql802d[70P0:2XO200X:b0302T]7P80:RhO0`0[
;b0802ha8003034c7P0`<Qd0;S0K0080;S0K00H0<38M038d7`0c=B00<SDP034d7`0_<Qd302d`6`08
02ha700_<Qd0=2hN03D_7`0e<1d0=S4M03Lb7P0h<ad203Te7008040e8@0m=B00?CDP03/e7`0j=Al0
=cDN03Hf7P0e=Ad803`g8@80?CTN0P0l>1d0100k=a`0>SHK03Xf6`0j=Q/803`h7@<0@3TO1P0o>1h2
03/f80<0>SDO0`0i=1h403Hd7@80=cDN0P0h=Ql803Xe7`80=38M0P0e<ah0100f=1l0=cDP03Le800g
=B0403Lb7`<0>3<P00<0>C@Q03Hd7@0g=Ah00`0h=Ql00`0f=1d0=38K03<a6P0803@f7P0F03Pc7`0i
=1h0?3LQ03hj8@10?240@3`O040m7P0o?1d0BcXV04`k9`1<?2D0C3`S04dm8`1=?R40CSlR04ho801E
@2<0ET4T05M29@1IA2L0FdHY05e8:`80GdX]00X0I4XW06E;:01UBbH0ITdU06M>9@1XCbH0JE4U06YB
9P1aERT0L5DX0P1_E2L02P1`EBP0LULZ07AI;01eFRd0MUH`07QH<@1kFc@0OUhe085R=P21HS@2085R
<`0A085T>P22IC/0PfHj08AX>@25JCT0QVXh08M[>@28KCP0Qfhh08Q_>@29KST0S6hj08i^>`2@Kc`0
TG0m09=_?@2AL3d00P2BLCh00`2CLSl0U7=009Ed@@0209Ie@P80VWQ:0`2KND/309ajC080WGa900<0
WWe:09mnB`2POd`00P2QP4d02P2RPDh0XX=30::2A@2RPTD0Xh=:0:B3CP2UPeD0YX=I0:N4GP2WPel2
0:N5E`<0Z8IH0`2YQeT00`2^S5`0[H]K0:^9F@020:Z8F0030:^9F@2]Re/0[XaL00P0[8YJ00<0[H]M
0:j<GP2^S5h00P2_SEl00`2`SV00/HmQ0;6?H@080;2AI@080;>@JP2bSfT0/HiV0;2=H`2`SV40/HmQ
0;>AH@2dTV820;>@IP80/XmU0`2aSV@00`2`SF<0/HiT0;2=H`020;2=H`80[haR0P2^Rf430;6>I0<0
/8eS0P2_S6830;6>I080/8eS0`2_S6830:n=G`D0/8iP00<0[8YL0:f;G@2_SEl00P2`SV00102_SEl0
[XaN0:f;G@2^S5h20:f;G@030:b:G02[RE/0ZXQJ0080ZHMI0P2/Qed20:f8GP040:j9G`2_RV00[hYP
0:n:H080Z8QQ00<0YhMP0:J6G`2UQEh00P2TQ5d00`2SPe`0XGiD0:5nE0020:9oE@0F0:>0EP2TPEL0
Y85G0:B1E`2RPUT0Xh=J0:B4F`2UQE`0Y8AK0::2F@2QPEP0WgmF0:9lB`2SODh0Y7i?0:EoDP2UOU<0
Y7eD0:9kE02QNU<0Y7a90:9mB@80XGa800D0X7a809elA`2LODL0Vge709YlAP0809YkA@0309UgB@2H
MTP0UWA60080UG=500H0UWA609QfB02IMdT0UG=309Ab@P2CLD42099`@00309=a@@2ELd<0UWA400<0
Ufi20P2FKD4209E/@00709A[?`2?KSP0Sfhi08m^>@2>KCX0SV`l08e[?@0208e[?P0308aV>@2;ICP0
RV@g0080RF<f00<0RV@g08aV>@2=IcX00P2>HcP208eR=`<0S64f00<0Rf0e08ER>025HSP00P24HCL3
08=P=P07089O=@20GCD0P5de07mL=01nFc<0OEXb07aI<@0207]H<080NeH/0P1lEbd207eH;P80OUT_
101mF2h207aG;@80NeH/00/0NE0`07YA<@1iDS40Me<a07EC<01bDBh0L4l/06a>:P1aDB/0L50Z06i>
:00206e=9`0306i>:01`D2X0LE4[00<0KdlY0P1^CRP306e=9`P0JDX[00D0Id`_06I;;P1VBbh0IDX]
06=8:`020697:P030656:@1SBBP0HdTX00H0HdTX00<0GT<X05a19P1I?R<00P1G?2400`1I?R<0G44V
05i3:00905/o:@80DclV0P1B?RD3054m9004050l8`1F>RD0Ec/V05Pl9`80FCdX00<0F3`W05Lk9P1F
>RD00P1B>2L00`1?>2H0CSTV04/i9@0204Xi9@0304Tj9@18=bD0B3LU00H0B3LU0P1;=R4204Xe80<0
BC@O00<0B3<N04/f8@1;=R401P1;=R400`16=B<0AC@R04Dd8P0204@c8@80@c8P00<0@S4O03hc7`0n
<al00P0m<Qh403`a7@P0>C0O200f;200100i;bD0=bdS03D[8@0c:Al3038X7P0303<Y7`0^:Qh0;RXN
00H0;RXN00H0=2XP03<Y7`0b:1h0<BLM030V700_9A/202hT6PP0<BLM100Y920202PS7`809b8N0`0X
9A`202TV7@<0:RLN0P0/:1l202/W7P<0:RHM00<0:BDL02TV7@0Y9Qd01P0Y9Qd<02PU7080:BHM0`0Z
9ah01P0]8Q`0;2<L02`S700[91`0:BDL02PU70809RHL200X9A`0200X92<09b<R02DQ800T81l08alN
02@P7`0U8B009R8Q200P81h301lO7@80820N0`0Q8Al301hN70807AdK0`0L71X801/M70P06Q`K200K
7A`801dO70P06adJ0`0M7a`201`N6`<06adJ400J71/801/M70P06A/J0P0L7Qd301/M70<06Q`K4@0I
6aX801LI60P051XH200F61L801LI600401PJ6@0I6aX06A/J01TK6P806Q`K0P0K7A`801XL6a006Q`I
0`0L7Q/201/M6P/06Q`I200I6aX801XL6`806adL0`0J71/;01TK6Q005aTH0`0I6aX301XL6`806adL
8@0J71/301XL6@806adJ1P0L7Q/201/M6P<06Q`I200J71/201PN700401LM6`0F71X05A/I01@J6080
4aTG0P0G7A/201HL6P805A/I0P0D6QP;01@J6R_ooooo000Zooooo`0309ie@@2PMd<0XWU50080Y7]7
00<0XgY60:9iA@2QN4@00P2UNTL00`2TNDH0XgQ50:9gA0020:5f@`0=0:1e@P2OM440X7E20:9gA02T
NDH0YGY70:AiAP2RMd@0XGI30:ElAP2SNT@0X7M109ed?P0209ac?@0309ie?`2OMT00WgHn0080X7Lo
00<0XGQ00:9i@@2SNT800P2TNd<30:=hA@80Y7U60`2UNTL01P2XODX0Yga90:MlB@2VNdP0YGY70:Ai
AP80XgQ50P2UNTL20:IkB080Yga90P2XODX0202SN4<0Y7U40:EjA@2VNdH0Yga70:QmB02YOTT0ZWm:
2@2XOdT00`2XODX0ZGi;0:^0C@020:b1CP060:^0C@2YOT/0Z7e:0:^0C@2ZOd`0Z7e:0P2WO4T00`2X
ODX0ZWm<0:^0C@020:b1CP040:^0C@2ZOd`0Z7e:0:MlB@80YW]8202YOT/40:^2CP@0ZX5=0P2XOd/3
0:V0C0H0ZX5=1@2YP4`80:^1C`P0[XEA0P2]Q5030:j5D@<0[hIB0`2/Pdl20:f4D0/0[XEA00P0[8Q>
0:f9C`2^RU00[h]A0:j:D02]RDl0ZhM=0:V5B`D0[XE=0`2_QTh20:f4C0040:f4CP2]Q500[HA@0:f3
D@80[H=C00H0ZXEA0:V4D02YQ500Z8=?0:N2CP2VPDd20:F0C0090:ImA@2WOTH0Z7m70:QoA`2WOTH0
YGa40:9i@@2PMcl0WgY60080WWU500<0WGQ409ag@`2KMT800P2JMD4209]a?`0309Y`?P2IKcd0VFlm
0080V6hl0P2GKC/209Y_@P0409Q]@02GK3l0UFXm09=X>`80TVLj00H0SfXm08iY?02>JC`0SFPk08aW
>P2;IST208YU>00608aV=`2;ICH0RfDf08YT=@29Hc@0R68c0P27HC802022GRh0Pel_08AO<P25H3@0
Q5le089L=@1oFC@0OELb0P1kF3000`1jEbl0NEH^07QE;@0207MD;00407IC:`1fERl0M5@]079B:`80
LE4Z00@0LU8[07=C;01eEBh0K4hZ0P1]Cb/0201^D2`0Ke4]071B;P1`DRh0LE<_06i@;01/CRX0JddY
0`1YBbL01@1[CBT0K4hZ06U;9`1XBRH0IdTU0080ITPT00<0J4XV06Y<:01/CRX00`1WCb/206Q@;0<0
JE4]0`1dE2/207=C:P<0LU8Y00<0MU<Y07MD:P1hEB/00P1iER`01@1hEB/0Me@Z07IC:@1fD2/0NU@_
0080OELb0P1kEC00101nF3<0PU`g07aI;`1lFBl207eJ<00307iK<@1oG380Oe`b00@0P5dc0P1oG383
07iK<@06085N=020GC<0P5dc07iK<@1mFS00O5T_0P1kF2h00`1lFC40NeP`07YG;`0207UF;P0307]H
<01mFS80Oe`d0080Oe`b00@0OU/a07eJ<01lFBl0NeP^0P1jEbd307YK;`<0NEX^0`1hFBd207eJ<P04
07aI<@1kF300NEH^07QE;@80Me@/201iFC8807AD:`0807QI;@1gF2`0M5@[075A:P1`D2X0L4l/075@
;@1bDC03071B;P80LE<_0`1bE3000`1fFC40M5L_075D;00206iA:@0;075D;01dEbl0MUTa07EH<01d
Ebl0LeH^075D;01`Db/0KU4Y06e@:01/CbL00P1^DRd0101]DB`0K50[06Y>:@1YCBP206Q<9`0806UB
:@1XDBP0IdlY06I>:P1UCBT0I4`Z06=::`1RBBX206=;:@04069::01QBBL0H4PV05m79@80GTHT00D0
ED8T05I39@1F@bD0Ed@V05Q59`0205U6:00305Y7:@1GA2H0Ed@V00H0Ed@V0P1@?bD205509P050591
9`1C@RP0Dd8X05A3:@1@@b<00P1?@R801@1?@240CchP050m7`1??1h0D3/N00P0B3TV00<0?CDP03lg
8P10>2<00P12>RD00`10>2<0?cLR03de8008040h8`<0?3LS0P0k=R8<03Xe8@0303Dc7P0f=1l0=cDP
0080>3HQ00D0=cDP03Hd7`0e<ah0>SDR03Td8@0203Lb7`0<03Pc800j=B80?CPU03hi9P0k=R80>C@Q
03Ha7P0d;Qh0<bdO03@^8P0e;R@0=RlU0P0g<BD00`0f<2@0=BlS03@^8P0203<]8@09038/800_<200
;c0P02h_7`0];Qh0:b`L02X[6`0Y:QX0:2TI00P0:bdR200W:Ah802h/7@P0:2XO200Y;24302T]7P80
:RhO0`0[;b0802ha800@034c7P0`<Qd0;S0K02d_6P0^<1/0<38M038d7`0c=B00<cHQ034d7`0_<Qd0
;C0K02`_6P0]<1/0;S4L02lb7@80<bdM00@0=2lL03D`700f<Ad0=c8L0P0h=1/01P10=B40?CDP03de
800k=Al0>C@N03Le7P80=CDM200l=b4203di7P0403`h7@0k=a`0>cLL03Xf6`80>CDJ200l>1d203hg
7@<0?cPN0`10>Al00`11>R00>cHP03/f800303Xe7`<0>C@N00@0=C<L03Hd7@0f=1d0=S@M0P0g=Ah2
03Pf7`P0>SDO00@0<c4L03@b7@0d<Qd0=C<N0P0f=1l203Le8080=C0M00<0=S4N03Lb7`0h<b000P0i
=2400`0j=B80=cDN03Le7P0303Tg800303Le7P0e<a`0=38K00P0=CLO00P0>3<O03Xe7`0l=b40?c/R
040l8@10?1l0@3dN03ll7@80CC/W00<0CC/U04hl901>?B<00P1??R801`1??R00ED0S05I1901H@bH0
FTDX05a7:P1NBB`00P1PBbh206I<:@0306I<9`1WCRH0IdhU0080J50T00<0J50R07EH;01dEb/00P1c
ERX02@1dEb/0MUT]07QK;`1jGC40NUXc07aL=@1oGcH0PV<g08EV>00208EV=`0908EW=@23IS`0PfHj
08AW>`25JCX0Qf/k08Q/>P28KCP0RFhi0080Rg8l00<0SG8m091b?P2BLSl00P2DLd001P2GLd40UGA1
09Ed@@2FMD80UgI309QgA080VGQ500<0VWU609ilCP2NO4h01P2OODl20:1oC0040:60C@2RPDh0XX5>
0:>2C`80Y8=@00X0XX=30:>3AP2SPdH0Y8A;0:B3CP2UPeD0YX=K0:N3G`2WPf40YhEG0`2XQUP20:V7
F@80ZXQJ00<0[heM0:f;F`2[RET00P2ZR5P00`2[RET0[H]K0:n=G@040:f;F`@0[8YJ0P2aSf420;:@
HP040;>AH`2dTV@0]99T0;FCI@P0/iAX00P0]Y=]0;FBK02cT6P0/XmU0;>AI02dTV@0]YAT0;RFIP80
]Y=Y0P2eTVP30;BAI`030;>@IP2cT6P0/i1X0080/XmW0`2aSVH01@2`SFD0]I9X0;FBJ02dTFL0/i1V
0080/XmU0P2aSV@20;BAI`80/i1V102bSfD30;:@HPD0/i5S00<0[XaN0:n=G`2aSf400P2cTF<00`2b
T680/8iP0:n=G`030;2>H0050:n=G`2^S5h0[H]M0:b:G02[RE/00P2`Rf40102aS680/XeS0;:=H`2c
SV@20;B?I@060:f<J`2/RfX0[8]Z0:^:J@2ZRFP0ZHQW0P2XQfH0102UPU`0YX=M0:J3G@2WQ5h20:R5
G`80ZHIP0100YhIS0:R7I02ZRFH0ZhYW0:Z9IP2XQf@0YXER0:F4H@2YPUL0ZX=H0:^4F`2/QEh0Zh=O
0:V1G@2WOe`0YWeM0P2ZPTh20:R3CP050:J3C@2TPdd0XX=<0::3C02QQ4`0202QPT/00`2NP4h0WGm=
09]mB`0209YlBP0609]mB`2MOdd0WX1>09UkA`2HNTH0UgU50P2FN4@00`2GNDD0VG]709YlB00809eb
B00;09Eh?P2DMcd0U7Lo09Af@02CMD40TgE3099d@P2BLd@0UF`n09A[?@2CJS`00P2BJC/00`2DJcd0
UF`n09M^@00309IZ?@80UFTl0`2DJ3/308mZ?@80SVTl0`2=J3/01P28IcX0QfHi08IU>025I3L0Q6<f
08=R=@80PV4d0P27HC@208QR=@0408US=P2:I3L0RV@g08]U>0@0Ped`0P22G2l2085K;P0;08AH=@24
FCH0Pe/g089J=P20FSD0O5Tc07UG<@1gEBl0N5D]07IC:`1dDBT00P1cD2P00`1dDBT0MU<[07QE;@02
07YG;`80NEH^0`1hEBd00`1gE2`0M5<b07AC<P0607AC<P0807=D=@1bDc@0LE8c071A<P1_D340KTl`
06e>;`1/CBh806a>:P0306Y;;`1WB2`0I4DY0080HT<W00<0I4DY06M8;01ZBbl02@1TA2/205e8:`80
G4LZ0`1KART0101JABP0IT8/06M3;@1XA2h206U5;`0306Q4;P1W@bd0IT8/0080F3dZ00<0EchZ05@n
:@1C?RT00P1@?RP00`1??bP0CcdY04lm:@0604lm:@<0ES/P0P1E>Ql305@i7PP0ES/P0P1@?RX0101?
?BT0CS`X04hl:01=>bL204`j9P0404Pl9P17>bD0Ac/U04Lk9@80ASXT0P15>B<803hf8`P0?SDV00@0
@3HZ03le:@0l<RH0>S0T0`0i;b<00`0j<2@0=c4S03La8`0603La8`0603/a9@0j<2@0>BlS03P^8P0g
;B40=R`P0P0e:al803P^8P80<R/U0`0a:R@3030Y8`80:bPO0P0/:B0302dZ8@0402h[8P0`:B40<2TQ
030Y8@80;bPP0`0^9al802/X7`T0;BXQ0`0^:b8202l/8`<0<2dT0P0^8ad00`0]91d0;2DM02XV7@02
02TV7@0302LW7@0Y9Qd0:BHM00H0:BHM00<0:RHU02TU900W8b800P0U8B000`0V8R409b<R02PT8`08
024Q7`80820N0P0Q8Al3028R800402<S8@0N7Q`07QhL01hN70<07AdK0P0L71X801/M70P06Q`K200K
7A`801hP7@P06adJ0`0M7a`301`N6`806adJ400J71/801/M70P06A/J0`0L7Qd201/M70<06Q`K4@0I
6aX801LI60P051XH200F61L801LI60@06A/J0P0J71/201/M70P06Q`K400J71T301`N6`806adJ2`0J
71T801TK6PP06Q`K0P0K7A`301XL6`/06A/J400G6AP301TK6P<06Q`K0P0K7A`Q01XL6`<06Q`I0P0K
7AX601`N6`806adJ0`0J71T801XL6`0801TO7@0H7Q`05adK01HL6P0E6aT051XH01<I5`0B61H201LM
6`805Q`J0P0E6aT201@J60/051XJ:oooool002[ooooo102OMd@40:1hA@P0X7I4202TNdL0302PO4P0
Wg]709ijAP2MNDD0W7Q409]g@`2JMT80VGE109ab@02NM480X7I40:9hAP80XgU700<0XWQ60:5gA@2U
NTL01`2UNTL30:EiB0<0YWY90P2WNdX01P2/NTT0ZWY90:YjB@2YNdT0Yga90:ImB@80YGe900<0Y7]7
0:=jAP2QN4@00P2QN4@00`2SNTH0YGa80:ImB@030:QmBP<0ZGi;1P2ZOd`20:UnB`<0Z7e:0P2VODT0
102WOTX0Z7m;0:QoB`2YP4`20:Z1C@030:YoC02[P4d0[85>0080[85>00<0ZWm<0:QmBP2WO4T0202Y
OD`30:Z1C@<0ZH1<0P2XOd/80:YoBPP0ZX5=202/Pdl20;27D`80[hIB00@0[XEA0:f4D02/Pdl0[8=?
102^QE440:f4D0040:b3C`2]Q500[HA@0:j5D@80[hIB0P2`Qe<20:^6D@80[8MB0`2]R5<02@2^RE@0
/XUA0;68D02aR580/8MC0:n6DP2^Q580[XAD0:f3D`080:j9E@080:f8D`2[QU40Z8=>0:N2C@2XPdh0
ZhIA0:n:E@2bSEP20:n6DP060:j5D@2/Pdl0Zh9>0:Z1C@2YP4`0Z7m;0P2ZPDd20:V0C0040:QoB`2W
OTX0YWe90:ImB@80YGa800T0Y7]70:=jAP2QN4@0X7M309mf@P2NMD40Ug8n09Qc?`2IM4000P2JMD42
09Qc?`0709Mb?P2FLCd0Ug8n09Mb?P2FLCd0UG0l09A_>`0209=^>P07099]>@2>JcD0SVXf08iZ=P2>
JSP0SFTi08eX>`0208eX?00908MQ=028HSD0RV@g08]U>02:I3L0RF<f08MQ=026H3<0Q5hg00<0Pedf
0P22G3D2085K=00407mL<P1nFc40O5T_07YG;@80NEH/00@0NUL]07]H;P1gE2`0Me@/0P1fDb/0101e
DRX0M54Y07=@:01cD2P207A@<00407=?;`1bCRh0LDd]075=;@80L4`/101ZC2P406U;9`80IDPV101V
BBL506M::00306Q;:@1YC2X0JTd[0080JTd[00H0LE0W079A:01cDRT0Le8Y07AC:P1eE2/207IE;006
07AF=01eEc<0MELc07IH<P1gFS80N5/a0P1iG30207AA:@80Le0X00@0M54Y07MD;01jEbl0NeP`0`1l
FBl407]H;P0307YG;@1oG380P5dc0080PEhd00@0P5dc07mL<P1mFS00NeP^0`21GS@00`20GC<0Oe`b
07iK<@0<07iK<@0<07eJ<01lFBl0NeP^07YG;@1iER`0N5D[07iK<`1lFC40NeP`07YG;`1iERh0NUL_
0P1lFC404P1mFS80N5TZ07QI:`1hFB/0N5T]07MG;P1eEBh0Le<]079B;01hFc40MEP/079E:@1cEbP0
MUXZ07MK:@1eFRD0LEHQ07AE:@<0Le@X0`1bDbL00`1aDRH0LE@/075D;003071C:`<0Ke8Z0`1^DRd3
06mC;P80L5@_0P1^DRX0101_Db/0L5@/071D;01aEBd2079F;P0P06mG<`1^E2l0KE<^079F;`1fFC40
N5P_07AC:01`Cb@0LEH[06mC:`1]DBT0JdlX06]?:P1/Cbd0KE0`06mB<P1]D2h0K4l]06Y=:`1XBbT0
IdXX06Q;:@1ZCB/0Jdh/05m5901QAbH0I4`Z06I?;@1SCb`0GddY05]99@1FAR8305i79@80GDHT0`1L
AB<205A39@H0Dd8T00@0C3/Q04hm8`1A@2H0Dd8X0`1D@bT04@1C@RP0E4<Y05919`1@?bD0CchT04hm
8`1??R@0D3lU05509P1B?RH0DCdU04lm9@1<?2<0BS`R04Lk8@16>R00AC/P0080?3PM00<0?CTN03hj
7`0o>b000P11?B802@12?R<0@S`V044k9@0o>R@0?STS03/i8P0i>B40=SPP03Dg7`0303`d7`80?CDP
0`0n=R400`0k<ah0?3@O03hf8@0203lg8P0403hf8@0l=1l0>c<N03/c7P80?CDR0`0l=24303/c8080
>cHR0`0j=B4303Td80P0=c8N200d<2@00`0b;a`0<BhK02l/6@0202h[600602l/6@0a;Q/0<RlL038_
800a;Ql0<2dN0P0^:a`00`0`;Ah0<BhO038_800402h_7`80;BhN0P0/;Ad802l`80P0;BhN00@09BLI
02HX6P0V:1X09bTK0P0X:Q`202T[7@0502h/7@0_;Ah0;bdN030^7`0a;b000P0b<2400`0c<B80;BhN
02d^7P0202h_7`80;c0P0P0`<B4802l`80@0;c4I0P0`<QX2034c6`<0=S@O1@0e<ah503Pf8@<0=cDP
0P0j<b0203/d8@<0?3DR00<0?CHS04<i7P13>Ah01P13>Ah303`g8@80>cHP0`0j=Al303Xh8`<0?3XU
00@0>SPS03Pf8@0g=B00>3HQ0`0g=B0203Hd7`80=C<N00P0=CXS03@i8P0e>B80=CLQ03He800g=B00
=S@O03Pc7`P0=S<P0P0d=R40100c=B00<S@O030b7@0_<A`202h`6`09030e7`0_=1h0;S4L02h`6`0`
;a/0<RlL03<`7@0f<Ah0>SDQ0080>C@P00<0>3<O03Lb7P0g<Qh00P0f<Ad00`0l>RD0>cTT03/i9002
03/i90<0>SPS00H0=SXO03Lk800h>b00>c/Q03dk8P0n?2<2044m900604`l9@1=?B@0CShU04lo9@1@
@B@0DT<T0P1CA2<03P1DA2<0Dd<R05=38@1DA280EdLS05]<9@1OD2L0HU<Z06I9:@1WBRP0J4/Y06U=
:01ZCRL0K50X0P1]DRL03P1fFC40MEP`07AG;`1cERh0M5L_07MJ<P1iG3@0Nehf07QN;@1jH2l0OF<b
07mU=020ISD0PFLf0P20ISD01022I380Q6Hd08MY=`2:K3X308a^?00708]]>`2?KST0T6lj091_>P2A
L3/0TW4l09=b?@0209Ac?PP0UgE5202MO4L30:1oBP80XH1;0`2RPD`01`2UPe<0YXAD0:J4E02WQED0
Z8IF0:V7E`2ZR5P00P2[RET30:Z8FP<0ZhUK0P2/RU`20:Z=E@80ZhiF0`2/SeL0102]T5P0[heO0:n=
G`2_SEl20;2>H0<0/HmQ00<0/8iP0;:@HP2cTF<00P2dTV@0102cTF<0/Y1R0;2>H02bSfD30;>@IP80
]95W0P2eTVP80;>DJ0030;JGJ`2eUVX0/iAX0080/Y=W00<0/iAX0;FFJP2fUf/00P2iUV`0102hUF/0
]iAZ0;FBJ02dTFL20;>@IP<0/XmU00<0/i1V0;BAI`2eTVP00P2eTVP80;>DJ0P0]95W202dTFT20:n@
I080[XmS00@0[HiR0:b=H@2/SF40ZhaP202^Sf<40:j;H`@0[haT00@0[HiR0:b=H@2/SF40[8eQ0P2[
S6020:Z;G`090:V7E`2ZR5P0[8YL0:j<G`2^Rf40[HYR0:b9H`2[R680[haR00<0[X]Q0P2]RV020:b9
G`80Z8EK0`2YQU`01@2ZQed0ZhQN0:^8GP2/REl0YhQL00@0YXMK0`2UQUX20:V6G0040:R5F`2WQ5X0
YH9H0:B1E`80Xh1F0P2POd`20:60C@040::1CP2SPTl0Xh9?0:B3D0<0Wge?0P2POU030:5oD@P0VgU;
00<0VGI<09QeB`2FLdT00P2ELTP00`2FLdT0V7E;09UfC00209QfB00409MeA`2FM4H0UG=509EcA@80
U7940P2FM4H309EcA@<0U79400P0UG@n09Ac?@2CLSl0TW10091^@@2?K4@0SV]508iZAP<0T6i000<0
Sfdo08i/?P2=Jcd00P2=Jcd808]Y>`80S6Lm00<0RfHl08YU>`29I3X00P27HSP01`26HCL0Qf8e08IQ
=025H3<0Q5lb08=N<@22GC000P21G2l8089N;P0607iK<`1mFS80O5Ta07]H<01jEbl0NEH^0P1hEBd8
07eJ<0@0NU@]101kEBh807A>9`T0Me4Z0P1dCbD01`1eCbP0M4hW07==:01aBbL0KTLV06e69@1dCRT0
0`1cCBP2079<9`80LD/V0P1WBB<206Q:900706U;9@1ZC2H0JT`V06]=9`1YBbD0IdTS06I88P0306A6
800706E78@1VB280ITPR06I88P1UAb40I4HP06=57`0206537@040612701R@bH0HT<V06939P<0HD8U
0P1P@B@00`1L?B00GChQ05m08`020611900705m08`1M?R40G3dP05Hk7@1H?Al0FSlQ05]08P0205a1
8`0505]08P1J?b40ESlO05Dn7P1C?1`00P1A>QX00`1C?1`0EChN05Ho7`08058k70<0DCTO0P1@>1h3
04lg7@P0C3LL00P0Ac8G04Td6@1:=AX0BcHK04Td6@16<AH0@bhC044/4@P0BS@L00@0CSLU04`e8`19
<R00ARlM0P15;Q`204H_7@80A2lL0`13;Q/3048]6P08048c7P13=1l0ACHQ04Hg8P15=R40@c@O040a
700n;aX2040a7P80@C8O0`12<b001@13=240AC0O04D`7`14;ah0@bhM0080A2lN00<0AS4P04Pc8P19
=2<0200n;Qh0400m;1`0?RdM03d]7@0k;Qd0>c0N03Ta7P0j<Ql0>C8O03L`800h<B40>C8R03Xc8`0i
<R80>34Q03H_7`0e;Qh3034Y7080<2PK0`0_9aX00`0/91L0;RHI030X6`02034Y7003030X6`0^9QT0
;2@G0080:2HJ00<09bDI02HT600U8aL00P0T8QH02@0S8AD092<Q02<R800R8Al08B0N020O7@0O7Q`0
7QdK01dL6P0301/K6@0301`L6P0M7A/07QhL00807QhL1@0Q8AT00`0P81P07alG01lO5`03028S6`80
8B8J0`0P8AT0200P8A`07b0K01hO6P0N7aX07b0K024R7@0S91l092DP200Q8Qd00`0J7aP06b0I01/P
6@0301/P6@80724J0P0I7QP401XO6@806b0J200I7ad201XL6`0401/M700L7Qd071hM01dO7P807R0O
00P07b4N01hP7@0L7Q/06Q`I01TK600J71T071hK01dO70<06b0L0P0J7a/301TN6P806QlK0P0I7QX4
01PM6@0401LL600I6Q`06AXL01TJ708061TK0`0G61X301PL6`D05a/J0`0F6Qd201DI70<051PK200E
6A`201HJ6@<05a/J0`0H71/201LI600301PJ6@0I6aX06Q`K00806adL00<071hM01/L7P0K71h00P0L
7Al301dN800301hO8@0L7Qd071hM00806adL0P0J71/201TK6P0401DI600F6QT05QXI01LK6P8061`K
0P0I7A`801PL6`0401dM7@0L71`071`L01`L70806a/K0P0J6QX00`0H61X06ATK01/K7@0201`L7P03
01/K7@0I6A/061PJ00P051dH00<06A/H01XL6@0K7AX00P0L7Q/00`0K7AX06Q`I01TK600801TK60P0
6AXL200G61X0100G6AH061XG01PJ5`0I6aP201XL6@D06adJ0P0J71T401TK61406Q`I0`0K7AX201`N
6`807AlL0P0J71T201TK60<061XG00<05aTF01XL6@0J71T01P0J71T801TK6P@061XI0P0G6AP201HH
5`P05aTH200D6QP301LI62_ooooo000Zooooo`@0WgM4102PN4D80:1fA0P0XWU50P2PNdL02P2ONTH0
WWU509ehA02LMd<0VgI209Ye@@2LLT00WWA20:1fA02RN4H20:=iA`030:9hAP2QMdD0YGY700L0YGY7
0`2TN4L30:EiB080YWY900H0[7Y90:YjB@2ZNTT0ZG]90:MlB@2VODT20:EmB@080:AkA`2SNTH0XWU5
0:5hA02RNDD0XgY60:ElB02VODT30:QmBP<0ZGi;1P2ZOd`20:UnB`<0Z7e:00<0YWe90:MnBP2WOTX0
0P2XOd/20:V0C0030:Z1C@2ZOd`0Zh1=00<0[85>00<0ZWm<0:QmBP2WO4T0202YOD`30:Z1C@<0ZH1<
0P2XOd/80:YoBPP0ZX5=202/Pdl30:n6DP80[XEA1`2]Q5040:b3C`<0[HA@00<0[XEA0:n6DP2_QU80
0P2`Qe<20:^6D@80[8MB102]R5<20;27C`040;27D@2_QU80[hIB0:n5D`80[XAD202^RED0202^RE@0
[8MB0:V4C`2WPTd0Z8=>0:Z5D02^RE@0/8]F0P2^QE40102]Q500[8=?0:^2CP2[PTh20:Z1C@060:^2
CP2ZPDd0ZX5=0:V0C02XOd/0Ygi:0`2VODT01@2UO4P0Y7]70:=jAP2QN4@0X7M30080WgI200<0V7<o
09Ud@02JMD400P2KMT8209Ye@@0609Qc?`2GLSh0Ug8n09Mb?P2FLCd0UG0l0P2DKc/209=^>P0608m/
=P2?JcL0SVXf08iZ>02>JSX0SFPk0P2=J3`00`28HSD0RF<f08YT=`0208]U>00308US=P27HC@0QV0c
00<0Q5le0P23GS@3089M<`04085N=01oG380OEX`07]H;P80NEH/00<0NUL]07]H;P1hEBd00P1gE2`0
0`1fDb/0ME8Z07AA:@0207=@:080M50^00<0Ldl]079>;01aCB/00P1`C2X00`1_BbT0JddY06]=:@03
06Y<:0<0JD/W1P1VBBL506M::00306Q;:@1YC2X0JD`Z0080JTd[0P1aCbT00`1bD2X0Le4[07AB;002
07EC;@0707ID;P1`DS00L58^075C;`1aDbd0LUD]07=F;00207AG:`0807IC:`1eDRX0ME8Z07AA:@1e
DRX0Me@/07UF;P1kF30607]H;P80NUL]00P0OU/a07mL<P20GC<0PEhd081M<`1nFc40O5T_07]H;P80
P5dc0P1oG380101nFc40OEX`07eJ<01mFS0:07iK<@0407eJ<01lFBl0NeP^07YG;@80NEH/00H0OU/c
07eJ<P1kF300NUL_07UF;P1jEbl207]H<00707aI<@1kG2d0NU/]07UJ;01gF2`0MUH]07EE;P0207EE
;`0807QK<@1dEbd0LUDY07=G:01fFRX0N5`Z07EI9`1bEb8407=D:0@0M5DY0`1aE2`2071C:`<0Ke8Z
0`1^DRd306mC;P80L5@_0P1^DRX206mC:`0G071D;01aEBd0LED]075E;@1_Ec<0KU@_06eC;P1aEBh0
MUTa07QH;`1dDbP0L4lT075F:`1_Db/0KE4Y06a@:@1[CbX0K4l]06e@<01^DC40KE0^06a?;@1ZCB/0
0`1XBbT206Y=:`0806579P1RB2L0I4`Z06A=:`1RCR/0GddY05a:9P1HB2@305i79@<0GDHT0P1LAB<4
05A39@@0Dd8T00@0CSdS04ln901A@2H0Dd8X0P1D@bT03`1C@RP0DT4W05A3:@1B@BL0D3lU04ln901>
?B<0CchT050o9@1A@2H0DShV054m9@1??BD0CCdT04Xl8P0204Lk8@0404Dk800o>Al0?cTO03li7`80
@3XP0P11>b401`12?280@SXU044k9@10>R@0?STS03/i8P0i>B400P0g>B4803de800303/c7P0l=1l0
?SHQ0080?cLR00@0?SHQ03`d7`0k<ah0>c<N0P0m=B8303`d8@<0>c<P0P0k=R8303Xe8@<0>C@P200g
<Qh803@a8P0303<`7@0b;a`0<2dJ0080;b`I00H0<2dJ038_700c<1d0<RlP034^7`0`;Ah202l/7@04
030]7P0a;Ql0<RlP02l`80<0;RlO0P0];Qh202`]7@P0;c0P200];Qh202T[7@80:R`N00@0:bdO02`^
800/;R00;2hP0P0_;Ah3030^7`<0<BlP0P0];Qh202h_7`80;c0P0P0`<B4802l`800402h`600_<AT0
;c4I02la6@80<38J0P0a<a/203Hd7`H0=C<N100h=R4403Le80<0>c@Q0P0l=B8303df8`P0@3TO0P0l
=b4303/f80<0>SDO0P0i=b801P0j>2<0>cTT03`j9@0k>B@0>SPS03Pf8@D0=cDP0P0f=1l203Dc7P80
=3TR00<0=3PQ03Dg8@0f=B000P0f=1l00`0h<al0=S<P03Hc800603Hc800603@f8@0c=B00<S@O034c
7P0`<Qd0;c4L0P0^<1/0200`=Al0;c@N02ha700^<1/0<2lK038_700c<1d0=S4N0P0i=20203Pc7`04
03Lb7P0f<Ad0=S4M03Ha7@80>cTR1P0j>240200g>b00>3/P03Tl8@0l?280?S`S044m9012?2@0@cdU
0P1=?B@01P1>?R@0Cd0S05528`1B@b80Dd@S05A68`80Ed@T00h0Ed@S05U78`1KBB<0GT`T065?9`1R
DBH0JD`Z06Y=:`1[CbX0KE4Z06mC:`1`E2`0LEH[079G;080MUTa00X0MEP`07AG;`1eF300MeXb07YM
=@1kGSH0NEl^07]Q<01mHc80OfDd0`21IcH01@20ISD0Q6Hd08IX=P29JcT0Rfdk00<0SFlm00H0S6hl
091_>P2@KcX0TG0k099a?02CLSd209Ac?P0409Ed?`2FM4@0UWA409IdA080UgE50P2HMTH00`2IMdL0
W7]609akAP0209elA`80WWe80P2OOTT20:1oBP80XH1;0`2RPD`0202SPTd0YXAD0:J4E02VQ5@0YhEE
0:R6EP2YQeL0ZXQH0P2[RET30:Z8FP80ZhUK0`2/RU`0102ZS5H0ZheG0:^=E`2[SEL20:b>F080[HmI
0`2_SEl20;2>H0@0/HmQ00L0/Y1R0;>AH`2dTV@0]99T0;>AH`2bT680/HmQ00@0/i1V0P2dTFL20;FB
J0P0/iAX00<0]YM[0;FFJP2cU6P00P2bTfL0102cU6P0]IIZ0;JGJ`2iUV`20;REJ`050;NDJP2eTVP0
]95W0;BAI`2cT6H00P2bSfD20;>@IP040;BAI`2eTVP0]I9X0;FBJ0P0/iAX202dTFL80;BAJ@80/95U
0P2_T6@20:j?H`80[HiR202^Sf<80:n<I080[HiR0P2/SF430:^<H0090:Z;G`2YQeL0ZhUI0:b:G02^
S5l0[X]Q0:j;H`2]RV@0[8US0080[haR0P2^Rf430:f:H0030:b9G`2YQU`0ZHIL0080ZHIL0P2ZQed0
0`2[R5h0[8UO0:b9G`050:R9G@<0YhQL00H0ZXMM0:V6G02XQE/0YhAJ0:J3F@2UPUP20:B1E`80XX5>
0P2SPTl0102TPe00YHAA0:F4D@2UQ5430::0DP80Xh5C0`2TPU@80:5oD@030:1mD`2OO580WGY@0080
W7U?00@0WGY@09mlDP2POE<0WWa>0`2MNdd409ajC00409]iB`2JN4X0VWQ:09UgB@80V7I80P2GMDL0
202GMT00UgI109Ie@P2FM4@0UG=609AaA`2CL4P0Tg1:0`2DLT@00`2CLD<0TW12099`@P02095_@@P0
Sfdo00H0TFa2091[@@2?JT00SVTo08eX?P2<Icd208]V?080S6Lj00@0RfHi08YU>029I3L0R6<f0P27
HSD808MS<`80QV<i00H0QF8h08AQ=`23H3H0PUle085N=020GC<808=P=P03085L<P22GC<0PUdc00D0
PUdc201lEbd907iI;`0807YE:@1kER`0O5L]07aF;`1kEC00NE<_07M@;`1fCbh307YD;`80NE<^0`1h
DRd3071@:P03075A:`1bDR`0LU8/0080Le<]00P0LU8/075A:`1_CbT0KThX06e=9`1^CRP0KdlY071@
:P80KdlY00@0KThX06e=9`1/C2H0Jd/U0P1ZBR@306]::`80JTTZ0`1YB2T00`1VABH0IdHW06U8:@02
06Y9:P0606U8:@1WARL0ITDV06138`1QA2@0HdHV0`1UB2P01@1TAbL0HdHV05m79@1NAR@0GDDS0080
Fd<Q00<0GDDS05i6901OAbD0201J@B<0101K@BH0FT0U05Y09@1J@2D205To9080F3hS201F?R82058j
7P0605<k7`1B>Qh0DSXN050h701>=QX0CCDI201@>2001P1C>RH0DCPT04he8@1<<al0Bc8N04Xa7@80
Bc8N0P1;=R4204Xe80<0BC@O00T0B3<N04Lg8018>240B3PQ04Ti8P18>240AcLP04De7P14=1d00`15
=20204He8@<0AcHR00@0BC@Q04Pc8017<Ql0AS4N0P17<Ql00`19=240BcHS04`g900804@c8@80@RlN
00@0@C0N044b7`0o<Ql0?c8O0P0o=2002@0k<R40?3<R03dd8`0n=B@0?C@S03`c8P0j<B00>C0O03T`
8@0303P_8080=bhO0P0f;Ah00`0d:a`0=B`M03L^7`0203P_800303L^7`0e;1d0=2/L0080;b`M00H0
;R/L02dZ6`0/:AX0;2TJ02/X6@0Z9aP202XW8P0402TV8@0X9B009b@O02LT7`809R<N0P0R8A`00`0S
8Qd092<N02@S7P0202DT7`0302HU800Y9Qd0:2DL0080:2DL0P0W91/202HS6P809BDK0`0T91X302<S
6@0302@S7P0S8Qd08R4L00808R4L00<092<N02HU800W9R40200S8Qd4024T6`@08RDL1P0M81T201hQ
6PP06b0L0`0M7A/201hN700601lO7@0P81h0820N024Q7`0P81h07QhL0`0L71X00`0N7Q`07alM01hP
7@0301dO708071hK0P0K7AX0100M7a`071hK01`N6`0L7Q/301/M6P806Q`I0P0M7ah201`N7@<06adL
00<06Q`K01PM6@0H7AT00P0H7AT401LL60<05QXK0P0E6AX301@H6@P05ATJ0P0F6aL201LL60<061dI
00<06AhJ01PJ5`0I6aP00P0I6aP401XL6@0401XL6`0K7A`06adL01/M708071hM0P0M7ah201`N6`80
6adJ0`0J71T01@0I6aP05Q/G01HK5`0F6aL05a`H008061dI0P0I7QX801PM6@<071`J0P0K6aT301XJ
600301PH6P0I6A/06a/M008071`N00<06a/M01TI6`0H61X0200F71P00`0H6QL06A/H01/M6P0201`N
6`0301/M6P0I6aP061XG00P06A/H200I6Q`801PI6`805aTF0P0H6QL0100I6aP06Q`I01XL6@0J71T3
01/M6P806Q`I100I6aPC01XL6@806adJ0`0L7Q/301XL6@806A/H0`0H6QL801XL6@T06A/J0`0H6QT2
01LI60805QPG200G6AP801@J60<05aTH:oooool002[ooooo102QMdD<0:1fA0P0X7M30P2ONTH0102N
NDD0WGQ409ag@`2LMd<209]f@P0409ec@@2NM480X7I40:5gA@@0XWQ6202UNTL20:9fA@<0XgM60`2T
N4L01P2/NTT0ZWY90:YjB@2YNdT0Yga90:ImB@80YGe900P0Y7]70:=jAP2RNDD0XWU50:=jAP2TNdL0
YGa80:ImB@<0Z7e:0`2YOT/60:YoC080ZGi;0`2XODX30:MnBP80Z7m;0`2YP4`00`2ZOd`0Zh1=0:b1
CP020:b1CP030:YoC02XODX0Yga900P0ZGe<0`2ZPDd30:V0C080Z7m;202ZOdX80:Z1C@P0[8=?102]
Q5030:j5D@030:n6DP2[PTh0Zh9>00H0Zh9>0P2]Q5030:j5D@<0[hIB0`2[QU420:b7DP<0[HQC0P2^
QDd0102^QDl0[hIB0:n6DP2_QE<20;26EPP0[HQD00<0[hYE0:f8D`2[QU400P2XPdh00`2YQ4l0[8MB
0:f8D`070:b3C`<0Zh9>00<0ZX5=0:V0C02XOd/00P2WOTX02@2VODT0Ygi:0:ImB@2UO4P0Y7]70:9i
A@2QN4@0X7M309mf@P0209]f@P<0WGQ40P2KMT800`2IM400V7<o09Qc?`0209Mb?P0309Ia?@2EL3`0
U6lk0080Tfhj00H0T6dg091/>02?JcL0Sf/i08iZ>P2>JC`208eX?00308YT=`2;ICP0RfDh0080RfDh
00<0RV@g08QR=@27HC@00`25H3H208AO=@<0Pehd00@0Pf0f085N=01oG380O5T_101jEbd01P1iERh0
N5D]07QE;@1gE2`0MU<[07EB:P80M54Y0P1dD2h0101cCbd0LTh/075=:`1`C2X206m;:@80K4hZ0P1[
CBT206Y<:080JD/W1@1WBRP306I99`<0IdXX0P1XBbT306U<:P80KdlX00<0L50Y075A:P1bDR/00P1c
Db`0301dE2d0Jdd[06]=:@1/CRX0KDlY06iA:@1_DRP0Ke8V071C9`1iERh0N5D]07MD;080MU<[00<0
Me@/07QE;@1iERh0201jEbd02@1mFS00OU/a07mL<P20GC<0Oe`b07iK<@1lFBl0NeP^07iK<@0307eJ
<0<0O5T_00<0NeP^07eJ<01mFS001P1mFS0207iK<@0407eJ<01lFBl0NeP^07]H;P80NUL]00H0OU/c
07eJ<P1kF300NUL_07UF;P1jEbl207]H<00A07aI<@1nGc00O5d_07UJ;01fEb/0MED/07IF;`1hF380
NETc07MJ<P1dEbl0LUD[07=F:P1gFb`0N5`/07EI9`1bER@00P1cDbX0101dE2/0MED/07EE;01fERd2
07MG;P04079E;@1aE2`0LE@/075D;080L5<[0P1_DRX306iB;@<0Ke<^0P1`E2l0101^DRX0Ke<[06mC
:`1_Db/3071D;00F075E;@1_Ec<0KE<^06aB;@1`E2d0MEP`07MG;P1eE2T0LE0U071E:P1_Db/0KU8Z
06a@:@1/D2/0K4l]06e@<01^DC40K4l]06]>;01ZCB/0JD`Z06Q;:@80JD`Z00T0JTd[06A::@1TBRT0
Hd/Y069;:@1PC2T0GT`X05e;9`1JBRH00P1OB2H205i79@<0GDHT00@0G4DS05E49P1EA2H0ED@V0P1D
@bD305=2900H050o9@1A@2H0DT4W05=2:01D@bT0Dd8X05509P1@?bD0E4<Y05919`1@?bD0CchT04hm
8`1??R@0D3lU05509P1B?RH0DCdU04lm9@1=?B@0BcdS04Pl8P17>b40AS`Q0P13?283048k8@<0@CXP
00H0@SLS040h8`10>2<0?cTS03hi8`0l>R<203/k8`05040h8`0o=b80?cLR03hf8@0m=B000P0l=1l2
03/c7P0603`d7`0n=R40?cLR03lg8P0n=R40?3@O0P0k<ah203de8P<0?3@Q0`0k<b0203/f8P<0>SDQ
0`0i=20803Lb7PP0=C8S00<0=34N03<`7@0b;a`00`0b;a`01@0c<1d0=34N03<`8@0b;b00<2dN0080
;b`M00<0<2dN038_800c<2400`0_<20202h_7`<0;BhN200_<20802h_7`0402`^800];b40;BlQ02d_
8@<0;S0R00<0;c4S02l`800_<2000`0^;al502d^7P80;RlO0P0_<202030a8@P0;c0P0`0^<1X202la
6`<0<38L200e<ah803Le8080>SDQ0P0k=R8303`g8`0303dh900o>1h0?cPN00H0?cPN00@0?3LQ03/f
800k=R00>cHP0P0j=Al203Td7P<0>CLR0`0k>B@00`0i=b80=cDP03Hd7`0303Le8080=S@O0`0e<ah2
03<h8@0303<g800d=R00=C@O0080=S@O00<0>3<O03Hc800f<b001P0f<b001P0c=B00<S@O038d7`0a
<ah0<38M02la7080;S0K00P0;c@N02hc7@0^<A`0;S0K030_6`0b;a`0=34N03Lb7`@0=c8N0P0f<Ad2
03D`70L0>cHP00H0?3LQ03/k7`0k>al0?C`P040l8@12?28204@m8`0I04Lm901??BD0CchT050o9@1A
@2@0Dd8T05A48`1EAB<0ETHT05Q5901IARD0FdTU05e;9@1OCBL0H4hV061?901OCR<0K4l]06eA;01^
DRd0L5@]07=G;`1eFRl0MU/^07ML;`0207MJ<00:07II;`1gFS00MeX`07UL<P1kGS@0O5le07]O;`1m
HC40Of<c089V=P<0PfLg00H0PVHf08MY=`29JcT0Rfdk08e_?@2>L3h208ma?`0708i`?P2@KcX0TG0k
095`>`2BLC`0Tg8m09Ac?P0209Ed?`0609Ab@P2ELd<0UWA409MeA@2IMdL0VWQ80P2KNDT209]jA@06
09akAP2MO4L0Wgi90:1oBP2QP4/0XX5<0P2QP4/20::1C0<0Xh9=00@0Y8=>0:N5E@2WQED0YhEE0P2X
QUH0102YQeL0ZXQH0:^9F@2[RET20:Z8FP80ZhUK0`2/RU`00`2]Red0ZheG0:^=E`020:b>F0<0[HmI
00@0[Y1J0;2>H02`SV00/8iP0P2aSf430;:@HP030;6?H@2bT680]99T0080]I=U00<0]99T0;:@HP2a
Sf400`2cT6H20;BAI`<0]I9X202cU6P00`2fUf/0]IIZ0;>DJ0020;:CI`030;>DJ02eUVX0]YM[0080
^9E[00@0]iAZ0;JCJ@2fTfT0]I9X0P2dTFL30;>@IP80]95W0`2eTVP80;>DJ0P0]95W202dTFT40;6B
IP80/95U2P2_T6@70;2=I@030:n<I02^Sf<0[HiR0080[HiR0P2/SF420:^<H0060:Z8F02[RET0[H]M
0:n=H02_S680[haT0P2]RV@0102`SF<0[haR0:n<HP2_S6820:j;H@80[HYP0P2ZQed40:^8GP<0[8UO
102ZRel40:^<H080ZhQN00<0ZXMM0:V6G02XQE/00P2WQ5X0102VPeT0YXAD0:J4E02VQ5@30:N5E@80
Z8IF00@0YXAF0:N5E`2WQEL0YhEG0P2XQUP:0:V7F@80YhAJ00@0YX=I0:F2F02UPUP0YX=I0P2WQ5X3
0:B2E0<0YH=E0P2VQ5H20::0DP040:5oD@2POU00WWa>09ekC@80W7Y<0P2LNdP00`2LNTX0W7Y<09aj
C@0209aiC`0309aiD@2KND/0VWQ:0080VWQ:0`2IMdT00`2HMTP0UgE709MeA`0609MeA`80V7=900<0
Ug9809IaA`2EL4H00P2DKdD00`2CKT@0UG1309E`@`0209A_@P0409=^@@2BKD00TF`o095/?`P0T6`l
00H0TFi4091]@`2@KD<0Sfa208i[@@2=JT0208aY?`P0RfPn00<0S6Lm08]V?02;IS`01@2;IS`A08IQ
=`08089M<023GS80QF0d08IQ=`25GcP0Q5hi08=M>@22G3P3089L=@80PE/d0`20FS<307UI<P80NUXc
0`1kFc@00`1lG3D0Ne/d07UI<P0207MG<00407QH<@1iFC80NUXc07UI<P80N5Pa00<0MeL`07IF;`1e
EBh00P1dE2d207AC<P80Le8a0P1bDC02075@;`03071?;P1aD2l0Le8a0080M5<b00H0Le8a075@;`1`
Cbh0Jdd[06e?;@1^D2h3071B<00406i@;P1]Cbd0KE0^06a?;@@0Jdh/00<0K4l]06e@;P1XBb/01`1X
Bb/206U;;`80J4X^0`1WBBd00`1VB2`0HDPZ0658:P060658:P0305i59`1MA2H0G4<U0080Fd8T00<0
G4<U05e49P1MA2H0201H?R<01@1J@2T0F3hW05Hl9@1D>R<0DcTR00<0DSPQ0P1G?bL205Hn9P<0ECdU
00@0E3`T058n9@1B?RD0D3`S0`1?>b82050l8`80CSXR0P1?>b<3050l9005054m9@1B>B<0DCPR050g
8@1?=R000P1@=b400`1A>280DcXT05@k9@0804hi900604Xd7`1;=B00BSDP04Pf8019=b40B3PQ0P18
>B800`13=R<0A3LT04Dh9@0204Hi9P0304@g9012=B80@C@Q0080A3LV0P13=RD3048e9004044d8`10
<b80@3<R044d8`80@SDT00<0@C@S040c8P10<b800P0k<R400`0j<B00>C0O03P_7P0203L^7@0303H]
700b:b<0<R/S00@0<R/S0P0a:R82030Y8@<0<BXR0`0b:b<2038/8003034[7`0`:Qh0<2XN00<0<2XN
0P0/:1`302/W6`<0:RHJ00<0;2PO02/W7P0Z9Qd00P0Z9Qd00`0[9ah0;BTP02l[8P0802TU70L0:BTO
00<0:2PN028R6P0R8QX01P0R8QX8024R70<08B0K0`0R8A`202<R7@0302@S7P0S8Qd08B0K00<081lJ
0P0Q81/3020Q6`807b0J0`0N7aT0100P8A/07b0J01lP6P0O81X301hO6@807AhH00@08R8P024Q7`0Q
8Al08B4O0P0P81h201lO7@8071hK0P0K7AX201XL6@806A/H0`0I6aX201PJ6@<05aTH200H6QT301TK
60806Q`I0`0K7AX201`L6P<06a/I0`0J6QP301/K6@8071`J1P0M7A/201`L6P<06a/I0`0I6aP301XL
6@X06adJ0`0L71X201/K6@<06QXH00<061PH01TI6@0J6QX00P0K6a/00`0J6QX06ATI01PH600801LM
6@0301PJ5`0I6aP06Q`I00806adJ00<06Q`I01TK600H6QL0200H6QL801PJ6@P06A/J0P0G6AH301PJ
5`<06A/H0`0L7Q/201/M6Q@06Q`I0`0I6aP201XL6@D06adJ0P0J71T301TK600301PJ5`0J71T06Q`I
00H06Q`I2`0I6aX201PJ6@<05aTH200H6QT801@J60<05aTH:oooool002[ooooo102RMTD40:5eA0P0
X7I4202OMT820:1hA@80WgM40P2NMT<209ee@P80WWA200<0WgE30:1fA02QMdD00`2RN4H80:AiAP80
XGE40`2RMTD30:=gAP060:ajB@2ZNTT0ZWY90:UkB@2WO4T0YWe90P2UODT40:=jAP040:AkA`2UO4P0
YGa80:ImB@<0Z7e:0`2YOT/60:YoC080ZGi;0`2XODX80:QoB`030:YoC02[P4d0[85>0080[85>00<0
ZWm<0:QmBP2WO4T0202YOD`30:Z1C@<0ZH1<0P2XOd/80:YoBPP0ZX5=202/Pdl20:^2CP030:b3C`2]
Q500[XEA0080[hIB00<0/8MC0:V0C02YP4`0102ZPDd20:^2CPH0[XEA0P2_QU820:Z5D080ZhIA0P2/
Qe820:f8D`080:b3B`2]Q4`0[HA>0:j5D@2_QU80/8ID0;26EP2aQeL80:f8E0030;2;EP2^RE@0[8MB
00<0ZHA?00<0ZXE@0:^6D@2[PTh00P2[PTh30:b3C`80[HA@0P2[PTh0102ZPDd0ZH1<0:V0C02XOd/4
0:MnBP070:ImB@2UO4P0XgY60:9iA@2QN4@0X7M309ehA00209iiA@0609mjAP2NNDD0W7M309ag@`2J
MD40VGA00P2HLcl00`2GLSh0UW4m09E`?00209A_>`0909=^>P2BKcT0TFdi095]>@2@K3X0Sf/k08iY
?02>JCd0SFPl00<0SFLj00<0S6Hi08]U>02:I3L00P29HcH408IQ=@80QF0d0P24Gc<01025HSP0Pf0f
081M<`1mFS0407]H;P80NEH^0P1hEBd01@1gE2`0MU<[07EB:P1eDRX0ME4]0080M50/00<0Ldl[079>
:P1aCBT00P1`C2P01@1^D2`0KDl[06e?:`1/CRX0JddY0080JT`X00<0JD/W06Q;:@1XBbT0101WBRP2
06I99`@0IdXX101XBbT206a>:080KDlY00D0KU0Z06mA:`1`DR`0L58/06Y<:P0206]=:@0306a>:01]
D2P0KU4W0080Ke8V00<0NUL_07UF;P1iERh01@1hEBd00`1hEB/0NEH/07UF;00207UF;0<0NUL]00<0
O5T_07eJ<01nFc400P1oG3800`1mFS00O5T_07]H;P0807]H;PP0OEX`0P1nFc4207eJ<00807aI;`1k
F2h0NeP^07]H;P1oG3@0OU/c07aI<@1jEbl207UF;P80NUL_0140NeP`081Q<P1mGS00NEX/07EF:P1e
EB`0MeL`07YJ=01mGCL0MeTc07=F;P1aE2`0LeH/07MJ;P1hG2d0MUXZ07=G9`0207=C;00407AD;@1e
EBh0MeL`07QH<@80NETb0P1bEBd3075D;0<0L5<[0`1^DRd306mC;P80L5@_201_Db/03P1_Ec<0KE<^
06]A;01_Db`0M5L_07MG;P1eE2T0LU4V06mD:@1_Db/0KU8Z06eA:P1]DB`0KE0^0P1]D30206]>;080
JTd[101YC2X0201WCB`0IT`[06=;:@1QBRP0GTXW05e;9`1NC2P0G4`X0`1OB2H205i79@<0GDHT0P1G
ARP0101FABL0ED@V05E49P1D@bD205=2900@05509P1B@BL0Dd8X05A3:@1C@RP0DT4W050o9@1??R@0
E4<Y05919`1@?bD0CchT04hm8`1??R@0D3lU05509P80DCdU00L0CcdU04dm901;?B<0BCdS04Pl8P17
?B80ASlU0080AChT00<0@c`R048k8@11>R000P10>Al02011=R80@SLS040h8`10>2<0@3XT03lj900m
>b@0?S`U0P11>B@01010>2<0?cLR03de800l=1l303/c7P0603`d7`0n=R40?cLR03lg8P0n=R40?3@O
0P0k<ah203de8P<0?3@Q0`0k<b0203/f8P<0>SDQ0`0i=20803Lb7PP0=C8Q00<0=C8O03@a7P0d<Ah0
100d<Ah0100e<Ql0<c0Q038_800a;Ql202l/7@03034^7`0b;b00<c0Q00<0;c0P0`0^;al202d^7PP0
;c0P200^;al402`^80@0;BlQ00D0;c8Q02ha800^<B00;C0O02`_7P0202/^7@0302X]700];Qh0;BhN
0080;RlO0P0_<202030a8@P0;c0P0`0^<1/302la7080<38M00<0=38M03Dc7P0e<ah00P0e<ah603Hd
7`@0=cDP100h=R4203Tg8P<0>SPS200m=al303/f8080>SDO0`0i=1h203Pf8@0703Tg8P0j>2<0>SPS
03Xh8`0h=R40=S@O03Dc7P0203Le8080=S@O0P0e<ah203@b7@80<CHO00<0<SHO03<e7`0e=1l00P0e
<ah00`0g<Qh0=S<P03Hc800603Hc8003038d7`0a<ah0<C<N0080<38M0P0_<A`02@0^<1/0;c@N02hc
7@0^<A`0;S0K030_6`0b;a`0=34N03Lb7`0203Lb7PH0=S4M00<0>cDM03`f7P0l=Qh00P0l=Qh303dg
7`0603dl7P10?1l0@C`O048m8014?B40AcdR0P19?B<01P1B?RD0DShS05<o901E@R@0ET<S05Q59080
FDLS0100FTHU05e99P1PC2L0HThY06AA:@1SD2H0HDhS061=8P1/D2/0KE4Z06mC;01aEBd0LeP]07IK
;P1gG2d0N5d^0`1hFbl02`1iG300NUda07]N<P1lGc<0OF0d07iO<020HC80PV<d08EV=`26IcP0QfPi
0080QVLh00@0RV`j08]]>`2<KS`0SFlm0P2?LCl2091b@006095`>`2BLC`0TW4l09=b?@2DLch0UG@o
0P2FMD001P2DLT80UG=309IdA02HMTH0VWQ809]iB@80WG];00P0VWU409]jA@2LNdH0WWe80:1oBP2R
PD`0Xh9=0:B3CP<0Xh9=0`2TPdh20:F4C`@0Z8IF00<0ZHMG0:Z8F02ZR5P00P2[RET30:^9F`<0[8YL
0P2]Red20:b>FP80[HmK102^T5`30;6?H@<0/Y1R0P2cTF<00`2aSf40/i5S0;BBI0020;FCI@030;BB
I02cTF<0/HmQ0080/i1V0P2dTFL20;FBJ080]Y=Y202dUFT00`2fUf/0]IIZ0;>DJ0020;:CI`040;>D
J02eUVX0]YM[0;REJ`80]iAZ0P2fTfT20;FBJ0D0]95W102eTVP80;BEJ@P0]I9X202eTVX60;:CI`80
/I9V202`TFD40;6>IP@0/8eU102^Sf<20:f>HP80[8eQ00P0ZhUI0:b:FP2^S5h0/8iQ0;2=H`2_S6@0
[X]U0:f:I0@0/8eS0P2_S6820:j;H@D0[8UO102]RV040:f>HP@0[XmS0`2/REl00`2[R5h0ZXMM0:Z7
G@020:V6G0P0ZXQJ0`2[RE/20:b:G0<0[H]M202/RU`20:^8GP@0ZXMM0P2[R5h20:N5E`040:R6F02Y
QeT0ZXQJ0:Z8FP80ZhUK00H0ZXQJ0:V7F@2XQUP0YXAF0:F3E@2TPU@20::0DP80XX1@00<0XX1B0:>1
D`2SPE<00`2TPUD40:5oD@@0X7i@202OODl00`2PNe40WgY@09mjD00209iiC`80WGQ>00@0W7M=09mj
C@2NND`0WWU<0P2MN4/209agBP0309]fB@2JMTH0VWI600H0VWI60`2HMTT00`2GMDP0UWA709IdA`02
09EcAPP0TFi40`2CKT83099]@@80TFa0202>JCd908]V>P0908UT=`2:ICP0S6Lk08eX?02=J3h0SFM0
08aV@@2;ID00RF@j00<0R6<i0P27HSP208IQ=`<0PF0g1@22HCP02024HcX0Pf8i085P=`20GcH0Oehe
081O=P21H3L0PV4h0`20GcH00`1oGSD0OUdd07iM=00207eL<`<0NeTd0P1jF3<407UG<P0:07YH<`1k
FC@0OE/f07eK=P1kFC@0NUPc07UG<P1fE2l0MeD`07UG<P80NUPc00<0NELb07QF<@1gEC000`1fF382
07EG<@<0MUPb201`DS03079C=080LE8c0`1`DC8806]>;P0806U<;01XBb/0ITTY06A79`1UB2P0IdXZ
06Y=;@1[CRh806A7:@0606A6:P1SABT0HT@X06129P1O@BD0GT0T0P1M?b<20615:080Gd@W0`1N@bH0
101M@RD0H4LY05i59`1K@R@205U08P0305]2901MA2H0GdHX00<0Fd4V0P1L@RL305e3:00305a19P1K
@2D0FSlT00<0FChS00<0FSlT05a19P1M@RL0201J@2T205Hj900305Dk901E?BD0DcdU0080DclV00<0
DD0V04lm9@1??BD00`1A?bL00`1??BD0CC/S04`j8P0304hl9P80CC/U0`1<>R@204Xh8P@0BcTS0P1:
>28204@g900304<f8`12=B80@C@Q0080@3<P00@0?c8O03X^800j;R00>RhP0`0k;b4203``8PD0?2hQ
0`0m;b801@0k;al0>RhN03T]7@0h;1`0=b/K0080>2`L00@0>BdM03D^700e;Q`0=BhL0P0d;A/303</
6P0303H^8@0e;B00=2`O0080<b/N00<0=2`O03H^8@0g;b80200a:A`4034[7`@0<2XN0`0/9A/302/T
6P80:R<I400Y9A`0100Z9Qd0:BDL02TU700X91/402LS6P<09R<J0P0U8QT302@Q60809R<J0`0U8QT4
02@Q608092<N0P0S8Qd3028Q7006024P6`0P8A`07b0K01lP6`0N7aX07AhI0P0L7AP0100K71L071dH
01`M600L7AP201/L5`<06Q/F2P0K71L201`M60807AhI0P0N7aX01@0P7a/07ahJ01lN6P0N7AT07A`H
008071/G00@06aXF01dL5`0M71L07A`G0P0N7AP301lN6@8081lK0`0O7QX301hM6@@071dH3P0M7QT3
01`M60<06a`G0P0J6QP401/K6@806QXH200J7a/00`0H6QL06A/H01XL6@0201`N6`0301XL6@0I6aP0
61XG010061XG200J71T401PJ5`@06A/H0P0M7a`301`N6a@06adJ0`0I6aP201XL6@<06adJ0P0L7Q/2
01/M6P<06Q`I00<06A/H01/M6P0K7AX01P0K7AX801XL6`<06A/J0`0H6QT201LI60P061XI200D6QP3
01LI62_ooooo000Zooooo`80YGM60P2TMTD20:=eA080XWA3202OMD<809ie@@80X7I4102OMD<209id
@P<0WgE300<0X7I40:5gA@2RN4H00P2SNDL80:AiAP80XGE40`2RMTD30:=gAP060:ajB@2ZNTT0ZWY9
0:UkB@2WO4T0YWe90P2UODT20:=jAP030:AkA`2UO4P0YGa800<0YGa80`2XODX30:UnB`H0ZWm<0P2Y
OT/30:QmBPP0Z7m;00<0ZWm<0:^0C@2/PDh00P2/PDh00`2ZOd`0Z7e:0:MlB@080:UmC0<0ZX5=0`2Y
P4`20:QoB`P0ZWm:202YP4`80:b3C`060:Z1C@2[PTh0Zh9>0:b3C`2]Q500[XEA0P2_QU800`2XOd/0
ZH1<0:V0C0020:Z1C@80Zh9>00<0[8=?0:n6DP2_QU801P2^QE430:Z5D080ZhIA0`2/Qe820:b3B`04
0:f4CP2^QE40[XEA0:n5D`80/8IF202/Qe<0102_RUD0[XUD0:b7DP2ZQE020:V4C`80ZXE@0`2[PTh3
0:b3C`80[HA@0P2/Pdl0102[PTh0ZX5=0:V0C02XOd/20:MnBP80Z7m;00L0Ygi:0:ElB02TNdL0XgY6
0:9iA@2QN4@0WWU500<0WgY600H0WWU509ag@`2LMd<0VWE109Qc?`2IM40209Qc?`0309Mb?P2FLCd0
UG0l0080U6lk00H0Tg0j09=_>`2BKSX0TFdk091/?02?JSd208iY?@05091Z?@2?JC`0SVPk08eW>P2<
IST00P2;ICP00`2:I3L0R6<f08QS=P0208MR=@@0QV4d00@0QV<i08AQ=`21GS@0Oe`b101mFS0207YG
;`0407UF;P1hEBd0Me@/07MD;080MU<[00H0Me@^07IC;@1fDbd0ME8/07AA:`1cD2X2079?:@80Ke4]
00@0KU0/06e?:`1/CRX0JddY0P1ZC2P206U<:P80J4/Y0P1WBRP206I99`P0IdXX0P1YCBP0101ZCRT0
JdlZ06a@:`1]DB`206iB;@0906e?;@1]Cb/0KU0/06mA:`1`Db/0LE@Z075D:01bEBT0N5D]0080NEH^
0P1hEBd207MD;00507IC:`1gE2X0Me@Z07MD:P1hEB/00P1iER`307YG;@0707]H;P1mFS00OU/a07iK
<@1mFS00O5T_07]H;P0407YG;@@0NeP^201lFBl00`1nFc40OEX`07eJ<00207eJ<0<0O5T_00@0P5de
07iK<`1lFC40NUL_0P1iERh307YG;`0@07mP<@1lGBl0N5T[07EF:P1eEB`0MeL`07]K=@1nGSP0MUPd
07=E;`1aDbd0LeH^07MJ<01iG300Me//07AH:@80Le<]00@0M5@^07EE;`1gEc40N5Pb0P1iFC<3079E
;@<0LE@/0P1`Db/306iB;@<0Ke<^0P1`E2l406mC:`@0KU8Z00T0KUHb06aB;@1ZD2/0KE4Z079E;@1g
Ebh0MUDZ07=B9`1^DbP00P1^DRX00`1^DR/0KU8]06e@;P0206a?;`<0Jdh/0P1ZCB/206U<:P0606Q;
:@1XCRd0Idd/06A<:P1RBbT0Gd/X0P1MBbL00`1LC2P0H4TW06199`0205m89P80GTLU0P1MAR@01@1I
B2X0F4LY05Q7:@1GARP0ED@V0080E4<U0140Dd8T05509P1B@BL0Dd8X05A3:@1C@RP0DT4W050o9@1?
?R@0E4<Y05919`1@?bD0CchT04hm8`1??R@0D3lU05509P02054m9@0304lm9@1=?B@0C3hT0080BShT
00L0B3hS04Y09`19?bH0B3hU04Hl8`15>b80A3XQ0080@SPO0P13=R<01012=b<0@CTT040j9011>bD2
040k9@07048j9@11>B@0@3PS03lg8P0n=R40?CDP03`d7`0203/c7P0603`d7`0n=R40?cLR03lg8P0n
=R40?3@O0P0k<ah203de8P<0?3@Q0`0k<b0203/f8P<0>SDQ0`0i=20803Lb7PP0=S<P00<0=34N03Db
7`0e<Ql0100e<Ql0100d<Ah0=34R038_800a;Ql2030]7P03034^7`0b;b00=34R0080<34Q0`0_<203
02h_7a00;c0P100Z;1h402T[7@80;S4P00@0;C0O02`_7P0/;ah0:bhM0P0Z;A`202d^7P80;RlO0P0_
<202030a8@P0;c0P0P0];Q`302h_7@<0;c0N0`0d<Qd00`0e<ah0=S@O03Hd7`0203Le80<0=C<N00<0
=S@O03Le800g=B000P0h=R40100e=1l0=SDP03He800f=B0203Lf8@80>3LR200j=Al203/f8080>SDO
0P0i=1h203Pc7@80=cDP00L0>3HQ03Tg8P0i=b80>CLR03Le800f=1l0=38M00<0=S@O0P0e<ah303@b
7@80;c@M00<0<CDN038d7P0d<ah00P0e<ah00`0g<Qh0=C8O03Db7`0603Db7`@0<38M100_<A`0200^
<ad0;C8L02d`6`0^<1/0<2lK03<`7@0e<Ql0>3<P1P0g<Qh203Pc7`<0?CHL00<0?SLM03lh7P0o>1h0
0P10>Al09@12?Al0@c`O04@m8017?R40BChR04`n8`1=?B<0CShT05@o901E@2<0ET4T05M28`1IAB@0
FTHS05]78P1LB2<0GdPV065;9P1TCRT0Ie4Z06QB:@1WDRL0IE0S06A?8P1[CbP0K50X06eA:@1_E2T0
LULZ07AI:P1eFbX0MU`[07UM;P1jGRl0Nel`07aP<@1mHC800`1nHS<01021HC80PV8c08EU=P27IcP3
08UY>P0308QX>@2<KS`0S6hl0080SFlm00D0SW0n08ma?`2@LT00TG=1099a?00209=b?@0309Ac?P2E
M3l0UWE00080UgI100H0UG=309IdA02GMDD0VGM709]iB@2LNTX209ilC00809]jA@2LNdH0WGa709mn
B@2QP4/0Xh9=0:B3CP2UQ4l20:B3CP<0YHA?0`2VQE040:V7E`@0ZXQH00<0ZhUI0:^9F`2[RE/00`2/
RU`30:f;G@80[HmM0`2^T5h30:nAG`@0/Y1R0P2cTF<20;BBI0030;:@HP2cTF<0]99T0080]YAV00<0
]99T0;>AH`2bT6800`2dTFL20;FBJ0<0]Y=Y202dUFT00`2fUf/0]IIZ0;>DJ0020;:CI`030;>DJ02e
UVX0]YM[0080]iAZ102fTfT:0;FBJ0P0]9EY202eTVP80;FBJPD0/Y=W0`2cU6P80;6BIP80/i1X0P2b
SfL20;6>IP80/8eU0`2_T6@30:j?H`80[HiR00P0[8YJ0:f;F`2_SEl0/HmR0;6>I02`SFD0[haV0:j;
I@<0/HiT0`2`SF<20:n<HPT0[X]Q0`2^Sf<00`2_T6@0/95U0;2AI@020;6BIP<0[X]Q102]RV000`2/
REl0[H]N0:f;GP020:f;GP@0[8YM0P2]Red20:j<GP<0[heO00<0/8iP0:b:G02/RU`01P2/RU`00`2Z
Qed0ZhQN0:^8GP040:^8GP060:Z7G@2WQEL0Z8IH0:R6F02YQeT0ZXQJ0P2[RE/02@2/RU`0[XaN0:f;
G@2/RU`0ZhUK0:Z8FP2YQeT0Z8IH0:N5E`020:N5F0040:R6F@2XQUP0Z8IH0:V7F@80ZHMG0P2UPeD6
0:J4EPP0YH=E00<0YX5G0:F0EP2UP5H00P2UP5H30:AoE@<0YH1C102TOe800`2SOU40XWi>0:9nCP06
0:9nCP@0W7Y<102KND/809EbB080V7=60P2GLTD0102FLD@0UG1309E`@`2EL4<809=^@@T0T6/n00P0
SVXj08m[>`2AK3l0TVe109=^A02BKD<0TF]4091Z@`<0SFPl0P2<Ic/308]V>PH0R6Dk0P27I3X00`2:
Icd0RFHl08MT>P0308ER>080Qf@j1025HSP408AQ=`04089O=`21GSH0PEhf085N=P80P5de0`1oG3@0
2P20GCD0PUlg08=P>023H3P0PUlg081M=@1oG3@0OeTb081J<`21Fc@2089L=@04085K=01oFC80OUPa
07eL<`H0OUdd00<0OE`c07QF<@1hES401P1hES4207YH=@80NELd0`1hES<00`1gEC80M5<`07AC<006
07AC<003079A;P1`Cb`0KTdZ0080KD`Y00<0Kdh[079A;P1dDc00201_CRd02@1`Cbh0Kdh]06m>;@1^
CB`0K4/Z06Y9:01YB2L0J4LV06Q;:@0306M::080ITTW0P1UB2H00`1[CB/0JT`Z06M99`0206I89P03
06Q::01ZC2X0K4h/00<0J4TZ0P1YBR/306Y;;00306M::P1VBBT0IDPX00<0HdHV00<0I4LW06I9:@1W
BRX0201WB2`206=19P0306939`1Q@bL0H4DX0080GdHX00T0GdPY05]39`1LA2P0GDDY05i6:P1MABT0
G4@X05Y29P1I@BD00P1H@2H205Lo9@<0EShT00@0ECdS05@l8P1D?280E3`R0P1C>b4305@l8P80C3XR
00<0BcTQ04Xh8019=al00P18=Qh00`17=Ad0@S4M04<b7P0204<b7P<0A3<O00<0AC@P04Lb7`17<Ql0
1P17<Ql02014<b40@c8P040_7@0o;Q`0?RdK03l^7010;ad0@S4O0P11=242040c80<0?c8O00@0?S4N
048e9011=2<0?c8Q0P0n<B000`0o<R40@3<R044d8`0803/^7@<0>2`N0P0g:ad00`0f:Q`0=BTK03DY
6`0303HZ7P80=BTM00<0=2PL03<W6`0c9a/0200c:Ad7038Z7@03034Y700a:1l0<BPO00<0<BPO00@0
<2LN02lV7@0_9Qd0;RLM0`0]9Q`202`U6`80:b@J0P0^9ad202dV70@0;2DK00@0:b@J02HS6P0V8aX0
9R<J0P0U8QT302@Q600502@U7`0S91h08b@N024R700P8A/00P0O81X00`0N7aT0824I01lP600201lP
60807QlG0P0M7QH801hO5`807QlI0P0O81X3020Q6`07024R700U8Qd0924L02@Q700S81/08QlJ024N
6@02020M60808QlF0P0S81L302@Q600302DR6@0U8Qd09B8M0080924L0`0S81/0100R7aX0824K020Q
6`0P8A/?01lP6P807QlI0`0M7QP00`0L7AL07AhI01dN6@0401`M60807AhI200M7a`00`0I6aP06Q`I
01`N6`0201dO700301`N6`0J71T06A/H00P06Q`I200J71L801`N6@P06Q`I0P0N81d201dO70D071hK
400K7AX301XL6@806adJ0`0L7Q/0100M7a`071hK01`N6`0L7Q/201/M6P806Q`I200K7AX:01XL6`<0
6A/J0`0H6QT801TK6PP051XH0`0G6AP[ooooo`00:_ooool01@2WMdL0YWI60:IfAP2UMDD0Y7A40080
Xg=300<0XW9209me@`2OMD<01P2OMD<809mf@PD0X7A30`2OLd8409me@`040:1fA02QMdD0XgU70:Aj
B0P0XgQ50P2RMTD30:=gAP<0Y7Q700H0[7Y90:YjB@2ZNTT0ZG]90:MlB@2VODT20:EmB@030:9iA@2S
NTH0YGa800<0YWe90P2UO4P30:QmBP<0ZGi;1P2ZOd`20:UnB`<0Z7e:0`2YP4`20:QoB`<0Ygi:00<0
ZWm<0:^0C@2/PDh00P2/PDh00`2ZOd`0Z7e:0:MlB@080:UmC0<0ZX5=0`2YP4`20:QoB`P0ZWm:202Y
P4`80:b3C`040:^2CP2/Pdl0[8=?0:b3C`@0[HA@0P2YP4`0102ZPDd0Zh9>0:^2CP2/Pdl20:f4D0<0
[hIB0`2^QE420:f4D0040:V4C`2ZQE00ZXE@0:Z5D080ZhIA0P2/Qe820:f4C0060:f4CP2]Q500[XEA
0:j4DP2^Q5@0[hEE202/Qe<00`2]R5<0[8MB0:b7DP020:^6D@030:Z5D02[QU40ZhIA00L0[8=?00D0
Zh9>0:b3C`2/Pdl0Zh9>0:Z1C@020:V0C080Z7m;0P2YP4`01`2XOd/0YWe90:ElB02TNdL0XgY60:9i
A@2NNDD00`2ONTH01@2NNDD0VgI209]f@P2IM400Ug8n0080VGA000<0V7<o09Mb?P2FLCd00P2EL3`0
1`2DKc/0UG8l09A`?02CKc/0TVhl095]?@2?JSd00P2>JCd0102CKD00TV`o091Z?@2=IcX408aV>@<0
RFDe0P28I3@308MS<`0408ER>024HCL0PUle081M<`80Oe`b00L0P5dc085N=01kF300NeP`07YG;`1i
ERh0N5D]0080Me@/00@0MU<[07UF;P1iERh0N5D]0P1gE2`02@1fDb/0ME8Z07EB:P1aDbl0L58^06mA
;@1^D2`0KDl[06]=:@0206Y<:080JTd[00@0JD`Z06Q;:@1WBRP0IdXX0P1VBBL0101XBbT0IdXX06M:
:01WBRP306I99`0606E89P1XBbT0J4/Y06U<:P1ZCB/0Jdh/0P1/Cbd01`1]D2h0KU0^06mA;@1_DBd0
L58/075D;01bEB/00P1cERX00`1eDRX0MU<[07MD;00207QE;@0307MD;01fDb/0ME8Z0080ME8X00<0
MU<Y07MD:P1hEB/00P1iER`0101jEbd0N5D[07UF;01kF2h207eJ<00307aI;`1kF2h0NUL]00<0NUL]
0P1kF2h;07aI;`P0OEX`00@0PEhf07mL=01lFC40NUL_101iERh04@1jEbl0O5d^07YK;@1hFB/0MUL[
07IF;@1gEc00NUXd07aL=P1eEcD0LU@`071B;P1cEBl0MeXb07UL<P1gFRh0M5L[0080Le8_00@0M5<`
07ED<@1eE340MUDb0P1gES<207=F;P80LUD]0`1aE2`0101`Db/0KU8]06iB;@1^DRd306mC;P80L5@_
0`1_Db/206iB:P<0KE4Y0100KUHb06]A;01XCRT0K50Y075D;01fERd0MUDZ07AC:01]DRL0KU8Z06mC
:`1_Db`0Ke<^06e@;P1/Cbl0Jdh^0P1ZCB/306]>;00;06Y=:`1XBbT0IdXX06Q>;@1WCB`0ITh/06A=
:`1QCBX0GT`X05a:9P1JBRH00`1PBBL205m89P<0GTLU0P1JBB/05P1IB2X0F4LY05I59`1EA2H0E4<U
05=2901@?bD0DD0V05919`1C@RP0E4<Y05=2:01A@2H0D3lU05A3:@1B@BL0D3lU04ln901>?B<0CchT
050o9@1A@2H2054m9@0304lm9@1>?RD0CClU0080BclU00T0BT0U04/o9`1:?RH0BCdU04Pl9017>b<0
ASXR04Di8@14>2000P17>2D00`15>2D0@cPT044i9002040j900403lj9011>B@0@CTT040h8`80?cLR
00H0?SHQ03de800m=B00>c<N03`d7`0n=R4203lg8P0403hf8@0l=1l0>c<N03/c7P80?CDR0`0l=243
03/c8080>cHR0`0j=B4303Td80P0=c8N200f=1l00`0c<1d0=34N03Db7`0303Db7`0503@a7P0c<1d0
=34R03<`8@0a;Ql00P0`;Ah00`0a;Ql0<c0Q03@a8P03030a8@80;c0P0`0^;al@02l`800402X/7P0Y
:ad0:B/M02T[7@<0:2XL00<09bTK02``7`0[;ah00P0[;ah402X^7@80;BhN0P0^;al202l`8080<34Q
200_<20302d^7P80;RlO0`0_<20203<a700303@b7@0e<ah0=S@O0080=cDP00<0>3HQ03@b7@0d<Qd0
0P0e<ah0100f=1l0=cDP03Pf8@0h=R43034c7@80<S@N0`0c=Al803Le80<0>SDO0P0i=1h303Pc7@80
=S@O00L0=cDP03Pf8@0h=R40>3HQ03Hd7`0e<ah0<c4L0080=S@O0P0e<ah303@b7@0903<a700^<a`0
;S<L02lc700a<ad0<c8M03@b7@0e<ah0=c8N00P0=C8O200_<A`202db700602d`6`0];aX0<2lK03<`
7@0e<Ql0>C@Q0P0h<al303Td80<0>SDQ0P10=Q/01011=a`0@SPM04<i7P13>Ah204@j7`0604Hm8018
?B40B3dQ04/m8P1=?B<0CchT0P1B?RD03P1H@2@0F44R05U28`1KA2@0G4DS05e78P1NB240GdTR06=;
9`1TC2H0IThX06QA:01ZDbT0JU<W0P1ZE2D01P1]DBT0KU8Z06mD:@1`EBP0LULX07=I:080M5XW00<0
NUh^07]O;`1mHC400P1oHc<01`20I3@0Of<c07mS<`23HC<0QF<e08MU=`2:J3X00`2;JC/00`2:J3X0
SFlm08e_?@0308a^?00408i`?P2?LCl0T79009=b?@80U7<n00<0UG@o09Ie@02GMT400P2HMd801@2G
MDD0V7I609UgA`2JN4P0VgU90080WG];00L0WWa<09elA`2NODP0Wgi90:1oBP2RPD`0Xh9=0080Y8=>
00@0YHA?0:J5D02VQE00YXE@0P2WQU420:R7DPT0ZXQH00@0ZhUK0:b:G02/RU`0[8YL0P2]Red20:j<
GP<0[XmP0P2_T6430;2AHP040;:@HP2cTF<0/i5S0;>AH`80]99T0P2eTfD00`2bT680/i5S0;FCI@02
0;JDIP030;FCI@2cTF<0/Y1R0080]95W0P2eTVP30;JCJ@030;NDJP2eUVX0]IIZ00H0]IIZ00<0]YM[
0;FFJP2cU6P00P2bTfL00`2cU6P0]IIZ0;JGJ`080;JCJ@040;NDJP2fTfT0]Y=Y0;JCJ@<0]I9X00<0
]95W0;FFJP2eUVX01P2eUVX80;FBJ0P0]I9Z102aTVH20;:CI`80/iAX202bTfL01P2eTVX0]95Y0;BA
J@2cT6P0/XmW0;6>IP80/8eU0`2`TFD20:n@I0<0[XmS00P0[H]K0:j<G02`SV00/HmR0;:?I@2aSVH0
/8eW0:n<IP<0/XmU0P2aSV@80;2=H`80[haR0P2^Rf420:j?H`040:n@I02`TFD0/95U0;6BIP80/Y=W
0`2`SF<70:n<HP80[X]Q102]RV020:f;G@80[XaN0`2_SEl00`2`SV00ZhUK0:^9F`060:^9F`80ZXMM
00@0ZhQN0:b9G`2/REl0ZhQN0P2ZQed40:V7F@<0ZXQJ00<0ZhUK0:j<GP2^S5h00`2]Red30:b:G006
0:^8H02[R5h0ZhQN0:^9G02[RE/0ZhUI0P2[RUL0102WQEL0Z8IH0:R6F02XQUP30:V7F@030:Z8FP2Y
QeT0ZHMI00H0ZHMI202YQ5X80:R3EPP0Yh=C1@2POTh309mmC@P0VgQ>0P2MNDT209ahB00309]gA`2J
MTH0VGE500T0VGE52@2ELD402@2ELCl0UW9009Mc@`2HLdH0V7=709MbB02EL4H0U6i709A_@P0309=^
@@80TVe00P2AK3l0102BKD<0TFa2095/@P2AK483091[@@0908mZ@02AK480T6]108iY?`2=J3h0S6Lm
08eX?P2>JCl0SfY000D0S6Lm0`2;IS`308YU>`80RF@j0`28HcT00`27HSP0R6<i08UT>P0208YU>`03
08UT>P28HcT0Qf8h0080QUlf0`28HCP01P26GcH0QEhe08=L<`24GcD0QF0f08IQ=`80Qf8h00<0QV4g
08EP=P24GcD02021Fc@3085K=P80P5Xe0`1oFC@807]H<P0307YG<@1iES00N5D_0080Me@^0P1hEBl0
0`1iES00Me<a07MC<@0607MC<@@0NEH`00D0Me@^07EB;01cD2X0LTlY079B:`03075A:P80L50Y0P1_
CbP02@1eDR`0M54[07AA:`1cD2X0M54[07EB;01fDbd0Me@^07A@;P0307EA;`80MU8`0P1gDc400`1c
DRl0LE0]071?;00406i=:P80L4l/201aCBd01P1_B2T0KDTY06e9:@1]BRX0K4/Z06]=:`80JTd[00<0
ITTY06M::P1XBb/00P1YC2`00`1WBRX0IDPX06A79`030694:080HD<W0`1P@RH00`1O@BD0GT0T05do
8`0205`n8P0305do8`1N@2@0Gd4U0080EclS00<0EShR05Dm8@1D?2000P1C>al00`1B>Qh0CSXQ04hj
8@0604hj8@@0DSPQ0P1A=b02050f7`0304hj8P1<>200BCDM0080Ac<K00<0B3@L04Xf7P1<>2000P1=
>b<304`j8P<0BcTQ00<0CC/U04`j901:>2800P18=R000`19=b40BSPR04/i8`0804Hd7P80@S4Q00@0
@C0P040_7`0o;Qh0?bhN0P0n;Ad01P12<280@BlQ044_8@10;R00?bdO03h/7P80?B/M200l;ah303`a
7`<0>c0N0P0j;ad02@0i;B40>RhR03/_8`0k;b<0>RhR03T]8@0h;200=b/O03D[7`0303@Z7P80<bTM
0P0b:1`303D[7`80=2XN100c:Ad302XV6P80:BDI0`0X91P01P0Z:R80:BTQ02PX800W9al09BDM02@T
70808b<K0P0U9A/202@T6P<08b<I00<08R8H02@T6P0T91X01P0T91X302<S6`8092@L0`0U9Ad302PS
7@<09b8L0P0V8A/0100X91P0:BDI02TU6@0Y9AT202XV6P80:bLK00@0:RDO02TT7P0Y91h0:B@N0P0X
8ad202LR70<09BDM0`0T91`:02<S6`808R<K0P0Q8QX2020Q6@807b0H00<08B8L020Q6`0O81X00P0N
7aT00`0O81X0824K024R700801lO7@0301`N6`0M7a`07R0M00807b4N00<07R0M01dO700L7Q/0200L
7Q/801`O60P07B0I100M7a`201`N6`806adJ0P0O8Ah201hP7@@07AlL500L7Q/201dO70@07R0M0`0M
7a`201`N6`806adJ200L7Q/;01XL6`806A/J0`0H6QT801TK6PP051XH0`0G6AP[ooooo`00:_ooool2
0:MgA`040:IfAP2UMDD0Y7A40:=c@`80XW92202NM4880:1g@`H0XG=20P2RM4<0202PMT@0WgE309id
@P2NM480WgE30:5gA@2SNDL0YG]9202SN4D30:AhA`<0YGU80P2VNTT01P2/NTT0ZWY90:YjB@2YNdT0
Yga90:ImB@80YGe900<0XWU50:=jAP2UO4P00`2WOTX00`2VODT0YGa80:QmBP020:QmBP<0ZGi;1P2Z
Od`20:UnB`<0Z7e:00<0ZX5=0:V0C02YP4`00P2XOd/20:MnBP030:ImB@2ZOd`0Zh1=00<0[85>00<0
ZWm<0:QmBP2WO4T0202YOD`30:Z1C@<0ZH1<0P2XOd/80:YoBPP0Z7m;202/Pdl30:f4D080[8=?0`2[
PTh20:Z1C@040:^2CP2/Pdl0[HA@0:j5D@80[hIB0P2`Qe<20:n6DP040:j5D@2]Q500[HA@0:f4D080
ZHA?0`2ZQE030:^6D@80[XE=00@0[XE?0:f4D02]Q500[H=A0P2/PU880:^6DP80ZXE@0P2[QU440:b7
DP80[XEA00@0[HA@0:b3C`2[PTh0Zh9>0P2ZPDd01P2]Q500[8=?0:b3C`2[PTh0ZX5=0:V0C080Z7m;
00H0ZX5=0:V0C02XOd/0Ygi:0:ImB@2TNdL20:=jAP@0WWU500D0W7M309Ye@@2JMD40Ug8n09E`?002
09Ud@080V7<o0100Ug8n09Ia?@2EL3`0UG0l09Ic?@2FLSh0U70l09=_?@2AKCd0T6/n08mZ?P2>JCd0
UFm209=]@02AJch0SVPk0`2<IST0102=IcX0RVHd08YV=02:IS@208UU<`<0R6@b00<0Q64g08=P=P21
GS@00P20GC<00`21GS@0Pf0f08AQ=`0207aI<@0307]H<01jEbl0NEH^0080N5D]00H0Me@/07aI;`1l
FBl0NeP^07YG;@1iER`207QE:`0907MD:P1bE300LU@`071B;P1_DBd0KDl[06a>:P1[CBT0JT`X0080
Jdh/00H0JTd[06U<:P1XBbT0IdXX06I99`1UB2H206Q;:@80IdXX00@0ITTW06E89P1UB2H0IDPV0P1U
BbX00`1VC2/0Idd/06Q>;@0206U?;P0706Y@;`1]Cbd0KDl[06i@;01_DB/0L5<[071C:@02075D:005
071=9@1bCbL0M54Y07IC:`1gE2`00P1fDb/04@1eDRX0M54W07AA9`1eDRP0MU<Y07MD:P1hEB/0NEH/
07YG;@1gE2X0N5D[07YG;@1lFBl0OEX`07aI;`1kF2h0NUL]00<0NeP^00<0O5T_07eJ<01mFS000P1n
Fc4807]H;P@0OEX`101nFc401P21GSH0Oe`d07eJ<P1jEbl0NEH^07QE;@<0NEH^00H0MePY07MH:P1g
F2X0MeP/07MG;P1gEc0207QH<P0807EG=@1bE380L58^079D;P1gFS80NE`d07QK<@1eF2h407=B;`@0
M5<`0`1cERh2079E;@<0LE@/0`1^DRd306mC;P80L5@_0`1_Db/00`1^DRX0KE4Y06eA:@0206a@:00P
06iF<P1[DB`0IddX06]?:01`Db/0MUH]07MF:`1eE2T0KE8W06iB:P1_Db/0L5@]06mC;P1^DBl0K4l_
06Y=;@1YC2X0JTd[06]>;01/Cbd0Jdh/06Y=:`1XBbT0IdXX06I<:`1WCB`0J50^06M@;P1SCb`0GddY
05]99@1GAb<406199`80GdPV0P1NAbD0301LBbd0FdX/05Y9:`1HAbT0EdHX05E49P1D@bD0Dd8T04hm
8`1??R@0DD0V05=2:080E4<Y00X0Dd8X05919`1D@bT0DT4W050o9@1??R@0CSdS04ln901@?bD0DD0V
0P1A?BD00`1??BD0CShU04do9@0204/o9@0304Y09@1<?BH0C3dV0080Bc`U00@0BS/T04Tj8`19>R<0
B3TR0P1:>BL01P18>BH0ACPU04<h9011>B@0@3PS03li8`80@3PS1P0o=b800`0k<ah0?3@O03hf8@02
03lg8P0403hf8@0l=1l0>c<N03/c7P80?CDR0`0l=24303/c8080>cHR0`0j=B4303Td80P0=c8N200f
=1d00`0a;Q/0<RlL03@a7P0203Db7`0603@a7P0b;a`0<BhK03@a8P0c<240<RlP0P0a;Ql00`0b;b00
<c0Q03@a8P02034b8P80<34Q0`0_<2000`0^;al0;c0P02l`800602l`80P0<34Q0P0];b4202`^8004
02/]7`0Z;1h0:R`N02X/7P809bhL0`0X;ad302T`7P80;BhN0P0^;al202l`8080<34Q200_<20202`]
7@80;BhN0`0^;al01`0_<200<S0K03<a700d<Qd0=C<N03Hd7`0g=B000P0h=R4203<a700403@b7@0e
<ah0=S@O03Le8080>3HQ00@0;S0J02la6`0_<A/0;c4K0P0`<Q`2034c7@P0=C@P0P0j=Al203Td7P@0
>3<M0P0e<ah01`0f=1l0=cDP03Pf8@0g=B00=S@O03@b7@0c<A`00`0e<ah303@b7@80<c4L0P0]<Q/0
1P0^<Q/0<38L03<b7@0d<Qd0=C<N03Lb7PP0=34N0`0^<1/502la700802db700/<A/0;2lJ02d_6P0a
<1`0=34N03Hc800i=24303Xe8@0303/f8P0l=b<0?3LS0080?CPT00H0@SLK04<h7014>Ad0ACXN04Hk
7`17?20204Pm8@0604Xl7`1;?B00C3dP04hm8@1??R80DShS0P1D?b@205U28`0605Y38`1LAB<0GDLR
05i88@1OBB80H4XQ0P1VC2L01P1WCRH0J4lV06YB9P1]EBL0L5PZ075I:@80M5T^00`0M5T/07EJ:`1e
FbX0ME/X07IL:@1fGBL0Nel]07aP;P1oHc40PFDc089V=021IC<2081T<P0408AR=026I3H0R6Hh08]Y
>`<0S6Xl00T0RfTk08e_?@2<KS`0Rfdk08Y/>P2;KC/0S6hl08i`?P2?LCl00P2DLch00`2EM3l0UWE0
09Mf@@0209Qg@P0509Uh@`2JN4P0VWQ809YhB02KNDT00P2LNTX209ekB`80X7m:0P2QP4/20::1C080
Xh9=00@0YXE@0:N6D@2WQU40YhIA0P2XQe820:V8D`D0ZhUI102ZR5P30:b:G080[H]M0`2^S5h30:n@
HP80/95S0`2aTV@20;>AH`80]99T0`2eTfD0102fU6H0/i5S0;BBI02eTfD20;JDIP030;FCI@2dTV@0
/i5S00<0]I9X0`2fTfT20;NDJPP0]IIZ00<0]YM[0;FFJP2cU6P00P2bTfL00`2cU6P0]IIZ0;JGJ`08
0;JCJ@<0]iAZ00<0]Y=Y0;FBJ02eTVP00P2dTFL80;FFJPP0]Y=Y202fTf/20:n@I080/95U0P2aTVH:
0;:CI`050;JCJ`2eTVX0]I9Z0;BAJ@2bSfL00P2aSVH0102`SFD0/I9V0;6BIP2aTVH20;2AI@<0[i1T
00P0[XaL0:n=G@2aSf40/Y1S0;>@IP2bSfL0/HiX0;2=I`<0/i1V0P2bSfD30;6>I080/XmU0`2aSV@0
102`SF<0[haR0:n<HP2_S6820:f>HP060:j?H`2_T6@0/95U0;6BIP2bTfL0/iAX1P2aSV@20;:?I@03
0;2=H`2_S680[haR0080[X]Q0P2]RV00102/REl0[8YL0:b:G02/RU`20:f;G@<0[XaN202/RU`00`2[
R5h0[8UO0:j;H@020:n<HP030:j;H@2/REl0ZhQN0080[H]M0`2/RU`30:^9F`80[8YL0P2]Red30:j<
GP090:n=G`2^RfD0[X]S0:f:H02/RUd0ZhUI0:^:E`2ZRE@0ZXUC00<0Z8IH00<0ZHMI0:Z8FP2ZR5X0
0P2[RE/80:Z8FP<0ZXEK1@2[QU`40:R3EP@0ZHAG202ZQUH00`2TPe00YHAA0:F4D@050:F4D@P0Xh1F
0P2TP4h0102SOdd0XWi<0:5mB`2PO4X209mkB@P0X7a:2@2MNDL209ijAP0609mkB@2PO4`0WgY=09eh
C02KMTX0VGA:0P2LN4P209]gA`<0VWI600@0VGE509aeBP2LMDX0VgA90P2JLdP409UbA`0309QaAP2F
Kd@0U6e20080U6e20P2FKd@509=/@@<0U6e20P2DKT4209=]@0<0TV`o00@0TF/n08mY?02@JSd0TF/n
0P2BK3l01@2AJch0T6Xm08mY?02@ICX0TFHk00<0TVLl00H0T6Dj08iS>02=HSL0RV@g08]U>02=IcX2
08iX>`0308eW>P2;ICP0RV@g00P0RF8i0`27H3T208IO>0<0QEhg2024GSL408=M=P04089L=@21Fc@0
OeTb07iH<@P0OUPc00T0PE`b089M<`22GC<0PUdc085L<P1nFBl0NeH/07YE:`1mFS000`1lFBl207]H
;P80NUL]00D0Ne@[07aE;01nEbh0OeP_081I<00207mH;`0407iG;P1nES80OUHb07iF<P80OeLc0`20
F3@0101kF380NULa07QE;`1fDbd207EB;00307IC;@1gE2h0N5D_00P0NE4^00H0N4d[07I>:`1fCR/0
MU0/07A@;01cDB`207=C;@0806m>:`1`Cb`0LE0]079A;P1aD2d0L4l/06i=:P1/BbP306e<;@80K4//
101[BR/01`1YB2T0J4LX06M69`1WARL0J4LX06U8:@1[BR/00P1QARP00`1PABL0Gd@V05i39@0205e2
900605a18`1MARL0G4DV05a59P1KA2D0FT<T0P1I@R<01@1H@B80Gd0T05m0901O@2@0GSlS0080GChR
0P1L?B40201K@bT0FD4W05Dm8`1C>b40DSXP05@l8P1G?bD0FD4W0P1G@RL205I19P@0ED0U00<0EClW
05@n9P1B?2@00`1@>R800`1A>b<0DS`T04li8@0704li8@0504hi:01=>2L0CCPW04`g9P1:=B@00P19
=2<01`18<b80BcDW04Xd9P19<bD0B38T04La8`16<2800P15;b4804Dd80<0@cLQ0P12=R002`11=Al0
@3@N040d7P0o<R80@3<S044d9012=BD0@C@T040c8`0n<B40?2lO00<0>blO0P0j;Qh303T]7@<0?30P
0P0k;al403X^7P<0<BhO0P0`;Ah302l/7@06030]900_;2<0;R/R02dZ8@0[:1l0:RLN0P0X9A`0100[
:A`0:RPK02XX6`0Z:1/202TW6P80:2HI200Y9aX0100X9A`0:BHM02TV7@0Y9Qd202XW7P80:bPO100Z
9Qd302/W7P0402`X7`0^:a`0;R/L02h[7080;b`M0`0`;Ah302dY8080;2PO0`0[9ah302/X7`0302XW
7P0Y9Qd0:BHM0080:2DL200Y9Qd0100U9a`092HK02@V6`0T9Q/202<U6P808R@I00<092DO02<T7P0Q
8Q`00P0P8A/00`0Q8Q`08b@N02@U7`08024P7P0301hP7@0O8Ah08B<P00808R@Q00<08B<P01lQ7P0N
81d0200O8Ah801lR6`P07R4J0`0P8Ql201lQ7P0401hP7@0M7a`07AlL020R7`<07b4N0P0N81d301dO
710071hK0`0N81d201lQ7P<0828O0`0N81d201dO70/071hK2P0K7A`201XL6`<06A/J00<061XI01XL
6`0J71/01P0J71/801@J60<05aTH:oooool002[ooooo00P0ZWM80:UfA`2XMDH0YgA50:IcA02ULT<0
Y7520:=`@@P0WWA2202QN4@20:1b@@@0XG=20P2RM4<0202PMT@0WgE309id@P2NM480WgE30:5gA@2S
NDL0YG]9202SN4D30:EiB0<0YWY90P2WNdX01P2/NTT0ZWY90:YjB@2YNdT0Yga90:ImB@80YGe900P0
XWU50:AkA`2VODT0Ygi:0:QoB`2WOTX0YWe90:AkA`<0Z7e:0`2YOT/60:YoC080ZGi;0`2XODX20:Z1
C@040:V0C02XOd/0Z7m;0:MnBP80YWe900<0ZWm<0:^0C@2/PDh00P2/PDh00`2ZOd`0Z7e:0:MlB@08
0:UmC0<0ZX5=0`2YP4`20:QoB`P0ZWm:202XOd/80:b3C`80[XEA00@0[HA@0:b3C`2[PTh0Zh9>0`2Z
PDd01`2[PTh0[8=?0:f4D02^QE40[hIB0;27D`2aR5@00P2`Qe<20:n6DP040:j5D@2]Q500[HA@0:b3
C`<0ZHA?0P2ZQE030:^6D@80[hI>00@0[XE?0:f4D02]Q500[89@0P2[PE480:^6DP80ZHA?00<0ZXE@
0:^6D@2/Qe800`2]R5<20:n6DP060:j5D@2/Pdl0Zh9>0:Z1C@2YP4`0Z7m;0P2]Q500102/Pdl0Zh9>
0:Z1C@2YP4`20:QoB`80ZX5=00H0ZH1<0:MnBP2VODT0YGa80:AkA`2SNTH209ehA00309iiA@2MN4@0
VgI20080VGA000<0UW4m09A_>`2JMD400P2IM4000`2HLcl0Ug8n09Ia?@0209E`?00@09Md?P2FLSh0
UG4m09=_?@2BKSh0T6/n08mZ?P2>JCd0UW1309A^@@2AJch0SVPk08eW>P2<IST0SFLj08iX>`80RfLe
0P2:IS@308UU<`0308QT<P23H3H0PUle00<0PEhd00<0Pf0f08ER>026HcT00P1lFC40101kF300NUL_
07UF;P1iERh207QE;@80OU/a00<0OEX`07aI;`1kF2h00P1jEbd04@1iER`0LeDa079D<01aDbl0Ke4]
06i@;01/CRX0JddY06Y<:01/Cbd0Jdh/06Y=:`1YC2X0J4/Y06M::01VBBL0IDPV0080J4/Y00@0IdXX
06I99`1VBBL0IDPV0P1TAbD01P1SBbT0I4`Z06A<:P1UCB/0ITh/06M?;@80J50^00H0JT`Z06Y<:01[
CBT0K4hX06e@:01^DBL206mB9P0406i;8`1_C2@0LTlW07EB:P80MU<[00P0ME8Z07AA:@1cD2H0M54W
07EB:01fDbT0Me@Z07QE:`80NEH/00@0MU<Y07QE:`1jEbd0NeP^0P1lFBl01@1kF2h0NUL]07]H;P1k
F2h0O5T_0080OEX`00<0OU/a07mL<P1oG380201kF2h307eJ<0D0OU/a00D0PEhf081M=@1mFS80NUL_
07UF;P0307QE;@0707UF;P1dEBH0MEHX07IG:@1gF2`0N5P_07MG<00207IF<00907AE=P1aDc40L58`
079D<01gFC<0NUde07QK<@1eF2h0M5<b00<0Le8a0`1bDC00101aD2l0LeH^07=F;P1cERh3079E;@80
LE@/0`1^DRd306mC;P80L5@_0`1_Db/00`1^DRX0KE4Y06a@:00206a@:00C06iF<P1ZD2/0IddX06Y>
9`1`Db/0MUH]07MF:`1fEBX0K54V06iB:P1_Db/0L5@]071D;`1^DBl0K4l_06Y=;@1YC2X0JTd[06]>
;00206a?;@0<06Y=:`1XBbT0ITTW06E;:P1WCB`0JE4_06UB<01UDBh0H4hZ05]99@1EAB40HDXX0`1P
BBL205m89P80GTLU0P1LBbd0101JBB/0FDPZ05M6:01EA2H205A39@0404`k8@1>?B<0DD0V05=2:0<0
E4<Y00T0Dd8X05A3:@1B@BL0D3lU04ln901>?B<0CchT050o9@1A@2H00P1A?BD00`1??BD0CShU04do
9@0204a09P0304]19P1<?BH0Bc`U00<0Bc`U0`1:>b@204/j:00404Tj9`16>BH0@cPT048g8`80?cLR
00@0?SHQ03lg8P0o=b80?cLR0`10>2<01011>B@0>c<N03`d7`0n=R4203lg8P0403hf8@0l=1l0>c<N
03/c7P80?CDR0`0l=24303/c8080>cHR0`0j=B4303Td80P0=c8N200f=1d00`0`;AX0<BhK03<`7@02
03@a7P0603<`7@0a;Q/0<2dJ03Db8`0c<240<RlP0P0a;Ql00`0b;b00<c0Q03Db8`02034b8P80<34Q
300_<208030a8@04034c9@0`<R@0<38T02la8`80;S0R0P0];b4202H]6`0402L^700X;ad0:2lM02T`
7P80:S4O0P0];Qh202h_7`80;c0P0P0`<B4802l`8080;2dO0P0];R0402h_8@06038`6`0c<A`0<c4L
03Dc7P0f=1l0=cDP0P0h=R401P0b<1/0<c4L03@b7@0e<ah0=S@O03Le8080>3HQ0`0/<1T202da6P<0
;S8K200d<al203Xe7`80>C@N0`0h<ad0100g<Q`0=C<N03Dc7P0f=1l303Le800303Dc7P0d<Qd0<S0K
00<0=C<N0P0d<Qd303<a7080;34J00<0;S8K02la6`0b<A`00P0d<Qd00`0g<Qh0=34N03@a7P0603@a
7P@0;S0K100_<A`202`a6`0602`_6P0];aX0<C0L03@a7P0f<b00>SDR0P0k=R8203`g8`0403dh900n
>BD0?STU03lj9P80A3TM01l0ACXN04Hk7`17?200B3dQ04Tn8P1:?b<0BchN04`m7P1=?Ql0CchP058o
8@1D?b80EShR05Lo8`1J@B<0Fd8S05a3901MAB<0GdLS06188P1QBR40HT/R06M=:01WCRH0ITdU06M>
9@1ZDRH0KUHX07=K:`1eGBd0NEhc0080NEha00<0NEh_07UO;P1hGR/00P1hGbT0301kGbd0OF4_07mS
<@22IS@0PfLe089V=021IC<0P6@b08MR=@28HcH0RfHi08eX>`80SfXm0P2>JC`00`2=Kcd0S6hl08Y/
>P0208U[>@0408]]>`2=Kcd0SW0n09Ac?P80UG@o00<0UWE009Mf@@2HMd800P2IN4<809ajBPP0XX5<
0`2WQU420:R7DP<0ZHQC1P2[RET30:Z8F080[8YL0`2]Red30:j<GP<0[i1R0P2`TF<30;6BI0040;>A
H`2dTV@0]99T0;BBI080]I=U0P2fU6H00`2cTF<0]99T0;FCI@020;NEI`030;FCI@2dTV@0/i5S00<0
]I9X0P2fTfT30;NDJPP0]IIZ00<0]YM[0;FFJP2cU6P00P2bTfL00`2cU6P0]IIZ0;JGJ`020;FBJ0@0
]Y=Y0P2gU6X20;REJ`040;NDJP2fTfT0]Y=Y0;FBJ080]95W202eUVX80;JCJ@P0]Y=[0P2^Sf<20:n@
I0040;2AI@2aTVH0/I9V0;:CI`P0/iAX00P0]iA/0;JCJ`2eTVX0]95Y0;>@J02bSfL0/HiV0;2=I@<0
/I9V0P2`TFD30:n@I0080:j<G02_SEd0/HmQ0;:@H`2cT6H0/XmW0;6>J02`SFL30;>@IP80/XmU0`2a
SV@20;>@IP80/XmU0P2aSV@02`2`SF<0[haR0:n<HP2/SF40[HiR0:j?H`2_T6@0/95U0;6BIP2bTfL0
/iAX0080/HiT102bSfD20;>@IP040;2=I@2_S6@0[haT0:j;H`80[HYR0P2/RF430:^9F`80[8YL0`2]
Red80:n=G`030:j;H@2_S680/HiT0080/XmU00@0/HiT0:n<HP2^Rf40/HmQ0P2`SV001@2_SEl0[XaN
0:f;G@2]Red0[8YL0080ZXQJ00@0ZhUK0:b:G02^S5h0[heO0P2`SV002@2_RfL0[haV0:j;H`2/RUd0
ZhUI0:Z9EP2YR580Z8MA0:N5E`020:R6F0030:V7F@2ZR5X0ZXQJ0080ZhUK202ZR5X00`2ZQE/0ZhIL
0:^6G0020:^6G0<0[8MM0P2WPUD40:R3EP80ZHAG202[QeL00`2XQe@0ZHQE0:V8E@020:V8E@<0ZXUF
202YQU`01P2ZQU@0ZHEC0:V5D`2WPe40YX9@0:F1C`80Y81>202UPDl90:B0CP80YH5=00H0YX9@0:F1
D@2TOe80XWe@09mjCP2NNDd30:9nCP80XGe=0`2PO4`0102SOE00XWa?0:9lC`2QNdh20:1jC@80WgU<
00P0WWQ;09egBP2KMDP0VWA709UcAP2JM4L0VgE809afB@<0V7951@2ILdH309YdA@<0VG=40P2HLT<0
0`2DKSl0UFm009Ma@P0209Qb@`0309Ma@P2EKd00U6ho0080UV/n00T0Uf`o09Q]@02GK3l0UFXm09=X
>`2BIcX0T6Li099Y>`2DJcd00P2EK3h00`2DJcd0TVTk091W>@08095W?@0408iT?02=Hc/0SF<k08eS
>`80S68j0P2;HCT808]T>`0808UR>@2:HcX0S6Dl08aU?02;I3/0R64h08AM=022Fc88085I=@0808EN
<`26Gc@0Qf0e08MP=@25GS<0Pe`a081I;P1nEb`308=Q=0<0PV0c0P21Gc802@1nE2X0P5H/08=I;`26
G380Qedc08IL<P24FS00PUP^08=I<@0308AJ<P80QE/c0P26G3@0101nFc40OEX`07]H;P1iER`207QE
:`0307UF;01jEbd0NeP^00P0OE8_00H0O50]07]@;@1kD2d0NU8^07UC;P1hEBl207ME;`0307=A;01d
DRd0ME<^0080ME<^00<0Le4/079@:`1`CRT00P1eDS8207AA<@<0Le0`0P1bCbl01`1aCRh0Kd`/06i;
:`1^Bb/0Kd`/075>;P1bCbl00P1YC2`00`1XBb/0IdXZ06I9:@0206E8:00706A79`1XCRd0Idd/06I<
:`1UBbX0HdTX06989`0206579P80J4LX00@0IdHW06I59P1VABH0ID@U0P1T@b@00`1TBBh0HTL/05i3
:00205]09@0305e29`1PABX0HTL/0080GDDY0P1LA2P405]39`0405Y2:01I@BL0EclU05Dm8`80E3`R
00<0ECdS05Hn901D?2801`1D?280201F?bd0ECh/05@m:`1C?2X0DS/Y054j:01@>BL0CcPV0P1?>2P0
101>=bL0CCHV04`e9@1:<b<204Tb8PP0BCLQ0P19>R<204Pi8P0704Lh8@16=b00ASLP04Df7`14=2D0
ACDV04Hf9`0204Lg:00304De9P13<b@0@C4R0080?c8R0P0n<B4403d`80<0@3<S0P0o<R8403ha8@80
>C<S0P0h<R8303La8@0903H`800c<2L0<RlV034^9@0_;2<0;BXQ02`Y800[:1l0:RLN0080;B/L0`0/
:Q/302/Y6PP0;2XK0`0[:1l202`Y80<0;BXQ0P0]9Qh202hW7`0402lX800`:B40<BXR034Z8P80<bdM
0P0d;Qh303D_7`0403H`800a:R80<BXR034Z8P80<2TQ0`0_:200100^:b80;BXQ02dZ8@0/:B0202/X
7`80:RLN200[:1l302HX7@809BLL0`0T9Q/00`0V9al09BHN02<T7002028S6`0302<T700U9Qh09RLO
00P08R4O00<0828O024S800R92400P0S9B800`0R92408B<P020R7`08020R7`P082<J200O8QT3028T
8@03024S800P8Ql07b4N00807b4N0P0P8Ql201lQ7P@07R0M00<07AlL01`N6`0L7Q/03P0L7Q/201lQ
7P80828O0`0Q8b000`0R92407b4N01hP7@0201hP7@807AlL2P0L7Q/:01/M70806Q`K100I6aX801XL
6`P051XH0`0G6AP[ooooo`00:_ooool20:5f@`040:1e@P2OM440WgA109ic@080WG8o00/0Y7U>0:Ai
C02SN4/0XWQ80:5gA@2PMd<0X7M109mf@02PMD80XGI30:9gA0020:=hA@030:9gA02QMT<0X7E20080
Y7520`2ULT<30:IcA00@0:=jAP2PMd<0WWE10:1g@`2TNdL0YGa80:=jAP2PMd<0Y7M=0:=gBP2QMDP0
X7A50:5eA02SN4D0YGY50:IkAP80Y7U60`2UNTL30:IkB080Z7e:00<0Yga90:IkB02UNTL00P2SN4D0
0`2RMd@0YGY70:EjA`060:EjA`T0ZGm=00<0Ygi:0:ImB@2UO4P00P2UO4P00`2WOTX0ZH1<0:Z1C@03
0:MnBP80Z7m;2`2YP4`0102WOTX0Z7m;0:QoB`2YP4`20:Z1C@80Zh9>0`2YPD@20:R0@`<0Ygm200@0
Z7e80:UnB@2YOTT0ZGi90P2ZOdX20:^0B`P0Zh5A0P2ZPDd20:^2CP040:b3C`2]Q500[HA@0:j5D@P0
[8=?0`2[PT`30:b3C@80[HA>00H0Zh9>0:b3C`2/Pdl0[XEA0:n6DP2`Qe<20;68E0P0[HA@202[QU82
0:Z6C0040:Z5CP2ZQE00ZXE@0:Z5D@80ZXAC0`2_QU030:j5C`80[HA>0P2]R5@0102/Qe<0ZhIB0:V4
D02XPdl20:N2CP80ZXEA0`2YQ5030:R3C`80ZX5=00H0ZH1<0:QoB`2VODT0YGa80:AkA`2SNTH20:5m
@`030:1kA02ONTD0WWU40080WGQ400d0WGM609afA@2KMc/0VgLk09Yf?02IMC/0V7<l09Mb?@2GLSh0
UW4m099^>P2DL3`0UW8n0080Ug<o00<0U70l099^>P2@K3P00P2BK3d00`2AJc`0T6Xk08mY>P0208iX
>@0:08eW>02?JCX0SVPi08]U=P29Hc@0R68c08US=02:I3D0RfDf08QR=@<0Qf4d0P26H3<208EO<P80
OU/a0P1mFS0307aI;`0407]H;P1gFRh0MeX^07MJ;P80MUT]0`1eF2`307=C:P80LU8Y0`1aDBP02@1]
Cb/0K50[06]?:P1XCRT0IThX06A>9`1RCbL0HDhV06]=:`0206Y<:P0306U;:@1XBRP0IdTW0080ITPV
00<0JD/Y06Y<:P1[CB/00P1]Cbd01P1[CB/0JT`Z06U;:@1XBR@0JT`V06e?:@80Ke4[01H0KU0Z06]=
9`1ZC2H0Jd`]06a=;P1]Cbd0Ke4]075C;@1bEBd0M5L_07AG;@1aDBP0LU8Y07AD:`1fERd0MeL^07IF
;@1dE2/0Le<Z07aG:P1kERT0NUDX0P1iE2L00`1jEBP0NeHY07aG:P0807MG;P0307QH;`1iFC00O5`c
00<0OUhe0100O5`c07]K<P1nFc<0OU/c07aI<@1jEbl0N5D]07MD;01eDRX0M54Y089O=@21GS@0Oe`b
07eJ<01lFBl0OEX`0P1oG3800`20GC<0MeL^07MG;P0607MG;P@0LUH^101cEbl01@1cE2P0M5DY07AE
:@1eERX0MUL[0080MeP/00@0N5T]07UI<P1gEc00MED^0P1cDb`00`1dE2d0MED^07MG<00206mC:`04
071D;01aEBd0LUH^079F;P80LeL_00P0LeH^075D;01_DRX0KU4Y06mB:P1aE2`0M5L_07II<@<0JE4[
00<0JU8/06]C;@1/E2h00P1/E2h00`1/D2P0KE4Y06mC:`02071D;00306iB:P1/D2P0JdlW0080K50[
00<0JdlZ06Y>:@1YCBP00P1XC2L00`1WBbH0IdXX06M::00606M::00506QA;`1VCbd0Hd`Z06199`1M
AR@00`1LAB<00`1NAbP0GdPY0619:P020619:P0305i7:01LABH0Fd@U00<0F4DU1@1IARH0101A@2H0
D3lU050o9@1@?bD204ln9080CSdS0P1C?bL00`1A?bL0D40W04m19`0204e19`0304a29`17>b40Ac/Q
00H0Ac/Q00P0CcdW04`l9@1:>R<0AcPQ04@h8013>B00@S/Q04<l8P80@CTT0P10>2<303lg8P0303hf
8@0o=b80?cLR00L0?cLR00H0@3/W03lj9P0n>BD0?CPT03`g8`0j=B4203Td80P0>cHR200f<Ad203Pa
7P0303Lb7P0e<ah0=3<N0080<cDO00T0<SHO03Xh8`0i=b80>3HQ03Le800f=1l0=C<N03@b7@0c<A`0
200c<1d0200`;Ah0<BhO03<`8@0e<R<0=34R038_800_;1d0;BXK200`<B400`0_<A`0<38M038d7`02
03<e8003038d7`0`<Qd0;c4L0080<C<N00@0<38M02la700];aX0;2hI0P0[;AP8030b7@P0;c4L00H0
:b`N02`]7`0^;b40<34S034b900`<B<202l`8P0303@a7P0c<1d0<c0M0080<c0M0`0b;a`803@_6`<0
=C0L0P0f<Ad303Lb7P80>3HO0P0g=Ah203Hd7@80=C<L200h=Ql00`0m>2@0>cHR03Td800203Lb7P03
03Td800k=R80?CPT0080>3HQ0`0g=B0203Hd7`80=C<N200d<Qd303<a7080=38M0`0e<ah01P0c;QX0
<BlJ034_6P0`;aX0;c4K02hb6`80;C8K0P0^<Ah202lb7`<0<3<P00<0<C@Q03@a7P0d<Ah00P0e<Ql3
03Hc800;03Ld8@0m>B00?SPP03li7`11>Qh0A3/N04Hk7@18>Qd0BC`L04Hh7P1:?2800P1=?bD204/m
8`0>04m19`1BA2X0D3`S054m901C?b@0ED8T05I38`1F@b80ED8Q05E37`1N@B40H4<S06=69P1UB2P2
06M::P0B06I9:@1UB2P0HdhQ06A?8P1VDB@0JE@W06aG:P1_FRd0LUd`07=N<@1aDR<0MEHW07YK;01o
H340PF8c07mP<@1lGBh0NU//0P21Hc400`22I380PfDc08AV=00208EW=@0:08IX=P2:J3P0RfTi08aZ
>P2=Jc/0Sfdm091^?P2AKcl0TW1008m^>@80T6lj00<0TG0k099a?02CLSd00P2DLch0102CLTD0U7=6
09IeB02HMdX209UhB`80V7M:0180VgU909YhB02IMdL0VGM709]iB@2MNd/0Wge=0:5oC`2QODd0XWi>
0:=oC`2TP500YX9B0:R4E02YQED0ZXIF0:R6EP2WQED30:F3D`030:N5E@2YQeL0ZXQH00H0ZhUK0`2Z
R5X0102]Red0[XaN0:j<GP2^S5h20:n=G`80/8iP0P2aSV@20;:?I@@0/i1V00@0/XmU0;>@IP2cT6H0
/i1V0P2dTFL20;FBJ080]Y=Y0`2eTVP30;BAI`P0]iAZ00<0/i5S0;BBI02fU6H00P2gUFL00`2fU6H0
]99T0;>AH`080;FBJ0030;REJ`2gU6X0]I9X0080]95W00<0]I9X0;NDJP2hUF/0202gU6X80;JCJ`P0
/iI^202fTfT80;BAI`80]YAV0`2eTfD30;BBI0@0/i5S102dTV@20;BCH0030;>AH@2cTF<0/Y1S0080
/HiT00<0/8eU0;2AHP2`TF801P2`TF802P2dTV@0]I=U0;JDIP2fU6H0]I=U0;>AH`2aSf40[heO0;2>
H02_SEl20:j<GP80[H]M00/0[XaN0:n=G`2`SV00ZhQN0:b9G`2]RV00[haR0;:?I@2dTFL0]I9X0;JC
J@080;6>I080/HmQ0`2`SV030:n=G`P0/HeM202_SEl30:n<HPD0/8eS00P0/XmU0;6>I02`SF<0[haR
0:j;H@2]RV00[8UO0:^8GPP0/8eS00P0[HYP0:n<HP2aSV@0/XmU0;6>I02_S680[8UO0:Z7G@P0[HYP
102[R6040:b9H@060:j;H@2]RV00[HYP0:^8GP2ZQed0ZHIL0P2XQE/20:N7GP80Z8QO00@0ZHUP0:Z:
H@2ZRV40Zh]R202/REl20:j;H@040:f:H02/REl0[8UO0:^8GP80ZXMM00H0[HYR0:f:H02]RV00[8YM
0:b:G02[RET20:^:E`040:V4E`2XPeH0Z8=F0:R3EP80Yh9E0P2VPE@00`2UPeD0YXAF0:N5E`020:R6
F0030:N5E`2VQ5H0YH=E00T0Z8EK202WQ5X00`2TOe80YX5D0:R3EP020:V4E`030:N2E@2TOe80XWe@
00P0Y7mB0P2SOU420:9mD0040:5lC`2PNdh0X7]>09mjC@@0WWY80P2ONdT20:1lBP80X7a<1P2ONd/8
09]fB@80U6m20P2EL4<309IaA00309MbA@2DKd80U6m20080UG130`2FLD@00`2GLTD0TW12099`@P02
095_@@07091^@02?KCl0Sfdo08i/?P2CKT40TVe0091[?P0208mZ?@03091[?P2BKD00Tfi10080TF`o
0P2@Jch408mZ?@0809A_@P2BKD00T6/n08iY?02=J3/0SVTl08mZ?@2@Jch808eY>@0408aP<`2=HC@0
SF4d08eQ=0@0SV8e0P29ICD308QT=0<0Qf<c00/0R6@d08MS<`25HC40Pel_08AP<026HS80RFDe08]W
=`22GC00Q5lb08MR=@0208UT=`0308IQ=023GS40P5/^00T0QEhc0`2;HSH208YQ=@<0RF0d0P20FS<3
07mI<P<0OUPa201lES40201dCRT0MDlZ07I@:`1hDRd0NE<^07]E<01lES40OELb0P1hES0207ME;`@0
MU@^00H0M58/07=A:`1cDB/0LU0Z075?:@1`CRP306m=9`07071>:01aCbT0LDlY075?:@1_CBL0KT`V
06a:9002075;9`<0L4XV0`1_BBD206i<9`0406a:9@1ZB2<0J4HQ06I47`80I48M0P1SA2L206A5:008
06E6:@1VAbX0ITLZ06M8:`1WB2`0ITL[06A5:@1R@bL206529P80HT<W00H0IdPY06I7:01UARL0I4DV
06=49@1R@b@206528`030651:P1O?bP0G3`U0080FSXS00H0Fc/T05dm9P1O?bP0FcdU05Xl901H>R82
05Hh800605Pj8P1J?2@0FcdU05Tk8`1H>R80ESPP0P1E=al00`1F>200F3XR05Tk8`0205Dg6`80ESPL
00@0EcTM05Pj7P1I>al0FC/O0`1A=ah3058h7`80DcTP00/0CcLO05<k8`1D?RH0DCdT04Th7P16=Q`0
BCTO04`n8`15=Ah0AcLP04Ti8P0204/k9080BSXS00<0B3PQ04Lg8015>B<00P15>B<204@h8P<0@cLQ
0P11<Qd00`10<A`0?c0K03h_6P0203d^6@0303`]6010<A`0@C8M0080@S<N00@0@34L03h_6P0k;1L0
>BXE0P0m;Q/403`]6P80>b`I00<0?BdM03h^7P10<2000P11<B401P10<200?RhN03d]7@0l;AP0?RlJ
03l`6`<0@C8M00H0@34L03l`6`0n;aX0@34L048c7P14=B0204Df8@0504<d7`12<ah0?RlL03d^6`0k
;1T00P0j:aP00`0k;1T0?BhK03h_7002040b5`0703l`6@0n;aX0?BdM03/[7P0k:R00>RTQ048c7P02
044d8@0C03ld8P0j<B00=RlO038/7P0`:Q`0<2LN02hU700]91/0;2<J02dT6`0^9A`0<2LN038Y800f
;ad0=BhL038[6`0`:1/0;bLL02hU700202lV7`08030[9@0_:R@0;BPR02/V800Z9Al0:bHP02dX8P0^
:B<802XV7@@092@H100S8aL01P0/:Qh0:bTM02/Y7@0Z:1`0:BLK02PV6P809bDI0P0X91T0100W9AT0
9BDI02@V6@0T9QT202<W6@X0:2DL00<09b@K02HS6P0U8QT00`0T8AP00`0S81L08B0N024P7P06024P
7P04024Q5`0R8QP08R8H028R60@08b<I00H07A`G01hM600P7aX08B0K02<R7@0U91l202LV8@0802DX
8@0T9b008bHO028U7P0Q91d082<L01lR6`0N8AX401dR70D07R<M0`0M8Q`201`Q6`806b0J1P0G7QH2
01HM5@807b4L00@07R0K01dO6P0M7aX071hI0P0K7AP801XN7`<06QlI:oooool002[ooooo0P2QMT<2
0:1e@P0509md@@2NLd00WW=009ic@02RMd`00P2RMdX00`2RN4P0XGM50:5hA0020:5h@P030:1e@P2Q
MT<0XWM40080XgQ500<0XWM40:5f@`2PMD800P2RLT830:=c@`<0Y7A40100Y7]70:5hA02OMT80X7M3
0:=jAP2UO4P0XWU509mf@P2SMT`0XgM:0:5eB02QMDH0XGE40:=hA@2UNTD0YW]60P2TNDH30:EjA`<0
YW]80P2XODX01P2WO4T0YW]80:EjA`2TNDH0XgQ50:9gA0P0YGY72@2XOT`00`2WOTX0YWe90:ElB002
0:ElB0030:MnBP2YP4`0ZX5=00<0Ygi:0P2XOd/;0:V0C0030:MnBP2XOd/0Z7m;0080ZH1<0P2ZPDd0
102[PTh0ZH560:V1AP2YPDH20:R0A@<0Ygm400@0ZGi90:YoBP2ZOdX0ZWm:0P2[P4/20:b1C0P0Zh5A
0P2ZPDd20:^2CP80[8=?0P2]Q5080:b3C`<0Zh9<0`2/Pdd20:f4CP060:^2CP2/Pdl0[HA@0:j5D@2_
QU80/8MC0P2aR5@80:f4D0P0ZhIB0P2ZQT`0102ZQDh0ZXE@0:Z5D02ZQE420:Z4D`<0[hI@0`2^QDl2
0:f4CP80[8MC0P2[QU80102ZQE40ZHA@0:R3C`2XPdl30:Z5D@80ZHA@0`2XPdl20:V0C080Z7m;00T0
Ygi:0:ImB@2UO4P0YGa80:9nA02QOD<0XGa50:1kAP2ONTD00P2NNDD209egAP0909ah?02KMc/0VgLm
09Ye?P2IM3l0V7<o09Mb?P2GLD00U70l0080UG4m00H0UW8n09Ea?@2DL3`0Tflk099^>P2CKCh2099/
?@03095[?02@JS/0SfTj0080SVPi00@0T6Xk08iX>@2<ISL0RV@e0P29Hc@0102:I3D0RfDf08MQ=027
HC@208IP<`<0QElb00@0Q5ha07iK<@1nFc40OU/a0P1mFS0307aI;`<0NEX^0`1hFBd207MH;0<0Le<Z
0P1bDRT3075A:00806i@;01]Cb/0K50[06U?:P1WCbT0IDlX06A>9`1RCbL206]=:`0406Y<:P1YBbT0
J4XX06M99`80ITPV00<0JD/Y06Y<:P1[CB/00P1/CR`01P1[CB/0JT`Z06U;:@1ZC2H0JddW06a>:080
KDlY00<0K4hX06]=9`1[CBL00P1/CBh04@1]Cbd0KU0/071B;01aE2`0LUD]079E:`1`D2T0LU8[07AD
;@1eEBh0MUH_07EE;P1dE2d0Le</07YH:`1iEbX0MeDX0080MU@W00<0MeDX07UG:P1jF2/02@1hF2l0
0`1iFC00Ne/b07eM=00207eM=00807aL<`1kFc80Oe`d07iK<`1mFS80NeP`07UF;P1hEBd207IC:`06
089O=@20GC<0OU/a07eJ<01lFBl0OEX`0P1nFc400`1oG380MeL^07MG;P0607MG;P@0LUH^101cEbl2
07AE:@<0MEHZ0`1fEb/0201hF340MeL`07EE;P1dE2d0Le</07AD;@1eEBh0MUH_0`1`E2`2075E;@<0
LUH^0P1`Db/206mB:P04071C:`1aE2`0LUD]07=F;P80JU0[0P1[DB`206aB;@80KE<^00P0K50X06eA
:@1_Db/0L5@/06mC:`1^DRX0K50X06]?9`80K50[00@0JdlZ06Y>:@1YCBP0JDdX0P1XC2L806M::005
06M@;P1UCR`0HT/Y05m89P1MAR@00P1KA2800`1LAB<0GTLX05m8:@030619:P0305i7:01LABH0Fd@U
0080F4DU1P1IARH205509P80D3lU0`1??R@01P1>?B<0DShV058n9P1@?RH0CclV04i09P80C40V00<0
Bd4V04Pl8P18?2801P18?280201??BL0C3`U04Xj8`17>240A3PP04<i8012>b40@c`R0P11>B@2040h
8`@0?cLR2@0n=R4203hi9@80?CPT00@0?3LS03/f8P0j=B40>SDQ200k=R8803Lb7P80>34N00<0=c8N
03Dc7P0e=1l00P0c=Al01`0b=Ql0>CLR03Tg8P0h=R40=cDP03Hd7`0e<ah00P0d<Qd803<`7@80<RlP
0`0c<2400`0b;b00<2dN02l/7@08030a8@0302la700`<Qd0<S@O0080<cDP00@0<S@O030b7@0_<A`0
<S@O0P0a<ah01@0`<Qd0;S0K02d_6P0];aX0;2hI00P0<38M200_<A`0100[;1`0;BhN02l`800`<B42
034b8P04030a8@0_<200=34N03@a7PH0<c0M2P0e<1`203Ha7@<0=c8N00<0>3<O03Pf7`0h=Ql00P0g
=Ah203Hd7@80=C<L200h=Ql00`0k=R80>SDQ03Td800303Td800303Xe8@0k=R80=cDP00@0=cDP0P0f
=1l203Dc7PP0=38M0`0c<A`203@b7@<0=C<N00H0<bhJ034_6P0a;aX0<C0K02la6`0^<Q/202db6`04
02h_7@0_<1h0;c0N02l`7P80<34O0P0a<R0303Db7`80=S<P0`0g=2402P0l>1l0?SPP03li7`10>Ad0
@cXM04Dj7018>Qd0B3/K04Hh7@1:?24204i09@80C3hS00h0Cd4V05=5:P1A?B@0DShS05A09@1F@bD0
Ed@T05M48`1FA200ED<O05m28P1QA2@0HdHV06I9:@<0IdXZ00d0ITTY06E@8`1VDB@0J5<V06YE:01]
F2/0KeX]075L;`1bGC00M5DV07IG:01jFb`0OEh_0080Of0a00@0OEh_07aM;P21Hc40PV@b0P23IC<0
1024IS@0QFLe08IX=P26J3H208]Y>@0408aZ>P2>K3`0Sfdm095_?`80TW100P2@KcX00`2AL3/0TW4l
09=b?@0209Ac?P0509Ed?`2CLTD0UGA709MfB@2IN4/00P2JND`0102IN4/0V7M:09]iB@2KNDT209Yh
B00D09]iB@2MNd/0X7i>0:5oC`2QODd0XWi>0:=oC`2UPE40YX9B0:R4E02YQED0ZXIF0:R6EP2WQED0
YXAD0:F3D`2VQ5@0YhEE0:V7E`2ZR5P90:^9F`@0[XaN0P2_SEl20;2>H080/HiT0P2bSfD30;>@IP03
0;BAI`2cT6H0/i1V0080/i1V0P2dTFL20;FBJ0<0]Y=Y0P2eTVP30;BAI`P0]iAZ00<0/i5S0;BBI02f
U6H00P2gUFL00`2fU6H0]99T0;>AH`080;FBJ0030;REJ`2gU6X0]I9X0080]95W00<0]I9X0;NDJP2h
UF/0202gU6X80;JCJ`P0]IE^202fTfT80;BAI`80]YAV0`2eTfD30;BBI0@0/i5S102dTV@20;BCH003
0;>AH@2cTF<0/Y1S0080/HiT00<0/HiV0;6BH`2aTV<01P2aTV<02P2dTV@0]I=U0;JDIP2fU6H0]I=U
0;>AH`2aSf40[heO0;6?H@2`SV020:j<GP80[H]M00T0[XaN0;2>H02aSf40[X]Q0:n<HP2`SF<0/HiT
0;:?I@2dTFL00P2eTVP80;6>I080/HmQ0`2`SV030:n=G`P0/HeM202_SEl80;2=H`060;:?I@2aSV@0
/8eS0:n<HP2^Rf40[HYP0P2/REl80;2=H`80[haR0P2`SF<0102_S680[X]Q0:f:H02/REl80:f:H0<0
[8UQ1@2]RV820:j;H@040:f:H02/REl0ZhQN0:Z7G@80ZHIL0`2XR5l00`2YRF00ZXYQ0:Z:H@020:^;
HPP0[8UO0P2^Rf420:f:H0050:b9G`2[R5h0ZhQN0:^8GP2]RV800P2]RV000`2/RUd0[8YL0:b:FP02
0:^:E`<0ZXEH0P2YQ5L30:R3EP030:J4EP2WQEL0ZHMI0080ZXQJ00<0ZHMI0:N5E`2VQ5H02@2YQU`8
0:R5F`80Z8=F0`2YQ5L00`2WPUD0YX5D0:F0D`0:0:F0D`80Y7mB00@0XgiA0:9mD02ROE00XWe@0`2P
O4X20:5mB`<0XWi<0P2TP5020:=oC`80XWi>0P2QODd809iiC0<0VgI90P2LMdX309ehB`<0VgI90P2L
MdX309ehB`80V7I80P2GMDL01`2FM4H0UG=509EcA@2ELdD0UW5409E`@`2CKT400P2BKD000`2CKT40
UG1309IaA00309MbA@80UW540`2EL4<00`2GLTD0UG1309=^@@03095/?`03099]@02CKT40Sf/k00L0
Sf/k202@ICP0102<J3P0RfLg08]W=`2;IcL208YV=P80RFDe00<0RfLg08YV=P29ICD00`28I3@01@29
ICD0RVHf08QS=P2:ICP0SFPk0080SVTl00<0S6Lj08QS=P26HC@02@2:HcP308aS=`80Rf8f0`2:HCD4
08EP=P80Q5le0P23GS@8081J=@80O5Ha00<0OELb07iH<`1oFC@00P20FSD01021FcH0OE/e07eK=@1m
FcD207aJ=0<0NeTc0P1jF3800`1iEc40N5H`07ME;`0207ID;P0907EC;@1dDR`0ME<]07ID;P1gEBl0
MU@^07EC;@1cDB/0LU0Z00@0MU0/0P1eCb/207A>:P0807=A;01bD2/0LDlZ071>:@1^C2L0KD/V06a:
9@1[BB@206]::`80K4//0P1]C2d206i=;P0406e;<01[BBh0JDL/06M5:P80IT@Y00<0IdDZ06Q6:`1[
BR/00P1ZBBX00`1XAbP0IdHW06I59P0206E49@0306E3:P1T@RT0Hd4X00<0HClV0P1R@2L00`1P@RP0
Gd4W05i09P0205do9@0605i09P1O@BL0H48X0612:01O@BL0GClU0P1L?R@00`1M?bD0Gd4W0612:003
05do8`<0GT0T0P1O@BD605Tn8`80F3dR00/0DcTR05Dm9@1H@2P0E3hV04hj8@1:>Al0C3`R04lo9@1:
>200BcTQ04dk8`0204hl9080CC/S00<0BcTQ04Xh801:>b@00`19>R<204Pi8P80AcPQ00H0B3PQ04Lg
8017=b00ASHO04De7P14=1d204<c7003048b6`13<a`0A3@M0080A3@M00<0@S8K03l_600n;QL01013
<R04048a7`03044`7P12<Al0@c8P0080A3<Q00X0@c8P048a7`11<1h0@C4J048b6`14=1d0ACDN04Hf
7`15=Ah0A3@M0P13<a`02P14=1d0ASHO04Lg8018>240AcLP04De7P14=1d0AC@R04<b8012<Al2044`
7P03048a7`13<R00AC@R0080ASHL00@0ACDL04@c7`13<R00@S0R0P11;b<204@e8009048e8P10=B<0
?3@Q03Pa7`0e;Qh0<R`L03H/800e:al0=2XN0080<bTM00h0=B/O03L]8@0h;R80>30M03L^7@0e;1/0
<bXK038X700b:1h0<bTP03@Z8@0d;BD0<b`T034Z8P<0;bPP00<0<BXR038[8`0^9al01`0^9al602/Y
7080:RPK0`0]:Ad302`X7080:bLK0P0]9a/01P0[9a/0:RHJ02TW6P0V9aT09BLI02@V60X0:bLN00<0
:RHM02TU700X91/00`0W8aX00`0V8QT08b8N02<R7P0602<R7P<09BDK1@0T91X2020P6007028R6P0S
8a/09BDM02LW7`0X:200:BTQ02LX800202HW7`0502DV7P0S91`08R<K028S6`0Q8QX01P0P8a`2024T
7@<082<L0P0O8Q/301hQ6P@072<K100K8QX201lQ70807R0K00@07AlJ01`N6@0L7QT071hI200J7Qd3
01XO6B_ooooo000Zooooo`040:5f@`2PMD80X7E20:1e@P<0WgA100L0WW=00:1eBP2PMDP0XGI90:5g
A`2QMdD0XWU50080XWU300<0X7E20:5f@`2RMd@00P2SN4D00`2RMd@0XGI30:1e@P020:9b@P<0Xg=3
0`2TM4@0102VODT0XWU509mf@P2PMd<20:=jAP030:1g@`2LLcl0XgI<0080XWI900D0XGE60:9fA@2S
N4D0Y7U40:EjA@020:AiAP<0YGY70`2VNdP01P2XODX0Yga90:MlB@2VNdP0YGY70:AiAP80XgQ5202V
NdP90:IlBP030:MnBP2VODT0YGa80080YGa800<0Ygi:0:V0C02ZPDd00`2WOTX20:QoB`/0ZH1<102X
Od/20:V0C080ZX5=0`2YPDH20:R0A@<0Ygm400@0ZWm:0:^0B`2[P4/0Zh1;0P2/PD`20:f2C@P0Zh5?
0P2ZPDd30:^2CP/0[8=?0`2[PT`30:b3C@80[HA>0P2/Pdl00`2]Q500[XEA0:n6DP020;27D`030;68
E02]Q500[HA@00H0[HA@202[QU820:Z6C0040:Z5CP2ZQE00ZXE@0:Z5D@80ZXAC0`2_QU030:j5C`80
[HA>1@2[QU830:Z5D@040:^6DP2ZQE40ZXEA0:Z5D@80ZHA@0P2XPdl80:QoB`80XWi400<0XGa50:1k
AP2ONTD00P2NNDD0202NN4L0WGM609ei?`2LN3h0W7M009]f@@2JMD00VGA00P2HLT401@2GLcl0UW8n
09Ea?@2DL3`0Tflk0080U70l00H0UG4m09=]?P2CKCh0TV`m095[?02@JS/208mY>P0508iX>@2@JS/0
SVPi08eW>02;ICH00`2:I3D0102;ICH0QV0c08IP<`26H3<208EO<P<0Q5ha0`1oG38207iK<@<0OEX`
0P1jFbl207UJ;P<0N5T]00@0MeP/07AD:`1dE2/0M5@[0P1cDbX3079B:@80L4l/00H0KDl[06]?:P1X
CRT0IThX06E?:01TCRL206]=:`0306Y<:P1YBbT0J4XX0080IdTW00@0ITPV06Q::01YBbT0Jdd[0P1/
CR`01@1[CB/0JD/Y06Q::01/CRX0JddY00@0JT`X00L0JddY06a>:P1]CRl0KDh_06e?;@1^D2`0KU0Z
0080Ke8Z00@0L5<Y071@:@1aDBX0LU8[0`1dE2d207=C;00307UF;01hEB/0MU<Y0080ME8X00<0MU<Y
07QE:`1iER`0201iFC001P1hF2l0NET`07YJ<@1kFc80O5`c07]K<P80NUXa00d0Oe`d07iK<`1mFS80
O5Ta07]H<01jEbl0NEH^07QE;@20GC<0Oe`b07iK<@1mFS00O5T_00<0OEX`00<0OU/a07MG;P1gEbh0
1P1gEbh407AG;`@0LeH^0P1fERd307EE;0<0M5@[00D0MeL`07IF;`1eEBh0M5@]07=C;00207AD;@03
07EE;P1bERh0LED]0080LED]101`E2`00`1]D2P0KU4Y06mB:P03071C:`80Ke8Z00@0K50[06eA;01]
DB`0KE4/0`1^DRd0101_Dbh0K50X06eA:@1^DRX206mC:`0406iB:P1]DBT0K50X06eA;080K50[00<0
JdlZ06Y>:@1YCBP00P1XC2L806Q;:@0506E>;01SC2X0H4TW05i79@1LAB<00P1KA2800`1LAB<0GTLX
05m8:@030619:P0305i7:01LABH0Fd@U00P0FDHV00@0DT4W05509P1A@2H0DD0V0P1@?bD204ln9080
DCdU00<0CcdU04hn9@1=?bD00P1;?bD00`1:@2D0BShT04Xn900604Xn900804lm9`1=?BH0BSXS04Lh
8@15>B40A3XQ048k8@13?283044i9080@3PS0`0o=b8903de800303dh900l=b<0?3LS00D0?3LS200k
=R8803Td8080>C8O00<0>3<O03Hd7`0e=1l00P0c=Al01P0b=Ql0>CLR03Pf8@0h=R40=cDP03Hd7`80
=C<N00<0=38M03<`7@0c<1d01P0c<1d00`0e<R<0=34R038_8003034^7`80<RlP200`<B42030b7@@0
<S@O0P0`<Qd01@0c=B00<S@O038d7`0a<ah0<38M0080;c4L00<0;S0K030b7@0`<Qd03P0`<Qd0200]
;Qh0;RlO030a8@0a<R80<S<S034b8P0`<B40;c0P200d<Ah803Lb7P<0=S4M0P0g<Qh303Pc7`80>3HO
0P0g=Ah203Hd7@80=C<L200h=Ql203Td800403Xe8@0k=R80>cHR03Xe8@80>C@P100g=B0203Hd7`<0
=C<N200d<Qd303<a7080=38M0`0e<ah01P0d;a/0<S0K038`6`0a<1/0;c4K02hb6`80;C8K0`0^<1/2
02la70<0<38M0`0f=1l203Le80<0>3HQ00X0?3PO03dg7`0n>1h0@3TM04<j7@15>Q`0AcTL04Pk6`18
>1h0C3`R0P1@@2H204hn900?05519`1EAB/0DShS05A09@1F@bD0F4DU05U69@1IAb<0F4HR05M57`1Q
A280HdHT06E89P1WBRP0J4/Y00<0JD`Z00P0JU<W06]D:01/EBT0KEHZ06mH;01`FBd0LEX^079K;`80
NEX[00H0NU//07aM;P1mGRl0OUl`07mP<@20HC8208=U<`80Q6Hd00`0QFLe08IX=P27JCL0QfTg08]Y
>@2<JSX0SF/k08i/?02@KSh0TFlo099`@02CLD42095`>`03099a?02CLSd0U7<n0080UG@o00D0UWE0
09EcA@2FM4H0V7I809YhBP0209]iB`80VWQ:00h0WG];09ajBP2KNDT0VgU909ajBP2NO4`0X7i>0::0
D02ROTh0Xgm?0:B0D02UPE40Yh=C0:R4E080ZHEE00P0Z8IF0:N5E@2VQ5@0YXAD0:N5E@2XQUH0ZHMG
0:Z8F0T0ZhUK0`2^S5h20:n=G`<0/8iP0`2bSfD20;>@IP<0]95W0`2cT6H20;BAI`<0]I9X00@0]iAZ
0;JCJ@2fTfT0]Y=Y0P2eTVP20;BAI`P0]iAZ00<0]99T0;FCI@2fU6H00P2gUFL00`2fU6H0]I=U0;BB
I0080;FBJ0030;REJ`2gU6X0]I9X0080]95W00<0]I9X0;NDJP2hUF/0202gU6X80;NDK0P0]IE/202f
TfT80;BAI`80]YAV0`2eTfD70;BBI0@0/i5S0P2cTUl01P2cTF40/Y1R0;:@H`2bSfD0/HiT0;6>IPP0
/Y=T102eTfD01P2dTV@0/i5S0;6?H@2`SV00/HmQ0;2>H080[heO0P2^S5h00`2_SEl0/8iP0;6?H@02
0;:?I@80/i1V0P2dTFL20;FBJ0P0/XmU0P2aSf430;2>H0<0[heO202aS5l80:n=G`P0/8eS0P2aSV@2
0;2=H`040:n<HP2^Rf40[HYP0:f:H0P0/8eS00<0/HiT0;2=H`2_S6800`2]RV000`2^Rf40[haR0:j;
H@070:j;H@D0[haT0`2^Rf<01P2_S680[X]Q0:j;H@2]RV00[8UO0:^8GP80ZXMM0`2YRF030:Z:H@80
Zh]R202]RV00102^Rf40[HYP0:f:H02]RV030:b9G`0:0:^8GP2^Rf<0[X]Q0:f:H02]Reh0[8YL0:b:
FP2/ReP0ZhYG0:f8F`<0[8MJ0P2[QUT20:Z5F0030:R6F02YQeT0ZhUK0080[8YL00<0ZhUK0:V7F@2X
QUP02@2ZQed80:^8GP030:f8F`2/QeX0ZXEH00<0ZHAG0P2ZQEP:0:R3EP<0Yh9E0`2VPE@30:B0D080
YH5A0`2VPU80202[QeL0ZXIF0:Z6EP2XQ5@0Yh=C0:J2DP2UPE40Y81@202ROE020:=nD@80Y7mB0`2U
P5<00`2VPE@0XgiA0:=nD@020:AoDP<0YH1C00<0YX5D09mmC`2OODl00`2NO4h309ekC@0309]fB@2J
MDP0VGA70080V7=600<0VGA709YeB02KMTT00`2ONTd209iiC0<0WGQ;00<0VgI909YeB02HLdH00`2G
LTD209QcAPP0U7100P2HKD00102GK3l0UV/n09EZ?@2EJSd209AY?0<0T6`l0P2?Jc/308iZ>P80Sf/k
0P2@K3`01`2?Jc/0SFTi08aX>02:ISH0SfXm095/?`2CKT400P2DKd800`2BKD00SfXm08eX>`09091Z
?@80SFLj0`2<IST308]U>0<0S6Lm0P2;IS`308YU>`P0QV0i2025GcP208AQ>@<0Pf0h0`22GcL208=P
>003089O=`21GSH0P5de0080Oe`d00<0OU/c07aI<@1mFS800`1nFc<00`1lFC40NeP`07UF;P0307eG
<P80O5Ha0`1kEC0207QE;`80Me@^0`1fDbd00`1eDR`0LU4`07=B<@0207=B<@<0M5<b00D0ME@c079A
<P1aD340Kdh_06e<;@0206a;;080KD`]0P1^CB`0101]C2/0K4/Z06a;:P1[BRT206Y9:00;06Q6:`1Y
Ab`0JTP]06Y8;@1YAb`0J4H[06M5:P1VA2T0J4T]06M8;01VAb/00P1UARX01P1VAb/0IdP/06Q9;@1Y
BRh0J4T]06M8;080ITL[00<0IdP/06Q9;@1YBRh0101XBBX406M8:@80I4HZ00@0HdDY0694:01RA2P0
HD<W0P1P@RH02@1J?b@0G44V05a29`1J@RH0ED0S058o8@1D@B<0E4<U05<o9P0305A09`0505<o9P1B
?RD0DShU050l8`1?>b800P1@?RH204lm9@80CS`T0P1=>b<01P1@?RH0CcdU04lm9@1>?2@0CC/S04`j
8P80BcTQ0P17=Ad01P18=Qh0BCLO04Tg7`18=Qh0AcDM04Hd70P0BSPR00<0AcDO04Pf8019=b400P1:
>2801P19=b40B3HP04Le7`17=Ad0B3HN04Xh80<0C3XR00d0BcTQ04Xh801:>200BSPP04/i8@1<>R80
BcTQ04Xh8019=al0B3HN04`j901;>B<0BSPR0080BCLQ00<0BSPR04/i8`1<>R@00P1=?2801`1<>R80
BcTS04Xh901:=bH0BCHU04Tf9`19=al00P18>2401`17>2<0@cHS03ld8P0j<B00>2lN03hb8P0m<B40
0P0l<200400m<B40?S8R03lc8`10=2@0?34M03/`700i;Q`0>2`L03P/7P0i;B40>RhR03/^9@0i;bD0
>2hT03L]8`0f;28203D[8@0303H/8P0g;B<0=2XP00L0=2XP200d;R04034[7@<0<R`N00T0<bdO03L[
7`0e:al0=2XN034Y700_:A/0;2TJ02XX6@0Y9aP0200`:Qh01P0a:al0<2XN030Z7P0_:Ad0;RPL02dW
6`<0;2HJ200Z9Al202dY7@80;2PL00T0:bLK02XV6P0Y9AT0:BDI02LS6P0X91/0:BDL02XV7@0[9ah0
0P0]:B001P0^:R40:RXP02XZ800Y:Al0:2PN02LW7@809RHL00<09BDK02<T700S91`0200S91`2028S
6`<08B8J00<0824I02DX7`0T9ah00P0T9ah202<V7@808RDL0`0P8A/301lP6P807QlI200M7a`301`O
62_ooooo000Zooooo`P0X7E200H0WW=809mdA`2OM4L0X7I60:5gA@2RNDD20:=jA0030:1e@P2QMT<0
XWM40080XgQ500<0XWM40:5f@`2PMD800P2QLd830:9d@`<0XgE400@0Ygi:0:=jAP2PMd<0X7M30P2R
NDD00`2NMD40Vg8n0:9eB`020:9fB@030:9fA`2SMdH0XgQ50080Y7U40P2TNDH30:EjA`<0YW]80P2W
O4T20:IkB0040:EjA`2TNDH0Y7U60:AiAPP0YW]82@2UNdT00`2WOTX0YWe90:ElB0020:ElB0030:Mn
BP2YP4`0ZX5=00<0Ygi:0P2XOd/30:V0C0h0Z7m;0P2YP4`30:V0B080Z7m70`2WOTH20:^0B`80[85<
102]PTd80:^2CP80ZX5=1P2[PTh80:b3C`<0Zh9<0`2/Pdd20:f4CP<0[HA@00<0[XEA0:n6DP2_QU80
0P2`Qe<80:f4D0P0ZhIB0P2ZQT`0102ZQDh0ZXE@0:Z5D02ZQE420:Z4D`<0[hI@0`2^QDl20:f4CP<0
ZXEA0P2[QU830:b7D`80ZhIB0`2ZQE430:V4D0<0Z7m;0`2YP4`20:Z1C@80Xgm500<0XWe60:5lA`2P
NdH00P2ONTH0202ONDP0WWQ709ij@02NND80WGQ309ag@P2KMT80VWA30P2ILd@00`2JMT80V7A009Ea
?@0209=_>`0309A`?02FLSh0V7A00080U6ho00<0Tfdn099/?@2AJc`00P2@JS/01P2?JCX0T6Xk08mY
>P2>J3T0SFLh08aV=`<0RfDf0P26H3<208EO<P@0Q5ha0P21GS@2081M<`<0Oe`b00@0OU/a07]J;`1k
FRl0NeX_0P1jFBh307UH;@80MED/0`1dE2/307=C:P09079@;@1aD2d0L4l/06e?:`1[CbX0J4hY06M?
:@1VCRP0K4h/0080Jdd[00<0JT`Z06U;:@1XBRP00P1WBBL00`1XBRP0JD/Y06Y<:P0206a>;00606Y<
:P1YBbT0J4XX06i@;P1/CR`0JD/Y0P1WBBL00`1XBRP0Jdd[06a>;00206e>;`0306e?;@1]Cb/0KDlY
0080KE0X00<0KE0V071@:P1`D2X00P1aDB/4079B;00307MF:`1eE2T0M5<X0080Le8W00<0M5<X07ED
:@1gER/0201iFC0207QH;`H0NET`0P1nFc<0101mFS80O5Ta07aI<@1kF30207YG;`0407mL<P1nFc40
OEX`07eJ<0D0O5T_201gEbh407IF;`@0MED^00D0MeL`07IF;`1fERl0MED^07AD;@0207=C;004079B
:`1fERl0MUH_07EE;PD0M5@]00H0LeL_079F;P1bERh0LED]071D;01_Db/206iB:P0306]>9P1/CbL0
Ke8Z0080LE@/00<0Ke8Z06e@:01[CRH0101]DB`406iB;@0306a@:01]DBT0KE4Y00D0KU8Z0P1]DB`0
0`1/D2/0JdlZ06Y>:@0206U=:00306Q<9`1XBbT0J4/Y00H0J4/Y00@0Hd`Z069;:@1PBBL0GDHT0`1L
AB<00`1MAR@0GTLX05m8:@030619:P0405i7:01LABH0Fd@U05Y79`@0FDHV0`1HABD405919`80DD0V
0P1@?bD204lk8`0304dk8`1<?2<0BcdS0080BCdS00<0B3hS04/o9@1;?bD01P1;?bD0201??BL0CCdV
04/k9018>B80ACTQ04@j8@13?280A3dS0P12>RD2044i9080@3PS0P0o=b8903de8080>cHR0`0l=b<3
03dh9100>cHR0P0j<b000`0i=200=S@O03Dd7`0203<e7`03034e7P0h=R40>3HQ0080=cDP0P0f=1l2
03Dc7PP0=34N00P0=c@U03Db8`0b;b00<2dN02l/7@0a;Ql0<c0Q03@a8PP0<34Q200a<ah203<e8080
<S@O0P0a<ah2030b7A00<C<N00<0;RlM02l`7P0a<R000P0b<b400`0a<R00<34O02l`7P0303@a7P@0
=C8O00<0=S<P03Td800i=2001P0i=20303Lb7P80>3<O0`0i=20203Pf7`80=cDN0P0f=1d203Dc70P0
>3HO00<0=c8N03Td800k=R800P0m>2@00`0k=R80>C@P03Lb7P0303Le8080=S@O0P0e<ah:03@b7@<0
<c4L0P0d<Qd303Dc7P0603D`700c<A`0<c4L038a700_<A/0;S8K0P0]<Q/4030_6P80<C0K0P0b<A`2
03Le7P80>3HO100i=b002P0l>1l0?SPP03hh7P10>Ad0@cXM04Dj7018>Qd0B3/K04/j7P1??R820591
9@80D3lS00l0Dd8V05M6:P1E@R@0ET<U05Q59@1JAbH0FdTU05]98`1JB280FDLO06A88`1UBB@0Id/V
06Q<9`1ZCRT00P1[CbX00`1/D2/0KeL[06mG:`02071H;00<075I;@1bFRh0LUX^07=K;`1mGRl0O5d^
07]L;@1jFb`0O5d^07iO<021HS<0Pf@e0P24IS@00`25IcD0QVPf08MY=`0208QZ>00:08U[>@2<JSX0
SF/k08i/?02?KCd0TFlo099`@02CLD40U792099a?080Tg8m00<0U7<n09Ed?`2FMD000P2GMT40102H
M4@0VGE509]gA`2MNDT209ijBP80WGU900<0Wge=09ilC02MNd/00P2MNd/02@2OODd0XGm?0::0D02S
Odl0Y81@0:F1D@2VPU80Yh=C0:R4E0020:V5E@@0YhEE00@0Z8IF0:V7E`2YQeL0ZXQH102[RE/40:b:
G0030:f;G@2^S5h0[XaN0080[heO0P2`SV020;6?H@80/XmU0`2cT6H30;BAI`80/i1V0P2dTFL20;FB
J080]Y=Y0P2gU6X30;JCJ@<0]I9X202gU6X00`2eTfD0]YAV0;JDIP040;JDIP030;FCI@2fTfT0]Y=Y
00H0]Y=Y00<0^9E[0;NDJP2eTVP00P2dTFL00`2eTVP0]iAZ0;REJ`080;NDJPP0]iA/202fUFX80;JC
J@P0]I9X0P2fU6H30;FCI@L0]99T102cTF<20;>BG`030;:@H02bT680/Y1S0080/XmU00<0/XmW0;>D
I@2cU6D01P2cU6D30;FCI@030;BBI02cTF<0/Y1R0080/HmQ00@0/Y1R0;6?H@2`SV00/8iP0P2_SEl0
0`2`SV00/HmQ0;:@HP020;JCJ@D0]I9X00<0]95W0;:?I@2bSfD01P2bSfD20;6?H@<0/8iP0`2_SEl8
0;:=H@P0/8iP00<0/XmU0;6>I02aSV@00P2aSV@30;2=H`80/HiT0P2`SF<20:n<HP80[X]Q202`SF<0
202bSfD0/8eS0:f:H02/REl0ZhQN0:f:H02_S680/HiT202^Rf430;6>IP<0/8eU0P2_S6@30:n<HP03
0:j;H@2]RV00[HYP0080[8UO0P2ZRV460:^;HQ00[HYP00H0[X]S0:j;H@2^Rf40[H]N0:f;G@2/RUX2
0:b;F0<0[hYM0P2^RE`30:f8F`030:Z8FP2[RE/0[H]M0080[XaN00<0[H]M0:^9F`2ZR5X02@2[R5h8
0:f:H0080;6<G`2_RUd0[8MJ0:Z5F02YQ5L0ZhII0:f8F`2^RE`=0:^6F@<0ZXEH0`2XPeH20:V4E`<0
ZXEH00H0/HeM0;2<G02_Re/0[HUI0:^7E`2ZQUH20:R4E0P0YX5D00@0Yh9E0:R3EP2XPeH0Z8=F0P2Y
Q5L20:Z5F0040:N2E@2XPeH0Z8=F0:R3EP80ZHAG0P2ZQEP80::0DP030:5lC`2PNdh0WgY=0080WWU<
00@0WgY=0:1kCP2QO4l0Y7mB0`2SOU420:9mD080XGa?0P2ONTd609iiC0P0VGE50P2OMTP01`2NMDL0
W7=509]bA02JLD<0VG1209Q_@@2GLd<00`2FLT8209Ea@@80U7100100UG5109Ib@P2GLd<0V7A409Ib
@P2CKcl0T6`l08iZ>P2EL4<0UW5409MbA@2HLdH0Ug9509E`@`2BKD00TF`o2@2DKSl3091[?P80SfXm
0`2>JC`3091[?`80SfXn0`2>JCd808YU>`<0RfHl00<0RVDk08UT>P29I3X00P28HcT308UT>P80R6<i
0`27HSP208YU>`0808UT>P28HcT0Qf8h08MR>026HCL0QF0f089M<`23GS@308AO=@03089M<`21G380
OeX`00<0PE/d0P20FS<307mI<P0307aF;`1mEc00OEL`00<0OEL`0P1nF3400`1hES40NELb07UG<P05
07UG<P0407YG=`1hECD0MU<c07AA<@80Le0`00@0M54a07EB<P1dDRl0M58_0P1cDBh01`1bD2d0LDl/
075?;01aCb`0KT/]071=;`1bCc400P1cD3800`1aCS00KT/]06a9:`0206i=;P@0KD`]0P1^CBh2071?
<0@0Kdh_0P1`Cc001@1bDC00LE0_075@;`1`Cbh0Kdh]0080KTd/0140KD`[06Y=;@1ZCBd0JD`/06Q;
:`1VBBT0IDPX06A79`1SARH0I4DX06E6:@1TAbT0HDHX05m69`1MARH0FdLV05a89`0205i6:P0305e5
:@1LA2P0Fd<W0080FD4U00<0F40T05Lo8`1J@RP00P1J@RP205U19`<0F40V0P1G@RL00`1F@BH0ED0U
05@o900205<n8`04058m8P1?>Ql0CcXO050k80D0DC`Q0P1@>R83054k8`<0DS`T00<0DC/S058l901C
?BD00P1D?RH02`1C?BD0DS`T054k8`1A?240DSdR05@o901E@2D0ET4V05E09@1D?b@0DchS00<0E3lT
00P0DchS058m8P1A?240D3/P04lj7`1D?RH0DcdU054k8`80D3XR00<0DC/S05<m9@1D?RH00P1C?BD2
058l900<054k901@>R<0D3XS050j8`1?>b00Cc/R04dl8P1=>b<0BSXS04Lh8`12=B80@C@Q1@14=B80
2`15=R<0ASLT04Hg9013=1d0@S<N044b7@10<Ah0@30P048b8`13<bH0ACDX0080?c<S00<0?S8R03da
8@0m<B400`0m<B4803X^80@0>blO100l<20203H]700403L^7@0h;ah0>C0O03T`7`80>S4P0P10<240
1P0l;al0>RhN03H]700c;1X0<R/I030[60P0=bhO00H0>2lP03L^7`0g;Ql0=RdN03D/7@0d:a`303<Z
6`P0<RXO00H0=c0P03H_7`0e;Qh0=2dM038[6`0a:QX2030Y6@80<2PM00@0<BTN038Z7`0b:Ql0<b/P
0P0d;242030/8080;b/O00D0;RXN02dY7@0]:Ad0;BTM02XX700402TW6`<0:2HJ0P0Y9a/202PV6P<0
9bDI00@09R@H02PZ7`0X:Ql09bTN0P0V:1d00`0U9a`092HK02@V6`0202<S6`H08R8J200P8A/301lP
62_ooooo000Zooooo`@0X7E2102QMT<02`2NLdP0WW=609mdA`2PMTH0XGM50:9iA@2RND<0XgY40:1e
@P2QMT<0XWM40080XgQ500<0XWM40:5f@`2PMD800P2OLd830:1d@`<0XGE400@0YWe90:=jAP2OMT80
WgI20P2QN4@00`2NMD40VW4m0:5dBP020:9fB@030:=gB02SMdH0Y7U60080Y7U40P2TNDH30:EjA`H0
YW]8102UNTL00`2TNDH0Yga90:MlB@060:MlB@T0YG]900<0Ygi:0:ImB@2UO4P00P2UO4P00`2WOTX0
ZH1<0:Z1C@030:MnBP80Z7m;0`2YP4`>0:QoB`80Ygi:0`2YP4X20:QoB@<0Ygi80`2[P4/20:b1C0<0
[H9=2P2[PTh60:Z1C@P0[8=?0`2[PT`30:b3C@80[HA>00<0[HA@0:j5D@2^QE400P2^QE430:n6DPP0
[HA@202[QU820:Z6C0040:Z5CP2ZQE00ZXE@0:Z5D@80ZXAC0`2_QU030:j5C`80[HA>00@0ZXEA0:^6
DP2[QU80ZhIB0`2/Qe<0102]R5@0ZhIB0:^6DP2[QU830:Z5D@80ZHA@0`2YP4`30:Z1C@80Zh9>0P2T
P4H00`2SOTL0XWe80:5lA`020:1kA`080:1jB@2ONDP0WgY309mjA@2NND@0WGQ409afA@2LMTL209]e
B00809]g@`2IMD40UW8n09A`?02CKc/0UG4m09Mc?`2HM40209E_@00309A^?`2CKCh0TV`m0080TF/l
0`2@JS/208mY>P0408iX>@2=IcP0RfDf08]U=P80Qf4d0P26H3<308EO<P0408AN<@22GcD0PUle089O
=@80PEhd0`20GC<207eJ<080O5T_0P1kF2h207YG;@80MUH]0P1eEB`407AD:`0807A@;P1cDBh0LU0]
071?;01]Cb/0JdlZ06U?:P1XCRT206a>;00306]=:`1ZC2X0JD/Y0080J4XX0P1WBBL02P1YBbT0JT`Z
06]=:`1[CB/0JT`Z06U;:@1WBBL0KU0^06a>;01YBbT206I89P0306M99`1YBbT0JT`Z0080Jd`]00<0
Jdd[06]=:@1[CBL00P1[CRH00`1[CR@0Kdh[06m>:`0206m>:`80L4l/0P1aD2d00`1dE2/0Le<Z079B
:@02071@9`03079B:@1cDbX0M5@[00X0N5P_1P1gEbh407aI<@@0NeP`101mFS0207aI;`80NeP^00<0
NUL]07MG;P1gEbh01P1gEbh207QF<080MeD_0P1fE2h207EC;@80MUH`00@0MED_07AD;P1dE2h0Le<]
0P1bDR`407EE;P0407AD;@1cDb`0Le</079B:`80LUH^00<0LED]071D;01_Db/00P1^DRX0101]DBT0
JdhV06e@:01_DRX2075D;00306mB:P1/CbL0JdhV00@0Ke4]101^D2`306a@:080KE4Y00@0KU8Z06mC
:`1`E2`0KU8]0P1]DB`00`1/D2/0JdlZ06Y>:@0206U=:0P0JD`Z00X0Hd`Z069;:@1PBBL0GTLU05e6
901NAbD0GdPV06199`1NAbP0GdPY0`1PBBX00`1NAbP0G4DV05]49@0305Y79`0305U69P1HABD0F4DU
0080Ed@T0`1C@RP305919`80DD0V0P1?>b<00`1=>b<0C3`S04/m8`0204Tm8`0304Pn8`1;?bD0BclU
00H0BclU00P0D3hX04hn9`1;>b@0B3TR04Di8@15>b80@c`R04@m8`<0@SXU0P11>B@3040h8`T0?SHQ
0P0k=R8303`g8`<0?CPT200k=R8803`g8`80>c@Q00H0>SDQ03Le800e=1l0<cDO038d7P0a=Ah403Le
80@0=S@O200d<Ah00`0g=2D0=C8S038_8002030]7P03034^7`0c<240=C8S00P0<34Q200a<ah4038d
7a@0<C<N00<0<38M034c7P0b=1l00P0c=B000`0b=1l0<38M02la700203@a7P80=C8O00@0=S<P03Ld
8@0g=240=c@Q200i=20303Pc7`80>C@P0`0j=B4203Pf7`80=cDN0P0f=1d203Dc70P0>3HO00<0=c8N
03Td800k=R800P0m>2@00`0k=R80>C@P03Lb7P0403Hd7`80=C<N2`0d<Qd303<a7080=38M0`0e<ah0
2@0g<Qh0=38M03@b7@0b<A`0<38L02hb6`0]<Q/0;34J034_6P03038`6`80<c4L0P0d<Qd403Tg7P80
>SPO0P0k>B002P0n>R40?cTQ040j8012>al0AC`O04Ll7P19>ah0BSdM04`k7@1@?b4205A39@80DD0R
00H0ED@V05U8:P1GA2@0F4DU05]89`1MBbL205e;9@0:05e;8`1LBb00J4`U06Q<9@1YCBH0JThW06]?
:01]DBX0KU8[06mC;0<0M5T^0`1eFRl207IK<009081Q<P1oH340O5d^07]L;@1lGBh0Of0a089S=024
ICH0QFLe0080QVPf00<0QfTg08QZ>029JcT00P2:K3X0202=Jc/0SV`l08m]?@2@KSh0TW1009=a@@2D
LT80UG=30P2DLch00`2EM3l0UWE009Mf@@0209Qg@P0509Uh@`2IMD<0VWI409ahAP2NNTP00P2ONdT2
09ijB0080:5oC`2POTh0Wge=09ilC02OODd0X7i>0::0D02SPE420:F1D@80YX9B00@0Yh=C0:R4E02X
Q5@0ZHEE0P2WQED00`2XQUH0ZHMG0:V7E`030:V7E`@0ZhUK00<0[8YL0:f;G@2]Red00P2^S5h30:n=
G`80/8iP0`2aSf430;>@IP<0]95W0P2eTVP30;BAI`80]I9X0`2fTfT30;NDJP<0]Y=Y0P2eTVP80;ND
JP030;NEI`2fU6H0]YAV00@0]YAV00<0]iEW0;JCJ@2fTfT01P2fTfT00`2hUF/0]iAZ0;FBJ0020;BA
I`030;FBJ02gU6X0^9E[00P0]iAZ202hUFd80;NEJ0P0]Y=Y202eTVP20;JDIP<0]I=U0`2dTV@20;FC
I@80]99T0P2cTF<20;:@HP80/Y5N00H0/Y1P0;:@HP2bT6<0/XmU0;>@IP2cT6P80;>DI@80]YAV00<0
]I=U0;BBI02cTF<00`2bT680102cTF<0/Y1R0;6?H@2aSf420;2>H0030;6?H@2bT680/i5S0080]iAZ
0P2fTfT20;FBJ080]95W202cT6H20;6?H@<0/8iP0`2_SEl80;:=H`P0/8iP0P2cT6H20;:?I@040;6>
I02`SF<0/8eS0;2=H`80/HiT102`SF<20:n<HPP0/8eS00P0/HiT0:n<HP2]RV00ZhQN0:b9G`2]RV00
/8eS0;:?I@P0[haR0P2bSfL20;6>IP80/8eU0P2_S6@30;2=H`@0[haR00<0[X]Q0:b<H`2/S6<00`2/
S6<30:^;HPP0[X]Q102]RV040:j;H@060:n<I02_S680[X]Q0:j<G`2]Red0[H]K0P2/ReP40;2;GP80
[hYM0P2^RE`00`2[RE/0[8YL0:j<GP020:n=G`030:j<GP2/RU`0ZhUK00T0[HYP202_S6800`2bSF00
/8]N0:f8F`020:^6F@030:b7FP2^RE`0/8]N00`0[HQK102^RE`20:^6FP80[8MK0P2]R5`20:j9G@06
0;B@H02cSel0/XiN0;2<G02^RUX0[HUI0P2[QeL80:Z5F0<0Z8=F0P2YQ5L30:Z5F0<0Z8=F0P2YQ5L3
0:Z5F0H0Xh5C0P2TPU@00`2VPE@0YH1C0:AoDP020:=nD@030:AoDP2UP5<0YX5D00<0YH1C0P2TOe86
0:=nD@@0Y7mB00<0XgiA0:1lC02PO4`01P2PO4`20:=mCP060:9lC@2QNd`0WgU:09ihB@2MMdP0W7I7
0`2MNDT209ahB0@0VgM700L0WGU909ijBP2ONd/0WGU909YfAP2GLd<0U7100080VGA700H0VWE809Ud
A`2HLdH0UW5409A_@P2CKT4909I`?`<0UW540P2EL4<309A_@P<0TVe00P2AK3l3091[?PP0SFPl0P2?
JSh0102>JCd0SFPl08aW>`2;ISX508YU>@80RF@h0`28HcL01P2=J3`0S6Lk08aW>`2;ISX0RVDi08UT
>080R6<g00P0Q5lc08EP=026HCD0Qf8f08IQ=@25H3@0Pehb089M<@<0Pehd0P22GC<3085L<P0307iI
;`1oFS00OeX`0080P5/a0`21G38507eJ<P<0O5Ta00@0P5`h07mK=`1mFCD0NeLc0P1jES800`1kEc<0
O5Pd07YF<P0207YF<P<0NEDa0P1hE3002@1fDS00Me<a07UE<`1kEcD0NUHd07QD<P1eDBl0Ldl]075?
;006079@;@03075?;01cDBh0Le4^00@0M58_0P1cDBh207ID;`0307EC;P1dDRd0Le4/0080LU0[00L0
LDlZ06mA;@1^D2`0KDl[06a>:P1ZC2P0JD/W0080J4XV00P0Kd`/06i;:`1/BbX0JT`Z06Y=:`1XCR/0
IThZ06A<:080Id`^00<0IDX/06A9:`1RAbT00`1QARP00`1PABL0I4HZ06A6:P0206=5:@<0HT@X00L0
HD<W05e49P1L@bD0G4<U05]2901J@B<0FD0R0080F3lQ1@1I@2800`1J@B<0Fd8T05]2900305Dk8P03
05Hl8`1G?B@0EcdT0080F3hU00<0Fd8T05a39@1MA2H00P1NABL01P1MA2H0G4<U05]2901I@280Fd8T
05a39@<0GTDW00D0GD@V05a39@1MA2H0GD@V05]2900205Y18`<0FD0R00<0FT0W05To9P1G?B@00P1F
?2<00`1G?B@0FClV05Y09`0305Lm900305Hl8`1F?240ES`Q0080EC/P00T0ESlP05Hn8P1E@2D0E40U
050o9@1>?2@0Bc/T04Ti8P17=Ad00P18=Qh00`19=al0BSPP04Xh800204Xh800804Xi7`19=al0B3HN
04Le7`18=R80BCHU04/h:@1<>BX404Lh9@0404Hg9015=R<0ACHS04@e8PP0@S8R0`10;ad00`11<1h0
@S4O048a7`0204<b8080?S4N0P0o<Ql03010<b00@C@Q048e8P12=B80BSDT04Td8`16<b80@c8P040a
7P0l;a`0>bhK03T^6PP0?c8Q0P10<b800`0o<R40?S4P03d`7`0303`_7P0303/^7@0h;ah0>2lN00H0
>2lN00H0?CDR03`d8@0k<b00>S8O03Ta7P0g;a`203H^6`0303L^7`0h;b00>2lP00D0>2lP0`0f;al3
03D^7P80=2dM00<0<R`N034[7@0a:ad00P0`:Q`302lY6`<0<2XL0P0_:A/302hX6P0502`Z7P0[:Ad0
:bTM02TW6`0X9QX00P0W9AT0100V91P09b@K02LT6`0W91/502PU70P08bDJ0`0R91T[ooooo`00:_oo
ool30:1e@P80XGI30`2RMd@01P2OM4T0WgA709mdA`2PMTH0X7I40:1g@`80XGQ200<0X7E20:5f@`2R
Md@00P2SN4D00`2RMd@0XGI30:1e@P0209id@P<0WgE30`2PMT@03P2UO4P0XGQ409ie@@2NMD40XGQ4
0:9iA@2OMT80Vg8n0:1cB@2QMDP0XgM:0:AhB@2TN4L0Y7U60P2SN4<20:AiAP<0YGY70`2VNdP80:Ej
A`P0Yga92@2VO4X00`2WOTX0YWe90:ElB0020:ElB0030:MnBP2YP4`0ZX5=00<0Ygi:0P2XOd/30:V0
C0P0Ygi:102XOd/20:MnBP80YWe90`2YP4`20:QoB`<0Ygi:0P2YOTT20:YoBP<0Zh1;00<0[85<0:^2
C02[PT`01P2[PT`20:^2CP<0ZX5=0`2YP4`80:b3C`<0Zh9<0`2/Pdd20:f4CPP0[XEA202]Q5080:^6
DP80ZXI<00@0ZXE>0:Z5D02ZQE00ZXEA0P2ZQ5<30:n6D0<0[XE?0P2]Q4h:0:b7D`80ZhIB0`2ZQE40
0`2YQ500Zh9>0:^2CP030:^2CP<0ZX5=0P2UPDL00`2TOdP0Xgi90:9mB0020:5lB0030:5kBP2PNTT0
XGa70080X7]700<0WgU809ihB@2MMdX00P2LMDX0102JMT80VGE109Qd@02GLcl209Ib?P0709Mc?`2H
M400UW1109I`@@2EKd00U6ho09=]?P02099/?@09095[?02@JS/0T6Xk095[?02@JS/0SfTj08iX>@2<
ISL0RfDf0080RF<f0P28HSD308MQ=00308IP<`24HCL0Pf0f0080Pf0f0P22GcD2085N=0<0OeX`0P1n
FBl307eH;P80MeL^0P1fERd307EE;00:07AD:`1gD2l0ME4_07A@;P1bD2d0L4l/06e?:`1/D2/0JdlZ
06e?;@80K4h/00<0Jdd[06Y<:P1YBbT00P1XBRP00`1WBBL0J4XX06Y<:P0206]=:`0706Y<:P1XBRP0
IdTW06a=;P1[C2d0JDX[06M8:@0206I7:080IdPY00D0J4TZ06U::`1YBbT0JT`X06Y<9P0206]>9P03
06]>901^CB`0KTd/00<0KD`[00H0Kdh]071?;P1aD2l0LE@/071C:`1^DBT206e@:00306iA:@1`Db/0
LE@/00P0MUH]00H0N5P_07MG;P1fERd0MED/07AD:`1eEB`207IF;@80NEH^0`1jEbl307]H<00607]H
;P1lFBl0O5T_07eJ<01lFBl0NeP^0P1jEbd00`1iER`0MeL^07MG;P0607MG;P0507YG<@1iES00NEH`
07QE;`1gE2h00P1fDbd00`1eDR`0ME@a07AC<00207AC<0@0Le8_0P1dE2d307EE;P0307=C;01bDR/0
LE4Z00@0L5@/0`1_Db/00`1^DRX0Ke8Z06mB:P03071C:`0406mB:P1^DBT0KE0X079A;P<0LE0]0`1`
Cb`00`1_CR/0K50X06a@:00206a@:00406eA:@1^DRX0L5@/075E;@80KU8]00<0KE4/06a@:`1[CbX0
0P1ZCRT00`1YCBP0JD`Z06U<:P0606U<:P0306=<:P1RBbT0HDXX00<0H4TW00@0HT/Y06=<:P1NAbP0
GdPY0`1PBBX00`1NAbP0G4DV05]49@0205]8:00305Y79`1IARH0F4DU0080Ed@T00@0ET<S05A3:@1D
@bT0E4<Y0P1C@RP305919`80DCdU00<0CcdU04hn9@1=?bD00P1;?bD00`1:@2D0BShT04Xn900604Xn
9009050n:01>?RL0C3`U04Tj8`16>R80AC/R04@m8`15?R@0@c/V00<0@SXU0P11>B@;040h8`0303dh
900l=b<0?3LS00D0?3LS200k=R8803`g8`80?3DR00H0>SDQ03Pf8@0f=B00<cDO038d7P0a=Ah403Le
80@0=S@O200e<Ql00`0f<b@0=C8S03@a8P03038_8080<c0Q200`<B42038d7`@0<38M0P0b=1l4034c
7P@0<38M400b=1l00`0b=1h0<cDO03@f800203@f800403<e7`0a<ad0;c4K03@a7P80=C8O00<0=S<P
03Ld8@0h=B800P0i=R<;03Td8080>SDQ0`0k=R8203Pf7`80=cDN0P0f=1d203Dc70P0>3HO0P0i=200
100j=B40>cHR03/f8P0j=B4203Td80<0=S@O0P0e<ah303@b7@0303<a700d<Qd0=38M00H0=38M0`0c
<A`203@b7@<0=C<N00H0>3<O03Dc7P0e<ah0<c8M030b700^<Q/202`a6P0403D`6P0f<A/0=S4K03Ha
6`80=c8L0P0h<ad303Xi7@80>cXN0`0l>al02P10?2<0@S`T048l8P14?B40AchQ04Tn801<?R40C3lO
050m7@1C@20205M49080ED8R00X0F4DU05a9:@1IARD0FdPW05e;9`1OCBL0H4hX061>9P1OCR<0GTdR
101[CbL0101]DBT0Ke<[075E;@1bERh207II;`80MeX`0P1hFc4207UL<P03089S=020HC80Of0a0080
OUl`00<0P64b08=T=@24ICH00P27JCL01028JSP0RF/i08Y/>P2:K3X208]]>`0908i/?02?KCd0T6hn
095_?`2CLD40U79209Ec@`2FM4@0UG@o0080UWE000<0UgI109Qg@P2IN4<00P2JND@0102KMT80W7M3
09iiA@2PNdL20:5lB080X7]700<0Xh5A0::0D02QOdl00P2POTh00`2QOdl0XX1@0:>1D@030:J2DP80
Yh=C0P2XQ5@0102YQED0YXAD0:N5E@2YQeL30:Z8F080ZHMG00L0ZXQJ0:^9F`2[RE/0ZhUK0:b:G02]
Red0[XaN00@0[heO0P2`SV030;6?H@040;:@HP2cT6H0/i1V0;>@IP80]95W0`2eTVP20;BAI`80]I9X
0`2fTfT00`2gU6X0^9E[0;REJ`020;NDJP<0]Y=Y00<0]I9X0;NDJP2gU6X01P2gU6X00`2hUVP0]iEW
0;JDIP020;FCI@030;JDIP2gUFL0^9IX00P0]iAZ00<0^9E[0;NDJP2eTVP00P2dTFL00`2eTVP0]iAZ
0;REJ`080;NDJPP0^9E]202iU6L80;JCJ@P0]I9X0P2fU6H30;FCI@<0]99T00D0]YAV0;FCI@2eTfD0
]99T0;>AH`020;:@HP060;6?H@2aT5d0/I1M0;:@H02bT680/Y1S0P2cT6H00`2cT6P0/Y=T0;:CI006
0;:CI0040;NEI`2fU6H0]99T0;>AH`@0/Y1R00@0]99T0;>AH`2bT680/Y1R0P2aSf400`2bT680/i5S
0;BBI0020;JCJ@<0]I9X0`2dTFL80;>@IP80/HmQ0`2`SV030:n=G`P0/XaU202`SV020;BAI`030;>@
IP2bSfD0/HiT0080/8eS00@0[haR0;6>I02aSV@0/HiT3@2`SF<00`2_S680[X]Q0:f:H0020:f:H003
0:n<HP2`SF<0/HiT00P0[haR0P2bSfL0102aSVH0/8eU0:n<I02_S6@20:j;H`D0/HiT0`2`SF<20:j>
I@80[HeT102/S6<80:j;H@<0[HYP0P2^Rf430:n<HP060:n<I02_S680[haR0:j<G`2^S5h0[H]K0P2]
S5T20;6<G`80/8]N0`2_RUd0102^RE`0ZhUK0:b:G02^S5h20:n=G`030:j<GP2/RU`0ZhUK00T0[X]Q
202_S6800`2aS5l0/8]N0:j9G0030:f8F``0[XUL0`2_RUd30;2;GP040:f8GP2^REl0[XUO0:j9G`80
[hYP0P2`Rf420;>?G`060;:>GP2aSEd0[h]K0:j:FP2]RET0[8QH202]R5/30:R3EP80ZHAG0`2ZQEP3
0:R3EP80ZHAG0`2ZQEP20:B2E0<0YH=E0`2VQ5H00`2ZQEP0ZHAG0:R3EP020:N2E@030:R3EP2YQ5L0
ZXEH0080Z8=F0P2WPUD30:J1E080YH1C00@0YX5D0:N2E@2XPeH0ZHAG0P2XPeH00`2WPUD0YH5A0:F1
D@060:F1D@80YX9B00<0YH5A0:B0D02SOdl00`2ROTh0102TP500Xgm?0:=oC`2SOdl20:9nCP80XGe=
0P2ROTh20:=oC`040:9nCP2PO4`0Wg];09ijBP<0WWU<00D0WGQ;09]fB@2JMDP0V7=609MbA@0909Ud
@0<0VWQ:0`2IMdT209QfB0<0UW920P2ELD4309A`@0X0Tfi100@0TVe0095/?`2@Jch0T6/n0P2?JSd3
08iX>`<0SFLj0P2<IST01P2AJch0T6Xm091Z?@2?JC`0SVPk08eW>P80S6Hi00P0RF<f08YT=`2;ICP0
S6Hi08]U>02:I3L0R68e08MQ=0<0Qf8h0P26HCL308EP=P0308AM=025GSD0QEhe0080QEhe0`26GcH3
08AO=@80Pehd0`22GC<01027HCX0QElh08=M=P21Fc@2081J<`03085K=022G3D0PE/f00<0PE/f1020
FSD02`1nF3<0OeTd07mI=020FSD0OeTd07iH<`1mEc80O5Ha07IC;@1gE2h0N5D_0080NEH`00H0N5D_
07MD;P1fDbd0Me@^07QE;`1iES0207YG<@0307UF<01hEBl0Me@^00@0NEH^101hEBd207AD;@0407=C
;01bDR/0LU8[075A:P80L50Y00`0NU<b07EA;`1cCbd0Le4^07AC<01bE300Ke<^06a@:`1`DS00Ke4_
06e?;@1[CB/306Y<:P80Jdd[0`1/Bb`206]::`<0JTTZ0P1TAbL00`1SARH0HTDU0654900206138`04
05m28P1TAbL0HdHV06959@80HD@T00<0HTDU06=69P1SARH00P1K?B400`1L?R80GClS05i0900205m1
9@0406129P1UB2H0ITTW06M::080J4/Y00h0IdXX06I99`1UB2H0HD@T06959@1TAbL0IDPX06I9:@1U
B2P0I4LW06=69P1UB2P0I4LW06959@<0HD@T00D0HTDU06=69P1Q@bL0H48V05m19@0205i0900305m1
9@1P@RH0HD<W0080GClW00<0GClU05do8`1M@2800P1M@200301M@1h0Fd0R05a18`1L@bD0Fd<W05Q3
:01E@BP0DclV04lm9@1<>A/0CCXL04ll7P<0D3dO0P1??1h0201B?b40DCdR04lk801>>R40CSXR04lj
9@1A?2T0DSdZ0P1=>b<304hl900304dk8`1;>B40BSPP00P0B3DT0P16<A`204Lb7@0504Pc7P19=1l0
BSDP04Xe8016=Ql00`17=b0404Ph8@08054f8`1@=b<0CcHR04/e8019=1l0AS@N04@d7@13<a`804He
8`80B3LU00<0AcHT04He8`15=2800`14<b400`13<R00@3<P040c8006040c80<0@cHS00<0@SDR044d
8@10<b000P0o<Ql4040c8P<0?c8Q00<0?S4P03`a7`0l<Al01P0l<Al203T`7`80>2lN00@0=bhM03H]
700e;1/0=B`K0`0g;Qd203H]70<0=B`K0P0a:al01P0`:Qh0;RPL02dW6`0/9QX0:bDI02XT60<0;2PO
0`0]:B0202hZ8@P0:BXL0`0W9ad[ooooo`00:_ooool30:1e@P030:5f@`2RMd@0XWM40080XgQ500H0
X7E:0:1eB02PMDP0X7I609me@`2OMT8209mf@0030:1e@P2QMT<0XWM40080XgQ500<0XWM40:5f@`2P
MD800P2MMD8309if@`<0WgM40100XWU509mf@P2LLcl0WWE10:5hA02RNDD0X7M309ed@02PLdT0XGE8
0:=gBP2TN4T0YGU80:AiAP2SN4<0XWM20P2TNDH30:EjA`<0YW]81P2UNTL20:IkB0P0Z7e:2@2XOT`0
0`2WOTX0YWe90:ElB0020:ElB0030:MnBP2YP4`0ZX5=00<0Ygi:0P2XOd/30:V0C0P0Ygi:00<0ZH1<
0:QoB`2XOd/00P2WOTX20:ImB@040:ElB02YOdd0ZGm=0:UoC@80Z7i<0`2WOD/20:MlA`80Z7e80`2Y
OTT00`2ZOdX0Zh9:0:^2BP060:^2BP80Zh9>0P2ZPDd20:V0C080Z7m;202/Pdl30:^2C0<0[8==0P2]
Q4h20:n6DPH0[XEA202]Q5080:^6DP80ZXI<00@0ZXE>0:Z5D02ZQE00ZXEA0P2ZQ5<30:n6D0<0[XE?
0P2]Q4h30:j9E@030:f8E02/Qe<0ZhIB0080ZXEA0`2/Qe<20:^6DP<0ZXEA0`2]Q5000`2/Pdl0Zh9>
0:Z1C@020:V0C0050:J2B02UPDL0YH190:AoBP2SOTT00P2RODT20:5kBP0:0:9mB@2QO4P0XG]:0:1j
B`2OND`0WWM<09efB`2MMTd0V7A009Ue@@80VWI200D0VGE109Qd@02GLcl0UW8n09Ma@P0209I`@@03
09E_@02DKSl0Tfdn0080TV`m00P0T6Xk095[?02AJc`0TV`m095[?02?JCX0S6Hg08]U=P<0RfDh0P2:
I3L308US=P0408ER>024HCL0Q64g08AQ=`80Pf0f0P22GcD4081I<080OeP_0P1nEbh0101hF2l0MeL^
07MG;P1gEbh207IF;@80MED/00H0N54`07M@;`1eDBl0Le4^075@;@1`Cb`206e?:`80KDl]00@0K4h/
06]=:`1ZC2X0JD/Y0P1XBRP00`1WBBL0J4XX06U;:@0206Y<:P0306U;:@1XBRP0IdTW0080JDX]00H0
JT/^06U:;@1XBB`0ITLZ06E6:@1SA2L206I7:00A06M99`1XBRH0JT`V06]>9P1/CbL0K4lU06i=;P1]
C2d0K4//06]::`1/Bb`0KD`]06m>;`1aD340Ke</06iB:`1/D2T00P1[CbP00`1/D2T0KU8[06mC;008
07AD:`0307QH;`1gEbh0MED/00<0Le<Z00H0M5@[07EE;01fDb/0MU<[07MD;01hEBd207UF;P80NUL_
00H0NUL]07]H;P1lFBl0OEX`07aI;`1kF2h207UF;00307MD:P1gEbh0MeL^00H0MeL^0P1jEc40101i
ES00N5D_07MD;P1fDbd207EB;080LU4^0`1cDRl307AC<080Le</0`1eEBh00`1cDb`0LE4Z071@:@03
06iB:P80Ke<[0`1`E2`0101cERh0LUD]075D;01`Db/206mB:P80L5<[0P1cDBh2079@;@80LDl/0P1`
CR/0201]DBT0K50X06]?9`1[CbL0K50X06iB:P1aEBd0LUH^0P1^DRd206eA;00406a@:`1[CbX0JThY
06Y>:@P0JTd[00<0IDh/06A=:`1RBbT00P1RBbT01@1SC2X0IDh/06I?;@1NAbP0GdPY00<0H4TZ00T0
GTLX05a59P1KA2D0G4TY05]8:01JAbL0FDHV05Q59@1GA2@00P1F@b<305E4:P80E4<Y0`1C@RP2058n
9P03050n9P1??bH0CT0V0080C40V00<0Bd4V04Pl8P18?2801P18?280201A?bT0CShW04`l9@19>R<0
ASXR04Dk8P14?B<0AChT0P13>bH3048j9@<0@CTT2@12>RD203hi9@80?CPT00@0?3LS03/f8P0j=B40
>SDQ400k=R8203df8`0603/f8P0h=R40=SDP03<e7`0b=1h0<CDN100f=1l403Le80P0=C8O0P0d<B83
03Db8`0303@a8P0b;b00<BhO00P0<34Q00<0<cDP038d7`0`<Qd00P0_<A`00`0`<Qd0<S@O03<e8008
02la70P0<S@O200c=B000`0c=Ad0=3HN03Dg7`0203Dg7`0903<e7@0a<a/0<38J03@a7P0e<Ql0=S<P
03Ld8@0h=B80>CHS0080>SLT200h<al0100i=200>SDQ03Xe8@0j=B4203/f8P80?3LS0P0h=Ql203Le
7P80=S@M0P0e<a`803Pf7`0303/f8P0j=B40>C@P00<0>C@P00<0>SDQ03/f8P0e<ah00`0e<ah303@b
7@80<c4L200d<Qd303<a7080=38M0`0e<ah01P0i=200=S@O03Dc7P0c<Qd0<38L02hb6`80;34J0`0i
<a/203Xd70<0>cDM0`0k>Qh203`k7`<0?C`P00X0@clV04@n9P15?bD0Ad0T04Y1901;@280CT0S04m2
8P1B?Qd0ED4P0P1IAB@205M38P0805Y69@1NBRT0FdPW05a:9P1OCBT0H4hX065?9`1QD2D2061?8`80
KE4Y0P1/D2P0101^DRX0L5@/07=G;`1dF30207QH;`0307UI<01jFS40Ne/b0080OEdd00D0OUhe085R
<`21HS<0PF8c081Q<P02085R<`06089S=023I3D0R6Xh08QZ>029JcT0RV`j0P2;KC/0202<KS`0SFlm
08m]?@2?KCd0T6hn099`@02CLD40UG=30P2FM4@01P2FMD00UgI109Mf@@2HMd80VGQ309YiA080VgY5
00@0WGE209mgA02QNDH0Xg]80P2TO4T01@2SNdP0XWY70:F3D`2TPU80XX1@0080XGm?00<0XX1@0:>1
D@2TPU80102WPe<40:R4E0030:J4E02WQED0ZHMG00<0ZhUI00<0ZXQH0:V7E`2ZR5X00`2[RE/0102/
RU`0[XaN0:n=G`2_SEl40;2>H0<0/HmQ0P2bT680102cT6H0]95W0;BAI`2dTFL20;FBJ080]Y=Y0`2e
TVP30;JCJ@80]iAZ0`2hUF/20;NDJP<0]Y=Y202gU6X00`2iUfT0^9IX0;JDIP020;FCI@030;JDIP2h
UVP0^IMY00P0]iAZ00<0^9E[0;NDJP2eTVP00P2dTFL00`2eTVP0]iAZ0;REJ`080;NDJPP0^9E]202j
U6D@0;JCJ@80]YAV0`2eTfD30;BBI080]YAV00@0]I=U0;BBI02cTF<0/Y1R0P2aSf420;6@G@060;6?
G`2bT680/i5T0;>@IP2dTFL0]95Y202aTV<0102hUVP0]YAV0;BBI02bT6820;6?H@040;:@HP2cTF<0
]I=U0;BBI080/Y1R0P2aSf400`2bT680]99T0;FCI@030;>@IPD0]95W202cT6H20;6?H@<0/8iP0`2_
SEl80;>=J0P0/HmQ00D0]I9X0;BAI`2dTFL0/i1V0;6>I0020;2=H`030:n<HP2`SF<0/8eS00H0/HiT
202`SF<0102/REl0[HYP0:j;H@2_S6820;2=H`80[haR202`SF<01P2bSfL0/HiV0;2=I@2_S6@0[X]S
0:f:HP80[8UQ0`2aSV@50;:?I@80[hmV0P2^SVD0102]SF@0[8aS0:b<H`2/S6<80:j;H@<0[HYP00<0
[X]Q0:n<HP2_S6800P2`SF<01P2_S6@0[haR0:n<HP2_SF00[XaN0:j<G080[HaI0`2`Reh20:n:G@<0
[XUL00<0ZXQJ0:^9F`2]Red00P2^S5h00`2]Red0ZhUK0:Z8FP090:n<HPP0[X]Q0P2^RE`30:n:G@03
0:j9G02/QeX0ZhII00X0[XUL0P2_RUd0102`Reh0/HaO0;6<G`2aS5l20:j9G`80[hYP0`2`Rf40102a
S680/8aL0;2<G02`S5`20:n;F`80[XYJ00<0[HUI0:j9G02^RE`01P2^RE`20:Z5F080ZhII0`2/QeX0
0`2]R5/0ZXEH0:Z5F0020:^6F@<0[8MJ00<0[HQK0:R6F02XQUP00P2YQeT01`2ZR5X0ZhUK0:^9F`2[
RE/0[HQK0:b7FP2ZQEP00P2YQ5L0102ZQEP0[8MJ0:f8F`2]R5/30:b7FP80ZhII0P2ZQEP0202VPE@0
Yh9E0:V4E`2[QUT0[8MJ0:^6F@2ZQEP0ZHAG202ZQUH50:F3D`<0Y89B0`2XQ5@20:N3D`<0YX9B0P2W
Pe<03P2VPU80YH5A0:F1D@2UPE40YX9B0:N3D`2VPE@0YH1C0:AoDP2SOU40XGa?0:1kCP2ONTd0WWU<
2@2ONTH309moD080WWi?0`2MODh209eiA`80W7Q6102KMdD809ahB0D0V7A40`2GLd<309I]?`80UF`n
0`2DJcd01P2HKd40Ufi009M^@02FKCl0UF`n09A[?@80TfXl00<0TVTk09=Z?02DJcd00P2DJcd00`2B
JC/0T6Li08mV>00208iY?@80SFPl102<Ic/308mU>`D0SV@j00<0SFLj08aV>@2<IST00P2;ICP208YT
=`0508US=P2:HcX0RF8i08MP=`25GSD00P24GC@208EN=@<0QEdi1@26GSX00`25GSL0Q5df089K=003
085J<`80PU/d00<0OEXb07iK<`20GCD00P21GSH01P20GCD0OU/c07eJ<P1lFC40OEXb07mL=080P5de
00<0Oe`d07eJ<P1lFC400P1mFS0307iK<@<0Oe`b0P1kFS4607YI<00;085I=@1mEC40NE<^07QE;`1j
F380NUXc07MG<01aE2`0ME@a07AC<01bDBh00P1aD2d2079A;P0307=B;`1dDc00LTh^0080LTh^0P1a
CBd3071<;080K4h/00<0Jdd[06Y<:P1YBbT00P1XBRP0101WBBL0K4h/06]=:`1XBRP306I89P0306M9
9`1XBRP0HT<T0080Hd@U00P0I4DV06I7:01WB2T0IdPY06Q9:P1[CBL0K4hX06e?:@80KU0Z00H0KDlY
06a>:01[CBL0I4HT06I89P1WBBL306U;:@0506Q::01WBBL0J4XX06M99`1VB2H00P1UAbD01P1WBBL0
JD/Y06Y<:P1YBR/0J4TZ06M8:@80IDHW00<0IdPY06Q9:P1YBR/00P1TA2d0101TA2/0I4DX06A59P1T
AR8206A6800F06538@1QA2@0HTDU06159`1NABL0G4@X05Q3:01F@BH0EChN05M0801I@R80FT<S05]4
901J@b<0FD8R05Q18@1KA2D0FD8S05Lo8`1E?B<0ECdU05Dl9P80ESdY00P0DShS05<o901D@2D0ED4V
05A09@1C?b@0DCdR04lk80P0CSTT00H0CSDO04lf801@=b40DCPR058i8`1C>R@205@k9@80CC/S0`1<
>R8304/i8@0605Hg8`1D>2<0DcLR058g8P1@=b40CSPQ0P1<>20804/i8`0604dk9@1<>R@0C3XT04/i
8`1:>280BCLQ0`18=R0804Lg80P0B3PQ0P18=bD01017=R@0ASDS04Dd8P15=28204@c8@@0?c8O1010
<b001P11=R@0@3DS03ld8P0n<b40?C8P03`a7`80>c0N0P0n<b4203db8080?34O0P0k<1h01P0i;b<0
>2hR03L]8@0e:al0=2XN038X7080<BLK0P0_:b02030/8@04034]8P0b;R<0<RhS038^8`P0;R`M0`0/
:Qh[ooooo`00:_ooool30:1e@P030:5f@`2RMd@0XgQ50080XgQ500H0XWM<0:5fB@2QMTT0X7I609me
@`2NMD4209ed?P030:1e@P2QMT<0XWM40080XgQ500<0XWM40:5f@`2PMD800P2MMD8309if@`<0WgM4
0100XGQ409ie@@2LLcl0WGA00:5hA02SNTH0XGQ409ie@@2OLTP0XGE80:=gBP2UNDX0YGU80:AiAP2S
N4<0XWM20P2TNDH30:EjA`<0YW]81@2UNTL30:IkB0P0Z7e:2@2YOdd00`2WOTX0YWe90:ElB0020:El
B0030:MnBP2YP4`0ZX5=00<0Ygi:0P2XOd/30:V0C0P0Ygi:00@0ZH1<0:QoB`2XOd/0Ygi:0P2VODT2
0:ElB0<0ZGm=0P2XOT`30:MmB`80YW]60`2WO4L30:QmB0P0Zh9:0P2[PTh20:Z1C@040:V0C02XOd/0
Z7m;0:MnBPP0[8=?0`2[PT`30:b3C@80[HA>0`2_QU850:j5D@P0[HA@202[QU820:Z6C0040:Z5CP2Z
QE00ZXE@0:Z5D@80ZXAC0`2_QU030:j5C`80[HA>00P0/8]G0:n:EP2^RED0[HQD0:b7D`2[QU80ZXEA
0:V4D0<0[8MC0`2[QU820:Z5D@80[hIB00H0[XEA0:b3C`2[PTh0ZX5=0:V0C02XOd/20:J2B0030:F0
B@2TOdX0Xgi90080XWe90180XWa;0:5kBP2RODT0XWa;0:5kBP2PNT/0WgU<09mhC@2NMdh0WGI=09Mc
?`2HM400VgM309ahA02KMd<0VGE109Ib?P2DL3`209Ma@P0309I`@@2EKd00U6ho0080Tfdn00<0TV`m
091Z>`2AJc`00P2BK3d0102AJc`0SfTj08eW>02;ICH308aV>@<0RfDh0P2:I3L308ER>080Q64g0`23
H3H01021FS40P5T`081I<020FC0207mH;`80OUL^0P1hF2l207MG;P<0MUH]00T0MED/07U@<01hDC00
Me0_07A@;P1bD2d0L4l/06i@;01]Cb/00P1]Cbd00`1/CR`0Jdd[06Y<:P0206U;:@0406Q::01VB2H0
J4XX06U;:@80JT`Z00/0JD/Y06Q::01VB2H0IdP[06Q9;01ZBbh0Jd`_06U:;@1WB2/0Hd@W06529@02
06A59P0A06I89P1WBBD0JD/U06]>9P1/CbL0KE0V06i=;P1]C2d0JdX[06Y9:P1[BR/0KD`]06m>;`1`
Cc00KU8[06eA:P1/D2T00P1[CbP00`1/D2T0KE4Z06iB:`0807=C:P0307QH;`1gEbh0M5@[00<0LU8Y
00@0M5@[07EE;01dDBT0ME8Z0P1fDb/207QE;@0807UF;P1jEbl0NEH/07YG;@1lFBl0OEX`07aI;`1j
Ebd207QE:`0307MD:P1gEbh0MeL^00H0MeL^00P0OELb07aF<@1kEC00NU@_07UC;P1hDRd0Me4/07I@
:`80LE0_00@0LU4`07=B<@1cDS40M5<b0P1eE3<0201bDR/0Le</07EE;P1fERl0MED^07=C;01aDBX0
L50Y0P1]DBT206iB:P0<06mC:`1`E2`0LED]075E;@1fFC40M5L_075D;01_DRX0KU4Y06mB:P1aE2`0
LeH^0`1cDBh00`1bD2d0LDl/071>:`02071>:`0906eA:@1/D2P0JdlW06]?9`1/D2P0KU8Z075E;@1c
Ebl0Ke<^0080KU8]00<0KE4/06a@:`1[CbX00P1ZCRT806Y=:`80IDh/0`1SC2X01@1UCR`0Ie0^06QA
;`1NAbP0GdPY00<0H4TZ00@0GTLX05a59P1KA2D0G4TY0P1KB2P00`1IARH0F4DU05M4900205I38`<0
ED@Z0P1D@bT305=2:080DclW00<0DClW05109`1?@BL00P1=@BL00`1<@RL0Ac/Q04Lk8@0604Lk8@08
054o:@1??bP0C3`U04Tj8`16>R80AS`S04@m8`15?R@304<k9P80@SXU0`11>B@904@l9`06040k9`0o
>RH0?STU03dh900l=b<0>SDQ0P0i=20803/f8PP0>SDQ00P0?SLT03df8`0k=R80>3HQ03He800c=Al0
<S@N034e7P@0=S@O100g=B0803Db7`03038_800d<B80=S<T0080=c@U00<0=C8S038_800`;Ah0200`
<B400`0c=B00<S@O030b7@0202la7003030b7@0b=1l0<cDP0080;BlJ100^<1/202la70P0<S@O200c
=B0203@f7P0603Dg7`0f>200=CLO03<e7@0a<a/0<38J0P0e<Ql01P0f<b00=c@Q03Pe8P0i=R<0>SLT
03/h9@P0=c8N0`0j=B4203/f8P<0?3LS0P0h=Ql203Le7P80=S@M0P0e<a`803Pf7`0303dh900k=R80
>C@P0080=c8N00<0>C@P03/f8P0m>2@0100e<ah203@b7@<0<c4L200d<Qd303<a7080=38M0`0e<ah0
1P0i=200=cDP03Hd7`0d<ah0<38L02hb6`80;34J0P0j=1`303/e7@<0?3HN00@0>cXL03`k7@0l>ad0
?3/M0P0m?1h203hm7`0:04A09`16@2P0AT0V04Q19@1;@RD0CD8T05129@1@@b<0DShM05I28@80FDDT
0P1G@b801P1KAbH0Gd/Z05a:9P1MBbL0GddW065?9`80HU4V0P1QD2@206iC:080KE8W00@0KU<X075F
:`1dFBh0MU/`0P1hF2l01P1iFC00Ne/b07aL<`1nGSD0Oelf081P=`80PF8c00@0PV<d08=T=@23I3D0
Pf@e0P22Hc@01P28JSP0RF/i08U[>@2:K3X0Rfdk08a^?080SFlm00P0Sfdm091^?P2AKcl0TW1009Ab
@P2ELd<0UWA409MeA@80UgI100<0V7M209Uh@`2JND@00P2KNTD01@2LNdH0WWI209mg@`2QNDD0Xg]7
0080Y7a80P2SNdL00`2VQ5@0Y89B0:>1D@020:5oC`030::0D02SPE40Y89B00<0Yh=C1@2XQ5@02@2V
Q5@0Z8IF0:Z8F02[RET0[8YJ0:^9F@2ZR5P0Z8IF0:Z8FP030:^9F`030:f;G@2^S5h0[heO00D0/8iP
0P2aSf430;:@HP@0]95W0P2eTVP20;JCJ@<0]I9X0P2fTfT30;NDJP<0^9E[0`2gU6X20;JCJ@P0]iAZ
00<0^IMY0;RFJ02fU6H00P2eTfD00`2fU6H0^9IX0;VGJ@080;NDJP030;REJ`2gU6X0]I9X0080]95W
00<0]I9X0;NDJP2hUF/0202gU6X80;REK@P0^YAU402fTfT20;JDIP<0]I=U0`2dTV@0402gUFL0]YAV
0;FCI@2dTV@0/i5S0;:@HP2aSf40/8iP0;2?G02aT5d0/HmO0;:@HP2cTF@0/i1V0;BAI`2dTFT80;2A
HP040;RFJ02fU6H0]99T0;:@HP80/HmQ00@0/Y1R0;>AH`2eTfD0]99T0P2cTF<20;:@HP040;>AH`2d
TV@0]I=U0;6>I080/XmU0P2cT6H30;BAI`P0/i1V0P2aSf430;2>H0<0[heO202cSFP80;6?H@80]I9X
00<0]95W0;>@IP2bSfD00P2`SF<00`2_S680/8eS0;2=H`040;6>I080/XmU202`SF<0202ZQed0[8UO
0:n<HP2aSV@0/XmU0;6>I02_S680[HYP202`SF<20;6>IP040;2=I@2_S6@0[HYR0:b9H@80ZhQP00<0
/HiT0;:?I@2bSfD00P2bSfD30;>@IP040;2@I`2_SfH0[hmV0:j>I@80[HeT0P2/S6<80:j;H@<0[HYP
00<0[X]Q0:n<HP2`SF<00P2`SF<01P2`SFD0[haR0:n<HP2_SF00[XaN0:j<G080[HaI0P2`Reh20:n:
G@<0[XUL00@0[HQK0:Z8FP2[RE/0[8YL0P2]Red00`2/RU`0ZhUK0:Z8FP090;2=H`P0[X]Q00P0[8MJ
0:f8F`2_RUd0/HaO0;2;GP2^RE`0ZhII0:V4E`P0[HQK0P2^RE`20:n:G@050;2;GP2aS5l0/HaO0;:=
H02^R6400`2_RF820;2:H`80/H]T202^RUX80:j9G0<0[HQK0P2^RE`30:n:G@<0[HQK0P2^RE`30:n:
G@80[8YL0P2]Red01`2^S5h0[heO0:n=G`2`SV00[XUL0:f8F`2[QUT00P2ZQEP00`2[QUT0[HQK0:j9
G0020;6<G`80/8]N0`2_RUd01@2^RE`0YX5D0:R3EP2ZQEP0[8MJ0080[HQK00<0ZhII0:Z5F02/R5P0
1`2/R5P30:F3D`80YXAD0`2WQED20:^7E`<0ZXIF0`2YQED03P2ZQUH0ZHEE0:N3D`2UPE40YX9B0:R4
E02[QeL0[HUI0:b7FP2[QUT0ZXEH0:R3EP2VPE@0YH1C0P2TOe890:F0B`<0XX9C0P2QPE830:20D@<0
XWi<0`2QOD/20:1lBPP0Xgm?102MNDT409ijBP@0Vg940P2JLD<209U`@P80W7=500<0Vg9409Ya@`2I
L4800P2HKd4209M^@00709Q_@@2IL480VW5309U`@P2HKd40UVdo09E/?P0309=^@@<0TVe00P2AK3l3
09E/@080U6/o0P2CJSh01@2BJCd0Tfdn099/?@2BK3d0TF/l0080T6Xk0P2?JCX0102<ICX0RV<h08QQ
=P26Gc@208EN<`0308IO=027H3D0Qf0i0080Qf0i1028HCX03029HS/0R64h08IO=P23G3<0PEXa081I
<022Fc80Q5dd08EN=@25H3H0QV4g08QS>@80RF@j00H0R6<i08IQ=`25H3H0Pehd08AO=@26HCL208MR
>00308IQ=`24GcD0Pehd0080Pehb00@0Q5lc08EP=026HCD0QV4e0P27HSH207mN<`<0P5ld0`21H3D0
2`26FcP0OeLc07aD<01lES40OU/e07iL=P1jFS<0MED^07ME<01fE2l0ME<^0080M58]0P1fE2l00`1h
ES40NELb07M@;`0307I?;P80MDh]0P1dCB`01P1dDc00Le8_07=B;`1bDBh0LE0]071?;080Kdh[00@0
LU4^071?;01]C2T0JdXW0P1YB2D03@1ZBBH0JdXW06U8:@1ZBBX0JdX[06a;;01]C2d0KTd^06m>;`1`
Cc00KdlX071@:@1bDR/00P1cDb`05P1bDR/0L50Y06m?:01XAb@0JDPU06]:9`1/BbP0KD`Y06a;:01[
BRL0JTTV06]:9`1ZBBH0JDPU06Q7901YB2D0JdXW06i=:P1`Cb`0LE0a071?<01^CBh206e<;@0306i=
;P1`Cc00LE0a0080JdPb0140JdT^06]9;@1[BRT0K4`V06a<9@1/C2<0HdDS06A6901TAbL0HTLY0617
:@1NAbP0G4@X05Q39P1KA280G4DS05i79@0306199`0805i79@1MAR@0GTLW05e69`1J@b@0F40T05Hn
901F?RH205Ln:00305E08`1F@B@0Ed8U0080F4<V00<0ET4T05@o8P1B?B00201A>bH0201E>B<0ESXT
05Lk9@1H?2H0FCdW05Xn:01K?bT0G40Z0P1B?RD00`1A?B@0D3`S04lk8P0204hj8@0704di801H>2<0
F3PS05Lh8`1E>B<0E3XS058j8P02050j8PP0CSTT00H0DC`W050k9P1@>bH0CcXU04hi901=>2<304`g
8PP0BCTO0P19>B8304Xj8`<0Bc/T0P1:>BD01019>2@0B3LS04Lf8P16=B4204Dd8080@S<N1013=1l2
04@e800804Dh9@14=b@0@cHS048e8P11=240@3<P03lb7`0n<Ah3044d8@<0@3<P0P0o<Ql203dc9`04
03`b9P0j<2@0>2hR03L]8@80=B/O0P0c;B40100d;R80=BlS03D_8`0f<2@203La9@P0<C0N0`0^;1l[
ooooo`00:_ooool809me@`80XGI900@0X7E809mdA`2MLTD0W7540P2KL4<30:1eB0D0WgA700@0X7E2
0:5f@`2QMT<0XGI30`2RMd@01@2SN4D0W7<o09ie@@2PMd<0XWU50080XgY60P2QN4@0102KN480WGY4
09mlAP2PODL20:5nB0030:1mA`2OO4H0YWi:00<0YGe90P2TO4P20:=kA`P0Y7]50P2VODT00`2UO4P0
Y7]70:=jAP020:9iA@030:5hA02WOTX0Ygi:00@0Ygi:0`2VODT01P2`Ndl0[ga?0:mlC@2/O4/0Zge;
0:QmB080Ygi600H0YWi10:In@`2WOd@0Z7m70:QoB@2YP4`20:Z0CP<0ZX5=0`2YP4`:0:QoB`80[89B
00<0Zh5A0:Z0D02YOdl00P2WODd00`2VO4`0Z7m;0:QoB`060:QoB`060:N2E@2XPU<0Z89C0:Z2D@2[
PDl0[85>0P2^P4`80:^1C`060:^0E@2[P5<0Zh1C0:^1D@2[PDl0Zh9>0P2[PT`;0:b3C`030:^2CP2Z
PDd0ZH1<0080ZH1<0P2^QDd0102^QDl0[XEA0:j5D@2^Q5820:j4E080/8ID0P2_QE<0102^Q580[H=A
0:f3D@2/PU080:V4C`040:n5D`2`QU@0/8ID0;26E080/HME0P2bR5H01P2bSET0/HaH0;6<F02`ReL0
[XUE0:f8E080[8MC0P2^RED20:f8E080[8MC0P2[QU80202XPdl0ZHA@0:Z5D@2[QU80ZXEA0:V4D02W
PTh0YX5=0P2XPdh00`2WPTd0YX5<0:AoBP020:=nB@80XWe80`2PNdH209mjA@<0WWU40100VWA309]e
A02LMTD0WGM609afA@2ILd80Ug5009E_?P2GMT40UWE009Mc?`2GLSh0Ufll09M]>`2FK3X0Uf/j0`2@
JcL2095/>0<0TVdi00L0Sf/k08iZ>P2=JCT0S6Ph08YV=P29ICD0R6@d0080Qf<c00L0R6@d08UU=@29
ICD0RFDe08MS<`26HS80Q60`0080OU`^101oGBl2081N<00;085N=01oG380O5Ta07YG;`1iES00NUHb
07]G=@1lF3H0N5Pa07IF;`1dE2d00P1bDR/02`1cDb`0M5@]07EE;P1fERl0M5@]075A:P1^CRL0KDdV
06i>9`1`D2T0LE4Z0080IdTU00H0J4XV06U;9`1ZC2P0JddY06a>:P1]Cb/306Q::080IdTW0`1VB2H0
201SAB<0I4HT06E79@1VB2H0J4XX06U;:@1ZC2X0Jdd[201ZCB/306i@;080Ke4]0`1`DRh0101^DBL0
Ke8X06mB:01_DRP2071C:@80LE@Z0140NU@_07UC;P1hDRd0Me4/07QB;@1iDbh0NeD`07aF<@1eEB`0
MeL^07UI<01jFS40NET`07MG;P1dE2/0LU8Y07AE9P0207EF9`0307IG:01gF2T0N5TZ00<0NEX[0`1g
F2T207QI:P<0NEX[0P1nES800`1lES40NEH`07ME;`0207EE;P04079E;@1dE2d0Le</079B:`80LE4Z
00H0Le</07EE;P1fERl0LU8[07=C;01eEBh207IF;`0A07EE;P1cDb`0LU8[06mB:P1^DBT0K4lW06]>
9P1/CbL0Ke8Z079E;@1dEbl0MeXb07II<@1eF300M5L_07=F;P1bEBd00P1aE2`04P1cERh0LUD]075D
;01_DRX0KU4Y06a?9`1[CRH0JTdU07=F;P1bEBd0LE@/06mB:P1^DBT0K4lW06]>9P1ZCBD0Ke8Z071C
:`80LE@/02@0L5<[06e@:01[CRH0JD`T06MA;01UCbX0HT/Y05m8:01OB2T0HTX^06E=<@1XD3H0HDTW
06=;:@1UCB/0ITh/06M?;@1VCR`0I4`Z06=;:@1NC2P0G4XV05Y8901HAR80FDLS05a:9P1PCRX0He4]
05m6:01OB2T0H4TZ05i9:P1MBRX0FDTX05I79P1EARD205Y79`<0FDHV0`1HABD205919`80DD0V0`1@
?bD03`1??R@0Bc/T04/k901<?2D0CCdV04hn9`1??bP0D40Y0551:P17@2@0ASlS04Dn8P14?B40@c`P
044j7P02040i7@P0AC/R0P17>24304Hg80@0ACHO00<0@3PS03lg8P0m=B000P0k<ah00`0l=1l0?CDP
03hf8@0203Pc7@0403Td7P0j=Al0?3LQ03dh8P80?STS0P0k=R8303Xe8@/0>C@P00D0=38M03Dc7P0e
<ah0=S@O03Le800203Pf8@0503Tg8P0c<1d0=34N03@a7P0e<Ql00P0f<b0203Ld8@0303Hc800e<Ql0
=34N0080<c0M00<0=34N03Db7`0f<b000`0b<b<2034b8P<0<34Q00P0<c@T038c8`0`<B40;RlO02d^
7P0^;al0<34Q034b8P<0<38M0P0a<ah3038d7`0803Db7`0d<Ah0<c0M03<`7@0d<Ah0=S<P03Pe8P0i
=R<203@a7P<0=C8O0`0f<b00200_<A/0<C<M03@f800f>280=cTS03Dg8@0c=Al0<S@N200i=b800`0h
=R40=cDP03Hd7`0203Dc7P0303Hd7`0g=B00>3HQ00P0>SDQ0P0h=R4203Le8080=S@O0P0e<ah02`0b
<1/0<c4L03Dc7P0f=1l0=cDP03Hd7`0e<ah0=38M03Pe8P0f<b00=34N0080<c0M00<0=C8O03Pe8P0i
=R<00`0c=B00100b=1l0<C<N034c7P0`<Qd202la70<0<S0K0`0c<A`:03@b7@80<C0L00H0<S4M03<b
7P0d<al0=3<O03Dd800f=B4203He800603Pf8@0k=R80?CHS03hf8`0o=b@0@SLU0P11=R801P12=b40
@cTP04Dk8016?240AchQ04Po8P80BSTU00h0Bc/T04`l8`1>?R@0Cd0S0511901A@R<0DT@Q05A48P1E
AB40FDLQ05a88`1PBR<0HT/R06=<8`80IDdY00`0IThZ06M?:`1YDBd0JU8^06]C;`1/E300LE@X079E
:@1cERX0M5L[07II;@1gFRh207QK;`80NU//00L0Ne`]07aM;P1nGc00Of0a081Q<P21HS<0QF@_0080
QVD`00<0QfHa08QW<P29J3<00P2:JC@0202:IS80RfLc08aX=02=JCD0Sf/g095]>@2BKSX0Tflk0P2B
LC/0102CLS`0UG@n09Ie?`2HMd4209Uh@P0309]g@`2LN4@0W7Q400@0W7Q400@0WGU509ajBP2LNTX0
W7Y:0P2MNd/309ilC080Xgm;00<0Y81<0:F1C@2VPTh00P2WPdl00`2XQ500YhEE0:N5E@020:N5E@@0
YXAD0P2/RUX20:f;F`@0[XaL102_SU/20;2?G0<0/I1M0P2cTF<20;:@HP040;6?H@2`SV00[heO0:n=
G`80]99T00@0]I=U0;JDIP2fU6H0]iEW0P2hUVP01P2dTFL0]I9X0;JCJ@2gU6X0^9E[0;VFK080^YM]
202jV6X80;VGJ@<0^9IX0`2gUFL20;JDIPP0]iEW202iUfT:0;REJ`80^II/00@0^YM]0;^HKP2kV6h0
_9U_202gUFL20;JHIP040;FFI`2dUFL0]9EY0;>CJP80/Y9[00P0/i1V0;FBJ02iUV`0^iQ^0;VFK02e
TVP0/8eS0:b9G`<0]iAZ0P2fTfT30;FBJ0@0/I9V102bTfL00`2bT680/i5S0;BBI0020;FCI@030;BB
I02cTF<0/Y1R0080]I=U0P2dTV@20;>AH`80/Y1R202cTF<02P2gUFL0]I=U0;>AH`2cTF<0/Y1R0;6?
H@2bT680/i5S0;FCI@2bT6830;>AH`<0]99T00<0]I=U0;:?I@2cT6H00`2dTFL0102bSfD0/8eS0:n<
HP2]Red20:j<GP030:n=G`2`SV00/HmQ0080/Y1R0`2bSfD20;6>I0<0/8eS00<0]8mR0;>>H@2bSF00
0P2aS5l02`2cSV40]I1S0;JAI02eTVP0]95W0;:?I@2aSV@0/8eS0;6>I02bSfD0/i1V00<0/HmQ0P2`
SV030:n=G`80/HmQ0`2`SV030:n=G`<0[HYP00<0[X]Q0:n<HP2`SF<00P2`SF<00`2cTF<0/8iP0:b:
G0020:V7F@030:^9F`2^S5h0/8iP00P0/HiT0P2^Rf420:n<HP050;2=H`2aSV@0/HiT0;:?I@2`SV00
0`2_SEl30:j<GP030:f;G@2^S5h0[XaN0080[XaN102_SEl30:n<HP<0/8eS0P2aSV@20:^:E`030:b:
FP2]Red0[XaO0080[haR00<0/8eU0;6<G`2bSF000P2dSf80102cSV40/8]N0:b7FP2ZQEP30:n=G`80
[XaN0`2]Red20:n<HP<0[X]Q00@0[HYP0:b9G`2/REl0ZhQN0P2`SV020:n=G`<0[XaN00<0[H]M0;2=
H`2`SF<01P2`SF<80:n=G`030;2<G02_Re/0[XYJ0080[HUI00<0[h]K0;6=G@2cSel0202_S6820:b<
G@040:f;G@2_RUd0[hYM0;2:G@80/XUM00<0/8iP0:j<GP2/RU`00P2[RE/00`2/RU`0[XaN0;2>H008
0:j9G0080:f:I02]RV80[8UQ0:^8GP2ZR5/0ZXQJ0:V7F@2YQeL80:n=G`P0[XUL202ZQed0202XQE/0
ZHIL0:Z7G@2[R5h0[8UO0:f:H02^Rf40[haR202[QeL01P2_S5H0[h]G0:j:EP2^RUP0[XYJ0:j9G080
[HQL2@2/REl40:^8GP<0ZXMM0P2ZQEP20:V4E`<0Z8=F00@0Yh9E0:R2D`2XPU<0Z89C0`2WPE830:J0
D@P0ZHEE00@0Yh=C0:J2DP2VPU80YH5A0P2TP5020:=oC`0509ehB`2ONTd0XWe@0:F0D`2VPE@00P2W
PUD00`2VPE@0YH5?0:F1C`020:B0CP<0Xgm=00X0XWi<0:5lC`2PNdh0WgY=09iiC02MN4/0W7M:09]f
B@2JMDP0VWI60`2IMDD209QdA080Ug=30`2IM40509Qc?`P0UW920P2GLSh309Ia?@<0UG0l0`2FLCd2
09E`?0<0U6lk102>JSX208eY>@80S6Ph0P29ICD208YV=P0508]W=`2<J3P0S6Ph08eY>@2=J3/00`2<
IcX208]V>@80RVDh0140TFPl091W>`2>ICT0SF@h08aS=`2=I3P0SVDi08mV>P26HCD0R6<g08YU>@2<
Ic/0SFPl08aW>`2;ISX0RVDi08QR?@0208QR>`0308QS>@28HcL0R6<f00<0R6@d0`27Hc<208IR<P80
QF4a00H0Qf4l08IP>`26H3/0Q5hi08=M>022G3L2085K=P05081I<P21FS<0PU/d08=L=@22Fc@00P1o
F340101mERl0Ne@]07YI<01jFC0207UH;`0807QG;P1gERd0MeH]07IE;01iEc40N5H`07EC;@1cDB/2
079@:P80Le4[0`1kEC0207YD;`<0NE<^00H0M54[07EB;01eDR`0MU<]07MD;P1hEBl207UF<080N5<Y
101iE2X207QC:@80Mdl[00@0MThZ07E=:@1dC2P0Ld/W0P1bBRH02`1fDbd0ME8/07=@:P1aCRP0L4dW
075>:01cD2X0M54[06]>9P1/CbL0KU4Y00<0Ke8Z00<0KE0X06a?9`1[CBL01`1[CBL01P1^BRX0KDTY
06e9:@1/B2P0JdLW06Y69P80JDDU0P1^BRH01P1]BBD0K4PT06]78`1ZAR80JDDQ06Q480<0HTDS0P1Q
A28306138@80ITDV00H0I4DV06=69P1OAB@0Fd<Q05U17`1F?ad205m2800B06138`1P@bD0H48V0612
:01Q@bT0HD<[058i6P1F?Ah0Fd8S05m69`1QB2T0GdHW05a3901J@B80HDL^05m5;01K@BP0F3hU0P1G
?B@00`1I?bH0FT0W05U08@0205U08@80F3lP0`1I@24205Dm8@0405Hn8P1G?b<0EclS05Q09080FD4U
00<0FD0Q05Y18P1K@R<00P1K@R<0101I@240F3lP05Po801F?Ah205]19P0405Y09@1I?b@0EcdR05Hl
8@80EC/P00D0D3/N054l7`1B?B00E3lR05E08`0305I1900304dg7`1@>R80DcdU0080ET0X00<0DcdU
04li8@1<=Qh00`1<?2D204/k90<0BSXS01P0DS`W050j9@1>>2<0C3HQ04/e801<=R40CCLR04hh8`1<
>bL0BSTU04Pg8`15=200A3<O04Dd8016=B40AcHR03lf9@0n=B@0?C@S03`c8P0j<B00>2lN03L^7@0f
;A`303ha8@80?c8R0`10<b<02011;Ql0@2dN03h]7@0k:a/0>B`K03T^700j;ad0>C4N0`0j<b0[oooo
o`00:_ooool809me@`050:5fB@2PMDP0X7E809mdA`2MLTD00P2LLD@00`2KL4<0X7E80:1eB00609md
A`@0XWM4102QMT<0302NMD40WgI20:5hA02RNDD0XgY60:9iA@2QN4@0X7M309eh@`2NND@0X7]60:5l
A`80XWe800<0XGa70:1kAP2UODT00`2UODT20:AlB080Xg]7202TNdD20:ImB@<0YGa80`2TNdL70:Mn
BP80YWe90P2_O4l0302]ODd0Zge;0:UnB`2WOTP0Ygi60:IoAP2VOT40YWi30:MoA02WOTH0Z7m90:V0
C080ZGm=0`2ZPDd20:V0C0/0Z7m;00D0[89B0:^1D@2[PE40ZX1@0:QnCP020:MmC@030:IlC02XOd/0
Z7m;00H0Z7m;00H0Yh9E0:R2D`2XPU<0ZX9A0:^1C`2/PDh20:j0C0P0Zh5?00H0Zh1E0:^0D`2[P5<0
Zh5A0:^1C`2[PTh20:^2C0/0[8=?00<0Zh9>0:Z1C@2ZPDd00P2YP4`20:j5C@040:j5C`2^QE40[XEA
0:j4DP80[XAD0P2`QU@20:n5D`040:j4DP2]Pe40[H=A0:f3D@P0ZhIA0P2_QE<20;26E0<0/HME00<0
/XQF0;2;E`2`ReL00P2_RUH20:j9E@80[HQD0P2^RED20:f8E080[8MC0P2[QU820:V4D0<0ZhIB00<0
ZHA@0:N2CP2VPDd00P2XPdh00`2WPTd0YX5<0:F0B`020:AoBP030:=nB@2RODP0X7]60080X7]60P2O
NTD309iiA080VgE400/0W7I509egAP2LMTD0VWA309Ma@02FL3l0UWE009Ed?`2GLcl0Ug8n09Q`?@02
09Q^?00409Q/>`2BKCT0TVdi099]>@D0TF`h0P2?Jc/0102>JSX0S6Ph08]W=`29ICD208QT=00808MS
<`28I3@0RFDe08YV=P29ICD0R6@d08IR<P25HC4407mM;`@0P5h`00/0P5ha07iK<@1lFBl0NUL_07UF
<01iEC40NUHd07]G=@1hF340MeL`07EE;P0307=C;00607AD;@1eEBh0MED^07AD;@1bDR/0L50Y0`1_
CbP0101`D2T0JD/W06U;9`1YBbL206Y<:0<0JddY00@0JD/Y06Q::01XBRP0J4XX0P1WBBL206I89P80
I4HT00@0IDLU06I89P1XBRP0JD/Y0P1ZC2X806U<:P0406a>:P1]Cb/0KDl[06e?:`80KU0/0P1_DBd2
06iA:@80Ke8Z0`1`Db/00`1aE2`0Me@^07MD;P0307EB;00707MD;P1iES00NULa07=C:P1dE2/0MED/
07MG;P0407QH;`@0MULY201gF2X307QI:`80NEX/0P1nES802@1lES40NEH`07ME;`1eEBh0M5@]079E
;@1eEBh0M5@]07=C;002075A:P06079B:`1dE2d0MED^079B:`1cDb`0MED^0P1fERl01@1eEBh0Le</
079B:`1_DRX0KU4Y00<0KE0X00@0Ke8Z071C:`1aE2`0LE@/0P1`Db/03P1_DRX0KE0X06a?9`1/CbL0
JdhV07=F;P1bEBd0LE@/06mB:P1^DBT0K4lW06]>9P1ZCBD0LE@/0P1`Db/00`1_DRX0KU4Y06e@:002
06a?9`0306iA:@1_DRX0LE@/0080LE@/00h0Ke8Z06e@:01/CbL0J58]06I@:`1SC2X0H4TY0619:P1R
Bb`0IDda06M?<`1RBRP0Hd/Y06E=:`80ITh/00H0IDd[06A<:P1SBbT0GddY05e;9`1JB2@205U78`0;
05a:9P1OCBT0HDl[05m6:01OB2T0H4TZ05i9:P1MBRX0FDTX05I79P1EARD00P1JAbL305U69P<0F4DU
0P1B@BL205509P@0D3lU0`1<?2D204dm9P<0CShW00D0ASlS04Dn8P15?R80A3dQ04<l8002048k7`03
044j7P15>b80AC/R00H0AC/R0P17>24304Hg80@0ACHO00P0@3PS03lg8P0m=B00?3@O03/c7P0l=1l0
?CDP03hf8@<0>SDO0P0k=R0203`g8@0303dh8P0k=R80>cHR00<0>SDQ2`0i=20203Dc7P<0=S@O0`0g
=B0303@a7P0303Db7`0f<b00=S<P00<0=c@Q00L0=S<P03Db7`0d<Ah0=34N03Db7`0f<b00=c@Q00<0
<S<S0P0a<R83030a8@0303<d900b<b<0<34Q00<0;RlO00<0<34Q034b8P0`<Qd00P0`<Qd2034c7P<0
<S@O0P0e<Ql01P0d<Ah0<c0M03@a7P0e<Ql0=c@Q03Tf8`80=34N0`0e<Ql303Hc8004034c7@0b=1h0
<cDO03@f8080=CLQ00<0=3HP03<e7`0i=b801`0i=b800`0h=R40=cDP03Hd7`0203@b7@0303Hd7`0g
=B00>3HQ00P0>SDQ0P0h=R4203Le8080=S@O0P0e<ah00`0d<Qd0=C<N03Hd7`0203Le800703Hd7`0e
<ah0<c4L03Hc800e<Ql0=34N03<`7@0203@a7P80=S<P100b=1l00`0a<ah0<38M030b7@0202la70<0
<S0K0P0c<A`;03@b7@06034`700b<Ad0<S4M03<b7P0d<al0=C@P0P0f=B401P0f=Qh0>3HO03Pf7`0k
=R00?CLQ03lg8P80@SLS0200@SDR04<f8`14>280ACTQ04Lk8@18?B40BChR04Xo8@1:>BD0Bc/T04`l
9@1=?B@0CclU0511901A@R<0DT<T05A48P1EAB<0F4HR05]78P1OBB@0HD/T06=<8`1TCB@0IT`W06M=
:01XCRT0JDlZ06]A;01/DRd0KE<^06iD;`80LUDY00h0LeHZ07EH;01fFBd0MeX^07QK;`1iG300NU//
07]L;@1lGBh0OEh_07mP<@20HC80PF8c089S=080QVD`00<0QfHa08QW<P29J3<00P2:JC@04P2;JSD0
S6Pd08aX=02>JSH0Sf/g095]>@2BKSX0Tflk09A`?02BLC/0Tg8l09Ac?@2EM3h0UgI009Qg@@2IN480
VWU309ahA0@0WGU50`2NNTH209ajBP80WG];0`2NO4`01`2OODd0Xgm;0:B0C02TP4`0YH5=0:J2CP2W
Pdl00P2XQ5050:R6EP<0YhEE0P2/RUX20:f;F`<0[XaL00<0[heM0:n>F`2_SU/00P2_SU/20;2?G0<0
/I1M102bT6830;6?H@040;2>H02dTV@0]99T0;FCI@80]YAV00<0]iEW0;RFJ02hUVP00P2eTVP0102f
TfT0]iAZ0;REJ`2iUV`20;ZGK@P0^YQZ202iUfT30;RFJ0<0]iEW0P2fU6H80;NEI`P0^IMY2P2hUF/2
0;VFK080^YM]0P2kV6h80;NEI`80]IMU00@0]IIW0;BEI`2dUFT0]9A[0P2cTf`0202dTFL0]Y=Y0;RE
J`2hUF/0]iAZ0;BAI`2aSV@0[haR0P2gU6X30;JCJ@<0]I9X102aTVH40;:CI`030;:@HP2cTF<0]99T
0080]I=U00<0]99T0;>AH`2bT6800P2eTfD20;BBI080/i5S2P2bT680102gUFL0]YAV0;BBI02dTV@3
0;:@HP040;>AH`2dTV@0]99T0;BBI0H0/i5S00<0/XmU0;>@IP2dTFL00P2dTFL00`2bSfD0/8eS0:n<
HP020:j<GP80[heO00@0/8iP0;6?H@2bT680/Y1R0`2bSfD30;6>I080/8eS00<0/hiQ0;:=H02aS5l0
0P2aS5l02`2cSV40]I1S0;JAI02eTVP0]95W0;:?I@2aSV@0/8eS0;6>I02bSfD0/i1V00<0/HmQ0P2`
SV030:n=G`<0/HmQ0P2`SV030:n=G`80[HYP0P2^Rf401`2_S680/8eS0;2=H`2`SF<0/Y1R0;2>H02]
Red00P2ZR5X00`2[RE/0[XaN0;2>H0080;6>I080[X]Q0P2_S680102`SF<0/HiT0;6>I02aSV@40:j<
GP@0[heO102^S5h40:n=G`<0[haR0P2`SF<30;6>I080[HaI00<0[H]K0:f;G@2^S5l00P2^Rf400`2^
Rf<0/HaO0;:=H0020;:=H0040;6<G`2`Reh0[XUL0:f8F`80/8iP0`2_SEl30:j<GP80[haR0`2^Rf42
0:f:H080[8UO0P2`SV020:n=G`@0[XaN202`SF<80:n=G`080;2<G02_Re/0[XYJ0:f9F@2^RUX0[h]K
0;6=G@2cSel80:n<HP80[HeN00@0[XaN0;2;GP2`Reh0/H]N0P2cRUh00`2_SEl0[XaN0:f;G@020:b:
G0030:f;G@2^S5h0[heO00P0[XUL0P2/RF40102/REl0ZhQN0:^9G02[RE`20:Z8FPP0[heO202^RE`8
0:b9G`80ZXMM00H0ZhQN0:b9G`2]RV00[X]Q0:n<HP2`SF<80:b8F0060:n<EP2_ReL0[h]G0:n;F@2^
RUX0[XUL0P2^REd;0:b9G`D0ZhQN00@0[8MJ0:^6F@2[QUT0ZhII0P2ZQEP20:V4E`<0ZXAE0`2YPe@3
0:R2D`P0ZXIF0`2XQ5@00`2WPe<0YX9B0:J2DP020:F1D@060:1kCP2QO4l0Y7mB0:N2E@2XPeH0ZHAG
0P2XPeH20:N3D@80YX9@0`2UPDl01`2TP4h0XgiA0:9mD02QO4l0X7]>09mjC@2NND`00P2MN4/309mk
B`80WWY:0`2MNDT609]f@P80VWE1202KMdL209Ye@@80VGA00P2HLcl209Mb?P80V7<o0P2GLSh309Ia
?@0409E`?02AKCd0TFdm095]?@80T6`l0`2?Jc/00`2<J3P0SFTi08eY>@0208iZ>P80Sf/k00<0T6`l
08mZ?@2>JC`00P2>JC`208eX>`80S6Lj00/0UVe109E/@02CJSh0TVTm095X?02BJCd0TfXn09A[?`2:
ICT0RfHj08eX?00208iY?@0308eX?02;ISX0RVDi0080RF<l00<0RF@j08UT>029I3L00P29ICD01029
IC<0RFDe08UU=@29ICD208QT=0<0Qf<c0P28HSd01027HC`0QV0k08EO>P24GST208=M>005089K<P23
G3<0Q5dd08AM=023G3<00P21FS400`1oF2l0OEH]07aK<00207]J;`80NUT^0P1iF2d01@1hEb`0NeTc
07YH<P1gEBl0ME<]0080M58/0P1eDbd207eG<P80O5Ha0P1kEC0207YD;`@0N5D_101iES0807eH;P80
O5@`00<0Ne<_07YB;P1iDBd00P1hD2`0301gCb/0N5D_07IC;@1dDB/0Le0Z079?:@1cD2X0M54[07EB
;01bDR/0Le</07EE;P80MUH_00<0MED^07AD;@1cDb`00P1cDbd2079B;080LE4[0P1`D2X01P1cCbd0
LTh/079>;01aCB/0L4`Z06m;:@80KTXX0`1^BRH206e99@80K4PT00@0JdLS06M;9P1WBbH0Id/V0P1V
BRD306E9900806Q59`1XAbP0J4LX06I7:01SARH0GT@S05]38@1I@Al206548P0406959@1RABL0HT@X
0694:080HT@Z00/0FChP05a18`1OA2H0HTLY06A9:`1SB2X0HDHX06159`1QAR/0H4DZ05i3:00505a1
9PP0GD8T0P1J@b@205]49@0705a59P1MARL0GDHW05e69`1K@280G44S05e2900205i39@0:05a18`1J
?b40FSlQ05Tn801N@bH0GD8U05a1901K@2<0FSlR05Tn8@80F3dP0P1E?Ql0101F?b00Ed0Q05Q18P1I
@R<205Y39008058l901C?BD0EClW05M1:@1F@2P0E3hV054k8`1?>B4204lm9@80CS`T0P1=>b<204`j
8P0=05<m9P1B?2D0D3XS04hh8@1==b00CSPQ04li8P1@>R<0CS`V04dk9@1:>280B3HP04Le7`0204Pf
800904Tg8@15>RP0ACXX04@i9`12=bD0@CHT03ld8P0n<b40?C8P00<0@3<R0`11=2<2048e900404Hc
8P15<R40@S4O040a7P80?S4N00<0?c@P040e8@0l=1l00P0l=1l[ooooo`00:_ooool809me@`80X7E8
00@0WgA709icAP2NLdH0WG950P2LLD@809mdA`050:AiAP2SN4D0XgQ50:9gA02QMT<00P2PMD800`2O
M440X7M30:5hA0030:9iA@060:1g@`2OMT80WWE109eh@`2NND@0X7]60P2RODP00`2QO4L0X7]609mj
A@030:ImB@80YGa80`2TNdL80:AkA@80YGa80`2VODT<0:MnBP060:mlC`2]ODl0[Ge=0:]mB`2YOT/0
Ygi80P2VOdH0202VOT40Ygm40:MoA02WOTH0Z7m90:QoB`2XOT`0ZGm=0P2ZPDd20:V0C0<0Z7m;00<0
Ygi:0:QoB`2XOd/01P2XOd/20:^1C`030:Z0CP2YOdd0Z7i<0080Yge;00<0YWa:0:QoB`2XOd/01P2X
Od/01P2WPUD0Z89C0:R2D`2ZPU40Zh5?0:b1CP80[X1<202[PDl01P2[P5D0Zh1C0:^0D`2[PE40Zh5?
0:^2CP80Zh9<2`2/Pdl20:^2CP<0ZX5=0P2^QDd0102^QDl0[XEA0:j5D@2^Q5820:j4E0<0[hEC0`2^
Q5820:f3D@P0[8MB00@0[XAB0:n5D`2_QE<0[hEC0P2`QU@20;67E@<0[HQD0`2^RED20:n:EP80[XUE
0P2]R5@20:b7D`80ZhIB00P0ZHA@0:Z5D@2[QU80[8MC0:^6DP2ZQE40Z8=?0:N2CP80Z8=>00<0Yh9=
0:J1C02UP4/00`2TOdX0102SOTT0XGa70:5lA`2QO4L20:1kAP<0WgY50P2LMd<209ehA00409ag@`2J
MD40V7<o09Mb?P80U7<n00<0UW8n09Mb?P2ILCh00P2JL3h00`2KKch0U6lk09A_>`0209=^>P0;099]
>@2AK3P0T6/g091[=`2@K3`0Sf/k08iZ>P2=JCT0RfLg08YV=P29ICD00P28I3@01`29ICD0RVHf08YV
=P2:ISH0R6@d08MS<`25HC402020GS001P1nG2h0OE/^07]I;01jEbd0NEH^07QE;`80NEDa00<0N5Pa
07MG<01fERl00`1dE2d207EE;P80Le</00H0M5@]07=C;01bDR/0LE4Z06m?:01^CRL206a>:P80JddY
101ZC2P306U;:@80J4XX0`1WBBL206E79@0406I89P1WBBL0IdTW06Q::080JD/Y201XBbT206Y<:080
JddY0`1/CRX00`1]Cb/0KE0X06iA:@0206iA:@80Ke8Z0P1`Db/207IC;@<0M54[00<0MU<]07QE;`1i
ES000`1bDRT01@1cDbX0MED/07QH;`1kFc80O5`c00<0MeP/0`1fEb/307EF:P80MUL[0P1gF2`307QI
;@0>07UJ;P1nES80OEDa07aF<@1iES00MeD_07EE;P1dE2d0LUD]07QH<@1fERl0M5@]079B:`1aDBX2
079B:`0407=C;01bDR/0Le</07AD;@80MED^00D0M5@]07=C;01bDR/0KU4Y06mB:P03071C:`0306iA
:@1]D2P0K4lW0080L5<[00<0Ke8Z06iA:@1]D2P00P1/CbL02@1[CRH0LUD]075D;01`Db/0Ke8Z06iA
:@1]D2P0K4lW06]>9P0906iA:@0306mB:P1`Db/0LUD]0080LUD]00X0LE@/071C:`1ZDR`0J50Z06I>
:P1SBbT0HdX[06A;;@1VCBl0J4hc0P1SBbT05P1TC2X0IDd[06E=:`1TC2X0Hd/Y069::01QCb/0GddY
05a:9P1JB2@0FDLS05]99@1MBbL0GddY05m6:01OB2T0H4TZ05i9:P1MBRX0FDTX05I79P1EARD205Y7
9`<0FDHV0`1HABD305919`80DD0V0`1@?bD304dm90<0C3`S0P1;>b8804Hl8@P0AC/R0P15>B4304@h
80@0@cLO00<0@CTT03lg8P0n=R400`0l=1l00`0m=B00?SHQ03dh8P0303`g8@<0>cHP00<0>SDO03/f
8P0k=R800`0j=B4;03Td8080=cDP0`0f=1l303Dc7P80=34N0`0e<Ql303Hc800303Pe8P0g=240=S<P
0080=C8O00<0=S<P03Ld8@0h=B800`0b<b<2034b8P<0<34Q00<0<c@T038c8`0`<B400`0_<202030a
8@<0<38M0P0a<ah3038d7`0803Hc800e<Ql0=34N03<`7@0d<Ah0=C8O03Ld8@0h=B8203@a7P<0=C8O
0`0f<b00200d=R00<cDO038d7P0b=1h0<cDO03@f800e=b40=SPR2@0h=R401`0g=B00=C<N03@b7@0d
<Qd0=C<N03Le800h=R40200j=B4203Pf8@80=cDP0P0f=1l203Dc7P0<03Le800h=R40>CLR03Tg8P0h
=R40=S@O03@b7@0c<A`0<RlL03<`7@0d<Ah0=C8O0P0d<Ah0100c<1d0<RlL038d7`0b=1l3034c7P<0
<38M00<0;c4L038`6`0b<1/00P0c<A`303@b7@T0=C<N00H0<c4L03@b7@0d<Qd0=C<N03Hd7`0g=B02
03Pf8@0603Pf7`0i=b00>cHP03dg8@0o=b80@SLS0P14=b@204@h8P0<04Di8@17>b40B3dQ04Tn801:
?b40Bd0P04dk9@1>?2H0CcdU050o9@1B@BD0Dd8T0P1DA2<0201EAB<0F4DT05U78`1LB2<0H4XU06=;
9@1UC2@0ITdU0P1ZCRT01P1[CbX0KE4/06iB;@1_Dbh0L5@_075E<080LeHZ00@0M5L[07II;@1gFRh0
NE``0P1jGC4207aM;P0607eN;`1oH340P64b085R<`22Hc@0Pf@e0P27IS400`28Ic80RFPc08YY=002
08]Z=@0?08a[=P2?JcL0Sf/g091/>02BKSX0Tflk09A`?02ELCd0UW8n09=b?02DLcd0UG@n09Ie?`2G
MT00VGQ20080VWU30`2NNTH209mkA`<0X7a80`2MNd/209ilC0<0Wge=0P2TP4`00`2UPDd0YX9>0:N3
C`020:R4D0040:V5D@2YQeL0ZHMG0:V7E`D0ZXQH0`2]Re/20:j<G0<0[heM102`SUh20;6?G`<0/Y1P
0P2aSf430;:@HP<0/i5S0P2dTV@0102eTfD0]YAV0;JDIP2gUFL20;RFJ080]Y=Y0P2gU6X0102hUF/0
^II/0;ZGK@2jUfd@0;VGJ@<0^9IX0`2gUFL20;JDIPP0]iEW202iUfT:0;REJ`<0^II/0`2jUfd80;NE
I`80]9IT00H0]9EV0;BEI`2eUVX0]IE/0;FEKP2fUVl20;NDJP030;JCJ@2eTVP0]95W0080/i1V00<0
/XmU0;NDJP2fTfT00P2fTfT20;FBJ080]95W102bTfL40;6BIP030;:@HP2cTF<0]99T0080]I=U00<0
]99T0;>AH`2bT6800P2eTfD20;BBI080/i5S0P2bT6880;6?H@040;NEI`2fU6H0]99T0;BBI0<0/i5S
0P2dTV@20;FCI@040;BBI02cTF<0/i5S0;:@HP80/HmQ00<0/XmU0;>@IP2dTFL00P2dTFL00`2bSfD0
/8eS0:n<HP020:j<GP030:n=G`2`SV00/HmQ0080/Y1R00<0/i5S0;>@IP2cT6H00P2bSfD30;6>I00A
0;2=H`2cSV40/XeP0;6<G`2`Reh0/HaO0;:=H02dSf80]I1S0;FBJ02dTFL0/XmU0;6>I02`SF<0/HiT
0;:?I@2cT6H00`2bT6820;6?H@<0/8iP00@0/Y1R0;6?H@2aSf40/HmQ0P2`SV020:n=G`<0[X]Q0P2_
S6830;2=H`030;:@HP2`SV00[H]M0080ZhUK00<0[8YL0:j<GP2`SV00202aSV@30:n<HP<0/8eS0P2a
SV@01@2/RU`0[H]M0:f;G@2^S5h0[heO0080/8iP00<0/HmQ0:n=G`2_SEl00P2_SEl40:j<GP80[haR
0P2`SF<30;6>I0060;:?I@2_SU/0[hiK0:j<G02^S5h0[XaO0P2]RV00102]RV80/XeP0;6<G`2`Reh2
0:n:G@030;2;GP2aS5l0/HaO00<0/HmQ0P2`SV030:n=G`80[haR102^Rf430:f:H0<0/8iP0P2_SEl3
0:j<GPP0/8eS202_SEl0202`S5`0[h]K0:n;F`2^RUX0[h]K0;2<G02aSEd0/XiN202_S6820:n?H004
0;2>H02bSF00/XeP0;>=H080]HaP00<0[heO0:j<GP2]Red00`2]Red00`2^S5h0[heO0:n:G@070:n:
G@<0ZhQN00<0[8UO0:b:G@2/RUd00P2]Reh80:n=G`P0[hYM202^Rf401P2/REl0[HYP0:f:H02^Rf40
[haR0;2=H`80/HiT202_Re/01P2_S5H0[h]G0:n;E`2_ReT0[h]K0:n:G@80[hYN202]RV050:b9G`<0
[HYP0`2^RE`30:f8F`80[8MJ0P2]QeP40:b6E`<0ZhEF202/R5P0102[QeL0ZXIF0:Z6EP2ZQUH30:V5
E@070:R4E02TOe80YH1C0:R3EP2ZQEP0ZhII0:b7FP020:^6F@<0ZXIF0P2YQED30:R4E080YX5D00<0
YH1C0:AoDP2SOU400P2ROE000`2QO4l0YX9B0:F1D@020:F1D@80Y81@0P2SOdl809mjAPP0XWi>0`2N
NDD209ehA0<0W7M30`2JMD4309Ud@080V7<o0P2FLT8209Ea@@<0U71000<0Tflo099^?P2BKSh00`2C
Kcl309A`@0<0TVe00P2AK3l3091[?P0309YdA`2HLTD0Ug5400<0UFm200<0UW1309MaA02@Jch00`2A
K3l01@2@Jch0SfXm08eX>`2<IcX0SFM00080SFPn00<0SFPl08eX>`2=JCT00P2=JCL308aX>080RfLg
0`2:ISH208]U?P0308YT?@29Hc`0R68k0080Qf4j00<0QV0i08IO=P27H3L00P27H3L01@26GcH0Q5dd
08AM=023G3<0PEXa00@0Oe`b0P1nFc4207eJ<00407mL=01nFc<0O5Ta07YG;`80NEH^00@0NUL_07]H
<020FS<0P5Xc0P1oFC8307iH<@0307eG<01mFS80OEXb00<0O5Ta0`1kF30208=N=0@0PUdc0P23GS@2
089K=004085J<`20FC80OePa07iG<080OEH_00@0NUL_07UF;P1hEBd0Me@/0P1fDb/01@1gE2`0N5D]
07QH;`1iFC00Ne/b0080O5`c00<0Ne/b07UI<01hF2l00P1jFS<01P1iFC80N5Pa07IF;`1eEBh0M5@]
07=C;080N5@b00<0Me<a07IB<01eDBl00P1dD2h00`1cCbd0KT/U06m<9P0206m<9P<0L4dW00<0LDhX
06i@;01^D2`00P1]Cb/306a>:P0906]=:@1[B2P0K4TY06]::@1YBbT0ITTW06989@1PAR<0GDDQ0080
ITPT00<0ITPV06I7:01VAbX00P1VAb/0101VARd0I4LW06A79`1UB2P206I9:@0706M::P1XBb/0J4/[
06539`1RA2P0HdDY06A6:P0206=5:@040694:01Q@bL0HdHV06=69P@0I4LW0P1SARH30658:P<0HTT[
0P1SBR`00`1P@b<0HD@T06959@0206=69P040654901O@R80Gd8R05i18@80HT@X00@0HD<W06129P1O
@BD0Gd4U0P1N@2@305Y18`80Fd8T00<0GD@V05i59`1NABL00`1K@bL01@1J@RH0FD4U05Lo8`1F?R80
ECdQ0080E40W0P1C?bH3058n9@06054m901G?bL0EShV05Dm9@1D?2@0Dc/S0P1D?2@01@1E?BD0DclW
054m9@1@?2@0CSXR00<0CCTQ00T0CSXR04/n:`1;?R/0BSdZ04Pk:017>RL0ASTV04Dh9@14=b@00`16
=B<204Lf90<0B3LU00P0CSTX04`g9P19=RD0ASDS04@e8P13=R<0A3LT04@i9@<0@3DQ:oooool002[o
oooo202NM4800`2PMDP0WgA709mdA`0209icAP80WG9500<0W75409icAP2OM4L00`2OM4L30:1eB008
0:EjA`2TNDH0XgQ50:9gA02QMT<0X7E209md@@2NLd030:9iA@80XGQ400H0WgI209ie@@2NMD40X7Q4
0:5iA@2SNdL20:AlB0030:=kA`2RNTH0XGU50080Yga90P2VNdP20:EjA`80Y7U6202TNdD20:ElB003
0:ImB@2WOTX0Z7m;0080ZH1<00@0ZX5=0:ImB@2VODT0YWe91@2WOTX01`2XOd/0[Ge?0:amC`2/OTd0
ZGi;0:QoB`2VOdP00P2TP4H01P2WOd80Ygm40:MoA02WOTH0Ygi80:MnBP80Yge;0`2YP4`30:QoB`80
Ygi:202XOd/20:Z1C@80ZH1<00@0Z7m;0:MnBP2WOTX0Ygi:202XOd/01P2WPUD0Z89C0:R2D`2ZPU40
Zh5?0:b1CP80[X1<202[PDl01P2[P5D0Zh1C0:^0D`2[PE40Zh5?0:^2CP80Zh9<302/Pdl40:^2CP80
[HA<00@0[HA>0:f4D02]Q500[H=A0P2]Pe<20:n5D`H0[XAB202]R5<40:j4DP80[hEC0P2`QU@20:Z5
D@040:^6DP2/Qe<0[XUE0:n:EP80/8]G0P2^RED20:f8E080[8MC0P2[QU802@2ZQE40ZhIB0:b7D`2]
R5@0[8MC0:^6DP2YQ500Z8=?0:R3CP020:N2C@80YX5<0`2UP4/00`2TOdX0XWe80:9mB0030:5lA`<0
X7]60P2NND@209eh@`0409ag@P2KMT40VWE009Ud?`80U7<n00<0UW8n09Qc?`2JLSl00P2LLT001`2M
LD00UW4m09Ia?@2EL3`0U6lk099]>@2AK3P00P2@JcL01`2AKCd0T6`l08m[>`2>JSX0S6Ph08]W=`2:
ISH00P29ICD01`2:ISH0RfLg08]W=`2;IcL0RFDe08QT=026HS800P22H384085O<@80P5h`00H0OE/]
07aJ;01kFB`0NUP[07UF;01iERh207QE;`0307QH<@1gEc00MeL`0080MUH_0P1eEBh04@1fERl0LU8[
07=C;01eEBh0MUH_07EE;P1bDR/0KdlX06e=9P1_DBd0KU0/06e?:`1/CRX0JddY06Y<:01YBbL0J4XV
00<0JT`Z0P1YBbT306Q::080ITPV101WBBL206Q::0P0IdXX0P1XBRH206U;9`<0JT`X00<0JddY06e?
:@1]CbT00P1]CbT206i@:P80Ke4[0100M58/07=A:`1bD2X0LDlY079@:P1cDB/0ME<]07ID;P1eEB`0
M5@[079B:@1aDBP0LU8Y07EE;01hF2l0NUXa0P1hFBd00`1gF2`0MUL[07EF:P0307AE:@0407=D:01f
Eb/0MUL[07IG:`80MeP/0`1hFBd207eE<@0307]E<01hEBl0MU@^0080M5@]00L0LE@/07UI<P1hF340
MED^07=C;01bDR/0LE4Z0080LU8[0`1cDb`207AD;@<0Le</00P0KU4Y06mB:P1aE2`0LUD]075D;01^
DBT0JdhV06U<90<0M5L_00<0LeH^079E;@1bEBd0101aE2`0101`Db/0Ke8Z06iA:@1]D2P506a?9`03
06e@:01^DBT0Ke8Z0080Ke8Z00@0KU4Y06mB:P1`Db/0LE@/0P1cERh207AG;`0806eD;01/Db/0JDlZ
06M=:P1UBbX0IT/]06M<;`1XCC0506A<:P0706=;:@1RBRP0HTXX065?:`1OCBT0GD/W05]99@0205Y8
9080G4XV00P0GdHX05m8:@1PBBX0GTTZ05e::P1IBBP0ETLV05E69@80FTLW0`1IARH305Q59@80Dd8X
0P1B@BL205509P80D3lU0P1??bD0101>?R@0CCdS04/k8@1:>R0204Ti7`80ASXP0`17>b4304Pl8PP0
AC/R0P14>R4304<i80@0@SPO00<0@CTT040h8`0n=R400P0l=1l00`0m=B00?SHQ03lg8P0203lj9004
03hi8`0m>280>cHP03Xe7`80>C@N0P0k=R8303Xe8@/0>C@P00D0>3HQ03Le800g=B00=S@O03Dc7P02
03@b7@0303<a700e<Ql0=C8O00@0=C8O0P0f<b000`0i=R<0>3DR03Ld8@0203Db7`0303Ld8@0h=B80
>CHS00<0<S<S0P0a<R83030a8@80<S<S0P0a<R84030a8@<0<38M0P0a<ah3038d7`0803Ld8@0f<b00
=34N03<`7@0d<Ah0=C8O03Hc800g=24203@a7P<0=C8O0`0f<b00200e=b40=3HP038d7P0`<Q`0<C<M
03<e7`0f>280>3XT200h=R400`0g=B00=S@O03Dc7P0203@b7@0303Dc7P0f=1l0=cDP00P0>SDQ0P0h
=R4203Le8080=S@O0P0e<ah203Tg8P80>SPS00L0>3HQ03Hd7`0d<Qd0<S0K030]6P0b;a`0=34N0080
=C8O00<0<c0M030]6P0^:aP02@0`<Qd303<a70<0=38M2P0e<ah203Lb700403Pc7@0i=1h0>SDO03Xe
7`80>cHP0P0l>1l05@0n>200@3PQ04<h8P14>280ACTS04Lh8`17>240B3TR04Tk8@1:?240C3hQ04do
8P1>@B40Cd8R054m9@1B?RH0DclV05A09@1F@bD0Ed@T05Q59@0205U69@0E05]79P1LB2D0H4XU06=;
9`1VC2L0JDdV06Y>9`1[CbP0K50Y06eA:P1^DR/0L5@]075E;P1bERl0LeL`07AG:`1eF2`0MUT]07MJ
;P1iG300NUda0080Nehb00T0OEh_07iO<01oH340P64b089S=023I3D0Q6Df08EV=`28Ic800P29J3<0
0`2:JC@0RfXe08a[=P0208e/=`80TVhj00H0Tflk09A`?02ELCd0UW8n09Mc?`2HM40209Ac?@0409Ed
?P2GMT00V7M109Yi@`80VgY40`2ONdL01@2PO4P0XGe90:9nBP2ROTX0Xgm;00<0WWa<0P2OODd30:1n
CP80YH5=00<0YX9>0:N3C`2XQ5000P2YQE400`2ZQU80ZXQH0:Z8F0030:^9F@<0[8YJ0P2]Re/30:j<
G0<0[heM102aSf430;:@HP80/i5S0P2aSf40102bT680/i5S0;>AH`2dTV@20;FCI@80]99T00@0]I=U
0;JDIP2fU6H0]iEW0P2hUVP30;NDJP030;REJ`2iUV`0^II/0080^YM]402iUfT30;RFJ0<0]iEW0P2f
U6H80;NEI`P0^IMY2P2hUF/60;VFK0P0]iEW0P2cUF<0102dUFH0]IIX0;FFJP2fUVd20;NGL0070;VF
K02gU6X0]I9X0;>@IP2bSfD0/i1V0;BAI`040;JCJ@80]I9X0`2dTFL40;:CI`@0/I9V00<0/Y1R0;>A
H`2dTV@00P2eTfD00`2dTV@0/i5S0;:@HP020;FCI@80]99T0P2cTF<20;:@HPP0/8iP0P2fU6H20;FC
I@D0]99T00X0]YAV0;FCI@2dTV@0/i5S0;:@HP2aSf40/8iP0:n=G`2bSfD0/i1V0`2dTFL0102bSfD0
/8eS0:n<HP2^S5h20:n=G`030;2>H02aSf40/Y1R0080/i5S0`2cT6H20;:?I@<0/HiT00<0/hiQ0;:=
H02aS5l00P2`Reh02`2bSF00]8mR0;F@H`2eTVP0]95W0;:?I@2aSV@0/8eS0;6>I02bSfD0/i1V0080
/i5S0`2bT6830;6?H@80/Y1R0`2aSf430;2>H0@0[haR102`SF<00`2bT680/8iP0:j<GP020:b:G003
0:f;G@2^S5h0[heO00P0/HiT0P2_S6860;2=H`080:^9F`2/RU`0[H]M0:j<GP2_SEl0/8iP0;6?H@2b
T6840:n=G`@0[XaN0`2`SF<30;6>I080/XmU0100/I1M0;2?G02`SUh0[heO0:j<G`2]RV00[8UO0:b9
H@2bSF00/HaO0:n:G@2]R5/0[XUL0;2;GP2cSV40]I1S0P2bT6820;6?H@<0/8iP00<0[heO0:n<HP2_
S6801`2^Rf420;6?H@80/8iP0P2_SEl20:j<GPP0/8eS202_SEl30:n;F`80/8aL0P2aSEd00`2bSUh0
[haR0:n<HP060:n<HP80/91Q00@0/HmQ0;>>H@2cSV40]8iQ0P2fSF400`2_SEl0[XaN0:j<GP040:j<
GP030:n=G`2_RUd0[hYM00H0[hYM0P2[RE/20:b:G@040:f:H02^Rf40[haT0:n<I0P0[heO202_RUd8
0;2=H`030:j;H@2_S680[haR0080/8eS0P2aSV@00`2bSfD0/HeM0;6=G@060;6=G@060:n<EP2_ReL0
/8aH0;2<FP2`S5`0/8]N0P2aS6080:j;H@<0[HYP102^Rf40102_S680/HaO0;6<G`2aS5l20;2;GP<0
[hYM0P2`RU/20:n9FP@0[XQI00<0[HMH0:j:FP2^RUX01P2^RUX30:f9F@D0[8QH00@0Yh9E0:V4E`2[
QUT0[HQK0`2^RE`40:f8F`80[8MJ0`2[QUT30:V4E`80Z8=F00<0Yh9E0:J1E02VPE@00`2XQ5@20:N3
D`<0YX9B102SOTX40:AoB`P0YH5A0`2SOTX20:9mB@<0XGa80`2NNDD209ehA0<0W7M30P2KMdL209Yf
AP<0VGE500<0V7A409UeA@2IMDD01@2IMDD0102JMTH0Ug9509MbA@2GLTD209IaA0<0UG130140VgI9
09YeB02HLdH0Ug9509IaA02GLTD0V7=609UdA`2HM4@0Ug=309Ib@P2ELD40Tflo099^?P2@K3`0Sf/k
095/@P02095/@003095/?`2AKCd0TFdk0080TFdi0`2@K3`208m[>`<0SVXj0P2>JCl208eX?P80S6Lm
0P2;IS`01@2<ICX0Rf@i08]T>@2;I3T0RV<h0080R64f0P27H3D708EP=00508AO<`25H3H0Q5le089M
<`21G3800P20Fc401021G380PUdc08AO=@24GcD208=N=0<0PUdc00L0PE`b08=P=P22GcD0PUle085N
=020GC<0Oe`b0080OU/a00<0QV4g08EP=P24GcD00P23GS@00`24GcD0QF0f08IQ=`0208EN=@0308AM
=023G3<0PU/b0080PEXa00@0P5T`07eJ<01mFS00O5T_1@1kF2h04@1mG340OUdb07mN<`20Gc@0Oehc
07iM<P1lFc00NeX_07mN=@1nGC@0OE`c07]J<@1iF2l0MeH]07IE;01eE2/0NeLc0080NUHb00<0NEDa
07QD<01gDbl00P1fDRh2071=9@04075>9P1bCbL0M54Y07EB:P80MU<[00@0Le<]079B;01bDR`0LU8/
0P1aDB/2071@:P80L4`Z00H0L4h[06m>:`1/CRX0JDdX06M;9P1SBB@206e=9`0406a;:01/BbX0K4//
06]9;@80JdT^00<0JD`Z06Q;:@1VBBL00P1UB2H01P1WBRP0JD`Z06]>;01RABD0I4LW06M::P80JD`/
00D0J4/[06I9:@1TAbL0J4/Y06U<:P0406Y=:`0306U<:P1XBbT0IDX/00L0IDX/00<0I4LU06E89P1V
BBL00P1WBRP0101UB2H0HdHT06=6901RAB<306E8:P0306A7:@1SARP0HdHX00@0HTDW0P1QA2H02@1R
ABL0HdHX06A7:@1VBB/0I4//06=::`1PAbP0GTDV05a3900305]28`80Fd<W0P1J@RH305U19@0305Q0
901K@BH0Fd4V00H0FT0U00D0FD4W05Q09P1G?bD0EShT05Dm8`0305@l8P060510:@1??bP0CShW04dm
9P1<?2D0Bc/T0P1:>R<304/i8`80C3XT0`1=>bD0201A>RP0D3TW04dh9@19=b<0AcHR04Hg8P15>B<0
ASXT0`17>2<[ooooo`00:_ooool809id@P80WgA7102NLdH209ebA@<0WW=600<0WgA70:1eB02PMDP0
0P2QMTT0202UNTL0Y7U60:=hA@2RMd@0XGI30:1e@P2OM440WW=00P2SNTH00`2RNDD0X7M30:1g@`03
09mf@P030:9iA@2SNTH0Y7]70080YGa800<0Y7]70:9iA@2QN4@00`2XNTP20:MiA`<0YWQ6202TNdD2
0:ElB0030:ImB@2WOTX0Z7m;0080ZH1<00<0ZX5=0:ElB02UO4P00P2VODT20:MnBP<0Z7m;00H0[7e?
0:YnC`2ZOTd0Z7m;0:MoB`2TOdP20:>0AP060:Mo@P2WOd@0Ygm40:MnAP2VODL0YWe90P2VO4X20:V0
C0<0Z7m;0`2WOTX80:QoB`030:V0C02XOd/0Z7m;0080Z7m;0`2WOTX80:QoB`060:N2E@2XPU<0Z89C
0:Z2D@2[PDl0[85>0P2^P4`80:^1C`060:^0E@2[P5<0Zh1C0:^1D@2[PDl0Zh9>0P2[PT`@0:b3C`80
[HA<00@0[HA>0:f4D02]Q500[H=A0P2]Pe<60:j4DP80[hEC202]R5<30:f3D@<0[XAB0P2_QE<0202X
Pdl0ZHA@0:Z5D@2[QU80[HQD0:j9E@2_RUH0/8]G0P2^RED20:f8E080[8MC0`2[QU801`2/Qe<0[HQD
0:j9E@2]R5@0[8MC0:Z5D@2YQ500102WPTd50:J1C080Xgi90P2RODP40:5lA`050:1kAP2ONTD0WWU4
09eh@`2LMd800`2KMT4209Ed?`0309Mc?`2IM400Vg=00080WG=100L0WW9109Mb?P2GLSh0UW4m09E`
?02CKSX0TVdi0080TF`h00L0TVhn095]?@2@K3`0Sf/k08eY>@2<J3P0RfLg0080RVHf00P0RfLg08aX
>02<J3P0S6Ph08YV=P28I3@0Qf<c08AR=080Pf4c0P22H382085O<@09081N<01mFb/0OE/[07eK;@1l
FRd0NeP^07YG;@1iERh0N5D]00@0N5Pa0P1gEc0207IF;`0807=C;01dE2d0MUH_07MG<01fERl0Le</
071@:@1^CRL2071B;P0406mA;@1]Cb/0K4hZ06Y<:080JD/W0`1[CB/206Y<:P<0JD/Y0P1XBRP406M9
9`80ITPV201UB2H206M99@80J4XV0`1YBbL0101ZC2P0K4hZ06a>:P1/CRX306e?:`80KU0/00<0LU8[
075A:P1`D2T00P1_CbP0301aDBX0Le</07AD;@1iFC00MeL^07AD:`1aDBP0L50W075A:01cDbX0M5@[
07QH;`80MeL^00<0MUH]07EE;01dE2/00`1cDbX207EE;080MUH]0P1gEbh207QH;`0<07eE<@1lE300
NeD`07QE;`1fE2h0M5@]07=C;01aE2`0NUXc07QH<@1fERl0Le</0`1bDR/407=C;080LU8[0`1cDb`0
201^DBT0Ke8Z075D;01bEBd0LE@/06iA:@1[CRH0JD`T0`1cERh4079E;@80LE@/0P1`Db/01`1_DRX0
KU4Y06e@:01]D2P0K4lW06Y=9@1[CRH00P1/CbL206iA:@0@06mB:P1`Db/0KU4Y06iA:@1_DRX0L5<[
079E;@1dEbl0MEP`07II<@1aEBd0L5@/06iB:`1[CbX0JD`Z06U<;080JD`^00@0IDd[06A<:P1SBbT0
Hd/Y101RBRP0101PCRX0GddY05e;9`1LBRH305]99@0905a:9P1OARP0GdPY0619:P1NBBX0GDXZ05U9
:01FAbH0EDHU0080FTLW0`1IARH305Q59@<0Dd8X0P1B@BL305509P0805529@1@@B@0Cd0S04ho8P1<
?B00Bc`O04Xk7P19>Qd304Tk8@<0BS`R0P1;?B<804Dk8P80@S/Q0`11>R04040i7`08048j9@10>2<0
?SHQ03de800l=1l0?CDP03hf8@0o=b82040k9@0403lj900m>280?3LQ03Xe7`80>C@N0P0k=R8303Xe
8@/0>C@P0P0g=B00100f=1l0=C<N03Dc7P0d<Qd203<a7080=S<P1P0e<Ql00`0i=R<0>3DR03Hc8002
03Db7`0303Hc800h=B80>CHS00<0<S<S0P0a<R83030a8@@0<S<S0P0a<R82030a8@<0<38M0P0a<ah3
038d7`0803Ld8@0f<b00=C8O03@a7P0c<1d0=34N03Hc800g=24203@a7P<0=C8O0`0f<b00200e=b40
=3HP038d7P0`<Q`0<C<M03<e7`0f>280>3XT200h=R400`0g=B00=S@O03@b7@0203<a700303@b7@0f
=1l0=cDP00P0>SDQ0P0h=R4203Le8080=S@O0P0e<ah0400h=R40>CLR03Xh8`0i=b80>3HQ03Hd7`0c
<A`0<S0K034^6`0b;a`0=34N03Hc800e<Ql0<c0M030]6P0^:aP502la70@0<38M0P0c<A`303@b7@<0
=C<N200f=1l203Tc6`0403Xd700k=Ad0?3HN03dg7`80?SPP0P0n>1h03P10>Al0@cTP04Di8@18>B80
BCXS04Xj8`1:>R40Bc/R04`l8P1=?B<0Cd0S05118P1A@R40DT<R0P1E?bL05P1F@BH0F4<V05U49@1K
AbH0G4PW05a89@1LB2L0GdPX06199`1SBbL0IT`Y06Y>:@1/CRP0KDlY06iA:@1_DRX0L5<[075D;01c
ERh0M5L_07EH<01fFC4207II;@0>07MJ;P1hFbl0NUda07]N<P1lGc<0OF0d07mP<@20HC80PF8c089S
=024ICH0QFHg08IW>027J3T208YY=00308]Z=@2<JcH0SF`g0080SVdh00D0Sfhi09A`?02ELCd0UG4m
09Ib?P0209Mc?`80V7A00P2EM3h0102FMCl0V7M109Uh@P2KNT@209akA@0509ijAP2ONdL0Wg]70:1l
B02ROTX00P2SOd/0102TP4`0Wge=09mmC@2OODd20:1nCP<0XGm?0P2VPTh00`2WPdl0Z8A@0:V5D@02
0:Z6DP030:^7D`2ZR5P0ZXQH0080ZhUI0P2/RUX20:f;F`<0[XaL0`2_SEd20;2>GPD0/Y1S0P2cTF@2
0;BBI@80/Y1R00@0/i5S0;BBI02dTV@0]I=U0P2fU6H20;BBI0040;FCI@2fU6H0]YAV0;NEI`80^9IX
0`2hUF/40;VFK0030;ZGK@2hUVP0^9IX00H0^9IX202iUfT30;RFJ0<0]iEW0P2fU6H80;NEI`P0^IMY
202gU6X20;VFK0H0^9E[202gUFL02`2cUF<0]9IT0;BEIP2eUVP0]YM[0;NGKP2gUg00^9Qa0;VFK02g
U6X0]95W0080/HiT00<0/i1V0;FBJ02gU6X00P2fTfT20;FBJ080]95W0P2cT6H20;>DJ080/Y=W0P2a
TVH20;2AI@030;:@HP2cTF<0]99T0080]I=U00<0]99T0;>AH`2bT6800P2eTfD20;BBI080/i5S0P2b
T6880;6?H@D0]YAV00@0]I=U0;BBI02dTV@0/i5S0P2eTfD0102dTV@0/i5S0;6?H@2`SV020:n=G`03
0;:?I@2cT6H0]95W0080]95W00<0/XmU0;2=H`2_S6800P2_SEl00`2`SV00/HmQ0;:@HP020;>AH`03
0;BBI02dTFL0]95W0080/i1V0P2bSfD20;6>I00@0;:=H02aS5l0/8]N0:n:G@2`Reh0/HaO0;>>H@2e
T6<0]I9X0;BAI`2bSfD0/HiT0;2=H`2aSV@0/XmU0;>@IP80]99T0P2cTF<70;:@HP<0/HmQ0P2`SV08
0;2=H`050;6?H@2`SV00[heO0:j<GP2]Red00P2^S5h00`2_SEl0/HiT0;6>I0060;6>I0H0/8eS0P2_
S680202[RE/0[8YL0:f;G@2^S5h0[heO0;2>H02aSf40/Y1R0P2`SV020:n=G`80[XaN0P2]Red20;2=
H`<0/HiT0`2bSfD20;6@G@030;2>GP2_SEl0[XaO0080[HYP00T0[8UQ0;:=H02aS5l0[hYM0:f8F`2^
RE`0/8]N0;>>H@2eT6<00`2aSf420;2>H0<0[heO0P2^Rf470:n<HP<0/HmQ0P2`SV030:n=G`P0/8eS
202_SEl00`2_Re/0/8aL0;2<G0020;6=G@<0/XiN202_S6820;6AHP040;:@HP2dSf80]8mR0;F?HP80
]hiR00<0[XaN0:n=G`2_SEl0102_SEl00`2^S5h0/8]N0;2;GP060;2;GP080:^:E`2/RUX0[8YL0:f;
GP2^Rf40[haT0;2=I`2`S6P80:n=G`P0/8]N202aSV@40;2=H`@0/HiT202bSUh0202_S5H0/8aH0;2<
F02aSE/0/HeM0;:=H02bSF40/hiR202_S6830:j;H@030:n<HP2`SF<0/8eS0080/HiT0`2cSV420;:=
H0<0/HaO0P2bS5d20;6;G0<0/8YK0P2_REX80:n;F`H0[XYJ0P2_Re/01P2[QUT0[8MJ0:j9G02`Reh0
/HaO0;2;GP80[hYM0P2`Rel20:n:GP80[XUM0P2]R5`30:b7FP@0ZhII00@0ZXEH0:R4E02XQ5@0Z8AD
0P2WPe<30:J2DP80YX5=0P2WPTh20:R3C`80ZHA@202TP500102XPdl0Yh9>0:N2CP2WPTh20:J1C@80
YH1<0P2RODT20:5lB0<0X7]700@0WgY609mkB`2ONd/0Wg];0P2NNTX309eiB@@0Wg];102NNTX0102M
N4/0W7M:09agBP2LMdX209]fB@80VWE80140W7M:09]fB@2IM4L0V7=609MbA@2HLdH0VGA709YeB02N
NTP0WGU709]gA@2IMD<0Ug=109Ib@02ELCl0U70n09IaA@0209IaA00309Ib@P2FLT00UW8n0080UW<m
00@0UG5109A`@02DL400U7100P2CKcl2099^?P80TVe10`2AK403091[?`80TF/n00<0T6Xm08iX>`2=
IcX00`2=IcX0102<IST0RF@g08UT=`29I3L508YU>00708YU>@29I3P0Qf8f08IQ=@25H3@0QV4e08MR
=P0408QS=`80Qf8f0`26HCD208MU>080QV@g00L0QF<f08AR=@23HC@0Pf4d08MR>026HCL0Q5le0080
Pehd00<0Q5le08IQ=`27HSP00P26Gc@01P25GS<0Q5db08=L<@23G340PU/`085J;`@0PElb0180P5ha
07mM<01oGC00OU`_07mM<020GS40PElb089P<`21Gc80Oed`07eK;P1lFRd0P5dc07mL<P1nFc40O5T_
07YG;@1iER`207MD:P0607aI<`1kF380NePb07YG<@1iES00N5D_0P1gE2h0201cD2H0M54W07EB:01f
DbT0N5D[07UF;01jEbd0NeP^0`1dDR`207=A:`<0LU0Z00P0MU0/07MA;@1fDRh0ME<^07=C;@1_DB/0
KDlY06]?:080Le4[00@0LU0[079@;@1aCRh0L4d_0P1`CC400`1^D2h0Jdd[06Q::00206I89P0>06M9
9`1ZC2X0K4h/06Q:9P1ZC2P0K4hZ06i@;01_DBd0KU0/06]=:@1ZC2P0KDl]06i@;P1`DS02075C<@03
071B<01^D2h0KDl]00<0J4/[1@1WBRX00`1ZC2X0Jdd[06a>;00206a>;00406Y<:P1YBbT0JD/Y06M9
9`<0JT//0`1YBR/206Q9:P0306]::`1ZBBX0JDPY0080J4LX00T0JDPY06a;;01]C2d0JU0]06Q>:`1V
C2T0I4XW06989@1QAb@00P1PAR<30656:080H4DW101OA2H206159`<0HDHX0P1PABL305i39P0505e2
9@1L@B@0Fd0S05Xo8P1I?R400P1B?RD2054m9004050l8`1?>b80CSXQ04hj8@<0DS`T0P1C?BD305@n
9P0605@k9`1B>BD0CSPS04/f8@18=R00AcLP0P17>24304`j92_ooooo000Zooooo`P0WG=1202NLdH2
09ebA@0309icAP2OM4L0X7E80080XGI900H0XWM:0:AiAP2SN4D0XgQ50:9gA02QMT<20:1e@P0409md
@@2SNTH0XWU50:5hA0<0WgI200D0X7M30:5hA02SN4D0Y7U60:EjA`020:IkB0030:AiAP2RMd@0XGI3
0080ZGU80P2XN4L30:MgAP030:IfA@2TNdD0Y7]500H0Y7]50P2UO4P30:ImB@<0Ygi:00@0Y7]70:El
B02UO4P0YWe90P2WOTX02@2XOd/0ZH1<0:V0C02ZOTl0ZGm?0:UoC@2WOd/0YH1;0:>0B0020:61AP06
0:Mo@P2WOd@0Ygm40:ImA@2VODL0YGa80P2UNdT0102YP4`0Z7m;0:QoB`2XOd/20:MnBP80YWe9202X
Od/80:MnB0P0Z7m;00H0Yh9E0:R2D`2XPU<0ZX9A0:^1C`2/PDh20:j0C0P0Zh5?00H0Zh1E0:^0D`2[
P5<0Zh5A0:^1C`2[PTh20:^2C0P0[8=?00@0Zh9>0:b3C`2/Pdl0[8=?0`2]Q500102^QE40[8=;0:b3
B`2/Pdd20:b3C`030:b2D02/PU80[89B0080[H=A0`2^Q5830:n5D`P0[8MB0`2/PU020:f3D@<0[XAB
0P2XPdl0102YQ500ZXEA0:b7D`2]R5@40:j9E@80[HQD0P2/Qe<20:^6DP080:b7D`2]R5@0[XUE0:n:
EP2^RED0[HQD0:^6DP2ZQE490:N2C@80Y7m:0P2SOTT30:9mB0050:5lA`2QO4D0X7]409ii@P2MN440
102LMd0209Mf@@0309Ue@@2JMD40W7A10080WG=100D0WW9109Mb?P2GLSh0UW4m09E`?00209A_>`80
Tfhj00L0Tflo099^?P2AKCd0T6`l08iZ>P2=JCT0S6Ph00<0RfLg0`2=JCT00`2;IcL0RFDe08QT=002
08ES=@0408AR=023HC<0PV0b089P<P80PEla00T0OUdZ07mN:`1oGBd0Oed_07iL;`1lFBl0NeP^07UF
;P1hF3400P1iFC80101jFS<0NETb07QH<@1gEc0507IF;`0<07EE;P1dE2d0LU8[075A:P1aDbl0L58^
06mA;@1^D2`0KDl[06a>:P1[CBT0JT`X0`1/CR`206]=:`<0JT`Z0P1YBbT0101XBRP0IdTW06M99`1V
B2H206E79@P0I4LU00@0IdTU06Q:9P1XBRH0J4XV0P1YBbL206Y<:0<0Jdd[0P1/CR`306e?;@0306iA
:@1]D2P0K4lW0080K4lW00P0KU4Y06mB:P1aE2`0NET`07QH;`1eEB`0Le<Z075A:0<0KdlV0P1fERl3
07EE;P@0M5@]0`1eEBh207IF;`<0MeL`0P1lE3000`1jE2l0Me@^07EC;@0207=C;005071C:`1iFC80
N5Pa07EE;P1dE2d00P1cDb`01@1dE2d0MED^07AD;@1cDb`0LU8[0080LE4Z00D0LU8[07=C;01dE2d0
KU4Y06mB:P03071C:`0306iA:@1]D2P0K4lW00P0K4lW0P1`Db/206mB:P80KU4Y0P1]D2P306]>9P04
06a?9`1]D2P0KU4Y06iA:@80Ke8Z0P1^DBT02`1_DRX0L5<[079E;@1dEbl0MEP`07AG;@1cERh0LE@/
06mA:`1/CRX0Jdd[0080JDX[00H0ITh/06E=:`1SBbT0HTXX06599`1PB2H206599`80GT`X00<0GD/W
05a:9P1LBRH00`1LBRH0201OARP0GdPY0619:P1NBBX0GDXZ05U9:01FAbH0EDHU0P1JAbL305U69P<0
F4DU00@0E4<Y05=2:01C@RP0Dd8X0P1B@BL205509P80DT<T00@0DD8S05118P1>?b00CChO0P1<?Ah8
04/k8PP0AC/R0P12>b43044j80@0@3TO00<0@SXU044i900o=b800P0m=B000`0n=R40?cLR040h8`02
040k9@0403lj900n>B<0?3LQ03/f8080>SDO0P0k=R8303Xe8@/0>C@P00@0=S@O03Dc7P0e<ah0=C<N
100d<Qd303Hc80<0=C8O0P0d<Ah00`0g=240=S<P03Db7`0203@a7P0303Db7`0f<b00=c@Q00<0<S<S
0P0a<R83030a8@80<S<S0`0c=2@00`0b<b<0<34Q02l`8003030b7@80<C<N0`0b=1l0200h=B80=c@Q
03Db7`0d<Ah0<c0M03@a7P0e<Ql0=S<P0P0d<Ah303Db7`<0=S<P00P0=3HP03<e7`0b=1h0<S@N03<e
7`0d=R00=CLQ03Hh8PP0=cDP00<0=S@O03Dc7P0d<Qd00P0c<A`00`0d<Qd0=C<N03Hd7`0803Xe8@80
>3HQ0P0g=B0203Hd7`80=C<N0P0f=1l01`0g=B00>3HQ03Le800e<ah0<c4L034_6P0d<Ah00`0e<Ql0
100d<Ah0<RlL034^6`0`;AX402h`6`80;c4L0`0`<Qd0100c<A`0=38M03@b7@0d<Qd203Dc7PX0=S@O
00H0>c@J03`e6`0l=A/0?CHL03hg7@0o>1h2040i7`0>040i7@11>Qh0@cTN04Di7`18>R00BSXQ04/k
8P1<>R80CC/S04hm8`1??R@0D3lS05508P1C@b8205A48P0F05U19`1J@RP0Fd<W05a59P1MARH0GdPV
06199`1PBRD0H4TY065::P1SBbT0IT`Y06Y=:`1]Cb/0L50Z075A:`1bDRT0Le<Z07AD:`1eEB`0MUH]
07QH;`80NET`0P1gFRh0101hFbl0NUda07]N<P1mH3@207iQ=@06085R<`22Hc@0Pf@e08AU=P25ISL0
QfPi0P28JCX01P2;JSD0S6/f08a[=P2=K3L0SVdh08m^>@80T6lj0P2ELCd209Ib?P80Ug<o0P2HM402
09Ie?`0609Mf@02IN480VWU309]jA02LNdD0WGa60P2MNDD01P2NNTH0X7a80:5mB@2ROTX0Xgm;0:B0
C0<0X7i>0P2QOdl30::0D080Yh=?00<0Z8A@0:V5D@2ZQU800P2[Qe<00`2/R5@0ZHMG0:V7E`020:Z8
F0040:^9F@2/RUX0[H]K0:f;F`<0[XaL0P2_SEd30;2>GP030;:?I@2cT6H0/i1V0080/i1V0P2dTFL2
0;FBJ0<0]99T0`2eTfD20;JDIP80]99T00@0]I=U0;JDIP2fU6H0]iEW0P2hUVP80;VFK0P0^9IX202i
UfT30;RFJ0<0]iEW0P2fU6H80;NEI`P0^IMY202gU6X20;VFK0<0^9E[0`2gU6X80;NEI`80]IMU00@0
]IIW0;JGJ@2fUf/0]YI]0P2gUg000`2gU6X0]Y=Y0;BAI`020;:?I@030;BAI`2fTfT0]iAZ00<0]I9X
0P2dTFL30;>@IP050;BEJ@2cU6P0/iAX0;:CI`2aTVH00P2`TFD0102_T6@0/Y1R0;>AH`2dTV@20;FC
I@030;BBI02cTF<0/Y1R0080]I=U0P2dTV@20;>AH`X0/Y1R00<0]I=U0;JDIP2gUFL00P2gUFL01@2f
U6H0]I=U0;BBI02cTF<0]99T0080/i5S00L0/Y1R0;6?H@2`SV00/8iP0:n=G`2bSfD0/i1V00<0]95W
00@0/XmU0;2=H`2_S680[heO0P2`SV000`2aSf40/Y1R0;>AH`020;BBI0<0]95W0P2cT6H30;:?I@0@
0;:=H02aS5l0/8]N0:n:G@2`Reh0/HaO0;>>H@2dSf80]I9X0;BAI`2bSfD0/HiT0;2=H`2aSV@0/XmU
0;>@IP80]I=U0P2dTV@30;>AH`030;:@HP2cTF<0/i5S0080/Y1R0`2aSf400`2`SV00/XmU0;6>I002
0;6>I0<0/8eS00D0[haR0;6?H@2`SV00/8iP0:n=G`030:j<GP030:n=G`2aSV@0/HiT00P0/HiT0`2`
SF<30:n<HP050:b:G02]Red0[H]M0:j<GP2_SEl00P2`SV020;6?H@80/8iP00H0[heO0:j<GP2]Red0
[H]M0:b:G02`SF<30;6>I080/XmU0P2cT6H20;2?G0090;2>GP2_SEl0[heP0:n<HP2^Rf40[X]S0;:=
H02aS5l0/8]N0080[hYM00<0/8]N0;6<G`2aS5l00P2`SV020:n=G`<0[XaN00<0[H]M0:j;H@2^Rf40
102_S6830;2=H`040;:@HP2aSf40/HmQ0;6?H@80/8iP0P2_SEl80;2=H`P0[heO00D0[h]K0;2<G02a
SEd0/XiN0;>?G`020;:>GP030;6=G@2_S680[haR00H0[haR0P2`T640102aSf40/hiQ0;>>H@2dSV42
0;J=H@030:j<GP2_SEl0/8iP00<0/8iP00<0[heO0:j<GP2`Reh01`2`Reh0202^SEL0[XeH0:j<G02^
S5h0[haT0:n<IP2_RfT0/8a/202_SEl80;2;GPP0/HiT202`SF<80;6=G@060;2=E`2`S5P0/HeI0;6=
F`2bSUh0/hiQ0P2dSf<80;2=H`060:j;H@2_S680[haR0;2=H`2aSV@0/XmU0P2cT6H20;B?HP<0/hiQ
0`2bSF030;:<G@@0/H]L0P2`RU/80:n;F`<0[XYJ0P2_Re/30;2<G0080:f8F`2^RE`0/8]N0;6<G`2b
SF00/HaO0;2;GP2_RUd20;6<HP80/8]Q0`2_RV000`2^REl0[HQK0:f8F`060:f8F`80ZHEE0P2XQ5@3
0:N3D`040:J2DP2XPdl0Z8=?0:V4D080ZXEA00<0ZhIB0:b7D`2/Qe<0202UPE40102[QU80ZXEA0:Z5
D@2ZQE420:V4D080Z8=?0`2UP4`30:AoB`80Xgi:0`2ROTh20:5mC@<0X7a<102SOdl20:9nCP80XGe=
00@0XWe@0:5lC`2QO4l0XGa?0P2PNdh209mjC@0309ekC@2LNT`0VWQ:00<0V7I80P2JN4X01@2SOd/0
XGe909mkA`2MNDD0VgM300<0VWI200H0VgI909]gA`2KMdL0VgM509]g@`2KN48209]h@00409UeA@2H
M4@0V7A409QdA080Ug=30P2FLT8809E`@`0409Ma@P2EKd00U6ho099/?@@0TF/l00<0TV`m08iX>@2>
J3T00`2?JCX3091Z>`0808mY?02>J3/0SFLj08aV>@2;ICP0S6Hi08iX>`2?JC`308aW>P80RfHi0`2:
ICP0102;JC/0RVPj08YX>P2:J3X408UW>@0308YU>`28HcT0QV4g0080Q5le00<0QV4g08QS>@2:IC/0
0P29HcH01028HSD0Qf4d08MQ=026H3<208EO<P80Q68d0`25HcD00`24HS@0PV0b085O<@0208EP<`80
QV4d00D0QF0c08AO<P21G2l0P5/^08=N=002089M<`05081K<@1oFS00OUT_07eH;P1lEbd00P1nFc<0
0`1mFS80O5Ta07]H<00207YG;`0907UF;P1gE2X0N5D[07UF;01jEbd0NeP^07aI;`1mFS00OU/a00<0
N5D]0P1gE2`307IC:`0>07]C;`1lE300O5Ha07YG<@1iEc40MUH_07AD;@1aE2`0N5D]07QE;`1gE2h0
Me<_07IB<01eDC4207A?<P0807AC<01bDBh0Kdh[06e<:@1/BbP0KD`Y06i=:P1_CR/2075A:P09079B
:`1cDb`0Le</079B:`1aDBX0L50Y075@;@1cDRl0MUDb0080MeHc00<0MUDb07=B;`1aD2d00P1/CR`2
06]=:`@0JT`Z00<0L4l/075@;@1bDBh00P1bDBh0101`Cb`0Kdh[06m>:`1]C2T806m>;@0307=?;`1a
CBd0Kd/[0080KDTY00<0Kd/[075=;@1cCbl00`1]DB`01@1/D2/0JThY06U=:01WBbH0ITXU00<0J4XX
0P1WBBL306I89P0306A79@1UB2H0IdXX00<0J4/Y00<0IdXX06I99`1TABH00`1UARL0101TABH0HT<T
06528`1O@24205Lo8`80EShR0P1E?B4205@l80<0FClT0P1J@2D305]19P0605Ll9`1E?2H0DSTS04hh
8@1;=al0BCLO0P19>B03054m9B_ooooo000Zooooo`P0WG=1202NLdH01P2LLD@0WG9509icAP2OM4L0
X7E80:5fB@80XWM:102RMd@40:5f@`0:0:5hA02PMd<0WgI209ie@@2OMT80X7M30:9iA@2SNTH0YWQ6
0:MiA`80Z7Y800@0YgU70:IhAP2TMT@0XgE30`2XN4L30:MgAP80YWI5202TNdD20:ImB@<0YGa81@2T
NdL01`2UO4P0YWe90:MnBP2WOTX0Z7m;0:V0C02ZPDd00P2YOdl01`2XP4d0YH1;0:B1B`2QPDP0XH56
0:22AP2WOd800P2WOd@00`2VODD0YGa60:ElB0020:AjB0<0Z7m;0P2WOTX30:ImB@P0Z7m;202WOTH8
0:QoB`060:N2E@2XPU<0Z89C0:Z2D@2[PDl0[85>0P2^P4`80:^1C`060:^0E@2[P5<0Zh1C0:^1D@2[
PDl0Zh9>0P2[PT`80:b3C`80Zh9>0P2/Pdl0102]Q500[XEA0:j5D@2^QE420:b3B`040:b3C@2/Pdl0
[8=?0:b2D080[89B0`2]Pe400`2^Q580[hEC0:n5D`020;26E0P0ZhIA0`2[PDl20:b2D0<0[H=A0`2Y
Q5000`2ZQE40ZhIB0:b7D`020:b7D`80[XUE0P2]R5@20:b7D`80ZhIB00<0[HQD0:j9E@2_RUH00P2_
RUH00`2]R5@0[8MC0:Z5D@050:N2C@@0Z8=>00@0YH1;0:AoBP2TOdX0Y7m:0P2SOTT20:9mB0040:=o
A@2QOD<0Wg]109ei?`80W7Pn00L0WGTo09ij@02JND@0VGQ309]g@`2KMT80W7A10080W79000<0W70o
09Ia?@2FLCd00`2FLCd309E`?080Tflo00@0TVhn091/?02?Jc/0SFTi0P2<J3P0202;IcL0S6Ph08eY
>@2>JSX0SFTi08aX>02:ISH0RFDe0P26I3H01025HcD0Q68d08=Q<`22H382085O<@0D081O:P21H2/0
PF0]089P<021Gc40Oed`07aJ;@1kF2h0N5Pa07UI<P1jFS<0Ne/d07YJ<`1iFC80MeL`07IF;`1iFC80
N5Pa07IF;`1dE2d207=C;080M5@]0P1`DRh0101_DBd0KU0/06i@;01]Cb/206a>:P80KDl]0P1/CR`3
06]=:`<0JT`Z00@0JD/Y06Q::01VB2H0IDLU0P1TAR@806=69080J4XV0P1YBbL306Y<:00406]=:@1Z
Bb`0JT//06Y;;080Jd`]0`1/CBh00`1/D2P0JdlW06Y>9P0206Y>9P0406a@:01]DBT0Ke<[07=C:P<0
M5@[00@0Le<Z075A:01`D2L0KdlV101dE2h907EE;`80MUH`0P1gEc4207aD<00A07YD;`1gE2h0ME<]
07=C;01bDR/0L5<[07MG<01fERl0MED^07AD;@1cDb`0M5@]07IF;`1gEc00M5@]07=C;01aDBX00P1`
D2T01@1aDBX0Le</07AD;@1_DRX0KU4Y00<0KE0X00<0Ke8Z071C:`1aE2`0201/CbL406mB:P@0KU4Y
1@1/CbL306e@:00306mB:P1^DBT0KE0X0080KE0X0100Ke8Z075D;01cERh0N5P_07MG;P1eEBh0Le</
071@:P1]C2T0JdXY06Y9:01WCbd0IDd[06=;:@1QBBL0GdLU0P1PB2H00`1QBBL0FdTU05a:9P0205a:
9P@0GD/W00P0GdHX05m8:@1PBBX0GTTZ05e::P1IBBP0ETLV05E69@80FTLW0`1IARH305Q59@80E4<Y
0`1C@RP305919`80Dd@S00@0DT<R05528@1A@R40D44P0P1?@1l01@1>?RD0CCdT04dm901<?2<0Bc/R
0080BSXQ00<0BCTP04Dk8P15>b801P15>b82044k8@<0@3XP100o>Al02012>RD0@CTT03lg8P0n=R40
?CDP03hf8@0o=b80@3PS0P0o>R@203hi8`0403dh8P0l=b40?3LQ03/f8080>cHR0`0j=B4;03Td8080
<c4L0`0d<Qd303Dc7P80=c@Q0P0f<b001`0e<Ql0=34N03@a7P0d<Ah0=C8O03@a7P0c<1d00P0b;a`0
0`0c<1d0=34N03Db7`03038c8`80<C8R0`0`<B400`0a<R80<S<S03@e9@0203@e9@03038c8`0`<B40
;c0P00<0<38M0P0a<ah3038d7`0603Tf8`0g=240=C8O03@a7P0c<1d0=34N0P0e<Ql203@a7P<0=C8O
0`0f<b00100a<ad0<S@N03<e7`0d=R0203Dg8@0303@f800c=Al0=cDP00L0=cDP00<0=S@O03Dc7P0c
<A`00P0b<1/00`0c<A`0=C<N03Hd7`0803Xe8@80>3HQ0P0g=B0203Hd7`80=C<N00<0<S0K03<a700d
<Qd00P0e<ah01`0d<Qd0<c4L034_6P0i=R<0>3DR03Hc800d<Ah0100c<1d302d_6P80;S0K00@0;c4L
030b7@0`<Qd0<38M0`0d<Qd203Dc7P/0=S@O00H0?3DK03df700m=Q`0?SLM03lh7P10>Al2044j8006
04<j7@14>ah0ACXN04Hk7`19>b00Bc/Q0P1=?280201@?2<0DCdR058n8`1C@280ED8R05I38P1GAB40
F4HR0P1K@bL0701LABH0GTLX05m8:01PBBL0HD/V069<9`1RBBX0HdX[06E;:P1YC2X0K4h/071?;01a
DB/0Le4/07AC:01eE2T0MUDZ07MF:`1iF2d0NUT^07]J;`1lFc00N5/_07UL<01jGC40Nehb07aO<`1n
HCD207mR=P09089S=023I3D0Q6Df08EV=`27J3T0R6Tj08UZ>`2:Jc`0S6/f0080SF`g00<0SVdh08m^
>@2@KcX00P2AL3/209Ea?@<0UW8n0`2GLcl03P2FMCl0UgI009Qg@@2IN480VgY409akA@2MO4H0WWe7
09]g@`2LN4@0WGU509ijAP2PO4P0XWi:0P2SOd/0102POTh0XGm?0:5oC`2QOdl20::0D080Xh5A00H0
Yh=?0:R4D02XQ500ZHEA0:Z6DP2[Qe<20:b8E080YhEE00L0Z8IF0:V7E`2ZR5P0ZhUI0:b:FP2]Re/0
[XaL00<0[heM0P2`SUh20;6?G`<0/i1V0P2dTFL30;FBJ0030;JCJ@2gUFL0]YAV0080]YAV102eTfD2
0;BBI0040;FCI@2fU6H0]YAV0;NEI`80^9IX102jUfd40;VFK0P0]iEW202iUfT30;RFJ0<0]iEW0P2f
U6H80;NEI`P0^IMY202fTfT20;VFK080^9E[0P2gU6X20;JCJ@P0]iEW0P2gVFL0102gV6T0]YMY0;JG
J`2fUVd20;FEKP80]I9X0`2dTFL20;FBJ0030;JCJ@2eTVP0]I9X0080]95W102cT6H20;BEJ@040;>D
J02bTfL0/I9V0;2AI@80[i1T00<0/Y1R0;>AH`2dTV@00P2eTfD00`2dTV@0/i5S0;:@HP020;FCI@80
]99T0P2cTF<20;:@HPP0]99T00T0]I=U0;JDIP2gUFL0]iEW0;RFJ02gUFL0]YAV0;BBI02cTF<0202a
Sf400`2bSfD0/i1V0;BAI`020;BAI`030;:?I@2`SF<0[haR0080/8iP00@0/HmQ0;:@HP2cTF<0/i5S
0P2dTV@40;BAI`80/i1V0P2bSfD00`2aS5l0/8]N0:n:G@020:n:G@0<0;6<G`2bSF00]8mR0;FBJ02d
TFL0/XmU0;6>I02`SF<0/HiT0;:?I@2cT6H0]YAV0`2eTfD20;BBI0D0/i5S0P2bT6830;6?H@<0/XmU
00<0/HiT0;2=H`2`SF<00P2_S6820;6?H@80/8iP0P2_SEl20:j<GP/0/HiT00<0/8eS0:n<HP2_S680
0P2^Rf440:j<GP@0[heO0P2aSf40102`SV00[heO0:j<GP2]Red20:b:G0<0/HiT0P2bSfD30;>@IP80
[hiK00<0[heM0:n=G`2`SV400P2`SF<00`2`SFD0/HaO0;:=H0020;:=H0040;6<G`2`Reh0[XUL0:f8
F`80[XaN0P2]Red40:b:G080[X]Q0`2_S6820;2=H`80/HiT0P2bT6830;6?H@<0/8iP202`SF<80:n=
G`080:j:FP2`S5`0/XiN0;>?G`2dT600/hmO0;:>GP2aSEd80:n<HP80[hmP00@0/8iP0;:=H02bSF00
/heP0P2eS6000`2^S5h0[heO0;2>H0020;6?H@030;2>H02_SEl0[XaN00P0/8]N00P0/91G0;2?F@2`
Se`0/8iP0:n<I02_RfL0[h][0:j9K0P0[heO202`Reh80;2=H`H0[haR0P2^Rf480;6=G@060;2=E`2`
S5P0/HeI0;:>G02cSel0]8mR0P2eT6@80;6>I080[haR00@0/8eS0;6>I02bSfD0/i1V0P2dTFL20;B?
HP80/hiQ0`2bSF00102aS5l0/XaM0;:<G@2bS5d30;6;G0<0/8YK202^RUX20:f9F@030:j:FP2_Re/0
[h]K0080/8aL00@0/HeM0:f8F`2_RUd0/8]N0P2bSF000`2aS5l0/8]N0:n:G@030;6<HP80/8]Q0`2_
RV060:j9G080[hYM0`2/R5P20:^7E`<0ZXIF00H0Z8=?0:V4D02ZQE40ZhIB0:b7D`2]R5@20:j9E@P0
ZHEE0`2/Qe<20:^6DP<0ZXEA0`2XPdl20:N2CP<0YX5=0P2TP5020:=oC`<0XWi>00<0XGe=0:J2DP2V
PU800P2UPE420:B0D080Xgm?0`2UP5<20:AoDP<0XgiA00`0XH5B0:20D@2NOTl0WGe>09alC@2MODh0
WWi?09moD02VPTh0Y81<0:9nBP2ONdL209ijAP80Wg]70P2NNTX00`2NNTP0WWY609ikA@0209ik@`03
09ik@@2LN4P0W7Q80080VgM70P2JMTH209UeA@P0V7A400@0VgE409Uc@P2GLD00UFln0`2DKSd0102E
Kch0UW0o09=[>P2CJcX209A/>`80UFdl0P2FKSd00`2DJcd0TfXl099Y>`02095X>P0309=Z?02DJcd0
UF`n00<0Sf/k0P2>JSX308eY>@<0S6Xj0P2=Jc/308i/?003091[@@2>JCl0RfHl0080RF@j00<0RfHl
08iY?`2@Jd400P2?JCX02@2>J3T0SFLh08aV=`2<ISL0RfDf08YT=@26I3@0QfDe08QV=P0208UW=`03
08MU=@25Hc<0Q68b0080S6Hg0P2=IcP0102<ISL0RV@e08MQ<P26H34308MP=@80QUld0P25GS<01`24
GC80Q64g08=P=P23H3H0PUle085N=020GC<00P1oG380101kFB`0O5X]07aJ;@1mFbh207iL;`80Oed`
00@0OU/a07eJ<01mFS00OEX`0P1lFBl207]H;P08081E<P1nES80P5Pd07mI=01mFS@0NeTc07QH<@1g
Ec0207aI<@0;07]H<P1jEc40NEDa07QD<P1gDc<0MU8b07]I=01jF3<0NELb07ME<01fE2l00`1eDbh0
101iF2l0N5L^07IE;01eE2/307AC:P0407ED:`1dDRd0MU@_07UG<P80NeTd00@0NELb07ID;`1dDRd0
M5<`0P1cDRl2079A;P09075@;@1`Cb`0L4l/07AB;@1eDbh0MU@_07ME<01fE2l0ME<^0080Le4/00<0
LDlZ07=A;P1cDBh0101cDBh207AB;`0307UB<@1gD2l0M4d/0080LDXY00H0Ld`[07I?;P1hDC00K50X
06iB:P1`E2`2075E;@0306iB:P1[CbL0JDdU00<0KD`Y0P1/BbP306]:9`0306I:9@1XC2L0JThY00<0
K50[00<0JdlZ06Y>:@1YB2L00P1ZBBP01@1[BRT0JTTX06Q79P1UA2<0I4<R00@0G4<U101K@R@205m1
9@<0H48V0`1Q@bL0201M@b`0Fd4Z05Lo9`1E?BD0DC/S050l8`1>?B<0CchT0`1F?RH[ooooo`00:_oo
ool809ec@@80WG95102NLdH209mdA`0609aaA02MLTD0WG9509mdA`2PMDP0XGI90P2RMdX0102PMD80
XGI30:5f@`2QMT<30:9gA0030:=hA@2PMd<0X7M30080WWE100H0WgI20:5hA02SNTH0YGa80:IhAP2W
NDL20:QjB0040:MiA`2VN4H0Y7I40:9d@P<0ZWQ70P2YMdH30:QfA@P0Y7]50P2VODT00`2UO4P0Y7]7
0:=jAP020:9iA@050:5hA02TNdL0Y7]70:ElB02VODT00P2WOTX20:V0C0070:Z1C@2YOdl0Z81?0:R0
C@2UP4/0Y85;0:61B0020:22AP060:Mo@P2WOd@0Ygm40:ImA@2UO4H0Y7]70P2TNTP20:QoB`<0Ygi:
0`2VODT80:QoB`<0YWe51@2WOTH80:QoB`060:N2E@2XPU<0Z89C0:Z2D@2[PDl0[85>0P2^P4`80:^1
C`060:^0E@2[P5<0Zh1C0:^1D@2[PDl0Zh9>0P2[PT`80:b3C`80Zh9>00@0[8=?0:f4D02]Q500[XEA
0P2_QU820:b3B`040:b3C@2/Pdl0[8=?0:b2D080[89B00@0[89@0:f3D@2]Pe40[XAB0P2_QE<20;26
E0P0ZHA?0`2[PDl20:b2D0<0[H=A0P2YQ5030:Z5D@<0ZhIB0P2^RED20:f8E080[8MC0P2[QU80202]
R5@0[XUE0:n:EP2`ReL0[hYF0:j9E@2/Qe<0ZhIB102WPTd50:R3CP80YH1;0P2TOdX30:=nB@050:9m
B02SOdD0XWi409mk@@2MNCl00P2LN3h02P2NNT00Wg]109]jA@2KNTD0W7Q409ag@`2LM440W79009]a
?`2KKch309E`?080UW4m0`2GLSh01`2DL400Tflo099^?P2AKCd0Sf/k08iZ>P2=JCT00`2<J3P308iZ
>P0308aX>02:ISH0RFDe0080QfDg00@0QV@f08ES=@23HC<0PV0b0P21Gc406021H2/0PV4/08=R;`23
HC40PV0b081N<01nG2l0O5X]07QH<@1iFC80Ne/d07aL=@1kFc@0NETb07MG<01fERl0Ne/d07UI<P1f
ERl0Le</079B:`1cDb`0MED^07IF;`@0Ke4]101^D2`306e?;@80K4h/101[CB/01`1ZC2X0JD/Y06Q:
:01VB2H0IDLU06A6901SAB<0201RAB<306U;9`80JT`X0`1[CBT306Y;;080Jd`]0`1/CBh0401/D2P0
JdlW06Y>9P1YCBD0JThV06]?9`1]DBT0KU8Z06e=901_CbH0LU8Y07AD:`1eEB`0M5@[079B:@1`D2L2
079B;00307=C;@1dE2h0MED_00<0MUH`00<0MeLa07AD;P1eEBl00P1eEBl207IF<080MeLa01<0O5@`
07]C;`1jE2l0Me@^07EC;@1cDb`0LU8[071C:`1fERl0MED^07AD;@1cDb`0M5@]07EE;P1gEc00N5Pa
07AD;@1cDb`0LE4Z0080L50Y00/0LE4Z07=C;01dE2d0Ke8Z06iA:@1/CbL0JdhV06a?9`1_DRX0LUD]
07AG;`05075D;0<0LUD]101_DRX406iA:@P0K4lW00<0Ke8Z06iA:@1]D2P00P1/CbL03`1^DBT0L5<[
075D;01iFRh0N5P_07IF;@1dE2d0LE4[06i=:P1[BRT0JTTX06M?;@1UCB/0Hd/Y06189P0205m79@05
06189P1QBBL0FTPT05Y8901KBBD00P1MBbL305i<:00805m6:01OB2T0H4TZ05i9:P1MBRX0FDTX05I7
9P1EARD205Y79`<0FDHV0`1HABD305A3:@80Dd8X0`1B@BL405=48`@0DT<R0P1@?RH01P1??BD0CC/S
04`j8P1;>B40BSPP04Tg7`P0AC/R0P10?24303lk80@0?SXO00P0@SXU044i900o=b80?SHQ03de800n
=R40?cLR040h8`@0?STS100m>28203/f8P<0>SDQ2`0i=202038`6`0403<a700d<Qd0=38M03Dc7P80
=S@O0P0g=24203Hc800703Db7`0d<Ah0=34N03<`7@0d<Ah0<c0M038_7002030]6P03038_700c<1d0
=34N00<0<S<S0P0a<R83030a8@08034b8P0b<b<0=3DU03Df9P0d=BD0<S<S030a8@0_<203030b7@80
<C<N0`0b=1l0100i=R<0>3DR03Hc800d<Ah203<`7@0403@a7P0e<Ql0=34N03@a7P<0=C8O0`0f<b00
200_<A/0<C<M03@f800f>280=cTS03Dg8@0c=Al0<S@N200g=B000`0f=1l0=C<N03<a7002038`6`03
03<a700e<ah0=S@O00P0>SDQ0P0h=R4203Le8080=S@O0P0e<ah00`0_;AP0<BlJ038`6`0303@b7@0:
038`6`0a;aX0?3TV03Xg900f<b00<c0M038_700c<1d0=34N03Hc80@0;BlJ00<0;S0K02la700`<Qd0
0P0`<Qd203@b7@<0=C<N2`0f=1l203le6P03040f6`11=a`0@SPM0080@cTN00H0A3XO04@k7P14>ah0
AS/O04Tk801;>b4204dl8P07050l8`1A?B80DShS05=08P1D@B<0ET<S05M48`0205Q68P80GD<X01@0
GTDW0617:01QBBL0HTXV06=;9`1TC2H0HdX[06E:;01VC2/0JTd[06e?;@1aD2d0Le4/07AB;@1eE2T0
MUDZ07MF:`1hEb`0NUT^07]J;`80O5/`0P1iG300301jGC40Nehb07eP=01nHCD0Of8f081S=`23I3D0
Q6Df08EV=`26IcP0R6Tj08UZ>`80RV/l0P2=K3L00`2>KCP0Sfhi091_>P02095`>`03099a?02ELCd0
UG4m0080UG4m102FLSh209Mf@00409Qg@@2JND<0VgY409elAP80WWe700P0VWI209]g@`2LN4@0WWY6
09mkA`2QODT0XWi:0:=oB`<0XGm?0P2RP5030:>1D@80Z8A@00<0ZHEA0:Z6DP2[Qe<00P2/R5@01`2]
RED0YXAD0:J4E02WQED0Z8IF0:Z8F02[RET00P2/RUX40:n=G@80/8iN0P2aSel00`2cT6P0]95Y0;BA
J@020;BAJ@80]I9Z0P2fTf/20;RFJ0040;NEI`2fU6H0]I=U0;FCI@@0]99T00@0]I=U0;JDIP2fU6H0
]iEW0P2hUVP50;ZGK@<0^II/202gUFL80;VGJ@<0^9IX0`2gUFL20;JDIPP0]iEW202iUfT80;JCJ@80
^II/0P2hUF/0102gU6X0]Y=Y0;JCJ@2eTVP80;NEI`0:0;VKJ@2hVVP0^9UZ0;NHJP2fUf/0]IE/0;FE
KP2dU6d0/i1V0;BAI`80]I9X00<0]Y=Y0;FBJ02eTVP00`2eTVP20;BAI`<0/i1V00`0/XmU0;FFJP2d
UFT0/iAX0;:CI`2aTVH0/95U0:n@I02^Sf<0/Y1R0;>AH`2dTV@20;FCI@030;BBI02cTF<0/Y1R0080
]I=U0P2dTV@20;>AH`80/Y1R2@2eTfD00`2fU6H0^9IX0;RFJ0020;RFJ0030;JDIP2dTV@0/i5S00<0
/8iP0P2aSf430;:@HP030;:?I@2cT6H0]95W0080]95W00<0/XmU0;2=H`2_S6800P2`SV000`2aSf40
/Y1R0;>AH`020;BBI0030;FCI@2eTVP0]95W0080]95W0P2cT6H20;:?I@0@0;6<G`2`Reh0[hYM0:j9
G02_RUd0/8]N0;:=H02dSf80]I9X0;BAI`2bSfD0/HiT0;2=H`2aSV@0/XmU0;>@IP80]YAV0P2eTfD3
0;BBI0@0/i5S0`2bT6820;6?H@80/i1V00@0/XmU0;6>I02aSV@0/8eS0P2_S6800`2`SV00/HmQ0;6?
H@020;2>H080[heO00<0[XaN0;6>I02aSV@01P2aSV@0102bSfD0/HiT0;6>I02`SF<20:n<HP80[X]Q
00@0/8iP0:n=G`2_SEl0[heO0`2^S5h02@2]Red0/Y1R0;6?H@2`SV00[heO0:j<GP2]Red0[8YL0:^9
F`020;6>I0<0/XmU0`2cT6H02P2]S5T0[XeJ0:j<G02_SEl0/8iQ0;6>I02bSfD0/XmW0;6<G`2bSF02
0;B?HP040;>>H@2`Reh0[8MJ0:Z5F080[H]M0P2/RU`20:^9F`80ZXQJ0P2^Rf430:n<HP040;2=H`2a
SV@0/HiT0;:?I@<0/Y1R0P2aSf430;2>H0P0/8eS202_SEl00`2^RUX0/8aL0;:>GP020;B@H0030;>?
G`2bSUh0/HeM00P0[haR0P2^SUl0102_SEl0/HaO0;6<G`2bS5l20;B;G`030:f;G@2_SEl0/HmQ0080
/Y1R00<0/HmQ0:n=G`2]Red0202`Reh0202bTUT0/Y5K0;6@G@2`SV00[haT0:j:IP2^RVX0[HQ[202_
SEl80;2;GPT0[haR1@2^Rf420:f:H0P0/8aL00H0/8eG0;2<F02aSET0/XiL0;B@H02eT6<20;JAI@P0
/HiT00H0[haR0;2=H`2`SF<0/XmU0;>@IP2dTFL20;FBJ0040;B?HP2cSV40/hiQ0;>>H@80/XeP0P2a
S5l30;:<G@<0/H]L0`2`RU/;0:f9F@030:j:FP2_Re/0/8aL0080/8aL00H0[HQK0:n:G@2`Reh0/HaO
0;:=H02aS5l20:n:G@80/H]T0`2`RV<30:n9HP@0[XUL102_RUd20;2<G080[h]K0`2^RUX02@2]RET0
ZHA@0:V4D02ZQE40ZhIB0:b7D`2]R5@0[XUE0:n:EP080:b8F080[HQD0P2/Qe<30:^6DP80ZXEA0`2Y
Q5020:R3C`80Yh9>0`2TP5020:=oC`<0XWi>0`2WPe<00`2VPU80YH5A0:B0D0020:B0D0<0Yh9E0P2V
PE@30:F0D`0<0:J6E`2UQEH0Xh=D0::2D`2QPE80XX9C0:>3E02TQ5D0YhA>0:F2C02SP4X0XGi80P2P
ODL00`2ROdT0Xh1:0:1lC0020:1lBP030:1lB02PODL0X7e50080X7e30`2MNDT209ahB0<0VgM70`2I
MDD509YfAP0509egAP2KMD@0VG=209I`?`2EKch00P2FL3l00`2GLD00V79109A/>`0209E]?00309I^
?@2GKch0Ufln0080V70o00<0UVdo09E/?P2DJcd00P2CJS`00`2EK3h0UVdo09Q_@@02095]?@80T6`l
0`2?Jc/00`2>JSX0SF/k08e[>`0208i/?00708m]?@2@KSh0TFlo095_?`2EL4H0Tfi408mZ@00208eX
?P0308mZ@02CKT@0UG160080U6ho0P2CKCh01`2BK3d0TF/l091Z>`2@JS/0R6Hf08UW=`2:J3P00P2;
JCT00`29IcL0QfDe08ES<`02095[?080TV`m00@0TF/l08mY>P2<ISL0RfDf1@2;ICP308YT=`0608UV
?028IC/0R6Dk08MT>P26HcT0QF8h0P24HCL307iL;P@0Oed_00<0P5h`08EP=P24GcD00P24GcD208=N
=080PUdc00h0PELa089H<P21FS<0PE/d07mL=01mG3<0NeXa07UI<020Fc40P5Xc07mI<P1nF3<0O5Hb
07]D<`80NU<d0`20GST02@1oGCP0OE/f07]I=01jF3<0NELb07iM<P1lFc00N5L/07ED:@0207AC:005
07IE:P1gER/0M58]07ID;`1jF3<00P1lFSD0101jF3<0MU@_07AB;@1iF3D207QG=00307MF<`1fEC80
MUDb0080ME@a0P1fE2l307QF<@0407ID;`1dDRd0M58]07=A;080M58_101eDc0207ID<@0307aC<`1j
DC40MTd]0080M4/[00H0MTd]07U@<01kDS80K4lW06mB:P1cERh207EH<00307=F;P1^DBT0K4lW0080
L4hY0P1_CBP306i<9`0406e;9P1YBbD0JT`V06e?:@<0Ke4[00X0KU0Z06e?:@1[BBH0K4XW06e;:01^
C2T0KD/X06Y89@1XAR<0IT@Q0`1RAbT50656:0<0HD@V0P1RABL306=6:00806=7<@1PARl0GD</05U1
:@1F@2P0E40W05919`1C@RP305Q0:2_ooooo000Zooooo`<0WG=10P2NM48309me@`0309ib@@2PM4<0
XGE40080XWI500T0XGE40:1d@`2NLT40WG5009ib@@2OLd80X7A30:5eA02RMTD00P2SMdH00`2SN4D0
XWM40:5f@`020:1e@P040:5f@`2RMd@0XgQ50:=iA`80XWQ600H0XGM50:1fA02OMD<0WgE309id@P2T
NdL20:=jAP030:9iA@2QN4@0XGQ40080X7M3202SNTH00`2YOTT0Yga70:AiA0020:5f@@040:AiA02W
O4L0ZGi90:MjD080Yg]>00<0Yg]<0:MkBP2WO4T00P2WO4L30:UkBP@0ZWa;0P2[OD`0102YP4`0Z7m;
0:QoB`2WOTX20:ImB@80YGa8202WOTX00`2WODd0Z7i>0:UoC@020:V0C0030:ImA`2TNd<0XWU10080
YWe500@0YWe70:ImB@2VODT0YWa:0P2VO4`20:QmBP040:UnB`2ZOd`0Zh1=0:^0C@80[85>202XOdT4
0:^2CP@0ZX5=00<0[HA@0:b3C`2ZPDd00P2YP4`00`2ZPDd0[8=?0:f4D0040:N2C@@0Z8=>0P2]Pe<0
102]Pe40[HA@0:f4D02]Q4h20:f4C080ZH1800T0ZX5;0:^2CP2/Pdl0[XAB0:j4E02_QED0ZHA?0:Z5
D02/Qe800P2]R5<00`2ZQE00Yh9=0:F0B`080;22CPP0[8=?0`2XPdl30:V4D080ZXEA0P2ZQDh20:^6
C`@0[8M@0`2]R5@30:j9E@80[hYF00H0[8II0:b6E`2[QEH0ZhED0:Z5D@2ZQE020:Z5CP80ZHA@0P2X
Pdl40:N2CP060:J1C@2UP4/0YH1;0:AoBP2SOTT0XWe80P2QO4L0102PNdH0X7a20:1l@P2PNd@209mj
A@0909iiA@2NN4L0WWQ709eh@`2MN4@0W7M309afA@2KMDH0VWA70080VG97102HLcl209Mb?P80UW4m
202AK3P02P2?JSH0T6/g091[=`2@JcL0SVTe08aW<`29I300R6<_085P=`22HCP308AS>P03089Q>020
GcH0OUdd00<0PE`_00<0PUd`08=N<@23GS400P24Gc80201lFC<0OEXd07iK=@1oG3H0OU/e07eJ=01k
F380NULa0`1gDbl207IB;P<0ME4]00@0ME@c07=B<@1aD2l0Kdh]0P1^CB`00`1_CRd0L4l^071B;P02
06mA;@0306i@;01]Cb/0K4hZ00<0JddY00D0JT`X06U;9`1XBRH0ITPT06E78`0206A68P0;05e;9@1N
BRD0H4XU06=99P1UB2H0J4LV06U69P1ZARH0IdXX06I99`1TAbD00P1SAR@00`1TAbD0ITTW06M::002
06Q;:@0406M::01VBBL0ITTW06E89P80I4LU00P0HTDS06E89P1XBbT0Jdh/06a?;@1[CR`0JTd[06U<
:P@0Ke8X101^DBL01P1/CRX0KDl[06i@;01_DBd0L58^079D<0<0LeDa201cDRl307AB;080ME<]0`1f
E2h2071C:`80LE@/0P1bEBd207=F;P0606e@:01^DBT0Ke8Z071C:`1bEBd0LeH^0P1dEbl00`1`DRh0
KU0/06e?:`0306]=:@0H06a>:P1]Cb/0LeDa079D<01_DBd0KU0/06e?:`1^D2`0L58^075C;`1ZC2P0
JddY06e?:`1_DBd0L58^06mA;@1]Cb/0K4hZ06e@9P1/CbL0JdhV06Y<9P1YBbL0IdTW0P1VAbP00`1[
CbX0K50[06iB;@0306mC;P0:06eA;01/D2/0Ke8Z075D;01dEbl0MUTa07EH<01bEBd0KU4Y06a?9`80
K4l]00<0Jdh/06Y=:`1YC2X00P1XBbT01`1WBRP0GdLU06189P1PB2H0HDTW069::01SBbT00P1TC2X2
06A9;0060699:`1PBBX0GDPY05]8:01JAbL0F4PW0`1NAbP205e69`<0G4DV00P0FdPX05Y79`1IARH0
F4DU05M4901F@b<0ED8R05A18@80ED8T0`1D@B<305=08P80DCdT00T0CC`R04/k8@18>Ql0ACXN04<h
7012>A`0BCdS04Pl8P15>Al00P13=ad02P15>Al0B3`R04Tm8`15=Ql0ASLP04Di8@15>b80@c`R040j
800n>1h203/g7009044i9010>2<0?SHQ03de800l=1l0?CDP03hf8@0o=b80?SHQ00<0?cLR0`10>2<0
1@11>B@0?3LS03/f8P0k=R80>SDQ0080>C@P0P0h<al203Xe8@80>C@P0`0h<al00`0g<Qh0=C8O03Hc
800303Ld8@0303Db7`0c<1d0<RlL00P0<RlL00H0;c8M030b7@0`<Qd0<S4M03<`7@0e<1d203H_7@<0
=34N0P0c<1d3038_7100<S@O00P0?c`Y03`i9P0h=B80=34N03<`7@0d<Ah0=c@Q03Tf8`P0=cDP200d
=R02038`6`80<c4L0P0d<Qd203Dc7P0503@b7@0e<ah0=C<N03Hd7`0g=B000P0h=R400`0i=b80=cDP
03Le800603Le80P0=C<N00@0<38M034c7P0a<ah0<S@O0P0c=B0203@f8@03038e800a=1l0<3<N0080
;c8M00<0<3<N034d7`0b=B000P0^<Q/202la6`03034`6`0b<1/0=2lK0080=BhK0`0e=Ad503@d70<0
=SHJ0P0g=a/303Ph700@03`f800m=b40?SHO044g7P13=ad0ASPN04Li7P18>1h0Ad0T04To9018?R<0
BCdS04do9@1@@2L0E48Z05E3:`80Ed0P00<0F44Q05U28P1J@b<00P1KA2@0101LABD0GTLU05m89P1R
BbT406A=:`0706=<:P1VCbD0IdhU06Q?9P1/D2P0KU4Y079B:`0207AB;00407MJ;P1hFbl0N5/_07QK
;`80NE``0P1jGC402P21Hc40P68`07iP;P1mGbd0OV0^07mQ;`21Hc40PV@b08YY=029J3<208QW<P0=
08UX<`2;JSD0SF`g08m^>@2BKSX0Tflk09Ea?@2GLcl0V7A009Mc?`2ELCd0U70l09Ic?@0209Md?P03
09Qe?`2IMT00VWM10080VgQ20P2ONdL20:1lB0@0XGe90P2QOTP0102ROdT0Xh1:0:F2C02VPdd20:N4
CP090:J2CP2UPDd0Y81<0:B0C02UPDd0Yh=?0:V5D@2[Qe<0Z8IF00<0ZHMG0P2ZR5P20:^9F@80ZXIF
00<0ZhMG0:b8F02]RET00P2_Re/00`2`S5`0[heM0:n=G@020;2>GP<0/HmO0P2bT6040;>AH@80]99R
0P2eTf<20;BEJ@80]IIZ102fUf/80;JDIPP0^II/202iUfT30;NEI`030;RFJ02iUfT0^YQZ0080^YQZ
0`2jUfd00`2iUV`0^9E[0;NDJP020;NDJPP0]iEW202iUV`20;JDIP<0]iEW0`2hUVP30;ZGK@030;VF
K02hUF/0]iAZ0080]iAZ202gUFL40;RFJ080]iEW0P2fU6H80;JCJ@80]YAV0`2eTfD30;BBI0P0/Y=T
0P2fTfT30;FBJ0<0]95W202eTfD30;:@HP030;>AH`2dTV@0]I=U0080]I=U0P2fTF@20;F@H`030;B?
HP2bSF00/HaO0080/8]N202eT6<00`2cTF<0/Y1R0;2>H0020:n=G`030;2>H02bT680/i5S0100/Y1R
00<0/8eS0:n<HP2^Rf400P2^Rf400`2`SF<0/XmU0;>@IP030;:@HP80/HmQ0`2`SV080;:?I@80/XmY
00@0/XmW0;6>I02aSf80/8iP0P2`SUh80;:=H080/9=[0P2_TVX0302^TFT0[I1X0:b?I`2/SfL0]i9U
0;JAI02eT6<0]8mR0;:=H02aS5l0/8]N0:n:G@P0/8eS0P2aSf430;2>H0<0[heO0P2bSUh20;6=G@80
/8aL0P2_Re/80:n=G`P0/8eS0P2cT6X0102bSfL0/HiT0;6?HP2`SV020:n=G@P0[hYM2@2bSUh80;6=
G@P0/XeP202]Red20;2<G080/HeM00L0/XiN0;>?G`2cSel0]91P0;:>GP2`S5`0[XYJ0080[HUI00<0
[XYJ0;2<G02bSUh0202cSV420;:=H0060;6<G`2`Reh0[hYM0:j9G02]R5/0[8MJ0`2aS5l30;:=H080
/hiQ00h0[h]K0;2<G02bSUh0/hmO0;B@H02cSel0/XiN0;6=G@2eT6<0]8mR0;>>H@2bSF00/HaO0;2;
GP80[hYM0P2]RET20:j:FP040:n;F`2`S5`0/8aL0;6=G@P0[hmP202aS5l00`2dSf80/XeP0;6<G`02
0;2;GP030;6<G`2bSF00]8mR00<0/hiQ1@2dSf820;>>H@040;:=H02aS5l0[hYM0:j9G080[HQK00<0
[X]Q0;2=H`2bSfD00`2dTFL20;>@IP030;BBHP2cTF40/HmO00<0[heM00H0/HmO0;:@H02_SEl0[8YL
0:Z8FP2[RE/20:j<GP090;2>H02]Red0ZXQJ0:j;D@2^Re<0[haF0:n;F@2_RUd0/8]O0080/8YS202_
Re/30;2>H080/HmQ0`2bT6830;2<G0D0[h]K202/RU`20:^7E`<0ZXIF0`2YQED80:f9F@060:b6G`2/
Qed0[8MM0:b7F`2/QeX0[8QH0P2/R5H30:b8F080ZhMG0`2ZQUH30:^7E`<0ZXIF0P2YQED02P2ZQU80
Z8A@0:J2CP2UPDd0Y81<0:F1C@2VPTh0Yh=?0:V5E@2ZQUH20:^7E`060:Z6EP2YQED0Yh=C0:F1D@2X
Q5@0Yh=C0`2VPU801P2XQ5@0ZXIF0:^7E`2ZQUH0ZHEE0:N3D`80YX9B00d0Yh=C0:V5E@2ZQUH0ZXIF
0:R4E02VPU80YH5A0:B0D02UPE40YX9B0:R4E02TP500YH5A0080YX9B00@0YH5A0:=oC`2PO4`0WWY:
0`2SOTX20:9mB@<0XGa8202MNDT0102JMTH0VGE509UeA@2IMDD309QdA080Ug=30P2EL3/0102FLC`0
Ug8m09Ud?`2JMD0209]f@@80V7A01@2GLcl0102FLSh0UG5109Ea@@2ELD4409Ib@P0:09Mc@`2ELD40
UW9209Mc@`2HM4@0Ug=309Ib@P2DL400Tflo09UeA@80V7A400D0Ug=309Ib@P2ELD40UG5109A`@002
09A_@P80Tfi100@0TVe0095/?`2AK3l0T6/n0P2EL3`309A_>`<0Tfhj00<0TF`h09=^>P2DKc/00P2E
L3`00`2CKSX0TF`h08mZ=P0808m[>`80SfPm0P2>Ic`208eV>`80S6Dj00T0PE`_08=N<@25H3<0QV4d
08MR=@26HC@0Q5lb08=N<@28I3@00`27Hc<01026HS80Qf<c08MS<`27Hc<208EO>080Q5hg0`23GCH0
1@22G3D0R6<f08MR=@24Gc80PUd`0080PE`_00@0Peha08AO<P21HC80PF4b0P20H34207mO<080OUh_
0`1jFR/207]K;0<0O5`]0P1oG3H0101nFcD0OEXd07aI<`1lFC<207]H<P@0P5lf101oGSD01P22G2l0
PE/^07mJ;@1kFB/0N5PY07IG:080MEHW00@0LUHV07QE;@1hEBd0N5D]0`1gE2`207IC:`09075?:@1c
DB/0MU@^07UG<@1jF380NELa07ME;`1eDbd0NePb0080NULa00<0N5D_07MD;P1fDbd00P1eDR`00`1^
C2H0KddW075?:@0207=A:`06075?:@1_CBL0KT`V06iA:@1_DRX0LE@/0P1bEBd00`1aE2`0Ke8Z06iA
:@0406e?:@80K4hX0P1[CBL02`1TC2P0Hd/W069:9P1QBBD0HTXV06=;9`1UCBT0IThZ069:9P1SBbL0
I4`X0080IDdY00/0I4`X069:9P1QBBD0HD8U05m2901N@B<0Fd0R05]28`1LABD0GDTX05i::@0305m1
9b_ooooo000Zooooo`<0WG=10P2NM48309me@`0309ib@@2PM4<0XGE40080XWI500<0XGE40:1d@`2N
LT400P2NLT40102OLd80X7A30:5eA02RMTD20:=gAP030:=hA@2RMd@0XGI30080X7E200<0XGI30:9g
A02SN4D0102QMdD40:1fA0<0XgY600<0XWU50:5hA02QN4@00P2PMd<80:=jAP030:UnB@2WO4L0Y7U4
0080XWM200@0Y7U40:MlA`2YOTT0YgY@0P2WNdh00`2WNd`0Yg]:0:MlB@020:MlA`<0ZG]:102ZO4/2
0:]mC0<0Z7m;00<0Ygi:0:ImB@2VODT00P2UO4P80:MnBP080:IlC02WODd0Z7i<0:V0C02XOd/0Ygi8
0:ElA02TNd<20:ImA@040:ImA`2VODT0YWe90:IlBP80YWa<0`2YOT/20:YoC0<0Zh1=202XOdT40:^2
CP@0ZX5=00<0[8=?0:^2CP2YP4`00P2XOd/00`2YP4`0Zh9>0:b3C`040:N2C@@0Z8=>0P2]Pe<0102]
Pe40[HA@0:f4D02]Q4h20:f4C080ZH1800L0ZX5;0:^2CP2/Pdl0[H=A0:j4E02_QED0ZXE@0080ZhIA
00D0[8MB0:^6D@2ZQE00Z8=>0:N2C@080;22CPP0[8=?0`2XPdl20:V4D0<0ZXEA0P2ZQDh20:^6C`<0
[8M@00@0[HQA0:f8E02]R5@0[HQD0`2^RED20:n:EP060:f7FP2]QeP0[8IG0:b6E@2/Qe<0ZhIA0P2[
QTl20:V4D080Z8=?1@2WPTh20:F0B`040:AoBP2SOTT0XWe80:9mB080XGa700H0XGe30:1l@P2PNd@0
X7]609mjA@2ONTH209ihA`0609iiA02MN4@0WGQ409afA@2KMDH0VWA70P2ILTL0102IM400V7<o09Qc
?`2HLcl209Mb?P80UW4m202BKCT4091[=`0<08mZ=P2<Ic<0RVDa08QS;`22HCH0Pf8g08AS>025I3T0
Q6<h08=R=`21H3D0Oehc2023GS40201lFC<0OEXd07iK=@1oG3H0OU/e07eJ=01kF380NULa0P1iEC42
07QD<0<0Me<_00D0MU8^07ED<@1dDc00LU4^071?;00206m>:`08071?;01aD2d0L58^071B;P1_DBd0
KU0/06e?:`1/CRX206]=:@0506Y<:01YBbL0JD/W06Q:9P1WBBD00P1VB2@01`1UAb<0Gd/V05m;9P1Q
BbH0HdTV06E89P1XAbH00P1YARH00`1WBRP0ITTW06A79@0206=6900306A79@1VBBL0IdXX0080IdXX
0`1VBBL306E89P0406A79@1UB2H0IdXX06U<:P@0JTd[201^DBT206e?:`0306i@;01_DBd0L58^00@0
LE<_201cDRl307AB;080ME<]0`1fE2h206mB:P80L5<[101aE2`01@1^DBT0Ke8Z06mB:P1`Db/0LE@/
0080LUD]00@0LeH^075C;`1`DRh0KU0/0`1/CRX03@1]Cb/0KU0/07=E<@1aDbl0Ke4]06i@;01]Cb/0
KU0/06mA;@1`DRh0JT`X06]=:@1]Cb/00`1_DBd206e?:`0606mB:01_DRX0KU4Y06e?:@1/CRX0K4h/
0P1[C2d00`1[CbX0K50[06iB;@0206mC;P0606iB;@1]DB`0K50[06mB:P1aE2`0M5L_0P1fFC400`1d
Ebl0LE@/06iA:@0206a?;@0306]>;01ZCB/0JD`Z0080J4/Y00D0IdXX06A<:P1SBbT0Hd/Y069::002
06599`80H4PV0P1TBB`01P1RBB/0H4TZ05e8:@1KB2P0FTLW05Q89`<0GTLX0P1MARL305a59P0505Y7
9`1IARH0FDHV05Q59@1GA2@00P1F@b<0101E@R80ED8T05E2901E@R@205A18`<0Dd0R00/0DclV058n
9@1??R@0C3`R04Xl8@16>al0ACXN04<j7@18?280Ac/Q04Hj800204Di7`0:04Hj8017>b40B3`R04Df
7`16=b00ACTQ04Dk8P13?280@3XP03hh7P80?3PM00P0@CTT040h8`0n=R40?CDP03`d7`0m=B00?SHQ
03lg8P@0@3PS100o=b8303/f8P0303Xe8@0i=200>C@P0080>3<O0P0j=B4203Td80@0>3<O00<0=C8O
03Hc800g=2400P0g=2400`0e<Ql0<c0M038_700803<`7@06034d7`0b=1l0<S@O03@c7`0e<Ql0=c8O
0P0h<Al303@a7P80<c0M0`0b;a`@038d7`0803hk:00k>2D0>3DR03@a7P0c<1d0=34N03Ld8@0h=B88
03Le80P0=3HP100d<Qd203Dc7PH0=S@O300g=B0803Dc7P<0<C<N00<0<S@O03<e800c=B000P0d=R40
0`0c=B00<S@O030b7@0202la7003030b7@0b=1l0<cDP0080;S8K0P0_<A/00`0a<1/0<S0K03@_6`02
03D^6`D0=CDM0`0d=1`203Hf6P80=cLK0`0h>1`02`0i>Ad0?CLQ03hf8@0o=b00@SPO04@h7P17>Ah0
B3PN04Tj7@19@2<0B3lR0080BChR00@0CClT05109P1C@RP0ED@Z0P1H@B400`1I@R80FT<S05]49002
05a59@0505e69P1OB2H0H4TW069;:@1TCB/00P1UCR`206A=:`0606M@9P1XCbH0JE0W06eA:@1_DRX0
Le</0P1eDbd307QK;`80NE``0`1jGC402022I380PF<a07mQ;`1nH2h0Of4_081R<022I380PfDc0P2:
JC@308UX<`0608]Z=@2>KCP0Sfhi099^>P2CKc/0UG4m0`2GLcl209Ea?@80Ug@n00<0V7Do09Uf@02J
Md400P2KN4800`2LND<0Wg]709mkA`020:1lB0<0XGe900D0XWi:0:9oB@2ROdT0Xh1:0:B1B`020:F2
C080YX==0P2VPTh20:F1C@040:J2CP2XQ500ZXIB0:^7D`@0ZHMG0P2ZR5P20:^9F@060:Z6EP2[QeL0
[8QH0:f9F@2^RUX0[h]K0P2`S5`20;2>GP80/HmO0P2bT6070;>AH@80]99R0P2eTf<20;BEJ@80]IIZ
0`2fUf/00`2gV6`0]YAV0;JDIP060;JDIPP0^II/202iUfT20;NEI`80^9IX0P2iUfT20;ZHJP80^YM]
0P2iUV`20;REJ`80]iAZ202gUFL80;VFK080]YAV0`2gUFL30;RFJ080^YM]0P2iUV`0102hUF/0]iAZ
0;NDJP2gU6X80;NEI`040;VGJ@2hUVP0^9IX0;RFJ080]iEW0P2fU6H80;JCJ@80]YAV0`2eTfD30;BB
I0P0/Y=T00<0]95W0;FBJ02eTVP01@2eTVP80;FCI@80/Y1R0P2cTF<20;BBI080]I=U00H0]Y5T0;F@
H`2eT6<0]I1S0;B?HP2bSF020;6<G`030;2;GP2eT6<0]I1S00H0]I1S00<0/i5S0;:@HP2`SV000P2_
SEl00`2`SV00/Y1R0;>AH`0@0;:@HP030;6>I02`SF<0[haR0080[X]Q00<0/8eS0;:?I@2cT6H00`2b
T6830;6?H@80/8iP202bSfD20;:?J@040;:?I`2aSV@0/HmR0;2>H080/8iN202bSF030;6AJP80/91Y
0`2_SfP20;JAI0040;F@H`2dSf80/XeP0;6<G`80/8]N202`SF<20;6?H@<0/8iP0`2_SEl20;:>GP80
/HeM0P2`S5`20:n;F`P0[heO202`SF<0202cT6X0/XmY0;:?I`2aSV@0/HmR0;2>H02`SUh0[heM202`
Reh90;:>GPP0/HeM202bSF080:f;G@80/8aL0P2aSEd01`2bSUh0/hmO0;>?G`2cSel0/HeM0;2<G02_
Re/00P2^RUX00`2_Re/0/8aL0;6=G@080;>>H@80/XeP00@0/HaO0;2;GP2_RUd0[XUL0P2]R5/30;6<
G`<0/XeP0P2cSV40202`S5`0/HeM0;:>GP2cSel0]91P0;>?G`2aSEd0/8aL0P2dSf80102cSV40/XeP
0;6<G`2`Reh20:n:G@80[XYJ0P2_Re/0102`S5`0/HeM0;6=G@2aSEd80:n?H0P0/HaO00<0]8mR0;:=
H02aS5l00P2`Reh00`2aS5l0/XeP0;B?HP040;B?HP@0]I1S00D0]8mR0;>>H@2cSV40/XeP0;2;GP02
0:n:G@040:j9G02_S680/8eS0;:?I@80]95W00H0/i1V0;:?I@2aSV@0]99R0;>AH@2aSel20:n=G@07
0;2>GP2aSel0/Y1P0;2>H02]Red0ZhUK0:b:G0020;2>H00;0;6?H@2^S5h0ZhUK0;2=E@2_S5@0[h]G
0:n;F@2_RUd0[hYN0:n:H02_RF80202_Re/30;2>H0<0/HmQ0P2bT6830;2<G0@0[h]K00<0[XYJ0:b:
G02/RU`01P2/RU`30:b8F080ZhMG0`2ZQUH80:f9F@060:b6G`2/Qed0[8MM0:b7F`2/QeX0[8QH0P2/
R5H30:f9F@80[8QH1P2[QeL30:Z6EP80ZHEE00<0ZXIB0:R4D02WPdl00`2UPDd0102VPTh0Yh=?0:V5
E@2ZQUH20:^7E`070:Z6EP2YQED0Yh=C0:J2DP2YQED0Z8AD0:N3D`020:J2DP060:R4E02ZQUH0ZhMG
0:Z6EP2YQED0Yh=C0P2VPU801P2WPe<0ZHEE0:Z6EP2ZQUH0ZHEE0:N3D`<0YH5A00@0YX9B0:N3D`2V
PU80YX9B0P2WPe<01@2VPU80Y81@0:5mC@2PO4`0YH1<00<0Y7m;0P2SOTX20:9mB@P0Wg];0`2KMdL2
09YfAP@0VGE50P2GLSh01P2HLcl0VGA009Ye@@2KMT80W7M309ehA0L0VGE100<0V7A009Mc@`2HM4@0
1P2HM4@0202GLd<0V7A409UeA@2JMTH0VGE509QdA02FLT80UG51102HM4@309Mc@`0309Ib@P2FLD@0
UW540080UG130P2DKd8209=^@@@0UW4m0P2EL3`209A_>`0809=^>P2DKc/0UG0l09Ia?@2EL3`0U6lk
099]>@2AK3P8091/?0<0T6Tn0P2?J3d308iW?00308QS=P29I3L0RfHi0080S6Lj00<0RfHi08YU>029
I3L00P2;IcL00`2:ISH0RFDe08UU=@0308QT=0<0RF@j0P28HcT308MR>00408YU>028HcH0QV4d08AO
<P80Peha00<0Q5lb08EP<`22HS<00P22HS<2085Q<P<0P60a1P21HC82081P<@@0Oe`f101nFcD01023
HSL0PV4f089Q=P21H3D2081O=080Oehc00H0Ped`089L;`20Fbh0OE/]07YJ:`1gF2T207IG:00307AH
:01kF300NeP`00<0NUL_0`1iERh01@1fE2h0MeD_07UG<@1jF380NeTc0080NUPb00`0NELa07aI<`1l
FC<0NePb07YG<@1iES00N5D_07MD;P1fDbd0Le4[07AB;01fE2h207ME;`0607ID;P1dDR`0Le4[07AD
;@1eEBh0MeL`0P1hF3400`1gEc00MED^07AD;@02075A:`<0L50Z0`1_CbT00`1WCBP0IT`W06E;9P02
06A:9@0C06E;9P1WCBP0J4hY06E;9P1VC2L0IddX06Q>:@1WCBP0IT`W06A:9@1SBB@0ITLZ06E6:@1S
ARP0H4DW0617:01PBBT0HT/[065=;00306=5:B_ooooo000Zooooo`<0WG=10P2NM48309me@`0309ib
@@2PM4<0XGE40080XWI500<0XGE40:1d@`2NLT400P2OLd820:1d@`070:5eA02RMTD0XgM60:=gAP2S
N4D0XWM40:5f@`020:1e@P030:5f@`2RMd@0XgQ500@0X7I4102QMdD20:=jAP<0XWU50`2QN4@80:9i
A@030:QmB02WO4L0Y7U40080XWM200@0Y7U40:MlA`2XODP0YgY@0P2WNdh00`2WNd`0Yg]:0:MlB@02
0:MlA`<0Yg]:102XO4/20:UmC080Z7m;0`2WOTX30:ImB@P0Ygi:0P2UNd/01@2WOD/0Z7m;0:QoB`2X
OdT0Ygi600<0YWe500@0YWe70:ImB@2VODT0YWa:0P2VO4`0102[P4d0ZWm<0:YoC02ZOd`40:UnB`P0
Z7m9102ZPDd40:^2CP80ZX5=00@0ZH1<0:QoB`2XOd/0ZH1<0P2ZPDd40:R3CP@0Yh9=0P2/PU80102/
PU00[8=?0:b3C`2/Pdd20:b3B`060:V0B02ZPDT0ZX5;0:^2CP2/Pdl0[H=A0P2^Q5@00`2/Qe80ZhIA
0:Z5D0030:V4C`80ZXE@202^Pdh80:b3C`80Z8=?0P2YQ5030:Z5D@040:^6DP2[QU40ZhIA0:^6D@80
[8MB0`2]R5<30:f8E0<0[XUE0P2_RUH01P2^R5/0[XQI0:j8F@2]QeH0[HQD0:f8D`80[8M@0`2YQ502
0:R3C`@0Yh9>0P2VPD`00`2UP4/0Y7m:0:=nB@020:9mB0070:5lA`2ROT@0XGe30:5lA@2QO4L0X7]6
0:1kA`0209miB00609mjA@2NNDD0WWU509egAP2LMTL0VgE80P2JLdP309Ud@080V7<o0`2GLSh809=^
>P09091[=`2AK3P0TF`h095/>02?JSH0SFPd08]V<P29I300QF8h0080QV<i00<0Qf@j08IS>@25HSP0
0P23H3H01P26HC@0QF0c08EP<`24Gc80Peha089M<080PE`_00P0OEXb07iK<`1oG3@0P5de07mL=01n
Fc<0O5Ta07]H<080O5Tc0P1kF38207YG<@80NEH`00@0MUDb07ED<@1cDRl0LE0]0P1`Cb`01`1aD2d0
LU4^071B;P1`DRh0Ke4]06i@;01]Cb/00P1/CRX00`1[CBT0J4XV06Q:9P0606Q:9P80HD/V00@0HTXV
06=99P1UB2H0ITPV0P1XAbH00`1WBRP0ITTW06E89P0206A79@0406E89P1VBBL0IdXX06A79@<0IDPV
201VBBL0101WBRP0J4/Y06Y=:`1[CR`706e@:00406iA:@1^D2`0KU0/06i@;0H0Ke4]201bDBh3079B
:`80Le</0`1dE2d206e@:080KU4Y0`1_DRX9071C:`0;079D<01aDbl0Ke4]06i@;01]Cb/0KU0/06mA
;@1`DRh0LU@`075C;`1_DBd00`1^D2`206mA;@0506]=:@1/CRX0KDl[06i@;01_DBd00P1^D2`01`1]
Cb/0L5<Y071C:`1`Db/0L58/071B;P1`DS000P1_D3400`1[CbX0K50[06iB;@0206mC;P0;06iB;@1/
D2/0JdlZ06iA:@1`Db/0LeH^07II<@1gFS80MUTa07AG;`1bEBd00P1/Cbd00`1[CR`0JTd[06U<:P02
06Q;:@0906M::01WCbd0ITh/06E=:`1SBbT0HDTW05m79@1MAB<0G4@R0080I4T/00H0HTT[0619:P1M
B2T0FdPX05Y79`1HB2L305i7:080GDHW0`1LABH405Q59@@0Ed@T00@0ET<U05E2901E@R@0ED8T0P1D
@B<205=08P80E40W00H0DD0V04hn901<?R<0BChR04Pm8@16?B0204Hj800404Lk8@18?280B3`R04Lk
8@80ASXP00L0ASLP04Lh8@16>R80AC/R048k8@10>R00?cTO0080?CTN00<0@SXU044i900o=b800`0m
=B0203lg8P05048j9@11>B@0@CTT040h8`0o=b800P0n=R400`0m=B00>cHR03/f8P0303Xe8@<0>C@P
0`0j=B4203Td80<0>3<O0P0e<Ql303Ld8@0303Db7`0d<Ah0<RlL00P0=C8O00H0<SDP03<e800c=B00
=C@P03Hc800h<b0203Tb80<0=C8O0P0d<Ah303<`7A00<S@O00P0?CXW03Xg900g=240=C8O03@a7P0e
<Ql0=c@Q03Pe8PP0=cDP200d=R00100e<ah0=S@O03Hd7`0f=1l203Le8080>3HQ100g=B0403Hd7`P0
=cDP200f=1l2034c7P<0<S@O0`0c=B000`0b=1l0<C<N02la700202h`6`0302la700a<ah0<S@O0080
;c<L0P0`<Q`00`0b<A`0<c4L03D`700203H_70L0=S@M00<0=cDN03Pg6`0h=a/00P0i>1`303Xi7@0:
03/j7P0o=b00@3PQ048h7`14>1h0AcTN04Tj7@1:>ah0BcXL04U08`80BChR00D0BcdR04dm8`1A@2H0
ED4X05M3:P0205Y38@0405]48P1LAB<0GDHT05e69080GTLU00@0HTXV06=;9`1UCBT0Idl[0P1XD2`0
201WCb/0IThZ06UB9P1[DbL0K5@X06mD:@1aE2X0MED/0P1gERd307UL<080NUda0`1kGS802@22I380
PF<a081R<020HS00PF<a089T<P23IC<0Q6Hd08]Z=@0308YY=00708]Z=@2=K3L0Sfhi091_>P2CKc/0
U70l09Ea?@0309Mc?`80UW8n00H0Ug@n09Qe?`2HMCl0VGI009Yg@@2KN48209ai@`<0X7a80P2QODT3
0:9nBP<0Y85;1@2UPT`0202WPdl0YX9>0:J2CP2UPDd0YX9>0:R4D02ZQU80[8QD0`2YQeL20:Z8F0<0
ZhUI0P2/R5P20:f9F@040:j:FP2_Re/0/8aL0;2<G0<0/Y1P0P2cTF430;BBHP@0/i5Q0P2dTV830;FC
H`<0]IIZ0P2fUf/30;NHK0P0]iEW202iUV`80;VGJ@040;NEI`2hUVP0^9IX0;RFJ0<0^IMY00<0^YQZ
0;ZGK@2iUV`00P2iUV`30;REJ`030;NDJP2gUFL0]iEW00H0]iEW202iUV`20;JDIP<0]iEW0`2hUVP3
0;VFK080^9E[0`2gU6X80;NEI`<0^IMY0P2hUVP30;NEI`P0]Y=Y0P2fU6H30;FCI@<0]99T202bTf@2
0;>@IP80]95W00@0]I9X0;JCJ@2gU6X0]iAZ202eTfD0102bT680/i5S0;>AH`2cTF<30;BBI0030;FC
I@2eT6<0]I1S0080]8mR0P2cSV400`2bSF00/HaO0;6<G`080;F@H`030;>AH`2bT680/HmQ0080/8iP
00<0/HmQ0;:@HP2cTF<0402bT680202aSV@0/8eS0:n<HP2^Rf40[haR0;2=H`2bSfD0/i1V0P2cTF<2
0;:@HP<0/HmQ00<0/8iP0;:?I@2bSfD01P2bSfD20;:?J@040;:?I`2aSV@0/HmR0;2>H080/8iN202b
SF040:n?IP<0/91W00@0/I5X0;F@H`2eT6<0]8mR0P2cSV400`2bSF00/HaO0;6<G`080;2=H`80/HmQ
0`2`SV030:n=G`80/XiN0P2aSEd20;2<G080[h]K202_SEl80;2=H`80/XmY00@0/XmW0;6>I02aSf80
/8iP0P2`SUh80;6<G`T0/XiN202aSEd80;:=H0P0[XaN0`2aSEd30;:>GP80/hmO00<0/HeM0;2<G02_
Re/00`2_Re/00`2`S5`0/HeM0;>>H@070;>>H@80/XeP00@0/HaO0;2;GP2_RUd0[hYM0P2^RE`30;6<
G`<0/XeP0P2cSV400`2`S5`0/HeM0;>?G`020;B@H0030;:>GP2aSEd0/8aL0080/hiQ0P2bSF00102a
S5l0/8]N0:n:G@2_RUd20;2<G0<0/HeM0`2bSUh80;2>H0P0/HaO00<0]8mR0;:=H02aS5l00P2`Reh0
0`2aS5l0/XeP0;B?HP080;JAI0050;F@H`2dSf80]8mR0;>>H@2bSF000P2aS5l02@2`Reh0/HiT0;:?
I@2cT6H0]95W0;>@IP2bSfD0/8eS0:n<HP020;>AH@030;6?G`2`SUh0[heM0080/8iN00D0/HmO0;:@
HP2_SEl0[8YL0:f;G@020;6?H@090;:@HP2`SV00[H]M0;6>F02aSET0/8aH0;2<FP2_Re/0[XUL0080
[HQL202_Re/20:n=G`80/8iP0`2aSf400`2bT680/HeM0;2<G0020;2<G0040:n;F`2^RUX0[XYJ0:j:
FPP0[H]M0`2^RUX20:f9F@<0[8QH202]RET01P2/QUl0[8MM0:b7G@2/Qe/0[8MJ0:b8F080[8QF0P2_
Re/20:j:FP80[HUI0P2/R5P30:^7E`<0ZXIF0P2YQED02`2ZQU80ZHEA0:N3C`2VPTh0YH5=0:J2CP2W
Pdl0Z8A@0:R4E02YQED0ZXIF0080ZhMG00d0ZHEE0:N3D`2VPU80ZHEE0:R4E02WPe<0YX9B0:N3D`2X
Q5@0ZXIF0:^7E`2ZQUH0ZHEE00@0Z8AD00D0ZHEE0:Z6EP2ZQUH0ZHEE0:N3D`030:J2DP80Yh=C102X
Q5@0102WPe<0YX9B0:B0D02SOdl20:N2CP80YX5=0`2UP4`00`2TOd/0XGe=0:5mC@060:5mC@<0WWY:
0P2MNDT409ahB00609Ye@@2KMT80VgI209ag@`2MN4@0WWU50P2ONTH809ahA0P0VgM700<0VWI609]g
A`2LN4P00P2MNDT00`2KMdL0VGE509QdA00209QdA0<0VGE50`2JMTH0102JMDP0VGA709UdA`2IM4L3
09QcAP0409MbA@2IM400VGA009Ud@080V7<o0`2GLSh0202FLCd0Ug8n09Mb?P2HLcl0Ug8n09Ia?@2E
L3`0U6lk202BKSh3099/?`80TF/n0`2@JSd2091[?P06095/?`2BKD00TVe0095/?`2@Jch0SfXm0P2@
K3`01P2?Jc/0SVXj08eY>@2;IcL0RVHf08UU=@<0SVTo0P2=J3h308aW?@0408aW>P2;IST0RF@g08MR
=@<0QV4d00@0Qf8e08ES=@25HcD0QF<e0P24HS@308=Q<`80RVPj00@0RFLi08QV>028ISP0QfDg0P26
I3H408=M=P<0Q5hg00L0QElh08MT>P27I3X0QV<i08ER>024HCL0PUle0080PEhd00H0QElb08AN<@22
GC00Oed_07eM;P1kG2d207YK;00407MK:`1oG3@0Oe`d07mL=080OU/c0`1mFS80201oG3@0OU/c07eJ
<P1mFS80OU/c07mL=020GCD0PEhf0P1nFc<0101mFS80O5Ta07aI<@1kF30307YG;`0:07]H<01lFC40
OEXb07eJ<P1lFC40NeP`07YG;`1iFC00NUXa07]K<P80O5`c00<0Ne/b07YJ<@1iFC000P1dE2d207=C
;080LU8[0P1aDBX00`1/D2/0JdlZ06Y>:@0206U=:00C06Y>:@1[CbX0K50[06Y>:@1[CbX0K50[06eA
;01/D2/0JThY06U=:01WBbH0Kdh_06i=;P1ZBb`0J4/[06I<:`1UCB/0IDh/06I?;@0306Q:;R_ooooo
000Zooooo`<0WG=10P2NM48309me@`0309ib@@2PM4<0XGE40080XWI500<0XGE40:1d@`2NLT400`2P
M4<00`2QMD@0XWI50:9fA@020:=gAP030:=hA@2RMd@0XGI30080X7E200@0XGI30:9gA02SN4D0WWA2
0P2OMD<01@2PMT@0XGM50:9hAP2RN4H0XgU700H0XWU50P2QN4@80:9iA@030:MlA`2VNdH0Y7U40080
XgQ300@0Y7U40:IkAP2WO4L0YgY@0P2WNdh00`2WNd`0Yg]:0:MlB@020:MlA`<0YWa:102WOD/20:Qn
C0H0Ygi:0P2VODT80:MnBP080:AjBP2UNd/0YWa:0:MnBP2XOd/0Z7m90:QoA`2YP4P20:MnAP040:Mn
B02WOTX0Ygi:0:MmB`80Yge=00H0[85>0:^0C@2[P4d0ZWm<0:UnB`2XODX20:MlB@P0Z7m9102ZPDd4
0:^2CP80ZH1<102XOd/20:V0C0@0Z8=>102WPTd20:b2DP040:b2D02/Pdl0[8=?0:b3C@80[8=;0P2Z
PDT0102[PT`0Zh9>0:b3C`2]Pe420:f3D`030:f8D`2/Qe80ZHA?0080Yh9=00<0ZHA?0:^6D@2]R5<0
202]Q4h80:f4D0<0ZHA@0`2ZQE440:^6DP<0[8MC1P2]R5@30:j9E@80[hYF00H0[hUL0:n9FP2_REX0
[hUH0:j9E@2^RE@20:f8D@80ZXEA0P2YQ5030:R3C`80Yh9>0P2WPTd0102VPD`0YH1;0:AoBP2SOTT2
0:9mB080Xgm500@0XWe60:9mB02RODP0XGa80P2QNdX01P2ONTD0WgY609iiA@2NN4L0WGM809afB@80
VgA90`2IM40309Qc?`80Ug8n202DKc/0202AK3P0TVdi099]>@2BKCT0T6/g08iY=@2;IS80RVDa0`2:
ICT208UT>080R6<g0180Qf8f08UT=`28HcH0Qf8e08EP<`23GS40PUd`085L;`20Fbh0OU/a07mL<P20
GC<0PEhd081M<`1oG380OEX`07aI;`1oG3@307iK<`80OEXb0P1lFC40101hF380MUH`07AD;P1bDR`2
075A:`03079B;01cDbd0LE<_0080L58^00<0Ke4]06i@;01]Cb/00P1/CRX306Q:9P80JD/W0`1ZC2P0
1@1UBbP0I4XW06A:9`1TBRL0ITTW00<0IDPV0`1VBBL206E89P<0ITTW0P1SAR@0101TAbD0IDPV06E8
9P1VBBL206M::00806Q;:@1VBBL0I4LU06=6901TAbD0ITTW06U<:P1[CR`406a>:0@0KDlY0P1_DBd3
06i@;0@0KDl[201aD2d206mB:P<0L5<[0`1aE2`306a?9`80KE0X0`1^DBT3071C:`80Ke8Z0`1^DBT0
201cEC40LU@`071B;P1_DBd0KU0/06mA;@1`DRh0LE<_0P1`DRh206mA;@@0KU0/0P1/CRX206e?:`@0
KU0/00H0KU4W06iA:@1^DBT0Ke4[06mA;@1_DBl2071A<P80K50[0`1^DRd02`1]DB`0JdlZ06Y>:@1]
D2P0Ke8Z079E;@1eF300MUTa07MJ<P1fFC40MEP`0080K4l]00<0Jdh/06Y=:`1YC2X00P1XBbT02@1W
BRP0IDd[06E=:`1TC2X0HTXX06599`1PB2H0GdLU05i6900206A9;0060699:`1PBBX0GDPY05]8:01J
AbL0F4PW0`1NAbP205e69`<0G4DV00@0ET<S05M4901GA2@0Ed@T0`1HABD00`1IARH0ET<U05I39@03
05E290<0E44S0P1E@BP02@1B@BL0D40V04i09@1;@2@0BSlS04U08`14>1h0ASXP04Pl8P0204Xn9003
04Pl8P16>R00A3PN0080B3TR00<0ASXR04@j8@12>b400P10>R0203hj7`0@048j9@11>B@0?cLR03hf
8@0m=B00?SHQ03lg8P10>2<0@c/V048j9@11>B@0@3PS03lg8P0n=R40?CDP03`d7`H0>SDQ0P0i=202
03/f8P80>SDQ0P0i=20203Pc7`0303@a7P0e<Ql0=S<P0080=c@Q00<0=S<P03@a7P0c<1d0200g=240
1P0c=R40=3HQ03@f8@0f=B40=c@Q03Td8@80>S<Q0P0f<b0303Db7`<0=34N400b=1l0200k>2D0>CHS
03Ld8@0e<Ql0=34N03Db7`0f<b00=c@Q200g=B0803Dg8@<0=cDP0P0h=R4403Tg8P80>3HQ00D0=cDP
03Hd7`0e<ah0=C<N03@b7@0803Le80P0=S@O1P0b=1l203<e800303@c7`0c<Qh0<C0L0080<2lK00<0
<C0L03<b7P0d<al00P0a=Ah2038d7P0303@c7P0e<ah0=c8N0080>34N00<0>3<M03Td7P0i=1h00P0i
=1h303Xe7`<0?3PM0`0m>Ah203hj7`80@cTP00H0ACTO04Pj7`1:>ah0C3/O04dl7P1??1h204Xo8@06
04/m801=?R40CchR05A09@1G@RL0FD@Y0P1LAR400`1MAb80GTPS05m99002061:9@05065;9P1UBbH0
IT`W06Q>:@1ZD2/00P1[DB`206Y@:`0906aF9`1]EBL0KUHX079G:P1dEb/0MeP/07UH;@1jFBh0NUda
00<0Nehb0P1lGc<207eP=0<0PV@b0P23IC<00`24IS@0QFLe08IX=P0208]Z=@80S6/f00D0SF`g08i]
>02@KcX0T6lj09A`?00209Ea?@0309Ib?P2GLcl0Ug<o0080Ug<o00H0V7Do09Uf@02IMT00VWM109]h
@P2LND<209ejA080X7a80`2QODT30:9nBP<0YX==0P2UPT`30:B1B`080:R4D02WPdl0YX9>0:J2CP2W
Pdl0ZHEA0:^7D`2]RED20:V7E`80ZXQH0P2[RET20:b:FP80[HUI0P2^RUX0102_Re/0/8aL0;2<G02`
S5`30;>AH@80]99R0`2eTf<30;>AH@80]99R0P2eTf<20;JDI080]IIZ0`2fUf/30;NHK0P0]iEW202i
UV`80;VGJ@@0^9IX102iUfT40;VFK0@0^9E[202gUFL80;VFK080]YAV0`2gUFL30;RFJ0@0^9E[102g
U6X80;NEI`<0^IMY0`2hUVP20;NEI`P0]Y=Y0P2fU6H30;FCI@<0]99T202bTf@01P2aSV@0/XmU0;>@
IP2dTFL0]I9X0;NDJP80^9E[202fU6H40;>AH`@0]99T00@0]I1S0;B?HP2dSf80]8mR0P2cSV420;:=
H0030;6<G`2eT6<0]I1S00H0]I1S602bT6800`2aSV@0/8eS0:n<HP020:n<HP030;6>I02cT6H0]95W
00<0/i5S0P2bT6830;6?H@P0/XmU0P2bSfT0102bSfL0/HiT0;6?HP2`SV020;2>GPP0/hiQ0P2^SF80
0`2_SV<0/8mT0;6@I@020;:AIP030;>BI`2dSf80]8mR00@0/hiQ0P2bSF080;2=H`80/HmQ0`2`SV03
0:n=G`80/XiN0P2aSEd20;2<G080[h]K202_SEl80;2=H`80/HiX00@0/HiV0;6>I02aSf80/HmQ0P2a
Sel80;:=H0T0/XiN202aSEd80;:=H0P0[XaN0P2aSEd60;:>GP030;6=G@2`S5`0/8aL00@0/8aL00<0
/HeM0;>>H@2cSV401P2cSV420;:=H080/HaO00@0/8]N0:n:G@2_RUd0[hYM0`2aS5l30;:=H080/hiQ
00P0/HeM0;:>GP2cSel0]91P0;>?G`2bSUh0/8aL0:n;F`<0/XeP00<0/HaO0;2;GP2`Reh00P2_RUd5
0;:>GP<0/hmO402bSF000`2dSf80/XeP0;6<G`020;2;GP030;6<G`2bSF00]8mR00<0]i9U102fTF@3
0;F@H`80]8mR0P2cSV420;:=H080/XmU0`2cT6H0102aSV@0[haR0:f:H02cTF420;:@H0030;6?G`2`
SUh0/8iN0080/8iN00@0/i5S0;2>H02]Red0[heO0P2bT6802@2cTF<0/HmQ0:j<GP2cSed0/XiL0;6=
F`2`S5`0[h]K0:f9F@020:b7FPP0[h]K0`2_SEl20;2>H0<0/HmQ0P2aSEd20;2<G0040:n;F`2^RUX0
[XYJ0:f9F@P0[H]M00@0/8aL0:n;F`2_Re/0[h]K0P2^RUX:0:f9F@060:b6G`2/Qed0[8MM0:b7F`2/
QeX0[8QH0P2/R5H20;2<G080[h]K0`2^RUX0102]RET0ZhMG0:^7E`2[QeL30:Z6EP80ZHEE00/0ZhMC
0:V5D@2WPdl0YX9>0:F1C@2VPTh0Yh=?0:R4D02XQ5@0ZHEE0:Z6EP020:^7E`050:Z6EP2XQ5@0Yh=C
0:V5E@2XQ5@00`2WPe<00`2YQED0ZhMG0:b8F0030:Z6EP80ZHEE0`2ZQUH20:V5E@030:R4E02WPe<0
Yh=C00<0Yh=C102YQED0102XQ5@0Yh=C0:N3D`2VPU820:V4D080Z8=?0`2WPTh00`2VPDd0Xgm?0:=o
C`060:=oC`<0XGe=0P2PO4`409mkB`80WWQ70P2ONDP0102PNTT0XG]:0:5kBP2QNdX409ijAP@0Wg]7
102ONd/509ijBP0709mkB`2PO4`0X7a<0:1lC02NNTX0WGU909]gA`0209UeA@0309YfAP2KMdL0W7Q8
0080WGU900<0WWY:09ehB`2MN4/00`2MN4/309agBP80WGQ40P2LMd<309]f@PH0VWE100<0VGA009Qc
?`2HLcl0202ELD40102FL440UFm009E_@02EKd0209A^?`80Tfdn00@0U6m209E`@`2EL4<0UG130P2D
Kd8209=^@@<0UG5100D0U710099^?P2?Jc/0SFTi08]W=`03091[?`80SfXn0`2>JCd208iY?00308eX
>`2<IcX0RfHi00<0RVDh00@0RfHi08YU>02:ICP0RVDh0P29I3L208QS=P80T6/n00L0SfXm08iY?02<
IcX0RfHi08YU>029I3L0QUlf0080Qf0g00D0R64h08UR>@2:HcX0RV<j08]T>`0208eX?00;08]V>P2:
ICT0RF@h08MR=P26HCD0QF0d08QR=@27HC@0QV4d08=Q<`21HC800`1nGc000`1kGbl0Q64i08AQ>@02
08=P>0<0PUlg00@0PEhf08QS>@27HSP0Q5le0P23GS@00`25H3H0Qf8h08UT>P02085N=080P5dc0P1o
G38207iK<@80OeX`1020Fc4207mJ<0<0OE`a0P1nGC8307eL<@<0N5L^0P1gERd307IE;003075E;P1`
E2d0KU8[0080K50Y00D0KE4Z06iB:`1_Db`0KU8[06mC;002071D;@0:06mC;01^DR/0K50Y06Y>9`1b
Cbl0L4l^06m>;@1/CR`0JTd[06Q>:`80IThZ0`1YC2h[ooooo`00:_ooool309ec@@80WWA20`2OMD<0
0`2NLT40X7A30:5eA0020:9fA@030:5eA02PM4<0WW9100<0XGE4102RMTD0102SMdH0XgQ50:9gA02Q
MT<20:1e@P040:5f@`2RMd@0XgQ509id@P80WgE300D0X7I40:5gA@2RN4H0XWQ60:=iA`020:5hA0h0
XWU500<0Yga70:IkAP2UNTD00P2TND@0102UNTD0YW]60:MlA`2WNU020:MkCP030:MkC02WNdX0Yga9
0080Yga70`2UODX40:InB`80Ygm<0P2VODT>0:MnBP80YG];00@0YG]90:ImB@2WOTX0Z7m90P2YP4P2
0:MnAP040:MnB02WOTX0Ygi:0:MmB`80Yge=0P2[P4d00`2ZOd`0ZGi;0:QmBP020:MlB@030:IkB02X
OdT0Z7m900H0Z7m90P2YP4`20:Z1C@80Zh9>0P2/Pdl00`2XOd/0ZH1<0:V0C0040:V0C0030:QoB`2Y
Q4l0ZHA?0080Z8=>0P2WPTd20:J1C080[89B00@0[89@0:b3C`2/Pdl0[8==0P2/Pd/20:^2BP090:^2
C02/Pdl0[8=?0:b2D02/PU80[H=C0:f8D`2[QU40ZHA?0080Yh9=00<0ZHA?0:b7DP2]R5<0202/QDh8
0:f4D080ZHA@0`2ZQE430:^6DP<0[8IE0`2]QeH20:j8E`<0[HQD0`2^RED20:n:EP060:n9G02_REX0
[hUJ0:n9F02^RED0[XUD0P2]R5430:Z5D@80ZHA@102XPdl20:R3CP040:N2C@2VPD`0YH1;0:AoBP80
Xgi90P2TP4H0102TOdP0Xgi90:=nB@2SOTX20:9lB`060:1kAP2PNdL0WgY609ihA`2MMdP0WGM:0P2L
MDX209Ye@@<0VGA00`2HLcl809E`?008099]>@2CKSX0Tfhj09=^>P2AK3P0SfXf08aW<`2;IS8208aW
>P80RfHi1P2:ICP03P28HcH0QV4d08AO<P22GC00PE`_081K;P1oGC00P5ha085O<P22H3<0PElb081N
<@1nG2l0O5X]0`20GC<307mL<P80OU/a00@0NETb07QH<@1fERl0M5@]0P1cDb`207AD;@80LE<_00<0
L58^06mA;@1^D2`00P1]Cb/0101/CRX0JD/W06U;9`1YBbL206Y<:0<0JddY0P1XBbT206M::00406A:
9`1SBBH0HdTV06=99P<0ITTW0P1WBRP306I99`0506958`1SAR@0HdHT06A79@1UB2H00P1VBBL02@1W
BRP0J4/Y06I99`1TAbD0HTDS06=6901UB2H0IdXX06U<:P0206Y<:080JddY0P1/CRX206e?:`80KU0/
0`1]Cb/406a>:PP0L4l/0P1]DBT206iB:P@0Ke<[0P1[CRH206a?9`<0KE0X00@0KU4Y06mB:P1_DRX0
Ke8Z0P1^DBT306e@:00807=E<@1bE300L58^06mA;@1^D2`0Ke4]071B;P1aDbl406mA;@80KU0/0P1]
Cb/306a>:P80KDl[0P1^D2`01`1_DBd0JdhT06]>9P1[CRH0K4hX06a>:P1/CR`00P1]CRl03@1/D2/0
KE4/06iB;@1^DRd0KE4/06a@:`1ZCRT0JDdX06a?9`1]D2P0L5<[07=F;P1eF3000`1fFC4206a?;@03
06]>;01ZCB/0JD`Z0080J4/Y00@0IdXX06599`1QBBL0HDTW0`1RBRP206=;:@80I4T/00H0HTT[0619
:P1MB2T0FdPX05Y79`1HB2L305i7:080GDHW0`1LABH0101F@b<0Ed@T05M4901GA2@305Q59@0405U6
9P1F@bD0ET<U05I39@<0ED8T0P1D@B<01@1F@RT0ED4X05=2:01A@BL0Cd4V0080C44U00@0BT4T04Di
7`17>b40BCdS0P1;?bD02019?B<0Ac/Q04Di7`19>R<0B3TR04Hj8P14>R40@S/Q0P10>R0203lk8003
04<k9P12>RD0@3PS00<0?SHQ00X0?cLR040h8`13>bH0@SXU044i9010>2<0?cLR03hf8@0m=B00?3@O
0P0i=20603Xe8@<0>cHR0P0j=B4303Td800303<`7@0d<Ah0=S<P0080=c@Q00<0=S<P03Db7`0d<Ah0
200g=2401P0c=R40=3HQ03@f8@0f=B40=c@Q03Td8@80>S<Q0P0g=24203Hc80@0=C8O400b=1l203Pe
8P0603Hc800e<Ql0=C8O03Db7`0f<b00=c@Q200g=B0803Dg8@0403Le800h=R40>3HQ03Pf8@80>CLR
0P0j>2<01@0i=b80>3HQ03Pf8@0g=B00=S@O0080=C<N00<0=38M03Le800g=B003P0g=B0203<e80H0
<S@O00<0=S<P03Db7`0c<1d00P0b;a`00`0c<1d0=C8O03Hc8002038f7`80<cDO00<0=C@O03Hd7`0h
<al00P0i<Ql303Xd7P0303/e7`0l=R00?3HP0080?CLQ0P0n>1h303li7`<0@3XP0P16>R001P19>b00
Bc/Q04dl801>?Al0DChN058m7P80CT4Q00L0CSlP050o8@1C@280ET4T05]39`1MABT0GTPS0080GdTT
00<0H4XU065;9P1RC2L00P1SCBP0101YCBH0JdlX06eA:P1_Db`2071D;@0:06mC;01^DR/0KeTX071H
:01aFBT0M5TZ07MK;01jFbd0O5/^07eL;`<0O5lc0P1mH3@307iQ=@06089T<P23IC<0Q6Hd08EW=@26
J3H0QfTg0P28JSP208a[=P0408i]>02?KST0T6lj091_>P80TG0k1@2FLSh0102GLcl0V7A009Qd@02I
MT0209Yg@@0309]h@P2LND<0WGY40080WW]50`2QODT30:9nBP80Xgm;00@0YhA>0:J3C@2VPdd0YX==
0`2UPT`00`2TPD/0ZHEA0:R4D0020:N3C`040:R4D02ZQU80[8QD0:j:EP<0ZXQH0P2[RET30:b:FP<0
[h]K102`S5`0102aSEd0/i5Q0;>AH@2cTF420;BBHP<0]I=S102dTV820;FCH`<0]YAT0`2fUf/30;NH
K080^9U]202hUVP80;VFK0`0^IMY102hUVP40;REJ`@0^II/202gUFL80;VFK080]YAV0`2gUFL30;RF
J0P0]iAZ202gUFL20;ZHJP<0^IMY0`2hUVP80;JCJ@80]YAV0`2eTfD30;BBI0P0/Y=T00H0/HiT0;:?
I@2cT6H0]95W0;FBJ02gU6X20;REJ`P0]YAV102dTV@40;>AH`80]8mR1@2cSV420;:=H0P0]8mR0P2b
T6840;>AHa80/Y1R00P0/XmU0;6>I02`SF<0[haR0;2=H`2aSV@0/i1V0;BAI`80]99T0P2cTF<20;:@
HP80/HmQ202bSfD20;:?J@040;:?I`2aSV@0/HmR0;2>H080/8iN202cSV401P2^S5l0[heP0:n=H02`
SV40/HmR0;:@H`80/i5T0P2bSF040;>>H@80]8mR202`SF<20;6?H@<0/8iP0`2_SEl20;:>GP80/HeM
0P2`S5`20:n;F`P0[heO202`SF<20;6>J0040;6>IP2aSV@0/HmR0;6?H@80/HmO202bSF090;:>GPP0
/HeM202bSF080:n=G`H0/XiN0P2aSEd00`2`S5`0/HeM0;6=G@040;6=G@030;2<G02cSV40/hiQ00H0
/hiQ00<0/XeP0;6<G`2aS5l00P2aS5l30;2;GP<0/HaO0`2bSF020;>>H@80/XiN00H0/hmO0;B@H02c
Sel0/XiN0;2<G02^RUX30;6<G`@0/8]N00@0[hYM0;>?G`2cSel0/hmO1@2bSUh@0;:=H0030;B?HP2b
SF00/HaO0080/8]N00<0/HaO0;:=H02dSf800`2gTVD00`2fTF@0]I1S0;F@H`060;B?HP@0/hiQ00P0
/HiT0;:?I@2cT6H0/i1V0;:?I@2`SF<0[X]Q0:f:H0@0/Y1P00P0/HmO0;2>GP2`SUh0[heM0;>AH`2`
SV00[H]M0:n=G`80/Y1R00T0/i5S0;6?H@2^S5h0/hiQ0;:=H02aSEd0/8aL0:n;F`2]REL00P2/R5H8
0:n;F`80[XaN0P2_SEl20;2>H080/HmQ0P2bSUh01P2aSEd0/8aL0:n;F`2^RUX0[HUI0:b8F0P0[XaN
0P2`S5`30:n;F`<0[XYJ202]RET01P2/QUl0[8MM0:b7G@2/Qe/0[8MJ0:b8F080[8QF0P2`S5`20:n;
F`<0[XYJ00@0[HUI0:^7E`2[QeL0ZhMG0`2ZQUH20:V5E@030:^7D`2ZQU80Z8A@0080YX9>00H0Yh=?
0:R4D02YQE40Yh=C0:R4E02ZQUH20:^7E`0<0:Z6EP2YQED0Z8AD0:Z6EP2YQED0Z8AD0:N3D`2XQ5@0
ZHEE0:^7E`2/R5P0ZXIF1P2[QeL00`2ZQUH0ZHEE0:V5E@020:V5E@050:R4E02WPe<0Yh=C0:J2DP2Z
QUH00P2YQED50:R4E080ZXEA0P2YQ5030:R3C`030:N2CP2TP500Y81@00H0Y81@0P2SOdl30:9nCP@0
XGe=102QNd`40:9lC@80Wg]70P2PO4P20:5mB@80XWi:0`2ROTh00`2QODd0X7a<0:1lC00209mkB`09
0:1lC02QODd0XWi>0:=oC`2ROTh0XGe=09mkB`2NNTX0VgM70080W7Q800<0WGU909ijBP2ONd/00P2P
O4`80:1kCP040:5lB02PNdL0X7]70:1kA`80WgY6102NNDD00`2MN4@0W7M309ag@`0309ag@`P0V7A4
0P2ILd8209Qb@@<0Ug5000@0UW0o09MbA@2FLD@0UG130P2DKd8309=^@@0809Mc@`2HM4@0V7A409Qd
A02FLT80Tflo091/?02>JSX2091[?P80SfXm0`2>JC`01`2=J3/0TF`o095/?`2AK3l0T6/n08mZ?@2>
JC`00P2=J3/208iY?080SFPk0`2<IcX02@2;IST0T6/n091[?P2?JSd0SFPk08aW>P2;IST0RVDh08UT
=`0208eS>@80SV@j00X0SfDk091V?02AIcd0TFLm091[?P2?JSd0SVTl08eX>`2<IcX0RfHi0P2:ICP2
08]U>00408UT=`26I3H0QFDf08=T=@80PV<d00<0P6@d08QU?@27I3`00P27I3`208IS>`80QF8j00<0
SFPl08aW>`29I3P00P27HSH00`29I3P0RfHj08eX?00408AR=@@0Pf4d0`20Fbl207mJ;P<0P5/_0P1n
G2l407eK;P80OU`_0`1mFS0207aI;`<0NeP^00<0MUTa07EH<01cERh00`1aE2`00`1bEBd0LeH^07AG
;`0307EH<00<07AG;`1bEBd0L5<[06iA:@1bCRh0LDh^071=;@1_CRd0K4h/06Y=:`1WCBX0IT`Y0`1X
Bb/[ooooo`00:_ooool309ec@@80WWA20`2OMD<00`2NLT40X7A30:5eA0020:9fA@030:5eA02PM4<0
WW9100P0XWI500<0XgQ50:9gA02QMT<00P2PMD800`2QMT<0XWM40:=hA@040:1fA0@0XGM50`2QN4@3
0:9iA@80XgY6202QN4@00`2VNdH0YGY50:EjA@040:EjA@070:IkAP2WNU00Yg]>0:MkCP2WNd`0Yg]:
0:MlB@020:MlA`<0Xgi:102TOd/20:F0C0<0YWe90`2WOTX20:QoB`P0Ygi:00P0Yge=0:IlC02VO4X0
YGa80:ImB@2WOTP0Z7m70:V0B080Ygi600@0Ygi80:MnBP2WOTX0Yge;0P2WODd40:UnB`<0Z7e:00<0
Yga90:QoB@2XOdT01P2XOdT01@2XOd/0ZH1<0:V0C02ZPDd0Zh9>0080[8=?00@0[HA@0:V0C02ZPDd0
Zh9>0P2/Pdl0102[PTh0ZX5=0:V0C02ZQE020:V4C`050:R3CP2WPTd0YX5<0:J1C02UP4/00P2[PE40
102[PDl0Zh9>0:^2CP2[PT`20:^2BP80[8=;00@0[8==0:b3C`2/Pdl0[89@0P2/PU820:Z5D0<0ZHA?
00<0ZXE@0:^6D@2/Qe80202ZQDh80:j5D@040:V4D02ZQE40ZXEA0:Z5D@80ZhIB0P2/Qe<30:b6E`80
[HMH0`2^R5T30:f8E0<0[XUE0P2_RUH01P2^R5/0[XQI0:j8F@2]QeH0[HQD0:f8D`80[8M@00@0ZhIB
0:Z5D@2ZQE40ZXEA0`2YQ5020:R3C`060:V4C`2XPdh0Z8=>0:N2C@2VPD`0YH1;0P2TOdX20:J2B00>
0:F0B@2UP4/0Y7m:0:AoB`2TOTd0Xge<0:5lA`2QO4P0X7]709miB02NN4T0WGM:09efB`2LMDX309Ye
@@80VGA00`2HLcl809Mb?P80Tfhj0P2DKc/01`2BKCT0T6/g08eX=02<Ic<0T6Xk08mY>P2>J3T00`2<
ISL0202=IcP0SVPi08]V>@2:ICP0RF@g08MR=@25H3<0Q5lb0P22GC000`20GS00PEla089P<P02089P
<P03081N<01oGBl0OE/]00<0PEhd0P20GC<307mL<P0407]K<P1iFC00MeL^07EE;080M5@[00<0MED/
07IF;@1bE3000P1aDbl00`1`DRh0Ke4]06i@;00206e?:`P0JddY0P1/BbX02@1YBbT0IdXX06A:9`1R
BRH0HD/V061:9@1UB2H0ITTW06M::00206Q;:@0306M::01VBBL0IDPV0080HdHT0`1TAbD306E89P03
06I99`1UB2H0I4LU0080HdHT00@0I4LU06E89P1VBBL0J4XX0P1YBbT00`1ZC2X0Jdd[06a>;00206e?
;@T0K4hZ201_CR/206a@:080KE4Y0`1^DRX0101_Db/0K4lW06a?9`1/CbL206e@:0<0KU4Y201]D2P0
201bE300LE<_06mA;@1^D2`0KDl[06i@;01_DBd0L58^0P1^D2`306mA;@0306i@;01/CRX0JddY0080
KDl[0`1/CRX0101]Cb/0Ke4]071B;P1[CR@206]>9P0306]=9`1[CBT0Jdd[0080Jd`]00h0K50[06eA
;01^DRd0KU8]06eA;01[CbX0JDdX06M;9P1[CRH0K4lW06iA:@1`Db/0LUD]07=F;P80M5L_0P1/Cbd0
0`1[CR`0JTd[06U<:P0206Q;:@0906M::01OAbD0GdLU06189P1QBBL0HTXX06=;:@1TC2X0IDd[0080
I4T/00H0HTT[0619:P1MB2T0FdPX05Y79`1HB2L305i7:080GDHW0`1LABH405Q59@@0Ed@T0P1GA2H2
05I39@<0ED8T00/0E44S05E1:01E@BP0DT4W05519`1?@BH0CD8V04a19@1;@RD0Ac/Q04Pl8P0404Tm
8`0904Pl8P17>b40BS/T04Tj8`16>R80A3XQ044j8010>R00@C/Q0080@CdR00T0@c/V048j9@10>2<0
?cLR03hf8@0o=b80@3PS044i9012>RD00P11>B@01@10>2<0?cLR03hf8@0n=R40?CDP00<0>C@P0`0j
=B4203/f8P0403`g8`0k=R80>cHR03/f8P80>SDQ0P0i=2000`0b;a`0=34N03Db7`0303Ld8@80=C8O
200g=2401P0b=B00<cDP03<e800e=200=S<P03Pc8080>C8P0P0h=B8203Ld8@<0=S<P00<0=C8O038d
7`0b=1l03P0b=1l303Hc8080=C8O0`0f<b0803Le80P0=CLQ0`0g=B0203Pf8@<0>CLR100g=B0403Hd
7a00=cDP0`0c=B03038d7`80<C<N00<0>SDR03Td8@0g<Ql00P0f<Ah00`0g<Ql0>C@Q03Xe8P0203<g
8080=3HP00<0=SDP03Le800i=2000P0j<b0203/c7P0403`d7`0m=B00?SHQ03hf8@80?cLR00@0@3TO
044j8011>R00@CXP0P12>b4204<l8P0804Xl8P1:?240C3`R04hm8@1??R00DSlO05<o7P1D@1l20593
8P0605928@1D@B40Ed8S05]49@1NAbP0H4LY0P1QBb@2069<9@0806==9P1TCRL0IDlX06E?:01/CbL0
KU4Y071C:`1bEBd207=F;P0:079E;@1aE2`0LE/Y07=L:P1dGB/0Med/07YN;P1mGRl0Oel`081P<@80
OF0d0P1nHCD307mR=P06081S=`22I380Q6Hd08IX=P28JSP0RF/i0P2:K3X01@29JcT0S6/f08e/=`2?
KST0TG0k00<0TW4l00X0TG0k09Mc?`2FLSh0UW8n09Ea?@2FLSh0Ug<o09Qd@02IMD40VWM10P2KN480
0`2LND<0WGY409ikA@0209mlAP<0XGe90P2ROTX30:=oB`P0YX==00P0ZXIB0:V5D@2XQ500Z8A@0:V5
D@2[Qe<0[HUE0:n;E`80ZXQH0P2[RET30:b:FP030:f;F`2`S5`0/HeM00H0/HeM0`2bT6020;>AH@H0
]99R0P2eTf<30;JDI0040;NEI@2fUf/0]YM[0;JGJ`80]iQ/0`2hVFd80;RFJ0P0^II/202iUfT0102j
V6X0^IMY0;VGJ@2iUfT30;RFJ0030;NEI`2gU6X0^9E[0080^9E[0`2iUV`00`2jUfd0]iEW0;NEI`06
0;NEI`P0^II/0P2fU6H30;NEI`<0^9IX00@0]I9X0;JCJ@2fTfT0]Y=Y0`2gU6X00`2hUF/0]iEW0;NE
I`060;NEI`<0^YQZ0P2iUfT30;RFJ0P0]Y=Y0P2fU6H30;FCI@<0]99T202bTf@20;>@IP80]95W00@0
]I9X0;JCJ@2gU6X0]iAZ202gUFL0102eTfD0]99T0;BBI02dTV@30;>AH`030;:@HP2cSV40/hiQ00L0
/hiQ202dSf820;:@HP040;>AH`2dTV@0]99T0;>AHa80/Y1R00<0/XmU0;6>I02`SF<00P2`SF<00`2b
SfD0/i1V0;FBJ0030;BBI080/i5S0`2bT6880;:?I@80/XmY00@0/XmW0;6>I02aSf80/8iP0P2`SUh8
0;B?HP040;6<G`2bSF00/XeP0;:=H0@0/hiQ0P2aS5l0102bSF00/hiQ0;>>H@2dSf820;F@H`P0/8eS
0P2aSf430;2>H0<0[heO0P2bSUh20;6=G@80/8aL0P2_Re/80:n=G`P0/8eS0P2`SFL0102`SFD0/HiT
0;6?HP2bT6820;:@H0P0/HaO2@2bSUh80;6=G@P0/XeP202_SEl20;>?G`<0/XiN0`2aSEd00`2`S5`0
/HeM0;:>GP030;:>GP030;6=G@2`S5`0/hiQ00L0/hiQ2`2aS5l30;:=H080/hiQ00P0/XiN0;>?G`2d
T600]91P0;>?G`2aSEd0[h]K0:j:FPP0/8]N0`2bSUh30;6=G@80/8aL202cSF080;:=H0030;B?HP2b
SF00/HaO0080/8]N00@0/HaO0;:=H02dSf80]i9U0P2fTF@00`2eT6<0]8mR0;>>H@020;:=H0@0/hiQ
102bSF000`2_S680/8eS0;:?I@020;:?I@040;6>I02_S680[X]Q0;6?G`80/Y1P00<0/i5Q0;:@H02a
Sel00P2_SEd0102bT680[heO0:b:G02]Red20;6?H@030;:@HP2`SV00[H]M0080/HaP00H0/8]N0;2<
G02_ReT0[XYF0:f9E@2]RU@80:n;F`<0[XaN0P2_SEl30;2>H0060;>?G`2bSUh0/HeM0;2<G02_Re/0
[HUI0P2/R5P80:j<GP<0[h]K0P2^RUX;0:f9F@060:b6G`2/Qed0[8MM0:b7F`2/QeX0[8QH0P2/R5H2
0:n;F`80[XYJ0P2]RET20:b8F0<0ZhMG0`2ZQUH20:V5E@0;0:^7D`2ZQU80Z8A@0:N3C`2VPTh0Yh=?
0:R4D02YQE40YX9B0:N3D`2YQED00P2[QeL01@2ZQUH0ZHEE0:R4E02ZQUH0ZHEE00<0Z8AD00H0ZXIF
0:^7E`2]RET0ZXIF0:^7E`2/R5P20:f9F@050:b8F02[QeL0ZXIF0:R4E02YQED00P2ZQUH0102YQED0
Z8AD0:N3D`2VPU820:V5E@@0Yh=C00<0Z8AD0:V5E@2ZQE400`2YQ5020:R3C`80Yh9>2P2TP5020:=o
C`<0XWi>0P2QODd80:9lC`80Wg]700<0X7a80:5mB@2ROTX00P2SOd/01@2TP4`0Y81@0:B0D02SOdl0
XWi>0080XGe=0P2PO4`01`2QODd0XWi>0:=oC`2TP500Xgm?0:9nCP2PO4`0102ONd/30:1lC080XGe=
0`2QO4l20:9mD0<0XgiA0`2TOd/20:=nBP@0XWe900@0XGa80:1kA`2ONTH0WWU50P2ONTH00`2PNdL0
VWI609YfAP0609YfAP<0W7M30P2KMT8309Ye@@0409UdA`2HLdH0UW5409E`@`<0U6m200X0UG1309Mc
@`2HM4@0VWI609]gA`2IMDD0UW9209=_?`2@K3`0TVhn0`2AKCd2091/?080Sf/k00P0U6m209E`@`2E
L4<0UG1309A_@P2BKD00T6/n08mZ?@<0TV`o0P2AJch3091Z?@05095[?P2@JSd0T6Xm08mY?02>J3/0
0P2=IcX0102<IST0TfPm09=X?@2CJ3d309AY?P80UFXo0P2BK3d3095[?0<0T6Xk0P2>J3/0102<IcX0
RVPj08QX>@27J3T208IW>00408AX>02:Icl0RVLo08YW?`80RFHn0`28ICd01P2@JSd0SfTl08iX>`2=
IcX0S6Hi08eW>P80SVPk2027ICL208AN<@0408=M<022G2l0PU`_08=M<080Q5ha00<0PUd`085L;`20
Fbh00P1oFRd00`20Fbh0PE`_089M<00208=N=080PUdc0P21G382081K<@0407eM=01kFc80NET`07MG
;P80MUH]00<0MeL^07QH;`1jFS400`1kFc80301jFS40MeL^07EE;01cDbX0Ld`[079>;01cCbd0LU0]
075@;@1^D2`0JdlZ06Y>:@<0JTd[:oooool002[ooooo0`2MLd4209id@P<0WgE300<0WW910:1d@`2Q
MD@00P2RMTD00`2QMD@0X7A309ib@@040:=gAP@0XWI500<0XgQ50:9gA02QMT<00P2PMD800`2QMT<0
XWM40:=hA@040:5gA@@0X7I40P2PMd<20:5hA0040:9iA@2SNTH0XgY60:=jAPP0XGQ4202UNTD01P2W
NU00Yg]>0:MkCP2WNd`0Yg]:0:MlB@80Yga70`2SOTX40:AoB`80YH1<0P2UO4P20:ImB@040:MnBP2X
Od/0Z7m;0:QoB`P0Ygi:00<0ZX1@0:QnCP2VO4X00P2UO4P00`2UO4H0Ygi60:QoA`020:QoA`040:Qo
B@2XOd/0Z7m;0:QnC080Z7i>0`2WO4T20:QmBP<0ZGi;202XOdT20:QoB`040:V0C02ZPDd0Zh9>0:b3
C`80[HA@00<0ZX5=0:^2CP2]Q5000P2^QE400`2]Q500Zh9>0:Z1C@020:Z5D0040:V4C`2XPdh0Yh9=
0:J1C080YH1;0P2[PE40102[PDl0Zh9>0:^2CP2[PT`20:^2BP80[8=;00@0[8==0:b3C`2/Pdl0[89@
0P2[PE401@2WPTd0Z8=>0:Z5D02[QU40[8MB0080ZhIA00<0ZXE@0:Z5CP2ZQDh01P2ZQDh80:j5D@<0
ZXEA0P2[QU830:b7D`040:b6E`2]QeP0[HMH0:f7F080[XQI0P2_REX30:f8E0<0[XUE0P2_RUH01P2]
QeX0[HMH0:b6E`2/QUD0[8MC0:^6D@80ZhI?0P2[QU830:Z5D@@0ZHA@0P2YQ4l20:R3CP040:N2C@2V
PD`0YH1;0:F0B`80Yh=900h0YX5:0:J1C02UP4/0YH1<0:EoCP2TOTd0XWe80:9mB@2QO4P0X7Y909mi
BP2NN4/0WWM<09efB`80VgI20P2JMD4309Ud@0T0V7<o0P2DKc/02@2EL3`0U6lk09=^>P2@JcL0SVTe
08aW<`2DK3/0Tf/j095Y>00308mW=P03095Y>02BJST0RVDh0080RF@g00<0Qf8e08IQ=025H3<00P24
Gc800`20GRh0PEl_089P<00208=Q<@03085O;`1oGBd0OU`/00<0PElb0P20GS4307mM<00407aM<@1j
Fbl0N5T]07IG:`80MEHZ00P0MUL[07MH;01bE300LU@`075C;`1`DRh0Ke4]06i@;080KDl[00D0KU0/
06e?:`1]Cb/0K4hZ06]=:@0206Y<:00<06U;9`1^Bb/0KDXZ06a;:P1XBbT0I4XW065;9P1OBbH0GTXU
06E89P1VBBL0J4/Y0P1YC2X00`1XBbT0ITTW06E89P0206E89P<0I4LU101SAR@0201TAbD0IDPV06E8
9P1UB2H0I4LU06=6901RAB<0IdPY0P1XBBX01@1YBR/0Jd`]06a=;P1/CBh0KDh_0080JD/W00@0JT`X
06]=:@1/CRX0K4hZ0`1]Cb/806i=:P0406U@9`1ZDBP0JU4X06YA:080Je8Y0P1/DbX206e@:0<0KU4Y
0`1_DRX01@1ZCBD0JdhV06]>9P1/CbL0KE0X0080KU4Y00@0Ke8Z075C;`1`DRh0KU0/0`1/CRX04`1]
Cb/0KU0/06e?:`1^D2`0Ke4]071B;P1_DBd0KU0/06a>:P1ZC2P0KU0/06e?:`1/CRX0JddY06a>:P1]
Cb/0Ke4]071B;P1`DbT00P1_DRX01`1^D2X0KDl[06a>;01/CBh0Jd`]06a@:`1]DB`00P1^DRd01@1/
D2/0JThY06Q<9`1WBbH0JdhV0080K4lW00<0KE0X06mB:P1`Db/00P1aE2`206a?;@0306]>;01ZCB/0
JD`Z0080J4/Y00<0IdXX069::01RBRP0101RBRP206599`80I4T/00H0HTT[0619:P1MB2T0FdPX05Y7
9`1HB2L305i7:080GDHW0`1LABH01@1JAbL0FDHV05U69P1HABD0Ed@T0080ET<S00@0ED8R05M49P1G
A2H0Ed@V0P1F@bD305E29080DclV00<0DD0V05109P1>@2D00P1<@BD0101;@RD0BShT04Tm8`18?282
04Lk8@0:04Pl8P19?B<0BShT04/l9@1:>b@0ASXR04<i8011>R00@C/Q048l8P80@ShS00P0A3`W048j
9@10>2<0?cLR03hf8@0o=b80@3PS044i90@0@3PS100o=b8203Pc7`80>C@P00@0>SDQ03/f8P0k=R80
>cHR0P0l=b<303/f8P<0>SDQ00<0<RlL03<`7@0e<Ql00`0g=2400`0f<b00=C8O03Hc800703Hc8006
034d7`0b=1l0<S@O03@c7`0e<Ql0=c8O0P0h<Al0100i=R<0>3DR03Pe8P0h=B8203Ld8@80=S<P400b
=1l303Db7`D0=S<P200g=B0803Hh8P<0=S@O0`0g=B0203Pf8@@0=S@O300g=B0803Pf8@80=3HQ0P0c
=B001`0b=1l0<C<N034c7P0a<ah0?CHT03`e8`0j<b400P0i<R000`0j<b40?3DS03df900203@h8@80
=CLQ00<0=cHQ03Pf8@0j=B400P0k=24203/c7P0703`d7`0m=B00?SHQ03lg8P10>2<0@CTT044j8003
048k8@80@c`R0P14?B<01P1;?B80CChQ04dn8@1??R00DSlO05A07`80Ed0N0P1FAR@01`1GA2<0F4@S
05a59@1NAbL0HTTZ06=::`1RC2<00P1SCB@00`1TCRD0IDlV06I@9`0206MA:004071@:@1bDR/0M5@]
07IF;`80MeL`00X0MUH_07EE;P1cGRT0MEhZ07IO:`1iGb`0O60^07mQ;`21HC00PV8a0P1nHCD207mR
=P<0P6<g00L0PF@h08=U<`24IS@0QfTg08Y/>P2;KC/0S6hl0080Rfdk00<0SF`g08i]>02AL3/00`2C
LSd2099a?00809Qd@02GLcl0UW8n09Ea?@2FLSh0Ug<o09Ue@@2JMT8209]h@P0309ai@`2MNT@0WW]5
0080Wga600<0X7e70:5mB@2ROTX00P2ROTX20:=oB`80Y81<0P2TPD/00`2UPT`0YX==0:N4CP030:R5
C`80ZXIB0P2YQE40102ZQU80[8QD0:j:EP2_ReL30:^9F@<0[8YJ0P2]Re/30;:>GPD0/HeM0P2`SUh2
0;6?G`80/Y1P0P2cTF440;FCH`<0]YAT0P2gUFD0102fUf/0]iQ/0;NHK02gV6`20;RIK@80^IY^202h
UVP80;VFK0P0^IMY0P2jV6X20;VGJ@80^9IX0P2gUFL20;NDJP80^9E[0P2iUV`20;ZGK@P0]iEW202i
UV`20;JDIP<0]iEW0`2hUVP30;FBJ0030;JCJ@2gU6X0]iAZ0080^9E[202gUFL20;^IJ`80^YQZ0`2i
UfT00`2hUVP0]Y=Y0;JCJ@060;JCJ@80]YAV0`2eTfD30;BBI0P0/Y=T00<0]95W0;FBJ02eTVP01@2e
TVP80;NEI`80]I=U0P2dTV@20;>AH`80/Y1R4@2cSV400`2aSf40/Y1R0;BBI0020;FCI@030;BBI02b
T680/HmQ0100/Y1R00<0/i1V0;:?I@2aSV@00P2`SF<00`2bSfD0]95W0;FBJ0040;BBI080/i5S0P2b
T6880;:?I@80/XmY00@0/XmW0;6>I02aSf80/8iP0P2`SUh80;B?HP<0]8iO0P2cSEh30;:<G@80/8]N
00@0/HaO0;:=H02dSf80]I1S0P2fTF@80;2=H`80/HmQ0`2`SV030:n=G`80/XiN0P2aSEd20;2<G080
[h]K202_SEl80;2=H`080:n<IP2`SFL0/8eU0;6>I02aSf80/Y1R0;:@H02cTF480;2;GPT0/XiN202a
SEd80;:=H0P0/8iP0`2cSel00`2bSUh0/HeM0;6=G@030;2<G0070;6=G@2bSUh0/hmO0;>?G`2bSUh0
/HeM0;2<G0080;>>H@@0/HaO102bSF030;6<G`<0/XeP0P2cSV420;>?G`80]91P00@0/hmO0;6=G@2_
Re/0[HUI102_RUd40;2;GP<0/HeM00<0/8aL0:n;F`2_Re/00P2^RUX80;F<H0P0/hiQ00<0]8mR0;:=
H02aS5l00P2`Reh00`2aS5l0/XeP0;B?HP020;F@H`040;B?HP2cSV40/XeP0;6<G`80/8]N202aS5l0
0`2]RV00[X]Q0;2=H`020;:?I@060;6>I02`SF<0[haR0;2>GP2aSel0/Y1P0P2cTF401`2aSel0[heM
0:j<G02`SV00[H]M0:^9F`2/RU`00P2`SV002@2aSf40[XaN0:^9F`2`RV<0[hYP0:n:GP2_RUd0[h]I
0:n;E`020:n<E0P0[h]K102^S5h20:n=G`80/8iP0P2cSel01P2bSUh0/8aL0:j:FP2]RET0[8QH0:^7
E`P0[XaN0`2^RUX20:f9F@<0[8QH202]RET01P2/QUl0[8MM0:b7G@2/Qe/0[8MJ0:b8F080[8QF0`2]
RET20:b8F0H0ZhMG0`2ZQUH20:V5E@030:b8E02[Qe<0ZHEA00<0Yh=?00H0Z8A@0:V5D@2VPU80Yh=C
0:V5E@2ZQUH20:^7E`050:Z6EP2YQED0ZhMG0:Z6EP2YQED00P2XQ5@01P2ZQUH0[8QH0:f9F@2ZQUH0
[8QH0:f9F@80[XYJ00h0[HUI0:b8F02ZQUH0Z8AD0:V5E@2ZQUH0ZhMG0:Z6EP2YQED0Yh=C0:J2DP2X
Q5@0Yh=C0:J2DP80YH5A00<0YX9B0:R4E02YQED00P2YQ5020:R3C`<0Yh9>00<0YX5=0:=oC`2SOdl0
1P2SOdl0102TP500Xgm?0:=oC`2SOdl30:9nCP80XGe=00<0XgaA0:9kD02RNe001@2RNe001P2NNTH0
Wg]70:1lB02QODT0XWi:0:=oB`80Y81<0P2UPE401P2TP500Xgm?0:9nCP2QODd0X7a<09mkB`80XWi>
0`2TP500102ROTh0X7a<09mkB`2SOdl30:9nCP@0XGe=00<0XGa?0:9mD02ROE000P2SOU420:AoDP03
0:F0D`2WPTh0Yh9>0080YX5=1@2UP4`01`2TOd/0XWe90:5lB02PNdL0XGa80:9mB@2SOTX0202LN4P3
09iiA@80WGQ40`2LMd<0102NND`0WGQ;09YeB02HLdH209MbA@80V7=600T0UG5109Mc@`2JMTH0W7Q8
09]gA`2HM4@0UG5109=_?`2GLd400`2FLT0209Ea?`80U70n00P0UW5409MbA@2HLdH0V7=609MbA@2E
L4<0Tfi1095/?`<0UVe10P2EK40;09A[?`<0V6e00P2GK3l309I[?P<0U6`k0P2EKC`209I^?@0609M_
?P2@JSd0T6Xm08mZ?@2<JS`0Rf/l0`2:Jc`01027Jc/0RfQ008]X@02;J40308YW?`80RFHn0P2BJC/2
09=Z?004099Y>`2AJ3X0T6Li08mV>0<0RFLg1@2:J3P00`2<HcD0Rf8d08YQ<`0208QO<@0608YQ<`2;
HS@0S6<e08QR<`27HC80QV0a0P24GRl00`26H340Qf4b08QR<`0308IO=0<0QEhc0P24GC801021H3D0
Oehc07eL<@1kFRl207YI;P80NeX_0100OUdb07mN<`1oGS<0Oehc07eL<@1kFRl0N5L/07IE:P1fD2`0
Me4]07MC;`1gEC00MeLa07IF<01cEBl0LU@^0`1^DRd[ooooo`00:_ooool309ec@@80WWA20`2OMD<0
0`2NLT40X7A30:5eA0020:9fA@030:5eA02PM4<0WW9100D0XgM60`2RMTD00`2SN4D0XWM40:5f@`02
0:1e@P040:5f@`2RMd@0XgQ50:=iA`80XWQ600D0XGM50:1fA02OMD<0WgE309id@P020:1g@`80XGQ4
00@0XWU50:=jAP2SNTH0Y7]7202QN4@30:EjA@80YW]60`2UNTD01P2WNU00Yg]>0:MkCP2WNd`0Yg]:
0:MlB@80Yga70`2ROTX40:=oB`80Y81<0P2UO4P20:ImB@040:MnBP2XOd/0Z7m;0:V0C0P0Ygi:00P0
Zh5A0:Z0D02WOD/0YGa80:AkA`2UO4H0YWe50:MnAP80Z7m700@0Z7m90:QoB`2XOd/0Z7i<0P2XOTh2
0:IkB080Yga900@0Z7e:0:UnB`2ZOd`0ZWm<202XOdT02`2WOTX0Z7m;0:V0C02ZPDd0Zh9>0:b3C`2]
Q500[XEA0:^2CP2]Q500[XEA0080/8MC00/0[XEA0:f4D02[PTh0ZhIA0:Z5D02YQ4l0Z8=>0:N2C@2V
PD`0YH1;0:AoBP020:^1D@040:^1C`2[PTh0Zh9>0:^2C080Zh9:0P2/Pd/0102/Pdd0[8=?0:b3C`2[
PDl20:^1D@030:F0B`2WPTd0ZXE@0080[HQC00<0[8MB0:Z5D02YQ4l0202YQTh80:j5D@80ZXEA0`2[
QU830:b7D`@0[HMJ0P2^R5/20:n9G0<0[HQD0`2^RED20:n:EP060:b6F@2/QUL0ZhEF0:^5E02ZQE40
ZXE@0P2ZQDh30:^6DP80ZXEA102YQ5001P2ZQE00ZHA?0:V4C`2XPdh0Yh9=0:J1C080YH1;0P2WPdT0
102WPT/0YX5<0:J1C02UP4`20:EoCP060:9mB02RODT0XGa80:1jB@2ONDX0WgU<0P2NMd`209]f@P80
VWE1102IM40809Qc?`0@09A_>`2EL3`0UG0l09E`?02CKSX0TF`h08iY=@2=J3@0UFdl09A/>`2AJCP0
T6Pg08mW=P2@J3L0TFTh09=[>P80RF@g0P28HcH01P27HSD0QV4d08EP<`25H3<0PEl_089P<0<0Pf4a
00<0PEl_081N;P1nG2`00P21Gc42081N<0<0Oed_00D0OU`^07aM<@1kG300NEX^07MH;00207IG:`80
MeP/0P1bE3000`1aDbl0L58^06mA;@0206i@;00D06e?:`1_DBd0Ke4]06i@;01]Cb/0JddY06Y<:01Y
BbL0J4XV06m;:`1^Bb/0K4/Z06Q;:@1UBbP0HD/V05m;9P1MBbD0IDPV06I99`1XBbT206U<:P0406Q;
:@1VBBL0IDPV06I99`80IDPV00@0I4LU06=6901RAB<0HTDS0P1QA2805@1SAR@0IDPV06M::01VBBL0
I4LU06958`1P@b40ITLX06M8:@1XBBX0JDX[06Y;;01[C2d0K4d^06e>;`1WBBD0J4XV06U;9`1ZC2P0
K4hZ06e?:`0306i@;0P0KTdZ0P1XDBL206UB:0<0JU<Y00@0Je@Z06iA:@1^DBT0KU4Y0P1_DRX3071C
:`80JD`T00T0JTdU06]>9P1]D2P0KU4Y06mB:P1`Db/0L58^06i@;01]Cb/00`1[CBT03@1/CRX0KDl[
06a>:P1]Cb/0Ke4]071B;P1_DBd0KU0/06]=:@1ZC2P0KU0/06e?:`1/CRX00P1[CBT02@1]Cb/0Ke4]
075C;`1eF2h0M5L_07=F;P1bE2h0L58^06mA;`0206i?<00806a@:`1]DB`0KU8]06eA;01/D2/0JThY
06Q<9`1VBRD306]>9P0306a?9`1]D2P0KU4Y0080Ke8Z0P1/Cbd00`1[CR`0JTd[06U<:P0206Q;:@09
06M::01VCR`0ITh/06A<:P1SBbT0HDTW05m79@1NAR@0GDDS0080I4T/00H0HTT[0619:P1MB2T0FdPX
05Y79`1HB2L305i7:080GDHW0`1LABH0201KB2P0FTLW05U69P1HABD0Ed@T05I38`1E@R80E44Q0`1G
A2H305I39@80ED8T0P1B?RD02@1@?bD0CclU04i09@1<@BD0Bd0T04Y1901<@2H0BShT04Lk8@0204Hj
800:04Lk8@1:?R@0C40V04`m9P1:>b@0ASXR04<i8011>R00@C/Q048l8P80@ShS00<0A3`W048j9@11
>B@00`0o=b800`10>2<0@CTT03hf8@0303lg8P<0@3PS00<0@CTT03Pc7`0h<al00P0i=2000`0j=B40
>cHR03/f8P0403`g8`80>cHR0`0j=B400`0b;a`0<c0M03Db7`0303Ld8@0303Hc800e<Ql0=C8O00L0
=C8O00H0;c8M030b7@0`<Qd0<S4M03<`7@0e<1d203H_7@80>CHS0P0h=B8303Ld8@0303Hc800b=1l0
<S@O00h0<S@O00<0=34N03Db7`0e<Ql01@0f<b0803Le80P0=SPR0`0e<ah203Hd7`<0=cDP00D0=38M
03Dc7P0e<ah0=S@O03Le800203Pf8@0303Tg8P0g=B00=cDP00H0=cDP200h=R4203@f8@80<cDP00L0
<S@O034c7P0a<ah0<38M03hg9@0m=R@0?3DS0080>c@R00<0?3DS03df900n=bD00P0e>B8203Hh8P03
03Pg8P0i=b80>cHR0080?3DR00H0?C8N03hc7`0n<al0@3DQ044f8P12=b<204<h90<0A3XQ0P15>b83
04Hl8`80CChQ00l0CchP058o8@1D?b00ED4P05M07P1H@Al0F4PV05M79@1IARD0FTHU05i79`1QB2T0
HdX[06I;;@1SCB@00P1TCRD00`1UCbH0IU0W06MA:00206QB:@05075A:01cDbX0MED/07MG;P1hF2l0
0P1gEbh02@1fERd0M5lZ07IO:`1gH2`0NV0]07eQ;`20HS00PV8a08=S<P0307mR=P80P6<g0`21I3P0
3023IC<0QFLe08QZ>02;KC/0S6hl08e_?@2<KS`0Rfdk08e/=`2?KST0TG0k09=b?@80U7<n00D0Tg8m
099a?02IMD40Ug<o09Ib?P0209Ea?@0409Mc?`2IMD40VgM309]h@P80W7U300<0WGY409ikA@2OO4H0
0P2PODL40:9nBP80Xgm;0P2TP4`02P2SP4X0Y85;0:F2C02VPdd0YhA>0:R5C`2YQU00ZXMA0:^7D`2Z
QU820:V5D@040:Z6DP2/R5@0[XYF0;2<F0<0ZhUI0P2/RUX30:f;F`D0/XiN0`2aSEd20:n=G@80/8iN
0`2aSel00`2bT600]I=S0;FCH`020;FCH`80]YAT0`2gUFD40;NHK080^9U]0P2iVVh80;RFJ0P0^II/
202iUfT30;ZHJP030;VGJ@2hUVP0]iEW0080]iEW0`2gU6X00`2hUF/0^II/0;ZGK@020;ZGK@P0]iEW
202iUV`20;JDIP<0]iEW0`2hUVP20;BAI`040;FBJ02fTfT0]Y=Y0;NDJP80^9E[202gUFL20;^IJ`80
^YQZ102iUfT80;JCJ@80]YAV0`2eTfD30;BBI0P0/Y=T0P2fTfT30;FBJ0<0]95W202gUFL30;FCI@03
0;BBI02cTF<0/Y1R0080/Y1R0P2bSF050;>>H@80]8mR202cSV400`2aSf40/i5S0;BBI0020;JDIP03
0;BBI02cTF<0/HmQ0100/Y1R00T0/i1V0;:?I@2aSV@0/8eS0;6>I02bSfD0]95W0;FBJ02eTfD00`2d
TV@20;>AH`80/Y1R202bSfD20;:?J@040;:?I`2aSV@0/HmR0;2>H080/8iN202dSf820;F?H0040;B>
G`2cSEh0/XaM0;:<G@80/H]L00P0[hYM0;2;GP2aS5l0/XeP0;B?HP2eT6<0]Y5T0;NBI@P0/8eS0P2a
Sf430;2>H0<0[heO0P2bSUh20;6=G@80/8aL0P2_Re/80:n=G`P0/8eS0P2_S6H0102`SFD0/HiT0;6?
HP2bT6820;>AH@P0[hYM2@2bSUh80;6=G@P0/XeP202`SV00102dT600/hmO0;>?G`2bSUh20;6=G@80
/8aL00<0[h]K0;6=G@2cSel00P2dT6000`2cSel0/HeM0:n;F`080;>>H@<0/HaO1@2bSF030;6<G`<0
/XeP0P2cSV40202cSel0]91P0;B@H02dT600/hmO0;6=G@2^RUX0[HUI1@2_RUd30;2;GP040;6=G@2`
S5`0/8aL0:n;F`80[XYJ0P2]RET80;F<H0P0/hiQ00<0]8mR0;:=H02aS5l00P2`Reh00`2aS5l0/XeP
0;B?HP020;B?HP030;>>H@2bSF00/HaO0080[hYM00<0[XUL0:n:G@2_RUd0102`Reh20;6<G`040:b9
G`2]RV00[haR0;6>I080/XmU00@0/HiT0;2=H`2`SUh0/HmO0`2cTF401`2aSel0[heM0:j<G02_SEl0
[8YL0:Z8FP2[RE/00P2^S5h00`2`SV00[H]M0:Z8FP020:j8H@060:n:GP2_RUd0[h]I0;2=E`2`SED0
/8eC202_Re/0102]Red0[XaN0:j<GP2^S5h20:n=G`80/8iP00P0]91P0;>?G`2bSUh0/8aL0:j:FP2]
RET0[8QH0:^7E`P0[XaN0`2]RET20:b8F0<0ZhMG202]RET01P2/QUl0[8MM0:b7G@2/Qe/0[8MJ0:b8
F080[8QF0`2/R5P20:^7E`<0ZXIF0`2[QeL30:Z6EP80ZHEE00<0[8QD0:^7D`2YQE400P2WPdl01`2X
Q500ZHEA0:Z6DP2UPE40Yh=C0:V5E@2ZQUH00P2[QeL03@2ZQUH0ZHEE0:^7E`2ZQUH0ZHEE0:R4E02Y
QED0ZXIF0:b8F02]RET0ZXIF0:b8F02^RUX00P2_Re/01@2^RUX0[8QH0:Z6EP2XQ5@0ZHEE00<0ZhMG
00H0ZHEE0:N3D`2VPU80Yh=C0:J2DP2UPE420:B0D0030:F1D@2WPe<0ZHEE00<0Z8=?0P2WPTh30:J1
C@P0XWi>0`2SOdl20:9nCP@0XGe=00<0XgaA0:9kD02RNe000P2RNe030:5jC`80WWY600<0Wg]70:1l
B02QODT00P2SOd/01`2TP4`0YH5A0:F1D@2TP500Xgm?0:5mC@2PO4`00P2ONd/00`2QODd0XWi>0:=o
C`020:B0D0040:9nCP2PO4`0Wg];0:F1D@80Y81@00H0Xgm?0:9nCP2QODd0XGe=0:1lC02QO4l20:9m
D0030:=nD@2TOe80Y7mB0080YH1C0`2XPdl30:N2CP80YX5=00<0Yh9>0:F0C02SOTX00P2QO4P00`2R
ODT0Xgi:0:F0C00809ijBP80X7]60P2ONTD209iiA080WGQ300@0XWe@0:5lC`2NND`0VgI90P2JMDP0
1@2KMTT0W7M:09A`@02FLT80VWI60080W7Q800<0VWI609Ib@P2DL4000`2KMdD209YfA0<0VGE300P0
Ug9509QcAP2JMDP0VWE809UdA`2GLTD0U6m209=^@@80V6m30P2GKT8209I]@@80UFa00P2FKD4209M^
@P@0V6m30P2LL4<00`2KKd80VVi109U]@00209Q/?`0709M[?P2DK3/0U6`k09E]?02FKSd0Ufln09Q`
?`0209Ua@080TF/n00<0T6/n08i/?P2=KCh00`2;K3d00`29KCd0S6U108aY@@0208]X@0<0RVLo00@0
RFHn095X>P2CJS`0U6/m0P2EK3h00`2BJC/0SfHh08eT=P0508]Y>@<0S6Xj00<0TFPj091W>@2>ICL0
0P2=I3H01P2>ICL0T6Li095X>P2=IcP0S6Hg08YT=@80R68c00<0RV@e08aV=`2=IcP00P28HSD208MQ
=0@0QV0c00@0Pf8g085P=@1oGS<0OE`a0P1kFRl207aK<00@081O=021H3D0PF0e081O=01oGS<0O5/`
07UH;@1hEb`0NU8_07YD<01mEc<0OETe07eK=P1kFcD0N5Xd07MI<`<0LUHa:oooool002[ooooo0P2O
Ld830:1d@`<0XGE40P2NLd000`2OM440X7E20:5f@`020:9gA0030:=hA@2RMTD0XWI50080XWI50P2S
MdH20:AhA`060:=hA@2RMd@0XWM40:5f@`2PMD80WgA10P2NLd020:9g@0040:=h@@2TND80YGY30:Ik
A080Yga50P2QMT<02@2PMD80WgA10:1e@P2RMd@0Y7U60:EjA`2OLd80XGE40:9fA@020:AhA`030:9f
A@2QMD@0Wg=20080Xg]:00H0Y7Y80:EjA`2WNDL0Z7U50:Qi@`2ZN4<20:EjA@80YW]60P2WO4L20:Qm
B0@0Yga90`2XODX20:UnB`80Y7]70P2UO4P20:ImB@80Ygi:0P2YOD`00`2YOT/0ZGi90:UnA`020:Uo
A@040:Uo@`2VNdH0Yga70:UnB@80Zh1;00<0ZWm:0:UnB@2XODP00P2[PTh20:b3C`040:Z1C@2XOd/0
YWe90:AkA`80YGa80P2VODT01`2WOTX0Z7m;0:QoB`2YP4`0[8=?0:Z1C@2VODT00P2TNdL00`2VODT0
ZX5=0:b3C`020:ImB@060:MnBP2XOd/0ZH1<0:Z1C@2[PTh0[8=?0`2ZPDd30:V0C080Z7m;202ZP4h2
0:QoB`80ZH1<102ZPDd80:^2CP030:f4D02^QE40[XEA0080[XEA0`2_QU8:0:f4D0<0[XEA0`2_QU82
0:R3CP040:V4C`2ZQE00ZXE@0:^6D@80[8MB202[QU80202YQ4l0ZXE@0:^6D@2/Qe80[HQC0:j9E02_
RUD0/8]F0P2^RE@00`2]R5<0[8MB0:^6D@020:V4C`030:R3CP2/Qe80[8MB0080ZhIA00<0ZXE@0:V4
C`2YQ4l00P2XPdh01P2/Qe80ZhIA0:^6D@2YQ4l0Z8=>0:N2C@80YX5<202XPdh20:N2CP080:J1C@2U
P4`0Xgi:0:9mB@2QO4P0X7]709ihB`2OND`20:1jC@0409miC02MMdX0VgE809UcAP<0VWE00P2IM3l3
09Qc?P<0VGA00P2HLcl309Mb?P80Tfdn00H0TF/l091Z>`2>J3T0S6Hg08]U=P2:I3D308UW>@80R6Hh
0`27ICL00`24GS40QElb08MQ=00208QR=@0<08MQ=025Gc80Q5ha08EP=P24GcD0PUdc085L<P20Fc40
PE`b089M<`23GS@0OU/c0P1mFS800`1lFC40NeP`07YG;`0207UF;P80MU<]0P1gE2h01`1hEBl0NEH`
07UF<01iES00Le<]075A:`1_CbT00P1]CBL00`1^CRP0KdlY071@:P0806M99`@0JD/W0P1XBRH206M9
9@0306Y=:`1XBbT0IDPV0080HdHT00<0I4LU06I99`1XBbT01@1NB2<305m9900306E8:01VBBT0IdXZ
0080J4/[00<0IdXZ06E8:01TAbL00`1XBb/206U<;0@0JTd]00H0IdXX06Q;:@1XBbT0JD`Z06Y=:`1[
CR`506a?;@D0KE0^201/D2/2071>:`0306m>:`1]Cb/0K50[0080JU0[00L0JE4[06U=:01ZCRT0JThY
06]?:P1/D2/0KE4/0080KU8]201/D2/3071B;P0306mA;@1^D2`0KDl[0080KDl[00<0Idl[06Q@;01Z
DRh00P1[Dbl01P1ZDRh0J50/06M?:`1^DR/0K50Y06]?:080JDdV00<0JThW06]?:01/D2T00`1VD2/2
06MA;0<0J58]0P1[CBT0101ZC2P0JD/W06U;9`1XBRH206M99@0606E69`1TAbL0I4LW06989`1PB2H0
GdPV0P1MBBH2065::080H4TW0P1OB2H205i79@0305a59P1MARL0GTLX0080GdPY00<0GDHW05]49@1J
@b@00P1OB2T0101NAbP0GDHW05e69`1LABH205]49@P0FDHV0P1EA2H0101D@bD0Dd8T05=2901B@B<2
05508P0805A3:@1B@BL0CchT04dl8P1<>b40CC`R04ln901A@2H204`l8`80Bc/R0`1:>R4204Ti8080
ASXR00<0AC/R048k8@11>b400P0o>b000`0m?200>3HO03Pf7`0403Tg8080>SPQ0P0j<Ql203/c8007
03`d8@0m=B80?CDR03hf8`0i<Ah0>S8O03/c800203`d8@0;03/c800j<Ql0>C4N03`e8P0k=240>C@P
03Hd7`0d<ah0<38L02la6`0^<Q/0200h=R4203Pe8P80=c@Q0P0f<b0203Db7`80=3HQ0P0c=B00100b
=1l0<C<N034c7P0`<Qd303<`7@80=34N0`0e<Ql403@f8@0703<e800b=1l0<C<N030b7@0f;ad0=c0N
03Tb800203Xc8@0303Tb800g<1h0=RlM00P0<S@O200e<1d8038e6PP0<S@N200h=R4203Li8`80=SPR
00@0=CLQ03@f800d=R00<cDO0`0f=1l503Dc7P0603Lc600h=1T0>3@I03Te6P0j=Q/0>cLL0P0l>1d3
03Xf7@0303/g7P0l>1l0?CTP0080?SXQ00@0?c/R048h7`12>1l0@SPO1011=ah04`10=Qd0@C`O048m
8013?200AS`Q04Pl8P1;?B<0C3hT04dm901;>b40C3`R04dn8@1?@240DD8Q05948@1CAB80E4HQ05a7
:01MB2T00P1MBBP0101NBRL0GTXU05m<901OC2@206U=9P0306Y>9`1[CbP0K50Y0080KE4Z00@0KU8[
07=I:01cFBP0LeTX0P1dFRT307EK:P0907eM=P1nGSD0P60g089S=`23I3H0Pf@e089T<P21Hc40Q6Ph
00<0PfLg1022ISH05025IS00R6Tc08a]=`2?L3X0T74k08m`>P2<KCL0RV/e08iY?02?JSd0TF`o099]
@02DKd80UW5409MbA@2HLdH0Ug<o09Qd@02KMd<0WGU50P2NNTH00`2LN4@0VgM309akAP0209akAP80
WGa70`2NODP20:J2CP040:F1C@2TP4`0Y81<0:=oB`80XWi:00P0YH9<0:J3C@2XQDl0ZHI@0:Z7D@2Y
QU00Z8E?0:N4CP@0ZhMG102/R5P80:j:FPP0/8iN0`2`SV020;6?H@<0/Y1R0`2eTfD30;JDIP<0]iEW
202jV6X80;NEI`T0^IMY00P0^YQZ0;bJK02mVfd0_I]]0;bJK02jV6X0^IMY0;ZEJ080^iIY00<0_9MZ
0;fHJ`2mV6/00P2nVF`@0;VFK080]iAZ0P2hUF/20;VFK080^YM]00H0]iA/0;NDJP2gU6X0]YAW0;JD
IP2eTf<20;FDH@<0]iEW0P2fU6H30;FCI@80]Y=Y0`2gU6X30;REJ`P0^II/00P0]iAZ0;REJ`2iUV`0
^II/0;REJ`2eTVP0/XmU0;6>I0P0]YAV00H0^9E]0;NDK02gU6`0]I9Z0;BAJ@2cT6P20;:?I`050;JD
IP2eTfD0]I=U0;BBI02cTF<00P2bT680102aSf40]Y9R0;JBHP2fTV830;NCH`80^9AT202eTfD60;:@
HP<0/i5S202fTF@20;NFH`030;JDI02eTfD0]99U0080/i1V00<0/XmW0;:@HP2bT6800P2cTF<30;BB
I0040;FCI@2eTF40]I5Q0;FAH@D0]91P202bT6000`2dT600]Y9R0;NCH`020;RDI0060;JBHP2dT600
/XiN0;BBI02cTF<0/Y1R0P2`SV000`2bT680/i5S0;BBI0080;BBHP030;FCI@2cTF<0/8iP0080[XaN
00<0[heO0;6?H@2cTF<00P2aSEd00`2cSel0]91P0;B@H0020;B@H0030;>?G`2bSF00/XeP00H0/XeP
202`SV030;B@H080/hmO0`2bSUh80;2>H0P0/Y1R00<0]8mR0;>>H@2bSF000P2`Reh02`2bSF00/hiQ
0;B?HP2_Re/0/8aL0;:>GP2cSel0]91P0;>?G`2bSUh0/HeM0080]HaP00@0/heP0;:=H02bSF00/8iP
0P2_Sf000`2cSV40/XeP0;2;GP020:n:G@060;2;GP2bSF00]8mR0;F@H`2bSUh0/HeM0`2`S5`00`2b
SUh0/hmO0;FAH@020;2>H080[heO0`2^S5h01`2]Red0]HmX0;B?I@2dSfD0/XeQ0;6<G`2`S5`00P2_
ReT20:n:G@030;2;GP2aS5l0/XeP0080]8mR00@0]I1S0;:=H02bSF00/XeP0P2cSV430;B?HPP0/hmO
0P2cSV420;:=H0@0/HaO202cSel30;6<G`D0/XeP0P2cSEh20;:<G@80/H]L0P2`RU/0202cSV40/XeP
0;2;GP2_RUd0/8]N0;6<G`2dSf80]I1S0P2^S5h0102_SEl0/8iP0;:@HP2cTF<20;BBI0P0/XiN0P2_
RUd00`2`Reh0/HaO0;:=H0020;B?HP060;F@H`2cSE`0/heL0;>=GP2cSF00/haQ0P2bRf800`2bRf@0
/hiQ0;>>H@030;:=H0<0/HaO202_RUd80;>=GP030;6<H02`Rel0[hYN00<0[HQL00<0[hYN0;2;G`2a
S600202_Re/80;6=G@060;6>F02aSET0/HeI0;6=F`2bSUh0/XeP0P2cSV830;2<F0<0[h]G0P2^RUH0
102`S5`0/HeM0;6=G@2aSEd20;:>GP80/hmO00H0/8aL0:n;F`2_Re/0[HUI0:b8F02[QeL:0:Z6EP80
ZhMG0P2/R5P0102]RET0[XYJ0:j:FP2_Re/20:f9F@030:b8F02[QeL0ZXIF0080Z8AD00X0Yh=C0:R4
E02YQED0ZhMG0:b8F02]RET0ZhMG0:Z6EP2XQ5@0Yh=?0P2XQ5000`2ZQU80ZhMC0:b8E0020:f9E@<0
ZXIF0P2YQED40:R4E080ZHEE00<0ZXIF0:^7E`2[QeL00`2/R5P01`2]RET0[XYJ0:n;F`2^RUX0[HUI
0:^7E`2ZQUH00P2YQ5L30:R3EP<0Yh9E0P2XQ5@40:V5E@80ZXIF00P0Z8=?0:V4D02ZQE40ZhIB0:Z5
D@2YQ500Yh9>0:J1C@80Z89C00@0Yh5B0:J0D@2TOTl0Xge>0P2RO4d01@2WPTh0YX5=0:J1C@2TOd/0
Xgi:0080XWe90P2QO4P20:>1E0030:AoD`2TOE80YG]A0080YGY@00<0YGQ?0:1lC02ONd/00P2ONd/0
0`2PO4`0Xgm?0:F1D@020:N3D`80YX9B00D0YH5A0:B0D02ROTh0XGe=0:1lC0020:AoD`<0YH1D0`2V
PED30:F1C@80Y81<102SOd/20:B0C0030:F1C@2VPTh0YX9>0080Yh=?00D0ZXE@0:V4C`2YQ4l0Z8=>
0:N2C@020:J1C0040:F0B`2SOd/0Xgm;0:=oB`<0XWi:0P2QODT809emCP080:5kC02PNT/0WWQ909af
A`2MMdP0WgU:0:9lC@2TOTl209ijBP0609ihB@2OMTP0WgA70:1dA`2OLdH0XG960`2RO4l01@2QNdh0
X7Y=09egBP2JM4L0V79500<0VgM70P2JMTH309UeA@0809Qg@P2IN4<0W7Q409ehA02NMT<0WG=109]a
?`2JKSd309Mc?`80UW8n0`2ELCd04`2ELd<0U79209=a@@2BL400Tg5109Ec@`2HMTH0VWQ809Ib@P2I
MDD0W7Q809ijBP2MNDT0VWI609Ea@@2BKSh0VGE109Qd@02GLcl00P2FLSh0202GLcl0V7A009Ue@@2J
M4D0VG=409I`@@2CKCh0TV`m0`2AJc`04@2BK3d0T6Xm08eW>P2;ICP0SFLj099/?`2DKT40TV`o08mY
?02>JcD0SVXf08m[=`2?JcT0T6`l091[?P2@Jcl0TFa000P0Tflo00@0T6/o095/@02AK400TFa0102B
KD4208iZ=PD0Sf/g00L0T6`h08mY>P2?JCX0SFLh08aV=`2:I3D0RF<d0080Qf4b0`29HS/208QQ>P<0
Qf0i00D0QF0c08IQ=027HSD0Qf8e08QS=P0308MR=@80Q5lb00<0Peha089M<021G2l00P1oFRd0101n
FB`0Oe`b07mL<P1oG38[ooooo`00:_ooool309mc@P80X7A30`2QMD@209md@@<0X7E20`2QMT<0102Q
MD@0XWI50:9fA@2RMTD20:=gAP80Y7Q700H0XgQ50:9gA02RMd@0XGI30:1e@P2OM44209ic@080XGHo
00@0XWM00:=h@@2TND80YGY30P2VNd@02`2RMd@0XGI30:1e@P2OM440X7E20:9gA02TNDH0YGY70:1d
@`2QMD@0XWI50080XgM600<0XWI50:5eA02PM4<00P2RNTT01P2SNDL0Y7U60:IhAP2WN4@0YgQ20:Ug
@P80YGY50P2VNdH20:MlA`80Z7e800@0YW]80:MlB@2WO4T0Yga90`2XODX20:UnB`80Y7]70P2UO4P2
0:ImB@80Ygi:0P2YOD`00`2YOT/0ZGi90:UnA`020:UoA@0;0:Uo@`2VNdH0Yga70:UnB@2ZOdX0Zh1;
0:YoBP2YOTT0Z7e80:V0C02ZPDd00P2[PTh00`2ZPDd0ZH1<0:ImB@030:ElB080YWe900L0Ygi:0:Qo
B`2XOd/0Z7m;0:b3C`2ZPDd0YWe90080Y7]700<0YWe90:Z1C@2/Pdl00P2WOTX01P2XOd/0ZH1<0:Z1
C@2[PTh0[8=?0:f4D0<0ZX5=0`2YP4`20:QoB`P0Zh5?0P2XOd/20:V0C0<0ZX5=00<0Zh9>0:b3C`2/
Pdl01P2/Pdl20:f4D0H0[XEA2`2]Q5020:j5D@<0[hIB00<0Z8=>0:V4C`2YQ4l00P2ZQE020:^6D@03
0:b7DP2[QU80ZhIB00H0ZhIB0P2ZQE00102[QU40[8MB0:f8D`2^RE@20:n:E@80[XUD00L0[HQC0:b7
DP2[QU40ZXE@0:V4C`2XPdh0[HQC0080[8MB00@0ZhIA0:Z5D02YQ4l0ZHA?0P2XPdh01@2/Qe80ZhIA
0:^6D@2ZQE00Z8=>0080Yh9=00<0YX5<0:R3CP2XPdh01P2XPdh0202XPdl0Yh9>0:J1C@2UP4`0Xgi:
0:9mB@2QO4P0X7]70P2ONDX20:1jB`0509miBP2MMdP0VgE609YdA@2JMD000`2IM3l209Qc?P80Ug8m
0`2HLcl209Mb?P<0UW4m00H0Tfdn099/?@2AJc`0T6Xk08iX>@2=IcP208aV=`<0RFLi0P28ISP308MU
=`0308AN<@26H3<0Qf4d0080R68e00H0Qf4d08IP<`24GS40QV4g08AO=@23GS@3085L<P06089M<`23
GS@0OU/c07iK<`1mFS80O5Ta0P1kF3000`1jEbl0NEH^07QE;`0707QE;`0307=C;@1bDR`0L50Z00<0
KThX00@0L50Z075A:`1/CR`0K4h/0P1[CB/206Y<:P80JD/Y00@0JT`X06U;9`1YBbL0JD/W0P1XBRH2
06M99@80J4/Y00<0ITTW06E89P1UB2H00P1UB2H0101VBBL0GTPS05i88`1NB2<505m9900806=69P1T
AbL0ITTY06M::P1XBb/0IdXZ06I9:@1UB2P306M::P<0J4/[0`1YC2`0101XBbT0JD`Z06U<:P1YC2X4
06Y=:`80K4l]1@1[CR`00`1ZCB/0K50[06a@:`0606a@:`80L4h[00<0Kdh[06e?:`1/D2/00P1ZD2/0
0`1YDB/0JdlZ06]?:P0306a@:`<0KE4/201/D2/00`1`DRh0Ke4]06mA;@0206i@;080KDl[00@0K4hZ
06M?:`1XD2`0JU8^0P1[Dbl02@1ZDRh0J50/06M?:`1^DR/0KE4Z06]?:01YCBH0J4`U06U=9P0206Y>
9`<0IU0[0`1WDB`206QB;@0306a>:P1[CBT0JddY0080JT`X0P1YBbL01`1XBRH0ITLX06E8:01TAbL0
HTPW06599`1OB2H00P1MBBH406199`@0GdPV00<0G4DV05e69`1NAbP00P1OB2T00`1MARL0Fd@U05Y3
900205i7:0<0GDHW0`1LABH805Q59@80ED@V00@0E4<U05=2901C@R@0DT4S0P1A@280101C@RP0DT4W
050o9@1??R@404hm8`<0C3`S0P1;>b8404Xj8@0604Pi8P16>R80ASXR04@j8@12>b40@C/Q0P0o>b04
03Tg80@0>SPQ00<0>S8O03/c800k<b000P0l=24203de8P0403hf8`0i<Ah0>S8O03/c8080?CDR00P0
>c<P03Xb7`0i<Ah0>c@Q03Xc800i=200=S@O03@c7P80<C<M00<0;c<L03Pf8@0h=R401P0h=R4203Pe
8P80=c@Q0P0f<b0203Db7`80=3HQ0P0c=B00100b=1l0<C<N034c7P0a<ah203<`7@<0=34N0`0e<Ql0
0`0d=R40<cDP038d7`05034c7P0303H_7@0g<1h0>C8P0080>S<Q00<0>C8P03L`7P0f;ad0200b=1l8
03Db7`P0<cHK200c=Al803Pf8@80=SPR0P0e=b40100d=R00<cDO03<e7`0c=Al503Hd7`<0=C<N0P0h
=1T00`0i=AX0>SHK03/g700203`h7@0403di7P0k=Ad0>cDM03`f7P80?CLO00D0?SPP03li8@10>R80
@3XR04Di8@0704@h8006048m7`14?B00A3dP04Ln8@19?R80C3hS0P1>?R@0201=?B<0CChQ04m08`1@
@B80DT<R05=58P1DAR40EDLR0P1LAbP01P1MBBP0GTXW05m;9P1PCBD0HDhV065>9080JThW00H0JdlX
06a@:@1]DBX0KE4Z06iB:`1_Db`2079H9`0407=I:01dFRT0ME/Z07IL:`80Med/00P0OEdd07mO=P21
HSH0Pf@f08AU=P24IS@0PfDc089T<0P0QFHg01@0QVLa08UZ=02=KSP0T74k095b?02?L3X0SFhh08]/
=P2@K3`0TFdm099^?P2DL400UW9209Mc@`2IMDD0VWI609Mc?`2IMD40VgM309eiA@80WWY600@0WGU5
09ahA02LNdH0W7]60P2MO4L309imB00309mnB@2VPTh0YX9>0080YH5=00L0Y81<0:=oB`2SOd/0Xgm;
0:F2C02VPdd0Z8E?0080ZXMA00<0ZHI@0:R5C`2WQ4h00`2[QeL50:b8F0P0[XYJ202`SUh20;2>H080
/HmQ0`2bT6800`2cTF<0]99T0;FCI@020;FCI@030;JDIP2gUFL0]iEW0080^9IX202jV6X80;NEI`T0
^IMY00L0^YQZ0;bJK02mVfd0_I]]0;bJK02jV6X0^IMY00<0^YEX00<0^iIY0;bGJP2lUfX00P2mV6/@
0;VFK080]iAZ0P2hUF/20;VFK080^YM]00H0]iA/0;NDJP2gU6X0]YAW0;JDIP2fU6@20;FDH@<0]iEW
0`2fU6H20;FCI@80]Y=Y0`2gU6X30;REJ`P0^II/00P0]iAZ0;REJ`2hUF/0^9E[0;NDJP2eTVP0/i1V
0;6>I0P0]YAV00H0^9E[0;NDJP2fTfT0]I9X0;BAI`2cT6H20;:?I@@0]99T102cTF<30;JBHP<0]i=S
0P2hU6@80;FCI@D0/Y1R102cTF<80;JAI080]iIS00H0]YAT0;FCI@2dTVD0/i1V0;:?I@2bSfL20;:@
HP80/i5S102dTV@40;FAH@@0]91P202bT6002`2eTF40]Y9R0;NCH`2hU6@0]i=S0;JBHP2dT600/XiN
0;BBI02cTF<0/Y1R0080/8iP00<0/Y1R0;>AH`2dTV@0202dTV820;>AH`030;6?H@2`SV00/8iP0080
/8iP00<0/HmQ0;:>GP2bSUh00`2bSUh00`2cSel0]91P0;FAH@080;:=H0P0/8iP0P2dT6030;>?G`<0
/XiN202`SV080;:@HP030;>>H@2bSF00/HaO0080[hYM00/0/HaO0;:=H02cSV40[h]K0;2<G02bSUh0
/hmO0;B@H02cSel0/XiN0;6=G@020;F<H0040;>=H02bSF00/XeP0;2>H080[hmP0P2bSF040;2;GP0;
0;:=H02dSf80]I1S0;:>GP2aSEd0/8aL0:n;F`2`S5`0/HeM0;>?G`2eTF400P2`SV020:n=G`@0[XaN
00H0]HmX0;B?I@2cSV@0/XeQ0;6<G`2`S5`20:n;F@80[hYM00H0/8]N0;6<G`2bSF00/hiQ0;B?HP2e
T6<80;>>H@P0/hmO0P2cSV420;:=H0<0/HaO00<0/8]N0;>?G`2cSel01P2cSel40;6<G`@0/XeP0P2c
SEh20;:<G@80/H]L0P2`RU/02@2bSF00/HaO0;2;GP2_RUd0/8]N0;6<G`2cSV40]I1S0:j<GP020:n=
G`050;2>H02bT680/i5S0;>AH`2dTV@0202cSel20:n:G@060;2;GP2aS5l0/XeP0;>>H@2dSf80]I1S
0P2cSE`01P2cSEh0/heP0;><H@2cS6<0/X]R0;:;I080/hiQ0`2bSF030;6<G`P0[hYM202cSEh00`2a
S600/8]O0:n:GP030:f8G0030:n:GP2`Rel0/HaP00P0[h]K202aSEd01P2`SEL0/HeI0;6=F@2aSE/0
/XiN0;:=H080/hiR0`2`S5P20:n;E`<0[XYF0`2`S5`20;6=G@<0/XiN00H0/8aL0:n;F`2^RUX0[HUI
0:b8F02[QeL:0:Z6EP80ZhMG0P2/R5P20:f9F@80[XYJ0P2]RET0502/R5P0ZhMG0:Z6EP2YQED0Z8AD
0:N3D`2YQED0ZXIF0:b8F02]RET0[8QH0:^7E`2YQED0Z8AD0:N3C`2XQ500ZHEA0:Z6DP2[Qe<0[8QD
0P2]RED30:Z6EP<0ZHEE0P2XQ5@30:V5E@030:Z6EP2[QeL0ZhMG0080[8QH00<0ZXIF0:^7E`2]RET0
0P2^RUX00`2]RET0[8QH0:^7E`030:V4E`80Z8=F0`2WPUD80:V5E@080:R3C`2YQ500ZXEA0:^6DP2Z
QE40ZHA@0:N2CP2VPDd20:N1DP040:J0D@2UOe00YGm@0:AnC`80Xge>00D0Yh9>0:J1C@2UP4`0Y7m;
0:=nBP020:9mB@80XGa80P2RP5<00`2SOU80Y7eB0:IlDP020:IkD@0:0:MjD@2QODd0XGe=0:1lC02O
Nd/0X7a<0:9nCP2TP500YX9B0:N3D`80YX9B00D0YH5A0:B0D02ROTh0XWi>0:5mC@020:AoD`<0YH1D
0`2VPED30:F1C@<0Y81<0`2SOd/20:B0C080YH5=0P2VPTh0102WPdl0Z8=>0:R3CP2XPdh30:N2C@80
YX5<0`2TP4`30:=oB`80XWi:202MOD`0202QNd`0X7Y;09miBP2ONDX0X7Y;0:5kC02RO4d0Xge>0P2O
Nd/0102ONDX0X7M90:5fB@2PMDP20:1dA`090:1jC@2QNdh0XG]>0:5kCP2PNTd0WWQ;09]eB02JM4L0
W7Q800<0VgM70P2JMTH209UeA@0909Qg@P2IN4<0W7Q409iiA@2PN4D0WgE309ec@@2MLD00VGE100<0
V7A00P2GLcl209Ib?P0309QfAP2GMDD0UG=30080UG=300H0UWA409QfAP2JN4P0Ug=309UeA@2KMdL2
09ahB00609YfAP2GLd<0UG5109Yf@P2IMD40Ug<o0P2FLSh01`2GLcl0VGE109Yf@P2JM4D0VG=409Ma
@P2EKd00102DKSl03`2EKd00Tfe0091Z?@2>J3/0T6Xm09A^@@2EKd80Tfe0091Z?@2CL3X0Tflk09A`
?02DL3h0UG5109E`@`0209IaA@P0Tflo202BKD4308m[=`D0T6`h0P2@JS/01P2>J3T0SFLh08]U=P2:
I3D0RF<d08QR<`<0Rf@k0P2:HcX308UR>@80Qf8e0`26HC@208MR=@0908QS=P25H3<0QF0c08AO<P23
GS40PUd`085L;`20Fbh0OeX]00<0Oe`b:oooool002[ooooo00@0WW9109mc@P2OLd80Wg=20P2PM4<2
0:5eA0<0XGI30`2PMD8209md@@<0XGE40P2RMTD30:=gAP060:=hA@2RMd@0XWM40:5f@`2PMD80WgA1
0P2NLd020:1e@0040:5f@@2RMd80XWM20:=h@`80Y7U400/0XWM40:5f@`2PMD80WgA10:1e@P2QMT<0
XgQ50:AiAP2PM4<0XGE40:9fA@020:=gAP030:9fA@2QMD@0X7A30080X7Q700H0XGM50:9gA02TMT@0
YGI20:Ef@02WMD020:EjA@80YW]60P2WO4L20:QmB0<0YW]80`2WO4T30:QmBP80Y7]70P2UO4P20:Im
B@80Ygi:0P2YOD`00`2YOT/0ZGi90:UnA`020:UoA@040:Uo@`2UNTD0Yga70:QmB0<0ZWm:00X0ZGi9
0:QmB02WOTX0Z7m;0:Z1C@2[PTh0ZX5=0:V0C02XOd/0Ygi:0`2VODT30:MnBP80Z7m;00<0Zh9>0:V0
C02WOTX00P2UO4P00`2WOTX0ZH1<0:^2CP020:V0C0030:Z1C@2[PTh0[8=?0080[HA@00@0[XEA0:Z1
C@2ZPDd0ZX5=0`2YP4`20:QoB`P0[89@0`2YP4`20:Z1C@<0Zh9>602]Q500102/Pdl0[HA@0:f4D02]
Q5020:j5D@80[hIB0`2YQ4l20:Z5D0<0ZhIA202/Qe<01@2ZQE00ZhIA0:^6D@2/Qe80[HQC0080[XUD
00L0[hYE0:j9E02]R5<0[HQC0:b7DP2[QU40ZXE@0080ZHA?0P2]R5<00`2/Qe80ZhIA0:Z5D0030:V4
C`070:R3CP2/Qe80ZhIA0:^6D@2ZQE00ZHA?0:R3CP020:N2C@P0Z8=>00H0Z8=?0:N2CP2VPDd0YH1<
0:AoB`2RODT20:5lB00809miBP2PNT/0XG]<0:5kC02PNT/0WWQ909afA`2JM4D209Ud?`80V7<n0`2G
LSd0102FLC`0Ug8n09Mb?P2GLSh209Ia?@<0UG0l00<0TV`m095[?02AJc`00P2@JS/308mY>P<0S6Lj
0P2;IST308YU>00308IP<`27HC@0R68e0080RF<f00/0R68e08MQ=026H3<0QV4g08EP=P23GS@0PUdc
085L<P22GC<0Pehd08AO=@0207mL=00407iK<`1mFS80O5Ta07aI<@80NeP`0P1kF38207YG<@0907UF
<01hEBl0Me@^07MD;P1cDb`0LU8[075A:P1`D2T0KdlX0080L50Y00T0LE4Z075C<@1aDc40L58`06i@
;P1]Cbd0K4h/06]=:`1ZC2X00`1ZC2P206U;9`<0J4XV00<0ITTW06M::01WBRP00P1WBRP0101VBBL0
I4LU06A79@1QBBD70618900606959@1SARH0IDPX06M::P1XBb/0IdXZ0P1VBBT306E8:080ITTY101W
BRX0101ZCB/0JD`Z06U<:P1YC2X406Q;:@0506]>;01ZCB/0JTd[06U<:P1XBbT00`1WBRP806]?:P80
KddZ00<0KTdZ06a>:P1[CbX00P1YCbX00`1XD2X0KU8]06eA;00206eA;0`0K50[101^D2`206e?:`80
K4hZ00<0Idl[06Q@;01YDBd00`1YDBd01P1XD2`0Idl[06mC;P1]DB`0JdlZ06U=:080Id/V0P1XC2L2
06I>:P80Idl[0`1XD2`00`1YDBd0KDl[06a>:P0206a>:P<0JddY00L0JT`X06M8:@1VBBT0IDPX06=9
:01QBBL0H4TW0080GDTV101OB2H406199`0305a59P1MARL0GTLX0080GdPY00@0GDHW05]49@1J@b@0
Fd@U0`1LABH405e69`P0Ed@T0P1EA2H0101D@bD0Dd8T05=2901B@B<205508P@0DT4W00@0D3lU04ln
901=?280BcXP0P1=?B@204`l8`<0Bc/R0P1:>R4204Tj8`0304Hj8P15>b80@S/Q0080@C/Q00<0?c/P
03`g8@0l=b401P0l=b4203/c8080?3@Q100m=B800`0i<Ah0>S8O03`d8@0203de8P0303`d8@0j<Ql0
>C4N0080>C8O00<0>3<O03Hd7`0e=1l00P0c=Al00`0b=Ql0=cDP03Le800603Le8080>3DR0P0g=242
03Hc8080=C8O0`0c=B03038d7`80<C<N00@0<c0M03@a7P0d<Ah0=34N0P0e<Ql203Hc800303@f8@0b
=1l0<38M0080;S0K00H0;c4L030b7@0b=1l0=C0M03Ha7P0g<Ql203Pc800303Lb7`0f<Ah0=C0M00P0
<S@O200f<b0803@f7PP0=3HP200g=B0203@f80<0<cDO0`0b=1h703Hd7`0703Le800h=1T0>CDJ03Te
6P0j=Q/0>cLL03`h7@0203di7P<0?SLM0P0o>1h01010>Al0@CXP048k8@12>b4804Lk8@0@04Dn8@16
?b80B3lR04Xo8`1=?b@0CclU05109P1A@2H0D3lS0550901B@B<0Dd<R05E58`1FAR80EdLS05M88@80
GTLW00L0H4TW065;9P1SCBP0IDlX06I@9`1WDBP0JdlW0080K50X00<0KE4Y06iB:P1_Db/00P1`E2`0
401bERH0LeLW07AH:01fFRX0N5`/07YN;P1kGbl0O60`07iN=@20HCD0PV<g08AU=`25ISL0QFLe08AV
<P23IC4208AU=P0408EV=`26IcP0QfPi08MX>@80R6Tj01@0RFPc08]Z=@2>KCP0TG0k099a?02AL3/0
Sfhi08i]>02BKSh0Tflo09A`@02FLT80V7A409YfAP2KMdL0W7Q809Ue@@2JMT80W7Q409eiA@@0WWY6
0`2MO4L209imB0<0Wgi900@0YX9>0:F1C@2UPDd0YH5=0`2TP4`0102SOd/0YH9<0:N4CP2XQDl30:Z7
D@030:V6D02XQDl0ZhMG0080ZhMG0P2/R5P30:f9F@P0[h]K202`SUh30;6?H@80/Y1R102cTF<20;BB
I0060;FCI@2fU6H0]iEW0;RFJ02iUfT0^YQZ202iUfT80;RFJ0T0^IMY00L0^YQZ0;^IJ`2lVV`0_9Y/
0;^IJ`2jV6X0^IMY00<0^IAW0`2jUFP20;^FJA00^II/0P2gU6X20;REJ`80^II/0P2jUfd0202hUFd0
^9E[0;NDJP2gUFP0]YAV0;JDI02fUF80]IAQ0P2hUVP20;NEI`<0]YAV00<0]I=U0;JCJ@2fTfT00`2g
U6X30;REJ`P0^II/0P2gU6X20;REJ`040;NDJP2eTVP0]95W0;:?I@P0]YAV0P2gU6X00`2fTfT0]I9X
0;BAI`020;>@IP030;:?I@2cTF<0/i5S0080/i5S102dTV@30;JBHP<0]i=S0P2hU6@80;FCI@T0/i5S
202fTF@0202gUV<0]YER0;JDI02eTfD0]99U0;>@IP2bSfD0/XmW0`2bT6820;>AH`<0]99T202eTF48
0;>AH@030;FAH@2fTV80]i=S0080]i=S00H0]I5Q0;B@H02cSel0]99T0;>AH`2bT6820;2>H0030;:@
HP2cTF<0]99T00P0]99R00<0/HmQ0;:@HP2bT6800P2bT6802`2aSf40[heO0:n=G`2dT600/hmO0;2<
G02_Re/0/8aL0;:>GP2eTF40]i=S00P0/XeP202`SV00102dT600/hmO0;>?G`2cSel20;:>GP80/HeM
202`SV080;:@HP030;:=H02`Reh0[hYM0080[XUL00/0[hYM0;2;GP2bSF00[h]K0;2<G02bSUh0/hmO
0;B@H02cSel0/XiN0;6=G@020;F<H0040;>=H02bSF00/XeP0;2>H080[hmP00<0/XeP0;6<G`2aS5l0
0P2`Reh0302aS5l0/XeP0;>>H@2dSf80/XiN0;6=G@2`S5`0[h]K0;2<G02aSEd0/hmO0;B@H0<0/8iP
0P2_SEl30:j<GP090;B>I`2dSfD0/hiT0;:=H@2aS5l0/8aL0;2<FP2_ReT0[hYM0080/8]N00<0/HaO
0;:=H02cSV400P2dSf820;F@H`040;B?HP2cSV40/hiQ0;:=H080/HaO202bSUh30;:=H080/HaO0`2`
Reh80;:>GPP0/HaO0P2cSEh20;:<G@80/H]L0P2`RU/20;6<G`<0/8]N00<0/HaO0;>>H@2dSf800P2_
SEl0102`SV00/HmQ0;6?H@2bT6820;>AH`P0]91P00H0[hYM0;2;GP2`Reh0/HaO0;:=H02cSV420;B?
HP80/heL00<0/heN0;>=H02cS6400P2cS6<00`2cS6D0/hiQ0;>>H@030;:=H0<0/HaO202_RUd80;:<
G@030;6<G`2`Reh0[hYM00<0[HQK00<0[hYM0;2;GP2aS5l0202_Re/80;6=G@060;2=E`2`S5P0/8aH
0;6=F`2aSEd0/XeP0P2bSF420;2<F080[h]G0`2^RUH0102]RED0[h]K0:n;F`2_Re/20;2<G0<0/HeM
0P2_Re/00`2^RUX0[HUI0:b8F0020:^7E`030:Z6EP2[QeL0ZhMG00P0ZhMG0`2/R5P40:f9F@80[8QH
00<0ZhMG0:Z6EP2YQED00P2XQ5@50:b8F0030:Z6EP2YQED0Z8AD0080Z8A@00<0ZHEA0:Z6DP2[Qe<0
0P2/R5@00`2]RED0ZhMG0:^7E`020:Z6EP<0ZHEE00<0Z8AD0:V5E@2YQED00`2ZQUH30:^7E`040:R4
E02YQED0ZhMG0:f9F@80[XYJ00<0[HUI0:b8F02ZQEP00`2YQ5L20:R3EP80Yh9E202YQED0202XPdl0
ZHA@0:Z5D@2[QU80ZXEA0:V4D02WPTh0YX5=202UOe020:J1C@030:F0C02TOd/0Xgi:00<0XWe900`0
XGa80:1nD02POU00XWe@0:AnD@2VOE40YgaA0:QmDP2YO580Y81@0:=oC`2QODd20:1lC0080:5mC@2S
Odl0Y81@0:N3D`2VPU80YH5A0:B0D02SOdl30:9nCP80Y7mB0`2UP5<30:J1E080YX9>0P2UPDd30:B0
C0030:=oB`2TP4`0Y81<0080Y81<0P2UPDd20:J2CP<0YX5<0`2WPTd20:R3CP80YX9>0`2UPDd30:B0
C0P0WWa<0P2PNT/00`2RO4d0Xge>0:=mCP020:=mCP0A0:9lC@2OODd0Wge=0:1lC02PNT/0XGQ:0:5f
B@2PMDP0XGE809ihB`2OND`0X7Y=0:5kCP2PNTd0WgU<09egBP2KMDP00`2LN4P209]gA`<0VWI600P0
VGQ309YiA02MNDD0WgY60:9jA`2RN4H0XGM50:9fA@<0VgM30P2JMT8309Ue@@80VgU900@0VGM709Qf
AP2HMTH0V7I60P2IMdL0102HM4@0VGE509YfAP2JMTH209]gA`80VWI600<0VWI209Ue@@2HM4000P2G
Lcl01P2HM400VGE109Yf@P2JM4D0VG=409Qb@`80Ug5200d0V79309UcA02ILd@0VWA509UcAP2EKd80
Tfe009A^@@2GLD@0V79509E_@P2BK3l0VGI00080VGE100<0VWI409YfAP2KMTT00P2KMTX809Ea@@05
09IaA02EL4<0UG1309A_@P2CKT400P2BKD000`2AK3l0TFdi095]>@06095]>@06099/?@2AJc`0T6Xk
08mY>P2=IcP0S6Hg0P2;ICH208mX?`80SVLn0`2=ISd0102<IC`0RVDh08UT=`26HC@208EP<`0408IQ
=028HcH0RVDh08MR=@80QV4d00<0QF0c08AO<P23GS400P22GC03081M<b_ooooo000Zooooo`80WW91
0`2OLd830:1d@`060:=hA@2RMd@0XWM40:5f@`2PMD80WgA10P2NLd030:5eA0<0XWI50P2SMdH01P2S
N4D0XWM40:9gA02QMT<0X7E209md@@80WW=00P2OM4420:1e@P030:5f@`2RMd@0XgQ50080XgQ500L0
XWM40:5f@`2PMD80X7E20:5f@`2SN4D0Y7U60080XGE4102RMTD20:5eA080WgM600H0X7I40:5f@`2S
MD<0Y7E10:Ae?`2VM3l20:EjA@80YW]60P2WO4L20:QmB0<0YW]8102WO4T20:QmBP80Y7]70P2UO4P2
0:ImB@80Ygi:0P2YOD`00`2YOT/0ZGi90:UnA`020:UoA@040:Uo@`2UNTD0YW]60:QmB080ZWm:00H0
ZGi90:QmB02WO4L0YGa80:MnBP2XOd/30:Z1C@040:QoB`2WOTX0YWe90:ImB@H0Ygi:00<0ZX5=0:V0
C02WOTX00P2VODT00`2WOTX0ZH1<0:Z1C@030:^2CP030:b3C`2]Q500[HA@0080[XEA0`2ZPDd30:V0
C080Z7m;202]Pe420:V0C0<0ZX5=0`2[PTh80:j5D@<0[HA@102/Pdl00`2[PTh0[HA@0:f4D0060:f4
D080[8=?0`2]Q5030:j5D@P0ZXE@202/Qe<20:^6D@80[8MB0P2]R5<20:j9E080[HQC0P2/Qe80102[
QU40ZXE@0:Z5D02ZQE020:f8D`030:b7DP2[QU40ZhIA0080ZXE@0P2YQ4l30:^6D@030:Z5D02YQ4l0
ZHA?0080Z8=>202YQ4l20:R3C`080:N2CP2UP4`0Y7m;0:=nBP2RODT0XGa80:1jB@2QNdX20:9lB`05
0:5kBP2ONDP0WGM609]eA02IM3l00`2HLch209Mb?@80UW4l0`2FLCd309E`?080U6lk102BK3d4095[
?080SVPk0`2=IcX308aV>@0308QR=@29HcH0RF<f00@0RF<f00X0R68e08MR>026HCL0Q5le08=N=022
GC<0Pehd08AO=@25H3H0PEhf0P20GCD00`1oG3@0OU/c07eJ<P0207aI<@0907mL=P1nFcD0OEXd07]H
<P1jEc40N5D_07MD;P1fDbd0M5@[0080Le<Z0P1bDRT2075A:007079B:@1bE380LE<a071B<01^D2h0
K4h/06]=:`0206U;:@<0JT`X0`1YBbL206Q:9P0306A79@1VBBL0J4/Y0080JD`Z00<0IdXX06A79@1R
AB<00`1SBBH406989@050657901QA2@0HTDU06A79`1VBBT00P1WBRX206I9:@80HdHV0P1TAbL406E8
:00606I9:@1ZCB/0JTd[06U<:P1XBbT0IdXX0P1VBBL01`1UB2H0JD`Z06Q;:@1XBbT0IdXX06I99`1U
B2H00P1TAbD806Y>:@80KT`Y00<0KD`Y06]=:@1ZCRT00P1XCRT01`1WCbT0Ke<^06iB;@1^DRd0KE4/
06a@:`1[CbX00P1ZCRT806]?:P@0KDl[101/CRX306M?:`80J50/0`1WCb/0101_DS00KE0^06Y=:`1X
BbT306I99`0406M::01WCBX0IddZ06M=:P80J4h[0`1YCb`406e?:`@0K4hZ00P0JDX[06M::P1WBRX0
I4XY069::01PBBL0GTXW05e99P80GTLU0P1OB2H206199`80HDXX00<0G4DV05e69`1NAbP00P1OB2T0
0`1MARL0Fd@U05Y3900205Y3900405]49@1LABH0G4DV05e69`80GTLX201F@b<205E49P0405A39@1C
@R@0Dd8T05918`80DD0R00P0D3lU05919`1C@RP0E4<Y05=2:01@?bD0C3/Q04Xi7`80CShU0P1=?B@3
04`l8`80Bc/R0P1:>R<00`19>R<0ASXR04Dk8P02048k8@03044k8@0o>B<0?cTS00@0?SPR0P0m=b42
03`d8@H0?CDR00<0>S8O03/c800l=2400P0m=B800`0l=240>c<P03Xb7`0203Pa7P0303Pc7`0f=1l0
=C@O0080=3HP00<0<cLP03Le800g=B001P0g=B0203Pe8P80=c@Q0P0f<b0203Db7`80<cDP1P0b=1l3
03@a7P80=C8O0`0f<b000`0c=B00<C<N02h`6`0202`^6@0302h`6`0`<Qd0<S@O00<0=34N0P0e<Ql3
03@a7PP0<S@O200f=B4@03@f80P0=cDP1@0b=1h3034c7@0303Hd7`0g=B00=cDP0080=cDP0`0h=R40
1P0i=AX0>SHK03Xf6`0k=a`0?3PM03di7P80?SXO0`0o>1`00`10>Ad0@CXN048k7`0204<l800304@m
8@1<?R<0C3hS0080C3hS101=?b@0201:@B80Bd8S04a18`1?@B@0DD8U05=29P1D@bL0ET8W0P1F@bD0
301GA2@0F4DT05U78`1JB280FdTS05]98@1PAbP0HDTW069:9P1TC2P0IdlY06UB:@80Je@Z0P1^DbP0
101_E2T0L5DZ075F:`1aER/2079G;00]07EF9`1fEbP0MePY07YK;01lGBh0OUl`081Q<P21HS<0P64e
085R=023I3H0QFHg08IX=P26J3@0QFLa08AV<025ICH0QVHg08MW>028J3T0RFTj08YZ>`2;Jc`0S6`m
08eY=@2?JcL0TFdi09A`?02ELCd0U70l09=_>`2BKSX0U70n09Ea?`2FLT00V7A209YfA02LN4H0WGU7
09ijB02JMT80VgM309ahA02MNDD0WWY600<0Wg]70`2NODP209mnB@<0X7m:202UPDd02@2VPdd0YhA>
0:V6D02ZQe40ZhQB0:Z7D@2YQU00Z8E?0:Z6EP020:^7E`040:b8F02]RET0[XYJ0:j:FPT0[h]K202a
Sel30;:@HP80/i5S0`2dTV@02@2cTF<0]99T0;BBI02eTfD0]YAV0;RFJ02iUfT0^YQZ0;^IJ`080;VG
J@P0^9IX202iUfT80;ZHJP<0^9=V1@2iU6L@0;VFK080]iAZ0P2hUF/20;VFK080^YM]00H0^9E]0;RE
J`2hUF/0]iEX0;NEI`2fU6@20;JEHP<0^9IX0P2gUFL30;JDIP80]Y=Y0`2gU6X30;REJ`P0^II/102g
U6X0102fTfT0]I9X0;BAI`2dTFL80;JDIP<0]YAW00<0]I=V0;BBI@2dTVD00P2cTF@01@2aSf40/Y1R
0;:@HP2cTF<0]99T0080]I=U00@0]YAV0;JBHP2fTV80]Y9R0`2gTf<20;RDI0P0]I=U102dTV@40;>A
H`030;:@HP2fTF@0]Y5T00H0]Y5T0P2fUF800`2eTf<0]99T0;>AI0020;:?I@030;6>IP2aSf40/HmQ
0080/Y1R0P2cTF<20;BBI0030;B@H02eTF40]I5Q0080]I5Q0`2fTV880;>AH@D0]Y9R00H0]I5Q0;B@
H02dT600]99T0;>AH`2bT6820;2>H0030;:@HP2cTF<0]99T00P0]99R00<0[heO0;6?H@2cTF<00P2d
TV@01P2bT680[heO0:f;G@2fTV80/hmO0:n;F`80[HUI00<0/HeM0;FAH@2hU6@0202cSV480;6?H@<0
/hmO0P2bSUh30;6=G@P0/8iP202aSf400`2aS5l0[hYM0:j9G0020:f8F`0;0:j9G02_RUd0/HaO0:n;
F`2`S5`0/XiN0;>?G`2dT600/hmO0;:>GP2aSEd00P2eS600102cSF00/XeP0;:=H02`SV020:n?H0D0
/HaO0P2bSF020;>>H@030;6=G@2`S5`0[h]K0080[h]K00<0/HeM0;>?G`2dT6000P2aSf420;2>H080
[heO0P2^S5h01P2cSFH0/hiT0;>>I02bSF40/HaO0;6=G@80/8aJ0P2`Reh20;6<G`040;:=H02cSV40
/hiQ0;>>H@80]Y5T00@0]I1S0;B?HP2bSF00/HaO0P2`Reh80;:>GP80/XeP0`2aS5l30;2;GPP0/XiN
00<0/XeP0;6<G`2aS5l00P2aS5l30;2;GP80/heN0P2bS5d20;6;G080/8YK102`Reh20;6<G`80/XeP
00<0[heO0;2>H02`SV000P2aSf420;:@HP030;>AH`2eTF40]I5Q00H0]I5Q0P2`Reh20;6<G`040;:=
H02cSV40/hiQ0;>>H@80/XaK00<0/XaM0;>=H02cS6400P2cS6<00`2dSFH0/hiQ0;>>H@030;:=H0<0
/HaO202_RUd80;:<G@030;6=G@2`S5`0[h]K00<0[HUI00<0[h]K0;2<G02aSEd0202_Re/80;6=G@06
0;2=E`2`S5P0/8aH0;6=F`2aSEd0/HaO0P2bSF430:n;E`<0[XYF0P2]RED40:j:FP80[h]K0P2`S5`3
0:j:FP030:f9F@2/R5P0[8QH00`0ZhMG202/R5P20:^7E`040:Z6EP2YQED0ZHEE0:V5E@<0[HUI00D0
[8QH0:^7E`2ZQUH0ZHEE0:R4E0030:V5D@030:Z6DP2[Qe<0ZhMC0080[8QD0`2[QeL20:Z6EP<0ZHEE
1P2ZQUH20:^7E`040:F1D@2WPe<0ZHEE0:b8F0<0[HUI00<0[8QH0:Z5F02ZQEP00`2YQ5L30:R3EP80
ZXIF102YQED20:R4E0080:R3C`2YQ500ZXEA0:^6DP2ZQE40ZHA@0:N2CP2VPDd30:AnC`80YGm@0`2V
P5430:F0C0040:AoB`2SOTX0Xgi:0:=nBP80XWe901D0WWa<09mmC@2QODd0Xge>0:ImC`2XOE00ZGiA
0:YnD@2UPE40Y81@0:9nCP2QODd0X7a<0:5mC@2ROTh0Xgm?0:N3D`2VPU80Y81@0:=oC`2ROTh00P2S
Odl30:B0D0<0YH5A0`2VPU830:J2CP80YH5=2@2TP4`20:F1C@050:AoBP2UP4/0YH1;0:J1C02WPTd0
0P2XPdh00`2YQ4l0Yh=?0:N3C`030:J2CP<0YH5=202PO4X00`2ONDX0XG]<0:AnC`020:J0D@030:Eo
D02SODh0XG]<0080Wgm>00@0Wge=0:1lC02PNT/0XGQ:0P2QMTT00`2MMdX0WWQ;0:1jC@020:5kCP03
09miC02NN4/0WGM:00<0WGU90P2LN4P309]gA`0509YiA02KNTD0WWY60:1kA`2SNdP00P2UNdT00`2V
NTT0WWY609eiA@0209eiA@80W7Q40P2KMd<209ilC00309ekB`2LNTX0VgU900<0VWQ800/0VWI609Ue
A@2IMDD0VGE509YfAP2LN4P0WGU909ijBP2KMd<0VWI209Ue@@0209Qd@00509Ue@@2JMT80VgM309]e
AP2JM4D00`2ILd@0502KMDH0WGM809egB02NN4T0WWQ;09YdA`2GLD@0V79509YdA`2KMDP0V79509A^
@@2JMd40VWI209]g@`2KMdD0W7Q809agBP2LMd/0WGQ<202GLd<01P2IMDD0V7A409Mc@`2FLT80UG51
09=_?`80TVhn00<0U70l09=_>`2CKc/00P2CKc/3099^>P0609A^?`2CKCh0TV`m095[?02@JS/0SfTj
0P2>J3T0102CK440TV]0099[@02BJd02095Z?`80T6Tn00T0SFPk08]V>@28HcH0QV4d08EP<`27HSD0
RVDh08aW>P29I3L00P28HcH208MR=@80QV4d00@0QF0c089O=@22GcD0PUle:oooool002[ooooo0`2N
LT4309mc@P80X7A300H0XgQ50:9gA02RMd@0XGI30:1e@P2OM44209ic@080X7A30`2QMD@30:9fA@06
0:=hA@2RMd@0XWM40:5f@`2PMD80WgA10P2NLd0209md@@80X7E200L0XGI30:9gA02SN4D0XgQ50:Ai
AP2SN4D0XGI30080X7E200<0XGI30:9gA02SN4D00P2RMTD40:5eA080XWI50P2OMdH01P2PMT@0XGI3
0:=e@`2TMD40Y7Do0:Id?`80YGY50P2VNdH20:MlA`80Z7e80P2UNTL40:IkB0<0Yga90P2TNdL20:El
B080YWe90P2WOTX20:UmC0030:UnB`2YOTT0ZGi70080ZGm50100ZGm30:AiA02VNdH0Z7e80:UnB@2Z
OdX0ZGi90:QmB02WO4L0YGa80:ImB@2XOd/0ZH1<0:Z1C@2YP4`0Z7m;1`2WOTX20:ImB@80ZH1<102W
OTX20:V0C0030:^2CP2/Pdl0[8=?0080[8=?0`2]Q5030:Z1C@<0ZH1<0P2XOd/80:b2D0<0ZX5=0`2[
PTh20:b3C`X0[HA@0P2/Pdl0102[PTh0ZX5=0:Z1C@2ZPDd80:f4D0<0[8=?0`2]Q5020:j5D@P0ZXE@
202]R5@40:b7DP@0[HQC0`2/Qe840:^6D@060:Z5D02^RE@0[XUD0:f8D`2/Qe80ZhIA0P2ZQE020:V4
C`<0ZhIA102ZQE090:V4C`060:V4D02XPdl0Yh9>0:J1C@2UP4`0Xgi:0P2RODT02@2QO4P0XWe90:=n
BP2SOTX0XWe90:1kA`2NNDD0W7M309Ye@00309Ud?`80V7<n0P2GLSd209Mb?P80UW4m0`2EL3`00`2D
Kc/0Tfdn09=]?P0609=]?P80TFPl0P2@Ic/408mV>P0308]U>02:I3L0RV@g00@0RV@g00T0RfDh08QS
>@27HSP0QF0f08AO=@23GS@0Q5le08EP=P26HCL00P22GcL00`21GSH0P5de07mL=00207iK<`0:07eJ
<P21GSP0P5dg07mL=P1mFS@0NePb07UF<01hEBl0Me@^07AE:@80MEHZ0P1dEBT207=D:009079C9`1_
DBl0Ke4_06e?;@1/CR`0JT`Z06Q::01WBBL0ITPV0080JddY0`1ZC2P306U;9`0306A79@1VBBL0J4/Y
0080JD`Z00<0IdXX06A79@1RAB<00P1WBRP206I99`0:06E89P1TAbD0I4LU06A79@1QA2@0HTDU06A7
9`1VBBT0IdXZ06I9:@80IDPX0`1SARH206A79`@0IDPX0P1YC2X0101XBbT0IdXX06I99`1VBBL206E8
9P0406M::01VBBL0ITTW06E89P80I4LU0P1SAR@806U=:080KD/X00<0K4/X06Y<:01YCBP00P1WCBP0
1@1VCRP0KE4/06eA;01/D2/0JdlZ0080JThY0P1YCBP806]?:P@0JddY101/CRX00`1WCb/0IThZ06I>
:P0406I>:P0506M?:`1]D2h0Jdh/06U<:P1WBRP00`1VBBL00`1WBRP0J4/Y06Q;:@0206U<:P80JTd[
0P1[CR`406a>:P@0KDl[00H0JT//06U<;01XBb/0ID/Z06=;:@1QBRP205i:9`@0GdPV101PBBL00`1L
ABH0GDHW05i7:00205m8:@0405e69`1KA2D0FT<T05U28`80FT<T00D0Fd@U05a59P1MARL0GDHW05i7
:00805I38`80ED@V00@0E4<U05=2901C@R@0DT4S0P1A@2802@1??R@0DD0V05=2:01D@bT0Dd8X0550
9P1>?B<0C3/Q04lo9P0304hn9@80CCdT0`1<?2<204`j900704Xj8`19>R<0ASXR04Dk8P14>R40@S/Q
048j9@02044i9080@3PS0P0o=b800`0n=R40?SHS03hf8`0603de8P0303Xb7`0k<b00?CDR0080?SHS
00<0?CDR03/c800j<Ql00P0i<Ql01P0h<al0=cDP03He800d=R00=CLQ03@h8@P0=S@O0P0h=B8203Ld
8@80=S<P0P0e<Ql6038d7`80<cDP0P0d<Ah203Db7`80=S<P0P0g=2400`0a<ah0<38M02h`6`0202d_
6P0302h`6`0a<ah0<S@O00<0<c8N0P0b<Ad303<b7PP0<S@O200d=R4@03@f80P0=S@O0`0a<ad5038d
7P<0=cDP00<0>3HQ03Tg8P0i=b800P0j>2<01P0j=Q/0>cLL03/g700l>1d0?CTN03hj7`80?c/P0P12
>A`204<j7@0304@k7P15?1l0ASdP0080AchQ00<0CSlR04m08`1?@2<00P1@@B@205529@0I05939P1>
@b<0CT<S0554901CA2D0ED@V05I59`1HABL0FTDX05Y59P1KARL0FdLV05a89@1MBB@0GTXU05i;8`1N
Bb40HdTX06A:9`1VC2T0J4hY06YA:@1/DbX0KUHZ06mG:`02071E:004075F:@1bEbX0LeP[07AI;080
MEX]0100N5PY07UI:P1jFR/0OEd^07mO<021HC80Pf<d08AT=@21HS@0PV<d08EV=`27JCL0QfTe08MY
<`27JS80QVTa0P28ISP01029IcT0RVPj08aZ?02=Jcd208i/?P0408m[=`2AKCT0TVhj09A`?0<0UG4m
00T0U70l09Ea?@2FLSh0Ug<o09Ue@@2KMd<0WGU509ijAP2ONdL00P2LN4@209eiA@0409ijAP2ONdL0
X7a80:5mB@<0Wgi90P2POdX30:60B`@0YH5=102VPTh00`2VPdd0YhA>0:V6D0030:^8DP030:Z7D@2Y
QU00ZXIF0080ZhMG00@0[8QH0:j:FP2_Re/0[h]K2@2`S5`80;6?G`<0/i5S0P2dTV@30;FCI@090;BB
I02eTfD0]I=U0;JDIP2gUFL0^9IX0;VGJ@2jV6X0^iU[00P0^9IX402iUfT20;ZHJP@0^IMY0P2jV6X5
0;VDI`<0^9=V402iUV`20;NDJP80^9E[0P2iUV`20;ZGK@060;VFKP2iUV`0^9E[0;RFJ@2gUFL0]iEU
0P2fUF820;VGJ@80^9IX0P2gUFL20;JDIP80]Y=Y0`2gU6X30;REJ`P0^II/0P2gU6X20;JCJ@<0]I9X
00<0]Y=Y0;JDIP2fU6H01`2fU6H40;FCI@<0]99T00D0/HmQ0;:@HP2bT680/i5S0;BBI0020;FCI@04
0;JDIP2fTV80]Y9R0;JBHP<0]i=S0P2hU6@<0;FCI@030;BBI02cTF<0/i5S0080/Y1R202fTF@0202f
UF80]IAQ0;FCH`2dTV@0/i5T0;:?I@2aSV@0/HiV0`2aSf420;:@HP<0/i5S0P2dT6020;FAH@040;JB
HP2gTf<0]i=S0;NCH`P0]99R0P2gTf<00`2fTV80]I5Q0;FAH@030;FAH@030;BBI02cTF<0/Y1R0080
/8iP00<0/Y1R0;>AH`2dTV@0202dTV800`2_SEl0/HmQ0;>AH`020;BBI00;0;:@HP2_SEl0[H]M0;FA
H@2bSUh0[h]K0:b8F02]RET0/8aL0;FAH@2gTf<0202cSV480;6?H@80/hmO0P2bSUh20;6=G@80/8aL
202`SV080;6?H@030;6<G`2_RUd0[XUL0080[HQK00/0[XUL0:n:G@2aS5l0[h]K0;2<G02bSUh0/hmO
0;B@H02cSel0/XiN0;6=G@020;F<H0040;>=H02bSF00/XeP0;2>H080[hmP00<0/8]N0;6<G`2aS5l0
0`2bSF030;>>H@080;6=G@2`S5`0[h]K0:j:FP2_Re/0/8aL0;:>GP2cSel30;6?H@80/8iP0`2_SEl0
1P2cSFH0/XeS0;:=H`2bSF40/XeP0;6=G@80/HeK0`2aS5l40;:=H0070;>>H@2fTF@0]Y5T0;F@H`2d
Sf80/XeP0;6<G`020;2;GPP0/XiN0`2aS5l30;2;GP80[hYM202bSUh20;:=H080/HaO00@0/8]N0:n:
G@2_RUd0[hYM0P2cSEh20;:<G@80/H]L0P2`RU/20:n:G@80/8]N102aS5l20;2>H0@0/HmQ0P2bT688
0;FAH@<0/HaO102bSF001P2cSV40/H]J0;6;FP2bS5d0/XaO0;><H@80]8eT00<0]8eV0;>>H@2cSV40
0`2bSF030;6<G`P0[hYM202aRe`00`2aSE/0/8aJ0:n;F@030:f9E`030:n;F@2`S5X0/HeK00P0[h]K
202aSEd01P2_S5H0[h]G0;2<F02`S5X0/8aL0;6<G`80/HaP0P2_ReL30:j:EP<0[HUE0P2/R5P20:f9
F@D0[XYJ102]RET=0:b8F0T0ZhMG102ZQUH01@2YQED0[XYJ0:j:FP2]RET0[8QH0080ZhMG0P2ZQUH0
0`2YQE40ZXIB0:Z6DP020:Z6DP<0ZhMC0P2/R5P20:^7E`80ZXIF0P2YQED20:^7E`H0ZXIF00@0YH5A
0:J2DP2YQED0ZhMG0`2/R5P0102[QeL0ZXEH0:Z5F02ZQEP30:V4E`80Z8=F00<0ZhMG0:Z6EP2ZQUH0
0P2YQED20:R4E0090:N3D`2XPdl0ZHA@0:Z5D@2[QU80ZXEA0:V4D02WPTh0YX5=00<0Y7i?0P2UOe03
0:J0D@030:F0C02TOd/0Y7m;0080Y7m;102SOTX02`2NODX0Wgi;0:5mB`2SOD`0YWi=0:QnCP2YOdl0
ZWi?0:J2DP2UPE40Xgm?0080XGe=00H0XWi>0:=oC`2TP500Yh=C0:J2DP2TP5020:9nCP030:=oC`2T
P500YH5A0080Y81>0`2UPDl30:J2D080Yh=?0P2VPTh20:F1C@P0Y81<0P2SOd/20:AoBP040:F0B`2V
PD`0YX5<0:N2C@80Z8=>0P2WPdl30:J2CP<0YH5=202PO4P00`2ONDX0XG]<0:AnC`020:J0D@030:Eo
D02SODh0XG]<0080WX1>00@0WWi=09ilC02ONd/0WgU:0P2PMdT00`2MMdX0WWQ;0:1jC@020:5kCP03
09miC02NN4/0WGM:00<0WWY:0P2MNDT309ahB080W7]600H0Wg]70:1kA`2SNdP0YG]90:IlBP2XO4/2
09mkA`<0WWY60`2MNDD209mmC@80WWa<00D0WG];09ajBP2KNDT0VWQ809]gA`0309YfAP0709]gA`2M
NDT0WWY:09mkB`2LN4@0VgM309Yf@P0209Ue@@0309Yf@P2KMd<0W7Q40080VgE60P2JM4D01`2KMDH0
WGM809miBP2ONDX0XG]<0:5kCP2MMdX00P2JM4L01@2MMdX0WWQ;09YdA`2GLD@0VGI00080VGE100<0
VWI409YfAP2JMDP00P2KMTX809QdA00609]gA@2JMT@0VGE309Qd@P2GLd40UG4o0P2DL3h309Ib?P03
09Ea?@2DL3`0U70l0080Tflk00@0UW1109E_@02EKd00U6ho0P2CKCh2099/?@<0UFm20`2DKT4209=]
@008091[?P2>JC`0S6Lj08YU>029I3L0RVDh08aW>P2=J3/208]V>@<0RVDh0`29I3L308ER>2_ooooo
000Zooooo`80WG500P2NLT4309mc@P040:1d@`2QMT<0XGI30:5f@`<0X7E20P2OM4430:1d@`80XGE4
0`2RMTD01P2SN4D0XWM40:9gA02QMT<0X7E209md@@80WW=00P2PM4<0102QMD@0XWI50:9fA@2SMdH2
0:AhA`0;0:AiAP2SN4D0XGI30:1e@P2OM440X7E20:5f@`2RMd@0XgM60:9fA@2QMD@00P2PM4<00`2Q
MD@0XWI50:=gAP020:1hA`060:5gA@2RMd@0Y7I40:Ef@P2UMT00YgE00P2UNTD20:IkAP80Yga70P2X
ODP30:EjA`<0YW]80`2WO4T20:AkA`80YGa80P2VODT20:MnBP80ZGe<00<0ZGi;0:UnB@2YOTL00P2Y
OdD0102YOd<0Y7U40:EjA@2WO4L20:UnB@060:QmB02WO4L0YW]60:ImB@2WOTX0Z7m;0P2YP4`00`2X
Od/0YWe90:ElB0020:QoB`<0Ygi:0`2VODT00`2YP4`0Z7m;0:QoB`020:MnBP80Z7m;00<0ZH1<0:^2
CP2[PTh01P2[PTh30:Z1C@<0ZH1<0P2XOd/80:^1C`<0ZX5=0P2[PTh;0:b3C`060:f4D02/Pdl0[8=?
0:^2CP2ZPDd0ZH1<0P2XOd/80:f4D080Zh9>0P2/Pdl30:f4D0040:j5D@2[QU40ZhIA0:^6D@80ZXE@
0`2YQ4l80:f8E0@0[8MB102]R5<80:^6D@80[XUD00<0[HQC0:b7DP2[QU400P2[QU420:Z5D0P0ZhIA
202YQ4l20:V4D0070:R3C`2VPDd0YH1<0:AoB`2SOTX0XWe90:9mB0020:=nB@060:AoBP2SOTT0XGa7
09mjA@2MN4<0W7M20`2KMT4209Ye@080VG@o0`2HLcl209Mb?P<0UW4m0P2FL44209E_@00409A^?`2C
KCh0Tfdn09=]?P80TfPm0P2BIc`3095V>`04091U>P2=IcX0S6Hi08]U>080RV@g00/0RfDh08aV>@2=
IcX0RF@j08QS>@26HCL0QF0f08AO=@25H3H0QV4g08MR>00208=P>080PUlg00d0PEhf081M=@1oG3@0
Oe`d089O>@21GSP0P5dg07iK=@1lFC<0NePb07YG<@1iES00MEHZ0080MUL[00/0MeP/07IG:`1eERX0
M5DY07=D:01^D2h0KDl]06a>;01[CB/0JT`Z06Q::00206M99`<0JddY0P1ZC2P306U;9`0306I99`1W
BRP0IdXX0080IdXX00<0ITTW06A79@1TAbD00P1YBbT206Q::00706M99`1VB2H0IDLU06E79@1RABD0
HdHV06E8:00206I9:@0406E8:01SARH0HTDU06=69P<0I4LW0P1UB2P306I9:@80IdXX0`1VBBL306E8
9PD0I4LU0`1UB2H806Q<9`80K4XW00<0JdXW06U;9`1XC2L00P1VC2L00`1UCBL0JDdX06U=:00206U=
:0<0J4`W00<0Id/V06Y>:@1ZCRT01P1ZCRT406Y<:080JddY0P1/CRX00`1WCb/0IThZ06E=:@0206A<
:00;06E=:@1VCRX0Idl[06Y=;@1YC2`0IdXZ06I9:@1UB2P0ITTY06M::P1XBb/00`1YBbT206Y<:P<0
Jdd[00@0JT`X06]=:@1[CBT0JddY0`1/CRX01`1]Cb/0K4d^06Y=;@1YC2`0IT`[06A<:P1QBRP00P1N
BRL2065::080H4TW0P1OB2H205i79@0305a59P1MARL0GTLX0080GdPY00<0GDHW05]49@1J@b@00P1J
@b@305]49@<0G4DV201GA2@205E49P0405A39@1C@R@0Dd8T05918`80DD0R00D0CchT050o9@1A@2H0
DT4W05=2:00205919`0305509P1@@2L0CclV0080CclV0P1>?RD304dm9080CSTT00<0C3XT04Xj8`19
>R<00P16>R801@15>b80ACXV04Dj9P14>BD0@cPT0080@SLS0P11=R8203lg9080?SHS100m=B800`0k
<b00?3@Q03de8P0203hf8`0303de8P0l=240>c<P0080>S<P00<0>C@P03Le800f=B000P0d=R000`0c
=b00=S@O03Hd7`0603Hd7`80>3DR0P0g=24203Hc8080=C8O0P0a<ah3038d7`<0<cDP0`0e<Ql203Hc
80<0=c@Q0P0_<A`2030b7@@0<C<N00<0<S@O034c7P0`<Qd00P0_<A`00`0`<Qd0<C<N038d7`08038d
7`P0<SDP200b=1l8038d7PP0=S@O0`0b=1h303<e7`80=3HP0P0g=B00100h=R40>CLR03Xh8`0j>2<2
03/i900603/g700l>1d0?3PM03di7P0n>Ql0?c/P0P10?24304Dj7P0404Hk7`17?200B3dQ04Pm8@80
BChR0P1@?b40101A@280DT4S05=2901C@R@205A39@80DdHT00H0EDHU05M79P1HB2L0FdPX05a7:01M
B2T20619:@0406199`1QBbH0HD/V069<9@80HT`S00L0JD`Z06U=:01[CbX0K50Y06iB:P1`EBX0LEHY
0080LULZ0P1cF2/00`1dFB`0MEX]07IK;P0207ML;`0@07aJ;01mFbd0OU`^081N<021Gc40Pf4c08AR
=025HcD0PV<d08AV=026J3H0R6Xf08U[=@29K3@0R6/a08MZ<080S6Lj00<0SFPk08iY?02?JSd00`2@
Jch209=^>P0309A_>`2FLCd0Ug8n00<0Ug8n00H0UG8l09Ic?@2GM3h0VGI009]h@P2LND<209ikA@80
WWY60P2MNDD0102NNTH0X7a80:9nBP2SOd/30:1oBP80XH1;0`2RPD`30:F1C@80YX9>0`2WPdl0202W
Q4h0Z8E?0:Z7D@2[R580[8UC0:^8DP2ZQe40ZHI@0P2ZQUH01P2[QeL0[HUI0:j:FP2_Re/0/8aL0;6=
G@P0/8aL202bT6030;BBI080]I=U0`2fU6H40;NEI`80^9IX0`2iUfT80;RFJ100^IMY0P2jV6X0102i
UfT0^9IX0;RFJ02iUfT20;ZHJP80^iIY0`2jUFP30;VDIa00^II/0P2gU6X20;REJ`80^II/0P2jUfd0
1P2iUVh0^II/0;VFK02hUVT0^9IX0;NEI@80]iIS0`2iUfT20;RFJ0<0]iEW0P2fTfT30;NDJP<0^9E[
202iUV`20;NDJP060;JCJ@2eTVP0]I9X0;FBJ02fTfT0]iAZ202fU6H80;FCH`@0/i5S102dTV@30;JB
HP<0]i=S0P2hU6@80;FCI@80]YAV0`2eTfD0102dTV@0/i5S0;:@HP2bT6880;JAI080]IAQ00<0]99R
0;>AH`2bT6<00P2aSV@00`2`SFD0/8iP0;6?H@020;6?H@80/Y1R0P2cTF<20;B@H0040;FAH@2fTV80
]i=S0;NCH`80^9AT202dTV800`2hU6@0]i=S0;JBHP030;B@H0050;FAH@2fTV80]99T0;>AH`2bT680
0P2`SV000`2bT680/i5S0;BBI0080;BBHP030;6?H@2bT680/Y1R0080/Y1R00H0/HmQ0:n=G`2_SEl0
/hmO0;6=G@2_Re/20:j:FP030;2<G02cSel0]I5Q00P0]8mR202bT6830;:>GP80/HeM0`2`S5`@0;2>
H0030;:=H02`Reh0[hYM0080[XUL00/0[hYM0;2;GP2bSF00[h]K0;2<G02bSUh0/hmO0;B@H02cSel0
/XiN0;6=G@020;F<H0040;>=H02bSF00/XeP0;2>H080[hmP00<0[hYM0;2;GP2bSF00102cSV420;:=
H080/8aL0`2^RUX0102`S5`0/XiN0;>?G`2bT6830;6?H@80/8iP0P2_SEl01P2bS6D0/XeS0;:=H`2b
SF40/XeP0;:>GP80/XiL202bSF020;F@H`040;B?HP2cSV40/hiQ0;:=H080/HaO202aSEd30;6<G`80
/8]N0`2_RUd80;6=G@80/XeP00@0/HaO0;2;GP2_RUd0[hYM0P2^RE`20;>=GP80/XaM0P2aRe`20;2:
F`030:f8F`2^RE`0/8]N00<0/HaO0P2`Reh80;6?H@P0/hmO202bSF00202`RUT0/H]J0;6;G02bS5l0
/haQ0;B=I02eSVD0]HiW0P2cSV430;:=H0<0/HaO202_RUd80;6;G0030;6=F@2`S5P0[h]G00<0[HUE
00<0[h]G0;2<F02aSET0202_Re/80;6=G@060:n<EP2_ReL0[h]G0;2<FP2`S5`0/HaO0P2aS600102_
ReL0[XYF0:j:EP2^RUH20:f9E@80[8QD0`2[QeL20:b8F0/0[HUI2P2/R5P30:^7E`/0ZXIF0P2]RET0
1P2/R5P0ZhMG0:^7E`2/R5P0[HUI0:j:FPP0ZXIB0`2/R5P20:^7E`<0ZXIF0`2[QeL30:Z6EP80ZHEE
00@0YH5A0:J2DP2XQ5@0ZXIF0P2[QeL0102ZQUH0ZHEE0:^6F@2[QUT20:Z5F0<0ZHAG00@0Z8=F0:^7
E`2[QeL0ZXIF0P2YQED02`2XQ5@0Yh=C0:N3D`2XPdl0ZHA@0:Z5D@2[QU80ZXEA0:V4D02WPTh0YX5=
00P0YGm@2@2TOd/20:1oBP090:9nBP2TOd/0YWi;0:MmB`2XOT`0ZGe<0:F1D@2TP500Xgm?0080XWi>
00H0Xgm?0:B0D02UPE40Yh=C0:F1D@2SOdl20:5mC@030:=oC`2UPE40Yh=C0080Y81<0`2UPDd30:J2
CP<0Yh=?0P2VPTh30:F1C@@0Y81<0P2SOd/20:9nBP@0YH1;0`2VPD`00`2WPTd0YX9>0:J2CP030:F1
C@<0Y81<202QO4L20:1jB`030:9lC@2SODh0Xge>0080Xge>00L0XWa=09]oC@2MOdd0W7i<09alB`2L
NTX0WGU90080WGM800P0WWQ;09miC02PNTd0XG]>0:1jC@2OND`0WGM:09]eB0<0Wg];0P2NNTX309ei
B@80WWe800H0Wg]709mjAP2RNTL0Y7Y80:EkB@2WNdX309mkA`80WWY60`2MNDD02@2MNd/0WWa<09il
C02OODd0WWa<09ekB`2LNTX0VgU909]gA`0209ahB0D0WGU900<0WGU509ahA02KMd<00P2JMT800`2K
Md<0W7Q409eiA@0209afA`0409]eAP2JM4D0VgE609egB080WgU:00X0X7Y;0:5kCP2NN4/0VgE809af
B@2OND`0X7Y=09egBP2JM4L0V7Do0P2HM4000`2IMD<0VGE509YeB00209YeB@P0VWI60P2KMd<0102J
MT80VGE109Ue@@2HM40209Mc?`0509Ue@@2HM400V7A009Mc?`2FLSh00P2ELCd00`2DL3`0V79309Qb
@`0209Ma@P80UW110P2EKd0309Ma@P80UW110`2EKd02099]@003095/?`2@Jch0SfXm0080SVTl202=
J3/0102<IcX0RFHl08UV?029IS`[ooooo`00:_ooool309ea@080WW910`2OLd8209md@@<0X7E20`2Q
MT<209mc@P80X7A30`2QMD@01`2RMTD0XgQ50:9gA02RMd@0XGI30:1e@P2OM4400P2NLd020:5eAP04
0:9fA`2SMdP0Y7Q90:EiBP80YWY;00/0YGY70:AiAP2RMd@0X7E209md@@2PMD80XGI30:9gA02SMdH0
XWI50:5eA0020:1d@`030:5eA02RMTD0XgM60080XWY900H0XgU70:AiAP2VN4H0YgQ40:Mh@P2YMd82
0:EjA@80YW]60P2WO4L20:QmB080Y7U60P2UNTL40:IkB0030:MlB@2TNdL0Y7]70080YGa80P2VODT2
0:MnBP80ZGe<00<0ZGi;0:UnB@2YOTL00P2YOdD02`2YOd<0Y7U40:EjA@2WO4L0Z7e80:UnB@2XODP0
Yga70:IkAP2WOTX0Z7m;0080ZH1<00@0Z7m;0:ImB@2TNdL0XgY60`2XOd/00`2WOTX0YWe90:ImB@02
0:ElB0P0Z7m;1P2ZPDd20:V0C0<0ZX5=0`2YP4`20:QoB`P0ZGm=00@0ZX5=0:^2CP2[PTh0Zh9>0P2/
Pdl20:f4D0P0ZX5=00H0[HA@0:b3C`2[PTh0ZX5=0:V0C02XOd/20:MnBPP0[HA@0`2[PTh20:b3C`<0
[HA@00<0[8MB0:^6D@2[QU400P2ZQE020:V4C`030:R3CP2^RED0[XUE00H0[XUE102]R5<40:b7DPH0
ZhIA0P2/Qe801@2_RUD0[XUD0:j9E02]R5<0[8MB0080ZhIA0P2ZQE080:^6D@P0ZXE@00P0ZXEA0:V4
D02XPdl0Yh9>0:F0C02TOd/0Xgi:0:9mB@80Xgi70P2TOdP0102SOTL0XGa509mj@`2NND8209iiA080
WGQ30`2LMd80102KMT40VWE109Ye@@2JMD4209Ud@0<0V7<o00H0VG=409Qb@`2GLD80UW1109E_@02C
KCh2099/?@0409AY?P2CJ3d0TfPm09=X?@80TVLl0P2AIS/00`2?JC`0SFLj08aV>@0208]U>00608aV
>@2=IcX0SfTl08YU>`29I3X0Qf8h0`25H3H208MR>00608ER>P24HCT0Pf0h08=P>022GcL0PEhf0P20
GCD2085N>008081M=`1oG3H0OU/e07eJ=01lFC<0NePb07EF:01fEbT307QI:`0307IG:@1dEBL0Le@V
0080Ke4_0P1^D2h206e?;@80K4h/0P1/CRX206]=:@<0JT`X00@0JD/W06Q;:@1XBbT0ITTW101UB2H0
1`1VBBL0KD`[06a;:P1[BRT0JTTX06U89`1XAbH00P1WARD0201TAbL0IDPX06I9:@1VBBT0IDPX06=6
9P1QA2@0Gd8R101UB2P206I9:@<0IdXZ0P1TAbD306E89P<0ITTW00H0HTDS06=6901SAR@0I4LU06E8
9P1VBBL206M::0P0J4`W0P1/BRL00`1[BRL0JD/W06Q<9`0206I<9`0406E=9`1UBB@0IDTT06E990<0
ITXU0P1WBbH806Y>:@0306Q:9P1YBbL0JD/W0080JT`X0P1[CBT0101/CRX0Idl[06E=:@1TC2P206=;
9`0;06A<:01UCBT0Idl[06M:;01VBB/0IDPZ06A7:@1UB2X0ITT[06Q;;@1ZCBl0101[BRT206a;:P80
KD`[00<0J4XV06U;9`1YBbL00P1ZC2P206]=:@0906a>:P1]CRl0K4l_06Y=;@1WCB`0I4`Z069;:@1O
BbP0GTXW0080Hd`Z00@0HT/Y06199`1OB2H0GDHT0P1LAB<00`1LABH0GDHW05i7:00205m8:@0305e6
9`1KA2D0FT<T0080G4DV0`1KA2D305Y390P0F4DU0P1EA2H0101D@bD0Dd8T05=2901B@B<205508P08
04ln901>?B<0CchT04ln901A@2H0Dd8X05I5:`1GAR`305109`80CclV101>?RD01P1?>B@0CSTT04hi
901<>R@0BSXS04Tj8`80ASXR0P17>RL01016>BH0ACPU04@g9013=R<2048e8P03040h9@0o=b@0?cLT
0080?SHS0P0m=B80100l=240>c<P03`d8@0n=R<203lg900803hf8`0l=240>c<P03df8`0l=B80>cHR
03Pf8@0f=B0203<e7`03034e7P0e<ah0=C<N00H0=C<N0P0h=B8203Ld8@80=S<P0P0e<Ql3034c7P03
038d7`0c=B00<cDP0080=3HQ0P0e<Ql203Hc80@0=c@Q00<0;BlJ02la700b=1l00P0e=b801P0d=R40
<S@O030b7@0b=1l0<C<N02la7080;S0K00<0;c4L034c7P0b=1l0200b=1l8030e7`P0<34O200`<Q`8
03Dc7P<0<cDO00<0=3HP03Dg8@0e=b400P0f>28203Le800603Pf8@0i=b80>SPS03/i900l>RD0?C/V
0P0l>1d00`0m>Ah0?SXO03lk8002040l8@06044m8P18>Qd0B3XM04Pj7@19>ah0BS`O0P1;?B00201<
?R40CClR058o7`1B?al0Dd0P05A18@1E@R80ET<S0P1GA2@02@1EB2D0ETPU05M99P1IBBL0G4TX05i:
:@1PBBT0HDXZ069;:`0206=<:P0306==:01SCBH0I4hU0080I4lT00P0K50[06eA;01]DBX0KU8Z06mD
:@1`EBP0LEHY079G:080M5TZ00<0MEX[07IK;01gG2d00P1hGBh04@1iGRl0Oed_081N<020GS00PEla
089P<P23HC<0Q68d08ES=@23IC<0QFLe08MY=@29JcD0RVde08Y]<`29K380R6/_00H0T6Xm0P2AJch0
1P2FKS/0Ufll09M_?02HL3d0VG4n09Yb?`80Vg=000P0U74i09Eb>P2FLc/0V7Dm09Yg?`2LND40WGY2
09ik@`80Wg]700L0WWY609eiA@2NNTH0X7a80:=oB`2TP4`0X7m:00<0XH1;0P2RPD`20:>2C@<0YH5=
00<0YX9>0:N3C`2WPdl00P2XQ5000`2WQ4h0Z8E?0:Z7D@020:b9D`030:^8DP2ZQe40ZHI@0080ZXIF
00H0ZhMG0:f9F@2_Re/0/8aL0;6=G@2bSUh80;2<G0P0/Y1P00@0]99T0;FCI@2eTfD0]I=U0P2fU6H2
0;NEI`030;ZHJP2iUfT0^IMY0080^IMY0P2hUVP:0;NEI`P0^YQZ202iUfT00`2kVF/0^YQZ0;RFJ002
0;NEI`030;RFJ02jV6X0^iU[0080_IQ[0P2lUfX0102kUVT0^YEX0;ZEJ02jUFP@0;VFK080]iAZ0P2h
UF/20;VFK080^YM]00H0^II^0;VFK02iUV`0^IMZ0;RFJ02hUVH20;NFH`@0^IMY0P2hUVP20;NEI`80
]Y=Y0`2gU6X30;REJ`P0^II/00<0]iAZ0;JCJ@2eTVP00P2dTFL00`2eTVP0]iAZ0;REJ`080;JDIP80
]9=P1P2eU6440;BBI0@0/i5S0`2fTV830;NCH`80^9AT202eTfD20;NEI`80]YAV00<0]I=U0;BBI02c
TF<00P2bT6880;JAI080]IAQ00H0]99R0;>AH`2bT6<0/HiT0;2=H`2`SFD20;2>H0<0/HmQ0`2bT682
0;B@H0040;FAH@2fTV80]i=S0;RDI080^IEU202eTf<02`2iUFD0]i=S0;FAH@2dT600/hmO0;B@H02e
TF40]Y9R0;BBI02cTF<0/Y1R0080/8iP00<0/Y1R0;>AH`2dTV@0202dTV820;>AH`030;6?H@2`SV00
/8iP0080/8iP00<0/HmQ0;2<G02`S5`00`2`S5`00`2aSEd0/XiN0;>?G`080;B?HPP0/Y1R0P2bSUh2
0;6=G@@0/8aL402`SV000`2cSV40/XeP0;6<G`020:n:G@0;0;6<G`2bSF00/hiQ0:n;F`2`S5`0/XiN
0;>?G`2dT600/hmO0;:>GP2aSEd00P2eS600102cSF00/XeP0;:=H02`SV020:n?H0030:n:G@2`Reh0
/XeP0080/hiQ00`0]8mR0;>>H@2bSF00/HaO0;2<G02_Re/0[XYJ0:f9F@2^RUX0[h]K0;6=G@2bSUh2
0;:@HP<0/HmQ0`2`SV001P2aRf@0/HaR0;:=H`2bSF40/XeP0;:>GP80/XiL1P2bSF020;6<G`P0/hiQ
202aSEd0102aS5l0/8]N0;2;GP2`Reh20:n:G@80[XUL202aSEd20;:=H0040;6<G`2`Reh0[hYM0:j9
G080[HQK0P2cSEh20;:<G@80/H]L0P2`RU/0202/QeX0[XUL0;2;GP2aS5l0/XeP0;6<G`2`Reh0[hYM
202aSf480;6=G@H0/XeP0P2aS5l20;2:F@060;6;G02bS5l0/haQ0;B=I02eSVD0]XmX0P2cSV430;:=
H0<0/HaO202_RUd80;2:F`030;6=F@2`S5P0[h]G00<0[HUE00<0[h]G0;2<F02aSET0202_Re/80;6=
G@080:j;E@2^RUH0[h]G0:n;F@2`S5`0/8]N0;2;G`2aS6030:j:EP80[HUE0`2/R5@30:Z6EP80ZhMG
1@2/R5P>0:f9F@80[8QH0P2[QeL20:Z6EP80ZHEE1P2ZQUH20:^7E`080:b8F02[QeL0ZXIF0:Z6EP2[
QeL0[HUI0:n;F`2aSEd20:^7D`H0ZXIB102/R5P20:^7E`80ZXIF0P2/R5P20:^7E`070:Z6EP2YQED0
ZHEE0:V5E@2VPU80Yh=C0:V5E@020:Z6EP030:V5E@2XQ5@0Yh=C00<0ZhII0P2ZQEP30:V4E`050:b8
F02[QeL0ZhMG0:Z6EP2XQ5@00P2WPe<02@2VPU80Z8=?0:V4D02ZQE40ZhIB0:Z5D@2YQ500Yh9>0:J1
C@020:N1DP040:J0D@2UOe00YGm@0:AnC`80Xge>0P2SOTX70:AoB`80XX5<00<0Xgm;0:AoB`2VOT/0
0P2VO4X00`2WNdX0Xgm?0:=oC`030:9nCP060:B0D02VPU80Z8AD0:N3D`2UPE40XWi>0P2PO4`00`2S
Odl0YX9B0:R4E0020:B0C0<0YH5=0`2VPTh40:N3C`80YX9>0`2UPDd20:B0C080Xgm;0P2ROTX0102Q
ODT0YX5<0:J1C02VPD`30:F0B`80Y7m:0`2TP4`30:=oB`80XWi:202SO4D0202QNd`0X7Y;09miBP2O
NDX0X7Y;0:5kC02RO4d0Xge>0P2IOD/0102JO4X0VG]909YjB@2JN4P209]gA`080:1jC@2QNdh0XG]>
0:5kCP2PNTd0WWQ;09]eB02JM4L20:1lC080Wg];0`2NNTX02@2MNDT0X7m:09mnB@2ONdL0WWU50:1h
A@2RN4H0XgU70:EiB00209mkA`80WWY60`2MNDD0102LN4@0VWQ809]iB@2MNd/209mmC@0>09ilC02M
Nd/0W7Y:09]gA`2MNDT0Wg];0:5mC@2PO4`0WWY:09]gA`2IMDD0WWY609eiA@2KMd<209Yf@P0609]g
@`2MNDD0WWY609egB02LMTL0VgE60P2JM4D04P2LMTL0WGM809egB02ONDX0X7Y=09egBP2JM4L0W7I9
0:1jC@2RO4l0WgU<09afB@2JMd40VWI209]g@`2KMdD0W7Q809agBP80WGQ<202LN4P309]g@`D0VWI2
00H0VgM309Yf@P2IMD40V7A009Mc?`2FLSh209Ea?@@0VG=4102HLT<0102HLT40Ug5009Ma@02GLD02
09I`?`80UFln00P0Tfi109A_@P2FLD@0Ug9509IaA02CKT40SfXm08eX>`<0SVTl1@2?JSd308eZ@2_o
oooo000Zooooo`<0WG500`2NLT4209mc@P80WW=000<0WgA10:1e@P2QMT<00P2RMd@00`2SN4D0Wg=2
09mc@P020:1d@`@0XGE400H0XgQ50:9gA02RMd@0XGI30:1e@P2OM44209ic@080XWI700@0XgM80:Ah
B@2UNDX0YWY;0P2WNd`01P2UNTL0Y7U60:9gA02PMD80WgA10:1e@P80XGI300<0Y7Q70:9fA@2QMD@0
0P2OLd800`2QMD@0XWI50:AhA`020:=kBP060:AjB02UNTL0YgU70:QiA@2XND<0ZWQ30P2UNTD20:Ik
AP80Yga70P2XODP20:AiAP80YGY71@2VNdP20:AkA`80YGa80P2VODT20:MnBP80ZGe<00<0ZGi;0:Un
B@2YOTL00P2YOdD02P2YOd<0Y7U40:EjA@2WO4L0Z7e80:UnB@2XODP0Yga70:IkAP2XOd/30:V0C005
0:QoB`2VODT0XgY60:9iA@2YP4`00P2XOd/00`2WOTX0YWe90:ImB@020:ElB0P0Z7m;1@2YP4`30:Qo
B`<0ZX5=0`2YP4`20:QoB`P0Z7i<102[PTh20:b3C`80[HA@202YP4`20:b3C`060:^2CP2ZPDd0ZH1<
0:QoB`2WOTX0YWe9202]Q5030:^2CP<0[8=?0P2]Q5020:b7DP040:^6D@2ZQE00ZXE@0:V4C`80Z8=>
202^RED40:f8D`@0[8MB1@2[QU430:b7DP80[hYE00<0[XUD0:f8D`2/Qe800P2[QU420:Z5D0D0ZhIA
0`2/Qe880:Z5D0060:Z5D@2YQ500Z8=?0:N2CP2UP4`0Y7m;0P2SOTX0202SOTL0Y7m80:F0B@2UP4T0
Y7m80:9mAP2PNd@0WWU20`2ONTD209iiA0<0WGQ30`2KMT8309Ye@@80VGA000P0VgE609YdA@2ILd@0
Ug5209E_@02CKCh0TV`m095[?080UFPn0P2DIcd309=V?004099U>`2?JC`0SVPk08aV>@80RfDh00/0
S6Hi08iX>`2?JC`0RVDk08UT>P27HSP0QV4g08EP=P26HCL0Qf8h08QS>@0208ER>P0308AQ>@23H3P0
PUlg0080PEhf00D0P5de085N>021GSP0P5dg07mL=P0207iK=@80OEXd00<0MULX07MH:@1hFBX00P1i
FR/00`1gF2T0MEHW07=D9@08075C<@80K4hZ0P1[CBT406Y<:00306Y=:`1XBbT0IDPV0080HdHT00<0
I4LU06I99`1XBbT00P1]C2/00`1/BbX0JdXY06Y9:00206Q79P0:06M69@1VBBT0ITTY06M::P1VBBT0
I4LW06959@1O@R80GT4Q06E8:0<0ITTY0P1WBRX306Q;:`80HdHT0P1TAbD0301UB2H0ITTW06M::01W
BRP0HD@R06958`1SAR@0IDPV06I99`1XBbT0JD`Z06Y=:`P0Id/V0P1[BBH00`1ZBBH0J4XV06M;9P02
06E;9P0606A<9P1RAR40HTHQ06=78P1TB2<0IDTT0P1VBRD00`1WBbH0JThY06Y>:@0606Y>:@<0J4XV
00<0JD/W06Y<:01[CBT00P1[CBT00`1WCb/0IDdY06=;9`02069:9P0406=;9`1UCBT0Idl[06E8:P<0
I4LY00D0IDPZ06M:;01YC2h0Jdh`06Y9:00306]::@80K4/Z0P1]C2/206M99@0406Q:9P1YBbL0JD/W
06Y<:080JddY01<0KTl`06a?;`1[CRh0Idd/06E=:`1RBbT0Gd/X05i:9`1UCR`0I4d[06=<:P1QBRP0
GTLU05a58`1KA280FT<Q05a59P1MARL0GTLX0080GdPY00@0GDHW05]49@1J@b@0GDHW0P1LABH01@1K
A2D0FT<T05U28`1I@R<0F44R00P0FDHV0P1EA2H0101D@bD0Dd8T05=2901B@B<205508P0904ln901>
?B<0CC`R04hm8`1@?bD0E4<Y05Q7;@1KBS00DD4X00<0D40W0P1??bH304hn9@08050j9@1?>B@0CSTT
04`j901:>R<0BCXS04Pi8P16>R8204Pk:00404Lj9`16>BH0A3LT04<f8`80@SDR0P10>2D203lg9007
03hf8`0m=B80?CDR03`d8@0k<b00?3@Q03hf8`0203lg900303hf8`0l=240>c<P0080?SLT00H0?3LS
03Pf8@0f=B00<cDO038d7P0`=1d803Dc7P80>3DR0P0g=24203Hc8080=C8O00@0<38M034c7P0a<ah0
<S@O0P0c=B0203@f8@80=C8O0P0f<b0303Ld8@0403Pe8P0/;QT0;c4L03@f8@80>3XU00H0=SPS038d
7`0_<A`0<C@O030c7P0^<A`202d`6`0302ha700`<ah0<C@O00P0<S@O200^<ad802l`7PP0;c4K200e
<ah0100c=Al0=3HP03@f800e=b4203Hh8P80=cTS00H0=cDP03Pf8@0h=R40>SPS03/i900l>RD203dk
9P0603`h7@0m>Ah0?CTN03hj7`0o>b00@3`Q0P11?B8204Pk6`80BC`L00<0BSdM04/n7P1<?al00P1=
@2001P1A?Qh0DSlO05=0801D@B40ED8R05I38`80Ed@T0P1GBBH01P1IBBL0G4TX05i::@1OBbX0HDXZ
069;:`80IDd[00@0IDdY06E=9`1UCRD0ITlV0P1VCbD01P1_DBd0L58/071B;01aE2`0LE@Z079E:@80
LUHW0P1eFbX00`1fG2/0Med/07QN;@0207UO;P0307YP;`23GS40Peha0080Q5lb0P25H3<208IQ=006
08AV=025Ic<0R6Xf08U[=@2:KCD0RVdc0P29K302099/?`<0TF/n0`2@JSd209M_?080V70m01@0VG4n
09Yb?`2KLd00W7A109=`>02DLCT0UG8j09Md?02IMSh0VgQ009ai@@2MNT80X7a809mkA`2NNTH0WGU5
09ijAP2QODT0Xgm;0:F1C@<0XH1;0P2RPD`30:>2C@<0YH5=00<0YX9>0:N3C`2XQ5000P2XQ5000`2W
Q4h0Z8E?0:Z7D@030:b9D`080:^8DP2ZQe40ZXIF0:Z6EP2/R5P0[HUI0:n;F`2`S5`20;:>GPP0/8aL
202bT6030;FCI@80]YAV0`2gUFL30;^IJ`060;ZHJP2iUfT0^9IX0;NEI`2fU6H0]I=U202gUFL80;ZH
JPP0^IMY00<0^iU[0;VGJ@2hUVP00P2fU6H00`2hUVP0^IMY0;^IJ`020;jIK080_IQ[00@0_9MZ0;^F
J@2kUVT0^YEX402iUV`20;NDJP80^9E[0P2iUV`20;ZGK@060;ZGK`2iUV`0^II/0;VGJP2hUVP0^9IV
0P2gUV<0102jV6X0^IMY0;VGJ@2iUfT20;RFJ080]iEW0P2fTfT30;NDJP<0^9E[202iUV`00`2hUF/0
]Y=Y0;FBJ0020;BAI`030;FBJ02hUF/0^II/00P0]YAV0`2dTf050;FDH@050;JDIP2eTfD0]I=U0;BB
I02cTF<00P2bT680102aSf40]Y9R0;JBHP2fTV830;NCH`80^9AT202eTfD01`2hUVP0]iEW0;JDIP2f
U6H0]I=U0;BBI02cTF<00P2bT6880;JAI0080;FDH@2dTf00]99R0;>AH`2bT6<0/HiT0;2=H`2`SFD3
0;2>H080/HmQ0`2bT6820;B@H0060;FAH@2fTV80]i=S0;RDI02iUFD0^YIV202eTf<00`2iUFD0]i=S
0;FAH@020;>?G`060;B@H02eTF40]i=S0;BBI02cTF<0/Y1R0P2`SV000`2bT680/i5S0;BBI0080;BB
HP030;FCI@2cTF<0/8iP0080[XaN00L0[heO0;6?H@2cTF<0[XYJ0:n;F`2`S5`0/HeM0080/XiN0P2a
SEd80;B?HPP0/Y1R0P2bSUh20;6=G@<0/8aL00<0[h]K0;2>H02`SV003P2`SV000`2dSf80/hiQ0;:=
H0020;2;GP0;0;:=H02cSV40]8mR0:n;F`2`S5`0/XiN0;>?G`2dT600/hmO0;:>GP2aSEd00P2eS600
102cSF00/XeP0;:=H02`SV020:n?H0030:j9G02`Reh0/XeP00<0]8mR00/0/hiQ0;:=H02aS5l0/8aL
0:n;F`2^RUX0[HUI0:j:FP2_Re/0/HeM0;:>GP030;:@HP80/HmQ0`2`SV001P2aRf@0/HaR0;6<HP2b
SF40/XeP0;:>GP80/XiL1@2bSF030;6<G`<0/XeP0P2cSV430;B?HPP0/HeM102`Reh20:n:G@80[XUL
202aSEd20;:=H0060;6<G`2`Reh0[hYM0:j9G02]R5/0[8MJ0P2cSEh20;:<G@80/H]L0P2`RU/0202/
QeX0[HQK0;2;GP2aS5l0/XeP0;6<G`2_RUd0[XUL0P2bT6840;6?H@80/8iP202`S5`50;:=H0<0/HaO
0P2`RUT00`2aRe`0/XaO0;><H@020;F>I@030;J?J02cSV40/hiQ00<0/XeP0`2aS5l80:n:G@P0/8YK
00<0/HiH0;2=E`2_S5H00`2]RU@00`2_S5H0/8eG0;6>F0080:n;F`P0/HeM00H0[X]E0:j:EP2_ReL0
[h]I0;2<G02`Reh20;2;G`80[XYF0`2]RED30:b8E080ZHEE0P2ZQUH30:^7E`@0[8QH3@2]RET20:b8
F080ZhMG00@0ZXIF0:V5E@2YQED0Z8AD1@2ZQUH40:^7E`070:Z6EP2YQED0ZXIF0:^7E`2^RUX0/HeM
0;>?G`030:^7D`D0ZXIB00@0[HUI0:b8F02/R5P0[8QH0P2[QeL20:Z6EP80[8QH0P2[QeL0302ZQUH0
ZHEE0:V5E@2XQ5@0Yh=C0:R4E02YQED0ZXIF0:V5E@2XQ5@0YX9B0:F1D@<0ZhII0`2ZQEP20:V4E`80
[8QH00@0ZhMG0:Z6EP2XQ5@0Yh=C0P2VPU80202XPdl0ZHA@0:Z5D@2[QU80ZXEA0:V4D02WPTh0YX5=
0P2XPU<0102WPE80YX1A0:AnC`2SODh20:9lC@<0Xgi:1P2TOd/20:>2C0030:B1B`2TOdX0YGe90080
YGa800<0YGY70:9nCP2ROTh00P2QODd01`2SOdl0YH5A0:R4E02YQED0Yh=C0:F1D@2ROTh00P2PO4`0
0`2SOdl0YX9B0:V5E@020:B1B`<0YH9<0`2VPdd0102XQ500Yh=?0:N3C`2WPdl20:J2CP<0YH5=0P2T
P4`00`2SOd/0XWi:0:9nBP020:5mB@80Yh9=00@0YX5<0:F0B`2UP4/0Y7m:0P2SOTT30:=oB`<0XWi:
0P2QODT80:=lA@0>0:5kC02PNT/0WWQ909afA`2MMdP0WgU:0:9lC@2TOTl0Uge:09QlBP2GNdT0V7Y8
09QhA`2IMdL209YfAP<0XWa?00D0XG]>0:1jC@2MMdX0VWA709QbA@030:1lC080Wg];0`2NNTX0202Q
P4/0Wgi909mkA`2NNDD0WgM40:1fA02QMdD0XgM60`2NNTH209eiA@<0W7Q400@0V7I609YhB02LNTX0
WWa<0P2OODd03@2MNd/0W7Y:09]gA`2NNTX0XGe=0:=oC`2ROTh0WWY:09YfAP2GLd<0WWY609eiA@2L
N4@00P2KMd<01P2LN4@0WGU509ijAP2NN4T0WGM809]eAP80VWA501@0VgE609afA`2LMTL0WGM809ih
B`2KMDP0VWA709afB@2PNTd0XWa?0:5kCP2NN4/0WGY409eiA@2NNTH0WWY809mkB`2ONTd0WgY>0:1k
C`P0W7Q80P2JMd4309]h@P<0W7U300P0W7Q409]g@`2JMT80VGE109Qd@02GLcl0UW8n09Ea?@@0VWA5
102ILd@209Qb@@80Ug500P2FL3l209E_?P0809=^@@2FLD@0VGA709]fB@2JMDP0UW54095/?`2=J3/3
08mZ?@D0T6/n0`2@KD<[ooooo`00:_ooool209ab@080WG=10`2NM4800`2OMD<0WW9109mc@P0209mc
@P80X7A30P2QMD@809id@PP0X7A30`2SN4D00`2RMd@0XGI30:1e@P020:1e@P80XWU50P2QN4@20:1g
@`80WgI2202PMD820:=hA@030:=h@`2SN440XgTo0080XWPl00@0XWTk0:9i@@2SNT80YGa60P2VODT0
1P2UNdT0XgU90:9hB02SNTH0Y7]70:ImB@<0Ygi:00<0YWe90:AkA`2SNTH0202XODP0202YP4`0Z7m;
0:MnBP2VODT0YGa80:AkA`2SNTH0XWU50P2WNd`0102WNdX0Yga90:MlB@2WO4L20:MlA@030:YoC02Y
OT/0Yga90080YGY700<0Yga90:UnB`2ZOd`00P2WO4D0102XODH0ZGi70:UnA`2ZOdP20:^0B@P0ZGi;
0100ZH1:0:QoB@2WOTP0Ygi80:QoB@2ZPD/0[8==0:f4CP2WOTP0ZH1:0:^2C02/Pdd0[HA>0:b3C@2[
PT`0ZH1:0P2XOd/20:V0C0@0ZX5=202]Pe480:b3B`80ZX5=0P2[PTh00`2/Pdl0[HA@0:f4D0030:j5
D@@0[HA@0P2/Pdl30:V0B080ZX590`2[PTX80:j5D@090:V5B`2ZQT`0ZhI?0:b7DP2]R5<0[XUE0:n9
F02`RUT0/8]F0080[hYE00<0[XUD0:f8D`2]R5<00P2/Qe801P2^PeP0[X=F0:n4E`2_QED0/8ID0;27
D`80/HQB2@2]R5@0202YQ500ZXEA0:b7D`2]R5@0[8MC0:Z5D@2XPdl0Yh9>0P2YQ5040:Z5D@80ZhIB
0P2XPdl0102WPTh0YX5=0:AoB`2SOTX20:9mB@80Y7m;0P2SOTX30:9mB@030:5lB02NNDD0WGQ40080
WGQ40P2LMd<209]f@P0309]f@@2JMD00VG@o0080V7<n00<0VG@o09]f@@2LMd800P2HLcl209Mb?P04
09Ia?@2EL3`0U6lk09A_>`<0TV`m0P2AJc`3091Z>`<0SFLj0P2<IST308]U>0<0RfLg0P2:ISH308UU
=@H0QV0a0P25Gc02081M=`0307mL=P1nFcD0OEXd0080O5Tc00X0NePb07iK<`1nFc<0O5Ta07YG;`1h
EBd0MU<[07AA:@1cD2P0M54W1@1eDRP207IC:@80LE0_00<0L4l^06m>;@1^CB`00P1/BbX00`1[BRT0
KD`]06e<;@0606e<;@P0I4`Z00H0ITPV06E79@1UAbD0I4HT06=58`1RA28206538@0605hn9@1P@2L0
HT8Y06A4:`1UAB`0I4@[0P1S@bX00`1R@RT0HD@T065490060654900606=4:01RA2P0HdDY0697:P1Q
B2X0HDX[0P1PBb`0201LA280GdLU06=;:@1UCB/0ITh/06A<:P1QBBL0GdLU201TC2X00`1TB2<0ITXU
06Q<9`0206Y>:@0306Q<9`1VBRD0I4PS00@0Jdh^00H0JTd]06U<;01XBb/0IdXZ06E8:01TAbL206=6
9P0406A79`1VBBT0J4/[06U<;0P0HTT[0P1TC2X206E=:`<0ITh/00@0Idl]06A<:01SBbL0HTXV1@1P
B2@0201XD2X0IdlY06I>:01UCBL0IThX06M?:@1YDB/0JU8/0P1XD2h206M?;@<0ITh/00L0IDd[06=;
:@1SBbT0HTXX06599`1PB2H0GdLU0080GTHT00<0Ed@T05Q59@1JAbL00P1LBBT00`1KB2P0FTLW05U6
9P0205a19P0305]19P1J@RH0F4<V0080Ed@V00/0ED@V05Y7:@1F@bD0DSlQ05=08P1HABL0FTLY05M4
9P1C@280DT4S05508P03050o8@0305918`1D@bD0ED@V00P0DD0V00L0C4<V04e29P1<@BD0CClT04dm
8`1=?280Cc/R0080CSXQ00P0D3lQ04ln8P1=?200C3/Q04/i8@1<>R@0CC/W04hl:080B3`T0P17>b<0
1016>R80ACTQ04Di8@14>20204@j8@<0@cTP0`12>1l01P0k<ah0?3@O03de800n=R40?cLR040h8`80
@CTT00H0?CPT03`g8`0l=b<0>SDQ03Td800h<al203Lb7PD0<CDN0`0b=Ql403@f8@@0<cDP0P0c<1d0
0`0d<Ah0=C8O03Hc800203Ld8@0703Pe8P0d=b80=CLR03Dg8P0f=B40=S<P03Lb7`0203Pa7`<0<c0M
0P0d<Ah303Db7`80<C<N0`0`<Qd302la70<0;c0P0`0`<B42034b8P80<S@O100a<ah2030b7@0302lb
7@0^<A`0;C0K0080;2lJ00@0;C0K02ha700_<Qd09cDL0P0X=1`00`0[=Ad0;3@M02hc7@02030c7P<0
=C<N0P0f=1l303Le8009030_6`0a<1`0<c8N03Dd800g=R80>CPT03Xi9@0k>RH0>cLN0080?3PO00<0
?CTP03hj8@0o>b800P10?2<02011@2@0@ShS040l8@11>b40@S/Q04Dk8P18?2@0BCdU0P1=?R400`1>
?b80DD8U05=49`0205A5:00605=49`1B@bH0DT@Q05=58P1EAb@0EdTV0P1HBRL205M99P0805=5801I
BBD0GThZ069@;01QCBX0HT/Y06I>;01YDBl206M@9`0306QA:01YDRT0JU<Z0080Je@[00D0K5D/06aA
9P1]DRL0L5DZ07=H;@0207AI;P0407=H;@1bEb`0MeTW07IH9P80MELU00@0MUPV07QJ:01jG2X0O5h/
0P24HS@208ES=@0508IT=P27ICL0R6Hh08QV>02<J3@00`2=JCD208iZ=P<0Sf/g00L0T6`h095]>@2B
KSX0Tflk09A`?02ELCd0UW8n0080Tflk00L0U70l09Ib?P2GLcl0V7A009Ue@@2JMT80VWM10080VgQ2
00<0W7U309ejA02NNdD00P2OO4H0202NNd40Wga20:1mA@2QOTP0XWm90:=oB`2TP4h0YH5?0`2VPTh5
0:F1C@80YX9>00@0Yh=?0:R4D02ZQU80ZhMC0P2/R5@0102ZQUH0ZhMG0:^7E`2[QeL20:b8F080[HUI
00P0[HUE0:b8E02[Qe<0ZhMC0:b8E02^RUH0/8aH0;:>FP<0[hiK0P2`Se`30;6@G@080;:=H02cSV40
]8mR0;F@H`2fTF@0]i9U0;RCIP2iU6L30;FCI@80]YAV302gUFL0202dTV@0]I=U0;JDIP2hUVP0^IMY
0;^IJ`2lVV`0_I]]0P2kVF/30;ZHJP<0^IMY202jV6X0102iUfT0^9IX0;RFJ02gUFL20;JDIP80]I=U
202jV6X80;VGJ@P0^YQZ202jUFP80;VDI`D0]iEW0`2hUVP30;ZEJ080^iIY0`2lUfX80;NEI`030;VG
J@2hUVP0]iEW0080]I=U00/0]iEW0;RFJ02iUfT0^YQZ0;VGJ@2gUFL0]YAV0;FCI@2fU6H0]iEW0;RF
J0020;JDI0<0]I=S0`2dTV820;:@HP80/i5S0P2dTV@20;FCI@040;:@HP2cTF<0/i5S0;>AH`80]99T
0P2eTfD01P2gTFX0]i9X0;NBJ02gTVH0]i9U0;NCH`80]i=Q0P2fU6H40;FCI@<0]99T202eTfD80;BB
HP030;2>H02aSf40/i5S0080]99T00<0/i5S0;:@HP2aSf400P2cSV420;B?HP@0]I1S202dTV@00`2j
UVH0^IEU0;NCH`030;FAH@030;JBHP2gTf<0]I1S0080]I1S0`2dSf820;>>H@P0/hmO01<0]i9U0;JA
I02eT6<0]8mR0;>>H@2bSF00/HaO0;2;GP2aRfL0/XaW0;B>I`2eT6@0]I5Q0;B@GP2bSeT0/HiH0;B?
HP2cSV40/HaO0080/8]N00/0/HaO0;>>H@2dSf80]i=S0;JBHP2eTF40]91P0;>?G`2bSUh0/HeM0;2<
G0080;:>GP030:n;F`2`S5`0/XiN0080]91P00H0/hmO0;6=G@2`S5`0/XeP0;6<G`2`Reh20:n:G@03
0;2;GP2aS5l0/XeP00P0/HeM00H0/XmI0;:>FP2bSUX0/XiL0;:>GP2bSF020;:=H@P0[heO0P2_RUd3
0;2;GP80/HaO0P2bSF000`2_SEd0[XaL0:b:FP020:Z8F0030:^9F@2/RUX0[XaL0080/XeP0P2aS5l3
0;2;GP030:n:G@2fSUX0]XiJ0080]XiJ102gSe/20;>>H@80/XeP102aS5l40;B@H0@0/hmO00H0/hiI
0;>>FP2cSUX0/heL0;>=GP2cSF020;><H@P0/HaO0P2_RUd20;2;GP<0/HaO00D0/XeP0;FAH@2cSel0
/HeM0:n;F`020:j:FP040;2<G02aSEd0/XiN0;:>GP80/HeM0P2`S5`20:n;F`040:n:G@2`Reh0/8]N
0;2;GP80/HaO0P2bSF080;2;GP030;F@H`2dSf80/XeP00<0/8]N00L0/HaO0;:=H02cSFT0/heY0;>=
J02cSFH0/hiT0080/hiR00<0/hiQ0;B?HP2dSf801P2dSf800`2]Red0[heO0;6?H@020;>AH`040;6?
H@2_SEl0[H]M0:f9F@80[XYJ00<0[h]K0;2<G02`S5`02P2aSEd30;2<F0D0[h]G0140[XYF0:^6FP2[
QUX0[8MJ0:f9F@2_ReT0/8aH0;6=F@2aSUP0[h]K0;6=G@2bSUh0/hmO0;:>GP2aSEd0[h]K0:f9F@03
0:n;F`80[XYJ0`2]RET80:b8E0080:^8DP2/R5@0[HUE0:n;F@2_Re/0[HQK0:b7F`2[QUX20:n9FP<0
[XQI0`2]QeP20:j:FP<0[HUI0`2/R5P20:f8G080[8MK0P2[QUX20:Z5F@P0ZhMC00H0ZHI@0:V5D@2Z
QU80ZXID0:Z6EP2[QUT20:^6FPP0Z8A@202ZQUH0102ZRE`0ZHQK0:V8F`2YR5/20:R7FP80YhII202Z
QUH80:^6DP080:j5E`2]Q5H0ZH=D0:J2DP2UPE40Y89B0:F5E02VQUD80:R4E0P0Yh=?0`2TOd/20:F0
C0@0YX5=102RODT40:=nBP<0Y7m;0P2UP4`30:J1C@<0YH9:0P2TPDT30:>0B0@0YX9B102WPe<30:N1
DP@0YX1A00L0YGm@0:=mCP2TOTl0Y7i?0:J0D@2WPE80Z89C0080ZH=D0`2UPDd20:B0C0<0Xgm;00/0
Xgm?0:F1D@2WPe<0ZHEE0:N3D`2TP500X7a<09eiB@2MNT80Wga40:5nAP020:9oA`060:5nAP2OO4@0
WGY20:5mB@2PO4P0WWY60P2MNDD00`2NNTH0X7a80:5mB@030:=oC`80XWi>0`2QODd00`2LN4P0WWY:
0:5mC@020:=oC`030:1lC02LN4P0VWI60080VW]500@0Vga609amA`2LODL0WGi80P2NOdT209miBP@0
X7Y;0P2QNd`309]kBP80W7a;0`2MOD`20:5mB@060:1lB02NNTH0WGU509ahA02KMd<0VWI2202NNTH8
09ijBP80Wg];0P2NNTX509eiB@80X7]700<0WgY609iiA@2MN4@00`2LMd<209mkB`80WWY:00D0WGU9
09ahB02LN4P0VgM709]h@P0209]g@`0309]gA@2KMdL0VgI90080VgI:0P2MMdP0102LMTL0VgE609]e
AP2JM4D209UcA0P0V7A40P2HMd800`2JMT80VgI209ee@P0209id@P0309mc@P2KMDH0VgE600<0VWA5
0`2ILd@00`2FLT80Ug=309QdA00209QdA00409Ib@P2DL400Tflo09MbA@80UW5400<0U6m209=^@@2B
KD000P2AK3l308mY>R_ooooo000Zooooo`80WG=10P2NM48409me@`80WG500P2NLT4209mc@P80X7A3
202NM4880:1d@`<0XgQ500<0XWM40:5f@`2QMT<00P2PMD820:9iA@80XGQ40P2PMd<209mf@PP0XGI3
0P2SN4D0102SN4<0XgQ10:=i?`2SNCl20:9h?0030:9i@@2SNT80YGa60080YWe900H0YG]90:=iB@2R
N4P0XWU50:=jAP2UO4P30:ImB@030:ElB02SNTH0XWU500P0Z7e800D0Z7m;0:MnBP2WOTX0YWe90:El
B0020:AkA`040:=jAP2WNd`0Yg]<0:MkBP80Yga900H0Yga70:MlA@2WO4D0ZGi;0:QmBP2WO4T20:Ik
B0030:MlB@2XODX0ZGi;0080Yga50P2XODH20:UnA`80ZWm8202YOT/20:V0BP090:QoB@2WOTP0Z7m9
0:V0BP2[PT`0[HA>0:MnB02XOdT0ZX5;00<0[8==00@0Zh9<0:Z1B`2XOd/0Z7m;0P2YP4`30:Z1C@03
0:^2CP2]Pe40[H=A00H0[H=A202/Pd/20:Z1C@80Zh9>0P2/Pdl80:f4D080[8=?0`2ZPDT20:^2BP<0
[8=;202^QE40202ZQT`0ZhM=0:^6C`2/Qe80[HQC0:j9E@2^R5L0[hUH0P2_RUD20:j9E080[HQC0P2/
Qe801P2^PeP0[X=F0:n4E`2_QED0/8ID0;27D`80/HQB2@2]R5@20:Z5D@<0[8MC00<0ZXEA0:R3C`2W
PTh01P2ZQE420:^6DP80Z8=?00@0Yh9>0:J1C@2UP4`0Y7m;0P2SOTX30:AoB`80Xgi:0`2RODT309ii
A@80WGQ40`2LMd<00`2LMd80VgI109Ud?`0209Qc?P0409Ye@02KMT40W7M209Ud@080V7<o00<0Ug8n
09Ia?@2EL3`00P2DKc/0102CKCh0TV`m099/?@2BK3d2095[?080T6Xk0P2>J3/208eW>P<0S6Hi00@0
RfDh08]W=`2;IcL0RfLg0P2:ISH308UU=@@0Qf4b1026H3401P21GSP0P5dg081M=`1oG3H0OU/e07eJ
=080O5Tc00P0Oe`d07iK<`1lFC40NUL_07QE;@1fDb/0ME8Z07AA:@<0ME8X1@1fDbT01P1bDBh0LE0]
071?;01_CR/0KTdZ06e<:@80K4/X201]C2d806I<:`80ITPV00`0IDLU06A6901SAB<0HdDS06948P1Q
@b40Gd0T06119@1SA2P0I4DY06E6:P1TABT206=4:00306939`1QA2@0HD@T00H0HD@T00H0HT<W0653
9`1RA2P0H4DX0617:@1PBBX205i9:P0305a48P1OAbD0HTXX0080IDd[00<0I4`Z06599`1OAbD0201R
BRP206I:9@0406M;9P1XC2L0J4`W06M;9P80ITXU00@0J4/[06M::P1VBBT0ITTY0P1UB2P206I9:@03
06M::P1VBBT0IDPX0080I4LW00<0ITTY06Q;:`1YC2`0201RBB/306A<:P80IDd[0`1VCR`406=;9`06
069:9P1QBBD0H4PT0618901VCRP0IDdW0`1TC2H00`1VCRP0IdlY06UA:`0306M?;@80ITh/0`1UCB/2
069::080HDTW00L0H4PV05m79@1OAbD0GdLU05Q59@1IARH0FdPX0080G4TY00<0FdPX05U69P1HABD0
0P1M@RL00`1L@RL0Fd<W05U49`0205Q59`0<05I59`1IARP0ED8T05=08P1D@B<0F4DW05U6:01GA2H0
Dd0R05=2901B@B<0DD0R0P1@?b400`1B@B<0E4<U05E49P0805509P0604a39P1=@RH0C44U04i09@1?
?bD0CchT0`1A?B@0201@@B80Cd0S04dn8@1<?280Bc/R04`l9@1=?2P0CSdY0P18?2@204Lk8`80ASXR
0P15>B4304@j8@80@cTP0`12>1l203de8080?SHQ0P0o=b82040h8`0603dh900l=b<0>cHR03Xe8@0i
=200>3<O0P0g<Qh4038d7P@0<cDO0P0e=b8203@f8@0403<e800b=1l0<S@O038d7`80<c0M00@0=34N
03Db7`0f<b00=S<P0P0g=2401P0d=b80=CLR03@f8@0f=B40=S<P03Lb7`80>34O200d<Ah2034c7P<0
<38M0`0_<A`302l`80<0<34Q0P0a<R88034c7P03030c7P0^<A`0;C0K0080;2lJ00<0;C0K02ha700`
<ah00P0X=1`0100Z=1`0:cDM02`d7@0_=1h2030c7P<0=38M0P0e<ah303Hd7`08038a7@0c<Qh0=3<O
03Dd800g=R80>3LS03Th900j>BD203dg7`0303hh800o>B40@3XR0080@C/S00T0@S`T04<o9012?R<0
@S`R048k8@15>b80Ac/S04Tm9@1<?BH00P1=?R401@1>?b80DD8U05=49`1DABP0Dd@W0080DT<V00@0
DT@Q05A68`1FB2D0F4XW0P1IBbP02P1HBRL0EdTV05I68P1KBbL0HU0/06A@;@1TCB/0HT/Y06E=:`1X
D2h206U@:00306YA:@1[DRX0K5<[0080KE@/00@0KUD]075F:@1bEbX0MEX]0`1gG2l0101fFbh0MEX]
07aN;01kGB/207YL:P0<07]M:`1mGbd0Of4_085S<@22H380Pf4c08AR=025HcD0QV@f08MU=`28ISP0
RFLi0`2=JCD208iZ=P<0Sf/g00D0T6`h095]>@2AKCT0TVhj09A`?00209Ea?@0909Ib?P2CKc/0U70l
09Ea?@2FLSh0V7A009Ue@@2JMT80VgM30080VgQ20P2LND<0302MNT@0WW]509mlAP2OO4H0Wga20:1m
@`2PODD0XGi80:>0BP2TP4`0Y81>0:F1C`D0YX9>0`2UPDd01P2VPTh0Yh=?0:R4D02YQE40ZXIB0:^7
D`80[8QD0`2[QeL20:b8F0<0[HUI0P2^RUH20:f9E@040:j:EP2`S5P0/XiJ0;>?F`<0[hiK0P2`Se`3
0;6@G@80/hiQ00H0]8mR0;F@H`2fTF@0]i9U0;RCIP2iU6L20;FCI@<0]YAV302gUFL20;JDIP040;NE
I`2hUVP0^IMY0;ZHJP80^iU[00<0^IMY0;ZHJP2jV6X03@2jV6X30;VGJ@030;RFJ02gUFL0]iEW0080
]YAV202jV6X80;VGJ@P0^YQZ202jUFP80;VDI`H0]iEW0P2hUVP30;VDI`80^YEX0`2kUVT80;NEI`03
0;VGJ@2hUVP0]iEW0080]I=U00/0]iEW0;RFJ02iUfT0^YQZ0;VGJ@2gUFL0]YAV0;FCI@2fU6H0]iEW
0;RFJ0020;JDI0<0]I=S0`2dTV820;:@HP80/i5S0P2dTV@20;FCI@@0/i5S0P2dTV@20;FCI@060;NA
JP2gTVP0]i9X0;NBIP2gTVD0]i=S0P2gTf420;JDIP@0]I=U0`2dTV@80;FCI@P0]99R00<0/8iP0;6?
H@2cTF<00P2dTV@00`2cTF<0/Y1R0;6?H@020;>>H@80]8mR0`2eT6<00`2fTF@0]99T0;BBI0060;BB
I0080;ZFIP2iUFD0]i=S0;FAH@2dT600]I5Q0;JBHP2gTf<30;F@H`<0]8mR0P2cSV480;>?G`80]I1S
00@0]8mR0;>>H@2bSF00/HaO0P2`Reh02`2aRfH0/XaU0;B?I@2eT6@0]I5Q0;B@GP2bSUX0/HiH0;B?
HP2cSV40/HaO0080/8]N00<0/HaO0;>>H@2dSf800P2eTF401P2dT600/hmO0;:>GP2aSEd0/8aL0:n;
F`P0/XiN00<0[h]K0;6=G@2bSUh00P2dT6001P2cSel0/HeM0;2<G02bSF00/HaO0;2;GP80[hYM00<0
/8]N0;6<G`2bSF00202`S5`01P2bSeT0/XiJ0;:>FP2bSU`0/XiN0;:=H080/XeQ202_SEl20:n:G@<0
/8]N0P2aS5l20;:=H0080:n=G@2^S5`0[8YJ0:^9F@2ZR5P0ZhUI0:f;F`2^S5`20;:=H080/HaO102`
Reh20;B<F@80]HeJ0P2fSU/20;N?G0<0/hiQ0P2bSF030;6<G`@0/XiN102cSel01P2cSUT0/hiJ0;>>
FP2cSE`0/heN0;>=H080/haQ202aS5l20:n:G@80/8]N102aS5l0202dT600/hmO0;6=G@2_Re/0[XYJ
0:n;F`2`S5`0/HeM0P2bSUh20;6=G@80/8aL0P2_Re/40;2;GP80/HaO0P2bSF080;6<G`030;F@H`2d
Sf80/XeP00<0/8]N00<0/HaO0;:=H02cSFT00P2cSFP00`2cSFH0/hiT0;>>HP0:0;>>H@80[heO00@0
/8iP0;6?H@2aSf40/8iP0P2_SEl30:j:FP030:n;F`2`S5`0/8aL00X0/HeM0P2aSET20;2<F080[h]G
0P2^RUH01P2]RED0ZhIJ0:b7F`2/QeX0[HUI0:n;F@80/8aH00<0/HiH0;2<G02aSEd00`2bSUh00`2`
S5`0[XYJ0:f9F@030:n;F`80[XYJ0`2]RET80:b8E0080:^8DP2/R5@0[HUE0:n;F@2_Re/0[HQK0:b7
F`2[QUX20:n9FP<0[XQI0`2]QeP20:j:FP<0[HUI0`2/R5P20:f8G080[8MK0P2[QUX20:Z5F@P0ZhMC
00H0ZHI@0:V5D@2ZQU80ZXID0:Z6EP2[QUT20:^6FPP0ZXIB202ZQUH40:V8F`80Z8MJ0P2WQUT80:Z6
EPP0ZhIB00<0[XEG0:f4EP2YPe@00P2VPU800`2TPU80YHED0:F5E0080:R4E0P0Yh=?0`2TOd/20:F0
C0@0YX5=0`2RODT50:=nBP<0Y7m;0P2UP4`30:J1C@<0YH9:0`2TPDT20:>0B080YH5A0P2VPU820:N3
D`80Z8AD0P2XPU<20:N1DP050:J0D@2UOe00YGm@0:AnC`2SODh00P2TOTl01@2UOe00Yh5B0:R2D`2X
PU<0ZH=D00<0YH5=0P2TP4`30:=oB`0;0:=oC`2UPE40Yh=C0:R4E02WPe<0Y81@0:1lC02MNDT0Wga4
0:1mA@2ROdL00P2SP4P01P2ROdL0X7e509mlA02QODT0X7a809ijAP80WGU500<0WWY60:1lB02QODT0
0`2ROTh20:5mC@<0X7a<00P0W7Q809ijBP2QODd0Xgm?0:9nCP2PO4`0W7Q809YfAP80VW]50P2KO4H0
102LODL0WGi809enB02MOTP209miBPH0X7Y;202LO4/20:1lB00409mkA`2NNTH0WGU509eiA@80W7Q4
202NNTH309mkB`0509ijBP2MNDT0WGU909eiB@2LN4P00P2ONd/209ijBPD0WGU90P2ONTH209iiA@@0
WGQ40P2PO4`209mkB`0509ijBP2MNDT0WGU909eiB@2KN4800P2KMd<00`2KMdD0VgM709]fB@0209]f
BP80WGM800@0W7I709]eAP2KMDH0VWA50P2ILd@809QdA080V7M200<0VWI209]f@P2MMD800P2NM480
0`2OLd80VgE609]eAP0309YdA@<0VG=400<0UW9209Mc@`2HM4@00P2HM4@0102FLT80U71009=_?`2G
LTD209IaA00509E`@`2CKT40TVe0099]@02AK3l00`2AJc`[ooooo`00:_ooool209id@P80WgE30`2P
MT@0102QMdD0W70o09a`?`2LL3l209ea@0<0WW91202NM4880:1d@`<0XgQ50P2RMd@30:5f@`80XWU5
0P2QN4@20:1g@`80WgI2202RMd@20:=gAP030:=hA@2SN4<0XgQ10080XgTo00@0XgTm0:=j@P2TNd<0
YGa60P2VODT01P2UNdT0Y7Y:0:=iB@2QN4@0XWU50:AkA`<0YGa800<0Y7]70:9iA@2QN4@0202WO4L4
0:ImB@@0YGa80P2WNd`0102WNdX0Yga90:MlB@2WO4L20:MlA@80Z7e:00@0Yga90:IkB02VNdP0Yga9
0P2XODX30:MlA`<0Z7e80P2YOTT00`2ZOd`0ZGi;0:UnB`020:QmBP80ZGi;00`0ZWm<0:Z1B`2YP4X0
Z7m90:MnB02XOdT0ZH1:0:^2C02/Pdd0Ygi80:QoB@2ZPD/30:^2C080ZX5;0`2YP4`20:Z1C@<0Zh9>
202/PU080:b3C@80ZX5=0`2[PTh80:b3C`<0[HA@0P2[PT`20:b3C@80[HA>0P2^QDl80:j5D@80[8Q>
00@0[8M@0:b7DP2]R5<0[HQD0P2]QeH30:j9E0<0[HQC0P2/Qe801P2^PeP0[X=F0:n4E`2_QED0/8ID
0;27D`80/HQB2@2]R5@20:^6DP<0[8MC00<0ZXEA0:V4D02XPdl01@2[QU830:Z5D@80Z8=?0P2WPTh0
102VPDd0YH1<0:AoB`2TOd/20:F0C080Y7m;0`2SOTX0102RODT0WgY609mjAP2ONTH209iiA@<0WGQ4
00<0WGQ309ag@P2JMD000P2IM3l0102JMD00W7M209eh@`2JMD4209Ud@00309Qc?`2GLSh0UW4m0080
UG0l0`2CKCh2099/?@<0TF/l0P2?JC`208iX>`<0SFLj00@0S6Hi08aX>02<J3P0S6Ph0P2;IcL308YV
=P80RF<d0P28HS<208MQ<P80QV0a00H0PUlg085N=P21GSH0P5de07mL=01nFc<207eJ<P0607mL=01n
Fc<0OEXb07]H<01iERh0N5D]0P1fDb/807MD:P0607=B;`1bDBh0LU4^075@;@1`Cb`0Kdh[0P1^CBX8
06i=;0P0JD`Z0P1WBBL0101VB2H0IDLU06A6901TAR@206=58`0306529P1R@bL0I4DY00<0IDHZ0`1T
ABT806959@0606529P1P@RH0H48V05m49`1NABL0GTLX0P1LAbP0201LA280GTHT06599`1SBbT0I4`Z
06=;:@1PB2H0GdLU201PB2H206M::00406I99`1UB2H0IDPV06I99`80IdXX00/0IDPX06=69P1QA2@0
H4<S0654901RABD0IDPX06I9:@1ZCBd0J4/[06M::P0206E8:00306I9:@1WBRX0J4/[00P0HDPZ0`1S
BbT206A<:P<0IDd[00<0HDTU06=;9`1UCBT00P1VCRX02`1TC2P0HDTU05m78`1TC2P0Hd/W069:9P1Q
BBD0HTXV06=;9`1UCBT0IThZ00<0ITh/0P1UCB/306A<:PP0H4PV00P0FTLW05]8:01LBBT0G4TY05]8
:01JAbL0Ed@T05I38`80GT<X00<0GD<X05a4:01JABP00P1IARP01@1GARP0Ed@V05E2901D@B<0ED8T
0080F4DW00X0ET<U05=08P1C@R@0DT4S05508P1@?b40DD0R05918`1D@bD0ED@V201A@2H01P1;@RD0
C44U04e29P1?@BH0D40V05919`<0E40W00P0DD8S0511901>?b80CCdS04`l8`1=?BH0CSdY04ln:P80
B3`T0`17>b<304Hj8P0404Dk8P14>R40A3XQ04@j8@80@cTP0P12>1l2040h8`<0?cLR0`0n=R4203`g
8`0303/f8P0j=B40>C@P0080>3<O00<0=c8N03<e7`0c=Al01P0c=Al203Hh8`0403Dg8P0d=R40<S@O
034c7P80<38M00H0<RlL03<`7@0c<1d0=34N03Db7`0f<b0203Ld8@0603<f8@0d=R40=3HQ03Dd800f
<b00=c8O0P0h<Al203Hc800403Db7`0d<Ah0=34N03<`7@80<RlL0P0a<ah3030b7@<0;c4L0`0_<203
030a8@80<C8R200a<ah00`0`<ah0;c8M02d`6`0202`_6P0;02d`6`0_<Qd0<3<N02Pd700Z=1`0:cDM
02`d7@0_=1h0<3<N034c7P0b=1l00P0c<A`203@b7@<0=C<N00@0=S@O03Le800g=B00=cDP0P0h=R42
03Tg8P0603Xh8`0o>1h0?cPN040i7`11>R00@S/Q0P13?2802@14?B<0AD4T04E08`14?b80A3dQ04Lm
8P19?B<0CClU04i09P0204hm7`0304ln801A@280Dd8T00<0E4<U00D0Dd8T05E58@1FAR80F4PT05Y:
9P0205];9`80FTXV00P0FDXS061>:01TDR`0IU8]06E?:P1TC2P0IT`Y06U?;080KE4Y00@0KU8Z06mC
:`1`E2`0L5@/0P1aEBd00`1hFbl0NE``07YM<@0207]N<P0407YM<@1iG300NE``085S<@<0P68`00X0
PF<a08=U<`24IS@0QVPf081N<021Gc40PV0b08AR=026I3H0QfDg0P29IcT308iZ=P80Sf/g0`2@K3P0
1P2AKCT0TVhj099^>P2CKc/0U70l09Ea?@80UW8n00T0U70l09Ea?@2FLSh0Ug<o09Ue@@2JMT80VgM3
09ahA02KN4800P2LND<00`2MNT@0WW]509mlAP020:1mA`060:1m@`2QOT@0XGi60:9oB@2SP4X0Y81<
0P2UPDl70:J2CP80Yh=?0P2XQ5000`2YQE40ZXIB0:^7D`020:b8E0040:^7E`2/R5P0[8QH0:b8F080
[HUI0P2^RUX20;2<F080[h]G00@0/8aH0;:>FP2dT5`0]I5M0`2`SUh20;6?G`<0/Y1P0P2dSf80102e
T6<0]Y5T0;NBI@2gTVD20;RCIP040;FCI@2fU6H0]YAV0;JDIP80]iEW3`2hUVP40;VGJ@80^9IX0P2i
UfT0102jV6X0^iU[0;bJK02lVV`;0;ZHJP<0^IMY0P2hUVP80;ZHJQ00^IMY202jUFP80;VDI`P0]iEW
0P2gTVD20;RCIP80^IAW0P2jUFP80;NEI`030;VGJ@2hUVP0]iEW0080]I=U00/0]iEW0;RFJ02iUfT0
^YQZ0;VGJ@2gUFL0]YAV0;FCI@2fU6H0]iEW0;RFJ0020;JDI0<0]I=S0`2dTV820;:@HP80/i5S0P2d
TV@20;FCI@<0/i5S0P2dTV@30;FCI@060;NAJP2gTVP0]i9X0;NBIP2gTVD0]i=S0P2gTf420;JDIP@0
]I=U2`2dTV@80;BBHP030;6?H@2bT680/i5S0080]99T00<0/i5S0;6?H@2`SV000`2dSf820;F@H`<0
]Y5T202dTV@0202iUFD0^9AT0;JBHP2eTF40]91P0;FAH@2fTV80]i=S0`2eT6<30;B?HP80/hiQ202d
T6020;>>H@040;:=H02aS5l0/HaO0;2;GP80[hYM00/0/H]T0;:=H`2dSfD0]I1T0;F@H`2dT600/XiL
0;6=F`2cSV40/XeP0;6<G`020;2;GP040;6<G`2bSF00/hiQ0;>?G`80/XiN00<0/HeM0;2<G02_Re/0
0P2^RUX80;:>GP80/HeM00T0/XiN0;>?G`2cSel0/XiN0;6=G@2`S5`0/XeP0;6<G`2`Reh00P2_RUd0
0`2`Reh0/HaO0;:=H0080:n;F`060;:?F@2bSUX0/XiJ0;:>G02bSUh0/XeP0P2bSF480:n=G`80[hYM
0`2`Reh20;6<G`80/XeP0P2^S5`01P2]Re/0[8YJ0:b:FP2]Re/0[XaL0:n=G@<0/XeP0P2aS5l30;2;
GP80[hYF00@0/8]G0;6<F02cSUX0]8mK0P2eT5`50;>>H@030;:=H02aS5l0/HaO0080[h]K00@0/8aL
0;6=G@2aSEd0/XiN0P2cSel01P2bSEP0/XeI0;:=F@2bS5/0/XaM0;:<G`80/X]P202aS5l30:n:G@80
/8]N0`2aS5l00`2cSel0/XiN0;6=G@030:n;F`040;2<G02aSEd0/XiN0;:>GP80/HeM0P2`S5`20:n;
F`<0/8]N0P2aS5l30;:=H0P0/hiQ00<0]I1S0;B?HP2bSF000`2`Reh0202aS5l0/XeP0;:<I`2bS6L0
/XaU0;:=H`2bSF40/XeP0P2bSUh80;6<G`030;6?H@2`SV00[heO00<0[heO00@0/8iP0;6?H@2^RUX0
[XYJ0`2_Re/30;2<G0P0/HeM00@0/hmK0;:>FP2aSET0/8aH0P2_ReL00`2]RED0[8QD0:b8E0020:b7
F`060:f8F`2^RUX0[XYH0:n;E`2`S5P0/8eG0P2`S5`30;6=G@030;2<G02^RUX0[HUI00<0[h]K0P2^
RUX30:f9F@P0[8QD00P0ZhQB0:b8E02]RED0[h]I0:n;F`2]R5/0[8MK0:^6FP80[hUJ0`2^R5T30:f7
F080[XYJ0`2]RET30:b8F080[HQK0P2/QeX20:^6F@80ZXEH202[Qe<01P2YQU00ZHEA0:Z6DP2ZQU@0
ZXIF0:^6F@80ZhIJ202[Qe<80:Z6EP<0ZXQJ0P2YQeT30:R6F0P0ZXIF202[QU80202]Q5H0[8=E0:V3
E02WPe<0YX9B0:F3D`2TQ5<0YHED202XQ5@80:N3C`<0Y7m;0P2UP4`40:J1C@P0Xgi:0`2TOd/20:F0
C0<0YX5=0P2VPdd20:F2C0<0Y85;00l0Xh1:0:=oC`2TP500YH5A0:J2DP2WPe<0Z8AD0:V5E@2ZQUH0
ZXAE0:V3E02XPU<0Yh5B0:J0D@2TOTl00`2SODh20:AnC`030:EoD02VP540Yh5B0080Z89C0`2UPDd2
0:B0C0<0Xgm;00/0Xgm?0:B0D02VPU80Yh=C0:J2DP2SOdl0X7a<09ijBP2QOTP0XWm90:>0BP020:B1
B`060:>0BP2ROdT0XGi80:5mB@2PO4P0Wg]70P2NNTH00`2ONdL0X7a80:5mB@020:5mC@80X7a<0P2O
Nd/209ijBP0309eiB@2ONd/0XGe=0080XWi>00@0X7a<09eiB@2KMdL0VgY50`2LNdH309elA`0409im
B02PNT/0X7Y;0:1jB`D0WgU:00D0Wge=09ilC02NO4`0WG];09ajBP0209]iB@0309YhB02NNTH0WWY6
00D0WWY600<0WGU509ijAP2NNTH01P2NNTH20:5mC@070:1lC02NNTX0WGU909ahB02KMdL0VWI609ij
BP0309mkB`0509ijBP2MNDT0WGU909eiB@2LN4P00P2MN4@209iiA@<0WgY600<0WWU50:5mC@2QODd0
0`2PO4`309mkB`0609ai@`2LN4@0W7Q409ahAP2LN4P0W7M:0P2LMd/209egB00409afA`2KMDH0VgE6
09YdA@80VG=4202HM4@209Qg@P0309Yf@P2KMT80WGE20080WWA200<0Wg=209]eAP2KMDH00`2JM4D3
09UcA00309Ib@P2GLd<0V7A40080V7A400@0UW9209A`@02CKcl0Ug950P2FLD@00`2EL4<0U6m209=^
@@02099]@0<0Tfdn:oooool002[ooooo0`2OMD<20:1fA0<0XGM50`2KKch209a`?`<0WG50202NM488
0:1d@`@0XgQ5102RMd@20:9iA@80XGQ40P2PMd<209mf@PP0XgQ50P2RMTL01P2RMTD0XgQ50:=h@`2S
N440XgTo0:Aj@080Y7]300@0Y7]50:ElB02UO4P0Y7Y80P2TNTX00`2PMd<0XGQ40:=jAP030:AkA`03
0:=jAP2QN4@0X7M300P0Yga700@0Y7]70:ElB02UO4P0YGa80`2VODT0102WOTX0Yg]<0:MkC02WNdX2
0:MlB@030:MlA`2WO4D0Yga500<0Yga90P2VNdP;0:MlB@80ZWm<102XODX20:YoC0080:^2C02ZPD/0
Z7m90:MnB02XOdT0ZH1:0:Z1B`2[PT`20:QoB@030:V0BP2ZPD/0ZX5;00<0ZX5;0P2YP4`30:Z1C@<0
Zh9>202/PU080:b3C`80ZX5=202[PTh40:b3C`80[HA@00@0[8=?0:f4D02]Q500[HA@0P2^QE420:n6
DPP0[XEA00P0[XY@0:f9C`2]R540[HQC0:b7DP2/Qe<0[8IE0:^5E0H0[HQC0P2/Qe801P2^PeP0[X=F
0:n4E`2_QED0/8ID0;27D`80/HQB2@2]R5@40:b7D`040:^6DP2ZQE40ZXEA0:V4D080[8MC102[QU82
0:Z5D@030:V4D02XPdl0Z8=?0080Yh9>0P2VPDd00`2UP4`0YX5=0:J1C@020:F0C0<0Y7m;00<0Xgi:
0:1kA`2PNdL00P2PNdL209mjAP80WWU500<0WWU409eh@`2LMd800P2JMD000`2KMT40W7M209eh@`02
09Ye@@80VGA000@0V7<o09Mb?P2FLCd0UW4m0`2DKSl209=]?P<0TV`m0`2@JSd208mY?0<0SVPk0P2=
JCT308aX>0<0RfLg0P2;ICH0102:I3D0RF<d08QR<`28HS<208MQ<P80Pf0f00<0PUle085N=020GC<0
0P1oG3801`1nFc40P5de07mL=01nFc<0OEXb07]H<01iERh00P1hEBd207UF;0@0N5D[0P1gE2X00`1d
E2h0Le<]07=C;@02079B;080LE4[00<0L50Z071?;01`Cb`01P1`Cb`806Y>:@0606U;:@1XBRP0J4XX
06M99`1VB2H0IDLU0P1TAR@01@1TABP0IDHY06E6:@1UART0ITLZ00@0IDHY201RABD01P1P@BD0Gd4U
05m19@1M@RD0GD@V05a59P80FTDV00<0G4@R05i6901PB2H00P1RBRP00`1QBBL0H4PV05m79@0805m7
9@0306Q;:`1VBBT0I4LW0080HTDU00H0I4LW06I9:@1XBb/0IDPX06=69P1QA2@206138`0706=69P1W
BRX0JD`/06]>;P1ZCBd0J4/[06I9:@0206E8:00306I9:@1WBRX0HDPZ00L0HDPZ0P1QBBL2069::0<0
Hd/Y00/0I4`Z05m78`1RBRH0IThZ06UA;@1XD2`0IThZ06599@1OAb<0HDTW06189P0305m79@030659
9`1RBRP0I4`Z0080IDd[0P1TC2X406=;:@@0GdLU101PB2H205a9:@0605e::P1LBBT0FdPX05U69P1F
@b<0ED8R0P1OA2T00`1NA2T0GDDY05]6:@0205Y7:@0505Q7:@1E@R@0ED8T05E2901F@bD00P1GA2H0
101E@R@0Dd0R05=2901B@B<305508P0305=2901EA2H0ETDW00P0DD0V00L0Bd8U04a19@1=@RH0D48W
0592:01D@bT0ET8Y0080Ed<Z00P0DD@T05129@1>@2<0C3hS04`n901=?RL0CSlZ04m0:`80B3`T1P17
>b<204Dk8P<0A3XQ0`13>B02048j9@06044i9010>2<0?cLR03hf8@0m=B00?3@O0`0k=R800`0j=B40
>C@P03Td800203Pc7`<0=SDP100e=1l02@0d<ah0=cTT03Hh8`0e=b80<cDP038d7`0`<Qd0;c4L02h`
6`02038_700303<`7@0d<Ah0=C8O0080=S<P00L0=c@Q038e800c=B00<cDP03Dd800e<Ql0=c8O0080
>34O0P0g=240100f<b00=C8O03<`7@0b;a`2034^6`80<C<N0`0`<Qd302la70<0;c0P0`0`<B42034b
8P80<38M100a<ah2038d7`03030c7P0_<Qd0;S4L0080;C0K00<0;S4L02lb7@0`<ah00P0[=Ad0100/
=1d0;c@N030c7P0a<ah203@c7`80<c4L0`0d<Qd303Dc7P@0?3LQ100k=R02040i7@04044j7P12>al0
@c`P04@m8@80AChR00P0Ad8T04M08`16?b80B3lR04Xo8`1>@2D0DD4W0592:080DSlO00<0Dd0P05A1
8@1E@R800P1F@b<205M4900405U78@1JB280G4XT05i<9P80GddW00X0GT`V05e;9@1NC2@0I54Y06QE
;@1ZE2d0IdlY06I<9`1YCBP0JdlZ0P1_E2T00`1`EBX0LEH[079G;00207=H;@0307AI;P1lGBl0O5d_
00<0O5d_00<0Ne`^07YK;@1jFbd00P21Hc42089T<P0:08=U<`25IcD0QVPf08IX=P20GS00PEla089P
<P24HS@0QV@f08QV>080RVPj00@0Sf/g091/>02@K3P0T6`h0P2AKCT2099^>P80Tflk0P2DL3`209Ea
?@@0UW8n00H0Ug<o09Ue@@2JMT80VgM309ahA02MNDD209ai@`0409ejA02NNdD0Wga60:1mA`80XGi8
0P2ROdD0102SP4P0Xh1:0:B1B`2TP4`20:F1C`030:J2CP2WPdl0Yh=?0080Yh=?102XQ5020:V5D@80
ZXIB0P2[Qe<00`2/R5@0[8QH0:f9F@020:f9F@80[XYJ0P2_Re/20;:>FP80/HeI00@0/XiJ0;B@G02f
TUh0]i=O0`2aSf430;:@HP80/i5S0P2eT6<20;JAI080]i9U0P2hTfH30;JDIP80]iEW302hUVP30;ZH
JP030;VGJ@2hUVP0]iEW0080]iEW00H0]YAV0;NEI`2hUVP0^IMY0;ZHJP2lVV`20;fKK@P0^YQZ0`2k
VF/=0;ZHJQ00^IMY202jUFP80;VDI`<0^9IX102gUFL00`2fU6H0]Y5T0;JAI0020;NBI@<0^9=V00<0
^IAW0;NEI`2gUFL01P2gUFL00`2iUfT0^9IX0;NEI`020;FCI@0;0;NEI`2hUVP0^IMY0;ZHJP2iUfT0
]iEW0;JDIP2eTfD0]YAV0;NEI`2hUVP00P2fU6@30;FCH`<0]99R0P2bT6820;>AH`80]99T0P2eTfD2
0;>AH`80]99T0P2eTfD20;JDIP060;NAJP2gTVP0]i9X0;NBIP2gTVD0]i=S0P2gTf420;JDIP@0]I=U
2`2dTV@80;BBHP030;6?H@2bT680/i5S0080]99T00<0/i5S0;6?H@2`SV000P2dSf830;F@H`<0]Y5T
202dTV@00`2hU6@0]i=S0;FAH@020;B@H0030;FAH@2fTV80]i=S00<0]I1S0`2dSf820;>>H@P0]91P
00<0/XeP0;6<G`2aS5l00P2`Reh20:n:G@040:j9G02aS600/XeQ0;B?H`80]I1S00<0]8mR0;:>GP2a
SEd00`2bSF020;6<G`<0/XeP00<0/HeM0;2<G02`S5`00P2_Re/20:j:FP030:f9F@2bSUh0/XiN00/0
/XiN0P2aSEd0102`S5`0/XeP0;6<G`2`Reh20:n:G@030;2;GP2aS5l0/XeP00P0[XYJ00H0/XmI0;:>
FP2bSUX0/XiL0;:>GP2bSF020;:=H@P0[heO0P2_RUd30;2;GP80/HaO0P2bSF020:j<G080[H]K0P2^
S5`20:n=G@80/hiQ0P2bSF020;6<G`80/8]N00P0ZhME0:b8EP2]REL0[h]I0;6=F`2cSed0]91N0;FA
G`80/hiQ0`2dSf80102cSV40/HaO0;2;GP2]RET20:j:FP060:n;F`2`S5`0/HeM0;:>GP2cSel0/XeH
0P2bSET00`2bS5/0/XaM0;:<G`020;:;H0P0/HaO0P2^RE`20:n:G@80/8]N0P2aS5l30;6=G@@0/8aL
00<0/HeM0;:>GP2bSUh00P2aSEd20;2<G080[h]K0P2`Reh20;6<G`80/XeP0P2cSV480;B?HP030;F@
H`2dSf80/XeP00<0/8]N00L0/HaO0;:=H02bS6D0/XaU0;:=H`2bSF40/XeP0080/XiN00<0/XiL0;2;
GP2`Reh01P2`Reh00`2cTF<0/HmQ0:n=G`020:f;G@030:n=G`2aSf40/i5S00H0[h]K0P2`S5`80;6=
G@80/hmK00`0/HeI0;2<F02^RUH0[XYF0:f9E@2/R5@0ZhMC0:b7F`2]R5`0[HQK0:j:FP2^RUP20:n;
E`030;2=E`2`S5`0/8aL00<0/8aL00<0[h]K0:j:FP2^RUX00`2_Re/20:j:FP<0[HUI202/R5@0202[
R580[8QD0:f9E@2_ReT0[h]K0:f8F`2/Qe/0ZhIJ0P2_REX30:j8F@<0[HMH0P2^RUX30:f9F@<0[8QH
0P2]RET20:b8F080ZhMG0P2ZQUH80:^7D`060:V6D02YQE40ZXIB0:Z6E02ZQUH0ZhII0P2[QUX80:b8
E0P0ZXIF0P2/R5P20:^7E`80ZXIF2P2YQED80:Z5D@80[8=E00@0ZH=D0:R4E02WPe<0YH=C0P2TQ5<8
0:R4E0P0Yh=?0`2TOd/20:F0C0@0YX5=102TOd/40:=nBP<0Y7m;0P2UP4`30:J1C@<0YX9>0P2UPDd3
0:B0C0080:9nCP2SOdl0Y81@0:J2DP2WPe<0ZHEE0:Z6EP2[QeL20:Z4E@060:R2D`2WPE80YGm@0:An
C`2SODh0XWa=0`2TOTl00`2UOe00YX1A0:J0D@020:N1DP<0YH5=0P2TP4`30:=oB`080:9nCP2SOdl0
YH5A0:J2DP2UPE40Xgm?0:5mC@2ONd/30:=oB`80Y81<0`2SOd/00`2ROTX0XGe909mkA`0209ijAP04
09mkA`2QODT0XWi:0:1lC0<0Wg];0P2NNTX209eiB@0309ijBP2ONd/0XGe=0080XGe=00<0Wg];09ei
B@2LN4P0202NNTH20:1jB`@0WgU:0P2NN4T20:5mC@040:1lC02ONd/0WGU909ahB080VgM70`2MNDD3
09ijAP80Wg]7202NNTH20:9nCP060:1lC02ONd/0WGU909]gA`2JMTH0VGE50P2NNTX309mkB`0809ij
BP2LN4P0W7Q809]gA`2KMT80W7M309iiA@2ONTH30:1kA`0309mjAP2QODd0XGe=00@0XGe=0P2PO4`0
1P2LND<0W7Q409ahA02LN4H0W7Q809agBP80W7M;0P2MMdP0102LMTL0VgE609]eAP2JM4D209UcA0P0
VGE50P2HMd800`2JMT80VgI209ee@P0209id@P0309mc@P2KMDH0VgE600<0VWA50`2ILd@00`2FLT80
Ug=309QdA00209QdA00309Ib@P2DL400Tflo00<0UW5400<0UG1309A_@P2DKd800P2CKT4309E_@2_o
oooo000Zooooo`0409id@P2OMD<0WgE309me@`80X7I40P2QMdD309]_?P80W70o0`2MLD0809id@PP0
X7A3202SN4D20:9iA@80XGQ40P2PMd<209mf@PP0XgQ50P2QMDP0102RMTL0XWI50:=hA@2TND@20:Ai
@P030:ElA02TNd<0Y7]50080Y7]700H0Y7Y80:AjBP2UNd/0XGQ40:9iA@2SNTH30:AkA`030:=jAP2R
NDD0XGQ400P0YW]600@0Y7]70:ElB02UO4P0YGa80`2VODT0102WOTX0Yg]<0:MkC02WNdX20:MlB@03
0:MlA`2WO4D0Yga500<0YW]80P2WO4T;0:IkB0030:^0C@2ZOd`0Z7e:0080Yga900/0Z7e:0:YoC02[
P4d0Zh9<0:Z1B`2YP4X0Z7m90:MnB02XOdT0ZX5;0:^2C0040:QoB@040:V0BP2ZPD/0ZX5;0:^2C0<0
ZX5=0`2[PTh20:b3C`P0[89@202/Pdl20:^2CPP0ZX5=0P2[PTh20:b3C`80[HA@00@0[8=?0:f4D02]
Q500[HA@0P2^QE420:n6DPP0[XEA00P0[XY@0:f9C`2]R540[HQC0:b7DP2/Qe<0[8IE0:^5E0H0[8MB
0P2]R5<01P2^PeP0[X=F0:n4E`2_QED0/8ID0;27D`80/HQB2`2]R5@00`2/Qe<0ZhIB0:^6DP030:^6
DP80[HQD0P2/Qe<20:^6DP80ZXEA0P2YQ5040:R3C`<0Yh9>0`2VPDd20:F0C080Y7m;0P2RODT20:5l
B0@0X7]700<0X7]609mjA@2MN4<00`2KMT401P2LMd80WGQ309]f@P2KMT80VWE109Ud@080V7<o0P2G
LSh309E_@080U6ho0`2CKCh0102BK3l0TF/n095[?P2AJch2091Z?@80SfTl0P2>JSX208eY>@@0S6Ph
0P2=IcP01`2<ISL0RfDf08YT=@29Hc@0R68c08MQ<P25HcH00P24HSD00`23HC@0PV0c085O<P02081N
<@80P5de00@0Oe`d07iK<`1mFS80NeP`0P1jEbl207]H;P80NUL]0P1iER`207QE:`80MED^101dE2d2
07=C;0P0LE4[201]CbT206Y<:P0306U;:@1XBRP0IdTW0080ITPV00@0IDLU06M8:@1WB2T0IdPY1@1V
AbP00`1WB2T0HdHV06=69P0606=69P0606119@1O@BD0Gd4U05e29@1L@bD0Fd@U0P1IA2D00`1LA280
GDDS05m79@0306189P80GdLU201NAR@00`1WBR`0ITT[06=6:00206549P0?06=6:01VBB/0IdX/06I9
:@1UB2P0I4LW06=69P1TAbL0ITTY06U<;01[CRh0JTd]06U<;01WBRX0IDPX0080I4LW00<0IDPX06I9
:@1PAbT01`1PAbT306189P80HDTW0`1RBRP00`1NAR80HDTU06E=:@0206Q@;00;06I>:P1RBRH0GdLS
0617:01OARL0GTDV05e49@1NABH0GdHW0658:@1RBBX0101SBbT2069::080HDTW00<0H4PV05m79@1O
AbD0101OAbD02@1NAR@0G4TY05a9:@1MBRX0G4TY05]8:01IARH0ET<S05E28P0205i3:00305e3:01L
A2P0FTDX0080FDHX00<0EdHX058o8@1D@B<00`1GA2H02`1E@R@0E44S05=08P1D@bD0Dd8T05918`1A
@280DT4S05=2901EA2H0ETDW00P0DD0V00L0Bd8U04a19@1=@RH0D48W0592:01D@bT0ET8Y0080Ed<Z
00P0Cd@T04e2901<@B<0BSlS04Xn901:?RH0BclY04a0:P80Ac/S1P18?2@304Dk8P<0A3XQ0P13>B00
1P14?2L0@c/V048j9@11>B@0?cLR03hf8@80?3@O00<0>cHR03Xe8@0j=B400P0j=B4303Td80<0>3HQ
00<0=cDP03Hd7`0f=1l00P0e<ah02@0g>B@0=SPS03Dg8P0c=B00<C<N02la700^<1/0;BlJ034^6`02
038_700303<`7@0d<Ah0=C8O0080=S<P00H0<C@O038d7`0b=1l0=3<O03Db7`0g<Ql203Pa7`80=c@Q
00@0=S<P03Db7`0c<1d0<RlL0P0a;Q/2034c7P<0<38M0`0_<A`302l`80<0<34Q0P0a<R800`0_<A`0
<38M030b7@02034c7P80<S@O00@0<cDP034d7`0`<ah0;S4L0P0]<1/00`0^<A`0<3<N034d7`0202`d
7@0402ld7P0`<ah0<C<N03@c7`80=C8O0`0d<Qd203Dc7P<0=S@O0`0o>B4203hh80<0?CLO0P14>ah2
04Dl7`0<04Hm8017?R40B3lR04Po8P1:A2@0Bd8S04Y18P1;@280CT0S05939P1EA2P0ETDY101F@R40
2@1G@b80F4@S05U5901JARD0FdLV05]78P1MBB@0Gd/V065=:002069>:@0;065=:01PC2L0HDhT06QB
:@1/ERd0K5D/06YA:@1ZCRL0K4hX06i@:P1bEBT00P1cERX00`1dEb/0MEP/07II;@0207MJ;P80O5`]
00<0Ne//07YJ:`1jFR/00`1jFR/0101oHBl0P68`085S<@22I38208=U<`80Q6Hd00P0PV0b08=Q<`24
HS@0QV@f08QV>029IcT0RVPj08]Y>`<0TFdi0P2BKSX309=_>`@0UG4m102FLSh01P2GLcl0V7A009Ue
@@2JMT80VgM309eiA@80WWY60P2MNT@0102NNdD0Wga60:1mA`2QOTP20:9oB@80Y85700@0Y8590:B1
B`2UPT`0YH5=0P2UPDl30:N3C`030:R4D02YQE40ZHEA00H0ZXIB102[Qe<20:f9F@80[XYJ0`2_Re/0
0`2`S5`0/hmK0;>?F`020;:>FP040;>?F`2eTEd0]i=O0;RDH0@0/Y1S0P2cTF@20;BBI@80]Y5T102g
TVD20;RCIP80]YAV0P2gUFL20;RFJ0/0^IMY0P2kVF/0102jV6X0^IMY0;RFJ02gUFL30;JDIP050;NE
I`2hUVP0^IMY0;ZHJP2lVV`00P2mVfd=0;ZHJP<0^iU[202jV6X80;VGJ@P0^9IX402iU6L20;VGJ@80
^9IX00@0]iEW0;JDIP2fU6H0]YAV0P2fTF@20;NBI@<0^9=V00<0^IAW0;NEI`2gUFL01P2gUFL00`2i
UfT0^9IX0;NEI`020;FCI@0;0;NEI`2hUVP0^IMY0;ZHJP2iUfT0]iEW0;JDIP2eTfD0]YAV0;NEI`2h
UVP00P2fU6@30;FCH`<0]99R0P2bT6820;>AH`80]99T0P2eTfD30;BBI080]I=U0`2fU6H01P2gTFX0
]i9X0;NBJ02gTVH0]i9U0;NCH`80]i=Q0P2fU6H40;FCI@<0]99T202cTF<80;BBHP030;:@HP2cTF<0
]99T0080]99T00<0/Y1R0;2>H02_SEl00`2eT6<30;JAI080]i9U202dTV@0202gTf<0]Y9R0;B@H02c
Sel0]91P0;FAH@2fTV80]i=S0`2eT6<30;B?HP80/hiQ202eTF420;6<G`@0/8]N0P2_RUd00`2aSEd0
/XiN0;B?HP020;F@H`040;B?H`2bSF40/HaP0;6<G`H0/XeP00<0/HaO0:n;F`2_Re/00P2_Re/40:j:
FPP0/XiN00@0]91P0;>?G`2bSUh0/XiN102aSEd00`2bSF00/HaO0;2;GP020:n:G@030;2;GP2aS5l0
/XeP00P0[h]K00H0/XmI0;:>FP2bSUX0/XiL0;:>GP2bSF020;:=H@P0[heO0P2_RUd30;2;GP80/HaO
0P2bSF020:f;F`030:j<G02_SEd0/8iN00<0/8iN0`2cSV420;:=H0<0/HaO0100ZhMG0:b8F02]RET0
[h]K0;6=G@2cSel0]91P0;FAH@2bSF00/hiQ0;F@H`2fTF@0]I1S0;>>H@2aS5l0/8]N0P2^RUX0102_
Re/0/8aL0;2<G02aSEd20;:>GP060;6<E`2aS5P0/HaH0;6;FP2aRe`0/H]N0P2aRUl80;6<G`<0[XUL
0P2_RUd30;2;GP<0/8aL102aSEd00`2`S5`0/XiN0;:>GP020;6=G@80/8aL0P2_Re/30;6<G`80/XeP
0`2cSV480;B?HP030;F@H`2dSf80/XeP00<0/8]N00L0/HaO0;:=H02bSF<0/XeS0;:=H@2bSF00/XiN
0080/XiL00<0/XiJ0;2;GP2`Reh01P2`Reh00`2cTF<0/HmQ0:n=G`020:f;G@030:n=G`2aSf40/i5S
0080/8aL1P2_Re/80;6=G@80/XiJ00L0/HeI0;2<F02_ReL0[h]G0:j:EP2]RED0[8QD0080[HQL00L0
[XUL0:j:FP2^RUP0[XYF0:n;E`2_S5H0/HeM0080/8aL00<0[h]K0:j:FP2^RUX00P2^RUX30:n;F`80
[XYJ0`2]RET80:b8E0080:^8DP2/R5@0[HUE0:n;F@2_Re/0[HQK0:b7F`2[QUX20:n9FP<0[XQI0`2]
QeP20:j:FP<0[HUI0`2/R5P20:f9E`80[8QF0P2[QeD20:Z6E0P0ZXIB00H0ZHI@0:V5D@2ZQU80ZXID
0:Z6EP2[QUT20:^6FPP0[8QD202ZQUH30:^7E@80ZXID0`2YQE<80:V5E@P0ZXEA0P2/PeD01P2ZQ5D0
Z8AD0:R4E02UPe<0Y8AC0:>3DPP0Z8AD202WPdl30:AoB`80YH1<1@2VPDd20:F0C080Y7m;0P2SOTX0
102RODT0Y7m;0:AoB`2TOd/20:F0C0<0YX5=0P2WPe420:J2D080YH5?0P2TP4h0202ROTh0Xgm?0:B0
D02VPU80Yh=C0:V5E@2ZQUH0ZhMG0P2YPe@01P2XPU<0Yh5B0:J0D@2UOe00Y7i?0:=mCP<0Y7i?102U
Oe00102VP540YH5=0:F1C@2UPDd20:B0C0<0Xgm;00<0XWi>0:=oC`2TP5000P2TP500102SOdl0XGe=
0:1lC02TP4h60:=oC@040:B0CP2ROTX0XGe90:1lB080Wg]700@0X7a80:5mB@2ROTX0X7a<0`2ONd/2
09ijBP80WGU90P2ONd/01P2PO4`0XGe=0:1lC02ONd/0WGU909ahB0@0WWY6102MNDD20:1jB`80WgU:
0P2NN4T209egB0080:5mC@2PO4`0Wg];09ijBP2MNDT0W7Q809]gA`2JMTH309eiA@<0WWY60P2ONdL8
09ijAP80XWi>00T0X7a<09mkB`2MNDT0VgM709YfAP2IMDD0WGU909ijBP2ONd/00P2PO4`0302NNTX0
W7Q809ahB02JMTH0VgI209ag@`2ONTH0XGa80:9mB@2QO4P0X7]709mjAP80X7a<1P2QODd01P2MNT@0
WGU509eiA@2MNDL0WGU909ehB`80WGQ<0P2MMdP0102LMTL0VgE609]eAP2JM4D209UcA0P0VGE50P2H
Md800`2JMT80VgI209ee@P0209id@P0309mc@P2KMDH0VgE600<0VWA50`2ILd@00`2FLT80Ug=309Qd
A00209QdA00309Ib@P2DL400Tflo00<0UW54102EL4<0102DKd80UW1109I`@@2FL44[ooooo`00:_oo
ool309ec@@80WWA20`2OMD<309a`?`80WG500`2NLT4809id@PP0X7A300@0XWM40:=hA@2SN4D0XgQ5
0`2TNDH00`2UNTL0XWU50:9iA@020:5hA080X7M30P2OMT880:9gA0060:1cB@2QMDP0XGE80:9fA`2S
MdH0Y7U60P2UNTD00`2VODD0YGa40:AkA@020:=jAP060:AjB02UNd/0YWa<0:9iA@2SNTH0YGa80`2V
ODT00`2UO4P0XgY60:9iA@080:IkAP@0YWe9102UO4P20:MkC0040:MkBP2WO4T0Yga90:MlA`80Yga5
0P2UNTL0102VNdP0Yga90:MlB@2VNdP20:EjA`<0YWY90`2UNDP20:AhA`030:b1CP2ZOd`0Z7e:0080
YW]800d0Z7e:0:YoC02/PDh0[8==0:^2C02YP4X0Z7m90:MnB02XOdT0ZH1:0:Z1B`2YP4X0Z7m90080
Ygi800@0Z7m90:V0BP2ZPD/0Zh9<0`2ZPDd20:^2CP<0[8=?202[PDl80:b2D080Zh9>0`2ZPDd50:V0
C0040:Z1C@2[PTh0[8=?0:b3C`80[HA@0P2[PDl20:b2D080[H=A0P2^Q5880:j5D@80[8Q>00@0[8M@
0:b7DP2]R5<0[HQD0P2]QeH30:^6D@<0[8MB0P2]R5<01P2^PeP0[X=F0:n4E`2_QED0/8ID0;27D`80
/HQB2@2]R5@01@2^RED0[HQD0:b7D`2[QU80ZXEA0080ZhIB00D0[8MC0:j9E@2^RED0[HQD0:b7D`02
0:^6DP80ZXEA202YQ500102XPdl0Yh9>0:N2CP2WPTh20:J1C@80YH1<0`2SOTX20:9mB@<0XGa800D0
XWe80:1kAP2NND@0W7M209]f@@0209ag@P0609eh@`2LMd<0W7M309]f@P2JMD40VGA00P2HLcl0102G
LSh0UW1109I`@@2FL44209E_@0<0U6ho0`2CKD02099/?`<0TF/n0P2?Jc/208iZ>P<0SFTi00T0S6Ph
08mY>P2?JCX0SVPi08aV=`2;ICH0RV@e08US=028HS<00P26I3H00`25HcD0Q68d08=Q<`02089P<P07
085O<@21GSH0PEhf081M=@1oG3@0OU/c07eJ<P0207aI<@80OEX`00@0O5T_07]H;P1jEbd0NUL]0P1i
ER`807IF;@P0Le</201`D2T206]=:`80JT`Z00T0JD/Y06Q::01WBBL0IdTW06Y<:P1YBbT0J4XX06M9
9`1VB2H00`1WBBL00`1XBRP0HdHV06=69P0606=69P0906939`1P@RH0H48V05i39P1L@bD0Fd@U05U4
9@1H@b@0G4@R0080GDDS00<0GTHT05m79@1OAbD02P1OAbD00`1UAb/0I4HZ06=5:@020694:00306=5
:@1TARX0IDL[00@0ITTY1@1WBRX01`1VBBT0I4LW06=69P1RABD0HdHV06A79`1UB2P0201PAbT0101N
AR@0GdLU05m79@1OAbD206189P80HDTW00<0GTHR0618901RBRH00P1UCBT01P1TC2P0HDTU0618901P
AbT0GdHX05i59`80GD@V00<0GdHX0658:P1RBB/00`1RBRP206599`<0H4PV0P1QBBL0101PB2H0GdLU
05i6901MAB<205a48P0805Y79`1KB2P0G4TY05a9:@1KB2P0FTLW05M4901F@b<205e29`0305a29`1K
@bL0FD@W0080F4DW00H0ETDW04ll7P1D@B<0F4DW05U6:01F@bD305=08P0305A39@1C@R@0DT4S0080
DT4S00<0E4<U05E49P1GARP0201A@2H01P1;@RD0C44U04e29P1?@BH0D40V05919`<0E40W00P0C4<R
04]28`19@240B3lR04Lm8P18?RD0BChX04Xo:@80Ac/S0`18?2@304Tm9@80AS`S0P15>b8304@j8@07
04<i8013>bH0@c/V048j9@11>B@0@3PS03hf8@0203de80P0>SDQ0P0k=R8203Xe8@0<03Td800h<al0
=c8N03Lb7P0e=b80=3HQ03<e800b=1l0<C<N030b7@0_<A`0;S0K0P0a;Q/00`0b;a`0<c0M03@a7P02
03Db7`0903Hc800_<Qd0<C<N034c7P0c<Qh0=C8O03Lb7`0h<Al0>C8P0080=S<P00@0=C8O03@a7P0d
<Ah0<c0M0P0b;a`2034c7P<0<38M0`0_<A`302l`80<0<34Q0P0a<R8202la7004030b7@0a<ah0<C<N
038d7`80<cDP00<0<C@O030c7P0_<Qd00P0^<A`02`0_<Qd0<3<N034d7`0^<ad0;c@N030c7P0a<ah0
=3<O03Db7`0f<b00>3<P00<0=S@O0P0g=B0303Pf8@<0@CXP1010>Al01P0o>1h0AS/O04Hk7`17?200
B3dQ04Tn8P80BSlS00T0Bd0T04e48`1>@b<0CD8R04m28P1B@b@0ED@V05Y7:@1KB2X01@1KA280201L
AB<0GDHT05m89P1PBBL0GdTR065;901SCBH0IDlX0P1VD2T02P1UCbP0I4hW06A?901XDbP0KUL]06mF
;@1^DRX0KE0X075A:P1cDb`207MH;080N5T]00@0NEX^07YK;`1kG300Ne``0P1lFRX02P1kFBT0NUPX
07YH:01kFBT0O5XZ07eK:`1mGbd0Of4_081R<022I38308=U<`05089T<P27ICL0QfDg08QV>029IcT0
0P2:J3X208]Y>`80TVhj0P2CKc/309A`?00309Ea?@2FLSh0UW8n00D0UW8n00T0Ug<o09Qd@02IMD40
VWI209]g@`2MNDD0WWY609mkA`2PO4P00P2NNdD00`2OO4H0X7e70:5nB0020:9oB@040:>0BP2UPTP0
YH980:F2BP80YH9<00<0YH5=0:F1C`2VPU000P2WPdl0102XQ500ZHEA0:Z6DP2ZQU8:0:^7D`80[XYJ
0P2_Re/30;2<G0030;6=G@2cSe/0/hmK0080/XiJ00D0/hmK0;FAG@2gTel0^9AP0;:?I@030;>@IP80
]95W0P2eTVP50;NBI@<0^9=V0`2gUFL20;RFJ0`0^IMY00D0^iU[0;ZHJP2jV6X0^IMY0;RFJ0020;NE
I`030;JDIP2hUVP0^9IX0080^IMY00@0^YQZ0;^IJ`2lVV`0_9Y/202jV6X20;RFJ0<0^IMY2`2jV6X8
0;VGJ@P0^9IX402iU6L01P2jV6X0^IMY0;VGJ@2hUVP0]iEW0;JDIP80]I=U0P2gTVD20;RCIP80^IAW
0P2jUFP80;NEI`030;VGJ@2hUVP0]iEW0080]I=U00/0]iEW0;RFJ02iUfT0^YQZ0;VGJ@2gUFL0]YAV
0;FCI@2fU6H0]iEW0;RFJ0020;JDI0<0]I=S0`2dTV820;:@HP80/i5S0P2dTV@20;FCI@80]99T0P2e
TfD30;JDIP070;NEI`2gTFX0]i9X0;NBJ02gTVH0]i9U0;NCH`020;NCH@80]YAV102eTfD30;BBI0P0
/i5S202dTV820;>AH`060;BBI02eTfD0]99T0;:@HP2`SV00[XaN0`2eT6<20;JAI0<0]i9U202dTV@0
0`2fTV80]I5Q0;>?G`020;>?G`030;FAH@2fTV80^9AT00<0]I1S0`2dSf820;>>H@P0]I5Q202aS5l0
2`2aSE/0/XiL0;B@H02eT6<0]I1T0;B?I@2bSF<0/H]T0;2;GP2aS5l0/XeP0080/hiQ00<0/XeP0;6<
G`2`Reh0202_Re/80;:>GP040;FAH@2dT600/hmO0;6=G@<0/8aL00@0/HeM0;:=H02aS5l0/8]N0P2_
RUd00`2`Reh0/HaO0;:=H0080;2<G0060;:?F@2bSUX0/XiJ0;:>G02bSUh0/XeP0P2bSF480:n=G`80
[hYM0`2`Reh20;6<G`80/XeP00@0[8YJ0:f;F`2_SEd0/HmO0P2bT6020;6?G`040;B?HP2cSV40/hiQ
0;>>H@80/XeP0P2aS5l20:b:G0040:f;G@2^S5h0/8iP0;6?H@80/Y1R00<0/XeP0;>>H@2fTF@00P2g
TVD00`2dSf80/HaO0:n:G@080;6=G@060;6<E`2aS5P0/HaH0;6;FP2aRe`0/H]N0P2aRUl80;6<G`04
0:f8F`2^RE`0[XUL0:j9G080[hYM0P2`Reh00`2^RUX0[h]K0;2<G0030;:>GP040;6=G@2`S5`0/XiN
0;:>GP80/HeM0P2`S5`20:n;F`80/HaO0P2bSF030;>>H@030;B?HP2cSV40/hiQ00H0/hiQ00<0]I1S
0;B?HP2bSF000`2`Reh01`2aS5l0/XeP0;6<H02aS600/HaO0;6=G@2aSE/00P2aSET00`2aSUP0/HaO
0;6<G`060;6<G`030;6?H@2`SV00[heO00<0[heO00<0/8iP0;6?H@2`S5`00P2`S5`30:n;F`80[XYJ
202aSEd30;2<F0@0[h]G0P2^RUH20:j9G@030:j9G02^RUX0[XYH0080[XYF00D0[X]E0;6=G@2`S5`0
[h]K0:j:FP020:f9F@030:j:FP2_Re/0[h]K0080[h]K0P2^RUX30:f9F@P0[8QD00P0ZhQB0:b8E02]
RED0[h]I0:n;F`2]R5/0[8MK0:^6FP80[hUJ0`2^R5T30:f7F080[XYJ0`2]RET30:b8F080[HUE0P2/
R5@20:^7D`X0ZXIB00H0ZHI@0:V5D@2ZQU80ZXID0:Z6EP2[QUT20:^6FPP0ZhMC202ZQUH20:b7D`80
ZhIB0`2ZQE400`2YQ500Z8AD0:R4E0060:R4E0P0ZHA@0P2[PU@01P2ZQ5D0ZHEE0:V5E@2VQ5@0Xh=B
0::2D@P0Z8AD202WPdl30:AoB`80YH1<102VPDd01P2WPTh0YX5=0:J1C@2UP4`0Y7m;0:=nBP80XWe9
0`2TOd/20:F0C0<0YX5=0`2WPe<20:J2DP<0YH5A00P0Xgm?0:B0D02UPE40YX9B0:N3D`2XQ5@0ZHEE
0:Z6EP<0Yh5B0`2VP5420:EoD0P0Y7i?0`2UPDd20:B0C0<0Xgm;0`2ROTh20:=oC`80XWi>00@0XGe=
0:B0D02SOdl0XWi>0P2QODd01P2ROTh0Xgm?0:B0D02SOd/0XWi:0:1lB080Wg]700<0X7a80:9nBP2S
Od/00P2QODd20:1lC080Wg];0P2NNTX40:1lC080Wg];00<0WWY:09eiB@2ONTH00P2ONTH209iiA@<0
WGQ40P2PNT/209miBP0409ihB@2MMdP0W7I709afA`80X7Y;00@0WgU:09ihB@2NN4T0WGM80P2LMTL7
09ijAP0309eiA@2NNTH0WWY600H0WWY60P2QODd02@2PO4`0WWY:09eiB@2LN4P0VgM709YfAP2LN4P0
WWY:0:1lC0020:5mC@0<09ijBP2KMdL0VgM709UeA@2KMT80WGQ40:1kA`2RODT0Xgi:0:5lB02ONTH0
WGQ40`2ONd/30:1lC080XGe=00H0WGY409eiA@2MNDD0WGU709eiB@2MN4/209ehC080WGM800@0W7I7
09]eAP2KMDH0VWA50P2ILd@809UeA@80V7M200<0VWI209]f@P2MMD800P2NM4800`2OLd80VgE609]e
AP0309YdA@<0VG=400<0UW9209Mc@`2HM4@00P2HM4@00`2FLT80U71009=_?`0809IaA0<0UW11:ooo
ool002[ooooo0P2KLCl309ab@0<0WG=10P2MLD0209ib@@80Wg=20P2PM4<809id@PP0X7A30P2RMd@2
0:=hA@040:AiAP2UNTL0YGY70:EjA`80XWU50P2QN4@20:1g@`80WgI2202QMT<20:1cB@090:5eB02R
MTT0XgM80:AhA`2UNTL0YW]80:ImA@2UO4@0XgY40080XWU500H0XgU70:EkB`2VO4`0Y7]70:ElB02W
OTX30:QoB`030:MnBP2UO4P0Y7]700P0YGY500D0Z7m;0:MnBP2WOTX0YWe90:ElB0020:AkA`040:=j
AP2WNd`0Yg]<0:MkBP80Yga900H0Yga70:MlA@2WO4D0Y7U60:EjA`2VNdP20:MlB@030:IkB02UNTL0
Y7U60080YWY;0P2UNDX20:AhB@80XgM800<0[H9?0:^0C@2WO4T00P2UNTL02@2WO4T0Zh1=0:f2C`2]
Q4h0Zh9<0:V0BP2XOdT0Ygi80:QoB@030:V0BP080:QoB@2WOTP0YWe70:MnB02XOdT0ZX5;0:^2C02Z
PDd30:^2CP80[8=?0P2]Q5080:^1C`P0[89B0P2[PTh20:Z1C@80ZH1<102XOd/01P2YP4`0ZX5=0:^2
CP2/Pdl0[HA@0:j5D@<0ZX1@0P2[PE430:b2DPP0[XEA00P0ZXI<0:^7C@2[QTl0[8MB0:f8D`2^RED0
[XQG0:n9F080ZXE@0P2[QU420:b7DP80[HQC00H0[X=H0:j3EP2_Q5L0[hEE0;26E02`Qe<20;68DPT0
[HQD00P0[hYF0:j9E@2/Qe<0ZhIB0:Z5D@2[QU80[8MC0:f8E080[hYF00D0[XUE0:f8E02/Qe<0ZhIB
0:Z5D@050:V4D0@0ZXEA0`2XPdl20:N2CP<0YX5=0`2TOd/20:=nBP<0XWe900@0Xgi90:5lA`2ONTD0
WGQ30P2LMd8209eh@`80WGQ400<0W7M309]f@P2JMD400P2IM4000`2HLcl0Ug5209Ma@P0209I`@@<0
UFm000@0U6ho09A^@@2DKT40U6i10P2CKD03099/?`04091/?02?Jc/0Sf/k08m[>`80SVXj0P2=JCT0
1P2AJc`0T6Xk08mY>P2=IcP0S6Hg08YT=@80RF<d0P27ICD00`26I3@0QF<c08AR<P0208=Q<@06089P
<022GcL0PEhf085N=P20GCD0Oe`d0`1nFc<01P1oG380OU/a07eJ<01lFBl0NeP^07YG;@80NEH/1`1g
F2`00`1hFBd0M5@]07AD;@0607AD;@P0LU0Z00H0KDl]06a>;01[CB/0Jdd[06Y<:P1YBbT206Q::003
06a>:P1[CBT0JD/W00<0IdTU0P1XBRH00`1YBbL0HdHV06=69P0606=69P0606=4:01RA2P0HT@X05m4
9`1MA2H0G4DV0P1IA2D305a48P80GDDS0P1NAR@00`1OAbD0H4PV06189P0606189P0306539`1RA2P0
HdDY0080I4HZ00h0HdDY0694:01Q@bL0HD@T06=69P1UB2P0IdXZ06I9:@1TAbL0HD@T05m28P1SARH0
HTDU06549080H4<S00<0HTDU06=69P1UB2P0201OARP0101MAB<0GTHT05i6901NAR@205m79@80H4PV
0P1NAR800`1OAb<0H4PT06599@0306599@080617:@1OARP0GTDW05e49P1NABL0GdHX0658:P1RBB/3
06599`80H4PV0`1OAbD02`1SBbT0HTXX06599`1OAbD0GDDS05]38@1J@R00FD4O05Q59@1IARH0FdPX
0080G4TY00<0FdPX05U69P1HABD00P1K@2D00`1J@2D0FD4U05M29@0205I39@0605A39@1=>Q`0Dd0R
05U6:01JAbT0ET<U0P1B?b40101C@280ED@V05A39@1C@R@205918`0305A39@1FABL0EdHX00P0DD0V
00H0C4<V04e29P1<@BD0CT0U04lo9@1??R@3054m900804Q28017@B40AClO04@m8013?200A3dS04Dm
9P16?RL204Lk8`80B3`T0P19?BD204Xn9P<0AS`S0P15>b8304@j8@<0@SXU00<0@CTT040h8`0o=b80
0P0o=b8203Td80H0>SDQ0P0m=R<0100l=B80>c@Q03Xc800i<Ql203Pa7P0503<e800b=1l0<S@O038d
7`0a<ah00`0`<Qd2034^6`80<RlL00D0<c0M03@a7P0e<Ql0=C8O02lb7@02030b7@0303<b7P0e<Ql0
=c8O0080>C8P200d<Ah2034c7P<0<38M0`0_<A`302l`80<0<34Q0P0a<R801@0^<1/0;c4L02la700`
<Qd0<S@O0080<cDP00@0=3HQ038e800a=1l0;c8M0P0^<A`00`0_<Qd0<C@O038e8002030c7P04034c
7P0d<al0=C8O03Hc8080>3<P0P0h=R4203Tg8P<0>SPS00<0>cTT044j8011>R000`11>R03048k8@80
BC/N00<0BS`O04/m801<?R400P1=?b802@1>@2<0CdDR04m58P1AA280DT<R05E5901IARH0G4TY05m:
:`0205m89P0;05i79@1MAR@0GDHT05i79@1PBBL0HT/Y06A=:`1QBb80HT`S06A>9@1VD2L00P1WDBP2
06I@9`0906A=8`1YDRP0KeH]079F;P1aE2`0LU8[07AD;@1gEBl0NEP[0080NUT/00<0NeX]07aK;P1m
G2l00P1nGC000`1oGR/0OUdZ07eL:@0207eL:@0707mN:`22HBh0Pf8_07mQ;`21Hc40PfDc08EW=@02
08IX=P0308EW=@24IS@0S6Xl00D0S6Xl0P2;JC/209=_>`80U70l0`2ELCd00`2FLSh0Ug<o09Mc?`06
09Mc?`0809Ue@@2JMT80VgM309ahA02NNTH0Wg]70:1lB02QODT209mlAP040:1mA`2QOTP0XWm90:9o
B@80Xh1:0P2VPdT0102VPd/0YX==0:J3C@2VPTh20:J2D080Yh=?00H0Z8A@0:V5D@2ZQU80ZhMC0:b8
E02]RED30:b8E0D0ZhMC0`2_Re/20;2<G0<0/HeM0P2bSUX20;6=F@040;:>FP2dT5`0]Y9N0;NCG`80
/i1V0P2dTFL30;FBJ0030;JCJ@2hTfH0^9=V00@0^9=V0P2gTVD20;NEI`80^9IX102iUfT90;ZHJP@0
^IMY102hUVP00`2iUfT0^YQZ0;ZHJP0=0;ZHJP80]YAV0P2gUFL0102hUVP0^IMY0;VGJ@2iUfT80;ZH
JPP0^IMY202gUFL80;RCIPP0^IAW0P2jV6X01P2iUfT0^9IX0;NEI`2fU6H0]I=U0;BBI0<0^IAW0P2j
UFP30;^FJ@P0]iEW00<0^IMY0;RFJ02gUFL00P2eTfD02`2gUFL0^9IX0;VGJ@2jV6X0^IMY0;NEI`2f
U6H0]I=U0;JDIP2gUFL0^9IX0080]YAT0`2eTf<30;BBHP80/Y1R0P2cTF<20;BBI0D0]I=U0`2fU6H2
0;NEI`060;NAJP2gTVP0]i9X0;NBIP2gTVD0]i=S0P2gTf420;JDIP@0]I=U0`2dTV@80;:@HPP0]99R
00T0/i5S0;BBI02eTfD0]I=U0;>AH`2aSf40[heO0:j<GP2eT6<00`2fTF@20;NBI@80^9=V202dTV@0
202eTF40]91P0;>?G`2bSUh0/hmO0;FAH@2gTf<0^9AT0`2eT6<30;B?HP80/hiQ202eTF440;:=H0@0
/hiQ00/0/HiH0;:>FP2dT5h0]I5Q0;F@I02dSfD0/XaU0;6;IP2`Reh0/HaO0;>>H@020;B?HP030;>>
H@2aS5l0/8]N00H0/8aL0P2aSEd80;:>GP040;NCH`2eTF40/hmO0;2<G080[h]K00D0/8aL0;6=G@2b
SF00/HaO0;2;GP020:n:G@030;2;GP2aS5l0/XeP00P0/XiN00H0/XmI0;:>FP2bSUX0/XiL0;:>GP2b
SF020;:=H@P0[heO0P2_RUd30;2;GP80/HaO0P2bSF00102/RUX0[H]K0;2>GP2bT6020;>AH@80/Y1P
0P2dSf830;>>H@<0/XeP0P2^SF020:n>H@80/8mR0P2aT6<00`2bSF00]8mR0;JAI0020;RCIP030;F@
H`2aS5l0[hYM0080]I5Q00@0]91P0;>?G`2bSUh0/HeM0P2`S5`01P2`ReH0/8]G0;2;E`2`RUT0/8YK
0;2:G@80/8UN202aS5l20:f8F`<0[XUL0`2_RUd0202]RET0[XYJ0;2<G02bSUh0/hmO0;:>GP2aSEd0
/8aL0P2bSUh20;6=G@80/8aL0P2_Re/30;:=H0<0/hiQ0P2dSf880;6<G`030;F@H`2dSf80/XeP00<0
/8]N00@0/HaO0;:=H02aS5l0/HaO0P2aSEd0102aSE/0/HeI0;6>F02aSUP80;>>H@80[heO00@0/8iP
0;6?H@2aSf40/8iP0P2_SEl20;6=G@80/8aL00@0[h]K0:j:FP2^RUX0[XYJ202aSEd30:j:EP030:n;
E`2`S5P0/8aH0080/8aH00H0/HeI0:j9G@2^REd0[XUL0:j:FP2^RUP20:j:EP080:j;E@2aSEd0/8aL
0:j:FP2]RET0[8QH0:f9F@2^RUX40:n;F`80[XYJ0`2]RET80:b8E0080:^8DP2/R5@0[HUE0:n;F@2_
Re/0[HQK0:b7F`2[QUX20:n9FP<0[XQI0`2]QeP20:j:FP<0[HUI0`2/R5P20:f9E@80[8QD0P2[Qe<2
0:Z6DPP0ZHEA00H0ZHI@0:V5D@2ZQU80ZXID0:Z6EP2[QUT20:^6FPP0ZXIB202ZQUH30:f5DP<0[8AA
0P2[Pe080:R4E0P0ZHA@00P0ZX5C0:^2E02ZQ5D0ZXIF0:V5E@2VQ5@0Xh=B0::2D@P0Z8AD202WPdl3
0:AoB`80YH1<102VPDd01P2XPdl0Yh9>0:J1C@2UP4`0Y7m;0:=nBP80XWe90`2TOd/20:F0C0<0YX5=
102WPe<20:J2DP@0YH5A0P2VPU820:N3D`80Z8AD0`2UOe001@2VP540Yh5B0:N1DP2WPE80Z89C00P0
Y7i?0`2UPDd20:B0C0<0Xgm;0`2QODd50:9nCP030:=oC`2ROTh0X7a<0080Wg];00H0X7a<0:9nCP2S
Odl0Xgm;0:9nBP2QODT209mkA`030:5mB@2ROTX0Xgm;00<0XWi>0P2QODd60:1lC080Wg];0`2NNTX3
0:5iAP030:1hA@2OMd@0WgM40080WWI300H0XG]<0:1jB`2ONDX0WWQ909egB02LMTL209]eAPH0X7M9
0P2OMTP20:1lB00409mkA`2NNTH0WGU509eiA@80W7Q4202NNTH309mkB`0;09ijBP2MNDT0WGU909ei
B@2LN4P0VgM709eiB@2PO4`0XWi>0:5mC@2ONd/00P2KMdL02@2IMDD0WGQ409mjAP2RODT0Y7m;0:=n
BP2QO4P0WGQ409]f@P0309eiB@0309ijBP2ONd/0Wg];0080X7a<00H0WW]509ijAP2NNTH0WWY809ij
BP2NND`209iiC@80WGM800@0W7I709]eAP2KMDH0VWA50P2ILd@809YfAP80V7M200<0VWI209]f@P2M
MD800P2NM4800`2OLd80VgE609]eAP0309YdA@<0VG=400<0UW9209Mc@`2HM4@00P2HM4@00`2FLT80
U71009=_?`0809IaA0<0UFm0:oooool002[ooooo0`2JL3h209]a?`<0W79000@0WW9109mc@P2OLd80
Wg=20P2PM4<20:5eA0P0WWA2202PM4<20:9gA0040:=hA@2TNDH0Y7U60:EjA`80YW]80P2RNDD20:5h
A080X7M30P2OMT880:1e@P0;0:1cBP2PLdT0XGA:0:9fB@2SMdP0YGU80:EjA`2VNdP0YWe50:ElA02S
NT@00P2RNDD01P2SNDL0YG];0:IlC02UO4P0Ygi:0:QoB`<0ZH1<00<0Z7m;0:MnBP2UO4P0202UNTD0
202YP4`0Z7m;0:MnBP2VODT0YGa80:AkA`2SNTH0XWU50P2WNd`0102WNdX0Yga90:MlB@2WO4L20:Ml
A@030:=hA@2TNDH0YW]80080Z7e:00<0YW]80:AiAP2SN4D00P2VNT/0102UNDX0Y7Q90:AhB@2SMdP2
0:9fA`030:f2C`2[P4d0Yga90080YGY700L0Yga90:^0C@2]PTl0[HA>0:b3C@2ZPD/0Z7m90080Ygi8
00@0Z7m90:V0BP2YP4X0Z7m90`2VODL00`2XOdT0ZX5;0:^2C0040:^2CP80[8=?0P2]Q5080:^1C`P0
[89B0P2[PTh20:Z1C@030:V0C02XOd/0Z7m;0080Ygi:00L0Z7m;0:V0C02ZPDd0Zh9>0:b3C`2]Q500
[XEA00<0ZGm?0P2ZP5030:^1D@P0[XEA00T0ZHE;0:Z6C02[QTl0[8MB0:f8D`2^RED0[hUH0;2:F@2Y
Q4l00P2ZQE000`2[QU40[8MB0:b7DP020:f8D`060:j3F02^PeH0[hAG0:n5E@2`QU@0/8MC0P2aR589
0:f8E0030;2;E`2^RED0[8MC0080ZXEA00X0ZhIB0:b7D`2^RED0/8]G0:n:EP2^RED0[HQD0:b7D`2[
QU80ZXEA0`2YQ5040:Z5D@80ZhIB00@0ZHA@0:R3C`2XPdl0Z8=?0P2WPTh20:J1C@80YH1<0P2TOd/3
0:=nBP050:9mB@2TOdX0XWe80:1kAP2NND@00P2LMd8209eh@`80WGQ400@0W7M309]f@P2JMD40VWE1
0P2IM40309Ma@P80UW110`2EKd00102EKd80U6i109A^@@2DKT4209=]@080TV`o0P2@K3`208m[>`<0
SVXj00L0SFTi095[?02AJc`0T6Xk08iX>@2<ISL0RfDf0080RF<d00H0R6Hf08MU=@27ICD0QV@d08ES
<`24HS8208=Q<@80PUlg0P21GSH03020GCD0Oe`d07mL=01nFc<0P5dc07mL<P1nFc40OEX`07aI;`1k
F2h0NUL]07UF;0<0MeP/101hFBd00`1iFRh0M5@[07AD:`0607AD:`P0Le8Y0P1]Cbd00`1/CR`0Jdd[
06Y<:P0206U;:@0506Q::01^D2`0K4hZ06Y<:01XBRH00P1WBBD206U;9`0306Y<:01SARH0HdHV00H0
HdHV00H0IDHZ06=5:@1SABT0H4DX05i59`1MARL205Y59P@0G4@R0P1MAB<205i690P0HDTW00<0Gd4W
0653:@1TAR`00P1UAbd01P1TAR`0HD<Y05m19`1M@200Gd8R06=69P80IDPX00@0HD@T05`o7`1H>a/0
H4<S0P1O@R801@1N@B40Gd8R0654901SARH0IDPX00P0GdHX0`1MAB<205i690<0GdLU0P1NAR8205e5
8@0405i68P1OAb<0HDTU069:9P80H4H[0`1NA2T0101PAR/0HTP]06=9;P1QBBL306189P80GdLU0P1N
AR@02`1UCB/0I4`Z069::01OAbD0GDDS05Y2801H@1h0EclM05M4901HABD0FTLW0080G4TY00<0FdPX
05Y79`1IARH00P1J?b@00`1I?b@0F40T05I1900205E2900305=2901<>A/0Dd0R0080FTLY00`0ET<U
054n801A?R00Dd0R05E49P1D@bD0Dd8T05918`1C@R@0E4<U05I59`1GARP805509P0704a39P1=@RH0
C44U04do901=?B<0CC`R04lk8P0204hj8@0804M17`16@200A3hN048k7P12>al0@c`R04@l9@15?BH2
04Lk8`80B3`T00@0BCdU04Xn9P1:?RH0BclW0`16?2<304Dk8P80A3XQ00<0@SXU044i9011>B@00P11
>B@3040h8`<0>C@P1@0j=B401P0n=b@0?CHS03`e8P0k=240>S<P03Tb7`80>34N200a<ah01P0`;AX0
<BhK034^6`0b;a`0<c0M03@a7P80=C8O00H0;S4L02la700`<Qd0<c8N03@a7P0g<Ql203Tb80<0<c0M
0P0d<Ah303Db7`80<C<N0`0`<Qd302la70<0;c0P0`0`<B42034b8P80;S0K00@0;c4L030b7@0b=1l0
<cDP0P0d=R400`0b=B00<C@O02lb7@0202ha700302lb7@0a=1l0<SDP0080<3<N00<0<S@O03@c7`0e
<Ql00P0h<b000`0i<R00>SPS03Xh8`0203Xh8`80>cTT0P0l>RD00`12>1d0@cTN04<i7P0204@j7`<0
AC/P00H0BC`L04Xm7@1;?Qh0BchN04`o7`1=@20204i18@0805168`1BAB<0DD@R05=48`1FARD0FTLW
05i9:P1PBb`2069:9P0;06599@1PB2@0GdLS0618901SBbL0IDdY06M?:`1RBb80I4dT06I?9P1XDBP0
0P1YDRT02`1XDBP0Ie0W06A=8@1ZDRH0KeL[079G;01bEB/0Le<Z07IE;01iF2l0NUX[0080Ne//00<0
O5`]07eM;P1nGRl00P1oGc003024H2h0Pel]089N;022GR`0Pel]08IR<029IC<0RVHd089T<P23IC<0
QVPf08QZ>080RF/i00@0R6Xh08MY=`2?KCl0Sfdo0P2>K3h0102=Jcd0S6Xl08aZ?02;JC/309A`?080
UG4m0`2FLSh409Qd@0@0Ug<o00H0VWI209]g@`2LN4@0WGU509ijAP2PO4P20:5mB@80Wga600<0X7e7
0:5nB02ROdT00P2SP4X01`2TPD/0YhA:0:N4BP2WQ4`0YhA>0:J3C@2VPTh00P2VPU001P2WPdl0Z8A@
0:R4D02ZQU80ZhMC0:b8E080[HUE102/R5@40:^7D`80[h]K0P2`S5`30;6=G@030;:>GP2bSUX0/HeI
0080/8aH00D0/HeI0;>?F`2eTEd0]i=O0;>@J0030;BAJ@80]I9Z0P2fTf/20;VDI`@0^9=V0P2gTVD2
0;NEI`80^9IX0`2iUfT:0;ZHJP@0^9IX102iUfT20;^IJ`<0^YQZ0`2iUfT80;ZHJP80]I=U0P2fU6H0
102gUFL0^9IX0;RFJ02iUfT80;ZHJPP0^IMY202gUFL80;RCIPP0^IAW0P2jV6X00`2iUfT0^9IX0;NE
I`020;FCI@040;BBI02jUFP0^YEX0;ZEJ080^iIY0`2lUfX80;NEI`030;VGJ@2hUVP0]iEW0080]I=U
00/0]iEW0;RFJ02iUfT0^YQZ0;VGJ@2gUFL0]YAV0;FCI@2fU6H0]iEW0;RFJ0020;JDI0<0]I=S0`2d
TV820;:@HP80/i5S0P2dTV@50;FCI@80]YAV0`2gUFL01P2gTFX0]i9X0;NBJ02gTVH0]i9U0;NCH`80
]i=Q0P2fU6H40;FCI@<0]99T202bT6880;BBHP80]99T0P2eTfD0102cTF<0/HmQ0:n=G`2]Red40;JA
I080]i9U0P2hTfH80;BBI0080;B@H02cSel0/XiN0;:>GP2cSel0]I5Q0;NCH`2hU6@30;F@H`<0]8mR
0P2cSV480;FAH@@0/hiQ102dSf802`2aSUP0/XmI0;B@GP2eTF40]I1T0;B>I`2bS6L0/H]W0;2;GP2a
S5l0/hiQ0080]8mR00@0/hiQ0;6<G`2`Reh0/8aL1@2aSEd:0;:>GP040;NCH`2eTF40/hmO0;2<G080
[h]K00D0/8aL0;6=G@2bSF00/HaO0;2;GP020:n:G@030;2;GP2aS5l0/XeP00P0]91P00H0/XmI0;:>
FP2bSUX0/XiL0;:>GP2bSF020;:=H@P0[heO0P2_RUd30;2;GP80/HaO0P2bSF00102/RUX0[H]K0;2>
GP2cTF420;BBHP030;>AH@2bT600]8mR0080]8mR0P2cSV430;:=H0@0/8mR102aT6<04@2aS5l0]8mR
0;NBI@2iU6L0^9=V0;F@H`2bSF00[hYM0;RDI02gTf<0]Y9R0;B@H02cSel0/HeM0;2<G02_Re/0/8]F
0080/8]G00<0/8YI0;2:F`2`RUd00P2`REh80;6<G`<0[HQK0P2^RE`30:n:G@040:b8F02^RUX0/8aL
0;:>GP80/hmO00@0/HeM0;2<G02bSUh0/XiN0P2aSEd20;2<G080[h]K0`2bSF020;>>H@<0]8mR202`
Reh00`2eT6<0]8mR0;:=H0030;2;GP070;6<G`2bSF00/HaO0;6<G`2aSEd0/HeK0;6=F@020;6>F003
0;6>EP2dSf80]8mR00H0]8mR00<0[H]M0:n=G`2aSf400P2cTF<00`2aSf40[heO0:f;G@020;6=G@80
/8aL00@0[h]K0:j:FP2^RUX0[HUI202aSEd0102/R5@0[HUE0:j:EP2_ReL20;2<F0030;6=F@2bSUX0
/XiJ0080[hYN00T0[XUL0:j:FP2^RUP0[XYF0:f9E@2]RU@0/HeM0;2<G02^RUX00`2/R5P00`2^RUX0
[h]K0:n;F`020:n;F`80[XYJ0`2]RET80:b8E0080:^8DP2/R5@0[HUE0:n;F@2_Re/0[HQK0:b7F`2[
QUX20:n9FP<0[XQI0`2]QeP20:j:FP<0[HUI0`2/R5P20:f:E080[8UC0P2[R5820:Z7D@P0ZHEA00H0
ZHI@0:V5D@2ZQU80ZXID0:Z6EP2[QUT20:^6FPP0Z8A@202ZQUH30:f5D@80[8A@0`2[Pdl80:R4E0P0
ZHA@00<0ZX5C0:^2E02ZQ5D00P2ZQUH00`2VQ5@0Xh=B0:61D0080:R4E0P0Yh=?0`2TOd/20:F0C0@0
YX5=0P2XPdl0102WPTh0YX5=0:AoB`2SOTX20:9mB@<0Y7m;0P2UP4`30:J1C@040:R3EP2WPUD0Yh9E
0:N2E@80YX5D0P2UP5<40:J2DP@0Yh=C00H0Xge>0:AnC`2UOe00YX1A0:N1DP2XPU<20:V3E0D0Y7i?
0`2SODh30:F1C@80Y81<0`2SOd/50:5mC@80XWi>00@0Xgm?0:9mD02QO4l0WgY=0P2MN4/01P2ONTd0
XGa?0:9mD02SOd/0XWi:0:5mB@80X7a800<0XGe90:9nBP2SOd/00`2SOdl20:9nCP@0XGe=0P2PO4`0
0`2ONd/0WWY:09ijBP0209ijBP<0XGU600<0X7Q509mgA02NMT<00P2NMT<02@2QNd`0X7Y;09miBP2N
N4T0WGM809afA`2KMDH0VWA509ieA`0309mfB0<0X7M900T0XGQ:0:5mB@2QODT0X7a809ijAP2MNDD0
W7Q409]g@`2JMT80202NNTH809ijBP0309]gA`2MNDT0X7a<0080XWi>00L0Wg];09]gA`2KMdL0V7A4
09iiA@2PNdL0Xgi:0080Y7m;00@0X7]709ag@`2JMD40VgM70P2LN4P00`2MNDT0WWY:09ijBP0209mk
B`0609ikA@2NNTH0WWY609ijB02NNTX0WWU<0P2NNDd209egB00409afA`2KMDH0VgE609YdA@80VG=4
202JMTH209Qg@P0309Yf@P2KMT80WGE20080WWA200<0Wg=209]eAP2KMDH00`2JM4D309UcA00309Ib
@P2GLd<0V7A40080V7A400<0UW9209A`@02CKcl01@2FLD@309MbA@<0U6ho:oooool002[ooooo0P2N
MCl00`2MM400WG=109ec@`0209aaA00409aaAP2PMT@0X7I409me@`80WWA200<0WG=109ab@02LLT00
0`2MLd4209id@P<0WgE300P0X7A30:5eA02RMTD0XgM60:9fA@2QMD@0Wg=209ib@@P0XgQ30P2QMT<2
0:1e@P@0WgA100<0XWQ60:5gA@2PMT@00P2OMD<00`2PMT@0XGM50:9hAP080:=hA@@0XGQ4102PMd<0
0`2QN4@0XWU50:AkA`030:ElB0060:AkA`2RNDD0XGQ40:^2CP2XOd/0Y7]70P2QN4@00`2TNdL0Z7m;
0:^2CP020:IlC0040:IlBP2VODT0YGa80:ElAP80YGa40`2WOTX00`2VODT0YGa80:AkA`020:AkA`0;
0:9gC02SN4/0YGY=0:IlC02VO4X0YGa80:=jA02RND<0XWM40:AiAP2VNdP00P2WO4T00`2VNdP0Y7U6
0:9gA0030:ImB@<0Ygi:0P2XOd/20:^2CP80ZX5=00<0ZH1<0:QoB`2XOd/0102WOTX20:QoB`d0ZH1<
0P2ZPDd30:^2CP030:b3C`2[PDl0Zh5?00H0Zh5?00<0ZX1>0:UoC@2YOdd00P2YOdd30:QnC0030:V0
C02ZPDd0Zh9>0080[8=?00@0Zh9>0:Z1C@2YP4`0YX5=0P2WPTh00`2XPdl0ZHA@0:Z5D@050:^6DP03
0:b7D`2]R5@0[XUE0080[XUE202^QE480:n5D`80/8IF00@0/8ID0;27D`2`Qe<0/8MA0P2`Qdl90:f8
E080ZhIB0P2/Qe<30:f8E0040:j9E@2[QU80ZhIB0:^6DP80ZXEA0`2YQ5080:f3D@80ZXE@0`2YQ4l3
0:R3CP040:J1C02UP4/0YH1;0:F0B`80Y7m:0P2SOTT01P2UP4`0Y7m;0:=nBP2RODT0XGa809mjAP80
WWU500<0VWE009]f@@2KMT400`2KMT4209ag@P0309QbA@2ILdH0VgE80080W7I900<0VWA709QbA@2G
LD@00`2GLSh209Ia?@<0UG0l0P2DKc/0102CKSX0TVdi091[=`2?JSH208iY=@0809AY=02BJC<0TVTe
091X=@2=IcH0RfLg08QV=P28ISP208AT<`80Pf<b0`22HS400`21HC00PUh^089N;P06089N;P<0PE`_
0P20Fbh307mJ;@<0NUD[0`1iE2X207QC:@0407IF;@1eEB`0MED/07EE;080M5@[0P1cDbX9079B:`0:
071@:@1^CRL0Jd/T06];901/C2D0KThW071@:@1]DB`0JdlZ06U=:080Id/V00L0J4`W06U=:01YCBP0
JThY06M::01UB2H0I4LU00<0HTDS00d0HdHT06A79@1Q@BP0HD<Y06=5:`1RAb`0H4H[05e5:@1IA2L0
F4<V05Y2801K@b40GDDS0080GdLU00<0GTHT05a48P1K@b400P1R@bL206=4:00406A5:@1UARX0IDHZ
06I7:`<0HDX[00D0H4TZ05i7:01KA2D0Ed0Q05Dn7`030659;@80H4P/0`1OAb/205a1900405e29@1N
@bH0H4DX0656:@80HTLZ0P1QBR/01P1PBBX0GTLX05e69`1LABH0Fd@U05Y390P0GT<X00H0FD4U05Y2
9P1J@RH0Fd<W05a4:01MABT205i6:PP0GTLX00<0FTLW05]8:01MBRX00P1NBb/0301MBRX0FdPX05Y7
9`1PCBd0Gd`/05i;:`1KB2P0FDHV05I38`1E@R80E44Q05=49@80E4<U00<0ET<U05M29@1J@RH00P1J
@RH0201M@b`0G4@/05]3:`1H@RX0ET8Y05919`1A@BL0D40V201C@RP80590:0P0CCdT2@18?28204Xn
9080BCdS1018?28304Dk8P80A3XQ0`13>B0204M09P0404Ho9@15?R@0AChT04@m8`80@c`R0P12>RD6
044i90P0?STS0P0m=B0303`d7`<0>c<N00<0>CPT03Lf8P0c<Qh00P0_;QX00`0`;a/0<c8N03Dd8005
03Db7`<0=S<P0P0c=B00100b=1l0<C<N034c7P0`<Qd202la700403Dg8P0c=B00<C<N02la7080;BlJ
0P0^<1/00`0a;Q/0<RlL03@a7P0303Hc800303@a7P0c<1d0<3@U00L0<3@U0P0_=al00`0a=Ql0<cLP
03@f800203Lf8@0303Pf8@0e=280=C@R00H0=C@R00H0=3HP03Dg8@0g=R40>CLR03`g8`0m>2@203lh
9@0603de7P0n=Ql0?SHO03lg8010>240@CTR0P12>R<204@i8`0604Dk8P16?240AchQ04Po8019@240
BT4P0P1AA2@00`1CA2D0E4<U05M49P0205Q39P0905]39`1F@b<0Ed@T05Q5901JAbH0GD/W05m=9`1P
CRH0HDlW0080HD/V00L0HddX06E?:P1WDB`0Ie4/06I@:`1UCbX0I4hY0080JddW0`1/CRP306e?:@04
06iB8P1`E2@0LeLW07IJ:P<0N5`/00@0Me/[07QJ:01jG2X0O5h/0`1nH2h03P1lGR`0Ned[085N>021
GSH0PUlg08=P=P25HcH0QV@f08MU=@28ISH0PFDc089V=024J3H0QVXh0P27JcT208IZ>080SVXf1P2?
JcL2099^>P0609A`?02ELCd0Ug<o09Ue@@2JMT80VgM30P2LM440102JMD40VWI209Yf@P2IN4<209Qi
@`0309mkA`2PO4P0XWi:00<0Y81<0P2ROTX20:1mA@070:9oB@2SOd/0YH5?0:J2DP2XQ5@0Z8=F0:F2
C0030:J3C@80YhA>0P2XQDl20:V5D@040:Z6DP2[Qe<0[8QD0:f9E@80[XYF202/R5@02`2/R5P0[HUI
0:j:FP2aSEd0/hmO0;FAH@2gTf<0^9AT0;6=G@2bSUh0]91P0080]I5Q00<0]91P0;:>GP2aSEd0202e
TfD01P2eTF40]Y9R0;NCH`2hU6@0^YIV0;bHJ080_IUY0`2gTf<20;RDI0<0^IEU2@2gUFL01P2jV6X0
^IMY0;VGJ@2hUVP0]iEW0;JDIP80]I=U202jV6X20;ZIIP030;ZHJ02jV6X0^YQ[0080^YM]00@0^YM_
0;VGJ@2iUfT0^IMY0`2jV6X20;^IJ`080;jJJP2mVFT0_9QX0;^GI`2jUVH0^IEU0;RDI02gTf<80;NE
I`@0^iIY102jUFP00`2kUVT0^YEX0;RCIP020;NBI@030;RCIP2jUFP0^iIY00P0^IAW202hTfH01P2e
TVP0]Y=Y0;REJ`2jUfd0^iQ^0;ZGK@80^II/0P2kUFh20;ZDK@040;VCK02hTV/0^99[0;NAJPP0]iEW
0`2hUVP30;NEI`80]YAV0P2hUVH0102gUFD0]YAT0;JDI02eTf<20;BBHP80]91P0P2eTF430;JBHP03
0;NCH`2dTV80]99R0080]99R0P2eTf<20;JDI0P0]Y5T2@2dSf80102gTVD0]Y5T0;JAI02fTF@20;F@
H`80]8mR0`2eT6<50;B?HP040;FCI@2dTV@0]99T0;BBI080/i5S0P2bT6880;JBHP080;JEG`2dTeh0
/I1K0:j=FP2^S5`0/HmQ0;BBI@2fU6L20;6<G`090;:=H02dSf80]I1S0;JAI02gTVD0^9=V0;VEI@2g
Tf<0]I5Q0080/hmO00<0]91P0;FAH@2gTf<0202gTVH0402cSV40/XeP0;6<G`2`Reh0/HaO0;>>H@2f
TF@0]i9U0;6;I02aS680/hiT0;>>HP2cSV40/HeM0:n;F@2^RUP20;2:H`80/H]T00@0/XaU0;>=IP2c
SFH0]8iW202]RET40;6=G@80/XiN0P2cSel30:n<I0<0/8eU0P2aSVH01P2^RE`0[hYM0;2;GP2aS5l0
/XeP0;B?HP80]I1S202cSel80;6<G`80/hiR0P2bSF440;6<H0T0/HeM0P2_RUd20;2;GP80/HaO0P2b
SF030;6=G@<0/XiN0P2cSel80;B@H080]i=S00@0]I5Q0;B@H02bSUh0/HeM0P2_Re/20;NCH`030;JB
HP2eTF40]91P0080/XiN00<0/HeM0;2<G02`S5`00P2`S5`20:n;F`80[XYJ202`Rel20;6=G@80/8aL
00L0[h]K0:j:FP2^RUX0[HUI0:f8F`2^RE`0/8]N0080/HaO00<0/8]N0:j9G02]R5/0202aSEd80;:<
G@<0/HeM0`2bSUh:0;>?G`P0/XiN00P0]i=S0;JBHP2cSel0/HeM0;2<G02aSEd0/XiN0;>?G`80]I5Q
00@0]91P0;>?G`2cSel0/XiN0P2aSEd80:n:G@<0ZXQH1@2[RET20:b8F080[HUI0P2^RUX00`2_Re/0
/8aL0;2<G0090;2<G00=0:j:FP2]RET0[8QH0:f9F@2^RUX0/8aL0;:>GP2`SEL0/8aH0:n;E`2^RUP0
[XYJ0:f8F`020:b7F`80[XYJ0`2]RET60:b8F0<0[HUI0P2^RUX20;6<G`80/8]N00X0[hYM0:j9G02^
RE`0[HQK0:n;F`2^RUX0[8QH0:Z6EP2YQED0ZXIF0P2[QeL20:R2D`80ZH=D0`2ZQ5D00`2[QEH0ZXE>
0:Z5CP060:Z5CP080:b9D`2/R5@0ZhMC0:^7E@2ZQUH0ZHAG0:V4F02XPeL80:Z5D@80ZhMC00@0ZXIB
0:V5D@2YQE40Z8A@0P2WPdl80:V4D0030:J2CP2WPdl0ZXIB0080ZhMC00<0ZXIB0:V5D@2WPdl0202V
PTh0102ZQU80ZHEA0:V5D@2XQ5020:N3C`80YX9>00P0ZXE@0:V4D02XPdl0Yh5@0:N1DP2XPUD0ZX=H
0:^4F@<0YX9B0`2UPE420:B0D0050:N2B`2VPDX0YH1;0:AoB`2TOTd00P2UOe000`2VP540Yh5D0:R5
C`020:N4CP030:J3C@2UPT`0Y85;0080Xh1:0P2RODT20:5lB0030:=nBP2UP4`0Yh9>00T0ZHA@202X
Q5@00`2VPDd0Yh9>0:R3C`020:R3C`030:J1C@2TOd/0Xgi:00P0YX9B202SOTX80:AnD@@0XGe90P2P
O4P209mkA`030:AoDP2ROE00X7]>00<0WWU<00D0X7]>0:5lC`2OND`0X7Y=0:5kCP020:9lC`030:1j
C@2NN4/0WGM:00P0WWY600P0Wg];0:1lC02QODd0XGe=09mkB`2MNDT0VWI609QdA080X7]60`2ONTD3
09iiA0<0XGe900<0X7a809mkA`2NNTH00P2NNTH20:>0BP030:9oB@2QOTP0X7e70080WW]500@0WGY4
0:9nCP2QODd0XGe=0P2PO4`309mkB`80VgM700H0W7Q809eiB@2NNTX0Wg];0:1lC02QODd20:1kA`<0
XGa8102RODT50:5lB0<0XWe900<0X7]>09mjC@2NND`00P2MN4/04`2ONTd0XGa?0:9mD02PO4P0Wg]7
09eiA@2LN4@0VgM309eiA@2ONdL0X7a809ag@`2KMT80VWE109Ud@02HLcl0Ug8n09Ia?@2EL3`00`2F
M4@309MeA@80V7I60`2MMdP309afA`80VgE60P2IMDD209QdA080Ug=30P2FLT80202GLd<0V7A409Ue
A@2JMTH0VGE509QdA02FLT80U710202ELD43099/?B_ooooo000Zooooo`80WWDo00<0WGA009ec@@2M
Ld<00P2LLD@0102LLDH0X7I409me@`2OMD<209id@P80WG=100<0W79009id@P2NM4801P2NM480202N
LT40Wg=20:1d@`2QMD@0XWI50:5eA02OLd80WW91202SN4<20:9gA0<0XGI30`2PMD800`2RN4H0XGM5
0:1fA00209id@P030:1fA02QMdD0XWQ600P0XgQ51@2QN4@30:1g@`030:5hA02RNDD0Y7]700<0YGa8
00H0Y7]70:9iA@2QN4@0Z7m;0:ImB@2TNdL20:9iA@030:AkA`2VODT0Z7m;0080YWa<00@0YWa:0:El
B02UO4P0YGa60P2UO4@20:MnBP80YWe90P2UO4P20:AkA`0;0:9gC02SN4/0YGY=0:IlC02VO4X0YGa8
0:=jA02RND<0Y7U60:EjA`2WO4T00P2XODX00`2WO4T0YGY70:AiAP030:ImB@<0Ygi:0P2XOd/20:^2
CP80ZX5=00@0ZH1<0:QoB`2XOd/0Z7m;0`2WOTX20:QoB`d0ZH1<0P2ZPDd40:^2CPP0Zh5?00@0[89@
0:^1C`2[PDl0ZX1>0P2YOdd20:QnC0030:V0C02ZPDd0Zh9>0080[HA@00@0Zh9>0:Z1C@2YP4`0YX5=
0P2WPTh00`2XPdl0ZHA@0:Z5D@050:^6DP030:b7D`2]R5@0[HQD0080[XUE202^QE480:n5D`80/8IF
00@0/8ID0;27D`2`Qe<0/8MA0P2`Qdl90:f8E080ZhIB0P2/Qe<40:f8E0<0ZhIB0`2ZQE420:V4D0P0
[H=A0`2ZQE020:V4C`<0Z8=>0P2WPTd20:J1C080YH1;0P2TOdX20:AoB`030:=nBP2RODT0XGa800<0
X7]70`2KMT4509ag@P0309UcA02JM4D0VgE60080W7I700<0VWA509UcA02GLD800`2GLSh309Ia?@<0
UG0l00D0U6lk09=^>P2BKCT0TF`h091[=`0208mZ=P0809AY=02CJS@0TVTe091X=@2=IcH0S6Ph08UW
=`28ISP308EU=080Q6@c0`23Hc8208EQ<@80Q60`0P23Gbl2089N;P04089M<021G2l0PE`_085L;`80
P5/^0P1oFRd0101mF2h0O5L]07aG;@1kER`207YE:`80NE@Z0`1fERd207EE;0<0M5@[201bDR/0101a
DBX0L50Y06m?:01^CRL206e=9P0806i>9`1_CbP0K50[06Y>:@1YCBP0Id/V06I:9@1WBbH206Q<9`04
06U=:01WBRP0ITTW06A79@80HTDS00h0HdHT06A79@1UB2H0HT<W0694:01SABT0HTLZ0617:@1NAbP0
FTDV05U49@1K@b40G4@R05i69080GdLU00<0GTHT05e58`1LA2800P1P@RH206539`80HT@X0P1SABT0
0`1KA2D0G4DV05i7:00205m8:@0405i7:01LABH0Fd@U0618;0<0GdL[0P1NARX205e5:@80G44T00H0
GD8U05i39P1OA2L0H4DX0656:@1RAbX20619:P80GdPY00@0GTLX05e69`1LABH0G4DV201OA2T405]3
9`@0G4@X201NAbP00`1KB2P0G4TY05e::P0205i;:`0305e::P1LBBT0FdPX0080Gd`/00H0GDXZ05]8
:01IARH0Ed@T05E28P1D@B4205A39@80ET<U0P1G@RD205Y29P0605e3;01K@b/0FT8Z05M1:@1E@BP0
DT4W0P1@@2H805=2:0P0DClW201=?B@904Pl8P80BShT0P19?B<304Pl8P0404Lk8@15>b80AC/R04Dk
8P80A3XQ0`13>B0304Dn900304@m8`13?280@c`R0080@S/Q1@10>2<3044i90P0?STS0`0m=B0203`d
7`<0>c<N00<0>3LS03He8@0b<Ad00P0`;a/00`0a<1`0=3<O03He8@0603Db7`80=S<P0`0b=1l2034c
7P<0<38M00@0=3HQ03<e800a<ah0;c4L0P0];aX01@0^<1/0;c4L034^6`0b;a`0=34N0080=S<P00<0
=C8O03@a7P0c<1d0200_<b801P0^=Qh0<CHO034f7`0b=Ql0=3HP03He8080>3HQ200e=28203@f7P03
03Lg7`0i=b00?3LQ0080?SPR00L0@3PS03hf7`0o=b00?cLP040h8@11>B80@SXS0080@c/T00H0ASXT
04Hj8P17>b<0B3`R04Tn8P1;@28204a18@0@05958`1CA2<0E4DT05E5901HABD0FD@U05]49@1LABH0
Ed@T05Q59@1IARD0FdTU05e;9@1OCBD0HDlW069A9P80HT`U00L0I4hW06I@:@1WDBX0J58[06MA:P1V
D2T0IDlX0080K4hX0P1]CbT306i@:P0506mA:`1`E2@0LUHV07EI:@1gFb/00`1hG2`0101gFb/0NU`Z
07]M:`1mGbd207mQ;`0?07iP;P1mGbd0O5h/085N=P22GcL0Pf0f08AR=@26I3H0QfDe08QV=P29J3D0
PfDc08EW=@27JCL0RF/i0080RV`j00<0RF/i08QZ>02?JcL00`2?JcL4091/>080U70l00@0UG4m09Ib
?P2HM400VGE10P2JMT801P2LM440WGE209]f@P2JMT80VgM309Uh@`80VGY400<0WWY60:1lB02QODT0
0`2SOd/02P2ROTX0XGe90:1mA@2QOTH0XWm90:=oB`2UPDl0Yh=C0:R4E02XPeH30:J3C@80YhA>0`2X
QDl01P2YQE40ZXIB0:Z6DP2[Qe<0[8QD0:f9E@80[XYF202]RED01P2]RET0[XYJ0:n;F`2aSEd0/hmO
0;B@H080]Y9R00<0/XiN0;>?G`2dT6000P2eTF400`2dT600/hmO0;:>GP080;FCI@80]i=S00<0^9AT
0;VEI@2jUVH00P2kUfL00`2lV6P0]i=S0;NCH`030;RDI0<0^IEU2@2gUFL30;RFJ0<0]iEW0P2fU6H8
0;ZHJP80^YUV00<0^YQX0;ZHJP2jV6/00P2jUfd0102jUfl0^IMY0;VGJ@2iUfT30;ZHJP80^iU[0P2m
VFT0102lV6P0^iMW0;ZFIP2iUFD20;RDI0P0]iEW1@2jUFP40;^FJ@070;ZEJ02hTfH0]i9U0;NBI@2h
TfH0^YEX0;^FJ@080;VDI`P0^9=V00P0]I9X0;JCJ@2hUF/0^YM]0;^HKP2jUfd0^II/0;REJ`80^iI/
0P2jUF/0102iU6X0^9=Y0;RCJ@2hTfT80;NEI`<0^9IX0`2gUFL20;JDIP80^9IV00@0]iEU0;JDI02f
U6@0]I=S0P2dTV820;B@H080]I5Q102fTV80102cTF40]99R0;BBHP2dTV820;FCH`80]YAT202fTF@9
0;B?HP@0]Y5T0P2eT6<20;B?HP80]I1S1P2dSf840;BBI080/i5S0P2bT6880;JBHP080;JEG`2dTeh0
/I1K0:n>F`2_SEd0/HmQ0;BBI@2fU6L20;:=H0040;>>H@2dSf80]I1S0;F@H`80]Y5T00P0^IEU0;NC
H`2eTF40]91P0;>?G`2dT600]I5Q0;JBHPP0]Y5U00<0/hiQ0;:=H02aS5l00P2aS5l02`2cSV40]I1S
0;NBI@2aRf@0/XeS0;>>I02dSf<0]8mR0;:>GP2`S5X0[h]I00<0/8]Q00<0/HaR0;:=H`2bSF<00P2c
SV@80:n;F`040;2<G02aSEd0/HeM0;6=G@80/XiN0P2cSel30:n<HP<0/8eS0P2aSV@20;2;GP80/HaO
00@0/XeP0;>>H@2dSf80]8mR202cSel80;6<G`80/hiR0P2bSF430;6<H0030;2;G`2aSEd0/HeM00L0
/HeM0P2_RUd20;2;GP80/HaO0P2bSF030;6=G@<0/XiN0P2cSel80;B@H0040;JBHP2eTF40]91P0;B@
H080/XiN00T0/HeM0;2<G02gTf<0]i=S0;JBHP2eTF40]91P0;>?G`2bSUh00P2aSEd30;2<G080[h]K
0P2^RUX80;2;G`80/HeM0P2`S5`01`2_Re/0[XYJ0:j:FP2^RUX0[HQK0:j9G02`Reh00P2aS5l00`2`
Reh0[XUL0:f8F`080;6=G@P0/XaM0`2aSEd30;:>GPX0/hmO202bSUh00`2fTV80]I5Q0;>?G`030;6=
G@040;:>GP2cSel0]91P0;B@H080/hmO0P2bSUh20;6=G@P0[hYM0P2ZR5P60:^9F@040:^7E`2/R5P0
[8QH0:f9F@80[XYJ00<0[h]K0;2<G02`S5`0202_Re/02@2^RUX0[HUI0:b8F02[QeL0[8QH0:f9F@2_
Re/0/HeM0:n<EP020:n;E`030:j:F02^RUX0[HQK0080[HQL0`2^RUX20:f9F@H0[8QH0`2]RET20:j:
FP030;6<G`2`Reh0/8]N0080[hYM0P2^RE`02@2]R5/0[h]K0:j:FP2/R5P0ZXIF0:V5E@2ZQUH0ZhMG
0:b8F0020:V3E080ZXAE0P2[QEH20:b6E`P0ZXE>00H0[8UC0:b8E02[Qe<0ZhME0:Z6EP2YQ5L20:V4
F0P0ZXEA00<0ZhMC0:Z6DP2ZQU800P2YQE420:R4D0030:N3C`2YQ500ZHA@00H0ZHA@00<0Yh=?0:R4
D02ZQU800P2[Qe<00`2ZQU80ZHEA0:R4D0080:N3C`<0ZHEA00<0Z8A@0:N3C`2WPdl00P2VPTh0202Z
QE00ZHA@0:R3C`2WPE00Yh5B0:R2E@2ZPeP0ZhAI0`2VPU830:F1D@80Y81@00D0Z8=<0:N2B`2VPD`0
YH1<0:EoCP020:J0D@030:N1DP2XPUD0YX==0080YX==0`2UPT`20:B1B`070:=nBP2RODT0XWe90:9m
B@2SOTX0YH1<0:N2CP090:V4D0P0Z8AD00<0YX5=0:N2CP2XPdl00P2XPdl00`2VPDd0Y7m;0:=nBP08
0:F1D@P0Xgi:202TOTl0102ROTX0XGe90:5mB@2QODT20:1lB080Wg]700<0XWi>0:5mC@2PO4`00P2N
NTX01P2ONd/0X7a<0:5mC@2ONDX0X7Y;0:5kC080XWa=00<0X7Y;09ihB@2MMdP0202NNTH0202ONd/0
X7a<0:5mC@2QODd0X7a<09eiB@2KMdL0VGE50P2PNdL309mjAP<0WWU50P2PO4P209mkA`0509ijAP2M
NDD0WGU509eiA@2SOd/00P2ROTX01@2QODT0Wg]709ijAP2NNTH0WGU500<0XGe=0P2PO4`309mkB`80
VgM700@0W7Q809eiB@2NNTX0Wg];0P2PO4`20:1kA`<0XGa8102RODT80:5lB00309mkB`2NNTX0WGU9
0080WGU900/0Wg];0:5mC@2SOdl0XGe90:1lB02NNTH0W7Q409]g@`2LN4@0WGU509ijAP0209]f@P04
09Ye@@2IM400V7<o09Mb?P80UW4m0`2FM4@309MeA@80V7I60`2MMdP209afA`<0VgE60P2IMDD209Qd
A080Ug=30P2FLT800`2GLd<0V7A409UeA@0209UeA@0309Mc@`2FLT80U71000P0UG510`2CKCh[oooo
o`00:_ooool209ie?`0309ed@02MLd40WG=30080W75400@0W75609me@`2OMD<0WgE30P2NM48309ec
@@80X7I400@0WgE309id@P2NM480WG=10P2LLT000`2JKSd0W70o09ib@@030:1d@`80Wg=2202RMd@3
0:=hA@<0XWM40P2QMT<00`2RN4H0XGM509me@`0209id@P0309me@`2QMdD0XWQ600P0XWM4202QN4@2
0:9iA@D0Y7]70P2RNDD20:AkA`@0XgY60P2TNdL20:EkB`040:EkB@2UO4P0YGa80:ElAP80YGa400@0
Ygi:0:ImB@2VODT0YWe90`2UO4P0302TNdL0XgQ=0:AiC02UNTd0YWa<0:IlBP2UO4P0Y7]50:=jA02V
NdP0Yga90:QmBP80ZGi;00<0Z7e:0:MlB@2VNdP00`2VODT30:MnBP80Z7m;0`2ZPDd30:V0C080Z7m;
0`2WOTX20:QoB`h0ZH1<0P2ZPDd30:^2CPP0Zh5?00H0[hEC0:j4DP2]Pe40[89@0:^1C`2YOdd20:Qn
C0030:V0C02ZPDd0[8=?0080[HA@00@0[8=?0:Z1C@2YP4`0YX5=0P2WPTh00`2XPdl0ZHA@0:Z5D@05
0:^6DP80[8MC0`2]R5@80:j5D@P0[hEC0P2`QUH0102`QU@0/8MC0;27D`2`Qe420;27C`T0[HQD0`2[
QU820:b7D`<0[HQD0P2/Qe<20:^6DP<0ZXEA00<0ZHA@0:j4DP2^Q5801P2^Q580102[QU40ZXE@0:Z5
D02ZQE020:V4C`D0Z8=>0P2WPTd30:J1C0<0Xgi:1@2RODT809eh@`0809YdA@2KMDH0W7I709afA`2K
MDH0VWA509UcA02HLT<209Qc?`80Ug8n0`2FLCd309E`?00309A_>`2CKSX0TVdi0080TF`h00T0T6/g
09EZ=@2DJcD0TfXf095Y=P2>J3L0SFTi08YX>02:J3X00P29IcL208QV=P<0QfDe00L0QV@d08UU=@29
ICD0R6@d08MS<`25HC40Q60`0080Pel_00@0Peha089M<022GC00PUd`0P21G2l2081K;P80P5/a00@0
OeX`07iI;`1mF2h0NeH/0P1jEB/307MG;P80MUH]0`1eEB`807=C;080L50Y0`1aDBX01P1`D2T0KThW
06e=9P1/CRX0JddY06U;9`<0J4XV0`1YBbL00`1XBbT0ITTW06E89P0306=6900:06A79@1UB2H0I4DY
06=5:@1TARX0HTLZ0658:P1OB2T0FdHW05Y59P80GDDS00H0GTHT05m79@1OAbD0GTHT05e58`1LA284
05m19@80H48V0P1Q@bL01@1F?b00F44R05]49@1NAbP0H4TZ0080HDX[00@0H4TZ05e5:@1MABT0GDDY
0P1LA2P305]39`80Fd8T00<0G4<U05e49P1NABL00P1OARP00`1PAbT0GdPY05m8:@0305m8:@<0GTLX
201OABX305a4:0<0Fd<W0P1J@RH805e69`0305]8:01LBBT0GT/[0080Gd`/00/0GT/[05a9:@1KB2P0
GT/[05e::P1LBBT0FTLW05U69P1GA2@0ET<S05E28P0605I39@80Ed8U00H0Fd4Z05Y2:P1I@BT0Ed4Y
05E1:01B@BL205109PP0DT4W201A?bL804`l8`T0B3`R0`19?B<204Pl8P<0Ac/Q0`15>b8204@j8@<0
@cTP0`13?282048k8@<0@CXP0P0m=B0203hf8@0403lg8P10>2<0@3PS044i90P0?STS00@0?SHQ03de
800m=B00?CDP0P0l=1l203/c7P0303Ld8@0f<b00<c0M0080<RlL00<0=34N03Ld8@0i=R<0200e<Ql3
030b7@80<C<N0`0b=1l01P0d=R40<S@O030b7@0^<1/0;BlJ02h`6`80;c4L0P0b;a`00`0d<Ah0=C8O
03Hc800203Db7`0303@a7P0_<R40;c8Q00H0;c8Q0P0`=Ah00`0a=Ah0<cDO03Dd7`0203Le800303Td
800f<b00=S<P00H0=S<P0P0f=Qh00`0h=Ql0>cHP03dg8@0203lg8P07048g8`12>1l0@cTP04<i8014
>R40AC/R04Hl8`0204Lm900804Lk8`18?2@0BCdS04Xo8`1<@B<0CD8R04i48@1?AB8205E69@0305I6
9@1IARH0FTDV0080GDHW00T0GTDW05U69@1JAbH0FdTU05e;9@1OCBL0HDlW069A9P1SDRL00P1VCRP0
0`1WCbT0J50Z06UA:`0206YB;00406UA:`1XD2X0KU4Y06iA:@80Ke8Z0`1`Db/01P1aE2`0M5PX07EI
:@1gFb/0N5`/07UM;@80N5`/00@0Me/[07aN;01mGbd0OV0^0`20HS0207mQ;`0<08=P>023H3H0Q64g
08IT=`27ICL0R6Hf08UX=@2:JCH0Q6Hd08IX=P28JSP0RV`j0P2;KC/00`2:K3X0RF/i091/>002091/
>080TFdi0`2BKSX00`2FLSh0Ug<o09Mc?`0209Qd@0<0VGE100H0WGE209if@`2LMd<0VgM309ahA02J
ND@209YkA@0A09ijAP2ONdL0XGe90:9nBP2SOd/0XWi:0:5mB@2PO4P0XGi60:9oA`2SP4X0Y81<0:F1
C`2WPe<0Z8AD0:R3EP2VPdd00`2WQ4h20:R5C`80ZHI@0P2ZQU80102[Qe<0[8QD0:f9E@2]RED20:j:
EPP0[h]G0P2_Re/0102`S5`0/HeM0;:>GP2cSel20;B@H0030;>?G`2dT600]I5Q00<0]I5Q00<0]91P
0;>?G`2eTfD01`2eTfD80;VEI@040;NCH`2hU6@0^9AT0;RDI080^IEU0P2jUVH90;RFJ080]YAV0`2g
UFL30;RFJ0P0^IMY0P2jVFH00`2jV6P0^YQZ0;ZHJ`020;ZGK@040;ZGK`2iUfT0^IMY0;VGJ@<0^YQZ
0P2kVF/01@2mVFT0_9QX0;bHJ02kUfL0^YIV0080^IEU00<0^9AT0;NEI`2gUFL01P2gUFL20;RCIP04
0;VDI`2jUFP0^YEX0;^FJ@80_9MZ00<0^iIY0;ZEJ02iU6L00P2hTfH00`2iU6L0^YEX0;^FJ@080;ZE
J0P0^IAW00P0]Y=Y0;NDJP2iUV`0^YM]0;^HKP2jUfd0^II/0;REJ`<0^YE[0`2iU6X20;RCJ@P0]iEW
0`2hUVP30;NEI`80]YAV0P2hUVH0102gUFD0]YAT0;JDI02eTf<20;BBHP<0]91P0P2eTF430;JBHP<0
/i5Q0P2dTV830;FCH`P0]Y5T2@2dSf830;JAI080]I1S2`2dSf830;BBI080/i5S0`2bT6880;JBHP08
0;FDGP2dTeh0/I1K0:n>F`2_SEd0/HmQ0;BBI@2eTfH70;B?HP040;F@H`2hU6@0]i=S0;JBHP<0]91P
00<0]I5Q0;JBHP2dSf801`2dSf820;>>H@<0/XeP00/0/hiQ0;B?HP2eT6<0/heV0;>>I02eT6H0]I1T
0;F@H`2cSel0/HeK0;2<FP040;2;H@80/HaR0P2bSF<;0;2<G080/HeM0`2bSUh30:n<HP<0/8eS0P2a
SV@00`2aS5l0/XeP0;:=H0050;:=H0P0/XiN202aS5l30;:=H080/HaO0`2`Reh90;6=G@80[hYM0P2`
Reh20;6<G`80/XeP0`2aSEd30;:>GP80/hmO202dT6080;>?G`060;NCH`2fTV80]Y9R0;FAH@2dT600
/hmO0P2bSUh30;6=G@80/8aL0`2_Re/80;2;GP<0/8aL0`2_Re/20:j:FP030:j9G02_RUd0/8]N0080
/HaO00<0/8]N0:n:G@2^RE`0202aSEd80;:<G@<0/HeM0`2bSUh20;>?Ga00/XiN00<0]I5Q0;B@H02c
Sel00`2aSEd0102bSUh0/hmO0;>?G`2cSel30;:>GP<0/HeM202_RUd80:f9F@80ZhMG00@0[8QH0:f9
F@2^RUX0[XYJ0P2_Re/00`2`S5`0[HUI0:f9F@060:f9F@060:b8F02[QeL0ZhMG0:Z6EP2[QeL0[8QH
0P2^RUX01P2]RU@0[HUE0:f9E@2^RUP0[XYJ0:n:G@80[hYN00@0[h]K0:j:FP2^RUX0[XYJ0P2]RET5
0:b8F0<0[HUI0P2^RUX20;2;GP80[hYM102^RE`0202^RUX0[HUI0:^7E`2ZQUH0ZHEE0:Z6EP2[QeL0
[8QH0`2[QEH20:b6E`<0[HMH202ZQE001P2[R580ZhMC0:^7D`2ZQU@0ZXIF0:Z5F080ZHAH202ZQE43
0:Z6DP80ZHEA0`2XQ5080:V4D0030:R4D02YQE40ZXIB0080ZXIB00<0ZHEA0:R4D02XQ500202XQ502
0:V5D@<0Z8A@0`2WPdl0202ZQE00ZHA@0:R3C`2VP4l0YX1A0:N1E02YPUL0ZX=H0`2VPU830:F1D@80
Y81@00D0ZHA=0:R3C02WPTd0YX5=0:J0C`020:N1DP040:R2D`2YPeH0Y85;0:B1B`<0YH9<0`2VPdd0
1`2TOd/0Xgi:0:9mB@2RODT0Xgi:0:F0C02WPTh02@2XPdl80:N3D`80YX5=0`2XPdl00`2VPDd0YH1<
0:=nBP080:=oC`P0Xgi:202TOTl30:9nBP80XGe90`2PO4P20:1lC00909mkB`2NNTX0Wg];0:1lC02Q
ODd0XWi>09miBP2PNT/0XG]<0080XWa=00<0X7Y;09ihB@2MMdP0202NNTH20:1lC080XGe=00@0X7a<
09ijBP2LN4P0VgM70P2PNdL309mjAP<0WWU500@0WWY609eiA@2MNDD0WGU50`2LN4@01P2KMd<0XWi:
0:9nBP2QODT0X7a809mkA`80WWY600@0WGU50:1lC02PO4`0XGe=0P2PO4`00`2ONd/0WWY:09ijBP02
09]gA`0409ahB02MNDT0WWY:09ijBP80Wg];0P2PNdL30:5lB0@0XWe9202QO4P409eiB@0809ijBP2P
O4`0XWi>0:B0D02ROTX0XGe909mkA`2MNDD409]g@`0509]f@P2JMD40VWE109Ud@02HLcl00P2GLSh0
102FLCd0V7A409QdA02HM4@309UeA@80VWI60P2MMdP209afA`<0VgE600<0VWA509UeA@2IMDD00P2H
M4@209Mc@`<0UW9200H0Ug=309QdA02IMDD0V7A409Mc@`2ELD4909A`@0<0Tfdn:oooool002[ooooo
0P2NMCl00`2MM400WG=109ec@`0209aaA00309aaAP2NM480WWA200H0WWA20P2QMdD0102PMT@0WgE3
09ec@@2LLT0209]a?`0409Q/>`2JKSd0W70o09ib@@80X7A30P2OLd880:9fA@@0Y7U60P2SN4D20:9g
A0030:5gA@2PMT@0WgE30080WWA200<0WgE30:1fA02QMdD0202RMd@40:5hA0@0XWU52@2SNTH00`2P
Md<0XGQ40:AkA`020:ElB0030:AkA`2QN4@0X7M30080Y7Y:00@0Y7Y80:AkA`2UO4P0YGa60P2UO4@4
0:ImB@@0YGa800H0Y7U>0:AiC02TND`0YG];0:EkB@2TNdL20:AkA@<0Z7e:0P2YOT/30:QmBP<0YWe9
0`2WOTX20:QoB`80ZX5=1P2YP4`30:MnBP80Z7m;2`2YP4`20:QoB`80ZH1<0P2ZPDd20:^2CPP0Zh5?
0P2`QU@02@2^Q580[H=A0:b2D02ZP4h0ZGm=0:QnC02ZPDd0Zh9>0:b3C`020:f4D0040:b3C`2[PTh0
ZX5=0:J1C@80Yh9>00<0Z8=?0:V4D02ZQE401P2[QU840:b7D`P0[XEA202_QE<20;26EP040;26E02`
Qe<0/8MC0;27D@80/8M?2@2]R5@20:Z5D@80ZhIB0P2/Qe<20:f8E0<0[8MC0P2[QU830:Z5D@P0[XAB
0P2[QU430:Z5D0H0ZHA?0P2XPdh30:N2C@80XWe90`2SOTX30:AoB`80WgY5102NND@209eh@`@0W7I5
00@0VgE409Yd@`2ILd80V7910`2HLcl209Mb?P@0UW4m0P2EL3`209A_>`80Tfhj00T0TVdi09M/=`2E
K3H0UF`h09=[>02@JST0SVXj08]Y>@2;JC/00`2=JCT208aX>0<0RfLg00H0SFTi08aX>02;IcL0RFDe
08MS<`26HS8208AP<080Q5lb0`23GS43089M<080Pehd00@0PUdc081K<@1oFS00OEP^0P1lEbd407QH
;`80MeL^0P1fERd807AD;@0306m?:01aDBX0Le</0080M5@]00<0LU8[06m?:01]CBH00P1]C2T00`1/
BbP0JdXW06]:9`0406]:9`0906U<:P1WBRP0IDPV06A79@1SAR@0I4LU06E89P1VBBL0ITLZ0080IDPZ
00D0HdPZ0658:@1PBBT0GDTX05a89`0605m79@80GTHT1P1L@B@205e29@0405M08@1H@B80Fd@U05i7
:0@0H4TZ00@0Fd<W05Y29P1J@RH0FT8V0P1I@BD205Q0900305Y3901KA2D0Fd@U0080G4DV0P1MARL0
0`1NAbP0GDHW05e69`0305i7:0<0GdPY201NARX205e5:@0305a4:01K@bL0FT8V0080FD4U00<0F40T
05a59P1LABH01P1LABH00`1KB2P0G4TY05e::P0205i;:`0305e::P1LBBT0FdPX0080G4TY00@0FdPX
05Y79`1HABD0Ed@T0P1F@b<205Y29P0<05Q39P1G@RD0ET<U05I39@1D@bD0Dd8T05Y0:@1I@BT0F40X
05I0:01D@2L0DD0V0P1@@2H805509PP0D3hV201<?2<;04Tm8`<0B3`R0`17>b4304Dk8P80A3XQ0`13
>B04044j80@0@3TO0P0k<ah0100l=1l0?CDP03hf8@0o=b82040h8`P0?STS0P0n=R4303de80<0?3@O
00P0>3<P03Lb7`0f<Ah0=C0M03Ha7P0h<b00>cHS03dh9@<0=S<P100e<Ql0100d<Ah0;c4L02la700`
<Qd2034c7P06038d7`0c=B00<cDP03<e800b=1l0<38M0`0^<1/00`0_<A`0<38M038_700203<`7@03
03@a7P0e<Ql0=C8O0080=C8O200`<Al2034e7P0303<e7`0e=1l0=cDP0080>C@P00<0>c@Q03Pc7`0h
<al01P0h<al203Pf7@0403/g7P0m=al0?SHO03lg8080@SLQ00H0ASXP04Lk8@17>b40B3`R04Tm8`1:
?R@204/o9@0804/m8`1<?R@0CClT04m1901@@b<0DTDS05=6901DAb@205Q89P0305]89`1LB2L0GdPX
0080H4LX00L0HDHX05a9:01MBbL0GT`V05m=9`1QCbL0He8W0080I5<W0`1ZDBT00`1[DRX0K5<[06aC
:`0306aC:`<0LE@Z0P1bEB/307=F;080N5`/1P1iGBd00`1oHBl0P68`081R<002085S<@<0PV@b00`0
Q64g08ES=P26I3L0QfDg08UW=`2:JCH0RfXe08a[=P27IcH0R6Pg08YZ>@2<K3/208e]?080S6`k0P2A
KCT2099^>P0409=_>`2DL3`0UG4m09Ea?@P0VGE10P2OMd@0102MN4@0WGU509eiA@2LNdH209]lAP0=
09eiA@2ONdL0XGe90:9nBP2SOd/0XWi:0:5mB@2PO4P0XWm70:>0B02SP4X0Y81<0:J2D0020:N3D`03
0:R3EP2WQ4h0Z8E?0080Z8E?0P2YQU020:Z7D@80ZXIB00@0ZhMC0:b8E02]RED0[XYF0P2_ReL80;2<
F0050;2<G02aSEd0/HeM0;6=G@2bSUh00`2cSel80;FAH@P0]YAV0P2kUfL20;ZFIP040;VEI@2hU6@0
^9AT0;NCH`<0^9AT0P2iUFD30;ZFIPT0^9IX0P2eTfD00`2fU6H0]iEW0;RFJ0020;VGJ@030;ZHJP2i
UfT0^IMY00H0^IMY0P2jVFH00`2jV6P0^YQZ0;ZHJ`020;ZGK@040;ZGK`2iUfT0^IMY0;VGJ@<0^YQZ
0P2kVF/20;bHJ080^iMW0P2jUVH20;VEI@P0]iEW0P2gTVD0102hTfH0^IAW0;ZEJ02kUVT20;bGJP03
0;ZEJ02iU6L0^IAW00@0^IAW2@2jUFP80;VDI`030;JCJ@2gU6X0^II/0080^YM]00<0^II/0;REJ`2g
U6X00P2jUFT60;VDJ0P0]iEW0`2hUVP30;NEI`80]YAV0P2hUVH0102gUFD0]YAT0;JDI02eTf<20;BB
HP80/hmO0P2dT6020;FAH@80]Y9R0`2cTF430;BBHP80]I=S202fTF@90;B?HP80]Y5T0P2eT6<20;B?
HP<0/hiQ102dSf830;F@H`80]99T0P2cTF<20;:@HP80/HmQ202fTV80202dTed0/i9M0;6@F`2`Se`0
/8iN0;6?H@2cTF@0]99U0`2eT6<30;B?HP80/hiQ0P2gTf<00`2fTV80]I5Q0;FAH@030;FAH@P0/hmO
0`2cSV400`2bSF00/hiQ0;>>H@020;B?HP080;>=IP2dSfD0]I1V0;JAI@2eT6<0]91P0;:>G02aSE/3
0:n:GPD0/8]O202aSEd30;2<G0<0/HeM0P2bSUh30:n=H0<0/8iQ0P2aSf820;>>H@<0/XeP0`2aS5l8
0;:>GPP0/HaO0P2bSUh30;6=G@<0/8aL2@2aSEd20:n:G@80/8]N0P2aS5l20;:=H0<0/HeM0`2bSUh:
0;>?G`80/HeM00@0/XiN0;>?G`2cSel0]91P0P2eTF420;JBHP80]I5Q00@0]91P0;>?G`2cSel0/hmO
0`2aSEd30;2<G080[h]K2P2`S5`60:n;F`<0[hYM0P2`Reh30:n:G@P0/HeM202bS5d30;6=G@<0/XiN
0P2cSel@0;:>GP80/hmO0P2bSUh0102aSEd0/XiN0;:>GP2bSUh80;6=G@P0[hYM00<0[hUJ0:j8F@2^
R5T00P2^R5T30:f7F080ZhMG00D0[8QH0:f9F@2]RET0[HUI0:j:FP020:n;F`P0[8QH102ZQUH20:^7
E`080:b8F02]RET0[8UC0:b8E02]RED0[XYH0:j:FP2_RUd20;2;G`80[h]K0`2^RUX30:f9F@<0[8QH
0`2]RET20:j:FP80[hYM1P2^RE`00`2^RUX0[HUI0:^7E`020:Z6EP030:^7E`2/R5P0[HUI00<0[8IG
0P2]QeP30:j8F@P0ZXEA00H0ZhQB0:^7D`2ZQU80ZXID0:Z6EP2ZQEP20:Z5F@P0ZXEA202YQE480:Z5
D@040:V5D@2ZQU80ZXIB0:Z6DP80ZHEA0P2XQ5080:V5D@H0Z8A@0P2WPdl0202ZQE00ZHA@0:N2CP2V
P4l0YX1A0:N1E02XPEH0ZH9G0`2VPU830:F1D@80Y81@00D0ZXE>0:V4C@2XPdh0YX5=0:J0C`020:R2
D`070:V3E02ZQ5L0Xh1:0:>0BP2TPD/0YH9<0:J3C@020:N4CP030:R5C`2UP4`0Y7m;00<0Xgi:00<0
YH1<0:N2CP2XPdl0202XPdl80:N3D`030:F0C02VPDd0Yh9>0080Z8=?00<0Yh9>0:F0C02TOd/0202Q
ODd80:=nBPP0Y7i=0`2ROTX30:5mB@80X7a80`2NNTP209mkB@060:1lBP2QOD/0XGe;09miB02PNTT0
XG]:0P2RO4/00`2PNTT0WWQ709egAP0809ijAP@0XGe=00@0X7a<09mkB`2NNTX0WWY:0P2PNTT309mi
B0<0WWQ7202KMd<20:5mB`80X7a:00D0Wg]909ijB02NNTP0WWY809mkB`020:1lC0050:5mC@2PO4`0
Wg];09ijBP2MNDT00P2KMdL209ahB00409eiB@2NNTX0WWY:09ijBP80X7]70`2QO4P40:9mB@<0XGa8
102PNdL03`2ONTH0W7Q609ahAP2MNDL0WWY809mkB@2QOD/0XWi<0:=oC@2ROTX0XGe909mkA`2MNDD0
VgM309Yf@P0209Ue@@80VWE10P2IM40209Qc?`80Ug8n0`2ILd@309YdA@80VgE60`2LMTL309]eAP80
VWA50P2IMDD209QdA080Ug=30`2FLT801`2GLd<0V7A409UeA@2HM4@0Ug=309Ea@@2CKcl0202DL403
09A^?b_ooooo000Zooooo`80WWDo00<0WGA009ec@@2MLd<00P2LLD@00`2LLDH0WWA209id@P0609id
@P80XGM500@0X7I409me@`2MLd40W7900P2KLCl0102HK3/0VVhm09a`?`2NLT420:1d@`80Wg=2202Q
MDH40:AiAP80XgQ50P2RMd@00`2QMdD0X7I409id@P0209ec@@0309id@P2PMT@0XGM500P0XGI300<0
X7M30:5hA02QN4@00P2RNDD20:=jAP030:AkA`2SNTH0XgY600L0XgY600<0WgI20:5hA02TNdL00P2V
ODT01P2TNdL0XGQ409mf@P2RN4P0XgU90:=iA`80Y7]700<0YGa60:ElA02VODD0102UO4P40:ImB@09
0:EjC`2TND`0Y7U<0:AjBP2TNTP0Y7]70:AkA@2UO4H0ZGi;00H0Z7e:00@0ZGi;0:ImB@2VODT0YWe9
0`2WOTX20:QoB`H0ZH1<0P2ZPDd30:MnBP80Z7m;2`2YP4`30:QoB`80ZH1<0`2ZPDd80:^1C`80[hEC
00T0[XAB0:f3D@2/PU00Zh5?0:Z0CP2YOdd0ZX5=0:^2CP2]Q5000P2^QE40102]Q500Zh9>0:Z1C@2V
PDd20:N2CP030:R3C`2YQ500ZXEA00X0ZhIB202^QE480:j4DP80/8IF00@0/8ID0;27D`2`Qe<0/8MA
0P2`Qdl90:f8E0<0ZXEA0P2[QU830:b7D`80[HQD0P2/Qe<20:^6DP80ZXEA202_QE<30:^6D@<0ZXE@
1@2YQ4l20:R3CP<0Yh9=0P2SOTX30:AoB`<0YH1<0P2QO4L20:1kAP80WgY50P2NND@01@2ONTH0WWU5
09ehA02KMT80VWE100D0VGA00P2HLcl209Mb?PH0UW4m102EL3`0202HKCP0Ufhh09I]>@2DK3T0TF/j
08m[>`2=Jc/0S6Xl0P2?Jc/208iZ>P<0SFTi00T0S6Ph08iZ>P2>JSX0S6Ph08]W=`29ICD0Qf<c08IR
<P25HC400`25H3<308AO<P80Peha0P24GcD01023GS@0PUdc081K<@1oFS0207iI;`80NUXa0P1iFC04
07QH;`P0MED^00P0LE4Z079B:`1dE2d0MUH_07EE;P1cDb`0L50Y06i>9`@0KddZ01<0KT`Y06e;:01]
BbP0KD/X06a:9`1YC2X0J4/Y06I99`1UB2H0I4LU06E89P1VBBL0IdXX06Q9:P1WBRX0ITTY06=9:01R
BRP0HDXX0080Gd/X00@0HTXX06599`1PB2H0H4PV101OAbD505]290<0FT4S00<0Fd@U05a59P1NAbP0
0P1OB2T00`1NAbP0G4DV05]49@0305U19@80F40T0`1G?b<405U49@@0FTDV0`1LABH305e69`80GTLX
201KART01P1MABT0G4@X05a4:01K@bL0FT8V05U19@80F40T201KA2D00`1IARH0FTLW05a9:@0205e:
:P0305a9:@1JAbL0FDHV0080FTLW0P1IARH205Q59@80Ed@T00D0GD8W05a29`1J@RH0F4<V05I39@02
059390090554901H?RL0EclW05Lo9`1D?RH0DclV05509P1@@2H0CclU00P0D3lU201??BD804`l8`T0
BCdS0`18?28304Lk8@80ASXP0`15>b8204@j8@<0@cTP2010>Al203`d7`80?CDP00@0?SHQ03lg8P0o
=b80@3PS200n>B<303hf8@<0?CDP0P0l=1l203Tb8080>34O00@0>C8P03/d8P0l=B<0?SLU0P0g=242
03Hc800403Db7`0d<Ah0=34N03@a7P80;c4L00@0<38M034c7P0a<ah0<S@O0P0c=B000`0b=1l0<C<N
02la700202h`6`0302la700`<Qd0<C<N00@0<c0M00@0=34N03Db7`0e<Ql0=S<P200c<Qh203@f8003
03He800h=R40>SDQ0080?3DR00<0?CDR03/d8@0k=2401P0k=2401P0k=a`0?3PM03hh7P0n>1h0@3TO
04<i8080ACTQ0P1;?B800`1<?R<0CClT04i09@0204m19P0905129`1>?R@0CclU0511901B@b@0E4DT
05I89@1HBRL0FD/V0080GD/W00h0GTXW06199`1RBRP0HdTX06A::@1VBBT0GddY061>:01QCbT0HU0X
06=B9`1UE2P0IE@V06IE9`D0Ke<[0P1`E2`00`1aEBd0LUH^07AG:`0207AG:`80MEP/0`1fFBd207]O
;`<0NUh^0`1kGbl3089T<P80PfDc0P24IS@03@25IcD0QV@g08MU=`28ISP0RFLg08]Z=`2<JcH0SF`f
08i]=`29IcL0RfTi08e[>`2?KCd00P2@KSh02P2?KCd0SV`l099^>P2BKSX0Tflk09A`?02ELCd0UW8n
09Mc?`2HM40809]g@`80X7Q500T0WgY609ijAP2ONdL0WGa709amA`2MOTP0WWY60:1lB02QODT00`2S
Od/01`2ROTX0XGe90:>0B02TPDT0Y85;0:F1C@2VPU000P2WPe<00`2XPeH0Z8E?0:R5C`020:V6D0<0
ZXMA00@0ZhQB0:^7D`2[Qe<0[8QD0P2]RED00`2^RUH0[h]G0:n;E`080;2<F0050;2<G02aSEd0/HeM
0;6=G@2bSUh00`2cSel80;JBHPP0]YAV00H0_9QX0;^GI`2kUfL0^YIV0;VEI@2hU6@20;NCH`80^9AT
0P2iUFD20;ZFIP80^iMW2@2iUfT20;FCI@030;JDIP2gUFL0^9IX0080^IMY00<0^YQZ0;RFJ02hUVP0
1P2hUVP20;ZIIP030;ZHJ02jV6X0^YQ[0080^YM]00@0^YM_0;VGJ@2iUfT0^IMY0`2jV6X20;^IJ`@0
^iMW102jUVH80;NEI`80]i9U00@0^9=V0;VDI`2iU6L0^YEX0P2kUVT30;VDI`80^YEX0`2iU6L80;^F
J@P0^YEX00<0]iAZ0;REJ`2iUV`00P2jUfd00`2iUV`0]iAZ0;JCJ@060;VDI`80^YEX202gUFL30;RF
J0<0]iEW0P2fU6H20;RFIP040;NEI@2fU6@0]YAT0;FCH`80]99R0`2cSel20;B@H0<0]I5Q0P2bT603
0;>AH@<0]99R202fTF@90;B?HP<0]I1S0P2dSf860;>>H@030;B?HP2eT6<0]I1S0080]Y5T0`2cTF<2
0;:@HP<0/HmQ202fTV80202dTed0/i9M0;:AG02aT5d0/HmO0;:@HP2cTF@0]99U0`2eT6<30;B?HP80
/hiQ1@2fTV800`2eTF40]91P0;B@H0080;:>G0<0/hiQ00<0]8mR0;>>H@2cSV400P2bSF00202cSFH0
]8mU0;F@IP2eT6@0]I1S0;>?G`2bSU`0/8aJ1P2_RUd20:j9G0P0/HeM0P2_Re/30;2<G0<0/HeM0`2_
SEl30;2>H080/HmQ0P2cSV430;:=H0<0/HaO202bSUh80;6<G`<0/HeK0`2`S5X20:n;F@T0/HeM0P2_
RUd20;2;GP80/HaO0P2bSF030;6=G@<0/XiN2P2cSel0102`S5`0/HeM0;:>GP2bSUh20;B@H0030;FA
H@2fTV80]I5Q0080]I5Q102dT6000`2cSel0/XiN0;:>GP030;6=G@<0/8aL202_ReT60:n;F`80/8aL
00<0/8]N0:n:G@2_RUd0102_RUd00`2`Reh0/HeM0;6=G@060;6=G@P0/XaM0`2aSEd30;:>GP80/hmO
402bSUh30;6=G@@0/XiN00<0/HeM0;2<G02`S5`01P2`S5`80:n:G@<0/HQJ00<0/8MI0:n6F02_QUP0
0P2^QEL20:Z6EP050:^7E`2/R5P0[HUI0:f9F@2^RUX00P2_Re/80:b8F0040:V5E@2ZQUH0ZXIF0:^7
E`@0[8QH00H0[8UC0:b8E02]RED0[XYH0:j:FP2_RUd20;2;G`<0[h]K0`2^RUX20:f9F@<0[8QH0`2]
RET20:j:FP80[HQK1P2^RE`00`2]RET0[8QH0:^7E`020:Z6EP030:^7E`2]RET0[XYJ00<0[8IG0P2]
QeP30:j8F@P0ZXAC00H0ZXMA0:Z6DP2ZQU80ZXID0:Z6EP2ZQEP20:^6FPP0ZXEA202YQE480:Z5D@80
ZhMC00<0ZXIB0:V5D@2XQ5002`2XQ5020:N3C`H0Z8A@00H0ZhIA0:V4D02WPTh0YX1?0:EoD02VP5<2
0:N0E@<0YX9B0`2UPE420:B0D0050:Z5CP2YQ4d0Yh9=0:J1C@2VP4l00P2WPE801`2YPe@0ZXAG0:>0
BP2SP4X0Y85;0:F2C02VPdd00P2WQ4h02@2XQDl0YX5=0:F0C02TOd/0Xgi:0:AoB`2UP4`0Yh9>0:R3
C`080:N2CPP0YX9B00<0Y7m;0:F0C02WPTh00P2XPdl00`2WPTh0YX5=0:F0C0080:5mC@P0Xgi:202T
Od/20:=oB`<0XWi:0`2QODT209ijAPH0Wg]700<0WgY60:1kA`2QO4P00P2RODT00`2PNdL0WWU509eh
A00809ijAP80XWi>00<0XGe=0:1lC02PO4`00`2PO4`20:1jB`<0WgU:0`2NN4T409Yf@P@0VgM300<0
X7a<09mkB`2ONd/00P2ONd/409ijBP0609mkB`2PO4`0XGe=0:5mC@2ONd/0WGU90P2KMdL409ahB0<0
WGU90P2PNdL30:5lB0@0XWe90`2QO4P00`2PNdL0WgY609mjAP0209iiA@0509]g@`2LN4@0WGU509mk
A`2PO4P00P2QODT02@2ROTX0X7a80:1lB02ONdL0WWY609ahA02JMT80V7A009Mc?`0409Ud@0@0V7<o
0`2KLT@309acA@80WGA60P2LMTL309]eAP<0VWA50P2IMDD209QdA080Ug=30P2FLT800`2ELD40UW92
09Mc@`0209QdA00309Ib@P2DL400Tflo00P0U7100`2EKd0[ooooo`00:_ooool209ie?`0309ed@02M
Ld40WG=30080W75400@0W75609ec@@2MLd40WG=10P2NM48309me@`80X7I400@0WgE309id@P2NM480
WG=10P2LLT000`2JKSd0W70o09ib@@030:1d@`80Wg=2202QMDP30:=hA@<0XWM40P2QMT<00`2PMT@0
WgE309id@P0209ec@@0309id@P2OMD<0X7I400P0XGI30P2PMd<00`2QN4@0XWU50:=jAP020:AkA`03
0:ElB02TNdL0Y7]700D0XWU50P2TNdL00`2QN4@0XWU50:ElB0020:ImB@090:ElB02RNDD0XGQ40:5g
A`2RN4P0XWQ60:=jAP2TNdL0YGa60080YWe500@0Y7]70:ElB02UO4P0YGa80`2VODT0302WOTX0YW]@
0:EjC@2TND`0XgU90:=iA`2TNdL0YGa60:ImA`2YOT/0Z7e:0:MlB@80YW]800<0Yga90:QmBP2YOT/0
0`2VODT30:MnBP@0Z7m;0`2YP4`30:Z1C@<0Ygi:0P2XOd/;0:V0C0040:MnBP2XOd/0Z7m;0:QoB`80
ZH1<0P2ZPDd80:^1C`<0[89@0`2[PDl20:Z0CP030:^2CP2/Pdl0[HA@0080[XEA00@0[HA@0:b3C`2[
PTh0YX5=0P2WPTh00`2XPdl0ZHA@0:Z5D@020:^6DP040:b7D`2[QU80ZhIB0:^6DP<0ZXEA00<0ZHA@
0:j5D@2^QE401P2^QE480:j4DP80/8IF00@0/8ID0;27D`2`Qe<0/8MA0P2`Qdl90:f8E0040:V4D02Z
QE40ZXEA0:Z5D@80ZhIB0P2/Qe<30:f8E080[8MC0`2[QU880:n5D`80[8MB0P2[QU430:Z5D0040:V4
C`2XPdh0Z8=>0:R3CP80Yh9=0`2VPD`80:F0C080Xgi900@0XWe80:5lA`2PNdH0X7]60P2ONTD01@2P
NdH0WgY509eh@`2KMT40VWE000<0VG@o0`2IM40209Qc?`/0Ug8n00P0VFhi09Q_>@2GKSX0UVhk09=]
?02AKCd0SV`l08i/?P<0T6Xk0P2?JCX308iX>@80SFTi00@0S6Ph08]W=`29ICD0R6@d0P27Hc<208MR
=@80QV4d0`25H3<00`24Gc80PUdc089M<`02089M<`80PE`b0P20Fc4307]K<P80NUXa0`1iFC0807IF
;`80M5@]0`1eEBh01@1dE2d0LU8[075A:P1aCB/0LTh/0080Ldl]01T0LTh/075=:`1`C2X0L4`Z06m;
:@1ZCB/0JD`Z06M::01VBBL0IDPV06I99`1WBRP0J4/Y06Y<:P1XBbT0IdXX06A:9`1RBRH0HT`W061<
9`1QCBP0I4`Z06=;:@1QBBL0H4PV00<0GdLU00<0H4PV05]49@1KA2D00P1KA2D205Y39080FD8S00P0
GTLX05m8:@1PBBX0GdPY05i7:01LABH0FT<T05Q18P80FD4U0P1H@2@305Lo8`0305Hn8P1HABD0F4DU
00H0F4DU0`1KA2D505Y390P0F4DW0P1K@bL305Y29P<0FD4U201J@b@00`1GA2@0F4DU05U69P0205Y7
9`0305U69P1HABD0Ed@T00P0F4DU00T0H48X05m19`1L@RL0F4<V05A39@1B@b@0CT<S04e48`1G?BH0
0P1E?BD00`1C?BD0DShU050o9@0204lo9@P0CchT201>?2@804/k8PT0BCdS0`18?28204Lk8@<0ASXP
0`15>b8204@j8@<0@cTP00@0?cPN040i7`10>Al0@3TO0`11>R000`12>b40?cLR03lg8P0603lg8PP0
?STS0P0o=b8203hf8@<0?CDP00<0?3@O03/b8@0k<R400P0k<R4203`c8P80?C@S00H0>3DR03Ld8@0g
=240=S<P03Db7`0d<Ah203<`7@<0<38M0P0a<ah4038d7`08034c7P0_<A`0;S0K02h`6`0_<A`0<38M
034c7P0d<Ah203<`7@03038_700c<1d0=34N0080=S<P200f=1l203Pg8P0303Xh8`0l=b<0?SLT0080
?cLT00<0@SLU03lg8P0o=b801P0o=b801P0n>Qd0@3/N040k7P12>al0AC/P04Lk8@80BS`R0P1??bD0
0`1@@2H0DD4W0592:00205=3:@0905A4:P1A@2@0DT4U05A39@1FARD0F4PV05Y:9P1LC2P0GDhW0080
H4`W00<0HT`W06A<:01UBbP00P1XBbT01`1YBbT0HU0Z06=A:@1SDBT0I5<X06ED:01VEBL00P1WEbH3
07=F;0<0LUD[00@0LeH/07EH;P1fFBl0MUT]0`1gFRh207QK;`80NE``0P1lH30207]O;`0407aP<01m
HC40OV8b07mS<`80QFLe0`24IS@02@26J3H0QfTg08QZ>028ISP0RFLg08YX>02;JSL0S6/f08i]=`02
08m_=P0408eY>@2>JSX0T6`l099^?P80Tflo00X0TVhn095]?@2CKc/0U70l09Ea?@2FLSh0Ug<o09Qd
@02IMD40VWI20`2KMd<209ahA080WGU500@0WWY60:9jA`2RNTL0X7]70P2PO4P01P2OOTT0WWm909io
B@2PO4P0XWi:0:=oB`<0YH5=00L0Y81<0:=oB`2UPTX0YH9:0:F2C02VPTh0YX9@0080Yh=C00<0Yh9E
0:V6D02YQU000P2ZQe430:^8DP060:b9D`2[Qe<0ZhMC0:b8E02]RED0[XYF0P2_ReL00`2`S5P0[h]G
0:n;E`060:n;E`80[h]K00@0/8aL0;6=G@2bSUh0/hmO0P2dT6000`2hU6@0]i=S0;JBHP030;JBHP03
0;NCH`2hU6@0]iEW00L0]iEW0P2kUfL20;ZFIP040;VEI@2hU6@0^9AT0;NCH`<0^IEU0P2jUVH30;^G
I`T0^IMY0P2fU6H30;NEI`/0^9IX0P2jVFH00`2jV6P0^YQZ0;ZHJ`020;ZGK@040;ZGK`2iUfT0^IMY
0;VGJ@<0^YQZ0P2kVF/40;^GI`@0^YIV202gUFL50;VDI`@0^9=V00L0^IAW0;ZEJ02kUVT0^iIY0;ZE
J02iU6L0^9=V00P0^iIY202jUFP0202hUF/0^II/0;ZGK@2kV6h0^YM]0;VFK02gU6X0]Y=Y0P2hU6@3
0;VEI@<0^YIV202gUFL30;RFJ0<0]iEW0P2fU6H20;RFIP040;NEI@2fU6@0]YAT0;FCH`80]99R00@0
/XiN0;>?G`2cSel0/hmO0P2dT6020;FAH@<0/Y1P0P2cTF430;BBHPP0]Y5T2@2dSf820;F@H`80]8mR
0`2cSV430;:=H0030;>>H@2dSf80]I1S0080]Y5T00<0]i9U0;>AH`2cTF<00P2bT6830;6?H@030;2>
H02fTV80]Y9R00H0]Y9R00P0/i9L0;:AG02bTE`0/Y5N0;:@H02bT680/Y1S0;>AI0L0]8mR00<0]I1S
0;FAH@2fTV800`2gTf<00`2eTF40]91P0;>?G`080;>?F`80/hiQ0`2dSf802`2cSV40/XeP0;6<G`2a
Rf@0/XeS0;>>I02dSf<0/hiQ0;:>GP2`S5X0[h]I0080[h]K0`2^RUX30:f9F@P0/8aL0`2_Re/20;2<
G0<0/HeM0`2_SEd30;2>GP80/HmO00<0/HaO0;:=H02bSF001@2bSF080;6=G@P0/HaO0`2aSET20;2<
F0<0[h]G2@2aSEd20:n:G@80/8]N0P2aS5l20;:=H0<0/HeM0`2bSUh20;>?G`P0/XiN0P2aSEd0102b
SUh0/hmO0;>?G`2dT6020;FAH@P0]91P0`2bSUh20;6=G@<0/8aL202_ReL20:j:FP<0[h]K0`2`S5`0
0`2aS5l0/8]N0:n:G@020:j9G0030:n:G@2`Reh0/HaO00P0/HeM202bS5d30;6=G@<0/XiN0P2cSel8
0;6=G@P0/XiN00H0[h]K0;2<G02aSEd0/XiN0;>?G`2bSUh20;6=G@80[XYJ0`2_Re/30;2<G0P0[hYM
0P2cR5/00`2bQeX0/HII0;25F0020:n4E`050:j3EP2ZQUH0ZXIF0:^7E`2/R5P00`2]RET20:j:FPP0
[HUI0P2ZQUH00`2/R5P0[HUI0:j:FP020:f9F@070:b8F02]RU@0[HUE0:f9E@2^RUP0[XYJ0:n:G@02
0:n:GP80/8aL0P2_Re/30:j:FP040:f9F@2/R5P0[8QH0:b8F0<0[HUI0P2^RUX20:b7FP80[HQK102^
RE`0202/R5P0ZhMG0:Z6EP2YQED0ZXIF0:^7E`2]RET0[XYJ0`2[QEH20:b6E`<0[HMH202ZQ5D01P2Y
QU00ZHEA0:Z6DP2ZQU@0ZXIF0:^6F@80ZhIJ202ZQE430:R4D080ZHEA0`2ZQU880:^6DP040:f9E@2[
Qe<0ZXIB0:R4D080Yh=?0P2XQ50;0:N3C`<0Z8A@0P2YQE401P2[QU40ZXEA0:N2CP2UOdh0YGm@0:Eo
DP80YWmD0`2VPU830:F1D@80Y81@00D0Z8=<0:N2B`2VPD`0YH1<0:EoCP020:J0D@040:N1DP2XPUD0
Y85;0:B1B`<0YH9<0`2VPdd00`2WPTh0YX5=0:F0C0020:AoB`030:F0C02WPTh0Z8=?00P0Yh9>202V
PU800`2SOTX0YH1<0:J1C@030:R3C`80YX5=202QODd80:=nBPP0Y7m:0`2SOd/20:9nBP<0XGe900/0
WW]509mlAP2PODL0X7e709mlAP2NNdD0WGY409ai@`2ONTD0X7]60:5lA`020:9mB0030:1kAP2NND@0
WGQ300P0WWY600<0Xgm?0:9nCP2QODd00P2PO4`00`2QODd0XWi>0:=oC`020:1jC@<0WgU<0`2NN4/3
09Yf@P80VgM30`2LN4@809iiC00809ahB02NNTX0X7a<0:9nCP2QODd0Wg];09ahB02JMTH809ahB080
X7]70`2QO4P50:9mB@80XGa800<0X7]709mjAP2NNDD00P2MN4@00`2MNT@0WW]509mlAP030:1mA`80
Wga6102NNTH0102LN4@0VWI209Qd@02GLcl409Ud@0@0V7<o0`2LLD@309ebA@80WW=600@0W7I709]e
AP2KMDH0VgE60P2JM4D209UcA080VGE50P2HM4@209Mc@`80UW9200L0UG5109Ib@P2GLd<0V7A409Mc
@`2FLT80U71000T0Tflo0`2FL44[ooooo`00:_ooool209ie?`0309ed@02MLd40WG=30080W75400@0
W75609ab@02MLd40WG=10P2NM48209me@`030:1fA02NM480WWA200H0WWA200P0WW9109mc@P2PM4<0
XGE40:9fA@2QMD@0Wg=209ib@@P0X7A70P2RMd@30:5f@`<0X7E200<0X7I409me@`2MLd400P2LLT00
0`2MLd40WgE30:1fA0080:1e@P80X7M300T0XGQ40:9iA@2SNTH0Y7]70:ElB02VODT0YGa80:AkA`2R
NDD00`2QN4@0102RNDD0Y7]70:ElB02TNdL20:ElB080YWe90P2UO4P01`2TNdL0X7I60:5gA`2RN4H0
XgY60:AkA`2UO4H00P2VODD20:AkA`80YGa80P2VODT20:MnBP0;0:IkD02UNTd0XgQ;0:9hB02RN4H0
XgY60:ElAP2VODL0Z7e:0:MlB@2UNTL00P2TNDH00`2UNTL0Yga90:QmBP030:ImB@<0Ygi:1@2XOd/0
0`2YP4`0ZX5=0:Z1C@020:^2CP<0Ygi:0P2XOd/;0:V0C080Ygi:0`2XOd/30:V0C0P0Zh5?00D0Z7i<
0:UoC@2YOdd0ZGm=0:Z0CP030:^1C`030:^2CP2/Pdl0[XEA0080[hIB00@0[XEA0:b3C`2[PTh0YX5=
0P2WPTh00`2XPdl0ZHA@0:Z5D@020:^6DP80[8MC0P2[QU80102ZQE40ZHA@0:V4D02YQ5080:j5D@P0
[H=A0P2`QUH0102`QU@0/8MC0;27D`2`Qe420;27C`T0[HQD0P2YQ5030:Z5D@<0ZhIB102]R5@20:b7
D`80ZhIB202_QE<30:b7DP80ZhIA0`2ZQE020:N2C@80YX5<0P2UP4/20:AoBP80Z8=?00@0Yh9>0:J1
C@2UP4`0YH1<0P2TOd/01P2UP4/0Y7m:0:=nB@2RODP0XGa70:1kAP80WgY500@0XWe60:1kA02NND80
VgHo0`2IM3d00`2JMCh0VGA009Ud@00209Ud@080V7<o102GLSh609Qc?`0909]`>`2IL3X0V6lk09M_
?02DKSd0TVhn08m]?@2?KCl0TVTk00<0TFPj0P2@IcT208mV>080RfLg0P2:ISH208UU=@80R6@d0P28
HcH208MR=@<0QV4d00@0QF0c081K<@20Fc40P5/a0P21G383089M<`<0O5`c0P1kFc8307YJ<@P0MUH_
00D0MeL`07IF;`1eEBh0M5@]07=C;00207AD;@0407EE;P1cCbd0M50^07EA;`80MU8`01P0M50^079>
;01bCR`0LDd[06]>;01ZCB/0J4/Y06M::01VBBL0IdXX06Q;:@1YC2X0K4hZ06Y>:@1XC2L0I4XU06=;
9@1RC2D0HTlW06=@:01VCR`0IDd[069::01PB2H205m79@80H4PV0P1KARL205Y59P80FD@U0P1H@b@0
201MARL0GTLX05m8:@1OB2T0GTLX05e69`1KA2D0FD8S0`1I@BD205Q090<0EclS1@1HABD305M49080
FT<T00@0FD8S05Q18P1G@240Ed0Q0P1F?b0805I39@@0FD4U101J@RH805Y3900305A18@1E@R80Ed@T
0080F4DU00<0Ed@T05E28P1D@B400`1GA2@405Q59@0:05U69P1S@BP0HD4X05e29`1J@RH0E4<U0554
901=A2<0BT@R05Dk9080E3`T00<0DcdU058n9@1@?bD00P1??bD804hm8`P0CC/S201;>b8904Xn9004
04Pl8P17>b40Ac/Q04Lk8@80ASXP0P15>Al304Dk8P80A3XQ0`13>B02040i7`80@CXP00D0@S/Q04<l
8P13?280@c`R04<k9P02048j9@03044i9010>2<0?cLR0080?SHQ200n>B<303lg8P80?SHQ0`0m=B04
03dd8`<0?3<R00T0>c8Q03Pe8P0h=B80=c@Q03Hc800e<Ql0=34N03<`7@0b;a`00`0b=1l2034c7P<0
<38M00<0<C<N030b7@0_<A`00P0^<1/01P0_<A`0<C<N038d7`0e<Ql0=34N03<`7@80<RlL00<0=34N
03Hc800g=240200h=Ql01P0k>RD0?3XU03`j9@0o>RH0@3TV048j9`80A3TW2012>R<01P12?Al0A3dP
04@m8017?R40BChR04`n8`80CShT0P1A@RD00`1B@bH0Dd@W05A5:00205E6:@0:05I7:P1E@R@0ET<U
05Q59@1JAbL0G4TX05m=:@1QCbT0HU0Z065>9P80I4hW00<0IDdW06M=:01YCBP00P1[CBT206EC:`03
06IE:P1VEBT0IeHX0080J5PW00@0JETV07QI;@1hFBd0MeP/0`1eERX0101gF2`0NEX^07YK;`1hG2d3
07UM;P80NUh_0P1kGc0207aP<080Nel_00L0OF4a07mS<`22ISH0PfLg08QZ>027JCL0QVPf0080QFLe
00l0QfTg08U[>@2:K3X0RFLg08YX>02;JSL0S6/f08i]=`2?KcH0T70g095a=P2?JCX0T6Xk099/?@2D
KSl00P2EKd002P2DKSl0Tfdn09A`?02DL3`0UW8n09Mc?`2IMD40VWI209]g@`2LN4@209Yf@P0409]g
@`2LN4@0WWY609mkA`80X7a80P2SNdP0102QO4P0XGe90:5mB@2POdX209n0BP080:=oB`2TP4`0YX9>
0:N3C`2XQ500Yh=?0:J2CP2UPDd20:J3B`030:J3C@2VPTh0YX9@0080Yh=C00@0Yh9E0:Z7D@2ZQe40
ZXMA0P2[R5830:b9D`060:^7D`2/R5@0[8QD0:f9E@2^RUH0[h]G0P2`S5P80:f9E@060:f9F@2^RUX0
[h]K0;6=G@2cSel0]91P0P2fTV800`2iUFD0^9AT0;NCH`020;JBHP030;NCH`2hU6@0^IEU00P0]iEW
0`2jUVH70;VEI@80^YIV102kUfL90;ZHJP<0^9IX0`2gUFL20;JDIPP0]iEW0P2jVFH00`2jV6P0^YQZ
0;ZHJ`020;ZGK@040;ZGK`2iUfT0^IMY0;VGJ@<0^YQZ0P2kVF/40;ZFIP@0^iMW202gUFL01P2kUVT0
^YEX0;ZEJ02iU6L0^9=V0;NBI@80]Y5T00<0]i9U0;RCIP2jUFP00P2kUVT00`2jUFP0^9=V0;NBI@08
0;bGJPP0^YEX00P0^9E[0;VFK02jUfd0^iQ^0;ZGK@2hUF/0]Y=Y0;FBJ0<0^9AR00<0^IES0;ZFI02j
UV@00P2kUfD80;NEI`<0^9IX0`2gUFL20;JDIP80^9IV00@0]iEU0;JDI02fU6@0]I=S0P2dTV820;:>
GP<0/hmO0`2dT6020;6?G`80/Y1P0`2cTF400`2dTV80]Y5T0;JAI0060;JAI0`0]8mR0`2cSV420;:=
H0060;6<G`2bSF00/hiQ0;B?HP2eT6<0]Y5T0P2gTVD30;:@HP<0/HmQ0P2`SV080;JBHP060;:AF`2b
TE`0/Y5L0;:AGP2bT600/Y1R0P2bT6<20;:=H0040;>>H@2dSf80]I1S0;F@H`80]Y5T00P0]I5Q0;JB
HP2gTf<0^9AT0;NCH`2fTV80]91P0;:>GPP0]91L00<0/hiQ0;B?HP2eT6<00P2eT6<02`2cSV40/HaO
0:n:G@2_RF80/8]Q0;6<HP2bSF40/XeP0;2<G02^RUP0[HUG0080[h]I0P2^RUP0102]REL0[8QF0:b8
EP2/R5H80:n;F`80[XYJ0P2_Re/30;2<G0040;6=G@2_SU/0[hiK0:n>F`<0/8mL0P2aT5d20;2;GP80
/HaO00@0/XeP0;>>H@2dSf80]8mR202aSEd80;6<G`040;6=F@2`S5P0/8aH0;2<F080[h]G0P2^RUH9
0;6=G@80[hYM0P2`Reh20;6<G`80/XeP0`2aSEd30;:>GP80/hmO2P2bSUh40;>?G`P0]91P0P2eTF42
0;>?G`80/XiN0`2aSEd00`2`S5`0[XYF0:j:EP060:j:EP<0[XYJ00<0[h]K0;2<G02`S5`00P2aSEd0
0`2aS5l0/8]N0:j9G0020:f8F`030:j9G02`Reh0/HaO00P0/HeM202bS5d30;6=G@<0/XiN0P2cSel8
0;6=G@P0/XiN00P0[HUI0:n;F`2aSEd0/XiN0;>?G`2bSUh0/HeM0;2<G080[HUI0P2^RUX20:n;F`80
/8aL202_RUd01P2dRE`0/hQK0;:7FP2aQUT0/8EH0:n4E`80[X=F00@0ZHEE0:Z6EP2ZQUH0ZhMG0P2/
R5P00`2]RET0[XYJ0:j:FP080:n;F`090:Z6EP2/R5P0[XYJ0:n;F`2`S5`0[h]K0:j:FP2]RET0[haF
0080[h]G00<0[XYH0:j:FP2]R5/00P2]R5`30;2<G080[h]K0`2^RUX30:b8F0<0[HUI0P2^RUX00`2[
QUT0[8MJ0:b7FP020:f8F`80[XUL00T0[hYM0:b8F02[QeL0ZXIF0:V5E@2ZQUH0[8QH0:j:FP2_Re/0
0P2YPe@20:Z4E@80ZhEF0P2/QUL80:Z4E@060:V6D02YQE40ZHEA0:Z6E02[QeL0ZhII0P2/Qe/80:Z5
D@030:N3C`2XQ500Z8A@0080ZHEA0P2ZQU800`2[Qe<0ZhIB0:^6DP060:^6DP040:j:EP2/R5@0ZXIB
0:R4D0<0Yh=?00<0Z8A@0:F1C@2UPDd01P2UPDd20:J2CP80Yh=?00X0Z8A@0:V5D@2YQE40ZHEA0:^6
D@2ZQE40Yh9>0:EoCP2TOTl0Y7iA0P2UOU<30:J2DP<0YH5A0P2TP5001@2VPDX0YH190:AoBP2SOTX0
Xge<0080Y7i?00<0YGm@0:J0D`2VPdd00P2VPdd30:F2C080Y85;00<0Z8=?0:N2CP2VPDd00P2TOd/0
0`2UP4`0YX5=0:N2CP080:J1C@P0YH5A00<0Xgi:0:AoB`2VPDd00`2XPdl00`2WPTh0YX5=0:9nCP07
0:9nCPP0Xgi:202TOdP20:B0C080Xgm;0`2ROTX00`2QODT0X7e50:1mA@020:5nAP0709mlA02MNT80
VWLo09Qe?@2ONT<0X7]40:5lA@020:9mAP030:1kA02NND80WGQ100P0WWY600<0Y81@0:=oC`2QODd0
0P2PO4`00`2ROTh0Xgm?0:F1D@020:1iCP<0WgQ=0`2NMd`309]g@`0309ahA02MNDD0WGU50080WWY6
202NNDd0202KMdL0WGU90:1lC02ROTh0XGe=09mkB`2KMdL0VGE5102LN4P409]gA`80X7]70`2QO4P5
0:9mB@80XGa800L0X7]709iiA@2MN4@0WGQ409ag@`2NNd<0Wga400<0XGi600/0Wga409ej@P2LND40
VgM309ahA02MNDD0WWY609eiA@2KMd<0VGE109Qd@00409Qc?`@0VGA00`2LLD@309ebA@80WW=60`2K
MDH209YdA@<0VG=40P2IMDD209QdA080Ug=30P2FLT800`2ELD40UW9209Mc@`0209Mc@`0309Ea@@2C
Kcl0TVhn00P0Tflo0`2GLD8[ooooo`00:_ooool209ie?`0309ed@02MLd40WG=30080W75400@0W756
09ab@02LLT00WG=10P2NM4800`2OMD<0X7I40:1fA00309ec@@80WWA20`2OMD<0202PM4<0XGE40:9f
A@2SMdH0XWI50:5eA02OLd80WW91202PLdT20:5f@`80X7E2102OM4400`2PMT@0WgE309ec@@0209ab
@00309ec@@2OMD<0X7I400P0X7E20P2PMd<0102QN4@0XWU50:AkA`2UO4P20:ImB@030:ElB02TNdL0
XWU500<0XGQ400@0XWU50:AkA`2UO4P0Ygi:0P2VODT20:ElB080YWe900L0Ygi:0:1fAP2PMTH0XGM5
0:9iA@2TNdL0YGa60080YWe50`2TNdL00`2UO4P0YWe90:MnBP020:MnBP0;0:IkD02UNTd0XgQ;0:9h
B02RN4H0XgY60:ElAP2VODL0Yga90:IkB02TNDH00P2RMd@00`2TNDH0YW]80:MlB@030:ImB@<0Ygi:
0P2XOd/0102WOTX0Z7m;0:QoB`2YP4`20:Z1C@80Zh9>0`2WOTX20:QoB`/0ZH1<0`2WOTX20:QoB`<0
ZH1<202[PDl20:IlBP090:MmB`2XOT`0ZGm=0:Z0CP2[PDl0[89@0:^2CP2/Pdl0[XEA0080[hIB00@0
[XEA0:b3C`2[PTh0YX5=0P2WPTh00`2XPdl0ZHA@0:Z5D@020:^6DP80[8MC00@0ZhIB0:Z5D@2ZQE40
ZHA@0P2XPdl80:j5D@P0[H=A0P2`QUH0102`QU@0/8MC0;27D`2`Qe420;27C`T0[HQD0`2YQ5020:Z5
D@<0ZhIB00@0[XUE0:f8E02]R5@0[HQD0P2/Qe<20:^6DPP0[hEC0`2/Qe830:^6D@80ZXE@00@0YX5<
0:F0B`2UP4/0YH1;0P2TOdX20:=nB@060:Z5D@2YQ500Z8=?0:N2CP2UP4`0Y7m;0P2SOTX0302VPD`0
YH1;0:AoBP2SOTT0XWe80:5lA`2PNdH0WgY50:=nA`2QO4D0WWU209]f?`<0VG@m00<0VWDn09Ye@@2I
M4000P2IM40209Qc?`80Ug8n102HLcl409Ud@00809]`>`2JLC/0VG0l09M_?02DKSd0TVhn091^?P2?
KCl3095X>P80T6Li0`2?ISP808UU=@<0R6<f0P27HSD308IQ=00607eH;P1nFBl0OeX`081K<@21G380
PUdc0P23GS@207eM=080O5`c0`1kFc800`1jFS40MeL`07MG<00607MG<00>07YJ<`1hF340MED^07=C
;01bDR/0Le</07IF;`1gEc00MTl^07QA<01iDS40NU<b07UB<@1hDC0207E>;@0E07A=;01[CR`0JTd[
06Q;:@1WBRP0ITTW06M::01XBbT0JD`Z06e?:`1ZCRT0J4`W06A:9@1SBbD0HddV069?9`1SD2P0Idl]
06E=:`1SBbT0H4PV0080GdLU00@0H4PV06599`1LAbP0G4LX0P1KARL01`1JABH0FD@U05U49@1H@b@0
FT<T05]49@1MARL00P1OB2T00`1NAbP0GDHW05a59P0205Y29P80FD4U0`1H@2@00`1G?b<0ETHU05I6
9@0205I69@@0EDDT00H0FT<T05U28`1H@B80Ed0Q05Ho801D?Ah205<l7@P0Dd8T0P1G?b<00`1H@2@0
FD4U05Y29P0205]39`0305a4:01I@R<0FD8S00H0FD8S00<0Dd0P05A18@1E@R800P1F@b<00`1E@R80
E44Q05=0800205I38`80Ed@T0P1HABD205U69P0906=1:01Q@BP0GD8W05Y29P1D@bD0CT<S04]58`19
AB80EC/T0080E3`T00<0DS`T054m901@?bD00P1??bD804hm8`P0CC/S201;>b8904Xn90@0Ac/Q0P16
>R0204Di7`<0AC/R0P14>R4304<i8080@CXP0P12>b401013?280A3dS04@m8`15?R@204Dm:00604@l
9`12>RD0@3PS03lg8P0n=R40?CDP200n>B<303lg8P<0?SHQ0P0m=B02044e9@80@3@T00@0?c<S03hb
8P0m<B40?30P0P0h=B800`0g=240=S<P03Db7`0203<`7@04038_700c=B00<cDP038d7`80<C<N00H0
<38M02la700_<A`0<C<N030b7@0_<A`202h`6`0502la700a<ah0<S@O03Db7`0d<Ah00`0b;a`00`0d
<Ah0=S<P03Ld8@0803/f8080?C/V00<0@3/W044j9`13>bP00P15>RP00`17>RT0AS/U04Hk9@0604Hk
9@80AChQ00H0B3lR04U08`1;@2@0CT0U04lo9@1@@2H205=2900305A39@1EA2H0ETDW0080EdHX01L0
F4LY05I39@1GA2H0F4DU05]89`1NC2P0H4hX069@:P1SDBT0I4hW06E?:01VCRP0IddX06Y>:@1[CBT0
K4hZ06i=:P1VE2`0IUDZ06MF:`1WERX0J5LY06UI:00206UI9P80NEX^00L0N5T]07IG:`1eERX0MUL[
07QI;@1jFbl0Ne``00<0NUh^0`1kGbl407aP<080Nel_00H0OF4a081T=023IcL0QVXj08U[>@28JSP3
08IX=P0908QZ>02:K3X0S6hl08YX>02;JSL0S6/h08e/=`2?KSP0T70g0080TG4f00@0SfTj095[?02C
KCh0UFm00P2FL440402EKd00U6ho09A`?02ELCd0UW8n09Qd@02IMD40VgM309ahA02MNDD0VGE109Yf
@P2KMd<0WGU509mkA`2PO4P20:9nBP80Xg]800T0XWe90:5mB@2ROTX0X7m:09n0BP2PPD/0Y81<0:F1
C@2WPdl00P2YQE400`2XQ500Yh=?0:J2CP020:J3B`030:J3C@2VPTh0Yh=A0080Yh=C00<0Yh9E0:Z7
D@2ZQe400P2[R5830:b9D`030:f:E02/R5@0[8QD0080[HUE00@0[XYF0:n;E`2`S5P0/8aH202/R5@0
2`2/R5P0[HUI0:j:FP2aSEd0/hmO0;FAH@2gTf<0^9AT0;ZFIP2iUFD0]i=S0080]Y9R00<0]i=S0;VE
I@2jUVH0202gUFL60;VEI@80^YIV0P2iUFD20;ZFIP<0^iMW00<0_9QX0;ZHJP2jV6X0202jV6X20;VG
J@030;RFJ02gUFL0]YAV0080]I=U202gUFL20;ZIIP030;ZHJ02jV6X0^YQ[0080^YM]00@0^YM_0;VG
J@2iUfT0^IMY0`2jV6X20;^IJ`@0^YIV102kUfL80;NEI`80_9MZ00@0^YEX0;VDI`2gTVD0]Y5T0P2d
Sf800`2gTVD0^9=V0;ZEJ0020;^FJ@030;ZEJ02hTfH0]i9U00P0_9MZ202jUFP20;VFK0070;ZGK@2k
V6h0^YM]0;REJ`2fTfT0]I9X0;NCH@020;RDHP030;VEH`2jUV@0^YIT0080^iMU202gUFL30;RFJ0<0
]iEW0P2fU6H20;RFIP040;NEI@2fU6@0]YAT0;FCH`80]99R0`2bSUh20;>?G`<0]91P0P2aSel20;:@
H0@0/i5Q202fTF@<0;B?HP80/hiQ0`2bSF001P2aS5l0/XeP0;:=H02dSf80]I1S0;JAI080]i9U0`2b
T6820;6?H@<0/8iP202fTV801P2bTE/0/Y5L0;:AG02cTUl0/i5Q0;:@HP80/Y1S0P2aS5l02@2bSF00
]8mR0;F@H`2fTF@0]i9U0;RCIP2dT600]Y9R0;NCH`020;RDI0030;JBHP2dT600/XiN00P0]I9L0140
/hiQ0;B?HP2eT6<0]Y5T0;F@H`2cSV40/8]N0:n:G@2^R640[hYP0;2;H@2aS600/8]N0:n;F`2]REL0
[8QF0:n;F@020:j:F0030:f9E`2/R5H0[8QF0080ZhME202]RET20:j:FP80[h]K102`S5`30:n>F`<0
/8mL0P2aT5d01P2^RE`0[hYM0;2;GP2aS5l0/XeP0;B?HP80]I1S202aSEd80;6<G`@0/8eG0P2_S5H2
0:j;E@T0/HeM0P2_RUd20;2;GP80/HaO0P2bSF030;6=G@<0/XiN0P2cSel80;:>GPP0/hmO1@2dT603
0;FAH@80/hmO0P2bSUh40;6=G@P0[X]E00@0[HUI0:j:FP2^RUX0[h]K0P2`S5`20;6=G@030;6<G`2`
Reh0[XUL0080[HQK00<0[XUL0;2;GP2aS5l0202aSEd80;:<G@<0/HeM0`2bSUh20;>?G`P0/HeM202b
SUh0102/R5P0[XYJ0;2<G02bSUh20;>?G`050;6=G@2`S5`0[8QH0:b8F02]RET00P2^RUX00`2_Re/0
/8aL0;2<G0080:n:G@060;F9G02dR5/0]8QK0;:6F@2aQEP0/8AG0P2_PeH20:V5E@050:Z6EP2[QeL0
[8QH0:b8F02]RET00P2^RUX80;2<G0030:^7E`2]RET0[h]K0080/HeM00T0/8aL0:n;F`2]RET0/8eG
0;2<F02_ReL0[XYH0:j:FP2]R5/00P2/Qe/30;2<G0<0[h]K0P2^RUX30:b8F0<0[HUI0P2^RUX20:^6
F@80[8MJ00@0[HQK0:j9G02^RE`0[hYM0P2[QeL01P2ZQUH0ZHEE0:Z6EP2/R5P0[XYJ0:n;F`80Z89C
0P2YPe@30:Z4E@030:^5EP2ZQ5L0ZXAG00H0ZXAG00H0Z8E?0:V5D@2YQE40ZXID0:^7E`2[QUT20:b7
F`P0ZXEA0P2WPdl0102XQ500ZHEA0:V5D@2ZQU820:^7D`P0ZhIB00@0[XYF0:f9E@2ZQU80Yh=?0P2V
PTh00`2WPdl0Z8A@0:B0C0070:B0C080YX9>0P2WPdl0302XQ500ZHEA0:V5D@2ZQU80ZhIA0:Z5D@2W
PTh0YGm>0:AnC`2TOU40Y7eB0:EnD`<0YX9B0`2UPE420:B0D0050:F0B@2TOdP0Xgi90:5lB02QNdX0
0P2SODh00`2TOTl0YGmB0:R5C`020:N4CP030:J3C@2UPT`0Y85;0080Xh1:00P0ZHA@0:R3C`2VPDd0
YH1<0:AoB`2UP4`0YX5=0:N2CPP0YX5=202UPE400`2SOTX0Y7m;0:J1C@030:R3C`030:N2CP2VPDd0
Xgm?00L0Xgm?202SOTX80:AoB080Y81<0P2SOd/40:9nBP80XGi600T0XWm70:5nAP2OO4@0W7U109Qe
?@2FLc/0WgY30:1kA02QO4D00P2RODH00`2PNd@0WWU209eh@@0809ijAP080:B0D02SOdl0XGe=0:1l
C02QODd0XWi>0:B0D02VPU820:1iCP<0WgQ=0`2NMd`209]g@`0409ahA02MNDD0WGU509ijAP80Wg]7
0`2MN4`509iiC@0309]gA`2MNDT0X7a<0080XWi>00<0Wg];09]gA`2IMDD00`2LN4P509]gA`80X7]7
0`2QO4P50:9mB@80XGa800<0WgY609iiA@2MN4@00P2LMd<0402PODD0XGi60:9oA`2ROdL0XGi609ik
@`2LND40VWLo09Ue@@2JMT80W7Q409ijAP2MNDD0W7Q409Yf@P2IMD4409Qc?`@0VGA00`2MLD@309ib
A@80Wg=60P2KMDH309YdA@<0VG=40P2IMDD209QdA080Ug=30P2FLT800`2DL400UG5109Ib@P0209Mc
@`0309Ea@@2CKcl0TVhn00P0Tflo0`2GLD8[ooooo`00:_ooool0102KLCl0W79009ab@02MLd4209id
@P80WgE300H0VVe309Y^@@2KKd80W71109ea@02NLd0209md?`0809md@@2PMD80XGI30:9gA02QMT<0
WgA109aa?P2JKc`309ibA@80Wg=60`2PM4L0202JL3h0WG=10:1fA02SNDL0Y7Y80:9hAP2OMD<0W790
0P2MLD00102NLT40Wg=209mc@P2PM4<20:5eA00309ec@@2NM480WgE30080XGM500<0WgE309id@P2M
Ld40202OMD<0302UNDP0Y7Q70:=gAP2RMTD0XGE40:1d@`2OLd80WW910:1e@P2QMT<0XWM40:AiAP80
YW]800@0Z7e:0:YoC02[P4d0Xh160P2SOdD00`2TOD@0Y7]30:Ej@`020:Ii@P030:5hA02RNDD0Y7]7
0080YGa800<0Y7]70:9iA@2QN4@00`2UNT<00`2VNd@0Yga50:QmAP020:QmAP030:UmCP2WNd`0YWY;
0080Y7Q900L0YWY;0:MkC02YODh0Zh1=0:UnB`2WO4T0YGY70080Y7U600<0YW]80:MlB@2VODT00P2V
ODT30:MnBP80Z7m;202WOTX30:QmBP80ZGi;0`2ZOd`00`2ZPDd0ZH1<0:MnBP020:ImB@030:MnBP2Y
P4`0ZX5=0080ZX5=00@0ZH1<0:QoB`2XOd/0Ygi:0P2VODT0402WOTP0Z7m90:V0BP2ZPD/0Zh9<0:b3
C@2]Q4h0[XE?0:j3F02]PUL0[85F0:^0E@2ZOe@0ZGiC0:QmDP2WO5420:UoC@060:Z0CP2[PDl0[89@
0:f3D@2^Q580[hEC202/Pdl01P2]PUL0[H9E0:f2E@2]Pe<0[H=A0:f4D080[HA>00<0ZhIB0:Z5D@2X
Pdl00P2WPTh00`2XPdl0ZXEA0:^6DP080;26E0P0[XAB00D0[HMJ0:f7F02/QUL0[8IE0:^6DP020:Z5
D0030:Z5CP2YQ4d0ZHA@0080ZXEA00<0ZhIB0:b7D`2/Qe<00P2]R5@01P2`RUT0[hUH0:n:EP2^RE@0
[HQC0:f8D@80[8Q>0P2[Qdd0102[QTl0ZhIA0:^6D@2[QU820:^5E080[HQD00@0[8MC0:^6DP2YQ500
Z8=?0P2WPTh80:R3C`030:R3CP2VPD`0YH1;0080Y7m:00<0YX5<0:R3CP2ZQE000P2TOU420:=mD0<0
XWa?00D0XG]>0:AoBP2RODP0X7]609eh@`0209ag@P0309eh@`2NND@0W7I90080W7I90P2KMDP309Yd
A`0309Mb?@2HLch0VG@o0080VWE000/0VG@o09Qc?P2GLSd0Ug<o09Ea?@2CKc/0TVhj095]>@2CKc/0
U70l09Ib?P0808iZ=P0<08m/=P2=JCD0RfLc08YV=02:ISH0RfHi08eX?02>JCd0RV@g08US=P28HSD0
Qf4d0P26H3<208EO<P80QF0c0P24Gc8308=N<@03089M<023GC00Ped`00H0Ped`0`1nFBl507mJ<006
07E@=P1eD3D0MU4d07IB<01fDbd0MU<[0P1fE2L01P1hGRd0LePY06iC901]DRD0Ke@Y075E;@80Ke</
00X0KE4Z071=;`1_C2h0KTd^06]<;@1YC2`0Idd/06I<:`1UCB/0ITh/0`1UCB/206A<:P80Hd/Y00/0
J4l`06M>;`1VCBh0I4//06=::`1QB2T0H4LX05m69`1RBbT0H4TW05i79@0205a58`0305e6901NAbD0
GdPV00<0FDTU0P1HB2@305M78`0606119@1O@BD0Gd4U05i39P1MA2H0G4DV0P1JABH805a4:0<0Dd8T
0P1B@B<305508P04050m7`1A?R00Dd0R05E29080ET<U00D0ED8T05A18`1@@2H0D40V05519`020592
:00605=3:@1DA2X0E4@Z05E4:P1D@bT0DT4W0`1@?bD04P1A@2H0DT4W05U8:P1HAbT0EdHX05I59`1E
A2H0E4<U05=2901B@B<0ED4X05I2:@1HA2/0FDD/05Q4:`1F@RT0E40W05<o9P<0E4@S0P1EAB@305A4
8`0505];<P1EAB`0CShU04`l8`1>?RD00P1@@2L01@1??bH0BcLO04`h801>>R80D3`T0080DCdU00<0
D3`T04lk8`1??BL00P1>?2H00`1=>bD0C3XT04`j900204/i8`80CChW0P1<?BH01@1;?2D0BS/T04Xk
9019>R<0BClV0080B3hU00@0AcdT04Hl8`15>b80AC/R0P14>R401015>b80A3XQ04@j8@14>R4204<i
8080@SPO00H0AS/W04Dj9P14>BD0@cPT048g8`11=R82040e8@80@S/Q0P11>R04040i7`04044i9P10
>2D0@3PU040h9@80?cLT0P0n=R<203hi9@<0?CPT0`0l=b<803Pg8PP0?3LT0P0f=B4203Dd800403@c
7`0c<Qh0<c8N038a7@P0=34P0P0e<ah203@b7@0403Dc7P0f=1l0=cDP03Le80D0=c@Q0`0f<b000`0o
>RH0?STU03`g8`0203Xe8@0<03/f8P0m>2@0?STU03`j8@0o>b80@3`S048l9014?2D0Ac`V04Tm9`1:
?RP0AC/R0`16?2<204Lm9080B3hU0P1<@BD05`1?@B@0D4<S05=48`1EAB<0F4DT05U78`1OB2P0GTLW
05e69P1LABD0GDHV05i79`1PBBT0HDXZ05Q17`1KA280GdLU06=9:01XBb/0JDX[06]::`1ZBBX0JdlX
0080K50Y00<0KE4Z06iB:`1_Db`00P1`E2d01P1[EBH0KEDW06eE9`1`EBP0LUDY07EF:P80MeH[0P1i
Gb`03`1hGR/0MU`Y07EK:01fG2T0MedZ07YP;@1kHBh0Nf4`07aR<@1mHC40Of0a085Q<P22H380Pf4c
08EP<`0508ES<`<0QV@d00P0QV@g08MU>028IST0RFLj08]Y?02=Jch0SV`o08m]@080T6`h0P2AKCT3
099^>P0409=_>`2DL3`0U70l09A`?080UG4m0`2FLSh209Ea?@0409Ib?P2HM400VWI209]g@`@0WGU5
00@0WWY609mkA`2PO4P0X7a80P2QODT80:B1B`P0YH5=0P2XQ5000`2YQE40ZXIB0:^7D`020:b8E003
0:f9E@2ZQU80ZXIB00H0ZXIB0`2/R5@20:f9E@<0[XYF0`2_ReL00`2`S5P0/HeI0;:>FP020;:>FP03
0;:>GP2dT600]Y9R00<0^IEU00<0^9AT0;NCH`2iUFD00P2iUFD20;RDI0<0]i=S0`2eTfD20;JDIP<0
]iEW0`2iUFD20;RDI0<0]i=S0`2iU6L00`2jUFP0^iIY0;bGJP020;bGJP<0_9QX0P2kUfL20;ZFIP80
^IEU00H0^iMW0;ZFIP2hU6@0]Y9R0;FAH@2fTV820;NCH`P0^IMW202iU6L80;NEI`040;NCH`2hU6@0
^9AT0;VEI@80^YIV0P2kUfL80;VEI@060;ZHJP2iUfT0^IMY0;RFJ02gUFL0]YAV0P2eTfD0102gTVH0
^9=W0;RCI`2iU6P20;ZEJ@80^iIZ0P2jUVH20;VEI@<0^9AT00<0]i=S0;VEH`2iUF<01P2iUF<20;NE
I`80^9IX0P2iUfT20;ZHJP030;FCI@2fU6H0^9IX0080^IMY00<0^9IX0;JDIP2eTfD02`2gUFL20;JD
IP<0]I=U00H0^iIY0;ZEJ02iU6L0^9=V0;JAI02dSf820;>>H@030;:>GP2dT600]I5Q0080]Y9R00H0
]I5Q0;B@H02bSUh0]91P0;FAH@2fTV820;NCH`060;JBHP2eTF40]91P0;NBI@2eT6<0/hiQ0P2bSF00
0`2cSV40]I1S0;NBI@040;>AH`<0/Y1R0P2aSf480;B@H0060;6=G@2bSUh0/XiN0;B@H02eTF40]Y9R
0P2gTf<0202hU6@0]i=S0;FAH@2dT600/hmO0;B@H02eTF40]Y9R202eTF40102bSUh0/hmO0;>?G`2d
T6020;FAH@80]Y9R0P2dT6020;FAH@<0]Y9R00<0]i=S0;JBHP2fTV801P2fTV820;>?G`<0]91P0`2e
TF480;6=F@@0/8aL102aSEd30;2<G0<0[h]K0P2^RUX80:f9F@80[XYJ0P2_Re/40;2<G080[h]K00<0
/8aL0;6=G@2bSUh00P2dT6001P2eTF40[XYJ0:n;F`2_Re/0/8aL0;6=G@80/XiN00@0/hmO0;2<G02a
SEd0/hmO0P2dT6000`2cSel0/HeM0;2<G00;0;6=G@<0/XiN0P2cSel20;:>G0<0/HeK0`2`S5X00`2_
ReT0/XiN0;:>GP060;:>GP<0/8YK00<0/H]L0;:<G@2cSEh00P2cSEh0202eT6<0]91P0;:>GP2aSE/0
/HeI0;:?F@2dTET0]I9J0`2fT6400`2eSf00]8iO0;>=GP020;>=GP0@0:b8EP2^RUP0/HeM0;>>H@2e
T6@0]8mU0;>>I02cSFH0/XaM0;6;G02_REX0[XQI0:n9FP2bS5d0]HmP0;NAHP80/8eE00T0/8eG0:n;
E`2_ReT0[h]K0:j:FP2^RE`0/8aL0:n;F`2]RET00P2/R5P02@2]RET0[h]K0;2<G02aSE<0/HaE0;2;
EP2_REP0[hUL0:j7G0020:f6G`@0/8aH102aSET01@2^RUX0[h]K0:n;F`2`S5`0/HeM0080/XiN00@0
/hmO0;6=G@2aSEd0/HeM0`2bSUh20;>?G`<0]91P0P2cSel30;:>GPD0[hYM0`2`Reh30;6=G@80/8aL
0`2_Re/80;2;G`P0/8aL0P2_R5d00`2_RE`0[hUJ0:n9F0020:n:EP040:n:E@2/R5P0[8QH0:b8F0@0
[HUI0P2^RUX0402`RUd0[hUJ0:f7F02/QUD0[8MC0:f8D`2_RU<0/8]D0:Z6EP2/R5P0[h]K0;:>GP2c
Sel0/XiN0;2<G02^RUX80:j8F@80[XYJ0`2]RET30:b8F0030:n;F`2^RUX0[HUI0080ZhMG00@0[HUI
0:j:FP2_Re/0Zh=O0P2[Q5d00`2[Q5/0ZhAI0:^5F0020:^5EP030:j:EP2/R5@0ZhMC0080ZHEA00H0
ZhMC0:b8E02^RUH0[8QH0:^7E`2YQED20:R4E0030:V5E@2[QeL0[8QH00P0ZXEA00<0ZhMC0:Z6DP2Y
QE400P2XQ5000`2ZQU80[8QD0:j:EP030:Z6DP80ZHEA0`2XQ5020:J2DP<0Yh=C102XQ5@01`2ZQUH0
[8QH0:f9F@2]RET0ZhMG0:R4E02VPU80202XPdl20:V4C`80Z8=>0P2WPTd20:J1C0P0ZHEE00@0[XUE
0:b7D`2ZQE40Z8=?0`2VPDd0102WPTh0Yh5B0:J0D@2TOTl20:=mCP030:AnC`2VP540Yh5B00T0Y7m:
00H0XWa?0:9lC@2SODh0Y7i=0:J1C@2WPTd20:R3C0P0YX5=00<0Z8=?0:N2CP2UP4`00`2SOTX01@2U
P4`0YX5=0:=nBP2TOd/0YX5=00<0Z8=?00<0Yh9>0:J1C@2UPDd00P2UPDd20:B0C0<0Xgm;202UP4`2
0:5mB@80XWi:00d0Xgm;0:B0C02TP4`0YH5=0:5lB02RODT0YH1<0:N2CP2XPdl0Yh9>0:J1C@2UP4`0
YX5=0080YH1<00<0Y7m;0:=nBP2SOTX00P2RODT0102SOdl0XWi>0:1lC02NNTX209eiB@80WWY:00/0
XWi>0:5mC@2NNTX0W7Q809]gA`2LN4P0WGU909ijBP2QO4P0X7]709mjAP0209iiA@0C0:1kA`2RODT0
Xgi:0:EoD02VP540Yh5B0:R2D`2WPE80YX1A0:AnC`2RO4d0WGQ40:5lB02TOd/0XWe909iiA@2LMd<0
WgY60:=nBP0309iiA@D0WgY60P2NMT<0102MN4@0W7Q409eiA@2KNTD209]lAP0;0:1kA`2QO4P0Xgi:
0:AoB`2RODT0WgY609ag@`2JMD40VgI209ag@`2NNDD00`2ONTH01@2MN4@0W7M309miBP2QNd`0XWa=
00<0Y7i?0P2SODh02@2RO4d0X7e50:5nAP2QOTH0X7e509mlA02LND40VGHn09Qe?@0209alB`80Vg]:
102JNTT01`2KMd<0WGU509ijAP2ONdL0WWY609eiA@2KMd<00P2IMD403`2HM400Ug<o09Ib?P2GLcl0
VGE109]g@`2MNDD0WGA609U`@P2EKd00UW9209]gA`2LNTX0V7Q709Ad@`0209QdA080VGE500@0V7A4
09Mc@`2FLT80UW920P2FL4T01P2FLDD0UW5409Ib@02GM3h0Ug@l09Md>P<0V7A400<0Ug=309Ib@P2E
LD400P2ELD400`2FLT80U710099^?P0308m[>`03091/?02AKCd0TF`o0080TF`o:oooool002[ooooo
0`2KLCl00`2LLT00WG=109ec@@0209id@P0609Y]@`2JKT40Vfm209a`@@2MLD00WW=00P2OM3l00`2N
Ld00WgA10:1e@P020:5f@`0309md@@2MLSl0W74n00<0WW950P2OLdH30:1dA`0309Y`?P2LLT00X7I4
0080XgU700@0XGM509me@`2MLd40WG500P2NLT4209mc@P80X7A300@0XGE409id@P2OMD<0X7I40P2R
N4H00`2PMT@0WgE309id@P0809me@`060:EiB02TN4L0XgM60:9fA@2QMD@0X7A30P2OLd80102QMT<0
XWM40:=hA@2TNDH20:IkB0040:MlB@2XODX0ZGi;0:5nA080XWi400<0Xga30:=j@P2TND800P2UN440
0`2QN4@0XWU50:AkA`020:ElB0030:AkA`2RNDD0XGQ40080YGY30P2VNd@20:MlA@80Z7e600<0Z7a=
0:MkC02VNT/00P2UNDX02`2VNT/0Yg]<0:QlC@2ZOd`0ZGi;0:MlB@2UNTL0Y7U60:EjA`2VNdP0Yga9
00<0YWe90`2WOTX20:QoB`P0Ygi:0`2XODX20:UnB`<0ZWm<00<0ZX5=0:V0C02WOTX00P2VODT0102W
OTX0ZH1<0:Z1C@2ZPDd20:V0C080Z7m;0P2WOTX01`2VODT0Ygi80:QoB@2YP4X0ZX5;0:^2C02/Pdd0
0P2]Q4h20:f2E@040:b1E02[P5<0ZWmB0:UnD@80Z7e@0P2YOdd0102ZP4h0Zh5?0:b2D02]Pe420:j4
DPP0[8=?00H0[H9G0:f2E@2]PUD0[H=C0:f3D@2]Q5020:f4CP030:^6DP2ZQE40Z8=?0080Yh9>00<0
Z8=?0:Z5D@2[QU80202_QE<80:j4DP050:f7FP2]QeP0[8IG0:b6E@2[QU800P2ZQE020:Z5CP80ZXEA
0P2[QU820:b7D`80[HQD0P2_REP0102^RED0[XUD0:f8D`2]R5440:b8CP040:b7D02/Qe80[8MB0:b7
D`80[8IE0P2]R5@01P2/Qe<0ZhIB0:Z5D@2YQ500Z8=?0:N2CPP0Z8=?00<0ZHA?0:R3CP2VPD`00P2U
P4/00`2VPD`0Yh9=0:R3CP030:AnC`80Xge>0`2RO4d0102TOdX0XWe80:1kAP2NND@209eh@`80WWU4
0P2MMdP209afA`<0VgE600@0VWA509Mb?@2HLch0VWE00P2KMT401P2JMD00V7<n09Mb?@2GLcl0UW8n
09A`?080TVhj00<0Tflk09A`?02ELCd0202@K3P0202@KCL0Sf/g08eY=@2;IcD0RVHf08]V>@2<Ic/0
SFPl0P2:I3L00`29HcH0R68e08MQ=00208IP<`0408EO<P25H3<0QF0c08EP<`80Q5lb0`23GS4808AN
<@0608=N=022GC<0PE`b081K<@1nFBl0OEP^0P1lEbd03P1gDSL0Me8e07MC<`1gDc40N5D_07QE;@1h
EB/0N5HY07QN;@1cF2T0KU<T06iC9P1`EBX0LED]0P1`E2d01P1]DBX0L4d_071=;`1^CBh0K4d^06Y=
;@80Idd/00@0ITh/06M=;01WCB`0Idd/0P1VC2/306E;:P0606M<;P1VBbd0IT/]06E:;01TBB/0HdPZ
0P1RAbT00`1RBbT0HDXX05m89P0305e6900305m89P1PBBL0G4XV00<0FdTU0P1JB2@205U78`060652
9P1P@RH0H48V05i39P1MA2H0G4DV0P1JABH805]39`<0ED8T0P1D@B<305=08P04054n801B?b40E44S
05E29080ET<U00@0ED8T05A18`1@@2H0D40V0P1A@BL01`1B@RP0Dd<Y05=3:@1C@bT0ED@Z05A3:@1B
@BL00`1@?bD00`1A@2H0DT4W05Q7:@0205M6:00>05I59`1D@bD0Dd8T05=2901B@B<0ED4X05I2:@1G
@bX0F4@[05M3:P1F@RT0E40W05<o9P1C@b8605A48`0605=38P1IBC00Dd<Z04dm901;>b80CShU0P1A
@BP02@1??bH0BcLO04`h801>>R80D3`T054m9@1@?2@0Cc/S04hj8P0204dm9P80C3`U0P1;>b@204Xj
8`<0Bc`U00<0BS/T04Tj8`19>R<00P18>B8304Lm90<0AS`S1P15>b8204@j8@<0@cTP0P15>RH01014
>BD0@cPT048g8`11=R82040e8@80@S/Q0P11>R03040i7`0303lh7P10>2D0@3PU0080@3PU0P0o=b@2
03hf8`80?CPT0`0l=b<303/f8PP0>3LR200k=R<303He8@0303Dd800d<al0=3<O0080<c8N200e<R40
0`0d<Qd0=C<N03Hd7`0503Le80D0>3DR0`0g=2404@11>bD0@3XT03hh8P0m=b40?3HP03dg8@0o>B<0
@3XT03lk8P10?2<0@S`T04@l9@17?2H0BCdW04Xn:01<?BP0Ac/S00<0B3`T0P19?BD204Xn9P0H04a1
9@1=@R@0D48U0593901EAB@0F4DT05U78`1KAb@0H4TY05m8:01NAbL0GDHV05i79`1OB2P0HDXZ069;
:`1NAbD0H4TW06A<:P1XCRd0K4l_06i?<01`Cc00Kdh_0P1/D2T00`1]DBX0KU8[06mC;002071D;@07
075E;P1]EbP0KeLY06mG:@1bEbX0M5L[07MH;00207UH;@80NEl/00L0N5h[07MM:P1fG2T0MedZ07QN
:`1jH2d0O68_0080O68a00<0OF4a081Q<P21HC800P23HC<01025H3<0QF<c08ES<`25Hc<308IT=080
QfDe0P27ICP01P29IcX0RVPk08aZ?@2=Jch0SV`o08m]@0<0TFdi0P2BKSX309=_>`0409A`?02ELCd0
UG4m09Ea?@80UW8n0P2GLcl01P2ELCd0UW8n09Mc?`2IMD40VWI209ahA0@0WGU500<0WWY609mkA`2P
O4P00P2QODT00`2ROTX0Y85;0:B1B`060:B1B`P0YX9>0P2XQ500102YQE40ZXIB0:^7D`2/R5@20:f9
E@P0ZhMC0P2/R5@20:f9E@<0[XYF0P2_ReL20;2<F080/HeI0P2bSUX01@2cSe/0/XiN0;B@H02fTV80
^9AT0080^IEU00<0^9AT0;NCH`2iUFD00P2iUFD20;RDI0<0]i=S0P2eTfD30;JDIP<0]iEW0`2iUFD3
0;RDI080]i=S0P2iU6L20;ZEJ080^iIY0P2lUfX30;bHJ080^iMW0P2jUVH20;VEI@080;bHJ02kUfL0
^IEU0;NCH`2fTV80]i=S0;RDI02iUFD80;VGI`P0^IAW202gUFL30;RDI0030;VEI@2jUVH0^YIV0080
^iMW202iUFD30;RFJ0<0]iEW0P2fU6H30;RCI`030;VDJ02jUFT0^YEY0080^iIZ0P2kUfL20;ZFIP<0
^IEU00<0^9AT0;VEH`2iUF<01P2iUF<20;NEI`80^9IX0P2iUfT20;ZHJP030;FCI@2fU6H0^9IX0080
^IMY00<0^9IX0;JDIP2eTfD02`2gUFL20;JDIP<0]I=U0P2iU6L00`2hTfH0]i9U0;JAI0020;F@H`04
0;B?HP2cSel0]91P0;FAH@80]Y9R00H0]I5Q0;B@H02cSel0]91P0;FAH@2fTV820;RDI0060;JBHP2e
TF40]91P0;JAI02eT6<0]8mR0P2cSV400`2dSf80]I1S0;JAI0040;>AH`80/Y1R0`2aSf480;B@H005
0;6=G@2bSUh0/XiN0;>?G`2eTF400P2fTV802@2gTf<0^9AT0;NCH`2eTF40]91P0;>?G`2dT600]I5Q
0;JBHP080;FAH@<0/hmO00<0]91P0;FAH@2eTF400P2fTV820;B@H080]I5Q102fTV880;FAH@80/hmO
0`2dT6030;FAH@P0/XiJ102`S5`40;6=G@<0/8aL0`2_Re/20:j:FPP0[h]K0P2^RUX20:n;F`<0/8aL
00T0/HeM0:n;F`2_Re/0/8aL0;6=G@2bSUh0/hmO0;B@H02eTF40102`S5`40;6=G@030;2<G02aSEd0
/hmO0080]91P00<0/hmO0;6=G@2`S5`02`2aSEd30;:>GP80/hmO0P2bSU`30;6=F`@0/8aJ202bSUh2
0;2:F`80/H]L0P2bS5d20;>=GP080;F@H`2dT600/XiN0;6=F`2aSET0/XmI0;BAF@2eTUX20;F?H080
]8iO0P2cSEh20;:<G@0:0:f9E`2^RUP0/HeM0;>>H@2dSf<0]8mU0;>>I02bS6D0/XaM0;6;G0<0/8YK
00<0/XaM0;>=GP2dSUl00P2`SED02@2`SEL0[h]G0:n;F@2_Re/0[XYJ0:j9G02`S5`0[h]K0:f9F@02
0:b8F0030:f9F@2_Re/0/8aL0080/HaE00H0/8]G0;2:F@2_RE`0[XML0:j7GP2^Qf040;2<F0@0/HeI
102`S5`70;6=G@<0/XiN0P2cSel20;B@H080/hmO0`2bSUh00`2aSEd0[hYM0:n:G@040:n:G@80/8]N
0P2bSUh30;6=G@<0/8aL202`Rel80:n;F`80[hQM00<0[hUL0:n9FP2_REP00P2_RUH0102_RUD0[8QH
0:b8F02/R5P40:f9F@80[XYJ00d0/8YM0:n9FP2]QeP0[8IE0:b7D`2]R5<0[hYC0;2;E02/R5P0[HUI
0:n;F`2`S5`0/HeM0080/8aL00<0[h]K0:j8F@2^R5T01P2^R5T20:j:FP<0[HUI0`2/R5P00`2^RUX0
[HUI0:b8F0020:Z6EP030:b8F02]RET0[XYJ0080[8EN00<0[8EL0:b5FP2/QUT00P2/QUL0102/QUD0
[HUE0:b8E02[Qe<20:Z6DP060:^7D`2/R5@0[HUE0:b8F02[QeL0ZHEE0P2XQ5@00`2YQED0ZhMG0:b8
F0080:Z5D@080:^7D`2ZQU80ZHEA0:R4D02YQE40ZXIB0:b8E02]RED30:Z6DP80ZHEA0`2XQ5020:N3
D`<0Z8AD0`2YQED00`2ZQUH0ZhMG0:^7E`020:^7E`030:Z6EP2XQ5@0Z8AD00P0Z8=?0P2YQ4l20:R3
CP80Yh9=0P2VPD`80:V5E@040:b7D`2[QU80ZHA@0:N2CP80YX5=00D0Yh9>0:R3C`2WPE80YX1A0:An
C`020:=mCP030:AnC`2VP540Yh5B00T0YX5<00H0XWa?0:=mCP2TOTl0YGm>0:J1C@2WPTd20:R3C0P0
YX5=00/0Z8=?0:N2CP2UP4`0Y7m;0:=nBP2TOd/0YH1<0:J1C@2SOTX0Y7m;0:J1C@030:R3C`030:N2
CP2VPDd0YH5=0080YH5=0P2TP4`30:=oB`P0YH1<0P2QODT20:9nBP070:=oB`2TP4`0Y81<0:B0C02Q
O4P0Xgi:0:F0C0030:N2CP040:J1C@2UP4`0YH1<0:F0C080Y7m;0P2SOTX20:9mB@040:=oC`2ROTh0
X7a<09ijBP80WGU900D0WWY:09mkB`2QODd0Wg];09eiB@0309ahB00509ijBP2ONd/0XGa80:1kA`2O
NTH00P2NNDD01@2PNdL0XWe90:=nBP2TOTl0YGm@00<0YX1A00/0Y7i?0:=mCP2QNd`0WGQ40:5lB02T
Od/0XWe909iiA@2LMd<0WgY60:=nBP0209iiA@H0WgY60P2NMT<0102MN4@0W7Q409eiA@2KNTD209]l
AP@0XWe900L0XGa809mjAP2MN4@0W7M309]f@P2LMd<0WWU50080WgY600H0WWU509ehA02LMd<0WgU:
0:1jB`2RO4d20:AnC`040:=mCP2RO4d0XWa=0:5kC080X7e500H0XGi60:1mA@2OO4@0W7U109Yg?`2H
MCd609YjB@80Vg]:00<0W7Q409eiA@2NNTH00P2NNTH01@2LN4@0VWI209Ue@@2IMD40V7A000<0Ug<o
00h0VGE109]g@`2LN4@0WGA609U`@P2EKd00UW9209]gA`2KNDT0V7Q709Ad@`2JMTH0VGE509QdA0D0
Ug=300H0UW1909IaA`2FLDD0UW5409Ib@02FLSh209Ic>`80UG510P2DL400202CKcl0TVhn099^?P2B
KSh0UW9209A`@02BKSh0T6`l0P2?Jc/00`2@K3`0TFdm095/?`02095/?b_ooooo000Zooooo`<0VW0n
0`2KLCl209ab@00609Y]@`2JKT40Vfm209a`@@2MLD00WW=00P2OM3l00`2LLCh0WG8o09ic@0030:1e
@P0309md@@2NLd00WW950080WW950P2OLdH30:1dA`0309Y`?P2LLT00WgE30080XWQ600<0XGM509id
@P2MLd400`2NLT4209mc@P<0X7A300<0WgE30:5gA@2RN4H00P2SNDL00`2RN4H0XGM509me@`0809me
@`80Y7Q70P2SMdH01@2RMTD0XGE40:1d@`2PM4<0XgQ500<0Y7U60`2UNTL20:IkB00609mlA02PNd@0
X7]40:5j@`2RND<0XgQ30P2TMT800`2QN4@0XWU50:AkA`020:ElB0040:AkA`2RNDD0XGQ40:EjA@<0
YW]60`2WO4L0102XODP0Z7a;0:MkBP2VNTT20:EiB0060:IjB@2WNdX0Z7a;0:UnB`2XODX0Yga90`2U
NTL00`2VNdP0Yga90:ImB@020:ImB@<0Ygi:0P2XOd/80:MnBP<0Z7e:0P2YOT/30:YoC0030:Z1C@2Y
P4`0Z7m;0080Ygi:00<0Z7m;0:V0C02ZPDd00`2YP4`20:QoB`<0Ygi:0P2XOdT20:V0BP050:Z1B`2[
PT`0[8==0:b3C@2]PUD00P2/PE@01@2[P5<0ZWmB0:UnD@2YOU40Z7e@0080ZGm=00@0ZX1>0:^1C`2/
PU00[89@0P2]Pe480:b3C`060:f2E`2]PUD0[H9E0:f3D`2]Pe40[HA@0P2]Q4h00`2[QU80ZXEA0:V4
D0020:R3C`030:V4D02ZQE40ZhIB0100[XAB00D0[8II0:b6E`2/QUL0ZhED0:^6DP020:^6D@80ZXE>
0`2[QU830:b7D`80[HQD0P2^R5L0102^RED0[HQC0:f8D`2]R5420:b8CP80[HU?00@0[HQA0:f8D`2]
R5<0[HQD0P2]QeH20:f8E0030:b7D`2[QU80ZXEA0080ZHA@2@2XPdl0102[QU40ZXE@0:R3CP2WPTd4
0:J1C080YGm@0P2TOTl30:=mCP050:9lC@2SOTT0XWe80:5lA`2ONTD00`2NND@00`2ONTD0WWQ909ih
B@0209egB0<0W7I700@0VgE609Qc?P2IM3l0VWE00P2KMT400`2JMD00VG@o09Qc?P0209Mc?`0309Ea
?@2DL3`0Tflk0080U70l00<0UG4m099^>P2BKSX01P2BKSX01P2BKcT0TFdi08m[=`2=JCL0RfLg08]V
>@80RfHj0P2;ICP208YT=`0408US=P28HSD0QV0c08IP<`80QV4d0P25H3<308AO<P0308=N<@24GS40
Q5ha00H0Q5ha00T0Qf8h08IQ=`24GcD0PE`b07mJ<01mF2h0NeH/07YE:`1kEcL00P1jES@00`1iEC40
NEH`07YG;`0207YG;@0607UM;@1eFBX0L5@U071C9`1cER`0M5L_0P1bE2h01P1_DB/0LDh^071=;@1_
CRd0KDl]06]>;080JDl/00@0Idl[06Y=:`1ZCB/0JTd[0P1YC2X306Q;:@P0ITTY00D0Hd/Y069::01Q
BBL0H4PV05m79@0206189P0406599`1LBRH0G4XV05a:9P80FdTU0`1JB2@01P1Q@RH0H48V06129P1N
@bH0GD@V05a59P80FTDV201J@RH305I39@80ED8T0`1D@B<00`1A?R00Dd0R05A18`0305I39@80E44S
00@0DD0V05919`1B@BL0DT4W0`1C@RP0101D@bT0ED@Z05A3:@1B@BL3050o9@0305509P1B@BL0EdHX
0080ETDW00<0ED@V05A39@1C@R@00P1B@B<0201E@BP0ET8Y05I2:@1G@bX0ET8Y05E1:01D@2L0DclV
0P1C@R@405918`80Dd8T00D0ETH]05109`1;>b80Bc/R04hn9@020551:00405109`19=al0BcTQ04`j
8P<0CS`T00<0C3XR04/i8@1<?2D00P1<?2D304/k9080BSXS0P17>b<204Hj8P@0ACTQ0`15>b8304Hl
8`<0AcdT0`16?2<204Dk8P<0A3XQ0P14>BD204<h9004048g8`11=R80@3DQ040e8@<0@CXP0P10>Al3
03lh7P<0@3PU0P0o=b@303hf8`<0>cHR0`0j=B4203Td80P0>SPS200j=B8403Ld8@80=S<P0P0e<Ql8
03Pc800303Ha7@0g<Qh0>SDQ0080?3LS00<0>cHR03Td800h<al0200k=R800`12>RD0@CTT040h8`02
040h8`04044i9012>RD0@SXU044m8P80@cdS00D0AChT04Pn9@1:?RH0C3dV04dn9`0204Tm8`80BShT
0`1;?bD05`1<@2H0D48U05539P1CA2D0EDDT05M79@1JB2@0G4PU05a88`1RBbT0HDXX06199`1OB2H0
H4TW065::01SC2X0I4d[06A>:@1VD2/0JE4]06aB;`1`Dc40LU@b0080ME@c00H0KE4Y06iB:P1^DRX0
Ke<[071D;01aEBd2079F;P06071J:`1aFB/0LUX/07EJ;@1gFRh0NU/_0P1lFc0207]O;@80NUh/00D0
NEd[07YN;01kGbd0O60^07eQ;`0207eS<P0307iR<P21HS<0PV8c0080Q68d00@0QV4d08IT=026I3@0
QV@d0P27ICD308QV=P0608QV>029IcT0RVPj08]Y>`2=Jcd0SV`n0P2?KCl3099^>P80Tflk0`2DL3`0
102ELCd0UW8n09Ib?P2FLSh209Mc?`80V7A00P2GLcl01@2HM400VWI209]g@`2LN4@0WGU500<0WWY6
00<0Wg]70:1lB02QODT00P2ROTX00`2SOd/0YH9<0:F2C0060:F2C0P0YX9>00H0Z8A@0:V5D@2YQE40
ZXIB0:^7D`2/R5@<0:f9E@80[XYF0`2_ReL00`2`S5P0/HeI0;6=F@020;6=F@80/XiJ0P2cSe/00`2c
Sel0]91P0;JBHP020;RDI0030;VEI@2hU6@0^9AT00<0^IEU0P2hU6@30;NCH`040;FCI@2fU6H0]YAV
0;JDIP80]iEW0P2hUVP20;ZFIP80^IEU0`2hU6@00`2gTf<0^IAW0;ZEJ0020;ZEJ0<0^iIY00@0_9MZ
0;bHJ02lV6P0_9QX0P2kUfL20;ZFIP80^IEU00<0_IUY0;bHJ02jUVH00P2hU6@00`2iUFD0^YIV0;^G
I`080;VGI`P0^IAW202gUFL20;RDI0<0^IEU0`2jUVH80;VEI@80]YAV0`2gUFL30;RFJ080^9=V0`2i
U6L30;ZEJ080_9QX0P2kUfL30;ZFIPT0^IEU0P2gUFL20;RFJ080^IMY0P2jV6X00`2fU6H0]iEW0;RF
J0020;VGJ@030;RFJ02gUFL0]YAV00/0]iEW0P2fU6H30;FCI@P0]i9U00<0/hmO0;B@H02fTV800P2g
Tf<01P2fTV80]91P0;>?G`2dT600]I5Q0;NCH`80^9AT00D0]i=S0;FAH@2dT600]Y5T0;F@H`040;B?
HP040;F@H`2fTF@0/i5S0;>AH`<0/Y1R0`2aSf400`2`SV00]91P0;B@H0060;B@H0060;6=G@2bSUh0
/XiN0;>?G`2dT600]I5Q0P2fTV800`2hU6@0]i=S0;FAH@020;>?G`030;B@H02eTF40]Y9R00P0]I5Q
0P2cSel30;B@H0<0]I5Q0`2dT6020;FAH@<0]Y9R2P2cSel30;B@H0<0]I5Q202dT5`40;6=G@L0/8aL
0`2_Re/20:j:FPP0/8aL0`2_Re/20;2<G0<0/HeM00H0[h]K0;2<G02`S5`0/HeM0;:>GP2cSel20;B@
H0@0/HeM1@2`S5`01`2aSEd0/XiN0;>?G`2cSel0/XiN0;6=G@2`S5`02`2aSEd30;:>GP80/hmO0`2b
SUh30;6=G@<0/8aL202aSEd0102`RU/0/H]L0;6;G02aRe`30;:<G@090;>=GP2dSf80/hmO0;:>GP2a
SE/0/HeI0;:?F@2cT5P0]95I00<0/heN0P2bS5d30;6;G0050:j:F02_ReT0/8aL0;:=H02cSV800P2c
SV@00`2bS6D0/H]L0;:<G@030;>=GP030;6;G02`RU/0[hUJ0080/8eE00H0/8eG0:n;E`2_ReT0[h]K
0:j:FP2^RE`20:n;F`@0[HUI0P2_Re/0202aS5L0/8]G0;2;E`2`RUT0[hUJ0:n9G02_R5d0[XML102a
SET40;2<F0@0/HeM102`S5`30;6=G@<0/XiN1@2cSel20;:>GP<0/HeM202_RUd30;>?G`80/XiN0`2a
SEd80;2;GPP0[HUI0P2^Qe`00`2^R5/0[XQI0:j8E`020:j9E@040:j9E02/R5P0[8QH0:b8F0@0[HUI
0P2^RUX02@2`RUd0[hUJ0:j8F@2]QeH0[HQD0:j9E02_RU<0/8]D0:n;F`020:j:FP050:f9F@2^RUX0
[h]K0;2<G02aSEd0202]QeP20:j:FP<0[HUI0`2/R5P00`2]RET0ZhMG0:Z6EP020:V5E@040:Z6EP2[
QeL0[HUI0:f6G`80[HIM00<0[HIK0:f7FP2]QeP00P2]QeH00`2]RED0[8QD0:^7D`020:Z6DP060:^7
D`2/R5@0[HUE0:^7E`2ZQUH0ZHEE0P2XQ5@00`2YQED0ZXIF0:^7E`080:Z5D@80ZXIB0`2YQE400`2Z
QU80[8QD0:f9E@030:Z6DP80ZHEA0`2XQ5030:V5E@<0ZXIF0P2[QeL0102/R5P0ZhMG0:Z6EP2YQED2
0:R4E0030:V5E@2ZQUH0Z8=?00L0Z8=?0P2YQ4l20:R3CP80Yh9=0P2VPD`80:R4E0030:Z5D@2YQ500
Yh9>0080YX5=00<0Yh9>0:R3C`2YQ5000P2VP5440:AnC`80YX1A2@2WPTd01P2SOE00Y7i?0:AnC`2U
Odh0YX5=0:N2C@80Z8=<202VPDd0102XPdl0Yh9>0:J1C@2UP4`20:AoB`050:F0C02VPDd0Xgi:0:Ao
B`2VPDd00`2XPdl00`2WPTh0YX5=0:F1C@020:F1C@80Y81<0`2SOd/80:AoB`<0XWi:0`2SOd/20:B0
C0030:=nBP2TOd/0YH1<00<0YX5=0P2UP4`30:AoB`<0Xgi:0P2RODT0102TP500XWi>0:1lC02NNTX2
09eiB@0309ijBP2ONd/0WWY:0080WGU900P0W7Q809eiB@2NNTX0Wg];0:1lC02QO4P0X7]709mjAP80
WWU500D0X7]70:9mB@2SOTX0XWa=0:=mCP030:AnC`0;0:9lC@2QNd`0WgU:09iiA@2PNdL0XWe90:5l
B02ONTH0WWU50:1kA`2RODT0202ONTH209if@`0409ehA02LN4@0WGU509]jA@80Vga600@0Y7m;0:9m
B@2QO4P0WgY60P2NNDD209mjAP0309ag@`2MN4@0WWU50080WgY600H0WWU509ehA02LMd<0WWQ90:1j
B`2QNd`30:=mCP80XWa=00<0XG]<09mlAP2PODL00P2PODL01@2OO4H0WGY409Yg@@2HMCl0V7I60080
VGM700D0VWQ809]iB@2LNTX0W7Y:09ekB`0209ahA0<0WGU500@0W7Q409Yf@P2IMD40VGE10P2HM400
5@2GLcl0V7A009Ue@@2JMT80VgM309acA@2JLD<0UW1109Mc@`2JMTH0VGM709MgAP2DM4<0W7Q809Yf
AP2HM4@0UW9209Ea@@2FLT80V7A409UeA@0209IaA@0309IaA02FLT80UW900080UW8n00@0UW<m099^
?P2BKSh0TVhn0`2AKCd2091/?00309Ea@@2DL400TVhn0080T6`l00<0Sf/k091/?02@K3`00`2AK3l[
ooooo`00:_ooool309U_?@D0VW0n00H0VVe309Y^@@2KKd80W71109ea@02NLd0209md?`0409]`?@2L
LCh0WG8o09ic@080WgA10P2PMD8309ibA@80Wg=60`2PM4L0202KLCl0W79009id@P2PMT@0XGM50:1f
A02NM480WG=1202OLd800`2PMT@0XWQ60:=iA`020:AjB0030:=iA`2RN4H0X7I400P0WgE30P2TN4L2
0:=gAP80XWI50P2QMD@30:EjA`H0Y7U600H0WW]509mjA@2NND@0X7Q40:5hA02RMd@20:AfA0030:5h
A02RNDD0Y7]70080YGa800<0Y7]70:9iA@2QN4@0102VNdP60:MlB@@0YW]81@2WO4T40:IkB0040:Ml
B@2VODT0YWe90:ImB@<0Ygi:0P2XOd/80:MnBP<0Z7e:0P2YOT/30:YoC0P0ZH1<202XOd/20:QoB@80
ZH1:0P2ZPD/20:^2C080[89B0P2[PE420:Z0D080ZGm?0P2YOdd20:Z0CP040:^1C`2/PU00[89@0:b2
D0P0[8=?00H0[H9G0:f2E@2]PUD0[H=C0:f3D@2]Q5020:f4CP<0ZXEA0P2YQ5030:Z5D@P0[89@202^
Q5801@2/QUT0[8IG0:^5EP2[QE@0ZhIB0080ZhIA0P2[QTl60:b7D`80[HQD0P2]QeH0102]R5@0[HQC
0:f8D`2]R5420:b8CP80[XY@00@0[XUB0:j9E02^RE@0[XUE0P2^R5L00`2]R5@0[8MC0:b7D`020:^6
DP80ZXEA2@2YQ5001@2/Qe80ZhIA0:Z5D02YQ4l0Yh9=0080YX5<00<0YH1;0:J0C`2VP4l00P2UOdh3
0:AnC@050:=mC02SOTT0XWe80:9mB02QO4L0102PNdH309miB080WWQ70`2MMdH00`2IM3l0VWE009]f
@@0209ag@P0309]f@@2JMD00VG@o0080V7A000<0Ug<o09Ib?P2ELCd02`2DL3`01P2CL3X0TVhj095]
>@2?JcT0SFTi08]V>@80RVDi00P0RfDh08aV>@2<IST0S6Hi08]U>029HcH0Qf4d08IP<`80Qf8e0P26
HC@308EP<`0308AO<P25Gc80QElb00H0QElb0P25H3H01024GcD0PUdc085L<P1oFS0207iI;`80OU/e
00`0O5Tc07]H<P1kF300NeP`07aI<@1mFS00Ne`]07MH:P1dEBL0M5DY07MG;P1hF34207EE;`09079B
;01aCb`0LDl/071?;01^D2`0KE4/06]A;01ZD2/0JE4[00@0JdlZ0P1ZCRT206U=:080I4LU00@0IDPV
06I99`1VBBL0IdXX0P1XBbT00`1UBbX0I4XY06A::@0206=9:080HTPW00@0HdTX05i:9`1NBRL0GTXW
0P1MBBH305a89@0606=4:01Q@bL0HD<W05m49`1NABL0G4DV0P1JABH805Y29P80F4<V0`1G@RD305I1
900805=08P1D@B<0ED8T05I39@1GA2H0ET<U05A18`1C@28805A09`0305E4:P1D@bT0DT4W00<0D3lU
00@0DD0V05919`1EA2H0ED@V0P1D@bD205=29080DT4S101E@BP205A09`80DclV00<0Dd8V05919@1A
@2@00P1@?b<01@1A@2@0DT4U05=29P1C@bX0CShU0080BSXQ00`0CShU0551:01A@BP0CclV04Ti801:
>R40Bc/R04`l8`1=?B@0C3`S04Xj8@19>B0604Xk9080BCXS1@13>B03048h7`0504<i8014>R40A3XQ
04Dk8P16?2<00P17?B@204Pn9@<0AS`S0P15>b8304@j8@<0@cPT00<0@SLS044f8P11=R800P10=B42
044j80<0@3TO0`0o>1h2040h9@80?cLT0P0n=R<203de8P<0>SDQ0`0i=20203Pc7`P0?3LS200i=243
03Xe8PD0>C@Q200k=240200h<Ah0>S<P03df8`0o>2D0@3TV03hg900l=B80>S<P100n>28403li8`D0
@c/T0P14?2D01`15?BH0AD0S04Ho8`16?b<0BClT04/o9@1=?bD00P1??bH0101=?b@0CT0U04i09@1>
@2D204m19P80D48W0100DTDU05A59P1FARD0EdLU05]99@1MBB@0H4XU065;901TCRT0HddX069<9`1Q
BbH0HT`W06==:01UCbX0IU0[0P1WDBX01P1ZDR`0KE<^071D;`1cEC40ME@a07IE<P80Ke@Y00@0L5DZ
075F:`1bEb`0LeP]0P1dFBh0201cGBh0M5`^07EM;`1hGC00NUda07eN<P1nGC80Oehc1P1nH2h0301o
HBl0P68`081R<01nI3<0OfDd081T=022Hc@0Q6@e08ES=@26I3H0R6<f08IT=080QfDe00<0R6Hf08UW
=`29IcL00`2:J3P01@2;JCT0S6Xj08e[>`2>K3`0Sfdm0080T6hn0P2CKc/209A`?0@0UG4m0`2GLcl2
09Qd@0D0VGE100D0VWI209]g@`2LN4@0WGU509ijAP0309mkA`040:1lB02QODT0XWi:0:9nBP80Xgm;
202UPT`80:N3C`80ZHEA00<0ZXIB0:^7D`2/R5@00P2]RED90:j:EP<0[h]G0`2`S5P20;6=F@@0/XiJ
102cSe/0102dT600]I5Q0;JBHP2gTf<20;RDI0D0^IEU0P2hU6@30;NCH`<0]YAV0P2gUFL30;RFJ0<0
^YIV0P2iUFD30;RDI0@0^YEX102kUVT30;bHJ080^iMW0P2jUVH20;VEI@030;fIJ@2lV6P0^iMW0080
^IEU00<0^YIV0;^GI`2lV6P0202iUfL80;VDI`P0]iEW1P2iUFD20;ZFIPP0^IEU0P2eTfD00`2fU6H0
]iEW0;RFJ0020;VGJ@030;ZHJP2iUFD0^IEU00@0^IEU0P2jUVH40;bHJ080^iMW0P2jUVH80;VDI`80
]iEW0P2hUVP20;VGJ@80^YQZ0`2gUFL20;RFJ0h0]iEW0P2fU6H30;FCI@80]I1S0P2fTF@01`2gTVD0
^9=V0;RCIP2iU6L0/hmO0;FAH@2fTV800P2gTf<01P2fTV80]I5Q0;>?G`2eTF40]Y9R0;NCH`80^9AT
00@0]i=S0;JBHP2eTF40]Y5T1P2eT6<00`2fTF@0/Y1R0;:@HP020;:@HP<0/HmQ0P2`SV080;B@H0<0
/XiN00<0/hmO0;B@H02dT6000P2eTF401`2hU6@0]Y9R0;B@H02cSel0/XiN0;>?G`2dT6002@2eTF46
0;B@H080]I5Q0P2cSel20;B@H080]I5Q0P2fTV880;6=G@80/hmO0`2dT6030;FAH@P0]I5M102aSEd7
0;2<G0<0[h]K0P2^RUX80;6=G@80[h]K0`2`S5`30;6=G@80/8aL0P2aSEd00`2bSUh0/hmO0;>?G`02
0;>?G`80/XiN00H0/HeM0;2<G02_Re/0[h]K0:j:FP2aSEd60;:>GP030;6=G@2bSUh0/XiN00H0/XiN
0`2aSEd30;:>GP80/hmO0P2cSV430;:=H080/HaO0P2`Reh80;6=G@@0/H]L102bS5d01P2bSF00/XiN
0;:>GP2bSU`0/XiJ0;:?F@80/XmG202aRe`20:n;F@030;2<G02aS5l0/XeQ0080/XeS00T0/XaU0;6;
G02bS5d0]8iO0;F?H02dSUl0/H]L0:j8F@2/QUL00P2`SED01P2`SEL0[h]G0:n;F@2_Re/0[XYJ0:j9
G0P0[XYJ0`2`RUT30;2:F`80/8YM102aSET40;2<F0050;>?G`2bSUh0/XiN0;6=G@2`S5`00P2_Re/0
102^RUX0/HeM0;6=G@2aSEd30;:>GP80/hmO0`2bSUh20;6=G@<0/8aL0`2`Reh40:n:G@030:j9G02d
T600]91P0080/hmO0`2bSUh00`2aSEd0/8aL0;2<G0060;2<G0P0[8QH0P2^Qe`00`2^R5/0[XQI0:j8
E`020:j9E@040:j9E02/R5P0[8QH0:b8F0@0[HUI0P2^RUX02`2aReh0[hUJ0:j8F@2]QeH0[HQD0:j9
E02_RU<0/HaE0;6=G@2_Re/0[HUI0080ZhMG00<0[HUI0;2<G02bSUh0202]QeP20:j:FP<0[HUI102/
R5P0202ZQUH0ZHEE0:R4E02XQ5@0ZHEE0:Z6EP2/R5P0[XMN0P2^Qe`00`2^R5/0[XQI0:j8E`020:j9
E@80[8QD102[Qe<20:b8E0030:^7E`2ZQUH0ZHEE0080Yh=C00<0ZHEE0:Z6EP2[QeL0202ZQE430:V5
D@80ZXIB0P2[Qe<0102/R5@0ZXIB0:Z6DP2ZQU820:V5D@<0Z8A@0`2ZQUH30:^7E`80[8QH00P0[HUI
0:b8F02YQED0Yh=C0:J2DP2WPe<0ZHEE0:^7E`P0ZHA@0P2YQ4l20:R3CP80Yh9=0P2VPD`80:N3D`80
Yh9>0`2UP4`00`2WPTh0Z8=?0:Z5D@080:EoD0T0Z8=>00P0Y7iA0:EoD02UOe00YX1?0:J1C@2WPTd0
Yh9;0:R3C0P0YX5=00@0Z8=?0:N2CP2WPTh0YX5=102UP4`00`2SOTX0Y7m;0:J1C@030:R3C`030:N2
CP2VPDd0YH5=0080YH5=0P2TP4`30:=oB`P0Y7m;0P2ROTX60:=oB`80Y7m;0P2UP4`0102VPDd0YH1<
0:F0C02UP4`60:=nBP80XWe900@0Y81@0:=oC`2QODd0Wg];0P2NNTX209mkB`<0W7Q800<0WGU909ij
BP2ONd/00P2PO4`00`2QO4P0X7]709mjAP0209iiA@0=0:1kA`2RODT0Xgi:0:1jB`2QNd`0XWa=0:=m
CP2RO4d0XG]<09miBP2NN4T0WWU509mjAP040:1kA`030:5lB02RODT0X7]700@0WgY60`2NNDD209if
@`0409ehA02LN4@0WGU509]jA@80Vga600<0YH1<0:=nBP2PNdL00P2MN4@00`2NNDD0X7]70:5lB002
09ehA0<0WgY600T0WWU509ag@`2KMT80WGM809miBP2QNd`0XWa=0:=mCP2RO4d00P2QNd`00`2PNT/0
Wg]709mkA`020:1lB00:09mkA`2MNDD0VgM309Ue@@2HM4@0VGE509YfAP2KMdL0W7Q809ijBP80Wg];
1@2LN4@00`2KMd<0VWI209Yf@P0209Ue@@<0V7A00P2IMD40302JMT80Vg9409Ya@`2HLT<0Ug=309Qd
A02GMDD0UGE409Ad@`2MNDT0VgM709QdA080UG5100<0UW9209UeA@2KMdL00P2FLD@00`2FLT80UG51
09Ea@@0209Ea?`0309A`?P2CKcl0Tflo00H0Tflo00@0U71009=_?`2BKSh0TFdm0P2@K3`208m[>`<0
TF`o:oooool002[ooooo1@2JL3h309U_?@0609Y]@`2JKT40Vfm209a`@@2MLD00WW=00P2OM3l309aa
?P80WG8o00<0WgA10:1e@P2PMD800`2NLTD209mcAP<0X7A700<0Vg4o09ab@02NM4800`2OMD<209id
@PP0Wg=200<0X7I40:9hAP2SNDL00P2TNTP00`2SNDL0XWQ60:1fA00809me@`80Y7Q7102SMdH20:9f
A@<0YGY700<0Y7U60:=hA@2SN4D00P2SN4D01`2RMd@0WGY409iiA02NND@0X7Q40:5hA02RMd@00P2U
MdD00`2QN4@0XWU50:AkA`020:ElB0030:AkA`2RNDD0XGQ400@0Yga91P2VNdP40:MlB@D0YW]8102W
O4T0102VNdP0YWe90:ImB@2VODT30:MnBP80Z7m;202WOTX30:QmBP80ZGi;0`2ZOd`20:V0C0@0ZX5=
0P2YP4`80:QoB`80Z7m9102YP4X20:Z1B`@0Zh5?102ZP4h00`2YOdd0ZX1>0:Z0CP020:Z0CP<0Zh5?
202/Pdl01P2]PUL0[H9E0:f2E@2]Pe<0[H=A0:f4D080[HA>0`2ZQE420:^6DP<0ZXEA202/PU080:j4
DP050:^5F02[QEH0ZhEF0:^5E02[QU800P2[QU420:b7D0H0[HQD0P2/Qe<20:b6E@040:b7D`2/Qe80
[8MB0:b7D080[HU?0P2^RU00102^RE80[XUD0:j9E02^RED20:j8E`@0[8MC102[QU880:V4D080[8MB
00L0ZhIA0:Z5D02YQ4l0Yh9=0:J1C02UP4/0Yh9>00<0YX5=0P2UP4`20:AoB`D0XWe80P2QO4L00`2P
NdH0XGa80:1kA`020:1kA`80WgY60P2NNDD00`2JMD00VgI109ag@P0209eh@`0309ag@P2KMT40VWE0
00<0VGE100D0V7A009Mc?`2ELCd0U70l09=_>`0809Ea?@0:09=`>P2CKc/0TVhj095]>`2?Jc/0SFPk
08]V>P2:ICT0S6Hi08eW>P80SVPk00D0SFLj08]U>028HSD0Qf4d08QS=P0308MR=@80QV4d0P25H3<8
08IP<`03085L<P22GC<0PUdc0080Pehd0`24GcD03P22H3<0P5dc07iK<@1lFBl0NeP`07aI<@1mFS80
OU/c07]K;01hEbX0MUDX07MF:`1kFS40NeTc0P1hES402@1eDbh0LU0[079@:`1aDB/0Ke4[06iB:`1/
Db/0KE@/06aE;00206i@:P80KDlY101/CRP206I89P0406M99`1XBRP0JD/Y06Y<:P80Jdd[00<0IdXZ
06Q;:`1XBb/00P1WBRX206I9:@0406E8:01QBRP0HDXX065::080H4TW0`1OB2H01P1TABT0HdDY0694
:01PABP0GTDW05a59P80FTDV201J@RH205]39`80FT8V101I@BD00`1D@B<0ED8T05I39@0205M49P03
05I39@1D@B<0Dd0R00@0EClW101D?RH00`1EA2X0E4<Y05919`03050o9@0305509P1B@BL0Dd8T00<0
Dd8T101B@B<00`1E@BP0E40W05A09`0205<o9P80DShU00@0DclV05919`1A@2H0CchT0P1>?B<01@1?
?R@0DD0V05919`1A@BP0CCdT0080BSXQ00L0CShU0551:01@@2L0CShU04Pj8019>b40BS`R0080BcdS
00<0BS`R04Pj8017>Al01P17>b<204Pl90<0?cPN1@10>Al204<i800404@j8@15>b80AC/R04Hl8`<0
AcdT0`15>b8204@j8@<0@cTP0`12=b<4044f8P04040e8@10>Al0@3TO040i7`<0?cPN0P0n=ad303lg
9080?SHS0`0m=B8303Xe8@<0>C@P0P0h<al803hg90P0>C@Q1P0k=28203`e8`P0?SHS00<0>c<P03de
8P10>2D00P12>RL01011>BH0?cLT03hf8`10>242044i8P80@SXS0P13>b@01014?2D0AS`S04Hl8`17
?B@204Pn9@<0BClV00H0B44T04]29@1;@RD0C44U04i09@1@@2H205509P<0DD8U0P1B@bH305=49`0:
05I79P1GAbH0F4PV05a:9P1NBRD0HT`W06A<9P1TCB@0IU0[06E?:P<0I4hY00<0IU0[06MA;01YDbh0
0P1VD2L01P1XDBP0JU4Y06eA:P1`DR`0Le<]07AD;P80LEHY00@0LULZ07=H:`1dFB`0MEX]0P1fFbh0
201eGc00MUh`07MO<@1jGc80O5lc07mP=020Gc@0PF0e0`20H2l00`21HC00PV8a089R<@03089R<@80
P6He00<0PFDe08AU=P25ICH00P27ICL02@29I3L0QfDe08MU=@28ISH0RFLg08YX>02;JCT0S6Xj08e[
>`0208e/>@80SVdj00@0Sfhk091_?02@Kc`0TG0m102ELCd209Ib?P80Ug<o0P2HM40209Ue@@<0VWI2
0`2KMd<0102LN4@0WGU509ijAP2NNTH209mkA`80X7a80P2QODT0102ROTX0Xgm;0:B0C02TP4`80:J3
C@P0Z8A@00H0ZHEA0:Z6DP2ZQU80ZhMC0:b8E02]RED20:j:EPP0[h]G0P2`S5P30;6=F@<0/XiJ102d
T5`40;>?F`<0]I5Q00D0]Y9R0;NCH`2hU6@0^IEU0;ZFIP030;VEI@80^9AT0`2gTf<20;JDIP80]iEW
0P2hUVP20;VGJ@80^iMW0P2jUVH20;VEI@80^9AT102kUVT40;ZEJ0<0_9QX0P2kUfL20;ZFIP80^IEU
00<0_9QX0;^GI`2jUVH00P2iUFD00`2kUfL0_9QX0;fIJ@080;VGI`P0^IAW202gUFL20;ZFIPh0^IEU
0P2eTfD00`2fU6H0]iEW0;RFJ0020;VGJ@030;ZHJP2jUV@0^YIT00H0^IES0`2lV6P20;^GI`<0^YIV
202iU6P20;NEI`80^9IX0P2iUfT20;ZHJP030;RFJ02gUFL0]iEW00@0]iEW00<0^9IX0;NEI`2gUFL0
2@2gUFL20;JDIP<0]I=U00H0]8mR0;F@H`2eT6<0]Y5T0;NBI@2hTfH20;VDI`030;B@H02eTF40]Y9R
0080^9AT00H0]Y9R0;FAH@2dT600]I5Q0;JBHP2hU6@20;VEI@040;RDI02fTV80]I5Q0;F@H`H0]Y5T
00<0]I1S0;:@HP2bT680102aSf430;2>H0P0]91P0`2bSUh40;>?G`040;B@H02gTf<0]Y9R0;B@H080
/XiN00<0/hmO0;B@H02eTF40202dT6020;FAH@H0]91P0`2cSel20;B@H0<0]I5Q202aSEd20;>?G`<0
]91P0`2eTF480;FAG@80/XiN0P2aSEd20;2<G080[h]K0`2`S5`30:n;F`80[XYJ202aSEd30;2<G0<0
/HeM0P2bSUh30;6=G@@0/XiN0P2cSel20;:>GP050;6=G@2`S5`0[h]K0:n;F`2^RUX00`2bSUh20;6=
G@/0/XiN0`2aSEd30;:>GP80/hmO0`2cSV830;:=H@<0/HaP202`S5`40;:<G@@0/H]L00H0/HaO0;6=
G@2bSUh0/XiL0;:>FP2bSeT20;6>EPP0/H]L0P2`S5X00`2`S5`0/8]N0;2;G`020;6<HP090;:<I@2a
Re`0/XaM0;B>G`2eSf00]8iO0;6;G02^R5T0[8IG0080/8eE00H0/8eG0:n;E`2_ReT0[h]K0:j:FP2^
RE`80:j:FP80/8YM0P2`RU/0102aRe`0/H]J0;6;FP2aReX20;:>FP80/HeI0P2`S5P20:n;E`050;>?
G`2bSUh0/XiN0;6=G@2`S5`00P2_Re/0102^RUX0/HeM0;6=G@2aSEd30;:>GP80/hmO0`2aSEd20;2<
G0<0[h]K0P2aS5l20;2;GP040:n:G@2^RE`0[XUL0:j9G0<0/hmO0P2bSUh30;6=G@P0[h]I202/R5P2
0:j7G0030:j8F`2^R5T0[XQG0080[XUE00@0[XUD0:b8F02/R5P0[8QH102]RET20:j:FP0;0;6;GP2`
RU/0[hUJ0:f7EP2]R5@0[hYE0;2;E02aS5D0/HeM0:n;F`2]RET00P2[QeL00`2/R5P0[h]K0;2<G008
0:b6E`80[XYJ0`2]RET40:b8F0080:Z6EP2YQED0Z8AD0:R4E02YQED0ZXIF0:b8F02^Qe`20:j8F`03
0:j8F@2^R5L0[XUE0080[XUD0P2[Qe<40:b8E080ZhMC00<0ZhMG0:V5E@2XQ5@00P2WPe<00`2XQ5@0
ZHEE0:^7E`080:Z5D@80ZHEA0P2ZQU840:^7D`<0ZXIB0P2YQE430:R4D0<0ZXIF0`2[QeL20:b8F003
0:f9F@2[QeL0Z8AD0080YX9B00<0Yh=C0:V5E@2[QeL0202YQ5020:V4C`80Z8=>0P2WPTd20:J1C0P0
YX9B00<0Yh9>0:J1C@2TOd/00P2TOd/00`2VPDd0Yh9>0:V4D0080:EoD0T0Z8=>00H0YX1C0:J0D@2V
P540YX1?0:N2CP2WPTd20:N2B`P0YX5=1@2WPTh01P2VPDd0YH1<0:F0C02SOTX0Y7m;0:J1C@<0Z8=?
00<0Yh9>0:J1C@2UPDd00P2UPDd20:B0C0<0Xgm;202TOd/60:=oB`80XWi:0P2VPDd20:F0C0040:Ao
B`2UP4`0YH1<0:F0C0H0XWe90P2SOTX0102UPE40Xgm?0:5mC@2ONd/209ijBP0609mkB`2PO4`0VgM7
09ahB02MNDT0WWY:0`2ONd/0102PO4`0XGa80:1kA`2ONTH209iiA@0<0:1kA`2RODT0Xgi:0:1jB`2Q
Nd`0XWa=0:=mCP2RO4d0XG]<09miBP2MMdP0WgY60P2NNDD01@2ONTH0XGa80:9mB@2RODT0XGa800<0
X7]700<0WgY609iiA@2NNDD00P2MN4@209if@`0409ehA02LN4@0WGU509]jA@80Vga600<0Y7m;0:9m
B@2ONTH00P2MN4@04@2NNDD0XGa80:9mB@2MN4@0WWU509mjAP2PNdL0WgY609ehA02KMT80VWE109eg
B02NN4T0X7Y;0:5kC02RO4d0XG]<0080X7Y;00<0WgU:09ijB02ONdT00P2PO4X02P2ONdT0WGU709]g
A@2JMT@0Ug=309QdA02IMDD0VWI609]gA`2MNDT209ijBP0409eiA@2LN4@0W7Q409]g@`@0VWI21P2I
MD4209Qd@00@09Ya@`2KLT@0VG=409QdA02GLd<0U79209Ad@`2EMD@0WGU909]gA`2IMDD0Ug=309Ib
@P2GLd<0VGE509YfAP<0UW9000<0UG5109A`@02DL4000P2CKT4809Mc@`<0Tflo00D0TVhn095]?@2@
K3`0Sf/k08iZ>P03095/?b_ooooo000Zooooo`80W7900`2KLCl309Y`?P0609Y]@`2JKT40Vfm209a`
@@2MLD00WW=00P2OM3l209eb?`<0W74n00<0WG8o09ic@02OM4400`2NLTD209mcAP<0X7A70P2LLT00
0`2MLd40WWA209id@P0309id@P<0X7A30P2OLd8309ib@@0309me@`2QMdD0XWQ60080XgU700<0XWQ6
0:5gA@2OMD<0202OMD<30:AhA`D0XgM60`2TNDH50:=hA@070:9gA02MNDD0WWU509mjAP2QNDH0XWQ6
0:AhA`020:IhA`030:5hA02RNDD0Y7]70080YGa800@0Y7]70:9iA@2QN4@0Z7a;0`2WNdX30:IjB@04
0:EiB02UNTD0YW]60:MlA`80Z7e800H0Yga70:IkAP2UNTD0Y7U60:EjA`2VNdP30:QmBP030:MlB@2V
NdP0YWe90080YWe90`2WOTX20:QoB`P0Ygi:0`2XODX20:UnB`<0ZWm<0P2YP4`0102ZPDd0Zh9>0:^2
CP2ZPDd20:V0C0<0Ygi:0P2XOd/30:V0C0<0Z7m91@2YP4X40:^2CP@0ZX5=202ZP4h80:b3C`060:f2
E`2]PUD0[H9E0:f3D`2]Pe40[HA@0P2]Q4h00`2YQ500ZXEA0:^6DP020:b7D`030:^6DP2ZQE40ZHA@
0100[XAB00D0ZXAG0:Z4E@2[QEH0ZhED0:^6DP020:b7DP80[8M@0`2^RED30:f8E080[8MC0P2[QE@0
102[QU80[8MB0:b7DP2/Qe040:f9C`040:f8D@2]R5<0[HQC0:f8E080[HMF202/Qe<80:V4D080ZhIA
0P2/Qe801@2[QU40ZHA?0:R3CP2WPTd0Z8=>00<0Yh9=0P2VPD`20:F0B`030:5lA`2RODP0Xgi90080
Y7m:00<0Xgi90:9mB02QO4L00`2RODP20:5lA`<0X7]600<0VgI109ag@P2MN4<00P2NND@00`2MN4<0
W7M209]f@@0409Yf@P0409Qd@02FLSh0U70l09=_>`P0UG4m0140TVli099^>P2CKc/0TVhl095]?@2?
JSd0SFPl08]V>P2<IST0SVPk08mY?02@JSd0SfTl08eW>P29HcH0Qf4d08UT=`0308QS=P80Qf8e0P26
HC@808MQ=006081K<@21G380PUdc08AO=@25H3H0Qf8h0P28HcT03P23HC40PEl_07iL;P1kFB`0NeP^
07]H<01mFS@0Oe`f07aJ;01jF2/0N5HY07YG;@1nFc<0OU/e0P1kEc<01P1gDbl0LU0Z07=A:`1bDR/0
L5<[071D;080KUD/00@0KUL]075A:P1aDBX0LE4Z0P1`D2T306m?:080JdXW0P1/BbP01@1]C2T0KTdZ
06m>:`1_CR/0JDX[0080JT//00D0Jd`]06Y;;01YBR/0J4TZ06M8:@0306=;:@80HTXX0`1QBBL0201U
ARX0I4HZ06=5:@1PABP0GTDW05a59P1JABH0FD@U201LA2P205e3:080G48W0`1K@BH02@1J@2D0ED8T
05I39@1GA2H0F4DW05M49P1F@bD0E44S05=08P0305Lo9`80EShV0`1E?BD00`1EA2X0E4<Y05919`03
050o9@0305509P1B@BL0DT4S00H0DT4S00@0DD0R05E1:01D@2L0DclV0`1A?B@2058n9@03054o9`1@
?RH0CC/S0080BcTQ01<0CC/S050n9P1A?bL0D40W04dm901:>R40Bc/R04hn9@1@@2L0CCdT04Xj8@16
>R00Ac/Q04Pl8P19?B<0B3`R04Lk8@15>Al0A3PN00<0AC/R0`16?2<204Lm90<0?cPN0`10>Al2044j
80@0A3XQ0`15>b8204Hl8`<0@cTP0P12>1l3044g7PP0@CHR0`10>Al203lh7P<0?SLM0P0o=b@203hf
8`<0?CDR00@0?3@Q03/f8P0k=R80>cHR0`0j=B4203Td80P0?cLT200k=R<203`c8P<0?C@S0`0n=B@8
048g8`<0@SLU0P13>2H304@i9`80A3XQ00@0AC/R04Hl8`17?B@0AcdT0P18?RD01017>b40B3`R04Xn
901<@2H204e19`80C40V00H0CD@W04i39`1>@bL0D48W05519`1B@BL205A09`<0E4<U0P1EA2H305I5
9`0605U99`1LBBP0GD/W05m;9P1RC2L0IDdW0P1WCRH00`1YDb`0J58[06MA:P0206I@:@0;06QB:`1Z
E2d0JeD^06MB9`1VDBH0Ie0V06Q?9P1[CbL0KU4Y079B:`1cDb`00P1cF2/00`1dFB`0MEX]07IK;P02
07ML;`0707QM<01fH340Mela07QP<P1kH3<0O5lc07mP=002085P=@80PV0`00@0Pf4a08AR<P25Hc<0
QV@d0P25Hc<01P24HS80PFLf085W=P23IcL0QFHg08MW>080R6Hh00T0RfHi08QV=P28ISH0RFLg08YX
>02<JSX0SF/k08i/?02?KCd00`2?KST2091_>P<0TG0k0`2FLSh209Mc?`<0V7A00`2JMT8209]g@`<0
W7Q40P2MNDD209ijAP80Wg]70`2PO4P20:5mB@030:9nBP2SOd/0Y81<0080YH5=202VPdd80:V5D@80
ZXIB00<0ZhMC0:b8E02]RED00P2^RUH00`2_ReL0[XYF0:j:EP060:j:EP040;6=F@2bSUX0/XiJ0;:>
FP80/hmK0P2dT5`40;FAG@80]91L0P2cSe/0202fTV80]I5Q0;FAH@2eTF40]Y9R0;RDI02iUFD0^YIV
0`2iUFD20;RDI0<0]i=S0`2gUFL20;RFJ0<0^IMY0`2kUfL20;ZFIP<0^IEU00@0_9MZ0;^FJ@2kUVT0
^iIY0`2jUFP0102iU6L0_9QX0;bHJ02lV6P20;^GI`80^YIV0P2iUFD00`2kUfL0^YIV0;VEI@020;RD
I0030;ZFIP2lV6P0_IUY00P0^IMW202iU6L80;NEI`<0^YIV0`2iUFD20;RDI0P0^IEU0P2fU6H30;NE
I`<0^9IX0`2jUV830;VEH@80^9AP00@0^iMW0;ZFIP2jUVH0^YIV0P2iUFD20;RDI0P0^IAZ0P2gUFL2
0;RFJ080^IMY0P2jV6X00`2iUfT0^9IX0;NEI`020;JDIP030;NEI`2hUVP0^IMY00/0]iEW0P2fU6H3
0;FCI@80]I1S0P2fTF@01`2gTVD0^9=V0;RCIP2iU6L0]91P0;FAH@2gTf<00P2hU6@01P2gTf<0]I5Q
0;B@H02fTV80]i=S0;RDI080^IEU00D0^9AT0;NCH`2fTV80]I1S0;JAI0040;NBI@030;JAI02eT6<0
/Y1R00@0/HmQ0P2`SV020:n=G`P0]91P202bSUh00`2gTf<0]I5Q0;B@H0030;:>GP030;>?G`2dT600
]91P00L0]91P0`2eTF430;B@H080/hmO00@0/XiN0;>?G`2cSel0/hmO0P2dT6020;FAH@P0/XiN0P2c
Sel30;B@H0<0]I5Q202dT5`01@2cSel0/XiN0;:>GP2aSEd0/8aL0080[h]K00@0[XYJ0;2<G02`S5`0
/8aL0`2_Re/20:j:FP/0/8aL0P2aSEd;0;:>GP@0/HeM102`S5`00`2cSel0/XiN0;6=G@020;2<G003
0;6=G@2bSUh0/hmO00P0/XiN0`2aSEd30;:>GP80/hmO00<0]8mU0;>>I02cSV@00P2cSV@20;:=H`80
/HaR202`S5`0102cSEh0/XaM0;:<G@2bS5d30;6;G0090;2:F`2`Reh0/HeM0;:>GP2bSU`0/XiJ0;:?
F@2aSUH0/8eE00<0/H]L0P2bS5d30;>=GP0:0;6=F`2`S5X0[h]K0:n:G@2_RUh0[hYP0;2;H@2aRf@0
/H]L0;:<G@<0/heN00<0/H]L0;2:F`2_REX00P2`SED01P2`SEL0[h]G0:n;F@2_Re/0[XYJ0:j9G080
[HUI102_Re/20:f9F@80/8UN00<0/8YM0;6;G02aReX00P2bSET01P2bSEP0/hmK0;:>FP2bSUX0/HeI
0;2<F080[h]G00<0[XYF0;6=G@2aSEd00P2aSEd40;2<G0<0/HeM0`2bSUh20;>?G`<0/8aL0P2_Re/3
0:j:FP060;:=H02aS5l0/HaO0;2;GP2_RUd0[XUL0P2]R5/20;:>GP80/HeM0`2`S5`00`2_Re/0[h]G
0:n;E`060:n;E`P0[HUI0P2]QU/00`2]QeX0[HMH0:f7EP020:f8E0040:f8D`2/R5P0[8QH0:b8F0@0
[HUI0P2^RUX02`2aReh0/8YK0:n9FP2^R5L0[XUE0:n:E@2`Re@0/HaE0;2<G02_Re/0[HUI00<0[8QH
0P2]RET80:b6E`80[XYJ0`2]RET30:b8F0030:f9F@2[QeL0ZXIF0080ZHEE00@0ZXIF0:^7E`2]RET0
[HMJ0P2]QeP00`2]QeH0[HQD0:f8D`020:f8D@030:Z6DP2[Qe<0[8QD0080[HUE00H0[8QD0:^7D`2Z
QU80ZXIF0:V5E@2XQ5@20:N3D`030:R4E02YQED0ZXIF00P0ZXEA00D0Z8A@0:V5D@2ZQU80ZhMC0:b8
E0020:^7D`@0ZXIB0P2YQE430:R4D0<0ZHEE0`2ZQUH30:^7E`030:Z6EP2XQ5@0Yh=C0080Yh=C0P2X
Q5@80:V4D080ZHA?0P2XPdh20:N2C@80YX5<202UPE400`2WPTh0YX5=0:AoB`020:=nBP030:AoB`2U
P4`0YX5=0080Y7i?102VP5420:AnC`T0Yh9=00H0Yh5D0:N1DP2WPE80Yh5@0:N2CP2WPTd20:N2B`P0
YX5=0P2WPTh30:R3C`060:N2CP2UP4`0Y7m;0:=nBP2TOd/0YX5=0`2XPdl00`2WPTh0YX5=0:F1C@02
0:F1C@80Y81<0`2SOd/80:=nBP80Y81<0`2SOd/30:9nBP030:N2CP2VPDd0YH1<00<0Y7m;0P2UP4`3
0:5lB0<0XWe90P2SOTX0102UPE40Y81@0:9nCP2PO4`209mkB`80X7a<0P2LN4P02@2NNTX0Wg];09mk
B`2ONd/0WWY:09eiB@2QO4P0X7]709mjAP0209iiA@060:1kA`2RODT0Xgi:0:1jB`2QNd`0XWa=0P2S
ODh02`2QNd`0WgU:09ihB@2PNdL0WWU509ag@`2NNDD0XWe90:AoB`2RODT0X7]70080XGa800<0X7]7
09mjAP2NNDD00P2MN4@01`2LMd<0WWI309if@`2MN4@0W7Q409eiA@2KNTD00P2KO4H20:5lB0080:1k
A`2ONTH0WgY609mjAP2PNdL0XGa809iiA@2ONTH20:1kA`0:09mjAP2MN4@0VgI209Ud@02LMTL0WGM8
09miBP2PNT/0XG]<0:1jB`80WgU:00T0WWQ909eiB@2NNTX0Wg];0:1lC02ONd/0WWY:09ahB02KMdL0
0P2ILd@209YdA@0809]eAP2LMTL0WGM809egB02MNDD0W7Q409]g@`2JMT8209Ue@@0409Yf@P2KMd<0
VGE109Ue@@<0VWI200`0VGE109Mc?`2FLSh0VG1209]bA02KMDH0V7A409Ea@@2BL400TW9109EeA02K
MdL309YfAP80VGE50P2HM4@01P2GM3h0UW8n09Ib?P2ELCl0U71009=^@@80TVe10`2HM4@309UeA@80
VWI600P0TVhn09=_?`2CKcl0Tflo099^?P2@K3`0Sf/k08iZ>P<0TF`o:oooool002[ooooo0P2NM482
09ec@@0:09ab@02KLCl0Vg4o09]a?`2JKD<0VVi109]_@P2LL440WG5009ic@080Wg@o00<0X7E209ic
@02LLCh00`2KL3d00`2MLSl0WW=009ibA@0209ibA@80Wg=60`2PM4L309ab@080WG=10`2NM4800`2Q
MD@0X7A30:1d@`0209mc@P80WW9100@0WG5009id@P2OMD<0X7I40P2RN4H00`2PMT@0WgE309id@P08
09me@`80XgM61P2TN4L00`2RMd@0XgQ50:=hA@060:=hA@0609ijB02ONDP0X7Y90:9jB@2TNTX0YWY;
0P2XND/00`2QN4@0XWU50:AkA`020:ElB0030:AkA`2RNDD0XGQ40080Z7a=0P2WNd`20:IjB`80YGU:
00<0YGY30:IkA02WO4D00P2XODH02`2WO4D0YW]40:Ej@`2SN4D0Y7U60:IkB02XODX0ZGi;0:QmBP2W
O4T0YW]800<0YWe90`2WOTX20:QoB`P0Ygi:0`2XODX20:UnB`<0ZWm<00<0Z7m;0:V0C02[PTh00P2/
Pdl0102[PTh0ZH1<0:QoB`2VODT20:MnBP80Z7m;0P2YP4`00`2ZPDd0ZH1:0:V0BP060:QoB@@0ZX5;
102[PT`40:Z0CP@0ZGm=202/Pdl01P2]PUL0[H9E0:f2E@2]Pe<0[H=A0:f4D080[HA>00<0ZHA@0:Z5
D@2/Qe<00P2]R5@00`2/Qe<0ZXEA0:V4D0080:n5D`P0[XAB00D0ZXAG0:Z4E@2ZQ5D0ZhED0:b7D`02
0:b7DP80[HQA0P2_RUH20:j9E@80[HQD0P2/Qe<20:Z4D`040:^6DP2[QU40[8MB0:b7D080[HU?0P2/
R4h0102/Qe00[8MB0:b7DP2/Qe<20:b6E@D0[8MC0`2]R5@80:Z5D@030:V4C`2ZQE00[8MB0080[HQC
00<0ZhIA0:Z5D02YQ4l00`2XPd`20:N2B`<0YX5:00<0XGa70:9mB02TOdX00P2UP4/00`2TOdX0Xgi9
0:9mB0030:=nA`80XWe60`2QO4D00`2KMT40W7M209iiA00209mjA@0409iiA02LMd80VgI109Yf@P<0
VgM300@0VGE109Mc?`2DL3`0TVhj202DL3`0402@KCL0TFdi099^>P2CKcd0TVhn095/?`2?JSh0SFPl
08eW>P2>J3/0TF/n099/?`2AJch0SVPk08YT=`28HSD308UT=`80R6<f0`27HSD808QR=@80Q5le0P25
H3H308IQ=`0?08MR>024Hbh0PV4^07iL;01jF2X0NEH/07YG;`1mFS@0OUXf07aJ;01jF2/0NELZ07aI
;`20GCD0P5dg0080O5Pd00H0N5@`07=A:`1cDB/0Le</075D;01aEBd2071G;P0406mH;P1cDB/0Le4[
07=A:`80LU0Z0`1aCbT5071>:@<0LDlZ00<0JdX[06a;;01^CBh00P1^CBh00`1/Bb`0JTTZ06U8:@02
06E;:P80I4XY0`1SBBP02@1RB2L0ITL[06A6:P1TARX0HDHY05i59`1LABH0FTDV05U49@0805i6:P04
05m4:@1N@bP0GT<X05i3:080GD8W0P1L@BH00`1F@bD0Ed@V05Q59`0205Q59`0305I39@1D@B<0Dd0R
00<0EclW00<0EShV05Dm9@1E?BD00P1D?2@00`1EA2X0E4<Y05919`03050o9@0305509P1B@BL0DD0R
00L0DD0R00<0ED4X05A09`1B?RD00`1@?2<01@1A?B@0DShU054o:@1??BL0C3XT0080BSPR00L0C3XT
04lm9`1A?bT0DD4X04dm901:>R40Bc/R0080CShU00X0Bc/R04Lg7P16>R00Ac/Q04Pl8P19?B<0B3`R
04Hj8014>1h0@cLM0P12>b4204<l8P80A3dS0P15?R@203hh7P80?cTO00@0@3XP044k8@11>b40@C/Q
0`15>b8304@j8@<0@cTP0`11=ah2040f7@<0?cDL1010=B44044f8P04040i7`0o>1h0?cPN03lh7P80
?SLM0P0m=Q`303hf8`<0?CDR0P0l=24203dh90<0?3LS0`0k=R8803lg90P0?CPU0P0l<b8203dd8`04
03he900o=RD0?cHU03lf9@P0A3PR00<0AcXY04Hi:013=RD00P12=B@00`15>2L0B3/Z04Xm;00204Hj
8P0304Lk8`18?2@0BCdU0080BclW00D0C40X04Xl8@1;?B80CT0U05129`020553:080D48W0P1@ABL0
0`1BA2L0DT<V05=29P0205E19P0405I19P1HABD0F4DU05Q59@80FDHV0`1JAbL02P1MBRT0GD/W05m;
:01SCBP0IDdW06M>9P1XCbH0JdlW06YD:`1YDbX306QB:@0<06YD:`1[EB`0KEL^06YE:P1YE2T0JE8X
06YA:01/D2P0Ke8Z07=C;01eEBh0M5TZ0P1eFR/00`1fFb`0Me`]07QM;P0207UN;`0607EO<01gGc40
Mela07YO<P1lGc<0Of0d0P21H3D2089P<00708AR<P26I3@0QfDe08QV=P27ICD0QV@d08ES<`02089X
=`0308AX>026IcP0R6Pi0080RFLi00L0S6Lj08QV=P29IcL0RVPh08]Y>@2=Jc/0SV`l0080T6hn0P2@
KcX3095`>`<0TW4l0`2GLcl209Qd@0<0VGE10`2KMd<209ahA0<0WGU5102ONdL40:1lB0060:5mB@2R
OTX0XWi:0:=oB`2TP4`0YH5=0P2VPTh80:J3C@X0ZXIB00@0ZhMC0:b8E02]RED0[XYF0P2_ReL80:f9
E@040;:>FP2cSe/0/hmK0;>?F`80]91L0P2eTEd00`2gTel0]Y9N0;JBGP020;FAG@80]91L00T0/hmK
0;JBHP2eTF40]I5Q0;B@H02eTF40]i=S0;ZFIP2kUfL00`2iUFD20;RDI0<0]i=S0P2gUFL20;RFJ0@0
^IMY102kUfL20;ZFIP80^IEU0P2lUfX20;^FJ@80^YEX0P2iU6L30;bHJ080^iMW0P2jUVH30;VEI@07
0;RDI02gTf<0]Y9R0;NCH`2iUFD0^iMW0;bHJ0080;VGI`P0^IAW202gUFL20;^GI`80^YIV00@0^IEU
0;RDI02hU6@0^9AT202iUFD30;RFJ0<0]iEW0P2fU6H20;^GH`80^YIR00D0^IEQ0;RDH02hU600^9AP
0;VEI@030;RDI080]i=S0P2fTV880;VDJP80]iEW0P2hUVP20;VGJ@80^YQZ00<0^IMY0;RFJ02fU6H0
0P2eTfD00`2fU6H0^9IX0;VGJ@0;0;NEI`80]YAV0`2eTfD30;JAI0D0]i9U00<0]I5Q0;JBHP2gTf<0
0P2hU6@01P2gTf<0]Y9R0;FAH@2fTV80]i=S0;VEI@80^YIV00H0^IEU0;NCH`2fTV80]I1S0;JAI02g
TVD20;RCIP030;NBI@2fTF@0]I1S00@0/HmQ0P2`SV030:n=G`P0]91P202bSUh0202fTV80]I5Q0;>?
G`2bSUh0/HeM0;:>GP2cSel0]91P202cSel20;JBHP80]I5Q00@0]91P0;>?G`2cSel0/hmO0P2bSUh3
0;>?G`<0]91P2P2cSel30;B@H0<0]I5Q202bSUX20;>?G`040;:>GP2aSEd0/8aL0:n;F`80[XYJ0`2`
S5`30:n;F`80[XYJ202_Re/0102`S5`0/HeM0;6=G@2aSEd20;:>GP80/hmO1P2bSUh20;6=G@@0/8aL
102aSEd00`2dT600/hmO0;6=G@020;2<G0030;6=G@2cSel0]91P00P0/hmO0`2aSEd30;:>GP80/hmO
0P2dSfD40;>>I0<0/XeS202_Re/20;>=GP80/XaM0P2aRe`20;2:F`080:n:G@2`S5`0/XiN0;>?G@2c
Se/0/XmI0;2=E@2_S5@20;:<G@80/heN0P2dSUl20;F?H00:0;:>G02aSE/0[h]K0:j9G02]R5`0[XUO
0;2;H@2aRf@0/XaM0;6;G0<0/8YK00<0/XaM0;>=GP2dSUl00P2`SED02@2`SEL0[h]G0:n;F@2_Re/0
[XYJ0:j9G02/R5P0[HUI0:n;F`020;2<G0090:n;F`2]RET0[8QH0;29HP2`RF00/8UN0;6;GP2bS5/0
/XeI0080/hiG0P2cSe/0102bSUX0/HeI0;2<F02_ReL20:j:EP@0/8aL1`2aSEd30;:>GP80/hmO00@0
/8aL0:n;F`2_Re/0[h]K0P2^RUX20:f9F@80/XeP00H0/HaO0;2;GP2_RUd0[XUL0:f8F`2/QeX20;2<
G080[h]K102^RUX80:j:EPP0[h]K0P2]QU/00`2]QeX0[HMH0:f7EP020:f8E0040:f8D`2/R5P0[8QH
0:b8F0@0[HUI0P2^RUX02@2bS5l0/H]L0:n9FP2^R5L0[XUE0:n:E@2aS5D0/XeF0:f9F@020:j:FP05
0:n;F`2^RUX0[HUI0:^7E`2ZQUH0202[QEH20:j:FP<0[HUI0`2/R5P00`2^RUX0[HUI0:b8F0020:Z6
EP030:b8F02]RET0[XYJ0080[8IG00<0[8IE0:b7D`2/Qe800P2/Qe00102/R4h0ZXIB0:^7D`2/R5@2
0:f9E@060:b8E02[Qe<0ZXIB0:Z6EP2YQED0Yh=C0P2VPU800`2WPe<0ZHEE0:Z6EP080:Z5D@030:N3
C`2XQ500ZXIB00<0[8QD1@2ZQU820:V5D@<0Z8A@0P2WPe<30:R4E0<0ZHEE0P2XQ5@30:V5E@030:R4
E02VPU80YX9B00P0ZXEA0P2YQ4l20:R3CP80Yh9=0P2VPD`80:B0D0040:R3C`2WPTh0YH1<0:=nBP80
XWe900D0Xgi:0:AoB`2SODh0Y7i?0:J0D@020:N1DP030:J0D@2TOTl0Xge>00T0YX5<00H0Z89E0:R2
D`2XPU<0Yh5@0:N2CP2WPTd20:N2B`P0YX5=00<0Yh9>0:R3C`2YQ5000P2YQ5001P2WPTh0YH1<0:Ao
B`2SOTX0Y7m;0:J1C@<0Z8=?00<0Yh9>0:J1C@2UPDd00P2UPDd20:B0C0<0Xgm;202SOTX30:B0C003
0:=oB`2ROTX0XWi:0080XGe900<0ZHA@0:N2CP2UP4`00`2SOTX0102TOd/0YH1<0:1kA`2PNdL20:5l
B080XWe90P2SOTX0102VPU80Y81@0:9nCP2PO4`209mkB`0=0:1lC02QODd0WGU909ijBP2ONd/0X7a<
09mkB`2NNTX0W7Q809]gA`2QO4P0X7]709mjAP0209iiA@050:1kA`2RODT0Xgi:0:9lC@2SODh00`2T
OTl04@2RO4d0X7Y;09miBP2PNdL0WGQ409]f@P2MN4@0Xgi:0:F0C02SOTX0X7]70:9mB@2QO4P0X7]7
09mjAP2NNDD0WGQ40080W7M30P2NMT<0102MN4@0W7Q409eiA@2KNTD209]lAP0309iiA@2ONTH0X7]7
00<0XGa800@0X7]709mjAP2ONTH0WgY60P2PNdL02P2ONTH0WGQ409Ye@@2IM400VgE609afA`2NN4T0
WgU:0:1jB`2ONDX209ihB@0909egB02MNDT0WWY:09mkB`2PO4`0Wg];09ijBP2LN4P0VgM700P0W7=5
01/0WGU509ahA02JMT80VGE109Qd@02IMD40VWI209]g@`2HM400VGE109Yf@P2KMd<0VWI209Ue@@2G
Lcl0UG4m09Q_@@2LLdD0W7I709UeA@2DL400T6hn095a@02EMD@0V7A409YfAP2LN4P00P2MNDT02`2J
MTH0Ug=309Ea@@2GM3`0UW<k09Ib?P2ELCl0Tfi1099]@@2BKD<0TF]40080UG510P2FLT801@2GLd<0
V7A409QdA02HM4@0TVhn0080Tflo00D0U71009=_?`2AKCd0SVXj08eY>@03095/?b_ooooo000Zoooo
o`80WgE30P2NM4802P2MLd40W79009ab@02KLCl0VVe309Y^@@2KKd80W71109ea@02NLd0209md?`04
0:5f@`2OM440WG8o09]`?@80VVll00<0W74n09eb?`2NLTD00P2NLTD209mcAP<0X7A7102LLT0209ec
@@80WWA20P2QMD@0102PM4<0Wg=209mc@P2NLT4209ea@00309ec@@2NM480WgE30080XGM500<0WgE3
09id@P2MLd40202OMD<20:=gAP@0Y7Q70P2UNDP20:5f@`80XWM40P2SN4D30:AiAP0;09mkB@2PNTT0
XG]:0:=kBP2UNd/0Yg]<0:UjC02ZNdd0XGQ40:9iA@2TNdL00P2UO4P00`2TNdL0XWU50:5hA0030:Ql
C@030:MkC02VNT/0YGU:0080YGU:00<0Y7U20:IkA02WO4D00P2YOTL01`2WO4D0YW]40:Ai@P2RMd@0
Y7U60:IkB02XODX00P2YOT/00`2WO4T0YW]80:ImB@020:ImB@<0Ygi:0P2XOd/80:MnBP<0Z7e:0P2Y
OT/30:YoC0030:QoB`2ZPDd0Zh9>0080[HA@00<0Zh9>0:Z1C@2XOd/00P2VODT0102WOTX0Z7m;0:Qo
B`2YP4`20:Z1C@80ZH1:102XOdT20:MnB0@0ZX5;102[PT`30:Z0CPD0ZGm=202/Pdl01P2]PUL0[H9E
0:f2E@2]Pe<0[H=A0:f4D080[HA>00<0ZHA@0:Z5D@2/Qe<00P2]R5@00`2/Qe<0ZXEA0:V4D0080;26
E0P0[XAB00D0ZH=F0:Z4E@2ZQ5D0ZhED0:b7D`020:b7DP80[HQA00@0/8]G0:n:EP2_RUH0[XUE0P2]
R5@20:b7D`060:V3DP2ZQ5<0ZXEA0:^6D@2/Qe80[8M@0P2]RDl20:^7C@040:^6C`2[QU40ZhIA0:^6
DP80ZhED102/Qe<40:f8E0P0ZXEA00T0Z8=>0:V4C`2/Qe80[HQC0:j9E02]R5<0ZhIA0:Z5D02YQ4d0
0`2XPd`20:N2B`80YX5:00<0XGa70:9mB02TOdX00P2VPD`0102UP4/0Xgi90:9mB02TOdP30:=nA`80
XWe60P2QO4D00`2LMd80WGQ309iiA00209mjA@0309iiA02MN4<0W7M20080VgM30P2LN4@0102JMT80
Ug<o09A`?02BKSX809=_>`0A08m/=P2@K3P0TVhj09=_?@2CKcl0TVe0091[?`2?JSh0SFLj08mY?02A
Jch0Tfe0099/?`2?JC`0RfDh08QR=@2:ICP00`29I3L208QS=P80Qf8e2028HSD01@29I3X0R6<i08MR
>026HCL0QF0f0080Q5le00X0Pehd08AS;@21H2/0OE`Y07YH:P1hERT0NUL_07aI<`1nFSH0OUT/0P1l
Eb/00`1oFS00Pedf08=M>00207mI=@0907YD<01cDRT0M5<Z07=C:P1bEB/0LUL/071H;01aFBd0L5T]
0080M5<Z0P1cDRT3079A:003075@9`1bD2/0LU0[00H0LU0[00<0K4//06e<;@1^CBh00P1_CRl00`1]
C2d0JdX[06U8:@0306E;:P80I4XY0`1SBBP0201VAb/0IDL[06A6:P1QART0GdHX05a59P1JABH0FD@U
201OAb/205m4:@80GT<X0`1M@RL00`1L@BH0ET<U05M49P0305Q59`0305I39@1D@B<0Dd0R00<0F3hW
00<0EcdV05Hl9@1E>b@00P1E>b@00`1EA2X0E4<Y05919`03050o9@0305509P1B@BL0D3lQ00<0D3lQ
101A@2800`1E@BP0DclV054m900204lk8P06050l8`1A?B@0DShU054o:@1??BL0BcTS0P19=b401@1;
>B<0CcdW054o:@1A@BP0CShU0080Bc/R0P1=?B@01019>B00ACDL04Dk8016?24304Lm8P0404Dk8013
>Ah0@SPM044j8080@S/Q00<0@c`R04@m8`14?B<00P15?R@0100m>Ah0?SXO03hj7`0o>b02040l8@80
@CdR0P16?2<01015>b80A3XQ04@j8@13>B03048h7`80@3HM0P0o=A`303hd6`0303dc6P10=B40@3DQ
00<0@3DQ0`11=R8403lh7P80?SLM0P0m=Q`303hf8`80?CDR0`0l=24203hi9@<0?CPT0`0l=b<8044f
90P0?STV00@0?S8R03lc8`0o<b<0@3@T0P11=BD2048f9PP0ACTS00<0BSd/04Lj:@13=RD00P11=2<0
0`15>2L0BC`[04e0;`0204Lk8@0304Pl8P19?B<0BShT0080C40V00D0CD4W04Xl8@1<?R<0Cd4V0553
:0020594:@0:0553:01@@RL0DDHV05=69P1BABD0Dd@U05A39@1F@bD0Ed8U05I190<0FDHV0P1JAbL3
05]8:00:05i<:01OBbP0H4`W06A>9`1VCbH0J4lW06]?9`1/D2P0JeD/06YD:`<0JE<Z00/0JeD/06aF
;@1^F2l0KEP[06aG:P1/EBT0K5@X06mD:@1bEB/0MUH]07QH;`0207EK:P0307IL:`1gGB`0N5h]0080
NEl^00L0NV0_07EO<01gGc40Mela07YO<P1lGc<0Of0d0080PF0e0P25HC401`26HS80RFDe08YV=P2;
IcL0RVHf08QT=027Hc<00P23JCP00`24J3P0QfPi08QX>@0208YX>P0908aW>P28ISH0RFLg08YX>02<
JSX0SV`l08m]?@2@KSh0TFlo00<0TG0j1@2BLC/0102GLcl0V7A009Qd@02HM40209Ue@@80VWI20P2K
Md<209ahA0<0WGU500<0WWY60:1lB02PO4P0102PO4P20:5mB@80XWi:0P2SOd/0102TP4`0YH5=0:J2
CP2VPTh80:J3C@T0ZXIB0P2[Qe<00`2/R5@0[HUE0:j:EP020:n;E`P0[8QD0`2cSe/20;B@G0<0]I5M
0`2gTel00`2fTUh0]I5M0;B@G0020;B@G0080;NCH`2fTV80]91P0;B@H02eTF40]i=S0;ZFIP2kUfL3
0;VEI@80^9AT0`2gTf<20;NEI`80^9IX0`2iUfT00`2jV6X0_9QX0;^GI`020;^GI`80^YIV0P2iUFD3
0;bGJP030;^FJ@2jUFP0^IAW0080^IAW0`2lV6P20;^GI`80^YIV0P2iUFD20;NCH`060;JBHP2eTF40
]Y9R0;RDI02jUVH0^iMW202iUfL80;VDI`P0]iEW0P2kUfL20;ZFIP040;VEI@2hU6@0^9AT0;NCH`P0
^IEU00H0^YQZ0;VGJ@2iUfT0^9IX0;NEI`2fU6H20;FCI@80^iQR0P2jUf40102iUV00^9EO0;REG`2g
U5h30;NCH`<0]Y9R0P2eTF480;VCK080]iEW0P2hUVP20;VGJ@80^YQZ00<0^IMY0;RFJ02fU6H00P2e
TfD00`2fU6H0^9IX0;VGJ@0;0;NEI`80]YAV0`2eTfD60;NBI@80]Y5T00<0]I5Q0;JBHP2gTf<00P2i
UFD01P2gTf<0]Y9R0;FAH@2fTV80]i=S0;VEI@80^YIV00H0^IEU0;NCH`2fTV80]8mR0;JAI02hTfH2
0;VDI`030;RCIP2fTF@0]8mR0080/HmQ102`SV030:n=G`P0]91P1@2bSUh30;6=G@030;JBHP2eTF40
/hmO0080/HeM00<0/XiN0;>?G`2dT600202cSel20;JBHP80]I5Q00<0]91P0;>?G`2cSel0102bSUh2
0;>?G`/0]91P0P2cSel30;B@H0<0]I5Q202aSET0202dT600/hmO0;:>GP2aSEd0/8aL0:n;F`2^RUX0
[HUI0`2`S5`30:n;F`80[XYJ202]RET40;6=G@80/XiN0P2cSel50;:>GP<0/HeM00D0[XYJ0:n;F`2_
Re/0/8aL0;6=G@020;:>GP040;>?G`2dT600/hmO0;6=G@80/8aL00<0/HeM0;>?G`2dT600202cSel3
0;6=G@<0/XiN0P2cSel30;B>I`<0/heV0`2bS6D80:n;F`<0/heN00<0/XaM0;6;G02`RU/00P2`RU/0
202^RE`0/8aL0;6=G@2cSed0/hmK0;6>F02`SED0[X]C0`2cSEh00`2dSUl0]HmP0;J@H@020;J@H@0@
0;:>G02aSE/0[h]K0:f8F`2]R5`0[XUO0;2;H@2aRf@0/XaM0;6;G02_REX0[XQI0:n9FP2bS5d0]HmP
0;NAHP80/8eE00T0/8eG0:n;E`2_ReT0[h]K0:j:FP2^RE`0[8QH0:f9F@2_Re/00P2`S5`00`2_Re/0
[HUI0:b8F0020;29HP0?0;29GP2aReh0/XaK0;>>F@2cSUL0/hmE0;B@G02cSe/0/XiJ0;6=F@2`S5P0
[h]G0:j:EP2]RED0[XYJ0080[h]K00D0/8aL0;6=G@2bSUh0/XiN0;>?G`030;6=G@<0/XiN0P2cSel3
0:n;F`80[XYJ0`2]RET20;:=H0030;6<G`2`Reh0[hYM0080[HQK00<0[8MJ0:n;F`2_Re/00P2^RUX2
0:f9F@80[8QH202^ReD80;2<G080[HIK00<0[HMJ0:f7F02]QeH00P2]R5@0102]R5<0[8QH0:b8F02/
R5P40:f9F@80[XYJ0100/XaO0;6;G02_REX0[XQG0:j9E@2_RUD0/HaE0;:=EP2/R5P0[HUI0:n;F`2`
S5`0[h]K0:f9F@2ZQUH0Z8AD202[QEH20:j:FP<0[HUI0`2/R5P00`2_Re/0[XYJ0:f9F@020:^7E`04
0:f9F@2^RUX0[h]K0:^5EP80ZhED00<0ZhIB0:^6D@2[QTl00P2[Qdd00`2YQE40ZhMC0:b8E0020:j:
EP060:b8E02[Qe<0ZHEA0:Z6EP2YQED0Yh=C0P2VPU800`2WPe<0ZHEE0:Z6EP080:Z5D@080:N3C`2X
Q500ZXIB0:b8E02]RED0[8QD0:Z6DP2YQE430:Z6DP80ZHEA0`2XQ5020:J2DP<0Yh=C0`2XQ5@00`2V
PU80Z8AD0:Z6EP020:^7E`030:R4E02VPU80Y81@00P0ZXEA0P2YQ4l20:R3CP80Yh9=0P2VPD`80:B0
D0040:V4D02WPTh0YH1<0:=nBP80XGa80P2RODT00`2SODh0Y7i?0:J0D@020:N1DP030:J0D@2TOTl0
Xge>00T0Y7m:00H0Z89E0:R2D`2XPU<0Z89A0:N2CP2WPTd20:N2B`T0YX5=00X0Z8=?0:V4D02ZQE40
ZHA@0:R3C`2VPDd0Y7m;0:=nBP2TOd/0YX5=0`2XPdl00`2WPTh0YX5=0:F1C@020:F1C@80Y81<0`2S
Od/80:=nBP040:F1C@2TP4`0Y81<0:=oB`80XWi:0P2QODT02@2YQ500Z8=?0:F0C02SOTX0XWe90:=n
BP2TOd/0YH1<09mjAP020:1kA`030:5lB02RODT0XWe90080Xgi:00@0YX9B0:B0D02ROTh0X7a<0P2O
Nd/0102PO4`0XGe=09ijBP2ONd/30:1lC00609eiB@2KMdL0VGE50:5lB02PNdL0WgY60P2NNDD00`2P
NdL0XWe90:=nBP020:=mCP<0YGm@00`0Xge>0:5kC02PNT/0X7]709ehA02JMD40WGQ40:=nBP2VPDd0
Xgi:0:1kA`2RODT20:5lB00309mjAP2NNDD0WGQ40080W7M30P2NMT<0102MN4@0W7Q409eiA@2KNTD2
09]lAP0309ag@`2NNDD0XGa80080Xgi:00<0XWe909mjAP2NNDD00P2ONTH20:1kA`0:09mjAP2LMd<0
VWE109Ud@02KMDH0W7I709ihB@2ONDX0X7Y;09miBP80WWQ900T0WGM809agBP2MN4/0WgY=0:1kCP2O
NTd0WWU<09ehB`2KMTT00P2MM4H309acA@<0Vg9400<0WGU509ahA02JMT800`2HM400102JMT80VgM3
09Qd@02IMD4309]g@`0>09Ue@@2FLSh0UG4m09Q_@@2LLdD0W7I709UeA@2DL400Sfdm095a@02EMD@0
UW9209UeA@2MNDT209mkB`0909]gA`2GLd<0Tflo09Md>P2FLc/0UW<m09A`?P2CKT40TVe10080TF]4
0`2BKSh00`2CKcl0U71009Ea@@0209Ea@@08095]?@2BKSh0U71009A`@02CKcl0TFdm08iZ>P2=JCT3
095/?b_ooooo000Zooooo`080:9hAP2QMdD0X7I409me@`2NM480WG=109ab@02KLCl309ebA@80WW=6
0`2OM4L01P2QMD@0X7A30:1d@`2NLT40WG5009a`?`80Vfln202PMD8809id@P0309ec@@2OMD<0X7I4
0080XGM500H0X7I409me@`2MLd40WW=009md@@2QMT<20:9gA0040:5f@`2OM440WW=00:9fA@80XGE4
00<0X7A309mc@P2OLd800P2NLT400`2SN4D0XWM40:5f@`020:5f@`060:=hA@2TNDH0YW]80:EiB02T
N4L0XWI50`2QMD@00`2RMTD0Y7Q70:EiB0020:5h@P090:5hA02RN4H0XWQ80:9gBP2SN4/0XgQ=09mj
AP2PNdL0XWe90080Xgi:00<0XWe90:1kA`2ONTH00P2UO4P01`2TNdL0XWU50:1g@`2OMT80WWE109ed
@02QN4@00P2RNDD00`2TNdL0YGa80:ImB@020:MnBP060:EjA`2VNdP0YW]80:MlB@2XODX0ZGi;0P2Z
Od`80:MlB@<0YWa:0`2WOD/20:QnC0<0Z7a=0P2YODh30:YnC`80Z7m;0`2YP4`30:Z1C@<0ZH1<0P2X
Od/30:MnBP080:Z0D02YOdl0Z7i>0:MmC@2XOTh0ZGm?0:^1D@2/PU820:f4D080[8=?102[PTh20:Un
D@80ZWmB0P2[P5<20:b1E0060:f2E`2]PUD0[H9E0:f3D`2]Pe40[HA@0P2]Q4h@0:f3D@P0ZXEA0P2b
Q5800`2`QE80[hIB0:j6DP020:b7DP030:^8DP2^Q5@0[XAD0080[hEE102`QUH00`2aQeL0ZhIA0:^6
D@060:^6D@<0[XEA00<0[hIB0;27D`2aR5@00P2aR5@30:b7D`<0ZhIB0`2ZQE401`2[QU80[HQD0:j9
E@2]R5@0ZhIB0:V4D02XPdl0202[QU80402[QEP0[8II0:f7FP2^R5/0[HMJ0:^5F02YPeH0Yh5D0:R0
G02XPEX0Z85F0:N1DP2WPTd0YX960:J3@`2VPd430:J1C@80YH1<0`2TOd/00`2ZPDd0ZH1<0:MnBP03
0:ElB0040:ImB@2WOTX0WgY509mjA@80WWU40`2MN4<0402LMd80Xge<0:9lB`2PNTT0WWQ709afA@2J
M4<0V79109Ma@02LMd<0VgI209Ye@@2IM400V7<o09Mb?P2FLCd209E`?00309A_>`2BKCT0T6/g0080
T6/g00P0TF`h099]>@2EKd00UFm009=]?P2BK3d0T6Xk08mY>P80SFLh0P29JCH00`28J3L0QfLh08IU
>00208ET>@0:08AS>P29ICD0RVHf08]W=`2<J3P0RfLg08YV=P28I3@0Qf<c08UT=`<0R6<f0P27HSD2
08IQ=00408AO=@23GS@0Pehd08=N=080PUdc0P21G389081J<`<0NULa0P1iES0307QE;`0407IF;@1e
EB`0MED/07EE;080M5@[0P1cDbX3079D;P80LE<]0`1`DR`0201TCB<0ITlV06QA:01[Dbd0K5@`06]C
<@1ZDC80JE0a201ZBb`206U<;P0406Q;;@1WBR`0IDPZ06A7:@80HdHX00<0H4LX0658:@1SBR/00P1T
Bb`0101SBR/0HDPY0617:01PBBL205m8:00305i7:01MABT0G4@Z0080Fd<[0P1JABH205U49@<0F4<T
00<0Ed8S05i5;`1K@R`00P1H?bT01`1J@B/0Fd8/05Y1:`1I@2X0ECdQ05Lo8`1I@BD00P1J@RH00`1G
?b<0ECdQ05<k7`0805A18`80C40X0P1>?bP0101>?RL0CcdW054l9`1@>bH404hl9P80CcdW0P1@?RP2
04`m:080Bc`W00D0BS/V04Tj9@19>RD0B3TT04/j9P0304Xi9@80BCPT0P18=b<00`13?280A3dS04Ho
9@0204M09P0304Ho9@14?B<0@c`R0080@SHN0P13=al02`14>200ACTQ04Di8@16>R80@SHN04<g7`14
>R40@c`R048l8P10?240?SXO0080>cXN2013=RD01P0l=b<0?CHS03df8`0n=R<0@3DS044d8`80@c<S
0`10>Al2044j80<0@S/Q2010>Al01P0g<Qh0>3<O03Td800j=B40?3LS03hi9@80?cXV200m=B82044f
9080@SLU00H0@cPV04@i9`14>BL0ACXX04@i8`13>282048g8@0504<h8P15>R@0Ac`V04Pm9`1<?BH0
1@1;?2D204Xk90P0C3hT00H0CS`T04lm9@1@?RH0DClW05=1:@1D@RX205E3:`@0ED@X0`1D@bL00`1C
@RH0ED@V05E49P0605E49P0605a59@1MARH0H4TY069;:`1SC2`0I4d]0P1SC2`02`1PBBT0HDXZ069;
:@1SCBP0IDlX06I@9`1WDBP0J5<X075D<P1`Dc40KU4_0080KE0^00<0KU4_071C<@1aE3800P1fEb/0
0`1gF2`0N5T]07UJ;P0207YK;`0707]L<01eHBh0Mf4_07QR<01jHc40OF<b081T=00208=T=@0807mM
;`20GS00PEla08=Q<`25HcD0QfDg08QV>029IcT208QR<`0508US=02:I3D0RV@e08]U=P2<ISL00P2=
IcP808iZ>P0808e[?@2=Jc/0SV`l08m^>`2@KcX0TG0j095a>02BLST809Ea?@0309Mc?`2HM400VWI2
0080W7Q400<0VWI209Mc?`2ELCd00P2JMDP209]fB@<0W7M:00@0WGQ;09mkA`2ONdL0Wg]70`2PO4P2
0:5mB@@0Y85;102SP4X80:R5B`80[8QD0P2[Qe<0102ZQU80ZHEA0:V5D@2XQ5020:Z6DP030:^7D`2/
R5@0[HUE0080[XYF00H0[h]G0;2;E`2`ReL0/8]G0;6<F02bSET30;>>FP080;:>GP2dT600]Y9R0;NC
H`2hU6@0]i=S0;JBHP2eTF480;NDGPP0]i=O0`2eTfD20;JDIP<0]iEW0`2jUVH30;VEI@@0^9AT0`2i
UFD30;ZFIPP0^IEU102lV6P00`2kUfL0^YIV0;VEI@0:0;VEI@030;^FJ@2jUFP0^9=V0080]i9U00<0
^9=V0;ZEJ02kUVT0202hU6@01P2fTF@0]i9U0;NBI@2iU6L0^YEX0;^FJ@80_9MZ00<0_IQ[0;^FJ@2i
U6L00P2gTVD01@2hTfH0^IAW0;ZEJ02gTel0^9AP00<0^YIR00<0^9AP0;JBGP2eTEd0202iUFD20;JD
IP<0]iEW0`2hUVP20;^GI`80^YIV00D0^IEU0;RDI02hU6@0]i=S0;BBI0020;FCI@030;NEI`2hUVP0
^IMY0080^YQZ00@0_YYZ0;fIJ@2mVFT0_9QX0P2kUfL20;ZFIP<0^IEU0P2hU6@30;NCH`<0^IEU0`2j
UVH20;^GI`040;VEI@2hU6@0^9AT0;NCH`80]Y9R0P2eTF400`2fTV80]i=S0;VEI@020;ZFIP030;VE
I@2gTf<0]Y9R00@0]I9J102fTe/80;VEI@<0]i9V00<0]Y5U0;F@I02dSf<00P2dSf<20;B?HPD0/hiQ
0P2bSF000`2hTfH0]Y5T0;F@H`020;>>H@030;F@H`2fTF@0^9=V0080]Y5U0P2eT6@0302dSf<0/hiR
0;>>HP2bSF40/8aL0;B@H02gTf<0]91P0:j:FP2/R5P0[XYJ0;:>GP<0/heN0P2dSUl30;F?H0P0]i=S
00H0/HeM0;:>GP2bSUh0]91P0;FAH@2fTV820;NCH`<0]91P0P2cSel30;:>GP<0/hiI0P2dSeX30;F@
F`80/i5Q00@0/Y1P0;6?G`2aSel0/8iN0P2_SEd20;:>GP80/HeM0P2`S5`20:n;F`80/HMQ00@0/8UR
0:n9HP2_RF80[X]S0P2]S6<20:j9G0<0[hYM0`2`Reh40;6=G@80/XiN0P2cSel30;6=G@<0/XiN0P2c
Sel80;:>GP@0/HaP0P2bSF420;>>HP<0]8mS0P2cSV830;:=H@P0/XiN0P2_Re/30;2<G080/HeM0P2b
SUh00`2`T640[XiO0:j<GP020:j9G0030;6;GP2dRel0]XeQ00P0/8aL00<0/hmO0;6=G@2`S5`00P2^
RUX00`2`S5`0/HeM0;>?G`080;2>GQ00/HeM0100]8mH0;>>E`2`Re@0[XUB0:f8D@2^RE80/8]D0;:=
EP2`ReH0/8]G0;6<F02aReX0/XaM0;:<G`2bRf00/haQ202`RU/0202eT5`0]8mK0;>>FP2bSET0/HaH
0;2;E`2_RUH0[XUE0P2]RET00`2^RUX0[h]K0;2<G0020;6=G@060;:>GP2dT600]91P0;>?G`2bSUh0
/HeM0P2`S5`02@2_Re/0]HmX0;B?I@2bSF<0/8]O0;2;GP2`S5`0/HeK0;:>G0020;6=G@80/8aL00@0
[h]K0:j:FP2^RUX0[HUI0`2`S5`30:n;F`80[XYJ0`2^R5T20:n9FP<0/8YK0P2]R5`00`2]R5/0[HUI
0:f9E`020:f9E@040:f:E02^RED0/8]G0;6<F080/XeI00<0/8]G0:j9E@2/Qe<02@2/R5P40:^7E`@0
[8QH0`2`ReL20:n:EP<0[XUE00P0ZHA@0:Z5D@2[QU80[8MC0:f8E02^RED0[hYF0;2;E`P0[XYJ0`2/
R5P30:f9F@80[XYJ0P2`ReL00`2_RUH0[XUE0:f8E0020:b7D`030:^6DP2/Qe<0[8MC0080ZhIB302Z
QE420:b7D0030:b7DP2/Qe<0[8IE0080[8IG00<0[8II0:^6DP2[QU801P2[QU880:Z6EP80ZXE@0`2Y
Q4l30:R3CP030:J2CP2WPdl0ZHEA0080ZhMC00<0ZXIB0:V5D@2XQ500202YQ5020:Z5D@80ZHA@102X
Pdl04`2[QU80ZXEA0:V4D02XPdl0Yh9>0:J1C@2UP4`0Y7m;0:N0E`2WP5D0YX1C0:J0C`2UP4/0Y7m8
0:=oA@2SOd<0XGi80:9oB@2TPD/00P2VPdd00`2UPT`0Y85;0:>0BP090:J1C@<0Yh9>0`2VPDd20:F0
C0P0YH5=00@0Xgm?0:B0D02TP500YH5A0P2VPU820:N3D`060:9nCP2SOdl0Xgm?0:F1D@2VPU80Yh=C
0P2XQ5@00`2VPTh0YH5=0:=oB`030:5mB@030:9nBP2SOd/0X81?0080X81?00<0Wgm>09inC@2MOD`0
0P2MOD`00`2UP4`0Xgi:0:9mB@020:5lB00A0:=nBP2UP4`0YX5=0:b8E02YQE40YH5=0:5mB@2PO4P0
XGe90:B0C02UPDd0WgY60:1kA`2QO4P0XWe90:=nBP2TOd/00P2UP4`80:=oB`080:F4C`2TPdh0XX5<
0:1oBP2MO4L0VWU409Uh@`2HMd880:1lB0030:1kA`2QO4P0XWe90080Xgi:01<0XWe90:1kA`2ONTH0
VGQ309]jA@2ONdL0XWe90:InB`2WOD/0YWa:0:MkBP2LMd<0WGQ409mjAP2PNdL0XGa80:1kA`2ONTH0
WWU50080W7M30P2MN4@209iiA@80WgY600<0WWY:09mkB`2QODd00P2QODd00`2ONd/0WGU909ahB002
09afA@80VgE400L0W7I509miB02QNdX0Xge<09ijBP2MNDT0W7Q80080VgM700@0W7Q809eiB@2MNDT0
WWY:0P2MNCl02@2MN440W7M209ag@P2LMd<0W7I509]eA02HLcl0VGA009]f@P0209ehA00309ag@`2K
MT80VWE100D0VGE10`2HM40209Mc@`0409QdA02IMDD0VgM709ahB080WGU900@0VWM109Uf@02GM3h0
UG8l0P2DLC/00`2ELS`0UW<m09Ib@P0209Mc@`0309QdA02IMDD0VWI60080VgM70P2IMD40102GLcl0
UW8n09A`?02CKc/2095]>@<0TV`m0P2CKCh309A^?`0609A`@02CKcl0Tflo099^?P2AKCd0T6`l0P2?
Jc/3095]?B_ooooo000Zooooo`0309ab@02MLd40WG=10080WG=10`2NM48309ebA@<0WW=60P2OM4L0
1P2QMD@0X7A309mc@P2NLT40WG5009a`?`80Vfln202OM44809id@P0309ec@@2OMD<0X7I40080XGM5
00H0X7I409me@`2MLd40WW=009md@@2QMT<20:9gA0030:5f@`2OM440WW=00080XWI50P2QMD@20:1d
@`80Wg=200/0XgQ50:9gA02QMT<0X7E20:5f@`2RMd@0Y7U60:IkB02UNDP0Y7Q70:9fA@030:5eA003
0:9fA@2TN4L0YGU80080XGQ200T0XGQ40:9hAP2RN4P0XWM:0:=hB`2SN4d0WgY60:1kA`2RODT00P2S
OTX01@2RODT0X7]709mjAP2UO4P0Y7]70080XgY600X0XWU50:5hA02PMd<0WgI20:5hA02RNDD0XgY6
0:AkA`2UO4P0YWe90P2WOTX40:MlB@@0Z7e:202WO4T30:IlBP<0Yge;0P2XOT`30:QlC@80ZGe>0`2Z
OTl20:QoB`<0ZH1<0`2ZPDd30:V0C080Z7m;0`2WOTX0202ZP500ZGm?0:QnCP2WODd0Z7i>0:UoC`2[
PE40[89B0P2]Q5020:b3C`<0Zh9>00<0ZX5=0:UnD@2YOU400P2ZOe820:^0D`80[85D00H0[H9G0:f2
E@2]PUD0[H=C0:f3D@2]Q5020:f4CPd0[H=A0`2/PU080:Z5D@80/H=A00<0[hAA0:j5D@2]QE400P2[
QU400`2ZQe40[XAD0:j4E0020:n5E@D0/8IF202[QU420:j5D@80[hIB0P2`Qe<20;68E0<0[8MC0`2[
QU820:Z5D@80ZhIB0`2]R5@00`2[QU80ZHA@0:R3C`080:^6DP030:^5EP2/QUL0[HMH0080[HMH00`0
ZhEF0:V3E02XPU<0ZH5M0:V2F`2YPUL0Z89C0:R3CP2XQ4X0Yh=50:N4A02WPTh30:J1C@80YH1<0P2T
Od/00`2ZPDd0ZH1<0:MnBP020:ElB0030:ImB@2WOTX0Z7m;00<0WgY50P2NND@309eh@`80WWQ70P2M
MdH0102LMTD0VgE409]eA02KMD@209]f@P0309Ye@@2IM400V7<o00<0Ug8n00P0UW4m09E`?02CKSX0
TVdi095/>02BKCT0Tfhj09A_>`80UFm00100U6ho099/?@2@JS/0SfTj08iX>@2=IcP0RVXg08UY=P29
JCP0R6Pi08MV>@26ICX0QF@i08ET>`2:ISH0RfLg0`2<J3P00`2:ISH0RFDe08MS<`0308UT=`80R6<f
0`27HSD308AO=@80Pehd0`22GC<9085L<P80NePb0P1jEc4307UF<00407QE;`1fERd0MUH]07IF;@80
MED/0`1dE2/207EE;`80M5@^0`1cDbd02@1bDR`0JE0W06YA:01/Db/0KE<^06iD<@1]Dc80Je4`06Y?
<@0806Y;;00606Y=;`1YC2h0J4/]06M:;01VBB/0IDPZ0P1TAbT00`1PAbP0HTTZ06=::`0206A;;003
06=::`1RBBX0H4LX0080H4TW00<0GdPX05i7:01MABT00P1LA2X0101K@b/0FTDV05Y59P1JABH205U4
9@<0F4<T00X0FT8Z05]3:`1LA2`0Fd<[05U1:@1H@2P0EclW05Q0:01G?b<0F40T0P1I@BD0101H@2@0
EclS05Hn8P1E?B4805A18`80CT8Z00H0Cd0Y04lo:01@?RP0DC`W050k9P1A>bH804hl9P0304`m:01;
?2L0Bc`W0080BS/V00<0BCXU04Pi9018>B@00P1;>RH204Xi9@<0BCPT00@0B3LS04<l8P14?B<0AChT
0P16?bD00`15?R@0A3dS04<l8P0304<g7`0304@h8015>B40ACTQ0080ASXR00L0A3DN04<g7`15>B40
AC/R04<l8P11>b40?SXO0080?CTN2013=R<01P0m>280?SPR03hh8P0o=b80@CHR048e8P80A3DR0`10
>Al2044j80<0@S/Q2010>Al01P0j=1h0>cDO03/e7`0l=R00?CLQ03hh8P80?cTS200n=R43048g8`03
04<h9014>BD0A3TU0080ACXV0P15>B<204@h8P0404Di8`17>bD0BCdW04Xn:0D0C3dV0`1;?2D304`n
8`80CClT0P1>@2D00`1?@BH0DclV05<o9P0205A09`0405E1:01F@RT0Ed<Z05M3:PH0Ed<X0P1HA2T3
05Q59@80FDHV0P1JAbL01@1KB2P0GTLW05m8:01QBRX0Hd`/0080I4d]00`0Hd`/069;:`1RBb/0Hd`Z
06A=:`1UCbX0Ie4Z06QB:@1YE2T0JUDZ071D;`1_Dbh306iB;@04071D;`1bES40LeLb07IG:`80MeP/
00<0N5T]07UJ;P1jFbl00P1kG30207QR<00>07YS<@1mHc80Of<c085R<`22Hc@0Pf<d085O<@22H380
Pf4c08AR=025HcD0QV@f08MU=`28ISP208US=080RV@e00<0RfDf08aV=`2=IcP00P2>J3T808iZ>P06
08e[?@2>K3`0SV`l08m^>`2@KcX0TG0j0P2BLST809Ib?P0309Qd@02IMD40VWI20080VWI200<0VGE1
09Qd@02HM4000`2KMdL209ahB0<0WGU90`2PO4P20:5mB@<0XWi:1@2UPT`30:B1B`P0Z8E;0P2/R5@2
0:^7D`80ZXIB0P2YQE420:^7D`040:b8E02]RED0[XYF0:n;E`80/8aH0P2`ReL20;6<F00<0;:=F@2c
SUX0/hiJ0;>>FP2bSUh0]91P0;JBHP2gTf<0^9AT0;NCH`2fTV80]I5Q402gTel20;FCI@<0]YAV0`2g
UFL30;ZFIP<0^IEU102hU6@30;VEI@<0^YIV202iUFD30;bHJ080^iMW00<0^YIV0;VEI@2iUFD02@2i
UFD00`2kUVT0^YEX0;RCIP020;NBI@030;RCIP2jUFP0^iIY00P0^9AT00H0]Y5T0;NBI@2hTfH0^IAW
0;ZEJ02kUVT30;bGJP0:0;^FJ@2iU6L0^9=V0;NBI@2hTfH0^IAW0;ZEJ02gTel0^9AP0;VEH@80^YIR
00<0^9AP0;JBGP2eTEd0202iUFD20;JDIP<0]iEW0`2hUVP20;^GI`80^YIV00X0^IEU0;RDI02hU6@0
^9AT0;BBI02eTfD0]YAV0;NEI`2hUVP0^IMY0P2jV6X20;fIJ@80_9QX0P2kUfL20;ZFIP<0^IEU0`2h
U6@20;NCH`<0^9AT0`2iUFD20;ZFIP<0^9AT00<0]i=S0;JBHP2fTV800P2eTF400`2fTV80]i=S0;VE
I@020;ZFIP030;VEI@2gTf<0]Y9R00@0]I9J102fTe/80;RDI080]i9V0P2fTFD0102eT6@0]8mS0;B?
H`2dSf<20;F@H`80]8mR0P2cSV401P2bSF00/HaO0;6<G`2gTVD0]Y5T0;F@H`80]8mR00<0]I1S0;JA
I02gTVD00P2fTFD20;F@I00<0;B?H`2cSV80/hiR0;>>HP2`S5`0]91P0;JBHP2dT600/8aL0:j:FP2a
SEd0]91P0`2cSEh20;B>G`<0]HmP202fTV801@2aSEd0/XiN0;:>GP2cSel0]I5Q0080]Y9R00@0]i=S
0;B@H02dT600]91P0P2cSel30;:>GP<0/hiJ0P2dSe/30;F@G0<0/Y1P0P2aSel30;2>GP80/XiN0P2a
SEd20;2<G080[h]K0P2aQel0102`RF00[hYP0:n:H02^Rf420:f<H@80[XUL0`2_RUd30;2;GP040;2<
G02aSEd0/HeM0;6=G@80/XiN0P2cSel30;6=G@<0/XiN0P2cSel80;:>GPP0/XeQ0P2dSf<30;>>HP<0
/XeQ202bSUh20:n;F`<0/8aL0P2aSEd20;:>GP030:n?H02^SUl0[XaN0080[hYM00<0/H]N0;B;G`2e
S600202aSEd00`2bSUh0/HeM0;2<G0020:n;F`030;2<G02aSEd0/XiN00P0/8iN402aSEd00`2cSUL0
/XeF0;2;E0030:n:D`80/8]D00H0/8]F0;2;E`2aS5P0/H]J0;:<G@2bS5l20;:;H0P0/8YK0P2dSe/0
1P2cSUX0/XeI0;6<F02`ReL0[hYF0:j9E@80[HUI00@0[XYJ0:n;F`2`S5`0/8aL0P2aSEd20;>?G`<0
/XiN0`2aSEd0202eSfP0]8mU0;:=H`2`Rel0/8]N0;2<G02aSE/0/XiL0P2aSEd20;2<G080[h]K0P2^
RUX30;2<G0<0[h]K0P2^RUX80:n9FP80[HQL00<0[HQK0:f9F@2]REL00P2]RED02@2]RU@0[XUE0:n:
EP2`ReL0/HaH0;2;E`2_RUH0[HQD0:^6DP0>0:b8F0<0ZhMG0P2`ReL30:n:EP<0[XUE0P2ZQE401P2[
QU80[8MC0:f8E02^RED0[hYF0;2;E`P0[XYJ0`2/R5P30:f9F@80[XYJ0P2`ReL0102_RUH0[XUE0:f8
E02/Qe<20:^6DP80[HQD0`2/Qe<30:^6DPP0ZXEA0P2/Qe000`2/Qe80[8MC0:b6E@020:b6E`030:b6
F@2[QU80ZhIB00H0ZhIB202ZQUH20:Z5D0<0ZHA?0`2XPdh00`2VPTh0Yh=?0:V5D@020:^7D`030:Z6
DP2YQE40Z8A@00P0ZHA@0P2ZQE420:V4D0<0Z8=?00L0Yh9>0:Z5D@2ZQE40ZHA@0:R3C`2WPTh0YX5=
0080YH1<00H0Z85F0:N0E@2WPE@0YX1?0:F0C02TOdP20:=oA@030:5nB02ROdT0Y85;0080YX==00<0
YH9<0:B1B`2SP4X0302WPTh30:J1C@80YH1<202UPDd30:B0D0030:F1D@2VPU80YX9B0080Yh=C00H0
XWi>0:=oC`2TP500YH5A0:J2DP2WPe<20:R4E0030:J2CP2UPDd0Xgm;00<0XGe900@0XWi:0:=oB`2P
P4l0X81?0P2OOdh209inC@80WGe<00<0YX5=0:AoB`2SOTX00P2RODT02`2SOTX0YH1<0:J1C@2ZQU80
Yh=?0:=oB`2PO4P0Wg]70:1lB02ROTX0Y81<0080XGa80P2RODT30:=nBP030:AoB`2SOd/0Xgm;00H0
Xgm;00P0Xh9=0::1C02QP4/0Wgi909elA`2KNTD0VWU409Uh@`P0X7a800<0X7]70:5lB02RODT00P2S
OTX0202RODT0X7]709mjAP2IN4<0VgY509mkA`2RODT0YGe:0P2VO4X0102VNTT0WGQ409iiA@2ONTH2
0:1kA`0309mjAP2NNDD0W7M30080W7M30P2MN4@209iiA@80WgY600/0WWY:09mkB`2PO4`0XGe=0:1l
C02ONd/0WGU909ahB02QNdX0WgU809ihA`0209afA@0609egAP2NN4L0WgU809ijBP2MNDT0W7Q80P2K
MdL0102LN4P0WGU909eiB@2NNTX209ij@00409ii@P2MN4<0W7M209]f@P80VgE400<0VGA009Ye@@2L
Md<00P2MN4@0102LMd<0VWE109Ud@02JMT8409Ue@@<0V7A00P2HM4@209UeA@0=09YfAP2KMdL0W7Q8
09ahB02IMD40V7A009Ib?P2ELCd0U70l09Ea?@2FLSh0Ug<o09Mc@`0309QdA0@0VGE500P0VGE109Qd
@02GLcl0UW8n09A`?02CKc/0TVhj095]>@<0Tfdn0P2DKSl309E_@080U71000@0Tflo099^?P2AKCd0
T6`l0P2?Jc/3095]?B_ooooo000Zooooo`0809M]>`2HKS`0VFlm09]a?`2LLT00WWA209me@`2PMT@2
09aaA080WG950`2NLdH01P2OM4L0X7A30:1d@`2OLd80WW9109ea@080W70o00<0Vfln09eb?`2MLSl0
1P2MLSl809id@P0309ec@@2OMD<0X7I40080XGM500H0X7I409me@`2MLd40WgA10:1e@P2QMT<20:9g
A0030:5f@`2PMD80WgA10080XgM60P2RMTD40:5eA00;0:=hA@2RMd@0XGI30:1e@P2QMT<0XWM40:Ai
AP2UNTL0Y7Q70:=gAP2RMTD00`2QMD@00`2RMTD0XgM60:AhA`020:5h@P090:5hA02RN4H0XWQ80:9g
BP2SN4/0XgQ=09mjAP2PNdL0XGa80080XWe900<0XGa80:1kA`2ONTH0202SNTH20:9iA@030:=jAP2T
NdL0YGa80080YWe900@0Ygi:0:QmBP2XODX0Z7e:0`2WO4T20:IkB0P0Yga90`2VO4X30:MmB`80Z7i<
0`2XO4/20:UmC0<0ZWi=0P2XOd/30:V0C0<0ZX5=0`2YP4`20:QoB`<0Ygi:00P0ZX1>0:UoC@2XOT`0
Yge;0:QnC02YOdd0Zh5?0:b2D0<0[8=?0P2[PTh30:Z1C@80ZGiA0P2ZOe820:^0D`80[85D00H0[85F
0:b1E02/PE@0[89B0:b2D02/Pdl20:b3C@P0[89@0`2^Q5801@2]Pe40[89@0:^1C`2[PDl0ZX1>00P0
ZXEA0P2_PDl00`2]PTl0[8=?0:^3C`020:V4C`040:R5C`2^Q580[XAB0:j4DP80[hEC102`QU@80:^6
D@040:j5D@2_QU80[hIB0:n6DP<0/8MC00@0/HQD0:b7D`2/Qe<0[8MC0`2[QU820:Z5D@080:^6DP2/
Qe<0[8MC0:f8E02/Qe<0ZhIB0:Z5D@2YQ5080:^6DP080:^5EP2/QUL0[8IG0:f7F02/QUL0ZhEF0:Z4
E@2YPe@20:^4F`060:^5F02ZQ5<0ZXE@0:V4C@2YQDT0ZHE70`2WPTh20:J1C@<0YH1<00P0ZX5=0:V0
C02WOTX0YWe90:ElB02VODT0Ygi:0:QoB`80X7]60P2ONTD309iiA00509eh@`2JMD40VWE109Ye@@2K
MT800P2LMd<209ehA0P0VGA000P0V7<o09Mb?P2EL3`0U6lk09=^>P2DKc/0UG0l09Ia?@80UFm00100
U6ho099/?@2AJc`0T6Xk08mY>P2>J3T0S6/h08]Z=`2;JCT0RVPj08UW>P28IC/0Qf@j08MT?02;IcL0
S6Ph0`2=JCT00`2;IcL0RVHf08QT=00308YU>080RF@g0`28HcH208IQ=`80QF0f0P24GcD208=N=0T0
PUdc0`1lFC4207]H<0<0NUL_0P1hF2l207MG;P80MUH]0P1eEB`207IF;`80MED^0`1dE2d02@1cDb`0
L5DZ071D;01aEBd0LED^075E<01`Dc40Ke8b06iA<@0806a>;080JTd]00<0JD`/06Q;:`1WBRX00P1V
BBT0101UB2P0HTXX06=;:@1TC2X206E=:`0406A<:P1SBbT0HTXX06=;9`80HTXX00<0HDPY0617:@1O
ABX00P1NA2/305e69`80G4DV0`1KA2D02`1J@RX0HDTa06M?=`1UCCD0GTH^05U1:@1J@RX0GDD]05]3
9`1J@RH0FD4U00<0EclS0P1H@2@805E29080DT@Z00@0DT8Y0590:01@?RH0DCdU0P1A>b@2050n9P03
04lm9@1>?2@0CC/S00<0C3XR0P1<?2D304/k90<0BSXS00@0C3`U04/k901;>b@0Bc/T0P1:>R<204Ti
8P0304@j8@15>b80AS`S0080AcdT00@0AS`S04Dk8P14>R40A3PP0`15>B4304Hj8P0804Lk8`16=b00
ASLP04Di8@15>b80@c`R044k8@10>R0203lk80P0A3LT00H0?STS03li8`0o>B<0@3PS048g8`13=R<2
04Df8`<0@cTP0P14>R4304Dk8PP0@cTP200o=b88044f8P0404<h9014>BD0A3TU04@i9@<0ACXV00<0
AS/W04Lk8`16>R800`16>R800`18?2@0BclW04a0:00804hn9@0604`l8P1=?B<0CShT04lo9@1@@2H0
DT8X0P1C@bT305I2:@D0Ed<Z0P1GA2H0101HABL0FDHX05U6:01JAbT205]8:P80FDHV00T0FTLW05a9
:@1MBRX0GT/[05m<;01PCBd0Hd/Y06A<:P1UCB/00P1VCR`00`1UCB/0I4`Z06=;:@0206M?;@0706Q@
;01ZDR`0Je@[06aE:`1]ER`0KUL[071D;`0306mC;P04071D;`1cEc80METd07MK=P80N5T]00<0NEX^
07YK;`1kG3000P1lGC401`1mGS80NfDc07aU<`1lIC<0OV@c07mS<`21HS<00P22HS<308AR=080QF<e
0P26I3H01@27ICL0RVHf08YV=P2:ISH0RfLg0080S6Ph00<0SFTi08iZ>P2>JSX0202?Jc/0202>K3h0
SV`l08m]?@2@Kc`0TG0k099a>`2BLST0Tg<j202GLcl00`2KMd<0VWI209Ue@@0309Ue@@0309Yf@P2K
Md<0W7Q80080W7Q80P2MNDT309ijBP80XWi:0P2SOd/30:B0C0040:F1C@2VPdd0YX==0:J3C@D0YhA>
202YQTh20:b8E0<0ZhMC0`2ZQU820:f9E@030:j:EP2_ReL0/8aH0080/HeI00@0/XiJ0;6<F02aS5P0
/HaH0P2bSET30;>>FP080;:>GP2dT600]Y9R0;NCH`2hU6@0]i=S0;JBHP2eTF4@0;NCG`040;FCI@2f
U6H0]YAV0;JDIP80]iEW0P2hUVP30;ZFIP<0^IEU102hU6@30;VEI@<0^YIV202iUFD40;^GI`80^YIV
2`2iUFD00`2kUVT0^YEX0;VDI`020;RCIP030;VDI`2jUFP0^iIY00P0^9AT0P2gTVD00`2hTfH0^IAW
0;ZEJ0020;^FJ@80_9MZ00<0^iIY0;VDI`2hTfH00P2hTfH20;VDI`060;RDH02iUF40^IEQ0;ZFHP2i
UF40^9AP0P2fTUh80;VEI@80]YAV0`2gUFL30;RFJ0<0^YIV0`2iUFD20;RDI080]I=U00<0]YAV0;NE
I`2hUVP00P2iUfT0102jV6X0_9QX0;bHJ02lV6P30;^GI`@0^YIV0P2iUFD30;RDI0030;NCH`2fTV80
]Y9R00<0]i=S1@2hU6@30;NCH`@0]Y9R00L0]i=S0;RDI02iUFD0^IEU0;RDI02gTf<0]Y9R00@0]Y=M
102eTU`80;JBHP<0]Y5T0P2eT6<30;B?HP80]Y5T0P2eT6<00`2dSf80/XeP0;6<G`020;2;GP030;NB
I@2fTF@0]I1S0080]8mR00<0]I1S0;JAI02gTVD00`2eT6<30;B?HP80/hiQ00P0/HeM0;>?G`2fTV80
]I5Q0;>?G`2bSUh0]91P0;NCH`<0/heN0P2dSUl30;F?H0P0]91P00H0/HeM0;:>GP2bSUh0/hmO0;B@
H02eTF420;JBHP<0]91P0P2cSel30;:>GP<0/hiJ0P2dSe/30;F@G0<0/XiN0P2cSel30;B@H080/XiN
0P2aSEd20;2<G080[h]K0P2aQel0102`RF00[hYP0:n:H02^Rf420:f<H@80[XUL0`2_RUd30;2;GP<0
/8aL0P2aSEd30;:>GP<0/HeM0`2bSUh20;>?G`P0/HeM102cSV401@2bSF00/HaO0;2;GP2_RUd0]8mR
00<0/hiQ0P2bSF020;6<G`P0/HeM0P2_Re/30;2<G080/HeM0P2bSUh00`2_Sf00[XiO0:j<GP020:n:
G@030;6;GP2dRel0]HaP00T0/XiN00L0/HeM0;2<G02_Re/0[h]K0;2<G02aSEd0/XiN00P0/8iN402a
SEd02@2`ReH0/HaG0;6<E`2bSEP0/HaG0;2;EP2_RUD0[XUD0;2;EP020;2;E`030;6;FP2aRe`0/XaO
0080/X]P202`RU/20;>>FP040;:=F@2aS5P0/8]G0;2;E`80[hYF00H0[8QH0:f9F@2]RET0[XYJ0:n;
F`2`S5`50;6=G@<0/XiN0P2cSel0202eSfP0]8mU0;:=H`2`Rel0/8]N0;2<G02aSE/0/XiL0P2aSEd3
0;2<G0<0[h]K0`2`S5`30:n;F`80[XYJ00D0/H]L0;2:F`2`RU/0[hUJ0:j8F@020:f7F0060:b6E`2]
R5`0[HQL0:f8F`2]RET0[HUG0P2]RED01`2]RU@0[HQD0:j9E@2^RED0[hYF0:j9E@2]R5@00P2[QU89
0:b8F080[XYJ00@0[HUI0:b8F02/R5P0ZhMG0P2ZQUH0102`ReL0[hYF0:n:EP2_RUH20:j9E@80[HQD
0P2[QU80102/Qe<0[HQD0:j9E@2^RED20:n:EPP0[HUI0`2/R5P30:f9F@80[XYJ00H0/8]G0:n:EP2_
RUH0[XUE0:f8E02/Qe<20:^6DP<0[XUE0`2]R5@20:b7D`P0ZhIB0P2/Qe000`2/Qe80[8MC0:b6E@02
0:b6E`030:b6F@2[QU80ZhIB00H0ZhIB202ZQUH20:Z5D0<0ZHA?0`2XPdh00`2VPTh0Yh=?0:V5D@02
0:^7D`030:Z6DP2YQE40Z8A@00/0ZHA@0P2XPdl30:N2CP050:Z5D@2YQ500ZHA@0:R3C`2WPTh00P2V
PDd0302UP4`0Z89E0:R2E@2WPE80YX1?0:F0C02TOdX0Y7m80:=nA`2QOTP0XWm90:B1B`80YX==00<0
YH9<0:B1B`2SP4X02@2XPdl30:N2CP<0YX5=0P2UP4`80:F1C@80Y81@0`2UPE430:J2DP80Xgm?00<0
Y81@0:F1D@2VPU800P2WPe<0102XQ5@0YX9>0:F1C@2SOd/30:5mB@030:9nBP2SOd/0XGm?00<0X7i>
0`2OODd0102NO4`0Yh9>0:J1C@2UP4`20:AoB`0;0:F0C02VPDd0YX5=0:N3C`2UPDd0XGe909mkA`2N
NTH0Wg]70:5mB@2ROTX00`2SOTX20:9mB@<0XGa8202ROTX01P2SOd/0XWi:0:9nBP2QODT0X7a809mk
A`80WWY6202PO4P00`2ONTH0X7]70:9mB@020:=nBP0;0:9mB@2QO4P0X7]709YiA02KNTD0Wg]70:9m
B@2UODX0YWa:0:EkB@2UNDP00P2ONTH30:1kA`0309iiA@2LMd<0VWE10080W7M30P2MN4@209iiA@80
WgY600d0WWY:09mkB`2PO4`0X7a<09mkB`2NNTX0WGU909ahB02TOd/0Xgi:0:1kA`2NNDD0WGQ400<0
W7M300<0WWY:09eiB@2LN4P00P2KMdL0102LN4P0WGU909eiB@2NNTX20:1l@P0409mj@`2MN4<0W7M2
09]f@P80VWA300P0VgI209ag@`2MN4@0WGQ409ag@`2KMT80V7<o09Mb?P<0VWI200D0VGE109Qd@02H
M400V7A009Mc?`0509UeA@<0VWI600T0Ug<o09Ib?P2ELCd0U70l09Ea?@2FLSh0V7A009Ue@@2IMDD0
0`2HM4@409Mc@`0809Ue@@2HM400Ug<o09Ib?P2DL3`0Tflk099^>P2AKCT209A^?`80UFm00P2FL442
09Ma@P80U71000<0Tflo099^?P2AKCd00P2@K3`0102?Jc/0TVhn099^?P2BKSh[ooooo`00:_ooool2
09Q^?080VFlm00@0VW0n09]a?`2LLT00W7900`2LLD@209ebA@<0WW=60`2OLd800`2NLT40WG5009ea
@00209a`?`P0W74n202NM4800`2MLd40WgE30:1fA0020:5gA@030:1fA02OMD<0WG=100<0X7E20P2Q
MT<30:1e@P<0XgM61@2RMTD00`2RMd@0XGI30:1e@P020:1e@P030:9gA02TNDH0YGY700<0XgM60`2R
MTD30:=gAP80XGQ200H0XGQ40:9hAP2RN4P0XWM:0:=hB`2SN4d30:1kA`80XGa80`2PNdL20:9iA@80
XgY600@0Y7]70:ElB02UO4P0YWe90`2SNTH00`2TNdL0YGa80:ElB0020:ImB@80ZGi;00<0Z7e:0:Ml
B@2VNdP00P2UNTL00`2TNDH0Yga90:MlB@060:MlB@<0YWa:0`2WOD/20:QnC0<0Z7e:0P2YOT/30:Yo
C080Z7m;0`2YP4`30:Z1C@<0ZH1<0P2XOd/30:MnBP070:Z1C@2YP4`0Z7m;0:MnBP2XOd/0ZH1<0:^2
CP030:b3C`<0Zh9>0`2ZPDd20:UnD@80ZWmB0P2[P5<20:b1E0060:b1EP2/PE@0[85D0:b2DP2/PU00
[8=?0P2/Pdd80:b2D0040:n5D`2^Q580[H=A0:f3D@80Zh5?00<0ZX1>0:UoC@2ZQE401`2ZQE420:j0
CP030:b1CP2[PTh0ZX9>0080Z8=>00<0YhA>0:f4D02]Q5000P2^QE430:n6DP80/8MC202[QU440:n6
DP@0/8MC0`2/Qe<30:^6DP80ZXEA102/Qe<20:^6DP80ZXEA202[QU820:^5E0<0[8IE0P2[QE@01P2Z
Q5<0[HIK0:f7FP2/QUL0[8IE0:^6DP80ZhI?00@0ZXI<0:R3C`2XPdl0Z8=?0P2WPTh30:J1C@030:^2
CP2ZPDd0Z7m;00<0YWe900@0Ygi:0:QoB`2QO4L0XGa70P2PNdH309mjA@0309iiA02KMT40VgI100H0
VgI100@0V7<o09Ud@02IM400VGA00`2JMD402P2KMT80VWE109Ud@02GLSh0UW4m09E`?02FLCd0Ug8n
09Qc?`2EKd0209A^?`0509=]?P2AJc`0T6Xk091Z>`2?JCX00P2?JcT00`2>JSX0SFPk08aW>`0208]V
?00908YT?@2<J3P0SFTi08iZ>P2?Jc/0SVXj08eY>@2;IcL0RVHf00@0RfHi0P2:ICP208UT=`@0Qf8h
0P26HCL208EP=PT0Q5lc0P1nFc4307eJ<0<0O5T_101iFC0207QH;`80MeL^0`1hEbh207MF;@<0MUD/
00H0M5T/07AI;P1dFBh0LeL_079F;`1aEC02071C<@P0KU0/00<0Jdh/06Y=:`1ZCB/00P1YC2X206Q;
:@0306M::01TC2P0IDdY00D0IDdY00L0I4`X06E;9P1UBbP0I4XW06A::@1SB2X0HTLZ0080HDH[0P1P
AbT205m6:0<0GTDW00`0GD@V05e5:`1XD3H0LETo06mG?@1UCC<0GDD[05i6;01SBc40GTHZ05a4:01I
@BD205Lo8`0305Q0901J@RH0G4@X00P0ET<U00P0E4H[05E5:`1D@bT0Dd8X05A09`1C?BD0E3`T05<k
8`80DD0V00@0D3lU04ln901=?280C3/Q0P1;>R0404dk8`@0C3XR101<?2<204/k8P80BSXQ0P16>R84
04Lk8`@0ASXR1P17>b<01@18>240BCTR04Pi8P16>R80AC/R0080@c`R0P11>b4804Di8`0603lk8P10
>R80@3XR044i8P13>280A3PR0P16=b8304Di8@<0ASXR0P17>b<804Hj8P80@c/T00@0@SXS044i8P11
>B80@3PQ0P0o=b0804@h8P80ACXT1P16>bD204/m8`80BS`R00@0BcdS04do9@1?@BL0D48X0`1@?bD4
05509P0905919`1>?B40CchR050o8`1B@BD0E4<W05I5:@1GARX0F4L[0080FdH[0`1JABX305U4:@80
FD@U00`0FTDV05a7:01MB2T0GTTZ05m::`1PBb`0G4PW05e9:01NBRT0H4`[069>;@1SCbh206EA<00@
06M=:P1XCR/0JDl/06Y@;@1YCb`0J4h[06I<:@1UBbP0Je4^06aB;`1]Dbh0KUD]06mF;@1aFBd0LUX^
079J;080LED^00H0L5@]075E;P1cEc00MUXc07QL=@1jGSL207YK;`0407]L<01lGC40OEhb07eN<P80
OUlc00P0OfPf081V=@20ISD0PFDe089S=023Hc@0Q68d08=Q<`P0QV@f0P29IcL208YX>00308]Y>@2<
JSX0SF/k0080SV`l202AKCd0202?KCl0Sfdm091^?P2AL3d0TW4l09=b?02CLcX0U7@k202HM4000`2M
NDD0VgM309Ue@@0209Qd@00309Yf@P2MNDD0Wg]70080WGU70P2NNTP409mkB@80Y81<0P2UPDd30:J2
CP030:N3C`2WQ4h0YhA>00<0Z8E?0`2YQU080:Z7D@80[8QD1P2[Qe<01P2^RUH0[h]G0:n;E`2`S5P0
/HeI0;:>FP80/hmK102bSET40;>>FP080;:>GP2dT600]Y9R0;NCH`2hU6@0]i=S0;JBHP2eTF480;RD
HPP0^9AP0`2fU6H20;NEI`<0^9IX0`2jUVH30;VEI@@0^9AT0`2iUFD30;ZFIPP0^IEU1@2jUVH<0;VE
I@030;ZEJ02iU6L0^IAW00@0^IAW00<0^YEX0;RDI02hU6@01P2hU6@30;RCIP030;VDI`2jUFP0^YEX
00<0^iIY0P2jUFP20;VDI`<0^9=V102iUF40102hU600]i=O0;NCG`2fTUh80;VEI@80]YAV0`2gUFL3
0;RFJ080^YIV1P2iUFD30;JDIP030;NEI`2hUVP0^9IX0080^IMY1P2kUfL50;ZFIP80^IEU0`2hU6@2
0;FAH@<0]Y9R2@2gTf<20;JBHP030;FAH@2fTV80^9AT0080^IEU00<0^9AT0;JBHP2eTF40102fTUh4
0;FAG@`0]I5Q102dT6002@2gTVD0]Y5T0;F@H`2eT6<0]8mR0;:=H02aS5l0/8]N0:n:G@020;JAI0@0
]I1S0P2fTF@20;FAH@H0]91P00<0/XiN0;>?G`2dT6000`2eTF400`2gTf<0^9AT0;>=GP020;>=GP80
]8iO0`2eSf080;>?G`<0/XiN00<0/hmO0;B@H02dT6000P2eTF430;B@H080/hmO0`2bSUh30;>=G080
]8iM0`2eSeh20;:<G@040;>=GP2dSUl0]8iO0;F?H080]Y1Q0P2bSUh20;6=G@80/8aL0P2_Re/20;67
G@040;29GP2_RUh0[hYN0:j<G`80[HaO0P2^RE`30:n:G@<0/8]N0`2`S5`30;6=G@80/XiN0`2aSEd3
0;:>GP80/hmO202aSEd40;B@H0040;:>GP2`S5`0[XYJ0:f9F@<0/hmO0P2bSUh;0;6=G@80[h]K0`2`
S5`20;6=G@80/XiN0P2^SUl0102^S5h0/8]N0;2;GP2aReh20;B;G`P0/hmO0P2aSEd40;2<G080/HeM
202`SUh@0;6=G@030:j9E@2`ReL0/XeI0080/hiJ00T0/HaH0:j9E@2/Qe<0[hYE0:n:EP2`ReL0/8YI
0;6;G02aReh00P2bRf080;2:F`80/XeI0P2aS5P20;2;E`80[hYF0P2/R5P00`2]RET0[XYJ0:n;F`02
0;2<G0070;6=G@2_Re/0/8aL0;2<G02aSEd0/XiN0;>?G`020;B@H0080;F?J02dSfD0/XeS0;2;G`2`
Reh0/8aL0;6=F`2bSU`20;6=G@T0/8aL0`2_Re/20:j:FP80/H]L00@0/8YK0:n9FP2]QeP0[8IG0P2[
QEH20:f8G0030:f8F`2]RET0[HUG0080[HUE00<0[HYD0:f8E02]R5@00P2]R5@0102/Qe<0ZhIB0:^6
DP2ZQE490:f9F@80[h]K00@0[XYJ0:f9F@2/R5P0ZhMG0P2ZQUH30:n:EP80[XUE0`2]R5@20:b7D`80
[HQD0P2^RED20:n:EPP0[HUI0`2/R5P30:f9F@80[XYJ0P2_RUH00`2^RED0[HQD0:b7D`020:^6DP03
0:Z5D@2_RUH0[hYF0080[hYF0P2^RED20:f8E0P0ZhIB0P2/Qe000`2/Qe80[8MC0:b6E@020:b6E`03
0:b6F@2ZQE40ZXEA00H0ZXEA202YQED20:Z5D0<0ZHA?0`2XPdh00`2VPTh0Yh=?0:V5D@020:^7D`03
0:Z6DP2YQE40Z8A@00X0ZHA@0`2XPdl30:N2CP80ZHA@0P2XPdl20:N2CP80YX5=0P2XPU402@2WPE00
YX1?0:J1C@2UP4`0Y7m;0:AoBP2QOTP0XWm90:B1B`020:J3C@030:F2C02TPD/0Xh1:00T0ZHA@0`2W
PTh30:J1C@80YH1<202UPDd60:F1D@80YX9B0`2TP5000`2UPE40YX9B0:J2DP020:N3D`030:J2CP2U
PDd0Xgm;00<0XGe900<0XWi:0:=oB`2ROTh00`2ROTh40:5mC@80Yh9>00<0YX5=0:F0C02UP4`00`2U
P4`0402TP4`0XWi:0:1lB02NNTH0WGU509ijAP2PO4P0XGe90:F0C02TOd/0Xgi:0:9mB@2QO4P0X7]7
09mjAP2NNDD80:9nBP<0XWe91@2QO4P809mkA`0309mjAP2PNdL0XWe90080Xgi:00`0XWe90:5lB02P
NdL0VWU409]jA@2ONdL0XWe90:AlB@2UNdT0Y7Y80:AhA`2ONTH30:1kA`0409mjAP2MN4@0VWE109Qc
?`80W7M30P2MN4@209iiA@80WgY6102ONd/0102NNTX0WGU909eiB@2LN4P20:9mB0030:5lA`2PNdH0
WgY500<0WWU400<0WWY:09eiB@2LN4P00P2KMdL0102LN4P0WGU909eiB@2NNTX20:5m@`0609mj@`2N
ND@0W7M209]f@P2JM4<0VG=20P2MN4@01`2NNDD0WGQ409ag@`2JMD40Ug8n09Ia?@2KMd<00P2JMT80
0`2IMD40V7A009Qd@00209Mc?`<0VWI60P2IMDD309QdA00809Ib@02ELCl0U70n09A`?P2ELCl0Ug=1
09Ue@`2JMT@209UeA@0309QdA02GLd<0UW920080UG5100H0U71009Qd@02GLcl0Ug<o09Ib?P2DL3`2
09=_>`03099^>P2EKd00UW110080UW110P2GLD8209Qb@`0609Ea@@2DL400U71009=_?`2BKSh0TFdm
0P2@K3`3099^?R_ooooo000Zooooo`0509ab@02KLCl0Vg4o09Y`?P2IKcd00P2HKS`00`2GKC/0Vg13
09]`@`0209aaA080WG950P2NLdH00`2OLd80WW9109ib@@0209ib@@<0WG50202LLCh809id@P0309ec
@@2OMD<0X7I40080XGM500@0X7I409me@`2MLd40XGI31P2PMD800`2QMT<0XGE40:5eA0060:9fA@09
0:9gA02QMT<0X7E209md@@2PMD80XGI30:=hA@2TNDH0XWI500L0XgM600T0XWI50:5h@P2QN480XGQ4
0:9hAP2RN4P0XWM:0:=hB`2SN4d00`2PNdL209mjAP<0X7]70P2QN4@0102RNDD0XgY60:AkA`2UO4P2
0:ImB@030:=jAP2TNdL0Y7]70080Y7]70`2UO4P01P2YOT/0Z7e:0:QmBP2WO4T0YW]80:EjA`80Y7U6
202WO4T30:IlBP<0Yge;0P2XOT`30:QmBP80ZGi;0`2ZOd`20:QoB`<0ZH1<0`2ZPDd30:V0C080Z7m;
0`2WOTX0202ZPDd0ZH1<0:QoB`2WOTX0Z7m;0:V0C02[PTh0[8=?0`2[PTh30:Z1C@80ZH1<0P2YOU42
0:YoDP80Zh1C0P2/PE@01P2/PEH0[85D0:b1E02/PU80[89@0:b3C`80[8==202/PU030:f3D@030:b2
D02[PDl0ZX1>0080ZX1>202ZQE420:j0CP030:b1CP2[PTh0ZX9>0080Z8=>00@0YhA>0:f4D02]Q500
[HA@0P2^QE440:n6DPP0ZhIA102`Qe<40:n6DP<0[8MC0`2[QU820:Z5D@030:f8E02/Qe<0[8MC0080
ZhIB0`2ZQE4>0:^6DP80[8MC0P2]QeP0102]QeH0[8IE0:b7D`2[QU820:^6D@<0ZHA@0P2XPdl30:N2
CP090:^2CP2ZPDd0Z7m;0:MnBP2VODT0Ygi:0:QoB`2YP4`0XWe800<0XGa70P2PNdH209mjA@080:5l
A`2PNdH0WgY509eh@`2KMT40VWE009Qc?P2GLSd309Ud@080VWE1102KMT80202JMD40V7<o09Mb?P2F
LCd0Ug8n09Qc?`2IM400UFm00P2DKSl03`2CKCh0TV`m095[?02AJc`0T6Xk095]>`2@K3X0T6`l08mZ
?@2>JCd0SFPn08aW?@2<ISl0SVXj08m[>`03091/?00308iZ>P2<J3P0RfLg0080SFPk0P2<IcX408]V
>@<0RF@j0`28HcT208MR>0T0QV4d0P20GS4207mM<0@0OU`_0`1kFc8307YJ<@80NET`00@0NeP^07YG
;@1jEbd0NUL]0P1iER`207QE:`0607MK;01gFRh0MUT]07EH;P1dEbl0LeD_0P1cEC4806mA:`@0Jdh/
101ZCB/00`1WCb/0IThZ06I>:P0406I>:P0706M?:`1YCBH0JDdX06Q;:@1WBRP0ITTY06I9:`0206E7
:`<0HTLZ0P1QART30615:00;05Y29P1UCC40KeLk06eE>@1SBbl0Fd<W05e5:@1RBRh0GdL[05e5:@1K
@bL00P1H@2@00`1I@BD0Fd<W05e5:@0805M49P0605I7:P1FABT0ED@X05I29`1F@BH0EclU0P1G?B@0
1P1C@RH0DT4U0550901@?b<0CchR04dl8080C3/O1@1>?B<304ln90<0CCdS0`1<?28204/k8@80BS/T
1019>R<204Xk9080BCdU1P18?2@204/i8`0304Xj8`18>B80ASXR0080AS`S0P14?B<804Di8@06044m
8P12?280@S`R04<l8P15>b80ASXR1P18>B8204Tj8`80BS/T2019>R<01@18?RD0AcdT04Hl8`15>b80
A3XQ0080@cTP00<0@SPO04Pi8P18>B801P18>B8204Pn9@H0AcdT00P0CclU04hn901=?B<0CCdS04hn
901@@2H0DT8X05A4:P80DD0T0P1B@BD0301C@RH0E4<W05A39`1D@bL0DD0R05918`1C@R@0ED@V05I5
9`1HAbT0FDPZ05Y9:`<0GdL[0`1NARX205e5:@0605e69P1NAbL0GdPX0619:@1QBRX0Hd`/0P1TCBd0
2P1PBBL0HDXX069;:@1TCB/0ITl]06QA;`1YDS00JU<a06]>;01/Cbd306iA;`0;06a?;@1[CR`0JD`Z
06mC;P1`E2l0LED^079F;P1dFBh0MEX]07IK;P1gG2d0101cEbl0101eFC40N5`d07]O=`1mHCT207aM
<@80OEhb00D0OUlc07mP=020HCD0P64e089X=`0208=W=`0308AU=P25ICH0QF<e0080Qf8e2027ICL2
08YZ>@80Rf/j00<0S6`k08e]?02>KSd00P2?Kch8099^?P08091^@02@KSh0TFlo099a?P2CLSd0U7<m
09Ad>`2EMC`809Ue@@0809eiA@2LN4@0VWI209Qd@02IMD40VgM309ijAP2PO4P409mkA`80X7a80P2Q
ODT20:F1C@80YX9>102WPdl20:N4CP80Z8E?0P2YQU020:Z7D@P0ZhQB0P2[Qe<60:b8E080[h]G00<0
/8aH0;6=F@2bSUX00P2cSe/00`2dT5`0/hiJ0;>>FP060;>>FP080;:>GP2dT600]Y9R0;NCH`2hU6@0
]i=S0;JBHP2eTF480;RDI0P0^9AP0P2fU6H20;NEI`80^9IX0P2iUfT30;ZFIP<0^IEU102hU6@30;VE
I@<0^YIV6@2iUFD30;VDI`80^YEX0`2iU6L80;RDI0030;RCIP2iU6L0^IAW0080^IAW1`2jUFP20;VD
I`80^9=V00@0^YIR0;VEH@2iUF40^9AP102gTel80;VEI@80]YAV0`2gUFL30;RFJ0H0^IEU0P2jUVH0
0`2fU6H0]iEW0;NEI`020;NEI`<0^9IX1P2jUVH40;^GI`80^YIV0P2iUFD20;RDI080]I5Q0`2fTV83
0;NCH`80]Y9R1P2gTf<00`2eTF40]Y9R0;NCH`020;RDI0030;NCH`2fTV80]I5Q0080]i=Q0P2fTV02
0;FAG`80]91N202eTF480;B@GP80]Y5T0P2eT6<00`2dSf80/XeP0;6<G`020;2;GP80]I1S102fTF@2
0;F@H`H0]91N0P2eTEl30;>?G`050;B@H02fTV80]i=S0;NCH`2fTV800`2cSEh20;B>G`<0]HmP2`2b
SUh40;>?G`@0]91P0P2cSel30;:>GP<0/heN0P2dSUl30;F?H080]8]M00@0]HaN0;J=G`2fSEl0]hiP
0P2hSf420;:>GP80/HeM0P2`S5`20:n;F`80/HQL00@0/8YM0:n:G@2_RUd0[XaN0P2]SEh20:j9G0<0
[hYM0`2`Reh20:n;F`<0/8aL1P2aSEd30;:>GP80/hmO202`S5`0202cSed0]91N0;FAG`2eTEl0/hmM
0;6=F`2^RUP0[8QF0P2cSed20;:>G080/HeK0P2`S5X80;2<G080[h]K0`2`S5`20;6=G@80/XiN0P2]
SEh0102_SEl0/HaO0;6<G`2bS5l20;>:GPP0/XiN0P2`S5`40;6=G@80/8aL202`SUh@0;6=G@030:j8
E`2`RUT0/XaK0080/heL00@0/H]J0:j8E`2/QUD0[hYE0P2_RUH00`2`RUT0/8YK0;6;GP020;6:G`P0
/8YK0P2aS5P40;2;E`80[hYF00H0ZhMG0:b8F02/R5P0[HUI0:j:FP2_Re/20;2<G0060:n;F`2`S5`0
/8aL0;6=G@2bSUh0/hmO0P2dT600202eSfP0]8mU0;:=H`2`Rel0/8]N0;2<G02aSE/0/XiL0P2`S5`6
0;6=G@<0/8aL0`2_Re/20:j:FP080;6;G02`RU/0[hUJ0:j8F@2]QeP0[8IG0:^5EP2ZQ5D20:f8G003
0:f8F`2]RET0[HUG0080[HUE00<0[HYD0:j9E@2]R5@00P2/Qe<40:^6DPT0[HUI0P2_Re/0102^RUX0
[HUI0:f9F@2/R5P20:^7E`80[hYF0P2^RED20:f8E080[8MC0P2]R5@40:j9E@80[hYF202]RET30:b8
F0<0[HUI0P2^RUX01P2_RUH0[XUE0:j9E@2]R5@0[8MC0:^6DP80ZXEA102_RUH20:j9E@80[HQD202/
Qe<20:^6C`030:^6D@2[QU80ZhED0080ZhEF00<0ZhEH0:Z5D@2ZQE401P2ZQE480:V5E@80ZXE@0`2Y
Q4l30:R3CP030:J2CP2WPdl0ZHEA0080ZhMC00<0ZXIB0:V5D@2XQ500202YQ5030:R3C`<0Yh9>0P2V
PDd40:R3C`@0Yh9>00H0ZHA?0:V4D02XPdl0Yh9>0:J0C`2UOdh20:AnC@030:5nB02ROdT0Y85;0080
YX==00<0YH9<0:B1B`2SP4X02@2YQ5030:N2CP<0YX5=0P2UP4`80:F1C@80YX9B1P2UPE400`2TP500
YH5A0:F1D@020:F1D@<0YX9B00<0YX9>0:F1C@2SOd/00`2QODT00`2ROTX0Xgm;0:5mC@030:5mC@@0
XWi>102VPDd20:F0C0050:AoB`2SOTX0XWi:0:5mB@2ONdL00`2NNTH02P2ONdL0X7a80:F0C02TOd/0
Xgi:0:9mB@2PNdL0WgY609iiA@2MN4@80:5mB@P0Xg]8202ONdL00`2NNDD0WgY60:5lB0030:=nBP0:
0:9mB@2QO4P0VWU409]jA@2ONdL0XGa80:AlB@2TNTP0XgU70:=gAP80WgY60P2PNdL0102NNDD0W7M3
09Ye@@2HLcl209ag@`80WGQ40P2NNDD209mjAP80Wg];00<0WWY:09eiB@2MNDT00`2MNDT209iiA003
09mjA@2PNdH0XGa700<0XWe800<0WWY:09eiB@2LN4P00P2KMdL02P2LN4P0WGU909eiB@2NNTX0XGe3
0:1l@P2ONT<0WWU409eh@`2LMd<209]eA080WGQ400`0WWU509ehA02LMd<0VWE109Mb?P2FLCd0W7Q4
09]g@`2JMT80VGE109Qd@02GLcl209Ib?P0409YfAP2IMDD0VGE509UeA@<0V7A400<0Ug=309Ib@P2E
LD400P2DL400102ELD40Ug=309UeA@2JMTH209QdA00409Mc@`2FLT80UG5109Ea@@80U7100P2GLcl0
102FLSh0UG4m09Ea?@2DL3`209=_>`0409E_@02FL440UW1109I`@@80Ug520P2HLT<209Ea@@0309A`
@02CKcl0TVhn0080TFdm00@0T6`l09=_?`2CKcl0Tflo:oooool002[ooooo0P2NM4801P2LLT00Vg4o
09U_?@2HKS`0Ufdk09I/>P<0Vg130P2LLD@309ebA@P0WW91202MLSl809id@P0309ec@@2OMD<0X7I4
0080XGM500H0X7I409me@`2MLd40XWM40:5f@`2PMD8209md@@030:1e@P2QMT<0XWM40080Wg=20P2P
M4<40:5eA080XGI30`2OM4401P2QMT<0XgQ50:AiAP2QMD@0XWI50:=gAP<0Y7Q700<0XgM60:9fA@2Q
MD@00P2QN4802@2QN4@0XWQ60:9hB02RMdX0XgQ;0:=hC@2QO4P0X7]709mjAP0209iiA@0309mjAP2P
NdL0XGa80080X7M30P2QN4@00`2RNDD0XgY60:AkA`090:AkA`80Yga90`2VNdP30:EjA`P0Yga90`2V
O4X30:MmB`80Z7i<0`2XODP20:UnB@<0ZWm:0P2XOd/30:V0C0<0ZX5=0`2YP4`20:QoB`<0Ygi:00P0
ZX5;0:V0BP2XOdT0Ygi80:QoB@2YP4X0Zh9<0:b3C@<0Zh9>0P2ZPDd30:V0C080ZGiA0P2ZOe820:^0
D`80[85D00H0Zh1E0:^0D`2[P5<0Zh5A0:^1C`2[PTh20:^2C100Zh5?202ZQE420:n1C`030:f2C`2/
Pdl0Zh=?0080ZHA?00<0Z8E?0:b3C@2]Q4h00P2]Q4h30:j5C`80[hI@202[QU40102aR5@0/8MC0;27
D`2`Qe<30:n6DP040:j5D@2/Qe<0[8MC0:b7D`<0ZhIB0P2ZQE400`2^RED0[HQD0:^6DP030:Z5D@X0
ZhIB0P2[QU430:Z5D0040:^6D@2]R5<0[XUD0:f8E0<0[8MC0P2[QU820:Z4D`<0ZXEA0P2YQ5030:R3
C`030:b3C`2ZPDd0ZH1<00<0Ygi:00<0Z7m;0:V0C02SOTT00`2RODP20:5lA`80X7]600P0YH190:Ao
B02RODH0WgY309eh@@2JMCh0VG@m09Qc?0<0VgI21@2JMD40202KMT80VWE109Qc?`2GLSh0UW4m09Mb
?P2HLcl0VGA00`2DKSl209=]?P<0TV`m0P2CKC`00`2BK3d0TF/n091Y?P0208mX?`0908iW@02?Jc/0
T6`l095]?@2BKSh0TFdm091/?02>JSX0SFTi00<0SVTl0P2=J3/308aW>P<0RfHl0P2:IC/308UT>PT0
R6@d0P22H382085O<@80P5h`0P1oGBl307eM=080O5`c0`1kFc8307iI;`80OEP^0`1lEbd01P1iFR/0
N5T[07MH:P1fEb/0MUH]07IF;`80MeLa201aE2`806a@:`0306UA:`1XD2X0IdlY0080IThX00<0IdlY
06Q@:P1YDB/00P1/CRP01`1[CBT0JT`Z06U;:@1XBBX0J4T/06M8:`1VB2`00`1UAb/206A6:P80HdDY
00`0ESlP05e69`1TCBh0Hd`]05a59P1H@B80FD8S05e69`1OAb/0GTHZ05e5:@1LA2P205]39`0305a4
:01MABT0F4DW00L0F4DW00H0ETDW05Q59`1HABL0F4<V05Y29P1J@2D205]09@80E4<U00@0Dd8T0591
8`1A@280DD0R0P1@?b42058n9@<0DclV0`1D@2L304hn9080CCdS0`1<?2800`1>?RL0CCdV04`l9@02
04/k900404`l9@1=?BH0CShW04/o9`<0BShV0`19?BD02018?2@0CcXU04hi901;>B<0BCTR04Pi8P17
>b<0B3`T0P18?RD804Hj8006048n8@13?R40@chQ04@m8@16?240Ac/Q0P19>b401019>B80BSXS04Xj
8`1:>R<204/k9080C3`U201;>b@0101:?R@0BCdS04Tm8`18?28204Lk8@80ASXP201;>b80101:@2D0
BClT04To9019?b@304Pn8`0:04Lm8P1B@BL0DD0V05509P1@?bD0DD0V05=2:01EA2X0EdH/05A18`80
ED8T00/0ET<U05M49P1HABL0F4DW05U6:01F@b<0Ed@T05Q59@1IARH0FTLW05a9:@0205e::PD0HDPZ
0`1RBB/2069::00406=;:@1TC2X0I4`Z06E=:`80ITh/0P1TC2P02@1UCBT0Idl[06Q@;01YDBd0JU8^
06]C;`1]Cb/0KU0/071B;P02075C;`03071B;P1_DBd0KU0/0080LU@^00L0LeH^07AG;@1fFBd0Me//
07QL;@1iGBd0Me`a00<0MU/`00D0Me`a07YO=01lHCH0OV<h07eN<P0207iO<`0307mP=020HCD0PF8f
0080PV<g00H0PfLg08EV=`25ISL0QVHg08MU=`29I3L208]U>00308IT=P27ICL0QfDg0080R6Hh0`29
IcT308]]>`0408a^?02=Kcd0SW0n08ma?`80T790202CKcl0202AKd40TFlo099`@02CLSl0U7<n09Ed
?P2EMC`0UWHm202KMd<0202LN4@0VgM309]g@`2KMd<0W7Q409eiA@2ONdL0X7a80`2PODL20:5nB0<0
XWm90`2UPDd20:J2CP<0Yh=?0P2VPdd20:N4CP040:R5C`2YQU00ZXMA0:Z7D@P0[8QD0P2[Qe<30:b8
E0<0[HUE00H0[XYF0:n;E`2_ReL0/8aH0;6=F@2bSUX20;>?F`040;F@G02dSe/0]8mK0;B?F`<0/hiJ
00T0/XeI0;:>GP2dT600]Y9R0;NCH`2hU6@0]i=S0;JBHP2eTF40202iU6L80;VEH@<0]iEW0P2hUVP3
0;VGJ@<0^YIV0`2iUFD40;RDI0<0^IEU0`2jUVH80;VEI@030;NCH`2hU6@0^9AT0080^9AT0`2iUFD0
0`2jUVH0^IEU0;VEI@060;VEI@030;RCIP2iU6L0^YEX0080^iIY00<0^YEX0;VDI`2hTfH0202hU6@9
0;VDI`80^YEX00D0^iIY0;ZEJ02iU6L0^9=V0;NBI@020;ZFHP030;RDH02gTel0]Y9N0080]i=O00<0
^9AP0;VEI@2iUFD01P2iUFD20;JDIP<0]iEW0`2hUVP20;RDI0<0^IEU0`2jUVH80;NEI`<0^IEU0`2j
UVH50;^GI`80^YIV0`2iUFD20;JBHP<0]i=S0`2hU6@30;JBHP<0]i=S0P2hU6@00`2dT600]I5Q0;NC
H`020;RDI0040;NCH`2eTF40]91P0;RDI080]i=S00D0]Y9R0;FAH@2dT600]91P0;>?G`080;JBHP04
0;:>FP2cSe/0/hmK0;>?F`<0]91L00<0]I5M0;B?HP2dSf800P2dSf820;>>H@<0/XeP00<0]8mR0;F@
H`2fTF@00P2gTVD00`2fTF@0]I1S0;B?HP020;>?F`<0]91L0`2eTEd0202eTF40/XiN0;6=G@2bSUh0
]I5Q0;NCH`2eTF40/hmO0`2cSEh20;B>G`<0]HmP202cSel80;:>GP<0]91P0P2cSel30;:>GP<0/heP
0P2dSV430;F?HP<0]X]N0P2gS5l30;R=H080/XiN0P2aSEd20;2<G080[h]K0P2aR5X0102`RU/0[h]K
0:n;F`2^S5`20:f=G080[XUL0`2_RUd30;2;GP<0[h]K0P2`S5`60;6=G@<0/XiN0P2cSel80;2<G008
0;6=F@2bSUX0]91L0;FAG@2dT5`0/XiJ0:n;E`2]RED30;:>FP80/HeI0`2`S5P80;2<G080[h]K0`2`
S5`20;6=G@80/XiN00<0[8aM0:f=GP2_SEl00P2bSF000`2bS5l0/hYN0;:9G@080;6=G@030:n;F`2`
S5`0/HeM0080/XiN00<0/HeM0;2<G02_Re/0202`SUh@0;6=G@090;2:F`2aRe`0/H]L0;:<G@2aRe`0
/8YK0:n9FP2^R5T0[XUD0080[hYF00<0[hUH0;2:F`2`RUd00P2aRUl80;2:F`D0/8]G0`2_RUH20:^7
E`030:b8F02]RET0[XYJ0080[h]K00@0/8aL0;6=G@2aSEd0/HeM0`2bSUh20;>?G`080;F?J02dSfD0
/XeS0;2;G`2`Reh0/8aL0;6=F`2bSU`20;2<G0<0/HeM0`2bSUh30;2<G0<0[h]K0P2^RUX20:n9FP04
0:j8F@2]QeP0[HMH0:b6E`80ZhEF0P2]R5`00`2]R5/0[HUI0:f9E`020:f9E@060:f:E02_RUH0[hYF
0:f8E02/Qe<0ZhIB0P2/Qe<00`2]R5@0[HUI0:f9F@0<0:f9F@<0[XYJ0`2^RED20:f8E0<0[8MC1@2^
RED30:n:EP/0[8QH0`2]RET20:j:FP80[XUE00<0[HQD0:b7D`2[QU800P2ZQE40102YQ500[XUE0:j9
E@2^RED30:f8E0X0[8MC0P2[QTl00`2[QU40ZhIB0:^5E0020:^5EP030:^5F02YQ500ZHA@00H0ZHA@
202XQ5@20:Z5D0<0ZHA?0`2XPdh00`2VPTh0Yh=?0:V5D@020:^7D`030:Z6DP2YQE40Z8A@00P0ZHA@
0`2XPdl20:N2CP<0YX5=102XPdl40:N2CP80ZHA=00@0Z8=>0:N2CP2VP4l0YX1A0P2UOe800`2QOTP0
XWm90:B1B`020:J3C@030:F2C02TPD/0Xh1:00T0Z8=?0`2WPTh30:J1C@80YH1<202UPDd30:J2DP<0
YH5A0P2TP5080:F1D@030:J2CP2UPDd0Xgm;00<0XGe900<0XWi:0:=oB`2QNd`00`2RO4d30:=mCP03
0:AnC`2UP4`0YH1<0080YX5=00D0YH1<0:=nBP2QO4P0X7]70:5mB@070:1lB0080:AoB`2SOTX0XWe9
0:5lB02PNdL0WgY609iiA@2MN4@80:5mB@80YG]91P2TNTP809ijAP0609ehA02ONTH0XGa80:=nBP2T
Od/0Xgi:0P2RODT02P2JND@0VgY509mkA`2QO4P0Xg]80:=iA`2RN4H0XWI509ehA02NNDD209mjAP04
09iiA@2LMd<0VWE109Ud@080W7M30P2MN4@209iiA@80WgY600<0X7a<09mkB`2MNDT00`2LN4P209ei
B@0509ag@02MN440X7]40:9mAP2SOTL00`2TOdP00`2NNTX0WGU909ahB00209]gA`0409ahB02MNDT0
WGU909ijBP80Wg]100@0WgY309iiA02NND@0WWU50P2MMdH0202KMT80W7M309ehA02MN4@0W7M309]f
@P2HLcl0Ug8n0P2LN4@01P2KMd<0VGE109Qd@02GLcl0UW8n09Ea?@P0V7A400P0Ug9509IaA02EL4<0
U6m209E`@`2FLD@0V7=609UdA`80UW920`2ELD4309A`@0<0UW8n0P2ELCd309A`?080U6ho0P2EKd02
09I`@@80Ug5200H0UW9209Ea@@2ELD40U71009=_?`2BKSh2095]?@<0Tflo:oooool002[ooooo0`2L
LT0409]a?`0309Y`?P2KL4<0Vg130080Vg130P2LLD@209ebA@80WG501P2NLT4809md@@P0WWA200<0
WG=109me@`2PMT@00P2QMdD01P2PMT@0WgE309ec@@2RMd@0XGI309md@@80WW=000<0WgA10:5f@`2R
Md@00P2MLD0209ib@@80Wg=20P2PM4<02`2QMT<0X7E209md@@2NLd00WgA10:1e@P2RMd@0XgQ50:5e
A02RMTD0Y7Q700<0YGU800<0Y7Q70:9fA@2QMD@00P2QN4802@2QN4@0XWQ60:9hB02RMdX0XgQ;0:=h
C@2QO4P0X7]709iiA@0209ehA00309iiA@2PNdL0XGa80080WgI2102PMd<20:5hA080YGa81P2TNdL4
0:EjA`@0YW]8202WO4T30:IlBP<0Yge;0P2XOT`30:QmAP80ZGi70`2ZOdP20:QoB`<0ZH1<0`2ZPDd3
0:V0C080Z7m;0`2WOTX02@2ZPDT0ZH180:QoA`2WOTH0Z7m70:V0B02[PTX0[8=;0:^2CP030:Z1C@80
ZH1<0P2XOd/20:UnD@80ZWmB0P2[P5<20:b1E0060:^0E@2[P5<0Zh1C0:^1D@2[PDl0Zh9>0P2[PT`8
0:^1C`060:QnC02YOdd0ZGm=0:Z0CP2[PDl0[89@0P2]Pe480:Z5D@80/H=A00<0[hAA0:j5D@2]QE40
0P2[QU400`2ZQe40[8=;0:b3B`030:f4C0@0[XE=202[QU420;68E080/8MC0P2_QU820:j5D@<0[8MC
0`2[QU820:Z5D@080:j9E@2]R5@0ZhIB0:Z5D@2YQ500ZXEA0:^6DP2/Qe<80:^6DP080:b7D02[QTl0
ZXE>0:V4C@2ZQDh0ZhI?0:f8D@2_RU<20:^6D@80ZhIB0P2ZQ5<20:V3E080ZhIB0P2ZQE430:V4D004
0:R3C`2/Pdl0Zh9>0:V0C080Ygi:00<0Z7m;0:V0C02ZPDd00`2SOTT20:9mB0<0XGa700D0Y8160:=o
A@2ROT@0XGe30:1l@P0209ij@00509ei?`2MN4@0WGQ409ag@`2KMT800P2JMD4209Ud@00809Ye@@2I
M400Ug8n09Ia?@2EL3`0UW4m09Mb?P2HLcl309A^?`D0Tfdn0P2FKSd00`2EK3h0U6/o09=Y?`02099X
@009095W@@2@K3`0TFdm099^?P2CKcl0TVhn095]?@2?Jc/0SVXj00<0SfXm0P2>JC`308eX>`0408eX
?P2<Icd0S6Lm08aW?@80RfHl0P2:IC/908UU<`<0Pf4a0P22H303085O;`0407mO=P1nGSD0OUhe07iN
=@80OEdd0P1lG3<3081I;P80OeP]0`1nEb`0201iFBX0N5PY07IE:01eE2T0MUD/07ME;`1iEc40NUPc
201cERh206a@:@H0KE4Z00<0Je@[06UB:@1XDBP00P1WD2L0301XDBP0JE8Y06]D:`1`D2T0KdlX06m?
:@1^CBX0KD`[06a;;01[BR/0JdT]06M9;@<0ITP/0P1UAb/206A6:P0305a59@1MARH0GdPX0080GdPX
00<0GTLW05m8:01PBBT00P1NARX305m7:`0305e5:@1LA2P0Fd<W00P0F4DW0P1GA2@00`1H@b@0Fd@U
05a39@0205i39P0306129P1EAB@0EDDT00H0E4@S00<0ED0U05I19P1F@BH00P1G@RL00`1H@bP0FD@Y
05U4:@0304m08`80CSlR0`1=?R400`1@@2T0CclX04hn9`0204dm9P0304hn9`1??bP0D40Y00<0C40X
00<0BclW04Xn9P1:?RH00P19?BD01`1A>bH0CcXU04hi901:>280BCTR04Xk9019?BD00P1:?RH804Ll
800604=08@14?b40A3lQ04Dn8@17?R40B3dQ0P1:?24204Xj8`80Bc/T0`1<?2D00`1=?BH0C3`U04`l
9@0604`l9@<0C3hS101;?B800`1:?240C3`R04`l8P0604`l8P<0Bd8U00<0BT4T04U08`19@2<00P18
?b80201F@RL0ED4V05A09@1D@2D0ED4V05M3:01IABX0FdL/0P1F@B801P1G@R<0F4<T05U49@1JABH0
FdHW05a7:080FdLV0P1LB2L205e9:080GTXY0P1RAbT0101SB2X0I4T[06E:;01UBR`206I;;@80IT`[
1P1WCB`206M=:080J4hY0P1YCbX206Y@:`0306m?:@1aDB/0Le<]00<0MED_0`1dE2h01`1dE2d0MED^
07MG;P1hFBd0NEX/07YK;01kG2d00P1jGc801P1iGS40N5d`07UN<@1jGc80O64d07eR=@80Of0d00<0
P64e085R=P22HcL00P23I3P01P24ICT0Q6Df08EV=`26ISL0R6Hh08]V>@80SFLj00T0T6Lk08ES=@26
I3H0QfDg08QV>029IcT0RVPj08]Y>`2<JS`00P2<KS`208e_?@0308i`?P2?LCl0T7900080TG=1202D
L4001P2AKd40TW10099`@02CLSl0U7<n09Ed?P80UWHm202LN4@0102IMD40VWI209ahA02NNTH409mk
A`<0XGi60P2ROdL30:>0B080Y81<0P2UPDd30:J2CP090:N3C`2TPD/0Y85;0:F2C02VPdd0YhA>0:R5
C`2YQU00ZXMA00P0[8QF0P2[Qe<20:b8E080[HUE0P2^RUH20:f9E@040:j:EP2_ReL0/8aH0;6=F@80
/XiJ0`2eT5`00`2dSe/0/hiJ0;>>FP020;:=F@080;:>GP2dT600]Y9R0;NCH`2hU6@0]i=S0;JBHP2e
TF480;VDJ0P0^IEQ0P2gUFL20;RFJ0@0^IMY0`2jUVH30;VEI@@0^9AT0`2iUFD30;ZFIPP0^IEU102g
Tf<00`2hU6@0^IEU0;VEI@020;ZFIPP0^IEU00<0]i9U0;RCIP2jUFP00P2kUVT00`2jUFP0^9=V0;NB
I@080;RDI080^YEX202iU6L30;^FJ@060;VDI`2gTVD0]Y5T0;^GH`2jUV80^9AP0P2fTUh00`2gTel0
^9AP0;VEH@080;VEI@80]YAV0`2gUFL30;RFJ0<0^9AT00<0^IEU0;ZFIP2jUVH00P2kUfL20;RFJ0H0
]iEW0P2hU6@20;VEI@80^YIV1P2kUfL20;ZFIP80^IEU0`2hU6@30;VEI@80^YIV0P2eTF420;JBHP07
0;NCH`2hU6@0^9AT0;RDI02dT600]I5Q0;JBHP020;RDI0030;JBHP2eTF40]91P0080^9AT00@0]i=S
0;JBHP2eTF40]91P0P2cSel80;RDI0<0/XiJ00<0/hmK0;B@G02dT5`00P2eTEd40;:=H080/hiQ102d
Sf801`2eT6<0]Y5T0;NBI@2gTVD0]Y5T0;F@H`2dSf800`2cSe/00`2dT5`0]I5M0;FAG@020;JBGP08
0;JBHP2bSUh0[h]K0;2<G02dT600]I5Q0;:>GP2^RUX30;>=GP80]8iO0`2eSf080;B@H0P0/XiN0`2d
T6020;>?G`<0/XiN0`2cS6420;B=HP<0]HiS0`2hSF020;N<G`<0]X]N0P2bSUh20;6=G@80/8aL0P2_
Re/20;69F0040;2:F@2_ReT0[h]I0:j=FP80[HeJ0P2^RE`30:n:G@<0/8]N0P2^RUX20:n;F`<0/8aL
102aSEd30;:>GP80/hmO202_Re/0202^RUH0/8aH0;>?F`2fTUh0]I5M0;>?F`2`S5P0[XYF0P2bSUX2
0;6=F@@0/8aH2P2_Re/30;2<G080/HeM0P2bSUh00`2/S5d0[HeN0:n=G`020;:=H0030;:<G`2cRUh0
/XUM00T0[h]K00L0/8aL0;6=G@2bSUh0/XiN0;6=G@2`S5`0[h]K00P0/8iN402aSEd00`2cSEh0/XaM
0;2:F`030:n9FP80/8YK00H0[XUD0:j9E@2_RUH0[hUH0:n9FP2`RUd20;29GPP0/8YK1P2_RUH20;2;
E`80ZhMG0P2/R5P0102]RET0[XYJ0:n;F`2_Re/20;>?G`<0/XiN0`2aSEd0202eSfP0]8mU0;:=H`2`
Rel0/8]N0;2<G02aSE/0/XiL0P2`S5`20;6=G@80/XiN0P2cSel30;2<G0<0[h]K0P2^RUX60:f7F080
[8IG0P2]R5`00`2]R5/0[HUI0:f9E`020:f9E@090:f:E02bSET0/8]G0:j9E@2]R5@0[8MC0:f8E02^
RED0[hYF00T0[XYJ00H0ZhMG0:b8F02/R5P0[HUI0:j:FP2_Re/20;2<G080[XUE0P2]R5@40:b7D`H0
[hYF0P2^RED;0:b8F0<0[HUI0P2^RUX20:j9E@040:f8E02/Qe<0ZhIB0:Z5D@80ZHA@0P2]R5@30:b7
D`<0ZhIB202/Qe<20:Z5CP030:Z5D02ZQE40ZXAC0080ZXAE00<0ZXAG0:V4D02YQ5001P2YQ5080:R4
E080ZXE@0`2YQ4l30:R3CP030:J2CP2WPdl0ZHEA0080ZhMC00<0ZXIB0:V5D@2XQ500202YQ500102X
Pdl0Yh9>0:N2CP2WPTh20:J1C@80YH1<102WPTh40:R3C`060:Z6C02YQD/0ZHA=0:R3C`2WPE00YX1C
0P2UOU<00`2QOTP0XWm90:B1B`020:J3C@030:F2C02TPD/0Xh1:00`0Yh9>0`2VPDd20:F0C0P0YH5=
0P2WPe<20:J2DP040:F1D@2TP500Y81@0:B0D080YX9B1P2UPE400`2VPTh0YH5=0:=oB`030:5mB@04
0:9nBP2SOd/0XgY<0:=jC080Y7]=0P2UO4h20:ImC`080:=nBP2TOd/0Y7m;0:AoB`2SOTX0XGa809mj
AP2MN4@50:5mB@<0XWi:0P2RODT20:5lB0040:1kA`2ONTH0WgY609iiA@P0X7a80P2VO4X20:EkB@04
0:AjB02SNDL0XgU70:=iA`P0WWY600@0WGQ409iiA@2PNdL0XWe90P2TOd/03@2SOTX0XWe909]jA@2L
NdH0Wg]70:5lB02SNdP0XWQ60:5gA@2QMD@0VgI209ag@`2MN4@00P2NNDD00`2MN4@0W7M309Ye@@02
09ag@`80WGQ40P2NNDD209mjAP030:1lC02ONd/0WGU900<0VgM700D0W7Q809eiB@2ONd40XGe30:9n
A0020:B0AP060:=oA@2ROT@0XGe309ijBP2MNDT0W7Q80P2KMdL0102LN4P0WGU909eiB@2NNTX209ei
?`0409ii@P2NND@0WgY509mjAP80X7Y900<0VGA009Ye@@2LMd<00P2MN4@02@2LMd<0VWE109Ud@02M
NDD0W7Q409]g@`2JMT80V7A009Ib?P0209Ea?@<0UW9200<0Ug=309QdA02IMDD00P2JMTH0202IM4P0
V7=709IaA@2EL4@0U6m309E`A02FLDD0Ug960P2CKcl309A`@0<0UG510P2FLSh409Ea?@80U70l0`2C
KCh209A^?`<0UFm00P2FLT80102ELD40U71009=_?`2BKSh2095]?@<0U710:oooool002[ooooo0P2I
Kcd01`2JL3h0Vg4o09ec@@2NM480WgE30:1fA02JKd800`2KL4<209aaA080WG950`2MLD0509ib@@P0
X7E2202NM4800`2MLd40WgE30:1fA0020:5gA@060:1fA02OMD<0WG=10:9gA02QMT<0WgA10P2NLd00
102OM440XGI30:9gA02KKch209a`?`0309ea@02NLT40WW910080Wg=200/0XGI30:1e@P2OM440WW=0
09md@@2PMD80XWM40:=hA@2QMD@0XWI50:AhA`030:EiB0030:AhA`2RMTD0XGE40080XGQ200T0XGQ4
0:9hAP2RN4P0XWM:0:=hB`2SN4d0XGa80:1kA`2NNDD00P2MN4@00`2NNDD0X7]70:5lB00609mf@P80
WWE10`2UO4P50:AkA`80XgQ500<0Y7U60:EjA`2VNdP00P2WO4T00`2XODX0Yga90:MlB@060:MlB@<0
YWa:0`2WOD/20:QnC0<0Z7e60P2YOTL30:YoB080Z7m;0`2YP4`30:Z1C@<0ZH1<0P2XOd/30:MnBP08
0:Z1B@2YP4P0Z7m70:MnAP2XOdL0ZH180:^2BP2/Pd/40:Z1C@80ZH1<0P2XOd/20:UnD@80ZWmB0P2[
P5<20:b1E0060:^0E@2[P5<0Zh1C0:^1D@2[PDl0Zh9>0P2[PT`80:^1C`080:IlBP2WOD/0Z7i<0:Z0
CP2[PDl0[H=A0:j4DP2_QE<80:Z5D@80/XAB00<0/8EB0:n6DP2^QU800P2/Qe80102[R580[8=;0:b3
B`2/Pd/20:f4C0@0[XE=202[QU430;68E0030;27D`2_QU80[XEA0080[XEA0`2/Qe<30:^6DP80ZXEA
00<0[hYF0:f8E02[QU800P2YQ5000`2ZQE40ZhIB0:b7D`080:^6DP030:b7D02[QTl0ZHA=0080ZHA=
00@0ZhI?0:j9DP2_RU<0ZhI?0P2ZQE000`2ZQE40ZH=B0:V3E0020:R2D`<0ZhIB0P2ZQE430:V4D009
0:b3C`2[PTh0ZH1<0:QoB`2WOTX0Z7m;0:V0C02ZPDd0Y7m:00<0Xgi90P2RODP20:5lA`<0XGe30`2R
OT@20:=oA@80WWU500@0WGQ409ag@`2JMD40VGA00P2HLcl00`2JMD40V7<o09Mb?P0309E`?00309Ia
?@2GLSh0U6ho00<0U6ho102CKCh0202GKch0UVhm09I]?`2EK400U6Y009=Y@@2BJ400TVQ20P2AKCd3
09=_?`03095]?@2?Jc/0SVXj0080T6/n0P2?JSd308iY?00408eX>`2=J3h0SFPn08eX?P80S6Lm0`2;
IS`908YV=080Q68b0P23HC43089P<004085O;`1oGcH0Oelf07mO=P80OUhe0`1mGC@01021Fbh0P5X]
081J;@20FRd207mI;080OUP[00P0MeLV07IF9`1eEBH0M5<V07ED:@1gERd0NUPb07aJ=0P0LeH/101]
DBX406iB:`0306]D:`1ZDbX0J54X0080Ie0W00<0J54X06YC:P1[E2/00P1`D2T01P1_CbT0KThX06e<
:@1/BbX0K4//06]::`<0J4T]0P1WB2`306I7:`0506M@<01TCBd0Hd`/06A=;@1WD3000P1ZDc<0101Y
DS80G4@X05i6:P1PB2`20659;@0305m7:`1LA2P0FT8V00P0FDHX00P0ET<S05M28`1H@b@0Fd@U05e4
9P1OA2L0HT@X06=5:@<0EDDT0P1FARD305M79P80Ed8U00@0F4<V05U49`1IA2L0FTDX0P1KART304m0
8@80CSlP0`1=?Ql00`1C@B/0DT0Z050n:00204lm9`03050n:01B@2X0Dd4[0080CD4Y0P1<@2P02`1;
?bL0BShV04Xn9P19?BD0DS`W054k9P1>>B@0BSPR04Ti8P1:>b@0C3dV0080BclW2017?2001P14@B80
AD0R04E08P16?b80B3lR04Tn8P80BcdR00@0BcTS04`j901<>R@0C3XT0P1=>bD:04hl9P0304/m8P1<
?R<0C3hS00D0C3hS201>?B<204a39P80Bd8U00H0BT4T04U08`19@2<0B3lR05M49P1F@bD205E2900<
05I39@1HABL0FTLY05a9:`1F@B80Ed8S05Q3901IA2D0FTDV05]69`1LAbP0GDPY201MBBP20697:@07
06=8:P1TBB/0IT/]06M<;P1XCBl0JDh`06U?;00306Q>:`@0IddZ201XCRT0101_CbT0L50Z07=C;@1e
EBl207MG<@80MUH`0P1dE2d02@1eEB`0MeP/07QI:`1iFR/0NU//07]M:`1mHSD0O64d07YO<P0207UN
<@0407YO<P1lHC@0OF8e07mP=080P64e00<0PF8f089S=`23I3P00P24ICT01P23I3D0QFDf08IV=`28
ISP0S6Lj08iX>`80TFPl00P0Q68d08ES=@26I3H0R6Hh08YX>P2<JS`0SF/m08i/?P80Rflm0P2<L3h0
0`2=LCl0SW9008mc@@02091d@PP0UG5100P0TW12099`@02CLD40U7=009Ed?`2FMCl0UWHm09Mg?PP0
W7Q400@0V7A009Yf@P2MNDD0X7a80P2QODT00`2ONdL0WWY60:5nAP030:9oA`80Xh180P2TPDT0102S
Od/0Y81<0:B0C02TP4`20:F1C@80YX9>0P2SP4X0102TPD/0YH9<0:N4CP2XQDl20:V6D0P0[HUG0P2[
Qe<20:b8E0050:f9E@2^RUH0[XYF0:n;E`2/R5@00P2]RED00`2^RUH0[h]G0;2<F0020;6=F@80]Y5M
00@0]I1L0;B?F`2dSe/0/hiJ0P2bSET0202bSUh0]91P0;JBHP2gTf<0^9AT0;NCH`2fTV80]I5Q202i
U6P80;VEH@80]iEW0P2hUVP30;VGJ@040;ZHJP2jUVH0^YIV0;ZFIP<0^IEU102hU6@30;VEI@<0^YIV
202iUFD30;JBHP040;NCH`2hU6@0^9AT0;VEI@80^YIV202iUFD00`2gTVD0^9=V0;ZEJ0020;^FJ@03
0;ZEJ02hTfH0]i9U00P0^9AT0`2jUFP50;VDI`0;0;RCIP2iU6L0^iIY0;bGJP2kUVT0^IAW0;NBI@2f
TF@0^iMS0;ZFHP2hU6000`2fTUh00`2hU600^IEQ0;VEI@070;VEI@80]YAV0`2gUFL30;RFJ0040;NC
H`2hU6@0^9AT0;VEI@80^YIV0P2kUfL30;RFJ0D0]iEW00@0]i=S0;RDI02hU6@0^IEU0P2jUVH20;^G
I`040;bHJ02kUfL0^iMW0;^GI`80^YIV1@2iUFD30;ZFIP80^iMW0P2eTF420;JBHP070;NCH`2hU6@0
^9AT0;VEI@2dT600]I5Q0;JBHP020;NCH`0;0;JBHP2eTF40]91P0;VDI`2hTfH0]i9U0;JAI02eT6<0
]8mR0;>>H@2bSF00202iUFD20;6>F0040;:?F@2cT5X0/i1J0;BAF`80]I9L0P2`Reh20;6<G`030;:=
H02dSf80]I1S0080]Y5T00<0/hiQ0;F@H`2fTF@00P2hTfH0102fTF@0]I1S0;>>H@2bSeT20;>@FP03
0;BAF`2eTU`0]I9L0080]Y=M00P0]i=S0;:>GP2^RUX0[h]K0;>?G`2dT600/8aL0:b8F0<0/heN0P2d
SUl30;F?H0P0]I5Q1@2bSUh30;6=G@<0]91P0P2cSel30;:>GP<0/haQ0P2dSF830;F>H`80^XiQ00@0
^HeP0;R<G`2hS5l0]h]N0P2fRUd20;:>GP80/HeM0P2`S5`20:n;F`80/HUH00@0/8YI0:n;F@2_ReT0
[XeJ0P2]SEX20:j9G0<0[hYM0`2`Reh20:j:FP80[h]K102`S5`30;6=G@<0/XiN0P2cSel80:n;F`03
0:f:E02_S5H0/i1J0080]Y=M00<0]95K0;6>F02_S5H00P2bSeT20;6>F0<0/8eG00<0[haF0:n;F`2_
Re/0202_Re/30;2<G080/HeM0P2bSUh00`2[Re`0[HeN0:n=G`020;>>H@030;:<G`2cRUh0/HQL00T0
[XYJ00L0/8aL0;6=G@2cSel0/hmO0;6=G@2`S5`0[XYJ00P0/8iN402aSEd02@2dSV40/heP0;2:G@2^
R5/0[HMJ0:j8F`2`RUd0/XaO0:j9E0020:j9E@030:n9F02_REX0/8YM0080/8UN202`RU/20:j9E@@0
[hYF0P2`ReL01P2ZQUH0ZhMG0:^7E`2/R5P0[HUI0:j:FP80[h]K0P2dT6000`2cSel0/XiN0;6=G@02
0;2<G0090:n;F`2eSfP0]8mU0;:=H`2`Rel0/8]N0;2<G02aSE/0/XiL0080/8aL0P2aSEd0102bSUh0
/hmO0;>?G`2dT6030;2<G0<0[h]K0P2^RUX0102[QEH0[8IG0:b6E`2/QUL30:f7F0060:j8F@2]R5`0
[HQL0:f8F`2]RET0[HUG0P2]RED02@2]RU@0/hiJ0;6<F02_RUH0[XUE0:f8E02^RED0[hYF0;6<F009
0:j:FP80ZXIF00@0[8QH0:f9F@2_Re/0/8aL0P2bSUh20:j9E@80[HQD0`2/Qe<00`2[QU80/8]G0;2;
E`040:n:EP80[XUE2`2/R5P30:f9F@80[XYJ00H0[XUE0:f8E02]R5@0[8MC0:^6DP2ZQE420:V4D080
[8MC0P2[QU840:Z5D@P0[8MC0P2ZQDh00`2ZQE00ZXEA0:Z4D`020:Z4E@030:Z4E`2YQ500ZHA@00H0
ZHA@202XQ5@20:Z5D0<0ZHA?0`2XPdh00`2VPTh0Yh=?0:V5D@020:^7D`030:Z6DP2YQE40Z8A@00P0
ZHA@102WPTh20:J1C@80YH1<102WPTh40:R3C`0;0:Z6BP2ZQT`0ZHA=0:R3CP2WPE00YX1C0:EnD`2U
OUD0XGi80:9oB@2TPD/00P2VPdd00`2UPT`0Y85;0:>0BP090:J1C@<0Yh9>0`2VPDd20:F0C0P0YH5=
0P2WPe<20:J2DP040:F1D@2TP500Y81@0:=oC`<0YX9B1@2UPE400`2VPTh0YH5=0:=oB`030:5mB@03
0:9nBP2SOd/0XgY<0080XgY<00<0Y7]=0:ElCP2VODl00P2VODl20:9mB@060:=nBP2TOd/0XWe90:1k
A`2MN4@0VgI20P2QODT20:9nBP80Xgm;0P2ROTX30:5lB0<0X7]70P2ONTH80:1lB080Z7a;00H0Yg]:
0:IjB@2UNDP0Y7Q70:=gAP2RMTD809ijAP0409ag@`2NNDD0X7]70:9mB@80Y7m;0P2SOTX02`2KNTD0
W7]609mkA`2QO4P0XWY70:9hAP2PMT@0X7A309Ud@02KMT80W7M300<0WWU5102LMd<209ehA080WWU5
0P2ONTH0202PO4`0WWY:09ahB02KMdL0VWI609]gA`2LN4P0WWY:0P2TP4H20:F1A`070:B0AP2QOD<0
Wg]109ei?`2NNTX0WGU909ahB00209]gA`0409ahB02MNDT0WGU909ijBP80W7Pn00T0WGQ109iiA02O
NTD0X7]70:5kBP2RO4/0V7<o09Ud@02KMT800P2MN4@05`2LMd<0VgI209Ye@@2MNDD0W7Q409]g@`2J
MT80V7A009Ib?P2ELCd0U70l09A`@02ELD40UW9209Mc@`2HM4@0VGE509YfAP2KMdL0VWE909UdB02G
LTH0UG140080U6m300@0UG1409IaA@2BKSh0TVhn0P2CKcl01@2DL400UG5109Ib@P2FLT80UW8n00H0
UG4m00@0U70l099/?@2BK3d0TV`m0P2CKCh309A^?`80UW9200<0UG5109A`@02CKcl00P2BKSh0102A
KCd0U71009A`@02DL40[ooooo`00:_ooool00`2MLTD0W75409Y_@P0209Q]@00509U^@@2KL4<0W754
09ib@@2MLD000`2LL3l00`2NLT40Wg=20:5eA00209ec@@80W7900P2KLCl209Y`?P0609U/@P2JKT40
WG540:1dA@2QMD@0XGI30P2PMD0809ec@@80Wg=20`2PM4<30:5eA080WW=0102OM4420:1e@P0@09]a
?`2LLT00WWA20:1fA02QMdD0X7I409id@P2MLd40Vg4o09ec@@2OMD<0XGM50:9hAP2QMdD0X7I409me
@`80XWQ800D0XWQ60:=jAP2SNTH0XgY60:AkA@020:Ak@`060:EkB@2TNTP0Y7Y80:9hAP2QMdD0X7I4
0P2OMD<01P2TNTP0XgU70:9hAP2PMT@0WWA209ec@@80Vg4o00H0W7Q409ehA02MN4@0WgM40:1fA02Q
MD@20:=eA0030:IjB@2TN4L0XWI50080XGE400L0XWI50:AhA`2VNTT0Ygi:0:ImB@2UO4P0Y7]700@0
XgY6202UO4P00`2RN4H0Y7Y80:IlBP020:QnC0030:MmB`2VO4X0Y7Y800P0Ygi:0P2XOd/30:V0C0<0
ZX5=00P0Ygi80:QoB@2XOd/0Z7i<0:UoC`2YOU40ZWmB0:YoE080Z7i>00@0ZGm=0:V0C02YP4`0ZX5;
0P2ZPDT80:Z1B`030:QnC02ZP4h0Zh5?0080[H=A00<0Zh5?0:Z0CP2XOT`00P2YOdd20:Z0CP80Zh5?
0P2/PU001P2XOd/0ZH1<0:Z1C@2[PTh0[8=?0:j5D@80[hIB102[PTX20:b3B`80[HA<00<0Yh9>0:R3
C`2YQ5000P2[QU800`2YQ500Z8=?0:N2CP030:^2CP<0[8=?0P2]Q5030:V4C`80ZXE@102[QU420:^6
C`030:^6D@2[QU80ZhED0080ZhEF00@0ZhEH0:V4C`2YQ4l0ZHA?0P2ZQE030:^6D@P0[HQD202_QE<3
0:b3C`80[HA@0`2^QE40202YQ4l0ZXE@0:^6D@2/Qe80[HQC0:j9E02_RUD0/8]F0P2_QU80102^QE40
[HA@0:f4D02/Pdl20:^2CPP0[HA@00H0[8II0:^5EP2[QEH0ZH=B0:R3C`2WPTd20:J1BPP0YH1<00H0
Xgm50:9nA02RODH0XWe80:5lA`2QO4P20:1jB@0609iiA@2MN4@0W7M309ag@`2KMT80VWE10P2IM403
09Ye@@80VGA00`2HLcl209Mb>`0309Mb?@2FLCd0UW0o0080UFm000@0UFm209Mb?P2EL3`0U6lk0`2B
KCT01`2CKSX0U6lk09I`@@2FL440UFm009A^?`2CKCh00P2BK3d0102AJc`0SfTj08mY>P2?JCX4091Z
>`04095[?02@JS/0T6Xk091Z>`80SfTj0`2>J3T408US?0D0R68k0P27HC`01025GcX0Q5hi089L=`21
FcH207mI=0P0P5de00P0OUT_07mJ<020Fc40PE`b081K<@1oFS00OEP^07aG;@P0OELb00X0MeLa07QH
<P1iFC<0NUXd07UI<`1fES00M5@^079B;01fES00MED_0P1dE2h0301cDbd0LU8/075A:`1aDB/0M5L_
07=F;P1`Db/0KU4Y06e@:01^DBT0Ke8Z071C:`P0Jdh^01H0KDl[06a>:P1ZC2P0J4XV06M99@1XBRH0
JD/W06Y<:01ZBb`0JDX[06Q9:P1WB2T0J4TZ06Y;;01/CBh0KTl`06U;<@1XBS00IdT_06I8;P1UAbd0
HdD[0P1RA2X805i4:@030694:P1Q@bT0Gd4W0080GT0V00<0Gd4W0653:@1RA2X0201JABX0201K@BP0
G48Y05e3:P1NA2/0GD<Z05a2:@1J@2L0FClV201D@bL804hn9@P0DD4X00L0Bc/R04Xj8@19>B00B3PO
04Ti801;>b80CShU0080CclV0`1;?B<304Xl8P80BC/Q0P19>B00101:>R40Bc/R04dm901>?RD204lo
9P0904`h801>>R80D3`T058n9P1C?bL0DShV054m9@1@?2@0Bc/R0080C3`S00<0CCdT04hn9@1>?RD0
0P1??bH404ho8P@0Cd0S00<0C3dP04ho8P1B@bH00P1EART00`1CA2L0D44T04ho8P0305509080DT4U
0`1C@RH01P1G@RD0F4<V05U49`1IA2L0FTDX05]6:@80G4LZ0P1JABP00`1KART0G4LZ05e8:`0205i9
;00405m:;@1NBRT0GTXY05i::@80Gd/Z0`1PC2/306I@:@80Ie4Z0`1XDR/02@1[CR`0KE0^06mB<01`
Dc40Ke8`06e@;P1ZCB/0J4/Y06e?:@0306i@:P80Ke4[0P1`DR`207AD;P0407EE;`1fES00N5Pb07UI
<`80NUXd00H0N5T]07UJ;P1iFRh0NU/_07]L<01lGC4207eN<P<0Oelf1@20H3L04023IcP0Q6Dg08=T
=P24HcH0QF<f08UT>02;I3T0SFHk08m[=`2>JSH0S6Pd08]W<`2<J3@0SFTe08m[=`2AKCT208i/?080
Sfdm0`2@KSh00`2AKcl0TFdi095]>@03099^>P80Tflk0P2DL3`0202CKc/0U70l09Mc?`2HM400VGE1
09Qd@02FLSh0UG4m0P2HM400102IMD40VWI209]g@`2KMd<209ahA0P0WGY40P2ONdL20:1lB0<0XGe9
00<0XWi:0:5mB@2QODT00P2ROTX0102SOd/0Y81<0:B0C02UPDd20:V5D`040:R4D02XQDl0Z8E?0:N4
C080YhA:0P2YQTh20:Z7C`@0ZhQ@0`2/R5P20:f9F@<0[XYJ00T0[8QH0:^7E`2[QeL0ZhMG0:f9F@2`
S5`0/XiN0;B@H02aSUP00P2aSET00`2bSU`0/XiN0;:=H0020;>>HP030;B@H02eTF40]Y9R0080]i=S
00<0]Y9R0;FAH@2dT6000P2eTF420;JBHP040;NCH`2hU6@0^9AT0;VEI@<0]i=S0P2hU6@30;VEI@<0
^YIV0`2iUFD20;RDI0P0^IEU202kUfL20;VEI@80^YIV0`2kUfL20;bHJ0070;^GI`2iUFD0^9AT0;NC
H`2hU6@0^IEU0;ZFIP090;VEI@80^IAW0P2jUFP30;^FJ@030;bGJP2hU6@0^9AT00H0^9AT0`2mV6`3
0;bGJ`80^iIZ00H0]Y9R0;NCH`2gTf<0^IEU0;ZFIP2kUfL20;bHJ0P0^IEU202iTf@20;RCIP<0^IAW
0`2jUFP80;ZEJ@P0^YIV00@0]i=S0;RDI02hU6@0^IEU0P2jUVH20;^GI`P0^YEX402iUFD@0;NCH`80
^YEX00@0^IAW0;RCIP2hTfH0]i9U0P2fTF@01P2fT6T0]Y5W0;JAI`2fTFD0]Y5T0;JBHP80]Y9P00T0
/XiL0;>?G@2cSel0]8mR0;F@I02eT6H0]Y5W0;J@J@2bSF000`2cSV400`2dSf80]I1S0;F@H`020;JA
I0P0]Y9R202dT6080;>?G`80/XaM00@0/heN0;B>G`2dSUl0]HmP0P2fT6400`2aRUl0/X]P0;B=HP02
0;F>H`040;B=HP2bRf00/HYO0;>=GP80]8iO00<0]HmP0;J@H@2fT6400P2gTF820;6=G@<0/8aL00<0
/XiN0;B@H02fTV801@2dSf850;F@H`040;B?HP2cSV40/hiQ0;:=H080/HaO202aSEd00`2/R5P0[HUI
0:n;F`030;6=G@030;2<G02_Re/0/HiH00L0/HiH0P2_Re/20;2<G080/HeM0P2bSUh01P2`RU/0/H]L
0;6;G02bS5d0/heN0;B>G`80]HmP0P2bSUX20;6=F@80/8aH0P2_ReL00`2^RUX0/8aL0;6=G@020;>?
G`030;6=G@2`S5`0[XYJ00P0/XiN102aSEd40;2<G080/HeM00D0/XiN0;>?G`2cSel0/hmO0;B@H002
0;FAH@80]8mR0P2cSV40102bSF00/HaO0;6<G`2`Reh20;:=H080/HaO0`2`Reh01P2_RUd0/hiQ0;:=
H02bSF00/HaO0;2;GP80[hYM00<0[XUL0;>=GP2bS5d00P2bS5d30;6;G0030;2:F`2bSUh0/XiN0080
/HeM0P2`S5`20:n;F`<0/HeM0`2bSUh20;>?G`<0[XYJ1@2_Re/80;2<G0P0/8YK0P2^RUX30:n;F`<0
/8aL0P2[QUT0102/QeX0[HQK0:n:G@2`Reh20;6<G`80[XYJ00@0[h]K0;2<G02aSEd0/XiN0P2cSel4
0;2<F0@0/HeI0P2dSUl0102cSEh0/XaM0;:<G@2aRe`20;2:F`80/hiJ00@0/HaH0;2;E`2^RED0[HQD
0P2[QU820:V5E@040:Z6EP2[QeL0ZhMG0:b8F080[HUI202^RED0202`Rel0[hYN0:f8F`2[QeL0ZhME
0:^7D`2/R5@0[HYD2@2^RUH01P2YQE40ZXIB0:^7D`2/R5@0[HUE0:n;E`80/8aH00<0Yh=?0:Z6DP2^
RUH00P2aSET00`2_ReL0[8QD0:Z6DP020;6<F0040;2;E`2_RUH0[hYF0:j9E@80[HQD0P2/QUl01P2/
Qe/0[8MJ0:b8EP2/RE<0[8UA0:b9C`P0[HQL0P2[QEH40:Z4E@80ZH=D2P2]R5@30:b7D`<0ZhIB00<0
Z8=?0:V4D02[QU800P2/Qe<00`2[QU80ZHA@0:R3C`080:Z4E@P0ZHA@00H0YH5=0:J2CP2VPTh0Yh=?
0:R4D02YQE420:Z6DP@0Yh9=102XPdh40:R3C`@0Yh9>00X0YX1C0:EoDP2TOU40Y7iA0:EoDP2WPE@0
ZH=F0:Z4E`2YOdd0Z7i<0P2WOD/0102XOT`0ZX1>0:b2D02]Pe430:N2CP<0YX5=2P2UP4`0102UP4/0
YX5<0:R3CP2ZQE030:^6D@030:Z5D02YQ4l0Y7m;0080Y7m;0P2UP4`30:J1C@060:V3EP2XPU<0Z89C
0:R2D@2WPTh0Yh9=0P2VPDX20:J1C@80Yh9>0P2XPdl20:V4D0030:V5D@2VPTh0XWi:0080X7a800<0
Y81<0:R4D02/R5@00P2WPTh20:J1C@<0YH1<00H0Y7m;0:5lB02QO4P0XWe90:=nBP2TOd/20:J1C@03
0:N2CP2TNTP0Y7Y800H0Y7Y800H0Xgi90:=nBP2SOTX0Xge<0:AnC`2TOU420:EnD`060:9mB@2QO4P0
XGa809mjAP2NNDD0WGQ40P2LMd<00`2VNTd0YGU<0:=gBP030:5eB0030:9fB@2SMdX0XWe90080XWe9
0`2QO4P20:1kA`<0X7a80P2ONdL309ijAP0609ag@`2MN4@0WGQ409iiA@2ONTH0X7]70P2QO4P20:1k
A`<0WgY61@2NNDD00`2MN4@0W7M309]f@P0209Ye@@0709Ud@02LMd<0WGQ409ehA02NNDD0WgY60:1k
A`020:5lB0<0WWU41@2ONTD20:9mAP0:0:9mB02QO4P0XG]:0:5kC02PNT/0X7Y=0:9oB@2PODL0WW]5
09]h@P@0VWM100T0VgQ20:1lC02LN4P0VWI609]gA`2NNTX0Wg];09eiB@2IMDD00P2HLT<209UcA004
09YdA@2KMDH0W7I709afA`80V7M100H0VGI009Ud?`2JLSh0VW4m09U`?02JKc`209Ia?@0409Mb?P2H
Lcl0VWE109]f@P80W7M300H0WWU509ehA02JMD40V7<o09Mb?P2FLCd209Mb?P0309Ec@`2DLT80U792
0080Tg510P2BL400102AKcl0Ug5209E_@02DKSl209=]?P0609A^?`2EKd00Ug5209=]?P2EKd00UW11
0P2HLT<0302GLD80UW1109E_@02AK400Tfi209E`@`2FLT80UW9009Ea?@2CKc/0TFhh09Ia?@80SVTe
:oooool002[ooooo00<0WG9509]`@`2JKd800P2HKD002`2IKT40Vg1309aaA02NLT40WG5009a`?`2K
Kch0W70o09ea@02OLd80XGE40080WG=10P2LLT0209]a?`80VW0n00P0VFa209]_@P2MLD@0Wg=40:1d
@`2OM440WW<n09eb?@P0WG=100<0XGE40:1d@`2PM4<01@2PM4<809md@@0309]a?`2LLT00WWA200<0
X7I40P2NM4800`2LLT00WG=109me@`030:5gA@060:1fA02OMD<0XGM70:9hB02RN4H0XWU50P2SNTH0
2@2SNT@0Y7]30:Ak@`2UNdT0Y7Y80:=iA`2RN4H0XGM50:1fA00209me@`@0X7I4102OMD<01P2MNDD0
WWU509iiA@2PN4D0XGM50:9fA@80Y7I500<0YWY90:EiB02SMdH00P2RMTD00`2SMdH0YGU80:IjB@02
0:ImB@030:ElB02TNdL0Y7]700<0XgY6202UO4P0202RN4H0Y7Y80:IlBP2WOD/0Z7i<0:MmB`2VO4X0
YG]9202WOTX30:QoB`80ZH1<0`2ZPDd20:ImA`060:MnBP2WOD/0Z7i>0:QmD02YOU40ZGiC0P2XOTh0
102XOT`0ZH1<0:V0C02ZPD/20:Z1B@P0ZX5;00<0ZGm=0:Z0CP2[PDl00P2/PU000`2[PDl0ZX1>0:Uo
C@020:UoC@80ZX1>0P2[PDl20:b2D0050:V0C02ZPDd0ZX5=0:^2CP2/Pdl00P2]Q5000`2^QE40ZX59
0:^2BP020:^2BP80[8=;0P2]Q4`00`2WPTh0Z8=?0:V4D0020:^6DP030:V4D02XPdl0Yh9>00<0Zh9>
0`2/Pdl20:f4D0<0ZHA?0P2ZQE040:^6D@80ZhI?00<0ZhIA0:^6DP2[QE@00P2[QEH0102[QEP0ZHA?
0:V4C`2YQ4l20:Z5D0<0ZhIA202/Qe<80:n5D`<0[8=?0P2]Q5030:j5D@80ZXE@00@0ZhIA0:b7DP2]
R5<0[XUD0P2_RUD20:n6DP80[XEA00@0[HA@0:b3C`2/Pdl0[8=?202]Q5001P2/QUT0ZhEF0:Z4E@2Y
Pe80Z8=?0:N2C@80YX5:202UP4`20:=oA@060:9mAP2RODP0XGa70:5lB02QNdX0X7Y90P2NNDD00`2M
N4@0W7M309]f@P0209Ye@@0309Ud@02JMD40VWE10080VGA00`2HLcl04@2GLSh0V7<l09Mb>`2GLSd0
Ug8n09I`?`2FL440UFm009E_@P2GLSh0UW4m09A_>`2CKSX0TVdi09=^>P2DKc/0UG0l0080UW1100@0
UFm009A^?`2CKCh0Tfdn0P2BK3d5091Z>`<0TF/l00@0T6Xk08mY>P2?JCX0SfTj0P2>J3T208eW>0<0
RVDk0`29I3X308QS>@0808US?P28HSd0Qf4l08EO>P24GST0PU`g085K=P20FSD8085N=00307mJ<020
Fc40PE`b0080PE`b00<0OeX`07iI;`1lEbd0201nF3<0201hF380NETc07YJ=01jFS@0NETc07MG<@1e
EBl0Le<]0P1fES000`1eEBl0M5@^07=C;@02079B;005075A:`1eF300LeH^075D;01_DRX00P1^DBT0
0`1_DRX0L5<[06a?;`0706a?;`0806e?:`1/CRX0JT`X06U;9`1XBRH0JD/W06]=:@1/CRX206Y;;080
J4TZ00@0JDX[06Y;;01/CBh0KTl`0P1WBBd206I8;00406E7:`1TARX0HdDY06=5:@P0GdHX00<0HdDY
06539`1P@RH00P1O@BD00`1P@RH0HD<W06=5:@0805]6:`0305a2:@1M@bX0GT@[0080GT@[00<0G48Y
05]1:01I?bH0201G@bP804lo9@P0DD4W00<0CCdS04`l8P1:>R000P1:>R00101<?280CCdS04lo9@1?
?bD804do9080BSXP00T0Bc/Q04`l8P1=?B<0CShT04lo9@1@@2H0Cc/R050l8`1B?RD00P1C?bH0101B
?RD0DCdT050l8`1<?28204dm8`80CShT0P1??bD00`1@@2H0CSlR04ho8P0204m08`80D44T0P1A@RD0
201=?R40Cd0S05=49`1EART0ETLZ05A5:01A@RD0Cd0S0`1D@2D205E19P<0ET8W00H0F4<T05U49@1I
A2D0FTDV05]69`1LAbP205e8:@80FdHW00<0G4LX05e8:@1NBBX00P1OBR/0101PBb`0Gd/Z05m;:P1O
BbX2061<:`<0HDd/00@0IU0Y06MA:P1WDBX0Ie4Z0P1XDR/206UC;080KU8]0P1_Dbh01@1^DRd0KE4/
06]?:P1ZCRT0KU0Z00<0Ke4[0P1`DR`2075C;@80MED_00@0MUH`07MG<@1hF380NETc0P1jFS@207UJ
;P0307YK;`1kG300O5da0080OEhb00<0OUlc081Q=@20HCD00P20HCD4085R=P0:08AX>@25ISP0Q6Dg
08AS=P26I3L0RF@h08aU>P2=IS/0SVXf08eY=@80S6Pd00D0SFTe08iZ=P2AKCT0TVhj08i/?00308m]
?@80T6hn0P2AKcl4099^>P80Tflk102DL3`01`2ELCd0Ug<o09Qd@02IMD40V7A009Mc?`2FLSh00P2H
M4000`2IMD40VWI209]g@`0209ahA00309eiA@2OO4H0Wga600H0Wga600@0Wg]70:1lB02PO4P0X7a8
0P2QODT50:9nBP030:=oB`2TP4`0Y81<0080YH5=0P2XQ580102XQ500Z8E?0:R5C`2XQDd20:R5B`80
ZHI>0P2ZQdl30:^8D0040:b9D@2/R5P0[8QH0:b8F080[HUI102^RUX0202]RET0[8QH0:b8F02]RET0
[h]K0;6=G@2cSel0/HiH0P2aSET00`2bSU`0/XiN0;>>H@020;>>HP030;B@H02eTF40]Y9R0080^9AT
00@0]Y9R0;FAH@2dT600]I5Q0P2fTV820;NCH`80^9AT00@0^IEU0;NCH`2gTf<0]i=S0P2hU6@30;VE
I@<0^YIV0`2iUFD20;RDI0P0^IEU202kUfL20;VEI@80^YIV102kUfL0202lV6P0^iMW0;VEI@2hU6@0
]i=S0;RDI02iUFD0^YIV2@2iUFD20;VDI`80^YEX102kUVT80;RDI0<0_9M[0P2kUVX30;ZEJ@050;JB
HP2gTf<0]i=S0;RDI02jUVH00P2kUfL00`2lV6P0^IEU0;VEI@060;VEI@P0^I=T0P2hTfH30;VDI`<0
^YEX202jUFT80;ZFIP<0^9AT00<0^IEU0;ZFIP2jUVH00P2kUfL80;ZEJ100^IEU402gTf<30;VDI`03
0;RCIP2gTVD0]i9U0080]Y5T00H0]Y1Y0;JAI`2fTFL0]Y5U0;JAI02fTV820;JBH080/hmM00H0/hmO
0;B?HP2eT6@0]I1V0;JAI`2fT6T40;>>H@030;B?HP2eT6<0]I1S0080]Y5T402eTF480;>?G`80/XaM
0P2cSEh01`2dSUl0]HmP0;F?H02eSf00/HYO0;:;H02dSF800P2eSV<00`2dSF80/X]P0;6:G`030;B>
G`030;F?H02fT640]Y1Q0080]i5R00<0/hmO0;:>GP2aSEd00P2`S5`00`2bSUh0]91P0;FAH@080;B?
HP030;F@H`2dSf80]8mR0080/hiQ0P2bSF000`2aS5l0/HeM0;6=G@060;6=G@030:b8F02]RET0[h]K
00<0/HeM00<0/8aL0:n;F`2aSET01`2aSET20:n;F`80/8aL0P2aSEd20;:>GP<0/XaM0`2cSEh20;B>
G`80/XiJ0P2aSET20;2<F080[h]G00<0[h]K0;2<G02aSEd00P2bSUh00`2aSEd0/8aL0:n;F`080;:>
GPD0/HeM0`2`S5`00`2aSEd0/XiN0;:>GP030;>?G`80]91P00<0]I5Q0;>>H@2cSV400P2bSF020;6<
G`80/8]N0P2bSF020;6<G`@0/8]N102aS5l40;2;GP@0/H]L102bS5d20;:>GP80/HeM0P2`S5`20:n;
F`<0/HeM0`2bSUh20;>?G`80[h]K3P2`S5`80;2:F`80[XYJ0`2_Re/30;2<G0050:^6F@2/QeX0[8MJ
0:f8F`2_RUd00P2`Reh01`2aS5l0[XYJ0:j:FP2_Re/0/8aL0;6=G@2bSUh00P2cSel40;2<F0@0/HeI
00<0/heN0;:<G@2bS5d00P2aRe`20;2:F`090:n9FP2cSUX0/XeI0;6<F02`ReL0[XUE0:f8E02/Qe<0
ZhIB0080ZXIF0P2[QeL0102/R5P0[HUI0:f9F@2]RET80:j9E@080;2;G`2_RUh0[HQK0:^7E`2[QeD0
ZhMC0:b8E02]RU@90:j:EP050:Z6DP2[Qe<0ZhMC0:b8E02]RED00P2^RUH02@2_ReL0Z8A@0:Z6DP2^
RUH0/8aH0;6=F@2_ReL0[8QD0:Z6DP030;2;E`80[hYF0`2^RED01P2/QUl0[8MM0:b7F`2/QeX0[8QF
0:b8E080[8UA202]R5`20:^5EPH0ZXAE2P2/Qe<30:^6DP<0ZXEA00<0Z8=?0:V4D02[QU800P2/Qe<0
0`2[QU80ZHA@0:R3C`080:Z4E@P0ZHA@0`2WPdl30:R4D080ZHEA102WPTd40:R3CP@0Z8=?102WPTh2
0:J0D@060:EoD02TOTl0YGm@0:J0D@2XPU<0ZXAE0P2YOdd01P2XOT`0Yge;0:QnC02YOdd0Zh5?0:f3
D@<0Yh9>0`2VPDd:0:F0C0050:F0B`2VPD`0Z8=>0:Z5D02[QU400P2ZQE000`2YQ4l0Z8=>0:AoB`02
0:AoB`80YH1<0`2VPDd01P2XPUD0Z89C0:R2D`2XPU40Yh9>0:N2C@80YX5:0P2VPDd20:N2CP80Z8=?
0P2YQ5000`2WPdl0YH5=0:=oB`020:9nBP030:B0C02WPdl0ZHEA0080YX5=0P2UP4`20:AoB`80Xgi:
0P2QO4P01P2RODT0Xgi:0:AoB`2UP4`0YX5=0:N2CPP0Y7Y800H0XWe80:=nBP2SOTX0Xge<0:AnC`2T
OU420:EnD`050:9mB@2QO4P0XGa80:1kA`2NNDD00P2MN4@0102LMd<0Y7U<0:=hB`2RMdX20:1eB003
0:5fB@2RMdX0XgQ;00<0XWe90P2QO4P30:1kA`<0X7a80P2ONdL309ijAP<0WWU50`2ONTH20:1kA`03
09iiA@2ONTH0WgY600L0WgY600@0WWU509ehA02LMd<0W7M30P2KMT8309iiA@<0WgY60P2PNdL409ii
A0@0WgY50P2QO4D00`2QO4L0XGa80:5kBP020:5kC0050:5kCP2QODT0Wg]709eiA@2KMd<00P2JMT82
09]g@`0:09ahA02ONd/0W7Q809UeA@2KMdL0WWY:09mkB`2MNDT0VGE509Qb@`80VG=40P2JM4D209]e
AP0:09afA`2HMd40V7M109Uf@02IM3l0VW8n09Ya?@2IL3`0VVll09E`?080UW4m00P0Ug8n09Ud@02J
MD40VWE109]f@P2LMd<0VWE109Qc?`<0UW4m0P2GLSh01P2@KSh0TFlo095_?`2BL400Tg5109Ab@P80
UG=300<0Ug5209E_@02DKSl00P2CKCh0502DKSl0UFm009Ma@P2DKSl0UFm009I`@@2GLD80V79309Ma
@P2EKd00U6ho099]@@2CKT80U6m209Ea@@2ELCl0U70l09=_>`2BKcT0UW4m0P2?JSH[ooooo`00:_oo
ool209]`@`0>09Y_@P2IKT40VFi109Y_@P2KL4<0W75409ib@@2MLD00W70o09]_?P2LL3l0WG5009mc
@P2PM4<209ec@@80W7900P2KLCl209Y`?P0609Y]@`2KKd80W71309ea@P2MLD00W74n0P2KL3/809ec
@@80XWI50P2QMD@0102PM4<0Wg=209ib@@2NLT4809md@@0309ab@02MLd40WWA200<0X7I40P2OMD<0
1@2MLd40WWA209me@`2PMT@0XGM50080X7I400@0WgE30:5gA`2QMdL0XGM50`2RNDD00`2SNT@0XgY2
0:=j@P020:AjB0030:=iA`2RN4H0XGM50080X7I400X0WgE309ec@@2MLd40WWA209me@`2PMT@0XGM5
0:9hAP2SNDL0Wg]70P2PNdL00`2RNTL0XgU70:AhA`020:IhA`030:MkBP2VNTT0YGU80080Y7Q700<0
YGU80:IjB@2WNdX01@2UO4P00`2TNdL0XgY60:=jAP080:ElB0030:=iA`2TNTP0YG]900<0Yge;00<0
YWa:0:EkB@2WOTX0202WOTX30:QoB`80ZH1<0P2ZPDd20:ElAP030:ElB02VO4X0YWa<0080Yga?00L0
YgaA0:MmC@2XOTh0Z7i<0:QoB`2YP4`0ZH1:0080ZX59202ZPD/00`2YOdd0ZX1>0:^1C`020:b2D003
0:^1C`2ZP4h0ZGm=0080ZGm=0P2ZP4h20:^1C`80[89@202[PTh30:Z1B`80Zh9<0`2/Pdd00`2WPTh0
Z8=?0:V4D0020:^6DP030:V4D02XPdl0Yh9>00<0Zh9>0`2/Pdl20:f4D0<0ZHA?0P2ZQE040:^6D@80
ZhI?00<0ZhIA0:^6DP2[QE@00P2[QEH0102[QEP0ZHA?0:V4C`2YQ4l20:Z5D0<0ZhIA202[QU880:n5
D`<0[8=?0P2]Q5030:j5D@050:Z5D02[QU40ZhIA0:b7DP2]R5<00P2^RE@00`2_RUD0[hIB0:j5D@02
0:j5D@<0[HA@00<0[8=?0:j5D@2^QE401P2^QE40202[QEP0ZhEF0:Z4E@2YPe80Z8=?0:N2C@2WPT/0
YX5:202VPDd01P2TP4H0Xgm50:=nA`2SOTT0XWe80:9mB@80XG]:0P2ONTH00`2NNDD0WGQ409ag@`02
09]f@P0409Ye@@2IM400VGA009Ud@080V7<o0`2GLSh209Qc?00309Qc?P2GLSh0Ug500080UW1100T0
UW1309Qc?`2GLSh0UG0l09A_>`2CKSX0U6lk09E`?02FLCd00P2GLD800`2FL440UFm009A^?`0209=]
?P@0TV`m1@2AJc`208mY>P80SVPi0`2=IcP0102<ISL0S6Lm08]V?02;IS`208YU>`@0RF@j0P2:I3d0
1P29Hc`0Qf4j08IP>@25GcP0Q5hg08=M=PP0PEhd00P0P5/a085L<P22GC<0Pehd089M<`21G380OeX`
07iI;`P0OeTb101jFS<0101iFC80N5Pa07IF;`1eEBh207MG<00307IF;`1eEBh0M5@]0080Le</00D0
LU8[07EH<01cERh0LUD]071C:`0306mB:P03071C:`1^D2h0KU0^00H0KU0^0P1/CRX01P1[CBT0JT`X
06]=:@1/CRX0KDl[06i@;080Jdd[0`1ZC2X00`1[CB/0KDl]06i@;P0806E7:`P0H4LY0P1SABT40653
9`80HdDY201NARX0201M@bP0GT@Y05m5:P1PAR/0GdDZ05i4:@1L@RL0Fd4V201HABL805919`P0Dd8X
00H0DD0V050o9@1??R@0CSdS04dl8P1>?B<304ln9080CclU00@0D40V05519`1A@BL0DT8X0P1C@bT0
1P1=?280CSdS04hm8`1??R@0D3lU05509P80DT4W00<0DShU05<o9P1D@2L00P1D@2L00`1C?bH0DShU
054m9003050o9@<0DD0V0P1B@BL01@1??R00D3lQ05508P1B@B<0Dd8T0080ED@V00T0ETDW050o8@1B
@B<0ED@V05M6:01HAbT0EdHX05A39@1C@R@00`1F@bD205M49P<0F4DW0P1LABH0101MARL0GTLX05i7
:01OB2T20619:P80GTLX00@0GdPY0619:P1QBR/0HT//0P1SC2d0101RBbT0Hd`Z06=<:P1SC2X206A=
:`80IDh/00@0J50Z06UA:`1YDB/0JE4[0P1ZDR`206]C;@03075E<01`E2l0Ke<^00<0KE4/00@0KU8]
06mC;P1`Db/0L5<[0P1aE2`3079E;@0407=F;P1gEc00MeL`07QH<@80NETb00@0NUXc07]K=01kFc@0
NU/_0P1kG3000`1lGC40OEhb07iO<`0207mP=005081Q=@21HSH0PF8f085R=P22HcL00`23I3P02025
JCT0QVLh08EV=`26ISL0QfDg08]V>@2>J3/0SfTl102=JCD0102?JcL0TFdi099^>P2DL3`208m]?@80
T6hn0`2AKcl00`2BL400Tflk09=_>`0209=_>`80U70l102ELCd00`2FLSh0Ug<o09Qd@00209Ue@@07
09Qd@02GLcl0VGE109Ue@@2JMT80VgM309ahA00209eiA@0309ijAP2QOTP0XGi800H0XGi80P2PO4P2
0:5mB@<0XWi:102SOd/30:B0C080YH5=0P2VPU00102WPdl0Z8E?0:V6D02ZQdl20:Z7C@<0ZXMA0P2[
R5830:b9D`<0[HUI0P2^RUX30:n;F`030;6=G@2`S5`0[XYJ0080[HUI00h0[XYJ0;2<G02aSEd0/HiH
0;6=F@2bSUX0/XiL0;>?G`2cSV40/hiR0;B?H`2dT600]I5Q0;NCH`80^9AT00<0]i=S0;FAH@2dT600
0P2fTV820;NCH`@0^9AT0`2gTf<20;RDI0<0^IEU0`2jUVH30;VEI@80^9AT202iUFD80;^GI`<0^IEU
0P2jUVH30;^GI`080;bHJ02kUfL0^IEU0;RDI02gTf<0^9AT0;VEI@2jUVH90;VEI@<0^IAW0P2jUFP3
0;^FJ@P0^9AT0`2jUFP20;VDI`<0^9=V00H0]Y9R0;NCH`2gTf<0^9AT0;VEI@2jUVH20;^GI`P0^IEU
202iTf@20;RCIP<0^IAW2`2jUFP80;ZFIP80^9AT0`2iUFD30;ZFIPP0^YEX402iUFD80;NCH`P0]Y9R
00@0^IAW0;RCIP2hTfH0^9=V0`2gTVD01`2fTF@0]Y1Y0;JAI`2fTFL0]Y5U0;JAI02fTV800P2fTV02
0;>?G@030;B@H02dSf80]8mS0080]I1V00<0]HmX0;>>H@2cSV40102dSf830;F@H`P0]91P202fTV88
0;>?G`040;:<G@2cSEh0/heN0;>=GP<0]8iO00@0]HmP0;6;GP2bS5l0/heP0P2dSV400`2cSF00/XaO
0;6;GP020;B>G`<0]HmP0`2fT640202eTF40]91P0;:>GP2aSEd0/8aL0;6=G@2bSUh0/hmO2`2dSf82
0;>>H@<0/XeP202aSEd00`2/R5P0[XYJ0:n;F`030;6=G@80[h]K202aSET20:n;F`80/8aL0P2aSEd2
0;:>GP80]8iO0`2cSEh30;:<G@80/XiJ0P2aSET20;2<F080[h]G00<0[h]K0;2<G02aSEd00P2bSUh0
0`2aSEd0/8aL0:n;F`080;:>GPP0/HeM0`2bSUh30;>?G`<0]91P102aS5l20;2;GP80[hYM0`2bSF02
0;6<G`L0/8]N102aS5l01@2_REX0/8YK0;2:F`2aRe`0/XaM0080/heN00<0]8iO0;:>GP2bSUh00P2a
SEd20;2<G080[h]K0`2aSEd30;:>GP80/hmO202aSEd80;2<G0P0/8YK0P2^RUX30:n;F`<0/8aL0P2/
QeX0102]R5/0[XUL0:j9G02_RUd20;2;GP80[XYJ00@0[h]K0;2<G02aSEd0/XiN0P2cSel40;6=F@@0
/8aH00@0/H]L0;2:F`2`RU/0/8YK0`2_REX02@2^R5T0/hiJ0;:=F@2aS5P0/8]G0:j9E@2]R5@0[8MC
0:^6DP030:b8F080[HUI0`2^RUX80:j9E@080;2;G`2_RUh0[HQK0:^7E`2[QeD0ZhMC0:b8E02]RU@9
0:f9E@P0[8QD00<0Z8A@0:Z6DP2]RED00P2`S5P00`2_ReL0[HUE0:^7D`030:j9E@80[hYF0`2`ReL2
0:b7F`030:b7FP2/R5P0[8QF0080[8QD00<0[8UC0:b7FP2/QeX01P2/QeX30:Z4E@D0ZhEF202[QU83
0:Z5D@<0ZHA@0`2XPdl01`2YQ500ZhIB0:b7D`2/Qe<0ZhIB0:V4D02XPdl0202ZQ5D80:V4D080ZHEA
0`2XQ5030:N3C`@0Z8=>102WPTd40:N2CP@0Z8=?0100Yh5B0:J0D@2UOe00Y7i?0:EoD02VP540Z89C
0:V3E02ZP4h0ZGm=0:QnC02WOD/0Z7i<0:UoC@2[PDl0[89@0`2WPTh30:J1C@80YH1<202VPDd00`2U
P4/0Yh9=0:R3CP040:Z5D0030:R3CP2WPTd0Y7m;0080Y7m;0P2UP4`30:J1C@060:R2E@2XPU<0Z89C
0:N1D02WPTh0YX5<0P2VPDX20:J1C@80Yh9>0P2XPdl20:V4D0@0Y81<0P2UPDd20:J2CP<0Y7m;0P2S
OTX30:9mB@060:5lB02RODT0XWe90:=nBP2TOd/0YH1<0P2VPDd80:AjB0060:9mB02RODT0XWe90:=m
C02SODh0Y7iA0P2TOE801P2RODT0XGa80:5lB02PNdL0WgY609iiA@80WGQ400P0XgQ;0:9gBP2QMTT0
X7E80:5fB@2RMdX0Y7U<0:EjC@80XWe90P2QO4P30:1kA`0409mjAP2PO4P0X7a80:1lB080Wg]70`2N
NTH20:1kA`<0WgY60`2NNDD209ehA080WWU500<0WgY60:1kA`2QO4P00`2QO4P00`2PNdL0WgY609ii
A@0209ehA00309ag@`2PNdL0X7]700<0WgY60`2NNDD809iiA080WWU200T0WgY50:1kA`2QNdX0XG]<
0:9lC@2RO4l0WWY609eiA@2LN4@00P2KMd<0302LN4@0WGU509eiA@2NNTH0WWY:09]gA`2IMDD0VWI6
09ijBP2ONd/0WGU909UeA@80VG=400<0VWA509]eAP2KMDH00`2KMDH209Qg@@0709Uf@02IM3l0VW8n
09Ya?@2IL3`0VVll09A_>`0209E`?00809Ia?@2GLSh0V7<o09Qc?`2IM400V7<o09Mb?P2EL3`209A_
>`0>09E`?02FLCd0Ug8n08m[>`2@K3`0TVhn09=_?`2ELD40Ug=309UeA@2JMTH0Ug5209E_@02DKSl2
09=]?P0609A^?`2EKd00Ug5209A^?`2EKd00UW110P2GLD80302FL440UFm009A^?`2BKD40Tfi209A_
@P2DL400U70n09A`?02CKc/0TVli09E`?080T6/g:oooool002[ooooo1@2JKd8209]`@`0309aaA02M
LD00W70o00<0Vfln00<0WG5009mc@P2PM4<00P2MLd4209ab@080Vg4o0P2JL3h0202KKT@0Vfm209]_
@P2KKd00Vfln09Y_?02JKcX0VFhi202MLd401P2TN4L0XgM60:9fA@2QMD@0X7A309ib@@80WG500P2P
MD8409md@@80WW=000@0WG=109id@P2NM480WgE3102PMT@00`2NM480WgE309me@`030:1fA080WgE3
0P2PMTH01@2PMT@0XGQ40:5hA02QN4@0XWU30080XWU10`2SNDL00`2RN4H0XGM50:5gA@020:1fA080
WgE30`2PMT@30:5gA@060:1lB02QO4P0XGa80:=kB02TNTP0YGU80P2WNDP80:IjB@030:=jAP2TNdL0
YGa80080YWe900<0YGa80:=jAP2SNTH0202UO4P20:AjB0030:EkB@2VO4X0YWa:00<0YWa:202XOd/2
0:MnBP<0Z7m;0`2YP4`20:AkA@030:AkA`2UNdT0YG];0080YW]>00@0YW]@0:MmC@2WODd0Z7i<0P2X
Od/00`2YP4X0ZH180:V0B0080:Z1B`80ZX1>102[PDl20:Z0CP80ZGm=0P2ZP4h20:^1C`80[89@0P2/
Pdl30:^2CPH0ZX5=0`2[PTh20:b3C`030:N2CP2XPdl0ZHA@0080ZhIB00<0ZHA@0:R3C`2WPTh00`2[
PTh30:b3C`80[HA@0`2YQ4l20:Z5D0@0ZhIA0P2[QTl00`2[QU40ZhIB0:^5E0020:^5EP040:^5F02Y
Q4l0ZHA?0:V4C`80ZXE@0`2[QU480:V4D0P0[hEC0`2/Pdl20:f4D0<0[XEA0P2[QU420:b7DP80[HQC
0P2^RE@@0:j5D@060:Z4E`2ZQ5D0ZXAE0:V3DP2XPdl0Z8=>0P2WPT/80:J1C@80Y81600@0Y7m80:Ao
BP2SOTT0Xgi:0P2RO4/20:1kA`80WgY600D0WWU509ehA02LMd<0W7M309Ye@@0309Ud@080V7<o0P2G
LSh209Ud?@0309Ud?`2HLcl0V7910080Ug5200T0Ug5409Ye@@2HLcl0UW4m09E`?02DKc/0UG0l09Ia
?@2GLSh00P2HLT<0102GLD80UW1109E_@02DKSl209=]?P0309A^?`2CKCh0Tfdn0080Tfdn0`2BK3d0
102?JCX0SVPi08iX>@2>J3T208eW>080S6Hg00D0SVTm08eX?02=J3`0S6Lk08]V>P0308YU>@0708UT
>02;IS`0RfHl08YU>`29I3X0R6<i08MR>00208IQ=`P0PV0c00L0PUdc08=N=024GcD0QF0f08AO=@23
GS@0PE`b00T0P5/a0P1lG3<207]K<P0407YJ<@1iFC00N5P_07MG;P80N5P_0P1gEbh02@1fERd0MED/
07AD:`1dE2/0MEP`07AG;`1cERh0LUD]075D;003071C:`P0LU4^1@1]Cb/0101^D2`0Ke4]06mA;@1]
Cb/406a>:P<0KDl[0`1UB2X306I9:`80IdX/201RBBX306A7:@80HdHX0`1TAbT80658:P0805m6:01P
AbT0HDPZ0699:`1QB2X0H4LY05i59`1MA2H805Y59PP0ED4V201G@bP205I29`0305E19P1D@2D0DclT
00@0DShS00H0CSdQ04ln8P1@?b<0DD0T05919@1D@bL205E4:080DShS0P1C?b@0101D@2D0ED4V05E1
9P1E@BH405I29`0405E19P1D@2D0E40U05<o90P0ED4V0P1C@2002@1E@R80ET<S05Q59@1JAbL0FdPX
05a9:@1E@R80Ed@T05U69P0205]8:00305Y79`1IARH0F4DU00<0FTDV0P1KARL305a7:00605i59P1O
ARL0GdHW0617:01QB2T0HTTZ0P1SBR/20658:@030699:P1SBR/0I4//0080ID`]00@0ITd^06I>:P1V
CRX0IThZ0`1WCb/206Q@;0<0Je4/0P1/DRd306eC;P0307AH<@1bERl0Ke</0080KE4Z00@0Ke</075E
;P1cEc00LUD[0`1cER`207AG;@80MEP^0P1iFC0207YJ<@0407]K<P1lG3<0O5`c07aL<`80O5da00@0
OEhb07iO<`1oH3@0P64e0P21HSH01@21HS@0PV<e089S=@23I3H0Q6Dg0080QFHh00T0QVLi08M[>@28
JSP0QfTg08MW=P29IcL0S6Ph08mY>P2AJc`00P2=JCD01P2>JSH0Sf/g095]>@2CKc/0U70l09Ea?@80
T6hn0P2AKcl4099`@080U70l0`2ELCd209Ib?P@0Ug<o0P2HM40409Ue@@80VWI200@0VgM309ahA02M
NDD0WGU50P2NNTH80:>0BP80XGe90P2ROTX40:=oB`80Y81<1P2UPDd01P2UPDl0YX9@0:N3C`2XQDl0
ZHI@0:^8D080[8U?0P2ZQU830:^7D`<0[8QD0`2^RUX30:n;F`80/8aL00@0]91P0;:>GP2`S5`0[h]K
0P2^RUX00`2_Re/0/8aL0;:?F@020;:>FP030;>?G@2cSel0/hiQ0080]8mS00<0]I5Q0;JBHP2gTf<0
0P2hU6@00`2gTf<0]Y9R0;FAH@020;NCH`H0^9AT0`2gTf<20;RDI0<0^IEU0`2jUVH30;VEI@80^9AT
202iUFD80;^GI`80^9AT0P2iUFD20;ZFIP80^iMW00P0_9QX0;^GI`2iUFD0^9AT0;NCH`2hU6@0^IEU
0;ZFIPT0^IEU0P2hTfH20;VDI`80^YEX0P2kUVT80;RDI080^IEU0P2hU6@30;NCH`050;JBHP2gTf<0
]i=S0;NCH`2hU6@00P2iUFD20;ZFIPP0^IEU202iTf@20;RCIP<0^IAW0`2jUFP@0;ZFIPH0^IEU0P2j
UVH80;ZEJ100^9AT202gTf<80;JBHPP0]i9U00H0]Y1Y0;JAI`2fTFL0]Y5U0;JAI02fTV820;JBH080
]91N00H0]91P0;B?HP2dSf<0]8mU0;F@IP2eSfP70;B?HP80]I1S202bSUh80;NCH`P0/hmO202cSEh0
0`2bS5d0/heN0;>=GP040;>=GP030;:<G@2eSf00]HmP00@0]HmP0P2fT6400`2gTf<0]I5Q0;>?G`03
0;6=G@80/XiN0`2dSf840;>>H@030;:=H02cSV40/hiQ00H0/hiQ202aSEd00`2]RET0[XYJ0;2<G002
0;6=G@030;2<G02_Re/0[XYJ00P0/HeK0P2_Re/20;2<G080/HeM0P2bSUh20;F?H0030;B>G`2cSEh0
/XaM0080/H]L00<0/8YK0;:>FP2bSUX00P2aSET20;2<F080[h]G0P2`S5`40;6=G@80/8aL202bSUh4
0;6=G@@0/XiN2@2cSel50;2;GP<0[hYM0P2cSV420;:=H080/HaO0P2`Reh01@2^RE`0[hYM0:n:G@2`
Reh0/HaO0080/XeP00T0/hiQ0:j8F@2_REX0/8YK0;6;G02bS5d0/heN0;B>G`2eSf000P2bSUh20;6=
G@80/8aL0P2_Re/30;6=G@<0/XiN1@2cSel40;:>GP030;6=G@2`S5`0/8aL00H0/8aL202`RU/20:j:
FP<0[h]K0`2`S5`00`2/QeX0[HQK0:f8F`020:j9G080[hYM00L0/8]N0:j:FP2^RUX0[h]K0;2<G02a
SEd0/XiN0080/hmO102aSET40;2<F0@0[hUJ102^R5T01@2bSET0/HaH0;6<F02`ReL0[XUE0080[HQD
00<0[8MC0:f9F@2]RET00P2]RET40:j:FPP0[XUE00P0/8]O0:n:GP2]R5/0ZhMG0:^7E@2[Qe<0[8QD
0:f:E0/0[HUE0`2/R5@30:^7D`030:V5D@2[Qe<0[HUE0080[h]G00<0[XYF0:f9E@2/R5@00P2]R5@0
102^RED0[hYF0:n:EP2`ReL20;6<F080[8MJ0`2/R5P30:b8EPP0[8QH0P2ZQ5D40:^5EP80[8IG2`2Y
Q5030:R3C`80Yh9>00<0Z8=?0:V4D02[QU800P2/Qe<00`2[QU80ZHA@0:R3C`080:Z4E@P0ZHA@0P2Z
QU800`2YQE40Z8A@0:N3C`020:J2CP030:F1C@2XPdh0Z8=>0080Z8=>102WPTd40:N2CP@0Z8=?0100
Z89A0:N1D02UOdh0Y7i=0:EoCP2VP4l0Yh5@0:R2D@2[PDl0ZX1>0:QnC02WOD/0Z7i<0:UoC@2ZP4h0
Zh5?0`2WPTh30:J1C@80YH1<202VPDd01@2VPD`0Yh9=0:R3CP2YQ4l0ZXE@0080ZHA?00<0Yh9=0:J1
C02TOd/00P2TOd/20:F0C0<0YX5=00H0Z89E0:R2D`2WPE80Yh5@0:J1C@2VPD`20:F0B@80YX5=0P2W
PTh20:R3C`80ZHA@00<0XGe90:9nBP2UPDd00P2WPdl00`2VPTh0Y81<0:=oB`030:=nBP80XWe90`2Q
O4P20:9mB@80Xgi:00@0Y7m;0:F0C02UP4`0YH1<202TNTP01P2RODP0XWe90:9mB@2SOD`0Xge>0:=m
D080Y7eB0`2QO4P00`2PNdL0WgY609mjAP0209iiA@030:9iB`2QN4X0X7M90080X7M900<0XWU;0:Ak
C@2UO4h00`2QO4P30:1kA`80WgY60`2PO4P209mkA`<0WWY60P2QO4P00`2PNdL0WgY609iiA@0209eh
A00709ag@`2KMT80W7M309ehA02NNDD0WgY60:5lB0020:9mB@060:=nBP2RODT0XWe90:5lB02PNdL0
WgY60P2NNDD20:5lB0030:1kA`2ONTH0WWU50080WGQ400<0W7M309mjA@2NND@00`2NND@309eh@`80
W7M000H0WGQ309mjAP2PNTT0XG]<0:9lC@2SOE0509ahAP0?09eiA`2NNTP0WWY809ijB02MNDT0VWI6
09QdA02JMTH0WGU909mkB`2MNDT0VWI609UcA02JM4D0VgE600<0W7I700X0VgE609YdA@2HMd40V7M1
09Uf@02IM3l0VW8n09Ya?@2IL3`0VVll0P2DKc/209E`?080UW4m0P2GLSh02@2EL3`0U6lk09=^>P2B
KCT0Tfhj09A_>`2FLCd0Ug8n099/?@0209=]?P0809A^?`2FL440Ug5209Ma@P2HLT<0Ug5209E_@02D
KSl209=]?P0609A^?`2EKd00Ug5209A^?`2EKd00UW110P2GLD80202EKd00U6ho099/?@2BKD40Tfi2
09=^@@2CKcl0Tflm0P2CKc/0102BKcT0Tfhj095/>02AK3P[ooooo`00:_ooool0102HKD00VFi109Y_
@P2JKd8409]`@`0809ea@02LL3l0Vfln09Y^?@2KKch0W70o09ib@@2OLd8209ec@@80W7900P2KLCl2
09Y`?P0609a_A@2LL4<0Vfm209Y^?`2JKSd0VVll0P2JKcX809ec@@060:AhA`2SMdH0XWI50:5eA02P
M4<0WW910P2MLD000`2QMT<0X7E20:1e@P0209md@@80WW=000<0WG8o09me@`2OMD<00`2OMD<00`2P
MT@0XGM50:5gA@020:1fA0H0WgE30P2OMDD01@2OMD<0X7M30:1g@`2PMd<0XGQ20080XGQ000<0XgU7
0:9hAP2RN4H00P2RN4H30:5gA@80Y7Y800L0XgU70:5gA@2PMT@0WgE309id@P2MLd40X7a80080XGa8
00<0Xg]80:AjB02UNDP00P2WNDP20:EiB0@0YWY90P2UNDP0202RNDD0XgY60:ElB02VODT0Ygi:0:El
B02TNdL0XWU5202TNdL50:EkB@030:IlBP2WOD/0Yge;00P0Z7m;0`2WOTX30:QoB`80ZH1<0P2TNdD0
0`2TNdL0YG]90:EkB`020:IkCP040:IkD02WODd0Yge=0:MmB`80Z7m;00<0Z7m90:V0B02YP4P0202Y
P4X20:^1C`@0ZX1>0P2[PDl20:UoC@80ZX1>0P2[PDl20:b2D0<0Zh9>0`2ZPDd40:V0C0<0ZX5=0`2[
PTh00`2WPTh0Z8=?0:V4D0020:^6DP030:V4D02XPdl0Yh9>00<0Zh9>0`2/Pdl20:f4D0<0ZHA?0P2Z
QE040:^6D@80ZhI?00<0ZhIA0:^6DP2[QE@00P2[QEH0102[QEP0ZHA?0:V4C`2YQ4l20:Z5D0<0ZhIA
202YQ5080:j4DP<0[8=?0P2]Q5030:j5D@@0[8MB102]R5<40:j5D@`0[hIB00H0ZXAG0:V3E02YPe@0
ZH=B0:V4D02XPdh20:R3C0P0Yh9>0P2UPDL0102UP4T0Y7m:0:AoBP2TOd/20:=mC080XWe900@0XGa8
0:1kA`2ONTH0WWU50P2MN4@309]f@P80VWE10`2IM40209Ye?P0309Ye@02IM400VG=20080V79300@0
V79509]f@P2JMD40V7<o0P2FLCd00`2GLSh0V7<o09Ud@00209UcA00409Qb@`2GLD80UW1109E_@080
U6ho0P2FL44209E_@00509A^?`2CKCh0Tfdn09=]?P2@JS/00`2?JCX208iX>@80SFLh00D0T6/n08mZ
?@2?JSd0SVTl08aW>P0308]V>@0608YU>02<Ic/0RfHj08]V>P2:ICT0RF@h0P28HcL00`27HSH0Pf4c
08=Q<`0608=Q<`0808AO=@25H3H0QV4g08MR>026HCL0QF0f08=N=021G388089M<@0407iO<`1mGS80
O5da07]L<080NU/_0P1iFRh207YK;`0407UJ;P1hFBd0MeP/07IG:`80MEHZ0P1eF30207AG;`0407=F
;P1bEBd0L5<[071C:`P0ME<^00<0KU0/06mA;@1_DBd01@1`DRh606i@:P80KDlY101WBRX206Q;:`80
JD`/201TC2X00`1UB2P0ITTY06I9:@0406I9:@0306E8:01TBB/0I4T[00H0I4T[00P0HDPY0699:P1S
BR/0I4//06=::`1RBBX0H4LX05i59PP0GTLW201H@bH;05U49`0305Q39P1G@RD0ET4T00<0ED0S00H0
CC`N04hm7`1??R00D3lQ05508P1C@R@205A39@0305I1901G@RD0Ed8U0080Ed8U0`1H@bH00`1IARP0
F4DW05Q59`0505M49P@0FD@W101H@bH205M38P0;05U5901JARD0G4PW05i::@1OBbX0H4`[05Y69@1K
AbH0G4PW05e9:01NBRT00P1MBBP00`1LB2L0GTLW05m8:00205m8:080H4TY0P1QBRX01P1QAbH0HTPW
06989`1SBBP0I4XY06E;:P80IT`[0P1TBRT00`1UBbX0IT`[06M=;00206Q>;@0306U?;P1YCb`0JDl/
00<0JU0]0`1[DBh206iB;@80Ke<^0`1`E2l0101aEC00METa07=G;`1aEBd206mC:`03075E;@1dF300
MUXb00<0MEP/0P1fFBd307MJ;P<0O5da101mGS8307iO<`0407mP=020HCD0PF8f089S=`80Pf@h0P23
I3D01024ICH0QFHg08IW>027J3T208QY>P0=08U^>@2:K3P0RF/g08UY=P2;JSL0SVXh095[>P2BK3/0
SVXf08m[=`2@K3P0TVhj09=_>`0209A`?00309Ea?@2AKcl0TFlo00<0TW100`2CLD4409Ib?P80Ug<o
1P2HM40209Ue@@80VWI20`2KMd<209ahA00409eiA@2NNTH0Wg]709mkA`P0Y85;0P2ROTX30:=oB`<0
Y81<1@2VPTh30:F1C@80YX9@00H0Yh=?0:V6D02ZQe40ZhQ@0:b9C`2]RU030:^7E@<0[8QF0P2]REL4
0:n;F`80/8aL0P2aSEd0102eTF40]91P0;:>GP2`S5`30:n;F`070;2<G02bSeT0/XiJ0;>?F`2cSed0
/hmO0;B?HP020;B?H`030;FAH@2fTV80^9AT0080^IEU00<0^9AT0;JBHP2eTF400P2iUFD60;RDI0<0
]i=S0P2hU6@30;VEI@<0^YIV0`2iUFD20;RDI0P0^IEU202kUfL30;RDI080^IEU0`2jUVH0202lV6P0
^iMW0;VEI@2hU6@0]i=S0;RDI02iUFD0^YIV2@2iUFD30;RCIP80^IAW0`2jUFP80;RDI0<0^9AR0`2g
Tf420;JBH0<0]i=S102hU6@90;VEI@P0^I=T0P2hTfH30;VDI`<0^YEX202iUF<80;VEI@80^YIV1P2i
UFD80;VDIa00^9AT202gTf<80;FAH@@0]Y5T102gTVD01P2fT6T0]Y5W0;JAI`2fTFD0]Y5T0;JBHP80
]Y9P0P2eTEl00`2dT600]8mR0;B?H`020;B?I@030;B>I`2eT6<0]I1S00L0]8mR202bSUh80;NCH`P0
/hmO102cSEh40;:<G@<0/heL0P2bS5/30;>=G080]Y1Q1P2eSf00102gTf<0]Y9R0;B@H02bSUh20;6=
G@030;:>GP2cSel0]8mR0080]8mR00<0/hiQ0;:=H02bSF000P2aS5l80;>>H@P0/HeM00<0[XYJ0:n;
F`2`S5`00P2aSEd00`2`S5`0[XYJ0:f9F@080;6=G@80[h]K0P2`S5`20;6=G@80/XiN0P2eSf000`2d
SUl0/heN0;:<G@020;6;G0030;2:F`2bSUX0/XiJ0080/HeI0P2`S5P20:n;E`80/HeM102`S5`20;6=
G@P0/XiN00<0/8aL0;6=G@2aSEd00P2bSUh20;>?G`030;B@H02cSel0/hmO00L0/hmO1P2`Reh20;6<
G`<0/hiQ0P2bSF030;6<G`050:j9G02_RUd0[hYM0;2;GP2aS5l00P2bSF002@2cSV40[XQI0:n9FP2`
RU/0/H]L0;:<G@2cSEh0]8iO0;F?H0020;:>GP80/HeM0P2`S5`20:n;F`<0/HeM0`2bSUh20;>?G`80
]91P0P2cSel0102bSUh0/HeM0;6=G@2aSEd80:n;F`P0/8YK0P2^RUX30:n;F`<0/8aL0P2]R5/40:j9
G080[hYM0P2^RUX0102_Re/0/8aL0;6=G@2bSUh20;>?G`80/XiJ0P2aSET20;2<F080[h]G102^R5T4
0:n9FP80/HaH00@0/8]G0:n:EP2_RUH0[XUE0P2]R5@80:f9F@P0[XUE00P0/8]O0:n:GP2]R5/0ZhMG
0:^7E@2[Qe<0[8QD0:f:E0T0[HUE0`2/R5@30:^7D`<0ZXIB00<0ZhMC0:f9E@2^RUH00P2^RUH20:f9
E@80[HQD00@0[XUE0:n:EP2_RUH0/8]G0P2aS5P30:b8EP<0[8QH0P2/QeX80:^7E@80ZXAE0P2[QEH2
0:b6E`80[HMH2`2YQ5030:R3C`80Yh9>00<0Z8=?0:V4D02[QU800P2/Qe<00`2[QU80ZHA@0:R3C`08
0:Z4E@P0ZHA@0P2ZQU800`2YQE40Z8A@0:N3C`020:J2CP030:F1C@2YQ4l0ZHA?0080Z8=>0P2WPTd2
0:J1C080YX5=0P2WPTh20:R3C`80ZHA@0100Z8=?0:N2CP2VPDd0YH1<0:AoB`2UP4`0Yh9>0:R3C`2[
PDl0ZX1>0:UoC@2XOT`0Yge;0:QnC02ZP4h0Zh5?0`2WPTh30:J1C@80YH1<202WPTh00`2VPD`0Yh9=
0:R3CP020:V4C`80Z8=>00<0YX5<0:F0B`2TOd/00P2TOd/20:F0C0<0YX5=00H0Yh5D0:N1DP2WPE80
YX1?0:J1C@2UP4/20:F0B@80YX5=0P2WPTh20:R3C`80ZHA@00<0Wg]70:5mB@2TP4`00P2WPdl00`2V
PTh0Xgm;0:9nBP030:=nBP80XWe90`2QO4P30:=nBP@0Y7m;00<0YH1<0:AjB02TNTP01P2TNTP01P2Q
O4L0XGa80:9mB@2RO4/0XWa=0:=mD080XgaA0`2QO4P40:1kA`0909mjAP2QNd`0X7Y;09miBP2NN4T0
WgU:0:1jB`2RO4d0Xge>0080XGa80`2PNdL309mjAP<0X7a80P2ONdL309ijAP80XGa800<0X7]709mj
AP2NNDD00P2MN4@01`2LMd<0VgI209ag@`2MN4@0WWU509mjAP2QO4P00P2RODT20:=nBP030:9mB@2Q
O4P0X7]70080WgY600H0WWU50:5lB02QO4P0X7]709mjAP2NNDD209ehA00309ag@`2ONTD0WgY50080
WWU400@0WGQ309ag@P2LMd80W7M20P2KMSl01P2LMd80WWU509miB02PNT/0XG]<0:9lC`80VgM700<0
W7Q809eiB@2MNDT0102MNDT0402LN4P0VGE509Mc@`2IMDD0WGU909mkB`2MNDT0VWI609UcA02KMDH0
W7I709ihB@2MMdP0W7I709YdA@2ILd@209Qg@@0609Uf@02IM3l0VW8n09Ya?@2IL3`0VVll102EL3`4
09Ia?@0309E`?02DKc/0Tfhj0080TVdi00<0U6lk09Ia?@2GLSh00P2IL480102HKd40Ufi009I]?`2E
K3h209A[?@0309Ma@P2EKd00U6ho0080Tfdn0100U6ho09E_@02GLD80U6ho09E_@02FL440Ug5209I`
@@2DKSl0TV`m095[?02CKT80TVe1099]@02BKSh0TVhl0P2BKSX0102CL3X0TF`h09=^>P2CKSX[oooo
o`00:_ooool0102GK3l0V6e009U^@@2KL4<309aaA00309]`@`2LL3l0W70o00<0VVhm00<0W70o09ib
@@2OLd800P2MLd4209ab@080Vg4o0P2JL3h0202ML4H0W71309]_@P2JKSl0Vfln09]`?@2LLC`0WG8m
202MLd420:9fA@80XGE400@0X7A309mc@P2NLT40WW910P2QMT<0102PMD80WgA109md@@2NLd0209eb
?`070:1fA02OMD<0WgE309id@P2OMD<0X7I40:5gA@020:9hAP030:5gA@2OMD<0WWA20080WWA20P2O
MD<209idA00509id@P2OMT80WgI209mf@P2PMd400P2PMcl80:9hAP80YWa:00L0Y7Y80:9hAP2PMT@0
WWA209ec@@2LLT00Wg]70080X7]700<0XWY70:=iA`2TN4L00P2VN4L00`2SMdH0Y7Q70:EiB0030:Ei
B00:0:AhA`2SMdH0X7M30:9iA@2UO4P0Ygi:0:QoB`2VODT0Y7]70:9iA@P0Y7]700<0YWa:0:EkB@2T
NTP00P2TNTP00`2VO4X0Yge;0:QnC0080:V0C080YWe90P2WOTX30:QoB`060:V0C02UO4H0YGa60:El
B02VO4X0YWa<0P2WO4l02@2WO540YWa<0:IlC02WOD/0Ygi:0:QoB`2XOdT0Z7m70:V0B0080:V0BP03
0:b2D02[PDl0ZX1>0080ZGm=00<0ZX1>0:^1C`2/PU000P2YOdd20:Z0CP80Zh5?0P2/PU080:Z1C@<0
ZGm=0P2ZP4h30:^1C`030:N2CP2XPdl0ZHA@0080ZhIB00<0ZHA@0:R3C`2WPTh00`2[PTh30:b3C`80
[HA@0`2YQ4l20:Z5D0@0ZhIA0P2[QTl00`2[QU40ZhIB0:^5E0020:^5EP040:^5F02YQ4l0ZHA?0:V4
C`80ZXE@0`2[QU480:^6DPP0[XAB0`2/Pdl20:f4D0<0[XEA102/Qe840:f8D`<0[XEA0P2_QU830;27
D`P0[hIB00H0ZH=F0:V3E02YPe@0ZH=B0:V4D02YQ4l20:V4C@P0Yh9>0P2VPTP0102VPDX0YH1;0:F0
B`2TOd/20:AnC@80Xgi:00<0XWe90:5lB02PNdL00P2ONTH209iiA@<0WGQ40P2LMd<209]f@P80VgHo
00<0VgI109Ye@@2JM4<00P2ILd@02P2ILdH0W7M309]f@P2IM400V7<o09Mb?P2HLcl0VGA009Ye@@2J
M4D209UcA00309Qb@`2GLD80UW110080UFm00P2HLT<00`2GLD80UW1109E_@00209A^?`0309=]?P2B
K3d0TF/l0080TF/l0P2@JS/208mY>P06099^?P2AKCd0T6`l08m[>`2>JSX0S6Ph0`2;IcL208]V>@80
RVDh0P29I3L208QS=PP0Q68b00<0QV4g08MR>028HcT00P28HcT00`26HCL0Q5le08=N=00808=N<@04
081Q=@1oH3@0OEhb07aM<@H0Ne``00<0NU/_07UJ;P1hFBd00P1gF2`02@1fEb/0MEP`07EH<01fFC40
MEP`07AG;`1cERh0LE@/071C:`0807QE;`09075C;`1bE300LeDa07=E<@1bE300LE<_071B;P1_DBd0
Ke8Z0080L5<[00D0LE@/071C:`1_DRX0KU4Y06e@:00406]>;0@0JTd[201VCRX00`1VBBL0IdXX06Q;
:@0206U<:P0306Q;:@1WBRP0ITTW00P0J4/[00<0Hd/Y06A<:P1UCB/00P1UCB/00`1SBbT0HDTW0618
9P0806189PP0G4DV201MARL205a59P0505e69`1NAbP0GDHW05a59P1KA2D00P1J@b@01@1B?al0Dd0P
05=0801D@B40ED8R0080ET<S00<0Ed@T05]49@1KA2D00`1KA2D305a59P0805Y79`1IARH0F4DU05Q5
9@1IARH0FTLW05]8:01LBBT205i7:080GDHW101LABH01P1LAB<0GDHT05i79@1OB2H0HDXX069;:@80
Hd`Z0P1OB2H00`1PBBL0HDXX065::003065::080HTXX0P1SBbT306A<:P0706E=:`1UB2H0IDPV06I9
9`1WBRP0J4/Y06U<:P0206Y=:`80J4/Y00@0JD`Z06Y=:`1ZCB/0Jdh/0P1/Cbd206eA;080KU8]0`1_
Dbh0101`E2l0LE<_075C;`1aDbl2079D<0<0LeDa0P1dFBh307=H;@0307AI;P1eFRl0MU/`00<0MeX^
0P1hFbl307UL<0@0OUlc101oH3@2081Q=@03085R=P22HcL0Pf@h0080Q6Di01H0QFHj08AV=024IS@0
QFLe08MY=`28JSP0RF/i08Y/>P2;KC/0Rg0i08a^>02;KCL0Rf`f08e/=`2@K3P0Tfhj09A_>`2AKCT0
TVhj09=_>`2DL3`0UG4m0P2DL3`0102CKc/0TW10099`@02BL40209=a@@<0U7920`2GLcl209Qd@0<0
VGE10`2JMT8309Ue@@0409Yf@P2LN4@0WGU509]g@`80W7Q400<0WGU509ijAP2ONdL00P2PO4P80:B1
B`<0Xgm;0P2TP4`30:F1C@80Z8A@0P2WPdl40:J2CP80Z8AB00@0Z8A@0:V6D02ZQe40ZhQ@0P2/RDl3
0:^7E`80[8QH0`2]RET0102_Re/0/8aL0;2<G02`S5`20;6=G@80/XiN00<0]Y9R0;B@H02bSUh00`2`
S5`00`2aSEd0/XiN0;:?F@020;>?F`030;>?G@2dT600]8mR0080]I1T00<0]Y9R0;NCH`2hU6@00P2i
UFD00`2hU6@0]i=S0;JBHP020;ZFIP80^IEU102hU6@30;NCH`80^9AT0`2iUFD30;ZFIP<0^IEU0P2h
U6@80;VEI@P0^iMW00@0]i=S0;RDI02hU6@0^9AT0P2iUFD20;ZFIP080;bHJ02kUfL0^IEU0;RDI02g
Tf<0^9AT0;VEI@2jUVH90;VEI@040;NBI@2hTfH0^9=V0;RCIP80^IAW0P2jUFP80;RDI0<0^IEQ0P2h
U6030;NCG`P0]i=S202iUFD80;VCI080^9=V0`2iU6L30;ZEJ0P0^IEQ202iUFD30;ZFIP<0^IEU0P2h
U6@80;VDIaP0]i=S202eTF430;F@H`80]Y5T0`2gTVD01P2fT6T0]Y5W0;JAI`2fTFD0]Y5T0;JBHP80
]Y9P0P2eTEl01P2eTF40]8mR0;B?H`2dSfD0/hiT0;>=IP@0]I1S0`2dSf820;>>H@P0]91P202fTV88
0;>?G`<0/heN0P2bS5d30;6;G0030;B?F`2cSUX0/XeI0080/HaH00<0/XeI0;>>FP2dSe/00`2fT643
0;F?H080]8iO00<0]Y9R0;FAH@2cSel00`2bSUh00`2dT600]I5Q0;F@H`020;B?HP030;>>H@2bSF00
/HaO0080/8]N0`2bSF020;>>H@<0]8mR202aSEd20:n;F`<0/HeM00<0[h]K0:j:FP2/R5P0202aS5l2
0:n;F`80/8aL0P2aSEd20;:>GP80]8iO0`2cSEh30;:<G@80/XiJ0P2aSET20;2<F080[h]G00<0/XiN
0;6=G@2`S5`00P2_Re/00`2`S5`0/HeM0;:>GP080;:>GP80/8aL00<0/HeM0;:>GP2cSel00P2dT600
102eTF40]91P0;B@H02dT6030;>?G`<0/XiN102aS5l20;:=H080/hiQ00@0]8mR0;>>H@2cSV40/hiQ
0P2bSF020;6<G`@0/8]N102aS5l01@2_REX0/8YK0;2:F`2aRe`0/XaM0080/heN00<0]8iO0;:>GP2b
SUh00P2aSEd20;2<G080[h]K0`2aSEd30;:>GP80/hmO00H0]91P0;>?G`2cSel0/XiN0;6=G@2`S5`:
0:n;F`P0/8YK0P2^RUX30:n;F`<0/8aL202^RE`20:j:FP040:n;F`2`S5`0/HeM0;:>GP80/hmO00D0
/hmK0;:>FP2bSUX0/HeI0;2<F0020:n;E`030:j:EP2^R5T0[hUJ0080[hUJ0`2`RU/0102aRe`0/8]G
0;2;E`2`ReL20:n:EP<0[XUE00@0[HUI0:b8F02/R5P0[8QH0`2[QeL00`2ZQUH0[XUE0:j9E@060:j9
E@080;2;G`2_RUh0[HQK0:^7E`2[QeD0ZhMC0:b8E02]RU@90:b8E0T0ZhMC0P2/R5@01@2]RED0[XYF
0:j:EP2^RUH0[HUE00<0[XUE0P2_RUH30;2;E`060:b9D`2/R5@0[8QD0:b8EP2/R5P0[8MJ0P2/Qe/8
0:^7D`80ZXAE0P2[QEH0102/QUL0[HMH0:j8F@2^R5T80:^6DP<0ZXEA0`2YQ5030:R3C`070:V4D02[
QU80[8MC0:b7D`2[QU80ZHA@0:R3C`080:Z4E@P0ZHA@0P2YQE430:R4D0<0Yh=?00D0ZXE@0:V4C`2Y
Q4l0Z8=>0:N2C@020:J1C0060:F0B`2UP4`0YX5=0:J1C@2WPTh0Z8=?0P2YQ5004@2ZQE40ZHA?0:R3
CP2VPD`0YH1;0:AoBP2UP4/0YX5<0:N2C@2/PU00Zh5?0:UoC@2XOT`0Yge;0:QnC02YOdd0ZX1>00<0
Yh9>0`2VPDd20:F0C0P0Yh9>00D0YX5<0:N2C@2XPdh0ZHA?0:R3CP020:N2C@030:F0B`2TOdX0Y7m;
0080Y7m;0P2UP4`30:J1C@080:N1E02WPE80YX1A0:J0C`2UP4`0YH1;0:F0B@2TOdP20:J1C@80Yh9>
0P2XPdl20:V4D0030:1lB02QODT0Y81<0080YX9>00<0YH5=0:=oB`2ROTX00`2TOd/20:=nBP<0XWe9
202TOd/80:AjB0060:5lA`2QO4P0XGa80:9lB`2RO4d0Xge@0P2SO5480:5lB0030:=oC`2ROTh0X7a<
00<0WWY:00<0Wg];0:1lC02QO4P00`2PNdL209mjAP80WWU50`2PO4P209mkA`<0WWY60P2PNdL309mj
AP<0WWU50P2MN4@209iiA@0509mjAP2PNdL0XGa80:5lB02SOTX00P2RODT00`2QO4P0X7]709mjAP02
09iiA@80X7]70`2ONTH309iiA@80WgY500@0WWU409eh@`2LMd80W7M20P2KMT401@2KMSl0W7M009ag
@P2MN4@0WWQ70080WgU:00@0X7Y=09]fB@2LMdX0WGQ;0P2NND`03`2MN4/0W7M:09agBP2KMTT0VgM7
09QdA02FLT80V7A409eiB@2ONd/0WGU909YfAP2JM4D0VgE609ihB@0209miBP0309afA`2JM4D0V793
0080V7M100H0VGI009Ud?`2JLSh0VW4m09U`?02JKc`409Ia?@D0Ug8n0180UW4m09A_>`2CKSX0Tfhj
09A_>`2EL3`0UW4m09aaA02KL4<0VVm209Q]@02FJch0U6Tl09=X>`2BIcX0Ug5209E_@02DKSl209=]
?P0309A^?`2EKd00Ug520080UFm00P2FL4403@2EKd00U6ho095[?02@JS/0Tfi2099]@@2AK3l0TFdm
095]>`2AKCT0TVhj09=`>P2@JcL00P2EL3`[ooooo`00:_ooool0102EJSd0Uf`o09U^@@2LLD@209eb
A@0:09aaA02KL4<0W70o09]_?P2JKSd0VFdl09Y^?@2KKch0WG5009ib@@80WG=10P2LLT0209]a?`80
VW0n00P0WG1609a`@`2KKd80Vfm009a`?`2NLd00X7E00:5f@@P0WG=100<0XGE40:1d@`2PM4<01@2P
M4<01@2RMd@0XGI30:5f@`2PMD80WW=00080WG8o00P0W74n0:5gA@2PMT@0WgE309id@P2OMD<0X7I4
0:9hAP80XgU700L0XGM509me@`2NM480WG=109id@P2OMD<0X7I40080WG=300L0WWA209ie@@2OMT80
WgI209mf@02OMSh0X7Lo0080XGM51P2RN4H01@2TNTP0XgU70:=iA`2RN4H0XGM50080X7I400L0WgE3
09eiA@2NNDD0WWU50:1hA@2QMdD0XWI50080Y7I500<0X7A30:5eA02SMdH00P2TN4L01P2SMdH0XGE4
0:1d@`2OMT80XGQ40:ElB080Z7m;00<0Ygi:0:AkA`2RNDD0202SNTH0202VO4X0YG]90:AjB02SNDL0
Y7Y80:EkB@2WOD/0ZGm=202YP4`30:ImB@80Ygi:0`2XOd/20:ImA`060:MnBP2WOD/0Z7i>0:QmD02Y
OU40ZGiC0P2VO4`0102VO4X0Ygi:0:MnBP2XOdT20:QoA`P0Z7m900<0[89@0:^1C`2ZP4h00P2YOdd0
0`2ZP4h0Zh5?0:b2D0020:UoC@80ZX1>0P2[PDl20:b2D0050:MnBP2XOd/0Z7m;0:V0C02ZPDd00P2[
PTh00`2/Pdl0Z7i>0:QnCP020:UoC`<0ZX1@00@0Zh5A0:N2CP2XPdl0ZHA@0P2[QU800`2YQ500Z8=?
0:N2CP030:^2CP<0[8=?0P2]Q5030:V4C`80ZXE@102[QU420:^6C`030:^6D@2[QU80ZhED0080ZhEF
00@0ZhEH0:V4C`2YQ4l0ZHA?0P2ZQE030:^6D@P0[8MC202]Pe430:b3C`80[HA@0`2^QE440:f8D`@0
[8MB0`2^QE400`2_QU80/8MC0;27D`020;68E0P0[hIB00H0Z89E0:R2D`2YPe@0ZH=B0:V4D02YQ4l2
0:V4C@P0Yh9>0P2WPdT0102WPT/0YX5<0:J1C02UP4`20:EoCP80Y7m;00<0Xgi:0:9mB@2QO4P00P2P
NdL0102ONTH0X7]70:1kA`2PNdL209mjAP<0WWU50P2LMd000`2KMT40VgI209Yd@`0209YdA@0909Uc
AP2MN4@0W7M309Ye@@2IM400V7<o09Ud@02JMD40VgI20080VWA50P2ILd@0102HLT<0Ug5209I`@@2F
L44209UcA00409Qb@`2GLD80UW1109E_@0@0U6ho0P2CKCh3099/?@07095[?02CKcd0Tflm099^?02@
K3X0Sf/i08eY=`0208aX=P0308]W=@29ICD0RFDe0080RFDe1028I3@808ET<@0808MR>028HcT0RF@j
08YU>`29I3X0R6<i08IQ=`25H3H808AP<004089S=@20HC<0OUla07aM;`80Ne`^00L0O5d_07eN<01l
GBl0O5d_07]L;P1jFbd0NEX/0080N5T[00T0MePZ07EH<01fFC40MUTa07MJ<P1fFC40M5L_075D;01`
Db/0201iES004@1dES80MELc07IH=01eEc<0M5Hb075C;`1_DBd0KDl[071C:`1aE2`0LUD]07=F;P1b
EBd0L5<[06iA:@1]D2P0L5@_0080Ke<^00D0KU8]06eA;01/D2/0K50[06]?:P0806M?:@0306M;9P1X
C2L0JThY0080JdlZ00<0JThY06Q<9`1WBbH0201YC2`0201TC2X0IDd[06I>;01WCbd0ITh/06E=:`1S
BbT0HTXX201RB2L805e69PP0GTLW00<0Fd@T05e69P1NAbL00`1PBBT00`1NAbL0GDHV05e69P0605]7
9P80G4PW0P1NAbL605e69P0805Y79P1IARD0F4DT05U69@1JAbH0GDXY05m<:`1QCRd20619:@80GdPX
00D0GTLW05e69P1MARH0GDHV06199`02065::080HT/Y0`1SC2X3065::080HT/Y0`1SC2X206E;:P80
IT`[0`1WCB`01`1XCRd0ITXU06M;9P1WBbH0J4`W06U=:01ZCRT00P1[CbX206U=:00306Y>:@1[CbX0
K50[0080KE4/00@0KU8]06mC;01_Db`0Ke</0P1`E2d3075E;P<0M5<`0P1eE34307IE<P80LeP[00@0
MEX]07IK;P1gG2l0Me`_0P1fFbh307UM;P80NUh_0`1kGc07081Q<`0707mP<P21HSH0PV<g089S=`23
I3P0Q6Di08EV>P0208IW>`80QFLc01H0QVPd08QZ=P29JcL0Rfdi08a^>P2=Kc/0S74j08e_>@2<KSP0
SFhh08i]>02BKSX0U6lk09Ia?@2DL3`0UG4m09Ib?P2GLcl0UW8n09A`?02BKSX0TFdi0`2CLD4209Ab
@P<0UG=30`2HM40209Ue@@<0VWI200<0VgM309ahA02KMd<00`2IMD40102KMd<0WGU509ijAP2LN4@2
09eiA@0309ijAP2ONdL0X7a80080XGe9202SP4X30:B0C080YH5=0`2VPTh20:V5D@80Z8A@00@0Yh=?
0:J2CP2VPTh0YX9>0P2ZQU@0102ZQU80ZXMA0:Z7D@2ZQdl20:Z7C@040:^7E`2/R5P0[8QH0:b8F080
[HUI0P2^RUX20;2<G080/HeM0`2bSUh0102cSel0]I5Q0;B@H02bSUh30;6=G@030;>?G`2dT600/i1J
0080/hmK00<0]91N0;B@H02eT6<00P2eT6@00`2fTV80]i=S0;VEI@020;ZFIP040;VEI@2gTf<0]Y9R
0;^GI`80^YIV0P2iUFD20;RDI0@0]i=S0P2hU6@30;VEI@<0^YIV0`2iUFD20;RDI0P0^IEU202kUfL2
0;NCH`<0^9AT0`2iUFD0202lV6P0^iMW0;VEI@2hU6@0]i=S0;RDI02iUFD0^YIV2@2iUFD20;NBI@<0
^9=V0`2iU6L80;RDI0<0^YIR0P2iUF430;RDH0P0]i=S202iUFD80;VCI080^9=V0`2iU6L30;ZEJ0P0
^9AP202hU6@20;^GI`80^YIV00@0^IEU0;RDI02hU6@0^9AT202hTfHH0;NCH`P0]91P0P2dSf820;F@
H`050;JAI02gTVD0]i9U0;NBI@2fT6T00P2fTFL00`2fTFD0]Y5T0;JBHP040;JBH0030;FAH@2eT6<0
]8mS0080/hiT00<0/heV0;JAI02fTF@00`2eT6<0102dSf80/hiQ0;>>H@2cSV4@0;FAH@P0/hmO0`2c
SEh00`2bS5d0/H]L0;6;G0020;2:F`030;F@G02dSe/0/XeI0080/HaH00<0/XeI0;B?F`2eT5`00P2g
TF820;J@H@070;F?H02dSUl0]8iO0;B>G`2eTF40]91P0;>?G`020;:>GP040;B@H02fTV80]i=S0;F@
H`80]8mR00H0/hiQ0;6<G`2`Reh0/8]N0:n:G@2aS5l20;:=H080/hiQ0P2dSf800`2eT6<0/HeM0;6=
G@060;6=G@030:n;F`2`S5`0/HeM0080/HeM00<0[h]K0:f9F@2/R5P0202aS6020:n;F`80/8aL0P2a
SEd20;:>GP<0/XaM0`2cSEh20;B>G`80/XiJ0P2aSET20;2<F080[h]G00<0/XiN0;6=G@2`S5`00P2_
Re/00`2`S5`0/HeM0;:>GP080;:>GP80/8aL00L0/HeM0;:>GP2cSel0]91P0;FAH@2fTV80]I5Q0080
]91P0`2cSel20;:>GP030;6=G@2bSF00/XeP0080/hiQ0P2dSf820;F@H`80]8mR0`2cSV430;:=H0@0
/HaO102`Reh40;6;G0@0/XaM0P2bSUh20;6=G@80/8aL0P2_Re/30;6=G@<0/XiN0`2cSel01@2bSUh0
/HeM0;2<G02_Re/0[XYJ0080[HUI202^RUX80;2:F`80[XYJ0`2_Re/30;2<G0P0[XUL0P2^RUX0102_
Re/0/8aL0;6=G@2bSUh20;>?G`80/hmK00@0/XiJ0;6=F@2`S5P0[h]G0P2^RUH00`2_REX0/8YK0;2:
F`020;6;G080/XaM00<0/heN0;2;E`2`ReL0102_RUH20:j9E@<0ZhMG00<0ZXIF0:V5E@2YQED00P2X
Q5@80:j9E@080;2;G`2_RUh0[HQK0:^7E`2[QeD0ZhMC0:b8E02]RU@90:b8E0050:R4D02YQE40ZHEA
0:Z6DP2[Qe<00P2/R5@00`2]RED0[8QD0:b8E0020:b8E080[HUE0P2^RUH30;2;E`80[hYF0`2^RED2
0:b9D@060:b8E02/R5H0[8MJ0:b7F`2/Qed0[8IO202ZQU801P2YPe@0ZXAE0:^5EP2/QUL0[HMH0:j8
F@80[hUJ2P2/Qe<30:^6DP<0ZXEA00<0Z8=?0:V4D02[QU800P2/Qe<00`2[QU80ZHA@0:R3C`080:Z4
E@P0ZHA@0`2WPdl30:R4D080ZHEA0P2ZQE00102YQ4l0Z8=>0:N2C@2VPD`20:F0B`80YH1<00@0YX5=
0:N2CP2XPdl0ZHA@0P2ZQE401P2ZQDh0Z8=<0:J1BP2UP4T0Y7m80:F0B@80YX5:00H0[H=A0:^1C`2Y
Odd0Z7i<0:MmB`2XOT`20:UoC@<0Yh9>0`2VPDd20:F0C0P0Yh9>00D0YX5<0:N2C@2XPdh0ZHA?0:R3
CP020:J1C0030:AoBP2SOTT0Y7m;0080Y7m;0P2UP4`30:J1C@060:J0D`2VP540YX1A0:EoCP2UP4`0
YH1;0P2TOdP20:J1C@80Yh9>0P2XPdl20:V4D0040:5mB@2ROTX0Xgm;0:=oB`<0Y81<00<0Xgm;0:J1
C@2VPDd00P2UP4`20:AoB`80Xgi:1P2TOd/20:=nBPP0Y7Y800P0X7]60:1kA`2QO4P0XG]:0:9lC@2R
O4l0XW]@0:=lD@P0XGa800@0Y89B0::0D02OODd0WG];0P2KNDT209ajBP<0X7]70P2ONTH309iiA@<0
X7a80P2ONdL309ijAP<0WWU50`2ONTH20:1kA`0309iiA@2ONTH0WgY600D0WgY60P2QO4P20:1kA`04
09mjAP2NNDD0WGQ409ehA0<0WWU50`2ONTH20:1kA`80WgY500@0WWU409eh@`2LMd80VgI10P2JMD02
09ag@00309eh@`2MN4@0WGM60080WGM800<0WGM:09ehC02NNDd00P2ONTh05@2NNDd0W7M;09YeB@2J
MDT0V7=709YfAP2GLd<0UG5109QdA02MNDT0Wg];09eiB@2JMTH0VWA509afA`2ONDX0X7Y;09miBP2M
MdP0VG=409Ma@P0209Qg@@0609Uf@02IM3l0VW8n09Ya?@2IL3`0VVll202HLcl01P2JMD40V7<o09Ia
?@2DKc/0Tfhj09A_>`80UG0l0P2IKT400`2HKD00Uf`o09I[?P0209EZ?@0409AY?02GLD80UFm009A^
?`80Tfdn00<0U6ho09E_@02GLD800P2EKd0209I`@@0=09E_@02CKCh0TF/l08mY>P2CKT80TVe1095/
?`2@K3`0T6`j095]>@2BKSX0Tg0j08mZ=P0209Ia?B_ooooo000Zooooo`0409EZ?@2GK3l0VFi109aa
A080WG9500X0W75409]`@`2LL3l0Vfln09Y^?@2IKC`0VVhm09]_?P2MLD00WW910P2MLd4209ab@080
Vg4o0P2JL3h0202ML4H0W71309]_@P2KKd00WG5009md@@2RMd80Y7U4202MLd4209mc@P<0X7A30`2Q
MD@20:9gA0040:5f@`2PMD80WW=009eb?`80W74n00<0XWQ60:1fA02OMD<00P2NM4801P2PMT@0XWQ6
0:AjB02SNDL0XWQ609me@`<0WG=100D0WgE30:1fA02MLd<0WG=309ec@@0309ie@@0309mf@02OMSh0
WgHn00<0XGM51@2RN4H01P2OMD<0X7I40:1fA02QMdD0XWQ60:=iA`80Y7Y800H0W7Q409ehA02MN4@0
WgM40:1fA02QMD@20:=eA00309mc@P2PM4<0XWI50080XgM600/0XWI50:1d@`2OLd80WWE10:5hA02U
O4P0Z7m;0:V0C02WOTX0Y7]70:9iA@080:=jAP030:MmB`2UNdT0Y7Y80080XgU700<0YG]90:MmB`2Y
Odd0202YP4`30:ImB@<0Ygi:0P2XOd/0202WOTP0Z7m90:QoB`2XOT`0ZGm?0:UnD@2ZOe80ZWmD0P2V
O4`0102VO4X0Ygi:0:MnBP2WOTP20:QoA`P0Z7m900<0[H=A0:^1C`2ZP4h00P2XOT`00`2ZP4h0Zh5?
0:f3D@020:UoC@80ZX1>0P2[PDl20:b2D080YWe900H0Ygi:0:V0C02ZPDd0Zh9>0:b3C`2]Q5020:Qn
CP80ZGm?102ZP5000`2WPTh0Z8=?0:V4D0020:^6DP030:V4D02XPdl0Yh9>00<0Zh9>0`2/Pdl20:f4
D0<0ZHA?0P2ZQE040:^6D@80ZhI?00<0ZhIA0:^6DP2[QE@00P2[QEH0102[QEP0ZHA?0:V4C`2YQ4l2
0:Z5D0<0ZhIA202]R5@80:f3D@<0[8=?0P2]Q5030:j5D@@0[HQC102/Qe830:j5D@030:n6DP2`Qe<0
/HQD0080/HQD202_QU801P2XPUD0Z89C0:R2D`2YPe80ZHA@0:V4C`80ZHA=202WPTh20:N3B@040:N2
B`2VPD`0YX5<0:F0C080YGm>00H0YH1<0:AoB`2TOd/0Xgi:0:9mB@2QO4P20:1kA`040:9mB@2QO4P0
XGa80:5lB080X7]70P2ONTH209ag@00309ag@P2KMT80VgE40080VWA500@0VWA709iiA@2MN4@0VgI2
0`2IM40209]f@P0609]eAP2JM4D0VWA509UcA02HLT<0Ug520P2FL44209YdA@0309UcA02HLT<0Ug52
0080UFm000@0U6ho09E_@02EKd00UFm00P2DKSl309=]?P80U70n00@0TVhl095]>`2?JcT0SFTg0`2<
J3H608QT=080Qf<c2025I3400`28HcT0RF@j08YU>`0208YU>`0308QS>@27HSP0QF0f00P0QF4a00T0
Pf@e085R<`1oH340O5d^07]L;@1lGBh0OEh_07iO<01mGRl00P1lGBh00`1kG2d0NU//07UJ:`0207QI
:P0807EH<01fFC40MeXb07MJ<P1fFC40M5L_079E;@1`Db/807aF;`@0MeTe0180MELc075C;`1^D2`0
K4hZ075D:P1bEB/0LeH/07AG;@1cER`0LE@Z06iA9`1]D2H0LeLb079F<@1aEC00L5@_06iB;@1]DB`2
06a@:`P0J50Z00<0Id/V06U=:01[CbX00P1/D2/00`1[CbX0JDdX06M;9P0806]=:`0306E=:@1VCRX0
Idl[0080Idl[00<0IDdY06A<:01RBRH0201SBBH@05m69`0705a3901MA2D0H4LX0699:P1SBR/0HTTZ
0658:@020617:004069>;@1QCB`0HDd/065=;0<0H4`[00<0Gd/Z0617:01PAbP0101OARL205i59P80
FDHU00H0F4DT05U69@1KB2L0GT/Z069?;P1TDC020699:P80HDPY00@0H4LX05m69`1OARL0GTDV201T
C2P406=;9`0506A<:01UCBT0IDdY06I>:P1VC2T00`1WCBX206Q>:`80JDl/00H0J4XV06U;9`1YBbL0
JT`X06]=:@1/CRX206e?:`80JddY00H0K4hZ06e?:`1^D2`0KU0/06mA;@1`DRh3075C;@80LU@^0`1c
EBl207AC<080ME@a0`1fEC80101gES<0LEHY07=H:`1fFbh207UN<@0307QM<01fFbh0MEX]00<0NUh^
0P1kGbl307aP<0@0PF8c1020HC82089S=`0308=T>024ICT0QFHj0080QVLk01<0QfPl08EW<`26J3@0
QfTe08QZ=P2:K3P0S6hj08e_>`2>L3`0SG<j08ia>@2=L3P0SFhg08m^>02BKcT0UG0k09Ia?02FLSh0
Ug<o0080V7A000@0Ug<o09A`?02AKCT0T6`h0`2CLD4209Ab@P<0UG=3102IMD4209Yf@P<0VgM300<0
W7Q409]g@`2JMT800P2IMD400`2KMd<0WGU509mkA`0209eiA@80WWY600@0Wg]70:1lB02QODT0XGe9
202ROdT30:B0C080YH5=0`2VPTh0102ZQU80ZHEA0:V5D@2XQ5020:N3C`80YX9>0P2[QeD0102[Qe<0
ZXMA0:Z7D@2ZQdl20:V6C0@0[8MJ0P2]R5/20:j9G0040;2<G02aSEd0/HeM0;6=G@80/XiN0P2cSel0
0`2dT600/hmO0;:>GP020;6=G@090;:>GP2dT600]I5Q0;>@FP2cSe/0]91L0;B@GP2dT600]I1S0080
]I1T00<0]Y9R0;NCH`2iUFD00P2jUVH00`2iUFD0]i=S0;JBHP020;^GI`80^YIV00<0^IEU0;RDI02h
U6@0102gTf<20;RDI0<0^IEU0`2jUVH30;VEI@80^9AT202iUFD80;^GI`<0]i=S0P2hU6@30;VEI@08
0;bHJ02kUfL0^IEU0;RDI02gTf<0^9AT0;VEI@2jUVH90;VEI@<0]i9U0P2hTfH30;VDI`P0^9AT0`2k
V6820;ZGH@<0^IIP1@2gTf<30;JBHPP0^IEU202iTf@20;RCIP<0^IAW0`2jUFP80;REG`P0^9AT0P2k
UfL20;ZFIP040;VEI@2hU6@0^9AT0;NCH`P0^9=V602gTf<80;B@H0<0]8mR00<0]I1S0;JAI02gTVD0
0P2gTVD01P2fT6T0]Y5W0;JAI`2fTFD0]Y5T0;JBHP@0]Y9P00<0]I5Q0;F@H`2dSf<00P2cSV@00`2b
S6D0]Y5T0;JAI0030;F@H`040;B?HP2cSV40/hiQ0;:=H0P0]Y9R202dT6080;>?G`<0/heN00<0/XaM
0;6;G02`RU/00P2`RU/00`2eT5/0]8mJ0;:=F0020;6<E`030;:=F02dSeX0]I1K0080]i5R0P2fT640
1P2eSf00]8iO0;B>G`2cSEh0]91P0;>?G`80/XiN00D0/hmO0;FAH@2gTf<0^9AT0;F@H`020;B?HP03
0;:=H02aS5l0/8]N0080[hYM0P2aS5l0102bSF00/hiQ0;>>H@2dSf820;F@H`P0/HeM00<0[h]K0;2<
G02aSEd00P2aSEd00`2_Re/0[HUI0:b8F0080;6<H080[h]K0P2`S5`20;6=G@80/XiN00H0/8YK0;6;
G02aRe`0/XaM0;>=GP2dSUl20;F?H080/XiJ0P2aSET20;2<F080[h]G00<0/hmO0;6=G@2`S5`00P2^
RUX00`2`S5`0/HeM0;>?G`080;:>GP80/8aL00@0/HeM0;:>GP2dT600]I5Q0P2fTV820;FAH@050;B@
H02cSel0/hmO0;>?G`2bSUh00P2aSEd20;>>H@80]8mR00@0]I1S0;JAI02fTF@0]i9U0`2dSf820;>>
H@<0/XeP00D0/hiQ0;:=H02bSF00/HaO0;2;GP020:n:G@030:j9G02cSEh0/XaM0080/XaM0`2aRe`0
0`2`RU/0/XiN0;:>GP020;6=G@80/8aL0P2_Re/30;6=G@<0/XiN0P2cSel01P2bSUh0/HeM0;2<G02_
Re/0[XYJ0:f9F@80[8QH202^RUX80;2:F`80[XYJ0`2_Re/30;2<G080[hYM102^RE`20:f8F`80[XYJ
00@0[h]K0;2<G02aSEd0/XiN0P2cSel0202dT5`0/hmK0;:>FP2aSET0/8aH0:n;E`2^RUH0[HUE0P2`
RU/0102aRe`0/XaM0;:<G@2cSEh20;B>G`030;2;E`2_RUH0[hYF00@0[hYF00H0[XUE0:Z6EP2ZQUH0
ZXIF0:V5E@2XQ5@30:N3D`P0[XUE00P0/8]O0:n:GP2]R5/0ZhMG0:^7E@2[Qe<0[8QD0:f:E0T0[8QD
0P2WPdl01P2XQ500ZXIB0:^7D`2/R5@0[HUE0:j:EP@0[8QD0P2]RED20:j:EP80/HaH00@0/8]G0:n:
EP2_RUH0[XUE0P2]R5@01P2/RDl0[8UA0:b9D`2/R5H0[8MJ0:b7F`80[8IO202ZQe40202YPe@0ZXAE
0:^5EP2/QUL0[HMH0:j8F@2_REX0/8YK2P2]R5@30:b7D`<0ZhIB00<0Z8=?0:V4D02[QU800P2/Qe<0
0`2[QU80ZHA@0:R3C`080:Z4E@P0ZHA@00H0YH5=0:J2CP2VPTh0Yh=?0:R4D02YQE420:Z6DP0D0:^6
D@2ZQE00ZHA?0:R3CP2WPTd0YX5<0:F0B`2TOdX0Y7m;0:F0C02VPDd0Yh9>0:R3C`2YQ500ZXEA0:^6
DP2ZQDh0ZHA=0:N2B`2UP4T20:AoB0060:F0B@2VPDX0[H=A0:b2D02ZP4h0Z7i<0P2WOD/00`2XOT`0
ZGm=0:N2CP020:N2CP<0YX5=0P2UP4`80:N2CP030:J1C02WPTd0Z8=>0080Z8=>0P2VPD`00`2TOdX0
Xgi90:AoB`020:AoB`80YH1<0`2VPDd01P2VP5<0YX1A0:J0D@2UOdh0YH1<0:AoBP80Y7m80P2VPDd2
0:N2CP80Z8=?0P2YQ5050:9nBP030:=oB`2TP4`0YH5=0080Yh9>0P2VPDd30:F0C0H0Y7m;0`2SOTX8
0:AjB0060:1kAP2PNdL0XGa80:5kBP2RO4d0XWa?0P2RNe050:5lB0<0XWe900D0YH=C0:B2DP2QOdl0
WG];09]iB@0209YhB00309]iB@2PNdL0X7]700<0WgY60`2NNDD30:1lB080Wg]70`2NNTH01P2LMd<0
WGQ409ehA02NNDD0WgY60:1kA`80XGa80P2PNdL309mjAP<0WWU500H0XGa80:1kA`2PNdL0WgY609ii
A@2MN4@309ag@`80WGQ400<0WWU509mjAP2PNdL00P2QO4P209mjA@0609iiA02MN4<0W7M209]f@@2J
MD00VG@o0P2MN4401`2MN4<0WGQ409afA@2LMTL0VgE609]eB02NNDd00`2ONTh05@2NNDd0VgI:09Ud
B02IM4P0Ug9609YfAP2GLd<0UG5109QdA02LN4P0Wg];09eiB@2KMdL0VWA509afA`2ONDX0XG]<0:1j
B`2MMdP0VG=409I`@@0209Qg@@0609Uf@02IM3l0VW8n09Ya?@2IL3`0VVll0P2JMD4409Ud@080V7<o
00@0W7M309Ye@@2HLcl0UG0l0`2DKc/00`2EL3`0UVXm09IZ?@0209M[?P80V6`o0P2IKD000`2GLD80
UFm009A^?`0209=]?P0309A^?`2EKd00Ug520080UFm00P2FL4403@2EKd00Tfdn091Z>`2?JCX0U6m3
099]@@2@Jch0Sf/k08m[>@2@K3P0TVhj09Aa>`2>JCD00P2FLCd[ooooo`00:_ooool809Y`?PP0W790
0`2LL3l309]_?P80VVhm00P0VW4m09]b?P2MM400WWE109mf@P2NMD40WGA009ac?`80Vg4o0P2LLT00
1@2MLd40WWA209id@P2OMD<0WG500080WW9100<0X7A30:5eA02RMTD00P2SMdH0102PLSh0XG<o0:5c
?`2RM4020:=e@@80Y7I200P0WWA209ec@@2LLT00WG=109id@P2QMdD0Y7Y80:IlBPP0WgI20P2LLT00
1`2MLd40WgE30:1fA02PMT@0XGM50:9hAP2SNDL0202TNdL40:5gA@@0X7I40P2NMD4309mf@P<0X7M3
202QMdD00`2NND@0WgY50:5lA`030:=nB@030:9mB02QO4L0YWe900<0YWe9102UO4P0202QN4@0XWU5
0:=jAP2UO4P0YWe90:QoB`2YP4`0ZX5=0P2WODd0102WOD/0Z7m;0:QoB`2YP4X20:V0B0<0Ygi:0P2X
Od/30:V0C0030:ImA@2WOTH0ZH180080ZX5900h0ZH180:MnAP2VODD0ZX5=0:QoB`2WOTX0YWe90:Mn
BP2XOd/0Zh9>0:b3C`2WOTX0ZH1<0:Z1C@80Zh9>00<0ZX5=0:V0C02WOTX0202YP4`80:YoC0030:Qn
C02ZP4h0[89@0080[XAB00<0[H=A0:b2D02[PDl0102[PTh20:b3C`80[HA@102WPTh40:R3C`080:b2
D02ZP4h0ZGm=0:QnC02YOdd0ZX1>0:b2D02^Q5840:^2CP<0[8=?0P2]Q5080:j4DP<0ZhIB0P2ZQE43
0:V4D0080:Z5D@2[QU80[8MC0:f8E02/Qe<0ZXEA0:N2CP2VPDd20:b7DP040:^6D@2ZQE00ZXE@0:V4
C`80Z8=>0P2ZQE030:^6D@<0[8MB1@2[QU430:Z5D0@0[8MB0P2[QU420:Z5D0030:Z5CP2/Qe00[HQA
0080[hYC00<0[HQA0:b7D02ZQDh00`2[QU820:Z5D@<0ZHA@0`2VPD`00`2WPTd0Z8=>0:V4C`020:V4
C`<0Yh9=102VPD`01`2UP4/0Y8=>0:>2C@2SPTd0XH1;0:1oBP2OOTT00P2NODP01P2WPTh0YX5=0:J1
C@2UP4`0Y7m;0:=nBP80XWe900<0VWE009]f@@2MN4<00P2ONTD00`2MN4<0VgI109Ye@00209ad@@04
09]f@P2JMT80VWI209Qg@P80V7U3202FL44309Ea?@80U70l0`2CKc/809Ia?@0609=]?P2BK3d0TV`m
091Z>`2?JCX0SVPi0`2=IcP00`2@JCh0SVLl08aU>P0308YS>00308aU>P2=IS/0S6Hg0080S6Hg0P2;
ICH308YT=@0A08YT?@2:IC/0RF@j08UT>028HcH0R6@d08QT<P27Hc40QV8b08MS<`29ICD0RVHf08UU
=@28I3@0QF4a08AP<024Gc800`23GS42089M<080PE`_00<0PEhh081M=`1nFcD00P1mFS@0101nFcD0
P5dg085N>01lGc<207eN<P0307eL<@1mFS00OeX`0080OeP_00H0NE``07YK;`1jFbl0NeX_07]H;P1m
F2h207eF;@80NUL]0`1iER`307QE:`0307=F;01dEbd0MEP^0080MUT_00<0M5L]079E:`1`DbT00P1c
Dbd00`1aDbd0L5@]06iE;@0206eF;@0406aF;@1_CbH0L50W075A:080LU8Y00T0L50W06i>9@1]CB@0
Jdd[06a>;01]Cbd0KU0^071B<01bE3800P1cEC<2079E;@06075D;01_DRX0KU4Y06e@:01/CbL0JdhV
201WCbT206M::P80ITTY0`1UB2P00`1TAbL0IDPX06E8:00606E8:080HT/Y0P1QBRP01`1PBBL0GdPV
05m89P1NAbD0FTHS05a89@1PC2T00P1SCb`0101QCBX0GTXW05a89@1LB2D305m;9P80H4`W0`1QCBP0
201OBRl0GTT/05e8:`1LAbP0GDTX05i:9`1PC2L0HDdX201SBR/0201TAbL0ITTY06U<;01[CRh0JTd]
06M::P1SARH0H4<S0`1TCB/206E>;0<0ITl]201UCR`206E=:@80IThZ00`0Idl[06Q@;01YDBd0JE4]
06UB:01ZDbT0KEH/06iG;@1_F2h0KUL]06eF;01[E2X4079B:@@0LE4X0P1fFC4307EH<0<0M5L_0P1h
F34207UI<P<0NUXc00@0Ne/d081M<`1oG380OU/a0P1mFS000`1oG380PEhd08=P=P0207YO<P0307]N
<P1mGS80OUdb0080Oe`b00@0PE`b07eP=P1nHCL0P6<i0`22IC/2081S>@80QV@d00L0QfDe08QV=P2:
J3P0RfTi08aZ>P2=Jc/0SfXm0080Sf/k00<0T6`j091/>02AKSP00P2AKSH209A_@P0309E`@`2FLD@0
Ug950080V7=600<0VGA709Ea?@2ELCd00P2FLSh309Mc?`0609Qd@02FLT80UW9209Mc@`2HM4@0VGE5
0P2KMdL00`2LN4P0VGE509UeA@0709UeA@0309mjAP2NNDD0WGQ40080WGQ400h0WgY60:5lB02RODT0
WgY50:1kAP2QO4L0XWe80:=nB@2TOdX0YH1;0:J1C02XPdh0Yh9=0:F0B`80Xgi900<0Y7m:0:F0B`2W
PTd00P2TP4h20:F1C`<0YX9@00T0Yh=A0:F2BP2VPd/0YX==0:J2CP2WPe40Yh=C0:R4E02XPeH0102[
Qe<20:Z6DP80ZHEA1@2`ReL30;6<F0040:n;F`2`S5`0/8aL0;2<G080/HeM0P2bSUh20;>?F`<0]91L
0`2eTEd00`2eTF40]Y9R0;RDI0020;VEI@030;RDI02fTV80]I5Q00<0]i=S0P2hU6@30;VEI@<0^YIV
0`2iUFD20;RDI080^9=V0`2iU6L30;ZEJ100^IEU00@0_9QX0;^GI`2kUfL0^iMW0P2jUVH20;VEI@P0
^IAX0`2gTf<20;RDI0L0^IEU0P2hU6@30;NCH`P0^9AT0P2dSf800`2eT6<0]Y5T0;NBI@020;VDI`04
0;ZEJ02iUFD0^IEU0;VEI@80^9AT0`2gTf<80;RDI0<0]i=S0P2hU6@30;VEI@080;VDJ02jUFT0^iIZ
0;^FJP2jUFT0]i9V0;B?H`2cSV830;VEI@030;ZFIP2kUfL0_9QX0080_9QX202gTf<20;RDI0<0^IEU
0`2jUVH20;^FJ@80^YEX00@0^IAW0;RCIP2hTfH0]i9U202gUFL80;RDHPP0]i=S0P2hU6@30;NCH`<0
]Y9R102cSV420;B?HP80]I1S00H0]Y1Y0;JAI`2fTFL0]i9V0;NBI@2gTf<20;RDHP030;:=H02dSf80
]I1S0080]Y5T00<0]I1S0;B?HP2bSF00202fTV800`2dTV80/i5Q0;6?G`020;6?G`040;:@H02dTV80
]YAT0;RFIP<0]I1T0`2dSf<20;>>HP060;BAF`2dT5`0]91L0;B@GP2dT600]8mR0P2dSf<80;NAHPP0
/hiI0P2dSUl30;F?H0<0]Y1Q202eSf000`2bSUh0/hmO0;FAH@020;JBHP060;FAH@2cSel0/XiN0;6>
F02bSeT0]95K0P2eTU`00`2dTE/0/XmI0;6>F0080;>>H@P0]91P0P2cSel0102bSUh0/HeM0;2<G02_
Re/20:j:FP030:b8F02]RET0[h]K0080/8aL00<0[h]K0:f9F@2/R5P00P2_Re/20;2<G080/HeM0P2b
SUh01P2aSUP0/HeI0;6=F@2bSU`0/XiN0;:=H080/hiR0P2gTf<00`2fTV80]I5Q0;B@H0020;:>GP04
0;6=G@2aSVH0[haT0:j;H`80[8UQ00<0[X]S0:n<I02aSVH00P2_Re/00`2`S5`0/HeM0;:>GP020;B@
H0030;FAH@2bSUh0/XiN00H0/XiN00<0/hmO0;6=G@2^RUX00P2/R5P05`2]RET0/8aL0;>?G`2fTV80
/HeM0;>?G`2eTF40]Y9R0;NCH`2fTV80]91P0;>?G`2`S5`0/HeM0;>?G`2dT600]I5Q0;B@H02cSel0
/XiN0:j9G02_RUd0/HaO0080/XeP00@0/HaO0;2;GP2_RUd0/XiN0`2aSEd20;2<G080[h]K00P0/XiN
0;>?G`2dT600]91P0;>?G`2aSEd0[h]K0:j:FP80[X]E0`2_S5H30;2=E`80[hYF0`2`ReL30;6<F006
0;2<F02`S5X0/8aJ0;2<G02`Reh0/8]O0P2`Rf430:n;E`80[XYF0`2]RED02@2]RU@0[HUE0:j:EP2_
ReT0/8aL0;6<G`2aS600/XeQ0:j7G0020:n8G@030;29GP2aRUl0/HYO0080/X]P0`2`ReL00`2aS5P0
/XeI0;>>FP020;>>FP80/8aL00@0[h]K0:j:FP2^RUX0[HUI0P2/R5P20:n:G@80/8]N0`2aS5l00`2b
SF00[XYJ0:j:FP030:f9F@<0[8QH202/R5@0102_S5@0[X]C0:j;D`2]RU820:b9D@80ZhQ@00H0[HMJ
0:f7F02]QeP0[HMF0:f8E02]R5<20:f8D@<0[8MB102[QU420:Z5D080ZXIB0P2YQE40102ZQU80[HUE
0:n;E`2`S5P80:f:E0030;2;E`2_RUH0[HQD0080[8MC00T0[HQD0:n:EP2`ReL0[XQK0:j8F@2]QeP0
[HMF0:b7D`2/Qe800P2[QTl00`2/Qe<0ZhIB0:V4D0020:R3C`0;0:V4D02[QU80[8MC0:R4D02ZQU80
[8QD0:f9E@2^RUH0[HUE0:b8E02[Qe<01@2[QU840:b7D`060:f8E02^RED0[XUE0:j9E@2/Qe<0ZhIB
2@2YQ5020:Z5D@<0ZHA@0`2XPdl20:b8E080ZhMC00L0ZXIB0:V5D@2YQE40Z8A@0:J1C@2XPdl0ZXEA
0080ZhIB00<0ZXEA0:R3C`2VPDd00P2YQE420:R4D0@0Yh=?00P0YX9>0:F1C@2TP4`0Y81<0:F1C@2W
Pdl0ZXIB0:b8E080Yh=900@0YX980:F1A`2UPDL0Y8160P2SOdD30:QlB`80ZGe<0`2ZOTd00`2RODH0
Xgi70:F0B@020:N2B`060:J1BP2UP4T0Y7m80:R3CP2WPTd0YH1;0P2TOdX01P2UP4/0Yh9=0:R3CP2Z
QE00Z8=>0:J1C080Y7m:0P2UP4/00`2VPD`0Yh9=0:J0D@070:J0D@030:V5D@2WPdl0YX9>0080Y81<
00D0YX9>0:N3C`2YQE40YX5=0:N2CP030:V4D0030:R3C`2VPDd0YH1<0080Y7i?0P2SODh30:9lC@03
0:5kC02TOTl0Y7i?00H0Y7i?0P2UP4`20:AoB`@0Xgi:00P0Xgi90:9mB02PNdH0WgY509iiA02PNdH0
XGa70:=nB@<0Y7m;00<0Xgi:0:9mB@2QO4P00P2QO4P309mjAP80X7]70`2QO4P80:1kA`80YX5=00@0
YH1<0:AoB`2RODT0XGa80P2PNdL209iiA@80WgY600P0X7]70:5lB02RODT0XWe90:EoD02TOTl0XG]<
09ihB@80WGM800@0WWQ909miBP2PNTd0X7Y=0`2OND`309ihB`030:=nBP2QO4P0WgY60080WGQ400<0
WgY60:5lB02SOTX00P2RODT0102QO4P0X7]709mjAP2ONTH209iiA@P0WWQ90P2ONTH0102NNDD0WGQ4
09ag@`2LMd<209]f@P80WWa<00@0Wg];09miBP2PMdT0XGI90P2PMDP02@2QMDP0VgI209ag@`2MN4@0
WWU509ehA02KMT80V7<o09Mb?P0209Qd@00409Ue@@2JMT80VWI209]g@`80W7Q41@2HM40309Mc?`03
09Ma@P2HLT<0VG=40080VG=400<0Ug5209I`@@2DKSl0202FLT8309E_@0<0U6ho0P2CKCh00`2EL3`0
U6lk09=^>P02099]>@0;09=^>P2DKc/0UG0l09Ic?@2ELCd0U70l09=_?@2BKSh0TF`o091[?`2?JSh0
202?Jc/3095]>b_ooooo000Zooooo`P0VW0n202LLT0309a`?`<0Vfln0P2JKSd0202JL3h0Vg4o09ec
@@2NM480WgE309id@P2MLd40W7900P2KLCl209ab@00509ec@@2NM480WWA209id@P2MLD000P2NLT40
1@2OLd80XGE40:9fA@2RMTD0XgM600<0XG<o00<0XWA00:=e@@2SMD400P2TMT80202NM480WG=109ec
@@2LLT00WG=109me@`2RN4H0XgU7202OMT8209ec@@0309id@P2OMD<0X7I40080X7I40P2QMdD80:9i
A@@0X7I4102QMdD00`2PMd<0WgI209mf@P0509mf@PP0XGM500<0WWU409mjA@2QO4L00`2SOTT00`2R
ODP0XGa70:ImB@020:ImB@D0YGa80P2SNTH0102TNdL0YGa80:ImB@2WOTX20:QoB`80Yge=00@0Yge;
0:QoB`2XOd/0Z7m90P2YP4P30:MnBP80Z7m;0`2YP4`00`2VODD0Ygi60:V0B0020:Z1B@050:V0B02W
OTH0YWe50:QoB`2WOTX00`2VODT01P2XOd/0ZX5=0:^2CP2WOTX0ZH1<0:Z1C@80Zh9>00<0ZX5=0:V0
C02WOTX0202YP4`80:YoC0090:QnC02ZP4h0[89@0:f3D@2^Q580[H=A0:b2D02[PDl0ZX5=00<0Zh9>
0P2/Pdl20:f4D0@0Yh9>102XPdl00`2[PDl0ZX1>0:UoC@020:UoC@040:^1C`2]Pe40[XAB0:Z1C@<0
Zh9>0`2/Pdl20:f4D0P0[XAB0`2[QU820:Z5D@<0ZHA@00<0ZXEA0:^6DP2/Qe<00P2/Qe<0102ZQE40
Z8=?0:J1C@2/Qe820:^6D@80ZXE@0P2YQ4l00`2XPdh0ZXE@0:Z5D0030:^6D@T0[8MB0P2[QU40102]
R5<0[8MB0:b7DP2/Qe820:^6D@80ZXE@00<0ZhI?0:b7D02^RE800P2_RU<00`2^RE80[8M@0:^6C`03
0:^6DP<0ZXEA0P2YQ5020:J1C080Yh9=00@0Z8=>0:V4C`2YQ4l0ZHA?0`2XPdh00`2WPTd0YX5<0:F0
B`020:F0B`050:B3CP2SPTd0Xh9=0::1C02POdX00P2OOTT01`2NODP0YX5=0:F0C02UP4`0Y7m;0:=n
BP2RODT00P2QO4P00`2KMT40W7M209eh@`0209mjA@0309eh@`2LMd80VgI10080WGE200@0VgI209Yf
@P2KMd<0VGQ30P2HND<809Ma@P0409Ib?P2ELCd0UG4m09Ea?@80U70l0P2CKc/809Ia?@80Tfdn00@0
TV`m095[?02@JS/0SfTj0`2>J3T02@2@JCh0SVLl08eV>`2;I3T0RV<h08]T>@2<ICX0SFHk08eW>003
08aV=`80RfDf0P2:I3D01P2:I3d0RVDk08YU>`29I3P0RF@g08QT=080R6@b00P0Qf<c08QT=029ICD0
RVHf08UU=@28I3@0QV8b08EQ<@<0Q5lb0P23GS43089M<003085N>020GCL0Oe`f0080OU/e00T0Oe`f
081M=`21GSP0O5lc07iO<`1mGS80OUdb07iK<@1oFS000P20FC001P1iG300Ne``07]L<01kFRl0O5T_
07eH;P80OUL^0P1kF2h207YG;@0607UF;01hEB/0N5D[07MD:P1eEB`0MUH]0`1hF2l0101fERd0M5@[
07=C:P1eDbh207AD;P03079D;P1aEBh0KeH^0080KUL^00P0LE4X079B:@1cDbX0M5@[07=C:P1bDRT0
L50W06m?9P80K4hZ00@0KDl[06i@;01_DBd0L58^0P1aDbl2075D;004071C:`1_DRX0Ke8Z06iA:@80
KE0X201YCbX0101YC2`0J4/[06Q;:`1XBb/206M::PX0ITTY0P1TCB/00`1SC2X0HT/Y069;:@02065:
:00806199`1KAb@0GDTV061<:@1SCb`0I50]069>:`1OBbP205e99P0405m;9P1PC2L0H4`W061<9`80
HDdX0P1RCRT0201QC2l0H4/^05m::`1NBBX0Gd/Z061<:@1RCRT0HdlZ201TBb`0201UB2P0IdXZ06Y=
;@1[CRh0JTd]06Q;:`1TAbL0HTDU0`1TCB/206E>;0/0ITl]00H0IT`W06M=:01WCBP0J4hY06U?:P1Z
D2/206]A;00306YA:01[DRT0KE@[00<0KeH]00<0KE@[06aC:P1dE2/00P1dE2/507=C:P<0MEP`1@1f
FC4307UI<P80NUXc0`1kFc@00`21GS@0P5dc07iK<@0207iK<@03081M<`22GcD0Pf0f0080Nf0c00<0
O5lc07iO<`1oGS<00P20GC<02@22GC<0P64e085R=P23I3P0Q6Di08EV>P24ICT0Pf@h089S=`0208QV
=P80RFLg00D0RVPh08]Y>@2<JSX0S6Xj08mZ?@02091/?003091/>P2AKCT0TFhh0080TVlg0P2DL400
102ELD40UW9209Mc@`2HM4@209UeA@0409Ea?@2FLSh0UW8n09Ib?P80Ug<o0P2HM40209Mc@`0409Qd
A02IMDD0VWI609]gA`/0W7Q800<0X7]709mjAP2NNDD00P2MN4@00`2ONTH0XGa80:9mB@030:5lA`03
0:9mB02SOTT0Y7m:0080YH1;00T0Z8=>0:N2C@2UP4/0Y7m:0:=nB@2TOdX0YX5<0:N2C@2TP4h00`2U
PDl20:J2D080Yh=A0P2VPd/00`2VPdd0Yh=?0:N3D@020:R4E0030:R3EP2ZQU80ZXIB00H0ZhMC102`
ReL40;6<F0<0/8aL0P2aSEd30;:>GP80/hmK0`2dT5`30;FAG@030;FAH@2fTV80^9AT0080^IEU00<0
^9AT0;JBHP2eTF400`2gTf<20;RDI0<0^IEU0`2jUVH30;VEI@80^9AT0P2hTfH30;VDI`<0^YEX402i
UFD40;^GI`80^YIV0P2iUFD80;VDJ080]i=S0`2hU6@70;VEI@<0^9AT0P2gTf<80;RDI080]8mR00H0
]I1S0;JAI02gTVD0^9=V0;VDI`2jUFP30;VEI@80^9AT0`2gTf<80;RDI0<0]i=S0P2hU6@30;VEI@08
0;VDJ02jUFT0^YEY0;ZEJ@2iU6P0]i9V0;F@I02cSV820;VEI@80^YIV0P2kUfL20;bHJ0P0]i=S0P2h
U6@30;VEI@<0^YIV0P2kUVT20;ZEJ0040;VDI`2hTfH0^9=V0;RCIPP0]iEW202hU6880;NCH`80^9AT
0`2gTf<30;JBHP<0]8mR0`2eT6<20;JAI0060;NAJP2gTVP0]i9X0;NBIP2fTF@0]Y9R0P2fTV000`2b
SF00]8mR0;F@H`020;JAI0030;F@H`2dSf80/XeP00P0]Y9R00T0]99R0;>AH@2bT600/Y1P0;6?G`2b
T600/i5Q0;FCH`2gUFD00`2eT6@30;B?H`80/hiR00H0]95K0;B@G02dT5`0]91N0;B@H02dSf820;B?
H`P0]Y1Q202cSUX20;B>G`<0]HmP0`2fT6480;F?H0030;:>GP2cSel0]I5Q0080]Y9R00H0]I5Q0;>?
G`2bSUh0/HeI0;:>FP2dT5`20;FAG@030;B@G02bSUX0/HeI00P0/hiQ202dT6020;>?G`040;:>GP2a
SEd0/8aL0:n;F`80[XYJ00<0[8QH0:f9F@2_Re/00P2`S5`00`2_Re/0[HUI0:b8F0020:n;F`80/8aL
0P2aSEd20;:>GP060;6>F02aSET0/HeI0;:>G02bSUh0/XeP0P2cSV801@2gTf<0]Y9R0;JBHP2eTF40
/hmO0080/XiN00@0/HeM0;6>I02`SF<0[X]Q0P2]RV00102^Rf40/8eS0;6>I02_Re/20;2<G0050;6=
G@2cSel0]91P0;B@H02eTF40202bSUh00`2cSel0/HeM0:n;F`030:f9F@060;2<G02dT600]Y9R0;:>
GP2cSel0]I5Q0P2fTV803@2eTF40]91P0;>?G`2`S5`0/HeM0;>?G`2dT600]I5Q0;B@H02cSel0/XiN
0:n:G@2`Reh00`2bSF000`2aS5l0[hYM0:j9G0040;6=G@80/8aL0P2_Re/0202aSEd0/XiN0;>?G`2d
T600/hmO0;6=G@2_Re/0[XYJ0P2^RUH30:n;E`<0/8aH00<0/HaH0;2;E`2`ReL01@2`ReL20;2<F003
0;2<FP2`S5`0/8]N0080/8]O00@0/8]Q0:n;E`2_ReL0[h]G0P2^RUH30:f9E@080:f:E02]RED0[XYF
0:n;F@2`S5`0/HaO0;6<H02bSF430:n8G@030;29GP2aRUl0/HYO0080/X]P0`2`ReL00`2aS5P0/XeI
0;:=F@020;>>FP<0[h]K00<0[XYJ0:f9F@2]RET00P2/R5P30:n:G@80/8]N0`2aS5l20:j:FP<0[HUI
0`2/R5P80:b8E0030:n<E02^Re<0[X]C0080[HYB0P2/RE401`2[R500[HMJ0:f7F02]QeP0[HMF0:f8
E02]R5<00P2]R5430:b7DP@0ZhIA0P2ZQE020:Z6DP80ZHEA00@0ZXIB0:b8E02_ReL0/8aH202]RED0
0`2`ReL0[hYF0:f8E0020:b7D`090:f8E02_RUH0/8]G0:j8F`2^R5T0[HMH0:f7EP2/Qe<0[8MB0080
ZhI?00<0[8MC0:^6DP2YQ5000P2XPdl02`2YQ500ZhIB0:b7D`2XQ500ZXIB0:b8E02]RED0[XYF0:f9
E@2/R5@0ZhMC00H0ZhIB0P2/Qe<00`2[QU80[8MC0:f8E0020:j9E@030:b7D`2ZQE40ZHA@00P0ZHA@
0P2ZQE430:V4D0<0Z8=?00<0[8QD0:^7D`2[Qe<00P2ZQU820:V5D@040:R4D02WPTh0Z8=?0:V4D080
ZXEA00<0ZHA@0:R3C`2WPTh00P2YQE420:R4D0<0Yh=?00<0YX9>0:F1C@2UPDd00P2TP4`01@2UPDd0
Yh=?0:Z6DP2[Qe<0Yh=90080YX980P2UPDL20:B0AP030:=oA@2XOT`0Z7i<00H0Z7i<00<0XWe60:=n
A`2UP4T00P2WPT/01P2VPDX0YH190:AoB02XPdh0Yh9=0:F0B`80Y7m:00P0YH1;0:N2C@2XPdh0ZHA?
0:R3CP2VPD`0YH1;0:AoBP80YH1;00<0YX5<0:N2C@2VP5401`2VP5400`2XQ500Yh=?0:J2CP020:F1
C@060:J2CP2WPdl0Z8A@0:J1C@2WPTh0Z8=?0P2YQ5000`2XPdl0YX5=0:F0C0020:AnC`80Xge>102R
O4d80:AnC`80YH1<0P2TOd/30:=nBP040:9mB@2SOTT0XWe80:5lA`80X7]600<0XGa70:=nB@2TOdX0
0P2TOd/20:=nBP040:9mB@2QO4P0XGa80:5lB080WgY60`2PNdL30:5lB0P0X7]700H0YH1<0:AoB`2S
OTX0XWe90:5lB02PNdL209mjAP0609ehA02NNDD0WWU509mjAP2PNdL0XGa80P2RODT0102UOe00Xge>
0:5kC02ONDX209ihB@80WgU:0`2PNT/209miBP<0WWQ90P2QO4P409mjAP80XGa80P2RODT00`2QO4P0
X7]709mjAP0209iiA@0309ehA02NN4T0WWQ900H0WWQ90P2ONTH309iiA@<0WGQ400H0Wge=09ilC02P
O4`0WgU:0:1gB@2PMDP209mdA`030:1dA`2KMT80W7M300<0WGQ400<0VgI209Ud@02GLSh00`2IMD43
09Yf@P80VgM3102DL3`409Ea?@0809Ma@P2HLT<0VG=409YdA@2ILd@0V79309I`@@2DKSl809Ib@P<0
UW110`2EKd0209A^?`0309E`?02DKc/0Tfhj0080TVdi00T0Tfhj09A_>`2EL3`0UG8l09Ea?@2DL3`0
Tflm099^?P2AK3l00P2@Jcl8095]?@<0Sf/i:oooool002[ooooo202JL3h809ab@0<0W70o0`2KKch2
09Y^?@0709Y`?P2KLCl0WG=109id@P2OMD<0WWA209ec@@0409ab@0<0WG=10P2NM4801P2MLD00WW91
09ib@@2OLd80X7A30:5eA080XWI50P2OM4430:1e@P<0XGI30P2NM4801P2MLd40W79009ab@02MLd40
WWA209me@`P0WgI2202OMD<00`2PMT@0X7M30:1g@`060:1g@`0509id@P2OMD<0WgE30:1fA02QMdD0
0P2RN4H00`2SNDL0XGQ40:5hA0020:1g@`0409mf@P2NMD40WGA009ed@0P0XGM500P0WWU409mjA@2Q
O4L0XWe80:=nB@2RODP0XGa70:1kAP`0YGa8102VODT20:IlC0060:MmB`2WOTX0Z7m;0:QoB@2XOdL0
ZH180`2WOTX20:QoB`<0ZH1<00<0YWe70:MnB02XOdT00P2YP4X01@2XOdT0Ygi80:ImA`2WOTX0YWe9
0080YGa800L0YWe90:MnBP2XOd/0ZH1<0:MnBP2YP4`0ZX5=0080Zh9>00<0ZX5=0:V0C02WOTX0202Y
P4`80:YoC0050:UoC@2ZP4h0Zh5?0:b2D02]Pe400P2/PU00102[PDl0ZX5=0:Z1C@2ZPDd20:^2CP<0
[8=?102XPdl40:N2CP80Zh5?0`2ZP4h00`2[PDl0[H=A0:j4DP030:Z1C@80Zh9>102/Pdl80:j4DP<0
ZhIB0P2ZQE430:V4D080ZXEA0`2[QU800`2ZQE40ZHA@0:R3C`030:^6D@80ZXE@0`2YQ4l20:Z5D0<0
ZhIA0`2/Qe8;0:f8D`80[8MB0`2[QU400`2/Qe80[HQC0:j9E0030:j9E0040:f8D`2/Qe80[8MC0:b7
D`80ZhIB0`2ZQE40102YQ500Yh9=0:N2C@2WPTd20:R3CP<0ZHA?0P2ZQE00102YQ4l0Yh9=0:J1C02U
P4/20:AoBP060:J2CP2UPDd0YH5=0:B0C02SOd/0XWi:0P2QODT20:AoB`030:=nBP2RODT0XGa80080
X7]700@0WgY609ag@P2MN4<0WWU40P2ONTD00`2NND@0WGQ309ag@P0209if@`0409ag@`2KMd<0VgM3
09Uh@`80V7U3202HLT<0102GLcl0UW8n09Ib?P2FLSh209Ea?@80U70l202GLSh01P2DKSl0Tfdn09=]
?P2BK3d0TF/l091Z>`<0SfTj00@0T6Xm08mY?02>J3/0SFLj0P2<IST00`2=IcX0SVPk08iX>@0308eW
>080S6Hg0P2;ICH02P2;ICh0RfHl08YU>`2:ICT0RF@g08UU=@29IC<0R6@b08QT=029ICD208YV=P04
08UU=@28I3@0Qf<c08IR<P<0QF0c0P24Gc8308=N<@03089O=`21GSH0P5de0080Oe`d00T0P5de085N
=P22GcL0O5lc07iO<`1mGS80OUdb07mL<P20Fc400P21FS401P1jGC40O5da07aM<@1lFc00OEX`07iI
;`80OeP_00T0OU/a07eJ<01lFBl0NeP^07YG;@1iER`0N5D[07MD:P1gEbh00P1hF2l01@1iFC00N5P_
07MG;P1fERd0MED/0080MU@^00<0MED^07=F;P1bERh00P1`Ebh00`1_F2h0M5@[07AD:`0307IF;@03
07AD:`1bDRT0LE4X00P0KU0/1@1`Db/306mB:PP0K50[0`1[CR`306Y=:`80JD`Z201XBbT306M?:`80
IThZ0`1UCBT00`1OBB@0HD/V06A>:@0206I@:`0506E?:P1SCBP0HD/V065;9P1RC2L00`1SCBP206A>
:@80IDlZ00P0IThb06E>;`1TCBh0Hd`/06=<:P1UCbX0Ie4Z06QB:`P0IDd[00<0IdXX06Q;:@1[CR`0
0P1/Cbd00`1YC2X0IdXX06E89P0306E=:@<0IThZ0P1WCb/806Q@;00606Y>:@1[CbX0JdlZ06a@:`1]
DB`0KU8]0P1_Dbh206eA:@0306mC:`1`E2`0LED]0080L5@/00@0Ke<[07IF;@1fERd0MUH]1@1gEbh2
07EH<00407II<@1gFS80MeXb07QK<`80NE`d0P1jFS4207]K<P80O5`c0P1mGC@2085N=0<0P5dc00<0
PEhd08=P=P24HCL00P1mHSD00`1nHCD0P64e085P=@02089O=@0408AO=@21HSH0PV<g08AU>@<0QVLk
00<0QFHj08AU>@2;JCT01P2;JCT01`2<JSX0T6/n095]?@2AKCd0TFdk099^>P2BKcT00P2CL3P01P2D
L400UG5109Ea@@2FLT80Ug=309QdA080VGE50P2FLSh209Mc?`<0V7A000H0VGE109QdA02HM4@0VGE5
09YfAP2KMdL209ahB00309eiB@2PO4`0X7a<00L0X7a<00P0X7]709mjAP2NNDD0WGQ409iiA@2ONTH0
XGa80:9mB@P0Xgi90P2WPTd01P2VPD`0YH1;0:F0B`2VPD`0Yh9=0:R3CP80YH5=0P2VPTh30:N3C`06
0:R4D02WQ4`0YhA<0:N4CP2XQ500Z8AB0P2YQED01P2YQ5L0ZHEA0:Z6DP2ZQU80ZhMC0:b8E080[HUE
00@0[XYF0:n:EP2`ReL0/8]G0P2aS5P30;:=F@040;2<G02aSEd0/HeM0;6=G@80/XiN0P2cSel20;>?
F`<0]91L0`2eTEd00`2eTF40]Y9R0;NCH`020;RDI0030;NCH`2fTV80]I5Q00<0]i=S0P2hU6@30;VE
I@<0^YIV0`2iUFD20;RDI080^9=V0`2iU6L30;ZEJ0P0^IEU202jUVH30;^GI`80^YIV0`2iUFD80;VD
I`040;NCH`2hU6@0^9AT0;RDI080^IEU1@2jUVH20;VEI@<0^9AT00<0]i=S0;RDI02hU6@01P2hU6@0
1P2dSf80]I1S0;F@H`2fTF@0]i9U0;RCIP80^IAW0`2iUFD20;RDI0h0]i=S0P2hU6@30;VEI@80^IAW
0P2jUFP01@2iU6L0]i9U0;JAI02dSf80^IEU00<0^YIV0`2kUfL00`2lV6P0]i=S0;NCH`060;NCH`80
^9AT0`2iUFD30;ZFIP<0^YEX0`2iU6L20;RCIPP0]iEW202hU6@80;NCH`80^9AT0`2gTf<30;JBHP80
]I1S0`2fTF@30;NBI@060;RBJ`2hTfT0]i9X0;NBIP2fTF@0]I5Q0P2dT5h00`2bSF00]8mR0;F@H`02
0;JAI0030;F@H`2dSf80/XeP00P0]Y9R0P2cTF420;:@H0050;6?G`2bT600/i5Q0;BBHP2eTf<00`2e
T6<30;B?HP80/hiQ00H0]95K0;B@G02dT5`0]91N0;B@H02dSf820;B?H`P0]8iO202cSUX20;B>G`<0
]HmP0`2fT6480;F?H0030;>?G`2dT600]I5Q0080]Y9R00H0]I5Q0;B@H02cSel0/HeI0;:>FP2dT5`2
0;FAG@030;B@G02bSUX0/HeI00P0/hiQ202dT6020;>?G`040;:>GP2aSEd0/8aL0:n;F`80[XYJ00<0
[HUI0:j:FP2_Re/00P2`S5`00`2_Re/0[XYJ0:f9F@020:n;F`80/8aL0P2aSEd20;:>GP060;6>F02a
SET0/HeI0;:>G02bSUh0/XeP0P2cSV820;JBHP030;FAH@2dT600/hmO0080/XiN00@0/HeM0;2=H`2`
SF<0[haR0P2^Rf400`2_S680/8eS0;2=H`020;2<G0030;6=G@2bSUh0/hmO0080]91P00<0]I5Q0;:>
GP2bSUh01P2bSUh00`2cSel0/XiN0;2<G0020:j:FP040:n;F`2aSEd0]91P0;JBHP80/hmO00h0]91P
0;FAH@2eTF40]91P0;>?G`2bSUh0[h]K0;2<G02bSUh0/hmO0;B@H02cSel0/XiN0;6=G@80/HaO00H0
/XeP0;>>H@2bSF00/8]N0:j9G02]R5/30;6=G@80/8aL0`2_Re/00`2`S5`0/HeM0;>?G`020;>?G`03
0;6=G@2`S5`0[XYJ0080[XYF0`2_ReL30;2<F080/XeI0P2aS5P01@2`ReL0[hYF0:j9E@2^RED0/8eG
0080/8aH00<0/8aJ0;2<G02`Reh00P2`Rel30:n;E`80[XYF0`2]RED0202]RU@0[HUE0:j:EP2_ReT0
/8aL0;6<G`2aS600/XeQ0P2_RE`30;2:G@<0/H]N0`2`ReL20;6<F0<0/XeI00@0[h]K0:j:FP2^RUX0
[XYJ0`2]RET00`2/R5P0[XUL0:j9G0020:n:G@<0/8]N00<0/HaO0:j:FP2^RUX00`2]RET30:b8F0P0
[8QD102^ReD20:f:E080[8UC00H0[HMJ0:f7F02]QeP0[HMF0:f8E02]R5<20:f8D@<0[8MB102[QU42
0:Z5D0080:^7D`2ZQU80ZHEA0:V5D@2ZQU80[8QD0:j:EP2`S5P80:b8E0030:n:EP2^RED0[HQD0080
[8MC00T0[HQD0:j9E@2_RUH0[XQK0:j8F@2]QeP0[HMF0:b7D`2/Qe800P2[QTl20:^6DP@0ZHA@0P2[
QU80202XQ500ZXIB0:b8E02]RED0[XYF0:f9E@2/R5@0ZhMC2@2[QU801`2/Qe<0[HQD0:f8E02]R5@0
ZhIB0:Z5D@2XPdl0202YQ5020:Z5D@<0ZHA@0`2XPdl20:^7D`80ZXIB102YQE400`2WPTh0Z8=?0:V4
D0030:V4D0030:R3C`2WPTh0Z8A@0080Z8A@0P2WPdl30:J2CP80YH5=0P2TP4`0102UPDd0Yh=?0:R4
D02ZQU830:J1BP80YH190`2TOdP20:Z0CP040:UoC@2XOT`0Z7i<0:MmB`80YWa:00<0XWe80:=nB@2U
P4/00P2WPTd01P2VPD`0YH1;0:AoBP2XPdh0Yh9=0:J1C080YH1;00H0YX5<0:N2C@2XPdh0ZHA?0:R3
CP2VPD`40:F0B`80YX5<202VP5400`2XQ500Yh=?0:J2CP020:F1C@060:J2CP2WPdl0Z8A@0:F0C02V
PDd0Z8=?0P2YQ5000`2XPdl0YX5=0:F0C0030:AnC`80Xge>0`2RO4d80:=mCP<0Y7m;0P2SOTX30:9m
B@D0XWe800<0Y7m:0:J1C02WPTd00`2SOTX20:9mB@<0XGa800@0WgY60:1kA`2PNdL0X7]70P2QO4P2
0:9mB@P0X7]70P2RODT0102QO4P0X7]709mjAP2ONTH209iiA@80WGQ400<0WWU509mjAP2PNdL00P2Q
O4P01@2RODT0Y7i?0:=mCP2QNd`0X7Y;00<0WgU:00<0X7Y;0:5kC02PNT/00P2PNT/209miBP80WWQ9
00<0WWU509mjAP2QO4P00P2RODT00`2QO4P0WgY609iiA@020:5lB0030:1kA`2ONTH0WWU50080WGQ4
00<0W7M309ihB@2NN4T01P2NN4T309iiA@<0WgY60P2PNdL20:1nCP040:1lC02PNT/0X7M909mdA`80
WW=600<0WW9509]f@P2KMT800`2LMd<00`2KMT80VWE109Ud@00409Yf@P<0VGE100H0V7A0091/>02A
KCT0TFdi099^>P2CKc/309A`?00809Ma@P2HLT<0VG=409YdA@2ILd@0V79309I`@@2EKd0809Mc@`80
V7930`2GLD8309I`@@0309E`?02DKc/0Tfhj0080TVdi00@0Tfhj09A_>`2EL3`0UG8l0P2DL3`01@2C
Kcd0TVhn095/?`2AK400T6/o00P0TVhn0`2>JSX[ooooo`00:_ooool809Y`?PP0W7900`2LL3l309]_
?P80VVhm00P0VW1009]a@@2MLd<0WWA409meA@2NM4@0WG=309ab@P80W7901P2MLd4309ib@@0309mc
@P2PM4<0X7A30080XGE41P2OMD<20:1fA00409me@`2NM480WG=109ab@0@0Vg4o202NMD430:1fA0@0
WgE30P2NM48809mf@P80WWA200@0WgE30:1fA02QMdD0XWQ60P2SNDL01P2SNTH0XWU50:5hA02PMd<0
WgI209ed@080W7<o202QMdD00`2NND@0WgY50:5lA`020:9mB0030:5lA`2PNdH0WgY500@0Y7]7102U
O4P30:MnBP030:ImB@2UO4P0Y7]70080Y7]70P2VO4`0102VO4X0Ygi:0:MnBP2XOdT20:QoA`<0Ygi:
0P2XOd/30:V0C0P0Ygi:102UO4P20:ImB@050:MnBP2XOd/0Ygi:0:V0C02ZPDd00P2[PTh00`2ZPDd0
ZH1<0:MnBP080:QoB`P0ZWm<00<0ZGm=0:Z0CP2ZP4h00P2[PDl30:b2D0<0ZX5=0`2[PTh20:b3C`@0
Z8=?102WPTh50:^1C`030:b2D02]Pe40[H=A00<0ZX5=102[PTh20:b3C`P0[H=A0`2[QU820:Z5D@<0
ZHA@0`2ZQE400`2[QU80ZXEA0:Z5D@020:V4D0X0ZXE@0`2[QU430:b7DP030:f8D`2^RE@0[XUD0080
[XUD0`2_RUD30:f8D`<0[8MB0P2[QU420:f8E0@0[XUE0P2]R5@30:b7D`80ZhIB0`2ZQE440:R3CP@0
ZHA?0P2[QU401P2YQ4l0Z8=>0:J1C02UP4/0Y7m:0:=nB@<0YX5=00<0YH1<0:AoB`2TOd/0102SOTX0
0`2RODT0XGa80:1kA`0209mjAP0409iiA@2NND@0WWU409iiA080WgY50`2NND@20:1hA@0409ehA02L
N4@0W7Q409YiA080V7U3202ILd@209Qd@0<0Ug<o0`2FLSh809Mb?P<0U6ho00<0Tfdn099/?@2BK3d0
102AJc`2091Z>`0308mY>P2>J3T0SVPi0080SVPi0P2?JCX308iX>@<0SFLh00P0S6Ho08aW?@2;IS`0
RfHj08YU>02:ISH0RVHd08UU<`@0RVHf0P29ICD208QT=0@0QV4d0P25H3<208AO<P0308AQ=`23H3H0
PEhd0080P5dc00@0PEhd08=P=P24HCL0O5lc0P1nGc<00`1oGS<0P5dc089M<`02089K<P0607]N<P1m
GS80OEhb07iM<P1nFc40P5/a0P20FC002020GC<0Oe`b07iK<@1mFS00NeP^07YG;@1iER`0N5D[1@1j
FC000`1iF2l0N5L^07QG;P0207UF;P0307QG;P1gEbh0MEP^0080M5T^00T0LUX^07IF;@1gEbh0N5P_
07UI<01hF2l0MeL^07EE;01dE2/00`1`DR`00`1_DB/0KU0Z06e?:@0206e?:@0406mB:P1`Db/0L5<[
071C:`<0LE@/00<0LUD]06iB;@1^DRd02@1^DRd206eA;0<0K50[201ZCRT706Y@:`0406U?:P1RBR@0
I4`V06I>:080J50Z00@0IdlY06I>:01UCBL0IDdW0`1UCBT206I>:P<0Idl[0P1YD3801P1WCRl0Idl]
06M?:`1YDB/0Je@[06aE;0P0Idl[00<0JDdX06Y>:@1/D2/00P1]DB`00`1/D2/0JThY06Q<9`0206I<
9`80IddX0P1XCRT206U?:PP0K58]00H0K50Y06eA:P1]DBX0KU8[06mC;01`E2d2075E;P0306iB:P1_
Db/0Ke<[0080L5@/0`1aEBd307UI<0<0NUXa0P1kFc801P1eF300MUTa07MJ<P1hFc<0NE`d07]N=P80
O5lg0P1lGC4207eN<P@0OUlc1022GcD01023H3H0Q64g08AQ=`25HSP207mT=`03081S=`22HcL0Pf8g
0080Q64g00@0QV4g08AS=P25I3L0QfHi0P29J3/00`28IcX0QfHi08IU>00308i/?080SF/k0`2<JSX0
1P2BKD00TVhn099^?P2CKcd0Tflk09Aa>`80U74i0P2ELCl00`2FLT00Ug=109Qd@P0209Ue@`0309Yf
A02GLcl0Ug<o0080V7A0102IMD4209YfAP80VgM700@0W7Q809eiB@2MNDT0WGU92@2ONd/00`2PNdL0
WgY609iiA@0209iiA@040:1kA`2RODT0Xgi:0:F0B`<0Y7m:0`2SOTT00`2RODP0Yh9=0:N2C@020:J1
C080Yh9=0P2XPdh20:J3C@80YhA>102XQDl0202XQDd0ZHI>0:V6D02YQE40ZXID0:Z6EP2[QeL0ZhII
0P2YQE401`2ZQU80[8QD0:f9E@2^RUH0[h]G0;2<F02_RUH00P2`ReL00`2aS5P0/XeI0;:=F@020;>>
FP040;6=G@2bSUh0/XiN0;:>GP80/hmO0P2dT6020;>?F`<0]91L0`2eTEd00`2fTV80]i=S0;NCH`04
0;NCH`040;JBHP2gTf<0]i=S0;NCH`80^9AT0`2iUFD30;ZFIP<0^IEU0P2hU6@20;RCIP<0^IAW0`2j
UFP80;VEI@P0^YIV0P2kUfL20;ZFIP80^IEU3@2hU6@20;VEI@L0^YIV0P2iUFD;0;RDI080]I1S0P2f
TF@0102gTVD0^9=V0;RCIP2hTfH30;VEI@80^9AT3P2gTf<20;RDI0L0^IEU00@0^9AT0;NCH`2fTV80
]Y9R102jUVH40;^GI`X0^9AT0`2iUFD30;ZFIP80^YEX1P2iU6L80;NEI`P0^9=V202gTf<20;RDI0<0
]i=S0`2fTV820;JAI080]i9U102hTfH02`2iTf`0^IAZ0;RCJ@2fTFD0]I1S0;B@H02cSed0/XiL0;:=
H02dSf80]I1S0080]Y5T00<0]I1S0;B?HP2bSF00202fTV800`2cTF40/Y1P0;:@H0030;:@H0<0/i5Q
0`2eTF430;B@H080/hmO00H0/i1J0;>?F`2cSe/0/hmM0;>?G`2cSV420;>>HPP0/XaM202dSUd20;B>
G`<0]HmP0`2fT6480;F?H0<0]91P0P2eTF430;B@H0030;6=F`2bSU`0]91N0080]I5O00<0]91N0;:>
G02aSE/0202cSV4:0;>?G`040;:>GP2aSEd0/8aL0:n;F`80[XYJ2P2_Re/20;2<G080/HeM0P2bSUh0
1P2aSUP0/HeI0;6=F@2bSU`0/XiN0;:=H080/hiR0P2eTF420;B@H0040;>?G`2bSUh0/XiN0;:>GP80
/8iQ102_SF020;2>H@80/HeM0P2bSUh0102cSel0]91P0;B@H02dT6080;:>GP030;B@H02bSUh0/HeM
0080/8aL00@0/HeM0;:>GP2dT600]Y9R1@2dT6001P2cSel0/XiN0;:>GP2^RUX0[h]K0;6=G@80/hmO
00D0/XiN0;6=G@2`S5`0/HaO0;:=H0020;>>H@040;:=H02`Reh0[XUL0:b7FP80/HeM0P2`S5`20:n;
F`80[XYJ00P0[h]K0;2<G02bSUh0/hmO0;:>GP2aSEd0/8aL0:n;F`80[XYH0`2_ReT30;2<FP060;B?
F`2cSUX0/XeI0;6<F02`ReL0[XUE0P2]R5@01P2`SED0/8eG0;2=E`2`S5P0/8aJ0;2<G080/8]N0`2_
ReL20:j:EP<0[HUE00P0[HYD0:f9E@2^RUH0[h]I0;2<G02aS5l0/HaP0;:=H@H0/8YK0P2aRe`40;2;
E`@0/HaH202]RET20:f8F`80[XUL0`2_RUd00`2`Reh0[XYJ0:j:FP030:f9F@<0[8QH202/R5@60:j:
EP80[HUE00H0[XQK0:j8F@2^R5T0[XQG0:j9E@2^RE@20:j9DP<0[8MB102[QU420:Z5D0080:b8E02[
Qe<0ZXIB0:V5D@2ZQU80[8QD0:j:EP2_ReL80:b8EP<0[XUE0P2]R5@30:j9E@060:j8F`2^R5T0[HMH
0:f7EP2/Qe<0[8MB0P2[QTl80:Z5D@080:R4D02ZQU80[8QD0:f9E@2^RUH0[HUE0:b8E02[Qe<30:b7
D`@0ZhIB0P2ZQE401`2[QU80[8MC0:f8E02/Qe<0ZhIB0:V4D02WPTh0202YQ5020:Z5D@<0ZHA@0`2X
Pdl20:Z6DPH0ZHEA00<0Yh9>0:R3C`2XPdl0102XPdl00`2WPTh0Z8A@0:R4D0030:N3C`<0YX9>0`2T
P4`20:F1C@030:J2CP2WPdl0Z8A@00P0YH1;0P2ZPTl0102YPDh0Z81=0:InB`2UODX20:AlB@030:9m
B@2SOTX0YH1<0080Yh9>00@0YX5=0:F0C02TOd/0Yh9=1P2VPD`0102WPTd0Z8=>0:N2C@2WPTd20:J1
C0@0YH1;202UOe020:N3C`@0YX9>0P2WPdl00`2TOd/0YH1<0:N2CP030:R3C`80YX5=0P2UOe020:An
C`80Xge>0P2RO4d80:=mCP80Y7m;0`2SOTX30:9mB@80XWe80P2SOTT0102TOdX0YX5<0:N2C@2WPTd4
0:9mB@@0XGa80`2PNdL20:5lB0<0XWe92P2PNdL209mjAP80WWU5102MN4@0102NNDD0WgY609mjAP2P
NdL20:5lB080Xge>00<0XWa=0:5kC02PNT/00`2PNT/20:5kBP<0X7Y90`2ONDP00`2LMd<0WWU50:9m
B@020:AoB`030:9mB@2NNDD0W7M30080X7]700@0WgY609iiA@2MN4@0WGQ40P2LMd<809ihB@0509eh
A02NNDD0WWU509mjAP2PNdL00P2QO4P01`2RODT0XGm?0:1nCP2QODd0X7Y;0:1gB@2OM4L00P2MLTD0
1@2NLTD0VgI209]f@P2KMT80W7M30080VgI20P2JMD4209]g@`0409Yf@P2IMD40VGE109Qd@080Ug<o
0P2BKSX00`2CKc/0U70l09Ea?@0209Ib?P0309Mc?`2HLT<0VG=400<0VWA500<0V79309I`@@2EKd00
202GLd<209UcA0<0V7930`2GLD800`2EL3`0U6lk09=^>P02099]>@0909=^>P2DKc/0UG0l09Aa>`2D
L3`0Tflk09=_?@2BKSh0TVe00080TFa0202CKcl3091[?R_ooooo000Zooooo`P0VW0n202LLT0309a`
?`<0Vfln0P2JKSd0202JKd80Vg1309ebA@2NLdH0WgA709icAP2MLTD0W7541P2MLd4209ab@0<0WW91
102OLd800`2PM4<0WgM609mgAP0609ifA@<0WWA200D0WG=109ab@02KLCl0VW0n09U_?@0809ie@@<0
X7I4102OMD<209id@PP0WWE10`2OMD<00`2PMT@0XGM50:9hAP020:9hAP060:=jAP2RNDD0XGQ40:1g
@`2OMT80WGA00P2LLcl80:5gA@0909iiA02ONTD0XGa70:9mB02QO4L0X7]609mjA@2NND@0XWU50080
XgY60P2TNdL20:ElB0070:ImB@2XOd/0Z7m;0:MnBP2VODT0YGa80:AkA`020:=jAP80YG];00@0YWa:
0:ImB@2WOTX0Ygi80P2XOdL30:MnBP80Z7m;0`2YP4`20:MnBP@0YWe90P2WOTX20:ElB0030:ImB@2W
OTX0Ygi:00@0Ygi:00L0ZH1<0:Z1C@2[PTh0Zh9>0:Z1C@2YP4`0Ygi:00P0Z7m;202ZOd`30:UoC@80
ZX1>0P2[PDl00`2/PU00ZH1<0:V0C0030:Z1C@<0Zh9>0P2YQ5020:R3C`80Yh9>0P2VPDd0102ZP4h0
Zh5?0:^1C`2/PU040:f3D@80ZH1<0`2ZPDd40:^2CPP0[H=A0`2[QU820:Z5D@<0ZHA@0`2ZQE400`2Y
Q500ZXEA0:Z5D@020:^6DPX0ZXE@0`2[QU430:b7DP<0[HQC00<0[XUD0:n:E@2_RUD00P2`ReH20:j9
E0<0[HQC0`2/Qe880:j8E`80[HQD0P2/Qe<20:^6DP80ZXEA202YQ4l01P2[QU40ZXE@0:V4C`2XPdh0
Yh9=0:J1C080YH1;0`2XP4d40:MoC0060:InB`2SOTX0Xgi:0:9mB@2QO4P0X7]70P2ONTH00`2NNDD0
X7]609mjA@0509mjA@040:1kAP2RNTL0XGU609mjAP80WGU500<0VWU409UjA02HND<0202JM4D309Ue
@@<0V7A00P2GLcl809Qc?`<0UFm01@2DKSl00`2CKCh0TF/j095[>P03095[>P03091Z>@2?JCP0SfTh
00<0T6Xk0`2?JCX208iX>@0608eW@02<Icd0S6Lm08aW>`2;IST0RfLg0P2:IS@00`2<J3P0RfLg08]W
=`0208YV=P<0RFDe0P28HcH208MR=@@0QV4d00<0QF<f08AR=@23HC@00P22H3<01023HC@0Q68e08ES
=P1lGc<207iO<`03081O=021GS@0Pehd0080Q5dd00H0OF0d07mP=01nGc<0Oehc07mL<P21G382089K
<P80P5dc00<0Oe`b07iK<@1mFS000P1kF2h00`1jEbd0OU/c07eJ<P0207aI<@@0NeP`0P1mF2h00`1k
F2h0NUT^07UJ;P0207MJ;P0407IK;P1gEbh0N5P_07UI<080NUXa00P0N5P_07IF;@1eEB`0LeH^079E
;@1aE2`0L5<[06mB:P80KU4Y00<0KE0X071C:`1aE2`00P1aE2`3079E;@0307=F;P1aDbl0LE<_00H0
LE<_0`1`E2d206mC;0<0KU8[201/D2T206eA:PH0KU8[00<0ITdU06M>9P1YD2P00`1ZDBT306U@:080
IddZ0P1XCR/306U?;00906Y@;@1/DC<0Je0b06Y@;`1ZD2d0JU0[06aC:`1^EB`0KeH]00P0JE4]00<0
K50Y06eA:P1^DR/00P1_Db`00`1^DR/0KE4Z06eA:P0206Y>9`80JdlX0`1/D2T00`1]DBX0L5@]071D
;@06071D;@80L5<[00<0LE@/079E;@1cERh00P1dEbl00`1eF300LUD]079E;@03079E;@0307=F;P1d
Ebl0M5L_00<0Ne/b00<0O5`c07eM=01mGC@00P1nGSD01P1gFS80N5/c07UL=01jGCD0Nehf07eP>080
OV4i0P1nGc4307mP<P<0P64c00@0Pf0f08AQ=`24HCL0QF8h1026HcT2085V>@03089U>@24ICT0QF@i
0080QV<i00@0R6<i08MU=`28ISP0RVPj0P2<JS`00`2;JC/0RVPj08UW>@03091^?P80Sfdm0`2>K3`0
2@2CKT40Tflo09A`@02DL3h0UG4m09Eb?02ELSX0UW<k09Ea?@0209Ib?P0309Mc?`2HM400VGE10080
VWI20P2HM40309Ue@@<0VWI200<0W7Q809eiB@2MNDT00P2MNDT309ijBPT0W7Q800P0XGa80:1kA`2O
NTH0WWU509mjAP2PNdL0XWe90:=nBP<0YH1;0P2TOdX30:=nB@80YX5<00<0Yh9=0:R3CP2YQ4l00`2Y
Q4l20:N4CP<0Z8E?0`2YQU020:Z7C`030:Z7D@2[Qe<0ZhME0080[8QH00T0[8MJ0:Z6DP2ZQU80ZhMC
0:f9E@2^RUH0[h]G0;2<F02aSET00P2_RUH01P2`ReL0/HaH0;:=F@2cSUX0]8mK0;F@G080/XiN0P2c
Sel30;B@H0030;FAH@2cSe/0/hmK00<0]91L0`2eTEd30;NCH`80]Y9R1P2gTf<20;RDI0<0^IEU0`2j
UVH30;VEI@80^9AT0P2hTfH30;VDI`<0^YEX202iUFD80;^GI`<0^YIV0P2iUFD30;RDI0P0^9AR0P2h
U6@20;VEI@80^YIV1@2kUfL20;ZFIP80^IEU2P2hU6@30;JAI0@0]i9U00@0^9=V0;VEI@2iUFD0^IEU
0P2hU6@>0;NCH`80^9AT0`2iUFD20;VEH`80^9AR0`2gTf400`2hU680^iMW0;^GI`020;^GI`@0^YIV
2P2hU6@30;VEI@<0^YIV1P2iU6L20;ZEJ0P0]iEW202hTfL80;NCH`80^9AT0`2gTf<30;JBHP80]Y5T
0P2gTVD40;RCIP060;VCK02hTfT0]i9X0;JAI@2eT6<0/hmO0P2bSU`00`2bSF00]8mR0;F@H`020;JA
I0030;F@H`2dSf80/XeP00P0]Y9R102bT6000`2cTF40/Y1P0;:@H0020;6?G`<0]I5O0`2dT5h20;>?
G@060;>@FP2cSe/0/hmK0;>?G@2cSel0/hiQ0P2cSV880;:<G@X0]8iO0`2eSf030;J@H@P0]HmP00<0
]I5Q0;B@H02dT600102dT600102eTF40/HeM0;:>GP2dT6020;FAH@030;B@H02bSUh0/HeM00P0/hiQ
2P2cSel0102bSUh0/HeM0;2<G02_Re/20:j:FP80/8aL102_Re/20;2<G080[h]K0P2`S5`20;6=G@80
/XiN00H0/HiH0;6=F@2aSET0/XiL0;:>GP2bSF020;>>HP030;B@H02cSel0/hmO0080/hmO0`2bSUh8
0;2>H0030;:>GP2cSel0/hmO0080/hmO0`2dT6080;:>GP030;B@H02cSel0/XiN00<0/XiN00D0]91P
0;FAH@2fTV80]I5Q0;B@H0020;>?G`@0/XiN00<0[HUI0:j:FP2`S5`00P2bSUh00`2aSEd0/8aL0:n;
F`020;6<G`060;:=H02cSV40/XeP0;2;GP2^RE`0[HQK0`2`S5`20:n;F`@0[XYJ00L0[h]K0;6=G@2b
SUh0/XiN0;6=G@2`S5`0[h]K0080[XYJ0`2_Re/30;2<G0060;B?F`2cSUX0/XeI0;6<F02`ReL0[XUE
0P2]R5@01P2_S580[haD0:n<EP2_S5H0[h]G0:n;F@80[h]K0`2_ReL20:j:EP<0[HUE00P0[HYD0:f9
E@2^RUH0[h]I0;2<G02aS5l0/HaP0;:=H@80/H]J1P2`RUT80;2;E`@0[8QH102]RET0102/QeX0[HQK
0:f8F`2]R5/20:j9G080[hYM0P2^RUX30:f9F@<0[8QH202/R5@60:j:F080[h]I00H0[XQK0:j8F@2^
R5T0[XQG0:j9E@2^RE@20:j9DP<0[8MB102[QU420:Z5D080[8QD0`2ZQU800`2[Qe<0[HUE0:j:EP08
0:^7E`030:f8E02^RED0[XUE00@0[XUE00L0[HQD0:j8F`2^R5T0[HMH0:f7EP2/Qe<0[8MB0080ZhI?
202ZQE40202XQ500ZXIB0:b8E02]RED0[XYF0:f9E@2/R5@0ZhMC0P2]R5@20:b7D`0<0:^6DP2ZQE40
ZXEA0:Z5D@2YQ500ZXEA0:^6DP2/Qe<0ZhIB0:Z5D@2XPdl0Yh9>202YQ5020:Z5D@<0ZHA@0`2XPdl2
0:R4D0H0ZHEA00<0Z8=?0:N2CP2WPTh0102WPTh0102XPdl0Yh=?0:N3C`2WPdl30:J2CP80YH5=0P2T
P4`20:F1C@<0YX9>00<0YH5=0:F0B`2UP4/01P2UP4/20:R3C`040:N2CP2VPDd0Y7m;0:=nBP80XWe9
00<0XWa;0:=mC02UOdh00P2WPE000`2VP4l0YGm>0:AnC@030:J1C080Yh9=0`2VPD`40:N2C@<0YX5<
0P2UP4/80:EoD080YX9>102WPdl20:J2CP040:=nBP2TOd/0YX5=0:N2CP80Z8=?00<0Yh9>0:J1C@2U
Oe000P2UOe020:AnC`<0Xge>202RO4d30:=nBP<0XWe90P2QO4P01@2RODP0Xgi90:=nB@2TOdX0YH1;
00<0YX5<202QO4P20:1kA`80XGa80P2RODT20:=nBPP0X7]70P2ONTH409iiA@80WGQ40P2LMd<0102M
N4@0WWU509mjAP2PNdL20:5lB0D0XWa=0P2QNd`0102PNT/0XGa80:5lB02QO4P30:1kA`80WgY600<0
VgI209iiA@2RODT00P2UP4`00`2RODT0WWU509]f@P0209mjAP80WWU500@0WGQ409ag@`2KMT80VgI2
202NN4T209ehA00409iiA@2ONTH0X7]70:1kA`80XGa800H0X7i>09mmC@2PO4`0X7Y;0:1gB@2OM4L2
09icAP0509ibA@2KMT80VgI209]f@P2JMD400P2KMT8209ag@`0509]g@`2JMT80VWI209Ue@@2HM400
0P2GLcl209Ib?P80Ug<o00<0V7A009Ue@@2IMD400P2JMT80202HLT<0VG=409YdA@2KMDH0VWA509Uc
A02GLD80UW11202HM4@209UcA0<0V7930`2GLD800`2EL3`0U6lk09=^>P02099]>@0409=^>P2DKc/0
UG0l09=`>P80Tflk00<0Tflm099^?P2BKD000P2BKD4809=_?`<0U6m3:oooool002[ooooo202JL3h8
09ab@0<0W70o0`2KKch209Y^?@0809Y_A02KL4D0WG9709icB02OM4T0WW=809ebA`2LLDH209id@P<0
WG=10`2LLT0809ib@@<0WGM80`2LMTL209]eAP80WWA20P2OMD<0102NM480WG=109]a?`2JL3h809ed
@0P0WgE300<0X7I409mf@P2OMT801P2OMT840:5gA@@0X7I40P2QN4@20:1g@`0409mf@P2NMD40WGA0
09ed@0P0XGM50P2ONTD30:5lA`0409mjA@2NND@0W7M20:5hA080XWU500<0XgY60:AkA`2UO4P00P2V
ODT01@2XOd/0Ygi:0:MnBP2VODT0YGa80080Y7]700@0XgY60:EkB`2UNd/0YG]90P2VODT00`2WOTP0
Ygi60:MnAP030:MnBP80Z7m;0`2YP4`20:MmB`040:IlBP2UNdT0YG]90:IlBP80Yge;00<0YGa80:Im
B@2XOd/00`2YP4`20:QoB`030:MnBP2YP4`0ZX5=0080Zh9>00<0ZX5=0:V0C02WOTX0202WOTX80:Yo
C0080:Z0CP2YOdd0ZGm=0:QnC02YOdd0ZX1>0:^1C`2/PU030:V0C080ZX5=0`2[PTh01@2ZQE40ZHA@
0:V4D02XPdl0Yh9>0080YX5=00D0YH1<0:Z0CP2[PDl0[89@0:f3D@020:j4DP030:f3D@2/PU00ZH1<
0080ZH1<0P2ZPDd40:^2CPP0[89@0`2[QU820:Z5D@<0ZHA@0P2ZQE430:V4D0030:Z5D@2[QU80[8MC
00<0ZHA?0P2ZQE030:^6D@80ZXE@0`2[QU430:b7DP80ZhIA00<0[8MB0:f8D`2^RE@00P2_RUD0102`
ReH0[XUD0:j9E02^RE@20:f8D`<0[8MB00<0/8YK0:n9FP2^R5T00P2]QeP00`2^R5T0[hUJ0;2:F`03
0:f8E080[8MC0`2[QU80102[QU40ZXE@0:Z5D02ZQE030:V4C`040:R3CP2YQ4l0ZHA?0:V4C`<0Z8=>
0P2WPTd80:UoC@80Y7m;00<0Xgi:0:9mB@2QO4P00P2PNdL0102ONTH0XGa70:5lA`2PNdH209mjA@03
0:1kAP2QO4L0XGa70080Xg]800@0X7]709ijAP2MNDD0VgY50P2INT@809afA`80VgM30P2JMT8309Ue
@@0309Qd@02HLcl0V7<o00H0V7<o1@2FL44409E_@080TVdi0`2CKSX00`2BKCT0T6/g08mZ=P02099/
?@80TF/l0`2@JS/01`2?JCX0SVQ108eX?P2=J3h0SFPl08aW>P2<J3P00P2;IcD00`2>JSX0SFTi08]W
=`0308YV=P80RfLg0`29I3L208QS=P<0Qf8e00<0QfDg08IT=P24HS@00P23HC<01024HS@0QV@f08MU
=`1mH3@207mP=003081O=022GcD0Q5le0080QUlf00H0OV4e081Q=@20HCD0P5ld085N=022GC<208=L
<`04081M<`1oG380Oe`b07mL<P<0OU/a00@0OEX`089L=@21Fc@0OeTb0`1nF34207mI<P80P5T`00<0
OeX`07eJ<01lFc000P1kG3000`1iG300N5P_07UI<00307YJ<@0307QH;`1gEbh0MED/0080M5L]0P1c
ER`0101bEB/0LE@Z075D:P1`DbT307=F;PD0LUD]201eE342075E;@<0L5@/0`1_Db/806iB:P0406iA
:@1_DRX0Ke8Z06mB:P<0L5<[00@0LE@/06]?9`1[CbL0K50X1P1]DBT306]>;080K4l]0`1]D2h0201_
DS80KU4a06e@;P1/D2/0KE4Z06iB:P1`E2`0LUL/201[Dbd00`1^DRX0Ke<[06mC:`02071D;003075E
;@1`E2`0L5@/0080KU4Y0`1_DRX3071C:`P0LeH^0P1dE2/00`1eEB`0MUH]07MG;P0207QH;`0307UI
<01hF340MeL`00<0MUH_00<0N5Pa07UI<P1jFS<00P1kFc800`1lG3<0OEdd07iN=@0207mO=P06081P
=`1jGCD0Nehf07]N=P1lGcL0OF0h0P1nHCT0101oHSX0P64b081Q<P20HC82085R<`<0PV<d00<0Q64g
08ER>027I3X00`28IC/208MT>P80Q6Tl00<0QFPl08MX?028Ic`00P29IS`02P2;IS`0RfLg08aX>02>
JSX0Sf/k091/?02?Jc/0SVXj08eY>@2@KSh7095_?`0609E`@`2ELD40UG5109Ib@02FLSh0Ug@n0P2G
M3`209Ic?@0309Md?P2HMCl0VGI00080VWM100@0VgQ209Ue@@2IMD40VGE10P2JMT8309]g@`<0WWY:
1@2ONd/909ahB0030:5lB02PNdL0WgY60080WgY600<0XGa80:9mB@2TOd/01@2TOdX40:F0B`030:J1
C02XPdh0ZXE@0080ZhIA0P2ZQE030:R5C@80ZHI>0`2ZQdl20:^8D0030:b9D`2/R5@0[HUG0080[HUI
00D0[XUL0:b8E02/R5@0[HUE0:j:EP020:n;E`80/8aH0P2_RUH01P2`ReL0/HaH0;>>FP2dSe/0]I1L
0;JAG@80/hmO0P2dT6030;FAH@030;JBHP2cSe/0/hmK00<0]91L0`2eTEd00`2hU6@0]i=S0;JBHP02
0;FAH@030;JBHP2gTf<0^9AT00<0]i=S0P2hU6@30;VEI@<0^YIV0`2iUFD20;RDI080^9=V0`2iU6L3
0;ZEJ0P0^IEU202kUfL20;ZFIP80^IEU0`2hU6@00`2gTf<0]i=O0;NCG`060;NCG`<0^IEU0P2jUVH7
0;^GI`80^YIV0`2iUFD80;RDI0P0]i9U0`2iUFD20;RDI0<0]i=S202fTV830;NCH`80^9AT0`2iUFD2
0;VEH@070;RDH02gTel0]i=O0;NCG`2hU600^IEQ0;bHJ0030;^GI`<0^YIV2@2iUFD20;RDI0<0^IEU
0`2jUVH20;RCIP<0^IAW0`2jUFP80;NEI`P0^9=Y202gTf<20;RDI0<0]i=S0`2fTV820;F@H`<0]Y5T
0`2gTVD01P2gTFX0]i9X0;JAI`2eT6@0]8mR0;B@H080/hmM00<0/XeP0;B?HP2eT6<00P2fTF@00`2e
T6<0]8mR0;:=H0080;JBHP030;6?G`2bT600/i5Q00<0/i5Q00<0/HmO0;2>GP2_SEd00`2eTEd30;B@
G080/hmK00H0/XmI0;:>FP2bSUX0/XiL0;:>GP2bSF020;:=H@P0/heN202eSf820;B>G`<0]HmP0`2f
T6480;F?H0030;JBHP2eTF40]91P0080/hmO00H0]91P0;FAH@2fTV80/HaO0;:=H02dSf820;F@H`03
0;B?HP2bSF00/HaO00P0/hiQ202bSUh20;>?G`040;:>GP2aSEd0/8aL0:n;F`80[XYJ00<0/HeM0;2<
G02_Re/00`2_Re/0102`S5`0/HeM0:n;F`2_Re/20;2<G080/HeM0P2bSUh01P2aSUP0/HeI0;6=F@2b
SU`0/XiN0;:=H080/hiR202bSUh00`2_SEd0/8iN0;6?G`020;:@H0030;6?G`2`SUh0[heM00P0]91P
202bSUh20;B@H0050;>?G`2dT600]91P0;B@H02eTF400`2fTV801@2eTF40/hmO0;:>GP2aSEd0/8aL
0080/HeM00<0[8QH0:f9F@2_Re/00`2aSEd20:n;F`030:n:G@2`Reh0/HaO0080/XeP00<0/HaO0;2;
GP2_RUd00P2`S5`20:n;F`<0[XYJ0P2]RET01`2^RUX0/8aL0;6=G@2bSUh0/HeM0;2<G02_Re/00P2^
RE`30:n:G@<0/8]N0P2bSET20;6<F0040;2;E`2_RUH0[XUE0:j9E@80[haB00@0[haD0:n<EP2_S5H0
[h]G0P2_ReT30:n;E`80[XYF0`2]RED0202]RU@0[HUE0:j:EP2_ReT0/8aL0;6<G`2aS600/XeQ0`2a
S5P30;2;E`80[hYF00@0/HaH0;2;E`2`ReL0/8]G0`2_RUH0102^RED0ZhMG0:^7E`2[QeL20:b8F0<0
[HUI00@0ZhII0:b7FP2/QeX0[8MJ0P2]R5/20:j9G080[XYJ0`2]RET30:b8F0P0[8QD102^RUX20:n;
F`80/8aL00H0[XQK0:j8F@2^R5T0[XQG0:j9E@2^RE@20:j9DP<0[8MB102[QU420:Z5D0030:f9E@2/
R5@0ZhMC0080ZXIB00<0ZhMC0:b8E02]RED0202[QUT00`2/Qe<0[HQD0:j9E@020:n:EP090:j9E@2]
R5@0[8MC0:j8F`2^R5T0[HMH0:f7EP2/Qe<0[8MB0080ZhI?0P2YQ5040:^6DP80ZHA@00T0Z8A@0:Z6
DP2/R5@0[HUE0:j:EP2]RED0[8QD0:^7D`2^RED00P2]R5@00`2/Qe<0ZhIB0:Z5D@020:V4D0080:R3
C`2YQ500ZXEA0:^6DP2ZQE40ZHA@0:N2CP2VPDd80:V4D080ZXEA0`2YQ5030:R3C`80Yh=?0P2XQ504
0:V5D@030:R3C`2WPTh0YX5=00<0YX5=00<0Yh9>0:R3C`2WPdl00P2WPdl20:J2CP<0YH5=00<0Xgm;
0:B0C02UPDd00P2VPTh00`2UPDd0Y81<0:=oB`030:AoB`80YH1<0`2VPDd20:J2CP040:F1C@2TP4`0
Y81<0:=oB`80XWi:00<0XWa=0:=mCP2UOe000P2WPE801P2VP540YGm@0:AnC`2UP4/0YX5<0:N2C@80
Z8=>00@0Yh9=0:J1C02UP4/0YX5<0P2WPTd01P2XPdh0Yh9=0:J1C02VPD`0YH1;0:AoBPP0Y7i?00<0
YH5=0:J2CP2WPdl00P2XQ5001`2WPdl0YX9>0:F1C@2QO4P0Xgi:0:F0C02WPTh00P2XPdl00`2WPTh0
YX5=0:J0D@030:EoD080Y7i?0P2SODh80:9lC@<0Xgi:0P2RODT30:5lB0040:9mB02SOTT0Y7m:0:F0
B`80Y7m:00<0Xgi90:9mB02ONTH00`2PNdL30:5lB0040:9mB@2QO4P0XGa80:5lB080XWe90`2SOTX8
0:1kA`D0WgY60`2NNDD209ag@`0409ehA02NNDD0WgY609mjAP80X7]700<0XG]<0:9lC@2SODh00P2S
ODh00`2RO4d0XG]<0:5kC0020:9mB080XGa70`2PNdH0102ONTD0W7M309iiA@2RODT20:AoB`040:9m
B@2NNDD0W7M309mjAP80WWU500<0WGQ409ag@`2KMT800P2JMD4809ihB@@0WGQ40`2NNDD01P2ONTH0
WWa<09ilC02ONd/0WgU:0:1gB@<0X7E800<0X7A709]f@P2KMT800`2JMD400`2KMT80W7M309ehA003
09Ue@@<0V7A00P2GLcl809Yf@P80VG=40`2KMDH00`2ILd@0Ug5209I`@@0809QdA080V7930`2GLD83
09I`@@0309E`?02DKc/0Tfhj0080TVdi00@0Tfhj09A_>`2EL3`0Tg0j0P2CKc/00`2CKcd0TVhn099]
@002099]@@P0TVhn0`2DKdD[ooooo`00:_ooool809Y`?PP0W7900`2LL3l309]_?P80VVhm00P0VVm5
09]`AP2MLTP0WW=909mdBP2NLdT0WG9809aaA`<0WWA200<0WG=109ab@02LLT000P2KLCl809ib@@80
WWQ90P2MMdP01`2LMTL0VgE609]eAP2KMDH0WWA209me@`2PMT@00P2QMdD00`2OMD<0WG=109ab@008
09ed@080WG=100<0WWA209me@`2PMT@00P2PMT@20:5gA@P0X7M30P2SNDL0102RN4H0XGM50:1fA02O
MD<209id@P030:1g@`2OMT80WgI200D0WgI2202QMdD03P2ONTD0X7]60:5lA`2QO4L0X7]609mjA@2M
N4<0W7M20:1g@`2QN4@0XWU50:=jAP2TNdL0YGa81P2VODT40:ElB080YG];00@0YG]90:ElB02VODT0
YWe70P2WOTH30:MnBP80Z7m;0`2YP4`00`2XOTh0Yge=0:EkB`020:AjBP0>0:EkB`2WODd0Z7i>0:Mn
BP2XOd/0ZX5=0:^2CP2/Pdl0Zh9>0:Z1C@2YP4`0Ygi:0:V0C02ZPDd20:^2CP030:Z1C@2YP4`0Ygi:
00P0Ygi:202ZOd`0202ZP4h0ZGm=0:QnC02WOD/0Z7i<0:UoC@2[PDl0[H=A0P2XOd/20:V0C0<0ZX5=
00L0Zh9>0:Z5D@2ZQE40ZHA@0:R3C`2WPTh0YX5=0080YH1<00P0ZX1>0:^1C`2]Pe40[XAB0:n5D`2^
Q580[H=A0:b2D080Z7m;0P2YP4`40:Z1C@030:^2CP2/PU00[89@00H0[89@0`2[QU820:Z5D@<0ZHA@
00<0ZXEA0:V4D02XPdl00P2XPdl0102ZQE40[8MC0:j9E@2XPdh20:V4C`80ZXE@0P2[QU400`2/Qe80
ZXE@0:Z5D0030:^6D@<0[8MB0P2YQ4l01@2ZQE00ZhIA0:b7DP2]R5<0[XUD00<0[hYE0P2^RE@30:f8
D`040:b7DP2aRe`0/8YK0:j8F@80[HMH00<0[XQI0;2:F`2aRe`0102]R5@20:b7D`80ZhIB0`2[QU40
0`2ZQE00ZHA?0:V4C`020:R3CP80Yh9=0P2XPdh20:V4C`80ZXE@202YOdd01P2VPDd0YH1<0:F0C02T
Od/0Xgi:0:9mB@80XGa800<0Xgi90:9mB02PNdH00P2ONTD00`2PNdH0XWe80:=nB@020:AlB@040:5l
B02ONdL0WWY609]jA@80VGY4202MMdP209ahA080VgM30`2JMT800`2IMD40V7<o09Qc?`0609Qc?`<0
UW111P2GLD800`2BKCT0Tfhj09A_>`0209E`?00309=^>P2AK3P0T6/g0080Tfdn0P2BK3d3095[?007
091Z>`2>J440SVTo08iY?`2=J3`0SFPk08aX>00208aX=P0308m[>`2>JSX0S6Ph00<0RVHf00<0S6Ph
08eY>@2:ICP00P2:ICP208UT=`<0R6<f00<0R6Hf08MU=@25Hc<00P24HS801025Hc<0QfDe08QV=P1m
H3@207mP=003085P=@23H3H0QF0f0080Qf0g00H0Of8f085R=P21HSH0PF0e089O=@23GS@208AM=080
OU/a0P1oG382081M<`80PEhd00T0Q5df08=L=@21FS<0P5Tb07mH<@20FC80PEXc089K=023FBl00P21
FRl00`20Fbl0OU`_07eL;`0207aM;`0907MG;P1hF2l0NET`07YJ<@1iFC00N5P_07IF;@1eEB`0MUT]
00@0MEP/0`1dEb/207EH<00407AG;`1cERh0LeH^079E;@80LE@/201gEC82075E;@80L5@/0`1_Db/0
0`1^DRX0L5@/071D;006071D;0<0L50Y00<0LE4Z079B:`1bDR/00P1cDb`306eA:@80KU8Z101_Db/3
06a?;@80KE0^0`1^DBl0201_DS00KU4_06eA;01/D2T0KE4Y06iB:P1`EBX0LEH[201/EB`3071D;003
075E;@1bERh0LUH^0080LeL_0`1cDb`207AD;@<0MED^201gEc0207MF:`0307QG;01iF2d0NUT^0080
NeX_00T0O5/`07aJ=01kFC<0NUPb07UG<@1jF380NeTc07eK=@1oGCL00P1kFc801P1lG3<0OEdd07iN
=@1oGcH0P60g085Q>0P0OV4i0P21Hc42089T<P<0PfDc00@0Q6Hd08ER>026HcT0R6Dk0`2:Icd01`28
IC/0Qf@j08EZ?@25JSd0QVTm08QY?@29J3d00P2:Icd0102<Icd0SFLf08iX=`2@JST3099/>`80T6Xi
0P2@KSh0102AKcl0TW1009=a@@2CLD4209Ab@P0609IaA02FLT80UW9209Mc@@2GLcl0V7Do0P2HMCd2
09Ic>`0409Md?02HMCd0VGHn09Yg?`80VgQ00`2JMT8209]g@`<0W7Q41@2PO4`<09mkB`030:9mB@2Q
O4P0X7]70080WgY600<0XGa80:=nBP2TOd/00P2SOTT20:AoBP080:F0B`2VPD`0Yh9=0:N2C@2UP4/0
YX5<0:V4C`2[QU420:b7DP80ZhIA0`2YQT`20:Z7C@<0ZhQ>0P2/RE400`2]RU@0[HUE0:j:F0020:j:
FP030:n:G@2_ReL0[h]G00H0[h]G00P0[XUE0:n:EP2`ReL0/XeI0;>>FP2eT5`0]Y5M0;NBGP<0]91P
0P2eTF430;JBHP80/hmK0`2dT5`30;FAG@030;VEI@2hU6@0]Y9R0080]I5Q00<0]Y9R0;RDI02iUFD0
0`2gTf<20;RDI0<0^IEU0`2jUVH30;VEI@80^9AT0P2hTfH30;VDI`<0^YEX202iUFD80;bHJ0<0^IEU
0`2hU6@20;NCH`P0]i=O0P2iUFD20;ZFIPT0^iMW0P2jUVH20;VEI@P0^9AT1P2gTVD20;JAI0<0^IEU
0P2hU6@30;NCH`P0]Y9R0`2gTf<20;RDI0<0^IEU00<0^IEQ0;RDH02gTel00P2fTUh00`2gTel0^IEQ
0;ZFHP020;bHJ080^iMW0P2jUVH:0;VEI@80^9AT0`2iUFD30;ZFIP<0^9=V00<0^IAW0;ZEJ02jUFP0
0P2kUVT80;NEI`P0^9=Y202gTf<20;RDI0<0]i=S0`2fTV830;B?HP<0]I1S0P2fTF@01P2eSfP0]I1V
0;F@IP2eT6@0]8mR0;B@H080]91N00<0/XeP0;B?HP2eT6<00P2fTF@00`2eT6<0]8mR0;:=H0080;JB
HP030;6?G`2bT600/i5Q00<0/i5Q00<0/HmO0:n=G@2^S5`00`2eTEd30;B@G080/hmK00H0/XmI0;:>
FP2bSUX0/XiL0;:>GP2bSF020;:=H@P0]8iO202eSV<20;B>G`<0]HmP0`2fT6480;F?H0030;JBHP2e
TF40/hmO0080/XiN00H0/hmO0;FAH@2fTV80/HaP0;:=H@2dSf<20;F@I0030;B?H`2bSF40/HaP00P0
/hiQ202bSUh20;>?G`040;:>GP2aSEd0/8aL0:n;F`80[XYJ00<0/XiN0;6=G@2_Re/00P2^RUX00`2_
Re/0/HeM0;:>GP020:n;F`80/8aL0P2aSEd20;:>GP060;6>F02aSET0/HeI0;:>G02bSUh0/XeP0P2c
SV880;:>GP030:n>F`2`Se`0/Y5N0080/i9O00<0/Y5N0;2?G02_SU/0202dT6080;:>GP<0]91P0`2e
TF430;JBHP050;NCH`2eTF40/hmO0;6=G@2_Re/00P2`S5`0102aSEd0ZhMG0:f9F@2^RUX30;2<G006
0:n;F`2^RUX0[8MJ0:j9G02`Reh0/XeP0P2cSV400`2bSF00/HaO0:n;F`020:n;F`<0[XYJ0P2]RET0
202/R5P0[HUI0:n;F`2aSEd0/XiN0;6=G@2`S5`0[h]K0P2^REd30:n:GP<0/8]O00<0/HaH0;2;E`2`
ReL01@2`ReL20:j<C`030:j;D@2^Re<0[X]E0080[XYF00@0[XYH0:n;E`2_ReL0[h]G0P2^RUH30:f9
E@080:f:E02]RED0[XYF0:n;F@2`S5`0/HaO0;6<H02bSF420;:=F@80/HaH00@0/8]G0:n:EP2_RUH0
[hYF0P2aS5P20;2;E`040:n:EP2^RED0[XUE0:j9E@80ZXIF0P2[QeL0102/R5P0[HUI0:f9F@2]RET3
0:^6F@80[8MJ0`2]R5/20:j:FP<0[HUI0`2/R5P80:b8E0030:f9F@2^RUX0[XYJ0080[h]K0P2`S5`0
1`2aSEd0[hUL0:n9FP2_REX0[hUH0:n:EP2_RUD00P2_RU<30:b7DP@0ZhIA0P2ZQE000`2^RUH0[HUE
0:^7D`020:Z6DP030:^7D`2/R5@0[HUE00P0ZXEI00<0[8MC0:f8E02_RUH00P2`ReL02@2_RUH0[HQD
0:b7D`2^R5/0[XQI0:f7F02]QeH0[8MC0:b7DP020:^6C`030:R3C`2YQ500ZhIB0080[8MC00/0ZhIB
0:V4D02XPdl0Z8A@0:Z6DP2/R5@0[HUE0:j:EP2]RED0[8QD0:^7D`020:j9E@0>0:f8E02/Qe<0ZhIB
0:Z5D@2YQ500Z8=?0:N2CP2XPdl0ZHA@0:Z5D@2YQ500Z8=?0:J1C@2UP4`80:V4D080ZXEA0`2YQ503
0:R3C`030:J2CP2WPdl0Yh=?0080Z8A@0P2YQE40102ZQU80Z8=?0:N2CP2VPDd20:F0C0040:J1C@2W
PTh0Z8=?0:N3C`<0YX9>0P2UPDd20:B0C0030:=oB`2TP4`0YH5=0080YX9>00@0YH5=0:=oB`2ROTX0
Xge<0P2TOTd20:EoCP80YX1?00<0Yh5@0::1C02RPD`01P2RPD`00`2RO4d0Xge>0:EoD0020:N1DP06
0:J0D@2UOe00Y7i?0:AoBP2UP4/0Yh9=0P2XPdh00`2WPTd0YH1;0:AoBP020:J1C0<0Z8=>0P2VPD`0
0`2TOdX0Xgi90:AnC`070:AnC`030:F1C@2VPTh0Yh=?0080Z8A@00L0Yh=?0:J2CP2UPDd0XGa80:9m
B@2TOd/0YX5=0080Z8=?00@0Yh9>0:J1C@2VP540YX1A0`2UOe030:AnC`P0XG]<00@0Xgi:0:9mB@2R
ODT0XWe90P2QO4P20:1kA`080:9mB02SOTT0Y7m:0:AoBP2SOTT0XGa709mjA@2MN4<309mjAP030:1k
A`2QO4P0XGa80080XWe90P2QO4P20:9mB@@0Xgi:202PNdL309mjAPD0X7]700H0VgI209ag@`2LMd<0
WGQ409iiA@2ONTH20:1kA`030:1jB`2QNd`0Xge>0080Y7i?00<0Xge>0:9lC@2QNd`00`2RODH20:5l
A@<0X7]400<0WWU509mjAP2QO4P00P2RODT0102QO4P0WgY609iiA@2NNDD209ehA00309ag@`2KMT80
VWE10080VGA0202NN4T209ehA0<0W7M30`2KMT8209ajBP0309ijBP2ONDX0XGQ:00<0XWM:00<0XgM:
09]f@P2JMD400`2IM4000`2KMT80WGQ409mjAP0309Mc?`<0V7A00P2IMD4209Yf@P0309Ue@@2HM400
Ug<o0080UW8n00T0UG4m09UcA02JM4D0VgE609afA`2KMDH0VWA509Qb@`2GLD80202IMDD309I`@@<0
UFm00P2DKSl00`2EL3`0U6lk09=^>P02099]>@0409=^>P2DKc/0UG0l099_>@80TVhj00<0TVhl09=_
?`2CKT400P2CKT88095]?@<0T6]1:oooool002[ooooo202JL3h809ab@0<0W70o0`2KKch209Y^?@09
09Y_A@2KL4H0WG9809icB@2OM4X0WW=909ebB02LLDL0WgE30080WWA200<0WG=109ab@02LLT000P2K
LCl509ib@@<0WG500P2MN4/209agBP0709]fB@2JMDP0VWE809UdA`2MLd40WgE30:5gA@020:9hAP03
0:5gA@2OMD<0WWA200P0WGA00P2LLT001`2MLd40WgE30:1fA02PMT@0XGM50:9hAP2SNDL0202QN4@0
202UNdT0Y7Y80:=iA`2QMdD0X7I409id@P2MLd40W7900P2NMD4309mf@P<0X7M3202QMdD0202ONTD0
X7]60:5lA`2QO4L0X7]609iiA02LMd80VgI10P2PMd<0102QN4@0XWU50:AkA`2UO4P20:ImB@@0YGa8
102VODT01P2TNTX0YG];0:EkB@2UO4P0YWe90:ImA`80Ygi60`2WOTX20:QoB`<0ZH1<00<0Z7i>0:Il
C02UNd/00P2SNDT01P2UNd/0YWa<0:QnCP2XOd/0ZH1<0:^2CP<0[HA@00D0Zh9>0:Z1C@2WOTX0ZH1<
0:Z1C@020:^2CP030:Z1C@2YP4`0Ygi:00P0Ygi:202ZOd`00`2ZP4h0ZGm=0:QnC0020:MmB`030:Uo
C@2[PDl0[H=A0080Z7m;0P2YP4`40:Z1C@0;0:^6DP2ZQE40ZHA@0:R3C`2WPTh0YX5=0:F0C02TOd/0
ZX1>0:^1C`2]Pe400`2_QE<0102]Pe40[89@0:QoB`2XOd/20:V0C0D0ZX5=202/PU030:^6DP80ZXEA
0`2YQ500202ZQE40ZHA@0:R3C`2WPTh0Z8=?0:Z5D@2]R5@0[XUE0P2XPdh0102YQ4l0ZXE@0:Z5D02[
QU420:b7DP80ZXE@0`2[QU430:b7DP80Z8=>00H0ZHA?0:Z5D02[QU40[8MB0:f8D`2^RE@20:n:E@80
[XUD102]R5<00`2aReh0/8YM0:j8F`020:f7FP040:j8F`2`RUd0/H]N0:j9E@<0[HQD0P2/Qe<20:^6
DP80[8MB00@0ZhIA0:Z5D02ZQE00ZHA?0P2XPdh20:J1C0060:N2C@2XPdh0ZHA?0:Z5D02[QU40[8MB
1@2ZOTd30:]oCP060:N2CP2VPDd0YX5=0:F0C02TOd/0Xgi:0P2RODT00`2SOTT0XWe80:1kAP0209mj
A@030:1kAP2RODP0Xgi90080YGe:00@0XWe90:1lB02NNTH0VgY50P2INT@809egB0<0W7Q40P2KMd<3
09Yf@PP0V7<o00<0UW1109Ma@P2GLD800P2GLD8409Qb@`08099]>02DKcX0UG0k09Ia?02EL3/0U6lj
095/=`2@JcH309=]?P80TV`m0`2AJc`01P2?JD80SVTo08iY?`2>JCd0SFPk08eY>@80S6Pf00<0T6`l
08iZ>P2<J3P00P2:ISH00`2;IcL0S6Ph08eY>@0208]V>@80RVDh0`29I3L01028HcH0R6Hf08MU=@26
I3@208ES<`0D08IT=027ICD0R6Hf07eP=01oH3@0P64e085P=@23H3H0QV4g08MP=`28HCP0P6<g089S
=`21HSH0PV4f089O=@24GcD0QEhe08AM=01mFS0207iK<@03081M<`21GS@0PUle0080Pf0f00P0QEhg
08AM=P22Fc@0P5Tb07mH<@20FC80PU/d08=L=@80Q5/_00<0PU`_085L;`1oGBl00P1nGRl00`1mGRl0
MeL^07QH;`0307UI<00307MG;P1fERd0M5@[00@0MUT]101gFRh01P1gFS80MUTa07EH<01dEbl0LeH^
075D;080L5<[201hES<0101aER/0L5DZ071E:P1`EBX206mD:@80KU<X201aER/206m?9P04071@9`1a
DBP0LE4X079B:@80Le<Z1@1_DRP0101`DbT0LE@Z075D:P1aE2X206e?;@80KU0^0`1_DBl2071B<007
06mA;`1^D2`0KDlY06iA:@1_DRP0LE@Z079E:@0806eF;@@0LEH[00@0LUL/07=H;@1dFBh0MEX_0`1e
EB`207IF;@<0MeL^201hF2l207QG;00407UH;@1jFBh0NeX_07]J;`80O5/`00<0OU`f07eK=@1lFS@0
0P1kFC<0301mFcD0Oedg085O>@1jFS40Ne/b07aL<`1mGC@0OUhe07mO=P20H3L0PF4h081S>`<0Of8j
101nHCT3089T<P80PfDc0`24IS@00`25HSP0Qf@j08UV?00208]X?P0308YW?@29IS`0R6Dk0080QV/n
00<0QfXn08UZ?P2:JCh00P2;J3h03`2=J3h0SVPg08mY>02AJcX0TV`k09=]?02BK3/0TF/j091Z>@2?
KCd0T6hn095_?`2BL400U79209Ec@`0209IdA00909IaA02FLT80Ug=309Mc@@2HM400V7Do09Qe?@2I
MSh0UW<k0080Ug@l00<0V7Dm09Uf?P2JMcl00P2KN40309Yf@P80VgM30`2LN4@30:5mC@@0X7a<00<0
Wg];0:=oC`2SOdl01`2SOdl0202RODT0XGa80:1kA`2ONTH0X7]70:5lB02SOTX0Y7m;0P2RODP0102S
OTT0Y7m:0:J1C02WPTd20:R3CP040:F0B`2VPD`0ZHA?0:b7DP80[HQC00<0[8MB0:^6D@2YQT`00P2Y
QT`20:Z7C@<0ZhQ>0P2]RU800`2]RU@0[XYF0:j:F0020:n;F`040:n:G@2`S5P0/8aH0;2<F0<0[h]G
0P2^RUH0202^RED0[hYF0;2;E`2bSET0]8mK0;F@G02fTEd0]i9N0P2dT6020;FAH@<0]Y9R00<0]i=S
0;>?F`2cSe/00`2dT5`30;FAG@030;VEI@2hU6@0]Y9R0080]I5Q00<0]Y9R0;RDI02iUFD00`2gTf<2
0;RDI0<0^IEU0`2jUVH30;VEI@80^9AT0P2hTfH30;VDI`<0^YEX202iUFD80;bHJ0<0^IEU0P2hU6@3
0;NCH`P0]iAN0P2iUFD20;ZFIP<0^iMW0P2lV6P40;^GI`80^YIV0P2iUFD80;RDI0D0]i9U0`2fTF@3
0;VEI@80^9AT0`2gTf<80;JBHP<0]i=S0P2hU6@30;VEI@030;ZGH@2hUEl0]iAN0080]Y=M00<0]iAN
0;ZGH@2kV6800`2lV6P00`2kUfL0^YIV0;VEI@0:0;VEI@80^9AT0`2iUFD30;ZFIP040;NBI@2hTfH0
^9=V0;VDI`80^YEX0P2kUVT80;NEI`P0^99[202gTf<20;RDI0<0]i=S0`2fTV840;>>H@80]8mR0P2e
T6<01P2cSFH0/hiT0;B?I@2dSf<0]8mR0;FAH@80]I5O00<0/XeP0;B?HP2eT6<00P2fTF@00`2eT6<0
]8mR0;:=H0080;JBHP090;6?G`2bT600/i5Q0;>AH@2dTV80/i5Q0;6?G`2^S5`0[H]K00<0]I9L0`2d
TE/20;>@FP060;:?F@2bSUX0/XiJ0;:>G02bSUh0/XeP0P2bSF480;F?H0P0]HiS0P2dSUl30;F?H0<0
]Y1Q202eSf000`2fTV80]I5Q0;>?G`020;:>GP060;>?G`2eTF40]Y9R0;6<H02bSF40]8mS0P2eT6@0
0`2dSf<0/XeQ0;6<H0080;>>H@P0/XiN0P2cSel0102bSUh0/HeM0;2<G02_Re/20:j:FP030;>?G`2a
SEd0/8aL0080[XYJ00<0/8aL0;6=G@2cSel00P2_Re/20;2<G080/HeM0P2bSUh01P2aSUP0/HeI0;6=
F@2bSU`0/XiN0;:=H080/hiR0`2aSEd50;:>GP030:n>F`2`Se`0/Y5N0080/i9O00<0/Y5N0;2?G02_
SU/00`2eTF450;B@H0P0/XiN0P2dT6000`2eTF40]Y9R0;JBHP040;JBHP040;NCH`2eTF40/hmO0;2<
G080[h]K00D0/8aL0;6=G@2[QeL0[8QH0:j:FP020;2<G0090:n;F`2^RUX0[HUI0:Z5F02/QeX0[hYM
0;6<G`2cSV40]8mR0080/hiQ0`2_Re/20:j:FP<0[HUI00<0[8QH0:f9F@2_Re/00`2aSEd0102`S5`0
[h]K0:j9G@2^REd30:n:GP<0/8]O0P2_RUH30;2;E`<0/HaH0P2^S4l20:j;D@040:j;D`2^ReD0[XYF
0:j:EP<0[h]G0P2^RUH30:f9E@080:f:E02]RED0[XYF0:n;F@2`S5`0/HaO0;6<H02bSF420;:=F080
/HaG00@0/8]F0:n:E@2_RUD0[XUD0P2aS5P0102`ReL0[hYF0:n:EP2^RED20:f8E0<0ZXIF00<0ZhMG
0:b8F02]RET00P2]RET0102ZQEP0ZhII0:^6F@2[QUT20:b7FP80[HQK0P2^RUX30:f9F@<0[8QH202/
R5@0102]R5/0[XUL0:j9G02_RUd20;2;GP80/HaO00H0[hUL0:n9FP2_REX0[hUH0:n:EP2_RUD20:n:
D`<0[8MB102[QU420:Z5D0030:j:EP2]RED0ZhMC00<0ZXIB00<0[8QD0:f9E@2ZQET01`2ZQET00`2/
Qe<0[HQD0:n:EP020;2;E`090:n:EP2]R5@0[8MC0:j8F`2^R5T0[HMH0:f7EP2/Qe<0[8MB0080ZhI?
00<0Z8=?0:V4D02[QU800P2/Qe<02`2[QU80ZHA@0:R3C`2XQ500ZXIB0:b8E02]RED0[XYF0:f9E@2/
R5@0ZhMC0080[XUE00<0[HQD0:b7D`2[QU800P2YQ5002@2XPdl0Yh9>0:R3C`2YQ500ZXEA0:V4D02X
Pdl0YX5=0:F0C0080:V4D080ZXEA0`2YQ5030:R3C`80YX9>0P2WPdl01`2XQ500ZHEA0:V5D@2ZQU80
ZHA@0:N2CP2UP4`00P2TOd/00`2UP4`0Yh9>0:V4D0040:J2CP80YH5=0P2TP4`00`2ROTX0Y81<0:F1
C@020:J2CP030:F1C@2SOd/0XGe90080Xge<00@0Y7i=0:EoCP2UOdh0YX1?0P2WPE030:60B`80XX5<
0`2SPTd00`2RO4l0Xge@0:EoDP020:N1E0060:J0D`2UOe80Y7iA0:AoBP2UP4/0Yh9=0P2XPdh0202W
PTd0YH1;0:AoBP2UP4/0YX5<0:R3CP2YQ4l0Z8=>0P2VPD`00`2TOdX0Xgi90:AnC`070:AnC`030:B0
C02VPTh0Yh=?0080ZHEA00/0Yh=?0:J2CP2TP4`0X7]70:9mB@2TOd/0YX5=0:N2CP2XPdl0Yh9>0:J1
C@030:J0D@80YGm@0`2TOTl80:5kC0@0XWe90P2QO4P20:1kA`80Xgi90P2TOdX0102RODP0WgY509ag
@P2JMD0209iiA@0409mjAP2PNdL0X7]70:5lB080XWe90P2QO4P20:9mB@<0Xgi:00<0Y7m;0:1kA`2P
NdL02P2PNdL40:5lB080VgI200@0W7M309ehA02NNDD0WgY60P2PNdL00`2PNT/0XG]<0:=mCP020:Eo
D0030:AnC`2RO4d0XG]<00<0XWe60`2QO4D20:1kA00309mjAP2PNdL0X7]70080XGa80P2PNdL00`2O
NTH0WGQ409ehA00209ag@`0409]f@P2JMD40VGA009Ud@0P0WWQ900D0WGQ409ag@`2LMd<0VgI209Ye
@@0209Ud@00609Qc?`2JN4P0VWQ809eiB@2NN4T0XGQ:0`2SN4/02P2UND`0VgI209Ye@@2IM400V7<o
09Ud@02KMT80WWU509mjAP2ELCd209Ib?P0;09Mc?`2HM400VGE109Ue@@2JMT80VGE109Qd@02GLcl0
UW8n09A`?02BKSX00P2AKCT0202ILd@0VWA509]eAP2LMTL0VgE609YdA@2HLT<0Ug52202IMDD309E_
@0<0U6ho0P2CKCh00`2EL3`0U6lk09=^>P02099]>@0409=^>P2DKc/0UG0l099_>@80TVhj00<0TVhl
09=_?`2CKT400P2CKT8808m[>`<0S6Ho:oooool002[ooooo202IKcd01P2GKC/0V6hl09Q^?02JL3h0
Vg4o09ab@080WG=100<0W79009]a?`2IKcd00P2HKS`03P2IKcd0Vg4o09ab@02MLTD0Vg1309U^@@2H
KD00Uf`o09Q]@02JKd80Vg1309]a?`2LLT00WWA20P2PMT@00`2NM480W79009]a?`0309Y`?P0309]a
?`2LLT00WG=10080WG=1202NLT4809ad@`0<09Y`?P2LLT00WWA209me@`2PMT@0WgE309id@P2MLd40
W7<o09ie@@2PMd<0XWU50`2SNTH00`2QN4@0X7M309]f@P0709]f@P0309ec@`2NM4@0X7I60080XGM7
00<0X7I609idA02MLd<0202RN4P20:9hAP80XGM50P2PMT@209me@`0409mf@P2PMd<0X7M30:1g@`80
XGQ40P2RNDD30:=hA@80Y7U60`2UNTL80:IkB0030:MnBP2VODT0YGa80080Y7]700<0YGa80:ImB@2W
OTX00P2TNTP20:EkB@80YWa:0P2WOD/80:IlBPP0Z7i<202YOT/20:UoC@@0Z7i<0P2WOD/80:V0C080
YX5<0P2WPTd20:R3CP80ZHA?0P2VPDd0302WPTh0Z8=?0:V4D02ZQE40ZhIB0:b7D`2`Qdl0[hI>0:j5
C`2]Q500Zh9>0:UoC@80Z7i>0P2VPDd20:N2CP80Z8=?0P2YQ5090:R3C`P0ZHA?202YQ5020:Z4E`<0
ZhEH0`2/QUT30:^5E080ZXAC0`2YPe880:^5E0P0ZhIA0P2[QE@0102[QU80[8MB0:f8D`2^RE820:j:
D0P0[HQD0P2^RE@20:f8D`80[8MB0P2[QU480:V4C`<0ZhIA0P2ZQE030:V4C`@0ZX5=102[PTh30:Uo
C@80Z7i<0`2WOD/80:IlBP0309mjAP2PNdL0XWe90080Y7m;00<0XWe90:1kA`2ONTH00P2RODH01P2R
ODP0XWe90:5kBP2QNd`0X7Y;0:1jC@80X7M300@0WgI209ie@@2NMD40WGA00P2LLcl809YdA@T0Ug8n
102HLcl209Mb?P80UW4m0P2EKd8209A^@@<0Tfe000<0TV`o095]?@2BKSh00`2CKcl01P2AKCd0T6`l
08iZ>P2;JCT0S6Xj08i/?080Sfdm00/0SV`l08aZ>P2;JCT0TFa0091[?`2?JSh0SVTm08eX?02<Ic/0
RfHj08YU>@0808IU>P80RVDh0P29I3L308QS=P0408MR=@26HC@0QF0c08AO<P80Peha00T0Q5lb08IQ
=028HcH0OE`c07iM=020GcH0PV4h08=R>@22HCP00P21H3L2089O=@80PEhd00l0P5dc07mL<P1oG380
OU/a08YP>029GcL0QUlf08AO=@23GS@0P5dc07iM<P1mG340OEXb07iK<`20GCD00P21GSH00`20GCD0
OU/c07eJ<P0307]H;P80NUL]0`1iER`0101hFBd0MeP/07MH;01gF2`207IG:`80MEHZ201eEB`307IF
<080MeLa0`1hF38807QI;@P0Le</00<0L50Z075A:`1cDbd00`1eEBl307=C;@<0KdlY0P1`D2X3075A
:`80L5@/0P1aEBd3079F;P0307=G;`1fES00MED_0080MED_0P1dE2h207=C;@<0M5@[0P1eEB`307IF
;@P0NUL_00@0M5Pc07IJ=@1iGCH0Nelg0P1lHCH00`1kH3<0NUlb07]L<00207]L<080O5da0`1mGS83
081Q=@80PF8f0`22HcL01P21HCP0PF8f085R=P21HS@0PF8c085S<@80PF<_0`22HS<208=S=0<0Q6@e
00<0QV@d08MU=@27ICD00P28ISH308UW=`80RfTk0P2:J3X05029IcT0R6Hh08MU=`27ICL0U71009=_
?`2BKSh0TFdm099^?P2CKcl0UG5109Ib@P2?KCd0SV`l08aZ?02:J3/0RVLm08]X@02=JT80SV]50P2A
Kcl02@2BL400U79209Ec@`2FM4@0UgE509QfAP2CLSd0U7<n09Mf@@0309Uh@`0309Mf@@2FMD00VGE1
0080VGE10P2JMT8309]g@`0409]h@P2LND<0W7U309ai@`80WGY40P2NNdD30:5nB0D0X7e72@2SOTX0
202XPdl0Yh9>0:AoB`2RODT0XGa80:9mB@2SOTX0Y7m;0P2RODT01P2SOTX0Y7m;0:J1C@2WPTh0Z8=?
0:V4D0<0Z8A@0P2YQE4;0:Z6DP030:R8E`2YREP0Zh]J0080[8aK00<0Zh]J0:V9F02XR5L00`2^R5T2
0:n9FP<0/8YK0`2bSUh20;>?G`<0]91P0P2bSF400`2cSV40]91P0;FAG`020;JBGP030;NDGP2fTV80
]Y9R00H0]Y9R0`2jUFP50;VDI`040;NBI@2hTfH0^9=V0;VDI`80^YEX0P2kUVT90;^GI`070;ZFIP2h
U6@0]i=S0;NCH`2hU6@0^YIV0;^GI`030;ZFIP<0^IEU0P2hU6@30;ZGG`<0^IIN0P2hUEd80;ZEJ@<0
]i=S0P2hU6@30;VEI@80]i=S102hU6@20;VEIA40^9AT202gTf<80;RDI0P0]YAT202gTf<80;JBHPP0
^IEU00@0_9QX0;^GI`2kUfL0^iMW0P2jUVH20;VEI@<0]i=S0P2hU6@30;VEI@P0]iEU202hTfH20;RH
I`80]iMV00@0]YIU0;FEI02eUF@0]9AS402gTf<0102bSUh0/hmO0;>?G`2dT6020;FAH@D0]Y9R0`2g
Tf<20;RDI0030;J=G`2hSf40]i5R0080^9AT00T0]99R0;:BH@2`T5l0^9AT0;NCH`2fTV80]I5Q0;B@
H02bSUh00P2aSEd90;:>GPP0]91L0P2fTV820;FAH@040;B@H02cSel0/hmO0;:>GPP0/hmO00<0]I5Q
0;B@H02cSel00P2bSUh02`2dT600]Y9R0;RDI02fTed0]Y9N0;FAG@2eTEl0]91P0;>>H@2cSV80/XeQ
0080]Y9R0P2eTF40102dT600/hmO0;>?G`2bSUh80;FAG@80]I5Q00@0]91P0;>?G`2cSel0/XiN0P2a
SEd0202eSf00]8iO0;>=GP2bS5d0/H]L0;2:F`2_REX0[XQI0P2cSEh00`2cSF00/haQ0;><H`020;><
I@060;>;I`2dT600]91P0;>?G`2bSUh0/HeM0P2`S5`01P2_Re/0/8aB0;2<DP2`Re@0/8]F0;2;E`80
/8YI00@0/8YK0:f9F@2_Re/0/HeM0P2cSel00`2bSUh0/HeM0:n;F`040;6=G@@0/8aL0P2cSV400`2b
SUh0/XiL0;:>FP020;6>F0030;6>EP2cSEh0/heN00H0/heN202bT6030;:>GP030;6=G@2`S5`0[h]K
0080[h]K2@2cSV480;:=H080/HaP00<0/8]N0;2<G02_ReT00P2^RUH00`2]RU@0[h]K0:n;F`020;2<
G0<0/HeM00L0/XiN0:n:EP2_REP0[hUH0:n9FP2_RE`0[hQM0080[hQO0P2aS6000`2`Reh0[h]K0:j:
F0020:f9E@050:b9D`2^RUH0[XYF0:j:EP2_ReL00P2`S5P20;6=F@@0/8aL0P2_Re/20:j:FP040:f9
F@2^RUX0[XYJ0:n;F`80/8aL0P2aSEd30;2;E`80[hYF0`2^RED01P2`SEL0/8aH0;2<F02`S5X0/8aL
0;2;GP80/8]O202_RU<01P2^RE@0[XUE0:j9E@2^R5L0[XQI0:j8F`80[XML00<0[HUI0:b8F02[QeL0
0P2ZQUH00`2[QeL0[8QH0:f9F@080:f9F@080;B@H02cSel0/8aL0:j:FP2]RET0[XYJ0:n;F`2`S5`4
0:b6E`@0[HMH0P2/Qe<20:f8E0040:j9E@2_RUH0[hYF0;2;E`80[h]K00<0[XYJ0:f9F@2/R5P00P2[
QeL0102ZQUH0[HQD0:f8E02]R5@40:j9E@<0[hYF00L0ZhIB0:V4D02[QU80/8]G0;>>FP2`ReL0[8MC
0080ZHA@00<0ZXEA0:^6DP2/Qe<00P2]R5@00`2^RED0[8MC0:b7D`060:b7D`080;2:F`2_REX0[XQI
0:f7F02/QUL0ZhEF0:Z4E@2YPe@20:Z5D@<0ZhIB0`2/Qe<80:^6C`0;0:j:FP2]RET0[8QH0:^7E`2Y
QED0Yh=C0:J2DP2UPE40Z8=>0:Z5D02[QU400`2]R5<0102[QU40ZXE@0:Z5D@2ZQE430:V4D0<0Z8=?
202YQ5001P2[QEP0ZhEF0:^5EP2ZQ5<0ZXEA0:V4C`80ZHA=0`2TOd/30:=nBP80XWe900H0Y7m:0:F0
B`2VPD`0Yh9=0:R3CP2YQ4l20:Z5D0P0Y81<00<0Yh9>0:J1C@2TOd/00P2SOTX00`2TOd/0YX5=0:N2
CP080:J1C@80YH1<0`2VPDd60:N2CP<0YX5=0P2UP4`70:J1C080Yh9=0P2VPD`40:F0B`80Y7m:00<0
YX5<0:N2C@2XPdh00P2XPdh01P2VPD`0Y7m:0:=nB@2SOdl0Y81@0:J2DP80Yh=C00@0YX9B0:B0D02S
Odl0X7a80P2QODT00`2ROTX0Xgm;0:B0C0020:F1C@P0XWi>1P2QO4L20:9mB080XWe900@0XGa80:1k
A`2PNdL0WgY60P2NNDD209ik@`0309ikA@2ONdL0Wg]90080X7a<00<0X7]>0:5lA@2QO4D01P2QO4D0
0`2QO4L0XWe80:=nB@020:=nB@070:5lA`2ONTD0WWU409Ye@@2LMd<0WWU50:5lB0030:=nBP090:9m
B@2IM400VWE109]f@P2MN4@0WWU50:1kA`2QO4P0XWe900<0WgY60P2PNdL30:5lB0080:9nCP2QODd0
X7a<09mkB`2NNTX0WGU909ahB02KMdL20:1lB00309mkA`2NNTH0WGU50080W7Q400<0VgM309]f@P2K
MT801P2KMT8209ag@`80WGQ40P2NNDD209mjAP0309iiA@2MN4@0W7M30080VWE100<0W7M309ehA02N
NDD00`2ONTH00`2NNDD0WGQ409ag@`0309ag@`<0W7Q40`2KMd<209Yf@P0309UeA@2HM4@0UW920080
UG5100<0Ug=309UeA@2JMTH0202HM4001P2EL3`0UW4m09Qc?`2JMD40VgI209Ye@@80VGA0202GLSh8
09Qc?`80Ug8n00<0UW4m09E`?02DKc/00P2CKSX02P2BKCT0U6a909=[A`2BJd@0TFXo099/?@2CKC`0
UG0k09Ia?02BK3d209=]?P0509A^?`2CKCh0TF/l08mY>P2>J3T00`2AJDD[ooooo`00:_ooool809U_
?@0609M]>`2HKS`0VFlm09Y`?P2KLCl0W7900P2MLd400`2LLT00Vg4o09U_?@0209Q^?00609U_?@2K
LCl0W79009ebA@2LLD@0VVm20P2IKT401P2JKd80Vg1309aaA02JL3h0Vg4o09ec@@80WWA200<0WG=1
09]a?`2JL3h00P2JL3h209]a?`80W7900P2MLd4809ib@@P0W7A300`0Vg4o09ec@@2OMD<0X7I40:5g
A@2PMT@0WgE309id@P2MM400WWE10:1g@`2RNDD20:=jAP030:9iA@2QN4@0X7M300P0VgI200<0WG=3
09idA02PMTH00P2QMdL00`2PMTH0WWA409ec@`020:1fAP80XGM70P2RN4P20:=iB@80XWQ60P2QMdD2
0:1fA080WgE3102PMd<20:5hA080XWU50`2SN4D20:AiAP<0YGY7202VNdP00`2WOTX0YWe90:ElB002
0:=jAP030:ElB02VODT0Ygi:0080Y7Y80P2UNdT20:IlBP80Yge;202VO4X80:QnC0P0ZGi;202XOT`8
0:V0C080YX5<0P2WPTd20:R3CP80ZHA?0P2VPDd0102WPTh0Z8=?0:V4D02ZQE420:^6DP80[XE=00@0
[HA>0:b3C`2[PTh0ZX1>0P2YOdl20:J1C@80Yh9>0P2XPdl20:V4D0T0Z8=?202YQ4l80:V4D0<0ZXAE
0P2[QEH30:b6E`P0ZXAC202[QE@80:^6D@80ZhED00@0ZhIB0:b7DP2]R5<0[HQA0P2^RU080:f8E080
[XUD0P2]R5<20:b7DP80ZhIA202YQ4l30:^6D@80ZXE@0`2YQ4l30:Z1C@D0Zh9>00@0ZX1>0:UoC@2Y
Odd0ZGm=0P2XOT`20:MmB`P0YWa:00<0X7]70:5lB02RODT00P2TOd/02`2RODT0XGa80:1kA`2SOTL0
XWe60:9mB02RODT0XG]:0:5kC02PNT/0X7Y=00<0X7M300<0WgI209ie@@2NMD400P2MM40809YdA@T0
V7<o00@0VGA009Qc?`2HLcl0V7<o0P2GLSh209Ia?@<0UFm00P2DKSl309=]?P0;095]?@2BKSh0Tflo
09A`@02CKcl0TVhn091/?02?Jc/0RfTi08aZ>P2>K3`00P2?KCd0102>K3`0S6Xj08]Y>@2AK402091[
?`0508mZ?P2=J3`0S6Lk08aW>`2;ISX02026ICX308YU>080RF@g0`28HcH00`27HSD0QV4d08EP<`02
08AO<P0608EP<`27HSD0R6<f07iM<P1oGS<0PF0e0`23HSL00`22HCH0PF0e08=P=P02089O=@80PEhd
0P20GC<0301oG380RV0h08UO=`27H3L0QF0f08=N=020GC<0Oehc07iM<P1nFc40Oe`b081M<`80PEhd
00<0P5dc07mL<P1nFc400`1lFBl207]H;P<0NUL]0`1iFRh207QI;@<0MeP/201gEbh0101fES00MeLa
07MG<@1gEc4207QH<P80NETc201iFRh807MG<007075A:`1bDR`0M5@^07EE;`1fES00MED_07AD;P02
07=C;@<0LE4[0P1bDR`307=C;@<0LED]0P1bERh307=G;`<0MUH`0P1eEBl307AD;P<0MUH]0P1gEbh3
07QH;`P0NeP`00T0M5Pc07IJ=@1hG3D0NUhf07aQ=P1lHC@0Nf0c07YO<01kG3000`1lGC4207eN<P80
OUlc0`20HCD2085R=P<0PV<g00H0PF4h085R=P21HSH0PF8d085R<`21Hc42085S;`04089R<`23Hc@0
Pf<d08=S=080Q6@e0P25ICH408QV=P@0RFLg00@0RfTk08YX>P2:J3X0RVPj1029IcT0402CKcl0TVhn
095]?@2@K3`0TFdm099^?P2DL400UG51091_?02?KCd0SV`l08aZ?02<JSd0SFY008m/A02@KDD309=a
@@0309Ab@P2ELd<0UWA40080UgE500<0U7<n09Ed?`2GMT400`2IN4<0102HMd80UgI109Ue@@2IMD42
09Yf@P<0VgM300@0W7Q409ai@`2LND<0W7U30P2MNT@309ikA@D0XGi80`2PODL90:=nBP030:N2CP2V
PDd0Y7m;0080XWe900@0Xgi:0:AoB`2UP4`0Xgi:0P2TOd/01@2UP4`0YX5=0:N2CP2WPTh0Z8=?0080
Z8A@0`2YQE430:Z6DPP0ZhMC00<0Z8QG0:V9F02[ReX00P2/S5/00`2[ReX0ZHUH0:R8E`020:j8F@80
[hUJ0`2`RU/00`2aRe`0/XiN0;:>GP030;>?G`<0]91P0P2dSf<00`2dSf80]91P0;FAG`020;FAG@03
0;FBG02fTV80]Y9R00H0]Y9R0P2jUFP60;VDI`80^9=V0P2iU6L20;ZEJ080^iIY2@2kUfL01`2jUVH0
^9AT0;NCH`2gTf<0^9AT0;ZFIP2kUfL00`2jUVH30;VEI@80^9AT0`2jUel30;VFGP80^9EM202jUFT2
0;NCH`<0^9AT0`2iUFDI0;RDI0P0]i=S202hU6@80;JDI0P0]i=S202fTV880;VEI@@0^iMW0P2jUVH2
0;VEI@<0]i=S0P2hU6@30;VEI@P0]iEU202hU6@00`2hV6L0]iMV0;NGIP020;JFI@80]IET00<0]9AS
0;NCH`2gTf<03P2gTf<20;>?G`80]91P0P2eTF420;JBHPL0]i=S00@0]Y9R0;J=G`2gSV00]i5R0P2g
Tf<00`2dTV80/I5P0;2@G`020;JBHP80]I5Q00<0]91P0;>?G`2bSUh02P2bSUh80;B@G080]Y9R0P2e
TF400`2dT600/hmO0;>?G`090;>?G`030;FAH@2dT600/hmO0080/XiN00T0]91P0;JBHP2gTf<0]Y=M
0;JBGP2eTEd0]I5O0;B@H02cSV400P2cSV820;JBHP80]I5Q00@0]91P0;>?G`2cSel0/hmO202eTEd3
0;B@H0030;>?G`2bSUh0/XiN0080/HeM00H0]HmP0;B>G`2cSEh0/XaM0;6;G02`RU/20:n9FP060;>=
G02cSEh0/heN0;>=H02cS640/haS0P2cS6D20;B@H0040;>?G`2bSUh0/HeM0;2<G080[h]K00H0/8aB
0;2;E02`Re@0/8]F0;2;E`2`RUT20;2:F`080:f9F@2_Re/0/HeM0;:>GP2cSel0/XiN0;6=G@2`S5`5
0;6=G@<0/8aL0P2cSV420;:>GP040;:>G02aSET0/HiH0;6>F0P0]8iO202bT6030;:>GP030;6=G@2`
S5`0/8aL0080[h]K2@2cSV480;:=H080/HaP00H0/8]N0;2<G02_ReT0[h]G0:j:EP2^ReD20:n;F`80
/8aL102aSEd20:n:EP030:n9F02_REX0[hUL0080[hQM00T0[hQO0;:=H@2bSF40/HaO0;2<G02_ReT0
[XYF0:f9E@2]RU@01`2_ReL00`2`S5P0/HeM0;2<G0020;2<G080[h]K1@2^RUX00`2_Re/0/8aL0;2<
G0020;6=G@P0[hYF00H0/8eG0;2<F02`S5P0/8aJ0;2<G02`Reh20;2;G`P0[hYC00H0[hYE0:n:EP2_
RUH0[hUH0:n9FP2_RE`20:n8G@030:j:FP2/R5P0ZhMG0080ZXIF00<0ZhMG0:b8F02^RUX0202]RET0
0`2bSUh0/8aL0:j:FP030:f9F@030:n;F`2`S5`0[8IG00<0[8IG102]QeP20:b7D`80[HQD0P2^RED2
0:n:EP@0[HUI102/R5P40:j9E@D0[HQD00P0[hYF0:^6DP2YQ500ZhIB0;2;E`2bSET0/8]G0:b7D`80
ZXEA0`2[QU8;0:b7D`<0[XQI00<0[HMH0:b6E`2[QEH00P2ZQ5D30:Z5D@80ZhIB0`2/Qe<80:^6C`0;
0:n;F`2^RUX0[HUI0:^7E`2ZQUH0Z8AD0:N3D`2VPU80ZHA@0:^6DP2/Qe<00P2]R5@00`2/Qe<0ZXEA
0:V4D0020:Z5D@<0ZHA@0`2XPdl80:V4D0060:^5F02[QEH0ZXAE0:Z4D`2ZQE40ZHA?0P2YQ4d40:Ao
B`@0YH1<0P2VPD`20:N2C@<0Z8=>00<0ZHA?0:B0C02TP4`01P2TP4`00`2WPTh0YX5=0:AoB`020:=n
BP030:AoB`2VPDd0Yh9>00P0YX5=0P2UP4`30:J1C@H0Yh9>0`2VPDd20:F0C080Yh9=1@2VPD`20:F0
B`80YX5<1P2UP4/00`2VPD`0Yh9=0:R3CP020:R3CP060:J1C02TOdX0Xgi90:=oC`2TP500YX9B0P2W
Pe<00`2VPU80Y81@0:=oC`030:9nBP<0Xgm;0P2TP4`80:9nCP<0XWe81@2QO4L30:5lB0<0X7]70P2O
NTH209ik@`0309mlAP2ONdL0Wg]90080X7a<00<0X7]>0:5lA@2QO4D01P2QO4D00`2PNdH0XGa70:9m
B0020:=nB@070:5lA`2ONTD0WWU409ag@`2MN4@0WgY60:5lB0020:9mB@80XGa800P0VGA009Ye@@2K
MT80WGQ409iiA@2PNdL0XGa80:9mB@<0WgY60P2PNdL30:5lB080XWi>00@0XGe=0:1lC02ONd/0WWY:
0P2MNDT20:1lB00309mkA`2NNTH0WGU50080W7Q400<0VgM309ag@`2LMd<0202LMd<209ehA080WWU5
0P2ONTH00`2NNDD0WGQ409ag@`0209Ye@@0309ag@`2MN4@0WWU50080WgY60P2NNDD00`2MN4@0W7M3
09ag@`0209ag@`<0W7Q40P2KMd<309Yf@P0809UeA@2HM4@0UW9209Ea@@2FLT80Ug=309UeA@2JMTH3
09Qd@080Ug<o0`2FLSh00`2EL3`0UW4m09Qc?`0309Ye@@0309Ud@02HLcl0Ug8n00L0Ug8n0`2HLcl0
1@2GLSh0UW4m09Ia?@2FLCd0UG0l0080Ug8n00@0UW4m09E`?02DKc/0Tfhj0P2BKCT0402DK4P0Tfa5
099[@P2AJSl0TV`m09=]?02EL3`0UW4l099/?@2CKCh0U6ho09E_@02DKSl0TV`m091Z>`2?JCX3095Y
AB_ooooo000Zooooo`P0VFlm0P2HKS`00`2IKcd0VW0n09]a?`0209ab@00409ec@@2LLT00Vg4o09Y`
?P80VFlm00<0VW0n09]a?`2LLT000P2MLTD02@2LLD@0Vg1309]`@`2LLD@0WG9509icAP2IKcd0VW0n
09]a?`0209ab@00409]a?`2JL3h0VFlm09Y`?P<0Vg4o0`2LLT000`2MLd40WW9109ib@@0609ib@@T0
WG=100X0WWA20:1fA02RN4H0XWQ60:5gA@2PMT@0WgE309ie@@2OMT80X7M3102RNDD00`2QN4@0X7M3
09]f@P0709]f@P0309id@P2OMD<0X7I40080XGM500<0X7I409me@`2NM4800P2NM4801P2OMD<0XGM5
0:9hAP2SNDL0Y7Y80:EkB@80XWQ60P2QMdD20:1fA080WgE30`2PMd<20:5hA0<0XWU50`2SN4D20:Ai
AP<0YGY7202VNdP00`2WOTX0YWe90:AkA`020:=jAP030:AkA`2VODT0Ygi:0080Y7Y80P2UNdT20:Il
BP80Yge;202VO4X80:QnC0P0Z7e:202XOT`80:V0C080YX5<0P2WPTd20:R3CP80ZHA?0P2VPDd0102W
PTh0Z8=?0:V4D02YQ5020:Z5D@80Zh9:00@0Zh9<0:^2CP2[PTh0Zh5?0P2[PE420:J1C@80Yh9>0P2X
Pdl20:V4D0T0Z8=?202YQ4l80:V4D0040:V3E02ZQ5D0ZXAE0:Z4E@80ZhEF0P2/QUL20:R3C`040:V4
D02ZQE40ZXEA0:^6DP80[8MC202[QU880:^6D@80ZhED00@0ZhIB0:b7DP2/Qe80[HQA0P2]RDl80:f8
E080[XUD0P2]R5<20:b7DP80ZhIA202ZQE030:^6D@80ZXE@0`2YQ4l80:^2CP<0ZX1>0P2YOdd30:Qn
C0P0Yge;00<0XGa80:9mB@2SOTX00P2TOd/00`2SOTX0XWe90:5lB0020:=nA`030:=nB@2RODT0XWa;
0080XG]<00<0XG]>0:5hA02QN4@00P2PMd<409mf@PP0VWA52@2HLcl309Ud@080V7<o0`2GLSh209I`
@@80UFm00`2DKSl00`2CKCh0TVhn09=_?`0309A`@006099^?P2AKCd0Sf/k08iZ>P2?Jc/0TFdm0P2B
KSh00`2AKCd0Sf/k08iZ>P02095/?`03091[?P2?JSd0SVTl0080SFPk00<0S6Lj08QU>`28IC/01P28
IC/308]V>@80RVDh0`29I3L208QS=P0908MR=@26HC@0QV4d08IQ=027HSD0R6<f081M<`22GcD0Pf0f
00<0QF8h00<0Pf0f089O=@23H3H00P23H3H2089O=@<0PEhd0P2:H3P02027H3L0QF0f08AO=@21GS@0
P5ld07mN<`1oG380P5dc1021GS@00`20GC<0Oe`b07eJ<00207eJ<0<0O5T_0P1kF2h307aM<@80Ne``
0`1jFbl807UI<0<0N5Pa0P1iFC8307YJ<`P0NU/_201jFS<01`1bDR/0Le</07EE;P1fERl0MeL`07IF
;`1eEBh0101dE2d207EE;P<0MUH_00<0MeL`07=F;01cER`00P1dEbd207EH;P80MUT_0P1hF34207MG
<080MUH_0P1eEBh307UI<0<0NUXa0P1kFc8807aI<@0807IH<P1hFS@0NE`d07]N=01lGc<0O60a07]O
<01kGbl307eN<P80OUlc0`1oH3@3085R=P80PV<g0`23I3P01P22HST0PV<g089S=`22HcD0PV<d089T
<P80PV@`00@0Q68d08ES=@25HcD0QF<e0P26I3H208MU=`@0RVPh1029IcL408YX>P<0RfTk0140S6Xl
099^?P2AKCd0T6`l08m[>`2@K3`0TFdm09=_?`2DL400TW4n095`?@2@KSh0T6i0091^@@2AKT@0TVm5
099_A`0509Ec@`<0UWA40P2FMD00102HMd80VGQ309Uh@`2IN4<209Qg@P<0VWI20P2KMd<309ahA004
09ai@`2MNT@0WGY409ejA080WW]50P2OO4H70:5nB0030:9oB@2TOd/0Y7m;00L0Y7m;0P2UP4`01P2T
Od/0Xgi:0:AoB`2UP4`0YX5=0:N2CPP0YX5=00@0Z8A@0:V5D@2YQE40ZHEA0P2ZQU8:0:^7D`030:Z8
F02[RET0[H]K0080[XaL00<0[H]K0:^9F@2ZR5P00`2_REX20;2:F`<0/H]L00@0/XiN0;>?G`2cSel0
/hmO0P2dT6020;FAH@80]Y5U00<0]I1S0;FAH@2eTEl00P2dT5`00`2dTE/0]Y9R0;JBHP060;JBHP/0
^IAW0`2jUFP20;^FJ@T0^iMW00L0^YIV0;VEI@2hU6@0^9AT0;VEI@2jUVH0^iMW00<0^YIV0`2iUFD2
0;RDI0<0^YMQ0`2iUV020;REG`P0^YEX00@0]i=S0;RDI02hU6@0^9AT0P2iUFD20;ZFIQT0^9AT202g
Tf<80;RDI0P0]YAT202gTf<80;JBHPP0^IEU0`2kUfL20;ZFIP<0^IEU0`2gTf<20;RDI0<0^IEU202g
UFD80;RDI080^9IV0P2gUFD40;JDI0P0]Y9R202gTf<30;B@H0<0]I5Q0P2fTV820;VEI@040;RDI02g
Tf<0]Y9R0;JBHP80]I5Q0P2gSV00102fT640]Y9R0;JBHP2cTF420;6AH0030;FAH@2dT600]91P00D0
]91P2@2bSUh80;B@G0<0]I5Q0`2dT60:0;>?G`090;B@H02cSel0/XiN0;:>GP2cSel0]91P0;FAH@2f
TV80]I9L0080]I5M00<0]91N0;B@H02dSf800P2cSV830;FAH@<0]91P0P2cSel80;FAG@040;B@H02c
Sel0/hmO0;>?G`<0/XiN00<0/HeM0;B>G`2dSUl00P2cSEh0102bS5d0/H]L0;2:F`2`RU/20;>=G003
0;>=GP2cSF00/haQ0080/haS00L0/haU0;B@H02cSel0/hmO0;:>GP2aSEd0/8aL0080[h]K0P2aS5D0
0`2aS5L0/HaH0;6;FP020;6;G0040;6;GP2^RUX0[h]K0;2<G0<0/XiN00<0/HeM0;2<G02aSEd01`2a
SEd20;>>HP030;:=H02bSUh0/XiL0080/HeI00<0/HiH0;F?H02eSf001P2eSf080;:@H0<0/XiN0P2a
SEd30;2<G0T0/XeP202aS5l20;6<H0030;2;GP2`S5`0/8aJ0080[h]G00@0[haF0:n;F`2_Re/0[h]K
0P2`S5`30;6=G@060;2;EP2`ReL0/8]G0;2:F@2`RU/0/8YM0P2`REh20;>>HP030;:=H02aSEd0/8aJ
0080[h]G00<0[X]E0;2<F02_ReL00`2_ReL30:j:EP<0/HeM0P2`S5`30:n;F`80[XYJ0`2_Re/30;2<
G080[HQD00@0[XUE0:n:EP2_RUH0/8]G0P2aS5P01P2`SEL0/8aH0;2<F02`S5X0/8aL0;2;GP80/8]O
202_RUD01P2`ReH0/8]G0;2;E`2`RUT0/8YK0;2:G@80/8UN00<0[XYJ0:f9F@2[QeL00P2ZQUH00`2[
QeL0[HUI0:j:FP080:f9F@030:j:FP2]RET0[8QH0080[8QH00<0[HUI0:n;F`2_Re/0102]QeP40:b6
E`80[8MC0`2]R5@30:j9E@80ZhMG0`2/R5P30:f9F@80[hYF0P2^RED20:f8E00:0:b7D`2[QU80ZhIB
0:j9E@2/Qe<0ZXEA0:b7D`2_RUH0/8]G0:n:EP@0[8MC0`2[QU820:Z5D@P0[8MC202/QUL0102YQ500
ZXEA0:Z5D@2ZQE420:^6DP80[8MC202[QU420:n;F`080:j:FP2/R5P0ZhMG0:Z6EP2YQED0Z8AD0:^6
DP2/Qe<20:f8E0040:b7D`2ZQE40Z8=?0:N2CP80ZXEA0`2YQ5030:R3C`P0ZHA@00H0ZhEH0:Z4E@2Z
Q5D0ZXAC0:V4D02YQ4l20:R3C080Y7m;00<0YH1<0:J1C@2WPTh00`2XPdl30:R3CP80Yh9=0`2VPD`8
0:F1C@80YX5=102TOd/:0:J1C@80YH1<0`2VPDd60:N2CP<0YX5=0P2UP4`0102XPdh0Yh9=0:N2C@2V
PD`30:F0B`80Y7m:0`2UP4/60:J1C00:0:N2C@2XPdh0Z8=>0:R3CP2VPD`0Y7m:0:=nB@2SOdl0Y81@
0:F1D@80YX9B00<0YH5A0:B0D02SOdl00P2TP4`30:=oB`<0XWi:202ROTh20:=nB@80XWe800@0XGa7
0:1kAP2PNdH0WgY5102PNdL30:5lB0090:9mB@2NNd<0Wga409mlAP2ONdL0X7a:0:1lC02QODd0XGa?
00P0XGa700/0X7]60:5lA`2RODP0Xgi90:9mB02QO4L0WgY509iiA02NNDD0WgY60:5lB0020:9mB@0;
0:5lB02ONTH0WWU509Ye@@2KMT80W7M309ehA02NNDD0WgY60:1kA`2QO4P00`2ONTH20:1kA`<0XGa8
0P2SOdl0102ROTh0XGe=0:5mC@2PO4`209mkB`80X7a800<0Wg]709ijAP2MNDD00P2LN4@00`2KMd<0
WWU509iiA@0609iiA@80W7M30P2MN4@209iiA@80WgY600<0WWU509ehA02LMd<00P2JMD400`2LMd<0
WGQ409iiA@0309iiA@80WGQ4102LMd<209ahA080VgM30`2JMT80102IMD40VGE509QdA02GLd<209Ib
@P0>09Mc@`2HM4@0VGE509Ue@@2HM400Ug<o09Ib?P2ELCd0U70l09=_>`2BKSX0UG0l09Ia?@2HLcl2
09Ye@@0309Ud@02HLcl0Ug8n00P0Ug8n00H0VGA009Qc?`2GLSh0UW4m09E`?02CKSX2099]>@0609Mb
?P2FLCd0UW4m09E`?02DKc/0Tfhj0P2BKCT0402DKDH0Tfa3099[@P2AJSl0TF/n09=]?P2EKch0UW0o
09=]?P2DKSl0UFm009I`@@2EKd00U6ho099/?@2AJc`3095Z@b_ooooo000Zooooo`/0VFlm00<0VW0n
09]a?`2KLCl00P2LLT000`2KLCl0VW0n09Y`?P0409Y`?P0309]a?`2MLTD0WG9500<0WG950P2NLdH0
0`2OM4L0VFlm09Y`?P0509Y`?P0309U_?@2KLCl0Vg4o0080Vg4o102LLT0809ib@@P0WW=000<0WWA2
09me@`2QMdD00P2SNDL00`2RN4H0XGM50:1fA0030:1g@`D0XGQ400<0X7M309]f@P2KMT801P2KMT83
09mf@P80X7M30`2OMT801P2LLcl0WGA009ie@@2PMd<0XWU50:=jAP80YGa80P2RN4H20:5gA@80X7I4
0P2OMD<20:1g@`80XGQ40P2RNDD20:=jAP<0XgQ50P2TNDH30:EjA`P0YW]800<0YWe90:ElB02TNdL0
0P2SNTH00`2TNdL0YGa80:ImB@020:AjB080YG]90P2VO4X20:MmB`P0YWa:202XOT`80:QmBP80Yge;
102XOT`20:UoC@P0ZH1<0P2VPD`20:N2C@80Z8=>0P2YQ4l20:J1C@80Yh9>00@0Z8=?0:V4D02YQ500
ZHA@0P2YP4P01P2ZPD/0ZX5=0:^2CP2/PU00[89B0:f3D`80YX5=0P2WPTh20:R3C`80ZHA@2@2XPdl8
0:V4C`P0ZHA@0P2YPe830:Z4D`<0ZhED0P2WPTd0102XPdh0ZHA?0:^6D@2/Qe820:f8D`P0ZXE@202[
QU420:^5E0040:^6DP2[QU40[8MB0:b7D080[8Q>202]R5@20:j9E080[HQC0P2/Qe8=0:^6D@80ZXE@
0`2YQ4l40:b3C`@0Zh9>0`2[PDl20:Z0CP<0ZGm=202XOT`30:=nBP80Y7m;0`2SOTX20:=nA`060:=n
B@2RODT0XWa;0:9lC@2QNd`0XG]>202QN4@809]eAP`0VGA00`2HLcl209Mb?P80Ug500P2FL3l309E_
?P0309A^?@2CKcl0U71000<0UG5100H0Tflo099^?P2@K3`0T6Xk095[?02CKCh209A^?`0309=]?P2A
Jc`0T6Xk0080TFdm0P2@K3`208m[>`80SVXj202<Icd208eX>`80S6Lj0`2;IST308YU>00308UT=`28
HcH0R6<f00<0R6<f00<0Q5lc08EP=027HSH00P28HcL00`27HSH0QV4e08EP=00308AQ=`D0Pf0f0P2:
H3P01027H3L0QV4g08EP=P23H3H2085P=@P0PElb0`1oG38207iK<@<0OEX`0`1oH3@207iO<`<0OEhb
201lG3<307YJ<@<0Ne/b0P1lG3<807]L<0P0NUXc00<0Le<Z07AD:`1fERd00P1hF2l01@1gEbh0MUH]
07EE;01eEB`0MeL^00<0N5P_0P1iFC0207YJ<@80MeP/0P1hFBd407UJ;P@0NET`0P1hF2l207MG;P04
07]K<P1lG3<0O5`c07aL<`80OEdd0P1nGSD807iK<`80Ne/d00@0O5`c07eN<P1nGc40OUla0P1nGc03
07mP=0<0P64e0P21HSH3089S=`<0Pf@h0P24ICT01P24I3/0Q6Di08AU>@24ICL0Q6Df08AV=080Q6Hb
0`28HcH208UT=`<0RVDh0`2<JSX01@2;JCT0RVPh08YX>02:J3P0RFLg0080RVPj00@0RfTk08aZ?02<
JS`0SF/m0P2>K3h0202AKCd0T6`l08m[>`2>JSX0Sf/k091/?02BKSh0Tflo0P2CLSd01P2CLSl0Tg51
09AbA02DLTD0UG=609EbB0<0UgE50`2FM4@209Ec@`80V7M21P2IN4<309]g@`80W7Q40`2MNDD0102M
NT@0WW]509ikA@2NNdD209mlAP80X7e700<0XGi80:9oB@2ROdT00P2ROdT30:>0BPT0YH1<0`2TOd/0
0`2UP4`0YX5=0:N2CP050:R3C`80Yh9>0`2VPDd30:V5D@80ZXIB0`2[Qe<80:b8E0030:f9F@2^RUX0
/8aL0080/HeM00<0/8aL0:j:FP2]RET00`2`RU/20;6;G0<0/XaM0`2cSel20;B@H0<0]I5Q00P0^9=W
0;NBIP2gTVD0]Y9R0;FAG`2dT5`0/hmK0;>@FPP0]i=S00<0^9=V0;VDI`2iU6L00P2iU6L90;ZEJ080
^iIY202kUfL00`2jUVH0^IEU0;VEI@040;VEI@@0^YIV0`2iUFD20;RDI0<0^YIR0`2iUF420;RDH0P0
^YIV0`2hU6@20;VEI@<0^YIV0P2iUFD40;RDI080]i=S8@2hU6@80;JDI100]i=S202iUFD20;^GI`80
^YIV0P2iUFD20;RDI0<0]i=S0P2hU6@30;VEI@P0]iEU202hU6820;VEI@H0^9AT202fTV880;NCH`H0
]I5Q0P2fTV820;ZFIP060;VEI@2gTf<0]Y9R0;FAH@2dT600/hmO0P2gSV00102fT640]I5Q0;FAH@2c
TF420;6AH080/hmO0`2dT6030;FAH@T0/hmO202cSe/20;FAH@H0]91P202cSel30;:>GP80/hmO0P2d
T6001`2eTF40]I9L0;FAG@2dT5`0]91N0;B@H02dSf800P2dSf<20;FAH@H0]91P202eTEd80;:>GP80
]8iO0P2cSEh20;:<G@80/H]L0P2cSUX00`2cSE`0/heN0;>=H0020;><H@060;><H`2cSel0/hmO0;:>
GP2aSEd0/8aL0P2_Re/01P2^RUX0/HaG0;6<E`2aS5P0/H]J0;6;G080/H]N00@0/HYO0:n;F`2_Re/0
/8aL2@2aSEd40;:>GP80/hiT00<0/XeQ0;:=H02bSUh00P2aSE/00`2aSET0]Y1Q0;J@H@060;J@H@P0
/HmO102bSUh40;6=G@T0/XeP202aS5l20;6<H0030;2;GP2`S5`0/8aJ0080/8aH00<0/8eG0:j:FP2^
RUX00P2_Re/20;2<G080/HeM00H0/8]D0;2;EP2`ReH0/8]G0;2:F@2`RU/20;2:G@090;B?H`2cSV80
/hiQ0;:>GP2aSE/0/8aH0:n;E`2_S5H0/8aH00<0[h]G00@0[XYF0:f9E@2]RED0[HUE0`2aSEd30;2<
G0P0[h]K0P2`S5`20:b7D`040:f8E02^RED0/8]G0;6<F080/XeI00H0/8eG0;2<F02`S5P0/8aJ0;2<
G02`Reh20;2;G`P0[hYF00H0/HaG0;6<F02aS5P0/H]J0;6;G02aReh20;6:G`030:j:FP2]RET0[8QH
0080ZhMG00<0[8QH0:f9F@2^RUX0202]RET20:Z6EP80ZhMG00@0[8QH0:f9F@2^RUX0[h]K102]QeP4
0:b6E`80[8MC1P2]R5@01P2YQED0ZXIF0:Z6EP2[QeL0[8QH0:f9F@80[XYJ0P2`ReL0202_RUH0[HQD
0:b7D`2/Qe<0ZhIB0:Z5D@2YQ500[HQD0`2/Qe<01@2]R5@0[XUE0:f8E02/Qe<0[XUE0080[HQD00<0
[8MC0:^6DP2ZQE400P2YQ5080:b7D`040:Z4E@2[QEH0ZhEF0:^5EP<0[8IG00<0[HMH0:V4D02YQ500
0`2ZQE4;0:^6DP80[h]K00H0[XYJ0:f9F@2/R5P0ZhMG0:Z6EP2YQED20:b6E@80[HMF00@0ZhED0:V3
DP2WPE00YGm>0P2ZQE430:V4D0<0Z8=?202YQ5001P2ZQ5L0ZXAE0:Z4E@2YPe80ZHA@0:R3CP80Z8=<
00H0Y7m;0:F0C02VPDd0Yh9>0:V4D02ZQE420:^6DP080:Z5D02YQ4l0Z8=>0:N2C@2VPD`0YH1;0:Ao
BP2SOTT80:F1CA80YH1<0`2VPDd60:N2CP<0YX5=0P2UP4`01@2XPdh0Yh9=0:N2C@2VPD`0YH1;0080
Y7m:0P2SOTT20:F0B`@0YX5<0P2WPTd00`2VPD`0Yh9=0:R3CP020:R3CP060:J1C02TOdX0Xgi90:9n
CP2TP500YH5A0P2VPU800`2UPE40Y81@0:9nCP020:F1C@030:B0C02SOd/0XWi:0080XGe900<0X7a8
0:9nCP2ROTh01P2ROTh01P2TOdX0Xgi90:=nB@2RODP0XGa70:1kAP80WgY50P2ONTH0102PNdL0XGa8
0:5lB02RODT20:=nBP80Wga400<0Wga60:1lB02PO4X00P2QODd00`2QO4l0XGa80:5lB0060:5lB003
0:1kAP2QO4L0XWe80080XWe800D0X7]609iiA02MN4<0X7]70:5lB0020:9mB@040:5lB02PNdL0WWU5
09ag@`80VgI200@0W7M309ehA02NNDD0WgY60P2PNdL309mjAP80X7]70`2QO4P00`2TP500Xgm?0:=o
C`020:9nCP80XGe=00H0X7a<0:1lB02PO4P0Wg]709ijAP2MNDD209ahA00309]g@`2ONTH0WgY600H0
WgY60P2LMd<209ehA080WWU50P2ONTH00`2NNDD0WGQ409ag@`0209Ye@@0309ag@`2MN4@0WWU500@0
WGQ41@2LMd<309]g@`<0VWI20P2IMD400`2IMDD0V7A409QdA00509Mc@`0;09Ue@@2HM400Ug<o09Ea
?@2DL3`0TVhj095]>@2@K3P0UG0l09Ia?@2HLcl00P2IM4000`2HLcl0Ug8n09Ia?@0809Ia?@0609Ud
@02HLcl0Ug8n09E`?02CKSX0TVdi0P2@JcL209Ia?@0309E`?02DKc/0Tfhj0080TVdi00`0TF`h09=/
@@2BJd00TFXo091Z?@2AJch0TV`o09A^?`2FL440Tfdn09A^?`2EKd0209I`@@0309E_@02CKCh0TV`m
00<0TFY1:oooool002[ooooo2@2IKcd409Y`?P<0Vg4o0`2JL3h209]a?`<0VW0n00@0Vg1309aaA02M
LTD0WG95102NLdH309Y`?P80VFlm0`2JL3h409ab@0@0Vg4o202NLT480:1b@00309id@P2OMD<0XGM5
0080XgU700<0XWQ60:5gA@2PMT@00`2QN4@50:1g@`030:5hA02KMT80VgI200H0VgI200<0X7M309mf
@P2OMT80102OMT802@2PMd<0W7<o09ac?`2NMD40WgI20:5hA02SNTH0Y7]70:ElB0020:9hAP80XGM5
0P2PMT@209me@`<0XGQ40P2RNDD30:=jAP<0XgQ50P2TNDH;0:EjA`030:ImB@2UO4P0XgY60080XWU5
00<0XgY60:ElB02VODT00P2TNTP20:EkB@80YWa:0P2WOD/80:IlBPP0Z7i<202XODX00`2VO4X0Yge;
0:MmB`020:QnC080ZGm=00<0ZX1>0:V0C02YP4`01P2YP4`20:J1C080Yh9=0P2XPdh20:V4C`030:J1
C@2WPTh0Yh9>0080Yh9>0`2XPdl20:QoA`060:V0BP2ZPDd0Zh9>0:b2D02/PU80[H=C0P2VPDd20:N2
CP80Z8=?0P2YQ5090:R3C`P0ZHA?2`2YQ5030:Z5D@80ZhIB0P2WPTd0102XPdh0ZHA?0:^6D@2/Qe82
0:f8D`P0ZXE@202[QU420:^5E0040:^6DP2[QU40ZhIA0:^6C`80ZhM=202]R5@20:j9E080[HQC0P2/
Qe820:^6D@P0[8MB0`2[QU420:Z5D0<0ZHA?00<0[XEA0:f4D02]Q5000P2/Pdl20:^2CP040:Z1C@2/
PU00[89@0:b2D080Zh5?0`2ZP4h80:QnC0030:F0C02TOd/0Y7m;00@0Y7m;00H0YH1<0:AoB02TOdP0
Xgi90:=nBP2SOD`20:9lC@030:9lC`2RNDD0XWU50080XWU5102SNTH809]eAP/0VWE10`2IM40409Qc
?`<0Ug8n0P2FLCd209E`?00309A`@02ELD40UW920080UW9200H0U710099^?P2AKCd0TfXl09A[?@2E
K3h209M^@00309E/?P2DJcd0TfXl00@0TFdk102@K3X808eX?P<0SVTl0P2=J3/608aW>P80RfHi00H0
RVDh08UT=`29I3L0Qf8e08QS=P29I3L208YU>00308QS=P27HSD0QV4d00<0Q64g1@25HSP208YP>004
08QQ>027HSP0QV4g08AQ=`80Pf8g2022H383085N=080P5dc0`1oG382085R=P<0P64e0`1oH3@807eM
=0@0O5da0P1mGS8207iO<`P0O5da201hF3401`1dEBT0MUL[07QI;@1iFRh0NU/_07UJ;P1hFBd00P1g
F2`307YK;`80Ne``0`1lGC4207YI;0<0NeX]0`1lFbh307]L<0<0NU/_0P1iFRh207eM=080OUhe0P1o
GcH2081P=`P0P5de0P1oGSD207mN<`0407mN<@20H340PF4`085Q<0@0PF8f0P22HcL608=T>080Q6Di
0P25ISX01P25IC`0QFHj08EV>P25ISP0QFHg08EW=@80QFLc0P29I3L208YU>0<0RfHi00@0S6Lj08e[
>`2=Jc/0SF/k1@2<JSX01@2;JC/0S6Xl08aZ?02=Jcd0SV`n0080Sfdo00@0T6i0099^?P2AKCd0T6`l
0P2?Jc/00`2AKCd0Tflo09A`@00209Ac?@0309Ed?`2FMD80UgE50080UgE700@0UgE809QfAP2HMTH0
V7I60`2GMDD209IdA00309]jA@2JND@0VWU400<0VGQ30P2JND@309ahA080WGU50`2NNTH209ikA@80
Wga60`2PODL01@2QOTP0XWm90:9oB@2ROdT0Xh1:0080Y85;0P2UPT`90:F0C0040:AoB`2UP4`0YX5=
0:N2CP<0Z8=?102YQ5020:R3C`<0Yh9>0P2YQE420:Z6DP80ZhMC0P2/R5@80:f9E@030:j:FP2_Re/0
/8aL0080/XiN00<0/8aL0:n;F`2^RUX00`2aRe`20;:<G@<0/heN0P2cSel20;B@H080]I5Q0P2fTV82
0;RCI`030;NBI@2fTV80]I5O0080]91L00<0/i1J0;NCH`2gTf<01P2gTf<30;RCIP030;VDI`2jUFP0
^YEX00P0^iIY0P2jUFP80;^GI`<0^IEU0P2jUVH30;VEI@<0^YIV0`2iUFD20;RDI0<0^YIT0`2iUF<2
0;RDHPP0^IES0P2hU6@20;VEI@80^YIV0P2kUfL00`2jUVH0^IEU0;VEI@020;RDI080]i=S00<0]Y9R
0;RDI02hU6@07`2hU6@80;JDI100]i=S202iUFD30;ZFIP80^IEU0`2hU6@30;NCH`80^9AT0`2iUFD8
0;NEI@P0^9AP0P2gTf<60;RDI0P0]I5Q202gTf<60;JBHP80]I5Q0P2jUVH01P2iUFD0]i=S0;JBHP2e
TF40]91P0;>?G`80]hiP00@0]HmP0;B@H02dT600/Y1P0P2aTF020;>?G`<0]91P0`2eTF490;>?G`P0
/hmK1P2dT6020;FAH@P0/hmO00<0/HeM0;:>GP2bSUh00P2cSel30;B@H0060;BAF`2dT5`0]91L0;B@
GP2dT600]8mR0P2eT6@60;B@H080]I5Q202dT5`40;6=G@@0/XiN0P2dSUl40;>=GP80/XaM0P2cSUT0
0`2cSUX0/heL0;>=GP020;>=H0070;><H@2cSel0/XiN0;:>GP2aSEd0/8aL0:n;F`020:j:FP80/XeI
00<0/XaK0;:<G@2bS5l00P2bRf000`2bRf80/8aL0;2<G0030;2<G0040;6=G@2bSUh0/XiN0;2<G080
/HeM0P2bSUh20;>?G`060;B@H02cSFH0/heV0;:=H`2bSF40/XeP0P2aSEd00`2aSE/0]Y1Q0;J@H@06
0;J@H@P0/HmO202bSUh90;:=H0P0/8]N0P2`Rel00`2aS5l0/HeM0;6=F`020;6=F@040;6>F02^RUX0
[XYJ0:j:FP80[h]K0`2`S5`01P2aSE<0/HaE0;6<E`2aS5L0/HaH0;6;FP80/H]L0P2cSV800`2bSF00
/HeM0;2<FP020:n;E`030:j;E@2^RUH0[XYF00<0[XYF0`2]RED20;:>GP<0/HeM1@2`S5`60:n;F`80
[8MC00@0[HQD0:j9E@2`ReL0/HaH0P2bSET01P2_S5H0[h]G0:n;E`2_ReT0[h]K0:n:G@80[hYN202_
REP01P2aS5L0/HaH0;6<F02aReX0/H]L0;6;GP80/HYO00<0[h]K0:j:FP2/R5P00P2[QeL00`2/R5P0
[XYJ0:n;F`080:f9F@80ZXIF00<0ZhMG0:b8F02]RET00`2^RUX20:j8F@80[HMH0P2/QUL20:^5EP80
[HQD1P2/Qe<20:V5E@030:Z6EP2[QeL0[8QH0080[HUI00D0[XYJ0;2;E`2_RUH0[XUE0:f8E0020:b7
D`040:Z5D@2YQ500ZHA@0:b7D`<0[HQD00D0[8MC0:^6DP2/Qe<0[HQD0:j9E@020:f8E0030:b7D`2[
QU80ZXEA0080ZHA@202[QU830:Z4E@80ZhEF0`2/QUL30:V4D0<0ZXEA0P2[QU880:^5E080[XYJ00@0
[HUI0:b8F02[QeL0ZhMG0P2ZQUH0202[QEH0[8IG0:b6E`2/QUL0ZhEF0:V3E02VP540Y7i?0P2ZQE43
0:V4D0<0Z8=?202YQ5001P2ZQ5L0ZXAE0:V3E02YPe80Z8=?0:R3CP80Yh9;0P2UP4`03P2VPDd0Z8=?
0:V4D02ZQE40ZhIB0:b7D`2ZQE00ZHA?0:R3CP2WPTd0YH1;0:AoBP2SOTT0XWe8202VPThB0:F0C0<0
YX5=1P2WPTh30:J1C@80YH1<00@0Yh9=0:J1C02VPD`0YH1;0`2TOdX20:=nB@80YH1;0P2VPD`20:N2
C@80Z8=>00<0YX5<0:N2C@2XPdh00P2XPdh01P2VPD`0Y7m:0:=nB@2ROTh0Xgm?0:B0D080YX9B00<0
Y81@0:=oC`2ROTh00P2UPDd00`2TP4`0Xgm;0:9nBP020:5mB@030:1lB02ROTh0XWi>00H0XWi>0P2S
OTT20:9mB0050:5lA`2PNdH0X7]609mjA@2ONTH00P2PNdL01@2QO4P0XWe90:=nBP2SOTX0Y7m;0080
Wga400H0X7e70:1lB02QOD/0XGe=0:9nCP2ROE080:5kBP0809mjA@2PNdH0XGa70:9mB02QO4L0X7]6
09iiA02MN4<20:5lB080XWe900D0XGa809mjAP2MN4@0W7M309]f@P0209ag@`0509ehA02NNDD0WgY6
09mjAP2PNdL00`2ONTH20:1kA`<0XGa80P2SOdl40:9nCP80XGe=0P2PO4P00`2ONdL0WWY609eiA@02
09ahA00309]g@`2PNdL0X7]700H0X7]70P2LMd<209ehA080WWU50P2ONTH00`2NNDD0WGQ409ag@`02
09Ye@@0309ag@`2MN4@0WWU500T0W7M30P2KMd<309Yf@P<0VGE10`2IMDD209QdA00>09Mc@`2FLT80
UG5109Ue@@2HM400Ug<o09Ea?@2DL3`0TVhj095]>@2@K3P0UW4m09Mb?P2HLcl209Ud@00309Qc?`2F
LCd0UG0l00P0UW4m00H0VGA009Qc?`2GLSh0UG0l09=^>P2BKCT2091[=`0609Ia?@2EL3`0UG0l09A_
>`2CKSX0TVdi0P2AK3P00`2CKCh0TV`m095[?P02091Z?@06099[@02DKD80UFi3099/?@2CKCh0U6ho
0P2FL4400`2EKd00Tfdn099/?@03095Z?b_ooooo000Zooooo`P0VFlm202JL3h00`2IKcd0VW0n09]a
?`0209ab@00709]a?`2JL3h0VFlm09U^@@2JKd80Vg1309ebA@0309icAP0409ebA@2LLT00Vg4o09Y`
?P80VFlm00@0VW0n09]a?`2LLT00WG=10`2LLT0309]a?`0309Y`?P2NLT40WW9100H0WW91202QLSh0
0`2MLd40WWA20:1fA0020:9hAP060:5gA@2PMT@0WgE30:=jAP2RNDD0XGQ4102OMT800`2PMd<0XGQ4
09]f@P0709]f@P030:5h@P2PMd40WgI00080WWDo00T0WgI00:1g@@2QN480W7<m09ed?P2NMCl0WgI0
0:1g@@2RND<00P2SNT@20:9hAP80XGM50P2PMT@209me@`80XGQ40P2RNDD30:=jAP040:AkA`2SN4D0
XgQ50:=hA@80Y7U62`2UNTL00`2UO4P0Y7]70:=jAP020:9iA@030:=jAP2TNdL0YGa80080Y7Y80P2U
NdT20:IlBP80Yge;202VO4X80:QnC0P0Yga90P2VO4X0102WOD/0Z7i<0:QnC02YOdd20:Z0CPP0ZH1<
0P2VPD`20:N2C@80Z8=>0P2YQ4l80:N2CP80Z7m700@0ZH1:0:V0C02ZPDd0Zh5?0P2/PU820:J1C@80
Yh9>0P2XPdl20:V4D0T0Z8=?202YQ4l80:V4D080Z8=>0P2YQ4l30:Z5D0040:^6D@2XPd`0Z8=<0:V4
C@80ZXE>00<0ZhI?0:b7D02/Qe00202YQ4d80:^6D@080:b6E@2[QE@0ZhIB0:^6D@2ZQE00ZXE>0:Z6
C02YQD/80:f8E080[XUD0P2]R5<20:b7DP80ZhIA202]R5<30:^6D@80ZXE@0`2YQ4l01P2_QU80[XEA
0:j5D@2]Q500[8=?0:^2CP80ZX5=0`2]Pe420:b2D0<0Zh5?202YOdd20:J1C@040:F0C02TOd/0Y7m;
0:F0C080YX5=0P2TOdP00`2TOdX0Xgi:0:=mC0020:9lC@040:9lC`2SNTH0XgY60:=jAP<0Y7]70P2U
O4P809afA`T0VgI20`2JMD4209Ud@0<0V7<o00@0VG@o09Qc?P2HLch0V7<n0P2GLSd209Ia?080UG51
0`2GLd<01P2ELD40Tflo099^?P2EJSd0UV/n09M/?`80V6e000@0Uf`o09I[?P2EJSd0TVhj1`2AKCT8
08mX?`04091[?P2?JSd0SfXm08mZ?@80SVTl0P2=J3/408iY?00408eX>`2<IcX0RVDh08UT=`80RV@e
0`2<ISL00`2:I3D0RF<d08MQ<P0308ER>080QV<i0`27I3X00`2;HCT0RV0h08QQ>00208MR>00508ER
>024HcP0Q6<h08AR<P23HC401022H3001023HC40Q68b08=P=P23H3H3089O=@<0PEhd0P22HcL2085R
=P80P64e0P1oH3@807eM=080OEhb0P1nGc<207mP=080P64e201nGc<807QH<@0707IG:`1gF2`0NEX^
07YK;`1kG300NU/_07UJ;P0207QI;@<0Ne``0P1lGC4307eN<P<0OE/]0P1nG2h307mM;`<0OEhb0P1l
GC4307]L<080OUhe0`1oGcH3081P=`P0PUlg00P0QF8j08AQ=`23H3H0PV0c089P<P23HC40Q6<`08ET
<@80PV<g0P23I3P208AU>@80QFHj00@0Pf@h08AU>@24ICT0Q6Di0P25ISX208IW>`0608MW?P27J3`0
QfPl08MX>P27J3T0QfTg0P27JCD308aV>@80SFLj0`2>J3/208aZ>P80SF/k0P2>K3`208m]?@<0SV`n
0`2?KCl2091^@00=09=_?`2BKSh0TFdm091/?02AKCd0TVhn09A`@02ELD40Tg<j09Ad>`2FMCl0UgI1
09QgA00209QfAP0309QfB02HMTH0V7I600H0V7I600@0WGa709akAP2KNTD0VWU40P2IN4<00`2JND@0
VgY509eiA@0209eiA@80WWY60`2ONdL209mlAP80X7e70`2QOTP30:9oB@040:>0BP2TPD/0YH9<0:F2
C080YX==2@2VPDd00`2UP4`0YX5=0:R3C`030:V4D0030:R3C`2WPTh0ZHA@00L0ZHA@0`2ZQU820:^7
D`<0[8QD202^RUH00`2`RU/0/H]L0;:<G@020;>=GP030;:<G@2aRe`0/8YK00<0/XaM0P2cSEh30;B>
G`<0]91P0P2eTF430;JBHP80]i9V00H0]i9U0;JBHP2fTV00]Y9N0;FAG@2eTU`80;NCH`80]i9U00<0
^9=V0;VDI`2jUFP00P2kUVT40;bGJP<0^iIY0P2jUFP80;^GI`030;RDI02iUFD0^YIV0080^iMW00<0
^YIV0;VEI@2hU6@00`2jUVH30;VEI@80^9AT0`2jUVH30;VEI@80^9AT202iUF430;VEI@80^YIV0`2k
UfL20;ZFIP040;VEI@2hU6@0^9AT0;NCH`80]Y9R4@2hU6@80;VEI@P0^9AT202fU6@@0;NCH`P0^IEU
0P2jUVH20;VEI@<0^9AT102gTf<20;RDI0<0^IEU202gUFD80;REG`80]i5R0P2hTV<40;VCI0P0]I5Q
2`2gTf<30;JBHP80]I5Q0P2iUFD0102hU6@0]i=S0;JBHP2fTV820;FAH@030;R?H@2gSV00]8iO0080
/XiN00@0/HmO0;6AH02bTV40]I5Q402dT6080;:>FP80/hmO0`2dT6030;FAH@P0/hmO00@0/8aL0;6=
G@2bSUh0/hmO0P2dT600202cSel0/XiN0;>@FP2cSe/0]91L0;B@GP2dT600]I1S0P2eT6@20;>?G`<0
]91P0`2eTF480;B@G0<0/8aL0P2aSEd30;:>GP<0]8iO1@2cSEh20;>>E`030;>>F@2cSUX0/heL0080
/heN00H0/heP0;:>GP2bSUh0/HeM0;2<G02_Re/20:j:FP060:f9F@2bS5/0/XaK0;:<G@2bS5l0/X]P
0P2bRf800`2bRf@0/HeM0;2<G0030:n;F`030;6=G@2bSUh0/hmO0080/8aL00<0/HeM0;:>GP2cSel0
0P2dT6001`2eTF40/heX0;>=J02bS6D0/XeS0;:=H@2aS5l00P2aSEd80;B>G`P0/8iN00@0/HeM0;:>
GP2bSUh0/XiN0`2cSel00`2dT600/HaO0;6<G`070;6<G`P0/8]N0P2`Rel00`2aS5l0/HeM0;6=F`02
0;:>FP030;:?F@2]RET0[XYJ0080[XYJ0P2_Re/20;2<G080/HeC00@0/HaE0;6<E`2aS5L0/HaH0P2a
ReX0202bSF40/HaP0;6<G`2`S5`0[h]I0:j:EP2]RED0[HYD0P2/R5@20:f9E@<0[XYF00@0[h]G0;:>
GP2bSUh0/XiN0P2aSEd60;2<G0<0[h]K0P2^RUX20:f8E0040:j9E@2_RUH0[hYF0;2;E`80/HaH00H0
[haF0:n;E`2_ReL0[h]I0:n;F`2_RUd20:n:GPP0[hUJ00H0[hYE0:n:EP2_RUH0[hUH0:n9FP2_RE`2
0:n8G@030:n;F`2^RUX0[HUI0080[8QH00<0[HUI0:j:FP2_Re/0202]RET01@2[QeL0[8QH0:f9F@2^
RUX0[h]K0080[XYJ00H0[HUI0:n9FP2^R5T0[XQI0:f7F02/QUL20:^5EP030:Z4E@2]R5@0[HQD00<0
[8MC0`2[QU830:Z6EP<0ZhMG0P2/R5P20:j9E@030:f8E02/Qe<0ZhIB0080ZhIB0P2ZQE40202[QU80
[HQD0:n:EP2]R5@0ZXEA0:V4D02ZQE40[HQD0`2/Qe<30:^6DP80ZXEA202[QU850:^5EP<0ZXAE0P2X
Pdl20:V4D0<0ZXEA00<0ZhIB0:^5EP2[QEH01P2[QEH0102/R5P0ZhMG0:^7E`2[QeL20:Z6EP80ZHEE
0P2ZQ5L01P2[QEP0[8II0:^5F02YPeH0Yh5D0:EoDP80ZXEA0`2YQ5030:R3C`P0ZHA@00H0ZH=F0:V3
E02YPe@0Z89A0:R3C`2WPTd20:N2B`<0YX5=00<0Yh9>0:R3C`2YQ5000P2ZQE40202YQ4l0Z8=>0:N2
C@2VPD`0YH1;0:AoBP2SOTT0XWe8202VPTh20:AoB`@0YX5=2P2TOd/20:F0C0<0YX5=1P2WPTh30:J1
C@80YH1<2@2TOdX20:F0B`80YX5<00H0Yh9=0:R3CP2YQ4l0ZHA?0:J1C02WPTd30:R3CP060:J1C02T
OdX0Xgi90:9nCP2SOdl0Y81@0P2UPE400`2TP500Xgm?0:9nCP020:B0C0<0Xgm;0`2ROTX80:9nCPP0
XGa70`2QO4P30:9mB@80Xgi:0P2PODD00`2PODL0XGe90:5mB`020:9nCP030:9mD02QNd`0XG]<00H0
XG]<00<0WgY50:1kAP2QO4L00P2QO4L01@2ONTD0WWU409ag@P2PNdL0XGa80080XWe900<0XGa80:1k
A`2NNDD00`2LMd<209ehA080WWU51@2ONTH20:1kA`<0XGa8202QODd20:1lB00309mkA`2NNTH0WGU5
0080W7Q400<0VgM309mjAP2ONTH01P2ONTH209ag@`80WGQ40P2NNDD209mjAP0309iiA@2MN4@0W7M3
0080VWE100@0W7M309ehA02NNDD0VWE10`2KMT8409ag@`0309ehA02KMd<0VWI20080VWI20P2IMD42
09Qd@0@0VGE501@0V7A409Mc@`2ELD40U71009Ue@@2HM400Ug<o09Ib?P2ELCd0U70l09=_>`2BKSX0
UW4m09Mb?P2HLcl0VGA009Qc?`2GLSh0UG0l09A_>`P0UG0l00H0VGA009Qc?`2GLSh0UW4m09E`?02C
KSX2099]>@80UG0l00<0U6lk09=^>P2BKCT00P2AK3P0302@JcL0TV`k095[>P2@JS/0T6Xm091Y?P2B
Jd80Tfa309E^A`2?JCX0TF/l099/?@<0U6ho0P2BK3d3095[?R_ooooo000Zooooo`P0VFlm0P2KLCl6
09Y`?P0309Q^?02IKcd0Vg4o0080W79000L0Vg4o09U_?@2HKS`0UV/n09Q]@02JKd80W7540080WG95
0P2LLD@00`2NM480WG=109]a?`0209Y`?P0309]a?`2MLd40WWA20080WG=10P2LLT0209]a?`80VW0n
202NLT480:5b?00<09]a?`2MLd40WgE30:1fA02QMdD0X7I409me@`2NM480Y7]70:=jAP2QN4@0WgI2
0P2NMD400`2OMT80X7M30:5hA00809]f@P030:5h@02PMcl0WWDm0080WG@l00<0WWDm0:1g?`2QN400
0P2NMCd209mf?P80X7Lo0P2QN4020:9hAP80XGM50P2PMT@209me@`<0XWU50`2SNTH20:AkA`<0XgQ5
0P2TNDH30:EjA`P0Y7U600<0YGa80:AkA`2RNDD00P2QN4@00`2RNDD0Y7]70:ElB0020:AjB080YG]9
0P2VO4X20:MmB`P0YWa:202XOT`80:MlB@050:EkB@2VO4X0YWa:0:MmB`2YOdd00P2ZP4h00`2[PDl0
ZH1<0:V0C0060:V0C080YX5<0P2WPTd20:R3CP80ZHA?102WPTh40:J1C@80ZH1800@0ZH1:0:V0C02Z
PDd0ZX1>0P2ZP5020:J1C@80Yh9>0P2XPdl20:V4D0T0Z8=?202YQ4l80:V4D0<0Z8=<0P2YQ4d30:Z5
CPP0ZXI<202YQD/80:^6D@80[8IE00@0ZhIB0:^6D@2ZQE00ZHA=0P2YQD/80:f8E080[XUD0P2]R5<2
0:b7DP80ZhIA202]R5<30:^6D@80ZXE@0`2YQ4l01P2`Qe<0[hIB0:j5D@2]Q500[8=?0:^2CP80ZX5=
0P2^Q5820:f3D@<0[89@00<0Zh5?0:Z0CP2ZP4h01P2ZP4h00`2XPdl0Yh9>0:F0C0020:AoB`030:F0
C02WPTh0Z8=?0080YH1900<0Y7m:0:AoB`2SOD`00P2SODh0102RO4l0XgY60:=jAP2TNdL20:ElB0<0
YWe9202LMTL909ag@`80VgI20P2JMD4309Ud@00409Qc?`2IM3d0VG@m09Ud?@80V7<l0`2GLS/02`2E
LD40UW9209Mc@`2HM4@0Ug=309Ib@P2DL400Tflo09I[?P2GK3l0V6e00080VFi100<0V6e009M/?`2F
Jch0202BKSX8099X@004095/?`2@Jch0T6/n091[?P80SfXm0P2>JC`02P2?JSd0T6/n091[?P2@Jch0
SfXm08eX>`2;IST0RF@g08eU=02>ISD308mW=P0408eU=02;Hc80RV8a08ER>080QV<i0P27I3X208QU
>`0408UV?02;HCT0Rf4i08UR>@80R6<i00H0QV<i08ET>@25I3T0QF@a08AS<023HRl2089Q;P0308=R
;`24Hc00QF@a00<0Q64g0P23H3H3089O=@04089S=`21HSH0PF8f085R=P80P64e0P1oH3@807eM=0<0
Of0b0P20HC<3085R=0P0Of0d201lG3D01`1gF2X0N5T[07YK;@1kG2h0O5d_07]L;P1jFbd00P1iFR`2
07]L;P80O5d_0`1mGS000`1nGc40OU`/07iL;00207mM;@<0P5h^00<0PEl_07mP<P1nGc400P1nGc42
07eN<080O5d_0`1nGSD207mO=P<0P60g2023H3P02029IS`0R6Hi08IT=`25HcD0Q68b08ET<@27IS40
R6Lb0`24ICT208EV>P<0QVLk0P24ICT208EV>P<0QVLk00L0QfPl08QX?`28JCd0R6Tm08QY>`28JCX0
R6Xh0080R6Xf0`2?ISX2091W>`<0TFPl0P2;JCT0102<JSX0SV`l08m]?@2AKcl2099`@080TFm10`2@
KT0308m]?`0?09Ea@@2DL400Tflo099^?P2CKcl0U71009Ib@P2GLd<0TW8g09=c>P2FMSd0V7M109Uh
@`2IN4D0V7I600<0UgE50P2HMTH03@2IMdL0VWQ809]iB@2KNDT0Wgi909imB02KNTD0VWU409Uh@`2J
ND@0VgY509akAP2MNDD00`2NNTH209mkA`80X7a80`2PODL20:5nB0D0XWm900H0Xh1:0:B1B`2UPT`0
YX==0:N4CP2XQDl:0:N2CP080:R3C`2ZQE40ZXEA0:Z5D@2YQ500Yh9>0:F0C02WPTh20:R3C`050:V4
D02ZQE40ZhIB0:^6DP2/Qe<00P2ZQU820:^7D`@0[8QD202_ReL00`2cRU`0]8]M0;F<GP020;J=G`04
0;F<GP2dRed0/hYL0;:<G@<0/heN0P2dSUl20;F?H080]91P0P2eTF440;JBHP80]Y5U00<0]Y5T0;JB
HP2gTf400P2gTel00`2gU5h0^9AT0;RDI0060;RDI0060;JAI02gTVD0^9=V0;VDI`2jUFP0^iIY0P2l
UfX20;fHJ`80_9MZ0P2kUVT20;ZEJ0P0^iMW00<0]i=S0;RDI02jUVH00P2kUfL00`2jUVH0^9AT0;NC
H`030;ZFIP<0^IEU0P2hU6@30;ZFIP<0^IEU0P2hU6@80;RDH080^IEU0P2jUVH50;^GI`80^YIV00D0
^IEU0;NCH`2fTV80]Y9R0;FAH@0A0;RDI0P0^IEU202hU6@80;JDI0P0]i=S202hU6@;0;VEI@<0^9AT
1@2gTf<20;RDI0<0^IEU202gUFD80;REG@030;R?H@2iT680^I1R0080^Y5S0P2kTV@00`2lTfD0]91P
0;B@H0060;B@H0P0]i=S0P2hU6@20;NCH`80]Y9R0P2eTF470;NCH`040;JBHP2hSf40]hiP0;>=GP80
/HeM00<0/8iN0;6AH02bTV400P2fTV820;FAH@040;B@H02cSel0/XiN0;:>GPT0]91P202bSUX30;>?
G`030;B@H02eTF40]I5Q0080]Y9R202cSel00`2_Re/0/8aL0;:>GP020;B@H0040;>?G`2bSUh0/HeM
0;>@FP80/hmK00<0]91N0;FAH@2eT6<00P2fTFD30;>?G`030;B@H02eTF40]I5Q0080]Y9R202cSe/2
0:n;F`80/8aL00@0/HeM0;:>GP2bSUh0/XiN0P2cSEh60;B>G`060;>?E@2cSUL0/hiG0;>>F@2cSUX0
/heL0P2cSEh20;:>GP040;6=G@2`S5`0[h]K0:j:FP80[HUI00H0/heL0;>=GP2cSEh0/heP0;><H@2c
S6<20;><I@080;6=G@2`S5`0[h]K0:j:FP2_Re/0/8aL0;:>GP2dT6020;2<G00<0;6=G@2bSUh0/hmO
0;B@H02eTF40]Y9R0;>=J@2cSFP0/XaW0;:<I@2bSF<0/HaP0P2aS5l80;:<G@P0/8iN0P2aSEd20;:>
GP040;>?G`2dT600]91P0;B@H0T0/HaO202_RUd20;2;G`060;6<G`2aSEd0/XiL0;:>FP2cSe/0/i1J
0P2]RET30:j:FP<0[h]K0P2aSE400`2aSE<0/HaE0;6<E`020;6<F00A0;6;FP2`Rel0/8]O0:n:G@2^
RUX0[HUG0:b8E02[Qe<0ZhQB0:V5D@2ZQU80ZhMC0:b8E02^RUH0[h]G0;2<F02aSET00P2cSel20;:>
GP<0/HeM00<0/8aL0;6=G@2aSEd00P2`S5`0102_Re/0[XYJ0:j:FP2^RUX80:n:EP060:j;E@2^RUH0
[XYF0:j:F02^RUX0[XUL0P2^REd80:n9FP060:f8D`2]R5@0[HQD0:f7EP2]QeP0[HMJ0P2]QU/00`2`
S5`0[h]K0:f9F@020:b8F0030:f9F@2_Re/0/8aL00P0[HUI00P0[XYJ0:n;F`2`S5`0/HeM0;2<G02_
Re/0[HUI0:b8F080[hUJ00@0[XQI0:f7F02/QUL0ZhEF0P2ZQ5D20:f8E080[8MC0P2[QU820:Z5D@@0
ZhMG102ZQUH40:b7D`D0ZhIB00P0ZXEA0:j9E@2`ReL0[XUE0:V4D02WPTh0ZHA@0:f8E080ZXEA0`2[
QU830:b7D`P0ZXEA0P2/QUL20:^5EP040:Z4E@2YPe@0Z89C0:R2D`<0Z8=?0P2YQ5030:Z5D@P0ZhEF
102YQED40:R4E0030:N0E@2XPEH0ZX=H0080ZhAI00<0ZX=H0:R1EP2WP5D00P2ZQE430:V4D0<0Z8=?
202YQ5001P2YPeH0ZH=D0:R2D`2XPU40Yh9>0:N2C@80Yh9;102VPDd40:N2CP80Yh9=0P2VPD`0102U
P4/0Y7m:0:AoBP2SOTT80:J2CP030:=nBP2TOd/0YX5=0080Yh9>00<0YX5=0:AoB`2SOTX0202TOd/2
0:F0C0<0YX5=1P2WPTh30:J1C@80YH1<00D0XGa70:9mB02SOTT0Xgi90:AoBP020:F0B`080:J1C02W
PTd0Y7m:0:F0B`2VPD`0Yh9=0:R3CP2YQ4l20:Z5D0030:J1C02WPTd0Z8=>0080Z8=>00H0YX5<0:Ao
BP2SOTT0XGe=0:9nCP2TP5020:F1D@030:B0D02ROTh0XGe=00<0XWi:0`2SOd/20:B0C0P0XWi>0P2O
NTD00`2PNdH0XGa70:9mB0020:=nB@040:AoBP2SOTX0Xgi:0:=nBP<0XWe90P2QO4P20:1mA@030:5n
B02QODT0XWi<0080XWi>00<0XWe@0:5kC02QNd`01P2QNd`00`2NND@0WgY50:1kAP020:5lA`0609mj
A@2MN4<0W7M209mjAP2PNdL0XGa80P2RODT00`2PNdL0WgY609iiA@0409ehA0@0WWU50`2ONTH20:1k
A`<0XGa8102ONd/40:1lC080X7a800<0Wg]709ijAP2MNDD00P2LN4@00`2KMd<0WWU509iiA@0609ii
A@80W7M30P2MN4@209iiA@80WgY600<0WWU509ehA02LMd<00P2JMD400`2LMd<0WGQ409iiA@0309Ye
@@0309]f@P2LMd<0W7M300<0WGQ40`2JMT8209Ue@@<0V7A000P0V7A409UeA@2JMTH0VWI609UeA@2G
Ld<0U71009=_?`<0V7A00P2GLcl309Ib?P0309Ia?@2GLSh0V7<o0080V7<o00<0UW4m09A_>`2CKSX0
202EL3`309Qc?`0409Mb?P2FLCd0UW4m09Ia?@<0UG0l00@0U6lk09=^>P2BKCT0TF`h0P2@JcL0402B
KCP0TF`h091Z>@2?JCX0T6Tn095Z@@2CK4D0U6a808eW>02>J3T0T6Xk099/?@2CKCh0TV`m095[?02@
JS/3095[?2_ooooo000Zooooo`P0VFlm0`2KLCl509Y`?P0309Q^?02IKcd0Vg4o0080W79000T0Vg4o
09U_?@2HKS`0U6Tl09I[?P2IKT40Vg1309ebA@2LLD@00P2KL4<00`2PMT@0WWA209ab@00209]a?`03
09ab@02NM480X7I400<0WG=100<0W79009]a?`2JL3h00P2JL3h809ib@@P0Xg4l00`0VW0n09ab@02N
M480WgE30:1fA02OMD<0WWA209ec@@2UO4P0XgY60:5hA02OMT8309ie@@030:1g@`2QN4@0VgI200L0
VgI200<0XGQ00:1g?`2NMCd00P2MM3`00`2NMCd0X7Lo0:5h@00809mf?P80XWQ60P2QMdD20:1fA080
WgE30`2RNDD20:=jAP<0Y7]70`2SN4D20:AiAP<0YGY7202TNDH00`2UO4P0Y7]70:9iA@020:5hA003
0:9iA@2TNdL0YGa80080Y7Y80P2UNdT20:IlBP80Yge;202VO4X80:QnC0P0Yga90P2UNdT0102VO4X0
Yge;0:UoC@2ZP4h20:^1C`P0ZH1<0P2VPD`20:N2C@80Z8=>0P2YQ4l30:N2CPD0YX5=0P2ZPDT0102Y
P4X0ZH1<0:V0C02YOdd20:UoC`80YX5=0P2WPTh20:R3C`80ZHA@2@2XPdl80:V4C`P0ZHA@0`2XPd`3
0:V4C@80ZXE>0`2[Qdd20:Z6C0/0ZHE;202[QU420:b6E@040:^6DP2ZQE00ZXE@0:V4C@80Z8A:202]
R5@20:j9E080[HQC0P2/Qe820:^6D@P0[XUD0`2[QU420:Z5D0<0ZHA?0P2`Qe<0102_QU80[XEA0:b3
C`2[PTh20:Z1C@<0[XAB0P2]Pe430:b2D0P0ZX1>00<0Z8=?0:N2CP2UP4`00P2TOd/00`2UP4`0Yh9>
0:R3C`020:F0B@030:AoBP2TOd/0Xge<0080Xge>00D0Xge@0:=jAP2TNdL0Y7]70:ElB0020:ImB@80
Ygi:202LMTL909ag@`80VgI20P2JMD4409Ud@00409Ye?P2IM3d0VG@m09Ud?@80V7<l0P2GLS/209Ib
@P<0V7A400H0UW9209A`@02CKcl0Uf/n09Q/?`2IKD0209Y^@@0309U]@02HK3l0Uf/n00@0TVli102C
L3X809=Y@@<0TF`o0P2@Jch408mZ?@09091[?P2AK3l0TF`o091[?P2>JC`0RfHi08UT=`2>ISD0SfLf
0080T6Pg00@0SfLf08iV=@2<I3<0RV8a0P26HcT208MT>P0408QU>`29IS`0RFHl08YW?@80Rf4i00@0
RF8i08QS>@29I3X0Qf@j0P26ICX00`26IC80QF@a08=R;`02089Q;P0308=R;`25I340QVDb00<0QF8h
0P24HCL308=P=P<0PF8f0P20HCD307mP=0P0O5`c00@0Of0a081Q<P20HC80P64b0P21HS<2089S=0P0
Of0d2020H3T00`1gF2T0NEX[07YK;00307aM;P0307]L;@1jFb`0NU//0080Ne`]0P1lGBh407eN;`<0
PEd]0P22GRh308=O;`<0Of0a0P1nGc0307eN;`<0OUhe0P1oGcH3081P=`P0Q64i00T0SFPl08aW>`2:
ICP0R6<f08QT=029IC<0RVHb08aX=024ICT00`25ISX208IW>`80QfPl00@0Q6Di08EV>P25ISX0QFHj
0P26Ic/208MX?00608QX?`28JCd0R6Tm08QY>`28JCX0R6Xh0P28JSH208mV>P80T6Lk0`2AJ3`02P2B
JCd0RVPh08]Y>@2<JSX0SV`l091^?P2BL400U79209Ec@`2CLD<2099`@P03095_@@2@KT00Sfdo0080
SV`n0100UW9209Ea@@2DL400Tflo09A`@02ELD40Ug=309UeA@2ALCH0TW8g09Ee?02HMd40VGQ309Uh
A@2HMd@0UgE50P2FM4@03P2GMDD0V7I609YhB02KNDT0W7Y:09ekB`2POdX0WWe809akAP2JND@0VGQ3
09YiA02KNTD0W7]60`2NNTH209mkA`<0X7a80P2PODL20:5nB0<0XWm900L0Xh1:0:9oB@2SP4X0Xh1:
0:F2C02VPdd0YhA>0080Z8E?2@2WPTh03P2YQ500ZXEA0:^6DP2[QU80ZXEA0:R3C`2VPDd0Y7m;0:J1
C@2WPTh0Z8=?0:V4D02[QU80[8MC0P2]R5@20:Z6DP80ZhMC0`2/R5@00`2]RED0[h]G0:n;E`060:n;
E`030;>:G02dRed0]HaN0080]XeO00<0]HaN0;B;G@2cRU`00`2cSEh20;B>G`<0]HmP0P2dT6020;FA
H@<0]Y9R00T0]i=S0;B?H`2eT6@0]I1S0;JBHP2gTf40^9AP0;VEH@2iUV00202hU6@01P2fTF@0]i9U
0;NBI@2iU6L0^YEX0;^FJ@80_9MZ00@0_YU/0;fHJ`2mV6/0_9MZ0P2kUVT20;ZEJ0P0^iMW00<0]i=S
0;RDI02jUVH00P2kUfL00`2jUVH0^9AT0;NCH`030;ZFIP<0^IEU0P2hU6@30;ZEJ0<0^IAW0P2hTfH8
0;REG`80^IEU0P2jUVH30;^GI`070;bHJ02kUfL0^iMW0;ZFIP2iUFD0]i=S0;JBHP020;FAHA40^9AT
202iUFD80;RDI0P0]YAT202gTf<80;RDI0/0^IEU0P2hU6@60;NCH`80^9AT0`2iUFD80;NEI@P0^9EM
0P2hSf420;V@HP040;ZAH`2kTV@0^i9T0;bCI@P0]91P202gTf<0102iUFD0^9AT0;RDI02gTf<20;JB
HP80]I5Q0`2fTV830;NCH`80^9AT00<0^8mQ0;N>H02cSEh00P2aSEd02@2`SUh0/I5P0;:BH@2hU6@0
]i=S0;JBHP2eTF40]91P0;:>GP020;6=G@T0]91P202bSUX0102bSUh0/hmO0;>?G`2dT6020;FAH@80
]Y9R202cSel00`2^RUX0/8aL0;:>GP020;B@H0040;>?G`2bSUh0/HeM0;:?F@80/hmK00<0]91N0;FA
H@2eT6<00P2fTFD0102bSUh0/hmO0;>?G`2dT6020;FAH@80]Y9R202cSe/30:n;F`030;2<G02aSEd0
/XiN0080/XiN0P2cSEh40;B>G`80]HmP0P2cSeD00`2cSUL0/hiI0;>>FP020;>=G0070;>=GP2bSUh0
/HeM0;6=G@2`S5`0[h]K0:j:FP020:f9F@80/heN00<0/heP0;><H@2cS6<00P2cS6D0102cRfL0/XiN
0;2<G02_Re/20:j:FP030;2<G02bSUh0]91P0080/8aL00@0/HeM0;:>GP2dT600]I5Q0P2fTV820;>=
J@030;:<I`2bS6D0/XeS0080/HaP00<0/HaO0;6;G02aRe`01P2aRe`80;2>GP80/HeM00@0/XiN0;>?
G`2cSel0]91P0P2eTF490;6<G`P0[hYM0P2`Rel00`2aS5l0/HeM0;:>G0020;>?F`040;BAF`2]RET0
[HUI0:f9F@80[XYJ0`2_Re/20;6=D@80/HeC01@0/HaE0;6<E`2aS5P0/HaH0:n:GP2^REd0[XUL0:f9
F@2/R5H0ZhMC0:Z6DP2ZQe40Yh=?0:R4D02ZQU80[8QD0:j:EP2`S5P0/HeI0;:>FP80/hmO0P2bSUh6
0;6=G@80/8aL00@0[h]K0:j:FP2^RUX0[HUI0`2`ReL20:n:EP<0[XUE00H0[X]E0:j:EP2^RUH0[XYH
0:j:FP2^RE`20:j9G@P0[hUL00H0[8MB0:b7D`2/Qe<0[8IE0:b6E`2/QUT20:b5FP030;2<G02_Re/0
[HUI0080[8QH00<0[HUI0:n;F`2`S5`0202]RET00`2`S5`0/HeM0;:>GP020;:>GP0;0:n;F`2]RET0
ZhMG0;2:F`2_REX0[XQI0:f7F02/QUL0ZhEF0:Z4E@2YPe@00P2]R5@20:b7D`050:^6DP2ZQE40ZXEA
0:V4D02]RET00P2/R5P00`2[QeL0ZXIF0:V5E@020:R4E080ZXEA102[QU830:b7D`080:Z5D@2^RED0
/8]G0:j9E@2YQ500YX5=0:V4D02]R5@20:V4D0030:Z5D@2[QU80[8MC0080[HQD00<0[XUE0:Z5D@2Z
QE401P2ZQE420:f7F0040:b6E`2[QEH0ZH=D0:R2D`80Yh5B0`2XPdl30:V4D080ZXEA202[QEP30:R4
E0D0Yh=C00P0YWmD0:N0E@2YPUL0ZX=H0:^4F@2ZPeP0ZH9G0:R1EP80ZXEA0`2YQ5030:R3C`P0ZHA@
00P0ZH=F0:V3E02XPU<0Z89A0:N2CP2WPTd0Yh9;0:J1BP80Yh9>0P2VPDd40:F0C0<0YX5<0`2UP4/2
0:AoBPP0YX9>00<0Xgi:0:AoB`2VPDd00P2WPTh00`2VPDd0Y7m;0:=nBP080:AoB`80YH1<0`2VPDd6
0:N2CP<0YX5=0P2UP4`20:1kAP030:5lA`2SOTT0YH1;0080YX5<00`0Yh9=0:R3CP2TOdX0YH1;0:J1
C02WPTd0Z8=>0:V4C`2ZQE00ZhIA0:J1C02WPTd30:R3CP060:J1C02TOdX0Xgi90:5mC@2ROTh0Y81@
0P2UPE40102TP500XWi>0:5mC@2PO4P20:5mB@030:9nBP2SOd/0Y81<0080YH5=202ROTh01P2MN4<0
WWU409mjA@2PNdH0XWe80:AoBP80YH1;00D0YH1<0:AoB`2TOd/0Xgi:0:9mB@020:5lB0060:1kA`2P
ODD0X7e50:5nB02QODT0XWi<0P2ROTh00`2SOU40XG]>0:5kCP060:5kCP0;09iiA02ONTD0X7]60:5l
A`2PNdH0WgY509eh@`2LMd80WWU509mjAP2QO4P00P2RODT00`2QO4P0X7]709mjAP0409ehA0@0WWU5
0`2ONTH20:1kA`<0XGa8102NNTX409mkB`80X7a800<0Wg]709ijAP2MNDD00P2LN4@00`2KMd<0WGQ4
09ehA00609ehA080W7M30P2MN4@209iiA@80WgY600<0WWU509ehA02LMd<00P2JMD400`2LMd<0WGQ4
09iiA@0209Ud@00409Ye@@2KMT80VgI209ag@`<0WGQ40P2JMT8309Ue@@<0V7A000P0V7A409UeA@2J
MTH0VWI609UeA@2GLd<0U710099^?PP0V7A000P0UW4m09Mb?P2HLcl0V7<o09Mb?P2FLCd0U6lk099]
>@P0UG0l202HLcl01P2EL3`0U6lk09A_>`2CKSX0TVdi095/>080T6/g00/0TVdh095/=`2@JST0SfTj
08mX?@2AJT<0Tf]709A/B@2<ISL0SFLh08mY>P03095[?003091Z>`2?JCX0TF/l0080TF/l:oooool0
02[ooooo00@0Vfln09Y^?@2JKSd0VFdl0P2HK3/209M[>P0609AZ>02EJcT0UV`j09M]>`2HKS`0VW0n
0P2KLCl0402GKC/0V6hl09Y`?P2LLT00WG=109ab@02JL3h0VFlm09]a?`2JL3h0VFlm09Q^?02IKcd0
VW0n09ab@02MLd4309Q^?080VFlm0`2JL3h209mdA`@0WW=60P2MLTD809me@`P0WGA0202NLdH209eb
A`80W7560P2MLTL00`2OM4T0XGI;0:9gC00809ab@0P0WWE10`2NLT4209mc@P<0X7A300P0WW=009md
@@2PMD80XGI30:9gA02SN4D0Y7U60:EjA`80X7E20P2QMT<20:9gA080XgQ500<0X7M30:5hA02SNTH0
0P2UO4P00`2TNdL0XgY60:9iA@030:9hAP80XgU70`2TNTP20:ElB0040:AkA`2SNTH0XgY60:9iA@80
XGQ40`2SN4D20:AiAP<0YGY7202XOd/01P2TNdL0YGa80:ImB@2WOTX0Z7m;0:V0C080ZX5=0P2WODd0
102WOD/0Ygi:0:MnBP2WOTP20:MnAP<0Ygi:0P2XOd/30:V0C0<0ZWm:0P2YOTT30:QmB0040:j4DP2]
Pe40ZX1>0:QnC0<0Yge;00<0Z7i<0:Z1C@2YP4`00`2WOTX00`2YP4`0[8=?0:f4D0080:^2C0<0ZHA@
00<0Z8=?0:N2CP2VPDd00P2VPDd20:V4C`80Z8=>0`2WPTd20:J1C0P0[8=;0`2/Pdl00`2[PTh0ZX5=
0:V0C0020:V0C0<0Z8=?0`2YQ5020:Z5D@040:Z0CP2[PDl0Zh5?0:b2D080[H=A0P2^Q5880:j5D@P0
[H=A202/Qe080:b7DPP0[XUE0`2[QU800`2/Qe<0[HQD0:j9E@020:j9E@P0[hEC202]Pe<30:j5C`80
[HA>0`2/Pdd20:b3C`040:^2CP2ZPDd0ZX5=0:V0C080Z7m;0P2ZQE030:V4C`<0Z8=>00H0ZX5;0:V0
BP2YP4X0Ygi80:ImA`2UO4H20:AkA@0409mjA@2PNdH0X7]60:5lA`80XWe80P2SOTT00`2RODT0XGa8
09mjAP0309ehA0D0WgY600<0WWU509ehA02LMd<02`2LMd<209Qc?`0609Mb?P2FLCd0Ug8n09Ud@02K
MT80W7M30P2IMD4209Qd@0<0Ug<o00@0UW8n09Mb?P2FLCd0U6lk0P2CKSX0102DKc/0UW4m09Mb?P2G
LSh209Ia?@0309E`?02DKc/0U6lk0080Tfhj00H0U6lj09=^>P2CKSX0Tfdl099/?@2BK3l2095Z?`@0
Tfdn0P2BK3d2095[?00808a[=P2?KST0TW4l091_>P2<JcH0RVTd08e/=`2@KcX2091Z>`80SfTj0`2>
J3T0302=IcP0SFPk08aW>P2:ICP0RF@g08YU>02<IcX0SfXm095/?`2=JCT0S6Ph08YV=P80RFDe00<0
RVHf08aX>02=JCT02023IS`02028I3@0Qf<c08EQ<@24H300QF4a08MS<`2:ISH0S6Ph0P25I3400`25
Hc<0QF<e08ES=P0208ER>00308ER>P25H3<0QF0c00h0QF0c201oHc<0201kG2d0O5d^07eN;`1oH340
P64b089S=023I3D0Q6Df2@22HCP00`25HSX0Q64i089O=`02085N=P04089O=`24HCT0QF8j07mM;`80
P5h`00<0PEla089P<P23HC<00P24HS@02`1mHC40Of0a081Q<P21HC80Pf4c08IQ=027HC@0R68e08IS
>`25HSX0Pf0h0080PUlg00<0Pf0h08ER>P26Hc/02025HcD0102:J3X0RFLi08UW>@28ISP208MU=`80
QV@f1028ISP208MU=`80QV@f0P29IcL208YX>0<0RfTi00T0S6Xj08i[=@2?JcL0TFdi099^?02CKcl0
TVe0095/@02@Jcl00P2:JST03P2;JcX0S6`k08i^?@2?Kch0T70o095a@02>J440SfY0091[@@2BKD40
Tfi109Ea@@2FLT00Ug=1202CKcl0202IMDD0V7A409Mc@`2FLT80Ug=309QdA02JMTH0VgM70`2FLT82
09Mc@`<0V7A40`2NNDD209mjAP<0X7]700P0WGY209ik@`2OO4H0X7a80:5mB`2ROTh0Xgm?0:=nD@80
XGe;00@0XGe90:1mA`2PODL0X7e50P2POD<01@2ONdL0X7a80:1lB02QODT0XWi:0080Xgm;00H0Y81<
0:9nBP2SOd/0YX9>0:V5D@2ZQU820:^7D`050:Z6DP2VPTh0YX9>0:N3C`2YQE400P2ZQU801P2YQE40
Yh=?0:J2CP2XQ500ZXIB0:^7D`80[8QD00@0ZhMC0:Z6DP2XQ500ZhIB0`2/Qe<20:f8E080[XUE0P2^
RUH30:n;E`<0/8aH00@0[h]K0;2<G02`S5`0/8aL0P2aSEd20;:>GP<0/HaO0P2bSF030;>>H@80/hmO
00@0]91P0;FAH@2fTV80]i=S0P2hU6@30;F?H0030;J@H@2gTF80^99S0080^99S0`2fTV830;NCH`80
^9AT0P2iU6P00`2iU6L0^IEU0;VEH`020;VEH@030;VFH02jUVH0^YIV00h0^YIV0`2iUFD20;RDI0<0
]i=S0P2hTfL30;VDJ0<0^YEY0P2kUfL20;ZFIP040;VEI@2hU6@0^9AT0;NCH`80^YIV00@0^IEU0;RD
I02hU6@0]i=S0P2fTV880;RDI0040;bHJ02kUfL0^iMW0;^GI`80^YIV0P2iUFD20;ZFHP040;VEH@2h
U600^9AP0;NCG`80]Y9N2@2jUVH80;RDH080^9=L00<0^9=N0;VDH02iTf800P2jU6D0102jU6L0^YMQ
0;ZGH@2jUf430;VFH080^9EO402hU6@0202fTV80]i=S0;VEI@2kUfL0_9QX0;^GI`2iUFD0^9AT202j
UVH20;bHJ0030;^GI`2jUVH0^IEU0080]i=S00<0]Y9R0;VEI@2iUFD01P2iUFD80;NEI@80^9EM00<0
^9EO0;RDH02hU6800P2hU6@01@2hTfH0^IEU0;RDI02hU6@0]i=S0080]Y9R0P2eTF420;RDI0<0]i=S
0`2fTV880;B?HP/0]91P00<0]I5Q0;JBHP2gTf<0102gTf<20;JBHP80]I5Q2P2dT6020;FAH@80]91P
0P2cSel00`2bSUh0/HeM0;6=G@080;>>H@80/XiN00<0/hmO0;B@H02eTF400P2fTV80102gTf<0/i5Q
0;>AH@2cTF430;:@H080/HmO00H0/XaM0;>=GP2cSEh0]HmP0;J@H@2gTF820;RBH`P0]91L00<0/8]N
0;6<G`2dSf800P2eT6<00`2dSf80/hiQ0;6<G`020;>?G`<0/XiN1P2aSEd30;:>GP<0/hmO00X0]91P
0;FAH@2fTV80]I5Q0;>?G`2`S5`0[XYJ0;B?HP2bSF00/8]N0P2^RE`00`2_RUd0/8]N0;:=H0040;:<
G@@0/H]L0P2_RUd20;2;GP80/HaO0P2bSF030;2:F`030;6;G02bS5d0/heN0080/heN202bRf080;B=
HPP0]8aH00@0]I5Q0;>?G`2aSEd0[h]K0P2^RUX00`2`S5`0/HeM0;:>FP070;:>FP<0[haF0P2`SEL0
502aSUP0/XmI0;:?F@2bSeT0/XiN0;6=G@2_Re/0[XYJ0:f9F@2^RUX0[h]K0;2<G02_RUh0/8]O0;6<
G`2bSUh0/XiL0;6=F@2`S5P0[haF202`Reh80:n;F`060:f:E02]RED0[HUE0:j:F02^RUX0[hYM0P2_
RUh20:b8E0040:f9E@2^RUH0[XYF0:n;E`80/8aH00<0/HeI0;2<F02^RUH00P2]RED00`2^RUH0/8aH
0;6=F@080;2<F080/HeM0P2`S5`01P2_Re/0[XYJ0:j:FP2^RUX0/8aL0:n;F`<0[HUI00<0[h]K0;:>
GP2cSel0202_RUH30:f7F0D0[XQI202/R5P0202bS5l0/H]N0:j8F`2/QUT0ZhEH0:b6F@2]QeX0[XQK
0`2_Re/20:j:FP<0[HUI202[QeL80:V4D080ZhIA0P2/Qe820:f8D`80[XUD0P2[QEP20:Z4E`<0ZH=F
0P2XPUD20:f8E080[8MC00@0ZhIB0:Z5D@2ZQE40ZHA@102ZQDh40:V4C@<0Z8=?0`2YQ5020:Z5D@03
0:b7D`2[QU80ZHA@00<0Yh9>00<0Z8=?0:V4D02YQE401`2YQE400`2/Qe<0[HQD0:f8E0020:j9E@80
[HQD00T0[8MC0:^7B`2YQD/0Z8=<0:N2C@2WPE00Z89E0:V2E`2[Q5/0202XQUP0202[QU80ZHA@0:N2
CP2VPDd0YH1<0:J1C@2WPTh0Z8=?0P2VPDd20:N2CP80Z8=?102YQ5020:R3C`<0Yh9>00D0YX5=0:1l
B02QODT0XGe90:9nBP020:=oB`80Y81<0P2WPTh0102VPDd0YH1<0:F0C02TOd/20:=nBPP0YX5=0`2S
Od/20:B0C0<0YH5=00P0YH1<0:J1C@2XPdl0ZHA@0:R3C`2VPDd0Y7m;0:=nBP80XGe900@0XWi:0:=o
B`2UPDd0YX9>0P2WPdl30:F2BP030:B1B@2SP4P0XWm70080XWm72@2VPDd80:F0C0<0Yh9>0`2VPDd2
0:F0C0P0YH1;0P2TP4`30:=oB`<0XWi:0P2OOe00102NOTl0WGe>09]kC02JNT/209UiBP0309iiA@2P
NdL0XGa800<0Xgi:00<0XWe90:5lB02ONTH00P2ONTH20:1kA`<0XGa800@0WW]509mlAP2OO4H0X7e7
0P2QOTP20:9oB@P0X7]7202ONTH809ijAP0409Mb?P2IM400VgI209ehA080WgY60P2NNDD00`2QO4P0
XWe90:=nBP020:=nBP030:5lB02ONTH0WWU500<0VW]50`2KO4H209amA`@0VWE10P2IM40209Qc?`D0
X7A30`2OLd800`2IMD40VWI209]g@`0209eiA@0609]g@`2JMT80VGE109iiA@2MN4@0VgI20P2JMD40
1P2KMT80WGQ409iiA@2LMd<0VgI209Ud@080V7<o00D0VGA009]f@P2KMT80W7M309Ma@P0209Qb@`03
09UcA02JM4D0VgE60080W7I7202IMDD209Mc@`0609QdA02IMDD0Ug=309Ea@@2BKSh0T6`l202FLCd2
099^?P80Tflo00@0U71009Ea@@2ELD40UW920P2HLdL00`2GLTD0Ug=309Mc@@0209Ib?P0309Ic?@2E
L3`0UG0l0080U6lk0P2CKSX2099]>@P0TV`m0P2@JS/4095[?080TV`m0`2AJc`[ooooo`00:_ooool3
09Y^?@0309U]?02HK3/0V6`k0080Uf/j0P2FK3X0102GKC/0V6hl09Q^?02IKcd209Y`?P0309M]>`2H
KS`0VW0n00<0W7900P2JL3h0202KLCl0VW0n09U_?@2HKS`0VFlm09Y`?P2LLT00WG=10P2HKS`309U_
?@<0VW0n1P2NLdH209ebA@P0WG=1202MM40809icAP80WG950P2LLD@209ebA@0309mdA`2QMTT0XWM:
00P0WG=1202NMD4309ib@@80Wg=20`2PM4<209md@@040:1e@P2QMT<0XWM40:=hA@80Y7U60P2PMD82
0:5f@`80XWM40P2SN4D0202PMd<0XGQ40:=jAP2TNdL0YGa80:AkA`2SNTH0XWU50`2RN4H20:=iA`<0
Y7Y80`2TNdL20:=jAP<0XWU50`2SN4D20:AiAP<0YGY7202XOd/01P2SNTH0Y7]70:ElB02VODT0Ygi:
0:QoB`80ZH1<0P2WODd0102WOD/0Ygi:0:MnBP2WOTP20:MnAP<0Ygi:0`2XOd/20:V0C0P0ZGi900@0
[XAB0:b2D02ZP4h0Z7i<0`2WOD/02@2XOT`0ZX5=0:V0C02XOd/0Ygi:0:QoB`2YP4`0Zh9>0:f4D002
0:^2C0@0ZX5;0P2YP4X20:V4D080Z8=?00@0Yh9>0:J1C@2VPDd0YX5=0P2YQ4l20:R3CP<0Yh9=0P2V
PD`80:^2BP80[8=?0P2[PTh20:Z1C@80ZH1<0`2XPdl30:V4D080ZXEA0`2/PU000`2]Pe40[XAB0:j4
DP020:n5D`P0[XEA202]Pe480:b7D0P0[8MB202^RED20:^6DP80[8MC0P2]R5@20:j9E@P0[hEC202]
Pe<30:j5C`80[HA>0`2/Pdd20:f4D080[8=?00@0Zh9>0:Z1C@2ZPDd0ZX5=0P2ZQE030:V4C`<0Z8=>
0P2ZPD/01P2YP4X0Z7m90:MnB02VODL0YGa60:AkA@80X7]60P2QO4L02`2RODP0Xgi90:=nB@2SOTT0
XWe90:5lB02ONTH0WWU509ehA02NNDD0WgY60080X7]70P2ONTH209iiA@<0WGQ400<0W7M309ehA02M
N4@01P2MN4@00`2IM400V7<o09Mb?P0209Mb?P0309Ud@02KMT80W7M300<0VGE10P2HM40309Mc?`03
09Mb?P2FLCd0UG0l0080U6lk00<0UG0l09Ia?@2GLSh00P2GLSh209Ia?@0=09E`?02DKc/0U6lk09A_
>`2DKcX0U6lk09=^>P2CKC`0TV`m099/?`2BJd00TFXo09A^?`0309=]?P80TV`m0P2AJc`0202=K3L0
T6lj099a?02@KcX0S6/f08YY=02<JcH0Sfhi0`2@JS/208mY>P<0SVPi0P2<IcX208]V>@0708aW>P2=
J3/0SfXm091[?P2=JCT0S6Ph08]W=`0208YV=P0308]W=`2<J3P0SFTi00P0QFHj0P27Hc<208IR<P04
08MS<`28I3@0RVHf08]W=`80QVDb00<0QV@d08IT=P26I3L00P26HcT00`26Hc/0QF0c08EP<`0>08EP
<`P0PV<d0P1nGc00101oH340P64b085R<`22Hc@208=T=@T0PV4f00<0QF8h08AQ=`23H3H00P21GS@0
1023H3H0Q64g08ER>021Gc43089P<P@0Pf4c00H0OV8b081Q<P20HC80PV8c08AR=026HC@208QR=@03
08MT>P26HcT0Q64g0080Pf0f00<0Q64g08IS>@27I3X02026I3H208YX>P80RFLi00@0R6Hh08MU=`27
ICL0QfDg0P2:J3X208UW>@<0R6Hh00<0QfDg08UW=`2:J3P00P2:J3P208]Y>@80S6Xj00T0SFXd08iZ
=P2@K3P0TFdk099^?P2AK3l0T6/o08mZ?P2;JcX00P2<K3/03@2=KC`0SVhm08m_?P2?Kch0T70o08mY
@P2?JT00TFa2099]@@2DKd80UG5109Ib@02GLd40202CKcl00`2HM4@0Ug=309Ib@P0209Ib@P0309Qd
A02IMDD0VgM700<0V7A40P2IMDD309YfAP<0WWU50P2ONTH30:1kA`80WW]300H0Wga60:1lB02QOD/0
XWi>0:=oC`2TOe820:5mB`040:5mB@2QOTP0XGi80:1mA@80X7e30P2ONdL0102PO4P0XGe90:=oB`2T
P4`20:F1C@060:9nBP2TP4`0YX9>0:V5D@2ZQU80ZhMC0P2ZQU820:J2CP0:0:N3C`2YQE40ZXIB0:Z6
DP2YQE40Yh=?0:J2CP2YQE40ZXIB0:^7D`80[8QD00<0ZhMC0:Z6DP2YQE40102/Qe<20:f8E080[XUE
0P2^RUH30:n;E`<0/8aH102`S5`20;6=G@80/XiN0`2aS5l20;:=H0<0/hiQ0P2cSel0102dT600]I5Q
0;JBHP2gTf<20;RDI080]HmP0P2fT640102gTF80^99S0;RBH`2hTV<30;JBHP80]i=S0`2hU6@20;VD
J0030;VDI`2iUFD0^IES0080^IEQ00<0^IIP0;ZFIP2jUVH03P2jUVH30;VEI@80^9AT0`2gTf<80;VD
J080^iMW0P2jUVH01@2iUFD0^9AT0;RDI02hU6@0^YIV0080^IEU0P2hU6@20;NCH`030;JBHP2hU6@0
^9AT00H0^9AT102kUfL20;ZFIP80^IEU0`2iUF420;RDH0<0]i=O2@2iUFD80;RDH080^9=L00<0^9=N
0;VDH02iTf800P2jU6D0102jU6L0^YIR0;ZFHP2jUV830;VEH@80^9AP402hU6@00`2fTV80]i=S0;VE
I@030;^GI`80^IEU202jUVH01@2lV6P0^iMW0;^GI`2jUVH0^9AT0080]i=S00<0]Y9R0;RDI02hU6@0
1P2hU6@80;NEI@80^9EM00<0^9EO0;RDH02hU6800P2hU6@01@2hTfH0^9AT0;RDI02hU6@0]i=S0080
]Y9R0P2eTF420;RDI0<0]i=S0`2fTV880;B?HPX0]91P0P2eTF420;JBHP@0]i=S0P2fTV820;FAH@h0
]91P0P2cSel30;:>GP<0]8mR0P2cSV430;:=H080/XiN00<0/hmO0;B@H02eTF400P2fTV80102gTf<0
/i5Q0;>AH@2cTF430;:@H080/HmO00D0/XaM0;>=GP2cSEh0]8iO0;J@H@020;NAHP030;RBH`2dT5`0
]91L00H0]91L00<0/HaO0;:=H02dSf800P2eT6<00`2dSf80/hiQ0;:=H0020;>?G`<0/XiN1P2aSEd3
0;:>GP<0/hmO00l0]91P0;FAH@2eTF40]91P0;:>GP2`S5`0[XYJ0;B?HP2bSF00/8]N0:n:G@2^RE`0
[hYM0;2;GP2aS5l0102bS5d40;6;G080[hYM0P2`Reh20;6<G`80/XeP0P2`RU/20;6;G080/XaM0P2c
SEh80;:;H0<0/haQ1@2dSF880;B<F@080;B@H02cSel0/HeM0:n;F`2^RUX0[h]K0;2<G02aSEd80;:>
FP80[h]G0`2`S5P0502aSET0/XiJ0;:>FP2bSUX0/XiN0;6=G@2_Re/0[XYJ0:f9F@2^RUX0[h]K0;2<
G02_RUh0/8]O0;6<G`2bSUh0/XiL0;6=F@2`S5P0[haF202`Reh80:n;F`060:f:E02]RED0[HUE0:j:
F02^RUX0[hYM0P2_RUh00`2/R5@0[HUE0:f9E@020:j:EP80[h]G00@0/8aH0;6=F@2`S5P0[XYF0P2]
RED00`2^RUH0/8aH0;6=F@080;2<F0<0/8aL1@2_Re/0202`S5`0[h]K0:j:FP2]RET0[XYJ0:n;F`2a
SEd0/hmO0P2`ReL40:n:EP80[XUE0P2]QeP60:j8F@P0[8QH00<0/H]L0:n9FP2]QeP00`2/QUL0102^
R5T0[hUJ0:n;F`2_Re/30:j:FP<0[HUI202[QeL80:^6DP80ZhIA0P2/Qe820:f8D`80[XUD0P2/QUL2
0:^5EPD0ZXAE0P2]R5@20:b7D`040:^6DP2ZQE40ZXEA0:Z5D@@0ZhI?102ZQDh30:R3C`<0ZHA@0P2Z
QE400`2/Qe<0ZhIB0:V4D0030:N2CP030:R3C`2YQ500ZHEA00L0ZHEA0`2/Qe<20:^6DP<0[8MC00P0
ZXI<0:V5B`2XPd`0Yh9>0:N1D02XPUD0ZH9G0:Z3F0P0Z8IF00P0ZhIB0:V4D02WPTh0YX5=0:F0C02V
PDd0Yh9>0:R3C`80YX5=0P2WPTh20:R3C`@0ZHA@0P2XPdl40:N2CP80XWi:0P2SOd/20:B0C080YH5=
00<0Yh9>0:J1C@2VPDd00P2UP4`20:AoB`030:=nBP2VPDd0YX5=00H0YX5=0`2SOd/20:B0C0<0YH5=
0P2VPDd30:R3C`090:J1C@2TOd/0Xgi:0:5mB@2ROTX0Xgm;0:B0C02UPDd0YX9>0080Yh=?0`2VPd/0
0`2UPTX0Y8590:B1B@020:>0B140YX5=0`2WPTh30:J1C@80YH1<202UP4/20:B0C0<0Xgm;0`2ROTX2
09moCP0>09inC@2MOD`0W7a;09]kBP2JNTT0VGU809iiA@2PNdL0XWe90:=nBP2TOd/0Xgi:0:9mB@2Q
O4P209mjAP<0X7]70`2QO4P309mlAP030:1mA`2QOTP0XGi80080XWm92`2PNdL209mjAP80WWU500<0
WGQ409eiA@2MNDD01P2MNDD0102HLcl0VGA009ag@`2NNDD209mjAP80WWU500<0XGa80:9mB@2SOTX0
0P2SOTX00`2QO4P0WgY609iiA@0309YkA@<0Vga60P2LODL209ag@`80VgI20`2JMD400`2IM400X7I4
0:1fA0040:1fA080WgE300<0VWI209]g@`2LN4@00P2NNTH01P2LN4@0VgM309Yf@P2NNDD0WGQ409]f
@P80VWE100H0VgI209ehA02NNDD0W7M309]f@P2IM40209Qc?`0409Ud@02KMT80VgI209ag@`@0VG=4
102JM4D809UeA@0809Mc@`2HM4@0VGE509UeA@2HM4@0UW9209=_?`2BKSh809Ia?@80TVhn0P2CKcl0
102DL400UG5109Ea@@2ELD4209MbAP0309IaA02FLT80UG4o0080UG4m00<0U74k09E`?02EL3`00P2D
Kc/209=^>P80TVdi202BK3d6095[?080TV`m0`2AJc`[ooooo`00:_ooool209Y^?@<0VFdl0`2HK3/6
09Q^?080VFlm00D0V6hl09U_?@2JL3h0Vg4o09ab@00209]a?`0:09Y`?P2KLCl0VW0n09U_?@2HKS`0
VFlm09Y`?P2LLT00WG=109Q^?0<0VFlm0P2JL3h209]a?`D0WG950`2NLdH809]a?`P0WGA02P2MLTD2
09aaA080WG9500<0WgA70:5fB@2RMdX0202OMD<809ie@@<0WW910P2OLd830:1d@`0509md@@2PMD80
X7E20:5f@`2RMd@00P2SN4D00`2TNDH0X7E20:1e@P020:5f@`80XWM40P2SN4D00`2OMT80XGQ40:9i
A@030:AkA`030:=jAP2RNDD0XWQ60080XWQ60P2SNDL30:AjB0<0XWU50P2SNTH30:AkA`<0XgQ50P2T
NDH30:EjA`P0Ygi:00H0XWU50:=jAP2SNTH0Y7]70:ElB02VODT20:MnBP80YWa<00@0YWa:0:ImB@2V
ODT0YWe70P2VODD20:ImB@80Ygi:0`2XOd/0102YP4`0Yga70:MlA`2XODP20:UnB@080:YoBP2[P4/0
Zh1;0:f3D@2[PDl0ZGm=0:MmB`2VO4X20:MmB`030:QnC02YP4`0ZH1<00<0Z7m;00@0ZH1<0:^2CP2/
Pdl0Zh9<0P2ZPD/01@2YP4X0Z7m90:MnB02WOTP0YWe700<0Z8=?0P2WPTh30:J1C@80ZHA?0P2XPdh3
0:N2C@80YX5<202ZPD/0102/Pdl0Zh9>0:^2CP2[PTh30:Z1C@040:V0C02XPdl0Z8=?0:R3C`<0ZHA@
0P2ZQE40102]Pe40[XAB0:j4DP2^Q5830:n5D`030;26E02^QE40[XEA00H0[XEA202]Pe4@0:b7DPP0
[HQD00@0ZhIB0:b7D`2/Qe<0[8MC0`2]R5@00`2^RED0[hEC0:n5D`060:n5D`P0[XAB0`2^QDl20:f4
CP<0[8==0`2^QE420:f4D0<0[8=?0P2ZQE030:V4C`<0Z8=>0P2ZPDd0102YP4`0Z7m;0:MnBP2WOTX2
0:ImB@80XGa70P2RODP40:=nB@030:=nBP2RODT0X7]700<0WWU5102PNdL209mjAPD0WWU5202MN4@0
0`2JMD40VGA009Qc?`0209Qc?`0309Ud@02KMT80WGQ40080VWI20P2IMD4309Qd@00409Mc?`2HLcl0
Ug8n09Ia?@80UG0l00<0UW4m09Mb?P2HLcl00P2GLSh309Ia?@<0UG0l00H0UG0k09A_>`2DKc/0U6hm
09=]?P2CKD02099[@0<0U6ho0P2CKCh3099/?@08095]>@2DL3`0UW8n09=_>`2>JSH0S6Pd08eY=@2@
K3P2095[?080T6Xk0`2?JCX01P2>J3T0RfHi08aW>P2=J3/0SVTl08mZ?@80SVTl00@0SFPk08iZ>P2=
JCT0RfLg0P2:ISH00`2;IcL0SFTi08iZ>P0808IW>`0308MS<`28I3@0RFDe00<0RVHf0P29ICD208IU
<P0308IT=026I3H0QV@g0080QV<i00<0QV<k08IQ=026HC@03P26HC@808=T=@P0PV<d2@24HCL00`26
HcT0QF8h08AQ=`0208=P=P0308AQ=`25HSP0QV<i0080QF<e0`24HS@308=Q<`0;07mS<`22Hc@0PV<d
08=S=025HcD0Qf8e08QR=@29HcH0R6Dk08MT>P26HcT00P24HCL00`26HcT0Qf@j08QU>`0808MU=`04
08]Y>`2:J3X0RVPj08YX>P<0RFLi00@0R6Hh08aZ?02<JS`0S6Xl0P2;JC/308YX>P80RVPh0P2;JCT3
08aZ>P0708e[>`2<JC<0SFTe08m[=`2AKC/0TFdm095/?`0208mZ?PP0Sfdm00H0T6Y3095/@P2BKD<0
Tfi209A_@P2FLT8209Mc@@P0UG5100P0V7A409Mc@`2FLT80UG5109Ib@P2GLd<0VGE509YfAP<0VgM7
0`2LN4P209eiB@<0WgY60P2PNdL30:5lB080Wga400<0X7e70:5mB@2ROT`00P2SOdl0102TOe80XGe;
0:5mB`2QODT20:5nB00?0:5nAP2QOT@0XWm509ijAP2ONdL0X7a80:9nBP2TP4`0YH5=0:J2CP2WPdl0
XWi:0:B0C02WPdl0ZHEA00<0ZXIB00D0ZHEA0:N3C`2WPdl0Z8A@0:Z6DP020:^7D`060:Z6DP2XQ500
Yh=?0:V5D@2ZQU80[8QD0P2]RED00`2/R5@0ZXIB0:V5D@030:b7D`80[HQD0`2^RED20:j:EP<0[h]G
0`2`S5P30;2<G080/HeM0`2bSUh30;:=H080/hiQ0`2dSf820;>?G`040;B@H02eTF40]Y9R0;NCH`80
^9AT0`2fT6420;NAHP<0^99S0P2fTV820;NCH`<0^9AT00H0^IEU0;VDJ02iU6P0^IAW0;VEI@2iUF<2
0;VEH@030;VFH02jUVH0^YIV00h0^YIV0`2iUFD20;RDI0<0]i=S0P2kUVT00`2jUFP0^IAW0;RCIP03
0;NBI@<0^YIV0`2iUFD20;RDI0<0^IEU0P2hU6@30;NCH`P0^9AT0`2kUfL20;ZFIP<0^IEU0`2gTel2
0;RDH0<0^IEQ2@2gTf<80;RDH080^9=L00<0^9=N0;VDH02iTf800P2jU6D0102jU6L0^YIR0;ZFHP2j
UV830;VEH@80^9AP402hU6@01@2gTf<0^9AT0;VEI@2jUVH0^iMW0080^YIV00<0^IEU0;ZFIP2jUVH0
1P2jUVH20;^GI`030;ZFIP2iUFD0^9AT0080]i=S00<0]Y9R0;NCH`2gTf<01P2gTf<80;NEI@80^9EM
00<0^9EO0;RDH02hU6800P2hU6@00`2hTfH0^9AT0;RDI0030;NCH`<0]Y9R0P2hU6@30;NCH`<0]Y9R
202eT6<90;B@H0<0]I5Q0`2fTV830;NCH`80]Y9R0P2eTF4:0;B@H0@0/XiN0P2cSel30;B@H080]Y5T
00@0]I1S0;B?HP2bSF00/HaO0P2`Reh20;:>GP030;>?G`2dT600]I5Q0080]Y9R00@0]i=S0;>AH@2c
TF40/i5Q0`2bT6020;6?G`060;:<G@2cSEh0/heN0;B>G`2eSf00]Y1Q0P2gTF880;B@G0030;:=H02c
SV40]8mR0080]8mR00<0/hiQ0;:=H02bSF000P2cSel30;:>GPH0/HeM0`2bSUh20;>?G`@0]91P00L0
/hmO0;:>GP2`S5`0[h]K0;>>H@2bSF00/HaO00<0[hYM00<0/8]N0;6<G`2aRe`00`2aRe`40;:<G@80
[hYM0P2`Reh20;6<G`80/XeP00@0/8YK0;6;G02aRe`0/H]L0`2bS5d00`2cSEh0/XaO0;:<G`060;:<
G`050;6;GP2bS5l0/XaO0;>=H02dSV400`2eSf880;:=F@030;>?G`2bSUh0/HeM00<0[h]K00<0/8aL
0;6=G@2aSET01`2aSET30;2<F0<0/HeI0`2bSUX0402bSUh0/HeM0:n;F`2^RUX0[HUI0:j:FP2_Re/0
/8aL0:n:GP2`Rel0/HaO0;:>GP2bSU`0/HeI0;2<F02_S5H80;2;GPP0[h]K00H0[HYD0:f9E@2]RED0
[XYH0:j:FP2_RUd20:n:GP<0[HUE0P2^RUH30:n;E`030;6=F@2`S5P0[h]G0080[XYF00<0[h]G0;2<
F02aSET0202`S5P00`2^RUX0[h]K0:n;F`020:n;F`<0/8aL0P2_Re/30:j:FP030:n;F`2aSEd0/XiN
0080/HaH00@0/8]G0:n:EP2_RUH0[XUE0P2]R5@80:j8F@P0[8QH00T0[XQI0:f7F02]QeP0[8IG0:f7
F02^R5T0[hUJ0;2:F`2_Re/00`2^RUX20:f9F@80[8QH202[QeL80:b7D`80ZhIA0P2/Qe820:f8D`80
[XUD0P2^R5T20:f7F0@0[8IG00@0ZhEF0:b7D`2/Qe<0[8MC0`2[QU820:Z5D@P0[8MB0`2XPdl30:V4
D080ZXEA00<0[8MC0:Z5D@2YQ5000`2WPTh20:V4D0P0ZHEA00<0[HQD0:^6DP2YQ5000P2WPTh02`2Y
Q500ZhIB0:f8E02ZQDh0ZHA=0:N2C@2VPDd0YX1?0:N1DP2YPeH0ZXAG00P0ZXIF00P0ZhIB0:V4D02W
PTh0YX5=0:F0C02VPDd0Yh9>0:R3C`80YX5=0P2WPTh20:R3C`D0ZHA@0P2XPdl30:N2CP80Y81<0P2U
PDd40:J2CP<0YX5=0P2UP4`30:AoB`P0YX5=0`2SOd/20:B0C0<0YH5=00T0YX5=0:N2CP2WPTh0Z8=?
0:N2CP2VPDd0YH1<0:AoB`2ROTX00P2SOd/00`2TP4`0YH5=0:J2CP020:N3C`040:R5C`2WQ4h0YhA>
0:N4CP<0YX==00<0YH9<0:N2CP2WPTh01`2WPTh80:R3C`<0Yh9>0`2VPDd20:F0C0P0Y7m:0P2TP4`3
0:=oB`<0XWi:0P2POTh00`2OODd0WWa<09ekB`0209ajBP0:09]iB@2ONTH0X7]70:9mB@2SOTX0Y7m;
0:=nBP2RODT0XGa809mjAP<0X7]70P2QO4P20:9mB@80Wga60`2PODL30:5nB0P0X7]700H0Xgi:0:9m
B@2QO4P0X7]709mjAP2MN4@209ag@`P0W7Q400@0VGA009Ye@@2LMd<0WWU50P2ONTH0102NNDD0WGQ4
0:5lB02RODT30:=nBP030:5lB02ONTH0WWU500<0VgY50`2LNdH209elA`<0WWU50P2MN4@309ag@`P0
XGM500<0VgM309eiA@2NNTH00P2ONdL01P2NNTH0WGU509]g@`2MN4@0W7M309]f@P80VWE100D0VgI2
09ag@`2MN4@0W7M309]f@P0409Ye@@80VgI200@0W7M309YdA@2JM4D0VWA50`2ILd@209Qb@`X0VGE5
00H0VWI609UeA@2HM4@0Ug=309Ea@@2DL40809Ia?@<0Tflo0`2DL40209Ea@@80UG1400<0U6m209A`
@02CKcd00P2CKc/00`2BKcT0UG0l09E`?00209A_>`80Tfhj0P2BKCT=099/?@<0TF/l0`2@JS/[oooo
o`00:_ooool609U]?080V6`k0P2JL3h309U_?@<0V6hl0P2IKcd209Y`?PD0Vg4o00L0VW0n09U_?@2H
KS`0VFlm09Y`?P2LLT00WG=100<0VFlm0P2JL3h309]a?`80W754102MLTD209icAPP0VW0n202MM408
09ebA@80WG=30P2LLT8209ec@`0309meA@2QMdL0XWQ800P0X7I4202NMD4309ib@@80Wg=20`2PM4<2
0:1e@P80XGI30P2RMd@20:=hA@80X7E20P2QMT<20:9gA080XgQ500<0WgI20:1g@`2RNDD00P2TNdL0
0`2SNTH0XWU50:5hA0030:9hAP80XgU70`2TNTP20:5hA0040:9iA@2SNTH0XgY60:AkA`80YGa80`2S
N4D20:AiAP<0YGY7202WOTX20:9iA@80XgY600@0Y7]70:ElB02UO4P0YGa80P2VO4`0102VO4X0YWe9
0:ImB@2VODL20:ImA@<0YWe90P2WOTX30:QoB`80YW]600@0Yga70:QmB02ZOdX0Zh1;0P2/PD`01P2/
PU00ZX1>0:QnC02WOD/0YWa:0:MmB`80Z7i<1P2YP4`20:Z1C@80ZX5;00@0ZH1:0:QoB@2WOTP0YWe7
0P2UO4H40:N2CP@0YX5=0P2YQ4l20:R3CP<0Yh9=0P2VPD`80:V0C0@0Zh9>102ZPDd30:R3C`<0ZHA@
0P2ZQE480:n5D`P0[HA@202]Pe480:b7D`P0[8MB202]R5@40:b7D`@0[HQD202_QE<80:j5D@<0[XE?
0P2]Q4h30:b3C@@0[hIB102^QE420:Z5D0<0ZHA?0`2XPdh30:Z0CP030:UoC@2XOT`0Z7i<0080Yge;
1@2SOTT30:AoBP030:AoB`2SOTX0XGa800<0WgY600<0X7]70:5lB02PNdL00`2PNdL509mjAPP0WWU5
00<0W7M309]f@P2JMD400P2IM4000`2JMD40W7M309ehA00209]g@`80VWI20`2IMD40102HM400VWE1
09Ud@02GLSh209Ia?@0309Mb?P2IM400VWE100H0Ug8n0P2FLCd01P2EL3/0UG0l09E`?02EKch0U6ho
09A^@@80Tfa10`2DKSl309=]?P80TV`m00P0Tfhj09Ia?@2GLSh0UG0l08mZ=P2=J3@0SVTe095/>080
TV`m0P2AJc`3091Z>`0408mY>P2;IST0SFPk08mZ?@80TF`o00H0T6/n08eX>`2<IcX0Sf/k08iZ>P2<
J3P208]W=`0308aX>02>JSX0Sf/k00P0R6Lj00<0Qf<c08UU=@2;IcL00P2=JCT00`2<J3P0RFDe08QT
=00208MV<`0308MU=@27ICL0QfDh0080Qf@j00<0Qf@l08QS=P28HcH03P28HcH808IV=`<0QFHg00<0
Q6Df08=T=@22Hc@00P22Hc@908QS=`<0QV@g0P25HcH308IT=`0508QV>027ICL0QfDg08IT=P25HcD0
0P24HS@01`23HC<0PFDe08=T=@24ICH0QFDf08IT=P28HcH00P29HcH00`2:J3/0RFLj08MU>00208IT
=`0308MU>029IcX0RVPk00P0R6Hh1P2;JC/208YX>P<0SV`n0P2=Jcd308aZ?080RfTi0P2<JSX408e[
>`0808aY<`2=JCD0Sf/g095]>`2AKCd0T6/n08mZ?P2>JCd309=_?`80TVhn0`2AKCd01P2BK4D0TVe3
09=^A02DKd<0UG1309Ib@P80Ug=1202GLd<02@2HM4@0Ug=309Ib@P2ELD40UW9209Mc@`2IMDD0VWI6
09eiB@0309ijBP80Wg];0P2PO4`30:1kA`<0XGa80P2RODT20:5nAP090:5nB02ROTX0Xgm=0:=oC`2T
P500Y7mB0:5mB`2ROT`0XWi:0080XWm900l0Xh180:>0AP2SP4H0WWY609mkA`2QODT0Xgm;0:F1C@2V
PTh0Z8A@0:V5D@2SOd/0YH5=0:N3C`2YQE400P2ZQU820:V5D@80Z8A@00X0ZHEA0:^7D`2/R5@0[8QD
0:^7D`2YQE40Z8A@0:V5D@2[Qe<0[8QD0P2]RED00`2/R5@0ZhMC0:V5D@020:b7D`80[HQD0P2^RED2
0:n:EP80[XYF0`2_ReL30;2<F080/8aL0P2aSEd20;:>GP80/hmO0`2cSV430;B?HP80]I1S0P2cSel0
102dT600]I5Q0;JBHP2gTf<20;RDI0@0]i5R102hTV<30;NCH`<0^9AT0P2iUFD20;VDJ0030;VDI`2i
UFD0^IES0080^IEQ00<0^IIP0;ZFIP2jUVH03P2jUVH30;VEI@80^9AT0`2gTf<01P2lV6P0^iMW0;ZF
IP2iUFD0^9AT0;JBHP80]I5Q0P2jUVH60;VEIA00^9AT0P2kUfL20;ZFIP80^IEU0P2hU6@20;JBGP04
0;NCG`2hU600^9AP0;VEH@80^YIR2@2fTV880;RDH080^9=L00<0^9=N0;VDH02iTf800P2jU6D0102j
U6L0^YIT0;ZFI02jUV@30;VEH`80^9AR4P2hU6@20;VEI@h0^YIV0P2iUFD0102hU6@0]i=S0;NCH`2g
Tf<80;JBHPP0]YAT0P2hUEd00`2hUEl0^9AP0;RDHP020;RDI0030;RCIP2gTf<0]i=S00@0]i=S0P2f
TV820;RDI0<0]i=S0`2fTV880;F@H`P0]91P102eTF440;JBHP80]i=S0P2fTV820;FAH@X0]91P0P2a
SEd20;:>GP80/hmO00/0]91P0;FAH@2eTF40^9=V0;NBI@2fTF@0]8mR0;:=H02`Reh0[hYM0:j9G002
0;:>GP030;>?G`2dT600]I5Q0080]Y9R00@0]i=S0;>AH@2cTF40/i5Q0`2bT6020;6?G`<0/heN00<0
]8iO0;F?H02eSf000P2fT6480;B@G0040;>>H@2dSf80]8mR0;B?HP80/hiQ0P2bSF020;>?G`<0/XiN
1P2aSEd30;:>GP80/hmO0`2dT6001@2cSel0/XiN0;6=G@2`S5`0[h]K0080/XeP00<0/HaO0;2;GP2`
Reh00`2`Reh40;6;G0@0/XaM0P2_RUd20;2;GP80/HaO0P2bSF040;6;G0`0/XaM00@0/8YK0;6;G02b
S5d0/XaM0P2dSUl00`2eSf00]Y1Q0;6=F`070;6=F`<0/HeM102`S5`00`2aSEd0/HeI0;6=F@060;6=
F@D0/HeK102bSU`0402bSUh0/HeM0:n;F`2^RUX0[HUI0:j:FP2_Re/0/8aL0:n:GP2`Rel0/HaO0;:>
GP2bSU`0/HeI0;2<F02_S5H80;2;GPP0[h]K00H0[HYD0:f9E@2]RED0[XYH0:j:FP2_RUd20:n:GPP0
[XYF00<0/8aH0:n;E`2_ReL0102_ReL90;2<F0<0[XYJ00D0[h]K0;2<G02`S5`0/8aL0;6=G@060:n;
F`80/8aL00@0/XeI0;6<F02`ReL0/8]G0P2^RED00`2]R5@0[8MC0:n9FP040:j8F@<0[HMH202/R5P3
0:b6E@030:f7EP2^R5L0[hUH0080/8YI0`2^RUX20:f9F@<0[8QH202[QeL80:f8E080ZhIA0P2/Qe82
0:f8D`80[XUD0`2_REP30:j8E`<0[HMF0P2/Qe<60:^6DP80[8MC102]R5@20:j9E@<0Z8=?0`2YQ502
0:Z5D@030:^6DP2ZQE40Z8=?0080Yh9>00<0Z8=?0:V4D02ZQE40202YQE400`2]R5@0ZXEA0:J1C@02
0:AoB`0:0:J1C@2ZQE40[HQD0:Z5D02XPdl0Yh9>0:J1C@2VP4l0Yh5@0:R2D@T0ZXAC00P0ZhIB0:V4
D02WPTh0YX5=0:F0C02VPDd0Yh9>0:R3C`80YX5=0P2WPTh20:R3C`80ZHA@0P2ZQE420:V4D080Z8=?
0P2WPTh20:J2CPH0Yh=?402UP4`30:=oB`80Y81<0`2UPDd40:N2CP80YX5=0P2UP4`00`2SOd/0Y81<
0:B0C0020:F1C@80YX9>00<0Yh=?0:R4D02XQ5001P2XQ5090:N2CPP0ZHA@0`2WPTh30:J1C@80YH1<
202TOdX20:B0C0<0Xgm;0`2ROTX00`2ROT`0XGe;0:5mB`020:1lBP80Wg]900@0WWY809mjAP2PNdL0
XWe90`2TOd/00`2SOTX0XWe90:1kA`020:1kA`80XGa80`2RODT60:1mA`80XGi8202PNdL20:AoB`06
0:9mB@2QO4P0WgY609ehA02LMd<0VgI2202KMd<00`2JMD40VgI209ehA00309mjAP0409iiA@2MN4@0
XGa80:9mB@<0Xgi:00<0XGa809mjAP2NNDD00`2MNDD309ijAP80Wg]70`2PNdL209mjAP<0WWU500<0
X7Q50:5iAP2QNDH00P2QNDH30:9jA`0309ahA02NNTH0Wg]70080X7a800H0Wg]709ijAP2LN4@0WGQ4
09ag@`2KMT8209Ud@00309]f@P2LMd<0WGQ400<0W7M30P2KMT8409ag@`80VgE600<0VWA509UcA02H
LT<00P2GLD800`2FL440VGE509UeA@0:09UeA@80V7A400<0Ug=309Ib@P2FLCd01`2FLCd209=_?`H0
U7100P2CKT800`2CKT40TVhn099^?002095]>@03095^>02EL3`0UG0l0080U6lk0P2CKSX2099]>@P0
TV`m0P2CKCh4099/?@80TF/l0`2@JS/[ooooo`00:_ooool209Q/>`H0VFdl0`2JL3h309U_?@80V6hl
0`2IKcd209Y`?P80Vg4o00T0W79009]a?`2JL3h0VFlm09Q^?02IKcd0VW0n09ab@02MLd400P2IKcd2
09Y`?P80Vg4o0P2LLT0209]`@`80W7540P2MLTD209icAPP0VFlm202MM40809ebA@80WG=10P2LLT02
09ec@@0309me@`2QMdD0XWQ600P0X7I4202NMD4309ib@@80Wg=20`2PM4<40:5f@`@0XWM40P2PMD82
0:5f@`80XWM40P2SN4D0202NMD40X7M30:9iA@2SNTH0Y7]70:=jAP2RNDD0XGQ40`2RN4H20:=iA`<0
Y7Y80P2QN4@0102RNDD0XgY60:=jAP2TNdL20:ElB0<0XgQ50P2TNDH30:EjA`P0Ygi:0`2SNTH40:Ak
A`040:ElB02UNd/0YG];0:EkB@80YGa800<0YGa60:ElA02UO4@00P2UO4P20:ImB@80Ygi:0P2XOd/2
0:IkAP040:MlA`2XODP0ZWm:0:^0B`80[85<00<0ZX1>0:UoC@2WOD/00P2VO4X00`2WOD/0Z7i<0:Uo
C@020:V0C0<0ZX5=0P2YP4`01P2XOd/0ZH1:0:V0BP2YP4X0Z7m90:MnB0<0YWe7202VPDd20:V4C`80
Z8=>0`2WPTd20:J1C0P0ZH1<102ZPDd40:^2CP<0Z8=?0`2YQ5020:Z5D@@0[hEC102^Q5880:f4D0P0
[H=A202[QE@80:^6D@P0[8MC102]R5@40:b7D`P0[XAB202_QU830:j5C`80[HA>0`2/Pdd80:n6DP80
ZXE@0`2YQ4l30:R3CP030:^1D@2ZP500ZX1@0080ZX1@0`2YOdl20:F0B`H0Y7m:00<0YH1<0:=nBP2R
ODT00`2PNdL00`2QO4P0XWe90:1kA`030:1kA`D0XGa8202ONTH00`2NNDD0WGQ409]f@P0209Ye@@04
09]f@P2LMd<0WGQ409ahA0<0VgM30P2JMT8209Ue@@0309]f@P2JMD40V7<o0080Ug8n00<0V7<o09Ye
@@2KMT800`2GLSh509Qc?`0609Ia?02FLCd0UW4m09E_?P2EKd00UFm20P2DKD8209E_@0<0U6ho0`2C
KCh02@2EKCX0V70m09Ua?P2GKc`0TVXg091X=@2AJCH0U6`i09=]?P03099/?@80TF/l0P2@JS/00`2=
J3/0SVTl095/?`02099]@006091[?P2>JC`0S6Lj091/?02?Jc/0SFTi0P2<J3P00`2=JCT0Sf/k091/
?00808UW>@0308UU=@2;IcL0SFTi0080Sf/k00<0SFTi08YV=P28I3@00P28Ic@00`28ISH0R6Hh08QV
>@0208QU>`0308QU?@29I3L0RF@g00h0RF@g2029IcT208QY>P0408MX>@26IcP0QFHg08AU=P80Pf@e
2@29I3L308MU=`80R6Hh0`27ICL01@2:J3X0RFLi08UW>@28ISP0QfDg0080QV@f00L0QF<e08AX>026
IcP0QFHg08IV=`27ICL0RF@g0080RV@g00<0S6Xl08]Y>`29IcT00P28ISP00`29IcT0RfTk08aZ?008
08YX>PH0S6Xl0P2=Jcd208m]?`<0SV`n0`2=Jcd208aZ>P<0SF/k0`2>K3`0202=JS@0SVXf091/>02A
KC/0TVhn095/?`2@Jcl0SfXn0`2DL40209=_?`<0TVhn00P0Tfe609A_A@2DKdD0UG1409IaA02GLd<0
Ug=109Qd@PP0V7A400<0VWI609UeA@2HM4@00P2GLd<00`2IMDD0VgM709ahB00209mkB`80X7a<0P2Q
ODd20:9nCP@0XGa80P2RODT20:=nBP050:9oA`2SP4P0Xh1:0:=oB`2SOdd00P2TP5001`2TOe80XWi<
0:9nC02ROTX0Xh1:0:B1B`2TPDT00P2UPTP0302PO4P0XGe90:9nBP2TP4`0YH5=0:N3C`2XQ500ZHEA
0:B0C02UPDd0Yh=?0:V5D@80ZXIB00H0ZHEA0:R4D02YQE40ZHEA0:Z6DP2[Qe<20:f9E@060:^7D`2Z
QU80ZHEA0:Z6DP2[Qe<0[8QD0P2^RUH00`2/R5@0ZhMC0:Z6DP030:f8E080[XUE0`2_RUH20:j:EP<0
[h]G0`2`S5P30;6=G@80/XiN0`2cSel40;B?HP80]I1S0P2fTF@20;>?G`040;B@H02eTF40]Y9R0;NC
H`80^9AT202hTV<20;NCH`<0^9AT0`2iUFD20;VDJ0030;VDI`2iUFD0^IES0080^IEQ00<0^IIP0;VE
I@2iUFD04@2iUFD20;RDI0<0]i=S0P2kUfD01P2jUV@0^9AR0;NCH@2fTV00]I5O0;B@GPH0^IEU0P2j
UVH@0;RDI0<0^YIV0P2iUFD30;RDI080]Y9N00@0]i=O0;RDH02hU600^IEQ0P2jUV890;JBHPP0^9AP
0P2hTe`00`2hTeh0^IAP0;VCHP020;ZDI@040;ZDI`2jUVH0^YIV0;ZFIP<0^IEU5@2hU6@20;VEI@80
^YIV00<0^iMW0;VEI@2iUFD01`2iUFD40;RDI0<0]i=S202fTV880;JDI080^9EM00<0^9EO0;RDH02h
U6800P2hU6@00`2hTfH0]Y9R0;JBHP060;NCH`80^9AT0`2gTf<30;JBHPP0]Y5T202dT6040;JBHP@0
]I5Q0P2gTf<20;JBHP80]I5Q2P2dT6020;6=G@80/XiN0P2cSel02`2dT600]I5Q0;FAH@2hTfH0]i9U
0;JAI02dSf80/XeP0;2;GP2_RUd0[XUL0080/XiN00<0/hmO0;B@H02eTF400P2fTV80102gTf<0/i5Q
0;>AH@2cTF430;:@H080/HmO0`2cSEh40;B>G`030;F?H02dT5`0]91L00H0]91L0P2eT6<00`2dSf80
/hiQ0;:=H0030;:=H080/hmO0`2bSUh60;6=G@<0/XiN0P2cSel20;B@H0030;>?G`2bSUh0/HeM00<0
/8aL1@2aS5l00`2`Reh0[hYM0:n:G@020;2:F`80/H]L0P2bS5d20;>=GP80[hYM0P2`Reh20;6<G`80
/XeP102bS5d40;6;G0P0/XaK0`2aReX00`2bS5/0/heL0;B>G@020;B>G@P0/HeM0`2`S5`40;6=G@03
0;2<G02`S5P0/8aH00H0/8aH2P2bSUh03`2aSEd0[h]K0:j:FP2]RET0[XYJ0:n;F`2`S5`0[hYN0;2;
G`2aS5l0/XiN0;:>G02aSET0/8aH0:n<EP080:n:G@P0[h]K00H0[HYD0:f9E@2]RED0[XYH0:j:FP2_
RUd20:n:GPP0[XYF0`2_ReL20;2<F0/0[h]G1@2_Re/30;2<G080[h]K0`2`S5`20:n;F`040:j:FP2a
S5P0/HaH0;2;E`80[hYF00<0[XUE0:f8E02]R5@00`2_REX00`2^R5T0[HMH0:f7F0020:b6E`P0[8QH
00@0ZhIB0:b7D`2]R5@0[XUE0`2_RUH00`2`ReL0[XYJ0:j:FP020:f9F@80[8QH0P2[QeL80:Z6EPP0
[HQD0P2[QU420:b7DP80[HQC0P2^RE@20;2;E`80[hYF102^RED00`2]R5@0ZhIB0:^6DP040:^6DP80
[8MC00<0ZhED0:b6E@2/QUD00P2]QeH20:j8E`040:n9F02XPdl0Z8=?0:R3C`<0ZHA@0`2ZQE401`2Y
Q500Z8=?0:N2CP2WPTh0Z8=?0:Z5D@2[QU80202YQE400`2]R5@0ZXEA0:J1C@020:=nBP0;0:J1C@2Z
QE40[HQD0:V3DP2XPU40Yh5@0:EoCP2UP4`0Yh9>0:R3C`2YQ4l0202/Q540202[QU80ZHA@0:N2CP2V
PDd0YH1<0:J1C@2WPTh0Z8=?0P2VPDd20:N2CP80Z8=?0P2YQ5030:Z5D@80ZHA@0`2XPdl30:R4D0D0
Yh=?402UP4`30:=oB`80Y81<0`2UPDd00`2XPdl0Yh9>0:N2CP020:J1C@<0YH1<102UPDd40:J2CP@0
Z8AB102YQE<90:R3C`P0ZXEA0`2WPTh30:J1C@80YH1<202TOdX20:B0C0<0Xgm;0`2ROTX40:5mB@@0
X7a800P0X7]70:5lB02SOTX0Y7m;0:F0C02TOd/0Xgi:0:9mB@80X7]70P2QO4P20:9mB@80Xgi:0P2Q
OTP60:1mA`P0X7]700H0YH1<0:AoB`2SOTX0XGa809mjAP2NNDD209ag@`P0VgM300X0VgI209ag@`2N
NDD0WgY60:1kA`2ONTH0WWU509ehA02QO4P0XWe90`2SOTX00`2QO4P0WgY609iiA@0309eiA@<0WWY6
0P2ONdL20:5lB0<0X7]70`2ONTH309iiA@0309mjAP2PNdL0X7]70080XGa800<0W7Q409ijAP2ONdL0
0P2PO4P01P2ONdL0WWY609ahA02MN4@0VgI209Ye@@80VGA000@0VWE109]f@P2MN4@0W7M31`2MN4@0
1`2LMd<0VgE609YdA@2JM4D0VG=409Qb@`2GLD800P2FL44:09UeA@80V7A4102GLd<809Ia?@H0U710
0P2CKcl209=^@P03099]@02BKSh0TFdk0080TFdi00<0TFhh09E`?02EL3`00P2DKc/209=^>P80TVdi
202BK3d209A^?`80Tfdn0P2BK3d2095[?0<0T6Xk:oooool002[ooooo0`2HK3/309U]?080VVhm0P2I
Kcd809Y`?P<0VFlm00/0VW0n09ab@02MLd40Vg4o09Y`?P2IKcd0V6hl09U_?@2JL3h0W79009ec@@03
09Y`?P80Vg4o0`2LLT0209Y_@P0409]`@`2LLD@0WG9509ebA@80WW=6202JL3h809ed@0P0W7540P2M
M40209ac?`80WGA000<0WgI20:5hA02RNDD0202OMD<809ie@@<0WW910P2OLd830:1d@`@0XGI3102R
Md@20:1e@P80XGI30P2RMd@20:=hA@0309ie@@2OMT80XGQ40080XgY600<0XWU50:5hA02PMd<00`2R
N4H20:=iA`<0Y7Y80`2RNDD20:=jAP<0Y7]70`2SN4D20:AiAP<0YGY7202VODT80:ElB080YG];00@0
YG]90:ElB02UO4P0YGa60P2UO4@30:ElB080YWe90`2WOTX20:MlA`040:QmB02YOTT0ZGi90:YoBP80
Zh1;00T0ZGm=0:QnC02WOD/0YWa:0:EkB@2VO4X0Z7i<0:UoC@2YP4`00P2ZPDd01@2[PTh0ZX5=0:V0
C02XOd/0Ygi:00@0Z7m9102YP4X0102TOd/0YH1<0:F0C02UP4`30:J1C@030:N2CP2YQ4l0ZHA?0080
Z8=>0`2WPTd20:J1C0P0ZX1>00@0ZH1<0:Z1C@2ZPDd0ZX5=0`2[PTh0102/Pdl0Z8=?0:R3C`2XPdl3
0:V4D080ZXEA0`2^Q5820:f3D@<0[89@202/Pdl80:f3D@P0ZhEF202[QU480:b7D`040:j9E@2]R5@0
[HQD0:f8E0<0[8MC00<0ZhIB0:j4DP2^Q5801P2^Q5880:n6D0<0[XE?0P2]Q4h30:b3C@040:f4D02^
QE40[XEA0:j5D@<0[hIB00<0/8MC0:Z5D02ZQE000`2YQ4l30:R3CPL0Zh1C00@0ZWmB0:J1C02VPD`0
YX5<0`2UP4/20:AoBP030:J1C@2TOd/0Xgi:00<0XGa800@0XWe90:=nBP2PNdL0X7]70P2QO4P50:9m
B@P0X7]700T0WgY609iiA@2LMd<0VgI209Ye@@2KMT80W7M309ehA02MNDD00`2LN4@209]g@`80VWI2
00<0W7M309]f@P2JMD400P2IM4000`2JMD40VgI209ag@`0409Qc?`80VGA00P2JMD401P2GLSd0Ug8n
09Mb?P2FL3l0UW1109E_@P80UFi30`2EKd0209A^?`<0Tfdn00T0U6Xh09M]>`2JL3h0V6hl09AZ>02B
J3H0U6Xh09M]>`2DKSl00`2CKCh2099/?@80TF/l00/0T6/n095/?`2AK3l0TVe0095/?`2@Jch0SfXm
08iY?02AKCd0T6`l08iZ>P0208eY>@0308iZ>P2@K3`0TFdm00P0S6Ph0P2=JCT01P2>JSX0Sf/k08iZ
>P2=JCT0S6Ph08]W=`80RFPe00<0RFLg08UW>@29IcX00P29IS`00`29ISh0RfHi08]V>@0>08]V>@P0
SFPk0P29JS/208QY>P0408MX>@26IcP0QVLh08EV=`T0S6Hg00<0QfDe08QV=P29IcL00P2:J3P00`29
IcL0R6Hf08MU=@0308YX>P<0RFLi0P28ISP02`26JSX0QfPi08MX>@28J3T0R6Hh08YU>02;ICP0RV@g
08i/?02<JSX0RfTi0080RVPh00<0RfTi08aZ>P2>K3`0202;JC/0102<JS`0SF/m08e[?@2=Jcd308i/
?P<0Sfdo0P2>K3h308e[?@0408aZ?02=Jc/0SF/k08e[>`80SV`l0`2?KCd0202?K3H0T6`h099^>P2C
Kcd0U71009=^@@2BKD40TFa0202EKd001P2EKdP0UG1609IaA`2FLDD0Ug9509Mc@`80V7A2202JMTH0
202LN4P0VgM709YfAP2IMDD0VWI609]gA`2MNDT0WWY:0P2PO4`30:5mC@<0XWi>00@0XGa80:9mB@2R
ODT0XWe90P2SOTX20:AoB`80Y85900<0Y85;0:B0C02TP4h00P2TP5001`2TOe80XWi<0:9nC02SOd/0
Y85;0:F2C02UPTX00P2VPdT20:=oB`030:B0C02UPDd0YX9>0080Yh=?00T0Z8A@0:F1C@2VPTh0Z8A@
0:V5D@2ZQU80ZHEA0:R4D02WPdl00P2ZQU801P2[Qe<0[8QD0:f9E@2]RED0[8QD0:^7D`80ZXIB00L0
ZhMC0:f9E@2^RUH0[XYF0:f9E@2[Qe<0ZXIB0080[HQD0P2^RED30:n:EP030;2;E`2^RUH0[XYF00<0
[h]G0`2`S5P20;6=G@80/XiN0`2cSel00`2dT600]8mR0;F@H`020;F@H`80]Y5T0P2gTVD20;>?G`04
0;B@H02eTF40]Y9R0;NCH`80^9AT00@0^YAU0;VCI02iTf@0^I=T0`2hTV<00`2gTF80]i=S0;RDI002
0;RDI080^IEU0P2jUVH20;VDJ0030;VDI`2iUFD0^IES0080^IEQ00<0^IIP0;VEI@2iUFD04@2iUFD2
0;RDI0<0]i=S0`2iUF400`2hU600]i=O0;JBGP020;FAG@80^9AT0`2iUFD30;ZFIP<0]i=S0P2hU6@3
0;VEI@P0^9AT0P2jUVH20;VEI@<0^9AT00@0]i=S0;NCG`2gTel0]i=O0P2hU6030;VEH@T0]i=S202h
U6020;RCG0030;RCGP2iU600^I=R0080^YAU00@0^YAW0;ZEJ02jUFP0^YEX0`2iU6L20;RCIQ00^9AT
0P2iUFD30;RDI0030;VEI@2kUfL0_9QX00P0^IEU202gTf<80;RDI0P0]I=S0P2hUEd00`2hUEl0^9AP
0;RDHP020;RDI0040;RCIP2fTV80]Y9R0;JBHP<0]i=S102hU6@30;NCH`<0]Y9R202fTF@80;B@H004
0;NCH`2fTV80]Y9R0;JBHP<0]I5Q00<0]91P0;NCH`2gTf<00P2fTV820;FAH@X0]91P102bSUh20;>?
G`<0]91P0P2fTF@0102eT6<0]8mR0;:=H02aS5l20;2;GP80/XiN00<0/hmO0;B@H02eTF400P2fTV80
102gTf<0/i5Q0;>AH@2cTF430;:@H080/HmO202cSEh80;B@G0040;NBI@2eT6<0]8mR0;:=H080/HaO
0P2bSF020;>?G`<0/XiN1P2aSEd30;:>GP80/hmO00@0]I5Q0;B@H02bSUh0/8aL0P2_Re/20;2<G003
0;2;GP2aS5l0/XeP0080/XeP00@0/8]N0:n:G@2^RE`0[hUJ0P2`RU/01@2aRe`0/XaM0;>=GP2cSEh0
]8iO0080[hYM0P2`Reh20;6<G`80/XeP00@0/heN0;:<G@2bS5d0/XaM0`2aRe`00`2`RU/0/XeI0;:=
F@0>0;:=F@P0[heO00<0[XYJ0:n;F`2`S5`00`2bSUh00`2aSEd0/8aL0;2<F0070;2<F0030;B?HP2c
SV40/hiQ0080/hiQ0`2bSF004@2aS5l0/XiN0;6=G@2_Re/0[XYJ0:f9F@2^RUX0[h]K0;2<G02_RUh0
/8]O0;6<G`2bSUh0/XiL0;6=F@2`S5P0[haF00P0[hYM202_Re/01P2]RU@0[HUE0:f9E@2^RUP0[XYJ
0:n:G@80[hYN0`2_ReL20:j:EP<0[HUE00<0[XYF0:n;E`2`S5P00P2aSET00`2`S5P0[h]G0:j:EP08
0:n;E`050;6=G@2`S5`0/8aL0;2<G02_Re/00`2^RUX0202_Re/0/8aL0;2<G02aSEd0/8aL0:n;F`2^
RUX0[HUI202_RUH20;2:F`030:n9FP2^R5T0[HMH0080[8IG00<0ZhEF0:b8F02/R5P01P2/R5P20:b7
DP060:j9E02_RUD0[hYE0:n:E@2^RE@0[HQC0`2]RET20:b8F0<0ZhMG202ZQUH80:b7D`80ZhIA0P2/
Qe820:f8D`80[XUD0`2_RUD30:j9E0<0[HQC0P2ZQE430:^6DP<0[8MC0P2ZQ5D0102[QEH0[8IG0:b6
E`2]QeP20:j8F@<0Z8=?0`2YQ5020:Z5D@80ZHA@0`2WPTh00`2YQ500ZXEA0:b7D`080:V5D@030:b7
D`2ZQE40Yh9>0080YX5=00/0Yh9>0:Z5D@2/Qe<0ZH=F0:R2E@2VP540YGm>0:F0C02VPD`0Z8=<0:V4
C@080:b3C`080:^6DP2YQ500Yh9>0:J1C@2UP4`0YX5=0:N2CP2XPdl20:J1C@80Yh9>0P2XPdl20:V4
D0040:^6DP2ZQE40ZXEA0:Z5D@80ZHA@0P2XPdl20:R4D080Yh=?102VPTh30:AoB`80YH1<0`2VPDd8
0:AoB`<0Xgm;0P2TP4`30:F1C@030:V4D02XPdl0YX5=00<0YH1<0P2VPDd80:J2CP<0Yh=C0P2XQ5@3
0:V5E@T0Z8=?202YQ5030:N2CP<0YX5=0P2UP4`80:=nB@80Y81<0`2SOd/30:9nBPP0XWe800<0X7]7
0:5lB02SOTX00`2UP4`20:=nBP<0XGa80P2RODT30:=nBP<0XGi80`2PODL209mlAPP0X7]70P2TOd/0
1P2SOTX0XGa80:1kA`2ONTH0WWU509ehA0P0W7Q400<0W7M309ehA02ONTH00P2PNdL01@2ONTH0WWU5
09ehA02QO4P0XWe900<0Xgi:00<0XGa809mjAP2NNDD00`2NNDD309mjAP80X7]70P2QO4P20:1kA`<0
WgY600H0WWU509]g@`2KMd<0W7Q409eiA@2NNTH209mkA`040:1lB02KMd<0WGU509ijAP80Wg]700H0
WWY609eiA@2KMd<0W7M309]f@P2JMD4209Ud@00609Ye@@2KMT80W7M309ag@`2MN4@0WWU50P2ONTH0
102NNDD0WGQ409ehA02LMd<209UcA0<0V7930`2GLD8809UeA@0309QdA02GLd<0UW920080UG5100<0
UW9209Mc@`2GLd<0202FLCd209Ea@@<0U7100`2CKcl0202DKd<0Tfi209=^@@2CKcl0TVhl099^>P2A
KCT0TFhh0P2EL3`209A_>`80Tfhj0P2BKCT8099/?@80UFm000@0U6ho09=]?P2BK3d0TV`m0P2AJc`3
08mY>R_ooooo000Zooooo`80Uf/j0P2HK3/0102IKC`0VVhm09Y^?@2JKSd209Q^?00409U_?@2JL3h0
VW0n09]a?`80W7900100Vg4o09Y`?P2IKcd0V6hl09U_?@2JL3h0W79009ec@@2KLCl0VW0n09U_?@2H
KS`0VFlm09Y`?P2LLT00WG=10P2JL3h209]a?`@0W7900P2IKT401P2JKd80Vg1309aaA02MLTD0WW=6
09mdA`P0Vg4o202MM40809aaA080WG@n0P2LLcd209ed?P0309mf@02QN480XWU300P0WG=1202NMD43
09ib@@80Wg=20`2PM4<40:9gA0@0XGI30P2PMD820:5f@`80XWM40P2SN4D0202NMD40WgI20:5hA02R
NDD0XgY60:9iA@2QN4@0X7M30`2RN4H20:=iA`<0Y7Y80`2TNdL20:=jAP<0XWU50`2SN4D20:AiAP<0
YGY7202VODT20:MnBPH0YWe90P2TNTX0102TNTP0Y7]70:AkA`2TNdD20:Ak@`@0YGa80P2VODT20:Mn
BPP0ZGi900<0Z7i<0:MmB`2VO4X00P2UNdT01@2VO4X0Z7i<0:UoC@2YP4`0ZX5=00<0Zh9>00D0ZH1<
0:MnBP2VODT0Ygi80:QoB@020:V0BP80Zh9<00<0[8==0:f4CP2TOd/00P2TOd/00`2UP4`0YX5=0:J1
C@020:N2CP80ZHA?0P2XPdh30:N2C@80YX5<202[PE420:V0C080ZX5=0P2[PTh20:b3C`<0Z8=?0`2Y
Q5020:Z5D@80[H=A0P2/PU00102[PDl0ZX1>0:Z0CP2ZP4h80:b3C`P0[H=A202ZQ5D80:Z5D0P0ZhIB
0P2^RED20:f8E080[8MC0P2[QU880:f3D@P0[hI>0`2^QDl20:f4CP<0[8==0`2/Pdl00`2]Q500[XEA
0:j5D@020:n6DP80ZXE@0`2YQ4l30:R3CPD0Zh1C0`2/PE@30:N2C@030:J1C02UP4/0YH1;0080Y7m:
00T0YX5=0:F0C02SOTX0XWe90:5lB02RODT0Xgi:0:AoB`2PNdL00P2QO4P20:9mB@<0Xgi:00<0Y7m;
0:5lB02QO4P01`2QO4P00`2ONTH0WGQ409ag@`0209]f@P0309ag@`2MN4@0WGU50080WGU50P2LN4@3
09]g@`0309ehA02LMd<0VgI20080VWE100<0VgI209ag@`2MN4@00`2HLcl00`2IM400VWE109Ye@@02
09]f@P0609Qc?P2HLcl0V7<o09Ma@02GLD80UW130P2FKd@209I`@@80UFm00`2DKSl02@2CKCh0TVPf
09I/>P2IKcd0V6hl09E[>@2DJSP0Ufdk09Y`?P0309A^?`80Tfdn0`2BK3d0102DKd80Tfi1095/?`2@
Jch208mZ?@80T6/n00<0TFdm091/?02?Jc/00P2>JSX00`2?Jc/0T6`l095]?@0808iX=`03095]?@2@
K3`0Sf/k00@0SFTi00H0SVXj08YY=P2:JCH0RVPh08YX>P2:J3/208YW?@0308YW?`2<IcX0S6Lj00h0
S6Lj202?JC`408UZ>`@0R6Tj2@2?IcH00`28Ic@0RFPe08YY=P0208a[>00308YY=P29J3D0R6Ld00@0
RVPj0`2;JC/01`2<JS`0Qf/k08UZ>`29JS/0RFTj08UW>@2;IST00P2;ICP00`2?KS/0SVdj08a[>002
08]Z=`0308a[>02>KCX0Sfhk00P0S6Xl0P2=Jcd208i/?P0408m]?`2@KT00T6i0091^@0<0SV`n0P2=
Jcd308aZ?0<0SV`l0P2?KCd3091^?P09095^>02BKSX0U70l09Ib@02FLT80UG1309A_@`2CKT80UF`n
0080UVdo00/0Ufi009Q_@@2IL480VG1209Ya@`2FL4T0UW5709MbB02GLTH0Ug9509QdA00209Qd@PP0
W7Q80P2NNTX309ahB00309ijBP2PO4`0XGe=00<0X7a<0P2QODd30:9nCP80XWe90P2SOTX30:AoB`09
0:F0C02UPTX0YH9:0:F2C02UPDd0YH5?0:F1D@2TP500Y7mB0080XWi<00H0Xgm;0:B1B`2UPT`0YX=;
0:N4BP2XQD/80:J2CP080:F1C@2VPTh0Z8A@0:V5D@2ZQU80ZHEA0:R4D02WPdl20:^7D`060:b8E02]
RED0[XYF0:j:EP2]RED0[8QD0P2[Qe<01`2/R5@0[HUE0:j:EP2^RUH0[HUE0:b8E02[Qe<00`2^RED3
0:n:EP80/8]G0P2^RUH30:n;E`<0/8aH0`2bSUh30;>?G`80]91P0P2eT6<20;JAI0<0]i9U00L0^9=V
0;>?G`2cSel0]91P0;FAH@2fTV80]i=S0080^9AT0`2jU6D00`2iTf@0^99S0;RBH`020;NAHP<0^9AT
0P2iUFD30;ZFIP80^IAX00<0^IAW0;VEI@2iUF<00P2iUF400`2iUV00^9AT0;RDI00>0;RDI0<0^IEU
0P2hU6@30;NCH`P0]i=O0`2hU6@00`2iUFD0^YIV0;ZFIP020;^GI`030;JBHP2gTf<0]i=S0080^9AT
0P2iUFD00`2jUVH0^9AT0;RDI0060;RDI0<0^IEU0`2hU6@20;NCH`<0^IEQ0P2hU6030;NCG`T0^IEU
202hU6020;RCG0030;RCGP2iU600^I=R0080^YAU00@0^YAW0;ZEJ@2jUFT0^YEY0`2iU6P20;RCIa00
^9AT00P0^YIV0;VEI@2hU6@0]i=S0;RDI02iUFD0^iMW0;bHJ0P0^9AT202gTf<80;ZFIPP0]I=S0P2h
UEd00`2hUEl0^9AP0;RDHP020;RDI0030;RCIP2eTF40]I5Q0080]Y9R00<0]i=S0;RDI02hU6@00`2h
U6@30;NCH`<0]Y9R202gTVD80;B@H080]i=S0P2fTV820;FAH@80]91P0P2gTf<20;JBHP80]I5Q3P2d
T6020;>?G`<0/XiN0`2dSf820;>>H@<0/XeP0P2bSUh00`2cSel0]91P0;FAH@020;JBHP040;NCH`2c
TF40/i5Q0;>AH@<0/Y1P0P2aSel80;>=GPP0]91L00@0^9=V0;JAI02dSf80/XeP0`2aS5l00`2bSF00
/hmO0;>?G`030;:>GPH0/HeM0`2bSUh20;>?G`050;FAH@2dT600/HeM0:n;F`2^RUX00P2_Re/02@2`
S5`0/8]N0;6<G`2bSF00/hiQ0;:=H02aS5l0[hYM0:f8F`020:n9FP040;2:F`2aRe`0/XaM0;>=GP80
]8iO0P2_RUd20;2;GP80/HaO0P2bSF020;>=GP80/XaM0P2aRe`20;2:F`P0/XeI0P2dSe/00`2cSUX0
/XeI0;6<F0020;2;E`030:n:EP2^SF00[XeP00H0[XeP00P0[HUI0:j:FP2`S5`0/XiN0;>?G`2bSUh0
/HeM0;2<G0P0[h]G0`2dSf<20;>>HP80/XeQ0P2aS600402bSUh0/HeM0:n;F`2^RUX0[HUI0:j:FP2_
Re/0/8aL0:n:GP2`Rel0/HaO0;:>GP2bSU`0/HeI0;2<F02_S5H80:j9G0P0[h]K00H0[HYD0:f9E@2]
RED0[XYH0:j:FP2_RUd20:n:GP030;2<F02_ReL0[h]G0080[XYF0P2]RED0102/R5@0[HUE0:j:EP2`
S5P20;6=F@030;2<F02^RUH0[HUE00P0[XYF00X0/hmO0;:>GP2aSEd0/8aL0:j:FP2]RET0[8QH0:^7
E`2_Re/0/8aL0`2aSEd01@2_Re/0[HUI0:b8F02/Qe<0[HQD0080[XUE0P2`ReL0202aS5P0/XeI0;6;
G02`RU/0[hUJ0:j8F@2]QeP0[8IG0P2[QEH80:b8F0080:f8D@2^RE80[hYC0;2;E02_RU<0[XUB0:b7
D02[QTl20:f9F@80[8QH102[QeL80:V5E@P0ZhIB0P2[QU420:b7DP80[HQC0P2^RE@20:j9DP@0[HQA
0`2/Qe030:Z5D@030:^6DP2/Qe<0[8MC0080[HQD0P2XPU<0102YPe@0ZXAE0:^5EP2/QUL20:f7F0<0
Z8=?0`2YQ5020:Z5D@030:V4D02XPdl0Yh9>0080Yh9>00<0ZHA@0:^6DP2/Qe<0202YQE420:Z5D@@0
ZHA@0P2ZQE40202XPEH0Yh1E0:J0D`2UOdh0YH1<0:J1BP2WPdT0Z8A:202/Pdd0202[QU80ZHA@0:N2
CP2VPDd0YH1<0:J1C@2WPTh0Z8=?0P2VPDd20:N2CP80Z8=?0P2YQ5020:^6DP<0ZXEA0`2YQ5020:N3
C`80YX9>0P2UPDd20:B0C0030:=nBP2TOd/0Y7m;0080YH1<0P2VPDd00`2WPTh0Y7m;0:AoB`060:Ao
B`<0Xgm;0P2TP4`30:F1C@080:V4D02XPdl0YX5=0:F0C02TOd/0YH1<0:J1C@2WPTh30:N3C`D0YX9>
0P2UPE420:J2DP040:N3D`2XQ5@0Z8AD0:R4E0T0ZHA@202XPdl30:N2CP<0YX5=0P2UP4`80:=nB@80
Y81<0`2SOd/30:9nBPD0Y7e60`2UOTL0202QO4P0XWe90:AoB`2UP4`0YX5=0:F0C02TOd/0Xgi:0P2Q
O4P20:9mB@@0Xgi:0P2ROdT20:5nB0040:1mA`2OO4H0Wga609mlAPP0X7]700<0Xgi:0:9mB@2RODT0
0P2QO4P30:1kA`P0WGU500<0WGQ409iiA@2PNdL00P2PNdL01@2ONTH0WGQ409ag@`2QO4P0XWe900<0
Xgi:00<0XGa809mjAP2NNDD00`2PN4D30:5iAP80XWY70`2PNdL209mjAP<0WWU50P2GMT402@2HMd80
VGQ309YiA02KNTD0W7]609elA`2JMT80VgM309ahA00209ijAP0609ahA02KMd<0VWI209ag@`2KMT80
VGA00P2HLcl01P2IM400VgI209ag@`2LMd<0WWU509mjAP80X7]700@0WgY609iiA@2NNDD0W7M3102G
LD8409Qb@`P0VGE500P0UW9209Ea@@2CKcl0TVhn09=_?`2DL400UW9209Mc@`P0UW4m0`2ELD400`2D
L400Tflo09=_?`02099^?P0809E`A02DKd<0U6m209A`@02CKcd0Tflk099^>P2BKcT209E`?080U6lk
0P2CKSX2099]>@P0TV`m0P2FL4401P2EKd00U6ho09=]?P2BK3d0TF/l091Z>`<0SfTj:oooool002[o
oooo0P2GJcX209Q/>`0409U]?02JKSd0VVhm09]_?P80Ufdk00T0V6hl09Y`?P2KLCl0W79009ec@@2N
M480Vg4o09Y`?P2IKcd00P2HKS`02`2JL3h0W79009id@P2KLCl0VW0n09U_?@2HKS`0VFlm09Y`?P2L
LT00WG=10080VW0n0P2KLCl309ab@00909ec@@2HKD00VFi109Y_@P2KL4<0W75409ebA@2NLdH0WgA7
00P0W790202MM40809aaA080WG@n0P2LLcd209ed?P0309mf@02QN480XWU300P0W790202NMD4309ib
@@80Wg=20`2PM4<40:9gA0@0XGI30P2PMD820:5f@`80XWM40P2SN4D0202NMD40WgI20:5hA02RNDD0
XgY60:9iA@2QN4@0X7M30`2RN4H20:=iA`<0Y7Y80P2UO4P0102TNdL0XgY60:=jAP2RNDD20:5hA0<0
XgQ50P2TNDH30:EjA`P0YWe90`2XOd/50:MnBP80Y7Y:00@0Y7Y80:AkA`2TNdL0Y7]50P2TNd<0102T
NdL0YGa80:ElB02UO4P20:ImB@80Ygi:0`2ZOdX20:UnB@<0Z7e800<0Z7i<0:MmB`2VO4X00P2UNdT0
2`2VO4X0Z7i<0:UoC@2YP4`0ZX5=0:^2CP2/Pdl0Zh9>0:V0C02WOTX0YGa80080Ygi800@0ZH1:0:Z1
B`2/Pdd0[HA>0P2_QU020:=nBP040:AoB`2UP4`0YH1<0:J1C@80Yh9>0P2YQ4l20:R3CP<0Yh9=0P2V
PD`80:b2DP<0ZH1<00<0ZX5=0:^2CP2/Pdl00P2/Pdl30:R3C`<0ZHA@0P2ZQE420:b2D0040:^1C`2Z
P4h0ZX1>0:UoC@80Z7i<202/Pdl80:f3D@P0ZXAG202ZQE080:^6DP<0[XUE00<0[HQD0:b7D`2[QU80
0P2[QU880:f3D@P0[hI>0`2^QDl20:f4CP<0[8==00@0ZX5=0:^2CP2[PTh0[8=?0P2]Q5020:j5D@80
ZXE@0`2YQ4l30:R3CP<0Zh1E1@2/PEH20:R3CP80Yh9=00L0YX5<0:F0B`2UP4/0Y7m:0:N2CP2UP4`0
Y7m;00<0XWe900<0Xgi:0:AoB`2QO4P00P2QO4P00`2RODT0Xgi:0:AoB`030:AoB`T0XGa800D0X7]7
09iiA@2LMd<0VgI209ag@`0209ehA00409ijAP2MNDD0WGU509eiA@80W7Q40P2KMd<00`2NNDD0WGQ4
09]f@P0209Ye@@0309]f@P2MN4@0WWU50080V7<o0P2IM4001@2JMD40VgI209]f@P2LMd<0V7<n0080
V7<o00<0Ug5009Ma@P2FL4<00P2FKd@209I`@@80UFm0102DKSl0102BISD0UVXi09U]?02IKC`209IZ
>@0309U]?02MLD00UFm000<0U6ho0P2CKCh2099/?@0;09IaA02DKd80TF`o08mZ?@2>JC`0SfXm095/
?`2BKD00TVhn095]?@2?Jc/00P2>JSX00`2?Jc/0TFdm099^?P0808iX=`0809A`@02BKSh0Sf/k08aX
>02;IcL0S6Ph08iZ>P2@K3`208YY=P0308YX>02:J3X0RVPk0080RVLm00<0RVLo08aW>P2<IcX03P2<
IcX8091Z?@D0RFXk0`2:Jc`908mW=P0308QW=029J3D0RfXg0080S6/h00<0RfXg08UX=@28Ic@00P29
IcT00`2:J3X0RfTk08aZ?00208e[?@0<08i/?P28K3`0RV/l08UZ>`2:JS/0RVPj08]V>@2<IST0RfDh
091_?02?KS/0SF`i0P2<JcP00`2=K3T0Sfhk091_?00908e[?@80SV`n00<0Sfdo091^@02@KT000P2A
Kd4308e[?@80S6Xl0`2;JC/308i/?080Sfdm0`2@KSh03P2BKcT0U70l09Ib?P2GLd40V7A409MbA@2F
LDD0UG1409A[?@2EK3h0UVdo09M^@02IL480VW530P2KLT@01P2GLDX0Ug9809MbB02GLTH0V7=609Qd
A080V7A2202LN4P0202PO4`0Wg];09ijBP2MNDT0WWY:09mkB`2QODd0XWi>0`2PO4`20:5mC@<0XWi>
00@0XWe90:=nBP2SOTX0Xgi:0P2TOd/20:F0C080YX=;00<0YX==0:F1C@2UPDl00P2UPE401`2TOe80
XWi<0:=oC@2SOd/0YH9<0:J3C@2WQ4`00P2XQD/20:R4D080Yh=?00<0YX9>0:F1C@2UPDd00P2UPDd0
1`2WPdl0Z8A@0:V5D@2ZQU80ZHEA0:N3C`2VPTh00P2[Qe<01P2/R5@0[HUE0:j:EP2^RUH0[HUE0:b8
E080ZhMC00L0[8QD0:f9E@2_ReL0[h]G0:f9E@2/R5@0ZhMC00<0[XUE0P2_RUH30;2;E`80[XYF0`2_
ReL30;2<F0<0/XiN0P2cSel30;B@H0040;F@H`2fTF@0]Y5T0;JAI080]i9U0P2hTfH20;>?G`040;B@
H02eTF40]Y9R0;NCH`80^9AT0P2kUFH0102jU6D0^I=T0;VCI02hTV<20;NAHP80^9AT0`2iUFD30;ZF
IP80^IAX00<0^IAW0;VEI@2iUF<00P2iUF400`2iUV00^9AT0;RDI00>0;RDI0<0^IEU0P2hU6@30;NC
H`<0]Y=M0`2gU5h20;REG`040;NCH`2hU6@0^9AT0;VEI@80^YIV0P2kUfL20;JBHP040;NCH`2hU6@0
^9AT0;VEI@80^YIV202hU6@30;VEI@80^9AT0`2gTf<20;ZFHP040;VEH@2hU600^9AP0;NCG`80]Y9N
2@2jUVH80;RDH080^9=L00<0^9=N0;VDH02iTf800P2jU6D0102jU6L0^YEY0;ZEJ@2jUFT30;VDJ080
^9=W402hU6@00`2jUVH0^IEU0;RDI0020;NCH`030;VEI@2kUfL0_IUY00P0^9AT0`2fTV850;NCH`P0
^iMW202eTf<20;REG@030;REG`2hU600^9AR0080^9AT00<0^9=V0;FAH@2eTF400P2fTV80102gTf<0
^9AT0;RDI02iUFD20;RDI0<0]i=S0`2fTV880;NBI@P0]91P0`2gTf<00`2fTV80]I5Q0;B@H0020;B@
H080]i=S0P2fTV820;FAH@X0]91P0P2eTF420;B@H080/hmO00<0/XiN0;6=G@2aSEd0202cSV420;:>
GP030;>?G`2dT600]I5Q0080]Y9R00@0]i=S0;>AH@2cTF40/i5Q0`2bT6020;6?G`D0/heN0`2bS5d8
0;B@G0040;RCIP2gTVD0]8mR0;6<G`80/8]N00@0/HaO0;:=H02cSel0/hmO0`2bSUh60;6=G@<0/XiN
0P2cSel0102eTF40]91P0;6=G@2_Re/20:j:FP050:n;F`2`S5`0[hYM0;6<G`2bSF000P2cSV402`2a
S5l0[hYM0:f8F`2^R5T0[hUJ0;2:F`2aRe`0/XaM0;>=GP2dSUl0]HmP0080[hYM0P2`Reh20;6<G`80
/XeP0`2cSEh00`2bS5d0/H]L0;2:F`020;2:F`P0/XeH00P0]Y5L0;F@F`2dSeX0/XeH0;6<E`2_RUD0
[XUD0:f8D`P0[XeP00@0[8QH0:j:FP2`S5`0/XiN0P2cSel00`2aSEd0/8aL0:n;E`070:n;E`80]I1T
00D0]8mS0;>>HP2cSV80/hiR0;:=H@020;6<H00@0;:>GP2aSEd0[h]K0:j:FP2]RET0[XYJ0:n;F`2`
S5`0[hYN0;2;G`2aS5l0/XiN0;:>G02aSET0/8aH0:n<EPP0[XUL202_Re/01P2]RU@0[HUE0:f9E@2^
RUP0[XYJ0:n:G@80[hYN0P2`S5P0102_ReL0[XYF0:j:EP2]RED20:b8E0030:f9E@2^RUH0/8aH0080
/HeI00<0/8aH0:j:EP2]RED0202^RUH0402eTF40]91P0;:>GP2`S5`0[XYJ0:b8F02[QeL0ZXIF0:n;
F`2`S5`0/HeM0;:>GP2aSEd0[h]K0:f9F@2[QeL20:^6DP040:f8E02^RED0/8]G0;6<F080/hiJ00H0
/H]L0;2:F`2`RU/0[XQI0:f7F02/QUL20:^5EPP0[8QH00<0[XUB0:n:D`2`Re@00P2`Re@00`2]R540
ZhI?0:V4C@020:f9F@80[8QH0`2[QeL00`2ZQUH0ZHEE0:V5E@060:V5E@P0ZHA@0P2[QU420:b7DP80
[HQC0P2^RE@30:f8D@<0[8M@0`2[QTl0102YQ500ZXEA0:Z5D@2[QU820:b7D`80[HQD00P0YX1C0:N1
E02XPUD0ZH=F0:Z4E`2[QEP0[8II0:f7FP<0Z8=?0`2YQ5020:Z5D@030:V4D02XPdl0Yh9>0080Yh9>
00<0ZHA@0:^6DP2/Qe<0202YQE400`2YQ500ZXEA0:^6DP020:b7D`0;0:^6DP2ZQE40ZHA@0:R1F02W
P5D0YX1C0:AnC@2TOdX0YX5:0:N3B@2XQ4P0202]PTd0202[QU80ZHA@0:N2CP2VPDd0YH1<0:J1C@2W
PTh0Z8=?0P2VPDd20:N2CP80Z8=?0P2YQ5030:^6DP80ZXEA0`2YQ500102WPdl0YX9>0:J2CP2UPDd2
0:B0C080Xgm;0P2SOTX0102TOd/0YH1<0:F0C02VPDd20:N2CPP0Y7m;0`2SOd/20:B0C0<0YH5=00<0
ZXEA0:R3C`2VPDd00P2TOd/00`2UP4`0YX5=0:N2CP040:N3C`@0YX9>0P2TOe80102UP5<0YX5D0:J1
E02WPUD20:R3EPT0ZHA@2`2WPTh30:J1C@80YH1<202SOTT20:B0C0<0Xgm;0`2ROTX40:AmAP@0YGi7
00P0XGa80:9mB@2TOd/0YH1<0:J1C@2UP4`0Y7m;0:=nBP80XGa80P2RODT30:=nBP030:AoB`2ROdT0
XWm90080XGi800@0X7e709mlAP2OO4H0WW]5202PNdL80:5lB0P0WWY600X0WWU509mjAP2PNdL0XGa8
0:1kA`2ONTH0WGQ409ag@`2QO4P0XWe90`2SOTX00`2QO4P0WgY609iiA@030:1hA@<0XGU60P2RNTL3
09mjAP80WWU50`2MN4@209Ie@00909Mf@@2HMd80VGQ309YiA02KNTD0W7]609Ue@@2JMT80VgM30080
WGU500H0VgM309Yf@P2IMD40W7M309]f@P2IM40209Qc?`0609Ud@02KMT80W7M309ag@`2NNDD0X7]7
0P2QO4P0102PNdL0WWU509iiA@2LMd<209E_@00309I`@@2GLD80V7930080VG=400<0VWA509UeA@2I
MDD01P2IMDD00`2ELD40U710099^?P02095]?@0309=_?`2ELD40UW9200P0UW4m00@0UW9209Ea@@2E
LD40U7100P2CKcl2099^?P0809IaA@2EL4@0UG1309Ea@@2DL3h0U70l09=_>`2CL3X209E`?080U6lk
0P2CKSX2099]>@P0TV`m00P0Ug5209I`@@2EKd00U6ho09=]?P2BK3d0TF/l091Z>`<0SfTj:oooool0
02[ooooo202HKS`209E[>@0309I/>P2GKC/0V6hl0080VW0n00<0Vg4o09Q^?02HKS`03P2HKS`209M]
>`0409Q^?02IKcd0VFlm09Y`?P80Vg4o202HKD0309]`@`<0VVm20P2IKT4@09ec@@T0WGA000H0VG0l
09Ya?@2KLSh0W7<o09ed@02OMT820:1g@`P0WWDo00<0X7I409me@`2NM4800P2LLT002`2MLd40WWA2
09me@`2QMdD0XWQ60:=iA`2TNTP0XgU70:9hAP2PMT@0WgE30080XWM200<0XWM40:9fA@2RMTL00P2R
MTT0102RMD/0WG=109id@P2OMD<20:1fA00409id@P2MLd40W7900:9hAP<0XgU70P2TNTP20:EkB@06
0:ElB02TNdL0Y7]70:9iA@2QN4@0X7M30P2OMT8@0:IkB080YGa80P2VODT01@2WOTX0Z7m;0:QoB`2Y
P4`0XgY60080Y7]700P0YGa80:ImB@2WOTX0Ygi:0:QoB`2TNdL0YWe90:QoB`80ZH1<00<0Z7m;0:Im
B@2TNdL00`2TNdL00`2UO4P0YWe90:MnBP020:MnBPP0Ygi60`2YP4`20:QoB`<0Ygi:0P2TP4H0102T
OdP0YH1;0:F0B`2VPDd20:J0C`060:QmDP2XOE00ZGiA0:UoC`2YOdd0ZX5=0P2ZPD/90:UoC`P0YX5=
202VPD`00`2YOdd0ZX1>0:^1C`020:b2D0030:^1C`2ZP4h0ZGm=00P0Zh9>202/Pd/80:V5B`030:N2
C@2XPdh0ZXE@0080[8MB00<0ZhIA0:Z5D02YQ4l00`2YQ4l20:Z5D0<0ZhIA202[QU820:f8E080[8MC
00@0ZhIB0:Z5D@2ZQE40ZHA@0P2ZQE430:^6DP<0[8MC202]R5@80:f4D080[HMF0P2/QUD0102[QE@0
ZXAC0:Z4D`2YPe820:Z5CP030:Z5D02ZQE40ZXAC0080ZXAE00H0ZXAG0:^6DP2[QU80ZhIB0:Z5D@2Y
Q5030:R3C`80[8=?0P2[PTh30:Z1C@030:V0C02RODP0XWe80080Xgi900X0Y7m:0:F0B`2UP4/0YX5<
0:9lC`2SODh0Y7i?0:EoCP2UP4`0Xgi90P2QO4D00`2ONT<0Xgi:0:=nBP060:=nBPP0X7]70`2QO4L2
0:1kAP<0WgY500<0VWE009]f@@2KMT400`2KMT4209ag@P80WGQ40P2LMd<01`2KMT80VWE109Ud@02I
M400V7<o09Ye@@2LMd<00P2NNDD00`2LMd<0VWE109Qc?`0209Qc?`<0Ug8n0`2FLCd0102GLSh0V7<o
09Qc?`2HLcl209Ud@080VWE1202FLCd809A_>`0A09eb?@2KLS`0VG0l09I^>`2DKSd0UG5109Ec@`2F
M4H0UW8n09Ea?@2DL3`0TVhj091/>02?JcL0SVXf08eY=@2@JS/00P2AJc`00`2BK3d0Tfdn09=]?P02
09A^?`P0Sf/k00@0TV`m095[?02AJc`0T6Xk0P2?JCX208iX>@0608]W=`2<J3P0S6Ph08eY>@2>JSX0
Sf/k0P2@K3`00`2=JCT0SVXj091/?002095]?@07091/?02>JSX0SFTi08YT=@2<ISL0SVPi091Z>`02
095[?00508mY>P2>J3T0SVXj08m[>`2@K3`00P2AKCd0102?Jc/0SFTi08]W=`2;IcL@08iZ>P80Sf/g
0`2=JCD02`2?JcL0TFdi099^>P2>JSH0T6`h09=_>`2ELCd0UW8n09A`?02BKSX0TFdi0080TVhn0P2A
KCd0102@K3`0Sf/k08m[>`2>JSX408iZ=P07091/>02BKSX0UG4m09Mc?`2FLSh0UG4m09=_>`02099^
>P0309=_>`2ELCd0UW8n00<0Tflk0P2DL3`309Ea?@0609IaA02FLT80UW9209Ib@02FLSh0UW<m0P2F
Lc/209Yb?`0409Ud@02HM400VGE109Mf@@80UWM10P2GLd<01P2HM4@0VGE509]gA`2LN4P0WGU909ij
BP80W7U300@0WGY409ikA@2PODL0XGi80P2ROdT209mkA`80X7a80`2QODT40:9nBP80Xgm;2`2TP4`8
0:N3C`<0Yh=C0`2XQ5@20:V5E@<0Z8AD0P2YQED30:Z6EP080:Z7C`2[R500ZhQB0:^7D`2/R5H0[8QH
0:f9F@2]R5/90:f:DP030:n:EP2`ReL0/HaH0080/XeI00<0/HaH0;2;E`2_RUH00`2/R5P20:f9F@<0
[XYJ00<0[XYF0;2<F02bSUX00P2dT5`02@2cSe/0/XiJ0;6=F@2aSEd0/XiN0;>?G`2dT600]I5Q0;JB
HP0:0;NCH`80]91P00<0]I5Q0;JBHP2gTf<00P2iUFD0102jUVH0^YIR0;ZFHP2jUV830;VEH@80^9AP
202iUFD80;ZFIP80]Y9R00@0]i=S0;RDI02hU6@0^IEU1@2jUVH50;VEI@060;NDGP2gTel0]i=O0;RD
HP2hU6@0^IAW0P2iU6P20;FBFP040;JCF`2gU5`0^IIN0;ZGG`80^iQP0P2fTe/01P2gU5h0^9AP0;RD
HP2iUFD0^YIV0;ZEJ0<0^YIV0`2iUFD20;RDI080^IEU102hU6@50;NCH`80^9AT0`2iUFD80;NCH`07
0;ZGH@2jUV80^YIR0;VEH@2hU680^9AT0;NBI@020;JAI@P0^9AT0P2dT600102fTV80]i=S0;VEI@2j
UVH20;bHJ080^9AT0`2gTf<60;JBHP<0]i=S0P2hU6@80;VEI@P0^9AT0`2iUFD20;RDI0<0]i=S2@2f
TV802P2gTf<0^IEU0;ZFIP2jUVH0^IEU0;NCH`2fTV80^IEU0;RDI02fTV820;FAH@060;JBHP2hU6@0
^IEU0;RDI02fTV80]I5Q0P2cSel0102eTF40]Y9R0;RDI02iUF420;RDH0030;NCG`2fTUh0]Y9N0080
]I5M00H0^iQR0;^GH`2jUV80^IES0;NCH`2fTF@20;F@I0P0]91P402fTV880;B@H00:0;>>H@2bSF00
/HaO0;6<G`2bSF00/hiQ0;F@H`2gTVD0/hmK0;:>FP80/HeI0P2_ReL02`2aSET0/XiJ0;>?F`2hTel0
]i9N0;F@G02dSe/0/hiJ0;B?F`2eT5`0]Y5M0080]Y9R0P2eTF40102dT600/hmO0;>?G`2bSUh30;:=
H0<0/HaO0P2`Reh0102bSUh0/hmO0;>?G`2dT6020;FAH@80]Y9R202dT6030;:>FP80/hmK0`2dT5`0
0`2cSV40]8mR0;B?HP020;B?HP<0]I1S202cSel20;B@H0030;>?G`2bSUh0/HeM0080/8aL00@0[h]K
0:n;E`2_ReL0[h]G0P2^RUH30:f9E@030;B@H02cSel0/HeM0080/8aL00H0/HeM0;:>GP2cSel0/hmO
0;:>GP2aSEd20;2<G0030;6=G@2cSel0]91P00P0/hmO0P2fSUX30;F=F@<0]8aH102bSEH40;6<E@80
[XiM00H0[XaL0;2<G02_Re/0[hUJ0;68FP2`QeT20;6=G@<0/8aL00@0/XiN0;B@H02fTV80/XeP0P2b
SUh00`2bSU`0/XiJ0;:?F@020;:?E`030:n;F`2`S5`0/8aL0080/8aL0P2aSEd20;:>GP080:b8F02]
RET0/8aL0;6=G@2bSUh0/HeM0:n;F`2^RUX30;2<F0D0[h]G00@0[HQL0:j9G@2^REd0[hYN0P2`Rel2
0;6<H0P0[hYM00@0[HUI0:j:FP2^RUX0[h]K0P2`S5`20;6=G@0:0:n:GP2`Rel0/HaP0;6<H02`Rel0
[XUM0:b7F`2ZQET0/8]D0;6<E@<0/XeF00<0/8]D0:j9DP2]R5400`2^RED20:n:EP<0/8]G202]RED0
102[QU80[HQD0:n:EP2`ReL20;6<F0050;2;E`2_RUH0[8QD0:b8E02]RED00P2^RUH02@2_ReL0/8aH
0;2<F02dT600/hmO0;:>GP2`S5`0[XYJ0:f9F@020:^7E`0@0:n:H02^REd0[XUL0:f9E`2/RE<0[8UA
0:^8CP2[RD`0ZhI?0:f8D@2^RE@0[hYF0:n9F02]QeP0ZhEF0:V3EP80ZXIF0P2[QeL20:b8F080[HUI
00H0[hYF0:j9E@2]R5@0[8MC0:^6DP2YQ5020:R3C`X0ZhIA00X0[8MB0:f8D`2^RE@0[hYE0;2;EP2a
S5L0/hiG0;6<E@2_RU<0[HQA0`2[QTl20:b7D0@0ZhMG102/R5P50:R3C`<0ZHA@00P0YX5=0:N2CP2Y
Q500ZXEA0:^6DP2ZQE40ZHA@0:R3C`<0[8MC0`2[QU820:Z5D@P0Z89C0P2VPDd00`2WPTh0Z8=?0:V4
D0020:^6DP060:b7D`2[QU80ZhIB0:Z5D@2YQ500Z8=?0P2WPTh00`2VPDd0ZXEA0:Z5D@030:V4D0<0
Z8=?00P0ZhIB0:Z5D@2YQ500Z8=?0:N2CP2VPDd0YH1<0:AoB`80YX9B00@0Yh=C0:R4E02ZQUH0ZhMG
0P2/R5P0202VPDd0YH1<0:AoB`2TOd/0YH1<0:N2CP2YQ500ZXEA0`2WPTh30:J1C@80YH1<00@0ZXE@
0:V4C`2WPTd0YH1;0P2TOdX01@2UP4/0YX5<0:AoB`2SOTX0XWe90080XGa800<0XWe90:=nBP2TOd/0
0P2RO4/0102SOD`0Y7i=0:J0C`2WPE020:R2D@030:N1DP2XPU<0ZH=D0080ZhEF00h0ZH=D0:R2D`2W
PE80Z8=?0:N2CP2VPDd0YH1<0:J1C@2WPTh0ZHA@0:Z5D@2YQED0Z8AD0:F1D@<0Xgm?00L0YH5A0:J2
DP2WPE@0Yh5B0:R2D`2XPU40ZHA@0080ZXE@00<0ZXE>0:^6C`2WPdl01`2WPdl80:B0C0<0Xgi:1@2T
Od/80:9mB@P0XWm70`2QO4P20:9mB@<0Xgi:00P0Wg]70:1lB02ROTX0Xgm;0:9nBP2PO4P0WWY609ei
A@D0WgU:0`2NN4T@0:1kAP030:1lC02NNTX0WGU90080W7Q800H0WGU909ijBP2PO4`0Xgi:0:5lB02O
NTH209ehA00609iiA@2ONTH0X7]709Uh@`2JND@0W7]60P2NODP00`2MO4L0VgY509YiA0020:1lB0@0
Wg]70P2NNTH0202LND40WGY209ikA@2PO4P0X7a:09ijBP2MNDT0W7M:0P2NNTH409eiA@80W7Q40P2N
NDD0102MN4@0W7M309Ye@@2IM40209Qc?`P0VgM700H0V7<o09Ye@@2MN4@0WgY609iiA@2KMT8209Qc
?`0909E`?02DKc/0UG0l09Ia?@2HLcl0VGA009]f@P2LMd<0WGQ400P0V7<o00P0X6m409m^@`2LKD40
V6`o09M/?`2GKT00V6m109Ma@P80Tflo0P2BKSh01`2CKcl0UG5109QdA02IMDD0U71009=_?`2BKSh0
0P2AKCd00`2BKSh0Tflo09A`@00809E`?00909Ea@@2FLT80UW9209Ib@P2ELD40TVhn091/?02>JSX0
UFm00080U6ho00<0Tfdn099/?@2AJc`00P2@JS/8099/?`<0Tfdn:oooool002[ooooo202HKS`209E[
>@0609I/>P2GKC/0V6hl09U_?@2JL3h0Vg4o4`2HKS`209U_?@<0VW0n202HKD0309]`@`<0VVm20P2I
KT4@09ec@@T0WGA00P2KLSh209ac?`0409ed@02NMD40WgI209mf@PP0WWDo00<0X7I409me@`2NM480
0P2LLT002`2MLd40WWA209me@`2QMdD0XWQ60:=iA`2TNTP0XgU70:9hAP2PMT@0WgE30080X7E000T0
XGI30:5eA02QMDH0XGE80:9fB@2RMD/0WG=109id@P2OMD<00P2PMT@00`2OMD<0WG=109ab@0020:5g
A@80XWQ60P2SNDL20:AjB0050:ElB02TNdL0Y7]70:=jAP2QN4@00P2PMd<00`2OMT80YW]80:IkB00>
0:IkB080YGa80P2VODT20:MnBP80Z7m;102UO4P40:ImB@030:ElB02VODT0Ygi:0080Z7m;00<0Ygi:
0:ImB@2UO4P00P2TNdL20:ElB080YWe90P2WOTX80:MnAP<0ZH1<0P2XOd/30:MnBP80Y81600@0Y7m8
0:F0B`2UP4/0YX5=0P2VP4l01P2XOE80Z7e@0:UnD@2YOdl0ZGm=0:Z1C@80ZX5;2@2YOdl80:J1C@P0
YX5<00<0ZGm=0:Z0CP2[PDl00P2/PU000`2[PDl0ZX1>0:UoC@080:^2CPP0[8=;202YQD/00`2WPTd0
Z8=>0:Z5D0020:b7DP030:^6D@2ZQE00ZHA?00<0ZHA?0P2ZQE030:^6D@P0ZhIB0P2]R5@20:b7D`03
0:^6DP2ZQE40ZXEA00<0ZXEA0`2[QU830:b7D`P0[HQD0P2^QE440:f4D080[8=?0P2]QeH20:b6E@04
0:^5E02ZQ5<0ZXAC0:Z4D`80ZXE>00<0ZXE@0:Z5D@2ZQ5<00P2ZQ5D01@2ZQ5L0[8MC0:b7D`2/Qe<0
ZhIB0080ZXEA0P2YQ5020:b3C`80Zh9>102ZPDd30:=nB@030:AoBP2UP4/0YH1;0080YX5<00H0XWa?
0:=mCP2TOTl0YGm>0:F0C02SOTT20:5lA@030:1kA02SOTX0Xgi:00H0Xgi:202PNdL0102RODP0XGa7
0:5lA`2QO4L20:1kAP80WgY50`2KMT4509ag@P@0W7M30`2KMT8209Ye@@0309]f@P2LMd<0W7M30080
W7M300<0VgI209Ye@@2IM4000P2IM40209Qc?`<0Ug8n102HLcl209Ud@080VWE1202FLCd809A_>`0>
09aa?02JLC/0V6lk09I^>`2DKSd0U71009Ab@P2ELdD0UW8n09Ea?@2DL3`0Tflk095]>@2@K3P208iZ
=P80TF/l0P2BK3d0102CKCh0U6ho09A^?`2DKSl808m[>`80TV`m0P2AJc`0102@JS/0SfTj08mY>P2?
JCX208eY>@<0SVXj0`2?Jc/00`2=JCT0SVXj091/?002095]?@06091/?02>JSX0SFTi08aV=`2=IcP0
SfTj0`2AJc`0102@JS/0SfTj08iZ>P2?Jc/3095]?@0408m[>`2=JCT0S6Ph08aX>100SVXj00/0T6`h
08m[=`2>JSH0SFTe08iZ=P2?JcL0TFdi099^>P2@K3P0TFdi09=_>`0309A`?080Tflk00<0Tflo099^
?P2BKSh00P2AKCd01@2@K3`0Sf/k08m[>`2BKSX0TFdi0080T6`h00L0TFdi09=_>`2ELCd0Ug<o09Ib
?P2ELCd0U70l0080TVhj00<0U70l09Ea?@2FLSh00P2CKc/209A`?0<0UG4m00L0UW8n09MbA@2GLd<0
Ug=309Mc@@2GLcl0Ug@n0080Ug@l00H0Vg=009ad@@2JMD40VGE109Yf@P2HMd8209Qi@`0509QdA02I
MDD0VGE509YfAP2KMdL00P2LN4P01`2MNDT0WGY409ejA02NNdD0Wga60:1mA`2QOTP00P2ROdT30:1l
B080XGe91P2ROTX20:=oB`/0Y81<202WPdl30:N3D`80Z8AD0`2YQED20:R4E080ZHEE0`2ZQUH01P2[
QeL0ZhQ@0:^8D02[R580[8QD0:b8EP80[HUI00<0[HQK0:f:DP2]RU801`2]RU800`2_RUH0/8]G0;6<
F0020;:=F@030;6<F02`ReL0[hYF0080[8QH0P2]RET30:j:FP040:n;F`2_ReL0/8aH0;:>FP80]91L
00<0/hmK0;:>FP2aSET00P2bSUh0102cSel0]91P0;FAH@2fTV8:0;NCH`050;B@H02eTF40]I5Q0;JB
HP2hU6@00P2iUFD0102jUVH0^YIR0;ZFHP2jUV820;VEH@<0^9AP202iUFD80;ZFIP030;JBHP2gTf<0
]i=S0080^9AT0P2iUFD30;ZFIPH0^IEU00H0]iAN0;NCG`2gTel0^9AR0;RDI02iU6L20;VDJ0060;FB
FP2fTe/0]iAL0;REG@2iUUh0^YMO0P2kV6020;NDG0060;NDGP2hU600^IES0;VEI@2jUVH0^YEX0`2j
UVH30;VEI@X0^9AT0P2gTf<30;RDI0<0^IEU202gTf<02@2jUf40^IEQ0;VEH@2iUF40^9AR0;RDI02g
TVD0]i9V0;JAI@080;RDI0040;FAH@2fTV80]i=S0;NCH`80^IEU00@0^YIV0;^GI`2hU6@0^9AT0`2g
Tf<60;JBHP80]i=S0`2hU6@80;VEI@P0^9AT0`2iUFD20;RDI0<0]i=S2@2fTV802P2gTf<0^IEU0;ZF
IP2jUVH0^IEU0;NCH`2fTV80^IEU0;RDI02fTV820;FAH@060;JBHP2hU6@0^IEU0;NCH`2fTV80]I5Q
0P2dT6000`2eTF40]Y9R0;NCH`020;RDH080]i=O0P2fTUh20;FAG@060;ZGH@2jUV80^IEQ0;RDHP2g
Tf<0]i9U0P2fTFD80;B@H0P0]Y9R202eTF480;B@H00:0;>>H@2bSF00/HaO0;6<G`2bSF00/hiQ0;F@
H`2fTF@0]91L0;>?F`80/XiJ0P2aSET01P2bSUX0/hmK0;B@G02hTel0]i9N0;F@G080/hiJ00<0]8mK
0;F@G02fTEd00P2fTV820;FAH@050;B@H02cSel0/hmO0;>?G`2dSf800`2cSV420;:=H080/HaO0`2c
Sel00`2dT600]I5Q0;FAH@020;JBHPP0]91P202cSe/0102bSF00/hiQ0;>>H@2dSf820;F@H`80]Y5T
202cSel20;B@H0030;>?G`2bSUh0/HeM0080/8aL00@0[h]K0:n;E`2_ReL0[h]G0`2^RUH20:f9E@03
0;B@H02cSel0/HeM0080/8aL00H0/HeM0;:>GP2cSel0/hmO0;:>GP2aSEd20;2<G0030;6=G@2cSel0
]91P00P0/hmO0P2fSU/30;F=FP<0]8aI102bSEH40;6<E@80[XiM00@0[XaL0;2<G02_Re/0/8YK0P2a
R5X00`2cSel0/XiN0;2<G0020;2<G0040;:>GP2cSel0]I5Q0;:=H080/XiN00<0/XiL0;:>FP2bSeT0
0P2bSeL50;2<G080/HeM0P2bSUh0202/R5P0[XYJ0;2<G02aSEd0/XiN0;6=G@2`S5`0[h]K0`2`S5P4
0:n;E`050:j:EP2^REd0[XUM0:j9G@2_RUh00P2`Rel20;6<H0P0[hYM0P2^RUX20:n;F`80/8aL0P2a
SEd02P2`Rel0/HaP0;:=H@2bSF40/HaP0:n:GP2]R5`0[8MK0;2;E02aS5D30;:=EP030;2;E02^RE80
[HQA00<0[XUE0P2_RUH30;2;E`P0[HUE00@0[8MC0:f8E02_RUH0/8]G0P2aS5P00`2`ReL0[hYF0:b8
E0020:f9E@80[XYF0P2_ReL02@2`S5P0/XiN0;:>GP2aSEd0[h]K0:j:FP2]RET0[8QH0:^7E`020:j9
G@040:j9G02]REL0[8QD0:b9D@80ZhQ>00P0[8M@0:f8D@2^RE@0[hYF0:j8E`2]QeP0ZhEF0:V3EP80
ZXIF0P2[QeL20:b8F080[HUI0P2]R5@20:b7D`040:^6DP2ZQE40ZHA@0:V4D0X0ZhIA00@0[8MB0:f8
D`2^RE@0[hYE0P2`ReH0102bSEH0/HaE0:j9DP2/Qe030:^6C`80[8M@1@2[QeL30:b8F0@0ZHA@102Z
QE400`2VPDd0Yh9>0:V4D0020:^6DP030:Z5D@2YQ500Z8=?00<0[8MC0P2[QU830:Z5D@P0Z89C0P2V
PDd01P2WPTh0Z8=?0:V4D02ZQE40ZhIB0:b7D`80ZXEA0`2YQ5030:R3C`80ZXEA0`2YQ5030:R3C`80
ZXEA00@0ZHA@0:R3C`2WPTh0YX5=0P2UP4`01@2VPU80Yh=C0:N3D`2XQ5@0ZXIF0080ZhMG00T0[8QH
0:N2CP2VPDd0YH1<0:AoB`2UP4`0YX5=0:R3C`2YQ5000`2WPTh30:J1C@80YH1<00@0ZHA?0:R3CP2V
PD`0YH1;0P2TOdX01@2UP4/0YX5<0:F0C02SOTX0XWe90080XGa800@0XWe90:=nBP2UP4`0XWa;0P2S
OD`0202TOTd0YX1?0:N1D02WPE00Z89A0:N1DP2XPU<0ZH=D0P2ZQ5D0602YPe@0Z89C0:N1DP2YQ500
Z8=?0:N2CP2VPDd0YH1<0:J1C@2XPdl0ZHA@0:V5E@2WPe<0YH5A0:B0D02SOdl0Y81@0:F1D@2VPU80
Yh5D0:N1DP2XPU<0Z89A0:V4D080ZHA?0P2ZQDh80:N3C`P0Y81<0P2SOTX60:AoB`P0XWe9202ROdL3
0:9mB@<0Xgi:0P2TOd/20:1lB0<0XWi:00<0X7a809ijAP2MNDD0202ONDX@0:1kAP030:1lC02NNTX0
WGU90080W7Q800H0WGU909ijBP2PO4`0XWe90:5lB02ONTH309ehA00509iiA@2ONTH0VGQ309]jA@2L
NdH00P2NODP00`2MO4L0VgY509YiA00609mkA`80WWY600P0W7U109ej@P2NNdD0Wg]709mkB@2NNTX0
WGU909agBPP0W7Q400D0WWU509ehA02MN4@0W7M309Ye@@0209Ud@00309Qc?`2KMdL0VgM700H0VgM7
00<0VGA009]f@P2NNDD00P2ONTH0102LMd<0VGA009Ud@02GLSh209Ia?@0409Mb?P2HLcl0VGA009Ye
@@80VgI2202IM4004`2PKd@0WVm309a]@@2HK3l0Uf`o09M^@02FL440Ug5209Ib@P2ELD40U71009=_
?`2DL400UG5109Mc@`2HM4@0UG5109=_?`2BKSh00P2AKCd00`2BKSh0Tflo09Ea@@0809E`?00809A`
@02ELD40UW9209Ib@P2ELD40Tflo095]?@2@K3`309=]?P<0TV`m0P2AJc`8099/?`<0Tfdn:oooool0
02[ooooo202HKS`01P2EJcT0UV`j09I/>P2GKC/0V6hl09U_?@80VW0n402HKS`309Y`?P80VFlm0`2H
KS`809Q]@0<0Vg130`2JKd8209U^@A00W7902P2LLcl709ed@0P0WWE100<0X7I409me@`2MLd400P2L
LT000`2MLd40WgE30:1fA0020:5gA@<0XgU700P0XGM509me@`2NM480WG8m09ic?P2NLd00Wg=20:1d
A@80XGE800@0XWE;09ec@@2NM480WgE30P2PMT@00`2OMD<0WWA209ec@@030:1fA080XGM50`2RN4H0
1P2UO4P0Y7]70:AkA`2SNTH0XWU50:5hA080X7M3402VNdP20:ElB0<0YWe90`2WOTX40:ImB@D0YGa8
00<0YWe90:MnBP2WOTX00P2WOTX00`2VODT0YGa80:AkA`030:ElB0<0YWe900<0Ygi:0:MnB02WOTP0
1P2WOTP30:V0C080Z7m;0`2WOTX20:B0AP040:AoB02UP4/0YH1;0:J1C@80YX1?00H0Z7eB0:QmD02Y
OU40ZGm?0:UoC@2ZPDd20:Z1B`T0ZGm=202VPDd80:J1C0030:UoC@2ZP4h0Zh5?0080[89@00<0Zh5?
0:Z0CP2YOdd0202[PTh80:b3C@P0ZHA=00<0Yh9=0:R3CP2ZQE000P2/Qe800`2[QU40ZXE@0:V4C`03
0:V4C`80ZXE@0`2[QU480:^6DP<0[8MC0`2[QU840:Z5D@<0ZhIB0`2/Qe<80:f8E080[hIB00@0[XEA
0:f4D02]Q500[8=?0P2[PTh30:b7D`<0ZhIB0P2ZQE420:^6C`030:^6D@2[QU80ZhED0080ZhEF00<0
ZhEH0:j9E@2]R5@00P2]R5@30:b7D`040:^6DP2/Pdl0[8=?0:b3C`80Zh9>0`2ZPDd30:AoBP<0YH1;
0P2VPD`01P2TOU40Y7i?0:EoD02UOdh0YH1<0:=nB@80XWe600<0XGa50:=nBP2SOTX01P2SOTX80:5l
B0<0XWe80P2QO4L30:1kAPP0WGQ30P2KMT8309ag@`@0WGQ400P0W7M309]f@P2JMD40VWE109]f@P2L
Md<0WGQ409ag@`<0VgI20P2JMD4209Ud@0<0V7<o0P2IM40309Ye@@P0Ug8n202EL3`0202JKcX0VG0j
09Q_>`2FKS/0U6hm09A`@02CLD40Tg530P2FLSh01P2ELCd0U70l099^>P2AKCT0T6`h08m[=`80TV`m
0P2CKCh409A^?`P0T6`l00@0Tfdn099/?@2BK3d0TV`m0`2AJc`0102@JS/0T6`l091/?02@K3`308m[
>`80SVXj0P2?Jc/0102@K3`0TFdm095]?@2@K3`208m[>`0508iX>@2?JCX0T6Xk095[?02BK3d00P2A
Jc`00`2@JS/0T6`l091/?003095]?@04091/?02>JSX0SFTi08eY>A00Sf/k00X0TFdi091/>02?JcL0
SVXf08m[=`2@K3P0TVhj09=_>`2DL3`0Tflk0P2BKSX0102CKc/0U70l09Ea?@2FLSh309=_?`<0TVhn
0P2AKCd00`2GLcl0UW8n09A`?00209=_>`0609A`?02FLSh0Ug<o09Mc?`2FLSh0UG4m0P2DL3`00`2E
LCd0UW8n09Mc?`0209A`?080UG4m0`2FLSh01`2GLcl0V7=609QdA02HM4@0V7A209Qd@02HMCl00P2H
MCd209if@`0409ag@`2LN4@0W7Q409]jA@80VW]50P2KMdL609ahB080WW]500@0Wga60:1mA`2QOTP0
XGi80P2ROdT30:5mB@80XWi:1P2SOd/20:B0C0/0YH5=202WPdl20:N3D`80Z8AD0`2YQED0102ZQUH0
ZHEE0:V5E@2YQED20:Z6EP<0ZhMG00P0ZhQ@0:b9D@2/RE<0[8QD0:f9E`2]RET0[XYJ0:j9G0T0[X]E
00<0/8]G0;6<F02bSET00P2cSUX00`2bSET0/HaH0;2;E`020:f9F@80[XYJ0`2_Re/01@2`S5`0/8aH
0;6=F@2bSUX0/hmK0080]91L00@0/hmK0;:>FP2cSel0/hmO0P2dT6000`2eTF40]Y9R0;NCH`090;NC
H`80]I5Q00<0]Y9R0;NCH`2hU6@00P2iUFD00`2jUVH0^YIR0;ZFHP020;VEH@<0^9AP00<0]i=O0;VE
I@2iUFD01P2iUFD80;ZFIP<0]i=S0P2hU6@;0;VEI@060;NDGP2gTel0]i=O0;RDHP2hU6@0^IAW0P2i
U6P01P2fTed0]iAN0;NDGP2hUEl0^IIP0;ZGH@80^iQR00D0]iAL0;REG@2hUEl0^9AP0;VEH`020;VE
I@040;ZEJ02jUVH0^YIV0;ZFIP<0^IEU2P2hU6@0102gTf<0^9AT0;RDI02hU6@20;VEI@80^YIV202g
Tf<01`2iUV00^IEQ0;VEH@2iUF40^9AR0;RDI02gTVD00P2gTVHB0;RDI0<0]i=S1@2fTV820;NCH`<0
^9AT2@2iUFD80;RDI0<0^IEU0P2hU6@30;NCH`T0]Y9R00X0]i=S0;VEI@2jUVH0^YIV0;VEI@2gTf<0
]Y9R0;RDI02gTf<0]Y9R0P2eTF401P2fTV80]i=S0;RDI02gTf<0]Y9R0;FAH@80]91P00<0]I5Q0;JB
HP2gTf<00`2gTel30;JBGP80]I5M00H0^9EO0;RDH02hU600]i=Q0;NCH`2gTVD20;NBIPP0]91P202f
TV8@0;B@H0030;B?HP2cSV40/XeP0080/HaO00D0/hiQ0;F@H`2fTF@0]Y9N0;FAG@020;B@G080/hmK
00H0]91L0;FAG@2fTUh0^9=O0;JAG@2eT5`30;>>FP030;B?F`2eT5`0]I5Q0080]I5Q0`2dT6020;>?
G`040;JAI02eT6<0]I1S0;F@H`80]8mR0P2cSV420;>?G`<0]91P0`2eTF480;B@H0050;FAG@2dT5`0
]91L0;>?F`2bSUX00P2aSET02@2`S5P0/HaO0;6<G`2bSF00]8mR0;F@H`2fTF@0]i9U0;RCIP080;>?
G`80]91P00<0/hmO0;:>GP2aSEd00P2`S5`00`2_Re/0/8aH0;2<F0020:n;E`<0[XYF00@0[HUE0;>?
G`2bSUh0/8aL0P2_Re/01P2aSEd0/XiN0;>?G`2dT600/hmO0;6=G@80/8aL00<0/HeM0;:>GP2cSel0
202bSUh20;B?F`<0/hiJ0`2bSET40;6<E`@0/XeH0P2^SUd0102^S5`0/8aL0;2<G02`RU/20;:9F`03
0;FAH@2cSel0/XiN00<0/8aL00<0/XiN0;>?G`2bSF000P2bSUh00`2bSU`0/XiJ0;:?F@020;:?E`<0
/8aL0`2aSEd30;:>GP030:f9F@2^RUX0/8aL00<0/HeM0P2`S5`01@2aSET0/8aH0;2<F02`S5P0[h]G
00<0[XYF0P2^RE`30:n:G@/0/8]N0`2_Re/30;2<G080/HeM00X0/XeP0;>>H@2cSV40]8mR0;>>H@2a
S5l0[XUL0:f8F`2`ReH0/HaG0`2bSEP00`2`ReH0[XUD0:f8D`030:j9E@80[hYF0`2`ReL80:f9E@03
0:b7D`2]R5@0[hYF0080/HaH00<0/8]G0:n:EP2^RED00`2]RED20:j:EP<0[h]G00<0/8aL0:n;F`2_
Re/00P2^RUX30:f9F@80[XUL00@0[HUI0:f9E`2]RED0[8UC0P2/RE40202/Qe00[HQA0:j9E02^RED0
[XQG0:b6E`2[QEH0ZXAG0P2ZQUH20:^7E`80[8QH0P2]RET00`2/Qe<0ZhIB0:^6DP050:^6DPX0ZhIA
00@0[8MB0:f8D`2^RE@0[XUD0P2_RUD0102aS5L0/8]F0:j9E02/Qe830:^6D@030:b7DP2]R5<0ZhMG
00L0ZhMG202[QU800`2VPDd0Z8=?0:V4D0030:^6DP040:Z5D@2YQ500[8MC0:b7D`80ZhIB0`2ZQE40
0`2YQ500Z89C0:R2D`060:R2D`060:J1C@2WPTh0Yh9>0:R3C`2YQ500ZXEA0P2[QU830:R3C`<0ZHA@
102ZQE430:V4D0<0Z8=?00D0ZXEA0:V4D02YQ500Z8=?0:N2CP020:J1C@040:F0C02WPe<0Yh=C0:R4
E080ZHEE00H0ZXIF0:^7E`2[QeL0ZXEA0:R3C`2WPTh20:F0C0030:J1C@2WPTh0Z8=?00<0Yh9>0`2V
PDd20:F0C0030:V4C`2WPTd0YX5<00<0Y7m:0P2VPD`00`2UP4`0Y7m;0:9mB@020:5lB0030:9mB@2T
Od/0YH1<0080Xgi:00@0Y7m;0:F0C02UP4`0YX5=0P2WPTh00`2VP540Yh5B0:V3E0020:Z4E@070:V3
E02WPE80YX1A0:^6DP2ZQE40Yh9>0:J1C@020:F0C0050:J1C@2WPTh0Z8AD0:N3D`2UPE400`2TP502
0:F1D@050:N1E02WPE80Z89C0:R2D@2XPdl00P2YQ4l20:V4C@P0Yh=?202UPDd80:AoB`P0XWe9202R
OdT30:=nBP80Y7m;0`2UP4`0202PO4P0XGe90:5mB@2ROTX0XGe90:1lB02ONdL0WWY6202ONDX80:1k
APP0WgY500<0X7a<09ijBP2MNDT00P2LN4P0202MNDT0WWY:0:1lC02PNdL0WgY609iiA@2MN4@0W7M3
0P2MN4@0102NNDD0WGU509eiA@2NNTH209mkA`0309ijAP2MNDD0W7Q400D0WWY60`2ONdL0202KN400
W7U109ikA@2ONdL0Wg]909ijBP2LN4P0VgI9102JMT8409]g@`80WGQ400@0W7M309]f@P2KMT80VWE1
0P2IM40809]gA`0309]f@P2MN4@0WgY60080X7]700@0WWU509]f@P2KMT80VGA0102HLcl409Ud@0P0
VgI201<0Wg1409i_@`2JKT40Uf`o09I]?`2EKd00UW1109Ib@P2IMDD0V7A409Ib@P2ELD40U71009Ea
@@2FLT80Ug=309Ea@@2DL400TVhn0080TFdm00<0TVhn09A`@02ELD40202EL3`00`2BKSh0Tflo09A`
@00209Ea@@0309A`@02BKSh0TFdm0080TF/l0`2BK3d309=]?PP0TV`o0`2CKCh[ooooo`00:_ooool8
09Q^?080UV`j0P2GKC/0102HKS`0VFlm09U_?@2IKcd@09Q^?080Vg4o00@0VW0n09U_?@2IKcd0V6hl
0P2GKC/809U^@@<0Vg130`2JKd8209U^@A00W7902@2LLcl209ie@@<0WGA00`2LLcl809id@P0309me
@`2NM480WG=10080W79000/0WWA209me@`2QMdD0X7I40:5gA@2RN4H0XgU70:9hAP2QMdD0WgE309id
@P0209aa?00909eb?`2NLT40Wg=40:1dA`2QMDP0XGA:09ab@02NM480WgE30080XGM500<0X7I409me
@`2NM4800`2OMD<20:1fA0<0XGM50`2TNdL00`2SNTH0XWU50:9iA@020:5hA100YW]80P2UO4P60:Im
B@050:QoB`2WOTX0Ygi:0:ImB@2UO4P00P2TNdL00`2SNTH0YGa80:ImB@050:ImB@D0YGa8102VODT8
0:MnBP<0ZH1<0P2XOd/30:MnBP80Y81600@0Y7m80:F0B`2UP4/0YX5=0P2VP4l01P2XOE80Z7e@0:Un
D@2YOdl0ZGm=0:Z1C@80ZX5;2@2YP4`80:J1C@P0YX5<00<0ZGm=0:Z0CP2[PDl00P2/PU000`2[PDl0
ZX1>0:UoC@0@0:b3C`P0ZHA?00<0Yh9=0:R3CP2ZQE000P2/Qe800`2[QU40ZXE@0:V4C`030:V4C`80
ZXE@0`2[QU480:^6DP80[8MC1P2[QU820:Z5D@<0ZhIB0`2/Qe<80:f8E0040;27D`2_QU80[XEA0:j5
D@80[8=?00@0Zh9>0:Z1C@2/Qe80[8MB1P2[QU420:^6C`030:^6D@2[QU80ZhED0080ZhEF00<0ZhEH
0:j9E@2^RED01P2^RED20:f4D080[8=?0P2[PTh20:Z1C@80YH1;1P2VPD`01P2UOe80YGm@0:EoD02U
Odh0YH1<0:AoBP<0Xgi7202TOd/80:9mB@<0Xgi90P2RODP30:5lA`80WgY5102NND@209eh@`80VgI2
00@0W7M309ehA02MN4@0WWU50`2ONTH0202MN4@0VgI209Ud@02IM400VgI209ehA02ONTH0WWU50`2M
N4@209ag@`80VgI20P2HLcl209Ud@080VWE10P2KMT8809Qc?`P0Ug8n00P0VFhi09Q_>@2HKc/0Ufll
09E_?P2DL400TW10099`@P80Ug<o00H0UW8n09Ea?@2DL3`0Tflk099^>P2AKCT509A^?`<0UFm0202B
KSh609=]?P80TV`m00D0Tflo099^?P2BKSh0TFdm091/?00208m[>`0308iZ>P2@K3`0TFdm00D0TFdm
00@0T6`l095[?02AJc`0TF/l102BK3d0102AJc`0TVhn099^?P2BKSh2095]?@80T6`l0P2?Jc/@095]
?@03099^>P2AKCT0T6`h0080T6`h00/0TVhj09A`?02ELCd0UW8n09Ea?@2CKc/0TFdi099^>P2DL3`0
Ug<o09Ue@@0809A`@00509]g@`2JMT80V7A009Ib?P2ELCd00P2FLSh409Mc?`80UW8n0`2GLcl309Ib
?P<0Ug<o0P2HM4001P2IM4L0VGE509UeA@2IMD<0VGE109Uf@080VGHn0P2PN4D0102NNDD0WWY609ij
AP2MO4L209amA`<0WWY:0P2MNDT309ahB00309mlAP2PODL0X7e70080XGi80P2ROdT00`2SP4X0XWi:
0:9nBP020:=oB`L0Y81<0`2UPDd:0:J2CPP0Z8A@0`2XQ5@30:V5E@D0ZXIF0P2[QeL30:b8F0080:b9
D@2]RU80[HYD0:f9E@2^RUP0[XYJ0:n;F`2_RUd90;2<F0030;2;E`2bSET0/hiJ0080]8mK00<0/hiJ
0;:=F@2`ReL00`2_Re/30;2<G080/HeM00<0/HeI0;:>FP2bSUX00P2cSe/30;B@G0<0]91P00<0]I5Q
0;JBHP2fTV802P2gTf<20;JBHP80]i=S00@0^9AT0;VEI@2iUFD0^IEU0`2iUF430;RDH080]i=O202h
U6@80;ZFIPT0^9AT102iUFD30;ZFIP060;NDGP2gTel0]i=O0;RDHP2hU6@0^IAW0P2iU6P00`2gTel0
^9AP0;RDH0020;VEH@80^YIR00H0^iMS0;VFGP2iUUh0^IIP0;VEH@2iUF<20;VEI@040;VDI`2jUVH0
^YIV0;ZFIP<0^IEU0P2hU6@20;NCH`@0^9AT0P2iUFD30;RDI080^IEU0`2jUVH80;RDI0070;REG`2h
U600^9AP0;RDH02hU680^9AT0;RCIP020;RCI`P0^9AT0P2jUVH0102iUFD0^9AT0;RDI02gTf<20;JB
HP80^9AT0`2gTf<30;JBHP<0]i=S0`2hU6@:0;VEI@P0^9AT0`2iUFD20;RDI0/0]i=S00<0]Y9R0;NC
H`2iUFD00P2jUVH00`2iUFD0]i=S0;JBHP030;NCH`80]Y9R0`2gTf<20;JBHP@0]I5Q0P2fTV860;JB
GP80]I5M00H0]Y=M0;JBGP2fTUh0]i=Q0;NCH`2hTfH20;RCI`P0]91P202fTV880;:>GPP0]91P00<0
]8mR0;>>H@2bSF000P2aS5l01@2bSF00]8mR0;F@H`2hU600]i=O0080]I5M0P2dT5`02`2eTEd0]i=O
0;RDH02gTUh0]Y5M0;B?F`2cSUX0/XeI0;>>FP2dSe/0]I1L0080]I5Q1P2dT6030;NBI@80]Y5T0`2e
T6<60;B@H080]I5Q202cSel20;FAG@040;B@G02cSe/0/HeI0;2<F080[h]G00H0/8]N0;6<G`2bSF00
/hiQ0;F@H`2fTF@20;RCIPP0/hmO0P2dT6000`2cSel0/XiN0;6=G@020;2<G0040:n;F`2`S5P0/8aH
0;2<F080[h]G0`2^RUH00`2bSUh0/HeM0;2<G0020:n;F`060;2<G02bSUh0/hmO0;B@H02cSel0/HeM
0P2`S5`00`2aSEd0/XiN0;>?G`080;:>GP80/hmM0`2bSU`30;6=F`@0/HaH102bSET20:j>G@040:j<
G02`S5`0/8aL0;6;G080/hYL00<0]Y9R0;B@H02bSUh00`2`S5`20;6=G@060;:=H02bSUh0/XiN0;:>
G02bSUX0/XmI0P2bSeL20;2<G0<0/HeM0P2bSUh20;>?G`80[h]K0P2`S5`40;6=G@80/HeI0P2`S5P0
102_ReL0[XYF0:j:EP2]RED60:n;F`80/8aL202`Reh60;2<G080/HeM00X0/hmO0;B@H02dT600]I5Q
0;B@H02bSUh0[h]K0:j:FP2`ReL0/HaH0`2bSET00`2`ReL0[XUE0:f8E0030:j9E@80[hYF0`2`ReL8
0:j:EP030:f8E02^RED0/8]G0080/HaH00<0/8]G0:n:EP2^RED0202^RUH80:f9F@@0[HUG0P2]RED0
2P2/R5@0[8UC0:f8D@2]R540[HQC0:f8E02]QeH0[8IG0:^5EP2[QEP20:Z6EP80ZhMG0P2/R5P20:f9
F@80ZXEA0`2[QU830:b7D`X0ZhIA0P2/Qe801`2]R5<0[XUD0:j9E02^RE@0/8]G0:n:EP2]R5@0102[
QU800`2/Qe<0[HQD0:^7E`030:^7E`@0ZXIF0P2^RED30:f8E0<0[8MC00P0Yh9>0:R3C`2ZQE40ZhIB
0:b7D`2[QU80ZXEA0:V4D0<0ZhIB0`2ZQE420:V4D0P0Z89C0P2WPTh20:R3C`050:V4D02ZQE40ZXEA
0:Z5D@2VPDd00P2WPTh00`2XPdl0ZHA@0:Z5D@020:^6DP80ZXEA0`2YQ5030:R3C`80ZHA@0P2XPdl2
0:N2CP80YX5=00<0Yh=C0:R4E02XQ5@00P2YQED20:Z6EP050:^7E`2[QU80ZXEA0:R3C`2VPDd00P2U
P4`00`2VPDd0Yh9>0:N2CP020:N2CP<0YX5=0P2UP4`02`2WPTd0YX5<0:F0B`2TOdX0Xgi90:AoBP2V
PD`0Yh9=0:F0C02TOd/0Xgi:0080XWe900@0Xgi:0:AoB`2UP4`0Xgi90P2TOdX20:F0B`80YX5<00@0
Yh9=0:J0D@2WPE80Z89C0P2ZQ5D01`2XPU<0Yh5B0:J0D@2/Qe<0ZXEA0:R3C`2UP4`00`2TOd/00`2U
P4`0YX9B0:J2DP060:F1D@050:N1E02WPE80Z89C0:R2D@2XPdl00P2XPdh20:R3C0P0Yh=?202UPDd0
0`2UP4`0Y7m;0:AoB`020:AoB`<0Xgi:202RODT80:9nBP040:=nBP2TOd/0Y7m;0:AoB`80YH1<0P2V
PDd40:5mB@80X7a80P2ONdL309miBP@0X7Y;00<0XG]<0:1kAP2PNdH01P2PNdH809mjA@030:1lC02N
NTX0WGU90080W7Q800<0WGU909ijBP2PO4`00P2ONTH209iiA@@0WGQ41@2ONTH209iiA@0309ehA02M
NDD0WGU500@0WWY60P2ONdL0202KN400W7U109ejA02ONdL0Wg]909eiB@2LN4P0VgI9102IMD4409Yf
@P0309ehA02LMd<0W7M30080VgI20P2JMD400`2IM400VWI609YfAP0609YfAP0609ehA02NNDD0X7]7
0:5lB02PNdL0WWU50P2LMd<01P2KMT80VWE109Ye@@2JMD40VGA009Qc?`<0Ug8n202LMd<0302MLD@0
W71309U^@@2FKCl0U6ho09A`@02ELD40U79209ahB02JMTH0V7A409Ib@P<0UG5100@0UW9209Ea@@2D
L400Tflo0P2BKSh00`2CKcl0U71009Ea@@0809E`?008091/?02AKCd0Tflo09A`@02ELD40U71009=_
?`2BKSh2091Z>`03095[?02BK3d0Tfdn0080U6ho00<0UFm0099/?`2BK3l01P2BK3l309=]?R_ooooo
000Zooooo`P0V6hl0`2GKC/409Q^?00309U_?@2HKS`0V6hl00h0V6hl0P2KLCl0102JL3h0VFlm09U_
?@2HKS`209M]>`P0VFi10`2KL4<309Y_@P80VFi1402KLCl909]b?P80WWE10`2MM40309ac?`P0WWA4
00X0WWA209ec@@2LLT00W79009ec@@2NM480X7I40:5gA@2PMT@0XGM50`2RN4H00`2PMT@0WWA209ec
@@0209eb?@0309eb?`2NLT40Wg=40080X7A700P0X7=909ab@02MLd40WgE30:5gA@2RN4H0XGM50:1f
A0@0WgE30P2PMT@30:5gA@<0Y7]7102SNTH00`2RNDD0YGY70:EjA`0>0:EjA`80YWe91P2UO4P01@2X
Od/0Ygi:0:MnBP2VODT0YGa80080Y7]700<0XgY60:ImB@2UO4P01@2UO4P50:ImB@@0YGa8202WOTX3
0:V0C080Z7m;0`2WOTX20:B0AP040:AoB02UP4/0YH1;0:J1C@80YX1?00H0Z7eB0:QmD02YOU40ZGm?
0:UoC@2ZPDd20:Z1B`T0ZH1<202VPDd80:J1C0030:UoC@2ZP4h0Zh5?0080[89@00<0Zh5?0:Z0CP2Y
Odd0402/Pdl80:V4C`030:N2C@2XPdh0ZXE@0080[8MB00<0ZhIA0:Z5D02YQ4l00`2YQ4l20:Z5D0<0
ZhIA3P2[QU820:b7D`80ZXEA0`2[QU830:b7D`P0[HQD0P2_QU80102^QE40[HA@0:f4D02/Pdl20:^2
CPH0ZhIA0P2/Qe820:b7D0030:b7DP2/Qe<0[8IE0080[8IG00<0[8II0:j9E@2^RED00P2^RED40:n:
EP<0[HA@0P2/Pdl30:^2CPD0Yh9=0`2VPD`01P2WPE@0Yh5B0:J0D@2UOdh0YH1<0:F0B`<0YH19202T
Od/80:=nBP<0Y7m:0P2SOTT30:9mB080XGa70P2PNdH209mjA@80WWU40P2LMd<0102MN4@0WWU509ii
A@2ONTH20:1kA`0309mjAP2NNDD0VgI20080VWE100<0VgI209iiA@2ONTH0102NNDD209ehA080W7M3
0`2IM40209Ye@@<0VgI2202IM40809Qc?`0909U^>@2IL3X0VG0l09Q`?@2FL3l0UG5109=a@@2BL480
V7A00080Ug<o00<0UW8n09Ea?@2ELCd00P2DL3`209I`@@H0UFm0202CKcl609A^?`80UFm00P2DL400
102CKcl0TVhn099^?P2AKCd2091/?0<0TVhn0P2AKCd3099^?P0509A^?`2CKCh0Tfdn09=]?P2BK3d0
0`2CKCh209=_?`80TVhn1@2AKCd@099^?P0@09A`?02CKc/0TVhj095]>@2BKSX0Tflk09Ea?@2FLSh0
Ug<o09Ib?P2DL3`0TVhj09=_>`2ELCd0V7A009Yf@PP0UW9200D0WGU509ahA02JMT80V7A009Ib?P02
09Mc?`@0V7A00P2IMD4309Qd@080Ug<o0`2HM40309Ue@@0609]fB@2KMdL0VgM709]gA@2KMd<0VgQ2
0P2KN4020:5iAP0409mjAP2ONdL0Wg]709elA`80WGi800@0X7a<09mkB`2ONd/0Wg];0`2NNTX00`2M
NDT0XGi80:5nB0040:9oB@80Xh1:102TP4`20:F1C@80YX9>102UPDd20:J2CPX0Yh=?202XQ5020:R4
E0<0ZHEE0`2ZQUH30:^7E`80[8QH0`2]RET20:f:DP030:j;E@2^RUH0[h]I0080[h]K00<0/8]N0;6=
F`2aSE/01`2aSE/00`2aS5P0/XeI0;B?F`020;F@G0030;B?F`2bSET0/HaH0080/8aL0`2aSEd30;:>
GP<0/XiJ0P2cSe/20;B@G0040;FAG@2eTF40]I5Q0;FAH@@0]Y9R2P2gTf<40;RDI0<0^IEU0P2iUF43
0;RDH0<0]i=O202hU6@80;VEI@/0^9AT00<0^IEU0;ZFIP2jUVH00P2kUfL01P2gU5h0]i=O0;NCG`2h
U680^9AT0;VDI`80^IAX102iUF<40;ZFI080^YMO00<0^YMQ0;ZFHP2iUF<00P2iUFD0102iU6L0^YIV
0;ZFIP2jUVH30;VEI@80^9AT00<0]Y9R0;NCH`2gTf<00P2hU6@20;VEI@030;ZFIP2hU6@0^9AT0080
^IEU0P2jUVH20;^GI`P0^9AT00L0^9EO0;RDH02hU600^9AP0;RDHP2hU6@0^9=V0080^9=W202hU6@0
102kUfL0^YIV0;VEI@2iUFD20;NCH`040;JBHP2eTF40^9AT0;RDI0<0]i=S0`2fTV820;NCH`<0^9AT
2`2iUFD80;RDI0<0^IEU0P2hU6@;0;NCH`030;JBHP2gTf<0^IEU0080^YIV00@0^IEU0;NCH`2fTV80
]Y9R1P2gTf<00`2fTV80]I5Q0;FAH@040;JBHP80]I5Q1P2eTEd20;JBGP080;FBG02fTUh0]Y9N0;JB
H02gTf<0]i9U0;NBIP2hTfL80;B@H0P0]Y9R202bSUh80;B@H0030;F@H`2dSf80/XeP0080/HaO00D0
/XeP0;>>H@2dSf80^9AP0;NCG`020;JBGP80]91L00H0]Y9N0;NCG`2hU600]i9N0;JAG@2dSe/30;:=
F@030;>>FP2dSe/0]91P00D0]91P0P2eTF440;NBI@80]Y5T0P2eT6<20;FAH@H0]91P202cSel03P2e
TEd0]91L0;>?F`2bSUX0/HeI0;2<F02_ReL0[XYF0;6<G`2bSF00/hiQ0;B?HP2eT6<0]Y5T0P2gTVD8
0;>?G`80]91P00<0/hmO0;:>GP2aSEd00P2`S5`00`2_Re/0/HeI0;6=F@020;2<F080[h]G0P2^RUH2
0;2<G0090:n;F`2^RUX0[h]K0;2<G02bSUh0]91P0;FAH@2dT600/XiN00<0/8aL00<0/HeM0;:>GP2b
SUh01`2bSUh20;>?G`<0/XiN0`2aSEd20;2:F@80/H]J0P2bS5/20;>=G080[HeL00@0[heM0;6=G@2a
SEd0/XaM0P2dRed00`2fTV80]91P0;:>GP030;2<G080/HeM00H0/XeP0;:>GP2bSUh0/XiL0;:>FP2b
SeT20;:?E`<0/HeM0`2bSUh30;>?G`@0/8aL0P2aSEd20;:>GP80/XiJ00H0/HeI0;2<F02_ReL0[XYF
0:f9E@2/R5@20;2<FPH0[h]I202aS5l60;6=G@80/8aL00X0/hmM0;B@GP2dT5h0]I5O0;B@GP2bSU`0
[h]I0:j:F02`RUT0/H]J0`2bS5/00`2`RUT0[XQG0:f7EP030:j9E@80[hYF0`2`ReL80:j:EP030:j9
E@2_RUH0/8]G0080/HaH00<0/8]G0:j9E@2]R5@0202^RUH80:b8F0040:b9D`2/R5@0[HUE0:f9E@@0
[HUG0P2^RE800`2]R5<0[8MC0:b6E@020:b6E`030:b6F@2ZQUH0ZXIF0080ZhMG0P2/R5P20:f9F@80
ZXEA0`2[QU830:b7D`T0ZhIA102/Qe830:f8D`040:n9F02^R5L0[8IE0:^5E080ZXAC00@0ZhED0:b6
E@2]QeH0[8QH0P2[QeL20:Z6EP80ZHEE00<0Z8AD0:n:EP2_RUH00P2^RED01`2]R5@0[8MC0:b7D`2/
Qe<0Yh9>0:R3C`2ZQE400`2/Qe<0102[QU80ZXEA0:^6DP2[QU830:Z5D@<0ZHA@202XPU<30:R3C`@0
ZHA@00L0ZXEA0:J1C@2WPTh0Yh9>0:R3C`2YQ500ZXEA0080ZhIB0P2ZQE430:V4D0L0Z8=?102WPTh2
0:R4E0@0ZHEE0P2ZQUH00`2/Qe<0ZXEA0:R3C`030:J1C@D0Yh9>0`2VPDd20:F0C0030:J1C02UP4/0
Y7m:0080Xgi900H0Y7m:0:J1C02WPTd0YX5=0:F0C02SOTX20:9mB@030:=nBP2UP4`0YX5=0080Y7m:
102UP4/20:J1C0030:EoD02WPE80Z89C0080ZH=D00T0Z89C0:N1DP2UOe00ZhIB0:Z5D@2WPTh0YH1<
0:AoB`2SOTX00P2TOd/00`2TP500YH5A0:F1D@030:J2DP80YH5A00D0Z89E0:R2D`2WPE80Yh5@0:N2
CP020:N2C@80Yh9;202WPdl80:J2CP<0YH1<00<0Y7m;0:=nBP2SOTX00P2RODT80:5lB0P0XWi<0`2S
OTX20:AoB`<0YH1<00<0XWi:0:5mB@2QODT00P2PO4P309mkA`<0WgU:00<0X7Y;0:5kC02QNd`00P2R
O4d80:1kAPP0WgY500<0X7a<09ijBP2MNDT00P2LN4P0102MNDT0WWY:0:1lC02ONTH20:1kA`80WgY6
00D0WWU509ehA02MN4@0Xg]80:9jA`020:5iAP@0X7Q50P2LN4@209eiA@80WWY60P2ONdL0202JMcl0
W7U109ejA02NNTH0WWY809eiB@2LN4P0VWE80P2HM40209Ue@@80VWI20P2KMd<209ag@`@0VgI20P2J
MD4809YfAP0609iiA@2ONTH0WgY60:1kA`2ONTH0WWU50P2LMd<309]f@P0409Ye@@2IM400V7<o09Mb
?P80UW4m202LMd<0302LLD@0Vg1309Q_@@2DKSl0Tflo09A`@02CLD40Tg=209ahB02KMdL0V7A409Ib
@P<0U71000@0UG5109Ib@P2ELD40Tflo0P2BKSh00`2CKcl0UG5109Ib@P0809E`?00308m[>`2AKCd0
TVhn00<0U71000L0TVhn095]?@2@JS/0T6Xk095[?02BK3d0Tfdn0080U6ho00<0UFm0099/?`2BK3l0
1P2BK3l3099/?B_ooooo000Zooooob00V6hl0`2JL3h209U_?@<0V6hl202JKd8309]`@`<0VVm20P2I
KT4@09]a?`T0Vg8n00<0W7<o09ed@02MM4001@2MM40809icAP80WG=10P2LLT00302MLd40WgE30:5g
A@2RN4H0WgE30:1fA02QMdD0XWQ60:5gA@2PMT@0WWA209ec@@80X7E000<0X7E20:1d@`2OLd@00P2O
LdH01@2OLTP0W79009ec@@2OMD<0XGM50080XWQ600<0XGM50:1fA02PMT@00P2PMT@20:5gA@<0XWQ6
202TNdL@0:EjA`80YWe90`2UO4P30:AkA`@0YWe9102UO4P00`2VODT0YGa80:AkA`030:AkA`030:El
B02VODT0Ygi:00<0YWe90`2UO4P00`2TNdL0Yge;0:MmB`060:MmB`<0ZH1<0P2XOd/30:MnBP80Y816
00@0Y7m80:F0B`2UP4/0YX5=0P2VP4l01P2XOE80Z7e@0:UnD@2YOdl0ZGm=0:Z1C@80ZX5;2@2YP4X8
0:J1C@P0YX5<00<0ZGm=0:Z0CP2[PDl00P2/PU000`2[PDl0ZX1>0:UoC@080:b3C`P0[89@202YQ500
0`2WPTd0Z8=>0:Z5D0020:b7DP030:^6D@2ZQE00ZHA?00<0ZHA?0P2ZQE030:^6D@P0ZhIB0P2ZQE43
0:^6DP<0[8MC0P2ZQE430:^6DP<0[8MC202]R5@80:f4D080ZXE>0`2[QTl50:b7D0030:b7DP2/Qe<0
[8IE0080[8IG00@0[8II0:f8E02]R5@0[HQD0P2^RED30:n:EP040:j5D@2]Q500[HA@0:f4D080[8=?
0P2[PTh20:V4C`80Z8=>102WPTd01P2YPeH0Z89C0:N1DP2UOdh0YH1<0:F0B`<0YX5:402TOd/30:F0
B`80Y7m:1@2SOTT0102RODP0XGa70:1kAP2PNdH209mjA@<0WWU50`2ONTH20:1kA`0309iiA@2MN4@0
W7M300<0W7M300<0WGQ409iiA@2NNDD00P2NNDD209ehA0<0W7M30P2IM40209Ye@@<0VgI200<0W7M3
09Ye@@2JMD401P2JMD4809Ud@00809]`>`2JLC/0Vg8n09]c@02ILd80Ug=309Ab@P2DLT@309Qd@080
Ug<o0`2FLSh309Ma@P<0UW110P2EKd0809Ea@@0409A^?`2EKd00UFm009E_@0<0UW1100<0Ug5209A`
@02DL4000P2DL40309=_?`04099^?P2DL400Tflo099^?P80TFdm00H0TVhn09=_?`2DL400Ug5209I`
@@2DKSl309=]?P80U6ho00@0UG5109A`@02CKcl0TVhn0P2AKCd00`2BKSh0Tflo09=_?`0@09=_?`03
09Ea?@2DL3`0Tflk0080Tflk00<0UG4m09Ib?P2HM4000P2FLSh309Ea?@0309Mc?`2HM400VGE100<0
Ug=30`2HM4@209UeA@0409eiA@2LN4@0VGE109Qd@080Ug<o00D0V7A009Ue@@2HM400VGE109Yf@P02
09]g@`0409Yf@P2IMD40V7A009Qd@0<0VGE10P2JMT8209]g@`0609agBP2LN4P0W7Q809ahAP2LN4@0
W7U30P2LND401P2PN4D0XGU609mjAP2NNTH0Wg]709elA`80WGi8202PO4`80:>0BP<0YH5=0P2VPTh3
0:N3C`040:F1C@2VPTh0YX9>0:J2CP80Yh=?4P2XQ500102XQ5@0ZHEE0:V5E@2YQED20:Z6EP80ZhMG
0`2/R5P20:f9F@<0[XYJ0P2^Re<00`2_S5H0[h]G0;2<FP020;2<G0030;6<G`2cSel0/hmO00L0/hmO
00<0/XeI0;>>FP2eT5`00P2fTEd0102eT5`0/hiJ0;:=F@2aSEd30;:>GP80/hmO0P2dT600202dT5`0
/hmK0;:>FP2bSUX0/hmK0;B@G02eTEd0]Y9N202fTV880;NCH`P0^IEU00@0^IEQ0;RDH02hU600^9AP
0P2gTel20;JBGPP0]i=S2`2iUFD20;RDI0D0]i=S00<0^9AT0;VEI@2jUVH00P2kUfL01`2lV6P0]iAN
0;NCG`2gTel0^9AR0;RDI02iU6L00P2iU6P80;ZFIP80^iQP00<0^iQR0;ZFHP2jUV@00P2iUFD0102i
U6L0^YIV0;ZFIP2jUVH30;VEI@80^9AT0P2fTV80102gTf<0^9AT0;RDI02iUFD20;ZFIP<0^IEU0P2j
UVH30;^GI`P0^IEU00L0]iAN0;NCG`2gTel0]i=O0;RDHP2hU6@0^IAW0080^IAX202hU6@20;ZFIP04
0;VEI@2hU6@0^9AT0;NCH`80]Y9R0P2hU6@30;NCH`<0]Y9R00@0]i=S0;RDI02hU6@0^9AT0P2iUFD2
0;ZFIPP0^IEU202hU6@30;VEI@80^9AT2`2gTf<00`2fTV80]i=S0;VEI@020;ZFIP060;VEI@2gTf<0
]Y9R0;FAH@2fTV80]i=S0P2hU6@01P2gTf<0]Y9R0;FAH@2dT600]I5Q0;JBHP80]i=S00<0]Y9R0;FA
H@2dT6000`2dT5`30;FAG@80]Y9N00H0]Y=M0;JBGP2fTUh0]Y9P0;JBHP2fTF@20;JAI@P0]91P202f
TV8@0;B@H0030;JAI02eT6<0/hiQ0080/HaO00D0/XeP0;>>H@2dSf80]i=O0;JBGP020;FAG@80]91L
00/0]I5M0;JBGP2gTel0]Y5M0;F@G02cSUX0/XeI0;6<F02bSET0/hiJ0;B?F`020;>?G`<0]91P0`2e
TF420;NBI@80]Y5T0`2eT6<0102dSf80]I5Q0;FAH@2eTF430;B@H080/hmO202bSUh20;>?F`040;:>
FP2aSET0/HeI0;2<F080[h]G0P2cSV430;B?HP<0]I1S202cSel20;B@H0030;>?G`2bSUh0/HeM0080
/8aL00@0[h]K0;6=F@2aSET0/HeI0P2`S5P30:n;E`80[h]K0`2^RUX02@2`S5`0/hmO0;B@H02fTV80
]91P0;:>GP2`S5`0[h]K0;2<G00:0;6=G@80/HmQ0`2`SV030:n=G`050:n9FP2`RU/0/8YK0;6;G02b
S5d00P2cSEh0102dSUl0[HeL0:f=G02_SEd20;6=G@060;>=GP2eS5h0]HaN0;FAH@2cSel0/XiN0`2`
S5`00`2bSUh0/hmO0;:=H0020;:>GP030;:>G02bSUX0/XmI0080/XmG0P2aSEd30;:>GP<0/hmO00<0
]91P0;6=G@2aSEd00`2`S5`02@2aSEd0/hmO0;B@H02cSe/0/XiJ0;6=F@2`S5P0[h]G0:f9E@020:b8
E0<0/8aH0`2_ReL20:j:EPP0/HaO0`2bSUh30;6=G@80/8aL00X0/XiJ0;>?F`2cSe/0]91L0;>?F`2a
SET0[XYF0:f9E@2`RU/0/H]L0`2bS5d00`2`RU/0[XQI0:f7F0030:j9E@80[hYF0`2`ReL80:n;E`03
0:j9E@2_RUH0/8]G0080/HaH00<0[hYF0:f8E02/Qe<00`2_ReL20:j:EP<0[HUE0P2]RET20:b8F080
ZhMG0P2ZQUH20:b9D@040:b9D`2]RED0[HUG0:f9F@80[XUL00P0[hYC0:j9DP2]R5<0ZhIB0:^5E02[
QEH0[8IG0:f7FP80ZXIF0P2[QeL20:b8F080[HUI00<0[8MC0:^6DP2[QU801@2[QU880:^6D@P0[8MB
00<0[XQI0:f7F02[QEH00`2ZQ5D00`2[QEH0[8IG0:f7F0020:b8F0030:^7E`2ZQUH0ZHEE0080Z8AD
00H0Yh=C0:n:EP2_RUH0[XUE0:f8E02/Qe<20:^6DP0:0:Z5D@2XPdl0ZHA@0:^6DP2/Qe<0[HQD0:b7
D`2[QU80ZXEA0:^6DP<0ZXEA0P2YQ5020:R3C`P0Z89C202YQ5030:R3C`<0ZHA@102ZQE430:V4D0L0
Z8=?102WPTh80:V5E@080:^6DP2ZQE40Z8=?0:N2CP2VPDd0Yh9>0:R3C`2YQ5030:N2CP<0YX5=0P2U
P4`02`2UP4/0Y7m:0:=nB@2RODP0Xgi90:AoBP2VPD`0Yh9=0:J1C@2UP4`0Y7m;0080Xgi:00<0Y7m;
0:F0C02VPDd0202UP4T00`2UOe00YX1A0:R2D`020:V3E0080:R2D`2VP540YGm@0:Z5D@2XPdl0YX5=
0:AoB`2SOTX20:AoB`060:F0C02SOdl0Y81@0:F1D@2VPU80Yh=C0P2VPU801P2UPE40Z89E0:R2D`2W
PE80Yh5@0:N2CP80YX5<0P2VPDX80:N3C`P0YX9>0P2VPDd00`2UP4`0Y7m;0:=nBP020:9mB@T0XGa8
202ROTh0102QO4P0XWe90:9mB@2RODT20:=nBP80Y7m;00<0Xgm;0:9nBP2PO4P00`2ONdL20:1lB006
09ihB@2ONDX0WgU:0:1jB`2QNd`0XWa=0P2SODh80:1kAPP0WWU400<0X7a<09ijBP2MNDT00P2LN4P0
0`2MNDT0WWY:0:1lC0020:5lB0<0XWe900L0X7]709mjAP2NNDD0YG]90:AjB02SNDL0XGM500<0X7I4
00D0XGM509]g@`2KMd<0W7Q409eiA@0209ijAP80Wg]700T0VWLo09]h@02MNT@0WWY609ijB02MNDT0
VgM709YeB02HM4000P2IMD401@2JMT80VgM309ahA02LN4@0WGU500P0VgI2202IMDD409iiA@80WGQ4
0P2LMd<209]f@P80VWE100D0VGA009Qc?`2GLSh0Ug8n09Ia?@0809]f@P0309]bA02JLD<0UW110080
Tflo00h0TW10099b@@2CLd80VWI609UeA@2FLT80U71009=_?`2BKSh0Tflo09A`@02FLT80UG5109A`
@080Tflo00<0U71009Ea@@2FLT80202EL3`00`2@K3`0TFdm09=_?`0209A`@003099^?P2AKCd0T6`l
0080TF/l0`2BK3d309=]?PP0TV`o0`2BK3d[ooooo`00:_ooool>09Q^?080Ufdk4`2HKS`209U_?@<0
VW0n202JKd8309]`@`<0VVm20P2IKT4@09Y`?PT0VW4m0P2KLSh209ac?`0409ed@02NMD40WgI209mf
@PP0WW=601`0WG=109ab@02LLT00W79009ec@@2OMD<0XGM50:=iA`2OMD<0X7I40:5gA@2RN4H0XGM5
0:1fA02NM480W7900:AiA02SN4<0XWM40:9fA@2PM4D0X7A709mcAP2NLDL0W79009ec@@2OMD<0XWQ6
0P2SNDL0102RN4H0XGM50:5gA@2QMdD20:9hAP80XgU70P2TNTP80:AkAa00Y7U60P2VODT20:ElB080
Y7]70P2SNTH40:ElB0D0YWe900L0YGa80:AkA`2SNTH0XgY60:AkA`2UO4P0YWe90080Ygi:0P2VODT2
0:ElB080Y7]7202WODd30:V0C080Z7m;0`2WOTX20:B0AP040:AoB02UP4/0YH1;0:J1C@80YX1?00H0
Z7eB0:QmD02YOU40ZGm?0:UoC@2ZPDd20:Z1B`T0ZH18202VPDd80:J1C0030:UoC@2ZP4h0Zh5?0080
[89@00<0Zh5?0:Z0CP2YOdd0202]Q5080:b2DPP0ZH=B00<0Yh9=0:R3CP2ZQE000P2/Qe800`2[QU40
ZXE@0:V4C`030:V4C`80ZXE@0`2[QU480:^6DP<0ZXEA00<0ZhIB0:b7D`2/Qe<00P2]R5@20:Z5D@<0
ZhIB0`2/Qe<80:f8E0040:Z1C@2[PTh0[8=?0:b3C`80[XEA00<0[hIB0;27D`2ZQT`00P2ZQT`00`2[
Qdd0[8Q>0:b8CP020:f9C`80[8M@00<0[8MB0:b7D`2/QUD00P2/QUL00`2/QUT0ZhIB0:^6DP020:b7
D`040:f8E02^RED0[XUE0:j9E@80[XEA0`2]Q5030:b3C`80ZXE@0P2YQ4l02P2XPdh0Yh9=0:N2C@2W
PTd0ZXAG0:V3E02WPE80YGm>0:F0C02VPD`20:N2B`030:R3C02UP4`0YH1<00h0YH1<0P2VPD`20:F0
B`<0Y7m:00L0Xgi90:F0B`2TOdX0Xgi90:9mB02QO4L0X7]60080WgY500@0XGa80:1kA`2PNdL0X7]7
102ONTH00`2LMd<0WGQ409iiA@0209mjAP0409iiA@2MN4@0W7M309iiA@<0WGQ40P2LMd<209]f@P<0
VWE10`2KMT8209ag@`P0VgI2202JMD40202LLC`0W7<m09ie@@2NMT<0W7I509YfAP2FM4@0UG=50`2I
MD4309Qd@080Ug<o0`2HLT<00`2GLD80UW1109I`@@0209E_@0P0UW920P2EKd0209I`@@0509Ma@P2H
LT<0V79309Qb@`2CKcl00`2DL40509Ea@@0F09A`@02CKcl0TFdm095]?@2CKcl0U71009Ea@@2ILd@0
V79309E_@02DKSl0Tfdn09A^?`2EKd00UW1109Ib@P2ELD40Tflo099^?P2AKCd0TVhn09=_?a80U710
00<0UW8n09Ea?@2DL3`00P2DL3`0202FLSh0Ug<o09Ue@@2ELCd0UW8n09Mc?`2HM400VGE10P2HM400
102GLcl0Ug=309QdA02HM4@209UeA@0609YfAP2KMdL0VgM709]g@`2JMT80V7A00`2GLcl01@2IMD40
VWI209Ue@@2JMT80VgM30080WGU500@0VgM309Yf@P2IMD40VGE10`2JMT8209]g@`80W7Q400H0WGQ;
09eiB@2MNDT0WGU709eiA@2MNT@209ej@P80X7Q500@0WWU509ijAP2NNTH0WGa70P2LODL209mkB`80
X7a<00@0XGe=0:9nCP2SOdl0Xgm?102TPD/40:>0BP<0YX9>0P2WPdl30:R4D080YX9>0P2WPdl30:R4
D140ZHEA0`2YQED20:Z6EP<0ZhMG00@0[8QH0:f9F@2]RET0[HUI0P2^RUX20:n;F`80[haD00<0[haF
0;2<F02`S5X00P2aSEd00`2aS5l0]91P0;B@H0070;B@H0030;>>FP2dSe/0]Y5M0080]i9N00@0]Y5M
0;B?F`2cSUX0/XiN0`2cSel20;B@H080]I5Q00<0]I5M0;B@G02cSe/00P2bSUX00`2dT5`0]Y9N0;NC
G`040;NCH`@0]Y9R202gTf<80;VEI@<0^9AP0P2gTel30;JBGPP0]i=S202hU6@00`2jUVH0^IEU0;VE
I@020;RDI080]i=S0P2fTV801@2gTf<0^9AT0;VEI@2jUVH0^iMW0080_9QX00H0]iAN0;NCG`2gTel0
^9AR0;RDI02iU6L20;VDJ0<0^iMW1@2jUVH20;bIH@030;^HHP2kUf<0^YIT0080^IEU00@0^IAW0;ZF
IP2jUVH0^YIV0`2iUFD20;RDI0050;FAH@2fTV80]Y9R0;NCH`2iUFD00P2jUVH00`2kUfL0^IEU0;VE
I@020;ZFIP@0^iMW202iUFD02@2fTed0]i=O0;NCG`2gTel0^9AR0;RDI02iU6L0^IAX0;ZEJ@080;RD
I080^IEU102hU6@20;NCH`80^9AT0`2gTf<30;JBHP<0^9AT0P2iUFD30;ZFIPP0^IEU202hU6@30;VE
I@80^9AT0`2gTf<80;RDI0030;JBHP2gTf<0^IEU0080^YIV00H0^IEU0;NCH`2fTV80]I5Q0;JBHP2h
U6@20;VEI@060;RDI02fTV80]I5Q0;B@H02eTF40]Y9R0P2gTf<00`2fTV80]I5Q0;B@H0020;>?F`80
]91L0P2eTEd20;JBGP060;REG`2hU600]i=O0;JBH02eTF40]8mR0P2dSf<80;B@H0P0]Y9R202eTF48
0;B@H0040;JAI02eT6<0/hiQ0;:=H080/HaO00@0/XeP0;>>H@2fTUh0]I5M0P2dT5`20;>?F`060;B@
G02eTEd0]Y9N0;JAG@2eT5`0/hiJ0P2aS5P00`2bSET0/hiJ0;B?F`030;>?G`030;B@H02eTF40]I5Q
0080]Y9R0P2fTF@20;F@H`<0]8mR00<0/hiQ0;JBHP2fTV800P2eTF40102dT600/hmO0;>?G`2cSel8
0;:>GPH0/HeI0P2`S5P01@2fTF@0]I1S0;F@H`2eT6<0]8mR00<0/hiQ202cSel20;B@H0030;>?G`2b
SUh0/HeM0080/8aL00<0[h]K0;6=F@2aSET00P2aSET20;2<F080[h]G0P2^RUX20:f9F@080:j:FP2`
S5`0/hmO0;B@H02fTV80]I5Q0;>?G`2aSEd20:n;F`030;2<G02aSEd0/HeM00L0/HeM0P2`Sf830:n>
H@<0[XeP0P2_REX0102`RU/0/H]L0;:<G@2cSEh20;B>G`80[HeL00@0[heM0;6=G@2bSUh0/heN0P2f
SEl00`2cSel0/XiN0;2<G0020;2<G0040;:>GP2cSel0]I5Q0;:=H080/XiN00<0/XiL0;:>FP2bSeT0
0P2bSeL30;:>GP@0/hmO0P2dT600202bSUh0/HeM0;2<G02_Re/0/8aL0;6=G@2cSel0]I5Q0P2cSe/0
1P2bSUX0/8aH0:j:EP2]RED0[8QD0:^7D`80/HeI0P2`S5P0102_ReL0[XYF0:j:EP2^RUH80;:=H080
/hmO0P2bSUh20;6=G@80/8aL00X0/8aH0;6=F@2bSUX0/XiJ0;6=F@2_ReL0[HUE0:b8E02`RU/0/H]L
0`2bS5d00`2`RU/0[XQI0:f7F0030:j9E@80[hYF0`2`ReL80:n;E`090:n:EP2`ReL0/HaH0;6<F02`
ReL0[hYF0:f8E02/Qe<0/8aH0080[h]G0P2^RUH20:f9E@090:b8E02^RUX0[XYJ0:f9F@2[QeL0ZXIF
0:V5E@2XQ5@0Yh=C0080ZhQ>00@0[8UA0:b8E02]REL0[XUL0P2^REd0202`Re@0[XUB0:b7DP2[QU80
ZXAC0:^5EP2/QUL0[HMJ0P2ZQUH20:^7E`80[8QH0P2]RET20:f8E080[8MC00@0ZhIB0:Z5D@2YQ500
ZHA@202[QU440:b7DP@0ZhIA00<0[HMH0:b6E`2ZQ5D00`2ZQ5D00`2[QEH0[HMH0:j8F@020:b8F006
0:^7E`2ZQUH0ZHEE0:R4E02WPe<0YX9B0P2^RED0102]R5@0[8MC0:^6DP2ZQE420:V4D0030:R3C`2Y
Q500ZhIB0080[HQD00<0[8MC0:^6DP2ZQE400`2ZQE420:V4D0<0Z8=?202XPU<60:V4D080Z8=?0P2Z
QE430:V4D0<0Z8=?0P2ZQE430:V4D0<0Z8=?102WPTh40:R3C`P0ZHEE00<0ZHA@0:R3C`2WPTh00P2W
PTh00`2XPdl0ZXEA0:^6DP030:N2CP<0YX5=0P2UP4`00`2TOdX0Xgi90:9mB0020:9mB0060:AoBP2V
PD`0Yh9=0:N2CP2VPDd0Y7m;0P2SOTX00`2TOd/0YX5=0:N2CP080:F1A`030:EoD02VP540Yh5B0080
Z89C00H0Yh5B0:J0D@2UOe00Yh9>0:J1C@2UP4`20:=nBP060:AoB`2VPDd0Yh9>0:9nCP2SOdl0YH5A
0`2WPe<01`2VPU80YH5A0:R2E@2XPU<0Yh5B0:N1D02VPDd00P2VPD`20:F0B@P0Yh=?202VPTh01P2W
PTh0YX5=0:F0C02TOd/0Xgi:0:9mB@80XGa8202PNdL80:9nCP@0X7]70P2QO4P20:9mB@090:=oB`2R
OTX0X7a809mkA`2NNTH0Wg]70:1lB02QODT0WWQ90080WgU:00D0X7Y;0:9lC@2SODh0Xge>0:AnC`08
0:1kAPP0WWU400<0X7a<09ijBP2MNDT00P2LN4P03`2MNDT0WWY:0:1lC02RODT0Xgi:0:AoB`2UP4`0
Y7m;0:=nBP2QO4P0X7]70:MmB`2UNdT0XgU70:1fA00209me@`0C0:1fA02QMdD0VWI209Yf@P2KMd<0
W7Q409eiA@2NNTH0Wg]70:1lB02JMcl0VgQ009ai@`2MNDD0WGU709ahB02KMdL0VWE809Ue@@0209Yf
@P0509]g@`2MNDD0WWY609ijAP2ONdL0202KMT8809UeA@80WGQ40P2LMd<409]f@P0309Ye@@2IM400
VGA00080VGA0102HLcl809Ud@00<09]bA02HLT<0UW1109=_?`2AKcl0TG50095c@@2BM480Ug=309Ib
@P2DL400TVhn0P2AKCd01@2BKSh0Tflo09Mc@`2FLT80U7100080Tflo00<0U71009Ib@P2GLd<0202E
L3`0202BKSh0Tflo09=_?`2DL400Tflo095]?@2?Jc/0SVXj0`2CKCh3099/?@80TF/l202BK3l3095[
?2_ooooo000Zooooo`d0V6hl0`2GKC/@09Q^?080Ufdk00@0V6hl09U_?@2IKcd0VW0n0P2KLCl809Y_
@P<0Vg130`2JKd8209U^@A00VW0n2@2JLCd01P2IL3`0VW4m09]b?P2LLcl0WGA009mf@P80X7M3202N
LdP02P2MLd40W79009]a?`2LLT00WG=109me@`2QMdD0XgU709me@`2PMT@30:5gA@0309me@`2NM480
W7900080YW]600X0Y7U60:=gAP2QMDH0X7A709ibA@2NLDL0W79009ec@@2OMD<0XWQ60P2SNDL30:9h
AP<0XgU70P2TNTP20:EkB@D0Y7]70`2UO4P@0:AiAP80YWe90P2UO4P01@2TNdL0XgY60:=jAP2RNDD0
XgY60080Y7]700P0YGa80:ImB@2WOTX0Ygi:0:QoB`2WOTX0YGa80:=jAP80XWU500<0XgY60:ElB02W
OTX00`2WOTX00`2VODT0YGa80:AkA`020:AkA`P0Yge=0`2YP4`20:QoB`<0Ygi:0P2TP4H0102TOdP0
YH1;0:F0B`2VPDd20:J0C`060:QmDP2XOE00ZGiA0:UoC`2YOdd0ZX5=0P2ZPD/90:V0B0P0YX5=202V
PD`00`2YOdd0ZX1>0:^1C`020:b2D0030:^1C`2ZP4h0ZGm=00P0[HA@202/PU880:V3DP030:N2C@2X
Pdh0ZXE@0080[8MB00<0ZhIA0:Z5D02YQ4l00`2YQ4l20:Z5D0<0ZhIA202[QU80102YQ500ZXEA0:Z5
D@2[QU820:b7D`80[HQD0P2ZQE430:^6DP<0[8MC202]R5@20:V0C0040:^2CP2/Pdl0[XEA0:n6DP80
/HQD00@0ZHE;0:Z6C02ZQT`0ZhM=0P2/R4h20:f9C`80[8M@00<0[8MB0:b7D`2/QUD00P2/QUL0102/
QUT0ZXEA0:Z5D@2[QU820:b7D`030:f8E02^RED0[XUE00<0[XEA0P2]Q5030:b3C`040:^6D@2ZQE00
ZXE@0:V4C`80Z8=>0P2WPTd01P2[QEP0ZH=D0:N1DP2UOdh0YH1<0:J1C080Yh9;00<0Z8=<0:F0C02U
P4`03P2UP4`30:J1C080YH1;0`2TOdX0202VPD`0YH1;0:AoBP2SOTT0XWe80:5lA`2PNdH0WgY50P2R
ODT0102QO4P0X7]709mjAP2ONTH209iiA@0309Ye@@2LMd<0WgY60080X7]700<0WgY609ag@`2JMD40
0P2MN4@209ag@`<0VgI2102JMD4209]f@P<0W7M3402KMT80202MLSd0WWDo09mf@P2PN4D0WWQ709]g
A`2HMTH0UWA61@2IMD4309Qd@080VG=40P2HLT<0102GLD80UW1109I`@@2EKd0809Ib@P0409E_@02F
L440UW1109Ma@P80V7930P2ILd@209=_?`80U71000L0UG5109Ib@P2GLd<0Ug=309Ib@P2ELD40Tflo
0080TFdm0180Tflo09Ea@@2FLT80VWA509Qb@`2FL440U6ho09=]?P2DKSl0UFm009I`@@2GLd<0UW92
09=_?`2BKSh0TFdm099^?P2DL40B09Ea@@0@09Mc?`2FLSh0UG4m09A`?02ELCd0UW8n09Qd@02IMD40
Tflk09Ea?@2HM400VWI209]g@`2IMD40Ug<o09Ib?P80V7A40P2IMDD01`2JMTH0VgM709]gA`2LN4P0
VWI209Ue@@2GLcl00P2FLSh01P2HM400VGE109Yf@P2IMD40VWI209ahA080WGU500<0W7Q409Yf@P2I
MD400`2JMT8209]g@`<0W7Q400H0WWU<09ijBP2NNTX0WWY809ijAP2NNdD209ik@`80WgM400@0WGQ4
09eiA@2MNDD0W7]60P2KO4H209ijBP0609mkB`2QODd0XWi>0:=oC`2TP500YH5A0P2UPT`40:B1B`80
Xh1:00@0YX9>0:N3C`2WPdl0Yh=?0P2XQ5020:V5D@040:J2CP2WPdl0Yh=?0:N3C`80Z8A@4P2YQE42
0:V5E@<0ZXIF0`2[QeL30:f9F@80[XYJ0`2_Re/20:n<E0030;2=E`2`S5P0/HeK0080/HeM00<0/XeP
0;B?HP2dSf801`2dSf800`2cSUX0]8mK0;JAG@020;NBGP030;JAG@2dSe/0/hiJ00<0/hmO0P2dT603
0;FAH@030;FAG@2dT5`0/hmK0080/XiJ00<0]91L0;JBGP2hU6001@2gTf<30;JBHPP0]i=S0`2jUVH5
0;VEI@80^9AP0`2gTel30;JBGPP0]i=S202hU6@20;ZFIP040;VEI@2hU6@0^9AT0;NCH`<0]Y9R0P2g
Tf<00`2iUFD0^YIV0;^GI`020;bHJ0060;NDGP2gTel0]i=O0;RDHP2hU6@0^IAW0P2iU6P40;^FJ@@0
^YEX0P2lVF400`2lVF<0^iMS0;ZFI0020;VEI@040;VDI`2jUVH0^YIV0;ZFIP<0^IEU0P2hU6@20;FA
H@040;JBHP2gTf<0^IEU0;ZFIP80^iMW0P2iUFD20;ZFIP<0^iMW00<0_9QX0;VEI@2iUFD01P2iUFD0
1`2fTed0]Y9N0;JBGP2gTel0^9AR0;RDI02iU6L00P2jUFTB0;RDI0<0]i=S0`2fTV820;RDI0<0^IEU
0`2jUVH80;VEI@P0^9AT0`2iUFD20;RDI0<0]i=S202hU6@00`2fTV80]i=S0;VEI@020;ZFIP060;VE
I@2gTf<0]Y9R0;FAH@2fTV80^9AT0P2iUFD01P2hU6@0]Y9R0;FAH@2cSel0]I5Q0;JBHP80^9AT00@0
]Y9R0;FAH@2cSel0/XiJ0P2cSe/00`2dT5`0]I5M0;FAG@020;JBGP080;VFH02hU600]i=O0;JBH02e
TF40]8mR0;>>HP2bSF480;B@H100]Y9R202dT600102gTVD0]I1S0;>>H@2bSF020;6<G`040;:=H02c
SV40]I5M0;B@G080/hmK0P2bSUX01P2cSe/0]91L0;FAG@2fTEd0]I1L0;>>FP<0/HaH00<0/XeI0;>>
FP2bSUh00P2cSel00`2dT600]I5Q0;FAH@020;JBHP80]I1S0P2dSf830;>>H@030;:=H02fTV80]Y9R
0080]I5Q00<0]91P0;>?G`2cSel02@2bSUh0102_ReL0/8aH0;2<F02`S5P30;6=F@090;:>FP2gTVD0
]i9U0;JAI02eT6<0]8mR0;>>H@2bSF00/HaO00P0/hmO0P2dT6000`2cSel0/XiN0;6=G@020;2<G003
0:n;F`2bSUX0/HeI0080/HeI0P2`S5P20:n;E`0<0:j:FP2]RET0[HUI0:f9F@2^RUX0/8aL0;>?G`2d
T600]i=S0;FAH@2cSel0/HeM0P2_Re/20;2<G0P0/HeM0P2`Sf830:n>H@<0[XeP00P0[XQK0:n9G02`
RUd0/H]N0;:<G`2cSF00]8iQ0;F?HP80[HeL00H0[heM0;6=G@2bSUh0]8iO0;J=G`2gSV020;6=G@<0
/8aL00@0/XiN0;B@H02fTV80/XeP0P2bSUh00`2bSU`0/XiJ0;:?F@020;:?E`<0/XiN0`2cSel30;B@
H00@0;>?G`2bSUh0/8aL0:n;F`2`S5`0/HeM0;B@H02eTF40]91L0;>?F`2bSUX0/8aH0:j:EP2]RED0
[8QD0:^7D`80/HiH0P2`SEL0102_S5H0[X]E0:j;E@2]RU@80;:=H0040;B@H02cSel0/hmO0;:>GP80
/HeM0P2`S5`02P2_S5H0/8eG0;6>F02aSUP0/8eG0:j;E@2/RE<0ZXMA0;2:G@2aReh30;:<G`030;2:
G@2^R5/0[HMJ00<0[XUE0P2_RUH30;2;E`P0[h]G00P0[hYF0;2;E`2aS5P0/HaH0;2;E`2_RUH0[HQD
0:^6DP80/8aH00@0[h]G0:j:EP2^RUH0[HUE0P2/R5@01P2_Re/0[XYJ0:f9F@2[QeL0ZHEE0:R4E080
YX9B0100ZhU<0:^8CP2/RE40[8UC0:f9E`2^RE`0[XUM0:n:H02`Re@0[XUB0:b7DP2ZQE40ZXAC0:^5
EP2/QUL0[XQK0P2ZQUH20:^7E`80[8QH0P2]RET01P2_RUH0[XUE0:f8E02/Qe<0ZhIB0:V4D080Z8=?
202[QU430:b7DPD0ZhIA00@0[8II0:^5F02ZQ5L0ZH=F0P2ZQ5L00`2[QEP0[HMJ0:j8F`020:b8F004
0:^7E`2ZQUH0Z8AD0:N3D`80YX9B00H0[XUE0:f8E02/Qe<0ZhIB0:Z5D@2YQ5030:R3C`030:V4D02[
QU80[HQD0080[HQD00@0[8MC0:^6DP2ZQE40ZXEA0`2YQ5030:R3C`P0Z89C1@2YQ5030:R3C`80ZhIB
00<0ZXEA0:V4D02XPdl00P2WPTh00`2VPDd0ZXEA0:Z5D@030:V4D0<0Z8=?102WPTh40:R3C`80ZXIF
102YQED20:R4E080Z8=?00H0Yh9>0:J1C@2WPTh0ZHA@0:^6DP2]R5@30:N2CP<0YX5=0P2UP4`00`2T
OdX0Xgi90:9mB0020:9mB0060:AoBP2VPD`0Yh9=0:N2CP2VPDd0Y7m;0P2SOTX00`2TOd/0YX5=0:N2
CP020:J2B0@0YH570P2TP4H00`2TOTl0YX1A0:N1DP020:R2D`060:N1DP2VP540Y7i?0:J1C@2UP4`0
Y7m;0P2SOTX0402UP4`0Yh9>0:R3C`2QODd0Xgm?0:F1D@2WPe<0Z8AD0:N3D`2VPU80YH5A0:R2E@2X
PU<0Yh5B0:N1D02VPDd20:F0B`030:F0B@2TOdP0Yh=?00L0Yh=?202VPTh01P2WPTh0YX5=0:J1C@2T
Od/0Xgi:0:9mB@80XGa8202PNdL80:9mD080WWU50P2ONTH20:1kA`80XGa800<0Y81<0:9nBP2PO4P0
0P2NNTH0102ONdL0X7a80:5mB@2NN4T209miBP030:5kC02RO4d0Xge>0080Y7i?202PNdH809iiA003
0:1lC02NNTX0WGU90080W7Q800l0WGU909ijBP2PO4`0Xgi:0:AoB`2VPDd0Yh9>0:J1C@2TOd/0XWe9
0:5lB02XO4/0YWY90:AhA`2QMD@00P2PM4<04P2QMD@0XWI509Ue@@2JMT80VgM309ahA02MNDD0WWY6
09mkA`2PO4P0VGHn09]h@02LND<0WGU509eiA`2LN4P0VgM709UdA`80VWI200@0VgM309ahA02NNTH0
Wg]70P2PO4P209Ye@@@0VgI20P2LMd<809UeA@80W7M300<0VgI209Ye@@2JMD40102JMD4409Qc?`@0
VGA0202HLcl02`2ILd@0V79309Ea@@2AKcl0T70o095a@02ALd40TWA209Ea@@2CKcl0TVhn0080T6`l
00H0TFdm099^?P2CKcl0Ug=309Ib@P2DL40209=_?`0309A`@02FLT80Ug=300P0UG0l0P2CKcl209A`
@005099^?P2@K3`0SVXj08aX>02EKd000P2DKSl00`2CKCh0TV`m095[?002091Z>`P0TV`o0`2AJc`[
ooooo`00:_ooool309U^@@80VVm20`2KL4<809E/>0P0V6hl00<0UFXm09M/?`2IKT400P2JKd800`2I
KT40Uf`o09EZ?@0809U_?@80UV/n00@0Uf`o09Q]@02JKd80Vg130P2LLD@809U_?@P0W7900P2JL3h2
09]a?`80W790102MLd4209ab@0<0Vg4o0P2JL3h309Y_@P80VFi10`2HKD0809ec@@D0WGA00`2LLcl0
2@2MLd40WgE30:5gA@2RN4H0XgU70:9hAP2QMdD0X7I40:=hA@030:9gA080XGI30P2PMD800`2PMd<0
XGQ40:9iA@020:AkA`0<0:9iA@2QN4@0X7M309me@`2PMT@0XGM50:=iA`2TNTP0YWa:0:MmB`2XOT`0
WgE30`2PMT@20:5gA@80XWQ60P2VODT30:ElB0<0Y7]7202VN4H00`2SN4D0Y7U60:IkB0020:MlB@09
0:IkB02TNDH0XgQ50:EjD02UNTl0Y7U>0:=hB`2SNDT0XWQ60080XGQ40P2UO4@0102UO4H0YGa80:El
B02UNdT20:EkB`P0Z7m;0`2VODT50:MnBP<0YWe90`2WOTX20:QoB`P0Ygi:00P0YGa80:ImB@2WOTX0
Z7m;0:V0C02ZPDd0Zh9>0:b3C`<0ZX5=102YP4`20:QoB`80Z7i<0`2YOdd30:Z0CPP0ZWmB202XPdl8
0:V0C0<0[8=?0P2]Q5030:j5D@P0ZHA@00<0Z8=?0:V4D02[QU800P2/Qe<00`2[QU80ZHA@0:R3C`08
0:V4D080[HQA00<0[8MB0:b7D`2[QE@00P2ZQ5D00`2YPeH0ZhIB0:^6DP070:^6DP070:b7D`2]R5@0
[XUE0:j9E@2]R5@0[8MC0:^6DP030:b3C`80[HA@0`2^QE480:j4E0@0/8MC0P2aR5@20;:9E@P0[HQD
00D0ZXEA0:^6DP2[QU80[8MC0:f8E0020:j9E@040:n:EP2/Qe<0[8MC0:b7D`<0ZhIB0P2ZQE480:^6
DP<0Z8=?0`2YQ5050:Z5D@040:V4D02XPdl0Yh9>0:J1C@X0YH1<0`2TOdP20:F0B@<0YX5:202TOdX3
0:5lA`030:9mB02SOTT0Y7m:0080Y7m:0P2RODT0102QO4P0X7]70:1kA`2ONTH209iiA@P0WgY5202N
NDD209ijAP0609eiA@2LN4@0VgM309Yf@P2IMD40V7A00`2LMd<209]f@P<0VWE100P0VgI209Ye@@2I
M400V7<o09Ud@02KMT80WWU50:1kA`<0VWI60P2IMDD309QdA0P0Ug8n00@0Ug5209Qb@`2HLT<0V793
0P2ILd@209YdA@0609ahA02KMd<0VgM309Yf@P2IMD40V7A00P2GLcl809Mb?P0609Ue@@2HM400V7A0
09Mc?`2FLSh0UG4m0P2DL3`0102FLSh0Ug<o09Mc?`2GLcl209Qd@080VGE12@2FLSh309Ib@P80UG51
102DL4001`2ELD40UW9209Mc@`2HM4@0VGE509YfAP2KMdL0202IMD4209Ef@00>09Mf@@2JMT80VgM3
09ag@`2OMd@0X7Q509UcA02JM4D0VgE609egB02NN4T0X7Y;0:5kC02RO4d20:1lB00409ijAP2MNDD0
VgM309Yf@P80V7A000H0VWI209]g@`2KMd<0W7Q409eiA@2NNTH409mkA`0309ijAP2MNDD0VgM30080
VWI200@0VGE109eiA@2MNDD0WGU50P2NNTH309mkA`060:=l@`2TODH0XWe80:5mB`2ROE00X7iA0P2P
OeH80:B0C0040:F1C@2VPTh0YX9>0:J2CP80Yh=?0P2XQ500202XPeH0Yh=C0:J2DP2UPDl0YH5=0:J3
C@2WQ4`0Z8E=202ZQE020:F1C@030:J2CP2WPdl0Z8A@0080ZXIB00H0ZhMC0:V6CP2YQTh0ZHI@0:V5
D@2YQE<20:V5E@060:V4E`2YQE40ZXIB0:Z6DP2[Qe<0[8QD0P2]RED0102^RUH0[XQI0:j8F@2^R5T2
0:n9FP<0/8YK00H0[h]K0;2<G02aSEd0/XiN0;>?G`2dT6020;FAH@<0/hiR0P2dSf<40;F@I0P0]91P
00H0/HeI0;:>FP2cSe/0]91L0;FAG@2fTUh20;NCG`@0^9AT0P2gTf<20;JBHP80/hmO0P2dT600102e
TF40]Y9R0;NCH`2gTf<80;RCIP<0^IEU0P2hU6@30;NCH`P0^9=V202hU6@80;NCH`80^YIV00@0^IEU
0;RDI02hU6@0]i=S0P2fTV820;FAH@040;JBHP2gTf<0^IEU0;ZFIP80^iMW00@0]i=S0;RDI02hU6@0
^IEU0P2jUVH40;^GI`80^YIV00@0^IEU0;RDI02hU6@0]i=S202jUf480;RCIP<0]i=S0P2hU6@30;VE
I@050;JDIP2gUFL0]iEW0;RFJ02iUfT00P2jV6X0102kVF/0^IEU0;VEI@2iUFD20;RDI0<0]i=S0`2f
TV860;NCH`P0]Y9R00@0]91P0;FAH@2eTF40]I5Q0P2fTV820;NCH`P0]YAT202iUFD80;VEH@80]Y9R
00@0]i=S0;RDI02hU6@0^IEU0P2jUVH80;NCH`<0^YIV0`2iUFD20;RDI080^YEY00L0^IAW0;RDI02h
U680]i=O0;JBGP2fTed0^YMQ0080^IIP00<0]iAN0;JCG@2eTU`00P2dTE/80;NCH`P0^9AT0P2hU602
0;NCG`@0]Y9N00<0]91P0;>?G`2aSEd00P2aSEd04`2cSel0]I5Q0;NCH`2fTV80]I5Q0;B@H02cSel0
/XiN0;6=G@2`S5`0[h]K0;:>GP2dT600]Y9R0;NCH`2hU6@0]i=S0;JBHP2eTF400`2fT6430;F?H080
]8iO0P2cSel30;B@H0<0]I5Q1@2gTF840;J@H@P0/hmO00<0]Y9R0;FAH@2cSel00`2aSEd00`2cSel0
]91P0;:?F@020;:>FP030;:>G02bSUh0/XeP0080/XeQ00P0/XmE0;>@EP2dTET0]I9L0;FAG@2cSed0
/HeK0;2<G0P0/XaM0P2cSEh0102bS5d0/H]L0;6;G02`RU/20:n9FPP0/XiN0P2aSEd20;2<G0080;:>
GP2dT600]i=S0;RDI02fTEd0]I1L0;>>FP2`ReL20:n:EP80/8]G0P2dSUl30;>=GP<0/XaM00P0/HaG
0;6<F02`ReL0/H]J0;:<G@2eSf80]i1U0;VBI`80]Y1Q00@0]HmP0;B>G`2dSUl0/heN0P2bS5d20;B;
G`040;:<G`2aS5l0/HaO0:n=G`80[XiO0`2_SEl30;2>H080/HmQ0`2bSEP20;6<E`<0/8]F402bSUh0
1P2bSF00/XiN0;:>GP2cSed0]91L0;FBG080]I9J0P2aSEd30;:>GP@0/hmO202bSUXH0:n;F`080;F@
I02cSV80/8]N0:j:FP2/R5H0[HUE0:j:EP2^ReD20;>>FP040;6<F02`ReL0[XUE0:f8E080ZhIB0`2_
Re/20:j:FP<0[HUI00H0[X]E0:j:EP2^RUH0[XYH0:j:FP2^RE`20:j9G@030:^7E`2/R5P0[XYJ0080
[h]K00<0[XYJ0:b8F02[QeL00P2/R5P0102]RET0[XYJ0:j:FP2_Re/20;2<G0030:n;F`2^RUX0[8QH
0080ZhMG00H0[8QH0:j:FP2_Re/0[hYN0:j9G@2/Qe/20:^6FP030:b7F`2^REd0[hYN00<0ZhII0P2/
QeX30:f8F`80[8MK00H0[HQK0:j:FP2^RUP0[h]G0;2<F02`SEL80:f:D0<0ZhMC0`2ZQU8:0:V5D@80
ZHA@102ZQE420:^6DPT0ZXEA202[QU820:^7D`040:Z6DP2YQE40ZHEA0:R4D080Yh=?00<0Yh=90:R4
BP2ZQT`00P2[Qdd00`2ZQT`0ZHE;0:R4BP080:Z5D100Z8=?0P2YQ4l20:R3CP80Yh9=0P2VPD`0102V
PDd0Yh9>0:N2CP2WPTh30:R3C`030:V4D02VPDd0YX5=00H0YX5=0P2YQ500102XPdl0Yh9>0:N2CP2V
PDd20:F0C0060:J0D`2VP540YX1A0:N1D02XPdl0ZHA?0P2YQ4d0102YQ4l0Z8=>0:R3CP2XPdh20:N2
C@80YX5<00P0Xgi90:9mB02RODP0XGa70:9mB02TOdX0Yh9=0:R3CP80YH1;0`2TOdX30:=nB@030:Uo
C@2XOT`0Yge;0080YWa:01H0Z7i<0:Z0CP2[PDl0ZXAG0:Z4E@2YPe@0ZH=B0:R3C`2XPdh0Z8=<0:N2
B`2YQED0Yh=C0:B0D02ROTh0XGe=0:9nCP2SOdl0Y81@0:V4D02WPTh0YX5=0P2UP4`00`2WPTh0ZHA@
0:^6DP020:R4D080Yh=?0`2VPTh20:F1C@P0YX9>00@0Xgm;0:B0C02TP4`0YH5=0P2VPTh20:N3C`80
Z8=>00@0Yh9=0:J1C02TOdX0Xgi90P2RODP04@2RODT0XGa80:1kA`2ONTH0X7]70:5lB02SOTX0Y7m;
0:QmBP2TNTP0XGM50:AlB`2XPU<0ZXEH0:J4E`2SPE@0XG]>0080XG]<00<0XG]:0:5lB02QO4L00P2Q
O4D809mjAPP0WWU500<0X7a809mkA`2NNTH00P2MNDD02P2ONdL0XGe90:9nBP2RODT0XGa809iiA@2L
Md<0VgI209ag@`2MN4@209iiA@0:09ehA02KMT80VWE109]f@P2MN4@0WgY60:1kA`2QO4P0XWe90:=n
BP80Y7m;00<0Xgi:0:9mB@2QO4P0202PNd@0102IMD40VWI209Yf@P2KMd<209ahA080WGU500P0X7a8
09ijAP2LN4@0VgM309Yf@P2KMd<0W7Q409eiA@P0WWY:00T0X7a<09mkB`2NNTX0WGU909ahB02KMdL0
VWI609UeA@2LMd800`2KMT4209Ye@080VG@o00<0VWI209Ue@@2HM4000P2GLcl409Ib?P@0Ug=3102H
M4@209Qd@080Ug<o00@0UW8n09Ea?@2ELCd0U70l202DKSl00`2GLTD0UW5409E`@`0209=^@@0309A_
@P2EL4<0UW5400<0U7100P2ELD4309Ib@P80TVhn00@0TFdm091/?02@K3`0Sf/k0P2>JSX00`2BKSh0
Tflo09A`@00209Ib@P0409A`@02CKcl0TVhn09A^@@80Tfe000P0TV`o095[?P2@JSd0T6Xm08mY?02C
KT40TF`o08mZ?@80SVTl00<0SfXm091[?P2BKD000`2AL4<[ooooo`00:_ooool309U^@@80VVm20`2K
L4<809E[>@P0V6hl00<0UV/n09M/?`2HKD000P2IKT400`2HKD00Uf`o09I[?P0809U_?@0309M/?`2H
KD00V6e00080VFi10`2JKd8809U_?@P0W7900P2JL3h209]a?`80W790102MLd4209ab@0<0Vg4o0P2J
L3h809U^@@P0WG=11P2MM40209ac?`0809ec@@2OMD<0XGM50:9hAP2SNDL0XWQ60:5gA@2PMT@40:9g
A080XGI30P2PMD800`2PMd<0XGQ40:9iA@020:AkA`030:9iA@2QN4@0X7M30080X7I400@0XGM50:9h
AP2SNDL0Y7Y80P2UNdT40:1fA080XGM50P2RN4H20:ElB0<0Y7]70`2SNTH80:IhAP030:=hA@2TNDH0
YW]80080Yga900/0YW]80:AiAP2SN4D0YGY?0:AiCP2TND`0XgQ;0:=iB@2RN4H0XWU50:5hA0020:Im
A@040:ImA`2VODT0YWe90:IlBP80YWa<202XOd/40:ImB@@0Ygi:0`2VODT30:MnBP80Z7m;202WOTX0
1@2UO4P0YWe90:ImB@2WOTX0Z7m;0080ZH1<102ZPDd20:V0C0@0Z7m;0P2XOT`30:UoC@<0ZX1>202Z
Oe880:R3C`P0ZH1<0`2/Pdl30:f4D080[XEA202YQ5000`2XPdl0ZHA@0:^6DP020:b7D`030:^6DP2Y
Q500Z8=?00P0ZHA@00D0[HQA0:b7D02/Qe80ZhIB0:^5E0020:Z4E@030:V3EP2[QU80ZhIB00L0ZhIB
00L0[8MC0:f8E02^RED0[XUE0:f8E02/Qe<0ZhIB0080[8=?0`2]Q5030:j5D@P0[XAD00@0[hIB0;27
D`2`Qe<0/8MC0P2aR5@20;:9E@P0[HQD102/Qe<40:f8E0<0[8MC0`2[QU820:Z5D@P0ZhIB0`2XPdl2
0:V4D0H0ZXEA00<0ZHA@0:R3C`2WPTh00P2VPDd90:F0C0P0YH19202TOdX20:5lA`80XWe800@0Xgi9
0:AoBP2TOdX0Y7m:0P2RODT20:5lB080X7]70P2ONTH809mjA@P0WgY600H0Wg]709ijAP2MNDD0W7Q4
09]g@`2JMT8209Ue@@0409ehA02LMd<0W7M309ag@`80VgI20P2JMD40202PNdL0WWU509ag@`2JMD40
VGA009Ye@@2KMT80W7M30`2JMTH209UeA@<0V7A4202HLcl309Qb@`80VG=40`2JM4D209Yf@P<0VGE1
0`2HM40809Qc?`80V7A00`2GLcl309Ib?P<0Ug<o0P2HM40309Ue@@T0Ug<o0P2GLd<209Ib@P<0UG51
00H0U71009Ea@@2FLT80UW9209Mc@`2IMDD209YfAP0309]gA`2IMD40VGE100H0VGE100H0UGI009Ig
@@2GMT40VWI209]g@`2MN4@20:1hA@80VWA500H0W7I709egB02ONDX0X7Y;0:5kC02RO4d20:1lB004
09mkA`2NNTH0WGU509ahA080VgM30P2LN4@309eiA@<0WWY60P2ONdL209ijAP<0WGU500<0W7Q409ei
A@2MNDD00P2NNTH309mkA`090:1lB02TODH0Y7e60:9mB@2ROT`0XWe@0:5oDP2POe@0X7mF00P0Y81<
0`2VPTh20:N3C`<0Z8A@00P0ZHAG0:R4E02VPU80YH5?0:F1C@2VPdd0Z8E=0:V6CPP0ZXE@00H0YH5=
0:J2CP2WPdl0Z8A@0:V5D@2ZQU820:^7D`80ZHI>00<0ZHI@0:V5D@2YQE<00P2YQED0102YQ5L0ZhMC
0:^7D`2[Qe<30:b8E080[HUE0P2^R5T20:n9FP<0/8YK00L0/H]L0:n;F`2_Re/0/8aL0;6=G@2bSUh0
/hmO0080]91P0`2cSV820;B?H`<0]I1T00<0]Y5U0;B@H02dT6001P2dT6020;:>FP040;>?F`2dT5`0
]I5M0;JBGP80]i=O0`2gTf<30;JBHP80]I5Q0P2dT600102eTF40]Y9R0;JBHP2gTf<20;RDI0P0^9=V
0`2iUFD20;RDI0<0]i=S202hTfH80;RDI0P0]i=S00<0^YIV0;VEI@2iUFD00P2hU6@20;NCH`060;JB
HP2eTF40]Y9R0;JBHP2gTf<0^IEU0P2jUVH0102kUfL0]i=S0;RDI02hU6@20;VEI@80^YIV0P2kUfL2
0;ZFIP80^IEU0P2hU6@00`2gTf<0^YIR0;ZFHP060;ZFHPP0^9=V0`2gTf<20;RDI0<0^IEU0P2gUFL3
0;RFJ0<0^IMY0`2iUFD20;RDI0<0]i=S0`2hU6@40;NCH`X0]Y9R102eTF420;JBHP80]i=S202fU6@8
0;VEI@P0^IEQ0`2gTf<20;RDI0<0^IEU202gTf<30;ZFIP80^IEU0`2hU6@01@2jUFT0^IAX0;VDI`2h
U6@0^9AR0080]i=O00L0]Y=M0;ZFHP2iUF40^9AP0;NCG`2fTUh0]I5M0080]91L202gTf<80;RDI080
^9AP0P2gTel30;JBGP090;FAG@2dT600/hmO0;:>GP2aSEd0/XiN0;>?G`2eTF40]i=S0080]Y9R00@0
]I5Q0;B@H02cSel0/XiN0P2aSEd0202bSUh0]91P0;JBHP2gTf<0^9AT0;NCH`2fTV80]I5Q0`2fT643
0;F?H080]8iO0`2cSel20;B@H0<0]I5Q102gTF850;J@H@P0/hmO00<0]Y9R0;FAH@2cSel00P2aSEd0
102bSUh0/hmO0;B@H02bSeT20;:>FP030;:>G02bSUh0/XeP0080/XeQ00P0/XmE0;>@F02dTET0]I9L
0;FAG@2cSed0/HeM0;2<G0P0/XaM00<0]8iO0;>=GP2cSEh00P2bS5d20;6;G0030;2:F`2bSUh0/XiN
00P0/XiN0`2aSEd01`2cSel0]I5Q0;NCH`2fTEd0]I1L0;:=F@2`ReL00P2_RUH20;2;E`80]8iO0`2c
SEh30;:<G@080;2;EP2`ReL0[hYF0;2:F@2aRe`0]8iQ0;J?I02hTFH20;F?H0<0]8iO0`2cSEh20;B;
G`040;:<G`2aS5l0/HaO0:n=G`80[XiO0`2_SEl30;2>H080/HmQ0`2cSUX20;:=F@<0/HaH402bSUh0
1P2aS5l0/HeM0;6=G@2bSU`0/hmK0;>@FP80]95I0P2`S5`40;6=G@<0/XiN202bSUXH0:n;F`0:0;B?
H`2bSF40/8]N0:j:FP2]REL0[HUE0:j:EP2^ReD0/XeI0;6<F080/8]G0P2^RED00`2]R5@0[8MC0:n;
F`020:n;F`80[XYJ0`2]RET01P2^ReD0[XYF0:j:EP2^RUP0[XYJ0:j9G080[XUM00<0ZhMG0:b8F02^
RUX00P2_Re/0102^RUX0[8QH0:^7E`2/R5P20:f9F@80[XYJ0P2_Re/0102`S5`0[h]K0:j:FP2/R5P2
0:^7E`060:b8F02^RUX0[h]K0:n:GP2^REd0[8MK0P2[QUX00`2/Qe/0[XUM0:n:GP030:b7FP80[HQK
0`2^RE`20:f8G0030:f8F`2^RUX0[XYH0080[h]G00<0[haF0:f:D02]RU001P2]RU030:^7D`<0ZXIB
2P2YQE4A0:Z5D@P0ZhIB00<0ZhMC0:Z6DP2ZQU800P2YQE420:R4D0040:N3C`2VPTP0Yh=90:V5B`80
ZXI<00<0ZHE;0:R4BP2WPdT0202ZQE080:N2CPP0Z8=?0P2YQ4l20:R3CP80Yh9=0P2VPD`40:R3C`@0
Yh9>202VPDd30:V4D080Z8=?0`2WPTh01P2VP5<0YX1A0:N1DP2WPE00Z8=?0:R3CP80ZHA=102XPdh2
0:N2C@80YX5<00P0Xgi90:9mB02RODP0XGa70:9mB02TOdX0Yh9=0:R3CP<0YH1;0P2TOdX30:=nB@03
0:UoC@2XOT`0Yge;0080YWa:00@0Z7i<0:Z0CP2[PDl0ZXAG0P2YPe@00`2YPe80Z8=?0:R3CP020:N2
B`030:N3D`2VPU80Y81@0080XWi>00/0Xgm?0:B0D02UPE40Z8=?0:N2CP2VPDd0YH1<0:J1C@2WPTh0
ZHA@0:^6DP020:R4D080Yh=?0`2VPTh20:F1C@P0YX9>0`2TP4`00`2UPDd0YX9>0:J2CP020:N3C`80
Yh9=00@0YX5<0:F0B`2TOdX0Y7m:0P2SOTT04@2RODT0XGa80:1kA`2ONTH0X7]70:5lB02SOTX0Y7m;
0:UnB`2UNdT0XgU70:AlB`2WPE80Z8=F0:B2E@2QOe80XG]>0080XG]<00<0XG]:0:5lB02QO4L00P2Q
O4D809mjAPP0WWU500<0Wg]709ijAP2MNDD00P2MNDD01`2ONdL0XGe90:9nBP2QO4P0WgY609ehA02L
Md<00P2KMT8209ehA00309mjAP2NNDD0WGQ40080W7M300H0WWU50:1kA`2QO4P0X7]70:9mB@2SOTX2
0:AoB`030:=nBP2RODT0X7]700P0X7]40P2JMT8209]g@`80W7Q40P2MNDD0202PO4P0WWY609ahA02K
Md<0VWI209]g@`2LN4@0WGU5202NNTX01@2ONd/0WWY:09ijBP2MNDT0W7Q80080VgM700<0VWI609eh
@`2MN4<00P2LMd8209]f@@80VWE00`2IMD400`2HM400Ug<o09Mc?`0309Ib?PD0Ug=30`2HM4@209Qd
@080Ug<o00@0UW8n09Ea?@2ELCd0UG4m202DKSl00`2GLTD0UW5409A_@P0209=^@@0409A_@P2EL4<0
UW5409=_?`<0U7100P2ELD4209Ib@P80TVhn0P2AKCd01`2@K3`0Sf/k08m[>`2?Jc/0TVhn09=_?`2D
L4000P2ELD400`2DL400Tflo099^?P04095[?P@0T6Xm00<0TVe0095/?`2?JSd00P2>JC`00`2?JSd0
T6/n095/?`03091_@R_ooooo000Zooooo`<0V6e00P2IKT4309Y_@PP0UF/i202GKC/00`2FJch0Uf`o
09Q]@00309Q]@00309M/?`2FJch0V6hl00L0V6hl00@0VVm209U^@@2IKT40VFi10`2HKD000`2GK3l0
VFlm09U_?@0609U_?@P0W7900P2JL3h209]a?`80W790102MLd4209ab@0<0Vg4o0P2JL3h01@2GK3l0
V6e009Q]@02IKT40VVm20080Vg1300<0W75409ec@@2MLd401P2MLd4809ed@00809ec@@2OMD<0XGM5
0:9hAP2SNDL0XWQ60:5gA@2PMT@30:9gA080XGI30`2PMD800`2PMd<0XGQ40:9iA@020:AkA`030:9i
A@2QN4@0X7M300P0XGM50`2PMT@20:5gA@<0XWQ60`2SNTH30:9iA@80XGQ4202TNDH00`2SN4D0Y7U6
0:EjA`020:IkB0040:EjA`2TNDH0XgQ50:AiCP80Y7U<00<0XgU90:=iA`2RNDD00P2RND<20:MnAP04
0:MnB02WOTX0Ygi:0:MmB`80Yge=202WOTX;0:ImB@<0Ygi:0P2XOd/80:MnBPP0YWe90P2ZPDd20:V0
C0@0Z7m;00<0Ygi:0:QnC02XOT`00`2YOdd30:Z0CPP0ZWmB202XPdl80:V0C080Zh9>0P2/Pdl30:f4
D0030:j5D@2YQ500ZHA@00P0ZHA@102[QU8:0:V4D080[8M@00<0ZhIA0:^6DP2ZQ5<00P2ZQ5D00`2Z
Q5L0ZhIB0:^6DP070:^6DP080:b7D`2]R5@0[XUE0:j9E@2]R5@0[8MC0:^6DP2/Pdl30:f4D080[XEA
0P2_QU880:j4DP<0[hIB0P2`Qe<30;68E0`0[HQD1`2/Qe<30:^6DP80ZXEA202/Qe<20:R3C`80ZHA@
102ZQE400`2[QU80ZXEA0:Z5D@020:V4D0030:R3C`2WPTh0YX5=00T0YX5=00D0Z8=>0:N2C@2WPTd0
YX5<0:F0B`020:AoBP030:=nB@2TOdX0Y7m:00H0Y7m:0`2RODP20:=nB@<0Y7m:0`2RODT30:5lB080
X7]7202PNdH80:5lB00609mkA`2NNTH0WWY609eiA@2LN4@0VgM30P2JMT8309ehA080W7M30`2KMT80
1@2SOTX0XWe909mjAP2LMd<0VWE100<0VGA00`2KMdL209YfAP<0VGE5202JMD4309UcA080VWA50`2K
MDH0102GLcl0V7A009Qd@02HM40409Ue@@P0V7<o0`2GLcl309Qd@080VGE100@0Ug<o09Qd@02HM400
V7A00P2IMD4209Yf@PT0V7A00P2HM4@209Mc@`<0UW9200L0UG5109Ib@P2GLd<0Ug=309QdA02IMDD0
VWI60080VgM7202JMT801P2FMd40UgQ209Qg@P2KMd<0W7Q409iiA@80XGU600H0VgE609afA`2MMdP0
WWQ909miBP2QNd`20:9lC@L0X7a8102ONdL309ijAP80WGU50P2ONdL30:1lB0<0XGe90P2NNTH209mk
A`<0X7a800L0XGe90:AlB02UODX0Xgi:0:9nC02SOdl0XGmA0080XH1C202UPDd0102VPTh0Yh=?0:N3
C`2WPdl20:R4D080ZHEA00P0ZHAG0:R4E02WPe<0YX9@0:J2CP2WQ4h0Z8E=0:V6CPP0ZhIA0P2WPdl2
0:R4D0040:V5D@2ZQU80ZhMC0:^7D`80ZXM?00<0ZXMA0:Z6DP2ZQU@00P2ZQUH0102ZQEP0[HUE0:f9
E@2]RED30:b8E080ZhMC0`2_REX20;2:F`<0/H]L0P2^RUX00`2_Re/0/8aL0;6=G@020;:>GP030;>?
G`2dSf80]8mR0080]8mR0P2eT6<30;JAI0P0]I5Q0P2cSe/20;B@G0040;FAG@2fTUh0]i=O0;NCG`80
]Y9R0`2eTF430;B@H080]I5Q00@0]Y9R0;NCH`2hU6@0^IEU0P2jUVH80;RCIP<0^IEU0P2hU6@30;NC
H`P0^9=V202hU6@80;NCH`<0^IEU0P2hU6@30;NCH`80]Y9R00@0]i=S0;RDI02hU6@0^IEU0P2jUVH4
0;RDI080^IEU102jUVH20;VEI@@0^9AT202jUV880;RCIP<0]i=S0P2hU6@30;VEI@80^IMY0`2hUVP3
0;NEI`<0^IEU0P2hU6@30;NCH`<0^IEU0P2hU6@0102gTf<0]Y9R0;JBHP2eTF480;JBHP<0]I5Q0P2f
TV830;NCH`P0]YAT202iUFD80;VEH@<0^IEU0P2hU6@;0;NCH`80^YIV0P2iUFD30;RDI0060;NCH`2i
U6P0^IAX0;VDI`2hU6@0^9AR0P2gTel01P2gU5h0^IEQ0;VEH@2hU600]i=O0;JBGP80]I5M00<0]91L
0;NCH`2gTf<03P2gTf<30;NCG`80]Y9N0`2eTEd20;B@H0<0/hmO00<0]91P0;JBHP2gTf<00P2gTf<0
102fTV80]I5Q0;FAH@2dT6020;>?G`080;:>GP2dT600]Y9R0;NCH`2hU6@0]i=S0;JBHP2eTF430;J@
H@<0]HmP0P2dSUl0102bSUh0/hmO0;>?G`2cSel20;B@H080]I5Q2@2fT6480;>?G`80]I5Q00<0/hmO
0;:>GP2aSEd00P2bSUh01`2cSel0/XmI0;:>FP2bSUX0/XiL0;:>GP2bSF000P2bSF40202bSeL0/i1H
0;BAF`2eTEd0]I5O0;>?G`2aSEd0/8]N202bS5d0102eSf00]8iO0;B>G`2dSUl30;>=GP030;:<G@2b
SUh0/XiN00H0/XiN00<0]91P0;>?G`2bSUh00P2aSEd01`2bSUh0/hmO0;B@H02fTEd0]8mK0;:=F@2`
ReL00P2_RUH0102`ReL0/HaH0;B>G`2dSUl30;>=GP<0/XaM00T0[hYE0:j9E@2^RED0[XQG0;2:F`2b
S5l0]HiS0;J?I02bS5d00`2cSEh40;B>G`80]8]O00@0/XaO0;6<G`2aS5l0[heO0P2^SUl30:n=G`<0
/8iP0P2aSf420;F@G080]8mK0P2cSUX20;:=F@P0/HeM202bSUh0202_RUd0/8aL0;2<G02`S5X0/HeI
0;6>F02aSUH0/XmG0`2_Re/40;2<G080/HeM202bSUXH0:n;F`080;>>HP2bSF40/8]N0:j:FP2^RUP0
[HUE0:j:EP2^ReD80:n:EP<0[h]K0P2^RUX30:f9F@060:j;E@2^RUH0[XYF0:j:F02^RUX0[XUL0P2^
REd00`2/R5P0[HUI0:j:FP020:n;F`030:j:FP2]RET0[8QH00<0[HUI0P2^RUX30:n;F`030:j:FP2]
RET0[8QH0080ZhMG00H0[8QH0:f9F@2^RUX0[XUL0:f8F`2/QeX20:^6F@030:b7FP2]R5/0[XUL00<0
[HQK0P2^RE`30:n:G@80[hYN00<0[hYM0:j:FP2^RUP00P2]RED00`2]RU@0[8UA0:b9D@060:b9D@<0
ZhMC0`2ZQU820:V5D@P0ZXIB202ZQE4A0:^6DP<0ZXIB0P2YQE430:R4D0030:J1BP2WPT/0Z8=<0080
ZHA=00<0Z8=<0:J1BP2UP4T0202YQ4l80:J1C@P0Z8=?0P2YQ4l20:R3CP80Yh9=0P2VPD`01@2ZQE40
ZHA@0:V4D02XPdl0Yh9>0080YX5=00<0YH1<0:J1C@2VPDd01P2VPDd40:V4D0@0ZXEA00P0YX1C0:N1
DP2WPE80Yh5@0:R3C`2XPdh0Z8=<0:V4C@<0Z8=>0P2WPTd30:J1C0090:=nB@2RODP0XWe80:5lA`2R
ODP0Y7m:0:N2C@2XPdh0YX5<00<0YH1;0P2TOdX20:=nB@030:UoC@2XOT`0Yge;0080YWa:00d0Z7i<
0:Z0CP2[PDl0ZH=F0:V3E02XPU<0Z89A0:N2CP2WPTd0Yh9;0:J1BP2UPE40Y81@00<0Xgm?00D0YH5A
0:J2DP2WPe<0Z8=?0:N2CP030:J1C@030:R3C`2YQ500ZXEA0080Z8A@0P2WPdl30:J2CP80YH5=202V
PTh20:B0C0<0YH5=0`2VPTh30:F0B`D0Y7m:0140XWe90:5lB02PNdL0WgY60:1kA`2QO4P0Xgi:0:Ao
B`2ZOd`0YWa:0:EkB@2UOD`0YGm@0:F0D`2QOe80Wge@0:5kCP020:5kC0030:5kBP2QO4P0XGa70080
XGa5202ONTH809iiA@0809mkA`2NNTH0WGU509ahA02MNDD0WWY60:1lB02QODT209iiA@0409ag@`2K
MT80VgI209]f@P80W7M300<0X7]709mjAP2NNDD00P2NNDD01P2PNdL0XGa80:9mB@2PNdL0XGa80:=n
BP80Y7m;00<0Xgi:0:5lB02PNdL0202ONTD309]g@`<0W7Q40P2MNDD0202PO4P0WWY609ahA02KMd<0
VWI209]g@`2LN4@0WGU5302MNDT409ahB0<0WWU40P2MN4<309ag@P@0VGE10P2HM40209Mc?`0309Ib
?P2GLd<0Ug=300H0Ug=30`2GLcl309Ib?P80UG4m202EKd00202HLdH0UW5409A_@P2CKT40TVe009=^
@@2DKd80UG130`2CKcl209A`@0<0UG5100@0TVhn095]?@2AKCd0TFdm0`2@K3`0102?Jc/0TFdm099^
?P2DL40209Ea@@0309A`@02BKSh0TFdm00<0SVPk0P2?JC`3091Z?@03095/?`2@Jch0SfXm0080SVTl
00<0SfXm091[?P2AK3l00`2?KCl[ooooo`00:_ooool209M/?`<0V6e00`2IKT4809E[>`P0Ufdk00<0
UV/n09M/?`2GK3l0102GK3l00`2FJch0V6hl09Q^?00609Q^?080Vg1300@0VVm209U^@@2GK3l0UV/n
0P2EJSd809U_?@P0W7900P2JL3h209]a?`80W790102MLd4209ab@0<0Vg4o0P2JL3h209M/?`0409Q]
@02IKT40Vg1309aaA080WG95202MLd4309ac?`@0WGA000T0WWE109ec@@2OMD<0XGM50:9hAP2SNDL0
XWQ60:5gA@2PMT@00P2RMd@20:5f@`80X7E20P2OM4400`2PMd<0XGQ40:9iA@020:AkA`030:9iA@2Q
N4@0X7M30080XWQ600@0XGM50:1fA02PMT@0WgE30P2NM4820:1fA080XGM50P2RN4H20:=iA`<0XWU5
0`2QN4@20:1g@`P0XgY600<0XWM40:AiAP2UNTL00P2VNdP00`2UNTL0Y7U60:9gA0020:=hB`040:=i
B@2SNDL0XgY60:=jA080XgY20P2XOdL0102XOdT0Z7m;0:QoB`2XOT`20:QnCPP0YWe900<0Ygi:0:Im
B@2VODT00P2VODT30:ElB0<0YWe90`2WOTX20:QoB`P0Ygi:0`2VODT20:ElB0<0Y7]70`2YP4`40:Qo
B`80Ygi:0P2XOT`30:UoC@<0ZX1>202ZOe880:R3C`P0ZH1<0`2[PTh20:b3C`<0[HA@202YQ5080:Z5
D@P0ZHA@0P2[QTl00`2ZQE00ZXEA0:Z4D`020:Z4E@030:Z4E`2ZQE40ZXEA00H0ZXEA00<0ZhIB0:b7
D`2]R5@00P2^RED00`2]R5@0[8MC0:^6DP030:f4D080[XEA0`2_QU880:j5D@<0[hIB0`2`Qe<20;68
E0P0[XUE00D0[hYF0:j9E@2^RED0[HQD0:b7D`020:^6DP040:Z5D@2/Qe<0[8MC0:b7D`<0ZhIB0P2Z
QE480:b7D`<0ZHA@0`2ZQE450:^6DP040:Z5D@2YQ500Z8=?0:N2CPX0YX5=0P2YQ500102XPdl0Yh9>
0:F0C02TOd/20:=nBPP0YH1;102SOTT40:AoBPP0XWe9202QO4L80:=nBP80Wg]70P2NNTH0102MNDD0
W7Q409ahA02LN4@309iiA@80WGQ40`2LMd<01P2RODT0XGa80:1kA`2NNDD0WGQ409ag@`80VgI20P2L
N4P309]gA`<0VWI6202KMT80102JM4D0VgE609]eAP2KMDH209afA`80WGM800H0UW8n09Mc?`2GLcl0
V7A009Ue@@2JMT8209]g@`P0VGA00P2GLcl00`2HM400VGE109Yf@P0209]g@`0309ahA02HM400VGE1
0080VGE10P2JMT8209]g@`T0VGE10`2IMDD209QdA0<0Ug=30P2HM4@209UeA@80VWI60P2KMdL809ah
A080V7U300@0VWU409eiA@2NNTH0WgY60P2RNTL209egB00409ihB@2ONDX0X7Y;0:5kC080XWa=0P2P
O4P20:5mB@050:9nBP2SOd/0Xgm;0:=oB`2ROTX00P2QODT03@2PO4P0Wg]709ijAP2NNTH0WGU509mk
A`2PO4P0XGe90:9nBP2SOd/0Y81<0:F1C@2VPTh00`2PO4P30:5mB@80XWi:00H0YGe<0:InC@2TOTd0
Xgm?0:B0D02RP5020::2D`P0YX9>00@0Yh=?0:R4D02XQ500Z8A@0P2YQE420:Z6DP080:Z5F02YQED0
Z8AD0:N3D@2WPdl0Z8E?0:V6CP2ZQdl80:^6D@80Z8A@0P2YQE40102ZQU80ZhMC0:^7D`2[Qe<20:^8
D0030:^8DP2[Qe<0ZhME0080ZhMG00H0ZhII0:n;E`2^RUH0[XYF0:f9E@2/R5@20:^7D`040:Z6DP2`
RU/0/8YK0;2:F`80/H]L0`2bS5d20:j:FP80[h]K00@0/8aL0;6=G@2aSEd0/HeM0`2dT6030;FAH@<0
]Y9R202eTF430;B@G0030;FAG@2fTUh0]Y9N0080]i=O0P2eTF420;B@H0@0/hmO0P2fTV80102gTf<0
^9AT0;VEI@2jUVH20;^GI`P0^9=V0`2iUFD20;RDI0<0]i=S202hTfHH0;RDI0030;JBHP2gTf<0]i=S
0080^9AT0P2iUFD00`2jUVH0^9AT0;RDI0040;RDI0@0^IEU1P2hU6@80;ZFI0P0^9=V0`2gTf<20;RD
I0<0^IEU00D0^YQZ0;VGJ@2iUfT0^9IX0;NEI`020;JDIP040;FCI@2iUFD0^IEU0;VEI@80^9AT0`2g
Tf<30;ZFIP030;VEI@2hU6@0]i=S0080]Y9R00<0]I5Q0;NCH`2gTf<01P2gTf<20;FAH@80]Y9R0P2g
Tf<20;RDI0P0]YAT202hU6@80;RDH080^YIV00@0^IEU0;RDI02hU6@0]i=S0P2fTV880;NCH`<0^IEU
0`2hU6@20;NCH`80^9=W00<0^9=V0;RDI02hU6800P2hU6001@2hUEl0^9AR0;RDHP2hU680]i=Q0080
]Y9P0P2eTEl@0;NCH`80]i=O0`2fTUh30;FAG@@0]91P00D0]I5Q0;JBHP2fTV80]i=S0;RDI0020;NC
H`80]Y9R0P2eTF402@2dT600/XiN0;B@H02fTV80]i=S0;RDI02gTf<0]Y9R0;FAH@030;J@H@<0]HmP
0P2dSUl20;:>GP<0/hmO0`2dT6050;F?H0@0]Y1Q202cSel0102eTF40]91P0;B@H02cSel40;:>GP06
0;:?F@2bSUX0/XiJ0;:>G02bSUh0/XeP0P2bSF40202bSeT0/i1J0;B@G02eTEl0]I5Q0;>>H@2aS5l0
/8]O202cSEh40;F?H0@0]8iO202bSUh00`2eTF40]91P0;:>GP020;2<G00;0;6=G@2bSUh0/hmO0;F@
G02dSe/0/XeI0;2;E`2_RUH0/8]G0;6<F02bSET00P2dSUl30;>=GP<0/XaM00P0[XUD0:f8E02]R5@0
[HMF0:n9FP2aReh0]8eR0;F>H`80/H]L00@0/XaM0;>=GP2cSEh0]8iO0P2eSf020;B;G`040;:<G`2a
S5l0/HaO0:n=G`80[XiO0`2_SEl30;2>H080/HmQ0P2fT5l20;F?GP<0]8iM00<0/heL0;6=G@2aSEd0
1P2aSEd80;:>GP060:n:G@2_Re/0[h]K0:n;F@2_ReL0[haF0P2_S5@50:j:FP80[h]K0P2`S5`80;:>
FQP0[h]K0P2aS6000`2`Reh0[h]K0:j:F0020:j:EP040:j;E@2]R5@0[HQD0:j9E@80[hYF00<0/8]G
0;6<F02aS5P00`2_Re/20:j:FP<0[HUI00H0[X]E0:j:EP2^RUH0[XYH0:j:FP2^RE`20:j9G@030:f9
F@2^RUX0[XYJ00@0[XYJ00<0[HUI0:j:FP2^RUX01P2^RUX30:f9F@80[8QH1P2]RET20:b8F0<0[HUI
0`2^RE`30:n:G@80/8]N0P2`Rel01@2_RUd0[XYJ0:j:F02]RED0[8QD00T0[8UC0`2[Qe<30:Z6DP80
ZHEA202ZQU820:^6DP@0ZXEA0P2YQ50A0:^6DPP0ZHEA00P0YX5<0:N2C@2XPdh0ZHA?0:R3CP2WPTd0
YH1;0:AoBPP0ZHA?202TOd/80:R3C`80ZHA?0P2XPdh20:N2C@80YX5<00P0ZhIB0:Z5D@2YQ500Z8=?
0:N2CP2VPDd0YH1<0:AoB`P0YX5=00D0Z8=?0:V4D02YQ500ZXEA0:^6DP020:b7D`070:f8E02WPE@0
Yh5B0:N1DP2WPE00Z8=?0:R3CP020:R3C080Z8=>0P2WPTd20:J1C080YH1;00P0Xgi90:9mB02RODP0
XGa70:9mB02TOdX0Yh9=0:R3CP80YX5<0`2UP4/30:AoBP030:UoC@2XOT`0Yge;0080YWa:00T0Z7i<
0:Z0CP2[PDl0Z89E0:R2D`2WPE80Yh5@0:J1C@2VPD`00P2VPDX20:=oC`80Y81@00@0YH5A0:J2DP2W
Pe<0Z8AD1@2WPTh00`2XPdl0ZHA@0:V4D0020:R4D080Yh=?0`2VPTh20:F1C@P0YX9>1P2UPDd20:J2
CP<0Xgi90P2TOdX30:F0B`0A0:9mB@2QO4P0X7]709mjAP2PNdL0XGa80:=nBP2TOd/0ZWm<0:MmB`2V
O4X0YGe<0:=mCP2ROE00Wge@09ekCP2QNdh00P2QNd`00`2QNdX0XGa80:5lA`020:5lA@P0X7]7202N
NDD00`2ONdL0WWY609eiA@0209ahA00309ijAP2PO4P0XGe900<0W7M3102KMT800`2LMd<0X7]70:1k
A`030:1kA`060:5lB02RODT0XWe90:1kA`2QO4P0XWe90P2SOTX00`2RODT0XGa80:1kA`0809mjAPH0
W7Q40P2MNDD0202PO4P0WWY609ahA02KMd<0VWI209]g@`2LN4@0WGU5202MNDT0102KMdL0W7Q809ah
B02LN4P309eiB@0409ijBP2ONTD0WgY509mjA@80WWU40`2MN4<209Qd@00409Ue@@2JMT80VWI209Ue
@@80V7A000<0Ug<o09Mc@`2GLd<00P2GLd<409Ib@P80Ug<o1P2FLSh809I`@@0409QcAP2FLD@0U6m2
09=^@@80TVe000<0Tfi109A_@P2BKSh00P2BKSh209=_?`<0U7102@2AKCd01`2BKSh0Tflo09Ea@@2E
LD40Tflo099^?P2AKCd00P2<IST0102=IcX0SVPk08iX>`2?JC`2091Z?@0408mZ?@2>JC`0SVTl08iY
?080SfXm0P2@Jch308m[>b_ooooo000Zooooo`80UV/n0P2GK3l409Q]@0P0UFXm202FK3X00`2GK3l0
UV/n09I[?P0409I[?P0309M/?`2HKS`0V6hl00H0V6hl0P2KL4<0102JKd80V6e009M/?`2EJSd209AY
?0P0VFlm202LLT0209Y`?P80Vg4o0P2LLT0409ec@@80W7900`2KLCl209Y`?P0809M/?`2HKD00VFi1
09Y_@P2KL4<0W75409ebA@2NLdH809ec@@80Vg8n0P2LLcl0302MM400WWE109ie@@2NMD40WG=109me
@`2QMdD0XWQ60:=iA`2RN4H0XGM50:1fA0<0XGI30P2PMD8309md@@030:1g@`2QN4@0XWU50080Y7]7
00P0XWU50:5hA02PMd<0XgU70:9hAP2QMdD0X7I409me@`80WWA200@0WG=10:5gA@2QMdD0XGM50P2R
N4H30:=iA`<0XWU50`2QN4@20:1g@`P0XWY600<0XWM40:=hA@2TNDH00P2VNdP00`2TNDH0XgQ50:9g
A0020:=iB@040:=iA`2SNTH0XgY40:=j@P80Xg]00P2WOTH0102WOTP0Ygi:0:MnBP2WOD/20:MmC@P0
YGa80P2WOTX20:ImB@040:ElB02TNdL0Y7]70:AkA`<0YWe90`2WOTX20:QoB`P0Ygi:0`2VODT20:El
B0<0Y7]70P2YP4`30:QoB`@0Ygi:0P2XOT`30:UoC@<0ZX1>202YOU480:R3C`P0ZH1<0P2ZPDd20:^2
CP80[8=?0P2]Q5080:V4D0P0ZXEA202YQ5020:V4C@030:Z5D02ZQE40ZXAC0080ZXAE00<0ZXAG0:Z5
D@2ZQE401P2ZQE400`2[QU80[8MC0:f8E0020:j9E@030:f8E02/Qe<0ZhIB0080[HA@0P2^QE420:n6
DP80/8MC2P2^QE430:n6DP<0/8MC202^RED01@2_RUH0[XUE0:j9E@2]R5@0[8MC0080ZhIB00@0ZXEA
0:b7D`2/Qe<0[8MC0`2[QU820:Z5D@P0[HQD0P2YQ5030:Z5D@H0ZhIB00@0ZXEA0:V4D02YQ500Z8=?
2P2WPTh0202ZQ5<0ZH=B0:R2D@2WPE00YX1?0:EoCP2TOTd0Xge<202UP4/80:AoBPP0Xgi:202RODP8
0:=nBP<0Wg]7102NNTH0102MNDD0WgY609mjAP2ONTH209iiA@<0WGQ40P2NNDD00`2ONTH0X7]70:1k
A`030:1kA`80WGU90P2LN4P409]gA`P0WGQ40`2LMTL209egB0<0WWQ90P2HM400102IMD40VWI209]g
@`2KMd<209ahA0P0VWE100H0V7A009Ue@@2IMD40VWI209]g@`2LN4@209eiA@80VGE10P2JMT8309]g
@`0309ahA02KMd<0VgM300L0VgM300@0VgM709YfAP2JMTH0VWI60P2IMDD209QdA0@0VWI6102KMdL8
09eiA@80VGY400@0VgY509ijAP2ONdL0XGa80P2TO4T01@2NN4T0WgU:09miBP2PNT/0XG]<0080XWa=
00L0Xge>0:1lB02PO4P0XGe90:9nBP2SOd/0Y81<0080YH5=0P2SOd/0102ROTX0XGe90:5mB@2PO4P2
09mkA`080:1lB02QODT0XWi:0:=oB`2UPDd0YX9>0:N3C`2XQ5020:5mB@<0XWi:0`2SOd/20:ImD@06
0:EoD02TP500YH5A0:>2C`2RPTl0Xh=@202WPdl20:R4D080ZHEA0`2ZQU802@2[Qe<0ZhII0:Z6EP2Y
QED0Z8AB0:R4D02YQU00ZXM?0:^8D0080:b7DP<0ZXIB102[Qe<01P2/R5@0[8UA0:b9D@2/RE<0[8QD
0:b8EP80[8QH00@0[8MJ0:n;E`2_ReL0[XYF0P2]RED00`2/R5@0ZhMC0:^7D`030;6;G080/XaM0`2c
SEh20:n;F`<0/8aL0`2aSEd40;FAG`<0]Y9P0P2gTf480;JBHP<0]I5M102fTUh00`2gTel0]I5Q0;FA
H@020;B@H0@0/hmO0P2fTV80102gTf<0^9AT0;VEI@2jUVH20;^GI`P0^9=V0`2iUFD20;RDI0<0]i=S
202hTfHH0;RDI080]i=S102hU6@20;VEI@H0^9AT102gTf<60;RDI0P0^IEU202hTfH30;NCH`80^9AT
0`2iUFD20;VGJ@040;RFJ02gUFL0]iEW0;JDIP80]I=U0`2iUFD20;RDI0<0]i=S0`2jUVH20;VEI@04
0;RDI02gTf<0]i=S0;JBHPP0]i=S0`2fTV820;NCH`<0^9AT202fU6@80;RDI0P0^9AP0P2jUVH0102i
UFD0^9AT0;RDI02gTf<20;JBHPP0]i=S0P2iUFD30;RDI0<0]i=S0P2hTfL00`2hTfH0^9AT0;RDHP02
0;RDH0030;REG`2hU6@0]i=S00<0]i=S0`2fTV8@0;NCH`<0]Y9N0`2eTEd20;B@G0040;B@H02eTF40
]I5Q0;JBHPH0]i=S102fTV820;FAH@080;:>GP2dT600]Y9R0;NCH`2hU6@0]i=S0;JBHP2eTF430;J@
H@<0]HmP0P2dSUl30;:>GP<0/hmO0P2dT600102cSEh0]8iO0;B>G`2dSUl20;F?H080]Y1Q00<0]i5R
0;>?G`2cSel01P2cSel40;B@H0050;>?G`2bSUh0/XiN0;6=G@2bSeT00P2bSUX00`2bSU`0/XiN0;:=
H0020;:=H@080;:>FP2cSe/0]91N0;FAH@2eT6<0/hiR0;6<H02`Rf480;>=GP@0]8iO102eSf080;:>
GP0;0;B@H02cSel0/HeM0;2<G02_Re/0/8aL0;6=G@2bSUh0]8mK0;>>FP2aS5P00`2`ReL20;:=F@80
]8iO0`2cSEh30;:<G@090:j9E02]R5@0[HQD0:f7EP2_REX0/H]N0;B=HP2eSV<0/8YK0080/H]L00D0
/XaM0;>=GP2dSUl0]8iO0;F?H0020;B;G`040;:<G`2aS5l0/HaO0:n=G`80[XiO0`2_SEl30;2>H080
/HmQ0P2fT6420;F?H0<0]8iO00<0/heN0;2<G02`S5`01P2`S5`80;:>GP060:n:G@2_Re/0[h]K0:n;
F@2^RUH0[X]E0P2^Re<50:j:FP80[h]K0P2`S5`80;:>FQP0[h]K0P2`Rel0202`Reh0/8aL0;2<FP2_
ReL0[XYF0:j;E@2/Qe<0[HQD0P2^RED20;2;E`030;6<F02bSET0[h]K0080[h]K0P2^RUX30:f9F@06
0:j;E@2^RUH0[XYF0:j:F02^RUX0[XUL0P2^REd00`2_Re/0[XYJ0:j:FP040:j:FP030:n;F`2^RUX0
[XYJ00H0[XYJ00<0[8QH0:f9F@2]RET0102]RET00`2/R5P0[8QF0:f9E`050:f9E`030:b8EP2]R5/0
[HQK0080[XUL0`2_RUd02@2`Reh0/8]O0;2;G`2_RUd0[XYJ0:j:F02]RED0[8QD0:b9D`080:^8DP<0
ZhMC0`2ZQU820:V5D@P0ZhMC00<0[8MC0:^6DP2[QU800P2ZQE420:V4D0030:R3C`2/Qe<0[8MC00L0
[8MC202[QU880:V5D@030:N2C@2XPdh0ZHA?0080ZHA?00<0Yh9=0:F0B`2TOdX0202YQ4l80:AoB`P0
Z8=?0P2YQ4l20:R3CP80Yh9=0P2VPD`0202[QU80ZXEA0:V4D02XPdl0Yh9>0:J1C@2UP4`0Y7m;202V
PDd01@2XPdl0ZHA@0:V4D02ZQE40ZhIB0080[8MC00L0[HQD0:R2E@2XPU<0Z89C0:R2D@2WPTh0Yh9=
0080Yh9;0`2WPTd20:J1C0<0YH1;00P0Xgi90:9mB02RODP0XGa70:9mB02TOdX0Yh9=0:R3CP<0YX5<
0`2UP4/20:AoBP030:UoC@2XOT`0Yge;0080YWa:00T0Z7i<0:Z0CP2[PDl0Yh5D0:N1DP2VP540YX1?
0:J1C@2UP4/00P2UP4T20:=oC`030:B0D02VPU80YX9B00<0Yh=C0P2VPDd00`2WPTh0Z8=?0:R3C`03
0:R3C`80Z8A@0P2WPdl30:J2CPX0YH5=0P2VPTh60:F1C@040:9mB02SOTT0Xgi90:=nB@<0Y7m:00X0
YH1;0:9mB@2QO4P0X7]709mjAP2PNdL0XGa80:=nBP2TOd/0Z7e:0P2WOD/00`2UOD`0XG]<09mjC@02
09ekCP060:5kCP2QNd`0XG]<0:5kBP2QO4P0XGa70P2QO4D80:1kA`P0WWU500P0WWY609eiA@2LN4@0
VgM309ahA02MNDD0Wg]70:5mB@80VgI21P2LMd<209mjAP030:1kA`2QO4P0XGa800<0XGa800<0WgY6
0:1kA`2RODT00P2SOTX00`2RODT0X7]709mjAP0809miB0H0WGU50P2LN4@0202PO4P0WWY609ahA02K
Md<0VWI209]g@`2LN4@0WGU5202LN4P0102KMdL0W7Q809ahB02LN4P309eiB@0409ijBP2ONTD0WgY5
09mjA@80WWU40`2MN4<00`2FLSh0V7A009Yf@P0209]g@`0509Yf@P2HM400V7A009Mc?`2HM4@00P2G
Ld<209Ib@P80UG5100<0U71009Ib?P2FLSh0102FLSh209Mc?`P0UW1100@0V7=609MbA@2DKd80TVe0
0P2AK3l2099]@0<0TFdm0P2BKSh309=_?`@0TFdm102BKSh00`2@K3`0TVhn09=_?`0209A`@00309=_
?`2BKSh0T6`l0080S6Hi00@0SFLj08iX>`2>J3/0SfTl0P2@JSd00`2<IcX0SFPk08iY?00208mZ?@<0
T6/n0`2>JSP[ooooo`00:_ooool209I[?P80Uf`o102HKD0809EZ?@P0UV`j00<0Uf`o09I[?P2FJch0
102FJch00`2GK3l0V6hl09Q^?00609Q^?080Vg1300@0VVm209Q]@02GK3l0UFXm0P2DJC`809U_?@P0
W7900P2JL3h209]a?`80W790102MLd4209ab@0<0Vg4o0P2JL3h0202GK3l0V6e009U^@@2JKd80Vg13
09aaA02MLTD0WW=6202MLd4209]b?P80W7<o00`0WGA009ie@@2NMD40WWE109ec@@2OMD<0XGM50:9h
AP2SNDL0XWQ60:5gA@2PMT@30:5f@`80X7E20`2OM4400`2PMd<0XGQ40:9iA@020:AkA`080:9iA@2Q
N4@0X7M30:=iA`2RN4H0XGM50:1fA02OMD<209id@P0409ec@@2QMdD0XGM50:5gA@80XWQ60`2SNDL3
0:9iA@<0XGQ40P2PMd<80:9jAP030:9gA02SN4D0Y7U60080YW]800<0Y7U60:=hA@2RMd@00P2SNDT0
102SNDL0XgY60:=jA02SNT820:=k@080Ygi600@0Ygi80:MnBP2WOTX0Yge;0P2WODd80:ElB080Ygi:
0P2VODT0102UO4P0Y7]70:AkA`2TNdL30:ImB@<0Ygi:0P2XOd/80:MnBP<0YWe90P2UO4P30:AkA`80
ZH1<0`2XOd/40:MnBP80Z7i<0`2YOdd30:Z0CPP0ZGiA202XPdl80:V0C080ZX5=0P2[PTh20:b3C`80
[HA@202YQ5080:Z5D@P0ZHA@0P2YQ4d00`2ZQE00ZXEA0:Z4D`020:Z4E@030:Z4E`2ZQE40ZXEA00H0
ZXEA00<0ZhIB0:b7D`2]R5@00P2^RED00`2]R5@0[8MC0:^6DP020:f4D080[XEA0P2_QU820;27D`X0
[XEA0`2_QU830;27D`P0[XUE00D0[hYF0:j9E@2^RED0[HQD0:b7D`020:^6DP040:Z5D@2/Qe<0[8MC
0:b7D`<0ZhIB0P2ZQE480:f8E080ZHA@0`2ZQE460:^6DP040:Z5D@2YQ500ZHA@0:R3C`X0Yh9>00P0
ZXAC0:V3DP2XPU40Yh5@0:J0C`2UOdh0Y7i=0:=mC0P0YH1;202TOdX80:=nBPP0XWe8202SOTX309mk
A`@0WWY600@0WGU509mjAP2ONTH0WgY60P2NNDD309ehA080WWU500<0WgY60:1kA`2PNdL00`2PNdL2
09eiB@80W7Q8102KMdL809ehA0<0W7I70P2MMdP309ihB@80V7A000@0VGE109Yf@P2KMd<0VgM30P2L
N4@809Ye@@0609Qd@02IMD40VGE109Yf@P2KMd<0W7Q40P2MNDD209Ue@@80VWI20`2KMd<00`2LN4@0
VgM309]g@`0709]g@`0409]gA`2JMTH0VWI609YfAP80VGE50P2HM4@409YfAP@0VgM7202MNDD209Uj
A00409]jA@2NNTH0Wg]70:5lB080Y7a900D0WWQ909miBP2ONDX0X7Y;0:5kC0020:9lC@070:=mCP2P
O4P0X7a80:5mB@2ROTX0Xgm;0:B0C0020:F1C@80Xgm;00@0XWi:0:5mB@2QODT0X7a80P2ONdL0202P
O4P0XGe90:9nBP2SOd/0YH5=0:J2CP2WPdl0Z8A@0P2QODT30:9nBP<0Xgm;0P2VOE401P2UOe00Y81@
0:F1D@2SPTl0XX9?0:>3D0P0Yh=?0P2XQ5020:V5D@<0ZXIB00T0ZhMC0:^6F@2ZQUH0ZHEE0:R4DP2X
Q500ZHI@0:Z7C`2[R500202/Qe830:Z6DP@0ZhMC00H0[8QD0:b9D@2/RE40[8UC0:b8E02/R5H20:b8
F0040:b7FP2_ReL0[h]G0:j:EP80[HUE00<0[8QD0:^7D`2[Qe<00`2aRe`20;:<G@<0/heN0P2_Re/3
0;2<G0<0/HeM102eTEl30;JBH080]i=Q202fTV830;FAG@@0]Y9N00<0]i=O0;FAH@2eTF400P2dT604
0;>?G`80]Y9R00@0]i=S0;RDI02iUFD0^YIV0P2kUfL80;RCIP<0^IEU0P2hU6@30;NCH`P0^9=V602h
U6@20;NCH`@0^9AT0P2iUFD60;RDI0@0]i=S1P2hU6@80;VEI@P0^9=V0`2gTf<20;RDI0<0^IEU0P2i
UfT0102hUVP0]iEW0;NEI`2fU6H20;FCI@<0^IEU0P2hU6@30;NCH`<0^YIV0P2iUFD0102hU6@0]i=S
0;NCH`2fTV880;NCH`<0]Y9R0P2gTf<30;RDI0P0]YAT202hU6@80;RDH080^YIV00@0^IEU0;RDI02h
U6@0]i=S0P2fTV880;NCH`80^IEU0`2hU6@30;NCH`80^9=W00<0^9=V0;RDI02hU6800P2hU6000`2h
UEl0^9AT0;NCH`030;NCH`<0]Y9R402gTf<30;JBGP<0]I5M0P2dT5`0102dT600]I5Q0;FAH@2fTV86
0;NCH`@0]Y9R0P2eTF40202bSUh0]91P0;JBHP2gTf<0^9AT0;NCH`2fTV80]I5Q0`2fT6430;F?H080
]8iO0`2bSUh30;>?G`80]91P00@0/heN0;B>G`2dSUl0]8iO0P2eSf020;J@H@030;NAHP2cSel0/hmO
00H0/hmO102dT6001@2cSel0/XiN0;:>GP2aSEd0/XmI0080/XiJ00<0/XiL0;:>GP2bSF000P2bSF40
202bSUX0/hmK0;B@GP2eTF40]I1S0;>>HP2aS600/8]Q202cSEh40;B>G`@0]HmP202bSUh02`2dT600
/hmO0;6=G@2`S5`0[h]K0;2<G02aSEd0/XiN0;B?F`2cSUX0/HaH00<0/8]G0P2bSET20;B>G`<0/heN
0`2bS5d02@2^RE@0[HQD0:f8E02]QeH0[hUJ0;6;GP2dSF80]HiS0;2:F`020;6;G0050;:<G@2cSEh0
]8iO0;B>G`2eSf000P2dRel0102bS5l0/HaO0;6<G`2_SEl20:j>G`<0[heO0`2`SV020;6?H@80]Y1Q
0P2eSf030;B>G`030;>=GP2`S5`0/8aL00H0/8aL202bSUh01P2_RUd0[h]K0:n;F`2_ReT0[XYF0:j;
E@80[X]C1@2^RUX20:n;F`80/8aL202bSUXH0:n;F`80/8]O00P0/8]N0;2<G02`S5X0[h]G0:j:EP2^
ReD0[8MC0:f8E080[XUE0P2`ReL00`2aS5P0/XeI0:n;F`020:n;F`80[XYJ0`2]RET01P2^ReD0[XYF
0:j:EP2^RUP0[XYJ0:j9G080[XUM00<0[h]K0:j:FP2^RUX0102^RUX00`2_Re/0[XYJ0:j:FP060:j:
FP030:b8F02]RET0[HUI00@0[HUI00<0[8QH0:b8EP2]REL01@2]REL00`2/R5H0[HQK0:f8F`020:j9
G0<0[hYM00T0/8]N0;2;G`2`Rel0[hYM0:j:FP2^RUP0[HUE0:b8E02/RE<0202[R5830:^7D`<0ZXIB
0P2YQE480:^7D`030:b7D`2[QU80ZhIB0080ZXEA0P2YQ5000`2XPdl0[8MC0:b7D`070:b7D`P0ZhIB
202YQE400`2WPTd0Z8=>0:V4C`020:V4C`030:N2C@2UP4/0Y7m:00P0ZHA?202TOd/80:R3C`80ZHA?
0P2XPdh20:N2C@80YX5<00P0ZhIB0:Z5D@2YQ500Z8=?0:N2CP2VPDd0YH1<0:AoB`P0YX5=00D0Z8=?
0:V4D02YQ500ZXEA0:^6DP020:b7D`070:f8E02XPUD0Z89C0:R2D`2XPU40Yh9>0:N2C@020:N2B`<0
Yh9=0P2VPD`30:F0B`080:=nB@2RODP0XWe80:5lA`2RODP0Y7m:0:N2C@2XPdh30:J1C0<0YH1;0P2T
OdX00`2YOdd0Z7i<0:MmB`020:IlBP090:QnC02ZP4h0Zh5?0:N1E02WPE80YX1A0:J0C`2VPDd0YH1;
0080YH190P2SOdl00`2TP500YX9B0:J2DP030:N3D`80YX5=00<0Yh9>0:R3C`2XPdl00`2XPdl20:R4
D080Yh=?0`2VPTh:0:F1C@80YX9>1P2UPDd0102RODP0Xgi90:=nB@2SOTT30:AoBP0:0:F0B`2RODT0
XGa80:1kA`2ONTH0X7]70:5lB02SOTX0Y7m;0:QmBP80Yge;00<0YGe<0:5kC02ONTd00P2MNdh01P2Q
Ndh0XG]<0:5kC02QNdX0XGa80:5lA`80XGa5202PNdL809iiA@0809ijAP2MNDD0W7Q409]g@`2LN4@0
WGU509mkA`2QODT209]f@PH0W7M30P2ONTH00`2PNdL0XGa80:5lB0030:5lB00309mjAP2PNdL0XWe9
0080Xgi:00<0XWe90:1kA`2ONTH0202ONDP609eiA@80W7Q400P0X7a809ijAP2LN4@0VgM309Yf@P2K
Md<0W7Q409eiA@P0W7Q800@0VgM709ahB02LN4P0W7Q80`2MNDT0102NNTX0WgY509mjA@2ONTD209ii
A0<0WGQ300<0UW8n09Qd@02JMT800P2KMd<01@2JMT80V7A009Qd@02GLcl0V7A40080Ug=30P2FLT82
09Ea@@0309A`@02FLSh0UW8n00@0UW8n0P2GLcl809I`@@0409QcAP2GLTD0U6m2099]@080TF`o0P2B
KD03095]?@80TVhn0`2CKcl4095]?@@0TVhn00<0T6`l099^?P2CKcl00P2DL4000`2CKcl0TVhn091/
?00208aV>@0408eW>P2>J3/0SVPk08mY?080T6Xm00<0S6Lj08eX>`2>JC`00P2?JSd3091[?P<0SVXh
:oooool002[ooooo0P2EJSd209I[?P<0Uf`o00<0V6e009EZ?`2EJSl01P2EJSl809I/>P0309M/?`2F
Jch0UFXm00<0UFXm00<0UV/n09M/?`2GKC/01`2GKC/209Y_@P0409U^@@2HKD00UV/n09EZ?@80U6Tl
202IKcd809ab@080VW0n0P2KLCl209ab@0@0WG=10P2LLT0309]a?`80VW0n0P2IKT40102JKd80Vg13
09]`@`2LLD@209ebA@P0WG=100H0VW4m09]b?P2KLSh0W7<o09ed@02NMD4209mf@P0809ec@@2OMD<0
XGM50:9hAP2SNDL0XWQ60:5gA@2PMT@20:5f@`80X7E20`2OM440102NLd00X7M30:5hA02RNDD20:Ak
A`030:9iA@2QN4@0X7M30080XgU700@0XWQ60:5gA@2QMdD0X7I40P2OMD<20:5gA@80XWQ60`2SNDL0
102TNTP0XgY60:=jAP2SNTH30:9iA@80XGQ4202PNdH00`2RMd@0XgQ50:AiAP020:EjA`030:AiAP2S
N4D0XWM40080XWQ600<0XWU50:=jA02SNT800P2TO440102TO3l0YWe50:ImA@2VODL20:ImB@030:Il
BP2VO4`0YWa<00P0Y7]70P2WOTX0102VODT0YGa80:AkA`2TNdL20:=jAP<0YWe90`2WOTX20:QoB`P0
Ygi:202VODT0102YP4`0Z7m;0:QoB`2XOd/30:MnBP80YWe90P2XOT`30:UoC@<0ZX1>202YOU480:R3
C`P0ZH1<0`2ZPDd20:^2CP<0[8=?202YQ5020:^6DP@0ZHA@0P2[QU880:V4D080Z8=<00<0ZHA?0:V4
D02ZQ5<00P2ZQ5D00`2ZQ5L0ZHA@0:V4D0060:V4D0030:^6DP2/Qe<0[HQD0080[XUE00<0[HQD0:b7
D`2[QU800`2^QE420:n6DP<0/8MC202^QDl30:j5D@80[hIB0`2`Qe<80:j9E@@0[HQD1`2/Qe<30:^6
DP80ZXEA202]R5@0102YQ500ZXEA0:Z5D@2ZQE420:^6DP@0[8MC0P2[QU800`2ZQE40ZHA@0:R3C`0:
0:N2CP80ZH=D00@0Z89C0:N1DP2WPE80YX1A0P2UOe090:J1C0<0YH1;0`2TOdX0102SOTT0Xgi:0:=n
BP2SOTX30:AoB`80YH1<202SOTT80:=nBPP0Wg]70`2PNdL209mjAP<0WWU500@0WGQ409iiA@2PNdL0
XWe90`2SOTX00`2RODT0WWY:09ijBP0209eiB@<0W7Q800<0VgM709mjAP2ONTH01P2ONTH209egB080
WWQ90`2ONDX00`2PNT/0W7Q409ahA00209ahA0<0WGU500<0WWY609]f@P2KMT801P2KMT8209]g@`<0
W7Q40`2MNDD209Yf@P80VgM30`2LN4@00`2MNDD0W7Q409ahA00709ahA0<0W7Q80P2KMdL309YfAPL0
VgM700<0W7Q809mkA`2ONdL01P2ONdL01P2JNdD0Vga609akAP2ONdL0X7a80:9mB@80YGe:0P2PNT/2
0:5kC080XWa=0P2SODh01@2PO4P0XGe90:5mB@2ROTX0Xgm;00<0Y81<102SOd/30:9nBP80XGe90P2R
OTX01P2TP4`0YH5=0:J2CP2WPdl0Z8A@0:9nBP<0Xgm;0P2TP4`20:F1C@80YgeC00H0YX1C0:F1D@2V
PU00Y8=>0:>4CP2TQDh80:R4D080ZHEA0P2ZQU830:^7D`090:b8E02/QeX0ZhMG0:Z6EP2YQE<0ZHEA
0:Z7D@2[R500[8UA00P0[8MB00<0ZhMC0:b8E02/R5@01@2/R5@20:f:DP030:f:E02]RED0[HUG0080
[HUI00<0[HQK0:j:EP2^RUH00P2^RUH30:f9E@040:b8E02bS5d0/XaM0;:<G@80/heN0`2dSUl80;:>
GP@0]I5M0P2fTUh30;NCG`P0]Y9R202fTUh20;JBHP<0]I5Q0`2dT6020;FAH@040;JBHP2gTf<0^9AT
0;VEI@80^YIV202hTfH30;VEI@80^9AT0`2gTf<80;RCIPP0^9AT202iUFD30;NCH`80^9AT0`2iUFD<
0;RDI080]i=S102fTV820;NCH`@0^9AT202iU6L80;RCIP<0]i=S0P2hU6@30;VEI@040;RFJ02gUFL0
]iEW0;NEI`@0]YAV0`2iUFD20;RDI0<0]i=S2@2iUFD80;NCH`80]Y9R0P2gTf<30;RDI0030;VEI@2f
U6@0]YAT00H0]YAT202gTf<80;NCG`<0^IEU0P2hU6@;0;NCH`040;VEI@2hU6@0^9AT0;RDI080]i=S
0P2fTV820;NBIP030;NBI@2hU6@0^9AR0080^IEQ00<0^IIP0;NBI@2gTVD01P2gTVD80;NCH`P0]Y9R
0`2fTUh20;FAG@<0]91L00<0]91P0;FAH@2gTf<00`2hU6@20;NCH`P0]I5Q00P0/XiN0;B@H02fTV80
]i=S0;RDI02gTf<0]Y9R0;FAH@<0]Y1Q0`2eSf020;B>G`80/HeM0P2bSUh30;>?G`030;B@H02bS5d0
/heN0080/heN00<0]8iO0;F?H02fT6400P2gTF890;>?G`80]91P00<0]I5Q0;B@H02cSel00P2aSEd0
1P2bSeT0/XiJ0;:>FP2bSU`0/XiN0;:=H080/XeQ00P0/XiL0;>?G@2dT600]I1S0;F@I02cSV@0/HaR
0;2:H`P0/heN00@0/XaM0;>=GP2cSEh0/heN0`2dSUl00`2eSf00/XiN0;:>GP060;:>GP030;>?G`2b
SUh0/8aL0080[h]K00H0/8aL0;:>GP2cSel0/hiJ0;:=F@2aS5P20;2;E`030;6<F02bSET0/hiJ0080
]8iO0`2cSEh30;:<G@080:n:E@2^RED0[XUE0:j8E`2`RU/0/XaO0;F>H`2fSf@20;6;G0<0/XaM0`2c
SEh20;B;G`040;:<G`2aS5l0/HaO0:n=G`80[XiO0`2_SEl30;2>H080/HmQ0P2eSf820;B>H@80/heP
0P2bS5l80;2<G0P0/XiN00H0/8]N0;2<G02`S5`0[h]I0:n;E`2^ReD20:j;D`<0[h]K102`S5`20;6=
G@P0/XiJ602_Re/0202^REd0[hYN0;2;GP2aSEd0/8aJ0;2<F02_ReL0[X]E0P2]R5@0102^RED0[hYF
0:n:EP2`ReL20;6<F0<0[h]K0P2^RUX30:f9F@060:j;E@2^RUH0[XYF0:j:F02^RUX0[XUL0P2^REd0
0`2`S5`0[h]K0:j:FP020:f9F@030:j:FP2_Re/0/8aL00<0[h]K0P2^RUX30:f9F@030:^7E`2/R5P0
[HUI0080[XYJ00H0[HUI0:b8F02[QeL0ZhMC0:b8E02]RED20:j:EP030:f9E@2/R5@0ZhMC00<0[8MJ
0P2]R5/30:j9G080[hYN00<0[hYM0:j:FP2^RUP00P2]RED00`2]RU@0ZhMC0:^7D`090:^7D`<0ZXIB
0P2YQE480:^7D`80[8MC00@0ZhIB0:Z5D@2ZQE40ZHA@0P2XPdl90:b7D`P0ZhIB0`2XQ5020:V5D@<0
ZXIB00P0ZHA@0:Z5D@2[QU80ZhIB0:Z5D@2XPdl0YX5=0:F0C0P0Z8=>202VPDd80:R3C`80ZHA?0P2X
Pdh20:N2C@80YX5<00D0ZXEA0:V4D02YQ500Z8=?0:N2CP020:J1C@030:F0C02VPDd0YX5=00H0YX5=
102YQ5040:Z5D@080:V3EP2XPU<0Z89C0:R2D@2WPTh0Yh9=0:N2B`2VPDX20:N2C@80YX5<0`2UP4/0
2@2TOdX0Xgi90:9mB02RODP0XGa70:9mB02TOdX0Yh9=0:R3CP020:N2C@80YX5<0`2UP4/0102TOdX0
ZGm=0:QnC02WOD/20:IlBP040:QnC02ZP4h0Zh5?0:J0D`80YX1A00<0YGm>0:F0C02TOdX00P2TOdP0
0`2TP500YH5A0:J2DP030:N3D`80YX9B00<0YH1<0:J1C@2WPTh00`2YQ500102XPdl0Yh9>0:R4D02X
Q5020:N3C`<0YX9>2P2UPDd30:J2CP<0YH5=0P2TP4`80:=nB@0A0:9mB@2QO4P0X7]709mjAP2PNdL0
XGa80:=nBP2TOd/0YGY70:IlBP2XOT`0YGe<09miBP2MN4/0W7Y=09ilC`2QNdh00P2QNd`00`2QNdX0
XGa80:5lA`020:5lA@P0XGa8202NNDD0302NNTH0WGU509ahA02KMd<0W7Q409eiA@2ONdL0X7a809]f
@P2LMd<0WGQ409iiA@80WgY600D0WWU509ehA02MN4@0WWU509mjAP030:5lB0050:1kA`2ONTH0WgY6
0:1kA`2QO4P00P2RODT00`2QO4P0X7]709mjAP0809ihB@<0WWY60`2MNDD209ahA0080:1lB02NNTH0
W7Q409]g@`2JMT80VgM309ahA02MNDD809ahB0@0WGU9102LN4P309iiA080WGQ30`2LMd801P2ELCd0
Ug<o09Yf@P2LN4@0WGU509]g@`80VGE100H0Ug<o09QdA02HM4@0Ug=309Ib@P2ELD4209A`@00309=_
?`2ELCd0UG4m00<0UW8n0`2GLcl809Ma@P0609QcAP2GLTD0U6m2099]@02AK3l0T6/n0P2AK3l3091/
?080TFdm0`2BKSh3095]?@80TVhn0`2CKcl00`2@K3`0TFdm09=_?`0209A`@00309=_?`2AKCd0T6`l
00<0SVPk0P2?JC`3091Z?@0408YU>02<IcX0SFPk08mZ?@80T6/n0P2?JSd308mZ=R_ooooo000Zoooo
o`0409AY?02EJSd0UFXm09EZ?@80UV/n0P2GK3l809EZ@0P0UF/i00<0Uf`o09I[?P2EJSd00P2DJC`0
0`2EJSd0UV/n09M/?`0809M]>`0409U^@@2HKD00V6e009M/?`80UV/n0P2EJSd809U_?@P0W7900P2J
L3h209]a?`80W790102MLd4209ab@0<0Vg4o0P2JL3h609]`@`80W754202MLd4209Ya?@0>09]b?P2L
Lcl0WGA009ie@@2OMT80X7M309ec@@2OMD<0XGM50:9hAP2SNDL0XWQ60:5gA@2PMT@30:1e@P<0WgA1
0P2NLd000`2PMd<0XGQ40:9iA@020:AkA`030:9iA@2QN4@0X7M300@0XgU71`2RN4H30:=iA`80Y7Y8
0P2UO4P30:AkA`<0XgY6202PNdH00`2QMT<0XWM40:AiAP020:EjA`0;0:AiAP2RMd@0XGI30:5hA02R
NDD0XWU30:=j@P2SNd00Y7a10:Al?`2UOD000P2TNd<0102TNdD0Y7]70:AkA`2TNTP20:AjBPP0XgY6
0P2WOTX0102VODT0YGa80:AkA`2SNTH20:9iA@<0YWe90`2WOTX20:QoB`P0Ygi:00D0YGa80:ImB@2V
ODT0Ygi:0:QoB`020:V0C0040:Z1C@2XOd/0Z7m;0:QoB`80Ygi:102VODT20:QnC0<0ZGm=0`2ZP4h8
0:QmD0P0Z8=?202YP4`40:Z1C@80Zh9>0P2/Pdl80:V4D0030:b7D`2[QU80ZHA@0080Z8=?00<0ZHA@
0:^6DP2/Qe<0202YQ5001@2WPT/0Z8=<0:R3CP2YQ500ZH=B0080ZXAE00<0ZhEH0:V4D02YQ5001P2Y
Q5000`2[QU80[8MC0:f8E0020:j9E@030:f8E02/Qe<0ZhIB0080[XEA0P2_QU840;27D`P0[XE=0P2]
Q5020:j5D@<0[hIB00<0/8MC0:n:EP2_RUH01P2_RUH40:b7D`@0[HQD0`2/Qe<30:^6DP80ZXEA202^
RED30:Z5D@80ZhIB1P2/Qe<00`2[QU80ZXEA0:V4D0020:R3C`T0Yh9>0P2XPU<60:N1DP/0YX5<00<0
YH1;0:AoBP2TOdX00P2SOTT20:=nBP80Y7m;0P2UP4`20:J1C@P0Xgi9202RODT209mkA`H0X7a80P2Q
O4P20:1kA`<0WgY600@0WWU50:1kA`2QO4P0Xgi:0P2TOd/0102RODT0XGa80:1kA`2ONd/309ijBP80
WGU90P2LN4P80:1kA`80WWQ90P2ONDX30:1jB`040:5kC02PO4P0X7a80:1lB0<0Wg]70P2NNTH809ag
@`<0WWY60`2MNDD209ahA0<0VgM30P2LN4@<09eiA@<0WGU90P2LN4P309]gA`P0W7Q8202PO4P01P2K
O4H0W7e709elA`2PO4P0XGe90:=nBP80YWi;0P2QNd`30:9lC@<0Xge>102QODT50:9nBP<0Xgm;102T
P4`20:9nBP80Xgm;00D0Y81<0:F1C@2UPDd0YX9>0:=oB`030:B0C080YH5=0P2VPTh01P2XOUP0Z7iF
0:IoE02VPE@0YX9@0:F4C`80Y8E<202YQE430:Z6DP80ZhMC0`2/R5@0202]R5/0[8QH0:Z6EP2YQE<0
ZHEA0:Z7D@2/RE40[HYB202/Qe830:f9E@D0[8QD0P2^Re<00`2^ReD0[XYF0:j:F0020:j:FP040:j9
G02]RED0[HUE0:f9E@<0[XYF0P2_ReL0102bS5d0/heN0;>=GP2cSEh20;B>G`80]HmP102dT6040;>?
G`80]I5M0`2fTUh20;NCG`80^9AP202gTf<40;NCG`@0]Y9N0`2gTf<30;JBHP80]I5Q0P2dT600102e
TF40]Y9R0;JBHP2gTf<20;RDI0P0^9=V0`2iUFD20;RDI0<0]i=S202hTfH80;RDI0P0^IEU00<0]Y9R
0;NCH`2gTf<00P2hU6@20;VEI@030;ZFIP2hU6@0^9AT00H0^9AT00<0^IEU0;RDI02hU6@00P2gTf<2
0;JBHP80]I5Q0P2fTV820;NCH`80^9AT00<0^IEU0;RCI`2hTfL01P2hTfL80;RCIP<0]i=S0P2hU6@3
0;VEI@80]I=U0`2fU6H30;NEI`<0^IEU0P2hU6@30;NCH`050;JBHP2gTf<0]i=S0;RDI02iUFD00P2j
UVH00`2kUfL0_9QX0;RDI0070;RDI0<0]i=S0`2hU6@20;VEI@P0]YAT202gTf<80;NCG`<0]i=S0P2h
U6@30;VEI@P0]i=S0`2hU6@20;NCH`<0]Y9R00D0]Y5U0;NBIP2gTVD0^9AT0;RDHP020;VEH@030;ZG
H@2fTFD0]Y5U00H0]i9V202gTf<80;JBHP040;JBGP2eTEd0]I5M0;FAG@80]91L0P2cSe/0202dT600
]Y9R0;RDI02iUFD0^YIV0;VEI@2hU6@0]i=S102cSel40;B@H0080;:>GP2dT600]Y9R0;NCH`2hU6@0
]i=S0;JBHP2eTF430;J@H@<0]HmP0P2dSUl30;6=G@80/XiN0`2cSel01`2aRe`0/XaM0;>=GP2cSEh0
]8iO0;F?H02fT6400P2gTF880;>?G`030;:>GP2cSel0]91P0080]I5Q00@0/hmO0;6=G@2`S5`0/XmI
0P2bSUX00`2bSU`0/XiN0;:=H0020;:=H@080;:>G02cSel0]91P0;F@H`2eT6@0/hiT0;6;I02`RV<8
0;B>G`030;2:F`2aRe`0/H]L0080/XaM0P2cSEh00`2dSUl0/XiN0;:>GP060;:>GP80/8aL00T0[h]K
0:j:FP2_Re/0/HeM0;>?G`2eTF40/hiJ0;:=F@2aS5P00P2`ReL00`2aS5P0/hiJ0;B?F`020;B>G`<0
/heN0`2bS5d0202`ReH0/8]G0:n:EP2`RUT0/H]L0;B>H@2fSf@0^95V0P2cSEh30;:<G@<0/H]L0P2d
Rel0102bS5l0/HaO0;6<G`2_SEl20:j>G`<0[heO0`2`SV020;6?H@<0/haQ0P2bRf030;6:G`P0[h]K
202bSUh01P2bSF00/XiN0;6=G@2aSE/0/8aH0:n<EP80[haD0P2`S5`40;6=G@<0/XiN202bSUXH0:n;
F`080:f8G02^REd0/8]N0;6=G@2aSE/0/8aH0:n;E`2^ReD20:j9E@@0[hYF0P2`ReL30:n;F`80[XYJ
0`2]RET01P2^ReD0[XYF0:j:EP2^RUP0[XYJ0:j9G080[XUM00<0/HeM0;2<G02^RUX00P2]RET0102^
RUX0/8aL0;6=G@2`S5`20:n;F`80[XYJ0P2]RET0102/R5P0ZhMG0:b8F02^RUX20:n;F`060:j:FP2/
R5P0ZhMG0:^7D`2/R5@0[XYF0P2_ReL00`2^RUH0[8QD0:^7D`030:Z5F080ZhII0`2/QeX20:f8G003
0:f8F`2^RUX0[XYH0080[h]G00<0[haF0:Z6E02ZQU@01P2ZQU@30:^7D`<0ZXIB0P2YQE480:^7D`05
0:f8E02/Qe<0[8MC0:^6DP2YQ5000P2XPdl00`2WPTh0[8MC0:b7D`070:b7D`P0ZhIB00<0Yh=?0:R4
D02XQ5000P2YQE420:Z6DP030:^7D`2/QUD0[8IE0080[HMF00@0[8IE0:Z4D`2WPE00YX1?202XPdh8
0:N2CPP0Z8=?0P2YQ4l20:R3CP80Yh9=0P2VPD`40:R3C`@0Yh9>202VPDd30:V4D080Z8=?0`2WPTh0
1P2YPeH0ZH=D0:R2D`2XPU40Yh9>0:N2C@80YX5:0`2VPD`30:F0B`80Y7m:00P0Xgi90:9mB02RODP0
XGa70:9mB02TOdX0Yh9=0:R3CP<0Yh9=0P2VPD`30:F0B`030:UoC@2XOT`0Yge;0080YWa:00@0Z7i<
0:Z0CP2[PDl0YGmB0P2UOe000`2TOTd0Y7m;0:=nB@020:=nA`030:F1D@2VPU80Z8AD0080Z8AD00/0
Yh=C0:F1D@2SOdl0Y7m;0:J1C@2XPdl0ZHA@0:Z5D@2YQ500Z8=?0:N2CP020:R4D080Yh=?0`2VPTh2
0:F1C@P0Y81<0P2WPdl20:J2CP040:F1C@2TP4`0Y81<0:B0C080YH1;00<0Y7m:0:=nB@2RODP00`2Q
O4L04@2RODT0XGa80:1kA`2ONTH0X7]70:5lB02SOTX0Y7m;0:9gA02UNdT0Yge;0:EmC02NN4T0W7M:
09ajC@2POU40XG]>0080XG]<00<0XG]:0:5lB02QO4L00P2QO4D80:5lB0P0WWU500<0WGU509ahA02K
Md<00P2KMd<03P2MNDD0WWY60:1lB02LMd<0WGQ409mjAP2QO4P0XWe90:5lB02PNdL0WgY609]f@P2L
Md<0WWU50P2PNdL01P2ONTH0WWU509ehA02NNDD0WgY60:5lB080XWe900<0XGa809mjAP2NNDD0202N
N4T209mkA`80WWY60P2MNDD209ahA0080:1lB02NNTH0W7Q409]g@`2JMT80VgM309ahA02MNDD809]g
A`0509mkB`2NNTX0WWY:09eiB@2LN4P00P2KMdL00`2JMTH0WGQ309eh@`0209ag@P80VgI10P2JMD00
1P2DL3`0Ug<o09Yf@P2MNDD0WWY609ahA080VWI200T0V7A009QdA02HM4@0Ug=309Ib@P2ELD40U710
09=_?`2BKSh00`2ELCd00`2FLSh0Ug<o09Mc?`0209Qd@0P0V79300@0VGA709MbA@2DKd80TVe0102@
Jch208m[>`80T6`l0`2AKCd01@2BKSh0TFdm095]?@2AKCd0TVhn0080Tflo0P2DL4000`2@K3`0TFdm
099^?P0209=_?`03099^?P2AKCd0T6`l00@0TF/n102@JSd01029I3L0RVDh08eX>`2?JSd2091[?P80
SfXm0`2BJSL[ooooo`00:_ooool209AY?080UFXm0`2FJch00`2GK3l0UFY009EZ@00609EZ@0P0UF/i
00<0V6e009I[?P2DJC`00P2CJ3/00`2DJC`0UV/n09Q]@00809M]>`@0Uf`o102FJch809U_?@P0W790
0P2JL3h209]a?`80W790102MLd4209ab@0<0Vg4o0P2JL3h0102MLTD0W75409aaA02LLD@309]`@`03
09Y_@P2MLd40WG=100H0WG=10P2JLCd00`2KLSh0W7<o09ed@00209mf@P090:1g@`2MLd40WgE30:5g
A@2RN4H0XgU70:9hAP2QMdD0X7I400<0X7E20P2OM44309ic@0030:1g@`2QN4@0XWU50080Y7]700<0
XWU50:5hA02PMd<0102SNDL40:AjB0<0XWQ60P2SNDL30:AjB080YWe90`2UO4P30:AkA`P0Wga600<0
XGI30:9gA02TNDH00P2UNTL00`2TNDH0XWM40:5f@`020:5hA0060:9i@`2SNT80Xg]00:Al?`2UOD00
YGdo0P2SNT80102SNT@0XgY60:=jAP2SNDL20:=iB@P0XgY60P2WOTX01P2VODT0YGa80:AkA`2SNTH0
XWU50:5hA0<0YWe90`2WOTX20:QoB`P0Ygi:00P0YGa80:ImB@2WOTX0Z7m;0:V0C02ZPDd0Zh9>0:b3
C`80Z7m;0`2WOTX40:ImB@80Z7i<0`2YOdd30:Z0CPP0Z7e@202XPdl90:V0C0<0ZX5=0P2[PTh20:b3
C`P0ZHA@00<0[8MC0:^6DP2YQ5000P2XPdl00`2YQ500ZhIB0:b7D`080:V4D080Yh9;00<0Z8=>0:R3
C`2YPe800P2ZQ5D00`2[QEP0ZHA@0:V4D0060:V4D0030:^6DP2/Qe<0[HQD0080[XUE00<0[HQD0:b7
D`2[QU800P2^QE420:n6DP<0/8MC00<0/HQD0:j5C@2^QDd01P2^QDd20:f4D080[XEA102_QU880:n:
EP050:Z5D@2[QU80ZhIB0:b7D`2]R5@00P2^RED0102_RUH0[8MC0:b7D`2/Qe<30:^6DP80ZXEA202^
RED20:Z5D@<0ZhIB1P2/Qe<0102[QU80ZXEA0:V4D02YQ5020:R3C`P0Yh9>00@0YX1C0:N1E02WPE@0
Yh5D0`2XPUD00`2YPeH0YX5<0:J1C0060:J1C080Yh9=00@0YX5<0:F0B`2UP4/0Y7m:0P2SOTT20:=n
BP040:AoB`2UP4`0YH1<0:J1C@80Yh9>202TOdX80:5lB00309mkA`2PO4P0X7a80080X7a80`2QODT3
0:5lB080X7]70`2ONTH20:F0C080YX5=00@0Y7m;0:5lB02NNDD0VgI20P2ONd/209ijBP<0WGU900<0
W7Q80:5lB02QO4P01P2QO4P309miBP80X7Y;0`2QNd`20:=oB`030:9nBP2QODT0X7a80080Wg]700<0
WWY609ag@`2LMd<01P2LMd<20:1lB00309mkA`2NNTH0WGU50080W7Q40`2KMd<209ahA0<0WGU52P2N
NTH0102NNTX0WGU909eiB@2MNDT209ahB080VgM7102MNDT409ahB0P0X7a80P2LODL01P2NODP0XGe9
0:9nBP2TOd/0YWi;0:MoC0@0XWa=102SODh80:5mB@80XWi:0P2SOd/01@2TP4`0YH5=0:J2CP2VPTh0
XWi:00<0Xgm;1`2TP4`20:F1C@<0YX9>0P2XOUP01P2WP5D0YX5D0:N3D@2UQ4h0Y8E<0:F7B`P0ZHEA
0P2ZQU820:^7D`<0[8QD00T0[HUE0:f8F`2/R5P0ZhMG0:Z6E02ZQU80ZhQB0:b9D@2]RU80202/Qe85
0:f9E@<0[8QD0P2^Re<00`2^ReD0[XYF0:j:F0020:j:FP040:j9G02/R5@0[8QD0:f9E@80[XYF00<0
[h]G0;2<F02`S5P00`2cSEh20;B>G`<0]HmP1@2eTF430;B@H0D0]Y=M0P2gU5h20;REG`P0]i=S1@2g
Tel30;JBGP@0^9AT0P2gTf<20;JBHP80/hmO0P2dT600102eTF40]Y9R0;NCH`2gTf<80;RCIP<0^IEU
0P2hU6@30;NCH`P0^9=V202hU6@80;VEI@80]Y9R00@0]i=S0;RDI02hU6@0^IEU0P2jUVH20;VEI@@0
^9AT0P2gTf<0102iUFD0^9AT0;RDI02gTf<20;JBHP@0]I5Q0P2fTV80102gTf<0^9AT0;RDI02iUFD8
0;RCI`P0^9=V0`2gTf<20;RDI0<0^IEU0P2dTV@0102eTfD0]YAV0;JDIP2gUFL20;RFJ0<0^IEU0P2h
U6@30;NCH`070;FAH@2fTV80]Y9R0;NCH`2hU6@0^YIV0;bHJ0020;fIJ@P0^9AT0`2gTf<20;RDI0<0
^IEU202fU6@80;NCH`P0]i=O0P2fTV80102gTf<0^9AT0;RDI02iUFD20;ZFIPP0]i=S0P2hU6@30;NC
H`<0]Y9R0P2fTFD01P2gTVD0^9AT0;RDHP2iUF40^YIR0;ZGH@<0]Y5U1@2gTVH80;NCH`P0]Y9R102e
TEd20;B@G080/hmK00<0]91P0;JBHP2hU6@00`2jUVH00`2hU6@0]i=S0;:>GP030;:>GP@0/hmO00P0
/XiN0;B@H02fTV80]i=S0;RDI02gTf<0]Y9R0;FAH@<0]Y1Q0`2eSf020;B>G`<0/HeM0`2bSUh20;>?
G`80/H]L0P2bS5d00`2cSEh0]HmP0;J@H@020;NAHPP0/hmO00<0/XiN0;>?G`2eTF400P2eTF40102c
Sel0/HeM0;2<G02bSeT20;:>FP030;:>G02bSUh0/XeP0080/XeQ00P0/XiN0;>?G`2dSf80]I1T0;F@
IP2cSFH0/H]T0;2:I@P0]8iO0P2_REX0102`RU/0/H]L0;6;G02bS5d20;>=GPP0/XiN00X0[h]K0:j:
FP2^RUX0[XYJ0:n;F`2bSUh0]91P0;JBHP2cSUX0/XeI0`2`ReL00`2aS5P0/hiJ0;B?F`020;B>G`<0
/heN0`2bS5d02@2aS5L0/HaH0;2;E`2aReX0/XaM0;F?HP2gT6D0^I9W0;B>G`020;>=GP050;:<G@2a
Re`0/8YK0;2:F`2_REX00P2dRel0102bS5l0/HaO0;6<G`2_SEl20:j>G`<0[heO0`2`SV020;6?H@<0
/X]P0P2aRUl30;29GPP0[h]K202bSUh01P2cSV40/hmO0;:>GP2aSE/0/HeI0;2=E`80[haD0P2aSEd3
0;:>GP@0/hmO202bSUXH0:n;F`080:b7F`2^REd0/8]N0;6=G@2bSU`0/HeI0:n;E`2^ReD80:n:EP<0
[h]K0P2^RUX30:f9F@060:j;E@2^RUH0[XYF0:j:F02^RUX0[XUL0P2^REd00`2aSEd0/8aL0:j:FP02
0:f9F@030:j:FP2`S5`0/HeM0080/8aL00@0[h]K0:j:FP2^RUX0[HUI0P2/R5P00`2[QeL0[8QH0:j:
FP020:n;F`060:j:FP2/R5P0ZhMG0:^8DP2/RE<0[X]E0P2_S5H00`2^ReD0[8UC0:^8DP030:V4E`<0
ZXEH0P2[QUT20:b7F`060:f8F`2^RUX0[XYH0:n;E`2`S5P0/8eG202ZQU@30:^7D`<0ZXIB0P2YQE48
0:^7D`80[HQD00@0[8MC0:^6DP2YQ500Z8=?0P2WPTh90:b7D`P0ZhIB0P2WPdl0102XQ500ZHEA0:V5
D@2ZQU820:^7D`080:f7EP2^R5L0[XQG0:j8E`2]QeH0ZhED0:R2D@2WPE080:R3CQ00Z8=?0P2YQ4l2
0:R3CP80Yh9=0P2VPD`0102VPDd0Yh9>0:N2CP2WPTh30:R3C`030:V4D02VPDd0YX5=00H0YX5=0P2Y
Q500102XPdl0Yh9>0:N2CP2VPDd20:F0C0060:V3EP2YPe@0ZH=D0:R2D@2WPTh0YX5<0P2VPDX30:J1
C080YH1;0`2TOdX0202SOTT0XWe80:9mB02QO4L0XWe80:AoBP2WPTd0Z8=>0`2WPTd30:J1C080YH1;
00<0ZGm=0:QnC02WOD/00P2VO4X0102XOT`0ZX1>0:^1C`2UOe820:EoD0030:AnC@2TOd/0Xgi90080
Xgi700/0YX9B0:N3D`2YQED0ZHEE0:R4E02VPU80Y81@0:9nCP2TOd/0YX5=0:R3C`020:Z5D@030:V4
D02XPdl0YX5=0080Z8A@0P2WPdl30:J2CP80YH5=202TP4`20:N3C`80YX9>01d0YH5=0:B0C02TP4`0
Xgm;0:J1C02UP4/0Y7m:0:=nB@2RODP0XGa70:1kAP2ONTD0XWe90:5lB02PNdL0WgY60:1kA`2QO4P0
Xgi:0:AoB`2PMD80Y7Y80:MmB`2TO4/0WWQ909]fB@2MNdh0XGmB0:5kCP020:5kC0030:5kBP2QO4P0
XGa70080XGa5202QO4P809iiA@0<09eiA@2LN4@0VgM309Yf@P2KMd<0W7Q409ijAP2PO4P0W7M309ii
A@2PNdL0XWe90P2SOTX01@2QO4P0X7]709Ye@@2KMT80WGQ400<0WgY600D0WGQ409ag@`2NNDD0WgY6
0:5lB0020:9mB@030:5lB02ONTH0WWU500P0WWQ;00@0X7a809mkA`2ONdL0WWY60P2MNDD209ahA008
0:1lB02NNTH0W7Q409]g@`2JMT80VgM309ahA02MNDD809]gA`090:1lC02ONd/0WWY:09eiB@2LN4P0
VgM709YfAP2IMDD0W7M200<0VgI10P2JMD0209Ud?`0309A`?02GLcl0VgM30080WWY600@0WGU509Yf
@P2JMT80V7A00P2HM4@0102GLd<0UW9209A`@02CKcl2099^?P0409A`?02ELCd0UG4m09Ib?P80Ug<o
0P2HM40809Qb@`0609UdA`2GLTD0U6m2099]@02@Jch0SfXm0P2@Jch308m[>`80T6`l1P2AKCd00`2B
KSh0Tflo09A`@00209A`@00308m[>`2AKCd0TVhn0080Tflo00@0TVhn095]?@2?Jc/0U6i10P2CKD00
2@2BK3l0TF/n091Z?@2@JSd0SfTl08QS=P2:ICP0SFPk08mZ?@02091[?P0308mZ?@2>JC`0TVXf0080
TVXf:oooool002[ooooo0P2EJSl209I[@0<0Ufa100@0V6e209EZ?@2GK3l0VFi10P2JKd80102IKT40
Uf`o09EZ?@2GKC/209Q^?00309U_?@2JL3h0VW0n0080VW0n00<0Vg4o09Y`?P2HKS`00P2GKC/00`2H
KS`0VW0n09]a?`0209Y_@P0309U^@@2HKD00Uf`o0080UV/n00<0UFXm09Q]@02HKD001P2HKD000`2K
L4<0VVm209Q]@00309I[?P0309M/?`2HKD00Ufdk0080V6hl00<0VW0n09]a?`2LLT000P2MLd40102O
MD<0WWA209id@P2MLd4209ab@080Vg4o2@2JL3h809ic?PP0WWE100<0WgE309id@P2LLT000P2KLCl0
0`2LLT00WWA209me@`030:1fA0<0WgE30P2NM48209Yf?00409Ye?P2KMT40VgI109ag@`80W7I500P0
WgE30:1fA02RN4H0XgU70:AjB02SNDL0XWQ60:5gA@80XgU70P2RN4H40:5gA@P0XWM<0P2QMdD0102R
N4H0XgU70:=iA`2TNTP20:EkB@P0XgM6202TNDH80:9iA@P0XgY60P2TNTX0102TNTP0Y7]70:AkA`2T
NdD20:Ak@`<0Z7e:00<0Yga90:IkB02UNTL00P2UNTL80:ImA@80XgY60P2TNdL40:ElB0070:Z1C@2X
Od/0YWe90:ElB02TNdL0YGa80:MnBP0:0:QoB`/0Ygi:0P2XOd/30:V0C0P0ZX1>00P0[8=;0:b3C@2/
Pdl0Zh5A0:YoDP2YOU@0ZGeF0:UmF0P0[8=?00P0ZXE@0:R3CP2VPD`0YH1;0:N2C@2[QU40[hYE0;:=
F080[8MB00@0ZhIA0:Z5D02ZQE00ZHA?0P2XPdh80:f4D080Zh9>00@0[8=?0:f4D02]Q500[XEA0P2_
QU820:Z5D0<0ZhIA0`2/Qe880:Z5D0030:^6DP2/Qe<0[HQD0080[XUE00@0[HQD0:b7D`2[QU80[XUD
0`2]R5<20:b7DP80ZhIA0P2ZQT`0102[QTl0ZhIA0:^6D@2/Qe<20:b6E@80[8MC0P2]R5@0102^RED0
[hYF0:n:EP2`ReL20:^6DP80[8MC0P2]R5@20:j9E@P0ZXE@502[QU820:Z5D@<0ZHA@0P2WPTh20:R3
C`040:V4D02ZQE40ZhIB0:^6DP80ZXEA0`2YQ5030:R3C`d0YX5=0`2WPTh00`2ZQE40Z8=?0:N2CP02
0:F0C0030:N2CP2XPdl0ZXEA0080Zh9>0P2ZPDd01`2YP4`0Z7m;0:QoB`2WOTX0XWe90:=nBP2UP4`0
0P2VPDd00`2UP4`0Xgi:0:9mB@080:=nBP060:N2C@2VPD`0YX5<0:F0B`2TOdX0Xgi90P2RODP80:=n
BP80Xgi900@0XWe80:5lA`2ONTD0WWU40P2MN4<80:1lB0P0X7]70P2SOTX0102RODT0XGa809mjAP2N
NDD209ehA0P0W7Q40`2QNdh0202PNTd0WgU<09egBP2LMTT0VgE809iiA@2MN4@0W7M30P2KMT800`2L
Md<0WGQ409iiA@0309eiA@80WWY6102ONdL80:1kA`<0X7e70P2OO4H309ikA@80XGe900@0X7a809mk
A`2ONdL0WWY60P2MNDD0202MN4@0WgY60:9mB@2TOd/0YH1<0:=nBP2QO4P0X7]70`2TOd/20:F0C0<0
YX5=202SOd/80:AoB`030:R5C`2WQ4h0YX==0080YH9<00H0YX==0:N4CP2XQDl0YX9>0:N3C`2YQE42
0:Z6DP030:V5D@2WPdl0YX9>00<0Yh=?0P2XQ5030:V5D@<0Z8A@0P2YQE430:Z6DPP0[HUE202^RED2
0;6<F0@0/XeI0P2cSUX0402_REX0/8YK0;6;G02bS5d0/H]L0:n9FP2/QUL0ZhEF0:b7D02^RE80/8]F
0;:=F@2cSE`0/XaM0;6;G02`RUd20:^7E`80[8QH102]RET20:n;F`040;6=G@2bSUh0]91P0;FAH@80
]i=S0`2bSF020;>>H@<0]8mR2@2gTf<00`2fTV80]i=S0;VEI@020;ZFIP030;VEI@2gTf<0]Y9R00P0
]Y9R2`2gTf<20;RDI0<0^IEU0P2hTfH30;VDI`<0^YEX0P2hTV<20;NAHP80]Y1Q0P2eSf030;NCH`80
^9AT0`2iUFD01P2iU5l0^IAP0;RCG`2hTV40^99S0;NAI080]i1U00D0]i9N0;RCG`2hTel0^IAP0;ZE
H@020;^FHP030;bGH`2hU600^9AP0080^9AP102iUF480;VEI@<0^YIR0`2iUF420;RDH0P0]i=O0P2h
U6@30;NCH`D0]Y9R00@0]i=S0;RDI02hU6@0^IEU0P2jUVH20;^GI`040;ZFIP2iUFD0]i=S0;JBHP80
]I5Q0P2fTUh0102gTel0^9AP0;RDH02iUF420;ZFHP80^YIV00H0^IEU0;NCH`2fTV80]I5Q0;B@H02c
Sel90;RDH0P0^9=O202gU5`80;NCH`<0^99S0P2iTf@30;ZDI@P0]i=S202iUFD80;RCIPP0^9=O0P2e
TEd20;JBGP040;NCG`2hU600^9AP0;VEH@D0]i=S0`2fTV820;NCH`80]Y9R0P2eTF420;B@H080^YIR
0P2iUF420;RDH080]i=O0P2eT5T00`2fTE`0]Y5M0;NAH0020;NAHP030;RBI@2eSf00]HmP00/0]HmP
0`2dSUl0202aS5l0/hiQ0;JAI02hTfH0^IAW0;NBI@2eT6<0]8mR0P2eTF40102dT600/hmO0;>?G`2b
SUh20;6=G@<0]HmR0P2dSV430;>=H0090:n;F`2`S5`0/HeM0;6=G@2bSUh0/hmO0;B@H02eTF40]Y9R
00P0]8mK202cSel00`2eT6@0]8mS0;:=H@030;2;G`050;6<H02bSF40/XiN0;>?G`2eTF400P2fTV80
0`2eTF40/hmO0;:>GP020;:>GP80/HeM0P2`S5`20:n;F`80[8QD00<0[HUE0:j:EP2_ReL00P2aSET0
0`2bSUX0/XmI0;>@FP030;FBG0030;>@FP2aSUP0/8eG00<0[hYM00<0/8]N0;6<G`2bSF000P2bSF02
0;B>G`<0/heN0`2bS5d0102dT600/hmO0;>?G`2bSUh20;6=G@80/8aL0P2aSEd0102bSUh0/hmO0;>?
G`2dT6020;FAH@80]XeO00@0/heN0;6=G@2`S5`0[H]K0P2[ReX30;6<G`<0/XeP0P2cSV420;>>HP03
0;:=H02bSUh0/XiL0080/HeI00H0/HiH0;2;G`2`Rel0/HaO0;6=G@2bSU`20;>?F`070;BAF`2`SEL0
/8aH0;2<F02_ReT0[h]K0:n:G@020:n:GP040;B@H02cSel0/hmO0;:>GP80/HeM102`S5`02@2aSEd0
/XiN0;2<G02^RUX0ZhMG0:V5E@2aSEd0/8aL0:n;F`020:j:FP040:n;F`2`S5`0/XiN0;B@H080]I5Q
00@0]91P0;>?G`2cSel0/XiN0P2aSEd80:n;F`0I0;6=G@2bSUh0/hmO0;>?G`2bSUh0/8aL0:f9F@2[
QeL0ZXIF0:^7E`2/R5P0[XYJ0:n;F`2aSEd0/XiN0;>?G`2^RUH0[h]G0;6=F@2bSUX0/HeI0:n;E`2]
RED0[8QD0:j8F`020:j8F@030:n9F02_RUH0/8]F0080/8]D1@2_Re/30;2<G0P0[XYJ202_RUH20:j:
EP<0[HUE0`2/R5@30:n;E`<0/8aH0P2aSET30:f8E0<0[XUE0P2_RUH@0:j9E@@0ZhMC0P2ZQU820:V5
D@060:b7D`2[QU80ZhIB0:V4D02XPdl0Yh9>0P2VPDd01P2]PE00[89@0:b2D02/Q540ZXEA0:Z6DP80
Z8MB202ZQE00102XQe80ZHQC0:b8E02]R5@20:n7E0030:j4DP2]Pe40[81?00<0ZhIB0P2ZQE430:V4
D0P0Z8=?0P2ZQE430:V4D0<0Z8=?102UP4/20:J1C080Yh9=00P0Y7m;0:J1C@2YQ500ZhIB0:Z5D@2W
PTh0Xgi:0:1kA`P0ZHA@0P2ZQE420:V4D0@0Z8=?0P2YQ5020:R3C`80Yh9>2P2VPDd0202WPTh0Z8=?
0:V4D02YQ500Z8=?0:F0C02SOTX0XGa8202VPTP00`2SOTX0Y7m;0:J1C@020:N2CP030:J1C@2TOd/0
Xgi:00<0Xgi90`2TOdX20:F0B`<0YX5=0P2UP4`30:AoB`P0YX5=202YOT/I0:R3C`060:R3EP2WPe<0
Yh=C0:J2D02UPDd0Y85;0P2SP4P20:J1C@030:F0C02TOd/0Xgi:0080XWe900H0XGa80:5lA`2QO4L0
XGa70:9mB02SOTT30:AoBP0@0:=nD@2PNdh0WGQ;09]fB@2MN4/0XWe@0:N2E@2[QUT0YX980:F1A`2T
OdP0Xgi90:9mB02QO4P0X7Y909miB0P0Y7]7202ONTD0202UP4`0Xgi:0:1kA`2NNDD0WGQ409mjAP2Q
O4P0XWe90P2MN4@209iiA@0409mjAP2PNdL0X7]70:5lB080XWa?00@0XG]>0:1jC@2PNTd0WgU<0P2N
N4/809ijBP0309mjAP2QO4P0Xgi:0080YH1<00@0Xgi:0:5lB02ONTH0W7Q80P2KMdL01`2JMTH0VgM7
09eiB@2ONd/0X7a<09mjAP2NNDD00`2LMd<02`2MN4@0WgY60:1kA`2TOE80XgaA0:9lC`2QNd`0X7Y9
09mjAP2NNDD0WGQ30080Ug<o0`2HM40309Ue@@040:=oC`2QODd0Wg];09eiB@80VgM70P2LN4P30:5e
A0<0X7A30P2OLd8909Qd@00709Ue@@2HM400UW8n09Ea?@2DL3`0UG4m09Ib?P0409Mc?`<0UW8n0P2E
LCd309Eb?00309Aa>`2CL3X0Tg0j0080TVli0P2GLd<01P2FLT80U71009=_?`2BKSh0TFdm091/?080
TVhn00@0TFdm091/?02@K3`0Sf/k0P2>JSX02`2?Jc/0T6`l095]?@2BKSh0Tflo09A`@02ELD40UW92
08m[>`2AKCd0TVhn0080Tflo00d0TVhn095]?@2?Jc/0U6ho099/?@2@JS/0SVPi08eW>02>J3T0SfTj
091Z>`2?Jc/0T6`l00<0TVhn00<0T6`l08iZ>P2=JCT00`2=JCT[ooooo`00:_ooool209EZ?`80UV]0
102GK4400`2FJch0Uf`o09Q]@00209U^@@0409Q]@02GK3l0UV/n09M]>`80V6hl0P2IKcd309Y`?P03
09]a?`2JL3h0V6hl0080Ufdk00<0V6hl09Y`?P2KLCl0102HKD0409M/?`P0V6e000<0Vg1309Y_@P2H
KD000`2FJch00`2GK3l0V6e009M]>`0209Q^?00509U_?@2KLCl0W79009ab@02MLd400P2NM48209ec
@@80W7900P2KLCl909Y`?PP0WW<n202NMD400`2OMD<0WWA209ab@00209]a?`0309ab@02NM480WgE3
00<0X7I40P2OMD<309id@P80VgLm00@0VgHo09]f@@2KMT40VgI20P2KMD@0202OMD<0X7I40:9hAP2S
NDL0Y7Y80:=iA`2RN4H0XGM50P2SNDL20:9hAP<0XGM500<0X7I40:9gBP2RMdX01P2RMdX30:9hAP80
XgU70`2TNTP80:=gAPP0Y7U6202RNDD80:=jAP80Y7Y:00@0Y7Y80:AkA`2TNdL0Y7]50P2TNd<20:Qm
BP80Yga900@0YW]80:EjA`2UNTL0YGY7202VODD20:=jAP80Y7]70`2UO4P0102VODT0ZH1<0:QoB`2V
ODT20:ElB0030:ImB@2WOTX0Z7m;00T0Z7m;2`2WOTX20:QoB`<0ZH1<202ZP4h0202/Pd/0[8==0:^2
CP2[PDl0ZWmB0:UnD`2YOU@0ZGeF202/Pdl0202[QU40ZHA?0:N2C@2VPD`0Yh9=0:Z5D02]R5<0/8]F
0`2[QU400`2ZQE00ZHA?0:V4C`020:R3CPP0[HA@0P2[PTh20:b3C`040:f4D02^QE40[XEA0:j5D@<0
ZXE@0P2[QU430:b7DPP0ZXE@00<0ZXEA0:b7D`2]R5@00P2^RED00`2]R5@0[8MC0:Z5D@040:f8D`80
[8MB0P2[QU420:Z6C0040:^6C`2[QU40ZhIA0:b7D`80[8IE0P2/Qe<20:f8E080[XUE0P2_RUH20:^6
DP80[8MC0P2]R5@20:j9E@P0ZXE@202/Qe<<0:^6DP<0ZXEA0P2YQ5030:R3C`80ZHA@1P2ZQE420:V4
D0<0Z8=?202WPTh30:J1C@D0Yh9>00<0ZXEA0:V4D02WPTh00P2VPDd00`2WPTh0ZHA@0:Z5D@020:^2
CP80ZX5=0P2YP4`20:QoB`030:9mB@2SOTX0YH1<0080YX5=00<0YH1<0:=nBP2RODT0202SOTX0102U
P4/0Y7m:0:AoBP2TOdX40:=nB@P0Xgi:0P2SOTT0102RODP0XGa70:1kAP2ONTD209iiA0P0XGe9202P
NdL20:=nBP040:9mB@2QO4P0X7]709mjAP80WWU5202MNDD20:9lC@090:5kC02PNT/0WgU:09ihB@2M
MdP0W7I709mjAP2NNDD0W7M30080VgI200<0W7M309iiA@2ONTH00P2MNDD209ijAP<0Wg]70P2PO4P8
0:1kA`040:5nB02PODL0X7e70:1mA`80Wga60P2NNdD20:5mB@80X7a80P2ONdL209ijAP0309mjAP2P
NdL0XWe900<0Xgi:0P2RODT20:AoB`<0YH1<0`2VPDd80:=oB`P0Y7m;00<0ZHEA0:N3C`2VPTh00P2U
PDd01P2VPTh0Yh=?0:V5D@2VPTh0Yh=?0:V5D@80ZXIB00<0ZHEA0:N3C`2VPTh00`2WPdl20:R4D0<0
ZHEA0P2XQ5020:V5D@<0ZXIB00<0ZhMC0:f9E@2]RED01P2]RED80:j9E@P0/HaH00<0[hUJ0;2:F`2a
Re`00P2aRe`0302_REX0[HMH0:b6E`2]R540[XUB0;2;EP2bSET0/heL0;:<G@2aRe`0/8YM0:b8F0<0
[HUI0P2^RUX20:n;F`80/HeM00<0/XiN0;>?G`2dT6000P2eTF400`2fTV80/XeP0;:=H0030;>>H@<0
]8mR2@2gTf<00`2fTV80]i=S0;VEI@020;ZFIP030;VEI@2gTf<0]Y9R00P0]Y9R2`2gTf<30;RDI080
^IEU0`2hU6@20;VEI@<0^YIV0P2hTV<20;NAHP80]Y1Q0P2eSf030;NCH`<0^9AT0P2iUFD01P2iU5l0
^IAP0;RCG`2hTV40^99S0;NAI080]i1U102hTel40;VDH0@0]i=O102hU6080;VEI@<0^YIR0P2iUF43
0;RDH0P0]i=O0`2hU6@20;NCH`@0]Y9R0P2gTf<20;RDI080^IEU00L0^YIV0;^GI`2jUVH0^IEU0;RD
I02gTf<0]Y9R0080]I5Q0`2gTel30;RDH080^IEQ0P2iUFD0102hU6@0]i=S0;NCH`2fTV820;FAH@T0
^9AP202hTel80;NDG0P0]i=S0`2hTV<30;VCI080^YAU202gTf<80;VEI@P0^9=V202hTel20;FAG@80
]Y9N0P2gTel20;RDH0H0]i=S0P2fTV820;NCH`80]Y9R0P2eTF420;B@H0@0^9AP0P2gTel20;JBGP80
]I1I00<0]Y5L0;JAG@2gTF000P2gTF800`2gTF@0]HmP0;F?H00:0;F?H0@0]Y1Q00D0/hiQ0;B?HP2e
T6<0]Y5T0;NBI@020;JAI0040;F@H`2eTF40]I5Q0;B@H080/hmO00<0/XiN0;6=G@2aSEd00`2eSf82
0;B>H@<0/heP00L0/8aL0;6=G@2bSUh0/XiN0;>?G`2dT600]I5Q0080]Y9R202dSe/80;>?G`030;F@
I02dSf<0/XeQ00<0/8]O00D0/HaP0;:=H@2bSUh0/hmO0;FAH@020;JBHP030;FAH@2cSel0/XiN0080
/XiN0P2aSEd20;2<G080[h]K00D0[HUE0:j:EP2^RUH0[h]G0;6=F@020;:>FP040;>?F`2bSUX0/hmK
0;B@G080]I5M00<0/hmK0;6=F@2`S5P00P2_RUd20;2;GP040;6<G`2bSF00/XeP0;:=H080]8iO0`2c
SEh30;:<G@80/hmO0P2bSUh20;6=G@80/8aL0P2aSEd0102bSUh0/hmO0;>?G`2dT6020;FAH@80]XeO
00H0/heN0;6=G@2`S5`0[H]K0:b<F`2[ReX30;6<G`<0/XeP0P2cSV420;>>HP030;:=H02bSUh0/XiL
0080/HeI00H0/HiH0;2;G`2`Rel0/HaO0;6=G@2bSU`20;>?F`070;>@FP2`SEL0/8aH0:n;E`2_ReT0
[h]K0:n:G@020:n:GP<0/hmO00<0/XiN0;6=G@2aSEd00P2`S5`20;6=G@80/XiN00L0/HeM0:n;F`2]
RET0ZhMG0;6=G@2`S5`0[h]K0080[XYJ00<0[h]K0;2<G02bSUh00`2dT6030;>?G`<0/XiN202_Re/0
202aSEd0/XiN0;>?G`2cSel0/XiN0:n;F`2]RET0[8QH0P2]RET0102^RUX0[h]K0;2<G02aSEd20;:>
GP030:j:EP2_ReL0/HeI0080/HeI00@0[h]G0:f9E@2/R5@0[XQK0P2^R5T00`2_REP0[hYF0;2;EP02
0;2;E0H0[h]K0P2`S5`80:j:FPP0[hYF0P2^RUH30:f9E@<0[8QD102_ReL40:j:EP<0[HQD0`2^RED2
0:n:EQ00[XUE00@0[8QD0:^7D`2[Qe<0ZhMC0P2ZQU820:V5D@060:b7D`2[QU80ZXEA0:V4D02XPdl0
Yh9>0P2VPDd01P2]PE00[89@0:b2D02/Q540ZXEA0:Z6DP80Z8MB202ZQE00102XQe80ZHQC0:b8E02^
RED20:n7E0030:n5D`2]Pe40[81?00<0ZhIB0P2ZQE430:V4D0P0Z8=?0P2ZQE430:V4D0<0Z8=?0`2V
PD`30:N2C@80Z8=>00<0Y7m;0:J1C@2YQ5000P2ZQE400`2WPTh0Xgi:0:5lB0080:V4D080ZXEA0P2Y
Q5030:R3C`030:N2CP2YQ500ZHA@0080Z8=?0P2WPTh:0:J1C@080:N2CP2XPdl0ZHA@0:V4D02XPdl0
YH1<0:=nBP2QO4P80:J2B0030:=nBP2TOd/0YX5=0080Yh9>00<0YX5=0:AoB`2SOTX00`2SOTT20:Ao
BP<0YH1;0`2VPDd20:F0C0<0Y7m;202VPDd80:QoB`P0Yh9>4@2XPdl01P2XPeH0Yh=C0:N3D`2VPU00
YH5=0:B1B`80Xh180P2VPDd00`2UP4`0Y7m;0:=nBP020:9mB@030:5lB02QO4L0XGa70080XWe80P2S
OTT20:AoBP080:5mC@2PO4`0WWY:09ijBP2ONd/0XWi>0:J2DP2XQ5@30:AoB0030:=nB@2RODP0XGa8
0080X7]7202TNdL809mjA@040:9mB@2QO4P0X7]709mjAP80WWU500@0WgY60:1kA`2MN4@0WGQ40P2N
NDD01@2ONTH0X7]70:1kA`2PNdL0XWa=0080XG]<0P2PNT/209miBP0309ihB@2NNTX0WWY:00H0WWY:
00<0WgY60:1kA`2QO4P00P2RODT00`2QO4P0X7]709mjAP0209]gA`80VWI600L0VgM709ijBP2PO4`0
XGe=09mjAP2NNDD0WGQ40080W7M300<0WGQ409mjAP2PNdL00P2QNTl01P2QNdh0X7Y;09miB02NNDD0
WGQ409eh@`80V7A00P2IMD4309Yf@P0509]g@`2ROTh0X7a<09ijBP2LN4P00P2KMdL209ahB0<0X7I4
0P2OMD<309id@PT0V7A000L0VGE109Qd@02FLSh0UG4m09A`?02ELCd0UW8n00@0Ug<o0`2FLSh209Ea
?@D0U70l0`2CKc/309Ea@@0309A`@02CKcl0TVhn0080TFdm0P2BKSh2095]?@04091/?02?Jc/0Sf/k
08m[>`80T6`l00@0TFdm099^?P2CKcl0U7100P2ELD400`2?Jc/0TFdm099^?P0209=_?`06099^?P2A
KCd0Sf/k099/?@2AJc`0SfTj0P2>J3T02`2?JCX0T6Xk095[?02?Jc/0T6`l095]?@2BKSh0TFdm091/
?02>JSX0SFTi00<0SVXj:oooool002[ooooo0`2EJSl209I[@0<0Ufa100<0UV/n09M/?`2HKD000`2H
KD000`2GK3l0UV/n09Q^?00409Q^?00609U_?@2JL3h0VW0n09Y`?P2IKcd0V6hl0P2GKC/00`2HKS`0
VFlm09Y`?P0209I[?P<0Uf`o0`2HKD0809M/?`0309]`@`2IKT40V6e000<0UV/n0P2HKD001P2GKC/0
V6hl09Q^?02IKcd0VW0n09]a?`80W7900`2MLd4309ab@080Vg4o2@2JL3h809eb?`P0WGA000<0WWA2
09ec@@2LLT000P2KLCl00`2LLT00WG=109id@P020:1fA080WgE30`2NM480102MLd40WGTo09ei?`2L
Md0209]f@@0609Ye@@2ILd80VG=209id@P2OMD<0XGM50`2SNDL20:5gA@<0XWQ60P2QMdD30:1fA0P0
XWM:0`2TNTP20:=iA`<0XWQ6202RMTD80:=hA@P0XWU5202TNdL20:AjBP040:AjB02TNdL0Y7]70:Ak
A@80Y7]30`2WO4T20:IkB0<0YGY7202VODL30:AkA`80YGa80`2VODT0102XOd/0Ygi:0:ImB@2UO4P2
0:ImB@030:MnBP2XOd/0Z7m;00P0Z7m;2`2WOTX20:QoB`<0ZH1<202ZP4h20:^2C0040:^2CP2ZP4h0
ZX1@0:UnD@80ZGiC202[PTh00`2/Qe80ZhIA0:R3CP020:J1C0040:R3CP2[QU40[HQC0:^6D@<0ZXE@
0`2YQ4l00`2XPdh0[8=?0:b3C`060:b3C`040:^2CP2/Pdl0[8=?0:b3C`<0[HA@00<0[XEA0:V4C`2Z
QE000P2ZQE020:^6D@80[8MB202ZQE000`2ZQE40ZhIB0:f8E0020:j9E@030:f8E02[QU80ZXEA00<0
[HQC0P2/Qe830:^6D@80ZXI<00@0ZhI?0:^6D@2[QU40[8MC0P2/QUD20:b7D`<0[HQD0`2^RED20:^6
DP80[8MC0P2]R5@20:j9E@P0ZhIA202]R5@90:^6DP80[8MC0P2[QU830:Z5D@030:V4D02ZQE40ZXEA
0080ZXEA0`2YQ5000`2XPdl0ZhIB0:Z5D@020:Z5D@80ZHA@0P2XPdl80:V4D0030:R3C`2WPTh0Yh9>
00D0Yh9>0P2YQ500102XPdl0Yh9>0:N2CP2XPdl20:V4D080Zh9>0`2ZPDd30:V0C080Y7m;00@0YH1<
0:J1C@2VPDd0YH1<2P2TOd/30:9mB0<0Xgi90P2TOdX80:AoB`80Xgi90P2RODP0102QO4L0X7]609mj
A@2ONTD80:5mB@P0XGa80P2SOTX20:9mB@040:5lB02PNdL0WgY609mjAPP0X7a800D0Xge>0:9lC@2Q
Nd`0X7Y;09miBP0309ihB@030:1kA`2ONTH0WGQ40080W7M300<0WGQ409mjAP2PNdL00P2NNTH209mk
A`<0X7a80P2QODT80:5lB0<0XGi80P2PODL309mlAP<0XGe90`2PO4P209mkA`80XWe90`2QO4P0102S
OTX0Y7m;0:F0C02TOd/30:F0C080YX5=0P2WPTh80:B0C0P0YH1<00<0ZHEA0:R4D02VPTh00P2UPDd0
1P2VPTh0Z8A@0:V5D@2WPdl0Z8A@0:V5D@80ZXIB00<0ZHEA0:R4D02WPdl00`2XQ5020:V5D@<0ZXIB
0`2YQE420:Z6DP<0ZhMC202^RUH80:n:EP@0/8]G102_RUH00`2_REX0/8YK0;6;G0020;6;G00;0:n9
FP2^R5T0[HMH0:j9DP2_RU<0/HaG0;:=F@2bS5/0/XaM0;6;G02aReh00`2_Re/20;2<G0<0/HeM0`2c
Sel50;B@H0040;:=H02cSV40/hiQ0;>>H@80]8mR0P2eT6<90;NCH`030;JBHP2gTf<0^IEU0080^YIV
00<0^IEU0;NCH`2fTV804P2fTV820;NCH`<0^9AT00<0^IEU0;NCH`2hU6@00P2hU6@20;VEI@80^YIV
0P2hTV<20;NAHP80]Y1Q0P2eSf020;JBHP80]i=S0`2hU6@01`2iUFD0^IAO0;VDH02hTel0^99Q0;RB
H`2gTF@00P2gT6D30;RCG`80]i9N0`2fTEd80;JBGPP0^IEU0P2jUV820;VEH@<0^9AP2@2gTel0102i
UFD0^9AT0;RDI02hU6@20;NCH`80]Y9R0`2gTf<20;RDI0<0^IEU00H0^YIV0;VEI@2iUFD0^9AT0;NC
H`2fTV820;FAH@@0^9AP0`2gTel00`2fTUh0^9AT0;RDI0060;NCH`T0^9AP202hTel80;NDGPP0]i=S
0P2gTF820;RBH`<0^I=T00<0^YAU0;NCH`2gTf<01P2gTf<80;VEI@P0^9=V202hTel20;FAG@<0]Y9N
0`2gTel:0;NCH`80]Y9R0P2eTF420;B@H0040;NCG`2fTUh0]Y9N0;JBGP80]I5M0P2dT5`20;F@F@03
0;F@F`2fTEd0]Y1O0080]i5R00<0]i5T0;F?H02eSf00202eSf020;J@H@050;NAHP2hTV<0^99S0;VC
I02eT6<00P2dSf801@2cSV40]8mR0;F@H`2fTF@0]i9U0080]I5Q00@0]91P0;>?G`2cSel0/XiN0P2a
SEd30;F?HP80]8iQ0`2cSF020;:>GP80/hmO00D0]91P0;FAH@2fTV80]Y9R0;NCH`080;>>FPP0/hmO
00<0]I1S0;B?HP2bSF000`2`Reh01@2aS5l0/XeP0;:>GP2cSel0]91P0080]I5Q00<0]91P0;>?G`2b
SUh00P2bSUh20;6=G@80/8aL0P2_Re/20;2<F080/HeI00D0/XiJ0;>?F`2dT5`0]91L0;>?F`020;B@
G0030;FAG@2dT5`0/hmK0080/HeI0`2`Reh20;6<G`<0/XeP0P2dSUl30;>=GP<0/XaM0`2bSUh30;6=
G@80/8aL0P2aSEd0102bSUh0/hmO0;>?G`2dT6020;FAH@80]XeO00@0/heN0;:>GP2aSEd0[XaL0P2/
S5/30;6<G`<0/XeP0P2cSV420;>>HP030;:=H02bSUh0/XiL0080/HeI00X0/HiH0;6<H02aS600/HaO
0;:>GP2bSU`0/XiJ0;>?F`2cT5X0[haF0P2_ReL00`2_ReT0[h]K0:n:G@020:n:GP80/hmO0`2bSUh3
0;6=G@0;0;:>GP2cSel0/hmO0;>?G`2bSUh0/8aL0:n;F`2^RUX0/HeM0;2<G02_Re/00P2^RUX01@2_
Re/0/8aL0;:>GP2dT600/HeM00<0/XiN102cSel80:n;F`80/HeM0P2bSUh0102aSEd0[h]K0:f9F@2/
R5P80;6=G@80[h]G0`2`S5P0102_ReL0[HUE0:b8E02^R5/20:j8F@030:n9F02_RUH0/8]F0080/8]D
202_Re/80:f9F@P0[hYF0P2^RUH30:f9E@<0[8QD0P2_ReL00`2^RUH0[HUE0:b8E0030:^7D`<0[HQD
0`2^RED20:n:EQ00[XUE0`2/R5@20:^7D`<0ZXIB0P2[QU800`2ZQE40ZHA@0:R3C`020:N2CP070:J1
C@2]PE00[89@0:b2D02/Q540ZXEA0:Z6DP020:R7DPP0ZXE@00@0Z8MB0:V8D`2/R5@0[XUE0P2_Qe@0
0`2_QE<0[H=A0:f1D0030:^6DP80ZXEA0`2YQ5080:R3C`80ZXEA0`2YQ5030:R3C`80Yh9=0`2XPdh3
0:V4C`080:AoB`2VPDd0Z8=?0:Z5D@2YQ500Yh9>0:AoB`2RODT;0:V4D080Z8=?0`2WPTh20:V4D080
Z8=?0P2WPTh:0:J1C@080:N2CP2XPdl0Z8=?0:R3C`2WPTh0YH1<0:AoB`2SOTX80:J1BP030:=nBP2T
Od/0YX5=0080Yh9>00<0YX5=0:AoB`2SOTX00P2SOTT20:AoBP<0YH1;00@0YX5<0:J1C@2VPDd0YX5=
0P2UP4`30:AoB`P0YX5=202XOd/80:F0C140Z8=?00H0Z8=F0:N3D`2WPe<0YX9@0:F1C@2TPD/20:>0
B080YX5=00<0YH1<0:AoB`2SOTX00P2RODT00`2QO4P0XGa70:9mB0020:9mB0<0Xgi900H0Y7m:09mk
B`2PO4`0X7a<0:5mC@2ROTh20:=oC`030:B0D02RODP0XWe800H0XWe8202TNdL809mjA@0309iiA@2O
NTH0WgY60080WgY600<0WWU509ag@`2LMd<00`2NNDD309mjAP80X7]70`2QNd`20:1jB`<0WgU:202N
NTX00`2PNdL0WgY609iiA@0209ehA00409iiA@2ONTH0X7]709YfAP80VGE500P0VWI609ahB02NNTX0
XGe=0:=oC`2ONTH0WWU509ehA080W7M300<0WGQ409iiA@2ONTH00P2NMd`00`2NN4/0WGM809egAP02
09ehA00309eh@`2JMT80VWI20080VgM30`2LN4@01P2MNDD0XGe=09mkB`2MNDT0VgM709YfAP80VgM7
00<0W7Q80:1fA02PMT@00P2OMD<309id@P0309ec@@2HM400V7A000L0V7A000L0VGE109Qd@02FLSh0
UG4m09A`?02ELCd0UW8n00@0Ug<o0`2FLSh209Ea?@<0Tflk102DL3`00`2ELCd0Tflo09=_?`0309=_
?`@0TVhn0`2AKCd3091/?00608m[>`2@K3`0TFdm095]?@2BKSh0Tflo0P2DL400102ELD40Sf/k095]
?@2BKSh209=_?`05099^?P2AKCd0Sf/k095[?02@JS/00`2?JCX01@2@JS/0TV`m099/?@2?Jc/0T6`l
0080TFdm00@0T6`l08m[>`2>JSX0SFTi0`2@K3`[ooooo`00:_ooool209AY?P80UFXo0P2FJd0209M/
@@0309I[?P2GK3l0Uf`o00@0Uf`o00`0UV/n09Q^?02HKS`0Ufdk09I/>P2GKC/0V6hl09Y`?P2KLCl0
VW0n09U_?@2GKC/209I/>P0409M]>`2IKcd0VW0n09AY?080UFXm00<0UV/n09M/?`2HKD000P2IKT48
09M/?`0309Y_@P2IKT40Uf`o0080UV/n00<0Uf`o09Q]@02IKT400`2HKS`00`2IKcd0VW0n09Y`?P02
09]a?`H0W7900P2KLCl909Y`?PP0WG50202MM40309ec@@80W7900`2MLd4309me@`<0WWA20P2MLd42
09ij@00409eh@@2LMd80VWE009Ud@080V79100P0WWA209me@`2QMdD0XWQ60:=iA`2RN4H0XGM50:1f
A080XWQ60`2QMdD30:1fA0P0XWQ80P2UNdT0102TNTP0XgU70:=iA`2RN4H20:5gA@P0XWI5202SN4D8
0:9iA@P0Y7]70P2TNTX0102TNTP0Y7]70:AkA`2TNdD20:Ak@`@0YW]8102UNTL80:ImB@80Y7]70`2U
O4P80:ImB@030:MnBP2XOd/0Z7m;0140Z7m;0`2WOTX20:QoB`<0ZH1<202ZP4h40:Z1C@@0ZGm=202[
PTh01`2]R5<0[8MB0:V4C`2WPTd0YX5<0:N2C@2XPdh02@2YQ4l@0:b3C`80ZHA?0`2ZQE030:^6D@P0
ZXE@00<0ZXEA0:^6DP2/Qe<00P2]R5@00`2/Qe<0ZhIB0:Z5D@020:f8D`80[8MB0P2[QU420:Z5D080
ZXI<00@0ZhI?0:^6D@2[QU40[8MC0P2/QUD20:b7D`H0[HQD0P2[QU820:b7D`80[HQD0P2^RED80:^6
D@P0[XUE2@2[QU830:b7D`80ZhIB0`2ZQE420:b7D`030:^6DP2ZQE40ZHA@0080Z8=?00<0Yh9>0:^6
DP2[QU800`2ZQE430:V4D0P0ZhIB0`2YQ5040:R3C`030:N2CP2YQ500ZHA@00@0Z8=?0P2YQ5020:^2
CPH0ZX5=00<0YH1<0:J1C@2VPDd0102VPDd00`2UP4`0YX5=0:J1C@060:J1C@060:1kAP2QO4L0XGa7
0:9mB02SOTT0Y7m:0P2UP4/80:F0C0030:AoBP2SOTT0Xgi90080XWe80P2QO4L00`2PNdH0XWi:0:9n
BP060:9nBPP0XWe900<0Y7m;0:=nBP2SOTX00P2RODT20:5lB0030:1kA`2ROTX0XWi:00H0XWi:00@0
Y7i=0:=mC02QNdX0X7Y90P2ONDP01@2PNTT0XG]:0:5lB02PNdL0WgY60080WGQ400<0WgY60:1kA`2Q
O4P00`2PO4P30:5mB@<0XWi:202RODT30:9oB@80XGi80`2PODL80:5mB@080:F0C02SOTX0XGa80:1k
A`2QO4P0Xgi:0:J1C@2WPTh30:F0C080YX5=0`2WPTh80:F1C@P0Yh9>00<0ZHEC0:R4DP2WPe400P2V
PU00102WPe40Z8AB0:V5D`2XQ5060:V5D@040:R4D02YQE40ZHEA0:V5D@<0ZXIB0P2[Qe<30:Z6DP80
ZhMC0`2/R5@80:n;E`P0/8]G102_RUH40:j9E@<0/8YK00<0/H]L0;2:F`2`RU/00P2_REX0202`Re@0
/HaE0;6<E`2bSET0/XaK0;:<G@2aRe`0/H]N0`2aSEd20;:>GP<0/hmO0P2fTV80102eTF40]91P0;B@
H02cSel20;:>GP<0/hiQ0P2dSf830;F@H`T0]i=S00<0]Y9R0;NCH`2iUFD00P2jUVH00`2iUFD0]i=S
0;JBHP0C0;JBHP80]i=S0`2hU6@20;NCH@<0^9AR0`2iUF<20;RBH`80]i5R0P2fT6420;F?H0<0]Y9R
0P2gTf<30;RDI0060;VDG`2iU600^9=O0;RBH@2hTV<0]i5T0P2gT6D20;RCG`040;NBGP2fTEd0]Y5M
0;F@G080]8mK0P2fTUh40;FAG@80]91L202hU6@30;VEH@<0^9AP2P2gTel20;VEI@<0^9AT0`2gTf<8
0;RDI0030;VEI@2hU6@0^9AT0080]i=S0P2fTV80102eTF40^IEQ0;VEH@2hU6020;NCG`030;JBGP2e
TEd0]I5M00<0]i=S0`2hU6@20;VEI@T0^9AP202hTel80;NCG`P0]i=S0`2gTF820;RBH`<0^I=T202g
Tf<80;RDI0P0^9=V202hTel20;FAG@H0]Y9N0`2fTV840;NCH`030;RDI02gTf<0]i=S0080]Y9R0P2e
TF420;B@H0<0]I5M0P2dT5`30;>?F`80]8mH00H0]I1K0;F@G02fT5l0]Y1Q0;NAHP2gTF@:0;F?H004
0;J@H@2gTF80^99S0;VCI080^YAU00P0]Y5T0;F@H`2cSV40/HaO0;:=H02dSf80]i9U0;VDI`80]I5Q
00@0]91P0;>?G`2cSel0/XiN0P2aSEd30;F?HP80]8iQ0`2cSF00102cSel0]91P0;B@H02dT6020;FA
H@80]Y9R00<0]i=S0;>>FP2cSUX01P2cSUX80;>?G`030;FAH@2dT600/XiN00<0/8aL00D0/HeM0;:>
GP2aSEd0/hmO0;B@H0020;FAH@030;B@H02cSel0/HeM0080/XiN0P2aSEd20;2<G080[h]K0`2bSUX0
0`2cSe/0]91L0;B@G0020;FAG@@0]91N00@0/hmM0;:>G02bSU`0/HeK102aS5l40;:=H080]8iO0`2c
SEh30;:<G@H0/HeM0P2`S5`20;6=G@040;:>GP2cSel0/hmO0;B@H080]I5Q0P2gSV00102dSUl0/XiN
0;6=G@2^S5`20:b<F`<0/HaO0`2bSF020;>>H@80/hiR00<0/XeP0;:>GP2bSU`00P2aSET01P2aSUP0
/HaP0;6<H02bSF00/XiN0;:>G080/XiJ00L0/XmI0:j;E@2_ReL0[h]G0:n;F@2_Re/0/8]N0080/8]O
1P2bSUh20;6=G@@0/hmO0P2bSUh01@2aSEd0/8aL0;6=G@2`S5`0[h]K0080[XYJ00@0[h]K0;2<G02b
SUh0]91P0P2`S5`0102aSEd0/XiN0;:>GP2cSel20;B@H0P0[h]K0`2aSEd20;2<G0030:n;F`2^RUX0
[HUI0080/hmO0P2bSUh0102aSEd0/8aL0;2<G02_Re/40:n;E`80[XYF0P2]RED01P2^R5/0[XQI0:j8
F@2_REP0[hYF0;2;EP80/8]D0`2`S5`40:n;F`030:j:FP2]RET0[HUI00H0[HUI202_RUH20:j:EP<0
[HUE0`2/R5@01P2_ReL0[XYF0:f9E@2/R5@0ZXIB0:V5D@80Z8A@0`2]R5@30:j9E@80[hYF402^RED3
0:b8E0<0ZhMC0P2ZQU830:Z5D@030:V4D02XPdl0Z8=?0080Yh9>00H0[H5@0:b2D02/PU00[8AA0:Z5
D@2ZQU820:R7DPP0ZXE@00@0ZHQC0:Z9E02]RED0[XUE0P2`R5D00`2_QE<0[H=A0:f1D0030:^6DP80
ZXEA2`2YQ5020:Z5D@<0ZHA@0`2XPdl20:R3CP80ZHA?102ZQE00202TOd/0YX5=0:N2CP2YQ500Z8=?
0:N2CP2UP4`0Y7m;2P2YQ5030:R3C`<0Yh9>0P2YQ5020:R3C`80Yh9>2P2VPDd40:N2CP80YX5=00<0
YH1<0:AoB`2UP4/01`2UP4/00`2SOTX0Y7m;0:J1C@020:N2CP030:J1C@2TOd/0Xgi:00<0Y7m:0`2U
P4/20:J1C0<0YX5=0P2UP4`30:AoB`P0YX5=202WOd/80:=nBQ40Z8=?00H0Z8=F0:N3D`2WPe<0YX9@
0:F1C@2TPD/20:>0B080YX5=00<0YH1<0:AoB`2SOTX00P2RODT00`2QO4P0XWe80:9mB0020:9mB0@0
Xgi900<0WWY80:1lBP2ROT`00P2TP4h0102SOdd0XGe;0:1lBP2PNTT20:5lB0050:5lA`2RODP0XWe6
0:9mAP2SOdD0202SNTH809mjA@0309]f@P2MN4@0WgY60080X7]700<0WWU509]f@P2IM4000P2NNDD6
09mjAPP0X7Y9202NNTX00`2PNdL0WWU509ag@`0209Ye@@0309ag@`2NNDD0X7]700<0VGE500P0VWI6
09ahB02ONd/0XWi>0:=oC`2PNdL0WgY609ehA0<0W7M30P2NNDD209]dB@0309]eB02LMTL0W7I50080
WGQ400@0WGQ309ahA02LN4@0W7Q40P2MNDD309ijAP0309mkB`2NNTX0W7Q800<0VWI600<0VgM709ah
B02NMT<00P2NMT<309ee@P80W7A12@2HM4001`2IMD40V7A009Ib?P2ELCd0U70l09Ea?@2FLSh0102G
Lcl309Ib?P80UG4m00D0TVhl09=_?@2CKcd0Tflm09A`?P0309Ea?`<0TFdm0`2BKSh209=_?`X0TFdm
0P2BKSh209=_?`80U71000<0Sf/k095]?@2BKSh00P2CKcl00`2BKSh0TFdm08m[>`04091Z>`80TF/l
00<0TV`m09=]?P2@K3`00`2@K3`0102?Jc/0SVXj08iZ>P2=JCT3095]?B_ooooo000Zooooo`<0U6Tn
0P2EJSl309I[@00309M/?`2FJch0UV/n00@0UV/n00@0Uf`o09U_?@2GKC/0UV`j0P2EJcT01P2GKC/0
VFlm09]a?`2IKcd0V6hl09M]>`80UV`j00<0Ufdk09Q^?02IKcd00P2DJC`00`2EJSd0UV/n09M/?`02
09Q]@00309U^@@2FJch0UV/n00H0UV/n00<0VFi109Q]@02GK3l00P2FJch00`2GK3l0VFi109Y_@P03
09Q^?0@0VFlm00<0VW0n09]a?`2KLCl0102KLCl209ab@0T0VW0n202LL44809ed@00309ab@02MLd40
WG=100@0WG=100<0W79009me@`2OMD<00`2NM48309ec@@80WWY000@0WGQ109ag@P2JMD00VGA00P2H
LT400`2MLd40WWA20:1fA0030:9hAP030:5gA@2PMT@0XGM50080XGM50`2PMT@209me@`P0XWQ60P2U
NdT0102TNTP0XgU70:=iA`2RN4H20:5gA@P0XGE4202SN4D80:9iA@P0YGa80P2TNTX0102TNTP0Y7]7
0:AkA`2TNdD20:Ak@`P0YGY7202VODT30:ElB0<0YWe90P2WOTX20:ElB0030:ImB@2WOTX0Z7m;01@0
Z7m;0`2WOTX20:QoB`<0ZH1<202YOdd40:V0C0@0ZH1:202ZPDd01P2/Qe80ZhIA0:V4C`2XPdh0Yh9=
0:J1C080Yh9=102XPdh40:V4C``0[8=?102[PTh30:V4C`<0ZXE@0P2[QU480:Z5D0030:V4D02ZQE40
[8MC0080[HQD00<0[8MC0:Z5D@2YQ5000`2/Qe820:^6D@<0ZXE@0P2ZQT`0102[QTl0ZhIA0:^6D@2/
Qe<20:b6E@80[HQD1P2/Qe<20:^6DP80[8MC0P2]R5@20:j9E@P0[8MB202^RED90:^6DP80[HQD0P2/
Qe<20:^6DP80ZXEA00H0[HQD0:b7D`2/Qe<0ZhIB0:Z5D@2YQ5020:R3C`<0ZhIB0`2ZQE420:V4D0P0
[8MC0P2[QU820:Z5D@040:V4D02XPdl0Z8=?0:R3C`P0ZHA@0P2ZPDd60:^2CP<0Yh9>0P2VPDd;0:N2
CP060:5lA`2RODP0XWe80:=nB@2TOdX0YH1;0P2VPD`80:F0C080Y7m:102SOTT20:9mB0P0Xgm;202S
OTX20:AoB`@0Xgi:0P2RODT80:=oB`070:F0C02SOTX0XGa80:1kA`2ONTH0X7]70:9mB@020:=nBP07
0:5lB02PNdL0WgY609mjAP2PNdL0XGa80:=nBP020:5mB@<0XWi:102SOd/80:=nBP<0Xh1:0P2ROdT3
0:5nB0P0XWi:00<0YX5=0:AoB`2RODT00P2QO4P00`2TOd/0YX5=0:R3C`020:F0C080YX5=0P2WPTh2
0:R3C`P0YX9>202XPdl00`2ZQUH0ZHEE0:N3D`020:J2DP040:N3D`2YQED0ZXIF0:Z6DPH0ZHEA1@2Z
QU820:^7D`80[8QD0`2[Qe<20:b8E0<0[HUE202`S5P80;6<F080/8]G0P2_RUH20:j9E@80[HQD00<0
/H]L0;2:F`2`RU/00P2`RU/30;6;G0080;>>E`2bSEH0/XeH0;6<F02aReX0/H]L0;:<G@2bS5l30;:>
GP<0/hmO0P2dT6020;NCH`040;JBHP2eTF40]91P0;>?G`80/XiN0P2cSV420;B?HP80]I1S0P2fTF@9
0;NCH`030;JBHP2gTf<0^IEU0080^YIV00<0^IEU0;NCH`2fTV80202fTV8:0;FAH@80]Y9R0P2gTf<2
0;RDI0<0]i=O0`2hU6020;VEH@80^99S0P2gTF820;J@H@80]HmP0P2eTF420;JBHP80]i=S0P2hU6@0
1P2iU5l0^IAP0;RCG`2hTV40^99S0;NAI080]i1U0P2hTel0102gTUh0]Y5M0;JAG@2eT5`20;B?F`03
0;NCG`2fTUh0]Y9N0080]I5M0P2dT5`00`2cSe/0^9AT0;RDI0060;RDI080^IEQ0`2hU60;0;NCG`<0
^IEU0`2hU6@20;NCH`P0^9AT102gTf<40;JBHP050;VEH@2hU600^9AP0;NCG`2fTUh00P2eTEd00`2d
T5`0]i=S0;NCH`030;RDI0<0^IEU2@2hU6080;RCG`P0]i=Q202gTf<20;J@H@80]i5R0P2hTV<20;VC
I0P0]i=S202hU6@80;RCIPP0^9=O0P2fTUh60;FAG@80]I5Q0P2fTV80102gTf<0^9AT0;RDI02hU6@2
0;NCH`80]Y9R0P2eTF420;B@H0040;FAG@2dT5`0]91L0;B@G080/hmK0P2bSUX20;B?F0030;B?FP2e
T5`0]HmN0080]Y1Q00<0]Y1S0;F?H02eSf00202eSf020;J@H@070;NAHP2hTV<0^99S0;VCI02fTF@0
]8mR0;:=H0020;6<G`030;>>H@2fTF@0^9=V0080]I5Q00@0]91P0;>?G`2cSel0/XiN0P2aSEd30;F?
HP80]8iQ0`2cSF050;B@H0@0]I5Q202cSUX80;>?G`030;FAG`2dT5h0/XiL00<0/8aJ00D0/HeK0;:>
G02aSEd0/XiN0;>?G`020;FAH@030;>?G`2bSUh0/HeM0080/XiN0P2aSEd20;2<G080[h]K0`2cSe/4
0;B@G0050;FAG@2eTF40]91P0;B@H02cSel0102bSUh80;:=H080]8iO0`2cSEh30;:<G@H0/8aL102a
SEd0102bSUh0/hmO0;>?G`2dT6020;FAH@80]hiP00@0]8iO0;:>GP2bSUh0[heM0P2]SE`30;6<G`<0
/XeP0P2cSV420;>>HP030;:=H02bSUh0/XiL0080/HeI00X0/HiH0;:=H@2bSF40/XeP0;:>GP2bSU`0
/XiJ0;6=F@2aSUP0[X]E0P2^RUH00`2_ReT0/8aL0;2;GP020;6<H080/HeM1P2bSUh00`2dT600/hmO
0;>?G`050;:>GP030;6=G@2`S5`0[h]K0080[XYJ00D0[h]K0;2<G02bSUh0]91P0:n;F`020;2<G005
0;6=G@2bSUh0/hmO0;>?G`2dT600202_Re/20;2<G080[h]K0`2^RUX01P2_Re/0/hmO0;>?G`2bSUh0
/HeM0;2<G080[h]K00<0[XYJ0:n;E`2_ReL00P2^RUH40:f9E@060:j8F`2^R5T0[XQI0:n9F02_RUH0
/8]F0P2`Re@20;6=G@80/8aL00@0[h]K0:j:FP2^RUX0[XYJ202]RET80:n:EP80[XYF0`2]RED30:b8
E080[XYF00H0[HUE0:^7D`2ZQU80ZHEA0:R4D02WPdl30:f8E0<0[XUE0P2_RUH@0:j9E@80[HUE0`2/
R5@30:^7D`030:Z5D@2YQ500ZHA@0080ZHA@0`2XPdl01P2]PE00[89@0:b2D02/Q540ZXEA0:Z6DP80
Z8MB202ZQE00102YR5<0ZXUD0:f9E@2_RUH20;28E@030;26E02^Q580[X9A00<0ZhIB0P2ZQE4;0:V4
D080ZXEA0`2YQ5030:R3C`80Z8=>0P2YQ4l40:Z5D080YH1<00H0Yh9>0:R3C`2XPdl0Yh9>0:J1C@2U
P4`80:V4D0<0Z8=?0`2WPTh20:J1C@80ZHA@0P2XPdl20:N2CPX0YX5=00<0Z8=?0:N2CP2WPTh01@2V
PDd80:F0B`030:=nBP2TOd/0YX5=0080Yh9>00<0YX5=0:AoB`2SOTX00P2TOdX30:F0B`<0YX5<0`2V
PDd20:F0C0<0Y7m;202VPDd80:F0B`P0Xgi:4@2XPdl01P2XPeH0Yh=C0:N3D`2VPU00YH5=0:B1B`80
Xh180P2VPDd00`2UP4`0Y7m;0:=nBP020:9mB@030:5lB02SOTT0Xgi90080Xgi9102RODP00`2ONdL0
XGe90:=oB`020:F1C@030:9nBP2ONdL0WGU50080X7Y;00@0X7Y90:5lB02QO4D0XWi40P2ROT880:=j
APP0WgY500<0VgI209ehA02ONTH00P2PNdL00`2NNDD0VgI209Ud@00609mjAP80WWU5202PNdL809ij
BP030:1kA`2NNDD0VgI20080VWE100<0VgI209iiA@2PNdL00P2JMTH04`2IMDD0VWI609ahB02NNTX0
XGe=0:=oC`2QO4P0X7]709iiA@2LMd<0VgI209ag@`2MN4@0WWU509YcB02KM4T0VgE809]eAP2LMTD0
0P2LMd<00`2MN4<0W7Q409ahA00209eiA@@0WWY600<0WGU909ahB02KMdL00P2IMDD00`2JMTH0VgM7
09ahB00209ag@`<0VgI20`2JMD4909Qd@00709Ue@@2HM400UW8n09Ea?@2DL3`0UG4m09Ib?P0409Mc
?`<0UW8n0P2ELCd309=_?`D0U7100`2@K3`3095]?@80TVhn102AKCd8099^?P@0Tflo00<0Sf/k095]
?@2BKSh00P2CKcl0102BKSh0TFdm08m[>`2@JS/2095[?0@0TV`m00@0TF/l091/?02@K3`0Sf/k1@2>
JSX3095]?B_ooooo000Zooooo`0409=X?@2DJCh0U6Tn09AY?P80UFXo0P2FJd000`2GK3l0UV/n09EZ
?@0309EZ?@0509I[?P2GK3l0VFlm09M]>`2EJcT00P2DJSP01P2FK3X0VFlm09]a?`2IKcd0V6hl09I/
>P80UF/i00<0UV`j09Q^?02IKcd00`2EJSd309I[?P80Uf`o202FJch209Q]@0<0UV/n00<0V6e009U^
@@2KL4<0202HKS`309Y`?P<0Vg4o0P2LLT0909Y`?PP0W713202LLcl00`2KLCl0W79009ec@@0209id
@P0409ec@@2LLT00Vg4o09me@`<0WWA20P2MLd4209ab@080WGTo00@0W7M009]f@@2KMT40VWE10P2I
Ld80202MLd40WWA20:1fA02QMdD0XWQ60:5gA@2PMT@0WgE30`2QMdD20:1fA0<0WgE3202RNDD30:Aj
B080XgU70`2RN4H80:5eA0P0XWM4202RNDD80:ElB080Y7Y:00@0Y7Y80:AkA`2TNdL0Y7]50P2TNd<0
102SN4D0Y7U60:AiAP2TNDH30:EjA`030:IkB02VO4X0YWa:00H0YWa:0`2UO4P20:ImB@<0Ygi:00<0
XgY60:AkA`2VODT00P2XOd/00`2YP4`0Z7m;0:QoB`090:QoB`P0ZH1<0`2WOTX20:QoB`<0ZH1<202Y
Odd0202WOD/0Z7i<0:QoB`2XOdT0ZH180:V1AP2YPD@0ZX95202ZPDd0102[QU40ZXE@0:V4C`2XPdh7
0:N2C@80Z8=>0`2YQ4l80:^2CP<0[8=?0P2[PTh30:Z1C@80Z8=>0P2YQ4l30:Z5D0030:^6D@2ZQE00
ZXE@00H0ZXE@00<0ZHA@0:Z5D@2[QU800P2/Qe<00`2[QU80ZXEA0:V4D0020:b7DP80ZhIA0`2ZQE00
102YQ4l0ZXI<0:Z6C02[QTl20:^6D@030:b7D`2/QUD0[8IE0080[HQD0`2/Qe<50:^6DP80[8MC0P2]
R5@20:j9E@P0[8MB202]R5@90:^6DP<0[HQD0P2/Qe<30:^6DP040:b7D`2[QU80ZhIB0:^6DP@0ZXEA
0P2/Qe<20:^6DP<0ZXEA00<0ZHA@0:b7D`2/Qe<0202/Qe<20:^6DP030:Z5D@2YQ500Z8=?0080Z8=?
00L0ZHA@0:Z5D@2[QU80ZhIB0:Z5D@2YQ500Z8=?0080ZX5=0`2[PTh30:b3C`030:V4D02XPdl0Yh9>
0080YX5=00<0Yh9>0:R3C`2YQ500202XPdl40:F0B`<0YX5<00<0Yh9=0:J1C@2VPDd01P2VPDd80:Ao
BPP0Y81<402TOd/80:9nBP030:J1C02TOdX0XGa70080X7]600H0XGa70:AoBP2VPD`0Y7m;0:=nBP2Q
O4P20:1kA`040:5lB02SOTX0Y7m;0:9nBP<0Xgm;0P2TP4`30:F1C@P0Y7m;0`2TPD/20:>0BP<0XWm9
0`2ROTX30:=oB`80Y81<0P2UP4`30:AoB`030:F0C02WPTh0Z8=?00<0YX5=0P2WPTh30:R3C`P0Yh=?
202ZQE400`2ZQEP0ZHAG0:R3EP020:N2E@060:R3EP2YQ5L0ZXEH0:^7D`2ZQU80ZHEA0P2XQ500102Y
QE40ZXIB0:^7D`2ZQU830:^7D`80[8QD0P2]RED30:b8E080[HUE0`2^RUH80;6=F@T0/XeI0P2aS5P0
1@2`ReL0[hYF0:j9E@2^RED0[HQD0080/H]L00l0/8YK0:n9FP2`RU/0/H]L0;:<G@2cSEh0]I1I0;B?
F02bSEP0/HaH0;6;FP2aRe`0/XaM0;:<G`2aSEd00`2bSUh20;>?G`80]91P0P2gTf<0102fTV80]I5Q
0;FAH@2dT6020;>?G`<0]8mR0P2eT6<30;JAI0T0]i=S00<0]Y9R0;NCH`2iUFD00P2jUVH00`2iUFD0
]i=S0;JBHP080;JBHP/0]I5Q0P2fTV830;NCH`80]Y=M0P2gU5h30;REG`030;VFH02hTV<0^99S0080
]i5R0P2fT6420;F?H0<0]I5Q0P2fTV830;NCH`060;VDG`2iU600^9=O0;RBH@2hTV<0]i5T0P2gT6D3
0;RCG`80]i9N0`2fTEd20;RDH0040;NCG`2fTUh0]Y9N0;FAG@80]91L202gTf<0102iUF40^9AP0;RD
H02hU6020;NCG`80]Y9N202gTel20;ZFIP80^IEU0`2hU6@0102gTf<0^IEU0;VEI@2iUFD20;RDI0<0
]i=S202fTV830;NCG`<0]Y9N0P2eTEd60;VEI@80^9AT2@2hU6080;RCGa00]i=S0`2fT6420;NAHP<0
^99S402gTf<80;RCIPP0^9=O0P2fTUh30;FAG@<0]91L00H0]91P0;FAH@2eTF40]Y9R0;NCH`2hU6@2
0;VEI@80]i=S0P2fTV820;FAH@80]91P0`2eTEd20;B@G0<0/hmK00P0/hiG0;B?F02dSeX0]8mK0;F?
GP2eSf00]Y1Q0;J@Ha00]HmP00P0]8mR0;>>H@2bSF00/XeP0;>>H@2dSf80]I1S0;JAI080]I5Q00@0
]91P0;>?G`2cSel0/XiN0P2aSEd30;F?HP80]8iQ0`2cSF090;>?G`P0/XeI202cSel00`2eTEd0]91L
0;:>FP030;2<F0050;6=F@2bSUX0/HeM0;:>GP2cSel00P2dT6000`2cSel0/XiN0;6=G@020;:>GP80
/HeM0P2`S5`20:n;F`P0/hmK0P2eT6<00`2cSV40/XeP0;6<G`020;:=H0030;>>H@2dSf80/hiQ0080
/hiQ0`2bSF000`2aS5l0]8iO0;B>G`030;>=GP<0/XaM0`2_Re/30;2<G0@0/HeM00@0/XiN0;>?G`2c
Sel0]91P0P2eTF401P2hSf40]hiP0;F?H02cSel0/XiN0:n=G@80[HeL0`2aS5l30;:=H080/hiQ0P2c
SV800`2bSF00/XiN0;:>G0020;6=F@060;6>F02cSV80/hiR0;:=H02bSUh0/XiL0P2aSET02@2aSUP0
[HYD0:f9E@2^RUH0[h]I0;2<G02aS5l0/HaP0;:=H@030;6=G@<0/XiN0`2cSel01@2bSUh0/HeM0;2<
G02`S5`0/HeM0080/XiN00<0/HeM0;2<G02_Re/00P2^RUX0102_Re/0/8aL0;:>GP2dT6020;2<G0<0
/HeM0`2bSUh80:n;F`030;2<G02_Re/0[XYJ0080[HUI00<0[XYJ0:n;F`2`S5`00P2aSEd20;2<G007
0:n;F`2^RUX0[XYJ0:f9F@2`S5P0[h]G0:f9E@030:b8E080[HUE00H0[XQK0:j8F@2^R5T0[hUH0:n:
EP2`ReH20;2;E0060;:>GP2aSEd0/HeM0;2<G02_Re/0[XYJ0P2]RET80:b8F0P0[hYF0P2^RUH30:f9
E@<0[8QD0`2]RED00`2/R5@0ZhMC0:Z6DP020:V5D@<0[HQD0`2^RED20:n:EQ00[XUE0`2]RED20:b8
E0<0ZhMC202YQ5001P2]PE00[89@0:b2D02/Q540ZXEA0:Z6DP80Z8MB202ZQE020:Z9E0070:j:EP2_
RUH0/HUF0;69EP2`QU@0[XAB0:j2D@030:^6DP80ZXEA2`2YQ5020:Z5D@<0ZHA@0`2XPdl20:N2C@<0
Z8=>0`2YQ4l20:F0C0030:J1C@2WPTh0Yh9>00<0Yh9>202YQ5030:R3C`80Yh9>0`2VPDd20:V4D080
Z8=?0P2WPTh:0:J1C@030:R3C`2WPTh0YX5=0080YH1<00<0YX5=0:N2CP2WPTh0202TOd/00`2SOTX0
Y7m;0:J1C@020:N2CP040:J1C@2TOd/0Xgi:0:AoBP<0YH1;0P2VPD`20:N2C@<0YX5=0P2UP4`30:Ao
B`P0YX5=202TPD/80:AoBa40Z8=?00H0Z8=F0:N3D`2WPe<0YX9@0:F1C@2TPD/20:>0B080YX5=00<0
YH1<0:AoB`2SOTX00P2RODT00`2QO4P0Y7m:0:=nB@020:=nB@<0XWe800<0XGa70:5nB02ROdT00`2T
PD/02`2QOTP0Wga609ejA02QNTl0XG]>0:5kC02QO4P0XGa50:1l@02PO3h0X7dm00P0XWU5202ONTD0
0`2NNDD0WgY609mjAP0209mjAP0309iiA@2LMd<0W7M30080X7]70`2ONTH309iiA@<0WgY50P2PNdH3
0:5lA`P0WWY:00<0WgY609iiA@2MN4@00P2LMd<01@2MN4@0WWU509mjAP2LN4P0VgM70080VWI600P0
VgM709eiB@2ONd/0XGe=0:9mB@2PNdL0WWU509ag@`80VgI200L0W7M309ehA02LMDX0W7E:09afB@2L
MTL0W7I50080W7M300<0W7M209]g@`2LN4@00P2LN4@209eiA@80WWY600<0W7Q809]gA`2IMDD00P2H
M4@0102IMDD0VgM709ahB02KMd<309Yf@P80VGE12`2HM4001`2IMD40V7A009Ib?P2ELCd0U70l09Ea
?@2FLSh0102GLcl309Ib?P80UG4m0`2EL4<01@2DKd80Tfi109=^@@2CKT40TVe000P0T6`l0`2AKCd2
099^?P<0Tflo102BKSh409=_?`0308m[>`2AKCd0TVhn0080Tflo00<0TVhn095]?@2?Jc/00P2BK3d3
09=]?P06095[?02@JS/0SfTj095]?@2@K3`0SVXj0`2=JCT208iZ>P<0T6`l:oooool002[ooooo0P2C
J3d309AY?P<0UFXo00<0Uf`o09I[?P2EJSd00P2DJC`01P2EJSd0UV/n09M/?`2IKcd0Ufdk09AZ>080
TfTg00H0UV`j09U_?@2LLT00VFlm09M]>`2FK3X209E[>@0309I/>P2GKC/0VFlm00@0UV/n302EJSd0
0`2HKD00Uf`o09I[?P0209I[?P0309Q]@02JKd80Vg1300P0V6hl0P2IKcd209Y`?P80Vg4o0P2LLT09
09Y`?PP0Vfm2202LLcl00`2KLCl0W79009id@P0209me@`0309id@P2LLT00Vg4o00<0WWA20P2MLd43
09ab@080VgLm00@0VgHo09]f@@2KMT40VgI20P2KMD@02@2LLT00WWA20:1fA02QMdD0XWQ60:5gA@2P
MT@0WgE30:5gA@030:1fA080WgE30P2NM4880:9i@`<0XWQ60P2SNDL30:AjB0P0X7A3202RMd@80:9i
A@P0YGa80P2TNTX0102TNTP0Y7]70:AkA`2TNdD20:Ak@`<0XgQ500<0Y7U60:EjA`2UNTL00P2VNdP8
0:IlC0040:ElB02VODT0YWe90:ImB@80Ygi:0P2XOd/0102RNDD0Y7]70:ImB@2XOd/20:V0C0/0Z7m;
202YP4`30:MnBP80Z7m;0`2YP4`80:QnC0080:MmC@2WOD/0Ygi:0:QoB@2YPDH0ZH540:Z2A02ZPd88
0:V0C0D0Z8=>0`2WPTd20:J1C080Yh9=00@0Z8=>0:V4C`2YQ4l0ZHA?202[PTh30:b3C`030:^2CP2Z
PDd0ZX5=0080ZH1<0`2XPdh20:V4C`/0ZXE@00<0Z8=?0:V4D02[QU800P2/Qe<00`2[QU80ZHA@0:R3
C`030:^6D@<0ZXE@0P2YQ4l20:Z6C0040:^6C`2[QU40ZhIA0:b7D`80[8IE0P2]R5@20:b7D`80ZhIB
0P2ZQE420:^6DP80[8MC0P2]R5@20:j9E@P0[8MB202/Qe<90:^6DP@0[HQD0P2/Qe<20:^6DP<0ZXEA
0P2[QU860:b7D`80ZhIB0`2ZQE480:^6DP060:j9E@2]R5@0[8MC0:^6DP2ZQE40ZHA@0`2XPdl01`2Y
Q500ZhIB0:b7D`2/Qe<0ZhIB0:V4D02XPdl00P2ZPDd20:^2CP80[8=?0P2]Q5000`2ZQE40ZHA@0:R3
C`020:J1C@030:R3C`2YQ500ZXEA00P0ZHA@0P2YQ4l30:R3CP<0Yh9=202WPTh40:AoBP@0YH1;202U
PDd80:F0C0@0Y7m;102UP4`80:9nBP030:N2B`2TOdP0XWe60080X7]400H0XWe60:F0B@2WPT/0YH1<
0:AoB`2RODT20:5lB0040:9mB@2TOd/0YH1<0:=oB`<0Y81<0P2UPDd30:J2CPP0YH1<0P2UPT`20:B1
B`<0Xh1:00<0XWm90:9nBP2ROTX00P2SOd/20:B0C080YH5=00<0Xgi:0:AoB`2VPDd00`2WPTh40:J1
C@80Yh9>102XPdl80:N3C`P0ZhIB00<0ZhIJ0:Z5F@2XPeL00P2WPUH01P2XPeL0ZXEI0:^6FP2/R5@0
ZhMC0:V5D@80Z8A@00<0ZHEA0:^7D`2/R5@00P2[Qe<20:b8E0<0[HUE00<0[XYF0:b8E02]RED00P2]
RED20:j:EP80[h]G202aSET80;:=F@050;B?F`2cSUX0/hiJ0;:=F@2`ReL00P2_RUH04@2^RED0/XaM
0;6;G02`RU/0[hUJ0;2:F`2aRe`0/heN0;F?H02fTEX0]I1I0;>>F@2aS5P0/8YI0;6;G02bS5d0/heP
00<0/HeM0P2bSUh30;>?G`<0]Y9R1@2eTF420;B?HP80]I1S102fTF@90;NCH`030;JBHP2gTf<0^IEU
0080^YIV00<0^IEU0;NCH`2fTV80202fTV880;B@H0@0]I5Q0P2fTV820;NCH`<0]Y=K0P2gU5`30;RE
G@80^99S0P2gTF820;J@H@80]HmP102eTF420;JBHP80]i=S00H0^IAO0;VDH02hTel0^99Q0;RBH`2g
TF@20;N@I@@0^9=O102iU6020;ZFHP040;VEH@2hU600]i=O0;JBGP80]I5M202gTf<30;RDH080]i=O
0`2fTUh80;NCG`<0^YIV0P2iUFD30;RDI0030;ZFIP2iUFD0^IEU0080^9AT0P2gTf<0102fTV80]I5Q
0;FAH@2eTF450;JBHP<0]I5M0`2fTUh20;NCG`80^iMW00@0^YIV0;VEI@2iUFD0^9AT0P2gTf<90;RD
H0P0^9=O402gTf<40;J@H@80]i5R0P2hTV<@0;NCH`P0^9=V202hTel20;JBGP80]I5M0P2dT5`20;>?
F`80]91P00H0]I5Q0;JBHP2gTf<0^9AT0;VEI@2jUVH20;NCH`80]Y9R0P2eTF420;B@H0<0]Y9N0`2e
TEd20;B@G080/hiG00<0]8mJ0;B?F`2dSUd00P2eSf000`2eSf80]HmP0;F?H0060;F?H080]Y1Q00@0
]HmP0;B>G`2cSEh0/XaM0P2aRe`01@2aS5l0/XeP0;>>H@2dSf80]I1S0080]8mR00@0/hiQ0;FAH@2e
TF40]91P0P2cSel00`2bSUh0/HeM0;6=G@030;F?HP80]8iQ0`2cSF020;:>GPL0/HeM202bSET80;>?
G`030;FAG@2dT5`0/XiJ00<0/8aH00D0/HeI0;:>FP2`S5`0/HeM0;>?G`020;B@H0030;>?G`2aSEd0
/8aL0080/XiN0P2aSEd20;2<G080[h]K202bSUX00`2fTFD0]I1T0;>>HP020;6<H0030;:=H@2cSV80
]8mS00<0]8mR00<0/hiQ0;:=H02bSF000P2aS5l20;B>G`<0/heN0`2bS5d20:j:FP80[h]K0P2`S5`4
0;6=G@040;:>GP2cSel0/hmO0;B@H080]I5Q0P2hSf401P2eSf00/hmO0;:>GP2_SEd0[XiM0:f=G0<0
/HaO0`2bSF020;>>H@80/hiR00<0/XeP0;:>GP2bSU`00P2aSET03`2aSUP0/hiR0;>>HP2cSV40/XiN
0;6=F`2aSET0/8aH0;2=E`2/RE<0[HUE0:j:EP2_ReT0/8aL0;6<G`020;:=H@80/8aL0P2aSEd01`2b
SUh0/hmO0;>?G`2cSel0/HeM0;2<G02_Re/00P2^RUX01P2_Re/0/HeM0;:>GP2aSEd0/8aL0:n;F`80
[XYJ00@0[h]K0;2<G02bSUh0]91P0P2bSUh30;6=G@<0/8aL202_Re/00`2`S5`0[h]K0:f9F@020:b8
F0030:j:FP2_Re/0/HeM00@0[XYJ102]RET00`2`S5P0[h]G0:f9E@030:^7D`030:f9E@2^RUH0[XQK
0080[XQI00<0[hUH0:n:EP2`ReH00P2`Re@20;:>GP050;6=G@2`S5`0[h]K0:j:FP2]RET02@2/R5P8
0:n:EP80[XYF0`2]RED30:b8E0@0[HUE102/R5@30:f8E0<0[XUE0P2_RUH@0:j9E@80[XYF0P2]RED3
0:b8E0030:^7D`2XPdl0Z8=?00H0ZHA@00H0[H5@0:b2D02/PU00[8AA0:Z5D@2ZQU820:R7DPP0ZXE@
00@0ZXUD0:^:E@2^RUH0/8]G0P2aREH00`2aQeD0[hEC0:n3DP030:^6DP80ZXEA0`2YQ50:0:Z5D@<0
ZHA@0`2XPdl30:J1C0<0Yh9=0P2XPdh30:F0C080YX5=00<0Yh9>0:R3C`2XPdl0202YQ500102XPdl0
Yh9>0:N2CP2WPTh20:J1C@80YH1<0P2YQ5020:R3C`80Yh9>2P2VPDd00`2XPdl0Yh9>0:F0C0020:Ao
B`030:J1C@2WPTh0ZHA@00P0Y7i=00<0Xgi:0:AoB`2VPDd00P2WPTh00`2VPDd0Y7m;0:=nBP030:F0
B`80YX5<0`2WPTd30:J1C@80YH1<0`2TOd/80:J1C@P0XX5;202UP4`A0:R3C`060:R3EP2WPe<0Yh=C
0:J2D02UPDd0Y85;0P2SP4P20:J1C@030:F0C02TOd/0Xgi:0080XWe900<0XGa80:AoBP2TOdX00P2S
OTT20:9mB080XGa70`2TPDT00`2SP4P0XWm70:1mA@0209ik@`080:9kDP2RNe00XG]>0:5lB02PNd@0
Wg/m09ik>`2NNcT80:9iA@P0WgY500@0XWe90:5lB02PNdL0WgY60P2NNDD00`2ONTH0X7]70:1kA`02
0:1kA`0309mjAP2NNDD0WWU50080WGQ400<0WWU209mj@`2ONT<00P2PNd@20:5lA@030:9mAP2NNTX0
WWY:00H0WWY:00<0WGQ409iiA@2ONTH00P2PNdL01P2ONTH0WWU509ehA02NNTX0WGU909ahB080VgM7
00L0W7Q809eiB@2NNTX0XWe90:5lB02NNDD0W7M30080VgI20P2LMd<209mhC@0709ihB`2NN4T0WGM6
09ag@`2KMT80VgI109Yf@P0309]g@`80W7Q40P2MNDD00`2KMdL0VWI609QdA00209Mc@`0309UeA@2J
MTH0VgM700<0V7M20P2GMT4309Ie@0T0V7A000L0VGE109Qd@02FLSh0UG4m09A`?02ELCd0UW8n00@0
Ug<o0`2FLSh209Ea?@0809QcA`2GLTH0UW5509E`A02CKT80TVe1095/@02@Jcl2095]?@80T6`l00@0
Sf/k08iZ>P2=JCT0SFTi0`2AKCd00`2BKSh0Tflo09=_?`0209A`@0@0Tflo102BKSh00`2?Jc/0TFdm
099^?P0209=_?`03099^?P2AKCd0Sf/k0080U6ho0P2EKd001`2CKCh0TF/l08iX>@2<ISL0TFdm091/
?02>JSX00`2<J3P00`2=JCT0SVXj08iZ>P0208iZ>R_ooooo000Zooooo`<0TfPm0P2DJCh309EZ?`03
09Q]@02FJch0U6Tl0080TfPk00h0U6Tl09I[?P2HKD00VFlm09M]>`2DJSP0TVPf09=Y=`2FK3X0VFlm
09ab@02HKS`0Ufdk09I/>P80UF/i00@0UV`j09M]>`2HKS`0V6e00P2GK3l00`2FJch0UFXm09AY?002
09=X>`P0UFXm00<0V6e009M/?`2FJch00P2FJch00`2HKD00VVm209]`@`0509Q^?0<0Ufdk00@0V6hl
09U_?@2IKcd0VW0n0P2KLCl209ab@0T0VW0n202KKT@809ac?`0309]a?`2LLT00WWA20080WgE300<0
WWA209ab@02KLCl00P2NM48309ec@@<0W7900P2JMS`0102JMCh0VgI109]f@@2LMd<209afA@0309ab
@02NM480WgE300<0XGM500<0X7I409me@`2PMT@00`2PMT@209me@`80WWA2202RND<20:5gA@040:9h
AP2SNDL0XgU70:AjB080YG]9202PM4<80:9gA0P0XWU5202UO4P20:AjBP040:AjB02TNdL0Y7]70:Ak
A@80Y7]30P2RMd@0102SN4D0Y7U60:AiAP2UNTL20:IkB0P0YWa<102VODT20:MnBP80Z7m;00H0XGQ4
0:=jAP2VODT0Z7m;0:Z1C@2YP4`;0:QoB`P0ZH1<0`2WOTX20:QoB`<0ZH1<202XOT`0202VO4`0YWa:
0:MnBP2XOdL0Z8150:V1@`2ZPd80ZX=0202YP4`20:N2C@D0Z8=>00H0Yh9=0:J1C02VPD`0YX5<0:N2
C@2XPdh30:V4C`P0Zh9>0`2/Pdl00`2[PTh0ZX5=0:V0C0020:V0C0<0Z8=>0`2YQ4l:0:Z5D0030:R3
C`2YQ500ZhIB0080[8MC00<0ZhIB0:V4D02XPdl00`2[QU420:Z5D0<0ZHA?0P2ZQT`0102[QTl0ZhIA
0:^6D@2/Qe<20:b6E@80[HQD0P2/Qe<0102[QU80ZXEA0:Z5D@2YQ5020:^6DP80[8MC0P2]R5@20:j9
E@P0[8MB4@2[QU80102^RED0[HQD0:f8E02]R5@20:b7D`80ZhIB0P2YQ500102ZQE40ZhIB0:b7D`2/
Qe<20:f8E0<0[8MC0`2[QU820:Z5D@P0ZhIB0P2^RED00`2]R5@0[8MC0:^6DP020:V4D080Z8=?00L0
ZHA@0:^6DP2/Qe<0[8MC0:^6DP2YQ500Z8=?0080ZX5=0P2[PTh01`2/Pdl0[HA@0:f4D02^QE40ZhIB
0:Z5D@2XPdl00P2VPDd00`2XPdl0ZXEA0:^6DP080:Z5D@80ZhIA0P2ZQE00102YQ4l0Z8=>0:N2C@2W
PTd80:N2CP80Y7m:102UP4/20:J1C0P0YH5=202UP4`20:AoB`@0YH1<0P2VPDd80:5mB@030:N2B`2U
P4T0XWe60080X7]400H0XWe60:J1BP2XPd`0YH1<0:AoB`2SOTX20:9mB@030:=nBP2TOd/0YH1<00<0
Y81<0P2UPDd40:J2CPP0YH1<0`2UPT`20:B1B`<0Xh1:0P2ROTX0102SOd/0Y81<0:B0C02UPDd20:J2
CP030:9mB@2TOd/0Yh9>0080ZHA@00<0Z8=?0:J1C@2TOd/00P2VPDd20:N2CP<0Z8=?00<0ZHA@0:R4
D02XQ5001P2XQ5080:^6DP030:^6FP2ZQET0Z8=G0080Yh9F00H0Z8=G0:Z5F@2[QUX0[8QD0:^7D`2Y
QE420:R4D0040:V5D@2[Qe<0[8QD0:^7D`<0[8QD0P2]RED20:j:EP<0[HUE0P2^RUH30:n;E`P0/XiJ
202cSUX20;F@G0040;B?F`2cSUX0/HaH0;2;E`80[hYF0100/XaM0;6;G02_REX0[hUJ0;2:F`2bS5d0
]8iO0;J@H@2gTU/0]I1I0;>>F@2aS5P0/8YI0;6;G02bS5d0/heP0`2`S5`20;6=G@<0/XiN102eTF44
0;JBHP80]8mR0P2eT6<30;JAI0030;NBI@2gTf<0]i=S00L0]i=S00<0]Y9R0;NCH`2iUFD00P2jUVH0
0`2iUFD0]i=S0;JBHP080;JBHPT0]91P0`2eTF420;JBHP80]i=S0`2fTe/30;NDG080^9EM0P2hTV<2
0;NAHP80]Y1Q0P2eSf00102dT600]I5Q0;FAH@2eTF420;JBHP80]i=S00H0^IAO0;VDH02hTel0^99Q
0;RBH`2gTF@20;N@I@050;NBGP2hTel0^9=O0;VDH02jUF400P2kUV802@2lUf<0_9QT0;^GH`2jUV80
^IEQ0;RDH02gTel0]Y9N0;FAG@080;NCH`80^9AP0`2gTel30;JBGPP0]i=O0`2jUVH30;VEI@80^9AT
0P2jUVH0102iUFD0^9AT0;RDI02gTf<20;JBHP@0]I5Q102fTV801@2cSe/0]91L0;B@G02eTEd0]Y9N
0080]i=O00L0^9AP0;fIJ@2lV6P0^iMW0;ZFIP2iUFD0]i=S0080]Y9R2@2hU6080;RCG`P0]i9U202g
Tf<0102eSf00]Y1Q0;J@H@2fT6420;NAHP80^99S402gTf<80;RCIPP0^9=O0P2fTUh20;FAG@040;B@
G02cSe/0/hmK0;:>FP80]91P00<0]I5Q0;JBHP2gTf<00P2iUFD00`2jUVH0]i=S0;NCH`020;JBHP80
]I5Q0P2dT6030;NCG`80]Y9N0`2eTEd20;>>E`030;>>F@2dSe/0]8iM0080]HmP00<0]HmR0;F?H02e
Sf001P2eSf020;J@H@090;F?H02cSEh0/H]L0;2:F`2_REX0[XQI0:n:G@2aS5l0]8mR0080]Y5T00<0
]I1S0;>>H@2aS5l00P2eTF40102dT600/hmO0;>?G`2bSUh20;6=G@<0]HmR0P2dSV430;>=H080/HeM
1@2`S5`20:n;F`P0/XeI202cSel00`2eTU`0]95K0;:?F@030;2=E`050;6>F02bSeT0/8aL0;6=G@2c
Sel00P2dT6000`2cSel0/HeM0;2<G0020;:>GP80/HeM0P2`S5`20:n;F`<0/XiJ102aSET0102`S5P0
]Y5U0;F@I02cSV830;6<H0050;>>HP2dSf<0]I1S0;F@H`2dSf800P2cSV400`2bSF00/HaO0;6<G`02
0;B>G`<0/heN0`2bS5d0102]RET0[XYJ0:j:FP2_Re/20;2<G0@0/HeM00@0/XiN0;>?G`2cSel0]91P
0P2eTF420;R?H@040;F?H02cSel0/XiN0;2>GP80[XiM0`2aS5l30;:=H080/hiQ0P2cSV800`2bSF00
/XiN0;:>G0020;6=F@0:0;6>F02dSf<0/hiR0;>>H@2bSUh0/HeK0;6=F@2`S5P0/8eG0:b9D`80[HUE
00<0[h]I0;2<G02aS5l00P2bSF420;2<G080/HeM00l0/XiN0;>?G`2cSel0]91P0;2<G02_Re/0[HUI
0:b8F02]RET0[XYJ0;2<G02bSUh0/HeM0;2<G02_Re/00P2^RUX01@2_Re/0/8aL0;:>GP2dT600/hmO
0080/XiN00D0/HeM0;2<G02_Re/0[h]K0:j:FP080:n;F`030;2<G02^RUX0[HUI0080[8QH00<0[HUI
0;2<G02aSEd01P2/R5P20:f9F@090;2<F02_ReL0[HUE0:^7D`2ZQU80ZhMC0:f9E@2^RUH0[XQK0080
[XQI00<0[hUH0:n:EP2`ReH00P2`Re@20;:>GP030;6=G@2`S5`0[h]K0080[HUI2@2/R5P80:n:EP80
[XYF0`2]RED50:b8E080[HUE102^RUH30:f8E0<0[XUE0P2_RUH@0:j9E@80[XYF0P2]RED40:b8E0<0
Z8=?1@2YQ5001P2]PE00[89@0:b2D02/Q540ZXEA0:Z6DP80Z8MB202ZQE00102ZRE@0ZhYE0:j:EP2`
ReL20;69EP030;67E@2_QE<0[h=B00<0ZhIB0P2ZQE430:V4D0X0ZXEA0`2YQ5030:R3C`@0YH1;0P2V
PD`20:N2C@@0YH1<00<0YX5=0:N2CP2XPdl02@2YQ5040:N2CP80YX5=0P2UP4`20:V4D080Z8=?0P2W
PTh:0:J1C@030:R3C`2WPTh0YH1<0080Y7m;00<0YX5=0:R3C`2YQ500202TOTd00`2SOTX0Y7m;0:J1
C@020:N2CP030:J1C@2TOd/0Xgi:0080YH1;0`2VPD`30:N2C@<0YX5=0P2UP4`30:AoB`P0YX5=202R
PD/80:J1CA40Z8=?00H0Z8=F0:N3D`2WPe<0YX9@0:F1C@2TPD/20:>0B080YX5=00<0YH1<0:AoB`2S
OTX00P2RODT01P2QO4P0Y7m:0:AoBP2TOdX0Xgi90:9mB0<0XGa700D0YX=;0:F2BP2SP4P0XWm70:1m
A@0209mlA00909ik@`2SO5D0XgaC0:9lC`2QO4P0WgY309ij?02MNSP0WGXf00P0XWU5202ONTD02@2U
P4`0Xgi:0:1kA`2NNDD0WGQ409mjAP2QO4P0XWe90:5lB0020:1kA`0309mjAP2NNDD0WWU50080WGQ4
0P2NND80102ONT<0X7]40:1kA02QO4D20:9mAPP0WWY:00<0W7M309iiA@2QO4P00P2RODT03`2QO4P0
WWU509ag@`2PO4`0Wg];09eiB@2KMdL0VWI609]gA`2LN4P0WGU90:9mB@2QO4P0WgY609ag@`0209]f
@P80W7M300T0XW]@0:5jC`2PNTd0WgU:09egAP2LMd<0VgI209]f@@2IMD400`2JMT8209]g@`80W7Q4
00<0VWI609UeA@2HM4@00P2GLd<00`2HM4@0VWI609]gA`0209Qg@P<0UgI10`2FMD0909Qd@00709Ue
@@2HM400UW8n09Ea?@2DL3`0UG4m09Ib?P0409Mc?`<0UW8n0P2ELCd0202IM4P0V7=709MbAP2EL4@0
Tfi2095/@02?JSh0SVTm0P2BKSh01P2AKCd0T6`l08iZ>P2=JCT0S6Ph08]W=`<0TFdm00<0TVhn09=_
?`2DL4000P2DL40409=_?`@0TVhn00<0Sf/k095]?@2BKSh00P2CKcl0102BKSh0TFdm08m[>`2EKd03
09I`@@0<09=]?P2@JS/0SFLh08]U=P2AKCd0Sf/k08eY>@2<J3P0RfLg08aX>02=JCT0Sf/k0`2=JCT[
ooooo`00:_ooool809EY?00309AX=`2FJST0Uf/j0080V6`k00@0Uf/j09IZ>@2DJ3L0TfTg0P2DJSP0
0`2EJcT0UV`j09I/>P0209M]>`<0UV`j0`2EJcT209AZ>0<0UV/n0`2EJSd209AY?080U6Xh0`2EJcT3
09I/>P0309M/?`2FJch0U6Tl0080TVLj00<0U6Tl09I[?P2GK3l00P2GK3l0102HKD00VFi109U^@@2J
Kd8209]`@`0809ebA@2LLD@0Vg1309U^@@2HKD00UV/n09EZ?@2DJC`909U^@@0409Q^?02IKcd0VFlm
09Y`?P80Vg4o0P2LLT00202FLSh0UG4m09A`?02CKc/0U70l09Mc?`2IMD40VgM3202MLd4809ic@080
W79000@0WG=109id@P2NM480WgE30P2PMT@309ed@080WWE10`2OMT820:5h@P030:1g@`2PMT@0WgE5
0080WW=600@0WG970:5lB02PNdL0WWU50P2LMd<0102MN4@0WgY60:1kA`2MNDD209iiA@030:1hA@2Q
MdD0XWI50080Y7I5202RMTD20:9g@0040:9g@P2SN4D0XgQ50:=gAP80Y7Q90P2QN4@40:1g@`80WgI2
202SNTH0102UO4H0Y7]50:9i@`2QN4820:1g@@80XGQ200<0Yg]<0:EiBP2SMdP00P2QMDH00`2SMdP0
YGU:0:MkC0020:=h@`040:AiA02UNTD0YW]60:IkAP80Yga70P2QN4@03P2RNDD0Y7]70:ElB02VODT0
Ygi:0:QoB`2TND@0YW]60:MlB@2YOD`0ZGe>0:MkCP2VNTd0Y7M=0`2VODT40:MnBP80Z7m;0`2VPDd3
0:N2CP80Z8=?00<0YG]90:IlBP2XOT`00`2ZP4h00`2XOT`0Yge;0:QoB`070:QoB`050:F0B`2VPD`0
YX5<0:N2C@2XPdh00P2YQ4l0102ZQE00Z8=?0:N2CP2UP4`20:=nBP0;0:F0C02WPTh0Z8=?0:N2C@2X
Pdh0ZHA?0:Z5D02YQ4l0Z8=>0:J1C02TOdX00P2UP4/30:J1C0<0Yh9=0`2/Pdl20:f4D0<0[XEA00P0
ZhM=0:Z6C02YQ4d0Z8=>0:N2C@2VPDd0YGm>0:AnC@P0Z8=?202[QE@20:n6D0040:j5C`2]Q4h0[HA>
0:b3C@80Zh9<00<0[89@0:f3D@2_QE<00P2_QE<00`2]Pe40Zh5?0:Z0CP080:Z5D0040:j9E@2]R5@0
[HQD0:f8E080[8MC0P2[QU80102aS5P0[hYF0:f8E02[QU820:Z5D@050:^6DP2/Qe<0[hYF0:f8E02/
Qe<00P2ZQE400`2/Qe<0[HQD0:n:EP080:b7D`060:R3C`2YQ500ZHA@0:^6DP2/Qe<0[HQD0`2^RED8
0:f8E0030:^6DP2/Qe<0[HQD0080[XUE00H0[HQD0:b7D`2[QU80Z89C0:V3E02[QEH20:b6E`060:^5
EP2YPe@0Z89C0:V4C`2[QU40[8MB0P2]R5<00`2/Qe80ZhIA0:V4C`080:^6DP80ZXEA00@0ZHA@0:R3
C`2VPDd0YH1<0P2TOd/30:R3C`<0ZHA@0P2ZQE430:R3C`80ZHA@0`2ZQE420:R3C`040:V4D02ZQE40
ZXEA0:^6DP80[8MC202YQ4l80:R3C`090:J1C02UP4/0Y7m:0:AoBP2UP4/0Yh9=0:V4C`2[QU40ZHEA
0080Z8A@00L0Yh=?0:J2CP2UPDd0YH5=0:B0C02VPD`0YH1;0080Y7m:00@0YH1;0:N2C@2YQ4l0ZXE@
0P2UP4`0102UP4/0YH190:F1A`2UPDL20:F1A@060:J0D`2VP540YX1A0:J0C`2VPDd0YX5<0P2VPDX0
1P2VNdP0YGa80:ImB@2UODT0Y7m:0:>0BP80XH1:202WPdl90:UnB`P0YH1<0P2TP4`20:F1C@<0YX9>
00<0Yh=?0:AnC`2SODh00P2SODh0102TOTl0YX1A0:R2D`2ZQ5D20:V4D080Z8=?0`2WPTh00`2VPDd0
ZHEA0:V5D@060:V5D@<0Z8A@0P2YQE430:Z6DP80ZHEA0P2ZQU830:^7D`040:b8E02]R5@0[8MC0:^6
DP80ZXEA00<0ZhIB0:b7D`2]R5@0202ZQU830:f9E@80[XYF0`2_ReL30;2<F0D0[h]G00D0[hYE0;2;
EP2`ReH0/HaG0;:=F0020;>>F@030;B?FP2dReL0]8]G0080]8]G0P2cRUH20;:9E@030;B>G`2bS5d0
/H]L0080[hUJ00<0/H]L0;:<G@2dSUl00`2dRed30;F<GP80]XeO00D0/hiG0;:=EP2bSEP0/XeI0;6;
FP020;6;G0030;6;GP2aTF00/I5P0080/Y9Q0`2cTf802@2dU6<0/XiN0;>?G`2dT600]I5Q0;JBHP2g
Tf<0^9AT0;VEI@080;BAF@@0]i5R0`2hTV<20;VCI0060;^EIP2jU6D0^YAU0;RBH`2gTF80]Y1Q0P2e
Sf080;NCH`80^9=O0P2gTUh20;JAG@80]I1L202fTUh00`2fTV80]i=S0;VEI@020;ZFIP030;VEI@2g
Tf<0]Y9R00P0]91L0P2eT5`20;JAG@80]i9N0P2hTel20;NCH`80]Y9R0`2eTF40102dT600]Y9N0;JB
GP2fTUh30;NCG`80^9AP202fTV80102hTel0]i9N0;NBGP2gTUh30;JAG@030;F@G02gTf<0]i=S00H0
]i=S0P2jUV80102iUF40^9AP0;RDH02gTel20;JBGPP0^9=V202hU6@20;FAH@<0]Y9R0`2gTf<80;NC
G`080;RDI02gTf<0]I5Q0;B@H02eTF40]i=S0;VEI@2jUVH90;RDI0P0]i=S00@0/XiN0;>?G`2cSel0
]91P0P2eTF420;JBHPP0]i9U0P2eTF420;JBHP070;NCH`2hU6@0^9AT0;VEI@2dT600]Y9R0;RDI002
0;ZFIP030;RDI02fTV80]91P00P0]Y9N00<0]91P0;FAH@2gTf<00P2iUFD00`2hU6@0]Y9R0;FAH@08
0;JBHP<0]I5Q0`2dT6020;>?G`P0]91P00@0/XiN0;>?G`2cSel0/hmO0P2dT6020;FAH@P0]I1L00<0
]i5T0;J@H`2eSf800P2cSF002P2eSf80]Y1S0;NAI02iU6P0^9=W0;NBIP2fTFD0]I1T0;B?H`2cSV83
0;:=H@030;:=H02bSUh0/XiL0080/XiJ00@0/XmI0;:>FP2bSUX0/XiJ0P2cSe/30;B@G0030:n;F`2a
SEd0/hmO0080]I5Q00H0/hmO0;6=G@2_Re/0/XaM0;>=GP2eSf020;J@H@030;F?H02cSEh0/XaM0080
/HeM0P2bSUh01@2cSel0/XiN0;2<G02^RUX0[HUI00P0/heN202gTVD00`2bSUh0/hmO0;FAH@020;JB
HP030;FAH@2cSel0/XiN0080/XiN0P2aSEd30;2<G0030:n;F`2aSEd0/HeM0080/XiN102cSel80;6=
G@030;FAH@2dT600]91P0080/hmO0P2bSUh0102aSEd0/Y1P0;>AH@2dTV820;FCH`030;BBHP2cTF40
/Y1P0080/XiN0P2aSEd20;2<G080[h]K00<0/hmK0;6=F@2`S5P00P2^RUH00`2`S5P0/HeI0;>?F`08
0;:>GP080;JBHP2eTF40/hmO0;6=G@2`S5`0/HeM0;>?G`2dT6020;2<G080/HeM00@0/XiN0;>?G`2c
Sel0/hmO202bSUh20;6=G@@0/8aL0P2aSEd02`2dTE/0/XiJ0;6=F@2`S5X0/8aL0;6<G`2bSF40]8mS
0;>>FP2dSe/0]I1L0080]Y5M00<0]8mK0;:=F@2aS5P00`2]RED20:j:EP<0[h]G00<0/HaP0;2;G`2^
RE`00P2^RUX02P2_ReT0/HeI0;>?F`2eTU`0/hmO0;:>GP2aSEd0/8aL0:n;F`2]RET20:b8F0060:j8
F@2_REX0/8YK0;6;G02bS5d0/heN0P2dSUl0102]RED0[XYF0:j:EP2_ReL20;2<F080/HeI00<0[XQK
0;2:G@2aReh00P2bS5l00`2aReh0/8YM0:j8F`080:j:FP80/XiJ00@0/8aH0:n;E`2]RED0[8QD0P2Z
QU820;6<F0040;2;E`2_RUH0[hYF0:j9E@80[HQD00P0ZXIF0:^7E`2^RUX0/8aL0;6=G@2`S5`0[h]K
0:j:FP80/8UN00<0/8YM0:n9FP2_REP00P2^RED00`2^RE@0[XUB0:j9DP020:f8D@80[8M@0P2[QTl0
1@2_REX0[XQI0:j8F@2]QeP0[8IG0080ZhEF00<0ZXAE0:b8E02/R5@00P2/R5@40:^7D`80[XUE0P2]
R5@20:b7D`<0ZhIB0`2/Qe<30:f8E0030:j9E@2[QEP0ZhEH00H0ZhEH0P2ZPeX0102YPUL0ZH=F0:V3
E02XPU<20:R2D@80ZHEA0`2ZQU830:^7D`<0ZHA=0P2ZQDh30:^6C`<0ZXIB00<0ZhMC0:b8E02/R5@0
0`2]RED20:b8CP040:^6C`2ZQE00ZXE@0:V4D080Z89A202YQ5000`2ZPDT0Zh9:0:b3C@020:j5D@03
0:b2D02[PE40ZX1@0080YX1?00H0Yh9>0:R3CP2YQ4l0ZhI?0:^7C@2/R4h80:R3C`@0ZXEA0P2YQ502
0:R3C`P0Yh9=102WPTh20:J1C@80YH1<0`2UPDd20:B0C0<0Xgm;00<0Zh5?0:Z0CP2XOT`00P2WOD/0
0`2XOT`0ZX1>0:^1C`080:J1C@<0Xgi:0`2TOd/20:F0C080YX5<102UP4/20:AoBPP0YGm@202VP548
0:B1B`080:N2CP2VPDd0YH1<0:AoB`2UP4`0YX5=0:R3C`2YQ5030:F0C0030:J1C@2WPTh0Yh9>0080
Z8=?00D0Y85;0:F2C02UPT`0YX==0:N4CP030:R5C`0A0:V6D02[QE@0ZXAC0:V3DP2XPU40Yh5@0:J0
C`2UOdh0Y7i=0:5lB02RODT0Y7m;0:J1C@2WPTh0YX5=0:F0C02TOd/00P2OO4@30:1mA@<0XGi60P2R
OTX20:=oB`0?0:9nBP2PO4P0WWY609eiA@2TOE@0Y7eB0:=mD02RO4/0XGa70:5lA@2PO480X7a00:Ml
A@2UNT<0XgQ10080XGHo00<0XgQ10:Ej@`2WO4D00`2NND8209eh@@<0W7M00`2NNTH209mkA`<0X7a8
0`2MNDD309ijAPX0Wg]70P2PO4P409mkA`80WWY60P2ONTH209iiA@80WGQ40`2LMd<03`2MN4@0WWU5
09mjAP2ONTH0WWU509ehA02LMd<0XgaA0:1iCP2LMTT0VG=409Qb@@2IM400W7M309iiA00209iiA@80
WGQ400@0W7M309]f@P2KMT80VWE1202JMDT01@2MNDT0W7Q809UeA@2GLd<0UW920080Ug=300@0V7A4
09Mc@`2GLd<0Ug=30`2FLT8209Ea@@06099/A@2CKT@0U6m509E`A02GLTD0VGE50`2JMT@209Ud@080
V7<o00@0Ug8n09Ia?@2FLCd0UG0l1@2FLSh309Mc?`80Ug=300P0UW9209A`@02CKcl0TVhn095]?@2@
K3`0Ug9509A_@P80T6/n0P2BKD003@2?JSd0RfHi095[A02AK480TVe309=^@P2DKd80UG5109Ib@02G
Ld40T6Xk099/?@2CKCh00P2DKSl00`2CKCh0TV`m091Z>`08091/?003099/?@2CKCh0U6ho0080U6ho
00<0TV`m091Z>`2?JCX0102>JC`408eX>`<0S6Ph:oooool002[ooooo202EJC`00`2DJ3L0UVXi09M[
>P0209Q/>`0309M[>P2FJST0U6Pg00<0U6Xh00<0UF/i09I/>P2FK3X00P2GKC/309I/>P<0UF/i0P2D
JSP309I[?P<0UFXm0P2DJC`209AZ>0<0UF/i0`2FK3X00`2HKD00Uf`o09EZ?@0209AY?00309EZ?@2G
K3l0V6e00080Uf`o0P2HKD001@2IKT40VVm209Y_@P2JKd80W7540080Vg1300<0VVm209U^@@2HKD00
0P2GK3l909U^@@0309Q^?02IKcd0VFlm0080VW0n0P2KLCl00`2LLT00Ug8n09Ia?@0209E`?00409Ia
?@2HLcl0VWE109]f@PP0WG=1202NLd0309ec@@<0WWA20P2OMD<809ie@@80WgI000<0WgI209me@`2O
MDD00P2OM4L02P2OM4T0WgY609iiA@2LMd<0VgI209Ye@@2KMT80W7M309ehA02MNDD209iiA@030:1h
A@2QMdD0XWI50080Y7I5202RMTD20:9g@0040:9g@P2SN4D0XgQ50:=gAP80Y7Q9202QN4@80:=jAP@0
XgY400@0XWU30:5h@P2PMd40X7M10P2UNDX40:=gB080YGU:0`2TND@20:EjA@<0YW]60`2UO4P40:Ak
A`090:=jAP2UNTD0YW]60:MlB@2XO4/0Z7a=0:MkCP2VNTd0YGQ>00<0YWe9102WOTX20:QoB`<0YH1<
0`2VPDd20:N2CP030:EkB@2VO4X0Z7i<0080ZX1>00<0ZGm=0:QnC02WOD/0202XOd/40:N2C@@0Z8=>
00<0ZHA@0:R3C`2VPDd00P2UP4`01@2VPDd0Z8=?0:V4D02WPTd0Z8=>00<0ZHA?00<0Yh9=0:J1C02T
OdX00P2UP4/30:J1C0<0Yh9=0`2/Pdl30:f4D080[XEA00P0ZXI<0:V5B`2YQ4d0Z8=>0:N2C@2VPDd0
YX1?0:EoCPP0Z8=?202[QE@30:j5C`80[HA>0`2/Pdd00`2/PU00[H=A0:j4DP020:n5D`030:f3D@2[
PDl0ZX1>00P0ZXE@102]R5@20:b7D`80ZhIB00/0[hYF0:j9E@2/Qe<0ZhIB0:Z5D@2[QU80[8MC0:f8
E02^RED0[HQD0:b7D`020:^6DP030:b7D`2]R5@0[XUE00P0[8MC00H0Z8=?0:V4D02ZQE40ZhIB0:b7
D`2]R5@30:j9E@P0[HQD00<0ZhIB0:b7D`2]R5@00P2^RED01P2]R5@0[8MC0:^6DP2XPU<0ZH=D0:^5
EP80[8IG00H0ZhEF0:V3E02XPU<0ZXE@0:^6D@2/Qe820:f8D`030:b7DP2[QU40ZXE@00P0[8MC0P2[
QU801P2ZQE40ZHA@0:R3C`2WPTh0YX5=0:F0C0<0Z8=?0P2YQ5030:Z5D@<0Z8=?0P2YQ5030:Z5D@<0
ZHA@00<0ZXEA0:^6DP2[QU800P2/Qe<80:V4C`P0Z8=?00<0Z8=>0:N2C@2UP4/00P2UP4/00`2VPD`0
Z8=>0:Z5D0020:R4D0<0Yh=?0`2VPTh20:J1C0070:F0B`2TOdX0YH1;0:J1C02XPdh0ZXE@0:EoCP02
0:F0C0030:F0B`2UP4T0YH570080YH5500H0YX1C0:J0D@2VP540YX1?0:J1C@2VPD`20:J1BP060:Ml
B@2WOTX0Ygi:0:InBP2UP4/0Y85;0P2SPT`80:N3C`T0Z7m;202UP4`0102TP4`0YH5=0:F1C@2UPDd2
0:J2CP80Yh=?0P2TOTl20:=mCP040:AnC`2VP540ZH=D0:Z4E@80ZHA@0P2XPdl40:N2CPP0ZHEA0P2X
Q5020:V5D@<0ZXIB00<0ZhMC0:V5D@2ZQU800P2ZQU820:^7D`80[8QD00<0[HQD0:b7D`2[QU800P2Z
QE400`2[QU80[8MC0:f8E0080:^7D`80[HUE0`2^RUH30:n;E`@0/8aH102_ReL30;6<E`<0/XeH0P2c
SUT0102eS5P0]8]G0;B;E`2dReL20;>:EP80/XUE00<0]8iO0;>=GP2aRe`00P2`RU/00`2aRe`0/heN
0;B>G`030;B;G@80]HaN0`2fSEl20;:=EP030;:=F02bSET0/XaK0080/XaM00<0/XaO0;6AH02aTF00
0P2bTV440;>CHP050;>?G`2dT600]91P0;FAH@2fTV800P2gTf<00`2hU6@0]95I0;BAF@060;BAF@@0
]i5R0`2hTV<20;VCI0060;^EIP2jU6D0^I=T0;RBH`2gTF80]Y1Q0P2eSf080;NCH`80^9=O0P2gTUh2
0;JAG@80]I1L202fTUh00`2fTV80]i=S0;VEI@020;ZFIP030;VEI@2gTf<0]Y9R00P0]I5M0P2eT5`2
0;JAG@80]i9N0P2hTel20;NCH`80]Y9R102eTF430;JBGP<0]i=O0P2hU6080;JBHP80]Y5M1P2gTUh8
0;NCH`<0^IEQ00<0^9AP0;NCG`2gTel00P2fTUh80;RCIPP0^9AT0P2fTV830;NCH`<0^9AT202gTel2
0;NCH`<0]I5Q00<0]i=S0;VEI@2jUVH02@2hU6@80;NCH`80/hmO0P2dT6020;FAH@80]Y9R202gTVD2
0;FAH@80]Y9R00@0]i=S0;RDI02hU6@0^9AT0P2fTV80102gTf<0^9AT0;RDI02gTf<20;JBHPP0]Y9N
00P0]91P0;FAH@2gTf<0^9AT0;VEI@2hU6@0]Y9R0;FAH@P0]Y9R0`2eTF430;B@H080/hmO202dT600
102cSel0]91P0;B@H02dT6020;FAH@80]Y9R202eT5`00`2gTF@0]Y1S0;F?HP020;>=H0030;F?HP2f
T6<0]i5T0080^9=W00H0]i9V0;JAI@2eT6@0]8mS0;>>HP2bSF420;B?H`030;B?HP2dT600]91N0080
]91L00@0]95K0;:>FP2bSUX0/XiJ0P2cSe/30;B@G080/HeM00@0/XiN0;>?G`2cSel0/XiN0P2aSEd0
0`2bS5d0/heN0;F?H0020;J@H@030;F?H02cSEh0/XaM0080/HeM0P2bSUh01@2cSel0/XiN0;6=G@2_
Re/0[HUI00P0/heN202fTF@00`2bSUh0/hmO0;FAH@020;JBHP030;FAH@2cSel0/XiN0080/XiN0P2a
SEd60;2<G0<0/HeM2`2bSUh00`2dT600/hmO0;>?G`040;>?G`040;:>GP2aSel0/Y1P0;BBHP80]I=S
00<0]99R0;:@H02aSel00P2bSUh20;6=G@80/8aL0P2_Re/00`2bSUX0/HeI0:n;E`020:j:EP030:n;
E`2aSET0/XiJ00P0/XiN00<0]Y9R0;FAH@2cSel00`2aSEd20;>?G`@0/HeM302bSUh80;6=G@0@0;BA
F`2bSUX0/HeI0;2<FP2`S5`0/HaO0;:=H@2dSf<0/hiJ0;B?F`2eT5`0]Y5M0;F@G02dSe/0/XeI0;6<
F080[HUE0`2^RUH30:n;E`030;:=H@2aS600[hYM0080[h]K00@0[h]I0;2<F02bSUX0]95K0P2aSEd2
0;2<G0040:n;F`2^RUX0[HUI0:f9F@80/8YK0P2aRe`30;:<G@040;>=GP2]RED0[XYF0:j:EP80[h]G
0P2`S5P0102aSET0[XQI0;2:F`2aRe`20;:<G@030;6;G02`RU/0[XQI00P0[XYJ00@0/HeI0;2<F02_
ReL0[h]G0P2]RED00`2/R5@0ZhMC0;6<F0020;2;E`80[hYF0P2^RED0102]R5@0ZXIF0:b8F02^RUX3
0;2<G0070:n;F`2^RUX0/8UN0;29GP2_RE`0[hUJ0:n9F0020:j9E@030:j9E02^RE80[XUB0080[HQA
0P2/Qe020:^6C`<0[HMH0`2/QUL20:^5EP<0[8QD1@2[Qe<20:j9E@80[HQD0P2/Qe<20:^6DP@0[HQD
102/Qe<80:^5EP80ZX=H0P2YPeH0102YPe@0Z89C0:R2D@2XPU430:V5D@80ZXIB0`2[Qe<30:V4C@80
ZXE>0`2[QTl30:Z6DP040:^7D`2/R5@0[8QD0:b8E080[HUE00<0[8Q>0:^7C@2[QTl00P2ZQE000`2Y
Q500ZH=B0:R2D@080:V4D0030:Z1B@2[PTX0[8==0080[XEA00<0[89@0:^1D@2ZP5000P2VP4l01P2W
PTh0Z8=>0:V4C`2ZQDh0ZhM=0:b8CPP0Z8=?0`2YQ5030:R3C`80Yh9>202WPTd0102XPdl0Yh9>0:N2
CP2WPTh20:J1C@80YH1<0`2UPDd20:B0C0<0Xgm;00<0Zh5?0:Z0CP2XOT`00P2WOD/00`2XOT`0ZX1>
0:^1C`080:J1C@<0Xgi:0`2TOd/20:F0C080YX5<1P2UP4/80:EoD0P0YX1A202TPD/00`2WPTh0YX5=
0:F0C0020:AoB`030:J1C@2XPdl0ZHA@00D0YX5=0`2WPTh40:J2CPD0Yh=?0P2ZQ5<02@2YPe80Z89A
0:N1D02VP4l0YGm>0:AnC@2SOTX0Y7m;0:J1C@020:N2CP030:J1C@2UP4`0Y7m;0080Wga40`2PODD3
0:5nAP080:9nBP2SOd/0Y81<0:B0C02SOd/0XGe909mkA`2NNTH20:9kD0040:5kCP2QNdX0XGa80:1k
A080X7a20P2TNd<40:9i@@80Y7]30`2ONT<209ii@P<0WGQ10`2NNTH209mkA`<0X7a81`2NNTH00`2M
NDD0Wg]709mkA`0>09mkA`80WgY60P2NNDD209ehA0<0W7M30100WGQ409iiA@2ONTH0WgY609iiA@2M
N4@0W7M30:5jC`2ON4d0VgE809UcA02HLT40VWE109ehA02ONTD0WWU50P2MN4@209ag@`80VgI200<0
VWE109YeB@2JMDT01P2JMDT01@2MNDT0W7Q809UeA@2GLd<0UW920080Ug=300@0V7A409Mc@`2GLd<0
Ug=30`2FLT8209Ea@@0609=]AP2DKdD0UG1609IaA@2GLTD0Ug=30P2HM4800`2IMD<0VGA009Ud@002
09Qc?`0409Mb?P2FLCd0UW4m09Ia?@H0UW8n0P2GLcl209Ib@P0409Ea@@2DL400Tflo09=_?`80TVhn
00@0UW54099]@02?JSd0T6/n0P2CKT40202@Jch0S6Lj091Z@`2AK480TVe309=^@P2DKd80UG510P2F
LT000`2@JS/0TV`m09=]?P0209A^?`0309=]?P2BK3d0T6Xk0080TFdm102@K3`208m[>`03095[?02B
K3d0Tfdn0080U6ho00<0TV`m091Z>`2?JCX00`2>JC`508eX>`<0Sf/k:oooool002[ooooo202DJ3/0
0`2DJ3L0UVXi09M[>P0209Q/>`0309M[>P2FJST0U6Pg0080U6Xh0`2EJcT609I/>P<0UF/i0P2DJSP3
09I[?P<0UFXm0P2DJC`209AZ>0<0UF/i0`2FK3X00`2IKT40V6e009M/?`0209I[?P0409M/?`2HKD00
VFi109M/?`<0V6e00`2IKT40102JKd80Vg1309]`@`2KL4<509Y_@PT0VFi1102IKcd209Y`?P80Vg4o
00P0UW4m09E`?02EL3`0UG0l09Ia?@2HLcl0VGA009Ye@@P0W790202NLd0409id@P<0WG=100@0W790
0:1g@`2PMd<0WgI20P2NMD400`2MM400W7<o09ac?`0209ed?P0309ie@@2OMD<0X7I60080XGI900D0
XWM<09iiA@2MN4@0W7M309]f@P0209Ye@@0309]f@P2LMd<0WGU50080WWU500<0X7Q50:5gA@2RMTD0
0P2TMTD80:9fA@80XWM000@0XWM20:=hA@2SN4D0XgM60P2TN4T40:9iA@`0XgY600<0X7M10:5h@P2T
NdD00P2UO4H00`2RND<0X7M109ie?`020:=gAP@0YGU80P2SMdH0102VNdH0YGY50:EjA@2UNTD40:Ai
A080Z7m;00h0Ygi:0:ElB02SNTH0XWU50:5hA02PMd<0YGY50:IkAP2WO4T0Z7a;0:QlC@2WNdh0YWY=
0:EhCP<0YWe9102WOTX20:QoB`80Xgi:0`2TOd/30:F0C080YWa:00<0Z7i<0:UoC@2ZP4h00P2YOdd0
0`2XOT`0Z7m;0:QoB`060:QoB`@0Z8=>102WPTd00`2ZQE40ZHA@0:R3C`020:N2CP0;0:R3C`2YQ500
ZXEA0:J1C02WPTd0Z8=>0:V4C`2XPdh0Yh9=0:F0B`2TOdX00P2UP4/30:J1C0<0Yh9=0P2[PTh20:b3
C`<0[HA@00L0[XEA0:R4BP2XQ4X0Z8=<0:R3CP2WPTd0Yh9>0080Yh5@202XPdl80:^6DP<0[8=?0P2]
Q5030:j5D@060:f3D@2^Q580[XAB0:n5D`2^Q580[H=A0P2[PDl80:Z5D0<0[HQD0P2/Qe<30:^6DP80
[8MC00D0ZhIB0:Z5D@2[QU80[8MC0:f8E0020:j9E@070:f8E02/Qe<0ZhIB0:^6DP2/Qe<0[HQD0:j9
E@080:b7D`80ZHA@00<0ZXEA0:^6DP2/Qe<00`2]R5@00`2^RED0[HQD0:f8E0060:f8E0030:^6DP2/
Qe<0[HQD0080[XUE00H0[HQD0:b7D`2[QU80ZH=D0:Z4E@2[QEH20:b6E`060:^5EP2ZQ5D0ZH=D0:Z5
D02[QU40[HQC0P2^RE@00`2]R5<0ZhIA0:Z5D0080:f8E080[8MC0P2[QU800`2ZQE40ZHA@0:R3C`03
0:R3C`80ZHA@0`2ZQE40102[QU80ZHA@0:V4D02YQ5020:Z5D@<0ZhIB00@0ZHA@0:Z5D@2ZQE40ZXEA
0`2[QU800`2/Qe<0ZHA?0:V4C`060:V4C`P0ZHA@00<0ZXE@0:V4C`2WPTd00`2VPD`0102WPTd0Z8=>
0:J2CP2VPTh30:N3C`<0Z8A@00P0Yh9=0:J1C02UP4/0Y7m:0:F0B`2VPD`0Z8=>0:V4C`80YX1?00@0
YX5=0:J1C02VPD`0YX5:0P2VPTP01P2WPE@0Yh5B0:N1DP2WPE00Yh9>0:N2C@80Yh9;00H0ZWm<0:V0
C02YP4`0ZH5=0:N2C@2WQ4h20:F4CPP0Yh=?2@2YP4`80:J1C@80YH5=0P2VPTh30:N3C`030:R4D02V
P540YGm@0080Y7i?00@0YGm@0:N1DP2YPe@0ZXAE0`2YQ5020:R3C`<0Yh9>202ZQU830:V5D@80ZXIB
0`2[Qe<20:Z6DP80ZhMC0`2/R5@0102]RED0[XUE0:f8E02/Qe<20:^6DP030:b7D`2]R5@0[XUE00P0
[8QD00@0[HUE0:j:EP2^RUH0[XYF0P2_ReL:0;2<F0<0/hiI0`2bSEP20;6<E`<0]HaH0P2dReL30;>:
EP80/heN00@0/XaM0;6;G02aRe`0/XaM0P2cSEh20;:<G@80/heN0`2dSUl01P2eSf00/8]D0;6<E@2a
S5L0/XeI0;>=G080]8iO00@0]HmR0;:@H02bT600/Y1P0P2cTF430;BBHP@0]I5Q102fTV880;FBG0@0
]i5R0`2hTV<20;VCI080^YAU00<0^I=T0;RBH`2gTF800P2fT6400`2eSf00]i=S0;NCH`060;NCH`80
^9=O0P2gTUh20;JAG@80]I1L202fTUh00`2fTV80]i=S0;RDI0020;VEI@030;RDI02gTf<0]Y9R00P0
]i=O0P2eT5`20;JAG@80]i9N0P2hTel30;NCH`80]Y9R0`2eTF430;JBGP<0]i=O0P2hU6080;JBHP80
]I1L00@0]Y5M0;NBGP2gTUh0^9=O0P2iU6080;NCH`040;VEH@2hU600^9AP0;RDH0<0]i=O00<0]Y9N
0;RCIP2hTfH01P2hTfH;0;RDI0<0^IEU0P2jUVH80;NCG`080;NCH`2fTV80]Y9R0;FAH@2fTV80]i=S
0;RDI02iUFD90;RDI0P0]i=S0`2dT6030;FAH@80]Y9R202gTVD30;JBHP<0]i=S0`2hU6@00`2gTf<0
]Y9R0;JBHP020;JBHP030;NCH`2hU6@0]Y9N00L0]Y9N00<0]I5Q0;JBHP2gTf<00`2gTf<00`2fTV80
]I5Q0;JBHP070;JBHP<0]I5Q0`2dT6020;>?G`P0]I5Q00@0]91P0;FAH@2eTF40]I5Q0P2fTV820;NC
H`P0]I1L00<0]i5T0;J@H`2eSf800P2cSF000`2eSf80]Y1S0;NAI0020;NBI@040;JAI02eT6<0]8mR
0;B?HP80/hiQ0P2eT6@00`2eT6<0]I5Q0;FAG`020;FAG@040;FBG02bSUX0/XiJ0;:>FP80/hmK0`2d
T5`00`2dT600/hmO0;:>GP020;6=G@060;:>GP2cSel0]91P0;>=GP2dSUl0]HmP0P2fT6401@2eSf00
]8iO0;>=GP2`S5`0/HeM0080/XiN0P2cSel00`2aSEd0[h]K0:j:FP080;>=GPP0]Y5T00<0/XiN0;>?
G`2dT6000P2eTF400`2dT600/hmO0;:>GP030;:>GP80/HeM0`2`S5`30:n;F`<0/8aL0P2aSEd80;B@
H080/XiN102cSel20;B@H0030;6?G`2bT600/i5Q0080]99R00<0/i5Q0;:@H02aSel00P2bSUh20;6=
G@80/8aL0P2_Re/00`2aSET0/8aH0:n;E`030:n;E`030;2<F02aSET0/XiN00L0/XiN00<0]I5Q0;B@
H02cSel00`2aSEd50;:>GP<0/HeM0P2`S5`80;:>GP<0/HeM0P2bSUh30;6=G@0:0;BAF`2bSUX0/HeI
0;2<FP2`S5`0/HaO0;:=H@2dSf<0/hiJ0;B?F`<0]I1L00@0/hiJ0;:=F@2`ReL0[HUE0`2^RUH20:n;
E`80/8aH00<0/hiR0;:=H@2aS5l00P2`S5`01@2`S5X0/8aH0;6=F@2aSUP0/8aL00L0[h]K0`2bS5d2
0;6;G0<0/8YK102^RUH20:n;E`80/8aH00<0[XQI0;2:F`2aRe`00P2bS5d00`2aRe`0/8YK0:j8F@08
0:j:FPP0[XYF0`2`ReL20:n:EP<0[XUE00<0[8QH0:f9F@2^RUX00`2_Re/20:j:FP080;29GP2_R5d0
[hUL0:n9FP2^R5L0[XUE0:f8E02]R5<20:j9E080[HQC0P2/Qe820:^6D@<0ZhEF0`2/QUL20:f7F0P0
ZhMC0P2^RED20:f8E080[8MC0P2[QU801@2_RUH0[XUE0:j9E@2]R5@0[8MC0080ZhIB00<0ZXEA0:^5
EP2[QEH01P2[QEH20:Z4E@<0ZH=D0`2XPU<0102XQ500ZHEA0:V5D@2YQE420:Z6DP80ZhMC0`2YQ4l2
0:Z5D0<0ZhIA0`2ZQU830:^7D`<0[8QD0P2[Qdd0102[QTl0ZXE@0:Z5D02YQ5020:V3DPP0ZHA@00<0
ZX590:^2BP2/Pdd00P2^QE402@2/PU00Zh5A0:Z0D02VP4l0Yh5@0:N2CP2XPdh0ZHA?0:Z5CP020:^7
C@X0Z8=?0`2WPTh30:J1C@P0Yh9=0`2XPdl20:N2CP<0YX5=0`2UPDd20:B0C0<0Xgm;00<0ZX1>0:Uo
C@2XOT`00P2WOD/00`2XOT`0ZGm=0:Z0CP080:J1C@<0Xgi:0`2TOd/20:F0C0<0YH1;1@2VPD`80:Eo
D0P0YX1A202TPD/00`2VPDd0YH1<0:AoB`020:AoB`030:J1C@2WPTh0ZHA@00<0Yh9>102VPDd00`2U
P4`0Yh=?0:N3C`020:N3C`D0YX9>0P2YQ500102XPdl0Yh9>0:J1C@2VPDd20:F0C0080:N2CP2XPdl0
Z8=?0:V4D02XPdl0YX5=0:AoB`2RODT209mlAP<0X7e70`2QOTP20:B0C080YH5=00@0Y81<0:9nBP2P
O4P0Wg]70P2NN4/0102ONDX0WgU809mjAP2PNdH20:1kA080XWU3102TNdD20:9i@`80XGa50P2PNd@2
09mj@`80WWU20`2NNTH209mkA`D0X7a800@0Wg]709ijAP2MNDD0WGU50P2LN4@809ijAPP0Wg]70P2O
NTH209iiA@80WGQ40`2LMd<03`2MN4@0WWU509mjAP2ONTH0WWU509ehA02LMd<0WWM<09efB`2JM4L0
VG=409Uc@P2LMd<0WWU50:1kAP0209ehA080W7M3102KMT8809UdA`0509eiB@2LN4P0VGE509Mc@`2F
LT800P2GLd<0102HM4@0Ug=309Mc@`2GLd<309Ib@P80UG5100H0UW1909IaA`2FLDL0UW5509IaA02F
LT8309Ib@0<0V7<o0`2GLSh209Ia?@P0UW8n1`2DL4002P2CKcl0U6m2095/?`2>JC`0T6/n09=^@@2D
Kd80TVe008iY?02@JT<2095/@P03099]@@2CKT40U7100080UG4o00<0T6Xk099/?@2CKCh00P2DKSl0
0`2CKCh0TV`m091Z>`02099^?P04095]?@2@K3`0T6`l08m[>`80SVXj00P0TF/l099/?@2CKCh0U6ho
09=]?P2BK3d0T6Xk08mY>PP0SFPk0`2AKCd[ooooo`00:_ooool809AX>`0309AX=`2FJST0Uf/j0080
V6`k00<0Uf/j09IZ>@2DJ3L01P2EJcT509I/>P<0UF/i0P2DJSP309I[?P<0UFXm0P2DJC`209AZ>0<0
UF/i0`2FK3X00`2IKT40V6e009Q]@00409Q]@00309U^@@2HKD00V6e000H0V6e00P2IKT40102JKd80
Vg1309]`@`2LLD@209ebA@T0VFi11P2IKcd209Y`?P80UVhk0P2GKc`0102HL3d0VG4n09Yb?`2KLd08
09ab@0P0WW=00P2OMD<0102NM480WG=109ec@@2LLT0209]a?`80XGQ400@0X7M309mf@P2MM400W7<o
0P2KLSh02`2KLS`0W7<m09ed@02NM480X7I60:9gBP2SN4/0Y7U>0:5lB02PNdL0WgY60080WWU50`2M
N4@01P2MNDD0WWU509iiA@2PN4D0XGM50:9fA@80Y7I5202RMTD20:9g@0040:9g@P2SN4D0XgQ50:=g
AP80Y7Q9102SNTH40:AkA`P0XgY600/0WG@n0:1g@@2TNdD0Ygi80:ImA`2TNdD0WgI009ed?P2QMT<0
XgQ50:EjA`020:MlB@040:EjA`2SN4D0XGI30:MlA`80YW]600<0YGY50:AiA02SN4<00P2RMd801P2W
OTX0YWe90:ImB@2UO4P0Y7]70:=jAP80XWU50P2VNdH01P2WO4T0Yg]:0:MkC02WNdh0YWY=0:IiC`<0
YWe9102WOTX20:QoB`80XWe90`2SOTX30:AoB`040:IlBP2WOD/0Yge;0:QnC0@0ZGm=202XOd/01@2Z
QE00ZHA?0:V4C`2XPdh0Yh9=0080YX5<00<0YH1;0:Z5D@2YQ5001@2YQ5002@2ZQE40YX5<0:N2C@2X
Pdh0ZHA?0:R3CP2WPTd0YH1;0:=nB@020:F0B`<0YX5<0`2WPTd30:^2CP80[8=?0`2]Q500202VPTP0
Yh=90:N2B`2WPTd0Z8=>0:R3C`2XPU40ZH=B202XPdl80:Z5D080Zh5?00@0[89@0:f3D@2]Pe40[XAB
0P2_QE<40:j4DP040:f3D@2/PU00[89@0:^1C`P0ZXE@0P2]R5@20:b7D`80ZhIB1@2ZQE420:^6DP03
0:f8E02^RED0[XUE0080[HQD102/Qe<20:f8E0P0[8MC0`2ZQE400`2[QU80[8MC0:b7D`0;0:f8E003
0:^6DP2/Qe<0[HQD0080[XUE00H0[HQD0:b7D`2[QU80ZH=D0:Z4E@2/QUL20:f7F0060:b6E`2ZQ5D0
ZH=D0:Z5D02/Qe80[HQC0P2^RE@00`2]R5<0[8MB0:Z5D0080:j9E@80[HQD0P2/Qe<20:^6DP80ZXEA
0`2YQ5030:Z5D@80ZhIB0`2ZQE430:^6DP80[8MC202[QU880:V4C`P0ZXEA00@0ZhIA0:Z5D02YQ4l0
Z8=>0`2WPTd01P2VPD`0YH5=0:J2CP2VPTh0Yh=?0:R4D080ZHEA00T0ZXIB0:R3CP2WPTd0YH1;0:Ao
BP2UP4/0YX5<0:N2C@2XPdh00P2WPE801`2WPE00Yh9>0:N2C@2WPTd0Yh9;0:N3B@2WPE@00P2WPE80
0`2WPE00Yh9>0:N2C@020:N2B`060:b1CP2[PTh0Zh9>0:^3C`2YQ4l0ZHI@0P2WQU080:R4D0T0ZH5=
202WPTh20:J2CP80Yh=?102XQ500202WPE80YX1A0:EoD02UOe00YX1A0:N1DP2YPe@0ZXAE0P2ZQE42
0:V4D080Z8=?0P2WPTh;0:Z6DP80ZhMC0`2/R5@20:^7D`80[8QD102]RED00`2_RUH0[XUE0:f8E002
0:^6DP030:f8E02^RED0[hYF00P0[HUE0`2^RUH20:n;E`<0/8aH00<0[h]G0;2<F02`S5P00P2`S5P3
0;6=F@050;F@F`2dSeX0]8mJ0;>>F@2bSEP00P2aS5L0102`ReH0]HaH0;F<F02eS5P30;B;E`80/hYF
0P2cSEh40;:<G@80/heN0`2bSUh30;>?G`80]91P00P0/8]D0;6<E@2bSEP0/hiJ0;B>G@2eSf00]Y1Q
0;NAI080/hmO0P2dT6020;FAH@80]Y9R00@0]i=S0;JBHP2fTV80]Y9R0`2eTF400`2dT600]I5M0;FA
G@060;FAG@@0]i5R0`2hTV<50;VCI0030;RBH`2gTF80]i5R0080]Y1Q202gTf<20;RCG`80]i9N0P2f
TEd20;F@G0P0]i=O00<0]I5Q0;JBHP2hU6@00P2iUFD00`2hU6@0]Y9R0;FAH@080;RDH080]I1L0P2f
TEd20;NBGP80^9=O0P2hU6@20;NCH`80]Y9R0P2eTF430;JBGP<0]i=O0P2hU6080;NCH`080;B?F`2e
T5`0]Y5M0;NBGP2hTel0^IAP0;ZEH@2kUV880;NCH`P0]i=O202hTfH80;RDI0<0^IEU0`2jUVH20;^G
I`P0]i=O102fTV820;NCH`/0^9AT202gTf<60;FAH@80]Y9R202gTVD20;JBHPH0]i=S00<0^YIV0;RD
I02fTV800P2dT6000`2fTV80^9AT0;ZFIP080;JBGPD0]Y9R0P2eTF400`2dT600]Y9R0;JBHP060;JB
HP<0]I5Q0`2dT6020;>?G`X0]I5Q0P2fTV840;NCH`P0]I1L00<0]i5T0;J@H`2eSf800P2cSF000`2e
Sf80]Y1S0;NAI0020;JBHP80]I5Q0P2dT6020;>?G`80]Y5U00<0]Y5T0;JBHP2fTV000P2fTUh0102f
Ted0/XiJ0;:>FP2bSUX20;>?F`<0]91L00<0]Y9R0;B@H02bSUh00P2`S5`01P2bSUh0]91P0;JBHP2c
SEh0]8iO0;J@H@80]i5R00D0]Y1Q0;B>G`2cSEh0/8aL0;6=G@020;:>GP80/hmO00<0/XiN0;2<G02_
Re/0202cSEh80;F@H`<0/hmO0P2dT6050;>?G`80/XiN0P2aSEd20;2<G0@0[XYJ0P2_Re/20;2<G0P0
]I5Q0`2bSUh20;>?G`<0]91P00<0/8iN0;6?G`2bT6000P2cTF400`2bT600/HmO0;2>GP020;:>GP80
/HeM0P2`S5`20:n;F`80/8aH102_ReL20;2<F0P0/XiN00@0]91P0;>?G`2cSel0/XiN102aSEd30;:>
GP050;6=G@2`S5`0/8aL0;2<G02_Re/0202bSUh00`2`S5`0/HeM0;:>GP020;>?G`0>0;:>GP2aSEd0
/8aL0;BAF`2bSUX0/HeI0;2<FP2`S5`0/HaO0;:=H@2dSf<0/XeI0;>>FP2dSe/20;F@G0030;>>FP2a
S5P0/8]G00<0[XYF0P2_ReL30;2<F080]8mS00@0/hiQ0;6=G@2aSEd0/HeK0P2`S5P00`2`SEL0[XYJ
0:j:FP030:n;F`<0/8aL00P0]8iO0;>=GP2bS5d0/H]L0;2:F`2_REX0[XQI0:f7F0H0[XYF0P2_ReL0
0`2^R5L0/8YI0;6;FP020;:<F`030;6;FP2`RUT0[XQG00P0[XYJ0P2/R5@0102]RED0[XYF0:j:EP2_
ReL20;2<F0P0[hYF0P2]RET20:j:FP040:n;F`2^RUX0[XYJ0:j:FP80[hQM00<0[hUL0:j8F@2^R5L0
0P2]R5@00`2]R5<0[XUE0:j9E@020:f8E080[8MC0P2[QU801@2YPe@0ZXAE0:Z4E@2[QEH0[8IG0080
[HMH00<0[XQI0:Z6DP2ZQU800P2ZQU840:^7D`80[XUE0P2]R5@20:b7D`80ZhIB00P0/8]G0:n:EP2^
RED0[HQD0:b7D`2[QU80ZXEA0:V4D0P0ZhED00<0ZXE@0:Z5D@2YQ5000P2YPe830:R2D`80Z8A@0`2Y
QE430:Z6DP<0ZHA@0P2ZQE430:^6DP@0ZXIB1@2[Qe<20:Z6C0040:Z5CP2ZQE00ZXE@0:Z5D@80ZXAC
202ZQE400`2ZPDT0Zh9:0:b3C@020:j5D@030:b2D02[PE40ZX1@0080Yh5@00@0Z8=?0:R3CP2YQ4l0
ZXE>0P2ZQT`80:R3C`80Yh9>0P2VPDd40:F0C0P0Yh9=0`2XPdl30:N2CP80YX5=0`2UPDd20:B0C0<0
Xgm;00<0ZGm=0:QnC02XOT`0102XOT`00`2YOdd0YH1<0:F0C0060:F0C0<0Xgi:0`2TOd/20:F0C080
YH1;102VPD`20:N2C@P0YGm@202VP5480:B1B`070:J1C@2UP4`0Y7m;0:=nBP2TOd/0YH1<0:N2CP02
0:R3C`<0Yh9>00D0YX5=0:F0C02UP4`0YH1<0:V5D`020:R4DP030:N3D@2VPU00YH5?0080YH5?00<0
Y81>0:R3CP2XPdh00P2WPTd20:J1C080YH1;102ZQE40102XPdl0YH1<0:=nBP2QO4P209mkA`<0X7a8
0`2QODT0202TP4`0YH5=0:J2CP2VPTh0YH5=0:=oB`2QODT0Wg]70P2LMTD02@2MMdH0WWQ709mjAP2O
NTH0X7]70:1kAP2OMd<0XGU50:=kA`020:EmB@030:=kA`2QNDD0WgM30080XWe60P2QO4D30:1kA004
09mj@`2NNTH0WWY609ijAP80Wg]70`2PO4P20:5mB@060:1lB02NNTH0WGU509ahA02KMd<0VWI22P2N
NTH409mkA`80X7a80P2ONTH209iiA@80WGQ40`2LMd<03`2MN4@0WWU509mjAP2ONTH0WWU509ehA02L
Md<0W7E:09]dB@2JM4L0VWA509Yd@`2MN4@0WgY60:5lA`0209ag@`H0VgI2202IMDD01@2MNDT0W7Q8
09UeA@2GLd<0UW920080Ug=300@0V7A409Mc@`2GLd<0Ug=30`2FLT8209Ea@@0609MaBP2GLTP0UW57
09IaA@2EL4<0U7100P2DL3h00`2CKcd0V7<o09Qc?`0609Mb?P<0Ug<o102FLSh0102ELCd0Tflo09=_
?`2CKcl309A`@080UG5100h0Tfi1091[?P2>JC`0SfXm09=^@@2EL4<0Tfi1091[?P2@JT<0T6]1095/
@P2AK400TVe009=_?`80Tflm00<0T6Xk099/?@2CKCh00P2DKSl01@2CKCh0TV`m091Z>`2CKcl0TVhn
0080TFdm0P2?Jc/0102>JSX0SFTi095[?02BK3d309=]?P03095[?02?JCX0SVPi00@0S6Lj102=J3/3
08m[>b_ooooo000Zooooo`P0U6Pk00<0U6Pg09IZ>@2GJcX00P2HK3/00`2GJcX0UVXi09AX=`0209I/
>PH0UF/i0`2FK3X309E[>@80U6Xh0`2FJch309EZ?@80U6Tl0P2DJSP309E[>@<0UV`j0`2HKD0209U^
@@L0V6e0102GK3l209Q]@00409U^@@2JKd80Vg1309aaA080WG952@2IKT4609U_?@80V6hl00@0UV`j
09M]>`2HKS`0VFlm0P2JL3h:09]a?`P0WW=000D0WgE309id@P2NM480WG=109ab@00209]a?`0709Y`
?P2QN4@0XGQ40:1g@`2OMT80WGA009ac?`0209]b?P0809Ya>`2KLS`0W7<o09id@P2PMTH0XWM:0:Ai
C02TNDh20:F0C080Y7m;00D0XWe90:5lB02PNdL0WgY609eiA@0209iiA@030:1hA@2QMdD0XWI50080
Y7I5202RMTD20:9g@0040:9g@P2SN4D0XgQ50:=gAP80Y7Q90P2RNDD20:=jAP80Y7]70P2UO4P80:=j
AP0;09ed?P2OMT00Y7]50:ImA`2WOTP0Y7]50:1g@@2MM3h0XGI30:=hA@2UNTL00P2WO4T00`2UNTL0
XgQ50:5f@`020:IkAP030:EjA@2TND@0XgQ30080XWM200H0XGI10:9iA@2RNDD0XgY60:AkA`2UO4P2
0:ImB@090:MnBP2WO4L0Yga70:IkB02VNTT0YWY;0:IjC@2WNdh0YgY@00<0YWe9102WOTX20:QoB`80
XWe90`2SOTX30:AoB`@0Yge;00@0Z7i<0:UoC@2YOdd0ZX1>202XOd/01@2ZQE00ZHA?0:V4C`2XPdh0
Yh9=0080YX5<00@0YH1;0:V4D02YQ500ZHA@0P2ZQE430:V4D0030:F0B`2VPD`0Yh9=0080Z8=>00<0
YX5<0:AoBP2SOTT00P2UP4/30:J1C0<0Yh9=0P2ZPDd20:^2CP80[8=?0P2]Q500202VPTP0Yh=90:N2
B`2WPTd0Z8=>0:R3C`2XPU40ZH=B202XPdl80:Z5D080Zh5A00@0[89B0:f3D`2]Pe<0[XAD0P2_QED0
102_QE<0[XAB0:j4DP2]Pe440:b2D0P0ZXE@0`2/Qe<20:^6DP<0ZXEA00@0Z8=?0:V4D02ZQE40ZhIB
0P2/Qe<20:f8E080[8MC102]R5@20:b7D`P0ZhIB00<0ZXEA0:^6DP2[QU800P2[QU840:b7D`P0[HQD
00<0ZhIB0:b7D`2]R5@00P2^RED01P2]R5@0[8MC0:^6DP2ZQ5D0ZhEF0:b6E`80[HMH00H0[8IG0:^5
EP2ZQ5D0ZhIA0:b7DP2]R5<20:n:E@030:f8D`2/Qe80ZhIA00P0[XUE0P2]R5@40:b7D`80ZhIB0P2Y
Q5030:Z5D@L0ZhIB0P2/Qe<20:f8E0@0[8MC102[QU880:V4C`P0ZXEA0`2[QU400`2ZQE00ZHA?0:R3
CP020:N2C@80YX9>00@0Yh=?0:R4D02XQ500ZHEA0P2ZQU80202XPdh0Yh9=0:J1C02UP4/0Y7m:0:F0
B`2WPTd0Z8=>0P2XPUD00`2XPU<0Z89A0:R3C`020:R3CP070:R3C02XPUD0Z89C0:R2D`2XPU40Z8=?
0:R3CP020:R3C0060:f2C`2/Pdl0[8=?0:b4D02ZQE00ZHI@0P2XQe480:R4D0T0Z8=>202XPdl20:N3
C`<0Z8A@0`2YQE400`2YPe@0Z89C0:N1DP020:J0D@030:R2D`2YPe@0ZhEF00<0ZXEA0P2YQ5030:R3
C`/0ZhMC0P2/R5@30:f9E@80[8QD0`2]RED30:j:EP030;2;E`2_RUH0[HQD0080[8MC00<0[HQD0:n:
EP2`ReL0202_ReL20:j:EP80[h]G0P2`S5P20;6=F@80[h]G0P2`S5P0102aSET0/XiJ0;:>FP2bSUX2
0;F@F`040;B?FP2cSUT0/hiI0;:=F080/HaG0P2fSET30;F<F0<0]8]G202cSEh20;:>GP<0/hmO0`2d
T600202aS5D0/XeF0;>>F@2dSe/0]HmN0;J@H@2gTF80^99U0`2cSel20;B@H0<0]I5Q00@0]i=S0;JB
HP2fTV80]Y9R0`2eTF400`2dT600]Y9P0;JBH0060;JBH0@0]i5R0`2hTV<30;VCI0@0^99S0`2gTF88
0;NCH`80^9=O0P2gTUh20;JAG@80]I1L202gTel00`2eTF40]Y9R0;NCH`020;RDI0030;NCH`2fTV80
]I5Q00P0^IEQ0P2eT5`20;JAG@80]i9N0P2hTel30;RDI080]i=S0`2fTV830;JBGP<0]i=O0P2hU608
0;NCH`80]I1L00@0]Y5M0;NBGP2iU600^YEQ0P2kUV880;NCH`@0]Y9N102gTel80;RCIPP0^9AT0`2i
UFD30;ZFIP80^iMW202gTel00`2eTF40]Y9R0;JBHP020;NCH``0^9AT202gTf<60;JBHP80]I5Q202g
TVD60;NCH`80]Y9R00<0^YIV0;RDI02fTV800P2dT6000`2fTV80^9AT0;ZFIP080;JBGP80]i=S00<0
]Y9R0;FAH@2dT6000`2dT6080;JBHP<0]I5Q0`2dT6020;>?G`P0]Y9R0`2eTF420;JBHP<0]i=S202e
T5`00`2gTF@0]Y1S0;F?HP020;>=H0030;F?HP2fT6<0]i5T0080]I5O102dT5h20;>?G@80]Y5U00<0
]Y5T0;JBHP2fTV000P2fTUh0102fTed0/XiJ0;:>FP2bSUX20;>?F`<0]91L00<0]Y9R0;B@H02bSUh0
0P2`S5`01P2bSUh0]91P0;JBHP2dSUl0]HmP0;J@H@80]i5R00D0]Y1Q0;F?H02dSUl0/8aL0;6=G@02
0;>?G`80]91P00<0/hmO0;:>GP2aSEd0202cSEh80;B?HP<0/hmO0P2bSUh60;>?G`80/XiN0`2aSEd4
0:j:FP80[h]K0P2`S5`80;FAH@80/XiN102cSel20;B@H0030:n=G@2`SUh0/HmO0080/Y1P00<0/HmO
0;2>GP2_SEd00P2bSUh20;6=G@80/8aL0P2_Re/80:n;E`d0/XiN00<0/HeM0;2<G02`S5`00`2aSEd5
0;2<G0P0/XiN00<0/8aL0;6=G@2cSel00P2dT6004`2cSel0/HeM0;2<G02dTE/0/XiJ0;6=F@2`S5X0
/8aL0;6<G`2bSF40]8mS0;:=F@2cSUX0]8mK0;F@G02dSe/0/hiJ0;6<F02_RUH00P2^RUH20:n;E`80
/8aH0P2aSET20;B?H`070;>>H@2cSel0/hmO0;:>G02aSET0/8aH0:n<EP020:j:FP<0[h]K0`2`S5`0
202dSUl0/heN0;:<G@2aRe`0[hUJ0:j8F@2]QeP0[8IG1P2^RUH20:f9E@030:j9E@2`ReL0/HaH0080
/XeI00<0/HaH0;2;E`2^RED0202^RUX0102[Qe<0[8QD0:f9E@2]RED20:n;E`030;2<F02aSET0[hYF
00L0[hYF0P2_Re/20:j:FP040:f9F@2^RUX0[XYJ0:j:FP80[hQM00H0[XQK0:j8F@2]QeH0[HQD0:b7
D`2/Qe820:j8E`80[HMF0P2/QUD20:^5E080ZH=D00@0ZXAE0:^5EP2[QEH0[8IG0P2]QeP00`2XQ500
ZHEA0:V5D@020:Z6DP80ZhMC00<0[8QD0:j9E@2^RED00P2]R5@20:b7D`80ZhIB00P0/8]G0:n:EP2^
RED0[HQD0:b7D`2[QU80ZXEA0:V4D0P0ZhIB0P2ZQT`0102YQ4d0ZHA?0:V3DP2XPU<20:R2E@<0Z8A@
0`2YQE420:Z6DP<0ZH=B0P2ZQ5<30:^5E0T0ZXIB0P2ZQT`0102ZQDh0ZXE@0:Z5D02ZQE420:Z4D`P0
ZXEA00<0ZX590:^2BP2/Pdd00P2^QE400`2/PU00Zh5A0:Z0D0020:R2D@060:R3C`2YQ4l0ZHA?0:V4
C@2YQD/0ZXI<202XPdl20:N2CP80YX5=102UP4`80:J1C080ZHA@0`2XPdl30:N2CP<0YH5=0P2TP4`3
0:=oB`030:MmB`2XOT`0Z7i<00@0Z7i<00<0Yge;0:F0C02UP4`01P2UP4`30:=nBP<0Y7m;0P2UP4`2
0:F0B`80YX5<0P2WPTd20:R3CPP0YGm@202VP5480:B1B`030:F0C02TOd/0Xgi:0080Xgi:00<0YH1<
0:N2CP2XPdl00`2WPTh50:J1C@050:V5E@2XQ5@0Z8AD0:N3D`2VPU800`2UPE400`2TP500Yh9=0:N2
C@040:J1C080YH1;0`2ZQE401@2YQ500Yh9>0:AoB`2RODT0X7]70080Wg]90`2PO4X30:5mB`80Y81<
0P2UPDd0202TP4`0XWi:0:1lB02ONdL0W7M209ag@`2MN4@0WWU50P2ONDP20:1jB@0309eh@`2ONTD0
XGa70080Xgi900<0XGa709mjA@2MN4<00P2RODH20:5lA@<0X7]400@0WgY309ijAP2NNTH0WWY60P2O
NdL30:1lB080XGe900H0X7a809ijAP2MNDD0W7Q409]g@`2JMT8809ijAP0309eiA@2NNTH0WWY60080
Wg]70P2PO4P00`2QODT0WgY609mjAP0209iiA@80WGQ40`2LMd<01`2MN4@0WWU509mjAP2ONTH0WWU5
09ehA02LMd<00P2KM4T01P2JM4L0VWA509]eA02MN4@0WgY60:1kAP80VWE11P2KMT8809Ue@`0509ei
B@2LN4P0VGE509Mc@`2FLT800P2GLd<0102HM4@0Ug=309Mc@`2GLd<309Ib@P80UG5100H0Ug5:09Mb
B02FLDL0UG1409A_@P2CKcl209=_?@03099^?02GLSh0Ug8n00@0Ug8n0P2HLcl209Qd@080Ug<o00@0
UW8n09Ea?@2ELCd0UG4m0`2CKcl309A`@080UG5100T0Tfi1091[?P2>JC`0SfXm09=^@@2EL4<0Tfi1
091[?P2@JT<00P2@Jd40202AK400TF`o095]?@2AKC/0TVhl091Z>`2BK3d0Tfdn0P2DKSl00`2CKCh0
TV`m091Z>`02099^?P04095]?@2@K3`0T6`l08m[>`80SVXj00T0T6Xk095[?02BK3d0Tfdn099/?@2A
Jc`0SfTj08iX>@2:ICP00P2;IST208aW>P80SFPk00@0SVTl08YV=P2:ISH0RVHf:oooool002[ooooo
202CIcX00`2DJ3L0UVXi09M[>P0209Q/>`0309M[>P2FJST0U6Pg00<0UV`j0`2EJcT209AZ>0<0UV`j
0`2EJcT209AZ>0<0UV/n0`2EJSd209AY?080U6Xh0`2EJcT309I/>P0309I[?P2GK3l0V6e00080VFi1
00<0V6e009M/?`2FJch00`2HKD0209M/?`<0UV/n0P2GK3l0102HKD00VFi109U^@@2JKd8209]`@`T0
VFi1102IKcd209Q^?080Ufdk00@0UVXi09M[>P2HK3/0VVhm0`2KKch00`2JKSd0Vg4o09]a?`0609]a
?`P0WW=00`2MLd4309ab@080Vg4o0P2PMd<0102OMT80WWE109ie@@2MM40209ac?`80Vg8l00H0WGA0
09id@P2PMTH0XWM:0:=hB`2TNDh30:J1C@060:F0C02TOd/0XWe90:1kA`2ONTH0WGU50P2NNDD00`2P
N4D0XGM50:9fA@020:AfA@P0XWI50P2RMd00102RMd80XgQ50:=hA@2SMdH20:AhB@050:1g@`2QN4@0
XGQ40:9iA@2SNTH00P2TNdL00`2UO4P0XgY60:=jAP060:=jAP0309ie?`2PMd40XWU30080YGa600<0
Y7]50:5h@P2PMd400P2SN4<40:EjA@80XgQ3102TND@30:=h@`070:9g@P2PMd<0XGQ40:9iA@2SNTH0
YGa80:MnBP020:QoB`080:QmB02WO4L0YW]80:EiB02UNDX0YWY=0:MkCP2XNe430:ImB@@0Ygi:0P2X
Od/20:=nBP<0Y7m;0`2UP4`01P2XOT`0Yge;0:MmB`2VO4X0Yge;0:QnC080ZX1>202XOd/40:R3CP@0
Yh9=00<0Yh9>0:R3C`2YQ5000P2ZQE402`2YQ500Z8=?0:N2CP2UP4/0YX5<0:N2C@2XPdh0Yh9=0:J1
C02TOdX0Xgi90080YH1;0`2VPD`30:N2C@<0ZX5=0P2[PTh30:b3C`80Z8A:00@0Z8=<0:R3CP2WPTd0
Yh9>0P2WPE080:R3C`P0ZHA=0`2/PE@20:f2E@<0[X=F0P2_QE<00`2]Pe40[89@0:^1C`020:b2D003
0:f3D@2ZQE00ZXE@00H0ZXE@0P2/Qe<20:^6DP<0ZXEA00@0ZHA@0:R3C`2YQ500ZhIB0`2/Qe<01@2[
QU80ZXEA0:^6DP2/Qe<0[HQD0080[XUE00<0[HQD0:b7D`2[QU804@2[QU880:f8E0030:^6DP2/Qe<0
[HQD0080[XUE00H0[HQD0:b7D`2[QU80ZXAE0:^5EP2]QeP20:j8F@060:f7F02[QEH0ZXAE0:^6D@2/
Qe80[XUD0P2_RUD00`2^RE@0[8MB0:^6D@080:f8E0<0[8MC1@2[QU80102YQ500ZXEA0:Z5D@2ZQE42
0:^6DP80[8MC00@0ZhIB0:b7D`2/Qe<0[8MC0P2]R5@20:j9E@<0[HQD0P2/Qe<30:^6DPP0ZHA?202[
QU820:Z5D0070:^6D@2/Qe80ZhIA0:Z5D02YQ4l0Z8=>0:N3C`030:R4D0@0ZHEA00P0ZHA?0:R3CP2V
PD`0YH1;0:AoBP2UP4/0YX5<0:N2C@80ZH9G00<0ZH=F0:V3E02YPe800P2YQ5001`2YQ4l0Z89E0:R2
D`2XPU<0Z89A0:R3C`2XPdh00P2XPd`01P2/PDh0[8=?0:b3C`2[Pdl0ZXE@0:V6D080Z8MA202XQ509
0:R5C`P0ZHA@0`2XQ5020:V5D@<0ZXIB00<0ZhEF0:Z4E@2XPU<00P2WPE80102XPU<0ZXAE0:^5EP2[
QU830:Z5D@80ZHA@0P2XPdl80:^7D`<0[8QD0P2]RED30:j:EP<0[HUE0P2^RUH30:n;E`030;6<F02`
ReL0[XUE0080[HQD00<0[XUE0;2;E`2aS5P0202`S5P30:n;E`80/8aH0`2aSET20:n;E`040;2<F02a
SET0/XiJ0;:>FP80/hmK102dSeX30;>>F@040;:=F02fSET0]XeI0;J=F@80]HaH0`2dReL00`2bS5d0
/heN0;B>G`020;F?H0040;B>G`2cSEh0/XaM0;2>GP<0/HmO0P2bT6020;>AH@050;>>E`2dSeP0]8mJ
0;F@G02fT5l00P2gTF800`2hTVD0/heN0;B>G`020;B>G`80]HmP0P2fT6440;FAH@`0]Y9R102gTF83
0;RBH`80^I=T202hTV<80;NCH`80^9=O0P2gTUh20;JAG@80]I1L202gTel00`2dT600]I5Q0;NCH`02
0;RDI0030;NCH`2eTF40]91P00P0^9AP0P2eT5`20;JAG@80]i9N0P2hTel0102iUFD0^9AT0;RDI02h
U6@20;NCH`80]Y9R0`2fTUh30;NCG`80^9AP202gTf<01@2fTEd0]i9N0;NBGP2hTel0^IAP0080^YEQ
00<0^iIR0;NCH`2gTf<01P2gTf<30;FAG@80]Y9N0`2gTel80;RCIP/0^9AT0`2iUFD20;ZFIPP0]i=O
00<0]91P0;FAH@2gTf<00`2hU6@20;NCH`T0^9AT2`2gTf<30;JBHP80]I5Q202gTVD20;RDI0<0]i=S
0`2fTV800`2hU6@0]i=S0;JBHP030;JBHP030;NCH`2hU6@0]Y9N00L0]Y9N00@0^9AT0;NCH`2fTV80
]91P0`2cSel00`2dT600]Y9R0;JBHP060;JBHP<0]I5Q0`2dT6020;>?G`P0]Y9R0P2cSel20;B@H0<0
]I5Q00<0]Y9R0;F@G02eT5`01P2eT5`00`2gTF@0]Y1S0;F?HP020;>=H0030;F?HP2fT6<0]i5T00D0
]91L0`2cSe/20;F@I0030;F@H`2eTF40]I5O0080]I5M00@0]I9L0;:>FP2bSUX0/XiJ0P2cSe/30;B@
G0030;FAH@2dT600/hmO0080/XiN00H0/hmO0;B@H02eTF40]8iO0;F?H02gTF820;RBH`050;NAHP2e
Sf00]8iO0;2<G02aSEd00P2cSel30;B@H0030;>?G`2bSUh0/heN00L0/heN202cSV400`2dT600/hmO
0;:>GP020;6=G@040;:>GP2cSel0]91P0;B@H0<0/hmO0P2bSUh20;6=G@<0[h]K0`2`S5`20;6=G@/0
]91P0P2cSel30;:>GP030:j<G02_SEd0/8iN0080/HmO00<0/8iN0:n=G@2^S5`00P2bSUh20;6=G@80
/8aL0P2_Re/00`2]RED0[XYF0:n;E`020;2<F0030:n;E`2^RUH0[HUE00P0/XiN00T0/HeM0;:>GP2b
SUh0/hmO0;:>GP2aSEd0/8aL0:n;F`2^RUX00P2_Re/20;2<G0<0/HeM202bSUh00`2_Re/0/HeM0;B@
H0020;FAH@0>0;B@H02aSEd0[h]K0;BAF`2bSUX0/HeI0;2<FP2`S5`0/HaO0;:=H@2dSf<0/HaH0;:=
F@2cSUX20;B?F`030;:=F@2`ReL0[hYF00<0[h]G0P2`S5P30;6=F@030;:=H@2cSV80]8mR0080]91P
00D0]91N0;:>FP2aSET0/8eG0;2<G0070:n;F`080;>=GP2bS5d0/H]L0;2:F`2_REX0[XQI0:f7F02/
QUL40:j:EP80[HUE0P2/R5@00`2^RE@0/8]F0;6<E`020;:=F0030;6<E`2`ReH0[XUD00P0[XYJ0P2/
R5@0102]RED0[XYF0:j:EP2_ReL20;2<F0<0[XUE0P2_RUH30;2;E`030;2<G02_Re/0[XYJ00<0[HUI
0P2^RUX20:j7G0030:j8F`2]QeP0[HMF0080[8MC00<0[8MB0:j8F@2^R5T00P2]QeP20:b6E`80ZhEF
102ZQ5D30:^5EP070:b6E`2WPdl0Z8A@0:R4D02YQE40ZXIB0:^7D`020:b8E080[XUE0P2]R5@20:b7
D`80ZhIB00D0[hYF0:j9E@2^RED0[HQD0:b7D`020:^6DP030:Z5D@2[QU40ZhIA00H0ZhIA00P0ZXM7
0:Z6B02YQDT0ZHA=0:V4D02XPU<0Z89E0:R1EP80Yh=?0P2XQ5030:V5D@040:Z6DP2YPe@0ZH=D0:V3
E080ZXAE0`2[QEH0102[Qe<0ZXIB0:Z6DP2ZQU840:V5D@040:R4D02YQD/0ZHE;0:V4C@80ZXE@00<0
ZhIB0:^5E02[QE@0202[QU800`2ZPDT0Zh9:0:b3C@020:j5D@030:b2D02[PE40ZX1@0080ZH=B00@0
ZHA@0:V4C`2YQ4l0ZHA=0P2YQD/:0:R3C`<0Yh9>0`2VPDd80:J1C0<0ZHA@0P2XPdl30:N2CP<0YH5=
0P2TP4`30:=oB`030:IlBP2WOD/0Z7i<0080ZGm=00<0Z7i<0:MmB`2VO4X0202TOd/30:=nBP<0Y7m;
0P2UP4`20:F0B`80YX5<00@0Yh9=0:R3CP2YQ4l0ZHA?202UOe080:J0D@P0Y85;00P0YH1<0:AoB`2S
OTX0XWe90:=nBP2TOd/0YX5=0:N2CP<0YH1<00D0YX5=0:N2CP2WPTh0Yh9>0:R3C`040:N2E@D0YX5D
1@2VPDX30:F0B@@0Z8=?00@0YX5=0:=nBP2QO4P0WgY60P2ONd/30:1lC0<0XGe=00P0XWi:0:=oB`2T
P4`0Y81<0:=oB`2QODT0Wg]709eiA@80WWU200@0WgY509mjAP2ONDP0X7Y;0P2PNTd209ijAP@0X7a8
0P2NNTH20:5lA@80X7]40P2ONT<209ii@P<0WWY60P2ONdL50:1lB00409mkA`2NNTH0WGU509eiA@80
W7Q42P2MNDD0102NNTH0Wg]709mkA`2PO4P20:5mB@80WgY60P2NNDD209ehA0<0W7M300L0WGQ409ii
A@2ONTH0WgY609iiA@2MN4@0W7M30080W7E:00<0VgE809afA`2LMTD00P2MN4@00`2NND@0VGA009Ud
@00209Ye@@@0VgI2202HM4001@2MNDT0W7Q809UeA@2GLd<0UW920080Ug=300@0V7A409Mc@`2GLd<0
Ug=30`2FLT8209Ea@@0609I`B@2FLDL0UG1609E`A02DKd80Tflo0P2CKcd00`2BKS`0UW4m09Ia?@03
09Mb?P<0V7<o00H0VGE109Qd@02HM400Ug<o09Ib?P2ELCd209A`?0L0U71000X0Tflo09A_@P2AK3l0
SVTl091[?P2CKT40U6m2099]@02>JC`0T6Y30P2@Jd400`2@Jcl0T6/n091/?002091/>P03091Z>`2B
K3d0Tfdn0080U6ho00<0Tfdn099/?@2@JS/0202@K3`00`2@JS/0TF/l099/?@02099/?@04091Z>`2?
JCX0SFLh08UT=`80RVDh00<0RfHi08aW>P2=J3/00P2>JC`308QT=2_ooooo000Zooooo`P0TfLj00<0
U6Pg09IZ>@2GJcX00P2HK3/00`2GJcX0UVXi09AX=`0209M]>`80UV`j00@0UF/i09AZ>02DJSP0U6Xh
0`2FK3X309E[>@80U6Xh0`2FJch309EZ?@80U6Tl0P2DJSP309E[>@<0UV`j00<0U6Tl09EZ?@2GK3l0
0P2HKD000`2GK3l0UFXm09AY?00309Q]@00309M/?`2FJch0UV/n0080UFXm1@2GK3l309Q]@0T0VFi1
00<0VW0n09U_?@2IKcd00P2HKS`209M]>`0509I/>P2GJCP0V6Xi09Y/>`2LKSd00P2MKch00`2LKSd0
Vfdl09Y`?P0709Y`?PP0WW=00`2KLCl309ab@080WG=1202NMD40202LLcd0WG@n09ed@02OMD<0X7I6
0:5fB@2RMdX0XWM<0P2RODT01`2SOTX0XWe90:5lB02NNDD0VgI209Ye@@2MNDD00P2NNDD00`2PN4D0
XGM50:9fA@020:AfA@P0XWI50P2RMd00102RMd80XgQ50:=hA@2SMdH20:AhB@0509ie@@2OMT80WgI2
0:1g@`2RNDD00P2SNTH00`2TNdL0XgY60:=jAP060:=jAP80X7M100<0XGQ20:9i@`2SNT@00`2SNT@2
0:Ej@`@0XgQ10P2UNT<30:9g@P80XgQ30`2TND@00`2SNTH0Y7]70:AkA`020:AkA`<0YGa800P0Z7e8
0:MlA`2VNdP0YGU80:EiBP2VNTd0Yg]>0:QkD@<0YWe9102WOTX20:QoB`<0YH1<0`2VPDd20:N2CP03
0:UoC@2XOT`0Yge;0080YWa:00<0Z7i<0:Z0CP2[PDl0202XOd/40:N2C@@0Z8=>00<0YH1<0:J1C@2X
Pdl00P2YQ5001@2XPdl0YX5=0:F0C02UP4/0YX5<00<0Yh9=00<0YH1;0:=nB@2RODP00P2UP4/30:J1
C0<0Yh9=102ZPDd20:^2CP80[8=?00P0ZXI<0:V5B`2YQ4d0Z8=>0:N2C@2VPDd0YX1?0:EoCPP0Z8=?
202YQD/30:j3EP80[H9E0`2/PE@00`2`QU@0[hEC0:f3D@020:^1C`030:b2D02]Pe40[XAB00P0ZXE@
0`2[QU830:Z5D@<0ZHA@00X0ZXEA0:b7D`2/Qe<0[8MC0:Z5D@2YQ500Yh9>0:^6DP2/Qe<0[HQD0P2^
RED00`2]R5@0[8MC0:^6DP080:Z5D@80[8MC1`2[QU880:f8E0030:^6DP2/Qe<0[HQD0080[XUE00H0
[HQD0:b7D`2[QU80ZXAE0:b6E`2]QeP20:j8F@060:f7F02/QUL0ZXAE0:b7DP2]R5<0[XUD0P2_RUD0
0`2^RE@0[HQC0:b7DP080:b7D`D0ZXEA0`2[QU830:Z5D@80ZhIB1@2/Qe<20:f8E0<0[XUE00<0[hYF
0:j9E@2^RED00P2]R5@0102/Qe<0ZhIB0:^6DP2[QU880:V4C`P0[8MC00<0Z8=>0:V4C`2[QU400P2]
R5<00`2/Qe80ZhIA0:Z5D0020:Z6DP<0ZHEA0`2XQ5001P2ZQE00Z8=>0:J1C02UP4/0Y7m:0:F0B`80
YX5<00H0ZX=J0:Z3F02ZPeP0ZXAG0:Z4E@2ZQ5<20:Z5D@060:V3EP2YPe@0ZH=D0:V3DP2YQ500ZHA?
0P2YQ4d01P2/PDh0Zh9>0:^2CP2[Pdl0ZHA?0:V6D080YhI@202YQE490:N6D0P0ZXEA0`2YQE420:Z6
DP<0ZhMC00<0[8IG0:^5EP2YPe@00P2XPU<00`2YPe@0ZXAE0:^5EP020:^6DP<0ZXEA0`2YQ5080:^7
D`040:b8E02]RED0[HUE0:f9E@80[XYF0P2_ReL30:j:EP80[h]G0`2`S5P00`2bSET0/HaH0:n:EP02
0:j9E@030:n:EP2aS5P0/XeI00P0/HeI0P2_ReL20;2<F0@0/HeI0P2_ReL0102`S5P0/HeI0;:>FP2c
Se/20;B@G0<0/hiI0`2dSeX20;F@F`80]hiJ0P2fSET30;F<F0040;B;E`2bS5d0/heN0;F?H080]Y1Q
00<0]HmP0;>=GP2bS5d00`2`T5l20;6AH0<0/Y9Q0P2fTEX00`2fTE`0]Y5M0;J@G`020;J@H@030;J@
H`2eS5h0]HaN00<0]XeO0`2gSV001@2cSel0]91P0;B@H02eTF40]Y9R0080]i=S00<0^9AT0;NCH`2g
Tf<01P2gTf<40;NAHP<0^99S0P2iTf@20;NAHPH0^99S202gTf<20;RCG`80]i9N0P2fTEd20;F@G0P0
^9AP00<0]91P0;FAH@2fTV800P2hU6@00`2fTV80]I5Q0;B@H0080;NCG`80]I1L0P2fTEd20;NBGP80
^9=O0P2iUFD30;RDI0<0]i=S0`2fTUh30;NCG`80^9AP202hU6@80;VDH0P0]i=S0P2dT5`20;FAG@04
0;JBGP2gTel0]i=O0;NCG`P0^9=V202hU6@20;JBHP<0]i=S0`2hU6@80;NCG`080;B@H02eTF40]i=S
0;RDI02iUFD0^9AT0;NCH`2fTV890;RDI0P0]i=S0P2hU6@20;NCH`80]Y9R0P2eTF480;NBI@<0^9AT
00<0]i=S0;JBHP2fTV800P2eTF420;JBHP040;NCH`2hU6@0^9AT0;NCH`80]Y9R202fTUh0102iUFD0
^9AT0;FAH@2cSel20;:>GP030;>?G`2dT600]Y9R00L0]Y9R0`2eTF430;B@H080/hmO202gTf<20;6=
G@80/XiN0`2cSel00`2dT600]I1L0;F@G0060;F@G0030;NAI02fT6<0]HmR0080/heP00<0]HmR0;J@
H`2gTF@01P2cSe/20;B@G080]8mS00<0]8mR0;B@H02dT5h00P2dT5`0102dTE/0/XiJ0;:>FP2bSUX2
0;>?F`<0]91L00<0/hmO0;B@H02eTF400`2eTF401@2dT600/hmO0;B>G`2fT640]i5R0080^99S00D0
]i5R0;J@H@2dSUl0[h]K0;6=G@020;>?G`030;B@H02eTF40]91P0080/hmO202cSEh80;:=H0030;B@
H02cSel0/HeM0080/8aL00<0/HeM0;>?G`2dT6000P2dT6030;>?G`<0/XiN0P2`S5`30;6=G@/0/XiN
00/0]i=S0;JBHP2eTF40]91P0;:>GP2aSEd0/8aL0:n;F`2]Re/0[XaL0;2>GP020;6?G`030;2>GP2^
S5`0[H]K0080/XiN0P2aSEd20;2<G080[h]K00<0[8QD0:f9E@2_ReL00P2`S5P00`2_ReL0[HUE0:b8
E0080;:>GP080;2<G02aSEd0/XiN0;>?G`2bSUh0/HeM0:n;F`2^RUX20:b8F0040:f9F@2_Re/0/8aL
0;:>GP80/hmO202bSUh00`2_Re/0/HeM0;B@H0020;JBHP0C0;B@H02aSEd0[h]K0;BAF`2bSUX0/HeI
0;2<FP2`S5`0/HaO0;:=H@2dSf<0/HaH0;:=F@2cSUX0]8mK0;>>FP2bSET0/8]G0:n:EP020:n;E`80
/8aH102aSET00`2`Rel0/HaP0;>>H@020;FAH@040;FAG`2dT5`0/hmK0;:?F@80/HeM0P2`S5`0102_
Re/0[XYJ0:f9F@2]RET20;6;G080/8YK00D0[hUJ0:j8F@2^R5T0[HMH0:n;E`020:j:EP80[HUE0P2/
R5@0102[Qe<0[XUB0;2;E02aS5D20;:=EP030;6<E@2`Re@0[XUB00P0[XYJ0P2]RED40:j:EP80[h]G
00<0[HQD0:j9E@2^RED00P2_RUH20;2;E`040;6<F02bSUh0/8aL0:j:FP<0[8QH00L0[HUI0:j:FP2^
Qe`0[XML0:f7FP2]QeP0[8IE0080[8MC00<0[8MB0:j8F@2^R5T00P2]QeP20:b6E`D0ZhEF0`2ZQ5D2
0:V3E0060:J2CP2WPdl0Z8A@0:V5D@2ZQU80ZhMC0P2/R5@20:j9E@80[HQD0P2/Qe<20:^6DP@0[HQD
102/Qe<80:^6C`080:Z7@`2ZQdD0ZHE70:V5B`2YQ500Z89C0:R1EP2XPEP30:N3C`80Z8A@0`2YQE43
0:V3E080ZXAE0`2[QEH20:^7D`80ZXIB0P2YQE430:R4D0030:R4BP2YQD/0ZHA=0080ZXE@00<0ZhIB
0:^5E02/QUD0202[QU800`2ZPDT0Zh9:0:b3C@020:j5D@030:b2D02[PE40ZX1@0080ZH=B00@0ZHA@
0:V4C`2YQ4l0ZHA=0P2XQ4X80:R3C`<0ZHA@0`2XPdl20:N2CPP0YH1;0P2ZQE420:V4D0<0Z8=?00@0
Yh9>0:F1C@2UPDd0YH5=0P2TP4`30:=oB`030:EkB@2VO4X0Z7i<0080ZGm=00<0Z7i<0:IlBP2UNdT0
202TOd/30:=nBP<0Y7m;0P2UP4`01P2TOdX0YH1;0:J1C02WPTd0Z8=>0:V4C`80ZXE@202UOe080:J0
D@P0Y85;00<0YH1<0:AoB`2SOTX00P2RODT02`2TOd/0YX5=0:N2CP2RODT0Xgi:0:AoB`2UP4`0Yh9>
0:R3C`2YQ500ZXEA00@0YX5E1@2WPUH60:F1A`80YX980P2UP4`20:J1C@040:AoB`2RODT0X7]709ii
A@80Wg];0`2PO4`30:5mC@080:1lB02QODT0XWi:0:9nBP2QODT0Wg]709eiA@2KMd<20:9nA0040:5l
A@2QO4P0XG]:0:1jC@80X7U>0P2NODX409akB080WWe:0`2ONT<209ii@P<0WGQ10`2NNTH209mkA`<0
X7a81`2NNTH909eiA@0509ahA02MNDD0WGU509ijAP2PO4P00P2QODT00`2ROTX0WgY609mjAP0209ii
A@80WGQ40`2LMd<01`2MN4@0WWU509mjAP2ONTH0WWU509ehA02LMd<00P2MMT/01`2MMdX0WGM809af
A@2LMd<0VgI209]f@@2HLcl00P2IM40209Ye@@80VgI200<0W7M309Qd@02HM4001P2HM4001@2MNDT0
W7Q809UeA@2GLd<0UW920080Ug=300@0V7A409Mc@`2GLd<0Ug=30`2FLT8209Ea@@0609E_B02EL4H0
U6m509A_@`2DKd80U7100`2CKcd309Ia?@0309Mb?P2HLcl0V7<o0080VGA00P2IMD401P2HM400Ug<o
09Ib?P2ELCd0U70l09=_>`80UW9200@0UG5109A`@02CKcl0Tflo0P2BKSh0102FLD@0TVe008mZ?@2@
Jch209=^@@08091[?P2<IcX0T6Y3091[@@2?JT00SfXn08mZ?@2?Jc/208m[>@03091Z>`2BK3d0Tfdn
0080U6ho00D0Tfdn099/?@2@JS/0SFTi08iZ>P0208m[>`80TFdm00D0TVhn09=_?`2?JCX0T6Xk095[
?002099/?@09091Z>`2>J3T0SFLh08QS=P29I3L0RVDh08]V>@2<IcX0SFPk0080SVTl0`2:ISH[oooo
o`00:_ooool809=W>P0309AX=`2FJST0Uf/j0080V6`k00<0Uf/j09IZ>@2DJ3L00P2GKC/209I/>P04
09E[>@2DJSP0U6Xh09=Y=`<0UV`j0`2EJcT209AZ>0<0UV/n0`2EJSd209AY?080U6Xh0`2EJcT309I/
>P03099W>P2DJC`0UV/n0080Uf`o00<0UV/n09AY?02BIcX00`2HKD000`2GK3l0UV/n09EZ?@0209EZ
?@P0UV/n2@2IKT40102JL3h0VFlm09U_?@2HKS`209M]>`80UV`j00P0UVPg09QZ>@2JK3/0WFln09i`
?`2MKch0W6hm09]]?0P0VW0n202NLd001@2IKcd0VW0n09Y`?P2KLCl0W7900080WG=100@0WWA209ed
@02MM400WGA00P2NMD4309mf@P80WG@n00H0WWE109me@`2PMTH0X7E80:5fB@2QMT/209iiA@80WgY6
00D0WGQ409Ye@@2GLSh0UG0l09eiA@0209iiA@030:1hA@2QMdD0XWI50080Y7I5202RMTD20:9g@004
0:9g@P2SN4D0XgQ50:=gAP80Y7Q90P2MM400102NMD40WgI20:5hA02RNDD:0:=jAP80XGQ20P2PMd40
1`2QN480XWU30:AkA@2UO4H0Yga50:Ej@`2SN4400P2QMSl00`2SN440YGY30:MlA@020:5f@@80XWM2
00X0XgQ30:AiA02UNTD0YGY50:QoB`2WOTX0YWe90:ElB02TNdL0XWU50P2QN4@0202YOTT0Yga70:Ik
B02TN4L0Y7Q90:IjC@2WNdh0ZGaB0`2VODT40:MnBP80Z7m;0`2VPDd30:N2CP80Z8=?00<0ZGm=0:Qn
C02VO4X00P2VO4X00`2XOT`0ZX1>0:^1C`080:QoB`050:F0B`2VPD`0YX5<0:N2C@2XPdh00P2YQ4l0
102ZQE00Xgi:0:F0C02WPTh20:R3C`060:N2CP2UP4`0Xgi:0:AoBP2UP4/0YX5<0P2WPTd00`2UP4/0
Xgi90:9mB0020:F0B`<0YX5<0`2WPTd0102YP4`0ZX5=0:Z1C@2ZPDd20:^2CP80[8=?00P0ZhM=0:Z6
C02YQ4d0Z8=>0:N2C@2VPDd0YGm>0:AnC@P0Z8=?202YQD/20:n4F@040:j3F02]PUL0[H9G0:b1EP80
Zh1E00<0/8ID0:n5D`2]Pe400`2[PDl00`2]Pe40[XAB0:Z5D0070:Z5D0<0ZhIB0P2ZQE430:V4D00;
0:Z5D@2[QU80[8MC0:f8E02/Qe<0ZXEA0:N2CP2VPDd0ZXEA0:b7D`2]R5@00P2_RUH00`2]R5@0[8MC
0:Z5D@080:Z5D@<0[8MC1P2[QU880:f8E0030:^6DP2/Qe<0[HQD0080[XUE00H0[HQD0:b7D`2[QU80
ZhEF0:b6E`2]QeP20:j8F@060:f7F02/QUL0ZhEF0:b7DP2]R5<0[XUD0P2`ReH00`2^RE@0[HQC0:b7
DP080:^6DP@0ZHA@1P2ZQE430:^6DP@0[8MC0`2]R5@20:j9E@80[hYF0`2^RED00`2]R5@0[8MC0:^6
DP020:^6DPP0ZHA?202/Qe<0202WPTd0Z8=>0:^6D@2]R5<0[XUD0:f8D`2/Qe80ZhIA0P2[Qe<0102Z
QU80ZHEA0:V5D@2XQ5020:N3C`040:Z5D02YQ4l0Yh9=0:F0B`80Y7m:00L0YH1;0:J1C02ZPeX0ZX=J
0:Z3F02ZQ5L0ZXAE0080ZXAC00L0ZXEA0:V3EP2YPe@0ZH=D0:V3DP2YQ500ZHA?0080ZHA=00H0Zh1=
0:Z1C@2ZPDd0ZX9>0:R3CP2XQDl20:J5C`P0ZHEA2@2WQU080:Z5D@<0ZHEA0P2ZQU830:^7D`030:b6
E`2[QEH0ZXAE0080Z89C00<0ZH=D0:Z4E@2[QEH00`2[QU820:Z5D@<0ZHA@202[Qe<30:f9E@80[XYF
0`2_ReL30:j:EP80[h]G0`2`S5P00`2bSET0/HaH0:n:EP020:j9E@030:n:EP2aS5P0/XeI00P0/XiJ
0P2_ReL20;2<F0<0/HeI00T0/XiJ0:n;E`2_ReL0/8aH0;6=F@2bSUX0/hmK0;B@G02eTEd00P2bSEP0
102cSUT0]8mJ0;B?FP2eT5/20;JAG080]hiJ0P2fSET40;F<F0030;:<G@2cSEh0]HmP0080]Y1Q00<0
]HmP0;>=GP2bS5d00P2`T5l30;6AH0<0/Y9Q0P2gTU/00`2gTUd0]i9N0;J@G`020;J@H@040;F?HP2e
S5h0]HaN0;F<GP80]XeO0`2gSV00202bSUh0/hmO0;B@H02eTF40]Y9R0;NCH`2hU6@0^IEU202gTVD4
0;NAHP<0^99S0P2iTf@30;NAHPD0^99S202gTf<20;RCG`80]i9N0P2fTEd20;F@G0P0^9AP00<0]91P
0;FAH@2fTV800P2gTf<00`2fTV80]I5Q0;B@H0080;JBGP80]I1L0P2fTEd20;NBGP80^9=O0`2iUFD2
0;RDI0<0]i=S0`2fTUh30;NCG`80^9AP202hU6@30;ZEH@80^IAP0`2hTel80;NCH`<0]91L00<0]I5M
0;JBGP2gTel00P2gTel80;RCIPP0^9AT0P2eTF430;JBHP<0]i=S202gTel00`2cSel0]I5Q0;NCH`02
0;VEI@030;RDI02gTf<0]Y9R00T0^9AT202gTf<0102iUFD0^9AT0;RDI02gTf<20;JBHP80]I5Q202g
TVD0102iUFD0^9AT0;RDI02gTf<20;JBHP80]I5Q00<0]91P0;JBHP2hU6@00P2jUVH00`2hU6@0]Y9R
0;B@H0080;JBGP060;ZFIP2hU6@0]I5Q0;>?G`2aSEd0/XiN0P2cSel80;JBHP<0]I5Q0`2dT6020;>?
G`P0]i=S0P2`S5`30;6=G@<0/XiN202eT5`00`2gTF@0]Y1S0;F?HP020;>=H0030;F?HP2fT6<0]i5T
0080/XmI102cT5X20;BAF`80/XeQ00<0/XeP0;:>GP2bSU`00P2bSUX0102bSeT0/XiJ0;:>FP2bSUX2
0;>?F`<0]91L00<0/HeM0;>?G`2eTF400P2gTf<01P2eTF40/hmO0;6=G@2eSf00]Y1Q0;NAHP80^99S
00D0]i5R0;J@H@2eSf00[h]K0;6=G@020;>?G`050;B@H02eTF40]I5Q0;B@H02cSel0202cSEh80;:=
H0030;B@H02cSel0/HeM0080/8aL00<0/HeM0;>?G`2dT6000`2dT6020;>?G`<0/XiN0P2aSEd20;:>
GP@0/hmO202aSEd20;RDI0040;JBHP2dT600/XiN0;2<G080[XYJ00<0[H]K0:j<G02_SEd00P2`SUh0
0`2_SEd0[XaL0:f;F`020;:>GP80/HeM0P2`S5`20:n;F`030:b8E02]RED0[h]G0080/8aH00<0[h]G
0:f9E@2/R5@0202bSUh00`2_Re/0/HeM0;:>GP020;>?G`0;0;6=G@2_Re/0[HUI0:Z6EP2[QeL0[8QH
0:j:FP2`S5`0/XiN0;B@H02eTF40202bSUh00`2_Re/0/HeM0;FAH@020;NCH`0C0;FAH@2aSEd0[h]K
0;BAF`2bSUX0/HeI0;2<FP2`S5`0/HaO0;:=H@2dSf<0/HaH0;:=F@2cSUX0]8mK0;>>FP2bSET0/8]G
0:n:EP020:n;E`80/8aH0`2aSET0102bSUX0[XUM0;2;G`2cSV420;FAH@0:0;JBH02eTEd0]91L0;>@
FP2cSel0/XiN0;6=G@2`S5`0[h]K0:f9F@80[8QH0`2`RU/30:n9FP80[XQI00@0[h]G0:j:EP2^RUH0
[HUE0P2/R5@20:^7D`030:j9DP2`Re@0/HaE0080/XeF00<0/HaE0;2;E02^RE80202^RUX80:j:EP80
[HQD00@0[XUE0:n:EP2_RUH0/8]G0P2aS5P0202bSUh0/HeM0:j:FP2/R5P0ZhMG0:b8F02]RET0[XYJ
0P2^Qe`00`2]QeX0[HMH0:b6E@020:b7D`030:^6D@2^R5/0[XQK0080[HMJ0P2/QUT20:^5F080[8IG
00@0ZhEF0:Z4E@2ZQ5D0ZH=D0P2XPU<20:J2CP040:N3C`2XQ500ZXIB0:^7D`80[8QD0P2^RED20:f8
E080[8MC0`2[QU830:b7D`<0[HQD00<0[XUE0:^6C`2[QTl01P2[QTl0202ZR440ZXM30:V6AP2YQD/0
ZHA?0:R2D`2XPEH0Z85H0`2WPdl30:R4D080ZHEA0`2YPeH20:Z4E`<0ZhEH0P2[Qe<01@2ZQU80ZHEA
0:V5D@2YQE40Z8A@0080Yh=?0P2XQ4X0102YQ4d0ZXE@0:Z5D02[QU820:b6E@P0ZhIB00<0ZX590:^2
BP2/Pdd00P2^QE400`2/PU00Zh5A0:Z0D0020:V3DP040:V4D02YQ4l0ZHA?0:R3C080Z8A:202XPdl4
0:Z5D@80ZHA@0P2XPdl80:F0B`80ZXEA0P2YQ5040:R3C`<0YH5=0P2TP4`30:=oB`030:EkB@2VO4X0
Z7i<0080ZGm=00<0Z7i<0:IlBP2UNdT0202TOd/30:=nBP<0Y7m;0P2UP4`0202TOdX0YH1;0:J1C02W
PTd0Z8=>0:V4C`2ZQE00ZhIA202UOe080:J0D@P0Y85;00<0Y7m;0:=nBP2RODT00P2RODT0302TOd/0
YX5=0:N2CP2QO4P0XWe90:=nBP2UP4`0Yh9>0:V4D02[QU80[8MC0:AoD`80YH1D00<0YX5E0:N2EP2X
PeL00P2XPeL00`2YQ5P0Y8160:B0AP040:F1A`80YX9800P0XWe90:=nBP2TOd/0Y7m;0:=nBP2RODT0
WgY609iiA@80WgY=0`2PNdh30:5lC`0C09mkA`2PO4P0XGe90:5mB@2PO4P0WWY609ahA02JMT80Y814
0:B0AP2SOTL0XWe80:5kBP2QNdh0X7U>0:1iD02POd`0WWe:09akB00209YiAP0309akB02NODX0X7m<
00<0WWU20P2MN44309ag@0<0WWY60P2ONdL30:1lB0<0WGU50`2NNTH209mkA`P0WGU50P2LN4@0102M
NDD0WWY60:1lB02QODT20:9nBP80WgY60P2NNDD209ehA0<0W7M300L0WGQ409iiA@2ONTH0WgY609ii
A@2MN4@0W7M30080WWM<00H0WWQ;09egB02LMTD0VgI209Ye@@2JMD0209Qc?`80VGA000@0VWE109]f
@P2KMT80W7M3202HMCl01@2MNDT0W7Q809UeA@2GLd<0UW920080Ug=300@0V7A409Mc@`2GLd<0Ug=3
0`2FLT8209Ea@@0609=]AP2CKT@0U6m509A_@`2DKd80U7100`2DL3h0102EL3`0UW4m09Ia?@2GLSh2
09Qc?`80VGA00P2IMD400`2HM400Ug<o09Ib?P0209A`?00;09=_>`2GLd<0Ug=309Ib@P2DL400Tflo
099^?P2AKCd0T6`l09MbA@2DKd800P2@Jch2099]@00308mZ?@2;IST0T6Y30080SfY000<0SfXn08mZ
?@2>JSX00P2>JSP00`2@JS/0TV`m09=]?P0209A^?`0309=]?P2BK3d0T6Xk0080S6Ph00@0SVXj08m[
>`2AKCd0TVhn0P2DL400202?JCX0T6Xk095[?02BK3d0TF/l091Z>`2>J3T0SFLh0P28HcH01029I3L0
RVDh08aW>P2=J3/208iY?0<0S6Ph:oooool002[ooooo202BIcX209I[@00609EZ?`2CJ3d0TVLl095V
>`2@ICX0Sf@i202BK3d209A[=`<0UF`h0`2FKCT0202>HcH0T6Dh09=X>`2FJch0V6e009M/?`2EJSd0
U6Tl202FJch209QY?`0309IY?`2EJSl0U6/o0080TV`o00<0TF`o09M/@@2HKD800P2IKT<01`2HKD80
UV]009=X?@2AIS/0UFTl09IZ?@2IKD000P2JKT401P2IKD00UVXm09EY?02JL3h0VFlm09M]>`<0UF/i
00@0Ufdk09U_?@2JL3h0TG0j0P2AL3/00`2BLCh0TW10099`@P0209=aA00609E[>@2FK3X0UV`j09M]
>`2HKS`0VFlm0P2JL3h0102HKS`0VFlm09U_?@2JL3h209]a?`80W7900`2HK3/00`2IKC`0VVhm09]_
?P0209]_?P0409me@`2NM480WWA209ec@@80W7900P2KLCl0202IM400V7<o09Ia?@2FLCd0Ug8n09Ud
@02KMT80WGQ4202LMd<0202MLd40X7I40:=iA`2RN4H0WWA209ec@@2PMT@0XgU7202OMD<809mc@PP0
XGM500<0XWU50:1g@`2NMD400P2MM4000`2NMD40X7M30:9iA@040:1g@`@0XGQ40`2MNDD309ijAP80
Wg]70P2NM4801P2OMD<0X7I40:5gA@2RN4H0XgU70:AjB0P0Y7U>00<0Y7Y80:=iA`2RN4H00P2QMdD0
1P2SNDL0YG]90:IlBP2WO540YW]@0:EjC`80Y7U>00P0YGY?0:IkD02WO540Zh9<0:QoB@2UO4P0XgU7
0:=iB@80YGY=00<0Z7e@0:^0E@2XOT`01`2XOT`00`2[PDl0ZGm=0:MmB`020:EkB@030:MmB`2YOdd0
Zh5?0080YH1;0`2TOdX30:=nB@P0YX5<202XPdl0202ONTH0XWe90:N2CP2[QU80[8MC0:V4D02VPDd0
Xgi:0P2UOdh0102VPDd0YX5<0:J1C02WPT/20:N3B@P0[89@0P2ZQE420:V4D0@0Z8=?0P2XPU40102X
Pdl0ZHA?0:V4C`2YQ4d20:Z6C0080:f4D02^QE40[hIB0;27D`2_QU80[HA@0:Z1C@2YP4`80:Z5D0P0
[8=?0P2ZQE030:^6D@<0[8MB202YQ4l80:j5D@80Yh9>00@0Z8=?0:V4D02[QU80[8MC0P2]R5@0102Y
Q500ZXEA0:Z5D@2[QU820:b7D`80[HQD00<0ZXEA0:b7D`2]R5@00P2_RUH0102]R5@0[8MC0:b7D`2Z
QE480:j9E0P0[8MC202^R5T20:Z5D@80ZhIB102/Qe<80:f8D`P0ZhIA00@0ZhIB0:b7D`2/Qe<0[8MC
0P2]R5@20:j9E@080:Z8FP2ZR5P0[8QH0:f7EP2_Qe@0/8MC0;27D@2aQU420:n:E@<0[XUD0`2]R5<8
0:Z5D@060;6<F02_RUH0[8MC0:Z5D@2XPdl0ZHA@0P2ZQE401@2_RUH0[XUE0:j9E@2]R5@0[8MC0080
ZhIB2@2ZQE480:Z6C0P0ZXEA00@0ZhIB0:Z5D@2ZQE40ZXEA0P2YQ5020:R3C`<0ZXM?0P2[R5030:b9
D@80ZXE@0P2[QU440:b7DPT0[8QD0`2ZQU820:V5D@<0Z8A@0P2WQU420:R7DP@0ZHQC00P0[XQK0:j8
F@2]QeP0[HMF0:b7D`2/Qe80[8M@0:^6C`@0[HQD102/Qe<80:j:FPP0[XYF202bSET0102`RUd0/H]N
0;6;GP2aReh20;:<G`80/heP0P2^RE`0102_RUd0/8]N0;6<G`2aS5l20;:=H080/XeI00@0/hiJ0;B?
F`2dSe/0]I1L0P2fTEd80;>>F@P0]heK0P2cSEh20;:<G@<0/H]L00L0/8YK0;2:G@2aRe`0/H]L0;6;
FP2bSET0/XeH0080/hiG0P2dSe/20;F@G0@0]Y5M00<0^YAU0;RBH`2gTF800P2fT6401@2gTF80^99S
0;ZDI@2dT5`0]I5M00<0]Y9N00<0]91L0;>?F`2aSET0202eSf080;^?HPT0^IEU0P2eTEd20;JBGP04
0;NCG`2hU600^9AP0;VEH@P0]HmR0`2dT6000`2eTF40]Y9R0;NCH`020;NCH`030;VEI@2hU6@0]Y9R
0080]91P00<0]Y9R0;RDI02iUFD00P2jUV80102iUF40^9AP0;RDH02gTel20;JBGP80]i9V00<0]i9U
0;NCH`2gTf400P2fTUh0102fTed0^9AP0;RDH02gTel20;JBGP030;FAG@2dT5`0]91L00<0]Y=M0`2g
U5h20;REG`P0^9AT202gTf<0202eTF40]Y9R0;NCH`2hU6@0^IEU0;ZFIP2kUfL0_9QX0`2iU6P20;RC
I`<0]i9V202gTf<20;RDI0<0]i=S0`2fTV820;F@H`<0]Y5T0`2gTVD80;RDI0030;NAHP2hTV<0^I=T
0080^YAU00D0^99S0;J@H@2dSUl0]i=S0;RDI0020;VEI@040;RDI02fTV80]91P0;>?G`<0^9AT0`2g
Tf<30;JBHP80]I5M0P2fTUh0102gTel0^9AP0;RDH02iUF420;B@H080]I5Q0P2fTV820;NCH`P0^9=V
0P2hU6@30;NCH`<0]Y9R202gTf<80;VCI0P0]Y5T202eSf001P2_REX0/8YK0;2:F`2bS5d0/heN0;B>
G`80]HmP0P2cSEh0102dSUl0]HmP0;J@H@2fT6420;NAHPD0]Y5M0`2eT5`80;:>FPP0]I5Q202cSel2
0;>>HP030;>>H@2cSel0/hmM0080/hmK00<0/i1J0;F?H02eSf001P2eSf030;:<G@<0/heN0P2dSUl0
0`2hTel0]i9N0;F@G0020;F@G0030;NBGP2iU600^YEQ0080]Y9R0P2eTF400`2dT600/XiN0;6=G@02
0;2<G080]8iO0P2cSEh01@2bS5d0/H]L0;6;G02`RU/0[hYF0080/8]G00P0/HaH0;:=F@2cSUX0/hiJ
0;B?F`2`S5`0/HeM0;>?G`80]I5Q00<0]91P0;>?G`2bSUh00P2cSV800`2bSF00/XiN0;:>G0020;6=
F@030;6>F02cSEh0/heN00<0/heN0`2bS5d30;>>HP80/XeQ0P2aS6000`2`Rel0]8mK0;B?F`020;>>
FP@0/XeI202aSET03P2dT5H0]I1I0;F@F`2eSeh0]8iQ0;:;H02_R640[XMP0:b8F02]RET0[XYJ0:n;
F`2`S5`0/HeM0P2bSUh00`2eTF40]91P0;:>GP030;2<G0050;6=G@2bSUh0/HeI0;2<F02_ReL00P2]
RED02`2_ReL0/8aH0;6=F@2/RE<0[HYD0:j;E@2`SEL0/HiH0;>@FP2dTE/0]I9L0080/HmO0`2`SUh3
0:n=G@<0/XiN0P2cSel30;B@H0P0/XeI00<0[HUE0:n;E`2`S5P00P2aSET00`2`S5P0[h]G0:f9E@02
0:b8E080[HUE0`2^RUH0102_ReL0]I5Q0;FAH@2eTF420;B@H0080;>?G`2bSUh0/XiN0;:>GP2dT5`0
/XiJ0:n;E`2/R5@30:V5D@030:Z6DP2_Re/0[h]K00@0[XYJ0P2]RET30:n;E`80[XYF0`2]RED20:b;
EP030:j:EP2_RUH0/HUF0080/XQF00@0/hMF0:b8F02/R5P0[HUI0P2^RUX01P2_Re/0/8aL0;2<G02`
S5`0[h]K0:f9F@80[8QH00<0[HUI0:n;F`2`S5`0202]RED01P2ZQU80ZhMC0:b8E02]RED0[XYF0:n;
E`80/8aH202]RED0202ZQUH0ZhMG0:f9F@2^RUX0[h]K0:j:FP2]RET0[8QH0P2^RUH0102/R5@0ZXIB
0:R4D02VPTh20:B0C0040:R4D02YQE40ZHEA0:Z6DP80ZhMC0P2/R5@20:N3C`040:R4D02YQE40ZHEA
0:Z6DP80ZhMC00P0[HMJ0:b6E`2ZQ5D0ZH=B0:V4D02ZQE00[8M@0:f8D@80[XQI0P2_REX0102^R5T0
ZhEF0:V3E02WPE880:Z5D@80[HMH0P2/QUL0102[QEH0ZXAE0:Z4E@2YPe@20:R2D`040:V3E02ZQ5D0
ZXAE0:^5EP80[8IG0P2ZQE040:V4C`<0Z8=>0`2YQ5020:Z5D@H0ZhIB0P2ZQE430:V4D080YX9800@0
YX5:0:N2C@2XPdh0ZHA@0P2YPe820:R3C`040:V4C`2ZQDh0ZXI<0:^7C@80[8Q<0P2YQ5020:R3C`80
Yh9>0P2VPDd0102/Qe<0ZXEA0:R3C`2VPDd20:F0C00:0:J1C@2WPTh0Yh9=0:F0B`2SOTT0XWe80:5l
A`2RODP0Y7m:0:F0B`<0YH1<1@2VPDd0602ZQE00YX5<0:=nB@2TOdX0YX5<0:N2C@2TOdX0X7]60:9k
DP2RNe00XWa?0:9lB`2RODP0XWe60:9nA02ROT80Y7m;0:9mB@2ONTH0WWU509mjAP2RODT0YX5=0:V4
D080XGe=00H0X7a<09mkB`2PO4`0XWi>0:B0D02UPE480:J1C@P0Yh5B00H0YH1C0:F1D@2UPE40Y81>
0:B0C02SP4X20:>0B0P0Y7m:00H0XGa80:9mB@2RODT0Xgi:0:AoB`2UP4`20:J1C@<0X81A0P2QPE83
0::2D`80XWi<00<0Xgm=0:B0CP2TP4h00P2UPDl20:J2D080Yh9=00@0YX5<0:F0B`2UP4/0Y7m:0P2S
OTT00`2SOTX0XWe90:1kA`0309iiA@040:1kA`2QO4P0WWi=09inC@<0Wgm>00<0WGe<09]kBP2INDP0
0P2TOdX00`2SOTT0XWe80:5lA`0209mjA@0<09iiA02PNdL0XGa80:9mB@2SOTX0XWe90:1kA`2MN4@0
W7M309Ue@@2KMd<0Wg]70P2ROTX00`2PO4P0WGU509Yf@P0409ahA0@0WGU500<0X7a<0:5mC@2ROTh0
0P2ROTh02`2PO4`0WWY:09eiB@2QO4P0X7]709mjAP2NNDD0WGQ409ag@`2KMT80VWE10080VgI10`2L
Md8309eh@`80X7]60`2QO4L30:9mB00609mjAP2NNDD0WWU509ehA02LMd<0VgI20P2JMD401P2MN4/0
WGU909eiB@2MNDL0WGU509ejA080WGY200@0VWE109]f@P2KMT80W7M30P2MN4@209iiA@0809]dB@2H
LDH0Ug5409]eAP2PNTT0XGa809ag@`2FLC`809Ue@@0609Ud?`2IM400VWE109]eA02KMDH0W7I90P2M
MT/309Qb@`<0Ug520P2FL4401P2GLD`0UW1909I`B@2DKdD0Tfi2099]@0<0TFdm00<0U71009Ea@@2F
LT800P2GLd<0102ELD40U71009=_?`2JMT8209Ue@@0509Qd@02GLcl0UW8n09Ib?P2ELCd00P2ELD43
09Ib@P<0Ug=30P2CKcl3099^?P<0TFdm00T0SfXm08eX>`2;IST0RVDh08aW>P2?JSd0U6m209MbA@2@
KT000P2AKd400`2BL480Tg5309=a@`0209AbA0<0SVTl0`2?JSd2091[?P80T6`j00@0Sf/i08iZ>02<
J3H0RfLe0P2:IS@00`25HcD0QfDg08QV>00208UW>@0308QV>027ICL0QF<e00<0RVPj:oooool002[o
oooo202BIcX209EZ?`0409AY?P2CJ3d0TfPm099W?080TFHk202BK3d309AZ>080UF/i0`2FK3X0102@
ICP0TFHi09=X>`2EJSd<09I[?P80V6To00<0UVTo09EZ?`2DJcl00P2BK3l0302AK3l0UV]009M/@@2H
KD80VFi309Q]@P2GK440UFXo09=X?@2FJSd0Uf/n09Q/?`80VFe000H0V6`o09M[?P2FJSd0VFlm09Q^
?02GKC/309I/>P0409M]>`2HKS`0VFlm099a>`80TW4l00H0TW4n099`@02BL480TW13095_@P2EJcT2
09I/>P0309M]>`2HKS`0VFlm0080VW0n0`2IKcd00`2JL3h0Vg4o09]a?`0209ab@080VFdl0P2JKSd2
09]_?P80W70o0P2NM48209ec@@80W7900P2KLCl00`2JMD40VGA009Mb?P0209Mb?P0309Qc?`2JMD40
W7M300P0WGQ400P0WG=10:1fA02RN4H0XGM509ec@@2KLCl0WWA20:5gA@P0WgE3202OLd880:5gA@03
0:5hA02PMd<0WgI20080WWE100<0WgI20:1g@`2QN4@0102PMd<40:5hA0<0WWU50`2ONTH20:1kA`04
09me@`2PMT@0X7I40:1fA080XGM50P2RN4H80:AiC0030:AjB02SNDL0XWQ60080XGM500H0XgU70:Ek
B@2VO4X0Yga?0:IkCP2UNTd20:AiC0080:EjC@2VNdh0Yga?0:Z1B`2XOdT0YGa80:=iA`2SNDT20:Ej
C@030:QmD02ZOe@0Z7i<00L0Z7i<00<0ZGm=0:QnC02WOD/00`2WOD/0102XOT`0ZGm=0:F0B`2UP4/3
0:AoBP<0Xgi9202VPD`80:N2CP080:5lB02SOTX0YX5=0:V4D02ZQE40Z8=?0:J1C@2UP4`20:EoCP04
0:J1C@2VPD`0YX5<0:N2B`80Yh=9202/PU020:Z5D@80ZHA@0`2XPdl0102WPTh0Z89A0:R2D@2XPdl2
0:V4C`050:V4C@2ZQT`0ZXI<0:f4D02^QE400`2_QU800`2]Q500Zh9>0:V0C0080:Z5D0P0[8=?0`2Z
QE020:^6D@<0[8MB202YQ4l80:j5D@050:N2CP2XPdl0Z8=?0:V4D02[QU800P2/Qe<01@2]R5@0ZXEA
0:Z5D@2ZQE40ZhIB0080[8MC0P2]R5@00`2ZQE40ZhIB0:f8E0020:j9E@040:f8E02[QU80ZhIB0:Z5
D@P0[XUD202/Qe<80:j8F@80ZXEA0P2[QU830:b7D`030:f8E02]R5<0[HQC00H0[HQC202[QU440:b7
D`80[HQD0P2^RED0202ZR5X0ZXQH0:b8F02]QeH0[hMD0;27D`2`Qe40/HIA0P2_RUD30:j9E0<0[HQC
202ZQE40102`ReL0[hYF0:b7D`2ZQE420:V4D0040:Z5D@2[QU80[XUE0:j9E@<0[HQD0`2/Qe<80:Z5
D@P0ZXI<202ZQE420:b7D`80ZhIB0P2ZQE420:V4D0<0ZHI>0P2ZQdl30:^8D080ZXE@0P2[QU430:b7
DP030:f8D`2/R5@0[8QD00L0[8QD00@0ZhMC0:Z6DP2ZQU80ZXIB0P2YQE420:R4D080YhIA0P2XQe83
0:V8D`070:Z9E02^R5/0[XQI0:f7F02]QeH0[8MC0:b7DP020:b7D0D0[HQD0`2/Qe<80:j:FPP0[XYF
202bSET40;6;G080/XaM0P2cSEh20:n;F`030;2<G02aSEd0/XiN0080/hmO00<0]91P0;>>FP2cSUX0
0`2dSe/30;F@G0P0/hiI202gSE/20;>=GP80/XaM102aRe`01P2aReh0/H]L0;6;G02bS5/0/XeI0;>>
F@80/hiG0P2dSe/20;F@G0<0]Y5M00@0]i9N0;VCI02hTV<0]i5R0P2fT6402`2gTF80^99S0;VCI02d
T5`0]I5M0;JBGP2gTel0]Y9N0;FAG@2cSe/0/HeI00P0]HmP202jSf890;RDI080]I5M0P2fTUh0102g
Tel0^9AP0;RDH02hU6080;F?H080]91P0P2eTF420;JBHP80]i=S00<0^9AT0;NCH`2fTV800P2eTF40
0`2fTV80]i=S0;RDI0030;VEH@030;RDH02gTel0]i=O0080]Y9N0P2gTVH00`2gTVD0]i=S0;JBH002
0;JBGP040;JCG@2gTel0]Y9N0;JBGP80]I5M0P2dT5`0102cSe/0]Y9N0;JBGP2fTUh30;NCG`80^9AP
202hU6@80;NCH`80]I5Q00@0]Y9R0;NCH`2hU6@0^IEU0P2jUVH30;VDJ080^9=W0`2gTVH80;NCH`03
0;JBHP2gTf<0]i=S00D0]i=S0P2fTF@30;NBI@<0^9=V202hU6@0202gTF80^99S0;VCI02jU6D0^I=T
0;RBH`2fT640]HmP0P2gTf<01P2hU6@0^IEU0;RDI02gTf<0]I5Q0;>?G`<0^9AT0`2gTf<30;JBHP80
]I5M0P2fTUh20;NCG`80^9AP0P2dT6020;FAH@80]Y9R0P2gTf<80;RCIP80^9AT0`2gTf<30;JBHPP0
]i=S1@2iTf@30;RBH`P0]Y9R202eSf001P2`RU/0/H]L0;:<G@2cSEh0]8iO0;F?H080]Y1Q0`2dSUl2
0;F?H0<0]Y1Q1P2eT5`20;B?F`P0/XiJ202eTF480;>?G`80/hiR00<0/hiQ0;>?G`2cSed00P2cSe/0
0`2cT5X0]HmP0;F?H0060;F?H0L0/heN00@0/XaM0;NBGP2fTEd0]I1L0P2dSe/0102fTEd0^9=O0;VD
H02fTV830;FAH@050;B@H02bSUh0/HeM0;6=G@2`S5`00P2eSf020;B>G`80/heN0P2bS5d40;6<F0@0
/XeI00<0/8aL0;6=G@2cSel00P2eTF400`2dT600/hmO0;:>GP020;>>HP030;>>H@2bSUh0/XiL0080
/HeI00<0/HiH0;>=GP2cSEh0102cSEh20;:<G@80/hiR0`2bSF420;6<H0030;2;G`2dSe/0]8mK0080
/hiJ0`2bSET00`2aS5P0/XiJ0;:>FP060;:>FP80]8mH00H0]I1L0;F?GP2dSV40/X]P0;29H02^Qf02
0:f9F@040:j:FP2_Re/0/8aL0;6=G@80/XiN00/0]I5Q0;B@H02bSUh0/8aL0:n;F`2`S5`0/HeM0;:>
GP2aSET0/8aH0:n;E`020:f9E@030:n;E`2`S5P0/HeI0080[XYF00@0[h]G0;2<F02aSET0/XiJ0P2c
Se/00`2_SEd0/8iN0;2>GP050;2>GPP0/hmO202bSET00`2^RUH0[h]G0;2<F0020;6=F@030;2<F02_
ReL0[XYF0080[HUE0P2^RUH20:n;E`80/8aH0P2dT6030;>?G`080;:>GP2aSEd0/HeM0;6=G@2cSe/0
/HeI0:j:EP2/R5@20:Z6DP80ZhMC0P2_Re/60:j:FP<0[h]G0`2^RUH20:f9E@80[8]F00<0[XYF0:n:
EP2aREH00P2bR5H00`2cQeH0[8QH0:b8F0020:f9F@070:j:FP2_Re/0[h]K0:n;F`2`S5`0[h]K0:f9
F@020:b8F0030:f9F@2_Re/0/8aL00P0[HUE00H0ZHEA0:Z6DP2[Qe<0[8QD0:f9E@2^RUH20:n;E`P0
[HUE0100ZhMG0:b8F02]RET0[XYJ0:n;F`2^RUX0[8QH0:^7E`2]RED0[8QD0:^7D`2ZQU80Z8A@0:N3
C`2VPTh0YH5=0`2YQE400`2ZQU80ZhMC0:^7D`020:b8E0<0Z8A@0P2YQE430:Z6DP080:f7FP2/QUL0
ZXAE0:V3DP2YQ500ZXE@0:b7D02]R5420:f7F0060:j8F@2_REX0[XQI0:b6E`2ZQ5D0Z89C202ZQE42
0:f7F080[8IG00@0ZhEF0:Z4E@2ZQ5D0ZXAE0`2YPe@00`2ZQ5D0ZhEF0:^5EP020:b6E`<0ZXE@0`2Y
Q4l30:R3CPP0ZXEA0`2[QU820:Z5D@<0ZHA@0P2VPTP0102WPT/0Yh9=0:R3CP2YQ5030:V3DP80ZHA@
00<0ZXE@0:Z5CP2ZQT`00P2[Qd/20:V4D080Z8=?0P2WPTh20:J1C@0;0:Z5D@2YQ500Yh9>0:J1C@2U
P4`0YX5=0:N2CP2XPdl0YX5<0:F0B`2SOTT00P2RODP00`2SOTT0Y7m:0:F0B`040:J1C@@0Yh9>00P0
ZHA?0:J1C02SOTT0Y7m:0:J1C02WPTd0Y7m:0:5lA`80XW]@00@0XWa?0:9lB`2RODT0XWe60P2ROT@0
0`2TOd/0XWe90:1kA`0209mjAP0;0:=nBP2VPDd0ZHA@0:9nCP2QODd0X7a<09mkB`2PO4`0XWi>0:B0
D02UPE40202VPDd80:N1DP060:F0D`2UPE40YH5A0:B0CP2TP4`0Xh1:0P2SP4P80:AoBP@0Xgi:102T
Od/30:20C`80XH5@0`2RPU400`2ROT`0Xgm=0:=oC@020:B0CP<0YH5?00@0YX9@0:J1C02VPD`0YX5<
0P2UP4/30:AoBP0:0:=nBP2RODT0X7]709mjAP2NNDD0WgY60:1kA`2QO4P0W7a;09emC0<0Wgm>00@0
WGe<09alB`2JNTT0Y7m:0P2SOTT01`2RODP0X7]609mjA@2ONTD0WWU40:1kA`2QO4P00`2RODT02`2P
NdL0WWU509ag@`2JMT80W7Q409mkA`2QODT0XWi:0:1lB02MNDD0VWI200<0VgM300<0W7Q409eiA@2N
NTH00P2NNTH00`2ONd/0X7a<0:5mC@020:9nCP030:1lC02NNTX0WGU90080X7]700@0WgY609iiA@2M
N4@0W7M30P2KMT8209]f@@<0W7M20`2MN4<80:5lA`0609mjAP2NNDD0WWU509ehA02LMd<0VgI20P2J
MD401P2LMdX0W7Q809ahB02LN4H0W7Q409ai@`80W7U100<0VWE109]f@P2KMT800P2LMd<209ehA009
09iiA@2KM4T0V75609MaA02JM4D0WgU80:1kA`2LMd<0Ug8m00P0VGE100H0VG@o09Ud@02JMD40VWA3
09]eAP2LMTT209aeBP<0V7930`2GLD8209I`@@0609MaBP2FL4T0UG1609A_@`2CKT40TVhn0P2AKCd0
102AKC/0U71009Ea@@2FLT8209Mc@`0309Ea@@2DL400Tflo00<0V7A00`2GLcl209Ib?PP0UW92202C
Kcl0202@Jch0SVTl08aW>P2;IST0S6Lj08mZ?@2CKT40UG130P2?KCl2091^@004095_@@2BL480TW12
099`@PP0SfXm00H0TFdk091/>P2?JcT0SVXh08eY=`2<J3H208]W=@0308MU=`28ISP0RFLi0080RVPj
00<0RFLi08QV>027ICL00`29IcT[ooooo`00:_ooool8099W>P80U6Tn1P2CJ3d8099/?@0409=Y=`2D
JSP0U6Xh09AZ>080UF/i0P2FK3X209=X>`80TVLj00@0TfPk09EZ?@2FJch0V6e0202FJch209QY?`03
09IY?`2EJSl0U6/o0080TV`o00@0TF`o09AY?P2EJSl0UV]00`2HKD801@2GK440UV]009U]@02HK3l0
Uf/n0080UVXm00<0Uf/n09Q/?`2IKD000P2HKS`01@2GKC/0UV`j09I/>P2FK3X0Ufdk0080V6hl00H0
UW<m09Ib?P2ELCd0U70n09=_?`2CKT42099]@@0609E[>@2FK3X0UV`j09M]>`2HKS`0VFlm0P2JL3h2
09U_?@<0VW0n0`2KLCl309]_?P80W70o0`2MLD0309ec@@<0W7900P2KLCl00`2KMT80VWE109Ud@003
09Qc?`80VGA0202NNDD0202MLd40X7I40:9hAP2PMT@0W79009Y`?P2KLCl0WWA2202OMD<80:1d@`P0
XGM500<0XGQ40:1g@`2OMT800`2OMT800`2PMd<0XGQ40:5hA0030:5hA0@0X7M30`2NNDD309mjAP80
X7]70`2RN4H20:5gA@<0X7I4202TND`00`2TNTP0XgU70:9hAP020:5gA@060:=iA`2UNdT0YWa:0:Ml
C`2VNdh0YGY=0P2TND`0202UNTd0YW]>0:MlC`2YP4X0Ygi80:ElB02SNDL0XgU90P2UNTd00`2WO4l0
ZGiC0:MmB`070:MmB`030:IlBP2WOD/0Z7i<0080ZGm=00<0Z7i<0:MmB`2VO4X00P2UP4/30:AoBP<0
Xgi9202VPD`;0:F0C0<0YX5=0P2WPTh20:EoCP040:J1C@2VPD`0YX5<0:N2B`80Yh=9202[PDl30:V4
D080Z8=?0`2WPTh20:R2D@040:R3C`2YQ4l0ZHA?0:V4C@80ZXI<0P2]Q5030:j5D@030:f4D02/Pdl0
Zh9>00P0ZXE@202/Pdl0102YQ4l0ZXE@0:Z5D02ZQE020:^6D@80[8MB202YQ4l80:j5D@80Z8=?00@0
ZHA@0:Z5D@2ZQE40ZhIB0P2/Qe<20:Z5D@<0ZhIB0`2/Qe<20:^6DP040:b7D`2]R5@0[HQD0:b7D`<0
ZhIB202]R5<80:b7D`P0[HMH0`2[QU820:b7D`<0[HQD202]R5<80:^6D@<0[8MC0P2]R5@30:j9E@08
0:Z8FP2ZR5P0[8QH0:f7EP2_Qe@0/8MC0;27D@2aQU420:n:E@<0[XUD0`2]R5<80:^6DP040:n:EP2^
RED0[HQD0:^6DP<0ZXEA00<0ZhIB0:b7D`2/Qe<00`2]R5@30:j9E@P0ZhIB202[QTl80:^6DP<0[HQD
0P2/Qe<30:^6DP<0Z8E?0P2YQU030:Z7D@<0ZhIA0P2/Qe830:f8D`T0[HUE0`2[Qe<20:Z6DP<0ZHEA
0`2ZQU820:^7D`<0[8QD00H0[XQK0:j8F@2^R5T0[HMF0:f8E02/Qe820:b7D0P0[HQD202^RUX80:n;
E`P0/XeI0`2aRe`20;:<G@<0/heN00H0/HeM0;:>GP2bSUh0/hmO0;B@H02eTF420;JBHP040;JAG@2e
T5`0]I1L0;F@G0@0]8mK202cSUT80;N=F`<0/heN0P2bS5d30;6;G0060;6;GP2bS5d0/XaM0;:<F`2c
SUX0/hiI0P2dSeP30;F@G080]Y5M0`2gTUh00`2iTf@0^99S0;J@H@020;F?H00;0;J@H@2hTV<0^I=T
0;B@G02eTEd0]Y9N0;NCG`2fTUh0]I5M0;>?F`2bSUX0202eSf080;Z?HPT0]Y9R0`2fTUh30;NCG`80
^9AP202fT640102dT600]I5Q0;FAH@2eTF430;JBHP<0]i=S00@0]Y9R0;FAH@2eTF40]Y9R0P2gTf<0
102iUF40^9AP0;RDH02hU6030;NCG`060;JBGP2hTfL0]i9V0;NBI@2fTV80]Y9P0P2eTEd00`2eTU`0
]I5M0;B@G0020;B@G0<0/hmK00@0/XiJ0;JBGP2fTUh0]Y9N0`2gTel20;RDH0P0^9AT202gTf<20;B@
H0040;FAH@2fTV80]Y9R0;NCH`80^9AT0`2iU6L20;RCIP<0]i9U202gTf<20;FAH@80]Y9R00@0]i=S
0;RDI02iUFD0^IEU0`2hTfH30;VDI`80^YEX202gTf<20;RBH`<0^I=T00/0^99S0;J@H@2eSf00]Y9R
0;NCH`2hU6@0^IEU0;RDI02gTf<0]I5Q0;B@H0030;RDI0<0]i=S0`2fTV820;FAG@<0]Y9N0`2gTel2
0;B@H080]I5Q0P2fTV820;NCH`P0^9=V0P2hU6@30;NCH`<0]Y9R202gTf<30;ZDI@050;VCI02hTV<0
]i5R0;NAHP2fT640202fTV880;F?H0060;:<G@2cSEh0/heN0;B>G`2eSf00]Y1Q0P2gTF80102fT640
]HmP0;F?H02eSf040;B>G`P0/hiJ202bSUX80;FAH@P0/hmO0P2cSV800`2cSV40/hmO0;>?G@020;>?
F`030;>@FP2eSf00]HmP00P0]HmP00@0]8iO0;>=GP2bS5d0/XaM0P2aRe`00`2eT5`0]8mK0;>>FP02
0;>>FP030;F@G02fTEd0]i9N0080]I5Q0P2dT6020;>?G`030;:>GP2aSEd0/HeM00@0]Y1Q0P2eSf02
0;B>G`@0/XeI102aS5P00`2`S5`0/HeM0;>?G`020;FAH@0;0;B@H02cSel0/XiN0;B?H`2cSV80/hiQ
0;>?G`2bSU`0/XiJ0;6=F@2aSUP0202cSEh20;>>H@030;:=H02aS5l0/HaO00<0/HaO0`2cSUX20;:=
F@<0/HaH202cSe/0202cSUT0]8mK0;F@G02eSeh0]8iO0;:<G`2`REh0[hQM0P2^RUX20:n;F`0?0;2<
G02aSEd0/XiN0;:>GP2dT600/hmO0;6=G@2`S5`0[h]K0;2<G02aSEd0/XiN0;6=F@2`S5P0[h]G0080
[HUE00<0[h]G0;2<F02aSET0102`S5P40;6=F@80[XaL0P2_SEd01@2`SUh0/HmO0;:@H02bT600]I5Q
0080]91P00D0/hmO0;:>GP2aSEd0/HeM0;2<G0080;:=F@030:j:EP2_ReL0/HeI0080/XiJ00<0/HeI
0:n;E`2^RUH00`2_ReL20;2<F0<0/HeI00<0/XiN0;6=G@2aSEd00P2aSEd30;2<G0040:n;F`2`S5P0
[h]G0:j:EP<0[8QD0P2]RED30:j:FPD0[h]K0P2`S5P20:n;E`<0[XYF00H0[HUE0:b;EP2/ReH0[XYF
0:n:EP2aREH20;:8EP030;>7EP2/R5P0[HUI0080[HUI0`2^RUX20:n;F`070:j:FP2]RET0[8QH0:b8
F02]RET0[XYJ0:n;F`080:b8E0060:R4D02YQE40ZHEA0:Z6DP2[Qe<0[8QD2P2]RED00`2[QeL0[8QH
0:j:FP020:n;F`030:f9F@2/R5P0ZhMG0080ZhMC0P2ZQU820:V5D@80Z8A@0P2YQE430:Z6DP<0ZhMC
0`2ZQU820:V5D@<0Z8A@00X0[8II0:^5EP2ZQ5D0ZH=B0:V4D02ZQE00ZhI?0:b7D02[QEH0[8IG0`2]
QeP00`2/QUL0ZhEF0:Z4E@080:Z5D@<0[8IG0`2[QEH20:Z4E@040:V3E02ZQ5D0ZXAE0:Z4E@<0ZhEF
00<0[8IG0:^6D@2ZQE000P2ZQE030:V4C`80Z8=>00D0[8MC0:^6DP2[QU80ZXEA0:V4D0020:R3C`04
0:N2CP2[QU80ZhIB0:^6DP80ZXEA0`2YQ5020:N3B@040:N2B`2XPdh0Z8=>0:V4D080ZH=B0P2ZQ5<0
1P2ZQE40ZXE@0:V4C`2YQ4d0ZHE;0:R4BP80ZHA@0P2XPdl20:N2CP80YX5=0P2WPTh01P2VPDd0YH1<
0:J1C@2WPTh0Z8=?0:V4D080YH1;00H0Y7m:0:=nB@2SOTT0Y7m:0:F0B`2VPD`80:R3C`080:V4C`2U
P4/0XWe80:=nB@2WPTd0Z8=>0:F0B`2QO4L20:9lC`040:9lC@2RO4/0XWe90:9mB080XWe600<0Y7m;
0:9mB@2PNdL00P2PNdL02`2SOTX0YX5=0:V4D02ROTh0XGe=0:1lC02ONd/0X7a<0:5mC@2SOdl0Y81@
00P0YX5=202WPE801P2UP5<0YH5A0:F1D@2TP4h0Y81<0:>0BP80Xh18202TOdX30:AoB`<0Xgi:0P2R
ODT30:5oC`80XX1@0`2SPE430:=oB`80Y81<102UPDd30:AoBP80YH1;0`2VPD`0102SOTX0XWe90:5l
B02PNdL209mjAP050:1kA`2QO4P0VgU909ekB`2NO4`00`2POTh01`2NO4`0WG];0:=nB@2SOTT0XWe8
0:5lA`2PNdH00P2ONTD00`2NND@0X7]70:1kA`030:5lB0060:1kA`2ONTH0WWU509]g@`2MNDD0Wg]7
0P2QODT0502ONdL0W7Q409]g@`2IMD40VWI209]g@`2LN4@0WGU509ijAP2ONdL0X7a809mkB`2PO4`0
XGe=0:9nCP2QODd0X7a<09ijBP2MNDT0X7]70P2ONTH01@2NNDD0WGQ409ag@`2LMd<0VgI20080VgI1
0`2LMd8309eh@`80Xgi900<0XWe80:5lA`2PNdH00`2ONTD01P2ONTH0WWU509iiA@2MN4@0W7M309]f
@P80VWE100H0VWE809YfAP2JMTH0VWI409Yf@P2JMd4209Yg?`@0VgI20P2LMd<209ehA00809YcB02H
LDH0V79509YdA@2MMdH0WWU509]f@P2HLch809Ue@@0809Ud?`2JMD40VWE109Yd@`2KMDH0VgE809]d
B@2LMDX309Qb@`<0Ug520P2FL4401P2FL4T0UW5709E`AP2DKd<0Tfi1099^?P80TVhl00@0TFdk09=_
?`2DL400UW920P2GLd<00`2FLT80U71009=_?`0309Ib?P<0Ug<o0P2HM40209Mc@`80UW9200@0UG51
09A`@02CKcl0Tflo0P2BKSh0102CKcl0U71009A`@02ELD4209Ib@P03099]@02@Jch0SVTl0080S6Lj
00<0SVTl095/?`2CKT40102>K3h208m]?`80T6i00`2AK3l00`2@Jch0SfXm08iY?00208eX>`80TFdm
00@0T6`l08m[>`2>JSX0SVXj0P2=JCT00`29IcT0RVPj08]Y>`0208aZ?00308]Y>`2:J3X0RFLi00<0
R6Hh:oooool002[ooooo202CJ3/309=X?@<0U6Tn0P2EJSl8099/?@80TfTi0`2DJSX309E[>`0309EZ
?@2DJC`0TVLj0080TFHi00<0U6Tl09M/?`2IKT40202FJch209QY?`0309IY?`2EJSl0U6/o0080TV`o
00D0TF`o09=X?@2DJCh0UFXo09I[@00209Q]@P80VFi300<0VVi109U]@02FJSd00P2EJC`00`2FJSd0
VFe009Y^@@0309M]>`<0UV`j0`2GKC/02@2HLch0V7<o09Mb?P2EKch0U6ho09=]@02BJd00TFXo09E[
>@0209I/>P0309M]>`2HKS`0VFlm00P0VW0n0P2KLCl809ea@0H0W7900P2KLCl209ag@`0309]f@P2I
M400VGA000<0V7<o202NNDD0202MLd40X7I40:9hAP2PMT@0Vg4o09U_?@2JL3h0WG=1202OMD<80:1d
@`P0XGM500<0XGQ40:1g@`2PMd<0102PMd<50:5hA0@0X7M30`2PN4D30:5iAP80XWY700P0YG]90:Aj
B02SNDL0XWQ60:5gA@2PMT@0WgE309id@PP0XgU900<0Y7Y80:=iA`2RN4H00P2QMdD01P2SNDL0YG]9
0:IlBP2WODd0YWa<0:EkB`80Y7Y:00P0YG];0:IlC02WODd0Z7m90:MnB02UO4P0Y7Y80:AjBP80YGY=
00<0Yga?0:QmDP2WOD/01`2WOD/00`2TNTP0YWa:0:QnC0020:Z0CP030:QnC02VO4X0Y7Y80080YH1;
0`2TOdX30:=nB@P0YH1;202SOTX00`2WPTh0YX5=0:AoB`020:=nBP030:AoB`2WPTh0Z8=?0080YGm>
00@0YX5=0:J1C02VPD`0Yh9;0P2WPdT80:^1C`80ZHA@0`2XPdl30:N2CP80Z89A00@0Z8=?0:V4C`2Y
Q4l0ZHA=0P2ZQT`30:f4D0030:j5D@2]Q500[HA@0080[8=?202ZQE080:b3C`80ZHA?0`2ZQE030:^6
D@P0ZHA?202]Q5000`2XPdl0ZHA@0:V4D0020:Z5D@80ZhIB00<0[8MC0:^6DP2[QU80102[QU820:b7
D`80ZhIB102/Qe<30:^6DPP0[HQC202/Qe<80:f7F080ZhIB0`2/Qe<30:f8E0P0[HQC202[QU420:b7
D`80[HQD0P2^RED20:n:EP080:^9F`2[RET0[HUI0:j8E`2`R5D0/HQD0;68DP2bQe820:n:E@<0[XUD
0`2]R5<80:^6DP80[XUE00<0[HQD0:b7D`2[QU80102[QU820:b7D`050:f8E02^RED0[hYF0:n:EP2`
ReL0202/Qe<80:^6D@P0[8MC0`2^RED20:f8E0<0[8MC0P2WPdl30:R4D0<0ZHEA0P2[QU430:b7DP<0
[HQC2@2^RUH30:b8E080ZhMC0`2ZQU820:^6DP<0[8MC0`2]R5@01P2_RE`0[hUJ0:j8F@2^R5L0[HQD
0:f8D`80[8M@102]R5@40:j9E@P0[XYJ202`S5P80;>>FP80/H]J0P2bS5/20;>=G080]8iM00H0/hmM
0;B@GP2dT5h0]I5O0;JBH02gTf420;RDHP80]i9N00@0]Y5M0;F@G02eT5`0]8mK0P2cSUX80;B?FPP0
]heK0P2dSUl20;>=GP80/XaM0P2aRe`01P2bS5l0/heN0;>=GP2cSE`0]8mK0;B?FP80]I1I0P2eT5`3
0;JAG@<0]i9N00<0^I=T0;NAHP2fT6400P2eSf001@2fT640]i5R0;VCI02eTEd0]Y9N00<0]i=O00<0
]I5M0;>?F`2bSUX0202eSf080;V@HPT0]I5Q0P2fTUh60;NCG`P0]Y1O102eTF470;JBHP80]I5Q0`2f
TV880;NCG`080;RCI`2gTVH0]i9U0;JBHP2eTEl0]I5M0;B@G02dTE/40;>?F`@0/XiJ0`2fTV030;NC
H@80^9AR202hU6@80;NCH`030;>?G`2dT600]91P0080]I5Q0P2fTV80102gTf<0^IEU0;VEI@2iUFD2
0;RDI0/0]i=S00H0/hmO0;B@H02eTF40]Y9R0;NCH`2iUFD20;ZFIP<0^IAW0`2jUFP20;^FJ@P0]i=S
0`2iTf@20;RBH`80]i5R00T0]Y1Q0;FAH@2fTV80^9AT0;VEI@2hU6@0]i=S0;JBHP2eTF400`2hU6@3
0;NCH`<0]Y9R0P2eTEd60;JBGP80]91P0P2eTF420;JBHP80]i=S202hTfH20;RDI0<0]i=S0`2fTV88
0;NCH`040;^EIP2jU6D0^I=T0;VCI080]i5R00<0]Y1Q0;F?H02fTV001`2fTV0:0;B>G`80]HmP00<0
]Y1Q0;NAHP2gTF800P2gTF820;J@H@030;F?H02dSUl0/heN0080/XaM00<0/HaH0;:=F@2bSET00P2b
SET30;>>FPP0/hmK202eTF480;>?G`80/hiR00<0/hiQ0;>?G`2cSed00P2cSe/00`2cT5X0]8iO0;B>
G`060;B>G`80]Y1Q00H0]HmP0;>=GP2bS5d0/H]L0;2:F`2_REX50;>>FP040;B?F`2eT5`0]I1L0;FA
H@<0]91P0P2cSel20;:>GP030;6=G@2gTF80]i5R00@0]i5R0P2fT6401@2dSe/0/hiJ0;>>FP2bSET0
/HaH0080/8]G00@0[hYF0;2<G02aSEd0/hmO0P2eTF400`2dT600/hmO0;:>GP020;B?H`030;>>H@2c
Sel0/hmM0080/XiJ00@0/XmI0;:<G@2bS5d0/XaM102cSEh01P2dSUl0]91P0;>?G`2bSUh0/HeM0;2<
G080/HeM00<0/XiN0;>>FP2cSUX00`2bSET30;6<F0P0]91L0P2cSE`01P2dSUd0]HmP0;B>G`2cSEh0
/H]N0:n9G0<0[h]K00<0/8aL0;6=G@2aSEd00P2bSUh00`2cSel0/XiN0;2<G0020:n;F`060;2<G02a
SEd0/XiN0;6=F@2`S5P0[h]G0P2]RED00`2_ReL0/8aH0;6=F@030;:>G0030;6=F`2`S5X0[h]I0080
[h]I00H0[8YJ0:f;F`2^S5`0[heM0;2>GP2bT6020;>AH@80]I5Q00@0]91P0;>?G`2aSEd0/8aL0P2_
Re/80;:=F@030:j:EP2`S5P0/HeI0080/XiJ00<0/HeI0;2<F02^RUH00`2`S5P20;6=F@<0/XiJ2@2_
Re/00`2^RUH0[HUE0:f9E@020:f9E@80[XYF00<0[h]G0:j:FP2^RUX0102_Re/20;2<G0<0/8aH0P2_
ReL30:j:EP80[8]F00<0[XYF0:n:EP2aREH00P2bR5H00`2cQeH0[HUI0:f9F@0>0:f9F@P0[8QD0P2X
Q5020:V5D@040:Z6DP2[Qe<0ZhMC0:^7D`P0[HUE00P0[8QH0:f9F@2^RUX0[h]K0:j:FP2]RET0ZhMG
0:Z6EP80ZHEA102ZQU820:^7D`H0ZXIB102[Qe<0102ZQU80ZHEA0:V5D@2XQ5020:N3C`080:b6F@2[
QEH0ZXAE0:R2D@2XPdl0ZXE@0:^6C`2/Qe020:Z4E@030:^5EP2/QUL0[8IG00<0[8IG202ZQE420:b6
E`h0ZhEF0P2[QU440:Z5D0<0ZHA?0P2/Qe<0102[QU80ZXEA0:R3C`2WPTh20:J1C@<0ZhIB0P2ZQE43
0:V4D080Z8A:00@0Z8=<0:R3CP2YQ4l0ZHA@0P2YPe820:^5EP060:Z4D`2YQ500ZHA?0:R3CP2WPT/0
Yh=90P2YQ5020:R3C`80Yh9>0P2VPDd30:F0C080YX5=00<0Z8=?0:V4D02YQ5001@2TOdX00`2UP4/0
YX5<0:J1C0030:V4D0@0Z8=?00T0Yh9>0:R3CP2UP4/0XWe80:=nB@2WPTd0Z8=>0:F0B`2RODP0102R
O4/30:9mB@030:9mB02SOTX0XWe90080XGa800L0XWe90:AoB`2VPDd0Z8=?0:=oC`2ROTh0XGe=0080
X7a<00<0XGe=0:=oC`2TP500202UP4`80:N1DP060:F0D`2UPE40YH5A0:B0CP2TP4`0Xh1:0P2SP4P8
0:F0B`80YH1<00<0Y7m;0:=nBP2RODT00P2QO4P0102PNdL0Xgm=0:=oC@2SOdd20:B0CP<0YH5?2@2T
PD/20:=nB@040:AoBP2UP4/0YH1;0:J1C080Yh9=00@0Xgi:0:9mB@2RODT0XGa8102PNdL00`2LN4P0
WWY:0:1lC0030:9nCP80XGe=0P2RODP20:5lA`040:1kAP2ONTD0WgY509mjA@<0X7]700<0XGa80:1k
A`2PNdL00P2ONTH00`2LN4@0WWY609mkA`020:1lB00309ijAP2LN4@0VgM30080VGE100@0VWI209ah
A02MNDD0Wg]70P2PO4P00`2ONd/0X7a<0:5mC@020:5mC@0309mkB`2MNDT0W7Q80080WgY60P2NNDD2
09ehA080W7M30P2KMT4309ag@P<0WGQ300H0Y7m:0:=nB@2RODP0XGa70:1kAP2NND@209eh@`0609mj
AP2NNDD0WWU509ehA02LMd<0VgI20P2JMD401P2HLdH0V7A409QdA02HM480V7A009Qe?`80V7Dm1P2K
MT8209ag@`80VG9700H0VG=609YdA@2KMD@0W7M309]f@P2JMD0809Ue@@0609Ye@02JMD40VWE109Yd
@`2JM4D0VWA70P2JLdP309Qb@`<0Ug520P2FL4401P2EL4H0UG1409E`A02DKd80Tflo09=_?@<0TVhj
00<0TVhn09A`@02ELD400P2GLd<0102FLT80UG5109A`@02DL3`209Ea?@0;09Ib?P2GLcl0V7A009Qd
@02IMD40V7A409Mc@`2FLT80UG5109A`@02BKSh00`2AKCd03`2BKSh0Tflo09A`@02ELD40UW9209Mc
@`2HM4@0U6m2099]@02@Jch0SVTl08eX>`2>JC`0SfXm091[?P0308aZ?0D0SF/m0P2CKT401P2BKD00
T6/n08mZ?@2>JC`0SFPk08aW>P80TF`o0P2@Jch208mZ?@80SVTl00<0RVPj08]Y>`2=Jcd00P2>K3h0
0`2=Jcd0RfTk08YX>P0308MU=b_ooooo000Zooooo`P0TfPk0P2CJ3d309AY?P<0UFXo202BK3d309=X
>`<0U6Tl0P2EJSd00`2FJch0UFXm099W>P02095V>@0309=X>`2FJch0V6e000P0UFXm0P2HJCl00`2F
JCl0UFXo09A[?`02099/?`0<095/?`2CJ3d0TfPm09AY?P2EJSl0Ufa109Q]@P2JKd@0Vg1509Y^@@2I
KD00UVXm0P2EJC`00`2FJSd0VFe009Y^@@0309I/>P<0Ufdk0`2FK3X02@2JLSh0VW8o09Ua?P2GKch0
UVdo09E/@02DJT00TfTo09E[>@0209I/>P0309M]>`2HKS`0VFlm0080VW0n0P2KLCl609Y`?PP0WG50
1P2KLCl209ab@080W7M30P2KMT80102JMD40VGA009Qc?`2GLSh809iiA@0809ec@@2PMT@0XWQ60:1f
A02LLT00VW0n09]a?`2NM48809me@`P0XGE4202QMdD00`2PMd<0XGQ40:5hA0040:5hA0030:1g@`2R
NDD0XWU50080XGQ40P2PMd<209mf@P<0XGM50`2RN4H20:=iA`080:IlBP2UNdT0Y7Y80:=iA`2QMdD0
X7I409me@`2NM4880:=iA`030:AjB02SNDL0XWQ60080XGM500H0XgU70:EkB@2VO4X0Yge;0:IlBP2U
NdT20:AjB0080:EkB@2VO4X0Yge;0:MnB02VODL0YGa80:AjB02TNTX20:EjC@030:IkCP2WO540Yge;
00L0Yge;00<0Y7Y80:EkB@2XOT`00P2YOdd00`2XOT`0YG]90:AjB0020:F0B`<0Y7m:0`2SOTT80:F0
B`P0Xgi:00<0ZHA@0:N2CP2TOd/00P2QO4P00`2SOTX0YX5=0:R3C`020:EoCP040:J1C@2VPD`0YX5<
0:N2B`80Yh=9202ZP4h30:R3C`<0Yh9>0P2VPDd20:R2D@040:R3C`2YQ4l0ZHA?0:V4C@80ZXI<0`2]
Q5000`2/Pdl0[HA@0:f4D0020:j5D@P0ZXE@202/Pdl30:V4C`<0ZXE@0P2[QU480:V4C`P0[HA@0P2Y
Q5040:Z5D@80ZhIB0P2/Qe<?0:^6DPP0[8MB202[QU880:b6E`<0[8MC0`2]R5@20:j9E@P0[HQC202[
QU430:f8E080[XUE0`2_RUH0202[RE/0ZhUI0:f9F@2^R5L0/8QE0;68E02aR580/XMB0P2_RUD30:j9
E0<0[HQC202/Qe<50:f8E080[8MC00@0ZhIB0:b7D`2/Qe<0[HQD0P2^RED00`2_RUH0/8]G0;2;E`08
0:f8E0P0[8MB202]R5@30:j9E@80[HQD0`2/Qe<0102WPe40Z8AB0:R4DP2XQ5820:V5D`80ZXID0`2/
Qe830:f8D`80[XUD2@2^RUH30:f9E@80[8QD0`2[Qe<30:j6D`<0[hMD0P2`R5D01P2_RE`0[hUJ0:n9
FP2^R5L0[XUE0:f8D`80[HQA00<0[8MC0:f8E02]R5@00P2^RED20:n:EP030;2;E`2^RUX0[XYJ00H0
[XYJ202aSET80;>>FP<0/XeI0P2cSUX30;B?F`80]91L00@0]I5M0;JBGP2gTel0^9AP0P2iUF401@2h
Tel0]i9N0;NBGP2fTEd0]I1L0080]8mK00<0/hiJ0;B?FP2dSeX01P2dSeX80;N=F`<0]8iO0P2cSEh3
0;:<G@080;>=H02cSEh0]8iO0;B>G@2eT5`0]I1K0;F@F@2fTEX30;JAG@<0]i9N0P2hTel00`2hTV<0
]i5R0;J@H@020;B>G`0;0;J@H@2gTF80^99S0;FAG@2fTUh0]i=O0;RDH02gTel0]Y9N0;B@G02cSe/0
202eSf080;NAHPT0]I5Q1P2gTel20;JBGPP0]i9N102fTV870;FAH@80]Y9R0`2eTF440;JBGP@0]i=O
0P2hTfL01P2gTVD0]Y9R0;FAG`2dT5`0/hmK0;:?F@@0/XiJ102cSe/30;JBHP<0]i=S2P2hU6@80;NC
H`80]91P102eTF420;JBHP<0^IES0P2hU6830;NCH@P0]i=S00H0/hmO0;B@H02eTF40]Y9R0;NCH`2i
UFD20;ZFIP<0^IAW0`2jUFP20;^FJ@P0]i=S0P2iTf@20;RBH`@0]i5R00P0]I5Q0;JBHP2gTf<0^9AT
0;VEI@2hU6@0]Y9R0;FAH@<0^9AT0`2gTf<30;JBHP80]Y9N1P2eTEd20;B@H080]I5Q0P2fTV820;NC
H`P0^9=V0P2hU6@30;NCH`<0]Y9R202gTf<30;VCI0030;RBH`2gTF80]Y1Q0080]Y1Q202fTUh80;B>
G`<0]HmP102fT6401P2gTF80]Y1Q0;J@H@2eSf00]8iO0;>=GP80/XaM00D0/H]L0;6<F02aS5P0/HaH
0;:=F@020;>>FP80]8mK202cSe/80;B@H0P0/hmO0P2cSV800`2cSV40/hmO0;>?G@020;>?F`030;>@
FP2dSUl0]8iO00H0]8iO0P2fT6401P2eSf00/heN0;:<G@2aRe`0/8YK0:n9FP80/XeI00<0/hiJ0;B?
F`2dSe/00`2dSe/20;B@H0D0/hmO0P2bSUh50;NAHP<0^99S00D0]8mK0;>>FP2cSUX0/XeI0;6<F002
0;2;E`040:n:EP2`S5`0/HeM0;>?G`80]I5Q00<0]91P0;>?G`2bSUh00P2dSf<01P2dSf80/hmO0;>?
G@2cSe/0/XiJ0;:?F@80/H]L0P2bS5d0302cSEh0]8iO0;B>G`2dSUl0]I5O0;B@GP2bSU`0/8aJ0:n;
F@2`S5X0/XiL0;>?G@<0/XeI0`2aS5P20;2;E`P0/hmK00P0/XaO0;>=H02dSUl0]HmP0;B>G`2cSE`0
/H]J0;2:F@<0/8aL102aSEd20;:>GP0:0;6=G@2_Re/0[XYJ0:n;F`2`S5`0/HeM0;:>GP2aSET0/8aH
0:n;E`80[HUE00<0[h]G0;2<F02aSET00P2cSel0102bSUh0/HeM0;2<G02_Re/20:j:FP060:b:FP2]
Re/0[XaL0:n=G@2`SUh0/Y1P0P2cTF40202eTF40]91P0;>?G`2bSUh0/HeM0;2<G02_Re/0[XYJ202b
SET00`2_ReL0/8aH0;6=F@020;>?F`030;6=F@2`S5P0[h]G00<0/8aH0P2aSET30;:>FPD0[XYJ102_
Re/0102/R5@0[HUE0:j:EP2^RUH40:n;E`80[XYJ0P2_Re/20;2<G080/HeM0P2aSET20;2<F080[h]G
0P2^RUH20:b;EP030:j:EP2_RUH0/HUF0080/XQF00<0/hMF0:f9F@2]RET00P2]RET60:b8F0@0[HUI
0P2/R5P80:^7D`<0ZHEA102ZQU800`2[Qe<0[HUE0:f9E@060:f9E@80[HUI00H0[XYJ0:n;F`2^RUX0
[HUI0:^7E`2YQED20:V5D@80ZXIB0P2[Qe<20:b8E080ZhMC1P2ZQU820:^7D`040:Z6DP2YQE40ZHEA
0:R4D080Yh=?00P0[8II0:Z4E@2YPe@0Z89A0:R3C`2YQ4l0ZXE>0:b7D0@0ZXAE0P2[QEH20:b6E`P0
ZXEA1P2[QEH60:b6E`@0ZhEF0`2[QU440:Z5D080ZHA?00P0[8MC0:^6DP2ZQE40ZHA@0:R3C`2WPTh0
YX5=0:F0C0<0ZhIB0P2ZQE430:V4D080ZHE;00@0ZHA=0:V4C`2YQ4l0ZHA@0P2YPe801@2[QEP0ZXAG
0:Z4E@2YPe80Z8=?0080Yh9=00<0YX5:0:V4D02YQ5000P2XPdl20:N2CP80YX5=00@0Xgi:0:AoB`2U
P4`0YX5=0P2WPTh20:R3C`040:=nB@2TOdX0YH1;0:F0B`@0YX5<0`2YQ5000`2XPdl0Yh9>0:N2CP02
0:J1C@090:N2C@2TOdX0XWe80:=nB@2WPTd0Z8=>0:J1C02SOTT0XGa700<0XGa8102QNdX20:=nBP80
XWe900L0Xgi:0:F0C02WPTh0Z8=?0:B0D02SOdl0XGe=0080X7a<00<0XGe=0:9nCP2SOdl0202UP4`8
0:J0D@060:F0D`2UPE40YH5A0:B0CP2TP4`0Xh1:0P2SP4P80:F0B`060:F0C02TOd/0Y7m;0:=nBP2R
ODT0XGa80P2PNdL30:=oB`80Y81<0`2UPDd90:B1B`80Xgi900@0Y7m:0:F0B`2UP4/0YX5<0P2WPTd5
0:9mB@060:5lB02PNdL0X7]709ahB02NNTX0X7a<0`2ROTh20:5mC@030:5lA`2PNdH0X7]60080X7]6
0`2ONTD30:1kA`0309mjAP2PNdL0X7]70080XGa800<0WWY609mkA`2ONdL00P2ONdL04`2MNDD0W7Q4
09]g@`2IMD40VWI209]g@`2LN4@0WGU509ijAP2ONdL0X7a809ijBP2ONd/0X7a<0:5mC@2PO4`0Wg];
09eiB@2LN4P0102NNDD409ehA080VgI10`2LMd8309eh@`80Xgi900L0XWe80:1kAP2ONTD0WWU409eh
@`2LMd80WgY60080WWU500<0WGQ409ag@`2KMT800P2JMD401P2HLdH0V7A409QdA02HM480V7A009Qe
?`80V7Dm1P2KMT8209Ye@@0809QaAP2ILTL0VG=609UcA02ILd80VGA009]f@P2LMd8809Ue@@0609Ye
@02JMD40VWE109Yd@`2ILd@0VG=60P2ILTL309Qb@`<0Ug520P2FL4401P2EL4@0U6m209A_@P2DL400
U70n09=_>`<0Tg0j00@0TVhn09=_?`2ELD40UW920P2GLd<01@2FLT80UG5109A`?02DL3`0UG4m0080
UW8n00T0Ug<o09Qd@02HM400Ug=309Ib@P2ELD40U71009=_?`2AKCd00P2@K3`2095]?@0:099^?P2C
Kcl0UG5109Ib@P2GLd<0V7A409A_@P2CKT40TF`o08mZ?@80SVTl0P2?JSd508aZ?0<0RfTk00H0U6m2
09=^@@2BKD00TF`o091[?P2>JC`208eX>`<0T6/o0`2?JSh208iY?@0308YX>P2<JS`0SF/m0080SV`n
00<0SF/m08aZ?02:J3X00`27ICL[ooooo`00:_ooool809=X>`H0UFXo0P2DJCh8099/?@80TVLl0P2C
J3d309AY?P0309EZ?`2EJSd0U6Tl00<0TfPk00<0U6Tl09EZ?@2EJSd0202EJSd209QY?`0309IY?`2E
JSl0U6/o0080TV`o00`0TF`o09EZ?`2DJCh0U6Tn09EZ?`2FJd00V6e209Y_A02KL4D0VFe009Q/?`2G
Jch209IZ?@0309M[?P2HK3l0VFe00080UF/i00D0UV`j09M]>`2GKC/0Ufdk09I/>P0209E[>@0609Ya
?@2JL3h0VFlm09Q^?P2GK3l0Ufa10P2FJd401P2EJcT0UV`j09I/>P2GKC/0V6hl09U_?@80VW0n0`2K
LCl309Y`?P80VFlm0`2MLD0209a`?`<0Vfln0`2JL3h309]a?`80W79000<0VWE109]f@P2LMd<00P2L
Md<00`2JMD40VGA009Qc?`0809ag@`0809ab@02PMT@0XWQ60:5gA@2MLd40W79009me@`2RN4H809me
@`P0XGE4202QMdD00`2PMd<0XGQ40:9iA@030:9iA@030:5hA02PMd<0XgY60080XWU500D0XGQ40:1g
@`2OMT80WgI209ie@@030:9fA@<0XgM60P2TN4L0202VO4X0YG]90:AjB02SNDL0XWQ60:5gA@2PMT@0
WgE3202RNDD00`2TNTP0XgU70:9hAP020:5gA@060:=iA`2UNdT0YWa:0:MnBP2VODT0YGa80P2TNdL0
0`2UO4P0YWe90:MnBP020:ElAP030:ElB02TNTP0Y7Y:00<0YGY=00<0YGY?0:IlBP2VO4X01P2VO4X0
0`2UNdT0YWa:0:MmB`030:MmB`040:IlBP2UNdT0YH1;0:F0B`<0Y7m:0`2SOTT80:AoBPP0Y7m;00<0
Z8=?0:J1C@2TOd/00P2RODT00`2SOTX0Y7m;0:J1C@020:EoCP040:J1C@2VPD`0YX5<0:N2B`80Yh=9
202ZP4h30:R3C`80Yh9>0`2VPDd20:R2D@040:R3C`2YQ4l0ZHA?0:V4C@80ZXI<0P2]Q5030:b3C`03
0:f4D02^QE40[hIB00P0ZXE@202/Pdl20:R3CP80ZHA?0`2ZQE000`2[QU40ZHA?0:V4C`060:V4C`P0
[8=?202ZQE430:b7D`<0ZhIB0P2ZQE400`2/Qe<0ZhIB0:Z5D@020:V4D0040:Z5D@2[QU80ZhIB0:b7
D`P0[8MB202[QU880:b6E`<0[8MC0P2]R5@30:j9E@P0[HQC202[QU420:f8E080[XUE0`2_RUH02@2`
ReL0ZhUK0:^9F@2]RET0[XQG0;28E@2aR5@0/HQB0;:7DP020:n:E@<0[XUD0`2]R5<90:b7D`030:f8
E02^RED0[XUE0080[XUE00<0[HQD0:b7D`2]R5@00`2^RED40:n:EPP0[XUE202/Qe<80:j9E@<0[HQD
0P2/Qe<30:^6DP<0ZHEE0P2ZQUH30:^7E`<0[8MB0P2]R5<30:j9E0T0[h]G0`2^RUH20:f9E@<0[8QD
0`2_QE<20;26E0<0/HME00H0/8YM0:n9FP2_REX0[hUH0:j9E@2^RE@20:f8D@80[8MC00<0[HQD0:j9
E@2_RUH00P2`ReL00`2aS5P0[XYJ0:j:FP060:j:FPP0/XiJ202cSUX20;:=F080/hiI0`2dSeX01P2e
T5/0]95K0;BAF`2eTU`0]Y=M0;NDGP80^9EO00<0^IIP0;NBGP2gTUh00`2fTEd30;F@G0P0]I1K202g
SE/0102eSf00]8iO0;B>G`2dSUl20;>=GP80/XaM00P0]8iQ0;B>G`2eSf00]HmN0;JAG@2fTE`0]Y5J
0;NBF`<0]Y5M0P2gTUh30;RCG`030;RBH`2gTF80]HmP0080]8iO00<0]HmP0;NAHP2hTV<00P2fTUh3
0;RDH0030;JBGP2dT5`0/hmK00P0]HmP4@2fTV820;RDH0<0]i=O0`2fTUh80;NBG@040;NCH`2fTV80
]Y9R0;JBHP<0]I5Q0`2dT600102eTF40]Y9R0;JBHP2eTF420;B@H0<0]I5M0P2fTUh30;NCG`80^9=W
00L0]i9U0;JBHP2dT5h0/hmK0;:>FP2aSUP0/XiJ00<0/hmK0`2dT5`0102eTEd0]Y5T0;JAI02fTF@3
0;NBI@80^9=V202hU6@80;NCH`P0]Y9R0`2iUF420;RDH0<0]i=O202gTf<20;FAH@80]Y9R00@0]i=S
0;RDI02iUFD0^IEU0`2hTfH30;VDI`80^YEX202fTV801@2jU6D0^I=T0;RBH`2gTF80]Y1Q0080]i5R
00T0^99S0;B@H02eTF40]i=S0;RDI02iUFD0^9AT0;NCH`2fTV800`2hU6@30;NCH`<0]Y9R0P2fTUh3
0;FAG@<0]91L0P2dT6020;FAH@80]Y9R0P2gTf<80;RCIP80^9AT0`2gTf<30;JBHPP0]i=S202gTF88
0;JCG@P0/heN202eSf040;B>G`<0/heN00H0/XaM0;6<F02aS5P0/XeI0;>>FP2dSe/20;F@G0030;JA
G@2dT5`0]91L00H0]91L202dT6080;>?G`80/hiR00<0/hiQ0;>?G`2cSed00P2cSe/00`2cT5X0/heN
0;>=GP060;>=GP80]HmP00@0]8iO0;>=GP2bS5d0/XaM0P2aRe`00`2bSET0/hiJ0;B?F`030;JAG@03
0;F@G02dSe/0/hmO00P0/hmO102fT6420;NAHP80^99S102bSET40;6<F0030;2<G02aSEd0/hmO0080
]I5Q00<0]91P0;>?G`2bSUh00P2eT6@00`2dSf80]91P0;>?G@020;>?F`070;:?F@2`RU/0/H]L0;6;
G02bS5d0/heN0;B>G`020;F?H0080;JBGP2dT5`0/HeI0:n;E`2^RUH0/8aH0;:>FP2dT5`30;:=F@80
/HaH0`2`ReL80;:>FP080;6:G`2bRf00]8iQ0;F?H02eSeh0/hiJ0;:=F@2aS5L90;6=G@0:0;2<G02^
RUX0[XYJ0:j:FP2`S5`0/HeM0;>?G`2aSET0/8aH0:n;E`80[HUE00@0[h]G0;2<F02aSET0/hiQ0P2b
SF001@2aS5l0/8]N0:n:G@2_RUd0[XUL0080[XaL0P2_SEd0102`SUh0/HmO0;:@H02bT6020;>?G`04
0;:>GP2aSEd0/HeM0;2<G080[h]K202bSET00`2_ReL0/8aH0;:>FP020;>?F`030;:>FP2`S5P0[h]G
00<0[h]G0P2`S5P30;6=F@<0[XYJ0`2_Re/30;2<G080[HUE00H0[h]G0;2<F02`S5P0/8aH0:n;E`2^
RUH20:j:FP80[h]K00@0/8aL0;6=G@2bSUh0/XiN0`2aSET20;2<F0<0[h]G0P2/ReH00`2^RUH0[hYF
0;69EP020;:8EP040;>7EP2]RET0[HUI0:f9F@80[8QH102[QeL00`2/R5P0[HUI0:f9F@020:f9F@03
0:b8F02[QeL0ZhMC00l0ZhMC202]RED0202]RET0[XYJ0:n;F`2_Re/0[XYJ0:b8F02ZQUH0ZHEE0`2Z
QU830:^7D`80[8QD0`2[Qe<30:Z6DP80ZHEA0`2ZQU820:V5D@<0Z8A@00/0ZhEH0:Z4E@2YPe@0Z89A
0:R3C`2YQ4l0ZXE>0:^6C`2/QUL0ZhEF0:Z4E@020:V3E0030:Z4E@2[QEH0[8IG00P0ZXEA0P2ZQ5D3
0:^5EP<0[8IG0`2]QeP20:b6E`<0ZhEF0P2/Qe820:^6D@@0ZXE@00@0ZHA?0:Z5D@2ZQE40ZHA@0P2X
Pdl00`2WPTh0YX5=0:J1C@030:^6DP80ZXEA0`2YQ500202[Qdd0ZXI<0:Z5CP2ZQE00ZHA?0:V4D02Y
Pe80Z89A0P2YPUL01P2YPeH0Z89C0:R2D@2XPdl0Yh9>0:N2C@80ZHA@0P2XPdl20:N2CP80YX5=00<0
Xgi:0:AoB`2VPDd00`2WPTh0202VPDd0YH1<0:9mB02SOTT0YH1;0:J1C02WPTd0Z8=>0P2WPTd01P2Y
Q500Z8=?0:R3C`2WPTh0YX5=0:F0C080Y7m;00P0Yh9=0:=nB@2QO4L0Xgi90:N2C@2YQ4l0Yh9=0:=n
B@80XGa500@0XGa70:5lB02QNdX0XG]<0P2QNdh40:=nBP0<0:AoB`2VPDd0Yh9>0:N2CP2TP500Xgm?
0:5mC@2PO4`0Wg];0:1lC02QODd0XWi>202TOd/80:J0D@060:F0D`2UPE40YH5A0:B0CP2TP4`0Xh1:
0P2SP4P80:J1C080Xgi:0`2RODT30:5lB0<0Y7m:0P2UP4/30:J1C0<0YH9:0P2TPDT40:>0B0<0Y7m:
0P2UP4/30:J1C080XWe90`2SOTX01P2RODT0X7]709mjAP2NN4T0X7Y;0:5kC0<0Xge>00<0XG]<0:1j
B`2ONTD01`2ONTD20:1kA`<0WgY600@0X7]70:5lB02RODT0X7a80`2ONdL00`2NNTH0WGU509ahA002
09]g@`<0W7Q40`2MNDD00`2NNTH0WWY:09mkB`030:1lC00309ijBP2MNDT0VgM700@0WWU5102MN4@2
09]f@@<0W7M20`2MN4<30:5lA`030:1kAP2ONTD0WWU40080WGQ300H0WgY609iiA@2NNDD0WGQ409ag
@`2KMT8209Ye@@0609UdA`2IMDD0VGE509Ue@`2IMD40VGI00P2IMSh409]f@P80VWE10P2IM400202G
L4D0VG9709YdA`2ILd@0Ug5009Mb?P2JMD40WGQ3202IMD401P2JMD00VWE109Ye@@2ILd80VG=409Qb
A@80V7560`2HLT<309Ma@P80UW1100H0U6m209A`@02DL400U70n09A`?02DLC/309Aa>@04095]?@2B
KSh0U71009Ib@P80Ug=30P2FLT8409Ea?@<0UW8n00H0Ug<o09Ea@@2DL400U71009=_?`2BKSh2095]
?@80T6`l0P2AKCd01@2BKSh0Tflo09A`@02DL400UG510080Tfi100<0TVe0095/?`2@Jch00`2?JSd2
08e[?@<0S6Xl0`2;JC/209=^@@03099]@02AK3l0T6/n00<0SfXm1@2>JCl308eX?P0308YX>P2;JC/0
S6Xl0080SF/m00<0S6Xl08]Y>`2:J3X00`29IcT[ooooo`00:_ooool809AY?080Ufa100@0UV]009EZ
?`2EJSl0U6Tn0P2CJ3d8099/?@<0TVLm0P2CJ3h309AY?`0309=X>`2DJC`0UFXm0080UFXm00<0U6Tl
09=X>`2BIcX0202DJC`209QY?`0309IY?`2EJSl0U6/o0080TV`o00`0TF`o09M/@@2FJd00UFXo09AY
?P2EJSl0Ufa109U^@`2JKd@0UVXm09M[?P2HK3l209U]@00609Q/?`2GJch0UVXm09AZ>02EJcT0UV`j
0`2GKC/0102FK3X0UF/i09AZ>02HKc/209Q^?00609Q^?P2HKD00V6e209Q]@`2GK480UF/i0P2FK3X0
0`2GKC/0V6hl09U_?@0209Y`?P80W7900P2KLCl0102JL3h0VFlm09U_?@2IKcd209a`?`80Vfln0P2J
KSd209U]?080VFlm0P2JL3h209]a?`80W79000<0V7<o09Ud@02KMT800P2MN4@00`2LMd<0VgI209Ye
@@0809Ye@@0809ab@02OMD<0XgU70:9hAP2PMT@0WgE30:=iA`2VO4X809me@`P0XGE4202QMdD00`2P
Md<0XGQ40:9iA@020:=jAP030:9iA@2QN4@0X7M30080XgY600@0XWU50:5hA02PMd<0WgI20P2NMD43
0:AfA@<0YGM60P2VN4L0102UNdT0Y7Y80:AjB02SNDL20:9hAP80XGM5202RND<00`2TNTP0XgU70:9h
AP020:5gA@060:=iA`2UNdT0YWa:0:MnB02VODL0YGa60P2TNdD00`2UO4H0YWe70:MnB0020:AkA@03
0:ElB02UNdT0YG];0080YGY=00<0Y7U<0:AiCP2VO4X01`2VO4X00`2WOD/0YWa:0:EkB@020:AjB003
0:EkB@2VO4X0Yge;0080YH1;0`2TOdX30:=nB@P0Y7m:202UP4`20:J1C@030:F0C02TOd/0Xgi:00<0
Xgi:0P2UOdh0102VPDd0YX5<0:J1C02WPT/20:N3B@P0ZGm=00@0Z8=?0:N2CP2WPTh0Yh9>0P2VPDd2
0:F0C080Z89A00@0Z8=?0:V4C`2YQ4l0ZHA=0P2ZQT`00`2]Q500[8=?0:^2CP020:^2CP030:f4D02_
QU80/HQD00P0ZXE@202/Pdl30:R3CP80ZHA?0`2ZQE080:V4C`P0[8=?202ZQE420:f8E080[8MC00L0
ZhIB0:Z5D@2ZQE40ZXEA0:b7D`2[QU80ZHA@0080Z8=?00@0ZHA@0:^6DP2[QU80[8MC202[QU480:Z5
D@P0ZhEF00@0[8MC0:f8E02]R5@0[HQD0P2^RED20:n:EPP0[HQC202[QU430:j9E@<0[hYF0P2`ReL0
202/RU`0[8YJ0:j:FP2_REP0/HUF0;:9E@2bRE<0/hQC0P2_RUD30:j9E0<0[HQC202/Qe<0202[QU80
[8MC0:j9E@2_RUH0/8]G0:n:EP2]R5@0[8MC0P2`ReL30:n:EP<0[XUE202_RUH80:b6E@P0[hYF0P2/
Qe<20:^6DP80ZXEA0P2YQ5030:^7E`80[8QH0`2]RET0102/Qe80[HQC0:f8D`2]R5<20:j9E080[hYE
2@2`S5P20:n;E`80[XYF0`2]RED00`2/R5@0[hEC0;26E0020;26E080/HME0P2bR5H01P2`RUd0/8YK
0:n9FP2_REP0[hYF0:j9E080[XUB0P2/Qe<01P2]R5@0[XUE0:n:EP2`ReL0/HaH0;:=F@P0[XYJ202c
Se/80;B?F`<0/hiG0`2dSeP20;F@F@060;>@F02dTET0]95I0;FBFP2fTe/0]iAL0P2hUEd20;F@G0<0
]Y5M0`2gTUh80;F@F`P0]heK0P2eSf030;B>G`<0/heN00H0]HmR0;F?H02eSf00]Y1O0;JAG@2gTUd2
0;NBF`040;JAG@2gTUh0]i9N0;NBGP80^9=O0P2iU6000`2gTF80]Y1Q0;F?H0020;B>G`0;0;F?H02f
T640]i5R0;JBGP2gTel0^9AP0;VEH@2hU600]i=O0;FAG@2dT5`0202eSf080;BBHPT0^9AT0`2hU600
0`2gTel0]Y9N0;JBGP020;FAG@P0^9=L0P2gTf<20;JBHP80]I5Q0P2dT6000`2cSel0]91P0;FAH@02
0;JBHP030;FAH@2dT600/hmO0080]91L0P2eTEd03@2fTUh0]i=O0;NCG`2gTel0^IAX0;RCI`2gTVD0
]I5Q0;B@GP2bSUX0/HeI0;2=E`2cSe/00P2dT5`20;FAG@80]Y9N00@0]i=O0;JAI@2fTFD0]Y5U0`2g
TVH20;RCI`P0^9AT202gTf<40;RDI0@0]i=S0`2iUF420;RDH0<0]i=O202gTf<00`2fTV80]i=S0;NC
H`050;NCH`80]Y5T0`2gTVD30;RCIPP0]Y9R00<0^iEV0;ZDI@2hTV<00`2fT6420;RBH`060;>?G`2e
TF40]i=S0;RDI02iUFD0^9AT0P2gTf<30;RDI0<0]i=S0`2fTV820;JBGP80]I5M0P2dT5`20;>?F`80
]91P0P2eTF420;JBHP80]i=S202hTfH20;RDI0<0]i=S0`2fTV880;NCH`060;B>G`2eSf00]HmP0;J@
H@2gTF80^99S0P2iTf@80;JCF`P0/heN0P2dSUl60;>=GP<0/XaM0P2cSEh30;B>G`80/XeI00H0/hiJ
0;B?F`2eT5`0]Y5M0;NBGP2hTel80;B@G100/hmO0P2cSV800`2cSV40/hmO0;>?G@020;>?F`030;>@
FP2cSEh0/heN00d0/heN00@0/XaM0;>>FP2dSe/0]Y5M0P2hTel00`2gTUh0]Y5M0;F@G0090;>?G`80
]8iO0P2eSf020;J@H@80]i5R102aS5P40;:=F@030;2<G02aSEd0/hmO0080]I5Q00<0]91P0;>?G`2b
SUh00P2eT6@00`2eT6<0]91P0;B@GP020;>?F`0<0;>@FP2`RU/0/8YK0;6;G02bS5d0/heN0;B>G`2e
Sf00]Y1Q0;NCG`2dT5`0/HeI0P2^RUH0102`S5P0/XiJ0;B@G02bSET30;6<F080/8]G0P2_RUH80;2<
F0080;6:H`2bRf80/haQ0;B>H@2eSeh0]8mK0;:=EP2aS5D40;:>GP@0/HeM00/0/8aL0:n;F`2^RUX0
[HUI0:j:FP2`S5`0/XiN0;>?G`2aSET0/8aH0:n;E`020:f9E@030:n;E`2`S5P0/HeI00@0/HaP102`
Rel00`2_SEd0/8iN0;2>GP050;2>GPH0/HeM0P2`S5`80;:=F@030;2<F02aSET0/XiJ0080/hmK00<0
/XiJ0;6=F@2`S5P00P2]RED20:j:EP80[h]G0P2`S5P30:n;F`80/8aL0P2aSEd20;:>GP030:j:EP2_
ReL0/8aH0080/HeI00T0/8aH0:j:EP2]RED0[HUI0:j:FP2_Re/0/8aL0;6=G@2bSUh00P2cSel40;6=
F@80/8aH0P2_ReL20:b;EP030:j:EP2_RUH0/HUF0080/XQF00D0/hMF0:f9F@2]RET0[HUI0:b8F002
0:^7E`<0ZXIF00L0ZhMG0:f9F@2^RUX0[XYJ0:f9F@2[QeL0ZXIF00P0ZXIB0P2]RED60:b8E0P0[HUE
0P2^RUX20:n;F`040:j:FP2/R5P0ZXIF0:R4E0<0[8QD1@2[Qe<20:b8E080ZhMC00@0ZXIB0:V5D@2Y
QE40ZHEA0`2XQ5020:V5D@<0ZXIB00`0ZhEH0:Z4E@2XPU<0Yh5@0:N2CP2XPdh0ZXE>0:^6C`2^R5T0
[HMH0:^5EP2YPe@20:R2D`030:V3E02ZQ5D0ZXEA00L0ZXEA0`2ZQ5D00`2[QEH0[8IG0:b6E`020:f7
F080[XQI0P2]QeP0102/QUL0ZhEF0:^5EP2[QEH30:b7DP<0ZhIA0`2ZQE060:R3C`80Yh9>0`2[QU82
0:Z5D@<0ZHA@0P2[Qdd0102[QTl0ZXE@0:V4C`2YQ5020:R2D@060:N0E`2WP5D0Yh1E0:R2E@2XPU<0
Z89A102YQ5020:R3C`80Yh9>0P2VPDd00`2TOd/0YH1<0:N2CP020:N2CP080:F0C02TOd/0XWe90:5l
A`2SOTT0YH1;0:N2C@2YQ4l20:R3CP070:N2C@2WPTh0Yh9>0:J1C@2UP4`0Y7m;0:=nBP020:9mB@08
0:J1C02SOTT0XGa70:=nB@2WPTd0ZHA?0:N2C@2TOdX20:1l@P040:1kA02PNdL0X7Y90:1jC@80X7U>
00H0XWe90:=nBP2SOTX0Y7m;0:F0C02VPDd20:N2CP080:F1D@2TP500XWi>0:1lC02ONd/0X7a<0:5m
C@2ROTh80:AoB`P0YGm@00H0YH1C0:F1D@2UPE40Y81>0:B0C02SP4X20:>0B0P0YX5<102QO4P40:9m
B@<0YWm80P2WP4T30:R1BP030:J3B@2UPTP0YH980080Y8570`2SP4H0102ROdD0YX5<0:J1C02VPD`2
0:F0B`<0Y7m:00<0XWe90:=nBP2TOd/00P2TOd/01@2RODT0X7]709mjAP2RND/0XgY<00<0YGa>00<0
XgY<0:9iB`2PMdT0202ONTD00`2PNdL0WgY609iiA@0209iiA@090:1kA`2RODT0Y7m;0:5mB@2PO4P0
Wg]709ijAP2MNDD0W7Q40080VgM30P2NNTH209eiA@80W7Q40P2KMd<00`2MNDT0WWY:09mkB`020:1l
C00309ijBP2LN4P0VgM700@0WGQ4102NNDD209]f@@<0W7M20`2MN4<809mjA@0609mjAP2NNDD0WWU5
09ehA02LMd<0VgI20P2JMD401P2JMDP0VWI609YfAP2JMT@0VWI209Yg@@80VWLo00<0W7M309]f@P2K
MT800P2JMD4209Ud@00909Qc?`2FKd@0VG9709]eB02ILd@0UFln09E`?02JMD40WgY500P0VGE100H0
VWE009Ye@@2JMD40VG=209Qb@`2HLTD209M`A@<0V7930`2GLD8209I`@@80Tflo00<0U70n09A`?02D
LC/00`2DLCT01@2DLCL0T6`l099^?P2DL400UW9200<0Ug=300@0UW9209Ib?P2FLSh0UW8n0`2ELCd2
09A`?0H0TVhn0P2AKCd2091/?0H0TFdm0P2BKD04095/?`80T6/n0`2>K3h00`2=Jcd0S6Xl08aZ?002
08]Y>`P0TF`o0`2;IS`508aW?@0308UW>@2:J3X0RfTk0080S6Xl00<0RfTk08YX>P29IcT00`2;JC/[
ooooo`00:_ooool809AY?00609U^@`2HKD80Ufa109I[@02EJSl0TfPm0P2BIc`8099/?@<0TVLm0`2C
J3h209AY?`03099W>P2CJ3/0UV/n0080Uf`o00<0UFXm099W>P2@ICP0202DJC`209QY?`0309IY?`2E
JSl0U6/o0080TV`o00@0TF`o09Q]@P2GK440UFXo0P2DJCh01P2FJd00V6e209Y_A02EJC`0UVXm09U]
@080VVi100H0VFe009IZ?@2EJC`0TfTg09AZ>02FK3X309Q^?00409I/>P2DJSP0TfTg09Q]>P80V6`k
00<0VFdn09U]@02IK4800P2JKD@01P2EJcT0UV`j09I/>P2GKC/0V6hl09U_?@80VW0n0P2LLT0209]a
?`0409Y`?P2IKcd0VFlm09Q^?0<0Vfln00<0VVhm09U]?02HK3/00P2HK3/0102HKS`0VFlm09U_?@2J
L3h209]a?`80W79000P0UW4m09Qc?`2KMT80WGQ409iiA@2MN4@0W7M309]f@PP0VGA000P0Vg4o09me
@`2SNDL0XgU70:5gA@2RN4H0YG]90:UoC@P0WgE3202QMD@80:5gA@0309mf@P2QN4@0XgY60080Y7]7
00/0XgY60:5hA02OMT80Y7]70:=jAP2RNDD0XGQ40:1g@`2OMT80WWE109ed@0030:AfA@<0YGM60P2V
N4L20:AjB0<0XgU70`2RN4H80:9i@`030:AjB02SNDL0XWQ60080XGM500H0XgU70:EkB@2VO4X0Ygi8
0:ImA`2UO4H20:AkA@030:ElAP2VODL0Ygi80080Y7]500<0Y7]70:EkB@2UNd/00`2TND`00`2TNDh0
YWa:0:IlBP060:IlBP030:UoC@2WOD/0Y7Y80080XgU700<0Y7Y80:MmB`2YOdd00P2UP4/30:AoBP<0
Xgi9202TOdX80:J1C@@0YH1<00@0Y7m;0:=nBP2RODT0XGa80P2UOdh0102VPDd0YX5<0:J1C02WPT/2
0:N3B@P0ZGm=102WPTh20:J1C@80YH1<0P2XPU40102XPdl0ZHA?0:V4C`2YQ4d20:Z6C0080:f4D02/
Pdl0Zh9>0:Z1C@2[PTh0[HA@0;27D`2aR5@80:Z5D0P0[8=?0`2XPdh30:V4C`80ZXE@202YQ4l80:b3
C`80ZhIB102ZQE420:V4D080[HQD0P2/Qe<01`2[QU80ZXEA0:Z5D@2YQ500[8MC0:^6DP2YQ5000P2X
Pdl0102YQ500ZhIB0:^6DP2/Qe<80:^6D@P0ZXEA202[QEH40:f8E080[XUE0P2_RUH80:f8D`P0ZhIA
0`2^RED20:n:EP<0/8]G00P0[8YL0:b:FP2^RUX0[hUH0;69EP2bRED0/XUC0;>8D`80[hYE0`2^RE@3
0:f8D`P0[8MC00<0ZhIB0:b7D`2^RED00P2`ReL00`2_RUH0[HQD0:b7D`020;6<F0040;2;E`2_RUH0
[hYF0:j9E@80[HQD202_RUH80:b6E@P0[hYF00@0ZhIB0:Z5D@2ZQE40ZXEA0P2YQ5020:R3C`80[8MJ
0`2]R5/30:j9G0@0[HQC0P2^RE@20:n:E@T0/8aH0`2_ReL20:j:EP<0[HUE102aQE@20;:6E@80/hMF
00H0/8YM0;2:F`2`RU/0[hUH0:n:EP2^RE@20:j9DP80[8MC00@0[HQD0:j9E@2`ReL0/HaH0P2bSET8
0:j:FPP0/hmK202dSe/30;>>E`80]8mH0`2eT5T01P2bSeL0/i1H0;>@F02dTET0]I9J0;JCF`80]iAL
00D0]8mK0;F@G02eT5`0]Y5M0;NBGP020;RCG`030;VDH02eT5/0]I1K00H0]I1K202gSE/30;F?H080
]8iO0`2cSEh0202eSf80]HmP0;J@H@2fT5l0]i9N0;NBG@2gTU/0^9=L102gTUh20;RCG`80^IAP00<0
]i5R0;J@H@2eSf000P2cSEh02`2eSf00]Y1Q0;NAHP2fTUh0]i=O0;RDH02iUF40^9AP0;NCG`2eTEd0
]91L00P0]HmP202dTV890;VEI@040;VEH@2hU600^9AP0;NCG`80]Y9N0P2eTEd80;RCG0<0]i=S00<0
]Y9R0;FAH@2dT6000P2dT6000`2bSUh0/hmO0;FAH@020;NCH`030;FAH@2cSel0/XiN00<0]91L00<0
]I5M0;JBGP2gTel00P2gTel0202iU6P0^9=W0;NBI@2eTF40/hmM0;:>FP2aSET0/8eG0P2dT5`0102e
TEd0]Y9N0;JBGP2gTel20;RDH0<0]Y5U0`2gTVH20;RCI`P0^9AT202gTf<40;VEI@@0^9AT0`2iUV02
0;REG`<0]iAN202gTf<20;RDI0<0]i=S0`2fTV820;F@H`<0]Y5T0`2gTVD80;JBHP0<0;^EIP2jU6D0
^99S0;J@H@2eSf00]Y1Q0;RBH`2iTf@0/hmO0;B@H02fTV80^9AT0P2iUFD00`2hU6@0]i=S0;RDI002
0;RDI0<0]i=S0`2fTV820;JBGP80]I5M00@0]91L0;>?F`2cSe/0/XiJ0P2dT6020;FAH@80]Y9R0P2g
Tf<80;RCIP80^9AT0`2gTf<30;JBHPP0]i=S00P0/XaM0;>=GP2dSUl0]Y1Q0;NAHP2iTf@0^YAU0;^E
IPP0]Y=K2`2cSEh50;:<G@80/H]L0P2bS5d0102cSEh0]8iO0;F?H02eSf020;>>FP030;B?F`2eT5`0
]Y5M0080^9=O00<0^IAP0;B@G02dT5`01P2dT5`@0;>?G`80/hiR00<0/hiQ0;>?G`2cSed00P2cSe/0
0`2cT5X0/heN0;>=GP060;>=GP<0/XaM0`2cSEh20;B>G`080;B?F`2eT5`0]i9N0;VDH02jUF40^IAP
0;NBGP2fTEd20;:>GPD0/hmO0P2dT6020;>=GP80]8iO00D0]HmP0;J@H@2fT640]i5R0:n:EP020;2;
E`080;6<F02bSET0/hiJ0;>>FP2dSe/0/8aL0;6=G@2cSel20;FAH@030;B@H02cSel0/XiN0080]I1T
00H0]I1S0;B@H02dT5h0]91L0;>?F`2cT5X20;2:F`030;6;G02bS5d0/heN0080]HmP00T0]Y1Q0;ND
GP2dTE/0/HiH0:j;E@2]RU@0[haF0;:?F@2eTU`0102aS5P20;2;E`80[hYF202_ReL0202`RF80/HYS
0;><H@2dSV40]HmN0;B?FP2cSUL0/XiD1@2bSUh30;6=G@0;0:n;F`2^RUX0[HUI0:f9F@2^RUX0/8aL
0;:>GP2cSel0/HeI0;2<F02_ReL00P2]RED00`2_ReL0/8aH0;6=F@040;2;G`@0/HaP0P2aSel30;2>
GP<0[heM00@0[h]K0;2<G02`S5`0/8aL0`2aSEd00`2bSUh0/XeI0;:=F@060;:=F@030;2<F02aSET0
/XiJ0080]91L00<0/XiJ0;6=F@2`S5P00P2/R5@20:f9E@<0[XYF00@0[h]G0:n;F`2_Re/0/8aL0`2a
SEd0502bSUh0/hmO0;>?G`2_ReL0/8aH0;6=F@2bSUX0/HeI0:n;E`2]RED0ZhMC0:f9F@2^RUX0[h]K
0;2<G02aSEd0/XiN0;>?G`2dT600/XiJ0`2aSET20;2<F080[h]G0P2/ReH00`2^RUH0[hYF0;69EP02
0;:8EP060;>7EP2]RET0[HUI0:f9F@2/R5P0ZhMG0`2ZQUH00`2YQED0ZhMG0:b8F0020:j:FP030:b8
F02[QeL0ZHEE00P0ZXIB0`2^RUH=0:f9E@080:j:FP2_Re/0[h]K0:n;F`2^RUX0[8QH0:V5E@2XQ5@2
0:f9E@80[8QD0P2[Qe<20:Z6DP80[8QD0P2[Qe<0102ZQU80ZHEA0:V5D@2XQ5020:N3C`040:R4D02Y
QE40ZHEA0:Z6DP80ZhMC00`0ZhEH0:Z4E@2XPU<0Yh5@0:N2CP2XPdh0ZXE>0:^6C`2`RU/0[XQI0:^5
EP2XPU<20:N1DP030:R2D`2YPe@0ZXEA00L0ZXEA00@0ZH=D0:Z4E@2ZQ5D0ZhEF0P2/QUL20:f7F0<0
[XQI00<0[HMH0:b6E`2[QEH00P2[QEH30:b7DP@0ZhIA0P2ZQE00102VPDd0Yh9>0:N2CP2WPTh30:R3
C`040:V4D02[QU80ZhIB0:^6DP80ZXEA0`2YQ5020:b8CP040:^6C`2ZQE00ZXE@0:V4D080Z89A00D0
YGiE0:IoEP2VOe@0Yh5D0:R2D`020:V3DP030:Z5D@2YQ500ZHA@0080Z8=?0P2WPTh20:J1C@0<0:F0
C02VPDd0Yh9>0:R3C`2WPTh0YH1<0:9mB@2QO4P0XGa70:=nB@2UP4/0Z8=>0P2YQ4l01`2XPdh0Yh9=
0:J1C@2VPDd0YH1<0:AoB`2SOTX00P2QO4P05P2PNdL0YX5<0:=nB@2QO4L0Xgi90:N2C@2YQ4l0Yh9=
0:AoBP2PO400X7a20:1kA02PNdH0X7Y90:1jC@2PNDh0X7U@0:9mB@2SOTX0Y7m;0:F0C02VPDd30:N2
CP060:F1D@2TP500XWi>0:1lC02ONd/0X7a<0P2QODd80:AoB`P0YGm@00H0YH1C0:F1D@2UPE40Y81>
0:B0C02SP4X20:>0B0P0YX5<0P2ONTH00`2PNdL0XGa80:9mB@020:=nBP040:AoB`2VOdP0YWm80:Io
B080Yh190`2XPDX20:J3B@030:F2B02TPDL0Y8570080Xh160P2ROdD20:N2C@040:J1C02UP4/0YH1;
0:AoBP80Xgi900P0XGa80:=nBP2TOd/0YH1<0:AoB`2SOTX0XGa809mjAP80Y7]=0`2UO4h00`2SNT`0
XGQ:09mfB00309iiA0D0WgY500P0X7]709mjAP2NNDD0WGQ409iiA@2PNdL0Xgi:0:AoB`80XGe900@0
Wg]709ijAP2MNDD0W7Q40P2KMd<209mkA`0409ijAP2MNDD0W7Q409]g@`80VWI200P0WGU909ijBP2O
Nd/0X7a<09mkB`2NNTX0W7Q809]gA`@0WGQ4102NNDD209]f@@<0W7M20`2MN4<309iiA0<0WgY50P2P
NdH01P2ONTH0WWU509iiA@2MN4@0W7M309]f@P80VWE100H0VgI909]gA`2KMdL0VgM509]g@`2KN482
09]h@00409ag@`2KMT80VgI209Ye@@80VGA00P2HLcl0202FKd@0VG9709]eB02HLT<0U6hm09A_>`2J
MD40WgY5202IMD401P2JMD00VWE109Ye@@2ILd80V79309MaA080Ug150`2HLT<309Ma@P80UW1100H0
Tflo09=_?@2CKcd0U70l09Aa>`2DLCT309Aa=`08091/?02BKSh0U71009Ib@P2GLd<0V7A409Mc@`2F
LT8209Mc?`0409Ib?P2ELCd0UG4m09A`?080Tflk0P2@K3`2095]?@@0TVhn00@0TFdm091/?02@K3`0
T6`l0`2?Jc/0102>JSX0T6/n095/?`2AK3l3099]@080TF`o0P2?KCl208i/?P0408e[?@2<JS`0S6Xl
08]Y>`80T6/n0`2AK3l3099]@0@0RV@m102;ICh00`28ISP0RFLi08YX>P0208]Y>`0308YX>P29IcT0
R6Hh00<0S6Xl:oooool002[ooooo00<0TfPk09EZ?@2FJch00P2GK3l01P2EJSd0TfPk095V>@2<HCH0
Sf@i09AY?P80Ufa100<0U6Tn08mT>@2<HCH00P2AIST0102BIcX0TfPk09EZ?@2FJch209M/?`0609Q/
?`2GJch0UVXm09EY?02CIcX0TFDh0P2@I3L809AY?080TVLj00@0TfPk09AY?02DJC`0UFXm0P2FJch8
09AY?0P0UFXm0P2HKD00102FJch0UFXm09=X>`2BIcX2091U>004095V>@2DJC`0Uf`o09Y_@P80Vg13
00H0VFi109I[?P2DJC`0UV/n09M/?`2HKD0209Y_@P0309Q]@02GK3l0UV/n00D0V6hl0`2GKC/209Q]
@`0309Q]@P2HKD00V6hn0080V6hl00T0V6lk09U_?@2JL3h0W79009ec@@2LLT00Vg4o09U_?@2GKC/0
0`2MLd400`2LLT00Vg4o09Y`?P0209Y`?PP0WG=10P2MM3h01P2NMD40WWA209idA02NLdH0WgA709md
B@@0X7I400@0XGM50:9hAP2RN4H0XgU70`2OMD<00`2NM480WG=109ab@00209ab@0080:9`?`2TLT40
YWA30:MeA02XMTD0YgE40:Ec@P2TLT4209mcA0<0X7A50`2QMDH809mf@P080:9g@P2QMT40X7E209ib
@@2NLT<0X7A70:5eB02RMD/20:=iA`<0XWQ60`2QMdD80:9iA@P0XgY600P0XGM50:9hAP2TNTP0YWa:
0:MmB`2VO4X0Y7Y80:=iA`P0XGe32@2VODT40:F0B`@0YX5<202XOd/0202WPTd0YX5=0:AoB`2SOD`0
Xge>0:EoDP2WP5D0Z85F0P2XOT`20:MmB`@0YWa:202WOTX30:J1C080YH1;0`2TOdX20:IlC0040:Mm
C@2XOTh0Z7i>0:UoC`80ZX1@0P2/Pd/0102/Pdd0Zh9>0:Z1C@2YOdd20:UoC`P0Zh5?202/PU080:V3
EP080:b1EP2]PUD0[hAG0;26EP2`QU@0[hIB0:f4CP2/Pdd80:b3C`<0Zh9>0`2/Pdl20:f4D0<0Zh5?
0`2/PU020:f3D@P0[8=;00P0[H=A0:j4DP2_QE<0[hEC0:j4DP2/PU00ZX1>0:UoC@80/8MC0P2_QU80
102^QE40[HA@0:f4D02/Pdl90:Z5D@X0[hIB00@0[XEA0:f4D02]Q500[8=?0P2[PTh80:j4DP80/XQF
00H0/HME0:n5D`2]Pe40[89@0:^1C`2ZP4h30:^6D@030:b7DP2]R5<0[XUD0080[XUD0P2^QE420:n6
DP80/8MC0P2aR5@80:j9E@80/XeI0P2aS5P0102`ReL0[hYF0:n:EP2^RED80:j9E0040;>9E`2bR5H0
/XQF0;67E@80/8ID0P2_QE<20:f8E0040:j9E@2_RUH0[hYF0;2;E`80/HaH202^R5T30:j9E@030:f8
E02/Qe<0ZhIB0080ZhIB0P2_RUH30:j9E@/0[HQD00<0/H]J0;2:F@2^R5L00`2/QUD00`2]QeH0[XQG
0:n:E@070:n:E@<0[XUD0P2_RUD30;2;EP030:j8F@2`RU/0/H]L0080/XaM00@0/H]L0;2:F`2^R5T0
[XQI202_REX30;2;E`80[hYF0`2^RED0202^S5l0[H]N0:j9G02^R5T0/8QG0;>9E`2eReT0^8eJ0P2c
REL20;B:F080]H]I0P2fS5X0102aSEd0/8aL0;2<G02`S5`20:n;F`80[XYJ1@2bSUh30;6=G@<0/XmI
0P2cT5X30;BAF`80]8mK0P2eT5`40;JAG@P0^9=N0`2fTE`30;F@F`80]8mJ202fTEd00`2fT640]HmP
0;>=GP030;6;G0030;:<G@2cSEh0/hiJ0080/hiJ0P2dSe/30;F@G080/hiJ00<0]8mK0;F@G02fTEd0
0P2gTUh01@2hTel0/heN0;B>G`2dSUl0]HmP0080]Y1Q0P2gTF820;F@G080]Y5M0`2gTUh00`2hTel0
]i9N0;NBGP060;NBGP80^9=O0P2gTUh20;JAG@80]I1L102fTV820;NCH`80^9AT102gTf<00`2fTV80
]I5Q0;B@H0020;B@H0080;^EIP2jU6D0]i5R0;J@H@2eSf00]Y1Q0;RBH`2iTf@90;RBH`<0]i5R0P2f
T6420;F?H0030;B?HP2eT6<0]Y5T0080]i9U00<0]Y5T0;F@H`2dSf800`2gTf<00`2fTV80]I5Q0;B@
H0020;B@H0P0]Y5U00P0]i=O0;RDH02iUF40^IEQ0;RDH02fTUh0]91L0;>?F`P0]i=O00<0^9=O0;VD
H02jUF400P2kUV800`2iU600]i9N0;JAG@080;B@H080/hmK00H0]91L0;JBGP2hU600^IEQ0;ZFHP2k
Uf<80;RDH0P0]i=O2`2gTf<20;RDI0<0^IEU00@0^IIP0;REG`2hUEl0]iAN0P2fTed20;FBG0P0]i9N
00H0^91L0;R@G@2gTUh0]i=Q0;VEI@2hUVP20;RGJPT0^9AT0100]Y5M0;F@G02dSe/0]8mK0;F@G02g
TUh0^IAP0;^FHP2kUfL0^YIV0;VEI@2gTf<0]91P0;:>GP2aSEd0/8aL202fTUh20;>@FP80]95K102e
TU`80;FAG@<0]95K00<0]I9L0;JCG@2gU5h00P2gU5h0102gU5`0]Y=K0;FBFP2dTET40;>@F080/hiJ
102dSe/20;F@G0P0]91P202bSF430;FAH@<0]91P0P2cSel30;B@H080/hmO102bSUh01`2cSel0]91P
0;FAH@2eTF40/hmO0;6=G@2`S5`00`2cSUX20;B?F`<0]I1L202eTF480;B>G`040;2;E`2aS5P0/HaH
0;6<F080/XeI0P2cSUX20;FAH@040;B@H02cSel0/hmO0;:>GP80/HeM0P2eTF420;B@H080/hmO00<0
/XiN0;6=G@2aSEd00`2fT6430;F?H080]8iO0P2`S5P20;6=F@040;:>FP2cSe/0/hmK0;B@G0P0/hiQ
0`2dT6020;>?G`<0/XiN202bS5d80;:>GP@0/8aL0P2_Re/20:j:FP80]HeJ0P2dS5T20;>;F080/XYG
0P2`ReL20;6<F080/XeI0P2cSUX20;B?F`80/hiJ102bSET20:n;F`@0[XYJ0P2]RET80;:>FP080;B@
G02cSe/0/XiJ0;6=F@2`S5P0[h]G0:j:EP2]RED20;>?G`80/XiN102aSEd00`2_SEd0[XaL0:b:FP02
0:^9F@030:b:FP2^S5`0[heM00P0/8aH0`2`S5`30:n;F`80[XYJ202]RET20:n;E`D0[XYF0P2]RED0
0`2^RED0/8]G0;6<F0020;:=F@030;6<F02`ReL0[XUE00P0[XYJ0`2aS5P30;2;E`80[hYF00@0[h]K
0:j:FP2^RUX0[HUI0P2/R5P20:^7E`P0[HUI0P2/QUL20:f7F0080:j8F@2_REX0[hUJ0;2:F`2YQED0
ZXIF0:b8F02^RUX20:n;F`030:j:FP2]RET0[XUL0080[XYJ00<0[XYH0:j:EP2^ReD00P2^Re<0202_
ReL0[HUE0:^7D`2ZQU80ZHEA0:Z6DP2[Qe<0[8QD202]R5@01P2ZQ5L0ZXAE0:^5EP2[QE@0ZhIB0:b7
DP80[8M@0P2/Qe<0102[QU80ZXEA0:Z5D@2YQ5020:R3C`80Yh9>0P2XPdl0102YQ500ZXEA0:^6DP2[
QU820:V4D0@0ZXEA0P2[QU820:j8F@040:b6E`2[QEH0ZH=D0:R2D`80YX1A0`2/Qe<30:^6DP80ZXEA
0P2YQE430:Z6DP<0ZhMC202^R5L00`2XPdl0ZHA@0:V4D0030:Z5D@80ZhIB00@0[8MC0:J1C@2WPTh0
ZHA@0P2[QU803@2ZQE40Z8=?0:N2CP2UOe80Yh5B0:R2D`2ZQ5<0ZXEA0:R3CP2WPT/0YH190:V5B`2Z
QT`00`2/R4h00`2ZQT`0Z8A:0:N3B@080:J1C@0D0:V3EP2XPU<0YX1A0:EoCP2TOd/0YH1;0:J1BP2W
PT/0ZGe<0:UoC@2[PDl0Zh=@0:R3C`2UPDd0XH1;0:1oBP2SOTX0Y7m;0:N2CP2YQ5020:Z5D@0:0:V4
D02XPdl0Y7iA0:EoD02VP540YX1?0:F0C02SOTT0XGa50:1kA080XWe600<0XWe80:9mB@2RO4/00P2R
O4d00`2RO4l0XGe=0:5mC@030:1lC0<0Wg];202TP4`20:F1C`060:B0C02SP4X0XWm90:5nAP2QOT@0
X7e3202SOU400`2TOd/0YH1<0:J1C@020:N2CP060:F0C02TOd/0XWe90:J2CP2TP4`0Xgm;0`2QODT0
1@2SOd/0Y81<09ik@`2PODD0XWm700<0Y8590P2SP4P209inA@060:5nAP2SOTL0YWm80:QoB@2YP4X0
Zh1;202TOdX20:J1C@D0YH1<0P2TOd/0202TOdX0Xgi90:9mB02RODP0Xgi90:F0B`2WPTd0Z8=>202R
OTX05P2SOTX0Y7m;0:F0C02UP4`0Y7m;0:9mB@2PNdL0WWU50:J1C@2UP4`0Y7m;0:=nBP2RODT0XGa8
0:1kA`2ONTH0Yh9>0:F0C02RODT0X7]709iiA@2ONTH20:1kA`80XWe900@0XGa80:1kA`2PNdL0WgY6
0P2NNDD809ijAP0309]g@`2LN4@0WWY60080X7a800/0Wg]709eiA@2LN4@0VgM709ahB02MNDT0WWY:
09eiB@2LN4P0VWI609UeA@0309mjAP0309iiA@2MN4@0W7M30080W7M300H0VG@o09]f@@2NND@0X7]6
0:9mB02QO4L20:1kAP80X7a800<0Wg]709ijAP2MNDD00P2LN4@00`2KMd<0W7M309ag@`0609ag@`04
09Mb?P2HLcl0V7<o09Qc?`<0VGA000H0VWE109]_@P2KKd80Vfm209a`@`2MLD@309ibA@0309]f@@2J
MD00Ug8m0080UW4l00<0Ug8m09Ye@02KMT400P2KMDH209YdA@<0VG=400<0V79309A`@02DL4001P2D
L40309=_?`<0U7100`2ELD40202?Jc/0TFdm09=_?`2DL400UG5109A`@02BKSh0TFdm0P2HM4@0102G
Ld<0UW9209A`@02CKcl2099^?P04095]?@2BKSh0TVhn099^?P80Tflo0P2DL40209E]>@0409=^>@2B
KcT0Tg0j095`>P80T74j0P2?KCl408i/?P80SF/m0`2BKD03095/?`80T6/n0P2@KD<0102?K480SV]1
08i[@@2=JT0208aY?`@0SFPk0P2<IcX208]V>@80SfXm102@Jch2095/?`<0SFTi:oooool002[ooooo
00/0TfPk09AY?02EJSd0UV/n09EZ?@2DJC`0TVLj091U>02>HcP0T6Dj09=X?@0209EZ?`0309=X?@2@
ICX0SV<h0080TFHi00H0TVLj09=X>`2DJC`0UFXm09I[?P2GK3l209IZ?@0309EY?02DJ3/0TfLj0080
TVHi00<0TFDh09AY?02DJC`01P2DJC`00`2BIcX0TfPk09=X>`0209AY?080UFXm00<0UV/n09AY?02D
JC`01P2DJC`809EZ?@0409M/?`2FJch0UFXm09EZ?@80TfPk00D0TVLj095V>@2AIST0TfPk09M/?`03
09Y_@P0609Q]@02FJch0U6Tl09I[?P2GK3l0V6e00P2IKT400`2HKD00Uf`o09I[?P0609Q^?080Ufdk
0P2HKD<00`2HKD80V6e009Q^?P0209Q^?00409Q_>`2IKcd0VW0n09]a?`80W79000<0Vg4o09U_?@2H
KS`00P2MLd4209ab@080Vg4o0P2JL3h809ec@@80WWDo00<0WWE109id@P2NM4@00P2NLdH0102NLdP0
WgE309me@`2OMD<20:1fA0<0XGM50P2PMT@209me@`80WWA20P2MLd400`2QLD00XW910:Ad@`020:Ee
A0030:Ad@`2SLd80XW910080Wg=40`2PM4D30:5eAPP0WgI200P0XWM20:5f@@2PMD80WW9109ib@`2P
M4L0XGE80:9eB`80XgU70`2RN4H30:5gA@P0XWU5202SNTH00`2QMdD0XWQ60:AjB0030:IlBP030:Aj
B02SNDL0XGe300L0XGe32@2VODT50:AoBP<0YH1;202XOd/0202WPTd0YX5=0:AoB`2SOD`0XWa=0:=m
D02UOU<0YWmD0P2XOT`20:MmB`<0YWa:00<0YG]90:MnBP2WOTX01P2WOTX30:J1C080YH1;0`2TOdX0
0`2VO4`0Yge=0:MmC@020:QnCP80ZGm?00L0ZX1@0:b3B`2/Pd/0Zh9<0:^2CP2ZPDd0ZGm=0080ZGm?
202[PDl80:b2D0P0ZH=D00P0[85F0:f2E@2_Q5L0/8IF0;26E02_QU80[HA>0:b3C@P0[8=?0`2[PTh3
0:b3C`80[HA@0`2[PDl30:b2D080[H=A202/Pd/00`2/PU00[H=A0:j4DP020:n5D`040:f3D@2[PDl0
ZX1>0;27D`80[hIB0P2^QE420:f4D0030:b3C`2ZQE40ZXEA00L0ZXEA2@2_QU820:j5D@80[HA@0P2/
Pdl00`2[PTh0[XAB0:j4DP060:j4DP060;67E@2`QU@0/8ID0:n5D`2^Q580[H=A0P2/PU030:^6D@03
0:b7DP2]R5<0[HQC0080[XUD0P2^QE420:n6DP80/8MC0P2aR5@80:j9E@030;:=F@2aS5P0/HaH0080
/8]G0P2_RUH00`2^RED0[XUD0:j9E0060:j9E0<0/XQF00<0/HME0;26E02`QU@00P2_QE<00`2]R5@0
[XUE0:j9E@020:n:EP80/8]G00<0/HaH0:j8F@2^R5T01P2^R5T30:j9E@030:f8E02/Qe<0[8MC0080
ZhIB0`2_RUH20:j9E@/0[HQD00<0/H]J0;2:F@2^R5L00`2/QUD00`2]QeH0[XQG0:n:E@070:n:E@80
[XUD0`2_RUD30;2;EP030:n9FP2`RU/0/H]L0080/XaM00<0/H]L0;2:F`2_REX02@2_REX30;2;E`<0
[hYF0P2^RED0202^S5l0[H]N0:j9G02^R5T0/HUH0;>9E`2eReT0^8eJ0P2cREL20;B:F080]H]I0P2f
S5X20;6=G@80/8aL0`2_Re/00`2^RUX0/XiN0;:>GP040;:>GP80/HeM0P2bSUX30;>?F`<0]91L0P2d
Se/20;F@G0<0]Y5M00<0]i9N0;RCG`2hTel01P2hTel30;JAG0<0]I1K0P2dSeX80;JAG@030;J@H@2e
Sf00/heN0080/H]L00<0/XaM0;>=GP2dSUl00`2cSUX20;B?F`<0]I1L0P2cSUX00`2dSe/0]I1L0;JA
G@020;NBGP050;RCG`2dSUl0]8iO0;B>G`2eSf000P2fT6420;NAHP80]I1L0P2fTEd<0;NBGP80^9=O
0P2gTUh20;JAG@80]I1L00@0]I5Q0;JBHP2fTV80]Y9R0P2gTf<20;RDI0<0]i=S0P2fTV820;FAH@80
]91P00L0^iEV0;VCI02gTF80]Y1Q0;F?H02fT640]i5R00T0^99S102gTF820;J@H@80]HmP00<0]8mR
0;F@H`2fTF@00P2gTVD00`2fTF@0]I1S0;B?HP020;NCH`80]Y9R0P2eTF420;B@H0P0]Y5U0P2gTel0
1P2hU600^IEQ0;RDH02gTel0]I5M0;>?F`P0]i=O00P0^9=O0;VDH02jUF40^iIR0;ZEH@2iU600]i9N
0;JAG@P0]91P00H0]91L0;FAG@2eTEd0]Y9N0;NCG`2hU6020;VEH@P0^9AP202gTel;0;NCH`<0^9AT
0P2iUFD30;RDH0030;NCG`2fTUh0]Y9N0080]I5M202gTUh01P2iTEd0^I5N0;RCG`2gTf40^9AT0;NE
I`80]iIY2@2hU6@00`2gTUh0]Y5M0;F@G0020;F@G0030;JAG@2hTel0^IAP0080^IEU00@0^9AT0;JB
HP2eTF40/hmO0P2bSUh80;JBGP80/hmK0P2dT5`30;FAG@030;JBGP2eTEd0]I5M00H0]I5M0`2dT5`0
0`2eTEd0]Y9N0;JBGP020;NCG`80]Y=K0P2eTUX0102dTET0/i1H0;>@F02cT5P60;B?F`80]I1L202d
T6080;:=H@L0]91P00@0]I5Q0;B@H02dT600]91P0P2cSel40;:>GP070;>?G`2dT600]I5Q0;FAH@2c
Sel0/HeM0;2<G0030;>>FP<0]8mK0P2eT5`80;B@H0P0]8iO102aS5P20;:=F@80/hiJ00<0]I5Q0;B@
H02dT6000P2cSel20;:>GP030;6=G@2dT600]91P0080]91P0P2cSel30;:>GP<0]Y1Q0P2eSf030;B>
G`80/8aH0P2aSET0102bSUX0/hmK0;>?F`2cSe/80;>>H@80]91P0`2cSel30;:>GPP0/XaM202bSUh0
102aSEd0/8aL0;2<G02`S5`20:n;F`80[XYJ0P2eSEX20;B<F@80/h]H0P2bRUL20;2;E`80/HaH0P2b
SET20;>>FP80]8mK0P2cSUX30;:=F@030;6<F02_Re/0[h]K00H0[XYJ202bSUX20;>?F`040;:>FP2a
SET0/8aH0:n;E`80[XYF0P2cSel20;:>GP<0/HeM00@0/8aL0:n=G@2^S5`0[8YJ0P2[RET00`2/RUX0
[XaL0:n=G@080;2<F0<0/8aL0`2_Re/20:j:FPP0[HUI2@2^RUH00`2_RUH0/8]G0;6<F0020;:=F@03
0;6<F02`ReL0[hYF00P0[XYJ0`2aS5P20;2;E`<0[hYF00<0[h]K0:j:FP2^RUX00P2]RET20:b8F003
0:^7E`2]RET0[HUI00H0[HUI0P2/QUL20:f7F00:0:j8F@2_REX0[hUJ0:n9FP2YQED0ZhMG0:f9F@2^
RUX0[h]K0:j:FP80[HUI00H0[XUL0:j:FP2^RUX0[XYH0:j:EP2^ReD20:j;D`080:n;E`2]RED0ZhMC
0:Z6DP2YQE40ZXIB0:^7D`2/R5@80:f8E0060:Z4E`2ZQ5D0ZhEF0:^5E02[QU80[8MB0P2/Qe030:^6
DP<0ZXEA0P2YQ5020:R3C`<0ZHA@2@2ZQE420:^6DPP0ZXAE0`2/Qe<20:^6DP<0ZXEA0`2YQE420:Z6
DP<0ZhMC202]QeH00`2YQ500ZXEA0:Z5D@050:Z5D@040:^6DP2VPDd0Z8=?0:V4D080ZhIB01<0ZXEA
0:R3C`2WPTh0YX1C0:N1DP2XPU<0ZH=B0:V4D02XPdh0Yh9;0:J1BP2YQD/0ZXI<0:^7C@2/R4h0ZhM=
0:Z6C02XQ4X0Yh=900P0YX5=01D0ZH=F0:R2D`2VP540YGm>0:AoB`2UP4/0YX5:0:N2B`2ZOTd0ZGm=
0:^1C`2ZPTl0Z8=?0:F1C@2QP4/0X7m:0:=nBP2TOd/0Yh9>0:V4D02ZQE400P2YQ5002@2XPdl0YGmB
0:EoD02VP540YX1?0:F0C02SOTT0XGa50:1kA0020:=nA`030:=nB@2SOTX0Xge<0080Xge>00@0Xge@
0:9nCP2ROTh0XWi>0P2QODd30:1lC0P0Y81<0P2UPDl0102TP4`0Xh1:0:9oB@2QOTH20:1m@`P0Xgm?
00/0Xgi:0:AoB`2VPDd0Yh9>0:J1C@2UP4`0Y7m;0:=nBP2TP4`0Xgm;0:9nBP020:5mB@060:9nBP2T
P4`0YH5=0:1mA@2ROdL0Xh180`2UPTX02P2SP4P0XWm709inA@2NOTD0XGi60:=nA`2VOdP0Z7m90:V0
BP2ZOdX80:AoBPL0YH1<0P2TOd/0202VPD`0YH1;0:AoBP2SOTT0Y7m:0:F0B`2WPTd0Z8=>202ROTX0
0`2RODT0Xgi:0:AoB`020:AoB`030:=nBP2QO4P0X7]70080YH1<00X0Y7m;0:=nBP2RODT0XGa80:1k
A`2ONTH0YX5=0:AoB`2RODT0X7]70`2ONTH0102PNdL0XWe90:5lB02QO4P20:1kA`80WgY600<0WWU5
09ijAP2NNTH01P2NNTH0402KMd<0W7Q409ijAP2ONdL0X7a809mkA`2MNDD0W7Q409ahB02MNDT0WWY:
09mkB`2NNTX0WGU909]gA`2JMTH209mjAP80WWU50P2MN4@209ag@`0409Ye@02KMT40WWU40:1kAP80
XGa700<0X7]609mjA@2NNTH00`2NNTH409eiA@P0W7M31P2IM40209Qc?`80VVm20P2KL4<209aaA080
WG9500<0VWE109Ud@02HLcl00P2GLSh0102HLcl0VGA009Ye@@2KMDH309YdA@80VG=40P2HLT<809A`
@0<0Tflo0`2DL40309Ea@@0>099^?P2CKcl0UG5109Mc@`2HM4@0Ug=309Ib@P2ELD40V7A409Mc@`2F
LT80UG5109A`@02CKcl6099^?P80Tflo0P2DL40209E]>P0409=^>P2BKSX0Tflk095`>`80T74k202>
K3h3099]@080TF`o0`2@Jch01P2AKT@0T6e3091]@`2>Jd40SFY008aY?`80RfPn00@0SVTl08eX>`2=
J3/0SFPk0P2<IcX208]V>@80SfXm1P2@Jch308eY>B_ooooo000Zooooo`06099W>P2CJ3/0TfPk09AY
?02CJ3/0TVLj0P2@ICP2095V>`@0TVLl0P2AIS/2095V>@03099W>P2CJ3/0U6Tl0080UFXm00<0UV/n
09AX>`2DJ3/01P2DJ3/809AY?0<0TfPk0P2DJC`309EZ?@P0U6Tl202EJSd809AY?004095V>@2CJ3/0
UV/n09Q]@080VFi100H0Uf`o09EZ?@2DJC`0UFXm09I[?P2HKD0209U^@@0309Q]@02FJch0UFXm00P0
V6hl0P2HKD<00`2HKD80V6e009Q^?P0209Q^?00409Q_>`2HKS`0VFlm09Y`?P80Vg4o00@0VW0n09U_
?@2IKcd0WG=10`2LLT0309]a?`0309Y`?P2MLd40WG=100H0WG=10P2NMCl00`2NMD40WWA209idA002
09icAP0409icB02MLd40WG=109id@PD0WgE30`2QMdD20:1fA0<0WgE300@0XW910:=c@P2TM4<0YGE4
0P2TM4<0102SLd80XW9109mc@P2OLd830:1d@`<0XGE4202PMd<0202RMd80XGI10:1e@P2NLT40WW93
0:1dA`2QMDP0XWE;0P2SNDL30:9hAP<0XGM5202RNDD80:=jAP030:5gA@2RN4H0Y7Y800<0YG]90P2T
NTP80:5lA@T0YWe90`2SOTT50:9mB0P0Ygi:00H0YX5<0:F0C02TOd/0XWa;0:5kC02QNdh20:9kD0<0
Yge;0P2VO4X30:EkB@P0Ygi:0`2VPD`20:F0B`<0Y7m:0`2WOD/20:QnC0<0ZGm=0P2[PTX0102[PT`0
ZX5=0:Z1C@2YOdd20:UoCa00Zh5?202YPe@0202/PEH0[H9E0:j3EP2^Q5@0[XAB0:j5D@2]Q4h0[8==
202/Pdl30:^2CP<0[8=?0P2]Q5030:^1C`<0[89@0P2]Pe480:b3C@030:Z0CP2[PDl0[H=A0080[hEC
00<0[XAB0:f3D@2/PU000P2_QU820:j5D@@0[HA@2@2[QU880:n6DP<0[XEA0P2]Q5030:b3Ca00[XAB
0`2[QU420:b7DP<0[HQC0P2^QE420:n6DP80/8MC0P2aR5@80:j9E@80/HaH0P2`ReL40:n:EPP0[XUD
0P2bR5H30;67E@<0/8ID0`2^RED20:n:EP<0/8]G202^R5T30:j9E@80[HQD0`2/Qe<0102`ReL0[hYF
0:n:EP2_RUH20:j9E@X0[HQD00<0/HaH0:n:EP2^RED00`2/Qe<20:j9E@P0/8]F00@0[XUD0:n:E@2_
RUD0[hYE0P2`ReH20;6<E`030:n9FP2`RU/0/XaM0080/heN00@0/XaM0;2:F`2_REX0[hUJ202`RU/2
0;6<F080/8]G0`2_RUH02@2^RED0[XaO0:f;GP2_RUd0[hUJ0;::F@2dRUP0]H]I0;N<F@020;>9E`80
]8YH0P2eReT20;J<FP040;:>GP2aSEd0/HeM0;6=G@80/8aL0P2_Re/80;:>GP040;:>FP2cSe/0/hmK
0;>?F`80]91L0P2eTEd30;F@G080]Y5M0`2gTUh80;RCG`<0]Y5L0`2eT5/20;B?FPP0]Y5M00P0]Y1Q
0;F?H02cSEh0/XaM0;6;G02bS5d0/heN0;B>G`<0/hiJ0P2dSe/30;F@G080/hiJ00<0]8mK0;F@G02f
TEd00P2gTUh00`2hTel0]8iO0;B>G`030;F?H0<0]Y1Q0`2eT5`20;JAG@/0]i9N0P2hTel20;NBGP80
]Y5M0P2eT5`30;FAH@80]Y9R1@2gTf<30;JBHP<0]I5Q00@0]91P0;ZDI@2iTf@0]i5R0`2fT64=0;NA
HP80]Y1Q0`2eSf000`2dSf80]I1S0;JAI0020;NBI@040;JAI02eT6<0]8mR0;NCH`<0]Y9R0`2eTF40
0`2dT600]Y5T0;JAI0060;JAI0080;JBGP2gTel0^9AP0;VEH@2hU600]i=O0;FAG@2dT5`80;NCG`03
0;RCG`2iU600^YEQ0080^YEQ00<0^9=O0;NBGP2eT5`0202dT6080;NCG`P0^9AP202gTel80;NCH`80
]Y9R0P2gTf<30;RDI0030;VEI@2hU600^9AP00<0]i=O0`2fTUh80;NBGP060;ZBGP2jTUl0^9=O0;NC
H@2gTf<0]YAV0P2eU6L90;NCH`030;VDH02hTel0]Y5M00<0]I1L00@0]Y5M0;NBGP2gTf<0]i=S0P2f
TV820;FAH@80]91P202fTUh30;B@G080]I5M0`2fTUh80;FAG@<0]91L0P2eTEd30;JBGP050;FBG02f
Ted0]Y=M0;JCG@2eTU`00P2dTE/00`2cT5X0]I1L0;F@G0030;F@G0<0]8mK202dT6080;:=H080/XiN
00@0/hmO0;B@H02eTF40]I5Q0P2fTV830;B@H080/hmO102bSUh01`2cSel0]91P0;FAH@2eTF40/hmO
0;6=G@2`S5`00P2bSET20;>>FP<0]8mK00<0]I1L0;:>GP2bSUh01P2bSUh80;B>G`<0/HaH0P2bSET3
0;>>FP<0]91P0P2cSel70;:>GP80/hmO0`2dT6020;J@H@80]HmP0`2dSUl0102cSEh0/HeI0;6=F@2a
SET30;:>FP80/hmK202cSV40102dT600/hmO0;>?G`2cSel20;:>GP80/HeM202bS5d;0;6=G@80/8aL
0`2_Re/20;>>FP80/XeI0P2aS5P40;2;E`80/HaH0P2bSET50;>>FP80/XeI0`2aS5P30:j:FPD0[h]K
202bSUX01@2cSe/0/XiJ0;:>FP2aSET0/8aH0080[h]G00@0[XYF0;:>GP2bSUh0/XiN0P2aSEd30;2<
G0030:n=G@2^S5`0[H]K0080[8YJ00<0[H]K0:j<G02_SEd0202`S5P30;2<G0<0[h]K0P2^RUX80:f9
F@T0[XYF00<0[hYF0;2;E`2bSET00P2cSUX00`2bSET0/8]G0:n:EP080:j:FP80/HaH0P2`ReL30:n:
EP030:j9E@2^RUX0[XYJ0080[XYJ0P2]RET20:b8F0P0[HUI0`2]QeP30:j8F@80[hUJ00T0ZXIF0:^7
E`2]RET0[XYJ0:n;F`2^RUX0[HUI0:b8F02]R5/00P2]RET00`2]REL0[HUE0:f:E0020:f:DP080:n;
E`2]RED0ZhMC0:Z6DP2YQE40ZXIB0:^7D`2/R5@80:f8E0060:Z4E`2ZQ5D0ZhEF0:^5E02[QU80[8MB
0P2/Qe040:Z5D@<0ZhIB00<0[8MC0:^6DP2[QU800`2ZQE430:V4D0D0ZhIB0`2ZQE420:J0D@040:R2
D`2YPe@0ZhEF0:b6E`80[XQI0P2/Qe<20:^6DP<0ZXEA00<0ZHA@0:R4D02YQE400P2YQE420:Z6DP80
ZhMC2P2[QU850:Z5D@80ZHA@0P2XPdl0402YQ500ZXEA0:Z5D@2YQ500Z8=?0:N2CP2VP5<0Yh5B0:R2
D`2YPe80ZHA@0:R3CP2WPT/0YX5:0:V4C@2ZQDh20:^6C`040:Z5CP2YQ4d0Z8=<0:N2B`P0Yh9>00H0
ZXAG0:V3E02WPE80YGm>0:F0C02UP4/20:N2B`0<0:YnC@2ZP4h0ZX1>0:Z2C`2WPTh0YH5=0::1C02Q
P4/0Xgi:0:AoB`2VPDd0Z8=?0P2YQ5020:R3C`080:EoDP2VP540YX1A0:N1D02VPDd0Y7m:0:9mAP2P
Nd@20:F0B@030:F0B`2UP4`0YGm>0080YGm@00@0YGmB0:B0D02TP500Y81@0P2SOdl30:9nCPP0Xgm;
00H0YH5?0:B0CP2TP4`0Xh1:0:9oB@2QOTH20:1m@`P0XWi>00<0Xgi:0:AoB`2UP4`00P2VPDd00`2U
P4`0Y7m;0:=nBP020:9nBP<0XGe900/0Xgm;0:F1C@2WPdl0Y85;0:F2C02VPdd0YhA>0:J3C@2UPT`0
Xh1:0:9oB@0209imA`060:5nB02SOTT0YWi:0:MnBP2XOd/0ZGi;202SOTT50:AoB`@0YH1<00P0ZHA?
0:R3CP2VPD`0YH1;0:AoBP2UP4/0YX5<0:N2C@P0XWi:00<0X7]70:5lB02SOTX00`2TOd/01P2SOTX0
XWe90:AoB`2TOd/0Xgi:0:9mB@80XGa80P2PNdL0102TOd/0Xgi:0:5lB02PNdL309mjAP040:1kA`2Q
O4P0XGa80:5lB080X7]70`2ONTH809ijAP0309ahA02MNDD0WWY600<0WWY600/0WGU509ahA02MNDT0
WWY:09mkB`2PO4`0Wg];09ijBP2LN4P0VgM709mjAP0309iiA@<0WGQ400D0W7M309]f@@2LMd80WGQ3
09mjA@030:1kAP0309mjA@2LN4@0W7Q400<0WGU50`2NNTH809ag@`80VgI200@0VWE109Ud@02IM400
V7<o0P2GLSh0102JKd80Vg1309]`@`2KL4<309aaA00409ebA@2GLSh0V7<o09Ud@080VWE100<0VGA0
09Qc?`2GLSh00P2JM4D209UcA0<0V79300<0Ug5209=_?`2CKcl02@2CKcl309A`@0<0UG5100D0Tflo
09A`@02FLT80V7A409UeA@0309YfAP0609Mc@`2FLT80UW9209Ea@@2DL400Tflo1@2BKSh209=_?`<0
U7100P2FKS/0102DKc/0Tflk099^>P2@KcX208m`>PP0SV`n0P2BKD02095/?`<0T6/n00T0SfXm099_
A@2AKT@0T6e308i[@@2=JT00RfPn08YW?@29IS`00`2>JC`208eX>`<0S6Lj0`2@Jch508mZ?@<0S6Ph
:oooool002[ooooo102BIcX01`2AIST0T6Dh091U>02?I3L0U6Tn09=X?@2@ICX00P2?I3T0102@ICX0
TfPm09AY?P2AIST2099W>P80TfPk0P2DJC`00`2EJSd0TVHi099V>@0209=W>P0409AX>`2EJC`0UFTl
09IZ?B00U6Tl0P2BIcX0102CJ3/0U6Tl09AY?02EJSd209I[?P04095V>@2CJ3/0UFXm09I[?P80Uf`o
00H0UV/n09EZ?@2CJ3/0UFXm09I[?P2GK3l209U^@@0309M/?`2FJch0UFXm00<0Ufdk102HKS`01P2I
Kcd0V6e309Q]@`2HKD80V6e009Q^?P80V6hl00@0V6lk09Q^?02HKS`0VFlm1@2JL3h409ab@0@0Vg4o
202NM48209mf@00909ie@@2NM480WWA409icAP2MLTD0WG9709]a?`2LLT00WG=100<0WgE300<0WWA2
09ec@@2QMdD01`2QMdD50:=e@`030:9d@P2QLd40XG=10080WgA10`2PMD830:5f@`P0X7M300P0XWM2
0:5f@@2PMD80WW9109ib@`2PM4L0XGE80:9eB`80XgU70`2RN4H30:5gA@P0XWU5202SNTH20:9hAP80
XgU7102TNTP80:5lA`T0YWe90P2RODP30:5lA`<0X7]6202WOTX01P2UP4/0Y7m;0:=nBP2RO4/0XG]<
0:1jC@80X7U>0P2WOD/30:IlBP<0YG]9202WOTX30:J1C080YH1;0`2TOdX80:QoB`80ZX5900@0ZX5;
0:Z1C@2YP4`0ZGm=0P2YOdl@0:^1C`P0ZH=B00H0[85F0:b1E02/PE@0[H=C0:f3D@2/Pdl20:b3C@P0
[8=?0`2[PTh30:b3C`80[HA@0`2[PDl30:b2D080[H=A202/Pdl0102YOdd0ZX1>0:b2D02^Q5820:n5
D`040:j4DP2]Pe40[XEA0:j5D@H0[HA@2@2[QU880:n6DPP0[HA@202^Q580102/PU00[H=A0:f3D@2^
Q5820:n5D`80/8ID102[QU440:b7DP80[XEA0P2_QU820;27D`80/HQD202^RED20;2;E`H0[hYF202^
RE@60;67E@80/8ID202_RUH80:j8F@@0[XUE102]R5@20;2;E`<0[hYF2`2^RED00`2`ReH0[hYE0:f8
D`020:b7DP030:f8D`2^RE@0[hYE00P0/8]F0`2_RUD20;2;EP<0/HaG00<0[hUJ0;6;G02bS5d00P2c
SEh0102bS5d0/H]L0:n9FP2_REX80;2:F`<0/HaH0P2`ReL30:n:EP80[H]N00<0[hYM0;6;G02cReX0
0P2eReT00`2gS5T0/hUG0;>9E`020;B:F080]H]I0P2fS5X40;:>GP80/HeM0P2`S5`30;6=G@@0/XiN
00@0/hmO0;>?G@2cSed0/hmM0P2dT5h30;FAG`80]I1L0`2fTEd30;NBGPP0^99Q0`2fTE`30;F@F`80
]8mJ202fTEd00`2gTF80]Y1Q0;B>G`030;:<G@030;>=GP2dSUl0/hiJ0080/hiJ0P2dSe/30;F@G080
/hiJ00<0]8mK0;F@G02fTEd00P2gTUh00`2hTel0]HmP0;F?H0040;F?H080]Y1Q0P2dSe/20;F@G080
]Y5M2P2gTUh20;RCG`80]i9N0P2fTEd20;F@G0<0]I5Q0`2fTV820;NCH`D0]Y9R102eTF420;RBH`80
]i5R102fT64:0;NAHP80]Y1Q0P2eSf020;B>G`030;B?HP2eT6<0]Y5T0080]i9U00<0]Y5T0;F@H`2d
Sf80102fTV840;FAH@P0]Y9R00P0]I5M0;JBGP2hU600^IEQ0;RDH02gTel0]Y9N0;FAG@P0]i=O00<0
]i9N0;RCG`2iU6000P2jUF400`2hTel0]Y5M0;F@G0080;B@H0040;VEH@2hU600^9AP0;NCG`80]Y9N
0P2eTEd80;RDH0P0]i=O202gTf<30;JBHP80]i=S0`2hU6@60;NCH@80]Y9P202gTUh01P2kTel0^i=P
0;VDH02gTf40]i=S0;BBI080/i9U2@2gTf<0102kUV80^IAP0;NBGP2eT5`20;B?F`030;F@G02fTEd0
]I5Q00<0]I5Q102fTV880;JBGP80]91N0`2eTEl30;JBH0P0]I5M102dT5h40;FAG`030;B@G02eTEd0
]Y9N0080]i=O00<0]Y9N0;B@G02dT5`00P2fTEd40;F@G080]8mK402cSel20;6=G@060;:>GP2dT600
]I5Q0;JBHP2gTf<0^9AT0`2dT6020;>?G`@0/XiN00L0/hmO0;B@H02eTF40]I5Q0;>?G`2aSEd0/8aL
00<0/XeI0P2cSUX30;B?F`P0/8aL202dSUl20;6<F080/XeI0P2cSUX20;B?F`P0/hmO0P2aSEd20;:>
GP80/hmO00<0]91P0;FAH@2eTF400`2eSf030;B>G`80/heN0P2aSET60;:>FPP0/hiQ0`2cSel20;:>
GP<0/HeM202cSEh;0;6=G@<0/8aL0P2_Re/20;:>FP80/HeI0P2`S5P20:n;E`80/8]G0P2aS5P20;:=
F@@0/hiJ0`2bSET30;6<F080[XYJ102_Re/20;2<G0X0/XiJ0P2aSET20;2<F080[h]G0P2bSUh30;6=
G@<0/8aL00<0[XaL0:f;F`2]Re/0102]Re/00`2^S5`0/8aH0;2<F0060;2<F0<0/8aL0`2_Re/20:j:
FPP0[HUI0P2]RED50:j:EP80[h]G00<0[hYF0;6<F02bSET00P2cSUX00`2bSET0/HaH0:n:EP080:j:
FP<0/8]G0`2_RUH20:j9E@H0[XYJ2P2]RET20:f7F0H0[XQI00T0ZhMG0:b8F02]RET0[XYJ0:n;F`2^
RUX0[8QH0:^7E`2]R5/00P2]RET00`2]REL0[HUE0:f:E0020:f:DP080:n;E`2]RED0ZhMC0:Z6DP2Y
QE40ZXIB0:^7D`2/R5@80:f8E0060:Z4E`2ZQ5D0ZhEF0:^5E02[QU80[8MB0P2/Qe020:V4D0040:Z5
D@2[QU80ZhIB0:b7D`@0[HQD00@0[8MC0:^6DP2ZQE40ZXEA0P2YQ5020:b7D`@0ZhIB0P2ZQE420:N1
DP040:R2D`2YPe@0ZhEF0:b6E`80[HMH0`2[QU830:Z5D@80ZHA@0P2XQ5030:V5D@<0ZXIB202ZQE03
0:^6DP<0ZXEA202YQ5020:R3C`070:N2CP2WPE@0Yh5B0:R2D`2XPU40Z8=?0:R3CP020:N2B`@0ZXE@
00@0ZHA?0:R3CP2XPdh0Yh9=202WPTh02@2ZQ5L0ZH=D0:N1DP2VP4l0YH1<0:J1C02WPT/0Z8=<0:]o
CP020:Z0CP030:V1CP2VPDd0YH5=0080XX5<0P2TOd/00`2UP4`0YX5=0:N2CP030:R3C`080:EoDP2V
P540Yh5B0:N1D02VPDd0Y7m:0:9mAP2QO4D20:J1BP030:J1C02VPDd0YX1?0080YX1A00<0YX1C0:J2
DP2UPE400P2UPE420:B0D080Xgm?202SOd/20:B0CP060:=oB`2ROdT0XGi80:1mA@2POD<0Wga2202R
OT`00`2QO4P0Xgi:0:AoB`020:J1C@030:F0C02TOd/0Xgi:0080XGe90P2PO4P01P2ROTX0Y81<0:J2
CP2XQ500YX9>0:N3C`80Z8A@00@0Yh=?0:F1C@2SOd/0XWi:0P2NODP00`2QODT0XWe90:EmBP020:Mm
B`030:QlB`2SOTT0Xgi900H0Xgi90P2SOTX50:AoB`80YH1<00@0ZhIA0:Z5D02XPdh0YX5<0P2UP4/0
0`2VPD`0Yh9=0:=oB`070:=oB`0409iiA@2PNdL0XWe90:AoB`80YH1<00@0Y7m;0:=nBP2SOTX0Xgi:
0P2RODT20:5lB080X7]70P2RODT00`2QO4P0X7]709mjAP0309mjAPP0X7]7202NNTH509eiA@80W7Q4
00T0VgM309ijBP2ONd/0X7a<0:5mC@2PO4`0Wg];09eiB@2LN4P0102NNDD409ehA080W7M200<0WGQ3
09iiA02ONTD00`2ONTD01P2JMT80VgM309]g@`2LN4@0WGU509ijAP80Wg]7202LMd<0202MN4@0W7M3
09]f@P2JMD40VGA009Qc?`2GLSh0UW4m102JLD<409]bA00309I`?`2GLD00VWA30080VgE400<0VWA3
09Ma@02FL3l00P2ILd@209Qb@`@0Ug522`2CKcl309A`@0<0UG5100H0TFdm099^?P2DL400UG5109Mc
@`2HM4@209UeA@0309Ib@P2ELD40UG510080U7100P2CKcl3099^?P80Tflo0P2DL40209Ea@@80UVhm
00@0U6hm09=_?@2BKS`0T6ll0P2?Kc`208e[?@@0SV`n0P2?KCl3095/?`<0T6/n0P2?JSd0202BKdD0
TFi4091]@`2>Jd40S6To08YW?@29IS`0R6Dk0`2>JC`308eX>`80S6Lj0P2@Jch408mZ?@80SVTl0`2;
IcL[ooooo`00:_ooool0102CJ3/0TVLj095V>@2AIST4091U>00309EZ?`2CJ3d0T6Dj0080SV<h00<0
T6Dj09=X?@2EJSl0102BIcX409=X>`06095U>02BIST0TVHi09=W>P2DJ3/0UFTl0P2FJSdP09AY?004
095V>@2BIcX0TfPk09=X>`80UFXm00D0UV/n09M/?`2AIST0TVLj09=X>`0409EZ?@0509AY?02CJ3/0
U6Tl09I[?P2GK3l00P2HKD000`2GK3l0UV/n09AY?00209I/>P80Ufdk00@0V6hl09U_?@2IKcd0VFlm
0P2HKD<00`2HKD80V6e009Q^?P0209Q^?00309Q_>`2HKS`0V6hl0080V6hl0P2IKcd00`2JL3h0Vg4o
09]a?`0309]a?`@0W790202NM4801@2PMd40WgI009mf@P2NM480WWA40080WG9500T0W75609Y`?P2L
LT00WWA209me@`2PMT@0WgE309id@P2LLT00202QMdD20:9gA0030:5f@`2PMD80WgA100D0WgA10`2P
MD830:5f@`P0XGQ400P0XWM20:5f@@2PMD80WW9109ib@`2PM4L0XGE80:9eB`80XgU70`2RN4H30:5g
A@P0XWU5202SNTH40:9hAP80XgU70P2TNTP80:5lA`T0YWe90P2RODP20:5lA`80X7]60P2ONTD80:Mn
BP060:=nB@2SOTX0Xgi:0:=mC02RO4d0XG]>0P2PNDh30:IlBP<0YG]90P2TNTP80:MnBP<0YX5<0P2U
P4/30:AoBPP0Z7m;0P2YP4P0102YP4X0ZH1<0:V0C02YOdd20:UoC`P0Zh5?202ZP4h80:V4D0080:b1
EP2[P5<0Zh1C0:^1D@2[PDl0Zh9>0:^2C02/Pdd80:b3C`<0Zh9>0`2/Pdl20:f4D0<0Zh5?0`2/PU02
0:f3D@P0[8=?00@0ZGm=0:Z0CP2/PU00[XAB0P2_QE<0102^Q580[H=A0:b3C`2/Pdl60:f4D0T0[8MC
202^QE480:f4D0P0[XAB0P2/PU000`2]Pe40[XAB0:n5D`020;26E0030;67E@2[QU40ZhIA00H0ZhIA
0P2^QE420:n6DP80/8MC0P2aR5@:0:j9E@H0[hYF202^RE@20;26E0H0/HME202_RUH80:j8F@P0[XUE
0`2`ReL30:n:EPX0[XUE00<0[hYE0:j9E02]R5<00P2/Qe800`2]R5<0[hYE0;2;EP080;6<E`80[hYE
0P2`ReH20;6<E`80/XeH00<0/8YK0;6;G02bS5d00P2dSUl0102bS5d0/H]L0;2:F`2`RU/80;6;G080
/XeI0P2aS5P20;2;E`80[hYF00D0[H]N0:j<G`2`Reh0/XaM0;B<F`020;J<FP030;N<F@2cREL0/hUG
0080]8YH0P2eReT20;J<FP<0/hmO0`2bSUh20;6=G@80/8aL0P2aSEd00`2bSUh0/hmO0;>?G`030;>?
G`80]91P0P2eTF420;JBHP<0]Y5M0`2gTUh20;RCG`P0^99S0`2fTE`30;F@F`80]8mJ202eT5`0202g
TF80]Y1Q0;B>G`2cSEh0/XaM0;>=GP2dSUl0]HmP0`2cSUX20;B?F`<0]I1L0P2cSUX00`2dSe/0]I1L
0;JAG@020;NBGP030;RCG`2fT640]Y1Q00H0]HmP0`2dSe/20;F@G0<0]Y5M202gTUh20;RCG`80]i9N
0P2fTEd20;F@G080]91P0`2eTF430;JBHPD0]I5Q102fTV840;NAHP80]Y1Q0P2eSf0;0;J@H@80]HmP
0`2dSUl00`2dSf80]I1S0;JAI0020;NBI@030;JAI02eT6<0]8mR00@0]I5Q102fTV880;JBH0080;FA
G@2fTUh0]i=O0;RDH02iUF40^9AP0;JBGP2eTEd80;NCG`080;NBGP2hTel0^IAP0;ZEH@2iU600^9=O
0;JAG@2dSe/80;B@H080^IEQ00<0^9AP0;NCG`2fTUh00P2eTEd00`2dT5`0^9AP0;RDH0060;RDH0P0
]i=O202gTf<20;FAH@80]Y9R0P2gTf<20;RDI080]Y9R1P2gTf<80;NBGP080;^CG`2jTUl0^9=O0;NC
H@2fTV80]99T0;>BI@2bTF@90;NCH`040;^FHP2iU600]i9N0;F@G080]8mK00@0]I1L0;JAG@2dT600
]91P0P2eTF420;JBHP80]i=S202fTUh30;FAH@<0]Y9R0P2gTf<80;B@G0P0]91P00<0/hmM0;B@GP2f
TV000P2hU6800`2gTf40]I5O0;B@GP020;NBGP80]Y5M0P2eT5`20;B?F`P0/hmO202cSed20;6=G@06
0;:>GP2dT600]I5Q0;JBHP2gTf<0^9AT0`2dT6020;>?G`@0/XiN00L0/hmO0;B@H02eTF40]I5Q0;>?
G`2aSEd0/8aL0080/HaH0P2bSET20;>>FP80]8mK202`S5`80;B>G`<0/XeI0P2cSUX30;B?F`P0/hmO
0P2aSEd20;:>GP80/hmO00<0]91P0;FAH@2eTF400P2eSf030;B>G`<0/heN1P2bSUX20;6=F@P0/hiQ
0P2cSel20;:>GP80/HeM0P2`S5`80;>=GPP0/8aL0P2bSUh30;6=G@<0/8aL0P2bSUX20;6=F@80/8aH
0P2_ReL20;2;E`80/HaH0P2bSET20;>>FP<0/XeI0`2aS5P20;2;E`80[XYJ0P2_Re/20;2<G080/HeM
202bSUX40;6=F@@0/8aH0`2aSEd30;2<G080[h]K0`2]Re/20:j<G0<0[H]K202_ReL30;2<G0<0[h]K
0P2^RUX80:f9F@030:b8E02]RED0[HUE00<0[XYF0P2_ReL0102`S5P0/8]G0;6<F02bSET20;B?F`03
0;:=F@2aS5P0/8]G00P0[XYJ0P2`ReL30:n:EP<0[XUE1P2^RUX20:n;F`P0[HUI1P2^R5T20:f7F009
0:^7E`2/R5P0[XYJ0:n;F`2^RUX0[HUI0:b8F02[QeL0[HQK0080[HUI00<0[HUG0:f9E@2]RU@00P2]
RU80202_ReL0[HUE0:^7D`2ZQU80ZHEA0:Z6DP2[Qe<0[8QD202]R5@01P2ZQ5L0ZXAE0:^5EP2[QE@0
ZhIB0:b7DP80[8M@00D0ZHA@0:Z5D@2ZQE40ZhIB0:b7D`020:f8E0<0[XUE00<0[HQD0:b7D`2[QU80
0P2ZQE400`2YQ500[HQD0:f8E0020:b7D`80ZhIB0P2ZQE420:^5EP@0ZXAE0P2YPe@20:^6DP<0ZXEA
0`2YQ5030:R4D0<0ZHEA0P2ZQU880:V4C`80ZhIB1@2ZQE420:V4D0040:^6DP2ZQE40ZHA@0:V4D0@0
Z8=?00H0Z89E0:R2D`2WPE80Yh5@0:N2CP2WPTd20:R3C080ZXE@00<0ZHA?0:R3CP2XPdh00`2XPdh8
0:R3C`090:^5F02ZQ5D0Z89C0:J0C`2VPDd0YX5<0:N2B`2XPd`0[81?0080ZX1>00<0Z81=0:J1C@2T
P4`00P2RPD`30:AoB`060:F0C02VPDd0Yh9>0:R3C`2YQ500YX1C0P2WPE801@2XPU40Yh9>0:F0B`2R
ODH0XGa50080YX5:00<0YX5<0:J1C@2VP4l00P2VP5400`2VP5<0YX9B0:J2DP030:F1D@<0Y81@202S
Od/01P2TP4h0Xgm=0:=oB`2ROdT0XGi80:1mA@80Wga2202QODT0202PNdL0XGa80:=nBP2UP4`0YX5=
0:F0C02TOd/0Xgi:0P2QODT20:1lB0060:9nBP2TP4`0YX9>0:R4D02VPU00Yh=A0P2XQ5802@2WPe40
YH5?0:=oC@2ROT`0WWe:09mnB`2QOD/0XWa;0:AlB`020:IlC0030:MkC02RODP0XWe800H0XWe80P2R
ODT20:=nBP<0Y7m;0P2UP4`01@2[QU40ZHA?0:N2C@2UP4/0Y7m:0080YH1;00<0YX5<0:=oB`2SOd/0
1P2SOd/0102NNDD0X7]70:9mB@2TOd/20:F0C0040:AoB`2SOTX0XWe90:9mB@@0XGa81`2PNdL209mj
AP0309iiA@2PNdL0X7]700H0X7]72P2NNTH00`2MNDD0W7Q409]g@`0309]g@`0309eiB@2NNTX0Wg];
0080X7a<00<0WWY:09ahB02KMdL0102MN4@409iiA@D0WGQ30P2NND@01P2ONTD0VWI209Yf@P2KMd<0
W7Q409eiA@80WWY600<0Wg]709ag@`2LMd<01P2LMd<209ehA00409ag@`2KMT80VGA009Qc?`80Ug8n
102ILd@409Qb@`0309I`@@2GLD80VWA50080VgE600<0VWA509Ma@P2FL4400P2HLT<309Ma@P<0UW11
202BKSh309=_?`<0U7100`2ELD4208m[>`04091/?02AKCd0TVhn09=_?`80UG51102DL40709=_?`80
U7100`2ELD4209M^@00409A^?`2CKcl0TVhn091^?P80SVhm00<0S6Xl08e[?@2=Jcd00P2>K3h208m]
?`03091^@02AK3l0TF`o00<0T6/n0`2?JSd0202AKT@0T6e308m/@P2=JT00S6To08YW?@29IS`0R6Dk
0P2?JSd308iY?0<0SFPk0P2@Jch208mZ?@80SVTl0P2=J3/308]W=b_ooooo000Zooooo`80U6Tl00<0
TVLj095V>@2@ICP00P2AIST0102BIcX0U6Tn09=X?@2@ICX208mT>@03091U>P2CJ3d0U6Tn00P0TVLj
0P2BIST209=W>P0409AX>`2EJC`0UFTl09IZ?@P0U6Tl0`2EJSd209AY?0<0TfPk202DJC`809=X>`80
TVLj00@0TfPk09AY?02DJC`0UFXm0P2FJch2095V>@05099W>P2CJ3/0TfPk09=X>`2DJC`00P2CJ3/0
0`2DJC`0UFXm09M/?`0209Q]@00409M/?`2EJSd0U6Tl09E[>@80UV`j00<0Ufdk09Q^?02IKcd00P2J
L3h209Q]@`0309Q]@P2HKD00V6hn0080V6hl00X0V6lk09M]>`2GKC/0UV`j09M]>`2HKS`0VFlm09]a
?`2LLT00VW0n0`2KLCl309ab@00309ec@@2OMD<0WgE300H0WgE30P2PMd403P2OMT80WWA209idA02M
LTD0W75409aaAP2JL3h0W79009me@`2QMdD0XWQ60:1fA02NM480WG=10`2OMD<20:1fA0<0XGM500<0
XgY60:9iA@2PMd<00P2NMD400`2MM400WWE109ie@@0209md?`<0X7E00`2QMT480:5hA0080:9g@P2Q
MT40X7E209ib@@2NLT<0X7A70:5eB02RMD/20:=iA`<0XWQ60`2QMdD80:9iA@P0XgY60P2RN4H30:5g
A@030:9hAP2TNTP0YG]900P0XGa82@2VODT20:=nB@80XWe800@0XGa70:1kAP2ONTD0WgY5202VODT0
202RODP0XWe90:=nBP2TOTd0Y7i?0:AnD@2SO540XW]@0`2VO4X20:EkB@<0Y7Y8202WOTX30:J1C080
YH1;0`2TOdX30:V0BP80Z7m90`2WOTP0202WOTH0Z7m70:QoB@2XOd/0ZH1<0:UoC@2YOdl0ZX1@202[
PDl80:Z0CPP0ZHA?00P0[85F0:^0D`2ZOe80ZGm?0:UoC@2ZPDd0Zh9<0:b3C@P0[8=?0`2[PTh30:b3
C`80[HA@0`2[PDl30:b2D080[H=A202/PU000`2ZP4h0Zh5?0:f3D@020:n5D`030:j4DP2]Pe40[89@
0080Zh9>0P2/Pdl40:f4D0T0[8MC202^QE430:b3C`80[HA@0`2^QE480:j4DP040:b2D02]Pe40[H=A
0:j4DP80[hEC0P2`QU@0102/Qe80ZhIA0:^6D@2[QU430:Z5D0030:V4C`2^QE40[XEA0080[hIB0P2`
Qe<20;68E0P0[XUE0P2]R5@20:j9E@@0[hYF202^RE@30;26E0<0/HME0P2bR5H30;2;E`80[hYF0`2^
RED80:j8F@040:f8E02^RED0[XUE0:j9E@<0[hYF00<0/8]G0;6<F02aS5P00P2`ReL30:n:EPT0[XUE
0P2^RE830:b7D0030:j9DP2_RU<0/HaE00P0/HaG0`2`ReH20;6<E`<0/XeH00<0/8YK0;6;G02cSEh0
0P2dSUl0102cSEh0/H]L0;2:F`2`RU/80;6;G0<0/XeI0P2aS5P30;2;E`050:f;GP2^S5l0/HaO0;>=
GP2fSUd00P2fS5X00`2fReP0/hUG0;>9E`020;B:F080]H]I0P2fS5X30;B@H080/hmO0`2bSUh01P2_
Re/0/8aL0;2<G02aSEd0/XiN0;>?G`80]91P0`2dSf820;F@H`<0]Y5T0`2fTEd20;NBGP<0^9=O202h
TVD30;JAG0<0]I1K0P2dSeX80;F@G0030;RBH`2fT640]HmP00<0/heN00<0]8iO0;F?H02cSUX00P2c
SUX20;B?F`<0]I1L0P2cSUX00`2dSe/0]I1L0;JAG@020;NBGP040;RCG`2fT640]Y1Q0;J@H@<0]HmP
0P2dSUl0102cSUX0]8mK0;B?F`2dSe/20;F@G080]Y5M202gTUh20;RCG`80]i9N0P2fTEd20;F@G0<0
]91P0P2eTF430;JBHP80]91P0`2eTF430;JBHP030;NCH`2fT640]Y1Q00<0]i5R00<0]Y1Q0;B>G`2c
SEh02P2fT6420;F?H0<0]8iO00@0/heN0;B?HP2eT6<0]Y5T0P2gTVD0102fTF@0]I1S0;B?HP2dT603
0;FAH@<0]Y9R00<0]i=S0;JBGP2fTUh01P2fTUh0202dT5`0]I5M0;NCG`2hU600^IEQ0;RDH02gTel0
]Y9N202gTel00`2fTEd0]i9N0;RCG`020;VDH0030;NBGP2eT5`0]8mK00P0]91P00@0^IEQ0;RDH02h
U600]i=O0P2fTUh20;FAG@P0^9AP202gTel80;NCH`<0]I5Q0P2fTV830;NCH`<0]Y5T0`2gTVD20;RC
IPP0]i9N00H0^I5M0;VAGP2gTUh0]Y9P0;JBHP2dTV@20;>BI@T0]Y9R00<0^IAP0;RCG`2fTEd00`2e
T5`00`2fTEd0]i9N0;FAH@030;FAH@@0]Y9R202fTUh30;F@H`80]Y5T0`2gTVD80;B@G0040;F@H`2d
Sf80]8mR0;B?HP<0/hiQ00@0/XeP0;:>GP2dT600]i=S0P2iUFD00`2hU6@0]Y9R0;B@H0020;RCG`04
0;NBGP2fTEd0]I1L0;F@G080]8mK202bSUh80;B@G080/XiN00@0/hmO0;B@H02eTF40]I5Q0P2fTV83
0;B@H080/hmO102bSUh01`2cSel0]91P0;FAH@2eTF40/hmO0;6=G@2`S5`00`2aS5P20;:=F@<0/hiJ
202`S5`80;B>G`80/XeI0P2cSUX30;B?F`040;F@G02bSUh0/XiN0;:>GP80/hmO0`2dT6040;:>GP80
/hmO0`2dT600102eSf00]8iO0;B>G`2dSUl20;>=GP80/XaM0P2cSe/30;:>FP<0/HeI202cSV430;:>
GP80/HeM0`2`S5`80;>=GPP0/8aL0`2bSUh20;6=G@<0/8aL0P2`SeX20:n>F@80[XeH0P2]S5L20;2;
E`80/HaH0P2bSET20;>>FP<0/XeI0P2aS5P30;2;E`80[XYJ0P2_Re/0102`S5`0/HeM0;:>GP2bSUh8
0;:>FP@0/HeI102`S5P30;6=G@80/8aL0`2_Re/00`2/RUX0[H]K0:j<G0020:n=G@030:j<G02]Re/0
[8YJ00P0[h]G0`2`S5`30:n;F`80[XYJ202]RET20:b8E0050:f9E@2^RUH0[XYF0:j:EP2_ReL00P2`
S5P00`2`ReL0/HaH0;>>FP020;B?F`030;>>FP2aS5P0/8]G00P0[XYJ00@0/8]G0:n:EP2_RUH0[hYF
0P2^RED20:f8E0@0[XYJ0P2_Re/20;2<G0P0[HUI0P2_REX30:j8F@<0[HMH00T0[8QH0:f9F@2^RUX0
[h]K0:j:FP2]RET0ZhMG0:Z6EP2/QeX00P2/R5P00`2/R5H0[8QD0:b9D`020:b9D@080:n;E`2]RED0
ZhMC0:Z6DP2YQE40ZXIB0:^7D`2/R5@80:f8E0060:Z4E`2ZQ5D0ZhEF0:^5E02[QU80[8MB0P2/Qe03
0:^6DP<0[8MC0P2]R5@0102^RED0[HQD0:f8E02]R5@40:b7D`80[XUE00@0[HQD0:b7D`2[QU80ZhIB
0P2ZQE420:b6E`040:^5EP2ZQ5D0ZXAE0:V3E080Z89C00@0ZhIB0:Z5D@2ZQE40ZXEA0P2YQ5020:R3
C`80Yh=?0P2XQ5030:V5D@030:Z6DP2ZQDh0ZXE>00H0ZXE>0`2YQ5030:Z5D@<0ZhIB00@0[8MC0:^6
DP2ZQE40Z8=?0`2WPTh0302XPdl0ZH=F0:R2D`2WPE80YX1?0:J1C@2WPTd0Z8=<0:V4C@2[QU80ZXEA
0:R3C`<0Yh9>2P2XPdl03P2[QEP0ZXAE0:R2D`2WPE00YX5=0:N2C@2XPd`0ZHA=0:f1D02[PDl0ZGm=
0:MoC02UP4`0Y81<0P2SPTd40:AoB`0<0:F0C02VPDd0Z8=?0:V4D02VP5<0Yh5B0:R2D`2XPU40Yh9>
0:F0B`2SOTL0XGa50P2UP4T00`2UP4/0YH1<0:EoCP020:EoD0040:EoDP2UPE40YH5A0:F1D@80Y81@
0`2SOdl80:9nBP80Xgm=00H0XWi:0:5nB02PODL0Wga409ml@P2NNd480:5nB00409mjAP2PNdL0Xgi:
0:AoB`80YH1<0P2TOd/20:9nBP<0XGe900/0Xgm;0:F1C@2WPdl0Y81@0:F1D@2VPU80Yh=C0:J2DP2U
PE40Xgm?0:9nCP0209mmC@030:5mC@2RO4d0Y7]=0080YGY=00<0YWY=0:9mB02RODP01P2RODP20:5l
B0030:9mB@2SOTX0Y7m;0080Y7m;0P2UP4`00`2XPdh0Yh9=0:F0B`020:=nB@030:AoBP2UP4/0YX5<
00P0Xgm;00<0X7]70:5lB02SOTX00`2TOd/00`2SOTX0XWe90:5lB0040:5lB0<0X7]700<0WWU509mj
AP2PNdL00P2QO4P00`2PNdL0WgY609iiA@0309mjAP80X7]70`2QO4P809ijAP0409mkA`2NNTH0WGU5
09]g@`<0VWI200X0VgM309ahB02MNDT0WWY:09mkB`2NNTX0WGU909]gA`2JMTH0W7M30`2MN4@309ii
A@0309mjAP2NND@0WGQ300@0W7M200<0WGQ309iiA02KMd<00P2KMd<309ahA080WGU5202LMd<01@2M
N4@0W7M309ag@`2KMT80VWE10080VGA000<0V7<o09UeA@2HM4@00P2HM4@309Mc@`0409Ib@P2GLD@0
V79509UcAP80VWA700<0VG=609QbA@2GLD@00`2GLD8209I`@@<0UFm0202BKSh309=_?`<0U7100`2E
LD42091/?00608m[>`2>JSX0Sf/k091/?02AKCd0TVhn2P2CKcl209A`@0<0UG5100T0UW9209Q_@`2G
KT80UFm209=^@@2BKD00Sfdo08i^?`2=KCh00P2<JS`0102=Jcd0SV`n08i/?P2?KCl2091^@004095/
?`2@Jch0T6/n091[?P80SfXm0P2>JC`208i[@@80SFY000@0S6To08]X?P2:Icd0RVLm0`2?JSd208iY
?0<0SFPk0P2@Jch208mZ?@0408iY?02=J3/0S6Lj08aW>P<0RVHf:oooool002[ooooo00P0Uf`o09EZ
?@2CJ3/0TVLj095V>@2BIcX0TfPk09AY?080TVLl102AIS/2099W?0D0TVLj0`2AIST309=W>PD0U6Pk
202DJC`00`2FJch0UFXm09EZ?@0209AY?080TfPk00<0TVLj09AY?02DJC`01P2DJC`:09=X>`@0U6Tl
0P2EJSd3095V>@<0TVLj0`2CJ3/00`2DJC`0UFXm09I[?P0209M/?`0309I[?P2EJSd0U6Tl0080UF/i
00H0UV`j09M]>`2HKS`0VFlm09Y`?P2KLCl209Q]@`0309Q]@P2HKD00V6hn0080V6hl00T0V6lk09M]
>`2FK3X0UV`j09E[>@2GKC/0VFlm09]a?`2MLd400P2JL3h209]a?`80W7900P2MLd4809me@`050:5h
@P2PMd40X7M309me@`2MLd<00P2LLD@0202KL4D0Vg4o09ec@@2QMdD0XgU70:AjB02RN4H0WgE30`2M
Ld4209id@P80WgE30P2PMT@0102SNdL0XGU509mg@`2MMD4209ad@080WGE10P2OM3d30:1e?P<0XGHo
202RNDD0202RMd80XGI10:1e@P2NLT40WW930:1dA`2QMDP0XWE;0P2SNDL30:9hAP<0XGM5202RNDD8
0:=jAP030:=iA`2RN4H0X7I40080X7I400<0XWQ60:AjB02UNdT0202QNdX90:ImB@80YH1;00H0Y7m:
0:=nB@2RODP0XGa70:1kAP2ONTD80:ImB@090:1kAP2RODT0Y7m;0:J0C`2WPE80Yh5D0:IoE02UOU<0
YWa:00<0YG]90P2TNTP20:=iA`P0Ygi:0`2VPD`20:F0B`<0Y7m:00<0ZX590:V0B02YP4P00P2XOdL2
0:MnAP070:ImA@2WOTH0Ygi60:MnB02XOd/0ZH1<0:UoC@020:Z0D0P0Zh5?202YOdd80:V4C@080:b1
EP2ZOe80ZGiA0:QnCP2XOT`0ZH1<0:Z1B`2/Pdd80:b3C`<0Zh9>0`2/Pdl20:f4D0<0Zh5?0`2/PU02
0:f3D@P0[89B00<0[89@0:f3D@2^Q5800P2_QE<0102]Pe40Zh5?0:Z0CP2ZPDd20:^2CP80[8=?0P2]
Q5000`2^QE40[8MC0:b7D`070:b7D`P0[HA@00<0Zh9>0:b3C`2/Pdl00P2]Q5020:j5D@030:n6DP2^
Q580[XAB00/0[XAB0`2_QE<20:b7DP80ZhIA00@0ZXE@0:V4C`2YQ4l0ZHA?0P2^QE420:n6DP80/8MC
0P2aR5@80:j9E@030:b7D`2]R5@0[HQD0080[XUE0P2_RUH00`2`ReL0[XUD0:j9E0060:j9E080[hEC
0P2`QU@01@2aQeD0/XQF0;:8EP2bR5H0/HaH0080/8]G0P2_RUH20:j9E@030:f8E02^R5T0[XQI00H0
[XQI0P2]R5@20:j9E@040:n:EP2`ReL0/8]G0;2;E`<0/HaH0P2`ReL;0:n:EP030:j:D02]RDl0[8Q>
0080[8Q>00<0[XY@0;2<DP2aSE<0202aS5L20;2;EP80/HaG102bSEP00`2aRe`0/XaM0;>=GP020;B>
G`030;>=GP2bS5d0/H]L00T0/H]L102bSET20;6<F080/8]G00P0[8YM0:j<G`2bSF00]8iO0;N?GP2g
SE/0]XaJ0;J;F080/hUG0P2dRUP20;F;F@80]XaJ0`2eTF420;B@H0<0/hmO0P2_Re/01P2`S5`0/HeM
0;:>GP2cSel0]91P0;FAH@80]8mS0P2eT6@40;JAI@040;JAG@2gTUh0]i9N0;NBGP80^9=O0P2iU608
0;RAIP<0]Y5L0`2eT5/20;B?FPP0]8mK00<0^99S0;NAHP2eSf000P2cSEh00`2dSUl0]HmP0;J@H@03
0;>>FP80]8mK0`2eT5`20;>>FP030;B?F`2eT5`0]Y5M0080]i9N00<0^9=O0;NAHP2gTF800P2fT640
102eSf00]8iO0;B>G`2dSUl20;>>FP<0]8mK0`2eT5`80;NBGP80^9=O0P2gTUh20;JAG@80]I1L0P2c
Sel20;B@H0<0]I5Q00@0]Y9R0;B@H02dT600]91P0P2eTF420;JBHP80]i=S00P0]HmP0;J@H@2gTF80
^99S0;NAHP2fT640]8iO0;:<G@/0]HmP0`2dSUl20;>=GP030;B?HP2eT6<0]Y5T0080]i9U00<0]Y5T
0;F@H`2dSf800P2dT6020;FAH@80]Y9R0P2gTf<80;JBGP060;>?F`2eTEd0]i=O0;RDH02iUF40^9AP
2P2gTel0202fTEd0]i9N0;RCG`2iU600^9=O0;NBGP2eT5`0]8mK202dT6050;NCG`<0]Y9N202hU608
0;NCG`P0]i=S102eTF420;JBHP80]i=S0P2eT6@20;JAI@040;NBIP2hTfL0^9=W0;RCI`P0]i9N00H0
]hmK0;N?G02eT5`0]I5O0;JBHP2eTfD20;FDI`T0]Y9R00<0]i9N0;JAG@2eT5`00P2eT5`00`2fTEd0
^9=O0;VDH0040;JBHP@0]I5Q202fTUh0102eT6@0]Y5U0;JAI@2fTFD20;NBIP80^9=W202cSe/20;F@
I080]8mS00`0/hiR0;:=H@2bSF40/XeQ0;6=G@2dT600]i=S0;ZFIP2kUfL0^IEU0;JBHP2dT6020;VD
H0060;RCG`2gTUh0]Y5M0;F@G02dSe/0/hiJ202bSUh80;B@G0L0]91P00@0]I5Q0;B@H02dT600]91P
0P2cSel40;:>GP070;>?G`2dT600]I5Q0;FAH@2cSel0/HeM0;2<G0040;6<F080/XeI0P2cSUX80;6=
G@P0]8iO0`2cSUX30;B?F`80]I1L00<0/HeM0;:>GP2bSUh00P2cSel20;B@H0030;FAH@2dT600]91P
0080]91P0P2cSel30;:>GP<0]8iO0P2cSEh30;:<G@<0/hmK00<0/XiJ0;6=F@2aSET00P2`S5P80;>>
H@80/XiN0P2aSEd40;2<G0P0]8iO202_Re/20;>?G`80/XiN0`2aSEd00`2`S5`0[i1J0:n@FP020:j?
F@80[HiH0P2/SEL20;2;E`80/HaH0P2bSET20;>>FP040;:=F@2aS5P0/HaH0;6<F080/8]G0P2_RUH0
1P2]RET0[XYJ0:n;F`2`S5`0/HeM0;:>GP80/hmO202bSUX40;2<F0@0/HeI00@0/HeM0;2<G02`S5`0
/8aL0P2_Re/20:j:FP030:^9F@2/RUX0[XaL0080[heM00<0[XaL0:b:FP2[RET0202^RUH30;2<G0<0
[h]K0P2^RUX80:f9F@030:^7D`2/R5@0[8QD0080[HUE00L0[h]G0;2<F02`S5P0/HeI0;6<F02bSET0
/hiJ0080]8mK00<0/hiJ0;:=F@2aS5P0202^RUX30:n:EP80[XUE0`2]R5@00`2]RET0[XYJ0:j:FP02
0:n;F`80/8aL00<0/HeM0:f9F@2]RET01P2]RET30:n9FP030:j8F@2]QeP0[HMH0080[8IG0P2]RET0
1`2^RUX0[h]K0:j:FP2]RET0ZhMG0:V5E@2/QeX00P2/R5P00`2/R5H0[8QD0:b9D`020:b9D@080:n;
E`2]RED0ZhMC0:Z6DP2YQE40ZXIB0:^7D`2/R5@80:f8E0060:Z4E`2ZQ5D0ZhEF0:^5E02[QU80[8MB
0P2/Qe030:f8E0<0[8MC0P2[QU80102/Qe<0[HQD0:f8E02]R5@40:j9E@80[hYF00H0[XUE0:f8E02/
Qe<0ZhIB0:Z5D@2YQ5020:R2D`040:V3E02ZQ5D0ZXAE0:^5EP80[8IG0`2ZQE420:V4D0<0Z8=?0`2W
Pdl20:R4D0<0ZHEA202[Qdd0102VPDd0Yh9>0:R3C`2YQ5020:^6DP070:b7D`2]R5@0[XUE0:j9E@2/
Qe<0ZXEA0:N2CP020:J1C@0=0:N2CP2XPdl0ZH=F0:R2D`2WPE80YX1?0:J1C@2WPTd0Z8=<0:V4C@2[
QE@0ZXAC0:R2D@030:J0C`030:N1D02XPU40ZHA@00L0ZHA@0180[8II0:Z4E@2XPU<0Yh5@0:J1C@2W
PTd0Z8=<0:V4C@2]PE00Zh5?0:UoC@2WOd`0Y7m;0:B0C02SPTd0Y8=>0:F0C02TOd/20:=nBP0<0:Ao
B`2VPDd0Z8=?0:Z5D@2WPE@0Yh5B0:R2D`2XPU40Yh9>0:F0B`2SOTL0XWe60P2SOTL00`2SOTT0Xgi:
0:=mC0020:=mCP040:=mD02TP500Y81@0:B0D080Xgm?0`2ROTh80:9nBP80Xgm=00@0XWi:0:5nB02P
ODL0Wga40P2NNd480:1mA@0409iiA@2PNdL0XWe90:AoB`80YH1<0P2TOd/00`2TP4`0Xgm;0:9nBP02
0:5mB@060:9nBP2TP4`0YH5=0:1lC02ROTh0Xgm?0`2UPE401`2SOdl0XWi>09mmC@2OODd0XGe=0:9l
C@2SNT`00P2TND`00`2UND`0XGa70:5lA`060:5lA`80X7]700<0XGa80:9mB@2SOTX00P2TOd/02P2U
P4`0YX5=0:AoBP2SOTT0XWe80:5lA`2RODP0Xgi90:F0B`2VPD`80:B0C0030:9mB@2SOTX0Y7m;0080
Y7m;00<0Xgi:0:5lB02PNdL01P2PNdL20:5lB00309ehA02NNDD0X7]70080XGa800@0X7]709mjAP2M
N4@0WWU50P2ONTH20:1kA`80XGa800<0XWe909ijAP2NNTH01P2NNTH0102PO4P0Wg]709ahA02JMT82
09Ue@@0:09Yf@P2KMd<0VWI609]gA`2LN4P0WGU909ahB02KMdL0VGE509QdA080W7M30P2MN4@209ii
A@80WgY600P0WgY509iiA02LMd80VgI109Ye@02KMT40WGQ309iiA0@0W7Q4102KMd<809ag@`P0VgI2
0P2GMDD209IdA080UG=30P2DLT800`2JLdP0VG9709QaAP0209M`A@0309QaAP2ILTL0VW=800<0UW11
0P2EKd0309A^?`P0TFdm0`2CKcl309A`@0@0UG5100L0U710099^?P2@K3`0T6`l095]?@2BKSh0Tflo
00<0TVhn1@2CKcl309A`@0<0UG510P2FLT8209Q^A00409E^@`2CKT80TVe108m]@080SF`o00D0RfTk
08aZ?02<JS`0SF/m08m]?`02091^@004095_@@2@Jch0T6/n091[?P80SfXm0`2>JC`808aY?`80T6/n
0P2?JSd308iY?00708eX>`2AK3l0T6/n08mZ?@2>JC`0SFPk08aW>P0208]V>@<0RFDe:oooool002[o
oooo00P0V6e009I[?P2DJC`0TfPk099W>P2CJ3/0U6Tl09I[?P80TFHk102BIc`2095V>`@0TVLj102A
IST609AX>`80TfLj202DJC`209I[?P0409EZ?@2DJC`0U6Tl09=X>`80TVLj202DJC`809=X>`P0U6Tl
1P2AIST01P2BIcX0TfPk09=X>`2CJ3/0UFXm09I[?P80Uf`o00<0UV/n09EZ?@2CJ3/00P2EJcT00`2F
K3X0Ufdk09Q^?00209Y`?P0609]a?`2HKD<0V6e309Q]@P2HKD00V6hn0P2HKS`00`2HKc/0Ufdk09I/
>P0209E[>@0409I/>P2IKcd0Vg4o09ec@@<0VW0n00<0Vg4o09ab@02MLd400P2MLd4809me@`80XGQ2
00T0X7M309me@`2MLd<0W75409]`@`2KL4D0W79009id@P2RN4H00P2UNdT00`2SNDL0X7I409id@P03
09ab@00309ec@@2NM480WgE30080WgE300H0Y7a80:9jAP2OMd<0WGE109]c?`2LM40209ee@@80Wg@m
0`2PMCh30:5f?`P0XWU500P0XWM20:5f@@2PMD80WW9109ib@`2PM4L0XGE80:9eB`80XgU70`2RN4H3
0:5gA@P0XWU5202SNTH0202SNDL0XWQ60:1fA02OMD<0X7I40:9hAP2TNTP0YG]9202QNdX90:ImB@80
YX5<00@0YH1;0:AoBP2RODP0XGa70P2PNdH80:ImB@0809mjA@2QO4P0Y7m;0:N1D02YPe@0ZH=F0:R1
EP2WP5D40:EkB@80Y7Y80P2SNDL80:MnBP<0YX5<0P2UP4/30:AoBP80ZX5900@0ZH180:QoA`2XOdL0
Ygi6102VODD0102WOTP0Z7m;0:QoB`2YOdd20:Z0D0P0Zh5?202YOdd80:V4C@080:b1EP2ZOe80Z7e@
0:MmC@2WOD/0Z7m;0:Z1B`2/Pdd80:b3C`<0Zh9>0`2/Pdl20:f4D0<0Zh5?0`2/PU020:f3D@P0[89B
00P0[H=A0:j4DP2_QE<0[hEC0:j4DP2/PU00ZX1>0:UoC@80ZX5=0P2[PTh0102/Pdl0[HA@0:f4D02^
QE490:b7D`P0[HA@0P2[PTh0102/Pdl0[HA@0:f4D02^QE420:n6DPP0[XAB0P2_QE<60:j4DP80[8MB
00@0ZhIA0:Z5D02ZQE00ZHA?0P2XPdh20:j5D@80[hIB0P2`Qe<20;68E0P0[XUE0P2/Qe<20:f8E004
0:j9E@2_RUH0[hYF0;2;E`P0[XUD0P2_QE<20;26E0040;67E@2bR5H0/XQF0;>9E`80/HaH00@0/8]G
0:n:EP2_RUH0[XUE0P2]R5@80:j8F@80[HQD00@0[XUE0:n:EP2_RUH0/8]G1@2aS5P30;2;E`X0[hYF
00<0[XY@0:f9C`2/R4h00P2/R4h00`2^RU00/8aB0;6=D`080;6<E`80/8]F0P2aS5L30;:=F0040;>>
F@2aRe`0/XaM0;>=GP80]HmP00<0/heN0;:<G@2aRe`02@2aRe`0102cSUX0/XeI0;:=F@2bSET20;6<
F080/8]G00P0[8YM0:j<G`2bSF00]HmP0;N?GP2gSE/0]XaJ0;J;F080/hUG0P2dRUP20;F;F@80]XaJ
0`2eTF420;B@H0<0/hmO0P2_Re/00`2`S5`0/HeM0;:>GP020;B@H0030;FAH@2dSf<0]8mS0080]I1T
0`2fTFD00`2gTVH0]i9N0;NBGP020;NBGP80^9=O0P2iU6080;RAIP<0]Y5L0`2eT5/20;B?FPP0]8mK
00P0^99S0;NAHP2eSf00]8iO0;>=GP2dSUl0]HmP0;J@H@<0/hiJ0P2dSe/30;F@G080/hiJ00<0]8mK
0;F@G02fTEd00P2gTUh00`2hTel0]i5R0;NAHP020;J@H@040;F?H02dSUl0]8iO0;>=GP<0/hiJ0P2d
Se/30;F@G0P0]i9N0P2hTel20;NBGP80]Y5M0P2eT5`20;>?G`80]91P102eTF440;B@H0030;FAH@2f
TV80]i=S0080]i=S00P0]8iO0;F?H02gTF80^99S0;NAHP2fT640/heN0;:<G@/0]HmP0P2dSUl30;>=
GP030;B?HP2eT6<0]Y5T0080]i9U00<0]Y5T0;F@H`2dSf800`2dT6000`2eTF40]Y9R0;NCH`020;NC
H`P0]Y=M00@0/hmK0;B@G02fTUh0^9AP0P2iUF400`2hU600]i=O0;NCG`070;NCG`080;JAG@2gTUh0
^9=O0;VDH02hTel0]i9N0;F@G02dSe/80;B@H080]Y9N1P2gTel80;RDH0P0]i=O202gTf<0102dT600
]I5Q0;FAH@2eTF420;JBHP80]i=S0P2eT6@20;JAI@040;NBIP2hTfL0^9=W0;VDJ0P0]i9N00P0]HeI
0;J>F`2eT5`0]I5O0;JBHP2eTfD0]IAW0;JEJ0T0]Y9R00P0]Y5M0;F@G02dSe/0]8mK0;F@G02gTUh0
^IAP0;^FHP80]i=S0P2fTV820;FAH@80]91P202fTUh40;JAI@80]i9V0P2hTfL80;>?F`80]I1T00@0
]8mS0;>>HP2cSV80/XeQ0P2aS600402aS5l0/hiQ0;NBI@2jUFP0^iIY0;VDI`2gTVD0]I1S0;ZEH@2i
U600^9=O0;NBGP2fTEd0]I1L0;B?F`2cSUX80;:>GPP0]95K0`2eTF430;B@H080/hmO0`2dT6020;>?
G`@0/XiN00P0/hmO0;B@H02eTF40]I5Q0;>?G`2aSEd0/8aL0;2;E`<0/HaH0P2bSET20;>>FPP0/XiN
202dSUl30;>>FP80]8mK0`2eT5`20;6=G@040;:>GP2cSel0/hmO0;B@H0@0]I5Q0P2dT6020;>?G`03
0;:>GP2aSEd0/HeM0080]8iO0`2cSEh30;:<G@040;B@G02cSe/0/hmK0;:>FP80/HeI0P2`S5P80;>>
H@80/XiN0P2aSEd30;2<G0030:n;F`2dSUl0]8iO00H0]8iO202_Re/20;>?G`80/XiN102aSEd20:n@
FP80[XmI0P2]SUP20:b=E`80/8]G0P2aS5P20;:=F@80/hiJ102aS5P20;2;E`80[hYF00P0[HUI0:j:
FP2_Re/0/8aL0;6=G@2bSUh0/hmO0;B@H0P0/XiJ102`S5P40;6=F@@0/8aL0P2_Re/20:j:FP030:^9
F@2/RUX0[XaL0080[heM00<0[XaL0:b:FP2[RET0202^RUH30;2<G0<0[h]K0P2^RUX80:f9F@80ZhMC
00D0[8QD0:f9E@2]RED0[h]G0;2<F0020;6=F@030;6<F02bSET0/hiJ0080]I1L00<0/hiJ0;:=F@2a
S5P0202^RUX20:n:EP<0[XUE0`2]R5@0102]RET0[XYJ0:j:FP2_Re/20;2<G080/HeM202]RET0102`
RU/0[hUJ0:n9FP2^R5T20:f7F080[8IG00T0[HUI0:j:FP2_Re/0[h]K0:j:FP2/R5P0ZXIF0:V5E@2/
QeX00P2/R5P00`2/R5H0[8QD0:b9D`020:b9D@080:n;E`2]RED0ZhMC0:Z6DP2YQE40ZXIB0:^7D`2/
R5@80:f8E0060:Z4E`2ZQ5D0ZhEF0:^5E02[QU80[8MB0P2/Qe001@2_RUH0[XUE0:j9E@2]R5@0[8MC
0080ZhIB00L0ZXEA0:^6DP2/Qe<0[8MC0:f8E02^RED0[hYF00<0/8]G00l0[hYF0:j9E@2]R5@0[8MC
0:^6DP2ZQE40ZHA@0:=mCP2TOTl0YX1A0:V3E02[QEH0[XQI0;2:F`2aRe`00P2ZQE430:V4D0<0Z8=?
0`2WPdl30:R4D080ZHEA202/R4h20:F0C0050:N2CP2YQ500ZhIB0:^6DP2]R5@00P2_RUH0102^RED0
[8MC0:Z5D@2WPTh20:J1C@0B0:N2CP2XPdl0ZXAG0:R2D`2WPE80YGm>0:F0C02WPTd0Z8=<0:Z5CP2[
QE@0ZH=B0:N1D02VP4l0YGm>0:J0C`2WPE00ZH=B202YQ5006@2/QUT0ZXAE0:V3E02WPE00Yh9>0:N2
C@2XPd`0ZHA=0:j2D@2[PDl0ZGm=0:InB`2TOd/0Y81<0:>2C@2TPdh0YH1<0:AoB`2SOTX0XWe90:=n
BP2UP4`0Z8=?0:Z5D@2WPE@00P2XPU<0102XPU40Z8=?0:J1C02SOTL30:9mAP030:9mB02RODT0XWa;
0080XWa=00@0XWa?0:=oC`2SOdl0Xgm?0P2ROTh30:5mC@P0XWi:00H0Xgm=0:9nC02ROTX0XGi80:1m
A`2OO4@209ik@@P0X7e500@0WWU509mjAP2RODT0Y7m;0P2UP4`20:AoB`030:J2CP2TP4`0Xgm;00<0
XGe900D0Xgm;0:B0C02NND`0X7]>0:9mD0030:AoDP80XgiA0P2OODl00`2QO4l0XG]>0:=jCP020:Ai
CP030:EhCP2QO4L0XGa700H0XGa700D0WgY60:1kA`2QO4P0XWe90:=nBP020:AoB`040:F0C02VPDd0
XWe80:5lA`80X7]600@0XGa70:=nB@2UP4/0YX5<202TP4`0202SOTX0Y7m;0:F0C02UP4`0Y7m;0:9m
B@2PNdL0WWU50P2ONTH40:1kA`80XGa800<0W7M309ehA02ONTH00P2QO4P00`2PNdL0WWU509ehA002
09iiA@0409mjAP2PNdL0X7]70:5lB080XWe9202NNTH01P2QODT0Wg]709ahA02JMT80V7A009Ue@@80
VWI200P0VGE509YfAP2KMdL0W7Q809]gA`2JMTH0V7A409Ib@P<0W7M300<0WGQ409iiA@2ONTH00P2O
NTH00`2ONTD0WWU409ag@P0209Ye@00409]f@@2MN4<0WWU409ijAP80WGU500<0W7Q409]g@`2JMT80
0P2IMD4809ag@`<0VWE10P2KMT8309ag@`<0UgE500<0UWA409Ec@`2DLT800P2DLT800`2KM4T0VW=8
09M`A@0209I_A00309M`A@2JLdP0VgA900<0UW110P2EKd0309A^?`P0TFdm0`2CKcl309A`@0<0UG51
00H0VWI609UeA@2FLT80U710099^?P2CKcl209A`@0@0TVhn102CKcl309A`@080UG510`2FLT80202I
KdD0V6i409E^@`2CKT80TVe108m]@02=K3l0S6/n0P2;JC/0102<JS`0SF/m08m]?`2@KT02095_@@80
T6/n0`2?JSd308iY?080RVLm0P2;J3h0102<JCl0SFY008eZ@02=JT02091[?P80SfXm102>JC`0202A
K3l0T6/n08mZ?@2>JC`0SFPk08aW>P2;IST0RVDh0`29ICD[ooooo`00:_ooool809AY?P0609=W@P2B
ISl0TVHo095V?02@ICX0Sf@g0P2>I3@00`2EJSd0U6Tl099W>P02091U>009099W>P2DJC`0UFXm09M/
@@2FJd00UFXo09AY?P2BIc`0T6Dj0080Sf@i00P0TVLj09=X>`2EJSd0UV/n09EZ?@2DJC`0TVLj091U
>0P0UFXm0P2FIC`00`2FIcd0U6Lm09=X?@02099Y?@03091Z?@2CJ3/0TfPk00H0TfPk00<0TV`m095[
?02@JS/00`2@JS/0102AJc`0TV`m09=W>P2DJ3/409IZ?@0309AX>`2AICP0T6@g0080TfLj00@0U6Pk
09EY?02EJC`0UVXm0P2GJch209E[>@0409I/>P2GKC/0V6hl09U_?@80VW0n0`2EJcT00`2FK3X0Ufdk
09Q^?00209Q^?0P0VFlm0P2JL3h209]a?`80W7900P2MLd4209a`?`0409ea@02NLT40X7A30:5eA080
XWI50P2RM4<00`2PM4<0WgE309if@`0209ag@`0609]g@`2MM400WGA009ie@@2OMT80X7M30P2QN4@0
0`2RNDD0WWA209id@P0309me@`<0X7I400@0WG=109id@P2NM480WgE30P2PMT@20:5gA@<0WgA10P2N
Ld0309eb?`0309ac?`2MM400WgI20080X7M300<0WgI209ed@02LLcl0202PMT@80:5hA080WgI20P2P
Md<20:5hA080XWU500@0WgE30:1fA02PMT@0X7I40P2QMdD20:9hAPP0XWM:202VODT00`2QN4@0XWU5
0:AkA`040:ImB@0B0:ElB02TNdL0YH9<0:B1B`2SP4X0XWm90:5nB02PODL0Wga609ikA@2UP4T0Y7m8
0:5lA@2ONT<0WWU209mj@`2PNd@0XGa50P2TOdP00`2TOdX0Xgi:0:9lB`020:5kC0060:5kCP2TNdL0
Y7]70:ElB02VODT0Ygi:0P2YP4`0102ZPDd0YWe70:ImA`2VODL30:MnB080Z7m90`2YP4`20:QoB`<0
Ygi:202XOd/20:^2BP80ZX5900@0ZH180:QoA`2XOdL0Ygi6202WPTh80:V0C0P0Zh9>202ZPDd40:F4
C`80YXE@0P2WQU480:f4D0<0[8=?0P2]Q5030:j5D@P0ZXEA00H0[h9H0:n3EP2^PUD0[X9C0:j2D@2^
Pe020:f2C@<0[89@0P2]Pe430:j4DP040:j9E@2]R5@0[HQD0:f8E080[8MC0`2[QU880:V4D0<0[XAB
0P2]Pe430:b2D0P0[HA@0P2ZP4h30:^1C`<0[89@0`2^QE400`2_QU80/8MC0;68E0020;68E0<0[hIB
1@2^QE400`2YQ4d0ZhI?0:f8D@030;2;E0030:n:D`2^RE80[HQD0080[HQD1@2^RED20:^6DP80[8MC
0P2]R5@20:j9E@80[8Q>00H0[HQA0:f8D`2^RE@0[hYF0:n9F02`RUT30:f9E@80[XYF0`2_ReL80:n:
EP030:f8E02_RUH0/HaH0080/hiJ00<0/XeI0;6<F02`ReL00`2^RED20:n:EP<0/8]G00P0[XUE0:n:
EP2`ReL0/HaH0;:=F@2cSUX0]8mK0;F@G080[XUE0P2_RUH00`2`ReL0/HaH0;6<F00A0;:=F@<0/XaM
0`2cSEh30;B>G`80/XaM00@0/heN0;B>G`2dSUl0]HmP0P2fT6420;B@G0030;>?F`2bSUX0/HeI0080
/8aH00<0[h]G0;B>G`2dSUl00`2eSf030;J@H@P0/XiN202cSel30;>>FP80]8mK0`2eT5`00`2iTf@0
]i5R0;J@H@020;B>G`030;J@H@2gTF80^I=T0080^9=O0P2gTUh20;JAG@80]I1L0P2hTel20;NBGP80
]Y5M0P2eT5`20;NBGP040;JAG@2eT5`0/hiJ0;:=F@80/HaH00P0]8mK0;>>FP2bSET0/HaH0;:=F@2d
Se/0]i9N0;RCG`80]Y5J00H0]Y5L0;F@G02eSeh0]HmP0;B>G`2dSV430;>=GP80]8iO0`2eSf020;>?
G`<0]91P0`2eTF430;F@G080]8mK0`2cSUX80;B>G`P0]I1L102fTV820;NCH`80^9AT0P2dSeP00`2d
SeX0]8mK0;B>G@020;B>G`030;B>H@2eSf00]HmP00l0]HmP202eTF430;JAG@<0]I1L0P2dSe/80;NB
GP<0]91P00<0]I5Q0;JBHP2gTf<00P2gTf<00`2jUVH0^IEU0;NCH`030;FAH@030;JBHP2gTf<0^9AT
00L0^9AT202gTf<20;NDG0030;NDGP2gTel0]i=Q0080]i=S00<0]i9U0;JBGP2fTUh01P2fTUh01P2f
Ted0]Y9N0;JBGP2gTf40]i=S0;NBI@80^9=W202hU6@30;NCH`80^9AT0`2iUFD80;RDH080]i=S0P2f
TV820;FAH@@0]91P0P2eTF420;JBHP80]i=S00<0^IAX0;NBIP2eT6@00P2cSV800`2dSf<0]I1T0;NB
IP030;NCH`030;JBHP2eTF40]91P0080]91P0`2fTUh0102eTEd0]91L0;:>FP2aSET20;2<F0P0]I5M
202dSf830;:>GP80/hmO0`2dT6080;>?G`<0]I5Q0`2dT6030;>?G`070;B@H02eTF40]I5Q0;B@H02c
Sel0/HeM0:n;F`020;B@H080]I5Q0`2fTV800`2gTf<0]I1S0;F@H`060;F@H`P0]I5M0P2fTV820;FA
H@040;B@H02cSel0/hmO0;:>GP80/heN00@0]8iO0;F?H02fT640]Y1Q0P2gTF801P2iTEd0^91L0;N?
F`2fSUX0]8aH0;::EP80/HUE202aSUP80;:>GPP0/H]L202cSUX80;>=GPP0]8iO00@0]I5Q0;B@H02b
SUh0/XiN0P2aSEd00`2bSUh0]91P0;FAH@020:j:FP80[h]K0`2`S5`00`2aSEd0/XiN0;:>GP060;:>
GPP0]I5Q0`2_Re/00`2`S5`0/HeM0;:>GP020;:>GP030:j>G@2_Seh0/Y1P0080]I5Q00<0]HmP0;F<
GP2dRed02@2bSET01`2cSUX0]I1L0;F@G02eT5`0/hiJ0;2;E`2_RUH0202`ReL01P2^R5T0[hUJ0;6;
G02cSEh0]8iO0;>=GP80/XaM00<0[h]K0;2<G02bSUh00P2bSUh01P2aSEd0[h]K0:j:FP2/R5@0[HUE
0:n;E`<0/HeI00@0/8aH0:n;E`2aSEd0/HeM0P2bSUh40;>?G`P0/8aH0P2cSel01P2bSUh0/8aL0:j:
FP2]RET0[8QH0:^7E`@0/HaH102bSET01@2fTEd0]I1L0;:=F@2_RUH0[XUE0080[HQD00@0[XUE0;2<
F02`S5P0/8aH0`2_ReL20:j:EP030;2<G02_Re/0[h]K0080[XYJ0P2]RET00`2/R5P0/H]L0;6;G007
0;6;G0P0/8aL0P2`R5D01P2]R5@0[8QD0:f9E@2^SEP0[i1J0;6BG080/HeI0`2`S5P40:n;E`80[XYF
00<0[HUE0:b8E02/R5@00P2[Qe<00`2^RUX0[8QH0:^7E`020:V5E@030:^7E`2/R5P0[XYJ00P0[8QH
202_RUH20:j:EP<0[HUE0`2/R5@30:^8DP<0ZXMA0P2YQU00102^RED0[HQD0:f8E02]R5@20:b7D`80
ZhIB00@0ZH=D0:Z4E@2ZQ5D0ZhEF0P2/QUL20:f7F0P0ZhIB1@2ZQU830:^7D`080:f8E02/Qe<0ZhIB
0:Z5D@2XPdl0YX5=0:F0C02TOd/20:R3C`040:V4D02ZQE40ZhIB0:b7D`80[HQD00L0[8QD0:^7D`2Z
QU80ZHEA0:N3C`2UPDd0Y81<0080Xgm;00X0Y81<0:F1C@2VPTh0Yh=?0:R4D02YQE40ZXIB0:V4D02[
QU80[8MC0P2]R5@00`2ZQE40Yh9>0:F0C0090:V4D080ZhED00<0ZXAC0:V3DP2XPU400P2WPE000`2V
P4l0YX1C0:J0D`020:N1E080Z89E0P2YPeH0202XPdl0Yh9>0:J1C@2UP4`0YX5=0:N2CP2YQ500ZhIB
1@2ZQe430:^8DP<0ZHA@00<0Z8=?0:N2CP2VPDd00P2VPDd20:R3C`80Yh9>00@0YX5=0:F0C02UP4`0
Y7m;0P2QO4L00`2RODP0Xgi90:AoBP020:J1C0030:N2C@2UP4/0YH1;00<0Y7m:0`2SOTT80:=oB`80
Yge;0P2VO4X30:EkB@030:AjB02ROTX0XWi:0080XGe900@0X7a809mkA`2ONdL0WWY60`2PO4P209mk
A`<0WWY60`2QO4P30:9mB@80Xgi:00@0YX5=0:F0C02UP4`0Y7m;0P2SOTX20:9mB@P0Wg]7202QODd0
1@2SOTX0Yh9>0:V4D02WPTh0XWe90080WWU500@0X7]70:AoB`2RODT0X7]70P2NNDD00`2PNdL0XWe9
0:AoB`020:=mC0030:=nBP2SOTT0Xgi90080Xgi70P2SOdD20:F0B`040:AoBP2SOTT0XGa70:1kAP80
WgY5202TOdP0202ONTd0XGe=0:9nCP2TP4h0Y81<0:9oB@2QOTH0Wga40P2NNdD00`2OO4H0X7e70:5n
B0020:9oB@040:>0BP2MNDD0Wg]70:5mB@80XWi:00@0X7a809eiA@2KMd<0YGY70P2TNDH00`2SN4D0
XWM40:9gA0020:5f@`80Wg]70`2PO4P30:5mB@0909miBP2NN4T0W7I709]eAP2JM4D0VgE609afA`2M
MdP0VgM30080VWI200<0VGE109Qd@02HM4000P2GLcl0202NNc/0WWXl09ij?P2NND80WWU509ihB@2N
N4/0WWM<0`2NNd400`2MNT00W7To09]h?P0209]h?P0809ikA@2MNT@0W7U309eiA@2NNTP0WWY:09ei
B@2LMdX209iiA@D0WgY600@0X7]709ahA02KMd<0VWI20P2IMD400`2KMd<0WGU509mkA`0209]c@004
09Ud@02HM400V7A009Ie@080UGI00`2HLcl309Mb?P80UW4m0P2IKC`209Q/>`<0Uf/j00T0UVXi091Z
>`2AJc`0TV`m09=]?P2DKSl0UFm009I`@@2GLD802@2ELCd01P2GLd<0UW9209Ea@@2DL400Tflo099^
?P80TFdm00T0U74k09=`>P2AKSP0T6dg08m/=P2@KCL0TFhh099_>@2FL4400P2EKd001@2DKSl0Tfdn
099/?@2BK3d0TF/l00<0Sfhk0P2>KCX308e/>@80S6Xl00@0SF/m08i/?P2>K3h0Sfdo0P2@KT001`2?
JSd0T6/n095/?`2AK3l0T6/n08iY?02<IcX00P2:ICP01`2<IcX0SVTl08mZ?@2@Jch0SfXm08iY?02=
J3/00`2@Jch00`2?JSd0SVTl08iY?00308eX>`0708iY?02@Jch0T6/n08mZ?@2=J3/0RfHi08UT=`03
08]W=b_ooooo000Zooooo`P0TFHk00H0SV8m08mS?02?Hc`0T6Dk095V>`2AIST2099X>00309AY?02C
J3/0TVLj0080TFHi00<0TVLj09=X>`2DJC`00P2EJSl0102DJCh0TfPm099W?02AIS/2091U>P03095V
>@2BIcX0TfPk0080U6Tl00<0TfPk095V>@2@ICP0202DJC`01P2GISd0UVLm09IW?@2DIcd0TfPm095X
?080SfTl202CJ3/00`2@JS/0TF/l095[?004095[?005091Z>`2CIcX0U6Pk09EY?02FJSd00P2EJC`0
102DJ3/0TVHi091T=`2CIcX209AX>`80UFTl0P2FJSd00`2GJch0VFlm09Q^?00209Q^?080Ufdk0P2F
K3X209E[>@80UV`j00@0Ufdk09Q^?02HKS`0V6hl202IKcd209Y`?P80Vg4o0P2LLT0209ec@@<0WW91
0P2OLd830:1d@`80XWA300<0X7A309me@`2NMT<00P2LMd<00`2KMd<0WWE109ie@@0309mf@P<0X7M3
0`2NM48209me@`<0X7I40`2NM4800`2OMD<0X7I40:1fA0020:5gA@040:9gA02QMT<0XGI30:5f@`80
X7E20P2OM4400`2LLcl0WGA009mf@P020:1g@`0309mf@P2MM400W7<o00P0X7I4202QN4@209mf@P80
X7M30P2QN4@20:9iA@@0X7I40P2QMdD20:9hAPP0XWM:202UO4P00`2QN4@0XWU50:AkA`040:ImB@0B
0:ElB02TNdL0YH1;0:F0B`2TOdX0Xgi90:9mB02QO4L0X7]609mjA@2RODH0XGa50:1kA02ONT<0X7]4
0:9mAP2TOdP0YX5:0P2TOdP01P2SOTT0Xgi:0:9lB`2RO4d0XG]<0:5kCP80Y7]700H0YGa80:ImB@2W
OTX0Z7m;0:V0C02ZPDd30:ImA`<0Ygi80P2XOdT30:V0C080Z7m;0`2WOTX80:QoB`80Zh9:0P2ZPDT0
102YP4P0Z7m70:QoA`2XOdL80:N2CPP0ZX5=202[PTh80:Z1C@040:B3CP2UQ4l0YHA?0:F4C`80YXE@
0P2WQU480:f4D0<0[8=?0`2]Q5020:j5D@P0ZXEA00H0[H9G0:f2E@2]PUD0[H=C0:f3D@2]Q5020:f4
CP<0[89@0P2]Pe430:j4DP@0[HQD0P2/Qe<;0:^6DP<0[XAB0P2]Pe430:b2D0P0[HA@0P2[PDl20:b2
D0<0[H=A00D0[XAB0:j5D@2^QE40[XEA0:n6DP020;27D`80/HQD102_QU840:j5D@080:^6C`2/Qe00
[XUB0:n:D`2`Re@0[hYC0:j9DP2]R5420:f8E0H0[XUE0P2[QU820:b7D`80[HQD0P2^RED20:b8CP04
0:f8D@2]R5<0[XUD0:n:EP80[hUH0`2]RED20:j:EP<0[h]G202_RUH0202/Qe<0[XUE0;2;E`2aS5P0
/XeI0;6<F02`ReL0[hYF0P2^RED30:n:EP<0/8]G0P2_RUH0102`ReL0/HaH0;:=F@2cSUX20;B?F`80
[hYF0P2`ReL00`2aS5P0/XeI0;:=F@0A0;:=F@<0/XaM0`2cSEh30;B>G`<0/heN0P2dSUl30;F?H080
/hmK0`2bSUX30;6=F@<0]8iO0P2eSf030;J@H@P0/XiN202cSel20;>>FP<0]8mK0`2eT5`00`2hTV<0
]i5R0;J@H@020;F?H0030;J@H@2gTF80^99S0080^9=O0P2gTUh20;JAG@80]I1L0P2hTel20;NBGP80
]Y5M0P2eT5`01@2gTUh0]Y5M0;JAG@2eT5`0/hiJ0080/XeI00<0/HaH0;B?F`2cSUX00`2bSET00`2d
Se/0]Y5M0;RCG`020;JAFP030;JAG02eT5`0]HmN0080]8iO00@0]8iQ0;>=GP2cSEh0/heN0P2dSUl3
0;F?H080/hmO0`2dT6030;FAH@<0]I1L0P2dSe/30;>>FPP0]8iO202eT5`0102eTF40]Y9R0;JBHP2f
TV820;NCH`80^9AT0P2dSeP00`2dSeX0]8mK0;B>G@020;B>G`030;B>H@2eSf00]HmP00l0]HmP202e
TF430;JAG@<0]I1L0P2dSe/80;NBGP80]91P0P2eTF420;JBHP80]i=S00P0^YIV0;VEI@2gTf<0]I5Q
0;B@H02eTF40]Y9R0;NCH`P0^9AT202gTf<20;NDG0030;NDGP2gTel0]i=Q0080]i=S00<0]i9U0;JB
GP2fTUh01P2fTUh01P2fTed0]Y9N0;JBGP2gTf40]i=S0;NBI@80^9=W202hU6@30;NCH`<0^9AT0P2i
UFD80;RDH080]i=S0P2fTV820;FAH@@0]91P0P2eTF420;JBHP80]i=S00P0^IAX0;NBIP2eT6@0]8mS
0;>>HP2dSf<0]I1T0;JAI@80]i=S0P2fTV820;FAH@80]91P0`2fTUh01P2eTEd0]91L0;>?F`2bSUX0
/HeI0;2<F0P0]I5M202dT60@0;>?G`<0]I5Q0`2dT6030;>?G`070;B@H02eTF40]I5Q0;B@H02cSel0
/HeM0;2<G0020;B@H080]I5Q102fTV880;FAH@P0]I5M0P2fTV820;FAH@040;B@H02cSel0/hmO0;>?
G`<0]8iO0P2eSf030;J@H@040;R@G@2gSe`0]XiK0;F=FP80]8aI00<0/h]H0;::E`2aSET01`2aSET8
0;:>GPP0/H]L202cSUX80;>=GPP0]8iO00@0]I5Q0;B@H02bSUh0/XiN0P2aSEd0102bSUh0]91P0;FA
H@2^RUX30:n;F`80/8aL0P2aSEd80;:>GPP0]91P0P2_Re/20;2<G0070;6=G@2bSUh0/XiN0;:>GP2^
SUd0[hmN0;:@H0020;FAH@030;F?H02eS5h0]8]M00T0/XeI00L0/hiJ0;B?F`2eT5`0]8mK0;:=F@2`
ReL0[hYF00P0/8]G00/0[XQI0:n9FP2aRe`0/heN0;B>G`2cSEh0/XaM0;6;G02_Re/0/8aL0;6=G@02
0;:>GP060;6=G@2_Re/0[XYJ0:b8E02]RED0[h]G0`2aSET0102`S5P0[h]G0;2<G02`S5`30;6=G@<0
/XiN202_ReL01P2bSUh0/HeM0;6=G@2`S5`0[h]K0:j:FP80[HUI102aS5P40;:=F@040;F@G02cSUX0
/HaH0:n:EP80[XUE0P2_RUH30;2<F080[h]G0`2^RUH01P2[QeL0[8QH0:b8F02]RET0[XYJ0:n;F`80
/8aL2@2aRe`80;2<G0080;28E@2_Qe@0[8MC0:^7D`2/R5@0[8]F0:f>F02_T5X20;2<F0<0[h]G1P2^
RUH00`2]RED0[8QD0:b8E0020:^7D`030:j:FP2]RET0ZhMG0080ZXIF00<0ZhMG0:f9F@2^RUX0202/
R5P80:n:EP030:b8E02]RED0[HUE00D0[HUE0`2[R5830:Z7D@80ZHI@102]R5@20:b7D`80ZhIB0`2Z
Q5D00`2[QEH0[8IG0:b6E`020:f7F0P0ZhIB1P2ZQU820:^7D`060:f8E02/Qe<0ZhIB0:Z5D@2XPdl0
YX5=0P2UP4`20:N2CP040:R3C`2YQ500ZXEA0:^6DP80[8MC00H0[8QD0:^7D`2ZQU80ZHEA0:N3C`2U
PDd40:B0C0060:F1C@2VPTh0Yh=?0:R4D02YQE40ZXIB0P2ZQE430:^6DP030:Z5D@2XPdl0Z8=?00T0
ZHA@0P2[QE@0102ZQ5<0ZH=B0:R2D@2WPE020:J0C`80YX1A0P2WPE820:R2D`80ZH=D00<0Z8=?0:N2
CP2VPDd00P2VPDd00`2XPdl0ZHA@0:^6DP080:Z7D@80ZHA@0P2XPdl0102WPTh0YX5=0:J1C@2VPDd2
0:R3C`80Yh9>00D0YX5=0:F0C02UP4`0YH1<0:5lA`020:9mB0050:=nB@2UP4/0YX5<0:J1C02WPTd0
0`2UP4/20:AoBP<0Xgi9202SOd/20:MmB`80YWa:102UNdT20:9nBP80XGe90P2PO4P209mkA`<0X7a8
0`2ONdL209ijAP80XGa80P2RODT00`2SOTX0Y7m;0:AoB`030:F0C080Y7m;0P2SOTX20:9mB@P0Wg]7
202QODd01@2RODT0YH1<0:R3C`2VPDd0XGa80080WGQ400@0WgY60:9mB@2RODT0XGa80P2PNdL00`2Q
O4P0XWe90:9mB@020:AnC@030:AoB`2TOdX0Y7m:0080Y7m80P2TP4H01P2VPD`0YH1;0:AoBP2SOTT0
XWe80:5lA`80X7]6202TOdP0202ONTd0X7a<0:9nCP2SOdd0Xgm;0:9oB@2PODD0Wga40P2NNdD00`2O
O4H0X7e70:5nB0020:9oB@0:0:>0BP2ONdL0X7a80:1lB02QODT0X7a809mkA`2NNTH0WGU50:AkA`80
XgY60P2RNDD20:5hA0030:1g@`2PO4P0X7a800H0X7a800T0WgU:09ihB@2LMTL0VgE609YdA@2KMDH0
W7I709egB02KMd<00P2JMT8209Ue@@80V7A000T0Ug<o09ij?02NNSh0WWY009ii@P2NNDD0WWQ709ih
B@2NN4/00P2NNd4209ej@080W7To0P2KN3h209ahA00309]g@`2LN4H0WGU700<0WGU90`2KMT8509ag
@`0309eiA@2LN4@0VWI20080VGE100<0VWI209ahA02MNDD00P2KLd00102IM400V7A009Qd@02FMD02
09Ef@0<0V7<o0`2GLSh209Ia?@80V6hl0P2GKC/409I/>P80TF/l00@0TV`m09=]?P2DKSl0UFm00P2F
L44909Ea?@<0UG5100d0U71009=_?`2CKcl0Tflo099^?P2DL3`0Tflk095]>@2@K3P0Sf/g091/>02A
KCT0TVhj00<0U6ho0`2CKCh2099/?@P0SVdj0P2<JS`208e[?@0608i/?P2?KCl0Sfdo08m]?`2?JSd0
T6/n0P2AK3l00`2@Jch0SVTl08aW>P0208YU>00708aW>P2>JC`0SfXm091[?P2?JSd0SVTl08eX>`04
08mZ?@@0SVTl00<0S6Lj08eX>`2?JSd00P2?JSd00`2>JC`0S6Lj08YU>00308]W=b_ooooo000Zoooo
o`P0SV<h00P0Relj08aP>@2=HCX0Sf@j095V>`2CJ3/0UF/k09I/?080TfPk00@0TVLj095V>@2AIST0
TVLj0P2CJ3/8099W?00308mT=`2@ICP0TFHi0080TVLj00<0TFHi091U>02@ICP0202BIcX0202HJCl0
UfPn09EX?P2CJ3d0TFPl08mY?02>J3/0SFPk202CJ3/00`2=IcP0SfTj099/?@0209=]?P03099/?@2?
JCX0SFLh0080U6Pk102EJC`00`2DJ3/0TVHi095U>00309AX>`80UFTl0`2FJSd01P2KLCl0VW0n09U_
?@2GKC/0UV`j09AZ>080TfTg0`2FK3X209M]>`<0V6hl202IKcd209Y`?P80Vg4o0P2LLT0209ec@@<0
X7A30P2OLd8309ib@@80XWA300<0X7A309me@`2NMT<00P2LMd<0102KMd<0X7M30:1g@`2PMd<309mf
@P80WWE100@0WG=109id@P2NM480WWA20P2OMD<20:1fA080WWA20`2OMD<30:1fA0040:=hA@2RMd@0
XWM40:9gA080XGI30P2PMD8209ed@0@0WgI20P2MM4080:1fA0P0XGQ40P2OMT820:1g@`80XGQ40P2R
NDD30:1fA080XGM50`2RN4H80:9gBPP0XgY600<0XGQ40:9iA@2TNdL0102VODT01P2UO4P0Y7]70:Ao
BP2TOdX0Xgi90:9mB080XGa70P2PNdH209mj@`0;0:1kA02QO4D0Xgi70:J1BP2XPd`0ZXE>0:AoB02S
OTL0Xgi90:=nBP2RO4/00P2RO4d01`2QNdh0Y7]70:ElB02UO4P0YWe90:MnBP2XOd/00P2YP4`30:Im
A`<0Ygi80P2XOdT30:V0C080Z7m;0`2WOTX80:QoB`<0ZX5;0`2YP4X20:QoB@P0Yh9>402[PTh80:Z1
C@<0YX9>0P2WPdl30:R4D0P0[8=?0P2[PTh20:b3C`<0[HA@00<0[XEA0:Z5D@2ZQE401P2ZQE401P2]
PUL0[H9E0:f2E@2]Pe<0[H=A0:f4D080[HA>0`2/PU020:f3D@<0[XAB0`2]R5@20:b7D`@0ZhIB202/
Qe<30:j4DP80[H=A0`2/PU080:f4D080[H=A0P2^Q5830:n5D`040;26E02^QE40[XEA0:j5D@80[hIB
0`2`Qe<80:n6DP030:f8D`2^RE@0[hYE0080[hYE00<0[XUD0:b7DP2/Qe80202^RED20:^6DP80[8MC
0P2]R5@20:j9E@80[HU?00@0[HQA0:j9E02^RE@0[XUE0P2_REP30:f9E@80[XYF0`2_ReL80:n:EP03
0:^6DP2/Qe<0[XUE00<0[hYF0`2^RED30:n:EP80/8]G0P2aS5P01@2_RUH0/8]G0;2;E`2aS5P0/XeI
0080/hiJ00<0]8mK0;6<F02aS5P00`2bSET30;>>FQ00/XeI0`2bS5d30;>=GP<0]8iO0`2eSf020;B>
G`<0/heN0`2aSET30;:>FP80/hmK00@0/heN0;B>G`2dSUl0]8iO0P2eSf020;J@H@P0/XiN202cSel0
102cSUX0]8mK0;B?F`2dSe/20;F@G080]Y5M00<0^99S0;NAHP2fT6400P2eSf000`2fT640]i5R0;RB
H`020;RCG`80]i9N0P2fTEd20;F@G080^9=O0P2gTUh20;JAG@80]I1L0P2fTEd0102eT5`0]8mK0;B?
F`2cSUX20;:=F@80]8mK0`2cSUX00`2dSe/0]I1L0;JAG@020;JAFP030;F@F`2eT5`0]8iM0080]8iO
00@0/heP0;>=GP2cSEh0/heN0P2dSUl30;F?H080/hmO0`2dT6030;FAH@<0]I1L0P2dSe/30;>>FPP0
]8iO202eT5`30;FAH@80]Y9R0`2gTf<20;B?F0030;B?FP2dSe/0]8iM0080]8iO00<0]8iQ0;F?H02e
Sf003`2eSf080;FAH@<0]Y5M0`2eT5`20;B?F`P0]i9N00@0]91P0;FAH@2eTF40]I5Q0`2fTV80202g
Tf<0^IEU0;RDI02fTV80]I5Q0;B@H02eTF40]Y9R2@2gTf<80;JBHP80]iAL00<0]iAN0;NCG`2gTf40
0P2gTf<00`2gTVD0]Y9N0;JBGP060;JBGP060;JCG@2fTUh0]Y9N0;NCH@2gTf<0]i9U0P2hTfL80;NC
H`80]Y9R0P2gTf<30;RDI0030;VEI@2hU600^9AP00H0^9AP0P2gTf<20;JBHP80]I5Q102dT6020;FA
H@80]Y9R0P2gTf<00`2hTfH0]i9U0;JAI0030;B?HP030;F@H`2fTF@0]i=S00<0]Y9R0`2eTF401`2d
T600]Y9N0;JBGP2fTUh0]I5M0;B@G02cSe/00P2bSUX00`2aSET0]I5M0;FAG@060;FAG@P0]91P00D0
]Y9R0;FAH@2eTF40]91P0;>?G`020;:>GP030;6=G@2dT600]91P00H0]91P0`2eTF430;B@H080/hmO
00<0/XiN0;>?G`2dT6000P2eTF400`2cSel0/HeM0;2<G0030;B@H080]I5Q0`2fTV880;FAH@P0]I5M
0`2eTF430;B@H080/hmO00@0]Y1Q0;F?H02eSf00]HmP102dSUl80;>>FPP0/HeI202bSUh80;6;G0P0
/hiJ202cSEh80;B>G`040;B@H02cSel0/XiN0;:>GP80/HeM00<0/XiN0;>?G`2dT6000P2_Re/20;2<
G0<0/HeM4@2bSUh30;2<G080/HeM0`2bSUh00`2^SUd0[hmN0;6?G`020;B@H0030;B>G`2eS5h0]8]M
00T0/XeI0P2cSUX0102dSe/0/hiJ0;:=F@2aS5P90;2;E`0;0:n9FP2`RU/0/XaM0;>=GP2dSUl0/heN
0;:<G@2aRe`0[h]K0;2<G02aSEd00P2bSUh01P2aSEd0/8aL0:n;F`2/R5@0[XYF0:n;E`<0/HeI0P2_
ReL30:n;F`<0/8aL0P2aSEd80:j:EPP0[h]K102bSET40;6<F0030;:=F@2aS5P0/8]G0080[XUE00<0
[hYF0;6<F02bSET00P2`S5P20:n;E`<0[XYF00T0[HUE0:R4E02YQED0ZhMG0:b8F02^RUX0/8aL0;:>
GP2cSel02@2aRe`80;2<G0030;28E@2_Qe@0[8MC0080ZhMC00<0ZXUD0:Z;E@2[S5H00`2^RUH30:f9
E@80[8QD0P2^RUH30:f9E@<0[8QD0P2]RET0102/R5P0ZhMG0:^7E`2/R5P20:f9F@P0[8QH202^RED2
0:^7D`80[8QD00@0[HUE0:j:EP2_ReL0[h]G0`2[R5830:Z7D@80ZHI@0`2]R5@20:b7D`<0ZhIB0P2Z
Q5D30:^5EP<0[8IG202[QU880:Z6DP80[8MC00H0ZhIB0:V4D02XPdl0Yh9>0:J1C@2UP4`20:J1C@04
0:N2CP2XPdl0Z8=?0:V4D080ZXEA0P2[Qe<01P2ZQU80Z8A@0:N3C`2VPTh0YH5=0:B0C080YH5=00@0
YX9>0:N3C`2XQ500Z8A@0P2YQE400`2ZQE40ZHA@0:R3C`020:R3C`030:V4D02[QU80[8MC00T0ZHA@
00H0ZhIB0:Z5D@2ZQE40ZHA@0:R3C`2WPTh20:J1C@80YX1A0P2WPE820:R2D`80ZH=D00P0ZHA@0:R3
C`2WPTh0YX5=0:N2CP2XPdl0ZXEA0:^6DPP0ZXMA0`2XPdl20:N2CP<0YX5=0`2WPTh30:J1C@80YH1<
0P2RODP00`2SOTT0Y7m:0:F0B`020:J1C0030:N2C@2VPD`0YH1;0080YH1;0P2TOdX20:=nB@P0Xgm;
0`2WOD/20:IlBP<0YG]90P2ROTX30:5mB@<0X7a80P2QODT20:1lB0<0Wg]700L0WWY60:5lB02QO4P0
XWe90:=nBP2UP4`0YX5=0080Yh9>0`2TOd/30:=nBP80XWe9202PO4P80:5mC@050:1kA`2SOTX0YX5=
0:F0C02PNdL00P2LMd<00`2NNDD0X7]70:5lB0040:9mB@050:5lB02PNdL0YGm>0:EoCP2UP4`00P2U
P4/20:F0B@80YH570P2VPD`0102UP4/0Y7m:0:=nB@2SOTT20:9mB0P0Xgi900H0X7]>0:1lC02QODd0
XWi<0:9nBP2QOTP20:1mA@80WW]500<0Wga60:1mA`2QOTP00P2ROdT01@2SP4X0XWi:0:5mB@2PO4P0
Wg]70080WWY600<0Wg]70:1lB02SNTH00`2SNTH20:9iA@80XGQ40P2ROTX00`2QODT0X7a809mkA`03
09ijAP0809miBP2NN4T0W7I709]eAP2JM4D0VgE609afA`2MMdP409Yf@P80VGE10P2HM400102NNSh0
WWY009ii@P2NND8209iiA@0309ihA`2NN4T0WW]300<0WGY20`2LND400`2KN400V7A409UeA@0409]g
A`0309eiB@2NNTX0VGA000L0VGA000@0WWY609eiA@2KMd<0VWI20`2IMD40102JMT80Vg=009]c@02I
M40209Qd@00309Ie@02EMT00UGI000<0V7<o0`2GLSh209Ia?@<0V6hl0P2GKC/309I/>P05095[?02B
K3d0TV`m09=]?P2DKSl00P2EKd000`2FL440U70l09A`?00709A`?0<0Tflo0`2DL40209Ea@@0809A`
?02CKc/0TFdi091/>02?JcL0T6`h095]>@2BKSX3099/?@<0Tfdn0P2DKSl01@2<JSX0SF/k08e[>`2>
K3`0Sfdm0080T6hn00<0TFlo08aZ?02=Jcd00P2=Jcd308i/?P0308m]?`2?JSd0T6/n00<0T6/n00X0
SVTl08]V>@2:ICP0RVDh08aW>P2>JC`0SfXm091[?P2?JSd0SVTl0`2=J3/308iY?0<0SfXm00<0RfHi
08aW>P2=J3/00`2>JC`208eX>`<0S6Ph:oooool002[ooooo202?I3T0202=HC`0SF4j08iR>`2@IC/0
TFHk099W>P2CJCT0U6Xj0`2BIcX2095V>@<0TVLj0P2@ICX2095V>`05099W?02CJ3d0TfPm09AY?P2>
HcH00P2?I3L5091U>0P0TFHi0P2FJCl00`2DJCh0TVTm08mY?00208eX>`0308YX>P2CJ3/0TfPk00H0
TfPk00<0RfDf08iX>@2BK3d00P2EKd000`2BK3d0SVPi08]U=P0709AX>`80TfLj202EJC`309M]>`03
09I/>P2EJcT0UF/i0080U6Xh102GKC/409Q^?0P0VFlm0P2JL3h209]a?`80W7900P2MLd420:9fA@04
0:5eA02PM4<0WW9109ea@080W70o0P2RM4<00`2PM4<0WgE309if@`0209ag@`0709]g@`2RNDD0XGQ4
0:5hA02PMd<0WgI209ie@@0209ed@080WG=10`2NM48909me@`80X7I40`2PMD8209md@@<0WW=0202N
MD480:1fA0P0XGQ40P2OMT820:1g@`80XGQ40P2RNDD20:1fA080XGM50P2RN4H20:=iA`P0XgQ;2@2Q
N4@00`2RNDD0Y7]70:ImB@030:ImB@040:ElB02TNdL0YGe90:EmB@80Y7a80P2SNdL20:9jAP80XGa5
00H0XWe60:=nA`2UP4T0YX5:0:N2B`2XPd`20:=nA`030:=nB@2SOTX0XWa;0080XWa=00<0XWa?0:El
B02UO4P00P2VODT0102WOTX0Z7m;0:QoB`2XOd/30:ImA`<0Ygi80P2XOdT30:V0C080Z7m;0`2WOTX8
0:QoB`80ZX5=1P2YP4`80:N2CPP0[8=?202[PTh80:Z1C@<0Yh9>0`2XPdl20:V4D0P0[8=?0`2[PTh2
0:b3C`<0[HA@202ZQE401P2[PUH0Zh9D0:b3E@2/Q5<0[8AA0:b4D080[HI?0`2/PU020:f3D@<0[XAB
0P2]R5@20:b7D`80ZhIB0`2ZQE480:f8E0<0[XAB0P2]Pe430:b2D0P0[HA@0`2_QE<20;26E0<0/HME
102^QE440:n6DP030:j5D@2_QU80[hIB0080[hIB0`2`Qe<02@2`ReL0[hYF0:n:EP2_RUH0[XUE0:f8
E02/Qe<0ZhIB0:n:EP040:j9E@<0[HQD0P2[QU820:b7D`80[HQD0P2^RED20:f9C`040:j9DP2^RE@0
[XUD0:j9E@80[XQG0`2]RED20:j:EP<0[h]G202_RUH20:^6DP80[8MC102]R5@30:n:EP80/8]G0`2a
S5P20;2;E`80/HaH0P2bSET70;>>FP<0]8mK202bSET80;>>FP<0/XaM0`2cSEh30;B>G`80]Y1Q00@0
]HmP0;B>G`2dSUl0/heN0P2bS5d01P2_ReL0/8aH0;2<F02aSET0/XiJ0;>?F`80]91L0P2cSEh30;B>
G`<0]HmP402cSel30;B?F`80]I1L0`2fTEd20;NAHP@0]Y1Q0P2gTF820;RCG`80]i9N0P2fTEd20;F@
G080^9=O0P2gTUh20;JAG@80]I1L00<0]Y5M0;F@G02eT5`00P2dSe/20;>>FP050;:=F@2dSe/0]8mK
0;B?F`2cSUX00P2dSe/20;F@G080]I1I00H0]I1K0;B?F`2dSUd0]8iO0;>=GP2cSF030;>=GP80]8iO
0`2eSf020;>?G`<0]91P0`2eTF430;F@G080]8mK0`2cSUX80;B>G`P0]I1L0`2eTF430;JBHP80]i=S
0P2dSeP00`2dSeX0]8mK0;B>G@020;B>G`030;B>H@2eSf00]HmP00l0]HmP202eTF430;JAG@<0]I1L
0P2dSe/80;NBGP@0]I5Q102fTV800`2hU6@0]i=S0;FAH@020;B@H0030;FAH@2fTV80]i=S00P0]i=S
202fTV820;NDG0030;NDGP2gTel0]i=Q0080]i=S00<0]i9U0;JBGP2fTUh01P2fTUh01P2fTed0]Y9N
0;JBGP2gTf40]i=S0;NBI@80^9=W202gTf<30;JBHP80]i=S0`2hU6@80;RDH080]i=S0P2fTV820;FA
H@@0]91P0P2eTF420;JBHP@0]i=S00<0]Y9R0;FAH@2eTF400`2eTF440;JBHP@0]I5Q00@0]Y9N0;FA
G@2eTEd0]I5M0P2dT5`20;>?F`030;:>FP2eTEd0]I5M00H0]I5M202dT5h20;NCH`040;JBHP2eTF40
/hmO0;:>GP80/HeM202dT6030;FAH@<0]91P0P2cSel00`2bSUh0/hmO0;B@H0020;FAH@030;B@H02b
SUh0/HeM0080/hmO0P2dT6020;FAH@80]Y9R202eTEl80;FAG@80]I5Q1P2dT6001P2gTF80]Y1Q0;J@
H@2eSf00]8iO0;>=GP80/XaM0P2aSE/20;:>G0040;>?G@2dT5h0]91N0;FAG`P0/XiL202bSUh80;6;
G0P0/hiJ202cSEh80;B>G`040;B@H02cSel0/HeM0;6=G@80/8aL00<0/HeM0;>?G`2dT6000P2`S5`2
0;6=G@`0/XiN202`S5`40;6=G@@0/XiN00<0[HeL0:j>G@2aSel00P2dT6000`2dSUl0]8]M0;>:G00>
0;:=F@80/HaH202`ReL00`2_REX0/8YK0;:<G@020;>=GP060;:<G@2aRe`0/8YK0:j:FP2_Re/0/HeM
0`2bSUh20;2<G0030:f9E@2^RUH0/8aH0080/HeI00<0/8aH0:n;E`2^RUH0102^RUX20:n;F`80/8aL
202]RED0102]RET0[XYJ0:j:FP2_Re/20;2<G080/HeM102bSET40;6<F0080;2;E`2_RUH0[XUE0:j9
E@2_RUH0/HaH0;>>FP2dSe/30:n;E`<0[XYF0P2]RED01@2ZQUH0ZhMG0:^7E`2/R5P0[XYJ0080[h]K
00<0/8aL0;6;G02aRe`01`2aRe`80;2<G080[hMD00@0[8MC0:^7D`2ZQU80Z8MB0P2WR5830:f9E@<0
[8QD0P2[Qe<60:f9E@80[8QD0P2]RET40:b8F080[HUI202/R5P80:f8E0060:V5D@2ZQU80ZhMC0:b8
E02]RED0[h]G0P2`S5P30:^8DP<0ZXMA0P2YQU020:f8E080[8MC0P2[QU820:Z5D@H0ZhEF0P2/QUL8
0:^6DP<0ZhMC102ZQU801`2YQE40[8MC0:^6DP2ZQE40ZHA@0:R3C`2WPTh00P2VPDd20:F0C080YX5=
00X0Yh9>0:R3C`2YQ500ZHA@0:^7D`2ZQU80ZHEA0:R4D02WPdl0YX9>0P2UPDd20:J2CP80Yh=?0P2X
Q5020:V5D@030:Z5D@2XPdl0YX5=0080YX5=00<0ZHA@0:b7D`2^RED02@2YQ5020:Z5D0030:V4C`2X
Pdh0Yh9=0080YX5<00<0YH1;0:J0C`2VP4l00P2WPE020:R2D@80ZH=B00P0ZHA@0:R3C`2WPTh0YX5=
0:N2CP2XPdl0ZXEA0:b7D`<0ZXMA102YQU000`2XQDl0Yh9>0:N2CP020:N2CP@0YX5=0P2WPTh60:J1
C@80Xgi90P2TOdX00`2UP4/0YX5<0:J1C0030:J1C0<0YH1;0`2TOdX80:=oB`80Z7i<0P2WOD/20:Il
BP80YG]90P2ROTX90:5mB@80X7a80`2ONdL20:5lB0040:9mB@2TOd/0YH1<0:N2CP80Z8=?1P2SOTX2
0:9mB@P0X7a8202QODd01`2NNDD0XWe90:F0C02TOd/0WgY609]f@P2LMd<00P2NNDD01`2PNdL0XWe9
0:AoB`2TOd/0XWe90:1kA`2NNDD00P2VP4l00`2VPDd0YX5<0:J1C0020:J1BP80YX980P2VPD`20:F0
B`80Y7m:0P2SOTT80:=nBP060:1kCP2PO4`0XGe=0:5mB`2QODT0XGi80P2PODD209ikA@0309mlAP2P
ODL0XGi80080XWm900@0Xh1:0:B0C02ROTX0Wg]70P2MNDD00`2NNTH0X7a80:9nBP060:9jAP80XGU5
00H0Xgm;0:9nBP2QODT0X7a809mkA`2MNDD209ahA00809miBP2NN4T0W7I709]eAP2JM4D0VgE609af
A`2MMdP609Yf@P80VGE10`2NND8209iiA0<0WWU5102MNT@409ai@`0409IaA@2IM4P0VgI:09]fB@80
VWI600<0W7Q609mkB@2KMT800`2KMT8409Ye@@0609ijAP2MNDD0W7Q409Yf@P2IMD40V7A00P2GLcl2
09]c@00409Ud@02HM400V7A009Ie@080UGI00`2HLcl309Mb?P80UW4m0P2HL3d209M_?080UVhk0P2E
KCX2099/?@80Tfdn0P2DKSl209E_@0T0U70l0P2AKCd03`2BKSh0Tflo09A`@02ELD40UW9209Mc@`2D
L3h0Tflm095]>`2@K3X0Sf/i091/>P2AKC/0TVhl091Z>`02095[?005099/?@2CKCh0U6ho09A^?`2E
Kd000P2<JS`0102=Jcd0SV`n091^@02AKd42099`@PP0SF/m00L0SVTl08mZ?@2@Jch0T6/n08mZ?@2=
J3/0RfHi0080RVDh00P0S6Lj08iY?02?JSd0T6/n08mZ?@2>JC`0SFPk08aW>P<0SFPk00@0SVTl08mZ
?@2?JSd0SfXm0P2:ICP00`2;IST0SFPk08eX>`0308iY?0<0S6Ph:oooool002[ooooo202BIc`01P2A
ID00TFDn095U?P2@IC/0T6Dj091U>080SfDe0`2AIST2099W>P<0TFHi0P2?I3T00`2@ICX0TFHk099W
?00209=X?@0309AY?P2?I3L0Sf@g0080Sf@g0P2@ICP00`2AIST0TVLj095V>@07095V>@0409EZ?`2D
JCh0TfXn091Z?@80SVTl00<0RfTk08YZ>`2CJ3/01`2CJ3/00`2;ICH0SVPi095[?00209A^?`03095[
?02>J3T0RfDf0080U6Pk102CIcX209AX>`T0UFTl0P2AIcD01P2CJCL0U6Xh09I/>P2GKC/0V6hl09U_
?@P0V6hl202IKcd209Y`?P80Vg4o0P2LLT0209ec@@080:=gAP2RMTD0XGE40:1d@`2NLT40WG5009a`
?`2KKch20:9d@`030:1d@`2OMD<0WWI30080W7M300L0VgM30:9iA@2QN4@0XGQ40:1g@`2OMT80WWE1
0080WGA00`2MLd4309id@P80WgE30P2PMT@609me@`0409eb?`2LLCh0W74n09aa?P80Vg0m0P2JKc`8
09ie@@P0WgE3202QN4@209mf@P80X7M30P2QN4@20:9iA@<0XGM50P2RN4H30:=iA`P0XgQ;2@2QN4@0
0`2RNDD0Y7]70:ImB@030:ImB@040:ElB02TNdL0YGa80:ElB0@0Y7]70P2SNTH50:F0B@030:AoB02S
OTL0Xgi70080XWe600<0XWe80:9mB@2SOD`00P2SODh0102SOE00YWe90:ImB@2VODT40:MnBP040:Qo
B`2VODL0YWe70:ImA`<0Ygi80P2XOdT30:V0C080Z7m;0`2WOTX80:QoB`H0ZH1<0P2ZPDd80:J1C@P0
[8=?202[PTh80:V0C080Z81=0`2YPDh30:Z2C`P0[8=?0P2ZPDd20:^2CP80[8=?0P2]Q5080:Z5D@08
0:R2E@2YPe@0ZH=D0:Z4D`2ZQE40ZhIA0:^6C`2/Qe030:b2D080[H=A0`2^Q5830:b7D`80ZhIB102Z
QE480:f8E0<0[XAB0P2]Pe430:b2D0P0[HA@0P2_QE<20;26E0@0/HME2P2^QE420:n6DP040;27D`2a
R5@0/HQD0;68E080/8YI00<0[hUH0:j8E`2]QeH00`2/QUD30:n:EP030:j9E@2]R5@0[HQD0080[8MC
0P2[QU820:b7D`80[HQD0P2^RED20:j:D0040:j9DP2^RE@0[XUD0:j9E@80[HMF0`2]RED20:j:EP<0
[h]G202_RUH40:^6DP80[8MC0P2]R5@20:n:EP80/8]G0P2aS5P20;:=F@@0/HaH102bSET30;B?F`D0
/hiJ202bSET80;>>FP<0/XaM0`2cSEh30;B>G`80]Y1Q00@0]HmP0;B>G`2dSUl0/heN0P2bS5d01P2_
ReL0/8aH0;2<F02aSET0/XiJ0;>?F`80]91L0`2cSEh30;B>G`80]HmP402cSel20;B?F`80]I1L0P2f
TEd20;NBGP80]Y1Q102gTF820;J@H@80^9=O0P2gTUh20;JAG@80]I1L0P2hTel20;NBGP80]Y5M102e
T5`40;B?F`80/hiJ0`2dSe/00`2eT5`0]8mK0;B?F`020;>>FP80]I1I00<0]8mJ0;B?F`2dSUd00P2c
SEh0102cSF00/heN0;>=GP2cSEh20;B>G`<0]HmP0P2cSel30;B@H0<0]I5Q0`2eT5`20;B?F`<0/hiJ
202dSUl80;F@G080]91P0`2eTF430;JBHP80]8mH00<0]8mJ0;B?F`2dSUd00P2dSUl00`2dSV40]HmP
0;F?H00?0;F?H0P0]91P0`2fTEd30;F@G080]8mK202gTUh40;JBHP@0]I5Q00L0]i=S0;JBHP2dT600
/hmO0;B@H02eTF40]Y9R00T0]i=S202eTF420;NDG0030;NDGP2gTel0]i=Q0080]i=S00<0]i9U0;JB
GP2fTUh01P2fTUh01P2fTed0]Y9N0;JBGP2gTf40]i=S0;NBI@80^9=W202gTf<20;FAH@80]Y9R0P2g
Tf<20;RDI0P0^9AP0P2gTf<20;JBHP80]I5Q102dT6020;FAH@80]Y9R0P2gTf<50;JBH0030;FAG`2d
T5h0]91N00@0]I5Q102fTV850;FAGA@0]91L00P0^9AT0;NCH`2fTV80]I5Q0;B@H02cSel0/XiN0;6=
G@/0]I5Q0`2dT6020;>?G`030;6=G@2bSUh0]91P0080]I5Q00<0]91P0;>?G`2bSUh00`2cSel20;B@
H0<0]I5Q402dT5`60;B@H080]I5Q0P2fT6400`2eSf00]8iO0;>=GP020;:<G@060;6;G02aSEd0/HeM
0;:>GP2cSel0]91P0P2eTF400`2fTV80/XiN0;:>GP0>0;:>GPP0/8YK202cSUX80;>=GPP0]8iO00@0
/hmO0;:>GP2aSEd0/HeM0P2`S5`00`2aSEd0/XiN0;>?G`020;6=G@<0/XiN0`2cSel80;:>GPP0/8aL
202bSUh00`2]SE`0[XiM0;2>GP020;>?G`030;>=GP2dRed0/hYL00P0/XeI1P2aS5P20;:=F@P0/8]G
00<0/8YK0;6;G02bS5d00P2cSEh03P2bS5d0/8YK0:n9FP2]RET0[XYJ0;2<G02bSUh0/hmO0;:>GP2a
SEd0/8aL0:j:EP2_ReL0/8aH0P2aSET00`2`S5P0[XYF0:f9E@040:j:FP80[h]K0P2`S5`80:j:EP80
[HUI00<0[XYJ0:n;F`2`S5`00P2aSEd00`2bSUh0/hiJ0;>>FP020;:=F@80/HaH0P2`ReL20:n:EP80
[XUE00@0[hYF0;6<F02cSUX0]I1L0P2_ReL30:j:EP<0[HUE0P2_Re/0102^RUX0[HUI0:b8F02[QeL2
0:Z6EPT0/8YK202_Re/20:n7E0060:f8E02/R5@0ZhMC0:V8D`2WR580YXMA0`2]RED30:b8E080ZhMC
0P2/R5@60:f9E@P0[HUI202/R5P80:b7D`060:V5D@2ZQU80ZhMC0:b8E02]RED0[h]G0P2`S5P30:^8
DP<0ZXMA0P2YQU030:b7D`80ZhIB0`2ZQE420:b6E`H0ZhEF202[QU820:b8E080ZhMC00D0ZXIB0:V5
D@2YQE40ZHEA0:^6DP020:Z5D@030:V4D02XPdl0Z8=?0080Yh9>0P2UP4`20:J1C@050:N2CP2XPdl0
ZHA@0:V4D02ZQU800P2YQE400`2XQ500Yh=?0:N3C`020:J2CP80Yh=?102XQ5020:V5D@080:V4D02X
Pdl0YX5=0:F0C02VPDd0ZHA@0:b7D`2^RED90:V4D0060:Z5D02YQ4l0ZHA?0:R3CP2WPTd0YX5<0P2U
P4/20:J1C@80Yh9>0P2XPdl20:V4D0030:Z5D@2YQ500Z8=?0080Yh9>00<0ZHA@0:^6DP2/Qe<00`2Z
Qe400`2YQU00Z8E?0:R5C`020:N4CPh0YX5=0P2WPTh00`2TOdX0YH1;0:F0B`020:F0B`H0YX5<0`2U
P4/20:AoBPP0Xgm;0`2XOT`20:MmB`<0YWa:0P2QODT80:9nBP80XGe90P2PO4P209mkA`80XGa800@0
XWe90:=nBP2UP4`0YX5=0P2WPTh60:9mB@80Xgi:202QODT80:1lC00509ehA02QO4P0Y7m;0:=nBP2O
NTH00P2LMd<209iiA@070:1kA`2RODT0Y7m;0:AoB`2RODT0X7]709iiA@020:EoCP030:F0C02UP4/0
YH1;0080YH190P2UPDL30:F0B`<0Y7m:0P2SOTT80:9lB`060:1kCP2PO4`0X7a<0:1lBP2PO4P0X7e7
0P2PODD209ikA@0309mlAP2PODL0XGi80080XWm900T0Xh1:0:F1C@2SOd/0X7a809ijAP2MNDD0Wg]7
0:5mB@2ROTX01P2PNdH20:5lA`80XWi:00h0XGe909mkA`2NNTH0WGU509ahA02KMd<0WgU:09ihB@2L
MTL0VgE609YdA@2KMDH0W7I709egB0H0VWI20P2KMd<309iiA@80WWU40`2NND8409ai@`@0WGY400T0
UW1;09YdC@2NNDl0WGQ<09UdA`2HM4@0W7Q60:1lB02PNdL00P2ONTH209iiA@80WGQ400T0W7M309ei
A@2MNDD0W7Q409]g@`2JMT80V7A009Mc?`2FLSh00P2KLd00102IM400V7A009Qd@02FMD0209Ef@0<0
V7<o0`2GLSh509Ia?@80UG0l0`2DKc/409=]?P@0U6ho2@2DL3`2091/?00>099^?P2CKcl0UG5109Ib
@P2GLd<0V7A409A`@02CKcl0TFdm091/?02?Jc/0T6`l095]?@2BKSh2091Z>`04095[?02BK3d0TV`m
09=]?P80U6ho00P0S6Xm08e[?P2>K3l0Sfe0091^@@2AKd80TW1309=aA0@0SF/m102<JS`03`2>JC`0
SfXm08mZ?@2@Jch0SfXm08eX>`2:ICP0RF@g08YU>02<IcX0SVTl08mZ?@2@Jch0SfXm08iY?00608eX
>`<0SVTl0P2:ICP208]V>@0408aW>P2=J3/0SVTl08mZ?@<0SFTi:oooool002[ooooo202CJ3d0202C
Id80TfM0099V?`2AIS`0T6Dj08mT=`2>I3@0SF<c0P2@ICP0102AIST0TVLj099W>P2AIST2091U>080
Sf@i0P2@ICX01@2AIS/0TVLl09=X?@2CJ3d0T6Dh00<0Sf@g00@0T6Dh099W>P2CJ3/0U6Tl202BIcX2
099Y?@04091Z?@2?JSd0SfXm08e[?@80S6`m202CJ3/00`2<ISL0SVPi091Z>`02099/?@04091Z>`2>
J3T0S6Hg09AX>`80TfLj00D0TVHi09=W>P2CIcX0U6Pk09EY?00409IZ?@80UFTl0`2DJ3/208iT<P05
091V=02CJCL0UF/i09M]>`2IKcd00P2JL3h309U_?@<0V6hl00<0Ufdk09U_?@2IKcd01P2IKcd209Y`
?P80Vg4o0P2LLT0209ec@@80XWI500@0XGE40:1d@`2NLT40WG500P2LL3l20:9d@`030:1d@`2OMD<0
WWI30080W7M300@0VgM30:1g@`2PMd<0X7M30`2OMT8209ie@@80W7900P2MLd4309id@P0409me@`2P
MT@0X7I40:1fA0<0WgE30P2NM48309aa?P80Vg0m0`2JKc`209mf@P@0WGA00P2OMT8809me@`P0XGQ4
0P2OMT820:1g@`80XGQ40P2RNDD20:5gA@80XWQ60`2SNDL00`2TNTP0Y7U<0:AiC0060:AiC0P0XWU5
00<0XGQ40:9iA@2TNdL0102VODT00`2UO4P0Y7]70:EjA`040:EjA`<0Y7U6102UP4T02@2TOdP0XWe6
0:1kA02ONT<0XGa50:9mAP2RODP0XWe90:=mC0020:=mCP030:AnD@2WOTX0Ygi:00H0Ygi:0`2VODL3
0:MnB080Z7m90`2YP4`20:QoB`<0Ygi:202XOd/20:QnC0<0ZGm=0`2ZP4h80:J1CA00Zh9>202YP4`3
0:UoC@80ZX1>0`2[PDl80:^2CP<0ZX5=0P2[PTh30:b3C`P0ZXEA00H0Yh9E0:N3D`2XQ5@0ZHEC0:V5
D@2ZQe420:^8D0<0[89@0P2]Pe430:j4DP80[8MC0P2[QU840:Z5D@030:V4D02/Qe<0[8MC00H0[8MC
0`2^Q5820:f3D@<0[89@202]Q500102^Q580[hEC0:n5D`2_QE<20;26E080/HME00@0[hIB0:j5D@2^
QE40[XEA0`2]Q5001@2/Pdl0[XEA0:j5D@2_QU80/8MC0080/HQD0P2bRED01@2`RU/0[hUJ0:j8F@2]
QeP0[8IG0080[HMH00H0[XQI0;2;E`2`ReL0[hYF0:j9E@2]R5@20:b7D`<0ZhIB0P2/Qe<20:f8E080
[XUE0P2_Re40102^RE80[XUD0:j9E02]R5@20:f7EP<0[HUE0P2^RUH30:n;E`P0[hYF0P2/Qe<30:^6
DP030:b7D`2^RED0[hYF00<0/8]G0P2aS5P30;:=F@@0/HaH102bSET30;>>FP<0/XeI0P2aS5P80;:=
F@P0/hiJ0`2bS5d30;>=GP<0]8iO0`2eSf020;B>G`<0/heN0`2aSET30;:>FP80/hmK0P2bS5d20;>=
GP<0]8iO00<0]HmP0;B@H02dT6001P2dT6080;>?G`<0]I1L0P2fTEd30;NBGP030;F?H02fT640]i5R
0080^99S00<0]i5R0;J@H@2eSf000P2hTel20;NBGP80]Y5M0P2eT5`20;RCG`80]i9N0P2fTEd20;F@
G0X0]8mK0`2eT5`02`2dSe/0/hiJ0;:=F@2eT5T0]8mH0;B?FP2dSe/0/heL0;>=GP2bS5d0/XaO00<0
/heN0P2dSUl30;F?H080/hmO0`2dT6030;FAH@<0]I1L0P2dSe/30;>>FPP0]8iO202eT5`30;B@H080
]I5Q0`2fTV820;B?F0030;B?FP2dSe/0]8iM0080]8iO00<0]8iQ0;F?H02eSf003`2eSf080;B@H0<0
]Y5M0`2eT5`20;B?F`P0]i9N00@0]i=S0;JBHP2fTV80]Y9R0`2eTF400`2dT600]Y9R0;FAH@030;>?
G`030;FAH@2fTV80^9AT00P0]Y9R202eTF420;NDG0030;NDGP2gTel0]i=Q0080]i=S00<0]i9U0;JB
GP2fTUh01P2fTUh01P2fTed0]Y9N0;JBGP2gTf40]i=S0;NBI@80^9=W202fTV830;FAH@80]Y9R0`2g
Tf<80;RDH080]i=S0P2fTV820;FAH@@0]91P0P2eTF420;JBHP80]i=S00<0]I5M0;JBGP2gTel00P2g
Tel0102eTEd0]91L0;>?F`2dT6030;FAH@<0]Y9R00<0]i=S0;FAG@2eTEd01`2eTEd80;B@G0P0]95K
0P2gTf<0102fTV80]I5Q0;FAH@2dT6020;>?G`/0]I5Q0`2dT6020;>?G`030;2<G02aSEd0/hmO0080
]I5Q00@0]91P0;>?G`2bSUh0/XiN0`2cSel20;B@H080]I5Q202dTE/80;B@G080/hmO0`2dT6030;FA
H@@0]8iO0`2cSEh00`2bS5d0/8iP0;2>H0020;6?H@040;:@HP2cTF<0/i5S0;BBI0P0/XeP202bSUh8
0;2:F`P0/hiJ202cSEh80;B>G`040;>?G`2bSUh0/8aL0;2<G080[h]K00<0/8aL0;:>GP2cSel00`2b
SUh20;>?G`<0]91P202bSUh80;2<G0040;B@H02cSel0/hmO0;>?G`<0/XiN00@0/HeM0:b<F`2]SE`0
/8iN0P2cSel00`2cSEh0/hYL0;:9F`080;:=F@080;6<F02`ReL0/8]G0:n:EP2`ReL0/HaH0;:=F@2c
SUX80;2;E`0<0;6;G02bS5d0/heN0;B>G`2cSEh0/XaM0;2:F`2_REX0[8QH0:j:FP2`S5`0/XiN0P2c
Sel0102bSUh0/HeM0:n;E`2_ReL30;6=F@030:n;E`2^RUH0[8QD00<0[h]K0`2`S5`20;6=G@P0[h]G
00@0[HUI0:j:FP2^RUX0[h]K0P2`S5`20;6=G@050;B?F`2cSUX0/hiJ0;:=F@2aS5P00P2`ReL00`2_
RUH0/8]G0:n:EP020:j9E@050:n:EP2aS5P0/hiJ0;B?F`2_ReL00`2^RUH20:f9E@80[8QD00P0/HeM
0;2<G02_Re/0[HUI0:^7E`2YQED0Z8AD0:N3D`T0/8YK202_Re/00`2]QE80[XIC0:f8E0020:f9E@03
0:^:E@2YRU@0Z8UC00<0[XYF0`2]RED50:b8E0<0[HUE0P2^RUH00`2/R5P0[HUI0:j:FP020:n;F`03
0:j:FP2]RET0[8QH00P0[8QH202[QU820:^7D`80[8QD00@0[HUE0:j:EP2_ReL0[h]G0`2[R5830:Z7
D@80ZHI@0P2/Qe<20:^6DP<0ZXEA00@0ZHA@0:b6E`2/QUL0[8IG0`2[QEH20:Z4E@P0ZhIB00H0[HUE
0:b8E02/R5@0ZhMC0:Z6DP2YQE420:R4D0<0ZXEA00D0ZHA@0:R3C`2XPdl0Z8=?0:N2CP020:J1C@04
0:N2CP2XPdl0Z8=?0:V4D080ZXEA0`2YQE401@2XQ500Yh=?0:N3C`2WPdl0YX9>00D0Z8A@0`2YQE42
0:R3C`<0Yh9>00<0Z8=?0:V4D02ZQE402@2YQ5020:V4C@030:R3C02WPT/0YX5:0080YH1900<0Y7m8
0:J1C02VPD`00P2WPTd20:R3CP80ZHA?00T0ZXEA0:V4D02XPdl0Yh9>0:R3C`2YQ500ZhIB0:b7D`2[
R5800P2ZQe400`2YQU00Z8E?0:N4CP020:J3C@040:AoB`2UP4`0YH1<0:F0C0<0YX5=00<0Yh9>0:F0
C02UP4`00`2VPDd30:N2CPP0YX5<0P2WPTd20:J1C0<0YH1;00<0Y7m:0:=oB`2SOd/01P2SOd/0102Y
Odd0Z7i<0:QnC02XOT`20:MmB`80YWa:0P2QODT30:9nBP<0Xgm;0`2ROTX20:5mB@<0X7a800@0XGa8
0:9mB@2RODT0XWe90`2SOTX0102TOd/0XGa80:5lB02QO4P30:9mB@80Xgi:202QODT80:1lC00709eh
A02RODT0YH1<0:AoB`2PNdL0WGQ409iiA@020:1kA`030:5lB02RODT0XWe90080XWe900D0XGa80:1k
A`2TOTd0Y7i=0:AoB`020:AoBP80Y7m80P2TP4H50:=nB@<0XWe8202RO4d0202QO4l0X7a<09mkB`2N
NTP0WWY609mlAP2PODD0XGi60P2NNdD00`2OO4H0X7e70:5nB0020:9oB@060:>0BP2SOd/0XWi:0:5m
B@2PO4P0Wg]70P2PO4P00`2QODT0Wga609mlAP0209mlAP80X7e70P2QOTP30:1lB00309mkA`2NNTH0
WGU50080W7Q400P0WgU:09ihB@2LMTL0VgE609YdA@2KMDH0W7I709egB0@0VWI20P2KMd<209ahA004
09ihB@2NN4L0WWU509iiA@80WWU200<0WWY009ij?P2KMd<00`2LN4@309eiA@0:09ijAP2HLE80WWMF
0:9lE`2PNU<0VGA709Mc@`2KMd<0XGi80:9mB@80XGa800<0X7]709mjAP2NNDD00P2MN4@0202JMT80
VgM309]g@`2KMd<0VWI209Ue@@2GLcl0UW8n0P2KLd00102IM400V7A009Qd@02FMD0209Ef@0<0V7<o
0`2GLSh209Ia?@0409Ib?P2ELCd0UG4m09Ea?@80U70l0P2CKc/409=]?P@0U6ho2@2CKc/01P2@K3`0
TFdm099^?P2CKcl0U71009Ib@P80Ug=300P0U6m209=^@@2AK3l0T6/n08mZ?@2@Jch0TF`o099]@0@0
TF/l0`2BK3d0102CKCh0SV]108i[@@2?K482091]@`03095^A02BKdD0TVm500<0SF/m0P2<JS`308]Y
>`0@08eX>`2>JC`0SfXm08mZ?@2>JC`0S6Lj08YU>029I3L0RVDh08aW>P2>JC`0SfXm091[?P2?JSd0
SVTl08eX>`<0SVTl0P2=J3/208aW>P0308]V>@2<IcX0RfHi00<0RVDh00<0S6Lj08eX>`2>JC`00`2=
JCT[ooooo`00:_ooool8091U>P06091T?`2@I3d0T6@m091U>`2@ICX0T6Dh0P2AIcL00`2?I3L0T6Dh
095V>@02099W>P03095V>@2@ICP0Sf@g00@0T6Dj102AIS/2095V>@80T6Dh00@0TFHi09=X>`2EJSd0
Uf`o202DJC`01P2?ISX0SVPk08iX>`2>JC`0SF/m08e]?P80SFho202CJ3/208iX>@@0SfTj0P2>J3T0
0`2DJ3/0TfLj099V>@03099V>@0409AX>`2FJSd0Uf/n09M[?P80UVXm0P2EJC`209AX>`0909=W>P2@
IS@0T6Hd095W=@2BJ3H0U6Xh09E[>@2FK3X0Ufdk00<0VW0n00<0VFlm09Q^?02HKS`00P2GKC/809U_
?@80VW0n0P2KLCl209ab@080WG=10P2QMD@0102PM4<0Wg=209mc@P2NLT4209ea@080XWA300<0X7A3
09me@`2NMT<00P2LMd<00`2KMd<0WWE109ie@@0309mf@P<0X7M30`2LLT0209ec@@<0WWA20P2QMdD2
0:1fA00409me@`2NM480WWA209id@P<0X7E20P2OM44309ic@0030:1g@`2OMT80WGA00080W7<o00<0
WGA009mf@P2PMd<0202NM4880:5hA080WgI20P2PMd<20:5hA080XWU50`2RN4H30:=iA`80Y7Y8202T
ND`80:=jAP030:5hA02RNDD0Y7]700@0YWe900<0YGa80:AkA`2VN4H01@2VN4H20:MiA`0309mj@`2Q
O4D0XWe60080Y7m800<0Xgi70:5lA@2PNd@00P2QO4D01P2RODP0XWe90:=mC02SODh0Y7i?0:AnD@H0
Ygi:0P2VODT30:ImA`<0Ygi80P2XOdT30:V0C080Z7m;0`2WOTX80:QoB`<0Z7i>00<0ZGm?0:Z0D02Z
P5000P2[PE480:F0C0P0ZX5=202[PTh80:QoB`80Z7i<0P2YOdd30:Z0CP030:^1C`2[PTh0Zh9>00H0
Zh9>102ZPDd20:^2CP80[8=?202ZQE40202TPU@0YH=C0:F3D`2VQE80Z8MB0:V8DP2YRE00ZXYA0`2/
PU020:f3D@<0[XAB0`2[QU830:Z5D@<0ZHA@202[QU830:j4DP80[H=A0`2/PU080:f4D0040:f3D@2^
Q580[XAB0:j4DP80[hEC0P2`QU@20:n6DP80[XEA00@0[HA@0:b3C`2/Pdl0[8=?0P2^QE40102_QU80
/8MC0;68E02bRED20;>:EP030:n9FP2^R5T0[8IG0080[8IG00T0[HMH0:n9FP2aRe`0/HaH0;2;E`2_
RUH0[XUE0:f8E02/Qe<0102[QU820:b7D`80[HQD0P2^RED20:n;D@040:n:D`2^RE@0[HQC0:f8E080
[8IE0`2]RED20:j:EP<0[h]G202_RUH0202^RED0[HQD0:b7D`2[QU80[8MC0:f8E02_RUH0/HaH0P2`
ReL20;6<F0P0/XeI102aS5P30;:=F@030;6<F02`ReL0/8]G0080[hYF202bSET80;B?F`<0/XaM0`2c
SEh30;B>G`<0/heN0P2dSUl30;F?H080/hmK0`2bSUX30;6=F@<0/XaM0P2cSEh30;B>G`P0]91P202c
Sel20;F@G080]Y5M102gTUh00`2eSf00]Y1Q0;NAHP020;RBH`030;NAHP2fT640]HmP0080^9=O0P2g
TUh20;JAG@80]I1L0P2hTel20;NBGP80]Y5M0P2eT5`90;B?F`070;F@G02fTEd0]Y5M0;JAG@2dSe/0
/XeI0;2;E`020;B?F0030;B?FP2cSUX0/heL0080/XaM00@0/XaO0;>=GP2cSEh0/heN0P2dSUl30;F?
H080/hmO0`2dT6030;FAH@<0]I1L0P2dSe/30;>>FPP0]8iO202eT5`20;>?G`80]91P0`2eTF401P2f
TV80]8mH0;B?F02dSeX0]8mK0;B>G@80]8iO00<0]8iQ0;F?H02eSf003`2eSf080;>?G`<0]Y5M0`2e
T5`20;B?F`P0]i9N0P2gTf<20;JBHP80]I5Q0P2dT600202eTF40]91P0;>?G`2bSUh0/hmO0;FAH@2g
Tf<0^9AT202fTV880;B@H080]iAL00<0]iAN0;NCG`2gTf400P2gTf<00`2gTVD0]Y9N0;JBGP060;JB
GP060;JCG@2fTUh0]Y9N0;NCH@2gTf<0]i9U0P2hTfL80;JBHP@0]I5Q0P2fTV820;NCH`P0^9AP0P2g
Tf<20;JBHP80]I5Q102dT6020;FAH@80]Y9R0P2gTf<0202eTEd0]Y9N0;NCG`2hU600]i=O0;JBGP2d
T5`0/XiJ0P2dT6020;FAH@80]Y9R0P2gTf<60;FAG@<0]Y9N202cSe/80;BAF@80]Y9R4@2eTF430;B@
H080/hmO00@0/8aL0;6=G@2cSel0]91P0P2eTF40102dT600/hmO0;:>GP2bSUh30;>?G`<0]91P202c
T5P80;>?F`<0/hmO00<0]91P0;FAH@2eTF400P2fTV830;:<G@80/heN0`2dSUl20;2?HP@0/I1S0P2b
TF@80;>>HPP0/XiN202_REX80;>>FPP0/heN202dSUl0102cSel0/HeM0;2<G02`S5`20:n;F`030;2<
G02aSEd0/hmO00<0/hmO0P2dT6030;FAH@P0/XiN202aSEd30;B@H0030;>?G`2bSUh0/XiN0080/HeM
00<0[8aK0:f=G02_SEd00P2cSel00`2bS5d0/hYL0;:9F`080;:=F@080;6<F02`ReL0[hYF0:j9E@2_
RUH0/HaH0;>>FP2dSe/80;2;E`0<0;6;G02bS5d0/heN0;B>G`2cSEh0/H]L0:n9FP2^R5T0[8QH0:f9
F@2`S5`0/XiN0P2cSel20;:>GP030:n;E`2`S5P0/HeI0080/HeI00<0[h]G0:f9E@2/R5@00P2`S5`3
0;6=G@<0/XiN202aSET50:n;F`<0/8aL0P2dSe/0102cSUX0/XeI0;6<F02`ReL20:n:EP080;6<F02`
ReL0[hYF0:j9E@2_RUH0/8]G0;:=F@2cSUX30:j:EP80[HUE0`2/R5@20:j:FP030:f9F@2/R5P0ZhMG
0080ZXIF00<0ZHEE0:n9FP2_REX01`2_REX80:j:FP080:b4D@2^QU<0[XUE0:n;E`2`S5P0[XeH0:b=
E`2[S5H20;2<F0<0[h]G0`2^RUH20:^7D`80[8QD00L0[HUE0:j:EP2^RUH0[XYF0:b8F02]RET0[h]K
0080/8aL00<0[h]K0:f9F@2/R5P0202/R5P80:Z5D@030:b8E02]RED0[HUE00D0[HUE0`2[R5830:Z7
D@80ZHI@0`2[QU830:Z5D@80ZHA@0P2]QeP20:b6E`040:^5EP2ZQ5D0ZXAE0:Z4E@P0ZhIB0P2]RED0
1`2/R5@0ZhMC0:Z6DP2YQE40Z8A@0:N3C`2ZQE40102YQ5030:R3C`80Yh9>00@0Z8=?0:V4D02ZQE40
ZhIB0P2/Qe<00`2YQE40Z8A@0:R4D0020:R4D0<0Yh=?1P2YQE420:R4D0030:N2CP2XPdl0ZHA@0080
ZHA@00<0Z8=?0:J1C@2VPDd02@2YQ5020:V5B`040:R4BP2WPdT0YX980:F1A`80Y8160P2VPDX20:N2
B`80Z8=<0P2YQ4d00`2ZQE40ZHA@0:R3C`020:R3C`040:Z5D@2/Qe<0[HQD0:^8DP80ZXMA00D0ZHI@
0:N4CP2VPdd0YX==0:F2C0030:AoB`030:F0C02VPDd0YX5=0080Yh9>0`2UP4`00`2VPDd0Yh9>0:N2
CP020:R3C`P0YX5<0`2WPTd20:J1C0<0YH1;202SOd/20:UoC@<0Z7i<0`2WOD/20:5mB@80XWi:0P2S
Od/20:B0C0@0XWi:0P2QODT20:1lB080XWe90P2QO4P30:1kA`0309mjAP2PNdL0X7]70080XGa80P2R
ODT20:=nBPP0XGe9202ONd/01`2NNDD0Xgi:0:J1C@2VPDd0XWe909mjAP2PNdL00`2RODT0102QO4P0
X7]70:1kA`2QO4P20:9mB@80XWa;00<0XWe90:9mB02RODP00P2RODH20:9nA0<0X7]61@2QO4L80:5k
C0080:5lC`2PO4`0WWY:09eiA`2MNDD0WW]50:1mA@2QOTH209ikA@0309mlAP2PODL0XGi80080XWm9
00X0Xh1:0:5mB@2ROTX0XWi:0:=oB`2ROTX0XGe90:1lB02ONdL0W7]50P2MO4H209imA`80Wgi800<0
X7m909ijAP2NNTH01P2NNTH02@2ONDX0WWQ909afA`2KMDH0VWA509]eAP2LMTL0WGM809Ue@@0209Yf
@P80VgM30P2LN4@02@2MNDD0WWQ;09ihB@2NN4L0WWU509ii@P2NNT00WWXn09ij?00209]gA@80W7Q6
0P2MNDL209ijB00>09]dE`2RNeh0YWmN0:=mEP2JMDT0UW9209]g@`2QOTP0X7]709mjAP2NNDD0WGQ4
09ag@`2KMT8209Ye@@0309Mc?`2HM400VWI20080VgM300<0VWI209Qd@02GLcl00P2KLd00102IM400
V7A009Qd@02FMD0209Ef@0<0V7<o0`2GLSh209Ia?@80U7<n0`2CLSd3099a?0@0U6ho102CKCh909=_
>`80TVhn0P2CKcl0302DL400UG5109Ea@@2FLT80U6m309=^@P2AK400T6/o08mZ?P2@Jcl0TFa0099]
@@<0TV`m0`2AJc`2091Z>`H0T6e30P2AKT@308e[?@0308aZ?02;JC/0RfTk0080RVPj0100SFPk08iY
?02?JSd0SfXm08iY?02<IcX0RVDh08QS=P2:ICP0S6Lj08iY?02?JSd0T6/n08mZ?@2>JC`0SFPk0P2@
Jch0102?JSd0SFPk08aW>P2:ICP208UT=`0308iY?02=J3/0RfHi0080RF@g00<0RVDh08]V>@2<IcX0
0`2=JCT[ooooo`00:_ooool808aQ=P0;08aP>`2<H3T0SV8k08mT>P2AIS/0TfPk09AZ>P2EJc/0SV<f
08mT=`2AIST00P2CJ3/00`2AIST0Sf@g08iS=P02095V>`H0T6Dj0P2BIcX01P2AIST0T6Dh099W>P2D
JC`0Uf`o09U^@@P0UFXm0P2<IST01P2<IcX0S6Xl08e]?P2>KSl0SVm008m`@@P0TfPk00<0T6Xk08mY
>P2>J3T00P2=IcP01`2>J3T0SfTj091Z>`2DJ3/0TfLj099V>@2AICP00P2BIST00`2DJ3/0UVXm09Q/
?`0209M[?P0409IZ?@2EJC`0UFTl09AX>`80TfLj1`2CJCL0102BJ3H0Vg4o09]a?`2JL3h209U_?@03
09Q^?02GKC/0Ufdk00P0VFlm0P2JL3h209]a?`80W7900P2MLd420:1d@`@0Wg=20P2NLT420:9d@`03
0:1d@`2OMD<0WWI30080W7M300H0VgM309ed@02MM400WWE109mf@P2PMd<20:5hA0040:9iA@2LLT00
W79009ab@0<0WG=10P2NM4820:5gA@80X7I400D0WgE309id@P2NM480WG=10:EjA`030:AiAP80XgQ5
0P2RMd@00`2PMd<0WgI209ed@00209ac?`0309ed@02OMT80X7M300P0WWA2202QN4@209mf@P80X7M3
0P2QN4@20:9iA@<0XWQ60P2SNDL30:AjB0P0Y7U<202TNdL00`2QN4@0XWU50:AkA`040:ImB@040:El
B02TNdL0YGM50:EgA@@0YWQ60P2WNDL0102JMCh0W7M009mj@`2RODH30:AoB0060:=nA`2QO4D0XGa5
0:5lA`2RODT0Xge<0P2TOTl00`2TOU40Ygi:0:MnBP030:MnBP<0YWe90`2VODL30:MnB080Z7m90`2Y
P4`20:QoB`<0Ygi:202XOd/0102WODd0Z7i>0:QnCP2YOdl20:Z0D080Zh5A202UP4`80:V0C0P0Zh9>
202XOd/20:UmC080ZWi=102[Odh80:^2CP040:V0C02ZPDd0ZX5=0:Z1C@80Zh9>0P2/Pdl80:Z5D@06
0:B2E02TPU80YH=C0:J5DP2XQe80ZHQB0P2ZRU430:b2D080[H=A0`2^Q5830:^6DP80ZXEA302YQ503
0:j4DP80[H=A0`2/PU080:f4D0040:b2D02]Pe40[H=A0:f3D@80[XAB0P2_QE<20:n6DP040:j5D@2]
Q500[HA@0:b3C`80Zh9>0P2^QE403`2_QU80/8MC0;68E02bRED0/hYF0;B;E`2^R5/0[HMJ0:b6F@2[
QEP0[8II0:j8F`2aReh0/XaO0;6<F0020;2;E`030:j9E@2]R5@0[8MC00@0ZhIB0P2/Qe<20:f8E080
[XUE00H0/8aB0:n;D@2_RU<0[XUD0:f8D`2]R5@20:b6E@<0[HUE0P2^RUH30:n;E`T0[hYF00L0[XUE
0:f8E02/Qe<0[8MC0:j9E@2`ReL0/XeI0080/8]G0P2aS5P30;:=F@030;>>FP2bSET0/XeI0080/XeI
102aS5P0102bSET0/HaH0;6<F02`ReL20:n:EP80[XUE202bSET80;B?F`<0/XaM0`2cSEh30;B>G`80
/XaM00@0/heN0;B>G`2dSUl0]HmP0P2fT6420;B@G0030;>?F`2bSUX0/HeI0080/8aH00@0[h]G0;:<
G@2bS5d0/XaM0`2cSEh20;B>G`P0]91P202cSel20;F@G080]Y5M0`2gTUh0102hTel0]8iO0;J@H@2g
TF820;VCI0030;NAHP2fT640]8iO0080^9=O0P2gTUh20;JAG@80]I1L0P2hTel20;NBGP80]Y5M0P2e
T5`20;>>FP@0]8mK0P2eT5`0202dSe/0]I1L0;JAG@2gTUh0]Y5M0;B?F`2aS5P0/8]G0P2dSeP00`2c
SUT0/hiJ0;>=G0020;:<G@040;:<G`2cSEh0/heN0;>=GP80]8iO0`2eSf020;>?G`<0]91P0`2eTF43
0;F@G080]8mK0`2cSUX80;B>G`P0]I1L0P2cSel20;B@H0@0]I5Q0P2dSeP00`2dSeX0]8mK0;B>G@02
0;B>G`030;B>H@2eSf00]HmP00l0]HmP202cSel30;JAG@<0]I1L0P2dSe/80;NBGP<0]i=S00<0]Y9R
0;FAH@2dT6000`2dT6001`2cSel0/XiN0;:>GP2cSel0]I5Q0;NCH`2hU6@0202fTV880;B@H080]iAL
00<0]iAN0;NCG`2gTf400P2gTf<00`2gTVD0]Y9N0;JBGP060;JBGP060;JCG@2fTUh0]Y9N0;NCH@2g
Tf<0]i9U0P2hTfL80;JBHP040;B@H02eTF40]I5Q0;FAH@80]Y9R0P2gTf<80;RDH080]i=S0P2fTV82
0;FAH@@0]91P0P2eTF420;JBHP80]i=S00<0]95K0;JCG@2gU5h00P2hUEl00`2fTed0]95K0;:?F@03
0;B@H0030;FAH@2fTV80]i=S0080]i=S1@2eTEd40;JBGPP0/hmK202dTET0102dT600]I5Q0;FAH@2e
TF430;JBHP030;NCH`2eTF40]I5Q00T0]I5Q0`2dT6020;>?G`040:n;F`2aSEd0/hmO0;B@H080]I5Q
00<0]91P0;>?G`2bSUh00P2bSUh20;>?G`<0]91P202cT5P80;>?F`040;:>GP2cSel0/hmO0;B@H080
]I5Q0P2fTV820;6;G080/XaM00@0/heN0;B>G`2eSf00]HmP0P2bTF@60;6@H`P0/hiR202bSUh80:n9
FPP0/hiJ202cSEh80;B>G`040;:>GP2aSEd0/8aL0;2<G080[h]K00<0/8aL0;6=G@2bSUh00`2cSel2
0;B@H0<0]I5Q402bSUh20;FAH@040;B@H02cSel0/hmO0;:>GP80/HeM00<0[8aK0:f=G02_SEd00P2b
SUh00`2bS5d0/hYL0;:9F`080;:=F@030;6<F02`ReL0[XUE0080[XUE00<0/8]G0;>>FP2dSe/0202`
ReL20;:<G@0:0;>=GP2dSUl0/heN0;6;G02_REX0[XQI0:b8F02]RET0[h]K0;:>GP80/hmO0P2bSUh0
0`2_ReL0/8aH0;6=F@020;6=F@030:n;E`2]RED0[8QD0080/HeM0P2bSUh40;>?G`P0/XiJ0P2`S5`6
0:n;F`0@0;F@G02dSe/0/hiJ0;:=F@2aS5P0/8]G0:n:EP2^RED0/XeI0;6<F02`ReL0[hYF0:j9E@2_
RUH0/HaH0;:=F@80[XYF0`2]RED30:b8E080ZXIF0P2[QeL20:b8F080[HUI2@2_REX80:j:FP080:b4
D@2^QU<0[XUE0;2<F02aSET0[hiI0:j?F@2]SUP20;6=F@<0/8aH0`2_ReL20:^7D`80[8QD00L0[HUE
0:j:EP2^RUH0[h]G0:b8F02]RET0[h]K0080/8aL00<0[h]K0:f9F@2/R5P0202/R5P80:Z5D@80[XYF
0`2]RED30:b8E0<0ZhQB0`2ZQe420:V6D0<0ZhIB0P2ZQE430:V4D080[HMH0P2/QUL0102[QEH0ZXAE
0:Z4E@2YPe@80:^6DP80[HUE00<0[8QD0:^7D`2ZQU800P2XQ5000`2WPdl0ZHA@0:V4D0030:V4D0D0
Z8=?00@0ZHA@0:Z5D@2[QU80[8MC0P2]R5@50:R4D0<0Yh=?0P2ZQU840:V5D@80Z8A@00P0Yh9>0:R3
C`2ZQE40ZhIB0:Z5D@2WPTh0Y7m;0:9mB@T0ZHA@00H0ZHE;0:R4BP2XQ4X0Yh=90:J2B02UPDL20:B0
AP80YX5:0P2WPT/20:R3C080ZHA=00<0ZhIB0:Z5D@2YQ5000P2XPdl0102ZQE40[8MC0:f8E02[R582
0:Z7D@030:R5C`2WQ4h0YX==0080YH9<0P2SOTX0102TOd/0YH1<0:F0C02VPDd20:N2CP040:AoB`2U
P4`0YH1<0:J1C@80Yh9>0P2XPdl30:N2C@D0YX5<0`2WPTd30:J1C080YH1;202SOd/30:UoC@80Z7i<
0`2WOD/20:5mB@80XWi:00D0Xgm;0:B0C02TP4`0YH5=0:=oB`030:9nBP80XGe90P2PO4P20:9mB@04
0:5lB02PNdL0WgY609iiA@80WGQ400@0WgY60:1kA`2PNdL0XGa80P2RODT20:=nBPP0XGe9202ONd/0
2`2ONTH0Xgi:0:N2CP2WPTh0Xgi:0:1kA`2QO4P0Xgi:0:AoB`2RODT0X7]70080WWU500<0X7]70:9m
B@2TOd/00P2QNdX00`2QO4P0XGa70:5lA`020:5lA@80XGe3102ONTD40:1kAPP0XG]>00P0XGa?0:1l
C02NNTX0WGU709eiA@2NNdD0X7e50:5nAP80WW]500<0Wga60:1mA`2QOTP00P2ROdT02P2SP4X0X7a8
0:5mB@2SOd/0YH5=0:B0C02ROTX0Wg]709eiA@2LNdD209elAP0309imA`2OOTP0Wgi80080X7m90`2M
NDD309ijAP80Wg]700T0WgU:09ihB@2LMTL0VgE609YdA@2KMDH0W7I709egB02IMD400P2JMT800`2K
Md<0W7Q409ahA00209eiA@0809igC02NN4/0WWQ909iiA@2NND80WWXn09ij?02NNc/309]gA@0309ah
AP2MNDL0WWY80080WWY801<0WWIM0:AmH02YPV<0Y7iI09]fBP2FLT80VgM30:5nB02MN4@0W7M309]f
@P2JMD40VGA009Qc?`2GLSh0UW4m09Ea?@2GLcl0VGE10080VgM300<0VWI209Ue@@2HM4000P2KLd00
102IM400V7A009Qd@02FMD0209Ef@0<0V7<o0`2GLSh209Ia?@<0U7<n0P2CLSd3099a?0@0U6ho102C
KCh909=_>`<0Tflo102DL4002@2ELD40U6m309=^@P2AK400T6/o08mZ?P2@Jcl0TFa0099]@@0209=]
?P04099/?@2AJc`0TF/l091Z>`80SfTj00@0TVm7095^AP2AKTH0TFi60`2@KDD01P2?K4@0SF/m08e[
?@2=Jcd0S6Xl08]Y>`<0RVPj0200SFPk08iY?02>JC`0SfXm08iY?02<IcX0RF@g08QS=P2:ICP0S6Lj
08iY?02?JSd0T6/n08mZ?@2>JC`0SFPk099]@02AK3l0SfXm08eX>`2;IST0RF@g08QS=P27HSD0T6/n
08iY?02;IST0RF@g08QS=P29I3L0RVDh08]V>@<0SFTi:oooool002[ooooo202;I3/208YT=`0408]U
>02<IST0S6Hi08eW>P80SVPk202?I3T3091U>080Sf@g0`2>HcH01P2<HCH0SF8g08iS>02?I3T0TFHk
099W?080U6Tn0P2AIS/00`2BIc`0TfPm09AY?P0209EZ?`0309I[@02@ICX0T6Dj00H0T6Dj00/0U5lm
09=Q?P2DHSl0U6A009=U@@2CId80TfU309AZA02?Jc/0SVXj08eY>@0208aX>00308eY>@2>JSX0Sf/k
00<0TFHi0`2BIcX609=X>`80U6Tl0`2EJSd209EY?080UVXm102GJch209U^@@<0VVm20`2KL4<00`2L
LT00VFlm09I/>P0209AZ>00309I/>P2IKcd0W79000@0W7900P2MLd4209id@P<0W7900`2MLd4209id
@PP0WgE30P2LLT00102MLd40WWA209id@P2OMD<20:1fA080Wg=20`2PM4<30:5eA00809Ua?P2JLSl0
WGE209mgA02PN4D0WgM409if@`2MMD8309me@`<0X7I40P2QMdD00`2RN4H0XGM509me@`0209id@P06
09me@`2QMdD0XWQ609me@`2PMT@0XWQ60P2SNDL01@2RN4H0X7I409me@`2PMd<0XGQ40080XgY600@0
XWU50:1g@`2NMD40W7<o202OMT802@2QO4l0XGe=0:1lC02PO4X0Wg]709mlAP2OO4@0WW]30:5gA@02
0:9hAP030:AjB02UNdT0YWa:0080Yge;00H0XGI;0:5fB@2RMdX0XgU90:=iA`2TNdL20:ElAP<0Y7]7
0P2SNTH40:9iA@030:ElAP2TNdD0XgY40080XWU300@0Y7]50:ImA`2XOdT0YGe00P2UOD800`2UO4@0
YWe70:ImB@020:IlBPP0YW]800D0X7]60:5lA`2QO4L0XWe80:=nB@020:AoBP030:F0B`2YP4`0ZH1<
00H0ZH1<00<0ZX5=0:V0C02WOTX00P2VODT00`2WOTX0ZH1<0:Z1C@080:QoB`80Z8=?0P2WPTh01`2V
PDd0YH1<0:AoB`2TOd/0Ygi:0:ImB@2UO4P00P2TNdL00`2VODT0Z7m;0:Z1C@020:Z1C@040:V0C02X
Od/0Z7m;0:MnBP80YWe900@0ZH1<0:QoB`2XOd/0Ygi:0P2VODT20:ElB0030:MmB`2XOT`0ZX1>0080
Zh5?00<0ZX1>0:QnC02WOD/00P2YP4X20:Z1B`80Zh9<0P2/Pdd30:b3C`030:^2CP2ZPDd0ZH1<0080
ZH1<00<0[8=?0:f4D02_QU800P2_QU800`2]Q500Zh9>0:Z1C@020:UoC`030:Z0D02[PE40[89B0080
[XAD00@0[hEE0:^2CP2[PTh0Zh9>0`2/Pdl20:f4D0030:N2CP2XPdl0ZXEA0080[8MC00H0ZhIB0:Z5
D@2YQ500[89@0:f3D@2^Q5820:n5D`070:f3D@2[PDl0Zh5?0:Z0CP2[PDl0[89@0:j4DP020:n5D`03
0:j4DP2/PU00Zh5?0080[HA@0`2^QE430:n6DPP0[89@0P2ZQE430:^6DP<0[8MC202[QU801P2]QeX0
[HMH0:f7F02]QeH0[HQD0:f8D`80[HQA00@0/8]G0:n:EP2_RUH0[XUE0P2]R5@20:b7D`P0[XUE00H0
/HMG0;26EP2`QU@0/8MC0:n6DP2_QU020:j5C@060;>8D@2bRE40/hYD0;::EP2`ReH0/8aH0P2^SEX8
0:j9E@80/HaH00@0/8]G0:n:EP2_RUH0[XUE1@2]R5@30:j9E@80[hYF00P0[H=A0:n5D`2cREL0]XaJ
0;N=F`2fS5X0]H]I0;>9E`P0/XeI202`ReL20:f:DP030:j;D`2_S5@0/8eE0080/HiF00<0/XmG0;B?
FP2dSeX01P2dSeX01`2`S580/XeF0;>>F@2dSUd0]8iQ0;:;H02`RF800P2^Qf030;>=GP80]8iO0`2e
Sf030;:=F@<0/hiJ0P2dSe/20;B>G`<0]HmP0`2fT640102iU600^9=O0;F@G02bSET20;6<F0030;:=
F@2cSUX0]91P0080]91P0P2cSel30;:>GP040;2<G02aSEd0]91P0;NCH`80^9AT00<0]i=S0;JBHP2i
U6000P2hTel01P2gTUh0]Y5M0;F@G02eT5`0]8mK0;VDG`<0^YEP00@0^IAO0;NBG@2dSeX0/hiI0P2b
SET0102cSUX0]8mK0;B?F`2eT5`20;JAG@P0/hiI0P2gTUh20;JAG@030;F@G02dSe/0/hiJ00T0/hiJ
202eT5`80;B@H080]I5Q00@0]91P0;>?G`2cSel0/XiN0P2aSEd02@2cT5X0/XmI0;:?F@2bSeT0/i1J
0;FBG02hUEl0^IIP0;RBH`020;NAHP030;J@H@2eSf00]8iO0080/heN0P2fTEd0102eT5`0]8mK0;B?
F`2cSUX20;:=F@80/XiJ102cSe/20;B@G0@0]91P0P2cSel30;:>GP0;0;J@H@2eSf00]8iO0;>=GP2d
SUl0]HmP0;NAHP2hTV<0]I5M0;JBGP2hU6000P2iUF402`2hU600]Y9N0;FAG@2hTel0]i9N0;F@G02d
Se/0/hiJ0;B?F`2eT5`0]Y5M00<0]I5Q0`2dT6020;>?G`030;ZFIP2hU6@0]I5Q0080/XiN00<0]I5Q
0;RDI02kUfL00`2fTV820;FAH@@0]91P00X0]I5Q0;JBHP2gTf<0]i=S0;JBHP2eTF40]91P0;NCG`2f
TUh0]I5M0P2dT5`02`2eTEd0]Y9N0;NCG`2iUFD0^9AT0;NCH`2fTV80]I5Q0;B@H02cSel0/XiN00P0
]Y9R0`2dT6000`2eTF40]Y9R0;NCH`020;NCH`80^9AT0`2gTf<30;JBHQ00]Y9N202hU6@30;B@H080
]I5Q0`2fTV820;NCH`80]Y9R0P2eTF420;B@H0080;JBHP2gTf<0^9AT0;RDI02gTf<0]I5Q0;:>GP2`
S5`30;B?F`<0]I1L0`2fTEd00`2cSUX0/XeI0;2;E`020;2;E`030;:=F@2eT5`0]Y5M00P0]Y5M0`2e
TF430;B@H080/hmO00@0/i5T0;BBI@2dTVD0]I=V0P2fU6L20;NEJ0030;RDI02gTf<0]I5Q00<0/hmO
00<0]91P0;FAH@2eSf001`2eSf002@2dTUD0]95G0;BAF@2cT5X0/hmM0;:=H02bSF40/XeS0;NCG`02
0;JBGP030;FAG@2dT5`0/hmK0080/XiJ00<0/HeM0;:>GP2dT6000P2eTF400`2dT600/XiN0;6=G@02
0;JBHP80]I5Q00L0]91P0;>?G`2cSel0/XiN0;>=GP2dSUl0]Y1Q0080]i5R00<0]Y1Q0;B>G`2cSEh0
0`2dSf820;>>H@<0/XeP0P2cSed00`2cSel0/hiQ0;>>HP020;>>I0060;>=IP2bSUh0/XiN0;:>GP2c
Sel0]91P0`2eTF400`2eSf00]8iO0;:<G@020;6;G0030;:<G@2dSUl0]HmP0080]8iO0`2cSEh30;:<
G@030;2;E`2aS5P0/hiJ0080/hiJ00<0/XeI0;2;E`2_RUH00P2_RUH01P2`ReL0/XeI0;B?F`2eT5`0
]Y5M0;NBGP80/X]D0P2`ReH02@2_ReL0[h]I0:f;F`2/S5/0[8aM0;>?G`2bSUh0/HeM0;2<G0020;6=
G@80/hmO202dT600102bSUX0/HeI0;6=F@2aSET30;2<F00<0:n;E`2/Reh0[8]N0:j<G`2aS600/XeQ
0;B=HP2gSF<0^8iT0;>?G`2aSEd0/8aL0P2^RUX00`2`S5`0/HeM0;>?G`080;:=F@090;B@G02cSe/0
/XiJ0;6=F@2`S5P0[h]G0:j:EP2]RED0[HUI0080[XYJ00<0[h]K0;2<G02`S5`00P2aSEd01P2`Reh0
/8aL0;2<G02`S5X0/8aH0;2=E`80/8eE0P2]RED00`2^RUH0[h]G0;2<F0020;6=F@090;:>FP2]RU80
[X]C0:j;E@2_ReL0/8aJ0;2<G02aSEd0/HaO00<0[hYN00<0/8]O0;6<H02bSF400`2bSF401`2aS600
/HaO0;6=G@2`S5X0/8aH0:n;E`2_S5H00P2_ReL20:j:EP040:f9E@2/R5@0[8QD0:^7D`P0]8QG0`2`
S5`30:n;F`80[XYJ00@0/XiJ0;6=F@2^RUH0ZhMC0P2ZQU820:^7D`80ZhIB00@0ZXIB0:V8D`2YRU@0
ZX]E0P2YReD00`2^RE`0[XYJ0:j:FP020:j:F0040:j:EP2^ReD0[X]C0:j;D`80[hYN102^REd20:f8
G0P0[h]K00H0/hiJ0;:=F@2bSET0/HaH0;2;E`2_RUH20:j9E@80[HQD00@0[XUE0:n:EP2_RUH0/8]G
0P2aS5P00`2`Re@0[hYC0:f8D@020:^6C`030:f8D@2_RU<0/8]D00<0[8MC0`2[QU820:Z5D@<0ZhMC
0`2ZQU820:V5D@030:Z5D@2[QU80[XUE0080[hYF00<0[XUE0:^6DP2ZQE400P2]R5@20:b7D`050:^6
DP2ZQE40ZXEA0:V4D02/QUT00P2/QUL00`2[QE@0ZhIB0:^6D@020:Z5CQ00ZhIB00H0[8MC0:^6DP2[
QU80ZHA@0:R3C`2WPTh20:J1C@P0ZhIA0P2XPdh0102YQ4l0ZXE@0:Z5D02[QU420:b7DP040:^6DP2Z
QE40ZXEA0:V4D080Z8=?0P2WPTh20:AoBP040:F0B`2VPD`0Z8=>0:V4C`80ZXE@202YQ4l90:R3CP08
0:Z5D02[QU40ZhIA0:^6D@2ZQE00Z8=>0:F0B`2TOdX80:R3CP060:9oB@2SP4X0Xh1:0:F2C02VPdd0
YhA>0P2XQDl20:V4D080Z8=?0P2WPTh20:J1C@P0XWi:00P0XGe90:9nBP2SOd/0Y81<0:J2CP2XQ500
ZHEA0:Z6DPP0Z7m;0P2UP4/30:AoBP<0Xgi90P2PNTT0102QO4P0XGa70:9mB02RODH20:9nA0030:Ao
B`2UP4`0YX5=0080Yh9>00h0YH1<0:AoB`2SOTX0XGa50:1kA02ONTD0WgY609miB02RO4d0Y7i?0:J0
D`2TOd/0XWe90:1kA`80WWU500<0WgY60:9mB@2SOTX00P2NN4L0102ONDP0X7Y90:1jB@2QNdX20:9l
B`080:9mB02SOTT0Y7m:0:AoBP2SOTT0X7]609iiA02LMd820:9mB080Xgi900@0Y7m:0:F0B`2UP4/0
YX5<0`2ONTH20:1kA`<0XGa8202SOTX0202PNTd0WgU<09ihB`2NN4/0WgU<0:1jC@2RO4l0Y7iA0`2T
OdX00`2SOTT0XWe80:5lA`030:5lA`80Xgm500@0Xgi70:=nB@2SOTT0Xgi:0P2SOD`01P2NND`0WWY:
09ijBP2MNDL0WGU509ejA080WGY200T0Y7e40:5j@@2PND80Xg]70:R0C@2ZPU40YGe<0:5hBP2ONTD0
0P2PNdH00`2QO4L0XWe80:9mB0020:=nB@@0Y7m:00@0XWe80:1kAP2ONTD0WGQ30P2RODT0102QO4P0
X7]70:1kA`2ONTH209iiA@030:5mC@2PO4`0WWY:0080WGU900/0WWY:0:1lC02QODd0WgQ=09miC02N
N4T0WWU509eh@@2MNCd0WGTk09ai>@0209iiC080WGQ;0P2LMdX209]fB@P0WW]501P0V79509YdA`2L
MTT0WWQ;09miC02NN4/0WGM:09afB@2ILUD0WGIG0:1jEP2MMe00V7=609Ib?P2JMcl0WW]109ehA02L
Md<0VWE109Qc?`2GLSh0V7<o09Ye@@2KMT8209]gA`0309YfAP2IMDD0V7A40080Ug=300<0UW9209Ea
?@2ELCd00P2FLSh409Mc?`0809Ib@P2HM4@0VGE509YfAP2IMDD0V7A409Ib@P2DL40209I`@@80UFm0
102DKSl0202ELD40T6`l08eY>@2>JSX0TVhn09=_?`2@K3`0RfLg0P2BKD000`2CKT40U6m209E`@`03
09IaA00309MbA@2DKc/0U6lk00H0U6lk0`2DKT4209=]@0<0TV`o00<0TVhn091/?02<J3P00P2;IcL0
1P2>JSX0TFdm09A`@02=JCT0T6`l09=_?`80UG5100<0Tflo091/?02=JCT0102=J3/408iY?00808]Y
>`2:J3X0RFLi08UW>@2:J3X0S6Xl08m]?`2AKd4808eX>`0;08eY>@2>JSX0SfXm091[?`2?JT00SFM0
08]U@02:I3l0SF/m08]Y>`29IcT00`27ICL00`29IcT0RVPj08iY?00208iY?2_ooooo000Zooooo`P0
Rf@k0`2;ICP308aV>@80SFLj202?I3T3091U>080Sf@g0`2>HcH208eR=`0608iS>02@ICX0TFHk099W
?02CJ3d0U6Tn0P2AIS/3099W?0<0TfPm202@ICX01P2EHC`0Tf4l09AR?@2DI3h0TfHo09=W@080TfU1
00<0T6Xk08mY>P2>J3T00P2=IcP00`2>J3T0SfTj091Z>`03099W>P<0TfPk0`2DJC`309=X>`80U6Tl
0`2EJSd209EY?080UVXm0`2GJch0102HK3l0VFi109U^@@2IKT4209Y_@P<0Vg1300<0W79009Y`?P2F
K3X00P2DJSP0102FK3X0VW0n09ab@02KLCl309ab@080WG=10P2NM48309ab@0<0WG=10P2NM48809me
@`80W7900P2MLd40102NM480WgE309me@`2OMD<309mc@P80X7A30`2QMD@00`2JLSl0Vg=009ee@P02
09mgA00309if@`2MMD80W7A100<0WWA20`2OMD<20:1fA0030:5gA@2PMT@0WWA20080WG=100H0WWA2
0:1fA02QMdD0WWA209me@`2QMdD20:9hAP050:5gA@2OMD<0WWA209mf@P2PMd<00`2RNDD00`2QN4@0
WgI209ed@00809mf@P060:5kCP2QNd`0X7Y;0:1jB@2ONTH0WgY50P2NND801@2QMdD0XWQ60:9hAP2S
NDL0YG]90080YWa:00L0Yge;0:9gC02RMdX0XWM:0:=iB@2SNDL0XgY60080Y7]50P2TNdL30:=jAP@0
XWU500<0YGa60:AkA@2SNT@00P2RND<0102TNdD0YWe70:MnB02VOT420:In@`030:ElA02UO4H0YGa8
0080YG]9202VNdP40:9mB0@0Xgi9202YP4`00`2ZPDd0ZH1<0:MnBP020:ImB@030:MnBP2YP4`0ZX5=
00P0Z7m;0`2WPTh20:J1C@<0YH1<00L0Z7m;0:MnBP2VODT0YGa80:ImB@2WOTX0ZH1<0080ZX5=0P2Y
P4`20:QoB`80Ygi:00@0YWe90:V0C02XOd/0Z7m;0P2WOTX20:ImB@040:ElB02WOD/0Z7i<0:Z0CP80
Zh5?00<0ZX1>0:QnC02WOD/00P2YP4X20:Z1B`80Zh9<0P2/Pdd20:b3C`80Zh9>0P2ZPDd20:V0C008
0:b3C`2]Q500[XEA0:n6DP2^QE40[HA@0:^2CP2ZPDd20:UoC`060:Z0D02[PE40[89B0:f3D`2^Q5@0
[hEE0`2[PTh30:b3C`80[HA@00<0Yh9>0:R3C`2ZQE400P2/Qe<01P2[QU80ZXEA0:V4D02/PU00[H=A
0:j4DP80[hEC00L0[H=A0:^1C`2[PDl0ZX1>0:^1C`2/PU00[XAB0080[hEC00<0[XAB0:b2D02[PDl0
0`2]Q5020:j5D@<0[hIB202/PU020:Z5D@<0ZhIB0`2/Qe<80:^6DP060:f7FP2]QeP0[HMH0:f7EP2]
R5@0[HQC0P2]R5420:n:EP80[XUE0P2]R5@20:b7D`P0[HQD00H0]8YJ0;>9F@2cREL0/hYF0;:9E@2b
RE<20;68D0060;>8D@2bRE40/XUC0;::EP2`ReH0/8aH0P2^SEX80:j9E@<0/8]G00<0[hYF0:j9E@2^
RED01@2]R5@20:j9E@<0[hYF00@0[hEC0;26E02bR5H0]8YH102eReT80;:=F@P0/8]G0P2]RU80102^
Re<0[haD0;2=E@2aSUH20;:?E`P0]8mJ00L0/HaE0;:=EP2cSUX0]8iM0;>=H02bRf00/8UP0080[hQQ
202dSUl30;:=F@<0/hiJ0P2dSe/30;B>G`80]HmP0`2fT640102iU600]i9N0;F@G02cSUX30;:=F@04
0;>>FP2dT600]91P0;B@H0<0/hmO0P2bSUh0102aSEd0/hmO0;FAH@2gTf<20;RDI080]i=S0`2gTUh3
0;JAG@80]I1L0P2iU5l20;ZEH0040;VDG`2gTUd0]8mJ0;>>F@<0/hiJ00<0]8mK0;F@G02eT5`00P2f
TEd80;>>F@<0]Y5M0P2eT5`30;B?F`P0/hiJ202eT5`80;B@H080]I5Q0P2dT600102cSel0/XiN0;:>
GP2bSUh20;>?F`80/XiJ00@0/hmK0;FAG@2gTel0^IEQ0P2gTF820;J@H@050;F?H02dSUl0/heN0;>=
GP2fTEd00P2eT5`20;B?F`80/hiJ00<0/XeI0;>?F`2cSe/01P2cSe/90;>?G`0;0;J@H@2eSf00]8iO
0;>=GP2dSUl0]HmP0;NAHP2hTV<0]I5M0;JBGP2hU6000P2iUF402`2hU600]Y9N0;FAG@2hTel0]i9N
0;F@G02dSe/0/hiJ0;B?F`2eT5`0]Y5M00<0]I5Q0`2dT6020;>?G`090;NCH`2eTF40/XiN0;2<G02a
SEd0]91P0;NCH`2jUVH0^IEU0080^9AT00P0]i=S0;FAH@2dT600]91P0;>?G`2dT600]I5Q0;JBHP80
]i=S00H0]Y9R0;FAH@2dT600]i=O0;JBGP2eTEd20;>?F`030;FAG@2fTUh0]i=O0080^9AT00H0]i=S
0;JBHP2eTF40]91P0;>?G`2bSUh80;JBHP80]91P0P2eTF420;JBHP80]i=S102fTV840;NCHa00]Y9N
202hU6@30;>?G`80]91P0`2eTF420;NCH`80]Y9R0P2eTF420;B@H0080;JBHP2gTf<0^9AT0;RDI02g
Tf<0]91P0;:>GP2aSEd30;B?F`<0]I1L0`2fTEd0202dSe/0/hiJ0;:=F@2aS5P0/XeI0;>>FP2eT5`0
]i9N202fTEd30;FAH@<0]91P0P2cSel00`2bT6<0/i5T0;>AI0020;BBI@80]I=V00@0]YAW0;NCH`2f
TV80]91P0`2bSUh00`2cSel0]91P0;F?H0070;F?H080]95G00@0]95I0;>?F`2cSed0/XeP0P2bSF42
0;JBGP80]I5M00L0]91L0;>?F`2bSUX0/XiJ0;6=G@2bSUh0]91P0080]I5Q00@0]91P0;:>GP2aSEd0
]Y9R0P2eTF420;B@H080/hmO00@0/XiN0;>=GP2dSUl0]Y1Q0P2gTF800`2fT640]8iO0;>=GP080;>?
G`80/hmM00<0/hmO0;>>H@2cSV800P2cSV@00`2cSFH0/HeM0;6=G@020;:>GP80/hmO0P2dT6000`2e
Sf00]8iO0;:<G@020;6;G0030;:<G@2dSUl0]HmP0080]8iO0`2cSEh30;:<G@090;2;E`2aS5P0/hiJ
0;B?F`2cSUX0/XeI0;6<F02_RUH0/8]G0080/HaH00<0/XeI0;>>FP2dSe/00P2eT5`20;:;E080/8]F
00D0[h]G0:n;F@2]Re/0[8aK0:b<G@060;:>GP030;6=G@2`S5`0/hmO00L0/hmO102`S5P40;6=F@06
0:f<G`2^SF00[heP0;6<H02bSF40]8eR0P2fS6800`2bSUh0/HeM0;2<G0020:n;F`030;2<G02aSEd0
/XiN00P0/XeI0P2cSe/0102bSUX0/HeI0;2<F02_ReL20:j:EP<0[XYJ00<0[h]K0;2<G02`S5`00P2a
SEd01P2aS5l0/HeM0;6=G@2aSE/0/HeI0;6>F080/HiF0P2^RUH30:n;E`<0/8aH0P2^Re<01P2^ReD0
[h]G0;2<FP2`S5`0/HeM0;6<G`80[hYN0P2`Rel20;6<H080/XeQ0P2aS6001P2aS5l0/HeM0;2<FP2`
S5P0[h]G0:n<EP80/8aH0P2_ReL0102^RUH0[HUE0:f9E@2]RED80;>9E`<0/8aL0`2_Re/20:j:FP05
0;6=F@2_ReL0[HUE0:^7D`2ZQU800P2[Qe<01`2/R5@0[HEB0:^6DP2/Qe<0ZhMC0:Z9E02YRU@00P2Y
ReD00`2^RE`0[XYJ0:j:FP020:j:F0040:j:EP2^ReD0[X]C0:j;D`P0[XUM202_Re/30;6<F0<0/8]G
0P2_RUH30:j9E@<0[hYF0P2`ReL00`2_RU<0[XUB0:f8D@020:b7D0030:f8D@2^RE80[hYC00<0[8MC
0`2[QU820:Z5D@<0ZhMC0`2ZQU820:V5D@030:^6DP2/Qe<0[HQD0080[XUE00@0[HQD0:b7D`2[QU80
[HQD0P2/Qe<20:^6DP80ZXEA00L0ZHA@0:b6F@2/QUL0[8IG0:^5E02[QU80ZXE@0080ZXE>402[QU80
1P2/Qe<0ZhIB0:Z5D@2YQ500Z8=?0:N2CP80YX5=202ZQE020:R3CP80ZHA?00@0ZXE@0:^6D@2[QU40
ZhIA0`2ZQE400`2YQ500Z8=?0:R3C`020:N2CP050:F0B`2VPD`0YX5<0:N2C@2YQ4l00P2ZQE001@2[
QU40ZXE@0:Z5D02ZQE00ZHA?00<0Z8=>00<0Yh9=0:R3CP2XPdh01`2XPdh20:Z5D080ZhIA00@0ZXE@
0:R3CP2UP4/0Y7m:202XPdh01P2ROdT0Xh1:0:B1B`2UPT`0YX==0:N4CP80Z8E?0P2YQ5020:R3C`80
Yh9>0P2VPDd80:=oB`060:5mB@2ROTX0Xgm;0:B0C02VPTh0Z8A@0P2YQE480:QoB`80YH1;0`2TOdX3
0:=nB@80X7Y901L0XGa80:5lA`2RODP0XWe60:9nA02SOdD0Y7m;0:F0C02VPDd0Yh9>0:J1C@2UP4`0
Xgi:0:9mB@2RODH0XGa50:1kAP2ONTH0WgU80:5kC02SODh0Y7iA0:9mB@020:5lB080X7]700@0XGa8
0:=nBP2SOTX0WWQ70P2ONDP20:1jB@80XG]:00<0XWa;0:1kAP2QO4L00`2SOTT00`2QO4L0WgY509ii
A0030:9mB0030:=nB@2TOdX0Y7m:0080YH1;0P2ONTH30:1kA`<0XGa8202SOTX00`2PNT/0WgU:09ih
B@0209ihB@030:1jB`2RO4d0Xge>0080Y7m:0P2SOTT00`2RODP0XGa70:5lA`020:5lA`80XWi400@0
XWe60:9mB02RODP0XWe90P2RO4/01P2ONTd0Wg];09ijBP2NNTP0WWY609ikA@80WW]300P0XW]20:5j
@`2QNT<0XWY60:AlB@2TO4/0XWU;0:1gB@80X7]60P2QO4L20:9mB080Xgi900@0Y7m:0:=nB@2RODP0
XGa70P2ONTD209iiA080XGa80`2PNdL309mjAP030:5mC@2PO4`0WWY:0080WGU900/0WWY:0:1lC02Q
ODd0WgU<09miBP2NN4L0WWU509eh@@2MNCl0WGTm09ei>`0209ijBP80WGU90P2LN4P209]gA`P0WW]5
00<0VG=409YdA@2LMTL00`2NN4T03@2MMdP0W7I709QaDP2LME@0WgUD09ehCP2IM4L0V7A009]h@02O
O4@0WGQ409ag@`2JMD400`2HLcl01`2JMD40VgI209]gA`2KMdL0VWI609UeA@2HM4@00P2GLd<00`2F
LT80UG4m09Ea?@0209Ib?P<0Ug<o00<0V7A009Mc@`2HM4@00`2IMDD00`2GLd<0UG5109A`@00209I`
@@80UFm00`2DKSl02@2CKCh0U710095]?@2=JCT0SVXj099^?P2CKcl0T6`l08aX>002095/?`03099]
@02CKT40U6m200<0UG1300<0UW5409=^>P2CKSX01P2CKSX209E_@P<0U6i10`2CKD000`2CKcl0TFdm
08eY>@0208]W=`0608eY>@2@K3`0TVhn08eY>@2?Jc/0TVhn0P2ELD400`2BKSh0Sf/k08eY>@0508eX
>`<0SVTl00P0RfTk08YX>P29IcT0RFLi08YX>P2<JS`0Sfdo091^@0P0SVTl0100SVXj08m[>`2@Jch0
T6/o08mZ@02=Id00RfE008US?P2=Jcd0RfTk08UW>@28ISP0QfDg08QV>029IcT0RVPj0`2>JC`[oooo
o`00:_ooool808]T>`@0S6Hi0`2;ICP00`2:I3L0Sf@i08mT>@0608mT>@<0T6Dh0P2?I3L308iS=P80
SV<h00@0Sf@i091U>P2AIS/0TFHk102BIc`3095V>`/0T6Dj00/0UF4l09AR?@2DHSd0U6@n09=V?`2C
Id00TVQ009=Y@@2@JS/0SfTj08iX>@0208eW>00308iX>@2?JCX0T6Xk00<0TfPk0`2DJC`309EZ?@<0
TfPk0P2DJC`309EZ?@<0UVXm0P2GJch309Q/?`0409Q]@02IKT40VFi109U^@@80VVm20P2KL4<00`2K
LCl0VW0n09M]>`0209E[>@0309M]>`2JL3h0Vg4o00<0Vg4o0P2LLT0309ec@@<0W7900`2MLd4209id
@PP0WgE300@0W79009ec@@2MLd40WG=10`2NM4800`2OMD<0WW9109mc@P0209mc@P80X7A30P2QMD@2
09id@P<0WgE300<0WWA209ec@@2LLT000P2LLT0309ec@@<0WWA200<0WgE309id@P2MLd400P2LLT00
1P2MLd40WWA209me@`2MLd40WWA209me@`80X7I400H0WgE309id@P2MLd40WWE109mf@P2PMd<30:5h
A080X7M3202OMT801P2OND`0WgU:09miBP2NN4L0WWU509eh@`80WGQ100H0XGM50:9hAP2RN4H0XgU7
0:AjB02UNdT20:IlBP090:=hC@2SN4/0XgQ;0:=iB@2RN4H0XWU50:9i@`2QN480Y7]700<0XgY60`2R
NDD20:5hA00>0:AkA`2SNTH0XWU50:9iA@2SNTH0Y7]70:ElB02VODT0Ygm20:MoA02VOT<0YGa40:El
AP2TNdL20:=iA`P0YW]8102SOTT40:9mB0X0ZH1<102WOTX20:V0C0P0Z7m;102UP4`30:J1C@090:N2
CP2YP4`0Z7m;0:QoB`2WOTX0Z7m;0:V0C02ZPDd0Zh9>00<0ZH1<0P2XOd/30:MnBP@0Z7m;0P2WOTX2
0:ImB@030:QnC02YOdd0ZX1>0080Zh5?00<0ZX1>0:UoC@2XOT`00P2YP4X20:Z1B`80Zh9<0P2/Pdd0
102/Pdl0Zh9>0:^2CP2[PTh30:Z1C@030:V0C02/Pdl0[HA@0080[XEA00D0[HA@0:b3C`2[PTh0ZX5=
0:UoC@020:Z0CP030:^1C`2/PU00[H=A0080[XAB0`2[PTh30:b3C`80[HA@00<0Yh9>0:R3C`2ZQE40
0P2/Qe<01P2[QU80ZXEA0:V4D02/PU00[H=A0:j4DP80[hEC00L0[H=A0:^1C`2[PDl0ZX1>0:^1C`2/
PU00[XAB0080[hEC00@0[XAB0:b2D02[PDl0[8=?0`2]Q5020:j5D@80[hIB202/PU020:Z5D@<0ZhIB
0`2/Qe<80:^6DP060:f7FP2]QeP0[HMH0:f7EP2]R5@0[HQC0P2]R5430:j9E@<0[HQD2P2/Qe<20;J<
G00<0;F;F@2eS5P0]8]G0;B;E@2dRe<0/hYB0;:7D02bRE40/XUC0;69E@2`ReH0[h]G0P2^SEX80:j9
E@040;2;E`2_RUH0[hYF0:n:EP<0[XUE0`2]R5@20:j9E@<0[hYF00@0/8]G0;:8EP2bR5H0/HME0P2b
R5H00`2dRUP0]XaJ0;N=F`080;:=F@P0/HaH00H0[HYD0:j;E@2^ReD0[haF0;2=E`2aSUP20;:?F@P0
/hiI00L0/XeH0;>>FP2cSUX0]8iM0;>=GP2bS5l0/HYO0080/8UN00D0]Y1Q0;F?H02eSf00]8iO0;>=
GP020;:<G@040;6;G02bSET0/XeI0;:=F@<0/hiJ0P2dSe/0102cSEh0]8iO0;B>G`2dSUl20;F?H080
]Y1Q00@0^9=O0;JAG@2eT5`0/hiJ0P2bSET20;>>FP80]I5Q0P2dT6030;>?G`050;:>GP2cSel0]91P
0;JBHP2hU6@00P2iUFD20;RDI0<0]I1L0`2fTEd20;NBGP80^9=N0`2iU5l0102gTUd0]8mJ0;>>F@2c
SUX30;B?F`<0]I1L00<0]Y5M0;>>F@2cSUT01P2cSUT40;B?F`<0]I1L00<0]Y5M0;>>FP2cSUX01P2c
SUX80;F@G0P0]91P00@0]I5Q0;B@H02dT600]91P0`2cSel00`2bSUh0]91L0;>?F`020;:>FP040;>?
F`2eTEd0]i=O0;RDH080]i5R00<0]Y1Q0;F?H02dSUl00P2cSEh0102bS5d0]I1L0;F@G02eT5`20;B?
F`<0/hiJ202cSe/30;6=G@040;:>GP2cSel0/hmO0;B@H080]I5Q00/0]Y1Q0;F?H02dSUl0/heN0;B>
G`2eSf00]i5R0;RBH`2eTEd0]Y9N0;NCG`020;RDH00;0;NCG`2fTUh0]I5M0;RCG`2gTUh0]I1L0;B?
F`2cSUX0]8mK0;F@G02fTEd00`2eTF430;B@H0<0/hmO0180/XiN0;6=G@2`S5`0/HeM0;B@H02hU6@0
^YIV0;bHJ02kUfL0^YIV0;RDI02gTf<0]I5Q0;B@H02cSel0]91P0;FAH@2fTV820;NCH`060;JBHP2e
TF40]91P0;NCG`2fTUh0]91L0P2cSe/00`2dT5`0]Y9N0;NCG`020;NCH`040;JBHP2eTF40]91P0;B@
H080/hmO202fTV80102dT600]I5Q0;FAH@2eTF430;JBHP050;NCH`2dT600]91P0;FAH@2fTV800P2g
Tf<20;RDI100]Y9N202gTf<30;:>GP80/hmO0`2dT6020;NCH`80]Y9R0P2eTF420;B@H080]Y9R0P2g
Tf<0102fTV80]91P0;:>GP2aSEd30;B?F`<0]I1L0`2fTEd0202eT5`0]8mK0;B?F`2cSUX0]8mK0;F@
G02fTEd0]i9N202fTEd30;FAH@<0]91P0P2cSel20;6?H@<0/Y1R0`2cTF<0202eTF40]91P0;:>GP2a
SEd0/8aL0;6=G@2bSUh0/hmO202eSf020;BAF@040;BAF`2cSe/0/hmM0;:>GP80/XeP0P2fTUh00`2e
TEd0]91L0;>?F`020;:>FP040;6=F@2aSEd0/XiN0;B@H080]I5Q00<0]91P0;:>GP2aSEd00P2eTF42
0;B@H0@0/hmO00<0/heN0;B>G`2eSf000P2fT6400`2eSf00]8iO0;>=GP020;6=G@040;:>GP2cSel0
/hmO0;B@H080]I5Q0P2cSed00`2cSel0/hiQ0;>>HP020;>>I0040;>=IP2`S5`0/8aL0;2<G080/HeM
0`2bSUh00`2dSUl0/heN0;:<G@020;6;G0030;:<G@2cSEh0]8iO0080]8iO0`2cSEh30;:<G@030;2;
E`2aS5P0/hiJ0080]8mK00<0/hiJ0;6<F02`ReL0202cSUX20;><E@80/HaG00d0/8aH0;2<FP2^S5`0
[HeL0:f=GP2aSEd0/XiN0;B@H02eTF40]91P0;:>GP2_Re/0[HUI00P0/XiN00D0[XYF0:n;E`2_ReL0
/8aH0;6=F@020;:>FP040;>?F`2`T640/91Q0;2>H080/XeP00H0/XaO0;B;G`2dRel0/XiN0;6=G@2`
S5`20:n;F`030;2<G02aSEd0/XiN00P0/XeI00D0/hmK0;:>FP2bSUX0/HeI0;2<F0020:n;E`030:j:
EP2^RUX0[XYJ00<0[h]K0`2`S5`01P2bSF00/XiN0;:>GP2bSU`0/XiJ0;:?F@80/XmG0`2`S5P30:n;
E`80[XYF0P2^Re<00`2_S5H0[h]G0:n;F@020;2<G0030;2;GP2_RUd0/8]N0080/8]N0`2aS5l01P2b
SF00/HaP0;6<H02aS5l0/8aL0;2<FP80[h]G00<0[haF0;6=F@2`S5P00P2`S5P30:n;E`030:j:EP2c
REL0/hUG00H0/hUG0`2`S5`30:n;F`80[XYJ00<0[XYF0:f9E@2/R5@00P2[Qe<20:b8E00:0:f9E@2]
QE80[XIC0:b7D`2[Qe<0[8QD0:Z9E02YRU@0ZX]E0:f8F`80[HUI0P2]REL0102]RED0[HYD0:f:DP2]
RU880:j9G0P0[h]K0P2_RUH30;2;E`<0/HaH102_RUH30:j9E@040:f8E02^RE@0[XUD0:f8D`80[8MB
00<0[HQC0:j9E02^RE@00`2/Qe<30:^6DP80ZXEA0`2[Qe<30:Z6DP80ZHEA00<0[XUE0:f8E02/Qe<0
0P2[QU800`2/Qe<0[HQD0:j9E@020:b7D`80ZhIB102ZQE40202/QUT0[8IG0:^5EP2[QE@0ZXEA0:Z5
D02ZQDh0ZHA=4P2[QU800`2ZQE40ZHA@0:R3C`020:N2CP030:J1C@2XPdh0Z8=>00L0Z8=>0`2YQ4l3
0:Z5D0030:^6D@2ZQE40ZXEA00<0ZHA@0`2XPdl01@2WPTd0Z8=>0:R3CP2YQ4l0ZXE@0080ZhIA0`2/
Qe801P2[QU40ZHA?0:R3CP2WPTd0YX5<0:F0B`T0Z8=>0P2YQ4l30:Z5D0030:R3CP2UP4/0Y7m:00P0
Z8=>0P2SP4X00`2TPD/0YH9<0:J3C@020:N4CP030:R5C`2YQ500ZHA@0080Z8=?0P2WPTh20:J1C@P0
YH5=0P2ROTX01P2SOd/0YH5=0:J2CP2WPdl0Z8A@0:V5D@P0Z7m;0P2UP4/30:AoBP<0Xgi90P2QNdX0
102QO4P0XWe80:9mB02SOTL20:=oA@0=0:AoB`2UP4`0YX5=0:N2CP2VPDd0Y7m;0:=nBP2QO4P0Xgi7
0:9mAP2QO4L0X7]709miB0020:1jB`040:5kCP2ONTH0X7]70:9mB@@0Y7m;00@0Xgi:09mjAP2ONTH0
WgY60P2PNdL30:5lB00309iiA02ONTD0XGa700<0XWe80P2QO4L40:9mB080Xgi90P2TOdX0102ONTH0
X7]70:1kA`2PNdL20:5lB080XWe9202SOTX0202PNT/0WgU:09ihB@2MMdP0WWQ909miBP2QNd`0XWa=
0`2SOTT20:9mB0@0XGa70P2PO480102PNd@0X7]60:1kAP2PNdL20:1jB@060:1kCP2PO4`0X7a<0:1l
BP2PO4P0X7e70P2PODD01@2NND80WgY30:1kAP2ONTH0WGM60080W7I700@0WGM:0:5lA`2QO4L0XGa7
0`2RODP20:=nB@090:AoBP2RODP0WgY509ag@P2KMT40W7M209iiA02ONTD0WWU500<0WgY6102PNdL0
0`2PO4`0Wg];09ijBP0209eiB@0;09ijBP2ONd/0X7a<09miBP2ONDP0WgY609iiA@2NND80WGQ109ei
?`2MNCd00P2NNTX209eiB@80W7Q80P2KMdL809ikA@0509YdA@2KMDH0W7I709egB02NN4T00P2MMdP0
302LMTL0Ug5=09YdC`2MMe00WGQ<09]gA`2KMd<0WGY409mlA02MN4@0W7M309Ye@@<0VGA00P2JMD42
09]gA`0309YfAP2IMDD0V7A40080Ug=300@0UW9209Ib?P2FLSh0UW8n0P2GLcl309Qd@080Ug=30`2H
M4@00`2GLd<0UG5109A`@00309E_@080U6ho0`2CKCh0102DL400TFdm08m[>`2@K3`2099^?P03091/
?02=JCT0SfXm0080T6/n00<0TF`o099]@02CKT400`2DKd88099]>@<0UW130P2EKd8309A^@@0;09A`
@02BKSh0Sf/k08aX>02;IcL0S6Ph08iZ>P2@K3`0SFTi08m[>`2AKCd00P2CKcl00`2AKCd0Sf/k08eY
>@0808eX>`@0RVPj00@0RfTk08aZ?02>K3h0Sfdo202@Jch208m[>`09091[?P2@Jcl0SfY008aV?`2:
I3l0RF<n08e[?@2<JS`0RVPj00<0RFLi0P2:J3X308iY?2_ooooo000Zooooo`P0Rf@k0P2=IcX0102<
IST0RfDh08]U>02:I3L208US=PP0Sf@i0`2@ICP208mT=`<0SV<f00<0Sf@i091U>P2@ICX00P2@ICX3
095V>`80TVLl00<0TFHk091U>P2?I3T00P2>HcP00`2=HSL0T6Dj091U>P06091U>P0609IR>`2DHc/0
UF@l09AT?02CISd0TVLm0P2BJ3h00`2BJC/0TFPj091W>@0208mV>003091W>@2AJ3X0TVTk00<0U6Tl
102EJSd209I[?P<0TfPk0P2DJC`309EZ?@80UVXm0`2GJch309Q/?`80V6e00`2IKT4309Y_@P0309]a
?`2JL3h0V6hl0080Ufdk00<0V6hl09Y`?P2KLCl00`2KLCl309ab@080WG=10`2LLT0309ec@@X0WWA2
202MLd4209ib@@<0Wg=20`2PM4<20:5eA080X7A300@0Wg=209ib@@2MLD00W70o0P2KLCl309ab@0@0
WG=11P2LLT0309ec@@@0WWA20P2MLd4209ed@00309ie@@2PMd<0X7M300<0XGQ4202OMT801P2PMd/0
X7M90:1gB@2OMdH0WgM409if@P80WWM00`2RN4H00`2SNDL0Y7Y80:AjB0020:EkB@060:AiCP2TND`0
XgQ;0:9hB02RN4H0XGQ40P2PMd430:=jAP80XWU5102QN4@30:9hAP80XgU70P2TNTP01`2UNdT0Ygm2
0:MoA02VOT<0YGa40:AkA@2SNTH00P2RN4H80:IkB0050:F0B`2TOdX0Y7m:0:=nB@2RODP00P2QO4L0
0`2PNdH0Z7m;0:QoB`0F0:QoB`80Xgi:00<0Y7m;0:F0C02VPDd00P2WPTh00`2XPdl0ZH1<0:V0C002
0:V0C080ZX5=0P2[PTh>0:QoB`80Ygi:0`2YOdd20:Z0CP<0ZGm=0P2YP4X20:Z1B`80Zh9<0P2/Pdd4
0:^2CP@0ZX5=102]Q5000`2/Pdl0Zh9>0:^2CP030:Z1C@80Zh9>00@0[8=?0:f4D02]Q500[HA@0`2[
PTh30:b3C`80[HA@00<0Yh9>0:R3C`2ZQE400P2/Qe<01P2[QU80ZXEA0:V4D02/PU00[H=A0:j4DP80
[hEC00L0[H=A0:^1C`2[PDl0ZX1>0:^1C`2/PU00[XAB0080[hEC00<0[XAB0:b2D02[PDl00P2/Pdl3
0:f4D0<0[XEA202]Pe420:Z5D@<0ZhIB0`2/Qe<80:^6DP060:f7FP2]QeP0[HMH0:f7EP2]R5@0[HQC
0P2]R5460:f8E0X0[8MC0P2dRUX0102cREL0/hYF0;>:EP2bRE<20;:9D@060;:7D02aR500/XUC0;69
E@2_RUD0[h]G0P2]S5TC0:j9E@<0[hYF0P2`ReL0202eReT0/hUG0;67E@2`QU@0/HME0;>9E`2fS5X0
^8iL202bSET80;6<F080[XYF00<0[h]G0;2<F02aSET00P2bSUX00`2cSe/0/hiI0;>>F@060;>>F@<0
/heL0P2cSEh0102bS5d0/H]N0;6;GP2aReh20;J@H@040;F?H02dSUl0/XaM0;6;G080/8YK0`2bSET3
0;>>FP80]8mK0P2cSEh30;B>G`<0]HmP0P2fTEd00`2eT5`0]8mK0;>>FP030;>>FP<0]I5Q0P2dT603
0;>?G`030;FAH@2fTV80]i=S0080^9AT0`2iUFD01@2cSUX0]8mK0;B?F`2eT5`0]Y5M0080]i9N00T0
^9=O0;NBG@2gTUd0^9=N0;VDG`2hTeh0]i9M0;F@F`2cSUT0202eT5`80;>>F@80/XeI00<0/hiJ0;B?
F`2eT5`00P2fTEd00`2gTUh0/hiJ0;>>FP060;>>FPP0]8mK402dT6020;B@GP070;>?G@2bSU`0/hmM
0;B@GP2fTV00^9AR0;NAHP020;J@H@030;F?H02dSUl0/heN0080/XaM202dSe/20;B@G0@0/hmK0P2b
SUX30;2<G0040;6=G@2bSUh0]91P0;FAH@80]Y9R00T0]Y1Q0;F?H02dSUl0/heN0;B>G`2eSf00]i5R
0;RBH`2fTUh01P2gTel02@2fTUh0^9=O0;NBGP2eT5`0]8mK0;>>FP2dSe/0]I1L0;JAG@030;FAH@<0
]91P0P2cSel0202dT600/hmO0;>?G`2cSel0]I5Q0;RDI02kUfL0_IUY0P2nVVX02@2lV6P0^YIV0;NC
H`2eTF40]91P0;>?G`2dT600]I5Q0;JBHP020;NCH`060;JBHP2eTF40]91P0;JBGP2eTEd0]91L0P2c
Se/00`2dT5`0]I5M0;JBGP020;JBHP80]I5Q0P2dT6020;>?G`P0]Y9R102eTF440;JBHP060;:>GP2c
Sel0]91P0;FAH@2fTV80^9AT0P2iUFD@0;NCG`P0]i=S0P2aSEd30;:>GP<0/hmO0P2gTf<20;JBHP80
]I5Q0P2dT6030;JBHP80]I5Q00<0]91P0;>?G`2bSUh00`2dSe/30;F@G0D0]Y5M0`2eT5`20;JAG@03
0;NBGP2fTEd0]Y5M00H0]Y5M0`2eTF430;B@H080/hmO0`2`SUh50;6?G`080;B@H02cSel0/HeM0;2<
G02_Re/0/8aL0;6=G@2bSUh80;B>G`050;BAF`2dT5`0]91L0;>?F`2cSed00`2bSU`01P2fTUh0]I5M
0;FAG@2dT5`0/hmK0;:>FP80/HeI00<0/HeM0;:>GP2dT6000P2eTF400`2dT600/XiN0;6=G@020;B@
H0H0/hmO00<0/XaM0;B>G`2eSf000P2fT6400`2eSf00]8iO0;:<G@020;2<FP040;6=F`2bSU`0]91N
0;FAG`80]Y9P0P2cSed00`2cSel0/hiQ0;>>HP020;>>I0030;>=IP2`S5`0/8aL00H0/8aL0`2cSEh2
0;:<G@<0/heN0P2dSUl30;>=GP<0/XaM00<0/8]G0;6<F02cSUX00`2dSe/20;:=F@040;F@G02dSe/0
]8mK0;>>FP80/XeI0P2aS5P20;><E@80/HaG00d0/8aH0;2<FP2^S5`0[HeL0:f=GP2`S5`0/XiN0;FA
H@2gTf<0]Y9R0;:>GP2^RUX0ZXIF00P0/HeM00h0[HUE0:j:EP2_ReL0/8aH0;6=F@2bSUX0/hmK0;B@
G02bTV40/I5P0;6?G`2bSUh0/HeM0;6;G080/XUK0P2aSEd40;2<G080/HeM202bSET20;:>FP80/HeI
0P2`S5P20:n;E`H0[h]K0P2`S5`01P2cSV40/hmO0;>?G`2cSed0/hmK0;>@FP80/i1H00H0/XiJ0;6=
F@2aSET0/8aH0:n;E`2^RUH20:f9E@80[haD00H0[haF0:n;E`2_ReT0[h]K0;2<G02`Reh40;2<G0@0
/HeM0P2aS6001P2`Reh0/8aL0:n;F@2_ReL0[XYF0:j;E@P0/8aH202bRUL30;2<G0<0[h]K0P2^RUX4
0:^7D`80[8QD0P2]RED20:n5D`070:j6D`2/Qe<0[8QD0:b8E02ZRE@0ZHYD0:f8F`020:f9F@80[HUG
00@0[HUE0:f:E02]RU80[HYB0P2]RET40:j:FPX0[h]K0P2^RED00`2_RUH0/8]G0;6<F0020;:=F@04
0;>>FP2`ReL0/8]G0:n:EP80[XUE00<0[HQD0:b7D`2/Qe<00`2]R5@20:b7D`<0[HQD0`2/Qe<30:^6
DP80ZXEA0`2[Qe<30:Z6DP80ZHEA00<0[hYF0:j9E@2[QU800P2ZQE400`2[QU80[XUE0:n:EP020:^6
DPH0ZXEA00H0ZhEH0:^5EP2[QEH0ZXAC0:Z5D@2ZQE020:V4C@P0ZhIB2`2ZQE400`2YQ500Z8=?0:R3
C`020:N2CPP0Yh9=202YQ4l60:V4D080Z8=?0P2YQ4l20:Z5D080ZhIA0P2/Qe820:f8D`060:^6D@2Z
QE00Z8=>0:J1C02UP4/0Y7m:2`2XPdh01P2YQ4l0ZXE@0:V4C`2XPdh0YX5<0:AoBPP0Z8=>0`2TPD/0
0`2UPT`0YX==0:J3C@020:N4CP80ZHA@0P2XPdl20:N2CP80YX5=202VPTh01P2ROTX0Xgm;0:B0C02U
PDd0YX9>0:N3C`80Z8A@202XOd/20:F0B`<0Y7m:0`2SOTT20:5kBP040:9mB@2RODP0XWe80:=nA`80
Xgm500d0Y7m;0:F0C02VPDd0YX5=0:F0C02TOd/0XWe90:1kA`2SOTL0XWe60:5lA`2PNdL0WgU80080
WgU:00T0WWQ;09iiA@2PNdL0Xgi:0:J1C@2WPTh0YX5=0:AoB`2SOTX0202PNdH209eh@`0409mjA@2P
NdH0XGa70:9mB080Xgi90`2QO4L50:9mB0<0X7]70P2QO4P30:9mB@P0Xgi:00<0X7Y909miB02NN4L0
0P2MMdH00`2NN4L0X7Y90:5kBP040:9mB0D0XGa70P2NNT00102NND80WWU409iiA02NNDD209ihA`0@
0:1kCP2PO4`0X7a<0:5mB`2QODT0XGi80:5nAP2ROdL0VgQ209ikA@2QODT0X7a:09ahB02JMDP0VgI9
09ehC0H0XWe80P2SOTT0202TOdX0XGa709ag@P2IM3l0V7<n09Ye@02NND@0X7]60P2MN4@0102NNDD0
WgY609mjAP2PNdL20:5lB0P0WWY:0P2PNdL0102ONTH0WgY509iiA02NND8209eh@@80WWY80P2MNDL2
09ahAP80VgM5202NNdD00`2KMD@0W7I509afA@0309egAP80W7I500P0Ug5:09UdBP2LMd/0WGQ;09ij
BP2NNTH0WW]509mlAP80W7M30P2KMT8409Ye@@80VgM700<0VWI609UeA@2HM4@00P2GLd<00`2FLT80
UW8n09Ib?P0309Mc?`<0V7A01@2GLd<00`2FLT80UG5109Ea@@0209E_@0<0U6ho0`2CKCh00`2CKcl0
TVhn095]?@03095]?@03091/?02?Jc/0SVTl0080SfXm00<0T6/n095/?`2BKD000`2CKT48095/>080
Ug540P2FL4<309E_@P0509A^@@2DL400Tflo091/?02=JCT00P2<J3P01@2=JCT0SVXj08eY>@2>JSX0
T6`l0080TFdm00<0T6`l08iZ>P2=JCT0102=J3/408aW>P<0RVPj0P2;JC/00`2<JS`0SF/m08i/?P08
095/?`80Sf/k00L0T6/n091[?`2?JT00SFM008YT?`29Hch0SF/m0080S6Xl00<0RfTk08YX>P2:J3X0
0P2:J3X308mZ?B_ooooo000Zooooo`P0Rf@k00D0SFLj08aV>@2<IST0RfDh08YT=`0208US=P0308QR
=@2?I3T0Sf@i00H0Sf@i0`2@ICP208mT=`<0SV<f0`2AIS/4091U>P0608mT>@2BIc`0TVLl095V>`2@
ICX0Sf@i0P2>HcP00`2=HSL0T6Dj091U>P06091U>P0609MS>`2EI3/0UF@k09AU>`2CIS`0TVLl0P2A
J3`00`2CJ3/0TVLj095V>@02091U>003095V>@2BIcX0TfPk0080TfPk0P2DJC`409EZ?@0409I[?P2C
J3/0TfPk09=X>`80U6Tl0`2EJSd309M[?P<0V6`o0P2IKD0309Q]@0<0VFi10P2JKd800`2KLCl0VW0n
09U_?@0209Q^?00309U_?@2JL3h0Vg4o0080VW0n0`2KLCl609ab@0<0WG=12P2NM48409ec@@@0W790
0`2NLT4309mc@P80X7A300@0Y7I50:=eA02RM4<0XG=20P2PLT4209ma@080Vg4o0`2LLT0309ec@@<0
W7900P2MLd4309ab@080WWA2102MLd4209id@P80WGA00P2NMD40102OMT80X7M30:5hA02RNDD809mf
@P060:5fB`2QMTT0XGI90:1fAP2PMT@0WgI20P2OMT030:9hAP@0XgU700T0Y7Y80:AiCP2SN4/0XgQ;
0:9hB02QMdD0X7M30:1g@@2OMT000P2SNTH20:9iA@<0XGQ40P2PMd<00`2QMdL0XWQ80:9hB0020:=i
B@<0Y7Y:00H0YWi10:In@`2UOD80Y7]30:AkA@2SNTH20:9hAPP0YGY700D0YH1;0:AoBP2TOdX0Xgi9
0:9mB0020:5lA`030:1kAP2XOd/0Z7m;01H0Z7m;00H0XWe90:=nBP2SOTX0Y7m;0:F0C02VPDd20:N2
CP030:QoB`2YP4`0ZH1<0080ZX5=0`2[PTh>0:QoB`80ZH1<00<0ZX1>0:UoC@2YOdd0102YOdd00`2Z
P4h0ZH1:0:V0BP020:Z1B`80Zh9<0P2/Pdd40:Z1C@@0Zh9>0P2]Q5000`2/Pdl0Zh9>0:^2CP060:^2
CP@0[8=?00@0[HA@0:^2CP2[PTh0Zh9>0`2/Pdl20:f4D0030:N2CP2XPdl0ZXEA0080[8MC00H0ZhIB
0:Z5D@2YQ500[89@0:f3D@2^Q5820:n5D`070:f3D@2[PDl0Zh5?0:Z0CP2[PDl0[89@0:j4DP020:n5
D`030:j4DP2/PU00Zh5?00<0[8=?0`2]Q5020:j5D@P0[H=A0P2ZQE430:^6DP<0[8MC202[QU801P2]
QeX0[HMH0:f7F02]QeH0[HQD0:f8D`80[HQA1P2/Qe<20:f8E0P0[8MC0P2`QUH0102_QE<0[hIB0:n6
DP2^QDl20:j5C@060;:7D02aR500/HQB0;69E@2_RUD0[XYF0P2]S5T80:j9E@@0[HQD1P2^RED30:n:
EP<0/8]G00<0]H]I0;B:F02bR5H00P2`QU@00`2bR5H0]H]I0;N=F`0@0;:=F@060:j:F02_ReT0[h]I
0;2<FP2aSE/0/XiL0P2cSed80;>>F@050;F?HP2dSV40]8iO0;>=GP2bS5d0102bS5/0202fT640]HmP
0;B>G`2cSEh0/XaM0;6;G02`RU/0[hUJ0`2bSET30;>>FP80]8mK0`2cSEh30;B>G`80]HmP00@0]8mK
0;F@G02eT5`0]I1L0P2dSe/20;>>FP80]Y9R0P2eTF420;B@H080/hmO0P2gTf<20;JBHP80]i=S0P2h
U6@20;>>FP040;B?F`2eT5`0]I1L0;JAG@80]i9N00<0]I1K0;JAG02gTUd00P2hTeh00`2gTUd0]I1K
0;B?FP040;JAG@@0]I1L202cSUT01P2aS5P0/XeI0;:=F@2cSUX0]8mK0;F@G080]Y5M202cSUX80;B?
F``0]91P1@2eTF401`2dT600/hmO0;:>GP2cSel0]91P0;JBHP2gTf<00P2fT6400`2eSf00]8iO0;>=
GP020;:<G@030;6;G02dSe/0]8mK00H0]8mK00<0]I5M0;B@G02dT5`00P2cSe/20;:>FP080;6=F@2`
S5`0/8aL0;2<G02aSEd0/XiN0;B@H02eTF420;JBHP080;J@H@2eSf00]8iO0;>=GP2dSUl0]HmP0;NA
HP2hTV<30;NCG`80]Y9N0`2gTel0202hTel0]i9N0;F@G02dSe/0/hiJ0;B?F`2eT5`0]Y5M0`2eTF43
0;B@H080/hmO0`2gTf<01@2hU6@0^YIV0;fIJ@2oVf/0`Ie]0080_YYZ00T0_9QX0;ZFIP2gTf<0]I5Q
0;B@H02cSel0]91P0;FAH@2fTV800P2gTf<01P2fTV80]I5Q0;B@H02fTUh0]I5M0;>?F`80/XiJ00<0
/hmK0;FAG@2fTUh00P2eTF440;B@H080/hmO302fTV840;FAH@80/XiN00H0/hmO0;FAH@2fTV80]i=S
0;RDI02iUFD@0;NCG`P0]i=S00@0/HeM0;:>GP2bSUh0/XiN0P2cSel20;B@H080]i=S0P2fTV820;FA
H@80]91P0P2eTF420;B@H0<0/hmO00@0]91P0;B?F`2dSe/0]8mK0`2eT5`90;JAG@X0]I1L0`2eTF43
0;B@H080/hmO0P2aT5d60;2?G0080;B@H02cSel0/HeM0;2<G02_Re/0/8aL0;6=G@2bSUh80;B>G`<0
]91N00D0/hmM0;>?F`2bSUX0/XiJ0;:?F@020;FAG@030;B@G02cSe/0/XiJ0080/HeI00@0/8aH0;6=
G@2bSUh0]91P0P2eTF400`2dT600/XiN0;6=G@020;:>GPH0/hmO00<0/XaM0;>=GP2dSUl00P2fT640
0`2dSUl0/heN0;:<G@020;2<F0040;6=F@2bSUX0]91L0;FAG@80]Y9N0P2cSed00`2cSel0/hiQ0;>>
HP020;>>I0030;>=IP2`S5`0/8aL00H0/8aL00<0/XaM0;>=GP2cSEh0102cSEh00`2bS5d0]8iO0;B>
G`030;>=GP<0/XaM00@0/8]G0;6<F02cSUX0]8mK0P2eT5`01`2dSe/0/hiJ0;F@G02eT5`0]8mK0;>>
FP2bSET00P2aS5P00`2`ReL0]8eF0;B=EP020;:=F00=0;6=F@2aSE/0[heM0:j>G@2^SUl0[h]K0;6=
G@2eTF40]i=S0;JBHP2cSel0[XYJ0:^7E`080;6=G@0>0:f9E@2^RUH0[h]G0;2<F02aSET0/XiJ0;>?
F`2dT5`0/i=P0;:BG`2bTEh0/hmM0;6=F`2aReX20;69F080/8aL102aSEd20;2<G0P0/XeI102aSET4
0;2<F080/8aL1P2_Re/01P2bSF00/XiN0;:>GP2bSU`0/XiJ0;:?F@80/XmG00H0/XiJ0;6=F@2aSET0
/8aH0:n;E`2^RUH20:f9E@80/8eE00<0[haF0:n;E`2_ReT00P2_Re/00`2_RUd0/HeK0;6=F`020;6=
F`@0/8aJ0P2`Rel00`2`Reh0[h]K0:n;F@020:j:EP030:j;E@2_ReL0[h]G0080[h]G102`S5P80;2;
E`<0/8aL0`2_Re/20:j:FP80ZXIB0P2[Qe<40:b8E080/HED00<0/8ID0:n7E02/Qe<00P2[Qe<0102Y
R5<0[HQK0:f9F@2]RET20:f9E`050:f9E@2]RU@0[HYB0:f:DP2/R5H00P2]REL20:j:F080[h]I00<0
/8aJ0:n;F`2_Re/01P2_Re/20:j9E@030:n:EP2`ReL0/HaH0080/XeI00H0/hiJ0;2;E`2_RUH0[hYF
0:j9E@2]R5@20:b7D`040:^6DP2/QUD0[8IE0:b6E@80[HMF0`2/QUD30:b7D`<0ZhIB0P2ZQE430:^7
D`<0ZXIB0P2YQE400`2_RUH0[XUE0:^6DP020:Z5D@030:^6DP2^RED0[hYF0080ZHA@1P2ZQE401P2[
QEP0ZhEF0:Z4E@2ZQ5<0ZXEA0:V4C`80ZHA=202[QU890:Z5D@@0ZHA@0`2XPdl80:N2C@@0ZHA?102X
Pdh20:R3C`H0ZHA@102ZQE040:^6D@80[HQC00H0ZhIA0:Z5D02XPdh0YX5<0:F0B`2TOdX90:R3CP03
0:J1C02WPTd0Z8=>0080ZHA?00<0Z8=>0:J1C02UP4/0202XPdh00`2TPD/0YH9<0:F2C0020:F2C0<0
YX==0P2YQ5020:R3C`80Yh9>0P2VPDd80:J2CP040:=oB`2TP4`0Y81<0:F1C@80YX9>0P2WPdl80:Qo
B`80YH1;0`2TOdX30:=nB@80XWa;00@0XWe90:=nB@2SOTT0Xgi70P2TP4H20:F0C080YX5=01@0YH1<
0:=nBP2PNdL0WgY60:9mAP2QO4D0XGa70:5lB02PNTT0WgU:09ihB@2MMdX0WWU50:1kA`2SOTX0YH1<
0:J1C@2UP4`0Xgi:0:9mB@P0X7]600P0W7M209eh@`2MN4<0WgY50:1kAP2RODP0Xgi90:AoBPH0XGa7
0P2PNdH20:1kA`80XGa80P2RODT:0:=nBP030:5lB02PNdL0WWU50080WGQ400<0WWU509mjAP2PNdL0
2@2QO4L209ij@00409ii@P2NND@0WWU409iiA@80WWQ700H0WgY=09mkB`2PO4`0X7a:0:5mB@2ROdT2
0:9oA`0809Yf@P2MNDD0XWi<0:B0D02TOe80XWeA0:1kC`2ONU060:=nB@<0XWe800P0WgY509]f@@2H
Lch0V7<n09Ye@02NND@0XGa709ag@`80WGQ400D0WWU509mjAP2PNdL0X7]70:5lB00209eiB@@0WWY:
0P2MNDT30:1kA080WgY50`2NNDD209ijAP80WGU50P2LN4@209]g@`P0WW]50P2MN4@609ag@`0809Qc
AP2IM4L0VgM709ijBP2PO4X0X7a809mkA`2MNDD409ag@`80VgI20P2JMD4209]gA`0309YfAP2IMDD0
V7A40080Ug=300@0UW9209Mc?`2GLcl0Ug<o0`2HM40209Ue@@0409QdA02GLd<0Ug=309Ib@P@0UG51
0`2DKSl309=]?P80TV`m00D0TVhn09=_?`2CKcl0TVhn095]?@02091/?007095]?@2>JC`0SfXm08mZ
?@2@Jch0TF`o099]@00309=^@@P0TVdi0`2FL4<209E_@P<0U6i100D0U710099^?P2@K3`0SVXj08eY
>@0208aX>080SFTi00P0SVXj08m[>`2@K3`0T6`l08m[>`2>JSX0SFTi08iY?080SFPk0P2<IcX208]V
>@0408YU>02:J3X0RfTk08]Y>`D0S6Xl202AK3l0202=JCT0SVXj08mZ?@2@Jcl0SfY008eW@02;ID00
RV@o102=Jcd0102<JS`0RfTk08]Y>`2:J3X308mZ?B_ooooo000Zooooo`P0Rf@k0`2;ICP308YT=`80
RF<f202?I3T3091U>080Sf@g0`2>HcH2099W?080TFHk00@0T6Dj08mT>@2>HcP0SV<h0P2BIc`3095V
>`/0T6Dj00H0Uf@i09ET>@2EI3T0U6Di09=W>P2BIcX2095X>P0309AX>`2CIcX0TVHi0080TFDh00<0
TVHi09=W>P2DJ3/00`2BIcX309=X>`<0U6Tl0`2CJ3/209AY?0<0UFXm0`2GJch209Q/?`<0VFe00P2G
K3l209Q]@0<0VFi100<0VVm209Y`?P2JL3h0102IKcd509Y`?P80Vg4o1P2LLT0309ec@@80WWA22`2M
Ld4209ab@0<0Vg4o0P2MLD0209ib@@<0Wg=200@0X7A30:AdA02SLd<0XW920`2QLD420:9b@P80W790
0`2MLd4309id@P0309ab@02MLd40WWA20080WgE300H0WWA209ec@@2LLT00X7I409me@`2NM48209ec
@@0509id@P2OMD<0X7I409mf@P2NMD400`2MM4000`2OMT80X7M30:5hA00809mf@P060:=fC02SMdX0
XgM:0:9fA`2RMTD0XGI30P2QMT480:9hAP060:9gC02RMdX0XWM:0:5gA`2QMdD0XGQ40P2PMd430:9i
A@80XGQ4102PMd<0102PMDP0XGI90:9gBP2SN4/20:AiC0030:=hB`2RMdX0Xg/n0080Xg]000<0Y7]3
0:AkA@2TNdL00P2TNTP80:EjA`@0Xgi9102RODP:0:MnBP@0ZH1<0P2WOTX80:QoB`040:=nBP2TOd/0
Y7m;0:AoB`@0YH1<00<0YWe90:MnBP2YP4`00`2ZPDd20:V0C0<0Ygi:0P2XOd/30:V0C0@0Z7m;0P2Y
P4`20:Z1C@030:^1C`2ZP4h0ZGm=0080Z7i<00<0ZGm=0:Z0CP2[PDl00P2YP4X20:Z1B`80Zh9<0P2/
Pdd0102YP4`0ZX5=0:Z1C@2ZPDd30:^2CP040:b3C`2^QE40[HA@0:^2CP<0ZX5=0P2[PTh80:b3C@<0
Zh9>0`2/Pdl20:f4D0030:N2CP2XPdl0ZXEA0080[8MC00H0ZhIB0:Z5D@2YQ500[89@0:f3D@2^Q582
0:n5D`070:f3D@2[PDl0Zh5?0:Z0CP2[PDl0[89@0:j4DP020:n5D`030:j4DP2/PU00Zh5?0080Zh9>
0P2/Pdl30:f4D0030:j5D@2^Q580[XAB00H0[XAB0P2ZQE430:^6DP<0[8MC202[QU801P2]QeX0[HMH
0:f7F02]QeH0[HQD0:f8D`80[HQA0`2[QU830:b7D`80[HQD202^RED20:j4E0040:j4DP2]Q500[HA@
0:b3C@80[8=;00P0/HI?0;27C`2aR580/8QD0:n:E@2^RUH0[8]H0:f<F@P0[XUE0`2/Qe<20:f8E0@0
[XUE0`2_RUH20;2;E`80/HaH0P2dRUP01P2cREL0/XQF0;:8EP2cREL0]8YH0;F;FA00/XeI0P2_Re/0
0`2`S5`0/HeM0;:>GP020;>?G`030;B@H02bSEP0/XeH00H0/XeH00L0]XmT0;F>H`2dSV40/XaM0;:<
F`2bSET0/hiJ0080/hiI0P2dSUl0102cSEh0/XaM0;:<G@2aRe`20;2:F`<0/XeI0`2cSUX20;B?F`80
/XaM0P2cSEh30;B>G`030;F?H02cSUX0]8mK00<0]I1L00<0]8mK0;>>FP2cSUX00`2fTV820;FAH@<0
]91P00<0]i=S0;JBHP2eTF400P2dT6000`2eTF40]Y9R0;NCH`040;B?F`<0]I1L00@0]Y5M0;B?FP2e
T5/0]i9M0P2hTeh00`2fTE`0]I1K0;B?FP030;NBGP80]Y5M0`2eT5`80;>>F@040;:=F@2cSUX0/hiJ
0;>>FP@0]8mK402cSUX;0;B@H080]I5Q0`2fTV800`2fTF@0]I1S0;>>H@020;:=H0040;B?HP2eT6<0
]Y5T0;J@H@80]HmP00<0]8iO0;>=GP2bS5d00P2aRe`30;>>FP80]8mK0`2eT5`20;FAG@040;B@G02c
Se/0/hmK0;:>FP80/HeI0`2aSEd0102bSUh0/hmO0;>?G`2dT6020;FAH@0;0;J@H@2eSf00]8iO0;>=
GP2dSUl0]HmP0;NAHP2hTV<0^9AP0;NCG`2fTUh00P2eTEd02`2fTUh0]i=O0;RDH02hTel0]i9N0;F@
G02dSe/0/hiJ0;B?F`2eT5`0]Y5M00<0]I5Q0`2dT6020;>?G`0C0;RDI02iUFD0^IEU0;ZFIP2kUfL0
_IUY0;jJJP2oVf/0_9QX0;^GI`2jUVH0^9AT0;NCH`2eTF40]91P0;>?G`2dT600]I5Q0;JBHP020;NC
H`060;JBHP2eTF40]91P0;FAG@2dT5`0/hmK0P2bSUX00`2cSe/0]91L0;FAG@050;B@H0<0/hmO202f
TV80102gTf<0]Y9R0;JBHP2fTV830;FAH@030;B@H02cSel0/hmO0080]91P00@0]I5Q0;JBHP2gTf<0
]i=S402gTel80;JBHP<0/hmO0P2dT6030;FAH@80]i=S0P2fTV820;FAH@80]91P00<0]I5Q0;B@H02c
Sel00P2bSUh00`2cSel0]91P0;FAH@030;B?F`<0]I1L0`2fTEd20;F@G0<0]Y5M00<0]I1L0;>>FP2b
SET0202eT5`30;FAH@<0]91P0P2cSel20;:AG0<0/I1K0`2`SeX0202eTF40]91P0;:>GP2aSEd0/8aL
0;6=G@2bSUh0/hmO202cSEh20;B?HP040;B@H02cSed0/hmK0;:?F@80/XmG00H0]I5M0;B@G02dT5`0
/hmK0;:>FP2aSET20;2<F0030;6=G@2bSUh0]91P0080]I5Q00<0]91P0;:>GP2aSEd00P2aSEd20;:>
GP@0/hmO00<0/XaM0;>=GP2dSUl00P2eSf000`2dSUl0/heN0;:<G@020;6>F0040;:?F@2cT5X0/i1J
0;BAF`80]I9L0P2cSed00`2cSel0/hiQ0;>>HP020;>>I0040;>=IP2bSUh0/XiN0;:>GP80/HeM0`2`
S5`00`2aRe`0/XaM0;>=GP020;B>G`030;>=GP2bS5d0/H]L0080]8iO0`2cSEh30;:<G@050:n:EP2a
S5P0/hiJ0;F@G02fTEd00P2eT5`01@2dSe/0]I1L0;B?F`2dSe/0/hiJ0080/XeI0P2aS5P20;B=EP80
/XeH00P0/HeI0;6=F`2_SEd0[XiM0:j>G`2_Re/0/8aL0;>?G`80]I5Q00<0/hmO0;6=G@2_Re/0202c
Sel01@2^RUH0[h]G0:n;E`2`S5P0/HeI0080/XiJ00`0/hmK0;:CG@2bTed0/Y5L0;:>FP2aSET0/HaH
0;::E`2aREH0[h]K0;2<G02aSEd20;:>GP030;6=G@2`S5`0[h]K00P0/XeI102aSET40;2<F0<0/8aL
0`2_Re/20:j:FP060;6<G`2aSEd0/HeM0;6=F`2aSET0/HiH0P2aSUH30;2<F0<0[h]G0P2^RUH20;2=
E@070;2=E`2_ReL0[h]I0:n;F`2^RUX0[XUL0;:>FP030;6=F@<0/8aH00H0[h]G0;2;G`2`Rel0[hYM
0:n;F`2^RUP20:j:EP040:f:E02]RED0[HUE0:f9E@80[XYF2`2_ReL30;2<G0<0[h]K0P2^RUX00`2Z
QU80ZhMC0:^7D`020:b8E0080:^7D`2ZQU80ZHEA0;B6E@2cQE@0/HED0;26E02^QU<20:b7D`040:Z6
DP2/QeX0[8QH0:b8F080[8QF00@0[8QD0:b9D`2/RE40[8UA0P2/R5@0102]RED0[XYF0:j:EP2_ReL2
0;2<F0P0[h]K0P2_RUH30;2;E`<0/HaH0`2^RED30:f8E080[8MC0P2[QEH0102/QUL0[HMH0:f7F02/
QUL20:^5EP<0[8MC0`2[QU820:Z5D@<0ZhMC0`2ZQU820:V5D@030:j9E@2]R5@0[8MC0080ZhIB00<0
[8MC0:f8E02^RED00P2XPdl20:V4D0@0ZXEA00H0ZhEH0:Z4E@2ZQ5D0ZXAC0:V4D02YQ4l20:R3C0P0
ZhIB402YQ5080:R3CP<0ZHA?0P2XPdh30:N2C@<0Z8=?0`2YQ5020:Z5D@@0ZHA?102ZQE020:b7DP06
0:^6D@2YQ4l0Z8=>0:N2C@2VPD`0YH1;2@2XPdh00`2UP4/0YX5<0:R3CP020:V4C`030:N2C@2VPD`0
YH1;00P0Z8=>202UPT`20:V4D080Z8=?0P2WPTh20:J1C@P0YH5=0`2TP4`01@2UPDd0YX9>0:J2CP2V
PTh0Yh=?00P0Z7m;0P2UP4/30:AoBP<0Xgi90P2RO4/0102RODT0Xgi90:=nB@2TOdP20:B0AP80YH1<
0P2VPDd03`2TOd/0XWe909mjAP2NNDD0WgY30:1kA02PNdH0XGa80:1jB@2ONDX0WWQ909egBP2PNdL0
XGa80:9mB@020:=nBP030:9mB@2QO4P0X7]700<0XGa50P2PNd@309mj@`@0WGQ300@0WgY50:5lA`2S
OTT0Y7m:0P2QO4L30:1kAP<0WgY50`2QO4P20:9mB@/0Xgi:00<0XGa70:1kAP2NND@00P2LMd80102M
N4<0WWU409mjA@2ONTD30:1kAP@0XGa700@0XWe809mk@@2ONd40WgY30P2ONTD0102ONTH0WgU809mi
B02MN4/209ijBP0309mkB@2PO4P0XGi80080XWm700P0V7M409YiAP2POTh0ZHMI0;2>H@2_S680Z8EK
0:5nEP<0Y7m:0`2SOTT20:9mB0030:1kAP2ONTD0W7M20080VWE000<0W7M209iiA02PNdH00P2MN4@3
09iiA@<0WgY600<0W7Q809eiB@2NNTX00`2NNTX0102MNDT0W7Q80:5m@@2PO4820:1kA080WgY600@0
WWQ709ihB@2NNdD0WW]50P2MNT@209ai@`80VgQ2202NNdD00`2ONTD0WWU409ag@P0309]f@@80W7M2
0P2JMT801P2KMd<0Wg]70:9nBP2ROTX0WWY809YfA080W7M30`2MN4@00`2LMd<0VWE109Ud@00209]g
A`0309YfAP2IMDD0V7A40080Ug=300@0UW9209Mc?`2GLcl0Ug<o0P2HM40309Ue@@0409QdA02GLd<0
UW9209Ea@@80U71000<0UG5109Ib@P2DKSl00P2DKSl209=]?P<0TV`m00T0TFdm09=_?`2ELD40Tflo
091/?02?Jc/0T6`l09=_?`2?JSd00P2@Jch00`2AK3l0TVe009=^@@0309A_@PP0Tfhj0P2EKd8209A^
@@<0Tfe000H0TV`o095]?@2AKCd0T6`l08m[>`2>JSX508eY>@@0SVXj0P2=JCT208iY?00308eX>`2<
IcX0RfHi0080RVDh00@0RF@g08YX>P2;JC/0S6Xl0P2=Jcd00`2<JS`0RfTk08YX>P08091[?P0808YV
=P2<J3P0SVTl08mZ?P2@Jd40SfU208iX@`2=Id8208e[?@<0SV`n00<0SF/m08]Y>`2:J3X00`2?JSd[
ooooo`00:_ooool808]T>`<0RF<f0`2:I3L208]U>0P0Sf@i0`2@ICP208mT=`<0SV<f00H0U6Tn09=X
?@2BIc`0TFHk091U>P2>HcP208eR=`80TFHk0`2BIc`309=X?@P0T6Dj00H0V6Dh09IV>02FISP0UFHh
099V=`2AIcL2091X=`0309IW>`2EISX0U6Di0080Tf@h00<0U6Di09EV>P2FIc/00`2@ICP3095V>@<0
TVLj0`2CJ3/209AY?0<0UFXm00@0Uf/n09Q/?`2HK3l0V6`o0P2IKD0209Y^@@<0Uf`o0P2HKD0309U^
@@P0VW0n0P2IKcd209Y`?P<0Vg4o102LLT0309ec@@80WWA22`2MLd400`2LLT00Vg4o09]a?`0209Y`
?P<0WG500P2NLT4309mc@P030:=c@`2RLT80XG510080X71000<0XW920:AdA02UMDD00`2NM48309me
@`80X7I400<0WG=109id@P2PMT@00P2QMdD01P2PMT@0WWA209ec@@2RN4H0XGM509me@`80WWA200H0
WgE30:5gA@2RN4H0XGQ40:1g@`2NMD4209ac?`0309ed@02NMD40WgI200P0WgI200H0YgQ>0:MhC02V
Md/0YWM90:EgAP2UMdD20:Af@PP0XWQ600H0X7E:0:1eB02PMDP0XGM70:5gA@2QN4@20:9i@`80XWU5
0P2QN4@50:1g@`0309mdA`2PMDP0XWM:0080Y7U<00/0XgQ;0:9gBP2QMTT0XGTl0:5i?P2RNSl0XgY2
0:AkA@2UO4P0YG]90:IlBP080:AiAP@0XWe8102SOTT80:MnBP030:ImB@2WOTX0ZH1<0080ZX5=00<0
ZH1<0:MnBP2VODT0202XOd/30:F0C080Y7m;0`2SOTX00`2TNdL0YGa80:MnBP030:V0C080Ygi:00<0
YWe90:MnBP2WOTX00P2XOd/20:V0C0040:Z1C@2WOTX0Z7m;0:QoB`80ZH1<0P2ZPDd0102[PTh0Zh5?
0:Z0CP2XOT`20:MmB`030:QnC02ZP4h0Zh5?0080ZH1:0P2ZPD/20:^2C080[8==0P2YP4`20:Z1C@80
Zh9>0P2/Pdl00`2^QE40[HA@0:^2CP030:V0C0030:Z1C@2[PTh0[8=;00D0[8=;0P2[PTX30:^2CP<0
[8=?0P2]Q5000`2WPTh0Z8=?0:Z5D@020:b7D`060:^6DP2ZQE40ZHA@0:b2D02]Pe40[XAB0P2_QE<0
1`2]Pe40Zh5?0:^1C`2ZP4h0Zh5?0:b2D02^Q5800P2_QE<00`2^Q580[89@0:^1C`030:^2CP80[8=?
0`2]Q5080:j4DP80ZXEA0`2[QU830:b7D`P0ZhIB00H0[HMJ0:f7F02]QeP0[HMF0:f8E02]R5<20:f8
D@80ZXEA0P2[QU820:b7D`80[HQD202`ReL20;26EP040;26E02_QU80[hIB0:j5C`80[XE=00H0/HI?
0;27C`2`Qe40/8QD0:j9E02^RUH20:b;F0P0[XUE0P2[QU820:b7D`040:f8E02^RED0[XUE0:j9E@<0
[hYF0P2`ReL30;6<F0040;:8EP2cREL0]8YH0;F;F@80]8YH0P2bR5H80;:=F@P0/hiJ0P2_Re/0102`
S5`0/HeM0;:>GP2cSel20;B@H0P0/XeH00H0]i1Y0;J?IP2dSF80/XaO0;:<F`2bSET30;B?F0H0/XaM
0P2aRe`30;:=F@<0/hiJ0P2dSe/30;:<G@80/heN0`2dSUl00`2bSET0/hiJ0;F@G0020;JAG@030;F@
G02dSe/0/hiJ00@0]Y9R0P2eTF420;B@H0030;JBHP2eTF40/hmO0080/XiN00<0/hmO0;B@H02eTF40
0`2eT5`30;B?F`80/hiJ00<0/hiI0;B?FP2fTE`00P2gTUd00`2fTE`0]I1K0;B?FP020;RCG`80]i9N
00@0]Y5M0;F@G02eT5`0]I1L202cSUT30;B?F`80/hiJ0`2bSET@0;>>FP/0]91P00<0]I5Q0;JBHP2f
TV800P2gTf<0202fTFD0]I1T0;B?H`2cSV80/XeQ0;>>HP2eT6@0]Y5U0P2eSf00102dSUl0/heN0;:<
G@2bS5d20;6;G0030;:=F@2cSUX0/hiJ0080]8mK0P2eT5`01P2fTEd0]Y9N0;FAG@2eTEd0]91L0;:>
FP80/HeI00<0/8aH0;>?G`2cSel01`2cSel02`2fT640]HmP0;B>G`2cSEh0]8iO0;F?H02gTF80^99S
0;VEH@2hU600]Y9N0080]I5M00/0]Y9N0;RDH02iUF40^9=O0;NBGP2eT5`0]8mK0;>>FP2dSe/0]I1L
0;JAG@030;FAH@<0]91P0P2cSel20;JBHP80]i=S00<0^9AT0;VEI@2iUFD00P2iUFD20;RDI0080;NC
H`2eTF40]91P0;B@H02cSel0]91P0;FAH@2fTV820;NCH`060;JBHP2eTF40]91P0;FAG@2dT5`0/XiJ
0P2aSET00`2bSUX0]91L0;FAG@060;>?G`80]91P202fTV820;NCH`80]Y9R0P2eTF460;B@H0@0]I5Q
402hU6080;JBHP<0]I5Q0P2fTV850;NCH`80]Y9R0P2eTF420;B@H0030;FAH@2dT600/XiN0080/HeM
00<0/hmO0;B@H02fTV800`2dSe/30;F@G0<0]Y5M00<0/hiJ0;B?F`2eT5`00P2eT5`00`2cSUX0/HaH
0;2;E`080;B?F`<0]I5Q0`2dT6020;>?G`030;BCGP2cTUd0/i9M0080/Y5L0P2aT5/0102`SeX0]i=S
0;JBHP2dT6030;:>GP030;>?G`2dT600/heN00L0/heN0P2dSf<0102dSf80/hmM0;>?F`2bSeL20;:?
E@80]91L00@0/hmK0;:>FP2aSET0/HeI0P2`S5P00`2aSEd0/XiN0;B@H0020;FAH@040;B@H02bSUh0
/HeM0;2<G080/HeM0P2bSUh20;>?G`040;B@H02aRe`0/XaM0;B>G`80]HmP00<0]8iO0;:<G@2aRe`0
202cT5P20;>?G@030;>?G`2cSV40/hiR0080/hiT00<0/heV0;B@H02dT6000P2cSel20;:>GP80/HeM
00<0/H]L0;:<G@2dSUl00P2eSf000`2dSUl0/XaM0;6;G0020;B>G`<0/heN0`2bS5d0102_RUH0/HaH
0;>>FP2eT5`20;JAG@80]I1L1@2cSUX30;:=F@80]HiG0P2cSUT01@2bSUX0/XiL0;2>GP2_Seh0[hmP
0080[h]K00@0/HeM0;:>GP2cSel0/hmO0P2dT6080;FAH@@0/8aH102aSET01P2aTU`0/95K0;6@F`2b
SUX0/HeI0;:=F@80/h]H00<0[h]K0;2<G02aSEd00P2bSUh00`2aSEd0/8aL0:n;F`080;:=F@@0/8aH
102aSET20;6=G@80/8aL00D0[h]K0:j:FP2^RUX0[XYJ0:n:G@020:n;F`030:n;F@2_ReL0[haF0080
[haD0P2^RUH30:n;E`<0/8aH0P2aSUH00`2`SEL0/8aH0:n;F@020:j:FP030:j9G02bSUX0/XiJ0080
/HeI0P2`S5P20:n;E`80[hYN00H0[hYM0:j:FP2^RUP0[XYF0:f9E@2]RU@30:^7D`030:b8E02]RED0
[HUE0080[XYF202]S5L30;2<G0<0[h]K0P2^RUX03P2[Qe<0[8QD0:b8E02]RED0[8QD0:Z6DP2XQ500
YX9>0;F5E@2dQUD0/hED0;65E02_QE<0[XIC0P2[QU800`2/QeX0[8QH0:b8F0020:b8EP050:b8E02/
RE<0[8UA0:b9D@2[Qe<00P2/R5@01@2]RED0[h]G0;2<F02`S5P0/HeI00P0[h]K0`2aS5P30;2;E`80
[hYF0`2/Qe<30:f8E080[XUE00<0ZXAE0:^5EP2/QUL00P2]QeP00`2/QUL0ZhEF0:Z4E@030:b7D`<0
ZhIB0P2ZQE430:^7D`<0ZXIB0P2YQE400`2[QU80[8MC0:f8E0020:j9E@040:f8E02/Qe<0ZhIB0:N2
CP80Z8=?0P2YQ5020:Z5D@070:^6DP2ZQ5L0ZXAE0:Z4E@2YPe80ZHA@0:R3CP020:R3C0P0ZhIB202Y
Q5020:R3C`H0ZHA@202ZQE030:V4C`030:R3CP2WPTd0Yh9=0080YX5<0P2WPTh20:R3C`040:V4D02Z
QE40ZXEA0:Z5D@P0Z8=>0`2ZQE001@2YQ4l0Z8=>0:R3CP2XPdh0Yh9=00T0Z8=>00<0Y7m:0:F0B`2W
PTd00P2XPdh00`2WPTd0YX5<0:F0B`080:R3CP80YX==1P2UPT`20:V4D080Z8=?0P2WPTh20:J1C@P0
Xgm;00<0Y81<0:F1C@2UPDd00P2UPDd30:J2CPP0Z7m;0P2UP4/30:AoBP<0Xgi900H0XWa;0:=mC02S
OTX0Xgi90:AoBP2TOdP20:F1A`80YH1<0180YX5=0:F0C02TOd/0XGa809mjAP2MN4@0W7M009eh@@2O
NTD0XGa80:5kBP2PNT/0WgU:09ihB`2SOTX0XWe90:1kA`2ONTH409iiA@030:9nA02QOD<0XGe30080
X7a20P2ONd400`2NNT00WgY509iiA00309eh@`0309mjA@2QO4L0Xgi90080XGa70P2PNdH0102ONTD0
WWU409iiA02NND@20:5lB080XWe9302SOTX00`2QO4D0X7]409ii@P0309ag@00309eh@@2NND80WgY5
0080WgY500@0X7]60:5lA`2QO4L0XGa70P2RODP20:1l@P040:1kA02PNdH0X7]60:1kA`80X7Y900H0
VgI909ahB02MNDT0WWY809mkA`2PODL20:5nAP0809QhA@2HN4L0Wgm>0:n?H02nWG00`9md0;:AJ02T
PeX20:F0B`80Y7m:0P2SOTT20:9mB00309mjA@2NND@0WWU400<0WWU40P2ONTD209mjAP<0WWU50`2M
N4@00`2KMdL0W7Q809ijBP0209mkB`0;09ijBP2LN4P0VgM70:5m?`2QOD40X7a20:1kA02PNdL0WgU8
09miBP2OND`00P2NNd<209ej@P80W7U10P2KN40809ikA@0<0:1kA02NND80W7M009]f?`2JMCh0VgHo
09ag@02MN440W7U109]h@02KN480Wga60P2SOd/0102MNDL0Ug=109]f@P2LMd<309iiA@0309ag@`2J
MD40VGA00080VgM700<0VWI609UeA@2HM4@00P2GLd<00`2FLT80Ug<o09Qd@00209Qd@080VGE10P2J
MT802@2HM4@0Ug=309Ea@@2DL400Tflo09A`@02ELD40UW9209A^?`0309=]?P80TV`m0P2AJc`0202A
KCd0U71009Ib@P2DL400T6`l08iZ>P2AKCd0U7100P2AK3l00`2BKD00Tfi109A_@P0309E`@`0309Ia
A02EL3`0UG0l00H0UG0l0P2CKD02099/?`@0TF/n1P2?Jc/208iZ>PP0SFTi0P2>JC`03P2=J3/0S6Lj
08]V>@2:ICP0RF@g08QS=P2:J3X0RfTk08e[?@2>K3h0SF/m08aZ?02:J3X0RFLi202>JC`01P27Hc<0
RFDe08aW>P2>JCd0T6]1095[A080T6Y500P0SF/m08i/?P2?KCl0T6i008m]?`2>K3h0S6Xl08YX>P<0
T6/n:oooool002[ooooo202;I3/01@27HC@0R68e08QR=@29HcH0RV@g0080RfDh00<0S6Hi08mT>@2?
I3T01P2?I3T3091U>080Sf@g0`2>HcH209AY?P06099W?02AIS/0Sf@i08iS>02=HSL0S64f0P2AIS/0
0`2BIc`0TfPm09AY?P0209EZ?`0309I[@02@ICX0T6Dj00H0T6Dj00H0V6Dh09IV>02FISP0UFHh099V
=`2AIcL2091X=`0309IW>`2EISX0U6Di0080Tf@h00<0U6Di09EV>P2FIc/00`2?I3L4091U>080TFHi
0`2CJ3/209AY?0<0UFXm102HK3l209U]@080VVi10`2GK3l309Q]@080VFi10`2JL3h209]a?`<0VW0n
0P2IKcd209Y`?P@0Vg4o0`2LLT0309ec@@80WWA22`2MLd400`2LLT00Vg4o09Y`?P0209Y`?P<0WG50
0`2NLT4209mc@P080:Aa@P2SL440XVm00:5^?`2RKd00Y7520:MdA@2XMDH309me@`<0X7I40P2QMdD0
0`2NM480WgE30:5gA@020:9hAP060:5gA@2OMD<0WWA20:=iA`2RN4H0X7I40P2OMD<02`2PMT@0XWQ6
0:=iA`2SNTH0XGQ409ie@@2LLcl0Vg8n09ac?`2MM400WWE100P0WgI200P0Z7U?0:QiC@2WN4`0YgQ:
0:IhA`2VN4H0YWQ40:Eg@`D0XWQ60`2QMdD0202NLdP0WgA709mdA`2PMTH0XGM50:9iA@2RND<0XgY4
0P2RNDD20:5hA0@0X7M300@0WgI209icB02PMDX0XWM<0P2TNDh02@2SN4d0XWM<0:5fB`2OMcX0WgLl
0:5i?P2RND40Y7]50:ElB0020:MmB`P0Y7U600D0X7]60:5lA`2QO4L0XWe80:=nB@020:AoBP030:F0
B`2WOTX0Ygi:00H0Ygi:00<0YWe90:MnBP2YP4`00P2ZPDd00`2YP4`0Ygi:0:ImB@080:QoB`80YX5=
00@0YH1<0:AoB`2SOTX0Xgi:0P2RODT0202SNTH0Y7]70:ImB@2XOd/0ZH1<0:QoB`2VODT0YGa80P2V
ODT0102WOTX0Z7m;0:QoB`2YP4`20:Z1C@040:MnBP2XOd/0Z7m;0:V0C080ZX5=0P2[PTh00`2[PDl0
ZX1>0:QnC0020:MmB`030:QnC02ZP4h0Zh5?0080ZH1:0P2ZPD/20:^2C080[8==0`2YP4`00`2ZPDd0
Zh9>0:b3C`020:b3C`080:j5D@2/Pdl0ZX5=0:V0C02XOd/0ZH1<0:Z1C@2/Pdl50:b3B`<0Zh9:0`2[
PTh30:b3C`80[HA@00<0Yh9>0:R3C`2ZQE400P2/Qe<01P2[QU80ZXEA0:V4D02/PU00[H=A0:j4DP80
[hEC00L0[H=A0:^1C`2[PDl0ZX1>0:^1C`2/PU00[XAB0080[hEC00<0[XAB0:b2D02[PDl00`2[PTh3
0:b3C`80[HA@202^Q5820:Z5D@<0ZhIB0`2/Qe<80:^6DP060:f7FP2]QeP0[HMH0:f7EP2]R5@0[HQC
0P2]R540102YQ500ZXEA0:Z5D@2[QU820:b7D`80[HQD202aS5P20;>9F@040;>9E`2bRED0/XUE0;68
DP80/HQ@00H0/HI?0;27C`2`Qe40/8QD0:j9E02]RED20:b;F0P0[XUE0`2[QU800`2/Qe<0[HQD0:j9
E@020:j9E@80[hYF0`2`ReL30;6<F0030;67E@2cREL0]H]I0080]XaJ00<0]8YH0;67E@2`QU@0202b
SET80;>>FP060:n:G@2`Reh0/8]N0;6<G`2bSF00/hiQ0P2dSf880;:=F0070;N@J@2fSfP0]8eR0;:<
G`2aReX0/XeH0;B?F0020;FAE`040;2:F`2aRe`0/H]L0;6;G0<0/XaM00@0/heN0;:=F@2bSET0/XeI
0`2cSUX20;B?F`<0/XaM0`2cSEh20;B>G`030;6<F02bSET0]I1L0080]Y5M00@0]I1L0;B?F`2bSET0
]i=S0`2fTV820;FAH@80]91P00<0]I5Q0;B@H02bSUh00P2`S5`00`2aSEd0/hmO0;B@H0020;JAG@04
0;F@G02dSe/0]8mK0;>>FP80/XeI00<0/hiI0;B?FP2fTE`00P2gTUd00`2fTE`0]I1K0;B?FP030;RC
G`030;NBGP2fTEd0]I1L0080]I1L202cSUT20;F@G0040;B?F`2cSUX0/XeI0;:=F@80/HaH402cSUX;
0;B@H0030;FAH@2fTV80]i=S0080]i=S00P0]i9V0;JAI@2dSf<0/hiR0;:=H@2cSV80]8mS0;F@I080
]HmP00<0]8iO0;>=GP2bS5d00P2aRe`0102`RU/0/XeI0;:=F@2cSUX20;B?F`030;F@G02fTEd0]Y5M
0080]Y9N00@0]I5M0;B@G02bSUX0/HeI0P2`S5P40;B@H080/hmO0`2bSUh02`2fT640]HmP0;B>G`2c
SEh0]8iO0;F?H02gTF80^99S0;VEH@2hU600]Y9N0080]I5M00/0]Y9N0;RDH02iUF40^9=O0;NBGP2e
T5`0]8mK0;>>FP2dSe/0]I1L0;JAG@030;FAH@<0]91P102cSel40;B@H080/hmO0`2fTV820;FAH@@0
]91P00X0]I5Q0;JBHP2gTf<0]i=S0;JBHP2eTF40]91P0;FAG@2dT5`0/XiJ0P2aSET00`2bSUX0]91L
0;FAG@020;:>GP@0/hmO0P2dT6080;JBHP<0]i=S00<0]Y9R0;FAH@2dT6000P2dT6030;FAH@<0]91P
0P2cSel@0;RDH0X0]Y9R0`2gTf<30;RDI080]i=S0P2fTV820;FAH@80]91P00<0]I5Q0;>?G`2bSUh0
0P2aSEd00`2bSUh0]I5Q0;JBHP030;B?F`<0]I1L0`2fTEd0202bSET0/hiJ0;B?F`2eT5`0]8mK0;:=
F@2`ReL0[XUE202dSe/30;FAH@<0]91P0P2cSel0102eU5h0]9=M0;BCG@2cTU`20;:AF`80/I1J00<0
^9AT0;NCH`2eTF400`2cSel00`2dT600]I5Q0;>=GP070;>=GP080;B?I@2dSf<0]8mR0;>?G@2cT5X0
/XmG0;:?E@2bT5<20;B@G0030;>?F`2bSUX0/HeI0080/8aH00@0[h]G0;6=G@2bSUh0]91P0P2eTF40
0`2dT600/XiN0;6=G@020;2<G080/HeM00L0/XiN0;>?G`2cSel0]91P0;6;G02bS5d0]8iO0080]HmP
00<0]8iO0;:<G@2aRe`00`2dTET20;>@F0<0/XmG0P2cSed00`2cSel0/hiQ0;>>HP020;>>I0060;>=
IP2eTF40]I5Q0;FAH@2dT600/hmO0`2bSUh00`2aRe`0/XaM0;B>G`020;F?H0030;B>G`2bS5d0/H]L
0080]8iO0`2cSEh30;:<G@040:n:EP2aS5P0/hiJ0;F@G0<0]Y5M00<0]I1L0;:=F@2bSET01P2cSUX2
0;F>E`80/hiI00D0/XiJ0;:>G02`SUh0[hmN0:n?H0030:n;F`050;2<G02aSEd0]91P0;JBHP2gTf<0
202fTV80102bSUX0/HeI0;6=F@2aSET30;2<F0040:n;E`2`TEX0[i1I0;2?F@80/XmI00H0/XeH0;B<
F02dS5P0[XYJ0;2<G02aSEd20;>?G`030;6=G@2`S5`0[XYJ00P0/XeI102`S5P40;6=F@80/HeM0P2`
S5`01@2_Re/0[XYJ0:j:FP2]RET0[XUL0080[XYJ00<0[XYH0:j:EP2^ReD00P2^Re<20:f9E@030:j:
EP2_ReL0/8aH0080/HeI00H0/XiJ0;6>EP2aSUH0/8eG0;2<F02_ReT20:j:FP060:f8F`2bSeT0/XmI
0;:?F@2aSUP0/8eG0`2_S5H20:n:GP030:n:G@2^RUX0[XYH0080[HUE00@0[HYD0:V5D@2YQE40ZXIB
0P2[Qe<00`2/R5@0[HUE0:f9E@080:f<E`<0/8aL0`2_Re/20:j:FP80[8QD0P2]RED0102/R5@0ZHEA
0:J2CP2UPDd20;F5E@030;B6E@2aQE@0[hEC0080[HEB00@0ZhIB0:b7FP2/R5P0[8QH0P2/R5H0102/
R5@0[8UC0:b9D@2/RE420:^8DP040:b9D`2]RU@0[haF0;2=E`80/HiH202_Re/01P2cSUX0/XeI0;:=
F@2aS5P0/8]G0:n:EP80[XUE00D0ZXEA0:^6DP2[QU80[8MC0:f8E0020:j9E@040:n:EP2YPeH0ZXAG
0:b6F@80[XQK00<0[8II0:Z4E`2YPeH00`2/Qe<30:^6DP80ZXEA0`2[Qe<30:Z6DP80ZHEA00<0ZXEA
0:^6DP2^RED00P2_RUH00`2^RED0ZhIB0:Z5D@020:N2CP80Z8=?00X0ZHA@0:Z5D@2ZQE40ZhIB0:Z4
E`2ZQ5D0ZH=D0:V3DP2YQ500Z8=>0P2XPd`80:^6DPP0ZHA@0`2XPdl50:V4D0P0ZhIA0`2YQ4l00`2X
Pdh0Yh9=0:J1C0020:J1C080Yh9>0P2XPdl0102YQ500ZXEA0:Z5D@2[QU820:R3CP@0Yh9=0P2VPD`8
0:V4C`T0Z8=>00<0Y7m:0:F0B`2WPTd00P2XPdh00`2WPTd0YX5<0:F0B`080:R3CP<0YX==1@2UPT`2
0:V4D080Z8=?0P2WPTh20:J1C@P0XWi:1@2UPDd30:J2CPP0Z7m;0P2UP4/30:AoBP<0Xgi90P2SOD`0
102SOTX0Xgi90:AoBP2TOdP20:F1A`80YH1<01H0YX5=0:F0C02SOTX0XGa809iiA@2LMd<0VWDn09ag
@02NND@0XGa80:5kBP2QNd`0X7Y;09miC02UP4`0Xgi:09mjAP2LMd<0VWE109]f@P2LMd<0WGQ40P2R
OT@0102QOD<0X7a20:1l@P2ONd4209ij@0090:1kAP2ONTD0WGQ309ag@P2MN4<0WWU40:1kAP2RODP0
XGa70080X7]600<0WgY509iiA02NND@00P2MN4<20:5lB080XWe90`2SOTX00`2TOd/0Xgi:0:=nBP06
0:=nBP060:5lA@2PNd@0WWU209ag@02KMSl0W7M00P2MN44209iiA00309mjA@2PNdH0X7]60080XGa7
0P2RODP20:5m@`040:5lA@2QO4L0XGa70:5lB080XG]:00H0VWE809]gA`2KMdL0WGU709ijAP2OO4H2
0:1mA@0909UiB02HN4L0Wgm@0;BCIP38Yg`0bjZ10;VHK`2VQ5h0YX5<0080YH1;00<0Y7m:0:=nB@2S
OTT00P2RODP01P2MN4<0WWU409mjA@2PNdH0XGa70:1kAP80WgY500D0X7]709mjAP2ONTH0WWU509eh
A00209ag@`0409]f@P2JMTH0W7Q809eiB@80Wg];00/0WGU909ahB02JMTH0XGhn0:5m?`2QOD40X7]4
0:1kA`2ONDX0WgU<09mhC@0209ik@`80WGY20P2LND4209]h@0P0WW]500<0X7]409mj@`2LMd000`2J
MCh00`2LMd00WGQ109ik@@0209ai@@0=0:1mA`2TP4`0Xgm=09ahAP2ELCl0VgI209ag@`2NNDD0WgY6
09iiA@2LMd<0VWE109Ud@00209]gA`0309YfAP2IMDD0V7A40080Ug=300<0UW9209Qd@02HM4000P2H
M40209Ue@@80VWI200<0V7A409Mc@`2ELD400`2CKcl00`2ELD40UW9209=]?P0309=]?P80TV`m0P2A
Jc`0202@K3`0U71009Mc@`2ELD40T6`l08iZ>P2AKCd0UG510P2BKD000`2CKT40U6m209E`@`0309Ia
A00309MbA@2GLSh0Ug8n00H0Ug8n0P2BK3l2095[?P80T6Xm0P2?JC`00`2=JCT0SVXj08iZ>P0208m[
>`04091/?02?Jc/0Sf/k08eY>@H0S6Ph00L0SFTi08iY?02>JC`0SFPk08aW>P2:ICP0RF@g0080R6<f
00<0RVPj08]Y>`2=Jcd00P2>K3h00`2<JS`0RVPj08UW>@0808eX>`0608IR<P28I3@0RfHi08iY?@2A
K480TVa50P2BK4L00`2=Jcd0SV`n091^@002091^@00308i/?P2<JS`0RVPj00<0T6/n:oooool002[o
oooo202:HcX208US=P80RV@g00D0RfDh08aV>@2<IST0SFLj08QR=@0208US=P0308YT=`2;ICP0S6Hi
0080SFLj00<0RfDf08YT=@29Hc@00P29Hc@02@2;ICH0SFLh08iX>@2=IcP0S6Hg08aV>@2;I3T0RV<j
08YS?00208UQ?@P0SVPk00<0TVLm091U>`2>HcT00P2<HCL04@2=HSP0SV<i08mT>P2AJ3@0TVTe09=Z
=P2DJcL0TfXf099Y=@2@Ic<0SVDa095V>@2@ICP0Sf@g08iS=P2=HSD0S64d0080Rf0c00@0UV<d09AT
=02EICD0U6He0P2CIcH0102BJ3H0TVXg099Z=`2@IS@2095W=@03099X=P2CJCL0U6Xh0080UF/i0P2E
JSd00`2FJch0Uf`o09Q]@00209Y_@P0609]`@`2HKD<0V6e309Q]@P2IKT40VFlo0P2JL3h0102JLCd0
VW0n09Y`?P2JL3h209U_?@<0V6hl0P2JKd8209]`@`80W7540P2MLTD209U_?@<0VW0n0`2KLCl00`2I
Kcd0Vg4o09ab@00209id@P0309ab@02KLCl0VFlm0080WWA20P2MLd4409ab@0P0W7<o202PLT001`2L
LT00WG=109me@`2PMT@0XGM50:1fA02OMD<02@2NM4801P2LLT00WG=109ec@@2OMD<0X7I40:5gA@80
XWQ60`2OMT8209ie@@<0WGA00P2OMT820:1g@`<0XGQ400`0XWU50:5gA@2PMT@0WgE309id@P2OMD<0
X7I40:9hAP2SNDL0XGM50:9hAP2TNTP20:EkB@0<0:AjB02RN4H0XGM50:5eCP2QMT`0XGI;0:5gA`2P
Md<0X7M10:1g?`2PN3d0Y7Y80P2SNDL0102RN4H0XGM50:5gA@2QMdD30:1fA0030:5gA@2SNDL0YG]9
0080YG]900D0XgU70:9hAP2QN4@0XGQ40:9iA@020:=jAP0;0:AkA`2UO4P0YGa80:IhA`2UMdH0XGE4
09me@`2OMd@0WgY60:5lB02QODT00P2UO4P20:ImB@040:MnBP2XOd/0Z7m;0:V0C080ZWe600@0ZWa8
0:YlBP2ZO4X0ZWa;0P2ZNdd80:ImB@P0Y7m;202WOD/20:V0C0@0Z7m;0P2WOTX80:QoB`<0YWe90`2W
OTX20:QoB`80ZX5900@0ZX5;0:Z1C@2ZPDd0ZX1>0P2ZP5030:UoC@030:Z0CP2[PDl0[89@0080[89@
0P2YQ5020:R3C`80Yh9>0P2VPDd80:b3C`030:f4D02[PTh0ZX5=0080Z7m;00<0ZX5=0:^2CP2]Q500
402/Pdl90:b2D0P0[H=A202ZQE400`2^Q580[H=A0:^1C`020:Z0CP030:^1C`2]Pe40[XAB00D0ZhIB
1@2/Qe<02@2[QU80ZXEA0:V4D02XPdl0Yh9>0:J1C@2ZQE40[8MC0:f8E0020:n:EP030:f8E02/Qe<0
ZXEA0080ZXEA0`2[QU830:b7D`<0[HQD0`2^RED20:n:EPP0/XUE0P2_RUH30:j9EA<0[HQD102bSET4
0;6<F0<0/hiJ00<0/XeI0;6<F02`ReL02P2`ReL80;6;G0050:n:EP2`ReL0/8]G0;6<F02bSET00P2c
SUX0102dSe/0/i1H0;>@F02cT5P50;:?E`T0/hiJ0`2bSET30;>>FP80]8mK0`2bSEP30;>>F@80]8mJ
0140^HeP0;N;GP2eRE`0]8QK0;>7FP2dR5/0]HUL0;J:G@2cSEh0]Y1Q0;RBH`2fT640/XaM0;2:F`2b
S5d0]HmP0;^?HP020;Z?HP030;V@HP2fT640]I5Q0080/i5Q202dT600202dSe/0]I1L0;JAG@2gTUh0
]Y5M0;B?F`2aS5P0/8]G202eT5T80;F?H0P0]8mK0`2bSET30;>>FP80]8mK0P2cT5P00`2cT5X0/hmK
0;>?G@020;>?G`030;>>H@2dSe/0]8mK00H0]8mK00<0/XeI0;>>FP2eT5`00P2fTEd00`2eT5`0/hiJ
0;:=F@080;J@H@<0/XeI00<0/hiJ0;B?F`2eT5`00P2eT5`80;B?F`P0/XeI00P0]Y5M0;NBGP2gTUh0
]i9N0;F@G02bSET0/8]G0:j9E@T0]8mR0P2`S5`0102aSEd0/XiN0;B@H02eTF4:0;JBHPT0/hiJ0P2d
Se/00`2eT5`0]Y5M0;JAG@020;NBGP80^99S0P2gTF820;J@H@80]HmP202cSel01P2`ReL0/XaK0;B>
G@2fT640^99U0;RAIP80]i1W202eSf080;B?F`060;NCH`2fTV80]Y9R0;FAH@2dT600/hmO0P2bSUh8
0;NAHP040;B@G02eTEd0]I5M0;FAG@<0]Y9N00<0]i=O0;FAH@2eTF401P2eTF400`2cSel0]I5Q0;JB
HP020;RDI0040;JBHP2eTF40/hmO0;:>GP80/hmO00<0]91P0;FAH@2eTF400P2fTV820;RDI080]i=S
102fTV830;NCH`030;JBHP2eTF40]91P0080]91P00H0/XmI0;:>FP2bSUX0/hmM0;>?G`2dSf820;B?
H`T0]HmP0P2eSf820;J@H`040;NAI02hTVD0^99U0;VCIPP0/XiN202aSET30;B@G0<0]I5M0P2fTUh2
0;2<G0<0/HeM0`2bSUh0202aSET0/8aH0;2<F02`S5P0/XiJ0;FAG@2gTel0^IEQ0P2fTV820;FAH@04
0;B@H02cSel0/hmO0;:>GPP0/hmO202`Reh0202cSel0/XiN0;6=G@2`S5`0/HeM0;>?G`2fTV80^9AT
0P2fT640102eSf00]8iO0;B>G`2cSEh20;:<G@080:f:E02cT5X0^9EO0;REG`2cT5X0/8eG0;6>F02d
TE/;0;B@H080/hmO0`2bSUh02`2eTEd0]91L0;:>FP2`S5P0[h]G0;2<F02bSUX0/hmK0;2<G02aSEd0
/XiN0080]91P00<0/XiN0;6=G@2`S5`0202aSEd<0;6=F@<0/XiJ0P2cSe/20;B@H0030;>?G`2bSUh0
/HeM0080[h]K00<0[XYJ0;F@G02eT5`01P2eT5`80;6<H0090;2:G@2aRe`0/XaM0;>=G02cSUX0/XeH
0;6<E@2`Re@0[XUE0080[hYF00<0/8]G0;6<F02aS5P00P2bSET20;>?G`80/XiN102aSEd40;6;G0@0
/XaM0100]91L0;>?F`2bSUX0/HeI0;2<F02_ReL0[XYF0:f9E@2dTET0/i1H0;6>F02_ReL0/8aJ0;6=
G@2cSel0]8mR0`2`S5P30:n;E`80[XYF202aSET20:n:EP<0/8]G0`2aS5P0102bSUh0/HeM0;6=G@2a
SEd20;2<G080[h]K402]RED30:b8E0<0[HUE0P2^RUH0202[QU80ZXEA0:V4D02YQ500ZXEA0:b7D`2^
RED0[hYF202/R5@90:f8F`80[8MC0P2]R5@01`2^RED0[hYF0:n:EP2`ReL0[XUE0;2;E`2aS5P00`2c
SUX00`2bSET0/HaH0;2;EP070;2;EPP0ZhI?0P2YQ5000`2ZQE40ZhIB0:b7D`020:f8E0030:j9E@2Y
QE40ZHEA00<0ZXIB0`2[Qe<40:b7D`@0[HQD00T0ZXEI0:^6FP2/Qe/0[HQL0:b7F`2ZQET0Z8=G0:J1
E@2[QeL00P2ZQUH20:V5E@80Z8AD00<0Yh=C0:^6DP2[QU801P2[QU820:R3C0060:R3CP2YQ500ZH=B
0:V3E02ZQ5D0ZXAG202YQ5000`2XPdl0ZHA@0:Z5D@020:^6DP030:V4D02WPTh0YH1<0080Yh=C00@0
Z8AD0:V5E@2YQED0ZXIF0P2[QeL01P2ZQ5L0ZXAE0:V3E02YPe80Z8=?0:R3CP80Z8=<00P0ZH9G0:V3
EP2YPe@0ZHA@0:V4C@2YQDT0ZHE70:V6AP<0ZHA=0P2ZQDh30:^6C`80ZHE;0P2XQ4X30:N3B@040:J2
B02WPTh0YX5=0:AoB`<0Xgi:00h0Y7m;0:J1C@2WPTh0Yh=?0:R4D02YQE40ZXIB0:V5D@2XQ500YX9>
0:F1C@2VPdd0YhA>0:R5C`80ZHI@00<0YhA>0:F2C02TPD/00P2XPd`00`2XPdh0Z8=?0:R2D@020:R2
D`070:R2E@2SOTT0Y7m:0:AoBP2VPD`0Yh9=0:R3CP020:V4C`<0YX9>0`2UPDd20:B0C0060:EoDP2U
Oe00YX1A0:J0C`2VPDd0Yh9=0P2WPT/20:F1A`040:F0B@2UP4/0YH1;0:F0C080YGm>00@0ZhIB0:V4
D02VPDd0Xgi:0P2RODT00`2SOTX0Y7m;0:=nBP020:=nBP<0Y7m;0P2UP4`20:F1A`040:AoB02SOTT0
XWe80:5lB080X7Y9402ONdL0102LMd<0WGQ409ehA02NNDD209mjAP80X7]700<0WGQ309iiA02PNdH0
0P2QO4L00`2PNdH0WWU409eh@`080:1kAP060:J1C@2UP4`0Xgi:0:5lB02PNdL0XGa80P2RODT00`2N
NDD0WgY60:5lB0020:9mB@060:5lB02PNdL0WgY60:=nBP2QO4P0WgY60P2NNDD01P2QO4P0Xgi:0:F0
C02RODT0XGa809mjAP@0WGQ400<0WWU509mjAP2MN4/00P2MNDT01P2NNTP0WWY609ikA@2NNd<0Wga4
09YeB080VWI600h0VgM509ahA02NNdD0X7e50:5nAP2KMd<0XWi:0:f9E@2fTUh0^9AP0;>?F`2[Qe<0
YH5=09iiA@80WgY600<0X7]70:5lB02QO4P00P2QO4P30:5mB@<0X7a80P2ONdL209ag@P0309eh@`2N
ND@0WgY50080XGa700T0XWe809ijAP2MNDD0W7Q409]g@`2LN4@0WWY60:5mB@2ROTX00P2NNd<00`2N
NdD0Wg]709mkB@020:1lC0030:1kCP2NNTX0WWY:00H0WWY:00/0WWY609eiA@2LN4@0VgM309ahA02N
NTH0XGe90:9nBP2JMT80W7Q409eiA@0209mkA`0509eiA@2LN4@0VWI209mjAP2PNdL00`2QO4P0102N
NDD0W7M309Ye@@2NNTH209eiA@0309ahA02KMd<0VWI20080VGE10`2GLcl309Ib?P80UG4m202JMcl0
0`2FLD@0UG1309=^@@02099]@00>09=^@@2EL4<0UW54099]>02DKc/0UG0l09I`?`2FL440U6i1099[
@02@JCh0TV`m09=]?P2EKd0209I`@@0609E_@02CKCh0TV`m08iY?02@Jch0TF`o0P2BKD001`2@Jch0
SVTl08iY?02<IcX0TF/l099/?@2DKSl00P2EKd000`2DKSl0TV`m095[?002099^?PH0TFdm00<0Tflo
095]?@2>JSX00P2<J3P05@2?Jc/0Tflo09Ea@@2CKcd0TVhl08m[>`2=J3/0S6Lk08aW?@2>JCl0SfU2
091_?02?KS/0Sfdm08e[?@2<JSd0RfPn08YW?@2:Icl0S6Lj08eX>`0308iY?00408aW>P2;IST0RF@g
08mY@P80SfY000<0SfXn08mZ?@2@K3`00P2@K3X808aZ?0P0S6/h0`2BKD0[ooooo`00:_ooool808UR
>@80RF<f0P2:I3L0102;ICP0S6Hi08aV>@2<IST308YT=`<0RfDh0P2<IST00`2;ICH0RV@e08US=002
08US=00308]U=P2=IcP0SVPi0080S6Hg00@0S6Hi08]T>@2:HcX0RV<l0P29HCd808iX>`0:099W?@2A
IS`0Sf@j08iS>@2=HSP0SV<i08mT>P2@IC/0TFLe099X=P<0TfTg00<0TFLe091V=02>I3800`2?I3L2
08iS=P<0SF8e00@0UV<d09AT=02EICD0U6He0P2CIcH00`2BJ3H0TVXg099Z=`02095W=@80TVPf00@0
TfTg09AZ>02EJcT0UF/i0P2EJSd01P2FJch0Uf`o09Q]@02IKT40VVm209]`@`80V6e300<0V6e209U^
@@2IKcl00P2JL3h0102JLCd0VW0n09Y`?P2JL3h209U_?@<0V6hl1P2KL4<209aaA080VFlm0`2JL3h3
09]a?`0309Y`?P2KLCl0W7900080WG=100<0W79009]a?`2JL3h00P2NM48209ec@@<0W79000<0Vg4o
09ac?`2LLcl01P2LLcl80:1b@@0809ab@02MLd40WgE30:1fA02OMD<0WWA209ec@@2LLT0809id@P06
09ab@02MLd40WWA209me@`2PMT@0XGM50P2RN4H309mf@P80WWE10`2MM40209mf@P80X7M3102QN4@0
2`2QMdD0X7I409me@`2NM480WgE30:1fA02RN4H0XgU70:5gA@2RN4H0XgU70080Y7Y800<0XgU70:9h
AP2QMdD00P2QMT`0102QMT/0XGM70:1fA02PMd420:1g?`<0XgU700@0XWQ60:5gA@2QMdD0XGM50`2P
MT@01`2QMdD0XgU70:EkB@2UNdT0Y7Y80:=iA`2RN4H00`2RNDD20:=jAP<0Y7]700P0YWQ70:EgAP2Q
MD@0X7I409mgA02ONTH0XGa80:5mB@80YGa80P2VODT0102WOTX0Z7m;0:QoB`2XOd/20:YmAP040:Yl
B02ZO4X0ZWa:0:YlB`80ZW]=202WOTX80:AoB`P0YWa:402XOd/30:ImB@80Ygi:0`2XOd/20:Z1B@04
0:Z1B`2ZPDd0ZX5=0:Z0CP80ZX1@0P2YOdd20:Z0CP80Zh5?0P2/PU020:V4D080Z8=?0P2WPTh20:J1
C@T0[8=?00H0Zh9>0:Z1C@2YP4`0ZH1<0:Z1C@2[PThA0:b3C`T0[89@202]Pe480:Z5D@030:j4DP2]
Pe40Zh5?0080ZX1>00<0Zh5?0:f3D@2^Q580202[QU820:b7D`80ZhIB0P2ZQE420:V4D0030:Z5D@2[
QU80[HQD0080[XUE00<0[HQD0:^6DP2ZQE400P2ZQE430:^6DP<0[8MC0`2]R5@30:j9E@80[hYF202b
RED20:n:EP<0[XUE4`2]R5@30;:=F@D0/HaH0P2cSUX20;:=F@80/HaH0P2`ReL80;6<F0P0/H]L102a
S5P40;:=F@80/XmG1P2aSUH90;>>FP<0/XeI0`2cSUX20;B?F`<0/XeI0`2cSUX20;B?F`030;R=H02f
Reh0]HYM00<0/hQK00/0]8UL0;F:G@2cSEh0]Y1Q0;RBH`2fT640/XaM0;2:F`2bS5d0]HmP0;Z>H@02
0;V>H@030;R?H@2fT640]I5Q0080/i5Q202dT6000`2dSe/0]I1L0;JAG@020;JAG@030;B?F`2bSET0
/8]G00P0]I1I202eSf080;B?F`<0/XeI0`2cSUX20;B?F`80/i1H00<0/i1J0;>?F`2cSed00P2cSel0
0`2cSV40]8mK0;B?F`060;B?F`030;:=F@2cSUX0]I1L0080]Y5M00<0]I1L0;>>FP2bSET0202fT642
0;>>FP80]8mK0P2eT5`20;JAG@P0]8mK202bSET20;F@G080]Y5M00@0]I1L0;>>FP2aS5P0/8]G2@2d
T6001P2`S5`0/HeM0;:>GP2cSel0]91P0;FAH@X0]Y9R202eT5`30;B?F`030;F@G02fTEd0]Y5M0080
]i9N0P2hTV<20;NAHP80]Y1Q0P2eSf080;>?G`080;6<F02bSET0]8iM0;J@H@2hTVD0^95V0;N@I@2f
SfH80;F?H0P0]8mK0`2eTF430;B@H080/hmO202gTF840;JBGP@0]I5M202fTV800`2cSel0]91P0;JB
HP020;NCH`030;JBHP2dT600/hmO00<0/hmO00<0]91P0;FAH@2eTF400P2fTV820;RDI080]i=S0`2f
TV800`2eTF40]i=S0;NCH`020;JBHP0:0;FAH@2dT600]91P0;B@H02bSeT0/XiJ0;>?F`2cSed0/hmO
0;B?HP80]8mS2@2eSf030;:<G@030;>=GP2dSUl0]8iO0080]HmP202bSUh90;:>FP<0/hmK0P2dT5`2
0;FAG@030;>?G`2bSUh0/XiN00D0/XiN0P2bSUX20;6=F@050;:>FP2dT5`0]Y9N0;NCG`2fTV800P2e
TF420;B@H080/hmO00<0/XiN0;>?G`2cSel01P2cSel80;6<G`80/XiN0P2aSEd01@2bSUh0]91P0;JB
HP2gTf<0]Y1Q0080]HmP0P2dSUl20;>=GP030;:<G@2^RUH0/hmK0080]i=O00@0/hmK0;2<F02aSET0
]91L2P2dT6030;>?G`<0/XiN00<0]I5M0;B@G02bSUX00`2`S5P20;:>FP030;2<G02aSEd0/XiN0080
]91P00<0/XiN0;6=G@2`S5`0202aSEd<0;6=F@<0/XiJ0P2cSe/20;FAH@060;B@H02cSel0/XiN0;6=
G@2`S5`0[h]K202dSe/80;6<H0080;2:G@2aRe`0/XaM0;>=G02cSUX0/XeH0;6<E@2`Re@20:n:EP80
/8]G0P2aS5P20;:=F@80/hmO0P2bSUh30;6=G@030;2<G02aRe`0/H]L0080/H]L102bS5d20;>?F`0>
0;:>FP2aSET0/8aH0:n;E`2^RUH0[HUE0;:?E`2aSUH0/8eG0:n;E`2`S5X0/XiN0;B@H02eT6<30;2<
F0<0[h]G0P2^RUH80;6=F@80[hYF0`2`ReL30;6<F0@0/HeM0P2`S5`20:n;FaP0[HUE00P0[8MC0:^6
DP2ZQE40ZHA@0:Z5D@2[QU80[HQD0:j9E@P0[8QD2@2]RET20:b7D`80[HQD00L0[XUE0:n:EP2_RUH0
[hYF0:j9E@2_RUH0/HaH0080/hiJ00<0/XeI0;6<F02`ReL0202_RUD80:^6C`@0ZhIB102/Qe<20:V5
D@<0ZXIB0`2[Qe<50:b7D`<0[HQD00<0ZXEI0:^6FP2/Qe/00P2/Qe/0102ZQET0Z8=G0:J1E@2ZQUH6
0:V5E@030:R4E02[QU80ZhIB00H0ZhIB0P2XPd`00`2XPdh0ZHA@0:V3DP020:Z4E@030:Z4E`2YQ500
ZHA@00H0ZHA@00P0Z8=?0:V4D02ZQE40ZhIB0:Z5D@2YQ500Yh9>0:J1C@80Yh=C0P2XQ5@0502YQED0
ZXIF0:Z6EP2ZQUH0ZXAG0:Z4E@2YPe@0ZH=B0:R3C`2XPdh0Z8=<0:N2B`2YPeH0ZH=D0:V3DP2YQ500
ZHA=0:V5B`2YQDT0ZHE70`2YQ4d30:Z5CP80ZhI?0P2YQD/20:R4BP@0Yh=900<0Yh9>0:J1C@2TOd/0
0`2SOTX03P2TOd/0YX5=0:N2CP2WPdl0Z8A@0:V5D@2ZQU80ZHEA0:R4D02VPTh0YH5=0:F2C02VPdd0
YhA>0P2XQDl00`2VPdd0Y85;0:>0BP020:N2B`030:N2C@2WPTh0Yh5@0080Yh5B00L0Yh5D0:=nB@2T
OdX0YH1;0:J1C02WPTd0Z8=>0080ZHA?0`2VPTh30:F1C@80Y81<00H0YGmB0:EoD02VP540YX1?0:J1
C@2WPTd20:N2B`80YH5700@0YH190:F0B`2UP4/0YH1<0P2UOdh0102YQ500Z8=?0:F0C02TOd/20:=n
BP030:AoB`2UP4`0Xgi:0080Xgi:0`2TOd/20:F0C080YH5700@0Y7m80:=nB@2RODP0XGa80P2PNTT@
09mkA`0309ehA02NNDD0WWU50080WgY60P2PNdL0102QO4P0WGQ309iiA02PNdH20:5lA`030:1kAP2N
ND@0WGQ300P0X7]600@0YX5=0:AoB`2RODT0XGa80P2PNdL01@2QO4P0XWe909mjAP2PNdL0XGa80080
XWe900<0XGa809mjAP2NNDD00P2QO4P30:1kA`080:5lB02SOTX0Xgi:0:9mB@2QO4P0WgY609ehA02L
Md<209ehA00J09iiA@2ONTH0W7M:09ahB02MNDT0WGU709ijAP2OO4H0Wga40:1mA@2LMdX0VgM709Yf
AP2IMD<0VgM309ejA02PODD0XWm709eiA@2PO4P0YH5=0:R4D02ZQU80ZHEA0:N3C`2UPDd309mjAP80
X7]70`2QO4P30:5mB@80X7a80`2ONdL209ag@P0809eh@`2NND@0WgY50:1kAP2QO4L0XWe809mkA`2N
NTH309ahA00309eiA@2ONdL0XGe90080WW]300H0WW]509mkA`2ONdT0Wg];0:1lC02PNdh809ijBP80
WWY600T0W7Q409]g@`2LN4@0WGU509mkA`2PO4P0VgM309ahA02MNDD00P2NNTH02@2MNDD0W7Q409]g
@`2KMT80W7M309iiA@2PNdL0XGa80:1kA`0209mjAP80WGU50P2LN4@0102KMd<0VWI209Ue@@2IMD43
09Mc?`<0UW8n0P2ELCd809Md?00309IaA02EL4<0Tfi10080TVe000h0Tfi109E`@`2FLD@0Tfhi09A_
>`2EL3`0UW0o09E_@02DKT40TV]0095Z?`2BK3d0Tfdn09A^?`80UFm000T0U6ho09=]?P2BK3d0T6/n
095/?`2BKD00Tfi1099]@02AK3l00P2?JSd0102>JC`0TV`m09=]?P2EKd0209I`@@0309E_@02CKCh0
TV`m00D0TFdm102BKSh0302@K3`0SVXj08aX>02<J3P0Sf/k099^?P2ELD40Tflm099^?02?Jc/0SFPk
08aW>`80SFPn0180SVQ1091_?02?KS/0SV`l08e[?@2<JSd0RfPn08YW?@2:Icl0S6Lj08eX>`2>JC`0
SfXm08iY?02=J3/0RfHi08UT=`2=Id0208iY?`0308iY?@2>JC`0Sf/k0080Sf/i202<JS`308a[>0@0
SF`i00@0SVdj099]@02BKD00TVe0:oooool002[ooooo2028HCP308YT=`<0RfDh102<IST308]U>0<0
RV@g0P2;ICH308US=00308]U=P2<ISL0SVPi0080S6Hg00@0RfDh08]T>@2;I3/0RV<l0P2:HSh808iX
>`0309=X?@2BIc`0TFHk00<0Sf@i0P2@ICX0202@IS@0TFLe099X=P2CJCL0TVPf095W=@2?IC<0SV@b
0P2=HSD208iS=P@0Sf@g00@0UV<d09AT=02EICD0U6He0P2CIcH00`2BJ3H0TVXg099Z=`02095W=@03
099X=P2CJCL0U6Xh0080UF/i00L0UV`j09EZ?@2FJch0UV/n09M/?`2HKD00VFi10080VVm20P2HKD<0
0`2HKD80VFi109U_?`0209Y`?P0409Ya?@2JL3h0VW0n09Y`?P80VFlm0`2HKS`409]`@`@0VVm20P2I
Kcd309Y`?P<0Vg4o00<0VW0n09]a?`2LLT000P2MLd400`2LLT00Vg4o09Y`?P0309ec@@80W7900`2K
LCl809ac?`P0WW9100P0WG=109id@P2OMD<0WgE309id@P2LLT00VW0n09U_?@P0WWA20P2MLd400`2N
M480WgE30:1fA0020:5gA@040:9hAP2OMT80WgI209mf@P80WWE10`2MM40309mf@P80X7M30`2QN4@0
0`2QMdD0X7I409me@`0209id@P030:1fA02RN4H0XgU70080XGM500@0XWQ60:=iA`2SNDL0XWQ60P2Q
MdD20:1eBP040:1eB02PMTH0XGM50:5hA080XGQ20P2SNDL30:9hAPH0XGM500<0XgU70:AjB02UNdT0
0P2TNTP0102SNDL0Y7]70:AkA`2TNdL20:=jAP<0XWU50P2UMdH01P2RMTD0XGM50:1hA@2ONTH0XGa8
0:5mB@<0YWe90`2WOTX20:QoB`80Z7e600@0Z7e80:QmBP2XODX0Z7a;0P2XO4d80:QoB`P0Xgi:202U
NdT@0:QoB`80YWe90P2WOTX30:QoB`040:V0C02ZPDT0ZX590:Z1B`80ZX5=00@0ZX1>0:Z0D02ZP500
ZH1<0`2ZPDd30:^2CP030:b3C`2YQ500ZHA@0080Z8=?0P2WPTh20:J1C@P0Zh9>00<0[8=?0:^2CP2Z
PDd00P2YP4`00`2ZPDd0Zh9>0:b3C`0@0:^2CQ40[89@202ZQE400`2^Q580[H=A0:b2D0020:^1C`03
0:b2D02]Pe40[XAB00/0ZhIB0P2/Qe<30:f8E080ZhIB00@0[8MC0:f8E02]R5@0[8MC0P2[QU820:Z5
D@<0ZhIB0`2/Qe<30:f8E0<0[XUE0P2_RUH80;68E080[hYF0`2^REDC0:f8E0P0/HaH00@0/hiJ0;:=
F@2bSET0/XeI0`2aS5P00`2`ReL0/XeI0;:=F@060;:=F@P0/H]L102bSET40;6<F0P0/8eG2@2cSUX3
0;:=F@<0/hiJ0P2dSe/30;:=F@<0/hiJ0P2dSe/04@2hSF00]haO0;F:G@2dRE`0/hQK0;B9G02eRUd0
]X]N0;>=GP2fT640^99S0;J@H@2bS5d0/8YK0;:<G@2eSf00^HeP0080^8eP00D0]hiP0;F?H02dT600
/Y1P0;>AH@080;B@H080]8mK0`2eT5`00`2dSe/0/hiJ0;:=F@080;F@F`P0]8iO202cSUX30;:=F@<0
/hiJ0P2dSe/20;>@F0030;>@FP2cSe/0/hmM0080/hmO00<0/hiQ0;B?F`2dSe/01P2dSe/00`2bSET0
/hiJ0;F@G0020;JAG@030;F@G02cSUX0/XeI00P0]Y1Q0`2eT5`20;JAG@<0]i9N202dSe/90;:=F@07
0;>>FP2eT5`0]Y5M0;JAG@2eT5`0/hiJ0;:=F@090;B@H0060;6=G@2bSUh0/XiN0;>?G`2dT600]I5Q
2P2fTV880;JAG@80]8mK0`2eT5`30;JAG@80^99S0P2gTF820;J@H@80]HmP202cSel01P2aS5L0/hiJ
0;F@G02gTF00^99S0;NAI080]XmT202eSf080;B?F`80/hmO0`2dT6030;FAH@P0]i5R00D0^9AP0;NC
G`2gTel0]Y9N0;FAG@020;B@G0030;>?F`2hU6@0^9AT00H0^9AT0P2dT600102eTF40]Y9R0;JBHP2e
TF420;B@H080/hmO0`2dT6030;FAH@<0]i=S0P2fTV830;FAH@<0]Y9R0P2eTF430;B@H0060;:?F@2c
Se/0/hmK0;>?G@2dT600]8mR0P2eT6@90;F?H0<0/8YK0`2aRe`20;:<G@P0/XiN202dT5`0102`S5P0
/HeI0;6=F@2aSET20;:>FP80/hmK0P2fTV80102eTF40]91P0;>?G`2cSel20;:>GP030;FAG@2dT5`0
/XiJ0080/HeI00<0/XiJ0;B@G02eTEd00P2eTF420;B@H0@0/hmO202bSUh80;>>H@080;:>GP2aSEd0
/HeM0;6=G@2bSUh0]91P0;JBHP2gTf<30;F?H080]8iO0`2cSEh01@2_ReL0/XiJ0;FAG@2eTEd0/XiJ
0080/HeI00<0/hmK0;B@H02dT6001`2dT6030;>?G`80/XiN0P2aSEd01@2dT5`0/hmK0;:>FP2aSET0
/8aH0080/HeI00@0/XiJ0;2<G02aSEd0/XiN0P2dT6000`2bSUh0/HeM0;2<G0080;6=G@`0/HeI0`2b
SUX20;>?F`80]Y9R00<0]I5Q0;B@H02cSel00P2bSUh00`2aSEd0/XeI0;:=F@060;:=F@P0/HaO00P0
/8YM0;6;G02bS5d0/heL0;>>FP2bSEP0/HaE0;2;E0<0/8]G0`2aS5P20;:=F@<0/XiN0P2aSEd30;2<
G0@0/XaM102aRe`20;:>FP040;6=F@2`S5P0[h]G0:n;E`80[XYF0P2_S5@01P2_S5H0[h]G0;6=F`2c
Sel0]I5Q0;JAI0<0/8aH0`2_ReL20:j:EPP0/HeI0P2_RUH30;2;E`<0/HaH0`2aSEd20;2<G0<0[h]K
402]RED30:n;E`030:j:EP2]RED0[8QD0080ZhMC00<0[hYF0:f8E02/Qe<00P2ZQE400`2[QU80[8MC
0:f8E0080:b8E0T0[HUI0`2]R5@30:j9E@80[hYF00<0[HQD0:n:EP2`ReL00`2bSET00`2aS5P0/8]G
0:f8D`070:f8D`P0ZhIA0P2]R5@30:b7D`<0ZhIB0P2YQE430:Z6DP<0ZhMC202/Qe<20:Z5F0<0ZhII
00<0ZXEH0:R3EP2WPUD00P2XQ5@40:V5E@80ZXIF202[QU820:R3C0030:V4C`2YQ500ZXAC0080ZXAE
00<0ZhEH0:V4D02YQ500202YQ5030:Z5D@040:V4D02WPTh0YX5=0:N3D`<0Z8AD0`2YQED01`2ZQUH0
ZH=F0:V3E02YPe@0Z89A0:R3C`2WPTd00P2WPT/0102XPU<0Z89A0:R3C`2XPdl20:R3C0040:R4BP2X
Q4P0Z8=>0:R3CP80ZHA?0`2ZQE00102[QU40ZHA=0:V4C@2YQ4d20:R3C0<0Yh9;00<0Yh9>0:J1C@2U
P4`00`2TOd/04`2UP4`0YX5=0:N2CP2WPdl0Z8A@0:V5D@2ZQU80ZHEA0:R4D02VPTh0YH5=0:B1B`2U
PT`0YX==0:N4CP2VPdd0YH9<0:>0BP2QOTP00P2VPDX00`2VPD`0YX5=0:J0C`020:J0D@060:J0D`2T
OdX0Y7m:0:F0B`2VPD`0Yh9=0P2XPdh0102YQ4l0YX9>0:J2CP2VPTh30:F1C@80Y81<00H0YGmB0:Eo
D02VP540YX1?0:J1C@2WPTd20:N2B`80YH5700@0YH190:F0B`2UP4/0YH1<0P2UOdh00`2WPTh0YX5=
0:F0C0030:AoB`030:F0C02VPDd0Xgi:0080Xgi:0`2TOd/20:F0C080YH5700@0Y7m80:=nB@2RODP0
XGa80P2PNTT@09mkA`80WgY60`2PNdL30:5lB00309eh@`2NND@0WgY50080X7]600<0WgY509iiA02M
N4<0202PNdH02@2TOd/0Xgi:0:5lB02PNdL0WgY60:1kA`2QO4P0XWe90:5lB0020:9mB@080:=nBP2R
ODT0X7]709iiA@2MN4@0WWU509mjAP2QO4P30:9mB@<0XGa800@0X7]709iiA@2MN4@0W7M30P2MN4@0
202NNDD0WgY609YeB02KMdL0W7Q809eiA`2NNTH0X7e70P2QOTH0402ONTd0W7Q809UeA@2HM480VGE1
09ai@`2PODD0Xh180:1lB02ONdL0W7Q409]g@`2LN4@0WWY60:5mB@2SOd/409mjAP80X7]700@0XGa8
0:9mB@2QODT0XGe90P2PO4P309mkA`0709ijAP2LMd80WGQ309eh@`2NND@0WgY50:1kAP020:5lA`05
0:1lB02ONdL0WWY609eiA@2LN4@00P2MNDD01P2NNTH0WGY209ej@P2NNdD0WWY609mkB@80Wg];00<0
X7]>09ijBP2NNTX01P2NNTX209mkA`0409eiA@2LN4@0W7Q409ahA080WGU500<0VgM309ahA02MNDD0
0P2NNTH0202MNDD0W7Q409]g@`2HLcl0VGA009ag@`2NNDD0XGa80`2RODT209eiA@0309ahA02KMd<0
VWI20080VGE100@0V7A009Mc?`2GLcl0Ug<o0`2FLSh209Ea?@P0U74k00<0UW5409E`@`2DKd800P2C
KT40102DKd80UG1309IaA02DKcX209E`?00809I`?`2EKd00U6i109=/@@2BJd00TF/l099/?@2CKCh2
09A^?`0309=]?P2BK3d0TF/l0080Tfi10`2DKd801`2BKD00TF`o095/?`2@Jch0U6ho09E_@02FL440
0P2GLD80102FL440UFm009A^?`2?Jc/2091/?003095]?@2BKSh0TVhn0080Tflo00d0TFdm091/?02=
JCT0S6Ph08eY>@2?Jc/0TVhn09A`@02BKS`0TFdk091/?02>JC`0SFPl0080SFPn00H0SVQ108m^>`2?
KS/0SV`l08e[?@2<JSd208]X?P0:08YW?`2<IcX0SFPk08iY?02?JSd0SVTl08eX>`2;IST0RVDh08]U
?P80S6Lm00<0S6Lk08eX>`2>JSX00P2>JSP808aZ?0<0S6Xj00D0SF/k08i/?02?KCd0Sfdm091^?P03
095/?b_ooooo000Zooooo`P0QUlf0P2:I3L608]U>080SFLj00<0S6Hi08]U>02:I3L00P29HcH01028
HSD0S6Hg08]U=P2:I3D208US=00308YT=@2<ISL0SFLh0080RfDf00@0RfDh08]T>@2;I3/0Rf@m0P2:
HSh808iX>`0409=X>`2BIcX0TVLj095V>@@0T6Dh00P0T6Hf095W=`2BJ3P0TfTi099X>02AIcL0SfDe
08eS<`80S64d00X0SF8e08iS=P2?I3L0T6Dh095V>@2BIcX0UV<d09AT=02EICD0U6He0P2CIcH0102B
J3H0TVXg099Z=`2AIcD2099X=P0309=Y=`2DJSP0UF/i0080UV`j0P2FJch209M/?`0409Q]@02IKT40
VFi109U^@@80V6e300<0V6e209U^@@2IKcl00P2JL3h0102JLCd0VW0n09Y`?P2JL3h209U_?@<0V6hl
0P2KL4<209Y_@P80VFi10P2HKD0209U_?@<0VW0n1@2KLCl409ab@080Vg4o0P2MLd4309ab@0<0Vg4o
202LLcl809ec@`80WWA200H0WgE309id@P2MLd40Vg4o09Q^?02GKC/;09id@P0309me@`2PMT@0X7I4
0080XGM50`2OMT8209ie@@<0WGA00P2NMD4209mf@P80X7M30P2QN4@0202PMT@0WgE309id@P2MLd40
WWA209me@`2QMdD0XgU7202QMdD40:1fAP<0XGM500<0XGQ40:9hAP2RN4H01@2RN4H30:5gA@80XWQ6
00<0XgU70:AjB02TNTP00P2TNTP20:ElB0040:AkA`2SNTH0XgY60:9iA@80XGQ40P2UMdH01P2SMdH0
XWQ60:9jA`2PNdL0XGa80:1lB080YWe91P2WOTX20:MnAP040:MnB02WOTX0Ygi:0:MmB`80Yge=202Y
P4`80:=nBPP0Y7Y80P2WOTX40:QoB`80ZH1<202XOd/30:MnBP<0Z7m;0P2YP4`20:Z1B@040:Z1B`2Z
PDd0ZX5=0:Z0CP80ZX1@102ZPD/40:^2C080ZHA@0P2XPdl20:N2CP80YX5=2P2[PTh40:Z1CA80Zh9>
4@2/PU080:Z5D@<0[H=A0P2/PU030:f3D@<0ZhIB102ZQE401`2YQ500ZXEA0:Z5D@2[QU80[8MC0:j9
E@2_RUH00P2`ReL20:^6DP@0[8MC0P2[QU820:Z5D@<0ZhIB0`2/Qe<30:f8E0<0[XUE0P2_RUH80;68
E080[hYF0`2^RED30:f8E100[XUE102`ReL40;6<F0@0/XeI102aS5P80;>>FPP0/H]L00D0]8mK0;>>
FP2cSUX0/XeI0;6<F0020;2;E`040:n:EP2^RUH0[XYF0:j:EP@0[h]G00<0/8aH0;>>FP2cSUX01`2c
SUX30;:=F@<0/hiJ0P2dSe/30;:<F`<0/heL0P2dSUd04@2hSf40]XeO0;B;G@2cRU`0/XUK0;>:G02d
Red0]HaN0;>=GP2fT640^99S0;J@H@2bS5d0/8YK0;:<G@2eSf00^8aO0080]haO00<0]XeO0;F?H02d
T6000P2bT6080;B@H0<0]8mK00<0]I1L0;B?F`2dSe/00P2cSUX80;B?F`P0/heN202cSUX30;:=F@<0
/hiJ0P2dSe/20;>@F0030;>@FP2cSe/0/hmM0080/hmO00<0/hiQ0;B?F`2dSe/01P2dSe/00`2bSET0
/hiJ0;F@G0020;JAG@030;F@G02cSUX0/XeI00P0]Y1Q202gTUh80;B?F`P0/XeI00@0/8]G0;:=F@2d
Se/0]I1L0P2fTEd00`2eT5`0]8mK0;B@GP080;B@GP030;:>GP2cSel0/hmO0080]91P0P2eTF490;JB
HPP0]i9N1P2eT5`20;JAG@80^99S0P2gTF820;J@H@80]HmP202cSel0202bSEH0/hiI0;F@F`2gTUh0
]i5P0;NAHP2fT6<0]HmR202eSf080;B?F`80/XiN00<0/hmO0;B@H02eTF400P2fTV800`2gTf<0]i5R
0;NAHP060;NAHP080;VEH@2hU600]i=O0;JBGP2eTEd0]91L0;>?F`2bSUX80;VEI@80]91P102eTF48
0;B@H080]I5Q0P2gTf<30;JBHPL0]I5Q102dT6001P2cT5X0/hmK0;>?F`2dT5h0]91P0;F@H`80]I1T
2@2eSf060;:<F`80/heL202cSel80;FAG@<0[h]G0P2`S5P30;6=F@80^9AT00X0]i=S0;FAH@2dT600
/hmO0;:>GP2aSEd0]i=O0;FAG@2cSe/0/XiJ0P2aSET0102bSUX0/hmK0;B@H02dT6060;>?G`P0/XiN
202dSf830;6=G@050;:>GP2cSel0]91P0;FAH@2fTV80202dSUl01P2aSE/0/XiL0;>?G@2cSed0/XiL
0;6=F`80/XiL2`2cSel20;:>GP<0/HeM0P2cSe/20;:>FP@0/HeI00<0/8aL0;6=G@2bSUh00P2dT600
0`2bSUh0/HeM0;2<G0080;6=G@`0/HeI0`2bSUX20;>?F`<0]Y9R00<0]I5Q0;B@H02dT6000P2cSel8
0;6<F0P0/HeM00P0/8YM0;6;G02bS5d0/heL0;>>FP2bSEP0/HaE0;2;E0H0/HaH0P2bSET20;:>GP<0
/HeM0`2`S5`40;:<G@@0/H]L0P2aSET20;2<F080[h]G0P2^RUH20:f:DP060:j;E@2_ReL0/HeK0;>?
G`2eTF40]Y5T0`2`S5P30:n;E`80[XYF202aSET20:n:EP<0/8]G0`2aS5P20;6=G@80/8aL0P2_Re/2
0:j:FPP0[XYF202]RED20;6=F@0:0;2<F02^RUH0[HUE0:b8E02[Qe<0ZXIB0;2;E`2_RUH0[HQD0:^6
DP80ZXEA00<0ZhIB0:b7D`2/R5@01`2/R5@90:f9E`80[HQD1P2^RED0202/Qe<0[XUE0;2;E`2aS5P0
/XeI0;6<F02`ReL0[hYF202/Qe880:^6DP060:n:EP2^RED0[XUE0:f8E02/Qe<0ZhIB0P2ZQE420:V5
D@<0ZXIB0`2[Qe<40:b7D`@0ZhIB0P2YQED30:Z6EP80ZHEE102XQ5@20:V5E@<0ZXIF202ZQE420:V4
C@060:V4C`2ZQE40ZXAC0:Z4E@2[QEH0ZhEH2`2ZQE420:V4D080Z8=?00<0Yh9>0:R4E02XQ5@01P2X
Q5@01P2YPeH0ZH=D0:R2D`2XPU40Z8=?0:N2C@80Yh9;0`2XPdl20:R3CP<0Z8=<0`2XPdl20:V4D0<0
ZXEA0P2ZQE020:V4C`80Z8=>0P2WPTd00`2XPdl0Yh9>0:F0C0030:AoB`0C0:F0C02WPTh0Z8=?0:N3
C`2XQ500ZHEA0:Z6DP2YQE40Z8A@0:J2CP2UPDd0Xh1:0:B1B`2UPT`0YX==0:F2C02TPD/0XWm90:1m
A`020:F0B@030:F0B`2UP4`0YGm>0080YGm@00D0YGmB0:F0B`2UP4/0YH1;0:J1C0020:N2C@80Z8=>
0`2VPTh30:F1C@80Y81<00H0YGmB0:EoD02VP540YX1?0:J1C@2WPTd20:N2B`80YH5700@0YH190:F0
B`2UP4/0YH1<0P2UOdh40:AoB`80YH1<0P2VPDd30:=nBP<0Y7m;0P2UP4`20:F1A`040:AoB02SOTT0
XWe80:5lB080X7Y9402ONdL20:1kA`H0XGa800<0WWU409mjA@2ONTD0102ONTD00`2NND@0X7]60:1k
AP060:1kAP030:=nBP2RODT0X7]70080WgY600<0X7]70:5lB02RODT00P2RODT20:=nBP070:9mB@2P
NdL0WWU509ehA02LMd<0WWU50:5lB0020:=nBP060:9mB@2PNdL0WWU50:1kA`2ONTH0WGQ40P2LMd<2
09ehA00E09iiA@2ONTH0VWE809YfAP2LN4P0WGU709mkA`2PODL0XGi60:9oA`2PNdh0WGU909UeA@2G
Ld40V7A009]h@P2PODD0Xh180:1lB02NNTH0VgM30080V7A000<0VWI209eiA@2ONdL00P2PNdL01P2O
NTH0WWU509mjAP2PNdL0XWe90:=nBP<0X7a80`2ONdL209ijAP80WGQ30P2NND@0102ONTD0X7]60:1k
AP2PNdH20:1lB00309mkA`2NNTH0WGU500<0W7Q40P2MNT800`2MNT@0WWY609ijB00209mkB`0309mj
C@2NNTX0WWY:00H0WWY:0P2ONdL00`2NNTH0WGU509ahA00309]g@`80W7Q4102MNDD209ahA00609Ye
@@2KMT80W7M309iiA@2ONTH0X7]70P2QO4P01P2MNDD0W7Q409ahA02KMd<0VWI209Ue@@80V7A00`2G
Lcl309Ib?P80UG4m202FLSh00`2GLTD0UG1309A_@P0209=^@@0409A_@P2EL4<0Ug9509E`>`80UG0l
00<0UFln09E_@02DKT400P2CK4400`2AJc`0TV`m09=]?P0209A^?`0309=]?P2BK3d0TF/l00@0UG13
0P2DKd8209=^@@03099]@02FL440UW1100@0Ug520P2FL44208m[>`03091/?02AKCd0TVhn0080Tflo
00<0U710091/?02?Jc/00`2=JCT0202?Jc/0TFdm099^?P2BKS`0TFdk091/?02?JSd0SVTm0P2=J3h0
2`2=Id00SVdj08i]>P2>K3`0SF/m08aZ?@2<JCl0RfPn08]X@02=J3/0SVTl00<0SfXm00/0SFPk08]V
>@2:ICP0RV@m08YU>`2;IS`0RfHj08aW>P2=JCT0SFTg08iZ>00808e[?@0608]Y>`2<JS`0S6Xl08e[
?@2>K3h0Sfdo0P2@KT0308mZ?B_ooooo000Zooooo`P0QUlf1P2;ICP208YT=`80SFLj00<0S6Hi08]U
>02:I3L00P29HcH01028HSD0SFLh08aV=`2:I3D208US=00308YT=@2;ICH0S6Hg0080RV@e00@0RfDh
08]T>@2;I3/0Rf@m0P2;Hcl808eW>PD0TFLg00H0T6Hf08mU=@2?ICD0Sf@g091U>02AIST2099W>P09
091U>02>HcH0SF8e08]P<`2<HC@0SF8e08iS=P2@ICP0TFHi0080TfPk00@0UV<d09AT=02EICD0U6He
0P2CIcH00`2BJ3H0TVXg099Z=`02099X=P0309=Y=`2DJSP0UF/i0080UV`j00@0Ufdk09M/?`2GK3l0
Uf`o102HKD001P2IKT40V6e309Q]@`2HKD80VFi109U_?`80VW0n00@0VW4m09Y`?P2JL3h0VW0n0P2I
Kcd309Q^?0@0VFi1102HKD0209U_?@<0VW0n0`2KLCl209ab@0@0Vg4o1@2LLT0309]a?`80VW0n202L
Lcl809acA@0809id@P2OMD<0WgE309me@`2NM480Vg4o09U_?@2GKC/909id@P@0WgE30`2PMT@309mf
@P80WWE10`2MM40309ie@@80WgI20`2PMd<00`2PMT@0WgE309id@P0209ec@@0309me@`2QMdD0XWQ6
00P0X7I400@0WgI209me@`2PMT@0X7I40P2QMdL20:9hB080XGM52`2RN4H0102SNDL0Y7Y80:AjB02U
NdT20:ElB0040:AkA`2SNTH0XgY60:9iA@80XGQ40P2UMdH00`2TN4L0XgU70:=kB0020:5lB0030:1l
B02WOTX0Ygi:00@0Ygi:0P2VODT20:IoAP040:IoB02VOTX0YWi:0:InB`80YWi=202XOd/80:9mB@P0
Y7Y800<0YWe90:MnBP2WOTX00P2XOd/20:V0C0030:Z1C@2XOd/0Z7m;00H0Z7m;0P2WOTX30:QoB`<0
ZH1<0P2YP4P0102YP4X0ZH1<0:V0C02YOdd20:UoC`@0Zh9:102ZPDT20:V4D080Z8=?0P2WPTh20:J1
C@X0ZX5=102[PThB0:Z1CA40[89@202ZQE430:f3D@80[XAB0`2]Pe430:^6DP030:Z5D@2YQ500ZHA@
0080Z8=?00P0ZHA@0:Z5D@2[QU80[8MC0:j9E@2_RUH0/8]G0;6<F0P0ZhIB0P2ZQE430:^6DP<0[8MC
0`2]R5@30:j9E@80[hYF202aR5@20:n:EP<0[XUE0`2]R5@A0:j9E@80[hYF0P2`ReL20;6<F0030;:=
F@2aS5P0/HaH0080/HaH102bSET80;>>FPP0/8YK00D0]8mK0;>>FP2cSUX0/XeI0;6<F0020;2;E`03
0:n:EP2]REL0[HUG0080[XYH00@0[h]I0;2<FP2`S5X0/8aJ2@2cSUX30;:=F@<0/hiJ0P2dSe/30;:<
G@<0/heN0P2dSUl00`2fT640]HmP0;>=GP020;6;G00A0;:<G@2cSEh0]8iO0;>=GP2fT640^99S0;J@
H@2bS5d0/8YK0;:<G@2eSf00]XYM0;F:G@2fReh0]HaN0;B>G`2cSel00P2bT6080;B@H0<0]8mK00<0
/hiJ0;B?F`2dSe/00P2eT5`80;B>G@P0/XaM202cSUX30;:=F@<0/hiJ0P2dSe/20;>@F0030;>@FP2c
Se/0/hmM0080/hmO00<0/hiQ0;B?F`2dSe/01P2dSe/00`2bSET0/hiJ0;F@G0020;JAG@030;F@G02c
SUX0/XeI00P0]HmP202gTUh80;B?F`P0/XeI00@0/8]G0;6<F02cSUX0]I1L0P2fTEd20;F@G0T0]91L
102dT6040;FAH@P0]Y9R202gTUh20;JAG@H0]I1L0P2hTV<20;NAHP80]Y1Q0P2eSf080;>?G`080;>?
E@2dSeP0]Y5L0;NBG@2gTUh0]Y1O0;F?H02dSUl80;F?H0P0]8mK0P2bSUh00`2cSel0]91P0;FAH@02
0;JBHP030;NCH`2gTF80]i5R00H0]i5R00P0^IEQ0;RDH02gTel0]Y9N0;FAG@2dT5`0/hmK0;:>FPP0
^IEU202dT6020;FAH@H0]91P0`2fTV830;FAH@X0]91P00H0/i1J0;>?F`2dT5`0]91N0;FAH@2eT6<2
0;JAI@T0]HmP1P2fTEd20;F@G0P0/hmO202eTEd40:n;E`80/8aH0P2aSET20;RDI00:0;NCH`2eTF40
]91P0;>?G`2bSUh0/HeM0;NCG`2fTUh0]91L0;:>FP80/HeI0P2bSUX20;:>GPH0/hmO202bSUh80;B?
HP050;2<G02aSEd0/XiN0;>?G`2dT6000`2eTF480;B>G`040;>?G`2bSUh0/8aL0;6=G@<0/XiN00<0
/HeM0;>?G`2cSel0202cSel20;:>GP80/HeM0P2`S5`30;>?F`80/XiJ0P2aSET0102`S5P0/8aL0;6=
G@2bSUh20;B@H0030;:>GP2aSEd0/8aL00P0/HeM302aSET30;:>FP80/hmK00<0]Y9R0;FAH@2eTF40
0P2eTF430;B@H0P0/HaH202aSE/0202`RUd0/H]L0;:<G@2cSE`0/hiJ0;:=F02aS5D0/8]D1P2bSET2
0;6<F0<0/HeM0`2`S5`20:n;F`80/heN0P2bS5d20;6;G080/8YK0P2`S5P40:n;E`80[XYF00P0ZhQ@
0:b9D@2^ReD0/8aH0;:>G02cSel0]91P0;B?HP<0/8aH0`2_ReL20:j:EPP0/HeI0P2_RUH30;2;E`<0
/HaH0`2`S5`20:n;F`<0[XYJ202^RUH80:f9E@060;:>FP2aSET0/8aH0:n;E`2^RUH0[8QD0P2[Qe<0
0`2aS5P0[hYF0:f8E0030:^6DP80[8MC202/R5@90:f9E@H0[XUE0P2]R5@0202/Qe<0[HQD0:n:EP2`
ReL0/HaH0;2;E`2_RUH0[XUE202/Qe880:^5E080[hYF00<0[XUE0:f8E02/Qe<00P2[QU800`2ZQE40
ZHEA0:V5D@030:Z6DP<0ZhMC00<0[HQD0:b7D`2/Qe<00P2[QU820:Z5D@030:V4D02YQE<0ZHEC00<0
Z8AB0P2YQE<00`2ZQU@0Z8AD0:R4E0040:V5E@80ZXIF202ZQE420:V4C@030:Z5D02ZQE40ZXAC0080
ZhEF00<0ZhEH0:Z5D@2ZQE40202ZQE420:V4D0@0Z8=?102XQ5@40:N3D`060:R2E@2XPU<0Z89C0:N1
D02WPTh0Yh9=0P2VPDX30:N2B`80Yh9=0`2WPTh20:N1D080Z89A0P2YPe820:Z4D`<0ZXE@0P2YQ4l3
0:R3CP030:R3C`2WPTh0YX5=00<0YH1<01<0YX5=0:N2CP2XPdl0Yh=?0:R4D02YQE40ZXIB0:V5D@2X
Q500YX9>0:F1C@2SP4X0Y85;0:F2C02VPdd0YH9<0:B1B`2ROdT0X7e70080YX5:00<0YX5<0:J1C@2V
P4l00P2VP5400`2VP5<0YH1;0:J1C0030:J1C0<0Yh9=0`2VPTh30:F1C@80Y81<00H0YGmB0:EoD02V
P540YX1?0:J1C@2WPTd20:N2B`80YH5700@0YH190:F0B`2UP4/0YH1<0P2UOdh20:AoB`80YH1<102V
PDd30:=nBP<0Y7m;0P2UP4`20:F1A`040:AoB02SOTT0XWe80:5lB080X7Y9402ONdL30:5lB0D0X7]7
0`2ONTD209iiA0<0WgY5202PNdH00`2QO4P0X7]709mjAP0209iiA@0309mjAP2QO4P0XWe90080XWe9
01<0Xgi:0:AoB`2SOTX0XGa809mjAP2NNDD0W7M309ehA02PNdL0XWe90:=nBP2RODT0X7]709iiA@2O
NTH0WWU509ag@`2KMT80W7M30080WGQ40180WWU509mjAP2KMTT0VgM709ahB02MNDL0WWY609mlAP2P
ODD0XGi60:1kCP2NNTX0VWI609Qd@P2HM400VgQ209mlA02ROdL209ijAP80Wg]700H0WWY609eiA@2L
N4@0VgM30:5lB02PNdL309iiA@030:1kA`2RODT0Xgi:0080X7a80`2ONdL309ijAP<0WWU4102ONTD0
0`2PNdH0X7a809mkA`0209mkA`0409ijAP2MNDD0W7Q409]g@`80W7U100H0WGY409eiA@2NNTP0WWY:
09mkB`2ONTd809ijBP<0WWY600<0WGU509ahA02KMd<00P2JMT8209eiA@@0W7Q40P2MNDD00`2ONTH0
WWU509iiA@0209ehA00309ag@`2MN4@0WGQ40080W7Q400<0VgM309Yf@P2IMD400P2HM40409Mc?`<0
UW8n0P2ELCd809Ue@`0309MbA@2FLD@0UG130080Tfi100@0UG1309IaA02GLTD0Ug8m0P2FLCd00`2E
Kch0U6ho09A^@@0209A]@P03099/?@2CKCh0U6ho0080UFm000<0U6ho09=]?P2BK3d00P2FLD@00`2E
L4<0U6m209A_@P0409A_@P80Ug52102FL44209Ma@P0408m[>`2@K3`0T6`l095]?@80TVhn0P2CKcl0
0`2?Jc/0SVXj08eY>@0208eY>@0308m[>`2@K3`0TFdm0080TFdk00/0T6`l091[?P2?JSh0SVTo08eX
?P2<ISl0SVdj08e/>@2=Jc/0SF/m08e[?P0208aY?`0A08aY@@2=J3/0SVTl08mZ?@2@Jch0SfXm08iY
?02<IcX0RfHi08US?029I3X0RVDk08]V>P2<IcX0SFTi08iZ>02?JcT0202=Jcd208]Y?080S6Xm00@0
SF/n08i/?`2>K3l0Sfe00`2>JC`[ooooo`00:_ooool808QQ>080S6Hi0`2;ICP308YT=`80S6Hi0`2;
ICP308YT=`0308iX>@2<ISL0RfDf00<0RF<d0P2;ICH208YT=@0408YT=`2;I3T0Rf@k08]T?@80S6A0
202=IcX05@2?IC<0T6Hd091V=02AIcD0T6Hd08mU<`2>I380SF<a08mT>@2@ICX0TFHk099W?02AIS/0
T6Dj08iS>02=HSL0S64d08eR=@2>HcH0Sf@g091U>002099W>P0509=X>`2FHc@0U6@d09EU=@2DISD0
0P2CIcH0102BJ3H0TVXg099Z=`2BJ3H209=Y=`0309AZ>02EJcT0UV`j0080Ufdk202HKD0209Q]@`03
09Q]@P2IKT40VFlo0080VW0n00@0VW4m09Y`?P2JL3h0VW0n0P2IKcd309Q^?080UV/n0P2GK3l209Q]
@080VFi10P2IKcd309Y`?P<0Vg4o00<0WG=109ab@02KLCl00P2JL3h00`2KLCl0W79009ec@@0309ab
@080Vg4o0`2JL3h809ac?`P0VWA700P0WWA209me@`2PMT@0X7I409me@`2MLd40Vg4o09Y`?PP0WWA2
202OMD<309mf@P80WWE1102MM40309ie@@80WgI20P2PMd<00`2OMD<0WWA209ec@@0209ec@@0309me
@`2PMT@0XWQ60080X7I400@0WgE309id@P2NM480WgE30P2PMT@0202NMCl0WgI009mf@P2PMT@0XGM7
0:9gBP2RMd`0XgQ=0`2QMdD40:9hAP<0XgU70P2RN4H00`2QMdD0XWQ60:=iA`020:EkB@<0Y7]70P2S
NTH30:9iA@080:AfA@2UMdH0YGU80:EkB@2TO4T0XWe90:5lB02PO4P20:QoB`<0Ygi:0`2VODT20:B0
AP040:AoB02TOdX0Y7m:0:AoB`80Y7i=202WOTX80:9mB@P0YG]90P2VODT0102WOTX0Z7m;0:QoB`2Y
P4`20:Z1C@P0Z7m;00@0Ygi:0:QoB`2XOd/0Z7m;0P2YP4`20:Z1C@80ZH1800@0ZH1:0:V0C02YP4`0
ZGm=0P2YOdl0102/Q4T0Zh=80:^3B02[PdP30:Z2A`030:V1AP2YQ500ZHA@0080Z8=?0P2WPTh20:J1
C@P0ZX5=00<0ZH1<0:Z1C@2[PTh00P2/Pdl00`2[PTh0ZX5=0:V0C00@0:Z1C@T0[89@202[PDl80:Z5
D@030:b2D02]Pe40[XAB0080[hEC00@0[XAB0:f3D@2/PU00[8MC0P2[QU800`2ZQE40ZHA@0:R3C`02
0:N2CP80ZHA@00@0ZXEA0:^6DP2]R5@0[XUE0P2_RUH00`2/Qe<0ZhIB0:Z5D@020:V4D0030:Z5D@2[
QU80[8MC0080ZXEA0`2[QU830:b7D`<0[HQD0`2^RED20:n:EPP0/8MC0P2_RUH30:j9E@<0[HQD402^
RED01P2]R5@0[XUE0:j9E@2_RUH0/8]G0;6<F080/XeI00@0/8]G0;6<F02aS5P0/HaH0`2bSET00`2c
SUX0/XeI0;:=F@060;:=F@P0/8YK102bSET40;6<F0060:f9F@2^RUX0[XYJ0:n;F`2`S5`0/HeM0P2b
SUh90;>>FP<0/XeI0`2cSUX20;B?F`<0/XaO0`2cSF020;B>H@0A0;FAH@2dT600/XiN0;6=G@2`S5`0
/HeM0;:>GP2cSel0/heN0;J@H@2hTV<0]Y1Q0;:<G@2`RU/0/XaM0;F?H02dR5/00P2dRE`00`2dRed0
/heN0;>?G`020;:@H0P0]91P0P2dSe/30;>>FP030;B?F`2eT5`0]Y5M00P0/heN202aRe`;0;:=F@<0
/hiJ0P2dSe/20;>@F0030;>@FP2cSe/0/hmM0080/hmO00<0/hiQ0;B?F`2dSe/01P2dSe/00`2bSET0
/hiJ0;F@G0020;JAG@030;F@G02cSUX0/XeI00P0]HmP0`2gTUh20;JAG@<0]I1L202dSe/80;:=F@04
0;2;E`2bSET0]8mK0;F@G080]Y5M00<0]I1L0;B?F`2dTE/0202dTE/80;FAH@P0]Y9R2`2fTEd30;F@
G080]8mK0P2hTV<20;NAHP80]Y1Q0P2eSf080;>?G`030;>?E@2dT5H0]Y5J0080]i9M00<0]Y5M0;F?
GP2dSUd0202eSf080;B?F`80/hmO0`2dT6030;FAH@P0]i5R00D0^9AP0;NCG`2gTel0]Y9N0;FAG@02
0;B@G0030;>?F`2hU6@0^9AT00H0^9AT00<0]I5Q0;B@H02cSel00P2bSUh00`2cSel0]91P0;FAH@03
0;FAH@<0]91P0P2cSel30;JBHP80]I5Q0`2dT600102bSUh0/hmO0;>?G`2cSel30;B@H0070;FAH@2d
TE/0]91L0;B@G02eTEl0]I5Q0;JAI0020;JAI@T0]HmP0`2hTeh30;NBG@80]Y5L202dT6080;B@G080
[h]G0P2`S5P30;6=F@050;:>FP2fTV80]Y9R0;FAH@2dT6000P2cSel20;:>GP040;NCG`2eTEd0/hmK
0;:>FP80/HeI00@0/XiJ0;>?F`2aSEd0/HeM0P2bSUh40;>?G`P0/HeM202cSV40102_Re/0/8aL0;:>
GP2dT6030;FAH@040;B@H02cSEh0/heN0;>=GP80]8iO0`2eSf00202dSf80/HaO0:j9G02^RE`0/HaO
0;>>H@2bSF00/8]N2`2bSUh20;6=G@<0/8aL0P2bSUX30;>?F`060;:>FP2`S5P0[h]G0;2<G02aSEd0
/XiN0P2dT6000`2bSUh0/HeM0;2<G0080;6=G@`0/HeI0`2bSUX20;>?F`P0]91P202bSET80;6=F@08
0;2:G@2aRe`0/XaM0;>=G02cSUX0/XeH0;6<E@2`Re@30;>>FP<0/XeI0P2aS5P30;6=G@80/8aL0`2_
Re/01@2dSUl0/heN0;>=GP2bS5d0/H]L0080/8YK00<0[hUJ0:n;E`2_ReL00`2_ReL30:j:EP050:^8
D02/RE40[X]E0;2<F02bSU`00P2bSUh0102bSF00/8aH0;2<F02`S5P30:n;E`80[XYF202aSET20:n:
EP<0/8]G0`2aS5P20;2<G080[h]K0`2^RUX00`2]RET0[h]G0:n;E`060:n;E`P0[HUE0P2aSET00`2`
S5P0[h]G0:j:EP030:f9E@080;2;E`2_RUH0[HQD0:b7D`2[QU80[8MC0:f8E02^RED80:b8E0T0[HYD
0P2_RUH30:j9E@<0[HQD00P0ZhIB0:b7D`2^RED0[hYF0;2;E`2_RUH0[XUE0:f8E0P0[HQC202[QEH3
0:j9E@<0[HQD0P2/Qe<20:V5D@<0ZXIB0`2[Qe<20:f8E0030:b7D`2[QU80ZXEA0080ZHA@00<0Z8=?
0:R4D02XQ5000`2WPdl00`2XQ500ZXIB0:^7D`030:Z6EP80ZHEE0`2XQ5@80:V4D0080:V4C@2ZQDh0
ZXE@0:Z5D@2[QE@0ZhEF0:b6E`2/QUT90:^6DP040:Z5D@2YQ500Z8=?0:N2CP80Z8=?00@0ZHA@0:R4
E02XQ5@0Z8AD0P2WPe<30:J2DP060:R2E@2XPU<0Z89C0:N1D02WPTh0YX5<0P2VPDX0102WPdL0Yh=9
0:N2B`2WPT/20:N2CP030:N1D02WPE80Yh5B0080Yh5B0P2XPU<30:V3E0040:^6DP2ZQE40ZXEA0:Z5
D@80ZHA@0P2XPdl00`2YQ500Z8=?0:J1C@030:F0C00C0:J1C@2XPdl0ZHA@0:N3C`2XQ500ZHEA0:Z6
DP2YQE40Z8A@0:J2CP2UPDd0Y85;0:F2C02VPdd0YhA>0:J3C@2UPT`0Xh1:0:5nB0020:N2B`030:N2
C@2WPTh0Yh5@0080Yh5B00<0Yh5D0:J1C02VPD`01P2VPD`30:J2CP<0YH5=0P2TP4`01P2UOe80YGm@
0:J0D@2VP4l0YX5=0:N2C@80Yh9;0P2UPDL0102UP4T0YH1;0:F0B`2UP4`20:EoCP030:AoB`2UP4`0
YX5=0080YX5=00<0YH1<0:AoB`2SOTX00`2SOTX30:AoB`80YH1<0P2UPDL0102TOdP0Xgi90:9mB02Q
O4P20:1jBA00Wg]70P2PNdL309mjAP<0WWU500<0X7]609mjA@2NND@00P2MN4<00`2NND@0WgY50:1k
AP080:1kAP0309mjAP2NNDD0WGQ40080WGQ400H0WWU50:1kA`2RODT0X7]70:5lB02SOTX20:AoB`07
0:=nBP2QO4P0X7]709ehA02NNDD0WgY60:1kA`020:5lB0040:1kA`2ONTH0WWU509ehA0<0VgI20P2M
N4@00`2NNDD0X7]709ehB`0209eiB@0309ijB02NNTH0WW]50080Wga401<0WWU<09eiB@2LN4P0VgM5
09]g@`2LND<0WGY209ik@`2LN4@0WWY60:5mB@2TP4`0Xgm;0:1lB02MNDD0VWI20:9mB@2PNdL0WWU5
0080WGQ400@0WgY60:9mB@2TOd/0X7a80`2ONdL209ijAP80WGU5202ONTD00`2MNDD0WWY609mkA`02
09mkA`0309ijAP2LN4@0W7Q40080W7U100<0W7U309eiA@2MNDL00P2NNTX00`2NND`0WWY:09ijBP06
09ijBP80W7Q40`2MNDD01P2LN4@0VWI209Yf@P2NNTH0WGU509ahA080VgM300L0W7Q409eiA@2NNTH0
XGa80:1kA`2NNDD0W7M300@0VgI200H0W7Q409]g@`2KMd<0VWI209Ue@@2HM40509Mc?`<0UW8n0P2E
LCd809]gA`0309MbA@2FLD@0UG130080U6m200T0UG1309IaA02GLTD0V7<n09Mb?P2FLCd0U6hm09A^
?`2DKT400P2EKT<00`2DKSl0UFm009I`@@0209Ma@P0809I`@@2EKd00U6ho09IaA02EL4<0U6m209=^
@@2BKD0309=^@@0409A_@P2GLD80UW1109E_@080U6ho00<0UFm009I`@@2GLD80202AKCd408eY>@04
08iZ>P2?Jc/0Sf/k091/?080T6`j00H0TFdm091[?P2@Jcl0SVTo08aW?@2;ICh208e/>@0308e[>`2=
Jcd0SF/n0080SFY000<0SFY208iY?02>JC`00`2@Jch02@2>JC`0S6Lj08]V>@29Hc`0RVDk08]V?02<
Ic/0SFPk08m[>`02091/>PP0SF/m202;J3h308eX>b_ooooo000Zooooo`P0RF8i0`2<IST00`2;ICP0
RV@g08YT=`0208US=P<0RV@g0`2;ICP208aV>@0308iX>@2=IcP0RfDf00<0RF<d00P0RV@e08]U=P29
Hc@0RF<d08YT=`2:HcP0Rf@k08aU?P80S6A0202<IST208eS<@<0SfDc00D0SF<a08]Q;`2:H2h0Sf@j
091U>`03095V?00308mT>P2=HSP0S64g0080SV<f00@0Sf@g091U>02@ICP0TFHi0P2BIcX0102FHc@0
U6@d09EU=@2DISD209=W=P03099X=P2BJSL0TVXg0080TfTg00@0U6Xh09E[>@2FK3X0UV`j0P2GKC/6
09Q]@080Uf`o0P2HKD<00`2HKD80VFi109U_?`0209Y`?P0409Ya?@2JL3h0VW0n09Y`?P80VFlm0`2H
KS`0202CJ3/0U6Tl09EZ?@2FJch0V6e009U^@@2JKd80Vg130P2IKcd309Y`?P<0Vg4o00<0WG=109ab
@02KLCl00P2JL3h0102KLCl0W79009ec@@2LLT0309]a?`80VW0n0P2IKcd809ac?`P0VW=800<0WWA2
09me@`2QMdD00P2RN4H00`2PMT@0WgE309id@P0809id@P80X7I41P2OMD<309mf@P80WWE11@2MM403
09ie@@<0WgI200/0WgE309id@P2MLd40W79009ec@@2NM480X7I40:5gA@2PMT@0WgE309id@P0209ec
@@0309id@P2OMD<0X7I40080WWDm00@0WgI00:1fA02QMdL0XWM<0P2SN4h20:1fA080XGM500<0XWQ6
0:=iA`2SNDL00P2SNDL00`2TNTP0XgU70:9hAP020:5gA@030:=iA`2UNdT0YWa:00<0XWU50P2SNTH3
0:AkA`080:AfA@2UMdH0YGU80:IlBP2UODX0Xgi:0:5lB02ONdL30:QoB`030:MnBP2VODT0YWe90080
YGa80P2TP4H0102TOdP0Y7m:0:AoBP2TOd/20:AnC@P0YGa8202QO4P80:IlBP050:ElB02VODT0YWe9
0:MnBP2YP4`00P2ZPDd00`2[PTh0Z7m;0:QoB`090:QoB`80ZH1<0`2ZPDd20:QoA`040:QoB@2XOd/0
Z7m;0:QnC080Z7i>0P2/Q4T20:^3B080ZX970P2YPDH20:V4D080Z8=?0P2WPTh20:J1C@T0ZH1<00H0
ZX5=0:^2CP2/Pdl0[8=?0:^2CP2ZPDdA0:V0C0T0[89@202[PDl80:Z5D@030:b2D02]Pe40[hEC0080
/8ID00@0[hEC0:f3D@2/PU00[8MC0P2[QU801@2ZQE40Z8=?0:N2CP2WPTh0YX5=00<0ZHA@00<0ZXEA
0:^6DP2/Qe<00`2/Qe<01`2[QU80ZHA@0:R3C`2XPdl0ZHA@0:^6DP2/Qe<00P2ZQE430:^6DP<0[8MC
0`2]R5@30:j9E@80[hYF202`Qe<20:n:EP<0[XUE0`2]R5@@0:n:EP060:b7D`2]R5@0[XUE0:n:EP2`
ReL0/HaH0P2bSET20;2;E`80/HaH0P2bSET20;>>FPP0/HaH202_REX40;6<F0@0/XeI00H0[XYJ0:n;
F`2`S5`0/HeM0;:>GP2cSel20;B@H0T0/hiJ0`2bSET30;>>FP80]8mK0`2bRf030;><H@80]8eR00<0
]99R0;>AH@2aSel00`2_SEd02`2`SUh0/HmO0;>=GP2fT640^99S0;J@H@2bS5d0/8YK0;:<G@2eSf00
/hMJ0080/hQK00D0/hYL0;>=GP2cSel0/HmO0;:@H0080;B@H0030;B?F`2cSUX0/XeI0080/XeI00<0
]8mK0;JAG@2hTel0202cSEh80;6;G0/0/XeI0`2cSUX20;B?F`80/i1H00<0/i1J0;>?F`2cSed00P2c
Sel00`2cSV40]8mK0;B?F`060;B?F`030;:=F@2cSUX0]I1L0080]Y5M00<0]I1L0;>>FP2bSET0202d
SUl20;JAG@80]I1L0P2dSe/20;>>FPP0]8mK2@2bSET01`2cSUX0]8mK0;JAG@2fTEd0]I1L0;B?F`2c
SUX02@2dTET30;JBHPD0]I5Q202fTV880;F@G080]i9N0P2fTEd0102eT5`0]8mK0;B?F`2dSe/20;RB
H`80]i5R0P2fT6420;F?H0P0/hmO00P0]91D0;FAE@2fTUP0]i9K0;NBG@2fTEd0]8mK0;>=G0P0]HmP
202dSe/30;FAH@<0]91P0P2cSel80;NAHP@0]Y9N102eTEd80;JBHP030;FAH@2dT600/XiN0080/HeM
00<0/XiN0;B@H02eTF400P2fTV820;FAH@050;B@H02cSel0/hmO0;>?G`2fTV800`2eTF420;B@H080
/hmO0`2bSUh00`2cSel0]91P0;B@H0020;FAH@060;BAF`2dT5`0]I5M0;FAG`2fTV80]Y5T0P2fTFD9
0;F?H0<0]Y5J00<0]I1I0;B?F02dSeP00P2cSUL80;B@H0P0/XiJ0P2`S5P20;6=F@<0/XiJ00<0/hmK
0;>?G`2bSUh01P2bSUh00`2eTEd0]91L0;>?F`020;6=F@040;:>FP2cSe/0]91L0;2<G080/HeM0P2b
SUh20;>?G`030;B@H02aSEd0/HeM00H0/HeM202aS5l0102_Re/0/8aL0;:>GP2dT6020;FAH@80]91P
00<0/XaM0;>=GP2cSEh00P2dSUl20;F?H0090;J@H@2fTFD0/HaP0:b7F`2]R5`0/HaP0;>>HP2bSF40
/8]O00X0/XiN0P2aSEd40;2<G00;0;6=F@2bSUX0/hmK0;B@G02cSe/0/XiJ0;2<F02_ReL0/8aL0;6=
G@2bSUh00P2dT6000`2bSUh0/HeM0;2<G0080;6=G@`0/HeI0`2bSUX20;>?F`H0/XiN0P2cSel80;B?
F`P0/HeI00P0/8YM0;6;G02bS5d0/heL0;>>FP2bSEP0/HaE0;2;E080]8mK0P2cSUX20;:=F@80/HaH
00@0/HeM0;2<G02`S5`0/8aL0P2_Re/20:j:FP80]8iO00@0/heN0;:<G@2aRe`0/8YK0P2_REX60:j:
EP80[h]G00P0[8UA0:f:DP2_S5H0/HeI0;:>G02aSEd0/8aL0:n:G@<0/8aH0`2_ReL20:j:EPP0/HeI
0P2_RUH30;2;E`<0/HaH0`2_Re/30:j:FP80[HUI202_ReL80:f9E@P0[h]G00<0[XUE0:f8E02/Qe<0
0P2/Qe<00`2]R5@0[hYF0;2;E`080:b8E0T0[HYB0`2_RUH00`2^RED0[HQD0:f8E0020:b7D`080:Z5
D@2[QU80[HQD0:j9E@2_RUH0[XUE0:f8E02/Qe<80:n:E@P0ZhEF102]R5@40:j9E@80ZHEA0`2ZQU83
0:^7D`80[HQD00P0[8MC0:^6DP2ZQE40ZHA@0:R3C`2WPTh0Z8A@0:N3C`<0YX9>00/0Z8A@0:Z6DP2/
R5@0[HUI0:b8F02[QeL0ZXIF0:R4E02WPe<0YX9B0:F1D@080:V4D080ZXE>00<0ZXE@0:^6DP2[QE@0
0P2/QUL00`2/QUT0ZhIB0:^6DP060:^6DP030:b7D`2[QU80ZHA@00<0Yh9>0P2YQ5030:R4E0030:N3
D`2VPU80YX9B0080YH5A00H0Z89E0:N1DP2WPE80Yh5@0:J1C@2VPD`20:F0B@080:J2A02VPTH0YX98
0:J1BP2VPDd0YX1?0:J0D@2VP5<40:N1DP80Z89C0P2YPe@20:^5E0<0ZXAC0`2YPe800`2YQ500Z8=?
0:N2CP030:F0C00>0:N2CP2XPdl0ZHA@0:N3C`2XQ500ZHEA0:Z6DP2YQE40Z8A@0:J2CP2UPDd0YH9<
0:J3C@2WQ4h20:R5C`030:J3C@2TPD/0Xh1:0080ZHA=00<0ZHA?0:V4D02YPe800P2YPe@00`2YPeH0
Yh9=0:N2C@060:J1C0<0YX9>0`2UPDd20:B0C0060:EoDP2UOe00YX1A0:J0C`2VPDd0Yh9=0P2WPT/2
0:F1A`040:F0B@2UP4/0YH1;0:F0C080YGm>00P0YH1<0:J1C@2WPTh0Yh9>0:J1C@2UP4`0XWe90:5l
B0<0Xgi:0`2TOd/20:F0C080YH5700@0Y7m80:=nB@2RODP0XGa80P2PNTT@09mkA`0309mjAP2NNDD0
WWU50080WGQ40P2LMd<0102KMT80XGa70:1kAP2NND@209eh@`0309iiA02PNdH0XGa700P0X7]600<0
WWU509ehA02LMd<00P2LMd<0202NNDD0X7]70:5lB02NNDD0WgY60:9mB@2TOd/0YH1<0P2TOd/00`2S
OTX0WgY609iiA@0309iiA@0809mjAP2QO4P0XGa809ehA02LMd<0VgI209Ye@@2KMT8209ehA00309mj
AP2PNdL0WgY=0080Wg];0100WWY809eiA@2MNT@0WGY209ai@@2LMdX0W7Q809eiB@2NNTP0WWY609ej
A02LND40VgQ009ahA02MNDD0Wg]70P2PO4P02`2ONdL0WWY609eiA@2SOTX0XGa809iiA@2LMd<0WGQ4
09mjAP2SOTX0YH1<00<0Wg]70P2NNTH309eiA@H0WgY50P2NND@0202KMd<0W7Q409ijAP2ONdL0X7a8
09mkA`2NNTH0WGU50P2LND401P2LND<0W7Q409eiA`2MNDT0WWY:09iiC0P0WWY:00H0VGE109Yf@P2L
N4@0WGU509ijAP2MNDD209]g@`0309ijAP2MNDD0W7Q40080VgM300/0W7Q409eiA@2NNTH0WWU509eh
A02KMT80VWE109]f@P2LMd<0WWU509mjAP0209]g@`0409Yf@P2IMD40V7A009Qd@0D0Ug<o0`2FLSh2
09Ea?@P0V7A400<0V7=609MbA@2EL4<00P2DKd802@2EL4<0Ug9509QcAP2IM3l0V7<o09Ia?@2DKSd0
U6ho09A^@@0209I_A00309I`@@2GLD80V7930080VG=400H0V79309Ma@P2FL440UW5409E`@`2CKT43
095/?`<0Tfi100<0UW1109E_@02CKCh00P2BK3d0102CKCh0UFm009I`@@2DL40209=_?`03099^?P2A
KCd0T6`l0080Sf/k00<0S6Ph08eY>@2=JCT00`2>JSX208m[>`0808m[>@2@K3X0TFdm095/?`2@Jcl0
SVTo08aW?@2:I3d208a[>00308e[>`2=Jcd0SF/n0080SFY000l0SFY208iY?02?JSd0T6/n095/?`2@
Jch0SfXm08eX>`2<IcX0RV@m08]V?02<Icd0SFPl08mZ?@2AKCd00P2BKS`808i/?P80RfPn00<0RVLm
08UV?028IC/00P27I3X01026HcT0S6Lj08aW>P2<IcX[ooooo`00:_ooool808YS>P0408eW>P2<IST0
S6Hi08]U>080RV@g0P29HcH01P28HSD0RF<f08US=P2:I3L0RfDh08aV>@80SFLj00<0SVPi08eW>02;
ICH00`29Hc@02P2:I3D0RfDf08US=029Hc@0RV@g08YS>02;I3/0S6Dn08aT@02=ID4808aV>@0308]R
;P2<Hbl0SVDa0080SVDa00H0S6<_08YQ;@29H2`0SV<i08mT>P2@IC/2095V?00308mT>P2=HSP0S64g
0080Sf@g0`2@ICP3095V>@0409IS=02DI3@0UFDe09AV=@80TfLf00<0TVPf099Z=`2BJSL00P2CJCL0
0`2DJSP0UF/i09I/>P0209M]>`0309Q^?02HKD00V6e000<0V6e00`2GK3l209Q]@`0309Q]@P2IKT40
VFlo0080VW0n00@0VW4m09Y`?P2JL3h0VW0n0P2IKcd309Q^?008095V>@2BIcX0TfPk09EZ?@2HKD00
VVm209]`@`2LLD@209U_?@<0VW0n0`2KLCl00`2NM480W79009]a?`0209U_?@0309]a?`2LLT00WWA2
00@0Vg4o0P2JL3h209U_?@P0W7<o202IM4P00`2NM480WgE30:5gA@020:=iA`030:9hAP2QMdD0X7I4
00P0WWA20`2PMT@509me@`<0WgI20P2NMD4609ed@080WWE10`2OMT800`2OMD<0WWA209ec@@0209ab
@00609id@P2PMT@0XGM50:1fA02OMD<0WG=10P2LLT002`2MLd40WgE30:1fA02MMCX0WWDm09mf@02P
Md<0XGM70:9gC02SN4h0Y7QA0080X7I40P2QMdD0102RN4H0XgU70:=iA`2SNDL20:AjB0070:=iA`2Q
MdD0XGM50:5gA@2SNDL0YG]90:IlBP020:5hA0040:9iA@2SNTH0XgY60:AkA`80YGa800T0Y7I50:Eg
AP2UNDP0YWa:0:InB`2SOTX0XGa809mkA`2YP4`00P2XOd/00`2WOTX0YWe90:ImB@020:ElB080Xh16
00@0Xh180:>0BP2SP4X0Xgm;0P2SOdd80:AkA`P0XGa8202WOD/20:ElB0040:ImB@2WOTX0ZH1<0:Z1
C@80Zh9>2P2XOd/30:V0C0<0ZX5=0P2XOdL0102XOdT0Z7m;0:QoB`2XOT`20:QnCP<0[8A700<0Zh=6
0:Z2A@2YPD@00P2YPD@20:V4D080Z8=?0P2WPTh20:J1C@P0ZH1<00<0Z7m;0:Z1C@2[PTh00P2]Q500
0`2[PTh0ZX5=0:QoB`0@0:V0C0T0[89@202[PDl80:Z5D@030:b2D02]Pe40[hEC0080/8ID00@0[hEC
0:f3D@2/PU00[8MC0P2[QU800`2YQ500Z8=?0:N2CP020:J1C@@0ZHA@102ZQE400`2/Qe<0ZhIB0:V4
D0020:R3C`030:V4D02[QU80[8MC0080ZXEA0`2[QU830:b7D`<0[HQD0`2^RED20:n:EPP0/8MC0P2_
RUH30:j9E@<0[HQD402_RUH20:b7D`040:f8E02^RED0/8]G0;6<F080/XeI0`2`ReL00`2aS5P0/XeI
0;>>FP020;>>FPP0/8]G202_REX01@2_RUH0/8]G0;2;E`2aS5P0/XeI0080/hiJ00L0]8mK0:n:G@2`
Reh0/HaO0;:=H02cSV40]8mR0080]I1S2@2cSUX30;:=F@<0/hiJ0P2dSe/30;:;H0<0/haQ0P2dSF80
0`2dTV80/i5Q0;6?G`020:n=G@0C0;2>GP2aSel0/Y1P0;>=GP2fT640^99S0;J@H@2bS5d0/8YK0;:<
G@2eSf00/XII0;:7FP2cR5/0/hYL0;:<G@2bSUh0/HmO0;:@H0080;B@H0080;B?F`2cSUX0/XeI0;6<
F02bSET0]8mK0;NBGP2hTel80;>=H0P0/8YK2`2bSET30;>>FP80]8mK0P2cT5P00`2cT5X0/hmK0;>?
G@020;>?G`030;>>H@2dSe/0]8mK00H0]8mK00<0/XeI0;>>FP2eT5`00P2fTEd00`2eT5`0/hiJ0;:=
F@080;B>G`<0]I1L00<0]8mK0;>>FP2bSET00P2bSET80;B?F`P0/XeI00<0/hiJ0;B?F`2eT5`00P2f
TEd00`2eT5`0/hiJ0;:=F@090;BAF@@0]Y9R102eTF480;JBHPP0/hiJ0P2gTUh20;JAG@040;F@G02d
Se/0]8mK0;>>FP80^99S0P2gTF820;J@H@80]HmP202cSel0202dT5@0]I5E0;JBF02gTeT0]i9K0;JA
G02dSe/0/hiJ202eSf080;B?F`060;NCH`2fTV80]Y9R0;FAH@2dT600/hmO0P2bSUh80;NAHP040;B@
G02eTEd0]I5M0;FAG@<0]Y9N00<0]i=O0;FAH@2eTF401`2eTF401`2dT600/XiN0;6=G@2aSEd0/XiN
0;B@H02eTF400P2fTV820;FAH@040;B@H02cSel0/hmO0;:>GP@0]I5Q0P2dT6020;>?G`80/HeM00@0
/XiN0;>?G`2cSel0]91P0P2eTF40202dTE/0]91L0;FAG@2eTEl0]Y9R0;JAI02fTFD0]i9V2@2eSf02
0;>>E`80/XeF00@0/HaE0;2;E02`Re@0[hYC202dT60:0;6=F@80/XiJ0`2cSe/00`2dT5`0/8aL0;2<
G0030;6=G@<0/XiN00<0]91L0;>?F`2bSUX00P2aSET00`2bSUX0]91L0;FAG@020;2<G080/HeM00@0
/XiN0;>?G`2cSel0]91P202aSEd80;2;GP080:j:FP2`S5`0/hmO0;FAH@2fTV80]I5Q0;B@H02cSel2
0;:<G@040;>=GP2dSUl0]8iO0;F?H080]Y1Q00P0]Y5U0;6<H02/Qe/0[8MK0;6<H02dSf<0/XeQ0:n:
GPX0/XiN0P2aSEd30;2<G0040:n;F`2aSET0/XiJ0;>?F`80]91L00H0/XiJ0;2<F02^RUH0/8aL0;6=
G@2bSUh20;B@H0030;:>GP2aSEd0/8aL00P0/HeM302aSET30;:>FP80/hmK1@2aSEd30;:>GPP0]I1L
202aSUP02@2`RUd0/H]L0;:<G@2cSE`0/hiJ0;:=F02aS5D0/8]D0;F@G0020;B?F`030;>>FP2bSET0
/XeI0080/HaH102`S5`20:n;F`80[XYJ00P0]HmP0;B>G`2cSEh0/XaM0;6;G02`RU/0[hUJ0:j8F@80
[HUE102^RUH20:n;E`080:f:DP2^Re<0/8eG0;6=F@2bSU`0/8aL0:j:FP2]R5/30;2<F0<0[h]G0P2^
RUH80;6=F@80[hYF0`2`ReL30;6<F0<0[h]K0P2^RUX30:f9F@P0[h]G202]RED20:j:EP<0[h]G0`2`
S5P20:f8E0060:b7D`2[QU80[8MC0:j9E@2`ReL0/XeI202/R5@90:f:DP040;2;E`2_RUH0[hYF0:j9
E@80[HQD0P2/Qe<0202ZQE40ZhIB0:f8E02^RED0[hYF0:j9E@2]R5@0[8MC202`ReH80:^5F0060:^6
DP2/Qe<0[8MC0:f8E02^RED0[hYF0P2`ReL20:V5D@<0ZXIB0`2[Qe<20:f8E0040:b7D`2[QU80ZHA@
0:R3C`80Yh9>00P0Z8E?0:N4CP2VPdd0YH9<0:J3C@2XQDl0ZXMA0:b9D`80[XYJ00@0[8QH0:Z6EP2X
Q5@0YX9B0P2TP5080:V4D080ZXE>00<0ZhIA0:^6DP2[QE@00P2/QUL00`2/QUT0ZhIB0:^6DP060:^6
DP080:b7D`2[QU80ZHA@0:N2CP2VPDd0Yh9>0:V4D02ZQE430:R4E0030:N3D`2VPU80YH5A0080YH5A
00H0Yh5D0:N1DP2WPE80Yh5@0:J1C@2VPD`20:F0B@090:J3@`2VPT@0YX960:J1BP2VPDd0YX1A0:J0
D`2VOe@0YX1C00<0Yh5D0P2XPUD20:V3EP<0ZhED0P2ZQ5<30:V3DP030:V4D02XPdl0Yh9>00<0YX5=
00h0Yh9>0:R3C`2YQ500Yh=?0:R4D02YQE40ZXIB0:V5D@2XQ500YX9>0:F1C@2VPdd0YhA>0:R5C`80
ZHI@00<0YhA>0:F2C02TPD/00P2[QTl00`2[QU40ZhIB0:^5E0020:^5EP040:^5F02WPTd0Yh9=0:N2
C@D0YX5<0`2VPTh30:F1C@80Y81<00H0YGmB0:EoD02VP540YX1?0:J1C@2WPTd20:N2B`80YH5700@0
YH190:F0B`2UP4/0YH1<0P2UOdh0202VPDd0Yh9>0:R3C`2XPdl0Yh9>0:AoB`2QO4P0WgY60`2SOTX3
0:AoB`80YH1<0P2UPDL0102TOdP0Xgi90:9mB02QO4P20:1jBA00Wg]700@0WWU509ehA02MN4@0W7M3
0P2KMT8209Ye@@030:5lA`2PNdH0WWU40080WGQ300<0WWU40:1kAP2QO4L0202PNdH209ehA00<09ag
@`2KMT80W7M309iiA@2PNdL0XGa809ag@`2NNDD0XGa80:=nBP2UP4`0YX5=0P2UP4`00`2QO4P0WgY6
09ehA00209ag@`0509iiA@2QO4P0Xgi:09ag@`2KMT800P2JMD402`2KMT80WGQ409ehA02ONTH0X7]7
0:5lC`2PO4`0Wg];09ijB02MNDD0W7U30080VgQ000P0VWE809ahB02NNTX0X7a:0:1lB02NNdD0VWLo
09Qe?@80W7Q400T0VgM309Yf@P2KMd<0WGU509ijAP2PO4P0Xgi:0:5lB02NNDD00P2LMd<00`2ONTH0
Xgi:0:F0C00209mkA`<0WWY60`2MNDD509mjA@<0WWU400<0VGE109]g@`2MNDD00`2PO4P02P2ONdL0
WWY609]h@02LND40W7U309ahA02MNDL0WGU909ijBP2NND`809ijBP0;09Mc?`2HM400VgM309eiA@2N
NTH0WGU509ahA02KMd<0Wg]709eiA@2LN4@00P2JMT80102LN4@0WGU509mkA`2JMD4309Ud@00409]f
@P2NNDD0XGa80:=nBP80VgM300<0VWI209Ue@@2HM4000P2GLcl0102FLSh0Ug<o09Mc?`2GLcl309Ib
?P80UG4m202EL4<00`2HLdH0Ug9509E`@`0209A_@P0>09E`@`2GLTD0V7=609Ud?`2HLcl0UW4m09A^
?@2CKCh0U6i109I_A02GL4D0Ug5209Qb@`2JM4D209]eAP0909YdA@2HLT<0Ug5209E`@`2DKd80TVe0
091[?P2?JSd0T6/n0080TVe000@0Tfi109E_@02DKSl0TV`m0P2AJc`00`2BK3d0U6ho09E_@00209Ea
@@0609A`@02BKSh0T6`l08m[>`2>JSX0SFTi0P2<J3P00`2=JCT0SVXj08iZ>P0308iZ>P0808m[>@2@
K3X0TFdm095/?`2AK400SVTo08aW?@2:I3d208a[>00308aZ>P2=Jcd0SF/n0080SFY00140SFY208iY
?02?JSd0T6/n095/?`2@Jch0SfXm08eX>`2<IcX0RfDn08aW?@2=J3h0SVTm091[?P2BKSh0Tflm09A`
?P0808i/?P80RfQ000H0RVLo08QU?@26Hc/0QF8j08AQ>@23H3P308]V>B_ooooo000Zooooo`80R60l
0P29HCd208YR?P80Rf<o00P0R68e08US=P2;ICP0SFLj08aV>@2:I3L0Qf4d08EO<PP0RV<j00D0Qf4d
08QR=@28HSD0RF<f08YT=`0208]U>00908aV>@2?I3T0Sf@i08iS>02=HSL0SV<h091U>P2BIc`0TfPm
0080R68e00@0RF<f08YT=`2;ICP0RfDh0P2<IST01P2<IcX0S6Hi08aV>@2=I3P0SF8g08iQ=`80Sf0f
00<0SV<h08mT>@2AIS/00P2BIc`00`2AIS/0Sf@i08iS>00208eV>`@0S6Dj0P2;I3T0102GK3l0UV/n
09EZ?@2DJC`2099W>P05091U>02?I3L0Sf@g099]>@2AK3P00P2@JcL0302AK3P0Tfhj09E`?02GLSh0
Tflo09E_@02GLD80VW5309]`@`2KKd80Vfa009Y[?`80UV/n00@0Uf`o09Q]@02JKd80Vg130P2LLD@2
09Ma@P0409I`@@2EKd00U6ho09A^?`80Tfdn0`2HKD0209U^@@<0VVm200<0Vg1309U^@@2GK3l00P2F
Jch00`2HKD00Vg1309ebA@0809Y_@P0609A^?`2EKd00UFm009Ma@P2HLT<0VG=40P2JM4D209Y`?P80
Vg4o0P2LLT0209ec@@P0W7560P2MN4<309iiA00309ag@P2JMD00V7<n0080XGQ40`2PMd<309mf@P80
VGA00`2KMT800`2IM400Ug8n09Ia?@0809me@`0809mf@P2PMd<0XWU50:=jAP2TNdL0XgY60:9iA@2Q
N4@209eh@@0409ag@02KMSl0VgHo09Ye?P80VG@m202HLcl80:5gA@80Y7Y800<0XgU70:9hAP2QMdD0
0`2PMT@02@2OMD<0VgI209]f@P2JMD40VGA009Ye@@2LMd<0WWU50:1kA`080:AjB0P0YWe900P0XWU5
0:AkA`2VODT0Ygi:0:QoB`2WOTX0YWe90:AkA`P0Y7m:00H0Z7m;0:MnBP2VODT0YGa80:AkA`2RNDD2
0:5hA0030:=nBP2RODT0XGa80080WgY600<0XGa80:9mB@2SOTX00P2VPD`40:N2C@80Z8=>0P2TNdL2
0:ElB080YWe90P2WOTX80:QnC0P0YH1<00<0YWe90:MnBP2YP4`00`2[PTh00`2ZPDd0ZH1<0:Z1C@07
0:Z1C@P0ZX1>202YOdd01P2YOU<0ZGiA0:UnD@2YOdl0ZGm=0:V0C080ZH1:0P2YQ5001P2XPdl0Yh9>
0:J1C@2UP4`0Y7m;0:=nBPP0ZH1<2@2XPdl20:^2CP80[8=?102]Q5001P2UP4/0YX5<0:J1C02XPdh0
ZHA?0:Z5D080ZhIA0P2XPd`01P2YQ4l0ZXEA0:Z4D`2[QEH0[8IG0:b6F@P0ZHA@0`2XPdl30:V4D080
ZXEA00H0Z8E30:V6AP2YQDL0ZhM=0:b7DP2]QeH20:j8F@080:n:EP2^RED0[8MC0:^6DP2ZQE40ZhIB
0:b7D`2]R5@20:Z5D@80ZhIB102/Qe<00`2YQ500ZhIB0:f8E0020:n:EP040:j9E@2]R5@0ZhIB0:f8
E080[XUE00D0[hYF0;2;E`2aS5P0/HaH0;:=F@030:f8E0<0[XUE0P2_RUH80:j9E@060:j8F`2^R5T0
[XQI0:n9F02_RUH0/8]F0P2`Re@0102cSUX0/XeI0;:=F@2bSET20;6<F080/8]G202_ReL@0;2:F`P0
/heN0`2bSET30;>>FP<0]8mK00H0]I5Q0;B@H02dT600/XiN0;6=G@2`S5`20:n;F`<0/HeM0`2bSUh2
0;>?G`0@0;>=GP2dSUl0]Y1Q0;NAHP2fT640]8iO0;:<G@2`RU/0]HiS0;J?I02gTF@0]i5R0;NAH02e
T5`0/hiJ0;:=F0<0/XeI1@2cSUX20;:=F@040;>>FP2dSe/0]8mK0;F@G080]Y5M202cSUT01P2`ReH0
/8]G0;2;E`2aReX0/H]L0;:<G`80/X]P0P2^RUH0102_ReL0/8aH0;6=F@2bSUX20;>?F`80/8]G0P2a
S5P20;:=F@80/hiJ202cSe/50;JAG@<0]I1L202cSUX00`2aSET0/XiJ0;B@G0020;FAG@030;B@G02b
SUX0/HeI0080/hmK0`2dT5`30;FAG@<0]91P0P2cSel30;:>GPP0/XeI0`2aSET30;:>FP80/hmK302d
T6020;FAH@<0]Y9R202dT6080;FAH@P0/hmK0`2dT6030;FAH@80]Y9R00@0/XiJ0;>?F`2cSe/0]91L
0P2eTEd20;JBGP080;J@K02dSVT0/H]T0;:=H@2gTf<0^iMU0;jKI@2oW6H80;FAG@P0]8mH0P2_T5X0
1`2aT5/0]91L0;FAG@2gTUh0^I5N0;ZBG`2hTel00`2gTUh20;JAG@80]I1L0P2cT5P00`2dTE/0]91L
0;B@GP020;FAH@0:0;F@H`2hUEl0]iAN0;FBG02dTE/0/i1J0;BAF`2eTU`0]Y=M0;:>GP80/hmO00<0
]91P0;FAH@2eTF400P2fTV880;>@F080]I5M102fTUh20;NCG`P0/hmO00H0/HeI0;:>FP2bSUX0]91L
0;FAG@2fTUh20;NCG`P0]I1L102eTF430;B@H080/hmO0`2fT6430;F?H080]8iO202dSe/20;FAH@04
0;B@H02cSel0/hmO0;:>GP80/HeM202cSel20;6=G@040;:>GP2cSel0/hmO0;B@H080]I5Q0P2]RET0
102^RUX0[h]K0;6=G@2bSUh20;>?G`80/8aL0P2aSEd0102bSUh0/hmO0;>?G`2dT6020;2<G080/HeM
00L0/XiN0;>?G`2cSel0]91P0:j:FP2`S5`0/XiN0080]91P00@0/hmO0;:>GP2aSEd0/i1J0P2cSe/0
0`2cSed0/hmO0;>>H@020;>>HP030;6=G@2bSUh0]91P0080]I5Q00<0]91P0;:>GP2aSEd00P2bSUh2
0;6=G@80/8aL0P2_Re/80;:>FP<0/XaO0`2cSF020;B>H@P0/HeI00H0ZhMC0:b8E02]RED0[XYF0:n;
E`2aSET20;:>FPP0/8mJ00P0[HUE0:j:EP2_ReL0/8aH0;6=F@2bSUX0/hmK0;B@G0T0/XiN00<0/HaH
0;>>FP2eT5`00P2gTUh00`2eT5`0/hiJ0;6<F0080;2@G`80/XiN0P2aSEd30;2<G0030:n;F`2aS5P0
/HaH0080/XeI00l0/hiJ0;B?F`2dSe/0]I1L0;JAG@2eT5`0/hiJ0;:=F@2aS5P0/XeI0;>>FP2dSe/0
[XUE0:n:EP2aS5P00P2bSET02`2aS5P0[hYF0:j9E@2]R5@0/8]G0;>>FP2eT5`0]8mK0;6<F02^RED0
ZhIB0080/XiN00<0/HeM0;2<G02_Re/00P2]RET00`2/R5P0[hYF0:n:EP060:n:EP<0/8aL0`2_Re/2
0:j:FP080:j9DP2`Re@0/XeF0;>>E`2dSeP0/hiG0;:=EP2`Re@30:b8E0@0[HUE00@0[XYF0:j9E02^
RE@0[XUD0`2]R5<20:b7DP040;>>FP2bSET0/HaH0;2;E`@0[hYF00H0[HaG0:b;EP2ZRE@0Z8MB0:N6
D@2XQe820:V8D`P0[HUE0P2^RE800`2^RE@0[XUE0:j8E`020:j8F@070:j8F`2^RUH0[HUE0:b8E02[
Qe<0ZXIB0:R4D0020:N3C`030:R3C`2YQ500ZXEA0080ZhIB00L0[8MC0:f8E02^RED0[XUE0;:=F@2a
S5P0[XUE0080[HQD00H0[XUE0:n:EP2aS5P0ZHEA0:Z6DP2/R5@20:f9E@030:b8E02ZQU80ZHEA00P0
[XQI00P0[8MC0:f8E02_RUH0[hYF0:j9E@2/Qe<0ZXEA0:R3C`P0ZXEA00H0[8II0:b6E`2[QEH0ZXAC
0:Z5D@2YQ4l20:R3C080Z8=?00@0ZHA@0:Z5D@2ZQE40ZhIB0P2/Qe<20:f7FP80[8II00@0ZhEH0:Z4
E`2YPeH0ZH=F0`2[Qe<30:Z6DP80ZHEA0100ZXM?0:V6CP2WQ4`0YX=;0:F2BP2WQ4`0Z8E=0:Z7C`2_
ReL0[HUE0:^7D`2YQE40Z8A@0:V5D@2ZQU80ZhMC202YQE420:b8E0<0ZhMC0`2ZQU800`2UPDd0YX9>
0:N3C`020:R4D0030:N3C`2VPTh0YH5=00<0Z8E;00<0YhA:0:J3B@2UPTP00P2UPTP:0:N2CP80Z8=?
00@0ZHA@0:Z5D@2ZQE40ZXEA202XPdh90:J1C0P0ZHEA00<0YH5=0:J2CP2XQ5000P2ZQU800`2YQE40
Yh=?0:J2CP080:N3C`P0YH1;0`2VPD`20:F0B`<0Y7m:0P2TOdP00`2TOdX0Y7m;0:AnC@020:AnC`03
0:AnD@2YOT/0ZGi;00H0ZGi;0P2UP4/30:AoBP<0Xgi900<0Y7m:0:F0B`2VPD`00P2WPTd00`2UP4/0
Xgi90:9mB0020:=nBP040:9mB@2QO4P0WgY609iiA@80WGQ40140W7Q409eiA@2NNTH0Wg]709ijAP2M
NDD0VgM309Yf@P2MNDD0WWY60:1lB02ROTX0Xgm;0:9nBP2PO4P0Wg]70:9mB@020:5lB00309mjAP2N
NDD0WGQ40080W7M3202NNTH0102TOdX0Xgi90:=nB@2SOTT20:9mB080XGa700P0WgY609iiA@2MN4@0
WGQ409iiA@2PNdL0XWe90:=nBP<0X7a<0P2ONd/309ijBP060:1jC@2PNT/0WgU:09miB02NNDD0WWU4
0P2NND801@2LMd<0VgI209Ud@02HLcl0Ug8n0080V7<o00<0VGA009Ye@@2LN4@00`2LN4@209]g@`80
VWI2202MNT000`2ONTD0WWU409eh@`0209eh@`0609mjA@2QO4L0XWe80:5lB02ONTH0WWU50P2MN4@0
2`2NNDD0WgY60:5lB02SOTT0XGa709mjA@2LMd80VgI109ag@P2MN4<0WWU400<0X7a80P2ONdL309ij
AP0309]g@`2MNDD0Wg]70080X7a800H0Wg]709eiA@2KMd<0XWe60:1kA02MN44209]f?`0D09eh@@2Q
O4D0Xgi709mlAP2NNdD0WGY409ai@`2JMd40V7Do09Md?P2FLcd0V7A409UeA@2JMTH0W7Q809eiB@2O
Nd/0X7a<0:5mC@2NNTH209eiA@0309ahA02KMd<0VWI200D0VGE10P2JMT8409]g@`H0VWI200@0VGE1
095b?02CM3h0UG@o0P2HM4002@2HLcl0VG4n09M_?02CKc/0U70l09Ea?@2GLcl0V7A009Ue@@0209Yf
@P0;095/?`2BKD00UG1309MbA@2HLdH0Ug9509IaA02EL4<0Tg@n099c?@2AL3/00P2BKSX02`2DKc/0
V70m09Ua?P2DMCl0UWM109UjA02JNdD0VGY409Ig@@2BLcd0Sg0j00<0Tflo0P2BKSh4095]?@0F09A`
@02CKcl0TFdm091/?02?Jc/0T6`l095]?@2BKSh0UG8l09Ea?@2DL3`0TVhl091/?02?JSd0SVTm08eX
?02AJd@0T6Y308iX@@2<ISl0RfDn08aV?`80SFM000H0UFm209A^@@2DKT40Tfe0099/?`2AJch2091Z
?@0408YV=P2;IcL0SVXj091/?0<0TFdm00T0T6`l099]@02AK3l0T6/n08iY?02=J3/0RfHi08YU>029
I3L00P2<J3P01P2=J3/0SFPl08iY?`2>J440SVQ308mYA0D0SfXm0`2>JC`0102?JSd0SFPk08]V>@29
I3L208MR=@80R6<f0`2>JC`[ooooo`00:_ooool208QP?080RF4m0P2:HSh208]S?`0808US=P2:I3L0
RfDh08]U>02:I3L0RF<f08QR=@27HC@808YS>P@0RF<f102:I3L0202?I3T0SV<h08eR=`2<HCH0SF8g
08mT>@2AIS/0TVLl0P2:I3L308]U>0<0S6Hi00H0RfHi08aV>@2<IST0SF@h08eR=`2>HCL208mP=P03
08iS>02?I3T0TFHk0080TVLl00<0TFHk08mT>@2>HcP00P2=IS/608aU>P80UFXm00@0U6Tl09=X>`2B
IcX0TVLj0P2AIST04P2@ICP0TVdi095/>02AK3P0T6/g095/>02CKSX0UW4m09Mb?P2CKcl0UFm009Ma
@P2JLD<0Vg1309]_@P2KK400VV/o09I[?P80Uf`o00D0V6e009Y_@P2KL4<0Vg1309aaA00309I`@@80
UFm00`2DKSl309Q]@080VFi10`2JKd800`2IKT40V6e009Q]@00209Q]@00309U^@@2KL4<0Vg1300P0
VVm200H0U6ho09E_@02FL440Ug5209Qb@`2ILd@209YdA@80VW0n0P2KLCl209ab@080WG=1202LLD@0
0`2KMT40W7M209eh@`0209iiA00309ag@P2JMD00VG@o0080X7M30`2OMT8309ie@@0309Ud@02JMD40
VgI20080W7M300<0VWE109Qc?`2GLSh0202OMD<02@2OMT80X7M30:9iA@2SNTH0Y7]70:=jAP2RNDD0
XGQ409eh@@0209ag@080VgHo0P2JMCh00`2IM3d0VGA009Ud@00609Ud@0P0XGM50P2SNDL30:9hAP@0
XGM500<0WWU509ehA02KMT800P2KMT800`2MN4@0WWU50:1kA`080:AjB0P0YGa800<0XWU50:=jAP2U
O4P00`2WOTX00`2VODT0YGa80:AoBP070:AoBP80YWe90P2UO4P01`2TNdL0XgY60:9iA@2RNDD0Xgi:
0:9mB@2QO4P00P2ONTH00`2QO4P0XWe90:=nBP030:9mB0D0Xgi90P2TNdL20:ElB080YWe90P2WOTX8
0:QnC0P0YH1<00<0YWe90:MnBP2YP4`00P2[PTh00`2ZPDd0ZH1<0:QoB`080:Z1C@P0ZX1>202YOdd0
1P2YOU<0ZGiA0:UnD@2YOdl0ZGm=0:V0C080ZH1:0P2YQ500102XPdl0Yh9>0:J1C@2UP4`20:AoB`P0
ZH1<2@2XPdl20:Z1C@<0Zh9>0`2/Pdl01P2VPD`0Yh9=0:R3CP2YQ4l0ZXE@0:^6D@80[8MB00D0Z8=<
0:V4C@2YQ4l0ZXEA0:Z4D`020:^5EP030:b6F@2YQ500ZHA@00H0ZHA@0`2XPdl20:V4D0<0ZXEA00H0
Z8E50:V5A`2ZQTX0ZhI?0:b7DP2]R5@20:j8F@080:n:EP2^RED0[8MC0:^6DP2ZQE40ZhIB0:b7D`2]
R5@20:Z5D@80ZhIB0`2/Qe<02@2]R5@0ZHA@0:^6DP2]R5@0[XUE0:n:EP2^RED0[HQD0:b7D`040:j9
E@@0[hYF1`2^RED00`2]R5@0[XUE0:j9E@060:j9E@060:j8F`2^R5T0[XQI0:n9F02_RUH0/8]F0P2`
Re@40;:=F@80/HaH0P2`ReL80;2<F100/8YK202cSEh30;:=F@<0/hiJ0`2dSe/01P2eTF40]91P0;>?
G`2bSUh0/HeM0;2<G080[h]K0`2aSEd30;:>GP80/hmO00<0/heN0;B>G`2eSf000P2fT6402`2eSf00
/heN0;:<G@2eSV<0]XmT0;NAI02gTF80]i5P0;F@G02cSUX0/XeH0080/XeI2@2cSUX30;B?F`80]I1L
202cSUT01P2aS5L0/HaH0;6<F02bS5/0/XaM0;>=H080/haQ0P2_ReL20;2<F080/HeI0P2bSUX20;2;
E`80/HaH0P2bSET20;>>FPP0/hmK1P2eT5`20;B?F`P0/hiJ00<0/HeI0;:>FP2dT5`00P2eTEd00`2d
T5`0/XiJ0;6=F@030;>?F`80]91L0`2eTEd30;B@H080/hmO0`2bSUh80;:=F@<0/HeI0`2bSUX20;>?
F`P0]91P102eTF430;JBHP80]i=S202dT6080;FAH@80]91L102cSe/20;:>FP<0/hmO0`2dT6020;FA
H@<0/hmK00<0]91L0;FAG@2eTEd00P2fTUh0202cSFP0/heV0;>>I02bSF40/HeM0;6=F`2cSe/0]I9L
202dT5`80;B?F080/95K00@0/Y5L0;B@G02dT5`0]Y5M0P2hT5d40;NBGP80]Y5M0P2eT5`20;>@F003
0;BAF`2dT5`0]91N0080]I5Q00T0]I1S0;RDH02gTel0]I5M0;B@G02cSe/0]91L0;FAG@2fTUh00`2c
Sel00`2dT600]I5Q0;FAH@020;JBHPP0/i1H202eTEd80;>?G`060;6=F@2bSUX0/hmK0;B@G02eTEd0
]Y9N0P2gTel80;F@G0T0]91P0`2fT6420;F?H0<0]8iO202dSe/30;B@H080/hmO0`2bSUh80;>?G`<0
/XiN0`2cSel20;B@H0050:j:FP2_Re/0[h]K0;2<G02bSUh00P2cSel00`2dT600/8aL0;2<G0020;6=
G@040;:>GP2cSel0/hmO0;>?G`80/8aL0P2aSEd20;:>GP80/hmO00T0[h]K0;2<G02bSUh0/hmO0;B@
H02cSel0/XiN0;6=G@2cT5X00P2cSe/00`2cSed0/hmO0;>>H@020;>>HP030;6=G@2bSUh0]91P0080
]I5Q00<0]91P0;:>GP2aSEd00P2bSUh20;6=G@80/8aL0P2_Re/80;:>FP@0/heN102bS5d80;6=F@80
[XYF0P2_ReL0102`S5P0/HeI0;:>FP2bSUX80;2?FP80[XYF00@0[h]G0;2<F02aSET0/XiJ0P2cSe/9
0;:>GP80/hiJ00@0]8mK0;F@G02eT5`0]8mK0P2cSUX80;2@G`80/XiN0P2aSEd40;2<G080/HaH0P2b
SET01`2cSUX0]8mK0;B?F`2dSe/0]I1L0;B?F`2bSET00P2`ReL01P2aS5P0/XeI0;>>FP2^RED0[hYF
0;6<F080/XeI00H0/HaH0:n:EP2^RED0[XUE0;2;E`2cSUX20;B?F`030;6<F02^RED0[8MC0080/XiN
00H0/HeM0;2<G02_Re/0[XYJ0:f9F@2/R5P80:n:EP<0/8aL0`2_Re/20:j:FP030:j9DP2_RU<0/HaE
00<0/hiG00<0/XeF0;6<E@2]RED01@2]RED20:j:EP<0[hYE0`2^RE@20:f8D`030;:=F@2aS5P0/HaH
0080/8]G0`2_RUH00`2]S5L0[8]F0:Z9E0030:R7DP030:V8D`2ZRE@0[HUE00L0[HUE0P2^RE800`2^
RE@0[XUE0:j8E`020:j8F@060:j8F`2]RED0[8QD0:b8E02[Qe<0ZXIB0P2YQE40102XQ500ZHA@0:V4
D02ZQE420:^6DP070:b7D`2]R5@0[XUE0:j9E@2aS5P0/8]G0:j9E@020:f8E0060:j9E@2_RUH0/8]G
0:Z6DP2[Qe<0[HUE0P2^RUH00`2]RED0ZhMC0:Z6DP080:j8F@080:b7D`2]R5@0[XUE0:n:EP2^RED0
[8MC0:Z5D@2YQ5080:Z5D@080:b6F@2[QEH0ZhEF0:Z4D`2ZQE40ZHA?0:V4C@2XPd`30:V4D080ZXEA
0`2[QU830:b6E`80ZhEF0`2ZQ5D30:^7D`<0ZXIB0P2YQE400`2YQTh0Z8E=0:N4C0020:J3B`060:R5
C@2YQTh0ZhQ@0:f9E@2/R5@0ZXIB0`2XQ5000`2YQE40ZXIB0:V5D@070:V5D@80ZhMC0P2ZQU830:V5
D@040:R4D02UPDd0YX9>0:N3C`80Z8A@00<0Yh=?0:J2CP2UPDd00P2XQD/20:N4BP040:J3B@2UPTP0
YH980:F2B0P0YX5=0`2XPdl50:V4D0P0Z8=>2@2WPTd80:V5D@080:J2CP2WPdl0ZHEA0:Z6DP2YQE40
Z8A@0:J2CP2UPDd80:N3C`P0YH1;0`2VPD`30:F0B`80Y7m:0P2TOdP00`2TOdX0Y7m;0:AnC@020:An
C`030:AnD@2XOd/0Z7m;00H0Z7m;0P2UP4/30:AoBP<0Xgi900P0Y7m:0:F0B`2VPD`0Yh9=0:J1C02U
P4/0Xgi90:9mB080XWe90P2QO4P03`2PNdL0WgY609iiA@2NNDD0W7Q409eiA@2NNTH0Wg]709ijAP2M
NDD0VgM309Yf@P2MNDD0WWY60:1lB0030:9nBP80X7a800D0XWe90:5lB02QO4P0X7]709iiA@0209eh
A00309ag@`2NNTH0WWY600H0WWY60`2SOTT20:9mB0<0XGa70P2NNDD01P2MN4@0W7M309ehA02NNDD0
X7]70:9mB@P0Wg];00/0X7Y=0:1jB`2ONDX0WgU809iiA@2NND@0WWU209eh@@2MN4@0W7M309Ye@@04
09Ud@00309]f@P2LMd<0W7Q400<0W7Q40P2KMd<209Yf@PP0WGY000<0WgY509iiA02MN4<00P2MN4<0
1P2ONTD0XGa70:9mB02QO4P0WgY609iiA@80WGQ400L0WWU509mjAP2QO4P0Y7m:0:9mB02PNdH0WWU4
0080WGQ300@0WWU409mjA@2PO4P0X7a80`2ONdL309ijAP0309ahA02MNDD0WWY60080Wg]700H0WWY6
09eiA@2LN4@0XWe60:1kA02MN44209]f?`0909eh@@2QO4D0Xgi70:1lB02ONdL0WWY609eiA@2KMd<0
VGE10080V7A000T0V7A409UeA@2JMTH0W7Q809eiB@2ONd/0X7a<0:5mC@2NNTH00P2MNDD00`2LN4@0
VgM309Yf@P0509Ue@@80VWI21@2KMd<409Yf@P80VGE100<0TW<m09=d?P2EM3l00P2HM4001@2HLcl0
VG4n09Q`?@2CKc/0U70l0080UG4m00L0UW8n09Mc?`2HM400V7A0099]@02CKT40UG1300<0Ug9500D0
UW5409E`@`2CM3h0TW<m095`>`02099^>P0609A_>`2HL3d0VG4n09=d?P2EMT00UgQ20P2INT@00`2F
Md40Tg@n095b?00209A`@0<0Tflo102BKSh00`2DL400Tflo095]?@0208m[>`0C091/?02AKCd0TVhn
09Aa>`2CKc/0TVhj099^?02AKCd0T6/n08mZ?P2>JCd0TFa2091[@@2>JCl0S6Lm08]V?02<Icd0SFPn
08iY?`02091Z?@<0SfTl0`2>J3/0102:ISH0S6Ph08iZ>P2@K3`2095]?@80T6`l00P0TVe0095/?`2@
Jch0SVTl08eX>`2;IST0RVDh08UT=`80S6Ph00@0SFPk08eX?02>JCl0SVQ10P2>J4<608mZ?@80SVTl
00@0SfXm08eX>`2;IST0RF@g0P28HcH208UT=`<0SVTl:oooool002[ooooo0P28HCX208UR>`80RV<l
0P2;I3d0102<IST0RfDh08YT=`29HcH208QR=@0308US=P2:I3L0RV<j00L0RV<j102:I3L408US=P03
08iS>02=HSL0S64f0080Rf0e00<0SF8g08mT>@2@ICX00P2>J3/308eW>P<0S6Hi00H0RfHi08aV>@2;
ICP0SF@h08iS>02>HCL2091Q=`0308mT>@2@ICX0TFHk0080TVLl00<0TFHk091U>P2?I3T00`2<IST5
08eW>PT0TfPk0P2BKCT03P2AK3P0TVdi09=^>P2DKc/0UW4m09Mb?P2CKcl0UFm009I`@@2IL480VVm2
09Y^@@2KK400VV/o0P2GK3l0102HKD00VFi109U^@@2JKd8209]`@`0409A^?`2EKd00UFm009E_@0@0
UW110`2HKD0209U^@@<0VVm20P2GK3l00`2IKT40VVm209Y_@P0209Y_@P0309U^@@2JKd80VVm200H0
VVm20P2EKd000`2FL440Ug5209Qb@`0209UcA00309YdA@2JL3h0VW0n0080Vg4o0P2LLT0209ec@@P0
W75400P0VG@o09Ye@02LMd80WGQ309iiA02MN4<0W7M209]f@@<0WWE10`2MM40209ac?`80VgI20`2M
N4@00`2KMT80VGA009Qc?`0809me@`0309ie@@2OMT80XGQ400<0XgY60P2QN4@309ag@P80VgI10`2J
MD0809]f@P/0XGM5102RN4H20:=iA`080:5lB02PNdL0WWU509ehA02LMd<0WGQ409iiA@2ONTH80:Aj
B0P0XgY600<0XWU50:=jAP2UO4P00`2VODT20:ElB0P0Xgi900<0YGa80:AkA`2TNdL01@2TNdL00`2S
OTX0XWe90:5lB00209mjAP030:5lB02RODT0Xgi:00L0WgY500<0WWU40:AkA`2TNdL00P2UO4P20:Im
B@80Ygi:202XOT`80:F0C0080:ImB@2WOTX0ZH1<0:Z1C@2[PTh0ZX5=0:V0C02XOd/80:Z1C@P0ZX1>
202YOdd01P2ZOe@0ZWmB0:YoDP2ZP500ZX1>0:Z1C@80ZX5;0P2YQ500102XPdl0Yh9>0:J1C@2VPDd2
0:F0C0P0ZX5=2@2XPdl30:V0C0<0ZX5=0P2[PTh01P2XPdh0ZHA?0:V4C`2ZQE00ZhIA0:b7DP80[HQC
0P2YQ4d00`2YQ4l0ZXEA0:Z4D`020:^5EP030:^5F02YQ500ZHA@00H0ZHA@0P2XPdl20:V4D0<0ZXEA
00`0ZhIB0:V5B@2YQD/0ZXE>0:^6C`2/Qe<0[HQD0:f7EP2^R5T0[hYF0:j9E@2/Qe<20:Z5D@030:^6
DP2/Qe<0[HQD00<0ZhIB0P2/Qe<30:f8E0030:Z5D@2[QU80[8MC00<0[XUE00<0[HQD0:b7D`2^RED0
0P2^RED20:f8E0<0[8MC0P2`ReL0102_RUH0[XUE0:f8E02]R5@20:b7D`P0[XUE00H0[XQK0:j8F@2^
R5T0[hUH0:n:EP2`ReH20;2;E0<0/XeI0P2aS5P30;2;E`P0/HeI202`RU/80;6;G0P0/XaM0`2bSET3
0;>>FP<0]8mK0P2dT6000`2cSel0/XiN0;6=G@020;2<G0040:n;F`2aSEd0/HeM0;6=G@<0/XiN0P2c
Sel00`2bS5d0/heN0;B>G`030;F?H080]8iO00P0]HiS0;J?I02gTF@0]i5R0;NAH02eT5`0/hiJ0;:=
F0P0/hiJ102dSe/30;>>FP030;:=F@2bSEP0/XeH00L0/XeH00D0/XeI0;>>FP2cSE`0]8iO0;B>H@02
0;F>H`040;:>FP2aSET0/HeI0;6=F@<0/8aH00<0[h]G0;2;E`2`ReL00P2aS5P20;:=F@80/hiJ202c
Se/@0;>>FP030;6=F@2bSUX0]91L0080]I5M00@0]91L0;:>FP2aSET0/XiJ0`2cSe/20;B@G080]I5M
0`2dT6020;>?G`<0/XiN202bSET30;6=F@<0/XiJ0P2cSe/80;B@H0@0]Y9R0P2gTf<30;RDI0P0]91P
202eTF420;FAG@040;B@G02cSe/0/hmK0;:>FP80/HeI0P2aSEd30;:>GP<0/hmO0P2cSe/30;B@G0<0
]I5M00P0/XaU0;RCJ@2lUfd0^9=W0;2;GP2/R5P0[HUG0;6=F`P0/XiJ202dSeX20;:CG@040;>BG@2d
T5`0]91L0;F@G080]XiK0`2gTUh20;JAG@<0]I1L0P2cT5P00`2dTE/0]91L0;B@GP020;FAH@040;F@
H`2hU600]i=O0;FAG@80/hmK00<0]91L0;FAG@2fTUh00P2cSel30;B@H0<0]I5Q202cT5X40;B@G0@0
/hmK202cSel20;:>FP030;>?F`2dT5`0]I5M0080]Y9N00<0]i=O0;F@G02eT5`01P2eT5`40;:>GP03
0;>?G`2dT600]I5Q0080]Y9R0P2fT6420;F?H0<0]8iO00<0/heN0;>>FP2cSUX01P2cSUX30;:>GP80
/hmO0`2dT6080;:>GP@0/hmO0`2bSUh01P2aSEd0/8aL0;6=G@2aSEd0/XiN0;>?G`80]91P00@0]I5Q
0;6=G@2aSEd0/HeM0`2bSUh20;>?G`80/8aL0`2aSEd30;:>GP030:n;F`2`S5`0/XiN00<0/hmO0P2b
SUh01P2cT5X0/hmK0;>?F`2cSed0/hmO0;>>H@80/hiR00<0/HeM0;:>GP2cSel00P2dT6000`2cSel0
/XiN0;6=G@020;:>GP80/HeM0P2`S5`20:n;F`P0/HeI0P2dSUl20;>=GP040;:<G@2aRe`0/8YK0;2:
F`l0/HeI2@2bSUX01@2^RUH0[h]G0:n;E`2`S5P0/HeI0080/XiJ00<0/hmK0;:>GP2bSUh01`2bSUh0
0`2eT5`0]8mK0;>>FP020;:=F@030;>>FP2dSe/0]I1L00P0/8iN0`2bSUh20;6=G@<0/8aL0`2bSET3
0;>>FP80]8mK00/0/hiJ0;:=F@2`ReL0[hYF0:j9E@2_RUH0/8]G0;6<F02_RUH0/8]G0;6<F0020;:=
F@060;6<F02`ReL0[hYF0:n:EP2aS5P0/hiJ0P2dSe/0102aS5P0[hYF0:f8E02bSUh20;6=G@030;2<
G02_Re/0[XYJ0080[HUI202_RUH30;2<G0<0[h]K0P2^RUX00`2^RE@0[hYE0;6<E`030;:=F080/HaG
202^RUH20;6<E`<0/8]F0`2_RUD20;2;E`030;6<F02`ReL0/8]G0080[hYF00@0[XUE0:n;E`2^RUH0
[8QD0P2ZQU800`2[Qe<0[8QD0:f9E@080:f9E@80[XUB00<0[XUD0:j9E@2^R5L00P2^R5T00`2^R5/0
ZhMC0:^7D`060:^7D`80ZXEA0`2[QU801P2/Qe<0[HQD0:j9E@2^RED0/8]G0:n:EP<0[XUE00H0[hYF
0;2;E`2`ReL0[8QD0:f9E@2^RUH20:n;E`030:j:EP2]RED0[8QD00P0[XQI00<0[8MC0:f8E02^RED0
0P2^RED00`2/Qe<0ZhIB0:Z5D@080:^6DP060:^5F02[QEH0ZhEF0:Z4D`2ZQE40ZHA?0P2YQ4d30:^6
DP80ZXEA0`2YQ5040:Z4E@<0ZhEF00@0[8IG0:^7D`2[Qe<0ZhMC0`2ZQU820:V5D@030:R5C`2WQ4h0
YhA>0080YhA>00H0ZHI@0:^8DP2/RE<0ZhMC0:Z6DP2XQ5030:N3C`80Z8A@2P2YQE420:R4D0<0Yh=?
00@0YX9>0:F1C@2VPTh0Yh=?0P2XQ5000`2WPdl0YX9>0:F1C@030:N4C080YX=;0`2UPTX80:F0C003
0:Z5D@2YQ500ZHA@0080ZHA@0`2XPdlA0:R3CPX0Z8A@0P2YQE40102XQ500Yh=?0:F1C@2TP4`80:N3
C`P0YH1;0P2WPTd20:J1C0<0YH1;00H0Y7m:0:AoB02TOdP0Y7m:0:AoB`2TOTd20:AnC`030:AnD@2W
OTX0Ygi:00H0Ygi:0P2UP4/30:AoBP<0Xgi900<0Y7m:0:F0B`2VPD`00P2VPD`00`2TOdX0Xgi90:5l
A`050:5lB0<0X7]700<0W7Q409eiA@2NNTH00P2ONdL0202MNDD0VgM309Yf@P2NNTH0Wg]70:1lB02Q
ODT0XWi:0P2QODT01`2PO4P0XWe90:5lB02QO4P0X7]709mjAP2NNDD00P2MN4@809ijAP040:=nB@2R
ODP0XWe80:9mB080XGa70P2PNdH209ehA0<0VgI200@0WGQ409iiA@2PNdL0W7Q80P2MNDT01P2NNTX0
Wg];0:1lC02PO4`0XGe=09miC080WgU:00<0WWQ709iiA@2MN4<00P2MN4401@2NNDD0WGQ409]f@P2J
MD40VgI20080W7M300<0WGQ409iiA@2MNDD00P2LN4@01@2KMd<0VWI209Yf@P2JMT80VgM300P0WGY2
00<0WgY509iiA02MN4<00P2MN4<01P2ONTD0XGa70:9mB02QO4P0WgY609iiA@80WGQ400L0WWU509mj
AP2QO4P0Y7m:0:=nB@2RODP0X7]600<0WgY500<0X7]60:1lB02ONdL00P2ONdL209ijAP80WGU500<0
W7Q409eiA@2NNTH00`2NNTH01@2MNDD0W7Q40:9mB02PNdH0WWU40080W7M200T0WGQ30:1kAP2RODP0
XGe90:1lB02ONdL0WWY609eiA@2KMd<00P2JMT802@2IMDD0VWI609]gA`2LN4P0WGU909ijBP2ONd/0
X7a<09ijAP0209eiA@0309ahA02KMd<0VWI200D0VGE10P2JMT8609]g@`80VWI20`2IMD400`2BLcd0
Tg@n09Ie@00209Ue@@0409Ud@02ILCh0V70m09Ea?@D0U70l0P2ELCd00`2CKT40U6m209E`@`0309Mb
A@0509IaA02EL4<0Tg@n099c?@2BLC`00P2CKc/02`2EL3`0V70m09Ua?P2BLC`0U7<n09Ie@02HMd80
VGQ309Mf@@2EM3l0U7<n00<0UG510P2DL40409=_?`0309A`@02BKSh0TFdm00<0Sf/k00<0T6`l095]
?@2AKSP00P2AKCT00`2AKC/0TFdm095/?`02095/@008091[@@2?JT00SFPn08aW?@2;IS`0S6Lm08eX
?P2>JCl208YU>0<0RfHi0`2<IcX0102;IcL0S6Ph08iZ>P2@K3`2095]?@0:091/?02?Jc/0TF`o091[
?P2?JSd0SVTl08eX>`2<IcX0RfHi08YU>080S6Ph00@0S6Lj08eX?02=J3h0SVQ10P2>J4<908mZ?@03
08iY?02;IST0RVDh0080RF@g0P2:ICP308iY?2_ooooo000Zooooo`80R64h0P29HST208YS>P80Rf@k
00P0SVPk08aV>@29HcH0Qf4d08IP<`28HSD0RV@g08]U>0P0RV<j00D0S6Hi08]U>02;ICP0RV@g08US
=P0208QR=@0408MQ=02=HSL0S64f08]P=@80RUld00<0Rf0e08eR=`2>HcP00P2@JSd0102?JC`0SVPk
08eW>P2=IcX208aV>@0608YU>02;ICP0RfDh08eT>02>HcP0Sf8h0P2@HCL3091U>P80TFHk0`2@ICX2
08aV=`@0SFLh0P2>J3T2095V>@80TVLj0P2CJ3/209AY?00309EZ?@2BKCT0TVdi0080Tfhj00D0U6lk
09E`?02GLSh0Ug8n09A`@00209E_@00309M^@02HKD00VFe00080Vfa000<0Uf`o09Q]@02HKD000P2I
KT4209Y_@P0709]`@`2CKCh0U6ho09A^?`2EKd00UW1109Ma@P0209Qb@`<0V6e00P2IKT4309Y_@P03
09EZ?@2GK3l0VVm20080W75400<0Vg1309U^@@2GK3l0202JKd8309I`@@0309Ma@P2HLT<0V7930080
VG=40P2JL3h209]a?`80W7900P2MLd4809ab@P0309Mb?@2IM3l0VgI100<0WGQ30P2LMd8309ed@0<0
W7<o0P2KLSh0202KMT80W7M309ehA02NNDD0WGQ409ag@`2JMD40VGA0202NM480202NMD40WgI20:5h
A02RNDD0XgY60:9iA@2QN4@0X7M3202KMT8809ehA0P0XGM500D0WgE30:1fA02PMT@0XGM50:9hAP02
0:=iA`80Y7Y800@0Xgi:0:9mB@2PNdL0WWU50P2MN4@00`2NNDD0WgY60:=iA`070:=iA`P0XGQ40P2S
NTH00`2TNdL0YGa80:ElB0030:ElB0P0Xgi90P2SNTH30:AkA`<0YGa800<0Xgi:0:9mB@2QO4P00P2O
NTH00`2QO4P0XWe90:=nBP020:1kAP<0WgY50`2NND@20:AkA`80YGa80P2VODT20:MnBPP0Z7i<202U
P4`00`2UO4P0YWe90:QoB`030:Z1C@030:V0C02XOd/0ZX5=00L0ZX5=202ZP4h80:UoC@060:YoE02Z
Oe80ZWmB0:Z0D02ZP4h0ZX5=0P2ZPD/20:V4D080Z8=?00@0Yh9>0:J1C@2VPDd0YX5=202ZPDd90:V4
D0@0Z7m;0P2YP4`20:Z1C@80ZXE@0P2[QU40102/Qe80[HQC0:f8D`2]R5<20:Z5CP030:Z5D02ZQE40
ZXAC0080ZXAE00<0ZXAG0:V4D02YQ5002@2YQ5030:Z5D@80ZhIB0`2ZQE000`2[QU80[8MC0:b7D`02
0:f7EP080:n:EP2]R5@0ZhIB0:Z5D@2YQ500ZXEA0:^6DP2/Qe<20:^6DP<0[8MC0`2]R5@20:^6DP03
0:b7D`2]R5@0[HQD00<0[HQD0P2^RED0102]R5@0[8MC0:b7D`2[QU820:Z5D@80/HaH00H0/8]G0:j9
E@2]R5@0[8MC0:^6DP2ZQE480:j9E@060:j8F`2^R5T0[XQI0:n9F02_RUH0/8]F0P2`Re@20;:=F@80
/HaH0P2`ReL20:n:EPP0/XiJ202`RU/80;6;G0P0/XaM0`2bSET30;>>FP<0]8mK0`2cSel00`2bSUh0
/HeM0;6=G@020;2<G0<0/HeM0`2bSUh20;>?G`040;:<G@2cSEh0/heN0;B>G`@0]HmP00T0]HiS0;J?
I02gTF@0]i5R0;NAH02eT5`0/hiJ0;:=F02dSe/0102cSUX30;:=F@80]I1L00@0]8mK0;>>FP2cSUX0
/XeI0P2aS5P80;:=F0060;>>F@2dSe/0]8mK0;B>G@2eSf00]HmR0P2fSf@0202dT5`0/hmK0;:>FP2a
SET0/8aH0:n;E`2^RUH0[HUE0P2`ReL20;6<F080/XeI0P2cSUX80;>?F`030;6<F02bSET0/XeI0080
/XeI0`2cSUX80;B?F`030;6=F@2bSUX0]91L0080]I5M00<0]91L0;:>FP2aSET00P2bSUX30;>?F`<0
]91L0`2dT6020;>?G`<0/XiN202bSET30;6=F@<0/XiJ0P2cSe/80;B@H080]Y9R0`2gTf<20;RDI080
^IEU202dT6080;FAH@040;JBGP2eTEd0]91L0;B@G080/XiJ00@0/HeI0;2<F02`S5`0/8aL0`2aSEd3
0;:>GPH0]91L0P2eTEd0202cSV80_IQ/0<BOL`31W6l0]Y5T0:n:G@2bSUh0^9AT202aSET80;B?F`06
0;BEG`2cU5h0]9=N0;FAG@2dT5`0]8mK0P2eSEX20;NBGP80]Y5M0P2eT5`20;B?F`80/i1H00<0]95K
0;B@G02dT5h00P2eTF402@2eT6<0^9AR0;JBH02dT5h0/hmM0;:>G02cSed0]91N0;FAG`060;B@H080
]I5Q302cSe/40;:>FPP0/hmO0`2cSe/00`2dT5`0]I5M0;FAG@020;JBGPP0]8mK0`2`S5`01P2aSEd0
/hmO0;B@H02eTF40]Y9R0;NCH`<0]HmP0`2dSUl20;>=GPP0/hiJ0P2aSEd0102bSUh0/hmO0;>?G`2d
T6020;FAH@P0/XiN0P2dT600102cSel0/XiN0;:>GP2aSEd20;2<G080/XiN0P2cSel20;B@H080]I5Q
0P2aSEd60;:>GP80/8aL1P2aSEd00`2`S5`0/HeM0;6=G@020;:>GP<0/hmO00H0/i1J0;>?F`2cSe/0
/hmM0;>?G`2cSV420;>>HPX0/XiN0P2aSEd20;2<G080[h]K202aSET20;F?GP060;B>G@2bS5/0/H]J
0;2:F@2_REP0[XQG202aSET30;>?F`<0/XiJ0P2aSET80;>>FP80[h]G0P2`S5P20;6=F@80/XiJ2@2b
SUh00`2fTEd0]8mK0;:=F@020;2;E`030;:=F@2dSe/0]Y5M00P0/XiN0P2cSel20;:>GP80/HeM0P2`
S5`20;:=F@H0/hiJ00<0/XeI0;2;E`2_RUH00`2]R5@00`2^RED0[hYF0;2;E`020;2;E`80/HaH102`
ReL01`2aS5P0/hiJ0;B?F`2cSUX0/HaH0:n:EP2^RED00P2aSEd20;2<G0040:n;F`2^RUX0[XYJ0:j:
FPP0[hYF0`2`S5`30:n;F`80[XYJ0P2_RUH00`2`ReL0/HaH0;6<F0030;6<F0030;2<F02_ReL0[h]G
0080[h]G0`2^RUH20;:=F0<0/HaG0`2`ReH00`2^RED0[hYF0;2;E`020;6<F0060;2;E`2^RED0[XUE
0;2;E`2_RUH0[HQD0P2/Qe<00`2]R5@0[XUE0:n:EP080:f9E@80[XUB00<0[XUD0:j9E@2^R5L00P2^
R5T00`2^R5/0ZXIB0:Z6DP030:^7D`<0[8QD0`2[QU820:b7D`80[HQD0P2^RED0102_RUH0[XUE0:j9
E@2^RED20:n:EP80/8]G00<0[HUE0:j:EP2_ReL00P2`S5P00`2_ReL0[XYF0:f9E@080:j8F@030:b7
D`2]R5@0[HQD0080[HQD0`2/Qe<80:^6DP060:Z4E`2ZQ5D0ZXAE0:Z4D`2ZQE40ZXE@0P2ZQDh20:b7
D`040:^6DP2ZQE40ZXEA0:V4D080Z8=?0P2XPU400`2YPe80ZXAC0:^5E0020:b6E@040:f7EP2[Qe<0
ZhMC0:^7D`<0ZXIB0P2YQE430:N3C`050:R4D02YQE40ZXIB0:^7D`2/R5@00P2XQ5060:N3C`P0ZHEA
0`2WPdl20:J2CP@0YH5=00L0YX9>0:N3C`2XQ500Z8A@0:N3C`2VPTh0YH5=00@0YX==102UPT`80:Ao
B`<0ZXEA00D0ZHA@0:R3C`2XPdl0Z8=?0:N2CP0A0:V4C`P0Z8A@0P2YQE420:R4D0040:N3C`2UPDd0
Y81<0:B0C0P0Yh=?202UP4/30:N2C@80YX5<0`2UP4/20:AoB0030:AoBP2TOd/0Y7i=0080Y7i?00<0
Y7iA0:InBP2VOTX01P2VOTX20:F0B`<0Y7m:102SOTT01`2TOdX0YH1;0:J1C02VPD`0Y7m:0:9mB02Q
O4L00`2PNdL20:5lB0<0XWe900P0WGU509ijAP2ONdL0X7a809mkA`2NNTH0W7Q409Yf@P80Wg]70P2P
O4P40:5mB@<0XGa800<0X7]709mjAP2ONTH00P2NNDD809mkA`040:9mB02QO4L0XGa70:5lA`80X7]6
0P2ONTD00`2MN4@0W7M309]f@P0209Ye@@0309]f@P2MN4@0WWU50080VgM700@0W7Q809eiB@2ONd/0
X7a<0P2QODd01P2OND`0WgU:09ihB@2NN4L0WWU509eh@`80WGQ100<0WgY609iiA@2MN4@00P2LMd<2
09iiA@0509mjAP2PNdL0WWY609eiA@2KMd<00`2JMT8209]g@`P0WGY400<0WgY509iiA02MN4<00P2M
N4<01P2ONTD0XGa70:9mB02QO4P0WgY609iiA@80WGQ400P0WWU509mjAP2QO4P0YH1;0:AoBP2SOTT0
XWe80:5lA`<0X7]60`2ONdL209ijAP<0WGU500<0W7Q409eiA@2MNDD0102MNDD02@2LN4@0XWe90:1k
A`2NNDD0WGQ409ag@`2MN4@0WgY60:1kA`020:5mB`060:1lBP2ONdT0WWY809eiA`2LN4H0VgM50P2J
MTH0102KMdL0W7Q809eiB@2NNTX209mkB`0609ijAP2MNDD0WGU509ahA02KMd<0VWI21@2IMD4209Yf
@P<0VgM30P2LN4@0102KMd<0VWI209Yf@P2IMD4209Qd@003099c?@2DMCl0UWE00080VGE100H0VGA0
09Yb?`2HL3d0UW8n09Ea?@2CKc/3099^>P0409=_>`2DL3`0UG1309E`@`80UW5400@0Ug9509IaA02F
LD@0UW540P2BLcd0102CLSd0U70l09A`?02FLCd209Q`?@03099^>P2DL3`0UW8n00<0VGE100@0V7A0
09Mc?`2FLT80UW920P2ELD4409A`@080Tflo00P0TVhn091/?02?Jc/0SVXj08m[>`2@K3`0TFdm08i[
=@80Sf/g00<0T6`j095]?@2AK3l00P2BKD400`2@Jcl0SfXn08eX?00208aW>`0308eX?02>JCd0SfXn
0080R6Hh00@0RFLi08YX>P2:J3X0RfTk0P2<JS`01P2;IcL0SFTi08m[>`2@K3`0TFdm091/?080Sf/k
0P2@Jch0102?JSd0SVTl08eX>`2<IcX208]V>@80RfLg00@0S6Lj08aW>`2=J3h0SFM00P2>J4<308iY
?0@0SfXm00@0T6/n08mZ?@2>JC`0S6Lj0`2:ICP00`2;IST0S6Lj08iY?00208iY?2_ooooo000Zoooo
o`80R64f0P29HSL208YS>080Rf@i00P0SVPk08aV>@29HcH0Qf4d08IP<`28HSD0RV@g08]U>0P0RV<j
00D0S6Hi08]U>02;ICP0RV@g08US=P0208QR=@0408MQ=02>HcP0SF8g08]P=@80RUld00<0Rf0e08aQ
=P2=HSL00P2@JSd0102?JC`0SVPk08eW>P2=IcX208aV>@0608UT=`2:I3L0RfDh08eT>02>HcP0Sf8h
0P2AHSP00`2AIS/0T6Dj091U>P04091U>P03095V>`2<ISD0S6He0080SFLf0P2>J3L208mY>004091U
>02AIST0TFHi099W>P80TfPk00P0U6Tl09EZ?@2EJSd0TVdi09=^>P2DKc/0UG0l09Ia?@<0Ug8n00H0
U71009E_@02DKSl0UVdo09M/?`2HK3l209]/@080V6e0102IKT4209Y_@P80U6ho00<0UFm009I`@@2G
LD800P2HLT<0102ILd@0V6e009Q]@02HKD0209U^@@<0VVm200<0UFXm09M/?`2JKd800P2LLD@00`2K
L4<0VFi109M/?`0809Y_@P0309I`@@2GLD80Ug520080Ug520`2HLT<209Y`?P80Vg4o0P2LLT0209ec
@@P0W79000@0Ug8m09Qc?P2JMD00W7M20P2MN4<00`2LMd80VgI109ed@00209ed@0<0W7<o0P2KLSh0
0`2KMT80W7M309ehA00209ehA00309]f@P2JMD40V7<o00P0WWA200<0WGA009ie@@2PMd<00`2RNDD0
0`2QN4@0X7M309]eA00709]eA0P0WGQ4202QMdD01@2OMD<0X7I40:1fA02QMdD0XWQ60080XgU70P2T
NTP0102SOTX0XWe90:1kA`2NNDD209ehA00309iiA@2ONTH0XgU700L0XgU7202QN4@40:=jAP040:Ak
A`2UO4P0YGa80:ImB@P0XWe80P2SNTH30:AkA`<0YGa800<0Xgi:0:9mB@2QO4P00P2ONTH00`2QO4P0
XWe90:=nBP020:AoBP80Xgi90P2RODP20:5lA`80Y7]70P2UO4P20:ImB@80Ygi:202XOT`80:F0C008
0:ElB02VODT0Z7m;0:V0C02ZPDd0ZH1<0:QoB`2WOTX80:V0C100ZGm=00H0Zh1E0:^0D`2[P5<0Zh5A
0:^1C`2[PTh20:^2C0030:V4D02XPdl0Z8=?0080Z8=?0`2WPTh80:^2CPT0ZHA@102XOd/20:V0C080
ZX5=0`2[QU440:b7DP060:f8D`2ZQDh0ZXE>0:Z5D02ZQE40ZXAC0P2ZQ5D00`2ZQ5L0ZHA@0:V4D008
0:V4D0<0ZXEA0`2[QU800`2ZQ5D0ZhEF0:^5E0020:^5E0<0[8MC00<0[XUE0:f8E02[QU800P2YQ500
0`2ZQE40ZhIB0:b7D`030:b7D`<0[HQD0P2^RED50:b7D`030:f8E02^RED0[XUE0080[XUE00@0[HQD
0:b7D`2/Qe<0ZhIB0P2ZQE420;6<F0060;2;E`2^RED0[HQD0:b7D`2[QU80ZXEA202^RED01P2^R5/0
[XQI0:j8F@2_REP0[hYF0;2;EP80/8]D0`2aS5P20;2;E`<0[hYF202bSUX80;2:F`P0/XaM202aRe`3
0;:=F@<0/hiJ0`2dSe/00`2cSel0/XiN0;:>GP020;:>GPH0/HeM0`2bSUh20;>?G`80]8iO0P2cSEh2
0;B>G`80]HmP00P0]HiS0;J?I02gTF@0]i5R0;NAH02eT5`0/hiJ0;:=F0<0]8mK00<0/hiJ0;:=F@2b
SET00P2aS5P01@2eT5`0]8mK0;B?F`2cSUX0/XeI0080/HaH00<0/8]G0;6<E`2aS5L01P2aS5L01P2c
SUT0]8mK0;B?F`2dSUd0]HmP0;F?HP80]XmT0P2dT5`0102cSe/0/HeI0;2<F02^RUH20:f9E@80/8]G
0P2aS5P20;:=F@80/hiJ202cSe/30;6<F0030;:=F@2cSUX0/hiJ00X0]8mK00<0/HeI0;:>FP2dT5`0
0P2eTEd00`2dT5`0/XiJ0;6=F@030;:>FP<0/hmK0P2dT5`30;B@H080/hmO0`2bSUh80;:=F@<0/HeI
0`2bSUX20;>?F`P0]91P102fTV820;NCH`<0^9AT402dT6020;FAG@040;B@G02cSe/0/hmK0;:>FP80
/HeI0P2`S5`30;6=G@<0/XiN0P2eTEd60;B@G0080:f9F@2gTf<0`9]^0;jIK02eT6<0/8]O0;B?H`2k
UVX80;6=F@P0]8iM00H0]9EO0;>DGP2dTeh0]I5M0;B@G02dSe/20;F=FP<0]Y5M0P2eT5`30;B?F`80
/i1H00<0]95K0;B@G02dT5h00P2eTF40102eT6<0]i=S0;JBHP2dT6020;:>GP030;>?G`2dT600]I5Q
0080]I5Q1P2dT6080;>?G@80]91L0P2cSe/20;:>FP80/HeI202cSel00`2cSe/0]91L0;B@G0020;B@
G0<0]I5M202dSe/01`2_Re/0/8aL0;2<G02aSEd0/XiN0;>?G`2eTF400P2fTV820;F?H0<0]8iO0`2c
SEh80;>>FP80/HeM00@0/XiN0;>?G`2cSel0]91P0P2eTF480;:>GP050;B@H02cSel0/hmO0;:>GP2a
SEd00P2`S5`00`2_Re/0/hmO0;>?G`020;>?G`@0]91P1P2bSUh40;6=G@H0/8aL102aSEd20;:>GP80
/hmO00H0/i1J0;>?F`2cSe/0/hmM0;>?G`2cSV420;>>HP80/XiN102aSEd40;:>GP80/HeM0P2`S5`2
0:n;F`P0/8aH00H0]I1L0;B?F`2cSUX0/XeI0;6<F02_RUH20:j9E@P0/HeI0`2cSe/30;:>FP80/HeI
202eSEX40;2<F0@0/HeI2@2bSUh00`2eT5`0]8mK0;6<F0020;2;E`030;6<F02dSe/0]I1L00P0/XiN
0`2cSel20;:>GP<0/HeM1P2cSUX20;:=F@090;6<F02`ReL0[XUE0:f8E02/Qe<0[HQD0:j9E@2_RUH0
/HaH00H0/8]G00<0/HaH0;:=F@2bSET00`2cSUX00`2bSET0/8]G0:n:EP030;2<G0@0[h]K00<0[XYJ
0:n:EP2_RUH01P2_RUH30;2<G0<0[h]K0P2^RUX40:n9F0040;2:F@2aReX0/H]J0;:<F`<0/HeI00<0
/8aH0:n;E`2_ReL00P2^RUH20;:=F0<0/HaG0`2`ReH00`2/Qe<0[HQD0:n:EP020;6<F0060;2;E`2^
RED0[HQD0;69EP2`R5D0[hMD0P2^QU<00`2_Qe@0/HUF0;::E`080:f9E@80[XUB00<0[XUD0:j9E@2^
R5L00P2^R5T0102^R5/0ZhMC0:^7D`2[Qe<30:b8E080[HUE0`2/Qe<50:f8E0050:j9E@2]R5@0[HQD
0:j9E@2_RUH0102`ReL00`2]RED0[XYF0:n;E`020;2<F0030:n;E`2^RUH0[HUE00P0[XQI00<0[HQD
0:b7D`2/Qe<00P2/Qe<30:f8E0P0[8MC00H0ZXAG0:Z4E@2ZQ5D0ZXAC0:Z5D@2ZQE020:Z5CP80[8MC
00@0ZhIB0:Z5D@2ZQE40ZHA@0P2XPdl01P2WPTh0Z8=?0:R3C`2YQ500ZXEA0:^6DP80[8MC0`2[Qe<3
0:Z6DP80ZHEA0P2WPe40102XQ580ZHEC0:Z6E02ZQU@20:^7E@030:J2CP2WPdl0Yh=?00<0Z8A@0P2W
Pdl80:V5D@80Yh=?0P2VPTh50:F1C@070:J2CP2WPdl0Z8A@0:R4D02WPdl0YX9>0:F1C@080:F2C0P0
YH1<1@2YQ5030:R3Ca40ZHA?202XQ500102YQE40Z8A@0:N3C`2VPTh40:F1C@P0Yh=?202UP4/20:R3
CP80Yh9=0P2VPD`20:F0B`80Y7m800<0Y7m:0:AoB`2TOTd00P2TOTl00`2TOU40Y7m:0:AoBP060:Ao
BP80YH1;0`2TOdX40:=nB@080:AoBP2UP4/0YX5<0:F0B`2TOdX0XWe80:1kAP2PNdL30:5lB0<0XWe9
00@0Xgi:09eiA@2NNTH0Wg]70P2PO4P00`2NNTH0W7Q409]g@`0309mkA`80X7a80P2QODT0102ROTX0
XGa80:5lB02QO4P40:1kA`0309mjAP2ONdL0Wg]700H0Wg]70P2QO4L20:1kAP<0WgY500@0WWU409ii
A@2MN4@0VgI20P2JMD40302KMT80W7M309ehA02JMTH0VgM709ahB02MNDT0WWY:09mkB`2PO4`0XGe=
09ihB`80WWQ900<0WGM609ehA02MN4<00P2LMd0209iiA@0309ehA02LMd<0WGQ40080WWU500D0X7]7
0:9mB@2ONdL0WGU509]g@`0209Ue@@0309Yf@P2KMd<0W7Q400P0WGY400<0WgY509iiA02MN4<00P2M
N4<01P2ONTD0XGa70:9mB02QO4P0WgY609iiA@80WGQ400<0WWU509mjAP2QO4P00P2TOdX20:=nB@04
0:9mB02QO4L0X7]609mjA@80Wg]70P2NNTH209eiA@80W7Q400<0WGU509ahA02LN4@0102LN4@01@2M
NDD0XWa;0:5kBP2ONDP0WWQ70080WGM60P2NN4L20:1lC080Wg];00D0WWY:09eiB@2MNDT0W7Q809Yf
AP0209]gA`0609ahB02MNDT0WWY:09ijBP2ONd/0WWY60P2MNDD00`2LN4@0VgM309Yf@P0509Ue@@80
VWI20`2KMd<01@2MNDD0W7Q409ahA02KMd<0VGE10080V7A000@0Ug<o09=d?P2DMCl0UWE00P2JMT80
1P2IM400VW8o09Ua?P2GLcl0UG4m09=_>`80TFdi00<0TVhj09=_>`2DL3`00`2GLTD409IaA00409Mb
A@2BLcd0TW<m09=b?@80UW8n00L0UW4m09Q`?@2HL3d0TVhj09=_>`2ELCd0Ug<o0080V7A00P2GLcl3
09Ea@@80U7101@2CKcl00`2BKSh0T6`l08iZ>P0208iZ>P0308m[>`2@K3`0SFXd0080SVXf00<0Sf/i
091/?02AK3l00P2BKD400`2?JSd0SVTl08eX>`0208aW>P0308eX>`2?JSd0T6/n0080RVXk00@0Rf/l
08a/?@2<K3d0SFdn0P2>KSl02@2<J3P0SFTi08m[>`2@K3`0TFdm091/?02?Jc/0SVXj091[?P0208mZ
?@0508iY?02=J3/0S6Lj08aW>P2;IST00P2;IcL0102;IST0S6Lk08aW?@2=Id0208eW@P80SFPk0P2>
JC`01`2?JSd0T6/n091[?P2@Jch0SfXm08iY?02<IcX00P2;IST00`2<IcX0SFPk08iY?00308iY?2_o
oooo000Zooooo`80R68e0P29HcH208YT=`80RfDh00@0S6Hi08]U>02:I3L0RF<f0P28HSD00`29HcH0
RV@g08YS>P0708YS>P@0RV@g1029HcH00`2@ICX0Sf@i08eR=`0208]P=@0308aQ=P2=HSL0SV<h0080
SVPk0`2=IcX308aV>@0608UT=`2:I3L0RV@g08eT>02>HcP0Sf8h0P2BHcT00`2BIc`0TFHk091U>P02
08mT>@03091U>P2AIS/0TVLl0080S6Lc0P2=J3@0102>JCD0SfXf091[=`2@JcL2095V>@80TVLj0P2C
J3/209AY?00509EZ?@2BKCT0U6lk09E`?02GLSh00`2HLcl01`2GLSh0U71009E_@02DKSl0UF`n09I[
?P2HK3l00P2KK40809U^@@@0UW110`2GLD80102HLT<0V6e009Q]@02HKD0209U^@@<0VVm20P2GK3l0
0`2IKT40VVm209Y_@P0209Y_@P0309U^@@2JKd80VVm200H0VVm2202GLD8209Y`?P80Vg4o0P2LLT02
09ec@@P0W7<o00<0V7<n09Ud?`2KMT400`2LMd800`2JMD00VG@o09ie@@0209ie@@<0WGA00P2LLcl0
202IM400VWE109]f@P2LMd<0VgI209Ye@@2HLcl0Ug8n202MLd40202MM400WWE10:1g@`2QN4@0XWU5
0:5hA02PMd<0WgI20`2JM4D209]eAP<0W7I7202LMd<;0:5gA@@0XWQ60P2SNDL0202QO4P0X7]709ii
A@2MN4@0W7M309ehA02NNDD0WgY6202RN4H80:9iA@080:AkA`2SNTH0XWU50:9iA@2SNTH0Y7]70:El
B02VODT80:9mB0030:ElB02TNdL0Y7]700D0Y7]700<0Xgi:0:9mB@2QO4P00P2ONTH00`2QO4P0XWe9
0:=nBP020:N2C@040:J1C02UP4/0Y7m:0:AoBP80Xgi90P2TNdL20:ElB080YWe90P2WOTX80:QnC0P0
YH1<00<0Y7]70:ImB@2WOTX00`2YP4`00`2XOd/0Ygi:0:V0C0070:V0C100ZGm=00H0Zh1E0:^0D`2[
P5<0Zh5A0:^1C`2[PTh20:^2C0P0Z8=?202[PTh90:V4D0<0ZH1<0`2ZPDd20:^2CPP0ZhIA0P2[QTl0
0`2[QU40ZXEA0:Z4D`020:V3E0030:V3EP2YQ500ZHA@00L0ZHA@0`2ZQE420:^6DP80[8MC0P2[Q5T0
0`2[QEP0ZhEF0:^5E0020:^6DP040:^6D@2^RED0[8MC0:^6DP<0ZHA@00<0ZXEA0:^6DP2/Qe<00P2/
Qe<20:f8E0<0[XUE00<0[HQD0:b7D`2[QU800P2[QU800`2]R5@0[XUE0:n:EP030:j9E@80[HQD0`2/
Qe<20;2;E`040:n:EP2^RED0[HQD0:f8E080[8MC202^RED01P2^R5/0[XQI0:j8F@2_REP0[hYF0;2;
EP80/8]D0P2aS5P20;2;E`<0[hYF00<0[XUE0;6=F@2aSET01P2aSET80;2:F`P0/XaM202aRe`30;:=
F@<0/hiJ0`2dSe/80;:>GP<0/HeM0`2bSUh20;>?G`050;NAHP2fT640]8iO0;>=GP2bS5d00P2cSEh0
2@2dSUl0]HiS0;J?I02gTF@0]i5R0;NAH02eT5`0/hiJ0;:=F0020;F@G0030;B?F`2cSUX0/XeI0080
/HaH00@0/8]G0;>>FP2cSUX0/hiJ0`2bSET20;6<F0P0/HaG00H0/XeH0;:=F@2cSUX0/heL0;B>G`2d
SV420;F>H`080;B@G02cSe/0/XiJ0;6=F@2`S5P0[h]G0:j:EP2]RED20;2;E`80/HaH0P2bSET20;>>
FPP0/hmK0P2aS5P00`2bSET0/hiJ0;B?F`020;F@G0030;JAG@2eT5`0]I1L00H0]I1L00<0/HeI0;:>
FP2dT5`00P2eTEd00`2dT5`0/XiJ0;6=F@020;6=F@80/XiJ0`2cSe/0102dT5`0]91P0;B@H02dT602
0;>?G`<0/XiN202bSET30;6=F@<0/XiJ0P2cSe/:0;B@H0<0]I5Q0P2fTV820;NCHa00]91P202cSe/2
0;6=G@<0/XiN0`2cSel30;FAG@<0]91L0P2cSe/0202VPU00[HUG0;>?G`2bSF00[XUM0:b7G@2`Rf40
]HmX202bSUX80;B>G`80/Y=M00@0/i9M0;B@G02dT5`0]I1L0P2fSU/20;JAG@80]I1L0`2dSe/01P2c
SUX0/i1H0;>@F02dTE/0]91L0;B@GP80]I5Q00@0]I1S0;NBI@2eT6<0]8mR0`2bSF000`2cSV40]8mR
0;FAH@020;FAH@<0]91P2P2cSel01@2fTUh0]I5M0;FAG@2dT5`0/hmK0080/XiJ00<0/HeI0;>?G`2c
Sel01P2cSel80;B@G0P0/hiJ0`2`S5`00`2aSEd0/XiN0;>?G`030;B@H0040;F?H02dSUl0]8iO0;B>
G`80/heN0P2bS5d80;:=F@<0/XiN0P2cSel30;B@H0P0/HeM0`2bSUh30;6=G@80/8aL102bSUh60;>?
G`<0/XiN1@2aSEd30;2<G0<0[h]K00T0/XiN0;6=G@2aSEd0/8aL0;6=G@2bSUh0/hmO0;B@H02cT5X0
0P2cSe/00`2cSed0/hmO0;>>H@020;>>HP80/XiN00@0/HeM0;2<G02`S5`0/HeM102bSUh20;6=G@80
/8aL0P2_Re/80;2<F080/hiI00@0/XeH0;6<E`2`ReH0/8]F0P2_RUD?0;6=F@030;:>FP2fS5X0]XaJ
00H0]XaJ102`S5P40;6=F@T0/XiN0P2cSUX0102bSET0/HaH0;6<F02bSET20;>>FPP0/XaM00@0]91P
0;>?G`2cSel0/hmO0P2bSUh20;6=G@80]8mK0`2cSUX40;:=F@030;6<F02_RUH0[HQD0080[HQD0P2_
RUH00`2bSET0/HaH0;2;E`020:n:EP030;2;E`2aS5P0/XeI00@0/hiJ0P2bSET00`2aS5P0/8]G0:n;
F`070:n;F`P0[hYF0`2`S5`30:n;F`80[XYJ00P0/8YK0:n9FP2^R5T0[XQI0:n9FP2`RU/0/H]L0;:<
G@80/hmK00<0/XiJ0;6=F@2`S5P00P2_ReL00`2^RUH0/HaG0;6<E`030;2;EP<0[hYE0100ZXEA0:b7
D`2_RUH0/HaH0;:=F@2`ReL0[XUE0:b7D`2bR5H0/HME0;26E02_QE<0/8ID0;67E@2cREL0]8YH202]
RED20:j9DP030:j9E02^RED0[XQG0080[XQI00<0[XQK0:b8E02/R5@01P2/R5@90:f8E0040:^6DP2]
R5@0[XUE0;2;E`80/HaH0P2`ReL00`2/R5@0[HUE0:j:EP020:n;E`030:j:EP2]RED0[8QD00P0[XQI
00<0[HQD0:b7D`2[QU800P2[QU800`2]R5@0[XUE0:n:EP080:b7D`060:V3EP2YPe@0ZH=D0:Z4D`2Z
QE40ZhIA0P2[QTl30:^6DP80ZXEA0`2YQ500102XPdh0ZHA?0:V4C`2YQ4l40:Z5D0<0ZhMC0`2ZQU82
0:V5D@80ZHEE00/0ZXIF0:^7E`2[QeL0ZXIF0:V5E@2XQ5@0YX9>0:N3C`2XQ500ZHEA0:Z6DP020:V5
D@030:R4D02YQE40ZHEA00H0ZHEA00@0Z8A@0:N3C`2WPdl0Yh=?0P2VPTh30:F1C@080:J2CP2WPdl0
Z8A@0:R4D02WPdl0YX9>0:F1C@2SOd/30:B0C0<0YH5=00<0YX9>0:J1C@2VPDd01P2VPDd01@2WPTh0
Z8=?0:R3C`2XPdl0ZHA@00<0ZXEA202YQ4l90:R3CPT0Yh=?00<0YX9>0:F1C@2UPDd00P2UPDd00`2V
PTh0Yh=?0:N3C`070:N3C`P0YH1;0`2XPdh20:N2C@<0YX5<0P2TOdP00`2TOdX0Y7m;0:AnC@020:An
C`030:AnD@2ROdT0XWm900H0XWm90P2UP4/30:AoBP<0Xgi900<0XWe80:=nB@2TOdX00P2UP4/00`2S
OTT0XGa70:1kAP080:9mB@0309ijAP2ONdL0X7a80080X7a800<0WWY609eiA@2KMd<00P2PO4P309mk
A`030:1lB02ROTX0Xgm;00P0XGa8202PO4P20:1kAP80WgY50`2NND@0102MN4<0X7]709iiA@2MN4@3
09]f@P80WGQ40P2KMdL0102LN4P0WGU909eiB@2NNTX209mkB`0609ihB`2NN4T0WWQ909egAP2MN4@0
W7M20P2LMd001@2MN4@0W7M309ag@`2KMT80W7M30080WWU500D0X7]70:9mB@2PO4P0WWY609]g@`02
09Qd@00309Ue@@2KMd<0WGU500P0WGU500<0WgY509iiA02MN4<00P2MN4<01P2ONTD0XGa70:9mB02Q
O4P0WgY609iiA@80WGQ400<0WWU509mjAP2QO4P00P2RODP01P2SOTT0XWe80:9mB02PNdH0WWU409eh
@`<0WWY60P2MNDD309ahA00309eiA@2LN4@0VgM300<0VgM300L0W7Q409eiA@2RO4d0XG]<0:1jB`2O
NDX0WWQ900<0WGM800D0WgY=09iiC02NND`0WWU<09ehB`0309agBP80VgM70P2LN4P209eiB@80WWY:
00H0WWY609eiA@2MNDD0W7Q409]g@`2JMT8509Ue@@80VWI20`2KMd<02`2NNTH0WGU509ahA02KMd<0
VGE109Qd@02GLcl0UW8n09=d?P2DMCl0UgI10080VWI200H0VWE109Yb?`2ILCh0Ug<o09Ea?@2CKc/2
095]>@0909=_>`2FLSh0V7A009UdA`2HLdH0Ug9509IaA02EL4<0UW540080Ug9500<0TG8l099c?@2D
Lch00P2GLcl01@2GLSh0V70m09M_?02DKc/0UG0l0080UW4m0P2GLSh209Ia?@80U7100P2CKcl4099^
?P0:095]?@2BKSh0TFdm08m[>`2>JSX0SFTi08iZ>P2?Jc/0T6`l08eZ=080SVXf00<0Sf/i091/?02@
Jch00P2AK400202>JSX0SFTi08aX>02;IcL0S6Ph08eY>@2?Jc/0T6`l0`2;K3d308a]?P80SFho00<0
SFTi08iZ>P2?Jc/00P2AKCd00`2@K3`0SVXj08eY>@0208mZ?@80SVTl0P2=J3/208aW>P0608YV=P2;
IcL0RfHi08]V>P2<Icd0S6Ho0P2=Id801P2<IcX0SFPk08eX>`2>JC`0SfXm091[?P80TF`o00<0T6/n
08iY?02=J3/00P2<IcX00`2=J3/0SVTl08mZ?@0308iY?2_ooooo000Zooooo`80R68c0P29Hc@208YT
=@80RfDf00P0RF<f08YT=`2;ICP0RfDh08YT=`29HcH0R68e08MQ=0P0RV<j1029HcH408YT=`08099W
?02AIS/0Sf@i08eR=`2<HCH0SF8g08iS>02?I3T208YT=`<0RfDh0`2<IST01P28HcH0RF<f08YT=`2<
HcL0SV<h091S>@80TV<i00<0TVLl095V>`2?I3T00P2>HcP02@2?I3T0TFHk099W?02;IS80S6Lc08eX
=02>JCD0SfXf091[=`02095/>0<0TVLj1P2CJ3/0102BKCT0U6lk09Ia?@2HLcl209Ud@00:09Qc?`2G
LSh0UG5109E_@02CKCh0U6/m09EZ?@2GJch0Vfa009a]@@P0VFi10`2HLT<209Ma@P<0UW110`2HKD02
09U^@@<0VVm200<0VFi109Q]@02HKD000P2HKD000`2IKT40Vg1309]`@`0809Y_@P80V7931P2GLD82
09Y`?P80Vg4o0P2LLT0209ec@@P0W7<m00<0VG@o09Ye@02KMT400P2LMd800`2JMD00V7<n09Mb?@02
0:1g@`<0WgI20`2NMD400`2GLSh0V7<o09Ud@00209Ye@@0309Qc?`2FLCd0UG0l00P0WG=100T0W7<o
09ie@@2PMd<0XGQ40:9iA@2QN4@0X7M309mf@P2ILd@00P2JM4D209]eAP80W7I700<0WGM809]f@P2K
MT801P2KMT880:5gA@80XgU70`2RN4H40:5gA@0309iiA@2MN4@0VgI20080VgI200<0WGQ409iiA@2P
NdL0202RN4H80:=jAP080:AkA`2SNTH0XWU50:5hA02RNDD0XgY60:ElB02VODT80:5lA`80YWe90P2U
O4P01`2TNdL0XgY60:9iA@2RNDD0Xgi:0:9mB@2QO4P00P2ONTH02@2QO4P0XWe90:=nBP2WPTd0YX5<
0:F0B`2TOdX0Xgi90:9mB0020:5lA`80Y7]70P2UO4P20:ImB@80Ygi:202XOT`80:F0C0030:AkA`2U
O4P0Ygi:0080ZH1<00<0Z7m;0:MnBP2VODT0202XOd/80:QnC0P0ZGm=00H0[85F0:b1E02/PE@0[89B
0:b2D02/Pdl20:b3C@@0Z8=?102YQ5080:b3C`T0ZXEA0P2ZPDd30:^2CP<0[8=?0P2ZQE060:V4C`05
0:b7D02[QTl0ZhIA0:Z5D@2ZQ5<00P2YPe@00`2XPUD0ZHA@0:V4D0060:V4D0<0ZXEA0P2[QU830:b7
D`80[8EN00@0ZhAK0:^5F02[QEH0ZhIB0P2[QU402@2]R5@0[8MC0:Z5D@2YQ500Z8=?0:V4D02ZQE40
ZhIB0:b7D`030:f8E080[XUE0P2_RUH0202]R5@0[8MC0:^6DP2ZQE40ZhIB0:b7D`2^RED0/8]G102^
RED40:n:EPL0[XUE00<0[HQD0:j9E@2^RED01P2^RED01P2^R5/0[XQI0:j8F@2_REP0[hYF0;2;EP80
/8]D0`2`ReL30:n:EP80[XUE202`S5P80;2:F`P0/heN202`RU/30;:=F@<0/hiJ0`2dSe/20;6=G@H0
/XiN0`2aSEd30;:>GP80/hmO00@0^YAU0;RBH`2eSf00/heN0P2aRe`20;:<G@0>0;F>H`2fSf@0]i5T
0;NAHP2gTF00]I1L0;>>FP2bSEP0]Y5M0;F@G02dSe/0/hiJ0;:=F@2aS5P20;2;E`<0/HaH0`2bSET2
0;>>FPP0/8]F00H0/HaG0;6<F02aS5P0/XaK0;:<G@2cSF020;><H@<0/XiJ00<0/HeI0;2<F02_ReL0
0P2_ReL20;2;E`80/HaH0P2bSET20;>>FPP0/hmK0P2bSET01P2cSUX0]8mK0;F@G02fTEd0]i9N0;RC
G`P0]I1L00<0/HeI0;:>FP2dT5`00P2eTEd00`2dT5`0/XiJ0;6=F@030;6=F@80/XiJ0`2cSe/30;B@
H080/hmO0`2bSUh80;:=F@<0/HeI0`2bSUX20;>?F`P0]91P1@2cSel20;B@H080]I5Q202dT6080;>?
G`040;2<F02aSET0/XiJ0;:>FP80]91L00<0]I5M0;JBGP2cSel00P2cSel30;B@H080]I5Q0P2fTUh2
0;FAG@0<0;B@G02cSe/0/hmK0;>?F`2[R580[8QD0:b8EP2[QeL0ZhIJ0:b7G@2^R640/8YU202dT5`8
0;B>G`80/95K00@0/Y5L0;B@G02dT5`0]Y5M0P2hT5d30;F@G0<0]8mK0P2cSUX20;>@F0030;BAF`2d
T5`0]91N0080]I5Q00T0]I1S0;JAI@2eT6@0/hiR0;:=H@2aS600/XeQ0;>>HP2dSf<00P2fTV820;FA
H@030;B@H02cSel0/hmO00T0/hmO00D0^9AP0;NCG`2gTel0]Y9N0;B@G0020;>?F`030;:>FP2cSel0
/hmO00H0/hmO0P2eTEd60;B@G0P0/hiJ2@2bSUh30;B>G`80/heN0`2bS5d80;:=F@<0]91P0P2cSel3
0;:>GPP0/HeM0`2`S5`30;6=G@80/XiN202aSEd30;>?G`030;:>GP2aSEd0/HeM0080/8aL0P2aSEd2
0;2<G080[h]K0P2^RUX20;:>GP<0/8aL00@0/XiN0;B@H02eTF40/i1J0P2cSe/00`2cSed0/hmO0;>>
H@020;>>HP030;>?G`2bSUh0/8aL0080[h]K00<0/8aL0;:>GP2cSel00P2bSUh20;6=G@80/8aL0P2_
Re/80:n;E`@0/HaE102`Re@80;6=F@80[XYF0P2_ReL0102`S5P0/HeI0;:>FP2bSUX80;J<FP@0/HeI
102`S5P90;:>GP030;2;E`2aS5P0/XeI0080/hiJ00<0/XeI0;6<F02`ReL0202dRed20;B@H0<0/hmO
0`2bSUh30;B?F`030;>>FP2bSET0/XeI0080/HaH00<0/hiJ0;:=F@2`ReL00P2^RED01P2_RUH0/8]G
0;6<F02bSET0/HaH0:n:EP80[XUE00<0[hYF0;6<F02bSET00P2dSe/20;>>FP<0/XeI00<0/HaH0:n;
F`2_Re/0102_Re/20;2<G0P0[hYF0`2`S5`30:n;F`80[XYJ00P0/8YK0:n9FP2^R5T0[HMH0:j8F@2_
REX0/H]L0;:<G@80]91L00H0/hmK0;:>FP2aSET0/8aH0:n;E`2^RUH30:n:E@<0[XUD0P2]R5<02P2Y
Q500ZhIB0:n:EP2aS5P0/XeI0;2;E`2^RED0[8MC0;:8EP2aQeD30;26E0030;:8EP2dRUP0]H]I00P0
[HUE0P2^RE800`2^RE@0[XUE0:j8E`020:j8F@060:j8F`2_ReL0[XYF0:j:EP2]RED0[8QD0P2[Qe<0
0`2ZQU80[XUE0:j9E@030:j9E@@0[HQD00@0ZXEA0:b7D`2^RED0/8]G0`2aS5P0102`ReL0ZXIB0:^7
D`2]RED20:j:EP030:f9E@2[Qe<0ZXIB00P0[XQI00P0[HQD0:b7D`2[QU80ZXEA0:^6DP2]R5@0[hYF
0;2;E`P0[8MC00P0Z89E0:V3E02YPe@0ZXAC0:Z5D@2[QU40ZhI?0:b7D0<0ZHA@0P2ZQE430:^6DP<0
ZXE>0P2YQ4d30:R3C0<0ZhMC0`2ZQU820:V5D@80ZhMG0P2/R5P02`2[QeL0ZHEE0:N3D`2VPU80YX9>
0:R4D02ZQU80ZhMC0:b8E02[Qe<0ZXIB00X0ZHEA0`2XQ5020:N3C`80YX9>00<0YH5=0:J2CP2WPdl0
0P2XQ5000`2WPdl0YX9>0:F1C@030:=oC@030:B0CP2UPDl0YH5?0080YX9@202XPdl0202UP4`0YX5=
0:N2CP2XPdl0ZXEA0:^6DP2/Qe<0[HQD202ZQE090:N2C@P0Yh=?00P0YH5=0:B0C02SOd/0Xgm;0:B0
C02VPTh0Z8A@0:Z6DPP0Yh=?202UP4/40:R3CP80Yh9=0P2VPD`20:AoB0030:AoBP2TOd/0Y7i=0080
Y7i?00<0Y7iA0:1oB@2POdT01P2POdT20:F0B`<0Y7m:0`2SOTT0202RODP0Xgi90:AoBP2UP4/0Y7m:
0:=nB@2QO4L0X7]60`2TOd/00`2SOTX0XWe90:5lB0020:1kA`0@09ijAP2ONdL0X7a80:5mB@2PO4P0
Wg]709eiA@2LN4@0XGe90:1lB02ONdL0WWY609mkA`2PO4P0XWi:0:=oB`P0XGa8202PO4P309mjA@80
WWU40`2MN4<01P2RODT0X7]709iiA@2MN4@0W7M309ehA080WWU50P2LN4P609eiB@0609ihB`2MMdP0
WGM809egAP2LMd<0W7M20P2KMSl209]f@P80VWE100d0VgI209ehA02MN4@0X7]70:5lB02PO4P0WWY6
09Yf@P2HM400Ug<o09Ue@@2LN4@0WWY600P0WGU700<0WgY509iiA02MN4<00P2MN4<01P2ONTD0XGa7
0:9mB02QO4P0WgY609iiA@80WGQ400@0WWU509mjAP2QO4P0X7]60P2QO4L01@2RODP0XGa709mjA@2L
Md80VgI10080WWY60P2MNDD409ahA00309eiA@2LN4@0VgM30080VWI200<0VgM309ahA02MNDD00P2Q
Nd`0102PNT/0WgU:09ihB@2MMdP209afA`0309ehC02LMd/0W7M;0080W7M;0`2KMTX409ahB0@0WGU9
00H0WWY609eiA@2MNDD0W7Q409]g@`2JMT8509Ue@@80VWI20`2KMd<02`2NNTH0WGU509ahA02KMd<0
VGE109Qd@02GLcl0UW8n09Ae?`2EMT00UgI10080VWI200H0VWE109]c@02JLSl0Ug<o09Ea?@2CKc/2
099^>P0>09Ea?@2IMD40W7Q409]fB@2IM4L0Ug9509IaA02EL4<0UW5409MbA@2HLdH0TG8l099c?@2E
M3l209Qd@00309Qc?`2HL3d0Ufll00<0V70m0`2GKc`209I^>`80TVhn0P2AKCd5091/?003099^?P2A
KCd0Sf/k0080SFTi00T0SVXj08m[>`2@K3`0SV/e08iZ=P2?JcL0Sf/i08m[>`2?JSd00P2@Jcl0202>
JSP0SFTg08aX=P2;IcD0S6Pf08iZ>02@K3X0TFdk0`2:Jc`308UZ>`80R6Tj00P0SFTi08iZ>P2@K3`0
TFdm091/?02?Jc/0SVXj08eY>@@0SVTl102=J3/208YV=P0408]V>@2;ISX0RfHl08aV?`80S6I10P2<
IcX03P2=J3/0SVTl08mZ?@2@Jch0TF`o099]@02@Jch0SfXm08eX>`2<IcX0SFPk08iY?02?JSd0TF`o
0`2>JC`[ooooo`00:_ooool208QR<`80RF<d0P2:I3D208]U=P0808QR=@29HcH0RfDh08eW>P2<IST0
RV@g08MQ=025Gc8808YS>P0508MQ=028HSD0R68e08US=P2:I3L00P2;ICP01`2<IST0TfPm099W?02@
ICX0SV<h08eR=`2>HcP00P2?I3T208QR=@0408US=P2:I3L0RfDh08]U>080S6Hi00/0R6<f08US=P2:
I3L0S6<g08iS>02@HcT0TV<i09=T>P2BIc`0TFHk08mT>@0208iS>00;08mT>@2AIS/0TVLl08]V<@2<
Ic80SFPc08iY=02?JSD0T6/f095/=`2BKCP01`2CJ3/2099W>P0@09=^>P2DKc/0Ug8n09Ud@02JMD40
VGA009Qc?`2GLSh0UG5109A^?`2CKCh0TfXl09AY?02GJch0VV/o09a]@@80VVm2102IKT4209Q]@080
VG=40P2HLT<0102GLD80UW1109E_@02EKd0309Q]@080VFi10`2JKd800`2KL4<0VFi109M/?`0209I[
?P0309Q]@02KL4<0WG9500P0VVm20`2HLT<509Ma@P80VW0n0P2KLCl209ab@080WG=1202LLcd0202J
MD00VgI109ag@P2LMd80VgI109Ud?`2GLSd0UW4l0P2QN4@30:1g@`<0WgI200P0UW4m09Mb?P2HLcl0
VGA009Qc?`2GLSh0UG0l09A_>`P0WG=100<0W7<o09ie@@2OMT800`2QN4@01@2PMd<0WgI209UcAP2I
LdH0VWA70080VgE800<0W7I909egBP2MMdX0202JMD480:5gA@80Y7Y800<0XgU70:9hAP2QMdD00`2P
MT@02@2OMD<0VgI209]f@P2JMD40VGA009Ye@@2LMd<0WWU50:1kA`080:9hAPT0Y7]700L0XgY60:5h
A02QN4@0XGQ40:=jAP2UO4P0YWe900P0XGa700H0Z7m;0:MnBP2VODT0YGa80:AkA`2RNDD20:5hA003
0:=nBP2RODT0XGa80080WgY600T0XGa80:9mB@2SOTX0YH1;0:AoBP2SOTT0XWe80:5lA`2PNdH00P2O
NTD20:AkA`80YGa80P2VODT20:MnBPP0Z7i<202UP4`0202TNdL0YGa80:MnBP2XOd/0ZH1<0:QoB`2W
OTX0YWe9202XOd/80:QnC0P0ZGm=00H0[85F0:b1E02/PE@0[89B0:b2D02/Pdl20:b3C@<0Z8=?1@2Y
Q5080:b3C`T0ZXEA0P2[PTh20:b3C`@0[HA@0`2YQ4l50:R3CP80[8M@00H0ZhIA0:Z5D@2ZQ5<0ZH=D
0:R2D`2XPUD80:V4D080ZXEA0`2[QU830:b7D`80[8AP00T0[8EL0:^4F@2[QEH0ZhIB0:^6D@2[QTl0
[HQD0:b7D`2ZQE400P2XPdl00`2YQ500ZXEA0:^6DP040:f8E080[XUE0P2_RUH00`2^RED0[8MC0:^6
DP020:Z5D@040:b7D`2^RED0/8]G0:f8E080[XUE00D0[hYF0;2;E`2aS5P0/HaH0;:=F@030:f8E0<0
[XUE0P2_RUH80:j9E@060:j8F`2^R5T0[XQI0:n9F02_RUH0/8]F0P2`Re@30;2;E`80[hYF0`2^RED8
0:n;E`P0/8YK202cSEh80;2:F`<0/XeI0`2cSUX30;B?F`<0/HeM1@2bSUh30;6=G@<0/XiN0P2cSel0
1@2lUVL0^YAU0;J@H@2cSEh0/H]L0080/8YK00X0/H]L0;F>H`2fSf@0]i5T0;NAHP2gTF00]I1L0;>>
FP2bSEP0]Y5M0P2eT5`00`2cSUX0/XeI0;6<F0020;2;E`050:n:EP2`ReL0/8]G0;6<F02bSET00P2c
SUX00`2dSe/0/8]F0;2;EP070;2;EP80/8]G00<0/H]J0;6;G02bS5l00P2bRf040;6=F@@0/8aH0P2`
ReL20;6<F080/XeI0P2cSUX80;>?F`80/hiJ00<0]8mK0;F@G02fTEd00P2hTel00`2iU600]I1L0;F@
G0060;F@G0030;6=F@2bSUX0]91L0080]I5M00<0]91L0;:>FP2aSET00`2aSET30;:>FP80/hmK0`2d
T6020;>?G`<0/XiN202bSET30;6=F@<0/XiJ0P2cSe/80;B@H0<0/HeM0P2bSUh20;>?G`X0]91P202c
Sel20:n;E`040;6=F@2bSUX0]91L0;FAG@80]i=O0`2dT6030;FAH@80]Y9R0P2fTUh20;FAG@0<0;B@
G02cSe/0/hmK0;:>FP2fTed0/XmI0:j:F02]RET0[XUM0;2:H`2aRfH0/8YV202eTEd80;B>H@80[i1J
00H0/I1K0;B@G02eTEd0]i9N0;VAGP2jTUl30;F@G080]8mK0`2cSUX20;>@F0030;BAF`2dT5`0]91N
0080]I5Q00@0]I1S0;JAI@2eT6@0/hiR0P2aS6000`2bSF40/hiR0;B?H`020;JBHP80]I5Q00@0]91P
0;>?G`2cSel0/XiN202cSV420;VEH@040;RDH02gTel0]I5M0;B@G080/hmK202cSel30;FAG@D0]91L
202cSUX30;>?G`<0/XiN0`2aSEd20;B>G`<0/heN0`2bS5d80;:=F@80]I5Q00@0]91P0;>?G`2cSel0
/XiN2P2aSEd01@2^RUX0[h]K0:n;F`2`S5`0/HeM0080/XiN00<0/hmO0;6=G@2aSEd0102`S5`20:n;
F`040;B@H02cSel0/hmO0;:>GP80/HeM0P2`S5`20;6=G@80/8aL00d0[h]K0:j:FP2^RUX0[HUI0;>?
G`2bSUh0/8aL0:n;F`2`S5`0/XiN0;B@H02eTF40/i1J0080/hmK00<0/hmM0;>?G`2cSV400P2cSV80
0`2cSel0/HeM0;2<G0020:j:FP030;2<G02aSEd0/hmO0080/XiN0P2aSEd20;2<G080[h]K202_ReL2
0:n:D`<0/8]D0`2aS5D80;6=F@060:^7D`2/R5@0[HUE0:j:EP2_ReL0/HeI0P2bSUX80;N;FP@0/HeI
102`S5P90;:>GP030:n:EP2`ReL0/hiJ0080]I1L00<0/hiJ0;2;E`2_RUH0202dRed30;B@H080/hmO
0`2bSUh0102eT5`0]8mK0;B?F`2cSUX20;:=F@80/HaH00<0]8mK0;>>FP2aS5P00`2_RUH20;6<F003
0;:=F@2aS5P0[hYF0080[XUE00<0[hYF0;6<F02bSET00P2dSe/20;>>FP@0/XeI1@2_Re/30;2<G0P0
[hYF0`2`S5`30:n;F`80[XYJ00<0/8YM0:n9G02]QeX00P2]QeX02@2_RE`0/H]N0;:<G`2eTEd0]91L
0;>?F`2bSUX0/HeI0;2<F0020:n;E`<0[XUD0`2]R5<20:b7DP0:0:R3C`2ZQE40[XUE0;6<F02bSET0
/HaH0:j9E@2/Qe<0/hMF0;:6E@80/HED00@0/XIE0;>7EP2eREP0]h]J202]RED20:j9DP030:j9E02^
RED0[XQG0080[XQI00T0[XQK0;2<F02`S5P0[h]G0:f9E@2/R5@0ZhMC0:Z6DP2YQE401P2^RED30:f8
E0040:Z5D@2[QU80[XUE0;6<F080/XeI00D0/HaH0;2;E`2YQE40ZXIB0:b8E0020:f9E@030:b8E02Z
QU80ZHEA00P0[XQI00P0[HQD0:b7D`2ZQE40ZXEA0:^6DP2]R5@0[hYF0;6<F0P0[8MC00H0Z89E0:R2
D`2YPe@0ZXAC0:Z5D@2[QU420:b7D080Z8=?00@0ZHA@0:Z5D@2ZQE40ZhIB0P2/Qe<20:^6C`040:Z5
CP2YQ4d0Z8=<0:R3C080Yh9;0`2[Qe<30:Z6DP80ZHEA00/0[8MJ0:f8F`2^RE`0[HQK0:b7FP2YQ5L0
YX5D0:AoDP2WPdl0Z8A@0:^7D`030:f9E@030:^7D`2ZQU80ZHEA00L0ZHEA00@0ZXIB0:V5D@2YQE40
ZHEA0P2XQ5020:N3C`030:F1C@2VPTh0Yh=?0080Z8A@00<0Yh=?0:J2CP2UPDd00P2ROT`0102SOdd0
Y81>0:B0CP2UPDl20:J2D0P0ZHA@00P0Xgi:0:AoB`2VPDd0Z8=?0:Z5D@2/Qe<0[HQD0:j9E@P0ZXE@
2@2VPD`80:N3C`80Xgm;0P2ROTX0102TP4`0Yh=?0:Z6DP2/R5@80:N3C`P0YH1;00@0ZHA?0:R3CP2X
Pdh0Z8=>0P2WPTd20:J1C080Y7m800<0Y7m:0:AoB`2TOTd00P2TOTl00`2TOU40X7m90:1oB@060:1o
B@80YH1;0`2TOdX30:=nB@0C0:9mB02SOTT0Y7m:0:F0B`2TOdX0Xgi90:5lA`2PNdH0YX5=0:F0C02T
Od/0Xgi:0:9mB@2QO4P0X7]709mjAP2NNTH0Wg]70:1lB0020:5mB@0609mkA`2MNDD0W7Q40:5mB@2P
O4P0Wg]70P2NNTH00`2PO4P0XWi:0:B0C0050:5lB0<0XWe9202PO4P209mjA@80WWU40`2MN4<01@2L
Md80Xgi:0:9mB@2PNdL0WWU50080WGQ400<0WWU509mjAP2NNTX00`2MNDT309ahB00709]gA`2MMdX0
WGM809egB02MMdH0W7M309ag@P0209]f?`80VWE10P2IM400202JMD40WGQ409ehA02ONTH0XGa80:5m
B@2NNTH0VWI20P2GLcl00`2IMD40W7Q409ijAP0809eiA`0309mjA@2NND@0WGQ30080WGQ300H0WgY5
0:5lA`2RODP0XGa809mjAP2NNDD209ehA00509iiA@2ONTH0XGa809iiA02ONTD00P2QO4L0102PNdH0
WWU409]f@@2JMD0209ijAP80WGU50`2LN4@0102KMd<0WWY609ahA02JMT8209Ue@@0309Yf@P2LN4@0
WWY600<0XG]>00D0X7Y=09miC02MMdX0W7I909]eB00509]fBP<0VWE9102LN4P409eiB@0609ijAP2M
NDD0WGU509ahA02KMd<0VWI21@2IMD4209Yf@P<0VgM30P2NNTH0102LN4@0VgM309Ue@@2HM40209Ib
?P0309Ae?`2EMT00UgI10080VgM300l0VWE109]c@02JLSl0Ug<o09Ib?P2CKc/0TVhj09=_>`2GLcl0
VgM309ijAP2LMdX0VWE809QcAP2FLD@00P2EL4<01@2GLTD0V7=6095b?02BLcd0UG@o0080V7A000P0
V7<o09Q`?@2GKc`0VW8o09Ua?P2HL3d0Ufll09I^>`<0UFdj0P2AKCd2091/?080Sf/k0`2>JSX00`2B
KSh0TFdm08m[>`0308eY>@0308iZ>P2?Jc/0Sf`f0080Sf/g00<0Sf/i08m[>`2?JSd00P2>JCd208eY
=`0608aX=P2;IcD0S6Pf08iZ>02@K3X0TFdk0P26JSX00`25JCT0Q6Ph08=W=`02089V=P09085U=@2>
JSX0Sf/k091/?02AKCd0T6`l08m[>`2=JCT0S6Ph00@0SVTl102=J3/208YV=P0408YU>02;ISX0RfHl
08aV?`80S6I10P2<IcX00`2=J3/0SVTl08mZ?@02095/?`04099]@02@Jch0SfXm08iY?080SFPk00<0
SVTl091[?P2AK3l00`2>JC`[ooooo`00:_ooool308QQ>00308UR>@2:HcX0Rf@k0080Rf@k0P2BISl0
102AICh0T6@m08iR>`2=HCX208aP>@P0RV<j0P2;H3D208aQ=P80SF8g0P2>HcP2095V>`0>091U>P2>
HcP0SF8g08aQ=P2;H3D0RUld08IP<`27HC@0R68e08US=P2:I3L0RfDh08aV>@2=IcX208aR<P0308eS
<`2>I3@0SfDe0080T6Hf00T0TFLg08YS?02;I3/0SFHm08iW?02>J3/0SFLh08]U=02:I3<00P2?JSD2
08iY=00708eX<`2<Ic80S6Lb08]V<@2CIcH0UFTh09IZ>@0309M[>P0309IZ>@2CIcH0TVHe0080UVXi
0P2GJcX309Q/>`0409U]?02MLd40Vg4o09U_?@80Ufdk00<0V6hl09Y`?P2KLCl0102IL3`209Q_>`80
Ufhj0P2JL3h409U_?@80V6hl00<0Vg4o09Y`?P2HKS`00P2GKC/00`2HKS`0VW0n09]a?`0309]`@`03
09Y_@P2IKT40V6e00080V6e00`2DKSl309E_@080UW1100@0V6e009U^@@2IKT40VVm20P2KL4<209aa
A0P0Ug8n00P0W79009]a?`2JL3h0VFlm09Y`?P2KLCl0WG=109id@PP0WGA0202MLd4309me@`80WWA2
0`2MLd4209ag@00309]f?`2JMCh0VG@m0080V7<l00D0Ug8k09Ye@@2KMT80VgI209ag@`0209ehA080
WWU50`2LLT0309ec@@80WWA20P2KMT8309ag@`<0WGQ40P2NM48209me@`@0X7I400<0WgY609iiA@2M
N4@00P2LMd<209ehA00309iiA@2ONTH0XGQ400L0XGQ40P2SNTH30:AkA`<0YGa80P2PMd<20:5hA00?
0:9iA@2SNTH0XgY60:AkA`2TOd/0Xgi:0:5lB02ONTH0X7]70:9mB@2UP4`0Yh9>0:5lB02RODT0Xgi:
0080YH1<00<0Y7m;0:=nBP2RODT00`2TNdL20:=jAP<0XWU50`2ONTD20:1kAP<0XGa7102RODP40:=n
B@P0Yge;202YP4`80:QnC080Z7m;0`2YP4`30:Z1C@040:MnBP2XOd/0Z7m;0:V0C080ZX5=0P2[PTh2
0:Z0D0040:Z0CP2ZPDd0ZX5=0:Z1B`80ZX59202ZPDd0402WOD/0ZGm=0:^1C`2/PU00[H=A0:b2D02[
PDl0ZX1>0:ImB@2WOTX0ZH1<0:^2CP2/Pdl0Zh9>0:V0C02XOd/80:R3CP80[89@00@0Zh5?0:Z0CP2Z
P4h0ZGm=0`2XOT`30:^2CP<0[8=?0P2]Q5020:Z5D@<0ZHA@0`2XPdl01P2WPUD0Z89C0:V3E02/Q5<0
[H=A0:n4D@80/XA@202]Q5000`2_QU80[HA@0:^2CP020:Z1C@030:b3C`2_QU80/HQD00P0[HA@202]
Pe480:b7D`P0ZXE@00P0/XeF0;2;E02^RE@0[8MC0:b6E@2^R5T0/8YK0;:<G`P0[hYF0`2`SEL30:n<
EP80[X]E0`2]R5@30:j9E@80[hYF0`2^RED30:f8E080[8MC0P2bSEP20;6<E`040;2;EP2_RUD0[hYE
0:j9E0@0/HaE102bSEH03P2gTUh0]Y5M0;B?F`2cSUX0/XeI0;>>FP2dSe/0]I1L0:j;E@2^RUH0[h]G
0:n;F@2_Re/0/8]N0P2`Rel20;6=G@80/8aL00<0[h]K0:j:FP2^RUX00P2]RET80;:=H080[h]K00<0
/8aL0;6=G@2bSUh00P2dT6000`2eTF40/heN0;>=GP060;>=GPP0^8aK0P2cSUX20;:=F@80/HaH0P2`
ReL80;>>FP80/XUE0`2cRUH30;B;E`060:f8E02^RED0[XUE0;2;E`2aS5P0/XeI0P2cSUX80;:=F@P0
/HeM202cSEh80;>>FP080;B?F`2cSUX0/XeI0;:=F@2cSUX0]8mK0;JAG@2hTel20;JAG@040;F@G02d
Se/0]8mK0;>>FP80/XeI00<0]91L0;FAG@2fTUh00P2fTUh00`2dT5`0/XiJ0;6=F@030;:<G@<0/heN
0P2dSUl00`2`ReL0/HaH0;>>FP020;F@G0030;B?F`2bSET0/HaH00<0/XaM0`2cSEh20;B>G`80]91P
0P2eTF430;JBHP030;NCH`2bSUX0/XiJ0080/hmK00<0]91L0;FAG@2eTEd00P2fTUh80;>?F`80/XiB
0P2bSU@01P2bSEH0/XeH0;:=F@2bSET0/XiN0;6=G@80/8aL00l0/HeM0;B@H02gTf<0^9AT0;:=H@2c
SV80/hiQ0;B@H02eTEl0]I5M0;JBGP2fTed0/X]P0;><H@2eSV<00P2fSf@00`2eSV<0/haQ0;:;H003
0;:>FP<0/HeI0P2`S5P00`2dT600/hmO0;:>GP020;6=G@030;>?G`2dT600]I5Q0080]8mK0`2eT5`3
0;JAG@P0]8mK0`2dT6020;>?G`<0/XiN0`2fTEd50;F@G080/i1J0`2bSeT30;6>F080]Y9R0P2eTF40
0`2dT600/hmO0;>?G`020;:>GP0:0;>?G`2eTF40]Y9R0;JBHP2eTF40/hmO0;:>GP2cSel0]91P0;JB
HP80^9AT00<0]i=S0;FAH@2dT6000`2bSUX20;>?F`<0]91L0P2hTeh00`2gTUd0]Y5L0;F@F`020;>>
F@040;:=F02`S5`0/HeM0;>?G`<0]I5Q00<0/hmO0;:>GP2cSUX00`2cSUX30;:=F@80/HaH202cSUX2
0;2:F`030;6;G02bS5d0/heN0080]HmP00@0]Y1Q0;F?H02eSf00]HmP0P2dSUl30;>=GPT0/XeI00L0
/hiJ0;B?F`2eT5`0]8mK0;>>FP2aS5P0/8]G0080/heN00@0/XaM0;6;G02aRe`0/8YK0P2_REX20;>>
FP80/XeI0P2aS5P20;2;E`030;B?FP2bSEP0/8]F0080[XUD00<0/8]F0;:=F02dSeX00P2bS5d20;6;
G0050;2:F`2_REX0[hUJ0:j8F@2dT6000P2cSel00`2bSUh0/HeM0;6=G@020;2<G080]HmP00<0]8iO
0;>=GP2bS5d00P2aRe`0102`RU/0/HeM0;6=G@2aSEd20;2<G0<0[h]K00P0]95K0;:?F@2`SEL0[haF
0:j;E@2_S5H0/8eG0;6>F080/hmO00@0/XiN0;6=G@2`S5`0[h]K0P2^RUX40;2;GP80[hYM0P2^RE`0
0`2eREP0]8QG0;:6E@020;:6E@040;B8E`2gReX0^8aK0:n:EP80/8]G00D0/HaH0;:=F@2cSUX0/hiJ
0;B?F`080;>?G`H0[h]G0`2`S5P0102dT5`0/hmK0;>?F`2bSUX20;6=F@80/8aH202aSET0202aS5P0
/8]G0:n:EP2_RUH0/8]G0;:=F@2eT5`0]i9N202cSEh80;6=F@080:f9F@2^RUX0[h]K0;2<G02aSEd0
/XiN0;>?G`2dT6020;B?F`040;>>FP2bSET0/HaH0;2;E`80[hYF0`2]R5`20:j9G@<0[hYN202]RET2
0;6=F@<0/8aH0`2_ReL20:n9FP<0/8YK0`2aRe`30;2<F0<0[h]G0P2^RUH01@2^REd0[hYN0:n:GP2`
Rel0/HaP0080/XeQ00<0/hiR0:f9E@2]RED01P2]RED30;2;EP80[hYE0`2^RE@20:b:C@040:b9C`2]
RU00[HYB0:f:E080[XYF00H0[8MJ0:b8F02/R5P0[8QF0:b8E02/RE<20:b9D@<0[XUE0P2]R5@30:b7
D`030:f8F`2[QUT0ZXEH00<0ZHAG00<0ZhII0:f8F`2_RUd0202]R5@20:b7D`80[HQD00@0[XUE0:n:
EP2_RUH0/8]G202/R5P0202/Qe00ZhI?0:Z5CP2YQ4d0ZXE>0:^6C`2]R540[XUB202_Pe830:N3D`80
Z8AD0`2YQED20:^6DP040:Z5D@2YQ500Z8=?0:R3C`80Yh9>00T0ZhM;0:^7C@2[QTl0ZhIA0:^5E02/
QUT0[8EJ0:b5G02XQDl00P2XQ5000`2YQE<0ZHEE0:Z5F0020:Z5F@80Yh=?00@0Z8A@0:V5D@2YQE40
ZXIB0P2[Qe<80:Z6DP040:^6DP2ZQE40ZXEA0:Z5D@80ZHA@0P2XPdl0202YQ4l0Z8=>0:N2C@2VPD`0
Yh9=0:R3CP2ZQE00ZhIA202VPDd30:N2CP<0YX5=0P2UP4`20:J1C080Yh9=0`2XPdh00`2YQ4l0Z8E?
0:R5C`060:R5C`P0Z8=?0P2YQ5020:R3C`<0Yh9>0P2VPDd50:J1C0<0Yh9=0P2UPTX0202VPdd0YX9>
0:N3D@2WPe<0Z8AD0:R3EP2TP4`0YH5=0`2WPdl01`2UPDd0XWi:0:5mB@2WPTd0YX5<0:AoBP2RODP0
0P2QO4L0102RODP0Xgi90:J2CP2VPTh20:F1C@<0Y81<00@0Xgm;0:F1C@2UPDd0YH5=0P2TP4`30:=o
B`060:AmDP2TOU40Y7iA0:AnC`2TOTd0Y7m;0P2TOdX0102QOD<0XWi40:9nA02ROT@30:=oA@060:B0
AP2UP4T0Y7m80:AoB02SOTL0XWe60P2QO4D00`2PNd@0XGa70:5lA`060:5lA`040:F0C02TOd/0XWe9
0:1kA`80WgY600D0X7]70:5lB02SOTX0XGa809mjAP0209ehA00909mjAP2QO4P0Xgi:0:EhCP2UND`0
Y7Q;0:=gB02SMdH0Y7U60080YGY51P2QO4L20:9mB00309eiA@2LN4@0VgM30080VGE100<0VgM309ah
A02MNDD00P2NNdD209ejA0<0W7U300H0VgQ20:1kA`2ONTH0WgY609iiA@2MN4@209ag@`0309]f@P2O
NTH0WWU50080WWU50P2MN4@209ag@`0309miBP2NN4T0W7I70080VWA50P2KMDH00`2MMdP0WWQ909ah
A00709ahA00309Qd@02JMT80W7Q40080WGU500<0W7Q409Yf@P2HM4000P2ONTh00`2ONTd0Wg];09mk
B@0209mkA`0409mlAP2NND@0WWU409iiA0<0WgY50P2PNdH20:9k@P0709mk@@2NNd40WGY009Yj?`2I
Ncl0V7Xn09UnA`0209]mA`0309amA`2MO4L0Wg]70080X7]7202NODL20:5lA@030:1kAP2ONTH0WWQ7
0080WGM800X0W7I90:5mB@2QODT0X7a809ijAP2MNDD0W7Q409]g@`2JMT80VGE50P2JMTH00`2KMdL0
W7Q809ahB00209eiB@0609ijBP2MNDT0WGU909ahB02KMdL0VWI60P2IMDD00`2FLT80V7A409UeA@03
09]gA`0809YfAP2IMDD0WWY609ijAP2LN4@0VgM309Ue@@2HM40209Ib?P0;09UeA@2HM4@0UW9209Ea
@@2DL400UG5109Ib@P2GLd<0TVhn09=_?`2ELD400`2FLT801@2DL400Tflo09U`@P2IL480Ug520080
UW9200<0U79209=c@P2CLd800P2JM4D209UcA00409Qb@`2GLD80Ug5209Ma@P80U6lk0P2CKSX01`2B
KCT0TF`h095/>02@JcL0SVXj091/?02BKSh00P2CKcl01@2AKCd0SVXj08iZ>P2<J3P0T6`l0080TVhn
00D0SVXj08UU=@28I3@0RfLg08m[>`02099/?@04095[?02@JS/0SfTj08mY>P80SVPi0`2?JSd00`2>
JC`0SFPk08aW>P0208aW>P80S6To0P2;J3h02P2:Icd0RFHl08UV?028IC/0RfP^08]X<02;J380RfLe
08]V>@2;ISX208]U?P<0SFPk1@2<IcX00`2;JC/0RFLi08QV>00308IT=P0=08QV>029IcT0S6Pf08aX
=P2=JCL0SVXh08m[>@2@K3X0TFdk099^?02BKD00TF`o08mZ?@0208iY?00308mZ?@2AK3l0TVe000<0
SfXe:oooool002[ooooo0P28HCP208UR>@80RV<j0P2;I3/2095U?P04091T?@2?Hc`0SV8k08eQ>P80
S60i202:HcX208]P=@80S64f0P2=HSL208iS>080T6Dj00@0Sf@i08iS>02=HSL0SF8g0P2<HCH208MQ
=00408QR=@29HcH0RV@g08]U>080S6Hi0P2>I3@308mU=@<0T6Hf00P0RV<l08]T>`2=ISd0SVLl08iX
>`2=IcP0RfDd08YT<`80SfXf0P2>JCD01`2=J3@0S6Lc08aW<`2<Ic<0U6Pg09EY>02FJST00`2GJcX0
0`2FJST0U6Pg09=W=P0209IZ>@80Uf/j102HK3/00`2JL3h0VFlm09M]>`0209I/>P0309Q^?02IKcd0
VW0n00<0V6hl0`2GKC/209I/>PH0VFlm0P2HKS`00`2KLCl0VW0n09Q^?00209M]>`0309Q^?02JL3h0
Vg4o0080VVm20P2IKT4209Q]@080Uf`o0`2DKSl309E_@080UW1100<0V6e009U^@@2IKT400P2JKd82
09]`@`0309aaA02GLSh0Ug8n00H0Ug8n00P0WG=109ab@02KLCl0VW0n09U_?@2JL3h0W79009ec@@P0
WGA0202MLd4309me@`80WWA20`2MLd4209]f?`<0VWDn0`2IM3d00`2JMD40VgI209]f@P0209ag@`80
WGQ400@0WWU509ab@02LLT00W7900`2MLd4209id@P80VgI20`2LMd<309ehA080WWA20P2OMD<30:1f
A0040:5gA@2ONTH0WWU509ehA080W7M30P2MN4@00`2NNDD0WgY60:5hA0070:5hA0<0XgY60P2TNdL3
0:ElB080X7M30P2QN4@0102RNDD0XgY60:=jAP2SNTH20:9mB@<0XGa800H0XWe90:AoB`2UP4`0X7]7
0:5lB02RODT20:AoB`030:=nBP2RODT0XGa800P0XgY60P2ONTD30:1kAP<0XGa70`2SOTT50:9mB0P0
Yge;202YP4`80:QnC0<0Z7m;0P2YP4`30:Z1C@030:MnBP2XOd/0Z7m;0080ZH1<0P2ZPDd0102[PTh0
ZX1@0:Z0D02ZP4h20:Z1C@030:Z1B`2ZPDT0ZX5900P0ZX5=00/0Yge;0:UoC@2[PDl0[89@0:f3D@2/
PU00Zh5?0:Z0CP2VODT0Ygi:0:V0C0030:^2CP80ZH1<202XPdh00`2]Pe40[89@0:b2D0020:^1C`<0
ZX1>00@0ZGm=0:^2CP2[PTh0Zh9>0`2/Pdl20:f4D080ZXEA0`2YQ5030:R3C`060:N2E@2XPU<0ZH=D
0:^3DP2]Pe40[hAA0P2aPdl:0:f4D0<0[8=?00<0[HA@0:n6DP2`Qe<01@2]Q5030:j5D@P0[H=A202/
Qe<80:f8D`080;2;E02_RU<0[XUD0:j9E@2^R5L0[XQI0:n9FP2`RUd80:n:EPP0[haF0`2]R5@20:j9
E@H0[hYF0`2^RED20:f8E080/XeH0P2aS5L0102`ReH0[hYE0:n:E@2_RUD50;6<E@<0/XeF00h0]Y5M
0;F@G02cSUX0/XeI0;6<F02bSET0/hiJ0;B?F`2^ReD0[XYF0:n;E`2_ReT0[h]K0;2;GP80/8]O0P2a
SEd20;2<G0030:n;F`2^RUX0[XYJ0080[XYJ202bSF020:n;F`060;2<G02aSEd0/XiN0;>?G`2dT600
]I5Q202cSEh80;N=F`80/hiJ0P2bSET20;6<F080/8]G202bSET00`2dReL0/hYF0;>:EP050;>:EP06
0:f8E02^RED0[hYF0;2;E`2aS5P0/XeI0P2cSUX80;:=F@P0/HeM202cSEh80;>>FP030;B?F`2cSUX0
/XeI0080/XeI00<0]8mK0;JAG@2gTUh00`2eT5`00`2dSe/0/hiJ0;>>FP020;:=F@030;B@G02eTEd0
]Y9N0080]Y9N00<0]91L0;:>FP2aSET00`2bS5d20;>=GP<0]8iO00P0/8]G0;6<F02cSUX0]8mK0;F@
G02dSe/0/XeI0;6<F0<0/XaM0`2cSEh20;B>G`80]91P0P2eTF440;JBHP@0/hmK00<0]91L0;FAG@2e
TEd00P2fTUh80;>?F`80/XiB00<0/XiD0;:=EP2bSEP00P2bSET00`2bS5/0/XiN0;:>GP020;6=G@04
0;:>GP2dT600]Y9R0;RDI080/hiR00T0/hiQ0;B@H02eTEl0]I5M0;JBGP2fTed0/X]P0;><H@2eSV<0
0P2fSf@00`2eSV<0/haQ0;:;H0030;>?F`<0/XiJ0P2aSET00`2dT600/hmO0;:>GP020;6=G@030;>?
G`2dT600]I5Q00<0]8mK0P2eT5`30;JAG@P0]8mK0`2dT6020;>?G`<0/XiN0P2fTEd60;F@G0<0/hmK
0P2bSUX30;6=F@80]Y9R0P2eTF401`2dT600/hmO0;>?G`2cSel0/XiN0;>?G`2eTF400P2fTV801P2e
TF40/hmO0;:>GP2cSel0]91P0;JBHP80]i=S00<0]Y9R0;FAH@2dT6000`2bSUX20;>?F`<0]91L00D0
^9=O0;NBGP2gTUh0]Y5M0;B?F`020;>>FP040;:=F@2`S5`0/HeM0;>?G`80]I5Q00<0]91P0;>?G`2b
SUh0102dSe/30;>>FP80/XeI202cSUX20;2:F`060;6;G02bS5d0/heN0;B>G`2eSf00]Y1Q0P2eSf03
0;B>G`<0/heN2@2bSET01`2cSUX0]8mK0;F@G02dSe/0/hiJ0;6<F02`ReL00`2cSEh20;:<G@<0/H]L
0P2cSUX20;:=F@80/HaH0P2`ReL00`2cSUT0/XeH0;6<E`030;6<E`040;:=F02cSUT0/XaM0;:<G@80
/H]L0P2`RU/20:n9FP<0/hmO00<0/XiN0;6=G@2aSEd00P2`S5`20;B>G`<0/heN0`2bS5d30;:>GP80
/HeM0`2`S5`0202dTE/0/XmI0;2=E`2_S5H0[X]E0:n<EP2`SEL0/HiH0P2bSUh20;6=G@80/8aL0P2_
Re/0102aSEd0/8aL0;2<G02`S5`20:n;F`80[XYJ00P0]8YH0;>9E`2bR5H0/HME0;:8EP2cREL0]H]I
0;N=F`@0/HaH102bSET80;>?G`L0[h]G0P2`S5P20;>?F`80/XiJ0P2aSET20;2<F0P0/HeI00P0/HaH
0;2;E`2_RUH0[hYF0;2;E`2bSET0]I1L0;JAG@P0/heN202aSET01P2]RET0[XYJ0:n;F`2`S5`0/HeM
0;:>GP80/hmO00H0]8mK0;>>FP2cSUX0/XeI0;6<F02`ReL20:n:EP<0[HQL0P2^REd30:n:GPP0[HUI
0P2`S5P30:n;E`<0[XYF0`2_REX20;2:F`<0/H]L0`2`S5P30:n;E`80[XYF0P2_RUh30;2;G`<0/HaP
202]RED20;2;EP<0[hYE0`2^RE@20:b:C@070:b9C`2]RU80[HYD0:f9E@2^RUH0[XYH0:b7FP020:b8
F0030:b8EP2/R5@0[8UC0080[8UA0`2]R5@20:b7D`<0ZhIB00<0[8QH0:^7E`2ZQUH00P2YQED0102Z
QUH0ZhMG0:f9F@2_Re/80:f8E0030:b7D`2]R5@0[HQD0080[XUE0P2_RUH00`2`ReL0[8QH0:b8F006
0:b8F0080:b7D02[QTl0ZXE>0:V4C@2ZQDh0ZhI?0:f8D@2^RE880:j4DP<0Yh=C0P2XQ5@30:V5E@<0
ZXEA0P2YQ5030:R3C`80ZhM=00@0ZhI?0:^6DP2[QE@0ZhEH0P2[Q5T01P2XQDl0Z8A@0:R4D02YQE<0
ZHEE0:V4E`80ZXEI00<0Yh=?0:R4D02XQ5000P2YQE420:Z6DP030:^7D`2ZQU80ZXIB00H0ZXIB102[
QU820:Z5D@80ZHA@00P0Yh9=0:J1C02UP4/0Y7m:0:F0B`2VPD`0Z8=>0:V4C`P0YX5=0`2WPTh30:J1
C@80YH1<0P2VPD`20:N2C@@0Z8=>202XQDl80:R3C`80ZHA@0P2XPdl30:N2CP80YX5=1P2VPD`20:N2
C@80YH9:01H0YX==0:J2CP2WPe40Yh=C0:R4E02XPeH0YH5=0:J2CP2WPdl0Z8A@0:N3C`2UPDd0Xgm;
0:9nBP2XPdh0Yh9=0:F0B`2SOTT0XWe80:=nB@2TOdX0YH1;0P2WPdl20:J2CP<0YH5=2@2TP4`20:An
D@80Y7i?00@0Y7i=0:AoB`2TOdX0Y7m:1P2SOdD20:9nA0@0Xgi7102RODH80:5lA`040:F0C02TOd/0
XWe90:1kA`80WgY600@0X7]70:5lB02QO4P0XGa8102ONTH20:5lB0060:=hC@2SN4/0XgQ;0:AjBP2T
NTP0XgY60P2SNT@20:9mB0@0XGa70P2PNdH00`2MNDD0W7Q409]g@`0209Yf@P0309]g@`2LN4@0WGU5
0080WW]50P2MNT@409ai@`@0WWU5102MN4@409iiA@80WGQ40P2LMd<00`2NN4T0WGM809]eAP0209Yd
A@80VgE600<0W7I709ihB@2LN4@01`2LN4@00`2JMT80VgM309ahA00209eiA@0309ahA02KMd<0VWI2
0080W7M;00<0W7M:09ahB02LN4H00P2LN4@0102LND<0WWU409iiA02NND@309mjA@80X7]600<0Xga3
0:9k@P2PO4800P2NNd40102KNd00VWa009Uk?`2IOTL209]mA`0309amA`2MO4L0Wg]70080X7]7202N
ODL20:1kA00309mjA@2ONTH0WgU80080WWQ900D0WWQ;0:1lB02PO4P0Wg]709ijAP0209eiA@80W7Q4
0`2JMTH00`2KMdL0W7Q809ahB00209eiB@0609ijBP2MNDT0WGU909ahB02KMdL0VWI60P2IMDD00`2G
Ld<0VGE509YfAP0309ahB00809]gA`2JMTH0WWY609eiA@2LN4@0VgM309Ue@@2GLcl209Ib?P0309Ue
A@2HM4@0UW9200<0UG5100D0Ug=309QdA02CKcl0U71009Ib@P0209Mc@`0309Ib@P2ELD40U7100080
VG1200@0Ug5209Ib@P2FLT80U7920P2CLd8209YdA@80VG=400@0V79309Ma@P2GLD80UW110P2DKc/2
09=^>P80TVdi0P2AK3P00`2@K3`0TFdm095]?@02095]?@05091/?02>JSX0SVXj08iZ>P2@K3`00P2A
KCd01@2>JSX0RFDe08QT=02;IcL0Sf/k00<0TF/l0P2@JS/308mY>P80SfXm0P2>JC`208eX>`80S6Lj
0P2<JCl208]X?P0408YW?@29IS`0RFHl08UV?080RfP`00H0RfLc08]W=@2;IST0RfHj08]V?02;ICh2
08eX>`H0S6Lj00<0RVPj08QV>027ICL00P26I3H00`27ICL0RFLi08YX>P0208eY=`80SVXh0P2?JcT2
091/>P0308iY?02=J3/0S6Lj0080RfHi00<0S6Lj08eX>`2>JC`00`2>JCD[ooooo`00:_ooool01028
HCP0RF8i08UR>@29HST308YS>P0508]T>`2@I3d0T6@m08mS?02>HS/00P2=HCX208aP>@P0RV<j0P2;
H3D208aQ=P80SF8g2@2>HcP01P2=HSL0Qf4d08QR=@28HSD0RF<f08YT=`80RfDh00<0S6Hi095V>@2A
IST00P2AIST3091U>00708mT=`2;I3d0Rf@k08eV?@2=IS/0SFLj08eW>00208]U=0<0SVTe0`2=J3@2
08aW<`80U6Pg00<0UFTh09IZ>@2FJST00P2FJST00`2EJCP0U6Pg09IZ>@0209IZ>@80Uf/j0`2HK3/0
202FK3X0UF/i09E[>@2EJcT0UV`j09M]>`2IKcd0VW0n0P2GKC/309I/>P<0UF/i1@2HKS`309U_?@03
09]a?`2JL3h0V6hl0080Ufdk00<0V6hl09Y`?P2KLCl00`2HKD0209M/?`<0UV/n0`2DKSl309E_@080
UW11102IKT4209Y_@P80Vg13202GLSh0102OMD<0WWA209]a?`2JL3h209U_?@0309Y`?P2KLCl0W7<o
00L0W7<o202MLd4309me@`80WWA20`2MLd4309Ud?`<0VWE00P2KMT4409]f@P80W7M30P2MN4@309ab
@0<0WG=10P2NM48209]f@P<0W7M30`2MN4@309me@`80X7I40`2QMdD00`2ONTH0WWU509ehA00209ag
@`80WGQ400<0WWU509mjAP2QN4@01`2QN4@0102RNDD0XgY60:=jAP2SNTH20:AkA`80YGa80`2QN4@3
0:9iA@80XgY600<0WgY60:1kA`2RODT00`2SOTX20:9mB@0309mjAP2PNdL0XGa80080XWe900<0XGa8
0:1kA`2ONTH00P2QN4@0102RNDD0XgY60:=jAP2TNdL20:ElB00409mjA@2PNdH0X7]60:1kAP80XGa7
0P2RODP20:AoBP040:=nB@2RODP0XWe80:5lA`80X7]6202VO4X80:QoB`P0Yge;00@0Ygi:0:QoB`2X
Od/0Z7m;0P2YP4`20:Z1C@@0Z7m;0P2YP4`20:Z1C@80ZX1@00@0ZX1>0:Z1C@2ZPDd0ZX5;0P2ZPDT8
0:Z1C@0=0:MmB`2YOdd0Zh5?0:b2D02]Pe40[89@0:^1C`2ZP4h0Ygi:0:QoB`2YP4`0ZX5=0:^2CP02
0:Z1C@030:V0C02XPdh0Z8=>00H0Z8=>00@0[XAB0:f3D@2]Pe40[H=A102/PU00102[PDl0Zh9>0:^2
CP2[PTh30:b3C`80[HA@0P2ZQE430:V4D0<0Z8=?00P0Yh9E0:V3E02YPe@0Zh=B0:f3D@2^Pe00/89>
0;63C`P0[HA@00<0Zh9>0:b3C`2]Q5000`2_QU820:j5D@<0[8=?00D0[HA@0:j5D@2_QU80[hIB0;27
D`080:f3D@P0[8MC202`ReH0202]R540[XUB0:n:E@2`ReL0/8YI0:n9FP2^R5T0[HMJ202^RED30:f:
E0030:j;E@2_S5H0/8eG0080/HiH0P2]R5@20:j9E@<0[hYF00<0/8]G0;6<F02aS5P00`2`ReL30:n:
EP<0/HaG0`2`ReH20:n:E@P0/HaG00<0]8mK0;>>FP2aS5P00`2_RUH20;6<F0060:j;E@2^RUH0[h]G
0:n;F@2_Re/0/8]N0P2`Rel30;2<G0<0[h]K0`2^RUX80;:=H0060:n;F`2`S5`0/8aL0;6=G@2bSUh0
/hmO0P2dT6080;>=GPP0]XaJ0P2cSUX20;:=F@80/HaH0P2`ReL80;6<F080]HaH0P2dReL0102cRUH0
/XUE0;68E02aR5@20:j9E@030:n:EP2`ReL0/HaH0080/XeI00<0/hiJ0;:=F@2bSET01P2bSET80;6=
G@P0/heN202cSUX02@2dSe/0/hiJ0;:=F@2aS5P0/XeI0;>>FP2eT5`0]Y5M0;F@G0030;B?F`<0/hiJ
00T0/XeI0;>?F`2dT5`0]I5M0;JBGP2eTEd0]91L0;:>FP2aSET00P2bS5d20;>=GP<0]8iO00<0]HmP
0;6<F02bSET0102cSUX00`2bSET0/HaH0;:<G@020;:<G@<0/heN0P2dSUl30;B@H080]I5Q0`2fTV83
0;>?F`<0]91L0`2eTEd80;>?F`80/XiD00@0/XeF0;:=F02bSEP0/XeI0P2bS5/0202cSel0/XiN0;:>
GP2bSUh0/hmO0;B@H02fTV80]i=S0P2cSV800`2dSf80]91P0;B@GP020;FAG@030;FBG02cSF00/heP
00@0]HmR0P2cSF020;FAG@<0]91L0`2cSe/00`2eTF40]91P0;:>GP020;6=G@040;:>GP2dT600]I5Q
0;>>FP<0]8mK0P2eT5`20;JAG@P0]8mK0`2dT6020;>?G`<0/XiN202eT5`0102dT5`0/hmK0;>?F`2c
Se/20;:>FP80/HeI0`2eTF430;B@H080/hmO00<0/XiN0;>?G`2dT6000P2eTF401@2dT600/hmO0;:>
GP2dT600]I5Q00<0]Y9R00<0]I5Q0;B@H02dT6000`2bSUX20;>?F`<0]91L0P2gTUh00`2fTEd0]I1L
0;B?F`020;>>FP060;:=F@2aSEd0/HeM0;>?G`2dT600]I5Q0P2dT600102cSel0]Y5M0;JAG@2fTEd3
0;F@G0<0]8mK202cSUX01P2`RU/0/H]L0;6;G02bS5d0/heN0;B>G`<0]HmP0`2dSUl20;>=GP80/XaM
2@2bSET01`2cSUX0]8mK0;F@G02dSe/0/hiJ0;6<F02`ReL0102cSEh40;B>G`80/hiJ0P2bSET20;6<
F080/8]G0P2bSEP0102cSUT0]8mJ0;B?FP2cSUT20;:=F080/XaM0`2aRe`30;2:F`80/hmO0`2bSUh3
0;6=G@<0/XaM0`2cSEh20;B>G`80]91P0P2cSel20;:>GP80/HeM00T0]95K0;:?F@2`SEL0[haF0:j;
E@2_S5H0/8eG0;6>F02_Re/00`2`S5`30;6=G@040;:>GP2aSEd0/HeM0;6=G@80/8aL0`2_Re/20;>9
E`<0/XQF00<0/hUG0;F;F@2fS5X0102bSET40;6<F0P0/XiN2@2_ReL30;:>FP<0/HeI0P2`S5P80;6=
F@@0/8]G00@0/HaH0;:=F@2dSe/0]I1L202bS5d80;6=F@80[XYJ0P2_Re/0102`S5`0/HeM0;:>GP2b
SUh20;>>FP040;:=F@2aS5P0/8]G0;2;E`80[hYF0`2]R5/20:j9G0<0[hYM202]RET30:j:EP<0[HUE
0P2/R5@0102^R5T0[hUJ0:n9FP2_REX20;2:F`80/H]L0`2`S5P30:n;E`80[XYF0P2aS5l30;2;GP<0
[hYM202]RED0102`ReH0[hYE0:n:E@2_RUD20:j9E080[HQC0P2/RDl0102/RE40[HYD0:f:E02]RED2
0:j:F0060:b7FP2/R5P0[8QH0:b8EP2/R5@0[8UC0P2/RE420:b7D`80ZhIB0P2ZQE420:V4D0030:b8
F02[QeL0ZXIF00<0ZXIF00<0[8QH0:f9F@2^RUX02P2]R5@20:j9E@@0[hYF202/R5P20:b7DP<0ZXE@
00<0[8MB0:j9E02_RUD0202_QE<30:R4E080ZHEE0`2ZQUH0102XPdl0ZHA@0:V4D02YQ5040:Z5D@80
ZhI?00@0ZhIA0:^6DP2[QE@0ZhEF0P2[QEP0202WQ4h0Yh=?0:R4D02XQ580ZHEE0:V4E`2YQ5P0ZXEI
0`2XQ5020:V5D@/0ZXIB00@0[HQD0:b7D`2/Qe<0[8MC0P2[QU820:Z5D@080:J1C02UP4/0Y7m:0:=n
B@2TOdX0YH1;0:N2C@2XPdh;0:N2CP<0YX5=0P2UP4`30:J1C080Yh9=0`2XPdh80:N4CPP0Z8=?0P2Y
Q5020:R3C`<0Yh9>0P2VPDd80:J1C080YH9:00H0YX==0:J2CP2WPe40Yh=C0:R4E02XPeH20:N3C`<0
Z8A@00/0Yh=?0:F1C@2TP4`0ZHA?0:R3CP2VPD`0YH1;0:AoBP2UP4/0YX5<0:N2C@020:R4D080Yh=?
0`2VPTh0102UPDd0XWi:0:9nBP2SOd/20:B0C0040:F1C@2VPTh0YX9>0:AnD@80Y7i?00<0Y7i=0:Ao
B`2TOdX00P2TOdP20:F0B@040:AoB02SOTL0Xgi70:9mAP80XGa5102RODP40:=nB@P0XGa700@0YH1<
0:AoB`2RODT0X7]70P2ONTH0102PNdL0XGa809mjAP2ONTH40:5lB080WgY600T0XGI;0:9gBP2UNTd0
Yge=0:MmB`2UO4P0XWU30:5h@P2SOTT00P2RODP00`2QO4L0X7]60:1kAP0209mjA@0309ijAP2MNDD0
VgM30080VWI200<0VgM309eiA@2NNTH00`2NNdD209ejA0<0W7U3102MN4@709iiA@80WGQ40`2LMd<0
0`2MMdP0W7I709]eAP0209YdA@80VgE600<0W7I709egB02LN4@01`2LN4@00`2KMd<0W7Q409eiA@02
09ijAP0309eiA@2LN4@0VgM30080VGA800<0VGA709UeA@2IMD<00P2IMD40102IMT00WWU409iiA02N
ND@309mjA@80X7]60P2SO4D0102QO4D0Wga409mlA02MOD@209]l@`0609YoB02LOTP0W7i809enB02N
ODP0X7a80P2QO4P809imA`80WWU200H0WWU409mjAP2ONDP0WgU:0:1jB`2PNTd709ijAP0309eiA@2J
MTH0VWI600<0VgM70`2LN4P01P2NNTX0WGU909eiB@2LN4P0VgM709YfAP80VGE500<0V7A409YfAP2K
MdL00`2MNDT0202LN4P0VgM709eiA@2LN4@0VgM309Yf@P2IMD40Ug<o0P2FLSh00`2HM4@0Ug=309Ib
@P0209Ea@@0609Ib@P2HM4@0VGE509Ea@@2FLT80V7A40P2IMDD00`2HM4@0UW9209Ea@@0209U`@P04
09Ma@P2FLT80UW9209Ab@P80Tg=20P2JM4D00`2ILd@0V79309Ma@P0209I`@@0309E_@02DKc/0U6lk
00<0Tfhj0`2BKCT2099^?P03091/?02?Jc/0Sf/k00<0Sf/k00X0T6`l08m[>`2AKCd0TFdm08iZ>P29
ICD0R6@d08aX>02@K3`0SfTj0`2@JS/4095[?00408mZ?@2>JC`0SVTl08iY?0<0SFPk00@0S6Lj08]X
?P2;J3h0RfPn0`2:Icd208UV?00608aY<`2<J3@0S6Pd08aX=P2<J3P0S6Lj0P2<Ic/808aW>P0808QV
>027ICL0QV@f08IT=P27ICL0RFLi08]Y>`2<JS`308m[>`<0SVXj0P2=JCT00`2;IST0RVDh08UT=`02
08QS=P0308UT=`2:ICP0RfHi00<0RVHb:oooool002[ooooo1029HST408YS>P0308mS?02>HS/0SV8k
0080SF4j0P2<H3T00`2;GcP0RV<j08YS>P0608YS>P80Rf0e0P2<HCH208eR=`80SV<h0`2=HSL308iS
>080Sf@i0P28HSD208US=P80RV@g0P2;ICP209=X?@04099W?02AIS/0TFHk091U>P80Sf@i00H0S6Dn
08aU?02<IC`0S6Dj08aV>@2<ISL208aV=@80SVPg1P2=IcH209AX=`80UFTh102FJST309EY>080UVXi
0P2GJcX209Q/>`80TVPf00H0TfTg09AZ>02EJcT0Ufdk09Q^?02IKcd209I/?080UF/k102DJSX209M]
>`@0V6hl0P2IKcd00`2KLCl0VW0n09Q^?00209M]>`0309Q^?02JL3h0Vg4o00P0UV/n0`2DKSl309E_
@080UW111P2IKT4209Y_@PP0Ug8n00@0X7I409id@P2LLT00VFlm0`2HKS`00`2IKcd0W7<o09ac?`06
09ac?`P0WG=10`2OMD<209id@P<0WG=100H0Ug8n09Qc?`2HLcl0VGA009Ye@@2KMT8209ag@`H0VgI2
0P2LMd<309ab@0<0WG=10P2NM48209]f@P<0W7M30`2MN4@209me@`<0X7I40`2QMdD00`2ONTH0WWU5
09ehA00209ag@`80WGQ400<0WWU509mjAP2QN4@01`2QN4@20:9iA@<0XgY60`2TNdL20:5hA0H0XWU5
00X0WGQ409mjAP2RODT0Y7m;0:F0C02SOTX0XGa80:1kA`2NNDD0WgY60`2QO4P00`2PNdL0WWU509eh
A0020:1g@`040:5hA02RNDD0Y7]70:ElB080YWe90`2PNdH20:5lA`<0XWe80P2TOdX0102SOTT0XWe8
0:5lA`2PNdH209mjA@P0YWa:202WOTX80:MmB`80Ygi:0`2XOd/30:V0C0H0Z7m;0P2YP4`20:Z0D004
0:Z0CP2ZPDd0ZX5=0:Z1B`80ZX59202ZPDd0202WOD/0ZGm=0:^1C`2/PU00[H=A0:b2D02[PDl0ZX1>
0P2XOd/20:V0C0@0ZX5=202XPdh40:j4DPD0[H=A0`2[PTh30:b3C`80[HA@0P2ZQE430:V4D0<0Z8=?
00H0Z8=F0:V3E02YPe@0Zh=B0:b2D02]PTl20:n1C@P0[HA@00<0ZX5=0:b3C`2_QU800P2aR5@01@2`
Qe<0[XEA0:b3C`2[PTh0[8=?0080[HA@0P2_QU800`2`Qe<0/HQD0:f3D@070:f3D@P0[8MC202^RE@0
202[QTl0[HQA0:n:E@2aS5P0/H]J0:n9FP2]QeP0ZhEH202^RED20:^8DP060:b9D`2^ReD0[haF0;2=
E`2aSUP0/XmI0`2^RED30:n:EP80/8]G0P2bSET30;6<F0<0/8]G0P2aS5L60;2;EP@0/HaH102`ReL0
0`2bSET0/HaH0:n:EP020:f8E0090:j9E@2_RUH0/8]G0:j;E@2^RUH0[h]G0:n;F@2_Re/0/8]N0080
/8]O0P2`S5`70:n;F`P0/XeP0P2`S5`20;6=G@040;:>GP2cSel0/hmO0;>?G`P0/heN202eSEX20;>>
FP80/XeI0P2aS5P:0;2;E`060;N>FP2fSET0]HaH0;B;E`2cRUH0/HQD0P2`Qe<30:n:EP030;2;E`2a
S5P0/HaH00X0/XeI202aSEd80;>=GPP0/hiJ00<0]8mK0;>>FP2bSET00P2aS5P00`2bSET0]8mK0;F@
G0080;>>FP030;:>FP2cSe/0]91L0080]I5M00<0]91L0;:>FP2aSET00`2cSEh30;B>G`80]HmP1@2b
SET20;6<F0040;2;E`2bS5d0/XaM0;:<G@<0/heN0P2dSUl20;>?G`80]91P0P2eTF420;JBHPL0]91L
0P2eTEd80;>?F`060;>?E@2cSUL0/hiI0;>>F@2cSUX0/heL0P2cSEh40;>?G`040;B@H02eTF40]Y9R
0;JBHP80]8mS00H0]8mR0;B@H02dT5h0]91L0;FAG@2eTU`80;B>G`80]Y9N0`2eTEd30;B@G0030;JB
HP2dT600/hmO0080/HeM00<0/XiN0;>?G`2dT6000P2cSUX30;B?F`<0]I1L202dSe/30;B@H080/hmO
0`2bSUh00`2dSe/0]I1L0;F@G0020;F@G0<0]Y5M0P2dT5h30;>?G@<0/XiL0P2eTF460;B@H0<0/hmO
0P2dT6030;>?G`D0]I5Q0P2dT600102cSel0/XiJ0;:>FP2bSUX20;>?F`<0]91L0P2fT5l20;F?GP05
0;B>G@2cSE`0/heL0;>=G02aSEd00P2bSUh00`2cSel0]91P0;B@H0020;B@H0<0]i9N0`2fTEd30;F@
G0P0/hiJ0P2aRe`20;:<G@030;>=GP2dSUl0]8iO00@0]8iO0P2cSEh30;:<G@T0/XeI00P0/hiJ0;B?
F`2eT5`0]8mK0;>>FP2aS5P0/8]G0;:<G@80/heN00D0]8iO0;F?H02fT640]Y1Q0;NAHP020;>>FP80
/XeI0P2aS5P20;2;E`030;6<E`2bSEP0]I1K0080]i9M00<0]I1K0;:=F02aS5L00P2bS5d60;6;G0H0
/XiN0P2aSEd01P2`RU/0/H]L0;6;G02bS5d0/heN0;B>G`80]HmP0P2eTF420;B@H0<0/hmO0140/XiN
0;BAF`2bSeT0/8eG0:n<EP2^ReD0[haF0;2=E`2aSUP0[HUI0:j:FP2_Re/0/8aL0;6=G@2bSUh0/hmO
0;B@H0030;6=F`<0/8aJ0P2_ReT60;::E`80/h]H00D0]8mK0;>>FP2cSUX0/XeI0;6<F0020;2;E`03
0:n:EP2bSUh0/XiN00H0/XiN102`S5P40:n;E`030:j:EP2aSET0/HeI00@0/HeI0P2`S5P80;6=F@<0
/8]G0P2aS5P00`2bSET0/hiJ0;B?F`080;:<G@P0/HeI0P2^RUX20:n;F`80/8aL0P2aSEd20;>>FP04
0;:=F@2aS5P0/8]G0:n:EP80[XUE0`2]RET20:j:FP<0[h]K202^RUX30:f9E@<0[8QD0P2[Qe<20:j8
F@<0[hUJ0`2`RU/30;2<F0<0[h]G0P2^RUH01@2bSUh0/HeM0;6=G@2`S5`0[h]K0080[XYJ00<0[HUI
0:j:EP2^RUH01P2^RUH30:n:E@80[XUD0`2]R5<01P2/RDl0[8UA0:b9D`2]RU@0[HUE0:f9E`80[XYJ
00H0[8MJ0:b8F02/R5P0[8QF0:b8E02/RE<20:b9D@040:^6DP2ZQE40ZXEA0:Z5D@80ZHA@0P2XPdl6
0:^7E@030:b8EP2]REL0[HUG00P0[HQD0P2^RED60:n:EPP0[HUI00P0[HQD0:b7D`2[QU80ZXEA0:^6
DP2/Qe<0[XUE0:n:EPP0[XIC0`2YQED30:Z6EP80ZhMG00H0Yh9>0:R3C`2XPdl0ZHA@0:Z5D@2[QU82
0:b7D`040:^6D@2[QU80ZhIB0:Z5D@<0ZXAC00L0ZH=B0:N4CP2WPdl0Yh=?0:R4DP2XQ5@0ZHAG0080
ZHAH402YQE430:f8E080[8MC0`2[QU80202XPdh0Yh9=0:J1C02UP4/0YX5<0:N2C@2YQ4l0ZhIA2`2W
PTh30:J1C@80YH1<0P2UP4/20:J1C080Yh9=0P2XPdh80:N4CPP0Z8=?0P2YQ5020:R3C`<0Yh9>0P2V
PDd30:N2C@@0YX5<00T0YH1;0:F2BP2UPTX0YX==0:J2CP2WPe40Yh=C0:R4E02XPeH00P2WPdl30:R4
D080Yh=?00@0YX9>0:Z5D02YQ4l0Yh9=0P2VPD`00`2WPTd0Z8=>0:V4C`040:R4D080Yh=?0P2VPTh2
0:5mB@040:9nBP2SOd/0YH5=0:J2CP80Yh=?0P2UOe00102UOdh0YH1<0:F0B`2UP4T20:F1A`090:N2
C@2VPD`0YH1;0:AoBP2SOTT0XWe80:5lA`2PNdH0X7]70080XGa800D0XWe90:=nBP2TOd/0Y7m;0:F0
C0080:5lA`040:F0C02TOd/0XWe90:1kA`80WgY600D0X7]70:5lB02MN4@0WgY60:5lB0020:=nBP0<
0:5lB02ONTH0WGQ409ieB@2QN4X0YGa>0:R0C`2XP4d0YGe90:5j@`2NMd00Xgi90P2RODP00`2QO4L0
X7]609mjA@0209iiA00309ijAP2MNDD0W7Q40080VWI200<0W7Q409eiA@2NNTH00P2OO4H209ikA@80
WGY40P2LND<01@2KMT80W7M309ag@`2MN4@0WWU50080WgY600<0X7]709iiA@2NNDD00P2MN4@209ag
@`80VgI21@2KMDH309afA`0309egB02LN4@0W7Q400H0W7Q40`2MNDD209ijAP<0WGU50P2KMTX00`2K
MTT0VgM709]gA@0209]g@`0409]h@P2NND@0WWU409iiA0<0WgY50P2PNdH20:=kA`040:5lA`2PODL0
X7e709imA`80W7e600H0VWm809anB02LOTP0WGi809imB02PO4P20:5lB0P0WGa600P0W7M009eh@@2M
N4<0WWU509miB02PNT/0XG]<0:5kCP<0WGU50`2NNTH209mkA`H0VgM70P2LN4P01P2NNTX0WGU909ei
B@2LN4P0VgM709YfAP<0VGE500P0VWI609ahB02NNTX0WWY:09eiB@2LN4P0VgM709ahA080VgM30100
VWI209Qd@02GLcl0Ug<o09Ib?P2HM4@0Ug=309Ib@P2ELD40UW9209Mc@`2IMDD0VWI609Mc@`2HM4@0
VGE50P2JMTH00`2HM4@0Ug=309Ea@@0209Q_@@0409I`@@2ELD40UG5109=a@@80TW9100P0VgE609Yd
A@2ILd@0V79309Ma@P2FL440UFm009A^?`80U6lk1P2CKSX00`2DL400TVhn08m[>`0208eY>@0=08iZ
>P2@K3`0T6`l099^?P2>JSX0T6`l095]?@2>JSX0RVHf08UU=@2<J3P0T6`l08iX>@0208mY>P03091Z
>`2AJc`0TV`m0080Tfdn102>JC`408eX>`80RfPn1P2:Icd308aX=P<0S6Ph0P2<IcX00`2;IST0S6Lj
08aW>P0208aW>P<0SFPk0P27ICL208IT=P0:08QV>02:J3X0S6Xl08i/?P2AK3l0T6/n08mZ?@2>JC`0
SFPk08aW>P80RfHi0`2:ICP208UT=`<0RVDh0`26IC8[ooooo`00:_ooool408YS>P@0RF8i0P2=HCX4
08aP>@80Relh202:HcX208]P=@80S64f0P2=HSL208iS>0<0SF8g0`2>HcP208mT>@@0RF<f102:I3L0
1@2CJ3h0TVLm099W?@2AIS`0T6Dk0080Sf@j00L0SV<i08aU?P2<IC`0S6Dl08aU>P2<IST0S6Hg0080
S6He1P2=IcP208iX>@@0U6Pg0P2EJCP00`2FJST0Uf/j09M[>P0309EY>080UVXi0`2GJcX2095W=@03
09=Y=`2DJSP0UV`j00<0Ufdk0P2FJch209EZ?@@0U6Tl0P2FK3X209M]>`80V6hl0P2IKcd00`2KLCl0
VW0n09Q^?00209M]>`0309Q^?02JL3h0Vg4o00P0UV/n0`2DKSl309E_@080UW111P2IKT4209Q]@0P0
Ug8n00H0WgE309id@P2KLCl0VFlm09Q^?02GKC/209Q^?0P0Vg8n202MLd4309me@`80WWA20`2MLd40
1P2GLD00V79109Qb@@2ILd80VWA309]eA080W7I51P2KMT8209Ye@@<0W7900`2MLd4209id@P80VgI2
0`2LMd<309ehA0<0X7I40`2QMdD20:9hAP0309mjAP2NNDD0WGQ40080W7M30P2MN4@00`2NNDD0WgY6
0:5hA0070:5hA0<0XWU50`2SNTH20:AkA`H0XWU50P2QN4@00`2MN4@0WgY60:9mB@020:AoB`0;0:=n
BP2QO4P0WgY609mjAP2PNdL0XGa80:9mB@2QO4P0WgY609ehA02LMd<00P2PMd<0102QN4@0XWU50:Ak
A`2UO4P20:ImB@80X7]60P2QO4L20:9mB0@0Xgi900@0XWe80:5lA`2QO4L0X7]60P2ONTD80:EkB@P0
YWe9202WOD/30:MnBP<0Z7m;0P2YP4`60:QoB`80Ygi:0P2YOdl0102YOdd0ZH1<0:V0C02YP4X20:V0
B0P0ZH1<00P0Yge;0:UoC@2[PDl0[89@0:f3D@2/PU00Zh5?0:Z0CP<0Z7m;0P2YP4`20:Z1C@030:^2
CP2XPdh0Z8=>00H0Z8=>102]Pe450:j4DP<0Zh9>0`2/Pdl20:f4D080ZXEA0`2YQ5030:R3C`060:R3
EP2YPe@0ZH=D0:^3DP2[PDl0[85>0P2^P4`80:f4D0070:Z1C@2/Pdl0[hIB0;68E02bRED0/8MC0:j5
D@040:f4D0030:j5D@2_QU80/8MC0080/8MC202]Pe480:^6DPP0ZhIA00P0ZhI?0:b7D02_RUD0/8]G
0;2:F@2_REX0[8IG0:^5F0P0[XUE00H0ZXMA0:^8DP2/RE<0[HYD0:j;E@2`SEL20;6>F080[XUE0`2_
RUH30;2;E`80/XeI0`2aS5P30;2;E`H0/8]F0P2aS5L00`2bS5/0/H]J0;6;FP020;2:F@80[hUH00@0
[XQG0;6<F02`ReL0[XUE0P2/Qe<02@2]R5@0[XUE0:n:EP2^ReD0[XYF0:n;E`2_ReT0[h]K0;2;GP02
0;2;G`H0[h]K0`2`S5`80;:=H0<0/HeM102bSUh00`2cSel0/heN0;>=GP060;>=GPX0/hiJ0P2bSET2
0;6<F0X0/8]G00H0]hiJ0;J=F@2eS5P0]8]G0;>:EP2aR5@20;27D`030:n:EP2`ReL0/8]G0080/8]G
0`2aS5P80;:=F@P0/HeM202cSEh80;>>FP030;F@G02dSe/0/XeI0080/HaH00<0/XeI0;>>FP2dSe/0
102bSET40;>>FP080;6=F@2bSUX0/hmK0;B@G02eTEd0]91L0;:>FP2aSET20;>=GP<0]8iO0`2eSf02
0;>>FP030;:=F@2aS5P0/8]G00<0/8]G0`2bS5d30;>=GP80]8iO0`2cSel20;B@H0<0]I5Q0`2eTEd6
0;B@G0P0/hmK00H0/hiG0;>>F@2cSUT0/hiJ0;>=G02cSEh20;>=H0030;>?G`2dT600]91P00D0]I5Q
0P2eT6@00`2dSf80]91P0;B@GP020;B@G0030;BAF`2dSUd0]8iM00H0]8iM0P2fTUh30;FAG@<0]91L
00@0]Y9R0;FAH@2cSel0/XiN0P2aSEd00`2bSUh0/hmO0;>>FP020;>>FP<0]8mK0P2eT5`80;B?F`<0
]91P0P2cSel30;:>GP<0]8mK00<0]I1L0;JAG@2fTEd00P2gTUh30;B@H0<0/hmO0P2bSUh60;B@H080
]I5Q0`2cSel20;:>GP<0/hmO0P2fTV800`2eTF40]91P0;>?G`030;>?G`<0/XiJ0P2cSe/30;B@G003
0;F?H02dSUl0]8iO0080]8iO0`2cSEh40;:>GP040;>?G`2dT600]91P0;FAH@<0]i9N0`2fTEd30;F@
G0P0/hiJ0`2bS5d40;>=GP<0]8iO0P2cSEh20;:<G@80/H]L2@2bSET0202cSUX0]8mK0;F@G02dSe/0
/hiJ0;6<F02`ReL0/XaM0P2cSEh01@2dSUl0]HmP0;J@H@2fT640]i5R0080/hiJ0P2bSET20;6<F080
/8]G00<0/8]F0;:=F02dSeX00P2fTE`00`2dSeX0/XeH0;2;EP020;6;G0H0/XaM0P2aSEd60;:>GP06
0;2:F`2aRe`0/H]L0;:<G@2cSEh0]8iO0P2eSf020;FAH@80]91P0`2cSel02@2bSUh0]95K0;:?F@2`
SEL0[haF0:j;E@2_S5H0/8eG0;6>F0020:f9F@040:j:FP2`S5`0/HeM0;>?G`80]91P0P2bSUX30;6=
F@<0/8aH0P2`ReL30;6<F080/8]G00H0[hYF0;B?F`2cSUX0/hiJ0;:=F@2aS5P20;2;E`030:n:EP2b
SUh0/XiN00H0/XiN0P2aSET30;2<F0040:n;E`2^RUH0[XYF0:j:EPH0/8aH2P2aSET00`2`ReL0/HaH
0;6<F0050;:=F@P0/H]L202aSET20:j:FP@0[h]K0P2`S5`20;:=F@040;6<F02`ReL0/8]G0:n:EP80
[XUE0`2]REL20:j:F0<0[h]I202^RUX30:f9E@<0[8QD0P2[Qe<30:j8F@<0[hUJ0P2`RU/30;2<F0<0
[h]G0P2^RUH20;6=F`040;2<FP2_ReT0[h]I0:j:F080[HUG202^RUH20:n:E@80[XUD0P2]R5<20:b7
DP060:b9D@2/RE<0[8UC0:f9E@2]REL0[HUI0P2^RE`01P2/QeX0[8QH0:b8F02/R5H0[8QD0:b9D`80
[8UA00@0ZhIB0:Z5D@2ZQE40ZXEA0P2YQ5020:R3C`80ZXIB00<0ZhMC0:b8E02/R5@0102/R5@80:f8
E080/8]G1P2_RUH80:f9F@030:f7EP2/QUD0ZhED0080ZhED00<0[HMF0:n9F02`RUT0202]R5@40:Z6
EP80ZhMG0P2/R5P20:R3C`030:V4D02ZQE40ZhIB0080[8MC00D0[HQD0:^5E02[QE@0ZhED0:Z4D`02
0:V4D0080:R3C`2XPdh0YX==0:J2CP2WPdl0Yh=A0:R4E02XPeH20:V4F100ZHEA0P2]R5@20:b7D`<0
ZhIB00T0ZXEA0:b7DP2[QU40ZXE@0:V4C`2ZQE00ZhIA0:f8D`2^RE@0202XPdl30:N2CP<0YX5=0P2U
P4`30:F0B`80YX5<0`2WPTd80:J3C@P0Z8=?0P2YQ5020:R3C`<0Yh9>0P2VPDd20:R3CP80Yh9=00@0
YX5<0:F0B`2UP4/0YH1;0P2UPTX01P2VPdd0YX9>0:N3D@2WPe<0Z8AD0:R3EP80Yh=?0`2VPTh20:N3
C`090:R4D02ZQE00ZHA?0:N2C@2VPD`0Yh9=0:R3CP2YQ4l0ZXE@00<0Z8A@0P2WPdl30:J2CP80XGe9
00@0XWi:0:=oB`2UPDd0YX9>0P2WPdl20:EoCP040:F0C02UP4/0YH190:F1A`80YH550P2WPTd0102V
PD`0YH1;0:=nB@2RODP20:5lA`050:1jB@2QNdX0XG]:0:9lB`2SOD`00P2TOTd00`2UOdh0XGa70:5l
A`060:5lA`040:F0C02TOd/0XWe90:1kA`80WgY600D0X7]70:5lB02MN4@0WgY60:5lB0020:=nBP0<
0:5lB02ONTH0WGQ409egBP2PNT/0Xge>0:J0C`2VPDd0Xgi90:1kA02MN440XWe80P2QO4L00`2PNdH0
WgY509mjA@0209iiA00309mkA`2MNDD0W7Q40080VgM300<0W7Q409eiA@2ONdL00`2OO4H209ikA@<0
WGY400D0VgI209ag@`2LMd<0WGQ409iiA@0209mjAP040:1kA`2MN4@0WGQ409ehA080W7M30`2KMT82
09UcA00309YdA@2KMDH0W7I700@0W7I7202KMd<309eiA@80W7Q40`2MNDD209iiC@0309iiC02NNTX0
WWY80080WWY600@0WW]509iiA02NND@0WWU40`2ONTD20:1kAP80XWY600@0X7]609mlAP2OO4H0WWe7
0P2MOTL01P2KP4T0WGm909eoB@2NOdT0Wgi90:5mB@80XWe9202MO4H0202LMd00WGQ109eh@`2NNDD0
WgU80:1jB`2QNd`0XG]>0`2MNDD309ijAP80Wg]70P2LN4P609]gA`0609ijBP2MNDT0WGU909ahB02K
MdL0VWI60`2IMDD0202JMTH0W7Q809eiB@2NNTX0WGU909ahB02KMdL0VgM30P2JMT801`2IMD40V7A0
09Mc?`2GLcl0UW8n09QdA02GLd<00`2FLT801@2HM4@0VWI609]gA`2HM4@0VGE500<0VWI600<0V7A4
09Ib@P2ELD400P2HKd40102FL440UG5109Ea@@2CLD42099b@@0809]eAP2JM4D0VG=409Qb@`2FL440
UFm009A^?`2CKCh209=^>PH0U6lk00<0U710099^?P2?Jc/00P2=JCT01@2>JSX0T6`l091/?02BKSh0
SFTi0080T6`l00D0SVXj08YV=P29ICD0SFTi095]?@0208mY>P03091Z>`2AJc`0TV`m0080Tfdn00<0
U6ho08eX>`2=J3/00P2=J3/408iY?0H0RVLm0P2;J3h208eX>`<0SFTi0`2=JCL308]V>@0308aW>P2=
J3/0SFPk0080SVTl00P0R6Hh08MU=`27ICL0QfDg08QV>02:J3X0SF/m08m]?`80TFa000H0SfXn08iY
?@2<Ic/0RfHj08YU>@29I3P308aW>P80SFPk0`2<IcX308AT<b_ooooo000Zooooo`0408]T>`2:HcX0
RV<j08YS>P<0RF8i00<0R64h08]O>02;GcP01P2;GcP808YS>P80Rf0e0P2<HCH208eR=`T0SV<h00<0
SF8g08US=P29HcH00P29HcH408YT=`<0T6@m0`2?Hc`208iR>`0608eV?`2=ISd0Rf@k08]T>@2;ICP0
RfDf0P2=IcH208aV>@<0SFLj0`2>J3/209AX=`80TfLf0P2DJ3L0102FJST0Uf/j09U]?02DJ3L309EY
>080UVXi0P2GJcX0102BJ3H0TfTg09AZ>02FK3X209M]>`80UV`j0P2GK44309I[@0<0UFXo0P2EJcT0
102FK3X0Ufdk09Q^?02HKS`209U_?@0309]a?`2JL3h0V6hl0080Ufdk00<0V6hl09Y`?P2KLCl00`2F
Jch209M/?`<0V6e00`2DKSl309E_@080UW11102IKT4209Q]@080Uf`o202GLSh01@2NM480W79009Y`
?P2HKS`0Ufdk0080V6hl00<0VFlm09]b?P2KLSh01P2KLSh809ec@@<0WgE30P2NM48309ec@@<0VG=4
0`2JM4D209]eAP@0VgI20P2JMD4209Ud@0<0W7900`2MLd4209id@P80VgI20`2LMd<309ehA0<0X7I4
0P2QMdD30:9hAP0309mjAP2NNDD0WGQ40080W7M30P2MN4@00`2NNDD0WgY60:5hA0090:5hA080XWU5
0`2SNTH00`2TNdL0XgY60:=jAP030:9iA@<0XGQ400<0WWU509mjAP2PNdL00`2RODT30:5lB0070:9m
B@2SOTX0Xgi:0:9mB@2PNdL0WWU509ag@`020:5hA0040:9iA@2SNTH0XgY60:AkA`80YGa80`2QO4L2
0:9mB0<0Xgi90`2PNdH50:5lA`P0YG]9202UO4P80:IlBP80YWe90P2WOTX30:QoB`030:V0C02XOd/0
Z7m;0080Z7m;0P2WOTX20:ImB@80ZGm?00@0ZGm=0:V0C02YP4`0ZH1:0P2YP4P80:V0C0080:MmB`2Y
Odd0Zh5?0:b2D02]Pe40[89@0:^1C`2ZP4h20:V0C0<0Z7m;00<0ZH1<0:^2CP2/Pdl0202XPdh0102[
PDl0[89@0:b2D02/PU040:f3D@040:j4DP2[PTh0Zh9>0:^2CP<0[8=?0P2]Q5020:Z5D@<0ZHA@0`2X
Pdl01P2XPeH0ZH=D0:V3E02ZPU40Zh5?0:^0C@80[Gm;202]Q5000`2/Pdl0[HA@0:n6DP030;27D`X0
[hIB202]Pe480:^6DPP0ZHA?00P0[8M@0:f8D@2^RE@0[XUE0:j8E`2^R5T0[HMH0:b6F@P0[HQD0P2[
R5800`2/RE<0[HYD0:j;E@030:n<EP040:j9E@2_RUH0[hYF0:n:EP80/8]G102aS5P30;2;E`<0[hYF
0P2_RUD30;2;EP<0/HaG0P2bS5d00`2aRe`0/8YK0:n9FP020:j8F@0?0:f7F02aS5P0/8]G0:j9E@2]
R5@0[8MC0:f8E02^RED0[hYF0:j;E@2^RUH0[h]G0:n;F@2_Re/0/8]N0080/8]O0P2^RUX30:n;F`@0
/8aL202bSF080;:>GPP0/heN202aSET20;>>FP80/XeI0P2aS5P20;2;E`P0/HaH0P2eS5P20;B;E`04
0;>:EP2bRED0/HQD0;68E0P0/8]G202bSET80;6=G@P0/heN202cSUX00`2eT5`0]8mK0;:=F@020;2;
E`030;6<F02bSET0/hiJ00<0/HaH0P2bSET30;>>FP030:n;E`2aSET0/XiJ00<0]91L0P2bSUX0102c
SEh0]8iO0;B>G`2dSUl20;F?H080]Y1Q00@0]8mK0;>>FP2bSET0/8]G0`2_RUH0102`ReL0/XaM0;:<
G@2bS5d30;>=GP80]8iO00@0/XiN0;>?G`2cSel0/hmO0P2dT6020;FAH@@0]I5M0`2dT5`:0;>?F`06
0;>>F@2cSUX0/hiJ0;>=G02cSEh0/heP0P2cS6420;B@H0060;FAH@2fTV80]Y9R0;JBHP2eTF40]91P
0P2eT6@01P2eT6<0]91P0;B@GP2dT5`0/hmK0;>@FP80]I1L102cSUX20;F@G080]I5M0`2dT5`30;>?
F`040;NCH`2fTV80]91P0;:>GP80/HeM0P2bSUh20;:=F@80/hiJ0`2dSe/00`2eT5`0]8mK0;B?F`06
0;B?F`<0]91P0P2cSel30;:>GP80/hiJ00<0]8mK0;F@G02fTEd00P2gTUh00`2hTel0]I1S0;F@H`02
0;B?HP<0/hiQ00<0/XeP0;>?G`2cSel00`2dT6030;FAH@030;B@H02cSel0/XiN0080/HeM00L0/XiN
0;>?G`2dT600]i=S0;JBHP2dT600/hmO00<0/XiN00@0/hmO0;:>FP2bSUX0/XiJ0P2cSe/30;B@G0P0
/heP00H0/hmO0;:>GP2bSUh0/HeM0;:>GP2cSel20;FAH@<0]Y5M0`2eT5`30;B?F`P0/hiJ2`2cSEh2
0;:<G@<0/H]L2@2bSET01`2cSUX0]8mK0;F@G02dSe/0/hiJ0;6<F02`ReL0102cSEh40;B>G`80/hiJ
0P2bSET20;6<F080/8]G00<0/8]F0;6<E`2bSEP00P2cSUT00`2bSEP0/HaG0;2;EP020;6;G0<0/XaM
0`2cSEh30;6=G@<0/XiN0P2cSel30;:<G@<0/heN0P2dSUl20;B@H080/hmO0P2bSUh20;6=G@0@0;BA
F`2bSeT0/8eG0:n<EP2^ReD0[haF0;2=E`2aSUP0[HUI0:j:FP2_Re/0/8aL0;6=G@2bSUh0/hmO0;B@
H0<0/XmI0P2aSUP30;2=E`080:n;E`2`S5P0/8aH0;6=F@2`S5P0[h]G0:j:EP2]RED40;:=F@@0/HaH
202aSEd01`2bSUX0/HeI0;6=F@2aSET0/8aH0:n;E`2^RUH00P2]RED30:n;E`<0/8aH2P2aSET00`2`
ReL0/HaH0;:=F@020;>>FP030;:=F@2aS5P0/8]G00P0/H]L202aSET30:j:FPD0[h]K0P2bSET00`2a
S5P0/8]G0:n:EP020:j9E@040:f8E02]RED0[HUE0:f9E@80[XYF0`2_ReL80:n;F`<0[XYF0`2]RED2
0:b8E080[HMH0P2^R5T30:n9FP040;2:F`2`S5P0/8aH0;2<F0<0[h]G0P2^RUH0102`S5P0[h]G0:n;
E`2_ReL40:j:EPP0[h]G0`2^RE@20:f8D`<0[8MB00H0[8UC0:b8E02/R5@0[HUG0:f9F@2]R5/20:j9
G@060:b7FP2/R5P0[8QH0:b8EP2/R5@0[8UC0P2/RE420:b7D`80ZhIB0P2ZQE420:V4D0030:V6D02Z
Qe40ZhQB00@0[HYD00<0[8UC0:^8DP2]R5@01`2]R5@20;6<F080/8]G102_RUH80:f9F@080:j8F@2]
QeP0[8IG0:^5EP2/QUL0[HMH0:n9FP2`RU/80:b8E0040:Z6EP2[QeL0ZhMG0:^7E`80[8QH0P2]RET4
0:Z5D@<0ZhIB00L0[8MC0:b6F@2[QEP0ZhEF0:Z4D`2YQ500Z8=>0080Yh9;00H0YX==0:J2CP2VPTh0
Yh=A0:N3D`2XPeH20:R3E`<0ZXIB0P2YQE4;0:R4D0<0ZhIB0P2ZQE430:V4D0080:b7DP2[QU40ZXE@
0:V4C`2ZQE00ZhIA0:f8D`2^RE@80:R3C`<0Yh9>0`2VPDd20:F0C0040:AoBP2UP4/0YH1;0:F0B`80
YX5<0P2WPTd80:J3C@P0Z8=?0P2YQ5020:R3C`<0Yh9>0P2VPDd01P2YQ4l0Z8=>0:R3CP2WPTd0YX5<
0:F0B`80Y7m:0P2UPTX01P2VPdd0YX9>0:N3D@2WPe<0Z8AD0:R3EP80YH5=0`2TP4`00`2UPDd0Yh=?
0:R4D0020:R3CP<0YX5<00@0Z8=>0:V4C`2[QU40Yh=?0`2VPTh20:F1C@80Y81<0P2ROTX0102SOd/0
Y81<0:B0C02UPDd20:J2CP80YX5=00<0YX5<0:J1BP2VPTP00P2VPTH01P2VPT@0Yh9>0:J1C@2VPDd0
YH1<0:AoB`80Xgi:00<0XWe90:9lC@2RO4d00P2RO4d40:=mCPP0XGa700@0YH1<0:AoB`2RODT0X7]7
0P2ONTH0102PNdL0XGa809mjAP2ONTH40:5lB080WgY600P0WWU<0:1lC02ROTh0Y81>0:B0C02ROdT0
X7e509ik@`P0WgY500<0Wg]709ijAP2LN4@00P2KMd<0102LN4@0WWY609mkA`2PODL309mlAP80WW]5
0P2MNT@409ehA0@0WWU50P2MN4@209ag@`<0VgI200D0VWE109Ma@P2HLT<0VWA509]eAP0409afA`03
09]eAP2KMd<0VgM300H0VgM300<0WGU509ahA02KMd<00P2JMT800`2KMd<0W7Q409eiA@020:1kC`03
0:1kCP2PO4`0X7a:0080X7a800@0X7e709iiA02NND@0WWU40`2ONTD20:1kAP80X7Q500@0WWU509ij
AP2NNTH0W7]60P2LODL01P2KP4T0WGm909eoB@2NOdT0Wgi90:5mB@80XWe9202LNdD209ii@P0609ii
A02ONTH0WgU809miBP2PNT/0X7Y=1`2NNTH0102MNDD0W7Q809ahB02LN4P309]gA`80VWI600H0WWY:
09eiB@2MNDT0W7Q809]gA`2JMTH209UeA@0309Mc@`2HM4@0VWI60080W7Q800<0VgM709YfAP2IMDD0
0`2IMD4209Qd@0<0Ug<o00P0V7A409Mc@`2FLT80UW9209Mc@`2IMDD0VgM709ahB080V7A40P2IMDD0
102HM4@0UW9209A`@02CKcl209M^@00409E_@02DL400U710099`@080TG500P2KMDH01P2ILd@0V793
09I`@@2DKSl0Tfdn099/?@80Tfhj0`2DKc/309E`?080TVhn00<0T6`l08m[>`2?Jc/00`2?Jc/01@2@
K3`0SFTi08m[>`2@K3`0SFTi0080RVHf00<0SVXj099^?P2AJc`00`2AJc`3099/?@0309=]?P2<IcX0
SFPk0080SFPk0`2>JC`00`2?JSd0RFHl08UV?00308YW?@<0RfPn0P2=J3`00`2=J3/0SFTi08eY=`02
08eY=@0608eZ=02:ICP0RVDh08]V>@2<IcX0SFPk0P2>JC`02@2?JSd0RFLi08UW>@28ISP0QfDg08QV
>02:J3X0S6Xl08i/?P02091[@@0408mZ@02=J3h0S6Lm08]V?080RVDk00<0RfHi08aW>P2=J3/00P2>
JC`00`2=J3/0S6Lj08]V>@0308AU=R_ooooo000Zooooo`80Rf@k0P2:HcX208UR>@80R64h102:GSL4
08]O>0P0RV<j0P2;H3D208aQ=P80SF8g0P2>HcP2091U>P0408mT>@2>HcP0SF8g08eR=`80S64f102:
I3L408US=P80S60i0`2=HCX308iR>`0808iW@02=ISd0Rf@k08YS>02:I3L0RfDf08eW=P2>J3L308aU
>P0308eV>`2>Ic`0SVLl0080SfPm00@0U6Pg09=W=P2CIcH0TfLf0P2DJ3L00`2FJST0V6`k09Y^?@02
09AX=`<0UFTh0`2FJST00`2DJSP0UF/i09M]>`0209Q^?00309M]>`2FK3X0UF/i00<0V6e30`2GK482
09I[@@80U6Xh00T0UF/i09I/>P2GKC/0V6hl09U_?@2JL3h0Vg4o09Y`?P2HKS`00P2GKC/00`2HKS`0
VW0n09]a?`0209M/?`80V6e00P2IKT4209Y_@P<0U6ho0`2EKd0209I`@@0309Y_@P2IKT40VFi10080
V6e00P2GK3l00`2FJch0Ug8n09Mb?P0609Mb?P0309]a?`2JL3h0VFlm0080Ufdk00<0V6hl09Y`?P2K
LCl0202JLCd809ec@@<0WgE30P2NM48309ec@@80VgE60`2JM4D309UcA00309ag@`2KMT80VgI20080
VWE10P2IM400102HLcl0W79009ab@02LLT0309ec@@80WWA20P2KMT8309ag@`<0WGQ400@0X7I40:5g
A@2QMdD0XGM50P2RN4H20:=iA`0309mjAP2NNDD0WGQ40080W7M30P2MN4@00`2NNDD0WgY60:5hA00:
0:5hA080XWU51P2SNTH00`2RNDD0XGQ40:5hA0020:1g@`80X7]70`2ONTH0102PNdL0XWe90:=nBP2S
OTX30:AoB`040:=nBP2QO4P0WgY609ehA0P0XgY60P2QO4L20:9mB0@0Xgi90P2NND@00`2ONTD0X7]6
0:5lA`020:9mB0030:=nB@2TNTP0Y7Y800H0Y7Y8202UO4P80:IlBP<0YWe90P2WOTX30:QoB`030:V0
C02XOd/0Z7m;0080Ygi:0P2VODT0102UO4P0Z7i>0:QnCP2XOT`20:QoB`030:QoB@2XOdL0Z7m700P0
Z7m;0100Yge;0:UoC@2[PDl0[89@0:f3D@2/PU00Zh5?0:Z0CP2ZPDd0ZH1<0:QoB`2WOTX0Z7m;0:V0
C02[PTh0[8=?202XPdh00`2YOdd0ZX1>0:Z0CP020:^1C`<0[89@00@0[H=A0:^2CP2[PTh0Zh9>0`2/
Pdl20:f4D080ZXEA0`2YQ5030:R3C`060:R3EP2YPe@0ZH=D0:Z2D@2ZP4h0Zh1=0P2/OTX80:f4D080
[hIB0`2^QE40102_QU80/HQD0;:9E@2bRED20;68E0030;27D`2_QU80[XEA0080[HA@202]Pe480:Z5
D@P0[8MB00P0[XUB0:f8D@2/Qe80ZhIB0:^5E02/QUL0[HMH0:j8F`P0[HQD202]RU@30:n:EP80/8]G
0`2aS5P30:n:EP<0[XUE0P2]R5@30:n:E@030;2;EP2aS5L0/HaG0080/XeH0P2bS5d02@2aRe`0/8YK
0:n9FP2^R5T0[HMH0:b6E`2bSET0/HaH0:n:EP020:f8E0090:j9E@2_RUH0/8]G0:j;E@2^RUH0[h]G
0:n;F@2_Re/0/8]N0080/8]O0`2^RUX00`2_Re/0/8aL0;2<G0030;6=G@P0/XeP1P2bSUh20;6=G@P0
/heN202_SUT20;>>FP80/XeI0P2aS5P20;2;E`P0/XeI00<0]8]G0;>:EP2cRUH01@2cRUH20;6<F0H0
/8]G202bSET80;6=G@P0/heN202cSUX00`2eT5`0]8mK0;:=F@030;2;E`040;6<F02bSET0/8]G0;2;
E`80/HaH00P0/XeI0;>>FP2cSUX0/hiJ0:n;E`2`S5P0/XiJ0;>?F`80]91L00<0/hmK0;:>FP2dSUl0
0P2dSUl20;F?H0<0]Y1Q00@0]I1L0;B?F`2aS5P0[hYF0P2^RED00`2_RUH0/8]G0;:<G@020;:<G@<0
/heN0P2dSUl20;:>GP<0/hmO0`2dT6030;JBGP80]I5M00<0]91L0;>?F`2cSe/02@2cSe/20;B?F`03
0;B>G@2dSUl0]8iQ0080]8eR00@0]8eT0;B@H02eTF40]Y9R0P2gTf<00`2fTV80]91P0;>?G`020;JA
I@030;F@H`2eTF40]91N0080/hmK00@0/i1J0;JAG@2eT5`0/hiJ0P2bSET00`2cSUX0]I1L0;JAG@03
0;>?F`<0/XiJ0P2aSET0102hU6@0]Y9R0;B@H02bSUh30;6=G@040;:>GP2bSET0/XeI0;:=F@80/hiJ
2`2dSe/30;B@H080/hmO0`2bSUh01P2bSET0/hiJ0;B?F`2eT5`0]Y5M0;NBGP80^9=O0`2eT6@20;B?
H`<0/hiR0`2cSel00`2dT600]I5Q0;FAH@020;JBHP030;B@H02cSel0/HeM0080/8aL00L0/HeM0;>?
G`2dT600^9AT0;JBHP2dT600/XiN0080/HeM0P2bSUh30;:>FP80/hmK0`2dT5`80;><H@030;B@H02c
Sel0/XiN0080/HeM00<0/hmO0;FAH@2fTV80102dSe/30;>>FP80/XeI202cSUX60;>=GP80/XaM0P2c
SEh20;:<G@@0/H]L2@2bSET01`2cSUX0]8mK0;F@G02dSe/0/hiJ0;6<F02`ReL00`2cSEh20;:<G@<0
/H]L0P2cSUX20;:=F@80/HaH0P2`ReL00`2aS5L0/8]F0:n:E@020:j9E0030:n:E@2`ReH0/HaG0080
/H]L0P2bS5d20;>=GP80]8iO0P2`S5`20;6=G@040;:>GP2cSel0/hmO0;>?G`80]8iO0`2cSEh30;:<
G@<0/XiN0P2aSEd30;2<G0080;BAF`2bSeT0/8eG0:n<EP2^ReD0[haF0;2=E`2aSUP30:n;F`030;2<
G02aSEd0/XiN0080/XiN0P2cT5P20;:?E`<0/HiF00<0/8eE0:f<E`2^SEP00`2_SUT00`2]S5L0ZhYE
0:Z9E0040;6<F0@0/XeI202aSEd20;:>FP80/HeI00D0/8aH0:n;E`2^RUH0[HUE0:b8E0020:j:EP80
[h]G0P2`S5P:0;6=F@080;2;E`2aS5P0/hiJ0;B?F`2cSUX0/XeI0;2;E`2_RUH80;2:F`P0/HeI0P2_
Re/60:j:FP060;:=F@2aS5P0/HaH0;2;E`2_RUH0[XUE0P2]R5@30:f9E@80[XYF0`2_ReL80:n;F`80
/8aH0`2_ReL30:j:EP<0[HMH0P2^R5T30:n9FP<0/8aH0`2_ReL20:j:EP80[HUE0`2^RUH;0:n;E`80
[XUD0P2]R5<40:b7DP80[8QD00L0[8QF0:f9F@2]R5/0[HQL0:j9G@2^REl0[8MJ0080[8QH00<0[8QF
0:b8E02/RE<00P2/RE430:f8E080[8MC0`2[QU800`2XQDd0ZXM?0:b9D@020:f:DP040:j;D`2]RU80
[8UA0:^8D0P0[HQD00<0/XeI0;6<F02aS5P00P2`ReL20:n:EP030:j9E@2^RUX0[XYJ00H0[XYJ00P0
[XQI0:f7F02/QUL0ZhEF0:b6E`2]QeP0[hUJ0;6;G0P0ZhYE0P2[QeL20:b8F0<0[HUI00@0[XYJ0:b7
D`2/Qe<0[8MC0P2[QU830:Z5D@090:b5FP2[Q5T0ZhEH0:Z4D`2XPdl0Yh9;0:N3B@2VPTP0YX==0080
YX9>00<0YX9@0:N3D`2WPUD00P2XPeL00`2[Qe<0ZXIB0:Z6DP020:V5D@80Z8A@00<0Yh=?0:R4D02X
Q5001P2XQ5030:V4D0<0Z8=?0P2WPTh0202XPdh0Yh9=0:J1C02UP4/0YX5<0:N2C@2YQ4l0ZXE@202Y
Q5030:N2CP<0YX5=0P2UP4`20:AoBP<0YH1;0`2VPD`80:F2C0P0Z8=?0P2YQ5020:R3C`<0Yh9>0P2V
PDd20:V4C`060:R3CP2WPTd0YX5<0:F0B`2TOdX0Xgi90P2UPTX05`2VPdd0YX9>0:N3D@2WPe<0Z8AD
0:R3EP2TP4`0Xgm;0:9nBP2QODT0XWi:0:B0C02VPTh0Yh=?0:N2C@2VPD`0YH1;0:AoBP2UP4/0Yh9=
0:V4C`2ZQE00YH5=00<0Y81<0P2SOd/20:9nBPP0Y81<0P2VPD`0102VPDX0YX980:J2AP2VPTH20:J2
A0P0YGm>102SODh40:9lC@P0XGa700@0YH1<0:AoB`2RODT0X7]70P2ONTH0102PNdL0XGa80:5lB02Q
O4P409mjAP80XGa800H0Wge?09mmC@2POTh0X7m<0:1oBP2POdT209moAP0;09ag@P2MN4<0WWU409ii
A02ONTD0X7]60:5lA`2RODP0Wg]709ijAP2MNDD00P2LN4@00`2MNDD0WWY609mkA`020:1mA`<0Wga6
0`2NNdD409iiA@@0WGQ40`2LMd<309]f@P80VWE100@0UFm009Ma@P2ILd@0VgE6102LMTL00`2KMDH0
VWI209Yf@P0609Yf@P0309]g@`2JMT80VGE10080V7A000<0VGE109Yf@P2KMd<00P2MN4`00`2MN4/0
WGU909eiA`0209eiA@0409ejA02NND@0WWU409iiA0<0WgY50P2PNdH00`2MMD@0WWI509afA@0209ah
AP0409]jA`2JNTL0Vg]809^0B@80WGm900<0WWm909mnB@2QODT00P2RODT809akA@80X7]400<0WgY5
09mjAP2ONDP00P2NN4T01@2NN4/0X7a80:1lB02ONdL0WWY60080WGU50P2LN4@209eiB@80W7Q800D0
VgM709YfAP2JMTH0VWI609ijBP0209eiB@0309ahB02KMdL0VWI60080VGE500<0UG5109Ib@P2HM4@0
0`2JMTH00`2IMDD0V7A409Qd@00409Qd@0<0Ug<o0P2GLd<209Ib@P0409Mc@`2IMDD0W7Q809eiB@80
Ug=30P2HM4@0102GLd<0UG51099^?P2AKCd209M^@00409E_@02DL400U710099`@080TG5000P0W7I7
09]eAP2ILd@0Ug5209E_@02CKCh0TV`m095[?080Tfhj0P2DKc/209E`?080UW4m00<0T6`l095]?@2A
KCd00P2AKCd0202@K3`0SVXj08iZ>P2>JSX0S6Ph08iZ>P2@K3`0SFTi0P2:ISH00`2>JSX0TVhn09=]
?P0209=]?P80TV`m0`2AJc`208aW>P80SFPk0P2>JC`208mZ?@<0RFHl00<0RVLm08]X?P2;J3h00P2<
JCl01P2=Id00SFPn08eX?02=J3/0SFTg08eY=@80SFXb00H0RF@g08YU>02;IST0S6Lj08eX>`2>JC`2
08mZ?@0308aZ?02;JC/0RFLi0080R6Hh00<0RFLi08]Y>`2<JS`00`2>JCl00`2=J3h0S6Lm08]V?002
08]V?00308QS=P29I3L0RVDh0080RfHi00<0RVDh08UT=`28HcH00`24ICL[ooooo`00:_ooool308]T
>`0308YS>P29HST0R64h0080R64h0P29GCH408YN=`80Relh202:HcX208]P=@80S64f0P2=HSL208iS
>080TFHk00H0T6Dj08iS>02=HSL0S64f08]P=@2:Gc@408YT=`@0RF<f0P2:GST0102;GcX0S60k08aP
>`2=HC`208iR?@0908iW@02=ISd0Rf@k08YS>02:I3L0RfDf08eW=P2>J3L0Rf@i0080S6Dj00<0SFHk
08iW?02>Ic`00P2?J3d0102DJ3L0TfLf099V=@2BISD209=W=P0309IZ>@2IKC`0VVhm00<0U6Pg0P2E
JCP309IZ>@0809I/>P2GKC/0VFlm09Y`?P2IKcd0Ufdk09E[>@2DJSP409U^A080V6e30P2GK4802`2C
JCL0U6Xh09E[>@2FK3X0Ufdk09Q^?02IKcd0VW0n09]a?`2JL3h0V6hl0080Ufdk00<0V6hl09Y`?P2K
LCl00`2HKD000`2IKT40VVm209]`@`0209]`@`<0U6ho0`2EKd0209I`@@0409Y_@P2IKT40VFi109Q]
@080Uf`o0P2FJch809Mb?P0309Y`?P2IKcd0V6hl0080Ufdk00<0VFlm09]a?`2LLT00202JLCd809ec
@@<0WgE30P2NM48309ec@@80W7I900<0VgE809YdA`2ILdH00P2HLTD01@2GLD@0W7M309]f@P2KMT80
VWE10080VGA00P2HLcl309ab@0<0WG=10P2NM48209]f@P<0W7M30`2MN4@40:5gA@80XWQ60P2SNDL0
0`2ONTH0WWU509ehA00209ag@`80WGQ400<0WWU509mjAP2QN4@02P2QN4@30:9iA@80XgY600@0Y7]7
0:=jAP2SNTH0XWU50P2QN4@20:1g@`030:9mB@2PNdL0WWU50080WGQ400/0WgY60:9mB@2TOd/0Y7m;
0:F0C02VPDd0YH1<0:AoB`2RODT0X7]709iiA@030:AkA`80XgY60`2RNDD20:5lA`80XWe80`2SOTT0
1`2TOdX0W7M209ag@P2NND@0WgY50:5lA`2RODP00P2TOdX80:AjB0P0Y7]7202VO4X30:ImB@<0Ygi:
0P2XOd/0102YP4`0Z7m;0:QoB`2WOTX20:ImB@80YGa80P2XOTh0102XOT`0Z7m;0:QoB`2XOdT20:Qo
A`P0Z7m;00/0Yge;0:UoC@2[PDl0[89@0:f3D@2/PU00Zh5?0:Z0CP2ZPDd0ZH1<0:QoB`020:MnBP03
0:V0C02[PTh0[HA@00P0Z8=>0P2XOT`0102YOdd0ZX1>0:Z0CP2[PDl30:b2D0<0Zh9>0`2/Pdl20:f4
D080ZXEA0`2YQ5030:R3C`060:R3EP2YPe@0ZH=D0:Z2D@2ZP4h0ZWm<0P2/OTX80:f4D0070;68E02`
Qe<0[XEA0:b3C`2]Q500[hIB0;:9E@020;B;E`070;>:EP2bRED0/8MC0:n6DP2]Q500[8=?0:^2CP08
0:f3D@P0ZXEA202_RUD0202`Re@0[XUB0:^6D@2ZQE40ZXAC0:^5EP2^R5T0/8YM202]R5@20:j;E@<0
[HYD0`2/RE<20:n:EP<0/8]G0`2aS5P30:j9E@<0[HQD0P2/Qe<0102^RE@0[hYE0:n:E@2`ReH20;6<
E`80/XeH0P2bS5l0102aReh0/8YM0:j8F`2]QeX20:b6F@030;>>FP2aS5P0/8]G00<0[XUE00P0[hYF
0;2;E`2^ReD0[XYF0:n;E`2_ReT0[h]K0;2;GP80/8]O00@0[HUI0:j:FP2^RUX0[h]K0P2`S5`30;6=
G@P0/XeP1@2bSUh30;6=G@P0/heN202_SUT20;>>FP80/XeI0P2aS5P20;2;E`P0/hiJ0P2bRED30;>:
EP<0]8]G0`2aS5P50;2;E`P0/XeI202aSEd80;>=GPP0/hiJ00H0]I1L0;B?F`2bSET0/8]G0:n:EP2`
ReL20;6<F0<0/8]G00<0/HaH0;:=F@2cSUX00P2cSUX0102^RUH0[h]G0;6=F@2cSe/20;B@G0040;>?
F`2bSUX0]8iO0;B>G`<0]HmP0`2fT6401P2fTEd0]8mK0;6<F02_RUH0[HQD0:j9E@80[hYF0`2bS5d3
0;>=GP80]8iO0`2bSUh20;>?G`<0]91P0`2fTUh20;FAG@040;B@G02cSe/0/hmK0;:>FPP0/hmK00H0
]8mK0;B>G@2dSUd0]8iO0;B>H@2dSF820;B=I0030;B@H02eTF40]i=S0080^9AT00<0]Y9R0;B@H02c
Sel00P2fTFD00`2eT6<0]I5Q0;B@GP020;>?F`040;:?F@2fTE`0]I1K0;>>F@80/XeH00<0/hiI0;F@
F`2fTE`00`2bSUX30;6=F@80/8aH00P0^9AT0;JBHP2dT600/XiN0;6=G@2`S5`0/HeM0;:>GP<0/XeI
0`2cSUX:0;B?F`<0]91P0P2cSel30;:>GP060;:=F@2cSUX0/hiJ0;F@G02fTEd0]i9N0P2hTel30;F@
I0<0]8mS0P2cSV80102bSUh0/hmO0;>?G`2dT6020;FAH@80]Y9R00<0]91P0;>?G`2aSEd00P2`S5`0
1`2aSEd0/hmO0;B@H02hU6@0]i=S0;B@H02aSEd00P2`S5`00`2aSEd0/XiN0;:>FP020;:>FP80/hmK
0`2dT5`30;:;H0D0/haQ00<0]91P0;>?G`2aSEd00P2aSEd00`2cSel0]I5Q0;JBHP040;>>FP<0/XeI
0P2aS5P80;>>FPD0/heN0`2bS5d20;>=GP80/XaM0`2aRe`00`2`RU/0/XeI0;:=F@070;:=F@070;>>
FP2dSe/0]I1L0;B?F`2cSUX0/HaH0;2;E`020;>=GP040;:<G@2aRe`0/H]L0;2:F`80[hUJ0P2cSUX2
0;:=F@80/HaH0P2`ReL00`2aS5L0/8]F0:f8D`020:b7DP030:f8D`2`ReH0/HaG0080/H]L0P2bS5d0
102cSEh0]8iO0;B>G`2eSf020;2<G080/HeM00@0/XiN0;>?G`2cSel0]91P0P2eSf000`2dSUl0/heN
0;:<G@020;6;G0040;2:F`2aSEd0/HeM0;6=G@80/8aL0`2_Re/0202dTE/0/XmI0;2=E`2_S5H0[X]E
0:n<EP2`SEL0/HiH102`S5`40;6=G@80/i1H0P2bSeL40;6>EP090:f<E`2^SEP0[hiI0;2?FP2_SUT0
[HaG0:^:E@2YR5<0[hYF0080/8]G00D0/HaH0;:=F@2cSUX0/hiJ0;B?F`080;6=G@80/XiJ0P2aSET0
1P2`S5P0[h]G0:f9E@2]RED0[8QD0:f9E@80[XYF00<0[h]G0;2<F02`S5P02P2aSET00`2`ReL0/HaH
0;>>FP020;B?F`030;:=F@2`ReL0[hYF00P0/8YK202aSET20:n;F`@0[XYJ0P2]RET20;6<F080/8]G
00@0[hYF0:j9E@2]R5@0[HQD0`2]RU@20:j;E@<0[haF202_Re/20;6=F@<0/8aH0`2_ReL30:f7F0<0
[XQI0P2_REX30;2<F0<0[h]G0P2^RUH20:b9D`040:f:E02^ReD0[X]E0:n<EP80/8eG202_ReL20:j9
E080[HQC0`2/Qe801`2[QU40[8QD0:b8EP2/R5H0[HUI0:f8F`2]R5`00P2^REl01P2/QeX0[8QH0:b8
F02/R5H0[8QD0:b9D`80[8UA0`2^RED20:f8E0<0[8MC00<0Z8E=0:Z7C`2/RE400`2^Re<00`2]RU80
[8UA0:Z7C`080:f8E080/XeI0P2aS5P0102`ReL0[hYF0:n:EP2^RED80:j:FP030:j8F`2]QeX0[8II
0080[8II00<0[XQK0:n9G02aReh0202[RUD0102[QeL0[8QH0:b8F02/R5P20:f9F@80[XYJ0P2]R5@2
0:b7D`0=0:^6DP2ZQE40ZHA@0:V4D02/QE`0ZhAI0:^5F02YPe80Z8=>0:N2B`2VPTP0YX960:F2C002
0:J2CP030:J2D02WPe<0Yh9E0080Z8=G0P2[Qe<0102ZQU80ZHEA0:V5D@2XQ5020:N3C`P0Z8A@0`2X
Pdl20:N2CP<0YX5=00P0Y7m:0:=nB@2RODP0XGa70:9mB02SOTT0YH1;0:J1C0P0ZHA@0`2WPTh30:J1
C@80YH1<0`2TOdX20:F0B`<0YX5<202UPT`80:R3C`80ZHA@0P2XPdl30:N2CP80YX5=0P2YQ4l00`2X
Pdh0Yh9=0:J1C0020:AoBP0;0:=nB@2UPTX0YH9:0:J3C@2VPTh0Yh=A0:N3D`2XQ5@0Z8=F0:=oB`2R
OTX00`2PO4P02`2ROTX0YH5=0:J2CP2VPD`0YH1;0:AoBP2SOTT0Y7m:0:J1C02XPdh0ZHA?00<0Xgm;
0`2ROTX20:5mB@<0YH5=0P2TP4`30:=oB`80YX5<00<0YX5:0:J2B02VPTH00P2VPT@0102VPd<0Y7i=
0:AnC@2TOTd20:EoCP<0YX1?00D0YGmB0:AnD@2TOU40Xge@0:9lC`020:5kCP030:1jC@2QO4L0XGa7
00H0XGa700@0YH1<0:AoB`2RODT0X7]70P2ONTH01@2PNdL0XGa80:=nBP2QO4P0WgY60080WGQ400/0
WgY60:5lB02SOTX0XGmA0:1nCP2OODd0WWe:09imB02OOTP0X8170:61B00209]f@@0909ag@P2NND@0
X7]60:5lA`2RODP0Xgi90:1lB02NNTH0WGU50080W7Q400<0WGU509ijAP2PO4P00`2PODL209mlAP<0
WW]500D0X7]709mjAP2ONTH0WWU509ehA00209ag@`0409]f@P2LMd<0W7M309ag@`80VgI20`2JMD40
1@2DKSl0UW1109UcA02KMDH0WGM80080W7I70P2KMDH909Yf@P0709Ue@@2GLcl0UW8n09Ib?P2GLcl0
VGE109Yf@P0209YeB@0309YeB02JMTH0VWI40080VWI200@0VWM109iiA02NND@0WWU40`2ONTD20:1k
AP80W7A300L0VgE409YfA02KMdD0VWU609UiAP2JNTL0Vh190080WGm900<0WWm909mnB@2QODT00P2R
ODT809akA@80XGa500<0X7]609mjAP2NN4L00P2MMdP02@2LMTT0XGe90:5mB@2PO4P0WWY609eiA@2L
N4@0VgM309Yf@P0209eiB@80W7Q800D0VgM709YfAP2JMTH0VGE509ijBP0209eiB@0309ahB02KMdL0
VWI60080VGE500<0U71009Ea@@2GLd<00P2IMDD00`2HM4@0Ug=309Ib@P0409Qd@0@0Ug<o0P2GLd<2
09Ib@P0409QdA02JMTH0W7Q809ijBP80UW920P2GLd<0102FLT80Tflo095]?@2@K3`209M^@00409E_
@02DL400U710099`@080TG5000P0W7I709]eAP2ILd@0Ug5209E_@02CKCh0TF/l091Z>`80Tfhj0P2D
Kc/01`2EL3`0UW4m09Ia?@2GLSh0SVXj091/?02BKSh00P2CKcl00`2AKCd0SVXj08iZ>P0208aX>003
08iZ>P2?Jc/0SFTi0080RVHf00@0SVXj09=_?`2DKSl0U6ho0P2CKCh0102BK3d0TF/l091Z>`2@JS/3
08aW>P0308eX>`2>JC`0SfXm0080SfXm00@0R6Dk08UV?029IS`0RVLm0P2;J3h208aY?`80SFM000L0
SFPl08eX>`2=JCL0SFXd08eZ<P2=JS00RF@g0080RVDh00<0S6Lj08eX>`2>JC`00P2?JSd0202=Jcd0
S6Xl08YX>P29IcT0R6Hh08UW>@2:J3X0RfTk0`2=Id0408aV?`0408]U?P24Gc80QF0c08MR=@80R6<f
00<0Qf8e08EP<`24Gc800`23IcP[ooooo`00oooooooooooooooooooooooooooooooooooooooonOoo
ool00?ooooooooooooooooooooooooooooooooooooooooWooooo003ooooooooooooooooooooooooo
oooooooooooooooiooooo`00oooooooooooooooooooooooooooooooooooooooonOooool00?oooooo
ooooooooooooooooooooooooooooooooooWooooo003ooooooooooooooooooooooooooooooooooooo
oooiooooo`00oooooooooooooooooooooooooooooooooooooooonOooool00?oooooooooooooooooo
ooooooooooooooooooooooWooooo003ooooooooooooooooooooooooooooooooooooooooiooooo`00
oooooooooooooooooooooooooooooooooooooooonOooool00?oooooooooooooooooooooooooooooo
ooooooooooWooooo003ooooooooooooooooooooooooooooooooooooooooiooooo`00oooooooooooo
oooooooooooooooooooooooooooonOooool00?ooooooooooooooooooooooooooooooooooooooooWo
oooo003ooooooooooooooooooooooooooooooooooooooooiooooo`00oooooooooooooooooooooooo
oooooooooooooooonOooool00?ooooooooooooooooooooooooooooooooooooooooWooooo003ooooo
oooooooooooooooooooooooooooooooooooiooooo`00oooooooooooooooooooooooooooooooooooo
oooonOooool00?ooooooooooooooooooooooooooooooooooooooooWooooo003ooooooooooooooooo
oooooooooooooooooooooooiooooo`00oooooooooooooooooooooooooooooooooooooooonOooool0
0?ooooooooooooooooooooooooooooooooooooooooWooooo003ooooooooooooooooooooooooooooo
oooooooooooiooooo`00oooooooooooooooooooooooooooooooooooooooonOooool00?oooooooooo
ooooooooooooooooooooooooooooooWooooo0000\
\>"], "Picture",
  Evaluatable->False,
  ImageSize->{397.188, 250.25},
  ImageMargins->{{0, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}}],

Cell["\<\
Fig. 5.13 Reflection and refraction caustics formed by a light \
source to the left of, and slightly above, a glass of water. (Photo: D. \
Dubin.)\
\>", "Caption",
  CellTags->"Fig. 5.13"]
}, Closed]],

Cell[CellGroupData[{

Cell["5.3.2 Conservation of Wave Action", "Subsubtitle",
  CellTags->"c:36"],

Cell[TextData[{
  " In order to improve upon the lowest-order WKB approximation,  it is \
useful to introduce the \"4-wave vector\" ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["\[Kappa]",
            FontWeight->"Bold"], "=", 
          RowBox[{"(", 
            RowBox[{\(-\[Omega]\), ",", 
              StyleBox["k",
                FontWeight->"Bold",
                FontSlant->"Plain"]}], ")"}]}], TraditionalForm]]],
  ". Then the eikonal equation ",
  ButtonBox["(5.3.7)",
    ButtonData:>"(5.3.7)",
    ButtonStyle->"Hyperlink"],
  " becomes ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"D", "(", 
            RowBox[{
              StyleBox["z",
                FontWeight->"Bold",
                FontSlant->"Plain"], ",", 
              StyleBox["\[Kappa]",
                FontWeight->"Bold"]}], ")"}], "=", "0"}], TraditionalForm]]],
  ".  Because ",
  Cell[BoxData[
      \(TraditionalForm\`D\&^\)]],
  " is Hermitian, one can show that ",
  Cell[BoxData[
      FormBox[
        RowBox[{"D", "(", 
          RowBox[{
            StyleBox["z",
              FontWeight->"Bold",
              FontSlant->"Plain"], ",", 
            StyleBox["\[Kappa]",
              FontWeight->"Bold"]}], ")"}], TraditionalForm]]],
  " is a real function of ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox["z",
            FontWeight->"Bold",
            FontSlant->"Plain"], " "}], TraditionalForm]]],
  "and ",
  Cell[BoxData[
      FormBox[
        StyleBox["\[Kappa]",
          FontWeight->"Bold"], TraditionalForm]]],
  " (see the exercises). We will use this fact in the following derivation."
}], "Text"],

Cell[TextData[{
  "\tIn order to obtain an equation for the wave amplitude, we now keep terms \
of order ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\)]],
  " in Eq. ",
  ButtonBox["(5.3.1)",
    ButtonData:>"(5.3.1)",
    ButtonStyle->"Hyperlink"],
  ". For example, it is an exercise [Exercise (3)] to show that, to \
first-order in ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\)]],
  ", "
}], "Text"],

Cell[TextData[{
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(\(\[Lambda]\^n\) \[PartialD]\^n\ \[ExponentialE]\
\^\(S/\[Lambda]\)/\[PartialD]z\_i\^n\)\(=\)\(\(\[ExponentialE]\^\(S/\[Lambda]\
\)\)[\((\[PartialD]S\/\[PartialD]z\_i)\)\^n\  + \[Lambda]\ \(\(n(
                    n - 1)\)\/2\) \(\[PartialD]\^2 
                    S\/\[PartialD]z\_i\^2\) \((\[PartialD]S\/\[PartialD]z\_i)\
\)\^\(n - 2\) + 0 \((\[Lambda]\^2)\)\ ]\)\(\ \)\)\)]],
  "."
}], "NE3",
  CellTags->"(5.3.17)"],

Cell[TextData[{
  "Using identities of this sort, along with the fact that ",
  Cell[BoxData[
      FormBox[
        RowBox[{"D", "(", 
          RowBox[{
            StyleBox["z",
              FontWeight->"Bold",
              FontSlant->"Plain"], ",", 
            StyleBox["\[Kappa]",
              FontWeight->"Bold"]}], ")"}], TraditionalForm]]],
  " is real, one can prove the following important result [see Exercise \
(4)]:"
}], "Text"],

Cell[TextData[Cell[BoxData[{
    FormBox[
      RowBox[{\(0 = \(\[ExponentialE]\^\(\(S\^*\)/\[Lambda]\)\) \(D\&^\) \
\[ExponentialE]\^\(S/\[Lambda]\) - \(\(\(\[ExponentialE]\^\(S/\[Lambda]\)\) \
\((\(D\&^\) \[ExponentialE]\^\(S/\[Lambda]\))\)\)\^*\)\), "  "}], 
      TraditionalForm], "\[IndentingNewLine]", 
    FormBox[
      RowBox[{"   ", 
        RowBox[{"=", 
          RowBox[{
            RowBox[{"\[ImaginaryI]", " ", 
              
              RowBox[{\(\[ExponentialE]\^\(\((S + \(S\^*\))\)/\[Lambda]\)\), 
                "  ", "[", 
                RowBox[{
                  RowBox[{"2", " ", "Im", " ", 
                    RowBox[{"(", 
                      RowBox[{
                        RowBox[{"D", "(", 
                          RowBox[{
                            StyleBox["z",
                              FontWeight->"Bold",
                              FontSlant->"Plain"], 
                            StyleBox[",",
                              FontWeight->"Plain"], 
                            RowBox[{
                              StyleBox[\(-\[ImaginaryI]\),
                                FontWeight->"Plain"], 
                              FractionBox[\(\[PartialD]S\), 
                                RowBox[{"\[PartialD]", 
                                  StyleBox["z",
                                    FontWeight->"Bold",
                                    FontSlant->"Plain"]}]]}]}], ")"}], 
                        "-", \(\(1\/2\) \[Lambda] \(\[Sum]\+\(i, j\)\(\
\[PartialD]\^2 
                                    S\/\(\[PartialD]z\_i \[PartialD]z\_j\)\) \
\[PartialD]\^2 D\/\(\[PartialD]\[Kappa]\_i \[PartialD]\[Kappa]\_j\)\)\)}], 
                      " ", ")"}]}], "-", 
                  " ", \(\[Lambda] \(\[Sum]\+j\[PartialD]\^2 \
D\/\(\[PartialD]z\_j \[PartialD]\[Kappa]\_j\)\)\)}], " ", "]"}]}], 
            "+", \(\(O(\[Lambda]\^2)\)\(.\)\)}]}]}], 
      TraditionalForm]}]]], "NE3",
  CellTags->"(5.3.18)"],

Cell[TextData[{
  "With the substitution ",
  Cell[BoxData[
      FormBox[
        RowBox[{"S", "=", 
          RowBox[{\(S\_o\), "+", " ", 
            RowBox[{"\[Lambda]", " ", 
              StyleBox[
                RowBox[{"\[CapitalDelta]", 
                  StyleBox["S",
                    FontSlant->"Italic"]}]]}]}]}], TraditionalForm]]],
  ", Eqs. ",
  ButtonBox["(5.3.5)",
    ButtonData:>"(5.3.5)",
    ButtonStyle->"Hyperlink"],
  " imply that ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"D", "(", 
            RowBox[{
              StyleBox["z",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[",",
                FontWeight->"Plain"], 
              RowBox[{
                StyleBox[\(-\[ImaginaryI]\),
                  FontWeight->"Plain"], 
                FractionBox[\(\[PartialD]S\), 
                  RowBox[{"\[PartialD]", 
                    StyleBox["z",
                      FontWeight->"Bold",
                      FontSlant->"Plain"]}]]}]}], ")"}], "=", 
          RowBox[{"D", "(", 
            RowBox[{
              StyleBox["z",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[",",
                FontWeight->"Plain"], 
              RowBox[{
                StyleBox["\[Kappa]",
                  FontWeight->"Bold"], 
                StyleBox["-",
                  FontWeight->"Plain"], 
                RowBox[{
                  StyleBox["\[ImaginaryI]",
                    FontWeight->"Plain"], " ", "\[Lambda]", 
                  FractionBox[
                    RowBox[{"\[PartialD]", 
                      StyleBox[
                        RowBox[{"\[CapitalDelta]", 
                          StyleBox["S",
                            FontSlant->"Italic"]}]]}], 
                    RowBox[{"\[PartialD]", 
                      StyleBox["z",
                        FontWeight->"Bold",
                        FontSlant->"Plain"]}]]}]}]}], ")"}]}], 
        TraditionalForm]]],
  ". Taylor-expanding to first-order in ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\)]],
  " , the zeroth-order terms in Eq. ",
  ButtonBox["(5.3.18)",
    ButtonData:>"(5.3.18)",
    ButtonStyle->"Hyperlink"],
  "  cancel, and using ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(\[PartialD]S\_o\), "/", 
            RowBox[{"\[PartialD]", 
              StyleBox["z",
                FontWeight->"Bold",
                FontSlant->"Plain"]}]}], 
          StyleBox[" ",
            FontWeight->"Plain"], 
          StyleBox["=",
            FontWeight->"Plain"], 
          StyleBox[" ",
            FontWeight->"Plain"], 
          RowBox[{
            StyleBox["\[ImaginaryI]",
              FontWeight->"Plain"], 
            StyleBox[" ",
              FontWeight->"Plain"], 
            StyleBox["\[Kappa]",
              FontWeight->"Bold"]}]}], TraditionalForm]]],
  " we obtain "
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{"0", "=", 
        RowBox[{\(-\[ImaginaryI]\), " ", "\[Lambda]", " ", 
          RowBox[{
            
            RowBox[{\(\[ExponentialE]\^\(\((S + \(S\^*\))\)/\[Lambda]\)\), 
              "[", 
              RowBox[{
                RowBox[{
                  FractionBox[\(\[PartialD]D\), 
                    RowBox[{"\[PartialD]", 
                      StyleBox["\[Kappa]",
                        FontWeight->"Bold"]}]], "\[CenterDot]", 
                  FractionBox[
                    RowBox[{"\[PartialD]", 
                      StyleBox[
                        RowBox[{"\[CapitalDelta]", 
                          StyleBox["S",
                            FontSlant->"Italic"]}]]}], 
                    RowBox[{"\[PartialD]", 
                      StyleBox["z",
                        FontWeight->"Bold",
                        FontSlant->"Plain"]}]]}], "+", 
                RowBox[{
                  FractionBox[\(\[PartialD]D\), 
                    RowBox[{"\[PartialD]", 
                      StyleBox["\[Kappa]",
                        FontWeight->"Bold"]}]], "\[CenterDot]", 
                  FractionBox[
                    RowBox[{"\[PartialD]", 
                      SuperscriptBox[
                        StyleBox[
                          RowBox[{"\[CapitalDelta]", 
                            StyleBox["S",
                              FontSlant->"Italic"]}]], "*"]}], 
                    RowBox[{"\[PartialD]", 
                      StyleBox["z",
                        FontWeight->"Bold",
                        FontSlant->"Plain"]}]]}], 
                "+", \(\[Sum]\+\(i, j\)\(\[PartialD]\ \
\[Kappa]\_j\/\[PartialD]z\_i\) \[PartialD]\^2 D\/\(\[PartialD]\[Kappa]\_i \
\[PartialD]\[Kappa]\_j\)\), 
                "+", \(\[Sum]\+j\[PartialD]\^2 D\/\(\[PartialD]z\_j \
\[PartialD]\[Kappa]\_j\)\)}], "]"}], " ", "."}]}]}], 
      TraditionalForm]]]], "NE3",
  CellTags->"(5.3.19)"],

Cell[TextData[{
  "We now substitute ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          StyleBox[
            RowBox[{"\[CapitalDelta]", 
              StyleBox["S",
                FontSlant->"Italic"]}]], "=", " ", \(ln(A)\)}], 
        TraditionalForm]]],
  ", where ",
  Cell[BoxData[
      FormBox[
        RowBox[{"A", "(", 
          RowBox[{
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[",",
              FontWeight->"Plain"], 
            StyleBox["t",
              FontWeight->"Plain"]}], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  " is the amplitude of the solution: ",
  Cell[BoxData[
      \(TraditionalForm\`f = \ 
        A\ \[ExponentialE]\^\(\[ImaginaryI]\ \[Phi]\)\)]],
  ".  Then, Eq. ",
  ButtonBox["(5.3.19)",
    ButtonData:>"(5.3.19)",
    ButtonStyle->"Hyperlink"],
  " becomes"
}], "Text"],

Cell[TextData[{
  "\t\t",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{\(A\^*\), 
              RowBox[{
                FractionBox[\(\[PartialD]D\), 
                  RowBox[{"\[PartialD]", 
                    StyleBox["\[Kappa]",
                      FontWeight->"Bold"]}]], "\[CenterDot]", 
                FractionBox[\(\[PartialD]A\), 
                  RowBox[{"\[PartialD]", 
                    StyleBox["z",
                      FontWeight->"Bold",
                      FontSlant->"Plain"]}]]}]}], "+", 
            RowBox[{"A", 
              RowBox[{
                FractionBox[\(\[PartialD]D\), 
                  RowBox[{"\[PartialD]", 
                    StyleBox["\[Kappa]",
                      FontWeight->"Bold"]}]], "\[CenterDot]", 
                FractionBox[\(\[PartialD]\(A\^*\)\), 
                  RowBox[{"\[PartialD]", 
                    StyleBox["z",
                      FontWeight->"Bold",
                      FontSlant->"Plain"]}]]}]}], 
            "+", \(\((\[Sum]\+\(i, j\)\(\[PartialD]\ \
\[Kappa]\_j\/\[PartialD]z\_i\) \[PartialD]\^2 D\/\(\[PartialD]\[Kappa]\_i \
\[PartialD]\[Kappa]\_j\) + \[Sum]\+j\[PartialD]\^2 D\/\(\[PartialD]z\_j \
\[PartialD]\[Kappa]\_j\))\) \((\(|\)\(A\)\(|\))\)\^2\)}], "=", "0"}], 
        TraditionalForm]]],
  "."
}], "Text"],

Cell["However, this expression collapses to", "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FractionBox["\[PartialD]", 
              RowBox[{"\[PartialD]", 
                StyleBox["z",
                  FontWeight->"Bold",
                  FontSlant->"Plain"]}]], "\[CenterDot]", 
            RowBox[{"(", 
              RowBox[{
                FractionBox[\(\[PartialD]D\), 
                  RowBox[{"\[PartialD]", 
                    StyleBox["\[Kappa]",
                      FontWeight->"Bold"]}]], \(\((\(|\)\(A\)\(|\))\)\^2\)}], 
              ")"}]}], "=", "0"}], TraditionalForm]]],
  ","
}], "NE3",
  CellTags->"(5.3.20)"],

Cell[TextData[{
  "where the partial derivative ",
  Cell[BoxData[
      FormBox[
        FractionBox["\[PartialD]", 
          RowBox[{"\[PartialD]", 
            StyleBox["z",
              FontWeight->"Bold",
              FontSlant->"Plain"]}]], TraditionalForm]]],
  " does not hold ",
  Cell[BoxData[
      FormBox[
        StyleBox["\[Kappa]",
          FontWeight->"Bold"], TraditionalForm]]],
  " fixed; rather,  ",
  Cell[BoxData[
      FormBox[
        StyleBox["\[Kappa]",
          FontWeight->"Bold"], TraditionalForm]]],
  " is taken to be a function of ",
  Cell[BoxData[
      FormBox[
        StyleBox["z",
          FontSlant->"Plain"], TraditionalForm]],
    FontWeight->"Bold"],
  " given by the solution of the geometric optics equations. "
}], "Text"],

Cell[TextData[{
  "\tEquation ",
  ButtonBox["(5.3.20)",
    ButtonData:>"(5.3.20)",
    ButtonStyle->"Hyperlink"],
  " is the required conservation law. It can be put in more familiar form by  \
going back to  ",
  Cell[BoxData[
      FormBox[
        RowBox[{"(", 
          RowBox[{
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[",",
              FontWeight->"Plain"], 
            StyleBox["t",
              FontWeight->"Plain"]}], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  "  and ",
  Cell[BoxData[
      FormBox[
        RowBox[{"(", 
          RowBox[{\(-\[Omega]\), ",", 
            StyleBox["k",
              FontWeight->"Bold",
              FontSlant->"Plain"]}], ")"}], TraditionalForm]]],
  " notation:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          
          RowBox[{\(\(-\(\[PartialD]\/\[PartialD]t\)\) \((\(\[PartialD]D\/\
\[PartialD]\[Omega]\) \((\(|\)\(A\)\(|\))\)\^2)\)\), "+", 
            RowBox[{"\[Del]", 
              RowBox[{"\[CenterDot]", 
                RowBox[{"(", 
                  RowBox[{
                    FractionBox[\(\[PartialD]D\), 
                      RowBox[{"\[PartialD]", 
                        StyleBox["k",
                          FontWeight->"Bold",
                          
                          FontSlant->
                            "Plain"]}]], \(\((\(|\)\(A\)\(|\))\)\^2\)}], 
                  ")"}]}]}]}], "=", "0"}], TraditionalForm]]],
  "."
}], "NE3",
  CellTags->"(5.3.21)"],

Cell[TextData[{
  "We now define the ",
  StyleBox["wave action",
    FontSlant->"Italic"],
  " ",
  Cell[BoxData[
      FormBox[
        RowBox[{"N", "(", 
          RowBox[{
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[",",
              FontWeight->"Plain"], 
            StyleBox["t",
              FontWeight->"Plain"]}], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  ","
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{"N", "(", 
            RowBox[{
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"], 
              StyleBox[",",
                FontWeight->"Plain"], 
              StyleBox["t",
                FontWeight->"Plain"]}], 
            StyleBox[")",
              FontWeight->"Plain"]}], 
          StyleBox[" ",
            FontWeight->"Plain"], 
          StyleBox["=",
            FontWeight->"Plain"], 
          
          RowBox[{\(\[PartialD]D\/\[PartialD]\[Omega]\), \
\(\((\(|\)\(A\)\(|\))\)\^2\), 
            StyleBox[" ",
              FontWeight->"Plain"]}]}], TraditionalForm]]],
  ". "
}], "NE3",
  CellTags->"(5.3.22)"],

Cell[TextData[{
  "With this definition,  and using the identity ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{\(\[PartialD]\[Omega]\), "/", 
            RowBox[{"\[PartialD]", 
              StyleBox["k",
                FontWeight->"Bold",
                FontSlant->"Plain"]}]}], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{
            RowBox[{
              StyleBox["-",
                FontWeight->"Plain"], 
              RowBox[{
                StyleBox["(",
                  FontWeight->"Plain"], 
                RowBox[{\(\[PartialD]D\), "/", 
                  RowBox[{"\[PartialD]", 
                    StyleBox["k",
                      FontWeight->"Bold",
                      FontSlant->"Plain"]}]}], ")"}]}], 
            StyleBox["/",
              FontWeight->"Plain"], 
            RowBox[{
              StyleBox["(",
                FontWeight->"Plain"], \(\[PartialD]D/\[PartialD]\[Omega]\), 
              ")"}]}]}], TraditionalForm]]],
  ",  Eq. ",
  ButtonBox["(5.3.21)",
    ButtonData:>"(5.3.21)",
    ButtonStyle->"Hyperlink"],
  " becomes"
}], "Text"],

Cell[TextData[Cell[BoxData[
    FormBox[
      RowBox[{
        RowBox[{
          RowBox[{
            RowBox[{\(\[PartialD]\/\[PartialD]t\), 
              RowBox[{"N", "(", 
                RowBox[{
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], 
                  StyleBox[",",
                    FontWeight->"Plain"], 
                  StyleBox["t",
                    FontWeight->"Plain"]}], 
                StyleBox[")",
                  FontWeight->"Plain"]}]}], "+", 
            RowBox[{"\[Del]", 
              RowBox[{"\[CenterDot]", 
                RowBox[{"[", 
                  RowBox[{
                    RowBox[{
                      SubscriptBox[
                        StyleBox["v",
                          FontWeight->"Bold",
                          FontSlant->"Plain"], "g"], "(", 
                      RowBox[{
                        StyleBox["r",
                          FontWeight->"Bold",
                          FontSlant->"Plain"], 
                        StyleBox[",",
                          FontWeight->"Plain"], 
                        StyleBox["t",
                          FontWeight->"Plain"]}], 
                      StyleBox[")",
                        FontWeight->"Plain"]}], " ", 
                    RowBox[{"N", "(", 
                      RowBox[{
                        StyleBox["r",
                          FontWeight->"Bold",
                          FontSlant->"Plain"], 
                        StyleBox[",",
                          FontWeight->"Plain"], 
                        StyleBox["t",
                          FontWeight->"Plain"]}], 
                      StyleBox[")",
                        FontWeight->"Plain"]}]}], "]"}]}]}]}], "=", "0"}], 
        ","}], TraditionalForm]]]], "NE3",
  CellTags->{"i:120", "(5.3.23)"}],

Cell[TextData[{
  "where ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          SubscriptBox[
            StyleBox["v",
              FontWeight->"Bold",
              FontSlant->"Plain"], "g"], "(", 
          RowBox[{
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[",",
              FontWeight->"Plain"], 
            StyleBox["t",
              FontWeight->"Plain"]}], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  "is the group velocity.  Equation ",
  ButtonBox["(5.3.23)",
    ButtonData:>"(5.3.23)",
    ButtonStyle->"Hyperlink"],
  " implies that the wave action ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(N\)\(\ \)\)\)]],
  "is transported at the group velocity, and is a conserved quantity: ",
  Cell[BoxData[
      \(TraditionalForm\`\[Integral]N \[DifferentialD]\^3 r\)]],
  " is constant, assuming that ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(N\)\(\[Rule]\)\(\ \)\(0\)\(\ \)\)\)]],
  "at infinity faster than ",
  Cell[BoxData[
      \(TraditionalForm\`1/r\^2\)]],
  ". "
}], "Text",
  CellTags->"i:92"],

Cell[TextData[{
  "\tComparing Eq. ",
  ButtonBox["(5.3.22)",
    ButtonData:>"(5.3.22)",
    ButtonStyle->"Hyperlink"],
  "  with  Eq. ",
  ButtonBox["(5.1.102)",
    ButtonData:>"(5.1.102)",
    ButtonStyle->"Hyperlink"],
  ", we see that the wave action is identical to the conserved quantity for \
Schr\[ODoubleDot]dinger-like wave equations in a uniform medium. For Schr\
\[ODoubleDot]dinger's equation itself, the wave action is just \[HBar] times \
the probability density ",
  Cell[BoxData[
      \(TraditionalForm\`\((\(|\)\(\[Psi]\)\(|\))\)\^2\)]],
  ".   Furthermore, comparing Eq. ",
  ButtonBox["(5.3.22)",
    ButtonData:>"(5.3.22)",
    ButtonStyle->"Hyperlink"],
  " with Eq. ",
  ButtonBox["(5.2.60)",
    ButtonData:>"(5.2.60)",
    ButtonStyle->"Hyperlink"],
  " , we see that for classical wave equations the wave action and the energy \
density are closely related:"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]\ N/4\  = \ \[Epsilon]\&_/\[Omega]\)]],
  "."
}], "NE3",
  CellTags->"(5.3.24)"],

Cell[TextData[{
  "Except for  the constant factor ",
  Cell[BoxData[
      \(TraditionalForm\`\[Rho]/4\)]],
  ", the wave action is related to the energy density in the same way as the \
adiabatic invariant for a harmonic oscillator is related to its energy; see \
Eq. ",
  ButtonBox["(5.2.24)",
    ButtonData:>"(5.2.24)",
    ButtonStyle->"Hyperlink"],
  ". From the perspective of quantum mechanics, a wave is made up of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(N\)\(\ \)\)\)]],
  "photons per unit volume with energy per unit volume ",
  Cell[BoxData[
      \(TraditionalForm\`\[Epsilon]\  = \ N\ \[HBar]\ \[Omega]\)]],
  ", and the conservation of wave action corresponds to the conservation of \
photon number ",
  Cell[BoxData[
      \(TraditionalForm\`N = \[Epsilon]/\[HBar]\[Omega]\)]],
  ". In other words, in media with slowly varying time or space dependence, \
photons are neither created nor destroyed.   When the system is \
time-independent, Eq. ",
  ButtonBox["(5.3.14)",
    ButtonData:>"(5.3.14)",
    ButtonStyle->"Hyperlink"],
  " implies that ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\)]],
  " is a fixed parameter of the wave packet, and conservation of wave action \
is then equivalent to conservation of energy. "
}], "Text",
  CellTags->"i:93"]
}, Closed]],

Cell[CellGroupData[{

Cell["Exercises for Sec. 5.3", "Subsubtitle",
  CellTags->"c:37"],

Cell[TextData[{
  StyleBox["(1)(a)",
    FontWeight->"Bold"],
  " Solve Eqs. ",
  ButtonBox["(5.3.12)",
    ButtonData:>"(5.3.12)",
    ButtonStyle->"Hyperlink"],
  " - ",
  ButtonBox["(5.3.13)",
    ButtonData:>"(5.3.13)",
    ButtonStyle->"Hyperlink"],
  " to determine the evolution of the wavenumber ",
  Cell[BoxData[
      \(TraditionalForm\`k(t)\)]],
  " and position ",
  Cell[BoxData[
      \(TraditionalForm\`x(t)\)]],
  " from given initial conditions ",
  Cell[BoxData[
      \(TraditionalForm\`x = x\_o\)]],
  ", ",
  Cell[BoxData[
      \(TraditionalForm\`k = k\_o\)]],
  ", for the following dispersion relation: ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\  = \ \[Alpha]\ x\ k\^2\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Alpha]\)]],
  " is a constant."
}], "Text"],

Cell[TextData[{
  " ",
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Use the results of part (a) determine ",
  Cell[BoxData[
      \(TraditionalForm\`k(x, t)\)]],
  " and ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega](x, t)\)]],
  ", given the following initial conditions on the phase:"
}], "Text"],

Cell[TextData[{
  " (i)  ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](x, 0)\  = \ \(k\_o\) x\)]],
  ". "
}], "Text"],

Cell[TextData[{
  " (ii) ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](x, 0) = 2\ \@\(\[Omega]\_o\ x/\[Alpha]\)\)]],
  ", where ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_o\)]],
  " is a constant. "
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Use these results, along with Eq. ",
  ButtonBox["(5.3.6)",
    ButtonData:>"(5.3.6)",
    ButtonStyle->"Hyperlink"],
  " to determine the phase ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](x, t)\)]],
  ". \n[Solution for (i): ",
  Cell[BoxData[
      \(TraditionalForm\`\[Phi](x, t) = \(k\_o\) 
          x/\((1\  + \ \[Alpha]\ k\_o\ t)\)\)]],
  ". ]"
}], "Text"],

Cell[TextData[{
  StyleBox["(2)",
    FontWeight->"Bold"],
  " For the example displayed in Cell ",
  ButtonBox["5.44",
    ButtonData:>"Cell 5.44",
    ButtonStyle->"Hyperlink"],
  ", assume that the dispersion function ",
  Cell[BoxData[
      FormBox[
        RowBox[{"D", "=", 
          RowBox[{\(\[Omega]\^2\), "-", 
            RowBox[{
              SuperscriptBox[
                RowBox[{"c", "(", 
                  StyleBox["r",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], 
                  StyleBox[")",
                    FontWeight->"Plain"]}], \(\(2\)\(\ \)\)], \(k\^2\)}]}]}], 
        TraditionalForm]]],
  ", and that a time-independent beam with wavenumber ",
  Cell[BoxData[
      \(TraditionalForm\`\[Kappa] = 1\)]],
  " is directed along the ",
  Cell[BoxData[
      \(TraditionalForm\`y - axis\)]],
  ".  Use Eq. ",
  ButtonBox["(5.3.16)",
    ButtonData:>"(5.3.16)",
    ButtonStyle->"Hyperlink"],
  " to determine the amplitude ",
  Cell[BoxData[
      \(TraditionalForm\`A(y)\)]],
  " of the beam along the ",
  Cell[BoxData[
      \(TraditionalForm\`y - axis\)]],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`\((x = 0)\)\)]],
  ", assuming that the  ",
  Cell[BoxData[
      \(TraditionalForm\`A(0) = 1\)]],
  ". Plot the result for ",
  Cell[BoxData[
      \(TraditionalForm\`0 < y < 6\)]],
  ". (Hint: Numerically evaluate the width ",
  Cell[BoxData[
      \(TraditionalForm\`d\)]],
  " of the ray tube that travels down the y-axis.) "
}], "Text"],

Cell[TextData[{
  StyleBox["(3)",
    FontWeight->"Bold"],
  " Prove Eq. ",
  ButtonBox["(5.3.17)",
    ButtonData:>"(5.3.17)",
    ButtonStyle->"Hyperlink"],
  " for:"
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " ",
  Cell[BoxData[
      \(TraditionalForm\`n = 2\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  "  general ",
  Cell[BoxData[
      \(TraditionalForm\`n \[GreaterEqual] \ 2\)]],
  ". (Hint: Use recursion. Assuming that the result is correct for ",
  Cell[BoxData[
      \(TraditionalForm\`n = n\_o\)]],
  ", prove it for ",
  Cell[BoxData[
      \(TraditionalForm\`n = n\_o + 1\)]],
  ".)"
}], "Text"],

Cell[TextData[{
  StyleBox["(4)",
    FontWeight->"Bold"],
  " Consider the following linear differential operator ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(D\)\(\ \)\)\&^\)]],
  ", acting on a function ",
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            RowBox[{"f", "(", 
              StyleBox["z",
                FontWeight->"Bold",
                FontSlant->"Plain"], ")"}], " ", "where", " ", 
            StyleBox["z",
              FontWeight->"Bold",
              FontSlant->"Plain"]}], 
          StyleBox[" ",
            FontWeight->"Plain"], 
          StyleBox["=",
            FontWeight->"Plain"], 
          RowBox[{
            StyleBox["(",
              FontWeight->"Plain"], 
            RowBox[{
              StyleBox["t",
                FontWeight->"Plain"], 
              StyleBox[",",
                FontWeight->"Plain"], 
              StyleBox["r",
                FontWeight->"Bold",
                FontSlant->"Plain"]}], ")"}]}], TraditionalForm]]],
  ":"
}], "Text"],

Cell[TextData[{
  Cell[BoxData[
      FormBox[
        RowBox[{\(\(\(\(D\)\(\ \)\)\&^\) f\), "=", 
          RowBox[{\(\[Sum]\+\(n, m = 0\)\%M\), 
            RowBox[{\(\[Sum]\+\(j, k = 1\)\%4\), 
              RowBox[{\(\[PartialD]\^n\/\[PartialD]z\_j\^n\), 
                RowBox[{\(b\_\(j\ k\ n\ m\)\), "(", 
                  StyleBox["z",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], 
                  StyleBox[")",
                    
                    FontWeight->
                      "Plain"]}], \(\[PartialD]\^m\/\[PartialD]z\_k\^m\), 
                RowBox[{"f", "(", 
                  StyleBox["z",
                    FontWeight->"Bold",
                    FontSlant->"Plain"], 
                  StyleBox[")",
                    FontWeight->"Plain"]}]}]}]}]}], TraditionalForm]]],
  "."
}], "NE3",
  CellTags->"(5.3.25)"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Show that this operator is Hermitian with respect to the inner product ",
  Cell[BoxData[
      FormBox[
        RowBox[{\((f, g)\), " ", "=", " ", 
          RowBox[{"\[Integral]", 
            RowBox[{
              RowBox[{\(\[DifferentialD]\^3\), 
                StyleBox["r",
                  FontWeight->"Bold",
                  FontSlant->"Plain"]}], \(\[DifferentialD]t\), 
              " ", \(f\^\(\(\ \)\(*\)\)\), "  ", "g", " "}]}]}], 
        TraditionalForm]]],
  ", provided that ",
  Cell[BoxData[
      \(TraditionalForm\`b\_\(k\ j\ m\ n\) = \ \(\(\((\(-1\))\)\^\(m + 
                n\)\) \(b\_\(j\ k\ n\ m\)\%\(\(\ \)\(*\)\)\)\(\ \)\)\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Under the conditions of part (a), show that the dispersion relation ",
  Cell[BoxData[
      FormBox[
        RowBox[{"D", "(", 
          RowBox[{
            StyleBox["z",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[",",
              FontWeight->"Plain"], 
            StyleBox["\[Kappa]",
              FontWeight->"Bold"]}], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  " associated with this operator is a real function of ",
  Cell[BoxData[
      FormBox[
        StyleBox["z",
          FontWeight->"Bold",
          FontSlant->"Plain"], TraditionalForm]]],
  " and ",
  Cell[BoxData[
      FormBox[
        StyleBox["\[Kappa]",
          FontWeight->"Bold"], TraditionalForm]]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Prove Eq. ",
  ButtonBox["(5.3.18)",
    ButtonData:>"(5.3.18)",
    ButtonStyle->"Hyperlink"],
  " using the operator of Eq. ",
  ButtonBox["(5.3.25)",
    ButtonData:>"(5.3.25)",
    ButtonStyle->"Hyperlink"],
  " , for ",
  Cell[BoxData[
      \(TraditionalForm\`M = 2\)]],
  ". (Hint: Taylor expand in ",
  Cell[BoxData[
      \(TraditionalForm\`\[Lambda]\)]],
  " using ",
  StyleBox["Series",
    FontFamily->"Courier",
    FontWeight->"Bold"],
  " )."
}], "Text"],

Cell[TextData[{
  StyleBox["(d)",
    FontWeight->"Bold"],
  " Prove Eq. ",
  ButtonBox["(5.3.18)",
    ButtonData:>"(5.3.18)",
    ButtonStyle->"Hyperlink"],
  " for general ",
  Cell[BoxData[
      \(TraditionalForm\`M\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(5)",
    FontWeight->"Bold"],
  " A wave packet of plane-polarized light travels across a gas cell where \
the density of gas is uniform, but is varying with time as gas is removed or \
added. As a result, the index of refraction is ",
  Cell[BoxData[
      \(TraditionalForm\`n = n(t)\)]],
  ".  Maxwell's equations then imply that the electric field ",
  Cell[BoxData[
      FormBox[
        RowBox[{"E", "(", 
          RowBox[{
            StyleBox["r",
              FontWeight->"Bold",
              FontSlant->"Plain"], 
            StyleBox[",",
              FontWeight->"Plain"], 
            StyleBox["t",
              FontWeight->"Plain"]}], 
          StyleBox[")",
            FontWeight->"Plain"]}], TraditionalForm]]],
  "satisfies the following  wave equation:\n\t\t",
  Cell[BoxData[
      \(TraditionalForm\`\(\[PartialD]\/\[PartialD]t\) \(n(
              t)\) \(\[PartialD]\/\[PartialD]t\) E - \(c\^2\) \[Del]\^2 E\  = 
        0\)]],
  "."
}], "Text"],

Cell[TextData[{
  StyleBox["(a)",
    FontWeight->"Bold"],
  " Show that this equation is Hermitian with respect to the inner product \
given in the previous problem."
}], "Text"],

Cell[TextData[{
  StyleBox["(b)",
    FontWeight->"Bold"],
  " Show that the wave packet still travels in a straight line, and determine \
how its central frequency varies with time. If the index increases, does the \
frequency increase or decrease? "
}], "Text"],

Cell[TextData[{
  StyleBox["(c)",
    FontWeight->"Bold"],
  " Determine how the amplitude ",
  Cell[BoxData[
      \(TraditionalForm\`A\)]],
  " of the wave packet varies with time. If the index increases, does the \
amplitude increase or decrease?"
}], "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{

Cell["References", "Subtitle",
  CellTags->{"refs", "c:34"}],

Cell[TextData[{
  "C. Bender and  S. Orzag, ",
  StyleBox["Advanced Mathematical Methods for Scientists and Engineers",
    FontSlant->"Italic"],
  ", (McGraw-Hill, New-York, 1978)."
}], "Text"],

Cell[TextData[{
  "H. Goldstein, ",
  StyleBox["Classical Mechanics",
    FontSlant->"Italic"],
  ", 2nd ed. (Addison Wesley,  Reading, Mass.,1980)"
}], "Text"],

Cell[TextData[{
  "D. J. Griffiths, ",
  StyleBox["Introduction to Electrodynamics, ",
    FontSlant->"Italic"],
  "3rd ed",
  StyleBox[". ",
    FontSlant->"Italic"],
  " (Prentice Hall, Englewood Cliffs, NJ, 1999)."
}], "Text"],

Cell[TextData[{
  "I. Kay and J.B. Keller, ",
  StyleBox["Asymptotic evaluation of the field at a caustic",
    FontSlant->"Italic"],
  ", J. Appl. Phys. ",
  StyleBox["25",
    FontWeight->"Bold"],
  ", 876 (1954).",
  "\nP. K. Kundu, ",
  StyleBox[" Fluid Mechanics",
    FontSlant->"Italic"],
  ", (Academic Press, San Diego, 1990)."
}], "Text"],

Cell[TextData[{
  "L.D. Landau and E. M. Lifshitz, ",
  StyleBox["Mechanics",
    FontSlant->"Italic"],
  ", 3rd ed. (Pergamon Press, Oxford, 1976)"
}], "Text"],

Cell[TextData[{
  "E. H. Lockwood, ",
  StyleBox["A Book of Curves ",
    FontSlant->"Italic"],
  "(Cambridge University Press, Cambridge, 1967)."
}], "Text"],

Cell[TextData[{
  "M. Schulz and L. Lanzerotti, ",
  StyleBox["Particle Diffusion in the Radiation Belts ",
    FontSlant->"Italic"],
  " (Springer-Verlag, 1974)."
}], "Text"],

Cell[TextData[{
  "T. Stix, ",
  StyleBox["Theory of Plasma Waves",
    FontSlant->"Italic"],
  ",  (McGraw-Hill, New York, 1962)."
}], "Text"],

Cell[TextData[{
  "S. Weinberg, ",
  StyleBox["Eikonal Methods in Geometrical Optics",
    FontSlant->"Italic"],
  ", Phys. Rev. ",
  StyleBox["126",
    FontWeight->"Bold"],
  ", 1899 (1962). "
}], "Text"]
}, Closed]]
}, Open  ]]
},
FrontEndVersion->"4.1 for Macintosh",
ScreenRectangle->{{0, 1024}, {0, 746}},
ShowPageBreaks->False,
WindowToolbars->"EditBar",
WindowSize->{800, 556},
WindowMargins->{{1, Automatic}, {Automatic, 0}},
Visible->True,
PrintingCopies->1,
PrintingPageRange->{1, Automatic},
PageHeaders->{{Inherited, Inherited, Cell[ 
        TextData[ {"Chapter 5, Section 5.", 
          CounterBox[ "Subtitle"]}], "Header"]}, {Cell[ 
        TextData[ "Dubin"], "Header"], Cell[ 
        TextData[ 
        "Numerical and Analytical Methods for Scientists and Engineers"], 
        FontWeight -> Bold, FontSlant -> Italic, FontFamily -> Times], 
      Inherited}},
TaggingRules:>{"NextIndexingNumber" -> 143, "IndexEntries" -> {{"i:110", \
"Dominant balance"}, {"i:12", "Wavepacket"}, {"i:128", "Brillouin, \
L\[EAcute]on"}, {"i:128", "Jeffreys, Harold"}, {"i:128", "Rayleigh, John"}, \
{"i:13", "Group velocity"}, {"i:130", "Retarded time"}, {"i:131", \
"Decibels"}, {"i:132", "Caustics"}, {"i:133", "Diffraction"}, {"i:134", \
"Diffraction"}, {"i:135", "Huygens"}, {"i:136", "wavepacket amplitude"}, \
{"i:137", "Wave kinetic equation"}, {"i:138", "Evanescence"}, {"i:140", \
"Asymptotic expansion"}, {"i:18", "Wavevector"}, {"i:39", "Doppler shift"}, \
{"i:47", "Bessel beam"}, {"i:51", {"Poynting flux (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Energy flux)"}}, {"i:53", "Mach cone"}, {"i:56", "Whistler \
waves"}, {"i:69", "WKB limit"}, {"i:70", "Dominant balance"}, {"i:79", \
"Geometrical optics"}, {"i:83", "Turning points"}, {"i:9", "Phase velocity"}, \
{"i:1", "Partial differential equations", {"in infinite domains (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Fourier transforms, WKB method)"}}, {"i:10", "Dispersion", \
"definition"}, {"i:100", "Plasma", "propagation of radio waves through"}, \
{"i:102", {"Waves (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Eigenmodes)"}, "P-"}, {"i:104", "Boundary conditions", \
"moving"}, {"i:104", "WKB method", "for a string with time-varying length"}, \
{"i:106", "Wave equation", {"WKB solution (", 
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " WKB method)"}}, {"i:109", "Airy functions", "asymptotic form \
for large argument"}, {"i:114", "Geometrical optics", "Hamiltonian form"}, \
{"i:114", "Hamiltonian", "in geometrical optics"}, {"i:115", "Geometrical \
optics", "equations of, derivation"}, {"i:117", "Flux", {"momentum (", 
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " Momentum flux)"}}, {"i:117", "Momentum", "flux"}, {"i:118", \
"Wave equation", "vector"}, {"i:119", "Continuity equation", "for energy \
density"}, {"i:12", "Density", {"probability (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Shroedinger's equation)"}}, {"i:120", "Continuity equation", \
"for wave action"}, {"i:121", {"Eikonal (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " WKB method)"}, "equation"}, {"i:122", {"Eikonal (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " WKB method)"}, "equation"}, {"i:129", "Dispersion", "relation, \
for light"}, {"i:139", "Group velocity", "definition, in 3 dimensions"}, \
{"i:14", "Group velocity", "definition, in 1 dimension"}, {"i:141", "WKB \
method ", "for travelleing waves in multiple dimensions"}, {"i:142", "Phase", \
"WKB"}, {"i:15", "Dispersion", "of a Gaussian wavepacket, in 1 dimension"}, \
{"i:16", "Wavepacket", "width, Gaussian, in 1 dimension"}, {"i:17", \
"Shroedinger's equation", "multidimensional"}, {"i:20", "Group velocity", "in \
an isotropic medium"}, {"i:21", "Phase velocity", "in multidimensions"}, \
{"i:24", "Dispersion", "longitudinal and transverse"}, {"i:27", "Wavepacket", \
{"velocity (", 
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " Group velocity)"}}, {"i:30", "Wavepacket", "average energy \
density and flux"}, {"i:32", "Wavepacket", "energy density and flux for \
general classical wave equation"}, {"i:33", "Density", {"momentum (", 
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " Momentum density)"}}, {"i:33", "Momentum", "density"}, \
{"i:33", "Wavepacket", "average momentum density"}, {"i:34", "Energy", {"in \
wavepacket (", 
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " Wavepacket)"}}, {"i:35", "Wave equation", "general classical \
form"}, {"i:36", "Dispersion", "relation, for classical wave equations"}, \
{"i:37", "Potential", "retarded"}, {"i:40", "Fourier transforms", "in \
spherical coordinates"}, {"i:41", "Heat equation", "Green's function"}, \
{"i:42", "Group velocity", "for complex frequencies (damped waves)"}, \
{"i:43", "Phase velocity", "for complex frequencies (damped waves)"}, \
{"i:44", "Dispersion", "relation, for heat equation"}, {"i:48", \
"Shroedinger's equation", "conservation law for probability density"}, \
{"i:49", "Wave equation", "general quantum form"}, {"i:5", "Fourier \
transforms", "used to solve 1D wave equation"}, {"i:52", "Fourier \
transforms", "in cylindrical coordinates"}, {"i:54", "Plasma", "waves, \
magnetized"}, {"i:55", "Frequency", {"plasma (", 
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " Plasma frequency)"}}, {"i:55", "Plasma", "frequency"}, \
{"i:56", "Plasma", {"waves, whistler (", 
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " Whistler waves)"}}, {"i:57", "Frequency", "cyclotron"}, \
{"i:58", "Dispersion", "of whistler waves"}, {"i:59", "Fourier transforms", \
"in solution of 3D wave equation"}, {"i:6", "Wave equation", "d'Alembert's \
solution"}, {"i:60", "Fourier transforms", "in solution of 3D heat \
equation"}, {"i:61", "Fourier transforms", "in cylindrical coordinates"}, \
{"i:62", "Fourier transforms", "in cylindrical coordinates"}, {"i:63", \
"Fourier transforms", "in cylindrical coordinates"}, {"i:64", "Fourier \
transforms", "in cylindrical coordinates"}, {"i:65", "Fourier transforms", \
"in cylindrical coordinates"}, {"i:71", "WKB method", "higher-order \
corrections"}, {"i:72", "WKB method", "for travelling waves on a nonuniform \
string"}, {"i:73", "WKB method", "and adiabatic invariants"}, {"i:75", "WKB \
method", "for shallow water waves near a beach"}, {"i:77", "WKB method", "ray \
trajectories"}, {"i:78", "WKB method", "Snell's law"}, {"i:8", "Dispersion", \
"relation, for free quantum particle"}, {"i:80", "Wavepacket", {"trajectory \
(", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Geometrical optics)"}}, {"i:80", "WKB method", {"wavepacket \
trajectory (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Geometric optics)"}}, {"i:81", "Geometrical optics", \
"equations of"}, {"i:82", "Geometrical optics", "connection to ray \
trajectories"}, {"i:84", "Turning points", "and total internal reflection"}, \
{"i:85", "Geometrical optics", "for quantum system"}, {"i:86", "Turning \
points", "and breakdown of WKB method"}, {"i:87", "Turning points", "behavior \
of a wave near"}, {"i:89", "Geometrical optics", "and neglect of \
dispersion"}, {"i:90", "Geometrical optics", {"wavepacket amplitude (", 
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " Wave action)"}}, {"i:90", "Wave action", "for general \
classical wave equations"}, {"i:91", "Dispersion", "relation, local"}, \
{"i:92", "Wave action", "conservation law"}, {"i:93", "Wave action", \
"connection to adiabatic invariants"}, {"i:94", "Bessel functions", \
"asymptotic form for large argument"}, {"i:95", "Recursion relation", "used \
in WKB method"}, {"i:96", "Recursion relation", "used in WKB method"}, \
{"i:97", "Recursion relation", "used in approximate solution of polynomial \
roots"}, {"i:98", "WKB method", "for solution to general wave equation in \
1D"}, {"i:101", {"Refraction (", 
  StyleBox[ 
  "see also", FontSlant -> 
    "Italic"], " WKB method, Ray trajectories, Snell's law)"}, "in optical \
fibres", ""}, {"i:102", {"Ray trajectories (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Geometrical optics)"}, "for P waves in the earth", ""}, \
{"i:103", "Geometrical optics", "for whistler waves", ""}, {"i:103", \
"Whistler waves", "trajectories through magnetosphere", ""}, {"i:105", \
{"Adiabatic invariants (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " WKB method)"}, "for waves on a string", ""}, {"i:107", {"Ray \
trajectories (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Geometrical optics)"}, "", ""}, {"i:108", {"Ray trajectories \
(", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Geometrical optics)"}, "for shallow water waves near the \
beach", ""}, {"i:111", {"Snell's law (", 
  StyleBox[ 
  "see", FontSlant -> 
    "Italic"], " WKB method, Ray trajectories)"}, "and lensing effect", ""}, \
{"i:112", {"Refraction (", 
  StyleBox[ 
  "see also", FontSlant -> 
    "Italic"], " WKB method, Ray trajectories, Snell's law)"}, "index of", \
""}, {"i:113", {"Refraction (", 
  StyleBox[ 
  "see also", FontSlant -> 
    "Italic"], " WKB method, Ray trajectories, Snell's law)"}, "index of", \
""}, {"i:116", "Energy", "flux", ""}, {"i:124", {"Waves (", 
  StyleBox[ 
  "see also", FontSlant -> "Italic"], " Eigenmodes)"}, {"electromagnetic (", 
  StyleBox[ 
  "see also", FontSlant -> 
    "Italic"], " Refraction, Wave equation)"}, ""}, {"i:125", {"Waves (", 
  StyleBox[ 
  "see also", FontSlant -> "Italic"], " Eigenmodes)"}, {"electromagnetic (", 
  StyleBox[ 
  "see also", FontSlant -> 
    "Italic"], " Refraction, Radiation, Wave equation)"}, ""}, {"i:126", \
{"Waves (", 
  StyleBox[ 
  "see also", FontSlant -> "Italic"], " Eigenmodes)"}, {"electromagnetic (", 
  StyleBox[ 
  "see also", FontSlant -> 
    "Italic"], " Refraction, Radiation, Wave equation)"}, ""}, {"i:127", \
{"Waves (", 
  StyleBox[ 
  "see also", FontSlant -> "Italic"], " Eigenmodes)"}, {"electromagnetic (", 
  StyleBox[ 
  "see also", FontSlant -> 
    "Italic"], " Refraction, Wave equation)"}, ""}, {"i:13", "Velocity", \
{"group (", 
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " Group velocity)"}, ""}, {"i:19", {"Waves (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Eigenmodes)"}, "phase", ""}, {"i:2", {"Waves (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Eigenmodes)"}, "travelling, in 1D", ""}, {"i:22", \
"Wavepacket", "form neglecting dispersion, in 1D", ""}, {"i:23", \
"Wavepacket", "form neglecting dispersion, in 3D", ""}, {"i:24", \
"Wavepacket", {"dispersion (", 
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " Dispersion)"}, ""}, {"i:25", {"Rayleigh length (", 
  StyleBox[ 
  "see", FontSlant -> 
    Italic], " Dispersion, transverse)"}, "", ""}, {"i:26", {"Uncertainty \
principle (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Bandwidth)"}, "and Rayleigh length", ""}, {"i:28", \
"Wavepacket", "energy density, neglecting dispersion", ""}, {"i:29", \
"Wavepacket", "energy flux, neglecting dispersion", ""}, {"i:3", \
"Dispersion", "relation, for waves on a string", ""}, {"i:37", "Green's \
function(s)", "for wave equation", ""}, {"i:37", {"Radiation (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Wavepacket energy and momentum flux)"}, "from a stationary \
point source", ""}, {"i:38", {"Waves (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Eigenmodes)"}, "in an anisotropic medium", ""}, {"i:41", \
"Green's function(s)", "for heat equation", ""}, {"i:45", "Dispersion", \
"relation, for deep water waves", ""}, {"i:46", "Dispersion", "relation, for \
water waves including surface tension", ""}, {"i:50", "Wave action", "for \
general quantum wave equations", ""}, {"i:52", "Dispersion", "relation, for \
deep water waves", ""}, {"i:56", {"Waves (", 
  StyleBox[ 
  "see also", FontSlant -> "Italic"], " Eigenmodes)"}, {"plasma (", 
  StyleBox[ 
  "see", FontSlant -> 
    "Italic"], " Plasma waves, Whistler waves)"}, ""}, {"i:66", "WKB method", \
"", ""}, {"i:67", {"Eikonal (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " WKB method)"}, "", ""}, {"i:68", {"Eikonal (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " WKB method)"}, "", ""}, {"i:7", {"Waves (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Eigenmodes)"}, "travelling, in 1D", ""}, {"i:73", {"Adiabatic \
invariants (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " WKB method)"}, "", ""}, {"i:74", "Wavepacket", "WKB, on a \
nonuniform string", ""}, {"i:76", {"Refraction (", 
  StyleBox[ 
  "see also", FontSlant -> 
    "Italic"], " WKB method, Ray trajectories, Snell's law)"}, "", ""}, \
{"i:78", {"Ray trajectories (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Geometrical optics)"}, "Snell's law", ""}, {"i:78", {"Snell's \
law (", 
  StyleBox[ 
  "see", FontSlant -> 
    "Italic"], " WKB method, Ray trajectories)"}, "", ""}, {"i:83", \
"Geometrical optics", {"turning points (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Turning points)"}, ""}, {"i:85", "Hamiltonian", "mechanics, as \
WKB limit of quantum mechanics", ""}, {"i:88", "Wavepacket", {"amplitude (", 
  StyleBox[ 
  "see also", FontSlant -> 
    Italic], " Wave action)"}, ""}, {"i:89", "Dispersion", "neglect of, in \
geometrical optics", ""}, {"i:9", "Velocity", {"phase (", 
  StyleBox[ 
  "see", FontSlant -> 
    "Italic"], " Phase velocity, Wave speed)"}, ""}, {"i:93", {"Waves (", 
  StyleBox[ 
  "see also", FontSlant -> "Italic"], " Eigenmodes)"}, {"electromagnetic (", 
  StyleBox[ 
  "see also", FontSlant -> 
    "Italic"], " Refraction, Radiation, Wave equation)"}, ""}, {"i:99", \
{"Poynting flux (", 
  StyleBox[ "see also", FontSlant -> Italic], " Energy flux)"}, "", ""}}},
CellLabelAutoDelete->True,
ScriptSizeMultipliers->0.85,
Magnification->1.25,
StyleDefinitions -> Notebook[{
  
  Cell[CellGroupData[{
  Cell["Style Definitions", "Subtitle"],
  
  Cell["\<\
Modify the definitions below to change the default appearance of \
all cells in a given style.  Make modifications to any definition using \
commands in the Format menu.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell["Style Environment Names", "Subsection"],
  
  Cell[StyleData[All, "Working"],
    CellBracketOptions->{"Color"->RGBColor[0, 0.2, 1]},
    ScriptMinSize->9],
  
  Cell[StyleData[All, "Printout"],
    PageWidth->PaperWidth,
    PrivateFontOptions->{"FontType"->"Outline"}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Notebook Options", "Subsection"],
  
  Cell["\<\
  The options defined for the style below will be used at the \
Notebook level.  \
\>", "Text"],
  
  Cell[StyleData["Notebook"],
    PageHeaders->{{Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"], None, Cell[ 
            TextData[ {
              OptionValueBox[ "FileName"]}], "Header"]}, {Cell[ 
            TextData[ {
              OptionValueBox[ "FileName"]}], "Header"], None, Cell[ 
            TextData[ {
              CounterBox[ "Page"]}], "PageNumber"]}},
    PrintingOptions->{"FirstPageHeader"->False,
    "FacingPages"->True},
    CellLabelAutoDelete->False,
    CellFrameLabelMargins->6,
    StyleMenuListing->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Headings", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Title"],
    CellMargins->{{12, Inherited}, {2, 20}},
    CellGroupingRules->{"TitleGrouping", 0},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Title",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subtitle", 0}, {"Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->30,
    FontWeight->"Bold"],
  
  Cell[StyleData["Title", "Printout"],
    CellMargins->{{2, 10}, {2, 30}},
    FontSize->24]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subtitle"],
    CellMargins->{{12, Inherited}, {2, 2}},
    CellGroupingRules->{"TitleGrouping", 10},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Subtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}, {
        "Subsubtitle", 0}},
    FontFamily->"Helvetica",
    FontSize->24,
    FontColor->RGBColor[0, 0, 0.6]],
  
  Cell[StyleData["Subtitle", "Printout"],
    CellMargins->{{2, 10}, {2, 4}},
    FontSize->18,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubtitle"],
    CellMargins->{{12, Inherited}, {2, 12}},
    CellGroupingRules->{"TitleGrouping", 20},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Subsubtitle",
    CounterAssignments->{{"Section", 0}, {"Equation", 0}, {"Figure", 0}},
    FontFamily->"Helvetica",
    FontSize->14,
    FontSlant->"Italic",
    FontColor->RGBColor[0, 0, 0.6]],
  
  Cell[StyleData["Subsubtitle", "Printout"],
    CellMargins->{{2, 10}, {2, 8}},
    FontSize->12,
    FontColor->GrayLevel[0]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Section"],
    CellMargins->{{10, 4}, {2, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->12},
    CellGroupingRules->{"SectionGrouping", 30},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Section",
    FontFamily->"Helvetica",
    FontWeight->"Bold"],
  
  Cell[StyleData["Section", "Printout"],
    CellMargins->{{2, 4}, {2, 18}},
    FontSize->10]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsection"],
    CellDingbat->"\[FilledSquare]",
    CellMargins->{{24, 4}, {2, 18}},
    CellElementSpacings->{"ClosedGroupTopMargin"->12},
    CellGroupingRules->{"SectionGrouping", 40},
    PageBreakBelow->False,
    CellFrameLabelMargins->6,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Subsection",
    CounterAssignments->{{"Subsubsection", 0}},
    FontFamily->"Helvetica",
    FontSize->15,
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsection", "Printout"],
    CellMargins->{{2, 4}, {2, 18}},
    FontSize->12]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Subsubsection"],
    CellMargins->{{20, 4}, {0, 8}},
    CellElementSpacings->{"ClosedGroupTopMargin"->12},
    CellGroupingRules->{"SectionGrouping", 50},
    PageBreakBelow->False,
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    CounterIncrements->"Subsubsection",
    FontWeight->"Bold"],
  
  Cell[StyleData["Subsubsection", "Printout"],
    CellMargins->{{2, 4}, {2, 18}},
    FontSize->10]
  }, Open  ]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Text", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Text"],
    CellMargins->{{10, 4}, {0, 8}},
    InputAutoReplacements->{"TeX"->StyleBox[ 
            RowBox[ {"T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "LaTeX"->StyleBox[ 
            RowBox[ {"L", 
              StyleBox[ 
                AdjustmentBox[ 
                "A", BoxMargins -> {{-0.35999999999999999, \
-0.10000000000000001}, {0, 0}}, BoxBaselineShift -> -0.20000000000000001], 
                FontSize -> Smaller], "T", 
              AdjustmentBox[ 
              "E", BoxMargins -> {{-0.074999999999999997, \
-0.085000000000000006}, {0, 0}}, BoxBaselineShift -> 0.5], "X"}]], 
        "mma"->"Mathematica", "Mma"->"Mathematica", "MMA"->"Mathematica"},
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    CounterIncrements->"Text"],
  
  Cell[StyleData["Text", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MathCaption"],
    CellFrame->{{4, 0}, {0, 0}},
    CellMargins->{{47, 62}, {0, 14}},
    CellFrameMargins->5,
    CellFrameColor->RGBColor[0, 0.2, 1],
    Hyphenation->True,
    LineSpacing->{1, 1},
    ParagraphSpacing->{0, 8},
    FontColor->RGBColor[0, 0, 0.6]],
  
  Cell[StyleData["MathCaption", "Printout"],
    CellMargins->{{34, 62}, {0, 14}},
    CellFrameColor->GrayLevel[0.700008],
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Input/Output", "Subsection"],
  
  Cell["\<\
The cells in this section define styles used for input and output \
to the kernel.  Be careful when modifying, renaming, or removing these \
styles, because the front end associates special meanings with these style \
names.    \
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Input"],
    CellMargins->{{56, 4}, {3, 9}},
    Evaluatable->True,
    CellGroupingRules->"InputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->StandardForm,
    ShowStringCharacters->True,
    NumberMarks->True,
    LinebreakAdjustments->{0.85, 2, 10, 0, 1},
    CounterIncrements->"Input",
    FontWeight->"Bold",
    Background->RGBColor[0, 1, 1]],
  
  Cell[StyleData["Input", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{42, 4}, {3, 8}},
    LinebreakAdjustments->{0.85, 2, 10, 1, 1},
    FontSize->10,
    Background->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Output"],
    CellMargins->{{57, 4}, {5, 2}},
    CellEditDuplicate->True,
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    LanguageCategory->"Formula",
    FormatType->StandardForm,
    CounterIncrements->"Output",
    Background->RGBColor[1, 1, 0]],
  
  Cell[StyleData["Output", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{42, 4}, {4, 2}},
    FontSize->10,
    Background->None]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Message"],
    CellMargins->{{56, 4}, {3, 8}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Message",
    StyleMenuListing->None,
    FontColor->RGBColor[0, 0.2, 1]],
  
  Cell[StyleData["Message", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{42, 4}, {4, 2}},
    FontSize->10,
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Print"],
    CellMargins->{{56, 4}, {3, 8}},
    CellGroupingRules->"OutputGrouping",
    PageBreakWithin->False,
    GroupPageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    CellLabelMargins->{{21, Inherited}, {Inherited, Inherited}},
    DefaultFormatType->DefaultOutputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    AutoItalicWords->{},
    FormatType->InputForm,
    CounterIncrements->"Print",
    StyleMenuListing->None],
  
  Cell[StyleData["Print", "Printout"],
    ShowCellBracket->False,
    CellMargins->{{42, 4}, {4, 2}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Graphics"],
    CellMargins->{{56, Inherited}, {Inherited, Inherited}},
    CellGroupingRules->"GraphicsGrouping",
    CellHorizontalScrolling->True,
    PageBreakWithin->False,
    GeneratedCell->True,
    CellAutoOverwrite->True,
    ShowCellLabel->False,
    DefaultFormatType->DefaultOutputFormatType,
    FormatType->InputForm,
    CounterIncrements->"Graphics",
    StyleMenuListing->None],
  
  Cell[StyleData["Graphics", "Printout"],
    CellMargins->{{40, 4}, {4, 2}},
    ImageSize->{250, 250},
    FontSize->9]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["CellLabel"],
    StyleMenuListing->None,
    FontFamily->"Helvetica",
    FontSize->9,
    FontColor->RGBColor[0, 0.2, 1]],
  
  Cell[StyleData["CellLabel", "Printout"],
    FontSize->7,
    FontSlant->"Oblique",
    FontColor->GrayLevel[0]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NumberedEquation"],
    CellMargins->{{72, 10}, {0, 10}},
    ConversionRules:>{"TeX" -> {"\\[\n", "\n\\]\n\n"}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(5.", 
              CounterBox[ "Subtitle"], ".", 
              CounterBox[ "NumberedEquation"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NumberedEquation",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NumberedEquation", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NE2"],
    CellMargins->{{72, 10}, {0, 10}},
    ConversionRules:>{"TeX" -> {"\\[\n", "\n\\]\n\n"}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(5.", 
              CounterBox[ "Subtitle"], ".", 
              CounterBox[ "NE2"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NE2",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NE2", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NE3"],
    CellMargins->{{72, 10}, {0, 10}},
    ConversionRules:>{"TeX" -> {"\\[\n", "\n\\]\n\n"}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(5.", 
              CounterBox[ "Subtitle"], ".", 
              CounterBox[ "NE3"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NE3",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NE3", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["NE4"],
    CellMargins->{{72, 10}, {0, 10}},
    ConversionRules:>{"TeX" -> {"\\[\n", "\n\\]\n\n"}},
    CellFrameLabels->{{None, Cell[ 
            TextData[ {"(5.", 
              CounterBox[ "Subtitle"], ".", 
              CounterBox[ "NE4"], ")"}]]}, {None, None}},
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    CounterIncrements->"NE4",
    FormatTypeAutoConvert->False],
  
  Cell[StyleData["NE4", "Printout"],
    FontSize->10]
  }, Closed]]
  }, Open  ]],
  
  Cell[CellGroupData[{
  
  Cell["Unique Styles", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["TextTop"],
    CellFrame->{{0, 0}, {0, 2}},
    CellMargins->{{10, 4}, {2, 80}},
    CellHorizontalScrolling->True,
    CellFrameMargins->4,
    ShowSpecialCharacters->Automatic,
    ParagraphSpacing->{0, 8},
    CounterIncrements->"Text"],
  
  Cell[StyleData["TextTop", "Printout"],
    CellMargins->{{2, 4}, {2, 80}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedText"],
    CellMargins->{{20, 4}, {0, 8}},
    ShowSpecialCharacters->Automatic,
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    ParagraphIndent->-15,
    CounterIncrements->"Text"],
  
  Cell[StyleData["ItemizedText", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ItemizedTextNote"],
    CellMargins->{{35, 4}, {0, 4}},
    ShowSpecialCharacters->Automatic,
    Hyphenation->True,
    ParagraphSpacing->{0, 4},
    CounterIncrements->"Text"],
  
  Cell[StyleData["ItemizedTextNote", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["IndentedText"],
    CellMargins->{{20, 4}, {0, 6}},
    ShowSpecialCharacters->Automatic,
    Hyphenation->True,
    ParagraphSpacing->{0, 8},
    CounterIncrements->"Text"],
  
  Cell[StyleData["IndentedText", "Printout"],
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Note"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    ShowSpecialCharacters->Automatic,
    ParagraphSpacing->{0, 8},
    CounterIncrements->"Text",
    FontFamily->"Helvetica",
    FontSize->10],
  
  Cell[StyleData["Note", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->8]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["1ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1}],
  
  Cell[StyleData["1ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.39, 0.59}}],
  
  Cell[StyleData["2ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnSmallBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.35,
    ColumnAlignments->{Right, Left}}],
  
  Cell[StyleData["2ColumnSmallBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.325}],
  
  Cell[StyleData["3ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnSmallBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnSpacings->1.5,
    ColumnWidths->0.23,
    ColumnAlignments->{Right, Center, Left}}],
  
  Cell[StyleData["3ColumnSmallBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["4ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.145, 0.345, 0.145, 0.345}}],
  
  Cell[StyleData["4ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["5ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->0.195}],
  
  Cell[StyleData["5ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["6ColumnBox"],
    CellFrame->True,
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LineIndent->0,
    Background->GrayLevel[0.8],
    FrameBoxOptions->{BoxMargins->{{1, 1}, {1.5, 1.5}}},
    GridBoxOptions->{ColumnWidths->{0.13, 0.23, 0.13, 0.13, 0.23, 0.13}}],
  
  Cell[StyleData["6ColumnBox", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10,
    Background->GrayLevel[0.900008]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Picture"],
    CellMargins->{{10, Inherited}, {0, 8}},
    CellHorizontalScrolling->True],
  
  Cell[StyleData["Picture", "Printout"],
    CellMargins->{{2, Inherited}, {0, 8}}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Caption"],
    CellMargins->{{10, 50}, {0, 3}},
    PageBreakAbove->False,
    Hyphenation->True,
    FontFamily->"Helvetica",
    FontSize->9],
  
  Cell[StyleData["Caption", "Printout"],
    CellMargins->{{2, 50}, {2, 4}},
    FontSize->7]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Tables", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["2ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    GridBoxOptions->{ColumnWidths->{0.39, 0.59},
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["2ColumnTable", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["3ColumnTable"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    StyleMenuListing->None,
    GridBoxOptions->{ColumnWidths->0.325,
    ColumnAlignments->{Left}}],
  
  Cell[StyleData["3ColumnTable", "Printout"],
    CellMargins->{{2, 4}, {0, 8}},
    FontSize->10]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Formulas and Programming", "Subsection"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["ChemicalFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    AutoSpacing->False,
    ScriptLevel->1,
    ScriptBaselineShifts->{0.6, Automatic},
    SingleLetterItalics->False,
    ZeroWidthTimes->True],
  
  Cell[StyleData["ChemicalFormula", "Printout"],
    CellMargins->{{34, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["DisplayFormula"],
    CellMargins->{{42, Inherited}, {Inherited, Inherited}},
    CellHorizontalScrolling->True,
    DefaultFormatType->DefaultInputFormatType,
    HyphenationOptions->{"HyphenationCharacter"->"\[Continuation]"},
    LanguageCategory->"Formula",
    ScriptLevel->0,
    SingleLetterItalics->True,
    SpanMaxSize->Infinity,
    UnderoverscriptBoxOptions->{LimitsPositioning->True},
    GridBoxOptions->{ColumnWidths->Automatic}],
  
  Cell[StyleData["DisplayFormula", "Printout"],
    CellMargins->{{34, Inherited}, {Inherited, Inherited}},
    FontSize->10]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Program"],
    CellMargins->{{10, 4}, {0, 8}},
    CellHorizontalScrolling->True,
    LanguageCategory->"Formula",
    FontFamily->"Courier"],
  
  Cell[StyleData["Program", "Printout"],
    CellMargins->{{2, Inherited}, {Inherited, Inherited}},
    FontSize->9.5]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Hyperlink Styles", "Subsection"],
  
  Cell["\<\
The cells below define styles useful for making hypertext \
ButtonBoxes.  The \"Hyperlink\" style is for links within the same Notebook, \
or between Notebooks.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["Hyperlink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookLocate[ #2]}]&),
    Active->True,
    ButtonNote->ButtonData}],
  
  Cell[StyleData["Hyperlink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell["\<\
The following styles are for linking automatically to the on-line \
help system.\
\>", "Text"],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["MainBookLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "MainBook", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["MainBookLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["AddOnsLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "AddOns", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["AddOnsLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["RefGuideLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontFamily->"Courier",
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "RefGuide", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["RefGuideLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["GettingStartedLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "GettingStarted", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["GettingStartedLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell[StyleData["OtherInformationLink"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    FontColor->RGBColor[0, 0, 1],
    FontVariations->{"Underline"->True},
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`HelpBrowserLookup[ "OtherInformation", #]}]&),
    Active->True,
    ButtonFrame->"None"}],
  
  Cell[StyleData["OtherInformationLink", "Printout"],
    FontSize->10,
    FontColor->GrayLevel[0],
    FontVariations->{"Underline"->False}]
  }, Closed]]
  }, Closed]],
  
  Cell[CellGroupData[{
  
  Cell["Palette Styles", "Subsection"],
  
  Cell["\<\
The cells below define styles that define standard \
ButtonFunctions, for use in palette buttons.\
\>", "Text"],
  
  Cell[StyleData["Paste"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, After]}]&)}],
  
  Cell[StyleData["Evaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["EvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionMove[ 
          FrontEnd`InputNotebook[ ], All, Cell, 1], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluate"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluate[ 
          FrontEnd`InputNotebook[ ], All]}]&)}],
  
  Cell[StyleData["CopyEvaluateCell"],
    StyleMenuListing->None,
    ButtonStyleMenuListing->Automatic,
    ButtonBoxOptions->{ButtonFunction:>(FrontEndExecute[ {
        FrontEnd`SelectionCreateCell[ 
          FrontEnd`InputNotebook[ ], All], 
        FrontEnd`NotebookApply[ 
          FrontEnd`InputNotebook[ ], #, All], 
        FrontEnd`SelectionEvaluateCreateCell[ 
          FrontEnd`InputNotebook[ ], All]}]&)}]
  }, Closed]]
  }, Open  ]]
  }]
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{
  "i:1"->{
    Cell[1727, 52, 98, 1, 111, "Title",
      CellTags->{"i:1", "c:1"}]},
  "c:1"->{
    Cell[1727, 52, 98, 1, 111, "Title",
      CellTags->{"i:1", "c:1"}]},
  "Fig. 5.1"->{
    Cell[31467, 452, 86, 1, 16, "Caption",
      CellTags->"Fig. 5.1"]},
  "c:3"->{
    Cell[33150, 495, 68, 1, 39, "Subtitle",
      CellTags->"c:3"]},
  "c:4"->{
    Cell[33262, 502, 82, 1, 41, "Subsubtitle",
      CellTags->"c:4"]},
  "i:2"->{
    Cell[33369, 507, 62, 1, 41, "Section",
      CellTags->{"i:2", "c:5"}]},
  "c:5"->{
    Cell[33369, 507, 62, 1, 41, "Section",
      CellTags->{"i:2", "c:5"}]},
  "(5.1.1)"->{
    Cell[33671, 518, 195, 6, 42, "NumberedEquation",
      CellTags->"(5.1.1)"]},
  "(5.1.2)"->{
    Cell[33921, 528, 230, 4, 58, "NumberedEquation",
      CellTags->"(5.1.2)"]},
  "i:5"->{
    Cell[34154, 534, 558, 18, 50, "Text",
      CellTags->"i:5"]},
  "(5.1.3)"->{
    Cell[34715, 554, 213, 6, 42, "NumberedEquation",
      CellTags->"(5.1.3)"]},
  "(5.1.4)"->{
    Cell[35646, 593, 472, 15, 33, "NumberedEquation",
      CellTags->"(5.1.4)"]},
  "(5.1.5)"->{
    Cell[36722, 632, 222, 6, 41, "NumberedEquation",
      CellTags->"(5.1.5)"]},
  "(5.1.6)"->{
    Cell[37166, 648, 133, 5, 28, "NumberedEquation",
      CellTags->"(5.1.6)"]},
  "i:3"->{
    Cell[37302, 655, 180, 6, 26, "Text",
      CellTags->"i:3"]},
  "(5.1.7)"->{
    Cell[37689, 671, 330, 9, 31, "NumberedEquation",
      CellTags->"(5.1.7)"]},
  "(5.1.8)"->{
    Cell[39049, 716, 970, 26, 40, "NumberedEquation",
      CellTags->"(5.1.8)"]},
  "(5.1.9)"->{
    Cell[41697, 794, 895, 25, 37, "NumberedEquation",
      CellTags->"(5.1.9)"]},
  "i:7"->{
    Cell[42595, 821, 1067, 38, 63, "Text",
      CellTags->"i:7"]},
  "Cell 5.1"->{
    Cell[43687, 863, 445, 11, 116, "Input",
      CellTags->"Cell 5.1"]},
  "Cell 5.2"->{
    Cell[601001, 12500, 458, 11, 116, "Input",
      CellTags->"Cell 5.2"]},
  "c:6"->{
    Cell[1160055, 24179, 54, 1, 30, "Section",
      CellTags->"c:6"]},
  "(5.1.10)"->{
    Cell[1160599, 24198, 831, 21, 70, "NumberedEquation",
      CellTags->"(5.1.10)"]},
  "i:6"->{
    Cell[1161572, 24229, 164, 5, 70, "NumberedEquation",
      CellTags->{"i:6", "(5.1.11)"}]},
  "(5.1.11)"->{
    Cell[1161572, 24229, 164, 5, 70, "NumberedEquation",
      CellTags->{"i:6", "(5.1.11)"}]},
  "(5.1.12)"->{
    Cell[1164166, 24318, 323, 10, 70, "NumberedEquation",
      CellTags->"(5.1.12)"]},
  "(5.1.13)"->{
    Cell[1165232, 24360, 391, 8, 70, "NumberedEquation",
      CellTags->"(5.1.13)"]},
  "(5.1.14)"->{
    Cell[1166571, 24409, 190, 6, 70, "NumberedEquation",
      CellTags->"(5.1.14)"]},
  "c:7"->{
    Cell[1167163, 24431, 86, 1, 30, "Subsubtitle",
      CellTags->"c:7"]},
  "c:8"->{
    Cell[1167274, 24436, 128, 4, 41, "Section",
      CellTags->"c:8"]},
  "(5.1.15)"->{
    Cell[1167791, 24455, 287, 8, 70, "NumberedEquation",
      CellTags->"(5.1.15)"]},
  "(5.1.16)"->{
    Cell[1168299, 24475, 202, 5, 70, "NumberedEquation",
      CellTags->"(5.1.16)"]},
  "(5.1.17)"->{
    Cell[1169169, 24503, 284, 8, 41, "NumberedEquation",
      CellTags->"(5.1.17)"]},
  "(5.1.18)"->{
    Cell[1169732, 24525, 233, 8, 31, "NumberedEquation",
      CellTags->"(5.1.18)"]},
  "i:8"->{
    Cell[1170262, 24548, 160, 3, 41, "NumberedEquation",
      CellTags->{"i:8", "(5.1.19)"}]},
  "(5.1.19)"->{
    Cell[1170262, 24548, 160, 3, 41, "NumberedEquation",
      CellTags->{"i:8", "(5.1.19)"}]},
  "(5.1.20)"->{
    Cell[1170686, 24564, 461, 13, 37, "NumberedEquation",
      CellTags->"(5.1.20)"]},
  "i:9"->{
    Cell[1171150, 24579, 1172, 33, 100, "Text",
      CellTags->"i:9"]},
  "(5.1.21)"->{
    Cell[1172325, 24614, 156, 5, 30, "NumberedEquation",
      CellTags->"(5.1.21)"]},
  "i:10"->{
    Cell[1172484, 24621, 1008, 30, 88, "Text",
      CellTags->"i:10"]},
  "(5.1.22)"->{
    Cell[1173676, 24659, 224, 8, 35, "NumberedEquation",
      CellTags->"(5.1.22)"]},
  "i:12"->{
    Cell[1173903, 24669, 1488, 47, 97, "Text",
      CellTags->"i:12"]},
  "Cell 5.3"->{
    Cell[1176022, 24743, 818, 17, 240, "Input",
      CellTags->"Cell 5.3"]},
  "(5.1.23)"->{
    Cell[1242821, 26459, 409, 10, 37, "NumberedEquation",
      CellTags->"(5.1.23)"]},
  "(5.1.24)"->{
    Cell[1243401, 26478, 389, 11, 50, "NumberedEquation",
      CellTags->"(5.1.24)"]},
  "Cell 5.4"->{
    Cell[1243948, 26499, 303, 7, 146, "Input",
      CellTags->"Cell 5.4"]},
  "(5.1.25)"->{
    Cell[1244390, 26514, 232, 7, 46, "NumberedEquation",
      CellTags->"(5.1.25)"]},
  "Cell 5.5"->{
    Cell[1246396, 26582, 291, 6, 130, "Input",
      CellTags->"Cell 5.5"]},
  "Cell 5.6"->{
    Cell[1247859, 26630, 713, 14, 178, "Input",
      CellTags->"Cell 5.6"]},
  "i:13"->{
    Cell[1991385, 49526, 62, 1, 30, "Section",
      CellTags->{"i:13", "c:9"}]},
  "c:9"->{
    Cell[1991385, 49526, 62, 1, 30, "Section",
      CellTags->{"i:13", "c:9"}]},
  "Cell 5.7"->{
    Cell[1992722, 49576, 101, 3, 66, "Input",
      CellTags->"Cell 5.7"]},
  "(5.1.26)"->{
    Cell[1993716, 49614, 553, 14, 50, "NumberedEquation",
      CellTags->"(5.1.26)"]},
  "(5.1.27)"->{
    Cell[1994436, 49636, 732, 17, 50, "NumberedEquation",
      CellTags->"(5.1.27)"]},
  "i:22"->{
    Cell[1995171, 49655, 673, 19, 60, "Text",
      CellTags->"i:22"]},
  "i:27"->{
    Cell[1995847, 49676, 535, 15, 55, "Text",
      CellTags->"i:27"]},
  "i:14"->{
    Cell[1996385, 49693, 356, 11, 40, "NumberedEquation",
      CellTags->{"i:14", "(5.1.28)"}]},
  "(5.1.28)"->{
    Cell[1996385, 49693, 356, 11, 40, "NumberedEquation",
      CellTags->{"i:14", "(5.1.28)"}]},
  "(5.1.29)"->{
    Cell[1997005, 49715, 192, 6, 30, "NumberedEquation",
      CellTags->"(5.1.29)"]},
  "Cell 5.8"->{
    Cell[1998184, 49754, 546, 12, 135, "Input",
      CellTags->"Cell 5.8"]},
  "i:15"->{
    Cell[8714569, 298485, 59, 1, 30, "Section",
      CellTags->{"i:15", "c:10"}]},
  "c:10"->{
    Cell[8714569, 298485, 59, 1, 30, "Section",
      CellTags->{"i:15", "c:10"}]},
  "(5.1.30)"->{
    Cell[8717176, 298564, 428, 10, 41, "NumberedEquation",
      CellTags->"(5.1.30)"]},
  "i:16"->{
    Cell[8719181, 298621, 186, 6, 37, "NumberedEquation",
      CellTags->{"i:16", "(5.1.31)"}]},
  "(5.1.31)"->{
    Cell[8719181, 298621, 186, 6, 37, "NumberedEquation",
      CellTags->{"i:16", "(5.1.31)"}]},
  "c:11"->{
    Cell[8720463, 298662, 82, 1, 30, "Subsubtitle",
      CellTags->"c:11"]},
  "i:17"->{
    Cell[8720570, 298667, 103, 1, 42, "Section",
      CellTags->{"i:17", "c:12"}]},
  "c:12"->{
    Cell[8720570, 298667, 103, 1, 42, "Section",
      CellTags->{"i:17", "c:12"}]},
  "(5.1.32)"->{
    Cell[8721307, 298691, 720, 21, 41, "NumberedEquation",
      CellTags->"(5.1.32)"]},
  "(5.1.33)"->{
    Cell[8722200, 298720, 519, 17, 28, "NumberedEquation",
      CellTags->"(5.1.33)"]},
  "(5.1.34)"->{
    Cell[8723480, 298765, 626, 13, 35, "NumberedEquation",
      CellTags->"(5.1.34)"]},
  "(5.1.35)"->{
    Cell[8724184, 298782, 1152, 31, 32, "NumberedEquation",
      CellTags->"(5.1.35)"]},
  "i:18"->{
    Cell[8725339, 298815, 733, 29, 27, "Text",
      CellTags->"i:18"]},
  "(5.1.36)"->{
    Cell[8726075, 298846, 695, 20, 41, "NumberedEquation",
      CellTags->"(5.1.36)"]},
  "(5.1.37)"->{
    Cell[8727032, 298876, 586, 18, 31, "NumberedEquation",
      CellTags->"(5.1.37)"]},
  "(5.1.38)"->{
    Cell[8728610, 298929, 1398, 37, 45, "NumberedEquation",
      CellTags->"(5.1.38)"]},
  "i:19"->{
    Cell[8730011, 298968, 809, 23, 46, "Text",
      CellTags->"i:19"]},
  "(5.1.39)"->{
    Cell[8730823, 298993, 465, 15, 28, "NumberedEquation",
      CellTags->"(5.1.39)"]},
  "(5.1.40)"->{
    Cell[8732000, 299038, 182, 6, 28, "NumberedEquation",
      CellTags->"(5.1.40)"]},
  "i:21"->{
    Cell[8733150, 299080, 776, 25, 38, "NumberedEquation",
      CellTags->{"i:21", "(5.1.41)"}]},
  "(5.1.41)"->{
    Cell[8733150, 299080, 776, 25, 38, "NumberedEquation",
      CellTags->{"i:21", "(5.1.41)"}]},
  "(5.1.42)"->{
    Cell[8734802, 299139, 710, 19, 46, "NumberedEquation",
      CellTags->"(5.1.42)"]},
  "i:139"->{
    Cell[8735515, 299160, 1272, 38, 45, "Text",
      CellTags->"i:139"]},
  "Fig. 5.2"->{
    Cell[8816819, 300193, 229, 9, 15, "Caption",
      CellTags->"Fig. 5.2"]},
  "c:13"->{
    Cell[8817085, 300207, 76, 1, 31, "Section",
      CellTags->"c:13"]},
  "i:20"->{
    Cell[8819782, 300299, 637, 23, 37, "NumberedEquation",
      CellTags->{"i:20", "(5.1.43)"}]},
  "(5.1.43)"->{
    Cell[8819782, 300299, 637, 23, 37, "NumberedEquation",
      CellTags->{"i:20", "(5.1.43)"}]},
  "c:14"->{
    Cell[8820755, 300337, 77, 1, 31, "Section",
      CellTags->"c:14"]},
  "(5.1.44)"->{
    Cell[8821020, 300349, 921, 28, 70, "NumberedEquation",
      CellTags->"(5.1.44)"]},
  "(5.1.45)"->{
    Cell[8822714, 300406, 1406, 42, 70, "NumberedEquation",
      CellTags->"(5.1.45)"]},
  "i:59"->{
    Cell[8824123, 300450, 825, 29, 70, "Text",
      CellTags->"i:59"]},
  "(5.1.46)"->{
    Cell[8824951, 300481, 1187, 36, 70, "NumberedEquation",
      CellTags->"(5.1.46)"]},
  "(5.1.47)"->{
    Cell[8826171, 300521, 3855, 96, 70, "NumberedEquation",
      CellTags->"(5.1.47)"]},
  "(5.1.48)"->{
    Cell[8832791, 300710, 3427, 99, 70, "NumberedEquation",
      CellTags->"(5.1.48)"]},
  "(5.1.49)"->{
    Cell[8841472, 300980, 3953, 99, 70, "NumberedEquation",
      CellTags->"(5.1.49)"]},
  "(5.1.50)"->{
    Cell[8855476, 301368, 2195, 57, 70, "NumberedEquation",
      CellTags->"(5.1.50)"]},
  "i:23"->{
    Cell[8874821, 301944, 2729, 76, 32, "NumberedEquation",
      CellTags->{"i:23", "(5.1.51)"}]},
  "(5.1.51)"->{
    Cell[8874821, 301944, 2729, 76, 32, "NumberedEquation",
      CellTags->{"i:23", "(5.1.51)"}]},
  "i:24"->{
    Cell[8878065, 302038, 71, 1, 28, "Subsubsection",
      CellTags->"i:24"]},
  "(5.1.52)"->{
    Cell[8878635, 302057, 2145, 58, 70, "NumberedEquation",
      CellTags->"(5.1.52)"]},
  "(5.1.53)"->{
    Cell[8883856, 302221, 1830, 50, 70, "NumberedEquation",
      CellTags->"(5.1.53)"]},
  "(5.1.54)"->{
    Cell[8886301, 302297, 429, 10, 70, "NumberedEquation",
      CellTags->"(5.1.54)"]},
  "i:133"->{
    Cell[8886733, 302309, 1306, 40, 127, "Text",
      CellTags->"i:133"]},
  "(5.1.55)"->{
    Cell[8894858, 302534, 1122, 29, 68, "NumberedEquation",
      CellTags->"(5.1.55)"]},
  "(5.1.56)"->{
    Cell[8897585, 302614, 163, 5, 32, "NumberedEquation",
      CellTags->"(5.1.56)"]},
  "i:25"->{
    Cell[8897751, 302621, 400, 16, 47, "Text",
      CellTags->"i:25"]},
  "i:26"->{
    Cell[8898154, 302639, 486, 9, 77, "Text",
      CellTags->"i:26"]},
  "i:34"->{
    Cell[8900392, 302707, 77, 1, 28, "Subsubsection",
      CellTags->"i:34"]},
  "(5.1.57)"->{
    Cell[8901470, 302733, 384, 11, 37, "NumberedEquation",
      CellTags->"(5.1.57)"]},
  "i:28"->{
    Cell[8901857, 302746, 75, 1, 26, "Text",
      CellTags->"i:28"]},
  "(5.1.58)"->{
    Cell[8901935, 302749, 233, 6, 42, "NumberedEquation",
      CellTags->"(5.1.58)"]},
  "i:29"->{
    Cell[8902353, 302766, 325, 11, 37, "NumberedEquation",
      CellTags->{"i:29", "(5.1.59)"}]},
  "(5.1.59)"->{
    Cell[8902353, 302766, 325, 11, 37, "NumberedEquation",
      CellTags->{"i:29", "(5.1.59)"}]},
  "(5.1.60)"->{
    Cell[8905535, 302871, 3142, 91, 30, "NumberedEquation",
      CellTags->"(5.1.60)"]},
  "(5.1.61)"->{
    Cell[8912164, 303064, 2513, 70, 57, "NumberedEquation",
      CellTags->"(5.1.61)"]},
  "i:30"->{
    Cell[8915187, 303148, 2394, 66, 62, "NumberedEquation",
      CellTags->{"i:30", "(5.1.62)"}]},
  "(5.1.62)"->{
    Cell[8915187, 303148, 2394, 66, 62, "NumberedEquation",
      CellTags->{"i:30", "(5.1.62)"}]},
  "(5.1.63)"->{
    Cell[8920291, 303299, 334, 8, 50, "NumberedEquation",
      CellTags->"(5.1.63)"]},
  "i:35"->{
    Cell[8920628, 303309, 1459, 49, 113, "Text",
      CellTags->"i:35"]},
  "i:36"->{
    Cell[8923270, 303400, 769, 24, 40, "NumberedEquation",
      CellTags->{"i:36", "(5.1.64)"}]},
  "(5.1.64)"->{
    Cell[8923270, 303400, 769, 24, 40, "NumberedEquation",
      CellTags->{"i:36", "(5.1.64)"}]},
  "i:112"->{
    Cell[8924042, 303426, 773, 24, 63, "Text",
      CellTags->"i:112"]},
  "(5.1.65)"->{
    Cell[8926899, 303499, 519, 13, 40, "NumberedEquation",
      CellTags->"(5.1.65)"]},
  "(5.1.66)"->{
    Cell[8927547, 303521, 217, 6, 41, "NumberedEquation",
      CellTags->"(5.1.66)"]},
  "(5.1.67)"->{
    Cell[8928090, 303540, 545, 12, 50, "NumberedEquation",
      CellTags->"(5.1.67)"]},
  "(5.1.68)"->{
    Cell[8929151, 303575, 861, 19, 51, "NumberedEquation",
      CellTags->"(5.1.68)"]},
  "(5.1.69)"->{
    Cell[8930038, 303598, 416, 9, 51, "NumberedEquation",
      CellTags->"(5.1.69)"]},
  "(5.1.70)"->{
    Cell[8933863, 303713, 774, 20, 40, "NumberedEquation",
      CellTags->"(5.1.70)"]},
  "(5.1.71)"->{
    Cell[8934662, 303737, 683, 20, 42, "NumberedEquation",
      CellTags->"(5.1.71)"]},
  "i:32"->{
    Cell[8936013, 303782, 685, 20, 40, "NumberedEquation",
      CellTags->{"i:32", "(5.1.72)"}]},
  "(5.1.72)"->{
    Cell[8936013, 303782, 685, 20, 40, "NumberedEquation",
      CellTags->{"i:32", "(5.1.72)"}]},
  "(5.1.73)"->{
    Cell[8938490, 303864, 614, 21, 32, "NumberedEquation",
      CellTags->"(5.1.73)"]},
  "i:116"->{
    Cell[8939107, 303887, 140, 4, 26, "Text",
      CellTags->"i:116"]},
  "(5.1.74)"->{
    Cell[8940043, 303917, 517, 16, 37, "NumberedEquation",
      CellTags->"(5.1.74)"]},
  "i:117"->{
    Cell[8940563, 303935, 1597, 57, 78, "Text",
      CellTags->"i:117"]},
  "i:33"->{
    Cell[8942163, 303994, 927, 30, 27, "NumberedEquation",
      CellTags->{"i:33", "(5.1.75)"}]},
  "(5.1.75)"->{
    Cell[8942163, 303994, 927, 30, 27, "NumberedEquation",
      CellTags->{"i:33", "(5.1.75)"}]},
  "(5.1.76)"->{
    Cell[8943115, 304028, 152, 5, 30, "NumberedEquation",
      CellTags->"(5.1.76)"]},
  "(5.1.77)"->{
    Cell[8946953, 304156, 3496, 84, 45, "NumberedEquation",
      CellTags->"(5.1.77)"]},
  "i:40"->{
    Cell[8950452, 304242, 1955, 65, 80, "Text",
      CellTags->"i:40"]},
  "(5.1.78)"->{
    Cell[8956487, 304429, 334, 9, 65, "NumberedEquation",
      CellTags->"(5.1.78)"]},
  "Cell 5.9"->{
    Cell[8957088, 304453, 620, 14, 180, "Input",
      CellTags->"Cell 5.9"]},
  "c:15"->{
    Cell[9982677, 339547, 59, 1, 31, "Section",
      CellTags->"c:15"]},
  "(5.1.79)"->{
    Cell[9983296, 339571, 1331, 39, 42, "NumberedEquation",
      CellTags->"(5.1.79)"]},
  "(5.1.80)"->{
    Cell[9985776, 339648, 2535, 65, 33, "NumberedEquation",
      CellTags->"(5.1.80)"]},
  "(5.1.81)"->{
    Cell[9992091, 339836, 1998, 54, 46, "NumberedEquation",
      CellTags->"(5.1.81)"]},
  "Cell 5.10"->{
    Cell[9995920, 339955, 251, 6, 86, "Input",
      CellTags->"Cell 5.10"]},
  "(5.1.82)"->{
    Cell[9996611, 339980, 1253, 35, 45, "NumberedEquation",
      CellTags->"(5.1.82)"]},
  "(5.1.83)"->{
    Cell[10002906, 340173, 1702, 46, 38, "NumberedEquation",
      CellTags->"(5.1.83)"]},
  "(5.1.84)"->{
    Cell[10006050, 340268, 632, 21, 38, "NumberedEquation",
      CellTags->"(5.1.84)"]},
  "i:37"->{
    Cell[10006685, 340291, 668, 19, 78, "Text",
      CellTags->"i:37"]},
  "(5.1.85)"->{
    Cell[10010393, 340400, 2067, 60, 45, "NumberedEquation",
      CellTags->"(5.1.85)"]},
  "i:130"->{
    Cell[10012463, 340462, 716, 25, 44, "Text",
      CellTags->"i:130"]},
  "i:38"->{
    Cell[10013216, 340492, 90, 1, 31, "Section",
      CellTags->{"i:38", "c:16"}]},
  "c:16"->{
    Cell[10013216, 340492, 90, 1, 31, "Section",
      CellTags->{"i:38", "c:16"}]},
  "(5.1.86)"->{
    Cell[10014389, 340528, 1221, 39, 28, "NumberedEquation",
      CellTags->"(5.1.86)"]},
  "(5.1.87)"->{
    Cell[10016920, 340615, 6976, 155, 85, "NumberedEquation",
      CellTags->"(5.1.87)"]},
  "(5.1.88)"->{
    Cell[10024787, 340802, 750, 24, 28, "NumberedEquation",
      CellTags->"(5.1.88)"]},
  "i:39"->{
    Cell[10025540, 340828, 1064, 34, 77, "Text",
      CellTags->"i:39"]},
  "(5.1.89)"->{
    Cell[10026649, 340866, 1643, 45, 35, "NumberedEquation",
      CellTags->"(5.1.89)"]},
  "(5.1.90)"->{
    Cell[10028773, 340932, 678, 21, 38, "NumberedEquation",
      CellTags->"(5.1.90)"]},
  "Fig. 5.3"->{
    Cell[12259242, 411074, 156, 4, 16, "Caption",
      CellTags->"Fig. 5.3"]},
  "c:17"->{
    Cell[12259435, 411083, 52, 1, 31, "Section",
      CellTags->"c:17"]},
  "(5.1.91)"->{
    Cell[12260080, 411108, 1761, 53, 37, "NumberedEquation",
      CellTags->"(5.1.91)"]},
  "i:60"->{
    Cell[12262734, 411194, 900, 31, 46, "Text",
      CellTags->"i:60"]},
  "(5.1.92)"->{
    Cell[12266482, 411322, 2007, 58, 48, "NumberedEquation",
      CellTags->"(5.1.92)"]},
  "(5.1.93)"->{
    Cell[12270390, 411446, 2871, 75, 48, "NumberedEquation",
      CellTags->"(5.1.93)"]},
  "(5.1.94)"->{
    Cell[12274505, 411557, 176, 6, 31, "NumberedEquation",
      CellTags->"(5.1.94)"]},
  "i:44"->{
    Cell[12274684, 411565, 180, 5, 43, "Text",
      CellTags->"i:44"]},
  "i:43"->{
    Cell[12275328, 411583, 575, 18, 35, "NumberedEquation",
      CellTags->{"i:43", "(5.1.95)"}]},
  "(5.1.95)"->{
    Cell[12275328, 411583, 575, 18, 35, "NumberedEquation",
      CellTags->{"i:43", "(5.1.95)"}]},
  "i:42"->{
    Cell[12275906, 411603, 61, 1, 26, "Text",
      CellTags->"i:42"]},
  "(5.1.96)"->{
    Cell[12275970, 411606, 506, 17, 37, "NumberedEquation",
      CellTags->"(5.1.96)"]},
  "i:41"->{
    Cell[12277179, 411644, 83, 1, 29, "Subsubsection",
      CellTags->"i:41"]},
  "(5.1.97)"->{
    Cell[12277615, 411661, 1312, 41, 28, "NumberedEquation",
      CellTags->"(5.1.97)"]},
  "Cell 5.11"->{
    Cell[12287550, 411962, 349, 8, 120, "Input",
      CellTags->"Cell 5.11"]},
  "(5.1.98)"->{
    Cell[12288187, 411980, 1188, 30, 55, "NumberedEquation",
      CellTags->"(5.1.98)"]},
  "(5.1.99)"->{
    Cell[12290274, 412043, 1870, 56, 32, "NumberedEquation",
      CellTags->"(5.1.99)"]},
  "(5.1.100)"->{
    Cell[12293285, 412138, 241, 9, 32, "NumberedEquation",
      CellTags->"(5.1.100)"]},
  "c:18"->{
    Cell[12293959, 412165, 65, 1, 30, "Subsubtitle",
      CellTags->"c:18"]},
  "i:45"->{
    Cell[12297622, 412293, 1291, 39, 86, "Text",
      CellTags->"i:45"]},
  "i:46"->{
    Cell[12298916, 412334, 719, 24, 56, "Text",
      CellTags->"i:46"]},
  "i:47"->{
    Cell[12305424, 412566, 1320, 37, 98, "Text",
      CellTags->"i:47"]},
  "i:48"->{
    Cell[12307628, 412636, 1174, 32, 94, "Text",
      CellTags->"i:48"]},
  "i:49"->{
    Cell[12311284, 412745, 636, 17, 45, "NumberedEquation",
      CellTags->{"i:49", "(5.1.101)"}]},
  "(5.1.101)"->{
    Cell[12311284, 412745, 636, 17, 45, "NumberedEquation",
      CellTags->{"i:49", "(5.1.101)"}]},
  "i:50"->{
    Cell[12313066, 412805, 1336, 38, 31, "NumberedEquation",
      CellTags->{"i:50", "(5.1.102)"}]},
  "(5.1.102)"->{
    Cell[12313066, 412805, 1336, 38, 31, "NumberedEquation",
      CellTags->{"i:50", "(5.1.102)"}]},
  "i:51"->{
    Cell[12315762, 412895, 1325, 34, 119, "Text",
      CellTags->"i:51"]},
  "i:131"->{
    Cell[12317448, 412945, 1874, 59, 174, "Text",
      CellTags->"i:131"]},
  "i:62"->{
    Cell[12320096, 413031, 1796, 56, 78, "Text",
      CellTags->"i:62"]},
  "i:52"->{
    Cell[12324808, 413189, 484, 16, 73, "Text",
      CellTags->"i:52"]},
  "Fig. 5.4"->{
    Cell[18765182, 549010, 95, 1, 17, "Caption",
      CellTags->"Fig. 5.4"]},
  "i:61"->{
    Cell[18765280, 549013, 246, 8, 27, "Text",
      CellTags->"i:61"]},
  "(5.1.103)"->{
    Cell[18766475, 549049, 360, 8, 59, "NumberedEquation",
      CellTags->"(5.1.103)"]},
  "i:63"->{
    Cell[18775052, 549329, 1881, 49, 102, "Text",
      CellTags->"i:63"]},
  "Fig. 5.5"->{
    Cell[18813751, 550248, 66, 1, 16, "Caption",
      CellTags->"Fig. 5.5"]},
  "i:64"->{
    Cell[18814368, 550268, 643, 20, 61, "Text",
      CellTags->"i:64"]},
  "i:53"->{
    Cell[18821334, 550536, 636, 19, 44, "Text",
      CellTags->"i:53"]},
  "i:65"->{
    Cell[18821973, 550557, 1174, 37, 103, "Text",
      CellTags->"i:65"]},
  "i:54"->{
    Cell[18828322, 550757, 397, 11, 61, "Text",
      CellTags->"i:54"]},
  "i:55"->{
    Cell[18828918, 550778, 906, 31, 54, "Text",
      CellTags->"i:55"]},
  "i:56"->{
    Cell[18834799, 550960, 264, 7, 44, "Text",
      CellTags->"i:56"]},
  "(5.1.104)"->{
    Cell[18835066, 550969, 197, 6, 33, "NumberedEquation",
      CellTags->"(5.1.104)"]},
  "i:57"->{
    Cell[18835266, 550977, 638, 20, 44, "Text",
      CellTags->"i:57"]},
  "i:58"->{
    Cell[18838416, 551070, 1164, 27, 112, "Text",
      CellTags->"i:58"]},
  "i:66"->{
    Cell[18844036, 551242, 68, 1, 40, "Subtitle",
      CellTags->{"i:66", "c:19"}]},
  "c:19"->{
    Cell[18844036, 551242, 68, 1, 40, "Subtitle",
      CellTags->{"i:66", "c:19"}]},
  "c:20"->{
    Cell[18844148, 551249, 80, 1, 40, "Subsubtitle",
      CellTags->"c:20"]},
  "i:67"->{
    Cell[18844253, 551254, 60, 1, 42, "Section",
      CellTags->{"i:67", "c:21"}]},
  "c:21"->{
    Cell[18844253, 551254, 60, 1, 42, "Section",
      CellTags->{"i:67", "c:21"}]},
  "i:128"->{
    Cell[18845132, 551275, 922, 27, 78, "Text",
      CellTags->"i:128"]},
  "i:106"->{
    Cell[18846057, 551304, 453, 13, 44, "Text",
      CellTags->"i:106"]},
  "(5.2.1)"->{
    Cell[18846513, 551319, 200, 6, 43, "NE2",
      CellTags->"(5.2.1)"]},
  "(5.2.2)"->{
    Cell[18847238, 551342, 194, 7, 31, "NE2",
      CellTags->"(5.2.2)"]},
  "(5.2.3)"->{
    Cell[18847904, 551371, 180, 6, 43, "NE2",
      CellTags->"(5.2.3)"]},
  "i:68"->{
    Cell[18849039, 551412, 215, 9, 27, "Text",
      CellTags->"i:68"]},
  "(5.2.4)"->{
    Cell[18849257, 551423, 139, 5, 32, "NE2",
      CellTags->"(5.2.4)"]},
  "(5.2.5)"->{
    Cell[18849459, 551432, 186, 6, 29, "NE2",
      CellTags->"(5.2.5)"]},
  "i:142"->{
    Cell[18849648, 551440, 826, 29, 47, "Text",
      CellTags->"i:142"]},
  "(5.2.6)"->{
    Cell[18850477, 551471, 198, 6, 42, "NE2",
      CellTags->"(5.2.6)"]},
  "(5.2.7)"->{
    Cell[18851696, 551511, 352, 10, 33, "NE2",
      CellTags->"(5.2.7)"]},
  "(5.2.8)"->{
    Cell[18852654, 551545, 201, 7, 40, "NE2",
      CellTags->"(5.2.8)"]},
  "i:69"->{
    Cell[18852858, 551554, 226, 9, 27, "Text",
      CellTags->"i:69"]},
  "i:70"->{
    Cell[18854291, 551605, 912, 25, 98, "Text",
      CellTags->"i:70"]},
  "(5.2.9)"->{
    Cell[18859449, 551777, 218, 7, 30, "NE2",
      CellTags->"(5.2.9)"]},
  "(5.2.10)"->{
    Cell[18862732, 551891, 409, 10, 35, "NE2",
      CellTags->"(5.2.10)"]},
  "(5.2.11)"->{
    Cell[18863497, 551918, 404, 6, 33, "NE2",
      CellTags->"(5.2.11)"]},
  "(5.2.12)"->{
    Cell[18864741, 551953, 224, 6, 41, "NE2",
      CellTags->"(5.2.12)"]},
  "(5.2.13)"->{
    Cell[18867248, 552029, 224, 7, 42, "NE2",
      CellTags->"(5.2.13)"]},
  "(5.2.14)"->{
    Cell[18869847, 552123, 302, 9, 37, "NE2",
      CellTags->"(5.2.14)"]},
  "(5.2.15)"->{
    Cell[18870642, 552152, 410, 9, 36, "NE2",
      CellTags->"(5.2.15)"]},
  "(5.2.16)"->{
    Cell[18871261, 552172, 459, 11, 43, "NE2",
      CellTags->"(5.2.16)"]},
  "i:96"->{
    Cell[18872066, 552197, 790, 28, 60, "Text",
      CellTags->"i:96"]},
  "(5.2.17)"->{
    Cell[18872859, 552227, 236, 7, 42, "NE2",
      CellTags->"(5.2.17)"]},
  "i:71"->{
    Cell[18873098, 552236, 1094, 37, 91, "Text",
      CellTags->"i:71"]},
  "Cell 5.12"->{
    Cell[18875042, 552302, 163, 4, 66, "Input",
      CellTags->"Cell 5.12"]},
  "Cell 5.13"->{
    Cell[18875398, 552314, 121, 3, 67, "Input",
      CellTags->"Cell 5.13"]},
  "Cell 5.14"->{
    Cell[18875648, 552326, 88, 3, 67, "Input",
      CellTags->"Cell 5.14"]},
  "Cell 5.15"->{
    Cell[18877823, 552386, 151, 4, 67, "Input",
      CellTags->"Cell 5.15"]},
  "i:140"->{
    Cell[18879362, 552434, 1522, 43, 129, "Text",
      CellTags->"i:140"]},
  "i:72"->{
    Cell[18880921, 552482, 102, 1, 31, "Section",
      CellTags->{"i:72", "c:22"}]},
  "c:22"->{
    Cell[18880921, 552482, 102, 1, 31, "Section",
      CellTags->{"i:72", "c:22"}]},
  "(5.2.18)"->{
    Cell[18882277, 552520, 541, 11, 47, "NE2",
      CellTags->"(5.2.18)"]},
  "Cell 5.16"->{
    Cell[18883321, 552554, 596, 12, 150, "Input",
      CellTags->"Cell 5.16"]},
  "Cell 5.17"->{
    Cell[19605688, 567283, 276, 7, 100, "Input",
      CellTags->"Cell 5.17"]},
  "Cell 5.18"->{
    Cell[19607341, 567342, 490, 10, 123, "Input",
      CellTags->"Cell 5.18"]},
  "Cell 5.19"->{
    Cell[19608081, 567367, 211, 5, 85, "Input",
      CellTags->"Cell 5.19"]},
  "Cell 5.20"->{
    Cell[19687944, 568948, 198, 4, 66, "Input",
      CellTags->"Cell 5.20"]},
  "i:73"->{
    Cell[19796007, 570863, 128, 4, 31, "Section",
      CellTags->{"i:73", "c:23"}]},
  "c:23"->{
    Cell[19796007, 570863, 128, 4, 31, "Section",
      CellTags->{"i:73", "c:23"}]},
  "(5.2.19)"->{
    Cell[19798154, 570912, 187, 6, 37, "NE2",
      CellTags->"(5.2.19)"]},
  "(5.2.20)"->{
    Cell[19798634, 570929, 179, 6, 31, "NE2",
      CellTags->"(5.2.20)"]},
  "(5.2.21)"->{
    Cell[19799841, 570970, 233, 7, 42, "NE2",
      CellTags->"(5.2.21)"]},
  "Cell 5.21"->{
    Cell[19802021, 571043, 913, 20, 260, "Input",
      CellTags->"Cell 5.21"]},
  "(5.2.22)"->{
    Cell[19909175, 573657, 138, 5, 28, "NE2",
      CellTags->"(5.2.22)"]},
  "Cell 5.22"->{
    Cell[19911667, 573731, 363, 8, 105, "Input",
      CellTags->"Cell 5.22"]},
  "i:74"->{
    Cell[20122334, 584183, 65, 1, 31, "Section",
      CellTags->{"i:74", "c:24"}]},
  "c:24"->{
    Cell[20122334, 584183, 65, 1, 31, "Section",
      CellTags->{"i:74", "c:24"}]},
  "(5.2.23)"->{
    Cell[20123265, 584211, 207, 6, 42, "NE2",
      CellTags->"(5.2.23)"]},
  "(5.2.24)"->{
    Cell[20123653, 584226, 273, 8, 28, "NE2",
      CellTags->"(5.2.24)"]},
  "(5.2.25)"->{
    Cell[20124384, 584253, 496, 9, 37, "NE2",
      CellTags->"(5.2.25)"]},
  "(5.2.26)"->{
    Cell[20125663, 584293, 574, 12, 50, "NE2",
      CellTags->"(5.2.26)"]},
  "(5.2.27)"->{
    Cell[20126539, 584318, 539, 12, 51, "NE2",
      CellTags->"(5.2.27)"]},
  "(5.2.28)"->{
    Cell[20128422, 584377, 179, 3, 31, "NE2",
      CellTags->"(5.2.28)"]},
  "(5.2.29)"->{
    Cell[20130808, 584449, 232, 7, 32, "NE2",
      CellTags->"(5.2.29)"]},
  "(5.2.30)"->{
    Cell[20131972, 584496, 184, 7, 33, "NE2",
      CellTags->"(5.2.30)"]},
  "Cell 5.23"->{
    Cell[20134182, 584572, 915, 22, 297, "Input",
      CellTags->"Cell 5.23"]},
  "i:75"->{
    Cell[21110653, 612603, 104, 1, 31, "Section",
      CellTags->{"i:75", "c:25"}]},
  "c:25"->{
    Cell[21110653, 612603, 104, 1, 31, "Section",
      CellTags->{"i:75", "c:25"}]},
  "(5.2.31)"->{
    Cell[21111520, 612633, 492, 15, 41, "NE2",
      CellTags->"(5.2.31)"]},
  "(5.2.32)"->{
    Cell[21114672, 612738, 295, 8, 42, "NE2",
      CellTags->"(5.2.32)"]},
  "(5.2.33)"->{
    Cell[21114994, 612750, 171, 3, 32, "NE2",
      CellTags->"(5.2.33)"]},
  "(5.2.34)"->{
    Cell[21115435, 612766, 184, 6, 32, "NE2",
      CellTags->"(5.2.34)"]},
  "(5.2.35)"->{
    Cell[21117123, 612823, 330, 9, 40, "NE2",
      CellTags->"(5.2.35)"]},
  "(5.2.36)"->{
    Cell[21118206, 612864, 519, 17, 45, "NE2",
      CellTags->"(5.2.36)"]},
  "Fig. 5.6"->{
    Cell[21163700, 613444, 102, 1, 15, "Caption",
      CellTags->"Fig. 5.6"]},
  "Cell 5.24"->{
    Cell[21165811, 613518, 968, 22, 392, "Input",
      CellTags->"Cell 5.24"]},
  "Cell 5.25"->{
    Cell[21628814, 624466, 364, 8, 105, "Input",
      CellTags->"Cell 5.25"]},
  "i:76"->{
    Cell[27219837, 820456, 471, 11, 60, "Text",
      CellTags->"i:76"]},
  "i:107"->{
    Cell[27220345, 820472, 66, 1, 31, "Section",
      CellTags->{"i:107", "c:26"}]},
  "c:26"->{
    Cell[27220345, 820472, 66, 1, 31, "Section",
      CellTags->{"i:107", "c:26"}]},
  "(5.2.37)"->{
    Cell[27220712, 820485, 222, 7, 30, "NE2",
      CellTags->"(5.2.37)"]},
  "(5.2.38)"->{
    Cell[27223441, 820566, 1026, 32, 38, "NE2",
      CellTags->"(5.2.38)"]},
  "i:77"->{
    Cell[27225557, 820639, 2498, 80, 130, "Text",
      CellTags->"i:77"]},
  "(5.2.39)"->{
    Cell[27228058, 820721, 294, 10, 46, "NE2",
      CellTags->"(5.2.39)"]},
  "Cell 5.26"->{
    Cell[27228765, 820751, 901, 16, 218, "Input",
      CellTags->"Cell 5.26"]},
  "i:108"->{
    Cell[27781331, 840344, 997, 31, 90, "Text",
      CellTags->"i:108"]},
  "(5.2.40)"->{
    Cell[27782331, 840377, 281, 8, 45, "NE2",
      CellTags->"(5.2.40)"]},
  "i:78"->{
    Cell[27783581, 840420, 191, 7, 42, "NE2",
      CellTags->{"i:78", "(5.2.41)"}]},
  "(5.2.41)"->{
    Cell[27783581, 840420, 191, 7, 42, "NE2",
      CellTags->{"i:78", "(5.2.41)"}]},
  "Fig. 5.7"->{
    Cell[27839114, 841129, 201, 6, 15, "Caption",
      CellTags->"Fig. 5.7"]},
  "i:79"->{
    Cell[27839957, 841153, 98, 1, 29, "Subsubtitle",
      CellTags->{"i:79", "c:27"}]},
  "c:27"->{
    Cell[27839957, 841153, 98, 1, 29, "Subsubtitle",
      CellTags->{"i:79", "c:27"}]},
  "i:80"->{
    Cell[27840080, 841158, 71, 1, 41, "Section",
      CellTags->{"i:80", "c:28"}]},
  "c:28"->{
    Cell[27840080, 841158, 71, 1, 41, "Section",
      CellTags->{"i:80", "c:28"}]},
  "i:124"->{
    Cell[27840154, 841161, 142, 4, 26, "Text",
      CellTags->"i:124"]},
  "(5.2.42)"->{
    Cell[27840299, 841167, 165, 6, 30, "NE2",
      CellTags->"(5.2.42)"]},
  "i:113"->{
    Cell[27840467, 841175, 643, 14, 95, "Text",
      CellTags->"i:113"]},
  "i:129"->{
    Cell[27841113, 841191, 1308, 40, 96, "Text",
      CellTags->"i:129"]},
  "(5.2.43)"->{
    Cell[27842424, 841233, 117, 2, 26, "NE2",
      CellTags->"(5.2.43)"]},
  "(5.2.44)"->{
    Cell[27845069, 841308, 343, 6, 50, "NE2",
      CellTags->"(5.2.44)"]},
  "(5.2.45)"->{
    Cell[27847417, 841377, 221, 7, 46, "NE2",
      CellTags->"(5.2.45)"]},
  "(5.2.46)"->{
    Cell[27849240, 841434, 184, 3, 37, "NE2",
      CellTags->"(5.2.46)"]},
  "(5.2.47)"->{
    Cell[27849877, 841456, 318, 8, 37, "NE2",
      CellTags->"(5.2.47)"]},
  "i:81"->{
    Cell[27850198, 841466, 1073, 33, 95, "Text",
      CellTags->"i:81"]},
  "(5.2.48)"->{
    Cell[27851274, 841501, 1748, 51, 43, "NE2",
      CellTags->"(5.2.48)"]},
  "i:114"->{
    Cell[27853025, 841554, 1511, 46, 77, "Text",
      CellTags->"i:114"]},
  "(5.2.49)"->{
    Cell[27856360, 841664, 328, 9, 45, "NE2",
      CellTags->"(5.2.49)"]},
  "i:82"->{
    Cell[27858289, 841718, 950, 27, 80, "Text",
      CellTags->"i:82"]},
  "(5.2.50)"->{
    Cell[27862270, 841827, 253, 8, 62, "NE2",
      CellTags->"(5.2.50)"]},
  "Cell 5.27"->{
    Cell[27863659, 841876, 351, 9, 145, "Input",
      CellTags->"Cell 5.27"]},
  "Fig. 5.8"->{
    Cell[27919887, 843447, 213, 6, 20, "Caption",
      CellTags->"Fig. 5.8"]},
  "i:83"->{
    Cell[27920599, 843466, 1544, 45, 112, "Text",
      CellTags->"i:83"]},
  "i:84"->{
    Cell[27922146, 843513, 821, 24, 80, "Text",
      CellTags->"i:84"]},
  "i:85"->{
    Cell[27923628, 843559, 108, 1, 30, "Section",
      CellTags->{"i:85", "c:29"}]},
  "c:29"->{
    Cell[27923628, 843559, 108, 1, 30, "Section",
      CellTags->{"i:85", "c:29"}]},
  "(5.2.51)"->{
    Cell[27924131, 843575, 321, 9, 41, "NE2",
      CellTags->"(5.2.51)"]},
  "(5.2.52)"->{
    Cell[27925734, 843630, 259, 7, 41, "NE2",
      CellTags->"(5.2.52)"]},
  "(5.2.53)"->{
    Cell[27926186, 843648, 201, 7, 38, "NE2",
      CellTags->"(5.2.53)"]},
  "(5.2.54)"->{
    Cell[27928852, 843736, 444, 14, 85, "NE2",
      CellTags->"(5.2.54)"]},
  "i:86"->{
    Cell[27929772, 843770, 63, 1, 30, "Section",
      CellTags->{"i:86", "c:30"}]},
  "c:30"->{
    Cell[27929772, 843770, 63, 1, 30, "Section",
      CellTags->{"i:86", "c:30"}]},
  "(5.2.55)"->{
    Cell[27931856, 843833, 186, 7, 31, "NE2",
      CellTags->"(5.2.55)"]},
  "(5.2.56)"->{
    Cell[27933506, 843896, 180, 7, 30, "NE2",
      CellTags->"(5.2.56)"]},
  "(5.2.57)"->{
    Cell[27933731, 843907, 225, 7, 32, "NE2",
      CellTags->"(5.2.57)"]},
  "(5.2.58)"->{
    Cell[27934732, 843944, 165, 3, 32, "NE2",
      CellTags->"(5.2.58)"]},
  "Cell 5.28"->{
    Cell[27935590, 843975, 308, 7, 115, "Input",
      CellTags->"Cell 5.28"]},
  "i:87"->{
    Cell[27935901, 843984, 86834, 1665, 263, 12693, 744, "GraphicsData", 
    "PostScript", "Graphics",
      CellTags->"i:87"]},
  "i:138"->{
    Cell[28022750, 845652, 899, 18, 111, "Text",
      CellTags->"i:138"]},
  "i:88"->{
    Cell[28025470, 845715, 70, 1, 30, "Section",
      CellTags->{"i:88", "c:31"}]},
  "c:31"->{
    Cell[28025470, 845715, 70, 1, 30, "Section",
      CellTags->{"i:88", "c:31"}]},
  "i:119"->{
    Cell[28026762, 845749, 1840, 50, 37, "NE2",
      CellTags->{"i:119", "(5.2.59)"}]},
  "(5.2.59)"->{
    Cell[28026762, 845749, 1840, 50, 37, "NE2",
      CellTags->{"i:119", "(5.2.59)"}]},
  "(5.2.60)"->{
    Cell[28029595, 845836, 584, 18, 37, "NE2",
      CellTags->"(5.2.60)"]},
  "(5.2.61)"->{
    Cell[28037683, 846091, 602, 17, 33, "NE2",
      CellTags->"(5.2.61)"]},
  "i:125"->{
    Cell[28038288, 846110, 1316, 36, 86, "Text",
      CellTags->"i:125"]},
  "i:89"->{
    Cell[28041275, 846197, 625, 22, 43, "Text",
      CellTags->"i:89"]},
  "c:33"->{
    Cell[28043355, 846266, 65, 1, 29, "Subsubtitle",
      CellTags->"c:33"]},
  "i:94"->{
    Cell[28043423, 846269, 136, 5, 27, "Text",
      CellTags->"i:94"]},
  "i:109"->{
    Cell[28045436, 846351, 1205, 41, 116, "Text",
      CellTags->"i:109"]},
  "i:95"->{
    Cell[28046644, 846394, 443, 15, 44, "Text",
      CellTags->"i:95"]},
  "Fig. 5.9"->{
    Cell[28101050, 847908, 415, 11, 29, "Caption",
      CellTags->"Fig. 5.9"]},
  "i:97"->{
    Cell[28101468, 847921, 1345, 41, 104, "Text",
      CellTags->"i:97"]},
  "i:110"->{
    Cell[28102816, 847964, 525, 12, 78, "Text",
      CellTags->"i:110"]},
  "i:98"->{
    Cell[28103825, 847995, 291, 11, 27, "Text",
      CellTags->"i:98"]},
  "(5.2.62)"->{
    Cell[28104543, 848023, 541, 12, 44, "NE2",
      CellTags->"(5.2.62)"]},
  "i:127"->{
    Cell[28109881, 848217, 622, 18, 64, "Text",
      CellTags->"i:127"]},
  "i:126"->{
    Cell[28111882, 848281, 951, 34, 49, "Text",
      CellTags->"i:126"]},
  "i:118"->{
    Cell[28112836, 848317, 2016, 58, 44, "NE2",
      CellTags->{"i:118", "(5.2.63)"}]},
  "(5.2.63)"->{
    Cell[28112836, 848317, 2016, 58, 44, "NE2",
      CellTags->{"i:118", "(5.2.63)"}]},
  "i:99"->{
    Cell[28118277, 848499, 287, 9, 44, "Text",
      CellTags->"i:99"]},
  "i:111"->{
    Cell[28124565, 848702, 2149, 67, 126, "Text",
      CellTags->"i:111"]},
  "i:100"->{
    Cell[28126717, 848771, 1580, 48, 143, "Text",
      CellTags->"i:100"]},
  "i:101"->{
    Cell[28135952, 849064, 1620, 51, 116, "Text",
      CellTags->"i:101"]},
  "i:102"->{
    Cell[28137575, 849117, 756, 21, 79, "Text",
      CellTags->"i:102"]},
  "i:103"->{
    Cell[28145357, 849371, 882, 24, 81, "Text",
      CellTags->"i:103"]},
  "Fig. 5.10"->{
    Cell[28349212, 852524, 101, 1, 16, "Caption",
      CellTags->"Fig. 5.10"]},
  "i:104"->{
    Cell[28349316, 852527, 1721, 49, 129, "Text",
      CellTags->"i:104"]},
  "(5.2.64)"->{
    Cell[28351155, 852584, 344, 10, 44, "NE2",
      CellTags->"(5.2.64)"]},
  "(5.2.65)"->{
    Cell[28354485, 852690, 249, 8, 33, "NE2",
      CellTags->"(5.2.65)"]},
  "i:105"->{
    Cell[28356605, 852764, 216, 8, 27, "Text",
      CellTags->"i:105"]},
  "i:90"->{
    Cell[28358849, 852847, 97, 2, 40, "Subtitle",
      CellTags->{"i:90", "c:32"}]},
  "c:32"->{
    Cell[28358849, 852847, 97, 2, 40, "Subtitle",
      CellTags->{"i:90", "c:32"}]},
  "c:35"->{
    Cell[28360063, 852877, 69, 1, 40, "Subsubtitle",
      CellTags->"c:35"]},
  "(5.3.1)"->{
    Cell[28360620, 852898, 113, 5, 33, "NE3",
      CellTags->"(5.3.1)"]},
  "(5.3.2)"->{
    Cell[28360904, 852912, 800, 26, 38, "NE3",
      CellTags->"(5.3.2)"]},
  "(5.3.3)"->{
    Cell[28369326, 853180, 298, 7, 33, "NE3",
      CellTags->"(5.3.3)"]},
  "(5.3.4)"->{
    Cell[28370962, 853238, 1043, 29, 39, "NE3",
      CellTags->"(5.3.4)"]},
  "i:121"->{
    Cell[28372008, 853269, 341, 13, 27, "Text",
      CellTags->"i:121"]},
  "(5.3.5)"->{
    Cell[28372919, 853302, 1186, 37, 46, "NE3",
      CellTags->"(5.3.5)"]},
  "(5.3.6)"->{
    Cell[28374430, 853354, 916, 30, 31, "NE3",
      CellTags->"(5.3.6)"]},
  "i:122"->{
    Cell[28375546, 853394, 502, 17, 29, "NE3",
      CellTags->{"i:122", "(5.3.7)"}]},
  "(5.3.7)"->{
    Cell[28375546, 853394, 502, 17, 29, "NE3",
      CellTags->{"i:122", "(5.3.7)"}]},
  "(5.3.8)"->{
    Cell[28376269, 853421, 474, 16, 29, "NE3",
      CellTags->"(5.3.8)"]},
  "i:91"->{
    Cell[28377990, 853482, 1249, 43, 78, "Text",
      CellTags->"i:91"]},
  "(5.3.9)"->{
    Cell[28379841, 853548, 189, 7, 43, "NE3",
      CellTags->"(5.3.9)"]},
  "(5.3.10)"->{
    Cell[28384437, 853718, 789, 25, 53, "NE3",
      CellTags->"(5.3.10)"]},
  "(5.3.11)"->{
    Cell[28385694, 853761, 728, 21, 43, "NE3",
      CellTags->"(5.3.11)"]},
  "(5.3.12)"->{
    Cell[28387767, 853830, 974, 29, 38, "NE3",
      CellTags->"(5.3.12)"]},
  "(5.3.13)"->{
    Cell[28388793, 853863, 1100, 34, 38, "NE3",
      CellTags->"(5.3.13)"]},
  "(5.3.14)"->{
    Cell[28395276, 854064, 193, 6, 38, "NE3",
      CellTags->"(5.3.14)"]},
  "i:115"->{
    Cell[28395472, 854072, 1170, 36, 78, "Text",
      CellTags->"i:115"]},
  "i:141"->{
    Cell[28396645, 854110, 4526, 144, 146, "Text",
      CellTags->"i:141"]},
  "Cell 5.29"->{
    Cell[28401893, 854276, 120, 3, 67, "Input",
      CellTags->"Cell 5.29"]},
  "Cell 5.30"->{
    Cell[28402522, 854300, 154, 4, 67, "Input",
      CellTags->"Cell 5.30"]},
  "(5.3.15)"->{
    Cell[28403830, 854343, 503, 14, 39, "NE3",
      CellTags->"(5.3.15)"]},
  "Cell 5.31"->{
    Cell[28405323, 854390, 384, 9, 105, "Input",
      CellTags->"Cell 5.31"]},
  "Cell 5.32"->{
    Cell[28405710, 854401, 397, 9, 105, "Input",
      CellTags->"Cell 5.32"]},
  "Cell 5.33"->{
    Cell[28406110, 854412, 1316, 25, 257, "Input",
      CellTags->"Cell 5.33"]},
  "Cell 5.34"->{
    Cell[28407600, 854445, 152, 4, 67, "Input",
      CellTags->"Cell 5.34"]},
  "Cell 5.35"->{
    Cell[28408051, 854464, 208, 5, 67, "Input",
      CellTags->"Cell 5.35"]},
  "Cell 5.36"->{
    Cell[28408337, 854475, 159, 4, 67, "Input",
      CellTags->"Cell 5.36"]},
  "Cell 5.37"->{
    Cell[28517508, 856388, 97, 3, 67, "Input",
      CellTags->"Cell 5.37"]},
  "Cell 5.38"->{
    Cell[28517608, 856393, 295, 8, 86, "Input",
      CellTags->"Cell 5.38"]},
  "Cell 5.39"->{
    Cell[28518164, 856414, 92, 3, 67, "Input",
      CellTags->"Cell 5.39"]},
  "Cell 5.40"->{
    Cell[28518259, 856419, 326, 7, 105, "Input",
      CellTags->"Cell 5.40"]},
  "Cell 5.41"->{
    Cell[28518610, 856430, 261, 6, 86, "Input",
      CellTags->"Cell 5.41"]},
  "Cell 5.42"->{
    Cell[29527555, 882466, 291, 6, 105, "Input",
      CellTags->"Cell 5.42"]},
  "Cell 5.43"->{
    Cell[29527849, 882474, 389, 8, 124, "Input",
      CellTags->"Cell 5.43"]},
  "Cell 5.44"->{
    Cell[29528263, 882486, 273, 5, 86, "Input",
      CellTags->"Cell 5.44"]},
  "(5.3.16)"->{
    Cell[29665205, 885274, 176, 7, 29, "NE3",
      CellTags->"(5.3.16)"]},
  "Fig. 5.11"->{
    Cell[29713826, 885886, 316, 10, 29, "Caption",
      CellTags->"Fig. 5.11"]},
  "i:136"->{
    Cell[29714145, 885898, 791, 21, 78, "Text",
      CellTags->"i:136"]},
  "Cell 5.45"->{
    Cell[29715428, 885936, 187, 5, 67, "Input",
      CellTags->"Cell 5.45"]},
  "Cell 5.46"->{
    Cell[29715640, 885945, 159, 4, 67, "Input",
      CellTags->"Cell 5.46"]},
  "Cell 5.47"->{
    Cell[29820610, 887798, 291, 8, 85, "Input",
      CellTags->"Cell 5.47"]},
  "Cell 5.48"->{
    Cell[29820904, 887808, 328, 7, 105, "Input",
      CellTags->"Cell 5.48"]},
  "Cell 5.49"->{
    Cell[29821257, 887819, 261, 6, 85, "Input",
      CellTags->"Cell 5.49"]},
  "Fig. 5.12"->{
    Cell[31950550, 943698, 152, 4, 16, "Caption",
      CellTags->"Fig. 5.12"]},
  "i:132"->{
    Cell[31950705, 943704, 1347, 22, 197, "Text",
      CellTags->"i:132"]},
  "i:134"->{
    Cell[31952709, 943745, 655, 16, 78, "Text",
      CellTags->"i:134"]},
  "i:135"->{
    Cell[31953367, 943763, 1196, 29, 112, "Text",
      CellTags->"i:135"]},
  "Fig. 5.13"->{
    Cell[38302022, 1022163, 198, 5, 16, "Caption",
      CellTags->"Fig. 5.13"]},
  "c:36"->{
    Cell[38302257, 1022173, 76, 1, 29, "Subsubtitle",
      CellTags->"c:36"]},
  "(5.3.17)"->{
    Cell[38304445, 1022248, 489, 11, 45, "NE3",
      CellTags->"(5.3.17)"]},
  "(5.3.18)"->{
    Cell[38305385, 1022276, 1977, 42, 82, "NE3",
      CellTags->"(5.3.18)"]},
  "(5.3.19)"->{
    Cell[38310361, 1022412, 1988, 46, 50, "NE3",
      CellTags->"(5.3.19)"]},
  "(5.3.20)"->{
    Cell[38314699, 1022533, 641, 19, 37, "NE3",
      CellTags->"(5.3.20)"]},
  "(5.3.21)"->{
    Cell[38316967, 1022613, 760, 21, 37, "NE3",
      CellTags->"(5.3.21)"]},
  "(5.3.22)"->{
    Cell[38318230, 1022657, 763, 26, 37, "NE3",
      CellTags->"(5.3.22)"]},
  "i:120"->{
    Cell[38320143, 1022722, 1879, 48, 37, "NE3",
      CellTags->{"i:120", "(5.3.23)"}]},
  "(5.3.23)"->{
    Cell[38320143, 1022722, 1879, 48, 37, "NE3",
      CellTags->{"i:120", "(5.3.23)"}]},
  "i:92"->{
    Cell[38322025, 1022772, 1143, 37, 48, "Text",
      CellTags->"i:92"]},
  "(5.3.24)"->{
    Cell[38324073, 1022838, 143, 5, 28, "NE3",
      CellTags->"(5.3.24)"]},
  "i:93"->{
    Cell[38324219, 1022845, 1289, 32, 128, "Text",
      CellTags->"i:93"]},
  "c:37"->{
    Cell[38325545, 1022882, 65, 1, 29, "Subsubtitle",
      CellTags->"c:37"]},
  "(5.3.25)"->{
    Cell[38330782, 1023086, 881, 23, 53, "NE3",
      CellTags->"(5.3.25)"]},
  "refs"->{
    Cell[38335815, 1023260, 60, 1, 40, "Subtitle",
      CellTags->{"refs", "c:34"}]},
  "c:34"->{
    Cell[38335815, 1023260, 60, 1, 40, "Subtitle",
      CellTags->{"refs", "c:34"}]}
  }
*)

(*CellTagsIndex
CellTagsIndex->{
  {"i:1", 38383349, 1024692},
  {"c:1", 38383434, 1024695},
  {"Fig. 5.1", 38383524, 1024698},
  {"c:3", 38383608, 1024701},
  {"c:4", 38383688, 1024704},
  {"i:2", 38383771, 1024707},
  {"c:5", 38383859, 1024710},
  {"(5.1.1)", 38383951, 1024713},
  {"(5.1.2)", 38384048, 1024716},
  {"i:5", 38384141, 1024719},
  {"(5.1.3)", 38384223, 1024722},
  {"(5.1.4)", 38384320, 1024725},
  {"(5.1.5)", 38384418, 1024728},
  {"(5.1.6)", 38384515, 1024731},
  {"i:3", 38384608, 1024734},
  {"(5.1.7)", 38384689, 1024737},
  {"(5.1.8)", 38384786, 1024740},
  {"(5.1.9)", 38384884, 1024743},
  {"i:7", 38384978, 1024746},
  {"Cell 5.1", 38385062, 1024749},
  {"Cell 5.2", 38385152, 1024752},
  {"c:6", 38385240, 1024755},
  {"(5.1.10)", 38385328, 1024758},
  {"i:6", 38385427, 1024761},
  {"(5.1.11)", 38385539, 1024764},
  {"(5.1.12)", 38385651, 1024767},
  {"(5.1.13)", 38385755, 1024770},
  {"(5.1.14)", 38385858, 1024773},
  {"c:7", 38385956, 1024776},
  {"c:8", 38386043, 1024779},
  {"(5.1.15)", 38386132, 1024782},
  {"(5.1.16)", 38386235, 1024785},
  {"(5.1.17)", 38386338, 1024788},
  {"(5.1.18)", 38386441, 1024791},
  {"i:8", 38386539, 1024794},
  {"(5.1.19)", 38386651, 1024797},
  {"(5.1.20)", 38386763, 1024800},
  {"i:9", 38386862, 1024803},
  {"(5.1.21)", 38386951, 1024806},
  {"i:10", 38387050, 1024809},
  {"(5.1.22)", 38387139, 1024812},
  {"i:12", 38387238, 1024815},
  {"Cell 5.3", 38387327, 1024818},
  {"(5.1.23)", 38387421, 1024821},
  {"(5.1.24)", 38387525, 1024824},
  {"Cell 5.4", 38387629, 1024827},
  {"(5.1.25)", 38387722, 1024830},
  {"Cell 5.5", 38387825, 1024833},
  {"Cell 5.6", 38387918, 1024836},
  {"i:13", 38388008, 1024839},
  {"c:9", 38388101, 1024842},
  {"Cell 5.7", 38388199, 1024845},
  {"(5.1.26)", 38388291, 1024848},
  {"(5.1.27)", 38388395, 1024851},
  {"i:22", 38388495, 1024854},
  {"i:27", 38388579, 1024857},
  {"i:14", 38388663, 1024860},
  {"(5.1.28)", 38388777, 1024863},
  {"(5.1.29)", 38388891, 1024866},
  {"Cell 5.8", 38388994, 1024869},
  {"i:15", 38389084, 1024872},
  {"c:10", 38389180, 1024875},
  {"(5.1.30)", 38389280, 1024878},
  {"i:16", 38389381, 1024881},
  {"(5.1.31)", 38389495, 1024884},
  {"c:11", 38389605, 1024887},
  {"i:17", 38389695, 1024890},
  {"c:12", 38389792, 1024893},
  {"(5.1.32)", 38389893, 1024896},
  {"(5.1.33)", 38389998, 1024899},
  {"(5.1.34)", 38390103, 1024902},
  {"(5.1.35)", 38390208, 1024905},
  {"i:18", 38390310, 1024908},
  {"(5.1.36)", 38390399, 1024911},
  {"(5.1.37)", 38390504, 1024914},
  {"(5.1.38)", 38390609, 1024917},
  {"i:19", 38390711, 1024920},
  {"(5.1.39)", 38390800, 1024923},
  {"(5.1.40)", 38390905, 1024926},
  {"i:21", 38391005, 1024929},
  {"(5.1.41)", 38391120, 1024932},
  {"(5.1.42)", 38391235, 1024935},
  {"i:139", 38391337, 1024938},
  {"Fig. 5.2", 38391428, 1024941},
  {"c:13", 38391519, 1024944},
  {"i:20", 38391605, 1024947},
  {"(5.1.43)", 38391720, 1024950},
  {"c:14", 38391831, 1024953},
  {"(5.1.44)", 38391921, 1024956},
  {"(5.1.45)", 38392026, 1024959},
  {"i:59", 38392128, 1024962},
  {"(5.1.46)", 38392217, 1024965},
  {"(5.1.47)", 38392323, 1024968},
  {"(5.1.48)", 38392429, 1024971},
  {"(5.1.49)", 38392535, 1024974},
  {"(5.1.50)", 38392641, 1024977},
  {"i:23", 38392743, 1024980},
  {"(5.1.51)", 38392859, 1024983},
  {"i:24", 38392971, 1024986},
  {"(5.1.52)", 38393067, 1024989},
  {"(5.1.53)", 38393173, 1024992},
  {"(5.1.54)", 38393279, 1024995},
  {"i:133", 38393381, 1024998},
  {"(5.1.55)", 38393473, 1025001},
  {"(5.1.56)", 38393579, 1025004},
  {"i:25", 38393679, 1025007},
  {"i:26", 38393764, 1025010},
  {"i:34", 38393848, 1025013},
  {"(5.1.57)", 38393944, 1025016},
  {"i:28", 38394045, 1025019},
  {"(5.1.58)", 38394132, 1025022},
  {"i:29", 38394232, 1025025},
  {"(5.1.59)", 38394347, 1025028},
  {"(5.1.60)", 38394462, 1025031},
  {"(5.1.61)", 38394568, 1025034},
  {"i:30", 38394670, 1025037},
  {"(5.1.62)", 38394786, 1025040},
  {"(5.1.63)", 38394902, 1025043},
  {"i:35", 38395002, 1025046},
  {"i:36", 38395089, 1025049},
  {"(5.1.64)", 38395204, 1025052},
  {"i:112", 38395316, 1025055},
  {"(5.1.65)", 38395406, 1025058},
  {"(5.1.66)", 38395511, 1025061},
  {"(5.1.67)", 38395615, 1025064},
  {"(5.1.68)", 38395720, 1025067},
  {"(5.1.69)", 38395825, 1025070},
  {"(5.1.70)", 38395929, 1025073},
  {"(5.1.71)", 38396034, 1025076},
  {"i:32", 38396135, 1025079},
  {"(5.1.72)", 38396250, 1025082},
  {"(5.1.73)", 38396365, 1025085},
  {"i:116", 38396467, 1025088},
  {"(5.1.74)", 38396556, 1025091},
  {"i:117", 38396658, 1025094},
  {"i:33", 38396745, 1025097},
  {"(5.1.75)", 38396860, 1025100},
  {"(5.1.76)", 38396975, 1025103},
  {"(5.1.77)", 38397079, 1025106},
  {"i:40", 38397181, 1025109},
  {"(5.1.78)", 38397271, 1025112},
  {"Cell 5.9", 38397375, 1025115},
  {"c:15", 38397466, 1025118},
  {"(5.1.79)", 38397556, 1025121},
  {"(5.1.80)", 38397662, 1025124},
  {"(5.1.81)", 38397768, 1025127},
  {"Cell 5.10", 38397875, 1025130},
  {"(5.1.82)", 38397969, 1025133},
  {"(5.1.83)", 38398075, 1025136},
  {"(5.1.84)", 38398182, 1025139},
  {"i:37", 38398284, 1025142},
  {"(5.1.85)", 38398374, 1025145},
  {"i:130", 38398478, 1025148},
  {"i:38", 38398565, 1025151},
  {"c:16", 38398662, 1025154},
  {"(5.1.86)", 38398763, 1025157},
  {"(5.1.87)", 38398870, 1025160},
  {"(5.1.88)", 38398978, 1025163},
  {"i:39", 38399080, 1025166},
  {"(5.1.89)", 38399171, 1025169},
  {"(5.1.90)", 38399278, 1025172},
  {"Fig. 5.3", 38399384, 1025175},
  {"c:17", 38399476, 1025178},
  {"(5.1.91)", 38399567, 1025181},
  {"i:60", 38399670, 1025184},
  {"(5.1.92)", 38399760, 1025187},
  {"(5.1.93)", 38399867, 1025190},
  {"(5.1.94)", 38399974, 1025193},
  {"i:44", 38400075, 1025196},
  {"i:43", 38400160, 1025199},
  {"(5.1.95)", 38400276, 1025202},
  {"i:42", 38400388, 1025205},
  {"(5.1.96)", 38400476, 1025208},
  {"i:41", 38400578, 1025211},
  {"(5.1.97)", 38400675, 1025214},
  {"Cell 5.11", 38400783, 1025217},
  {"(5.1.98)", 38400879, 1025220},
  {"(5.1.99)", 38400986, 1025223},
  {"(5.1.100)", 38401094, 1025226},
  {"c:18", 38401196, 1025229},
  {"i:45", 38401287, 1025232},
  {"i:46", 38401374, 1025235},
  {"i:47", 38401460, 1025238},
  {"i:48", 38401547, 1025241},
  {"i:49", 38401634, 1025244},
  {"(5.1.101)", 38401752, 1025247},
  {"i:50", 38401865, 1025250},
  {"(5.1.102)", 38401984, 1025253},
  {"i:51", 38402098, 1025256},
  {"i:131", 38402187, 1025259},
  {"i:62", 38402276, 1025262},
  {"i:52", 38402363, 1025265},
  {"Fig. 5.4", 38402453, 1025268},
  {"i:61", 38402544, 1025271},
  {"(5.1.103)", 38402634, 1025274},
  {"i:63", 38402736, 1025277},
  {"Fig. 5.5", 38402828, 1025280},
  {"i:64", 38402919, 1025283},
  {"i:53", 38403005, 1025286},
  {"i:65", 38403091, 1025289},
  {"i:54", 38403179, 1025292},
  {"i:55", 38403265, 1025295},
  {"i:56", 38403351, 1025298},
  {"(5.1.104)", 38403441, 1025301},
  {"i:57", 38403543, 1025304},
  {"i:58", 38403629, 1025307},
  {"i:66", 38403717, 1025310},
  {"c:19", 38403815, 1025313},
  {"c:20", 38403913, 1025316},
  {"i:67", 38404004, 1025319},
  {"c:21", 38404101, 1025322},
  {"i:128", 38404199, 1025325},
  {"i:106", 38404287, 1025328},
  {"(5.2.1)", 38404377, 1025331},
  {"(5.2.2)", 38404467, 1025334},
  {"(5.2.3)", 38404557, 1025337},
  {"i:68", 38404644, 1025340},
  {"(5.2.4)", 38404732, 1025343},
  {"(5.2.5)", 38404822, 1025346},
  {"i:142", 38404910, 1025349},
  {"(5.2.6)", 38405000, 1025352},
  {"(5.2.7)", 38405090, 1025355},
  {"(5.2.8)", 38405181, 1025358},
  {"i:69", 38405268, 1025361},
  {"i:70", 38405353, 1025364},
  {"(5.2.9)", 38405442, 1025367},
  {"(5.2.10)", 38405533, 1025370},
  {"(5.2.11)", 38405626, 1025373},
  {"(5.2.12)", 38405718, 1025376},
  {"(5.2.13)", 38405810, 1025379},
  {"(5.2.14)", 38405902, 1025382},
  {"(5.2.15)", 38405994, 1025385},
  {"(5.2.16)", 38406086, 1025388},
  {"i:96", 38406175, 1025391},
  {"(5.2.17)", 38406265, 1025394},
  {"i:71", 38406353, 1025397},
  {"Cell 5.12", 38406445, 1025400},
  {"Cell 5.13", 38406541, 1025403},
  {"Cell 5.14", 38406637, 1025406},
  {"Cell 5.15", 38406732, 1025409},
  {"i:140", 38406824, 1025412},
  {"i:72", 38406913, 1025415},
  {"c:22", 38407011, 1025418},
  {"(5.2.18)", 38407113, 1025421},
  {"Cell 5.16", 38407207, 1025424},
  {"Cell 5.17", 38407305, 1025427},
  {"Cell 5.18", 38407402, 1025430},
  {"Cell 5.19", 38407500, 1025433},
  {"Cell 5.20", 38407596, 1025436},
  {"i:73", 38407687, 1025439},
  {"c:23", 38407785, 1025442},
  {"(5.2.19)", 38407887, 1025445},
  {"(5.2.20)", 38407979, 1025448},
  {"(5.2.21)", 38408071, 1025451},
  {"Cell 5.21", 38408164, 1025454},
  {"(5.2.22)", 38408261, 1025457},
  {"Cell 5.22", 38408354, 1025460},
  {"i:74", 38408446, 1025463},
  {"c:24", 38408543, 1025466},
  {"(5.2.23)", 38408644, 1025469},
  {"(5.2.24)", 38408736, 1025472},
  {"(5.2.25)", 38408828, 1025475},
  {"(5.2.26)", 38408920, 1025478},
  {"(5.2.27)", 38409013, 1025481},
  {"(5.2.28)", 38409106, 1025484},
  {"(5.2.29)", 38409198, 1025487},
  {"(5.2.30)", 38409290, 1025490},
  {"Cell 5.23", 38409383, 1025493},
  {"i:75", 38409476, 1025496},
  {"c:25", 38409574, 1025499},
  {"(5.2.31)", 38409676, 1025502},
  {"(5.2.32)", 38409769, 1025505},
  {"(5.2.33)", 38409861, 1025508},
  {"(5.2.34)", 38409953, 1025511},
  {"(5.2.35)", 38410045, 1025514},
  {"(5.2.36)", 38410137, 1025517},
  {"Fig. 5.6", 38410230, 1025520},
  {"Cell 5.24", 38410327, 1025523},
  {"Cell 5.25", 38410425, 1025526},
  {"i:76", 38410517, 1025529},
  {"i:107", 38410604, 1025532},
  {"c:26", 38410702, 1025535},
  {"(5.2.37)", 38410804, 1025538},
  {"(5.2.38)", 38410896, 1025541},
  {"i:77", 38410986, 1025544},
  {"(5.2.39)", 38411078, 1025547},
  {"Cell 5.26", 38411172, 1025550},
  {"i:108", 38411266, 1025553},
  {"(5.2.40)", 38411357, 1025556},
  {"i:78", 38411445, 1025559},
  {"(5.2.41)", 38411547, 1025562},
  {"Fig. 5.7", 38411649, 1025565},
  {"i:79", 38411741, 1025568},
  {"c:27", 38411842, 1025571},
  {"i:80", 38411943, 1025574},
  {"c:28", 38412040, 1025577},
  {"i:124", 38412138, 1025580},
  {"(5.2.42)", 38412228, 1025583},
  {"i:113", 38412317, 1025586},
  {"i:129", 38412405, 1025589},
  {"(5.2.43)", 38412497, 1025592},
  {"(5.2.44)", 38412589, 1025595},
  {"(5.2.45)", 38412681, 1025598},
  {"(5.2.46)", 38412773, 1025601},
  {"(5.2.47)", 38412865, 1025604},
  {"i:81", 38412953, 1025607},
  {"(5.2.48)", 38413044, 1025610},
  {"i:114", 38413135, 1025613},
  {"(5.2.49)", 38413227, 1025616},
  {"i:82", 38413315, 1025619},
  {"(5.2.50)", 38413405, 1025622},
  {"Cell 5.27", 38413498, 1025625},
  {"Fig. 5.8", 38413594, 1025628},
  {"i:83", 38413686, 1025631},
  {"i:84", 38413774, 1025634},
  {"i:85", 38413860, 1025637},
  {"c:29", 38413958, 1025640},
  {"(5.2.51)", 38414060, 1025643},
  {"(5.2.52)", 38414152, 1025646},
  {"(5.2.53)", 38414244, 1025649},
  {"(5.2.54)", 38414336, 1025652},
  {"i:86", 38414425, 1025655},
  {"c:30", 38414522, 1025658},
  {"(5.2.55)", 38414623, 1025661},
  {"(5.2.56)", 38414715, 1025664},
  {"(5.2.57)", 38414807, 1025667},
  {"(5.2.58)", 38414899, 1025670},
  {"Cell 5.28", 38414992, 1025673},
  {"i:87", 38415084, 1025676},
  {"i:138", 38415227, 1025680},
  {"i:88", 38415315, 1025683},
  {"c:31", 38415412, 1025686},
  {"i:119", 38415510, 1025689},
  {"(5.2.59)", 38415615, 1025692},
  {"(5.2.60)", 38415720, 1025695},
  {"(5.2.61)", 38415813, 1025698},
  {"i:125", 38415903, 1025701},
  {"i:89", 38415991, 1025704},
  {"c:33", 38416077, 1025707},
  {"i:94", 38416168, 1025710},
  {"i:109", 38416254, 1025713},
  {"i:95", 38416343, 1025716},
  {"Fig. 5.9", 38416433, 1025719},
  {"i:97", 38416526, 1025722},
  {"i:110", 38416615, 1025725},
  {"i:98", 38416702, 1025728},
  {"(5.2.62)", 38416792, 1025731},
  {"i:127", 38416882, 1025734},
  {"i:126", 38416970, 1025737},
  {"i:118", 38417058, 1025740},
  {"(5.2.63)", 38417163, 1025743},
  {"i:99", 38417264, 1025746},
  {"i:111", 38417350, 1025749},
  {"i:100", 38417440, 1025752},
  {"i:101", 38417530, 1025755},
  {"i:102", 38417620, 1025758},
  {"i:103", 38417708, 1025761},
  {"Fig. 5.10", 38417800, 1025764},
  {"i:104", 38417894, 1025767},
  {"(5.2.64)", 38417987, 1025770},
  {"(5.2.65)", 38418080, 1025773},
  {"i:105", 38418169, 1025776},
  {"i:90", 38418255, 1025779},
  {"c:32", 38418353, 1025782},
  {"c:35", 38418451, 1025785},
  {"(5.3.1)", 38418545, 1025788},
  {"(5.3.2)", 38418635, 1025791},
  {"(5.3.3)", 38418726, 1025794},
  {"(5.3.4)", 38418816, 1025797},
  {"i:121", 38418906, 1025800},
  {"(5.3.5)", 38418996, 1025803},
  {"(5.3.6)", 38419088, 1025806},
  {"i:122", 38419177, 1025809},
  {"(5.3.7)", 38419279, 1025812},
  {"(5.3.8)", 38419381, 1025815},
  {"i:91", 38419469, 1025818},
  {"(5.3.9)", 38419559, 1025821},
  {"(5.3.10)", 38419650, 1025824},
  {"(5.3.11)", 38419743, 1025827},
  {"(5.3.12)", 38419836, 1025830},
  {"(5.3.13)", 38419929, 1025833},
  {"(5.3.14)", 38420023, 1025836},
  {"i:115", 38420112, 1025839},
  {"i:141", 38420201, 1025842},
  {"Cell 5.29", 38420296, 1025845},
  {"Cell 5.30", 38420392, 1025848},
  {"(5.3.15)", 38420487, 1025851},
  {"Cell 5.31", 38420581, 1025854},
  {"Cell 5.32", 38420678, 1025857},
  {"Cell 5.33", 38420775, 1025860},
  {"Cell 5.34", 38420874, 1025863},
  {"Cell 5.35", 38420970, 1025866},
  {"Cell 5.36", 38421066, 1025869},
  {"Cell 5.37", 38421162, 1025872},
  {"Cell 5.38", 38421257, 1025875},
  {"Cell 5.39", 38421353, 1025878},
  {"Cell 5.40", 38421448, 1025881},
  {"Cell 5.41", 38421545, 1025884},
  {"Cell 5.42", 38421641, 1025887},
  {"Cell 5.43", 38421738, 1025890},
  {"Cell 5.44", 38421835, 1025893},
  {"(5.3.16)", 38421930, 1025896},
  {"Fig. 5.11", 38422023, 1025899},
  {"i:136", 38422118, 1025902},
  {"Cell 5.45", 38422210, 1025905},
  {"Cell 5.46", 38422306, 1025908},
  {"Cell 5.47", 38422402, 1025911},
  {"Cell 5.48", 38422498, 1025914},
  {"Cell 5.49", 38422595, 1025917},
  {"Fig. 5.12", 38422691, 1025920},
  {"i:132", 38422785, 1025923},
  {"i:134", 38422875, 1025926},
  {"i:135", 38422963, 1025929},
  {"Fig. 5.13", 38423057, 1025932},
  {"c:36", 38423151, 1025935},
  {"(5.3.17)", 38423247, 1025938},
  {"(5.3.18)", 38423341, 1025941},
  {"(5.3.19)", 38423436, 1025944},
  {"(5.3.20)", 38423531, 1025947},
  {"(5.3.21)", 38423625, 1025950},
  {"(5.3.22)", 38423719, 1025953},
  {"i:120", 38423810, 1025956},
  {"(5.3.23)", 38423916, 1025959},
  {"i:92", 38424018, 1025962},
  {"(5.3.24)", 38424110, 1025965},
  {"i:93", 38424199, 1025968},
  {"c:37", 38424288, 1025971},
  {"(5.3.25)", 38424384, 1025974},
  {"refs", 38424474, 1025977},
  {"c:34", 38424573, 1025980}
  }
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 98, 1, 111, "Title",
  CellTags->{"i:1", "c:1"}],
Cell[1828, 55, 16, 0, 27, "Text"],
Cell[1847, 57, 684, 15, 78, "Text"],
Cell[2534, 74, 1125, 27, 112, "Text"],
Cell[3662, 103, 27802, 347, 159, 27684, 343, "GraphicsData", "Bitmap", \
"Picture",
  Evaluatable->False],
Cell[31467, 452, 86, 1, 16, "Caption",
  CellTags->"Fig. 5.1"],
Cell[31556, 455, 890, 18, 112, "Text"],
Cell[32449, 475, 676, 16, 95, "Text"],

Cell[CellGroupData[{
Cell[33150, 495, 68, 1, 39, "Subtitle",
  CellTags->"c:3"],
Cell[33221, 498, 16, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[33262, 502, 82, 1, 41, "Subsubtitle",
  CellTags->"c:4"],

Cell[CellGroupData[{
Cell[33369, 507, 62, 1, 41, "Section",
  CellTags->{"i:2", "c:5"}],
Cell[33434, 510, 234, 6, 43, "Text"],
Cell[33671, 518, 195, 6, 42, "NumberedEquation",
  CellTags->"(5.1.1)"],
Cell[33869, 526, 49, 0, 26, "Text"],
Cell[33921, 528, 230, 4, 58, "NumberedEquation",
  CellTags->"(5.1.2)"],
Cell[34154, 534, 558, 18, 50, "Text",
  CellTags->"i:5"],
Cell[34715, 554, 213, 6, 42, "NumberedEquation",
  CellTags->"(5.1.3)"],
Cell[34931, 562, 250, 10, 31, "Text"],
Cell[35184, 574, 244, 7, 40, "Text"],
Cell[35431, 583, 212, 8, 26, "Text"],
Cell[35646, 593, 472, 15, 33, "NumberedEquation",
  CellTags->"(5.1.4)"],
Cell[36121, 610, 598, 20, 82, "Text"],
Cell[36722, 632, 222, 6, 41, "NumberedEquation",
  CellTags->"(5.1.5)"],
Cell[36947, 640, 216, 6, 43, "Text"],
Cell[37166, 648, 133, 5, 28, "NumberedEquation",
  CellTags->"(5.1.6)"],
Cell[37302, 655, 180, 6, 26, "Text",
  CellTags->"i:3"],
Cell[37485, 663, 201, 6, 26, "Text"],
Cell[37689, 671, 330, 9, 31, "NumberedEquation",
  CellTags->"(5.1.7)"],
Cell[38022, 682, 1024, 32, 71, "Text"],
Cell[39049, 716, 970, 26, 40, "NumberedEquation",
  CellTags->"(5.1.8)"],
Cell[40022, 744, 1378, 36, 121, "Text"],
Cell[41403, 782, 291, 10, 26, "Text"],
Cell[41697, 794, 895, 25, 37, "NumberedEquation",
  CellTags->"(5.1.9)"],
Cell[42595, 821, 1067, 38, 63, "Text",
  CellTags->"i:7"],

Cell[CellGroupData[{
Cell[43687, 863, 445, 11, 116, "Input",
  CellTags->"Cell 5.1"],

Cell[CellGroupData[{
Cell[44157, 878, 56075, 1164, 232, 10518, 597, "GraphicsData", "PostScript", \
"Graphics"],
Cell[100235, 2044, 55845, 1163, 70, 10543, 599, "GraphicsData", "PostScript", \
"Graphics"],
Cell[156083, 3209, 55317, 1152, 70, 10457, 594, "GraphicsData", "PostScript", \
"Graphics"],
Cell[211403, 4363, 55726, 1164, 70, 10574, 602, "GraphicsData", "PostScript", \
"Graphics"],
Cell[267132, 5529, 55320, 1154, 70, 10492, 596, "GraphicsData", "PostScript", \
"Graphics"],
Cell[322455, 6685, 56205, 1166, 70, 10514, 597, "GraphicsData", "PostScript", \
"Graphics"],
Cell[378663, 7853, 55581, 1160, 70, 10546, 599, "GraphicsData", "PostScript", \
"Graphics"],
Cell[434247, 9015, 55529, 1155, 70, 10454, 594, "GraphicsData", "PostScript", \
"Graphics"],
Cell[489779, 10172, 55616, 1163, 70, 10581, 602, "GraphicsData", \
"PostScript", "Graphics"],
Cell[545398, 11337, 55554, 1157, 70, 10491, 596, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],

Cell[CellGroupData[{
Cell[601001, 12500, 458, 11, 116, "Input",
  CellTags->"Cell 5.2"],

Cell[CellGroupData[{
Cell[601484, 12515, 56106, 1164, 232, 10503, 597, "GraphicsData", \
"PostScript", "Graphics"],
Cell[657593, 13681, 55585, 1157, 70, 10476, 596, "GraphicsData", \
"PostScript", "Graphics"],
Cell[713181, 14840, 55646, 1162, 70, 10566, 602, "GraphicsData", \
"PostScript", "Graphics"],
Cell[768830, 16004, 55560, 1155, 70, 10439, 594, "GraphicsData", \
"PostScript", "Graphics"],
Cell[824393, 17161, 55611, 1159, 70, 10531, 599, "GraphicsData", \
"PostScript", "Graphics"],
Cell[880007, 18322, 56236, 1166, 70, 10499, 597, "GraphicsData", \
"PostScript", "Graphics"],
Cell[936246, 19490, 55351, 1154, 70, 10477, 596, "GraphicsData", \
"PostScript", "Graphics"],
Cell[991600, 20646, 55757, 1164, 70, 10559, 602, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1047360, 21812, 55348, 1152, 70, 10442, 594, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1102711, 22966, 55876, 1163, 70, 10528, 599, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],
Cell[1158614, 24133, 621, 19, 60, "Text"],
Cell[1159238, 24154, 780, 20, 83, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[1160055, 24179, 54, 1, 30, "Section",
  CellTags->"c:6"],
Cell[1160112, 24182, 484, 14, 70, "Text"],
Cell[1160599, 24198, 831, 21, 70, "NumberedEquation",
  CellTags->"(5.1.10)"],
Cell[1161433, 24221, 136, 6, 70, "Text"],
Cell[1161572, 24229, 164, 5, 70, "NumberedEquation",
  CellTags->{"i:6", "(5.1.11)"}],
Cell[1161739, 24236, 745, 22, 70, "Text"],
Cell[1162487, 24260, 434, 14, 70, "Text"],
Cell[1162924, 24276, 390, 11, 70, "Text"],
Cell[1163317, 24289, 846, 27, 70, "Text"],
Cell[1164166, 24318, 323, 10, 70, "NumberedEquation",
  CellTags->"(5.1.12)"],
Cell[1164492, 24330, 737, 28, 70, "Text"],
Cell[1165232, 24360, 391, 8, 70, "NumberedEquation",
  CellTags->"(5.1.13)"],
Cell[1165626, 24370, 272, 12, 70, "Text"],
Cell[1165901, 24384, 667, 23, 70, "Text"],
Cell[1166571, 24409, 190, 6, 70, "NumberedEquation",
  CellTags->"(5.1.14)"],
Cell[1166764, 24417, 350, 8, 70, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[1167163, 24431, 86, 1, 30, "Subsubtitle",
  CellTags->"c:7"],

Cell[CellGroupData[{
Cell[1167274, 24436, 128, 4, 41, "Section",
  CellTags->"c:8"],
Cell[1167405, 24442, 383, 11, 70, "Text"],
Cell[1167791, 24455, 287, 8, 70, "NumberedEquation",
  CellTags->"(5.1.15)"],
Cell[1168081, 24465, 215, 8, 70, "Text"],
Cell[1168299, 24475, 202, 5, 70, "NumberedEquation",
  CellTags->"(5.1.16)"],
Cell[1168504, 24482, 662, 19, 70, "Text"],
Cell[1169169, 24503, 284, 8, 41, "NumberedEquation",
  CellTags->"(5.1.17)"],
Cell[1169456, 24513, 273, 10, 30, "Text"],
Cell[1169732, 24525, 233, 8, 31, "NumberedEquation",
  CellTags->"(5.1.18)"],
Cell[1169968, 24535, 291, 11, 26, "Text"],
Cell[1170262, 24548, 160, 3, 41, "NumberedEquation",
  CellTags->{"i:8", "(5.1.19)"}],
Cell[1170425, 24553, 258, 9, 26, "Text"],
Cell[1170686, 24564, 461, 13, 37, "NumberedEquation",
  CellTags->"(5.1.20)"],
Cell[1171150, 24579, 1172, 33, 100, "Text",
  CellTags->"i:9"],
Cell[1172325, 24614, 156, 5, 30, "NumberedEquation",
  CellTags->"(5.1.21)"],
Cell[1172484, 24621, 1008, 30, 88, "Text",
  CellTags->"i:10"],
Cell[1173495, 24653, 178, 4, 43, "Text"],
Cell[1173676, 24659, 224, 8, 35, "NumberedEquation",
  CellTags->"(5.1.22)"],
Cell[1173903, 24669, 1488, 47, 97, "Text",
  CellTags->"i:12"],
Cell[1175394, 24718, 196, 6, 31, "Text"],
Cell[1175593, 24726, 404, 13, 62, "Text"],

Cell[CellGroupData[{
Cell[1176022, 24743, 818, 17, 240, "Input",
  CellTags->"Cell 5.3"],
Cell[1176843, 24762, 65467, 1675, 232, 19137, 1098, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[1242325, 26440, 493, 17, 43, "Text"],
Cell[1242821, 26459, 409, 10, 37, "NumberedEquation",
  CellTags->"(5.1.23)"],
Cell[1243233, 26471, 165, 5, 26, "Text"],
Cell[1243401, 26478, 389, 11, 50, "NumberedEquation",
  CellTags->"(5.1.24)"],
Cell[1243793, 26491, 130, 4, 26, "Text"],

Cell[CellGroupData[{
Cell[1243948, 26499, 303, 7, 146, "Input",
  CellTags->"Cell 5.4"],
Cell[1244254, 26508, 91, 1, 55, "Output"]
}, Open  ]],
Cell[1244360, 26512, 27, 0, 26, "Text"],
Cell[1244390, 26514, 232, 7, 46, "NumberedEquation",
  CellTags->"(5.1.25)"],
Cell[1244625, 26523, 910, 27, 77, "Text"],
Cell[1245538, 26552, 185, 6, 26, "Text"],
Cell[1245726, 26560, 490, 13, 61, "Text"],
Cell[1246219, 26575, 152, 3, 43, "Text"],

Cell[CellGroupData[{
Cell[1246396, 26582, 291, 6, 130, "Input",
  CellTags->"Cell 5.5"],
Cell[1246690, 26590, 254, 4, 113, "Output"]
}, Open  ]],
Cell[1246959, 26597, 875, 29, 50, "Text"],

Cell[CellGroupData[{
Cell[1247859, 26630, 713, 14, 178, "Input",
  CellTags->"Cell 5.6"],

Cell[CellGroupData[{
Cell[1248597, 26648, 51552, 1745, 232, 19730, 1348, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1300152, 28395, 52155, 1768, 70, 19959, 1366, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1352310, 30165, 52733, 1762, 70, 19816, 1351, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1405046, 31929, 51326, 1711, 70, 19397, 1312, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1456375, 33642, 49748, 1647, 70, 18844, 1261, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1506126, 35291, 48716, 1592, 70, 18306, 1212, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1554845, 36885, 47501, 1514, 70, 17524, 1139, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1602349, 38401, 46104, 1428, 70, 16629, 1059, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1648456, 39831, 45011, 1347, 70, 15804, 982, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1693470, 41180, 43997, 1280, 70, 15114, 919, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1737470, 42462, 43349, 1229, 70, 14575, 869, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1780822, 43693, 42841, 1196, 70, 14249, 838, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1823666, 44891, 42439, 1180, 70, 14098, 825, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1866108, 46073, 42039, 1160, 70, 13828, 807, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1908150, 47235, 41578, 1140, 70, 13602, 790, "GraphicsData", \
"PostScript", "Graphics"],
Cell[1949731, 48377, 41156, 1131, 70, 13520, 785, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],
Cell[1990914, 49512, 434, 9, 60, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[1991385, 49526, 62, 1, 30, "Section",
  CellTags->{"i:13", "c:9"}],
Cell[1991450, 49529, 1247, 43, 70, "Text"],

Cell[CellGroupData[{
Cell[1992722, 49576, 101, 3, 66, "Input",
  CellTags->"Cell 5.7"],
Cell[1992826, 49581, 53, 1, 45, "Output"]
}, Open  ]],
Cell[1992894, 49585, 291, 7, 43, "Text"],
Cell[1993188, 49594, 525, 18, 43, "Text"],
Cell[1993716, 49614, 553, 14, 50, "NumberedEquation",
  CellTags->"(5.1.26)"],
Cell[1994272, 49630, 161, 4, 43, "Text"],
Cell[1994436, 49636, 732, 17, 50, "NumberedEquation",
  CellTags->"(5.1.27)"],
Cell[1995171, 49655, 673, 19, 60, "Text",
  CellTags->"i:22"],
Cell[1995847, 49676, 535, 15, 55, "Text",
  CellTags->"i:27"],
Cell[1996385, 49693, 356, 11, 40, "NumberedEquation",
  CellTags->{"i:14", "(5.1.28)"}],
Cell[1996744, 49706, 258, 7, 43, "Text"],
Cell[1997005, 49715, 192, 6, 30, "NumberedEquation",
  CellTags->"(5.1.29)"],
Cell[1997200, 49723, 435, 12, 45, "Text"],
Cell[1997638, 49737, 521, 13, 63, "Text"],

Cell[CellGroupData[{
Cell[1998184, 49754, 546, 12, 135, "Input",
  CellTags->"Cell 5.8"],

Cell[CellGroupData[{
Cell[1998755, 49770, 108060, 4044, 335, 55630, 3392, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2106818, 53816, 107796, 4076, 70, 56322, 3436, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2214617, 57894, 110120, 4164, 70, 57447, 3509, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2324740, 62060, 112860, 4226, 70, 58045, 3545, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2437603, 66288, 114643, 4292, 70, 58824, 3599, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2552249, 70582, 114075, 4280, 70, 58774, 3593, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2666327, 74864, 116506, 4326, 70, 59058, 3612, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2782836, 79192, 116638, 4321, 70, 58952, 3605, "GraphicsData", \
"PostScript", "Graphics"],
Cell[2899477, 83515, 117507, 4363, 70, 59569, 3643, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3016987, 87880, 118706, 4383, 70, 59736, 3651, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3135696, 92265, 117199, 4318, 70, 58690, 3591, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3252898, 96585, 117251, 4310, 70, 58597, 3582, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3370152, 100897, 117029, 4288, 70, 58176, 3557, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3487184, 105187, 116666, 4273, 70, 57935, 3544, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3603853, 109462, 117193, 4242, 70, 57255, 3498, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3721049, 113706, 116813, 4255, 70, 57604, 3520, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3837865, 117963, 117173, 4224, 70, 56919, 3476, "GraphicsData", \
"PostScript", "Graphics"],
Cell[3955041, 122189, 115613, 4158, 70, 55902, 3417, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4070657, 126349, 116313, 4132, 70, 55322, 3375, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4186973, 130483, 115117, 4100, 70, 54924, 3353, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4302093, 134585, 114437, 4048, 70, 54114, 3299, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4416533, 138635, 114546, 4002, 70, 53153, 3239, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4531082, 142639, 113629, 3950, 70, 52240, 3187, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4644714, 146591, 114565, 3944, 70, 51994, 3167, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4759282, 150537, 113582, 3887, 70, 51063, 3110, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4872867, 154426, 113301, 3851, 70, 50535, 3071, "GraphicsData", \
"PostScript", "Graphics"],
Cell[4986171, 158279, 113871, 3858, 70, 50534, 3071, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5100045, 162139, 113658, 3832, 70, 50021, 3041, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5213706, 165973, 114301, 3813, 70, 49547, 3009, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5328010, 169788, 112632, 3736, 70, 48380, 2938, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5440645, 173526, 112866, 3706, 70, 47767, 2897, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5553514, 177234, 112545, 3673, 70, 47130, 2860, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5666062, 180909, 111531, 3624, 70, 46489, 2816, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5777596, 184535, 112347, 3625, 70, 46280, 2804, "GraphicsData", \
"PostScript", "Graphics"],
Cell[5889946, 188162, 111960, 3585, 70, 45634, 2761, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6001909, 191749, 111927, 3581, 70, 45516, 2756, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6113839, 195332, 111805, 3535, 70, 44576, 2700, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6225647, 198869, 111397, 3533, 70, 44646, 2704, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6337047, 202404, 111167, 3468, 70, 43468, 2627, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6448217, 205874, 111200, 3443, 70, 43031, 2596, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6559420, 209319, 110783, 3407, 70, 42351, 2557, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6670206, 212728, 110346, 3385, 70, 42040, 2537, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6780555, 216115, 110352, 3370, 70, 41766, 2518, "GraphicsData", \
"PostScript", "Graphics"],
Cell[6890910, 219487, 110534, 3350, 70, 41337, 2491, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7001447, 222839, 110235, 3314, 70, 40677, 2450, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7111685, 226155, 109718, 3291, 70, 40318, 2429, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7221406, 229448, 110017, 3277, 70, 40026, 2408, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7331426, 232727, 109702, 3270, 70, 39889, 2403, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7441131, 235999, 109876, 3248, 70, 39488, 2374, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7551010, 239249, 110204, 3225, 70, 38901, 2340, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7661217, 242476, 108846, 3179, 70, 38405, 2304, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7770066, 245657, 109122, 3169, 70, 38082, 2287, "GraphicsData", \
"PostScript", "Graphics"],
Cell[7879191, 248828, 37894, 2267, 70, 37631, 2260, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[7917088, 251097, 37263, 2226, 70, 37000, 2219, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[7954354, 253325, 37320, 2233, 70, 37057, 2226, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[7991677, 255560, 36915, 2205, 70, 36652, 2198, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[8028595, 257767, 36530, 2180, 70, 36267, 2173, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[8065128, 259949, 36439, 2172, 70, 36176, 2165, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[8101570, 262123, 36043, 2149, 70, 35780, 2142, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[8137616, 264274, 35863, 2135, 70, 35600, 2128, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[8173482, 266411, 35458, 2108, 70, 35195, 2101, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[8208943, 268521, 35341, 2101, 70, 35078, 2094, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[8244287, 270624, 35097, 2087, 70, 34834, 2080, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[8279387, 272713, 34898, 2074, 70, 34635, 2067, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[8314288, 274789, 34648, 2054, 70, 34385, 2047, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[8348939, 276845, 34338, 2034, 70, 34075, 2027, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[8383280, 278881, 34028, 2015, 70, 33765, 2008, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[8417311, 280898, 33921, 2008, 70, 33658, 2001, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[8451235, 282908, 33890, 2008, 70, 33627, 2001, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[8485128, 284918, 33516, 1984, 70, 33253, 1977, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[8518647, 286904, 33592, 1991, 70, 33329, 1984, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[8552242, 288897, 33112, 1958, 70, 32849, 1951, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[8585357, 290857, 32996, 1950, 70, 32733, 1943, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[8618356, 292809, 32153, 1897, 70, 31890, 1890, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[8650512, 294708, 32199, 1899, 70, 31936, 1892, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[8682714, 296609, 31580, 1863, 70, 31317, 1856, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False]
}, Closed]]
}, Open  ]],
Cell[8714321, 298476, 211, 4, 43, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[8714569, 298485, 59, 1, 30, "Section",
  CellTags->{"i:15", "c:10"}],
Cell[8714631, 298488, 551, 12, 80, "Text"],
Cell[8715185, 298502, 1108, 34, 93, "Text"],
Cell[8716296, 298538, 523, 14, 45, "Text"],
Cell[8716822, 298554, 351, 8, 60, "Text"],
Cell[8717176, 298564, 428, 10, 41, "NumberedEquation",
  CellTags->"(5.1.30)"],
Cell[8717607, 298576, 220, 4, 43, "Text"],
Cell[8717830, 298582, 1348, 37, 141, "Text"],
Cell[8719181, 298621, 186, 6, 37, "NumberedEquation",
  CellTags->{"i:16", "(5.1.31)"}],
Cell[8719370, 298629, 560, 13, 81, "Text"],
Cell[8719933, 298644, 481, 12, 61, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[8720463, 298662, 82, 1, 30, "Subsubtitle",
  CellTags->"c:11"],

Cell[CellGroupData[{
Cell[8720570, 298667, 103, 1, 42, "Section",
  CellTags->{"i:17", "c:12"}],
Cell[8720676, 298670, 628, 19, 43, "Text"],
Cell[8721307, 298691, 720, 21, 41, "NumberedEquation",
  CellTags->"(5.1.32)"],
Cell[8722030, 298714, 167, 4, 43, "Text"],
Cell[8722200, 298720, 519, 17, 28, "NumberedEquation",
  CellTags->"(5.1.33)"],
Cell[8722722, 298739, 755, 24, 43, "Text"],
Cell[8723480, 298765, 626, 13, 35, "NumberedEquation",
  CellTags->"(5.1.34)"],
Cell[8724109, 298780, 72, 0, 26, "Text"],
Cell[8724184, 298782, 1152, 31, 32, "NumberedEquation",
  CellTags->"(5.1.35)"],
Cell[8725339, 298815, 733, 29, 27, "Text",
  CellTags->"i:18"],
Cell[8726075, 298846, 695, 20, 41, "NumberedEquation",
  CellTags->"(5.1.36)"],
Cell[8726773, 298868, 256, 6, 52, "Text"],
Cell[8727032, 298876, 586, 18, 31, "NumberedEquation",
  CellTags->"(5.1.37)"],
Cell[8727621, 298896, 986, 31, 60, "Text"],
Cell[8728610, 298929, 1398, 37, 45, "NumberedEquation",
  CellTags->"(5.1.38)"],
Cell[8730011, 298968, 809, 23, 46, "Text",
  CellTags->"i:19"],
Cell[8730823, 298993, 465, 15, 28, "NumberedEquation",
  CellTags->"(5.1.39)"],
Cell[8731291, 299010, 706, 26, 43, "Text"],
Cell[8732000, 299038, 182, 6, 28, "NumberedEquation",
  CellTags->"(5.1.40)"],
Cell[8732185, 299046, 962, 32, 60, "Text"],
Cell[8733150, 299080, 776, 25, 38, "NumberedEquation",
  CellTags->{"i:21", "(5.1.41)"}],
Cell[8733929, 299107, 870, 30, 48, "Text"],
Cell[8734802, 299139, 710, 19, 46, "NumberedEquation",
  CellTags->"(5.1.42)"],
Cell[8735515, 299160, 1272, 38, 45, "Text",
  CellTags->"i:139"],
Cell[8736790, 299200, 80026, 991, 307, 79904, 987, "GraphicsData", "Bitmap", \
"Picture",
  Evaluatable->False],
Cell[8816819, 300193, 229, 9, 15, "Caption",
  CellTags->"Fig. 5.2"]
}, Closed]],

Cell[CellGroupData[{
Cell[8817085, 300207, 76, 1, 31, "Section",
  CellTags->"c:13"],
Cell[8817164, 300210, 526, 16, 43, "Text"],
Cell[8817693, 300228, 921, 29, 35, "Text"],
Cell[8818617, 300259, 89, 3, 26, "Text"],
Cell[8818709, 300264, 1070, 33, 70, "Text"],
Cell[8819782, 300299, 637, 23, 37, "NumberedEquation",
  CellTags->{"i:20", "(5.1.43)"}],
Cell[8820422, 300324, 296, 8, 43, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[8820755, 300337, 77, 1, 31, "Section",
  CellTags->"c:14"],

Cell[CellGroupData[{
Cell[8820857, 300342, 50, 0, 26, "Subsubsection"],
Cell[8820910, 300344, 107, 3, 70, "Text"],
Cell[8821020, 300349, 921, 28, 70, "NumberedEquation",
  CellTags->"(5.1.44)"],
Cell[8821944, 300379, 584, 17, 70, "Text"],
Cell[8822531, 300398, 180, 6, 70, "Text"],
Cell[8822714, 300406, 1406, 42, 70, "NumberedEquation",
  CellTags->"(5.1.45)"],
Cell[8824123, 300450, 825, 29, 70, "Text",
  CellTags->"i:59"],
Cell[8824951, 300481, 1187, 36, 70, "NumberedEquation",
  CellTags->"(5.1.46)"],
Cell[8826141, 300519, 27, 0, 70, "Text"],
Cell[8826171, 300521, 3855, 96, 70, "NumberedEquation",
  CellTags->"(5.1.47)"],
Cell[8830029, 300619, 2759, 89, 70, "Text"],
Cell[8832791, 300710, 3427, 99, 70, "NumberedEquation",
  CellTags->"(5.1.48)"],
Cell[8836221, 300811, 563, 20, 70, "Text"],
Cell[8836787, 300833, 1720, 52, 70, "Text"],
Cell[8838510, 300887, 934, 23, 70, "Text"],
Cell[8839447, 300912, 801, 22, 70, "Text"],
Cell[8840251, 300936, 1218, 42, 70, "Text"],
Cell[8841472, 300980, 3953, 99, 70, "NumberedEquation",
  CellTags->"(5.1.49)"],
Cell[8845428, 301081, 5534, 173, 70, "Text"],
Cell[8850965, 301256, 4406, 105, 70, "Text"],
Cell[8855374, 301363, 99, 3, 70, "Text"],
Cell[8855476, 301368, 2195, 57, 70, "NumberedEquation",
  CellTags->"(5.1.50)"],
Cell[8857674, 301427, 1909, 63, 70, "Text"],
Cell[8859586, 301492, 2082, 65, 70, "Text"],
Cell[8861671, 301559, 1172, 28, 70, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[8862880, 301592, 37, 0, 28, "Subsubsection"],
Cell[8862920, 301594, 3790, 118, 95, "Text"],
Cell[8866713, 301714, 3857, 92, 42, "Text"],
Cell[8870573, 301808, 4245, 134, 81, "Text"],
Cell[8874821, 301944, 2729, 76, 32, "NumberedEquation",
  CellTags->{"i:23", "(5.1.51)"}],
Cell[8877553, 302022, 475, 11, 60, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[8878065, 302038, 71, 1, 28, "Subsubsection",
  CellTags->"i:24"],
Cell[8878139, 302041, 493, 14, 70, "Text"],
Cell[8878635, 302057, 2145, 58, 70, "NumberedEquation",
  CellTags->"(5.1.52)"],
Cell[8880783, 302117, 1435, 50, 70, "Text"],
Cell[8882221, 302169, 1213, 35, 70, "Text"],
Cell[8883437, 302206, 416, 13, 70, "Text"],
Cell[8883856, 302221, 1830, 50, 70, "NumberedEquation",
  CellTags->"(5.1.53)"],
Cell[8885689, 302273, 180, 5, 70, "Text"],
Cell[8885872, 302280, 426, 15, 70, "Text"],
Cell[8886301, 302297, 429, 10, 70, "NumberedEquation",
  CellTags->"(5.1.54)"],
Cell[8886733, 302309, 1306, 40, 127, "Text",
  CellTags->"i:133"],
Cell[8888042, 302351, 733, 25, 45, "Text"],
Cell[8888778, 302378, 4703, 106, 76, "Text"],
Cell[8893484, 302486, 60, 0, 26, "Text"],
Cell[8893547, 302488, 807, 26, 35, "Text"],
Cell[8894357, 302516, 498, 16, 60, "Text"],
Cell[8894858, 302534, 1122, 29, 68, "NumberedEquation",
  CellTags->"(5.1.55)"],
Cell[8895983, 302565, 587, 17, 75, "Text"],
Cell[8896573, 302584, 330, 7, 45, "Text"],
Cell[8896906, 302593, 676, 19, 73, "Text"],
Cell[8897585, 302614, 163, 5, 32, "NumberedEquation",
  CellTags->"(5.1.56)"],
Cell[8897751, 302621, 400, 16, 47, "Text",
  CellTags->"i:25"],
Cell[8898154, 302639, 486, 9, 77, "Text",
  CellTags->"i:26"],
Cell[8898643, 302650, 429, 12, 60, "Text"],
Cell[8899075, 302664, 1280, 38, 82, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[8900392, 302707, 77, 1, 28, "Subsubsection",
  CellTags->"i:34"],
Cell[8900472, 302710, 995, 21, 110, "Text"],
Cell[8901470, 302733, 384, 11, 37, "NumberedEquation",
  CellTags->"(5.1.57)"],
Cell[8901857, 302746, 75, 1, 26, "Text",
  CellTags->"i:28"],
Cell[8901935, 302749, 233, 6, 42, "NumberedEquation",
  CellTags->"(5.1.58)"],
Cell[8902171, 302757, 179, 7, 26, "Text"],
Cell[8902353, 302766, 325, 11, 37, "NumberedEquation",
  CellTags->{"i:29", "(5.1.59)"}],
Cell[8902681, 302779, 648, 17, 60, "Text"],
Cell[8903332, 302798, 713, 21, 35, "Text"],
Cell[8904048, 302821, 1052, 31, 77, "Text"],
Cell[8905103, 302854, 429, 15, 43, "Text"],
Cell[8905535, 302871, 3142, 91, 30, "NumberedEquation",
  CellTags->"(5.1.60)"],
Cell[8908680, 302964, 3481, 98, 83, "Text"],
Cell[8912164, 303064, 2513, 70, 57, "NumberedEquation",
  CellTags->"(5.1.61)"],
Cell[8914680, 303136, 504, 10, 81, "Text"],
Cell[8915187, 303148, 2394, 66, 62, "NumberedEquation",
  CellTags->{"i:30", "(5.1.62)"}],
Cell[8917584, 303216, 575, 17, 48, "Text"],
Cell[8918162, 303235, 1578, 46, 87, "Text"],
Cell[8919743, 303283, 488, 12, 61, "Text"],
Cell[8920234, 303297, 54, 0, 26, "Text"],
Cell[8920291, 303299, 334, 8, 50, "NumberedEquation",
  CellTags->"(5.1.63)"],
Cell[8920628, 303309, 1459, 49, 113, "Text",
  CellTags->"i:35"],
Cell[8922090, 303360, 1177, 38, 75, "Text"],
Cell[8923270, 303400, 769, 24, 40, "NumberedEquation",
  CellTags->{"i:36", "(5.1.64)"}],
Cell[8924042, 303426, 773, 24, 63, "Text",
  CellTags->"i:112"],
Cell[8924818, 303452, 1609, 30, 160, "Text"],
Cell[8926430, 303484, 466, 13, 55, "Text"],
Cell[8926899, 303499, 519, 13, 40, "NumberedEquation",
  CellTags->"(5.1.65)"],
Cell[8927421, 303514, 123, 5, 26, "Text"],
Cell[8927547, 303521, 217, 6, 41, "NumberedEquation",
  CellTags->"(5.1.66)"],
Cell[8927767, 303529, 320, 9, 60, "Text"],
Cell[8928090, 303540, 545, 12, 50, "NumberedEquation",
  CellTags->"(5.1.67)"],
Cell[8928638, 303554, 510, 19, 43, "Text"],
Cell[8929151, 303575, 861, 19, 51, "NumberedEquation",
  CellTags->"(5.1.68)"],
Cell[8930015, 303596, 20, 0, 26, "Text"],
Cell[8930038, 303598, 416, 9, 51, "NumberedEquation",
  CellTags->"(5.1.69)"],
Cell[8930457, 303609, 1420, 42, 120, "Text"],
Cell[8931880, 303653, 848, 22, 38, "Text"],
Cell[8932731, 303677, 274, 7, 37, "Text"],
Cell[8933008, 303686, 852, 25, 63, "Text"],
Cell[8933863, 303713, 774, 20, 40, "NumberedEquation",
  CellTags->"(5.1.70)"],
Cell[8934640, 303735, 19, 0, 26, "Text"],
Cell[8934662, 303737, 683, 20, 42, "NumberedEquation",
  CellTags->"(5.1.71)"],
Cell[8935348, 303759, 662, 21, 26, "Text"],
Cell[8936013, 303782, 685, 20, 40, "NumberedEquation",
  CellTags->{"i:32", "(5.1.72)"}],
Cell[8936701, 303804, 264, 9, 27, "Text"],
Cell[8936968, 303815, 1415, 42, 40, "Text"],
Cell[8938386, 303859, 101, 3, 26, "Text"],
Cell[8938490, 303864, 614, 21, 32, "NumberedEquation",
  CellTags->"(5.1.73)"],
Cell[8939107, 303887, 140, 4, 26, "Text",
  CellTags->"i:116"],
Cell[8939250, 303893, 790, 22, 77, "Text"],
Cell[8940043, 303917, 517, 16, 37, "NumberedEquation",
  CellTags->"(5.1.74)"],
Cell[8940563, 303935, 1597, 57, 78, "Text",
  CellTags->"i:117"],
Cell[8942163, 303994, 927, 30, 27, "NumberedEquation",
  CellTags->{"i:33", "(5.1.75)"}],
Cell[8943093, 304026, 19, 0, 26, "Text"],
Cell[8943115, 304028, 152, 5, 30, "NumberedEquation",
  CellTags->"(5.1.76)"],
Cell[8943270, 304035, 257, 10, 26, "Text"],
Cell[8943530, 304047, 1272, 33, 111, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[8944839, 304085, 58, 0, 28, "Subsubsection"],
Cell[8944900, 304087, 2050, 67, 68, "Text"],
Cell[8946953, 304156, 3496, 84, 45, "NumberedEquation",
  CellTags->"(5.1.77)"],
Cell[8950452, 304242, 1955, 65, 80, "Text",
  CellTags->"i:40"],
Cell[8952410, 304309, 1708, 42, 47, "Text"],
Cell[8954121, 304353, 591, 19, 43, "Text"],
Cell[8954715, 304374, 1620, 46, 45, "Text"],
Cell[8956338, 304422, 146, 5, 26, "Text"],
Cell[8956487, 304429, 334, 9, 65, "NumberedEquation",
  CellTags->"(5.1.78)"],
Cell[8956824, 304440, 239, 9, 26, "Text"],

Cell[CellGroupData[{
Cell[8957088, 304453, 620, 14, 180, "Input",
  CellTags->"Cell 5.9"],

Cell[CellGroupData[{
Cell[8957733, 304471, 37794, 1311, 232, 16739, 1046, "GraphicsData", \
"PostScript", "Graphics"],
Cell[8995530, 305784, 35724, 1257, 70, 16196, 1011, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9031257, 307043, 35970, 1243, 70, 15855, 990, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9067230, 308288, 35569, 1218, 70, 15494, 965, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9102802, 309508, 34457, 1193, 70, 15261, 951, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9137262, 310703, 34065, 1175, 70, 14978, 934, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9171330, 311880, 33556, 1156, 70, 14757, 919, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9204889, 313038, 32843, 1120, 70, 14198, 885, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9237735, 314160, 32641, 1106, 70, 13955, 870, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9270379, 315268, 32206, 1078, 70, 13545, 843, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9302588, 316348, 31505, 1056, 70, 13269, 826, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9334096, 317406, 31681, 1055, 70, 13226, 822, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9365780, 318463, 31552, 1048, 70, 13117, 815, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9397335, 319513, 31265, 1029, 70, 12806, 796, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9428603, 320544, 31164, 1027, 70, 12782, 795, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9459770, 321573, 31169, 1028, 70, 12779, 796, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9490942, 322603, 31278, 1031, 70, 12831, 798, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9522223, 323636, 31275, 1035, 70, 12909, 803, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9553501, 324673, 31458, 1043, 70, 13040, 811, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9584962, 325718, 31361, 1039, 70, 12971, 807, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9616326, 326759, 31425, 1055, 70, 13262, 826, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9647754, 327816, 32024, 1082, 70, 13654, 850, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9679781, 328900, 32308, 1100, 70, 13938, 868, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9712092, 330002, 32593, 1119, 70, 14239, 887, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9744688, 331123, 32755, 1131, 70, 14442, 900, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9777446, 332256, 33021, 1147, 70, 14675, 915, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9810470, 333405, 33400, 1168, 70, 15018, 936, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9843873, 334575, 33831, 1197, 70, 15473, 965, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9877707, 335774, 34363, 1227, 70, 15928, 994, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9912073, 337003, 34518, 1238, 70, 16095, 1005, "GraphicsData", \
"PostScript", "Graphics"],
Cell[9946594, 338243, 34622, 1258, 70, 16467, 1029, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],
Cell[9981243, 339505, 1385, 36, 151, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[9982677, 339547, 59, 1, 31, "Section",
  CellTags->"c:15"],
Cell[9982739, 339550, 554, 19, 27, "Text"],
Cell[9983296, 339571, 1331, 39, 42, "NumberedEquation",
  CellTags->"(5.1.79)"],
Cell[9984630, 339612, 1143, 34, 44, "Text"],
Cell[9985776, 339648, 2535, 65, 33, "NumberedEquation",
  CellTags->"(5.1.80)"],
Cell[9988314, 339715, 709, 21, 47, "Text"],
Cell[9989026, 339738, 200, 6, 27, "Text"],
Cell[9989229, 339746, 1659, 50, 30, "Text"],
Cell[9990891, 339798, 1197, 36, 48, "Text"],
Cell[9992091, 339836, 1998, 54, 46, "NumberedEquation",
  CellTags->"(5.1.81)"],
Cell[9994092, 339892, 1803, 59, 89, "Text"],

Cell[CellGroupData[{
Cell[9995920, 339955, 251, 6, 86, "Input",
  CellTags->"Cell 5.10"],
Cell[9996174, 339963, 72, 1, 65, "Output"]
}, Open  ]],
Cell[9996261, 339967, 313, 9, 47, "Text"],
Cell[9996577, 339978, 31, 0, 27, "Text"],
Cell[9996611, 339980, 1253, 35, 45, "NumberedEquation",
  CellTags->"(5.1.82)"],
Cell[9997867, 340017, 2150, 64, 94, "Text"],
Cell[10000020, 340083, 1221, 35, 43, "Text"],
Cell[10001244, 340120, 505, 15, 44, "Text"],
Cell[10001752, 340137, 1151, 34, 64, "Text"],
Cell[10002906, 340173, 1702, 46, 38, "NumberedEquation",
  CellTags->"(5.1.83)"],
Cell[10004611, 340221, 1436, 45, 112, "Text"],
Cell[10006050, 340268, 632, 21, 38, "NumberedEquation",
  CellTags->"(5.1.84)"],
Cell[10006685, 340291, 668, 19, 78, "Text",
  CellTags->"i:37"],
Cell[10007356, 340312, 2239, 61, 130, "Text"],
Cell[10009598, 340375, 792, 23, 61, "Text"],
Cell[10010393, 340400, 2067, 60, 45, "NumberedEquation",
  CellTags->"(5.1.85)"],
Cell[10012463, 340462, 716, 25, 44, "Text",
  CellTags->"i:130"]
}, Closed]],

Cell[CellGroupData[{
Cell[10013216, 340492, 90, 1, 31, "Section",
  CellTags->{"i:38", "c:16"}],
Cell[10013309, 340495, 1077, 31, 77, "Text"],
Cell[10014389, 340528, 1221, 39, 28, "NumberedEquation",
  CellTags->"(5.1.86)"],
Cell[10015613, 340569, 1304, 44, 60, "Text"],
Cell[10016920, 340615, 6976, 155, 85, "NumberedEquation",
  CellTags->"(5.1.87)"],
Cell[10023899, 340772, 885, 28, 43, "Text"],
Cell[10024787, 340802, 750, 24, 28, "NumberedEquation",
  CellTags->"(5.1.88)"],
Cell[10025540, 340828, 1064, 34, 77, "Text",
  CellTags->"i:39"],
Cell[10026607, 340864, 39, 0, 26, "Text"],
Cell[10026649, 340866, 1643, 45, 35, "NumberedEquation",
  CellTags->"(5.1.89)"],
Cell[10028295, 340913, 475, 17, 31, "Text"],
Cell[10028773, 340932, 678, 21, 38, "NumberedEquation",
  CellTags->"(5.1.90)"],
Cell[10029454, 340955, 354, 9, 43, "Text"],
Cell[10029811, 340966, 352, 6, 60, "Text"],
Cell[10030166, 340974, 790, 16, 111, "Text"],

Cell[CellGroupData[{
Cell[10030981, 340994, 52021, 1577, 370, 15154, 1117, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10083005, 342573, 52302, 1574, 70, 14982, 1109, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10135310, 344149, 51774, 1553, 70, 14749, 1091, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10187087, 345704, 52255, 1568, 70, 14943, 1103, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10239345, 347274, 51967, 1585, 70, 15262, 1127, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10291315, 348861, 52645, 1587, 70, 15154, 1119, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10343963, 350450, 52260, 1582, 70, 15134, 1119, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10396226, 352034, 51881, 1544, 70, 14609, 1079, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10448110, 353580, 52210, 1579, 70, 15092, 1116, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10500323, 355161, 52373, 1571, 70, 14923, 1104, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10552699, 356734, 52820, 1623, 70, 15864, 1162, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10605522, 358359, 52803, 1607, 70, 15596, 1143, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10658328, 359968, 53009, 1618, 70, 15757, 1153, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10711340, 361588, 54122, 1663, 70, 16348, 1192, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10765465, 363253, 53955, 1667, 70, 16452, 1199, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10819423, 364922, 53851, 1652, 70, 16239, 1183, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10873277, 366576, 54840, 1717, 70, 17285, 1249, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10928120, 368295, 54941, 1720, 70, 17252, 1250, "GraphicsData", \
"PostScript", "Graphics"],
Cell[10983064, 370017, 55049, 1730, 70, 17457, 1261, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11038116, 371749, 54823, 1703, 70, 17102, 1233, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11092942, 373454, 56737, 1816, 70, 18704, 1342, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11149682, 375272, 56260, 1787, 70, 18320, 1314, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11205945, 377061, 55593, 1743, 70, 17783, 1272, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11261541, 378806, 55638, 1757, 70, 17896, 1286, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11317182, 380565, 57789, 1852, 70, 19209, 1371, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11374974, 382419, 57704, 1861, 70, 19428, 1384, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11432681, 384282, 56113, 1794, 70, 18643, 1327, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11488797, 386078, 55550, 1775, 70, 18298, 1310, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11544350, 387855, 56845, 1844, 70, 19330, 1376, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11601198, 389701, 57687, 1883, 70, 19913, 1412, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11658888, 391586, 55980, 1816, 70, 19028, 1355, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11714871, 393404, 55053, 1772, 70, 18458, 1316, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11769927, 395178, 55258, 1793, 70, 18776, 1338, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11825188, 396973, 56719, 1871, 70, 19925, 1412, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11881910, 398846, 56234, 1851, 70, 19647, 1395, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11938147, 400699, 53606, 1734, 70, 18047, 1290, "GraphicsData", \
"PostScript", "Graphics"],
Cell[11991756, 402435, 54159, 1749, 70, 18224, 1301, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12045918, 404186, 55184, 1818, 70, 19212, 1369, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12101105, 406006, 54536, 1767, 70, 18362, 1316, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12155644, 407775, 51625, 1637, 70, 16743, 1202, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12207272, 409414, 51955, 1657, 70, 16992, 1221, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[12259242, 411074, 156, 4, 16, "Caption",
  CellTags->"Fig. 5.3"]
}, Closed]],

Cell[CellGroupData[{
Cell[12259435, 411083, 52, 1, 31, "Section",
  CellTags->"c:17"],

Cell[CellGroupData[{
Cell[12259512, 411088, 41, 0, 27, "Subsubsection"],
Cell[12259556, 411090, 521, 16, 26, "Text"],
Cell[12260080, 411108, 1761, 53, 37, "NumberedEquation",
  CellTags->"(5.1.91)"],
Cell[12261844, 411163, 887, 29, 26, "Text"],
Cell[12262734, 411194, 900, 31, 46, "Text",
  CellTags->"i:60"],
Cell[12263637, 411227, 1804, 55, 35, "Text"],
Cell[12265444, 411284, 1035, 36, 46, "Text"],
Cell[12266482, 411322, 2007, 58, 48, "NumberedEquation",
  CellTags->"(5.1.92)"],
Cell[12268492, 411382, 1895, 62, 46, "Text"],
Cell[12270390, 411446, 2871, 75, 48, "NumberedEquation",
  CellTags->"(5.1.93)"],
Cell[12273264, 411523, 1238, 32, 70, "Text"],
Cell[12274505, 411557, 176, 6, 31, "NumberedEquation",
  CellTags->"(5.1.94)"],
Cell[12274684, 411565, 180, 5, 43, "Text",
  CellTags->"i:44"],
Cell[12274867, 411572, 458, 9, 77, "Text"],
Cell[12275328, 411583, 575, 18, 35, "NumberedEquation",
  CellTags->{"i:43", "(5.1.95)"}],
Cell[12275906, 411603, 61, 1, 26, "Text",
  CellTags->"i:42"],
Cell[12275970, 411606, 506, 17, 37, "NumberedEquation",
  CellTags->"(5.1.96)"],
Cell[12276479, 411625, 663, 14, 95, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[12277179, 411644, 83, 1, 29, "Subsubsection",
  CellTags->"i:41"],
Cell[12277265, 411647, 347, 12, 43, "Text"],
Cell[12277615, 411661, 1312, 41, 28, "NumberedEquation",
  CellTags->"(5.1.97)"],
Cell[12278930, 411704, 2098, 67, 65, "Text"],
Cell[12281031, 411773, 2562, 62, 68, "Text"],
Cell[12283596, 411837, 2125, 67, 63, "Text"],
Cell[12285724, 411906, 1663, 45, 66, "Text"],
Cell[12287390, 411953, 135, 5, 26, "Text"],

Cell[CellGroupData[{
Cell[12287550, 411962, 349, 8, 120, "Input",
  CellTags->"Cell 5.11"],
Cell[12287902, 411972, 195, 3, 85, "Output"]
}, Open  ]],
Cell[12288112, 411978, 72, 0, 26, "Text"],
Cell[12288187, 411980, 1188, 30, 55, "NumberedEquation",
  CellTags->"(5.1.98)"],
Cell[12289378, 412012, 420, 11, 60, "Text"],
Cell[12289801, 412025, 470, 16, 26, "Text"],
Cell[12290274, 412043, 1870, 56, 32, "NumberedEquation",
  CellTags->"(5.1.99)"],
Cell[12292147, 412101, 740, 20, 77, "Text"],
Cell[12292890, 412123, 392, 13, 43, "Text"],
Cell[12293285, 412138, 241, 9, 32, "NumberedEquation",
  CellTags->"(5.1.100)"],
Cell[12293529, 412149, 369, 9, 60, "Text"]
}, Closed]]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[12293959, 412165, 65, 1, 30, "Subsubtitle",
  CellTags->"c:18"],
Cell[12294027, 412168, 359, 11, 44, "Text"],
Cell[12294389, 412181, 422, 14, 37, "Text"],
Cell[12294814, 412197, 421, 13, 37, "Text"],
Cell[12295238, 412212, 638, 23, 46, "Text"],
Cell[12295879, 412237, 1395, 45, 67, "Text"],
Cell[12297277, 412284, 342, 7, 61, "Text"],
Cell[12297622, 412293, 1291, 39, 86, "Text",
  CellTags->"i:45"],
Cell[12298916, 412334, 719, 24, 56, "Text",
  CellTags->"i:46"],
Cell[12299638, 412360, 743, 24, 61, "Text"],
Cell[12300384, 412386, 597, 15, 78, "Text"],
Cell[12300984, 412403, 1717, 51, 116, "Text"],
Cell[12302704, 412456, 220, 7, 27, "Text"],
Cell[12302927, 412465, 482, 16, 30, "Text"],
Cell[12303412, 412483, 402, 16, 27, "Text"],
Cell[12303817, 412501, 105, 4, 27, "Text"],
Cell[12303925, 412507, 233, 6, 40, "Text"],
Cell[12304161, 412515, 505, 16, 31, "Text"],
Cell[12304669, 412533, 130, 4, 27, "Text"],
Cell[12304802, 412539, 177, 5, 27, "Text"],
Cell[12304982, 412546, 226, 8, 39, "Text"],
Cell[12305211, 412556, 210, 8, 27, "Text"],
Cell[12305424, 412566, 1320, 37, 98, "Text",
  CellTags->"i:47"],
Cell[12306747, 412605, 604, 15, 67, "Text"],
Cell[12307354, 412622, 271, 12, 27, "Text"],
Cell[12307628, 412636, 1174, 32, 94, "Text",
  CellTags->"i:48"],
Cell[12308805, 412670, 1835, 51, 48, "Text"],
Cell[12310643, 412723, 638, 20, 44, "Text"],
Cell[12311284, 412745, 636, 17, 45, "NumberedEquation",
  CellTags->{"i:49", "(5.1.101)"}],
Cell[12311923, 412764, 1140, 39, 62, "Text"],
Cell[12313066, 412805, 1336, 38, 31, "NumberedEquation",
  CellTags->{"i:50", "(5.1.102)"}],
Cell[12314405, 412845, 1354, 48, 48, "Text"],
Cell[12315762, 412895, 1325, 34, 119, "Text",
  CellTags->"i:51"],
Cell[12317090, 412931, 355, 12, 27, "Text"],
Cell[12317448, 412945, 1874, 59, 174, "Text",
  CellTags->"i:131"],
Cell[12319325, 413006, 768, 23, 71, "Text"],
Cell[12320096, 413031, 1796, 56, 78, "Text",
  CellTags->"i:62"],
Cell[12321895, 413089, 879, 25, 73, "Text"],
Cell[12322777, 413116, 2028, 71, 91, "Text"],
Cell[12324808, 413189, 484, 16, 73, "Text",
  CellTags->"i:52"],
Cell[12325295, 413207, 326, 8, 32, "Text"],
Cell[12325624, 413217, 203, 8, 27, "Text"],
Cell[12325830, 413227, 7286, 209, 168, "Text"],
Cell[12333119, 413438, 711, 19, 65, "Text"],

Cell[CellGroupData[{
Cell[12333855, 413461, 205283, 4344, 302, 123421, 3327, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12539141, 417807, 197070, 4198, 70, 122420, 3271, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12736214, 422007, 194947, 4161, 70, 122261, 3258, "GraphicsData", \
"PostScript", "Graphics"],
Cell[12931164, 426170, 205104, 4337, 70, 123674, 3326, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13136271, 430509, 199471, 4246, 70, 123055, 3297, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13335745, 434757, 192996, 4113, 70, 121618, 3226, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13528744, 438872, 206410, 4366, 70, 123570, 3337, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13735157, 443240, 204366, 4318, 70, 123296, 3311, "GraphicsData", \
"PostScript", "Graphics"],
Cell[13939526, 447560, 192688, 4103, 70, 121569, 3219, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14132217, 451665, 206836, 4376, 70, 123749, 3344, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14339056, 456043, 205644, 4349, 70, 123533, 3329, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14544703, 460394, 198332, 4214, 70, 122365, 3270, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14743038, 464610, 208494, 4390, 70, 123953, 3340, "GraphicsData", \
"PostScript", "Graphics"],
Cell[14951535, 469002, 210014, 4415, 70, 123760, 3344, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15161552, 473419, 202376, 4292, 70, 123117, 3308, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15363931, 477713, 210363, 4424, 70, 124028, 3352, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15574297, 482139, 210783, 4428, 70, 123914, 3350, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15785083, 486569, 209842, 4415, 70, 123791, 3347, "GraphicsData", \
"PostScript", "Graphics"],
Cell[15994928, 490986, 211485, 4432, 70, 123818, 3344, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16206416, 495420, 213307, 4467, 70, 123874, 3357, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16419726, 499889, 211000, 4425, 70, 123863, 3343, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16630729, 504316, 212979, 4458, 70, 123943, 3353, "GraphicsData", \
"PostScript", "Graphics"],
Cell[16843711, 508776, 213266, 4465, 70, 124206, 3360, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17056980, 513243, 214594, 4487, 70, 124108, 3364, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17271577, 517732, 214172, 4480, 70, 123880, 3359, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17485752, 522214, 214470, 4486, 70, 124239, 3366, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17700225, 526702, 213190, 4460, 70, 124053, 3354, "GraphicsData", \
"PostScript", "Graphics"],
Cell[17913418, 531164, 215366, 4493, 70, 124119, 3361, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18128787, 535659, 212265, 4450, 70, 124148, 3356, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18341055, 540111, 212324, 4446, 70, 123891, 3348, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18553382, 544559, 211785, 4448, 70, 124049, 3359, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]],
Cell[18765182, 549010, 95, 1, 17, "Caption",
  CellTags->"Fig. 5.4"],
Cell[18765280, 549013, 246, 8, 27, "Text",
  CellTags->"i:61"],
Cell[18765529, 549023, 943, 24, 73, "Text"],
Cell[18766475, 549049, 360, 8, 59, "NumberedEquation",
  CellTags->"(5.1.103)"],
Cell[18766838, 549059, 1476, 47, 47, "Text"],
Cell[18768317, 549108, 696, 23, 35, "Text"],
Cell[18769016, 549133, 1573, 41, 145, "Text"],
Cell[18770592, 549176, 1345, 42, 102, "Text"],
Cell[18771940, 549220, 325, 9, 32, "Text"],
Cell[18772268, 549231, 485, 18, 44, "Text"],
Cell[18772756, 549251, 2293, 76, 78, "Text"],
Cell[18775052, 549329, 1881, 49, 102, "Text",
  CellTags->"i:63"],
Cell[18776936, 549380, 826, 21, 46, "Text"],
Cell[18777765, 549403, 599, 18, 73, "Text"],
Cell[18778367, 549423, 3705, 110, 248, "Text"],
Cell[18782075, 549535, 31673, 711, 233, 7858, 412, "GraphicsData", \
"PostScript", "Picture"],
Cell[18813751, 550248, 66, 1, 16, "Caption",
  CellTags->"Fig. 5.5"],
Cell[18813820, 550251, 545, 15, 58, "Text"],
Cell[18814368, 550268, 643, 20, 61, "Text",
  CellTags->"i:64"],
Cell[18815014, 550290, 550, 22, 44, "Text"],
Cell[18815567, 550314, 463, 14, 47, "Text"],
Cell[18816033, 550330, 323, 11, 27, "Text"],
Cell[18816359, 550343, 790, 26, 81, "Text"],
Cell[18817152, 550371, 330, 13, 27, "Text"],
Cell[18817485, 550386, 339, 13, 27, "Text"],
Cell[18817827, 550401, 608, 22, 27, "Text"],
Cell[18818438, 550425, 794, 27, 39, "Text"],
Cell[18819235, 550454, 76, 0, 27, "Text"],
Cell[18819314, 550456, 179, 7, 27, "Text"],
Cell[18819496, 550465, 690, 23, 51, "Text"],
Cell[18820189, 550490, 185, 8, 27, "Text"],
Cell[18820377, 550500, 624, 21, 46, "Text"],
Cell[18821004, 550523, 327, 11, 27, "Text"],
Cell[18821334, 550536, 636, 19, 44, "Text",
  CellTags->"i:53"],
Cell[18821973, 550557, 1174, 37, 103, "Text",
  CellTags->"i:65"],
Cell[18823150, 550596, 302, 8, 49, "Text"],
Cell[18823455, 550606, 161, 5, 27, "Text"],
Cell[18823619, 550613, 271, 8, 70, "Text"],
Cell[18823893, 550623, 669, 19, 64, "Text"],
Cell[18824565, 550644, 3754, 111, 118, "Text"],
Cell[18828322, 550757, 397, 11, 61, "Text",
  CellTags->"i:54"],
Cell[18828722, 550770, 193, 6, 28, "Text"],
Cell[18828918, 550778, 906, 31, 54, "Text",
  CellTags->"i:55"],
Cell[18829827, 550811, 564, 22, 46, "Text"],
Cell[18830394, 550835, 2574, 66, 77, "Text"],
Cell[18832971, 550903, 951, 27, 61, "Text"],
Cell[18833925, 550932, 871, 26, 69, "Text"],
Cell[18834799, 550960, 264, 7, 44, "Text",
  CellTags->"i:56"],
Cell[18835066, 550969, 197, 6, 33, "NumberedEquation",
  CellTags->"(5.1.104)"],
Cell[18835266, 550977, 638, 20, 44, "Text",
  CellTags->"i:57"],
Cell[18835907, 550999, 2506, 69, 118, "Text"],
Cell[18838416, 551070, 1164, 27, 112, "Text",
  CellTags->"i:58"],
Cell[18839583, 551099, 855, 23, 90, "Text"],
Cell[18840441, 551124, 206, 5, 44, "Text"],
Cell[18840650, 551131, 279, 8, 43, "Text"],
Cell[18840932, 551141, 360, 10, 47, "Text"],
Cell[18841295, 551153, 2692, 83, 193, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[18844036, 551242, 68, 1, 40, "Subtitle",
  CellTags->{"i:66", "c:19"}],
Cell[18844107, 551245, 16, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[18844148, 551249, 80, 1, 40, "Subsubtitle",
  CellTags->"c:20"],

Cell[CellGroupData[{
Cell[18844253, 551254, 60, 1, 42, "Section",
  CellTags->{"i:67", "c:21"}],
Cell[18844316, 551257, 813, 16, 112, "Text"],
Cell[18845132, 551275, 922, 27, 78, "Text",
  CellTags->"i:128"],
Cell[18846057, 551304, 453, 13, 44, "Text",
  CellTags->"i:106"],
Cell[18846513, 551319, 200, 6, 43, "NE2",
  CellTags->"(5.2.1)"],
Cell[18846716, 551327, 519, 13, 67, "Text"],
Cell[18847238, 551342, 194, 7, 31, "NE2",
  CellTags->"(5.2.2)"],
Cell[18847435, 551351, 466, 18, 44, "Text"],
Cell[18847904, 551371, 180, 6, 43, "NE2",
  CellTags->"(5.2.3)"],
Cell[18848087, 551379, 123, 5, 27, "Text"],
Cell[18848213, 551386, 823, 24, 67, "Text"],
Cell[18849039, 551412, 215, 9, 27, "Text",
  CellTags->"i:68"],
Cell[18849257, 551423, 139, 5, 32, "NE2",
  CellTags->"(5.2.4)"],
Cell[18849399, 551430, 57, 0, 27, "Text"],
Cell[18849459, 551432, 186, 6, 29, "NE2",
  CellTags->"(5.2.5)"],
Cell[18849648, 551440, 826, 29, 47, "Text",
  CellTags->"i:142"],
Cell[18850477, 551471, 198, 6, 42, "NE2",
  CellTags->"(5.2.6)"],
Cell[18850678, 551479, 1015, 30, 95, "Text"],
Cell[18851696, 551511, 352, 10, 33, "NE2",
  CellTags->"(5.2.7)"],
Cell[18852051, 551523, 600, 20, 44, "Text"],
Cell[18852654, 551545, 201, 7, 40, "NE2",
  CellTags->"(5.2.8)"],
Cell[18852858, 551554, 226, 9, 27, "Text",
  CellTags->"i:69"],
Cell[18853087, 551565, 463, 15, 47, "Text"],
Cell[18853553, 551582, 170, 6, 30, "Text"],
Cell[18853726, 551590, 562, 13, 61, "Text"],
Cell[18854291, 551605, 912, 25, 98, "Text",
  CellTags->"i:70"],
Cell[18855206, 551632, 1133, 37, 84, "Text"],
Cell[18856342, 551671, 491, 13, 52, "Text"],
Cell[18856836, 551686, 1302, 39, 88, "Text"],
Cell[18858141, 551727, 552, 18, 60, "Text"],
Cell[18858696, 551747, 544, 18, 47, "Text"],
Cell[18859243, 551767, 154, 6, 40, "Text"],
Cell[18859400, 551775, 46, 0, 26, "Text"],
Cell[18859449, 551777, 218, 7, 30, "NE2",
  CellTags->"(5.2.9)"],
Cell[18859670, 551786, 863, 27, 62, "Text"],
Cell[18860536, 551815, 947, 28, 51, "Text"],
Cell[18861486, 551845, 282, 8, 40, "Text"],
Cell[18861771, 551855, 422, 14, 43, "Text"],
Cell[18862196, 551871, 533, 18, 43, "Text"],
Cell[18862732, 551891, 409, 10, 35, "NE2",
  CellTags->"(5.2.10)"],
Cell[18863144, 551903, 350, 13, 26, "Text"],
Cell[18863497, 551918, 404, 6, 33, "NE2",
  CellTags->"(5.2.11)"],
Cell[18863904, 551926, 834, 25, 88, "Text"],
Cell[18864741, 551953, 224, 6, 41, "NE2",
  CellTags->"(5.2.12)"],
Cell[18864968, 551961, 1061, 29, 107, "Text"],
Cell[18866032, 551992, 1213, 35, 105, "Text"],
Cell[18867248, 552029, 224, 7, 42, "NE2",
  CellTags->"(5.2.13)"],
Cell[18867475, 552038, 328, 12, 26, "Text"],
Cell[18867806, 552052, 328, 10, 60, "Text"],
Cell[18868137, 552064, 339, 11, 43, "Text"],
Cell[18868479, 552077, 639, 18, 43, "Text"],
Cell[18869121, 552097, 273, 10, 26, "Text"],
Cell[18869397, 552109, 447, 12, 68, "Text"],
Cell[18869847, 552123, 302, 9, 37, "NE2",
  CellTags->"(5.2.14)"],
Cell[18870152, 552134, 487, 16, 52, "Text"],
Cell[18870642, 552152, 410, 9, 36, "NE2",
  CellTags->"(5.2.15)"],
Cell[18871055, 552163, 203, 7, 26, "Text"],
Cell[18871261, 552172, 459, 11, 43, "NE2",
  CellTags->"(5.2.16)"],
Cell[18871723, 552185, 340, 10, 43, "Text"],
Cell[18872066, 552197, 790, 28, 60, "Text",
  CellTags->"i:96"],
Cell[18872859, 552227, 236, 7, 42, "NE2",
  CellTags->"(5.2.17)"],
Cell[18873098, 552236, 1094, 37, 91, "Text",
  CellTags->"i:71"],
Cell[18874195, 552275, 844, 25, 77, "Text"],
Cell[18875042, 552302, 163, 4, 66, "Input",
  CellTags->"Cell 5.12"],
Cell[18875208, 552308, 187, 4, 43, "Text"],
Cell[18875398, 552314, 121, 3, 67, "Input",
  CellTags->"Cell 5.13"],
Cell[18875522, 552319, 101, 3, 27, "Text"],

Cell[CellGroupData[{
Cell[18875648, 552326, 88, 3, 67, "Input",
  CellTags->"Cell 5.14"],
Cell[18875739, 552331, 1753, 39, 130, "Output"]
}, Open  ]],
Cell[18877507, 552373, 291, 9, 44, "Text"],

Cell[CellGroupData[{
Cell[18877823, 552386, 151, 4, 67, "Input",
  CellTags->"Cell 5.15"],
Cell[18877977, 552392, 800, 20, 72, "Output"]
}, Open  ]],
Cell[18878792, 552415, 567, 17, 64, "Text"],
Cell[18879362, 552434, 1522, 43, 129, "Text",
  CellTags->"i:140"]
}, Closed]],

Cell[CellGroupData[{
Cell[18880921, 552482, 102, 1, 31, "Section",
  CellTags->{"i:72", "c:22"}],
Cell[18881026, 552485, 1248, 33, 117, "Text"],
Cell[18882277, 552520, 541, 11, 47, "NE2",
  CellTags->"(5.2.18)"],
Cell[18882821, 552533, 475, 17, 43, "Text"],

Cell[CellGroupData[{
Cell[18883321, 552554, 596, 12, 150, "Input",
  CellTags->"Cell 5.16"],

Cell[CellGroupData[{
Cell[18883942, 552570, 79342, 1560, 232, 11145, 713, "GraphicsData", \
"PostScript", "Graphics"],
Cell[18963287, 554132, 79029, 1553, 232, 11132, 710, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19042319, 555687, 11283, 716, 232, 11161, 712, "GraphicsData", \
"PostScript", "Graphics",
  ImageCacheValid->False],
Cell[19053605, 556405, 77860, 1528, 232, 10907, 697, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19131468, 557935, 79496, 1558, 232, 11089, 709, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19210967, 559495, 79529, 1562, 232, 11146, 713, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19290499, 561059, 78966, 1552, 232, 11138, 710, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19369468, 562613, 77811, 1540, 232, 11153, 712, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19447282, 564155, 77984, 1530, 232, 10905, 697, "GraphicsData", \
"PostScript", "Graphics"],
Cell[19525269, 565687, 79283, 1555, 232, 11091, 709, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],
Cell[19604579, 567246, 278, 5, 60, "Text"],
Cell[19604860, 567253, 421, 11, 60, "Text"],
Cell[19605284, 567266, 379, 13, 43, "Text"],

Cell[CellGroupData[{
Cell[19605688, 567283, 276, 7, 100, "Input",
  CellTags->"Cell 5.17"],
Cell[19605967, 567292, 215, 4, 80, "Output"]
}, Open  ]],
Cell[19606197, 567299, 1141, 41, 60, "Text"],
Cell[19607341, 567342, 490, 10, 123, "Input",
  CellTags->"Cell 5.18"],
Cell[19607834, 567354, 222, 9, 26, "Text"],

Cell[CellGroupData[{
Cell[19608081, 567367, 211, 5, 85, "Input",
  CellTags->"Cell 5.19"],
Cell[19608295, 567374, 79370, 1560, 232, 11129, 713, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[19687680, 568937, 239, 7, 43, "Text"],

Cell[CellGroupData[{
Cell[19687944, 568948, 198, 4, 66, "Input",
  CellTags->"Cell 5.20"],
Cell[19688145, 568954, 107238, 1883, 232, 11311, 694, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[19795398, 570840, 572, 18, 60, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[19796007, 570863, 128, 4, 31, "Section",
  CellTags->{"i:73", "c:23"}],
Cell[19796138, 570869, 383, 6, 77, "Text"],
Cell[19796524, 570877, 510, 10, 77, "Text"],
Cell[19797037, 570889, 560, 9, 95, "Text"],
Cell[19797600, 570900, 551, 10, 77, "Text"],
Cell[19798154, 570912, 187, 6, 37, "NE2",
  CellTags->"(5.2.19)"],
Cell[19798344, 570920, 287, 7, 43, "Text"],
Cell[19798634, 570929, 179, 6, 31, "NE2",
  CellTags->"(5.2.20)"],
Cell[19798816, 570937, 1022, 31, 81, "Text"],
Cell[19799841, 570970, 233, 7, 42, "NE2",
  CellTags->"(5.2.21)"],
Cell[19800077, 570979, 686, 23, 65, "Text"],
Cell[19800766, 571004, 1230, 35, 70, "Text"],

Cell[CellGroupData[{
Cell[19802021, 571043, 913, 20, 260, "Input",
  CellTags->"Cell 5.21"],
Cell[19802937, 571065, 105451, 2565, 280, 24410, 1560, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[19908403, 573633, 478, 13, 60, "Text"],
Cell[19908884, 573648, 288, 7, 47, "Text"],
Cell[19909175, 573657, 138, 5, 28, "NE2",
  CellTags->"(5.2.22)"],
Cell[19909316, 573664, 593, 18, 60, "Text"],
Cell[19909912, 573684, 421, 10, 42, "Text"],
Cell[19910336, 573696, 794, 16, 105, "Text"],
Cell[19911133, 573714, 509, 13, 60, "Text"],

Cell[CellGroupData[{
Cell[19911667, 573731, 363, 8, 105, "Input",
  CellTags->"Cell 5.22"],
Cell[19912033, 573741, 209203, 10403, 232, 151455, 9686, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[20121251, 584147, 500, 14, 47, "Text"],
Cell[20121754, 584163, 543, 15, 60, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[20122334, 584183, 65, 1, 31, "Section",
  CellTags->{"i:74", "c:24"}],
Cell[20122402, 584186, 860, 23, 95, "Text"],
Cell[20123265, 584211, 207, 6, 42, "NE2",
  CellTags->"(5.2.23)"],
Cell[20123475, 584219, 175, 5, 26, "Text"],
Cell[20123653, 584226, 273, 8, 28, "NE2",
  CellTags->"(5.2.24)"],
Cell[20123929, 584236, 452, 15, 43, "Text"],
Cell[20124384, 584253, 496, 9, 37, "NE2",
  CellTags->"(5.2.25)"],
Cell[20124883, 584264, 273, 9, 43, "Text"],
Cell[20125159, 584275, 501, 16, 43, "Text"],
Cell[20125663, 584293, 574, 12, 50, "NE2",
  CellTags->"(5.2.26)"],
Cell[20126240, 584307, 296, 9, 26, "Text"],
Cell[20126539, 584318, 539, 12, 51, "NE2",
  CellTags->"(5.2.27)"],
Cell[20127081, 584332, 1085, 32, 115, "Text"],
Cell[20128169, 584366, 250, 9, 26, "Text"],
Cell[20128422, 584377, 179, 3, 31, "NE2",
  CellTags->"(5.2.28)"],
Cell[20128604, 584382, 1694, 50, 103, "Text"],
Cell[20130301, 584434, 504, 13, 67, "Text"],
Cell[20130808, 584449, 232, 7, 32, "NE2",
  CellTags->"(5.2.29)"],
Cell[20131043, 584458, 926, 36, 60, "Text"],
Cell[20131972, 584496, 184, 7, 33, "NE2",
  CellTags->"(5.2.30)"],
Cell[20132159, 584505, 308, 11, 43, "Text"],
Cell[20132470, 584518, 1687, 50, 137, "Text"],

Cell[CellGroupData[{
Cell[20134182, 584572, 915, 22, 297, "Input",
  CellTags->"Cell 5.23"],

Cell[CellGroupData[{
Cell[20135122, 584598, 37365, 1088, 232, 13265, 786, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20172490, 585688, 36581, 1127, 70, 14231, 847, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20209074, 586817, 37954, 1191, 70, 15142, 905, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20247031, 588010, 36558, 1124, 70, 14167, 843, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20283592, 589136, 35541, 1083, 70, 13608, 808, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20319136, 590221, 34963, 1061, 70, 13321, 789, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20354102, 591284, 34089, 1020, 70, 12727, 752, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20388194, 592306, 33526, 998, 70, 12439, 733, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20421723, 593306, 33307, 989, 70, 12313, 725, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20455033, 594297, 32560, 955, 70, 11821, 694, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20487596, 595254, 32520, 949, 70, 11729, 688, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20520119, 596205, 32200, 941, 70, 11652, 683, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20552322, 597148, 31618, 912, 70, 11224, 656, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20583943, 598062, 31333, 894, 70, 10951, 638, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20615279, 598958, 30801, 874, 70, 10674, 621, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20646083, 599834, 30472, 856, 70, 10406, 604, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20676558, 600692, 30385, 859, 70, 10485, 609, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20706946, 601553, 30236, 853, 70, 10397, 604, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20737185, 602408, 29912, 832, 70, 10081, 583, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20767100, 603242, 29696, 831, 70, 10095, 584, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20796799, 604075, 29353, 809, 70, 9761, 563, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20826155, 604886, 29265, 808, 70, 9745, 562, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20855423, 605696, 29109, 802, 70, 9675, 558, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20884535, 606500, 28623, 780, 70, 9371, 538, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20913161, 607282, 28496, 778, 70, 9353, 537, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20941660, 608062, 28417, 773, 70, 9274, 532, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20970080, 608837, 28190, 761, 70, 9112, 521, "GraphicsData", \
"PostScript", "Graphics"],
Cell[20998273, 609600, 27977, 751, 70, 8943, 511, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21026253, 610353, 27996, 747, 70, 8865, 506, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21054252, 611102, 27691, 737, 70, 8734, 498, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21081946, 611841, 27625, 728, 70, 8604, 489, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],
Cell[21109598, 612573, 364, 9, 45, "Text"],
Cell[21109965, 612584, 651, 14, 95, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[21110653, 612603, 104, 1, 31, "Section",
  CellTags->{"i:75", "c:25"}],
Cell[21110760, 612606, 757, 25, 26, "Text"],
Cell[21111520, 612633, 492, 15, 41, "NE2",
  CellTags->"(5.2.31)"],
Cell[21112015, 612650, 1832, 58, 81, "Text"],
Cell[21113850, 612710, 819, 26, 65, "Text"],
Cell[21114672, 612738, 295, 8, 42, "NE2",
  CellTags->"(5.2.32)"],
Cell[21114970, 612748, 21, 0, 26, "Text"],
Cell[21114994, 612750, 171, 3, 32, "NE2",
  CellTags->"(5.2.33)"],
Cell[21115168, 612755, 264, 9, 26, "Text"],
Cell[21115435, 612766, 184, 6, 32, "NE2",
  CellTags->"(5.2.34)"],
Cell[21115622, 612774, 489, 18, 45, "Text"],
Cell[21116114, 612794, 1006, 27, 97, "Text"],
Cell[21117123, 612823, 330, 9, 40, "NE2",
  CellTags->"(5.2.35)"],
Cell[21117456, 612834, 514, 18, 45, "Text"],
Cell[21117973, 612854, 230, 8, 26, "Text"],
Cell[21118206, 612864, 519, 17, 45, "NE2",
  CellTags->"(5.2.36)"],
Cell[21118728, 612883, 44969, 559, 232, 44848, 555, "GraphicsData", "Bitmap", \
"Picture",
  Evaluatable->False],
Cell[21163700, 613444, 102, 1, 15, "Caption",
  CellTags->"Fig. 5.6"],
Cell[21163805, 613447, 1981, 67, 85, "Text"],

Cell[CellGroupData[{
Cell[21165811, 613518, 968, 22, 392, "Input",
  CellTags->"Cell 5.24"],

Cell[CellGroupData[{
Cell[21166804, 613544, 46090, 1091, 232, 10891, 652, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21212897, 614637, 45521, 1070, 70, 10646, 635, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21258421, 615709, 45860, 1083, 70, 10815, 646, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21304284, 616794, 46053, 1081, 70, 10732, 640, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21350340, 617877, 45945, 1086, 70, 10835, 648, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21396288, 618965, 46272, 1093, 70, 10891, 652, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21442563, 620060, 46051, 1077, 70, 10637, 635, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21488617, 621139, 45691, 1081, 70, 10824, 646, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21534311, 622222, 46047, 1081, 70, 10722, 640, "GraphicsData", \
"PostScript", "Graphics"],
Cell[21580361, 623305, 46503, 1093, 70, 10834, 648, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],
Cell[21626891, 624402, 885, 25, 95, "Text"],
Cell[21627779, 624429, 1010, 33, 61, "Text"],

Cell[CellGroupData[{
Cell[21628814, 624466, 364, 8, 105, "Input",
  CellTags->"Cell 5.25"],

Cell[CellGroupData[{
Cell[21629203, 624478, 559122, 19589, 370, 243690, 15690, "GraphicsData", \
"PostScript", "Graphics"],
Cell[22188328, 644069, 558918, 19590, 70, 243741, 15694, "GraphicsData", \
"PostScript", "Graphics"],
Cell[22747249, 663661, 559231, 19604, 70, 243836, 15706, "GraphicsData", \
"PostScript", "Graphics"],
Cell[23306483, 683267, 558734, 19583, 70, 243784, 15690, "GraphicsData", \
"PostScript", "Graphics"],
Cell[23865220, 702852, 559285, 19612, 70, 243918, 15714, "GraphicsData", \
"PostScript", "Graphics"],
Cell[24424508, 722466, 559122, 19589, 70, 243690, 15690, "GraphicsData", \
"PostScript", "Graphics"],
Cell[24983633, 742057, 558918, 19590, 70, 243741, 15694, "GraphicsData", \
"PostScript", "Graphics"],
Cell[25542554, 761649, 559231, 19604, 70, 243836, 15706, "GraphicsData", \
"PostScript", "Graphics"],
Cell[26101788, 781255, 558734, 19583, 70, 243784, 15690, "GraphicsData", \
"PostScript", "Graphics"],
Cell[26660525, 800840, 559285, 19612, 70, 243918, 15714, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],
Cell[27219837, 820456, 471, 11, 60, "Text",
  CellTags->"i:76"]
}, Closed]],

Cell[CellGroupData[{
Cell[27220345, 820472, 66, 1, 31, "Section",
  CellTags->{"i:107", "c:26"}],
Cell[27220414, 820475, 295, 8, 43, "Text"],
Cell[27220712, 820485, 222, 7, 30, "NE2",
  CellTags->"(5.2.37)"],
Cell[27220937, 820494, 2501, 70, 205, "Text"],
Cell[27223441, 820566, 1026, 32, 38, "NE2",
  CellTags->"(5.2.38)"],
Cell[27224470, 820600, 1084, 37, 31, "Text"],
Cell[27225557, 820639, 2498, 80, 130, "Text",
  CellTags->"i:77"],
Cell[27228058, 820721, 294, 10, 46, "NE2",
  CellTags->"(5.2.39)"],
Cell[27228355, 820733, 385, 14, 43, "Text"],

Cell[CellGroupData[{
Cell[27228765, 820751, 901, 16, 218, "Input",
  CellTags->"Cell 5.26"],
Cell[27229669, 820769, 551647, 19572, 370, 240419, 15725, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[27781331, 840344, 997, 31, 90, "Text",
  CellTags->"i:108"],
Cell[27782331, 840377, 281, 8, 45, "NE2",
  CellTags->"(5.2.40)"],
Cell[27782615, 840387, 963, 31, 61, "Text"],
Cell[27783581, 840420, 191, 7, 42, "NE2",
  CellTags->{"i:78", "(5.2.41)"}],
Cell[27783775, 840429, 637, 17, 77, "Text"],
Cell[27784415, 840448, 54696, 679, 198, 54576, 675, "GraphicsData", "Bitmap", \
"Picture",
  Evaluatable->False],
Cell[27839114, 841129, 201, 6, 15, "Caption",
  CellTags->"Fig. 5.7"],
Cell[27839318, 841137, 590, 10, 95, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[27839957, 841153, 98, 1, 29, "Subsubtitle",
  CellTags->{"i:79", "c:27"}],

Cell[CellGroupData[{
Cell[27840080, 841158, 71, 1, 41, "Section",
  CellTags->{"i:80", "c:28"}],
Cell[27840154, 841161, 142, 4, 26, "Text",
  CellTags->"i:124"],
Cell[27840299, 841167, 165, 6, 30, "NE2",
  CellTags->"(5.2.42)"],
Cell[27840467, 841175, 643, 14, 95, "Text",
  CellTags->"i:113"],
Cell[27841113, 841191, 1308, 40, 96, "Text",
  CellTags->"i:129"],
Cell[27842424, 841233, 117, 2, 26, "NE2",
  CellTags->"(5.2.43)"],
Cell[27842544, 841237, 1525, 43, 111, "Text"],
Cell[27844072, 841282, 658, 14, 65, "Text"],
Cell[27844733, 841298, 333, 8, 35, "Text"],
Cell[27845069, 841308, 343, 6, 50, "NE2",
  CellTags->"(5.2.44)"],
Cell[27845415, 841316, 1047, 29, 93, "Text"],
Cell[27846465, 841347, 265, 7, 40, "Text"],
Cell[27846733, 841356, 681, 19, 56, "Text"],
Cell[27847417, 841377, 221, 7, 46, "NE2",
  CellTags->"(5.2.45)"],
Cell[27847641, 841386, 379, 13, 45, "Text"],
Cell[27848023, 841401, 1214, 31, 111, "Text"],
Cell[27849240, 841434, 184, 3, 37, "NE2",
  CellTags->"(5.2.46)"],
Cell[27849427, 841439, 447, 15, 43, "Text"],
Cell[27849877, 841456, 318, 8, 37, "NE2",
  CellTags->"(5.2.47)"],
Cell[27850198, 841466, 1073, 33, 95, "Text",
  CellTags->"i:81"],
Cell[27851274, 841501, 1748, 51, 43, "NE2",
  CellTags->"(5.2.48)"],
Cell[27853025, 841554, 1511, 46, 77, "Text",
  CellTags->"i:114"],
Cell[27854539, 841602, 1038, 33, 61, "Text"],
Cell[27855580, 841637, 777, 25, 43, "Text"],
Cell[27856360, 841664, 328, 9, 45, "NE2",
  CellTags->"(5.2.49)"],
Cell[27856691, 841675, 1595, 41, 162, "Text"],
Cell[27858289, 841718, 950, 27, 80, "Text",
  CellTags->"i:82"],
Cell[27859242, 841747, 655, 12, 95, "Text"],
Cell[27859900, 841761, 762, 14, 111, "Text"],
Cell[27860665, 841777, 1361, 38, 130, "Text"],
Cell[27862029, 841817, 196, 6, 46, "Text"],
Cell[27862228, 841825, 39, 0, 26, "Text"],
Cell[27862270, 841827, 253, 8, 62, "NE2",
  CellTags->"(5.2.50)"],
Cell[27862526, 841837, 1108, 35, 85, "Text"],

Cell[CellGroupData[{
Cell[27863659, 841876, 351, 9, 145, "Input",
  CellTags->"Cell 5.27"],
Cell[27864013, 841887, 396, 5, 226, "Output"]
}, Open  ]],
Cell[27864424, 841895, 369, 15, 26, "Text"],
Cell[27864796, 841912, 55088, 1533, 370, 18107, 1072, "GraphicsData", \
"PostScript", "Picture"],
Cell[27919887, 843447, 213, 6, 20, "Caption",
  CellTags->"Fig. 5.8"],
Cell[27920103, 843455, 493, 9, 77, "Text"],
Cell[27920599, 843466, 1544, 45, 112, "Text",
  CellTags->"i:83"],
Cell[27922146, 843513, 821, 24, 80, "Text",
  CellTags->"i:84"],
Cell[27922970, 843539, 621, 15, 77, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[27923628, 843559, 108, 1, 30, "Section",
  CellTags->{"i:85", "c:29"}],
Cell[27923739, 843562, 389, 11, 43, "Text"],
Cell[27924131, 843575, 321, 9, 41, "NE2",
  CellTags->"(5.2.51)"],
Cell[27924455, 843586, 383, 11, 43, "Text"],
Cell[27924841, 843599, 517, 17, 46, "Text"],
Cell[27925361, 843618, 312, 8, 40, "Text"],
Cell[27925676, 843628, 55, 0, 26, "Text"],
Cell[27925734, 843630, 259, 7, 41, "NE2",
  CellTags->"(5.2.52)"],
Cell[27925996, 843639, 187, 7, 26, "Text"],
Cell[27926186, 843648, 201, 7, 38, "NE2",
  CellTags->"(5.2.53)"],
Cell[27926390, 843657, 1109, 32, 95, "Text"],
Cell[27927502, 843691, 1347, 43, 100, "Text"],
Cell[27928852, 843736, 444, 14, 85, "NE2",
  CellTags->"(5.2.54)"],
Cell[27929299, 843752, 436, 13, 60, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[27929772, 843770, 63, 1, 30, "Section",
  CellTags->{"i:86", "c:30"}],
Cell[27929838, 843773, 1177, 33, 97, "Text"],
Cell[27931018, 843808, 391, 8, 60, "Text"],
Cell[27931412, 843818, 441, 13, 43, "Text"],
Cell[27931856, 843833, 186, 7, 31, "NE2",
  CellTags->"(5.2.55)"],
Cell[27932045, 843842, 789, 28, 63, "Text"],
Cell[27932837, 843872, 666, 22, 60, "Text"],
Cell[27933506, 843896, 180, 7, 30, "NE2",
  CellTags->"(5.2.56)"],
Cell[27933689, 843905, 39, 0, 26, "Text"],
Cell[27933731, 843907, 225, 7, 32, "NE2",
  CellTags->"(5.2.57)"],
Cell[27933959, 843916, 770, 26, 65, "Text"],
Cell[27934732, 843944, 165, 3, 32, "NE2",
  CellTags->"(5.2.58)"],
Cell[27934900, 843949, 665, 22, 50, "Text"],

Cell[CellGroupData[{
Cell[27935590, 843975, 308, 7, 115, "Input",
  CellTags->"Cell 5.28"],
Cell[27935901, 843984, 86834, 1665, 263, 12693, 744, "GraphicsData", \
"PostScript", "Graphics",
  CellTags->"i:87"]
}, Open  ]],
Cell[28022750, 845652, 899, 18, 111, "Text",
  CellTags->"i:138"],
Cell[28023652, 845672, 751, 17, 95, "Text"],
Cell[28024406, 845691, 1027, 19, 128, "Text"]
}, Closed]],

Cell[CellGroupData[{
Cell[28025470, 845715, 70, 1, 30, "Section",
  CellTags->{"i:88", "c:31"}],
Cell[28025543, 845718, 384, 10, 60, "Text"],
Cell[28025930, 845730, 829, 17, 111, "Text"],
Cell[28026762, 845749, 1840, 50, 37, "NE2",
  CellTags->{"i:119", "(5.2.59)"}],
Cell[28028605, 845801, 987, 33, 43, "Text"],
Cell[28029595, 845836, 584, 18, 37, "NE2",
  CellTags->"(5.2.60)"],
Cell[28030182, 845856, 4125, 125, 100, "Text"],
Cell[28034310, 845983, 1378, 43, 95, "Text"],
Cell[28035691, 846028, 351, 10, 43, "Text"],
Cell[28036045, 846040, 197, 6, 35, "Text"],
Cell[28036245, 846048, 1435, 41, 70, "Text"],
Cell[28037683, 846091, 602, 17, 33, "NE2",
  CellTags->"(5.2.61)"],
Cell[28038288, 846110, 1316, 36, 86, "Text",
  CellTags->"i:125"],
Cell[28039607, 846148, 1665, 47, 153, "Text"],
Cell[28041275, 846197, 625, 22, 43, "Text",
  CellTags->"i:89"],
Cell[28041903, 846221, 1403, 39, 103, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[28043355, 846266, 65, 1, 29, "Subsubtitle",
  CellTags->"c:33"],
Cell[28043423, 846269, 136, 5, 27, "Text",
  CellTags->"i:94"],
Cell[28043562, 846276, 215, 6, 40, "Text"],
Cell[28043780, 846284, 335, 12, 44, "Text"],
Cell[28044118, 846298, 405, 14, 44, "Text"],
Cell[28044526, 846314, 340, 13, 30, "Text"],
Cell[28044869, 846329, 564, 20, 32, "Text"],
Cell[28045436, 846351, 1205, 41, 116, "Text",
  CellTags->"i:109"],
Cell[28046644, 846394, 443, 15, 44, "Text",
  CellTags->"i:95"],
Cell[28047090, 846411, 375, 12, 61, "Text"],
Cell[28047468, 846425, 1006, 34, 82, "Text"],
Cell[28048477, 846461, 52570, 1445, 283, 19235, 1029, "GraphicsData", \
"PostScript", "Picture"],
Cell[28101050, 847908, 415, 11, 29, "Caption",
  CellTags->"Fig. 5.9"],
Cell[28101468, 847921, 1345, 41, 104, "Text",
  CellTags->"i:97"],
Cell[28102816, 847964, 525, 12, 78, "Text",
  CellTags->"i:110"],
Cell[28103344, 847978, 478, 15, 44, "Text"],
Cell[28103825, 847995, 291, 11, 27, "Text",
  CellTags->"i:98"],
Cell[28104119, 848008, 278, 7, 43, "Text"],
Cell[28104400, 848017, 140, 4, 27, "Text"],
Cell[28104543, 848023, 541, 12, 44, "NE2",
  CellTags->"(5.2.62)"],
Cell[28105087, 848037, 175, 6, 32, "Text"],
Cell[28105265, 848045, 330, 12, 27, "Text"],
Cell[28105598, 848059, 218, 7, 27, "Text"],
Cell[28105819, 848068, 261, 7, 36, "Text"],
Cell[28106083, 848077, 439, 16, 31, "Text"],
Cell[28106525, 848095, 797, 29, 46, "Text"],
Cell[28107325, 848126, 410, 13, 53, "Text"],
Cell[28107738, 848141, 381, 12, 44, "Text"],
Cell[28108122, 848155, 793, 26, 73, "Text"],
Cell[28108918, 848183, 259, 8, 44, "Text"],
Cell[28109180, 848193, 264, 7, 43, "Text"],
Cell[28109447, 848202, 431, 13, 44, "Text"],
Cell[28109881, 848217, 622, 18, 64, "Text",
  CellTags->"i:127"],
Cell[28110506, 848237, 794, 21, 84, "Text"],
Cell[28111303, 848260, 576, 19, 53, "Text"],
Cell[28111882, 848281, 951, 34, 49, "Text",
  CellTags->"i:126"],
Cell[28112836, 848317, 2016, 58, 44, "NE2",
  CellTags->{"i:118", "(5.2.63)"}],
Cell[28114855, 848377, 308, 9, 44, "Text"],
Cell[28115166, 848388, 1115, 37, 50, "Text"],
Cell[28116284, 848427, 1990, 70, 66, "Text"],
Cell[28118277, 848499, 287, 9, 44, "Text",
  CellTags->"i:99"],
Cell[28118567, 848510, 1822, 52, 39, "Text"],
Cell[28120392, 848564, 115, 3, 27, "Text"],
Cell[28120510, 848569, 882, 29, 61, "Text"],
Cell[28121395, 848600, 580, 18, 55, "Text"],
Cell[28121978, 848620, 370, 15, 27, "Text"],
Cell[28122351, 848637, 404, 14, 44, "Text"],
Cell[28122758, 848653, 720, 19, 47, "Text"],
Cell[28123481, 848674, 125, 4, 27, "Text"],
Cell[28123609, 848680, 953, 20, 116, "Text"],
Cell[28124565, 848702, 2149, 67, 126, "Text",
  CellTags->"i:111"],
Cell[28126717, 848771, 1580, 48, 143, "Text",
  CellTags->"i:100"],
Cell[28128300, 848821, 165, 5, 27, "Text"],
Cell[28128468, 848828, 154, 6, 31, "Text"],
Cell[28128625, 848836, 971, 31, 47, "Text"],
Cell[28129599, 848869, 631, 18, 66, "Text"],
Cell[28130233, 848889, 153, 5, 27, "Text"],
Cell[28130389, 848896, 1019, 26, 49, "Text"],
Cell[28131411, 848924, 956, 28, 112, "Text"],
Cell[28132370, 848954, 2728, 81, 128, "Text"],
Cell[28135101, 849037, 848, 25, 78, "Text"],
Cell[28135952, 849064, 1620, 51, 116, "Text",
  CellTags->"i:101"],
Cell[28137575, 849117, 756, 21, 79, "Text",
  CellTags->"i:102"],
Cell[28138334, 849140, 212, 9, 28, "Text"],
Cell[28138549, 849151, 985, 30, 61, "Text"],
Cell[28139537, 849183, 583, 13, 45, "Text"],
Cell[28140123, 849198, 779, 25, 32, "Text"],
Cell[28140905, 849225, 1201, 39, 67, "Text"],
Cell[28142109, 849266, 1229, 39, 79, "Text"],
Cell[28143341, 849307, 2013, 62, 131, "Text"],
Cell[28145357, 849371, 882, 24, 81, "Text",
  CellTags->"i:103"],
Cell[28146242, 849397, 833, 25, 32, "Text"],
Cell[28147078, 849424, 1624, 45, 125, "Text"],
Cell[28148705, 849471, 200504, 3051, 370, 132653, 2211, "BoxData", \
"Graphics3D", "Graphics"],
Cell[28349212, 852524, 101, 1, 16, "Caption",
  CellTags->"Fig. 5.10"],
Cell[28349316, 852527, 1721, 49, 129, "Text",
  CellTags->"i:104"],
Cell[28351040, 852578, 112, 4, 27, "Text"],
Cell[28351155, 852584, 344, 10, 44, "NE2",
  CellTags->"(5.2.64)"],
Cell[28351502, 852596, 355, 9, 42, "Text"],
Cell[28351860, 852607, 269, 7, 36, "Text"],
Cell[28352132, 852616, 348, 7, 36, "Text"],
Cell[28352483, 852625, 950, 28, 70, "Text"],
Cell[28353436, 852655, 330, 8, 41, "Text"],
Cell[28353769, 852665, 713, 23, 61, "Text"],
Cell[28354485, 852690, 249, 8, 33, "NE2",
  CellTags->"(5.2.65)"],
Cell[28354737, 852700, 1308, 41, 46, "Text"],
Cell[28356048, 852743, 317, 10, 44, "Text"],
Cell[28356368, 852755, 234, 7, 27, "Text"],
Cell[28356605, 852764, 216, 8, 27, "Text",
  CellTags->"i:105"],
Cell[28356824, 852774, 194, 5, 41, "Text"],
Cell[28357021, 852781, 1151, 30, 112, "Text"],
Cell[28358175, 852813, 158, 7, 27, "Text"],
Cell[28358336, 852822, 207, 7, 27, "Text"],
Cell[28358546, 852831, 254, 10, 27, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[28358849, 852847, 97, 2, 40, "Subtitle",
  CellTags->{"i:90", "c:32"}],
Cell[28358949, 852851, 1089, 22, 129, "Text"],

Cell[CellGroupData[{
Cell[28360063, 852877, 69, 1, 40, "Subsubtitle",
  CellTags->"c:35"],
Cell[28360135, 852880, 482, 16, 27, "Text"],
Cell[28360620, 852898, 113, 5, 33, "NE3",
  CellTags->"(5.3.1)"],
Cell[28360736, 852905, 165, 5, 31, "Text"],
Cell[28360904, 852912, 800, 26, 38, "NE3",
  CellTags->"(5.3.2)"],
Cell[28361707, 852940, 2728, 85, 120, "Text"],
Cell[28364438, 853027, 1721, 55, 53, "Text"],
Cell[28366162, 853084, 3161, 94, 158, "Text"],
Cell[28369326, 853180, 298, 7, 33, "NE3",
  CellTags->"(5.3.3)"],
Cell[28369627, 853189, 1332, 47, 44, "Text"],
Cell[28370962, 853238, 1043, 29, 39, "NE3",
  CellTags->"(5.3.4)"],
Cell[28372008, 853269, 341, 13, 27, "Text",
  CellTags->"i:121"],
Cell[28372352, 853284, 564, 16, 61, "Text"],
Cell[28372919, 853302, 1186, 37, 46, "NE3",
  CellTags->"(5.3.5)"],
Cell[28374108, 853341, 319, 11, 27, "Text"],
Cell[28374430, 853354, 916, 30, 31, "NE3",
  CellTags->"(5.3.6)"],
Cell[28375349, 853386, 194, 6, 27, "Text"],
Cell[28375546, 853394, 502, 17, 29, "NE3",
  CellTags->{"i:122", "(5.3.7)"}],
Cell[28376051, 853413, 215, 6, 44, "Text"],
Cell[28376269, 853421, 474, 16, 29, "NE3",
  CellTags->"(5.3.8)"],
Cell[28376746, 853439, 1241, 41, 82, "Text"],
Cell[28377990, 853482, 1249, 43, 78, "Text",
  CellTags->"i:91"],
Cell[28379242, 853527, 596, 19, 48, "Text"],
Cell[28379841, 853548, 189, 7, 43, "NE3",
  CellTags->"(5.3.9)"],
Cell[28380033, 853557, 1516, 57, 44, "Text"],
Cell[28381552, 853616, 2882, 100, 61, "Text"],
Cell[28384437, 853718, 789, 25, 53, "NE3",
  CellTags->"(5.3.10)"],
Cell[28385229, 853745, 462, 14, 48, "Text"],
Cell[28385694, 853761, 728, 21, 43, "NE3",
  CellTags->"(5.3.11)"],
Cell[28386425, 853784, 1339, 44, 62, "Text"],
Cell[28387767, 853830, 974, 29, 38, "NE3",
  CellTags->"(5.3.12)"],
Cell[28388744, 853861, 46, 0, 27, "Text"],
Cell[28388793, 853863, 1100, 34, 38, "NE3",
  CellTags->"(5.3.13)"],
Cell[28389896, 853899, 352, 10, 44, "Text"],
Cell[28390251, 853911, 1208, 32, 36, "Text"],
Cell[28391462, 853945, 493, 19, 27, "Text"],
Cell[28391958, 853966, 1195, 30, 36, "Text"],
Cell[28393156, 853998, 175, 5, 27, "Text"],
Cell[28393334, 854005, 716, 23, 63, "Text"],
Cell[28394053, 854030, 1188, 30, 36, "Text"],
Cell[28395244, 854062, 29, 0, 27, "Text"],
Cell[28395276, 854064, 193, 6, 38, "NE3",
  CellTags->"(5.3.14)"],
Cell[28395472, 854072, 1170, 36, 78, "Text",
  CellTags->"i:115"],
Cell[28396645, 854110, 4526, 144, 146, "Text",
  CellTags->"i:141"],
Cell[28401174, 854256, 716, 18, 63, "Text"],
Cell[28401893, 854276, 120, 3, 67, "Input",
  CellTags->"Cell 5.29"],
Cell[28402016, 854281, 481, 15, 27, "Text"],

Cell[CellGroupData[{
Cell[28402522, 854300, 154, 4, 67, "Input",
  CellTags->"Cell 5.30"],
Cell[28402679, 854306, 47, 1, 46, "Output"]
}, Open  ]],
Cell[28402741, 854310, 1086, 31, 61, "Text"],
Cell[28403830, 854343, 503, 14, 39, "NE3",
  CellTags->"(5.3.15)"],
Cell[28404336, 854359, 984, 29, 61, "Text"],
Cell[28405323, 854390, 384, 9, 105, "Input",
  CellTags->"Cell 5.31"],
Cell[28405710, 854401, 397, 9, 105, "Input",
  CellTags->"Cell 5.32"],
Cell[28406110, 854412, 1316, 25, 257, "Input",
  CellTags->"Cell 5.33"],
Cell[28407429, 854439, 168, 4, 44, "Text"],
Cell[28407600, 854445, 152, 4, 67, "Input",
  CellTags->"Cell 5.34"],
Cell[28407755, 854451, 293, 11, 27, "Text"],
Cell[28408051, 854464, 208, 5, 67, "Input",
  CellTags->"Cell 5.35"],
Cell[28408262, 854471, 50, 0, 27, "Text"],

Cell[CellGroupData[{
Cell[28408337, 854475, 159, 4, 67, "Input",
  CellTags->"Cell 5.36"],
Cell[28408499, 854481, 108397, 1885, 302, 21210, 804, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[28516911, 856369, 427, 11, 44, "Text"],
Cell[28517341, 856382, 164, 4, 44, "Text"],
Cell[28517508, 856388, 97, 3, 67, "Input",
  CellTags->"Cell 5.37"],
Cell[28517608, 856393, 295, 8, 86, "Input",
  CellTags->"Cell 5.38"],
Cell[28517906, 856403, 255, 9, 27, "Text"],
Cell[28518164, 856414, 92, 3, 67, "Input",
  CellTags->"Cell 5.39"],
Cell[28518259, 856419, 326, 7, 105, "Input",
  CellTags->"Cell 5.40"],

Cell[CellGroupData[{
Cell[28518610, 856430, 261, 6, 86, "Input",
  CellTags->"Cell 5.41"],

Cell[CellGroupData[{
Cell[28518896, 856440, 46735, 1224, 331, 9201, 756, "GraphicsData", \
"PostScript", "Graphics"],
Cell[28565634, 857666, 46737, 1224, 70, 9203, 756, "GraphicsData", \
"PostScript", "Graphics"],
Cell[28612374, 858892, 46730, 1224, 70, 9204, 756, "GraphicsData", \
"PostScript", "Graphics"],
Cell[28659107, 860118, 46641, 1223, 70, 9200, 756, "GraphicsData", \
"PostScript", "Graphics"],
Cell[28705751, 861343, 46596, 1222, 70, 9216, 756, "GraphicsData", \
"PostScript", "Graphics"],
Cell[28752350, 862567, 46527, 1220, 70, 9192, 755, "GraphicsData", \
"PostScript", "Graphics"],
Cell[28798880, 863789, 46512, 1216, 70, 9136, 750, "GraphicsData", \
"PostScript", "Graphics"],
Cell[28845395, 865007, 46796, 1217, 70, 9137, 748, "GraphicsData", \
"PostScript", "Graphics"],
Cell[28892194, 866226, 47194, 1224, 70, 9130, 750, "GraphicsData", \
"PostScript", "Graphics"],
Cell[28939391, 867452, 47533, 1229, 70, 9153, 751, "GraphicsData", \
"PostScript", "Graphics"],
Cell[28986927, 868683, 48068, 1238, 70, 9194, 754, "GraphicsData", \
"PostScript", "Graphics"],
Cell[29034998, 869923, 48516, 1246, 70, 9220, 756, "GraphicsData", \
"PostScript", "Graphics"],
Cell[29083517, 871171, 48725, 1249, 70, 9194, 756, "GraphicsData", \
"PostScript", "Graphics"],
Cell[29132245, 872422, 48865, 1249, 70, 9197, 755, "GraphicsData", \
"PostScript", "Graphics"],
Cell[29181113, 873673, 49099, 1252, 70, 9204, 755, "GraphicsData", \
"PostScript", "Graphics"],
Cell[29230215, 874927, 49210, 1254, 70, 9193, 755, "GraphicsData", \
"PostScript", "Graphics"],
Cell[29279428, 876183, 49673, 1259, 70, 9195, 755, "GraphicsData", \
"PostScript", "Graphics"],
Cell[29329104, 877444, 49569, 1258, 70, 9196, 755, "GraphicsData", \
"PostScript", "Graphics"],
Cell[29378676, 878704, 49597, 1258, 70, 9200, 755, "GraphicsData", \
"PostScript", "Graphics"],
Cell[29428276, 879964, 49655, 1259, 70, 9197, 755, "GraphicsData", \
"PostScript", "Graphics"],
Cell[29477934, 881225, 48777, 1220, 70, 8850, 723, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],
Cell[29526738, 882449, 814, 15, 137, "Text"],
Cell[29527555, 882466, 291, 6, 105, "Input",
  CellTags->"Cell 5.42"],
Cell[29527849, 882474, 389, 8, 124, "Input",
  CellTags->"Cell 5.43"],

Cell[CellGroupData[{
Cell[29528263, 882486, 273, 5, 86, "Input",
  CellTags->"Cell 5.44"],
Cell[29528539, 882493, 134738, 2728, 490, 19459, 1300, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[29663292, 885224, 1910, 48, 197, "Text"],
Cell[29665205, 885274, 176, 7, 29, "NE3",
  CellTags->"(5.3.16)"],
Cell[29665384, 885283, 48439, 601, 260, 48318, 597, "GraphicsData", "Bitmap", \
"Picture",
  Evaluatable->False],
Cell[29713826, 885886, 316, 10, 29, "Caption",
  CellTags->"Fig. 5.11"],
Cell[29714145, 885898, 791, 21, 78, "Text",
  CellTags->"i:136"],
Cell[29714939, 885921, 486, 13, 44, "Text"],
Cell[29715428, 885936, 187, 5, 67, "Input",
  CellTags->"Cell 5.45"],

Cell[CellGroupData[{
Cell[29715640, 885945, 159, 4, 67, "Input",
  CellTags->"Cell 5.46"],
Cell[29715802, 885951, 104793, 1844, 302, 21344, 809, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[29820610, 887798, 291, 8, 85, "Input",
  CellTags->"Cell 5.47"],
Cell[29820904, 887808, 328, 7, 105, "Input",
  CellTags->"Cell 5.48"],

Cell[CellGroupData[{
Cell[29821257, 887819, 261, 6, 85, "Input",
  CellTags->"Cell 5.49"],

Cell[CellGroupData[{
Cell[29821543, 887829, 54694, 1543, 341, 11978, 1011, "GraphicsData", \
"PostScript", "Graphics"],
Cell[29876240, 889374, 54358, 1539, 340, 11970, 1011, "GraphicsData", \
"PostScript", "Graphics"],
Cell[29930601, 890915, 54501, 1541, 341, 11971, 1011, "GraphicsData", \
"PostScript", "Graphics"],
Cell[29985105, 892458, 54242, 1537, 341, 11972, 1011, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30039350, 893997, 54360, 1539, 341, 11976, 1011, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30093713, 895538, 54340, 1539, 341, 11972, 1011, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30148056, 897079, 54318, 1538, 341, 11971, 1011, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30202377, 898619, 54433, 1538, 341, 11948, 1009, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30256813, 900159, 54455, 1537, 341, 11921, 1007, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30311271, 901698, 54923, 1540, 341, 11916, 1005, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30366197, 903240, 55002, 1540, 341, 11897, 1003, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30421202, 904782, 55229, 1538, 341, 11853, 998, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30476434, 906322, 55528, 1538, 341, 11828, 994, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30531965, 907862, 55825, 1540, 341, 11793, 992, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30587793, 909404, 56161, 1540, 341, 11777, 988, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30643957, 910946, 56585, 1542, 341, 11735, 984, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30700545, 912490, 56754, 1542, 341, 11709, 981, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30757302, 914034, 57178, 1549, 341, 11700, 983, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30814483, 915585, 57528, 1553, 341, 11718, 983, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30872014, 917140, 57941, 1555, 341, 11694, 980, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30929958, 918697, 58528, 1559, 341, 11665, 976, "GraphicsData", \
"PostScript", "Graphics"],
Cell[30988489, 920258, 59455, 1574, 341, 11681, 980, "GraphicsData", \
"PostScript", "Graphics"],
Cell[31047947, 921834, 60151, 1583, 341, 11688, 980, "GraphicsData", \
"PostScript", "Graphics"],
Cell[31108101, 923419, 61051, 1595, 341, 11685, 981, "GraphicsData", \
"PostScript", "Graphics"],
Cell[31169155, 925016, 61581, 1602, 341, 11717, 982, "GraphicsData", \
"PostScript", "Graphics"],
Cell[31230739, 926620, 62416, 1613, 341, 11705, 982, "GraphicsData", \
"PostScript", "Graphics"],
Cell[31293158, 928235, 62548, 1616, 341, 11724, 984, "GraphicsData", \
"PostScript", "Graphics"],
Cell[31355709, 929853, 62936, 1619, 341, 11711, 982, "GraphicsData", \
"PostScript", "Graphics"]
}, Closed]]
}, Open  ]],
Cell[31418672, 931476, 561, 14, 77, "Text"],
Cell[31419236, 931492, 531311, 12204, 570, 109991, 6998, "GraphicsData", \
"PostScript", "Picture"],
Cell[31950550, 943698, 152, 4, 16, "Caption",
  CellTags->"Fig. 5.12"],
Cell[31950705, 943704, 1347, 22, 197, "Text",
  CellTags->"i:132"],
Cell[31952055, 943728, 651, 15, 78, "Text"],
Cell[31952709, 943745, 655, 16, 78, "Text",
  CellTags->"i:134"],
Cell[31953367, 943763, 1196, 29, 112, "Text",
  CellTags->"i:135"],
Cell[31954566, 943794, 6347453, 78367, 323, 6347332, 78363, "GraphicsData", \
"Bitmap", "Picture",
  Evaluatable->False],
Cell[38302022, 1022163, 198, 5, 16, "Caption",
  CellTags->"Fig. 5.13"]
}, Closed]],

Cell[CellGroupData[{
Cell[38302257, 1022173, 76, 1, 29, "Subsubtitle",
  CellTags->"c:36"],
Cell[38302336, 1022176, 1682, 54, 65, "Text"],
Cell[38304021, 1022232, 421, 14, 43, "Text"],
Cell[38304445, 1022248, 489, 11, 45, "NE3",
  CellTags->"(5.3.17)"],
Cell[38304937, 1022261, 445, 13, 43, "Text"],
Cell[38305385, 1022276, 1977, 42, 82, "NE3",
  CellTags->"(5.3.18)"],
Cell[38307365, 1022320, 2993, 90, 52, "Text"],
Cell[38310361, 1022412, 1988, 46, 50, "NE3",
  CellTags->"(5.3.19)"],
Cell[38312352, 1022460, 938, 33, 30, "Text"],
Cell[38313293, 1022495, 1347, 34, 50, "Text"],
Cell[38314643, 1022531, 53, 0, 26, "Text"],
Cell[38314699, 1022533, 641, 19, 37, "NE3",
  CellTags->"(5.3.20)"],
Cell[38315343, 1022554, 774, 26, 52, "Text"],
Cell[38316120, 1022582, 844, 29, 43, "Text"],
Cell[38316967, 1022613, 760, 21, 37, "NE3",
  CellTags->"(5.3.21)"],
Cell[38317730, 1022636, 497, 19, 26, "Text"],
Cell[38318230, 1022657, 763, 26, 37, "NE3",
  CellTags->"(5.3.22)"],
Cell[38318996, 1022685, 1144, 35, 26, "Text"],
Cell[38320143, 1022722, 1879, 48, 37, "NE3",
  CellTags->{"i:120", "(5.3.23)"}],
Cell[38322025, 1022772, 1143, 37, 48, "Text",
  CellTags->"i:92"],
Cell[38323171, 1022811, 899, 25, 80, "Text"],
Cell[38324073, 1022838, 143, 5, 28, "NE3",
  CellTags->"(5.3.24)"],
Cell[38324219, 1022845, 1289, 32, 128, "Text",
  CellTags->"i:93"]
}, Closed]],

Cell[CellGroupData[{
Cell[38325545, 1022882, 65, 1, 29, "Subsubtitle",
  CellTags->"c:37"],
Cell[38325613, 1022885, 810, 30, 47, "Text"],
Cell[38326426, 1022917, 307, 11, 27, "Text"],
Cell[38326736, 1022930, 122, 5, 27, "Text"],
Cell[38326861, 1022937, 226, 8, 31, "Text"],
Cell[38327090, 1022947, 433, 15, 52, "Text"],
Cell[38327526, 1022964, 1520, 50, 81, "Text"],
Cell[38329049, 1023016, 180, 8, 27, "Text"],
Cell[38329232, 1023026, 135, 7, 27, "Text"],
Cell[38329370, 1023035, 366, 13, 27, "Text"],
Cell[38329739, 1023050, 1040, 34, 31, "Text"],
Cell[38330782, 1023086, 881, 23, 53, "NE3",
  CellTags->"(5.3.25)"],
Cell[38331666, 1023111, 743, 20, 53, "Text"],
Cell[38332412, 1023133, 853, 29, 44, "Text"],
Cell[38333268, 1023164, 533, 22, 27, "Text"],
Cell[38333804, 1023188, 243, 11, 27, "Text"],
Cell[38334050, 1023201, 1003, 28, 91, "Text"],
Cell[38335056, 1023231, 179, 5, 27, "Text"],
Cell[38335238, 1023238, 263, 6, 44, "Text"],
Cell[38335504, 1023246, 262, 8, 44, "Text"]
}, Closed]]
}, Closed]],

Cell[CellGroupData[{
Cell[38335815, 1023260, 60, 1, 40, "Subtitle",
  CellTags->{"refs", "c:34"}],
Cell[38335878, 1023263, 194, 5, 43, "Text"],
Cell[38336075, 1023270, 160, 5, 26, "Text"],
Cell[38336238, 1023277, 229, 8, 26, "Text"],
Cell[38336470, 1023287, 348, 12, 51, "Text"],
Cell[38336821, 1023301, 160, 5, 26, "Text"],
Cell[38336984, 1023308, 158, 5, 26, "Text"],
Cell[38337145, 1023315, 175, 5, 26, "Text"],
Cell[38337323, 1023322, 143, 5, 26, "Text"],
Cell[38337469, 1023329, 206, 8, 26, "Text"]
}, Closed]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

